(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  64430254,    2158732]*)
(*NotebookOutlinePosition[  64431555,    2158773]*)
(*  CellTagsIndexPosition[  64431511,    2158769]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Vibrational Modes of the",
    FontColor->RGBColor[1, 0, 0]],
  " BSC",
  StyleBox[" Seismic Isolation System ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["(Initial LIGO SEI)",
    FontSize->18,
    FontColor->RGBColor[1, 0, 0]]
}], "Title",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  StyleBox["The modal calculations and visualization in this ",
    PageWidth->WindowWidth,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    PageWidth->WindowWidth,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" notebook are based upon the Hytec mass and stiffness matrices \
documented in:\n",
    PageWidth->WindowWidth,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"Times New Roman"],
  StyleBox["E. Ponslet, \"HAM and BSC Dynamic Models\", Hytec Inc., 4/22/98, \
LIGO-T990128-00",
    FontFamily->"Times New Roman"],
  StyleBox[" (http://www.ligo.caltech.edu/docs/T/T990128-00.pdf)\nThese mode \
shapes are for the passive isolation stack and a 12 dof representation of the \
elastic support structure.\n",
    PageWidth->WindowWidth,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"Times New Roman"],
  StyleBox["Notes:\n(1) The latest version of this document (T990128) was \
issued later than the model files that are used (and the only ones available \
at this date) for this analysis. The latest document refers to additional \
information in the model files which are not present in the available files. \
The model files used were issued in conjunction with a draft release of \
T990128 on 4/22/1998. According to Hytec, the additional data in the model \
files referred to in the later version of T990128-00 do not exist.",
    FontFamily->"Times New Roman"],
  StyleBox["\n(2) The eigenvector components for the optics table (the modal \
participation factors) are listed for all of the modes. In addition, for all \
modes that have a significant participation by the optics table, there are \
modal displacement plots and modal animations. One can read the notebook and \
display the modes dynamically with either Mathematica or the free MathReader \
application available from Wolfram research at:\n\t\
http://www.wolfram.com/products/mathreader/\nTo animate the modes, select the \
bracket at the right edge of the window, with an arrow at the bottom, and \
then select the menu item \"Cell\" --> \"Animate Selected Graphics\" (or just \
type Ctrl+Y). The cell bracket with an arrow at the bottom represents a \
closed set of cells; Double-clicking will open and display the sequence of \
graphics used to create the animation of the mode.\n(3) If you have \
Mathematica and attempt to recalculate the mode shapes, you will need the \
data file BSC_SEI_MK.txt, which is available in the same directory: ",
    PageWidth->WindowWidth,
    AspectRatioFixed->False,
    ImageRegion->{{0, 1}, {0, 1}},
    FontFamily->"Times New Roman"]
}], "Text",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}},
  FontFamily->"Courier"],

Cell[CellGroupData[{

Cell["Version History", "Subsection",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["version 1", "Subsubsection",
  PageWidth->PaperWidth],

Cell["\<\
1/30/2002 Calcualtion & visualization of the natural modes based on the Hytec \
mass and stiffness matrices. [Version 1 was done only for the BSC SEI system, \
but to keep the versions in synch, I will use the same version numbering for \
the HAM analysis.] Reads the mass and stiffness matrices from the file \
MK_BSC_SEI.txt. This file is created from the original Hytec Matlab model \
file (described in T980128) with the Matlab script HytecModel_2_Mathenatica.m\
\
\>", "Text",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["version 2", "Subsubsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "3/26/2002\na) Corrected the Euler angle convention/sequence used for \
visualizing the mode shapes.\nb) Added mode number and modal mass in the \
optics table modal participation factor table (and generated the table for \
all modes).\nc) Attempted to get a better diagonalization of the modal mass \
matrix by trying other transformations from the generalized to the standard \
eigenproblem, but was not sucessful; There modal mass matrix has some \
significant, complex off-diagonal terms. Perhaps there is a problem with the \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " routine?\nd) Generated a list of all modes with any optics table modal \
participation factor greater than a threshold; Used this list to plot mode \
shapes relevant to motion of the optics table. "
}], "Text",
  PageWidth->PaperWidth]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(Off[General::"\<spell\>"]\), "\n", 
    \(Off[General::"\<spell1\>"]\)}], "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Needs["\<Graphics`Animation`\>"];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Geometry`Rotations`\>"]\)], "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["RotationMatrix3D[phi,theta,psi]", "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->True],

Cell[BoxData[
    \({{Cos[phi]\ Cos[psi] - Cos[theta]\ Sin[phi]\ Sin[psi], 
        Cos[psi]\ Sin[phi] + Cos[phi]\ Cos[theta]\ Sin[psi], 
        Sin[psi]\ Sin[theta]}, {\(-Cos[psi]\)\ Cos[theta]\ Sin[phi] - 
          Cos[phi]\ Sin[psi], 
        Cos[phi]\ Cos[psi]\ Cos[theta] - Sin[phi]\ Sin[psi], 
        Cos[psi]\ Sin[theta]}, {Sin[phi]\ Sin[theta], \(-Cos[phi]\)\ Sin[
            theta], Cos[theta]}}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell["\<\
Note: Per J. Wertz, \"Spacecraft Attitude Determination and Control\", D. \
Reidel Pub., 1985, pp.763-764, This is a Type 2 Euler Angle representation \
with a z-x-z rotation sequence.\
\>", "Text",
  PageWidth->PaperWidth,
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Shapes`\>"]\)], "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< LinearAlgebra`Cholesky`\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(<< LinearAlgebra`MatrixManipulation`\)], "Input",
  PageWidth->PaperWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["Test rotation & translation directions", "Subsection",
  PageWidth->PaperWidth],

Cell["\<\
See the companion HAM SEI vibration mode Mathematica Notebook (T020045) for \
determination of the correct rotation & translation convention.\
\>", "Text",
  PageWidth->PaperWidth,
  FontColor->RGBColor[0, 1, 0]],

Cell["\<\
To rotate  +alpha about the x-axis:
    RotateShape[<shape>,-alpha,0,0]
To rotate +beta about the y-axis:
    RotateShape[<shape>,Pi/2,-beta,-Pi/2]
To rotate +gamma about the z-axis:
    RotateShape[<shape>,-gamma,0,0]
So, to rotate alpha, beta, gamma:
    RotateShape[RotateShape[<shape>,Pi/2,-beta,-gamma-Pi/2],0,-alpha,0]\
\>", "Text",
  PageWidth->PaperWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["Read Global Stiffness and Mass Matrices", "Section",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(\(fread = 
        OpenRead["\<C:/ligo1/SEI/LIGOStackModels/BSC_SEI/BSC_SEI_MK.txt\>"];\)\
\), "\[IndentingNewLine]", 
    \(\(nm = \(Read[fread, {Number}]\)[\([1]\)];\)\), "\[IndentingNewLine]", 
    \(\(format = Table[Number, {nm}, {6}];\)\), "\[IndentingNewLine]", 
    \(\(massdof = Read[fread, format];\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[massdof]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({16, 6}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[massdof]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    TagBox[GridBox[{
          {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`"},
          {"1.`", "2.`", "3.`", "4.`", "5.`", "6.`"},
          {"7.`", "8.`", "9.`", "10.`", "11.`", "12.`"},
          {"13.`", "14.`", "15.`", "16.`", "17.`", "18.`"},
          {"19.`", "20.`", "21.`", "22.`", "23.`", "24.`"},
          {"25.`", "26.`", "27.`", "28.`", "29.`", "30.`"},
          {"31.`", "32.`", "33.`", "34.`", "35.`", "36.`"},
          {"37.`", "38.`", "39.`", "40.`", "41.`", "42.`"},
          {"43.`", "44.`", "45.`", "46.`", "47.`", "48.`"},
          {"49.`", "50.`", "51.`", "52.`", "53.`", "54.`"},
          {"55.`", "56.`", "57.`", "58.`", "59.`", "60.`"},
          {"61.`", "62.`", "63.`", "64.`", "65.`", "66.`"},
          {"67.`", "68.`", "69.`", "70.`", "71.`", "72.`"},
          {"73.`", "74.`", "75.`", "76.`", "77.`", "78.`"},
          {"79.`", "80.`", "81.`", "82.`", "83.`", "84.`"},
          {"85.`", "86.`", "87.`", "88.`", "89.`", "90.`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[{
    \(\(km = 6*\((nm - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(format = Table[Number, {km}, {km}];\)\), "\[IndentingNewLine]", 
    \(\(M = Read[fread, format];\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[M[\([i, i]\)], {i, 1, km}]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({1983.684`, 1983.684`, 1983.684`, 4607.255999999999`, 6270.987`, 
      10878.24`, 433.1275`, 433.1275`, 433.1275`, 95.67786999999998`, 
      263.5148`, 359.1927`, 280.3702`, 280.3702`, 280.3702`, 5.631067`, 
      5.631067`, 10.229099999999999`, 173.2752`, 173.2752`, 173.2752`, 
      3.268547`, 3.268547`, 6.348631`, 109.63510000000001`, 
      109.63510000000001`, 109.63510000000001`, 1.99408`, 1.99408`, 
      3.990209`, 280.3702`, 280.3702`, 280.3702`, 5.631067`, 5.631067`, 
      10.229099999999999`, 173.2752`, 173.2752`, 173.2752`, 3.268547`, 
      3.268547`, 6.348631`, 109.63510000000001`, 109.63510000000001`, 
      109.63510000000001`, 1.99408`, 1.99408`, 3.990209`, 280.3702`, 
      280.3702`, 280.3702`, 5.631067`, 5.631067`, 10.229099999999999`, 
      173.2752`, 173.2752`, 173.2752`, 3.268547`, 3.268547`, 6.348631`, 
      109.63510000000001`, 109.63510000000001`, 109.63510000000001`, 
      1.99408`, 1.99408`, 3.990209`, 280.3702`, 280.3702`, 280.3702`, 
      5.631067`, 5.631067`, 10.229099999999999`, 173.2752`, 173.2752`, 
      173.2752`, 3.268547`, 3.268547`, 6.348631`, 109.63510000000001`, 
      109.63510000000001`, 109.63510000000001`, 1.99408`, 1.99408`, 
      3.990209`, 639.576`, 639.576`, 639.576`, 277.8`, 277.8`, 
      125.39`}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tr[M]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(39253.80818199995`\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tr[M + Transpose[M]]/2\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(39253.80818199995`\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[{
    \(\(Kr = Read[fread, format];\)\), "\[IndentingNewLine]", 
    \(\(Ki = Read[fread, format];\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(K = Kr + I\ Ki;\)\)], "Input",
  PageWidth->PaperWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenproblem:", "Section",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
    \(nDOFs = Round[km]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(90\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell["\<\
Check that M is positive definite (symmetric & m[[i,i]] > 0):\
\>", "Text",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[Abs[Table[M[\([i, i]\)], {i, 1, nDOFs}]]] > 0\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(True\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Md = Flatten[M - Transpose[M]];\)\), "\[IndentingNewLine]", 
    \(Md . Table[1, {\(Dimensions[Md]\)[\([1]\)]}] \[Equal] 0\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(True\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["transformation to the standard eigenproblem by Inverse[M].K", \
"Subsubsection",
  PageWidth->PaperWidth],

Cell[TextData[{
  "N.B.: The resulting modal matrix is not quite diagonal and has some \
complex entries. Attempts to factor M and K to transform from the generalized \
eigenproblem to the standard form eigenproblem (see subsections in the \
companion ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook for the HAM SEI, T020045) were not sucessful. The eigenvalues \
(vibration frequencies) and the mode shapes appear to be reasonable."
}], "Text",
  PageWidth->PaperWidth,
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[{
    \(\(Clear[vals, vecs];\)\), "\n", 
    \(\({vals, vecs} = Eigensystem[Inverse[M] . Kr];\)\)}], "Input",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(test = 
        Table[Max[
            Abs[Inverse[M] . Kr . vecs[\([i]\)] - 
                vals[\([i]\)]\ vecs[\([i]\)]]], {i, 1, nDOFs}];\)\), "\n", 
    \(Chop[test, 10^\(-5\)]\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
      0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Max[Im[vals]]\), "\[IndentingNewLine]", 
    \(Min[Im[vals]]\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(5.113003699644472`*^-11\)], "Output",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(-5.113003699644472`*^-11\)\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(freqs = Reverse[Sqrt[Re[vals]]/\((2\ Pi)\)]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({1.3573695695536339`, 1.3589970153897604`, 2.258504055131208`, 
      2.3517602945677583`, 2.3598988957761797`, 2.839469025058277`, 
      4.987391033546805`, 4.987391033546806`, 4.987391033546843`, 
      4.9873910335468485`, 4.9873910335468645`, 5.605433900714147`, 
      5.628853194275645`, 5.644402753529235`, 6.308757524070883`, 
      6.382330995002581`, 6.394839808884578`, 6.394839808884624`, 
      6.394839808884648`, 6.435172469202728`, 6.548198516685221`, 
      6.577070071926744`, 8.347298767731479`, 8.347298767731479`, 
      8.347298767731484`, 8.347298767731505`, 8.34729876773159`, 
      9.714617314885999`, 9.752535240165791`, 9.931230984824033`, 
      10.224504837396527`, 10.246105061388016`, 10.591178425646612`, 
      10.696221996221263`, 11.05712678791932`, 11.328523591985396`, 
      11.355428498140526`, 11.355428498140604`, 11.355428498140604`, 
      11.355428498140618`, 11.355428498140634`, 11.410790221356642`, 
      12.556883491675537`, 12.56651802009812`, 12.56651802009812`, 
      12.566518020098123`, 12.859254392790367`, 12.883764565444826`, 
      12.89693915642458`, 12.93290908819772`, 12.93290908819773`, 
      12.93290908819773`, 12.932909088197736`, 12.932909088197745`, 
      12.948298795553866`, 13.54821250631116`, 13.645329329759143`, 
      13.825563588829256`, 15.25519691856167`, 15.255196918561712`, 
      15.255196918561714`, 15.255196918561714`, 15.255196918561746`, 
      15.261643524373559`, 15.278382473820768`, 15.278805936283119`, 
      15.548494759603141`, 16.224616979580794`, 16.263096237724497`, 
      16.263814462986804`, 16.263814462986804`, 16.263814462986822`, 
      16.263814462986847`, 16.26381446298686`, 17.35677918398194`, 
      17.36345248836199`, 17.36345248836202`, 17.363452488362025`, 
      17.49419168586583`, 19.462829635092803`, 25.32379337748972`, 
      42.41170228818538`, 66.78249183815726`, 70.33630414682338`, 
      85.6946675213086`, 110.24393579509407`, 134.0354238118141`, 
      183.954295688122`, 214.3587119945904`, 227.18728114792728`}\)], "Output",\

  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[
    \(\(Mm = vecs . M . Transpose[vecs];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[Chop[Mm, 10^\(-9\)]]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    TagBox[GridBox[{
          {"1970.3200338966358`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "4547.942270679622`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "6250.832170496576`", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "506.88490190237377`", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "501.9983005990669`", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "368.8677759724001`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "95.7541496041355`", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "433.64907311930403`", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "263.635798697288`", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "374.930892891944`", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "385.6945817714399`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "11.842100456922365`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "6.654426708459394`", 
            "1.5903926944098816`", \(-0.16340338948472682`\), "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "1.5903926944098816`", 
            "6.654426708459398`", \(-0.13131417580120325`\), "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-0.16340338948472682`\), \(-0.13131417580120303`\), 
            "6.6544267084594`", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "6.659380653625257`", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "4.114790341087525`", "3.199997794866865`", 
            "0.17930491490774725`", \(\(-1.3992231531289423`\) - 
              0.5027144400764756`\ \[ImaginaryI]\), \
\(\(-1.3992231531289423`\) + 0.5027144400764756`\ \[ImaginaryI]\), "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "3.199997794866865`", 
            "4.114790341087539`", \(-0.16658062523288852`\), \
\(\(-1.0126655053674583`\) + 
              0.34483459065681205`\ \[ImaginaryI]\), \(\(-1.0126655053674583`\
\) - 0.34483459065681205`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0.17930491490774725`", \(-0.16658062523288855`\), 
            "4.1147903410875`", \(\(-0.4623804937482608`\) - 
              0.22867542126916493`\ \[ImaginaryI]\), \(\(-0.4623804937482608`\
\) + 0.22867542126916493`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", 
            "0", \(\(-1.3992231531289423`\) - 
              0.5027144400764756`\ \[ImaginaryI]\), \
\(\(-1.0126655053674583`\) + 
              0.34483459065681205`\ \[ImaginaryI]\), \(\(-0.4623804937482608`\
\) - 0.22867542126916493`\ \[ImaginaryI]\), \(\(\(0.845320215460408`\)\(\
\[InvisibleSpace]\)\) + 1.4690748880331326`\ \[ImaginaryI]\), 
            "4.114790341087506`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", 
            "0", \(\(-1.3992231531289423`\) + 
              0.5027144400764756`\ \[ImaginaryI]\), \
\(\(-1.0126655053674583`\) - 
              0.34483459065681205`\ \[ImaginaryI]\), \(\(-0.4623804937482608`\
\) + 0.22867542126916493`\ \[ImaginaryI]\), 
            "4.114790341087506`", \(\(\(0.845320215460408`\)\(\
\[InvisibleSpace]\)\) - 1.4690748880331326`\ \[ImaginaryI]\), "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "4.177977435169928`", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "4.156993051040156`",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "6.790333137030773`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "9.492749884695618`", \(-1.6533161040531215`*^-9\), "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-1.6533162428309996`*^-9\), "9.423095280033248`", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "6.657717691950877`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "8.931391026568951`", \(\(\(3.2974255639319066`\)\(\
\[InvisibleSpace]\)\) - 
              3.6203203965320827`\ \[ImaginaryI]\), \(\(\(3.2974255639319066`\
\)\(\[InvisibleSpace]\)\) + 
              3.6203203965320827`\ \[ImaginaryI]\), \(-4.353181411985574`\), \
\(-3.8118637759544147`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(3.2974255639319066`\)\(\[InvisibleSpace]\)\) - 
              3.6203203965320827`\ \[ImaginaryI]\), \(\(\(1.8069288908159975`\
\)\(\[InvisibleSpace]\)\) - 1.8298667419272514`\ \[ImaginaryI]\), 
            "8.931391026568637`", \(\(-2.4254810202680948`\) + 
              3.0950523683021003`\ \[ImaginaryI]\), \
\(\(\(0.39995318367290716`\)\(\[InvisibleSpace]\)\) + 
              2.9368189641482982`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(3.2974255639319066`\)\(\[InvisibleSpace]\)\) + 
              3.6203203965320827`\ \[ImaginaryI]\), 
            "8.931391026568637`", \(\(\(1.8069288908159975`\)\(\
\[InvisibleSpace]\)\) + 
              1.8298667419272514`\ \[ImaginaryI]\), \
\(\(-2.4254810202680948`\) - 
              3.0950523683021003`\ \[ImaginaryI]\), \
\(\(\(0.39995318367290716`\)\(\[InvisibleSpace]\)\) - 
              2.9368189641482982`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-4.353181411985575`\), \(\(-2.4254810202680943`\) + 
              3.0950523683021007`\ \[ImaginaryI]\), \
\(\(-2.4254810202680943`\) - 3.0950523683021007`\ \[ImaginaryI]\), 
            "8.93139102656858`", "3.095387718936019`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-3.811863775954415`\), \(\(\(0.3999531836729068`\)\(\
\[InvisibleSpace]\)\) + 
              2.9368189641482982`\ \[ImaginaryI]\), \(\(\(0.3999531836729068`\
\)\(\[InvisibleSpace]\)\) - 2.9368189641482982`\ \[ImaginaryI]\), 
            "3.0953877189360184`", "8.931391026568495`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "10.896973822528572`", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "9.262409109275183`", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "15.749958618883147`", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "163.66856388579862`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "7.147313482127543`", \(-1.8567868119430726`\), \
\(\(\(0.9688767256482074`\)\(\[InvisibleSpace]\)\) - 
              0.8554429357203801`\ \[ImaginaryI]\), \(\(\(0.9688767256482074`\
\)\(\[InvisibleSpace]\)\) + 
              0.8554429357203801`\ \[ImaginaryI]\), \(-3.4413827650856224`\), 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-1.8567868119430735`\), 
            "7.147313482127507`", \(\(-1.3745227203735202`\) + 
              1.2958486490241736`\ \[ImaginaryI]\), \
\(\(-1.3745227203735202`\) - 1.2958486490241736`\ \[ImaginaryI]\), 
            "3.2718398639219166`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(0.9688767256482074`\)\(\[InvisibleSpace]\)\) - 
              0.85544293572038`\ \[ImaginaryI]\), \(\(-1.3745227203735204`\) \
+ 1.2958486490241736`\ \[ImaginaryI]\), \(\(\(2.3553210444437545`\)\(\
\[InvisibleSpace]\)\) - 2.367325206681916`\ \[ImaginaryI]\), 
            "7.147313482127628`", \(\(-1.5248844978542213`\) + 
              2.611304533115611`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(0.9688767256482074`\)\(\[InvisibleSpace]\)\) + 
              0.85544293572038`\ \[ImaginaryI]\), \(\(-1.3745227203735204`\) \
- 1.2958486490241736`\ \[ImaginaryI]\), 
            "7.147313482127628`", \(\(\(2.3553210444437545`\)\(\
\[InvisibleSpace]\)\) + 
              2.367325206681916`\ \[ImaginaryI]\), \(\(-1.5248844978542213`\) \
- 2.611304533115611`\ \[ImaginaryI]\), "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-3.4413827650856224`\), 
            "3.2718398639219166`", \(\(-1.5248844978542215`\) + 
              2.611304533115611`\ \[ImaginaryI]\), \(\(-1.5248844978542215`\) \
- 2.611304533115611`\ \[ImaginaryI]\), "7.147313482127634`", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "167.60951421581638`", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "80.39039245629085`", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "76.53453688939062`", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", 
            "5.9118666194860765`", \(-1.0628843310049918`\), \
\(-5.150958114239659`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", \(-1.0628843310049922`\), 
            "5.911866619486073`", "0.3055149983060006`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", \(-5.150958114239659`\), 
            "0.3055149983060007`", "5.911866619486073`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "5.930911005844797`", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "5.601703135057916`",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "4.964979533251161`", 
            "0.22284341379096706`", \(\(\(1.7306087079180485`\)\(\
\[InvisibleSpace]\)\) + 
              0.29930303401111963`\ \[ImaginaryI]\), \
\(\(\(1.7306087079180485`\)\(\[InvisibleSpace]\)\) - 
              0.29930303401111963`\ \[ImaginaryI]\), "1.6089732964228485`", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0.22284341379096753`", 
            "4.964979533251095`", \(\(\(3.7474774774775557`\)\(\
\[InvisibleSpace]\)\) + 
              0.9120510835531214`\ \[ImaginaryI]\), \(\(\(3.7474774774775557`\
\)\(\[InvisibleSpace]\)\) - 0.9120510835531214`\ \[ImaginaryI]\), 
            "3.357313417041592`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(1.7306087079180483`\)\(\[InvisibleSpace]\)\) + 
              0.29930303401111963`\ \[ImaginaryI]\), \(\(\(3.747477477477555`\
\)\(\[InvisibleSpace]\)\) + 
              0.9120510835531214`\ \[ImaginaryI]\), \
\(\(\(2.930398165463102`\)\(\[InvisibleSpace]\)\) + 
              0.4684990805127628`\ \[ImaginaryI]\), 
            "4.964979533251062`", \(\(\(2.8680080138478514`\)\(\
\[InvisibleSpace]\)\) + 0.25165778622808116`\ \[ImaginaryI]\), "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(\(1.7306087079180483`\)\(\[InvisibleSpace]\)\) - 
              0.29930303401111963`\ \[ImaginaryI]\), \(\(\(3.747477477477555`\
\)\(\[InvisibleSpace]\)\) - 0.9120510835531214`\ \[ImaginaryI]\), 
            "4.964979533251062`", \(\(\(2.930398165463102`\)\(\
\[InvisibleSpace]\)\) - 
              0.4684990805127628`\ \[ImaginaryI]\), \(\(\(2.8680080138478514`\
\)\(\[InvisibleSpace]\)\) - 0.25165778622808116`\ \[ImaginaryI]\), "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "1.6089732964228485`", 
            "3.357313417041592`", \(\(\(2.8680080138478514`\)\(\
\[InvisibleSpace]\)\) + 
              0.25165778622808116`\ \[ImaginaryI]\), \
\(\(\(2.8680080138478514`\)\(\[InvisibleSpace]\)\) - 
              0.25165778622808116`\ \[ImaginaryI]\), "4.964979533250855`", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "5.4336730073597455`", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "3.980621135230109`", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "6.314305359651992`", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "10.736632635802362`", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "4.448297913144369`", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "166.34356666693725`", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "154.8422606152989`", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "16.230844266968262`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "16.84120720338277`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "3.533888476597641`", \(-2.0013756854432234`\), 
            "1.8143308429332945`", \(\(-1.3207572629929043`\) - 
              0.004640496489466739`\ \[ImaginaryI]\), \
\(\(-1.3207572629929043`\) + 0.004640496489466739`\ \[ImaginaryI]\), "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-2.0013756854432234`\), 
            "3.5338884765977845`", \(-2.4799131816632216`\), \
\(\(\(1.3142385375947614`\)\(\[InvisibleSpace]\)\) + 
              1.5650753420132537`\ \[ImaginaryI]\), \(\(\(1.3142385375947614`\
\)\(\[InvisibleSpace]\)\) - 1.5650753420132537`\ \[ImaginaryI]\), "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "1.8143308429332943`", \(-2.4799131816632216`\), 
            "3.533888476597835`", \(\(-1.9190513335120094`\) - 
              0.5932655891377422`\ \[ImaginaryI]\), \
\(\(-1.9190513335120094`\) + 0.5932655891377422`\ \[ImaginaryI]\), "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(-1.320757262992904`\) - 
              0.004640496489466739`\ \[ImaginaryI]\), \
\(\(\(1.3142385375947614`\)\(\[InvisibleSpace]\)\) + 
              
              1.5650753420132542`\ \[ImaginaryI]\), \
\(\(-1.9190513335120094`\) - 
              0.5932655891377422`\ \[ImaginaryI]\), \(\(\(0.5363572473512401`\
\)\(\[InvisibleSpace]\)\) + 0.23334422840050809`\ \[ImaginaryI]\), 
            "3.5338884765978484`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(\(-1.320757262992904`\) + 
              0.004640496489466739`\ \[ImaginaryI]\), \
\(\(\(1.3142385375947614`\)\(\[InvisibleSpace]\)\) - 
              1.5650753420132542`\ \[ImaginaryI]\), \
\(\(-1.9190513335120094`\) + 0.5932655891377422`\ \[ImaginaryI]\), 
            "3.5338884765978484`", \(\(\(0.5363572473512401`\)\(\
\[InvisibleSpace]\)\) - 0.23334422840050809`\ \[ImaginaryI]\), "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "7.086814257914002`", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "8.502424868848484`", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "8.928938308444893`", "0", "0", "0", "0",
             "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", 
            "5.363057387948494`", \(-0.04049485647380896`\), \
\(-0.06424737860081894`\), "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", \(-0.04049485647380888`\), 
            "5.363057387948498`", "0.43724403221593244`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", \(-0.06424737860081894`\), 
            "0.4372440322159322`", "5.3630573879484995`", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "239.55183342358515`", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "6.319828874258894`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "94.64118492040433`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "81.61700208398968`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "165.7107357241594`", "0", "0", "0", "0", "0", "0", "0", "0", "0",
             "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "41.3431367240783`", 
            "38.326807004306474`", \(-36.082268376843466`\), 
            "17.236826611681668`", \(-17.212934572661563`\), "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "38.32680700430647`", 
            "41.34313672407823`", \(-40.968916508827974`\), 
            "26.18728480410185`", \(-26.15336792887002`\), "0", "0", "0", "0",
             "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-36.082268376843466`\), \(-40.968916508827974`\), 
            "41.343136724078235`", \(-28.241938553116196`\), 
            "28.228081196644023`", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "17.236826611681668`", 
            "26.18728480410185`", \(-28.241938553116196`\), 
            "41.34313672407811`", \(-41.335190925936466`\), "0", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-17.212934572661563`\), \(-26.15336792887002`\), 
            "28.228081196644023`", \(-41.335190925936466`\), 
            "41.34313672407811`", "0", "0", "0", "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "268.39049756928125`", "0", "0", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "27.57983113493756`", "0", "0",
             "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "28.141277905312077`", 
            "0", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "24.497472964941895`", "0", "0"},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "168.73385466065702`", \(-6.4604194924428285`*^-9\)},
          {"0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", "0", "0", "0", "0", "0", "0", "0", "0", 
            "0", \(-6.460419714487433`*^-9\), "168.48877476268353`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  PageWidth->PaperWidth]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Flatten[Mm] . 
      Table[1, {\(Dimensions[Flatten[Mm]]\)[\([1]\)]}]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(\(18239.8681091627`\)\(\[InvisibleSpace]\)\) + 
      1.7748226178384401`*^-15\ \[ImaginaryI]\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tr[Re[Mm]]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(18342.246616097364`\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Tr[M]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(39253.80818199995`\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(modalMass = Table[\(Re[Mm]\)[\([i, i]\)], {i, 1, nDOFs}]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({1970.3200338966358`, 4547.942270679622`, 6250.832170496576`, 
      506.88490190237377`, 501.9983005990669`, 368.8677759724001`, 
      95.7541496041355`, 433.64907311930403`, 263.635798697288`, 
      374.930892891944`, 385.6945817714399`, 11.842100456922365`, 
      6.654426708459394`, 6.654426708459398`, 6.6544267084594`, 
      6.659380653625257`, 4.114790341087525`, 4.114790341087539`, 
      4.1147903410875`, 0.845320215460408`, 0.845320215460408`, 
      4.177977435169928`, 4.156993051040156`, 6.790333137030773`, 
      9.492749884695618`, 9.423095280033248`, 6.657717691950877`, 
      8.931391026568951`, 1.8069288908159975`, 1.8069288908159975`, 
      8.93139102656858`, 8.931391026568495`, 10.896973822528572`, 
      9.262409109275183`, 15.749958618883147`, 163.66856388579862`, 
      7.147313482127543`, 7.147313482127507`, 2.3553210444437545`, 
      2.3553210444437545`, 7.147313482127634`, 167.60951421581638`, 
      80.39039245629085`, 76.53453688939062`, 5.9118666194860765`, 
      5.911866619486073`, 5.911866619486073`, 5.930911005844797`, 
      5.601703135057916`, 4.964979533251161`, 4.964979533251095`, 
      2.930398165463102`, 2.930398165463102`, 4.964979533250855`, 
      5.4336730073597455`, 3.980621135230109`, 6.314305359651992`, 
      10.736632635802362`, 4.448297913144369`, 166.34356666693725`, 
      154.8422606152989`, 16.230844266968262`, 16.84120720338277`, 
      3.533888476597641`, 3.5338884765977845`, 3.533888476597835`, 
      0.5363572473512401`, 0.5363572473512401`, 7.086814257914002`, 
      8.502424868848484`, 8.928938308444893`, 5.363057387948494`, 
      5.363057387948498`, 5.3630573879484995`, 239.55183342358515`, 
      6.319828874258894`, 94.64118492040433`, 81.61700208398968`, 
      165.7107357241594`, 41.3431367240783`, 41.34313672407823`, 
      41.343136724078235`, 41.34313672407811`, 41.34313672407811`, 
      268.39049756928125`, 27.57983113493756`, 28.141277905312077`, 
      24.497472964941895`, 168.73385466065702`, 
      168.48877476268353`}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[
    \(\(vecs = Reverse[vecs];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(opticstableVecs = 
        Transpose[Take[Transpose[vecs], \(-6\)]];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(threshold = 0.01;\)\), "\n", 
    \(\(opticstableModes = 1;\)\), "\n", 
    \(\(Do[\[IndentingNewLine]If[\[IndentingNewLine]Max[
              Abs[opticstableVecs[\([i]\)]]] > 
            threshold, \[IndentingNewLine]opticstableModes = 
            Flatten[{opticstableModes, i}], \[IndentingNewLine]], {i, 2, 
          nDOFs}];\)\), "\n", 
    \(opticstableModes\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({1, 2, 3, 4, 5, 6, 13, 14, 15, 16, 20, 21, 22, 28, 29, 31, 32, 33, 34, 
      36, 42, 47, 48, 55, 56, 57, 58, 65, 66, 67, 68, 69}\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nTableLength = nDOFs;\)\), "\n", 
    \(\(tableHead = {"\<freq (Hz)\>", "\<x\>", "\<y\>", "\<z\>", "\<Rx\>", \
"\<Ry\>", "\<Rz\>"};\)\), "\n", 
    \(\(tableLabel = Table[i, {i, nTableLength}];\)\), "\n", 
    \(\(opticsTableModeShapes = 
        Transpose[
          Partition[
            Join[Take[freqs, nTableLength], 
              Flatten[Transpose[Take[opticstableVecs, nTableLength]]]], 
            nTableLength]];\)\), "\n", 
    \(Print[
      TableForm[Chop[opticsTableModeShapes, 10^\(-5\)], 
        TableHeadings \[Rule] {tableLabel, tableHead}]]\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"freq (Hz)\"\>", "\<\"x\"\>", "\<\"y\"\>", \
"\<\"z\"\>", "\<\"Rx\"\>", "\<\"Ry\"\>", "\<\"Rz\"\>"},
          {"1", "1.3573695695536339`", "0", "0.4354605412437912`", "0", 
            "0.3174660532830821`", "0", "0"},
          {"2", "1.3589970153897604`", "0.4358256659268467`", "0", "0", 
            "0", \(-0.31894523971908373`\), "0"},
          {"3", "2.258504055131208`", "0", "0", "0", "0", 
            "0", \(-0.23995101998645904`\)},
          {"4", "2.3517602945677583`", "0", \(-0.01296920154788037`\), "0", 
            "0.17484993359609935`", "0", "0"},
          {"5", "2.3598988957761797`", "0.013687997143602026`", "0", "0", "0",
             "0.17299286228890173`", "0"},
          {"6", "2.839469025058277`", "0", "0", \(-0.5179605215713575`\), "0",
             "0", "0"},
          {"7", "4.987391033546805`", "0", "0", "0", "0", "0", "0"},
          {"8", "4.987391033546806`", "0", "0", "0", "0", "0", "0"},
          {"9", "4.987391033546843`", "0", "0", "0", "0", "0", "0"},
          {"10", "4.9873910335468485`", "0", "0", "0", "0", "0", "0"},
          {"11", "4.9873910335468645`", "0", "0", "0", "0", "0", "0"},
          {"12", "5.605433900714147`", "0", "0", "0", "0", "0", "0"},
          {"13", "5.628853194275645`", "0", \(-0.0838878972178837`\), 
            "0", \(-0.0277983356139932`\), "0", "0"},
          {"14", "5.644402753529235`", \(-0.08770560083591984`\), "0", "0", 
            "0", "0.0389315762987978`", "0"},
          {"15", "6.308757524070883`", "0", "0", "0", "0", 
            "0", \(-0.049609184686489456`\)},
          {"16", "6.382330995002581`", "0", "0", "0.3152518045774056`", "0", 
            "0", "0"},
          {"17", "6.394839808884578`", "0", "0", "0", "0", "0", "0"},
          {"18", "6.394839808884624`", "0", "0", "0", "0", "0", "0"},
          {"19", "6.394839808884648`", "0", "0", "0", "0", "0", "0"},
          {"20", "6.435172469202728`", "0", \(-0.01777492299671598`\), "0", 
            "0.059942740114921636`", "0", "0"},
          {"21", "6.548198516685221`", "0.01928962060485302`", "0", "0", "0", 
            "0.059165173957675565`", "0"},
          {"22", "6.577070071926744`", "0", "0", "0", "0", "0", 
            "0.08189279171742733`"},
          {"23", "8.347298767731479`", "0", "0", "0", "0", "0", "0"},
          {"24", "8.347298767731479`", "0", "0", "0", "0", "0", "0"},
          {"25", "8.347298767731484`", "0", "0", "0", "0", "0", "0"},
          {"26", "8.347298767731505`", "0", "0", "0", "0", "0", "0"},
          {"27", "8.34729876773159`", "0", "0", "0", "0", "0", "0"},
          {"28", "9.714617314885999`", "0", "0.03585990495056744`", 
            "0", \(-0.03946335811339076`\), "0", "0"},
          {"29", "9.752535240165791`", \(-0.03228559427323165`\), "0", "0", 
            "0", \(-0.030869717045384423`\), "0"},
          {"30", "9.931230984824033`", "0", "0", "0", "0", "0", "0"},
          {"31", "10.224504837396527`", "0", "0", \(-0.14512049187229217`\), 
            "0", "0", "0"},
          {"32", "10.246105061388016`", "0", "0", "0", "0", "0", 
            "0.10537707547295953`"},
          {"33", "10.591178425646612`", "0", "0.029851934196357992`", 
            "0", \(-0.08468272726296523`\), "0", "0"},
          {"34", "10.696221996221263`", "0.023956794616841356`", "0", "0", 
            "0", "0.06611379717523583`", "0"},
          {"35", "11.05712678791932`", "0", "0.0011859341325115942`", 
            "0", \(-0.005422278930320811`\), "0", "0"},
          {"36", "11.328523591985396`", "0.008637059508573191`", "0", "0", 
            "0", "0.017936688252801442`", "0"},
          {"37", "11.355428498140526`", "0", "0", "0", "0", "0", "0"},
          {"38", "11.355428498140604`", "0", "0", "0", "0", "0", "0"},
          {"39", "11.355428498140604`", "0", "0", "0", "0", "0", "0"},
          {"40", "11.355428498140618`", "0", "0", "0", "0", "0", "0"},
          {"41", "11.355428498140634`", "0", "0", "0", "0", "0", "0"},
          {"42", "11.410790221356642`", "0", "0", "0", "0", 
            "0", \(-0.03460043162867133`\)},
          {"43", "12.556883491675537`", "0", "0", "0", "0", 
            "0", \(-0.0012514147879967264`\)},
          {"44", "12.56651802009812`", "0", "0", "0", "0", "0", "0"},
          {"45", "12.56651802009812`", "0", "0", "0", "0", "0", "0"},
          {"46", "12.566518020098123`", "0", "0", "0", "0", "0", "0"},
          {"47", "12.859254392790367`", "0", "0.025268811121987925`", 
            "0", \(-0.01587136137554712`\), "0", "0"},
          {"48", "12.883764565444826`", \(-0.014029692642239121`\), "0", "0", 
            "0", "0.010627844571785684`", "0"},
          {"49", "12.89693915642458`", "0", "0", "0", "0", "0", "0"},
          {"50", "12.93290908819772`", "0", "0", "0", "0", "0", "0"},
          {"51", "12.93290908819773`", "0", "0", "0", "0", "0", "0"},
          {"52", "12.93290908819773`", "0", "0", "0", "0", "0", "0"},
          {"53", "12.932909088197736`", "0", "0", "0", "0", "0", "0"},
          {"54", "12.932909088197745`", "0", "0", "0", "0", "0", "0"},
          {"55", "12.948298795553866`", "0", "0", "0.06062640190737526`", "0",
             "0", "0"},
          {"56", "13.54821250631116`", "0", "0.042683873021629785`", 
            "0", \(-0.09799207877612633`\), "0", "0"},
          {"57", "13.645329329759143`", "0", "0", "0", "0", "0", 
            "0.11505677084910008`"},
          {"58", "13.825563588829256`", "0.03606112368323981`", "0", "0", "0",
             "0.08112724609554044`", "0"},
          {"59", "15.25519691856167`", "0", "0", "0", "0", "0", "0"},
          {"60", "15.255196918561712`", "0", "0", "0", "0", "0", "0"},
          {"61", "15.255196918561714`", "0", "0", "0", "0", "0", "0"},
          {"62", "15.255196918561714`", "0", "0", "0", "0", "0", "0"},
          {"63", "15.255196918561746`", "0", "0", "0", "0", "0", "0"},
          {"64", "15.261643524373559`", "0", \(-0.0021622065416479533`\), "0",
             "0.0038910016123822034`", "0", "0"},
          {"65", "15.278382473820768`", "0.006395259766237876`", "0", "0", 
            "0", "0.012894815568767346`", "0"},
          {"66", "15.278805936283119`", "0", "0", "0", "0", "0", 
            "0.021338009155098616`"},
          {"67", "15.548494759603141`", "0", \(-0.013128643603450832`\), "0", 
            "0.028200842765541724`", "0", "0"},
          {"68", "16.224616979580794`", \(-0.0067717701118226266`\), "0", "0",
             "0", \(-0.014534842510414508`\), "0"},
          {"69", "16.263096237724497`", "0", "0", "0", "0", "0", 
            "0.020436919240896034`"},
          {"70", "16.263814462986804`", "0", "0", "0", "0", "0", "0"},
          {"71", "16.263814462986804`", "0", "0", "0", "0", "0", "0"},
          {"72", "16.263814462986822`", "0", "0", "0", "0", "0", "0"},
          {"73", "16.263814462986847`", "0", "0", "0", "0", "0", "0"},
          {"74", "16.26381446298686`", "0", "0", "0", "0", "0", "0"},
          {"75", "17.35677918398194`", "0", "0", "0", "0", "0", 
            "0.0032672760017328287`"},
          {"76", "17.36345248836199`", "0", "0", "0", "0", "0", "0"},
          {"77", "17.36345248836202`", "0", "0", "0", "0", "0", "0"},
          {"78", "17.363452488362025`", "0", "0", "0", "0", "0", "0"},
          {"79", "17.49419168586583`", "0", "0.002850080338115111`", 
            "0", \(-0.006084681628340004`\), "0", "0"},
          {"80", "19.462829635092803`", "0", "0", "0", "0", "0", 
            "0.0024957259342105035`"},
          {"81", "25.32379337748972`", "0.00008768238883087446`", "0", "0", 
            "0", "0.00018541972827553315`", "0"},
          {"82", "42.41170228818538`", "0", "0", "0", "0", "0", "0"},
          {"83", "66.78249183815726`", "0", "0", "0", "0", "0", "0"},
          {"84", "70.33630414682338`", "0", "0", "0", "0", "0", "0"},
          {"85", "85.6946675213086`", "0", "0", "0", "0", "0", "0"},
          {"86", "110.24393579509407`", "0", "0", "0", "0", "0", "0"},
          {"87", "134.0354238118141`", "0", "0", "0", "0", "0", "0"},
          {"88", "183.954295688122`", "0", "0", "0", "0", "0", "0"},
          {"89", "214.3587119945904`", "0", "0", "0", "0", "0", "0"},
          {"90", "227.18728114792728`", "0", "0", "0", "0", "0", "0"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ 
        BoxForm`e$, TableHeadings -> {{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
          13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 
          30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 
          47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 
          64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 
          81, 82, 83, 84, 85, 86, 87, 88, 89, 90}, {"freq (Hz)", "x", "y", 
          "z", "Rx", "Ry", "Rz"}}]]]], "Print",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[Table[Max[Abs[vecs[\([i]\)]]], {i, 1, nDOFs}]]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(0.23995101998645904`\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stack Geometry", "Section",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nLegs = 4;\)\), "\[IndentingNewLine]", 
    \(\(legRadius = 27.165;\)\), "\[IndentingNewLine]", 
    \(\(legPhase = Pi/4;\)\), "\[IndentingNewLine]", 
    \(\(legAngle = 2\ Pi/nLegs;\)\), "\[IndentingNewLine]", 
    \(legCenters = 
      Table[{legRadius\ Cos[legAngle\ \((i - 1)\) + legPhase], 
            legRadius\ Sin[legAngle\ \((i - 1)\) + legPhase]}, {i, 1, 
            nLegs}]\  // N\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \({{19.20855571093256`, 19.20855571093256`}, {\(-19.20855571093256`\), 
        19.20855571093256`}, {\(-19.20855571093256`\), \
\(-19.20855571093256`\)}, {19.20855571093256`, \(-19.20855571093256`\)}}\)], \
"Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[{
    \(\(nLayers = 4;\)\), "\[IndentingNewLine]", 
    \(\(nLegElements = nLayers - 1;\)\), "\[IndentingNewLine]", 
    \(\(springHeight = 2.516;\)\), "\[IndentingNewLine]", 
    \(\(legMassThickness = {6.0, 4.0, 2.0};\)\), "\[IndentingNewLine]", 
    \(\(legMassRadius = 21.25/2;\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(\(layerHeights = Table[0, {nLegElements}];\)\), "\[IndentingNewLine]", 
    \(\(layerHeights[\([1]\)] = 
        springHeight + 
          legMassThickness[\([1]\)]/2;\)\), "\[IndentingNewLine]", 
    \(\(Do[
        layerHeights[\([i]\)] = 
          layerHeights[\([i - 1]\)] + 
            springHeight + \((legMassThickness[\([i - 1]\)] + 
                  legMassThickness[\([i]\)])\)/2, {i, 2, 
          nLegElements}];\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(\(massPositions = 
        Table[Flatten[{legCenters[\([i]\)], layerHeights[\([j]\)]}], {i, 
            nLegs}, {j, nLayers - 1}];\)\), "\n", 
    \(\(downtubeMassHeight = 54.178;\)\), "\n", 
    \(\(downtubeRadius = 15.0;\)\), "\[IndentingNewLine]", 
    \(\(downtubeMassPos = \((legMassThickness . {1, 1, 1} + 
              4\ springHeight)\) - downtubeMassHeight/2;\)\), "\n", 
    \(\(massPositions = 
        Join[Flatten[massPositions, 
            1], {{0, 0, downtubeMassPos}}];\)\), "\[IndentingNewLine]", 
    \(\(nMasses = nLegs\ \((nLayers - 1)\) + 1;\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(<< Graphics`Shapes`\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(pts = 
        Table[Point[
            massPositions\[LeftDoubleBracket]i\[RightDoubleBracket]], {i, 
            nMasses}];\)\)], "Input",
  PageWidth->PaperWidth,
  InitializationCell->True,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    \(\(massCylinderHalfHeights = 
        legMassThickness/2;\)\), "\[IndentingNewLine]", 
    \(\(Do[
        massCylinderHalfHeights = 
          Flatten[Join[massCylinderHalfHeights, 
              legMassThickness/2]], {nLayers - 1}];\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[\[IndentingNewLine]Table[\[IndentingNewLine]TranslateShape[\
\[IndentingNewLine]Graphics3D[
              Cylinder[legMassRadius, massCylinderHalfHeights[\([i]\)], 
                20]], \[IndentingNewLine]massPositions[\([i]\)]], \
\[IndentingNewLine]{i, 
            nMasses - 
              1}], \[IndentingNewLine]TranslateShape[\[IndentingNewLine]\
Graphics3D[
            Cylinder[downtubeRadius, downtubeMassHeight/2, 
              20]], \[IndentingNewLine]massPositions[\([nMasses]\)]], \
\[IndentingNewLine]Graphics3D[{PointSize[0.02], 
            pts}], \[IndentingNewLine]AspectRatio \[Rule] 1, 
        PlotRange \[Rule] All, ViewPoint \[Rule] {40000, 100000, 10000}, 
        Boxed \[Rule] False];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.5641e-006 1 -0.134521 1.26905 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62275 .76135 m .62275 .66826 L .58294 .66719 L p .707 .577 .707 r
F P
0 g
s
.62275 .66826 m .62275 .76135 L .6634 .76092 L p .707 .577 .707 r
F P
0 g
s
.6634 .76092 m .6634 .66782 L .62275 .66826 L p .707 .577 .707 r
F P
0 g
s
.6634 .66782 m .6634 .76092 L .70092 .75903 L p .707 .577 .707 r
F P
0 g
s
.70092 .75903 m .70092 .66593 L .6634 .66782 L p .707 .577 .707 r
F P
0 g
s
.58294 .66719 m .58294 .76029 L .62275 .76135 L p .707 .577 .707 r
F P
0 g
s
.58294 .76029 m .58294 .66719 L .54788 .66474 L p .707 .577 .707 r
F P
0 g
s
.62275 .86246 m .62275 .80039 L .58294 .79933 L p .707 .577 .707 r
F P
0 g
s
.62275 .80039 m .62275 .86246 L .6634 .86202 L p .707 .577 .707 r
F P
0 g
s
.6634 .86202 m .6634 .79996 L .62275 .80039 L p .707 .577 .707 r
F P
0 g
s
.6634 .79996 m .6634 .86202 L .70092 .86014 L p .707 .577 .707 r
F P
0 g
s
.70092 .86014 m .70092 .79807 L .6634 .79996 L p .707 .577 .707 r
F P
0 g
s
.58294 .79933 m .58294 .8614 L .62275 .86246 L p .707 .577 .707 r
F P
0 g
s
.54788 .66474 m .54788 .75784 L .58294 .76029 L p .707 .577 .707 r
F P
0 g
s
.62275 .93253 m .62275 .9015 L .58294 .90043 L p .707 .577 .707 r
F P
0 g
s
.62275 .9015 m .62275 .93253 L .6634 .93209 L p .707 .577 .707 r
F P
0 g
s
.6634 .93209 m .6634 .90106 L .62275 .9015 L p .707 .577 .707 r
F P
0 g
s
.58294 .8614 m .58294 .79933 L .54788 .79688 L p .707 .577 .707 r
F P
0 g
s
.58294 .90043 m .58294 .93147 L .62275 .93253 L p .707 .577 .707 r
F P
0 g
s
.70092 .66593 m .70092 .75903 L .73163 .75588 L p .707 .577 .707 r
F P
0 g
s
.73163 .75588 m .73163 .66278 L .70092 .66593 L p .707 .577 .707 r
F P
0 g
s
.6634 .90106 m .6634 .93209 L .70092 .93021 L p .707 .577 .707 r
F P
0 g
s
.70092 .93021 m .70092 .89918 L .6634 .90106 L p .707 .577 .707 r
F P
0 g
s
.54788 .79688 m .54788 .85894 L .58294 .8614 L p .707 .577 .707 r
F P
0 g
s
.58294 .93147 m .58294 .90043 L .54788 .89798 L p .707 .577 .707 r
F P
0 g
s
.54788 .89798 m .54788 .92902 L .58294 .93147 L p .707 .577 .707 r
F P
0 g
s
.70092 .79807 m .70092 .86014 L .73163 .85698 L p .707 .577 .707 r
F P
0 g
s
.73163 .85698 m .73163 .79492 L .70092 .79807 L p .707 .577 .707 r
F P
0 g
s
.54788 .75784 m .54788 .66474 L .52099 .66114 L p .707 .577 .707 r
F P
0 g
s
.52099 .66114 m .52099 .75424 L .54788 .75784 L p .707 .577 .707 r
F P
0 g
s
.70092 .89918 m .70092 .93021 L .73163 .92705 L p .707 .577 .707 r
F P
0 g
s
.73163 .92705 m .73163 .89602 L .70092 .89918 L p .707 .577 .707 r
F P
0 g
s
.54788 .85894 m .54788 .79688 L .52099 .79328 L p .707 .577 .707 r
F P
0 g
s
.52099 .79328 m .52099 .85534 L .54788 .85894 L p .707 .577 .707 r
F P
0 g
s
.73163 .66278 m .73163 .75588 L .75253 .75176 L p .707 .577 .707 r
F P
0 g
s
.75253 .75176 m .75253 .65867 L .73163 .66278 L p .707 .577 .707 r
F P
0 g
s
.54788 .92902 m .54788 .89798 L .52099 .89438 L p .707 .577 .707 r
F P
0 g
s
.52099 .89438 m .52099 .92541 L .54788 .92902 L p .707 .577 .707 r
F P
0 g
s
.73163 .79492 m .73163 .85698 L .75253 .85287 L p .707 .577 .707 r
F P
0 g
s
.75253 .85287 m .75253 .7908 L .73163 .79492 L p .707 .577 .707 r
F P
0 g
s
.52099 .75424 m .52099 .66114 L .50492 .65674 L p .707 .577 .707 r
F P
0 g
s
.73163 .89602 m .73163 .92705 L .75253 .92294 L p .707 .577 .707 r
F P
0 g
s
.75253 .92294 m .75253 .89191 L .73163 .89602 L p .707 .577 .707 r
F P
0 g
s
.50492 .65674 m .50492 .74983 L .52099 .75424 L p .707 .577 .707 r
F P
0 g
s
.52099 .85534 m .52099 .79328 L .50492 .78887 L p .707 .577 .707 r
F P
0 g
s
.50492 .78887 m .50492 .85094 L .52099 .85534 L p .707 .577 .707 r
F P
0 g
s
.52099 .92541 m .52099 .89438 L .50492 .88998 L p .707 .577 .707 r
F P
0 g
s
.50492 .88998 m .50492 .92101 L .52099 .92541 L p .707 .577 .707 r
F P
0 g
s
.75253 .65867 m .75253 .75176 L .76158 .74709 L p .707 .577 .707 r
F P
0 g
s
.76158 .74709 m .76158 .654 L .75253 .65867 L p .707 .577 .707 r
F P
0 g
s
.75253 .7908 m .75253 .85287 L .76158 .8482 L p .707 .577 .707 r
F P
0 g
s
.76158 .8482 m .76158 .78613 L .75253 .7908 L p .707 .577 .707 r
F P
0 g
s
.50492 .74983 m .50492 .65674 L .50122 .65197 L p .707 .577 .707 r
F P
0 g
s
.75253 .89191 m .75253 .92294 L .76158 .91827 L p .707 .577 .707 r
F P
0 g
s
.76158 .91827 m .76158 .88724 L .75253 .89191 L p .707 .577 .707 r
F P
0 g
s
.50122 .65197 m .50122 .74507 L .50492 .74983 L p .707 .577 .707 r
F P
0 g
s
.50492 .85094 m .50492 .78887 L .50122 .7841 L p .707 .577 .707 r
F P
0 g
s
.50122 .7841 m .50122 .84617 L .50492 .85094 L p .707 .577 .707 r
F P
0 g
s
.50492 .92101 m .50492 .88998 L .50122 .88521 L p .707 .577 .707 r
F P
0 g
s
.50122 .88521 m .50122 .91624 L .50492 .92101 L p .707 .577 .707 r
F P
0 g
s
.76158 .654 m .76158 .74709 L .75788 .74233 L p .707 .577 .707 r
F P
0 g
s
.75788 .74233 m .75788 .64923 L .76158 .654 L p .707 .577 .707 r
F P
0 g
s
.76158 .78613 m .76158 .8482 L .75788 .84343 L p .707 .577 .707 r
F P
0 g
s
.75788 .84343 m .75788 .78136 L .76158 .78613 L p .707 .577 .707 r
F P
0 g
s
.76158 .88724 m .76158 .91827 L .75788 .9135 L p .707 .577 .707 r
F P
0 g
s
.75788 .9135 m .75788 .88247 L .76158 .88724 L p .707 .577 .707 r
F P
0 g
s
.50122 .74507 m .50122 .65197 L .51026 .6473 L p .707 .577 .707 r
F P
0 g
s
.51026 .6473 m .51026 .7404 L .50122 .74507 L p .707 .577 .707 r
F P
0 g
s
.50122 .84617 m .50122 .7841 L .51026 .77943 L p .707 .577 .707 r
F P
0 g
s
.51026 .77943 m .51026 .8415 L .50122 .84617 L p .707 .577 .707 r
F P
0 g
s
.50122 .91624 m .50122 .88521 L .51026 .88054 L p .707 .577 .707 r
F P
0 g
s
.51026 .88054 m .51026 .91157 L .50122 .91624 L p .707 .577 .707 r
F P
0 g
s
.75788 .64923 m .75788 .74233 L .7418 .73792 L p .707 .577 .707 r
F P
0 g
s
.7418 .73792 m .7418 .64483 L .75788 .64923 L p .707 .577 .707 r
F P
0 g
s
.75788 .78136 m .75788 .84343 L .7418 .83903 L p .707 .577 .707 r
F P
0 g
s
.7418 .83903 m .7418 .77696 L .75788 .78136 L p .707 .577 .707 r
F P
0 g
s
.18475 .7408 m .18475 .6477 L .14495 .64664 L p .707 .577 .707 r
F P
0 g
s
.18475 .6477 m .18475 .7408 L .2254 .74036 L p .707 .577 .707 r
F P
0 g
s
.2254 .74036 m .2254 .64727 L .18475 .6477 L p .707 .577 .707 r
F P
0 g
s
.51026 .7404 m .51026 .6473 L .53116 .64318 L p .707 .577 .707 r
F P
0 g
s
.2254 .64727 m .2254 .74036 L .26292 .73848 L p .707 .577 .707 r
F P
0 g
s
.26292 .73848 m .26292 .64538 L .2254 .64727 L p .707 .577 .707 r
F P
0 g
s
.75788 .88247 m .75788 .9135 L .7418 .9091 L p .707 .577 .707 r
F P
0 g
s
.7418 .9091 m .7418 .87807 L .75788 .88247 L p .707 .577 .707 r
F P
0 g
s
.14495 .64664 m .14495 .73974 L .18475 .7408 L p .707 .577 .707 r
F P
0 g
s
.14495 .73974 m .14495 .64664 L .10988 .64419 L p .707 .577 .707 r
F P
0 g
s
.18475 .8419 m .18475 .77984 L .14495 .77878 L p .707 .577 .707 r
F P
0 g
s
.18475 .77984 m .18475 .8419 L .2254 .84147 L p .707 .577 .707 r
F P
0 g
s
.2254 .84147 m .2254 .7794 L .18475 .77984 L p .707 .577 .707 r
F P
0 g
s
.53116 .64318 m .53116 .73628 L .51026 .7404 L p .707 .577 .707 r
F P
0 g
s
.51026 .8415 m .51026 .77943 L .53116 .77532 L p .707 .577 .707 r
F P
0 g
s
.2254 .7794 m .2254 .84147 L .26292 .83958 L p .707 .577 .707 r
F P
0 g
s
.26292 .83958 m .26292 .77752 L .2254 .7794 L p .707 .577 .707 r
F P
0 g
s
.14495 .77878 m .14495 .84084 L .18475 .8419 L p .707 .577 .707 r
F P
0 g
s
.10988 .64419 m .10988 .73729 L .14495 .73974 L p .707 .577 .707 r
F P
0 g
s
.18475 .91197 m .18475 .88094 L .14495 .87988 L p .707 .577 .707 r
F P
0 g
s
.18475 .88094 m .18475 .91197 L .2254 .91154 L p .707 .577 .707 r
F P
0 g
s
.2254 .91154 m .2254 .88051 L .18475 .88094 L p .707 .577 .707 r
F P
0 g
s
.53116 .77532 m .53116 .83739 L .51026 .8415 L p .707 .577 .707 r
F P
0 g
s
.14495 .84084 m .14495 .77878 L .10988 .77632 L p .707 .577 .707 r
F P
0 g
s
.14495 .87988 m .14495 .91091 L .18475 .91197 L p .707 .577 .707 r
F P
0 g
s
.26292 .64538 m .26292 .73848 L .29364 .73532 L p .707 .577 .707 r
F P
0 g
s
.29364 .73532 m .29364 .64223 L .26292 .64538 L p .707 .577 .707 r
F P
0 g
s
.51026 .91157 m .51026 .88054 L .53116 .87643 L p .707 .577 .707 r
F P
0 g
s
.2254 .88051 m .2254 .91154 L .26292 .90965 L p .707 .577 .707 r
F P
0 g
s
.26292 .90965 m .26292 .87862 L .2254 .88051 L p .707 .577 .707 r
F P
0 g
s
.53116 .87643 m .53116 .90746 L .51026 .91157 L p .707 .577 .707 r
F P
0 g
s
.10988 .77632 m .10988 .83839 L .14495 .84084 L p .707 .577 .707 r
F P
0 g
s
.7418 .64483 m .7418 .73792 L .71491 .73432 L p .707 .577 .707 r
F P
0 g
s
.71491 .73432 m .71491 .64122 L .7418 .64483 L p .707 .577 .707 r
F P
0 g
s
.14495 .91091 m .14495 .87988 L .10988 .87743 L p .707 .577 .707 r
F P
0 g
s
.10988 .87743 m .10988 .90846 L .14495 .91091 L p .707 .577 .707 r
F P
0 g
s
.26292 .77752 m .26292 .83958 L .29364 .83643 L p .707 .577 .707 r
F P
0 g
s
.29364 .83643 m .29364 .77436 L .26292 .77752 L p .707 .577 .707 r
F P
0 g
s
.10988 .73729 m .10988 .64419 L .083 .64058 L p .707 .577 .707 r
F P
0 g
s
.7418 .77696 m .7418 .83903 L .71491 .83542 L p .707 .577 .707 r
F P
0 g
s
.71491 .83542 m .71491 .77336 L .7418 .77696 L p .707 .577 .707 r
F P
0 g
s
.083 .64058 m .083 .73368 L .10988 .73729 L p .707 .577 .707 r
F P
0 g
s
.26292 .87862 m .26292 .90965 L .29364 .9065 L p .707 .577 .707 r
F P
0 g
s
.29364 .9065 m .29364 .87547 L .26292 .87862 L p .707 .577 .707 r
F P
0 g
s
.48779 .94189 m .48779 .10124 L .43159 .09975 L p .707 .577 .707 r
F P
0 g
s
.53116 .73628 m .53116 .64318 L .56188 .64003 L p .707 .577 .707 r
F P
0 g
s
.56188 .64003 m .56188 .73313 L .53116 .73628 L p .707 .577 .707 r
F P
0 g
s
.53116 .83739 m .53116 .77532 L .56188 .77217 L p .707 .577 .707 r
F P
0 g
s
.56188 .77217 m .56188 .83423 L .53116 .83739 L p .707 .577 .707 r
F P
0 g
s
.53116 .90746 m .53116 .87643 L .56188 .87327 L p .707 .577 .707 r
F P
0 g
s
.56188 .87327 m .56188 .9043 L .53116 .90746 L p .707 .577 .707 r
F P
0 g
s
.48779 .10124 m .48779 .94189 L .54518 .94127 L p .707 .577 .707 r
F P
0 g
s
.54518 .94127 m .54518 .10063 L .48779 .10124 L p .707 .577 .707 r
F P
0 g
s
.10988 .83839 m .10988 .77632 L .083 .77272 L p .707 .577 .707 r
F P
0 g
s
.7418 .87807 m .7418 .9091 L .71491 .9055 L p .707 .577 .707 r
F P
0 g
s
.71491 .9055 m .71491 .87446 L .7418 .87807 L p .707 .577 .707 r
F P
0 g
s
.56188 .73313 m .56188 .64003 L .5994 .63814 L p .707 .577 .707 r
F P
0 g
s
.5994 .63814 m .5994 .73124 L .56188 .73313 L p .707 .577 .707 r
F P
0 g
s
.56188 .83423 m .56188 .77217 L .5994 .77028 L p .707 .577 .707 r
F P
0 g
s
.5994 .77028 m .5994 .83235 L .56188 .83423 L p .707 .577 .707 r
F P
0 g
s
.56188 .9043 m .56188 .87327 L .5994 .87138 L p .707 .577 .707 r
F P
0 g
s
.5994 .87138 m .5994 .90242 L .56188 .9043 L p .707 .577 .707 r
F P
0 g
s
.54518 .10063 m .54518 .94127 L .59815 .93861 L p .707 .577 .707 r
F P
0 g
s
.59815 .93861 m .59815 .09797 L .54518 .10063 L p .707 .577 .707 r
F P
0 g
s
.083 .77272 m .083 .83479 L .10988 .83839 L p .707 .577 .707 r
F P
0 g
s
.29364 .64223 m .29364 .73532 L .31454 .73121 L p .707 .577 .707 r
F P
0 g
s
.31454 .73121 m .31454 .63811 L .29364 .64223 L p .707 .577 .707 r
F P
0 g
s
.10988 .90846 m .10988 .87743 L .083 .87383 L p .707 .577 .707 r
F P
0 g
s
.083 .87383 m .083 .90486 L .10988 .90846 L p .707 .577 .707 r
F P
0 g
s
.43159 .94039 m .43159 .09975 L .38209 .09628 L p .707 .577 .707 r
F P
0 g
s
.43159 .09975 m .43159 .94039 L .48779 .94189 L p .707 .577 .707 r
F P
0 g
s
.71491 .64122 m .71491 .73432 L .67985 .73187 L p .707 .577 .707 r
F P
0 g
s
.67985 .73187 m .67985 .63877 L .71491 .64122 L p .707 .577 .707 r
F P
0 g
s
.29364 .77436 m .29364 .83643 L .31454 .83231 L p .707 .577 .707 r
F P
0 g
s
.31454 .83231 m .31454 .77025 L .29364 .77436 L p .707 .577 .707 r
F P
0 g
s
.083 .73368 m .083 .64058 L .06692 .63618 L p .707 .577 .707 r
F P
0 g
s
.29364 .87547 m .29364 .9065 L .31454 .90239 L p .707 .577 .707 r
F P
0 g
s
.31454 .90239 m .31454 .87135 L .29364 .87547 L p .707 .577 .707 r
F P
0 g
s
.71491 .77336 m .71491 .83542 L .67985 .83297 L p .707 .577 .707 r
F P
0 g
s
.67985 .83297 m .67985 .77091 L .71491 .77336 L p .707 .577 .707 r
F P
0 g
s
.5994 .73124 m .5994 .63814 L .64005 .63771 L p .707 .577 .707 r
F P
0 g
s
.64005 .63771 m .64005 .73081 L .5994 .73124 L p .707 .577 .707 r
F P
0 g
s
.5994 .83235 m .5994 .77028 L .64005 .76985 L p .707 .577 .707 r
F P
0 g
s
.64005 .76985 m .64005 .83191 L .5994 .83235 L p .707 .577 .707 r
F P
0 g
s
.5994 .90242 m .5994 .87138 L .64005 .87095 L p .707 .577 .707 r
F P
0 g
s
.64005 .87095 m .64005 .90198 L .5994 .90242 L p .707 .577 .707 r
F P
0 g
s
.59815 .09797 m .59815 .93861 L .64151 .93416 L p .707 .577 .707 r
F P
0 g
s
.67985 .63877 m .67985 .73187 L .64005 .73081 L p .707 .577 .707 r
F P
0 g
s
.64005 .73081 m .64005 .63771 L .67985 .63877 L p .707 .577 .707 r
F P
0 g
s
.67985 .77091 m .67985 .83297 L .64005 .83191 L p .707 .577 .707 r
F P
0 g
s
.64005 .83191 m .64005 .76985 L .67985 .77091 L p .707 .577 .707 r
F P
0 g
s
.67985 .87201 m .67985 .90304 L .64005 .90198 L p .707 .577 .707 r
F P
0 g
s
.64005 .90198 m .64005 .87095 L .67985 .87201 L p .707 .577 .707 r
F P
0 g
s
.64151 .93416 m .64151 .09351 L .59815 .09797 L p .707 .577 .707 r
F P
0 g
s
.06692 .63618 m .06692 .72928 L .083 .73368 L p .707 .577 .707 r
F P
0 g
s
.083 .83479 m .083 .77272 L .06692 .76832 L p .707 .577 .707 r
F P
0 g
s
.71491 .87446 m .71491 .9055 L .67985 .90304 L p .707 .577 .707 r
F P
0 g
s
.67985 .90304 m .67985 .87201 L .71491 .87446 L p .707 .577 .707 r
F P
0 g
s
.06692 .76832 m .06692 .83038 L .083 .83479 L p .707 .577 .707 r
F P
0 g
s
.083 .90486 m .083 .87383 L .06692 .86942 L p .707 .577 .707 r
F P
0 g
s
.06692 .86942 m .06692 .90046 L .083 .90486 L p .707 .577 .707 r
F P
0 g
s
.38209 .93693 m .38209 .09628 L .34414 .0912 L p .707 .577 .707 r
F P
0 g
s
.38209 .09628 m .38209 .93693 L .43159 .94039 L p .707 .577 .707 r
F P
0 g
s
.31454 .63811 m .31454 .73121 L .32358 .72654 L p .707 .577 .707 r
F P
0 g
s
.32358 .72654 m .32358 .63344 L .31454 .63811 L p .707 .577 .707 r
F P
0 g
s
.31454 .77025 m .31454 .83231 L .32358 .82764 L p .707 .577 .707 r
F P
0 g
s
.32358 .82764 m .32358 .76558 L .31454 .77025 L p .707 .577 .707 r
F P
0 g
s
.06692 .72928 m .06692 .63618 L .06322 .63141 L p .707 .577 .707 r
F P
0 g
s
.31454 .87135 m .31454 .90239 L .32358 .89772 L p .707 .577 .707 r
F P
0 g
s
.32358 .89772 m .32358 .86668 L .31454 .87135 L p .707 .577 .707 r
F P
0 g
s
.64151 .09351 m .64151 .93416 L .67102 .92835 L p .707 .577 .707 r
F P
0 g
s
.67102 .92835 m .67102 .08771 L .64151 .09351 L p .707 .577 .707 r
F P
0 g
s
.06322 .63141 m .06322 .72451 L .06692 .72928 L p .707 .577 .707 r
F P
0 g
s
.06692 .83038 m .06692 .76832 L .06322 .76355 L p .707 .577 .707 r
F P
0 g
s
.06322 .76355 m .06322 .82562 L .06692 .83038 L p .707 .577 .707 r
F P
0 g
s
.06692 .90046 m .06692 .86942 L .06322 .86465 L p .707 .577 .707 r
F P
0 g
s
.06322 .86465 m .06322 .89569 L .06692 .90046 L p .707 .577 .707 r
F P
0 g
s
.32358 .63344 m .32358 .72654 L .31988 .72177 L p .707 .577 .707 r
F P
0 g
s
.31988 .72177 m .31988 .62867 L .32358 .63344 L p .707 .577 .707 r
F P
0 g
s
.34414 .93184 m .34414 .0912 L .32143 .08498 L p .707 .577 .707 r
F P
0 g
s
.34414 .0912 m .34414 .93184 L .38209 .93693 L p .707 .577 .707 r
F P
0 g
s
.32358 .76558 m .32358 .82764 L .31988 .82288 L p .707 .577 .707 r
F P
0 g
s
.31988 .82288 m .31988 .76081 L .32358 .76558 L p .707 .577 .707 r
F P
0 g
s
.32358 .86668 m .32358 .89772 L .31988 .89295 L p .707 .577 .707 r
F P
0 g
s
.31988 .89295 m .31988 .86191 L .32358 .86668 L p .707 .577 .707 r
F P
0 g
s
.06322 .72451 m .06322 .63141 L .07226 .62674 L p .707 .577 .707 r
F P
0 g
s
.07226 .62674 m .07226 .71984 L .06322 .72451 L p .707 .577 .707 r
F P
0 g
s
.06322 .82562 m .06322 .76355 L .07226 .75888 L p .707 .577 .707 r
F P
0 g
s
.07226 .75888 m .07226 .82095 L .06322 .82562 L p .707 .577 .707 r
F P
0 g
s
.67102 .08771 m .67102 .92835 L .68378 .92176 L p .707 .577 .707 r
F P
0 g
s
.68378 .92176 m .68378 .08111 L .67102 .08771 L p .707 .577 .707 r
F P
0 g
s
.06322 .89569 m .06322 .86465 L .07226 .85998 L p .707 .577 .707 r
F P
0 g
s
.07226 .85998 m .07226 .89102 L .06322 .89569 L p .707 .577 .707 r
F P
0 g
s
.31988 .62867 m .31988 .72177 L .3038 .71737 L p .707 .577 .707 r
F P
0 g
s
.3038 .71737 m .3038 .62427 L .31988 .62867 L p .707 .577 .707 r
F P
0 g
s
.31988 .76081 m .31988 .82288 L .3038 .81847 L p .707 .577 .707 r
F P
0 g
s
.3038 .81847 m .3038 .75641 L .31988 .76081 L p .707 .577 .707 r
F P
0 g
s
.32143 .92563 m .32143 .08498 L .31621 .07825 L p .707 .577 .707 r
F P
0 g
s
.32143 .08498 m .32143 .92563 L .34414 .93184 L p .707 .577 .707 r
F P
0 g
s
.07226 .71984 m .07226 .62674 L .09317 .62263 L p .707 .577 .707 r
F P
0 g
s
.31988 .86191 m .31988 .89295 L .3038 .88855 L p .707 .577 .707 r
F P
0 g
s
.3038 .88855 m .3038 .85751 L .31988 .86191 L p .707 .577 .707 r
F P
0 g
s
.09317 .62263 m .09317 .71573 L .07226 .71984 L p .707 .577 .707 r
F P
0 g
s
.07226 .82095 m .07226 .75888 L .09317 .75477 L p .707 .577 .707 r
F P
0 g
s
.09317 .75477 m .09317 .81683 L .07226 .82095 L p .707 .577 .707 r
F P
0 g
s
.07226 .89102 m .07226 .85998 L .09317 .85587 L p .707 .577 .707 r
F P
0 g
s
.09317 .85587 m .09317 .8869 L .07226 .89102 L p .707 .577 .707 r
F P
0 g
s
.3038 .62427 m .3038 .71737 L .27692 .71377 L p .707 .577 .707 r
F P
0 g
s
.27692 .71377 m .27692 .62067 L .3038 .62427 L p .707 .577 .707 r
F P
0 g
s
.3038 .75641 m .3038 .81847 L .27692 .81487 L p .707 .577 .707 r
F P
0 g
s
.27692 .81487 m .27692 .75281 L .3038 .75641 L p .707 .577 .707 r
F P
0 g
s
.68378 .08111 m .68378 .92176 L .67856 .91502 L p .707 .577 .707 r
F P
0 g
s
.67856 .91502 m .67856 .07438 L .68378 .08111 L p .707 .577 .707 r
F P
0 g
s
.09317 .71573 m .09317 .62263 L .12388 .61947 L p .707 .577 .707 r
F P
0 g
s
.3038 .85751 m .3038 .88855 L .27692 .88494 L p .707 .577 .707 r
F P
0 g
s
.27692 .88494 m .27692 .85391 L .3038 .85751 L p .707 .577 .707 r
F P
0 g
s
.12388 .61947 m .12388 .71257 L .09317 .71573 L p .707 .577 .707 r
F P
0 g
s
.09317 .81683 m .09317 .75477 L .12388 .75161 L p .707 .577 .707 r
F P
0 g
s
.12388 .75161 m .12388 .81368 L .09317 .81683 L p .707 .577 .707 r
F P
0 g
s
.27692 .62067 m .27692 .71377 L .24185 .71131 L p .707 .577 .707 r
F P
0 g
s
.24185 .71131 m .24185 .61822 L .27692 .62067 L p .707 .577 .707 r
F P
0 g
s
.09317 .8869 m .09317 .85587 L .12388 .85272 L p .707 .577 .707 r
F P
0 g
s
.12388 .85272 m .12388 .88375 L .09317 .8869 L p .707 .577 .707 r
F P
0 g
s
.31621 .07825 m .31621 .91889 L .32143 .92563 L p .707 .577 .707 r
F P
0 g
s
.31621 .91889 m .31621 .07825 L .32898 .07165 L p .707 .577 .707 r
F P
0 g
s
.27692 .75281 m .27692 .81487 L .24185 .81242 L p .707 .577 .707 r
F P
0 g
s
.24185 .81242 m .24185 .75035 L .27692 .75281 L p .707 .577 .707 r
F P
0 g
s
.12388 .71257 m .12388 .61947 L .1614 .61759 L p .707 .577 .707 r
F P
0 g
s
.1614 .61759 m .1614 .71069 L .12388 .71257 L p .707 .577 .707 r
F P
0 g
s
.27692 .85391 m .27692 .88494 L .24185 .88249 L p .707 .577 .707 r
F P
0 g
s
.24185 .88249 m .24185 .85146 L .27692 .85391 L p .707 .577 .707 r
F P
0 g
s
.12388 .81368 m .12388 .75161 L .1614 .74973 L p .707 .577 .707 r
F P
0 g
s
.24185 .61822 m .24185 .71131 L .20205 .71025 L p .707 .577 .707 r
F P
0 g
s
.20205 .71025 m .20205 .61715 L .24185 .61822 L p .707 .577 .707 r
F P
0 g
s
.1614 .74973 m .1614 .81179 L .12388 .81368 L p .707 .577 .707 r
F P
0 g
s
.1614 .71069 m .1614 .61759 L .20205 .61715 L p .707 .577 .707 r
F P
0 g
s
.12388 .88375 m .12388 .85272 L .1614 .85083 L p .707 .577 .707 r
F P
0 g
s
.1614 .85083 m .1614 .88186 L .12388 .88375 L p .707 .577 .707 r
F P
0 g
s
.20205 .61715 m .20205 .71025 L .1614 .71069 L p .707 .577 .707 r
F P
0 g
s
.24185 .75035 m .24185 .81242 L .20205 .81136 L p .707 .577 .707 r
F P
0 g
s
.20205 .81136 m .20205 .74929 L .24185 .75035 L p .707 .577 .707 r
F P
0 g
s
.79795 .70997 m .79795 .61687 L .75814 .61581 L p .707 .577 .707 r
F P
0 g
s
.79795 .61687 m .79795 .70997 L .8386 .70953 L p .707 .577 .707 r
F P
0 g
s
.8386 .70953 m .8386 .61643 L .79795 .61687 L p .707 .577 .707 r
F P
0 g
s
.1614 .81179 m .1614 .74973 L .20205 .74929 L p .707 .577 .707 r
F P
0 g
s
.8386 .61643 m .8386 .70953 L .87612 .70765 L p .707 .577 .707 r
F P
0 g
s
.87612 .70765 m .87612 .61455 L .8386 .61643 L p .707 .577 .707 r
F P
0 g
s
.67856 .07438 m .67856 .91502 L .65586 .90881 L p .707 .577 .707 r
F P
0 g
s
.65586 .90881 m .65586 .06817 L .67856 .07438 L p .707 .577 .707 r
F P
0 g
s
.24185 .85146 m .24185 .88249 L .20205 .88143 L p .707 .577 .707 r
F P
0 g
s
.20205 .88143 m .20205 .8504 L .24185 .85146 L p .707 .577 .707 r
F P
0 g
s
.75814 .61581 m .75814 .70891 L .79795 .70997 L p .707 .577 .707 r
F P
0 g
s
.20205 .74929 m .20205 .81136 L .1614 .81179 L p .707 .577 .707 r
F P
0 g
s
.75814 .70891 m .75814 .61581 L .72308 .61336 L p .707 .577 .707 r
F P
0 g
s
.79795 .81107 m .79795 .74901 L .75814 .74794 L p .707 .577 .707 r
F P
0 g
s
.79795 .74901 m .79795 .81107 L .8386 .81064 L p .707 .577 .707 r
F P
0 g
s
.8386 .81064 m .8386 .74857 L .79795 .74901 L p .707 .577 .707 r
F P
0 g
s
.1614 .88186 m .1614 .85083 L .20205 .8504 L p .707 .577 .707 r
F P
0 g
s
.20205 .8504 m .20205 .88143 L .1614 .88186 L p .707 .577 .707 r
F P
0 g
s
.8386 .74857 m .8386 .81064 L .87612 .80875 L p .707 .577 .707 r
F P
0 g
s
.87612 .80875 m .87612 .74669 L .8386 .74857 L p .707 .577 .707 r
F P
0 g
s
.75814 .74794 m .75814 .81001 L .79795 .81107 L p .707 .577 .707 r
F P
0 g
s
.72308 .61336 m .72308 .70645 L .75814 .70891 L p .707 .577 .707 r
F P
0 g
s
.79795 .88114 m .79795 .85011 L .75814 .84905 L p .707 .577 .707 r
F P
0 g
s
.79795 .85011 m .79795 .88114 L .8386 .88071 L p .707 .577 .707 r
F P
0 g
s
.8386 .88071 m .8386 .84968 L .79795 .85011 L p .707 .577 .707 r
F P
0 g
s
.75814 .81001 m .75814 .74794 L .72308 .74549 L p .707 .577 .707 r
F P
0 g
s
.75814 .84905 m .75814 .88008 L .79795 .88114 L p .707 .577 .707 r
F P
0 g
s
.87612 .61455 m .87612 .70765 L .90683 .70449 L p .707 .577 .707 r
F P
0 g
s
.90683 .70449 m .90683 .61139 L .87612 .61455 L p .707 .577 .707 r
F P
0 g
s
.8386 .84968 m .8386 .88071 L .87612 .87882 L p .707 .577 .707 r
F P
0 g
s
.87612 .87882 m .87612 .84779 L .8386 .84968 L p .707 .577 .707 r
F P
0 g
s
.72308 .74549 m .72308 .80756 L .75814 .81001 L p .707 .577 .707 r
F P
0 g
s
.75814 .88008 m .75814 .84905 L .72308 .8466 L p .707 .577 .707 r
F P
0 g
s
.32898 .9123 m .32898 .07165 L .35849 .06585 L p .707 .577 .707 r
F P
0 g
s
.32898 .07165 m .32898 .9123 L .31621 .91889 L p .707 .577 .707 r
F P
0 g
s
.72308 .8466 m .72308 .87763 L .75814 .88008 L p .707 .577 .707 r
F P
0 g
s
.87612 .74669 m .87612 .80875 L .90683 .8056 L p .707 .577 .707 r
F P
0 g
s
.90683 .8056 m .90683 .74353 L .87612 .74669 L p .707 .577 .707 r
F P
0 g
s
.72308 .70645 m .72308 .61336 L .69619 .60975 L p .707 .577 .707 r
F P
0 g
s
.69619 .60975 m .69619 .70285 L .72308 .70645 L p .707 .577 .707 r
F P
0 g
s
.87612 .84779 m .87612 .87882 L .90683 .87567 L p .707 .577 .707 r
F P
0 g
s
.90683 .87567 m .90683 .84464 L .87612 .84779 L p .707 .577 .707 r
F P
0 g
s
.72308 .80756 m .72308 .74549 L .69619 .74189 L p .707 .577 .707 r
F P
0 g
s
.69619 .74189 m .69619 .80395 L .72308 .80756 L p .707 .577 .707 r
F P
0 g
s
.90683 .61139 m .90683 .70449 L .92773 .70038 L p .707 .577 .707 r
F P
0 g
s
.92773 .70038 m .92773 .60728 L .90683 .61139 L p .707 .577 .707 r
F P
0 g
s
.72308 .87763 m .72308 .8466 L .69619 .84299 L p .707 .577 .707 r
F P
0 g
s
.69619 .84299 m .69619 .87403 L .72308 .87763 L p .707 .577 .707 r
F P
0 g
s
.90683 .74353 m .90683 .8056 L .92773 .80148 L p .707 .577 .707 r
F P
0 g
s
.92773 .80148 m .92773 .73942 L .90683 .74353 L p .707 .577 .707 r
F P
0 g
s
.65586 .06817 m .65586 .90881 L .6179 .90372 L p .707 .577 .707 r
F P
0 g
s
.6179 .90372 m .6179 .06308 L .65586 .06817 L p .707 .577 .707 r
F P
0 g
s
.69619 .70285 m .69619 .60975 L .68011 .60535 L p .707 .577 .707 r
F P
0 g
s
.90683 .84464 m .90683 .87567 L .92773 .87156 L p .707 .577 .707 r
F P
0 g
s
.92773 .87156 m .92773 .84052 L .90683 .84464 L p .707 .577 .707 r
F P
0 g
s
.68011 .60535 m .68011 .69845 L .69619 .70285 L p .707 .577 .707 r
F P
0 g
s
.69619 .80395 m .69619 .74189 L .68011 .73749 L p .707 .577 .707 r
F P
0 g
s
.68011 .73749 m .68011 .79955 L .69619 .80395 L p .707 .577 .707 r
F P
0 g
s
.35849 .06585 m .35849 .90649 L .32898 .9123 L p .707 .577 .707 r
F P
0 g
s
.35849 .90649 m .35849 .06585 L .40185 .06139 L p .707 .577 .707 r
F P
0 g
s
.69619 .87403 m .69619 .84299 L .68011 .83859 L p .707 .577 .707 r
F P
0 g
s
.68011 .83859 m .68011 .86962 L .69619 .87403 L p .707 .577 .707 r
F P
0 g
s
.92773 .60728 m .92773 .70038 L .93678 .69571 L p .707 .577 .707 r
F P
0 g
s
.93678 .69571 m .93678 .60261 L .92773 .60728 L p .707 .577 .707 r
F P
0 g
s
.92773 .73942 m .92773 .80148 L .93678 .79681 L p .707 .577 .707 r
F P
0 g
s
.93678 .79681 m .93678 .73475 L .92773 .73942 L p .707 .577 .707 r
F P
0 g
s
.68011 .69845 m .68011 .60535 L .67642 .60058 L p .707 .577 .707 r
F P
0 g
s
.92773 .84052 m .92773 .87156 L .93678 .86689 L p .707 .577 .707 r
F P
0 g
s
.93678 .86689 m .93678 .83585 L .92773 .84052 L p .707 .577 .707 r
F P
0 g
s
.6179 .06308 m .6179 .90372 L .56841 .90026 L p .707 .577 .707 r
F P
0 g
s
.56841 .90026 m .56841 .05962 L .6179 .06308 L p .707 .577 .707 r
F P
0 g
s
.67642 .60058 m .67642 .69368 L .68011 .69845 L p .707 .577 .707 r
F P
0 g
s
.68011 .79955 m .68011 .73749 L .67642 .73272 L p .707 .577 .707 r
F P
0 g
s
.67642 .73272 m .67642 .79478 L .68011 .79955 L p .707 .577 .707 r
F P
0 g
s
.40185 .90204 m .40185 .06139 L .45482 .05873 L p .707 .577 .707 r
F P
0 g
s
.40185 .06139 m .40185 .90204 L .35849 .90649 L p .707 .577 .707 r
F P
0 g
s
.68011 .86962 m .68011 .83859 L .67642 .83382 L p .707 .577 .707 r
F P
0 g
s
.67642 .83382 m .67642 .86486 L .68011 .86962 L p .707 .577 .707 r
F P
0 g
s
.93678 .60261 m .93678 .69571 L .93308 .69094 L p .707 .577 .707 r
F P
0 g
s
.93308 .69094 m .93308 .59784 L .93678 .60261 L p .707 .577 .707 r
F P
0 g
s
.56841 .05962 m .56841 .90026 L .51221 .89876 L p .707 .577 .707 r
F P
0 g
s
.51221 .89876 m .51221 .05812 L .56841 .05962 L p .707 .577 .707 r
F P
0 g
s
.93678 .73475 m .93678 .79681 L .93308 .79204 L p .707 .577 .707 r
F P
0 g
s
.93308 .79204 m .93308 .72998 L .93678 .73475 L p .707 .577 .707 r
F P
0 g
s
.45482 .89938 m .45482 .05873 L .51221 .05812 L p .707 .577 .707 r
F P
0 g
s
.45482 .05873 m .45482 .89938 L .40185 .90204 L p .707 .577 .707 r
F P
0 g
s
.93678 .83585 m .93678 .86689 L .93308 .86212 L p .707 .577 .707 r
F P
0 g
s
.93308 .86212 m .93308 .83108 L .93678 .83585 L p .707 .577 .707 r
F P
0 g
s
.67642 .69368 m .67642 .60058 L .68546 .59591 L p .707 .577 .707 r
F P
0 g
s
.51221 .05812 m .51221 .89876 L .45482 .89938 L p .707 .577 .707 r
F P
0 g
s
.68546 .59591 m .68546 .68901 L .67642 .69368 L p .707 .577 .707 r
F P
0 g
s
.67642 .79478 m .67642 .73272 L .68546 .72805 L p .707 .577 .707 r
F P
0 g
s
.68546 .72805 m .68546 .79011 L .67642 .79478 L p .707 .577 .707 r
F P
0 g
s
.67642 .86486 m .67642 .83382 L .68546 .82915 L p .707 .577 .707 r
F P
0 g
s
.68546 .82915 m .68546 .86019 L .67642 .86486 L p .707 .577 .707 r
F P
0 g
s
.93308 .59784 m .93308 .69094 L .917 .68654 L p .707 .577 .707 r
F P
0 g
s
.917 .68654 m .917 .59344 L .93308 .59784 L p .707 .577 .707 r
F P
0 g
s
.93308 .72998 m .93308 .79204 L .917 .78764 L p .707 .577 .707 r
F P
0 g
s
.917 .78764 m .917 .72558 L .93308 .72998 L p .707 .577 .707 r
F P
0 g
s
.35995 .68941 m .35995 .59631 L .32014 .59525 L p .707 .577 .707 r
F P
0 g
s
.35995 .59631 m .35995 .68941 L .4006 .68898 L p .707 .577 .707 r
F P
0 g
s
.4006 .68898 m .4006 .59588 L .35995 .59631 L p .707 .577 .707 r
F P
0 g
s
.68546 .68901 m .68546 .59591 L .70636 .5918 L p .707 .577 .707 r
F P
0 g
s
.4006 .59588 m .4006 .68898 L .43812 .68709 L p .707 .577 .707 r
F P
0 g
s
.43812 .68709 m .43812 .59399 L .4006 .59588 L p .707 .577 .707 r
F P
0 g
s
.93308 .83108 m .93308 .86212 L .917 .85771 L p .707 .577 .707 r
F P
0 g
s
.917 .85771 m .917 .82668 L .93308 .83108 L p .707 .577 .707 r
F P
0 g
s
.32014 .59525 m .32014 .68835 L .35995 .68941 L p .707 .577 .707 r
F P
0 g
s
.32014 .68835 m .32014 .59525 L .28508 .5928 L p .707 .577 .707 r
F P
0 g
s
.35995 .79052 m .35995 .72845 L .32014 .72739 L p .707 .577 .707 r
F P
0 g
s
.35995 .72845 m .35995 .79052 L .4006 .79008 L p .707 .577 .707 r
F P
0 g
s
.4006 .79008 m .4006 .72802 L .35995 .72845 L p .707 .577 .707 r
F P
0 g
s
.70636 .5918 m .70636 .6849 L .68546 .68901 L p .707 .577 .707 r
F P
0 g
s
.68546 .79011 m .68546 .72805 L .70636 .72393 L p .707 .577 .707 r
F P
0 g
s
.4006 .72802 m .4006 .79008 L .43812 .7882 L p .707 .577 .707 r
F P
0 g
s
.43812 .7882 m .43812 .72613 L .4006 .72802 L p .707 .577 .707 r
F P
0 g
s
.32014 .72739 m .32014 .78946 L .35995 .79052 L p .707 .577 .707 r
F P
0 g
s
.28508 .5928 m .28508 .6859 L .32014 .68835 L p .707 .577 .707 r
F P
0 g
s
.35995 .86059 m .35995 .82956 L .32014 .8285 L p .707 .577 .707 r
F P
0 g
s
.35995 .82956 m .35995 .86059 L .4006 .86016 L p .707 .577 .707 r
F P
0 g
s
.4006 .86016 m .4006 .82912 L .35995 .82956 L p .707 .577 .707 r
F P
0 g
s
.70636 .72393 m .70636 .786 L .68546 .79011 L p .707 .577 .707 r
F P
0 g
s
.32014 .78946 m .32014 .72739 L .28508 .72494 L p .707 .577 .707 r
F P
0 g
s
.32014 .8285 m .32014 .85953 L .35995 .86059 L p .707 .577 .707 r
F P
0 g
s
.43812 .59399 m .43812 .68709 L .46883 .68394 L p .707 .577 .707 r
F P
0 g
s
.46883 .68394 m .46883 .59084 L .43812 .59399 L p .707 .577 .707 r
F P
0 g
s
.68546 .86019 m .68546 .82915 L .70636 .82504 L p .707 .577 .707 r
F P
0 g
s
.4006 .82912 m .4006 .86016 L .43812 .85827 L p .707 .577 .707 r
F P
0 g
s
.43812 .85827 m .43812 .82724 L .4006 .82912 L p .707 .577 .707 r
F P
0 g
s
.70636 .82504 m .70636 .85607 L .68546 .86019 L p .707 .577 .707 r
F P
0 g
s
.28508 .72494 m .28508 .787 L .32014 .78946 L p .707 .577 .707 r
F P
0 g
s
.917 .59344 m .917 .68654 L .89012 .68293 L p .707 .577 .707 r
F P
0 g
s
.89012 .68293 m .89012 .58984 L .917 .59344 L p .707 .577 .707 r
F P
0 g
s
.32014 .85953 m .32014 .8285 L .28508 .82604 L p .707 .577 .707 r
F P
0 g
s
.28508 .82604 m .28508 .85708 L .32014 .85953 L p .707 .577 .707 r
F P
0 g
s
.43812 .72613 m .43812 .7882 L .46883 .78504 L p .707 .577 .707 r
F P
0 g
s
.46883 .78504 m .46883 .72298 L .43812 .72613 L p .707 .577 .707 r
F P
0 g
s
.28508 .6859 m .28508 .5928 L .2582 .5892 L p .707 .577 .707 r
F P
0 g
s
.917 .72558 m .917 .78764 L .89012 .78404 L p .707 .577 .707 r
F P
0 g
s
.89012 .78404 m .89012 .72197 L .917 .72558 L p .707 .577 .707 r
F P
0 g
s
.2582 .5892 m .2582 .6823 L .28508 .6859 L p .707 .577 .707 r
F P
0 g
s
.43812 .82724 m .43812 .85827 L .46883 .85511 L p .707 .577 .707 r
F P
0 g
s
.46883 .85511 m .46883 .82408 L .43812 .82724 L p .707 .577 .707 r
F P
0 g
s
.70636 .6849 m .70636 .5918 L .73708 .58864 L p .707 .577 .707 r
F P
0 g
s
.28508 .787 m .28508 .72494 L .2582 .72133 L p .707 .577 .707 r
F P
0 g
s
.917 .82668 m .917 .85771 L .89012 .85411 L p .707 .577 .707 r
F P
0 g
s
.89012 .85411 m .89012 .82308 L .917 .82668 L p .707 .577 .707 r
F P
0 g
s
.2582 .72133 m .2582 .7834 L .28508 .787 L p .707 .577 .707 r
F P
0 g
s
.73708 .58864 m .73708 .68174 L .70636 .6849 L p .707 .577 .707 r
F P
0 g
s
.46883 .59084 m .46883 .68394 L .48974 .67982 L p .707 .577 .707 r
F P
0 g
s
.48974 .67982 m .48974 .58673 L .46883 .59084 L p .707 .577 .707 r
F P
0 g
s
.28508 .85708 m .28508 .82604 L .2582 .82244 L p .707 .577 .707 r
F P
0 g
s
.70636 .786 m .70636 .72393 L .73708 .72078 L p .707 .577 .707 r
F P
0 g
s
.2582 .82244 m .2582 .85347 L .28508 .85708 L p .707 .577 .707 r
F P
0 g
s
.73708 .72078 m .73708 .78285 L .70636 .786 L p .707 .577 .707 r
F P
0 g
s
.89012 .58984 m .89012 .68293 L .85505 .68048 L p .707 .577 .707 r
F P
0 g
s
.85505 .68048 m .85505 .58738 L .89012 .58984 L p .707 .577 .707 r
F P
0 g
s
.70636 .85607 m .70636 .82504 L .73708 .82189 L p .707 .577 .707 r
F P
0 g
s
.46883 .72298 m .46883 .78504 L .48974 .78093 L p .707 .577 .707 r
F P
0 g
s
.48974 .78093 m .48974 .71886 L .46883 .72298 L p .707 .577 .707 r
F P
0 g
s
.73708 .82189 m .73708 .85292 L .70636 .85607 L p .707 .577 .707 r
F P
0 g
s
.2582 .6823 m .2582 .5892 L .24212 .5848 L p .707 .577 .707 r
F P
0 g
s
.46883 .82408 m .46883 .85511 L .48974 .851 L p .707 .577 .707 r
F P
0 g
s
.48974 .851 m .48974 .81997 L .46883 .82408 L p .707 .577 .707 r
F P
0 g
s
.89012 .72197 m .89012 .78404 L .85505 .78159 L p .707 .577 .707 r
F P
0 g
s
.85505 .78159 m .85505 .71952 L .89012 .72197 L p .707 .577 .707 r
F P
0 g
s
.73708 .68174 m .73708 .58864 L .7746 .58676 L p .707 .577 .707 r
F P
0 g
s
.24212 .5848 m .24212 .67789 L .2582 .6823 L p .707 .577 .707 r
F P
0 g
s
.2582 .7834 m .2582 .72133 L .24212 .71693 L p .707 .577 .707 r
F P
0 g
s
.7746 .58676 m .7746 .67985 L .73708 .68174 L p .707 .577 .707 r
F P
0 g
s
.89012 .82308 m .89012 .85411 L .85505 .85166 L p .707 .577 .707 r
F P
0 g
s
.85505 .85166 m .85505 .82063 L .89012 .82308 L p .707 .577 .707 r
F P
0 g
s
.24212 .71693 m .24212 .779 L .2582 .7834 L p .707 .577 .707 r
F P
0 g
s
.73708 .78285 m .73708 .72078 L .7746 .71889 L p .707 .577 .707 r
F P
0 g
s
.85505 .58738 m .85505 .68048 L .81525 .67942 L p .707 .577 .707 r
F P
0 g
s
.81525 .67942 m .81525 .58632 L .85505 .58738 L p .707 .577 .707 r
F P
0 g
s
.2582 .85347 m .2582 .82244 L .24212 .81804 L p .707 .577 .707 r
F P
0 g
s
.7746 .71889 m .7746 .78096 L .73708 .78285 L p .707 .577 .707 r
F P
0 g
s
.24212 .81804 m .24212 .84907 L .2582 .85347 L p .707 .577 .707 r
F P
0 g
s
.7746 .67985 m .7746 .58676 L .81525 .58632 L p .707 .577 .707 r
F P
0 g
s
.48974 .58673 m .48974 .67982 L .49878 .67515 L p .707 .577 .707 r
F P
0 g
s
.49878 .67515 m .49878 .58206 L .48974 .58673 L p .707 .577 .707 r
F P
0 g
s
.73708 .85292 m .73708 .82189 L .7746 .82 L p .707 .577 .707 r
F P
0 g
s
.7746 .82 m .7746 .85103 L .73708 .85292 L p .707 .577 .707 r
F P
0 g
s
.81525 .58632 m .81525 .67942 L .7746 .67985 L p .707 .577 .707 r
F P
0 g
s
.85505 .71952 m .85505 .78159 L .81525 .78053 L p .707 .577 .707 r
F P
0 g
s
.81525 .78053 m .81525 .71846 L .85505 .71952 L p .707 .577 .707 r
F P
0 g
s
.7746 .78096 m .7746 .71889 L .81525 .71846 L p .707 .577 .707 r
F P
0 g
s
.48974 .71886 m .48974 .78093 L .49878 .77626 L p .707 .577 .707 r
F P
0 g
s
.49878 .77626 m .49878 .71419 L .48974 .71886 L p .707 .577 .707 r
F P
0 g
s
.85505 .82063 m .85505 .85166 L .81525 .8506 L p .707 .577 .707 r
F P
0 g
s
.81525 .8506 m .81525 .81956 L .85505 .82063 L p .707 .577 .707 r
F P
0 g
s
.81525 .71846 m .81525 .78053 L .7746 .78096 L p .707 .577 .707 r
F P
0 g
s
.24212 .67789 m .24212 .5848 L .23842 .58003 L p .707 .577 .707 r
F P
0 g
s
.7746 .85103 m .7746 .82 L .81525 .81956 L p .707 .577 .707 r
F P
0 g
s
.48974 .81997 m .48974 .851 L .49878 .84633 L p .707 .577 .707 r
F P
0 g
s
.49878 .84633 m .49878 .8153 L .48974 .81997 L p .707 .577 .707 r
F P
0 g
s
.81525 .81956 m .81525 .8506 L .7746 .85103 L p .707 .577 .707 r
F P
0 g
s
.23842 .58003 m .23842 .67312 L .24212 .67789 L p .707 .577 .707 r
F P
0 g
s
.24212 .779 m .24212 .71693 L .23842 .71216 L p .707 .577 .707 r
F P
0 g
s
.23842 .71216 m .23842 .77423 L .24212 .779 L p .707 .577 .707 r
F P
0 g
s
.24212 .84907 m .24212 .81804 L .23842 .81327 L p .707 .577 .707 r
F P
0 g
s
.23842 .81327 m .23842 .8443 L .24212 .84907 L p .707 .577 .707 r
F P
0 g
s
.49878 .58206 m .49878 .67515 L .49508 .67038 L p .707 .577 .707 r
F P
0 g
s
.49508 .67038 m .49508 .57729 L .49878 .58206 L p .707 .577 .707 r
F P
0 g
s
.49878 .71419 m .49878 .77626 L .49508 .77149 L p .707 .577 .707 r
F P
0 g
s
.49508 .77149 m .49508 .70942 L .49878 .71419 L p .707 .577 .707 r
F P
0 g
s
.49878 .8153 m .49878 .84633 L .49508 .84156 L p .707 .577 .707 r
F P
0 g
s
.49508 .84156 m .49508 .81053 L .49878 .8153 L p .707 .577 .707 r
F P
0 g
s
.23842 .67312 m .23842 .58003 L .24746 .57536 L p .707 .577 .707 r
F P
0 g
s
.24746 .57536 m .24746 .66845 L .23842 .67312 L p .707 .577 .707 r
F P
0 g
s
.23842 .77423 m .23842 .71216 L .24746 .70749 L p .707 .577 .707 r
F P
0 g
s
.24746 .70749 m .24746 .76956 L .23842 .77423 L p .707 .577 .707 r
F P
0 g
s
.23842 .8443 m .23842 .81327 L .24746 .8086 L p .707 .577 .707 r
F P
0 g
s
.24746 .8086 m .24746 .83963 L .23842 .8443 L p .707 .577 .707 r
F P
0 g
s
.49508 .57729 m .49508 .67038 L .479 .66598 L p .707 .577 .707 r
F P
0 g
s
.479 .66598 m .479 .57288 L .49508 .57729 L p .707 .577 .707 r
F P
0 g
s
.49508 .70942 m .49508 .77149 L .479 .76709 L p .707 .577 .707 r
F P
0 g
s
.479 .76709 m .479 .70502 L .49508 .70942 L p .707 .577 .707 r
F P
0 g
s
.24746 .66845 m .24746 .57536 L .26836 .57124 L p .707 .577 .707 r
F P
0 g
s
.49508 .81053 m .49508 .84156 L .479 .83716 L p .707 .577 .707 r
F P
0 g
s
.479 .83716 m .479 .80613 L .49508 .81053 L p .707 .577 .707 r
F P
0 g
s
.26836 .57124 m .26836 .66434 L .24746 .66845 L p .707 .577 .707 r
F P
0 g
s
.24746 .76956 m .24746 .70749 L .26836 .70338 L p .707 .577 .707 r
F P
0 g
s
.26836 .70338 m .26836 .76545 L .24746 .76956 L p .707 .577 .707 r
F P
0 g
s
.24746 .83963 m .24746 .8086 L .26836 .80449 L p .707 .577 .707 r
F P
0 g
s
.26836 .80449 m .26836 .83552 L .24746 .83963 L p .707 .577 .707 r
F P
0 g
s
.479 .57288 m .479 .66598 L .45212 .66238 L p .707 .577 .707 r
F P
0 g
s
.45212 .66238 m .45212 .56928 L .479 .57288 L p .707 .577 .707 r
F P
0 g
s
.479 .70502 m .479 .76709 L .45212 .76348 L p .707 .577 .707 r
F P
0 g
s
.45212 .76348 m .45212 .70142 L .479 .70502 L p .707 .577 .707 r
F P
0 g
s
.26836 .66434 m .26836 .57124 L .29908 .56809 L p .707 .577 .707 r
F P
0 g
s
.479 .80613 m .479 .83716 L .45212 .83356 L p .707 .577 .707 r
F P
0 g
s
.45212 .83356 m .45212 .80252 L .479 .80613 L p .707 .577 .707 r
F P
0 g
s
.29908 .56809 m .29908 .66119 L .26836 .66434 L p .707 .577 .707 r
F P
0 g
s
.26836 .76545 m .26836 .70338 L .29908 .70023 L p .707 .577 .707 r
F P
0 g
s
.29908 .70023 m .29908 .76229 L .26836 .76545 L p .707 .577 .707 r
F P
0 g
s
.45212 .56928 m .45212 .66238 L .41705 .65993 L p .707 .577 .707 r
F P
0 g
s
.41705 .65993 m .41705 .56683 L .45212 .56928 L p .707 .577 .707 r
F P
0 g
s
.26836 .83552 m .26836 .80449 L .29908 .80133 L p .707 .577 .707 r
F P
0 g
s
.29908 .80133 m .29908 .83236 L .26836 .83552 L p .707 .577 .707 r
F P
0 g
s
.45212 .70142 m .45212 .76348 L .41705 .76103 L p .707 .577 .707 r
F P
0 g
s
.41705 .76103 m .41705 .69897 L .45212 .70142 L p .707 .577 .707 r
F P
0 g
s
.29908 .66119 m .29908 .56809 L .3366 .5662 L p .707 .577 .707 r
F P
0 g
s
.3366 .5662 m .3366 .6593 L .29908 .66119 L p .707 .577 .707 r
F P
0 g
s
.45212 .80252 m .45212 .83356 L .41705 .8311 L p .707 .577 .707 r
F P
0 g
s
.41705 .8311 m .41705 .80007 L .45212 .80252 L p .707 .577 .707 r
F P
0 g
s
.29908 .76229 m .29908 .70023 L .3366 .69834 L p .707 .577 .707 r
F P
0 g
s
.41705 .56683 m .41705 .65993 L .37725 .65887 L p .707 .577 .707 r
F P
0 g
s
.37725 .65887 m .37725 .56577 L .41705 .56683 L p .707 .577 .707 r
F P
0 g
s
.3366 .69834 m .3366 .76041 L .29908 .76229 L p .707 .577 .707 r
F P
0 g
s
.3366 .6593 m .3366 .5662 L .37725 .56577 L p .707 .577 .707 r
F P
0 g
s
.29908 .83236 m .29908 .80133 L .3366 .79944 L p .707 .577 .707 r
F P
0 g
s
.3366 .79944 m .3366 .83048 L .29908 .83236 L p .707 .577 .707 r
F P
0 g
s
.37725 .56577 m .37725 .65887 L .3366 .6593 L p .707 .577 .707 r
F P
0 g
s
.41705 .69897 m .41705 .76103 L .37725 .75997 L p .707 .577 .707 r
F P
0 g
s
.37725 .75997 m .37725 .69791 L .41705 .69897 L p .707 .577 .707 r
F P
0 g
s
.3366 .76041 m .3366 .69834 L .37725 .69791 L p .707 .577 .707 r
F P
0 g
s
.41705 .80007 m .41705 .8311 L .37725 .83004 L p .707 .577 .707 r
F P
0 g
s
.37725 .83004 m .37725 .79901 L .41705 .80007 L p .707 .577 .707 r
F P
0 g
s
.37725 .69791 m .37725 .75997 L .3366 .76041 L p .707 .577 .707 r
F P
0 g
s
.3366 .83048 m .3366 .79944 L .37725 .79901 L p .707 .577 .707 r
F P
0 g
s
.37725 .79901 m .37725 .83004 L .3366 .83048 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool007]oob0008Eoo`00KGoo3P001eYF00<005YFFUH03UYF00<005YFFUH01EYF3`00MWoo001UOol8
0006FUH00`00FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJEP0=FUH00`00FUIJEP04FUH=001YOol0
065oo`@00003FUH005YF00]JEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00=JEPL0069oo`00GWoo0`001EYF00<005YFFUH02UYF00<005YFFUH035YF
00<005YFFUH03UYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF00000P00
Ggoo001LOol30007FUH00`00FUIJEP0:FUH00`00FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJEP0=
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP02FUH2001MOol005Yoo`80009JEP03001J
EUYF00EJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP8005aoo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF
00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJ
EP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03
001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001J
EUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJ
EP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03
001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001J
EUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0005]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF
00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
05]oo`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJ
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]o
o`00FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
FWoo00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D0
05YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YF
FUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00FWoo8P001UYF00<005YFFUH0
3UYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF0000
Fgoo001<Ool?0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH9000>FUH00`00
FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH0001KOol004Uo
o`<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00MJEP04001JEUYFFUH70007FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH00`00FUH0001KOol004Ioo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0005]oo`00
A7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
FUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF0000Fgoo0014Ool0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF0000Fgoo0014Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YF00002Woo:`009Woo0014Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH00eYF00<005YF000017oo1P0015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH00UYF2@007Goo0014Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF
00@005YF001oo`<00003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEUYFFUH6000GOol004Aoo`04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH01000FUH0000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P0057oo0014Ool01000FUIJEP00
1EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH00eYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`00A7oo
00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2000COol004Aoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P004goo0014Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`00A7oo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol0
01moobH0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH2000COol001Qoo`L000AJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00QJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEUYF0P004goo000DOol40002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEP8001=oo`004goo0P001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00QJEP04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000BOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
25YF00<005YFFUH025YF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00QJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000BOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP08FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`00
4Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
25YF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00QJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP08FUH01000FUIJEP001EYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`004Woo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUH0
00EJEP03001JEUYF009JERX000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00QJEP04001JEUYF0003FUH70009FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH90004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP05FUH70002FUH20003FUH00`00FUIJEP0=FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJ
EP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`004Woo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF0`000UYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF0`0015YF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH00eYF2`001UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`004Woo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01P000eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP<000IJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00=JEP03001JEP0000EJEP03001JEUYF009JEQD00003FUH005YF00QJEQ8000IJEP04001JEUYFFUH2
000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00IJEPP000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF009JEPP000UJEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0000=JEPP000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00=JEP@0009JEP04001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJERd0011JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0000<000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEPD0009JEP8001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03
001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP8000=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP@001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0:P001UYF00<005YF
FUH03UYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF0`000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P0057oo000BOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60003FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH9000>FUH00`00FUIJEP0=FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000060004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`005Goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEPL000MJEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000IJEPT000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF009JEPP001Qoo`004Woo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH00eYF5P001UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`0015YF
00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF000025YF
00<005YFFUH015YF;00087oo000BOol00`00FUH00005FUH00`00FUIJEP02FUH;000;FUH00`00FUIJ
EP07FUH700000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20015Ool0019oo`03001JEP0000=JEPP000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH0
0008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20015Ool0019oo`03001JEP0000<000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUH0000Z000VOol0019oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJ
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00003FUH70004FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP02FUH9000MOol0019oo`8000=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP05001JEUYFFUH00002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF1P005goo000C
Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01@00
FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YF
FUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF0`001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YF00000P0057oo000EOol60004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEP8001=oo`006goo2@001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=J
EP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYFFUH2000COol002Aoob40009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol004Aoo`04001J
EUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0P004goo0014Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YF
FUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8001=oo`007goo9P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`0067oo1`0015YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=J
EP03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol001Aoo`@0009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00QJEP04001JEUYF0005FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000COol20005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP08FUH01000FUIJEP00
1EYF00<005YFFUH00UYF:P001EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
3EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEP8001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH025YF00@005YFFUH000=JEPL000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEPT000AJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00EJEPL0009JEP8000=JEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00QJEP<000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF
00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH2000COol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00QJEP8000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0003FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000BOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH30002FUH00`00FUIJEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30004FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P004goo000BOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP06
0003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0`001UYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH00eYF00<005YF00001EYF00<005YFFUH00UYF:`001EYF00<005YFFUH01EYF00@005YFFUIJ
EP8001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH01UYF20001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH00UYF20002EYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH00eYF00<005YF00000eYF20002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01eYF2@0015YF00@005YFFUIJEP8001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF;@00
45YF00<005YFFUH03EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF0000
0`001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH01EYF1P000UYF0P004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF
00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH035YF00<005YFFUH03UYF00<005YFFUH03EYF
00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF10004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH02UYF00<005YFFUH035YF00<005YFFUH03UYF00<005YFFUH03EYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF00004goo000BOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP0Z0006FUH00`00FUIJEP0>FUH00`00
FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000DOol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00AJEPH000=JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEPT000iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3000EOol0019o
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJ
EP04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF1`001eYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YF00001UYF2@001EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH00UYF200067oo000BOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUHF0006FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP0=
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJEP04
FUH/000POol0019oo`03001JEP0000EJEP03001JEUYF009JEP/000]JEP03001JEUYF00MJEPL00003
FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00AJEP03001JEUYF
009JEP8004Eoo`004Woo00<005YF00000eYF20002EYF00<005YFFUH02EYF00<005YFFUH025YF00D0
05YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000QJEP03001J
EUYF00AJEP03001JEUYF009JEP8004Eoo`004Woo00<005YF00000`001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH025YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000QJEP03001JEP0002X002Ioo`004Woo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00D005YFFUIJEP00009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0000=JEPL000AJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF009JEPT001eoo`004Woo0P000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH6000GOol001=oo`80009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUHZ0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00002000DOol001Eoo`H000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP05001JEUYFFUH00002FUH01000FUIJEUYF1`002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF2@0015YF00<005YFFUH00UYF0P000eYF00<005YFFUH03EYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8001=oo`006goo2@001EYF00<005YFFUH02EYF00<005YFFUH025YF00D005YFFUIJEP00009J
EP@000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00EJEPL0009JEP8000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol002Aoob<000=JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000COol004Ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP0=FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P004goo0015Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P004goo000OOol_0003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH03EYF
00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH00UYF
:`001EYF00<005YFFUH01EYF00@005YFFUIJEP8001=oo`0067oo1`0015YF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH00UYF30001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH00UYF20002EYF00<005YFFUH03EYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH00eYF00<005YF00000eYF20002EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01eYF2@0015YF00@005YFFUIJEP8001=oo`0057oo10000UYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJES00
011JEP03001JEUYF00eJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP00
00<000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00EJEPH0009JEP8001=oo`004goo0P001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001J
EUYF00EJEP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0001=oo`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8001Ao
o`004Woo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00EJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3000EOol0019oo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00
FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJEP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH00`00FUH00006FUH90005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH8000HOol0019oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00=JEP/000IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00
FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJEP0=FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJEP03FUH]000P
Ool0019oo`03001JEP0000EJEP03001JEUYF009JEQD00003FUH005YF00QJEQ8000IJEP04001JEUYF
0003FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJ
EP0=FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJ
EP04FUH00`00FUIJEP030016Ool0019oo`03001JEP0000=JEPP000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00QJEP03001JEUYF00=JEP@0009JEP04001JEUYF0003FUH00`00FUIJEP05
FUH00`00FUIJEP0:FUH00`00FUIJEP0<FUH00`00FUIJEP0>FUH00`00FUIJEP0=FUH00`00FUIJEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20015Ool0019oo`03001JEP0000<000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00IJEPD00003FUH005YF009JEP03001JEUYF00EJEP03001J
EUYF00YJEP03001JEUYF00aJEP03001JEUYF00iJEP03001JEUYF00eJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00AJEP03001JEUYF009JEP8004Eo
o`004Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YF
FUH02UYF00<005YFFUH035YF00<005YFFUH03UYF00<005YFFUH03EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YF000025YF00<005YFFUH015YF00<005YFFUH00UYF0P00AGoo
000BOol20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH0
2UYF00<005YFFUH035YF00<005YFFUH01UYF400025YF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH00eYF00<005YF000025YF00<005YFFUH015YF00<005YFFUH00UYF0P00AGoo000COol20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUHL000?
FUH?0007FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00008FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20015Ool001Eoo`H000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000800003Ool005YF009JEP03001JEUYF00EJ
EP04001JEUYFFUH6000;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJEP0;FUH=0005FUH0
0`00FUIJEP03FUH00`00FUH0000<0003FUH00`00FUIJEP02FUH20015Ool001]oo`T000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF009JEPH000Aoo`05001JEUYFFUH0
0004FUH70003FUH00`00FUIJEP0;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJEP0<FUH0
0`00FUIJEP09FUH70004FUH00`00FUH00004FUH00`00FUIJEP05FUH50003FUH20015Ool002Aoob`0
00Yoo`04001JEUYFFUH5000:FUH00`00FUIJEP0;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00
FUIJEP0<FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH3000015YF001JEP0015YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP000000AGoo001JOol01000FUH0000015YF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH03EYF00<005YFFUH03UYF00<005YFFUH035YF00<005YFFUH02UYF00<0
05YFFUH01EYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1000AGoo001JOol3
0005FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJ
EP0<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH00000AGoo001KOol20005FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJEP0<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH01@00
FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Agoo001LOol20004FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJEP0<FUH00`00FUIJ
EP0:FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH01EYF00<005YF00000P00BWoo001N
Ool300000eYF001JEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0=FUH00`00FUIJEP0>FUH00`00FUIJ
EP0<FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH30002FUH?001=Ool0065oo`L000EJEP03001JEUYF
00]JEP03001JEUYF00eJEP03001JEUYF00iJEP03001JEUYF00aJEP03001JEUYF00YJEP03001JEUYF
00T005aoo`00J7oo30001eYF00<005YFFUH03EYF00<005YFFUH03UYF00<005YFFUH035YF00<005YF
FUH015YF2@00IGoo001dOol?0008FUH00`00FUIJEP0>FUH00`00FUIJEP05FUH>001^Ool008=oob40
07aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.43595*^-06, 0.105997, \
0.00348436, 0.00274564}}]
}, Open  ]],

Cell[BoxData[{
    \(\(nsprings = {16, 10, 6, 4};\)\), "\[IndentingNewLine]", 
    \(\(springRadius = 1;\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(\(lowerStackRadius = 21.25/2;\)\), "\[IndentingNewLine]", 
    \(\(rl = lowerStackRadius - springRadius;\)\), "\[IndentingNewLine]", 
    \(\(upperStackRadius = 6.9;\)\), "\[IndentingNewLine]", 
    \(\(ru = upperStackRadius - springRadius;\)\), "\[IndentingNewLine]", 
    \(\(r = {rl, rl, rl, ru};\)\)}], "Input",
  PageWidth->PaperWidth]
}, Closed]],

Cell[CellGroupData[{

Cell["Modal Plots", "Section",
  PageWidth->PaperWidth,
  AspectRatioFixed->False,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
    \(\(massdof = Drop[massdof, 1];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(nElements = \(Dimensions[massdof]\)[\([1]\)]\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(15\)], "Output",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[BoxData[
    \(\(nPlots = \(Dimensions[opticstableModes]\)[\([1]\)];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(transdof = 
        Flatten[Transpose[Drop[Transpose[massdof], \(-3\)]]];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(rotatedof = 
        Flatten[Transpose[Drop[Transpose[massdof], 3]]];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[BoxData[{
    \(\(range = 40;\)\), "\[IndentingNewLine]", 
    \(\(factorT = 4000;\)\), "\[IndentingNewLine]", 
    \(\(factorR = 10;\)\)}], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell["Animated Mode Plots", "Subsection",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(eigenPlot[k_, factorT_, factorR_] := 
        Block[{j}, \n
          transvec = 
            Partition[
              Table[vecs[\([k, transdof[\([j]\)]]\)], {j, 1, 
                  Length[transdof]}], 3]; \n
          rotatevec = 
            Partition[
              Table[vecs[\([k, rotatedof[\([j]\)]]\)], {j, 1, 
                  Length[rotatedof]}], 3]; \[IndentingNewLine]jsin = 
            Table[Sin[j\ Pi], {j, 0, 
                2,  .2}]; \
\[IndentingNewLine]ShowAnimation[\[IndentingNewLine]Table[\[IndentingNewLine]\
Show[\[IndentingNewLine]Table[\[IndentingNewLine]TranslateShape[\
\[IndentingNewLine]RotateShape[\[IndentingNewLine]RotateShape[\
\[IndentingNewLine]Graphics3D[
                          Cylinder[legMassRadius, 
                            massCylinderHalfHeights[\([i - 2]\)], 
                            20]], \[IndentingNewLine]Pi/
                          2, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([i, 
                              2]\)], \(-Pi\)/2 - 
                          jsin[\([j]\)]\ factorR\ \ rotatevec[\([i, 3]\)]], 
                      0, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([i, 1]\)], 
                      0], \[IndentingNewLine]massPositions[\([i - 2]\)] + 
                      jsin[\([j]\)]\ factorT\ transvec[\([i]\)]], \
\[IndentingNewLine]{i, 3, 
                    nElements - 
                      1}], \[IndentingNewLine]TranslateShape[\
\[IndentingNewLine]RotateShape[\[IndentingNewLine]RotateShape[\
\[IndentingNewLine]Graphics3D[
                        Cylinder[downtubeRadius, downtubeMassHeight/2, 
                          20]], \[IndentingNewLine]Pi/
                        2, \(-jsin[\([j]\)]\)\ factorR\ \
rotatevec[\([nElements, 2]\)], \(-Pi\)/2 - 
                        jsin[\([j]\)]\ factorR\ \ rotatevec[\([nElements, 
                              3]\)]], 
                    0, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([nElements, 
                          1]\)], 
                    0], \[IndentingNewLine]massPositions[\([nElements - 
                          2]\)] + 
                    jsin[\([j]\)]\ factorT\ transvec[\([nElements]\)]], \
\[IndentingNewLine]Graphics3D[{PointSize[0.02], 
                    pts}], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 1}, 
                PlotRange \[Rule] {{\(-range\), range}, {\(-range\), 
                      range}, {\(-1.2\)\ range, 0.8\ range}}, 
                ViewPoint \[Rule] {40000, 100000, 30000}, 
                Boxed \[Rule] False], \[IndentingNewLine]{j, 1, 
                11}]\[IndentingNewLine]]; \n
          Print["\<Mode # \>", k, "\<     \>", 
            freqs[\([k]\)], "\< Hz\>"];\[IndentingNewLine]];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[
        eigenPlot[opticstableModes[\([k]\)], 20, 1], {k, 1, 
          nPlots}];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59829 .75401 m .59644 .69987 L .56528 .69839 L p .707 .577 .707 r
F P
0 g
s
.59644 .69987 m .59829 .75401 L .63011 .75204 L p .707 .577 .707 r
F P
0 g
s
.63011 .75204 m .62826 .6979 L .59644 .69987 L p .707 .577 .707 r
F P
0 g
s
.62826 .6979 m .63011 .75204 L .65946 .7468 L p .707 .577 .707 r
F P
0 g
s
.65946 .7468 m .65761 .69267 L .62826 .6979 L p .707 .577 .707 r
F P
0 g
s
.56713 .75252 m .56528 .69839 L .53781 .69358 L p .707 .577 .707 r
F P
0 g
s
.56528 .69839 m .56713 .75252 L .59829 .75401 L p .707 .577 .707 r
F P
0 g
s
.65761 .69267 m .65946 .7468 L .68347 .73881 L p .707 .577 .707 r
F P
0 g
s
.68347 .73881 m .68162 .68467 L .65761 .69267 L p .707 .577 .707 r
F P
0 g
s
.53966 .74772 m .53781 .69358 L .51674 .68593 L p .707 .577 .707 r
F P
0 g
s
.53781 .69358 m .53966 .74772 L .56713 .75252 L p .707 .577 .707 r
F P
0 g
s
.60065 .8149 m .59861 .77959 L .56746 .77837 L p .707 .577 .707 r
F P
0 g
s
.59861 .77959 m .60065 .8149 L .63243 .81216 L p .707 .577 .707 r
F P
0 g
s
.63243 .81216 m .63039 .77686 L .59861 .77959 L p .707 .577 .707 r
F P
0 g
s
.63039 .77686 m .63243 .81216 L .66173 .80573 L p .707 .577 .707 r
F P
0 g
s
.66173 .80573 m .65969 .77043 L .63039 .77686 L p .707 .577 .707 r
F P
0 g
s
.68162 .68467 m .68347 .73881 L .6998 .72884 L p .707 .577 .707 r
F P
0 g
s
.6998 .72884 m .69795 .67471 L .68162 .68467 L p .707 .577 .707 r
F P
0 g
s
.5695 .81367 m .56746 .77837 L .53998 .7733 L p .707 .577 .707 r
F P
0 g
s
.56746 .77837 m .5695 .81367 L .60065 .8149 L p .707 .577 .707 r
F P
0 g
s
.65969 .77043 m .66173 .80573 L .68567 .79624 L p .707 .577 .707 r
F P
0 g
s
.68567 .79624 m .68363 .76093 L .65969 .77043 L p .707 .577 .707 r
F P
0 g
s
.51674 .68593 m .51859 .74007 L .53966 .74772 L p .707 .577 .707 r
F P
0 g
s
.51859 .74007 m .51674 .68593 L .50411 .67619 L p .707 .577 .707 r
F P
0 g
s
.60242 .8511 m .60137 .83348 L .57022 .83227 L p .707 .577 .707 r
F P
0 g
s
.60137 .83348 m .60242 .8511 L .6342 .84831 L p .707 .577 .707 r
F P
0 g
s
.6342 .84831 m .63315 .83069 L .60137 .83348 L p .707 .577 .707 r
F P
0 g
s
.53998 .7733 m .54202 .80861 L .5695 .81367 L p .707 .577 .707 r
F P
0 g
s
.54202 .80861 m .53998 .7733 L .51887 .76489 L p .707 .577 .707 r
F P
0 g
s
.63315 .83069 m .6342 .84831 L .66349 .8418 L p .707 .577 .707 r
F P
0 g
s
.66349 .8418 m .66244 .82418 L .63315 .83069 L p .707 .577 .707 r
F P
0 g
s
.57127 .84989 m .57022 .83227 L .54274 .82718 L p .707 .577 .707 r
F P
0 g
s
.57022 .83227 m .57127 .84989 L .60242 .8511 L p .707 .577 .707 r
F P
0 g
s
.69795 .67471 m .6998 .72884 L .70684 .71788 L p .707 .577 .707 r
F P
0 g
s
.70684 .71788 m .70499 .66375 L .69795 .67471 L p .707 .577 .707 r
F P
0 g
s
.68363 .76093 m .68567 .79624 L .70192 .78461 L p .707 .577 .707 r
F P
0 g
s
.70192 .78461 m .69988 .7493 L .68363 .76093 L p .707 .577 .707 r
F P
0 g
s
.66244 .82418 m .66349 .8418 L .68743 .83221 L p .707 .577 .707 r
F P
0 g
s
.68743 .83221 m .68638 .81458 L .66244 .82418 L p .707 .577 .707 r
F P
0 g
s
.54274 .82718 m .54379 .84481 L .57127 .84989 L p .707 .577 .707 r
F P
0 g
s
.50411 .67619 m .50596 .73033 L .51859 .74007 L p .707 .577 .707 r
F P
0 g
s
.51887 .76489 m .52091 .80019 L .54202 .80861 L p .707 .577 .707 r
F P
0 g
s
.54379 .84481 m .54274 .82718 L .52163 .81872 L p .707 .577 .707 r
F P
0 g
s
.52091 .80019 m .51887 .76489 L .50619 .75395 L p .707 .577 .707 r
F P
0 g
s
.50596 .73033 m .50411 .67619 L .50118 .66531 L p .707 .577 .707 r
F P
0 g
s
.52163 .81872 m .52268 .83634 L .54379 .84481 L p .707 .577 .707 r
F P
0 g
s
.68638 .81458 m .68743 .83221 L .70367 .82046 L p .707 .577 .707 r
F P
0 g
s
.70367 .82046 m .70262 .80284 L .68638 .81458 L p .707 .577 .707 r
F P
0 g
s
.69988 .7493 m .70192 .78461 L .70888 .77198 L p .707 .577 .707 r
F P
0 g
s
.70888 .77198 m .70684 .73667 L .69988 .7493 L p .707 .577 .707 r
F P
0 g
s
.50619 .75395 m .50823 .78926 L .52091 .80019 L p .707 .577 .707 r
F P
0 g
s
.70499 .66375 m .70684 .71788 L .7039 .707 L p .707 .577 .707 r
F P
0 g
s
.7039 .707 m .70205 .65286 L .70499 .66375 L p .707 .577 .707 r
F P
0 g
s
.50118 .66531 m .50303 .71944 L .50596 .73033 L p .707 .577 .707 r
F P
0 g
s
.52268 .83634 m .52163 .81872 L .50895 .8077 L p .707 .577 .707 r
F P
0 g
s
.50823 .78926 m .50619 .75395 L .50319 .74156 L p .707 .577 .707 r
F P
0 g
s
.50895 .8077 m .51 .82533 L .52268 .83634 L p .707 .577 .707 r
F P
0 g
s
.50303 .71944 m .50118 .66531 L .50822 .65435 L p .707 .577 .707 r
F P
0 g
s
.70262 .80284 m .70367 .82046 L .71063 .80772 L p .707 .577 .707 r
F P
0 g
s
.71063 .80772 m .70958 .7901 L .70262 .80284 L p .707 .577 .707 r
F P
0 g
s
.70684 .73667 m .70888 .77198 L .70588 .75959 L p .707 .577 .707 r
F P
0 g
s
.70588 .75959 m .70384 .72429 L .70684 .73667 L p .707 .577 .707 r
F P
0 g
s
.50319 .74156 m .50523 .77687 L .50823 .78926 L p .707 .577 .707 r
F P
0 g
s
.70205 .65286 m .7039 .707 L .69128 .69726 L p .707 .577 .707 r
F P
0 g
s
.69128 .69726 m .68943 .64312 L .70205 .65286 L p .707 .577 .707 r
F P
0 g
s
.51 .82533 m .50895 .8077 L .50594 .79521 L p .707 .577 .707 r
F P
0 g
s
.50822 .65435 m .51007 .70848 L .50303 .71944 L p .707 .577 .707 r
F P
0 g
s
.50523 .77687 m .50319 .74156 L .51015 .72894 L p .707 .577 .707 r
F P
0 g
s
.50594 .79521 m .50698 .81284 L .51 .82533 L p .707 .577 .707 r
F P
0 g
s
.25529 .71719 m .25344 .66306 L .22227 .66157 L p .707 .577 .707 r
F P
0 g
s
.25344 .66306 m .25529 .71719 L .2871 .71522 L p .707 .577 .707 r
F P
0 g
s
.2871 .71522 m .28525 .66109 L .25344 .66306 L p .707 .577 .707 r
F P
0 g
s
.51007 .70848 m .50822 .65435 L .52454 .64438 L p .707 .577 .707 r
F P
0 g
s
.28525 .66109 m .2871 .71522 L .31645 .70998 L p .707 .577 .707 r
F P
0 g
s
.31645 .70998 m .3146 .65585 L .28525 .66109 L p .707 .577 .707 r
F P
0 g
s
.70958 .7901 m .71063 .80772 L .70762 .79523 L p .707 .577 .707 r
F P
0 g
s
.70762 .79523 m .70657 .77761 L .70958 .7901 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22412 .7157 m .22227 .66157 L .1948 .65677 L p .707 .577 .707 r
F P
0 g
s
.22227 .66157 m .22412 .7157 L .25529 .71719 L p .707 .577 .707 r
F P
0 g
s
.70384 .72429 m .70588 .75959 L .6932 .74866 L p .707 .577 .707 r
F P
0 g
s
.6932 .74866 m .69116 .71335 L .70384 .72429 L p .707 .577 .707 r
F P
0 g
s
.51015 .72894 m .51219 .76424 L .50523 .77687 L p .707 .577 .707 r
F P
0 g
s
.68943 .64312 m .69128 .69726 L .6702 .68961 L p .707 .577 .707 r
F P
0 g
s
.6702 .68961 m .66835 .63547 L .68943 .64312 L p .707 .577 .707 r
F P
0 g
s
.3146 .65585 m .31645 .70998 L .34046 .70199 L p .707 .577 .707 r
F P
0 g
s
.34046 .70199 m .33861 .64786 L .3146 .65585 L p .707 .577 .707 r
F P
0 g
s
.50698 .81284 m .50594 .79521 L .51289 .78247 L p .707 .577 .707 r
F P
0 g
s
.52454 .64438 m .52639 .69852 L .51007 .70848 L p .707 .577 .707 r
F P
0 g
s
.19665 .7109 m .1948 .65677 L .17373 .64912 L p .707 .577 .707 r
F P
0 g
s
.1948 .65677 m .19665 .7109 L .22412 .7157 L p .707 .577 .707 r
F P
0 g
s
.52639 .69852 m .52454 .64438 L .54856 .63639 L p .707 .577 .707 r
F P
0 g
s
.51219 .76424 m .51015 .72894 L .5264 .71731 L p .707 .577 .707 r
F P
0 g
s
.51289 .78247 m .51394 .8001 L .50698 .81284 L p .707 .577 .707 r
F P
0 g
s
.25764 .77808 m .2556 .74278 L .22445 .74155 L p .707 .577 .707 r
F P
0 g
s
.2556 .74278 m .25764 .77808 L .28942 .77535 L p .707 .577 .707 r
F P
0 g
s
.28942 .77535 m .28738 .74004 L .2556 .74278 L p .707 .577 .707 r
F P
0 g
s
.28738 .74004 m .28942 .77535 L .31872 .76892 L p .707 .577 .707 r
F P
0 g
s
.31872 .76892 m .31668 .73361 L .28738 .74004 L p .707 .577 .707 r
F P
0 g
s
.70657 .77761 m .70762 .79523 L .69493 .78422 L p .707 .577 .707 r
F P
0 g
s
.69493 .78422 m .69389 .76659 L .70657 .77761 L p .707 .577 .707 r
F P
0 g
s
.33861 .64786 m .34046 .70199 L .35679 .69203 L p .707 .577 .707 r
F P
0 g
s
.35679 .69203 m .35494 .63789 L .33861 .64786 L p .707 .577 .707 r
F P
0 g
s
.22649 .77686 m .22445 .74155 L .19697 .73648 L p .707 .577 .707 r
F P
0 g
s
.22445 .74155 m .22649 .77686 L .25764 .77808 L p .707 .577 .707 r
F P
0 g
s
.66835 .63547 m .6702 .68961 L .64274 .6848 L p .707 .577 .707 r
F P
0 g
s
.64274 .6848 m .64089 .63067 L .66835 .63547 L p .707 .577 .707 r
F P
0 g
s
.69116 .71335 m .6932 .74866 L .67209 .74025 L p .707 .577 .707 r
F P
0 g
s
.67209 .74025 m .67005 .70494 L .69116 .71335 L p .707 .577 .707 r
F P
0 g
s
.5264 .71731 m .52844 .75261 L .51219 .76424 L p .707 .577 .707 r
F P
0 g
s
.31668 .73361 m .31872 .76892 L .34266 .75942 L p .707 .577 .707 r
F P
0 g
s
.34266 .75942 m .34062 .72412 L .31668 .73361 L p .707 .577 .707 r
F P
0 g
s
.17373 .64912 m .17558 .70325 L .19665 .7109 L p .707 .577 .707 r
F P
0 g
s
.55041 .69052 m .54856 .63639 L .57791 .63115 L p .707 .577 .707 r
F P
0 g
s
.54856 .63639 m .55041 .69052 L .52639 .69852 L p .707 .577 .707 r
F P
0 g
s
.17558 .70325 m .17373 .64912 L .16111 .63938 L p .707 .577 .707 r
F P
0 g
s
.51394 .8001 m .51289 .78247 L .52914 .77073 L p .707 .577 .707 r
F P
0 g
s
.25941 .81429 m .25837 .79666 L .22721 .79546 L p .707 .577 .707 r
F P
0 g
s
.25837 .79666 m .25941 .81429 L .29119 .8115 L p .707 .577 .707 r
F P
0 g
s
.29119 .8115 m .29014 .79387 L .25837 .79666 L p .707 .577 .707 r
F P
0 g
s
.19697 .73648 m .19901 .77179 L .22649 .77686 L p .707 .577 .707 r
F P
0 g
s
.19901 .77179 m .19697 .73648 L .17586 .72807 L p .707 .577 .707 r
F P
0 g
s
.49165 .79215 m .52755 .27489 L .48359 .27092 L p .707 .577 .707 r
F P
0 g
s
.52844 .75261 m .5264 .71731 L .55034 .70781 L p .707 .577 .707 r
F P
0 g
s
.52914 .77073 m .53018 .78835 L .51394 .8001 L p .707 .577 .707 r
F P
0 g
s
.55034 .70781 m .55238 .74312 L .52844 .75261 L p .707 .577 .707 r
F P
0 g
s
.53018 .78835 m .52914 .77073 L .55307 .76113 L p .707 .577 .707 r
F P
0 g
s
.55307 .76113 m .55412 .77876 L .53018 .78835 L p .707 .577 .707 r
F P
0 g
s
.52755 .27489 m .49165 .79215 L .53647 .7948 L p .707 .577 .707 r
F P
0 g
s
.53647 .7948 m .57236 .27754 L .52755 .27489 L p .707 .577 .707 r
F P
0 g
s
.29014 .79387 m .29119 .8115 L .32048 .80499 L p .707 .577 .707 r
F P
0 g
s
.32048 .80499 m .31943 .78736 L .29014 .79387 L p .707 .577 .707 r
F P
0 g
s
.64089 .63067 m .64274 .6848 L .61157 .68332 L p .707 .577 .707 r
F P
0 g
s
.61157 .68332 m .60972 .62918 L .64089 .63067 L p .707 .577 .707 r
F P
0 g
s
.57791 .63115 m .57976 .68529 L .55041 .69052 L p .707 .577 .707 r
F P
0 g
s
.55238 .74312 m .55034 .70781 L .57964 .70138 L p .707 .577 .707 r
F P
0 g
s
.57964 .70138 m .58168 .73669 L .55238 .74312 L p .707 .577 .707 r
F P
0 g
s
.55412 .77876 m .55307 .76113 L .58237 .75462 L p .707 .577 .707 r
F P
0 g
s
.58237 .75462 m .58341 .77225 L .55412 .77876 L p .707 .577 .707 r
F P
0 g
s
.57236 .27754 m .53647 .7948 L .57774 .79587 L p .707 .577 .707 r
F P
0 g
s
.57976 .68529 m .57791 .63115 L .60972 .62918 L p .707 .577 .707 r
F P
0 g
s
.60972 .62918 m .61157 .68332 L .57976 .68529 L p .707 .577 .707 r
F P
0 g
s
.58168 .73669 m .57964 .70138 L .61142 .69865 L p .707 .577 .707 r
F P
0 g
s
.61142 .69865 m .61346 .73395 L .58168 .73669 L p .707 .577 .707 r
F P
0 g
s
.57774 .79587 m .61364 .27861 L .57236 .27754 L p .707 .577 .707 r
F P
0 g
s
.22826 .81308 m .22721 .79546 L .19974 .79037 L p .707 .577 .707 r
F P
0 g
s
.22721 .79546 m .22826 .81308 L .25941 .81429 L p .707 .577 .707 r
F P
0 g
s
.35494 .63789 m .35679 .69203 L .36383 .68107 L p .707 .577 .707 r
F P
0 g
s
.36383 .68107 m .36198 .62693 L .35494 .63789 L p .707 .577 .707 r
F P
0 g
s
.69389 .76659 m .69493 .78422 L .67382 .77575 L p .707 .577 .707 r
F P
0 g
s
.67382 .77575 m .67277 .75813 L .69389 .76659 L p .707 .577 .707 r
F P
0 g
s
.34062 .72412 m .34266 .75942 L .35891 .74779 L p .707 .577 .707 r
F P
0 g
s
.35891 .74779 m .35687 .71249 L .34062 .72412 L p .707 .577 .707 r
F P
0 g
s
.44769 .78817 m .48359 .27092 L .44478 .26601 L p .707 .577 .707 r
F P
0 g
s
.48359 .27092 m .44769 .78817 L .49165 .79215 L p .707 .577 .707 r
F P
0 g
s
.67005 .70494 m .67209 .74025 L .64461 .73518 L p .707 .577 .707 r
F P
0 g
s
.64461 .73518 m .64257 .69987 L .67005 .70494 L p .707 .577 .707 r
F P
0 g
s
.31943 .78736 m .32048 .80499 L .34442 .79539 L p .707 .577 .707 r
F P
0 g
s
.34442 .79539 m .34337 .77777 L .31943 .78736 L p .707 .577 .707 r
F P
0 g
s
.19974 .79037 m .20078 .80799 L .22826 .81308 L p .707 .577 .707 r
F P
0 g
s
.16111 .63938 m .16295 .69351 L .17558 .70325 L p .707 .577 .707 r
F P
0 g
s
.17586 .72807 m .1779 .76338 L .19901 .77179 L p .707 .577 .707 r
F P
0 g
s
.20078 .80799 m .19974 .79037 L .17862 .7819 L p .707 .577 .707 r
F P
0 g
s
.1779 .76338 m .17586 .72807 L .16318 .71714 L p .707 .577 .707 r
F P
0 g
s
.16295 .69351 m .16111 .63938 L .15817 .62849 L p .707 .577 .707 r
F P
0 g
s
.61346 .73395 m .61142 .69865 L .64257 .69987 L p .707 .577 .707 r
F P
0 g
s
.58341 .77225 m .58237 .75462 L .61414 .75183 L p .707 .577 .707 r
F P
0 g
s
.61414 .75183 m .61519 .76946 L .58341 .77225 L p .707 .577 .707 r
F P
0 g
s
.61364 .27861 m .57774 .79587 L .61144 .79525 L p .707 .577 .707 r
F P
0 g
s
.64257 .69987 m .64461 .73518 L .61346 .73395 L p .707 .577 .707 r
F P
0 g
s
.61519 .76946 m .61414 .75183 L .6453 .75304 L p .707 .577 .707 r
F P
0 g
s
.61144 .79525 m .64734 .278 L .61364 .27861 L p .707 .577 .707 r
F P
0 g
s
.17862 .7819 m .17967 .79953 L .20078 .80799 L p .707 .577 .707 r
F P
0 g
s
.34337 .77777 m .34442 .79539 L .36066 .78365 L p .707 .577 .707 r
F P
0 g
s
.36066 .78365 m .35962 .76602 L .34337 .77777 L p .707 .577 .707 r
F P
0 g
s
.67277 .75813 m .67382 .77575 L .64634 .77067 L p .707 .577 .707 r
F P
0 g
s
.64634 .77067 m .6453 .75304 L .67277 .75813 L p .707 .577 .707 r
F P
0 g
s
.40888 .78326 m .44478 .26601 L .41492 .26064 L p .707 .577 .707 r
F P
0 g
s
.44478 .26601 m .40888 .78326 L .44769 .78817 L p .707 .577 .707 r
F P
0 g
s
.35687 .71249 m .35891 .74779 L .36587 .73517 L p .707 .577 .707 r
F P
0 g
s
.36587 .73517 m .36383 .69986 L .35687 .71249 L p .707 .577 .707 r
F P
0 g
s
.16318 .71714 m .16522 .75244 L .1779 .76338 L p .707 .577 .707 r
F P
0 g
s
.36198 .62693 m .36383 .68107 L .36089 .67018 L p .707 .577 .707 r
F P
0 g
s
.36089 .67018 m .35904 .61605 L .36198 .62693 L p .707 .577 .707 r
F P
0 g
s
.15817 .62849 m .16002 .68263 L .16295 .69351 L p .707 .577 .707 r
F P
0 g
s
.17967 .79953 m .17862 .7819 L .16594 .77089 L p .707 .577 .707 r
F P
0 g
s
.6453 .75304 m .64634 .77067 L .61519 .76946 L p .707 .577 .707 r
F P
0 g
s
.16522 .75244 m .16318 .71714 L .16018 .70475 L p .707 .577 .707 r
F P
0 g
s
.16594 .77089 m .16699 .78851 L .17967 .79953 L p .707 .577 .707 r
F P
0 g
s
.16002 .68263 m .15817 .62849 L .16521 .61753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64734 .278 m .61144 .79525 L .63426 .79301 L p .707 .577 .707 r
F P
0 g
s
.63426 .79301 m .67016 .27576 L .64734 .278 L p .707 .577 .707 r
F P
0 g
s
.35962 .76602 m .36066 .78365 L .36762 .77091 L p .707 .577 .707 r
F P
0 g
s
.36762 .77091 m .36657 .75328 L .35962 .76602 L p .707 .577 .707 r
F P
0 g
s
.36383 .69986 m .36587 .73517 L .36287 .72278 L p .707 .577 .707 r
F P
0 g
s
.36287 .72278 m .36083 .68747 L .36383 .69986 L p .707 .577 .707 r
F P
0 g
s
.16018 .70475 m .16222 .74006 L .16522 .75244 L p .707 .577 .707 r
F P
0 g
s
.37902 .7779 m .41492 .26064 L .39694 .25536 L p .707 .577 .707 r
F P
0 g
s
.41492 .26064 m .37902 .7779 L .40888 .78326 L p .707 .577 .707 r
F P
0 g
s
.35904 .61605 m .36089 .67018 L .34827 .66044 L p .707 .577 .707 r
F P
0 g
s
.34827 .66044 m .34642 .60631 L .35904 .61605 L p .707 .577 .707 r
F P
0 g
s
.16699 .78851 m .16594 .77089 L .16293 .7584 L p .707 .577 .707 r
F P
0 g
s
.16521 .61753 m .16706 .67166 L .16002 .68263 L p .707 .577 .707 r
F P
0 g
s
.16222 .74006 m .16018 .70475 L .16714 .69212 L p .707 .577 .707 r
F P
0 g
s
.16293 .7584 m .16397 .77602 L .16699 .78851 L p .707 .577 .707 r
F P
0 g
s
.16706 .67166 m .16521 .61753 L .18153 .60757 L p .707 .577 .707 r
F P
0 g
s
.36657 .75328 m .36762 .77091 L .36461 .75842 L p .707 .577 .707 r
F P
0 g
s
.36461 .75842 m .36356 .74079 L .36657 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.67016 .27576 m .63426 .79301 L .64397 .78936 L p .707 .577 .707 r
F P
0 g
s
.67687 .6597 m .67502 .60557 L .66103 .60049 L p .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .66117 .54158 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .63963 .78466 L p .65197 .62748 L .707 .577 .707 r
F P
0 g
s
.65197 .62748 m .65277 .62262 L .64397 .78936 L .707 .577 .707 r
F
.65362 .60643 m .65409 .60236 L .64397 .78936 L F
.66117 .54158 m .6596 .5642 L p .65409 .60236 L F P
0 g
s
.6596 .5642 m .64397 .78936 L p .65409 .60236 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .62164 .77937 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .64132 .58818 L p .64995 .62627 L .707 .577 .707 r
F P
0 g
s
.65056 .6266 m .65394 .59792 L .64995 .62627 L .707 .577 .707 r
F
.63842 .61998 m .64248 .6222 L .63963 .78466 L F
.65059 .62662 m .64699 .67851 L p .64248 .6222 L F P
0 g
s
.64699 .67851 m .63963 .78466 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64132 .58818 L .6391 .57993 L p .707 .577 .707 r
F P
0 g
s
.65409 .60236 m .65394 .59792 L p .65056 .6266 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .65056 .6266 L .65037 .62814 L .707 .577 .707 r
F
.65409 .60236 m .65056 .6266 L .65059 .62662 L F
.67987 .27211 m .67016 .27576 L p .66139 .44768 L F P
0 g
s
.66117 .54158 m .67987 .27211 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64132 .58818 m .64248 .6222 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .64132 .58818 L .64781 .6459 L .707 .577 .707 r
F
.65754 .26212 m .67552 .26741 L p .63842 .61998 L F P
0 g
s
.62164 .77937 m .63291 .61698 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.63291 .61698 m .65754 .26212 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64781 .6459 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64317 .64231 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .65059 .62662 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.64781 .6459 m .65579 .65205 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65458 .59815 m .65394 .59792 L p .65445 .59929 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .65579 .65205 L .67687 .6597 L p .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .67987 .27211 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .67552 .26741 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .65059 .62662 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64248 .6222 L p .63838 .57729 L .707 .577 .707 r
F P
0 g
s
.6391 .57993 m .63838 .57729 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .65056 .6266 L .64995 .62627 L .707 .577 .707 r
F
.65197 .62748 m .65362 .60643 L .65277 .62262 L F
.67987 .27211 m .66117 .54158 L p .65362 .60643 L F P
0 g
s
.65579 .65205 m .65409 .60236 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .65607 .68305 L .64447 .67304 L p .707 .577 .707 r
F P
0 g
s
.64447 .67304 m .64339 .67211 L p .6442 .67465 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .64447 .67304 L .6442 .67465 L .707 .577 .707 r
F
.66103 .60049 m .65458 .59815 L p .66099 .61691 L F P
0 g
s
.66099 .61691 m .65458 .59815 L .65445 .59929 L .707 .577 .707 r
F
.67687 .6597 m .66103 .60049 L .66099 .61691 L F
.36083 .68747 m .36287 .72278 L .35019 .71184 L p F P
0 g
s
.35019 .71184 m .34815 .67654 L .36083 .68747 L p .707 .577 .707 r
F P
0 g
s
.16714 .69212 m .16918 .72743 L .16222 .74006 L p .707 .577 .707 r
F P
0 g
s
.34642 .60631 m .34827 .66044 L .32719 .65279 L p .707 .577 .707 r
F P
0 g
s
.32719 .65279 m .32534 .59866 L .34642 .60631 L p .707 .577 .707 r
F P
0 g
s
.16397 .77602 m .16293 .7584 L .16988 .74566 L p .707 .577 .707 r
F P
0 g
s
.18153 .60757 m .18338 .6617 L .16706 .67166 L p .707 .577 .707 r
F P
0 g
s
.36356 .74079 m .36461 .75842 L .35193 .7474 L p .707 .577 .707 r
F P
0 g
s
.35193 .7474 m .35088 .72978 L .36356 .74079 L p .707 .577 .707 r
F P
0 g
s
.36104 .77261 m .39694 .25536 L .39259 .25066 L p .707 .577 .707 r
F P
0 g
s
.39694 .25536 m .36104 .77261 L .37902 .7779 L p .707 .577 .707 r
F P
0 g
s
.18338 .6617 m .18153 .60757 L .20555 .59957 L p .707 .577 .707 r
F P
0 g
s
.16918 .72743 m .16714 .69212 L .18339 .68049 L p .707 .577 .707 r
F P
0 g
s
.16988 .74566 m .17093 .76328 L .16397 .77602 L p .707 .577 .707 r
F P
0 g
s
.32534 .59866 m .32719 .65279 L .29973 .64799 L p .707 .577 .707 r
F P
0 g
s
.29973 .64799 m .29788 .59386 L .32534 .59866 L p .707 .577 .707 r
F P
0 g
s
.34815 .67654 m .35019 .71184 L .32908 .70343 L p .707 .577 .707 r
F P
0 g
s
.32908 .70343 m .32704 .66812 L .34815 .67654 L p .707 .577 .707 r
F P
0 g
s
.18339 .68049 m .18543 .7158 L .16918 .72743 L p .707 .577 .707 r
F P
0 g
s
.2074 .65371 m .20555 .59957 L .2349 .59434 L p .707 .577 .707 r
F P
0 g
s
.20555 .59957 m .2074 .65371 L .18338 .6617 L p .707 .577 .707 r
F P
0 g
s
.17093 .76328 m .16988 .74566 L .18613 .73392 L p .707 .577 .707 r
F P
0 g
s
.18543 .7158 m .18339 .68049 L .20733 .671 L p .707 .577 .707 r
F P
0 g
s
.29788 .59386 m .29973 .64799 L .26856 .6465 L p .707 .577 .707 r
F P
0 g
s
.26856 .6465 m .26671 .59237 L .29788 .59386 L p .707 .577 .707 r
F P
0 g
s
.18613 .73392 m .18717 .75154 L .17093 .76328 L p .707 .577 .707 r
F P
0 g
s
.23675 .64847 m .2349 .59434 L .26671 .59237 L p .707 .577 .707 r
F P
0 g
s
.2349 .59434 m .23675 .64847 L .2074 .65371 L p .707 .577 .707 r
F P
0 g
s
.26671 .59237 m .26856 .6465 L .23675 .64847 L p .707 .577 .707 r
F P
0 g
s
.35088 .72978 m .35193 .7474 L .33081 .73894 L p .707 .577 .707 r
F P
0 g
s
.33081 .73894 m .32976 .72131 L .35088 .72978 L p .707 .577 .707 r
F P
0 g
s
.32704 .66812 m .32908 .70343 L .3016 .69836 L p .707 .577 .707 r
F P
0 g
s
.3016 .69836 m .29956 .66306 L .32704 .66812 L p .707 .577 .707 r
F P
0 g
s
.20733 .671 m .20937 .7063 L .18543 .7158 L p .707 .577 .707 r
F P
0 g
s
.7355 .66599 m .73365 .61186 L .70248 .61037 L p .707 .577 .707 r
F P
0 g
s
.73365 .61186 m .7355 .66599 L .76731 .66402 L p .707 .577 .707 r
F P
0 g
s
.76731 .66402 m .76546 .60989 L .73365 .61186 L p .707 .577 .707 r
F P
0 g
s
.39259 .25066 m .35669 .76791 L .36104 .77261 L p .707 .577 .707 r
F P
0 g
s
.35669 .76791 m .39259 .25066 L .4023 .24701 L p .707 .577 .707 r
F P
0 g
s
.76546 .60989 m .76731 .66402 L .79666 .65879 L p .707 .577 .707 r
F P
0 g
s
.79666 .65879 m .79481 .60465 L .76546 .60989 L p .707 .577 .707 r
F P
0 g
s
.20937 .7063 m .20733 .671 L .23663 .66457 L p .707 .577 .707 r
F P
0 g
s
.18717 .75154 m .18613 .73392 L .21006 .72432 L p .707 .577 .707 r
F P
0 g
s
.70433 .6645 m .70248 .61037 L .67502 .60557 L p .707 .577 .707 r
F P
0 g
s
.70248 .61037 m .70433 .6645 L .7355 .66599 L p .707 .577 .707 r
F P
0 g
s
.29956 .66306 m .3016 .69836 L .27045 .69714 L p .707 .577 .707 r
F P
0 g
s
.27045 .69714 m .26841 .66183 L .29956 .66306 L p .707 .577 .707 r
F P
0 g
s
.21006 .72432 m .21111 .74194 L .18717 .75154 L p .707 .577 .707 r
F P
0 g
s
.23867 .69987 m .23663 .66457 L .26841 .66183 L p .707 .577 .707 r
F P
0 g
s
.23663 .66457 m .23867 .69987 L .20937 .7063 L p .707 .577 .707 r
F P
0 g
s
.79481 .60465 m .79666 .65879 L .82068 .65079 L p .707 .577 .707 r
F P
0 g
s
.82068 .65079 m .81883 .59666 L .79481 .60465 L p .707 .577 .707 r
F P
0 g
s
.32976 .72131 m .33081 .73894 L .30333 .73385 L p .707 .577 .707 r
F P
0 g
s
.30333 .73385 m .30229 .71623 L .32976 .72131 L p .707 .577 .707 r
F P
0 g
s
.26841 .66183 m .27045 .69714 L .23867 .69987 L p .707 .577 .707 r
F P
0 g
s
.67502 .60557 m .67687 .6597 L .70433 .6645 L p .707 .577 .707 r
F P
0 g
s
.21111 .74194 m .21006 .72432 L .23936 .71781 L p .707 .577 .707 r
F P
0 g
s
.73785 .73306 m .73581 .69776 L .70466 .69653 L p .707 .577 .707 r
F P
0 g
s
.73581 .69776 m .73785 .73306 L .76963 .73033 L p .707 .577 .707 r
F P
0 g
s
.76963 .73033 m .76759 .69502 L .73581 .69776 L p .707 .577 .707 r
F P
0 g
s
.30229 .71623 m .30333 .73385 L .27218 .73264 L p .707 .577 .707 r
F P
0 g
s
.27218 .73264 m .27113 .71502 L .30229 .71623 L p .707 .577 .707 r
F P
0 g
s
.76759 .69502 m .76963 .73033 L .79893 .7239 L p .707 .577 .707 r
F P
0 g
s
.79893 .7239 m .79689 .68859 L .76759 .69502 L p .707 .577 .707 r
F P
0 g
s
.23936 .71781 m .2404 .73543 L .21111 .74194 L p .707 .577 .707 r
F P
0 g
s
.81883 .59666 m .82068 .65079 L .837 .64083 L p .707 .577 .707 r
F P
0 g
s
.837 .64083 m .83515 .5867 L .81883 .59666 L p .707 .577 .707 r
F P
0 g
s
.2404 .73543 m .23936 .71781 L .27113 .71502 L p .707 .577 .707 r
F P
0 g
s
.7067 .73184 m .70466 .69653 L .67718 .69146 L p .707 .577 .707 r
F P
0 g
s
.70466 .69653 m .7067 .73184 L .73785 .73306 L p .707 .577 .707 r
F P
0 g
s
.27113 .71502 m .27218 .73264 L .2404 .73543 L p .707 .577 .707 r
F P
0 g
s
.79689 .68859 m .79893 .7239 L .82288 .7144 L p .707 .577 .707 r
F P
0 g
s
.82288 .7144 m .82084 .67909 L .79689 .68859 L p .707 .577 .707 r
F P
0 g
s
.3664 .76426 m .4023 .24701 L .42512 .24476 L p .707 .577 .707 r
F P
0 g
s
.4023 .24701 m .3664 .76426 L .35669 .76791 L p .707 .577 .707 r
F P
0 g
s
.67718 .69146 m .67922 .72677 L .7067 .73184 L p .707 .577 .707 r
F P
0 g
s
.67922 .72677 m .67718 .69146 L .65607 .68305 L p .707 .577 .707 r
F P
0 g
s
.73963 .77906 m .73858 .76143 L .70743 .76022 L p .707 .577 .707 r
F P
0 g
s
.73858 .76143 m .73963 .77906 L .7714 .77627 L p .707 .577 .707 r
F P
0 g
s
.7714 .77627 m .77036 .75864 L .73858 .76143 L p .707 .577 .707 r
F P
0 g
s
.77036 .75864 m .7714 .77627 L .8007 .76976 L p .707 .577 .707 r
F P
0 g
s
.8007 .76976 m .79965 .75213 L .77036 .75864 L p .707 .577 .707 r
F P
0 g
s
.83515 .5867 m .837 .64083 L .84404 .62987 L p .707 .577 .707 r
F P
0 g
s
.84404 .62987 m .84219 .57573 L .83515 .5867 L p .707 .577 .707 r
F P
0 g
s
.70847 .77785 m .70743 .76022 L .67995 .75514 L p .707 .577 .707 r
F P
0 g
s
.70743 .76022 m .70847 .77785 L .73963 .77906 L p .707 .577 .707 r
F P
0 g
s
.82084 .67909 m .82288 .7144 L .83912 .70277 L p .707 .577 .707 r
F P
0 g
s
.83912 .70277 m .83709 .66746 L .82084 .67909 L p .707 .577 .707 r
F P
0 g
s
.65607 .68305 m .65811 .71836 L .67922 .72677 L p .707 .577 .707 r
F P
0 g
s
.79965 .75213 m .8007 .76976 L .82463 .76016 L p .707 .577 .707 r
F P
0 g
s
.82463 .76016 m .82359 .74253 L .79965 .75213 L p .707 .577 .707 r
F P
0 g
s
.67995 .75514 m .681 .77276 L .70847 .77785 L p .707 .577 .707 r
F P
0 g
s
.65754 .26212 m .62164 .77937 L .59178 .77401 L p .707 .577 .707 r
F P
0 g
s
.59178 .77401 m .62768 .25676 L .65754 .26212 L p .707 .577 .707 r
F P
0 g
s
.681 .77276 m .67995 .75514 L .65883 .74667 L p .707 .577 .707 r
F P
0 g
s
.65883 .74667 m .65988 .7643 L .681 .77276 L p .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .3664 .76426 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .38923 .76202 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.42512 .24476 m .45882 .24415 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .40642 .51423 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .42512 .24476 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.42261 .57752 m .42245 .57307 L .42149 .57313 L p .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .38923 .76202 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.42245 .57307 m .42261 .57752 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .43389 .60337 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .42292 .7614 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.47547 .60008 m .4642 .76248 L p .44794 .61369 L .707 .577 .707 r
F P
0 g
s
.4467 .60236 m .45297 .60186 L .44794 .61369 L .707 .577 .707 r
F
.45297 .60186 m .47547 .60008 L .44794 .61369 L F
.4518 .56784 m .45297 .60186 L p .46069 .58368 L F P
0 g
s
.4518 .56784 m .42245 .57307 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45365 .62197 m .45297 .60186 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45297 .60186 m .4518 .56784 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .47547 .60008 L p .45297 .60186 L .707 .577 .707 r
F P
0 g
s
.5001 .24522 m .54491 .24787 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .47972 .53888 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .5001 .24522 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47582 .55984 L .47368 .56056 L p .707 .577 .707 r
F P
0 g
s
.47368 .56056 m .46999 .56178 L p .47115 .56966 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47368 .56056 L .47115 .56966 L .707 .577 .707 r
F
.46999 .56178 m .4518 .56784 L p .46069 .58368 L F P
0 g
s
.47767 .61398 m .46999 .56178 L .46069 .58368 L .707 .577 .707 r
F
.5001 .24522 m .47972 .53888 L p .4467 .60236 L F P
0 g
s
.4467 .60236 m .47972 .53888 L .45297 .60186 L .707 .577 .707 r
F
.45365 .62197 m .47767 .61398 L p .46069 .58368 L F P
0 g
s
.45297 .60186 m .45365 .62197 L p .46069 .58368 L .707 .577 .707 r
F P
0 g
s
.44286 .6239 m .45365 .62197 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.44031 .60286 m .42261 .57752 L .43389 .60337 L .707 .577 .707 r
F
.44031 .60286 m .43389 .60337 L .44286 .6239 L F
.45365 .62197 m .44141 .60277 L .44031 .60286 L F
.44141 .60277 m .42245 .57307 L .44031 .60286 L F
.45882 .24415 m .5001 .24522 L p .4467 .60236 L F P
0 g
s
.43389 .60337 m .45882 .24415 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.45882 .24415 m .43389 .60337 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.43279 .61928 m .42292 .7614 L p .41704 .59132 L .707 .577 .707 r
F P
0 g
s
.45592 .68708 m .4542 .65728 L p .42459 .6582 L .707 .577 .707 r
F P
0 g
s
.4542 .65728 m .45388 .65177 L .4514 .65232 L p .707 .577 .707 r
F P
0 g
s
.4514 .65232 m .42459 .6582 L p .4542 .65728 L .707 .577 .707 r
F P
0 g
s
.43389 .60337 m .43279 .61928 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.41604 .56248 m .43279 .61928 L .41704 .59132 L .707 .577 .707 r
F
.42261 .57752 m .4243 .62721 L .44286 .6239 L p F P
0 g
s
.4243 .62721 m .42261 .57752 L p .39064 .57504 L .707 .577 .707 r
F P
0 g
s
.42149 .57313 m .39064 .57504 L p .42261 .57752 L .707 .577 .707 r
F P
0 g
s
.39064 .57504 m .39249 .62918 L .41659 .62769 L p .707 .577 .707 r
F P
0 g
s
.41659 .62769 m .4243 .62721 L p .4153 .61325 L .707 .577 .707 r
F P
0 g
s
.4153 .61325 m .39064 .57504 L .41659 .62769 L .707 .577 .707 r
F
.42512 .24476 m .40642 .51423 L p .40122 .45621 L F P
0 g
s
.82359 .74253 m .82463 .76016 L .84088 .74842 L p .707 .577 .707 r
F P
0 g
s
.84088 .74842 m .83983 .73079 L .82359 .74253 L p .707 .577 .707 r
F P
0 g
s
.83709 .66746 m .83912 .70277 L .84609 .69014 L p .707 .577 .707 r
F P
0 g
s
.84609 .69014 m .84405 .65484 L .83709 .66746 L p .707 .577 .707 r
F P
0 g
s
.84219 .57573 m .84404 .62987 L .84111 .61898 L p .707 .577 .707 r
F P
0 g
s
.84111 .61898 m .83926 .56485 L .84219 .57573 L p .707 .577 .707 r
F P
0 g
s
.64339 .67211 m .64543 .70742 L .65811 .71836 L p .707 .577 .707 r
F P
0 g
s
.63838 .57729 m .64023 .63143 L .64317 .64231 L p .707 .577 .707 r
F P
0 g
s
.65988 .7643 m .65883 .74667 L .64615 .73566 L p .707 .577 .707 r
F P
0 g
s
.64543 .70742 m .64339 .67211 L .64039 .65973 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64023 .63143 m .63838 .57729 L .64542 .56633 L p .707 .577 .707 r
F P
0 g
s
.62768 .25676 m .59178 .77401 L .55297 .7691 L p .707 .577 .707 r
F P
0 g
s
.55297 .7691 m .58887 .25185 L .62768 .25676 L p .707 .577 .707 r
F P
0 g
s
.64615 .73566 m .6472 .75328 L .65988 .7643 L p .707 .577 .707 r
F P
0 g
s
.83983 .73079 m .84088 .74842 L .84783 .73568 L p .707 .577 .707 r
F P
0 g
s
.84783 .73568 m .84679 .71805 L .83983 .73079 L p .707 .577 .707 r
F P
0 g
s
.84405 .65484 m .84609 .69014 L .84308 .67776 L p .707 .577 .707 r
F P
0 g
s
.84308 .67776 m .84104 .64245 L .84405 .65484 L p .707 .577 .707 r
F P
0 g
s
.64039 .65973 m .64243 .69503 L .64543 .70742 L p .707 .577 .707 r
F P
0 g
s
.83926 .56485 m .84111 .61898 L .82848 .60924 L p .707 .577 .707 r
F P
0 g
s
.82848 .60924 m .82663 .55511 L .83926 .56485 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64542 .56633 m .64727 .62046 L .64023 .63143 L p .707 .577 .707 r
F P
0 g
s
.6472 .75328 m .64615 .73566 L .64314 .72317 L p .707 .577 .707 r
F P
0 g
s
.58887 .25185 m .55297 .7691 L .50901 .76513 L p .707 .577 .707 r
F P
0 g
s
.50901 .76513 m .54491 .24787 L .58887 .25185 L p .707 .577 .707 r
F P
0 g
s
.64243 .69503 m .64039 .65973 L .64735 .6471 L p .707 .577 .707 r
F P
0 g
s
.39249 .62918 m .39064 .57504 L .35947 .57356 L p .707 .577 .707 r
F P
0 g
s
.64727 .62046 m .64542 .56633 L .66175 .55637 L p .707 .577 .707 r
F P
0 g
s
.64314 .72317 m .64419 .74079 L .6472 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.54491 .24787 m .50901 .76513 L .4642 .76248 L p .707 .577 .707 r
F P
0 g
s
.36132 .62769 m .35947 .57356 L .33201 .56875 L p .707 .577 .707 r
F P
0 g
s
.35947 .57356 m .36132 .62769 L .39249 .62918 L p .707 .577 .707 r
F P
0 g
s
.84679 .71805 m .84783 .73568 L .84482 .72319 L p .707 .577 .707 r
F P
0 g
s
.84482 .72319 m .84377 .70556 L .84679 .71805 L p .707 .577 .707 r
F P
0 g
s
.84104 .64245 m .84308 .67776 L .8304 .66682 L p .707 .577 .707 r
F P
0 g
s
.8304 .66682 m .82837 .63151 L .84104 .64245 L p .707 .577 .707 r
F P
0 g
s
.82663 .55511 m .82848 .60924 L .80741 .60159 L p .707 .577 .707 r
F P
0 g
s
.80741 .60159 m .80556 .54746 L .82663 .55511 L p .707 .577 .707 r
F P
0 g
s
.64735 .6471 m .64939 .68241 L .64243 .69503 L p .707 .577 .707 r
F P
0 g
s
.66175 .55637 m .6636 .6105 L .64727 .62046 L p .707 .577 .707 r
F P
0 g
s
.33386 .62289 m .33201 .56875 L .31093 .5611 L p .707 .577 .707 r
F P
0 g
s
.33201 .56875 m .33386 .62289 L .36132 .62769 L p .707 .577 .707 r
F P
0 g
s
.64419 .74079 m .64314 .72317 L .6501 .71043 L p .707 .577 .707 r
F P
0 g
s
.6636 .6105 m .66175 .55637 L .68576 .54837 L p .707 .577 .707 r
F P
0 g
s
.64939 .68241 m .64735 .6471 L .6636 .63547 L p .707 .577 .707 r
F P
0 g
s
.39484 .69625 m .3928 .66094 L .36165 .65971 L p .707 .577 .707 r
F P
0 g
s
.3928 .66094 m .39484 .69625 L .42662 .69351 L p .707 .577 .707 r
F P
0 g
s
.42662 .69351 m .42459 .6582 L .3928 .66094 L p .707 .577 .707 r
F P
0 g
s
.6501 .71043 m .65114 .72805 L .64419 .74079 L p .707 .577 .707 r
F P
0 g
s
.42459 .6582 m .42662 .69351 L .45592 .68708 L p .707 .577 .707 r
F P
0 g
s
.47582 .55984 m .47767 .61398 L .49399 .60401 L p .707 .577 .707 r
F P
0 g
s
.49399 .60401 m .49214 .54988 L .47582 .55984 L p .707 .577 .707 r
F P
0 g
s
.80556 .54746 m .80741 .60159 L .77994 .59679 L p .707 .577 .707 r
F P
0 g
s
.77994 .59679 m .77809 .54266 L .80556 .54746 L p .707 .577 .707 r
F P
0 g
s
.36369 .69502 m .36165 .65971 L .33417 .65465 L p .707 .577 .707 r
F P
0 g
s
.36165 .65971 m .36369 .69502 L .39484 .69625 L p .707 .577 .707 r
F P
0 g
s
.84377 .70556 m .84482 .72319 L .83214 .71217 L p .707 .577 .707 r
F P
0 g
s
.83214 .71217 m .83109 .69455 L .84377 .70556 L p .707 .577 .707 r
F P
0 g
s
.82837 .63151 m .8304 .66682 L .80929 .65841 L p .707 .577 .707 r
F P
0 g
s
.80929 .65841 m .80725 .6231 L .82837 .63151 L p .707 .577 .707 r
F P
0 g
s
.31093 .5611 m .31278 .61524 L .33386 .62289 L p .707 .577 .707 r
F P
0 g
s
.6636 .63547 m .66564 .67078 L .64939 .68241 L p .707 .577 .707 r
F P
0 g
s
.45388 .65177 m .45592 .68708 L .47987 .67759 L p .707 .577 .707 r
F P
0 g
s
.47987 .67759 m .47783 .64228 L .45388 .65177 L p .707 .577 .707 r
F P
0 g
s
.68761 .60251 m .68576 .54837 L .71511 .54314 L p .707 .577 .707 r
F P
0 g
s
.68576 .54837 m .68761 .60251 L .6636 .6105 L p .707 .577 .707 r
F P
0 g
s
.31278 .61524 m .31093 .5611 L .29831 .55136 L p .707 .577 .707 r
F P
0 g
s
.33417 .65465 m .33621 .68995 L .36369 .69502 L p .707 .577 .707 r
F P
0 g
s
.33621 .68995 m .33417 .65465 L .31306 .64623 L p .707 .577 .707 r
F P
0 g
s
.77809 .54266 m .77994 .59679 L .74878 .5953 L p .707 .577 .707 r
F P
0 g
s
.74878 .5953 m .74693 .54117 L .77809 .54266 L p .707 .577 .707 r
F P
0 g
s
.65114 .72805 m .6501 .71043 L .66634 .69868 L p .707 .577 .707 r
F P
0 g
s
.66564 .67078 m .6636 .63547 L .68755 .62598 L p .707 .577 .707 r
F P
0 g
s
.39662 .74224 m .39557 .72462 L .36442 .72341 L p .707 .577 .707 r
F P
0 g
s
.39557 .72462 m .39662 .74224 L .42839 .73945 L p .707 .577 .707 r
F P
0 g
s
.42839 .73945 m .42735 .72183 L .39557 .72462 L p .707 .577 .707 r
F P
0 g
s
.42735 .72183 m .42839 .73945 L .45769 .73294 L p .707 .577 .707 r
F P
0 g
s
.45769 .73294 m .45664 .71532 L .42735 .72183 L p .707 .577 .707 r
F P
0 g
s
.71696 .59727 m .71511 .54314 L .74693 .54117 L p .707 .577 .707 r
F P
0 g
s
.71511 .54314 m .71696 .59727 L .68761 .60251 L p .707 .577 .707 r
F P
0 g
s
.49214 .54988 m .49399 .60401 L .50103 .59305 L p .707 .577 .707 r
F P
0 g
s
.50103 .59305 m .49918 .53892 L .49214 .54988 L p .707 .577 .707 r
F P
0 g
s
.74693 .54117 m .74878 .5953 L .71696 .59727 L p .707 .577 .707 r
F P
0 g
s
.66634 .69868 m .66739 .71631 L .65114 .72805 L p .707 .577 .707 r
F P
0 g
s
.36546 .74103 m .36442 .72341 L .33694 .71832 L p .707 .577 .707 r
F P
0 g
s
.36442 .72341 m .36546 .74103 L .39662 .74224 L p .707 .577 .707 r
F P
0 g
s
.47783 .64228 m .47987 .67759 L .49611 .66596 L p .707 .577 .707 r
F P
0 g
s
.49611 .66596 m .49408 .63065 L .47783 .64228 L p .707 .577 .707 r
F P
0 g
s
.80725 .6231 m .80929 .65841 L .78182 .65334 L p .707 .577 .707 r
F P
0 g
s
.78182 .65334 m .77978 .61803 L .80725 .6231 L p .707 .577 .707 r
F P
0 g
s
.83109 .69455 m .83214 .71217 L .81103 .7037 L p .707 .577 .707 r
F P
0 g
s
.81103 .7037 m .80998 .68608 L .83109 .69455 L p .707 .577 .707 r
F P
0 g
s
.29831 .55136 m .30016 .60549 L .31278 .61524 L p .707 .577 .707 r
F P
0 g
s
.31306 .64623 m .3151 .68154 L .33621 .68995 L p .707 .577 .707 r
F P
0 g
s
.45664 .71532 m .45769 .73294 L .48162 .72334 L p .707 .577 .707 r
F P
0 g
s
.48162 .72334 m .48058 .70572 L .45664 .71532 L p .707 .577 .707 r
F P
0 g
s
.68755 .62598 m .68959 .66128 L .66564 .67078 L p .707 .577 .707 r
F P
0 g
s
.33694 .71832 m .33799 .73595 L .36546 .74103 L p .707 .577 .707 r
F P
0 g
s
.68959 .66128 m .68755 .62598 L .71684 .61955 L p .707 .577 .707 r
F P
0 g
s
.30016 .60549 m .29831 .55136 L .29537 .54048 L p .707 .577 .707 r
F P
0 g
s
.3151 .68154 m .31306 .64623 L .30038 .6353 L p .707 .577 .707 r
F P
0 g
s
.33799 .73595 m .33694 .71832 L .31582 .70986 L p .707 .577 .707 r
F P
0 g
s
.66739 .71631 m .66634 .69868 L .69028 .68909 L p .707 .577 .707 r
F P
0 g
s
.77978 .61803 m .78182 .65334 L .75066 .65212 L p .707 .577 .707 r
F P
0 g
s
.75066 .65212 m .74862 .61681 L .77978 .61803 L p .707 .577 .707 r
F P
0 g
s
.71888 .65485 m .71684 .61955 L .74862 .61681 L p .707 .577 .707 r
F P
0 g
s
.71684 .61955 m .71888 .65485 L .68959 .66128 L p .707 .577 .707 r
F P
0 g
s
.74862 .61681 m .75066 .65212 L .71888 .65485 L p .707 .577 .707 r
F P
0 g
s
.31582 .70986 m .31687 .72748 L .33799 .73595 L p .707 .577 .707 r
F P
0 g
s
.69028 .68909 m .69133 .70671 L .66739 .71631 L p .707 .577 .707 r
F P
0 g
s
.48058 .70572 m .48162 .72334 L .49787 .7116 L p .707 .577 .707 r
F P
0 g
s
.49787 .7116 m .49682 .69398 L .48058 .70572 L p .707 .577 .707 r
F P
0 g
s
.80998 .68608 m .81103 .7037 L .78355 .69862 L p .707 .577 .707 r
F P
0 g
s
.78355 .69862 m .7825 .68099 L .80998 .68608 L p .707 .577 .707 r
F P
0 g
s
.49408 .63065 m .49611 .66596 L .50308 .65333 L p .707 .577 .707 r
F P
0 g
s
.50308 .65333 m .50104 .61802 L .49408 .63065 L p .707 .577 .707 r
F P
0 g
s
.49918 .53892 m .50103 .59305 L .4981 .58217 L p .707 .577 .707 r
F P
0 g
s
.4981 .58217 m .49625 .52803 L .49918 .53892 L p .707 .577 .707 r
F P
0 g
s
.30038 .6353 m .30242 .67061 L .3151 .68154 L p .707 .577 .707 r
F P
0 g
s
.29537 .54048 m .29722 .59461 L .30016 .60549 L p .707 .577 .707 r
F P
0 g
s
.69133 .70671 m .69028 .68909 L .71957 .68258 L p .707 .577 .707 r
F P
0 g
s
.31687 .72748 m .31582 .70986 L .30314 .69884 L p .707 .577 .707 r
F P
0 g
s
.30242 .67061 m .30038 .6353 L .29738 .62291 L p .707 .577 .707 r
F P
0 g
s
.7825 .68099 m .78355 .69862 L .75239 .69741 L p .707 .577 .707 r
F P
0 g
s
.75239 .69741 m .75135 .67979 L .7825 .68099 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29722 .59461 m .29537 .54048 L .30241 .52952 L p .707 .577 .707 r
F P
0 g
s
.71957 .68258 m .72062 .7002 L .69133 .70671 L p .707 .577 .707 r
F P
0 g
s
.72062 .7002 m .71957 .68258 L .75135 .67979 L p .707 .577 .707 r
F P
0 g
s
.30314 .69884 m .30419 .71647 L .31687 .72748 L p .707 .577 .707 r
F P
0 g
s
.75135 .67979 m .75239 .69741 L .72062 .7002 L p .707 .577 .707 r
F P
0 g
s
.49682 .69398 m .49787 .7116 L .50482 .69886 L p .707 .577 .707 r
F P
0 g
s
.50482 .69886 m .50378 .68124 L .49682 .69398 L p .707 .577 .707 r
F P
0 g
s
.50104 .61802 m .50308 .65333 L .50007 .64094 L p .707 .577 .707 r
F P
0 g
s
.50007 .64094 m .49803 .60563 L .50104 .61802 L p .707 .577 .707 r
F P
0 g
s
.29738 .62291 m .29942 .65822 L .30242 .67061 L p .707 .577 .707 r
F P
0 g
s
.49625 .52803 m .4981 .58217 L .48547 .57243 L p .707 .577 .707 r
F P
0 g
s
.48547 .57243 m .48362 .51829 L .49625 .52803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30241 .52952 m .30426 .58365 L .29722 .59461 L p .707 .577 .707 r
F P
0 g
s
.30419 .71647 m .30314 .69884 L .30013 .68635 L p .707 .577 .707 r
F P
0 g
s
.29942 .65822 m .29738 .62291 L .30434 .61028 L p .707 .577 .707 r
F P
0 g
s
.30426 .58365 m .30241 .52952 L .31874 .51955 L p .707 .577 .707 r
F P
0 g
s
.30013 .68635 m .30118 .70398 L .30419 .71647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50378 .68124 m .50482 .69886 L .50181 .68637 L p .707 .577 .707 r
F P
0 g
s
.50181 .68637 m .50076 .66875 L .50378 .68124 L p .707 .577 .707 r
F P
0 g
s
.49803 .60563 m .50007 .64094 L .48739 .63001 L p .707 .577 .707 r
F P
0 g
s
.48739 .63001 m .48535 .5947 L .49803 .60563 L p .707 .577 .707 r
F P
0 g
s
.48362 .51829 m .48547 .57243 L .4644 .56478 L p .707 .577 .707 r
F P
0 g
s
.4644 .56478 m .46255 .51064 L .48362 .51829 L p .707 .577 .707 r
F P
0 g
s
.30434 .61028 m .30638 .64559 L .29942 .65822 L p .707 .577 .707 r
F P
0 g
s
.31874 .51955 m .32059 .57369 L .30426 .58365 L p .707 .577 .707 r
F P
0 g
s
.30118 .70398 m .30013 .68635 L .30709 .67361 L p .707 .577 .707 r
F P
0 g
s
.32059 .57369 m .31874 .51955 L .34275 .51156 L p .707 .577 .707 r
F P
0 g
s
.30638 .64559 m .30434 .61028 L .32059 .59865 L p .707 .577 .707 r
F P
0 g
s
.30709 .67361 m .30813 .69124 L .30118 .70398 L p .707 .577 .707 r
F P
0 g
s
.46255 .51064 m .4644 .56478 L .43693 .55997 L p .707 .577 .707 r
F P
0 g
s
.43693 .55997 m .43508 .50584 L .46255 .51064 L p .707 .577 .707 r
F P
0 g
s
.50076 .66875 m .50181 .68637 L .48913 .67535 L p .707 .577 .707 r
F P
0 g
s
.48913 .67535 m .48808 .65773 L .50076 .66875 L p .707 .577 .707 r
F P
0 g
s
.48535 .5947 m .48739 .63001 L .46628 .62159 L p .707 .577 .707 r
F P
0 g
s
.46628 .62159 m .46424 .58629 L .48535 .5947 L p .707 .577 .707 r
F P
0 g
s
.32059 .59865 m .32263 .63396 L .30638 .64559 L p .707 .577 .707 r
F P
0 g
s
.3446 .56569 m .34275 .51156 L .3721 .50632 L p .707 .577 .707 r
F P
0 g
s
.34275 .51156 m .3446 .56569 L .32059 .57369 L p .707 .577 .707 r
F P
0 g
s
.43508 .50584 m .43693 .55997 L .40577 .55848 L p .707 .577 .707 r
F P
0 g
s
.40577 .55848 m .40392 .50435 L .43508 .50584 L p .707 .577 .707 r
F P
0 g
s
.30813 .69124 m .30709 .67361 L .32333 .66187 L p .707 .577 .707 r
F P
0 g
s
.32263 .63396 m .32059 .59865 L .34454 .58916 L p .707 .577 .707 r
F P
0 g
s
.37395 .56046 m .3721 .50632 L .40392 .50435 L p .707 .577 .707 r
F P
0 g
s
.3721 .50632 m .37395 .56046 L .3446 .56569 L p .707 .577 .707 r
F P
0 g
s
.40392 .50435 m .40577 .55848 L .37395 .56046 L p .707 .577 .707 r
F P
0 g
s
.32333 .66187 m .32438 .67949 L .30813 .69124 L p .707 .577 .707 r
F P
0 g
s
.46424 .58629 m .46628 .62159 L .43881 .61653 L p .707 .577 .707 r
F P
0 g
s
.43881 .61653 m .43677 .58122 L .46424 .58629 L p .707 .577 .707 r
F P
0 g
s
.48808 .65773 m .48913 .67535 L .46801 .66689 L p .707 .577 .707 r
F P
0 g
s
.46801 .66689 m .46697 .64926 L .48808 .65773 L p .707 .577 .707 r
F P
0 g
s
.34454 .58916 m .34658 .62447 L .32263 .63396 L p .707 .577 .707 r
F P
0 g
s
.34658 .62447 m .34454 .58916 L .37383 .58273 L p .707 .577 .707 r
F P
0 g
s
.32438 .67949 m .32333 .66187 L .34727 .65227 L p .707 .577 .707 r
F P
0 g
s
.43677 .58122 m .43881 .61653 L .40765 .6153 L p .707 .577 .707 r
F P
0 g
s
.40765 .6153 m .40561 .57999 L .43677 .58122 L p .707 .577 .707 r
F P
0 g
s
.37587 .61804 m .37383 .58273 L .40561 .57999 L p .707 .577 .707 r
F P
0 g
s
.37383 .58273 m .37587 .61804 L .34658 .62447 L p .707 .577 .707 r
F P
0 g
s
.40561 .57999 m .40765 .6153 L .37587 .61804 L p .707 .577 .707 r
F P
0 g
s
.34727 .65227 m .34832 .6699 L .32438 .67949 L p .707 .577 .707 r
F P
0 g
s
.46697 .64926 m .46801 .66689 L .44054 .6618 L p .707 .577 .707 r
F P
0 g
s
.44054 .6618 m .43949 .64418 L .46697 .64926 L p .707 .577 .707 r
F P
0 g
s
.34832 .6699 m .34727 .65227 L .37656 .64576 L p .707 .577 .707 r
F P
0 g
s
.43949 .64418 m .44054 .6618 L .40938 .6606 L p .707 .577 .707 r
F P
0 g
s
.40938 .6606 m .40834 .64297 L .43949 .64418 L p .707 .577 .707 r
F P
0 g
s
.37656 .64576 m .37761 .66338 L .34832 .6699 L p .707 .577 .707 r
F P
0 g
s
.37761 .66338 m .37656 .64576 L .40834 .64297 L p .707 .577 .707 r
F P
0 g
s
.40834 .64297 m .40938 .6606 L .37761 .66338 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
MWoo7P00RGoo001aOol50002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP03FUH=001l
Ool006moo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00AJEPT007=oo`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H006eoo`00Kgoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPH006Mo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH6001QOol006moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH00002001NOol006moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001LOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006mo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005]oo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP03FUH0
1000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000GWoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol0
06]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF
0003FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP000UYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00
Jgoo00@005YFFUH0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`04001JEUYF
0002FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00003FUH01000FUIJ
EP0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo
001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUIJEP0A000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Ioo`P000AJ
EP03001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00H7oo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001LOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol005Yoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00F7oo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HGoo001FOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001EOol00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00HGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001DOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00HGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0057oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo2@0015YF00<005YFFUH0
0UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000Aoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP00008003Aoo`00Dgoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH=0005FUH80004FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEPD000=oo`05001JEUYF001JEP05
0009FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool01000FUIJEP0015YF00@005YFFUIJEP8000Qoo`05001JEUYF001JEP050009FUH00`00FUIJEP07
FUH200000eYF001JEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00D0
05YF000005YF00@000Eoo`05001JEUYF001JEP050009FUH00`00FUIJEP08FUH30003FUH20005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH015YF500015YF00<005YF
FUH025YF00@005YFFUH0009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF2P000UYF00<005YFFUH02EYF00@005YFFUIJEP@000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00EJEP03001JEP00
00H000AJEP03001JEUYF009JEPP000MJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP<00003FUH005YF00=JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
Agoo3`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00P0015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000oOol80004FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol60003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
10001Woo1@002Woo10000UYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH4
000:Ool5000;Ool70004FUH01@00FUIJEUYF0000;Goo000cOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001J
EP0000@000eoo`D000Moo`@00003FUH005YF00AJEP<00003FUH005YF009JEP03001oogoo02]oo`00
<Goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00FUH00004FUH200000eYF001JEP02FUH90005Ool300000goo000000050005FUH00`00
FUIJEP04FUH01000FUH000000eYF00<007ooOol0:goo000_Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJ
EPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH?0002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0
00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF008000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@0
00IJEP8000=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00001JEP020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001J
EUYFFUH200000eYF0000000H000:FUH300000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF0P0015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP000eYF00@005YF000000=JEP07001JEUYFFUH007oo00000UYF00<005YF
FUH01@0025YF00<005YFFUH025YF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEUYFFUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001J
EP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF0`001EYF00H005YFFUH007oo0002FUH00`00FUIJEP050008
FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000^Ool002aoo`03001J
EP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0002FUH01000FUIJEP001EYF00P005YFFUH007oo001JEP000eYF1@0025YF00<005YFFUH025YF
00@005YF0000009JEP@0009JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH00000;Woo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP08FUH20004FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF
000000050004FUH01000FUIJEUYF20001EYF0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH00UYF2@002Goo1P0000AJ
EP000000009JEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH50002FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH50009Ool3000:Ool2000015YF001JEUYF1000
0UYF10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF10001EYF00<005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YFFUH0
02eoo`00;7oo00@005YFFUH000AJEP04001JEUYFFUH2000=Ool50009Ool01000FUIJEP0015YF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
15YF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00;Goo00<005YF000015YF00D005YF000005YF00@000Yoo`D000Qoo`80
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP800003FUH005YF
00AJEQT0009JEP03001JEUYF008000IJEP03001JEUYF00AJEPH000QJEPT000AJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF000015YF00<005YFFUH00eYF2P0015YF00<005YFFUH00UYF2@002Goo0`0000EJEP00FUIJ
EP0002eoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP<000MJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEPD000AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEP0000@000=JEP8000Aoo`T001Eoo`80009JEP03001o
ogoo02]oo`00;Goo00<005YF00000P001EYF00<005YFFUH00`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF0P0015YF00@005YFFUIJEP8000Moo`D001Moo`800003
FUH007oo02aoo`00;Goo00D005YF001JEP0000EJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH200001EYF001JEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUH00005FUH00`00FUIJEP020007Ool5000FOol0
0`00FUH00002000]Ool002eoo`80009JEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH20002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP020007Ool5000EOol01@00FUIJEP00FUH00P00;7oo000]Ool20002FUH00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH200000eYF001JEP06
FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF00<0
05YFFUH00eYF00<005YFFUH00P0027oo3`0027oo0P000eYF00@005YF000002aoo`00;Goo0P000UYF
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P000eYF
00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YF00000P001eYF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P00
0UYF00<005YFFUH00eYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEP0000L00003FUH0
05YF009JEP04001JEP00000/Ool002eoo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP800003FUH005YF00IJEP03
001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJEP800003FUH005YF00aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUH000020004FUH60003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0
000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@00003FUH005YF
009JEP03001JEUYF00EJEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUH0000/Ool002ioo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF009JEQX0
00EJEP05001JEUYFFUH00007FUH01@00FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0006FUH30000
15YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000009J
EP8000EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP@002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00@005YFFUIJEPH0009JEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH01000FUH000001UYF00<005YFFUH00UYF2@0025YF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH6
0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@000AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001J
EP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030004FUH01000FUIJEP00
;Goo000]Ool00`00FUH00004FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP80009JEP8000Aoo`<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH300000eYF001JEP03FUH01@00FUIJEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00005FUH005YFFUH0000]
Ool002eoo`04001JEUYF0003FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030002FUH30006Ool20002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
1eYF0P000eYF00<005YFFUH00UYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001oogoo02]oo`00;Goo00@005YFFUH0
00=JEP8000Eooa`0009JEP03001JEUYF008000Eoo`800005FUH005YFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJ
EP000UYF00<007ooOol02Woo2@0015YF00<005YFFUH01EYF00<005YF00000UYF00@005YFFUIJEPD0
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@00003FUH005YF00EJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEP00
008000Ioo`<002aoo`00;Goo00<005YFFUH00`001goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00@005YFFUIJEPT000=JEP03001JEUYF00=JEPL000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEUYF001JEP00FUH00`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH015YF10002Woo0P00;7oo000^Ool01000FUH000001Woo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP020004FUH40005FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP04000>Ool2000/Ool002ioo`80009JEP80009oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00@005YFFUIJEP@00003FUH005YF00MJ
EP<0009JEPL0015oo`03001JEP0002aoo`00;Woo0P000UYF00@005YF000000IJEP03001JEUYF00EJ
EP03001JEUYF009JEPl000EJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000IJEP03001JEUYF00=JEP03001JEP0000h001Moo`800003FUH007oo02]oo`00;Woo00@0
05YFFUIJEP<000MJEP03001JEUYF009JEPP000]oo`P0009JEPH000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEPD000AJEP03001JEUYF00=JEP04001JEUYF000SOol01@00FUH0
05YF0000;7oo000^Ool01`00FUIJEUYF001JEP0000IJEPT000Uoo`L000IJEP03001JEP0000<000AJ
EPP000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0009JEPH000AJEP04001JEUYF000ROol01000FUIJEUYF
0P00;7oo000^Ool01000FUIJEP000eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEPT000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<00003FUH00000009JEP04001JEUYFFUH90003FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200001EYF00000000FUH01`0000EJEP00FUIJEP00021oo`8000AJEP03001oogoo02]oo`00
;Woo00<005YF000015YF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP8000Moo`80009JEP03001oogoo01Yoo`@00003FUH005YF00=JEP03001oogoo
02]oo`00;Woo0`0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YF00000P001Woo00<005YF000067oo10001EYF00D005YFFUIJEP00
02ioo`00;goo0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP02FUH30002Ool4000DOol40002FUH00`00FUIJEP04FUH01000FUH00000
;goo000^Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<00003FUH0000000aoo`L000IJ
EP03001JEUYF00AJEP80035oo`00;Woo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000Eoo`04001JEUYF0003FUHN0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00<Woo000^Ool0
1000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000Moo`03001JEP0000@001=JEP03001JEUYF00QJEPd000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Aoo`00;Woo0P0017oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002Goo0P0065YF
00<005YFFUH02EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>7oo000^Ool20007Ool50004FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04000:Ool200000eYF
0000000GFUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000kOol002ioo`<000]oo`T0009JEPD0009JEPL000eoo`04001JEUYFFUH4000EFUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000050004FUH00`00FUIJEP02
FUH00`00FUH00003FUH60002FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000oOol002io
o`800003FUH007oo019oo`T0019oo`8000AJEP80009oo`H000mJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEPH000=JEP03001JEP0000=JEP03001JEUYF00=JEP<0
0003FUH005YF010004Ioo`00;Woo0P000UYF0P004goo1@0047oo100000=JEP00FUH00eYF00<007oo
Ool01goo1`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomo
o`1BOol002moo`05001JEUYF001JEP03000AOol3000>Ool30005FUH01@00FUIJEUYF00004Goo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2001COol002moo`04001J
EUYF0004FUH3000KOol400000eYF001JEP05FUH01000FUH0000067oo20001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF00<00003FUH007oo059oo`00<7oo00@005YFFUH000AJEP03001JEP0000<0011oo`L0
00EJEP03001JEUYF00AJEP80029oo`d000IJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH50006FUH00`00FUIJEP03FUH30003Ool2001COol0035oo`<000AJEP03001JEUYF00=JEQ0000AJ
EP03001JEUYF00IJEP03001JEUYF009JEP8002eoo`03001JEUYF01l0009JEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo00=oo`8005=oo`00<goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00;goo00D005YFFUH007oo008000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0005Ool00`00FUH0001COol003Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@0039oo`03001JEP0000Aoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool00`00FUH0001COol003Qoo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003Moo`8000Moo`<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000Qoo`800003FUH007oo059oo`00>goo100000=JEP00
FUH01eYF00<005YFFUH00UYF1`00>goo0P002Woo100000=JEP00FUH01eYF0`000UYF2@0037oo0P00
00AJEP00FUH005=oo`00?goo3`00@Woo00@005YF000000aoo`l001=oo`8000AJEP03001oogoo059o
o`00T7oo00D005YFFUIJEP0001Aoo`D0019oo`800003FUH005YF00=JEP03001oogoo059oo`00T7oo
00@005YFFUIJEP<0019oo`D0011oo`8000=JEP03001JEUYF009JEP03001oogoo059oo`00T7oo00D0
05YFFUIJEP00009JEP80015oo`<000eoo`@000EJEP03001JEUYF008005Eoo`00TGoo00@005YFFUH0
00AJEPD001Qoo`@0009JEP03001JEUYF00AJEP<005Moo`00TWoo0`001EYF00@005YFFUIJEQP000IJ
EP03001JEUYF00=JEP8005Uoo`00U7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8005]oo`00UGoo0P000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005eoo`00Ugoo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00Ggoo002IOol5
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04001ROol009ioo`T000AJEP03001J
EUYF009JEPL006Ioo`00Ygoo2@00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59976 .75658 m .59678 .70354 L .56562 .7023 L p .707 .577 .707 r
F P
0 g
s
.59678 .70354 m .59976 .75658 L .63155 .75389 L p .707 .577 .707 r
F P
0 g
s
.63155 .75389 m .62856 .70085 L .59678 .70354 L p .707 .577 .707 r
F P
0 g
s
.62856 .70085 m .63155 .75389 L .66085 .74753 L p .707 .577 .707 r
F P
0 g
s
.66085 .74753 m .65786 .69449 L .62856 .70085 L p .707 .577 .707 r
F P
0 g
s
.56861 .75534 m .56562 .7023 L .53815 .69725 L p .707 .577 .707 r
F P
0 g
s
.56562 .7023 m .56861 .75534 L .59976 .75658 L p .707 .577 .707 r
F P
0 g
s
.65786 .69449 m .66085 .74753 L .6848 .73812 L p .707 .577 .707 r
F P
0 g
s
.6848 .73812 m .68181 .68509 L .65786 .69449 L p .707 .577 .707 r
F P
0 g
s
.54113 .75029 m .53815 .69725 L .51704 .68888 L p .707 .577 .707 r
F P
0 g
s
.53815 .69725 m .54113 .75029 L .56861 .75534 L p .707 .577 .707 r
F P
0 g
s
.6038 .81747 m .60052 .7836 L .5694 .78278 L p .707 .577 .707 r
F P
0 g
s
.60052 .7836 m .6038 .81747 L .63549 .81357 L p .707 .577 .707 r
F P
0 g
s
.63549 .81357 m .63221 .77971 L .60052 .7836 L p .707 .577 .707 r
F P
0 g
s
.68181 .68509 m .6848 .73812 L .70105 .72659 L p .707 .577 .707 r
F P
0 g
s
.70105 .72659 m .69806 .67356 L .68181 .68509 L p .707 .577 .707 r
F P
0 g
s
.63221 .77971 m .63549 .81357 L .66465 .80534 L p .707 .577 .707 r
F P
0 g
s
.66465 .80534 m .66137 .77148 L .63221 .77971 L p .707 .577 .707 r
F P
0 g
s
.57268 .81664 m .5694 .78278 L .54189 .77731 L p .707 .577 .707 r
F P
0 g
s
.5694 .78278 m .57268 .81664 L .6038 .81747 L p .707 .577 .707 r
F P
0 g
s
.66137 .77148 m .66465 .80534 L .68842 .79358 L p .707 .577 .707 r
F P
0 g
s
.68842 .79358 m .68514 .75972 L .66137 .77148 L p .707 .577 .707 r
F P
0 g
s
.52003 .74192 m .51704 .68888 L .50436 .67802 L p .707 .577 .707 r
F P
0 g
s
.51704 .68888 m .52003 .74192 L .54113 .75029 L p .707 .577 .707 r
F P
0 g
s
.54517 .81117 m .54189 .77731 L .52069 .76774 L p .707 .577 .707 r
F P
0 g
s
.54189 .77731 m .54517 .81117 L .57268 .81664 L p .707 .577 .707 r
F P
0 g
s
.69806 .67356 m .70105 .72659 L .70802 .71406 L p .707 .577 .707 r
F P
0 g
s
.70802 .71406 m .70503 .66103 L .69806 .67356 L p .707 .577 .707 r
F P
0 g
s
.6067 .85025 m .60501 .83338 L .57389 .83258 L p .707 .577 .707 r
F P
0 g
s
.60501 .83338 m .6067 .85025 L .63838 .84628 L p .707 .577 .707 r
F P
0 g
s
.63838 .84628 m .63669 .8294 L .60501 .83338 L p .707 .577 .707 r
F P
0 g
s
.63669 .8294 m .63838 .84628 L .66752 .83792 L p .707 .577 .707 r
F P
0 g
s
.66752 .83792 m .66584 .82105 L .63669 .8294 L p .707 .577 .707 r
F P
0 g
s
.68514 .75972 m .68842 .79358 L .70448 .77943 L p .707 .577 .707 r
F P
0 g
s
.70448 .77943 m .7012 .74557 L .68514 .75972 L p .707 .577 .707 r
F P
0 g
s
.57558 .84945 m .57389 .83258 L .54638 .82708 L p .707 .577 .707 r
F P
0 g
s
.57389 .83258 m .57558 .84945 L .6067 .85025 L p .707 .577 .707 r
F P
0 g
s
.50436 .67802 m .50735 .73105 L .52003 .74192 L p .707 .577 .707 r
F P
0 g
s
.66584 .82105 m .66752 .83792 L .69128 .826 L p .707 .577 .707 r
F P
0 g
s
.69128 .826 m .68959 .80913 L .66584 .82105 L p .707 .577 .707 r
F P
0 g
s
.50735 .73105 m .50436 .67802 L .50136 .66572 L p .707 .577 .707 r
F P
0 g
s
.52069 .76774 m .52397 .8016 L .54517 .81117 L p .707 .577 .707 r
F P
0 g
s
.54638 .82708 m .54807 .84396 L .57558 .84945 L p .707 .577 .707 r
F P
0 g
s
.52397 .8016 m .52069 .76774 L .50787 .75501 L p .707 .577 .707 r
F P
0 g
s
.54807 .84396 m .54638 .82708 L .52517 .81743 L p .707 .577 .707 r
F P
0 g
s
.7012 .74557 m .70448 .77943 L .71125 .76429 L p .707 .577 .707 r
F P
0 g
s
.71125 .76429 m .70796 .73043 L .7012 .74557 L p .707 .577 .707 r
F P
0 g
s
.70503 .66103 m .70802 .71406 L .70502 .70177 L p .707 .577 .707 r
F P
0 g
s
.70502 .70177 m .70203 .64873 L .70503 .66103 L p .707 .577 .707 r
F P
0 g
s
.68959 .80913 m .69128 .826 L .70732 .81168 L p .707 .577 .707 r
F P
0 g
s
.70732 .81168 m .70563 .7948 L .68959 .80913 L p .707 .577 .707 r
F P
0 g
s
.52517 .81743 m .52686 .83431 L .54807 .84396 L p .707 .577 .707 r
F P
0 g
s
.50787 .75501 m .51116 .78887 L .52397 .8016 L p .707 .577 .707 r
F P
0 g
s
.50136 .66572 m .50435 .71876 L .50735 .73105 L p .707 .577 .707 r
F P
0 g
s
.50435 .71876 m .50136 .66572 L .50833 .65319 L p .707 .577 .707 r
F P
0 g
s
.52686 .83431 m .52517 .81743 L .51234 .80457 L p .707 .577 .707 r
F P
0 g
s
.51116 .78887 m .50787 .75501 L .50469 .74035 L p .707 .577 .707 r
F P
0 g
s
.70563 .7948 m .70732 .81168 L .71407 .79636 L p .707 .577 .707 r
F P
0 g
s
.71407 .79636 m .71238 .77949 L .70563 .7948 L p .707 .577 .707 r
F P
0 g
s
.51234 .80457 m .51403 .82145 L .52686 .83431 L p .707 .577 .707 r
F P
0 g
s
.70796 .73043 m .71125 .76429 L .70807 .74964 L p .707 .577 .707 r
F P
0 g
s
.70807 .74964 m .70479 .71577 L .70796 .73043 L p .707 .577 .707 r
F P
0 g
s
.70203 .64873 m .70502 .70177 L .69235 .6909 L p .707 .577 .707 r
F P
0 g
s
.69235 .6909 m .68936 .63787 L .70203 .64873 L p .707 .577 .707 r
F P
0 g
s
.50469 .74035 m .50798 .77421 L .51116 .78887 L p .707 .577 .707 r
F P
0 g
s
.50833 .65319 m .51132 .70623 L .50435 .71876 L p .707 .577 .707 r
F P
0 g
s
.51403 .82145 m .51234 .80457 L .50915 .78976 L p .707 .577 .707 r
F P
0 g
s
.51132 .70623 m .50833 .65319 L .52459 .64166 L p .707 .577 .707 r
F P
0 g
s
.50798 .77421 m .50469 .74035 L .51146 .72521 L p .707 .577 .707 r
F P
0 g
s
.25676 .71976 m .25377 .66673 L .22261 .66549 L p .707 .577 .707 r
F P
0 g
s
.25377 .66673 m .25676 .71976 L .28854 .71707 L p .707 .577 .707 r
F P
0 g
s
.28854 .71707 m .28555 .66404 L .25377 .66673 L p .707 .577 .707 r
F P
0 g
s
.28555 .66404 m .28854 .71707 L .31784 .71071 L p .707 .577 .707 r
F P
0 g
s
.31784 .71071 m .31485 .65768 L .28555 .66404 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.50915 .78976 m .51083 .80663 L .51403 .82145 L p .707 .577 .707 r
F P
0 g
s
.71238 .77949 m .71407 .79636 L .71087 .78155 L p .707 .577 .707 r
F P
0 g
s
.71087 .78155 m .70919 .76467 L .71238 .77949 L p .707 .577 .707 r
F P
0 g
s
.2256 .71852 m .22261 .66549 L .19514 .66044 L p .707 .577 .707 r
F P
0 g
s
.22261 .66549 m .2256 .71852 L .25676 .71976 L p .707 .577 .707 r
F P
0 g
s
.70479 .71577 m .70807 .74964 L .69525 .7369 L p .707 .577 .707 r
F P
0 g
s
.69525 .7369 m .69197 .70304 L .70479 .71577 L p .707 .577 .707 r
F P
0 g
s
.68936 .63787 m .69235 .6909 L .67124 .68253 L p .707 .577 .707 r
F P
0 g
s
.67124 .68253 m .66825 .6295 L .68936 .63787 L p .707 .577 .707 r
F P
0 g
s
.31485 .65768 m .31784 .71071 L .34179 .70131 L p .707 .577 .707 r
F P
0 g
s
.34179 .70131 m .3388 .64827 L .31485 .65768 L p .707 .577 .707 r
F P
0 g
s
.51146 .72521 m .51475 .75907 L .50798 .77421 L p .707 .577 .707 r
F P
0 g
s
.52459 .64166 m .52757 .6947 L .51132 .70623 L p .707 .577 .707 r
F P
0 g
s
.19812 .71347 m .19514 .66044 L .17403 .65207 L p .707 .577 .707 r
F P
0 g
s
.19514 .66044 m .19812 .71347 L .2256 .71852 L p .707 .577 .707 r
F P
0 g
s
.52757 .6947 m .52459 .64166 L .54854 .63226 L p .707 .577 .707 r
F P
0 g
s
.51083 .80663 m .50915 .78976 L .5159 .77444 L p .707 .577 .707 r
F P
0 g
s
.51475 .75907 m .51146 .72521 L .52752 .71106 L p .707 .577 .707 r
F P
0 g
s
.26079 .78065 m .25751 .74679 L .22639 .74596 L p .707 .577 .707 r
F P
0 g
s
.25751 .74679 m .26079 .78065 L .29249 .77676 L p .707 .577 .707 r
F P
0 g
s
.29249 .77676 m .2892 .7429 L .25751 .74679 L p .707 .577 .707 r
F P
0 g
s
.3388 .64827 m .34179 .70131 L .35804 .68978 L p .707 .577 .707 r
F P
0 g
s
.35804 .68978 m .35506 .63674 L .3388 .64827 L p .707 .577 .707 r
F P
0 g
s
.66825 .6295 m .67124 .68253 L .64376 .67748 L p .707 .577 .707 r
F P
0 g
s
.64376 .67748 m .64077 .62445 L .66825 .6295 L p .707 .577 .707 r
F P
0 g
s
.5159 .77444 m .51759 .79131 L .51083 .80663 L p .707 .577 .707 r
F P
0 g
s
.2892 .7429 m .29249 .77676 L .32164 .76853 L p .707 .577 .707 r
F P
0 g
s
.32164 .76853 m .31836 .73467 L .2892 .7429 L p .707 .577 .707 r
F P
0 g
s
.70919 .76467 m .71087 .78155 L .69804 .76868 L p .707 .577 .707 r
F P
0 g
s
.69804 .76868 m .69636 .75181 L .70919 .76467 L p .707 .577 .707 r
F P
0 g
s
.69197 .70304 m .69525 .7369 L .67405 .72733 L p .707 .577 .707 r
F P
0 g
s
.67405 .72733 m .67077 .69347 L .69197 .70304 L p .707 .577 .707 r
F P
0 g
s
.22967 .77982 m .22639 .74596 L .19888 .7405 L p .707 .577 .707 r
F P
0 g
s
.22639 .74596 m .22967 .77982 L .26079 .78065 L p .707 .577 .707 r
F P
0 g
s
.55152 .68529 m .54854 .63226 L .57784 .6259 L p .707 .577 .707 r
F P
0 g
s
.54854 .63226 m .55152 .68529 L .52757 .6947 L p .707 .577 .707 r
F P
0 g
s
.31836 .73467 m .32164 .76853 L .34541 .75676 L p .707 .577 .707 r
F P
0 g
s
.34541 .75676 m .34213 .7229 L .31836 .73467 L p .707 .577 .707 r
F P
0 g
s
.52752 .71106 m .5308 .74493 L .51475 .75907 L p .707 .577 .707 r
F P
0 g
s
.17702 .7051 m .17403 .65207 L .16135 .6412 L p .707 .577 .707 r
F P
0 g
s
.17403 .65207 m .17702 .7051 L .19812 .71347 L p .707 .577 .707 r
F P
0 g
s
.64077 .62445 m .64376 .67748 L .61261 .67624 L p .707 .577 .707 r
F P
0 g
s
.61261 .67624 m .60962 .62321 L .64077 .62445 L p .707 .577 .707 r
F P
0 g
s
.5308 .74493 m .52752 .71106 L .55129 .6993 L p .707 .577 .707 r
F P
0 g
s
.51759 .79131 m .5159 .77444 L .53194 .76012 L p .707 .577 .707 r
F P
0 g
s
.58082 .67893 m .57784 .6259 L .60962 .62321 L p .707 .577 .707 r
F P
0 g
s
.57784 .6259 m .58082 .67893 L .55152 .68529 L p .707 .577 .707 r
F P
0 g
s
.20216 .77436 m .19888 .7405 L .17768 .73093 L p .707 .577 .707 r
F P
0 g
s
.19888 .7405 m .20216 .77436 L .22967 .77982 L p .707 .577 .707 r
F P
0 g
s
.60962 .62321 m .61261 .67624 L .58082 .67893 L p .707 .577 .707 r
F P
0 g
s
.67077 .69347 m .67405 .72733 L .64654 .72186 L p .707 .577 .707 r
F P
0 g
s
.64654 .72186 m .64326 .688 L .67077 .69347 L p .707 .577 .707 r
F P
0 g
s
.35506 .63674 m .35804 .68978 L .36501 .67725 L p .707 .577 .707 r
F P
0 g
s
.36501 .67725 m .36202 .62421 L .35506 .63674 L p .707 .577 .707 r
F P
0 g
s
.26369 .81344 m .262 .79656 L .23088 .79576 L p .707 .577 .707 r
F P
0 g
s
.262 .79656 m .26369 .81344 L .29537 .80946 L p .707 .577 .707 r
F P
0 g
s
.29537 .80946 m .29368 .79259 L .262 .79656 L p .707 .577 .707 r
F P
0 g
s
.29368 .79259 m .29537 .80946 L .32452 .80111 L p .707 .577 .707 r
F P
0 g
s
.32452 .80111 m .32283 .78423 L .29368 .79259 L p .707 .577 .707 r
F P
0 g
s
.69636 .75181 m .69804 .76868 L .67684 .75903 L p .707 .577 .707 r
F P
0 g
s
.67684 .75903 m .67515 .74216 L .69636 .75181 L p .707 .577 .707 r
F P
0 g
s
.53194 .76012 m .53362 .77699 L .51759 .79131 L p .707 .577 .707 r
F P
0 g
s
.34213 .7229 m .34541 .75676 L .36147 .74262 L p .707 .577 .707 r
F P
0 g
s
.36147 .74262 m .35819 .70876 L .34213 .7229 L p .707 .577 .707 r
F P
0 g
s
.23257 .81264 m .23088 .79576 L .20337 .79027 L p .707 .577 .707 r
F P
0 g
s
.23088 .79576 m .23257 .81264 L .26369 .81344 L p .707 .577 .707 r
F P
0 g
s
.16135 .6412 m .16434 .69424 L .17702 .7051 L p .707 .577 .707 r
F P
0 g
s
.55457 .73316 m .55129 .6993 L .58045 .69107 L p .707 .577 .707 r
F P
0 g
s
.55129 .6993 m .55457 .73316 L .5308 .74493 L p .707 .577 .707 r
F P
0 g
s
.32283 .78423 m .32452 .80111 L .34827 .78918 L p .707 .577 .707 r
F P
0 g
s
.34827 .78918 m .34658 .77231 L .32283 .78423 L p .707 .577 .707 r
F P
0 g
s
.16434 .69424 m .16135 .6412 L .15836 .62891 L p .707 .577 .707 r
F P
0 g
s
.64326 .688 m .64654 .72186 L .61542 .72104 L p .707 .577 .707 r
F P
0 g
s
.61542 .72104 m .61214 .68718 L .64326 .688 L p .707 .577 .707 r
F P
0 g
s
.17768 .73093 m .18096 .76479 L .20216 .77436 L p .707 .577 .707 r
F P
0 g
s
.20337 .79027 m .20506 .80714 L .23257 .81264 L p .707 .577 .707 r
F P
0 g
s
.53362 .77699 m .53194 .76012 L .55569 .7482 L p .707 .577 .707 r
F P
0 g
s
.18096 .76479 m .17768 .73093 L .16486 .71819 L p .707 .577 .707 r
F P
0 g
s
.58373 .72493 m .58045 .69107 L .61214 .68718 L p .707 .577 .707 r
F P
0 g
s
.58045 .69107 m .58373 .72493 L .55457 .73316 L p .707 .577 .707 r
F P
0 g
s
.61214 .68718 m .61542 .72104 L .58373 .72493 L p .707 .577 .707 r
F P
0 g
s
.20506 .80714 m .20337 .79027 L .18216 .78062 L p .707 .577 .707 r
F P
0 g
s
.67515 .74216 m .67684 .75903 L .64933 .75354 L p .707 .577 .707 r
F P
0 g
s
.64933 .75354 m .64764 .73667 L .67515 .74216 L p .707 .577 .707 r
F P
0 g
s
.55569 .7482 m .55738 .76507 L .53362 .77699 L p .707 .577 .707 r
F P
0 g
s
.35819 .70876 m .36147 .74262 L .36824 .72748 L p .707 .577 .707 r
F P
0 g
s
.36824 .72748 m .36496 .69362 L .35819 .70876 L p .707 .577 .707 r
F P
0 g
s
.36202 .62421 m .36501 .67725 L .36201 .66495 L p .707 .577 .707 r
F P
0 g
s
.36201 .66495 m .35902 .61192 L .36202 .62421 L p .707 .577 .707 r
F P
0 g
s
.34658 .77231 m .34827 .78918 L .36431 .77486 L p .707 .577 .707 r
F P
0 g
s
.36431 .77486 m .36262 .75799 L .34658 .77231 L p .707 .577 .707 r
F P
0 g
s
.18216 .78062 m .18385 .79749 L .20506 .80714 L p .707 .577 .707 r
F P
0 g
s
.55738 .76507 m .55569 .7482 L .58484 .73984 L p .707 .577 .707 r
F P
0 g
s
.16486 .71819 m .16815 .75205 L .18096 .76479 L p .707 .577 .707 r
F P
0 g
s
.15836 .62891 m .16134 .68194 L .16434 .69424 L p .707 .577 .707 r
F P
0 g
s
.64764 .73667 m .64933 .75354 L .61821 .75274 L p .707 .577 .707 r
F P
0 g
s
.61821 .75274 m .61652 .73587 L .64764 .73667 L p .707 .577 .707 r
F P
0 g
s
.5072 .24653 m .44966 .76431 L .49355 .7691 L p .707 .577 .707 r
F P
0 g
s
.49355 .7691 m .55109 .25131 L .5072 .24653 L p .707 .577 .707 r
F P
0 g
s
.55109 .25131 m .49355 .7691 L .53815 .7741 L p .707 .577 .707 r
F P
0 g
s
.16134 .68194 m .15836 .62891 L .16532 .61638 L p .707 .577 .707 r
F P
0 g
s
.18385 .79749 m .18216 .78062 L .16933 .76776 L p .707 .577 .707 r
F P
0 g
s
.58484 .73984 m .58652 .75671 L .55738 .76507 L p .707 .577 .707 r
F P
0 g
s
.53815 .7741 m .59569 .25632 L .55109 .25131 L p .707 .577 .707 r
F P
0 g
s
.59569 .25632 m .53815 .7741 L .5791 .77883 L p .707 .577 .707 r
F P
0 g
s
.16815 .75205 m .16486 .71819 L .16169 .70353 L p .707 .577 .707 r
F P
0 g
s
.58652 .75671 m .58484 .73984 L .61652 .73587 L p .707 .577 .707 r
F P
0 g
s
.61652 .73587 m .61821 .75274 L .58652 .75671 L p .707 .577 .707 r
F P
0 g
s
.46832 .24243 m .41078 .76021 L .44966 .76431 L p .707 .577 .707 r
F P
0 g
s
.44966 .76431 m .5072 .24653 L .46832 .24243 L p .707 .577 .707 r
F P
0 g
s
.5791 .77883 m .63664 .26105 L .59569 .25632 L p .707 .577 .707 r
F P
0 g
s
.36262 .75799 m .36431 .77486 L .37106 .75955 L p .707 .577 .707 r
F P
0 g
s
.37106 .75955 m .36937 .74267 L .36262 .75799 L p .707 .577 .707 r
F P
0 g
s
.16933 .76776 m .17102 .78463 L .18385 .79749 L p .707 .577 .707 r
F P
0 g
s
.36496 .69362 m .36824 .72748 L .36506 .71282 L p .707 .577 .707 r
F P
0 g
s
.36506 .71282 m .36178 .67896 L .36496 .69362 L p .707 .577 .707 r
F P
0 g
s
.35902 .61192 m .36201 .66495 L .34934 .65409 L p .707 .577 .707 r
F P
0 g
s
.34934 .65409 m .34635 .60105 L .35902 .61192 L p .707 .577 .707 r
F P
0 g
s
.16169 .70353 m .16497 .7374 L .16815 .75205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63664 .26105 m .5791 .77883 L .61238 .78283 L p .707 .577 .707 r
F P
0 g
s
.16532 .61638 m .16831 .66941 L .16134 .68194 L p .707 .577 .707 r
F P
0 g
s
.61238 .78283 m .66992 .26504 L .63664 .26105 L p .707 .577 .707 r
F P
0 g
s
.17102 .78463 m .16933 .76776 L .16614 .75294 L p .707 .577 .707 r
F P
0 g
s
.43825 .23942 m .38071 .7572 L .41078 .76021 L p .707 .577 .707 r
F P
0 g
s
.41078 .76021 m .46832 .24243 L .43825 .23942 L p .707 .577 .707 r
F P
0 g
s
.16831 .66941 m .16532 .61638 L .18158 .60485 L p .707 .577 .707 r
F P
0 g
s
.16497 .7374 m .16169 .70353 L .16845 .68839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16614 .75294 m .16782 .76982 L .17102 .78463 L p .707 .577 .707 r
F P
0 g
s
.36937 .74267 m .37106 .75955 L .36786 .74473 L p .707 .577 .707 r
F P
0 g
s
.36786 .74473 m .36618 .72786 L .36937 .74267 L p .707 .577 .707 r
F P
0 g
s
.36178 .67896 m .36506 .71282 L .35224 .70008 L p .707 .577 .707 r
F P
0 g
s
.35224 .70008 m .34896 .66622 L .36178 .67896 L p .707 .577 .707 r
F P
0 g
s
.34635 .60105 m .34934 .65409 L .32823 .64572 L p .707 .577 .707 r
F P
0 g
s
.32823 .64572 m .32524 .59268 L .34635 .60105 L p .707 .577 .707 r
F P
0 g
s
.16845 .68839 m .17174 .72225 L .16497 .7374 L p .707 .577 .707 r
F P
0 g
s
.66992 .26504 m .61238 .78283 L .63474 .7857 L p .707 .577 .707 r
F P
0 g
s
.18158 .60485 m .18457 .65788 L .16831 .66941 L p .707 .577 .707 r
F P
0 g
s
.18457 .65788 m .18158 .60485 L .20553 .59544 L p .707 .577 .707 r
F P
0 g
s
.16782 .76982 m .16614 .75294 L .17289 .73763 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .69228 .26791 L .66992 .26504 L p .707 .577 .707 r
F P
0 g
s
.17174 .72225 m .16845 .68839 L .18451 .67425 L p .707 .577 .707 r
F P
0 g
s
.36618 .72786 m .36786 .74473 L .35504 .73187 L p .707 .577 .707 r
F P
0 g
s
.35504 .73187 m .35335 .71499 L .36618 .72786 L p .707 .577 .707 r
F P
0 g
s
.41993 .23779 m .3624 .75557 L .38071 .7572 L p .707 .577 .707 r
F P
0 g
s
.38071 .7572 m .43825 .23942 L .41993 .23779 L p .707 .577 .707 r
F P
0 g
s
.32524 .59268 m .32823 .64572 L .30075 .64067 L p .707 .577 .707 r
F P
0 g
s
.30075 .64067 m .29777 .58763 L .32524 .59268 L p .707 .577 .707 r
F P
0 g
s
.17289 .73763 m .17458 .7545 L .16782 .76982 L p .707 .577 .707 r
F P
0 g
s
.34896 .66622 m .35224 .70008 L .33104 .69052 L p .707 .577 .707 r
F P
0 g
s
.33104 .69052 m .32776 .65665 L .34896 .66622 L p .707 .577 .707 r
F P
0 g
s
.20851 .64848 m .20553 .59544 L .23483 .58908 L p .707 .577 .707 r
F P
0 g
s
.20553 .59544 m .20851 .64848 L .18457 .65788 L p .707 .577 .707 r
F P
0 g
s
.18451 .67425 m .18779 .70811 L .17174 .72225 L p .707 .577 .707 r
F P
0 g
s
.29777 .58763 m .30075 .64067 L .2696 .63943 L p .707 .577 .707 r
F P
0 g
s
.2696 .63943 m .26661 .58639 L .29777 .58763 L p .707 .577 .707 r
F P
0 g
s
.18779 .70811 m .18451 .67425 L .20828 .66248 L p .707 .577 .707 r
F P
0 g
s
.17458 .7545 m .17289 .73763 L .18893 .7233 L p .707 .577 .707 r
F P
0 g
s
.23782 .64212 m .23483 .58908 L .26661 .58639 L p .707 .577 .707 r
F P
0 g
s
.23483 .58908 m .23782 .64212 L .20851 .64848 L p .707 .577 .707 r
F P
0 g
s
.26661 .58639 m .2696 .63943 L .23782 .64212 L p .707 .577 .707 r
F P
0 g
s
.32776 .65665 m .33104 .69052 L .30353 .68505 L p .707 .577 .707 r
F P
0 g
s
.30353 .68505 m .30025 .65119 L .32776 .65665 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .64399 .78716 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.64399 .78716 m .63923 .78707 L p .65376 .66634 L .707 .577 .707 r
F P
0 g
s
.65376 .66634 m .65435 .66424 L .64399 .78716 L .707 .577 .707 r
F
.66419 .6073 m .66369 .6071 L p .664 .60829 L F P
0 g
s
.67834 .66476 m .66369 .6071 L .66364 .62731 L .707 .577 .707 r
F
.64399 .78716 m .70153 .26937 L .69228 .26791 L p F P
0 g
s
.65516 .65467 m .65668 .64668 L .64399 .78716 L .707 .577 .707 r
F
.66369 .60991 m .6621 .62419 L p .65668 .64668 L F P
0 g
s
.6621 .62419 m .64399 .78716 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.66392 .52315 m .63474 .7857 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.65424 .60336 m .64157 .59249 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.65668 .64668 m .65424 .60336 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.66369 .6071 m .65424 .60336 L p .66144 .6217 L .707 .577 .707 r
F P
0 g
s
.66364 .62731 m .66369 .60991 L .66144 .6217 L .707 .577 .707 r
F
.66369 .60991 m .66369 .6071 L .66144 .6217 L F
.65424 .60336 m .65723 .65639 L .67834 .66476 L p F P
0 g
s
.64157 .59249 m .64456 .64553 L .65484 .65434 L p .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65549 .65164 L .65556 .65133 L .707 .577 .707 r
F
.65577 .65045 m .64157 .59249 L .65484 .65434 L F
.69228 .26791 m .66392 .52315 L p .66378 .57436 L F P
0 g
s
.65223 .67006 m .69676 .26929 L p .65516 .65467 L .707 .577 .707 r
F P
0 g
s
.70153 .26937 m .66369 .60991 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65556 .65133 L .65668 .64668 L .707 .577 .707 r
F
.65556 .65133 m .70153 .26937 L .65668 .64668 L F
.65484 .65434 m .65723 .65639 L p .65577 .65045 L F P
0 g
s
.69676 .26929 m .70153 .26937 L p .65556 .65133 L .707 .577 .707 r
F P
0 g
s
.65549 .65164 m .69676 .26929 L .65556 .65133 L .707 .577 .707 r
F
.63923 .78707 m .65223 .67006 L p .65516 .65467 L F P
0 g
s
.65723 .65639 m .65668 .64668 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.64456 .64553 m .64157 .59249 L .63857 .58019 L p .707 .577 .707 r
F P
0 g
s
.63923 .78707 m .62091 .78544 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.63857 .58019 m .64084 .62051 L p .64456 .64553 L .707 .577 .707 r
F P
0 g
s
.64314 .6397 m .64456 .64553 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.69676 .26929 m .6496 .69374 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.6496 .69374 m .63923 .78707 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .69676 .26929 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .63857 .58019 L .64396 .5705 L p .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .64311 .58569 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.64396 .5705 m .64412 .57021 L p .64311 .58569 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64396 .5705 L .64311 .58569 L .707 .577 .707 r
F
.62091 .78544 m .59084 .78243 L p .65229 .4214 L F P
0 g
s
.64311 .58569 m .62091 .78544 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.62091 .78544 m .64311 .58569 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64311 .58569 m .67845 .26766 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64156 .63323 L .64314 .6397 L p .707 .577 .707 r
F P
0 g
s
.64156 .63323 m .64084 .62051 L p .64554 .56766 L .707 .577 .707 r
F P
0 g
s
.64412 .57021 m .64554 .56766 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .6579 .69221 L .64893 .6833 L p .707 .577 .707 r
F P
0 g
s
.64893 .6833 m .64508 .67947 L p .64779 .68731 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .64893 .6833 L .64779 .68731 L .707 .577 .707 r
F
.65376 .66634 m .65516 .65467 L .65435 .66424 L F
.67834 .66476 m .67535 .61172 L .66419 .6073 L p F P
0 g
s
.67834 .66476 m .66419 .6073 L .664 .60829 L .707 .577 .707 r
F
.35335 .71499 m .35504 .73187 L .33383 .72222 L p F P
0 g
s
.33383 .72222 m .33214 .70534 L .35335 .71499 L p .707 .577 .707 r
F P
0 g
s
.18893 .7233 m .19061 .74018 L .17458 .7545 L p .707 .577 .707 r
F P
0 g
s
.21156 .69635 m .20828 .66248 L .23744 .65425 L p .707 .577 .707 r
F P
0 g
s
.20828 .66248 m .21156 .69635 L .18779 .70811 L p .707 .577 .707 r
F P
0 g
s
.73697 .67105 m .73398 .61802 L .70283 .61677 L p .707 .577 .707 r
F P
0 g
s
.73398 .61802 m .73697 .67105 L .76875 .66836 L p .707 .577 .707 r
F P
0 g
s
.76875 .66836 m .76576 .61532 L .73398 .61802 L p .707 .577 .707 r
F P
0 g
s
.76576 .61532 m .76875 .66836 L .79805 .662 L p .707 .577 .707 r
F P
0 g
s
.79805 .662 m .79506 .60897 L .76576 .61532 L p .707 .577 .707 r
F P
0 g
s
.30025 .65119 m .30353 .68505 L .27241 .68422 L p .707 .577 .707 r
F P
0 g
s
.27241 .68422 m .26913 .65036 L .30025 .65119 L p .707 .577 .707 r
F P
0 g
s
.41517 .2377 m .35763 .75548 L .3624 .75557 L p .707 .577 .707 r
F P
0 g
s
.3624 .75557 m .41993 .23779 L .41517 .2377 L p .707 .577 .707 r
F P
0 g
s
.70581 .66981 m .70283 .61677 L .67535 .61172 L p .707 .577 .707 r
F P
0 g
s
.70283 .61677 m .70581 .66981 L .73697 .67105 L p .707 .577 .707 r
F P
0 g
s
.19061 .74018 m .18893 .7233 L .21268 .71138 L p .707 .577 .707 r
F P
0 g
s
.24072 .68811 m .23744 .65425 L .26913 .65036 L p .707 .577 .707 r
F P
0 g
s
.23744 .65425 m .24072 .68811 L .21156 .69635 L p .707 .577 .707 r
F P
0 g
s
.26913 .65036 m .27241 .68422 L .24072 .68811 L p .707 .577 .707 r
F P
0 g
s
.79506 .60897 m .79805 .662 L .822 .6526 L p .707 .577 .707 r
F P
0 g
s
.822 .6526 m .81901 .59956 L .79506 .60897 L p .707 .577 .707 r
F P
0 g
s
.33214 .70534 m .33383 .72222 L .30632 .71672 L p .707 .577 .707 r
F P
0 g
s
.30632 .71672 m .30463 .69985 L .33214 .70534 L p .707 .577 .707 r
F P
0 g
s
.21268 .71138 m .21437 .72826 L .19061 .74018 L p .707 .577 .707 r
F P
0 g
s
.67535 .61172 m .67834 .66476 L .70581 .66981 L p .707 .577 .707 r
F P
0 g
s
.21437 .72826 m .21268 .71138 L .24183 .70302 L p .707 .577 .707 r
F P
0 g
s
.30463 .69985 m .30632 .71672 L .2752 .71593 L p .707 .577 .707 r
F P
0 g
s
.2752 .71593 m .27351 .69905 L .30463 .69985 L p .707 .577 .707 r
F P
0 g
s
.81901 .59956 m .822 .6526 L .83826 .64106 L p .707 .577 .707 r
F P
0 g
s
.83826 .64106 m .83527 .58803 L .81901 .59956 L p .707 .577 .707 r
F P
0 g
s
.24183 .70302 m .24351 .7199 L .21437 .72826 L p .707 .577 .707 r
F P
0 g
s
.74101 .74193 m .73773 .70807 L .7066 .70725 L p .707 .577 .707 r
F P
0 g
s
.73773 .70807 m .74101 .74193 L .7727 .73804 L p .707 .577 .707 r
F P
0 g
s
.7727 .73804 m .76942 .70418 L .73773 .70807 L p .707 .577 .707 r
F P
0 g
s
.24351 .7199 m .24183 .70302 L .27351 .69905 L p .707 .577 .707 r
F P
0 g
s
.76942 .70418 m .7727 .73804 L .80186 .72981 L p .707 .577 .707 r
F P
0 g
s
.80186 .72981 m .79857 .69595 L .76942 .70418 L p .707 .577 .707 r
F P
0 g
s
.27351 .69905 m .2752 .71593 L .24351 .7199 L p .707 .577 .707 r
F P
0 g
s
.70988 .74111 m .7066 .70725 L .6791 .70178 L p .707 .577 .707 r
F P
0 g
s
.7066 .70725 m .70988 .74111 L .74101 .74193 L p .707 .577 .707 r
F P
0 g
s
.79857 .69595 m .80186 .72981 L .82563 .71805 L p .707 .577 .707 r
F P
0 g
s
.82563 .71805 m .82234 .68419 L .79857 .69595 L p .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .36688 .75695 L .35763 .75548 L p .707 .577 .707 r
F P
0 g
s
.35763 .75548 m .41517 .2377 L .42442 .23916 L p .707 .577 .707 r
F P
0 g
s
.83527 .58803 m .83826 .64106 L .84522 .62854 L p .707 .577 .707 r
F P
0 g
s
.84522 .62854 m .84224 .5755 L .83527 .58803 L p .707 .577 .707 r
F P
0 g
s
.68238 .73564 m .6791 .70178 L .6579 .69221 L p .707 .577 .707 r
F P
0 g
s
.6791 .70178 m .68238 .73564 L .70988 .74111 L p .707 .577 .707 r
F P
0 g
s
.82234 .68419 m .82563 .71805 L .84168 .7039 L p .707 .577 .707 r
F P
0 g
s
.84168 .7039 m .8384 .67004 L .82234 .68419 L p .707 .577 .707 r
F P
0 g
s
.7439 .79056 m .74221 .77369 L .71109 .77289 L p .707 .577 .707 r
F P
0 g
s
.74221 .77369 m .7439 .79056 L .77558 .78659 L p .707 .577 .707 r
F P
0 g
s
.77558 .78659 m .7739 .76971 L .74221 .77369 L p .707 .577 .707 r
F P
0 g
s
.7739 .76971 m .77558 .78659 L .80473 .77823 L p .707 .577 .707 r
F P
0 g
s
.80473 .77823 m .80304 .76136 L .7739 .76971 L p .707 .577 .707 r
F P
0 g
s
.71278 .78976 m .71109 .77289 L .68358 .76739 L p .707 .577 .707 r
F P
0 g
s
.71109 .77289 m .71278 .78976 L .7439 .79056 L p .707 .577 .707 r
F P
0 g
s
.6579 .69221 m .66118 .72607 L .68238 .73564 L p .707 .577 .707 r
F P
0 g
s
.80304 .76136 m .80473 .77823 L .82848 .76631 L p .707 .577 .707 r
F P
0 g
s
.82848 .76631 m .8268 .74943 L .80304 .76136 L p .707 .577 .707 r
F P
0 g
s
.68358 .76739 m .68527 .78427 L .71278 .78976 L p .707 .577 .707 r
F P
0 g
s
.84224 .5755 m .84522 .62854 L .84223 .61624 L p .707 .577 .707 r
F P
0 g
s
.84223 .61624 m .83924 .5632 L .84224 .5755 L p .707 .577 .707 r
F P
0 g
s
.68527 .78427 m .68358 .76739 L .66238 .75774 L p .707 .577 .707 r
F P
0 g
s
.8384 .67004 m .84168 .7039 L .84845 .68876 L p .707 .577 .707 r
F P
0 g
s
.84845 .68876 m .84517 .6549 L .8384 .67004 L p .707 .577 .707 r
F P
0 g
s
.38924 .75982 m .36688 .75695 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.40894 .58257 m .38924 .75982 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .44678 .24203 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.36688 .75695 m .39606 .4944 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.39606 .4944 m .42442 .23916 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .38924 .75982 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .40852 .57971 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42275 .57851 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .42519 .62184 L p .45504 .62519 L .707 .577 .707 r
F P
0 g
s
.43654 .63772 m .43553 .6468 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.43553 .6468 m .42253 .76381 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42574 .63155 L .43127 .63034 L p .707 .577 .707 r
F P
0 g
s
.43127 .63034 m .45504 .62519 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.45504 .62519 m .45205 .57215 L .42275 .57851 L p .707 .577 .707 r
F P
0 g
s
.48006 .24603 m .43654 .63772 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.41709 .60227 m .43654 .63772 L .42519 .62184 L .707 .577 .707 r
F
.44678 .24203 m .48006 .24603 L p .41709 .60227 L F P
0 g
s
.38924 .75982 m .40894 .58257 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .40852 .57971 L .41351 .61383 L .707 .577 .707 r
F
.40894 .58257 m .44678 .24203 L p .41709 .60227 L F P
0 g
s
.41351 .61383 m .40894 .58257 L .39097 .5812 L .707 .577 .707 r
F
.40852 .57971 m .40778 .57978 L p .40894 .58257 L F P
0 g
s
.40778 .57978 m .39097 .5812 L p .40894 .58257 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .42519 .62184 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.39097 .5812 m .39396 .63424 L .41621 .63235 L p .707 .577 .707 r
F P
0 g
s
.41621 .63235 m .42574 .63155 L p .41351 .61383 L .707 .577 .707 r
F P
0 g
s
.41351 .61383 m .39097 .5812 L .41621 .63235 L .707 .577 .707 r
F
.44678 .24203 m .40894 .58257 L p .40167 .53279 L F P
0 g
s
.8268 .74943 m .82848 .76631 L .84452 .75199 L p .707 .577 .707 r
F P
0 g
s
.84452 .75199 m .84284 .73511 L .8268 .74943 L p .707 .577 .707 r
F P
0 g
s
.66238 .75774 m .66406 .77462 L .68527 .78427 L p .707 .577 .707 r
F P
0 g
s
.64508 .67947 m .64836 .71334 L .66118 .72607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64836 .71334 m .64508 .67947 L .6419 .66482 L p .707 .577 .707 r
F P
0 g
s
.66406 .77462 m .66238 .75774 L .64955 .74488 L p .707 .577 .707 r
F P
0 g
s
.83924 .5632 m .84223 .61624 L .82955 .60537 L p .707 .577 .707 r
F P
0 g
s
.82955 .60537 m .82656 .55234 L .83924 .5632 L p .707 .577 .707 r
F P
0 g
s
.84517 .6549 m .84845 .68876 L .84527 .6741 L p .707 .577 .707 r
F P
0 g
s
.84527 .6741 m .84199 .64024 L .84517 .6549 L p .707 .577 .707 r
F P
0 g
s
.84284 .73511 m .84452 .75199 L .85127 .73667 L p .707 .577 .707 r
F P
0 g
s
.85127 .73667 m .84959 .7198 L .84284 .73511 L p .707 .577 .707 r
F P
0 g
s
.64955 .74488 m .65123 .76176 L .66406 .77462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6419 .66482 m .64518 .69868 L .64836 .71334 L p .707 .577 .707 r
F P
0 g
s
.64554 .56766 m .64852 .6207 L .64156 .63323 L p .707 .577 .707 r
F P
0 g
s
.59084 .78243 m .64838 .26465 L .67845 .26766 L p .707 .577 .707 r
F P
0 g
s
.64852 .6207 m .64554 .56766 L .66179 .55613 L p .707 .577 .707 r
F P
0 g
s
.39396 .63424 m .39097 .5812 L .35982 .57996 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64518 .69868 m .6419 .66482 L .64867 .64968 L p .707 .577 .707 r
F P
0 g
s
.65123 .76176 m .64955 .74488 L .64635 .73007 L p .707 .577 .707 r
F P
0 g
s
.3628 .63299 m .35982 .57996 L .33234 .57491 L p .707 .577 .707 r
F P
0 g
s
.35982 .57996 m .3628 .63299 L .39396 .63424 L p .707 .577 .707 r
F P
0 g
s
.82656 .55234 m .82955 .60537 L .80844 .59701 L p .707 .577 .707 r
F P
0 g
s
.80844 .59701 m .80546 .54397 L .82656 .55234 L p .707 .577 .707 r
F P
0 g
s
.84199 .64024 m .84527 .6741 L .83246 .66137 L p .707 .577 .707 r
F P
0 g
s
.83246 .66137 m .82917 .62751 L .84199 .64024 L p .707 .577 .707 r
F P
0 g
s
.64635 .73007 m .64804 .74694 L .65123 .76176 L p .707 .577 .707 r
F P
0 g
s
.84959 .7198 m .85127 .73667 L .84808 .72185 L p .707 .577 .707 r
F P
0 g
s
.84808 .72185 m .84639 .70498 L .84959 .7198 L p .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .42253 .76381 L p .44345 .6548 L .707 .577 .707 r
F P
0 g
s
.45205 .57215 m .45504 .62519 L .46638 .62073 L p .707 .577 .707 r
F P
0 g
s
.47455 .60859 m .45205 .57215 L .46638 .62073 L .707 .577 .707 r
F
.48257 .59668 m .46347 .76854 L p .45408 .71521 L F P
0 g
s
.44345 .6548 m .47828 .60306 L .45408 .71521 L .707 .577 .707 r
F
.47828 .60306 m .48257 .59668 L .45408 .71521 L F
.476 .56274 m .47828 .60306 L p .48349 .57889 L F P
0 g
s
.476 .56274 m .45205 .57215 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47899 .61578 m .47828 .60306 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47828 .60306 m .476 .56274 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .48075 .61308 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .46347 .76854 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.56561 .25576 m .53865 .49838 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.53865 .49838 m .50807 .77355 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .47933 .64737 L .45814 .65786 L p .707 .577 .707 r
F P
0 g
s
.45814 .65786 m .45556 .65913 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .45814 .65786 L .45693 .66025 L .707 .577 .707 r
F
.45885 .693 m .48262 .68123 L p .45693 .66025 L F P
0 g
s
.45556 .65913 m .45588 .66235 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.45588 .66235 m .45885 .693 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.50336 .56829 m .48567 .56879 L .56561 .25576 L .707 .577 .707 r
F
.48075 .61308 m .48567 .56879 L p .50336 .56829 L F P
0 g
s
.48858 .55383 m .476 .56274 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .52101 .25076 L .54693 .25367 L p .707 .577 .707 r
F P
0 g
s
.54693 .25367 m .56561 .25576 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48349 .57889 m .48567 .56879 L .476 .56274 L .707 .577 .707 r
F
.48895 .55356 m .48858 .55383 L p .48567 .56879 L F P
0 g
s
.49525 .60425 m .49226 .55121 L .48895 .55356 L p .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .48257 .59668 L p .47828 .60306 L .707 .577 .707 r
F P
0 g
s
.49525 .60425 m .48895 .55356 L .48349 .57889 L .707 .577 .707 r
F
.52101 .25076 m .48567 .56879 L p .44345 .6548 L F P
0 g
s
.44345 .6548 m .48567 .56879 L .47828 .60306 L .707 .577 .707 r
F
.47899 .61578 m .49525 .60425 L p .48349 .57889 L F P
0 g
s
.47828 .60306 m .47899 .61578 L p .48349 .57889 L .707 .577 .707 r
F P
0 g
s
.46638 .62073 m .47899 .61578 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.64867 .64968 m .65195 .68354 L .64518 .69868 L p .707 .577 .707 r
F P
0 g
s
.66179 .55613 m .66478 .60917 L .64852 .6207 L p .707 .577 .707 r
F P
0 g
s
.64838 .26465 m .59084 .78243 L .55196 .77833 L p .707 .577 .707 r
F P
0 g
s
.33533 .62794 m .33234 .57491 L .31123 .56654 L p .707 .577 .707 r
F P
0 g
s
.33234 .57491 m .33533 .62794 L .3628 .63299 L p .707 .577 .707 r
F P
0 g
s
.66478 .60917 m .66179 .55613 L .68574 .54673 L p .707 .577 .707 r
F P
0 g
s
.55196 .77833 m .6095 .26055 L .64838 .26465 L p .707 .577 .707 r
F P
0 g
s
.65195 .68354 m .64867 .64968 L .66472 .63553 L p .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .48006 .24603 L .52101 .25076 L p .707 .577 .707 r
F P
0 g
s
.64804 .74694 m .64635 .73007 L .6531 .71475 L p .707 .577 .707 r
F P
0 g
s
.80546 .54397 m .80844 .59701 L .78097 .59195 L p .707 .577 .707 r
F P
0 g
s
.78097 .59195 m .77798 .53892 L .80546 .54397 L p .707 .577 .707 r
F P
0 g
s
.398 .70512 m .39472 .67126 L .36359 .67043 L p .707 .577 .707 r
F P
0 g
s
.39472 .67126 m .398 .70512 L .42969 .70123 L p .707 .577 .707 r
F P
0 g
s
.42969 .70123 m .42641 .66737 L .39472 .67126 L p .707 .577 .707 r
F P
0 g
s
.42641 .66737 m .42969 .70123 L .45885 .693 L p .707 .577 .707 r
F P
0 g
s
.45885 .693 m .45556 .65913 L .42641 .66737 L p .707 .577 .707 r
F P
0 g
s
.82917 .62751 m .83246 .66137 L .81126 .6518 L p .707 .577 .707 r
F P
0 g
s
.81126 .6518 m .80797 .61794 L .82917 .62751 L p .707 .577 .707 r
F P
0 g
s
.6531 .71475 m .65479 .73162 L .64804 .74694 L p .707 .577 .707 r
F P
0 g
s
.84639 .70498 m .84808 .72185 L .83525 .70899 L p .707 .577 .707 r
F P
0 g
s
.83525 .70899 m .83356 .69212 L .84639 .70498 L p .707 .577 .707 r
F P
0 g
s
.36687 .70429 m .36359 .67043 L .33608 .66496 L p .707 .577 .707 r
F P
0 g
s
.36359 .67043 m .36687 .70429 L .398 .70512 L p .707 .577 .707 r
F P
0 g
s
.68873 .59976 m .68574 .54673 L .71504 .54037 L p .707 .577 .707 r
F P
0 g
s
.68574 .54673 m .68873 .59976 L .66478 .60917 L p .707 .577 .707 r
F P
0 g
s
.6095 .26055 m .55196 .77833 L .50807 .77355 L p .707 .577 .707 r
F P
0 g
s
.31422 .61958 m .31123 .56654 L .29856 .55568 L p .707 .577 .707 r
F P
0 g
s
.31123 .56654 m .31422 .61958 L .33533 .62794 L p .707 .577 .707 r
F P
0 g
s
.66472 .63553 m .66801 .66939 L .65195 .68354 L p .707 .577 .707 r
F P
0 g
s
.77798 .53892 m .78097 .59195 L .74981 .59071 L p .707 .577 .707 r
F P
0 g
s
.74981 .59071 m .74682 .53768 L .77798 .53892 L p .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .56561 .25576 L .6095 .26055 L p .707 .577 .707 r
F P
0 g
s
.66801 .66939 m .66472 .63553 L .68849 .62377 L p .707 .577 .707 r
F P
0 g
s
.71803 .5934 m .71504 .54037 L .74682 .53768 L p .707 .577 .707 r
F P
0 g
s
.71504 .54037 m .71803 .5934 L .68873 .59976 L p .707 .577 .707 r
F P
0 g
s
.74682 .53768 m .74981 .59071 L .71803 .5934 L p .707 .577 .707 r
F P
0 g
s
.49226 .55121 m .49525 .60425 L .50221 .59172 L p .707 .577 .707 r
F P
0 g
s
.50221 .59172 m .49923 .53869 L .49226 .55121 L p .707 .577 .707 r
F P
0 g
s
.33937 .69883 m .33608 .66496 L .31488 .6554 L p .707 .577 .707 r
F P
0 g
s
.33608 .66496 m .33937 .69883 L .36687 .70429 L p .707 .577 .707 r
F P
0 g
s
.65479 .73162 m .6531 .71475 L .66914 .70043 L p .707 .577 .707 r
F P
0 g
s
.80797 .61794 m .81126 .6518 L .78375 .64633 L p .707 .577 .707 r
F P
0 g
s
.78375 .64633 m .78047 .61247 L .80797 .61794 L p .707 .577 .707 r
F P
0 g
s
.47933 .64737 m .48262 .68123 L .49867 .66709 L p .707 .577 .707 r
F P
0 g
s
.49867 .66709 m .49539 .63322 L .47933 .64737 L p .707 .577 .707 r
F P
0 g
s
.40089 .75375 m .3992 .73687 L .36808 .73607 L p .707 .577 .707 r
F P
0 g
s
.3992 .73687 m .40089 .75375 L .43257 .74977 L p .707 .577 .707 r
F P
0 g
s
.43257 .74977 m .43089 .7329 L .3992 .73687 L p .707 .577 .707 r
F P
0 g
s
.43089 .7329 m .43257 .74977 L .46172 .74142 L p .707 .577 .707 r
F P
0 g
s
.46172 .74142 m .46003 .72454 L .43089 .7329 L p .707 .577 .707 r
F P
0 g
s
.83356 .69212 m .83525 .70899 L .81404 .69934 L p .707 .577 .707 r
F P
0 g
s
.81404 .69934 m .81236 .68247 L .83356 .69212 L p .707 .577 .707 r
F P
0 g
s
.29856 .55568 m .30154 .60871 L .31422 .61958 L p .707 .577 .707 r
F P
0 g
s
.66914 .70043 m .67083 .7173 L .65479 .73162 L p .707 .577 .707 r
F P
0 g
s
.69178 .65763 m .68849 .62377 L .71765 .61554 L p .707 .577 .707 r
F P
0 g
s
.68849 .62377 m .69178 .65763 L .66801 .66939 L p .707 .577 .707 r
F P
0 g
s
.36977 .75295 m .36808 .73607 L .34057 .73058 L p .707 .577 .707 r
F P
0 g
s
.36808 .73607 m .36977 .75295 L .40089 .75375 L p .707 .577 .707 r
F P
0 g
s
.30154 .60871 m .29856 .55568 L .29556 .54338 L p .707 .577 .707 r
F P
0 g
s
.78047 .61247 m .78375 .64633 L .75263 .64551 L p .707 .577 .707 r
F P
0 g
s
.75263 .64551 m .74934 .61164 L .78047 .61247 L p .707 .577 .707 r
F P
0 g
s
.31488 .6554 m .31817 .68926 L .33937 .69883 L p .707 .577 .707 r
F P
0 g
s
.46003 .72454 m .46172 .74142 L .48547 .72949 L p .707 .577 .707 r
F P
0 g
s
.48547 .72949 m .48379 .71262 L .46003 .72454 L p .707 .577 .707 r
F P
0 g
s
.31817 .68926 m .31488 .6554 L .30207 .64266 L p .707 .577 .707 r
F P
0 g
s
.72093 .6494 m .71765 .61554 L .74934 .61164 L p .707 .577 .707 r
F P
0 g
s
.71765 .61554 m .72093 .6494 L .69178 .65763 L p .707 .577 .707 r
F P
0 g
s
.34057 .73058 m .34226 .74745 L .36977 .75295 L p .707 .577 .707 r
F P
0 g
s
.67083 .7173 m .66914 .70043 L .6929 .68851 L p .707 .577 .707 r
F P
0 g
s
.74934 .61164 m .75263 .64551 L .72093 .6494 L p .707 .577 .707 r
F P
0 g
s
.49923 .53869 m .50221 .59172 L .49921 .57942 L p .707 .577 .707 r
F P
0 g
s
.49921 .57942 m .49623 .52639 L .49923 .53869 L p .707 .577 .707 r
F P
0 g
s
.34226 .74745 m .34057 .73058 L .31937 .72093 L p .707 .577 .707 r
F P
0 g
s
.49539 .63322 m .49867 .66709 L .50544 .65194 L p .707 .577 .707 r
F P
0 g
s
.50544 .65194 m .50216 .61808 L .49539 .63322 L p .707 .577 .707 r
F P
0 g
s
.81236 .68247 m .81404 .69934 L .78653 .69385 L p .707 .577 .707 r
F P
0 g
s
.78653 .69385 m .78485 .67698 L .81236 .68247 L p .707 .577 .707 r
F P
0 g
s
.6929 .68851 m .69458 .70538 L .67083 .7173 L p .707 .577 .707 r
F P
0 g
s
.48379 .71262 m .48547 .72949 L .50151 .71517 L p .707 .577 .707 r
F P
0 g
s
.50151 .71517 m .49983 .6983 L .48379 .71262 L p .707 .577 .707 r
F P
0 g
s
.29556 .54338 m .29855 .59641 L .30154 .60871 L p .707 .577 .707 r
F P
0 g
s
.31937 .72093 m .32105 .7378 L .34226 .74745 L p .707 .577 .707 r
F P
0 g
s
.30207 .64266 m .30535 .67652 L .31817 .68926 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.69458 .70538 m .6929 .68851 L .72204 .68015 L p .707 .577 .707 r
F P
0 g
s
.29855 .59641 m .29556 .54338 L .30253 .53085 L p .707 .577 .707 r
F P
0 g
s
.78485 .67698 m .78653 .69385 L .75541 .69305 L p .707 .577 .707 r
F P
0 g
s
.75541 .69305 m .75373 .67618 L .78485 .67698 L p .707 .577 .707 r
F P
0 g
s
.30535 .67652 m .30207 .64266 L .29889 .628 L p .707 .577 .707 r
F P
0 g
s
.32105 .7378 m .31937 .72093 L .30654 .70807 L p .707 .577 .707 r
F P
0 g
s
.72204 .68015 m .72373 .69702 L .69458 .70538 L p .707 .577 .707 r
F P
0 g
s
.72373 .69702 m .72204 .68015 L .75373 .67618 L p .707 .577 .707 r
F P
0 g
s
.75373 .67618 m .75541 .69305 L .72373 .69702 L p .707 .577 .707 r
F P
0 g
s
.49623 .52639 m .49921 .57942 L .48654 .56856 L p .707 .577 .707 r
F P
0 g
s
.48654 .56856 m .48355 .51552 L .49623 .52639 L p .707 .577 .707 r
F P
0 g
s
.50216 .61808 m .50544 .65194 L .50226 .63729 L p .707 .577 .707 r
F P
0 g
s
.50226 .63729 m .49898 .60343 L .50216 .61808 L p .707 .577 .707 r
F P
0 g
s
.49983 .6983 m .50151 .71517 L .50826 .69985 L p .707 .577 .707 r
F P
0 g
s
.50826 .69985 m .50658 .68298 L .49983 .6983 L p .707 .577 .707 r
F P
0 g
s
.30654 .70807 m .30822 .72494 L .32105 .7378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29889 .628 m .30217 .66186 L .30535 .67652 L p .707 .577 .707 r
F P
0 g
s
.30253 .53085 m .30551 .58388 L .29855 .59641 L p .707 .577 .707 r
F P
0 g
s
.30551 .58388 m .30253 .53085 L .31878 .51932 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30217 .66186 m .29889 .628 L .30566 .61286 L p .707 .577 .707 r
F P
0 g
s
.30822 .72494 m .30654 .70807 L .30334 .69325 L p .707 .577 .707 r
F P
0 g
s
.48355 .51552 m .48654 .56856 L .46543 .56019 L p .707 .577 .707 r
F P
0 g
s
.46543 .56019 m .46244 .50715 L .48355 .51552 L p .707 .577 .707 r
F P
0 g
s
.49898 .60343 m .50226 .63729 L .48945 .62455 L p .707 .577 .707 r
F P
0 g
s
.48945 .62455 m .48616 .59069 L .49898 .60343 L p .707 .577 .707 r
F P
0 g
s
.30334 .69325 m .30503 .71013 L .30822 .72494 L p .707 .577 .707 r
F P
0 g
s
.50658 .68298 m .50826 .69985 L .50507 .68504 L p .707 .577 .707 r
F P
0 g
s
.50507 .68504 m .50338 .66817 L .50658 .68298 L p .707 .577 .707 r
F P
0 g
s
.30566 .61286 m .30894 .64672 L .30217 .66186 L p .707 .577 .707 r
F P
0 g
s
.31878 .51932 m .32177 .57235 L .30551 .58388 L p .707 .577 .707 r
F P
0 g
s
.32177 .57235 m .31878 .51932 L .34273 .50991 L p .707 .577 .707 r
F P
0 g
s
.30894 .64672 m .30566 .61286 L .32171 .59872 L p .707 .577 .707 r
F P
0 g
s
.30503 .71013 m .30334 .69325 L .31009 .67793 L p .707 .577 .707 r
F P
0 g
s
.46244 .50715 m .46543 .56019 L .43796 .55514 L p .707 .577 .707 r
F P
0 g
s
.43796 .55514 m .43497 .5021 L .46244 .50715 L p .707 .577 .707 r
F P
0 g
s
.48616 .59069 m .48945 .62455 L .46825 .61498 L p .707 .577 .707 r
F P
0 g
s
.46825 .61498 m .46496 .58112 L .48616 .59069 L p .707 .577 .707 r
F P
0 g
s
.31009 .67793 m .31178 .69481 L .30503 .71013 L p .707 .577 .707 r
F P
0 g
s
.50338 .66817 m .50507 .68504 L .49224 .67218 L p .707 .577 .707 r
F P
0 g
s
.49224 .67218 m .49055 .6553 L .50338 .66817 L p .707 .577 .707 r
F P
0 g
s
.34572 .56295 m .34273 .50991 L .37203 .50355 L p .707 .577 .707 r
F P
0 g
s
.34273 .50991 m .34572 .56295 L .32177 .57235 L p .707 .577 .707 r
F P
0 g
s
.32171 .59872 m .325 .63258 L .30894 .64672 L p .707 .577 .707 r
F P
0 g
s
.43497 .5021 m .43796 .55514 L .4068 .5539 L p .707 .577 .707 r
F P
0 g
s
.4068 .5539 m .40381 .50086 L .43497 .5021 L p .707 .577 .707 r
F P
0 g
s
.325 .63258 m .32171 .59872 L .34548 .58695 L p .707 .577 .707 r
F P
0 g
s
.37502 .55659 m .37203 .50355 L .40381 .50086 L p .707 .577 .707 r
F P
0 g
s
.37203 .50355 m .37502 .55659 L .34572 .56295 L p .707 .577 .707 r
F P
0 g
s
.40381 .50086 m .4068 .5539 L .37502 .55659 L p .707 .577 .707 r
F P
0 g
s
.31178 .69481 m .31009 .67793 L .32613 .66361 L p .707 .577 .707 r
F P
0 g
s
.46496 .58112 m .46825 .61498 L .44074 .60952 L p .707 .577 .707 r
F P
0 g
s
.44074 .60952 m .43746 .57565 L .46496 .58112 L p .707 .577 .707 r
F P
0 g
s
.49055 .6553 m .49224 .67218 L .47103 .66253 L p .707 .577 .707 r
F P
0 g
s
.47103 .66253 m .46935 .64565 L .49055 .6553 L p .707 .577 .707 r
F P
0 g
s
.32613 .66361 m .32782 .68049 L .31178 .69481 L p .707 .577 .707 r
F P
0 g
s
.34877 .62081 m .34548 .58695 L .37464 .57872 L p .707 .577 .707 r
F P
0 g
s
.34548 .58695 m .34877 .62081 L .325 .63258 L p .707 .577 .707 r
F P
0 g
s
.43746 .57565 m .44074 .60952 L .40961 .60869 L p .707 .577 .707 r
F P
0 g
s
.40961 .60869 m .40633 .57483 L .43746 .57565 L p .707 .577 .707 r
F P
0 g
s
.37792 .61258 m .37464 .57872 L .40633 .57483 L p .707 .577 .707 r
F P
0 g
s
.37464 .57872 m .37792 .61258 L .34877 .62081 L p .707 .577 .707 r
F P
0 g
s
.32782 .68049 m .32613 .66361 L .34989 .65169 L p .707 .577 .707 r
F P
0 g
s
.40633 .57483 m .40961 .60869 L .37792 .61258 L p .707 .577 .707 r
F P
0 g
s
.46935 .64565 m .47103 .66253 L .44352 .65703 L p .707 .577 .707 r
F P
0 g
s
.44352 .65703 m .44184 .64016 L .46935 .64565 L p .707 .577 .707 r
F P
0 g
s
.34989 .65169 m .35157 .66856 L .32782 .68049 L p .707 .577 .707 r
F P
0 g
s
.35157 .66856 m .34989 .65169 L .37903 .64333 L p .707 .577 .707 r
F P
0 g
s
.44184 .64016 m .44352 .65703 L .4124 .65623 L p .707 .577 .707 r
F P
0 g
s
.4124 .65623 m .41072 .63936 L .44184 .64016 L p .707 .577 .707 r
F P
0 g
s
.37903 .64333 m .38072 .66021 L .35157 .66856 L p .707 .577 .707 r
F P
0 g
s
.38072 .66021 m .37903 .64333 L .41072 .63936 L p .707 .577 .707 r
F P
0 g
s
.41072 .63936 m .4124 .65623 L .38072 .66021 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001fOol4002SOol007Ioo``0
09]oo`00MWoo00<005YF00001UYF00<005YFFUH02@00TWoo001fOol00`00FUH00006FUH00`00FUIJ
EP04FUH@0027Ool007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00=JEQD007Yoo`00
MGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEUYFFUHD001aOol007Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP04001JEUYFFUH6
0002FUH6001[Ool007Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEPl006Aoo`00MGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF3P00G7oo001eOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
3000EGoo001eOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001EOol007Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Eoo`00MGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH04EYF00<005YFFUH00eYF0P00
EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYFEWoo001dOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUIFOol007Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEWoo05Eoo`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0EGoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001FOol007Aoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Ioo`00M7oo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EWoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001FOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
Oomoo`1DOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1F
Ool007=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05Ioo`00Lgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0EWoo001cOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=oo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005Moo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Egoo001cOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Moo`00LWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Moo`00LWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEWoo05Moo`00LWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Egoo001bOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIoo`1GOol0079oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
05Qoo`00LWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00F7oo001bOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001HOol0079oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000EJEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Qoo`00LGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Qo
o`00LGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0F7oo001aOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001IOol0075oo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8005Uoo`00LGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<0
05YF00001EYF0P00FGoo001aOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001I
Ool0075oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Uoo`00L7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEP0005Uoo`00L7oo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF00001EYF0P00FWoo001`Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001JOol0071oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Yoo`00L7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00FWoo001`Ool00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001JOol0071oo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Yo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Yoo`00Kgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo001_Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006moo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8005]oo`00Kgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Fgoo001_Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001KOol006ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001^Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001LOol006ioo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00G7oo001]Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
G7oo001]Ool@0003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001LOol006Qoo`H000AJEP03001JEUYF00IJ
EP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0005aoo`00I7oo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`00G7oo001POol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol005aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005eoo`00FWoo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00GGoo001IOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00GGoo
001FOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0011oo`T004Aoo`00E7oo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Uoo`L000AJEP03001JEUYF009JEPP003aoo`00
E7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH4000hOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool30006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000fOol005Aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000017oo0000000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P00=7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP03
FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040002Ool0
0`00FUIJEP040003FUH00`00FUIJEP06FUH01000FUIJEUYF100015YF00@005YFFUH000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP@000Ioo`03001JEUYF00D0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP<00005FUH005YFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH0
0`00FUH00003000:Ool00`00FUIJEP0500000eYF001JEP08FUH00`00FUIJEP08FUH20002FUH20007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH2000>Ool00`00FUIJEP0500000eYF001J
EP08FUH00`00FUIJEP0:FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<0
05YFFUH01@002Goo00<005YFFUH04@0035YF10001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00@005YF001JEP80
00AJEP04001JEUYFFUH=0004FUH00`00FUIJEP06FUH00`00FUH00003000:FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH000020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH40006FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool004Moo`T000Aoo`05001JEP00FUH00005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo0011Ool60004FUH00`00FUIJEP02FUH60002FUH00`00FUIJ
EP03FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000015YF001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000mOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHG0004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20003FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH01@00FUIJEUYF00001UYF00<005YFFUH010001goo0`003Goo1@001EYF00D0
05YFFUIJEP0002eoo`00=goo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
0eYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00QJEP05001JEUYFFUH00005FUH4000:Ool5000AOol20003FUH01@00FUIJEUYF0000;Goo000eOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYFFUH2000>Ool5000@Ool200001EYF000005YF00000eYF0P00;7oo000cOol20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001JEP00
000@Ool5000>Ool20003FUH01000FUH000000eYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF1@0047oo20001Goo1@001EYF00D005YFFUIJ
EP00009JEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P003EYF00@005YFFUIJ
EPD000EJEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00H005YFFUIJEP00FUH40009Ool40002FUH00`00FUIJEP02FUH90006FUH00`00FUIJ
EP02FUH4000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP0;FUH00`00FUIJ
EP06FUH20003FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH00eYF2@001UYF00<005YFFUH01UYF00@005YFFUIJEPD0009J
EP03001JEUYF00=JEP<002aoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH0
1UYF00D005YFFUIJEP0000MJEP<00006FUH00000FUH005YF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00AJEP@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP<002aoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;FUH01000FUH000000UYF00<0
05YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00P0015YF00<005YF0000;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020006FUH00`00FUIJ
EP05FUH30007FUH01000FUIJEP002eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool0
02eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUH20003FUH40002FUH00`00FUIJEP04FUH=00000eYF001JEP09FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P0000=JEP000000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
1EYF00<005YF00003@002EYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002eoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@000eYF00D0
05YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002Ool01@00FUIJEP00FUH02`000eYF
00<005YFFUH025YF00@005YFFUIJEP800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`@0009JEP8000AJEP03001JEUYF00=JEP04001J
EUYF0002Ool70004FUH00`00FUIJEP02FUH80006FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0019oo`05001J
EUYF001oo`050005FUH01@00FUIJEP00Ool00P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPD00004FUH005YF0002FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@000aoo`L000Aoo`03001JEP0000Ioo`8000=JEP03001JEP00008000=JEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1`00
25YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00@005YFFUH002eoo`00;Goo00<005YF0000
15YF00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF009JEPH00003FUH007oo00=oo`800003FUH0
000000<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=J
EP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEP00000:Ool4
0006FUH00`00FUIJEP06FUH20002FUH50002FUH200000eYF001JEP07FUH00`00FUIJEP02FUH?0005
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00;7oo000]Ool00`00FUH00004FUH5
0005Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000AJEP00000000=JEP03
001JEUYF00EJEPL000UJEP03001JEUYF009JEP@00003FUH005YF00AJEP@000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003Ool200000eYF001JEP02
FUH00`00Oomoo`0ZOol002eoo`03001JEP00009JEP8000=JEP03001JEP0000@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF008000EJEP03001JEUYF009JEP@000EJEP03001J
EUYF00MJEPD00004FUH005YFFUH20005FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<000Moo`8000=JEP03001oogoo02Yoo`00;Goo00<005YF0000
0P001EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00@005YF0000
00IJEP03001JEP0000<0009JEP03001JEUYF00=JEP04001JEUYFFUH70005FUH00`00FUIJEP02FUH2
0003FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF
001JEP0000AJEP03001JEP0000@000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00@000aoo`04
001JEUYF000/Ool002eoo`05001JEP00FUH00004FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH20002FUH200000eYF001JEP05FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH200000eYF001JEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH0009JEP04001JEUYFFUH20005FUHI000AOol3000/Ool002eoo`80009JEP03001JEUYF
008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH01000
FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYF0002FUH0
1P00FUIJEP00FUH000EJEP03001JEUYF008000Moo`D001Qoo`800003FUH0000002]oo`00;Goo0P00
0UYF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH200001EYF001JEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUH0009JEP03001JEP00009JEP03001JEUYF00=JEP05001JEUYFFUH00007OolA000:Ool2
00000eYF001JEP02000[Ool002eoo`80009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP<000MJEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00D005YFFUIJEP00009oo`L000AJEP03
001JEUYF00IJEP03001JEP0000<000Eoo`06001JEUYFFUH005YF0P00:goo000]Ool200000eYF001J
EP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0003FUH01@00FUIJEUYF0000
1UYF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00D005YFFUIJ
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=oo`0000000P00
15YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0015YF
00@005YFFUH002]oo`00;Goo0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YF
FUH00eYF0P0000=JEP00000015YF00<005YFFUH015YF00<005YFFUH015YF1@001eYF00<005YFFUH0
1EYF00<005YFFUH00P0025YF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003Ool5000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P000eYF00@005YFFUH002]oo`00;Woo0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001EYF00<005YFFUH01eYF00H005YFFUIJEP00FUH40004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50007FUH00`00FUIJEP05FUH40008FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF0`000eYF100025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<005YF0000:goo000^Ool20005
FUH00`00FUIJEP04FUH00`00FUH000020007FUH00`00FUIJEP07FUH02P00FUIJEUYF001JEP00FUH0
05YF0`0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH015YF0P000UYF00<005YF
FUH01UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003
FUH500001EYF001JEUYF000025YF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000=JEP00
0000;7oo000^Ool20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP05FUH;0003FUH20002FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP06FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
009JEP03001JEUYF00<000AJEP03001JEUYF00AJEPH000eoo`800003FUH0000000@000AJEP03001J
EP00008002aoo`00;Goo00<005YF00001EYF00@005YFFUIJEP8000EJEP03001JEUYF00H000AJEP03
001JEUYF009JEPT000EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF
00EJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF
00@005YFFUH000IJEP03001JEUYF00@0011oo`<000=JEP03001JEUYF00=JEP8000=JEP03001JEP00
02eoo`00;Goo00<005YF00001EYF00@005YF000000MJEP<00003FUH005YF00MJEP03001JEUYF00IJ
EP80009JEPH000Eooa4000=JEP8000YJEP03001JEUYF00=JEP800003FUH00000009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000005FUH6
000<Ool60006FUH00`00FUIJEP05FUH200001EYF001JEUYF0000;7oo000]Ool01000FUIJEP0015YF
0P0000=JEP00FUH015YF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF0`0017oo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF009JEP8000=JEPl000AJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEP000002FUH0
0`00Oomoo`0ZOol002eoo`04001JEUYF0003FUH00`00Oomoo`03000015YF000000001eYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001EYF00<005YFFUH00P0000Aoo`000000009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP8000YJEP05001JEUYFFUH00004FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000800003FUH0
07oo02]oo`00;Goo00D005YFFUH005YF008000Eoo`800003FUH005YF00MJEP03001JEUYF009JEPl0
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEP00
008000AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH200000eYF001JEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003Ool00`00FUH0000[Ool002eoo`03001JEUYF008000Eoo`8000=JEP03001JEUYF
00EJEPX000Uoo`03001JEP0000<00003FUH005YF00AJEP<0009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Eoo`8002]oo`00;Woo00<0
05YF000017oo0P001EYF00<005YFFUH00UYF0`0017oo0`0037oo00<005YFFUH00P0000=oo`000000
1EYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF0P0015YF00@0
05YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP04
001JEUYFFUH20008Ool00`00Oomoo`0YOol002ioo`@0009oo`8000IJEP03001JEP00008000Ioo`D0
00]oo`05001JEUYF001JEP050003FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20006FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP04001JEP000009Ool2000[Ool002ioo`80009JEP800003FUH005YF00EJEP8000Uo
o`D000aoo`03001JEP0000AJEP@00004FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`001eYF00<005YFFUH015YF0`002goo0P00:goo000^Ool01@00FUIJEUYF00000eYF00@005YF
FUIJEP8000]oo`D000eoo`<000AJEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000EJEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEUYF0080009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000eoo`03001JEP0002]oo`00;Woo0P0000=JEP00FUH00eYF00@005YF
000000ioo`<000aoo`800003FUH0000000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04
001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1`004Goo00<005YF0000
:goo000^Ool200000eYF001JEP03FUH4000JOol30003FUH01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00000017oo4P005goo0P0000=JEP00
Ool0:Woo000^Ool40003FUH01@00FUIJEP00FUH0100047oo1P001UYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJ
EP<000Ioo`03001JEP0002=oo`04001JEP00000/Ool002moo`<00003FUH0000000=JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000020003Ool3000ROol01@00FUIJ
EUYF0000;7oo000_Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF000015YF00<005YFFUH00UYF100000=JEP0000007goo0P0015YF00<007oo
Ool0:Woo000_Ool01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=oo`0000003`000UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H0
05YF000005YF0004FUH00`00FUIJEP02FUH300000eYF0000000MOol200000eYF001JEP02FUH00`00
Oomoo`0[Ool002moo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`@000=JEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000002FUH50004FUH01000FUH005YF0P006goo0P000eYF00@005YF000002ioo`00
;goo0P0000=oo`0000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000Eoo`800003FUH007oo00P000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00
0002FUH30002Ool20003FUH01@00FUH005YF00005goo10001EYF0P00<7oo000_Ool20002Ool00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH000001Goo0P0000=JEP0000002Woo2`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF001oo`00FUH00002FUH200001UYF0000
0000FUH0009JEP8001=oo`@0009JEP03001JEUYF00AJEP03001oogoo02moo`00;goo0P000goo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001Woo00@0
05YFFUIJEP8001Eoo``000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP07001JEP00Ool005YF000015YF1P000UYF00<007ooOol03Goo1@001UYF00<005YFFUH0
0UYF0P00<Woo000_Ool30004Ool200000eYF001JEP06FUH00`00FUIJEP04FUH30008FUH00`00FUIJ
EP040007Ool20004FUH00`00Oomoo`0POol90009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002Ool30005FUH01000FUIJEUYF20001goo10000UYF00<005YFFUH01UYF
00<005YFFUH00P00=7oo000_Ool200000eYF001oo`04Ool50004FUH00`00FUIJEP03FUH50003FUH7
0009Ool200000eYF001JEP03FUH00`00Oomoo`0VOol90003FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000005FUH00`00FUIJEP05FUH01000FUIJEUYF
1`001UYF00<005YFFUH01UYF0`00=Woo000`Ool01000FUIJEP002Goo4P003Woo0P000eYF00D005YF
FUIJEP0002Uoo`<000=JEP03001JEUYF00T000EJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000=JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2000hOol0031oo`03001JEUYF00<0015oo`D000ioo`<000IJEP03001JEP0002Yoo`<0
009JEP03001JEUYF009JEP04001JEUYFFUH>0004FUH00`00FUIJEP02FUH00`00FUH00003FUH01000
FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000>Woo
000`Ool01000FUIJEP000UYF0P0047oo0`003Goo0P0000=JEP00FUH01UYF0P00:goo00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH0000;0003FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000nOol0035oo`04001JEUYF0003FUH3000JOol3
0003FUH00`00FUIJEP04FUH2000/Ool00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000goo0000000@0015Ool0039o
o`<000AJEP03001JEP0000<0011oo`H000MJEP04001JEUYFFUH2000^Ool00`00FUIJEP020005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0004Ool00`00FUH0001BOol003Aoo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF
00IJEP04001JEP00000`Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001Woo00<005YF0000DWoo000eOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000cOol200000goo
001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUH000001goo0P0000=JEP00Ool0DGoo000gOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000fOol01000Oomoogoo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0027oo00@005YF000005=oo`00>Goo0`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00>Goo0P0017oo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo00D005YFFUIJEP0005=oo`00
?7oo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?7oo00<005YF00001Goo0`001UYF00<0
05YFFUH01EYF0`001eYF00<005YF00000P002Woo0P0015YF00<007ooOol0DGoo0010Ool?0012Ool2
00000eYF001oo`06Ool40002FUH00`00FUIJEP04FUH50002FUH6000;Ool200000eYF001JEP02FUH0
0`00Oomoo`1BOol0099oo`04001JEUYF000:Ool@000?Ool20003FUH01000FUH00000EGoo002BOol0
0`00FUIJEP03000AOol5000=Ool40005FUH2001GOol009=oo`03001JEP00009JEP80011oo`<000Yo
o`@0009JEP03001JEUYF00AJEP03001oogoo05Ioo`00Tgoo00<005YF000015YF1@004Goo1`001UYF
00<005YFFUH00UYF0P00FGoo002DOol20005FUH01000FUIJEUYF4@0015YF00<005YFFUH01UYF00<0
05YFFUH00P00Fgoo002EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH3001MOol009Moo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8005moo`00VWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01000HGoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001UOol00:5ooa0006ao
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59976 .75658 m .59678 .70354 L .56562 .7023 L p .707 .577 .707 r
F P
0 g
s
.59678 .70354 m .59976 .75658 L .63155 .75389 L p .707 .577 .707 r
F P
0 g
s
.63155 .75389 m .62856 .70085 L .59678 .70354 L p .707 .577 .707 r
F P
0 g
s
.62856 .70085 m .63155 .75389 L .66085 .74753 L p .707 .577 .707 r
F P
0 g
s
.66085 .74753 m .65786 .69449 L .62856 .70085 L p .707 .577 .707 r
F P
0 g
s
.56861 .75534 m .56562 .7023 L .53815 .69725 L p .707 .577 .707 r
F P
0 g
s
.56562 .7023 m .56861 .75534 L .59976 .75658 L p .707 .577 .707 r
F P
0 g
s
.65786 .69449 m .66085 .74753 L .6848 .73812 L p .707 .577 .707 r
F P
0 g
s
.6848 .73812 m .68181 .68509 L .65786 .69449 L p .707 .577 .707 r
F P
0 g
s
.54113 .75029 m .53815 .69725 L .51704 .68888 L p .707 .577 .707 r
F P
0 g
s
.53815 .69725 m .54113 .75029 L .56861 .75534 L p .707 .577 .707 r
F P
0 g
s
.6038 .81747 m .60052 .7836 L .5694 .78278 L p .707 .577 .707 r
F P
0 g
s
.60052 .7836 m .6038 .81747 L .63549 .81357 L p .707 .577 .707 r
F P
0 g
s
.63549 .81357 m .63221 .77971 L .60052 .7836 L p .707 .577 .707 r
F P
0 g
s
.68181 .68509 m .6848 .73812 L .70105 .72659 L p .707 .577 .707 r
F P
0 g
s
.70105 .72659 m .69806 .67356 L .68181 .68509 L p .707 .577 .707 r
F P
0 g
s
.63221 .77971 m .63549 .81357 L .66465 .80534 L p .707 .577 .707 r
F P
0 g
s
.66465 .80534 m .66137 .77148 L .63221 .77971 L p .707 .577 .707 r
F P
0 g
s
.57268 .81664 m .5694 .78278 L .54189 .77731 L p .707 .577 .707 r
F P
0 g
s
.5694 .78278 m .57268 .81664 L .6038 .81747 L p .707 .577 .707 r
F P
0 g
s
.66137 .77148 m .66465 .80534 L .68842 .79358 L p .707 .577 .707 r
F P
0 g
s
.68842 .79358 m .68514 .75972 L .66137 .77148 L p .707 .577 .707 r
F P
0 g
s
.52003 .74192 m .51704 .68888 L .50436 .67802 L p .707 .577 .707 r
F P
0 g
s
.51704 .68888 m .52003 .74192 L .54113 .75029 L p .707 .577 .707 r
F P
0 g
s
.54517 .81117 m .54189 .77731 L .52069 .76774 L p .707 .577 .707 r
F P
0 g
s
.54189 .77731 m .54517 .81117 L .57268 .81664 L p .707 .577 .707 r
F P
0 g
s
.69806 .67356 m .70105 .72659 L .70802 .71406 L p .707 .577 .707 r
F P
0 g
s
.70802 .71406 m .70503 .66103 L .69806 .67356 L p .707 .577 .707 r
F P
0 g
s
.6067 .85025 m .60501 .83338 L .57389 .83258 L p .707 .577 .707 r
F P
0 g
s
.60501 .83338 m .6067 .85025 L .63838 .84628 L p .707 .577 .707 r
F P
0 g
s
.63838 .84628 m .63669 .8294 L .60501 .83338 L p .707 .577 .707 r
F P
0 g
s
.63669 .8294 m .63838 .84628 L .66752 .83792 L p .707 .577 .707 r
F P
0 g
s
.66752 .83792 m .66584 .82105 L .63669 .8294 L p .707 .577 .707 r
F P
0 g
s
.68514 .75972 m .68842 .79358 L .70448 .77943 L p .707 .577 .707 r
F P
0 g
s
.70448 .77943 m .7012 .74557 L .68514 .75972 L p .707 .577 .707 r
F P
0 g
s
.57558 .84945 m .57389 .83258 L .54638 .82708 L p .707 .577 .707 r
F P
0 g
s
.57389 .83258 m .57558 .84945 L .6067 .85025 L p .707 .577 .707 r
F P
0 g
s
.50436 .67802 m .50735 .73105 L .52003 .74192 L p .707 .577 .707 r
F P
0 g
s
.66584 .82105 m .66752 .83792 L .69128 .826 L p .707 .577 .707 r
F P
0 g
s
.69128 .826 m .68959 .80913 L .66584 .82105 L p .707 .577 .707 r
F P
0 g
s
.50735 .73105 m .50436 .67802 L .50136 .66572 L p .707 .577 .707 r
F P
0 g
s
.52069 .76774 m .52397 .8016 L .54517 .81117 L p .707 .577 .707 r
F P
0 g
s
.54638 .82708 m .54807 .84396 L .57558 .84945 L p .707 .577 .707 r
F P
0 g
s
.52397 .8016 m .52069 .76774 L .50787 .75501 L p .707 .577 .707 r
F P
0 g
s
.54807 .84396 m .54638 .82708 L .52517 .81743 L p .707 .577 .707 r
F P
0 g
s
.7012 .74557 m .70448 .77943 L .71125 .76429 L p .707 .577 .707 r
F P
0 g
s
.71125 .76429 m .70796 .73043 L .7012 .74557 L p .707 .577 .707 r
F P
0 g
s
.70503 .66103 m .70802 .71406 L .70502 .70177 L p .707 .577 .707 r
F P
0 g
s
.70502 .70177 m .70203 .64873 L .70503 .66103 L p .707 .577 .707 r
F P
0 g
s
.68959 .80913 m .69128 .826 L .70732 .81168 L p .707 .577 .707 r
F P
0 g
s
.70732 .81168 m .70563 .7948 L .68959 .80913 L p .707 .577 .707 r
F P
0 g
s
.52517 .81743 m .52686 .83431 L .54807 .84396 L p .707 .577 .707 r
F P
0 g
s
.50787 .75501 m .51116 .78887 L .52397 .8016 L p .707 .577 .707 r
F P
0 g
s
.50136 .66572 m .50435 .71876 L .50735 .73105 L p .707 .577 .707 r
F P
0 g
s
.50435 .71876 m .50136 .66572 L .50833 .65319 L p .707 .577 .707 r
F P
0 g
s
.52686 .83431 m .52517 .81743 L .51234 .80457 L p .707 .577 .707 r
F P
0 g
s
.51116 .78887 m .50787 .75501 L .50469 .74035 L p .707 .577 .707 r
F P
0 g
s
.70563 .7948 m .70732 .81168 L .71407 .79636 L p .707 .577 .707 r
F P
0 g
s
.71407 .79636 m .71238 .77949 L .70563 .7948 L p .707 .577 .707 r
F P
0 g
s
.51234 .80457 m .51403 .82145 L .52686 .83431 L p .707 .577 .707 r
F P
0 g
s
.70796 .73043 m .71125 .76429 L .70807 .74964 L p .707 .577 .707 r
F P
0 g
s
.70807 .74964 m .70479 .71577 L .70796 .73043 L p .707 .577 .707 r
F P
0 g
s
.70203 .64873 m .70502 .70177 L .69235 .6909 L p .707 .577 .707 r
F P
0 g
s
.69235 .6909 m .68936 .63787 L .70203 .64873 L p .707 .577 .707 r
F P
0 g
s
.50469 .74035 m .50798 .77421 L .51116 .78887 L p .707 .577 .707 r
F P
0 g
s
.50833 .65319 m .51132 .70623 L .50435 .71876 L p .707 .577 .707 r
F P
0 g
s
.51403 .82145 m .51234 .80457 L .50915 .78976 L p .707 .577 .707 r
F P
0 g
s
.51132 .70623 m .50833 .65319 L .52459 .64166 L p .707 .577 .707 r
F P
0 g
s
.50798 .77421 m .50469 .74035 L .51146 .72521 L p .707 .577 .707 r
F P
0 g
s
.25676 .71976 m .25377 .66673 L .22261 .66549 L p .707 .577 .707 r
F P
0 g
s
.25377 .66673 m .25676 .71976 L .28854 .71707 L p .707 .577 .707 r
F P
0 g
s
.28854 .71707 m .28555 .66404 L .25377 .66673 L p .707 .577 .707 r
F P
0 g
s
.28555 .66404 m .28854 .71707 L .31784 .71071 L p .707 .577 .707 r
F P
0 g
s
.31784 .71071 m .31485 .65768 L .28555 .66404 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.50915 .78976 m .51083 .80663 L .51403 .82145 L p .707 .577 .707 r
F P
0 g
s
.71238 .77949 m .71407 .79636 L .71087 .78155 L p .707 .577 .707 r
F P
0 g
s
.71087 .78155 m .70919 .76467 L .71238 .77949 L p .707 .577 .707 r
F P
0 g
s
.2256 .71852 m .22261 .66549 L .19514 .66044 L p .707 .577 .707 r
F P
0 g
s
.22261 .66549 m .2256 .71852 L .25676 .71976 L p .707 .577 .707 r
F P
0 g
s
.70479 .71577 m .70807 .74964 L .69525 .7369 L p .707 .577 .707 r
F P
0 g
s
.69525 .7369 m .69197 .70304 L .70479 .71577 L p .707 .577 .707 r
F P
0 g
s
.68936 .63787 m .69235 .6909 L .67124 .68253 L p .707 .577 .707 r
F P
0 g
s
.67124 .68253 m .66825 .6295 L .68936 .63787 L p .707 .577 .707 r
F P
0 g
s
.31485 .65768 m .31784 .71071 L .34179 .70131 L p .707 .577 .707 r
F P
0 g
s
.34179 .70131 m .3388 .64827 L .31485 .65768 L p .707 .577 .707 r
F P
0 g
s
.51146 .72521 m .51475 .75907 L .50798 .77421 L p .707 .577 .707 r
F P
0 g
s
.52459 .64166 m .52757 .6947 L .51132 .70623 L p .707 .577 .707 r
F P
0 g
s
.19812 .71347 m .19514 .66044 L .17403 .65207 L p .707 .577 .707 r
F P
0 g
s
.19514 .66044 m .19812 .71347 L .2256 .71852 L p .707 .577 .707 r
F P
0 g
s
.52757 .6947 m .52459 .64166 L .54854 .63226 L p .707 .577 .707 r
F P
0 g
s
.51083 .80663 m .50915 .78976 L .5159 .77444 L p .707 .577 .707 r
F P
0 g
s
.51475 .75907 m .51146 .72521 L .52752 .71106 L p .707 .577 .707 r
F P
0 g
s
.26079 .78065 m .25751 .74679 L .22639 .74596 L p .707 .577 .707 r
F P
0 g
s
.25751 .74679 m .26079 .78065 L .29249 .77676 L p .707 .577 .707 r
F P
0 g
s
.29249 .77676 m .2892 .7429 L .25751 .74679 L p .707 .577 .707 r
F P
0 g
s
.3388 .64827 m .34179 .70131 L .35804 .68978 L p .707 .577 .707 r
F P
0 g
s
.35804 .68978 m .35506 .63674 L .3388 .64827 L p .707 .577 .707 r
F P
0 g
s
.66825 .6295 m .67124 .68253 L .64376 .67748 L p .707 .577 .707 r
F P
0 g
s
.64376 .67748 m .64077 .62445 L .66825 .6295 L p .707 .577 .707 r
F P
0 g
s
.5159 .77444 m .51759 .79131 L .51083 .80663 L p .707 .577 .707 r
F P
0 g
s
.2892 .7429 m .29249 .77676 L .32164 .76853 L p .707 .577 .707 r
F P
0 g
s
.32164 .76853 m .31836 .73467 L .2892 .7429 L p .707 .577 .707 r
F P
0 g
s
.70919 .76467 m .71087 .78155 L .69804 .76868 L p .707 .577 .707 r
F P
0 g
s
.69804 .76868 m .69636 .75181 L .70919 .76467 L p .707 .577 .707 r
F P
0 g
s
.69197 .70304 m .69525 .7369 L .67405 .72733 L p .707 .577 .707 r
F P
0 g
s
.67405 .72733 m .67077 .69347 L .69197 .70304 L p .707 .577 .707 r
F P
0 g
s
.22967 .77982 m .22639 .74596 L .19888 .7405 L p .707 .577 .707 r
F P
0 g
s
.22639 .74596 m .22967 .77982 L .26079 .78065 L p .707 .577 .707 r
F P
0 g
s
.55152 .68529 m .54854 .63226 L .57784 .6259 L p .707 .577 .707 r
F P
0 g
s
.54854 .63226 m .55152 .68529 L .52757 .6947 L p .707 .577 .707 r
F P
0 g
s
.31836 .73467 m .32164 .76853 L .34541 .75676 L p .707 .577 .707 r
F P
0 g
s
.34541 .75676 m .34213 .7229 L .31836 .73467 L p .707 .577 .707 r
F P
0 g
s
.52752 .71106 m .5308 .74493 L .51475 .75907 L p .707 .577 .707 r
F P
0 g
s
.17702 .7051 m .17403 .65207 L .16135 .6412 L p .707 .577 .707 r
F P
0 g
s
.17403 .65207 m .17702 .7051 L .19812 .71347 L p .707 .577 .707 r
F P
0 g
s
.64077 .62445 m .64376 .67748 L .61261 .67624 L p .707 .577 .707 r
F P
0 g
s
.61261 .67624 m .60962 .62321 L .64077 .62445 L p .707 .577 .707 r
F P
0 g
s
.5308 .74493 m .52752 .71106 L .55129 .6993 L p .707 .577 .707 r
F P
0 g
s
.51759 .79131 m .5159 .77444 L .53194 .76012 L p .707 .577 .707 r
F P
0 g
s
.58082 .67893 m .57784 .6259 L .60962 .62321 L p .707 .577 .707 r
F P
0 g
s
.57784 .6259 m .58082 .67893 L .55152 .68529 L p .707 .577 .707 r
F P
0 g
s
.20216 .77436 m .19888 .7405 L .17768 .73093 L p .707 .577 .707 r
F P
0 g
s
.19888 .7405 m .20216 .77436 L .22967 .77982 L p .707 .577 .707 r
F P
0 g
s
.60962 .62321 m .61261 .67624 L .58082 .67893 L p .707 .577 .707 r
F P
0 g
s
.67077 .69347 m .67405 .72733 L .64654 .72186 L p .707 .577 .707 r
F P
0 g
s
.64654 .72186 m .64326 .688 L .67077 .69347 L p .707 .577 .707 r
F P
0 g
s
.35506 .63674 m .35804 .68978 L .36501 .67725 L p .707 .577 .707 r
F P
0 g
s
.36501 .67725 m .36202 .62421 L .35506 .63674 L p .707 .577 .707 r
F P
0 g
s
.26369 .81344 m .262 .79656 L .23088 .79576 L p .707 .577 .707 r
F P
0 g
s
.262 .79656 m .26369 .81344 L .29537 .80946 L p .707 .577 .707 r
F P
0 g
s
.29537 .80946 m .29368 .79259 L .262 .79656 L p .707 .577 .707 r
F P
0 g
s
.29368 .79259 m .29537 .80946 L .32452 .80111 L p .707 .577 .707 r
F P
0 g
s
.32452 .80111 m .32283 .78423 L .29368 .79259 L p .707 .577 .707 r
F P
0 g
s
.69636 .75181 m .69804 .76868 L .67684 .75903 L p .707 .577 .707 r
F P
0 g
s
.67684 .75903 m .67515 .74216 L .69636 .75181 L p .707 .577 .707 r
F P
0 g
s
.53194 .76012 m .53362 .77699 L .51759 .79131 L p .707 .577 .707 r
F P
0 g
s
.34213 .7229 m .34541 .75676 L .36147 .74262 L p .707 .577 .707 r
F P
0 g
s
.36147 .74262 m .35819 .70876 L .34213 .7229 L p .707 .577 .707 r
F P
0 g
s
.23257 .81264 m .23088 .79576 L .20337 .79027 L p .707 .577 .707 r
F P
0 g
s
.23088 .79576 m .23257 .81264 L .26369 .81344 L p .707 .577 .707 r
F P
0 g
s
.16135 .6412 m .16434 .69424 L .17702 .7051 L p .707 .577 .707 r
F P
0 g
s
.55457 .73316 m .55129 .6993 L .58045 .69107 L p .707 .577 .707 r
F P
0 g
s
.55129 .6993 m .55457 .73316 L .5308 .74493 L p .707 .577 .707 r
F P
0 g
s
.32283 .78423 m .32452 .80111 L .34827 .78918 L p .707 .577 .707 r
F P
0 g
s
.34827 .78918 m .34658 .77231 L .32283 .78423 L p .707 .577 .707 r
F P
0 g
s
.16434 .69424 m .16135 .6412 L .15836 .62891 L p .707 .577 .707 r
F P
0 g
s
.64326 .688 m .64654 .72186 L .61542 .72104 L p .707 .577 .707 r
F P
0 g
s
.61542 .72104 m .61214 .68718 L .64326 .688 L p .707 .577 .707 r
F P
0 g
s
.17768 .73093 m .18096 .76479 L .20216 .77436 L p .707 .577 .707 r
F P
0 g
s
.20337 .79027 m .20506 .80714 L .23257 .81264 L p .707 .577 .707 r
F P
0 g
s
.53362 .77699 m .53194 .76012 L .55569 .7482 L p .707 .577 .707 r
F P
0 g
s
.18096 .76479 m .17768 .73093 L .16486 .71819 L p .707 .577 .707 r
F P
0 g
s
.58373 .72493 m .58045 .69107 L .61214 .68718 L p .707 .577 .707 r
F P
0 g
s
.58045 .69107 m .58373 .72493 L .55457 .73316 L p .707 .577 .707 r
F P
0 g
s
.61214 .68718 m .61542 .72104 L .58373 .72493 L p .707 .577 .707 r
F P
0 g
s
.20506 .80714 m .20337 .79027 L .18216 .78062 L p .707 .577 .707 r
F P
0 g
s
.67515 .74216 m .67684 .75903 L .64933 .75354 L p .707 .577 .707 r
F P
0 g
s
.64933 .75354 m .64764 .73667 L .67515 .74216 L p .707 .577 .707 r
F P
0 g
s
.55569 .7482 m .55738 .76507 L .53362 .77699 L p .707 .577 .707 r
F P
0 g
s
.35819 .70876 m .36147 .74262 L .36824 .72748 L p .707 .577 .707 r
F P
0 g
s
.36824 .72748 m .36496 .69362 L .35819 .70876 L p .707 .577 .707 r
F P
0 g
s
.36202 .62421 m .36501 .67725 L .36201 .66495 L p .707 .577 .707 r
F P
0 g
s
.36201 .66495 m .35902 .61192 L .36202 .62421 L p .707 .577 .707 r
F P
0 g
s
.34658 .77231 m .34827 .78918 L .36431 .77486 L p .707 .577 .707 r
F P
0 g
s
.36431 .77486 m .36262 .75799 L .34658 .77231 L p .707 .577 .707 r
F P
0 g
s
.18216 .78062 m .18385 .79749 L .20506 .80714 L p .707 .577 .707 r
F P
0 g
s
.55738 .76507 m .55569 .7482 L .58484 .73984 L p .707 .577 .707 r
F P
0 g
s
.16486 .71819 m .16815 .75205 L .18096 .76479 L p .707 .577 .707 r
F P
0 g
s
.15836 .62891 m .16134 .68194 L .16434 .69424 L p .707 .577 .707 r
F P
0 g
s
.64764 .73667 m .64933 .75354 L .61821 .75274 L p .707 .577 .707 r
F P
0 g
s
.61821 .75274 m .61652 .73587 L .64764 .73667 L p .707 .577 .707 r
F P
0 g
s
.5072 .24653 m .44966 .76431 L .49355 .7691 L p .707 .577 .707 r
F P
0 g
s
.49355 .7691 m .55109 .25131 L .5072 .24653 L p .707 .577 .707 r
F P
0 g
s
.55109 .25131 m .49355 .7691 L .53815 .7741 L p .707 .577 .707 r
F P
0 g
s
.16134 .68194 m .15836 .62891 L .16532 .61638 L p .707 .577 .707 r
F P
0 g
s
.18385 .79749 m .18216 .78062 L .16933 .76776 L p .707 .577 .707 r
F P
0 g
s
.58484 .73984 m .58652 .75671 L .55738 .76507 L p .707 .577 .707 r
F P
0 g
s
.53815 .7741 m .59569 .25632 L .55109 .25131 L p .707 .577 .707 r
F P
0 g
s
.59569 .25632 m .53815 .7741 L .5791 .77883 L p .707 .577 .707 r
F P
0 g
s
.16815 .75205 m .16486 .71819 L .16169 .70353 L p .707 .577 .707 r
F P
0 g
s
.58652 .75671 m .58484 .73984 L .61652 .73587 L p .707 .577 .707 r
F P
0 g
s
.61652 .73587 m .61821 .75274 L .58652 .75671 L p .707 .577 .707 r
F P
0 g
s
.46832 .24243 m .41078 .76021 L .44966 .76431 L p .707 .577 .707 r
F P
0 g
s
.44966 .76431 m .5072 .24653 L .46832 .24243 L p .707 .577 .707 r
F P
0 g
s
.5791 .77883 m .63664 .26105 L .59569 .25632 L p .707 .577 .707 r
F P
0 g
s
.36262 .75799 m .36431 .77486 L .37106 .75955 L p .707 .577 .707 r
F P
0 g
s
.37106 .75955 m .36937 .74267 L .36262 .75799 L p .707 .577 .707 r
F P
0 g
s
.16933 .76776 m .17102 .78463 L .18385 .79749 L p .707 .577 .707 r
F P
0 g
s
.36496 .69362 m .36824 .72748 L .36506 .71282 L p .707 .577 .707 r
F P
0 g
s
.36506 .71282 m .36178 .67896 L .36496 .69362 L p .707 .577 .707 r
F P
0 g
s
.35902 .61192 m .36201 .66495 L .34934 .65409 L p .707 .577 .707 r
F P
0 g
s
.34934 .65409 m .34635 .60105 L .35902 .61192 L p .707 .577 .707 r
F P
0 g
s
.16169 .70353 m .16497 .7374 L .16815 .75205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63664 .26105 m .5791 .77883 L .61238 .78283 L p .707 .577 .707 r
F P
0 g
s
.16532 .61638 m .16831 .66941 L .16134 .68194 L p .707 .577 .707 r
F P
0 g
s
.61238 .78283 m .66992 .26504 L .63664 .26105 L p .707 .577 .707 r
F P
0 g
s
.17102 .78463 m .16933 .76776 L .16614 .75294 L p .707 .577 .707 r
F P
0 g
s
.43825 .23942 m .38071 .7572 L .41078 .76021 L p .707 .577 .707 r
F P
0 g
s
.41078 .76021 m .46832 .24243 L .43825 .23942 L p .707 .577 .707 r
F P
0 g
s
.16831 .66941 m .16532 .61638 L .18158 .60485 L p .707 .577 .707 r
F P
0 g
s
.16497 .7374 m .16169 .70353 L .16845 .68839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16614 .75294 m .16782 .76982 L .17102 .78463 L p .707 .577 .707 r
F P
0 g
s
.36937 .74267 m .37106 .75955 L .36786 .74473 L p .707 .577 .707 r
F P
0 g
s
.36786 .74473 m .36618 .72786 L .36937 .74267 L p .707 .577 .707 r
F P
0 g
s
.36178 .67896 m .36506 .71282 L .35224 .70008 L p .707 .577 .707 r
F P
0 g
s
.35224 .70008 m .34896 .66622 L .36178 .67896 L p .707 .577 .707 r
F P
0 g
s
.34635 .60105 m .34934 .65409 L .32823 .64572 L p .707 .577 .707 r
F P
0 g
s
.32823 .64572 m .32524 .59268 L .34635 .60105 L p .707 .577 .707 r
F P
0 g
s
.16845 .68839 m .17174 .72225 L .16497 .7374 L p .707 .577 .707 r
F P
0 g
s
.66992 .26504 m .61238 .78283 L .63474 .7857 L p .707 .577 .707 r
F P
0 g
s
.18158 .60485 m .18457 .65788 L .16831 .66941 L p .707 .577 .707 r
F P
0 g
s
.18457 .65788 m .18158 .60485 L .20553 .59544 L p .707 .577 .707 r
F P
0 g
s
.16782 .76982 m .16614 .75294 L .17289 .73763 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .69228 .26791 L .66992 .26504 L p .707 .577 .707 r
F P
0 g
s
.17174 .72225 m .16845 .68839 L .18451 .67425 L p .707 .577 .707 r
F P
0 g
s
.36618 .72786 m .36786 .74473 L .35504 .73187 L p .707 .577 .707 r
F P
0 g
s
.35504 .73187 m .35335 .71499 L .36618 .72786 L p .707 .577 .707 r
F P
0 g
s
.41993 .23779 m .3624 .75557 L .38071 .7572 L p .707 .577 .707 r
F P
0 g
s
.38071 .7572 m .43825 .23942 L .41993 .23779 L p .707 .577 .707 r
F P
0 g
s
.32524 .59268 m .32823 .64572 L .30075 .64067 L p .707 .577 .707 r
F P
0 g
s
.30075 .64067 m .29777 .58763 L .32524 .59268 L p .707 .577 .707 r
F P
0 g
s
.17289 .73763 m .17458 .7545 L .16782 .76982 L p .707 .577 .707 r
F P
0 g
s
.34896 .66622 m .35224 .70008 L .33104 .69052 L p .707 .577 .707 r
F P
0 g
s
.33104 .69052 m .32776 .65665 L .34896 .66622 L p .707 .577 .707 r
F P
0 g
s
.20851 .64848 m .20553 .59544 L .23483 .58908 L p .707 .577 .707 r
F P
0 g
s
.20553 .59544 m .20851 .64848 L .18457 .65788 L p .707 .577 .707 r
F P
0 g
s
.18451 .67425 m .18779 .70811 L .17174 .72225 L p .707 .577 .707 r
F P
0 g
s
.29777 .58763 m .30075 .64067 L .2696 .63943 L p .707 .577 .707 r
F P
0 g
s
.2696 .63943 m .26661 .58639 L .29777 .58763 L p .707 .577 .707 r
F P
0 g
s
.18779 .70811 m .18451 .67425 L .20828 .66248 L p .707 .577 .707 r
F P
0 g
s
.17458 .7545 m .17289 .73763 L .18893 .7233 L p .707 .577 .707 r
F P
0 g
s
.23782 .64212 m .23483 .58908 L .26661 .58639 L p .707 .577 .707 r
F P
0 g
s
.23483 .58908 m .23782 .64212 L .20851 .64848 L p .707 .577 .707 r
F P
0 g
s
.26661 .58639 m .2696 .63943 L .23782 .64212 L p .707 .577 .707 r
F P
0 g
s
.32776 .65665 m .33104 .69052 L .30353 .68505 L p .707 .577 .707 r
F P
0 g
s
.30353 .68505 m .30025 .65119 L .32776 .65665 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .64399 .78716 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.64399 .78716 m .63923 .78707 L p .65376 .66634 L .707 .577 .707 r
F P
0 g
s
.65376 .66634 m .65435 .66424 L .64399 .78716 L .707 .577 .707 r
F
.66419 .6073 m .66369 .6071 L p .664 .60829 L F P
0 g
s
.67834 .66476 m .66369 .6071 L .66364 .62731 L .707 .577 .707 r
F
.64399 .78716 m .70153 .26937 L .69228 .26791 L p F P
0 g
s
.65516 .65467 m .65668 .64668 L .64399 .78716 L .707 .577 .707 r
F
.66369 .60991 m .6621 .62419 L p .65668 .64668 L F P
0 g
s
.6621 .62419 m .64399 .78716 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.66392 .52315 m .63474 .7857 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.65424 .60336 m .64157 .59249 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.65668 .64668 m .65424 .60336 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.66369 .6071 m .65424 .60336 L p .66144 .6217 L .707 .577 .707 r
F P
0 g
s
.66364 .62731 m .66369 .60991 L .66144 .6217 L .707 .577 .707 r
F
.66369 .60991 m .66369 .6071 L .66144 .6217 L F
.65424 .60336 m .65723 .65639 L .67834 .66476 L p F P
0 g
s
.64157 .59249 m .64456 .64553 L .65484 .65434 L p .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65549 .65164 L .65556 .65133 L .707 .577 .707 r
F
.65577 .65045 m .64157 .59249 L .65484 .65434 L F
.69228 .26791 m .66392 .52315 L p .66378 .57436 L F P
0 g
s
.65223 .67006 m .69676 .26929 L p .65516 .65467 L .707 .577 .707 r
F P
0 g
s
.70153 .26937 m .66369 .60991 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65556 .65133 L .65668 .64668 L .707 .577 .707 r
F
.65556 .65133 m .70153 .26937 L .65668 .64668 L F
.65484 .65434 m .65723 .65639 L p .65577 .65045 L F P
0 g
s
.69676 .26929 m .70153 .26937 L p .65556 .65133 L .707 .577 .707 r
F P
0 g
s
.65549 .65164 m .69676 .26929 L .65556 .65133 L .707 .577 .707 r
F
.63923 .78707 m .65223 .67006 L p .65516 .65467 L F P
0 g
s
.65723 .65639 m .65668 .64668 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.64456 .64553 m .64157 .59249 L .63857 .58019 L p .707 .577 .707 r
F P
0 g
s
.63923 .78707 m .62091 .78544 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.63857 .58019 m .64084 .62051 L p .64456 .64553 L .707 .577 .707 r
F P
0 g
s
.64314 .6397 m .64456 .64553 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.69676 .26929 m .6496 .69374 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.6496 .69374 m .63923 .78707 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .69676 .26929 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .63857 .58019 L .64396 .5705 L p .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .64311 .58569 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.64396 .5705 m .64412 .57021 L p .64311 .58569 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64396 .5705 L .64311 .58569 L .707 .577 .707 r
F
.62091 .78544 m .59084 .78243 L p .65229 .4214 L F P
0 g
s
.64311 .58569 m .62091 .78544 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.62091 .78544 m .64311 .58569 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64311 .58569 m .67845 .26766 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64156 .63323 L .64314 .6397 L p .707 .577 .707 r
F P
0 g
s
.64156 .63323 m .64084 .62051 L p .64554 .56766 L .707 .577 .707 r
F P
0 g
s
.64412 .57021 m .64554 .56766 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .6579 .69221 L .64893 .6833 L p .707 .577 .707 r
F P
0 g
s
.64893 .6833 m .64508 .67947 L p .64779 .68731 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .64893 .6833 L .64779 .68731 L .707 .577 .707 r
F
.65376 .66634 m .65516 .65467 L .65435 .66424 L F
.67834 .66476 m .67535 .61172 L .66419 .6073 L p F P
0 g
s
.67834 .66476 m .66419 .6073 L .664 .60829 L .707 .577 .707 r
F
.35335 .71499 m .35504 .73187 L .33383 .72222 L p F P
0 g
s
.33383 .72222 m .33214 .70534 L .35335 .71499 L p .707 .577 .707 r
F P
0 g
s
.18893 .7233 m .19061 .74018 L .17458 .7545 L p .707 .577 .707 r
F P
0 g
s
.21156 .69635 m .20828 .66248 L .23744 .65425 L p .707 .577 .707 r
F P
0 g
s
.20828 .66248 m .21156 .69635 L .18779 .70811 L p .707 .577 .707 r
F P
0 g
s
.73697 .67105 m .73398 .61802 L .70283 .61677 L p .707 .577 .707 r
F P
0 g
s
.73398 .61802 m .73697 .67105 L .76875 .66836 L p .707 .577 .707 r
F P
0 g
s
.76875 .66836 m .76576 .61532 L .73398 .61802 L p .707 .577 .707 r
F P
0 g
s
.76576 .61532 m .76875 .66836 L .79805 .662 L p .707 .577 .707 r
F P
0 g
s
.79805 .662 m .79506 .60897 L .76576 .61532 L p .707 .577 .707 r
F P
0 g
s
.30025 .65119 m .30353 .68505 L .27241 .68422 L p .707 .577 .707 r
F P
0 g
s
.27241 .68422 m .26913 .65036 L .30025 .65119 L p .707 .577 .707 r
F P
0 g
s
.41517 .2377 m .35763 .75548 L .3624 .75557 L p .707 .577 .707 r
F P
0 g
s
.3624 .75557 m .41993 .23779 L .41517 .2377 L p .707 .577 .707 r
F P
0 g
s
.70581 .66981 m .70283 .61677 L .67535 .61172 L p .707 .577 .707 r
F P
0 g
s
.70283 .61677 m .70581 .66981 L .73697 .67105 L p .707 .577 .707 r
F P
0 g
s
.19061 .74018 m .18893 .7233 L .21268 .71138 L p .707 .577 .707 r
F P
0 g
s
.24072 .68811 m .23744 .65425 L .26913 .65036 L p .707 .577 .707 r
F P
0 g
s
.23744 .65425 m .24072 .68811 L .21156 .69635 L p .707 .577 .707 r
F P
0 g
s
.26913 .65036 m .27241 .68422 L .24072 .68811 L p .707 .577 .707 r
F P
0 g
s
.79506 .60897 m .79805 .662 L .822 .6526 L p .707 .577 .707 r
F P
0 g
s
.822 .6526 m .81901 .59956 L .79506 .60897 L p .707 .577 .707 r
F P
0 g
s
.33214 .70534 m .33383 .72222 L .30632 .71672 L p .707 .577 .707 r
F P
0 g
s
.30632 .71672 m .30463 .69985 L .33214 .70534 L p .707 .577 .707 r
F P
0 g
s
.21268 .71138 m .21437 .72826 L .19061 .74018 L p .707 .577 .707 r
F P
0 g
s
.67535 .61172 m .67834 .66476 L .70581 .66981 L p .707 .577 .707 r
F P
0 g
s
.21437 .72826 m .21268 .71138 L .24183 .70302 L p .707 .577 .707 r
F P
0 g
s
.30463 .69985 m .30632 .71672 L .2752 .71593 L p .707 .577 .707 r
F P
0 g
s
.2752 .71593 m .27351 .69905 L .30463 .69985 L p .707 .577 .707 r
F P
0 g
s
.81901 .59956 m .822 .6526 L .83826 .64106 L p .707 .577 .707 r
F P
0 g
s
.83826 .64106 m .83527 .58803 L .81901 .59956 L p .707 .577 .707 r
F P
0 g
s
.24183 .70302 m .24351 .7199 L .21437 .72826 L p .707 .577 .707 r
F P
0 g
s
.74101 .74193 m .73773 .70807 L .7066 .70725 L p .707 .577 .707 r
F P
0 g
s
.73773 .70807 m .74101 .74193 L .7727 .73804 L p .707 .577 .707 r
F P
0 g
s
.7727 .73804 m .76942 .70418 L .73773 .70807 L p .707 .577 .707 r
F P
0 g
s
.24351 .7199 m .24183 .70302 L .27351 .69905 L p .707 .577 .707 r
F P
0 g
s
.76942 .70418 m .7727 .73804 L .80186 .72981 L p .707 .577 .707 r
F P
0 g
s
.80186 .72981 m .79857 .69595 L .76942 .70418 L p .707 .577 .707 r
F P
0 g
s
.27351 .69905 m .2752 .71593 L .24351 .7199 L p .707 .577 .707 r
F P
0 g
s
.70988 .74111 m .7066 .70725 L .6791 .70178 L p .707 .577 .707 r
F P
0 g
s
.7066 .70725 m .70988 .74111 L .74101 .74193 L p .707 .577 .707 r
F P
0 g
s
.79857 .69595 m .80186 .72981 L .82563 .71805 L p .707 .577 .707 r
F P
0 g
s
.82563 .71805 m .82234 .68419 L .79857 .69595 L p .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .36688 .75695 L .35763 .75548 L p .707 .577 .707 r
F P
0 g
s
.35763 .75548 m .41517 .2377 L .42442 .23916 L p .707 .577 .707 r
F P
0 g
s
.83527 .58803 m .83826 .64106 L .84522 .62854 L p .707 .577 .707 r
F P
0 g
s
.84522 .62854 m .84224 .5755 L .83527 .58803 L p .707 .577 .707 r
F P
0 g
s
.68238 .73564 m .6791 .70178 L .6579 .69221 L p .707 .577 .707 r
F P
0 g
s
.6791 .70178 m .68238 .73564 L .70988 .74111 L p .707 .577 .707 r
F P
0 g
s
.82234 .68419 m .82563 .71805 L .84168 .7039 L p .707 .577 .707 r
F P
0 g
s
.84168 .7039 m .8384 .67004 L .82234 .68419 L p .707 .577 .707 r
F P
0 g
s
.7439 .79056 m .74221 .77369 L .71109 .77289 L p .707 .577 .707 r
F P
0 g
s
.74221 .77369 m .7439 .79056 L .77558 .78659 L p .707 .577 .707 r
F P
0 g
s
.77558 .78659 m .7739 .76971 L .74221 .77369 L p .707 .577 .707 r
F P
0 g
s
.7739 .76971 m .77558 .78659 L .80473 .77823 L p .707 .577 .707 r
F P
0 g
s
.80473 .77823 m .80304 .76136 L .7739 .76971 L p .707 .577 .707 r
F P
0 g
s
.71278 .78976 m .71109 .77289 L .68358 .76739 L p .707 .577 .707 r
F P
0 g
s
.71109 .77289 m .71278 .78976 L .7439 .79056 L p .707 .577 .707 r
F P
0 g
s
.6579 .69221 m .66118 .72607 L .68238 .73564 L p .707 .577 .707 r
F P
0 g
s
.80304 .76136 m .80473 .77823 L .82848 .76631 L p .707 .577 .707 r
F P
0 g
s
.82848 .76631 m .8268 .74943 L .80304 .76136 L p .707 .577 .707 r
F P
0 g
s
.68358 .76739 m .68527 .78427 L .71278 .78976 L p .707 .577 .707 r
F P
0 g
s
.84224 .5755 m .84522 .62854 L .84223 .61624 L p .707 .577 .707 r
F P
0 g
s
.84223 .61624 m .83924 .5632 L .84224 .5755 L p .707 .577 .707 r
F P
0 g
s
.68527 .78427 m .68358 .76739 L .66238 .75774 L p .707 .577 .707 r
F P
0 g
s
.8384 .67004 m .84168 .7039 L .84845 .68876 L p .707 .577 .707 r
F P
0 g
s
.84845 .68876 m .84517 .6549 L .8384 .67004 L p .707 .577 .707 r
F P
0 g
s
.38924 .75982 m .36688 .75695 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.40894 .58257 m .38924 .75982 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .44678 .24203 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.36688 .75695 m .39606 .4944 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.39606 .4944 m .42442 .23916 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .38924 .75982 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .40852 .57971 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42275 .57851 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .42519 .62184 L p .45504 .62519 L .707 .577 .707 r
F P
0 g
s
.43654 .63772 m .43553 .6468 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.43553 .6468 m .42253 .76381 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42574 .63155 L .43127 .63034 L p .707 .577 .707 r
F P
0 g
s
.43127 .63034 m .45504 .62519 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.45504 .62519 m .45205 .57215 L .42275 .57851 L p .707 .577 .707 r
F P
0 g
s
.48006 .24603 m .43654 .63772 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.41709 .60227 m .43654 .63772 L .42519 .62184 L .707 .577 .707 r
F
.44678 .24203 m .48006 .24603 L p .41709 .60227 L F P
0 g
s
.38924 .75982 m .40894 .58257 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .40852 .57971 L .41351 .61383 L .707 .577 .707 r
F
.40894 .58257 m .44678 .24203 L p .41709 .60227 L F P
0 g
s
.41351 .61383 m .40894 .58257 L .39097 .5812 L .707 .577 .707 r
F
.40852 .57971 m .40778 .57978 L p .40894 .58257 L F P
0 g
s
.40778 .57978 m .39097 .5812 L p .40894 .58257 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .42519 .62184 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.39097 .5812 m .39396 .63424 L .41621 .63235 L p .707 .577 .707 r
F P
0 g
s
.41621 .63235 m .42574 .63155 L p .41351 .61383 L .707 .577 .707 r
F P
0 g
s
.41351 .61383 m .39097 .5812 L .41621 .63235 L .707 .577 .707 r
F
.44678 .24203 m .40894 .58257 L p .40167 .53279 L F P
0 g
s
.8268 .74943 m .82848 .76631 L .84452 .75199 L p .707 .577 .707 r
F P
0 g
s
.84452 .75199 m .84284 .73511 L .8268 .74943 L p .707 .577 .707 r
F P
0 g
s
.66238 .75774 m .66406 .77462 L .68527 .78427 L p .707 .577 .707 r
F P
0 g
s
.64508 .67947 m .64836 .71334 L .66118 .72607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64836 .71334 m .64508 .67947 L .6419 .66482 L p .707 .577 .707 r
F P
0 g
s
.66406 .77462 m .66238 .75774 L .64955 .74488 L p .707 .577 .707 r
F P
0 g
s
.83924 .5632 m .84223 .61624 L .82955 .60537 L p .707 .577 .707 r
F P
0 g
s
.82955 .60537 m .82656 .55234 L .83924 .5632 L p .707 .577 .707 r
F P
0 g
s
.84517 .6549 m .84845 .68876 L .84527 .6741 L p .707 .577 .707 r
F P
0 g
s
.84527 .6741 m .84199 .64024 L .84517 .6549 L p .707 .577 .707 r
F P
0 g
s
.84284 .73511 m .84452 .75199 L .85127 .73667 L p .707 .577 .707 r
F P
0 g
s
.85127 .73667 m .84959 .7198 L .84284 .73511 L p .707 .577 .707 r
F P
0 g
s
.64955 .74488 m .65123 .76176 L .66406 .77462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6419 .66482 m .64518 .69868 L .64836 .71334 L p .707 .577 .707 r
F P
0 g
s
.64554 .56766 m .64852 .6207 L .64156 .63323 L p .707 .577 .707 r
F P
0 g
s
.59084 .78243 m .64838 .26465 L .67845 .26766 L p .707 .577 .707 r
F P
0 g
s
.64852 .6207 m .64554 .56766 L .66179 .55613 L p .707 .577 .707 r
F P
0 g
s
.39396 .63424 m .39097 .5812 L .35982 .57996 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64518 .69868 m .6419 .66482 L .64867 .64968 L p .707 .577 .707 r
F P
0 g
s
.65123 .76176 m .64955 .74488 L .64635 .73007 L p .707 .577 .707 r
F P
0 g
s
.3628 .63299 m .35982 .57996 L .33234 .57491 L p .707 .577 .707 r
F P
0 g
s
.35982 .57996 m .3628 .63299 L .39396 .63424 L p .707 .577 .707 r
F P
0 g
s
.82656 .55234 m .82955 .60537 L .80844 .59701 L p .707 .577 .707 r
F P
0 g
s
.80844 .59701 m .80546 .54397 L .82656 .55234 L p .707 .577 .707 r
F P
0 g
s
.84199 .64024 m .84527 .6741 L .83246 .66137 L p .707 .577 .707 r
F P
0 g
s
.83246 .66137 m .82917 .62751 L .84199 .64024 L p .707 .577 .707 r
F P
0 g
s
.64635 .73007 m .64804 .74694 L .65123 .76176 L p .707 .577 .707 r
F P
0 g
s
.84959 .7198 m .85127 .73667 L .84808 .72185 L p .707 .577 .707 r
F P
0 g
s
.84808 .72185 m .84639 .70498 L .84959 .7198 L p .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .42253 .76381 L p .44345 .6548 L .707 .577 .707 r
F P
0 g
s
.45205 .57215 m .45504 .62519 L .46638 .62073 L p .707 .577 .707 r
F P
0 g
s
.47455 .60859 m .45205 .57215 L .46638 .62073 L .707 .577 .707 r
F
.48257 .59668 m .46347 .76854 L p .45408 .71521 L F P
0 g
s
.44345 .6548 m .47828 .60306 L .45408 .71521 L .707 .577 .707 r
F
.47828 .60306 m .48257 .59668 L .45408 .71521 L F
.476 .56274 m .47828 .60306 L p .48349 .57889 L F P
0 g
s
.476 .56274 m .45205 .57215 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47899 .61578 m .47828 .60306 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47828 .60306 m .476 .56274 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .48075 .61308 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .46347 .76854 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.56561 .25576 m .53865 .49838 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.53865 .49838 m .50807 .77355 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .47933 .64737 L .45814 .65786 L p .707 .577 .707 r
F P
0 g
s
.45814 .65786 m .45556 .65913 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .45814 .65786 L .45693 .66025 L .707 .577 .707 r
F
.45885 .693 m .48262 .68123 L p .45693 .66025 L F P
0 g
s
.45556 .65913 m .45588 .66235 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.45588 .66235 m .45885 .693 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.50336 .56829 m .48567 .56879 L .56561 .25576 L .707 .577 .707 r
F
.48075 .61308 m .48567 .56879 L p .50336 .56829 L F P
0 g
s
.48858 .55383 m .476 .56274 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .52101 .25076 L .54693 .25367 L p .707 .577 .707 r
F P
0 g
s
.54693 .25367 m .56561 .25576 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48349 .57889 m .48567 .56879 L .476 .56274 L .707 .577 .707 r
F
.48895 .55356 m .48858 .55383 L p .48567 .56879 L F P
0 g
s
.49525 .60425 m .49226 .55121 L .48895 .55356 L p .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .48257 .59668 L p .47828 .60306 L .707 .577 .707 r
F P
0 g
s
.49525 .60425 m .48895 .55356 L .48349 .57889 L .707 .577 .707 r
F
.52101 .25076 m .48567 .56879 L p .44345 .6548 L F P
0 g
s
.44345 .6548 m .48567 .56879 L .47828 .60306 L .707 .577 .707 r
F
.47899 .61578 m .49525 .60425 L p .48349 .57889 L F P
0 g
s
.47828 .60306 m .47899 .61578 L p .48349 .57889 L .707 .577 .707 r
F P
0 g
s
.46638 .62073 m .47899 .61578 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.64867 .64968 m .65195 .68354 L .64518 .69868 L p .707 .577 .707 r
F P
0 g
s
.66179 .55613 m .66478 .60917 L .64852 .6207 L p .707 .577 .707 r
F P
0 g
s
.64838 .26465 m .59084 .78243 L .55196 .77833 L p .707 .577 .707 r
F P
0 g
s
.33533 .62794 m .33234 .57491 L .31123 .56654 L p .707 .577 .707 r
F P
0 g
s
.33234 .57491 m .33533 .62794 L .3628 .63299 L p .707 .577 .707 r
F P
0 g
s
.66478 .60917 m .66179 .55613 L .68574 .54673 L p .707 .577 .707 r
F P
0 g
s
.55196 .77833 m .6095 .26055 L .64838 .26465 L p .707 .577 .707 r
F P
0 g
s
.65195 .68354 m .64867 .64968 L .66472 .63553 L p .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .48006 .24603 L .52101 .25076 L p .707 .577 .707 r
F P
0 g
s
.64804 .74694 m .64635 .73007 L .6531 .71475 L p .707 .577 .707 r
F P
0 g
s
.80546 .54397 m .80844 .59701 L .78097 .59195 L p .707 .577 .707 r
F P
0 g
s
.78097 .59195 m .77798 .53892 L .80546 .54397 L p .707 .577 .707 r
F P
0 g
s
.398 .70512 m .39472 .67126 L .36359 .67043 L p .707 .577 .707 r
F P
0 g
s
.39472 .67126 m .398 .70512 L .42969 .70123 L p .707 .577 .707 r
F P
0 g
s
.42969 .70123 m .42641 .66737 L .39472 .67126 L p .707 .577 .707 r
F P
0 g
s
.42641 .66737 m .42969 .70123 L .45885 .693 L p .707 .577 .707 r
F P
0 g
s
.45885 .693 m .45556 .65913 L .42641 .66737 L p .707 .577 .707 r
F P
0 g
s
.82917 .62751 m .83246 .66137 L .81126 .6518 L p .707 .577 .707 r
F P
0 g
s
.81126 .6518 m .80797 .61794 L .82917 .62751 L p .707 .577 .707 r
F P
0 g
s
.6531 .71475 m .65479 .73162 L .64804 .74694 L p .707 .577 .707 r
F P
0 g
s
.84639 .70498 m .84808 .72185 L .83525 .70899 L p .707 .577 .707 r
F P
0 g
s
.83525 .70899 m .83356 .69212 L .84639 .70498 L p .707 .577 .707 r
F P
0 g
s
.36687 .70429 m .36359 .67043 L .33608 .66496 L p .707 .577 .707 r
F P
0 g
s
.36359 .67043 m .36687 .70429 L .398 .70512 L p .707 .577 .707 r
F P
0 g
s
.68873 .59976 m .68574 .54673 L .71504 .54037 L p .707 .577 .707 r
F P
0 g
s
.68574 .54673 m .68873 .59976 L .66478 .60917 L p .707 .577 .707 r
F P
0 g
s
.6095 .26055 m .55196 .77833 L .50807 .77355 L p .707 .577 .707 r
F P
0 g
s
.31422 .61958 m .31123 .56654 L .29856 .55568 L p .707 .577 .707 r
F P
0 g
s
.31123 .56654 m .31422 .61958 L .33533 .62794 L p .707 .577 .707 r
F P
0 g
s
.66472 .63553 m .66801 .66939 L .65195 .68354 L p .707 .577 .707 r
F P
0 g
s
.77798 .53892 m .78097 .59195 L .74981 .59071 L p .707 .577 .707 r
F P
0 g
s
.74981 .59071 m .74682 .53768 L .77798 .53892 L p .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .56561 .25576 L .6095 .26055 L p .707 .577 .707 r
F P
0 g
s
.66801 .66939 m .66472 .63553 L .68849 .62377 L p .707 .577 .707 r
F P
0 g
s
.71803 .5934 m .71504 .54037 L .74682 .53768 L p .707 .577 .707 r
F P
0 g
s
.71504 .54037 m .71803 .5934 L .68873 .59976 L p .707 .577 .707 r
F P
0 g
s
.74682 .53768 m .74981 .59071 L .71803 .5934 L p .707 .577 .707 r
F P
0 g
s
.49226 .55121 m .49525 .60425 L .50221 .59172 L p .707 .577 .707 r
F P
0 g
s
.50221 .59172 m .49923 .53869 L .49226 .55121 L p .707 .577 .707 r
F P
0 g
s
.33937 .69883 m .33608 .66496 L .31488 .6554 L p .707 .577 .707 r
F P
0 g
s
.33608 .66496 m .33937 .69883 L .36687 .70429 L p .707 .577 .707 r
F P
0 g
s
.65479 .73162 m .6531 .71475 L .66914 .70043 L p .707 .577 .707 r
F P
0 g
s
.80797 .61794 m .81126 .6518 L .78375 .64633 L p .707 .577 .707 r
F P
0 g
s
.78375 .64633 m .78047 .61247 L .80797 .61794 L p .707 .577 .707 r
F P
0 g
s
.47933 .64737 m .48262 .68123 L .49867 .66709 L p .707 .577 .707 r
F P
0 g
s
.49867 .66709 m .49539 .63322 L .47933 .64737 L p .707 .577 .707 r
F P
0 g
s
.40089 .75375 m .3992 .73687 L .36808 .73607 L p .707 .577 .707 r
F P
0 g
s
.3992 .73687 m .40089 .75375 L .43257 .74977 L p .707 .577 .707 r
F P
0 g
s
.43257 .74977 m .43089 .7329 L .3992 .73687 L p .707 .577 .707 r
F P
0 g
s
.43089 .7329 m .43257 .74977 L .46172 .74142 L p .707 .577 .707 r
F P
0 g
s
.46172 .74142 m .46003 .72454 L .43089 .7329 L p .707 .577 .707 r
F P
0 g
s
.83356 .69212 m .83525 .70899 L .81404 .69934 L p .707 .577 .707 r
F P
0 g
s
.81404 .69934 m .81236 .68247 L .83356 .69212 L p .707 .577 .707 r
F P
0 g
s
.29856 .55568 m .30154 .60871 L .31422 .61958 L p .707 .577 .707 r
F P
0 g
s
.66914 .70043 m .67083 .7173 L .65479 .73162 L p .707 .577 .707 r
F P
0 g
s
.69178 .65763 m .68849 .62377 L .71765 .61554 L p .707 .577 .707 r
F P
0 g
s
.68849 .62377 m .69178 .65763 L .66801 .66939 L p .707 .577 .707 r
F P
0 g
s
.36977 .75295 m .36808 .73607 L .34057 .73058 L p .707 .577 .707 r
F P
0 g
s
.36808 .73607 m .36977 .75295 L .40089 .75375 L p .707 .577 .707 r
F P
0 g
s
.30154 .60871 m .29856 .55568 L .29556 .54338 L p .707 .577 .707 r
F P
0 g
s
.78047 .61247 m .78375 .64633 L .75263 .64551 L p .707 .577 .707 r
F P
0 g
s
.75263 .64551 m .74934 .61164 L .78047 .61247 L p .707 .577 .707 r
F P
0 g
s
.31488 .6554 m .31817 .68926 L .33937 .69883 L p .707 .577 .707 r
F P
0 g
s
.46003 .72454 m .46172 .74142 L .48547 .72949 L p .707 .577 .707 r
F P
0 g
s
.48547 .72949 m .48379 .71262 L .46003 .72454 L p .707 .577 .707 r
F P
0 g
s
.31817 .68926 m .31488 .6554 L .30207 .64266 L p .707 .577 .707 r
F P
0 g
s
.72093 .6494 m .71765 .61554 L .74934 .61164 L p .707 .577 .707 r
F P
0 g
s
.71765 .61554 m .72093 .6494 L .69178 .65763 L p .707 .577 .707 r
F P
0 g
s
.34057 .73058 m .34226 .74745 L .36977 .75295 L p .707 .577 .707 r
F P
0 g
s
.67083 .7173 m .66914 .70043 L .6929 .68851 L p .707 .577 .707 r
F P
0 g
s
.74934 .61164 m .75263 .64551 L .72093 .6494 L p .707 .577 .707 r
F P
0 g
s
.49923 .53869 m .50221 .59172 L .49921 .57942 L p .707 .577 .707 r
F P
0 g
s
.49921 .57942 m .49623 .52639 L .49923 .53869 L p .707 .577 .707 r
F P
0 g
s
.34226 .74745 m .34057 .73058 L .31937 .72093 L p .707 .577 .707 r
F P
0 g
s
.49539 .63322 m .49867 .66709 L .50544 .65194 L p .707 .577 .707 r
F P
0 g
s
.50544 .65194 m .50216 .61808 L .49539 .63322 L p .707 .577 .707 r
F P
0 g
s
.81236 .68247 m .81404 .69934 L .78653 .69385 L p .707 .577 .707 r
F P
0 g
s
.78653 .69385 m .78485 .67698 L .81236 .68247 L p .707 .577 .707 r
F P
0 g
s
.6929 .68851 m .69458 .70538 L .67083 .7173 L p .707 .577 .707 r
F P
0 g
s
.48379 .71262 m .48547 .72949 L .50151 .71517 L p .707 .577 .707 r
F P
0 g
s
.50151 .71517 m .49983 .6983 L .48379 .71262 L p .707 .577 .707 r
F P
0 g
s
.29556 .54338 m .29855 .59641 L .30154 .60871 L p .707 .577 .707 r
F P
0 g
s
.31937 .72093 m .32105 .7378 L .34226 .74745 L p .707 .577 .707 r
F P
0 g
s
.30207 .64266 m .30535 .67652 L .31817 .68926 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.69458 .70538 m .6929 .68851 L .72204 .68015 L p .707 .577 .707 r
F P
0 g
s
.29855 .59641 m .29556 .54338 L .30253 .53085 L p .707 .577 .707 r
F P
0 g
s
.78485 .67698 m .78653 .69385 L .75541 .69305 L p .707 .577 .707 r
F P
0 g
s
.75541 .69305 m .75373 .67618 L .78485 .67698 L p .707 .577 .707 r
F P
0 g
s
.30535 .67652 m .30207 .64266 L .29889 .628 L p .707 .577 .707 r
F P
0 g
s
.32105 .7378 m .31937 .72093 L .30654 .70807 L p .707 .577 .707 r
F P
0 g
s
.72204 .68015 m .72373 .69702 L .69458 .70538 L p .707 .577 .707 r
F P
0 g
s
.72373 .69702 m .72204 .68015 L .75373 .67618 L p .707 .577 .707 r
F P
0 g
s
.75373 .67618 m .75541 .69305 L .72373 .69702 L p .707 .577 .707 r
F P
0 g
s
.49623 .52639 m .49921 .57942 L .48654 .56856 L p .707 .577 .707 r
F P
0 g
s
.48654 .56856 m .48355 .51552 L .49623 .52639 L p .707 .577 .707 r
F P
0 g
s
.50216 .61808 m .50544 .65194 L .50226 .63729 L p .707 .577 .707 r
F P
0 g
s
.50226 .63729 m .49898 .60343 L .50216 .61808 L p .707 .577 .707 r
F P
0 g
s
.49983 .6983 m .50151 .71517 L .50826 .69985 L p .707 .577 .707 r
F P
0 g
s
.50826 .69985 m .50658 .68298 L .49983 .6983 L p .707 .577 .707 r
F P
0 g
s
.30654 .70807 m .30822 .72494 L .32105 .7378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29889 .628 m .30217 .66186 L .30535 .67652 L p .707 .577 .707 r
F P
0 g
s
.30253 .53085 m .30551 .58388 L .29855 .59641 L p .707 .577 .707 r
F P
0 g
s
.30551 .58388 m .30253 .53085 L .31878 .51932 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30217 .66186 m .29889 .628 L .30566 .61286 L p .707 .577 .707 r
F P
0 g
s
.30822 .72494 m .30654 .70807 L .30334 .69325 L p .707 .577 .707 r
F P
0 g
s
.48355 .51552 m .48654 .56856 L .46543 .56019 L p .707 .577 .707 r
F P
0 g
s
.46543 .56019 m .46244 .50715 L .48355 .51552 L p .707 .577 .707 r
F P
0 g
s
.49898 .60343 m .50226 .63729 L .48945 .62455 L p .707 .577 .707 r
F P
0 g
s
.48945 .62455 m .48616 .59069 L .49898 .60343 L p .707 .577 .707 r
F P
0 g
s
.30334 .69325 m .30503 .71013 L .30822 .72494 L p .707 .577 .707 r
F P
0 g
s
.50658 .68298 m .50826 .69985 L .50507 .68504 L p .707 .577 .707 r
F P
0 g
s
.50507 .68504 m .50338 .66817 L .50658 .68298 L p .707 .577 .707 r
F P
0 g
s
.30566 .61286 m .30894 .64672 L .30217 .66186 L p .707 .577 .707 r
F P
0 g
s
.31878 .51932 m .32177 .57235 L .30551 .58388 L p .707 .577 .707 r
F P
0 g
s
.32177 .57235 m .31878 .51932 L .34273 .50991 L p .707 .577 .707 r
F P
0 g
s
.30894 .64672 m .30566 .61286 L .32171 .59872 L p .707 .577 .707 r
F P
0 g
s
.30503 .71013 m .30334 .69325 L .31009 .67793 L p .707 .577 .707 r
F P
0 g
s
.46244 .50715 m .46543 .56019 L .43796 .55514 L p .707 .577 .707 r
F P
0 g
s
.43796 .55514 m .43497 .5021 L .46244 .50715 L p .707 .577 .707 r
F P
0 g
s
.48616 .59069 m .48945 .62455 L .46825 .61498 L p .707 .577 .707 r
F P
0 g
s
.46825 .61498 m .46496 .58112 L .48616 .59069 L p .707 .577 .707 r
F P
0 g
s
.31009 .67793 m .31178 .69481 L .30503 .71013 L p .707 .577 .707 r
F P
0 g
s
.50338 .66817 m .50507 .68504 L .49224 .67218 L p .707 .577 .707 r
F P
0 g
s
.49224 .67218 m .49055 .6553 L .50338 .66817 L p .707 .577 .707 r
F P
0 g
s
.34572 .56295 m .34273 .50991 L .37203 .50355 L p .707 .577 .707 r
F P
0 g
s
.34273 .50991 m .34572 .56295 L .32177 .57235 L p .707 .577 .707 r
F P
0 g
s
.32171 .59872 m .325 .63258 L .30894 .64672 L p .707 .577 .707 r
F P
0 g
s
.43497 .5021 m .43796 .55514 L .4068 .5539 L p .707 .577 .707 r
F P
0 g
s
.4068 .5539 m .40381 .50086 L .43497 .5021 L p .707 .577 .707 r
F P
0 g
s
.325 .63258 m .32171 .59872 L .34548 .58695 L p .707 .577 .707 r
F P
0 g
s
.37502 .55659 m .37203 .50355 L .40381 .50086 L p .707 .577 .707 r
F P
0 g
s
.37203 .50355 m .37502 .55659 L .34572 .56295 L p .707 .577 .707 r
F P
0 g
s
.40381 .50086 m .4068 .5539 L .37502 .55659 L p .707 .577 .707 r
F P
0 g
s
.31178 .69481 m .31009 .67793 L .32613 .66361 L p .707 .577 .707 r
F P
0 g
s
.46496 .58112 m .46825 .61498 L .44074 .60952 L p .707 .577 .707 r
F P
0 g
s
.44074 .60952 m .43746 .57565 L .46496 .58112 L p .707 .577 .707 r
F P
0 g
s
.49055 .6553 m .49224 .67218 L .47103 .66253 L p .707 .577 .707 r
F P
0 g
s
.47103 .66253 m .46935 .64565 L .49055 .6553 L p .707 .577 .707 r
F P
0 g
s
.32613 .66361 m .32782 .68049 L .31178 .69481 L p .707 .577 .707 r
F P
0 g
s
.34877 .62081 m .34548 .58695 L .37464 .57872 L p .707 .577 .707 r
F P
0 g
s
.34548 .58695 m .34877 .62081 L .325 .63258 L p .707 .577 .707 r
F P
0 g
s
.43746 .57565 m .44074 .60952 L .40961 .60869 L p .707 .577 .707 r
F P
0 g
s
.40961 .60869 m .40633 .57483 L .43746 .57565 L p .707 .577 .707 r
F P
0 g
s
.37792 .61258 m .37464 .57872 L .40633 .57483 L p .707 .577 .707 r
F P
0 g
s
.37464 .57872 m .37792 .61258 L .34877 .62081 L p .707 .577 .707 r
F P
0 g
s
.32782 .68049 m .32613 .66361 L .34989 .65169 L p .707 .577 .707 r
F P
0 g
s
.40633 .57483 m .40961 .60869 L .37792 .61258 L p .707 .577 .707 r
F P
0 g
s
.46935 .64565 m .47103 .66253 L .44352 .65703 L p .707 .577 .707 r
F P
0 g
s
.44352 .65703 m .44184 .64016 L .46935 .64565 L p .707 .577 .707 r
F P
0 g
s
.34989 .65169 m .35157 .66856 L .32782 .68049 L p .707 .577 .707 r
F P
0 g
s
.35157 .66856 m .34989 .65169 L .37903 .64333 L p .707 .577 .707 r
F P
0 g
s
.44184 .64016 m .44352 .65703 L .4124 .65623 L p .707 .577 .707 r
F P
0 g
s
.4124 .65623 m .41072 .63936 L .44184 .64016 L p .707 .577 .707 r
F P
0 g
s
.37903 .64333 m .38072 .66021 L .35157 .66856 L p .707 .577 .707 r
F P
0 g
s
.38072 .66021 m .37903 .64333 L .41072 .63936 L p .707 .577 .707 r
F P
0 g
s
.41072 .63936 m .4124 .65623 L .38072 .66021 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001fOol4002SOol007Ioo``0
09]oo`00MWoo00<005YF00001UYF00<005YFFUH02@00TWoo001fOol00`00FUH00006FUH00`00FUIJ
EP04FUH@0027Ool007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00=JEQD007Yoo`00
MGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEUYFFUHD001aOol007Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP04001JEUYFFUH6
0002FUH6001[Ool007Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEPl006Aoo`00MGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF3P00G7oo001eOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
3000EGoo001eOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001EOol007Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Eoo`00MGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH04EYF00<005YFFUH00eYF0P00
EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYFEWoo001dOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUIFOol007Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEWoo05Eoo`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0EGoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001FOol007Aoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Ioo`00M7oo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EWoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001FOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
Oomoo`1DOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1F
Ool007=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05Ioo`00Lgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0EWoo001cOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=oo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005Moo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Egoo001cOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Moo`00LWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Moo`00LWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEWoo05Moo`00LWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Egoo001bOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIoo`1GOol0079oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
05Qoo`00LWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00F7oo001bOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001HOol0079oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000EJEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Qoo`00LGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Qo
o`00LGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0F7oo001aOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001IOol0075oo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8005Uoo`00LGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<0
05YF00001EYF0P00FGoo001aOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001I
Ool0075oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Uoo`00L7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEP0005Uoo`00L7oo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF00001EYF0P00FWoo001`Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001JOol0071oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Yoo`00L7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00FWoo001`Ool00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001JOol0071oo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Yo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Yoo`00Kgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo001_Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006moo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8005]oo`00Kgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Fgoo001_Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001KOol006ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001^Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001LOol006ioo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00G7oo001]Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
G7oo001]Ool@0003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001LOol006Qoo`H000AJEP03001JEUYF00IJ
EP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0005aoo`00I7oo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`00G7oo001POol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol005aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005eoo`00FWoo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00GGoo001IOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00GGoo
001FOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0011oo`T004Aoo`00E7oo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Uoo`L000AJEP03001JEUYF009JEPP003aoo`00
E7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH4000hOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool30006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000fOol005Aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000017oo0000000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P00=7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP03
FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040002Ool0
0`00FUIJEP040003FUH00`00FUIJEP06FUH01000FUIJEUYF100015YF00@005YFFUH000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP@000Ioo`03001JEUYF00D0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP<00005FUH005YFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH0
0`00FUH00003000:Ool00`00FUIJEP0500000eYF001JEP08FUH00`00FUIJEP08FUH20002FUH20007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH2000>Ool00`00FUIJEP0500000eYF001J
EP08FUH00`00FUIJEP0:FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<0
05YFFUH01@002Goo00<005YFFUH04@0035YF10001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00@005YF001JEP80
00AJEP04001JEUYFFUH=0004FUH00`00FUIJEP06FUH00`00FUH00003000:FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH000020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH40006FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool004Moo`T000Aoo`05001JEP00FUH00005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo0011Ool60004FUH00`00FUIJEP02FUH60002FUH00`00FUIJ
EP03FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000015YF001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000mOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHG0004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20003FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH01@00FUIJEUYF00001UYF00<005YFFUH010001goo0`003Goo1@001EYF00D0
05YFFUIJEP0002eoo`00=goo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
0eYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00QJEP05001JEUYFFUH00005FUH4000:Ool5000AOol20003FUH01@00FUIJEUYF0000;Goo000eOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYFFUH2000>Ool5000@Ool200001EYF000005YF00000eYF0P00;7oo000cOol20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001JEP00
000@Ool5000>Ool20003FUH01000FUH000000eYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF1@0047oo20001Goo1@001EYF00D005YFFUIJ
EP00009JEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P003EYF00@005YFFUIJ
EPD000EJEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00H005YFFUIJEP00FUH40009Ool40002FUH00`00FUIJEP02FUH90006FUH00`00FUIJ
EP02FUH4000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP0;FUH00`00FUIJ
EP06FUH20003FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH00eYF2@001UYF00<005YFFUH01UYF00@005YFFUIJEPD0009J
EP03001JEUYF00=JEP<002aoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH0
1UYF00D005YFFUIJEP0000MJEP<00006FUH00000FUH005YF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00AJEP@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP<002aoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;FUH01000FUH000000UYF00<0
05YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00P0015YF00<005YF0000;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020006FUH00`00FUIJ
EP05FUH30007FUH01000FUIJEP002eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool0
02eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUH20003FUH40002FUH00`00FUIJEP04FUH=00000eYF001JEP09FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P0000=JEP000000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
1EYF00<005YF00003@002EYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002eoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@000eYF00D0
05YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002Ool01@00FUIJEP00FUH02`000eYF
00<005YFFUH025YF00@005YFFUIJEP800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`@0009JEP8000AJEP03001JEUYF00=JEP04001J
EUYF0002Ool70004FUH00`00FUIJEP02FUH80006FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0019oo`05001J
EUYF001oo`050005FUH01@00FUIJEP00Ool00P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPD00004FUH005YF0002FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@000aoo`L000Aoo`03001JEP0000Ioo`8000=JEP03001JEP00008000=JEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1`00
25YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00@005YFFUH002eoo`00;Goo00<005YF0000
15YF00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF009JEPH00003FUH007oo00=oo`800003FUH0
000000<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=J
EP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEP00000:Ool4
0006FUH00`00FUIJEP06FUH20002FUH50002FUH200000eYF001JEP07FUH00`00FUIJEP02FUH?0005
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00;7oo000]Ool00`00FUH00004FUH5
0005Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000AJEP00000000=JEP03
001JEUYF00EJEPL000UJEP03001JEUYF009JEP@00003FUH005YF00AJEP@000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003Ool200000eYF001JEP02
FUH00`00Oomoo`0ZOol002eoo`03001JEP00009JEP8000=JEP03001JEP0000@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF008000EJEP03001JEUYF009JEP@000EJEP03001J
EUYF00MJEPD00004FUH005YFFUH20005FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<000Moo`8000=JEP03001oogoo02Yoo`00;Goo00<005YF0000
0P001EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00@005YF0000
00IJEP03001JEP0000<0009JEP03001JEUYF00=JEP04001JEUYFFUH70005FUH00`00FUIJEP02FUH2
0003FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF
001JEP0000AJEP03001JEP0000@000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00@000aoo`04
001JEUYF000/Ool002eoo`05001JEP00FUH00004FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH20002FUH200000eYF001JEP05FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH200000eYF001JEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH0009JEP04001JEUYFFUH20005FUHI000AOol3000/Ool002eoo`80009JEP03001JEUYF
008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH01000
FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYF0002FUH0
1P00FUIJEP00FUH000EJEP03001JEUYF008000Moo`D001Qoo`800003FUH0000002]oo`00;Goo0P00
0UYF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH200001EYF001JEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUH0009JEP03001JEP00009JEP03001JEUYF00=JEP05001JEUYFFUH00007OolA000:Ool2
00000eYF001JEP02000[Ool002eoo`80009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP<000MJEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00D005YFFUIJEP00009oo`L000AJEP03
001JEUYF00IJEP03001JEP0000<000Eoo`06001JEUYFFUH005YF0P00:goo000]Ool200000eYF001J
EP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0003FUH01@00FUIJEUYF0000
1UYF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00D005YFFUIJ
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=oo`0000000P00
15YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0015YF
00@005YFFUH002]oo`00;Goo0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YF
FUH00eYF0P0000=JEP00000015YF00<005YFFUH015YF00<005YFFUH015YF1@001eYF00<005YFFUH0
1EYF00<005YFFUH00P0025YF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003Ool5000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P000eYF00@005YFFUH002]oo`00;Woo0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001EYF00<005YFFUH01eYF00H005YFFUIJEP00FUH40004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50007FUH00`00FUIJEP05FUH40008FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF0`000eYF100025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<005YF0000:goo000^Ool20005
FUH00`00FUIJEP04FUH00`00FUH000020007FUH00`00FUIJEP07FUH02P00FUIJEUYF001JEP00FUH0
05YF0`0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH015YF0P000UYF00<005YF
FUH01UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003
FUH500001EYF001JEUYF000025YF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000=JEP00
0000;7oo000^Ool20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP05FUH;0003FUH20002FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP06FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
009JEP03001JEUYF00<000AJEP03001JEUYF00AJEPH000eoo`800003FUH0000000@000AJEP03001J
EP00008002aoo`00;Goo00<005YF00001EYF00@005YFFUIJEP8000EJEP03001JEUYF00H000AJEP03
001JEUYF009JEPT000EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF
00EJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF
00@005YFFUH000IJEP03001JEUYF00@0011oo`<000=JEP03001JEUYF00=JEP8000=JEP03001JEP00
02eoo`00;Goo00<005YF00001EYF00@005YF000000MJEP<00003FUH005YF00MJEP03001JEUYF00IJ
EP80009JEPH000Eooa4000=JEP8000YJEP03001JEUYF00=JEP800003FUH00000009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000005FUH6
000<Ool60006FUH00`00FUIJEP05FUH200001EYF001JEUYF0000;7oo000]Ool01000FUIJEP0015YF
0P0000=JEP00FUH015YF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF0`0017oo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF009JEP8000=JEPl000AJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEP000002FUH0
0`00Oomoo`0ZOol002eoo`04001JEUYF0003FUH00`00Oomoo`03000015YF000000001eYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001EYF00<005YFFUH00P0000Aoo`000000009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP8000YJEP05001JEUYFFUH00004FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000800003FUH0
07oo02]oo`00;Goo00D005YFFUH005YF008000Eoo`800003FUH005YF00MJEP03001JEUYF009JEPl0
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEP00
008000AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH200000eYF001JEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003Ool00`00FUH0000[Ool002eoo`03001JEUYF008000Eoo`8000=JEP03001JEUYF
00EJEPX000Uoo`03001JEP0000<00003FUH005YF00AJEP<0009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Eoo`8002]oo`00;Woo00<0
05YF000017oo0P001EYF00<005YFFUH00UYF0`0017oo0`0037oo00<005YFFUH00P0000=oo`000000
1EYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF0P0015YF00@0
05YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP04
001JEUYFFUH20008Ool00`00Oomoo`0YOol002ioo`@0009oo`8000IJEP03001JEP00008000Ioo`D0
00]oo`05001JEUYF001JEP050003FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20006FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP04001JEP000009Ool2000[Ool002ioo`80009JEP800003FUH005YF00EJEP8000Uo
o`D000aoo`03001JEP0000AJEP@00004FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`001eYF00<005YFFUH015YF0`002goo0P00:goo000^Ool01@00FUIJEUYF00000eYF00@005YF
FUIJEP8000]oo`D000eoo`<000AJEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000EJEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEUYF0080009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000eoo`03001JEP0002]oo`00;Woo0P0000=JEP00FUH00eYF00@005YF
000000ioo`<000aoo`800003FUH0000000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04
001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1`004Goo00<005YF0000
:goo000^Ool200000eYF001JEP03FUH4000JOol30003FUH01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00000017oo4P005goo0P0000=JEP00
Ool0:Woo000^Ool40003FUH01@00FUIJEP00FUH0100047oo1P001UYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJ
EP<000Ioo`03001JEP0002=oo`04001JEP00000/Ool002moo`<00003FUH0000000=JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000020003Ool3000ROol01@00FUIJ
EUYF0000;7oo000_Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF000015YF00<005YFFUH00UYF100000=JEP0000007goo0P0015YF00<007oo
Ool0:Woo000_Ool01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=oo`0000003`000UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H0
05YF000005YF0004FUH00`00FUIJEP02FUH300000eYF0000000MOol200000eYF001JEP02FUH00`00
Oomoo`0[Ool002moo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`@000=JEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000002FUH50004FUH01000FUH005YF0P006goo0P000eYF00@005YF000002ioo`00
;goo0P0000=oo`0000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000Eoo`800003FUH007oo00P000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00
0002FUH30002Ool20003FUH01@00FUH005YF00005goo10001EYF0P00<7oo000_Ool20002Ool00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH000001Goo0P0000=JEP0000002Woo2`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF001oo`00FUH00002FUH200001UYF0000
0000FUH0009JEP8001=oo`@0009JEP03001JEUYF00AJEP03001oogoo02moo`00;goo0P000goo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001Woo00@0
05YFFUIJEP8001Eoo``000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP07001JEP00Ool005YF000015YF1P000UYF00<007ooOol03Goo1@001UYF00<005YFFUH0
0UYF0P00<Woo000_Ool30004Ool200000eYF001JEP06FUH00`00FUIJEP04FUH30008FUH00`00FUIJ
EP040007Ool20004FUH00`00Oomoo`0POol90009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002Ool30005FUH01000FUIJEUYF20001goo10000UYF00<005YFFUH01UYF
00<005YFFUH00P00=7oo000_Ool200000eYF001oo`04Ool50004FUH00`00FUIJEP03FUH50003FUH7
0009Ool200000eYF001JEP03FUH00`00Oomoo`0VOol90003FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000005FUH00`00FUIJEP05FUH01000FUIJEUYF
1`001UYF00<005YFFUH01UYF0`00=Woo000`Ool01000FUIJEP002Goo4P003Woo0P000eYF00D005YF
FUIJEP0002Uoo`<000=JEP03001JEUYF00T000EJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000=JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2000hOol0031oo`03001JEUYF00<0015oo`D000ioo`<000IJEP03001JEP0002Yoo`<0
009JEP03001JEUYF009JEP04001JEUYFFUH>0004FUH00`00FUIJEP02FUH00`00FUH00003FUH01000
FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000>Woo
000`Ool01000FUIJEP000UYF0P0047oo0`003Goo0P0000=JEP00FUH01UYF0P00:goo00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH0000;0003FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000nOol0035oo`04001JEUYF0003FUH3000JOol3
0003FUH00`00FUIJEP04FUH2000/Ool00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000goo0000000@0015Ool0039o
o`<000AJEP03001JEP0000<0011oo`H000MJEP04001JEUYFFUH2000^Ool00`00FUIJEP020005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0004Ool00`00FUH0001BOol003Aoo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF
00IJEP04001JEP00000`Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001Woo00<005YF0000DWoo000eOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000cOol200000goo
001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUH000001goo0P0000=JEP00Ool0DGoo000gOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000fOol01000Oomoogoo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0027oo00@005YF000005=oo`00>Goo0`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00>Goo0P0017oo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo00D005YFFUIJEP0005=oo`00
?7oo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?7oo00<005YF00001Goo0`001UYF00<0
05YFFUH01EYF0`001eYF00<005YF00000P002Woo0P0015YF00<007ooOol0DGoo0010Ool?0012Ool2
00000eYF001oo`06Ool40002FUH00`00FUIJEP04FUH50002FUH6000;Ool200000eYF001JEP02FUH0
0`00Oomoo`1BOol0099oo`04001JEUYF000:Ool@000?Ool20003FUH01000FUH00000EGoo002BOol0
0`00FUIJEP03000AOol5000=Ool40005FUH2001GOol009=oo`03001JEP00009JEP80011oo`<000Yo
o`@0009JEP03001JEUYF00AJEP03001oogoo05Ioo`00Tgoo00<005YF000015YF1@004Goo1`001UYF
00<005YFFUH00UYF0P00FGoo002DOol20005FUH01000FUIJEUYF4@0015YF00<005YFFUH01UYF00<0
05YFFUH00P00Fgoo002EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH3001MOol009Moo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8005moo`00VWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01000HGoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001UOol00:5ooa0006ao
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59829 .75401 m .59644 .69987 L .56528 .69839 L p .707 .577 .707 r
F P
0 g
s
.59644 .69987 m .59829 .75401 L .63011 .75204 L p .707 .577 .707 r
F P
0 g
s
.63011 .75204 m .62826 .6979 L .59644 .69987 L p .707 .577 .707 r
F P
0 g
s
.62826 .6979 m .63011 .75204 L .65946 .7468 L p .707 .577 .707 r
F P
0 g
s
.65946 .7468 m .65761 .69267 L .62826 .6979 L p .707 .577 .707 r
F P
0 g
s
.56713 .75252 m .56528 .69839 L .53781 .69358 L p .707 .577 .707 r
F P
0 g
s
.56528 .69839 m .56713 .75252 L .59829 .75401 L p .707 .577 .707 r
F P
0 g
s
.65761 .69267 m .65946 .7468 L .68347 .73881 L p .707 .577 .707 r
F P
0 g
s
.68347 .73881 m .68162 .68467 L .65761 .69267 L p .707 .577 .707 r
F P
0 g
s
.53966 .74772 m .53781 .69358 L .51674 .68593 L p .707 .577 .707 r
F P
0 g
s
.53781 .69358 m .53966 .74772 L .56713 .75252 L p .707 .577 .707 r
F P
0 g
s
.60065 .8149 m .59861 .77959 L .56746 .77837 L p .707 .577 .707 r
F P
0 g
s
.59861 .77959 m .60065 .8149 L .63243 .81216 L p .707 .577 .707 r
F P
0 g
s
.63243 .81216 m .63039 .77686 L .59861 .77959 L p .707 .577 .707 r
F P
0 g
s
.63039 .77686 m .63243 .81216 L .66173 .80573 L p .707 .577 .707 r
F P
0 g
s
.66173 .80573 m .65969 .77043 L .63039 .77686 L p .707 .577 .707 r
F P
0 g
s
.68162 .68467 m .68347 .73881 L .6998 .72884 L p .707 .577 .707 r
F P
0 g
s
.6998 .72884 m .69795 .67471 L .68162 .68467 L p .707 .577 .707 r
F P
0 g
s
.5695 .81367 m .56746 .77837 L .53998 .7733 L p .707 .577 .707 r
F P
0 g
s
.56746 .77837 m .5695 .81367 L .60065 .8149 L p .707 .577 .707 r
F P
0 g
s
.65969 .77043 m .66173 .80573 L .68567 .79624 L p .707 .577 .707 r
F P
0 g
s
.68567 .79624 m .68363 .76093 L .65969 .77043 L p .707 .577 .707 r
F P
0 g
s
.51674 .68593 m .51859 .74007 L .53966 .74772 L p .707 .577 .707 r
F P
0 g
s
.51859 .74007 m .51674 .68593 L .50411 .67619 L p .707 .577 .707 r
F P
0 g
s
.60242 .8511 m .60137 .83348 L .57022 .83227 L p .707 .577 .707 r
F P
0 g
s
.60137 .83348 m .60242 .8511 L .6342 .84831 L p .707 .577 .707 r
F P
0 g
s
.6342 .84831 m .63315 .83069 L .60137 .83348 L p .707 .577 .707 r
F P
0 g
s
.53998 .7733 m .54202 .80861 L .5695 .81367 L p .707 .577 .707 r
F P
0 g
s
.54202 .80861 m .53998 .7733 L .51887 .76489 L p .707 .577 .707 r
F P
0 g
s
.63315 .83069 m .6342 .84831 L .66349 .8418 L p .707 .577 .707 r
F P
0 g
s
.66349 .8418 m .66244 .82418 L .63315 .83069 L p .707 .577 .707 r
F P
0 g
s
.57127 .84989 m .57022 .83227 L .54274 .82718 L p .707 .577 .707 r
F P
0 g
s
.57022 .83227 m .57127 .84989 L .60242 .8511 L p .707 .577 .707 r
F P
0 g
s
.69795 .67471 m .6998 .72884 L .70684 .71788 L p .707 .577 .707 r
F P
0 g
s
.70684 .71788 m .70499 .66375 L .69795 .67471 L p .707 .577 .707 r
F P
0 g
s
.68363 .76093 m .68567 .79624 L .70192 .78461 L p .707 .577 .707 r
F P
0 g
s
.70192 .78461 m .69988 .7493 L .68363 .76093 L p .707 .577 .707 r
F P
0 g
s
.66244 .82418 m .66349 .8418 L .68743 .83221 L p .707 .577 .707 r
F P
0 g
s
.68743 .83221 m .68638 .81458 L .66244 .82418 L p .707 .577 .707 r
F P
0 g
s
.54274 .82718 m .54379 .84481 L .57127 .84989 L p .707 .577 .707 r
F P
0 g
s
.50411 .67619 m .50596 .73033 L .51859 .74007 L p .707 .577 .707 r
F P
0 g
s
.51887 .76489 m .52091 .80019 L .54202 .80861 L p .707 .577 .707 r
F P
0 g
s
.54379 .84481 m .54274 .82718 L .52163 .81872 L p .707 .577 .707 r
F P
0 g
s
.52091 .80019 m .51887 .76489 L .50619 .75395 L p .707 .577 .707 r
F P
0 g
s
.50596 .73033 m .50411 .67619 L .50118 .66531 L p .707 .577 .707 r
F P
0 g
s
.52163 .81872 m .52268 .83634 L .54379 .84481 L p .707 .577 .707 r
F P
0 g
s
.68638 .81458 m .68743 .83221 L .70367 .82046 L p .707 .577 .707 r
F P
0 g
s
.70367 .82046 m .70262 .80284 L .68638 .81458 L p .707 .577 .707 r
F P
0 g
s
.69988 .7493 m .70192 .78461 L .70888 .77198 L p .707 .577 .707 r
F P
0 g
s
.70888 .77198 m .70684 .73667 L .69988 .7493 L p .707 .577 .707 r
F P
0 g
s
.50619 .75395 m .50823 .78926 L .52091 .80019 L p .707 .577 .707 r
F P
0 g
s
.70499 .66375 m .70684 .71788 L .7039 .707 L p .707 .577 .707 r
F P
0 g
s
.7039 .707 m .70205 .65286 L .70499 .66375 L p .707 .577 .707 r
F P
0 g
s
.50118 .66531 m .50303 .71944 L .50596 .73033 L p .707 .577 .707 r
F P
0 g
s
.52268 .83634 m .52163 .81872 L .50895 .8077 L p .707 .577 .707 r
F P
0 g
s
.50823 .78926 m .50619 .75395 L .50319 .74156 L p .707 .577 .707 r
F P
0 g
s
.50895 .8077 m .51 .82533 L .52268 .83634 L p .707 .577 .707 r
F P
0 g
s
.50303 .71944 m .50118 .66531 L .50822 .65435 L p .707 .577 .707 r
F P
0 g
s
.70262 .80284 m .70367 .82046 L .71063 .80772 L p .707 .577 .707 r
F P
0 g
s
.71063 .80772 m .70958 .7901 L .70262 .80284 L p .707 .577 .707 r
F P
0 g
s
.70684 .73667 m .70888 .77198 L .70588 .75959 L p .707 .577 .707 r
F P
0 g
s
.70588 .75959 m .70384 .72429 L .70684 .73667 L p .707 .577 .707 r
F P
0 g
s
.50319 .74156 m .50523 .77687 L .50823 .78926 L p .707 .577 .707 r
F P
0 g
s
.70205 .65286 m .7039 .707 L .69128 .69726 L p .707 .577 .707 r
F P
0 g
s
.69128 .69726 m .68943 .64312 L .70205 .65286 L p .707 .577 .707 r
F P
0 g
s
.51 .82533 m .50895 .8077 L .50594 .79521 L p .707 .577 .707 r
F P
0 g
s
.50822 .65435 m .51007 .70848 L .50303 .71944 L p .707 .577 .707 r
F P
0 g
s
.50523 .77687 m .50319 .74156 L .51015 .72894 L p .707 .577 .707 r
F P
0 g
s
.50594 .79521 m .50698 .81284 L .51 .82533 L p .707 .577 .707 r
F P
0 g
s
.25529 .71719 m .25344 .66306 L .22227 .66157 L p .707 .577 .707 r
F P
0 g
s
.25344 .66306 m .25529 .71719 L .2871 .71522 L p .707 .577 .707 r
F P
0 g
s
.2871 .71522 m .28525 .66109 L .25344 .66306 L p .707 .577 .707 r
F P
0 g
s
.51007 .70848 m .50822 .65435 L .52454 .64438 L p .707 .577 .707 r
F P
0 g
s
.28525 .66109 m .2871 .71522 L .31645 .70998 L p .707 .577 .707 r
F P
0 g
s
.31645 .70998 m .3146 .65585 L .28525 .66109 L p .707 .577 .707 r
F P
0 g
s
.70958 .7901 m .71063 .80772 L .70762 .79523 L p .707 .577 .707 r
F P
0 g
s
.70762 .79523 m .70657 .77761 L .70958 .7901 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22412 .7157 m .22227 .66157 L .1948 .65677 L p .707 .577 .707 r
F P
0 g
s
.22227 .66157 m .22412 .7157 L .25529 .71719 L p .707 .577 .707 r
F P
0 g
s
.70384 .72429 m .70588 .75959 L .6932 .74866 L p .707 .577 .707 r
F P
0 g
s
.6932 .74866 m .69116 .71335 L .70384 .72429 L p .707 .577 .707 r
F P
0 g
s
.51015 .72894 m .51219 .76424 L .50523 .77687 L p .707 .577 .707 r
F P
0 g
s
.68943 .64312 m .69128 .69726 L .6702 .68961 L p .707 .577 .707 r
F P
0 g
s
.6702 .68961 m .66835 .63547 L .68943 .64312 L p .707 .577 .707 r
F P
0 g
s
.3146 .65585 m .31645 .70998 L .34046 .70199 L p .707 .577 .707 r
F P
0 g
s
.34046 .70199 m .33861 .64786 L .3146 .65585 L p .707 .577 .707 r
F P
0 g
s
.50698 .81284 m .50594 .79521 L .51289 .78247 L p .707 .577 .707 r
F P
0 g
s
.52454 .64438 m .52639 .69852 L .51007 .70848 L p .707 .577 .707 r
F P
0 g
s
.19665 .7109 m .1948 .65677 L .17373 .64912 L p .707 .577 .707 r
F P
0 g
s
.1948 .65677 m .19665 .7109 L .22412 .7157 L p .707 .577 .707 r
F P
0 g
s
.52639 .69852 m .52454 .64438 L .54856 .63639 L p .707 .577 .707 r
F P
0 g
s
.51219 .76424 m .51015 .72894 L .5264 .71731 L p .707 .577 .707 r
F P
0 g
s
.51289 .78247 m .51394 .8001 L .50698 .81284 L p .707 .577 .707 r
F P
0 g
s
.25764 .77808 m .2556 .74278 L .22445 .74155 L p .707 .577 .707 r
F P
0 g
s
.2556 .74278 m .25764 .77808 L .28942 .77535 L p .707 .577 .707 r
F P
0 g
s
.28942 .77535 m .28738 .74004 L .2556 .74278 L p .707 .577 .707 r
F P
0 g
s
.28738 .74004 m .28942 .77535 L .31872 .76892 L p .707 .577 .707 r
F P
0 g
s
.31872 .76892 m .31668 .73361 L .28738 .74004 L p .707 .577 .707 r
F P
0 g
s
.70657 .77761 m .70762 .79523 L .69493 .78422 L p .707 .577 .707 r
F P
0 g
s
.69493 .78422 m .69389 .76659 L .70657 .77761 L p .707 .577 .707 r
F P
0 g
s
.33861 .64786 m .34046 .70199 L .35679 .69203 L p .707 .577 .707 r
F P
0 g
s
.35679 .69203 m .35494 .63789 L .33861 .64786 L p .707 .577 .707 r
F P
0 g
s
.22649 .77686 m .22445 .74155 L .19697 .73648 L p .707 .577 .707 r
F P
0 g
s
.22445 .74155 m .22649 .77686 L .25764 .77808 L p .707 .577 .707 r
F P
0 g
s
.66835 .63547 m .6702 .68961 L .64274 .6848 L p .707 .577 .707 r
F P
0 g
s
.64274 .6848 m .64089 .63067 L .66835 .63547 L p .707 .577 .707 r
F P
0 g
s
.69116 .71335 m .6932 .74866 L .67209 .74025 L p .707 .577 .707 r
F P
0 g
s
.67209 .74025 m .67005 .70494 L .69116 .71335 L p .707 .577 .707 r
F P
0 g
s
.5264 .71731 m .52844 .75261 L .51219 .76424 L p .707 .577 .707 r
F P
0 g
s
.31668 .73361 m .31872 .76892 L .34266 .75942 L p .707 .577 .707 r
F P
0 g
s
.34266 .75942 m .34062 .72412 L .31668 .73361 L p .707 .577 .707 r
F P
0 g
s
.17373 .64912 m .17558 .70325 L .19665 .7109 L p .707 .577 .707 r
F P
0 g
s
.55041 .69052 m .54856 .63639 L .57791 .63115 L p .707 .577 .707 r
F P
0 g
s
.54856 .63639 m .55041 .69052 L .52639 .69852 L p .707 .577 .707 r
F P
0 g
s
.17558 .70325 m .17373 .64912 L .16111 .63938 L p .707 .577 .707 r
F P
0 g
s
.51394 .8001 m .51289 .78247 L .52914 .77073 L p .707 .577 .707 r
F P
0 g
s
.25941 .81429 m .25837 .79666 L .22721 .79546 L p .707 .577 .707 r
F P
0 g
s
.25837 .79666 m .25941 .81429 L .29119 .8115 L p .707 .577 .707 r
F P
0 g
s
.29119 .8115 m .29014 .79387 L .25837 .79666 L p .707 .577 .707 r
F P
0 g
s
.19697 .73648 m .19901 .77179 L .22649 .77686 L p .707 .577 .707 r
F P
0 g
s
.19901 .77179 m .19697 .73648 L .17586 .72807 L p .707 .577 .707 r
F P
0 g
s
.49165 .79215 m .52755 .27489 L .48359 .27092 L p .707 .577 .707 r
F P
0 g
s
.52844 .75261 m .5264 .71731 L .55034 .70781 L p .707 .577 .707 r
F P
0 g
s
.52914 .77073 m .53018 .78835 L .51394 .8001 L p .707 .577 .707 r
F P
0 g
s
.55034 .70781 m .55238 .74312 L .52844 .75261 L p .707 .577 .707 r
F P
0 g
s
.53018 .78835 m .52914 .77073 L .55307 .76113 L p .707 .577 .707 r
F P
0 g
s
.55307 .76113 m .55412 .77876 L .53018 .78835 L p .707 .577 .707 r
F P
0 g
s
.52755 .27489 m .49165 .79215 L .53647 .7948 L p .707 .577 .707 r
F P
0 g
s
.53647 .7948 m .57236 .27754 L .52755 .27489 L p .707 .577 .707 r
F P
0 g
s
.29014 .79387 m .29119 .8115 L .32048 .80499 L p .707 .577 .707 r
F P
0 g
s
.32048 .80499 m .31943 .78736 L .29014 .79387 L p .707 .577 .707 r
F P
0 g
s
.64089 .63067 m .64274 .6848 L .61157 .68332 L p .707 .577 .707 r
F P
0 g
s
.61157 .68332 m .60972 .62918 L .64089 .63067 L p .707 .577 .707 r
F P
0 g
s
.57791 .63115 m .57976 .68529 L .55041 .69052 L p .707 .577 .707 r
F P
0 g
s
.55238 .74312 m .55034 .70781 L .57964 .70138 L p .707 .577 .707 r
F P
0 g
s
.57964 .70138 m .58168 .73669 L .55238 .74312 L p .707 .577 .707 r
F P
0 g
s
.55412 .77876 m .55307 .76113 L .58237 .75462 L p .707 .577 .707 r
F P
0 g
s
.58237 .75462 m .58341 .77225 L .55412 .77876 L p .707 .577 .707 r
F P
0 g
s
.57236 .27754 m .53647 .7948 L .57774 .79587 L p .707 .577 .707 r
F P
0 g
s
.57976 .68529 m .57791 .63115 L .60972 .62918 L p .707 .577 .707 r
F P
0 g
s
.60972 .62918 m .61157 .68332 L .57976 .68529 L p .707 .577 .707 r
F P
0 g
s
.58168 .73669 m .57964 .70138 L .61142 .69865 L p .707 .577 .707 r
F P
0 g
s
.61142 .69865 m .61346 .73395 L .58168 .73669 L p .707 .577 .707 r
F P
0 g
s
.57774 .79587 m .61364 .27861 L .57236 .27754 L p .707 .577 .707 r
F P
0 g
s
.22826 .81308 m .22721 .79546 L .19974 .79037 L p .707 .577 .707 r
F P
0 g
s
.22721 .79546 m .22826 .81308 L .25941 .81429 L p .707 .577 .707 r
F P
0 g
s
.35494 .63789 m .35679 .69203 L .36383 .68107 L p .707 .577 .707 r
F P
0 g
s
.36383 .68107 m .36198 .62693 L .35494 .63789 L p .707 .577 .707 r
F P
0 g
s
.69389 .76659 m .69493 .78422 L .67382 .77575 L p .707 .577 .707 r
F P
0 g
s
.67382 .77575 m .67277 .75813 L .69389 .76659 L p .707 .577 .707 r
F P
0 g
s
.34062 .72412 m .34266 .75942 L .35891 .74779 L p .707 .577 .707 r
F P
0 g
s
.35891 .74779 m .35687 .71249 L .34062 .72412 L p .707 .577 .707 r
F P
0 g
s
.44769 .78817 m .48359 .27092 L .44478 .26601 L p .707 .577 .707 r
F P
0 g
s
.48359 .27092 m .44769 .78817 L .49165 .79215 L p .707 .577 .707 r
F P
0 g
s
.67005 .70494 m .67209 .74025 L .64461 .73518 L p .707 .577 .707 r
F P
0 g
s
.64461 .73518 m .64257 .69987 L .67005 .70494 L p .707 .577 .707 r
F P
0 g
s
.31943 .78736 m .32048 .80499 L .34442 .79539 L p .707 .577 .707 r
F P
0 g
s
.34442 .79539 m .34337 .77777 L .31943 .78736 L p .707 .577 .707 r
F P
0 g
s
.19974 .79037 m .20078 .80799 L .22826 .81308 L p .707 .577 .707 r
F P
0 g
s
.16111 .63938 m .16295 .69351 L .17558 .70325 L p .707 .577 .707 r
F P
0 g
s
.17586 .72807 m .1779 .76338 L .19901 .77179 L p .707 .577 .707 r
F P
0 g
s
.20078 .80799 m .19974 .79037 L .17862 .7819 L p .707 .577 .707 r
F P
0 g
s
.1779 .76338 m .17586 .72807 L .16318 .71714 L p .707 .577 .707 r
F P
0 g
s
.16295 .69351 m .16111 .63938 L .15817 .62849 L p .707 .577 .707 r
F P
0 g
s
.61346 .73395 m .61142 .69865 L .64257 .69987 L p .707 .577 .707 r
F P
0 g
s
.58341 .77225 m .58237 .75462 L .61414 .75183 L p .707 .577 .707 r
F P
0 g
s
.61414 .75183 m .61519 .76946 L .58341 .77225 L p .707 .577 .707 r
F P
0 g
s
.61364 .27861 m .57774 .79587 L .61144 .79525 L p .707 .577 .707 r
F P
0 g
s
.64257 .69987 m .64461 .73518 L .61346 .73395 L p .707 .577 .707 r
F P
0 g
s
.61519 .76946 m .61414 .75183 L .6453 .75304 L p .707 .577 .707 r
F P
0 g
s
.61144 .79525 m .64734 .278 L .61364 .27861 L p .707 .577 .707 r
F P
0 g
s
.17862 .7819 m .17967 .79953 L .20078 .80799 L p .707 .577 .707 r
F P
0 g
s
.34337 .77777 m .34442 .79539 L .36066 .78365 L p .707 .577 .707 r
F P
0 g
s
.36066 .78365 m .35962 .76602 L .34337 .77777 L p .707 .577 .707 r
F P
0 g
s
.67277 .75813 m .67382 .77575 L .64634 .77067 L p .707 .577 .707 r
F P
0 g
s
.64634 .77067 m .6453 .75304 L .67277 .75813 L p .707 .577 .707 r
F P
0 g
s
.40888 .78326 m .44478 .26601 L .41492 .26064 L p .707 .577 .707 r
F P
0 g
s
.44478 .26601 m .40888 .78326 L .44769 .78817 L p .707 .577 .707 r
F P
0 g
s
.35687 .71249 m .35891 .74779 L .36587 .73517 L p .707 .577 .707 r
F P
0 g
s
.36587 .73517 m .36383 .69986 L .35687 .71249 L p .707 .577 .707 r
F P
0 g
s
.16318 .71714 m .16522 .75244 L .1779 .76338 L p .707 .577 .707 r
F P
0 g
s
.36198 .62693 m .36383 .68107 L .36089 .67018 L p .707 .577 .707 r
F P
0 g
s
.36089 .67018 m .35904 .61605 L .36198 .62693 L p .707 .577 .707 r
F P
0 g
s
.15817 .62849 m .16002 .68263 L .16295 .69351 L p .707 .577 .707 r
F P
0 g
s
.17967 .79953 m .17862 .7819 L .16594 .77089 L p .707 .577 .707 r
F P
0 g
s
.6453 .75304 m .64634 .77067 L .61519 .76946 L p .707 .577 .707 r
F P
0 g
s
.16522 .75244 m .16318 .71714 L .16018 .70475 L p .707 .577 .707 r
F P
0 g
s
.16594 .77089 m .16699 .78851 L .17967 .79953 L p .707 .577 .707 r
F P
0 g
s
.16002 .68263 m .15817 .62849 L .16521 .61753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64734 .278 m .61144 .79525 L .63426 .79301 L p .707 .577 .707 r
F P
0 g
s
.63426 .79301 m .67016 .27576 L .64734 .278 L p .707 .577 .707 r
F P
0 g
s
.35962 .76602 m .36066 .78365 L .36762 .77091 L p .707 .577 .707 r
F P
0 g
s
.36762 .77091 m .36657 .75328 L .35962 .76602 L p .707 .577 .707 r
F P
0 g
s
.36383 .69986 m .36587 .73517 L .36287 .72278 L p .707 .577 .707 r
F P
0 g
s
.36287 .72278 m .36083 .68747 L .36383 .69986 L p .707 .577 .707 r
F P
0 g
s
.16018 .70475 m .16222 .74006 L .16522 .75244 L p .707 .577 .707 r
F P
0 g
s
.37902 .7779 m .41492 .26064 L .39694 .25536 L p .707 .577 .707 r
F P
0 g
s
.41492 .26064 m .37902 .7779 L .40888 .78326 L p .707 .577 .707 r
F P
0 g
s
.35904 .61605 m .36089 .67018 L .34827 .66044 L p .707 .577 .707 r
F P
0 g
s
.34827 .66044 m .34642 .60631 L .35904 .61605 L p .707 .577 .707 r
F P
0 g
s
.16699 .78851 m .16594 .77089 L .16293 .7584 L p .707 .577 .707 r
F P
0 g
s
.16521 .61753 m .16706 .67166 L .16002 .68263 L p .707 .577 .707 r
F P
0 g
s
.16222 .74006 m .16018 .70475 L .16714 .69212 L p .707 .577 .707 r
F P
0 g
s
.16293 .7584 m .16397 .77602 L .16699 .78851 L p .707 .577 .707 r
F P
0 g
s
.16706 .67166 m .16521 .61753 L .18153 .60757 L p .707 .577 .707 r
F P
0 g
s
.36657 .75328 m .36762 .77091 L .36461 .75842 L p .707 .577 .707 r
F P
0 g
s
.36461 .75842 m .36356 .74079 L .36657 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.67016 .27576 m .63426 .79301 L .64397 .78936 L p .707 .577 .707 r
F P
0 g
s
.67687 .6597 m .67502 .60557 L .66103 .60049 L p .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .66117 .54158 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .63963 .78466 L p .65197 .62748 L .707 .577 .707 r
F P
0 g
s
.65197 .62748 m .65277 .62262 L .64397 .78936 L .707 .577 .707 r
F
.65362 .60643 m .65409 .60236 L .64397 .78936 L F
.66117 .54158 m .6596 .5642 L p .65409 .60236 L F P
0 g
s
.6596 .5642 m .64397 .78936 L p .65409 .60236 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .62164 .77937 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .64132 .58818 L p .64995 .62627 L .707 .577 .707 r
F P
0 g
s
.65056 .6266 m .65394 .59792 L .64995 .62627 L .707 .577 .707 r
F
.63842 .61998 m .64248 .6222 L .63963 .78466 L F
.65059 .62662 m .64699 .67851 L p .64248 .6222 L F P
0 g
s
.64699 .67851 m .63963 .78466 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64132 .58818 L .6391 .57993 L p .707 .577 .707 r
F P
0 g
s
.65409 .60236 m .65394 .59792 L p .65056 .6266 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .65056 .6266 L .65037 .62814 L .707 .577 .707 r
F
.65409 .60236 m .65056 .6266 L .65059 .62662 L F
.67987 .27211 m .67016 .27576 L p .66139 .44768 L F P
0 g
s
.66117 .54158 m .67987 .27211 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64132 .58818 m .64248 .6222 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .64132 .58818 L .64781 .6459 L .707 .577 .707 r
F
.65754 .26212 m .67552 .26741 L p .63842 .61998 L F P
0 g
s
.62164 .77937 m .63291 .61698 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.63291 .61698 m .65754 .26212 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64781 .6459 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64317 .64231 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .65059 .62662 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.64781 .6459 m .65579 .65205 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65458 .59815 m .65394 .59792 L p .65445 .59929 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .65579 .65205 L .67687 .6597 L p .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .67987 .27211 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .67552 .26741 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .65059 .62662 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64248 .6222 L p .63838 .57729 L .707 .577 .707 r
F P
0 g
s
.6391 .57993 m .63838 .57729 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .65056 .6266 L .64995 .62627 L .707 .577 .707 r
F
.65197 .62748 m .65362 .60643 L .65277 .62262 L F
.67987 .27211 m .66117 .54158 L p .65362 .60643 L F P
0 g
s
.65579 .65205 m .65409 .60236 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .65607 .68305 L .64447 .67304 L p .707 .577 .707 r
F P
0 g
s
.64447 .67304 m .64339 .67211 L p .6442 .67465 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .64447 .67304 L .6442 .67465 L .707 .577 .707 r
F
.66103 .60049 m .65458 .59815 L p .66099 .61691 L F P
0 g
s
.66099 .61691 m .65458 .59815 L .65445 .59929 L .707 .577 .707 r
F
.67687 .6597 m .66103 .60049 L .66099 .61691 L F
.36083 .68747 m .36287 .72278 L .35019 .71184 L p F P
0 g
s
.35019 .71184 m .34815 .67654 L .36083 .68747 L p .707 .577 .707 r
F P
0 g
s
.16714 .69212 m .16918 .72743 L .16222 .74006 L p .707 .577 .707 r
F P
0 g
s
.34642 .60631 m .34827 .66044 L .32719 .65279 L p .707 .577 .707 r
F P
0 g
s
.32719 .65279 m .32534 .59866 L .34642 .60631 L p .707 .577 .707 r
F P
0 g
s
.16397 .77602 m .16293 .7584 L .16988 .74566 L p .707 .577 .707 r
F P
0 g
s
.18153 .60757 m .18338 .6617 L .16706 .67166 L p .707 .577 .707 r
F P
0 g
s
.36356 .74079 m .36461 .75842 L .35193 .7474 L p .707 .577 .707 r
F P
0 g
s
.35193 .7474 m .35088 .72978 L .36356 .74079 L p .707 .577 .707 r
F P
0 g
s
.36104 .77261 m .39694 .25536 L .39259 .25066 L p .707 .577 .707 r
F P
0 g
s
.39694 .25536 m .36104 .77261 L .37902 .7779 L p .707 .577 .707 r
F P
0 g
s
.18338 .6617 m .18153 .60757 L .20555 .59957 L p .707 .577 .707 r
F P
0 g
s
.16918 .72743 m .16714 .69212 L .18339 .68049 L p .707 .577 .707 r
F P
0 g
s
.16988 .74566 m .17093 .76328 L .16397 .77602 L p .707 .577 .707 r
F P
0 g
s
.32534 .59866 m .32719 .65279 L .29973 .64799 L p .707 .577 .707 r
F P
0 g
s
.29973 .64799 m .29788 .59386 L .32534 .59866 L p .707 .577 .707 r
F P
0 g
s
.34815 .67654 m .35019 .71184 L .32908 .70343 L p .707 .577 .707 r
F P
0 g
s
.32908 .70343 m .32704 .66812 L .34815 .67654 L p .707 .577 .707 r
F P
0 g
s
.18339 .68049 m .18543 .7158 L .16918 .72743 L p .707 .577 .707 r
F P
0 g
s
.2074 .65371 m .20555 .59957 L .2349 .59434 L p .707 .577 .707 r
F P
0 g
s
.20555 .59957 m .2074 .65371 L .18338 .6617 L p .707 .577 .707 r
F P
0 g
s
.17093 .76328 m .16988 .74566 L .18613 .73392 L p .707 .577 .707 r
F P
0 g
s
.18543 .7158 m .18339 .68049 L .20733 .671 L p .707 .577 .707 r
F P
0 g
s
.29788 .59386 m .29973 .64799 L .26856 .6465 L p .707 .577 .707 r
F P
0 g
s
.26856 .6465 m .26671 .59237 L .29788 .59386 L p .707 .577 .707 r
F P
0 g
s
.18613 .73392 m .18717 .75154 L .17093 .76328 L p .707 .577 .707 r
F P
0 g
s
.23675 .64847 m .2349 .59434 L .26671 .59237 L p .707 .577 .707 r
F P
0 g
s
.2349 .59434 m .23675 .64847 L .2074 .65371 L p .707 .577 .707 r
F P
0 g
s
.26671 .59237 m .26856 .6465 L .23675 .64847 L p .707 .577 .707 r
F P
0 g
s
.35088 .72978 m .35193 .7474 L .33081 .73894 L p .707 .577 .707 r
F P
0 g
s
.33081 .73894 m .32976 .72131 L .35088 .72978 L p .707 .577 .707 r
F P
0 g
s
.32704 .66812 m .32908 .70343 L .3016 .69836 L p .707 .577 .707 r
F P
0 g
s
.3016 .69836 m .29956 .66306 L .32704 .66812 L p .707 .577 .707 r
F P
0 g
s
.20733 .671 m .20937 .7063 L .18543 .7158 L p .707 .577 .707 r
F P
0 g
s
.7355 .66599 m .73365 .61186 L .70248 .61037 L p .707 .577 .707 r
F P
0 g
s
.73365 .61186 m .7355 .66599 L .76731 .66402 L p .707 .577 .707 r
F P
0 g
s
.76731 .66402 m .76546 .60989 L .73365 .61186 L p .707 .577 .707 r
F P
0 g
s
.39259 .25066 m .35669 .76791 L .36104 .77261 L p .707 .577 .707 r
F P
0 g
s
.35669 .76791 m .39259 .25066 L .4023 .24701 L p .707 .577 .707 r
F P
0 g
s
.76546 .60989 m .76731 .66402 L .79666 .65879 L p .707 .577 .707 r
F P
0 g
s
.79666 .65879 m .79481 .60465 L .76546 .60989 L p .707 .577 .707 r
F P
0 g
s
.20937 .7063 m .20733 .671 L .23663 .66457 L p .707 .577 .707 r
F P
0 g
s
.18717 .75154 m .18613 .73392 L .21006 .72432 L p .707 .577 .707 r
F P
0 g
s
.70433 .6645 m .70248 .61037 L .67502 .60557 L p .707 .577 .707 r
F P
0 g
s
.70248 .61037 m .70433 .6645 L .7355 .66599 L p .707 .577 .707 r
F P
0 g
s
.29956 .66306 m .3016 .69836 L .27045 .69714 L p .707 .577 .707 r
F P
0 g
s
.27045 .69714 m .26841 .66183 L .29956 .66306 L p .707 .577 .707 r
F P
0 g
s
.21006 .72432 m .21111 .74194 L .18717 .75154 L p .707 .577 .707 r
F P
0 g
s
.23867 .69987 m .23663 .66457 L .26841 .66183 L p .707 .577 .707 r
F P
0 g
s
.23663 .66457 m .23867 .69987 L .20937 .7063 L p .707 .577 .707 r
F P
0 g
s
.79481 .60465 m .79666 .65879 L .82068 .65079 L p .707 .577 .707 r
F P
0 g
s
.82068 .65079 m .81883 .59666 L .79481 .60465 L p .707 .577 .707 r
F P
0 g
s
.32976 .72131 m .33081 .73894 L .30333 .73385 L p .707 .577 .707 r
F P
0 g
s
.30333 .73385 m .30229 .71623 L .32976 .72131 L p .707 .577 .707 r
F P
0 g
s
.26841 .66183 m .27045 .69714 L .23867 .69987 L p .707 .577 .707 r
F P
0 g
s
.67502 .60557 m .67687 .6597 L .70433 .6645 L p .707 .577 .707 r
F P
0 g
s
.21111 .74194 m .21006 .72432 L .23936 .71781 L p .707 .577 .707 r
F P
0 g
s
.73785 .73306 m .73581 .69776 L .70466 .69653 L p .707 .577 .707 r
F P
0 g
s
.73581 .69776 m .73785 .73306 L .76963 .73033 L p .707 .577 .707 r
F P
0 g
s
.76963 .73033 m .76759 .69502 L .73581 .69776 L p .707 .577 .707 r
F P
0 g
s
.30229 .71623 m .30333 .73385 L .27218 .73264 L p .707 .577 .707 r
F P
0 g
s
.27218 .73264 m .27113 .71502 L .30229 .71623 L p .707 .577 .707 r
F P
0 g
s
.76759 .69502 m .76963 .73033 L .79893 .7239 L p .707 .577 .707 r
F P
0 g
s
.79893 .7239 m .79689 .68859 L .76759 .69502 L p .707 .577 .707 r
F P
0 g
s
.23936 .71781 m .2404 .73543 L .21111 .74194 L p .707 .577 .707 r
F P
0 g
s
.81883 .59666 m .82068 .65079 L .837 .64083 L p .707 .577 .707 r
F P
0 g
s
.837 .64083 m .83515 .5867 L .81883 .59666 L p .707 .577 .707 r
F P
0 g
s
.2404 .73543 m .23936 .71781 L .27113 .71502 L p .707 .577 .707 r
F P
0 g
s
.7067 .73184 m .70466 .69653 L .67718 .69146 L p .707 .577 .707 r
F P
0 g
s
.70466 .69653 m .7067 .73184 L .73785 .73306 L p .707 .577 .707 r
F P
0 g
s
.27113 .71502 m .27218 .73264 L .2404 .73543 L p .707 .577 .707 r
F P
0 g
s
.79689 .68859 m .79893 .7239 L .82288 .7144 L p .707 .577 .707 r
F P
0 g
s
.82288 .7144 m .82084 .67909 L .79689 .68859 L p .707 .577 .707 r
F P
0 g
s
.3664 .76426 m .4023 .24701 L .42512 .24476 L p .707 .577 .707 r
F P
0 g
s
.4023 .24701 m .3664 .76426 L .35669 .76791 L p .707 .577 .707 r
F P
0 g
s
.67718 .69146 m .67922 .72677 L .7067 .73184 L p .707 .577 .707 r
F P
0 g
s
.67922 .72677 m .67718 .69146 L .65607 .68305 L p .707 .577 .707 r
F P
0 g
s
.73963 .77906 m .73858 .76143 L .70743 .76022 L p .707 .577 .707 r
F P
0 g
s
.73858 .76143 m .73963 .77906 L .7714 .77627 L p .707 .577 .707 r
F P
0 g
s
.7714 .77627 m .77036 .75864 L .73858 .76143 L p .707 .577 .707 r
F P
0 g
s
.77036 .75864 m .7714 .77627 L .8007 .76976 L p .707 .577 .707 r
F P
0 g
s
.8007 .76976 m .79965 .75213 L .77036 .75864 L p .707 .577 .707 r
F P
0 g
s
.83515 .5867 m .837 .64083 L .84404 .62987 L p .707 .577 .707 r
F P
0 g
s
.84404 .62987 m .84219 .57573 L .83515 .5867 L p .707 .577 .707 r
F P
0 g
s
.70847 .77785 m .70743 .76022 L .67995 .75514 L p .707 .577 .707 r
F P
0 g
s
.70743 .76022 m .70847 .77785 L .73963 .77906 L p .707 .577 .707 r
F P
0 g
s
.82084 .67909 m .82288 .7144 L .83912 .70277 L p .707 .577 .707 r
F P
0 g
s
.83912 .70277 m .83709 .66746 L .82084 .67909 L p .707 .577 .707 r
F P
0 g
s
.65607 .68305 m .65811 .71836 L .67922 .72677 L p .707 .577 .707 r
F P
0 g
s
.79965 .75213 m .8007 .76976 L .82463 .76016 L p .707 .577 .707 r
F P
0 g
s
.82463 .76016 m .82359 .74253 L .79965 .75213 L p .707 .577 .707 r
F P
0 g
s
.67995 .75514 m .681 .77276 L .70847 .77785 L p .707 .577 .707 r
F P
0 g
s
.65754 .26212 m .62164 .77937 L .59178 .77401 L p .707 .577 .707 r
F P
0 g
s
.59178 .77401 m .62768 .25676 L .65754 .26212 L p .707 .577 .707 r
F P
0 g
s
.681 .77276 m .67995 .75514 L .65883 .74667 L p .707 .577 .707 r
F P
0 g
s
.65883 .74667 m .65988 .7643 L .681 .77276 L p .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .3664 .76426 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .38923 .76202 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.42512 .24476 m .45882 .24415 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .40642 .51423 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .42512 .24476 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.42261 .57752 m .42245 .57307 L .42149 .57313 L p .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .38923 .76202 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.42245 .57307 m .42261 .57752 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .43389 .60337 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .42292 .7614 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.47547 .60008 m .4642 .76248 L p .44794 .61369 L .707 .577 .707 r
F P
0 g
s
.4467 .60236 m .45297 .60186 L .44794 .61369 L .707 .577 .707 r
F
.45297 .60186 m .47547 .60008 L .44794 .61369 L F
.4518 .56784 m .45297 .60186 L p .46069 .58368 L F P
0 g
s
.4518 .56784 m .42245 .57307 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45365 .62197 m .45297 .60186 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45297 .60186 m .4518 .56784 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .47547 .60008 L p .45297 .60186 L .707 .577 .707 r
F P
0 g
s
.5001 .24522 m .54491 .24787 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .47972 .53888 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .5001 .24522 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47582 .55984 L .47368 .56056 L p .707 .577 .707 r
F P
0 g
s
.47368 .56056 m .46999 .56178 L p .47115 .56966 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47368 .56056 L .47115 .56966 L .707 .577 .707 r
F
.46999 .56178 m .4518 .56784 L p .46069 .58368 L F P
0 g
s
.47767 .61398 m .46999 .56178 L .46069 .58368 L .707 .577 .707 r
F
.5001 .24522 m .47972 .53888 L p .4467 .60236 L F P
0 g
s
.4467 .60236 m .47972 .53888 L .45297 .60186 L .707 .577 .707 r
F
.45365 .62197 m .47767 .61398 L p .46069 .58368 L F P
0 g
s
.45297 .60186 m .45365 .62197 L p .46069 .58368 L .707 .577 .707 r
F P
0 g
s
.44286 .6239 m .45365 .62197 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.44031 .60286 m .42261 .57752 L .43389 .60337 L .707 .577 .707 r
F
.44031 .60286 m .43389 .60337 L .44286 .6239 L F
.45365 .62197 m .44141 .60277 L .44031 .60286 L F
.44141 .60277 m .42245 .57307 L .44031 .60286 L F
.45882 .24415 m .5001 .24522 L p .4467 .60236 L F P
0 g
s
.43389 .60337 m .45882 .24415 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.45882 .24415 m .43389 .60337 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.43279 .61928 m .42292 .7614 L p .41704 .59132 L .707 .577 .707 r
F P
0 g
s
.45592 .68708 m .4542 .65728 L p .42459 .6582 L .707 .577 .707 r
F P
0 g
s
.4542 .65728 m .45388 .65177 L .4514 .65232 L p .707 .577 .707 r
F P
0 g
s
.4514 .65232 m .42459 .6582 L p .4542 .65728 L .707 .577 .707 r
F P
0 g
s
.43389 .60337 m .43279 .61928 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.41604 .56248 m .43279 .61928 L .41704 .59132 L .707 .577 .707 r
F
.42261 .57752 m .4243 .62721 L .44286 .6239 L p F P
0 g
s
.4243 .62721 m .42261 .57752 L p .39064 .57504 L .707 .577 .707 r
F P
0 g
s
.42149 .57313 m .39064 .57504 L p .42261 .57752 L .707 .577 .707 r
F P
0 g
s
.39064 .57504 m .39249 .62918 L .41659 .62769 L p .707 .577 .707 r
F P
0 g
s
.41659 .62769 m .4243 .62721 L p .4153 .61325 L .707 .577 .707 r
F P
0 g
s
.4153 .61325 m .39064 .57504 L .41659 .62769 L .707 .577 .707 r
F
.42512 .24476 m .40642 .51423 L p .40122 .45621 L F P
0 g
s
.82359 .74253 m .82463 .76016 L .84088 .74842 L p .707 .577 .707 r
F P
0 g
s
.84088 .74842 m .83983 .73079 L .82359 .74253 L p .707 .577 .707 r
F P
0 g
s
.83709 .66746 m .83912 .70277 L .84609 .69014 L p .707 .577 .707 r
F P
0 g
s
.84609 .69014 m .84405 .65484 L .83709 .66746 L p .707 .577 .707 r
F P
0 g
s
.84219 .57573 m .84404 .62987 L .84111 .61898 L p .707 .577 .707 r
F P
0 g
s
.84111 .61898 m .83926 .56485 L .84219 .57573 L p .707 .577 .707 r
F P
0 g
s
.64339 .67211 m .64543 .70742 L .65811 .71836 L p .707 .577 .707 r
F P
0 g
s
.63838 .57729 m .64023 .63143 L .64317 .64231 L p .707 .577 .707 r
F P
0 g
s
.65988 .7643 m .65883 .74667 L .64615 .73566 L p .707 .577 .707 r
F P
0 g
s
.64543 .70742 m .64339 .67211 L .64039 .65973 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64023 .63143 m .63838 .57729 L .64542 .56633 L p .707 .577 .707 r
F P
0 g
s
.62768 .25676 m .59178 .77401 L .55297 .7691 L p .707 .577 .707 r
F P
0 g
s
.55297 .7691 m .58887 .25185 L .62768 .25676 L p .707 .577 .707 r
F P
0 g
s
.64615 .73566 m .6472 .75328 L .65988 .7643 L p .707 .577 .707 r
F P
0 g
s
.83983 .73079 m .84088 .74842 L .84783 .73568 L p .707 .577 .707 r
F P
0 g
s
.84783 .73568 m .84679 .71805 L .83983 .73079 L p .707 .577 .707 r
F P
0 g
s
.84405 .65484 m .84609 .69014 L .84308 .67776 L p .707 .577 .707 r
F P
0 g
s
.84308 .67776 m .84104 .64245 L .84405 .65484 L p .707 .577 .707 r
F P
0 g
s
.64039 .65973 m .64243 .69503 L .64543 .70742 L p .707 .577 .707 r
F P
0 g
s
.83926 .56485 m .84111 .61898 L .82848 .60924 L p .707 .577 .707 r
F P
0 g
s
.82848 .60924 m .82663 .55511 L .83926 .56485 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64542 .56633 m .64727 .62046 L .64023 .63143 L p .707 .577 .707 r
F P
0 g
s
.6472 .75328 m .64615 .73566 L .64314 .72317 L p .707 .577 .707 r
F P
0 g
s
.58887 .25185 m .55297 .7691 L .50901 .76513 L p .707 .577 .707 r
F P
0 g
s
.50901 .76513 m .54491 .24787 L .58887 .25185 L p .707 .577 .707 r
F P
0 g
s
.64243 .69503 m .64039 .65973 L .64735 .6471 L p .707 .577 .707 r
F P
0 g
s
.39249 .62918 m .39064 .57504 L .35947 .57356 L p .707 .577 .707 r
F P
0 g
s
.64727 .62046 m .64542 .56633 L .66175 .55637 L p .707 .577 .707 r
F P
0 g
s
.64314 .72317 m .64419 .74079 L .6472 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.54491 .24787 m .50901 .76513 L .4642 .76248 L p .707 .577 .707 r
F P
0 g
s
.36132 .62769 m .35947 .57356 L .33201 .56875 L p .707 .577 .707 r
F P
0 g
s
.35947 .57356 m .36132 .62769 L .39249 .62918 L p .707 .577 .707 r
F P
0 g
s
.84679 .71805 m .84783 .73568 L .84482 .72319 L p .707 .577 .707 r
F P
0 g
s
.84482 .72319 m .84377 .70556 L .84679 .71805 L p .707 .577 .707 r
F P
0 g
s
.84104 .64245 m .84308 .67776 L .8304 .66682 L p .707 .577 .707 r
F P
0 g
s
.8304 .66682 m .82837 .63151 L .84104 .64245 L p .707 .577 .707 r
F P
0 g
s
.82663 .55511 m .82848 .60924 L .80741 .60159 L p .707 .577 .707 r
F P
0 g
s
.80741 .60159 m .80556 .54746 L .82663 .55511 L p .707 .577 .707 r
F P
0 g
s
.64735 .6471 m .64939 .68241 L .64243 .69503 L p .707 .577 .707 r
F P
0 g
s
.66175 .55637 m .6636 .6105 L .64727 .62046 L p .707 .577 .707 r
F P
0 g
s
.33386 .62289 m .33201 .56875 L .31093 .5611 L p .707 .577 .707 r
F P
0 g
s
.33201 .56875 m .33386 .62289 L .36132 .62769 L p .707 .577 .707 r
F P
0 g
s
.64419 .74079 m .64314 .72317 L .6501 .71043 L p .707 .577 .707 r
F P
0 g
s
.6636 .6105 m .66175 .55637 L .68576 .54837 L p .707 .577 .707 r
F P
0 g
s
.64939 .68241 m .64735 .6471 L .6636 .63547 L p .707 .577 .707 r
F P
0 g
s
.39484 .69625 m .3928 .66094 L .36165 .65971 L p .707 .577 .707 r
F P
0 g
s
.3928 .66094 m .39484 .69625 L .42662 .69351 L p .707 .577 .707 r
F P
0 g
s
.42662 .69351 m .42459 .6582 L .3928 .66094 L p .707 .577 .707 r
F P
0 g
s
.6501 .71043 m .65114 .72805 L .64419 .74079 L p .707 .577 .707 r
F P
0 g
s
.42459 .6582 m .42662 .69351 L .45592 .68708 L p .707 .577 .707 r
F P
0 g
s
.47582 .55984 m .47767 .61398 L .49399 .60401 L p .707 .577 .707 r
F P
0 g
s
.49399 .60401 m .49214 .54988 L .47582 .55984 L p .707 .577 .707 r
F P
0 g
s
.80556 .54746 m .80741 .60159 L .77994 .59679 L p .707 .577 .707 r
F P
0 g
s
.77994 .59679 m .77809 .54266 L .80556 .54746 L p .707 .577 .707 r
F P
0 g
s
.36369 .69502 m .36165 .65971 L .33417 .65465 L p .707 .577 .707 r
F P
0 g
s
.36165 .65971 m .36369 .69502 L .39484 .69625 L p .707 .577 .707 r
F P
0 g
s
.84377 .70556 m .84482 .72319 L .83214 .71217 L p .707 .577 .707 r
F P
0 g
s
.83214 .71217 m .83109 .69455 L .84377 .70556 L p .707 .577 .707 r
F P
0 g
s
.82837 .63151 m .8304 .66682 L .80929 .65841 L p .707 .577 .707 r
F P
0 g
s
.80929 .65841 m .80725 .6231 L .82837 .63151 L p .707 .577 .707 r
F P
0 g
s
.31093 .5611 m .31278 .61524 L .33386 .62289 L p .707 .577 .707 r
F P
0 g
s
.6636 .63547 m .66564 .67078 L .64939 .68241 L p .707 .577 .707 r
F P
0 g
s
.45388 .65177 m .45592 .68708 L .47987 .67759 L p .707 .577 .707 r
F P
0 g
s
.47987 .67759 m .47783 .64228 L .45388 .65177 L p .707 .577 .707 r
F P
0 g
s
.68761 .60251 m .68576 .54837 L .71511 .54314 L p .707 .577 .707 r
F P
0 g
s
.68576 .54837 m .68761 .60251 L .6636 .6105 L p .707 .577 .707 r
F P
0 g
s
.31278 .61524 m .31093 .5611 L .29831 .55136 L p .707 .577 .707 r
F P
0 g
s
.33417 .65465 m .33621 .68995 L .36369 .69502 L p .707 .577 .707 r
F P
0 g
s
.33621 .68995 m .33417 .65465 L .31306 .64623 L p .707 .577 .707 r
F P
0 g
s
.77809 .54266 m .77994 .59679 L .74878 .5953 L p .707 .577 .707 r
F P
0 g
s
.74878 .5953 m .74693 .54117 L .77809 .54266 L p .707 .577 .707 r
F P
0 g
s
.65114 .72805 m .6501 .71043 L .66634 .69868 L p .707 .577 .707 r
F P
0 g
s
.66564 .67078 m .6636 .63547 L .68755 .62598 L p .707 .577 .707 r
F P
0 g
s
.39662 .74224 m .39557 .72462 L .36442 .72341 L p .707 .577 .707 r
F P
0 g
s
.39557 .72462 m .39662 .74224 L .42839 .73945 L p .707 .577 .707 r
F P
0 g
s
.42839 .73945 m .42735 .72183 L .39557 .72462 L p .707 .577 .707 r
F P
0 g
s
.42735 .72183 m .42839 .73945 L .45769 .73294 L p .707 .577 .707 r
F P
0 g
s
.45769 .73294 m .45664 .71532 L .42735 .72183 L p .707 .577 .707 r
F P
0 g
s
.71696 .59727 m .71511 .54314 L .74693 .54117 L p .707 .577 .707 r
F P
0 g
s
.71511 .54314 m .71696 .59727 L .68761 .60251 L p .707 .577 .707 r
F P
0 g
s
.49214 .54988 m .49399 .60401 L .50103 .59305 L p .707 .577 .707 r
F P
0 g
s
.50103 .59305 m .49918 .53892 L .49214 .54988 L p .707 .577 .707 r
F P
0 g
s
.74693 .54117 m .74878 .5953 L .71696 .59727 L p .707 .577 .707 r
F P
0 g
s
.66634 .69868 m .66739 .71631 L .65114 .72805 L p .707 .577 .707 r
F P
0 g
s
.36546 .74103 m .36442 .72341 L .33694 .71832 L p .707 .577 .707 r
F P
0 g
s
.36442 .72341 m .36546 .74103 L .39662 .74224 L p .707 .577 .707 r
F P
0 g
s
.47783 .64228 m .47987 .67759 L .49611 .66596 L p .707 .577 .707 r
F P
0 g
s
.49611 .66596 m .49408 .63065 L .47783 .64228 L p .707 .577 .707 r
F P
0 g
s
.80725 .6231 m .80929 .65841 L .78182 .65334 L p .707 .577 .707 r
F P
0 g
s
.78182 .65334 m .77978 .61803 L .80725 .6231 L p .707 .577 .707 r
F P
0 g
s
.83109 .69455 m .83214 .71217 L .81103 .7037 L p .707 .577 .707 r
F P
0 g
s
.81103 .7037 m .80998 .68608 L .83109 .69455 L p .707 .577 .707 r
F P
0 g
s
.29831 .55136 m .30016 .60549 L .31278 .61524 L p .707 .577 .707 r
F P
0 g
s
.31306 .64623 m .3151 .68154 L .33621 .68995 L p .707 .577 .707 r
F P
0 g
s
.45664 .71532 m .45769 .73294 L .48162 .72334 L p .707 .577 .707 r
F P
0 g
s
.48162 .72334 m .48058 .70572 L .45664 .71532 L p .707 .577 .707 r
F P
0 g
s
.68755 .62598 m .68959 .66128 L .66564 .67078 L p .707 .577 .707 r
F P
0 g
s
.33694 .71832 m .33799 .73595 L .36546 .74103 L p .707 .577 .707 r
F P
0 g
s
.68959 .66128 m .68755 .62598 L .71684 .61955 L p .707 .577 .707 r
F P
0 g
s
.30016 .60549 m .29831 .55136 L .29537 .54048 L p .707 .577 .707 r
F P
0 g
s
.3151 .68154 m .31306 .64623 L .30038 .6353 L p .707 .577 .707 r
F P
0 g
s
.33799 .73595 m .33694 .71832 L .31582 .70986 L p .707 .577 .707 r
F P
0 g
s
.66739 .71631 m .66634 .69868 L .69028 .68909 L p .707 .577 .707 r
F P
0 g
s
.77978 .61803 m .78182 .65334 L .75066 .65212 L p .707 .577 .707 r
F P
0 g
s
.75066 .65212 m .74862 .61681 L .77978 .61803 L p .707 .577 .707 r
F P
0 g
s
.71888 .65485 m .71684 .61955 L .74862 .61681 L p .707 .577 .707 r
F P
0 g
s
.71684 .61955 m .71888 .65485 L .68959 .66128 L p .707 .577 .707 r
F P
0 g
s
.74862 .61681 m .75066 .65212 L .71888 .65485 L p .707 .577 .707 r
F P
0 g
s
.31582 .70986 m .31687 .72748 L .33799 .73595 L p .707 .577 .707 r
F P
0 g
s
.69028 .68909 m .69133 .70671 L .66739 .71631 L p .707 .577 .707 r
F P
0 g
s
.48058 .70572 m .48162 .72334 L .49787 .7116 L p .707 .577 .707 r
F P
0 g
s
.49787 .7116 m .49682 .69398 L .48058 .70572 L p .707 .577 .707 r
F P
0 g
s
.80998 .68608 m .81103 .7037 L .78355 .69862 L p .707 .577 .707 r
F P
0 g
s
.78355 .69862 m .7825 .68099 L .80998 .68608 L p .707 .577 .707 r
F P
0 g
s
.49408 .63065 m .49611 .66596 L .50308 .65333 L p .707 .577 .707 r
F P
0 g
s
.50308 .65333 m .50104 .61802 L .49408 .63065 L p .707 .577 .707 r
F P
0 g
s
.49918 .53892 m .50103 .59305 L .4981 .58217 L p .707 .577 .707 r
F P
0 g
s
.4981 .58217 m .49625 .52803 L .49918 .53892 L p .707 .577 .707 r
F P
0 g
s
.30038 .6353 m .30242 .67061 L .3151 .68154 L p .707 .577 .707 r
F P
0 g
s
.29537 .54048 m .29722 .59461 L .30016 .60549 L p .707 .577 .707 r
F P
0 g
s
.69133 .70671 m .69028 .68909 L .71957 .68258 L p .707 .577 .707 r
F P
0 g
s
.31687 .72748 m .31582 .70986 L .30314 .69884 L p .707 .577 .707 r
F P
0 g
s
.30242 .67061 m .30038 .6353 L .29738 .62291 L p .707 .577 .707 r
F P
0 g
s
.7825 .68099 m .78355 .69862 L .75239 .69741 L p .707 .577 .707 r
F P
0 g
s
.75239 .69741 m .75135 .67979 L .7825 .68099 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29722 .59461 m .29537 .54048 L .30241 .52952 L p .707 .577 .707 r
F P
0 g
s
.71957 .68258 m .72062 .7002 L .69133 .70671 L p .707 .577 .707 r
F P
0 g
s
.72062 .7002 m .71957 .68258 L .75135 .67979 L p .707 .577 .707 r
F P
0 g
s
.30314 .69884 m .30419 .71647 L .31687 .72748 L p .707 .577 .707 r
F P
0 g
s
.75135 .67979 m .75239 .69741 L .72062 .7002 L p .707 .577 .707 r
F P
0 g
s
.49682 .69398 m .49787 .7116 L .50482 .69886 L p .707 .577 .707 r
F P
0 g
s
.50482 .69886 m .50378 .68124 L .49682 .69398 L p .707 .577 .707 r
F P
0 g
s
.50104 .61802 m .50308 .65333 L .50007 .64094 L p .707 .577 .707 r
F P
0 g
s
.50007 .64094 m .49803 .60563 L .50104 .61802 L p .707 .577 .707 r
F P
0 g
s
.29738 .62291 m .29942 .65822 L .30242 .67061 L p .707 .577 .707 r
F P
0 g
s
.49625 .52803 m .4981 .58217 L .48547 .57243 L p .707 .577 .707 r
F P
0 g
s
.48547 .57243 m .48362 .51829 L .49625 .52803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30241 .52952 m .30426 .58365 L .29722 .59461 L p .707 .577 .707 r
F P
0 g
s
.30419 .71647 m .30314 .69884 L .30013 .68635 L p .707 .577 .707 r
F P
0 g
s
.29942 .65822 m .29738 .62291 L .30434 .61028 L p .707 .577 .707 r
F P
0 g
s
.30426 .58365 m .30241 .52952 L .31874 .51955 L p .707 .577 .707 r
F P
0 g
s
.30013 .68635 m .30118 .70398 L .30419 .71647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50378 .68124 m .50482 .69886 L .50181 .68637 L p .707 .577 .707 r
F P
0 g
s
.50181 .68637 m .50076 .66875 L .50378 .68124 L p .707 .577 .707 r
F P
0 g
s
.49803 .60563 m .50007 .64094 L .48739 .63001 L p .707 .577 .707 r
F P
0 g
s
.48739 .63001 m .48535 .5947 L .49803 .60563 L p .707 .577 .707 r
F P
0 g
s
.48362 .51829 m .48547 .57243 L .4644 .56478 L p .707 .577 .707 r
F P
0 g
s
.4644 .56478 m .46255 .51064 L .48362 .51829 L p .707 .577 .707 r
F P
0 g
s
.30434 .61028 m .30638 .64559 L .29942 .65822 L p .707 .577 .707 r
F P
0 g
s
.31874 .51955 m .32059 .57369 L .30426 .58365 L p .707 .577 .707 r
F P
0 g
s
.30118 .70398 m .30013 .68635 L .30709 .67361 L p .707 .577 .707 r
F P
0 g
s
.32059 .57369 m .31874 .51955 L .34275 .51156 L p .707 .577 .707 r
F P
0 g
s
.30638 .64559 m .30434 .61028 L .32059 .59865 L p .707 .577 .707 r
F P
0 g
s
.30709 .67361 m .30813 .69124 L .30118 .70398 L p .707 .577 .707 r
F P
0 g
s
.46255 .51064 m .4644 .56478 L .43693 .55997 L p .707 .577 .707 r
F P
0 g
s
.43693 .55997 m .43508 .50584 L .46255 .51064 L p .707 .577 .707 r
F P
0 g
s
.50076 .66875 m .50181 .68637 L .48913 .67535 L p .707 .577 .707 r
F P
0 g
s
.48913 .67535 m .48808 .65773 L .50076 .66875 L p .707 .577 .707 r
F P
0 g
s
.48535 .5947 m .48739 .63001 L .46628 .62159 L p .707 .577 .707 r
F P
0 g
s
.46628 .62159 m .46424 .58629 L .48535 .5947 L p .707 .577 .707 r
F P
0 g
s
.32059 .59865 m .32263 .63396 L .30638 .64559 L p .707 .577 .707 r
F P
0 g
s
.3446 .56569 m .34275 .51156 L .3721 .50632 L p .707 .577 .707 r
F P
0 g
s
.34275 .51156 m .3446 .56569 L .32059 .57369 L p .707 .577 .707 r
F P
0 g
s
.43508 .50584 m .43693 .55997 L .40577 .55848 L p .707 .577 .707 r
F P
0 g
s
.40577 .55848 m .40392 .50435 L .43508 .50584 L p .707 .577 .707 r
F P
0 g
s
.30813 .69124 m .30709 .67361 L .32333 .66187 L p .707 .577 .707 r
F P
0 g
s
.32263 .63396 m .32059 .59865 L .34454 .58916 L p .707 .577 .707 r
F P
0 g
s
.37395 .56046 m .3721 .50632 L .40392 .50435 L p .707 .577 .707 r
F P
0 g
s
.3721 .50632 m .37395 .56046 L .3446 .56569 L p .707 .577 .707 r
F P
0 g
s
.40392 .50435 m .40577 .55848 L .37395 .56046 L p .707 .577 .707 r
F P
0 g
s
.32333 .66187 m .32438 .67949 L .30813 .69124 L p .707 .577 .707 r
F P
0 g
s
.46424 .58629 m .46628 .62159 L .43881 .61653 L p .707 .577 .707 r
F P
0 g
s
.43881 .61653 m .43677 .58122 L .46424 .58629 L p .707 .577 .707 r
F P
0 g
s
.48808 .65773 m .48913 .67535 L .46801 .66689 L p .707 .577 .707 r
F P
0 g
s
.46801 .66689 m .46697 .64926 L .48808 .65773 L p .707 .577 .707 r
F P
0 g
s
.34454 .58916 m .34658 .62447 L .32263 .63396 L p .707 .577 .707 r
F P
0 g
s
.34658 .62447 m .34454 .58916 L .37383 .58273 L p .707 .577 .707 r
F P
0 g
s
.32438 .67949 m .32333 .66187 L .34727 .65227 L p .707 .577 .707 r
F P
0 g
s
.43677 .58122 m .43881 .61653 L .40765 .6153 L p .707 .577 .707 r
F P
0 g
s
.40765 .6153 m .40561 .57999 L .43677 .58122 L p .707 .577 .707 r
F P
0 g
s
.37587 .61804 m .37383 .58273 L .40561 .57999 L p .707 .577 .707 r
F P
0 g
s
.37383 .58273 m .37587 .61804 L .34658 .62447 L p .707 .577 .707 r
F P
0 g
s
.40561 .57999 m .40765 .6153 L .37587 .61804 L p .707 .577 .707 r
F P
0 g
s
.34727 .65227 m .34832 .6699 L .32438 .67949 L p .707 .577 .707 r
F P
0 g
s
.46697 .64926 m .46801 .66689 L .44054 .6618 L p .707 .577 .707 r
F P
0 g
s
.44054 .6618 m .43949 .64418 L .46697 .64926 L p .707 .577 .707 r
F P
0 g
s
.34832 .6699 m .34727 .65227 L .37656 .64576 L p .707 .577 .707 r
F P
0 g
s
.43949 .64418 m .44054 .6618 L .40938 .6606 L p .707 .577 .707 r
F P
0 g
s
.40938 .6606 m .40834 .64297 L .43949 .64418 L p .707 .577 .707 r
F P
0 g
s
.37656 .64576 m .37761 .66338 L .34832 .6699 L p .707 .577 .707 r
F P
0 g
s
.37761 .66338 m .37656 .64576 L .40834 .64297 L p .707 .577 .707 r
F P
0 g
s
.40834 .64297 m .40938 .6606 L .37761 .66338 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
MWoo7P00RGoo001aOol50002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP03FUH=001l
Ool006moo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00AJEPT007=oo`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H006eoo`00Kgoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPH006Mo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH6001QOol006moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH00002001NOol006moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001LOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006mo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005]oo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP03FUH0
1000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000GWoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol0
06]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF
0003FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP000UYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00
Jgoo00@005YFFUH0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`04001JEUYF
0002FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00003FUH01000FUIJ
EP0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo
001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUIJEP0A000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Ioo`P000AJ
EP03001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00H7oo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001LOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol005Yoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00F7oo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HGoo001FOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001EOol00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00HGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001DOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00HGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0057oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo2@0015YF00<005YFFUH0
0UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000Aoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP00008003Aoo`00Dgoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH=0005FUH80004FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEPD000=oo`05001JEUYF001JEP05
0009FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool01000FUIJEP0015YF00@005YFFUIJEP8000Qoo`05001JEUYF001JEP050009FUH00`00FUIJEP07
FUH200000eYF001JEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00D0
05YF000005YF00@000Eoo`05001JEUYF001JEP050009FUH00`00FUIJEP08FUH30003FUH20005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH015YF500015YF00<005YF
FUH025YF00@005YFFUH0009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF2P000UYF00<005YFFUH02EYF00@005YFFUIJEP@000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00EJEP03001JEP00
00H000AJEP03001JEUYF009JEPP000MJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP<00003FUH005YF00=JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
Agoo3`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00P0015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000oOol80004FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol60003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
10001Woo1@002Woo10000UYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH4
000:Ool5000;Ool70004FUH01@00FUIJEUYF0000;Goo000cOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001J
EP0000@000eoo`D000Moo`@00003FUH005YF00AJEP<00003FUH005YF009JEP03001oogoo02]oo`00
<Goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00FUH00004FUH200000eYF001JEP02FUH90005Ool300000goo000000050005FUH00`00
FUIJEP04FUH01000FUH000000eYF00<007ooOol0:goo000_Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJ
EPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH?0002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0
00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF008000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@0
00IJEP8000=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00001JEP020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001J
EUYFFUH200000eYF0000000H000:FUH300000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF0P0015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP000eYF00@005YF000000=JEP07001JEUYFFUH007oo00000UYF00<005YF
FUH01@0025YF00<005YFFUH025YF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEUYFFUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001J
EP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF0`001EYF00H005YFFUH007oo0002FUH00`00FUIJEP050008
FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000^Ool002aoo`03001J
EP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0002FUH01000FUIJEP001EYF00P005YFFUH007oo001JEP000eYF1@0025YF00<005YFFUH025YF
00@005YF0000009JEP@0009JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH00000;Woo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP08FUH20004FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF
000000050004FUH01000FUIJEUYF20001EYF0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH00UYF2@002Goo1P0000AJ
EP000000009JEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH50002FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH50009Ool3000:Ool2000015YF001JEUYF1000
0UYF10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF10001EYF00<005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YFFUH0
02eoo`00;7oo00@005YFFUH000AJEP04001JEUYFFUH2000=Ool50009Ool01000FUIJEP0015YF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
15YF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00;Goo00<005YF000015YF00D005YF000005YF00@000Yoo`D000Qoo`80
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP800003FUH005YF
00AJEQT0009JEP03001JEUYF008000IJEP03001JEUYF00AJEPH000QJEPT000AJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF000015YF00<005YFFUH00eYF2P0015YF00<005YFFUH00UYF2@002Goo0`0000EJEP00FUIJ
EP0002eoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP<000MJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEPD000AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEP0000@000=JEP8000Aoo`T001Eoo`80009JEP03001o
ogoo02]oo`00;Goo00<005YF00000P001EYF00<005YFFUH00`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF0P0015YF00@005YFFUIJEP8000Moo`D001Moo`800003
FUH007oo02aoo`00;Goo00D005YF001JEP0000EJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH200001EYF001JEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUH00005FUH00`00FUIJEP020007Ool5000FOol0
0`00FUH00002000]Ool002eoo`80009JEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH20002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP020007Ool5000EOol01@00FUIJEP00FUH00P00;7oo000]Ool20002FUH00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH200000eYF001JEP06
FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF00<0
05YFFUH00eYF00<005YFFUH00P0027oo3`0027oo0P000eYF00@005YF000002aoo`00;Goo0P000UYF
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P000eYF
00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YF00000P001eYF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P00
0UYF00<005YFFUH00eYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEP0000L00003FUH0
05YF009JEP04001JEP00000/Ool002eoo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP800003FUH005YF00IJEP03
001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJEP800003FUH005YF00aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUH000020004FUH60003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0
000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@00003FUH005YF
009JEP03001JEUYF00EJEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUH0000/Ool002ioo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF009JEQX0
00EJEP05001JEUYFFUH00007FUH01@00FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0006FUH30000
15YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000009J
EP8000EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP@002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00@005YFFUIJEPH0009JEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH01000FUH000001UYF00<005YFFUH00UYF2@0025YF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH6
0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@000AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001J
EP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030004FUH01000FUIJEP00
;Goo000]Ool00`00FUH00004FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP80009JEP8000Aoo`<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH300000eYF001JEP03FUH01@00FUIJEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00005FUH005YFFUH0000]
Ool002eoo`04001JEUYF0003FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030002FUH30006Ool20002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
1eYF0P000eYF00<005YFFUH00UYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001oogoo02]oo`00;Goo00@005YFFUH0
00=JEP8000Eooa`0009JEP03001JEUYF008000Eoo`800005FUH005YFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJ
EP000UYF00<007ooOol02Woo2@0015YF00<005YFFUH01EYF00<005YF00000UYF00@005YFFUIJEPD0
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@00003FUH005YF00EJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEP00
008000Ioo`<002aoo`00;Goo00<005YFFUH00`001goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00@005YFFUIJEPT000=JEP03001JEUYF00=JEPL000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEUYF001JEP00FUH00`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH015YF10002Woo0P00;7oo000^Ool01000FUH000001Woo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP020004FUH40005FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP04000>Ool2000/Ool002ioo`80009JEP80009oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00@005YFFUIJEP@00003FUH005YF00MJ
EP<0009JEPL0015oo`03001JEP0002aoo`00;Woo0P000UYF00@005YF000000IJEP03001JEUYF00EJ
EP03001JEUYF009JEPl000EJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000IJEP03001JEUYF00=JEP03001JEP0000h001Moo`800003FUH007oo02]oo`00;Woo00@0
05YFFUIJEP<000MJEP03001JEUYF009JEPP000]oo`P0009JEPH000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEPD000AJEP03001JEUYF00=JEP04001JEUYF000SOol01@00FUH0
05YF0000;7oo000^Ool01`00FUIJEUYF001JEP0000IJEPT000Uoo`L000IJEP03001JEP0000<000AJ
EPP000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0009JEPH000AJEP04001JEUYF000ROol01000FUIJEUYF
0P00;7oo000^Ool01000FUIJEP000eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEPT000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<00003FUH00000009JEP04001JEUYFFUH90003FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200001EYF00000000FUH01`0000EJEP00FUIJEP00021oo`8000AJEP03001oogoo02]oo`00
;Woo00<005YF000015YF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP8000Moo`80009JEP03001oogoo01Yoo`@00003FUH005YF00=JEP03001oogoo
02]oo`00;Woo0`0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YF00000P001Woo00<005YF000067oo10001EYF00D005YFFUIJEP00
02ioo`00;goo0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP02FUH30002Ool4000DOol40002FUH00`00FUIJEP04FUH01000FUH00000
;goo000^Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<00003FUH0000000aoo`L000IJ
EP03001JEUYF00AJEP80035oo`00;Woo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000Eoo`04001JEUYF0003FUHN0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00<Woo000^Ool0
1000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000Moo`03001JEP0000@001=JEP03001JEUYF00QJEPd000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Aoo`00;Woo0P0017oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002Goo0P0065YF
00<005YFFUH02EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>7oo000^Ool20007Ool50004FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04000:Ool200000eYF
0000000GFUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000kOol002ioo`<000]oo`T0009JEPD0009JEPL000eoo`04001JEUYFFUH4000EFUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000050004FUH00`00FUIJEP02
FUH00`00FUH00003FUH60002FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000oOol002io
o`800003FUH007oo019oo`T0019oo`8000AJEP80009oo`H000mJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEPH000=JEP03001JEP0000=JEP03001JEUYF00=JEP<0
0003FUH005YF010004Ioo`00;Woo0P000UYF0P004goo1@0047oo100000=JEP00FUH00eYF00<007oo
Ool01goo1`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomo
o`1BOol002moo`05001JEUYF001JEP03000AOol3000>Ool30005FUH01@00FUIJEUYF00004Goo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2001COol002moo`04001J
EUYF0004FUH3000KOol400000eYF001JEP05FUH01000FUH0000067oo20001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF00<00003FUH007oo059oo`00<7oo00@005YFFUH000AJEP03001JEP0000<0011oo`L0
00EJEP03001JEUYF00AJEP80029oo`d000IJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH50006FUH00`00FUIJEP03FUH30003Ool2001COol0035oo`<000AJEP03001JEUYF00=JEQ0000AJ
EP03001JEUYF00IJEP03001JEUYF009JEP8002eoo`03001JEUYF01l0009JEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo00=oo`8005=oo`00<goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00;goo00D005YFFUH007oo008000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0005Ool00`00FUH0001COol003Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@0039oo`03001JEP0000Aoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool00`00FUH0001COol003Qoo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003Moo`8000Moo`<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000Qoo`800003FUH007oo059oo`00>goo100000=JEP00
FUH01eYF00<005YFFUH00UYF1`00>goo0P002Woo100000=JEP00FUH01eYF0`000UYF2@0037oo0P00
00AJEP00FUH005=oo`00?goo3`00@Woo00@005YF000000aoo`l001=oo`8000AJEP03001oogoo059o
o`00T7oo00D005YFFUIJEP0001Aoo`D0019oo`800003FUH005YF00=JEP03001oogoo059oo`00T7oo
00@005YFFUIJEP<0019oo`D0011oo`8000=JEP03001JEUYF009JEP03001oogoo059oo`00T7oo00D0
05YFFUIJEP00009JEP80015oo`<000eoo`@000EJEP03001JEUYF008005Eoo`00TGoo00@005YFFUH0
00AJEPD001Qoo`@0009JEP03001JEUYF00AJEP<005Moo`00TWoo0`001EYF00@005YFFUIJEQP000IJ
EP03001JEUYF00=JEP8005Uoo`00U7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8005]oo`00UGoo0P000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005eoo`00Ugoo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00Ggoo002IOol5
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04001ROol009ioo`T000AJEP03001J
EUYF009JEPL006Ioo`00Ygoo2@00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59423 .74459 m .59608 .68798 L .56491 .68566 L p .707 .577 .707 r
F P
0 g
s
.59608 .68798 m .59423 .74459 L .62605 .74504 L p .707 .577 .707 r
F P
0 g
s
.62605 .74504 m .6279 .68842 L .59608 .68798 L p .707 .577 .707 r
F P
0 g
s
.6279 .68842 m .62605 .74504 L .6554 .74356 L p .707 .577 .707 r
F P
0 g
s
.6554 .74356 m .65725 .68694 L .6279 .68842 L p .707 .577 .707 r
F P
0 g
s
.56307 .74227 m .56491 .68566 L .53745 .68169 L p .707 .577 .707 r
F P
0 g
s
.56491 .68566 m .56307 .74227 L .59423 .74459 L p .707 .577 .707 r
F P
0 g
s
.65725 .68694 m .6554 .74356 L .67941 .74031 L p .707 .577 .707 r
F P
0 g
s
.67941 .74031 m .68126 .68369 L .65725 .68694 L p .707 .577 .707 r
F P
0 g
s
.59234 .80394 m .59438 .7659 L .56323 .7633 L p .707 .577 .707 r
F P
0 g
s
.59438 .7659 m .59234 .80394 L .62412 .8052 L p .707 .577 .707 r
F P
0 g
s
.62412 .8052 m .62616 .76715 L .59438 .7659 L p .707 .577 .707 r
F P
0 g
s
.53745 .68169 m .5356 .7383 L .56307 .74227 L p .707 .577 .707 r
F P
0 g
s
.62616 .76715 m .62412 .8052 L .65342 .80498 L p .707 .577 .707 r
F P
0 g
s
.65342 .80498 m .65546 .76694 L .62616 .76715 L p .707 .577 .707 r
F P
0 g
s
.5356 .7383 m .53745 .68169 L .51637 .67645 L p .707 .577 .707 r
F P
0 g
s
.56323 .7633 m .56119 .80134 L .59234 .80394 L p .707 .577 .707 r
F P
0 g
s
.56119 .80134 m .56323 .7633 L .53575 .7596 L p .707 .577 .707 r
F P
0 g
s
.49099 .84163 m .45509 .37253 L .41113 .37108 L p .707 .577 .707 r
F P
0 g
s
.51637 .67645 m .51452 .73307 L .5356 .7383 L p .707 .577 .707 r
F P
0 g
s
.55946 .84894 m .56051 .82991 L .53303 .82624 L p .707 .577 .707 r
F P
0 g
s
.53303 .82624 m .53198 .84527 L .55946 .84894 L p .707 .577 .707 r
F P
0 g
s
.53371 .79765 m .53575 .7596 L .51464 .75518 L p .707 .577 .707 r
F P
0 g
s
.51464 .75518 m .5126 .79323 L .53371 .79765 L p .707 .577 .707 r
F P
0 g
s
.51452 .73307 m .51637 .67645 L .50375 .67047 L p .707 .577 .707 r
F P
0 g
s
.53198 .84527 m .53303 .82624 L .51192 .82187 L p .707 .577 .707 r
F P
0 g
s
.51192 .82187 m .51087 .8409 L .53198 .84527 L p .707 .577 .707 r
F P
0 g
s
.50375 .67047 m .5019 .72709 L .51452 .73307 L p .707 .577 .707 r
F P
0 g
s
.5126 .79323 m .51464 .75518 L .50196 .75047 L p .707 .577 .707 r
F P
0 g
s
.50196 .75047 m .49992 .78851 L .5126 .79323 L p .707 .577 .707 r
F P
0 g
s
.5019 .72709 m .50375 .67047 L .50081 .66432 L p .707 .577 .707 r
F P
0 g
s
.51087 .8409 m .51192 .82187 L .49923 .81724 L p .707 .577 .707 r
F P
0 g
s
.49923 .81724 m .49819 .83627 L .51087 .8409 L p .707 .577 .707 r
F P
0 g
s
.50081 .66432 m .49896 .72094 L .5019 .72709 L p .707 .577 .707 r
F P
0 g
s
.49992 .78851 m .50196 .75047 L .49896 .74591 L p .707 .577 .707 r
F P
0 g
s
.49896 .74591 m .49692 .78396 L .49992 .78851 L p .707 .577 .707 r
F P
0 g
s
.49819 .83627 m .49923 .81724 L .49622 .8128 L p .707 .577 .707 r
F P
0 g
s
.49896 .72094 m .50081 .66432 L .50785 .65861 L p .707 .577 .707 r
F P
0 g
s
.49622 .8128 m .49517 .83183 L .49819 .83627 L p .707 .577 .707 r
F P
0 g
s
.50785 .65861 m .506 .71523 L .49896 .72094 L p .707 .577 .707 r
F P
0 g
s
.49692 .78396 m .49896 .74591 L .50592 .74197 L p .707 .577 .707 r
F P
0 g
s
.50592 .74197 m .50388 .78002 L .49692 .78396 L p .707 .577 .707 r
F P
0 g
s
.49517 .83183 m .49622 .8128 L .50318 .80898 L p .707 .577 .707 r
F P
0 g
s
.506 .71523 m .50785 .65861 L .52418 .6539 L p .707 .577 .707 r
F P
0 g
s
.50318 .80898 m .50213 .82801 L .49517 .83183 L p .707 .577 .707 r
F P
0 g
s
.52418 .6539 m .52233 .71052 L .506 .71523 L p .707 .577 .707 r
F P
0 g
s
.50388 .78002 m .50592 .74197 L .52217 .73903 L p .707 .577 .707 r
F P
0 g
s
.52217 .73903 m .52013 .77707 L .50388 .78002 L p .707 .577 .707 r
F P
0 g
s
.50213 .82801 m .50318 .80898 L .51942 .80616 L p .707 .577 .707 r
F P
0 g
s
.51942 .80616 m .51837 .82519 L .50213 .82801 L p .707 .577 .707 r
F P
0 g
s
.52013 .77707 m .52217 .73903 L .54612 .73737 L p .707 .577 .707 r
F P
0 g
s
.53575 .7596 m .53371 .79765 L .56119 .80134 L p .707 .577 .707 r
F P
0 g
s
.54612 .73737 m .54408 .77541 L .52013 .77707 L p .707 .577 .707 r
F P
0 g
s
.51837 .82519 m .51942 .80616 L .54336 .80461 L p .707 .577 .707 r
F P
0 g
s
.54336 .80461 m .54231 .82364 L .51837 .82519 L p .707 .577 .707 r
F P
0 g
s
.45509 .37253 m .49099 .84163 L .5358 .83696 L p .707 .577 .707 r
F P
0 g
s
.52233 .71052 m .52418 .6539 L .52632 .65361 L p .707 .577 .707 r
F P
0 g
s
.59061 .85156 m .59166 .83253 L .56051 .82991 L p .707 .577 .707 r
F P
0 g
s
.56051 .82991 m .55946 .84894 L .59061 .85156 L p .707 .577 .707 r
F P
0 g
s
.5847 .69075 m .58798 .65242 L .60936 .64961 L .707 .577 .707 r
F
.57851 .64918 m .60936 .64961 L p .57739 .65381 L F P
0 g
s
.64052 .65193 m .63867 .70855 L .60954 .70638 L p .707 .577 .707 r
F P
0 g
s
.60954 .70638 m .60751 .70623 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60951 .70294 m .64052 .65193 L .60954 .70638 L .707 .577 .707 r
F
.60936 .64961 m .64052 .65193 L p .60951 .70294 L F P
0 g
s
.60751 .70623 m .60909 .65788 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60909 .65788 m .60936 .64961 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.65546 .76694 m .65342 .80498 L .67737 .80333 L p .707 .577 .707 r
F P
0 g
s
.67737 .80333 m .6794 .76528 L .65546 .76694 L p .707 .577 .707 r
F P
0 g
s
.66582 .74471 m .66378 .78275 L .65334 .78135 L p .707 .577 .707 r
F P
0 g
s
.65334 .78135 m .63631 .77906 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.65133 .76157 m .66582 .74471 L .65334 .78135 L .707 .577 .707 r
F
.63631 .77906 m .63835 .74102 L .6494 .7425 L p F P
0 g
s
.6494 .7425 m .66582 .74471 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.63631 .77906 m .6494 .7425 L .65133 .76157 L .707 .577 .707 r
F
.60741 .30478 m .60585 .30792 L p .60794 .33385 L F P
0 g
s
.64331 .77388 m .60741 .30478 L .60794 .33385 L .707 .577 .707 r
F
.60585 .30792 m .5977 .32437 L p .60684 .41447 L F P
0 g
s
.64331 .77388 m .60585 .30792 L .60684 .41447 L .707 .577 .707 r
F
.60306 .28571 m .60741 .30478 L p .61283 .38218 L F P
0 g
s
.63835 .74102 m .63631 .77906 L .61015 .77687 L p .707 .577 .707 r
F P
0 g
s
.61017 .7711 m .63835 .74102 L .61015 .77687 L .707 .577 .707 r
F
.60515 .77646 m .60719 .73841 L .61029 .73867 L p F P
0 g
s
.61029 .73867 m .63835 .74102 L p .61017 .7711 L .707 .577 .707 r
F P
0 g
s
.60515 .77646 m .61029 .73867 L .61017 .7711 L .707 .577 .707 r
F
.60715 .44787 m .61115 .50016 L p .60684 .41447 L F P
0 g
s
.61115 .50016 m .63359 .79346 L p .61123 .47672 L .707 .577 .707 r
F P
0 g
s
.60684 .41447 m .61115 .50016 L .61123 .47672 L .707 .577 .707 r
F
.63359 .79346 m .64331 .77388 L p .6113 .45843 L F P
0 g
s
.6113 .45843 m .60684 .41447 L .61123 .47672 L .707 .577 .707 r
F
.6113 .45843 m .61123 .47672 L .63359 .79346 L F
.61015 .77687 m .60515 .77646 L p .61017 .7711 L F P
0 g
s
.63896 .75481 m .60311 .2863 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60311 .2863 m .60306 .28571 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.64331 .77388 m .63896 .75481 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60741 .30478 m .61486 .4021 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.61486 .4021 m .64331 .77388 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.5977 .32437 m .60715 .44787 L p .60684 .41447 L .707 .577 .707 r
F P
0 g
s
.60936 .64961 m .60751 .70623 L .57569 .70578 L p .707 .577 .707 r
F P
0 g
s
.60338 .82483 m .60443 .8058 L .63558 .80842 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .63359 .79346 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57487 .34254 m .59357 .58692 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .57541 .73716 L .58182 .73741 L p .707 .577 .707 r
F P
0 g
s
.58182 .73741 m .60719 .73841 L p .578 .77017 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .58182 .73741 L .578 .77017 L .707 .577 .707 r
F
.59357 .58692 m .59587 .61687 L p .59877 .52608 L F P
0 g
s
.60719 .73841 m .60515 .77646 L .57337 .7752 L p .707 .577 .707 r
F P
0 g
s
.59587 .61687 m .61077 .81164 L p .60081 .57448 L .707 .577 .707 r
F P
0 g
s
.59877 .52608 m .59587 .61687 L .60081 .57448 L .707 .577 .707 r
F
.57569 .70578 m .57739 .65381 L p .58798 .65242 L F P
0 g
s
.57569 .70578 m .58798 .65242 L .5847 .69075 L .707 .577 .707 r
F
.58302 .63055 m .54118 .35753 L .57739 .65381 L F
.57739 .65381 m .57754 .64917 L .57851 .64918 L p F P
0 g
s
.54118 .35753 m .56611 .6833 L p .57739 .65381 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .58302 .63055 L .57739 .65381 L .707 .577 .707 r
F
.5716 .82352 m .57265 .80449 L .60443 .8058 L p F P
0 g
s
.60443 .8058 m .60338 .82483 L .5716 .82352 L p .707 .577 .707 r
F P
0 g
s
.57707 .82662 m .61077 .81164 L p .58396 .63667 L .707 .577 .707 r
F P
0 g
s
.57569 .70578 m .55714 .70672 L p .56338 .69042 L .707 .577 .707 r
F P
0 g
s
.54634 .70726 m .55859 .68445 L .56338 .69042 L .707 .577 .707 r
F
.55714 .70672 m .54634 .70726 L p .56338 .69042 L F P
0 g
s
.57648 .68171 m .57569 .70578 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.54118 .35753 m .4999 .36786 L p .55329 .68527 L .707 .577 .707 r
F P
0 g
s
.5557 .6849 m .54118 .35753 L .55329 .68527 L .707 .577 .707 r
F
.54634 .70726 m .54703 .68623 L p .55859 .68445 L F P
0 g
s
.56971 .73036 m .54118 .35753 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .57754 .64917 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.55329 .68527 m .4999 .36786 L .54703 .68623 L .707 .577 .707 r
F
.54703 .68623 m .54819 .65065 L p .55859 .68445 L F P
0 g
s
.55658 .70482 m .5557 .6849 L .55329 .68527 L .707 .577 .707 r
F
.54408 .77541 m .5458 .74331 L p .57541 .73716 L F P
0 g
s
.5458 .74331 m .54612 .73737 L .5486 .73735 L p .707 .577 .707 r
F P
0 g
s
.5486 .73735 m .57541 .73716 L p .5458 .74331 L .707 .577 .707 r
F P
0 g
s
.57754 .64917 m .57739 .65381 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.57739 .65381 m .57648 .68171 L p .56611 .6833 L .707 .577 .707 r
F P
0 g
s
.55859 .68445 m .57739 .65381 L .56611 .6833 L .707 .577 .707 r
F
.56611 .6833 m .56721 .69773 L p .58396 .63667 L F P
0 g
s
.57541 .73716 m .57337 .7752 L .54408 .77541 L p .707 .577 .707 r
F P
0 g
s
.56721 .69773 m .57707 .82662 L p .58296 .66421 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .56721 .69773 L .58296 .66421 L .707 .577 .707 r
F
.57707 .82662 m .56971 .73036 L p .55658 .70482 L F P
0 g
s
.54634 .70726 m .52233 .71052 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .52028 .63418 L p .54703 .68623 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .54703 .68623 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.54703 .68623 m .54634 .70726 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.55658 .70482 m .55329 .68527 L .54703 .68623 L .707 .577 .707 r
F
.54231 .82364 m .54336 .80461 L .57265 .80449 L p F P
0 g
s
.57265 .80449 m .5716 .82352 L .54231 .82364 L p .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .57707 .82662 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.52632 .65361 m .53001 .65311 L p .53493 .68135 L .707 .577 .707 r
F P
0 g
s
.53493 .68135 m .53001 .65311 L .53931 .67121 L .707 .577 .707 r
F
.52233 .71052 m .52632 .65361 L .53493 .68135 L F
.52028 .63418 m .5358 .83696 L p .55658 .70482 L F P
0 g
s
.53001 .65311 m .54819 .65065 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .45509 .37253 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .52028 .63418 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.52028 .63418 m .4999 .36786 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.59166 .83253 m .59061 .85156 L .62239 .85287 L p .707 .577 .707 r
F P
0 g
s
.62239 .85287 m .62344 .83384 L .59166 .83253 L p .707 .577 .707 r
F P
0 g
s
.62344 .83384 m .62239 .85287 L .65168 .85275 L p .707 .577 .707 r
F P
0 g
s
.65168 .85275 m .65273 .83372 L .62344 .83384 L p .707 .577 .707 r
F P
0 g
s
.44702 .84018 m .41113 .37108 L .37232 .36365 L p .707 .577 .707 r
F P
0 g
s
.41113 .37108 m .44702 .84018 L .49099 .84163 L p .707 .577 .707 r
F P
0 g
s
.68126 .68369 m .67941 .74031 L .69574 .73559 L p .707 .577 .707 r
F P
0 g
s
.69574 .73559 m .69759 .67898 L .68126 .68369 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .57487 .34254 L .54118 .35753 L p .707 .577 .707 r
F P
0 g
s
.65273 .83372 m .65168 .85275 L .67562 .8512 L p .707 .577 .707 r
F P
0 g
s
.67562 .8512 m .67667 .83217 L .65273 .83372 L p .707 .577 .707 r
F P
0 g
s
.6794 .76528 m .67737 .80333 L .69361 .80038 L p .707 .577 .707 r
F P
0 g
s
.69361 .80038 m .69565 .76234 L .6794 .76528 L p .707 .577 .707 r
F P
0 g
s
.40821 .83275 m .37232 .36365 L .34246 .35097 L p .707 .577 .707 r
F P
0 g
s
.37232 .36365 m .40821 .83275 L .44702 .84018 L p .707 .577 .707 r
F P
0 g
s
.69759 .67898 m .69574 .73559 L .70277 .72988 L p .707 .577 .707 r
F P
0 g
s
.70277 .72988 m .70462 .67327 L .69759 .67898 L p .707 .577 .707 r
F P
0 g
s
.67667 .83217 m .67562 .8512 L .69186 .84838 L p .707 .577 .707 r
F P
0 g
s
.69186 .84838 m .69291 .82935 L .67667 .83217 L p .707 .577 .707 r
F P
0 g
s
.63359 .79346 m .5977 .32437 L .57487 .34254 L p .707 .577 .707 r
F P
0 g
s
.69565 .76234 m .69361 .80038 L .70058 .79644 L p .707 .577 .707 r
F P
0 g
s
.70058 .79644 m .70262 .7584 L .69565 .76234 L p .707 .577 .707 r
F P
0 g
s
.35977 .69307 m .36162 .63645 L .35458 .64216 L p .707 .577 .707 r
F P
0 g
s
.35458 .64216 m .35273 .69878 L .35977 .69307 L p .707 .577 .707 r
F P
0 g
s
.36162 .63645 m .35977 .69307 L .35683 .68692 L p .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35752 .66589 L p .36162 .63645 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .32448 .33427 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.36284 .61728 m .34246 .35097 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.3609 .63496 m .36162 .63645 L p .35752 .66589 L .707 .577 .707 r
F P
0 g
s
.33825 .64687 m .3364 .70349 L .35273 .69878 L p .707 .577 .707 r
F P
0 g
s
.35273 .69878 m .35458 .64216 L .33825 .64687 L p .707 .577 .707 r
F P
0 g
s
.35265 .72552 m .35061 .76357 L .35757 .75963 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35961 .72158 L .35265 .72552 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35456 .75507 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35961 .72158 m .35904 .73221 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35904 .73221 m .35757 .75963 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .37836 .82006 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.32448 .33427 m .3494 .66004 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35219 .68472 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35683 .68692 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35219 .68472 m .34421 .68094 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.34962 .66199 m .35868 .63031 L .35219 .68472 L .707 .577 .707 r
F
.3566 .71703 m .35961 .72158 L p .35835 .72991 L F P
0 g
s
.35456 .75507 m .35628 .72297 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35628 .72297 m .3566 .71703 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.3364 .72847 m .33436 .76651 L .35061 .76357 L p .707 .577 .707 r
F P
0 g
s
.35061 .76357 m .35265 .72552 L .3364 .72847 L p .707 .577 .707 r
F P
0 g
s
.3566 .71703 m .35456 .75507 L .34188 .75036 L p .707 .577 .707 r
F P
0 g
s
.34188 .75036 m .34392 .71231 L .3566 .71703 L p .707 .577 .707 r
F P
0 g
s
.35602 .78429 m .36037 .80337 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34799 .6475 m .32448 .33427 L .34624 .63197 L .707 .577 .707 r
F
.34421 .68094 m .3459 .62897 L p .34962 .66199 L F P
0 g
s
.35351 .71365 m .32448 .33427 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34606 .62432 m .35868 .63031 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.32013 .3152 m .33883 .55958 L p .34624 .63197 L .707 .577 .707 r
F P
0 g
s
.31424 .65013 m .31239 .70674 L .3364 .70349 L p .707 .577 .707 r
F P
0 g
s
.3364 .70349 m .33825 .64687 L .31424 .65013 L p .707 .577 .707 r
F P
0 g
s
.34421 .68094 m .3391 .67967 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3391 .67967 m .32313 .67571 L p .33901 .64012 L .707 .577 .707 r
F P
0 g
s
.33901 .64012 m .34555 .62546 L .3391 .67967 L .707 .577 .707 r
F
.32448 .33427 m .32013 .3152 L p .34624 .63197 L F P
0 g
s
.32013 .3152 m .32984 .29562 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34421 .68094 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.34624 .63197 m .33883 .55958 L .3459 .62897 L .707 .577 .707 r
F
.32313 .67571 m .32498 .61909 L .34541 .62416 L p F P
0 g
s
.34541 .62416 m .34606 .62432 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.32313 .67571 m .34541 .62416 L .34555 .62546 L .707 .577 .707 r
F
.3404 .58009 m .34962 .7006 L p .34627 .63258 L F P
0 g
s
.34624 .63197 m .3459 .62897 L .34627 .63258 L .707 .577 .707 r
F
.3459 .62897 m .3404 .58009 L .34627 .63258 L F
.33883 .55958 m .3404 .58009 L p .3459 .62897 L F P
0 g
s
.34606 .62432 m .3459 .62897 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34606 .62432 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.35277 .71118 m .34624 .63197 L .34962 .7006 L .707 .577 .707 r
F
.34962 .7006 m .35602 .78429 L p .35277 .71118 L F P
0 g
s
.35277 .71118 m .34799 .6475 L .34624 .63197 L .707 .577 .707 r
F
.35602 .78429 m .33883 .55958 L p .3386 .4592 L F P
0 g
s
.33883 .55958 m .32013 .3152 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3494 .66004 m .36037 .80337 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35868 .63031 m .35752 .66589 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .35351 .71365 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35868 .63031 L .3609 .63496 L p .707 .577 .707 r
F P
0 g
s
.37836 .82006 m .36284 .61728 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .37836 .82006 L .40821 .83275 L p .707 .577 .707 r
F P
0 g
s
.69291 .82935 m .69186 .84838 L .69882 .84456 L p .707 .577 .707 r
F P
0 g
s
.69882 .84456 m .69987 .82553 L .69291 .82935 L p .707 .577 .707 r
F P
0 g
s
.70462 .67327 m .70277 .72988 L .69984 .72374 L p .707 .577 .707 r
F P
0 g
s
.69984 .72374 m .70169 .66712 L .70462 .67327 L p .707 .577 .707 r
F P
0 g
s
.70262 .7584 m .70058 .79644 L .69757 .79189 L p .707 .577 .707 r
F P
0 g
s
.69757 .79189 m .69961 .75385 L .70262 .7584 L p .707 .577 .707 r
F P
0 g
s
.69987 .82553 m .69882 .84456 L .69581 .84012 L p .707 .577 .707 r
F P
0 g
s
.69581 .84012 m .69686 .82109 L .69987 .82553 L p .707 .577 .707 r
F P
0 g
s
.70169 .66712 m .69984 .72374 L .68722 .71775 L p .707 .577 .707 r
F P
0 g
s
.68722 .71775 m .68907 .66114 L .70169 .66712 L p .707 .577 .707 r
F P
0 g
s
.25122 .70778 m .25307 .65116 L .22191 .64884 L p .707 .577 .707 r
F P
0 g
s
.25307 .65116 m .25122 .70778 L .28304 .70822 L p .707 .577 .707 r
F P
0 g
s
.28304 .70822 m .28489 .65161 L .25307 .65116 L p .707 .577 .707 r
F P
0 g
s
.28489 .65161 m .28304 .70822 L .31239 .70674 L p .707 .577 .707 r
F P
0 g
s
.31239 .70674 m .31424 .65013 L .28489 .65161 L p .707 .577 .707 r
F P
0 g
s
.22006 .70546 m .22191 .64884 L .19444 .64487 L p .707 .577 .707 r
F P
0 g
s
.22191 .64884 m .22006 .70546 L .25122 .70778 L p .707 .577 .707 r
F P
0 g
s
.69961 .75385 m .69757 .79189 L .68489 .78717 L p .707 .577 .707 r
F P
0 g
s
.68489 .78717 m .68693 .74913 L .69961 .75385 L p .707 .577 .707 r
F P
0 g
s
.24934 .76713 m .25138 .72908 L .22022 .72648 L p .707 .577 .707 r
F P
0 g
s
.25138 .72908 m .24934 .76713 L .28112 .76838 L p .707 .577 .707 r
F P
0 g
s
.28112 .76838 m .28316 .73034 L .25138 .72908 L p .707 .577 .707 r
F P
0 g
s
.19444 .64487 m .19259 .70149 L .22006 .70546 L p .707 .577 .707 r
F P
0 g
s
.28316 .73034 m .28112 .76838 L .31041 .76817 L p .707 .577 .707 r
F P
0 g
s
.31041 .76817 m .31245 .73013 L .28316 .73034 L p .707 .577 .707 r
F P
0 g
s
.68907 .66114 m .68722 .71775 L .66614 .71252 L p .707 .577 .707 r
F P
0 g
s
.66614 .71252 m .66799 .6559 L .68907 .66114 L p .707 .577 .707 r
F P
0 g
s
.19259 .70149 m .19444 .64487 L .17337 .63964 L p .707 .577 .707 r
F P
0 g
s
.22022 .72648 m .21818 .76452 L .24934 .76713 L p .707 .577 .707 r
F P
0 g
s
.69686 .82109 m .69581 .84012 L .68312 .83549 L p .707 .577 .707 r
F P
0 g
s
.68312 .83549 m .68417 .81646 L .69686 .82109 L p .707 .577 .707 r
F P
0 g
s
.21818 .76452 m .22022 .72648 L .19274 .72279 L p .707 .577 .707 r
F P
0 g
s
.2476 .81474 m .24865 .79571 L .2175 .79309 L p .707 .577 .707 r
F P
0 g
s
.24865 .79571 m .2476 .81474 L .27938 .81606 L p .707 .577 .707 r
F P
0 g
s
.27938 .81606 m .28043 .79703 L .24865 .79571 L p .707 .577 .707 r
F P
0 g
s
.19274 .72279 m .19071 .76083 L .21818 .76452 L p .707 .577 .707 r
F P
0 g
s
.2175 .79309 m .21645 .81212 L .2476 .81474 L p .707 .577 .707 r
F P
0 g
s
.28043 .79703 m .27938 .81606 L .30867 .81593 L p .707 .577 .707 r
F P
0 g
s
.30867 .81593 m .30972 .7969 L .28043 .79703 L p .707 .577 .707 r
F P
0 g
s
.31245 .73013 m .31041 .76817 L .33436 .76651 L p .707 .577 .707 r
F P
0 g
s
.33436 .76651 m .3364 .72847 L .31245 .73013 L p .707 .577 .707 r
F P
0 g
s
.17337 .63964 m .17152 .69625 L .19259 .70149 L p .707 .577 .707 r
F P
0 g
s
.21645 .81212 m .2175 .79309 L .19002 .78942 L p .707 .577 .707 r
F P
0 g
s
.19002 .78942 m .18897 .80845 L .21645 .81212 L p .707 .577 .707 r
F P
0 g
s
.19071 .76083 m .19274 .72279 L .17163 .71837 L p .707 .577 .707 r
F P
0 g
s
.68693 .74913 m .68489 .78717 L .66378 .78275 L p .707 .577 .707 r
F P
0 g
s
.66378 .78275 m .66582 .74471 L .68693 .74913 L p .707 .577 .707 r
F P
0 g
s
.30972 .7969 m .30867 .81593 L .33261 .81438 L p .707 .577 .707 r
F P
0 g
s
.33261 .81438 m .33366 .79535 L .30972 .7969 L p .707 .577 .707 r
F P
0 g
s
.17163 .71837 m .16959 .75641 L .19071 .76083 L p .707 .577 .707 r
F P
0 g
s
.66799 .6559 m .66614 .71252 L .63867 .70855 L p .707 .577 .707 r
F P
0 g
s
.63867 .70855 m .64052 .65193 L .66799 .6559 L p .707 .577 .707 r
F P
0 g
s
.17152 .69625 m .17337 .63964 L .16074 .63365 L p .707 .577 .707 r
F P
0 g
s
.18897 .80845 m .19002 .78942 L .16891 .78506 L p .707 .577 .707 r
F P
0 g
s
.60306 .28571 m .63896 .75481 L .62097 .73811 L p .707 .577 .707 r
F P
0 g
s
.62097 .73811 m .58508 .26902 L .60306 .28571 L p .707 .577 .707 r
F P
0 g
s
.68417 .81646 m .68312 .83549 L .66201 .83112 L p .707 .577 .707 r
F P
0 g
s
.66201 .83112 m .66306 .81209 L .68417 .81646 L p .707 .577 .707 r
F P
0 g
s
.16891 .78506 m .16786 .80409 L .18897 .80845 L p .707 .577 .707 r
F P
0 g
s
.16074 .63365 m .15889 .69027 L .17152 .69625 L p .707 .577 .707 r
F P
0 g
s
.16959 .75641 m .17163 .71837 L .15896 .71365 L p .707 .577 .707 r
F P
0 g
s
.33366 .79535 m .33261 .81438 L .34885 .81156 L p .707 .577 .707 r
F P
0 g
s
.34885 .81156 m .3499 .79253 L .33366 .79535 L p .707 .577 .707 r
F P
0 g
s
.15896 .71365 m .15692 .75169 L .16959 .75641 L p .707 .577 .707 r
F P
0 g
s
.15889 .69027 m .16074 .63365 L .15781 .62751 L p .707 .577 .707 r
F P
0 g
s
.16786 .80409 m .16891 .78506 L .15622 .78043 L p .707 .577 .707 r
F P
0 g
s
.36574 .76471 m .32984 .29562 L .35266 .27744 L p .707 .577 .707 r
F P
0 g
s
.32984 .29562 m .36574 .76471 L .35602 .78429 L p .707 .577 .707 r
F P
0 g
s
.66306 .81209 m .66201 .83112 L .63453 .82745 L p .707 .577 .707 r
F P
0 g
s
.63453 .82745 m .63558 .80842 L .66306 .81209 L p .707 .577 .707 r
F P
0 g
s
.15622 .78043 m .15518 .79946 L .16786 .80409 L p .707 .577 .707 r
F P
0 g
s
.15781 .62751 m .15596 .68412 L .15889 .69027 L p .707 .577 .707 r
F P
0 g
s
.58508 .26902 m .62097 .73811 L .59112 .72543 L p .707 .577 .707 r
F P
0 g
s
.59112 .72543 m .55522 .25633 L .58508 .26902 L p .707 .577 .707 r
F P
0 g
s
.63558 .80842 m .63453 .82745 L .60338 .82483 L p .707 .577 .707 r
F P
0 g
s
.15692 .75169 m .15896 .71365 L .15595 .7091 L p .707 .577 .707 r
F P
0 g
s
.3499 .79253 m .34885 .81156 L .35581 .80774 L p .707 .577 .707 r
F P
0 g
s
.35581 .80774 m .35686 .78871 L .3499 .79253 L p .707 .577 .707 r
F P
0 g
s
.15595 .7091 m .15391 .74714 L .15692 .75169 L p .707 .577 .707 r
F P
0 g
s
.15518 .79946 m .15622 .78043 L .15321 .77599 L p .707 .577 .707 r
F P
0 g
s
.15596 .68412 m .15781 .62751 L .16484 .6218 L p .707 .577 .707 r
F P
0 g
s
.15321 .77599 m .15217 .79502 L .15518 .79946 L p .707 .577 .707 r
F P
0 g
s
.35266 .27744 m .38856 .74654 L .36574 .76471 L p .707 .577 .707 r
F P
0 g
s
.38856 .74654 m .35266 .27744 L .38636 .26245 L p .707 .577 .707 r
F P
0 g
s
.16484 .6218 m .16299 .67841 L .15596 .68412 L p .707 .577 .707 r
F P
0 g
s
.55522 .25633 m .59112 .72543 L .55231 .71799 L p .707 .577 .707 r
F P
0 g
s
.55231 .71799 m .51641 .2489 L .55522 .25633 L p .707 .577 .707 r
F P
0 g
s
.15391 .74714 m .15595 .7091 L .16291 .70516 L p .707 .577 .707 r
F P
0 g
s
.35686 .78871 m .35581 .80774 L .3528 .8033 L p .707 .577 .707 r
F P
0 g
s
.3528 .8033 m .35385 .78427 L .35686 .78871 L p .707 .577 .707 r
F P
0 g
s
.16291 .70516 m .16087 .7432 L .15391 .74714 L p .707 .577 .707 r
F P
0 g
s
.15217 .79502 m .15321 .77599 L .16017 .77217 L p .707 .577 .707 r
F P
0 g
s
.42226 .73155 m .38636 .26245 L .42763 .25212 L p .707 .577 .707 r
F P
0 g
s
.38636 .26245 m .42226 .73155 L .38856 .74654 L p .707 .577 .707 r
F P
0 g
s
.16299 .67841 m .16484 .6218 L .18117 .61709 L p .707 .577 .707 r
F P
0 g
s
.16017 .77217 m .15912 .7912 L .15217 .79502 L p .707 .577 .707 r
F P
0 g
s
.51641 .2489 m .55231 .71799 L .50834 .71654 L p .707 .577 .707 r
F P
0 g
s
.50834 .71654 m .47245 .24745 L .51641 .2489 L p .707 .577 .707 r
F P
0 g
s
.18117 .61709 m .17932 .6737 L .16299 .67841 L p .707 .577 .707 r
F P
0 g
s
.46353 .72121 m .42763 .25212 L .47245 .24745 L p .707 .577 .707 r
F P
0 g
s
.42763 .25212 m .46353 .72121 L .42226 .73155 L p .707 .577 .707 r
F P
0 g
s
.47245 .24745 m .50834 .71654 L .46353 .72121 L p .707 .577 .707 r
F P
0 g
s
.16087 .7432 m .16291 .70516 L .17916 .70221 L p .707 .577 .707 r
F P
0 g
s
.35385 .78427 m .3528 .8033 L .34012 .79867 L p .707 .577 .707 r
F P
0 g
s
.34012 .79867 m .34116 .77964 L .35385 .78427 L p .707 .577 .707 r
F P
0 g
s
.17916 .70221 m .17712 .74026 L .16087 .7432 L p .707 .577 .707 r
F P
0 g
s
.17932 .6737 m .18117 .61709 L .20518 .61383 L p .707 .577 .707 r
F P
0 g
s
.15912 .7912 m .16017 .77217 L .17641 .76935 L p .707 .577 .707 r
F P
0 g
s
.17641 .76935 m .17536 .78838 L .15912 .7912 L p .707 .577 .707 r
F P
0 g
s
.34392 .71231 m .34188 .75036 L .32077 .74594 L p .707 .577 .707 r
F P
0 g
s
.32077 .74594 m .32281 .70789 L .34392 .71231 L p .707 .577 .707 r
F P
0 g
s
.20518 .61383 m .20333 .67045 L .17932 .6737 L p .707 .577 .707 r
F P
0 g
s
.32498 .61909 m .32313 .67571 L .29567 .67173 L p .707 .577 .707 r
F P
0 g
s
.29567 .67173 m .29752 .61512 L .32498 .61909 L p .707 .577 .707 r
F P
0 g
s
.17712 .74026 m .17916 .70221 L .20311 .70055 L p .707 .577 .707 r
F P
0 g
s
.20333 .67045 m .20518 .61383 L .23453 .61235 L p .707 .577 .707 r
F P
0 g
s
.34116 .77964 m .34012 .79867 L .319 .79431 L p .707 .577 .707 r
F P
0 g
s
.319 .79431 m .32005 .77528 L .34116 .77964 L p .707 .577 .707 r
F P
0 g
s
.20311 .70055 m .20107 .7386 L .17712 .74026 L p .707 .577 .707 r
F P
0 g
s
.29752 .61512 m .29567 .67173 L .2645 .66941 L p .707 .577 .707 r
F P
0 g
s
.2645 .66941 m .26635 .6128 L .29752 .61512 L p .707 .577 .707 r
F P
0 g
s
.17536 .78838 m .17641 .76935 L .20035 .7678 L p .707 .577 .707 r
F P
0 g
s
.23453 .61235 m .23268 .66897 L .20333 .67045 L p .707 .577 .707 r
F P
0 g
s
.20035 .7678 m .1993 .78683 L .17536 .78838 L p .707 .577 .707 r
F P
0 g
s
.32281 .70789 m .32077 .74594 L .2933 .74224 L p .707 .577 .707 r
F P
0 g
s
.2933 .74224 m .29534 .7042 L .32281 .70789 L p .707 .577 .707 r
F P
0 g
s
.73143 .64853 m .73328 .59192 L .70212 .5896 L p .707 .577 .707 r
F P
0 g
s
.73328 .59192 m .73143 .64853 L .76325 .64898 L p .707 .577 .707 r
F P
0 g
s
.76325 .64898 m .7651 .59236 L .73328 .59192 L p .707 .577 .707 r
F P
0 g
s
.23268 .66897 m .23453 .61235 L .26635 .6128 L p .707 .577 .707 r
F P
0 g
s
.7651 .59236 m .76325 .64898 L .7926 .6475 L p .707 .577 .707 r
F P
0 g
s
.7926 .6475 m .79445 .59088 L .7651 .59236 L p .707 .577 .707 r
F P
0 g
s
.26635 .6128 m .2645 .66941 L .23268 .66897 L p .707 .577 .707 r
F P
0 g
s
.20107 .7386 m .20311 .70055 L .2324 .70034 L p .707 .577 .707 r
F P
0 g
s
.70027 .64621 m .70212 .5896 L .67465 .58562 L p .707 .577 .707 r
F P
0 g
s
.70212 .5896 m .70027 .64621 L .73143 .64853 L p .707 .577 .707 r
F P
0 g
s
.32005 .77528 m .319 .79431 L .29152 .79063 L p .707 .577 .707 r
F P
0 g
s
.29152 .79063 m .29257 .7716 L .32005 .77528 L p .707 .577 .707 r
F P
0 g
s
.2324 .70034 m .23036 .73839 L .20107 .7386 L p .707 .577 .707 r
F P
0 g
s
.29534 .7042 m .2933 .74224 L .26214 .73964 L p .707 .577 .707 r
F P
0 g
s
.26214 .73964 m .26418 .7016 L .29534 .7042 L p .707 .577 .707 r
F P
0 g
s
.72955 .7017 m .73159 .66366 L .70043 .66106 L p .707 .577 .707 r
F P
0 g
s
.73159 .66366 m .72955 .7017 L .76133 .70296 L p .707 .577 .707 r
F P
0 g
s
.76133 .70296 m .76337 .66491 L .73159 .66366 L p .707 .577 .707 r
F P
0 g
s
.79445 .59088 m .7926 .6475 L .81661 .64424 L p .707 .577 .707 r
F P
0 g
s
.81661 .64424 m .81846 .58763 L .79445 .59088 L p .707 .577 .707 r
F P
0 g
s
.67465 .58562 m .6728 .64224 L .70027 .64621 L p .707 .577 .707 r
F P
0 g
s
.1993 .78683 m .20035 .7678 L .22964 .76767 L p .707 .577 .707 r
F P
0 g
s
.76337 .66491 m .76133 .70296 L .79063 .70275 L p .707 .577 .707 r
F P
0 g
s
.79063 .70275 m .79266 .6647 L .76337 .66491 L p .707 .577 .707 r
F P
0 g
s
.23036 .73839 m .2324 .70034 L .26418 .7016 L p .707 .577 .707 r
F P
0 g
s
.22964 .76767 m .22859 .7867 L .1993 .78683 L p .707 .577 .707 r
F P
0 g
s
.70043 .66106 m .6984 .6991 L .72955 .7017 L p .707 .577 .707 r
F P
0 g
s
.26418 .7016 m .26214 .73964 L .23036 .73839 L p .707 .577 .707 r
F P
0 g
s
.6984 .6991 m .70043 .66106 L .67296 .65736 L p .707 .577 .707 r
F P
0 g
s
.6728 .64224 m .67465 .58562 L .65358 .58039 L p .707 .577 .707 r
F P
0 g
s
.72782 .73953 m .72886 .7205 L .69771 .71788 L p .707 .577 .707 r
F P
0 g
s
.72886 .7205 m .72782 .73953 L .75959 .74084 L p .707 .577 .707 r
F P
0 g
s
.75959 .74084 m .76064 .72181 L .72886 .7205 L p .707 .577 .707 r
F P
0 g
s
.69771 .71788 m .69666 .73691 L .72782 .73953 L p .707 .577 .707 r
F P
0 g
s
.29257 .7716 m .29152 .79063 L .26037 .78801 L p .707 .577 .707 r
F P
0 g
s
.26037 .78801 m .26142 .76898 L .29257 .7716 L p .707 .577 .707 r
F P
0 g
s
.67296 .65736 m .67092 .69541 L .6984 .6991 L p .707 .577 .707 r
F P
0 g
s
.76064 .72181 m .75959 .74084 L .78889 .74072 L p .707 .577 .707 r
F P
0 g
s
.78889 .74072 m .78993 .72169 L .76064 .72181 L p .707 .577 .707 r
F P
0 g
s
.22859 .7867 m .22964 .76767 L .26142 .76898 L p .707 .577 .707 r
F P
0 g
s
.69666 .73691 m .69771 .71788 L .67023 .71421 L p .707 .577 .707 r
F P
0 g
s
.79266 .6647 m .79063 .70275 L .81457 .70109 L p .707 .577 .707 r
F P
0 g
s
.81457 .70109 m .81661 .66304 L .79266 .6647 L p .707 .577 .707 r
F P
0 g
s
.26142 .76898 m .26037 .78801 L .22859 .7867 L p .707 .577 .707 r
F P
0 g
s
.65358 .58039 m .65173 .63701 L .6728 .64224 L p .707 .577 .707 r
F P
0 g
s
.67023 .71421 m .66919 .73324 L .69666 .73691 L p .707 .577 .707 r
F P
0 g
s
.81846 .58763 m .81661 .64424 L .83294 .63953 L p .707 .577 .707 r
F P
0 g
s
.83294 .63953 m .83479 .58292 L .81846 .58763 L p .707 .577 .707 r
F P
0 g
s
.67092 .69541 m .67296 .65736 L .65185 .65294 L p .707 .577 .707 r
F P
0 g
s
.78993 .72169 m .78889 .74072 L .81282 .73917 L p .707 .577 .707 r
F P
0 g
s
.81282 .73917 m .81387 .72014 L .78993 .72169 L p .707 .577 .707 r
F P
0 g
s
.65185 .65294 m .64981 .69099 L .67092 .69541 L p .707 .577 .707 r
F P
0 g
s
.65173 .63701 m .65358 .58039 L .64095 .57441 L p .707 .577 .707 r
F P
0 g
s
.66919 .73324 m .67023 .71421 L .64912 .70984 L p .707 .577 .707 r
F P
0 g
s
.64912 .70984 m .64807 .72887 L .66919 .73324 L p .707 .577 .707 r
F P
0 g
s
.81661 .66304 m .81457 .70109 L .83082 .69814 L p .707 .577 .707 r
F P
0 g
s
.83082 .69814 m .83286 .6601 L .81661 .66304 L p .707 .577 .707 r
F P
0 g
s
.64095 .57441 m .6391 .63102 L .65173 .63701 L p .707 .577 .707 r
F P
0 g
s
.81387 .72014 m .81282 .73917 L .82907 .73635 L p .707 .577 .707 r
F P
0 g
s
.82907 .73635 m .83011 .71732 L .81387 .72014 L p .707 .577 .707 r
F P
0 g
s
.64981 .69099 m .65185 .65294 L .63917 .64823 L p .707 .577 .707 r
F P
0 g
s
.83479 .58292 m .83294 .63953 L .83998 .63382 L p .707 .577 .707 r
F P
0 g
s
.83998 .63382 m .84183 .57721 L .83479 .58292 L p .707 .577 .707 r
F P
0 g
s
.63917 .64823 m .63713 .68627 L .64981 .69099 L p .707 .577 .707 r
F P
0 g
s
.64807 .72887 m .64912 .70984 L .63644 .70521 L p .707 .577 .707 r
F P
0 g
s
.63644 .70521 m .63539 .72424 L .64807 .72887 L p .707 .577 .707 r
F P
0 g
s
.6391 .63102 m .64095 .57441 L .63802 .56826 L p .707 .577 .707 r
F P
0 g
s
.83286 .6601 m .83082 .69814 L .83778 .6942 L p .707 .577 .707 r
F P
0 g
s
.83778 .6942 m .83982 .65616 L .83286 .6601 L p .707 .577 .707 r
F P
0 g
s
.63802 .56826 m .63617 .62488 L .6391 .63102 L p .707 .577 .707 r
F P
0 g
s
.83011 .71732 m .82907 .73635 L .83602 .73253 L p .707 .577 .707 r
F P
0 g
s
.83602 .73253 m .83707 .7135 L .83011 .71732 L p .707 .577 .707 r
F P
0 g
s
.63713 .68627 m .63917 .64823 L .63616 .64367 L p .707 .577 .707 r
F P
0 g
s
.84183 .57721 m .83998 .63382 L .83704 .62767 L p .707 .577 .707 r
F P
0 g
s
.83704 .62767 m .83889 .57106 L .84183 .57721 L p .707 .577 .707 r
F P
0 g
s
.63616 .64367 m .63412 .68172 L .63713 .68627 L p .707 .577 .707 r
F P
0 g
s
.63539 .72424 m .63644 .70521 L .63343 .70077 L p .707 .577 .707 r
F P
0 g
s
.63343 .70077 m .63238 .7198 L .63539 .72424 L p .707 .577 .707 r
F P
0 g
s
.63617 .62488 m .63802 .56826 L .64506 .56255 L p .707 .577 .707 r
F P
0 g
s
.83982 .65616 m .83778 .6942 L .83478 .68965 L p .707 .577 .707 r
F P
0 g
s
.83478 .68965 m .83682 .65161 L .83982 .65616 L p .707 .577 .707 r
F P
0 g
s
.64506 .56255 m .64321 .61917 L .63617 .62488 L p .707 .577 .707 r
F P
0 g
s
.83707 .7135 m .83602 .73253 L .83301 .72809 L p .707 .577 .707 r
F P
0 g
s
.83301 .72809 m .83406 .70906 L .83707 .7135 L p .707 .577 .707 r
F P
0 g
s
.63412 .68172 m .63616 .64367 L .64313 .63973 L p .707 .577 .707 r
F P
0 g
s
.83889 .57106 m .83704 .62767 L .82442 .62169 L p .707 .577 .707 r
F P
0 g
s
.82442 .62169 m .82627 .56508 L .83889 .57106 L p .707 .577 .707 r
F P
0 g
s
.64313 .63973 m .64109 .67778 L .63412 .68172 L p .707 .577 .707 r
F P
0 g
s
.63238 .7198 m .63343 .70077 L .64038 .69695 L p .707 .577 .707 r
F P
0 g
s
.38842 .61172 m .39027 .5551 L .35911 .55278 L p .707 .577 .707 r
F P
0 g
s
.39027 .5551 m .38842 .61172 L .42024 .61216 L p .707 .577 .707 r
F P
0 g
s
.42024 .61216 m .42209 .55554 L .39027 .5551 L p .707 .577 .707 r
F P
0 g
s
.64038 .69695 m .63933 .71598 L .63238 .7198 L p .707 .577 .707 r
F P
0 g
s
.42209 .55554 m .42024 .61216 L .44959 .61068 L p .707 .577 .707 r
F P
0 g
s
.44959 .61068 m .45144 .55407 L .42209 .55554 L p .707 .577 .707 r
F P
0 g
s
.64321 .61917 m .64506 .56255 L .66138 .55784 L p .707 .577 .707 r
F P
0 g
s
.35726 .6094 m .35911 .55278 L .33164 .54881 L p .707 .577 .707 r
F P
0 g
s
.35911 .55278 m .35726 .6094 L .38842 .61172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83682 .65161 m .83478 .68965 L .8221 .68493 L p .707 .577 .707 r
F P
0 g
s
.8221 .68493 m .82414 .64689 L .83682 .65161 L p .707 .577 .707 r
F P
0 g
s
.66138 .55784 m .65953 .61445 L .64321 .61917 L p .707 .577 .707 r
F P
0 g
s
.38654 .66489 m .38858 .62684 L .35742 .62424 L p .707 .577 .707 r
F P
0 g
s
.38858 .62684 m .38654 .66489 L .41832 .66614 L p .707 .577 .707 r
F P
0 g
s
.41832 .66614 m .42036 .6281 L .38858 .62684 L p .707 .577 .707 r
F P
0 g
s
.45144 .55407 m .44959 .61068 L .4736 .60743 L p .707 .577 .707 r
F P
0 g
s
.4736 .60743 m .47545 .55081 L .45144 .55407 L p .707 .577 .707 r
F P
0 g
s
.33164 .54881 m .32979 .60542 L .35726 .6094 L p .707 .577 .707 r
F P
0 g
s
.42036 .6281 m .41832 .66614 L .44762 .66593 L p .707 .577 .707 r
F P
0 g
s
.44762 .66593 m .44965 .62789 L .42036 .6281 L p .707 .577 .707 r
F P
0 g
s
.83406 .70906 m .83301 .72809 L .82033 .72346 L p .707 .577 .707 r
F P
0 g
s
.82033 .72346 m .82138 .70443 L .83406 .70906 L p .707 .577 .707 r
F P
0 g
s
.35742 .62424 m .35539 .66228 L .38654 .66489 L p .707 .577 .707 r
F P
0 g
s
.64109 .67778 m .64313 .63973 L .65938 .63679 L p .707 .577 .707 r
F P
0 g
s
.82627 .56508 m .82442 .62169 L .80334 .61646 L p .707 .577 .707 r
F P
0 g
s
.80334 .61646 m .80519 .55984 L .82627 .56508 L p .707 .577 .707 r
F P
0 g
s
.35539 .66228 m .35742 .62424 L .32995 .62055 L p .707 .577 .707 r
F P
0 g
s
.32979 .60542 m .33164 .54881 L .31057 .54358 L p .707 .577 .707 r
F P
0 g
s
.38481 .70271 m .38585 .68368 L .3547 .68106 L p .707 .577 .707 r
F P
0 g
s
.38585 .68368 m .38481 .70271 L .41658 .70403 L p .707 .577 .707 r
F P
0 g
s
.41658 .70403 m .41763 .685 L .38585 .68368 L p .707 .577 .707 r
F P
0 g
s
.65938 .63679 m .65734 .67483 L .64109 .67778 L p .707 .577 .707 r
F P
0 g
s
.3547 .68106 m .35365 .70009 L .38481 .70271 L p .707 .577 .707 r
F P
0 g
s
.32995 .62055 m .32791 .65859 L .35539 .66228 L p .707 .577 .707 r
F P
0 g
s
.41763 .685 m .41658 .70403 L .44588 .7039 L p .707 .577 .707 r
F P
0 g
s
.44588 .7039 m .44692 .68487 L .41763 .685 L p .707 .577 .707 r
F P
0 g
s
.63933 .71598 m .64038 .69695 L .65662 .69413 L p .707 .577 .707 r
F P
0 g
s
.35365 .70009 m .3547 .68106 L .32722 .67739 L p .707 .577 .707 r
F P
0 g
s
.44965 .62789 m .44762 .66593 L .47156 .66427 L p .707 .577 .707 r
F P
0 g
s
.47156 .66427 m .4736 .62623 L .44965 .62789 L p .707 .577 .707 r
F P
0 g
s
.65953 .61445 m .66138 .55784 L .6854 .55458 L p .707 .577 .707 r
F P
0 g
s
.65662 .69413 m .65558 .71316 L .63933 .71598 L p .707 .577 .707 r
F P
0 g
s
.31057 .54358 m .30872 .60019 L .32979 .60542 L p .707 .577 .707 r
F P
0 g
s
.32722 .67739 m .32618 .69642 L .35365 .70009 L p .707 .577 .707 r
F P
0 g
s
.47545 .55081 m .4736 .60743 L .48993 .60272 L p .707 .577 .707 r
F P
0 g
s
.48993 .60272 m .49178 .5461 L .47545 .55081 L p .707 .577 .707 r
F P
0 g
s
.32791 .65859 m .32995 .62055 L .30884 .61613 L p .707 .577 .707 r
F P
0 g
s
.82414 .64689 m .8221 .68493 L .80099 .68051 L p .707 .577 .707 r
F P
0 g
s
.80099 .68051 m .80303 .64247 L .82414 .64689 L p .707 .577 .707 r
F P
0 g
s
.44692 .68487 m .44588 .7039 L .46981 .70235 L p .707 .577 .707 r
F P
0 g
s
.46981 .70235 m .47086 .68332 L .44692 .68487 L p .707 .577 .707 r
F P
0 g
s
.6854 .55458 m .68355 .6112 L .65953 .61445 L p .707 .577 .707 r
F P
0 g
s
.30884 .61613 m .3068 .65417 L .32791 .65859 L p .707 .577 .707 r
F P
0 g
s
.80519 .55984 m .80334 .61646 L .77588 .61249 L p .707 .577 .707 r
F P
0 g
s
.77588 .61249 m .77773 .55587 L .80519 .55984 L p .707 .577 .707 r
F P
0 g
s
.30872 .60019 m .31057 .54358 L .29794 .53759 L p .707 .577 .707 r
F P
0 g
s
.32618 .69642 m .32722 .67739 L .30611 .67303 L p .707 .577 .707 r
F P
0 g
s
.82138 .70443 m .82033 .72346 L .79922 .71909 L p .707 .577 .707 r
F P
0 g
s
.79922 .71909 m .80026 .70006 L .82138 .70443 L p .707 .577 .707 r
F P
0 g
s
.65734 .67483 m .65938 .63679 L .68332 .63513 L p .707 .577 .707 r
F P
0 g
s
.30611 .67303 m .30506 .69206 L .32618 .69642 L p .707 .577 .707 r
F P
0 g
s
.68355 .6112 m .6854 .55458 L .71475 .55311 L p .707 .577 .707 r
F P
0 g
s
.4736 .62623 m .47156 .66427 L .48781 .66133 L p .707 .577 .707 r
F P
0 g
s
.48781 .66133 m .48985 .62328 L .4736 .62623 L p .707 .577 .707 r
F P
0 g
s
.68332 .63513 m .68128 .67317 L .65734 .67483 L p .707 .577 .707 r
F P
0 g
s
.29794 .53759 m .29609 .59421 L .30872 .60019 L p .707 .577 .707 r
F P
0 g
s
.65558 .71316 m .65662 .69413 L .68056 .69258 L p .707 .577 .707 r
F P
0 g
s
.68056 .69258 m .67952 .71161 L .65558 .71316 L p .707 .577 .707 r
F P
0 g
s
.77773 .55587 m .77588 .61249 L .74471 .61017 L p .707 .577 .707 r
F P
0 g
s
.74471 .61017 m .74656 .55355 L .77773 .55587 L p .707 .577 .707 r
F P
0 g
s
.47086 .68332 m .46981 .70235 L .48606 .69953 L p .707 .577 .707 r
F P
0 g
s
.48606 .69953 m .4871 .6805 L .47086 .68332 L p .707 .577 .707 r
F P
0 g
s
.3068 .65417 m .30884 .61613 L .29616 .61141 L p .707 .577 .707 r
F P
0 g
s
.80303 .64247 m .80099 .68051 L .77351 .67682 L p .707 .577 .707 r
F P
0 g
s
.77351 .67682 m .77555 .63878 L .80303 .64247 L p .707 .577 .707 r
F P
0 g
s
.71475 .55311 m .7129 .60972 L .68355 .6112 L p .707 .577 .707 r
F P
0 g
s
.49178 .5461 m .48993 .60272 L .49697 .59701 L p .707 .577 .707 r
F P
0 g
s
.49697 .59701 m .49882 .54039 L .49178 .5461 L p .707 .577 .707 r
F P
0 g
s
.7129 .60972 m .71475 .55311 L .74656 .55355 L p .707 .577 .707 r
F P
0 g
s
.29616 .61141 m .29412 .64945 L .3068 .65417 L p .707 .577 .707 r
F P
0 g
s
.74656 .55355 m .74471 .61017 L .7129 .60972 L p .707 .577 .707 r
F P
0 g
s
.68128 .67317 m .68332 .63513 L .71262 .63492 L p .707 .577 .707 r
F P
0 g
s
.30506 .69206 m .30611 .67303 L .29343 .6684 L p .707 .577 .707 r
F P
0 g
s
.80026 .70006 m .79922 .71909 L .77174 .71542 L p .707 .577 .707 r
F P
0 g
s
.77174 .71542 m .77278 .69639 L .80026 .70006 L p .707 .577 .707 r
F P
0 g
s
.29343 .6684 m .29238 .68743 L .30506 .69206 L p .707 .577 .707 r
F P
0 g
s
.71262 .63492 m .71058 .67296 L .68128 .67317 L p .707 .577 .707 r
F P
0 g
s
.29609 .59421 m .29794 .53759 L .29501 .53144 L p .707 .577 .707 r
F P
0 g
s
.67952 .71161 m .68056 .69258 L .70986 .69246 L p .707 .577 .707 r
F P
0 g
s
.77555 .63878 m .77351 .67682 L .74236 .67422 L p .707 .577 .707 r
F P
0 g
s
.74236 .67422 m .7444 .63617 L .77555 .63878 L p .707 .577 .707 r
F P
0 g
s
.48985 .62328 m .48781 .66133 L .49477 .65739 L p .707 .577 .707 r
F P
0 g
s
.49477 .65739 m .49681 .61934 L .48985 .62328 L p .707 .577 .707 r
F P
0 g
s
.70986 .69246 m .70881 .71149 L .67952 .71161 L p .707 .577 .707 r
F P
0 g
s
.71058 .67296 m .71262 .63492 L .7444 .63617 L p .707 .577 .707 r
F P
0 g
s
.7444 .63617 m .74236 .67422 L .71058 .67296 L p .707 .577 .707 r
F P
0 g
s
.29501 .53144 m .29316 .58806 L .29609 .59421 L p .707 .577 .707 r
F P
0 g
s
.77278 .69639 m .77174 .71542 L .74058 .7128 L p .707 .577 .707 r
F P
0 g
s
.74058 .7128 m .74163 .69377 L .77278 .69639 L p .707 .577 .707 r
F P
0 g
s
.4871 .6805 m .48606 .69953 L .49301 .69571 L p .707 .577 .707 r
F P
0 g
s
.49301 .69571 m .49406 .67668 L .4871 .6805 L p .707 .577 .707 r
F P
0 g
s
.29412 .64945 m .29616 .61141 L .29315 .60686 L p .707 .577 .707 r
F P
0 g
s
.70881 .71149 m .70986 .69246 L .74163 .69377 L p .707 .577 .707 r
F P
0 g
s
.74163 .69377 m .74058 .7128 L .70881 .71149 L p .707 .577 .707 r
F P
0 g
s
.49882 .54039 m .49697 .59701 L .49403 .59086 L p .707 .577 .707 r
F P
0 g
s
.49403 .59086 m .49588 .53424 L .49882 .54039 L p .707 .577 .707 r
F P
0 g
s
.29315 .60686 m .29111 .6449 L .29412 .64945 L p .707 .577 .707 r
F P
0 g
s
.29238 .68743 m .29343 .6684 L .29042 .66396 L p .707 .577 .707 r
F P
0 g
s
.29042 .66396 m .28937 .68299 L .29238 .68743 L p .707 .577 .707 r
F P
0 g
s
.29316 .58806 m .29501 .53144 L .30205 .52574 L p .707 .577 .707 r
F P
0 g
s
.49681 .61934 m .49477 .65739 L .49177 .65283 L p .707 .577 .707 r
F P
0 g
s
.49177 .65283 m .49381 .61479 L .49681 .61934 L p .707 .577 .707 r
F P
0 g
s
.30205 .52574 m .3002 .58235 L .29316 .58806 L p .707 .577 .707 r
F P
0 g
s
.49406 .67668 m .49301 .69571 L .49 .69127 L p .707 .577 .707 r
F P
0 g
s
.49 .69127 m .49105 .67224 L .49406 .67668 L p .707 .577 .707 r
F P
0 g
s
.29111 .6449 m .29315 .60686 L .30012 .60292 L p .707 .577 .707 r
F P
0 g
s
.49588 .53424 m .49403 .59086 L .48141 .58488 L p .707 .577 .707 r
F P
0 g
s
.48141 .58488 m .48326 .52826 L .49588 .53424 L p .707 .577 .707 r
F P
0 g
s
.30012 .60292 m .29808 .64096 L .29111 .6449 L p .707 .577 .707 r
F P
0 g
s
.28937 .68299 m .29042 .66396 L .29737 .66014 L p .707 .577 .707 r
F P
0 g
s
.29737 .66014 m .29632 .67917 L .28937 .68299 L p .707 .577 .707 r
F P
0 g
s
.3002 .58235 m .30205 .52574 L .31837 .52102 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49381 .61479 m .49177 .65283 L .47909 .64812 L p .707 .577 .707 r
F P
0 g
s
.47909 .64812 m .48113 .61007 L .49381 .61479 L p .707 .577 .707 r
F P
0 g
s
.31837 .52102 m .31652 .57764 L .3002 .58235 L p .707 .577 .707 r
F P
0 g
s
.49105 .67224 m .49 .69127 L .47732 .68664 L p .707 .577 .707 r
F P
0 g
s
.47732 .68664 m .47837 .66761 L .49105 .67224 L p .707 .577 .707 r
F P
0 g
s
.29808 .64096 m .30012 .60292 L .31637 .59997 L p .707 .577 .707 r
F P
0 g
s
.48326 .52826 m .48141 .58488 L .46033 .57964 L p .707 .577 .707 r
F P
0 g
s
.46033 .57964 m .46218 .52303 L .48326 .52826 L p .707 .577 .707 r
F P
0 g
s
.31637 .59997 m .31433 .63802 L .29808 .64096 L p .707 .577 .707 r
F P
0 g
s
.29632 .67917 m .29737 .66014 L .31361 .65731 L p .707 .577 .707 r
F P
0 g
s
.31652 .57764 m .31837 .52102 L .34239 .51777 L p .707 .577 .707 r
F P
0 g
s
.31361 .65731 m .31257 .67634 L .29632 .67917 L p .707 .577 .707 r
F P
0 g
s
.48113 .61007 m .47909 .64812 L .45798 .6437 L p .707 .577 .707 r
F P
0 g
s
.45798 .6437 m .46002 .60565 L .48113 .61007 L p .707 .577 .707 r
F P
0 g
s
.34239 .51777 m .34054 .57438 L .31652 .57764 L p .707 .577 .707 r
F P
0 g
s
.46218 .52303 m .46033 .57964 L .43287 .57567 L p .707 .577 .707 r
F P
0 g
s
.43287 .57567 m .43472 .51905 L .46218 .52303 L p .707 .577 .707 r
F P
0 g
s
.47837 .66761 m .47732 .68664 L .4562 .68228 L p .707 .577 .707 r
F P
0 g
s
.4562 .68228 m .45725 .66325 L .47837 .66761 L p .707 .577 .707 r
F P
0 g
s
.31433 .63802 m .31637 .59997 L .34031 .59831 L p .707 .577 .707 r
F P
0 g
s
.34054 .57438 m .34239 .51777 L .37174 .51629 L p .707 .577 .707 r
F P
0 g
s
.34031 .59831 m .33827 .63636 L .31433 .63802 L p .707 .577 .707 r
F P
0 g
s
.31257 .67634 m .31361 .65731 L .33755 .65577 L p .707 .577 .707 r
F P
0 g
s
.33755 .65577 m .33651 .6748 L .31257 .67634 L p .707 .577 .707 r
F P
0 g
s
.43472 .51905 m .43287 .57567 L .4017 .57335 L p .707 .577 .707 r
F P
0 g
s
.4017 .57335 m .40355 .51673 L .43472 .51905 L p .707 .577 .707 r
F P
0 g
s
.46002 .60565 m .45798 .6437 L .4305 .64 L p .707 .577 .707 r
F P
0 g
s
.4305 .64 m .43254 .60196 L .46002 .60565 L p .707 .577 .707 r
F P
0 g
s
.37174 .51629 m .36989 .57291 L .34054 .57438 L p .707 .577 .707 r
F P
0 g
s
.36989 .57291 m .37174 .51629 L .40355 .51673 L p .707 .577 .707 r
F P
0 g
s
.40355 .51673 m .4017 .57335 L .36989 .57291 L p .707 .577 .707 r
F P
0 g
s
.33827 .63636 m .34031 .59831 L .36961 .5981 L p .707 .577 .707 r
F P
0 g
s
.45725 .66325 m .4562 .68228 L .42873 .6786 L p .707 .577 .707 r
F P
0 g
s
.42873 .6786 m .42977 .65957 L .45725 .66325 L p .707 .577 .707 r
F P
0 g
s
.36961 .5981 m .36757 .63615 L .33827 .63636 L p .707 .577 .707 r
F P
0 g
s
.33651 .6748 m .33755 .65577 L .36684 .65564 L p .707 .577 .707 r
F P
0 g
s
.43254 .60196 m .4305 .64 L .39935 .6374 L p .707 .577 .707 r
F P
0 g
s
.39935 .6374 m .40139 .59936 L .43254 .60196 L p .707 .577 .707 r
F P
0 g
s
.36684 .65564 m .3658 .67467 L .33651 .6748 L p .707 .577 .707 r
F P
0 g
s
.36757 .63615 m .36961 .5981 L .40139 .59936 L p .707 .577 .707 r
F P
0 g
s
.40139 .59936 m .39935 .6374 L .36757 .63615 L p .707 .577 .707 r
F P
0 g
s
.42977 .65957 m .42873 .6786 L .39757 .67598 L p .707 .577 .707 r
F P
0 g
s
.39757 .67598 m .39862 .65695 L .42977 .65957 L p .707 .577 .707 r
F P
0 g
s
.3658 .67467 m .36684 .65564 L .39862 .65695 L p .707 .577 .707 r
F P
0 g
s
.39862 .65695 m .39757 .67598 L .3658 .67467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolE0028Ool007Qoo`P000IJEP03001JEUYF00UJEP03001JEUYF00H0089oo`00M7oo
100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01UYF1000OWoo001`Ool40005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000O7oo001/Ool40009FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P00NWoo001ZOol200000eYF
001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001h
Ool006Qoo`8000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8007Ioo`00IWoo0P001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01eYF00<007ooOol0Lgoo001TOol20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00Oomo
o`1bOol006=oo`8000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001oogoo075oo`00HWoo00<005YF000025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02EYF00<007ooOol0L7oo001P
Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool005moo`03001JEUYF009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EW5oo`00GWoo00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYFLGoo001MOol00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005eoo`03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0KWoo001LOol20007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1^Ool005]oo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06io
o`00Fgoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0KWoo001KOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1]Ool005aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06eoo`00G7oo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00KWoo001LOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0KGoo001LOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YFKWoo001MOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVioo`00GGoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03
001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001^Ool005eoo`03001JEP0000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00GGoo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1/Ool0
05eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00KGoo001MOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<0
05YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1[Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]o
o`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00K7oo001NOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo
001OOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005moo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000=JEQ4000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo001HOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001EOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001[Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001[Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Jgoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1Y
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00]ooaX004Aoo`00Dgoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000fOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`02Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000bOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000=JEP04001JEUYFFUH8
00000eYF001JEP06FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005=oo`03001JEP00009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEPD000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2
0002Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP05
001oo`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOolO00000eYF001JEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]
Ool005Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80000
0eYF001JEP05FUH00`00FUIJEP030002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool0
05=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH;0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP050004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00Ool005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00=goo7@0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF008002ioo`00;Woo0`000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH300001EYF
000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF10000UYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJ
EP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP800003Ool005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEP0000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEP00FUH00P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP80009oo`800003FUH005YF00AJEQX000QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002FUH70007FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`090003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80000
0eYF001JEP05FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Ool0000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL00003FUH0
05YF0080035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000<Woo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1@0000=JEP0000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF0000800025YF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH=0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000=JEP04001JEUYFFUHJ0002FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000UYF1P00
25YF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH00UYF00@005YFFUIJEQ0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000015YF001JEUYF7P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP00009JEPd00003FUH005YF00EJ
EPl000IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH40005
FUH01000FUIJEUYF200015YF00<005YF00000P001EYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF1`000eYF00@005YFFUIJEP8002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF009JEQ/000=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00;Woo000/
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH50002FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000^Ool002eoo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYFFUH40002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF000000020003FUH@00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000^Ool002moo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEP00008000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPT00003FUH005YF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02ioo`00<Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1@0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH01EYF00<005YFFUH01000;goo000aOolN00000eYF001JEP06FUH00`00FUIJEP04FUHC
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP/003=oo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEQ80009oo`04001JEUYF0006FUH00`00FUIJEP02FUH@0000
0eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH70005Ool01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;goo000/Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP060002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00MJEPT000IJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF
001JEP040004FUH5000015YF001JEUYF0P002Goo0`000goo200015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUIJEPH000QJEPX000UJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUHC000:Ool70003FUH00`00FUIJEP02
000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00MJEPH000=JEP03001J
EUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUHE
0002FUH40002FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP004EYF00<0
05YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02EYF0P000UYF1@001UYF00@005YFFUIJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUH005YF000AFUH00`00FUH00003000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20007FUH20004
FUH01000FUIJEUYF0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000@FUH30003FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH20008FUH400000eYF001JEP03FUH00`00FUIJEP02FUH80004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
02moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000>FUH20006FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20008FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`00<7oo000[Ool00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000]JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP8000QJEP8000AJEP04001JEUYFFUH20003FUH01000FUIJEUYF1P001Woo8000<goo000[Ool00`00
FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJ
EP03FUH01000FUIJEP002eYF0`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P002EYF00<005YFFUH00eYF00D005YFFUH005YF00P005ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YF
FUH000UJEP80009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000MJEP03001JEP00008005]oo`00;7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEPD00003FUH005YF00IJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000MJEP03001JEUYF
009JEP<005Qoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EWoo000_Ool40003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF
00=JEP03001JEUYF008005Eoo`00<goo1`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP<000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0006FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol003Yoo`P000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH90002FUH01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF0P0025YF00<005YFFUH015YF00@005YF000000EJEP03001J
EUYF00AJEP03001JEUYF008005Eoo`00<7oo;0002Goo0UYF00@005YFFUH000QJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP03001JEUYF00AJEP04001J
EUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000]Ool30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000>Ool00eYF001JEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20008FUH0
0`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000[Ool30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0027oo00=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0100017oo00=JEP00FUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000Woo0P000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP0000001P000eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00@005YF
FUIJEQ0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00@000=J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP@000=JEP8005Eoo`00:goo
00<005YF000030002goo4@0015YF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000005Eo
o`00:goo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPP001Aoo`H000AJEP04001JEUYFFUH30003
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3001EOol002]oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF009JEQd00003
FUH005YF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0005Eoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF0`0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP03001JEUYF00@005Ioo`00;Woo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF01<005Yoo`00<Woo1`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF
001oo`0000=JEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP80
00QJEP/006Eoo`00>Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH010000goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH6001OOol0049oo`T0
00AJEP03001JEUYF00EJEP04001JEUYFFUH60008Ool00`00FUH00008FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP05
FUH00`00FUH00002001LOol004]ooa0000moo`8000QJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF009JEP<000QJEP03001JEUYF00EJEP03001JEUYF
009JEP<005Uoo`00Jgoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00P000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000P00EWoo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo
001`Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH3000;
Ool80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo001cOol40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH01000FUIJEUYF1P000UYF2@002goo1`000eYF00<005YFFUH00P00EWoo001gOol6
0002FUH00`00FUIJEP09FUH00`00FUIJEP07FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@
0002FUH500000eYF0000001FOol007eoo`P000IJEP04001JEUYFFUH60002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
EWoo0025Ool:00000goo000000020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002DOol70004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00
Egoo002SOolP001JOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49193 .84878 m .43439 .4082 L .3905 .40746 L p .707 .577 .707 r
F P
0 g
s
.55648 .84817 m .55816 .82904 L .53065 .82582 L p .707 .577 .707 r
F P
0 g
s
.53065 .82582 m .52897 .84495 L .55648 .84817 L p .707 .577 .707 r
F P
0 g
s
.53175 .79367 m .53503 .7554 L .51383 .75226 L p .707 .577 .707 r
F P
0 g
s
.51383 .75226 m .51055 .79052 L .53175 .79367 L p .707 .577 .707 r
F P
0 g
s
.52897 .84495 m .53065 .82582 L .50944 .82276 L p .707 .577 .707 r
F P
0 g
s
.50944 .82276 m .50776 .8419 L .52897 .84495 L p .707 .577 .707 r
F P
0 g
s
.50377 .6688 m .50078 .72584 L .51346 .73063 L p .707 .577 .707 r
F P
0 g
s
.51055 .79052 m .51383 .75226 L .50102 .74953 L p .707 .577 .707 r
F P
0 g
s
.50102 .74953 m .49774 .78779 L .51055 .79052 L p .707 .577 .707 r
F P
0 g
s
.50776 .8419 m .50944 .82276 L .49661 .82017 L p .707 .577 .707 r
F P
0 g
s
.49661 .82017 m .49493 .83931 L .50776 .8419 L p .707 .577 .707 r
F P
0 g
s
.50078 .72584 m .50377 .6688 L .50077 .66415 L p .707 .577 .707 r
F P
0 g
s
.50077 .66415 m .49778 .72119 L .50078 .72584 L p .707 .577 .707 r
F P
0 g
s
.49774 .78779 m .50102 .74953 L .49784 .74748 L p .707 .577 .707 r
F P
0 g
s
.49784 .74748 m .49456 .78575 L .49774 .78779 L p .707 .577 .707 r
F P
0 g
s
.49493 .83931 m .49661 .82017 L .49342 .81831 L p .707 .577 .707 r
F P
0 g
s
.49342 .81831 m .49173 .83744 L .49493 .83931 L p .707 .577 .707 r
F P
0 g
s
.51346 .73063 m .51644 .67359 L .50377 .6688 L p .707 .577 .707 r
F P
0 g
s
.49778 .72119 m .50077 .66415 L .50774 .6601 L p .707 .577 .707 r
F P
0 g
s
.50774 .6601 m .50475 .71715 L .49778 .72119 L p .707 .577 .707 r
F P
0 g
s
.49456 .78575 m .49784 .74748 L .50461 .74631 L p .707 .577 .707 r
F P
0 g
s
.50461 .74631 m .50133 .78458 L .49456 .78575 L p .707 .577 .707 r
F P
0 g
s
.49173 .83744 m .49342 .81831 L .50017 .81734 L p .707 .577 .707 r
F P
0 g
s
.50017 .81734 m .49849 .83647 L .49173 .83744 L p .707 .577 .707 r
F P
0 g
s
.50475 .71715 m .50774 .6601 L .51142 .65941 L p .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .47899 .40146 L .45306 .40538 L p .707 .577 .707 r
F P
0 g
s
.56204 .73881 m .56503 .68177 L .53755 .67806 L p .707 .577 .707 r
F P
0 g
s
.53755 .67806 m .53457 .7351 L .56204 .73881 L p .707 .577 .707 r
F P
0 g
s
.56254 .75866 m .55926 .79692 L .59038 .79996 L p .707 .577 .707 r
F P
0 g
s
.55926 .79692 m .56254 .75866 L .53503 .7554 L p .707 .577 .707 r
F P
0 g
s
.53457 .7351 m .53755 .67806 L .51644 .67359 L p .707 .577 .707 r
F P
0 g
s
.51644 .67359 m .51346 .73063 L .53457 .7351 L p .707 .577 .707 r
F P
0 g
s
.47899 .40146 m .51433 .67207 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.55655 .73776 m .47899 .40146 L .52886 .70807 L .707 .577 .707 r
F
.52101 .71409 m .52172 .70041 L p .52544 .70441 L F P
0 g
s
.5876 .85124 m .58928 .83211 L .55816 .82904 L p .707 .577 .707 r
F P
0 g
s
.53503 .7554 m .53175 .79367 L .55926 .79692 L p .707 .577 .707 r
F P
0 g
s
.55816 .82904 m .55648 .84817 L .5876 .85124 L p .707 .577 .707 r
F P
0 g
s
.53362 .71317 m .52101 .71409 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .52066 .74615 L .54185 .7469 L p .707 .577 .707 r
F P
0 g
s
.54185 .7469 m .54443 .74699 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .54185 .7469 L .54306 .74888 L .707 .577 .707 r
F
.50475 .71715 m .51142 .65941 L .51636 .6809 L F
.49664 .67262 m .51433 .67207 L .43439 .4082 L F
.52886 .70807 m .51433 .67207 L .52172 .70041 L F
.52399 .65705 m .52101 .71409 L .50475 .71715 L p F P
0 g
s
.50133 .78458 m .50461 .74631 L .52066 .74615 L p .707 .577 .707 r
F P
0 g
s
.52066 .74615 m .51738 .78441 L .50133 .78458 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .51738 .78441 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54443 .74699 m .54412 .75062 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54412 .75062 m .54115 .78525 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.49849 .83647 m .50017 .81734 L .51621 .81737 L p .707 .577 .707 r
F P
0 g
s
.51621 .81737 m .51452 .8365 L .49849 .83647 L p .707 .577 .707 r
F P
0 g
s
.51452 .8365 m .51621 .81737 L .53996 .81839 L p .707 .577 .707 r
F P
0 g
s
.53996 .81839 m .53828 .83753 L .51452 .8365 L p .707 .577 .707 r
F P
0 g
s
.49193 .84878 m .53653 .84205 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.43439 .4082 m .46135 .61464 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.46135 .61464 m .49193 .84878 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.53653 .84205 m .51925 .70977 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.51925 .70977 m .51433 .67207 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.59038 .79996 m .59366 .7617 L .56254 .75866 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .54318 .76162 L p .57359 .74876 L .707 .577 .707 r
F P
0 g
s
.54318 .76162 m .54443 .74699 L .55319 .74752 L p .707 .577 .707 r
F P
0 g
s
.55319 .74752 m .57359 .74876 L p .54318 .76162 L .707 .577 .707 r
F P
0 g
s
.5932 .7414 m .59618 .68435 L .56503 .68177 L p .707 .577 .707 r
F P
0 g
s
.59618 .68435 m .5932 .7414 L .62498 .7426 L p .707 .577 .707 r
F P
0 g
s
.56503 .68177 m .56204 .73881 L .5932 .7414 L p .707 .577 .707 r
F P
0 g
s
.59366 .7617 m .59038 .79996 L .62207 .80249 L p .707 .577 .707 r
F P
0 g
s
.62207 .80249 m .62536 .76423 L .59366 .7617 L p .707 .577 .707 r
F P
0 g
s
.62498 .7426 m .62797 .68556 L .59618 .68435 L p .707 .577 .707 r
F P
0 g
s
.60903 .65621 m .60604 .71326 L .58378 .71241 L p .707 .577 .707 r
F P
0 g
s
.58378 .71241 m .57426 .71205 L p .58649 .6924 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .60903 .65621 L .58378 .71241 L .707 .577 .707 r
F
.62536 .76423 m .62207 .80249 L .65123 .80427 L p F P
0 g
s
.65123 .80427 m .65451 .766 L .62536 .76423 L p .707 .577 .707 r
F P
0 g
s
.62797 .68556 m .62498 .7426 L .65428 .74232 L p .707 .577 .707 r
F P
0 g
s
.65428 .74232 m .65727 .68527 L .62797 .68556 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .60671 .71331 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60669 .71221 m .63368 .66916 L .60671 .71331 L .707 .577 .707 r
F
.63368 .66916 m .64018 .6588 L .63371 .66934 L F
.63368 .66916 m .63371 .66934 L .60671 .71331 L F
.58483 .32212 m .57558 .3462 L p .60413 .52426 L F P
0 g
s
.60903 .65621 m .64018 .6588 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .6364 .75434 L .64646 .75552 L p .707 .577 .707 r
F P
0 g
s
.65451 .766 m .65123 .80427 L .675 .80511 L p .707 .577 .707 r
F P
0 g
s
.675 .80511 m .67828 .76685 L .65451 .766 L p .707 .577 .707 r
F P
0 g
s
.64646 .75552 m .66391 .75759 L p .64932 .77418 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .64646 .75552 L .64932 .77418 L .707 .577 .707 r
F
.64236 .76271 m .6033 .46358 L p .60413 .52426 L F P
0 g
s
.6364 .75434 m .63312 .7926 L .60773 .79012 L p .707 .577 .707 r
F P
0 g
s
.60778 .78365 m .6364 .75434 L .60773 .79012 L .707 .577 .707 r
F
.602 .78956 m .60528 .7513 L .60802 .75156 L p F P
0 g
s
.60802 .75156 m .6364 .75434 L p .60778 .78365 L .707 .577 .707 r
F P
0 g
s
.602 .78956 m .60802 .75156 L .60778 .78365 L .707 .577 .707 r
F
.60475 .56956 m .60914 .60321 L p .60413 .52426 L F P
0 g
s
.60914 .60321 m .63311 .78679 L p .60938 .5718 L .707 .577 .707 r
F P
0 g
s
.60413 .52426 m .60914 .60321 L .60938 .5718 L .707 .577 .707 r
F
.63311 .78679 m .64236 .76271 L p .60948 .55766 L F P
0 g
s
.60948 .55766 m .60413 .52426 L .60938 .5718 L .707 .577 .707 r
F
.60948 .55766 m .60938 .5718 L .63311 .78679 L F
.60773 .79012 m .602 .78956 L p .60778 .78365 L F P
0 g
s
.64236 .76271 m .6376 .73959 L p .608 .50546 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .58483 .32212 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.608 .50546 m .59921 .43593 L .61078 .52349 L .707 .577 .707 r
F
.608 .50546 m .61078 .52349 L .64236 .76271 L F
.60604 .71326 m .60657 .70314 L p .60669 .71221 L F P
0 g
s
.60657 .70314 m .60903 .65621 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.58006 .299 m .58483 .32212 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6376 .73959 m .58831 .36214 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58831 .36214 m .58006 .299 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58483 .32212 m .6033 .46358 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .64236 .76271 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.64018 .6588 m .63808 .69891 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.63808 .69891 m .63719 .71584 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60671 .71331 m .60604 .71326 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .60475 .56956 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.55322 .36887 m .59106 .65864 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .55322 .36887 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .58753 .68473 L .60903 .65621 L .707 .577 .707 r
F
.59221 .65558 m .60903 .65621 L p .5748 .70161 L F P
0 g
s
.63311 .78679 m .60394 .56338 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.60394 .56338 m .57558 .3462 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .5748 .70161 L p .58753 .68473 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .58753 .68473 L .58649 .6924 L .707 .577 .707 r
F
.51993 .38791 m .56346 .7212 L p .5829 .68019 L F P
0 g
s
.5748 .70161 m .57426 .71205 L .56873 .71211 L p .707 .577 .707 r
F P
0 g
s
.56346 .7212 m .56447 .72893 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.5829 .68019 m .56346 .7212 L .5748 .70161 L .707 .577 .707 r
F
.57359 .74876 m .57031 .78703 L .54115 .78525 L p F P
0 g
s
.57031 .78703 m .57359 .74876 L .58061 .74932 L p .707 .577 .707 r
F P
0 g
s
.58061 .74932 m .60528 .7513 L p .57445 .7828 L .707 .577 .707 r
F P
0 g
s
.57031 .78703 m .58061 .74932 L .57445 .7828 L .707 .577 .707 r
F
.60528 .7513 m .602 .78956 L .57031 .78703 L p F P
0 g
s
.61075 .80945 m .55322 .36887 L .51993 .38791 L p .707 .577 .707 r
F P
0 g
s
.5748 .70161 m .57724 .65501 L .59221 .65558 L p .707 .577 .707 r
F P
0 g
s
.59106 .65864 m .59365 .67849 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.59365 .67849 m .61075 .80945 L p .60053 .6411 L .707 .577 .707 r
F P
0 g
s
.59833 .60485 m .59365 .67849 L .60053 .6411 L .707 .577 .707 r
F
.56742 .83944 m .56911 .82031 L .60079 .82293 L p F P
0 g
s
.57747 .8285 m .51993 .38791 L .47899 .40146 L p .707 .577 .707 r
F P
0 g
s
.57724 .65501 m .5748 .70161 L p .54496 .71234 L .707 .577 .707 r
F P
0 g
s
.56873 .71211 m .54496 .71234 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.58712 .69976 m .5829 .68019 L .56477 .73123 L .707 .577 .707 r
F
.56447 .72893 m .56477 .73123 L p .5829 .68019 L F P
0 g
s
.61075 .80945 m .63311 .78679 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .61075 .80945 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.56477 .73123 m .57747 .8285 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.53828 .83753 m .53996 .81839 L .56911 .82031 L p .707 .577 .707 r
F P
0 g
s
.56911 .82031 m .56742 .83944 L .53828 .83753 L p .707 .577 .707 r
F P
0 g
s
.55691 .8353 m .57747 .8285 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.52886 .70807 m .52172 .70041 L .55691 .8353 L .707 .577 .707 r
F
.54794 .6553 m .54496 .71234 L .53362 .71317 L p F P
0 g
s
.52544 .70441 m .54794 .6553 L .53362 .71317 L .707 .577 .707 r
F
.52399 .65705 m .54794 .6553 L p .52544 .70441 L F P
0 g
s
.52172 .70041 m .52399 .65705 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .55655 .73776 L .52886 .70807 L .707 .577 .707 r
F
.51636 .6809 m .51433 .67207 L .51651 .68043 L F
.51433 .67207 m .53653 .84205 L .55691 .8353 L p F P
0 g
s
.51142 .65941 m .52399 .65705 L p .51651 .68043 L .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .51142 .65941 L .51651 .68043 L .707 .577 .707 r
F
.45306 .40538 m .43439 .4082 L p .51433 .67207 L F P
0 g
s
.44804 .84804 m .3905 .40746 L .35162 .39931 L p .707 .577 .707 r
F P
0 g
s
.3905 .40746 m .44804 .84804 L .49193 .84878 L p .707 .577 .707 r
F P
0 g
s
.40915 .8399 m .35162 .39931 L .32155 .38456 L p .707 .577 .707 r
F P
0 g
s
.35162 .39931 m .40915 .8399 L .44804 .84804 L p .707 .577 .707 r
F P
0 g
s
.65727 .68527 m .65428 .74232 L .67823 .74056 L p .707 .577 .707 r
F P
0 g
s
.67823 .74056 m .68122 .68352 L .65727 .68527 L p .707 .577 .707 r
F P
0 g
s
.58928 .83211 m .5876 .85124 L .61928 .85387 L p .707 .577 .707 r
F P
0 g
s
.61928 .85387 m .62096 .83473 L .58928 .83211 L p .707 .577 .707 r
F P
0 g
s
.62096 .83473 m .61928 .85387 L .64843 .85578 L p .707 .577 .707 r
F P
0 g
s
.64843 .85578 m .65011 .83665 L .62096 .83473 L p .707 .577 .707 r
F P
0 g
s
.68122 .68352 m .67823 .74056 L .69448 .73751 L p .707 .577 .707 r
F P
0 g
s
.69448 .73751 m .69747 .68047 L .68122 .68352 L p .707 .577 .707 r
F P
0 g
s
.65011 .83665 m .64843 .85578 L .67218 .85681 L p .707 .577 .707 r
F P
0 g
s
.67218 .85681 m .67386 .83767 L .65011 .83665 L p .707 .577 .707 r
F P
0 g
s
.35147 .70069 m .35446 .64365 L .33821 .6467 L p .707 .577 .707 r
F P
0 g
s
.35446 .64365 m .35147 .70069 L .35844 .69665 L p .707 .577 .707 r
F P
0 g
s
.35844 .69665 m .35916 .68297 L p .35446 .64365 L .707 .577 .707 r
F P
0 g
s
.37908 .82515 m .35999 .67891 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35689 .65518 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35916 .68297 L .3626 .72506 L .707 .577 .707 r
F
.37908 .82515 m .40915 .8399 L p .34771 .52055 L F P
0 g
s
.35689 .65518 m .37908 .82515 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .36143 .6396 L .35604 .64273 L p .707 .577 .707 r
F P
0 g
s
.35604 .64273 m .35588 .64283 L p .35689 .65518 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35604 .64273 L .35689 .65518 L .707 .577 .707 r
F
.35588 .64283 m .35446 .64365 L p .35916 .68297 L F P
0 g
s
.32155 .38456 m .35689 .65518 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35844 .69665 L .35686 .6942 L p .707 .577 .707 r
F P
0 g
s
.32155 .38456 m .30323 .36465 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35689 .65518 m .32155 .38456 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.33821 .6467 m .33522 .70374 L .35147 .70069 L p .707 .577 .707 r
F P
0 g
s
.34805 .76813 m .35133 .72986 L .33527 .73003 L p .707 .577 .707 r
F P
0 g
s
.35133 .72986 m .34805 .76813 L .35482 .76696 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .3581 .7287 L .35133 .72986 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .35164 .76491 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.3581 .7287 m .35618 .75107 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35618 .75107 m .35482 .76696 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.34546 .68996 m .30323 .36465 L .34444 .68365 L .707 .577 .707 r
F
.33527 .73003 m .33199 .7683 L .34805 .76813 L p F P
0 g
s
.33882 .76218 m .3421 .72392 L .35107 .72583 L p .707 .577 .707 r
F P
0 g
s
.35107 .72583 m .35492 .72665 L p .35221 .73263 L .707 .577 .707 r
F P
0 g
s
.33882 .76218 m .35107 .72583 L .35221 .73263 L .707 .577 .707 r
F
.35113 .73139 m .34807 .70797 L p .35054 .72912 L F P
0 g
s
.34807 .70797 m .34676 .69794 L p .34774 .70599 L .707 .577 .707 r
F P
0 g
s
.34807 .70797 m .34774 .70599 L .35054 .72912 L .707 .577 .707 r
F
.34676 .69794 m .30323 .36465 L p .34546 .68996 L F P
0 g
s
.34676 .69794 m .34546 .68996 L .35054 .72912 L .707 .577 .707 r
F
.30323 .36465 m .29847 .34152 L p .34444 .68365 L F P
0 g
s
.36077 .80524 m .37908 .82515 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.30323 .36465 m .34676 .69794 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .3581 .7287 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35164 .76491 m .35366 .74128 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35366 .74128 m .35492 .72665 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .35164 .76491 L .33882 .76218 L p .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .36077 .80524 L p .35054 .72912 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .34332 .67676 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34516 .68811 m .34277 .68721 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.29847 .34152 m .30772 .31745 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .33644 .68587 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.33522 .70374 m .33821 .6467 L .31426 .64846 L p .707 .577 .707 r
F P
0 g
s
.33636 .65067 m .33856 .64587 L .33644 .68587 L .707 .577 .707 r
F
.29847 .34152 m .33631 .63129 L p .34484 .68665 L F P
0 g
s
.34576 .63016 m .34332 .67676 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34277 .68721 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.35054 .72912 m .34484 .68665 L .34758 .71757 L .707 .577 .707 r
F
.33631 .63129 m .29847 .34152 L p .33622 .59168 L F P
0 g
s
.31426 .64846 m .31127 .7055 L .33522 .70374 L p .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .32465 .62569 L .3363 .62816 L p .707 .577 .707 r
F P
0 g
s
.3363 .62816 m .34576 .63016 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .3363 .62816 L .33636 .65067 L .707 .577 .707 r
F
.34758 .71757 m .35601 .78211 L p .35054 .72912 L F P
0 g
s
.34676 .69794 m .36077 .80524 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.34576 .63016 m .35843 .63496 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34576 .63016 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.35843 .63496 m .35544 .692 L .34516 .68811 L p .707 .577 .707 r
F P
0 g
s
.34422 .68235 m .35843 .63496 L .34516 .68811 L .707 .577 .707 r
F
.35054 .72912 m .34546 .68996 L .34444 .68365 L F
.36077 .80524 m .35113 .73139 L p .35054 .72912 L F P
0 g
s
.36526 .75804 m .35601 .78211 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.30772 .31745 m .33608 .53463 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.36143 .6396 m .35916 .68297 L p .35544 .692 L .707 .577 .707 r
F P
0 g
s
.35686 .6942 m .35544 .692 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35544 .692 m .35843 .63496 L .36143 .6396 L p .707 .577 .707 r
F P
0 g
s
.33608 .53463 m .36526 .75804 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33631 .63129 m .34758 .71757 L p .34484 .68665 L .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .33631 .63129 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33644 .68587 m .32166 .68274 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.67828 .76685 m .675 .80511 L .69106 .80494 L p .707 .577 .707 r
F P
0 g
s
.69106 .80494 m .69434 .76668 L .67828 .76685 L p .707 .577 .707 r
F P
0 g
s
.67386 .83767 m .67218 .85681 L .68822 .85684 L p .707 .577 .707 r
F P
0 g
s
.68822 .85684 m .6899 .8377 L .67386 .83767 L p .707 .577 .707 r
F P
0 g
s
.69747 .68047 m .69448 .73751 L .70145 .73346 L p .707 .577 .707 r
F P
0 g
s
.70145 .73346 m .70444 .67642 L .69747 .68047 L p .707 .577 .707 r
F P
0 g
s
.69434 .76668 m .69106 .80494 L .69783 .80378 L p .707 .577 .707 r
F P
0 g
s
.69783 .80378 m .70111 .76551 L .69434 .76668 L p .707 .577 .707 r
F P
0 g
s
.6899 .8377 m .68822 .85684 L .69497 .85587 L p .707 .577 .707 r
F P
0 g
s
.69497 .85587 m .69665 .83674 L .6899 .8377 L p .707 .577 .707 r
F P
0 g
s
.70444 .67642 m .70145 .73346 L .69845 .72881 L p .707 .577 .707 r
F P
0 g
s
.69845 .72881 m .70144 .67177 L .70444 .67642 L p .707 .577 .707 r
F P
0 g
s
.70111 .76551 m .69783 .80378 L .69465 .80173 L p .707 .577 .707 r
F P
0 g
s
.69465 .80173 m .69793 .76346 L .70111 .76551 L p .707 .577 .707 r
F P
0 g
s
.69665 .83674 m .69497 .85587 L .69177 .854 L p .707 .577 .707 r
F P
0 g
s
.69177 .854 m .69346 .83487 L .69665 .83674 L p .707 .577 .707 r
F P
0 g
s
.70144 .67177 m .69845 .72881 L .68578 .72402 L p .707 .577 .707 r
F P
0 g
s
.68578 .72402 m .68876 .66698 L .70144 .67177 L p .707 .577 .707 r
F P
0 g
s
.58006 .299 m .6376 .73959 L .61929 .71967 L p .707 .577 .707 r
F P
0 g
s
.61929 .71967 m .56175 .27909 L .58006 .299 L p .707 .577 .707 r
F P
0 g
s
.25019 .70458 m .25317 .64754 L .22202 .64495 L p .707 .577 .707 r
F P
0 g
s
.25317 .64754 m .25019 .70458 L .28197 .70579 L p .707 .577 .707 r
F P
0 g
s
.28197 .70579 m .28496 .64875 L .25317 .64754 L p .707 .577 .707 r
F P
0 g
s
.28496 .64875 m .28197 .70579 L .31127 .7055 L p .707 .577 .707 r
F P
0 g
s
.31127 .7055 m .31426 .64846 L .28496 .64875 L p .707 .577 .707 r
F P
0 g
s
.21903 .702 m .22202 .64495 L .19454 .64125 L p .707 .577 .707 r
F P
0 g
s
.22202 .64495 m .21903 .702 L .25019 .70458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69793 .76346 m .69465 .80173 L .68183 .799 L p .707 .577 .707 r
F P
0 g
s
.68183 .799 m .68511 .76073 L .69793 .76346 L p .707 .577 .707 r
F P
0 g
s
.19454 .64125 m .19156 .69829 L .21903 .702 L p .707 .577 .707 r
F P
0 g
s
.24737 .76315 m .25066 .72488 L .21953 .72184 L p .707 .577 .707 r
F P
0 g
s
.25066 .72488 m .24737 .76315 L .27906 .76568 L p .707 .577 .707 r
F P
0 g
s
.27906 .76568 m .28235 .72741 L .25066 .72488 L p .707 .577 .707 r
F P
0 g
s
.21953 .72184 m .21625 .76011 L .24737 .76315 L p .707 .577 .707 r
F P
0 g
s
.28235 .72741 m .27906 .76568 L .30822 .76745 L p .707 .577 .707 r
F P
0 g
s
.30822 .76745 m .3115 .72919 L .28235 .72741 L p .707 .577 .707 r
F P
0 g
s
.69346 .83487 m .69177 .854 L .67895 .85141 L p .707 .577 .707 r
F P
0 g
s
.67895 .85141 m .68063 .83228 L .69346 .83487 L p .707 .577 .707 r
F P
0 g
s
.21625 .76011 m .21953 .72184 L .19203 .71859 L p .707 .577 .707 r
F P
0 g
s
.19156 .69829 m .19454 .64125 L .17344 .63678 L p .707 .577 .707 r
F P
0 g
s
.24459 .81443 m .24627 .79529 L .21515 .79222 L p .707 .577 .707 r
F P
0 g
s
.24627 .79529 m .24459 .81443 L .27627 .81705 L p .707 .577 .707 r
F P
0 g
s
.27627 .81705 m .27796 .79792 L .24627 .79529 L p .707 .577 .707 r
F P
0 g
s
.68876 .66698 m .68578 .72402 L .66467 .71955 L p .707 .577 .707 r
F P
0 g
s
.66467 .71955 m .66766 .66251 L .68876 .66698 L p .707 .577 .707 r
F P
0 g
s
.19203 .71859 m .18874 .75685 L .21625 .76011 L p .707 .577 .707 r
F P
0 g
s
.21515 .79222 m .21347 .81136 L .24459 .81443 L p .707 .577 .707 r
F P
0 g
s
.36526 .75804 m .30772 .31745 L .33008 .29478 L p .707 .577 .707 r
F P
0 g
s
.27796 .79792 m .27627 .81705 L .30542 .81897 L p .707 .577 .707 r
F P
0 g
s
.30542 .81897 m .3071 .79983 L .27796 .79792 L p .707 .577 .707 r
F P
0 g
s
.21347 .81136 m .21515 .79222 L .18764 .789 L p .707 .577 .707 r
F P
0 g
s
.17344 .63678 m .17045 .69382 L .19156 .69829 L p .707 .577 .707 r
F P
0 g
s
.18764 .789 m .18596 .80814 L .21347 .81136 L p .707 .577 .707 r
F P
0 g
s
.3115 .72919 m .30822 .76745 L .33199 .7683 L p .707 .577 .707 r
F P
0 g
s
.33199 .7683 m .33527 .73003 L .3115 .72919 L p .707 .577 .707 r
F P
0 g
s
.56175 .27909 m .61929 .71967 L .58922 .70492 L p .707 .577 .707 r
F P
0 g
s
.58922 .70492 m .53168 .26434 L .56175 .27909 L p .707 .577 .707 r
F P
0 g
s
.18874 .75685 m .19203 .71859 L .17083 .71544 L p .707 .577 .707 r
F P
0 g
s
.3071 .79983 m .30542 .81897 L .32917 .81999 L p .707 .577 .707 r
F P
0 g
s
.32917 .81999 m .33086 .80086 L .3071 .79983 L p .707 .577 .707 r
F P
0 g
s
.17083 .71544 m .16754 .75371 L .18874 .75685 L p .707 .577 .707 r
F P
0 g
s
.68511 .76073 m .68183 .799 L .66063 .79585 L p .707 .577 .707 r
F P
0 g
s
.66063 .79585 m .66391 .75759 L .68511 .76073 L p .707 .577 .707 r
F P
0 g
s
.18596 .80814 m .18764 .789 L .16643 .78595 L p .707 .577 .707 r
F P
0 g
s
.17045 .69382 m .17344 .63678 L .16076 .63198 L p .707 .577 .707 r
F P
0 g
s
.16643 .78595 m .16475 .80508 L .18596 .80814 L p .707 .577 .707 r
F P
0 g
s
.66766 .66251 m .66467 .71955 L .63719 .71584 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .64018 .6588 L .66766 .66251 L p .707 .577 .707 r
F P
0 g
s
.68063 .83228 m .67895 .85141 L .65774 .84836 L p .707 .577 .707 r
F P
0 g
s
.65774 .84836 m .65942 .82922 L .68063 .83228 L p .707 .577 .707 r
F P
0 g
s
.54496 .71234 m .54794 .6553 L .57724 .65501 L p .707 .577 .707 r
F P
0 g
s
.16076 .63198 m .15777 .68903 L .17045 .69382 L p .707 .577 .707 r
F P
0 g
s
.33008 .29478 m .38762 .73537 L .36526 .75804 L p .707 .577 .707 r
F P
0 g
s
.38762 .73537 m .33008 .29478 L .36336 .27574 L p .707 .577 .707 r
F P
0 g
s
.33086 .80086 m .32917 .81999 L .34521 .82002 L p .707 .577 .707 r
F P
0 g
s
.34521 .82002 m .34689 .80089 L .33086 .80086 L p .707 .577 .707 r
F P
0 g
s
.16754 .75371 m .17083 .71544 L .15801 .71271 L p .707 .577 .707 r
F P
0 g
s
.53168 .26434 m .58922 .70492 L .55033 .69678 L p .707 .577 .707 r
F P
0 g
s
.55033 .69678 m .4928 .25619 L .53168 .26434 L p .707 .577 .707 r
F P
0 g
s
.15801 .71271 m .15473 .75098 L .16754 .75371 L p .707 .577 .707 r
F P
0 g
s
.66391 .75759 m .66063 .79585 L .63312 .7926 L p .707 .577 .707 r
F P
0 g
s
.16475 .80508 m .16643 .78595 L .15361 .78336 L p .707 .577 .707 r
F P
0 g
s
.15361 .78336 m .15192 .80249 L .16475 .80508 L p .707 .577 .707 r
F P
0 g
s
.65942 .82922 m .65774 .84836 L .63023 .84514 L p .707 .577 .707 r
F P
0 g
s
.63023 .84514 m .63191 .826 L .65942 .82922 L p .707 .577 .707 r
F P
0 g
s
.15777 .68903 m .16076 .63198 L .15776 .62733 L p .707 .577 .707 r
F P
0 g
s
.4209 .71633 m .36336 .27574 L .40431 .26219 L p .707 .577 .707 r
F P
0 g
s
.36336 .27574 m .4209 .71633 L .38762 .73537 L p .707 .577 .707 r
F P
0 g
s
.15776 .62733 m .15477 .68438 L .15777 .68903 L p .707 .577 .707 r
F P
0 g
s
.4928 .25619 m .55033 .69678 L .50644 .69604 L p .707 .577 .707 r
F P
0 g
s
.50644 .69604 m .44891 .25545 L .4928 .25619 L p .707 .577 .707 r
F P
0 g
s
.63191 .826 m .63023 .84514 L .59911 .84207 L p .707 .577 .707 r
F P
0 g
s
.59911 .84207 m .60079 .82293 L .63191 .826 L p .707 .577 .707 r
F P
0 g
s
.34689 .80089 m .34521 .82002 L .35196 .81906 L p .707 .577 .707 r
F P
0 g
s
.35196 .81906 m .35365 .79992 L .34689 .80089 L p .707 .577 .707 r
F P
0 g
s
.15473 .75098 m .15801 .71271 L .15483 .71067 L p .707 .577 .707 r
F P
0 g
s
.60079 .82293 m .59911 .84207 L .56742 .83944 L p .707 .577 .707 r
F P
0 g
s
.15483 .71067 m .15155 .74893 L .15473 .75098 L p .707 .577 .707 r
F P
0 g
s
.46184 .70278 m .40431 .26219 L .44891 .25545 L p .707 .577 .707 r
F P
0 g
s
.40431 .26219 m .46184 .70278 L .4209 .71633 L p .707 .577 .707 r
F P
0 g
s
.44891 .25545 m .50644 .69604 L .46184 .70278 L p .707 .577 .707 r
F P
0 g
s
.15192 .80249 m .15361 .78336 L .15041 .78149 L p .707 .577 .707 r
F P
0 g
s
.15041 .78149 m .14872 .80063 L .15192 .80249 L p .707 .577 .707 r
F P
0 g
s
.15477 .68438 m .15776 .62733 L .16473 .62329 L p .707 .577 .707 r
F P
0 g
s
.16473 .62329 m .16174 .68033 L .15477 .68438 L p .707 .577 .707 r
F P
0 g
s
.35365 .79992 m .35196 .81906 L .34877 .81719 L p .707 .577 .707 r
F P
0 g
s
.34877 .81719 m .35045 .79805 L .35365 .79992 L p .707 .577 .707 r
F P
0 g
s
.15155 .74893 m .15483 .71067 L .1616 .7095 L p .707 .577 .707 r
F P
0 g
s
.1616 .7095 m .15832 .74776 L .15155 .74893 L p .707 .577 .707 r
F P
0 g
s
.14872 .80063 m .15041 .78149 L .15716 .78052 L p .707 .577 .707 r
F P
0 g
s
.15716 .78052 m .15548 .79966 L .14872 .80063 L p .707 .577 .707 r
F P
0 g
s
.16174 .68033 m .16473 .62329 L .18098 .62024 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18098 .62024 m .178 .67728 L .16174 .68033 L p .707 .577 .707 r
F P
0 g
s
.35045 .79805 m .34877 .81719 L .33594 .8146 L p .707 .577 .707 r
F P
0 g
s
.33594 .8146 m .33762 .79546 L .35045 .79805 L p .707 .577 .707 r
F P
0 g
s
.15832 .74776 m .1616 .7095 L .17765 .70933 L p .707 .577 .707 r
F P
0 g
s
.17765 .70933 m .17437 .7476 L .15832 .74776 L p .707 .577 .707 r
F P
0 g
s
.15548 .79966 m .15716 .78052 L .1732 .78055 L p .707 .577 .707 r
F P
0 g
s
.1732 .78055 m .17151 .79969 L .15548 .79966 L p .707 .577 .707 r
F P
0 g
s
.178 .67728 m .18098 .62024 L .20493 .61848 L p .707 .577 .707 r
F P
0 g
s
.3421 .72392 m .33882 .76218 L .31762 .75904 L p .707 .577 .707 r
F P
0 g
s
.31762 .75904 m .3209 .72077 L .3421 .72392 L p .707 .577 .707 r
F P
0 g
s
.20493 .61848 m .20195 .67552 L .178 .67728 L p .707 .577 .707 r
F P
0 g
s
.32465 .62569 m .32166 .68274 L .29418 .67903 L p .707 .577 .707 r
F P
0 g
s
.29418 .67903 m .29717 .62198 L .32465 .62569 L p .707 .577 .707 r
F P
0 g
s
.33762 .79546 m .33594 .8146 L .31473 .81154 L p .707 .577 .707 r
F P
0 g
s
.31473 .81154 m .31641 .79241 L .33762 .79546 L p .707 .577 .707 r
F P
0 g
s
.17437 .7476 m .17765 .70933 L .20142 .71017 L p .707 .577 .707 r
F P
0 g
s
.20142 .71017 m .19814 .74844 L .17437 .7476 L p .707 .577 .707 r
F P
0 g
s
.20195 .67552 m .20493 .61848 L .23423 .61819 L p .707 .577 .707 r
F P
0 g
s
.17151 .79969 m .1732 .78055 L .19695 .78158 L p .707 .577 .707 r
F P
0 g
s
.19695 .78158 m .19527 .80071 L .17151 .79969 L p .707 .577 .707 r
F P
0 g
s
.23423 .61819 m .23125 .67524 L .20195 .67552 L p .707 .577 .707 r
F P
0 g
s
.29717 .62198 m .29418 .67903 L .26303 .67644 L p .707 .577 .707 r
F P
0 g
s
.26303 .67644 m .26602 .6194 L .29717 .62198 L p .707 .577 .707 r
F P
0 g
s
.3209 .72077 m .31762 .75904 L .29011 .75579 L p .707 .577 .707 r
F P
0 g
s
.29011 .75579 m .29339 .71752 L .3209 .72077 L p .707 .577 .707 r
F P
0 g
s
.7304 .64285 m .73339 .5858 L .70223 .58322 L p .707 .577 .707 r
F P
0 g
s
.73339 .5858 m .7304 .64285 L .76218 .64406 L p .707 .577 .707 r
F P
0 g
s
.76218 .64406 m .76517 .58701 L .73339 .5858 L p .707 .577 .707 r
F P
0 g
s
.23125 .67524 m .23423 .61819 L .26602 .6194 L p .707 .577 .707 r
F P
0 g
s
.76517 .58701 m .76218 .64406 L .79148 .64377 L p .707 .577 .707 r
F P
0 g
s
.79148 .64377 m .79447 .58672 L .76517 .58701 L p .707 .577 .707 r
F P
0 g
s
.26602 .6194 m .26303 .67644 L .23125 .67524 L p .707 .577 .707 r
F P
0 g
s
.19814 .74844 m .20142 .71017 L .23058 .71195 L p .707 .577 .707 r
F P
0 g
s
.69925 .64026 m .70223 .58322 L .67476 .57951 L p .707 .577 .707 r
F P
0 g
s
.70223 .58322 m .69925 .64026 L .7304 .64285 L p .707 .577 .707 r
F P
0 g
s
.31641 .79241 m .31473 .81154 L .28722 .80832 L p .707 .577 .707 r
F P
0 g
s
.28722 .80832 m .2889 .78919 L .31641 .79241 L p .707 .577 .707 r
F P
0 g
s
.23058 .71195 m .2273 .75021 L .19814 .74844 L p .707 .577 .707 r
F P
0 g
s
.72759 .69142 m .73087 .65315 L .69975 .65011 L p .707 .577 .707 r
F P
0 g
s
.73087 .65315 m .72759 .69142 L .75928 .69395 L p .707 .577 .707 r
F P
0 g
s
.75928 .69395 m .76256 .65568 L .73087 .65315 L p .707 .577 .707 r
F P
0 g
s
.19527 .80071 m .19695 .78158 L .2261 .78349 L p .707 .577 .707 r
F P
0 g
s
.69975 .65011 m .69646 .68838 L .72759 .69142 L p .707 .577 .707 r
F P
0 g
s
.67476 .57951 m .67177 .63656 L .69925 .64026 L p .707 .577 .707 r
F P
0 g
s
.2261 .78349 m .22441 .80263 L .19527 .80071 L p .707 .577 .707 r
F P
0 g
s
.76256 .65568 m .75928 .69395 L .78844 .69572 L p .707 .577 .707 r
F P
0 g
s
.78844 .69572 m .79172 .65746 L .76256 .65568 L p .707 .577 .707 r
F P
0 g
s
.29339 .71752 m .29011 .75579 L .25899 .75275 L p .707 .577 .707 r
F P
0 g
s
.25899 .75275 m .26227 .71448 L .29339 .71752 L p .707 .577 .707 r
F P
0 g
s
.79447 .58672 m .79148 .64377 L .81543 .64201 L p .707 .577 .707 r
F P
0 g
s
.81543 .64201 m .81842 .58497 L .79447 .58672 L p .707 .577 .707 r
F P
0 g
s
.7248 .72686 m .72649 .70772 L .69537 .70465 L p .707 .577 .707 r
F P
0 g
s
.72649 .70772 m .7248 .72686 L .75648 .72948 L p .707 .577 .707 r
F P
0 g
s
.75648 .72948 m .75817 .71035 L .72649 .70772 L p .707 .577 .707 r
F P
0 g
s
.69537 .70465 m .69368 .72379 L .7248 .72686 L p .707 .577 .707 r
F P
0 g
s
.69646 .68838 m .69975 .65011 L .67224 .64686 L p .707 .577 .707 r
F P
0 g
s
.2273 .75021 m .23058 .71195 L .26227 .71448 L p .707 .577 .707 r
F P
0 g
s
.75817 .71035 m .75648 .72948 L .78563 .7314 L p .707 .577 .707 r
F P
0 g
s
.78563 .7314 m .78731 .71226 L .75817 .71035 L p .707 .577 .707 r
F P
0 g
s
.67224 .64686 m .66896 .68513 L .69646 .68838 L p .707 .577 .707 r
F P
0 g
s
.26227 .71448 m .25899 .75275 L .2273 .75021 L p .707 .577 .707 r
F P
0 g
s
.67177 .63656 m .67476 .57951 L .65365 .57504 L p .707 .577 .707 r
F P
0 g
s
.69368 .72379 m .69537 .70465 L .66786 .70143 L p .707 .577 .707 r
F P
0 g
s
.66786 .70143 m .66617 .72057 L .69368 .72379 L p .707 .577 .707 r
F P
0 g
s
.2889 .78919 m .28722 .80832 L .2561 .80525 L p .707 .577 .707 r
F P
0 g
s
.2561 .80525 m .25778 .78612 L .2889 .78919 L p .707 .577 .707 r
F P
0 g
s
.22441 .80263 m .2261 .78349 L .25778 .78612 L p .707 .577 .707 r
F P
0 g
s
.25778 .78612 m .2561 .80525 L .22441 .80263 L p .707 .577 .707 r
F P
0 g
s
.79172 .65746 m .78844 .69572 L .81221 .69657 L p .707 .577 .707 r
F P
0 g
s
.81221 .69657 m .81549 .6583 L .79172 .65746 L p .707 .577 .707 r
F P
0 g
s
.65365 .57504 m .65066 .63209 L .67177 .63656 L p .707 .577 .707 r
F P
0 g
s
.78731 .71226 m .78563 .7314 L .80938 .73242 L p .707 .577 .707 r
F P
0 g
s
.80938 .73242 m .81107 .71329 L .78731 .71226 L p .707 .577 .707 r
F P
0 g
s
.66896 .68513 m .67224 .64686 L .65104 .64371 L p .707 .577 .707 r
F P
0 g
s
.65104 .64371 m .64776 .68198 L .66896 .68513 L p .707 .577 .707 r
F P
0 g
s
.81842 .58497 m .81543 .64201 L .83169 .63896 L p .707 .577 .707 r
F P
0 g
s
.83169 .63896 m .83467 .58192 L .81842 .58497 L p .707 .577 .707 r
F P
0 g
s
.66617 .72057 m .66786 .70143 L .64665 .69838 L p .707 .577 .707 r
F P
0 g
s
.64665 .69838 m .64496 .71751 L .66617 .72057 L p .707 .577 .707 r
F P
0 g
s
.65066 .63209 m .65365 .57504 L .64097 .57025 L p .707 .577 .707 r
F P
0 g
s
.81549 .6583 m .81221 .69657 L .82826 .6964 L p .707 .577 .707 r
F P
0 g
s
.82826 .6964 m .83154 .65813 L .81549 .6583 L p .707 .577 .707 r
F P
0 g
s
.81107 .71329 m .80938 .73242 L .82542 .73245 L p .707 .577 .707 r
F P
0 g
s
.82542 .73245 m .82711 .71332 L .81107 .71329 L p .707 .577 .707 r
F P
0 g
s
.64097 .57025 m .63799 .62729 L .65066 .63209 L p .707 .577 .707 r
F P
0 g
s
.64776 .68198 m .65104 .64371 L .63822 .64098 L p .707 .577 .707 r
F P
0 g
s
.63822 .64098 m .63494 .67925 L .64776 .68198 L p .707 .577 .707 r
F P
0 g
s
.64496 .71751 m .64665 .69838 L .63382 .69579 L p .707 .577 .707 r
F P
0 g
s
.63382 .69579 m .63213 .71492 L .64496 .71751 L p .707 .577 .707 r
F P
0 g
s
.83467 .58192 m .83169 .63896 L .83866 .63491 L p .707 .577 .707 r
F P
0 g
s
.83866 .63491 m .84164 .57787 L .83467 .58192 L p .707 .577 .707 r
F P
0 g
s
.63799 .62729 m .64097 .57025 L .63797 .5656 L p .707 .577 .707 r
F P
0 g
s
.83154 .65813 m .82826 .6964 L .83503 .69523 L p .707 .577 .707 r
F P
0 g
s
.83503 .69523 m .83831 .65697 L .83154 .65813 L p .707 .577 .707 r
F P
0 g
s
.82711 .71332 m .82542 .73245 L .83217 .73148 L p .707 .577 .707 r
F P
0 g
s
.83217 .73148 m .83386 .71235 L .82711 .71332 L p .707 .577 .707 r
F P
0 g
s
.63797 .5656 m .63499 .62264 L .63799 .62729 L p .707 .577 .707 r
F P
0 g
s
.63494 .67925 m .63822 .64098 L .63504 .63894 L p .707 .577 .707 r
F P
0 g
s
.63504 .63894 m .63176 .6772 L .63494 .67925 L p .707 .577 .707 r
F P
0 g
s
.63213 .71492 m .63382 .69579 L .63062 .69392 L p .707 .577 .707 r
F P
0 g
s
.63062 .69392 m .62894 .71305 L .63213 .71492 L p .707 .577 .707 r
F P
0 g
s
.84164 .57787 m .83866 .63491 L .83566 .63026 L p .707 .577 .707 r
F P
0 g
s
.83566 .63026 m .83864 .57322 L .84164 .57787 L p .707 .577 .707 r
F P
0 g
s
.63499 .62264 m .63797 .5656 L .64494 .56155 L p .707 .577 .707 r
F P
0 g
s
.83831 .65697 m .83503 .69523 L .83185 .69318 L p .707 .577 .707 r
F P
0 g
s
.83185 .69318 m .83513 .65492 L .83831 .65697 L p .707 .577 .707 r
F P
0 g
s
.83386 .71235 m .83217 .73148 L .82898 .72962 L p .707 .577 .707 r
F P
0 g
s
.82898 .72962 m .83066 .71048 L .83386 .71235 L p .707 .577 .707 r
F P
0 g
s
.64494 .56155 m .64196 .6186 L .63499 .62264 L p .707 .577 .707 r
F P
0 g
s
.63176 .6772 m .63504 .63894 L .64181 .63777 L p .707 .577 .707 r
F P
0 g
s
.64181 .63777 m .63853 .67603 L .63176 .6772 L p .707 .577 .707 r
F P
0 g
s
.62894 .71305 m .63062 .69392 L .63738 .69295 L p .707 .577 .707 r
F P
0 g
s
.63738 .69295 m .63569 .71209 L .62894 .71305 L p .707 .577 .707 r
F P
0 g
s
.83864 .57322 m .83566 .63026 L .82298 .62547 L p .707 .577 .707 r
F P
0 g
s
.82298 .62547 m .82597 .56843 L .83864 .57322 L p .707 .577 .707 r
F P
0 g
s
.38739 .60603 m .39038 .54899 L .35922 .5464 L p .707 .577 .707 r
F P
0 g
s
.39038 .54899 m .38739 .60603 L .41917 .60724 L p .707 .577 .707 r
F P
0 g
s
.41917 .60724 m .42216 .5502 L .39038 .54899 L p .707 .577 .707 r
F P
0 g
s
.42216 .5502 m .41917 .60724 L .44847 .60695 L p .707 .577 .707 r
F P
0 g
s
.44847 .60695 m .45146 .54991 L .42216 .5502 L p .707 .577 .707 r
F P
0 g
s
.64196 .6186 m .64494 .56155 L .6612 .5585 L p .707 .577 .707 r
F P
0 g
s
.35624 .60345 m .35922 .5464 L .33175 .5427 L p .707 .577 .707 r
F P
0 g
s
.35922 .5464 m .35624 .60345 L .38739 .60603 L p .707 .577 .707 r
F P
0 g
s
.83513 .65492 m .83185 .69318 L .81903 .69045 L p .707 .577 .707 r
F P
0 g
s
.81903 .69045 m .82232 .65219 L .83513 .65492 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83066 .71048 m .82898 .72962 L .81615 .72703 L p .707 .577 .707 r
F P
0 g
s
.81615 .72703 m .81784 .70789 L .83066 .71048 L p .707 .577 .707 r
F P
0 g
s
.38458 .6546 m .38786 .61634 L .35674 .6133 L p .707 .577 .707 r
F P
0 g
s
.38786 .61634 m .38458 .6546 L .41627 .65713 L p .707 .577 .707 r
F P
0 g
s
.41627 .65713 m .41955 .61887 L .38786 .61634 L p .707 .577 .707 r
F P
0 g
s
.6612 .5585 m .65821 .61555 L .64196 .6186 L p .707 .577 .707 r
F P
0 g
s
.35674 .6133 m .35345 .65156 L .38458 .6546 L p .707 .577 .707 r
F P
0 g
s
.33175 .5427 m .32876 .59974 L .35624 .60345 L p .707 .577 .707 r
F P
0 g
s
.41955 .61887 m .41627 .65713 L .44543 .65891 L p .707 .577 .707 r
F P
0 g
s
.44543 .65891 m .44871 .62064 L .41955 .61887 L p .707 .577 .707 r
F P
0 g
s
.45146 .54991 m .44847 .60695 L .47242 .6052 L p .707 .577 .707 r
F P
0 g
s
.47242 .6052 m .47541 .54815 L .45146 .54991 L p .707 .577 .707 r
F P
0 g
s
.38179 .69004 m .38348 .67091 L .35236 .66784 L p .707 .577 .707 r
F P
0 g
s
.38348 .67091 m .38179 .69004 L .41347 .69267 L p .707 .577 .707 r
F P
0 g
s
.41347 .69267 m .41516 .67353 L .38348 .67091 L p .707 .577 .707 r
F P
0 g
s
.35236 .66784 m .35067 .68697 L .38179 .69004 L p .707 .577 .707 r
F P
0 g
s
.63853 .67603 m .64181 .63777 L .65787 .6376 L p .707 .577 .707 r
F P
0 g
s
.35345 .65156 m .35674 .6133 L .32923 .61004 L p .707 .577 .707 r
F P
0 g
s
.41516 .67353 m .41347 .69267 L .44262 .69458 L p .707 .577 .707 r
F P
0 g
s
.44262 .69458 m .4443 .67545 L .41516 .67353 L p .707 .577 .707 r
F P
0 g
s
.65787 .6376 m .65458 .67587 L .63853 .67603 L p .707 .577 .707 r
F P
0 g
s
.32923 .61004 m .32595 .64831 L .35345 .65156 L p .707 .577 .707 r
F P
0 g
s
.63569 .71209 m .63738 .69295 L .65341 .69298 L p .707 .577 .707 r
F P
0 g
s
.32876 .59974 m .33175 .5427 L .31064 .53823 L p .707 .577 .707 r
F P
0 g
s
.35067 .68697 m .35236 .66784 L .32485 .66462 L p .707 .577 .707 r
F P
0 g
s
.65341 .69298 m .65173 .71212 L .63569 .71209 L p .707 .577 .707 r
F P
0 g
s
.32485 .66462 m .32316 .68375 L .35067 .68697 L p .707 .577 .707 r
F P
0 g
s
.82597 .56843 m .82298 .62547 L .80187 .621 L p .707 .577 .707 r
F P
0 g
s
.80187 .621 m .80486 .56396 L .82597 .56843 L p .707 .577 .707 r
F P
0 g
s
.44871 .62064 m .44543 .65891 L .4692 .65975 L p .707 .577 .707 r
F P
0 g
s
.4692 .65975 m .47248 .62149 L .44871 .62064 L p .707 .577 .707 r
F P
0 g
s
.31064 .53823 m .30765 .59527 L .32876 .59974 L p .707 .577 .707 r
F P
0 g
s
.4443 .67545 m .44262 .69458 L .46637 .69561 L p .707 .577 .707 r
F P
0 g
s
.46637 .69561 m .46806 .67647 L .4443 .67545 L p .707 .577 .707 r
F P
0 g
s
.65821 .61555 m .6612 .5585 L .68515 .55675 L p .707 .577 .707 r
F P
0 g
s
.32595 .64831 m .32923 .61004 L .30803 .6069 L p .707 .577 .707 r
F P
0 g
s
.30803 .6069 m .30475 .64516 L .32595 .64831 L p .707 .577 .707 r
F P
0 g
s
.47541 .54815 m .47242 .6052 L .48868 .60214 L p .707 .577 .707 r
F P
0 g
s
.48868 .60214 m .49166 .5451 L .47541 .54815 L p .707 .577 .707 r
F P
0 g
s
.82232 .65219 m .81903 .69045 L .79783 .68731 L p .707 .577 .707 r
F P
0 g
s
.79783 .68731 m .80112 .64904 L .82232 .65219 L p .707 .577 .707 r
F P
0 g
s
.32316 .68375 m .32485 .66462 L .30364 .66156 L p .707 .577 .707 r
F P
0 g
s
.30364 .66156 m .30195 .6807 L .32316 .68375 L p .707 .577 .707 r
F P
0 g
s
.68515 .55675 m .68216 .61379 L .65821 .61555 L p .707 .577 .707 r
F P
0 g
s
.81784 .70789 m .81615 .72703 L .79494 .72397 L p .707 .577 .707 r
F P
0 g
s
.79494 .72397 m .79663 .70484 L .81784 .70789 L p .707 .577 .707 r
F P
0 g
s
.65458 .67587 m .65787 .6376 L .68164 .63844 L p .707 .577 .707 r
F P
0 g
s
.30765 .59527 m .31064 .53823 L .29796 .53343 L p .707 .577 .707 r
F P
0 g
s
.80486 .56396 m .80187 .621 L .7744 .61729 L p .707 .577 .707 r
F P
0 g
s
.7744 .61729 m .77738 .56025 L .80486 .56396 L p .707 .577 .707 r
F P
0 g
s
.68164 .63844 m .67835 .67671 L .65458 .67587 L p .707 .577 .707 r
F P
0 g
s
.47248 .62149 m .4692 .65975 L .48525 .65958 L p .707 .577 .707 r
F P
0 g
s
.48525 .65958 m .48853 .62132 L .47248 .62149 L p .707 .577 .707 r
F P
0 g
s
.65173 .71212 m .65341 .69298 L .67717 .69401 L p .707 .577 .707 r
F P
0 g
s
.67717 .69401 m .67548 .71314 L .65173 .71212 L p .707 .577 .707 r
F P
0 g
s
.46806 .67647 m .46637 .69561 L .48241 .69564 L p .707 .577 .707 r
F P
0 g
s
.48241 .69564 m .4841 .6765 L .46806 .67647 L p .707 .577 .707 r
F P
0 g
s
.68216 .61379 m .68515 .55675 L .71445 .55646 L p .707 .577 .707 r
F P
0 g
s
.29796 .53343 m .29498 .59048 L .30765 .59527 L p .707 .577 .707 r
F P
0 g
s
.30475 .64516 m .30803 .6069 L .29521 .60417 L p .707 .577 .707 r
F P
0 g
s
.29521 .60417 m .29193 .64243 L .30475 .64516 L p .707 .577 .707 r
F P
0 g
s
.80112 .64904 m .79783 .68731 L .77033 .68406 L p .707 .577 .707 r
F P
0 g
s
.77033 .68406 m .77361 .64579 L .80112 .64904 L p .707 .577 .707 r
F P
0 g
s
.71445 .55646 m .71146 .6135 L .68216 .61379 L p .707 .577 .707 r
F P
0 g
s
.30195 .6807 m .30364 .66156 L .29081 .65897 L p .707 .577 .707 r
F P
0 g
s
.77738 .56025 m .7744 .61729 L .74324 .61471 L p .707 .577 .707 r
F P
0 g
s
.74324 .61471 m .74623 .55767 L .77738 .56025 L p .707 .577 .707 r
F P
0 g
s
.29081 .65897 m .28912 .67811 L .30195 .6807 L p .707 .577 .707 r
F P
0 g
s
.49166 .5451 m .48868 .60214 L .49565 .5981 L p .707 .577 .707 r
F P
0 g
s
.49565 .5981 m .49863 .54105 L .49166 .5451 L p .707 .577 .707 r
F P
0 g
s
.79663 .70484 m .79494 .72397 L .76743 .72075 L p .707 .577 .707 r
F P
0 g
s
.76743 .72075 m .76912 .70162 L .79663 .70484 L p .707 .577 .707 r
F P
0 g
s
.71146 .6135 m .71445 .55646 L .74623 .55767 L p .707 .577 .707 r
F P
0 g
s
.67835 .67671 m .68164 .63844 L .71079 .64022 L p .707 .577 .707 r
F P
0 g
s
.71079 .64022 m .70751 .67848 L .67835 .67671 L p .707 .577 .707 r
F P
0 g
s
.74623 .55767 m .74324 .61471 L .71146 .6135 L p .707 .577 .707 r
F P
0 g
s
.67548 .71314 m .67717 .69401 L .70631 .69592 L p .707 .577 .707 r
F P
0 g
s
.70631 .69592 m .70463 .71506 L .67548 .71314 L p .707 .577 .707 r
F P
0 g
s
.29498 .59048 m .29796 .53343 L .29496 .52878 L p .707 .577 .707 r
F P
0 g
s
.77361 .64579 m .77033 .68406 L .7392 .68102 L p .707 .577 .707 r
F P
0 g
s
.7392 .68102 m .74249 .64275 L .77361 .64579 L p .707 .577 .707 r
F P
0 g
s
.48853 .62132 m .48525 .65958 L .49202 .65842 L p .707 .577 .707 r
F P
0 g
s
.49202 .65842 m .4953 .62015 L .48853 .62132 L p .707 .577 .707 r
F P
0 g
s
.70751 .67848 m .71079 .64022 L .74249 .64275 L p .707 .577 .707 r
F P
0 g
s
.76912 .70162 m .76743 .72075 L .73631 .71768 L p .707 .577 .707 r
F P
0 g
s
.73631 .71768 m .738 .69855 L .76912 .70162 L p .707 .577 .707 r
F P
0 g
s
.4841 .6765 m .48241 .69564 L .48916 .69467 L p .707 .577 .707 r
F P
0 g
s
.48916 .69467 m .49085 .67553 L .4841 .6765 L p .707 .577 .707 r
F P
0 g
s
.74249 .64275 m .7392 .68102 L .70751 .67848 L p .707 .577 .707 r
F P
0 g
s
.29496 .52878 m .29198 .58583 L .29498 .59048 L p .707 .577 .707 r
F P
0 g
s
.70463 .71506 m .70631 .69592 L .738 .69855 L p .707 .577 .707 r
F P
0 g
s
.738 .69855 m .73631 .71768 L .70463 .71506 L p .707 .577 .707 r
F P
0 g
s
.29193 .64243 m .29521 .60417 L .29203 .60212 L p .707 .577 .707 r
F P
0 g
s
.29203 .60212 m .28875 .64039 L .29193 .64243 L p .707 .577 .707 r
F P
0 g
s
.28912 .67811 m .29081 .65897 L .28761 .6571 L p .707 .577 .707 r
F P
0 g
s
.28761 .6571 m .28593 .67624 L .28912 .67811 L p .707 .577 .707 r
F P
0 g
s
.49863 .54105 m .49565 .5981 L .49265 .59345 L p .707 .577 .707 r
F P
0 g
s
.49265 .59345 m .49563 .53641 L .49863 .54105 L p .707 .577 .707 r
F P
0 g
s
.29198 .58583 m .29496 .52878 L .30193 .52474 L p .707 .577 .707 r
F P
0 g
s
.4953 .62015 m .49202 .65842 L .48884 .65637 L p .707 .577 .707 r
F P
0 g
s
.48884 .65637 m .49212 .6181 L .4953 .62015 L p .707 .577 .707 r
F P
0 g
s
.49085 .67553 m .48916 .69467 L .48597 .6928 L p .707 .577 .707 r
F P
0 g
s
.48597 .6928 m .48765 .67367 L .49085 .67553 L p .707 .577 .707 r
F P
0 g
s
.30193 .52474 m .29894 .58178 L .29198 .58583 L p .707 .577 .707 r
F P
0 g
s
.28875 .64039 m .29203 .60212 L .2988 .60095 L p .707 .577 .707 r
F P
0 g
s
.2988 .60095 m .29552 .63922 L .28875 .64039 L p .707 .577 .707 r
F P
0 g
s
.28593 .67624 m .28761 .6571 L .29436 .65614 L p .707 .577 .707 r
F P
0 g
s
.29436 .65614 m .29268 .67527 L .28593 .67624 L p .707 .577 .707 r
F P
0 g
s
.49563 .53641 m .49265 .59345 L .47997 .58866 L p .707 .577 .707 r
F P
0 g
s
.47997 .58866 m .48296 .53161 L .49563 .53641 L p .707 .577 .707 r
F P
0 g
s
.29894 .58178 m .30193 .52474 L .31819 .52169 L p .707 .577 .707 r
F P
0 g
s
.49212 .6181 m .48884 .65637 L .47602 .65364 L p .707 .577 .707 r
F P
0 g
s
.47602 .65364 m .47931 .61537 L .49212 .6181 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48765 .67367 m .48597 .6928 L .47314 .69021 L p .707 .577 .707 r
F P
0 g
s
.47314 .69021 m .47483 .67108 L .48765 .67367 L p .707 .577 .707 r
F P
0 g
s
.31819 .52169 m .3152 .57873 L .29894 .58178 L p .707 .577 .707 r
F P
0 g
s
.29552 .63922 m .2988 .60095 L .31486 .60078 L p .707 .577 .707 r
F P
0 g
s
.31486 .60078 m .31157 .63905 L .29552 .63922 L p .707 .577 .707 r
F P
0 g
s
.29268 .67527 m .29436 .65614 L .3104 .65617 L p .707 .577 .707 r
F P
0 g
s
.3104 .65617 m .30872 .6753 L .29268 .67527 L p .707 .577 .707 r
F P
0 g
s
.48296 .53161 m .47997 .58866 L .45886 .58419 L p .707 .577 .707 r
F P
0 g
s
.45886 .58419 m .46185 .52714 L .48296 .53161 L p .707 .577 .707 r
F P
0 g
s
.3152 .57873 m .31819 .52169 L .34214 .51993 L p .707 .577 .707 r
F P
0 g
s
.47931 .61537 m .47602 .65364 L .45482 .65049 L p .707 .577 .707 r
F P
0 g
s
.45482 .65049 m .45811 .61223 L .47931 .61537 L p .707 .577 .707 r
F P
0 g
s
.34214 .51993 m .33915 .57697 L .3152 .57873 L p .707 .577 .707 r
F P
0 g
s
.47483 .67108 m .47314 .69021 L .45193 .68716 L p .707 .577 .707 r
F P
0 g
s
.45193 .68716 m .45362 .66802 L .47483 .67108 L p .707 .577 .707 r
F P
0 g
s
.31157 .63905 m .31486 .60078 L .33863 .60163 L p .707 .577 .707 r
F P
0 g
s
.46185 .52714 m .45886 .58419 L .43139 .58048 L p .707 .577 .707 r
F P
0 g
s
.43139 .58048 m .43437 .52343 L .46185 .52714 L p .707 .577 .707 r
F P
0 g
s
.33863 .60163 m .33534 .63989 L .31157 .63905 L p .707 .577 .707 r
F P
0 g
s
.30872 .6753 m .3104 .65617 L .33416 .65719 L p .707 .577 .707 r
F P
0 g
s
.33416 .65719 m .33247 .67633 L .30872 .6753 L p .707 .577 .707 r
F P
0 g
s
.33915 .57697 m .34214 .51993 L .37144 .51964 L p .707 .577 .707 r
F P
0 g
s
.45811 .61223 m .45482 .65049 L .42732 .64724 L p .707 .577 .707 r
F P
0 g
s
.42732 .64724 m .4306 .60898 L .45811 .61223 L p .707 .577 .707 r
F P
0 g
s
.37144 .51964 m .36845 .57669 L .33915 .57697 L p .707 .577 .707 r
F P
0 g
s
.43437 .52343 m .43139 .58048 L .40023 .57789 L p .707 .577 .707 r
F P
0 g
s
.40023 .57789 m .40322 .52085 L .43437 .52343 L p .707 .577 .707 r
F P
0 g
s
.45362 .66802 m .45193 .68716 L .42442 .68394 L p .707 .577 .707 r
F P
0 g
s
.42442 .68394 m .42611 .6648 L .45362 .66802 L p .707 .577 .707 r
F P
0 g
s
.36845 .57669 m .37144 .51964 L .40322 .52085 L p .707 .577 .707 r
F P
0 g
s
.33534 .63989 m .33863 .60163 L .36778 .6034 L p .707 .577 .707 r
F P
0 g
s
.36778 .6034 m .3645 .64167 L .33534 .63989 L p .707 .577 .707 r
F P
0 g
s
.40322 .52085 m .40023 .57789 L .36845 .57669 L p .707 .577 .707 r
F P
0 g
s
.33247 .67633 m .33416 .65719 L .3633 .65911 L p .707 .577 .707 r
F P
0 g
s
.3633 .65911 m .36162 .67824 L .33247 .67633 L p .707 .577 .707 r
F P
0 g
s
.4306 .60898 m .42732 .64724 L .39619 .6442 L p .707 .577 .707 r
F P
0 g
s
.39619 .6442 m .39948 .60593 L .4306 .60898 L p .707 .577 .707 r
F P
0 g
s
.3645 .64167 m .36778 .6034 L .39948 .60593 L p .707 .577 .707 r
F P
0 g
s
.42611 .6648 m .42442 .68394 L .3933 .68087 L p .707 .577 .707 r
F P
0 g
s
.3933 .68087 m .39499 .66173 L .42611 .6648 L p .707 .577 .707 r
F P
0 g
s
.39948 .60593 m .39619 .6442 L .3645 .64167 L p .707 .577 .707 r
F P
0 g
s
.36162 .67824 m .3633 .65911 L .39499 .66173 L p .707 .577 .707 r
F P
0 g
s
.39499 .66173 m .3933 .68087 L .36162 .67824 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00O7oo4P00Sgoo001fOol60003FUH00`00FUIJEP0<FUH4002;
Ool0075oo`D000UJEP03001JEUYF011JEP@008Moo`00KWoo0`0000=JEP00FUH02eYF00<005YFFUH0
55YF0P00QGoo001/Ool20004FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20023
Ool006Uoo`<000IJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP80085oo`00Igoo
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH035YF0P00Ogoo001UOol3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001mOol006=oo`80
009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001oogoo07Yoo`00HGoo0P0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<007ooOol0NGoo001OOol20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomoo`1i
Ool005eoo`8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0007Yoo`00G7oo0P002UYF00<005YFFUH025YF00<005YFFUH02eYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH007Uoo`00Fgoo00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0007Qoo`00FWoo00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEWQoo`00FWoo
00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo07Eoo`00FGoo00<005YFFUH00UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0MGoo001HOol00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00Oomoo`1eOol005Moo`03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP8007Ioo`00Egoo00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00
EWoo0P001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00EWoo0P001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUIJEP8007Ioo`00EGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001f
Ool005Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1dOol005Ao
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007Eoo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2
001eOol005Eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001EOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Eoo`00EGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP04001JEUYFFUH2001eOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2001dOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00M7oo001EOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Aoo`00
EGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001dOol005Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00M7oo001FOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8007Aoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2001dOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
Oomoo`1bOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001cOol0
05Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Lgoo001FOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00EWoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001cOol005Moo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Lgoo001GOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00
Egoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001cOol005Moo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1aOol005Moo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo001GOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP80079oo`00Egoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH2001bOol005Moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo
001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80079oo`00F7oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH2001bOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000LWoo001HOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80075oo`00F7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001aOol005Qo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LGoo001IOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP80075oo`00FGoo00@005YFFUH000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH2001aOol005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00L7oo
001IOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80071oo`00FGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool005Uoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00L7oo001JOol01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP80071oo`00FWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool0
05Yoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000L7oo001JOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00FWoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001_Ool005Yoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Kgoo001KOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00
Fgoo00<005YFFUH040000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00F7oo1P000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF4@002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0KGoo001EOol30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00D005YFFUIJEP0006moo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006ioo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000UJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0K7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020009FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01@00FUIJEUYF0000KWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020009
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00002goo7P00AGoo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH8000m
Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P001Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEPL003Ioo`00Dgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04000bOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo001COol20002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`D000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0017oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005Ioo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00E7oo3@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00Oomoogoo001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP8002eoo`00Dgoo0P0015YF00@005YFFUIJEQ000003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000aJEP03001JEUYF00MJEP03001JEUYF00IJ
EP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eo
o`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF70000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP80009oo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo00<005YF000020001eYF00<005YF
FUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00<Goo1P00
0eYF00<005YFFUH01EYF00<005YFFUH00UYF300000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo0080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00=JEP8002ioo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
0003FUH0000002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<0
05YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH00008Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000h000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo
4`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000Aoo`00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ400003FUH0
05YF00IJEP04001JEUYFFUH6000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH2000017oo001JEP000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPd003Uoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF3`000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=goo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000EJEP00001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001oo`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP05000bOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEQ<000EJEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02@00FUIJEUYF001oo`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00003000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000UJ
EP03001JEUYF009JEQ80009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000<FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF3P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo
000/Ool20002FUHO0002FUHJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF6`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002mo
o`00;7oo1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2@000eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<005YF0000100000=JEP0000001P0015YF
00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00001EYF1`000eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP/000AJEP03001J
EP0000@0009JEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2000_Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF014000AJEP03001JEUYF00=JEPD0009JEP8000=JEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
15YF00@005YFFUIJEP800003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009J
EP8002moo`00;goo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00<000AJEP03
001JEUYF01<00003FUH0000000L000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUHJ
0006Ool@0003FUH01000FUIJEUYF1000;goo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH03UYF1P001UYF0P0000=JEP0000001`0025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000=Ool:000`Ool0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH5000<FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003moo`00@goo80000UYF00<005YFFUH01EYF
00<005YFFUH03eYF0`0015YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH025YF10001UYF
00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`00>7oo000]Ool@000UOol01000FUIJEP001eYF00<005YFFUH035YF0`00
1eYF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH035YF0P001EYF00D005YF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D003=oo`00;7oo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT001aoo`04001J
EUYF0007FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP0:FUH01000FUIJEUYF2`001eYF00@005YF
000000=JEP03001JEP00014000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000<002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@004goo00@005YFFUH000MJEP03001JEUYF00MJEP800003FUH005YF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF001JEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00@005YFFUIJEP8002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF3`0017oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP8000]JEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEPd0
00AJEP03001JEUYF00EJEQ4000=JEP03001JEUYF00=JEP03001JEUYF009JEP8002moo`00;7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P00
0eYF00<005YFFUH00eYF2`0015YF00<005YF000010000UYF00<005YFFUH015YF1P000eYF00@005YF
FUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF0P001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP0000000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000Woo2`000UYF00<005YF
FUH01EYF00<005YFFUH00UYF1@000UYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUH00006FUH20002FUH01@00FUIJEUYF00001UYF00<005YFFUH0
0UYF0`002Goo4P000eYF00<005YFFUH01000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF00006goo2P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP05FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP04001FOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001J
EUYF00AJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00@005YFFUIJEPH005Yoo`00:goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEUYFFUH0000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIoo`04
FUH01000FUIJEUYF2000H7oo000[OolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH2000;FUH2000;FUH00`00FUIJEP07FUH00`00OomJEP04FUH01000FUIJEP00Igoo000/Ool20000
0eYF001JEP04FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00gooFUH00009FUH00`00FUIJEP09FUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP02001VOol002ioo`@000=JEP03
001JEUYF00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP8000EJEP04001JEUYFFUH4001SOol0039oo`L000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03001JEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH5001NOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPD00003FUH00000009JEP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05001IOol0049ooa4000AJEP03001JEUYF00AJEP04001JEUYFFUH300001EYF
001JEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEP00
00<005Eoo`00Dgoo4P0000EJEP00FUIJEP0000IJEP03Ool005YF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol004Qoo`<001Uoo`<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol004Moo`D001Uoo`80009J
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001J
EUYF00MJEP03001JEUYF00AJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`T0
019oo`D001Uoo`03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00UJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP04001JEUYFFUH2001E
Ool002Yoo`<000AJEP04001JEUYFFUH@0002Ool5000IOol00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005Eoo`00:Woo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo00<005YFFUH00UYF00<005YF
FUH015YF00=oo`00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00
:Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF20003goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPH000Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03
001JEUYF009JEPH000AJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol002Yoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00P0009oo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF
0P00EWoo000ZOolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YF
FUH00UYF2@00EWoo000[Ool60003FUH00`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH02UYF00=oo`00FUH025YF00<005YFFUH02EYF00<005YF
FUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF6000EWoo000aOol70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<007ooOol0
K7oo000hOol90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P000goo
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF1000Kgoo0011Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
0003Ool01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH03eYF1@00Kgoo001:Ool@0003FUH01000FUIJEUYF100017oo00<005YF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF1@00Kgoo001J
Ool:0006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08001^Ool006]oo`80015JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP<000=JEP03001JEUYF009JEPP006Ioo`00KGoo0P001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEPL005mo
o`00Kgoo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH01EYF
0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00FWoo001aOol200000eYF001J
EP0EFUH00`00FUIJEP0:FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001FOol007=oo`<000UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEP0000/000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol007Ioo`@000EJEP03001JEUYF00UJEP03001JEUYF00MJEPD000AJEP03
001JEUYF00EJEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8005Ioo`00
NWoo100000=JEP00FUH02UYF00@005YFFUIJEP/000AJEP03001JEUYF00IJEP03001JEUYF00EJEPP0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2001GOol007iooa4000]oo`T000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000=JEP04001JEUYFFUH2001GOol00:=ooa4000AJEP03001JEUYF009JEPT0
05Moo`00]7oo4P00Egoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49193 .84878 m .43439 .4082 L .3905 .40746 L p .707 .577 .707 r
F P
0 g
s
.55648 .84817 m .55816 .82904 L .53065 .82582 L p .707 .577 .707 r
F P
0 g
s
.53065 .82582 m .52897 .84495 L .55648 .84817 L p .707 .577 .707 r
F P
0 g
s
.53175 .79367 m .53503 .7554 L .51383 .75226 L p .707 .577 .707 r
F P
0 g
s
.51383 .75226 m .51055 .79052 L .53175 .79367 L p .707 .577 .707 r
F P
0 g
s
.52897 .84495 m .53065 .82582 L .50944 .82276 L p .707 .577 .707 r
F P
0 g
s
.50944 .82276 m .50776 .8419 L .52897 .84495 L p .707 .577 .707 r
F P
0 g
s
.50377 .6688 m .50078 .72584 L .51346 .73063 L p .707 .577 .707 r
F P
0 g
s
.51055 .79052 m .51383 .75226 L .50102 .74953 L p .707 .577 .707 r
F P
0 g
s
.50102 .74953 m .49774 .78779 L .51055 .79052 L p .707 .577 .707 r
F P
0 g
s
.50776 .8419 m .50944 .82276 L .49661 .82017 L p .707 .577 .707 r
F P
0 g
s
.49661 .82017 m .49493 .83931 L .50776 .8419 L p .707 .577 .707 r
F P
0 g
s
.50078 .72584 m .50377 .6688 L .50077 .66415 L p .707 .577 .707 r
F P
0 g
s
.50077 .66415 m .49778 .72119 L .50078 .72584 L p .707 .577 .707 r
F P
0 g
s
.49774 .78779 m .50102 .74953 L .49784 .74748 L p .707 .577 .707 r
F P
0 g
s
.49784 .74748 m .49456 .78575 L .49774 .78779 L p .707 .577 .707 r
F P
0 g
s
.49493 .83931 m .49661 .82017 L .49342 .81831 L p .707 .577 .707 r
F P
0 g
s
.49342 .81831 m .49173 .83744 L .49493 .83931 L p .707 .577 .707 r
F P
0 g
s
.51346 .73063 m .51644 .67359 L .50377 .6688 L p .707 .577 .707 r
F P
0 g
s
.49778 .72119 m .50077 .66415 L .50774 .6601 L p .707 .577 .707 r
F P
0 g
s
.50774 .6601 m .50475 .71715 L .49778 .72119 L p .707 .577 .707 r
F P
0 g
s
.49456 .78575 m .49784 .74748 L .50461 .74631 L p .707 .577 .707 r
F P
0 g
s
.50461 .74631 m .50133 .78458 L .49456 .78575 L p .707 .577 .707 r
F P
0 g
s
.49173 .83744 m .49342 .81831 L .50017 .81734 L p .707 .577 .707 r
F P
0 g
s
.50017 .81734 m .49849 .83647 L .49173 .83744 L p .707 .577 .707 r
F P
0 g
s
.50475 .71715 m .50774 .6601 L .51142 .65941 L p .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .47899 .40146 L .45306 .40538 L p .707 .577 .707 r
F P
0 g
s
.56204 .73881 m .56503 .68177 L .53755 .67806 L p .707 .577 .707 r
F P
0 g
s
.53755 .67806 m .53457 .7351 L .56204 .73881 L p .707 .577 .707 r
F P
0 g
s
.56254 .75866 m .55926 .79692 L .59038 .79996 L p .707 .577 .707 r
F P
0 g
s
.55926 .79692 m .56254 .75866 L .53503 .7554 L p .707 .577 .707 r
F P
0 g
s
.53457 .7351 m .53755 .67806 L .51644 .67359 L p .707 .577 .707 r
F P
0 g
s
.51644 .67359 m .51346 .73063 L .53457 .7351 L p .707 .577 .707 r
F P
0 g
s
.47899 .40146 m .51433 .67207 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.55655 .73776 m .47899 .40146 L .52886 .70807 L .707 .577 .707 r
F
.52101 .71409 m .52172 .70041 L p .52544 .70441 L F P
0 g
s
.5876 .85124 m .58928 .83211 L .55816 .82904 L p .707 .577 .707 r
F P
0 g
s
.53503 .7554 m .53175 .79367 L .55926 .79692 L p .707 .577 .707 r
F P
0 g
s
.55816 .82904 m .55648 .84817 L .5876 .85124 L p .707 .577 .707 r
F P
0 g
s
.53362 .71317 m .52101 .71409 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .52066 .74615 L .54185 .7469 L p .707 .577 .707 r
F P
0 g
s
.54185 .7469 m .54443 .74699 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .54185 .7469 L .54306 .74888 L .707 .577 .707 r
F
.50475 .71715 m .51142 .65941 L .51636 .6809 L F
.49664 .67262 m .51433 .67207 L .43439 .4082 L F
.52886 .70807 m .51433 .67207 L .52172 .70041 L F
.52399 .65705 m .52101 .71409 L .50475 .71715 L p F P
0 g
s
.50133 .78458 m .50461 .74631 L .52066 .74615 L p .707 .577 .707 r
F P
0 g
s
.52066 .74615 m .51738 .78441 L .50133 .78458 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .51738 .78441 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54443 .74699 m .54412 .75062 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54412 .75062 m .54115 .78525 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.49849 .83647 m .50017 .81734 L .51621 .81737 L p .707 .577 .707 r
F P
0 g
s
.51621 .81737 m .51452 .8365 L .49849 .83647 L p .707 .577 .707 r
F P
0 g
s
.51452 .8365 m .51621 .81737 L .53996 .81839 L p .707 .577 .707 r
F P
0 g
s
.53996 .81839 m .53828 .83753 L .51452 .8365 L p .707 .577 .707 r
F P
0 g
s
.49193 .84878 m .53653 .84205 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.43439 .4082 m .46135 .61464 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.46135 .61464 m .49193 .84878 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.53653 .84205 m .51925 .70977 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.51925 .70977 m .51433 .67207 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.59038 .79996 m .59366 .7617 L .56254 .75866 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .54318 .76162 L p .57359 .74876 L .707 .577 .707 r
F P
0 g
s
.54318 .76162 m .54443 .74699 L .55319 .74752 L p .707 .577 .707 r
F P
0 g
s
.55319 .74752 m .57359 .74876 L p .54318 .76162 L .707 .577 .707 r
F P
0 g
s
.5932 .7414 m .59618 .68435 L .56503 .68177 L p .707 .577 .707 r
F P
0 g
s
.59618 .68435 m .5932 .7414 L .62498 .7426 L p .707 .577 .707 r
F P
0 g
s
.56503 .68177 m .56204 .73881 L .5932 .7414 L p .707 .577 .707 r
F P
0 g
s
.59366 .7617 m .59038 .79996 L .62207 .80249 L p .707 .577 .707 r
F P
0 g
s
.62207 .80249 m .62536 .76423 L .59366 .7617 L p .707 .577 .707 r
F P
0 g
s
.62498 .7426 m .62797 .68556 L .59618 .68435 L p .707 .577 .707 r
F P
0 g
s
.60903 .65621 m .60604 .71326 L .58378 .71241 L p .707 .577 .707 r
F P
0 g
s
.58378 .71241 m .57426 .71205 L p .58649 .6924 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .60903 .65621 L .58378 .71241 L .707 .577 .707 r
F
.62536 .76423 m .62207 .80249 L .65123 .80427 L p F P
0 g
s
.65123 .80427 m .65451 .766 L .62536 .76423 L p .707 .577 .707 r
F P
0 g
s
.62797 .68556 m .62498 .7426 L .65428 .74232 L p .707 .577 .707 r
F P
0 g
s
.65428 .74232 m .65727 .68527 L .62797 .68556 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .60671 .71331 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60669 .71221 m .63368 .66916 L .60671 .71331 L .707 .577 .707 r
F
.63368 .66916 m .64018 .6588 L .63371 .66934 L F
.63368 .66916 m .63371 .66934 L .60671 .71331 L F
.58483 .32212 m .57558 .3462 L p .60413 .52426 L F P
0 g
s
.60903 .65621 m .64018 .6588 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .6364 .75434 L .64646 .75552 L p .707 .577 .707 r
F P
0 g
s
.65451 .766 m .65123 .80427 L .675 .80511 L p .707 .577 .707 r
F P
0 g
s
.675 .80511 m .67828 .76685 L .65451 .766 L p .707 .577 .707 r
F P
0 g
s
.64646 .75552 m .66391 .75759 L p .64932 .77418 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .64646 .75552 L .64932 .77418 L .707 .577 .707 r
F
.64236 .76271 m .6033 .46358 L p .60413 .52426 L F P
0 g
s
.6364 .75434 m .63312 .7926 L .60773 .79012 L p .707 .577 .707 r
F P
0 g
s
.60778 .78365 m .6364 .75434 L .60773 .79012 L .707 .577 .707 r
F
.602 .78956 m .60528 .7513 L .60802 .75156 L p F P
0 g
s
.60802 .75156 m .6364 .75434 L p .60778 .78365 L .707 .577 .707 r
F P
0 g
s
.602 .78956 m .60802 .75156 L .60778 .78365 L .707 .577 .707 r
F
.60475 .56956 m .60914 .60321 L p .60413 .52426 L F P
0 g
s
.60914 .60321 m .63311 .78679 L p .60938 .5718 L .707 .577 .707 r
F P
0 g
s
.60413 .52426 m .60914 .60321 L .60938 .5718 L .707 .577 .707 r
F
.63311 .78679 m .64236 .76271 L p .60948 .55766 L F P
0 g
s
.60948 .55766 m .60413 .52426 L .60938 .5718 L .707 .577 .707 r
F
.60948 .55766 m .60938 .5718 L .63311 .78679 L F
.60773 .79012 m .602 .78956 L p .60778 .78365 L F P
0 g
s
.64236 .76271 m .6376 .73959 L p .608 .50546 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .58483 .32212 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.608 .50546 m .59921 .43593 L .61078 .52349 L .707 .577 .707 r
F
.608 .50546 m .61078 .52349 L .64236 .76271 L F
.60604 .71326 m .60657 .70314 L p .60669 .71221 L F P
0 g
s
.60657 .70314 m .60903 .65621 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.58006 .299 m .58483 .32212 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6376 .73959 m .58831 .36214 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58831 .36214 m .58006 .299 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58483 .32212 m .6033 .46358 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .64236 .76271 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.64018 .6588 m .63808 .69891 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.63808 .69891 m .63719 .71584 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60671 .71331 m .60604 .71326 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .60475 .56956 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.55322 .36887 m .59106 .65864 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .55322 .36887 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .58753 .68473 L .60903 .65621 L .707 .577 .707 r
F
.59221 .65558 m .60903 .65621 L p .5748 .70161 L F P
0 g
s
.63311 .78679 m .60394 .56338 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.60394 .56338 m .57558 .3462 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .5748 .70161 L p .58753 .68473 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .58753 .68473 L .58649 .6924 L .707 .577 .707 r
F
.51993 .38791 m .56346 .7212 L p .5829 .68019 L F P
0 g
s
.5748 .70161 m .57426 .71205 L .56873 .71211 L p .707 .577 .707 r
F P
0 g
s
.56346 .7212 m .56447 .72893 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.5829 .68019 m .56346 .7212 L .5748 .70161 L .707 .577 .707 r
F
.57359 .74876 m .57031 .78703 L .54115 .78525 L p F P
0 g
s
.57031 .78703 m .57359 .74876 L .58061 .74932 L p .707 .577 .707 r
F P
0 g
s
.58061 .74932 m .60528 .7513 L p .57445 .7828 L .707 .577 .707 r
F P
0 g
s
.57031 .78703 m .58061 .74932 L .57445 .7828 L .707 .577 .707 r
F
.60528 .7513 m .602 .78956 L .57031 .78703 L p F P
0 g
s
.61075 .80945 m .55322 .36887 L .51993 .38791 L p .707 .577 .707 r
F P
0 g
s
.5748 .70161 m .57724 .65501 L .59221 .65558 L p .707 .577 .707 r
F P
0 g
s
.59106 .65864 m .59365 .67849 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.59365 .67849 m .61075 .80945 L p .60053 .6411 L .707 .577 .707 r
F P
0 g
s
.59833 .60485 m .59365 .67849 L .60053 .6411 L .707 .577 .707 r
F
.56742 .83944 m .56911 .82031 L .60079 .82293 L p F P
0 g
s
.57747 .8285 m .51993 .38791 L .47899 .40146 L p .707 .577 .707 r
F P
0 g
s
.57724 .65501 m .5748 .70161 L p .54496 .71234 L .707 .577 .707 r
F P
0 g
s
.56873 .71211 m .54496 .71234 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.58712 .69976 m .5829 .68019 L .56477 .73123 L .707 .577 .707 r
F
.56447 .72893 m .56477 .73123 L p .5829 .68019 L F P
0 g
s
.61075 .80945 m .63311 .78679 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .61075 .80945 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.56477 .73123 m .57747 .8285 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.53828 .83753 m .53996 .81839 L .56911 .82031 L p .707 .577 .707 r
F P
0 g
s
.56911 .82031 m .56742 .83944 L .53828 .83753 L p .707 .577 .707 r
F P
0 g
s
.55691 .8353 m .57747 .8285 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.52886 .70807 m .52172 .70041 L .55691 .8353 L .707 .577 .707 r
F
.54794 .6553 m .54496 .71234 L .53362 .71317 L p F P
0 g
s
.52544 .70441 m .54794 .6553 L .53362 .71317 L .707 .577 .707 r
F
.52399 .65705 m .54794 .6553 L p .52544 .70441 L F P
0 g
s
.52172 .70041 m .52399 .65705 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .55655 .73776 L .52886 .70807 L .707 .577 .707 r
F
.51636 .6809 m .51433 .67207 L .51651 .68043 L F
.51433 .67207 m .53653 .84205 L .55691 .8353 L p F P
0 g
s
.51142 .65941 m .52399 .65705 L p .51651 .68043 L .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .51142 .65941 L .51651 .68043 L .707 .577 .707 r
F
.45306 .40538 m .43439 .4082 L p .51433 .67207 L F P
0 g
s
.44804 .84804 m .3905 .40746 L .35162 .39931 L p .707 .577 .707 r
F P
0 g
s
.3905 .40746 m .44804 .84804 L .49193 .84878 L p .707 .577 .707 r
F P
0 g
s
.40915 .8399 m .35162 .39931 L .32155 .38456 L p .707 .577 .707 r
F P
0 g
s
.35162 .39931 m .40915 .8399 L .44804 .84804 L p .707 .577 .707 r
F P
0 g
s
.65727 .68527 m .65428 .74232 L .67823 .74056 L p .707 .577 .707 r
F P
0 g
s
.67823 .74056 m .68122 .68352 L .65727 .68527 L p .707 .577 .707 r
F P
0 g
s
.58928 .83211 m .5876 .85124 L .61928 .85387 L p .707 .577 .707 r
F P
0 g
s
.61928 .85387 m .62096 .83473 L .58928 .83211 L p .707 .577 .707 r
F P
0 g
s
.62096 .83473 m .61928 .85387 L .64843 .85578 L p .707 .577 .707 r
F P
0 g
s
.64843 .85578 m .65011 .83665 L .62096 .83473 L p .707 .577 .707 r
F P
0 g
s
.68122 .68352 m .67823 .74056 L .69448 .73751 L p .707 .577 .707 r
F P
0 g
s
.69448 .73751 m .69747 .68047 L .68122 .68352 L p .707 .577 .707 r
F P
0 g
s
.65011 .83665 m .64843 .85578 L .67218 .85681 L p .707 .577 .707 r
F P
0 g
s
.67218 .85681 m .67386 .83767 L .65011 .83665 L p .707 .577 .707 r
F P
0 g
s
.35147 .70069 m .35446 .64365 L .33821 .6467 L p .707 .577 .707 r
F P
0 g
s
.35446 .64365 m .35147 .70069 L .35844 .69665 L p .707 .577 .707 r
F P
0 g
s
.35844 .69665 m .35916 .68297 L p .35446 .64365 L .707 .577 .707 r
F P
0 g
s
.37908 .82515 m .35999 .67891 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35689 .65518 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35916 .68297 L .3626 .72506 L .707 .577 .707 r
F
.37908 .82515 m .40915 .8399 L p .34771 .52055 L F P
0 g
s
.35689 .65518 m .37908 .82515 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .36143 .6396 L .35604 .64273 L p .707 .577 .707 r
F P
0 g
s
.35604 .64273 m .35588 .64283 L p .35689 .65518 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35604 .64273 L .35689 .65518 L .707 .577 .707 r
F
.35588 .64283 m .35446 .64365 L p .35916 .68297 L F P
0 g
s
.32155 .38456 m .35689 .65518 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35844 .69665 L .35686 .6942 L p .707 .577 .707 r
F P
0 g
s
.32155 .38456 m .30323 .36465 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35689 .65518 m .32155 .38456 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.33821 .6467 m .33522 .70374 L .35147 .70069 L p .707 .577 .707 r
F P
0 g
s
.34805 .76813 m .35133 .72986 L .33527 .73003 L p .707 .577 .707 r
F P
0 g
s
.35133 .72986 m .34805 .76813 L .35482 .76696 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .3581 .7287 L .35133 .72986 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .35164 .76491 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.3581 .7287 m .35618 .75107 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35618 .75107 m .35482 .76696 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.34546 .68996 m .30323 .36465 L .34444 .68365 L .707 .577 .707 r
F
.33527 .73003 m .33199 .7683 L .34805 .76813 L p F P
0 g
s
.33882 .76218 m .3421 .72392 L .35107 .72583 L p .707 .577 .707 r
F P
0 g
s
.35107 .72583 m .35492 .72665 L p .35221 .73263 L .707 .577 .707 r
F P
0 g
s
.33882 .76218 m .35107 .72583 L .35221 .73263 L .707 .577 .707 r
F
.35113 .73139 m .34807 .70797 L p .35054 .72912 L F P
0 g
s
.34807 .70797 m .34676 .69794 L p .34774 .70599 L .707 .577 .707 r
F P
0 g
s
.34807 .70797 m .34774 .70599 L .35054 .72912 L .707 .577 .707 r
F
.34676 .69794 m .30323 .36465 L p .34546 .68996 L F P
0 g
s
.34676 .69794 m .34546 .68996 L .35054 .72912 L .707 .577 .707 r
F
.30323 .36465 m .29847 .34152 L p .34444 .68365 L F P
0 g
s
.36077 .80524 m .37908 .82515 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.30323 .36465 m .34676 .69794 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .3581 .7287 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35164 .76491 m .35366 .74128 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35366 .74128 m .35492 .72665 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .35164 .76491 L .33882 .76218 L p .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .36077 .80524 L p .35054 .72912 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .34332 .67676 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34516 .68811 m .34277 .68721 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.29847 .34152 m .30772 .31745 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .33644 .68587 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.33522 .70374 m .33821 .6467 L .31426 .64846 L p .707 .577 .707 r
F P
0 g
s
.33636 .65067 m .33856 .64587 L .33644 .68587 L .707 .577 .707 r
F
.29847 .34152 m .33631 .63129 L p .34484 .68665 L F P
0 g
s
.34576 .63016 m .34332 .67676 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34277 .68721 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.35054 .72912 m .34484 .68665 L .34758 .71757 L .707 .577 .707 r
F
.33631 .63129 m .29847 .34152 L p .33622 .59168 L F P
0 g
s
.31426 .64846 m .31127 .7055 L .33522 .70374 L p .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .32465 .62569 L .3363 .62816 L p .707 .577 .707 r
F P
0 g
s
.3363 .62816 m .34576 .63016 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .3363 .62816 L .33636 .65067 L .707 .577 .707 r
F
.34758 .71757 m .35601 .78211 L p .35054 .72912 L F P
0 g
s
.34676 .69794 m .36077 .80524 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.34576 .63016 m .35843 .63496 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34576 .63016 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.35843 .63496 m .35544 .692 L .34516 .68811 L p .707 .577 .707 r
F P
0 g
s
.34422 .68235 m .35843 .63496 L .34516 .68811 L .707 .577 .707 r
F
.35054 .72912 m .34546 .68996 L .34444 .68365 L F
.36077 .80524 m .35113 .73139 L p .35054 .72912 L F P
0 g
s
.36526 .75804 m .35601 .78211 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.30772 .31745 m .33608 .53463 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.36143 .6396 m .35916 .68297 L p .35544 .692 L .707 .577 .707 r
F P
0 g
s
.35686 .6942 m .35544 .692 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35544 .692 m .35843 .63496 L .36143 .6396 L p .707 .577 .707 r
F P
0 g
s
.33608 .53463 m .36526 .75804 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33631 .63129 m .34758 .71757 L p .34484 .68665 L .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .33631 .63129 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33644 .68587 m .32166 .68274 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.67828 .76685 m .675 .80511 L .69106 .80494 L p .707 .577 .707 r
F P
0 g
s
.69106 .80494 m .69434 .76668 L .67828 .76685 L p .707 .577 .707 r
F P
0 g
s
.67386 .83767 m .67218 .85681 L .68822 .85684 L p .707 .577 .707 r
F P
0 g
s
.68822 .85684 m .6899 .8377 L .67386 .83767 L p .707 .577 .707 r
F P
0 g
s
.69747 .68047 m .69448 .73751 L .70145 .73346 L p .707 .577 .707 r
F P
0 g
s
.70145 .73346 m .70444 .67642 L .69747 .68047 L p .707 .577 .707 r
F P
0 g
s
.69434 .76668 m .69106 .80494 L .69783 .80378 L p .707 .577 .707 r
F P
0 g
s
.69783 .80378 m .70111 .76551 L .69434 .76668 L p .707 .577 .707 r
F P
0 g
s
.6899 .8377 m .68822 .85684 L .69497 .85587 L p .707 .577 .707 r
F P
0 g
s
.69497 .85587 m .69665 .83674 L .6899 .8377 L p .707 .577 .707 r
F P
0 g
s
.70444 .67642 m .70145 .73346 L .69845 .72881 L p .707 .577 .707 r
F P
0 g
s
.69845 .72881 m .70144 .67177 L .70444 .67642 L p .707 .577 .707 r
F P
0 g
s
.70111 .76551 m .69783 .80378 L .69465 .80173 L p .707 .577 .707 r
F P
0 g
s
.69465 .80173 m .69793 .76346 L .70111 .76551 L p .707 .577 .707 r
F P
0 g
s
.69665 .83674 m .69497 .85587 L .69177 .854 L p .707 .577 .707 r
F P
0 g
s
.69177 .854 m .69346 .83487 L .69665 .83674 L p .707 .577 .707 r
F P
0 g
s
.70144 .67177 m .69845 .72881 L .68578 .72402 L p .707 .577 .707 r
F P
0 g
s
.68578 .72402 m .68876 .66698 L .70144 .67177 L p .707 .577 .707 r
F P
0 g
s
.58006 .299 m .6376 .73959 L .61929 .71967 L p .707 .577 .707 r
F P
0 g
s
.61929 .71967 m .56175 .27909 L .58006 .299 L p .707 .577 .707 r
F P
0 g
s
.25019 .70458 m .25317 .64754 L .22202 .64495 L p .707 .577 .707 r
F P
0 g
s
.25317 .64754 m .25019 .70458 L .28197 .70579 L p .707 .577 .707 r
F P
0 g
s
.28197 .70579 m .28496 .64875 L .25317 .64754 L p .707 .577 .707 r
F P
0 g
s
.28496 .64875 m .28197 .70579 L .31127 .7055 L p .707 .577 .707 r
F P
0 g
s
.31127 .7055 m .31426 .64846 L .28496 .64875 L p .707 .577 .707 r
F P
0 g
s
.21903 .702 m .22202 .64495 L .19454 .64125 L p .707 .577 .707 r
F P
0 g
s
.22202 .64495 m .21903 .702 L .25019 .70458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69793 .76346 m .69465 .80173 L .68183 .799 L p .707 .577 .707 r
F P
0 g
s
.68183 .799 m .68511 .76073 L .69793 .76346 L p .707 .577 .707 r
F P
0 g
s
.19454 .64125 m .19156 .69829 L .21903 .702 L p .707 .577 .707 r
F P
0 g
s
.24737 .76315 m .25066 .72488 L .21953 .72184 L p .707 .577 .707 r
F P
0 g
s
.25066 .72488 m .24737 .76315 L .27906 .76568 L p .707 .577 .707 r
F P
0 g
s
.27906 .76568 m .28235 .72741 L .25066 .72488 L p .707 .577 .707 r
F P
0 g
s
.21953 .72184 m .21625 .76011 L .24737 .76315 L p .707 .577 .707 r
F P
0 g
s
.28235 .72741 m .27906 .76568 L .30822 .76745 L p .707 .577 .707 r
F P
0 g
s
.30822 .76745 m .3115 .72919 L .28235 .72741 L p .707 .577 .707 r
F P
0 g
s
.69346 .83487 m .69177 .854 L .67895 .85141 L p .707 .577 .707 r
F P
0 g
s
.67895 .85141 m .68063 .83228 L .69346 .83487 L p .707 .577 .707 r
F P
0 g
s
.21625 .76011 m .21953 .72184 L .19203 .71859 L p .707 .577 .707 r
F P
0 g
s
.19156 .69829 m .19454 .64125 L .17344 .63678 L p .707 .577 .707 r
F P
0 g
s
.24459 .81443 m .24627 .79529 L .21515 .79222 L p .707 .577 .707 r
F P
0 g
s
.24627 .79529 m .24459 .81443 L .27627 .81705 L p .707 .577 .707 r
F P
0 g
s
.27627 .81705 m .27796 .79792 L .24627 .79529 L p .707 .577 .707 r
F P
0 g
s
.68876 .66698 m .68578 .72402 L .66467 .71955 L p .707 .577 .707 r
F P
0 g
s
.66467 .71955 m .66766 .66251 L .68876 .66698 L p .707 .577 .707 r
F P
0 g
s
.19203 .71859 m .18874 .75685 L .21625 .76011 L p .707 .577 .707 r
F P
0 g
s
.21515 .79222 m .21347 .81136 L .24459 .81443 L p .707 .577 .707 r
F P
0 g
s
.36526 .75804 m .30772 .31745 L .33008 .29478 L p .707 .577 .707 r
F P
0 g
s
.27796 .79792 m .27627 .81705 L .30542 .81897 L p .707 .577 .707 r
F P
0 g
s
.30542 .81897 m .3071 .79983 L .27796 .79792 L p .707 .577 .707 r
F P
0 g
s
.21347 .81136 m .21515 .79222 L .18764 .789 L p .707 .577 .707 r
F P
0 g
s
.17344 .63678 m .17045 .69382 L .19156 .69829 L p .707 .577 .707 r
F P
0 g
s
.18764 .789 m .18596 .80814 L .21347 .81136 L p .707 .577 .707 r
F P
0 g
s
.3115 .72919 m .30822 .76745 L .33199 .7683 L p .707 .577 .707 r
F P
0 g
s
.33199 .7683 m .33527 .73003 L .3115 .72919 L p .707 .577 .707 r
F P
0 g
s
.56175 .27909 m .61929 .71967 L .58922 .70492 L p .707 .577 .707 r
F P
0 g
s
.58922 .70492 m .53168 .26434 L .56175 .27909 L p .707 .577 .707 r
F P
0 g
s
.18874 .75685 m .19203 .71859 L .17083 .71544 L p .707 .577 .707 r
F P
0 g
s
.3071 .79983 m .30542 .81897 L .32917 .81999 L p .707 .577 .707 r
F P
0 g
s
.32917 .81999 m .33086 .80086 L .3071 .79983 L p .707 .577 .707 r
F P
0 g
s
.17083 .71544 m .16754 .75371 L .18874 .75685 L p .707 .577 .707 r
F P
0 g
s
.68511 .76073 m .68183 .799 L .66063 .79585 L p .707 .577 .707 r
F P
0 g
s
.66063 .79585 m .66391 .75759 L .68511 .76073 L p .707 .577 .707 r
F P
0 g
s
.18596 .80814 m .18764 .789 L .16643 .78595 L p .707 .577 .707 r
F P
0 g
s
.17045 .69382 m .17344 .63678 L .16076 .63198 L p .707 .577 .707 r
F P
0 g
s
.16643 .78595 m .16475 .80508 L .18596 .80814 L p .707 .577 .707 r
F P
0 g
s
.66766 .66251 m .66467 .71955 L .63719 .71584 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .64018 .6588 L .66766 .66251 L p .707 .577 .707 r
F P
0 g
s
.68063 .83228 m .67895 .85141 L .65774 .84836 L p .707 .577 .707 r
F P
0 g
s
.65774 .84836 m .65942 .82922 L .68063 .83228 L p .707 .577 .707 r
F P
0 g
s
.54496 .71234 m .54794 .6553 L .57724 .65501 L p .707 .577 .707 r
F P
0 g
s
.16076 .63198 m .15777 .68903 L .17045 .69382 L p .707 .577 .707 r
F P
0 g
s
.33008 .29478 m .38762 .73537 L .36526 .75804 L p .707 .577 .707 r
F P
0 g
s
.38762 .73537 m .33008 .29478 L .36336 .27574 L p .707 .577 .707 r
F P
0 g
s
.33086 .80086 m .32917 .81999 L .34521 .82002 L p .707 .577 .707 r
F P
0 g
s
.34521 .82002 m .34689 .80089 L .33086 .80086 L p .707 .577 .707 r
F P
0 g
s
.16754 .75371 m .17083 .71544 L .15801 .71271 L p .707 .577 .707 r
F P
0 g
s
.53168 .26434 m .58922 .70492 L .55033 .69678 L p .707 .577 .707 r
F P
0 g
s
.55033 .69678 m .4928 .25619 L .53168 .26434 L p .707 .577 .707 r
F P
0 g
s
.15801 .71271 m .15473 .75098 L .16754 .75371 L p .707 .577 .707 r
F P
0 g
s
.66391 .75759 m .66063 .79585 L .63312 .7926 L p .707 .577 .707 r
F P
0 g
s
.16475 .80508 m .16643 .78595 L .15361 .78336 L p .707 .577 .707 r
F P
0 g
s
.15361 .78336 m .15192 .80249 L .16475 .80508 L p .707 .577 .707 r
F P
0 g
s
.65942 .82922 m .65774 .84836 L .63023 .84514 L p .707 .577 .707 r
F P
0 g
s
.63023 .84514 m .63191 .826 L .65942 .82922 L p .707 .577 .707 r
F P
0 g
s
.15777 .68903 m .16076 .63198 L .15776 .62733 L p .707 .577 .707 r
F P
0 g
s
.4209 .71633 m .36336 .27574 L .40431 .26219 L p .707 .577 .707 r
F P
0 g
s
.36336 .27574 m .4209 .71633 L .38762 .73537 L p .707 .577 .707 r
F P
0 g
s
.15776 .62733 m .15477 .68438 L .15777 .68903 L p .707 .577 .707 r
F P
0 g
s
.4928 .25619 m .55033 .69678 L .50644 .69604 L p .707 .577 .707 r
F P
0 g
s
.50644 .69604 m .44891 .25545 L .4928 .25619 L p .707 .577 .707 r
F P
0 g
s
.63191 .826 m .63023 .84514 L .59911 .84207 L p .707 .577 .707 r
F P
0 g
s
.59911 .84207 m .60079 .82293 L .63191 .826 L p .707 .577 .707 r
F P
0 g
s
.34689 .80089 m .34521 .82002 L .35196 .81906 L p .707 .577 .707 r
F P
0 g
s
.35196 .81906 m .35365 .79992 L .34689 .80089 L p .707 .577 .707 r
F P
0 g
s
.15473 .75098 m .15801 .71271 L .15483 .71067 L p .707 .577 .707 r
F P
0 g
s
.60079 .82293 m .59911 .84207 L .56742 .83944 L p .707 .577 .707 r
F P
0 g
s
.15483 .71067 m .15155 .74893 L .15473 .75098 L p .707 .577 .707 r
F P
0 g
s
.46184 .70278 m .40431 .26219 L .44891 .25545 L p .707 .577 .707 r
F P
0 g
s
.40431 .26219 m .46184 .70278 L .4209 .71633 L p .707 .577 .707 r
F P
0 g
s
.44891 .25545 m .50644 .69604 L .46184 .70278 L p .707 .577 .707 r
F P
0 g
s
.15192 .80249 m .15361 .78336 L .15041 .78149 L p .707 .577 .707 r
F P
0 g
s
.15041 .78149 m .14872 .80063 L .15192 .80249 L p .707 .577 .707 r
F P
0 g
s
.15477 .68438 m .15776 .62733 L .16473 .62329 L p .707 .577 .707 r
F P
0 g
s
.16473 .62329 m .16174 .68033 L .15477 .68438 L p .707 .577 .707 r
F P
0 g
s
.35365 .79992 m .35196 .81906 L .34877 .81719 L p .707 .577 .707 r
F P
0 g
s
.34877 .81719 m .35045 .79805 L .35365 .79992 L p .707 .577 .707 r
F P
0 g
s
.15155 .74893 m .15483 .71067 L .1616 .7095 L p .707 .577 .707 r
F P
0 g
s
.1616 .7095 m .15832 .74776 L .15155 .74893 L p .707 .577 .707 r
F P
0 g
s
.14872 .80063 m .15041 .78149 L .15716 .78052 L p .707 .577 .707 r
F P
0 g
s
.15716 .78052 m .15548 .79966 L .14872 .80063 L p .707 .577 .707 r
F P
0 g
s
.16174 .68033 m .16473 .62329 L .18098 .62024 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18098 .62024 m .178 .67728 L .16174 .68033 L p .707 .577 .707 r
F P
0 g
s
.35045 .79805 m .34877 .81719 L .33594 .8146 L p .707 .577 .707 r
F P
0 g
s
.33594 .8146 m .33762 .79546 L .35045 .79805 L p .707 .577 .707 r
F P
0 g
s
.15832 .74776 m .1616 .7095 L .17765 .70933 L p .707 .577 .707 r
F P
0 g
s
.17765 .70933 m .17437 .7476 L .15832 .74776 L p .707 .577 .707 r
F P
0 g
s
.15548 .79966 m .15716 .78052 L .1732 .78055 L p .707 .577 .707 r
F P
0 g
s
.1732 .78055 m .17151 .79969 L .15548 .79966 L p .707 .577 .707 r
F P
0 g
s
.178 .67728 m .18098 .62024 L .20493 .61848 L p .707 .577 .707 r
F P
0 g
s
.3421 .72392 m .33882 .76218 L .31762 .75904 L p .707 .577 .707 r
F P
0 g
s
.31762 .75904 m .3209 .72077 L .3421 .72392 L p .707 .577 .707 r
F P
0 g
s
.20493 .61848 m .20195 .67552 L .178 .67728 L p .707 .577 .707 r
F P
0 g
s
.32465 .62569 m .32166 .68274 L .29418 .67903 L p .707 .577 .707 r
F P
0 g
s
.29418 .67903 m .29717 .62198 L .32465 .62569 L p .707 .577 .707 r
F P
0 g
s
.33762 .79546 m .33594 .8146 L .31473 .81154 L p .707 .577 .707 r
F P
0 g
s
.31473 .81154 m .31641 .79241 L .33762 .79546 L p .707 .577 .707 r
F P
0 g
s
.17437 .7476 m .17765 .70933 L .20142 .71017 L p .707 .577 .707 r
F P
0 g
s
.20142 .71017 m .19814 .74844 L .17437 .7476 L p .707 .577 .707 r
F P
0 g
s
.20195 .67552 m .20493 .61848 L .23423 .61819 L p .707 .577 .707 r
F P
0 g
s
.17151 .79969 m .1732 .78055 L .19695 .78158 L p .707 .577 .707 r
F P
0 g
s
.19695 .78158 m .19527 .80071 L .17151 .79969 L p .707 .577 .707 r
F P
0 g
s
.23423 .61819 m .23125 .67524 L .20195 .67552 L p .707 .577 .707 r
F P
0 g
s
.29717 .62198 m .29418 .67903 L .26303 .67644 L p .707 .577 .707 r
F P
0 g
s
.26303 .67644 m .26602 .6194 L .29717 .62198 L p .707 .577 .707 r
F P
0 g
s
.3209 .72077 m .31762 .75904 L .29011 .75579 L p .707 .577 .707 r
F P
0 g
s
.29011 .75579 m .29339 .71752 L .3209 .72077 L p .707 .577 .707 r
F P
0 g
s
.7304 .64285 m .73339 .5858 L .70223 .58322 L p .707 .577 .707 r
F P
0 g
s
.73339 .5858 m .7304 .64285 L .76218 .64406 L p .707 .577 .707 r
F P
0 g
s
.76218 .64406 m .76517 .58701 L .73339 .5858 L p .707 .577 .707 r
F P
0 g
s
.23125 .67524 m .23423 .61819 L .26602 .6194 L p .707 .577 .707 r
F P
0 g
s
.76517 .58701 m .76218 .64406 L .79148 .64377 L p .707 .577 .707 r
F P
0 g
s
.79148 .64377 m .79447 .58672 L .76517 .58701 L p .707 .577 .707 r
F P
0 g
s
.26602 .6194 m .26303 .67644 L .23125 .67524 L p .707 .577 .707 r
F P
0 g
s
.19814 .74844 m .20142 .71017 L .23058 .71195 L p .707 .577 .707 r
F P
0 g
s
.69925 .64026 m .70223 .58322 L .67476 .57951 L p .707 .577 .707 r
F P
0 g
s
.70223 .58322 m .69925 .64026 L .7304 .64285 L p .707 .577 .707 r
F P
0 g
s
.31641 .79241 m .31473 .81154 L .28722 .80832 L p .707 .577 .707 r
F P
0 g
s
.28722 .80832 m .2889 .78919 L .31641 .79241 L p .707 .577 .707 r
F P
0 g
s
.23058 .71195 m .2273 .75021 L .19814 .74844 L p .707 .577 .707 r
F P
0 g
s
.72759 .69142 m .73087 .65315 L .69975 .65011 L p .707 .577 .707 r
F P
0 g
s
.73087 .65315 m .72759 .69142 L .75928 .69395 L p .707 .577 .707 r
F P
0 g
s
.75928 .69395 m .76256 .65568 L .73087 .65315 L p .707 .577 .707 r
F P
0 g
s
.19527 .80071 m .19695 .78158 L .2261 .78349 L p .707 .577 .707 r
F P
0 g
s
.69975 .65011 m .69646 .68838 L .72759 .69142 L p .707 .577 .707 r
F P
0 g
s
.67476 .57951 m .67177 .63656 L .69925 .64026 L p .707 .577 .707 r
F P
0 g
s
.2261 .78349 m .22441 .80263 L .19527 .80071 L p .707 .577 .707 r
F P
0 g
s
.76256 .65568 m .75928 .69395 L .78844 .69572 L p .707 .577 .707 r
F P
0 g
s
.78844 .69572 m .79172 .65746 L .76256 .65568 L p .707 .577 .707 r
F P
0 g
s
.29339 .71752 m .29011 .75579 L .25899 .75275 L p .707 .577 .707 r
F P
0 g
s
.25899 .75275 m .26227 .71448 L .29339 .71752 L p .707 .577 .707 r
F P
0 g
s
.79447 .58672 m .79148 .64377 L .81543 .64201 L p .707 .577 .707 r
F P
0 g
s
.81543 .64201 m .81842 .58497 L .79447 .58672 L p .707 .577 .707 r
F P
0 g
s
.7248 .72686 m .72649 .70772 L .69537 .70465 L p .707 .577 .707 r
F P
0 g
s
.72649 .70772 m .7248 .72686 L .75648 .72948 L p .707 .577 .707 r
F P
0 g
s
.75648 .72948 m .75817 .71035 L .72649 .70772 L p .707 .577 .707 r
F P
0 g
s
.69537 .70465 m .69368 .72379 L .7248 .72686 L p .707 .577 .707 r
F P
0 g
s
.69646 .68838 m .69975 .65011 L .67224 .64686 L p .707 .577 .707 r
F P
0 g
s
.2273 .75021 m .23058 .71195 L .26227 .71448 L p .707 .577 .707 r
F P
0 g
s
.75817 .71035 m .75648 .72948 L .78563 .7314 L p .707 .577 .707 r
F P
0 g
s
.78563 .7314 m .78731 .71226 L .75817 .71035 L p .707 .577 .707 r
F P
0 g
s
.67224 .64686 m .66896 .68513 L .69646 .68838 L p .707 .577 .707 r
F P
0 g
s
.26227 .71448 m .25899 .75275 L .2273 .75021 L p .707 .577 .707 r
F P
0 g
s
.67177 .63656 m .67476 .57951 L .65365 .57504 L p .707 .577 .707 r
F P
0 g
s
.69368 .72379 m .69537 .70465 L .66786 .70143 L p .707 .577 .707 r
F P
0 g
s
.66786 .70143 m .66617 .72057 L .69368 .72379 L p .707 .577 .707 r
F P
0 g
s
.2889 .78919 m .28722 .80832 L .2561 .80525 L p .707 .577 .707 r
F P
0 g
s
.2561 .80525 m .25778 .78612 L .2889 .78919 L p .707 .577 .707 r
F P
0 g
s
.22441 .80263 m .2261 .78349 L .25778 .78612 L p .707 .577 .707 r
F P
0 g
s
.25778 .78612 m .2561 .80525 L .22441 .80263 L p .707 .577 .707 r
F P
0 g
s
.79172 .65746 m .78844 .69572 L .81221 .69657 L p .707 .577 .707 r
F P
0 g
s
.81221 .69657 m .81549 .6583 L .79172 .65746 L p .707 .577 .707 r
F P
0 g
s
.65365 .57504 m .65066 .63209 L .67177 .63656 L p .707 .577 .707 r
F P
0 g
s
.78731 .71226 m .78563 .7314 L .80938 .73242 L p .707 .577 .707 r
F P
0 g
s
.80938 .73242 m .81107 .71329 L .78731 .71226 L p .707 .577 .707 r
F P
0 g
s
.66896 .68513 m .67224 .64686 L .65104 .64371 L p .707 .577 .707 r
F P
0 g
s
.65104 .64371 m .64776 .68198 L .66896 .68513 L p .707 .577 .707 r
F P
0 g
s
.81842 .58497 m .81543 .64201 L .83169 .63896 L p .707 .577 .707 r
F P
0 g
s
.83169 .63896 m .83467 .58192 L .81842 .58497 L p .707 .577 .707 r
F P
0 g
s
.66617 .72057 m .66786 .70143 L .64665 .69838 L p .707 .577 .707 r
F P
0 g
s
.64665 .69838 m .64496 .71751 L .66617 .72057 L p .707 .577 .707 r
F P
0 g
s
.65066 .63209 m .65365 .57504 L .64097 .57025 L p .707 .577 .707 r
F P
0 g
s
.81549 .6583 m .81221 .69657 L .82826 .6964 L p .707 .577 .707 r
F P
0 g
s
.82826 .6964 m .83154 .65813 L .81549 .6583 L p .707 .577 .707 r
F P
0 g
s
.81107 .71329 m .80938 .73242 L .82542 .73245 L p .707 .577 .707 r
F P
0 g
s
.82542 .73245 m .82711 .71332 L .81107 .71329 L p .707 .577 .707 r
F P
0 g
s
.64097 .57025 m .63799 .62729 L .65066 .63209 L p .707 .577 .707 r
F P
0 g
s
.64776 .68198 m .65104 .64371 L .63822 .64098 L p .707 .577 .707 r
F P
0 g
s
.63822 .64098 m .63494 .67925 L .64776 .68198 L p .707 .577 .707 r
F P
0 g
s
.64496 .71751 m .64665 .69838 L .63382 .69579 L p .707 .577 .707 r
F P
0 g
s
.63382 .69579 m .63213 .71492 L .64496 .71751 L p .707 .577 .707 r
F P
0 g
s
.83467 .58192 m .83169 .63896 L .83866 .63491 L p .707 .577 .707 r
F P
0 g
s
.83866 .63491 m .84164 .57787 L .83467 .58192 L p .707 .577 .707 r
F P
0 g
s
.63799 .62729 m .64097 .57025 L .63797 .5656 L p .707 .577 .707 r
F P
0 g
s
.83154 .65813 m .82826 .6964 L .83503 .69523 L p .707 .577 .707 r
F P
0 g
s
.83503 .69523 m .83831 .65697 L .83154 .65813 L p .707 .577 .707 r
F P
0 g
s
.82711 .71332 m .82542 .73245 L .83217 .73148 L p .707 .577 .707 r
F P
0 g
s
.83217 .73148 m .83386 .71235 L .82711 .71332 L p .707 .577 .707 r
F P
0 g
s
.63797 .5656 m .63499 .62264 L .63799 .62729 L p .707 .577 .707 r
F P
0 g
s
.63494 .67925 m .63822 .64098 L .63504 .63894 L p .707 .577 .707 r
F P
0 g
s
.63504 .63894 m .63176 .6772 L .63494 .67925 L p .707 .577 .707 r
F P
0 g
s
.63213 .71492 m .63382 .69579 L .63062 .69392 L p .707 .577 .707 r
F P
0 g
s
.63062 .69392 m .62894 .71305 L .63213 .71492 L p .707 .577 .707 r
F P
0 g
s
.84164 .57787 m .83866 .63491 L .83566 .63026 L p .707 .577 .707 r
F P
0 g
s
.83566 .63026 m .83864 .57322 L .84164 .57787 L p .707 .577 .707 r
F P
0 g
s
.63499 .62264 m .63797 .5656 L .64494 .56155 L p .707 .577 .707 r
F P
0 g
s
.83831 .65697 m .83503 .69523 L .83185 .69318 L p .707 .577 .707 r
F P
0 g
s
.83185 .69318 m .83513 .65492 L .83831 .65697 L p .707 .577 .707 r
F P
0 g
s
.83386 .71235 m .83217 .73148 L .82898 .72962 L p .707 .577 .707 r
F P
0 g
s
.82898 .72962 m .83066 .71048 L .83386 .71235 L p .707 .577 .707 r
F P
0 g
s
.64494 .56155 m .64196 .6186 L .63499 .62264 L p .707 .577 .707 r
F P
0 g
s
.63176 .6772 m .63504 .63894 L .64181 .63777 L p .707 .577 .707 r
F P
0 g
s
.64181 .63777 m .63853 .67603 L .63176 .6772 L p .707 .577 .707 r
F P
0 g
s
.62894 .71305 m .63062 .69392 L .63738 .69295 L p .707 .577 .707 r
F P
0 g
s
.63738 .69295 m .63569 .71209 L .62894 .71305 L p .707 .577 .707 r
F P
0 g
s
.83864 .57322 m .83566 .63026 L .82298 .62547 L p .707 .577 .707 r
F P
0 g
s
.82298 .62547 m .82597 .56843 L .83864 .57322 L p .707 .577 .707 r
F P
0 g
s
.38739 .60603 m .39038 .54899 L .35922 .5464 L p .707 .577 .707 r
F P
0 g
s
.39038 .54899 m .38739 .60603 L .41917 .60724 L p .707 .577 .707 r
F P
0 g
s
.41917 .60724 m .42216 .5502 L .39038 .54899 L p .707 .577 .707 r
F P
0 g
s
.42216 .5502 m .41917 .60724 L .44847 .60695 L p .707 .577 .707 r
F P
0 g
s
.44847 .60695 m .45146 .54991 L .42216 .5502 L p .707 .577 .707 r
F P
0 g
s
.64196 .6186 m .64494 .56155 L .6612 .5585 L p .707 .577 .707 r
F P
0 g
s
.35624 .60345 m .35922 .5464 L .33175 .5427 L p .707 .577 .707 r
F P
0 g
s
.35922 .5464 m .35624 .60345 L .38739 .60603 L p .707 .577 .707 r
F P
0 g
s
.83513 .65492 m .83185 .69318 L .81903 .69045 L p .707 .577 .707 r
F P
0 g
s
.81903 .69045 m .82232 .65219 L .83513 .65492 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83066 .71048 m .82898 .72962 L .81615 .72703 L p .707 .577 .707 r
F P
0 g
s
.81615 .72703 m .81784 .70789 L .83066 .71048 L p .707 .577 .707 r
F P
0 g
s
.38458 .6546 m .38786 .61634 L .35674 .6133 L p .707 .577 .707 r
F P
0 g
s
.38786 .61634 m .38458 .6546 L .41627 .65713 L p .707 .577 .707 r
F P
0 g
s
.41627 .65713 m .41955 .61887 L .38786 .61634 L p .707 .577 .707 r
F P
0 g
s
.6612 .5585 m .65821 .61555 L .64196 .6186 L p .707 .577 .707 r
F P
0 g
s
.35674 .6133 m .35345 .65156 L .38458 .6546 L p .707 .577 .707 r
F P
0 g
s
.33175 .5427 m .32876 .59974 L .35624 .60345 L p .707 .577 .707 r
F P
0 g
s
.41955 .61887 m .41627 .65713 L .44543 .65891 L p .707 .577 .707 r
F P
0 g
s
.44543 .65891 m .44871 .62064 L .41955 .61887 L p .707 .577 .707 r
F P
0 g
s
.45146 .54991 m .44847 .60695 L .47242 .6052 L p .707 .577 .707 r
F P
0 g
s
.47242 .6052 m .47541 .54815 L .45146 .54991 L p .707 .577 .707 r
F P
0 g
s
.38179 .69004 m .38348 .67091 L .35236 .66784 L p .707 .577 .707 r
F P
0 g
s
.38348 .67091 m .38179 .69004 L .41347 .69267 L p .707 .577 .707 r
F P
0 g
s
.41347 .69267 m .41516 .67353 L .38348 .67091 L p .707 .577 .707 r
F P
0 g
s
.35236 .66784 m .35067 .68697 L .38179 .69004 L p .707 .577 .707 r
F P
0 g
s
.63853 .67603 m .64181 .63777 L .65787 .6376 L p .707 .577 .707 r
F P
0 g
s
.35345 .65156 m .35674 .6133 L .32923 .61004 L p .707 .577 .707 r
F P
0 g
s
.41516 .67353 m .41347 .69267 L .44262 .69458 L p .707 .577 .707 r
F P
0 g
s
.44262 .69458 m .4443 .67545 L .41516 .67353 L p .707 .577 .707 r
F P
0 g
s
.65787 .6376 m .65458 .67587 L .63853 .67603 L p .707 .577 .707 r
F P
0 g
s
.32923 .61004 m .32595 .64831 L .35345 .65156 L p .707 .577 .707 r
F P
0 g
s
.63569 .71209 m .63738 .69295 L .65341 .69298 L p .707 .577 .707 r
F P
0 g
s
.32876 .59974 m .33175 .5427 L .31064 .53823 L p .707 .577 .707 r
F P
0 g
s
.35067 .68697 m .35236 .66784 L .32485 .66462 L p .707 .577 .707 r
F P
0 g
s
.65341 .69298 m .65173 .71212 L .63569 .71209 L p .707 .577 .707 r
F P
0 g
s
.32485 .66462 m .32316 .68375 L .35067 .68697 L p .707 .577 .707 r
F P
0 g
s
.82597 .56843 m .82298 .62547 L .80187 .621 L p .707 .577 .707 r
F P
0 g
s
.80187 .621 m .80486 .56396 L .82597 .56843 L p .707 .577 .707 r
F P
0 g
s
.44871 .62064 m .44543 .65891 L .4692 .65975 L p .707 .577 .707 r
F P
0 g
s
.4692 .65975 m .47248 .62149 L .44871 .62064 L p .707 .577 .707 r
F P
0 g
s
.31064 .53823 m .30765 .59527 L .32876 .59974 L p .707 .577 .707 r
F P
0 g
s
.4443 .67545 m .44262 .69458 L .46637 .69561 L p .707 .577 .707 r
F P
0 g
s
.46637 .69561 m .46806 .67647 L .4443 .67545 L p .707 .577 .707 r
F P
0 g
s
.65821 .61555 m .6612 .5585 L .68515 .55675 L p .707 .577 .707 r
F P
0 g
s
.32595 .64831 m .32923 .61004 L .30803 .6069 L p .707 .577 .707 r
F P
0 g
s
.30803 .6069 m .30475 .64516 L .32595 .64831 L p .707 .577 .707 r
F P
0 g
s
.47541 .54815 m .47242 .6052 L .48868 .60214 L p .707 .577 .707 r
F P
0 g
s
.48868 .60214 m .49166 .5451 L .47541 .54815 L p .707 .577 .707 r
F P
0 g
s
.82232 .65219 m .81903 .69045 L .79783 .68731 L p .707 .577 .707 r
F P
0 g
s
.79783 .68731 m .80112 .64904 L .82232 .65219 L p .707 .577 .707 r
F P
0 g
s
.32316 .68375 m .32485 .66462 L .30364 .66156 L p .707 .577 .707 r
F P
0 g
s
.30364 .66156 m .30195 .6807 L .32316 .68375 L p .707 .577 .707 r
F P
0 g
s
.68515 .55675 m .68216 .61379 L .65821 .61555 L p .707 .577 .707 r
F P
0 g
s
.81784 .70789 m .81615 .72703 L .79494 .72397 L p .707 .577 .707 r
F P
0 g
s
.79494 .72397 m .79663 .70484 L .81784 .70789 L p .707 .577 .707 r
F P
0 g
s
.65458 .67587 m .65787 .6376 L .68164 .63844 L p .707 .577 .707 r
F P
0 g
s
.30765 .59527 m .31064 .53823 L .29796 .53343 L p .707 .577 .707 r
F P
0 g
s
.80486 .56396 m .80187 .621 L .7744 .61729 L p .707 .577 .707 r
F P
0 g
s
.7744 .61729 m .77738 .56025 L .80486 .56396 L p .707 .577 .707 r
F P
0 g
s
.68164 .63844 m .67835 .67671 L .65458 .67587 L p .707 .577 .707 r
F P
0 g
s
.47248 .62149 m .4692 .65975 L .48525 .65958 L p .707 .577 .707 r
F P
0 g
s
.48525 .65958 m .48853 .62132 L .47248 .62149 L p .707 .577 .707 r
F P
0 g
s
.65173 .71212 m .65341 .69298 L .67717 .69401 L p .707 .577 .707 r
F P
0 g
s
.67717 .69401 m .67548 .71314 L .65173 .71212 L p .707 .577 .707 r
F P
0 g
s
.46806 .67647 m .46637 .69561 L .48241 .69564 L p .707 .577 .707 r
F P
0 g
s
.48241 .69564 m .4841 .6765 L .46806 .67647 L p .707 .577 .707 r
F P
0 g
s
.68216 .61379 m .68515 .55675 L .71445 .55646 L p .707 .577 .707 r
F P
0 g
s
.29796 .53343 m .29498 .59048 L .30765 .59527 L p .707 .577 .707 r
F P
0 g
s
.30475 .64516 m .30803 .6069 L .29521 .60417 L p .707 .577 .707 r
F P
0 g
s
.29521 .60417 m .29193 .64243 L .30475 .64516 L p .707 .577 .707 r
F P
0 g
s
.80112 .64904 m .79783 .68731 L .77033 .68406 L p .707 .577 .707 r
F P
0 g
s
.77033 .68406 m .77361 .64579 L .80112 .64904 L p .707 .577 .707 r
F P
0 g
s
.71445 .55646 m .71146 .6135 L .68216 .61379 L p .707 .577 .707 r
F P
0 g
s
.30195 .6807 m .30364 .66156 L .29081 .65897 L p .707 .577 .707 r
F P
0 g
s
.77738 .56025 m .7744 .61729 L .74324 .61471 L p .707 .577 .707 r
F P
0 g
s
.74324 .61471 m .74623 .55767 L .77738 .56025 L p .707 .577 .707 r
F P
0 g
s
.29081 .65897 m .28912 .67811 L .30195 .6807 L p .707 .577 .707 r
F P
0 g
s
.49166 .5451 m .48868 .60214 L .49565 .5981 L p .707 .577 .707 r
F P
0 g
s
.49565 .5981 m .49863 .54105 L .49166 .5451 L p .707 .577 .707 r
F P
0 g
s
.79663 .70484 m .79494 .72397 L .76743 .72075 L p .707 .577 .707 r
F P
0 g
s
.76743 .72075 m .76912 .70162 L .79663 .70484 L p .707 .577 .707 r
F P
0 g
s
.71146 .6135 m .71445 .55646 L .74623 .55767 L p .707 .577 .707 r
F P
0 g
s
.67835 .67671 m .68164 .63844 L .71079 .64022 L p .707 .577 .707 r
F P
0 g
s
.71079 .64022 m .70751 .67848 L .67835 .67671 L p .707 .577 .707 r
F P
0 g
s
.74623 .55767 m .74324 .61471 L .71146 .6135 L p .707 .577 .707 r
F P
0 g
s
.67548 .71314 m .67717 .69401 L .70631 .69592 L p .707 .577 .707 r
F P
0 g
s
.70631 .69592 m .70463 .71506 L .67548 .71314 L p .707 .577 .707 r
F P
0 g
s
.29498 .59048 m .29796 .53343 L .29496 .52878 L p .707 .577 .707 r
F P
0 g
s
.77361 .64579 m .77033 .68406 L .7392 .68102 L p .707 .577 .707 r
F P
0 g
s
.7392 .68102 m .74249 .64275 L .77361 .64579 L p .707 .577 .707 r
F P
0 g
s
.48853 .62132 m .48525 .65958 L .49202 .65842 L p .707 .577 .707 r
F P
0 g
s
.49202 .65842 m .4953 .62015 L .48853 .62132 L p .707 .577 .707 r
F P
0 g
s
.70751 .67848 m .71079 .64022 L .74249 .64275 L p .707 .577 .707 r
F P
0 g
s
.76912 .70162 m .76743 .72075 L .73631 .71768 L p .707 .577 .707 r
F P
0 g
s
.73631 .71768 m .738 .69855 L .76912 .70162 L p .707 .577 .707 r
F P
0 g
s
.4841 .6765 m .48241 .69564 L .48916 .69467 L p .707 .577 .707 r
F P
0 g
s
.48916 .69467 m .49085 .67553 L .4841 .6765 L p .707 .577 .707 r
F P
0 g
s
.74249 .64275 m .7392 .68102 L .70751 .67848 L p .707 .577 .707 r
F P
0 g
s
.29496 .52878 m .29198 .58583 L .29498 .59048 L p .707 .577 .707 r
F P
0 g
s
.70463 .71506 m .70631 .69592 L .738 .69855 L p .707 .577 .707 r
F P
0 g
s
.738 .69855 m .73631 .71768 L .70463 .71506 L p .707 .577 .707 r
F P
0 g
s
.29193 .64243 m .29521 .60417 L .29203 .60212 L p .707 .577 .707 r
F P
0 g
s
.29203 .60212 m .28875 .64039 L .29193 .64243 L p .707 .577 .707 r
F P
0 g
s
.28912 .67811 m .29081 .65897 L .28761 .6571 L p .707 .577 .707 r
F P
0 g
s
.28761 .6571 m .28593 .67624 L .28912 .67811 L p .707 .577 .707 r
F P
0 g
s
.49863 .54105 m .49565 .5981 L .49265 .59345 L p .707 .577 .707 r
F P
0 g
s
.49265 .59345 m .49563 .53641 L .49863 .54105 L p .707 .577 .707 r
F P
0 g
s
.29198 .58583 m .29496 .52878 L .30193 .52474 L p .707 .577 .707 r
F P
0 g
s
.4953 .62015 m .49202 .65842 L .48884 .65637 L p .707 .577 .707 r
F P
0 g
s
.48884 .65637 m .49212 .6181 L .4953 .62015 L p .707 .577 .707 r
F P
0 g
s
.49085 .67553 m .48916 .69467 L .48597 .6928 L p .707 .577 .707 r
F P
0 g
s
.48597 .6928 m .48765 .67367 L .49085 .67553 L p .707 .577 .707 r
F P
0 g
s
.30193 .52474 m .29894 .58178 L .29198 .58583 L p .707 .577 .707 r
F P
0 g
s
.28875 .64039 m .29203 .60212 L .2988 .60095 L p .707 .577 .707 r
F P
0 g
s
.2988 .60095 m .29552 .63922 L .28875 .64039 L p .707 .577 .707 r
F P
0 g
s
.28593 .67624 m .28761 .6571 L .29436 .65614 L p .707 .577 .707 r
F P
0 g
s
.29436 .65614 m .29268 .67527 L .28593 .67624 L p .707 .577 .707 r
F P
0 g
s
.49563 .53641 m .49265 .59345 L .47997 .58866 L p .707 .577 .707 r
F P
0 g
s
.47997 .58866 m .48296 .53161 L .49563 .53641 L p .707 .577 .707 r
F P
0 g
s
.29894 .58178 m .30193 .52474 L .31819 .52169 L p .707 .577 .707 r
F P
0 g
s
.49212 .6181 m .48884 .65637 L .47602 .65364 L p .707 .577 .707 r
F P
0 g
s
.47602 .65364 m .47931 .61537 L .49212 .6181 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48765 .67367 m .48597 .6928 L .47314 .69021 L p .707 .577 .707 r
F P
0 g
s
.47314 .69021 m .47483 .67108 L .48765 .67367 L p .707 .577 .707 r
F P
0 g
s
.31819 .52169 m .3152 .57873 L .29894 .58178 L p .707 .577 .707 r
F P
0 g
s
.29552 .63922 m .2988 .60095 L .31486 .60078 L p .707 .577 .707 r
F P
0 g
s
.31486 .60078 m .31157 .63905 L .29552 .63922 L p .707 .577 .707 r
F P
0 g
s
.29268 .67527 m .29436 .65614 L .3104 .65617 L p .707 .577 .707 r
F P
0 g
s
.3104 .65617 m .30872 .6753 L .29268 .67527 L p .707 .577 .707 r
F P
0 g
s
.48296 .53161 m .47997 .58866 L .45886 .58419 L p .707 .577 .707 r
F P
0 g
s
.45886 .58419 m .46185 .52714 L .48296 .53161 L p .707 .577 .707 r
F P
0 g
s
.3152 .57873 m .31819 .52169 L .34214 .51993 L p .707 .577 .707 r
F P
0 g
s
.47931 .61537 m .47602 .65364 L .45482 .65049 L p .707 .577 .707 r
F P
0 g
s
.45482 .65049 m .45811 .61223 L .47931 .61537 L p .707 .577 .707 r
F P
0 g
s
.34214 .51993 m .33915 .57697 L .3152 .57873 L p .707 .577 .707 r
F P
0 g
s
.47483 .67108 m .47314 .69021 L .45193 .68716 L p .707 .577 .707 r
F P
0 g
s
.45193 .68716 m .45362 .66802 L .47483 .67108 L p .707 .577 .707 r
F P
0 g
s
.31157 .63905 m .31486 .60078 L .33863 .60163 L p .707 .577 .707 r
F P
0 g
s
.46185 .52714 m .45886 .58419 L .43139 .58048 L p .707 .577 .707 r
F P
0 g
s
.43139 .58048 m .43437 .52343 L .46185 .52714 L p .707 .577 .707 r
F P
0 g
s
.33863 .60163 m .33534 .63989 L .31157 .63905 L p .707 .577 .707 r
F P
0 g
s
.30872 .6753 m .3104 .65617 L .33416 .65719 L p .707 .577 .707 r
F P
0 g
s
.33416 .65719 m .33247 .67633 L .30872 .6753 L p .707 .577 .707 r
F P
0 g
s
.33915 .57697 m .34214 .51993 L .37144 .51964 L p .707 .577 .707 r
F P
0 g
s
.45811 .61223 m .45482 .65049 L .42732 .64724 L p .707 .577 .707 r
F P
0 g
s
.42732 .64724 m .4306 .60898 L .45811 .61223 L p .707 .577 .707 r
F P
0 g
s
.37144 .51964 m .36845 .57669 L .33915 .57697 L p .707 .577 .707 r
F P
0 g
s
.43437 .52343 m .43139 .58048 L .40023 .57789 L p .707 .577 .707 r
F P
0 g
s
.40023 .57789 m .40322 .52085 L .43437 .52343 L p .707 .577 .707 r
F P
0 g
s
.45362 .66802 m .45193 .68716 L .42442 .68394 L p .707 .577 .707 r
F P
0 g
s
.42442 .68394 m .42611 .6648 L .45362 .66802 L p .707 .577 .707 r
F P
0 g
s
.36845 .57669 m .37144 .51964 L .40322 .52085 L p .707 .577 .707 r
F P
0 g
s
.33534 .63989 m .33863 .60163 L .36778 .6034 L p .707 .577 .707 r
F P
0 g
s
.36778 .6034 m .3645 .64167 L .33534 .63989 L p .707 .577 .707 r
F P
0 g
s
.40322 .52085 m .40023 .57789 L .36845 .57669 L p .707 .577 .707 r
F P
0 g
s
.33247 .67633 m .33416 .65719 L .3633 .65911 L p .707 .577 .707 r
F P
0 g
s
.3633 .65911 m .36162 .67824 L .33247 .67633 L p .707 .577 .707 r
F P
0 g
s
.4306 .60898 m .42732 .64724 L .39619 .6442 L p .707 .577 .707 r
F P
0 g
s
.39619 .6442 m .39948 .60593 L .4306 .60898 L p .707 .577 .707 r
F P
0 g
s
.3645 .64167 m .36778 .6034 L .39948 .60593 L p .707 .577 .707 r
F P
0 g
s
.42611 .6648 m .42442 .68394 L .3933 .68087 L p .707 .577 .707 r
F P
0 g
s
.3933 .68087 m .39499 .66173 L .42611 .6648 L p .707 .577 .707 r
F P
0 g
s
.39948 .60593 m .39619 .6442 L .3645 .64167 L p .707 .577 .707 r
F P
0 g
s
.36162 .67824 m .3633 .65911 L .39499 .66173 L p .707 .577 .707 r
F P
0 g
s
.39499 .66173 m .3933 .68087 L .36162 .67824 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00O7oo4P00Sgoo001fOol60003FUH00`00FUIJEP0<FUH4002;
Ool0075oo`D000UJEP03001JEUYF011JEP@008Moo`00KWoo0`0000=JEP00FUH02eYF00<005YFFUH0
55YF0P00QGoo001/Ool20004FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20023
Ool006Uoo`<000IJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP80085oo`00Igoo
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH035YF0P00Ogoo001UOol3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001mOol006=oo`80
009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001oogoo07Yoo`00HGoo0P0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<007ooOol0NGoo001OOol20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomoo`1i
Ool005eoo`8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0007Yoo`00G7oo0P002UYF00<005YFFUH025YF00<005YFFUH02eYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH007Uoo`00Fgoo00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0007Qoo`00FWoo00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEWQoo`00FWoo
00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo07Eoo`00FGoo00<005YFFUH00UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0MGoo001HOol00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00Oomoo`1eOol005Moo`03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP8007Ioo`00Egoo00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00
EWoo0P001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00EWoo0P001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUIJEP8007Ioo`00EGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001f
Ool005Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1dOol005Ao
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007Eoo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2
001eOol005Eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001EOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Eoo`00EGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP04001JEUYFFUH2001eOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2001dOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00M7oo001EOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Aoo`00
EGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001dOol005Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00M7oo001FOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8007Aoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2001dOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
Oomoo`1bOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001cOol0
05Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Lgoo001FOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00EWoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001cOol005Moo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Lgoo001GOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00
Egoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001cOol005Moo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1aOol005Moo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo001GOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP80079oo`00Egoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH2001bOol005Moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo
001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80079oo`00F7oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH2001bOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000LWoo001HOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80075oo`00F7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001aOol005Qo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LGoo001IOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP80075oo`00FGoo00@005YFFUH000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH2001aOol005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00L7oo
001IOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80071oo`00FGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool005Uoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00L7oo001JOol01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP80071oo`00FWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool0
05Yoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000L7oo001JOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00FWoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001_Ool005Yoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Kgoo001KOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00
Fgoo00<005YFFUH040000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00F7oo1P000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF4@002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0KGoo001EOol30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00D005YFFUIJEP0006moo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006ioo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000UJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0K7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020009FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01@00FUIJEUYF0000KWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020009
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00002goo7P00AGoo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH8000m
Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P001Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEPL003Ioo`00Dgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04000bOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo001COol20002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`D000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0017oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005Ioo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00E7oo3@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00Oomoogoo001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP8002eoo`00Dgoo0P0015YF00@005YFFUIJEQ000003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000aJEP03001JEUYF00MJEP03001JEUYF00IJ
EP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eo
o`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF70000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP80009oo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo00<005YF000020001eYF00<005YF
FUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00<Goo1P00
0eYF00<005YFFUH01EYF00<005YFFUH00UYF300000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo0080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00=JEP8002ioo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
0003FUH0000002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<0
05YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH00008Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000h000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo
4`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000Aoo`00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ400003FUH0
05YF00IJEP04001JEUYFFUH6000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH2000017oo001JEP000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPd003Uoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF3`000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=goo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000EJEP00001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001oo`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP05000bOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEQ<000EJEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02@00FUIJEUYF001oo`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00003000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000UJ
EP03001JEUYF009JEQ80009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000<FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF3P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo
000/Ool20002FUHO0002FUHJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF6`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002mo
o`00;7oo1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2@000eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<005YF0000100000=JEP0000001P0015YF
00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00001EYF1`000eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP/000AJEP03001J
EP0000@0009JEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2000_Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF014000AJEP03001JEUYF00=JEPD0009JEP8000=JEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
15YF00@005YFFUIJEP800003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009J
EP8002moo`00;goo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00<000AJEP03
001JEUYF01<00003FUH0000000L000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUHJ
0006Ool@0003FUH01000FUIJEUYF1000;goo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH03UYF1P001UYF0P0000=JEP0000001`0025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000=Ool:000`Ool0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH5000<FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003moo`00@goo80000UYF00<005YFFUH01EYF
00<005YFFUH03eYF0`0015YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH025YF10001UYF
00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`00>7oo000]Ool@000UOol01000FUIJEP001eYF00<005YFFUH035YF0`00
1eYF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH035YF0P001EYF00D005YF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D003=oo`00;7oo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT001aoo`04001J
EUYF0007FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP0:FUH01000FUIJEUYF2`001eYF00@005YF
000000=JEP03001JEP00014000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000<002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@004goo00@005YFFUH000MJEP03001JEUYF00MJEP800003FUH005YF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF001JEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00@005YFFUIJEP8002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF3`0017oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP8000]JEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEPd0
00AJEP03001JEUYF00EJEQ4000=JEP03001JEUYF00=JEP03001JEUYF009JEP8002moo`00;7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P00
0eYF00<005YFFUH00eYF2`0015YF00<005YF000010000UYF00<005YFFUH015YF1P000eYF00@005YF
FUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF0P001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP0000000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000Woo2`000UYF00<005YF
FUH01EYF00<005YFFUH00UYF1@000UYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUH00006FUH20002FUH01@00FUIJEUYF00001UYF00<005YFFUH0
0UYF0`002Goo4P000eYF00<005YFFUH01000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF00006goo2P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP05FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP04001FOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001J
EUYF00AJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00@005YFFUIJEPH005Yoo`00:goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEUYFFUH0000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIoo`04
FUH01000FUIJEUYF2000H7oo000[OolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH2000;FUH2000;FUH00`00FUIJEP07FUH00`00OomJEP04FUH01000FUIJEP00Igoo000/Ool20000
0eYF001JEP04FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00gooFUH00009FUH00`00FUIJEP09FUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP02001VOol002ioo`@000=JEP03
001JEUYF00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP8000EJEP04001JEUYFFUH4001SOol0039oo`L000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03001JEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH5001NOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPD00003FUH00000009JEP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05001IOol0049ooa4000AJEP03001JEUYF00AJEP04001JEUYFFUH300001EYF
001JEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEP00
00<005Eoo`00Dgoo4P0000EJEP00FUIJEP0000IJEP03Ool005YF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol004Qoo`<001Uoo`<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol004Moo`D001Uoo`80009J
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001J
EUYF00MJEP03001JEUYF00AJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`T0
019oo`D001Uoo`03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00UJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP04001JEUYFFUH2001E
Ool002Yoo`<000AJEP04001JEUYFFUH@0002Ool5000IOol00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005Eoo`00:Woo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo00<005YFFUH00UYF00<005YF
FUH015YF00=oo`00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00
:Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF20003goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPH000Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03
001JEUYF009JEPH000AJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol002Yoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00P0009oo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF
0P00EWoo000ZOolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YF
FUH00UYF2@00EWoo000[Ool60003FUH00`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH02UYF00=oo`00FUH025YF00<005YFFUH02EYF00<005YF
FUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF6000EWoo000aOol70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<007ooOol0
K7oo000hOol90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P000goo
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF1000Kgoo0011Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
0003Ool01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH03eYF1@00Kgoo001:Ool@0003FUH01000FUIJEUYF100017oo00<005YF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF1@00Kgoo001J
Ool:0006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08001^Ool006]oo`80015JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP<000=JEP03001JEUYF009JEPP006Ioo`00KGoo0P001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEPL005mo
o`00Kgoo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH01EYF
0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00FWoo001aOol200000eYF001J
EP0EFUH00`00FUIJEP0:FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001FOol007=oo`<000UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEP0000/000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol007Ioo`@000EJEP03001JEUYF00UJEP03001JEUYF00MJEPD000AJEP03
001JEUYF00EJEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8005Ioo`00
NWoo100000=JEP00FUH02UYF00@005YFFUIJEP/000AJEP03001JEUYF00IJEP03001JEUYF00EJEPP0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2001GOol007iooa4000]oo`T000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000=JEP04001JEUYFFUH2001GOol00:=ooa4000AJEP03001JEUYF009JEPT0
05Moo`00]7oo4P00Egoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59423 .74459 m .59608 .68798 L .56491 .68566 L p .707 .577 .707 r
F P
0 g
s
.59608 .68798 m .59423 .74459 L .62605 .74504 L p .707 .577 .707 r
F P
0 g
s
.62605 .74504 m .6279 .68842 L .59608 .68798 L p .707 .577 .707 r
F P
0 g
s
.6279 .68842 m .62605 .74504 L .6554 .74356 L p .707 .577 .707 r
F P
0 g
s
.6554 .74356 m .65725 .68694 L .6279 .68842 L p .707 .577 .707 r
F P
0 g
s
.56307 .74227 m .56491 .68566 L .53745 .68169 L p .707 .577 .707 r
F P
0 g
s
.56491 .68566 m .56307 .74227 L .59423 .74459 L p .707 .577 .707 r
F P
0 g
s
.65725 .68694 m .6554 .74356 L .67941 .74031 L p .707 .577 .707 r
F P
0 g
s
.67941 .74031 m .68126 .68369 L .65725 .68694 L p .707 .577 .707 r
F P
0 g
s
.59234 .80394 m .59438 .7659 L .56323 .7633 L p .707 .577 .707 r
F P
0 g
s
.59438 .7659 m .59234 .80394 L .62412 .8052 L p .707 .577 .707 r
F P
0 g
s
.62412 .8052 m .62616 .76715 L .59438 .7659 L p .707 .577 .707 r
F P
0 g
s
.53745 .68169 m .5356 .7383 L .56307 .74227 L p .707 .577 .707 r
F P
0 g
s
.62616 .76715 m .62412 .8052 L .65342 .80498 L p .707 .577 .707 r
F P
0 g
s
.65342 .80498 m .65546 .76694 L .62616 .76715 L p .707 .577 .707 r
F P
0 g
s
.5356 .7383 m .53745 .68169 L .51637 .67645 L p .707 .577 .707 r
F P
0 g
s
.56323 .7633 m .56119 .80134 L .59234 .80394 L p .707 .577 .707 r
F P
0 g
s
.56119 .80134 m .56323 .7633 L .53575 .7596 L p .707 .577 .707 r
F P
0 g
s
.49099 .84163 m .45509 .37253 L .41113 .37108 L p .707 .577 .707 r
F P
0 g
s
.51637 .67645 m .51452 .73307 L .5356 .7383 L p .707 .577 .707 r
F P
0 g
s
.55946 .84894 m .56051 .82991 L .53303 .82624 L p .707 .577 .707 r
F P
0 g
s
.53303 .82624 m .53198 .84527 L .55946 .84894 L p .707 .577 .707 r
F P
0 g
s
.53371 .79765 m .53575 .7596 L .51464 .75518 L p .707 .577 .707 r
F P
0 g
s
.51464 .75518 m .5126 .79323 L .53371 .79765 L p .707 .577 .707 r
F P
0 g
s
.51452 .73307 m .51637 .67645 L .50375 .67047 L p .707 .577 .707 r
F P
0 g
s
.53198 .84527 m .53303 .82624 L .51192 .82187 L p .707 .577 .707 r
F P
0 g
s
.51192 .82187 m .51087 .8409 L .53198 .84527 L p .707 .577 .707 r
F P
0 g
s
.50375 .67047 m .5019 .72709 L .51452 .73307 L p .707 .577 .707 r
F P
0 g
s
.5126 .79323 m .51464 .75518 L .50196 .75047 L p .707 .577 .707 r
F P
0 g
s
.50196 .75047 m .49992 .78851 L .5126 .79323 L p .707 .577 .707 r
F P
0 g
s
.5019 .72709 m .50375 .67047 L .50081 .66432 L p .707 .577 .707 r
F P
0 g
s
.51087 .8409 m .51192 .82187 L .49923 .81724 L p .707 .577 .707 r
F P
0 g
s
.49923 .81724 m .49819 .83627 L .51087 .8409 L p .707 .577 .707 r
F P
0 g
s
.50081 .66432 m .49896 .72094 L .5019 .72709 L p .707 .577 .707 r
F P
0 g
s
.49992 .78851 m .50196 .75047 L .49896 .74591 L p .707 .577 .707 r
F P
0 g
s
.49896 .74591 m .49692 .78396 L .49992 .78851 L p .707 .577 .707 r
F P
0 g
s
.49819 .83627 m .49923 .81724 L .49622 .8128 L p .707 .577 .707 r
F P
0 g
s
.49896 .72094 m .50081 .66432 L .50785 .65861 L p .707 .577 .707 r
F P
0 g
s
.49622 .8128 m .49517 .83183 L .49819 .83627 L p .707 .577 .707 r
F P
0 g
s
.50785 .65861 m .506 .71523 L .49896 .72094 L p .707 .577 .707 r
F P
0 g
s
.49692 .78396 m .49896 .74591 L .50592 .74197 L p .707 .577 .707 r
F P
0 g
s
.50592 .74197 m .50388 .78002 L .49692 .78396 L p .707 .577 .707 r
F P
0 g
s
.49517 .83183 m .49622 .8128 L .50318 .80898 L p .707 .577 .707 r
F P
0 g
s
.506 .71523 m .50785 .65861 L .52418 .6539 L p .707 .577 .707 r
F P
0 g
s
.50318 .80898 m .50213 .82801 L .49517 .83183 L p .707 .577 .707 r
F P
0 g
s
.52418 .6539 m .52233 .71052 L .506 .71523 L p .707 .577 .707 r
F P
0 g
s
.50388 .78002 m .50592 .74197 L .52217 .73903 L p .707 .577 .707 r
F P
0 g
s
.52217 .73903 m .52013 .77707 L .50388 .78002 L p .707 .577 .707 r
F P
0 g
s
.50213 .82801 m .50318 .80898 L .51942 .80616 L p .707 .577 .707 r
F P
0 g
s
.51942 .80616 m .51837 .82519 L .50213 .82801 L p .707 .577 .707 r
F P
0 g
s
.52013 .77707 m .52217 .73903 L .54612 .73737 L p .707 .577 .707 r
F P
0 g
s
.53575 .7596 m .53371 .79765 L .56119 .80134 L p .707 .577 .707 r
F P
0 g
s
.54612 .73737 m .54408 .77541 L .52013 .77707 L p .707 .577 .707 r
F P
0 g
s
.51837 .82519 m .51942 .80616 L .54336 .80461 L p .707 .577 .707 r
F P
0 g
s
.54336 .80461 m .54231 .82364 L .51837 .82519 L p .707 .577 .707 r
F P
0 g
s
.45509 .37253 m .49099 .84163 L .5358 .83696 L p .707 .577 .707 r
F P
0 g
s
.52233 .71052 m .52418 .6539 L .52632 .65361 L p .707 .577 .707 r
F P
0 g
s
.59061 .85156 m .59166 .83253 L .56051 .82991 L p .707 .577 .707 r
F P
0 g
s
.56051 .82991 m .55946 .84894 L .59061 .85156 L p .707 .577 .707 r
F P
0 g
s
.5847 .69075 m .58798 .65242 L .60936 .64961 L .707 .577 .707 r
F
.57851 .64918 m .60936 .64961 L p .57739 .65381 L F P
0 g
s
.64052 .65193 m .63867 .70855 L .60954 .70638 L p .707 .577 .707 r
F P
0 g
s
.60954 .70638 m .60751 .70623 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60951 .70294 m .64052 .65193 L .60954 .70638 L .707 .577 .707 r
F
.60936 .64961 m .64052 .65193 L p .60951 .70294 L F P
0 g
s
.60751 .70623 m .60909 .65788 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60909 .65788 m .60936 .64961 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.65546 .76694 m .65342 .80498 L .67737 .80333 L p .707 .577 .707 r
F P
0 g
s
.67737 .80333 m .6794 .76528 L .65546 .76694 L p .707 .577 .707 r
F P
0 g
s
.66582 .74471 m .66378 .78275 L .65334 .78135 L p .707 .577 .707 r
F P
0 g
s
.65334 .78135 m .63631 .77906 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.65133 .76157 m .66582 .74471 L .65334 .78135 L .707 .577 .707 r
F
.63631 .77906 m .63835 .74102 L .6494 .7425 L p F P
0 g
s
.6494 .7425 m .66582 .74471 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.63631 .77906 m .6494 .7425 L .65133 .76157 L .707 .577 .707 r
F
.60741 .30478 m .60585 .30792 L p .60794 .33385 L F P
0 g
s
.64331 .77388 m .60741 .30478 L .60794 .33385 L .707 .577 .707 r
F
.60585 .30792 m .5977 .32437 L p .60684 .41447 L F P
0 g
s
.64331 .77388 m .60585 .30792 L .60684 .41447 L .707 .577 .707 r
F
.60306 .28571 m .60741 .30478 L p .61283 .38218 L F P
0 g
s
.63835 .74102 m .63631 .77906 L .61015 .77687 L p .707 .577 .707 r
F P
0 g
s
.61017 .7711 m .63835 .74102 L .61015 .77687 L .707 .577 .707 r
F
.60515 .77646 m .60719 .73841 L .61029 .73867 L p F P
0 g
s
.61029 .73867 m .63835 .74102 L p .61017 .7711 L .707 .577 .707 r
F P
0 g
s
.60515 .77646 m .61029 .73867 L .61017 .7711 L .707 .577 .707 r
F
.60715 .44787 m .61115 .50016 L p .60684 .41447 L F P
0 g
s
.61115 .50016 m .63359 .79346 L p .61123 .47672 L .707 .577 .707 r
F P
0 g
s
.60684 .41447 m .61115 .50016 L .61123 .47672 L .707 .577 .707 r
F
.63359 .79346 m .64331 .77388 L p .6113 .45843 L F P
0 g
s
.6113 .45843 m .60684 .41447 L .61123 .47672 L .707 .577 .707 r
F
.6113 .45843 m .61123 .47672 L .63359 .79346 L F
.61015 .77687 m .60515 .77646 L p .61017 .7711 L F P
0 g
s
.63896 .75481 m .60311 .2863 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60311 .2863 m .60306 .28571 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.64331 .77388 m .63896 .75481 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60741 .30478 m .61486 .4021 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.61486 .4021 m .64331 .77388 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.5977 .32437 m .60715 .44787 L p .60684 .41447 L .707 .577 .707 r
F P
0 g
s
.60936 .64961 m .60751 .70623 L .57569 .70578 L p .707 .577 .707 r
F P
0 g
s
.60338 .82483 m .60443 .8058 L .63558 .80842 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .63359 .79346 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57487 .34254 m .59357 .58692 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .57541 .73716 L .58182 .73741 L p .707 .577 .707 r
F P
0 g
s
.58182 .73741 m .60719 .73841 L p .578 .77017 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .58182 .73741 L .578 .77017 L .707 .577 .707 r
F
.59357 .58692 m .59587 .61687 L p .59877 .52608 L F P
0 g
s
.60719 .73841 m .60515 .77646 L .57337 .7752 L p .707 .577 .707 r
F P
0 g
s
.59587 .61687 m .61077 .81164 L p .60081 .57448 L .707 .577 .707 r
F P
0 g
s
.59877 .52608 m .59587 .61687 L .60081 .57448 L .707 .577 .707 r
F
.57569 .70578 m .57739 .65381 L p .58798 .65242 L F P
0 g
s
.57569 .70578 m .58798 .65242 L .5847 .69075 L .707 .577 .707 r
F
.58302 .63055 m .54118 .35753 L .57739 .65381 L F
.57739 .65381 m .57754 .64917 L .57851 .64918 L p F P
0 g
s
.54118 .35753 m .56611 .6833 L p .57739 .65381 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .58302 .63055 L .57739 .65381 L .707 .577 .707 r
F
.5716 .82352 m .57265 .80449 L .60443 .8058 L p F P
0 g
s
.60443 .8058 m .60338 .82483 L .5716 .82352 L p .707 .577 .707 r
F P
0 g
s
.57707 .82662 m .61077 .81164 L p .58396 .63667 L .707 .577 .707 r
F P
0 g
s
.57569 .70578 m .55714 .70672 L p .56338 .69042 L .707 .577 .707 r
F P
0 g
s
.54634 .70726 m .55859 .68445 L .56338 .69042 L .707 .577 .707 r
F
.55714 .70672 m .54634 .70726 L p .56338 .69042 L F P
0 g
s
.57648 .68171 m .57569 .70578 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.54118 .35753 m .4999 .36786 L p .55329 .68527 L .707 .577 .707 r
F P
0 g
s
.5557 .6849 m .54118 .35753 L .55329 .68527 L .707 .577 .707 r
F
.54634 .70726 m .54703 .68623 L p .55859 .68445 L F P
0 g
s
.56971 .73036 m .54118 .35753 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .57754 .64917 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.55329 .68527 m .4999 .36786 L .54703 .68623 L .707 .577 .707 r
F
.54703 .68623 m .54819 .65065 L p .55859 .68445 L F P
0 g
s
.55658 .70482 m .5557 .6849 L .55329 .68527 L .707 .577 .707 r
F
.54408 .77541 m .5458 .74331 L p .57541 .73716 L F P
0 g
s
.5458 .74331 m .54612 .73737 L .5486 .73735 L p .707 .577 .707 r
F P
0 g
s
.5486 .73735 m .57541 .73716 L p .5458 .74331 L .707 .577 .707 r
F P
0 g
s
.57754 .64917 m .57739 .65381 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.57739 .65381 m .57648 .68171 L p .56611 .6833 L .707 .577 .707 r
F P
0 g
s
.55859 .68445 m .57739 .65381 L .56611 .6833 L .707 .577 .707 r
F
.56611 .6833 m .56721 .69773 L p .58396 .63667 L F P
0 g
s
.57541 .73716 m .57337 .7752 L .54408 .77541 L p .707 .577 .707 r
F P
0 g
s
.56721 .69773 m .57707 .82662 L p .58296 .66421 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .56721 .69773 L .58296 .66421 L .707 .577 .707 r
F
.57707 .82662 m .56971 .73036 L p .55658 .70482 L F P
0 g
s
.54634 .70726 m .52233 .71052 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .52028 .63418 L p .54703 .68623 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .54703 .68623 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.54703 .68623 m .54634 .70726 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.55658 .70482 m .55329 .68527 L .54703 .68623 L .707 .577 .707 r
F
.54231 .82364 m .54336 .80461 L .57265 .80449 L p F P
0 g
s
.57265 .80449 m .5716 .82352 L .54231 .82364 L p .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .57707 .82662 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.52632 .65361 m .53001 .65311 L p .53493 .68135 L .707 .577 .707 r
F P
0 g
s
.53493 .68135 m .53001 .65311 L .53931 .67121 L .707 .577 .707 r
F
.52233 .71052 m .52632 .65361 L .53493 .68135 L F
.52028 .63418 m .5358 .83696 L p .55658 .70482 L F P
0 g
s
.53001 .65311 m .54819 .65065 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .45509 .37253 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .52028 .63418 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.52028 .63418 m .4999 .36786 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.59166 .83253 m .59061 .85156 L .62239 .85287 L p .707 .577 .707 r
F P
0 g
s
.62239 .85287 m .62344 .83384 L .59166 .83253 L p .707 .577 .707 r
F P
0 g
s
.62344 .83384 m .62239 .85287 L .65168 .85275 L p .707 .577 .707 r
F P
0 g
s
.65168 .85275 m .65273 .83372 L .62344 .83384 L p .707 .577 .707 r
F P
0 g
s
.44702 .84018 m .41113 .37108 L .37232 .36365 L p .707 .577 .707 r
F P
0 g
s
.41113 .37108 m .44702 .84018 L .49099 .84163 L p .707 .577 .707 r
F P
0 g
s
.68126 .68369 m .67941 .74031 L .69574 .73559 L p .707 .577 .707 r
F P
0 g
s
.69574 .73559 m .69759 .67898 L .68126 .68369 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .57487 .34254 L .54118 .35753 L p .707 .577 .707 r
F P
0 g
s
.65273 .83372 m .65168 .85275 L .67562 .8512 L p .707 .577 .707 r
F P
0 g
s
.67562 .8512 m .67667 .83217 L .65273 .83372 L p .707 .577 .707 r
F P
0 g
s
.6794 .76528 m .67737 .80333 L .69361 .80038 L p .707 .577 .707 r
F P
0 g
s
.69361 .80038 m .69565 .76234 L .6794 .76528 L p .707 .577 .707 r
F P
0 g
s
.40821 .83275 m .37232 .36365 L .34246 .35097 L p .707 .577 .707 r
F P
0 g
s
.37232 .36365 m .40821 .83275 L .44702 .84018 L p .707 .577 .707 r
F P
0 g
s
.69759 .67898 m .69574 .73559 L .70277 .72988 L p .707 .577 .707 r
F P
0 g
s
.70277 .72988 m .70462 .67327 L .69759 .67898 L p .707 .577 .707 r
F P
0 g
s
.67667 .83217 m .67562 .8512 L .69186 .84838 L p .707 .577 .707 r
F P
0 g
s
.69186 .84838 m .69291 .82935 L .67667 .83217 L p .707 .577 .707 r
F P
0 g
s
.63359 .79346 m .5977 .32437 L .57487 .34254 L p .707 .577 .707 r
F P
0 g
s
.69565 .76234 m .69361 .80038 L .70058 .79644 L p .707 .577 .707 r
F P
0 g
s
.70058 .79644 m .70262 .7584 L .69565 .76234 L p .707 .577 .707 r
F P
0 g
s
.35977 .69307 m .36162 .63645 L .35458 .64216 L p .707 .577 .707 r
F P
0 g
s
.35458 .64216 m .35273 .69878 L .35977 .69307 L p .707 .577 .707 r
F P
0 g
s
.36162 .63645 m .35977 .69307 L .35683 .68692 L p .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35752 .66589 L p .36162 .63645 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .32448 .33427 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.36284 .61728 m .34246 .35097 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.3609 .63496 m .36162 .63645 L p .35752 .66589 L .707 .577 .707 r
F P
0 g
s
.33825 .64687 m .3364 .70349 L .35273 .69878 L p .707 .577 .707 r
F P
0 g
s
.35273 .69878 m .35458 .64216 L .33825 .64687 L p .707 .577 .707 r
F P
0 g
s
.35265 .72552 m .35061 .76357 L .35757 .75963 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35961 .72158 L .35265 .72552 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35456 .75507 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35961 .72158 m .35904 .73221 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35904 .73221 m .35757 .75963 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .37836 .82006 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.32448 .33427 m .3494 .66004 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35219 .68472 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35683 .68692 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35219 .68472 m .34421 .68094 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.34962 .66199 m .35868 .63031 L .35219 .68472 L .707 .577 .707 r
F
.3566 .71703 m .35961 .72158 L p .35835 .72991 L F P
0 g
s
.35456 .75507 m .35628 .72297 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35628 .72297 m .3566 .71703 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.3364 .72847 m .33436 .76651 L .35061 .76357 L p .707 .577 .707 r
F P
0 g
s
.35061 .76357 m .35265 .72552 L .3364 .72847 L p .707 .577 .707 r
F P
0 g
s
.3566 .71703 m .35456 .75507 L .34188 .75036 L p .707 .577 .707 r
F P
0 g
s
.34188 .75036 m .34392 .71231 L .3566 .71703 L p .707 .577 .707 r
F P
0 g
s
.35602 .78429 m .36037 .80337 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34799 .6475 m .32448 .33427 L .34624 .63197 L .707 .577 .707 r
F
.34421 .68094 m .3459 .62897 L p .34962 .66199 L F P
0 g
s
.35351 .71365 m .32448 .33427 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34606 .62432 m .35868 .63031 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.32013 .3152 m .33883 .55958 L p .34624 .63197 L .707 .577 .707 r
F P
0 g
s
.31424 .65013 m .31239 .70674 L .3364 .70349 L p .707 .577 .707 r
F P
0 g
s
.3364 .70349 m .33825 .64687 L .31424 .65013 L p .707 .577 .707 r
F P
0 g
s
.34421 .68094 m .3391 .67967 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3391 .67967 m .32313 .67571 L p .33901 .64012 L .707 .577 .707 r
F P
0 g
s
.33901 .64012 m .34555 .62546 L .3391 .67967 L .707 .577 .707 r
F
.32448 .33427 m .32013 .3152 L p .34624 .63197 L F P
0 g
s
.32013 .3152 m .32984 .29562 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34421 .68094 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.34624 .63197 m .33883 .55958 L .3459 .62897 L .707 .577 .707 r
F
.32313 .67571 m .32498 .61909 L .34541 .62416 L p F P
0 g
s
.34541 .62416 m .34606 .62432 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.32313 .67571 m .34541 .62416 L .34555 .62546 L .707 .577 .707 r
F
.3404 .58009 m .34962 .7006 L p .34627 .63258 L F P
0 g
s
.34624 .63197 m .3459 .62897 L .34627 .63258 L .707 .577 .707 r
F
.3459 .62897 m .3404 .58009 L .34627 .63258 L F
.33883 .55958 m .3404 .58009 L p .3459 .62897 L F P
0 g
s
.34606 .62432 m .3459 .62897 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34606 .62432 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.35277 .71118 m .34624 .63197 L .34962 .7006 L .707 .577 .707 r
F
.34962 .7006 m .35602 .78429 L p .35277 .71118 L F P
0 g
s
.35277 .71118 m .34799 .6475 L .34624 .63197 L .707 .577 .707 r
F
.35602 .78429 m .33883 .55958 L p .3386 .4592 L F P
0 g
s
.33883 .55958 m .32013 .3152 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3494 .66004 m .36037 .80337 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35868 .63031 m .35752 .66589 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .35351 .71365 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35868 .63031 L .3609 .63496 L p .707 .577 .707 r
F P
0 g
s
.37836 .82006 m .36284 .61728 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .37836 .82006 L .40821 .83275 L p .707 .577 .707 r
F P
0 g
s
.69291 .82935 m .69186 .84838 L .69882 .84456 L p .707 .577 .707 r
F P
0 g
s
.69882 .84456 m .69987 .82553 L .69291 .82935 L p .707 .577 .707 r
F P
0 g
s
.70462 .67327 m .70277 .72988 L .69984 .72374 L p .707 .577 .707 r
F P
0 g
s
.69984 .72374 m .70169 .66712 L .70462 .67327 L p .707 .577 .707 r
F P
0 g
s
.70262 .7584 m .70058 .79644 L .69757 .79189 L p .707 .577 .707 r
F P
0 g
s
.69757 .79189 m .69961 .75385 L .70262 .7584 L p .707 .577 .707 r
F P
0 g
s
.69987 .82553 m .69882 .84456 L .69581 .84012 L p .707 .577 .707 r
F P
0 g
s
.69581 .84012 m .69686 .82109 L .69987 .82553 L p .707 .577 .707 r
F P
0 g
s
.70169 .66712 m .69984 .72374 L .68722 .71775 L p .707 .577 .707 r
F P
0 g
s
.68722 .71775 m .68907 .66114 L .70169 .66712 L p .707 .577 .707 r
F P
0 g
s
.25122 .70778 m .25307 .65116 L .22191 .64884 L p .707 .577 .707 r
F P
0 g
s
.25307 .65116 m .25122 .70778 L .28304 .70822 L p .707 .577 .707 r
F P
0 g
s
.28304 .70822 m .28489 .65161 L .25307 .65116 L p .707 .577 .707 r
F P
0 g
s
.28489 .65161 m .28304 .70822 L .31239 .70674 L p .707 .577 .707 r
F P
0 g
s
.31239 .70674 m .31424 .65013 L .28489 .65161 L p .707 .577 .707 r
F P
0 g
s
.22006 .70546 m .22191 .64884 L .19444 .64487 L p .707 .577 .707 r
F P
0 g
s
.22191 .64884 m .22006 .70546 L .25122 .70778 L p .707 .577 .707 r
F P
0 g
s
.69961 .75385 m .69757 .79189 L .68489 .78717 L p .707 .577 .707 r
F P
0 g
s
.68489 .78717 m .68693 .74913 L .69961 .75385 L p .707 .577 .707 r
F P
0 g
s
.24934 .76713 m .25138 .72908 L .22022 .72648 L p .707 .577 .707 r
F P
0 g
s
.25138 .72908 m .24934 .76713 L .28112 .76838 L p .707 .577 .707 r
F P
0 g
s
.28112 .76838 m .28316 .73034 L .25138 .72908 L p .707 .577 .707 r
F P
0 g
s
.19444 .64487 m .19259 .70149 L .22006 .70546 L p .707 .577 .707 r
F P
0 g
s
.28316 .73034 m .28112 .76838 L .31041 .76817 L p .707 .577 .707 r
F P
0 g
s
.31041 .76817 m .31245 .73013 L .28316 .73034 L p .707 .577 .707 r
F P
0 g
s
.68907 .66114 m .68722 .71775 L .66614 .71252 L p .707 .577 .707 r
F P
0 g
s
.66614 .71252 m .66799 .6559 L .68907 .66114 L p .707 .577 .707 r
F P
0 g
s
.19259 .70149 m .19444 .64487 L .17337 .63964 L p .707 .577 .707 r
F P
0 g
s
.22022 .72648 m .21818 .76452 L .24934 .76713 L p .707 .577 .707 r
F P
0 g
s
.69686 .82109 m .69581 .84012 L .68312 .83549 L p .707 .577 .707 r
F P
0 g
s
.68312 .83549 m .68417 .81646 L .69686 .82109 L p .707 .577 .707 r
F P
0 g
s
.21818 .76452 m .22022 .72648 L .19274 .72279 L p .707 .577 .707 r
F P
0 g
s
.2476 .81474 m .24865 .79571 L .2175 .79309 L p .707 .577 .707 r
F P
0 g
s
.24865 .79571 m .2476 .81474 L .27938 .81606 L p .707 .577 .707 r
F P
0 g
s
.27938 .81606 m .28043 .79703 L .24865 .79571 L p .707 .577 .707 r
F P
0 g
s
.19274 .72279 m .19071 .76083 L .21818 .76452 L p .707 .577 .707 r
F P
0 g
s
.2175 .79309 m .21645 .81212 L .2476 .81474 L p .707 .577 .707 r
F P
0 g
s
.28043 .79703 m .27938 .81606 L .30867 .81593 L p .707 .577 .707 r
F P
0 g
s
.30867 .81593 m .30972 .7969 L .28043 .79703 L p .707 .577 .707 r
F P
0 g
s
.31245 .73013 m .31041 .76817 L .33436 .76651 L p .707 .577 .707 r
F P
0 g
s
.33436 .76651 m .3364 .72847 L .31245 .73013 L p .707 .577 .707 r
F P
0 g
s
.17337 .63964 m .17152 .69625 L .19259 .70149 L p .707 .577 .707 r
F P
0 g
s
.21645 .81212 m .2175 .79309 L .19002 .78942 L p .707 .577 .707 r
F P
0 g
s
.19002 .78942 m .18897 .80845 L .21645 .81212 L p .707 .577 .707 r
F P
0 g
s
.19071 .76083 m .19274 .72279 L .17163 .71837 L p .707 .577 .707 r
F P
0 g
s
.68693 .74913 m .68489 .78717 L .66378 .78275 L p .707 .577 .707 r
F P
0 g
s
.66378 .78275 m .66582 .74471 L .68693 .74913 L p .707 .577 .707 r
F P
0 g
s
.30972 .7969 m .30867 .81593 L .33261 .81438 L p .707 .577 .707 r
F P
0 g
s
.33261 .81438 m .33366 .79535 L .30972 .7969 L p .707 .577 .707 r
F P
0 g
s
.17163 .71837 m .16959 .75641 L .19071 .76083 L p .707 .577 .707 r
F P
0 g
s
.66799 .6559 m .66614 .71252 L .63867 .70855 L p .707 .577 .707 r
F P
0 g
s
.63867 .70855 m .64052 .65193 L .66799 .6559 L p .707 .577 .707 r
F P
0 g
s
.17152 .69625 m .17337 .63964 L .16074 .63365 L p .707 .577 .707 r
F P
0 g
s
.18897 .80845 m .19002 .78942 L .16891 .78506 L p .707 .577 .707 r
F P
0 g
s
.60306 .28571 m .63896 .75481 L .62097 .73811 L p .707 .577 .707 r
F P
0 g
s
.62097 .73811 m .58508 .26902 L .60306 .28571 L p .707 .577 .707 r
F P
0 g
s
.68417 .81646 m .68312 .83549 L .66201 .83112 L p .707 .577 .707 r
F P
0 g
s
.66201 .83112 m .66306 .81209 L .68417 .81646 L p .707 .577 .707 r
F P
0 g
s
.16891 .78506 m .16786 .80409 L .18897 .80845 L p .707 .577 .707 r
F P
0 g
s
.16074 .63365 m .15889 .69027 L .17152 .69625 L p .707 .577 .707 r
F P
0 g
s
.16959 .75641 m .17163 .71837 L .15896 .71365 L p .707 .577 .707 r
F P
0 g
s
.33366 .79535 m .33261 .81438 L .34885 .81156 L p .707 .577 .707 r
F P
0 g
s
.34885 .81156 m .3499 .79253 L .33366 .79535 L p .707 .577 .707 r
F P
0 g
s
.15896 .71365 m .15692 .75169 L .16959 .75641 L p .707 .577 .707 r
F P
0 g
s
.15889 .69027 m .16074 .63365 L .15781 .62751 L p .707 .577 .707 r
F P
0 g
s
.16786 .80409 m .16891 .78506 L .15622 .78043 L p .707 .577 .707 r
F P
0 g
s
.36574 .76471 m .32984 .29562 L .35266 .27744 L p .707 .577 .707 r
F P
0 g
s
.32984 .29562 m .36574 .76471 L .35602 .78429 L p .707 .577 .707 r
F P
0 g
s
.66306 .81209 m .66201 .83112 L .63453 .82745 L p .707 .577 .707 r
F P
0 g
s
.63453 .82745 m .63558 .80842 L .66306 .81209 L p .707 .577 .707 r
F P
0 g
s
.15622 .78043 m .15518 .79946 L .16786 .80409 L p .707 .577 .707 r
F P
0 g
s
.15781 .62751 m .15596 .68412 L .15889 .69027 L p .707 .577 .707 r
F P
0 g
s
.58508 .26902 m .62097 .73811 L .59112 .72543 L p .707 .577 .707 r
F P
0 g
s
.59112 .72543 m .55522 .25633 L .58508 .26902 L p .707 .577 .707 r
F P
0 g
s
.63558 .80842 m .63453 .82745 L .60338 .82483 L p .707 .577 .707 r
F P
0 g
s
.15692 .75169 m .15896 .71365 L .15595 .7091 L p .707 .577 .707 r
F P
0 g
s
.3499 .79253 m .34885 .81156 L .35581 .80774 L p .707 .577 .707 r
F P
0 g
s
.35581 .80774 m .35686 .78871 L .3499 .79253 L p .707 .577 .707 r
F P
0 g
s
.15595 .7091 m .15391 .74714 L .15692 .75169 L p .707 .577 .707 r
F P
0 g
s
.15518 .79946 m .15622 .78043 L .15321 .77599 L p .707 .577 .707 r
F P
0 g
s
.15596 .68412 m .15781 .62751 L .16484 .6218 L p .707 .577 .707 r
F P
0 g
s
.15321 .77599 m .15217 .79502 L .15518 .79946 L p .707 .577 .707 r
F P
0 g
s
.35266 .27744 m .38856 .74654 L .36574 .76471 L p .707 .577 .707 r
F P
0 g
s
.38856 .74654 m .35266 .27744 L .38636 .26245 L p .707 .577 .707 r
F P
0 g
s
.16484 .6218 m .16299 .67841 L .15596 .68412 L p .707 .577 .707 r
F P
0 g
s
.55522 .25633 m .59112 .72543 L .55231 .71799 L p .707 .577 .707 r
F P
0 g
s
.55231 .71799 m .51641 .2489 L .55522 .25633 L p .707 .577 .707 r
F P
0 g
s
.15391 .74714 m .15595 .7091 L .16291 .70516 L p .707 .577 .707 r
F P
0 g
s
.35686 .78871 m .35581 .80774 L .3528 .8033 L p .707 .577 .707 r
F P
0 g
s
.3528 .8033 m .35385 .78427 L .35686 .78871 L p .707 .577 .707 r
F P
0 g
s
.16291 .70516 m .16087 .7432 L .15391 .74714 L p .707 .577 .707 r
F P
0 g
s
.15217 .79502 m .15321 .77599 L .16017 .77217 L p .707 .577 .707 r
F P
0 g
s
.42226 .73155 m .38636 .26245 L .42763 .25212 L p .707 .577 .707 r
F P
0 g
s
.38636 .26245 m .42226 .73155 L .38856 .74654 L p .707 .577 .707 r
F P
0 g
s
.16299 .67841 m .16484 .6218 L .18117 .61709 L p .707 .577 .707 r
F P
0 g
s
.16017 .77217 m .15912 .7912 L .15217 .79502 L p .707 .577 .707 r
F P
0 g
s
.51641 .2489 m .55231 .71799 L .50834 .71654 L p .707 .577 .707 r
F P
0 g
s
.50834 .71654 m .47245 .24745 L .51641 .2489 L p .707 .577 .707 r
F P
0 g
s
.18117 .61709 m .17932 .6737 L .16299 .67841 L p .707 .577 .707 r
F P
0 g
s
.46353 .72121 m .42763 .25212 L .47245 .24745 L p .707 .577 .707 r
F P
0 g
s
.42763 .25212 m .46353 .72121 L .42226 .73155 L p .707 .577 .707 r
F P
0 g
s
.47245 .24745 m .50834 .71654 L .46353 .72121 L p .707 .577 .707 r
F P
0 g
s
.16087 .7432 m .16291 .70516 L .17916 .70221 L p .707 .577 .707 r
F P
0 g
s
.35385 .78427 m .3528 .8033 L .34012 .79867 L p .707 .577 .707 r
F P
0 g
s
.34012 .79867 m .34116 .77964 L .35385 .78427 L p .707 .577 .707 r
F P
0 g
s
.17916 .70221 m .17712 .74026 L .16087 .7432 L p .707 .577 .707 r
F P
0 g
s
.17932 .6737 m .18117 .61709 L .20518 .61383 L p .707 .577 .707 r
F P
0 g
s
.15912 .7912 m .16017 .77217 L .17641 .76935 L p .707 .577 .707 r
F P
0 g
s
.17641 .76935 m .17536 .78838 L .15912 .7912 L p .707 .577 .707 r
F P
0 g
s
.34392 .71231 m .34188 .75036 L .32077 .74594 L p .707 .577 .707 r
F P
0 g
s
.32077 .74594 m .32281 .70789 L .34392 .71231 L p .707 .577 .707 r
F P
0 g
s
.20518 .61383 m .20333 .67045 L .17932 .6737 L p .707 .577 .707 r
F P
0 g
s
.32498 .61909 m .32313 .67571 L .29567 .67173 L p .707 .577 .707 r
F P
0 g
s
.29567 .67173 m .29752 .61512 L .32498 .61909 L p .707 .577 .707 r
F P
0 g
s
.17712 .74026 m .17916 .70221 L .20311 .70055 L p .707 .577 .707 r
F P
0 g
s
.20333 .67045 m .20518 .61383 L .23453 .61235 L p .707 .577 .707 r
F P
0 g
s
.34116 .77964 m .34012 .79867 L .319 .79431 L p .707 .577 .707 r
F P
0 g
s
.319 .79431 m .32005 .77528 L .34116 .77964 L p .707 .577 .707 r
F P
0 g
s
.20311 .70055 m .20107 .7386 L .17712 .74026 L p .707 .577 .707 r
F P
0 g
s
.29752 .61512 m .29567 .67173 L .2645 .66941 L p .707 .577 .707 r
F P
0 g
s
.2645 .66941 m .26635 .6128 L .29752 .61512 L p .707 .577 .707 r
F P
0 g
s
.17536 .78838 m .17641 .76935 L .20035 .7678 L p .707 .577 .707 r
F P
0 g
s
.23453 .61235 m .23268 .66897 L .20333 .67045 L p .707 .577 .707 r
F P
0 g
s
.20035 .7678 m .1993 .78683 L .17536 .78838 L p .707 .577 .707 r
F P
0 g
s
.32281 .70789 m .32077 .74594 L .2933 .74224 L p .707 .577 .707 r
F P
0 g
s
.2933 .74224 m .29534 .7042 L .32281 .70789 L p .707 .577 .707 r
F P
0 g
s
.73143 .64853 m .73328 .59192 L .70212 .5896 L p .707 .577 .707 r
F P
0 g
s
.73328 .59192 m .73143 .64853 L .76325 .64898 L p .707 .577 .707 r
F P
0 g
s
.76325 .64898 m .7651 .59236 L .73328 .59192 L p .707 .577 .707 r
F P
0 g
s
.23268 .66897 m .23453 .61235 L .26635 .6128 L p .707 .577 .707 r
F P
0 g
s
.7651 .59236 m .76325 .64898 L .7926 .6475 L p .707 .577 .707 r
F P
0 g
s
.7926 .6475 m .79445 .59088 L .7651 .59236 L p .707 .577 .707 r
F P
0 g
s
.26635 .6128 m .2645 .66941 L .23268 .66897 L p .707 .577 .707 r
F P
0 g
s
.20107 .7386 m .20311 .70055 L .2324 .70034 L p .707 .577 .707 r
F P
0 g
s
.70027 .64621 m .70212 .5896 L .67465 .58562 L p .707 .577 .707 r
F P
0 g
s
.70212 .5896 m .70027 .64621 L .73143 .64853 L p .707 .577 .707 r
F P
0 g
s
.32005 .77528 m .319 .79431 L .29152 .79063 L p .707 .577 .707 r
F P
0 g
s
.29152 .79063 m .29257 .7716 L .32005 .77528 L p .707 .577 .707 r
F P
0 g
s
.2324 .70034 m .23036 .73839 L .20107 .7386 L p .707 .577 .707 r
F P
0 g
s
.29534 .7042 m .2933 .74224 L .26214 .73964 L p .707 .577 .707 r
F P
0 g
s
.26214 .73964 m .26418 .7016 L .29534 .7042 L p .707 .577 .707 r
F P
0 g
s
.72955 .7017 m .73159 .66366 L .70043 .66106 L p .707 .577 .707 r
F P
0 g
s
.73159 .66366 m .72955 .7017 L .76133 .70296 L p .707 .577 .707 r
F P
0 g
s
.76133 .70296 m .76337 .66491 L .73159 .66366 L p .707 .577 .707 r
F P
0 g
s
.79445 .59088 m .7926 .6475 L .81661 .64424 L p .707 .577 .707 r
F P
0 g
s
.81661 .64424 m .81846 .58763 L .79445 .59088 L p .707 .577 .707 r
F P
0 g
s
.67465 .58562 m .6728 .64224 L .70027 .64621 L p .707 .577 .707 r
F P
0 g
s
.1993 .78683 m .20035 .7678 L .22964 .76767 L p .707 .577 .707 r
F P
0 g
s
.76337 .66491 m .76133 .70296 L .79063 .70275 L p .707 .577 .707 r
F P
0 g
s
.79063 .70275 m .79266 .6647 L .76337 .66491 L p .707 .577 .707 r
F P
0 g
s
.23036 .73839 m .2324 .70034 L .26418 .7016 L p .707 .577 .707 r
F P
0 g
s
.22964 .76767 m .22859 .7867 L .1993 .78683 L p .707 .577 .707 r
F P
0 g
s
.70043 .66106 m .6984 .6991 L .72955 .7017 L p .707 .577 .707 r
F P
0 g
s
.26418 .7016 m .26214 .73964 L .23036 .73839 L p .707 .577 .707 r
F P
0 g
s
.6984 .6991 m .70043 .66106 L .67296 .65736 L p .707 .577 .707 r
F P
0 g
s
.6728 .64224 m .67465 .58562 L .65358 .58039 L p .707 .577 .707 r
F P
0 g
s
.72782 .73953 m .72886 .7205 L .69771 .71788 L p .707 .577 .707 r
F P
0 g
s
.72886 .7205 m .72782 .73953 L .75959 .74084 L p .707 .577 .707 r
F P
0 g
s
.75959 .74084 m .76064 .72181 L .72886 .7205 L p .707 .577 .707 r
F P
0 g
s
.69771 .71788 m .69666 .73691 L .72782 .73953 L p .707 .577 .707 r
F P
0 g
s
.29257 .7716 m .29152 .79063 L .26037 .78801 L p .707 .577 .707 r
F P
0 g
s
.26037 .78801 m .26142 .76898 L .29257 .7716 L p .707 .577 .707 r
F P
0 g
s
.67296 .65736 m .67092 .69541 L .6984 .6991 L p .707 .577 .707 r
F P
0 g
s
.76064 .72181 m .75959 .74084 L .78889 .74072 L p .707 .577 .707 r
F P
0 g
s
.78889 .74072 m .78993 .72169 L .76064 .72181 L p .707 .577 .707 r
F P
0 g
s
.22859 .7867 m .22964 .76767 L .26142 .76898 L p .707 .577 .707 r
F P
0 g
s
.69666 .73691 m .69771 .71788 L .67023 .71421 L p .707 .577 .707 r
F P
0 g
s
.79266 .6647 m .79063 .70275 L .81457 .70109 L p .707 .577 .707 r
F P
0 g
s
.81457 .70109 m .81661 .66304 L .79266 .6647 L p .707 .577 .707 r
F P
0 g
s
.26142 .76898 m .26037 .78801 L .22859 .7867 L p .707 .577 .707 r
F P
0 g
s
.65358 .58039 m .65173 .63701 L .6728 .64224 L p .707 .577 .707 r
F P
0 g
s
.67023 .71421 m .66919 .73324 L .69666 .73691 L p .707 .577 .707 r
F P
0 g
s
.81846 .58763 m .81661 .64424 L .83294 .63953 L p .707 .577 .707 r
F P
0 g
s
.83294 .63953 m .83479 .58292 L .81846 .58763 L p .707 .577 .707 r
F P
0 g
s
.67092 .69541 m .67296 .65736 L .65185 .65294 L p .707 .577 .707 r
F P
0 g
s
.78993 .72169 m .78889 .74072 L .81282 .73917 L p .707 .577 .707 r
F P
0 g
s
.81282 .73917 m .81387 .72014 L .78993 .72169 L p .707 .577 .707 r
F P
0 g
s
.65185 .65294 m .64981 .69099 L .67092 .69541 L p .707 .577 .707 r
F P
0 g
s
.65173 .63701 m .65358 .58039 L .64095 .57441 L p .707 .577 .707 r
F P
0 g
s
.66919 .73324 m .67023 .71421 L .64912 .70984 L p .707 .577 .707 r
F P
0 g
s
.64912 .70984 m .64807 .72887 L .66919 .73324 L p .707 .577 .707 r
F P
0 g
s
.81661 .66304 m .81457 .70109 L .83082 .69814 L p .707 .577 .707 r
F P
0 g
s
.83082 .69814 m .83286 .6601 L .81661 .66304 L p .707 .577 .707 r
F P
0 g
s
.64095 .57441 m .6391 .63102 L .65173 .63701 L p .707 .577 .707 r
F P
0 g
s
.81387 .72014 m .81282 .73917 L .82907 .73635 L p .707 .577 .707 r
F P
0 g
s
.82907 .73635 m .83011 .71732 L .81387 .72014 L p .707 .577 .707 r
F P
0 g
s
.64981 .69099 m .65185 .65294 L .63917 .64823 L p .707 .577 .707 r
F P
0 g
s
.83479 .58292 m .83294 .63953 L .83998 .63382 L p .707 .577 .707 r
F P
0 g
s
.83998 .63382 m .84183 .57721 L .83479 .58292 L p .707 .577 .707 r
F P
0 g
s
.63917 .64823 m .63713 .68627 L .64981 .69099 L p .707 .577 .707 r
F P
0 g
s
.64807 .72887 m .64912 .70984 L .63644 .70521 L p .707 .577 .707 r
F P
0 g
s
.63644 .70521 m .63539 .72424 L .64807 .72887 L p .707 .577 .707 r
F P
0 g
s
.6391 .63102 m .64095 .57441 L .63802 .56826 L p .707 .577 .707 r
F P
0 g
s
.83286 .6601 m .83082 .69814 L .83778 .6942 L p .707 .577 .707 r
F P
0 g
s
.83778 .6942 m .83982 .65616 L .83286 .6601 L p .707 .577 .707 r
F P
0 g
s
.63802 .56826 m .63617 .62488 L .6391 .63102 L p .707 .577 .707 r
F P
0 g
s
.83011 .71732 m .82907 .73635 L .83602 .73253 L p .707 .577 .707 r
F P
0 g
s
.83602 .73253 m .83707 .7135 L .83011 .71732 L p .707 .577 .707 r
F P
0 g
s
.63713 .68627 m .63917 .64823 L .63616 .64367 L p .707 .577 .707 r
F P
0 g
s
.84183 .57721 m .83998 .63382 L .83704 .62767 L p .707 .577 .707 r
F P
0 g
s
.83704 .62767 m .83889 .57106 L .84183 .57721 L p .707 .577 .707 r
F P
0 g
s
.63616 .64367 m .63412 .68172 L .63713 .68627 L p .707 .577 .707 r
F P
0 g
s
.63539 .72424 m .63644 .70521 L .63343 .70077 L p .707 .577 .707 r
F P
0 g
s
.63343 .70077 m .63238 .7198 L .63539 .72424 L p .707 .577 .707 r
F P
0 g
s
.63617 .62488 m .63802 .56826 L .64506 .56255 L p .707 .577 .707 r
F P
0 g
s
.83982 .65616 m .83778 .6942 L .83478 .68965 L p .707 .577 .707 r
F P
0 g
s
.83478 .68965 m .83682 .65161 L .83982 .65616 L p .707 .577 .707 r
F P
0 g
s
.64506 .56255 m .64321 .61917 L .63617 .62488 L p .707 .577 .707 r
F P
0 g
s
.83707 .7135 m .83602 .73253 L .83301 .72809 L p .707 .577 .707 r
F P
0 g
s
.83301 .72809 m .83406 .70906 L .83707 .7135 L p .707 .577 .707 r
F P
0 g
s
.63412 .68172 m .63616 .64367 L .64313 .63973 L p .707 .577 .707 r
F P
0 g
s
.83889 .57106 m .83704 .62767 L .82442 .62169 L p .707 .577 .707 r
F P
0 g
s
.82442 .62169 m .82627 .56508 L .83889 .57106 L p .707 .577 .707 r
F P
0 g
s
.64313 .63973 m .64109 .67778 L .63412 .68172 L p .707 .577 .707 r
F P
0 g
s
.63238 .7198 m .63343 .70077 L .64038 .69695 L p .707 .577 .707 r
F P
0 g
s
.38842 .61172 m .39027 .5551 L .35911 .55278 L p .707 .577 .707 r
F P
0 g
s
.39027 .5551 m .38842 .61172 L .42024 .61216 L p .707 .577 .707 r
F P
0 g
s
.42024 .61216 m .42209 .55554 L .39027 .5551 L p .707 .577 .707 r
F P
0 g
s
.64038 .69695 m .63933 .71598 L .63238 .7198 L p .707 .577 .707 r
F P
0 g
s
.42209 .55554 m .42024 .61216 L .44959 .61068 L p .707 .577 .707 r
F P
0 g
s
.44959 .61068 m .45144 .55407 L .42209 .55554 L p .707 .577 .707 r
F P
0 g
s
.64321 .61917 m .64506 .56255 L .66138 .55784 L p .707 .577 .707 r
F P
0 g
s
.35726 .6094 m .35911 .55278 L .33164 .54881 L p .707 .577 .707 r
F P
0 g
s
.35911 .55278 m .35726 .6094 L .38842 .61172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83682 .65161 m .83478 .68965 L .8221 .68493 L p .707 .577 .707 r
F P
0 g
s
.8221 .68493 m .82414 .64689 L .83682 .65161 L p .707 .577 .707 r
F P
0 g
s
.66138 .55784 m .65953 .61445 L .64321 .61917 L p .707 .577 .707 r
F P
0 g
s
.38654 .66489 m .38858 .62684 L .35742 .62424 L p .707 .577 .707 r
F P
0 g
s
.38858 .62684 m .38654 .66489 L .41832 .66614 L p .707 .577 .707 r
F P
0 g
s
.41832 .66614 m .42036 .6281 L .38858 .62684 L p .707 .577 .707 r
F P
0 g
s
.45144 .55407 m .44959 .61068 L .4736 .60743 L p .707 .577 .707 r
F P
0 g
s
.4736 .60743 m .47545 .55081 L .45144 .55407 L p .707 .577 .707 r
F P
0 g
s
.33164 .54881 m .32979 .60542 L .35726 .6094 L p .707 .577 .707 r
F P
0 g
s
.42036 .6281 m .41832 .66614 L .44762 .66593 L p .707 .577 .707 r
F P
0 g
s
.44762 .66593 m .44965 .62789 L .42036 .6281 L p .707 .577 .707 r
F P
0 g
s
.83406 .70906 m .83301 .72809 L .82033 .72346 L p .707 .577 .707 r
F P
0 g
s
.82033 .72346 m .82138 .70443 L .83406 .70906 L p .707 .577 .707 r
F P
0 g
s
.35742 .62424 m .35539 .66228 L .38654 .66489 L p .707 .577 .707 r
F P
0 g
s
.64109 .67778 m .64313 .63973 L .65938 .63679 L p .707 .577 .707 r
F P
0 g
s
.82627 .56508 m .82442 .62169 L .80334 .61646 L p .707 .577 .707 r
F P
0 g
s
.80334 .61646 m .80519 .55984 L .82627 .56508 L p .707 .577 .707 r
F P
0 g
s
.35539 .66228 m .35742 .62424 L .32995 .62055 L p .707 .577 .707 r
F P
0 g
s
.32979 .60542 m .33164 .54881 L .31057 .54358 L p .707 .577 .707 r
F P
0 g
s
.38481 .70271 m .38585 .68368 L .3547 .68106 L p .707 .577 .707 r
F P
0 g
s
.38585 .68368 m .38481 .70271 L .41658 .70403 L p .707 .577 .707 r
F P
0 g
s
.41658 .70403 m .41763 .685 L .38585 .68368 L p .707 .577 .707 r
F P
0 g
s
.65938 .63679 m .65734 .67483 L .64109 .67778 L p .707 .577 .707 r
F P
0 g
s
.3547 .68106 m .35365 .70009 L .38481 .70271 L p .707 .577 .707 r
F P
0 g
s
.32995 .62055 m .32791 .65859 L .35539 .66228 L p .707 .577 .707 r
F P
0 g
s
.41763 .685 m .41658 .70403 L .44588 .7039 L p .707 .577 .707 r
F P
0 g
s
.44588 .7039 m .44692 .68487 L .41763 .685 L p .707 .577 .707 r
F P
0 g
s
.63933 .71598 m .64038 .69695 L .65662 .69413 L p .707 .577 .707 r
F P
0 g
s
.35365 .70009 m .3547 .68106 L .32722 .67739 L p .707 .577 .707 r
F P
0 g
s
.44965 .62789 m .44762 .66593 L .47156 .66427 L p .707 .577 .707 r
F P
0 g
s
.47156 .66427 m .4736 .62623 L .44965 .62789 L p .707 .577 .707 r
F P
0 g
s
.65953 .61445 m .66138 .55784 L .6854 .55458 L p .707 .577 .707 r
F P
0 g
s
.65662 .69413 m .65558 .71316 L .63933 .71598 L p .707 .577 .707 r
F P
0 g
s
.31057 .54358 m .30872 .60019 L .32979 .60542 L p .707 .577 .707 r
F P
0 g
s
.32722 .67739 m .32618 .69642 L .35365 .70009 L p .707 .577 .707 r
F P
0 g
s
.47545 .55081 m .4736 .60743 L .48993 .60272 L p .707 .577 .707 r
F P
0 g
s
.48993 .60272 m .49178 .5461 L .47545 .55081 L p .707 .577 .707 r
F P
0 g
s
.32791 .65859 m .32995 .62055 L .30884 .61613 L p .707 .577 .707 r
F P
0 g
s
.82414 .64689 m .8221 .68493 L .80099 .68051 L p .707 .577 .707 r
F P
0 g
s
.80099 .68051 m .80303 .64247 L .82414 .64689 L p .707 .577 .707 r
F P
0 g
s
.44692 .68487 m .44588 .7039 L .46981 .70235 L p .707 .577 .707 r
F P
0 g
s
.46981 .70235 m .47086 .68332 L .44692 .68487 L p .707 .577 .707 r
F P
0 g
s
.6854 .55458 m .68355 .6112 L .65953 .61445 L p .707 .577 .707 r
F P
0 g
s
.30884 .61613 m .3068 .65417 L .32791 .65859 L p .707 .577 .707 r
F P
0 g
s
.80519 .55984 m .80334 .61646 L .77588 .61249 L p .707 .577 .707 r
F P
0 g
s
.77588 .61249 m .77773 .55587 L .80519 .55984 L p .707 .577 .707 r
F P
0 g
s
.30872 .60019 m .31057 .54358 L .29794 .53759 L p .707 .577 .707 r
F P
0 g
s
.32618 .69642 m .32722 .67739 L .30611 .67303 L p .707 .577 .707 r
F P
0 g
s
.82138 .70443 m .82033 .72346 L .79922 .71909 L p .707 .577 .707 r
F P
0 g
s
.79922 .71909 m .80026 .70006 L .82138 .70443 L p .707 .577 .707 r
F P
0 g
s
.65734 .67483 m .65938 .63679 L .68332 .63513 L p .707 .577 .707 r
F P
0 g
s
.30611 .67303 m .30506 .69206 L .32618 .69642 L p .707 .577 .707 r
F P
0 g
s
.68355 .6112 m .6854 .55458 L .71475 .55311 L p .707 .577 .707 r
F P
0 g
s
.4736 .62623 m .47156 .66427 L .48781 .66133 L p .707 .577 .707 r
F P
0 g
s
.48781 .66133 m .48985 .62328 L .4736 .62623 L p .707 .577 .707 r
F P
0 g
s
.68332 .63513 m .68128 .67317 L .65734 .67483 L p .707 .577 .707 r
F P
0 g
s
.29794 .53759 m .29609 .59421 L .30872 .60019 L p .707 .577 .707 r
F P
0 g
s
.65558 .71316 m .65662 .69413 L .68056 .69258 L p .707 .577 .707 r
F P
0 g
s
.68056 .69258 m .67952 .71161 L .65558 .71316 L p .707 .577 .707 r
F P
0 g
s
.77773 .55587 m .77588 .61249 L .74471 .61017 L p .707 .577 .707 r
F P
0 g
s
.74471 .61017 m .74656 .55355 L .77773 .55587 L p .707 .577 .707 r
F P
0 g
s
.47086 .68332 m .46981 .70235 L .48606 .69953 L p .707 .577 .707 r
F P
0 g
s
.48606 .69953 m .4871 .6805 L .47086 .68332 L p .707 .577 .707 r
F P
0 g
s
.3068 .65417 m .30884 .61613 L .29616 .61141 L p .707 .577 .707 r
F P
0 g
s
.80303 .64247 m .80099 .68051 L .77351 .67682 L p .707 .577 .707 r
F P
0 g
s
.77351 .67682 m .77555 .63878 L .80303 .64247 L p .707 .577 .707 r
F P
0 g
s
.71475 .55311 m .7129 .60972 L .68355 .6112 L p .707 .577 .707 r
F P
0 g
s
.49178 .5461 m .48993 .60272 L .49697 .59701 L p .707 .577 .707 r
F P
0 g
s
.49697 .59701 m .49882 .54039 L .49178 .5461 L p .707 .577 .707 r
F P
0 g
s
.7129 .60972 m .71475 .55311 L .74656 .55355 L p .707 .577 .707 r
F P
0 g
s
.29616 .61141 m .29412 .64945 L .3068 .65417 L p .707 .577 .707 r
F P
0 g
s
.74656 .55355 m .74471 .61017 L .7129 .60972 L p .707 .577 .707 r
F P
0 g
s
.68128 .67317 m .68332 .63513 L .71262 .63492 L p .707 .577 .707 r
F P
0 g
s
.30506 .69206 m .30611 .67303 L .29343 .6684 L p .707 .577 .707 r
F P
0 g
s
.80026 .70006 m .79922 .71909 L .77174 .71542 L p .707 .577 .707 r
F P
0 g
s
.77174 .71542 m .77278 .69639 L .80026 .70006 L p .707 .577 .707 r
F P
0 g
s
.29343 .6684 m .29238 .68743 L .30506 .69206 L p .707 .577 .707 r
F P
0 g
s
.71262 .63492 m .71058 .67296 L .68128 .67317 L p .707 .577 .707 r
F P
0 g
s
.29609 .59421 m .29794 .53759 L .29501 .53144 L p .707 .577 .707 r
F P
0 g
s
.67952 .71161 m .68056 .69258 L .70986 .69246 L p .707 .577 .707 r
F P
0 g
s
.77555 .63878 m .77351 .67682 L .74236 .67422 L p .707 .577 .707 r
F P
0 g
s
.74236 .67422 m .7444 .63617 L .77555 .63878 L p .707 .577 .707 r
F P
0 g
s
.48985 .62328 m .48781 .66133 L .49477 .65739 L p .707 .577 .707 r
F P
0 g
s
.49477 .65739 m .49681 .61934 L .48985 .62328 L p .707 .577 .707 r
F P
0 g
s
.70986 .69246 m .70881 .71149 L .67952 .71161 L p .707 .577 .707 r
F P
0 g
s
.71058 .67296 m .71262 .63492 L .7444 .63617 L p .707 .577 .707 r
F P
0 g
s
.7444 .63617 m .74236 .67422 L .71058 .67296 L p .707 .577 .707 r
F P
0 g
s
.29501 .53144 m .29316 .58806 L .29609 .59421 L p .707 .577 .707 r
F P
0 g
s
.77278 .69639 m .77174 .71542 L .74058 .7128 L p .707 .577 .707 r
F P
0 g
s
.74058 .7128 m .74163 .69377 L .77278 .69639 L p .707 .577 .707 r
F P
0 g
s
.4871 .6805 m .48606 .69953 L .49301 .69571 L p .707 .577 .707 r
F P
0 g
s
.49301 .69571 m .49406 .67668 L .4871 .6805 L p .707 .577 .707 r
F P
0 g
s
.29412 .64945 m .29616 .61141 L .29315 .60686 L p .707 .577 .707 r
F P
0 g
s
.70881 .71149 m .70986 .69246 L .74163 .69377 L p .707 .577 .707 r
F P
0 g
s
.74163 .69377 m .74058 .7128 L .70881 .71149 L p .707 .577 .707 r
F P
0 g
s
.49882 .54039 m .49697 .59701 L .49403 .59086 L p .707 .577 .707 r
F P
0 g
s
.49403 .59086 m .49588 .53424 L .49882 .54039 L p .707 .577 .707 r
F P
0 g
s
.29315 .60686 m .29111 .6449 L .29412 .64945 L p .707 .577 .707 r
F P
0 g
s
.29238 .68743 m .29343 .6684 L .29042 .66396 L p .707 .577 .707 r
F P
0 g
s
.29042 .66396 m .28937 .68299 L .29238 .68743 L p .707 .577 .707 r
F P
0 g
s
.29316 .58806 m .29501 .53144 L .30205 .52574 L p .707 .577 .707 r
F P
0 g
s
.49681 .61934 m .49477 .65739 L .49177 .65283 L p .707 .577 .707 r
F P
0 g
s
.49177 .65283 m .49381 .61479 L .49681 .61934 L p .707 .577 .707 r
F P
0 g
s
.30205 .52574 m .3002 .58235 L .29316 .58806 L p .707 .577 .707 r
F P
0 g
s
.49406 .67668 m .49301 .69571 L .49 .69127 L p .707 .577 .707 r
F P
0 g
s
.49 .69127 m .49105 .67224 L .49406 .67668 L p .707 .577 .707 r
F P
0 g
s
.29111 .6449 m .29315 .60686 L .30012 .60292 L p .707 .577 .707 r
F P
0 g
s
.49588 .53424 m .49403 .59086 L .48141 .58488 L p .707 .577 .707 r
F P
0 g
s
.48141 .58488 m .48326 .52826 L .49588 .53424 L p .707 .577 .707 r
F P
0 g
s
.30012 .60292 m .29808 .64096 L .29111 .6449 L p .707 .577 .707 r
F P
0 g
s
.28937 .68299 m .29042 .66396 L .29737 .66014 L p .707 .577 .707 r
F P
0 g
s
.29737 .66014 m .29632 .67917 L .28937 .68299 L p .707 .577 .707 r
F P
0 g
s
.3002 .58235 m .30205 .52574 L .31837 .52102 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49381 .61479 m .49177 .65283 L .47909 .64812 L p .707 .577 .707 r
F P
0 g
s
.47909 .64812 m .48113 .61007 L .49381 .61479 L p .707 .577 .707 r
F P
0 g
s
.31837 .52102 m .31652 .57764 L .3002 .58235 L p .707 .577 .707 r
F P
0 g
s
.49105 .67224 m .49 .69127 L .47732 .68664 L p .707 .577 .707 r
F P
0 g
s
.47732 .68664 m .47837 .66761 L .49105 .67224 L p .707 .577 .707 r
F P
0 g
s
.29808 .64096 m .30012 .60292 L .31637 .59997 L p .707 .577 .707 r
F P
0 g
s
.48326 .52826 m .48141 .58488 L .46033 .57964 L p .707 .577 .707 r
F P
0 g
s
.46033 .57964 m .46218 .52303 L .48326 .52826 L p .707 .577 .707 r
F P
0 g
s
.31637 .59997 m .31433 .63802 L .29808 .64096 L p .707 .577 .707 r
F P
0 g
s
.29632 .67917 m .29737 .66014 L .31361 .65731 L p .707 .577 .707 r
F P
0 g
s
.31652 .57764 m .31837 .52102 L .34239 .51777 L p .707 .577 .707 r
F P
0 g
s
.31361 .65731 m .31257 .67634 L .29632 .67917 L p .707 .577 .707 r
F P
0 g
s
.48113 .61007 m .47909 .64812 L .45798 .6437 L p .707 .577 .707 r
F P
0 g
s
.45798 .6437 m .46002 .60565 L .48113 .61007 L p .707 .577 .707 r
F P
0 g
s
.34239 .51777 m .34054 .57438 L .31652 .57764 L p .707 .577 .707 r
F P
0 g
s
.46218 .52303 m .46033 .57964 L .43287 .57567 L p .707 .577 .707 r
F P
0 g
s
.43287 .57567 m .43472 .51905 L .46218 .52303 L p .707 .577 .707 r
F P
0 g
s
.47837 .66761 m .47732 .68664 L .4562 .68228 L p .707 .577 .707 r
F P
0 g
s
.4562 .68228 m .45725 .66325 L .47837 .66761 L p .707 .577 .707 r
F P
0 g
s
.31433 .63802 m .31637 .59997 L .34031 .59831 L p .707 .577 .707 r
F P
0 g
s
.34054 .57438 m .34239 .51777 L .37174 .51629 L p .707 .577 .707 r
F P
0 g
s
.34031 .59831 m .33827 .63636 L .31433 .63802 L p .707 .577 .707 r
F P
0 g
s
.31257 .67634 m .31361 .65731 L .33755 .65577 L p .707 .577 .707 r
F P
0 g
s
.33755 .65577 m .33651 .6748 L .31257 .67634 L p .707 .577 .707 r
F P
0 g
s
.43472 .51905 m .43287 .57567 L .4017 .57335 L p .707 .577 .707 r
F P
0 g
s
.4017 .57335 m .40355 .51673 L .43472 .51905 L p .707 .577 .707 r
F P
0 g
s
.46002 .60565 m .45798 .6437 L .4305 .64 L p .707 .577 .707 r
F P
0 g
s
.4305 .64 m .43254 .60196 L .46002 .60565 L p .707 .577 .707 r
F P
0 g
s
.37174 .51629 m .36989 .57291 L .34054 .57438 L p .707 .577 .707 r
F P
0 g
s
.36989 .57291 m .37174 .51629 L .40355 .51673 L p .707 .577 .707 r
F P
0 g
s
.40355 .51673 m .4017 .57335 L .36989 .57291 L p .707 .577 .707 r
F P
0 g
s
.33827 .63636 m .34031 .59831 L .36961 .5981 L p .707 .577 .707 r
F P
0 g
s
.45725 .66325 m .4562 .68228 L .42873 .6786 L p .707 .577 .707 r
F P
0 g
s
.42873 .6786 m .42977 .65957 L .45725 .66325 L p .707 .577 .707 r
F P
0 g
s
.36961 .5981 m .36757 .63615 L .33827 .63636 L p .707 .577 .707 r
F P
0 g
s
.33651 .6748 m .33755 .65577 L .36684 .65564 L p .707 .577 .707 r
F P
0 g
s
.43254 .60196 m .4305 .64 L .39935 .6374 L p .707 .577 .707 r
F P
0 g
s
.39935 .6374 m .40139 .59936 L .43254 .60196 L p .707 .577 .707 r
F P
0 g
s
.36684 .65564 m .3658 .67467 L .33651 .6748 L p .707 .577 .707 r
F P
0 g
s
.36757 .63615 m .36961 .5981 L .40139 .59936 L p .707 .577 .707 r
F P
0 g
s
.40139 .59936 m .39935 .6374 L .36757 .63615 L p .707 .577 .707 r
F P
0 g
s
.42977 .65957 m .42873 .6786 L .39757 .67598 L p .707 .577 .707 r
F P
0 g
s
.39757 .67598 m .39862 .65695 L .42977 .65957 L p .707 .577 .707 r
F P
0 g
s
.3658 .67467 m .36684 .65564 L .39862 .65695 L p .707 .577 .707 r
F P
0 g
s
.39862 .65695 m .39757 .67598 L .3658 .67467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolE0028Ool007Qoo`P000IJEP03001JEUYF00UJEP03001JEUYF00H0089oo`00M7oo
100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01UYF1000OWoo001`Ool40005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000O7oo001/Ool40009FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P00NWoo001ZOol200000eYF
001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001h
Ool006Qoo`8000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8007Ioo`00IWoo0P001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01eYF00<007ooOol0Lgoo001TOol20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00Oomo
o`1bOol006=oo`8000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001oogoo075oo`00HWoo00<005YF000025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02EYF00<007ooOol0L7oo001P
Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool005moo`03001JEUYF009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EW5oo`00GWoo00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYFLGoo001MOol00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005eoo`03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0KWoo001LOol20007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1^Ool005]oo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06io
o`00Fgoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0KWoo001KOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1]Ool005aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06eoo`00G7oo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00KWoo001LOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0KGoo001LOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YFKWoo001MOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVioo`00GGoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03
001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001^Ool005eoo`03001JEP0000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00GGoo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1/Ool0
05eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00KGoo001MOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<0
05YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1[Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]o
o`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00K7oo001NOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo
001OOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005moo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000=JEQ4000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo001HOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001EOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001[Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001[Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Jgoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1Y
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00]ooaX004Aoo`00Dgoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000fOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`02Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000bOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000=JEP04001JEUYFFUH8
00000eYF001JEP06FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005=oo`03001JEP00009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEPD000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2
0002Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP05
001oo`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOolO00000eYF001JEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]
Ool005Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80000
0eYF001JEP05FUH00`00FUIJEP030002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool0
05=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH;0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP050004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00Ool005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00=goo7@0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF008002ioo`00;Woo0`000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH300001EYF
000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF10000UYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJ
EP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP800003Ool005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEP0000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEP00FUH00P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP80009oo`800003FUH005YF00AJEQX000QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002FUH70007FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`090003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80000
0eYF001JEP05FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Ool0000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL00003FUH0
05YF0080035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000<Woo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1@0000=JEP0000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF0000800025YF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH=0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000=JEP04001JEUYFFUHJ0002FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000UYF1P00
25YF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH00UYF00@005YFFUIJEQ0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000015YF001JEUYF7P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP00009JEPd00003FUH005YF00EJ
EPl000IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH40005
FUH01000FUIJEUYF200015YF00<005YF00000P001EYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF1`000eYF00@005YFFUIJEP8002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF009JEQ/000=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00;Woo000/
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH50002FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000^Ool002eoo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYFFUH40002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF000000020003FUH@00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000^Ool002moo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEP00008000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPT00003FUH005YF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02ioo`00<Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1@0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH01EYF00<005YFFUH01000;goo000aOolN00000eYF001JEP06FUH00`00FUIJEP04FUHC
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP/003=oo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEQ80009oo`04001JEUYF0006FUH00`00FUIJEP02FUH@0000
0eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH70005Ool01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;goo000/Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP060002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00MJEPT000IJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF
001JEP040004FUH5000015YF001JEUYF0P002Goo0`000goo200015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUIJEPH000QJEPX000UJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUHC000:Ool70003FUH00`00FUIJEP02
000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00MJEPH000=JEP03001J
EUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUHE
0002FUH40002FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP004EYF00<0
05YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02EYF0P000UYF1@001UYF00@005YFFUIJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUH005YF000AFUH00`00FUH00003000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20007FUH20004
FUH01000FUIJEUYF0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000@FUH30003FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH20008FUH400000eYF001JEP03FUH00`00FUIJEP02FUH80004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
02moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000>FUH20006FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20008FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`00<7oo000[Ool00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000]JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP8000QJEP8000AJEP04001JEUYFFUH20003FUH01000FUIJEUYF1P001Woo8000<goo000[Ool00`00
FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJ
EP03FUH01000FUIJEP002eYF0`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P002EYF00<005YFFUH00eYF00D005YFFUH005YF00P005ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YF
FUH000UJEP80009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000MJEP03001JEP00008005]oo`00;7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEPD00003FUH005YF00IJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000MJEP03001JEUYF
009JEP<005Qoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EWoo000_Ool40003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF
00=JEP03001JEUYF008005Eoo`00<goo1`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP<000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0006FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol003Yoo`P000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH90002FUH01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF0P0025YF00<005YFFUH015YF00@005YF000000EJEP03001J
EUYF00AJEP03001JEUYF008005Eoo`00<7oo;0002Goo0UYF00@005YFFUH000QJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP03001JEUYF00AJEP04001J
EUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000]Ool30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000>Ool00eYF001JEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20008FUH0
0`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000[Ool30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0027oo00=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0100017oo00=JEP00FUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000Woo0P000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP0000001P000eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00@005YF
FUIJEQ0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00@000=J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP@000=JEP8005Eoo`00:goo
00<005YF000030002goo4@0015YF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000005Eo
o`00:goo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPP001Aoo`H000AJEP04001JEUYFFUH30003
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3001EOol002]oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF009JEQd00003
FUH005YF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0005Eoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF0`0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP03001JEUYF00@005Ioo`00;Woo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF01<005Yoo`00<Woo1`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF
001oo`0000=JEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP80
00QJEP/006Eoo`00>Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH010000goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH6001OOol0049oo`T0
00AJEP03001JEUYF00EJEP04001JEUYFFUH60008Ool00`00FUH00008FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP05
FUH00`00FUH00002001LOol004]ooa0000moo`8000QJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF009JEP<000QJEP03001JEUYF00EJEP03001JEUYF
009JEP<005Uoo`00Jgoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00P000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000P00EWoo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo
001`Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH3000;
Ool80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo001cOol40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH01000FUIJEUYF1P000UYF2@002goo1`000eYF00<005YFFUH00P00EWoo001gOol6
0002FUH00`00FUIJEP09FUH00`00FUIJEP07FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@
0002FUH500000eYF0000001FOol007eoo`P000IJEP04001JEUYFFUH60002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
EWoo0025Ool:00000goo000000020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002DOol70004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00
Egoo002SOolP001JOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59829 .75401 m .59644 .69987 L .56528 .69839 L p .707 .577 .707 r
F P
0 g
s
.59644 .69987 m .59829 .75401 L .63011 .75204 L p .707 .577 .707 r
F P
0 g
s
.63011 .75204 m .62826 .6979 L .59644 .69987 L p .707 .577 .707 r
F P
0 g
s
.62826 .6979 m .63011 .75204 L .65946 .7468 L p .707 .577 .707 r
F P
0 g
s
.65946 .7468 m .65761 .69267 L .62826 .6979 L p .707 .577 .707 r
F P
0 g
s
.56713 .75252 m .56528 .69839 L .53781 .69358 L p .707 .577 .707 r
F P
0 g
s
.56528 .69839 m .56713 .75252 L .59829 .75401 L p .707 .577 .707 r
F P
0 g
s
.65761 .69267 m .65946 .7468 L .68347 .73881 L p .707 .577 .707 r
F P
0 g
s
.68347 .73881 m .68162 .68467 L .65761 .69267 L p .707 .577 .707 r
F P
0 g
s
.53966 .74772 m .53781 .69358 L .51674 .68593 L p .707 .577 .707 r
F P
0 g
s
.53781 .69358 m .53966 .74772 L .56713 .75252 L p .707 .577 .707 r
F P
0 g
s
.60065 .8149 m .59861 .77959 L .56746 .77837 L p .707 .577 .707 r
F P
0 g
s
.59861 .77959 m .60065 .8149 L .63243 .81216 L p .707 .577 .707 r
F P
0 g
s
.63243 .81216 m .63039 .77686 L .59861 .77959 L p .707 .577 .707 r
F P
0 g
s
.63039 .77686 m .63243 .81216 L .66173 .80573 L p .707 .577 .707 r
F P
0 g
s
.66173 .80573 m .65969 .77043 L .63039 .77686 L p .707 .577 .707 r
F P
0 g
s
.68162 .68467 m .68347 .73881 L .6998 .72884 L p .707 .577 .707 r
F P
0 g
s
.6998 .72884 m .69795 .67471 L .68162 .68467 L p .707 .577 .707 r
F P
0 g
s
.5695 .81367 m .56746 .77837 L .53998 .7733 L p .707 .577 .707 r
F P
0 g
s
.56746 .77837 m .5695 .81367 L .60065 .8149 L p .707 .577 .707 r
F P
0 g
s
.65969 .77043 m .66173 .80573 L .68567 .79624 L p .707 .577 .707 r
F P
0 g
s
.68567 .79624 m .68363 .76093 L .65969 .77043 L p .707 .577 .707 r
F P
0 g
s
.51674 .68593 m .51859 .74007 L .53966 .74772 L p .707 .577 .707 r
F P
0 g
s
.51859 .74007 m .51674 .68593 L .50411 .67619 L p .707 .577 .707 r
F P
0 g
s
.60242 .8511 m .60137 .83348 L .57022 .83227 L p .707 .577 .707 r
F P
0 g
s
.60137 .83348 m .60242 .8511 L .6342 .84831 L p .707 .577 .707 r
F P
0 g
s
.6342 .84831 m .63315 .83069 L .60137 .83348 L p .707 .577 .707 r
F P
0 g
s
.53998 .7733 m .54202 .80861 L .5695 .81367 L p .707 .577 .707 r
F P
0 g
s
.54202 .80861 m .53998 .7733 L .51887 .76489 L p .707 .577 .707 r
F P
0 g
s
.63315 .83069 m .6342 .84831 L .66349 .8418 L p .707 .577 .707 r
F P
0 g
s
.66349 .8418 m .66244 .82418 L .63315 .83069 L p .707 .577 .707 r
F P
0 g
s
.57127 .84989 m .57022 .83227 L .54274 .82718 L p .707 .577 .707 r
F P
0 g
s
.57022 .83227 m .57127 .84989 L .60242 .8511 L p .707 .577 .707 r
F P
0 g
s
.69795 .67471 m .6998 .72884 L .70684 .71788 L p .707 .577 .707 r
F P
0 g
s
.70684 .71788 m .70499 .66375 L .69795 .67471 L p .707 .577 .707 r
F P
0 g
s
.68363 .76093 m .68567 .79624 L .70192 .78461 L p .707 .577 .707 r
F P
0 g
s
.70192 .78461 m .69988 .7493 L .68363 .76093 L p .707 .577 .707 r
F P
0 g
s
.66244 .82418 m .66349 .8418 L .68743 .83221 L p .707 .577 .707 r
F P
0 g
s
.68743 .83221 m .68638 .81458 L .66244 .82418 L p .707 .577 .707 r
F P
0 g
s
.54274 .82718 m .54379 .84481 L .57127 .84989 L p .707 .577 .707 r
F P
0 g
s
.50411 .67619 m .50596 .73033 L .51859 .74007 L p .707 .577 .707 r
F P
0 g
s
.51887 .76489 m .52091 .80019 L .54202 .80861 L p .707 .577 .707 r
F P
0 g
s
.54379 .84481 m .54274 .82718 L .52163 .81872 L p .707 .577 .707 r
F P
0 g
s
.52091 .80019 m .51887 .76489 L .50619 .75395 L p .707 .577 .707 r
F P
0 g
s
.50596 .73033 m .50411 .67619 L .50118 .66531 L p .707 .577 .707 r
F P
0 g
s
.52163 .81872 m .52268 .83634 L .54379 .84481 L p .707 .577 .707 r
F P
0 g
s
.68638 .81458 m .68743 .83221 L .70367 .82046 L p .707 .577 .707 r
F P
0 g
s
.70367 .82046 m .70262 .80284 L .68638 .81458 L p .707 .577 .707 r
F P
0 g
s
.69988 .7493 m .70192 .78461 L .70888 .77198 L p .707 .577 .707 r
F P
0 g
s
.70888 .77198 m .70684 .73667 L .69988 .7493 L p .707 .577 .707 r
F P
0 g
s
.50619 .75395 m .50823 .78926 L .52091 .80019 L p .707 .577 .707 r
F P
0 g
s
.70499 .66375 m .70684 .71788 L .7039 .707 L p .707 .577 .707 r
F P
0 g
s
.7039 .707 m .70205 .65286 L .70499 .66375 L p .707 .577 .707 r
F P
0 g
s
.50118 .66531 m .50303 .71944 L .50596 .73033 L p .707 .577 .707 r
F P
0 g
s
.52268 .83634 m .52163 .81872 L .50895 .8077 L p .707 .577 .707 r
F P
0 g
s
.50823 .78926 m .50619 .75395 L .50319 .74156 L p .707 .577 .707 r
F P
0 g
s
.50895 .8077 m .51 .82533 L .52268 .83634 L p .707 .577 .707 r
F P
0 g
s
.50303 .71944 m .50118 .66531 L .50822 .65435 L p .707 .577 .707 r
F P
0 g
s
.70262 .80284 m .70367 .82046 L .71063 .80772 L p .707 .577 .707 r
F P
0 g
s
.71063 .80772 m .70958 .7901 L .70262 .80284 L p .707 .577 .707 r
F P
0 g
s
.70684 .73667 m .70888 .77198 L .70588 .75959 L p .707 .577 .707 r
F P
0 g
s
.70588 .75959 m .70384 .72429 L .70684 .73667 L p .707 .577 .707 r
F P
0 g
s
.50319 .74156 m .50523 .77687 L .50823 .78926 L p .707 .577 .707 r
F P
0 g
s
.70205 .65286 m .7039 .707 L .69128 .69726 L p .707 .577 .707 r
F P
0 g
s
.69128 .69726 m .68943 .64312 L .70205 .65286 L p .707 .577 .707 r
F P
0 g
s
.51 .82533 m .50895 .8077 L .50594 .79521 L p .707 .577 .707 r
F P
0 g
s
.50822 .65435 m .51007 .70848 L .50303 .71944 L p .707 .577 .707 r
F P
0 g
s
.50523 .77687 m .50319 .74156 L .51015 .72894 L p .707 .577 .707 r
F P
0 g
s
.50594 .79521 m .50698 .81284 L .51 .82533 L p .707 .577 .707 r
F P
0 g
s
.25529 .71719 m .25344 .66306 L .22227 .66157 L p .707 .577 .707 r
F P
0 g
s
.25344 .66306 m .25529 .71719 L .2871 .71522 L p .707 .577 .707 r
F P
0 g
s
.2871 .71522 m .28525 .66109 L .25344 .66306 L p .707 .577 .707 r
F P
0 g
s
.51007 .70848 m .50822 .65435 L .52454 .64438 L p .707 .577 .707 r
F P
0 g
s
.28525 .66109 m .2871 .71522 L .31645 .70998 L p .707 .577 .707 r
F P
0 g
s
.31645 .70998 m .3146 .65585 L .28525 .66109 L p .707 .577 .707 r
F P
0 g
s
.70958 .7901 m .71063 .80772 L .70762 .79523 L p .707 .577 .707 r
F P
0 g
s
.70762 .79523 m .70657 .77761 L .70958 .7901 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22412 .7157 m .22227 .66157 L .1948 .65677 L p .707 .577 .707 r
F P
0 g
s
.22227 .66157 m .22412 .7157 L .25529 .71719 L p .707 .577 .707 r
F P
0 g
s
.70384 .72429 m .70588 .75959 L .6932 .74866 L p .707 .577 .707 r
F P
0 g
s
.6932 .74866 m .69116 .71335 L .70384 .72429 L p .707 .577 .707 r
F P
0 g
s
.51015 .72894 m .51219 .76424 L .50523 .77687 L p .707 .577 .707 r
F P
0 g
s
.68943 .64312 m .69128 .69726 L .6702 .68961 L p .707 .577 .707 r
F P
0 g
s
.6702 .68961 m .66835 .63547 L .68943 .64312 L p .707 .577 .707 r
F P
0 g
s
.3146 .65585 m .31645 .70998 L .34046 .70199 L p .707 .577 .707 r
F P
0 g
s
.34046 .70199 m .33861 .64786 L .3146 .65585 L p .707 .577 .707 r
F P
0 g
s
.50698 .81284 m .50594 .79521 L .51289 .78247 L p .707 .577 .707 r
F P
0 g
s
.52454 .64438 m .52639 .69852 L .51007 .70848 L p .707 .577 .707 r
F P
0 g
s
.19665 .7109 m .1948 .65677 L .17373 .64912 L p .707 .577 .707 r
F P
0 g
s
.1948 .65677 m .19665 .7109 L .22412 .7157 L p .707 .577 .707 r
F P
0 g
s
.52639 .69852 m .52454 .64438 L .54856 .63639 L p .707 .577 .707 r
F P
0 g
s
.51219 .76424 m .51015 .72894 L .5264 .71731 L p .707 .577 .707 r
F P
0 g
s
.51289 .78247 m .51394 .8001 L .50698 .81284 L p .707 .577 .707 r
F P
0 g
s
.25764 .77808 m .2556 .74278 L .22445 .74155 L p .707 .577 .707 r
F P
0 g
s
.2556 .74278 m .25764 .77808 L .28942 .77535 L p .707 .577 .707 r
F P
0 g
s
.28942 .77535 m .28738 .74004 L .2556 .74278 L p .707 .577 .707 r
F P
0 g
s
.28738 .74004 m .28942 .77535 L .31872 .76892 L p .707 .577 .707 r
F P
0 g
s
.31872 .76892 m .31668 .73361 L .28738 .74004 L p .707 .577 .707 r
F P
0 g
s
.70657 .77761 m .70762 .79523 L .69493 .78422 L p .707 .577 .707 r
F P
0 g
s
.69493 .78422 m .69389 .76659 L .70657 .77761 L p .707 .577 .707 r
F P
0 g
s
.33861 .64786 m .34046 .70199 L .35679 .69203 L p .707 .577 .707 r
F P
0 g
s
.35679 .69203 m .35494 .63789 L .33861 .64786 L p .707 .577 .707 r
F P
0 g
s
.22649 .77686 m .22445 .74155 L .19697 .73648 L p .707 .577 .707 r
F P
0 g
s
.22445 .74155 m .22649 .77686 L .25764 .77808 L p .707 .577 .707 r
F P
0 g
s
.66835 .63547 m .6702 .68961 L .64274 .6848 L p .707 .577 .707 r
F P
0 g
s
.64274 .6848 m .64089 .63067 L .66835 .63547 L p .707 .577 .707 r
F P
0 g
s
.69116 .71335 m .6932 .74866 L .67209 .74025 L p .707 .577 .707 r
F P
0 g
s
.67209 .74025 m .67005 .70494 L .69116 .71335 L p .707 .577 .707 r
F P
0 g
s
.5264 .71731 m .52844 .75261 L .51219 .76424 L p .707 .577 .707 r
F P
0 g
s
.31668 .73361 m .31872 .76892 L .34266 .75942 L p .707 .577 .707 r
F P
0 g
s
.34266 .75942 m .34062 .72412 L .31668 .73361 L p .707 .577 .707 r
F P
0 g
s
.17373 .64912 m .17558 .70325 L .19665 .7109 L p .707 .577 .707 r
F P
0 g
s
.55041 .69052 m .54856 .63639 L .57791 .63115 L p .707 .577 .707 r
F P
0 g
s
.54856 .63639 m .55041 .69052 L .52639 .69852 L p .707 .577 .707 r
F P
0 g
s
.17558 .70325 m .17373 .64912 L .16111 .63938 L p .707 .577 .707 r
F P
0 g
s
.51394 .8001 m .51289 .78247 L .52914 .77073 L p .707 .577 .707 r
F P
0 g
s
.25941 .81429 m .25837 .79666 L .22721 .79546 L p .707 .577 .707 r
F P
0 g
s
.25837 .79666 m .25941 .81429 L .29119 .8115 L p .707 .577 .707 r
F P
0 g
s
.29119 .8115 m .29014 .79387 L .25837 .79666 L p .707 .577 .707 r
F P
0 g
s
.19697 .73648 m .19901 .77179 L .22649 .77686 L p .707 .577 .707 r
F P
0 g
s
.19901 .77179 m .19697 .73648 L .17586 .72807 L p .707 .577 .707 r
F P
0 g
s
.49165 .79215 m .52755 .27489 L .48359 .27092 L p .707 .577 .707 r
F P
0 g
s
.52844 .75261 m .5264 .71731 L .55034 .70781 L p .707 .577 .707 r
F P
0 g
s
.52914 .77073 m .53018 .78835 L .51394 .8001 L p .707 .577 .707 r
F P
0 g
s
.55034 .70781 m .55238 .74312 L .52844 .75261 L p .707 .577 .707 r
F P
0 g
s
.53018 .78835 m .52914 .77073 L .55307 .76113 L p .707 .577 .707 r
F P
0 g
s
.55307 .76113 m .55412 .77876 L .53018 .78835 L p .707 .577 .707 r
F P
0 g
s
.52755 .27489 m .49165 .79215 L .53647 .7948 L p .707 .577 .707 r
F P
0 g
s
.53647 .7948 m .57236 .27754 L .52755 .27489 L p .707 .577 .707 r
F P
0 g
s
.29014 .79387 m .29119 .8115 L .32048 .80499 L p .707 .577 .707 r
F P
0 g
s
.32048 .80499 m .31943 .78736 L .29014 .79387 L p .707 .577 .707 r
F P
0 g
s
.64089 .63067 m .64274 .6848 L .61157 .68332 L p .707 .577 .707 r
F P
0 g
s
.61157 .68332 m .60972 .62918 L .64089 .63067 L p .707 .577 .707 r
F P
0 g
s
.57791 .63115 m .57976 .68529 L .55041 .69052 L p .707 .577 .707 r
F P
0 g
s
.55238 .74312 m .55034 .70781 L .57964 .70138 L p .707 .577 .707 r
F P
0 g
s
.57964 .70138 m .58168 .73669 L .55238 .74312 L p .707 .577 .707 r
F P
0 g
s
.55412 .77876 m .55307 .76113 L .58237 .75462 L p .707 .577 .707 r
F P
0 g
s
.58237 .75462 m .58341 .77225 L .55412 .77876 L p .707 .577 .707 r
F P
0 g
s
.57236 .27754 m .53647 .7948 L .57774 .79587 L p .707 .577 .707 r
F P
0 g
s
.57976 .68529 m .57791 .63115 L .60972 .62918 L p .707 .577 .707 r
F P
0 g
s
.60972 .62918 m .61157 .68332 L .57976 .68529 L p .707 .577 .707 r
F P
0 g
s
.58168 .73669 m .57964 .70138 L .61142 .69865 L p .707 .577 .707 r
F P
0 g
s
.61142 .69865 m .61346 .73395 L .58168 .73669 L p .707 .577 .707 r
F P
0 g
s
.57774 .79587 m .61364 .27861 L .57236 .27754 L p .707 .577 .707 r
F P
0 g
s
.22826 .81308 m .22721 .79546 L .19974 .79037 L p .707 .577 .707 r
F P
0 g
s
.22721 .79546 m .22826 .81308 L .25941 .81429 L p .707 .577 .707 r
F P
0 g
s
.35494 .63789 m .35679 .69203 L .36383 .68107 L p .707 .577 .707 r
F P
0 g
s
.36383 .68107 m .36198 .62693 L .35494 .63789 L p .707 .577 .707 r
F P
0 g
s
.69389 .76659 m .69493 .78422 L .67382 .77575 L p .707 .577 .707 r
F P
0 g
s
.67382 .77575 m .67277 .75813 L .69389 .76659 L p .707 .577 .707 r
F P
0 g
s
.34062 .72412 m .34266 .75942 L .35891 .74779 L p .707 .577 .707 r
F P
0 g
s
.35891 .74779 m .35687 .71249 L .34062 .72412 L p .707 .577 .707 r
F P
0 g
s
.44769 .78817 m .48359 .27092 L .44478 .26601 L p .707 .577 .707 r
F P
0 g
s
.48359 .27092 m .44769 .78817 L .49165 .79215 L p .707 .577 .707 r
F P
0 g
s
.67005 .70494 m .67209 .74025 L .64461 .73518 L p .707 .577 .707 r
F P
0 g
s
.64461 .73518 m .64257 .69987 L .67005 .70494 L p .707 .577 .707 r
F P
0 g
s
.31943 .78736 m .32048 .80499 L .34442 .79539 L p .707 .577 .707 r
F P
0 g
s
.34442 .79539 m .34337 .77777 L .31943 .78736 L p .707 .577 .707 r
F P
0 g
s
.19974 .79037 m .20078 .80799 L .22826 .81308 L p .707 .577 .707 r
F P
0 g
s
.16111 .63938 m .16295 .69351 L .17558 .70325 L p .707 .577 .707 r
F P
0 g
s
.17586 .72807 m .1779 .76338 L .19901 .77179 L p .707 .577 .707 r
F P
0 g
s
.20078 .80799 m .19974 .79037 L .17862 .7819 L p .707 .577 .707 r
F P
0 g
s
.1779 .76338 m .17586 .72807 L .16318 .71714 L p .707 .577 .707 r
F P
0 g
s
.16295 .69351 m .16111 .63938 L .15817 .62849 L p .707 .577 .707 r
F P
0 g
s
.61346 .73395 m .61142 .69865 L .64257 .69987 L p .707 .577 .707 r
F P
0 g
s
.58341 .77225 m .58237 .75462 L .61414 .75183 L p .707 .577 .707 r
F P
0 g
s
.61414 .75183 m .61519 .76946 L .58341 .77225 L p .707 .577 .707 r
F P
0 g
s
.61364 .27861 m .57774 .79587 L .61144 .79525 L p .707 .577 .707 r
F P
0 g
s
.64257 .69987 m .64461 .73518 L .61346 .73395 L p .707 .577 .707 r
F P
0 g
s
.61519 .76946 m .61414 .75183 L .6453 .75304 L p .707 .577 .707 r
F P
0 g
s
.61144 .79525 m .64734 .278 L .61364 .27861 L p .707 .577 .707 r
F P
0 g
s
.17862 .7819 m .17967 .79953 L .20078 .80799 L p .707 .577 .707 r
F P
0 g
s
.34337 .77777 m .34442 .79539 L .36066 .78365 L p .707 .577 .707 r
F P
0 g
s
.36066 .78365 m .35962 .76602 L .34337 .77777 L p .707 .577 .707 r
F P
0 g
s
.67277 .75813 m .67382 .77575 L .64634 .77067 L p .707 .577 .707 r
F P
0 g
s
.64634 .77067 m .6453 .75304 L .67277 .75813 L p .707 .577 .707 r
F P
0 g
s
.40888 .78326 m .44478 .26601 L .41492 .26064 L p .707 .577 .707 r
F P
0 g
s
.44478 .26601 m .40888 .78326 L .44769 .78817 L p .707 .577 .707 r
F P
0 g
s
.35687 .71249 m .35891 .74779 L .36587 .73517 L p .707 .577 .707 r
F P
0 g
s
.36587 .73517 m .36383 .69986 L .35687 .71249 L p .707 .577 .707 r
F P
0 g
s
.16318 .71714 m .16522 .75244 L .1779 .76338 L p .707 .577 .707 r
F P
0 g
s
.36198 .62693 m .36383 .68107 L .36089 .67018 L p .707 .577 .707 r
F P
0 g
s
.36089 .67018 m .35904 .61605 L .36198 .62693 L p .707 .577 .707 r
F P
0 g
s
.15817 .62849 m .16002 .68263 L .16295 .69351 L p .707 .577 .707 r
F P
0 g
s
.17967 .79953 m .17862 .7819 L .16594 .77089 L p .707 .577 .707 r
F P
0 g
s
.6453 .75304 m .64634 .77067 L .61519 .76946 L p .707 .577 .707 r
F P
0 g
s
.16522 .75244 m .16318 .71714 L .16018 .70475 L p .707 .577 .707 r
F P
0 g
s
.16594 .77089 m .16699 .78851 L .17967 .79953 L p .707 .577 .707 r
F P
0 g
s
.16002 .68263 m .15817 .62849 L .16521 .61753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64734 .278 m .61144 .79525 L .63426 .79301 L p .707 .577 .707 r
F P
0 g
s
.63426 .79301 m .67016 .27576 L .64734 .278 L p .707 .577 .707 r
F P
0 g
s
.35962 .76602 m .36066 .78365 L .36762 .77091 L p .707 .577 .707 r
F P
0 g
s
.36762 .77091 m .36657 .75328 L .35962 .76602 L p .707 .577 .707 r
F P
0 g
s
.36383 .69986 m .36587 .73517 L .36287 .72278 L p .707 .577 .707 r
F P
0 g
s
.36287 .72278 m .36083 .68747 L .36383 .69986 L p .707 .577 .707 r
F P
0 g
s
.16018 .70475 m .16222 .74006 L .16522 .75244 L p .707 .577 .707 r
F P
0 g
s
.37902 .7779 m .41492 .26064 L .39694 .25536 L p .707 .577 .707 r
F P
0 g
s
.41492 .26064 m .37902 .7779 L .40888 .78326 L p .707 .577 .707 r
F P
0 g
s
.35904 .61605 m .36089 .67018 L .34827 .66044 L p .707 .577 .707 r
F P
0 g
s
.34827 .66044 m .34642 .60631 L .35904 .61605 L p .707 .577 .707 r
F P
0 g
s
.16699 .78851 m .16594 .77089 L .16293 .7584 L p .707 .577 .707 r
F P
0 g
s
.16521 .61753 m .16706 .67166 L .16002 .68263 L p .707 .577 .707 r
F P
0 g
s
.16222 .74006 m .16018 .70475 L .16714 .69212 L p .707 .577 .707 r
F P
0 g
s
.16293 .7584 m .16397 .77602 L .16699 .78851 L p .707 .577 .707 r
F P
0 g
s
.16706 .67166 m .16521 .61753 L .18153 .60757 L p .707 .577 .707 r
F P
0 g
s
.36657 .75328 m .36762 .77091 L .36461 .75842 L p .707 .577 .707 r
F P
0 g
s
.36461 .75842 m .36356 .74079 L .36657 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.67016 .27576 m .63426 .79301 L .64397 .78936 L p .707 .577 .707 r
F P
0 g
s
.67687 .6597 m .67502 .60557 L .66103 .60049 L p .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .66117 .54158 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .63963 .78466 L p .65197 .62748 L .707 .577 .707 r
F P
0 g
s
.65197 .62748 m .65277 .62262 L .64397 .78936 L .707 .577 .707 r
F
.65362 .60643 m .65409 .60236 L .64397 .78936 L F
.66117 .54158 m .6596 .5642 L p .65409 .60236 L F P
0 g
s
.6596 .5642 m .64397 .78936 L p .65409 .60236 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .62164 .77937 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .64132 .58818 L p .64995 .62627 L .707 .577 .707 r
F P
0 g
s
.65056 .6266 m .65394 .59792 L .64995 .62627 L .707 .577 .707 r
F
.63842 .61998 m .64248 .6222 L .63963 .78466 L F
.65059 .62662 m .64699 .67851 L p .64248 .6222 L F P
0 g
s
.64699 .67851 m .63963 .78466 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64132 .58818 L .6391 .57993 L p .707 .577 .707 r
F P
0 g
s
.65409 .60236 m .65394 .59792 L p .65056 .6266 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .65056 .6266 L .65037 .62814 L .707 .577 .707 r
F
.65409 .60236 m .65056 .6266 L .65059 .62662 L F
.67987 .27211 m .67016 .27576 L p .66139 .44768 L F P
0 g
s
.66117 .54158 m .67987 .27211 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64132 .58818 m .64248 .6222 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .64132 .58818 L .64781 .6459 L .707 .577 .707 r
F
.65754 .26212 m .67552 .26741 L p .63842 .61998 L F P
0 g
s
.62164 .77937 m .63291 .61698 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.63291 .61698 m .65754 .26212 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64781 .6459 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64317 .64231 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .65059 .62662 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.64781 .6459 m .65579 .65205 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65458 .59815 m .65394 .59792 L p .65445 .59929 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .65579 .65205 L .67687 .6597 L p .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .67987 .27211 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .67552 .26741 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .65059 .62662 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64248 .6222 L p .63838 .57729 L .707 .577 .707 r
F P
0 g
s
.6391 .57993 m .63838 .57729 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .65056 .6266 L .64995 .62627 L .707 .577 .707 r
F
.65197 .62748 m .65362 .60643 L .65277 .62262 L F
.67987 .27211 m .66117 .54158 L p .65362 .60643 L F P
0 g
s
.65579 .65205 m .65409 .60236 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .65607 .68305 L .64447 .67304 L p .707 .577 .707 r
F P
0 g
s
.64447 .67304 m .64339 .67211 L p .6442 .67465 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .64447 .67304 L .6442 .67465 L .707 .577 .707 r
F
.66103 .60049 m .65458 .59815 L p .66099 .61691 L F P
0 g
s
.66099 .61691 m .65458 .59815 L .65445 .59929 L .707 .577 .707 r
F
.67687 .6597 m .66103 .60049 L .66099 .61691 L F
.36083 .68747 m .36287 .72278 L .35019 .71184 L p F P
0 g
s
.35019 .71184 m .34815 .67654 L .36083 .68747 L p .707 .577 .707 r
F P
0 g
s
.16714 .69212 m .16918 .72743 L .16222 .74006 L p .707 .577 .707 r
F P
0 g
s
.34642 .60631 m .34827 .66044 L .32719 .65279 L p .707 .577 .707 r
F P
0 g
s
.32719 .65279 m .32534 .59866 L .34642 .60631 L p .707 .577 .707 r
F P
0 g
s
.16397 .77602 m .16293 .7584 L .16988 .74566 L p .707 .577 .707 r
F P
0 g
s
.18153 .60757 m .18338 .6617 L .16706 .67166 L p .707 .577 .707 r
F P
0 g
s
.36356 .74079 m .36461 .75842 L .35193 .7474 L p .707 .577 .707 r
F P
0 g
s
.35193 .7474 m .35088 .72978 L .36356 .74079 L p .707 .577 .707 r
F P
0 g
s
.36104 .77261 m .39694 .25536 L .39259 .25066 L p .707 .577 .707 r
F P
0 g
s
.39694 .25536 m .36104 .77261 L .37902 .7779 L p .707 .577 .707 r
F P
0 g
s
.18338 .6617 m .18153 .60757 L .20555 .59957 L p .707 .577 .707 r
F P
0 g
s
.16918 .72743 m .16714 .69212 L .18339 .68049 L p .707 .577 .707 r
F P
0 g
s
.16988 .74566 m .17093 .76328 L .16397 .77602 L p .707 .577 .707 r
F P
0 g
s
.32534 .59866 m .32719 .65279 L .29973 .64799 L p .707 .577 .707 r
F P
0 g
s
.29973 .64799 m .29788 .59386 L .32534 .59866 L p .707 .577 .707 r
F P
0 g
s
.34815 .67654 m .35019 .71184 L .32908 .70343 L p .707 .577 .707 r
F P
0 g
s
.32908 .70343 m .32704 .66812 L .34815 .67654 L p .707 .577 .707 r
F P
0 g
s
.18339 .68049 m .18543 .7158 L .16918 .72743 L p .707 .577 .707 r
F P
0 g
s
.2074 .65371 m .20555 .59957 L .2349 .59434 L p .707 .577 .707 r
F P
0 g
s
.20555 .59957 m .2074 .65371 L .18338 .6617 L p .707 .577 .707 r
F P
0 g
s
.17093 .76328 m .16988 .74566 L .18613 .73392 L p .707 .577 .707 r
F P
0 g
s
.18543 .7158 m .18339 .68049 L .20733 .671 L p .707 .577 .707 r
F P
0 g
s
.29788 .59386 m .29973 .64799 L .26856 .6465 L p .707 .577 .707 r
F P
0 g
s
.26856 .6465 m .26671 .59237 L .29788 .59386 L p .707 .577 .707 r
F P
0 g
s
.18613 .73392 m .18717 .75154 L .17093 .76328 L p .707 .577 .707 r
F P
0 g
s
.23675 .64847 m .2349 .59434 L .26671 .59237 L p .707 .577 .707 r
F P
0 g
s
.2349 .59434 m .23675 .64847 L .2074 .65371 L p .707 .577 .707 r
F P
0 g
s
.26671 .59237 m .26856 .6465 L .23675 .64847 L p .707 .577 .707 r
F P
0 g
s
.35088 .72978 m .35193 .7474 L .33081 .73894 L p .707 .577 .707 r
F P
0 g
s
.33081 .73894 m .32976 .72131 L .35088 .72978 L p .707 .577 .707 r
F P
0 g
s
.32704 .66812 m .32908 .70343 L .3016 .69836 L p .707 .577 .707 r
F P
0 g
s
.3016 .69836 m .29956 .66306 L .32704 .66812 L p .707 .577 .707 r
F P
0 g
s
.20733 .671 m .20937 .7063 L .18543 .7158 L p .707 .577 .707 r
F P
0 g
s
.7355 .66599 m .73365 .61186 L .70248 .61037 L p .707 .577 .707 r
F P
0 g
s
.73365 .61186 m .7355 .66599 L .76731 .66402 L p .707 .577 .707 r
F P
0 g
s
.76731 .66402 m .76546 .60989 L .73365 .61186 L p .707 .577 .707 r
F P
0 g
s
.39259 .25066 m .35669 .76791 L .36104 .77261 L p .707 .577 .707 r
F P
0 g
s
.35669 .76791 m .39259 .25066 L .4023 .24701 L p .707 .577 .707 r
F P
0 g
s
.76546 .60989 m .76731 .66402 L .79666 .65879 L p .707 .577 .707 r
F P
0 g
s
.79666 .65879 m .79481 .60465 L .76546 .60989 L p .707 .577 .707 r
F P
0 g
s
.20937 .7063 m .20733 .671 L .23663 .66457 L p .707 .577 .707 r
F P
0 g
s
.18717 .75154 m .18613 .73392 L .21006 .72432 L p .707 .577 .707 r
F P
0 g
s
.70433 .6645 m .70248 .61037 L .67502 .60557 L p .707 .577 .707 r
F P
0 g
s
.70248 .61037 m .70433 .6645 L .7355 .66599 L p .707 .577 .707 r
F P
0 g
s
.29956 .66306 m .3016 .69836 L .27045 .69714 L p .707 .577 .707 r
F P
0 g
s
.27045 .69714 m .26841 .66183 L .29956 .66306 L p .707 .577 .707 r
F P
0 g
s
.21006 .72432 m .21111 .74194 L .18717 .75154 L p .707 .577 .707 r
F P
0 g
s
.23867 .69987 m .23663 .66457 L .26841 .66183 L p .707 .577 .707 r
F P
0 g
s
.23663 .66457 m .23867 .69987 L .20937 .7063 L p .707 .577 .707 r
F P
0 g
s
.79481 .60465 m .79666 .65879 L .82068 .65079 L p .707 .577 .707 r
F P
0 g
s
.82068 .65079 m .81883 .59666 L .79481 .60465 L p .707 .577 .707 r
F P
0 g
s
.32976 .72131 m .33081 .73894 L .30333 .73385 L p .707 .577 .707 r
F P
0 g
s
.30333 .73385 m .30229 .71623 L .32976 .72131 L p .707 .577 .707 r
F P
0 g
s
.26841 .66183 m .27045 .69714 L .23867 .69987 L p .707 .577 .707 r
F P
0 g
s
.67502 .60557 m .67687 .6597 L .70433 .6645 L p .707 .577 .707 r
F P
0 g
s
.21111 .74194 m .21006 .72432 L .23936 .71781 L p .707 .577 .707 r
F P
0 g
s
.73785 .73306 m .73581 .69776 L .70466 .69653 L p .707 .577 .707 r
F P
0 g
s
.73581 .69776 m .73785 .73306 L .76963 .73033 L p .707 .577 .707 r
F P
0 g
s
.76963 .73033 m .76759 .69502 L .73581 .69776 L p .707 .577 .707 r
F P
0 g
s
.30229 .71623 m .30333 .73385 L .27218 .73264 L p .707 .577 .707 r
F P
0 g
s
.27218 .73264 m .27113 .71502 L .30229 .71623 L p .707 .577 .707 r
F P
0 g
s
.76759 .69502 m .76963 .73033 L .79893 .7239 L p .707 .577 .707 r
F P
0 g
s
.79893 .7239 m .79689 .68859 L .76759 .69502 L p .707 .577 .707 r
F P
0 g
s
.23936 .71781 m .2404 .73543 L .21111 .74194 L p .707 .577 .707 r
F P
0 g
s
.81883 .59666 m .82068 .65079 L .837 .64083 L p .707 .577 .707 r
F P
0 g
s
.837 .64083 m .83515 .5867 L .81883 .59666 L p .707 .577 .707 r
F P
0 g
s
.2404 .73543 m .23936 .71781 L .27113 .71502 L p .707 .577 .707 r
F P
0 g
s
.7067 .73184 m .70466 .69653 L .67718 .69146 L p .707 .577 .707 r
F P
0 g
s
.70466 .69653 m .7067 .73184 L .73785 .73306 L p .707 .577 .707 r
F P
0 g
s
.27113 .71502 m .27218 .73264 L .2404 .73543 L p .707 .577 .707 r
F P
0 g
s
.79689 .68859 m .79893 .7239 L .82288 .7144 L p .707 .577 .707 r
F P
0 g
s
.82288 .7144 m .82084 .67909 L .79689 .68859 L p .707 .577 .707 r
F P
0 g
s
.3664 .76426 m .4023 .24701 L .42512 .24476 L p .707 .577 .707 r
F P
0 g
s
.4023 .24701 m .3664 .76426 L .35669 .76791 L p .707 .577 .707 r
F P
0 g
s
.67718 .69146 m .67922 .72677 L .7067 .73184 L p .707 .577 .707 r
F P
0 g
s
.67922 .72677 m .67718 .69146 L .65607 .68305 L p .707 .577 .707 r
F P
0 g
s
.73963 .77906 m .73858 .76143 L .70743 .76022 L p .707 .577 .707 r
F P
0 g
s
.73858 .76143 m .73963 .77906 L .7714 .77627 L p .707 .577 .707 r
F P
0 g
s
.7714 .77627 m .77036 .75864 L .73858 .76143 L p .707 .577 .707 r
F P
0 g
s
.77036 .75864 m .7714 .77627 L .8007 .76976 L p .707 .577 .707 r
F P
0 g
s
.8007 .76976 m .79965 .75213 L .77036 .75864 L p .707 .577 .707 r
F P
0 g
s
.83515 .5867 m .837 .64083 L .84404 .62987 L p .707 .577 .707 r
F P
0 g
s
.84404 .62987 m .84219 .57573 L .83515 .5867 L p .707 .577 .707 r
F P
0 g
s
.70847 .77785 m .70743 .76022 L .67995 .75514 L p .707 .577 .707 r
F P
0 g
s
.70743 .76022 m .70847 .77785 L .73963 .77906 L p .707 .577 .707 r
F P
0 g
s
.82084 .67909 m .82288 .7144 L .83912 .70277 L p .707 .577 .707 r
F P
0 g
s
.83912 .70277 m .83709 .66746 L .82084 .67909 L p .707 .577 .707 r
F P
0 g
s
.65607 .68305 m .65811 .71836 L .67922 .72677 L p .707 .577 .707 r
F P
0 g
s
.79965 .75213 m .8007 .76976 L .82463 .76016 L p .707 .577 .707 r
F P
0 g
s
.82463 .76016 m .82359 .74253 L .79965 .75213 L p .707 .577 .707 r
F P
0 g
s
.67995 .75514 m .681 .77276 L .70847 .77785 L p .707 .577 .707 r
F P
0 g
s
.65754 .26212 m .62164 .77937 L .59178 .77401 L p .707 .577 .707 r
F P
0 g
s
.59178 .77401 m .62768 .25676 L .65754 .26212 L p .707 .577 .707 r
F P
0 g
s
.681 .77276 m .67995 .75514 L .65883 .74667 L p .707 .577 .707 r
F P
0 g
s
.65883 .74667 m .65988 .7643 L .681 .77276 L p .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .3664 .76426 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .38923 .76202 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.42512 .24476 m .45882 .24415 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .40642 .51423 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .42512 .24476 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.42261 .57752 m .42245 .57307 L .42149 .57313 L p .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .38923 .76202 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.42245 .57307 m .42261 .57752 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .43389 .60337 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .42292 .7614 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.47547 .60008 m .4642 .76248 L p .44794 .61369 L .707 .577 .707 r
F P
0 g
s
.4467 .60236 m .45297 .60186 L .44794 .61369 L .707 .577 .707 r
F
.45297 .60186 m .47547 .60008 L .44794 .61369 L F
.4518 .56784 m .45297 .60186 L p .46069 .58368 L F P
0 g
s
.4518 .56784 m .42245 .57307 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45365 .62197 m .45297 .60186 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45297 .60186 m .4518 .56784 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .47547 .60008 L p .45297 .60186 L .707 .577 .707 r
F P
0 g
s
.5001 .24522 m .54491 .24787 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .47972 .53888 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .5001 .24522 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47582 .55984 L .47368 .56056 L p .707 .577 .707 r
F P
0 g
s
.47368 .56056 m .46999 .56178 L p .47115 .56966 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47368 .56056 L .47115 .56966 L .707 .577 .707 r
F
.46999 .56178 m .4518 .56784 L p .46069 .58368 L F P
0 g
s
.47767 .61398 m .46999 .56178 L .46069 .58368 L .707 .577 .707 r
F
.5001 .24522 m .47972 .53888 L p .4467 .60236 L F P
0 g
s
.4467 .60236 m .47972 .53888 L .45297 .60186 L .707 .577 .707 r
F
.45365 .62197 m .47767 .61398 L p .46069 .58368 L F P
0 g
s
.45297 .60186 m .45365 .62197 L p .46069 .58368 L .707 .577 .707 r
F P
0 g
s
.44286 .6239 m .45365 .62197 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.44031 .60286 m .42261 .57752 L .43389 .60337 L .707 .577 .707 r
F
.44031 .60286 m .43389 .60337 L .44286 .6239 L F
.45365 .62197 m .44141 .60277 L .44031 .60286 L F
.44141 .60277 m .42245 .57307 L .44031 .60286 L F
.45882 .24415 m .5001 .24522 L p .4467 .60236 L F P
0 g
s
.43389 .60337 m .45882 .24415 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.45882 .24415 m .43389 .60337 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.43279 .61928 m .42292 .7614 L p .41704 .59132 L .707 .577 .707 r
F P
0 g
s
.45592 .68708 m .4542 .65728 L p .42459 .6582 L .707 .577 .707 r
F P
0 g
s
.4542 .65728 m .45388 .65177 L .4514 .65232 L p .707 .577 .707 r
F P
0 g
s
.4514 .65232 m .42459 .6582 L p .4542 .65728 L .707 .577 .707 r
F P
0 g
s
.43389 .60337 m .43279 .61928 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.41604 .56248 m .43279 .61928 L .41704 .59132 L .707 .577 .707 r
F
.42261 .57752 m .4243 .62721 L .44286 .6239 L p F P
0 g
s
.4243 .62721 m .42261 .57752 L p .39064 .57504 L .707 .577 .707 r
F P
0 g
s
.42149 .57313 m .39064 .57504 L p .42261 .57752 L .707 .577 .707 r
F P
0 g
s
.39064 .57504 m .39249 .62918 L .41659 .62769 L p .707 .577 .707 r
F P
0 g
s
.41659 .62769 m .4243 .62721 L p .4153 .61325 L .707 .577 .707 r
F P
0 g
s
.4153 .61325 m .39064 .57504 L .41659 .62769 L .707 .577 .707 r
F
.42512 .24476 m .40642 .51423 L p .40122 .45621 L F P
0 g
s
.82359 .74253 m .82463 .76016 L .84088 .74842 L p .707 .577 .707 r
F P
0 g
s
.84088 .74842 m .83983 .73079 L .82359 .74253 L p .707 .577 .707 r
F P
0 g
s
.83709 .66746 m .83912 .70277 L .84609 .69014 L p .707 .577 .707 r
F P
0 g
s
.84609 .69014 m .84405 .65484 L .83709 .66746 L p .707 .577 .707 r
F P
0 g
s
.84219 .57573 m .84404 .62987 L .84111 .61898 L p .707 .577 .707 r
F P
0 g
s
.84111 .61898 m .83926 .56485 L .84219 .57573 L p .707 .577 .707 r
F P
0 g
s
.64339 .67211 m .64543 .70742 L .65811 .71836 L p .707 .577 .707 r
F P
0 g
s
.63838 .57729 m .64023 .63143 L .64317 .64231 L p .707 .577 .707 r
F P
0 g
s
.65988 .7643 m .65883 .74667 L .64615 .73566 L p .707 .577 .707 r
F P
0 g
s
.64543 .70742 m .64339 .67211 L .64039 .65973 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64023 .63143 m .63838 .57729 L .64542 .56633 L p .707 .577 .707 r
F P
0 g
s
.62768 .25676 m .59178 .77401 L .55297 .7691 L p .707 .577 .707 r
F P
0 g
s
.55297 .7691 m .58887 .25185 L .62768 .25676 L p .707 .577 .707 r
F P
0 g
s
.64615 .73566 m .6472 .75328 L .65988 .7643 L p .707 .577 .707 r
F P
0 g
s
.83983 .73079 m .84088 .74842 L .84783 .73568 L p .707 .577 .707 r
F P
0 g
s
.84783 .73568 m .84679 .71805 L .83983 .73079 L p .707 .577 .707 r
F P
0 g
s
.84405 .65484 m .84609 .69014 L .84308 .67776 L p .707 .577 .707 r
F P
0 g
s
.84308 .67776 m .84104 .64245 L .84405 .65484 L p .707 .577 .707 r
F P
0 g
s
.64039 .65973 m .64243 .69503 L .64543 .70742 L p .707 .577 .707 r
F P
0 g
s
.83926 .56485 m .84111 .61898 L .82848 .60924 L p .707 .577 .707 r
F P
0 g
s
.82848 .60924 m .82663 .55511 L .83926 .56485 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64542 .56633 m .64727 .62046 L .64023 .63143 L p .707 .577 .707 r
F P
0 g
s
.6472 .75328 m .64615 .73566 L .64314 .72317 L p .707 .577 .707 r
F P
0 g
s
.58887 .25185 m .55297 .7691 L .50901 .76513 L p .707 .577 .707 r
F P
0 g
s
.50901 .76513 m .54491 .24787 L .58887 .25185 L p .707 .577 .707 r
F P
0 g
s
.64243 .69503 m .64039 .65973 L .64735 .6471 L p .707 .577 .707 r
F P
0 g
s
.39249 .62918 m .39064 .57504 L .35947 .57356 L p .707 .577 .707 r
F P
0 g
s
.64727 .62046 m .64542 .56633 L .66175 .55637 L p .707 .577 .707 r
F P
0 g
s
.64314 .72317 m .64419 .74079 L .6472 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.54491 .24787 m .50901 .76513 L .4642 .76248 L p .707 .577 .707 r
F P
0 g
s
.36132 .62769 m .35947 .57356 L .33201 .56875 L p .707 .577 .707 r
F P
0 g
s
.35947 .57356 m .36132 .62769 L .39249 .62918 L p .707 .577 .707 r
F P
0 g
s
.84679 .71805 m .84783 .73568 L .84482 .72319 L p .707 .577 .707 r
F P
0 g
s
.84482 .72319 m .84377 .70556 L .84679 .71805 L p .707 .577 .707 r
F P
0 g
s
.84104 .64245 m .84308 .67776 L .8304 .66682 L p .707 .577 .707 r
F P
0 g
s
.8304 .66682 m .82837 .63151 L .84104 .64245 L p .707 .577 .707 r
F P
0 g
s
.82663 .55511 m .82848 .60924 L .80741 .60159 L p .707 .577 .707 r
F P
0 g
s
.80741 .60159 m .80556 .54746 L .82663 .55511 L p .707 .577 .707 r
F P
0 g
s
.64735 .6471 m .64939 .68241 L .64243 .69503 L p .707 .577 .707 r
F P
0 g
s
.66175 .55637 m .6636 .6105 L .64727 .62046 L p .707 .577 .707 r
F P
0 g
s
.33386 .62289 m .33201 .56875 L .31093 .5611 L p .707 .577 .707 r
F P
0 g
s
.33201 .56875 m .33386 .62289 L .36132 .62769 L p .707 .577 .707 r
F P
0 g
s
.64419 .74079 m .64314 .72317 L .6501 .71043 L p .707 .577 .707 r
F P
0 g
s
.6636 .6105 m .66175 .55637 L .68576 .54837 L p .707 .577 .707 r
F P
0 g
s
.64939 .68241 m .64735 .6471 L .6636 .63547 L p .707 .577 .707 r
F P
0 g
s
.39484 .69625 m .3928 .66094 L .36165 .65971 L p .707 .577 .707 r
F P
0 g
s
.3928 .66094 m .39484 .69625 L .42662 .69351 L p .707 .577 .707 r
F P
0 g
s
.42662 .69351 m .42459 .6582 L .3928 .66094 L p .707 .577 .707 r
F P
0 g
s
.6501 .71043 m .65114 .72805 L .64419 .74079 L p .707 .577 .707 r
F P
0 g
s
.42459 .6582 m .42662 .69351 L .45592 .68708 L p .707 .577 .707 r
F P
0 g
s
.47582 .55984 m .47767 .61398 L .49399 .60401 L p .707 .577 .707 r
F P
0 g
s
.49399 .60401 m .49214 .54988 L .47582 .55984 L p .707 .577 .707 r
F P
0 g
s
.80556 .54746 m .80741 .60159 L .77994 .59679 L p .707 .577 .707 r
F P
0 g
s
.77994 .59679 m .77809 .54266 L .80556 .54746 L p .707 .577 .707 r
F P
0 g
s
.36369 .69502 m .36165 .65971 L .33417 .65465 L p .707 .577 .707 r
F P
0 g
s
.36165 .65971 m .36369 .69502 L .39484 .69625 L p .707 .577 .707 r
F P
0 g
s
.84377 .70556 m .84482 .72319 L .83214 .71217 L p .707 .577 .707 r
F P
0 g
s
.83214 .71217 m .83109 .69455 L .84377 .70556 L p .707 .577 .707 r
F P
0 g
s
.82837 .63151 m .8304 .66682 L .80929 .65841 L p .707 .577 .707 r
F P
0 g
s
.80929 .65841 m .80725 .6231 L .82837 .63151 L p .707 .577 .707 r
F P
0 g
s
.31093 .5611 m .31278 .61524 L .33386 .62289 L p .707 .577 .707 r
F P
0 g
s
.6636 .63547 m .66564 .67078 L .64939 .68241 L p .707 .577 .707 r
F P
0 g
s
.45388 .65177 m .45592 .68708 L .47987 .67759 L p .707 .577 .707 r
F P
0 g
s
.47987 .67759 m .47783 .64228 L .45388 .65177 L p .707 .577 .707 r
F P
0 g
s
.68761 .60251 m .68576 .54837 L .71511 .54314 L p .707 .577 .707 r
F P
0 g
s
.68576 .54837 m .68761 .60251 L .6636 .6105 L p .707 .577 .707 r
F P
0 g
s
.31278 .61524 m .31093 .5611 L .29831 .55136 L p .707 .577 .707 r
F P
0 g
s
.33417 .65465 m .33621 .68995 L .36369 .69502 L p .707 .577 .707 r
F P
0 g
s
.33621 .68995 m .33417 .65465 L .31306 .64623 L p .707 .577 .707 r
F P
0 g
s
.77809 .54266 m .77994 .59679 L .74878 .5953 L p .707 .577 .707 r
F P
0 g
s
.74878 .5953 m .74693 .54117 L .77809 .54266 L p .707 .577 .707 r
F P
0 g
s
.65114 .72805 m .6501 .71043 L .66634 .69868 L p .707 .577 .707 r
F P
0 g
s
.66564 .67078 m .6636 .63547 L .68755 .62598 L p .707 .577 .707 r
F P
0 g
s
.39662 .74224 m .39557 .72462 L .36442 .72341 L p .707 .577 .707 r
F P
0 g
s
.39557 .72462 m .39662 .74224 L .42839 .73945 L p .707 .577 .707 r
F P
0 g
s
.42839 .73945 m .42735 .72183 L .39557 .72462 L p .707 .577 .707 r
F P
0 g
s
.42735 .72183 m .42839 .73945 L .45769 .73294 L p .707 .577 .707 r
F P
0 g
s
.45769 .73294 m .45664 .71532 L .42735 .72183 L p .707 .577 .707 r
F P
0 g
s
.71696 .59727 m .71511 .54314 L .74693 .54117 L p .707 .577 .707 r
F P
0 g
s
.71511 .54314 m .71696 .59727 L .68761 .60251 L p .707 .577 .707 r
F P
0 g
s
.49214 .54988 m .49399 .60401 L .50103 .59305 L p .707 .577 .707 r
F P
0 g
s
.50103 .59305 m .49918 .53892 L .49214 .54988 L p .707 .577 .707 r
F P
0 g
s
.74693 .54117 m .74878 .5953 L .71696 .59727 L p .707 .577 .707 r
F P
0 g
s
.66634 .69868 m .66739 .71631 L .65114 .72805 L p .707 .577 .707 r
F P
0 g
s
.36546 .74103 m .36442 .72341 L .33694 .71832 L p .707 .577 .707 r
F P
0 g
s
.36442 .72341 m .36546 .74103 L .39662 .74224 L p .707 .577 .707 r
F P
0 g
s
.47783 .64228 m .47987 .67759 L .49611 .66596 L p .707 .577 .707 r
F P
0 g
s
.49611 .66596 m .49408 .63065 L .47783 .64228 L p .707 .577 .707 r
F P
0 g
s
.80725 .6231 m .80929 .65841 L .78182 .65334 L p .707 .577 .707 r
F P
0 g
s
.78182 .65334 m .77978 .61803 L .80725 .6231 L p .707 .577 .707 r
F P
0 g
s
.83109 .69455 m .83214 .71217 L .81103 .7037 L p .707 .577 .707 r
F P
0 g
s
.81103 .7037 m .80998 .68608 L .83109 .69455 L p .707 .577 .707 r
F P
0 g
s
.29831 .55136 m .30016 .60549 L .31278 .61524 L p .707 .577 .707 r
F P
0 g
s
.31306 .64623 m .3151 .68154 L .33621 .68995 L p .707 .577 .707 r
F P
0 g
s
.45664 .71532 m .45769 .73294 L .48162 .72334 L p .707 .577 .707 r
F P
0 g
s
.48162 .72334 m .48058 .70572 L .45664 .71532 L p .707 .577 .707 r
F P
0 g
s
.68755 .62598 m .68959 .66128 L .66564 .67078 L p .707 .577 .707 r
F P
0 g
s
.33694 .71832 m .33799 .73595 L .36546 .74103 L p .707 .577 .707 r
F P
0 g
s
.68959 .66128 m .68755 .62598 L .71684 .61955 L p .707 .577 .707 r
F P
0 g
s
.30016 .60549 m .29831 .55136 L .29537 .54048 L p .707 .577 .707 r
F P
0 g
s
.3151 .68154 m .31306 .64623 L .30038 .6353 L p .707 .577 .707 r
F P
0 g
s
.33799 .73595 m .33694 .71832 L .31582 .70986 L p .707 .577 .707 r
F P
0 g
s
.66739 .71631 m .66634 .69868 L .69028 .68909 L p .707 .577 .707 r
F P
0 g
s
.77978 .61803 m .78182 .65334 L .75066 .65212 L p .707 .577 .707 r
F P
0 g
s
.75066 .65212 m .74862 .61681 L .77978 .61803 L p .707 .577 .707 r
F P
0 g
s
.71888 .65485 m .71684 .61955 L .74862 .61681 L p .707 .577 .707 r
F P
0 g
s
.71684 .61955 m .71888 .65485 L .68959 .66128 L p .707 .577 .707 r
F P
0 g
s
.74862 .61681 m .75066 .65212 L .71888 .65485 L p .707 .577 .707 r
F P
0 g
s
.31582 .70986 m .31687 .72748 L .33799 .73595 L p .707 .577 .707 r
F P
0 g
s
.69028 .68909 m .69133 .70671 L .66739 .71631 L p .707 .577 .707 r
F P
0 g
s
.48058 .70572 m .48162 .72334 L .49787 .7116 L p .707 .577 .707 r
F P
0 g
s
.49787 .7116 m .49682 .69398 L .48058 .70572 L p .707 .577 .707 r
F P
0 g
s
.80998 .68608 m .81103 .7037 L .78355 .69862 L p .707 .577 .707 r
F P
0 g
s
.78355 .69862 m .7825 .68099 L .80998 .68608 L p .707 .577 .707 r
F P
0 g
s
.49408 .63065 m .49611 .66596 L .50308 .65333 L p .707 .577 .707 r
F P
0 g
s
.50308 .65333 m .50104 .61802 L .49408 .63065 L p .707 .577 .707 r
F P
0 g
s
.49918 .53892 m .50103 .59305 L .4981 .58217 L p .707 .577 .707 r
F P
0 g
s
.4981 .58217 m .49625 .52803 L .49918 .53892 L p .707 .577 .707 r
F P
0 g
s
.30038 .6353 m .30242 .67061 L .3151 .68154 L p .707 .577 .707 r
F P
0 g
s
.29537 .54048 m .29722 .59461 L .30016 .60549 L p .707 .577 .707 r
F P
0 g
s
.69133 .70671 m .69028 .68909 L .71957 .68258 L p .707 .577 .707 r
F P
0 g
s
.31687 .72748 m .31582 .70986 L .30314 .69884 L p .707 .577 .707 r
F P
0 g
s
.30242 .67061 m .30038 .6353 L .29738 .62291 L p .707 .577 .707 r
F P
0 g
s
.7825 .68099 m .78355 .69862 L .75239 .69741 L p .707 .577 .707 r
F P
0 g
s
.75239 .69741 m .75135 .67979 L .7825 .68099 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29722 .59461 m .29537 .54048 L .30241 .52952 L p .707 .577 .707 r
F P
0 g
s
.71957 .68258 m .72062 .7002 L .69133 .70671 L p .707 .577 .707 r
F P
0 g
s
.72062 .7002 m .71957 .68258 L .75135 .67979 L p .707 .577 .707 r
F P
0 g
s
.30314 .69884 m .30419 .71647 L .31687 .72748 L p .707 .577 .707 r
F P
0 g
s
.75135 .67979 m .75239 .69741 L .72062 .7002 L p .707 .577 .707 r
F P
0 g
s
.49682 .69398 m .49787 .7116 L .50482 .69886 L p .707 .577 .707 r
F P
0 g
s
.50482 .69886 m .50378 .68124 L .49682 .69398 L p .707 .577 .707 r
F P
0 g
s
.50104 .61802 m .50308 .65333 L .50007 .64094 L p .707 .577 .707 r
F P
0 g
s
.50007 .64094 m .49803 .60563 L .50104 .61802 L p .707 .577 .707 r
F P
0 g
s
.29738 .62291 m .29942 .65822 L .30242 .67061 L p .707 .577 .707 r
F P
0 g
s
.49625 .52803 m .4981 .58217 L .48547 .57243 L p .707 .577 .707 r
F P
0 g
s
.48547 .57243 m .48362 .51829 L .49625 .52803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30241 .52952 m .30426 .58365 L .29722 .59461 L p .707 .577 .707 r
F P
0 g
s
.30419 .71647 m .30314 .69884 L .30013 .68635 L p .707 .577 .707 r
F P
0 g
s
.29942 .65822 m .29738 .62291 L .30434 .61028 L p .707 .577 .707 r
F P
0 g
s
.30426 .58365 m .30241 .52952 L .31874 .51955 L p .707 .577 .707 r
F P
0 g
s
.30013 .68635 m .30118 .70398 L .30419 .71647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50378 .68124 m .50482 .69886 L .50181 .68637 L p .707 .577 .707 r
F P
0 g
s
.50181 .68637 m .50076 .66875 L .50378 .68124 L p .707 .577 .707 r
F P
0 g
s
.49803 .60563 m .50007 .64094 L .48739 .63001 L p .707 .577 .707 r
F P
0 g
s
.48739 .63001 m .48535 .5947 L .49803 .60563 L p .707 .577 .707 r
F P
0 g
s
.48362 .51829 m .48547 .57243 L .4644 .56478 L p .707 .577 .707 r
F P
0 g
s
.4644 .56478 m .46255 .51064 L .48362 .51829 L p .707 .577 .707 r
F P
0 g
s
.30434 .61028 m .30638 .64559 L .29942 .65822 L p .707 .577 .707 r
F P
0 g
s
.31874 .51955 m .32059 .57369 L .30426 .58365 L p .707 .577 .707 r
F P
0 g
s
.30118 .70398 m .30013 .68635 L .30709 .67361 L p .707 .577 .707 r
F P
0 g
s
.32059 .57369 m .31874 .51955 L .34275 .51156 L p .707 .577 .707 r
F P
0 g
s
.30638 .64559 m .30434 .61028 L .32059 .59865 L p .707 .577 .707 r
F P
0 g
s
.30709 .67361 m .30813 .69124 L .30118 .70398 L p .707 .577 .707 r
F P
0 g
s
.46255 .51064 m .4644 .56478 L .43693 .55997 L p .707 .577 .707 r
F P
0 g
s
.43693 .55997 m .43508 .50584 L .46255 .51064 L p .707 .577 .707 r
F P
0 g
s
.50076 .66875 m .50181 .68637 L .48913 .67535 L p .707 .577 .707 r
F P
0 g
s
.48913 .67535 m .48808 .65773 L .50076 .66875 L p .707 .577 .707 r
F P
0 g
s
.48535 .5947 m .48739 .63001 L .46628 .62159 L p .707 .577 .707 r
F P
0 g
s
.46628 .62159 m .46424 .58629 L .48535 .5947 L p .707 .577 .707 r
F P
0 g
s
.32059 .59865 m .32263 .63396 L .30638 .64559 L p .707 .577 .707 r
F P
0 g
s
.3446 .56569 m .34275 .51156 L .3721 .50632 L p .707 .577 .707 r
F P
0 g
s
.34275 .51156 m .3446 .56569 L .32059 .57369 L p .707 .577 .707 r
F P
0 g
s
.43508 .50584 m .43693 .55997 L .40577 .55848 L p .707 .577 .707 r
F P
0 g
s
.40577 .55848 m .40392 .50435 L .43508 .50584 L p .707 .577 .707 r
F P
0 g
s
.30813 .69124 m .30709 .67361 L .32333 .66187 L p .707 .577 .707 r
F P
0 g
s
.32263 .63396 m .32059 .59865 L .34454 .58916 L p .707 .577 .707 r
F P
0 g
s
.37395 .56046 m .3721 .50632 L .40392 .50435 L p .707 .577 .707 r
F P
0 g
s
.3721 .50632 m .37395 .56046 L .3446 .56569 L p .707 .577 .707 r
F P
0 g
s
.40392 .50435 m .40577 .55848 L .37395 .56046 L p .707 .577 .707 r
F P
0 g
s
.32333 .66187 m .32438 .67949 L .30813 .69124 L p .707 .577 .707 r
F P
0 g
s
.46424 .58629 m .46628 .62159 L .43881 .61653 L p .707 .577 .707 r
F P
0 g
s
.43881 .61653 m .43677 .58122 L .46424 .58629 L p .707 .577 .707 r
F P
0 g
s
.48808 .65773 m .48913 .67535 L .46801 .66689 L p .707 .577 .707 r
F P
0 g
s
.46801 .66689 m .46697 .64926 L .48808 .65773 L p .707 .577 .707 r
F P
0 g
s
.34454 .58916 m .34658 .62447 L .32263 .63396 L p .707 .577 .707 r
F P
0 g
s
.34658 .62447 m .34454 .58916 L .37383 .58273 L p .707 .577 .707 r
F P
0 g
s
.32438 .67949 m .32333 .66187 L .34727 .65227 L p .707 .577 .707 r
F P
0 g
s
.43677 .58122 m .43881 .61653 L .40765 .6153 L p .707 .577 .707 r
F P
0 g
s
.40765 .6153 m .40561 .57999 L .43677 .58122 L p .707 .577 .707 r
F P
0 g
s
.37587 .61804 m .37383 .58273 L .40561 .57999 L p .707 .577 .707 r
F P
0 g
s
.37383 .58273 m .37587 .61804 L .34658 .62447 L p .707 .577 .707 r
F P
0 g
s
.40561 .57999 m .40765 .6153 L .37587 .61804 L p .707 .577 .707 r
F P
0 g
s
.34727 .65227 m .34832 .6699 L .32438 .67949 L p .707 .577 .707 r
F P
0 g
s
.46697 .64926 m .46801 .66689 L .44054 .6618 L p .707 .577 .707 r
F P
0 g
s
.44054 .6618 m .43949 .64418 L .46697 .64926 L p .707 .577 .707 r
F P
0 g
s
.34832 .6699 m .34727 .65227 L .37656 .64576 L p .707 .577 .707 r
F P
0 g
s
.43949 .64418 m .44054 .6618 L .40938 .6606 L p .707 .577 .707 r
F P
0 g
s
.40938 .6606 m .40834 .64297 L .43949 .64418 L p .707 .577 .707 r
F P
0 g
s
.37656 .64576 m .37761 .66338 L .34832 .6699 L p .707 .577 .707 r
F P
0 g
s
.37761 .66338 m .37656 .64576 L .40834 .64297 L p .707 .577 .707 r
F P
0 g
s
.40834 .64297 m .40938 .6606 L .37761 .66338 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
MWoo7P00RGoo001aOol50002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP03FUH=001l
Ool006moo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00AJEPT007=oo`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H006eoo`00Kgoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPH006Mo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH6001QOol006moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH00002001NOol006moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001LOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006mo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005]oo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP03FUH0
1000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000GWoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol0
06]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF
0003FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP000UYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00
Jgoo00@005YFFUH0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`04001JEUYF
0002FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00003FUH01000FUIJ
EP0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo
001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUIJEP0A000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Ioo`P000AJ
EP03001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00H7oo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001LOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol005Yoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00F7oo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HGoo001FOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001EOol00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00HGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001DOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00HGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0057oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo2@0015YF00<005YFFUH0
0UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000Aoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP00008003Aoo`00Dgoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH=0005FUH80004FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEPD000=oo`05001JEUYF001JEP05
0009FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool01000FUIJEP0015YF00@005YFFUIJEP8000Qoo`05001JEUYF001JEP050009FUH00`00FUIJEP07
FUH200000eYF001JEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00D0
05YF000005YF00@000Eoo`05001JEUYF001JEP050009FUH00`00FUIJEP08FUH30003FUH20005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH015YF500015YF00<005YF
FUH025YF00@005YFFUH0009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF2P000UYF00<005YFFUH02EYF00@005YFFUIJEP@000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00EJEP03001JEP00
00H000AJEP03001JEUYF009JEPP000MJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP<00003FUH005YF00=JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
Agoo3`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00P0015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000oOol80004FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol60003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
10001Woo1@002Woo10000UYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH4
000:Ool5000;Ool70004FUH01@00FUIJEUYF0000;Goo000cOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001J
EP0000@000eoo`D000Moo`@00003FUH005YF00AJEP<00003FUH005YF009JEP03001oogoo02]oo`00
<Goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00FUH00004FUH200000eYF001JEP02FUH90005Ool300000goo000000050005FUH00`00
FUIJEP04FUH01000FUH000000eYF00<007ooOol0:goo000_Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJ
EPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH?0002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0
00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF008000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@0
00IJEP8000=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00001JEP020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001J
EUYFFUH200000eYF0000000H000:FUH300000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF0P0015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP000eYF00@005YF000000=JEP07001JEUYFFUH007oo00000UYF00<005YF
FUH01@0025YF00<005YFFUH025YF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEUYFFUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001J
EP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF0`001EYF00H005YFFUH007oo0002FUH00`00FUIJEP050008
FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000^Ool002aoo`03001J
EP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0002FUH01000FUIJEP001EYF00P005YFFUH007oo001JEP000eYF1@0025YF00<005YFFUH025YF
00@005YF0000009JEP@0009JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH00000;Woo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP08FUH20004FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF
000000050004FUH01000FUIJEUYF20001EYF0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH00UYF2@002Goo1P0000AJ
EP000000009JEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH50002FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH50009Ool3000:Ool2000015YF001JEUYF1000
0UYF10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF10001EYF00<005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YFFUH0
02eoo`00;7oo00@005YFFUH000AJEP04001JEUYFFUH2000=Ool50009Ool01000FUIJEP0015YF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
15YF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00;Goo00<005YF000015YF00D005YF000005YF00@000Yoo`D000Qoo`80
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP800003FUH005YF
00AJEQT0009JEP03001JEUYF008000IJEP03001JEUYF00AJEPH000QJEPT000AJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF000015YF00<005YFFUH00eYF2P0015YF00<005YFFUH00UYF2@002Goo0`0000EJEP00FUIJ
EP0002eoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP<000MJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEPD000AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEP0000@000=JEP8000Aoo`T001Eoo`80009JEP03001o
ogoo02]oo`00;Goo00<005YF00000P001EYF00<005YFFUH00`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF0P0015YF00@005YFFUIJEP8000Moo`D001Moo`800003
FUH007oo02aoo`00;Goo00D005YF001JEP0000EJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH200001EYF001JEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUH00005FUH00`00FUIJEP020007Ool5000FOol0
0`00FUH00002000]Ool002eoo`80009JEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH20002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP020007Ool5000EOol01@00FUIJEP00FUH00P00;7oo000]Ool20002FUH00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH200000eYF001JEP06
FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF00<0
05YFFUH00eYF00<005YFFUH00P0027oo3`0027oo0P000eYF00@005YF000002aoo`00;Goo0P000UYF
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P000eYF
00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YF00000P001eYF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P00
0UYF00<005YFFUH00eYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEP0000L00003FUH0
05YF009JEP04001JEP00000/Ool002eoo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP800003FUH005YF00IJEP03
001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJEP800003FUH005YF00aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUH000020004FUH60003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0
000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@00003FUH005YF
009JEP03001JEUYF00EJEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUH0000/Ool002ioo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF009JEQX0
00EJEP05001JEUYFFUH00007FUH01@00FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0006FUH30000
15YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000009J
EP8000EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP@002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00@005YFFUIJEPH0009JEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH01000FUH000001UYF00<005YFFUH00UYF2@0025YF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH6
0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@000AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001J
EP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030004FUH01000FUIJEP00
;Goo000]Ool00`00FUH00004FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP80009JEP8000Aoo`<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH300000eYF001JEP03FUH01@00FUIJEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00005FUH005YFFUH0000]
Ool002eoo`04001JEUYF0003FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030002FUH30006Ool20002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
1eYF0P000eYF00<005YFFUH00UYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001oogoo02]oo`00;Goo00@005YFFUH0
00=JEP8000Eooa`0009JEP03001JEUYF008000Eoo`800005FUH005YFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJ
EP000UYF00<007ooOol02Woo2@0015YF00<005YFFUH01EYF00<005YF00000UYF00@005YFFUIJEPD0
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@00003FUH005YF00EJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEP00
008000Ioo`<002aoo`00;Goo00<005YFFUH00`001goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00@005YFFUIJEPT000=JEP03001JEUYF00=JEPL000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEUYF001JEP00FUH00`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH015YF10002Woo0P00;7oo000^Ool01000FUH000001Woo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP020004FUH40005FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP04000>Ool2000/Ool002ioo`80009JEP80009oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00@005YFFUIJEP@00003FUH005YF00MJ
EP<0009JEPL0015oo`03001JEP0002aoo`00;Woo0P000UYF00@005YF000000IJEP03001JEUYF00EJ
EP03001JEUYF009JEPl000EJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000IJEP03001JEUYF00=JEP03001JEP0000h001Moo`800003FUH007oo02]oo`00;Woo00@0
05YFFUIJEP<000MJEP03001JEUYF009JEPP000]oo`P0009JEPH000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEPD000AJEP03001JEUYF00=JEP04001JEUYF000SOol01@00FUH0
05YF0000;7oo000^Ool01`00FUIJEUYF001JEP0000IJEPT000Uoo`L000IJEP03001JEP0000<000AJ
EPP000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0009JEPH000AJEP04001JEUYF000ROol01000FUIJEUYF
0P00;7oo000^Ool01000FUIJEP000eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEPT000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<00003FUH00000009JEP04001JEUYFFUH90003FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200001EYF00000000FUH01`0000EJEP00FUIJEP00021oo`8000AJEP03001oogoo02]oo`00
;Woo00<005YF000015YF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP8000Moo`80009JEP03001oogoo01Yoo`@00003FUH005YF00=JEP03001oogoo
02]oo`00;Woo0`0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YF00000P001Woo00<005YF000067oo10001EYF00D005YFFUIJEP00
02ioo`00;goo0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP02FUH30002Ool4000DOol40002FUH00`00FUIJEP04FUH01000FUH00000
;goo000^Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<00003FUH0000000aoo`L000IJ
EP03001JEUYF00AJEP80035oo`00;Woo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000Eoo`04001JEUYF0003FUHN0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00<Woo000^Ool0
1000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000Moo`03001JEP0000@001=JEP03001JEUYF00QJEPd000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Aoo`00;Woo0P0017oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002Goo0P0065YF
00<005YFFUH02EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>7oo000^Ool20007Ool50004FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04000:Ool200000eYF
0000000GFUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000kOol002ioo`<000]oo`T0009JEPD0009JEPL000eoo`04001JEUYFFUH4000EFUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000050004FUH00`00FUIJEP02
FUH00`00FUH00003FUH60002FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000oOol002io
o`800003FUH007oo019oo`T0019oo`8000AJEP80009oo`H000mJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEPH000=JEP03001JEP0000=JEP03001JEUYF00=JEP<0
0003FUH005YF010004Ioo`00;Woo0P000UYF0P004goo1@0047oo100000=JEP00FUH00eYF00<007oo
Ool01goo1`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomo
o`1BOol002moo`05001JEUYF001JEP03000AOol3000>Ool30005FUH01@00FUIJEUYF00004Goo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2001COol002moo`04001J
EUYF0004FUH3000KOol400000eYF001JEP05FUH01000FUH0000067oo20001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF00<00003FUH007oo059oo`00<7oo00@005YFFUH000AJEP03001JEP0000<0011oo`L0
00EJEP03001JEUYF00AJEP80029oo`d000IJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH50006FUH00`00FUIJEP03FUH30003Ool2001COol0035oo`<000AJEP03001JEUYF00=JEQ0000AJ
EP03001JEUYF00IJEP03001JEUYF009JEP8002eoo`03001JEUYF01l0009JEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo00=oo`8005=oo`00<goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00;goo00D005YFFUH007oo008000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0005Ool00`00FUH0001COol003Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@0039oo`03001JEP0000Aoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool00`00FUH0001COol003Qoo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003Moo`8000Moo`<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000Qoo`800003FUH007oo059oo`00>goo100000=JEP00
FUH01eYF00<005YFFUH00UYF1`00>goo0P002Woo100000=JEP00FUH01eYF0`000UYF2@0037oo0P00
00AJEP00FUH005=oo`00?goo3`00@Woo00@005YF000000aoo`l001=oo`8000AJEP03001oogoo059o
o`00T7oo00D005YFFUIJEP0001Aoo`D0019oo`800003FUH005YF00=JEP03001oogoo059oo`00T7oo
00@005YFFUIJEP<0019oo`D0011oo`8000=JEP03001JEUYF009JEP03001oogoo059oo`00T7oo00D0
05YFFUIJEP00009JEP80015oo`<000eoo`@000EJEP03001JEUYF008005Eoo`00TGoo00@005YFFUH0
00AJEPD001Qoo`@0009JEP03001JEUYF00AJEP<005Moo`00TWoo0`001EYF00@005YFFUIJEQP000IJ
EP03001JEUYF00=JEP8005Uoo`00U7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8005]oo`00UGoo0P000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005eoo`00Ugoo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00Ggoo002IOol5
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04001ROol009ioo`T000AJEP03001J
EUYF009JEPL006Ioo`00Ygoo2@00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59976 .75658 m .59678 .70354 L .56562 .7023 L p .707 .577 .707 r
F P
0 g
s
.59678 .70354 m .59976 .75658 L .63155 .75389 L p .707 .577 .707 r
F P
0 g
s
.63155 .75389 m .62856 .70085 L .59678 .70354 L p .707 .577 .707 r
F P
0 g
s
.62856 .70085 m .63155 .75389 L .66085 .74753 L p .707 .577 .707 r
F P
0 g
s
.66085 .74753 m .65786 .69449 L .62856 .70085 L p .707 .577 .707 r
F P
0 g
s
.56861 .75534 m .56562 .7023 L .53815 .69725 L p .707 .577 .707 r
F P
0 g
s
.56562 .7023 m .56861 .75534 L .59976 .75658 L p .707 .577 .707 r
F P
0 g
s
.65786 .69449 m .66085 .74753 L .6848 .73812 L p .707 .577 .707 r
F P
0 g
s
.6848 .73812 m .68181 .68509 L .65786 .69449 L p .707 .577 .707 r
F P
0 g
s
.54113 .75029 m .53815 .69725 L .51704 .68888 L p .707 .577 .707 r
F P
0 g
s
.53815 .69725 m .54113 .75029 L .56861 .75534 L p .707 .577 .707 r
F P
0 g
s
.6038 .81747 m .60052 .7836 L .5694 .78278 L p .707 .577 .707 r
F P
0 g
s
.60052 .7836 m .6038 .81747 L .63549 .81357 L p .707 .577 .707 r
F P
0 g
s
.63549 .81357 m .63221 .77971 L .60052 .7836 L p .707 .577 .707 r
F P
0 g
s
.68181 .68509 m .6848 .73812 L .70105 .72659 L p .707 .577 .707 r
F P
0 g
s
.70105 .72659 m .69806 .67356 L .68181 .68509 L p .707 .577 .707 r
F P
0 g
s
.63221 .77971 m .63549 .81357 L .66465 .80534 L p .707 .577 .707 r
F P
0 g
s
.66465 .80534 m .66137 .77148 L .63221 .77971 L p .707 .577 .707 r
F P
0 g
s
.57268 .81664 m .5694 .78278 L .54189 .77731 L p .707 .577 .707 r
F P
0 g
s
.5694 .78278 m .57268 .81664 L .6038 .81747 L p .707 .577 .707 r
F P
0 g
s
.66137 .77148 m .66465 .80534 L .68842 .79358 L p .707 .577 .707 r
F P
0 g
s
.68842 .79358 m .68514 .75972 L .66137 .77148 L p .707 .577 .707 r
F P
0 g
s
.52003 .74192 m .51704 .68888 L .50436 .67802 L p .707 .577 .707 r
F P
0 g
s
.51704 .68888 m .52003 .74192 L .54113 .75029 L p .707 .577 .707 r
F P
0 g
s
.54517 .81117 m .54189 .77731 L .52069 .76774 L p .707 .577 .707 r
F P
0 g
s
.54189 .77731 m .54517 .81117 L .57268 .81664 L p .707 .577 .707 r
F P
0 g
s
.69806 .67356 m .70105 .72659 L .70802 .71406 L p .707 .577 .707 r
F P
0 g
s
.70802 .71406 m .70503 .66103 L .69806 .67356 L p .707 .577 .707 r
F P
0 g
s
.6067 .85025 m .60501 .83338 L .57389 .83258 L p .707 .577 .707 r
F P
0 g
s
.60501 .83338 m .6067 .85025 L .63838 .84628 L p .707 .577 .707 r
F P
0 g
s
.63838 .84628 m .63669 .8294 L .60501 .83338 L p .707 .577 .707 r
F P
0 g
s
.63669 .8294 m .63838 .84628 L .66752 .83792 L p .707 .577 .707 r
F P
0 g
s
.66752 .83792 m .66584 .82105 L .63669 .8294 L p .707 .577 .707 r
F P
0 g
s
.68514 .75972 m .68842 .79358 L .70448 .77943 L p .707 .577 .707 r
F P
0 g
s
.70448 .77943 m .7012 .74557 L .68514 .75972 L p .707 .577 .707 r
F P
0 g
s
.57558 .84945 m .57389 .83258 L .54638 .82708 L p .707 .577 .707 r
F P
0 g
s
.57389 .83258 m .57558 .84945 L .6067 .85025 L p .707 .577 .707 r
F P
0 g
s
.50436 .67802 m .50735 .73105 L .52003 .74192 L p .707 .577 .707 r
F P
0 g
s
.66584 .82105 m .66752 .83792 L .69128 .826 L p .707 .577 .707 r
F P
0 g
s
.69128 .826 m .68959 .80913 L .66584 .82105 L p .707 .577 .707 r
F P
0 g
s
.50735 .73105 m .50436 .67802 L .50136 .66572 L p .707 .577 .707 r
F P
0 g
s
.52069 .76774 m .52397 .8016 L .54517 .81117 L p .707 .577 .707 r
F P
0 g
s
.54638 .82708 m .54807 .84396 L .57558 .84945 L p .707 .577 .707 r
F P
0 g
s
.52397 .8016 m .52069 .76774 L .50787 .75501 L p .707 .577 .707 r
F P
0 g
s
.54807 .84396 m .54638 .82708 L .52517 .81743 L p .707 .577 .707 r
F P
0 g
s
.7012 .74557 m .70448 .77943 L .71125 .76429 L p .707 .577 .707 r
F P
0 g
s
.71125 .76429 m .70796 .73043 L .7012 .74557 L p .707 .577 .707 r
F P
0 g
s
.70503 .66103 m .70802 .71406 L .70502 .70177 L p .707 .577 .707 r
F P
0 g
s
.70502 .70177 m .70203 .64873 L .70503 .66103 L p .707 .577 .707 r
F P
0 g
s
.68959 .80913 m .69128 .826 L .70732 .81168 L p .707 .577 .707 r
F P
0 g
s
.70732 .81168 m .70563 .7948 L .68959 .80913 L p .707 .577 .707 r
F P
0 g
s
.52517 .81743 m .52686 .83431 L .54807 .84396 L p .707 .577 .707 r
F P
0 g
s
.50787 .75501 m .51116 .78887 L .52397 .8016 L p .707 .577 .707 r
F P
0 g
s
.50136 .66572 m .50435 .71876 L .50735 .73105 L p .707 .577 .707 r
F P
0 g
s
.50435 .71876 m .50136 .66572 L .50833 .65319 L p .707 .577 .707 r
F P
0 g
s
.52686 .83431 m .52517 .81743 L .51234 .80457 L p .707 .577 .707 r
F P
0 g
s
.51116 .78887 m .50787 .75501 L .50469 .74035 L p .707 .577 .707 r
F P
0 g
s
.70563 .7948 m .70732 .81168 L .71407 .79636 L p .707 .577 .707 r
F P
0 g
s
.71407 .79636 m .71238 .77949 L .70563 .7948 L p .707 .577 .707 r
F P
0 g
s
.51234 .80457 m .51403 .82145 L .52686 .83431 L p .707 .577 .707 r
F P
0 g
s
.70796 .73043 m .71125 .76429 L .70807 .74964 L p .707 .577 .707 r
F P
0 g
s
.70807 .74964 m .70479 .71577 L .70796 .73043 L p .707 .577 .707 r
F P
0 g
s
.70203 .64873 m .70502 .70177 L .69235 .6909 L p .707 .577 .707 r
F P
0 g
s
.69235 .6909 m .68936 .63787 L .70203 .64873 L p .707 .577 .707 r
F P
0 g
s
.50469 .74035 m .50798 .77421 L .51116 .78887 L p .707 .577 .707 r
F P
0 g
s
.50833 .65319 m .51132 .70623 L .50435 .71876 L p .707 .577 .707 r
F P
0 g
s
.51403 .82145 m .51234 .80457 L .50915 .78976 L p .707 .577 .707 r
F P
0 g
s
.51132 .70623 m .50833 .65319 L .52459 .64166 L p .707 .577 .707 r
F P
0 g
s
.50798 .77421 m .50469 .74035 L .51146 .72521 L p .707 .577 .707 r
F P
0 g
s
.25676 .71976 m .25377 .66673 L .22261 .66549 L p .707 .577 .707 r
F P
0 g
s
.25377 .66673 m .25676 .71976 L .28854 .71707 L p .707 .577 .707 r
F P
0 g
s
.28854 .71707 m .28555 .66404 L .25377 .66673 L p .707 .577 .707 r
F P
0 g
s
.28555 .66404 m .28854 .71707 L .31784 .71071 L p .707 .577 .707 r
F P
0 g
s
.31784 .71071 m .31485 .65768 L .28555 .66404 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.50915 .78976 m .51083 .80663 L .51403 .82145 L p .707 .577 .707 r
F P
0 g
s
.71238 .77949 m .71407 .79636 L .71087 .78155 L p .707 .577 .707 r
F P
0 g
s
.71087 .78155 m .70919 .76467 L .71238 .77949 L p .707 .577 .707 r
F P
0 g
s
.2256 .71852 m .22261 .66549 L .19514 .66044 L p .707 .577 .707 r
F P
0 g
s
.22261 .66549 m .2256 .71852 L .25676 .71976 L p .707 .577 .707 r
F P
0 g
s
.70479 .71577 m .70807 .74964 L .69525 .7369 L p .707 .577 .707 r
F P
0 g
s
.69525 .7369 m .69197 .70304 L .70479 .71577 L p .707 .577 .707 r
F P
0 g
s
.68936 .63787 m .69235 .6909 L .67124 .68253 L p .707 .577 .707 r
F P
0 g
s
.67124 .68253 m .66825 .6295 L .68936 .63787 L p .707 .577 .707 r
F P
0 g
s
.31485 .65768 m .31784 .71071 L .34179 .70131 L p .707 .577 .707 r
F P
0 g
s
.34179 .70131 m .3388 .64827 L .31485 .65768 L p .707 .577 .707 r
F P
0 g
s
.51146 .72521 m .51475 .75907 L .50798 .77421 L p .707 .577 .707 r
F P
0 g
s
.52459 .64166 m .52757 .6947 L .51132 .70623 L p .707 .577 .707 r
F P
0 g
s
.19812 .71347 m .19514 .66044 L .17403 .65207 L p .707 .577 .707 r
F P
0 g
s
.19514 .66044 m .19812 .71347 L .2256 .71852 L p .707 .577 .707 r
F P
0 g
s
.52757 .6947 m .52459 .64166 L .54854 .63226 L p .707 .577 .707 r
F P
0 g
s
.51083 .80663 m .50915 .78976 L .5159 .77444 L p .707 .577 .707 r
F P
0 g
s
.51475 .75907 m .51146 .72521 L .52752 .71106 L p .707 .577 .707 r
F P
0 g
s
.26079 .78065 m .25751 .74679 L .22639 .74596 L p .707 .577 .707 r
F P
0 g
s
.25751 .74679 m .26079 .78065 L .29249 .77676 L p .707 .577 .707 r
F P
0 g
s
.29249 .77676 m .2892 .7429 L .25751 .74679 L p .707 .577 .707 r
F P
0 g
s
.3388 .64827 m .34179 .70131 L .35804 .68978 L p .707 .577 .707 r
F P
0 g
s
.35804 .68978 m .35506 .63674 L .3388 .64827 L p .707 .577 .707 r
F P
0 g
s
.66825 .6295 m .67124 .68253 L .64376 .67748 L p .707 .577 .707 r
F P
0 g
s
.64376 .67748 m .64077 .62445 L .66825 .6295 L p .707 .577 .707 r
F P
0 g
s
.5159 .77444 m .51759 .79131 L .51083 .80663 L p .707 .577 .707 r
F P
0 g
s
.2892 .7429 m .29249 .77676 L .32164 .76853 L p .707 .577 .707 r
F P
0 g
s
.32164 .76853 m .31836 .73467 L .2892 .7429 L p .707 .577 .707 r
F P
0 g
s
.70919 .76467 m .71087 .78155 L .69804 .76868 L p .707 .577 .707 r
F P
0 g
s
.69804 .76868 m .69636 .75181 L .70919 .76467 L p .707 .577 .707 r
F P
0 g
s
.69197 .70304 m .69525 .7369 L .67405 .72733 L p .707 .577 .707 r
F P
0 g
s
.67405 .72733 m .67077 .69347 L .69197 .70304 L p .707 .577 .707 r
F P
0 g
s
.22967 .77982 m .22639 .74596 L .19888 .7405 L p .707 .577 .707 r
F P
0 g
s
.22639 .74596 m .22967 .77982 L .26079 .78065 L p .707 .577 .707 r
F P
0 g
s
.55152 .68529 m .54854 .63226 L .57784 .6259 L p .707 .577 .707 r
F P
0 g
s
.54854 .63226 m .55152 .68529 L .52757 .6947 L p .707 .577 .707 r
F P
0 g
s
.31836 .73467 m .32164 .76853 L .34541 .75676 L p .707 .577 .707 r
F P
0 g
s
.34541 .75676 m .34213 .7229 L .31836 .73467 L p .707 .577 .707 r
F P
0 g
s
.52752 .71106 m .5308 .74493 L .51475 .75907 L p .707 .577 .707 r
F P
0 g
s
.17702 .7051 m .17403 .65207 L .16135 .6412 L p .707 .577 .707 r
F P
0 g
s
.17403 .65207 m .17702 .7051 L .19812 .71347 L p .707 .577 .707 r
F P
0 g
s
.64077 .62445 m .64376 .67748 L .61261 .67624 L p .707 .577 .707 r
F P
0 g
s
.61261 .67624 m .60962 .62321 L .64077 .62445 L p .707 .577 .707 r
F P
0 g
s
.5308 .74493 m .52752 .71106 L .55129 .6993 L p .707 .577 .707 r
F P
0 g
s
.51759 .79131 m .5159 .77444 L .53194 .76012 L p .707 .577 .707 r
F P
0 g
s
.58082 .67893 m .57784 .6259 L .60962 .62321 L p .707 .577 .707 r
F P
0 g
s
.57784 .6259 m .58082 .67893 L .55152 .68529 L p .707 .577 .707 r
F P
0 g
s
.20216 .77436 m .19888 .7405 L .17768 .73093 L p .707 .577 .707 r
F P
0 g
s
.19888 .7405 m .20216 .77436 L .22967 .77982 L p .707 .577 .707 r
F P
0 g
s
.60962 .62321 m .61261 .67624 L .58082 .67893 L p .707 .577 .707 r
F P
0 g
s
.67077 .69347 m .67405 .72733 L .64654 .72186 L p .707 .577 .707 r
F P
0 g
s
.64654 .72186 m .64326 .688 L .67077 .69347 L p .707 .577 .707 r
F P
0 g
s
.35506 .63674 m .35804 .68978 L .36501 .67725 L p .707 .577 .707 r
F P
0 g
s
.36501 .67725 m .36202 .62421 L .35506 .63674 L p .707 .577 .707 r
F P
0 g
s
.26369 .81344 m .262 .79656 L .23088 .79576 L p .707 .577 .707 r
F P
0 g
s
.262 .79656 m .26369 .81344 L .29537 .80946 L p .707 .577 .707 r
F P
0 g
s
.29537 .80946 m .29368 .79259 L .262 .79656 L p .707 .577 .707 r
F P
0 g
s
.29368 .79259 m .29537 .80946 L .32452 .80111 L p .707 .577 .707 r
F P
0 g
s
.32452 .80111 m .32283 .78423 L .29368 .79259 L p .707 .577 .707 r
F P
0 g
s
.69636 .75181 m .69804 .76868 L .67684 .75903 L p .707 .577 .707 r
F P
0 g
s
.67684 .75903 m .67515 .74216 L .69636 .75181 L p .707 .577 .707 r
F P
0 g
s
.53194 .76012 m .53362 .77699 L .51759 .79131 L p .707 .577 .707 r
F P
0 g
s
.34213 .7229 m .34541 .75676 L .36147 .74262 L p .707 .577 .707 r
F P
0 g
s
.36147 .74262 m .35819 .70876 L .34213 .7229 L p .707 .577 .707 r
F P
0 g
s
.23257 .81264 m .23088 .79576 L .20337 .79027 L p .707 .577 .707 r
F P
0 g
s
.23088 .79576 m .23257 .81264 L .26369 .81344 L p .707 .577 .707 r
F P
0 g
s
.16135 .6412 m .16434 .69424 L .17702 .7051 L p .707 .577 .707 r
F P
0 g
s
.55457 .73316 m .55129 .6993 L .58045 .69107 L p .707 .577 .707 r
F P
0 g
s
.55129 .6993 m .55457 .73316 L .5308 .74493 L p .707 .577 .707 r
F P
0 g
s
.32283 .78423 m .32452 .80111 L .34827 .78918 L p .707 .577 .707 r
F P
0 g
s
.34827 .78918 m .34658 .77231 L .32283 .78423 L p .707 .577 .707 r
F P
0 g
s
.16434 .69424 m .16135 .6412 L .15836 .62891 L p .707 .577 .707 r
F P
0 g
s
.64326 .688 m .64654 .72186 L .61542 .72104 L p .707 .577 .707 r
F P
0 g
s
.61542 .72104 m .61214 .68718 L .64326 .688 L p .707 .577 .707 r
F P
0 g
s
.17768 .73093 m .18096 .76479 L .20216 .77436 L p .707 .577 .707 r
F P
0 g
s
.20337 .79027 m .20506 .80714 L .23257 .81264 L p .707 .577 .707 r
F P
0 g
s
.53362 .77699 m .53194 .76012 L .55569 .7482 L p .707 .577 .707 r
F P
0 g
s
.18096 .76479 m .17768 .73093 L .16486 .71819 L p .707 .577 .707 r
F P
0 g
s
.58373 .72493 m .58045 .69107 L .61214 .68718 L p .707 .577 .707 r
F P
0 g
s
.58045 .69107 m .58373 .72493 L .55457 .73316 L p .707 .577 .707 r
F P
0 g
s
.61214 .68718 m .61542 .72104 L .58373 .72493 L p .707 .577 .707 r
F P
0 g
s
.20506 .80714 m .20337 .79027 L .18216 .78062 L p .707 .577 .707 r
F P
0 g
s
.67515 .74216 m .67684 .75903 L .64933 .75354 L p .707 .577 .707 r
F P
0 g
s
.64933 .75354 m .64764 .73667 L .67515 .74216 L p .707 .577 .707 r
F P
0 g
s
.55569 .7482 m .55738 .76507 L .53362 .77699 L p .707 .577 .707 r
F P
0 g
s
.35819 .70876 m .36147 .74262 L .36824 .72748 L p .707 .577 .707 r
F P
0 g
s
.36824 .72748 m .36496 .69362 L .35819 .70876 L p .707 .577 .707 r
F P
0 g
s
.36202 .62421 m .36501 .67725 L .36201 .66495 L p .707 .577 .707 r
F P
0 g
s
.36201 .66495 m .35902 .61192 L .36202 .62421 L p .707 .577 .707 r
F P
0 g
s
.34658 .77231 m .34827 .78918 L .36431 .77486 L p .707 .577 .707 r
F P
0 g
s
.36431 .77486 m .36262 .75799 L .34658 .77231 L p .707 .577 .707 r
F P
0 g
s
.18216 .78062 m .18385 .79749 L .20506 .80714 L p .707 .577 .707 r
F P
0 g
s
.55738 .76507 m .55569 .7482 L .58484 .73984 L p .707 .577 .707 r
F P
0 g
s
.16486 .71819 m .16815 .75205 L .18096 .76479 L p .707 .577 .707 r
F P
0 g
s
.15836 .62891 m .16134 .68194 L .16434 .69424 L p .707 .577 .707 r
F P
0 g
s
.64764 .73667 m .64933 .75354 L .61821 .75274 L p .707 .577 .707 r
F P
0 g
s
.61821 .75274 m .61652 .73587 L .64764 .73667 L p .707 .577 .707 r
F P
0 g
s
.5072 .24653 m .44966 .76431 L .49355 .7691 L p .707 .577 .707 r
F P
0 g
s
.49355 .7691 m .55109 .25131 L .5072 .24653 L p .707 .577 .707 r
F P
0 g
s
.55109 .25131 m .49355 .7691 L .53815 .7741 L p .707 .577 .707 r
F P
0 g
s
.16134 .68194 m .15836 .62891 L .16532 .61638 L p .707 .577 .707 r
F P
0 g
s
.18385 .79749 m .18216 .78062 L .16933 .76776 L p .707 .577 .707 r
F P
0 g
s
.58484 .73984 m .58652 .75671 L .55738 .76507 L p .707 .577 .707 r
F P
0 g
s
.53815 .7741 m .59569 .25632 L .55109 .25131 L p .707 .577 .707 r
F P
0 g
s
.59569 .25632 m .53815 .7741 L .5791 .77883 L p .707 .577 .707 r
F P
0 g
s
.16815 .75205 m .16486 .71819 L .16169 .70353 L p .707 .577 .707 r
F P
0 g
s
.58652 .75671 m .58484 .73984 L .61652 .73587 L p .707 .577 .707 r
F P
0 g
s
.61652 .73587 m .61821 .75274 L .58652 .75671 L p .707 .577 .707 r
F P
0 g
s
.46832 .24243 m .41078 .76021 L .44966 .76431 L p .707 .577 .707 r
F P
0 g
s
.44966 .76431 m .5072 .24653 L .46832 .24243 L p .707 .577 .707 r
F P
0 g
s
.5791 .77883 m .63664 .26105 L .59569 .25632 L p .707 .577 .707 r
F P
0 g
s
.36262 .75799 m .36431 .77486 L .37106 .75955 L p .707 .577 .707 r
F P
0 g
s
.37106 .75955 m .36937 .74267 L .36262 .75799 L p .707 .577 .707 r
F P
0 g
s
.16933 .76776 m .17102 .78463 L .18385 .79749 L p .707 .577 .707 r
F P
0 g
s
.36496 .69362 m .36824 .72748 L .36506 .71282 L p .707 .577 .707 r
F P
0 g
s
.36506 .71282 m .36178 .67896 L .36496 .69362 L p .707 .577 .707 r
F P
0 g
s
.35902 .61192 m .36201 .66495 L .34934 .65409 L p .707 .577 .707 r
F P
0 g
s
.34934 .65409 m .34635 .60105 L .35902 .61192 L p .707 .577 .707 r
F P
0 g
s
.16169 .70353 m .16497 .7374 L .16815 .75205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63664 .26105 m .5791 .77883 L .61238 .78283 L p .707 .577 .707 r
F P
0 g
s
.16532 .61638 m .16831 .66941 L .16134 .68194 L p .707 .577 .707 r
F P
0 g
s
.61238 .78283 m .66992 .26504 L .63664 .26105 L p .707 .577 .707 r
F P
0 g
s
.17102 .78463 m .16933 .76776 L .16614 .75294 L p .707 .577 .707 r
F P
0 g
s
.43825 .23942 m .38071 .7572 L .41078 .76021 L p .707 .577 .707 r
F P
0 g
s
.41078 .76021 m .46832 .24243 L .43825 .23942 L p .707 .577 .707 r
F P
0 g
s
.16831 .66941 m .16532 .61638 L .18158 .60485 L p .707 .577 .707 r
F P
0 g
s
.16497 .7374 m .16169 .70353 L .16845 .68839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16614 .75294 m .16782 .76982 L .17102 .78463 L p .707 .577 .707 r
F P
0 g
s
.36937 .74267 m .37106 .75955 L .36786 .74473 L p .707 .577 .707 r
F P
0 g
s
.36786 .74473 m .36618 .72786 L .36937 .74267 L p .707 .577 .707 r
F P
0 g
s
.36178 .67896 m .36506 .71282 L .35224 .70008 L p .707 .577 .707 r
F P
0 g
s
.35224 .70008 m .34896 .66622 L .36178 .67896 L p .707 .577 .707 r
F P
0 g
s
.34635 .60105 m .34934 .65409 L .32823 .64572 L p .707 .577 .707 r
F P
0 g
s
.32823 .64572 m .32524 .59268 L .34635 .60105 L p .707 .577 .707 r
F P
0 g
s
.16845 .68839 m .17174 .72225 L .16497 .7374 L p .707 .577 .707 r
F P
0 g
s
.66992 .26504 m .61238 .78283 L .63474 .7857 L p .707 .577 .707 r
F P
0 g
s
.18158 .60485 m .18457 .65788 L .16831 .66941 L p .707 .577 .707 r
F P
0 g
s
.18457 .65788 m .18158 .60485 L .20553 .59544 L p .707 .577 .707 r
F P
0 g
s
.16782 .76982 m .16614 .75294 L .17289 .73763 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .69228 .26791 L .66992 .26504 L p .707 .577 .707 r
F P
0 g
s
.17174 .72225 m .16845 .68839 L .18451 .67425 L p .707 .577 .707 r
F P
0 g
s
.36618 .72786 m .36786 .74473 L .35504 .73187 L p .707 .577 .707 r
F P
0 g
s
.35504 .73187 m .35335 .71499 L .36618 .72786 L p .707 .577 .707 r
F P
0 g
s
.41993 .23779 m .3624 .75557 L .38071 .7572 L p .707 .577 .707 r
F P
0 g
s
.38071 .7572 m .43825 .23942 L .41993 .23779 L p .707 .577 .707 r
F P
0 g
s
.32524 .59268 m .32823 .64572 L .30075 .64067 L p .707 .577 .707 r
F P
0 g
s
.30075 .64067 m .29777 .58763 L .32524 .59268 L p .707 .577 .707 r
F P
0 g
s
.17289 .73763 m .17458 .7545 L .16782 .76982 L p .707 .577 .707 r
F P
0 g
s
.34896 .66622 m .35224 .70008 L .33104 .69052 L p .707 .577 .707 r
F P
0 g
s
.33104 .69052 m .32776 .65665 L .34896 .66622 L p .707 .577 .707 r
F P
0 g
s
.20851 .64848 m .20553 .59544 L .23483 .58908 L p .707 .577 .707 r
F P
0 g
s
.20553 .59544 m .20851 .64848 L .18457 .65788 L p .707 .577 .707 r
F P
0 g
s
.18451 .67425 m .18779 .70811 L .17174 .72225 L p .707 .577 .707 r
F P
0 g
s
.29777 .58763 m .30075 .64067 L .2696 .63943 L p .707 .577 .707 r
F P
0 g
s
.2696 .63943 m .26661 .58639 L .29777 .58763 L p .707 .577 .707 r
F P
0 g
s
.18779 .70811 m .18451 .67425 L .20828 .66248 L p .707 .577 .707 r
F P
0 g
s
.17458 .7545 m .17289 .73763 L .18893 .7233 L p .707 .577 .707 r
F P
0 g
s
.23782 .64212 m .23483 .58908 L .26661 .58639 L p .707 .577 .707 r
F P
0 g
s
.23483 .58908 m .23782 .64212 L .20851 .64848 L p .707 .577 .707 r
F P
0 g
s
.26661 .58639 m .2696 .63943 L .23782 .64212 L p .707 .577 .707 r
F P
0 g
s
.32776 .65665 m .33104 .69052 L .30353 .68505 L p .707 .577 .707 r
F P
0 g
s
.30353 .68505 m .30025 .65119 L .32776 .65665 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .64399 .78716 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.64399 .78716 m .63923 .78707 L p .65376 .66634 L .707 .577 .707 r
F P
0 g
s
.65376 .66634 m .65435 .66424 L .64399 .78716 L .707 .577 .707 r
F
.66419 .6073 m .66369 .6071 L p .664 .60829 L F P
0 g
s
.67834 .66476 m .66369 .6071 L .66364 .62731 L .707 .577 .707 r
F
.64399 .78716 m .70153 .26937 L .69228 .26791 L p F P
0 g
s
.65516 .65467 m .65668 .64668 L .64399 .78716 L .707 .577 .707 r
F
.66369 .60991 m .6621 .62419 L p .65668 .64668 L F P
0 g
s
.6621 .62419 m .64399 .78716 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.66392 .52315 m .63474 .7857 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.65424 .60336 m .64157 .59249 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.65668 .64668 m .65424 .60336 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.66369 .6071 m .65424 .60336 L p .66144 .6217 L .707 .577 .707 r
F P
0 g
s
.66364 .62731 m .66369 .60991 L .66144 .6217 L .707 .577 .707 r
F
.66369 .60991 m .66369 .6071 L .66144 .6217 L F
.65424 .60336 m .65723 .65639 L .67834 .66476 L p F P
0 g
s
.64157 .59249 m .64456 .64553 L .65484 .65434 L p .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65549 .65164 L .65556 .65133 L .707 .577 .707 r
F
.65577 .65045 m .64157 .59249 L .65484 .65434 L F
.69228 .26791 m .66392 .52315 L p .66378 .57436 L F P
0 g
s
.65223 .67006 m .69676 .26929 L p .65516 .65467 L .707 .577 .707 r
F P
0 g
s
.70153 .26937 m .66369 .60991 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65556 .65133 L .65668 .64668 L .707 .577 .707 r
F
.65556 .65133 m .70153 .26937 L .65668 .64668 L F
.65484 .65434 m .65723 .65639 L p .65577 .65045 L F P
0 g
s
.69676 .26929 m .70153 .26937 L p .65556 .65133 L .707 .577 .707 r
F P
0 g
s
.65549 .65164 m .69676 .26929 L .65556 .65133 L .707 .577 .707 r
F
.63923 .78707 m .65223 .67006 L p .65516 .65467 L F P
0 g
s
.65723 .65639 m .65668 .64668 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.64456 .64553 m .64157 .59249 L .63857 .58019 L p .707 .577 .707 r
F P
0 g
s
.63923 .78707 m .62091 .78544 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.63857 .58019 m .64084 .62051 L p .64456 .64553 L .707 .577 .707 r
F P
0 g
s
.64314 .6397 m .64456 .64553 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.69676 .26929 m .6496 .69374 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.6496 .69374 m .63923 .78707 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .69676 .26929 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .63857 .58019 L .64396 .5705 L p .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .64311 .58569 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.64396 .5705 m .64412 .57021 L p .64311 .58569 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64396 .5705 L .64311 .58569 L .707 .577 .707 r
F
.62091 .78544 m .59084 .78243 L p .65229 .4214 L F P
0 g
s
.64311 .58569 m .62091 .78544 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.62091 .78544 m .64311 .58569 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64311 .58569 m .67845 .26766 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64156 .63323 L .64314 .6397 L p .707 .577 .707 r
F P
0 g
s
.64156 .63323 m .64084 .62051 L p .64554 .56766 L .707 .577 .707 r
F P
0 g
s
.64412 .57021 m .64554 .56766 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .6579 .69221 L .64893 .6833 L p .707 .577 .707 r
F P
0 g
s
.64893 .6833 m .64508 .67947 L p .64779 .68731 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .64893 .6833 L .64779 .68731 L .707 .577 .707 r
F
.65376 .66634 m .65516 .65467 L .65435 .66424 L F
.67834 .66476 m .67535 .61172 L .66419 .6073 L p F P
0 g
s
.67834 .66476 m .66419 .6073 L .664 .60829 L .707 .577 .707 r
F
.35335 .71499 m .35504 .73187 L .33383 .72222 L p F P
0 g
s
.33383 .72222 m .33214 .70534 L .35335 .71499 L p .707 .577 .707 r
F P
0 g
s
.18893 .7233 m .19061 .74018 L .17458 .7545 L p .707 .577 .707 r
F P
0 g
s
.21156 .69635 m .20828 .66248 L .23744 .65425 L p .707 .577 .707 r
F P
0 g
s
.20828 .66248 m .21156 .69635 L .18779 .70811 L p .707 .577 .707 r
F P
0 g
s
.73697 .67105 m .73398 .61802 L .70283 .61677 L p .707 .577 .707 r
F P
0 g
s
.73398 .61802 m .73697 .67105 L .76875 .66836 L p .707 .577 .707 r
F P
0 g
s
.76875 .66836 m .76576 .61532 L .73398 .61802 L p .707 .577 .707 r
F P
0 g
s
.76576 .61532 m .76875 .66836 L .79805 .662 L p .707 .577 .707 r
F P
0 g
s
.79805 .662 m .79506 .60897 L .76576 .61532 L p .707 .577 .707 r
F P
0 g
s
.30025 .65119 m .30353 .68505 L .27241 .68422 L p .707 .577 .707 r
F P
0 g
s
.27241 .68422 m .26913 .65036 L .30025 .65119 L p .707 .577 .707 r
F P
0 g
s
.41517 .2377 m .35763 .75548 L .3624 .75557 L p .707 .577 .707 r
F P
0 g
s
.3624 .75557 m .41993 .23779 L .41517 .2377 L p .707 .577 .707 r
F P
0 g
s
.70581 .66981 m .70283 .61677 L .67535 .61172 L p .707 .577 .707 r
F P
0 g
s
.70283 .61677 m .70581 .66981 L .73697 .67105 L p .707 .577 .707 r
F P
0 g
s
.19061 .74018 m .18893 .7233 L .21268 .71138 L p .707 .577 .707 r
F P
0 g
s
.24072 .68811 m .23744 .65425 L .26913 .65036 L p .707 .577 .707 r
F P
0 g
s
.23744 .65425 m .24072 .68811 L .21156 .69635 L p .707 .577 .707 r
F P
0 g
s
.26913 .65036 m .27241 .68422 L .24072 .68811 L p .707 .577 .707 r
F P
0 g
s
.79506 .60897 m .79805 .662 L .822 .6526 L p .707 .577 .707 r
F P
0 g
s
.822 .6526 m .81901 .59956 L .79506 .60897 L p .707 .577 .707 r
F P
0 g
s
.33214 .70534 m .33383 .72222 L .30632 .71672 L p .707 .577 .707 r
F P
0 g
s
.30632 .71672 m .30463 .69985 L .33214 .70534 L p .707 .577 .707 r
F P
0 g
s
.21268 .71138 m .21437 .72826 L .19061 .74018 L p .707 .577 .707 r
F P
0 g
s
.67535 .61172 m .67834 .66476 L .70581 .66981 L p .707 .577 .707 r
F P
0 g
s
.21437 .72826 m .21268 .71138 L .24183 .70302 L p .707 .577 .707 r
F P
0 g
s
.30463 .69985 m .30632 .71672 L .2752 .71593 L p .707 .577 .707 r
F P
0 g
s
.2752 .71593 m .27351 .69905 L .30463 .69985 L p .707 .577 .707 r
F P
0 g
s
.81901 .59956 m .822 .6526 L .83826 .64106 L p .707 .577 .707 r
F P
0 g
s
.83826 .64106 m .83527 .58803 L .81901 .59956 L p .707 .577 .707 r
F P
0 g
s
.24183 .70302 m .24351 .7199 L .21437 .72826 L p .707 .577 .707 r
F P
0 g
s
.74101 .74193 m .73773 .70807 L .7066 .70725 L p .707 .577 .707 r
F P
0 g
s
.73773 .70807 m .74101 .74193 L .7727 .73804 L p .707 .577 .707 r
F P
0 g
s
.7727 .73804 m .76942 .70418 L .73773 .70807 L p .707 .577 .707 r
F P
0 g
s
.24351 .7199 m .24183 .70302 L .27351 .69905 L p .707 .577 .707 r
F P
0 g
s
.76942 .70418 m .7727 .73804 L .80186 .72981 L p .707 .577 .707 r
F P
0 g
s
.80186 .72981 m .79857 .69595 L .76942 .70418 L p .707 .577 .707 r
F P
0 g
s
.27351 .69905 m .2752 .71593 L .24351 .7199 L p .707 .577 .707 r
F P
0 g
s
.70988 .74111 m .7066 .70725 L .6791 .70178 L p .707 .577 .707 r
F P
0 g
s
.7066 .70725 m .70988 .74111 L .74101 .74193 L p .707 .577 .707 r
F P
0 g
s
.79857 .69595 m .80186 .72981 L .82563 .71805 L p .707 .577 .707 r
F P
0 g
s
.82563 .71805 m .82234 .68419 L .79857 .69595 L p .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .36688 .75695 L .35763 .75548 L p .707 .577 .707 r
F P
0 g
s
.35763 .75548 m .41517 .2377 L .42442 .23916 L p .707 .577 .707 r
F P
0 g
s
.83527 .58803 m .83826 .64106 L .84522 .62854 L p .707 .577 .707 r
F P
0 g
s
.84522 .62854 m .84224 .5755 L .83527 .58803 L p .707 .577 .707 r
F P
0 g
s
.68238 .73564 m .6791 .70178 L .6579 .69221 L p .707 .577 .707 r
F P
0 g
s
.6791 .70178 m .68238 .73564 L .70988 .74111 L p .707 .577 .707 r
F P
0 g
s
.82234 .68419 m .82563 .71805 L .84168 .7039 L p .707 .577 .707 r
F P
0 g
s
.84168 .7039 m .8384 .67004 L .82234 .68419 L p .707 .577 .707 r
F P
0 g
s
.7439 .79056 m .74221 .77369 L .71109 .77289 L p .707 .577 .707 r
F P
0 g
s
.74221 .77369 m .7439 .79056 L .77558 .78659 L p .707 .577 .707 r
F P
0 g
s
.77558 .78659 m .7739 .76971 L .74221 .77369 L p .707 .577 .707 r
F P
0 g
s
.7739 .76971 m .77558 .78659 L .80473 .77823 L p .707 .577 .707 r
F P
0 g
s
.80473 .77823 m .80304 .76136 L .7739 .76971 L p .707 .577 .707 r
F P
0 g
s
.71278 .78976 m .71109 .77289 L .68358 .76739 L p .707 .577 .707 r
F P
0 g
s
.71109 .77289 m .71278 .78976 L .7439 .79056 L p .707 .577 .707 r
F P
0 g
s
.6579 .69221 m .66118 .72607 L .68238 .73564 L p .707 .577 .707 r
F P
0 g
s
.80304 .76136 m .80473 .77823 L .82848 .76631 L p .707 .577 .707 r
F P
0 g
s
.82848 .76631 m .8268 .74943 L .80304 .76136 L p .707 .577 .707 r
F P
0 g
s
.68358 .76739 m .68527 .78427 L .71278 .78976 L p .707 .577 .707 r
F P
0 g
s
.84224 .5755 m .84522 .62854 L .84223 .61624 L p .707 .577 .707 r
F P
0 g
s
.84223 .61624 m .83924 .5632 L .84224 .5755 L p .707 .577 .707 r
F P
0 g
s
.68527 .78427 m .68358 .76739 L .66238 .75774 L p .707 .577 .707 r
F P
0 g
s
.8384 .67004 m .84168 .7039 L .84845 .68876 L p .707 .577 .707 r
F P
0 g
s
.84845 .68876 m .84517 .6549 L .8384 .67004 L p .707 .577 .707 r
F P
0 g
s
.38924 .75982 m .36688 .75695 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.40894 .58257 m .38924 .75982 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .44678 .24203 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.36688 .75695 m .39606 .4944 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.39606 .4944 m .42442 .23916 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .38924 .75982 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .40852 .57971 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42275 .57851 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .42519 .62184 L p .45504 .62519 L .707 .577 .707 r
F P
0 g
s
.43654 .63772 m .43553 .6468 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.43553 .6468 m .42253 .76381 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42574 .63155 L .43127 .63034 L p .707 .577 .707 r
F P
0 g
s
.43127 .63034 m .45504 .62519 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.45504 .62519 m .45205 .57215 L .42275 .57851 L p .707 .577 .707 r
F P
0 g
s
.48006 .24603 m .43654 .63772 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.41709 .60227 m .43654 .63772 L .42519 .62184 L .707 .577 .707 r
F
.44678 .24203 m .48006 .24603 L p .41709 .60227 L F P
0 g
s
.38924 .75982 m .40894 .58257 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .40852 .57971 L .41351 .61383 L .707 .577 .707 r
F
.40894 .58257 m .44678 .24203 L p .41709 .60227 L F P
0 g
s
.41351 .61383 m .40894 .58257 L .39097 .5812 L .707 .577 .707 r
F
.40852 .57971 m .40778 .57978 L p .40894 .58257 L F P
0 g
s
.40778 .57978 m .39097 .5812 L p .40894 .58257 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .42519 .62184 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.39097 .5812 m .39396 .63424 L .41621 .63235 L p .707 .577 .707 r
F P
0 g
s
.41621 .63235 m .42574 .63155 L p .41351 .61383 L .707 .577 .707 r
F P
0 g
s
.41351 .61383 m .39097 .5812 L .41621 .63235 L .707 .577 .707 r
F
.44678 .24203 m .40894 .58257 L p .40167 .53279 L F P
0 g
s
.8268 .74943 m .82848 .76631 L .84452 .75199 L p .707 .577 .707 r
F P
0 g
s
.84452 .75199 m .84284 .73511 L .8268 .74943 L p .707 .577 .707 r
F P
0 g
s
.66238 .75774 m .66406 .77462 L .68527 .78427 L p .707 .577 .707 r
F P
0 g
s
.64508 .67947 m .64836 .71334 L .66118 .72607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64836 .71334 m .64508 .67947 L .6419 .66482 L p .707 .577 .707 r
F P
0 g
s
.66406 .77462 m .66238 .75774 L .64955 .74488 L p .707 .577 .707 r
F P
0 g
s
.83924 .5632 m .84223 .61624 L .82955 .60537 L p .707 .577 .707 r
F P
0 g
s
.82955 .60537 m .82656 .55234 L .83924 .5632 L p .707 .577 .707 r
F P
0 g
s
.84517 .6549 m .84845 .68876 L .84527 .6741 L p .707 .577 .707 r
F P
0 g
s
.84527 .6741 m .84199 .64024 L .84517 .6549 L p .707 .577 .707 r
F P
0 g
s
.84284 .73511 m .84452 .75199 L .85127 .73667 L p .707 .577 .707 r
F P
0 g
s
.85127 .73667 m .84959 .7198 L .84284 .73511 L p .707 .577 .707 r
F P
0 g
s
.64955 .74488 m .65123 .76176 L .66406 .77462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6419 .66482 m .64518 .69868 L .64836 .71334 L p .707 .577 .707 r
F P
0 g
s
.64554 .56766 m .64852 .6207 L .64156 .63323 L p .707 .577 .707 r
F P
0 g
s
.59084 .78243 m .64838 .26465 L .67845 .26766 L p .707 .577 .707 r
F P
0 g
s
.64852 .6207 m .64554 .56766 L .66179 .55613 L p .707 .577 .707 r
F P
0 g
s
.39396 .63424 m .39097 .5812 L .35982 .57996 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64518 .69868 m .6419 .66482 L .64867 .64968 L p .707 .577 .707 r
F P
0 g
s
.65123 .76176 m .64955 .74488 L .64635 .73007 L p .707 .577 .707 r
F P
0 g
s
.3628 .63299 m .35982 .57996 L .33234 .57491 L p .707 .577 .707 r
F P
0 g
s
.35982 .57996 m .3628 .63299 L .39396 .63424 L p .707 .577 .707 r
F P
0 g
s
.82656 .55234 m .82955 .60537 L .80844 .59701 L p .707 .577 .707 r
F P
0 g
s
.80844 .59701 m .80546 .54397 L .82656 .55234 L p .707 .577 .707 r
F P
0 g
s
.84199 .64024 m .84527 .6741 L .83246 .66137 L p .707 .577 .707 r
F P
0 g
s
.83246 .66137 m .82917 .62751 L .84199 .64024 L p .707 .577 .707 r
F P
0 g
s
.64635 .73007 m .64804 .74694 L .65123 .76176 L p .707 .577 .707 r
F P
0 g
s
.84959 .7198 m .85127 .73667 L .84808 .72185 L p .707 .577 .707 r
F P
0 g
s
.84808 .72185 m .84639 .70498 L .84959 .7198 L p .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .42253 .76381 L p .44345 .6548 L .707 .577 .707 r
F P
0 g
s
.45205 .57215 m .45504 .62519 L .46638 .62073 L p .707 .577 .707 r
F P
0 g
s
.47455 .60859 m .45205 .57215 L .46638 .62073 L .707 .577 .707 r
F
.48257 .59668 m .46347 .76854 L p .45408 .71521 L F P
0 g
s
.44345 .6548 m .47828 .60306 L .45408 .71521 L .707 .577 .707 r
F
.47828 .60306 m .48257 .59668 L .45408 .71521 L F
.476 .56274 m .47828 .60306 L p .48349 .57889 L F P
0 g
s
.476 .56274 m .45205 .57215 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47899 .61578 m .47828 .60306 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47828 .60306 m .476 .56274 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .48075 .61308 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .46347 .76854 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.56561 .25576 m .53865 .49838 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.53865 .49838 m .50807 .77355 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .47933 .64737 L .45814 .65786 L p .707 .577 .707 r
F P
0 g
s
.45814 .65786 m .45556 .65913 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .45814 .65786 L .45693 .66025 L .707 .577 .707 r
F
.45885 .693 m .48262 .68123 L p .45693 .66025 L F P
0 g
s
.45556 .65913 m .45588 .66235 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.45588 .66235 m .45885 .693 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.50336 .56829 m .48567 .56879 L .56561 .25576 L .707 .577 .707 r
F
.48075 .61308 m .48567 .56879 L p .50336 .56829 L F P
0 g
s
.48858 .55383 m .476 .56274 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .52101 .25076 L .54693 .25367 L p .707 .577 .707 r
F P
0 g
s
.54693 .25367 m .56561 .25576 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48349 .57889 m .48567 .56879 L .476 .56274 L .707 .577 .707 r
F
.48895 .55356 m .48858 .55383 L p .48567 .56879 L F P
0 g
s
.49525 .60425 m .49226 .55121 L .48895 .55356 L p .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .48257 .59668 L p .47828 .60306 L .707 .577 .707 r
F P
0 g
s
.49525 .60425 m .48895 .55356 L .48349 .57889 L .707 .577 .707 r
F
.52101 .25076 m .48567 .56879 L p .44345 .6548 L F P
0 g
s
.44345 .6548 m .48567 .56879 L .47828 .60306 L .707 .577 .707 r
F
.47899 .61578 m .49525 .60425 L p .48349 .57889 L F P
0 g
s
.47828 .60306 m .47899 .61578 L p .48349 .57889 L .707 .577 .707 r
F P
0 g
s
.46638 .62073 m .47899 .61578 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.64867 .64968 m .65195 .68354 L .64518 .69868 L p .707 .577 .707 r
F P
0 g
s
.66179 .55613 m .66478 .60917 L .64852 .6207 L p .707 .577 .707 r
F P
0 g
s
.64838 .26465 m .59084 .78243 L .55196 .77833 L p .707 .577 .707 r
F P
0 g
s
.33533 .62794 m .33234 .57491 L .31123 .56654 L p .707 .577 .707 r
F P
0 g
s
.33234 .57491 m .33533 .62794 L .3628 .63299 L p .707 .577 .707 r
F P
0 g
s
.66478 .60917 m .66179 .55613 L .68574 .54673 L p .707 .577 .707 r
F P
0 g
s
.55196 .77833 m .6095 .26055 L .64838 .26465 L p .707 .577 .707 r
F P
0 g
s
.65195 .68354 m .64867 .64968 L .66472 .63553 L p .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .48006 .24603 L .52101 .25076 L p .707 .577 .707 r
F P
0 g
s
.64804 .74694 m .64635 .73007 L .6531 .71475 L p .707 .577 .707 r
F P
0 g
s
.80546 .54397 m .80844 .59701 L .78097 .59195 L p .707 .577 .707 r
F P
0 g
s
.78097 .59195 m .77798 .53892 L .80546 .54397 L p .707 .577 .707 r
F P
0 g
s
.398 .70512 m .39472 .67126 L .36359 .67043 L p .707 .577 .707 r
F P
0 g
s
.39472 .67126 m .398 .70512 L .42969 .70123 L p .707 .577 .707 r
F P
0 g
s
.42969 .70123 m .42641 .66737 L .39472 .67126 L p .707 .577 .707 r
F P
0 g
s
.42641 .66737 m .42969 .70123 L .45885 .693 L p .707 .577 .707 r
F P
0 g
s
.45885 .693 m .45556 .65913 L .42641 .66737 L p .707 .577 .707 r
F P
0 g
s
.82917 .62751 m .83246 .66137 L .81126 .6518 L p .707 .577 .707 r
F P
0 g
s
.81126 .6518 m .80797 .61794 L .82917 .62751 L p .707 .577 .707 r
F P
0 g
s
.6531 .71475 m .65479 .73162 L .64804 .74694 L p .707 .577 .707 r
F P
0 g
s
.84639 .70498 m .84808 .72185 L .83525 .70899 L p .707 .577 .707 r
F P
0 g
s
.83525 .70899 m .83356 .69212 L .84639 .70498 L p .707 .577 .707 r
F P
0 g
s
.36687 .70429 m .36359 .67043 L .33608 .66496 L p .707 .577 .707 r
F P
0 g
s
.36359 .67043 m .36687 .70429 L .398 .70512 L p .707 .577 .707 r
F P
0 g
s
.68873 .59976 m .68574 .54673 L .71504 .54037 L p .707 .577 .707 r
F P
0 g
s
.68574 .54673 m .68873 .59976 L .66478 .60917 L p .707 .577 .707 r
F P
0 g
s
.6095 .26055 m .55196 .77833 L .50807 .77355 L p .707 .577 .707 r
F P
0 g
s
.31422 .61958 m .31123 .56654 L .29856 .55568 L p .707 .577 .707 r
F P
0 g
s
.31123 .56654 m .31422 .61958 L .33533 .62794 L p .707 .577 .707 r
F P
0 g
s
.66472 .63553 m .66801 .66939 L .65195 .68354 L p .707 .577 .707 r
F P
0 g
s
.77798 .53892 m .78097 .59195 L .74981 .59071 L p .707 .577 .707 r
F P
0 g
s
.74981 .59071 m .74682 .53768 L .77798 .53892 L p .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .56561 .25576 L .6095 .26055 L p .707 .577 .707 r
F P
0 g
s
.66801 .66939 m .66472 .63553 L .68849 .62377 L p .707 .577 .707 r
F P
0 g
s
.71803 .5934 m .71504 .54037 L .74682 .53768 L p .707 .577 .707 r
F P
0 g
s
.71504 .54037 m .71803 .5934 L .68873 .59976 L p .707 .577 .707 r
F P
0 g
s
.74682 .53768 m .74981 .59071 L .71803 .5934 L p .707 .577 .707 r
F P
0 g
s
.49226 .55121 m .49525 .60425 L .50221 .59172 L p .707 .577 .707 r
F P
0 g
s
.50221 .59172 m .49923 .53869 L .49226 .55121 L p .707 .577 .707 r
F P
0 g
s
.33937 .69883 m .33608 .66496 L .31488 .6554 L p .707 .577 .707 r
F P
0 g
s
.33608 .66496 m .33937 .69883 L .36687 .70429 L p .707 .577 .707 r
F P
0 g
s
.65479 .73162 m .6531 .71475 L .66914 .70043 L p .707 .577 .707 r
F P
0 g
s
.80797 .61794 m .81126 .6518 L .78375 .64633 L p .707 .577 .707 r
F P
0 g
s
.78375 .64633 m .78047 .61247 L .80797 .61794 L p .707 .577 .707 r
F P
0 g
s
.47933 .64737 m .48262 .68123 L .49867 .66709 L p .707 .577 .707 r
F P
0 g
s
.49867 .66709 m .49539 .63322 L .47933 .64737 L p .707 .577 .707 r
F P
0 g
s
.40089 .75375 m .3992 .73687 L .36808 .73607 L p .707 .577 .707 r
F P
0 g
s
.3992 .73687 m .40089 .75375 L .43257 .74977 L p .707 .577 .707 r
F P
0 g
s
.43257 .74977 m .43089 .7329 L .3992 .73687 L p .707 .577 .707 r
F P
0 g
s
.43089 .7329 m .43257 .74977 L .46172 .74142 L p .707 .577 .707 r
F P
0 g
s
.46172 .74142 m .46003 .72454 L .43089 .7329 L p .707 .577 .707 r
F P
0 g
s
.83356 .69212 m .83525 .70899 L .81404 .69934 L p .707 .577 .707 r
F P
0 g
s
.81404 .69934 m .81236 .68247 L .83356 .69212 L p .707 .577 .707 r
F P
0 g
s
.29856 .55568 m .30154 .60871 L .31422 .61958 L p .707 .577 .707 r
F P
0 g
s
.66914 .70043 m .67083 .7173 L .65479 .73162 L p .707 .577 .707 r
F P
0 g
s
.69178 .65763 m .68849 .62377 L .71765 .61554 L p .707 .577 .707 r
F P
0 g
s
.68849 .62377 m .69178 .65763 L .66801 .66939 L p .707 .577 .707 r
F P
0 g
s
.36977 .75295 m .36808 .73607 L .34057 .73058 L p .707 .577 .707 r
F P
0 g
s
.36808 .73607 m .36977 .75295 L .40089 .75375 L p .707 .577 .707 r
F P
0 g
s
.30154 .60871 m .29856 .55568 L .29556 .54338 L p .707 .577 .707 r
F P
0 g
s
.78047 .61247 m .78375 .64633 L .75263 .64551 L p .707 .577 .707 r
F P
0 g
s
.75263 .64551 m .74934 .61164 L .78047 .61247 L p .707 .577 .707 r
F P
0 g
s
.31488 .6554 m .31817 .68926 L .33937 .69883 L p .707 .577 .707 r
F P
0 g
s
.46003 .72454 m .46172 .74142 L .48547 .72949 L p .707 .577 .707 r
F P
0 g
s
.48547 .72949 m .48379 .71262 L .46003 .72454 L p .707 .577 .707 r
F P
0 g
s
.31817 .68926 m .31488 .6554 L .30207 .64266 L p .707 .577 .707 r
F P
0 g
s
.72093 .6494 m .71765 .61554 L .74934 .61164 L p .707 .577 .707 r
F P
0 g
s
.71765 .61554 m .72093 .6494 L .69178 .65763 L p .707 .577 .707 r
F P
0 g
s
.34057 .73058 m .34226 .74745 L .36977 .75295 L p .707 .577 .707 r
F P
0 g
s
.67083 .7173 m .66914 .70043 L .6929 .68851 L p .707 .577 .707 r
F P
0 g
s
.74934 .61164 m .75263 .64551 L .72093 .6494 L p .707 .577 .707 r
F P
0 g
s
.49923 .53869 m .50221 .59172 L .49921 .57942 L p .707 .577 .707 r
F P
0 g
s
.49921 .57942 m .49623 .52639 L .49923 .53869 L p .707 .577 .707 r
F P
0 g
s
.34226 .74745 m .34057 .73058 L .31937 .72093 L p .707 .577 .707 r
F P
0 g
s
.49539 .63322 m .49867 .66709 L .50544 .65194 L p .707 .577 .707 r
F P
0 g
s
.50544 .65194 m .50216 .61808 L .49539 .63322 L p .707 .577 .707 r
F P
0 g
s
.81236 .68247 m .81404 .69934 L .78653 .69385 L p .707 .577 .707 r
F P
0 g
s
.78653 .69385 m .78485 .67698 L .81236 .68247 L p .707 .577 .707 r
F P
0 g
s
.6929 .68851 m .69458 .70538 L .67083 .7173 L p .707 .577 .707 r
F P
0 g
s
.48379 .71262 m .48547 .72949 L .50151 .71517 L p .707 .577 .707 r
F P
0 g
s
.50151 .71517 m .49983 .6983 L .48379 .71262 L p .707 .577 .707 r
F P
0 g
s
.29556 .54338 m .29855 .59641 L .30154 .60871 L p .707 .577 .707 r
F P
0 g
s
.31937 .72093 m .32105 .7378 L .34226 .74745 L p .707 .577 .707 r
F P
0 g
s
.30207 .64266 m .30535 .67652 L .31817 .68926 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.69458 .70538 m .6929 .68851 L .72204 .68015 L p .707 .577 .707 r
F P
0 g
s
.29855 .59641 m .29556 .54338 L .30253 .53085 L p .707 .577 .707 r
F P
0 g
s
.78485 .67698 m .78653 .69385 L .75541 .69305 L p .707 .577 .707 r
F P
0 g
s
.75541 .69305 m .75373 .67618 L .78485 .67698 L p .707 .577 .707 r
F P
0 g
s
.30535 .67652 m .30207 .64266 L .29889 .628 L p .707 .577 .707 r
F P
0 g
s
.32105 .7378 m .31937 .72093 L .30654 .70807 L p .707 .577 .707 r
F P
0 g
s
.72204 .68015 m .72373 .69702 L .69458 .70538 L p .707 .577 .707 r
F P
0 g
s
.72373 .69702 m .72204 .68015 L .75373 .67618 L p .707 .577 .707 r
F P
0 g
s
.75373 .67618 m .75541 .69305 L .72373 .69702 L p .707 .577 .707 r
F P
0 g
s
.49623 .52639 m .49921 .57942 L .48654 .56856 L p .707 .577 .707 r
F P
0 g
s
.48654 .56856 m .48355 .51552 L .49623 .52639 L p .707 .577 .707 r
F P
0 g
s
.50216 .61808 m .50544 .65194 L .50226 .63729 L p .707 .577 .707 r
F P
0 g
s
.50226 .63729 m .49898 .60343 L .50216 .61808 L p .707 .577 .707 r
F P
0 g
s
.49983 .6983 m .50151 .71517 L .50826 .69985 L p .707 .577 .707 r
F P
0 g
s
.50826 .69985 m .50658 .68298 L .49983 .6983 L p .707 .577 .707 r
F P
0 g
s
.30654 .70807 m .30822 .72494 L .32105 .7378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29889 .628 m .30217 .66186 L .30535 .67652 L p .707 .577 .707 r
F P
0 g
s
.30253 .53085 m .30551 .58388 L .29855 .59641 L p .707 .577 .707 r
F P
0 g
s
.30551 .58388 m .30253 .53085 L .31878 .51932 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30217 .66186 m .29889 .628 L .30566 .61286 L p .707 .577 .707 r
F P
0 g
s
.30822 .72494 m .30654 .70807 L .30334 .69325 L p .707 .577 .707 r
F P
0 g
s
.48355 .51552 m .48654 .56856 L .46543 .56019 L p .707 .577 .707 r
F P
0 g
s
.46543 .56019 m .46244 .50715 L .48355 .51552 L p .707 .577 .707 r
F P
0 g
s
.49898 .60343 m .50226 .63729 L .48945 .62455 L p .707 .577 .707 r
F P
0 g
s
.48945 .62455 m .48616 .59069 L .49898 .60343 L p .707 .577 .707 r
F P
0 g
s
.30334 .69325 m .30503 .71013 L .30822 .72494 L p .707 .577 .707 r
F P
0 g
s
.50658 .68298 m .50826 .69985 L .50507 .68504 L p .707 .577 .707 r
F P
0 g
s
.50507 .68504 m .50338 .66817 L .50658 .68298 L p .707 .577 .707 r
F P
0 g
s
.30566 .61286 m .30894 .64672 L .30217 .66186 L p .707 .577 .707 r
F P
0 g
s
.31878 .51932 m .32177 .57235 L .30551 .58388 L p .707 .577 .707 r
F P
0 g
s
.32177 .57235 m .31878 .51932 L .34273 .50991 L p .707 .577 .707 r
F P
0 g
s
.30894 .64672 m .30566 .61286 L .32171 .59872 L p .707 .577 .707 r
F P
0 g
s
.30503 .71013 m .30334 .69325 L .31009 .67793 L p .707 .577 .707 r
F P
0 g
s
.46244 .50715 m .46543 .56019 L .43796 .55514 L p .707 .577 .707 r
F P
0 g
s
.43796 .55514 m .43497 .5021 L .46244 .50715 L p .707 .577 .707 r
F P
0 g
s
.48616 .59069 m .48945 .62455 L .46825 .61498 L p .707 .577 .707 r
F P
0 g
s
.46825 .61498 m .46496 .58112 L .48616 .59069 L p .707 .577 .707 r
F P
0 g
s
.31009 .67793 m .31178 .69481 L .30503 .71013 L p .707 .577 .707 r
F P
0 g
s
.50338 .66817 m .50507 .68504 L .49224 .67218 L p .707 .577 .707 r
F P
0 g
s
.49224 .67218 m .49055 .6553 L .50338 .66817 L p .707 .577 .707 r
F P
0 g
s
.34572 .56295 m .34273 .50991 L .37203 .50355 L p .707 .577 .707 r
F P
0 g
s
.34273 .50991 m .34572 .56295 L .32177 .57235 L p .707 .577 .707 r
F P
0 g
s
.32171 .59872 m .325 .63258 L .30894 .64672 L p .707 .577 .707 r
F P
0 g
s
.43497 .5021 m .43796 .55514 L .4068 .5539 L p .707 .577 .707 r
F P
0 g
s
.4068 .5539 m .40381 .50086 L .43497 .5021 L p .707 .577 .707 r
F P
0 g
s
.325 .63258 m .32171 .59872 L .34548 .58695 L p .707 .577 .707 r
F P
0 g
s
.37502 .55659 m .37203 .50355 L .40381 .50086 L p .707 .577 .707 r
F P
0 g
s
.37203 .50355 m .37502 .55659 L .34572 .56295 L p .707 .577 .707 r
F P
0 g
s
.40381 .50086 m .4068 .5539 L .37502 .55659 L p .707 .577 .707 r
F P
0 g
s
.31178 .69481 m .31009 .67793 L .32613 .66361 L p .707 .577 .707 r
F P
0 g
s
.46496 .58112 m .46825 .61498 L .44074 .60952 L p .707 .577 .707 r
F P
0 g
s
.44074 .60952 m .43746 .57565 L .46496 .58112 L p .707 .577 .707 r
F P
0 g
s
.49055 .6553 m .49224 .67218 L .47103 .66253 L p .707 .577 .707 r
F P
0 g
s
.47103 .66253 m .46935 .64565 L .49055 .6553 L p .707 .577 .707 r
F P
0 g
s
.32613 .66361 m .32782 .68049 L .31178 .69481 L p .707 .577 .707 r
F P
0 g
s
.34877 .62081 m .34548 .58695 L .37464 .57872 L p .707 .577 .707 r
F P
0 g
s
.34548 .58695 m .34877 .62081 L .325 .63258 L p .707 .577 .707 r
F P
0 g
s
.43746 .57565 m .44074 .60952 L .40961 .60869 L p .707 .577 .707 r
F P
0 g
s
.40961 .60869 m .40633 .57483 L .43746 .57565 L p .707 .577 .707 r
F P
0 g
s
.37792 .61258 m .37464 .57872 L .40633 .57483 L p .707 .577 .707 r
F P
0 g
s
.37464 .57872 m .37792 .61258 L .34877 .62081 L p .707 .577 .707 r
F P
0 g
s
.32782 .68049 m .32613 .66361 L .34989 .65169 L p .707 .577 .707 r
F P
0 g
s
.40633 .57483 m .40961 .60869 L .37792 .61258 L p .707 .577 .707 r
F P
0 g
s
.46935 .64565 m .47103 .66253 L .44352 .65703 L p .707 .577 .707 r
F P
0 g
s
.44352 .65703 m .44184 .64016 L .46935 .64565 L p .707 .577 .707 r
F P
0 g
s
.34989 .65169 m .35157 .66856 L .32782 .68049 L p .707 .577 .707 r
F P
0 g
s
.35157 .66856 m .34989 .65169 L .37903 .64333 L p .707 .577 .707 r
F P
0 g
s
.44184 .64016 m .44352 .65703 L .4124 .65623 L p .707 .577 .707 r
F P
0 g
s
.4124 .65623 m .41072 .63936 L .44184 .64016 L p .707 .577 .707 r
F P
0 g
s
.37903 .64333 m .38072 .66021 L .35157 .66856 L p .707 .577 .707 r
F P
0 g
s
.38072 .66021 m .37903 .64333 L .41072 .63936 L p .707 .577 .707 r
F P
0 g
s
.41072 .63936 m .4124 .65623 L .38072 .66021 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001fOol4002SOol007Ioo``0
09]oo`00MWoo00<005YF00001UYF00<005YFFUH02@00TWoo001fOol00`00FUH00006FUH00`00FUIJ
EP04FUH@0027Ool007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00=JEQD007Yoo`00
MGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEUYFFUHD001aOol007Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP04001JEUYFFUH6
0002FUH6001[Ool007Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEPl006Aoo`00MGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF3P00G7oo001eOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
3000EGoo001eOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001EOol007Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Eoo`00MGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH04EYF00<005YFFUH00eYF0P00
EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYFEWoo001dOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUIFOol007Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEWoo05Eoo`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0EGoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001FOol007Aoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Ioo`00M7oo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EWoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001FOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
Oomoo`1DOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1F
Ool007=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05Ioo`00Lgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0EWoo001cOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=oo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005Moo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Egoo001cOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Moo`00LWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Moo`00LWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEWoo05Moo`00LWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Egoo001bOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIoo`1GOol0079oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
05Qoo`00LWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00F7oo001bOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001HOol0079oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000EJEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Qoo`00LGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Qo
o`00LGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0F7oo001aOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001IOol0075oo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8005Uoo`00LGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<0
05YF00001EYF0P00FGoo001aOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001I
Ool0075oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Uoo`00L7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEP0005Uoo`00L7oo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF00001EYF0P00FWoo001`Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001JOol0071oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Yoo`00L7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00FWoo001`Ool00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001JOol0071oo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Yo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Yoo`00Kgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo001_Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006moo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8005]oo`00Kgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Fgoo001_Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001KOol006ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001^Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001LOol006ioo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00G7oo001]Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
G7oo001]Ool@0003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001LOol006Qoo`H000AJEP03001JEUYF00IJ
EP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0005aoo`00I7oo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`00G7oo001POol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol005aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005eoo`00FWoo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00GGoo001IOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00GGoo
001FOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0011oo`T004Aoo`00E7oo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Uoo`L000AJEP03001JEUYF009JEPP003aoo`00
E7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH4000hOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool30006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000fOol005Aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000017oo0000000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P00=7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP03
FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040002Ool0
0`00FUIJEP040003FUH00`00FUIJEP06FUH01000FUIJEUYF100015YF00@005YFFUH000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP@000Ioo`03001JEUYF00D0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP<00005FUH005YFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH0
0`00FUH00003000:Ool00`00FUIJEP0500000eYF001JEP08FUH00`00FUIJEP08FUH20002FUH20007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH2000>Ool00`00FUIJEP0500000eYF001J
EP08FUH00`00FUIJEP0:FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<0
05YFFUH01@002Goo00<005YFFUH04@0035YF10001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00@005YF001JEP80
00AJEP04001JEUYFFUH=0004FUH00`00FUIJEP06FUH00`00FUH00003000:FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH000020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH40006FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool004Moo`T000Aoo`05001JEP00FUH00005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo0011Ool60004FUH00`00FUIJEP02FUH60002FUH00`00FUIJ
EP03FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000015YF001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000mOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHG0004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20003FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH01@00FUIJEUYF00001UYF00<005YFFUH010001goo0`003Goo1@001EYF00D0
05YFFUIJEP0002eoo`00=goo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
0eYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00QJEP05001JEUYFFUH00005FUH4000:Ool5000AOol20003FUH01@00FUIJEUYF0000;Goo000eOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYFFUH2000>Ool5000@Ool200001EYF000005YF00000eYF0P00;7oo000cOol20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001JEP00
000@Ool5000>Ool20003FUH01000FUH000000eYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF1@0047oo20001Goo1@001EYF00D005YFFUIJ
EP00009JEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P003EYF00@005YFFUIJ
EPD000EJEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00H005YFFUIJEP00FUH40009Ool40002FUH00`00FUIJEP02FUH90006FUH00`00FUIJ
EP02FUH4000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP0;FUH00`00FUIJ
EP06FUH20003FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH00eYF2@001UYF00<005YFFUH01UYF00@005YFFUIJEPD0009J
EP03001JEUYF00=JEP<002aoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH0
1UYF00D005YFFUIJEP0000MJEP<00006FUH00000FUH005YF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00AJEP@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP<002aoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;FUH01000FUH000000UYF00<0
05YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00P0015YF00<005YF0000;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020006FUH00`00FUIJ
EP05FUH30007FUH01000FUIJEP002eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool0
02eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUH20003FUH40002FUH00`00FUIJEP04FUH=00000eYF001JEP09FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P0000=JEP000000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
1EYF00<005YF00003@002EYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002eoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@000eYF00D0
05YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002Ool01@00FUIJEP00FUH02`000eYF
00<005YFFUH025YF00@005YFFUIJEP800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`@0009JEP8000AJEP03001JEUYF00=JEP04001J
EUYF0002Ool70004FUH00`00FUIJEP02FUH80006FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0019oo`05001J
EUYF001oo`050005FUH01@00FUIJEP00Ool00P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPD00004FUH005YF0002FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@000aoo`L000Aoo`03001JEP0000Ioo`8000=JEP03001JEP00008000=JEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1`00
25YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00@005YFFUH002eoo`00;Goo00<005YF0000
15YF00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF009JEPH00003FUH007oo00=oo`800003FUH0
000000<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=J
EP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEP00000:Ool4
0006FUH00`00FUIJEP06FUH20002FUH50002FUH200000eYF001JEP07FUH00`00FUIJEP02FUH?0005
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00;7oo000]Ool00`00FUH00004FUH5
0005Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000AJEP00000000=JEP03
001JEUYF00EJEPL000UJEP03001JEUYF009JEP@00003FUH005YF00AJEP@000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003Ool200000eYF001JEP02
FUH00`00Oomoo`0ZOol002eoo`03001JEP00009JEP8000=JEP03001JEP0000@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF008000EJEP03001JEUYF009JEP@000EJEP03001J
EUYF00MJEPD00004FUH005YFFUH20005FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<000Moo`8000=JEP03001oogoo02Yoo`00;Goo00<005YF0000
0P001EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00@005YF0000
00IJEP03001JEP0000<0009JEP03001JEUYF00=JEP04001JEUYFFUH70005FUH00`00FUIJEP02FUH2
0003FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF
001JEP0000AJEP03001JEP0000@000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00@000aoo`04
001JEUYF000/Ool002eoo`05001JEP00FUH00004FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH20002FUH200000eYF001JEP05FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH200000eYF001JEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH0009JEP04001JEUYFFUH20005FUHI000AOol3000/Ool002eoo`80009JEP03001JEUYF
008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH01000
FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYF0002FUH0
1P00FUIJEP00FUH000EJEP03001JEUYF008000Moo`D001Qoo`800003FUH0000002]oo`00;Goo0P00
0UYF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH200001EYF001JEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUH0009JEP03001JEP00009JEP03001JEUYF00=JEP05001JEUYFFUH00007OolA000:Ool2
00000eYF001JEP02000[Ool002eoo`80009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP<000MJEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00D005YFFUIJEP00009oo`L000AJEP03
001JEUYF00IJEP03001JEP0000<000Eoo`06001JEUYFFUH005YF0P00:goo000]Ool200000eYF001J
EP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0003FUH01@00FUIJEUYF0000
1UYF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00D005YFFUIJ
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=oo`0000000P00
15YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0015YF
00@005YFFUH002]oo`00;Goo0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YF
FUH00eYF0P0000=JEP00000015YF00<005YFFUH015YF00<005YFFUH015YF1@001eYF00<005YFFUH0
1EYF00<005YFFUH00P0025YF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003Ool5000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P000eYF00@005YFFUH002]oo`00;Woo0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001EYF00<005YFFUH01eYF00H005YFFUIJEP00FUH40004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50007FUH00`00FUIJEP05FUH40008FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF0`000eYF100025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<005YF0000:goo000^Ool20005
FUH00`00FUIJEP04FUH00`00FUH000020007FUH00`00FUIJEP07FUH02P00FUIJEUYF001JEP00FUH0
05YF0`0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH015YF0P000UYF00<005YF
FUH01UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003
FUH500001EYF001JEUYF000025YF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000=JEP00
0000;7oo000^Ool20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP05FUH;0003FUH20002FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP06FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
009JEP03001JEUYF00<000AJEP03001JEUYF00AJEPH000eoo`800003FUH0000000@000AJEP03001J
EP00008002aoo`00;Goo00<005YF00001EYF00@005YFFUIJEP8000EJEP03001JEUYF00H000AJEP03
001JEUYF009JEPT000EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF
00EJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF
00@005YFFUH000IJEP03001JEUYF00@0011oo`<000=JEP03001JEUYF00=JEP8000=JEP03001JEP00
02eoo`00;Goo00<005YF00001EYF00@005YF000000MJEP<00003FUH005YF00MJEP03001JEUYF00IJ
EP80009JEPH000Eooa4000=JEP8000YJEP03001JEUYF00=JEP800003FUH00000009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000005FUH6
000<Ool60006FUH00`00FUIJEP05FUH200001EYF001JEUYF0000;7oo000]Ool01000FUIJEP0015YF
0P0000=JEP00FUH015YF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF0`0017oo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF009JEP8000=JEPl000AJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEP000002FUH0
0`00Oomoo`0ZOol002eoo`04001JEUYF0003FUH00`00Oomoo`03000015YF000000001eYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001EYF00<005YFFUH00P0000Aoo`000000009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP8000YJEP05001JEUYFFUH00004FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000800003FUH0
07oo02]oo`00;Goo00D005YFFUH005YF008000Eoo`800003FUH005YF00MJEP03001JEUYF009JEPl0
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEP00
008000AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH200000eYF001JEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003Ool00`00FUH0000[Ool002eoo`03001JEUYF008000Eoo`8000=JEP03001JEUYF
00EJEPX000Uoo`03001JEP0000<00003FUH005YF00AJEP<0009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Eoo`8002]oo`00;Woo00<0
05YF000017oo0P001EYF00<005YFFUH00UYF0`0017oo0`0037oo00<005YFFUH00P0000=oo`000000
1EYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF0P0015YF00@0
05YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP04
001JEUYFFUH20008Ool00`00Oomoo`0YOol002ioo`@0009oo`8000IJEP03001JEP00008000Ioo`D0
00]oo`05001JEUYF001JEP050003FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20006FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP04001JEP000009Ool2000[Ool002ioo`80009JEP800003FUH005YF00EJEP8000Uo
o`D000aoo`03001JEP0000AJEP@00004FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`001eYF00<005YFFUH015YF0`002goo0P00:goo000^Ool01@00FUIJEUYF00000eYF00@005YF
FUIJEP8000]oo`D000eoo`<000AJEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000EJEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEUYF0080009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000eoo`03001JEP0002]oo`00;Woo0P0000=JEP00FUH00eYF00@005YF
000000ioo`<000aoo`800003FUH0000000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04
001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1`004Goo00<005YF0000
:goo000^Ool200000eYF001JEP03FUH4000JOol30003FUH01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00000017oo4P005goo0P0000=JEP00
Ool0:Woo000^Ool40003FUH01@00FUIJEP00FUH0100047oo1P001UYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJ
EP<000Ioo`03001JEP0002=oo`04001JEP00000/Ool002moo`<00003FUH0000000=JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000020003Ool3000ROol01@00FUIJ
EUYF0000;7oo000_Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF000015YF00<005YFFUH00UYF100000=JEP0000007goo0P0015YF00<007oo
Ool0:Woo000_Ool01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=oo`0000003`000UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H0
05YF000005YF0004FUH00`00FUIJEP02FUH300000eYF0000000MOol200000eYF001JEP02FUH00`00
Oomoo`0[Ool002moo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`@000=JEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000002FUH50004FUH01000FUH005YF0P006goo0P000eYF00@005YF000002ioo`00
;goo0P0000=oo`0000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000Eoo`800003FUH007oo00P000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00
0002FUH30002Ool20003FUH01@00FUH005YF00005goo10001EYF0P00<7oo000_Ool20002Ool00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH000001Goo0P0000=JEP0000002Woo2`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF001oo`00FUH00002FUH200001UYF0000
0000FUH0009JEP8001=oo`@0009JEP03001JEUYF00AJEP03001oogoo02moo`00;goo0P000goo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001Woo00@0
05YFFUIJEP8001Eoo``000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP07001JEP00Ool005YF000015YF1P000UYF00<007ooOol03Goo1@001UYF00<005YFFUH0
0UYF0P00<Woo000_Ool30004Ool200000eYF001JEP06FUH00`00FUIJEP04FUH30008FUH00`00FUIJ
EP040007Ool20004FUH00`00Oomoo`0POol90009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002Ool30005FUH01000FUIJEUYF20001goo10000UYF00<005YFFUH01UYF
00<005YFFUH00P00=7oo000_Ool200000eYF001oo`04Ool50004FUH00`00FUIJEP03FUH50003FUH7
0009Ool200000eYF001JEP03FUH00`00Oomoo`0VOol90003FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000005FUH00`00FUIJEP05FUH01000FUIJEUYF
1`001UYF00<005YFFUH01UYF0`00=Woo000`Ool01000FUIJEP002Goo4P003Woo0P000eYF00D005YF
FUIJEP0002Uoo`<000=JEP03001JEUYF00T000EJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000=JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2000hOol0031oo`03001JEUYF00<0015oo`D000ioo`<000IJEP03001JEP0002Yoo`<0
009JEP03001JEUYF009JEP04001JEUYFFUH>0004FUH00`00FUIJEP02FUH00`00FUH00003FUH01000
FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000>Woo
000`Ool01000FUIJEP000UYF0P0047oo0`003Goo0P0000=JEP00FUH01UYF0P00:goo00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH0000;0003FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000nOol0035oo`04001JEUYF0003FUH3000JOol3
0003FUH00`00FUIJEP04FUH2000/Ool00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000goo0000000@0015Ool0039o
o`<000AJEP03001JEP0000<0011oo`H000MJEP04001JEUYFFUH2000^Ool00`00FUIJEP020005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0004Ool00`00FUH0001BOol003Aoo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF
00IJEP04001JEP00000`Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001Woo00<005YF0000DWoo000eOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000cOol200000goo
001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUH000001goo0P0000=JEP00Ool0DGoo000gOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000fOol01000Oomoogoo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0027oo00@005YF000005=oo`00>Goo0`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00>Goo0P0017oo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo00D005YFFUIJEP0005=oo`00
?7oo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?7oo00<005YF00001Goo0`001UYF00<0
05YFFUH01EYF0`001eYF00<005YF00000P002Woo0P0015YF00<007ooOol0DGoo0010Ool?0012Ool2
00000eYF001oo`06Ool40002FUH00`00FUIJEP04FUH50002FUH6000;Ool200000eYF001JEP02FUH0
0`00Oomoo`1BOol0099oo`04001JEUYF000:Ool@000?Ool20003FUH01000FUH00000EGoo002BOol0
0`00FUIJEP03000AOol5000=Ool40005FUH2001GOol009=oo`03001JEP00009JEP80011oo`<000Yo
o`@0009JEP03001JEUYF00AJEP03001oogoo05Ioo`00Tgoo00<005YF000015YF1@004Goo1`001UYF
00<005YFFUH00UYF0P00FGoo002DOol20005FUH01000FUIJEUYF4@0015YF00<005YFFUH01UYF00<0
05YFFUH00P00Fgoo002EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH3001MOol009Moo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8005moo`00VWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01000HGoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001UOol00:5ooa0006ao
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59976 .75658 m .59678 .70354 L .56562 .7023 L p .707 .577 .707 r
F P
0 g
s
.59678 .70354 m .59976 .75658 L .63155 .75389 L p .707 .577 .707 r
F P
0 g
s
.63155 .75389 m .62856 .70085 L .59678 .70354 L p .707 .577 .707 r
F P
0 g
s
.62856 .70085 m .63155 .75389 L .66085 .74753 L p .707 .577 .707 r
F P
0 g
s
.66085 .74753 m .65786 .69449 L .62856 .70085 L p .707 .577 .707 r
F P
0 g
s
.56861 .75534 m .56562 .7023 L .53815 .69725 L p .707 .577 .707 r
F P
0 g
s
.56562 .7023 m .56861 .75534 L .59976 .75658 L p .707 .577 .707 r
F P
0 g
s
.65786 .69449 m .66085 .74753 L .6848 .73812 L p .707 .577 .707 r
F P
0 g
s
.6848 .73812 m .68181 .68509 L .65786 .69449 L p .707 .577 .707 r
F P
0 g
s
.54113 .75029 m .53815 .69725 L .51704 .68888 L p .707 .577 .707 r
F P
0 g
s
.53815 .69725 m .54113 .75029 L .56861 .75534 L p .707 .577 .707 r
F P
0 g
s
.6038 .81747 m .60052 .7836 L .5694 .78278 L p .707 .577 .707 r
F P
0 g
s
.60052 .7836 m .6038 .81747 L .63549 .81357 L p .707 .577 .707 r
F P
0 g
s
.63549 .81357 m .63221 .77971 L .60052 .7836 L p .707 .577 .707 r
F P
0 g
s
.68181 .68509 m .6848 .73812 L .70105 .72659 L p .707 .577 .707 r
F P
0 g
s
.70105 .72659 m .69806 .67356 L .68181 .68509 L p .707 .577 .707 r
F P
0 g
s
.63221 .77971 m .63549 .81357 L .66465 .80534 L p .707 .577 .707 r
F P
0 g
s
.66465 .80534 m .66137 .77148 L .63221 .77971 L p .707 .577 .707 r
F P
0 g
s
.57268 .81664 m .5694 .78278 L .54189 .77731 L p .707 .577 .707 r
F P
0 g
s
.5694 .78278 m .57268 .81664 L .6038 .81747 L p .707 .577 .707 r
F P
0 g
s
.66137 .77148 m .66465 .80534 L .68842 .79358 L p .707 .577 .707 r
F P
0 g
s
.68842 .79358 m .68514 .75972 L .66137 .77148 L p .707 .577 .707 r
F P
0 g
s
.52003 .74192 m .51704 .68888 L .50436 .67802 L p .707 .577 .707 r
F P
0 g
s
.51704 .68888 m .52003 .74192 L .54113 .75029 L p .707 .577 .707 r
F P
0 g
s
.54517 .81117 m .54189 .77731 L .52069 .76774 L p .707 .577 .707 r
F P
0 g
s
.54189 .77731 m .54517 .81117 L .57268 .81664 L p .707 .577 .707 r
F P
0 g
s
.69806 .67356 m .70105 .72659 L .70802 .71406 L p .707 .577 .707 r
F P
0 g
s
.70802 .71406 m .70503 .66103 L .69806 .67356 L p .707 .577 .707 r
F P
0 g
s
.6067 .85025 m .60501 .83338 L .57389 .83258 L p .707 .577 .707 r
F P
0 g
s
.60501 .83338 m .6067 .85025 L .63838 .84628 L p .707 .577 .707 r
F P
0 g
s
.63838 .84628 m .63669 .8294 L .60501 .83338 L p .707 .577 .707 r
F P
0 g
s
.63669 .8294 m .63838 .84628 L .66752 .83792 L p .707 .577 .707 r
F P
0 g
s
.66752 .83792 m .66584 .82105 L .63669 .8294 L p .707 .577 .707 r
F P
0 g
s
.68514 .75972 m .68842 .79358 L .70448 .77943 L p .707 .577 .707 r
F P
0 g
s
.70448 .77943 m .7012 .74557 L .68514 .75972 L p .707 .577 .707 r
F P
0 g
s
.57558 .84945 m .57389 .83258 L .54638 .82708 L p .707 .577 .707 r
F P
0 g
s
.57389 .83258 m .57558 .84945 L .6067 .85025 L p .707 .577 .707 r
F P
0 g
s
.50436 .67802 m .50735 .73105 L .52003 .74192 L p .707 .577 .707 r
F P
0 g
s
.66584 .82105 m .66752 .83792 L .69128 .826 L p .707 .577 .707 r
F P
0 g
s
.69128 .826 m .68959 .80913 L .66584 .82105 L p .707 .577 .707 r
F P
0 g
s
.50735 .73105 m .50436 .67802 L .50136 .66572 L p .707 .577 .707 r
F P
0 g
s
.52069 .76774 m .52397 .8016 L .54517 .81117 L p .707 .577 .707 r
F P
0 g
s
.54638 .82708 m .54807 .84396 L .57558 .84945 L p .707 .577 .707 r
F P
0 g
s
.52397 .8016 m .52069 .76774 L .50787 .75501 L p .707 .577 .707 r
F P
0 g
s
.54807 .84396 m .54638 .82708 L .52517 .81743 L p .707 .577 .707 r
F P
0 g
s
.7012 .74557 m .70448 .77943 L .71125 .76429 L p .707 .577 .707 r
F P
0 g
s
.71125 .76429 m .70796 .73043 L .7012 .74557 L p .707 .577 .707 r
F P
0 g
s
.70503 .66103 m .70802 .71406 L .70502 .70177 L p .707 .577 .707 r
F P
0 g
s
.70502 .70177 m .70203 .64873 L .70503 .66103 L p .707 .577 .707 r
F P
0 g
s
.68959 .80913 m .69128 .826 L .70732 .81168 L p .707 .577 .707 r
F P
0 g
s
.70732 .81168 m .70563 .7948 L .68959 .80913 L p .707 .577 .707 r
F P
0 g
s
.52517 .81743 m .52686 .83431 L .54807 .84396 L p .707 .577 .707 r
F P
0 g
s
.50787 .75501 m .51116 .78887 L .52397 .8016 L p .707 .577 .707 r
F P
0 g
s
.50136 .66572 m .50435 .71876 L .50735 .73105 L p .707 .577 .707 r
F P
0 g
s
.50435 .71876 m .50136 .66572 L .50833 .65319 L p .707 .577 .707 r
F P
0 g
s
.52686 .83431 m .52517 .81743 L .51234 .80457 L p .707 .577 .707 r
F P
0 g
s
.51116 .78887 m .50787 .75501 L .50469 .74035 L p .707 .577 .707 r
F P
0 g
s
.70563 .7948 m .70732 .81168 L .71407 .79636 L p .707 .577 .707 r
F P
0 g
s
.71407 .79636 m .71238 .77949 L .70563 .7948 L p .707 .577 .707 r
F P
0 g
s
.51234 .80457 m .51403 .82145 L .52686 .83431 L p .707 .577 .707 r
F P
0 g
s
.70796 .73043 m .71125 .76429 L .70807 .74964 L p .707 .577 .707 r
F P
0 g
s
.70807 .74964 m .70479 .71577 L .70796 .73043 L p .707 .577 .707 r
F P
0 g
s
.70203 .64873 m .70502 .70177 L .69235 .6909 L p .707 .577 .707 r
F P
0 g
s
.69235 .6909 m .68936 .63787 L .70203 .64873 L p .707 .577 .707 r
F P
0 g
s
.50469 .74035 m .50798 .77421 L .51116 .78887 L p .707 .577 .707 r
F P
0 g
s
.50833 .65319 m .51132 .70623 L .50435 .71876 L p .707 .577 .707 r
F P
0 g
s
.51403 .82145 m .51234 .80457 L .50915 .78976 L p .707 .577 .707 r
F P
0 g
s
.51132 .70623 m .50833 .65319 L .52459 .64166 L p .707 .577 .707 r
F P
0 g
s
.50798 .77421 m .50469 .74035 L .51146 .72521 L p .707 .577 .707 r
F P
0 g
s
.25676 .71976 m .25377 .66673 L .22261 .66549 L p .707 .577 .707 r
F P
0 g
s
.25377 .66673 m .25676 .71976 L .28854 .71707 L p .707 .577 .707 r
F P
0 g
s
.28854 .71707 m .28555 .66404 L .25377 .66673 L p .707 .577 .707 r
F P
0 g
s
.28555 .66404 m .28854 .71707 L .31784 .71071 L p .707 .577 .707 r
F P
0 g
s
.31784 .71071 m .31485 .65768 L .28555 .66404 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.50915 .78976 m .51083 .80663 L .51403 .82145 L p .707 .577 .707 r
F P
0 g
s
.71238 .77949 m .71407 .79636 L .71087 .78155 L p .707 .577 .707 r
F P
0 g
s
.71087 .78155 m .70919 .76467 L .71238 .77949 L p .707 .577 .707 r
F P
0 g
s
.2256 .71852 m .22261 .66549 L .19514 .66044 L p .707 .577 .707 r
F P
0 g
s
.22261 .66549 m .2256 .71852 L .25676 .71976 L p .707 .577 .707 r
F P
0 g
s
.70479 .71577 m .70807 .74964 L .69525 .7369 L p .707 .577 .707 r
F P
0 g
s
.69525 .7369 m .69197 .70304 L .70479 .71577 L p .707 .577 .707 r
F P
0 g
s
.68936 .63787 m .69235 .6909 L .67124 .68253 L p .707 .577 .707 r
F P
0 g
s
.67124 .68253 m .66825 .6295 L .68936 .63787 L p .707 .577 .707 r
F P
0 g
s
.31485 .65768 m .31784 .71071 L .34179 .70131 L p .707 .577 .707 r
F P
0 g
s
.34179 .70131 m .3388 .64827 L .31485 .65768 L p .707 .577 .707 r
F P
0 g
s
.51146 .72521 m .51475 .75907 L .50798 .77421 L p .707 .577 .707 r
F P
0 g
s
.52459 .64166 m .52757 .6947 L .51132 .70623 L p .707 .577 .707 r
F P
0 g
s
.19812 .71347 m .19514 .66044 L .17403 .65207 L p .707 .577 .707 r
F P
0 g
s
.19514 .66044 m .19812 .71347 L .2256 .71852 L p .707 .577 .707 r
F P
0 g
s
.52757 .6947 m .52459 .64166 L .54854 .63226 L p .707 .577 .707 r
F P
0 g
s
.51083 .80663 m .50915 .78976 L .5159 .77444 L p .707 .577 .707 r
F P
0 g
s
.51475 .75907 m .51146 .72521 L .52752 .71106 L p .707 .577 .707 r
F P
0 g
s
.26079 .78065 m .25751 .74679 L .22639 .74596 L p .707 .577 .707 r
F P
0 g
s
.25751 .74679 m .26079 .78065 L .29249 .77676 L p .707 .577 .707 r
F P
0 g
s
.29249 .77676 m .2892 .7429 L .25751 .74679 L p .707 .577 .707 r
F P
0 g
s
.3388 .64827 m .34179 .70131 L .35804 .68978 L p .707 .577 .707 r
F P
0 g
s
.35804 .68978 m .35506 .63674 L .3388 .64827 L p .707 .577 .707 r
F P
0 g
s
.66825 .6295 m .67124 .68253 L .64376 .67748 L p .707 .577 .707 r
F P
0 g
s
.64376 .67748 m .64077 .62445 L .66825 .6295 L p .707 .577 .707 r
F P
0 g
s
.5159 .77444 m .51759 .79131 L .51083 .80663 L p .707 .577 .707 r
F P
0 g
s
.2892 .7429 m .29249 .77676 L .32164 .76853 L p .707 .577 .707 r
F P
0 g
s
.32164 .76853 m .31836 .73467 L .2892 .7429 L p .707 .577 .707 r
F P
0 g
s
.70919 .76467 m .71087 .78155 L .69804 .76868 L p .707 .577 .707 r
F P
0 g
s
.69804 .76868 m .69636 .75181 L .70919 .76467 L p .707 .577 .707 r
F P
0 g
s
.69197 .70304 m .69525 .7369 L .67405 .72733 L p .707 .577 .707 r
F P
0 g
s
.67405 .72733 m .67077 .69347 L .69197 .70304 L p .707 .577 .707 r
F P
0 g
s
.22967 .77982 m .22639 .74596 L .19888 .7405 L p .707 .577 .707 r
F P
0 g
s
.22639 .74596 m .22967 .77982 L .26079 .78065 L p .707 .577 .707 r
F P
0 g
s
.55152 .68529 m .54854 .63226 L .57784 .6259 L p .707 .577 .707 r
F P
0 g
s
.54854 .63226 m .55152 .68529 L .52757 .6947 L p .707 .577 .707 r
F P
0 g
s
.31836 .73467 m .32164 .76853 L .34541 .75676 L p .707 .577 .707 r
F P
0 g
s
.34541 .75676 m .34213 .7229 L .31836 .73467 L p .707 .577 .707 r
F P
0 g
s
.52752 .71106 m .5308 .74493 L .51475 .75907 L p .707 .577 .707 r
F P
0 g
s
.17702 .7051 m .17403 .65207 L .16135 .6412 L p .707 .577 .707 r
F P
0 g
s
.17403 .65207 m .17702 .7051 L .19812 .71347 L p .707 .577 .707 r
F P
0 g
s
.64077 .62445 m .64376 .67748 L .61261 .67624 L p .707 .577 .707 r
F P
0 g
s
.61261 .67624 m .60962 .62321 L .64077 .62445 L p .707 .577 .707 r
F P
0 g
s
.5308 .74493 m .52752 .71106 L .55129 .6993 L p .707 .577 .707 r
F P
0 g
s
.51759 .79131 m .5159 .77444 L .53194 .76012 L p .707 .577 .707 r
F P
0 g
s
.58082 .67893 m .57784 .6259 L .60962 .62321 L p .707 .577 .707 r
F P
0 g
s
.57784 .6259 m .58082 .67893 L .55152 .68529 L p .707 .577 .707 r
F P
0 g
s
.20216 .77436 m .19888 .7405 L .17768 .73093 L p .707 .577 .707 r
F P
0 g
s
.19888 .7405 m .20216 .77436 L .22967 .77982 L p .707 .577 .707 r
F P
0 g
s
.60962 .62321 m .61261 .67624 L .58082 .67893 L p .707 .577 .707 r
F P
0 g
s
.67077 .69347 m .67405 .72733 L .64654 .72186 L p .707 .577 .707 r
F P
0 g
s
.64654 .72186 m .64326 .688 L .67077 .69347 L p .707 .577 .707 r
F P
0 g
s
.35506 .63674 m .35804 .68978 L .36501 .67725 L p .707 .577 .707 r
F P
0 g
s
.36501 .67725 m .36202 .62421 L .35506 .63674 L p .707 .577 .707 r
F P
0 g
s
.26369 .81344 m .262 .79656 L .23088 .79576 L p .707 .577 .707 r
F P
0 g
s
.262 .79656 m .26369 .81344 L .29537 .80946 L p .707 .577 .707 r
F P
0 g
s
.29537 .80946 m .29368 .79259 L .262 .79656 L p .707 .577 .707 r
F P
0 g
s
.29368 .79259 m .29537 .80946 L .32452 .80111 L p .707 .577 .707 r
F P
0 g
s
.32452 .80111 m .32283 .78423 L .29368 .79259 L p .707 .577 .707 r
F P
0 g
s
.69636 .75181 m .69804 .76868 L .67684 .75903 L p .707 .577 .707 r
F P
0 g
s
.67684 .75903 m .67515 .74216 L .69636 .75181 L p .707 .577 .707 r
F P
0 g
s
.53194 .76012 m .53362 .77699 L .51759 .79131 L p .707 .577 .707 r
F P
0 g
s
.34213 .7229 m .34541 .75676 L .36147 .74262 L p .707 .577 .707 r
F P
0 g
s
.36147 .74262 m .35819 .70876 L .34213 .7229 L p .707 .577 .707 r
F P
0 g
s
.23257 .81264 m .23088 .79576 L .20337 .79027 L p .707 .577 .707 r
F P
0 g
s
.23088 .79576 m .23257 .81264 L .26369 .81344 L p .707 .577 .707 r
F P
0 g
s
.16135 .6412 m .16434 .69424 L .17702 .7051 L p .707 .577 .707 r
F P
0 g
s
.55457 .73316 m .55129 .6993 L .58045 .69107 L p .707 .577 .707 r
F P
0 g
s
.55129 .6993 m .55457 .73316 L .5308 .74493 L p .707 .577 .707 r
F P
0 g
s
.32283 .78423 m .32452 .80111 L .34827 .78918 L p .707 .577 .707 r
F P
0 g
s
.34827 .78918 m .34658 .77231 L .32283 .78423 L p .707 .577 .707 r
F P
0 g
s
.16434 .69424 m .16135 .6412 L .15836 .62891 L p .707 .577 .707 r
F P
0 g
s
.64326 .688 m .64654 .72186 L .61542 .72104 L p .707 .577 .707 r
F P
0 g
s
.61542 .72104 m .61214 .68718 L .64326 .688 L p .707 .577 .707 r
F P
0 g
s
.17768 .73093 m .18096 .76479 L .20216 .77436 L p .707 .577 .707 r
F P
0 g
s
.20337 .79027 m .20506 .80714 L .23257 .81264 L p .707 .577 .707 r
F P
0 g
s
.53362 .77699 m .53194 .76012 L .55569 .7482 L p .707 .577 .707 r
F P
0 g
s
.18096 .76479 m .17768 .73093 L .16486 .71819 L p .707 .577 .707 r
F P
0 g
s
.58373 .72493 m .58045 .69107 L .61214 .68718 L p .707 .577 .707 r
F P
0 g
s
.58045 .69107 m .58373 .72493 L .55457 .73316 L p .707 .577 .707 r
F P
0 g
s
.61214 .68718 m .61542 .72104 L .58373 .72493 L p .707 .577 .707 r
F P
0 g
s
.20506 .80714 m .20337 .79027 L .18216 .78062 L p .707 .577 .707 r
F P
0 g
s
.67515 .74216 m .67684 .75903 L .64933 .75354 L p .707 .577 .707 r
F P
0 g
s
.64933 .75354 m .64764 .73667 L .67515 .74216 L p .707 .577 .707 r
F P
0 g
s
.55569 .7482 m .55738 .76507 L .53362 .77699 L p .707 .577 .707 r
F P
0 g
s
.35819 .70876 m .36147 .74262 L .36824 .72748 L p .707 .577 .707 r
F P
0 g
s
.36824 .72748 m .36496 .69362 L .35819 .70876 L p .707 .577 .707 r
F P
0 g
s
.36202 .62421 m .36501 .67725 L .36201 .66495 L p .707 .577 .707 r
F P
0 g
s
.36201 .66495 m .35902 .61192 L .36202 .62421 L p .707 .577 .707 r
F P
0 g
s
.34658 .77231 m .34827 .78918 L .36431 .77486 L p .707 .577 .707 r
F P
0 g
s
.36431 .77486 m .36262 .75799 L .34658 .77231 L p .707 .577 .707 r
F P
0 g
s
.18216 .78062 m .18385 .79749 L .20506 .80714 L p .707 .577 .707 r
F P
0 g
s
.55738 .76507 m .55569 .7482 L .58484 .73984 L p .707 .577 .707 r
F P
0 g
s
.16486 .71819 m .16815 .75205 L .18096 .76479 L p .707 .577 .707 r
F P
0 g
s
.15836 .62891 m .16134 .68194 L .16434 .69424 L p .707 .577 .707 r
F P
0 g
s
.64764 .73667 m .64933 .75354 L .61821 .75274 L p .707 .577 .707 r
F P
0 g
s
.61821 .75274 m .61652 .73587 L .64764 .73667 L p .707 .577 .707 r
F P
0 g
s
.5072 .24653 m .44966 .76431 L .49355 .7691 L p .707 .577 .707 r
F P
0 g
s
.49355 .7691 m .55109 .25131 L .5072 .24653 L p .707 .577 .707 r
F P
0 g
s
.55109 .25131 m .49355 .7691 L .53815 .7741 L p .707 .577 .707 r
F P
0 g
s
.16134 .68194 m .15836 .62891 L .16532 .61638 L p .707 .577 .707 r
F P
0 g
s
.18385 .79749 m .18216 .78062 L .16933 .76776 L p .707 .577 .707 r
F P
0 g
s
.58484 .73984 m .58652 .75671 L .55738 .76507 L p .707 .577 .707 r
F P
0 g
s
.53815 .7741 m .59569 .25632 L .55109 .25131 L p .707 .577 .707 r
F P
0 g
s
.59569 .25632 m .53815 .7741 L .5791 .77883 L p .707 .577 .707 r
F P
0 g
s
.16815 .75205 m .16486 .71819 L .16169 .70353 L p .707 .577 .707 r
F P
0 g
s
.58652 .75671 m .58484 .73984 L .61652 .73587 L p .707 .577 .707 r
F P
0 g
s
.61652 .73587 m .61821 .75274 L .58652 .75671 L p .707 .577 .707 r
F P
0 g
s
.46832 .24243 m .41078 .76021 L .44966 .76431 L p .707 .577 .707 r
F P
0 g
s
.44966 .76431 m .5072 .24653 L .46832 .24243 L p .707 .577 .707 r
F P
0 g
s
.5791 .77883 m .63664 .26105 L .59569 .25632 L p .707 .577 .707 r
F P
0 g
s
.36262 .75799 m .36431 .77486 L .37106 .75955 L p .707 .577 .707 r
F P
0 g
s
.37106 .75955 m .36937 .74267 L .36262 .75799 L p .707 .577 .707 r
F P
0 g
s
.16933 .76776 m .17102 .78463 L .18385 .79749 L p .707 .577 .707 r
F P
0 g
s
.36496 .69362 m .36824 .72748 L .36506 .71282 L p .707 .577 .707 r
F P
0 g
s
.36506 .71282 m .36178 .67896 L .36496 .69362 L p .707 .577 .707 r
F P
0 g
s
.35902 .61192 m .36201 .66495 L .34934 .65409 L p .707 .577 .707 r
F P
0 g
s
.34934 .65409 m .34635 .60105 L .35902 .61192 L p .707 .577 .707 r
F P
0 g
s
.16169 .70353 m .16497 .7374 L .16815 .75205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63664 .26105 m .5791 .77883 L .61238 .78283 L p .707 .577 .707 r
F P
0 g
s
.16532 .61638 m .16831 .66941 L .16134 .68194 L p .707 .577 .707 r
F P
0 g
s
.61238 .78283 m .66992 .26504 L .63664 .26105 L p .707 .577 .707 r
F P
0 g
s
.17102 .78463 m .16933 .76776 L .16614 .75294 L p .707 .577 .707 r
F P
0 g
s
.43825 .23942 m .38071 .7572 L .41078 .76021 L p .707 .577 .707 r
F P
0 g
s
.41078 .76021 m .46832 .24243 L .43825 .23942 L p .707 .577 .707 r
F P
0 g
s
.16831 .66941 m .16532 .61638 L .18158 .60485 L p .707 .577 .707 r
F P
0 g
s
.16497 .7374 m .16169 .70353 L .16845 .68839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16614 .75294 m .16782 .76982 L .17102 .78463 L p .707 .577 .707 r
F P
0 g
s
.36937 .74267 m .37106 .75955 L .36786 .74473 L p .707 .577 .707 r
F P
0 g
s
.36786 .74473 m .36618 .72786 L .36937 .74267 L p .707 .577 .707 r
F P
0 g
s
.36178 .67896 m .36506 .71282 L .35224 .70008 L p .707 .577 .707 r
F P
0 g
s
.35224 .70008 m .34896 .66622 L .36178 .67896 L p .707 .577 .707 r
F P
0 g
s
.34635 .60105 m .34934 .65409 L .32823 .64572 L p .707 .577 .707 r
F P
0 g
s
.32823 .64572 m .32524 .59268 L .34635 .60105 L p .707 .577 .707 r
F P
0 g
s
.16845 .68839 m .17174 .72225 L .16497 .7374 L p .707 .577 .707 r
F P
0 g
s
.66992 .26504 m .61238 .78283 L .63474 .7857 L p .707 .577 .707 r
F P
0 g
s
.18158 .60485 m .18457 .65788 L .16831 .66941 L p .707 .577 .707 r
F P
0 g
s
.18457 .65788 m .18158 .60485 L .20553 .59544 L p .707 .577 .707 r
F P
0 g
s
.16782 .76982 m .16614 .75294 L .17289 .73763 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .69228 .26791 L .66992 .26504 L p .707 .577 .707 r
F P
0 g
s
.17174 .72225 m .16845 .68839 L .18451 .67425 L p .707 .577 .707 r
F P
0 g
s
.36618 .72786 m .36786 .74473 L .35504 .73187 L p .707 .577 .707 r
F P
0 g
s
.35504 .73187 m .35335 .71499 L .36618 .72786 L p .707 .577 .707 r
F P
0 g
s
.41993 .23779 m .3624 .75557 L .38071 .7572 L p .707 .577 .707 r
F P
0 g
s
.38071 .7572 m .43825 .23942 L .41993 .23779 L p .707 .577 .707 r
F P
0 g
s
.32524 .59268 m .32823 .64572 L .30075 .64067 L p .707 .577 .707 r
F P
0 g
s
.30075 .64067 m .29777 .58763 L .32524 .59268 L p .707 .577 .707 r
F P
0 g
s
.17289 .73763 m .17458 .7545 L .16782 .76982 L p .707 .577 .707 r
F P
0 g
s
.34896 .66622 m .35224 .70008 L .33104 .69052 L p .707 .577 .707 r
F P
0 g
s
.33104 .69052 m .32776 .65665 L .34896 .66622 L p .707 .577 .707 r
F P
0 g
s
.20851 .64848 m .20553 .59544 L .23483 .58908 L p .707 .577 .707 r
F P
0 g
s
.20553 .59544 m .20851 .64848 L .18457 .65788 L p .707 .577 .707 r
F P
0 g
s
.18451 .67425 m .18779 .70811 L .17174 .72225 L p .707 .577 .707 r
F P
0 g
s
.29777 .58763 m .30075 .64067 L .2696 .63943 L p .707 .577 .707 r
F P
0 g
s
.2696 .63943 m .26661 .58639 L .29777 .58763 L p .707 .577 .707 r
F P
0 g
s
.18779 .70811 m .18451 .67425 L .20828 .66248 L p .707 .577 .707 r
F P
0 g
s
.17458 .7545 m .17289 .73763 L .18893 .7233 L p .707 .577 .707 r
F P
0 g
s
.23782 .64212 m .23483 .58908 L .26661 .58639 L p .707 .577 .707 r
F P
0 g
s
.23483 .58908 m .23782 .64212 L .20851 .64848 L p .707 .577 .707 r
F P
0 g
s
.26661 .58639 m .2696 .63943 L .23782 .64212 L p .707 .577 .707 r
F P
0 g
s
.32776 .65665 m .33104 .69052 L .30353 .68505 L p .707 .577 .707 r
F P
0 g
s
.30353 .68505 m .30025 .65119 L .32776 .65665 L p .707 .577 .707 r
F P
0 g
s
.63474 .7857 m .64399 .78716 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.64399 .78716 m .63923 .78707 L p .65376 .66634 L .707 .577 .707 r
F P
0 g
s
.65376 .66634 m .65435 .66424 L .64399 .78716 L .707 .577 .707 r
F
.66419 .6073 m .66369 .6071 L p .664 .60829 L F P
0 g
s
.67834 .66476 m .66369 .6071 L .66364 .62731 L .707 .577 .707 r
F
.64399 .78716 m .70153 .26937 L .69228 .26791 L p F P
0 g
s
.65516 .65467 m .65668 .64668 L .64399 .78716 L .707 .577 .707 r
F
.66369 .60991 m .6621 .62419 L p .65668 .64668 L F P
0 g
s
.6621 .62419 m .64399 .78716 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.66392 .52315 m .63474 .7857 L p .66378 .57436 L .707 .577 .707 r
F P
0 g
s
.65424 .60336 m .64157 .59249 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.65668 .64668 m .65424 .60336 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.66369 .6071 m .65424 .60336 L p .66144 .6217 L .707 .577 .707 r
F P
0 g
s
.66364 .62731 m .66369 .60991 L .66144 .6217 L .707 .577 .707 r
F
.66369 .60991 m .66369 .6071 L .66144 .6217 L F
.65424 .60336 m .65723 .65639 L .67834 .66476 L p F P
0 g
s
.64157 .59249 m .64456 .64553 L .65484 .65434 L p .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65549 .65164 L .65556 .65133 L .707 .577 .707 r
F
.65577 .65045 m .64157 .59249 L .65484 .65434 L F
.69228 .26791 m .66392 .52315 L p .66378 .57436 L F P
0 g
s
.65223 .67006 m .69676 .26929 L p .65516 .65467 L .707 .577 .707 r
F P
0 g
s
.70153 .26937 m .66369 .60991 L p .65668 .64668 L .707 .577 .707 r
F P
0 g
s
.65516 .65467 m .65556 .65133 L .65668 .64668 L .707 .577 .707 r
F
.65556 .65133 m .70153 .26937 L .65668 .64668 L F
.65484 .65434 m .65723 .65639 L p .65577 .65045 L F P
0 g
s
.69676 .26929 m .70153 .26937 L p .65556 .65133 L .707 .577 .707 r
F P
0 g
s
.65549 .65164 m .69676 .26929 L .65556 .65133 L .707 .577 .707 r
F
.63923 .78707 m .65223 .67006 L p .65516 .65467 L F P
0 g
s
.65723 .65639 m .65668 .64668 L p .65577 .65045 L .707 .577 .707 r
F P
0 g
s
.64456 .64553 m .64157 .59249 L .63857 .58019 L p .707 .577 .707 r
F P
0 g
s
.63923 .78707 m .62091 .78544 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.63857 .58019 m .64084 .62051 L p .64456 .64553 L .707 .577 .707 r
F P
0 g
s
.64314 .6397 m .64456 .64553 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.69676 .26929 m .6496 .69374 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.6496 .69374 m .63923 .78707 L p .64277 .63668 L .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .69676 .26929 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .63857 .58019 L .64396 .5705 L p .707 .577 .707 r
F P
0 g
s
.67845 .26766 m .64311 .58569 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.64396 .5705 m .64412 .57021 L p .64311 .58569 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64396 .5705 L .64311 .58569 L .707 .577 .707 r
F
.62091 .78544 m .59084 .78243 L p .65229 .4214 L F P
0 g
s
.64311 .58569 m .62091 .78544 L p .65229 .4214 L .707 .577 .707 r
F P
0 g
s
.62091 .78544 m .64311 .58569 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64311 .58569 m .67845 .26766 L p .6374 .67326 L .707 .577 .707 r
F P
0 g
s
.64084 .62051 m .64156 .63323 L .64314 .6397 L p .707 .577 .707 r
F P
0 g
s
.64156 .63323 m .64084 .62051 L p .64554 .56766 L .707 .577 .707 r
F P
0 g
s
.64412 .57021 m .64554 .56766 L p .64084 .62051 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .6579 .69221 L .64893 .6833 L p .707 .577 .707 r
F P
0 g
s
.64893 .6833 m .64508 .67947 L p .64779 .68731 L .707 .577 .707 r
F P
0 g
s
.66118 .72607 m .64893 .6833 L .64779 .68731 L .707 .577 .707 r
F
.65376 .66634 m .65516 .65467 L .65435 .66424 L F
.67834 .66476 m .67535 .61172 L .66419 .6073 L p F P
0 g
s
.67834 .66476 m .66419 .6073 L .664 .60829 L .707 .577 .707 r
F
.35335 .71499 m .35504 .73187 L .33383 .72222 L p F P
0 g
s
.33383 .72222 m .33214 .70534 L .35335 .71499 L p .707 .577 .707 r
F P
0 g
s
.18893 .7233 m .19061 .74018 L .17458 .7545 L p .707 .577 .707 r
F P
0 g
s
.21156 .69635 m .20828 .66248 L .23744 .65425 L p .707 .577 .707 r
F P
0 g
s
.20828 .66248 m .21156 .69635 L .18779 .70811 L p .707 .577 .707 r
F P
0 g
s
.73697 .67105 m .73398 .61802 L .70283 .61677 L p .707 .577 .707 r
F P
0 g
s
.73398 .61802 m .73697 .67105 L .76875 .66836 L p .707 .577 .707 r
F P
0 g
s
.76875 .66836 m .76576 .61532 L .73398 .61802 L p .707 .577 .707 r
F P
0 g
s
.76576 .61532 m .76875 .66836 L .79805 .662 L p .707 .577 .707 r
F P
0 g
s
.79805 .662 m .79506 .60897 L .76576 .61532 L p .707 .577 .707 r
F P
0 g
s
.30025 .65119 m .30353 .68505 L .27241 .68422 L p .707 .577 .707 r
F P
0 g
s
.27241 .68422 m .26913 .65036 L .30025 .65119 L p .707 .577 .707 r
F P
0 g
s
.41517 .2377 m .35763 .75548 L .3624 .75557 L p .707 .577 .707 r
F P
0 g
s
.3624 .75557 m .41993 .23779 L .41517 .2377 L p .707 .577 .707 r
F P
0 g
s
.70581 .66981 m .70283 .61677 L .67535 .61172 L p .707 .577 .707 r
F P
0 g
s
.70283 .61677 m .70581 .66981 L .73697 .67105 L p .707 .577 .707 r
F P
0 g
s
.19061 .74018 m .18893 .7233 L .21268 .71138 L p .707 .577 .707 r
F P
0 g
s
.24072 .68811 m .23744 .65425 L .26913 .65036 L p .707 .577 .707 r
F P
0 g
s
.23744 .65425 m .24072 .68811 L .21156 .69635 L p .707 .577 .707 r
F P
0 g
s
.26913 .65036 m .27241 .68422 L .24072 .68811 L p .707 .577 .707 r
F P
0 g
s
.79506 .60897 m .79805 .662 L .822 .6526 L p .707 .577 .707 r
F P
0 g
s
.822 .6526 m .81901 .59956 L .79506 .60897 L p .707 .577 .707 r
F P
0 g
s
.33214 .70534 m .33383 .72222 L .30632 .71672 L p .707 .577 .707 r
F P
0 g
s
.30632 .71672 m .30463 .69985 L .33214 .70534 L p .707 .577 .707 r
F P
0 g
s
.21268 .71138 m .21437 .72826 L .19061 .74018 L p .707 .577 .707 r
F P
0 g
s
.67535 .61172 m .67834 .66476 L .70581 .66981 L p .707 .577 .707 r
F P
0 g
s
.21437 .72826 m .21268 .71138 L .24183 .70302 L p .707 .577 .707 r
F P
0 g
s
.30463 .69985 m .30632 .71672 L .2752 .71593 L p .707 .577 .707 r
F P
0 g
s
.2752 .71593 m .27351 .69905 L .30463 .69985 L p .707 .577 .707 r
F P
0 g
s
.81901 .59956 m .822 .6526 L .83826 .64106 L p .707 .577 .707 r
F P
0 g
s
.83826 .64106 m .83527 .58803 L .81901 .59956 L p .707 .577 .707 r
F P
0 g
s
.24183 .70302 m .24351 .7199 L .21437 .72826 L p .707 .577 .707 r
F P
0 g
s
.74101 .74193 m .73773 .70807 L .7066 .70725 L p .707 .577 .707 r
F P
0 g
s
.73773 .70807 m .74101 .74193 L .7727 .73804 L p .707 .577 .707 r
F P
0 g
s
.7727 .73804 m .76942 .70418 L .73773 .70807 L p .707 .577 .707 r
F P
0 g
s
.24351 .7199 m .24183 .70302 L .27351 .69905 L p .707 .577 .707 r
F P
0 g
s
.76942 .70418 m .7727 .73804 L .80186 .72981 L p .707 .577 .707 r
F P
0 g
s
.80186 .72981 m .79857 .69595 L .76942 .70418 L p .707 .577 .707 r
F P
0 g
s
.27351 .69905 m .2752 .71593 L .24351 .7199 L p .707 .577 .707 r
F P
0 g
s
.70988 .74111 m .7066 .70725 L .6791 .70178 L p .707 .577 .707 r
F P
0 g
s
.7066 .70725 m .70988 .74111 L .74101 .74193 L p .707 .577 .707 r
F P
0 g
s
.79857 .69595 m .80186 .72981 L .82563 .71805 L p .707 .577 .707 r
F P
0 g
s
.82563 .71805 m .82234 .68419 L .79857 .69595 L p .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .36688 .75695 L .35763 .75548 L p .707 .577 .707 r
F P
0 g
s
.35763 .75548 m .41517 .2377 L .42442 .23916 L p .707 .577 .707 r
F P
0 g
s
.83527 .58803 m .83826 .64106 L .84522 .62854 L p .707 .577 .707 r
F P
0 g
s
.84522 .62854 m .84224 .5755 L .83527 .58803 L p .707 .577 .707 r
F P
0 g
s
.68238 .73564 m .6791 .70178 L .6579 .69221 L p .707 .577 .707 r
F P
0 g
s
.6791 .70178 m .68238 .73564 L .70988 .74111 L p .707 .577 .707 r
F P
0 g
s
.82234 .68419 m .82563 .71805 L .84168 .7039 L p .707 .577 .707 r
F P
0 g
s
.84168 .7039 m .8384 .67004 L .82234 .68419 L p .707 .577 .707 r
F P
0 g
s
.7439 .79056 m .74221 .77369 L .71109 .77289 L p .707 .577 .707 r
F P
0 g
s
.74221 .77369 m .7439 .79056 L .77558 .78659 L p .707 .577 .707 r
F P
0 g
s
.77558 .78659 m .7739 .76971 L .74221 .77369 L p .707 .577 .707 r
F P
0 g
s
.7739 .76971 m .77558 .78659 L .80473 .77823 L p .707 .577 .707 r
F P
0 g
s
.80473 .77823 m .80304 .76136 L .7739 .76971 L p .707 .577 .707 r
F P
0 g
s
.71278 .78976 m .71109 .77289 L .68358 .76739 L p .707 .577 .707 r
F P
0 g
s
.71109 .77289 m .71278 .78976 L .7439 .79056 L p .707 .577 .707 r
F P
0 g
s
.6579 .69221 m .66118 .72607 L .68238 .73564 L p .707 .577 .707 r
F P
0 g
s
.80304 .76136 m .80473 .77823 L .82848 .76631 L p .707 .577 .707 r
F P
0 g
s
.82848 .76631 m .8268 .74943 L .80304 .76136 L p .707 .577 .707 r
F P
0 g
s
.68358 .76739 m .68527 .78427 L .71278 .78976 L p .707 .577 .707 r
F P
0 g
s
.84224 .5755 m .84522 .62854 L .84223 .61624 L p .707 .577 .707 r
F P
0 g
s
.84223 .61624 m .83924 .5632 L .84224 .5755 L p .707 .577 .707 r
F P
0 g
s
.68527 .78427 m .68358 .76739 L .66238 .75774 L p .707 .577 .707 r
F P
0 g
s
.8384 .67004 m .84168 .7039 L .84845 .68876 L p .707 .577 .707 r
F P
0 g
s
.84845 .68876 m .84517 .6549 L .8384 .67004 L p .707 .577 .707 r
F P
0 g
s
.38924 .75982 m .36688 .75695 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.40894 .58257 m .38924 .75982 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42442 .23916 m .44678 .24203 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.36688 .75695 m .39606 .4944 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.39606 .4944 m .42442 .23916 L p .40167 .53279 L .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .38924 .75982 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .40852 .57971 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42275 .57851 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.42275 .57851 m .42519 .62184 L p .45504 .62519 L .707 .577 .707 r
F P
0 g
s
.43654 .63772 m .43553 .6468 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.43553 .6468 m .42253 .76381 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42519 .62184 m .42574 .63155 L .43127 .63034 L p .707 .577 .707 r
F P
0 g
s
.43127 .63034 m .45504 .62519 L p .42519 .62184 L .707 .577 .707 r
F P
0 g
s
.45504 .62519 m .45205 .57215 L .42275 .57851 L p .707 .577 .707 r
F P
0 g
s
.48006 .24603 m .43654 .63772 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.41709 .60227 m .43654 .63772 L .42519 .62184 L .707 .577 .707 r
F
.44678 .24203 m .48006 .24603 L p .41709 .60227 L F P
0 g
s
.38924 .75982 m .40894 .58257 L p .41709 .60227 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .40852 .57971 L .41351 .61383 L .707 .577 .707 r
F
.40894 .58257 m .44678 .24203 L p .41709 .60227 L F P
0 g
s
.41351 .61383 m .40894 .58257 L .39097 .5812 L .707 .577 .707 r
F
.40852 .57971 m .40778 .57978 L p .40894 .58257 L F P
0 g
s
.40778 .57978 m .39097 .5812 L p .40894 .58257 L .707 .577 .707 r
F P
0 g
s
.42574 .63155 m .42519 .62184 L p .41163 .58908 L .707 .577 .707 r
F P
0 g
s
.39097 .5812 m .39396 .63424 L .41621 .63235 L p .707 .577 .707 r
F P
0 g
s
.41621 .63235 m .42574 .63155 L p .41351 .61383 L .707 .577 .707 r
F P
0 g
s
.41351 .61383 m .39097 .5812 L .41621 .63235 L .707 .577 .707 r
F
.44678 .24203 m .40894 .58257 L p .40167 .53279 L F P
0 g
s
.8268 .74943 m .82848 .76631 L .84452 .75199 L p .707 .577 .707 r
F P
0 g
s
.84452 .75199 m .84284 .73511 L .8268 .74943 L p .707 .577 .707 r
F P
0 g
s
.66238 .75774 m .66406 .77462 L .68527 .78427 L p .707 .577 .707 r
F P
0 g
s
.64508 .67947 m .64836 .71334 L .66118 .72607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64836 .71334 m .64508 .67947 L .6419 .66482 L p .707 .577 .707 r
F P
0 g
s
.66406 .77462 m .66238 .75774 L .64955 .74488 L p .707 .577 .707 r
F P
0 g
s
.83924 .5632 m .84223 .61624 L .82955 .60537 L p .707 .577 .707 r
F P
0 g
s
.82955 .60537 m .82656 .55234 L .83924 .5632 L p .707 .577 .707 r
F P
0 g
s
.84517 .6549 m .84845 .68876 L .84527 .6741 L p .707 .577 .707 r
F P
0 g
s
.84527 .6741 m .84199 .64024 L .84517 .6549 L p .707 .577 .707 r
F P
0 g
s
.84284 .73511 m .84452 .75199 L .85127 .73667 L p .707 .577 .707 r
F P
0 g
s
.85127 .73667 m .84959 .7198 L .84284 .73511 L p .707 .577 .707 r
F P
0 g
s
.64955 .74488 m .65123 .76176 L .66406 .77462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6419 .66482 m .64518 .69868 L .64836 .71334 L p .707 .577 .707 r
F P
0 g
s
.64554 .56766 m .64852 .6207 L .64156 .63323 L p .707 .577 .707 r
F P
0 g
s
.59084 .78243 m .64838 .26465 L .67845 .26766 L p .707 .577 .707 r
F P
0 g
s
.64852 .6207 m .64554 .56766 L .66179 .55613 L p .707 .577 .707 r
F P
0 g
s
.39396 .63424 m .39097 .5812 L .35982 .57996 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64518 .69868 m .6419 .66482 L .64867 .64968 L p .707 .577 .707 r
F P
0 g
s
.65123 .76176 m .64955 .74488 L .64635 .73007 L p .707 .577 .707 r
F P
0 g
s
.3628 .63299 m .35982 .57996 L .33234 .57491 L p .707 .577 .707 r
F P
0 g
s
.35982 .57996 m .3628 .63299 L .39396 .63424 L p .707 .577 .707 r
F P
0 g
s
.82656 .55234 m .82955 .60537 L .80844 .59701 L p .707 .577 .707 r
F P
0 g
s
.80844 .59701 m .80546 .54397 L .82656 .55234 L p .707 .577 .707 r
F P
0 g
s
.84199 .64024 m .84527 .6741 L .83246 .66137 L p .707 .577 .707 r
F P
0 g
s
.83246 .66137 m .82917 .62751 L .84199 .64024 L p .707 .577 .707 r
F P
0 g
s
.64635 .73007 m .64804 .74694 L .65123 .76176 L p .707 .577 .707 r
F P
0 g
s
.84959 .7198 m .85127 .73667 L .84808 .72185 L p .707 .577 .707 r
F P
0 g
s
.84808 .72185 m .84639 .70498 L .84959 .7198 L p .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .42253 .76381 L p .44345 .6548 L .707 .577 .707 r
F P
0 g
s
.45205 .57215 m .45504 .62519 L .46638 .62073 L p .707 .577 .707 r
F P
0 g
s
.47455 .60859 m .45205 .57215 L .46638 .62073 L .707 .577 .707 r
F
.48257 .59668 m .46347 .76854 L p .45408 .71521 L F P
0 g
s
.44345 .6548 m .47828 .60306 L .45408 .71521 L .707 .577 .707 r
F
.47828 .60306 m .48257 .59668 L .45408 .71521 L F
.476 .56274 m .47828 .60306 L p .48349 .57889 L F P
0 g
s
.476 .56274 m .45205 .57215 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47899 .61578 m .47828 .60306 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.47828 .60306 m .476 .56274 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.46347 .76854 m .48075 .61308 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .46347 .76854 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.56561 .25576 m .53865 .49838 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.53865 .49838 m .50807 .77355 L p .50336 .56829 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .47933 .64737 L .45814 .65786 L p .707 .577 .707 r
F P
0 g
s
.45814 .65786 m .45556 .65913 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.48262 .68123 m .45814 .65786 L .45693 .66025 L .707 .577 .707 r
F
.45885 .693 m .48262 .68123 L p .45693 .66025 L F P
0 g
s
.45556 .65913 m .45588 .66235 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.45588 .66235 m .45885 .693 L p .45693 .66025 L .707 .577 .707 r
F P
0 g
s
.50336 .56829 m .48567 .56879 L .56561 .25576 L .707 .577 .707 r
F
.48075 .61308 m .48567 .56879 L p .50336 .56829 L F P
0 g
s
.48858 .55383 m .476 .56274 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .52101 .25076 L .54693 .25367 L p .707 .577 .707 r
F P
0 g
s
.54693 .25367 m .56561 .25576 L p .48567 .56879 L .707 .577 .707 r
F P
0 g
s
.48349 .57889 m .48567 .56879 L .476 .56274 L .707 .577 .707 r
F
.48895 .55356 m .48858 .55383 L p .48567 .56879 L F P
0 g
s
.49525 .60425 m .49226 .55121 L .48895 .55356 L p .707 .577 .707 r
F P
0 g
s
.48567 .56879 m .48257 .59668 L p .47828 .60306 L .707 .577 .707 r
F P
0 g
s
.49525 .60425 m .48895 .55356 L .48349 .57889 L .707 .577 .707 r
F
.52101 .25076 m .48567 .56879 L p .44345 .6548 L F P
0 g
s
.44345 .6548 m .48567 .56879 L .47828 .60306 L .707 .577 .707 r
F
.47899 .61578 m .49525 .60425 L p .48349 .57889 L F P
0 g
s
.47828 .60306 m .47899 .61578 L p .48349 .57889 L .707 .577 .707 r
F P
0 g
s
.46638 .62073 m .47899 .61578 L p .47455 .60859 L .707 .577 .707 r
F P
0 g
s
.64867 .64968 m .65195 .68354 L .64518 .69868 L p .707 .577 .707 r
F P
0 g
s
.66179 .55613 m .66478 .60917 L .64852 .6207 L p .707 .577 .707 r
F P
0 g
s
.64838 .26465 m .59084 .78243 L .55196 .77833 L p .707 .577 .707 r
F P
0 g
s
.33533 .62794 m .33234 .57491 L .31123 .56654 L p .707 .577 .707 r
F P
0 g
s
.33234 .57491 m .33533 .62794 L .3628 .63299 L p .707 .577 .707 r
F P
0 g
s
.66478 .60917 m .66179 .55613 L .68574 .54673 L p .707 .577 .707 r
F P
0 g
s
.55196 .77833 m .6095 .26055 L .64838 .26465 L p .707 .577 .707 r
F P
0 g
s
.65195 .68354 m .64867 .64968 L .66472 .63553 L p .707 .577 .707 r
F P
0 g
s
.42253 .76381 m .48006 .24603 L .52101 .25076 L p .707 .577 .707 r
F P
0 g
s
.64804 .74694 m .64635 .73007 L .6531 .71475 L p .707 .577 .707 r
F P
0 g
s
.80546 .54397 m .80844 .59701 L .78097 .59195 L p .707 .577 .707 r
F P
0 g
s
.78097 .59195 m .77798 .53892 L .80546 .54397 L p .707 .577 .707 r
F P
0 g
s
.398 .70512 m .39472 .67126 L .36359 .67043 L p .707 .577 .707 r
F P
0 g
s
.39472 .67126 m .398 .70512 L .42969 .70123 L p .707 .577 .707 r
F P
0 g
s
.42969 .70123 m .42641 .66737 L .39472 .67126 L p .707 .577 .707 r
F P
0 g
s
.42641 .66737 m .42969 .70123 L .45885 .693 L p .707 .577 .707 r
F P
0 g
s
.45885 .693 m .45556 .65913 L .42641 .66737 L p .707 .577 .707 r
F P
0 g
s
.82917 .62751 m .83246 .66137 L .81126 .6518 L p .707 .577 .707 r
F P
0 g
s
.81126 .6518 m .80797 .61794 L .82917 .62751 L p .707 .577 .707 r
F P
0 g
s
.6531 .71475 m .65479 .73162 L .64804 .74694 L p .707 .577 .707 r
F P
0 g
s
.84639 .70498 m .84808 .72185 L .83525 .70899 L p .707 .577 .707 r
F P
0 g
s
.83525 .70899 m .83356 .69212 L .84639 .70498 L p .707 .577 .707 r
F P
0 g
s
.36687 .70429 m .36359 .67043 L .33608 .66496 L p .707 .577 .707 r
F P
0 g
s
.36359 .67043 m .36687 .70429 L .398 .70512 L p .707 .577 .707 r
F P
0 g
s
.68873 .59976 m .68574 .54673 L .71504 .54037 L p .707 .577 .707 r
F P
0 g
s
.68574 .54673 m .68873 .59976 L .66478 .60917 L p .707 .577 .707 r
F P
0 g
s
.6095 .26055 m .55196 .77833 L .50807 .77355 L p .707 .577 .707 r
F P
0 g
s
.31422 .61958 m .31123 .56654 L .29856 .55568 L p .707 .577 .707 r
F P
0 g
s
.31123 .56654 m .31422 .61958 L .33533 .62794 L p .707 .577 .707 r
F P
0 g
s
.66472 .63553 m .66801 .66939 L .65195 .68354 L p .707 .577 .707 r
F P
0 g
s
.77798 .53892 m .78097 .59195 L .74981 .59071 L p .707 .577 .707 r
F P
0 g
s
.74981 .59071 m .74682 .53768 L .77798 .53892 L p .707 .577 .707 r
F P
0 g
s
.50807 .77355 m .56561 .25576 L .6095 .26055 L p .707 .577 .707 r
F P
0 g
s
.66801 .66939 m .66472 .63553 L .68849 .62377 L p .707 .577 .707 r
F P
0 g
s
.71803 .5934 m .71504 .54037 L .74682 .53768 L p .707 .577 .707 r
F P
0 g
s
.71504 .54037 m .71803 .5934 L .68873 .59976 L p .707 .577 .707 r
F P
0 g
s
.74682 .53768 m .74981 .59071 L .71803 .5934 L p .707 .577 .707 r
F P
0 g
s
.49226 .55121 m .49525 .60425 L .50221 .59172 L p .707 .577 .707 r
F P
0 g
s
.50221 .59172 m .49923 .53869 L .49226 .55121 L p .707 .577 .707 r
F P
0 g
s
.33937 .69883 m .33608 .66496 L .31488 .6554 L p .707 .577 .707 r
F P
0 g
s
.33608 .66496 m .33937 .69883 L .36687 .70429 L p .707 .577 .707 r
F P
0 g
s
.65479 .73162 m .6531 .71475 L .66914 .70043 L p .707 .577 .707 r
F P
0 g
s
.80797 .61794 m .81126 .6518 L .78375 .64633 L p .707 .577 .707 r
F P
0 g
s
.78375 .64633 m .78047 .61247 L .80797 .61794 L p .707 .577 .707 r
F P
0 g
s
.47933 .64737 m .48262 .68123 L .49867 .66709 L p .707 .577 .707 r
F P
0 g
s
.49867 .66709 m .49539 .63322 L .47933 .64737 L p .707 .577 .707 r
F P
0 g
s
.40089 .75375 m .3992 .73687 L .36808 .73607 L p .707 .577 .707 r
F P
0 g
s
.3992 .73687 m .40089 .75375 L .43257 .74977 L p .707 .577 .707 r
F P
0 g
s
.43257 .74977 m .43089 .7329 L .3992 .73687 L p .707 .577 .707 r
F P
0 g
s
.43089 .7329 m .43257 .74977 L .46172 .74142 L p .707 .577 .707 r
F P
0 g
s
.46172 .74142 m .46003 .72454 L .43089 .7329 L p .707 .577 .707 r
F P
0 g
s
.83356 .69212 m .83525 .70899 L .81404 .69934 L p .707 .577 .707 r
F P
0 g
s
.81404 .69934 m .81236 .68247 L .83356 .69212 L p .707 .577 .707 r
F P
0 g
s
.29856 .55568 m .30154 .60871 L .31422 .61958 L p .707 .577 .707 r
F P
0 g
s
.66914 .70043 m .67083 .7173 L .65479 .73162 L p .707 .577 .707 r
F P
0 g
s
.69178 .65763 m .68849 .62377 L .71765 .61554 L p .707 .577 .707 r
F P
0 g
s
.68849 .62377 m .69178 .65763 L .66801 .66939 L p .707 .577 .707 r
F P
0 g
s
.36977 .75295 m .36808 .73607 L .34057 .73058 L p .707 .577 .707 r
F P
0 g
s
.36808 .73607 m .36977 .75295 L .40089 .75375 L p .707 .577 .707 r
F P
0 g
s
.30154 .60871 m .29856 .55568 L .29556 .54338 L p .707 .577 .707 r
F P
0 g
s
.78047 .61247 m .78375 .64633 L .75263 .64551 L p .707 .577 .707 r
F P
0 g
s
.75263 .64551 m .74934 .61164 L .78047 .61247 L p .707 .577 .707 r
F P
0 g
s
.31488 .6554 m .31817 .68926 L .33937 .69883 L p .707 .577 .707 r
F P
0 g
s
.46003 .72454 m .46172 .74142 L .48547 .72949 L p .707 .577 .707 r
F P
0 g
s
.48547 .72949 m .48379 .71262 L .46003 .72454 L p .707 .577 .707 r
F P
0 g
s
.31817 .68926 m .31488 .6554 L .30207 .64266 L p .707 .577 .707 r
F P
0 g
s
.72093 .6494 m .71765 .61554 L .74934 .61164 L p .707 .577 .707 r
F P
0 g
s
.71765 .61554 m .72093 .6494 L .69178 .65763 L p .707 .577 .707 r
F P
0 g
s
.34057 .73058 m .34226 .74745 L .36977 .75295 L p .707 .577 .707 r
F P
0 g
s
.67083 .7173 m .66914 .70043 L .6929 .68851 L p .707 .577 .707 r
F P
0 g
s
.74934 .61164 m .75263 .64551 L .72093 .6494 L p .707 .577 .707 r
F P
0 g
s
.49923 .53869 m .50221 .59172 L .49921 .57942 L p .707 .577 .707 r
F P
0 g
s
.49921 .57942 m .49623 .52639 L .49923 .53869 L p .707 .577 .707 r
F P
0 g
s
.34226 .74745 m .34057 .73058 L .31937 .72093 L p .707 .577 .707 r
F P
0 g
s
.49539 .63322 m .49867 .66709 L .50544 .65194 L p .707 .577 .707 r
F P
0 g
s
.50544 .65194 m .50216 .61808 L .49539 .63322 L p .707 .577 .707 r
F P
0 g
s
.81236 .68247 m .81404 .69934 L .78653 .69385 L p .707 .577 .707 r
F P
0 g
s
.78653 .69385 m .78485 .67698 L .81236 .68247 L p .707 .577 .707 r
F P
0 g
s
.6929 .68851 m .69458 .70538 L .67083 .7173 L p .707 .577 .707 r
F P
0 g
s
.48379 .71262 m .48547 .72949 L .50151 .71517 L p .707 .577 .707 r
F P
0 g
s
.50151 .71517 m .49983 .6983 L .48379 .71262 L p .707 .577 .707 r
F P
0 g
s
.29556 .54338 m .29855 .59641 L .30154 .60871 L p .707 .577 .707 r
F P
0 g
s
.31937 .72093 m .32105 .7378 L .34226 .74745 L p .707 .577 .707 r
F P
0 g
s
.30207 .64266 m .30535 .67652 L .31817 .68926 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.69458 .70538 m .6929 .68851 L .72204 .68015 L p .707 .577 .707 r
F P
0 g
s
.29855 .59641 m .29556 .54338 L .30253 .53085 L p .707 .577 .707 r
F P
0 g
s
.78485 .67698 m .78653 .69385 L .75541 .69305 L p .707 .577 .707 r
F P
0 g
s
.75541 .69305 m .75373 .67618 L .78485 .67698 L p .707 .577 .707 r
F P
0 g
s
.30535 .67652 m .30207 .64266 L .29889 .628 L p .707 .577 .707 r
F P
0 g
s
.32105 .7378 m .31937 .72093 L .30654 .70807 L p .707 .577 .707 r
F P
0 g
s
.72204 .68015 m .72373 .69702 L .69458 .70538 L p .707 .577 .707 r
F P
0 g
s
.72373 .69702 m .72204 .68015 L .75373 .67618 L p .707 .577 .707 r
F P
0 g
s
.75373 .67618 m .75541 .69305 L .72373 .69702 L p .707 .577 .707 r
F P
0 g
s
.49623 .52639 m .49921 .57942 L .48654 .56856 L p .707 .577 .707 r
F P
0 g
s
.48654 .56856 m .48355 .51552 L .49623 .52639 L p .707 .577 .707 r
F P
0 g
s
.50216 .61808 m .50544 .65194 L .50226 .63729 L p .707 .577 .707 r
F P
0 g
s
.50226 .63729 m .49898 .60343 L .50216 .61808 L p .707 .577 .707 r
F P
0 g
s
.49983 .6983 m .50151 .71517 L .50826 .69985 L p .707 .577 .707 r
F P
0 g
s
.50826 .69985 m .50658 .68298 L .49983 .6983 L p .707 .577 .707 r
F P
0 g
s
.30654 .70807 m .30822 .72494 L .32105 .7378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29889 .628 m .30217 .66186 L .30535 .67652 L p .707 .577 .707 r
F P
0 g
s
.30253 .53085 m .30551 .58388 L .29855 .59641 L p .707 .577 .707 r
F P
0 g
s
.30551 .58388 m .30253 .53085 L .31878 .51932 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30217 .66186 m .29889 .628 L .30566 .61286 L p .707 .577 .707 r
F P
0 g
s
.30822 .72494 m .30654 .70807 L .30334 .69325 L p .707 .577 .707 r
F P
0 g
s
.48355 .51552 m .48654 .56856 L .46543 .56019 L p .707 .577 .707 r
F P
0 g
s
.46543 .56019 m .46244 .50715 L .48355 .51552 L p .707 .577 .707 r
F P
0 g
s
.49898 .60343 m .50226 .63729 L .48945 .62455 L p .707 .577 .707 r
F P
0 g
s
.48945 .62455 m .48616 .59069 L .49898 .60343 L p .707 .577 .707 r
F P
0 g
s
.30334 .69325 m .30503 .71013 L .30822 .72494 L p .707 .577 .707 r
F P
0 g
s
.50658 .68298 m .50826 .69985 L .50507 .68504 L p .707 .577 .707 r
F P
0 g
s
.50507 .68504 m .50338 .66817 L .50658 .68298 L p .707 .577 .707 r
F P
0 g
s
.30566 .61286 m .30894 .64672 L .30217 .66186 L p .707 .577 .707 r
F P
0 g
s
.31878 .51932 m .32177 .57235 L .30551 .58388 L p .707 .577 .707 r
F P
0 g
s
.32177 .57235 m .31878 .51932 L .34273 .50991 L p .707 .577 .707 r
F P
0 g
s
.30894 .64672 m .30566 .61286 L .32171 .59872 L p .707 .577 .707 r
F P
0 g
s
.30503 .71013 m .30334 .69325 L .31009 .67793 L p .707 .577 .707 r
F P
0 g
s
.46244 .50715 m .46543 .56019 L .43796 .55514 L p .707 .577 .707 r
F P
0 g
s
.43796 .55514 m .43497 .5021 L .46244 .50715 L p .707 .577 .707 r
F P
0 g
s
.48616 .59069 m .48945 .62455 L .46825 .61498 L p .707 .577 .707 r
F P
0 g
s
.46825 .61498 m .46496 .58112 L .48616 .59069 L p .707 .577 .707 r
F P
0 g
s
.31009 .67793 m .31178 .69481 L .30503 .71013 L p .707 .577 .707 r
F P
0 g
s
.50338 .66817 m .50507 .68504 L .49224 .67218 L p .707 .577 .707 r
F P
0 g
s
.49224 .67218 m .49055 .6553 L .50338 .66817 L p .707 .577 .707 r
F P
0 g
s
.34572 .56295 m .34273 .50991 L .37203 .50355 L p .707 .577 .707 r
F P
0 g
s
.34273 .50991 m .34572 .56295 L .32177 .57235 L p .707 .577 .707 r
F P
0 g
s
.32171 .59872 m .325 .63258 L .30894 .64672 L p .707 .577 .707 r
F P
0 g
s
.43497 .5021 m .43796 .55514 L .4068 .5539 L p .707 .577 .707 r
F P
0 g
s
.4068 .5539 m .40381 .50086 L .43497 .5021 L p .707 .577 .707 r
F P
0 g
s
.325 .63258 m .32171 .59872 L .34548 .58695 L p .707 .577 .707 r
F P
0 g
s
.37502 .55659 m .37203 .50355 L .40381 .50086 L p .707 .577 .707 r
F P
0 g
s
.37203 .50355 m .37502 .55659 L .34572 .56295 L p .707 .577 .707 r
F P
0 g
s
.40381 .50086 m .4068 .5539 L .37502 .55659 L p .707 .577 .707 r
F P
0 g
s
.31178 .69481 m .31009 .67793 L .32613 .66361 L p .707 .577 .707 r
F P
0 g
s
.46496 .58112 m .46825 .61498 L .44074 .60952 L p .707 .577 .707 r
F P
0 g
s
.44074 .60952 m .43746 .57565 L .46496 .58112 L p .707 .577 .707 r
F P
0 g
s
.49055 .6553 m .49224 .67218 L .47103 .66253 L p .707 .577 .707 r
F P
0 g
s
.47103 .66253 m .46935 .64565 L .49055 .6553 L p .707 .577 .707 r
F P
0 g
s
.32613 .66361 m .32782 .68049 L .31178 .69481 L p .707 .577 .707 r
F P
0 g
s
.34877 .62081 m .34548 .58695 L .37464 .57872 L p .707 .577 .707 r
F P
0 g
s
.34548 .58695 m .34877 .62081 L .325 .63258 L p .707 .577 .707 r
F P
0 g
s
.43746 .57565 m .44074 .60952 L .40961 .60869 L p .707 .577 .707 r
F P
0 g
s
.40961 .60869 m .40633 .57483 L .43746 .57565 L p .707 .577 .707 r
F P
0 g
s
.37792 .61258 m .37464 .57872 L .40633 .57483 L p .707 .577 .707 r
F P
0 g
s
.37464 .57872 m .37792 .61258 L .34877 .62081 L p .707 .577 .707 r
F P
0 g
s
.32782 .68049 m .32613 .66361 L .34989 .65169 L p .707 .577 .707 r
F P
0 g
s
.40633 .57483 m .40961 .60869 L .37792 .61258 L p .707 .577 .707 r
F P
0 g
s
.46935 .64565 m .47103 .66253 L .44352 .65703 L p .707 .577 .707 r
F P
0 g
s
.44352 .65703 m .44184 .64016 L .46935 .64565 L p .707 .577 .707 r
F P
0 g
s
.34989 .65169 m .35157 .66856 L .32782 .68049 L p .707 .577 .707 r
F P
0 g
s
.35157 .66856 m .34989 .65169 L .37903 .64333 L p .707 .577 .707 r
F P
0 g
s
.44184 .64016 m .44352 .65703 L .4124 .65623 L p .707 .577 .707 r
F P
0 g
s
.4124 .65623 m .41072 .63936 L .44184 .64016 L p .707 .577 .707 r
F P
0 g
s
.37903 .64333 m .38072 .66021 L .35157 .66856 L p .707 .577 .707 r
F P
0 g
s
.38072 .66021 m .37903 .64333 L .41072 .63936 L p .707 .577 .707 r
F P
0 g
s
.41072 .63936 m .4124 .65623 L .38072 .66021 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001fOol4002SOol007Ioo``0
09]oo`00MWoo00<005YF00001UYF00<005YFFUH02@00TWoo001fOol00`00FUH00006FUH00`00FUIJ
EP04FUH@0027Ool007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00=JEQD007Yoo`00
MGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEUYFFUHD001aOol007Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP04001JEUYFFUH6
0002FUH6001[Ool007Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEPl006Aoo`00MGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF3P00G7oo001eOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
3000EGoo001eOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001EOol007Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Eoo`00MGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH04EYF00<005YFFUH00eYF0P00
EGoo001dOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYFEWoo001dOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUIFOol007Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEWoo05Eoo`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0EGoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001FOol007Aoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Ioo`00M7oo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00EWoo001dOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001FOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
Oomoo`1DOol007=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1F
Ool007=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05Ioo`00Lgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0EWoo001cOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=oo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005Moo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Egoo001cOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001GOol007=o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Moo`00LWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Moo`00LWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEWoo05Moo`00LWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Egoo001bOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIoo`1GOol0079oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
05Qoo`00LWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00F7oo001bOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001HOol0079oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000EJEP8005Qoo`00LGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Qoo`00LGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Qo
o`00LGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0F7oo001aOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001IOol0075oo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8005Uoo`00LGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<0
05YF00001EYF0P00FGoo001aOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001I
Ool0075oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Uoo`00L7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Uoo`00L7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEP0005Uoo`00L7oo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF00001EYF0P00FWoo001`Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001JOol0071oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005Yoo`00L7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00FWoo001`Ool00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001JOol0071oo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Yoo`00Kgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005Yo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005Yoo`00Kgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo001_Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006moo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8005]oo`00Kgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Fgoo001_Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001KOol006ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001^Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001LOol006ioo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00G7oo001]Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
G7oo001]Ool@0003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001LOol006Qoo`H000AJEP03001JEUYF00IJ
EP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0005aoo`00I7oo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`00G7oo001POol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol005aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005eoo`00FWoo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00GGoo001IOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00GGoo
001FOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0005eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0011oo`T004Aoo`00E7oo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Uoo`L000AJEP03001JEUYF009JEPP003aoo`00
E7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH4000hOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool30006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000fOol005Aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000017oo0000000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P00=7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP03
FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040002Ool0
0`00FUIJEP040003FUH00`00FUIJEP06FUH01000FUIJEUYF100015YF00@005YFFUH000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP@000Ioo`03001JEUYF00D0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP<00005FUH005YFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH0
0`00FUH00003000:Ool00`00FUIJEP0500000eYF001JEP08FUH00`00FUIJEP08FUH20002FUH20007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH2000>Ool00`00FUIJEP0500000eYF001J
EP08FUH00`00FUIJEP0:FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<0
05YFFUH01@002Goo00<005YFFUH04@0035YF10001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00@005YF001JEP80
00AJEP04001JEUYFFUH=0004FUH00`00FUIJEP06FUH00`00FUH00003000:FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH000020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH40006FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool004Moo`T000Aoo`05001JEP00FUH00005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo0011Ool60004FUH00`00FUIJEP02FUH60002FUH00`00FUIJ
EP03FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000015YF001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000mOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHG0004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20003FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH01@00FUIJEUYF00001UYF00<005YFFUH010001goo0`003Goo1@001EYF00D0
05YFFUIJEP0002eoo`00=goo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
0eYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00QJEP05001JEUYFFUH00005FUH4000:Ool5000AOol20003FUH01@00FUIJEUYF0000;Goo000eOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYFFUH2000>Ool5000@Ool200001EYF000005YF00000eYF0P00;7oo000cOol20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001JEP00
000@Ool5000>Ool20003FUH01000FUH000000eYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF1@0047oo20001Goo1@001EYF00D005YFFUIJ
EP00009JEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P003EYF00@005YFFUIJ
EPD000EJEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00H005YFFUIJEP00FUH40009Ool40002FUH00`00FUIJEP02FUH90006FUH00`00FUIJ
EP02FUH4000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP0;FUH00`00FUIJ
EP06FUH20003FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH00eYF2@001UYF00<005YFFUH01UYF00@005YFFUIJEPD0009J
EP03001JEUYF00=JEP<002aoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH0
1UYF00D005YFFUIJEP0000MJEP<00006FUH00000FUH005YF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00AJEP@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP<002aoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;FUH01000FUH000000UYF00<0
05YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00P0015YF00<005YF0000;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020006FUH00`00FUIJ
EP05FUH30007FUH01000FUIJEP002eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool0
02eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUH20003FUH40002FUH00`00FUIJEP04FUH=00000eYF001JEP09FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P0000=JEP000000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
1EYF00<005YF00003@002EYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002eoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@000eYF00D0
05YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002Ool01@00FUIJEP00FUH02`000eYF
00<005YFFUH025YF00@005YFFUIJEP800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`@0009JEP8000AJEP03001JEUYF00=JEP04001J
EUYF0002Ool70004FUH00`00FUIJEP02FUH80006FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0019oo`05001J
EUYF001oo`050005FUH01@00FUIJEP00Ool00P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPD00004FUH005YF0002FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@000aoo`L000Aoo`03001JEP0000Ioo`8000=JEP03001JEP00008000=JEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1`00
25YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00@005YFFUH002eoo`00;Goo00<005YF0000
15YF00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF009JEPH00003FUH007oo00=oo`800003FUH0
000000<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=J
EP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEP00000:Ool4
0006FUH00`00FUIJEP06FUH20002FUH50002FUH200000eYF001JEP07FUH00`00FUIJEP02FUH?0005
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00;7oo000]Ool00`00FUH00004FUH5
0005Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000AJEP00000000=JEP03
001JEUYF00EJEPL000UJEP03001JEUYF009JEP@00003FUH005YF00AJEP@000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003Ool200000eYF001JEP02
FUH00`00Oomoo`0ZOol002eoo`03001JEP00009JEP8000=JEP03001JEP0000@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF008000EJEP03001JEUYF009JEP@000EJEP03001J
EUYF00MJEPD00004FUH005YFFUH20005FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<000Moo`8000=JEP03001oogoo02Yoo`00;Goo00<005YF0000
0P001EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00@005YF0000
00IJEP03001JEP0000<0009JEP03001JEUYF00=JEP04001JEUYFFUH70005FUH00`00FUIJEP02FUH2
0003FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF
001JEP0000AJEP03001JEP0000@000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00@000aoo`04
001JEUYF000/Ool002eoo`05001JEP00FUH00004FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH20002FUH200000eYF001JEP05FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH200000eYF001JEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH0009JEP04001JEUYFFUH20005FUHI000AOol3000/Ool002eoo`80009JEP03001JEUYF
008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH01000
FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYF0002FUH0
1P00FUIJEP00FUH000EJEP03001JEUYF008000Moo`D001Qoo`800003FUH0000002]oo`00;Goo0P00
0UYF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH200001EYF001JEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUH0009JEP03001JEP00009JEP03001JEUYF00=JEP05001JEUYFFUH00007OolA000:Ool2
00000eYF001JEP02000[Ool002eoo`80009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP<000MJEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00D005YFFUIJEP00009oo`L000AJEP03
001JEUYF00IJEP03001JEP0000<000Eoo`06001JEUYFFUH005YF0P00:goo000]Ool200000eYF001J
EP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0003FUH01@00FUIJEUYF0000
1UYF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00D005YFFUIJ
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=oo`0000000P00
15YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0015YF
00@005YFFUH002]oo`00;Goo0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YF
FUH00eYF0P0000=JEP00000015YF00<005YFFUH015YF00<005YFFUH015YF1@001eYF00<005YFFUH0
1EYF00<005YFFUH00P0025YF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003Ool5000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P000eYF00@005YFFUH002]oo`00;Woo0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001EYF00<005YFFUH01eYF00H005YFFUIJEP00FUH40004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50007FUH00`00FUIJEP05FUH40008FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF0`000eYF100025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<005YF0000:goo000^Ool20005
FUH00`00FUIJEP04FUH00`00FUH000020007FUH00`00FUIJEP07FUH02P00FUIJEUYF001JEP00FUH0
05YF0`0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH015YF0P000UYF00<005YF
FUH01UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003
FUH500001EYF001JEUYF000025YF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000=JEP00
0000;7oo000^Ool20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP05FUH;0003FUH20002FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP06FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
009JEP03001JEUYF00<000AJEP03001JEUYF00AJEPH000eoo`800003FUH0000000@000AJEP03001J
EP00008002aoo`00;Goo00<005YF00001EYF00@005YFFUIJEP8000EJEP03001JEUYF00H000AJEP03
001JEUYF009JEPT000EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF
00EJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF
00@005YFFUH000IJEP03001JEUYF00@0011oo`<000=JEP03001JEUYF00=JEP8000=JEP03001JEP00
02eoo`00;Goo00<005YF00001EYF00@005YF000000MJEP<00003FUH005YF00MJEP03001JEUYF00IJ
EP80009JEPH000Eooa4000=JEP8000YJEP03001JEUYF00=JEP800003FUH00000009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000005FUH6
000<Ool60006FUH00`00FUIJEP05FUH200001EYF001JEUYF0000;7oo000]Ool01000FUIJEP0015YF
0P0000=JEP00FUH015YF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF0`0017oo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF009JEP8000=JEPl000AJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEP000002FUH0
0`00Oomoo`0ZOol002eoo`04001JEUYF0003FUH00`00Oomoo`03000015YF000000001eYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001EYF00<005YFFUH00P0000Aoo`000000009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP8000YJEP05001JEUYFFUH00004FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000800003FUH0
07oo02]oo`00;Goo00D005YFFUH005YF008000Eoo`800003FUH005YF00MJEP03001JEUYF009JEPl0
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEP00
008000AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH200000eYF001JEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003Ool00`00FUH0000[Ool002eoo`03001JEUYF008000Eoo`8000=JEP03001JEUYF
00EJEPX000Uoo`03001JEP0000<00003FUH005YF00AJEP<0009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Eoo`8002]oo`00;Woo00<0
05YF000017oo0P001EYF00<005YFFUH00UYF0`0017oo0`0037oo00<005YFFUH00P0000=oo`000000
1EYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF0P0015YF00@0
05YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP04
001JEUYFFUH20008Ool00`00Oomoo`0YOol002ioo`@0009oo`8000IJEP03001JEP00008000Ioo`D0
00]oo`05001JEUYF001JEP050003FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20006FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP04001JEP000009Ool2000[Ool002ioo`80009JEP800003FUH005YF00EJEP8000Uo
o`D000aoo`03001JEP0000AJEP@00004FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`001eYF00<005YFFUH015YF0`002goo0P00:goo000^Ool01@00FUIJEUYF00000eYF00@005YF
FUIJEP8000]oo`D000eoo`<000AJEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000EJEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEUYF0080009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000eoo`03001JEP0002]oo`00;Woo0P0000=JEP00FUH00eYF00@005YF
000000ioo`<000aoo`800003FUH0000000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04
001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1`004Goo00<005YF0000
:goo000^Ool200000eYF001JEP03FUH4000JOol30003FUH01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00000017oo4P005goo0P0000=JEP00
Ool0:Woo000^Ool40003FUH01@00FUIJEP00FUH0100047oo1P001UYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJ
EP<000Ioo`03001JEP0002=oo`04001JEP00000/Ool002moo`<00003FUH0000000=JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000020003Ool3000ROol01@00FUIJ
EUYF0000;7oo000_Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF000015YF00<005YFFUH00UYF100000=JEP0000007goo0P0015YF00<007oo
Ool0:Woo000_Ool01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=oo`0000003`000UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H0
05YF000005YF0004FUH00`00FUIJEP02FUH300000eYF0000000MOol200000eYF001JEP02FUH00`00
Oomoo`0[Ool002moo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`@000=JEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000002FUH50004FUH01000FUH005YF0P006goo0P000eYF00@005YF000002ioo`00
;goo0P0000=oo`0000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000Eoo`800003FUH007oo00P000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00
0002FUH30002Ool20003FUH01@00FUH005YF00005goo10001EYF0P00<7oo000_Ool20002Ool00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH000001Goo0P0000=JEP0000002Woo2`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF001oo`00FUH00002FUH200001UYF0000
0000FUH0009JEP8001=oo`@0009JEP03001JEUYF00AJEP03001oogoo02moo`00;goo0P000goo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001Woo00@0
05YFFUIJEP8001Eoo``000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP07001JEP00Ool005YF000015YF1P000UYF00<007ooOol03Goo1@001UYF00<005YFFUH0
0UYF0P00<Woo000_Ool30004Ool200000eYF001JEP06FUH00`00FUIJEP04FUH30008FUH00`00FUIJ
EP040007Ool20004FUH00`00Oomoo`0POol90009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002Ool30005FUH01000FUIJEUYF20001goo10000UYF00<005YFFUH01UYF
00<005YFFUH00P00=7oo000_Ool200000eYF001oo`04Ool50004FUH00`00FUIJEP03FUH50003FUH7
0009Ool200000eYF001JEP03FUH00`00Oomoo`0VOol90003FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000005FUH00`00FUIJEP05FUH01000FUIJEUYF
1`001UYF00<005YFFUH01UYF0`00=Woo000`Ool01000FUIJEP002Goo4P003Woo0P000eYF00D005YF
FUIJEP0002Uoo`<000=JEP03001JEUYF00T000EJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000=JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2000hOol0031oo`03001JEUYF00<0015oo`D000ioo`<000IJEP03001JEP0002Yoo`<0
009JEP03001JEUYF009JEP04001JEUYFFUH>0004FUH00`00FUIJEP02FUH00`00FUH00003FUH01000
FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000>Woo
000`Ool01000FUIJEP000UYF0P0047oo0`003Goo0P0000=JEP00FUH01UYF0P00:goo00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH0000;0003FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000nOol0035oo`04001JEUYF0003FUH3000JOol3
0003FUH00`00FUIJEP04FUH2000/Ool00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000goo0000000@0015Ool0039o
o`<000AJEP03001JEP0000<0011oo`H000MJEP04001JEUYFFUH2000^Ool00`00FUIJEP020005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0004Ool00`00FUH0001BOol003Aoo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF
00IJEP04001JEP00000`Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001Woo00<005YF0000DWoo000eOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000cOol200000goo
001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUH000001goo0P0000=JEP00Ool0DGoo000gOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000fOol01000Oomoogoo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0027oo00@005YF000005=oo`00>Goo0`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00>Goo0P0017oo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo00D005YFFUIJEP0005=oo`00
?7oo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?7oo00<005YF00001Goo0`001UYF00<0
05YFFUH01EYF0`001eYF00<005YF00000P002Woo0P0015YF00<007ooOol0DGoo0010Ool?0012Ool2
00000eYF001oo`06Ool40002FUH00`00FUIJEP04FUH50002FUH6000;Ool200000eYF001JEP02FUH0
0`00Oomoo`1BOol0099oo`04001JEUYF000:Ool@000?Ool20003FUH01000FUH00000EGoo002BOol0
0`00FUIJEP03000AOol5000=Ool40005FUH2001GOol009=oo`03001JEP00009JEP80011oo`<000Yo
o`@0009JEP03001JEUYF00AJEP03001oogoo05Ioo`00Tgoo00<005YF000015YF1@004Goo1`001UYF
00<005YFFUH00UYF0P00FGoo002DOol20005FUH01000FUIJEUYF4@0015YF00<005YFFUH01UYF00<0
05YFFUH00P00Fgoo002EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH3001MOol009Moo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8005moo`00VWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01000HGoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001UOol00:5ooa0006ao
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59829 .75401 m .59644 .69987 L .56528 .69839 L p .707 .577 .707 r
F P
0 g
s
.59644 .69987 m .59829 .75401 L .63011 .75204 L p .707 .577 .707 r
F P
0 g
s
.63011 .75204 m .62826 .6979 L .59644 .69987 L p .707 .577 .707 r
F P
0 g
s
.62826 .6979 m .63011 .75204 L .65946 .7468 L p .707 .577 .707 r
F P
0 g
s
.65946 .7468 m .65761 .69267 L .62826 .6979 L p .707 .577 .707 r
F P
0 g
s
.56713 .75252 m .56528 .69839 L .53781 .69358 L p .707 .577 .707 r
F P
0 g
s
.56528 .69839 m .56713 .75252 L .59829 .75401 L p .707 .577 .707 r
F P
0 g
s
.65761 .69267 m .65946 .7468 L .68347 .73881 L p .707 .577 .707 r
F P
0 g
s
.68347 .73881 m .68162 .68467 L .65761 .69267 L p .707 .577 .707 r
F P
0 g
s
.53966 .74772 m .53781 .69358 L .51674 .68593 L p .707 .577 .707 r
F P
0 g
s
.53781 .69358 m .53966 .74772 L .56713 .75252 L p .707 .577 .707 r
F P
0 g
s
.60065 .8149 m .59861 .77959 L .56746 .77837 L p .707 .577 .707 r
F P
0 g
s
.59861 .77959 m .60065 .8149 L .63243 .81216 L p .707 .577 .707 r
F P
0 g
s
.63243 .81216 m .63039 .77686 L .59861 .77959 L p .707 .577 .707 r
F P
0 g
s
.63039 .77686 m .63243 .81216 L .66173 .80573 L p .707 .577 .707 r
F P
0 g
s
.66173 .80573 m .65969 .77043 L .63039 .77686 L p .707 .577 .707 r
F P
0 g
s
.68162 .68467 m .68347 .73881 L .6998 .72884 L p .707 .577 .707 r
F P
0 g
s
.6998 .72884 m .69795 .67471 L .68162 .68467 L p .707 .577 .707 r
F P
0 g
s
.5695 .81367 m .56746 .77837 L .53998 .7733 L p .707 .577 .707 r
F P
0 g
s
.56746 .77837 m .5695 .81367 L .60065 .8149 L p .707 .577 .707 r
F P
0 g
s
.65969 .77043 m .66173 .80573 L .68567 .79624 L p .707 .577 .707 r
F P
0 g
s
.68567 .79624 m .68363 .76093 L .65969 .77043 L p .707 .577 .707 r
F P
0 g
s
.51674 .68593 m .51859 .74007 L .53966 .74772 L p .707 .577 .707 r
F P
0 g
s
.51859 .74007 m .51674 .68593 L .50411 .67619 L p .707 .577 .707 r
F P
0 g
s
.60242 .8511 m .60137 .83348 L .57022 .83227 L p .707 .577 .707 r
F P
0 g
s
.60137 .83348 m .60242 .8511 L .6342 .84831 L p .707 .577 .707 r
F P
0 g
s
.6342 .84831 m .63315 .83069 L .60137 .83348 L p .707 .577 .707 r
F P
0 g
s
.53998 .7733 m .54202 .80861 L .5695 .81367 L p .707 .577 .707 r
F P
0 g
s
.54202 .80861 m .53998 .7733 L .51887 .76489 L p .707 .577 .707 r
F P
0 g
s
.63315 .83069 m .6342 .84831 L .66349 .8418 L p .707 .577 .707 r
F P
0 g
s
.66349 .8418 m .66244 .82418 L .63315 .83069 L p .707 .577 .707 r
F P
0 g
s
.57127 .84989 m .57022 .83227 L .54274 .82718 L p .707 .577 .707 r
F P
0 g
s
.57022 .83227 m .57127 .84989 L .60242 .8511 L p .707 .577 .707 r
F P
0 g
s
.69795 .67471 m .6998 .72884 L .70684 .71788 L p .707 .577 .707 r
F P
0 g
s
.70684 .71788 m .70499 .66375 L .69795 .67471 L p .707 .577 .707 r
F P
0 g
s
.68363 .76093 m .68567 .79624 L .70192 .78461 L p .707 .577 .707 r
F P
0 g
s
.70192 .78461 m .69988 .7493 L .68363 .76093 L p .707 .577 .707 r
F P
0 g
s
.66244 .82418 m .66349 .8418 L .68743 .83221 L p .707 .577 .707 r
F P
0 g
s
.68743 .83221 m .68638 .81458 L .66244 .82418 L p .707 .577 .707 r
F P
0 g
s
.54274 .82718 m .54379 .84481 L .57127 .84989 L p .707 .577 .707 r
F P
0 g
s
.50411 .67619 m .50596 .73033 L .51859 .74007 L p .707 .577 .707 r
F P
0 g
s
.51887 .76489 m .52091 .80019 L .54202 .80861 L p .707 .577 .707 r
F P
0 g
s
.54379 .84481 m .54274 .82718 L .52163 .81872 L p .707 .577 .707 r
F P
0 g
s
.52091 .80019 m .51887 .76489 L .50619 .75395 L p .707 .577 .707 r
F P
0 g
s
.50596 .73033 m .50411 .67619 L .50118 .66531 L p .707 .577 .707 r
F P
0 g
s
.52163 .81872 m .52268 .83634 L .54379 .84481 L p .707 .577 .707 r
F P
0 g
s
.68638 .81458 m .68743 .83221 L .70367 .82046 L p .707 .577 .707 r
F P
0 g
s
.70367 .82046 m .70262 .80284 L .68638 .81458 L p .707 .577 .707 r
F P
0 g
s
.69988 .7493 m .70192 .78461 L .70888 .77198 L p .707 .577 .707 r
F P
0 g
s
.70888 .77198 m .70684 .73667 L .69988 .7493 L p .707 .577 .707 r
F P
0 g
s
.50619 .75395 m .50823 .78926 L .52091 .80019 L p .707 .577 .707 r
F P
0 g
s
.70499 .66375 m .70684 .71788 L .7039 .707 L p .707 .577 .707 r
F P
0 g
s
.7039 .707 m .70205 .65286 L .70499 .66375 L p .707 .577 .707 r
F P
0 g
s
.50118 .66531 m .50303 .71944 L .50596 .73033 L p .707 .577 .707 r
F P
0 g
s
.52268 .83634 m .52163 .81872 L .50895 .8077 L p .707 .577 .707 r
F P
0 g
s
.50823 .78926 m .50619 .75395 L .50319 .74156 L p .707 .577 .707 r
F P
0 g
s
.50895 .8077 m .51 .82533 L .52268 .83634 L p .707 .577 .707 r
F P
0 g
s
.50303 .71944 m .50118 .66531 L .50822 .65435 L p .707 .577 .707 r
F P
0 g
s
.70262 .80284 m .70367 .82046 L .71063 .80772 L p .707 .577 .707 r
F P
0 g
s
.71063 .80772 m .70958 .7901 L .70262 .80284 L p .707 .577 .707 r
F P
0 g
s
.70684 .73667 m .70888 .77198 L .70588 .75959 L p .707 .577 .707 r
F P
0 g
s
.70588 .75959 m .70384 .72429 L .70684 .73667 L p .707 .577 .707 r
F P
0 g
s
.50319 .74156 m .50523 .77687 L .50823 .78926 L p .707 .577 .707 r
F P
0 g
s
.70205 .65286 m .7039 .707 L .69128 .69726 L p .707 .577 .707 r
F P
0 g
s
.69128 .69726 m .68943 .64312 L .70205 .65286 L p .707 .577 .707 r
F P
0 g
s
.51 .82533 m .50895 .8077 L .50594 .79521 L p .707 .577 .707 r
F P
0 g
s
.50822 .65435 m .51007 .70848 L .50303 .71944 L p .707 .577 .707 r
F P
0 g
s
.50523 .77687 m .50319 .74156 L .51015 .72894 L p .707 .577 .707 r
F P
0 g
s
.50594 .79521 m .50698 .81284 L .51 .82533 L p .707 .577 .707 r
F P
0 g
s
.25529 .71719 m .25344 .66306 L .22227 .66157 L p .707 .577 .707 r
F P
0 g
s
.25344 .66306 m .25529 .71719 L .2871 .71522 L p .707 .577 .707 r
F P
0 g
s
.2871 .71522 m .28525 .66109 L .25344 .66306 L p .707 .577 .707 r
F P
0 g
s
.51007 .70848 m .50822 .65435 L .52454 .64438 L p .707 .577 .707 r
F P
0 g
s
.28525 .66109 m .2871 .71522 L .31645 .70998 L p .707 .577 .707 r
F P
0 g
s
.31645 .70998 m .3146 .65585 L .28525 .66109 L p .707 .577 .707 r
F P
0 g
s
.70958 .7901 m .71063 .80772 L .70762 .79523 L p .707 .577 .707 r
F P
0 g
s
.70762 .79523 m .70657 .77761 L .70958 .7901 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22412 .7157 m .22227 .66157 L .1948 .65677 L p .707 .577 .707 r
F P
0 g
s
.22227 .66157 m .22412 .7157 L .25529 .71719 L p .707 .577 .707 r
F P
0 g
s
.70384 .72429 m .70588 .75959 L .6932 .74866 L p .707 .577 .707 r
F P
0 g
s
.6932 .74866 m .69116 .71335 L .70384 .72429 L p .707 .577 .707 r
F P
0 g
s
.51015 .72894 m .51219 .76424 L .50523 .77687 L p .707 .577 .707 r
F P
0 g
s
.68943 .64312 m .69128 .69726 L .6702 .68961 L p .707 .577 .707 r
F P
0 g
s
.6702 .68961 m .66835 .63547 L .68943 .64312 L p .707 .577 .707 r
F P
0 g
s
.3146 .65585 m .31645 .70998 L .34046 .70199 L p .707 .577 .707 r
F P
0 g
s
.34046 .70199 m .33861 .64786 L .3146 .65585 L p .707 .577 .707 r
F P
0 g
s
.50698 .81284 m .50594 .79521 L .51289 .78247 L p .707 .577 .707 r
F P
0 g
s
.52454 .64438 m .52639 .69852 L .51007 .70848 L p .707 .577 .707 r
F P
0 g
s
.19665 .7109 m .1948 .65677 L .17373 .64912 L p .707 .577 .707 r
F P
0 g
s
.1948 .65677 m .19665 .7109 L .22412 .7157 L p .707 .577 .707 r
F P
0 g
s
.52639 .69852 m .52454 .64438 L .54856 .63639 L p .707 .577 .707 r
F P
0 g
s
.51219 .76424 m .51015 .72894 L .5264 .71731 L p .707 .577 .707 r
F P
0 g
s
.51289 .78247 m .51394 .8001 L .50698 .81284 L p .707 .577 .707 r
F P
0 g
s
.25764 .77808 m .2556 .74278 L .22445 .74155 L p .707 .577 .707 r
F P
0 g
s
.2556 .74278 m .25764 .77808 L .28942 .77535 L p .707 .577 .707 r
F P
0 g
s
.28942 .77535 m .28738 .74004 L .2556 .74278 L p .707 .577 .707 r
F P
0 g
s
.28738 .74004 m .28942 .77535 L .31872 .76892 L p .707 .577 .707 r
F P
0 g
s
.31872 .76892 m .31668 .73361 L .28738 .74004 L p .707 .577 .707 r
F P
0 g
s
.70657 .77761 m .70762 .79523 L .69493 .78422 L p .707 .577 .707 r
F P
0 g
s
.69493 .78422 m .69389 .76659 L .70657 .77761 L p .707 .577 .707 r
F P
0 g
s
.33861 .64786 m .34046 .70199 L .35679 .69203 L p .707 .577 .707 r
F P
0 g
s
.35679 .69203 m .35494 .63789 L .33861 .64786 L p .707 .577 .707 r
F P
0 g
s
.22649 .77686 m .22445 .74155 L .19697 .73648 L p .707 .577 .707 r
F P
0 g
s
.22445 .74155 m .22649 .77686 L .25764 .77808 L p .707 .577 .707 r
F P
0 g
s
.66835 .63547 m .6702 .68961 L .64274 .6848 L p .707 .577 .707 r
F P
0 g
s
.64274 .6848 m .64089 .63067 L .66835 .63547 L p .707 .577 .707 r
F P
0 g
s
.69116 .71335 m .6932 .74866 L .67209 .74025 L p .707 .577 .707 r
F P
0 g
s
.67209 .74025 m .67005 .70494 L .69116 .71335 L p .707 .577 .707 r
F P
0 g
s
.5264 .71731 m .52844 .75261 L .51219 .76424 L p .707 .577 .707 r
F P
0 g
s
.31668 .73361 m .31872 .76892 L .34266 .75942 L p .707 .577 .707 r
F P
0 g
s
.34266 .75942 m .34062 .72412 L .31668 .73361 L p .707 .577 .707 r
F P
0 g
s
.17373 .64912 m .17558 .70325 L .19665 .7109 L p .707 .577 .707 r
F P
0 g
s
.55041 .69052 m .54856 .63639 L .57791 .63115 L p .707 .577 .707 r
F P
0 g
s
.54856 .63639 m .55041 .69052 L .52639 .69852 L p .707 .577 .707 r
F P
0 g
s
.17558 .70325 m .17373 .64912 L .16111 .63938 L p .707 .577 .707 r
F P
0 g
s
.51394 .8001 m .51289 .78247 L .52914 .77073 L p .707 .577 .707 r
F P
0 g
s
.25941 .81429 m .25837 .79666 L .22721 .79546 L p .707 .577 .707 r
F P
0 g
s
.25837 .79666 m .25941 .81429 L .29119 .8115 L p .707 .577 .707 r
F P
0 g
s
.29119 .8115 m .29014 .79387 L .25837 .79666 L p .707 .577 .707 r
F P
0 g
s
.19697 .73648 m .19901 .77179 L .22649 .77686 L p .707 .577 .707 r
F P
0 g
s
.19901 .77179 m .19697 .73648 L .17586 .72807 L p .707 .577 .707 r
F P
0 g
s
.49165 .79215 m .52755 .27489 L .48359 .27092 L p .707 .577 .707 r
F P
0 g
s
.52844 .75261 m .5264 .71731 L .55034 .70781 L p .707 .577 .707 r
F P
0 g
s
.52914 .77073 m .53018 .78835 L .51394 .8001 L p .707 .577 .707 r
F P
0 g
s
.55034 .70781 m .55238 .74312 L .52844 .75261 L p .707 .577 .707 r
F P
0 g
s
.53018 .78835 m .52914 .77073 L .55307 .76113 L p .707 .577 .707 r
F P
0 g
s
.55307 .76113 m .55412 .77876 L .53018 .78835 L p .707 .577 .707 r
F P
0 g
s
.52755 .27489 m .49165 .79215 L .53647 .7948 L p .707 .577 .707 r
F P
0 g
s
.53647 .7948 m .57236 .27754 L .52755 .27489 L p .707 .577 .707 r
F P
0 g
s
.29014 .79387 m .29119 .8115 L .32048 .80499 L p .707 .577 .707 r
F P
0 g
s
.32048 .80499 m .31943 .78736 L .29014 .79387 L p .707 .577 .707 r
F P
0 g
s
.64089 .63067 m .64274 .6848 L .61157 .68332 L p .707 .577 .707 r
F P
0 g
s
.61157 .68332 m .60972 .62918 L .64089 .63067 L p .707 .577 .707 r
F P
0 g
s
.57791 .63115 m .57976 .68529 L .55041 .69052 L p .707 .577 .707 r
F P
0 g
s
.55238 .74312 m .55034 .70781 L .57964 .70138 L p .707 .577 .707 r
F P
0 g
s
.57964 .70138 m .58168 .73669 L .55238 .74312 L p .707 .577 .707 r
F P
0 g
s
.55412 .77876 m .55307 .76113 L .58237 .75462 L p .707 .577 .707 r
F P
0 g
s
.58237 .75462 m .58341 .77225 L .55412 .77876 L p .707 .577 .707 r
F P
0 g
s
.57236 .27754 m .53647 .7948 L .57774 .79587 L p .707 .577 .707 r
F P
0 g
s
.57976 .68529 m .57791 .63115 L .60972 .62918 L p .707 .577 .707 r
F P
0 g
s
.60972 .62918 m .61157 .68332 L .57976 .68529 L p .707 .577 .707 r
F P
0 g
s
.58168 .73669 m .57964 .70138 L .61142 .69865 L p .707 .577 .707 r
F P
0 g
s
.61142 .69865 m .61346 .73395 L .58168 .73669 L p .707 .577 .707 r
F P
0 g
s
.57774 .79587 m .61364 .27861 L .57236 .27754 L p .707 .577 .707 r
F P
0 g
s
.22826 .81308 m .22721 .79546 L .19974 .79037 L p .707 .577 .707 r
F P
0 g
s
.22721 .79546 m .22826 .81308 L .25941 .81429 L p .707 .577 .707 r
F P
0 g
s
.35494 .63789 m .35679 .69203 L .36383 .68107 L p .707 .577 .707 r
F P
0 g
s
.36383 .68107 m .36198 .62693 L .35494 .63789 L p .707 .577 .707 r
F P
0 g
s
.69389 .76659 m .69493 .78422 L .67382 .77575 L p .707 .577 .707 r
F P
0 g
s
.67382 .77575 m .67277 .75813 L .69389 .76659 L p .707 .577 .707 r
F P
0 g
s
.34062 .72412 m .34266 .75942 L .35891 .74779 L p .707 .577 .707 r
F P
0 g
s
.35891 .74779 m .35687 .71249 L .34062 .72412 L p .707 .577 .707 r
F P
0 g
s
.44769 .78817 m .48359 .27092 L .44478 .26601 L p .707 .577 .707 r
F P
0 g
s
.48359 .27092 m .44769 .78817 L .49165 .79215 L p .707 .577 .707 r
F P
0 g
s
.67005 .70494 m .67209 .74025 L .64461 .73518 L p .707 .577 .707 r
F P
0 g
s
.64461 .73518 m .64257 .69987 L .67005 .70494 L p .707 .577 .707 r
F P
0 g
s
.31943 .78736 m .32048 .80499 L .34442 .79539 L p .707 .577 .707 r
F P
0 g
s
.34442 .79539 m .34337 .77777 L .31943 .78736 L p .707 .577 .707 r
F P
0 g
s
.19974 .79037 m .20078 .80799 L .22826 .81308 L p .707 .577 .707 r
F P
0 g
s
.16111 .63938 m .16295 .69351 L .17558 .70325 L p .707 .577 .707 r
F P
0 g
s
.17586 .72807 m .1779 .76338 L .19901 .77179 L p .707 .577 .707 r
F P
0 g
s
.20078 .80799 m .19974 .79037 L .17862 .7819 L p .707 .577 .707 r
F P
0 g
s
.1779 .76338 m .17586 .72807 L .16318 .71714 L p .707 .577 .707 r
F P
0 g
s
.16295 .69351 m .16111 .63938 L .15817 .62849 L p .707 .577 .707 r
F P
0 g
s
.61346 .73395 m .61142 .69865 L .64257 .69987 L p .707 .577 .707 r
F P
0 g
s
.58341 .77225 m .58237 .75462 L .61414 .75183 L p .707 .577 .707 r
F P
0 g
s
.61414 .75183 m .61519 .76946 L .58341 .77225 L p .707 .577 .707 r
F P
0 g
s
.61364 .27861 m .57774 .79587 L .61144 .79525 L p .707 .577 .707 r
F P
0 g
s
.64257 .69987 m .64461 .73518 L .61346 .73395 L p .707 .577 .707 r
F P
0 g
s
.61519 .76946 m .61414 .75183 L .6453 .75304 L p .707 .577 .707 r
F P
0 g
s
.61144 .79525 m .64734 .278 L .61364 .27861 L p .707 .577 .707 r
F P
0 g
s
.17862 .7819 m .17967 .79953 L .20078 .80799 L p .707 .577 .707 r
F P
0 g
s
.34337 .77777 m .34442 .79539 L .36066 .78365 L p .707 .577 .707 r
F P
0 g
s
.36066 .78365 m .35962 .76602 L .34337 .77777 L p .707 .577 .707 r
F P
0 g
s
.67277 .75813 m .67382 .77575 L .64634 .77067 L p .707 .577 .707 r
F P
0 g
s
.64634 .77067 m .6453 .75304 L .67277 .75813 L p .707 .577 .707 r
F P
0 g
s
.40888 .78326 m .44478 .26601 L .41492 .26064 L p .707 .577 .707 r
F P
0 g
s
.44478 .26601 m .40888 .78326 L .44769 .78817 L p .707 .577 .707 r
F P
0 g
s
.35687 .71249 m .35891 .74779 L .36587 .73517 L p .707 .577 .707 r
F P
0 g
s
.36587 .73517 m .36383 .69986 L .35687 .71249 L p .707 .577 .707 r
F P
0 g
s
.16318 .71714 m .16522 .75244 L .1779 .76338 L p .707 .577 .707 r
F P
0 g
s
.36198 .62693 m .36383 .68107 L .36089 .67018 L p .707 .577 .707 r
F P
0 g
s
.36089 .67018 m .35904 .61605 L .36198 .62693 L p .707 .577 .707 r
F P
0 g
s
.15817 .62849 m .16002 .68263 L .16295 .69351 L p .707 .577 .707 r
F P
0 g
s
.17967 .79953 m .17862 .7819 L .16594 .77089 L p .707 .577 .707 r
F P
0 g
s
.6453 .75304 m .64634 .77067 L .61519 .76946 L p .707 .577 .707 r
F P
0 g
s
.16522 .75244 m .16318 .71714 L .16018 .70475 L p .707 .577 .707 r
F P
0 g
s
.16594 .77089 m .16699 .78851 L .17967 .79953 L p .707 .577 .707 r
F P
0 g
s
.16002 .68263 m .15817 .62849 L .16521 .61753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64734 .278 m .61144 .79525 L .63426 .79301 L p .707 .577 .707 r
F P
0 g
s
.63426 .79301 m .67016 .27576 L .64734 .278 L p .707 .577 .707 r
F P
0 g
s
.35962 .76602 m .36066 .78365 L .36762 .77091 L p .707 .577 .707 r
F P
0 g
s
.36762 .77091 m .36657 .75328 L .35962 .76602 L p .707 .577 .707 r
F P
0 g
s
.36383 .69986 m .36587 .73517 L .36287 .72278 L p .707 .577 .707 r
F P
0 g
s
.36287 .72278 m .36083 .68747 L .36383 .69986 L p .707 .577 .707 r
F P
0 g
s
.16018 .70475 m .16222 .74006 L .16522 .75244 L p .707 .577 .707 r
F P
0 g
s
.37902 .7779 m .41492 .26064 L .39694 .25536 L p .707 .577 .707 r
F P
0 g
s
.41492 .26064 m .37902 .7779 L .40888 .78326 L p .707 .577 .707 r
F P
0 g
s
.35904 .61605 m .36089 .67018 L .34827 .66044 L p .707 .577 .707 r
F P
0 g
s
.34827 .66044 m .34642 .60631 L .35904 .61605 L p .707 .577 .707 r
F P
0 g
s
.16699 .78851 m .16594 .77089 L .16293 .7584 L p .707 .577 .707 r
F P
0 g
s
.16521 .61753 m .16706 .67166 L .16002 .68263 L p .707 .577 .707 r
F P
0 g
s
.16222 .74006 m .16018 .70475 L .16714 .69212 L p .707 .577 .707 r
F P
0 g
s
.16293 .7584 m .16397 .77602 L .16699 .78851 L p .707 .577 .707 r
F P
0 g
s
.16706 .67166 m .16521 .61753 L .18153 .60757 L p .707 .577 .707 r
F P
0 g
s
.36657 .75328 m .36762 .77091 L .36461 .75842 L p .707 .577 .707 r
F P
0 g
s
.36461 .75842 m .36356 .74079 L .36657 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.67016 .27576 m .63426 .79301 L .64397 .78936 L p .707 .577 .707 r
F P
0 g
s
.67687 .6597 m .67502 .60557 L .66103 .60049 L p .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .66117 .54158 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64397 .78936 m .63963 .78466 L p .65197 .62748 L .707 .577 .707 r
F P
0 g
s
.65197 .62748 m .65277 .62262 L .64397 .78936 L .707 .577 .707 r
F
.65362 .60643 m .65409 .60236 L .64397 .78936 L F
.66117 .54158 m .6596 .5642 L p .65409 .60236 L F P
0 g
s
.6596 .5642 m .64397 .78936 L p .65409 .60236 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .62164 .77937 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .64132 .58818 L p .64995 .62627 L .707 .577 .707 r
F P
0 g
s
.65056 .6266 m .65394 .59792 L .64995 .62627 L .707 .577 .707 r
F
.63842 .61998 m .64248 .6222 L .63963 .78466 L F
.65059 .62662 m .64699 .67851 L p .64248 .6222 L F P
0 g
s
.64699 .67851 m .63963 .78466 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64132 .58818 L .6391 .57993 L p .707 .577 .707 r
F P
0 g
s
.65409 .60236 m .65394 .59792 L p .65056 .6266 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .65056 .6266 L .65037 .62814 L .707 .577 .707 r
F
.65409 .60236 m .65056 .6266 L .65059 .62662 L F
.67987 .27211 m .67016 .27576 L p .66139 .44768 L F P
0 g
s
.66117 .54158 m .67987 .27211 L p .66139 .44768 L .707 .577 .707 r
F P
0 g
s
.64132 .58818 m .64248 .6222 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .64132 .58818 L .64781 .6459 L .707 .577 .707 r
F
.65754 .26212 m .67552 .26741 L p .63842 .61998 L F P
0 g
s
.62164 .77937 m .63291 .61698 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.63291 .61698 m .65754 .26212 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64781 .6459 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.64248 .6222 m .64317 .64231 L p .64532 .62375 L .707 .577 .707 r
F P
0 g
s
.63963 .78466 m .65059 .62662 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.64781 .6459 m .65579 .65205 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65458 .59815 m .65394 .59792 L p .65445 .59929 L .707 .577 .707 r
F P
0 g
s
.65394 .59792 m .65579 .65205 L .67687 .6597 L p .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .67987 .27211 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.65059 .62662 m .67552 .26741 L p .65376 .60471 L .707 .577 .707 r
F P
0 g
s
.67552 .26741 m .65059 .62662 L p .63842 .61998 L .707 .577 .707 r
F P
0 g
s
.64317 .64231 m .64248 .6222 L p .63838 .57729 L .707 .577 .707 r
F P
0 g
s
.6391 .57993 m .63838 .57729 L p .64248 .6222 L .707 .577 .707 r
F P
0 g
s
.65037 .62814 m .65056 .6266 L .64995 .62627 L .707 .577 .707 r
F
.65197 .62748 m .65362 .60643 L .65277 .62262 L F
.67987 .27211 m .66117 .54158 L p .65362 .60643 L F P
0 g
s
.65579 .65205 m .65409 .60236 L p .65037 .62814 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .65607 .68305 L .64447 .67304 L p .707 .577 .707 r
F P
0 g
s
.64447 .67304 m .64339 .67211 L p .6442 .67465 L .707 .577 .707 r
F P
0 g
s
.65811 .71836 m .64447 .67304 L .6442 .67465 L .707 .577 .707 r
F
.66103 .60049 m .65458 .59815 L p .66099 .61691 L F P
0 g
s
.66099 .61691 m .65458 .59815 L .65445 .59929 L .707 .577 .707 r
F
.67687 .6597 m .66103 .60049 L .66099 .61691 L F
.36083 .68747 m .36287 .72278 L .35019 .71184 L p F P
0 g
s
.35019 .71184 m .34815 .67654 L .36083 .68747 L p .707 .577 .707 r
F P
0 g
s
.16714 .69212 m .16918 .72743 L .16222 .74006 L p .707 .577 .707 r
F P
0 g
s
.34642 .60631 m .34827 .66044 L .32719 .65279 L p .707 .577 .707 r
F P
0 g
s
.32719 .65279 m .32534 .59866 L .34642 .60631 L p .707 .577 .707 r
F P
0 g
s
.16397 .77602 m .16293 .7584 L .16988 .74566 L p .707 .577 .707 r
F P
0 g
s
.18153 .60757 m .18338 .6617 L .16706 .67166 L p .707 .577 .707 r
F P
0 g
s
.36356 .74079 m .36461 .75842 L .35193 .7474 L p .707 .577 .707 r
F P
0 g
s
.35193 .7474 m .35088 .72978 L .36356 .74079 L p .707 .577 .707 r
F P
0 g
s
.36104 .77261 m .39694 .25536 L .39259 .25066 L p .707 .577 .707 r
F P
0 g
s
.39694 .25536 m .36104 .77261 L .37902 .7779 L p .707 .577 .707 r
F P
0 g
s
.18338 .6617 m .18153 .60757 L .20555 .59957 L p .707 .577 .707 r
F P
0 g
s
.16918 .72743 m .16714 .69212 L .18339 .68049 L p .707 .577 .707 r
F P
0 g
s
.16988 .74566 m .17093 .76328 L .16397 .77602 L p .707 .577 .707 r
F P
0 g
s
.32534 .59866 m .32719 .65279 L .29973 .64799 L p .707 .577 .707 r
F P
0 g
s
.29973 .64799 m .29788 .59386 L .32534 .59866 L p .707 .577 .707 r
F P
0 g
s
.34815 .67654 m .35019 .71184 L .32908 .70343 L p .707 .577 .707 r
F P
0 g
s
.32908 .70343 m .32704 .66812 L .34815 .67654 L p .707 .577 .707 r
F P
0 g
s
.18339 .68049 m .18543 .7158 L .16918 .72743 L p .707 .577 .707 r
F P
0 g
s
.2074 .65371 m .20555 .59957 L .2349 .59434 L p .707 .577 .707 r
F P
0 g
s
.20555 .59957 m .2074 .65371 L .18338 .6617 L p .707 .577 .707 r
F P
0 g
s
.17093 .76328 m .16988 .74566 L .18613 .73392 L p .707 .577 .707 r
F P
0 g
s
.18543 .7158 m .18339 .68049 L .20733 .671 L p .707 .577 .707 r
F P
0 g
s
.29788 .59386 m .29973 .64799 L .26856 .6465 L p .707 .577 .707 r
F P
0 g
s
.26856 .6465 m .26671 .59237 L .29788 .59386 L p .707 .577 .707 r
F P
0 g
s
.18613 .73392 m .18717 .75154 L .17093 .76328 L p .707 .577 .707 r
F P
0 g
s
.23675 .64847 m .2349 .59434 L .26671 .59237 L p .707 .577 .707 r
F P
0 g
s
.2349 .59434 m .23675 .64847 L .2074 .65371 L p .707 .577 .707 r
F P
0 g
s
.26671 .59237 m .26856 .6465 L .23675 .64847 L p .707 .577 .707 r
F P
0 g
s
.35088 .72978 m .35193 .7474 L .33081 .73894 L p .707 .577 .707 r
F P
0 g
s
.33081 .73894 m .32976 .72131 L .35088 .72978 L p .707 .577 .707 r
F P
0 g
s
.32704 .66812 m .32908 .70343 L .3016 .69836 L p .707 .577 .707 r
F P
0 g
s
.3016 .69836 m .29956 .66306 L .32704 .66812 L p .707 .577 .707 r
F P
0 g
s
.20733 .671 m .20937 .7063 L .18543 .7158 L p .707 .577 .707 r
F P
0 g
s
.7355 .66599 m .73365 .61186 L .70248 .61037 L p .707 .577 .707 r
F P
0 g
s
.73365 .61186 m .7355 .66599 L .76731 .66402 L p .707 .577 .707 r
F P
0 g
s
.76731 .66402 m .76546 .60989 L .73365 .61186 L p .707 .577 .707 r
F P
0 g
s
.39259 .25066 m .35669 .76791 L .36104 .77261 L p .707 .577 .707 r
F P
0 g
s
.35669 .76791 m .39259 .25066 L .4023 .24701 L p .707 .577 .707 r
F P
0 g
s
.76546 .60989 m .76731 .66402 L .79666 .65879 L p .707 .577 .707 r
F P
0 g
s
.79666 .65879 m .79481 .60465 L .76546 .60989 L p .707 .577 .707 r
F P
0 g
s
.20937 .7063 m .20733 .671 L .23663 .66457 L p .707 .577 .707 r
F P
0 g
s
.18717 .75154 m .18613 .73392 L .21006 .72432 L p .707 .577 .707 r
F P
0 g
s
.70433 .6645 m .70248 .61037 L .67502 .60557 L p .707 .577 .707 r
F P
0 g
s
.70248 .61037 m .70433 .6645 L .7355 .66599 L p .707 .577 .707 r
F P
0 g
s
.29956 .66306 m .3016 .69836 L .27045 .69714 L p .707 .577 .707 r
F P
0 g
s
.27045 .69714 m .26841 .66183 L .29956 .66306 L p .707 .577 .707 r
F P
0 g
s
.21006 .72432 m .21111 .74194 L .18717 .75154 L p .707 .577 .707 r
F P
0 g
s
.23867 .69987 m .23663 .66457 L .26841 .66183 L p .707 .577 .707 r
F P
0 g
s
.23663 .66457 m .23867 .69987 L .20937 .7063 L p .707 .577 .707 r
F P
0 g
s
.79481 .60465 m .79666 .65879 L .82068 .65079 L p .707 .577 .707 r
F P
0 g
s
.82068 .65079 m .81883 .59666 L .79481 .60465 L p .707 .577 .707 r
F P
0 g
s
.32976 .72131 m .33081 .73894 L .30333 .73385 L p .707 .577 .707 r
F P
0 g
s
.30333 .73385 m .30229 .71623 L .32976 .72131 L p .707 .577 .707 r
F P
0 g
s
.26841 .66183 m .27045 .69714 L .23867 .69987 L p .707 .577 .707 r
F P
0 g
s
.67502 .60557 m .67687 .6597 L .70433 .6645 L p .707 .577 .707 r
F P
0 g
s
.21111 .74194 m .21006 .72432 L .23936 .71781 L p .707 .577 .707 r
F P
0 g
s
.73785 .73306 m .73581 .69776 L .70466 .69653 L p .707 .577 .707 r
F P
0 g
s
.73581 .69776 m .73785 .73306 L .76963 .73033 L p .707 .577 .707 r
F P
0 g
s
.76963 .73033 m .76759 .69502 L .73581 .69776 L p .707 .577 .707 r
F P
0 g
s
.30229 .71623 m .30333 .73385 L .27218 .73264 L p .707 .577 .707 r
F P
0 g
s
.27218 .73264 m .27113 .71502 L .30229 .71623 L p .707 .577 .707 r
F P
0 g
s
.76759 .69502 m .76963 .73033 L .79893 .7239 L p .707 .577 .707 r
F P
0 g
s
.79893 .7239 m .79689 .68859 L .76759 .69502 L p .707 .577 .707 r
F P
0 g
s
.23936 .71781 m .2404 .73543 L .21111 .74194 L p .707 .577 .707 r
F P
0 g
s
.81883 .59666 m .82068 .65079 L .837 .64083 L p .707 .577 .707 r
F P
0 g
s
.837 .64083 m .83515 .5867 L .81883 .59666 L p .707 .577 .707 r
F P
0 g
s
.2404 .73543 m .23936 .71781 L .27113 .71502 L p .707 .577 .707 r
F P
0 g
s
.7067 .73184 m .70466 .69653 L .67718 .69146 L p .707 .577 .707 r
F P
0 g
s
.70466 .69653 m .7067 .73184 L .73785 .73306 L p .707 .577 .707 r
F P
0 g
s
.27113 .71502 m .27218 .73264 L .2404 .73543 L p .707 .577 .707 r
F P
0 g
s
.79689 .68859 m .79893 .7239 L .82288 .7144 L p .707 .577 .707 r
F P
0 g
s
.82288 .7144 m .82084 .67909 L .79689 .68859 L p .707 .577 .707 r
F P
0 g
s
.3664 .76426 m .4023 .24701 L .42512 .24476 L p .707 .577 .707 r
F P
0 g
s
.4023 .24701 m .3664 .76426 L .35669 .76791 L p .707 .577 .707 r
F P
0 g
s
.67718 .69146 m .67922 .72677 L .7067 .73184 L p .707 .577 .707 r
F P
0 g
s
.67922 .72677 m .67718 .69146 L .65607 .68305 L p .707 .577 .707 r
F P
0 g
s
.73963 .77906 m .73858 .76143 L .70743 .76022 L p .707 .577 .707 r
F P
0 g
s
.73858 .76143 m .73963 .77906 L .7714 .77627 L p .707 .577 .707 r
F P
0 g
s
.7714 .77627 m .77036 .75864 L .73858 .76143 L p .707 .577 .707 r
F P
0 g
s
.77036 .75864 m .7714 .77627 L .8007 .76976 L p .707 .577 .707 r
F P
0 g
s
.8007 .76976 m .79965 .75213 L .77036 .75864 L p .707 .577 .707 r
F P
0 g
s
.83515 .5867 m .837 .64083 L .84404 .62987 L p .707 .577 .707 r
F P
0 g
s
.84404 .62987 m .84219 .57573 L .83515 .5867 L p .707 .577 .707 r
F P
0 g
s
.70847 .77785 m .70743 .76022 L .67995 .75514 L p .707 .577 .707 r
F P
0 g
s
.70743 .76022 m .70847 .77785 L .73963 .77906 L p .707 .577 .707 r
F P
0 g
s
.82084 .67909 m .82288 .7144 L .83912 .70277 L p .707 .577 .707 r
F P
0 g
s
.83912 .70277 m .83709 .66746 L .82084 .67909 L p .707 .577 .707 r
F P
0 g
s
.65607 .68305 m .65811 .71836 L .67922 .72677 L p .707 .577 .707 r
F P
0 g
s
.79965 .75213 m .8007 .76976 L .82463 .76016 L p .707 .577 .707 r
F P
0 g
s
.82463 .76016 m .82359 .74253 L .79965 .75213 L p .707 .577 .707 r
F P
0 g
s
.67995 .75514 m .681 .77276 L .70847 .77785 L p .707 .577 .707 r
F P
0 g
s
.65754 .26212 m .62164 .77937 L .59178 .77401 L p .707 .577 .707 r
F P
0 g
s
.59178 .77401 m .62768 .25676 L .65754 .26212 L p .707 .577 .707 r
F P
0 g
s
.681 .77276 m .67995 .75514 L .65883 .74667 L p .707 .577 .707 r
F P
0 g
s
.65883 .74667 m .65988 .7643 L .681 .77276 L p .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .3664 .76426 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .38923 .76202 L p .40122 .45621 L .707 .577 .707 r
F P
0 g
s
.42512 .24476 m .45882 .24415 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.38923 .76202 m .40642 .51423 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.40642 .51423 m .42512 .24476 L p .41698 .55551 L .707 .577 .707 r
F P
0 g
s
.42261 .57752 m .42245 .57307 L .42149 .57313 L p .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .38923 .76202 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.42245 .57307 m .42261 .57752 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.42292 .7614 m .43389 .60337 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .42292 .7614 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.47547 .60008 m .4642 .76248 L p .44794 .61369 L .707 .577 .707 r
F P
0 g
s
.4467 .60236 m .45297 .60186 L .44794 .61369 L .707 .577 .707 r
F
.45297 .60186 m .47547 .60008 L .44794 .61369 L F
.4518 .56784 m .45297 .60186 L p .46069 .58368 L F P
0 g
s
.4518 .56784 m .42245 .57307 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45365 .62197 m .45297 .60186 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.45297 .60186 m .4518 .56784 L p .44141 .60277 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .47547 .60008 L p .45297 .60186 L .707 .577 .707 r
F P
0 g
s
.5001 .24522 m .54491 .24787 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.4642 .76248 m .47972 .53888 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47972 .53888 m .5001 .24522 L p .52449 .37808 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47582 .55984 L .47368 .56056 L p .707 .577 .707 r
F P
0 g
s
.47368 .56056 m .46999 .56178 L p .47115 .56966 L .707 .577 .707 r
F P
0 g
s
.47767 .61398 m .47368 .56056 L .47115 .56966 L .707 .577 .707 r
F
.46999 .56178 m .4518 .56784 L p .46069 .58368 L F P
0 g
s
.47767 .61398 m .46999 .56178 L .46069 .58368 L .707 .577 .707 r
F
.5001 .24522 m .47972 .53888 L p .4467 .60236 L F P
0 g
s
.4467 .60236 m .47972 .53888 L .45297 .60186 L .707 .577 .707 r
F
.45365 .62197 m .47767 .61398 L p .46069 .58368 L F P
0 g
s
.45297 .60186 m .45365 .62197 L p .46069 .58368 L .707 .577 .707 r
F P
0 g
s
.44286 .6239 m .45365 .62197 L p .44031 .60286 L .707 .577 .707 r
F P
0 g
s
.44031 .60286 m .42261 .57752 L .43389 .60337 L .707 .577 .707 r
F
.44031 .60286 m .43389 .60337 L .44286 .6239 L F
.45365 .62197 m .44141 .60277 L .44031 .60286 L F
.44141 .60277 m .42245 .57307 L .44031 .60286 L F
.45882 .24415 m .5001 .24522 L p .4467 .60236 L F P
0 g
s
.43389 .60337 m .45882 .24415 L p .4467 .60236 L .707 .577 .707 r
F P
0 g
s
.45882 .24415 m .43389 .60337 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.43279 .61928 m .42292 .7614 L p .41704 .59132 L .707 .577 .707 r
F P
0 g
s
.45592 .68708 m .4542 .65728 L p .42459 .6582 L .707 .577 .707 r
F P
0 g
s
.4542 .65728 m .45388 .65177 L .4514 .65232 L p .707 .577 .707 r
F P
0 g
s
.4514 .65232 m .42459 .6582 L p .4542 .65728 L .707 .577 .707 r
F P
0 g
s
.43389 .60337 m .43279 .61928 L p .41604 .56248 L .707 .577 .707 r
F P
0 g
s
.41604 .56248 m .43279 .61928 L .41704 .59132 L .707 .577 .707 r
F
.42261 .57752 m .4243 .62721 L .44286 .6239 L p F P
0 g
s
.4243 .62721 m .42261 .57752 L p .39064 .57504 L .707 .577 .707 r
F P
0 g
s
.42149 .57313 m .39064 .57504 L p .42261 .57752 L .707 .577 .707 r
F P
0 g
s
.39064 .57504 m .39249 .62918 L .41659 .62769 L p .707 .577 .707 r
F P
0 g
s
.41659 .62769 m .4243 .62721 L p .4153 .61325 L .707 .577 .707 r
F P
0 g
s
.4153 .61325 m .39064 .57504 L .41659 .62769 L .707 .577 .707 r
F
.42512 .24476 m .40642 .51423 L p .40122 .45621 L F P
0 g
s
.82359 .74253 m .82463 .76016 L .84088 .74842 L p .707 .577 .707 r
F P
0 g
s
.84088 .74842 m .83983 .73079 L .82359 .74253 L p .707 .577 .707 r
F P
0 g
s
.83709 .66746 m .83912 .70277 L .84609 .69014 L p .707 .577 .707 r
F P
0 g
s
.84609 .69014 m .84405 .65484 L .83709 .66746 L p .707 .577 .707 r
F P
0 g
s
.84219 .57573 m .84404 .62987 L .84111 .61898 L p .707 .577 .707 r
F P
0 g
s
.84111 .61898 m .83926 .56485 L .84219 .57573 L p .707 .577 .707 r
F P
0 g
s
.64339 .67211 m .64543 .70742 L .65811 .71836 L p .707 .577 .707 r
F P
0 g
s
.63838 .57729 m .64023 .63143 L .64317 .64231 L p .707 .577 .707 r
F P
0 g
s
.65988 .7643 m .65883 .74667 L .64615 .73566 L p .707 .577 .707 r
F P
0 g
s
.64543 .70742 m .64339 .67211 L .64039 .65973 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64023 .63143 m .63838 .57729 L .64542 .56633 L p .707 .577 .707 r
F P
0 g
s
.62768 .25676 m .59178 .77401 L .55297 .7691 L p .707 .577 .707 r
F P
0 g
s
.55297 .7691 m .58887 .25185 L .62768 .25676 L p .707 .577 .707 r
F P
0 g
s
.64615 .73566 m .6472 .75328 L .65988 .7643 L p .707 .577 .707 r
F P
0 g
s
.83983 .73079 m .84088 .74842 L .84783 .73568 L p .707 .577 .707 r
F P
0 g
s
.84783 .73568 m .84679 .71805 L .83983 .73079 L p .707 .577 .707 r
F P
0 g
s
.84405 .65484 m .84609 .69014 L .84308 .67776 L p .707 .577 .707 r
F P
0 g
s
.84308 .67776 m .84104 .64245 L .84405 .65484 L p .707 .577 .707 r
F P
0 g
s
.64039 .65973 m .64243 .69503 L .64543 .70742 L p .707 .577 .707 r
F P
0 g
s
.83926 .56485 m .84111 .61898 L .82848 .60924 L p .707 .577 .707 r
F P
0 g
s
.82848 .60924 m .82663 .55511 L .83926 .56485 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64542 .56633 m .64727 .62046 L .64023 .63143 L p .707 .577 .707 r
F P
0 g
s
.6472 .75328 m .64615 .73566 L .64314 .72317 L p .707 .577 .707 r
F P
0 g
s
.58887 .25185 m .55297 .7691 L .50901 .76513 L p .707 .577 .707 r
F P
0 g
s
.50901 .76513 m .54491 .24787 L .58887 .25185 L p .707 .577 .707 r
F P
0 g
s
.64243 .69503 m .64039 .65973 L .64735 .6471 L p .707 .577 .707 r
F P
0 g
s
.39249 .62918 m .39064 .57504 L .35947 .57356 L p .707 .577 .707 r
F P
0 g
s
.64727 .62046 m .64542 .56633 L .66175 .55637 L p .707 .577 .707 r
F P
0 g
s
.64314 .72317 m .64419 .74079 L .6472 .75328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.54491 .24787 m .50901 .76513 L .4642 .76248 L p .707 .577 .707 r
F P
0 g
s
.36132 .62769 m .35947 .57356 L .33201 .56875 L p .707 .577 .707 r
F P
0 g
s
.35947 .57356 m .36132 .62769 L .39249 .62918 L p .707 .577 .707 r
F P
0 g
s
.84679 .71805 m .84783 .73568 L .84482 .72319 L p .707 .577 .707 r
F P
0 g
s
.84482 .72319 m .84377 .70556 L .84679 .71805 L p .707 .577 .707 r
F P
0 g
s
.84104 .64245 m .84308 .67776 L .8304 .66682 L p .707 .577 .707 r
F P
0 g
s
.8304 .66682 m .82837 .63151 L .84104 .64245 L p .707 .577 .707 r
F P
0 g
s
.82663 .55511 m .82848 .60924 L .80741 .60159 L p .707 .577 .707 r
F P
0 g
s
.80741 .60159 m .80556 .54746 L .82663 .55511 L p .707 .577 .707 r
F P
0 g
s
.64735 .6471 m .64939 .68241 L .64243 .69503 L p .707 .577 .707 r
F P
0 g
s
.66175 .55637 m .6636 .6105 L .64727 .62046 L p .707 .577 .707 r
F P
0 g
s
.33386 .62289 m .33201 .56875 L .31093 .5611 L p .707 .577 .707 r
F P
0 g
s
.33201 .56875 m .33386 .62289 L .36132 .62769 L p .707 .577 .707 r
F P
0 g
s
.64419 .74079 m .64314 .72317 L .6501 .71043 L p .707 .577 .707 r
F P
0 g
s
.6636 .6105 m .66175 .55637 L .68576 .54837 L p .707 .577 .707 r
F P
0 g
s
.64939 .68241 m .64735 .6471 L .6636 .63547 L p .707 .577 .707 r
F P
0 g
s
.39484 .69625 m .3928 .66094 L .36165 .65971 L p .707 .577 .707 r
F P
0 g
s
.3928 .66094 m .39484 .69625 L .42662 .69351 L p .707 .577 .707 r
F P
0 g
s
.42662 .69351 m .42459 .6582 L .3928 .66094 L p .707 .577 .707 r
F P
0 g
s
.6501 .71043 m .65114 .72805 L .64419 .74079 L p .707 .577 .707 r
F P
0 g
s
.42459 .6582 m .42662 .69351 L .45592 .68708 L p .707 .577 .707 r
F P
0 g
s
.47582 .55984 m .47767 .61398 L .49399 .60401 L p .707 .577 .707 r
F P
0 g
s
.49399 .60401 m .49214 .54988 L .47582 .55984 L p .707 .577 .707 r
F P
0 g
s
.80556 .54746 m .80741 .60159 L .77994 .59679 L p .707 .577 .707 r
F P
0 g
s
.77994 .59679 m .77809 .54266 L .80556 .54746 L p .707 .577 .707 r
F P
0 g
s
.36369 .69502 m .36165 .65971 L .33417 .65465 L p .707 .577 .707 r
F P
0 g
s
.36165 .65971 m .36369 .69502 L .39484 .69625 L p .707 .577 .707 r
F P
0 g
s
.84377 .70556 m .84482 .72319 L .83214 .71217 L p .707 .577 .707 r
F P
0 g
s
.83214 .71217 m .83109 .69455 L .84377 .70556 L p .707 .577 .707 r
F P
0 g
s
.82837 .63151 m .8304 .66682 L .80929 .65841 L p .707 .577 .707 r
F P
0 g
s
.80929 .65841 m .80725 .6231 L .82837 .63151 L p .707 .577 .707 r
F P
0 g
s
.31093 .5611 m .31278 .61524 L .33386 .62289 L p .707 .577 .707 r
F P
0 g
s
.6636 .63547 m .66564 .67078 L .64939 .68241 L p .707 .577 .707 r
F P
0 g
s
.45388 .65177 m .45592 .68708 L .47987 .67759 L p .707 .577 .707 r
F P
0 g
s
.47987 .67759 m .47783 .64228 L .45388 .65177 L p .707 .577 .707 r
F P
0 g
s
.68761 .60251 m .68576 .54837 L .71511 .54314 L p .707 .577 .707 r
F P
0 g
s
.68576 .54837 m .68761 .60251 L .6636 .6105 L p .707 .577 .707 r
F P
0 g
s
.31278 .61524 m .31093 .5611 L .29831 .55136 L p .707 .577 .707 r
F P
0 g
s
.33417 .65465 m .33621 .68995 L .36369 .69502 L p .707 .577 .707 r
F P
0 g
s
.33621 .68995 m .33417 .65465 L .31306 .64623 L p .707 .577 .707 r
F P
0 g
s
.77809 .54266 m .77994 .59679 L .74878 .5953 L p .707 .577 .707 r
F P
0 g
s
.74878 .5953 m .74693 .54117 L .77809 .54266 L p .707 .577 .707 r
F P
0 g
s
.65114 .72805 m .6501 .71043 L .66634 .69868 L p .707 .577 .707 r
F P
0 g
s
.66564 .67078 m .6636 .63547 L .68755 .62598 L p .707 .577 .707 r
F P
0 g
s
.39662 .74224 m .39557 .72462 L .36442 .72341 L p .707 .577 .707 r
F P
0 g
s
.39557 .72462 m .39662 .74224 L .42839 .73945 L p .707 .577 .707 r
F P
0 g
s
.42839 .73945 m .42735 .72183 L .39557 .72462 L p .707 .577 .707 r
F P
0 g
s
.42735 .72183 m .42839 .73945 L .45769 .73294 L p .707 .577 .707 r
F P
0 g
s
.45769 .73294 m .45664 .71532 L .42735 .72183 L p .707 .577 .707 r
F P
0 g
s
.71696 .59727 m .71511 .54314 L .74693 .54117 L p .707 .577 .707 r
F P
0 g
s
.71511 .54314 m .71696 .59727 L .68761 .60251 L p .707 .577 .707 r
F P
0 g
s
.49214 .54988 m .49399 .60401 L .50103 .59305 L p .707 .577 .707 r
F P
0 g
s
.50103 .59305 m .49918 .53892 L .49214 .54988 L p .707 .577 .707 r
F P
0 g
s
.74693 .54117 m .74878 .5953 L .71696 .59727 L p .707 .577 .707 r
F P
0 g
s
.66634 .69868 m .66739 .71631 L .65114 .72805 L p .707 .577 .707 r
F P
0 g
s
.36546 .74103 m .36442 .72341 L .33694 .71832 L p .707 .577 .707 r
F P
0 g
s
.36442 .72341 m .36546 .74103 L .39662 .74224 L p .707 .577 .707 r
F P
0 g
s
.47783 .64228 m .47987 .67759 L .49611 .66596 L p .707 .577 .707 r
F P
0 g
s
.49611 .66596 m .49408 .63065 L .47783 .64228 L p .707 .577 .707 r
F P
0 g
s
.80725 .6231 m .80929 .65841 L .78182 .65334 L p .707 .577 .707 r
F P
0 g
s
.78182 .65334 m .77978 .61803 L .80725 .6231 L p .707 .577 .707 r
F P
0 g
s
.83109 .69455 m .83214 .71217 L .81103 .7037 L p .707 .577 .707 r
F P
0 g
s
.81103 .7037 m .80998 .68608 L .83109 .69455 L p .707 .577 .707 r
F P
0 g
s
.29831 .55136 m .30016 .60549 L .31278 .61524 L p .707 .577 .707 r
F P
0 g
s
.31306 .64623 m .3151 .68154 L .33621 .68995 L p .707 .577 .707 r
F P
0 g
s
.45664 .71532 m .45769 .73294 L .48162 .72334 L p .707 .577 .707 r
F P
0 g
s
.48162 .72334 m .48058 .70572 L .45664 .71532 L p .707 .577 .707 r
F P
0 g
s
.68755 .62598 m .68959 .66128 L .66564 .67078 L p .707 .577 .707 r
F P
0 g
s
.33694 .71832 m .33799 .73595 L .36546 .74103 L p .707 .577 .707 r
F P
0 g
s
.68959 .66128 m .68755 .62598 L .71684 .61955 L p .707 .577 .707 r
F P
0 g
s
.30016 .60549 m .29831 .55136 L .29537 .54048 L p .707 .577 .707 r
F P
0 g
s
.3151 .68154 m .31306 .64623 L .30038 .6353 L p .707 .577 .707 r
F P
0 g
s
.33799 .73595 m .33694 .71832 L .31582 .70986 L p .707 .577 .707 r
F P
0 g
s
.66739 .71631 m .66634 .69868 L .69028 .68909 L p .707 .577 .707 r
F P
0 g
s
.77978 .61803 m .78182 .65334 L .75066 .65212 L p .707 .577 .707 r
F P
0 g
s
.75066 .65212 m .74862 .61681 L .77978 .61803 L p .707 .577 .707 r
F P
0 g
s
.71888 .65485 m .71684 .61955 L .74862 .61681 L p .707 .577 .707 r
F P
0 g
s
.71684 .61955 m .71888 .65485 L .68959 .66128 L p .707 .577 .707 r
F P
0 g
s
.74862 .61681 m .75066 .65212 L .71888 .65485 L p .707 .577 .707 r
F P
0 g
s
.31582 .70986 m .31687 .72748 L .33799 .73595 L p .707 .577 .707 r
F P
0 g
s
.69028 .68909 m .69133 .70671 L .66739 .71631 L p .707 .577 .707 r
F P
0 g
s
.48058 .70572 m .48162 .72334 L .49787 .7116 L p .707 .577 .707 r
F P
0 g
s
.49787 .7116 m .49682 .69398 L .48058 .70572 L p .707 .577 .707 r
F P
0 g
s
.80998 .68608 m .81103 .7037 L .78355 .69862 L p .707 .577 .707 r
F P
0 g
s
.78355 .69862 m .7825 .68099 L .80998 .68608 L p .707 .577 .707 r
F P
0 g
s
.49408 .63065 m .49611 .66596 L .50308 .65333 L p .707 .577 .707 r
F P
0 g
s
.50308 .65333 m .50104 .61802 L .49408 .63065 L p .707 .577 .707 r
F P
0 g
s
.49918 .53892 m .50103 .59305 L .4981 .58217 L p .707 .577 .707 r
F P
0 g
s
.4981 .58217 m .49625 .52803 L .49918 .53892 L p .707 .577 .707 r
F P
0 g
s
.30038 .6353 m .30242 .67061 L .3151 .68154 L p .707 .577 .707 r
F P
0 g
s
.29537 .54048 m .29722 .59461 L .30016 .60549 L p .707 .577 .707 r
F P
0 g
s
.69133 .70671 m .69028 .68909 L .71957 .68258 L p .707 .577 .707 r
F P
0 g
s
.31687 .72748 m .31582 .70986 L .30314 .69884 L p .707 .577 .707 r
F P
0 g
s
.30242 .67061 m .30038 .6353 L .29738 .62291 L p .707 .577 .707 r
F P
0 g
s
.7825 .68099 m .78355 .69862 L .75239 .69741 L p .707 .577 .707 r
F P
0 g
s
.75239 .69741 m .75135 .67979 L .7825 .68099 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29722 .59461 m .29537 .54048 L .30241 .52952 L p .707 .577 .707 r
F P
0 g
s
.71957 .68258 m .72062 .7002 L .69133 .70671 L p .707 .577 .707 r
F P
0 g
s
.72062 .7002 m .71957 .68258 L .75135 .67979 L p .707 .577 .707 r
F P
0 g
s
.30314 .69884 m .30419 .71647 L .31687 .72748 L p .707 .577 .707 r
F P
0 g
s
.75135 .67979 m .75239 .69741 L .72062 .7002 L p .707 .577 .707 r
F P
0 g
s
.49682 .69398 m .49787 .7116 L .50482 .69886 L p .707 .577 .707 r
F P
0 g
s
.50482 .69886 m .50378 .68124 L .49682 .69398 L p .707 .577 .707 r
F P
0 g
s
.50104 .61802 m .50308 .65333 L .50007 .64094 L p .707 .577 .707 r
F P
0 g
s
.50007 .64094 m .49803 .60563 L .50104 .61802 L p .707 .577 .707 r
F P
0 g
s
.29738 .62291 m .29942 .65822 L .30242 .67061 L p .707 .577 .707 r
F P
0 g
s
.49625 .52803 m .4981 .58217 L .48547 .57243 L p .707 .577 .707 r
F P
0 g
s
.48547 .57243 m .48362 .51829 L .49625 .52803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30241 .52952 m .30426 .58365 L .29722 .59461 L p .707 .577 .707 r
F P
0 g
s
.30419 .71647 m .30314 .69884 L .30013 .68635 L p .707 .577 .707 r
F P
0 g
s
.29942 .65822 m .29738 .62291 L .30434 .61028 L p .707 .577 .707 r
F P
0 g
s
.30426 .58365 m .30241 .52952 L .31874 .51955 L p .707 .577 .707 r
F P
0 g
s
.30013 .68635 m .30118 .70398 L .30419 .71647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50378 .68124 m .50482 .69886 L .50181 .68637 L p .707 .577 .707 r
F P
0 g
s
.50181 .68637 m .50076 .66875 L .50378 .68124 L p .707 .577 .707 r
F P
0 g
s
.49803 .60563 m .50007 .64094 L .48739 .63001 L p .707 .577 .707 r
F P
0 g
s
.48739 .63001 m .48535 .5947 L .49803 .60563 L p .707 .577 .707 r
F P
0 g
s
.48362 .51829 m .48547 .57243 L .4644 .56478 L p .707 .577 .707 r
F P
0 g
s
.4644 .56478 m .46255 .51064 L .48362 .51829 L p .707 .577 .707 r
F P
0 g
s
.30434 .61028 m .30638 .64559 L .29942 .65822 L p .707 .577 .707 r
F P
0 g
s
.31874 .51955 m .32059 .57369 L .30426 .58365 L p .707 .577 .707 r
F P
0 g
s
.30118 .70398 m .30013 .68635 L .30709 .67361 L p .707 .577 .707 r
F P
0 g
s
.32059 .57369 m .31874 .51955 L .34275 .51156 L p .707 .577 .707 r
F P
0 g
s
.30638 .64559 m .30434 .61028 L .32059 .59865 L p .707 .577 .707 r
F P
0 g
s
.30709 .67361 m .30813 .69124 L .30118 .70398 L p .707 .577 .707 r
F P
0 g
s
.46255 .51064 m .4644 .56478 L .43693 .55997 L p .707 .577 .707 r
F P
0 g
s
.43693 .55997 m .43508 .50584 L .46255 .51064 L p .707 .577 .707 r
F P
0 g
s
.50076 .66875 m .50181 .68637 L .48913 .67535 L p .707 .577 .707 r
F P
0 g
s
.48913 .67535 m .48808 .65773 L .50076 .66875 L p .707 .577 .707 r
F P
0 g
s
.48535 .5947 m .48739 .63001 L .46628 .62159 L p .707 .577 .707 r
F P
0 g
s
.46628 .62159 m .46424 .58629 L .48535 .5947 L p .707 .577 .707 r
F P
0 g
s
.32059 .59865 m .32263 .63396 L .30638 .64559 L p .707 .577 .707 r
F P
0 g
s
.3446 .56569 m .34275 .51156 L .3721 .50632 L p .707 .577 .707 r
F P
0 g
s
.34275 .51156 m .3446 .56569 L .32059 .57369 L p .707 .577 .707 r
F P
0 g
s
.43508 .50584 m .43693 .55997 L .40577 .55848 L p .707 .577 .707 r
F P
0 g
s
.40577 .55848 m .40392 .50435 L .43508 .50584 L p .707 .577 .707 r
F P
0 g
s
.30813 .69124 m .30709 .67361 L .32333 .66187 L p .707 .577 .707 r
F P
0 g
s
.32263 .63396 m .32059 .59865 L .34454 .58916 L p .707 .577 .707 r
F P
0 g
s
.37395 .56046 m .3721 .50632 L .40392 .50435 L p .707 .577 .707 r
F P
0 g
s
.3721 .50632 m .37395 .56046 L .3446 .56569 L p .707 .577 .707 r
F P
0 g
s
.40392 .50435 m .40577 .55848 L .37395 .56046 L p .707 .577 .707 r
F P
0 g
s
.32333 .66187 m .32438 .67949 L .30813 .69124 L p .707 .577 .707 r
F P
0 g
s
.46424 .58629 m .46628 .62159 L .43881 .61653 L p .707 .577 .707 r
F P
0 g
s
.43881 .61653 m .43677 .58122 L .46424 .58629 L p .707 .577 .707 r
F P
0 g
s
.48808 .65773 m .48913 .67535 L .46801 .66689 L p .707 .577 .707 r
F P
0 g
s
.46801 .66689 m .46697 .64926 L .48808 .65773 L p .707 .577 .707 r
F P
0 g
s
.34454 .58916 m .34658 .62447 L .32263 .63396 L p .707 .577 .707 r
F P
0 g
s
.34658 .62447 m .34454 .58916 L .37383 .58273 L p .707 .577 .707 r
F P
0 g
s
.32438 .67949 m .32333 .66187 L .34727 .65227 L p .707 .577 .707 r
F P
0 g
s
.43677 .58122 m .43881 .61653 L .40765 .6153 L p .707 .577 .707 r
F P
0 g
s
.40765 .6153 m .40561 .57999 L .43677 .58122 L p .707 .577 .707 r
F P
0 g
s
.37587 .61804 m .37383 .58273 L .40561 .57999 L p .707 .577 .707 r
F P
0 g
s
.37383 .58273 m .37587 .61804 L .34658 .62447 L p .707 .577 .707 r
F P
0 g
s
.40561 .57999 m .40765 .6153 L .37587 .61804 L p .707 .577 .707 r
F P
0 g
s
.34727 .65227 m .34832 .6699 L .32438 .67949 L p .707 .577 .707 r
F P
0 g
s
.46697 .64926 m .46801 .66689 L .44054 .6618 L p .707 .577 .707 r
F P
0 g
s
.44054 .6618 m .43949 .64418 L .46697 .64926 L p .707 .577 .707 r
F P
0 g
s
.34832 .6699 m .34727 .65227 L .37656 .64576 L p .707 .577 .707 r
F P
0 g
s
.43949 .64418 m .44054 .6618 L .40938 .6606 L p .707 .577 .707 r
F P
0 g
s
.40938 .6606 m .40834 .64297 L .43949 .64418 L p .707 .577 .707 r
F P
0 g
s
.37656 .64576 m .37761 .66338 L .34832 .6699 L p .707 .577 .707 r
F P
0 g
s
.37761 .66338 m .37656 .64576 L .40834 .64297 L p .707 .577 .707 r
F P
0 g
s
.40834 .64297 m .40938 .6606 L .37761 .66338 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
MWoo7P00RGoo001aOol50002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP03FUH=001l
Ool006moo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00AJEPT007=oo`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H006eoo`00Kgoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPH006Mo
o`00Kgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH6001QOol006moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH00002001NOol006moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001LOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001KOol006mo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP8005]oo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP8005]oo`00KWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005]oo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8005aoo`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005ao
o`00KWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000G7oo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00GGoo001]Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00GGoo001]Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001MOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001NOol006aoo`04001JEUYF0005FUH00`00FUIJEP03FUH0
1000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000GWoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol0
06]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF
0003FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001OOol006]oo`04001JEUYF0005FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00Ggoo001[Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
Ggoo001[Ool01000FUIJEP000UYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00
Jgoo00@005YFFUH0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`04001JEUYF
0002FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00003FUH01000FUIJ
EP0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo
001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUIJEP0A000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Ioo`P000AJ
EP03001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00H7oo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001LOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol005Yoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00F7oo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HGoo001FOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001EOol00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00HGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00HGoo001DOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00HGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
00001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0057oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo2@0015YF00<005YFFUH0
0UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000Aoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP00008003Aoo`00Dgoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH=0005FUH80004FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEPD000=oo`05001JEUYF001JEP05
0009FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool01000FUIJEP0015YF00@005YFFUIJEP8000Qoo`05001JEUYF001JEP050009FUH00`00FUIJEP07
FUH200000eYF001JEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00D0
05YF000005YF00@000Eoo`05001JEUYF001JEP050009FUH00`00FUIJEP08FUH30003FUH20005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH015YF500015YF00<005YF
FUH025YF00@005YFFUH0009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF2P000UYF00<005YFFUH02EYF00@005YFFUIJEP@000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00EJEP03001JEP00
00H000AJEP03001JEUYF009JEPP000MJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP<00003FUH005YF00=JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
Agoo3`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00P0015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000oOol80004FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP04
FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000iOol60003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
10001Woo1@002Woo10000UYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH4
000:Ool5000;Ool70004FUH01@00FUIJEUYF0000;Goo000cOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001J
EP0000@000eoo`D000Moo`@00003FUH005YF00AJEP<00003FUH005YF009JEP03001oogoo02]oo`00
<Goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00FUH00004FUH200000eYF001JEP02FUH90005Ool300000goo000000050005FUH00`00
FUIJEP04FUH01000FUH000000eYF00<007ooOol0:goo000_Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJ
EPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH?0002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@0
00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF008000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@0
00IJEP8000=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEP00001JEP020005FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001J
EUYFFUH200000eYF0000000H000:FUH300000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF0P0015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP000eYF00@005YF000000=JEP07001JEUYFFUH007oo00000UYF00<005YF
FUH01@0025YF00<005YFFUH025YF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEUYFFUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001J
EP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF0`001EYF00H005YFFUH007oo0002FUH00`00FUIJEP050008
FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YF000000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000^Ool002aoo`03001J
EP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0002FUH01000FUIJEP001EYF00P005YFFUH007oo001JEP000eYF1@0025YF00<005YFFUH025YF
00@005YF0000009JEP@0009JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH00000;Woo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP08FUH20004FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF
000000050004FUH01000FUIJEUYF20001EYF0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH00UYF2@002Goo1P0000AJ
EP000000009JEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH50002FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH50009Ool3000:Ool2000015YF001JEUYF1000
0UYF10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF10001EYF00<005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YFFUH0
02eoo`00;7oo00@005YFFUH000AJEP04001JEUYFFUH2000=Ool50009Ool01000FUIJEP0015YF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
15YF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00;Goo00<005YF000015YF00D005YF000005YF00@000Yoo`D000Qoo`80
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP800003FUH005YF
00AJEQT0009JEP03001JEUYF008000IJEP03001JEUYF00AJEPH000QJEPT000AJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF000015YF00<005YFFUH00eYF2P0015YF00<005YFFUH00UYF2@002Goo0`0000EJEP00FUIJ
EP0002eoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP<000MJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEPD000AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEP0000@000=JEP8000Aoo`T001Eoo`80009JEP03001o
ogoo02]oo`00;Goo00<005YF00000P001EYF00<005YFFUH00`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF0P0015YF00@005YFFUIJEP8000Moo`D001Moo`800003
FUH007oo02aoo`00;Goo00D005YF001JEP0000EJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH200001EYF001JEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUH00005FUH00`00FUIJEP020007Ool5000FOol0
0`00FUH00002000]Ool002eoo`80009JEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH20002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP020007Ool5000EOol01@00FUIJEP00FUH00P00;7oo000]Ool20002FUH00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH200000eYF001JEP06
FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF00<0
05YFFUH00eYF00<005YFFUH00P0027oo3`0027oo0P000eYF00@005YF000002aoo`00;Goo0P000UYF
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P000eYF
00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YF00000P001eYF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P00
0UYF00<005YFFUH00eYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEP0000L00003FUH0
05YF009JEP04001JEP00000/Ool002eoo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP800003FUH005YF00IJEP03
001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJEP800003FUH005YF00aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUH000020004FUH60003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH0
000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@00003FUH005YF
009JEP03001JEUYF00EJEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUH0000/Ool002ioo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF009JEQX0
00EJEP05001JEUYFFUH00007FUH01@00FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0006FUH30000
15YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000009J
EP8000EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP@002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00@005YFFUIJEPH0009JEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH01000FUH000001UYF00<005YFFUH00UYF2@0025YF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH6
0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@000AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001J
EP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030004FUH01000FUIJEP00
;Goo000]Ool00`00FUH00004FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP80009JEP8000Aoo`<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH300000eYF001JEP03FUH01@00FUIJEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00005FUH005YFFUH0000]
Ool002eoo`04001JEUYF0003FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030002FUH30006Ool20002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
1eYF0P000eYF00<005YFFUH00UYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001oogoo02]oo`00;Goo00@005YFFUH0
00=JEP8000Eooa`0009JEP03001JEUYF008000Eoo`800005FUH005YFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJ
EP000UYF00<007ooOol02Woo2@0015YF00<005YFFUH01EYF00<005YF00000UYF00@005YFFUIJEPD0
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@00003FUH005YF00EJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEP00
008000Ioo`<002aoo`00;Goo00<005YFFUH00`001goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00@005YFFUIJEPT000=JEP03001JEUYF00=JEPL000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEUYF001JEP00FUH00`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH015YF10002Woo0P00;7oo000^Ool01000FUH000001Woo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP020004FUH40005FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP04000>Ool2000/Ool002ioo`80009JEP80009oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00@005YFFUIJEP@00003FUH005YF00MJ
EP<0009JEPL0015oo`03001JEP0002aoo`00;Woo0P000UYF00@005YF000000IJEP03001JEUYF00EJ
EP03001JEUYF009JEPl000EJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000IJEP03001JEUYF00=JEP03001JEP0000h001Moo`800003FUH007oo02]oo`00;Woo00@0
05YFFUIJEP<000MJEP03001JEUYF009JEPP000]oo`P0009JEPH000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEPD000AJEP03001JEUYF00=JEP04001JEUYF000SOol01@00FUH0
05YF0000;7oo000^Ool01`00FUIJEUYF001JEP0000IJEPT000Uoo`L000IJEP03001JEP0000<000AJ
EPP000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0009JEPH000AJEP04001JEUYF000ROol01000FUIJEUYF
0P00;7oo000^Ool01000FUIJEP000eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEPT000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<00003FUH00000009JEP04001JEUYFFUH90003FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200001EYF00000000FUH01`0000EJEP00FUIJEP00021oo`8000AJEP03001oogoo02]oo`00
;Woo00<005YF000015YF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP8000Moo`80009JEP03001oogoo01Yoo`@00003FUH005YF00=JEP03001oogoo
02]oo`00;Woo0`0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YF00000P001Woo00<005YF000067oo10001EYF00D005YFFUIJEP00
02ioo`00;goo0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP02FUH30002Ool4000DOol40002FUH00`00FUIJEP04FUH01000FUH00000
;goo000^Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<00003FUH0000000aoo`L000IJ
EP03001JEUYF00AJEP80035oo`00;Woo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000Eoo`04001JEUYF0003FUHN0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00<Woo000^Ool0
1000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000Moo`03001JEP0000@001=JEP03001JEUYF00QJEPd000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Aoo`00;Woo0P0017oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002Goo0P0065YF
00<005YFFUH02EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>7oo000^Ool20007Ool50004FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04000:Ool200000eYF
0000000GFUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000kOol002ioo`<000]oo`T0009JEPD0009JEPL000eoo`04001JEUYFFUH4000EFUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000050004FUH00`00FUIJEP02
FUH00`00FUH00003FUH60002FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000oOol002io
o`800003FUH007oo019oo`T0019oo`8000AJEP80009oo`H000mJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEPH000=JEP03001JEP0000=JEP03001JEUYF00=JEP<0
0003FUH005YF010004Ioo`00;Woo0P000UYF0P004goo1@0047oo100000=JEP00FUH00eYF00<007oo
Ool01goo1`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomo
o`1BOol002moo`05001JEUYF001JEP03000AOol3000>Ool30005FUH01@00FUIJEUYF00004Goo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2001COol002moo`04001J
EUYF0004FUH3000KOol400000eYF001JEP05FUH01000FUH0000067oo20001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF00<00003FUH007oo059oo`00<7oo00@005YFFUH000AJEP03001JEP0000<0011oo`L0
00EJEP03001JEUYF00AJEP80029oo`d000IJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH50006FUH00`00FUIJEP03FUH30003Ool2001COol0035oo`<000AJEP03001JEUYF00=JEQ0000AJ
EP03001JEUYF00IJEP03001JEUYF009JEP8002eoo`03001JEUYF01l0009JEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo00=oo`8005=oo`00<goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00;goo00D005YFFUH007oo008000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0005Ool00`00FUH0001COol003Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@0039oo`03001JEP0000Aoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool00`00FUH0001COol003Qoo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003Moo`8000Moo`<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000Qoo`800003FUH007oo059oo`00>goo100000=JEP00
FUH01eYF00<005YFFUH00UYF1`00>goo0P002Woo100000=JEP00FUH01eYF0`000UYF2@0037oo0P00
00AJEP00FUH005=oo`00?goo3`00@Woo00@005YF000000aoo`l001=oo`8000AJEP03001oogoo059o
o`00T7oo00D005YFFUIJEP0001Aoo`D0019oo`800003FUH005YF00=JEP03001oogoo059oo`00T7oo
00@005YFFUIJEP<0019oo`D0011oo`8000=JEP03001JEUYF009JEP03001oogoo059oo`00T7oo00D0
05YFFUIJEP00009JEP80015oo`<000eoo`@000EJEP03001JEUYF008005Eoo`00TGoo00@005YFFUH0
00AJEPD001Qoo`@0009JEP03001JEUYF00AJEP<005Moo`00TWoo0`001EYF00@005YFFUIJEQP000IJ
EP03001JEUYF00=JEP8005Uoo`00U7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8005]oo`00UGoo0P000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005eoo`00Ugoo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00Ggoo002IOol5
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04001ROol009ioo`T000AJEP03001J
EUYF009JEPL006Ioo`00Ygoo2@00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59423 .74459 m .59608 .68798 L .56491 .68566 L p .707 .577 .707 r
F P
0 g
s
.59608 .68798 m .59423 .74459 L .62605 .74504 L p .707 .577 .707 r
F P
0 g
s
.62605 .74504 m .6279 .68842 L .59608 .68798 L p .707 .577 .707 r
F P
0 g
s
.6279 .68842 m .62605 .74504 L .6554 .74356 L p .707 .577 .707 r
F P
0 g
s
.6554 .74356 m .65725 .68694 L .6279 .68842 L p .707 .577 .707 r
F P
0 g
s
.56307 .74227 m .56491 .68566 L .53745 .68169 L p .707 .577 .707 r
F P
0 g
s
.56491 .68566 m .56307 .74227 L .59423 .74459 L p .707 .577 .707 r
F P
0 g
s
.65725 .68694 m .6554 .74356 L .67941 .74031 L p .707 .577 .707 r
F P
0 g
s
.67941 .74031 m .68126 .68369 L .65725 .68694 L p .707 .577 .707 r
F P
0 g
s
.59234 .80394 m .59438 .7659 L .56323 .7633 L p .707 .577 .707 r
F P
0 g
s
.59438 .7659 m .59234 .80394 L .62412 .8052 L p .707 .577 .707 r
F P
0 g
s
.62412 .8052 m .62616 .76715 L .59438 .7659 L p .707 .577 .707 r
F P
0 g
s
.53745 .68169 m .5356 .7383 L .56307 .74227 L p .707 .577 .707 r
F P
0 g
s
.62616 .76715 m .62412 .8052 L .65342 .80498 L p .707 .577 .707 r
F P
0 g
s
.65342 .80498 m .65546 .76694 L .62616 .76715 L p .707 .577 .707 r
F P
0 g
s
.5356 .7383 m .53745 .68169 L .51637 .67645 L p .707 .577 .707 r
F P
0 g
s
.56323 .7633 m .56119 .80134 L .59234 .80394 L p .707 .577 .707 r
F P
0 g
s
.56119 .80134 m .56323 .7633 L .53575 .7596 L p .707 .577 .707 r
F P
0 g
s
.49099 .84163 m .45509 .37253 L .41113 .37108 L p .707 .577 .707 r
F P
0 g
s
.51637 .67645 m .51452 .73307 L .5356 .7383 L p .707 .577 .707 r
F P
0 g
s
.55946 .84894 m .56051 .82991 L .53303 .82624 L p .707 .577 .707 r
F P
0 g
s
.53303 .82624 m .53198 .84527 L .55946 .84894 L p .707 .577 .707 r
F P
0 g
s
.53371 .79765 m .53575 .7596 L .51464 .75518 L p .707 .577 .707 r
F P
0 g
s
.51464 .75518 m .5126 .79323 L .53371 .79765 L p .707 .577 .707 r
F P
0 g
s
.51452 .73307 m .51637 .67645 L .50375 .67047 L p .707 .577 .707 r
F P
0 g
s
.53198 .84527 m .53303 .82624 L .51192 .82187 L p .707 .577 .707 r
F P
0 g
s
.51192 .82187 m .51087 .8409 L .53198 .84527 L p .707 .577 .707 r
F P
0 g
s
.50375 .67047 m .5019 .72709 L .51452 .73307 L p .707 .577 .707 r
F P
0 g
s
.5126 .79323 m .51464 .75518 L .50196 .75047 L p .707 .577 .707 r
F P
0 g
s
.50196 .75047 m .49992 .78851 L .5126 .79323 L p .707 .577 .707 r
F P
0 g
s
.5019 .72709 m .50375 .67047 L .50081 .66432 L p .707 .577 .707 r
F P
0 g
s
.51087 .8409 m .51192 .82187 L .49923 .81724 L p .707 .577 .707 r
F P
0 g
s
.49923 .81724 m .49819 .83627 L .51087 .8409 L p .707 .577 .707 r
F P
0 g
s
.50081 .66432 m .49896 .72094 L .5019 .72709 L p .707 .577 .707 r
F P
0 g
s
.49992 .78851 m .50196 .75047 L .49896 .74591 L p .707 .577 .707 r
F P
0 g
s
.49896 .74591 m .49692 .78396 L .49992 .78851 L p .707 .577 .707 r
F P
0 g
s
.49819 .83627 m .49923 .81724 L .49622 .8128 L p .707 .577 .707 r
F P
0 g
s
.49896 .72094 m .50081 .66432 L .50785 .65861 L p .707 .577 .707 r
F P
0 g
s
.49622 .8128 m .49517 .83183 L .49819 .83627 L p .707 .577 .707 r
F P
0 g
s
.50785 .65861 m .506 .71523 L .49896 .72094 L p .707 .577 .707 r
F P
0 g
s
.49692 .78396 m .49896 .74591 L .50592 .74197 L p .707 .577 .707 r
F P
0 g
s
.50592 .74197 m .50388 .78002 L .49692 .78396 L p .707 .577 .707 r
F P
0 g
s
.49517 .83183 m .49622 .8128 L .50318 .80898 L p .707 .577 .707 r
F P
0 g
s
.506 .71523 m .50785 .65861 L .52418 .6539 L p .707 .577 .707 r
F P
0 g
s
.50318 .80898 m .50213 .82801 L .49517 .83183 L p .707 .577 .707 r
F P
0 g
s
.52418 .6539 m .52233 .71052 L .506 .71523 L p .707 .577 .707 r
F P
0 g
s
.50388 .78002 m .50592 .74197 L .52217 .73903 L p .707 .577 .707 r
F P
0 g
s
.52217 .73903 m .52013 .77707 L .50388 .78002 L p .707 .577 .707 r
F P
0 g
s
.50213 .82801 m .50318 .80898 L .51942 .80616 L p .707 .577 .707 r
F P
0 g
s
.51942 .80616 m .51837 .82519 L .50213 .82801 L p .707 .577 .707 r
F P
0 g
s
.52013 .77707 m .52217 .73903 L .54612 .73737 L p .707 .577 .707 r
F P
0 g
s
.53575 .7596 m .53371 .79765 L .56119 .80134 L p .707 .577 .707 r
F P
0 g
s
.54612 .73737 m .54408 .77541 L .52013 .77707 L p .707 .577 .707 r
F P
0 g
s
.51837 .82519 m .51942 .80616 L .54336 .80461 L p .707 .577 .707 r
F P
0 g
s
.54336 .80461 m .54231 .82364 L .51837 .82519 L p .707 .577 .707 r
F P
0 g
s
.45509 .37253 m .49099 .84163 L .5358 .83696 L p .707 .577 .707 r
F P
0 g
s
.52233 .71052 m .52418 .6539 L .52632 .65361 L p .707 .577 .707 r
F P
0 g
s
.59061 .85156 m .59166 .83253 L .56051 .82991 L p .707 .577 .707 r
F P
0 g
s
.56051 .82991 m .55946 .84894 L .59061 .85156 L p .707 .577 .707 r
F P
0 g
s
.5847 .69075 m .58798 .65242 L .60936 .64961 L .707 .577 .707 r
F
.57851 .64918 m .60936 .64961 L p .57739 .65381 L F P
0 g
s
.64052 .65193 m .63867 .70855 L .60954 .70638 L p .707 .577 .707 r
F P
0 g
s
.60954 .70638 m .60751 .70623 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60951 .70294 m .64052 .65193 L .60954 .70638 L .707 .577 .707 r
F
.60936 .64961 m .64052 .65193 L p .60951 .70294 L F P
0 g
s
.60751 .70623 m .60909 .65788 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60909 .65788 m .60936 .64961 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.65546 .76694 m .65342 .80498 L .67737 .80333 L p .707 .577 .707 r
F P
0 g
s
.67737 .80333 m .6794 .76528 L .65546 .76694 L p .707 .577 .707 r
F P
0 g
s
.66582 .74471 m .66378 .78275 L .65334 .78135 L p .707 .577 .707 r
F P
0 g
s
.65334 .78135 m .63631 .77906 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.65133 .76157 m .66582 .74471 L .65334 .78135 L .707 .577 .707 r
F
.63631 .77906 m .63835 .74102 L .6494 .7425 L p F P
0 g
s
.6494 .7425 m .66582 .74471 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.63631 .77906 m .6494 .7425 L .65133 .76157 L .707 .577 .707 r
F
.60741 .30478 m .60585 .30792 L p .60794 .33385 L F P
0 g
s
.64331 .77388 m .60741 .30478 L .60794 .33385 L .707 .577 .707 r
F
.60585 .30792 m .5977 .32437 L p .60684 .41447 L F P
0 g
s
.64331 .77388 m .60585 .30792 L .60684 .41447 L .707 .577 .707 r
F
.60306 .28571 m .60741 .30478 L p .61283 .38218 L F P
0 g
s
.63835 .74102 m .63631 .77906 L .61015 .77687 L p .707 .577 .707 r
F P
0 g
s
.61017 .7711 m .63835 .74102 L .61015 .77687 L .707 .577 .707 r
F
.60515 .77646 m .60719 .73841 L .61029 .73867 L p F P
0 g
s
.61029 .73867 m .63835 .74102 L p .61017 .7711 L .707 .577 .707 r
F P
0 g
s
.60515 .77646 m .61029 .73867 L .61017 .7711 L .707 .577 .707 r
F
.60715 .44787 m .61115 .50016 L p .60684 .41447 L F P
0 g
s
.61115 .50016 m .63359 .79346 L p .61123 .47672 L .707 .577 .707 r
F P
0 g
s
.60684 .41447 m .61115 .50016 L .61123 .47672 L .707 .577 .707 r
F
.63359 .79346 m .64331 .77388 L p .6113 .45843 L F P
0 g
s
.6113 .45843 m .60684 .41447 L .61123 .47672 L .707 .577 .707 r
F
.6113 .45843 m .61123 .47672 L .63359 .79346 L F
.61015 .77687 m .60515 .77646 L p .61017 .7711 L F P
0 g
s
.63896 .75481 m .60311 .2863 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60311 .2863 m .60306 .28571 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.64331 .77388 m .63896 .75481 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60741 .30478 m .61486 .4021 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.61486 .4021 m .64331 .77388 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.5977 .32437 m .60715 .44787 L p .60684 .41447 L .707 .577 .707 r
F P
0 g
s
.60936 .64961 m .60751 .70623 L .57569 .70578 L p .707 .577 .707 r
F P
0 g
s
.60338 .82483 m .60443 .8058 L .63558 .80842 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .63359 .79346 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57487 .34254 m .59357 .58692 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .57541 .73716 L .58182 .73741 L p .707 .577 .707 r
F P
0 g
s
.58182 .73741 m .60719 .73841 L p .578 .77017 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .58182 .73741 L .578 .77017 L .707 .577 .707 r
F
.59357 .58692 m .59587 .61687 L p .59877 .52608 L F P
0 g
s
.60719 .73841 m .60515 .77646 L .57337 .7752 L p .707 .577 .707 r
F P
0 g
s
.59587 .61687 m .61077 .81164 L p .60081 .57448 L .707 .577 .707 r
F P
0 g
s
.59877 .52608 m .59587 .61687 L .60081 .57448 L .707 .577 .707 r
F
.57569 .70578 m .57739 .65381 L p .58798 .65242 L F P
0 g
s
.57569 .70578 m .58798 .65242 L .5847 .69075 L .707 .577 .707 r
F
.58302 .63055 m .54118 .35753 L .57739 .65381 L F
.57739 .65381 m .57754 .64917 L .57851 .64918 L p F P
0 g
s
.54118 .35753 m .56611 .6833 L p .57739 .65381 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .58302 .63055 L .57739 .65381 L .707 .577 .707 r
F
.5716 .82352 m .57265 .80449 L .60443 .8058 L p F P
0 g
s
.60443 .8058 m .60338 .82483 L .5716 .82352 L p .707 .577 .707 r
F P
0 g
s
.57707 .82662 m .61077 .81164 L p .58396 .63667 L .707 .577 .707 r
F P
0 g
s
.57569 .70578 m .55714 .70672 L p .56338 .69042 L .707 .577 .707 r
F P
0 g
s
.54634 .70726 m .55859 .68445 L .56338 .69042 L .707 .577 .707 r
F
.55714 .70672 m .54634 .70726 L p .56338 .69042 L F P
0 g
s
.57648 .68171 m .57569 .70578 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.54118 .35753 m .4999 .36786 L p .55329 .68527 L .707 .577 .707 r
F P
0 g
s
.5557 .6849 m .54118 .35753 L .55329 .68527 L .707 .577 .707 r
F
.54634 .70726 m .54703 .68623 L p .55859 .68445 L F P
0 g
s
.56971 .73036 m .54118 .35753 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .57754 .64917 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.55329 .68527 m .4999 .36786 L .54703 .68623 L .707 .577 .707 r
F
.54703 .68623 m .54819 .65065 L p .55859 .68445 L F P
0 g
s
.55658 .70482 m .5557 .6849 L .55329 .68527 L .707 .577 .707 r
F
.54408 .77541 m .5458 .74331 L p .57541 .73716 L F P
0 g
s
.5458 .74331 m .54612 .73737 L .5486 .73735 L p .707 .577 .707 r
F P
0 g
s
.5486 .73735 m .57541 .73716 L p .5458 .74331 L .707 .577 .707 r
F P
0 g
s
.57754 .64917 m .57739 .65381 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.57739 .65381 m .57648 .68171 L p .56611 .6833 L .707 .577 .707 r
F P
0 g
s
.55859 .68445 m .57739 .65381 L .56611 .6833 L .707 .577 .707 r
F
.56611 .6833 m .56721 .69773 L p .58396 .63667 L F P
0 g
s
.57541 .73716 m .57337 .7752 L .54408 .77541 L p .707 .577 .707 r
F P
0 g
s
.56721 .69773 m .57707 .82662 L p .58296 .66421 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .56721 .69773 L .58296 .66421 L .707 .577 .707 r
F
.57707 .82662 m .56971 .73036 L p .55658 .70482 L F P
0 g
s
.54634 .70726 m .52233 .71052 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .52028 .63418 L p .54703 .68623 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .54703 .68623 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.54703 .68623 m .54634 .70726 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.55658 .70482 m .55329 .68527 L .54703 .68623 L .707 .577 .707 r
F
.54231 .82364 m .54336 .80461 L .57265 .80449 L p F P
0 g
s
.57265 .80449 m .5716 .82352 L .54231 .82364 L p .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .57707 .82662 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.52632 .65361 m .53001 .65311 L p .53493 .68135 L .707 .577 .707 r
F P
0 g
s
.53493 .68135 m .53001 .65311 L .53931 .67121 L .707 .577 .707 r
F
.52233 .71052 m .52632 .65361 L .53493 .68135 L F
.52028 .63418 m .5358 .83696 L p .55658 .70482 L F P
0 g
s
.53001 .65311 m .54819 .65065 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .45509 .37253 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .52028 .63418 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.52028 .63418 m .4999 .36786 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.59166 .83253 m .59061 .85156 L .62239 .85287 L p .707 .577 .707 r
F P
0 g
s
.62239 .85287 m .62344 .83384 L .59166 .83253 L p .707 .577 .707 r
F P
0 g
s
.62344 .83384 m .62239 .85287 L .65168 .85275 L p .707 .577 .707 r
F P
0 g
s
.65168 .85275 m .65273 .83372 L .62344 .83384 L p .707 .577 .707 r
F P
0 g
s
.44702 .84018 m .41113 .37108 L .37232 .36365 L p .707 .577 .707 r
F P
0 g
s
.41113 .37108 m .44702 .84018 L .49099 .84163 L p .707 .577 .707 r
F P
0 g
s
.68126 .68369 m .67941 .74031 L .69574 .73559 L p .707 .577 .707 r
F P
0 g
s
.69574 .73559 m .69759 .67898 L .68126 .68369 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .57487 .34254 L .54118 .35753 L p .707 .577 .707 r
F P
0 g
s
.65273 .83372 m .65168 .85275 L .67562 .8512 L p .707 .577 .707 r
F P
0 g
s
.67562 .8512 m .67667 .83217 L .65273 .83372 L p .707 .577 .707 r
F P
0 g
s
.6794 .76528 m .67737 .80333 L .69361 .80038 L p .707 .577 .707 r
F P
0 g
s
.69361 .80038 m .69565 .76234 L .6794 .76528 L p .707 .577 .707 r
F P
0 g
s
.40821 .83275 m .37232 .36365 L .34246 .35097 L p .707 .577 .707 r
F P
0 g
s
.37232 .36365 m .40821 .83275 L .44702 .84018 L p .707 .577 .707 r
F P
0 g
s
.69759 .67898 m .69574 .73559 L .70277 .72988 L p .707 .577 .707 r
F P
0 g
s
.70277 .72988 m .70462 .67327 L .69759 .67898 L p .707 .577 .707 r
F P
0 g
s
.67667 .83217 m .67562 .8512 L .69186 .84838 L p .707 .577 .707 r
F P
0 g
s
.69186 .84838 m .69291 .82935 L .67667 .83217 L p .707 .577 .707 r
F P
0 g
s
.63359 .79346 m .5977 .32437 L .57487 .34254 L p .707 .577 .707 r
F P
0 g
s
.69565 .76234 m .69361 .80038 L .70058 .79644 L p .707 .577 .707 r
F P
0 g
s
.70058 .79644 m .70262 .7584 L .69565 .76234 L p .707 .577 .707 r
F P
0 g
s
.35977 .69307 m .36162 .63645 L .35458 .64216 L p .707 .577 .707 r
F P
0 g
s
.35458 .64216 m .35273 .69878 L .35977 .69307 L p .707 .577 .707 r
F P
0 g
s
.36162 .63645 m .35977 .69307 L .35683 .68692 L p .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35752 .66589 L p .36162 .63645 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .32448 .33427 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.36284 .61728 m .34246 .35097 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.3609 .63496 m .36162 .63645 L p .35752 .66589 L .707 .577 .707 r
F P
0 g
s
.33825 .64687 m .3364 .70349 L .35273 .69878 L p .707 .577 .707 r
F P
0 g
s
.35273 .69878 m .35458 .64216 L .33825 .64687 L p .707 .577 .707 r
F P
0 g
s
.35265 .72552 m .35061 .76357 L .35757 .75963 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35961 .72158 L .35265 .72552 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35456 .75507 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35961 .72158 m .35904 .73221 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35904 .73221 m .35757 .75963 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .37836 .82006 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.32448 .33427 m .3494 .66004 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35219 .68472 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35683 .68692 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35219 .68472 m .34421 .68094 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.34962 .66199 m .35868 .63031 L .35219 .68472 L .707 .577 .707 r
F
.3566 .71703 m .35961 .72158 L p .35835 .72991 L F P
0 g
s
.35456 .75507 m .35628 .72297 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35628 .72297 m .3566 .71703 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.3364 .72847 m .33436 .76651 L .35061 .76357 L p .707 .577 .707 r
F P
0 g
s
.35061 .76357 m .35265 .72552 L .3364 .72847 L p .707 .577 .707 r
F P
0 g
s
.3566 .71703 m .35456 .75507 L .34188 .75036 L p .707 .577 .707 r
F P
0 g
s
.34188 .75036 m .34392 .71231 L .3566 .71703 L p .707 .577 .707 r
F P
0 g
s
.35602 .78429 m .36037 .80337 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34799 .6475 m .32448 .33427 L .34624 .63197 L .707 .577 .707 r
F
.34421 .68094 m .3459 .62897 L p .34962 .66199 L F P
0 g
s
.35351 .71365 m .32448 .33427 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34606 .62432 m .35868 .63031 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.32013 .3152 m .33883 .55958 L p .34624 .63197 L .707 .577 .707 r
F P
0 g
s
.31424 .65013 m .31239 .70674 L .3364 .70349 L p .707 .577 .707 r
F P
0 g
s
.3364 .70349 m .33825 .64687 L .31424 .65013 L p .707 .577 .707 r
F P
0 g
s
.34421 .68094 m .3391 .67967 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3391 .67967 m .32313 .67571 L p .33901 .64012 L .707 .577 .707 r
F P
0 g
s
.33901 .64012 m .34555 .62546 L .3391 .67967 L .707 .577 .707 r
F
.32448 .33427 m .32013 .3152 L p .34624 .63197 L F P
0 g
s
.32013 .3152 m .32984 .29562 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34421 .68094 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.34624 .63197 m .33883 .55958 L .3459 .62897 L .707 .577 .707 r
F
.32313 .67571 m .32498 .61909 L .34541 .62416 L p F P
0 g
s
.34541 .62416 m .34606 .62432 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.32313 .67571 m .34541 .62416 L .34555 .62546 L .707 .577 .707 r
F
.3404 .58009 m .34962 .7006 L p .34627 .63258 L F P
0 g
s
.34624 .63197 m .3459 .62897 L .34627 .63258 L .707 .577 .707 r
F
.3459 .62897 m .3404 .58009 L .34627 .63258 L F
.33883 .55958 m .3404 .58009 L p .3459 .62897 L F P
0 g
s
.34606 .62432 m .3459 .62897 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34606 .62432 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.35277 .71118 m .34624 .63197 L .34962 .7006 L .707 .577 .707 r
F
.34962 .7006 m .35602 .78429 L p .35277 .71118 L F P
0 g
s
.35277 .71118 m .34799 .6475 L .34624 .63197 L .707 .577 .707 r
F
.35602 .78429 m .33883 .55958 L p .3386 .4592 L F P
0 g
s
.33883 .55958 m .32013 .3152 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3494 .66004 m .36037 .80337 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35868 .63031 m .35752 .66589 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .35351 .71365 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35868 .63031 L .3609 .63496 L p .707 .577 .707 r
F P
0 g
s
.37836 .82006 m .36284 .61728 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .37836 .82006 L .40821 .83275 L p .707 .577 .707 r
F P
0 g
s
.69291 .82935 m .69186 .84838 L .69882 .84456 L p .707 .577 .707 r
F P
0 g
s
.69882 .84456 m .69987 .82553 L .69291 .82935 L p .707 .577 .707 r
F P
0 g
s
.70462 .67327 m .70277 .72988 L .69984 .72374 L p .707 .577 .707 r
F P
0 g
s
.69984 .72374 m .70169 .66712 L .70462 .67327 L p .707 .577 .707 r
F P
0 g
s
.70262 .7584 m .70058 .79644 L .69757 .79189 L p .707 .577 .707 r
F P
0 g
s
.69757 .79189 m .69961 .75385 L .70262 .7584 L p .707 .577 .707 r
F P
0 g
s
.69987 .82553 m .69882 .84456 L .69581 .84012 L p .707 .577 .707 r
F P
0 g
s
.69581 .84012 m .69686 .82109 L .69987 .82553 L p .707 .577 .707 r
F P
0 g
s
.70169 .66712 m .69984 .72374 L .68722 .71775 L p .707 .577 .707 r
F P
0 g
s
.68722 .71775 m .68907 .66114 L .70169 .66712 L p .707 .577 .707 r
F P
0 g
s
.25122 .70778 m .25307 .65116 L .22191 .64884 L p .707 .577 .707 r
F P
0 g
s
.25307 .65116 m .25122 .70778 L .28304 .70822 L p .707 .577 .707 r
F P
0 g
s
.28304 .70822 m .28489 .65161 L .25307 .65116 L p .707 .577 .707 r
F P
0 g
s
.28489 .65161 m .28304 .70822 L .31239 .70674 L p .707 .577 .707 r
F P
0 g
s
.31239 .70674 m .31424 .65013 L .28489 .65161 L p .707 .577 .707 r
F P
0 g
s
.22006 .70546 m .22191 .64884 L .19444 .64487 L p .707 .577 .707 r
F P
0 g
s
.22191 .64884 m .22006 .70546 L .25122 .70778 L p .707 .577 .707 r
F P
0 g
s
.69961 .75385 m .69757 .79189 L .68489 .78717 L p .707 .577 .707 r
F P
0 g
s
.68489 .78717 m .68693 .74913 L .69961 .75385 L p .707 .577 .707 r
F P
0 g
s
.24934 .76713 m .25138 .72908 L .22022 .72648 L p .707 .577 .707 r
F P
0 g
s
.25138 .72908 m .24934 .76713 L .28112 .76838 L p .707 .577 .707 r
F P
0 g
s
.28112 .76838 m .28316 .73034 L .25138 .72908 L p .707 .577 .707 r
F P
0 g
s
.19444 .64487 m .19259 .70149 L .22006 .70546 L p .707 .577 .707 r
F P
0 g
s
.28316 .73034 m .28112 .76838 L .31041 .76817 L p .707 .577 .707 r
F P
0 g
s
.31041 .76817 m .31245 .73013 L .28316 .73034 L p .707 .577 .707 r
F P
0 g
s
.68907 .66114 m .68722 .71775 L .66614 .71252 L p .707 .577 .707 r
F P
0 g
s
.66614 .71252 m .66799 .6559 L .68907 .66114 L p .707 .577 .707 r
F P
0 g
s
.19259 .70149 m .19444 .64487 L .17337 .63964 L p .707 .577 .707 r
F P
0 g
s
.22022 .72648 m .21818 .76452 L .24934 .76713 L p .707 .577 .707 r
F P
0 g
s
.69686 .82109 m .69581 .84012 L .68312 .83549 L p .707 .577 .707 r
F P
0 g
s
.68312 .83549 m .68417 .81646 L .69686 .82109 L p .707 .577 .707 r
F P
0 g
s
.21818 .76452 m .22022 .72648 L .19274 .72279 L p .707 .577 .707 r
F P
0 g
s
.2476 .81474 m .24865 .79571 L .2175 .79309 L p .707 .577 .707 r
F P
0 g
s
.24865 .79571 m .2476 .81474 L .27938 .81606 L p .707 .577 .707 r
F P
0 g
s
.27938 .81606 m .28043 .79703 L .24865 .79571 L p .707 .577 .707 r
F P
0 g
s
.19274 .72279 m .19071 .76083 L .21818 .76452 L p .707 .577 .707 r
F P
0 g
s
.2175 .79309 m .21645 .81212 L .2476 .81474 L p .707 .577 .707 r
F P
0 g
s
.28043 .79703 m .27938 .81606 L .30867 .81593 L p .707 .577 .707 r
F P
0 g
s
.30867 .81593 m .30972 .7969 L .28043 .79703 L p .707 .577 .707 r
F P
0 g
s
.31245 .73013 m .31041 .76817 L .33436 .76651 L p .707 .577 .707 r
F P
0 g
s
.33436 .76651 m .3364 .72847 L .31245 .73013 L p .707 .577 .707 r
F P
0 g
s
.17337 .63964 m .17152 .69625 L .19259 .70149 L p .707 .577 .707 r
F P
0 g
s
.21645 .81212 m .2175 .79309 L .19002 .78942 L p .707 .577 .707 r
F P
0 g
s
.19002 .78942 m .18897 .80845 L .21645 .81212 L p .707 .577 .707 r
F P
0 g
s
.19071 .76083 m .19274 .72279 L .17163 .71837 L p .707 .577 .707 r
F P
0 g
s
.68693 .74913 m .68489 .78717 L .66378 .78275 L p .707 .577 .707 r
F P
0 g
s
.66378 .78275 m .66582 .74471 L .68693 .74913 L p .707 .577 .707 r
F P
0 g
s
.30972 .7969 m .30867 .81593 L .33261 .81438 L p .707 .577 .707 r
F P
0 g
s
.33261 .81438 m .33366 .79535 L .30972 .7969 L p .707 .577 .707 r
F P
0 g
s
.17163 .71837 m .16959 .75641 L .19071 .76083 L p .707 .577 .707 r
F P
0 g
s
.66799 .6559 m .66614 .71252 L .63867 .70855 L p .707 .577 .707 r
F P
0 g
s
.63867 .70855 m .64052 .65193 L .66799 .6559 L p .707 .577 .707 r
F P
0 g
s
.17152 .69625 m .17337 .63964 L .16074 .63365 L p .707 .577 .707 r
F P
0 g
s
.18897 .80845 m .19002 .78942 L .16891 .78506 L p .707 .577 .707 r
F P
0 g
s
.60306 .28571 m .63896 .75481 L .62097 .73811 L p .707 .577 .707 r
F P
0 g
s
.62097 .73811 m .58508 .26902 L .60306 .28571 L p .707 .577 .707 r
F P
0 g
s
.68417 .81646 m .68312 .83549 L .66201 .83112 L p .707 .577 .707 r
F P
0 g
s
.66201 .83112 m .66306 .81209 L .68417 .81646 L p .707 .577 .707 r
F P
0 g
s
.16891 .78506 m .16786 .80409 L .18897 .80845 L p .707 .577 .707 r
F P
0 g
s
.16074 .63365 m .15889 .69027 L .17152 .69625 L p .707 .577 .707 r
F P
0 g
s
.16959 .75641 m .17163 .71837 L .15896 .71365 L p .707 .577 .707 r
F P
0 g
s
.33366 .79535 m .33261 .81438 L .34885 .81156 L p .707 .577 .707 r
F P
0 g
s
.34885 .81156 m .3499 .79253 L .33366 .79535 L p .707 .577 .707 r
F P
0 g
s
.15896 .71365 m .15692 .75169 L .16959 .75641 L p .707 .577 .707 r
F P
0 g
s
.15889 .69027 m .16074 .63365 L .15781 .62751 L p .707 .577 .707 r
F P
0 g
s
.16786 .80409 m .16891 .78506 L .15622 .78043 L p .707 .577 .707 r
F P
0 g
s
.36574 .76471 m .32984 .29562 L .35266 .27744 L p .707 .577 .707 r
F P
0 g
s
.32984 .29562 m .36574 .76471 L .35602 .78429 L p .707 .577 .707 r
F P
0 g
s
.66306 .81209 m .66201 .83112 L .63453 .82745 L p .707 .577 .707 r
F P
0 g
s
.63453 .82745 m .63558 .80842 L .66306 .81209 L p .707 .577 .707 r
F P
0 g
s
.15622 .78043 m .15518 .79946 L .16786 .80409 L p .707 .577 .707 r
F P
0 g
s
.15781 .62751 m .15596 .68412 L .15889 .69027 L p .707 .577 .707 r
F P
0 g
s
.58508 .26902 m .62097 .73811 L .59112 .72543 L p .707 .577 .707 r
F P
0 g
s
.59112 .72543 m .55522 .25633 L .58508 .26902 L p .707 .577 .707 r
F P
0 g
s
.63558 .80842 m .63453 .82745 L .60338 .82483 L p .707 .577 .707 r
F P
0 g
s
.15692 .75169 m .15896 .71365 L .15595 .7091 L p .707 .577 .707 r
F P
0 g
s
.3499 .79253 m .34885 .81156 L .35581 .80774 L p .707 .577 .707 r
F P
0 g
s
.35581 .80774 m .35686 .78871 L .3499 .79253 L p .707 .577 .707 r
F P
0 g
s
.15595 .7091 m .15391 .74714 L .15692 .75169 L p .707 .577 .707 r
F P
0 g
s
.15518 .79946 m .15622 .78043 L .15321 .77599 L p .707 .577 .707 r
F P
0 g
s
.15596 .68412 m .15781 .62751 L .16484 .6218 L p .707 .577 .707 r
F P
0 g
s
.15321 .77599 m .15217 .79502 L .15518 .79946 L p .707 .577 .707 r
F P
0 g
s
.35266 .27744 m .38856 .74654 L .36574 .76471 L p .707 .577 .707 r
F P
0 g
s
.38856 .74654 m .35266 .27744 L .38636 .26245 L p .707 .577 .707 r
F P
0 g
s
.16484 .6218 m .16299 .67841 L .15596 .68412 L p .707 .577 .707 r
F P
0 g
s
.55522 .25633 m .59112 .72543 L .55231 .71799 L p .707 .577 .707 r
F P
0 g
s
.55231 .71799 m .51641 .2489 L .55522 .25633 L p .707 .577 .707 r
F P
0 g
s
.15391 .74714 m .15595 .7091 L .16291 .70516 L p .707 .577 .707 r
F P
0 g
s
.35686 .78871 m .35581 .80774 L .3528 .8033 L p .707 .577 .707 r
F P
0 g
s
.3528 .8033 m .35385 .78427 L .35686 .78871 L p .707 .577 .707 r
F P
0 g
s
.16291 .70516 m .16087 .7432 L .15391 .74714 L p .707 .577 .707 r
F P
0 g
s
.15217 .79502 m .15321 .77599 L .16017 .77217 L p .707 .577 .707 r
F P
0 g
s
.42226 .73155 m .38636 .26245 L .42763 .25212 L p .707 .577 .707 r
F P
0 g
s
.38636 .26245 m .42226 .73155 L .38856 .74654 L p .707 .577 .707 r
F P
0 g
s
.16299 .67841 m .16484 .6218 L .18117 .61709 L p .707 .577 .707 r
F P
0 g
s
.16017 .77217 m .15912 .7912 L .15217 .79502 L p .707 .577 .707 r
F P
0 g
s
.51641 .2489 m .55231 .71799 L .50834 .71654 L p .707 .577 .707 r
F P
0 g
s
.50834 .71654 m .47245 .24745 L .51641 .2489 L p .707 .577 .707 r
F P
0 g
s
.18117 .61709 m .17932 .6737 L .16299 .67841 L p .707 .577 .707 r
F P
0 g
s
.46353 .72121 m .42763 .25212 L .47245 .24745 L p .707 .577 .707 r
F P
0 g
s
.42763 .25212 m .46353 .72121 L .42226 .73155 L p .707 .577 .707 r
F P
0 g
s
.47245 .24745 m .50834 .71654 L .46353 .72121 L p .707 .577 .707 r
F P
0 g
s
.16087 .7432 m .16291 .70516 L .17916 .70221 L p .707 .577 .707 r
F P
0 g
s
.35385 .78427 m .3528 .8033 L .34012 .79867 L p .707 .577 .707 r
F P
0 g
s
.34012 .79867 m .34116 .77964 L .35385 .78427 L p .707 .577 .707 r
F P
0 g
s
.17916 .70221 m .17712 .74026 L .16087 .7432 L p .707 .577 .707 r
F P
0 g
s
.17932 .6737 m .18117 .61709 L .20518 .61383 L p .707 .577 .707 r
F P
0 g
s
.15912 .7912 m .16017 .77217 L .17641 .76935 L p .707 .577 .707 r
F P
0 g
s
.17641 .76935 m .17536 .78838 L .15912 .7912 L p .707 .577 .707 r
F P
0 g
s
.34392 .71231 m .34188 .75036 L .32077 .74594 L p .707 .577 .707 r
F P
0 g
s
.32077 .74594 m .32281 .70789 L .34392 .71231 L p .707 .577 .707 r
F P
0 g
s
.20518 .61383 m .20333 .67045 L .17932 .6737 L p .707 .577 .707 r
F P
0 g
s
.32498 .61909 m .32313 .67571 L .29567 .67173 L p .707 .577 .707 r
F P
0 g
s
.29567 .67173 m .29752 .61512 L .32498 .61909 L p .707 .577 .707 r
F P
0 g
s
.17712 .74026 m .17916 .70221 L .20311 .70055 L p .707 .577 .707 r
F P
0 g
s
.20333 .67045 m .20518 .61383 L .23453 .61235 L p .707 .577 .707 r
F P
0 g
s
.34116 .77964 m .34012 .79867 L .319 .79431 L p .707 .577 .707 r
F P
0 g
s
.319 .79431 m .32005 .77528 L .34116 .77964 L p .707 .577 .707 r
F P
0 g
s
.20311 .70055 m .20107 .7386 L .17712 .74026 L p .707 .577 .707 r
F P
0 g
s
.29752 .61512 m .29567 .67173 L .2645 .66941 L p .707 .577 .707 r
F P
0 g
s
.2645 .66941 m .26635 .6128 L .29752 .61512 L p .707 .577 .707 r
F P
0 g
s
.17536 .78838 m .17641 .76935 L .20035 .7678 L p .707 .577 .707 r
F P
0 g
s
.23453 .61235 m .23268 .66897 L .20333 .67045 L p .707 .577 .707 r
F P
0 g
s
.20035 .7678 m .1993 .78683 L .17536 .78838 L p .707 .577 .707 r
F P
0 g
s
.32281 .70789 m .32077 .74594 L .2933 .74224 L p .707 .577 .707 r
F P
0 g
s
.2933 .74224 m .29534 .7042 L .32281 .70789 L p .707 .577 .707 r
F P
0 g
s
.73143 .64853 m .73328 .59192 L .70212 .5896 L p .707 .577 .707 r
F P
0 g
s
.73328 .59192 m .73143 .64853 L .76325 .64898 L p .707 .577 .707 r
F P
0 g
s
.76325 .64898 m .7651 .59236 L .73328 .59192 L p .707 .577 .707 r
F P
0 g
s
.23268 .66897 m .23453 .61235 L .26635 .6128 L p .707 .577 .707 r
F P
0 g
s
.7651 .59236 m .76325 .64898 L .7926 .6475 L p .707 .577 .707 r
F P
0 g
s
.7926 .6475 m .79445 .59088 L .7651 .59236 L p .707 .577 .707 r
F P
0 g
s
.26635 .6128 m .2645 .66941 L .23268 .66897 L p .707 .577 .707 r
F P
0 g
s
.20107 .7386 m .20311 .70055 L .2324 .70034 L p .707 .577 .707 r
F P
0 g
s
.70027 .64621 m .70212 .5896 L .67465 .58562 L p .707 .577 .707 r
F P
0 g
s
.70212 .5896 m .70027 .64621 L .73143 .64853 L p .707 .577 .707 r
F P
0 g
s
.32005 .77528 m .319 .79431 L .29152 .79063 L p .707 .577 .707 r
F P
0 g
s
.29152 .79063 m .29257 .7716 L .32005 .77528 L p .707 .577 .707 r
F P
0 g
s
.2324 .70034 m .23036 .73839 L .20107 .7386 L p .707 .577 .707 r
F P
0 g
s
.29534 .7042 m .2933 .74224 L .26214 .73964 L p .707 .577 .707 r
F P
0 g
s
.26214 .73964 m .26418 .7016 L .29534 .7042 L p .707 .577 .707 r
F P
0 g
s
.72955 .7017 m .73159 .66366 L .70043 .66106 L p .707 .577 .707 r
F P
0 g
s
.73159 .66366 m .72955 .7017 L .76133 .70296 L p .707 .577 .707 r
F P
0 g
s
.76133 .70296 m .76337 .66491 L .73159 .66366 L p .707 .577 .707 r
F P
0 g
s
.79445 .59088 m .7926 .6475 L .81661 .64424 L p .707 .577 .707 r
F P
0 g
s
.81661 .64424 m .81846 .58763 L .79445 .59088 L p .707 .577 .707 r
F P
0 g
s
.67465 .58562 m .6728 .64224 L .70027 .64621 L p .707 .577 .707 r
F P
0 g
s
.1993 .78683 m .20035 .7678 L .22964 .76767 L p .707 .577 .707 r
F P
0 g
s
.76337 .66491 m .76133 .70296 L .79063 .70275 L p .707 .577 .707 r
F P
0 g
s
.79063 .70275 m .79266 .6647 L .76337 .66491 L p .707 .577 .707 r
F P
0 g
s
.23036 .73839 m .2324 .70034 L .26418 .7016 L p .707 .577 .707 r
F P
0 g
s
.22964 .76767 m .22859 .7867 L .1993 .78683 L p .707 .577 .707 r
F P
0 g
s
.70043 .66106 m .6984 .6991 L .72955 .7017 L p .707 .577 .707 r
F P
0 g
s
.26418 .7016 m .26214 .73964 L .23036 .73839 L p .707 .577 .707 r
F P
0 g
s
.6984 .6991 m .70043 .66106 L .67296 .65736 L p .707 .577 .707 r
F P
0 g
s
.6728 .64224 m .67465 .58562 L .65358 .58039 L p .707 .577 .707 r
F P
0 g
s
.72782 .73953 m .72886 .7205 L .69771 .71788 L p .707 .577 .707 r
F P
0 g
s
.72886 .7205 m .72782 .73953 L .75959 .74084 L p .707 .577 .707 r
F P
0 g
s
.75959 .74084 m .76064 .72181 L .72886 .7205 L p .707 .577 .707 r
F P
0 g
s
.69771 .71788 m .69666 .73691 L .72782 .73953 L p .707 .577 .707 r
F P
0 g
s
.29257 .7716 m .29152 .79063 L .26037 .78801 L p .707 .577 .707 r
F P
0 g
s
.26037 .78801 m .26142 .76898 L .29257 .7716 L p .707 .577 .707 r
F P
0 g
s
.67296 .65736 m .67092 .69541 L .6984 .6991 L p .707 .577 .707 r
F P
0 g
s
.76064 .72181 m .75959 .74084 L .78889 .74072 L p .707 .577 .707 r
F P
0 g
s
.78889 .74072 m .78993 .72169 L .76064 .72181 L p .707 .577 .707 r
F P
0 g
s
.22859 .7867 m .22964 .76767 L .26142 .76898 L p .707 .577 .707 r
F P
0 g
s
.69666 .73691 m .69771 .71788 L .67023 .71421 L p .707 .577 .707 r
F P
0 g
s
.79266 .6647 m .79063 .70275 L .81457 .70109 L p .707 .577 .707 r
F P
0 g
s
.81457 .70109 m .81661 .66304 L .79266 .6647 L p .707 .577 .707 r
F P
0 g
s
.26142 .76898 m .26037 .78801 L .22859 .7867 L p .707 .577 .707 r
F P
0 g
s
.65358 .58039 m .65173 .63701 L .6728 .64224 L p .707 .577 .707 r
F P
0 g
s
.67023 .71421 m .66919 .73324 L .69666 .73691 L p .707 .577 .707 r
F P
0 g
s
.81846 .58763 m .81661 .64424 L .83294 .63953 L p .707 .577 .707 r
F P
0 g
s
.83294 .63953 m .83479 .58292 L .81846 .58763 L p .707 .577 .707 r
F P
0 g
s
.67092 .69541 m .67296 .65736 L .65185 .65294 L p .707 .577 .707 r
F P
0 g
s
.78993 .72169 m .78889 .74072 L .81282 .73917 L p .707 .577 .707 r
F P
0 g
s
.81282 .73917 m .81387 .72014 L .78993 .72169 L p .707 .577 .707 r
F P
0 g
s
.65185 .65294 m .64981 .69099 L .67092 .69541 L p .707 .577 .707 r
F P
0 g
s
.65173 .63701 m .65358 .58039 L .64095 .57441 L p .707 .577 .707 r
F P
0 g
s
.66919 .73324 m .67023 .71421 L .64912 .70984 L p .707 .577 .707 r
F P
0 g
s
.64912 .70984 m .64807 .72887 L .66919 .73324 L p .707 .577 .707 r
F P
0 g
s
.81661 .66304 m .81457 .70109 L .83082 .69814 L p .707 .577 .707 r
F P
0 g
s
.83082 .69814 m .83286 .6601 L .81661 .66304 L p .707 .577 .707 r
F P
0 g
s
.64095 .57441 m .6391 .63102 L .65173 .63701 L p .707 .577 .707 r
F P
0 g
s
.81387 .72014 m .81282 .73917 L .82907 .73635 L p .707 .577 .707 r
F P
0 g
s
.82907 .73635 m .83011 .71732 L .81387 .72014 L p .707 .577 .707 r
F P
0 g
s
.64981 .69099 m .65185 .65294 L .63917 .64823 L p .707 .577 .707 r
F P
0 g
s
.83479 .58292 m .83294 .63953 L .83998 .63382 L p .707 .577 .707 r
F P
0 g
s
.83998 .63382 m .84183 .57721 L .83479 .58292 L p .707 .577 .707 r
F P
0 g
s
.63917 .64823 m .63713 .68627 L .64981 .69099 L p .707 .577 .707 r
F P
0 g
s
.64807 .72887 m .64912 .70984 L .63644 .70521 L p .707 .577 .707 r
F P
0 g
s
.63644 .70521 m .63539 .72424 L .64807 .72887 L p .707 .577 .707 r
F P
0 g
s
.6391 .63102 m .64095 .57441 L .63802 .56826 L p .707 .577 .707 r
F P
0 g
s
.83286 .6601 m .83082 .69814 L .83778 .6942 L p .707 .577 .707 r
F P
0 g
s
.83778 .6942 m .83982 .65616 L .83286 .6601 L p .707 .577 .707 r
F P
0 g
s
.63802 .56826 m .63617 .62488 L .6391 .63102 L p .707 .577 .707 r
F P
0 g
s
.83011 .71732 m .82907 .73635 L .83602 .73253 L p .707 .577 .707 r
F P
0 g
s
.83602 .73253 m .83707 .7135 L .83011 .71732 L p .707 .577 .707 r
F P
0 g
s
.63713 .68627 m .63917 .64823 L .63616 .64367 L p .707 .577 .707 r
F P
0 g
s
.84183 .57721 m .83998 .63382 L .83704 .62767 L p .707 .577 .707 r
F P
0 g
s
.83704 .62767 m .83889 .57106 L .84183 .57721 L p .707 .577 .707 r
F P
0 g
s
.63616 .64367 m .63412 .68172 L .63713 .68627 L p .707 .577 .707 r
F P
0 g
s
.63539 .72424 m .63644 .70521 L .63343 .70077 L p .707 .577 .707 r
F P
0 g
s
.63343 .70077 m .63238 .7198 L .63539 .72424 L p .707 .577 .707 r
F P
0 g
s
.63617 .62488 m .63802 .56826 L .64506 .56255 L p .707 .577 .707 r
F P
0 g
s
.83982 .65616 m .83778 .6942 L .83478 .68965 L p .707 .577 .707 r
F P
0 g
s
.83478 .68965 m .83682 .65161 L .83982 .65616 L p .707 .577 .707 r
F P
0 g
s
.64506 .56255 m .64321 .61917 L .63617 .62488 L p .707 .577 .707 r
F P
0 g
s
.83707 .7135 m .83602 .73253 L .83301 .72809 L p .707 .577 .707 r
F P
0 g
s
.83301 .72809 m .83406 .70906 L .83707 .7135 L p .707 .577 .707 r
F P
0 g
s
.63412 .68172 m .63616 .64367 L .64313 .63973 L p .707 .577 .707 r
F P
0 g
s
.83889 .57106 m .83704 .62767 L .82442 .62169 L p .707 .577 .707 r
F P
0 g
s
.82442 .62169 m .82627 .56508 L .83889 .57106 L p .707 .577 .707 r
F P
0 g
s
.64313 .63973 m .64109 .67778 L .63412 .68172 L p .707 .577 .707 r
F P
0 g
s
.63238 .7198 m .63343 .70077 L .64038 .69695 L p .707 .577 .707 r
F P
0 g
s
.38842 .61172 m .39027 .5551 L .35911 .55278 L p .707 .577 .707 r
F P
0 g
s
.39027 .5551 m .38842 .61172 L .42024 .61216 L p .707 .577 .707 r
F P
0 g
s
.42024 .61216 m .42209 .55554 L .39027 .5551 L p .707 .577 .707 r
F P
0 g
s
.64038 .69695 m .63933 .71598 L .63238 .7198 L p .707 .577 .707 r
F P
0 g
s
.42209 .55554 m .42024 .61216 L .44959 .61068 L p .707 .577 .707 r
F P
0 g
s
.44959 .61068 m .45144 .55407 L .42209 .55554 L p .707 .577 .707 r
F P
0 g
s
.64321 .61917 m .64506 .56255 L .66138 .55784 L p .707 .577 .707 r
F P
0 g
s
.35726 .6094 m .35911 .55278 L .33164 .54881 L p .707 .577 .707 r
F P
0 g
s
.35911 .55278 m .35726 .6094 L .38842 .61172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83682 .65161 m .83478 .68965 L .8221 .68493 L p .707 .577 .707 r
F P
0 g
s
.8221 .68493 m .82414 .64689 L .83682 .65161 L p .707 .577 .707 r
F P
0 g
s
.66138 .55784 m .65953 .61445 L .64321 .61917 L p .707 .577 .707 r
F P
0 g
s
.38654 .66489 m .38858 .62684 L .35742 .62424 L p .707 .577 .707 r
F P
0 g
s
.38858 .62684 m .38654 .66489 L .41832 .66614 L p .707 .577 .707 r
F P
0 g
s
.41832 .66614 m .42036 .6281 L .38858 .62684 L p .707 .577 .707 r
F P
0 g
s
.45144 .55407 m .44959 .61068 L .4736 .60743 L p .707 .577 .707 r
F P
0 g
s
.4736 .60743 m .47545 .55081 L .45144 .55407 L p .707 .577 .707 r
F P
0 g
s
.33164 .54881 m .32979 .60542 L .35726 .6094 L p .707 .577 .707 r
F P
0 g
s
.42036 .6281 m .41832 .66614 L .44762 .66593 L p .707 .577 .707 r
F P
0 g
s
.44762 .66593 m .44965 .62789 L .42036 .6281 L p .707 .577 .707 r
F P
0 g
s
.83406 .70906 m .83301 .72809 L .82033 .72346 L p .707 .577 .707 r
F P
0 g
s
.82033 .72346 m .82138 .70443 L .83406 .70906 L p .707 .577 .707 r
F P
0 g
s
.35742 .62424 m .35539 .66228 L .38654 .66489 L p .707 .577 .707 r
F P
0 g
s
.64109 .67778 m .64313 .63973 L .65938 .63679 L p .707 .577 .707 r
F P
0 g
s
.82627 .56508 m .82442 .62169 L .80334 .61646 L p .707 .577 .707 r
F P
0 g
s
.80334 .61646 m .80519 .55984 L .82627 .56508 L p .707 .577 .707 r
F P
0 g
s
.35539 .66228 m .35742 .62424 L .32995 .62055 L p .707 .577 .707 r
F P
0 g
s
.32979 .60542 m .33164 .54881 L .31057 .54358 L p .707 .577 .707 r
F P
0 g
s
.38481 .70271 m .38585 .68368 L .3547 .68106 L p .707 .577 .707 r
F P
0 g
s
.38585 .68368 m .38481 .70271 L .41658 .70403 L p .707 .577 .707 r
F P
0 g
s
.41658 .70403 m .41763 .685 L .38585 .68368 L p .707 .577 .707 r
F P
0 g
s
.65938 .63679 m .65734 .67483 L .64109 .67778 L p .707 .577 .707 r
F P
0 g
s
.3547 .68106 m .35365 .70009 L .38481 .70271 L p .707 .577 .707 r
F P
0 g
s
.32995 .62055 m .32791 .65859 L .35539 .66228 L p .707 .577 .707 r
F P
0 g
s
.41763 .685 m .41658 .70403 L .44588 .7039 L p .707 .577 .707 r
F P
0 g
s
.44588 .7039 m .44692 .68487 L .41763 .685 L p .707 .577 .707 r
F P
0 g
s
.63933 .71598 m .64038 .69695 L .65662 .69413 L p .707 .577 .707 r
F P
0 g
s
.35365 .70009 m .3547 .68106 L .32722 .67739 L p .707 .577 .707 r
F P
0 g
s
.44965 .62789 m .44762 .66593 L .47156 .66427 L p .707 .577 .707 r
F P
0 g
s
.47156 .66427 m .4736 .62623 L .44965 .62789 L p .707 .577 .707 r
F P
0 g
s
.65953 .61445 m .66138 .55784 L .6854 .55458 L p .707 .577 .707 r
F P
0 g
s
.65662 .69413 m .65558 .71316 L .63933 .71598 L p .707 .577 .707 r
F P
0 g
s
.31057 .54358 m .30872 .60019 L .32979 .60542 L p .707 .577 .707 r
F P
0 g
s
.32722 .67739 m .32618 .69642 L .35365 .70009 L p .707 .577 .707 r
F P
0 g
s
.47545 .55081 m .4736 .60743 L .48993 .60272 L p .707 .577 .707 r
F P
0 g
s
.48993 .60272 m .49178 .5461 L .47545 .55081 L p .707 .577 .707 r
F P
0 g
s
.32791 .65859 m .32995 .62055 L .30884 .61613 L p .707 .577 .707 r
F P
0 g
s
.82414 .64689 m .8221 .68493 L .80099 .68051 L p .707 .577 .707 r
F P
0 g
s
.80099 .68051 m .80303 .64247 L .82414 .64689 L p .707 .577 .707 r
F P
0 g
s
.44692 .68487 m .44588 .7039 L .46981 .70235 L p .707 .577 .707 r
F P
0 g
s
.46981 .70235 m .47086 .68332 L .44692 .68487 L p .707 .577 .707 r
F P
0 g
s
.6854 .55458 m .68355 .6112 L .65953 .61445 L p .707 .577 .707 r
F P
0 g
s
.30884 .61613 m .3068 .65417 L .32791 .65859 L p .707 .577 .707 r
F P
0 g
s
.80519 .55984 m .80334 .61646 L .77588 .61249 L p .707 .577 .707 r
F P
0 g
s
.77588 .61249 m .77773 .55587 L .80519 .55984 L p .707 .577 .707 r
F P
0 g
s
.30872 .60019 m .31057 .54358 L .29794 .53759 L p .707 .577 .707 r
F P
0 g
s
.32618 .69642 m .32722 .67739 L .30611 .67303 L p .707 .577 .707 r
F P
0 g
s
.82138 .70443 m .82033 .72346 L .79922 .71909 L p .707 .577 .707 r
F P
0 g
s
.79922 .71909 m .80026 .70006 L .82138 .70443 L p .707 .577 .707 r
F P
0 g
s
.65734 .67483 m .65938 .63679 L .68332 .63513 L p .707 .577 .707 r
F P
0 g
s
.30611 .67303 m .30506 .69206 L .32618 .69642 L p .707 .577 .707 r
F P
0 g
s
.68355 .6112 m .6854 .55458 L .71475 .55311 L p .707 .577 .707 r
F P
0 g
s
.4736 .62623 m .47156 .66427 L .48781 .66133 L p .707 .577 .707 r
F P
0 g
s
.48781 .66133 m .48985 .62328 L .4736 .62623 L p .707 .577 .707 r
F P
0 g
s
.68332 .63513 m .68128 .67317 L .65734 .67483 L p .707 .577 .707 r
F P
0 g
s
.29794 .53759 m .29609 .59421 L .30872 .60019 L p .707 .577 .707 r
F P
0 g
s
.65558 .71316 m .65662 .69413 L .68056 .69258 L p .707 .577 .707 r
F P
0 g
s
.68056 .69258 m .67952 .71161 L .65558 .71316 L p .707 .577 .707 r
F P
0 g
s
.77773 .55587 m .77588 .61249 L .74471 .61017 L p .707 .577 .707 r
F P
0 g
s
.74471 .61017 m .74656 .55355 L .77773 .55587 L p .707 .577 .707 r
F P
0 g
s
.47086 .68332 m .46981 .70235 L .48606 .69953 L p .707 .577 .707 r
F P
0 g
s
.48606 .69953 m .4871 .6805 L .47086 .68332 L p .707 .577 .707 r
F P
0 g
s
.3068 .65417 m .30884 .61613 L .29616 .61141 L p .707 .577 .707 r
F P
0 g
s
.80303 .64247 m .80099 .68051 L .77351 .67682 L p .707 .577 .707 r
F P
0 g
s
.77351 .67682 m .77555 .63878 L .80303 .64247 L p .707 .577 .707 r
F P
0 g
s
.71475 .55311 m .7129 .60972 L .68355 .6112 L p .707 .577 .707 r
F P
0 g
s
.49178 .5461 m .48993 .60272 L .49697 .59701 L p .707 .577 .707 r
F P
0 g
s
.49697 .59701 m .49882 .54039 L .49178 .5461 L p .707 .577 .707 r
F P
0 g
s
.7129 .60972 m .71475 .55311 L .74656 .55355 L p .707 .577 .707 r
F P
0 g
s
.29616 .61141 m .29412 .64945 L .3068 .65417 L p .707 .577 .707 r
F P
0 g
s
.74656 .55355 m .74471 .61017 L .7129 .60972 L p .707 .577 .707 r
F P
0 g
s
.68128 .67317 m .68332 .63513 L .71262 .63492 L p .707 .577 .707 r
F P
0 g
s
.30506 .69206 m .30611 .67303 L .29343 .6684 L p .707 .577 .707 r
F P
0 g
s
.80026 .70006 m .79922 .71909 L .77174 .71542 L p .707 .577 .707 r
F P
0 g
s
.77174 .71542 m .77278 .69639 L .80026 .70006 L p .707 .577 .707 r
F P
0 g
s
.29343 .6684 m .29238 .68743 L .30506 .69206 L p .707 .577 .707 r
F P
0 g
s
.71262 .63492 m .71058 .67296 L .68128 .67317 L p .707 .577 .707 r
F P
0 g
s
.29609 .59421 m .29794 .53759 L .29501 .53144 L p .707 .577 .707 r
F P
0 g
s
.67952 .71161 m .68056 .69258 L .70986 .69246 L p .707 .577 .707 r
F P
0 g
s
.77555 .63878 m .77351 .67682 L .74236 .67422 L p .707 .577 .707 r
F P
0 g
s
.74236 .67422 m .7444 .63617 L .77555 .63878 L p .707 .577 .707 r
F P
0 g
s
.48985 .62328 m .48781 .66133 L .49477 .65739 L p .707 .577 .707 r
F P
0 g
s
.49477 .65739 m .49681 .61934 L .48985 .62328 L p .707 .577 .707 r
F P
0 g
s
.70986 .69246 m .70881 .71149 L .67952 .71161 L p .707 .577 .707 r
F P
0 g
s
.71058 .67296 m .71262 .63492 L .7444 .63617 L p .707 .577 .707 r
F P
0 g
s
.7444 .63617 m .74236 .67422 L .71058 .67296 L p .707 .577 .707 r
F P
0 g
s
.29501 .53144 m .29316 .58806 L .29609 .59421 L p .707 .577 .707 r
F P
0 g
s
.77278 .69639 m .77174 .71542 L .74058 .7128 L p .707 .577 .707 r
F P
0 g
s
.74058 .7128 m .74163 .69377 L .77278 .69639 L p .707 .577 .707 r
F P
0 g
s
.4871 .6805 m .48606 .69953 L .49301 .69571 L p .707 .577 .707 r
F P
0 g
s
.49301 .69571 m .49406 .67668 L .4871 .6805 L p .707 .577 .707 r
F P
0 g
s
.29412 .64945 m .29616 .61141 L .29315 .60686 L p .707 .577 .707 r
F P
0 g
s
.70881 .71149 m .70986 .69246 L .74163 .69377 L p .707 .577 .707 r
F P
0 g
s
.74163 .69377 m .74058 .7128 L .70881 .71149 L p .707 .577 .707 r
F P
0 g
s
.49882 .54039 m .49697 .59701 L .49403 .59086 L p .707 .577 .707 r
F P
0 g
s
.49403 .59086 m .49588 .53424 L .49882 .54039 L p .707 .577 .707 r
F P
0 g
s
.29315 .60686 m .29111 .6449 L .29412 .64945 L p .707 .577 .707 r
F P
0 g
s
.29238 .68743 m .29343 .6684 L .29042 .66396 L p .707 .577 .707 r
F P
0 g
s
.29042 .66396 m .28937 .68299 L .29238 .68743 L p .707 .577 .707 r
F P
0 g
s
.29316 .58806 m .29501 .53144 L .30205 .52574 L p .707 .577 .707 r
F P
0 g
s
.49681 .61934 m .49477 .65739 L .49177 .65283 L p .707 .577 .707 r
F P
0 g
s
.49177 .65283 m .49381 .61479 L .49681 .61934 L p .707 .577 .707 r
F P
0 g
s
.30205 .52574 m .3002 .58235 L .29316 .58806 L p .707 .577 .707 r
F P
0 g
s
.49406 .67668 m .49301 .69571 L .49 .69127 L p .707 .577 .707 r
F P
0 g
s
.49 .69127 m .49105 .67224 L .49406 .67668 L p .707 .577 .707 r
F P
0 g
s
.29111 .6449 m .29315 .60686 L .30012 .60292 L p .707 .577 .707 r
F P
0 g
s
.49588 .53424 m .49403 .59086 L .48141 .58488 L p .707 .577 .707 r
F P
0 g
s
.48141 .58488 m .48326 .52826 L .49588 .53424 L p .707 .577 .707 r
F P
0 g
s
.30012 .60292 m .29808 .64096 L .29111 .6449 L p .707 .577 .707 r
F P
0 g
s
.28937 .68299 m .29042 .66396 L .29737 .66014 L p .707 .577 .707 r
F P
0 g
s
.29737 .66014 m .29632 .67917 L .28937 .68299 L p .707 .577 .707 r
F P
0 g
s
.3002 .58235 m .30205 .52574 L .31837 .52102 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49381 .61479 m .49177 .65283 L .47909 .64812 L p .707 .577 .707 r
F P
0 g
s
.47909 .64812 m .48113 .61007 L .49381 .61479 L p .707 .577 .707 r
F P
0 g
s
.31837 .52102 m .31652 .57764 L .3002 .58235 L p .707 .577 .707 r
F P
0 g
s
.49105 .67224 m .49 .69127 L .47732 .68664 L p .707 .577 .707 r
F P
0 g
s
.47732 .68664 m .47837 .66761 L .49105 .67224 L p .707 .577 .707 r
F P
0 g
s
.29808 .64096 m .30012 .60292 L .31637 .59997 L p .707 .577 .707 r
F P
0 g
s
.48326 .52826 m .48141 .58488 L .46033 .57964 L p .707 .577 .707 r
F P
0 g
s
.46033 .57964 m .46218 .52303 L .48326 .52826 L p .707 .577 .707 r
F P
0 g
s
.31637 .59997 m .31433 .63802 L .29808 .64096 L p .707 .577 .707 r
F P
0 g
s
.29632 .67917 m .29737 .66014 L .31361 .65731 L p .707 .577 .707 r
F P
0 g
s
.31652 .57764 m .31837 .52102 L .34239 .51777 L p .707 .577 .707 r
F P
0 g
s
.31361 .65731 m .31257 .67634 L .29632 .67917 L p .707 .577 .707 r
F P
0 g
s
.48113 .61007 m .47909 .64812 L .45798 .6437 L p .707 .577 .707 r
F P
0 g
s
.45798 .6437 m .46002 .60565 L .48113 .61007 L p .707 .577 .707 r
F P
0 g
s
.34239 .51777 m .34054 .57438 L .31652 .57764 L p .707 .577 .707 r
F P
0 g
s
.46218 .52303 m .46033 .57964 L .43287 .57567 L p .707 .577 .707 r
F P
0 g
s
.43287 .57567 m .43472 .51905 L .46218 .52303 L p .707 .577 .707 r
F P
0 g
s
.47837 .66761 m .47732 .68664 L .4562 .68228 L p .707 .577 .707 r
F P
0 g
s
.4562 .68228 m .45725 .66325 L .47837 .66761 L p .707 .577 .707 r
F P
0 g
s
.31433 .63802 m .31637 .59997 L .34031 .59831 L p .707 .577 .707 r
F P
0 g
s
.34054 .57438 m .34239 .51777 L .37174 .51629 L p .707 .577 .707 r
F P
0 g
s
.34031 .59831 m .33827 .63636 L .31433 .63802 L p .707 .577 .707 r
F P
0 g
s
.31257 .67634 m .31361 .65731 L .33755 .65577 L p .707 .577 .707 r
F P
0 g
s
.33755 .65577 m .33651 .6748 L .31257 .67634 L p .707 .577 .707 r
F P
0 g
s
.43472 .51905 m .43287 .57567 L .4017 .57335 L p .707 .577 .707 r
F P
0 g
s
.4017 .57335 m .40355 .51673 L .43472 .51905 L p .707 .577 .707 r
F P
0 g
s
.46002 .60565 m .45798 .6437 L .4305 .64 L p .707 .577 .707 r
F P
0 g
s
.4305 .64 m .43254 .60196 L .46002 .60565 L p .707 .577 .707 r
F P
0 g
s
.37174 .51629 m .36989 .57291 L .34054 .57438 L p .707 .577 .707 r
F P
0 g
s
.36989 .57291 m .37174 .51629 L .40355 .51673 L p .707 .577 .707 r
F P
0 g
s
.40355 .51673 m .4017 .57335 L .36989 .57291 L p .707 .577 .707 r
F P
0 g
s
.33827 .63636 m .34031 .59831 L .36961 .5981 L p .707 .577 .707 r
F P
0 g
s
.45725 .66325 m .4562 .68228 L .42873 .6786 L p .707 .577 .707 r
F P
0 g
s
.42873 .6786 m .42977 .65957 L .45725 .66325 L p .707 .577 .707 r
F P
0 g
s
.36961 .5981 m .36757 .63615 L .33827 .63636 L p .707 .577 .707 r
F P
0 g
s
.33651 .6748 m .33755 .65577 L .36684 .65564 L p .707 .577 .707 r
F P
0 g
s
.43254 .60196 m .4305 .64 L .39935 .6374 L p .707 .577 .707 r
F P
0 g
s
.39935 .6374 m .40139 .59936 L .43254 .60196 L p .707 .577 .707 r
F P
0 g
s
.36684 .65564 m .3658 .67467 L .33651 .6748 L p .707 .577 .707 r
F P
0 g
s
.36757 .63615 m .36961 .5981 L .40139 .59936 L p .707 .577 .707 r
F P
0 g
s
.40139 .59936 m .39935 .6374 L .36757 .63615 L p .707 .577 .707 r
F P
0 g
s
.42977 .65957 m .42873 .6786 L .39757 .67598 L p .707 .577 .707 r
F P
0 g
s
.39757 .67598 m .39862 .65695 L .42977 .65957 L p .707 .577 .707 r
F P
0 g
s
.3658 .67467 m .36684 .65564 L .39862 .65695 L p .707 .577 .707 r
F P
0 g
s
.39862 .65695 m .39757 .67598 L .3658 .67467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolE0028Ool007Qoo`P000IJEP03001JEUYF00UJEP03001JEUYF00H0089oo`00M7oo
100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01UYF1000OWoo001`Ool40005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000O7oo001/Ool40009FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P00NWoo001ZOol200000eYF
001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001h
Ool006Qoo`8000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8007Ioo`00IWoo0P001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01eYF00<007ooOol0Lgoo001TOol20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00Oomo
o`1bOol006=oo`8000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001oogoo075oo`00HWoo00<005YF000025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02EYF00<007ooOol0L7oo001P
Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool005moo`03001JEUYF009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EW5oo`00GWoo00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYFLGoo001MOol00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005eoo`03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0KWoo001LOol20007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1^Ool005]oo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06io
o`00Fgoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0KWoo001KOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1]Ool005aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06eoo`00G7oo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00KWoo001LOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0KGoo001LOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YFKWoo001MOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVioo`00GGoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03
001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001^Ool005eoo`03001JEP0000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00GGoo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1/Ool0
05eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00KGoo001MOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<0
05YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1[Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]o
o`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00K7oo001NOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo
001OOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005moo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000=JEQ4000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo001HOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001EOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001[Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001[Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Jgoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1Y
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00]ooaX004Aoo`00Dgoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000fOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`02Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000bOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000=JEP04001JEUYFFUH8
00000eYF001JEP06FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005=oo`03001JEP00009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEPD000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2
0002Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP05
001oo`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOolO00000eYF001JEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]
Ool005Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80000
0eYF001JEP05FUH00`00FUIJEP030002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool0
05=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH;0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP050004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00Ool005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00=goo7@0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF008002ioo`00;Woo0`000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH300001EYF
000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF10000UYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJ
EP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP800003Ool005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEP0000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEP00FUH00P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP80009oo`800003FUH005YF00AJEQX000QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002FUH70007FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`090003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80000
0eYF001JEP05FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Ool0000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL00003FUH0
05YF0080035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000<Woo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1@0000=JEP0000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF0000800025YF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH=0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000=JEP04001JEUYFFUHJ0002FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000UYF1P00
25YF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH00UYF00@005YFFUIJEQ0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000015YF001JEUYF7P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP00009JEPd00003FUH005YF00EJ
EPl000IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH40005
FUH01000FUIJEUYF200015YF00<005YF00000P001EYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF1`000eYF00@005YFFUIJEP8002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF009JEQ/000=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00;Woo000/
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH50002FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000^Ool002eoo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYFFUH40002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF000000020003FUH@00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000^Ool002moo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEP00008000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPT00003FUH005YF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02ioo`00<Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1@0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH01EYF00<005YFFUH01000;goo000aOolN00000eYF001JEP06FUH00`00FUIJEP04FUHC
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP/003=oo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEQ80009oo`04001JEUYF0006FUH00`00FUIJEP02FUH@0000
0eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH70005Ool01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;goo000/Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP060002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00MJEPT000IJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF
001JEP040004FUH5000015YF001JEUYF0P002Goo0`000goo200015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUIJEPH000QJEPX000UJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUHC000:Ool70003FUH00`00FUIJEP02
000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00MJEPH000=JEP03001J
EUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUHE
0002FUH40002FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP004EYF00<0
05YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02EYF0P000UYF1@001UYF00@005YFFUIJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUH005YF000AFUH00`00FUH00003000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20007FUH20004
FUH01000FUIJEUYF0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000@FUH30003FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH20008FUH400000eYF001JEP03FUH00`00FUIJEP02FUH80004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
02moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000>FUH20006FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20008FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`00<7oo000[Ool00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000]JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP8000QJEP8000AJEP04001JEUYFFUH20003FUH01000FUIJEUYF1P001Woo8000<goo000[Ool00`00
FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJ
EP03FUH01000FUIJEP002eYF0`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P002EYF00<005YFFUH00eYF00D005YFFUH005YF00P005ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YF
FUH000UJEP80009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000MJEP03001JEP00008005]oo`00;7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEPD00003FUH005YF00IJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000MJEP03001JEUYF
009JEP<005Qoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EWoo000_Ool40003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF
00=JEP03001JEUYF008005Eoo`00<goo1`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP<000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0006FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol003Yoo`P000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH90002FUH01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF0P0025YF00<005YFFUH015YF00@005YF000000EJEP03001J
EUYF00AJEP03001JEUYF008005Eoo`00<7oo;0002Goo0UYF00@005YFFUH000QJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP03001JEUYF00AJEP04001J
EUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000]Ool30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000>Ool00eYF001JEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20008FUH0
0`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000[Ool30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0027oo00=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0100017oo00=JEP00FUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000Woo0P000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP0000001P000eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00@005YF
FUIJEQ0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00@000=J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP@000=JEP8005Eoo`00:goo
00<005YF000030002goo4@0015YF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000005Eo
o`00:goo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPP001Aoo`H000AJEP04001JEUYFFUH30003
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3001EOol002]oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF009JEQd00003
FUH005YF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0005Eoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF0`0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP03001JEUYF00@005Ioo`00;Woo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF01<005Yoo`00<Woo1`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF
001oo`0000=JEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP80
00QJEP/006Eoo`00>Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH010000goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH6001OOol0049oo`T0
00AJEP03001JEUYF00EJEP04001JEUYFFUH60008Ool00`00FUH00008FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP05
FUH00`00FUH00002001LOol004]ooa0000moo`8000QJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF009JEP<000QJEP03001JEUYF00EJEP03001JEUYF
009JEP<005Uoo`00Jgoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00P000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000P00EWoo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo
001`Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH3000;
Ool80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo001cOol40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH01000FUIJEUYF1P000UYF2@002goo1`000eYF00<005YFFUH00P00EWoo001gOol6
0002FUH00`00FUIJEP09FUH00`00FUIJEP07FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@
0002FUH500000eYF0000001FOol007eoo`P000IJEP04001JEUYFFUH60002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
EWoo0025Ool:00000goo000000020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002DOol70004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00
Egoo002SOolP001JOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49193 .84878 m .43439 .4082 L .3905 .40746 L p .707 .577 .707 r
F P
0 g
s
.55648 .84817 m .55816 .82904 L .53065 .82582 L p .707 .577 .707 r
F P
0 g
s
.53065 .82582 m .52897 .84495 L .55648 .84817 L p .707 .577 .707 r
F P
0 g
s
.53175 .79367 m .53503 .7554 L .51383 .75226 L p .707 .577 .707 r
F P
0 g
s
.51383 .75226 m .51055 .79052 L .53175 .79367 L p .707 .577 .707 r
F P
0 g
s
.52897 .84495 m .53065 .82582 L .50944 .82276 L p .707 .577 .707 r
F P
0 g
s
.50944 .82276 m .50776 .8419 L .52897 .84495 L p .707 .577 .707 r
F P
0 g
s
.50377 .6688 m .50078 .72584 L .51346 .73063 L p .707 .577 .707 r
F P
0 g
s
.51055 .79052 m .51383 .75226 L .50102 .74953 L p .707 .577 .707 r
F P
0 g
s
.50102 .74953 m .49774 .78779 L .51055 .79052 L p .707 .577 .707 r
F P
0 g
s
.50776 .8419 m .50944 .82276 L .49661 .82017 L p .707 .577 .707 r
F P
0 g
s
.49661 .82017 m .49493 .83931 L .50776 .8419 L p .707 .577 .707 r
F P
0 g
s
.50078 .72584 m .50377 .6688 L .50077 .66415 L p .707 .577 .707 r
F P
0 g
s
.50077 .66415 m .49778 .72119 L .50078 .72584 L p .707 .577 .707 r
F P
0 g
s
.49774 .78779 m .50102 .74953 L .49784 .74748 L p .707 .577 .707 r
F P
0 g
s
.49784 .74748 m .49456 .78575 L .49774 .78779 L p .707 .577 .707 r
F P
0 g
s
.49493 .83931 m .49661 .82017 L .49342 .81831 L p .707 .577 .707 r
F P
0 g
s
.49342 .81831 m .49173 .83744 L .49493 .83931 L p .707 .577 .707 r
F P
0 g
s
.51346 .73063 m .51644 .67359 L .50377 .6688 L p .707 .577 .707 r
F P
0 g
s
.49778 .72119 m .50077 .66415 L .50774 .6601 L p .707 .577 .707 r
F P
0 g
s
.50774 .6601 m .50475 .71715 L .49778 .72119 L p .707 .577 .707 r
F P
0 g
s
.49456 .78575 m .49784 .74748 L .50461 .74631 L p .707 .577 .707 r
F P
0 g
s
.50461 .74631 m .50133 .78458 L .49456 .78575 L p .707 .577 .707 r
F P
0 g
s
.49173 .83744 m .49342 .81831 L .50017 .81734 L p .707 .577 .707 r
F P
0 g
s
.50017 .81734 m .49849 .83647 L .49173 .83744 L p .707 .577 .707 r
F P
0 g
s
.50475 .71715 m .50774 .6601 L .51142 .65941 L p .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .47899 .40146 L .45306 .40538 L p .707 .577 .707 r
F P
0 g
s
.56204 .73881 m .56503 .68177 L .53755 .67806 L p .707 .577 .707 r
F P
0 g
s
.53755 .67806 m .53457 .7351 L .56204 .73881 L p .707 .577 .707 r
F P
0 g
s
.56254 .75866 m .55926 .79692 L .59038 .79996 L p .707 .577 .707 r
F P
0 g
s
.55926 .79692 m .56254 .75866 L .53503 .7554 L p .707 .577 .707 r
F P
0 g
s
.53457 .7351 m .53755 .67806 L .51644 .67359 L p .707 .577 .707 r
F P
0 g
s
.51644 .67359 m .51346 .73063 L .53457 .7351 L p .707 .577 .707 r
F P
0 g
s
.47899 .40146 m .51433 .67207 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.55655 .73776 m .47899 .40146 L .52886 .70807 L .707 .577 .707 r
F
.52101 .71409 m .52172 .70041 L p .52544 .70441 L F P
0 g
s
.5876 .85124 m .58928 .83211 L .55816 .82904 L p .707 .577 .707 r
F P
0 g
s
.53503 .7554 m .53175 .79367 L .55926 .79692 L p .707 .577 .707 r
F P
0 g
s
.55816 .82904 m .55648 .84817 L .5876 .85124 L p .707 .577 .707 r
F P
0 g
s
.53362 .71317 m .52101 .71409 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .52066 .74615 L .54185 .7469 L p .707 .577 .707 r
F P
0 g
s
.54185 .7469 m .54443 .74699 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .54185 .7469 L .54306 .74888 L .707 .577 .707 r
F
.50475 .71715 m .51142 .65941 L .51636 .6809 L F
.49664 .67262 m .51433 .67207 L .43439 .4082 L F
.52886 .70807 m .51433 .67207 L .52172 .70041 L F
.52399 .65705 m .52101 .71409 L .50475 .71715 L p F P
0 g
s
.50133 .78458 m .50461 .74631 L .52066 .74615 L p .707 .577 .707 r
F P
0 g
s
.52066 .74615 m .51738 .78441 L .50133 .78458 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .51738 .78441 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54443 .74699 m .54412 .75062 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54412 .75062 m .54115 .78525 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.49849 .83647 m .50017 .81734 L .51621 .81737 L p .707 .577 .707 r
F P
0 g
s
.51621 .81737 m .51452 .8365 L .49849 .83647 L p .707 .577 .707 r
F P
0 g
s
.51452 .8365 m .51621 .81737 L .53996 .81839 L p .707 .577 .707 r
F P
0 g
s
.53996 .81839 m .53828 .83753 L .51452 .8365 L p .707 .577 .707 r
F P
0 g
s
.49193 .84878 m .53653 .84205 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.43439 .4082 m .46135 .61464 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.46135 .61464 m .49193 .84878 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.53653 .84205 m .51925 .70977 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.51925 .70977 m .51433 .67207 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.59038 .79996 m .59366 .7617 L .56254 .75866 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .54318 .76162 L p .57359 .74876 L .707 .577 .707 r
F P
0 g
s
.54318 .76162 m .54443 .74699 L .55319 .74752 L p .707 .577 .707 r
F P
0 g
s
.55319 .74752 m .57359 .74876 L p .54318 .76162 L .707 .577 .707 r
F P
0 g
s
.5932 .7414 m .59618 .68435 L .56503 .68177 L p .707 .577 .707 r
F P
0 g
s
.59618 .68435 m .5932 .7414 L .62498 .7426 L p .707 .577 .707 r
F P
0 g
s
.56503 .68177 m .56204 .73881 L .5932 .7414 L p .707 .577 .707 r
F P
0 g
s
.59366 .7617 m .59038 .79996 L .62207 .80249 L p .707 .577 .707 r
F P
0 g
s
.62207 .80249 m .62536 .76423 L .59366 .7617 L p .707 .577 .707 r
F P
0 g
s
.62498 .7426 m .62797 .68556 L .59618 .68435 L p .707 .577 .707 r
F P
0 g
s
.60903 .65621 m .60604 .71326 L .58378 .71241 L p .707 .577 .707 r
F P
0 g
s
.58378 .71241 m .57426 .71205 L p .58649 .6924 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .60903 .65621 L .58378 .71241 L .707 .577 .707 r
F
.62536 .76423 m .62207 .80249 L .65123 .80427 L p F P
0 g
s
.65123 .80427 m .65451 .766 L .62536 .76423 L p .707 .577 .707 r
F P
0 g
s
.62797 .68556 m .62498 .7426 L .65428 .74232 L p .707 .577 .707 r
F P
0 g
s
.65428 .74232 m .65727 .68527 L .62797 .68556 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .60671 .71331 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60669 .71221 m .63368 .66916 L .60671 .71331 L .707 .577 .707 r
F
.63368 .66916 m .64018 .6588 L .63371 .66934 L F
.63368 .66916 m .63371 .66934 L .60671 .71331 L F
.58483 .32212 m .57558 .3462 L p .60413 .52426 L F P
0 g
s
.60903 .65621 m .64018 .6588 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .6364 .75434 L .64646 .75552 L p .707 .577 .707 r
F P
0 g
s
.65451 .766 m .65123 .80427 L .675 .80511 L p .707 .577 .707 r
F P
0 g
s
.675 .80511 m .67828 .76685 L .65451 .766 L p .707 .577 .707 r
F P
0 g
s
.64646 .75552 m .66391 .75759 L p .64932 .77418 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .64646 .75552 L .64932 .77418 L .707 .577 .707 r
F
.64236 .76271 m .6033 .46358 L p .60413 .52426 L F P
0 g
s
.6364 .75434 m .63312 .7926 L .60773 .79012 L p .707 .577 .707 r
F P
0 g
s
.60778 .78365 m .6364 .75434 L .60773 .79012 L .707 .577 .707 r
F
.602 .78956 m .60528 .7513 L .60802 .75156 L p F P
0 g
s
.60802 .75156 m .6364 .75434 L p .60778 .78365 L .707 .577 .707 r
F P
0 g
s
.602 .78956 m .60802 .75156 L .60778 .78365 L .707 .577 .707 r
F
.60475 .56956 m .60914 .60321 L p .60413 .52426 L F P
0 g
s
.60914 .60321 m .63311 .78679 L p .60938 .5718 L .707 .577 .707 r
F P
0 g
s
.60413 .52426 m .60914 .60321 L .60938 .5718 L .707 .577 .707 r
F
.63311 .78679 m .64236 .76271 L p .60948 .55766 L F P
0 g
s
.60948 .55766 m .60413 .52426 L .60938 .5718 L .707 .577 .707 r
F
.60948 .55766 m .60938 .5718 L .63311 .78679 L F
.60773 .79012 m .602 .78956 L p .60778 .78365 L F P
0 g
s
.64236 .76271 m .6376 .73959 L p .608 .50546 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .58483 .32212 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.608 .50546 m .59921 .43593 L .61078 .52349 L .707 .577 .707 r
F
.608 .50546 m .61078 .52349 L .64236 .76271 L F
.60604 .71326 m .60657 .70314 L p .60669 .71221 L F P
0 g
s
.60657 .70314 m .60903 .65621 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.58006 .299 m .58483 .32212 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6376 .73959 m .58831 .36214 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58831 .36214 m .58006 .299 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58483 .32212 m .6033 .46358 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .64236 .76271 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.64018 .6588 m .63808 .69891 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.63808 .69891 m .63719 .71584 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60671 .71331 m .60604 .71326 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .60475 .56956 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.55322 .36887 m .59106 .65864 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .55322 .36887 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .58753 .68473 L .60903 .65621 L .707 .577 .707 r
F
.59221 .65558 m .60903 .65621 L p .5748 .70161 L F P
0 g
s
.63311 .78679 m .60394 .56338 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.60394 .56338 m .57558 .3462 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .5748 .70161 L p .58753 .68473 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .58753 .68473 L .58649 .6924 L .707 .577 .707 r
F
.51993 .38791 m .56346 .7212 L p .5829 .68019 L F P
0 g
s
.5748 .70161 m .57426 .71205 L .56873 .71211 L p .707 .577 .707 r
F P
0 g
s
.56346 .7212 m .56447 .72893 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.5829 .68019 m .56346 .7212 L .5748 .70161 L .707 .577 .707 r
F
.57359 .74876 m .57031 .78703 L .54115 .78525 L p F P
0 g
s
.57031 .78703 m .57359 .74876 L .58061 .74932 L p .707 .577 .707 r
F P
0 g
s
.58061 .74932 m .60528 .7513 L p .57445 .7828 L .707 .577 .707 r
F P
0 g
s
.57031 .78703 m .58061 .74932 L .57445 .7828 L .707 .577 .707 r
F
.60528 .7513 m .602 .78956 L .57031 .78703 L p F P
0 g
s
.61075 .80945 m .55322 .36887 L .51993 .38791 L p .707 .577 .707 r
F P
0 g
s
.5748 .70161 m .57724 .65501 L .59221 .65558 L p .707 .577 .707 r
F P
0 g
s
.59106 .65864 m .59365 .67849 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.59365 .67849 m .61075 .80945 L p .60053 .6411 L .707 .577 .707 r
F P
0 g
s
.59833 .60485 m .59365 .67849 L .60053 .6411 L .707 .577 .707 r
F
.56742 .83944 m .56911 .82031 L .60079 .82293 L p F P
0 g
s
.57747 .8285 m .51993 .38791 L .47899 .40146 L p .707 .577 .707 r
F P
0 g
s
.57724 .65501 m .5748 .70161 L p .54496 .71234 L .707 .577 .707 r
F P
0 g
s
.56873 .71211 m .54496 .71234 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.58712 .69976 m .5829 .68019 L .56477 .73123 L .707 .577 .707 r
F
.56447 .72893 m .56477 .73123 L p .5829 .68019 L F P
0 g
s
.61075 .80945 m .63311 .78679 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .61075 .80945 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.56477 .73123 m .57747 .8285 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.53828 .83753 m .53996 .81839 L .56911 .82031 L p .707 .577 .707 r
F P
0 g
s
.56911 .82031 m .56742 .83944 L .53828 .83753 L p .707 .577 .707 r
F P
0 g
s
.55691 .8353 m .57747 .8285 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.52886 .70807 m .52172 .70041 L .55691 .8353 L .707 .577 .707 r
F
.54794 .6553 m .54496 .71234 L .53362 .71317 L p F P
0 g
s
.52544 .70441 m .54794 .6553 L .53362 .71317 L .707 .577 .707 r
F
.52399 .65705 m .54794 .6553 L p .52544 .70441 L F P
0 g
s
.52172 .70041 m .52399 .65705 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .55655 .73776 L .52886 .70807 L .707 .577 .707 r
F
.51636 .6809 m .51433 .67207 L .51651 .68043 L F
.51433 .67207 m .53653 .84205 L .55691 .8353 L p F P
0 g
s
.51142 .65941 m .52399 .65705 L p .51651 .68043 L .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .51142 .65941 L .51651 .68043 L .707 .577 .707 r
F
.45306 .40538 m .43439 .4082 L p .51433 .67207 L F P
0 g
s
.44804 .84804 m .3905 .40746 L .35162 .39931 L p .707 .577 .707 r
F P
0 g
s
.3905 .40746 m .44804 .84804 L .49193 .84878 L p .707 .577 .707 r
F P
0 g
s
.40915 .8399 m .35162 .39931 L .32155 .38456 L p .707 .577 .707 r
F P
0 g
s
.35162 .39931 m .40915 .8399 L .44804 .84804 L p .707 .577 .707 r
F P
0 g
s
.65727 .68527 m .65428 .74232 L .67823 .74056 L p .707 .577 .707 r
F P
0 g
s
.67823 .74056 m .68122 .68352 L .65727 .68527 L p .707 .577 .707 r
F P
0 g
s
.58928 .83211 m .5876 .85124 L .61928 .85387 L p .707 .577 .707 r
F P
0 g
s
.61928 .85387 m .62096 .83473 L .58928 .83211 L p .707 .577 .707 r
F P
0 g
s
.62096 .83473 m .61928 .85387 L .64843 .85578 L p .707 .577 .707 r
F P
0 g
s
.64843 .85578 m .65011 .83665 L .62096 .83473 L p .707 .577 .707 r
F P
0 g
s
.68122 .68352 m .67823 .74056 L .69448 .73751 L p .707 .577 .707 r
F P
0 g
s
.69448 .73751 m .69747 .68047 L .68122 .68352 L p .707 .577 .707 r
F P
0 g
s
.65011 .83665 m .64843 .85578 L .67218 .85681 L p .707 .577 .707 r
F P
0 g
s
.67218 .85681 m .67386 .83767 L .65011 .83665 L p .707 .577 .707 r
F P
0 g
s
.35147 .70069 m .35446 .64365 L .33821 .6467 L p .707 .577 .707 r
F P
0 g
s
.35446 .64365 m .35147 .70069 L .35844 .69665 L p .707 .577 .707 r
F P
0 g
s
.35844 .69665 m .35916 .68297 L p .35446 .64365 L .707 .577 .707 r
F P
0 g
s
.37908 .82515 m .35999 .67891 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35689 .65518 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35916 .68297 L .3626 .72506 L .707 .577 .707 r
F
.37908 .82515 m .40915 .8399 L p .34771 .52055 L F P
0 g
s
.35689 .65518 m .37908 .82515 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .36143 .6396 L .35604 .64273 L p .707 .577 .707 r
F P
0 g
s
.35604 .64273 m .35588 .64283 L p .35689 .65518 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35604 .64273 L .35689 .65518 L .707 .577 .707 r
F
.35588 .64283 m .35446 .64365 L p .35916 .68297 L F P
0 g
s
.32155 .38456 m .35689 .65518 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35844 .69665 L .35686 .6942 L p .707 .577 .707 r
F P
0 g
s
.32155 .38456 m .30323 .36465 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35689 .65518 m .32155 .38456 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.33821 .6467 m .33522 .70374 L .35147 .70069 L p .707 .577 .707 r
F P
0 g
s
.34805 .76813 m .35133 .72986 L .33527 .73003 L p .707 .577 .707 r
F P
0 g
s
.35133 .72986 m .34805 .76813 L .35482 .76696 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .3581 .7287 L .35133 .72986 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .35164 .76491 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.3581 .7287 m .35618 .75107 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35618 .75107 m .35482 .76696 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.34546 .68996 m .30323 .36465 L .34444 .68365 L .707 .577 .707 r
F
.33527 .73003 m .33199 .7683 L .34805 .76813 L p F P
0 g
s
.33882 .76218 m .3421 .72392 L .35107 .72583 L p .707 .577 .707 r
F P
0 g
s
.35107 .72583 m .35492 .72665 L p .35221 .73263 L .707 .577 .707 r
F P
0 g
s
.33882 .76218 m .35107 .72583 L .35221 .73263 L .707 .577 .707 r
F
.35113 .73139 m .34807 .70797 L p .35054 .72912 L F P
0 g
s
.34807 .70797 m .34676 .69794 L p .34774 .70599 L .707 .577 .707 r
F P
0 g
s
.34807 .70797 m .34774 .70599 L .35054 .72912 L .707 .577 .707 r
F
.34676 .69794 m .30323 .36465 L p .34546 .68996 L F P
0 g
s
.34676 .69794 m .34546 .68996 L .35054 .72912 L .707 .577 .707 r
F
.30323 .36465 m .29847 .34152 L p .34444 .68365 L F P
0 g
s
.36077 .80524 m .37908 .82515 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.30323 .36465 m .34676 .69794 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .3581 .7287 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35164 .76491 m .35366 .74128 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35366 .74128 m .35492 .72665 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .35164 .76491 L .33882 .76218 L p .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .36077 .80524 L p .35054 .72912 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .34332 .67676 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34516 .68811 m .34277 .68721 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.29847 .34152 m .30772 .31745 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .33644 .68587 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.33522 .70374 m .33821 .6467 L .31426 .64846 L p .707 .577 .707 r
F P
0 g
s
.33636 .65067 m .33856 .64587 L .33644 .68587 L .707 .577 .707 r
F
.29847 .34152 m .33631 .63129 L p .34484 .68665 L F P
0 g
s
.34576 .63016 m .34332 .67676 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34277 .68721 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.35054 .72912 m .34484 .68665 L .34758 .71757 L .707 .577 .707 r
F
.33631 .63129 m .29847 .34152 L p .33622 .59168 L F P
0 g
s
.31426 .64846 m .31127 .7055 L .33522 .70374 L p .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .32465 .62569 L .3363 .62816 L p .707 .577 .707 r
F P
0 g
s
.3363 .62816 m .34576 .63016 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .3363 .62816 L .33636 .65067 L .707 .577 .707 r
F
.34758 .71757 m .35601 .78211 L p .35054 .72912 L F P
0 g
s
.34676 .69794 m .36077 .80524 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.34576 .63016 m .35843 .63496 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34576 .63016 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.35843 .63496 m .35544 .692 L .34516 .68811 L p .707 .577 .707 r
F P
0 g
s
.34422 .68235 m .35843 .63496 L .34516 .68811 L .707 .577 .707 r
F
.35054 .72912 m .34546 .68996 L .34444 .68365 L F
.36077 .80524 m .35113 .73139 L p .35054 .72912 L F P
0 g
s
.36526 .75804 m .35601 .78211 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.30772 .31745 m .33608 .53463 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.36143 .6396 m .35916 .68297 L p .35544 .692 L .707 .577 .707 r
F P
0 g
s
.35686 .6942 m .35544 .692 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35544 .692 m .35843 .63496 L .36143 .6396 L p .707 .577 .707 r
F P
0 g
s
.33608 .53463 m .36526 .75804 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33631 .63129 m .34758 .71757 L p .34484 .68665 L .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .33631 .63129 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33644 .68587 m .32166 .68274 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.67828 .76685 m .675 .80511 L .69106 .80494 L p .707 .577 .707 r
F P
0 g
s
.69106 .80494 m .69434 .76668 L .67828 .76685 L p .707 .577 .707 r
F P
0 g
s
.67386 .83767 m .67218 .85681 L .68822 .85684 L p .707 .577 .707 r
F P
0 g
s
.68822 .85684 m .6899 .8377 L .67386 .83767 L p .707 .577 .707 r
F P
0 g
s
.69747 .68047 m .69448 .73751 L .70145 .73346 L p .707 .577 .707 r
F P
0 g
s
.70145 .73346 m .70444 .67642 L .69747 .68047 L p .707 .577 .707 r
F P
0 g
s
.69434 .76668 m .69106 .80494 L .69783 .80378 L p .707 .577 .707 r
F P
0 g
s
.69783 .80378 m .70111 .76551 L .69434 .76668 L p .707 .577 .707 r
F P
0 g
s
.6899 .8377 m .68822 .85684 L .69497 .85587 L p .707 .577 .707 r
F P
0 g
s
.69497 .85587 m .69665 .83674 L .6899 .8377 L p .707 .577 .707 r
F P
0 g
s
.70444 .67642 m .70145 .73346 L .69845 .72881 L p .707 .577 .707 r
F P
0 g
s
.69845 .72881 m .70144 .67177 L .70444 .67642 L p .707 .577 .707 r
F P
0 g
s
.70111 .76551 m .69783 .80378 L .69465 .80173 L p .707 .577 .707 r
F P
0 g
s
.69465 .80173 m .69793 .76346 L .70111 .76551 L p .707 .577 .707 r
F P
0 g
s
.69665 .83674 m .69497 .85587 L .69177 .854 L p .707 .577 .707 r
F P
0 g
s
.69177 .854 m .69346 .83487 L .69665 .83674 L p .707 .577 .707 r
F P
0 g
s
.70144 .67177 m .69845 .72881 L .68578 .72402 L p .707 .577 .707 r
F P
0 g
s
.68578 .72402 m .68876 .66698 L .70144 .67177 L p .707 .577 .707 r
F P
0 g
s
.58006 .299 m .6376 .73959 L .61929 .71967 L p .707 .577 .707 r
F P
0 g
s
.61929 .71967 m .56175 .27909 L .58006 .299 L p .707 .577 .707 r
F P
0 g
s
.25019 .70458 m .25317 .64754 L .22202 .64495 L p .707 .577 .707 r
F P
0 g
s
.25317 .64754 m .25019 .70458 L .28197 .70579 L p .707 .577 .707 r
F P
0 g
s
.28197 .70579 m .28496 .64875 L .25317 .64754 L p .707 .577 .707 r
F P
0 g
s
.28496 .64875 m .28197 .70579 L .31127 .7055 L p .707 .577 .707 r
F P
0 g
s
.31127 .7055 m .31426 .64846 L .28496 .64875 L p .707 .577 .707 r
F P
0 g
s
.21903 .702 m .22202 .64495 L .19454 .64125 L p .707 .577 .707 r
F P
0 g
s
.22202 .64495 m .21903 .702 L .25019 .70458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69793 .76346 m .69465 .80173 L .68183 .799 L p .707 .577 .707 r
F P
0 g
s
.68183 .799 m .68511 .76073 L .69793 .76346 L p .707 .577 .707 r
F P
0 g
s
.19454 .64125 m .19156 .69829 L .21903 .702 L p .707 .577 .707 r
F P
0 g
s
.24737 .76315 m .25066 .72488 L .21953 .72184 L p .707 .577 .707 r
F P
0 g
s
.25066 .72488 m .24737 .76315 L .27906 .76568 L p .707 .577 .707 r
F P
0 g
s
.27906 .76568 m .28235 .72741 L .25066 .72488 L p .707 .577 .707 r
F P
0 g
s
.21953 .72184 m .21625 .76011 L .24737 .76315 L p .707 .577 .707 r
F P
0 g
s
.28235 .72741 m .27906 .76568 L .30822 .76745 L p .707 .577 .707 r
F P
0 g
s
.30822 .76745 m .3115 .72919 L .28235 .72741 L p .707 .577 .707 r
F P
0 g
s
.69346 .83487 m .69177 .854 L .67895 .85141 L p .707 .577 .707 r
F P
0 g
s
.67895 .85141 m .68063 .83228 L .69346 .83487 L p .707 .577 .707 r
F P
0 g
s
.21625 .76011 m .21953 .72184 L .19203 .71859 L p .707 .577 .707 r
F P
0 g
s
.19156 .69829 m .19454 .64125 L .17344 .63678 L p .707 .577 .707 r
F P
0 g
s
.24459 .81443 m .24627 .79529 L .21515 .79222 L p .707 .577 .707 r
F P
0 g
s
.24627 .79529 m .24459 .81443 L .27627 .81705 L p .707 .577 .707 r
F P
0 g
s
.27627 .81705 m .27796 .79792 L .24627 .79529 L p .707 .577 .707 r
F P
0 g
s
.68876 .66698 m .68578 .72402 L .66467 .71955 L p .707 .577 .707 r
F P
0 g
s
.66467 .71955 m .66766 .66251 L .68876 .66698 L p .707 .577 .707 r
F P
0 g
s
.19203 .71859 m .18874 .75685 L .21625 .76011 L p .707 .577 .707 r
F P
0 g
s
.21515 .79222 m .21347 .81136 L .24459 .81443 L p .707 .577 .707 r
F P
0 g
s
.36526 .75804 m .30772 .31745 L .33008 .29478 L p .707 .577 .707 r
F P
0 g
s
.27796 .79792 m .27627 .81705 L .30542 .81897 L p .707 .577 .707 r
F P
0 g
s
.30542 .81897 m .3071 .79983 L .27796 .79792 L p .707 .577 .707 r
F P
0 g
s
.21347 .81136 m .21515 .79222 L .18764 .789 L p .707 .577 .707 r
F P
0 g
s
.17344 .63678 m .17045 .69382 L .19156 .69829 L p .707 .577 .707 r
F P
0 g
s
.18764 .789 m .18596 .80814 L .21347 .81136 L p .707 .577 .707 r
F P
0 g
s
.3115 .72919 m .30822 .76745 L .33199 .7683 L p .707 .577 .707 r
F P
0 g
s
.33199 .7683 m .33527 .73003 L .3115 .72919 L p .707 .577 .707 r
F P
0 g
s
.56175 .27909 m .61929 .71967 L .58922 .70492 L p .707 .577 .707 r
F P
0 g
s
.58922 .70492 m .53168 .26434 L .56175 .27909 L p .707 .577 .707 r
F P
0 g
s
.18874 .75685 m .19203 .71859 L .17083 .71544 L p .707 .577 .707 r
F P
0 g
s
.3071 .79983 m .30542 .81897 L .32917 .81999 L p .707 .577 .707 r
F P
0 g
s
.32917 .81999 m .33086 .80086 L .3071 .79983 L p .707 .577 .707 r
F P
0 g
s
.17083 .71544 m .16754 .75371 L .18874 .75685 L p .707 .577 .707 r
F P
0 g
s
.68511 .76073 m .68183 .799 L .66063 .79585 L p .707 .577 .707 r
F P
0 g
s
.66063 .79585 m .66391 .75759 L .68511 .76073 L p .707 .577 .707 r
F P
0 g
s
.18596 .80814 m .18764 .789 L .16643 .78595 L p .707 .577 .707 r
F P
0 g
s
.17045 .69382 m .17344 .63678 L .16076 .63198 L p .707 .577 .707 r
F P
0 g
s
.16643 .78595 m .16475 .80508 L .18596 .80814 L p .707 .577 .707 r
F P
0 g
s
.66766 .66251 m .66467 .71955 L .63719 .71584 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .64018 .6588 L .66766 .66251 L p .707 .577 .707 r
F P
0 g
s
.68063 .83228 m .67895 .85141 L .65774 .84836 L p .707 .577 .707 r
F P
0 g
s
.65774 .84836 m .65942 .82922 L .68063 .83228 L p .707 .577 .707 r
F P
0 g
s
.54496 .71234 m .54794 .6553 L .57724 .65501 L p .707 .577 .707 r
F P
0 g
s
.16076 .63198 m .15777 .68903 L .17045 .69382 L p .707 .577 .707 r
F P
0 g
s
.33008 .29478 m .38762 .73537 L .36526 .75804 L p .707 .577 .707 r
F P
0 g
s
.38762 .73537 m .33008 .29478 L .36336 .27574 L p .707 .577 .707 r
F P
0 g
s
.33086 .80086 m .32917 .81999 L .34521 .82002 L p .707 .577 .707 r
F P
0 g
s
.34521 .82002 m .34689 .80089 L .33086 .80086 L p .707 .577 .707 r
F P
0 g
s
.16754 .75371 m .17083 .71544 L .15801 .71271 L p .707 .577 .707 r
F P
0 g
s
.53168 .26434 m .58922 .70492 L .55033 .69678 L p .707 .577 .707 r
F P
0 g
s
.55033 .69678 m .4928 .25619 L .53168 .26434 L p .707 .577 .707 r
F P
0 g
s
.15801 .71271 m .15473 .75098 L .16754 .75371 L p .707 .577 .707 r
F P
0 g
s
.66391 .75759 m .66063 .79585 L .63312 .7926 L p .707 .577 .707 r
F P
0 g
s
.16475 .80508 m .16643 .78595 L .15361 .78336 L p .707 .577 .707 r
F P
0 g
s
.15361 .78336 m .15192 .80249 L .16475 .80508 L p .707 .577 .707 r
F P
0 g
s
.65942 .82922 m .65774 .84836 L .63023 .84514 L p .707 .577 .707 r
F P
0 g
s
.63023 .84514 m .63191 .826 L .65942 .82922 L p .707 .577 .707 r
F P
0 g
s
.15777 .68903 m .16076 .63198 L .15776 .62733 L p .707 .577 .707 r
F P
0 g
s
.4209 .71633 m .36336 .27574 L .40431 .26219 L p .707 .577 .707 r
F P
0 g
s
.36336 .27574 m .4209 .71633 L .38762 .73537 L p .707 .577 .707 r
F P
0 g
s
.15776 .62733 m .15477 .68438 L .15777 .68903 L p .707 .577 .707 r
F P
0 g
s
.4928 .25619 m .55033 .69678 L .50644 .69604 L p .707 .577 .707 r
F P
0 g
s
.50644 .69604 m .44891 .25545 L .4928 .25619 L p .707 .577 .707 r
F P
0 g
s
.63191 .826 m .63023 .84514 L .59911 .84207 L p .707 .577 .707 r
F P
0 g
s
.59911 .84207 m .60079 .82293 L .63191 .826 L p .707 .577 .707 r
F P
0 g
s
.34689 .80089 m .34521 .82002 L .35196 .81906 L p .707 .577 .707 r
F P
0 g
s
.35196 .81906 m .35365 .79992 L .34689 .80089 L p .707 .577 .707 r
F P
0 g
s
.15473 .75098 m .15801 .71271 L .15483 .71067 L p .707 .577 .707 r
F P
0 g
s
.60079 .82293 m .59911 .84207 L .56742 .83944 L p .707 .577 .707 r
F P
0 g
s
.15483 .71067 m .15155 .74893 L .15473 .75098 L p .707 .577 .707 r
F P
0 g
s
.46184 .70278 m .40431 .26219 L .44891 .25545 L p .707 .577 .707 r
F P
0 g
s
.40431 .26219 m .46184 .70278 L .4209 .71633 L p .707 .577 .707 r
F P
0 g
s
.44891 .25545 m .50644 .69604 L .46184 .70278 L p .707 .577 .707 r
F P
0 g
s
.15192 .80249 m .15361 .78336 L .15041 .78149 L p .707 .577 .707 r
F P
0 g
s
.15041 .78149 m .14872 .80063 L .15192 .80249 L p .707 .577 .707 r
F P
0 g
s
.15477 .68438 m .15776 .62733 L .16473 .62329 L p .707 .577 .707 r
F P
0 g
s
.16473 .62329 m .16174 .68033 L .15477 .68438 L p .707 .577 .707 r
F P
0 g
s
.35365 .79992 m .35196 .81906 L .34877 .81719 L p .707 .577 .707 r
F P
0 g
s
.34877 .81719 m .35045 .79805 L .35365 .79992 L p .707 .577 .707 r
F P
0 g
s
.15155 .74893 m .15483 .71067 L .1616 .7095 L p .707 .577 .707 r
F P
0 g
s
.1616 .7095 m .15832 .74776 L .15155 .74893 L p .707 .577 .707 r
F P
0 g
s
.14872 .80063 m .15041 .78149 L .15716 .78052 L p .707 .577 .707 r
F P
0 g
s
.15716 .78052 m .15548 .79966 L .14872 .80063 L p .707 .577 .707 r
F P
0 g
s
.16174 .68033 m .16473 .62329 L .18098 .62024 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18098 .62024 m .178 .67728 L .16174 .68033 L p .707 .577 .707 r
F P
0 g
s
.35045 .79805 m .34877 .81719 L .33594 .8146 L p .707 .577 .707 r
F P
0 g
s
.33594 .8146 m .33762 .79546 L .35045 .79805 L p .707 .577 .707 r
F P
0 g
s
.15832 .74776 m .1616 .7095 L .17765 .70933 L p .707 .577 .707 r
F P
0 g
s
.17765 .70933 m .17437 .7476 L .15832 .74776 L p .707 .577 .707 r
F P
0 g
s
.15548 .79966 m .15716 .78052 L .1732 .78055 L p .707 .577 .707 r
F P
0 g
s
.1732 .78055 m .17151 .79969 L .15548 .79966 L p .707 .577 .707 r
F P
0 g
s
.178 .67728 m .18098 .62024 L .20493 .61848 L p .707 .577 .707 r
F P
0 g
s
.3421 .72392 m .33882 .76218 L .31762 .75904 L p .707 .577 .707 r
F P
0 g
s
.31762 .75904 m .3209 .72077 L .3421 .72392 L p .707 .577 .707 r
F P
0 g
s
.20493 .61848 m .20195 .67552 L .178 .67728 L p .707 .577 .707 r
F P
0 g
s
.32465 .62569 m .32166 .68274 L .29418 .67903 L p .707 .577 .707 r
F P
0 g
s
.29418 .67903 m .29717 .62198 L .32465 .62569 L p .707 .577 .707 r
F P
0 g
s
.33762 .79546 m .33594 .8146 L .31473 .81154 L p .707 .577 .707 r
F P
0 g
s
.31473 .81154 m .31641 .79241 L .33762 .79546 L p .707 .577 .707 r
F P
0 g
s
.17437 .7476 m .17765 .70933 L .20142 .71017 L p .707 .577 .707 r
F P
0 g
s
.20142 .71017 m .19814 .74844 L .17437 .7476 L p .707 .577 .707 r
F P
0 g
s
.20195 .67552 m .20493 .61848 L .23423 .61819 L p .707 .577 .707 r
F P
0 g
s
.17151 .79969 m .1732 .78055 L .19695 .78158 L p .707 .577 .707 r
F P
0 g
s
.19695 .78158 m .19527 .80071 L .17151 .79969 L p .707 .577 .707 r
F P
0 g
s
.23423 .61819 m .23125 .67524 L .20195 .67552 L p .707 .577 .707 r
F P
0 g
s
.29717 .62198 m .29418 .67903 L .26303 .67644 L p .707 .577 .707 r
F P
0 g
s
.26303 .67644 m .26602 .6194 L .29717 .62198 L p .707 .577 .707 r
F P
0 g
s
.3209 .72077 m .31762 .75904 L .29011 .75579 L p .707 .577 .707 r
F P
0 g
s
.29011 .75579 m .29339 .71752 L .3209 .72077 L p .707 .577 .707 r
F P
0 g
s
.7304 .64285 m .73339 .5858 L .70223 .58322 L p .707 .577 .707 r
F P
0 g
s
.73339 .5858 m .7304 .64285 L .76218 .64406 L p .707 .577 .707 r
F P
0 g
s
.76218 .64406 m .76517 .58701 L .73339 .5858 L p .707 .577 .707 r
F P
0 g
s
.23125 .67524 m .23423 .61819 L .26602 .6194 L p .707 .577 .707 r
F P
0 g
s
.76517 .58701 m .76218 .64406 L .79148 .64377 L p .707 .577 .707 r
F P
0 g
s
.79148 .64377 m .79447 .58672 L .76517 .58701 L p .707 .577 .707 r
F P
0 g
s
.26602 .6194 m .26303 .67644 L .23125 .67524 L p .707 .577 .707 r
F P
0 g
s
.19814 .74844 m .20142 .71017 L .23058 .71195 L p .707 .577 .707 r
F P
0 g
s
.69925 .64026 m .70223 .58322 L .67476 .57951 L p .707 .577 .707 r
F P
0 g
s
.70223 .58322 m .69925 .64026 L .7304 .64285 L p .707 .577 .707 r
F P
0 g
s
.31641 .79241 m .31473 .81154 L .28722 .80832 L p .707 .577 .707 r
F P
0 g
s
.28722 .80832 m .2889 .78919 L .31641 .79241 L p .707 .577 .707 r
F P
0 g
s
.23058 .71195 m .2273 .75021 L .19814 .74844 L p .707 .577 .707 r
F P
0 g
s
.72759 .69142 m .73087 .65315 L .69975 .65011 L p .707 .577 .707 r
F P
0 g
s
.73087 .65315 m .72759 .69142 L .75928 .69395 L p .707 .577 .707 r
F P
0 g
s
.75928 .69395 m .76256 .65568 L .73087 .65315 L p .707 .577 .707 r
F P
0 g
s
.19527 .80071 m .19695 .78158 L .2261 .78349 L p .707 .577 .707 r
F P
0 g
s
.69975 .65011 m .69646 .68838 L .72759 .69142 L p .707 .577 .707 r
F P
0 g
s
.67476 .57951 m .67177 .63656 L .69925 .64026 L p .707 .577 .707 r
F P
0 g
s
.2261 .78349 m .22441 .80263 L .19527 .80071 L p .707 .577 .707 r
F P
0 g
s
.76256 .65568 m .75928 .69395 L .78844 .69572 L p .707 .577 .707 r
F P
0 g
s
.78844 .69572 m .79172 .65746 L .76256 .65568 L p .707 .577 .707 r
F P
0 g
s
.29339 .71752 m .29011 .75579 L .25899 .75275 L p .707 .577 .707 r
F P
0 g
s
.25899 .75275 m .26227 .71448 L .29339 .71752 L p .707 .577 .707 r
F P
0 g
s
.79447 .58672 m .79148 .64377 L .81543 .64201 L p .707 .577 .707 r
F P
0 g
s
.81543 .64201 m .81842 .58497 L .79447 .58672 L p .707 .577 .707 r
F P
0 g
s
.7248 .72686 m .72649 .70772 L .69537 .70465 L p .707 .577 .707 r
F P
0 g
s
.72649 .70772 m .7248 .72686 L .75648 .72948 L p .707 .577 .707 r
F P
0 g
s
.75648 .72948 m .75817 .71035 L .72649 .70772 L p .707 .577 .707 r
F P
0 g
s
.69537 .70465 m .69368 .72379 L .7248 .72686 L p .707 .577 .707 r
F P
0 g
s
.69646 .68838 m .69975 .65011 L .67224 .64686 L p .707 .577 .707 r
F P
0 g
s
.2273 .75021 m .23058 .71195 L .26227 .71448 L p .707 .577 .707 r
F P
0 g
s
.75817 .71035 m .75648 .72948 L .78563 .7314 L p .707 .577 .707 r
F P
0 g
s
.78563 .7314 m .78731 .71226 L .75817 .71035 L p .707 .577 .707 r
F P
0 g
s
.67224 .64686 m .66896 .68513 L .69646 .68838 L p .707 .577 .707 r
F P
0 g
s
.26227 .71448 m .25899 .75275 L .2273 .75021 L p .707 .577 .707 r
F P
0 g
s
.67177 .63656 m .67476 .57951 L .65365 .57504 L p .707 .577 .707 r
F P
0 g
s
.69368 .72379 m .69537 .70465 L .66786 .70143 L p .707 .577 .707 r
F P
0 g
s
.66786 .70143 m .66617 .72057 L .69368 .72379 L p .707 .577 .707 r
F P
0 g
s
.2889 .78919 m .28722 .80832 L .2561 .80525 L p .707 .577 .707 r
F P
0 g
s
.2561 .80525 m .25778 .78612 L .2889 .78919 L p .707 .577 .707 r
F P
0 g
s
.22441 .80263 m .2261 .78349 L .25778 .78612 L p .707 .577 .707 r
F P
0 g
s
.25778 .78612 m .2561 .80525 L .22441 .80263 L p .707 .577 .707 r
F P
0 g
s
.79172 .65746 m .78844 .69572 L .81221 .69657 L p .707 .577 .707 r
F P
0 g
s
.81221 .69657 m .81549 .6583 L .79172 .65746 L p .707 .577 .707 r
F P
0 g
s
.65365 .57504 m .65066 .63209 L .67177 .63656 L p .707 .577 .707 r
F P
0 g
s
.78731 .71226 m .78563 .7314 L .80938 .73242 L p .707 .577 .707 r
F P
0 g
s
.80938 .73242 m .81107 .71329 L .78731 .71226 L p .707 .577 .707 r
F P
0 g
s
.66896 .68513 m .67224 .64686 L .65104 .64371 L p .707 .577 .707 r
F P
0 g
s
.65104 .64371 m .64776 .68198 L .66896 .68513 L p .707 .577 .707 r
F P
0 g
s
.81842 .58497 m .81543 .64201 L .83169 .63896 L p .707 .577 .707 r
F P
0 g
s
.83169 .63896 m .83467 .58192 L .81842 .58497 L p .707 .577 .707 r
F P
0 g
s
.66617 .72057 m .66786 .70143 L .64665 .69838 L p .707 .577 .707 r
F P
0 g
s
.64665 .69838 m .64496 .71751 L .66617 .72057 L p .707 .577 .707 r
F P
0 g
s
.65066 .63209 m .65365 .57504 L .64097 .57025 L p .707 .577 .707 r
F P
0 g
s
.81549 .6583 m .81221 .69657 L .82826 .6964 L p .707 .577 .707 r
F P
0 g
s
.82826 .6964 m .83154 .65813 L .81549 .6583 L p .707 .577 .707 r
F P
0 g
s
.81107 .71329 m .80938 .73242 L .82542 .73245 L p .707 .577 .707 r
F P
0 g
s
.82542 .73245 m .82711 .71332 L .81107 .71329 L p .707 .577 .707 r
F P
0 g
s
.64097 .57025 m .63799 .62729 L .65066 .63209 L p .707 .577 .707 r
F P
0 g
s
.64776 .68198 m .65104 .64371 L .63822 .64098 L p .707 .577 .707 r
F P
0 g
s
.63822 .64098 m .63494 .67925 L .64776 .68198 L p .707 .577 .707 r
F P
0 g
s
.64496 .71751 m .64665 .69838 L .63382 .69579 L p .707 .577 .707 r
F P
0 g
s
.63382 .69579 m .63213 .71492 L .64496 .71751 L p .707 .577 .707 r
F P
0 g
s
.83467 .58192 m .83169 .63896 L .83866 .63491 L p .707 .577 .707 r
F P
0 g
s
.83866 .63491 m .84164 .57787 L .83467 .58192 L p .707 .577 .707 r
F P
0 g
s
.63799 .62729 m .64097 .57025 L .63797 .5656 L p .707 .577 .707 r
F P
0 g
s
.83154 .65813 m .82826 .6964 L .83503 .69523 L p .707 .577 .707 r
F P
0 g
s
.83503 .69523 m .83831 .65697 L .83154 .65813 L p .707 .577 .707 r
F P
0 g
s
.82711 .71332 m .82542 .73245 L .83217 .73148 L p .707 .577 .707 r
F P
0 g
s
.83217 .73148 m .83386 .71235 L .82711 .71332 L p .707 .577 .707 r
F P
0 g
s
.63797 .5656 m .63499 .62264 L .63799 .62729 L p .707 .577 .707 r
F P
0 g
s
.63494 .67925 m .63822 .64098 L .63504 .63894 L p .707 .577 .707 r
F P
0 g
s
.63504 .63894 m .63176 .6772 L .63494 .67925 L p .707 .577 .707 r
F P
0 g
s
.63213 .71492 m .63382 .69579 L .63062 .69392 L p .707 .577 .707 r
F P
0 g
s
.63062 .69392 m .62894 .71305 L .63213 .71492 L p .707 .577 .707 r
F P
0 g
s
.84164 .57787 m .83866 .63491 L .83566 .63026 L p .707 .577 .707 r
F P
0 g
s
.83566 .63026 m .83864 .57322 L .84164 .57787 L p .707 .577 .707 r
F P
0 g
s
.63499 .62264 m .63797 .5656 L .64494 .56155 L p .707 .577 .707 r
F P
0 g
s
.83831 .65697 m .83503 .69523 L .83185 .69318 L p .707 .577 .707 r
F P
0 g
s
.83185 .69318 m .83513 .65492 L .83831 .65697 L p .707 .577 .707 r
F P
0 g
s
.83386 .71235 m .83217 .73148 L .82898 .72962 L p .707 .577 .707 r
F P
0 g
s
.82898 .72962 m .83066 .71048 L .83386 .71235 L p .707 .577 .707 r
F P
0 g
s
.64494 .56155 m .64196 .6186 L .63499 .62264 L p .707 .577 .707 r
F P
0 g
s
.63176 .6772 m .63504 .63894 L .64181 .63777 L p .707 .577 .707 r
F P
0 g
s
.64181 .63777 m .63853 .67603 L .63176 .6772 L p .707 .577 .707 r
F P
0 g
s
.62894 .71305 m .63062 .69392 L .63738 .69295 L p .707 .577 .707 r
F P
0 g
s
.63738 .69295 m .63569 .71209 L .62894 .71305 L p .707 .577 .707 r
F P
0 g
s
.83864 .57322 m .83566 .63026 L .82298 .62547 L p .707 .577 .707 r
F P
0 g
s
.82298 .62547 m .82597 .56843 L .83864 .57322 L p .707 .577 .707 r
F P
0 g
s
.38739 .60603 m .39038 .54899 L .35922 .5464 L p .707 .577 .707 r
F P
0 g
s
.39038 .54899 m .38739 .60603 L .41917 .60724 L p .707 .577 .707 r
F P
0 g
s
.41917 .60724 m .42216 .5502 L .39038 .54899 L p .707 .577 .707 r
F P
0 g
s
.42216 .5502 m .41917 .60724 L .44847 .60695 L p .707 .577 .707 r
F P
0 g
s
.44847 .60695 m .45146 .54991 L .42216 .5502 L p .707 .577 .707 r
F P
0 g
s
.64196 .6186 m .64494 .56155 L .6612 .5585 L p .707 .577 .707 r
F P
0 g
s
.35624 .60345 m .35922 .5464 L .33175 .5427 L p .707 .577 .707 r
F P
0 g
s
.35922 .5464 m .35624 .60345 L .38739 .60603 L p .707 .577 .707 r
F P
0 g
s
.83513 .65492 m .83185 .69318 L .81903 .69045 L p .707 .577 .707 r
F P
0 g
s
.81903 .69045 m .82232 .65219 L .83513 .65492 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83066 .71048 m .82898 .72962 L .81615 .72703 L p .707 .577 .707 r
F P
0 g
s
.81615 .72703 m .81784 .70789 L .83066 .71048 L p .707 .577 .707 r
F P
0 g
s
.38458 .6546 m .38786 .61634 L .35674 .6133 L p .707 .577 .707 r
F P
0 g
s
.38786 .61634 m .38458 .6546 L .41627 .65713 L p .707 .577 .707 r
F P
0 g
s
.41627 .65713 m .41955 .61887 L .38786 .61634 L p .707 .577 .707 r
F P
0 g
s
.6612 .5585 m .65821 .61555 L .64196 .6186 L p .707 .577 .707 r
F P
0 g
s
.35674 .6133 m .35345 .65156 L .38458 .6546 L p .707 .577 .707 r
F P
0 g
s
.33175 .5427 m .32876 .59974 L .35624 .60345 L p .707 .577 .707 r
F P
0 g
s
.41955 .61887 m .41627 .65713 L .44543 .65891 L p .707 .577 .707 r
F P
0 g
s
.44543 .65891 m .44871 .62064 L .41955 .61887 L p .707 .577 .707 r
F P
0 g
s
.45146 .54991 m .44847 .60695 L .47242 .6052 L p .707 .577 .707 r
F P
0 g
s
.47242 .6052 m .47541 .54815 L .45146 .54991 L p .707 .577 .707 r
F P
0 g
s
.38179 .69004 m .38348 .67091 L .35236 .66784 L p .707 .577 .707 r
F P
0 g
s
.38348 .67091 m .38179 .69004 L .41347 .69267 L p .707 .577 .707 r
F P
0 g
s
.41347 .69267 m .41516 .67353 L .38348 .67091 L p .707 .577 .707 r
F P
0 g
s
.35236 .66784 m .35067 .68697 L .38179 .69004 L p .707 .577 .707 r
F P
0 g
s
.63853 .67603 m .64181 .63777 L .65787 .6376 L p .707 .577 .707 r
F P
0 g
s
.35345 .65156 m .35674 .6133 L .32923 .61004 L p .707 .577 .707 r
F P
0 g
s
.41516 .67353 m .41347 .69267 L .44262 .69458 L p .707 .577 .707 r
F P
0 g
s
.44262 .69458 m .4443 .67545 L .41516 .67353 L p .707 .577 .707 r
F P
0 g
s
.65787 .6376 m .65458 .67587 L .63853 .67603 L p .707 .577 .707 r
F P
0 g
s
.32923 .61004 m .32595 .64831 L .35345 .65156 L p .707 .577 .707 r
F P
0 g
s
.63569 .71209 m .63738 .69295 L .65341 .69298 L p .707 .577 .707 r
F P
0 g
s
.32876 .59974 m .33175 .5427 L .31064 .53823 L p .707 .577 .707 r
F P
0 g
s
.35067 .68697 m .35236 .66784 L .32485 .66462 L p .707 .577 .707 r
F P
0 g
s
.65341 .69298 m .65173 .71212 L .63569 .71209 L p .707 .577 .707 r
F P
0 g
s
.32485 .66462 m .32316 .68375 L .35067 .68697 L p .707 .577 .707 r
F P
0 g
s
.82597 .56843 m .82298 .62547 L .80187 .621 L p .707 .577 .707 r
F P
0 g
s
.80187 .621 m .80486 .56396 L .82597 .56843 L p .707 .577 .707 r
F P
0 g
s
.44871 .62064 m .44543 .65891 L .4692 .65975 L p .707 .577 .707 r
F P
0 g
s
.4692 .65975 m .47248 .62149 L .44871 .62064 L p .707 .577 .707 r
F P
0 g
s
.31064 .53823 m .30765 .59527 L .32876 .59974 L p .707 .577 .707 r
F P
0 g
s
.4443 .67545 m .44262 .69458 L .46637 .69561 L p .707 .577 .707 r
F P
0 g
s
.46637 .69561 m .46806 .67647 L .4443 .67545 L p .707 .577 .707 r
F P
0 g
s
.65821 .61555 m .6612 .5585 L .68515 .55675 L p .707 .577 .707 r
F P
0 g
s
.32595 .64831 m .32923 .61004 L .30803 .6069 L p .707 .577 .707 r
F P
0 g
s
.30803 .6069 m .30475 .64516 L .32595 .64831 L p .707 .577 .707 r
F P
0 g
s
.47541 .54815 m .47242 .6052 L .48868 .60214 L p .707 .577 .707 r
F P
0 g
s
.48868 .60214 m .49166 .5451 L .47541 .54815 L p .707 .577 .707 r
F P
0 g
s
.82232 .65219 m .81903 .69045 L .79783 .68731 L p .707 .577 .707 r
F P
0 g
s
.79783 .68731 m .80112 .64904 L .82232 .65219 L p .707 .577 .707 r
F P
0 g
s
.32316 .68375 m .32485 .66462 L .30364 .66156 L p .707 .577 .707 r
F P
0 g
s
.30364 .66156 m .30195 .6807 L .32316 .68375 L p .707 .577 .707 r
F P
0 g
s
.68515 .55675 m .68216 .61379 L .65821 .61555 L p .707 .577 .707 r
F P
0 g
s
.81784 .70789 m .81615 .72703 L .79494 .72397 L p .707 .577 .707 r
F P
0 g
s
.79494 .72397 m .79663 .70484 L .81784 .70789 L p .707 .577 .707 r
F P
0 g
s
.65458 .67587 m .65787 .6376 L .68164 .63844 L p .707 .577 .707 r
F P
0 g
s
.30765 .59527 m .31064 .53823 L .29796 .53343 L p .707 .577 .707 r
F P
0 g
s
.80486 .56396 m .80187 .621 L .7744 .61729 L p .707 .577 .707 r
F P
0 g
s
.7744 .61729 m .77738 .56025 L .80486 .56396 L p .707 .577 .707 r
F P
0 g
s
.68164 .63844 m .67835 .67671 L .65458 .67587 L p .707 .577 .707 r
F P
0 g
s
.47248 .62149 m .4692 .65975 L .48525 .65958 L p .707 .577 .707 r
F P
0 g
s
.48525 .65958 m .48853 .62132 L .47248 .62149 L p .707 .577 .707 r
F P
0 g
s
.65173 .71212 m .65341 .69298 L .67717 .69401 L p .707 .577 .707 r
F P
0 g
s
.67717 .69401 m .67548 .71314 L .65173 .71212 L p .707 .577 .707 r
F P
0 g
s
.46806 .67647 m .46637 .69561 L .48241 .69564 L p .707 .577 .707 r
F P
0 g
s
.48241 .69564 m .4841 .6765 L .46806 .67647 L p .707 .577 .707 r
F P
0 g
s
.68216 .61379 m .68515 .55675 L .71445 .55646 L p .707 .577 .707 r
F P
0 g
s
.29796 .53343 m .29498 .59048 L .30765 .59527 L p .707 .577 .707 r
F P
0 g
s
.30475 .64516 m .30803 .6069 L .29521 .60417 L p .707 .577 .707 r
F P
0 g
s
.29521 .60417 m .29193 .64243 L .30475 .64516 L p .707 .577 .707 r
F P
0 g
s
.80112 .64904 m .79783 .68731 L .77033 .68406 L p .707 .577 .707 r
F P
0 g
s
.77033 .68406 m .77361 .64579 L .80112 .64904 L p .707 .577 .707 r
F P
0 g
s
.71445 .55646 m .71146 .6135 L .68216 .61379 L p .707 .577 .707 r
F P
0 g
s
.30195 .6807 m .30364 .66156 L .29081 .65897 L p .707 .577 .707 r
F P
0 g
s
.77738 .56025 m .7744 .61729 L .74324 .61471 L p .707 .577 .707 r
F P
0 g
s
.74324 .61471 m .74623 .55767 L .77738 .56025 L p .707 .577 .707 r
F P
0 g
s
.29081 .65897 m .28912 .67811 L .30195 .6807 L p .707 .577 .707 r
F P
0 g
s
.49166 .5451 m .48868 .60214 L .49565 .5981 L p .707 .577 .707 r
F P
0 g
s
.49565 .5981 m .49863 .54105 L .49166 .5451 L p .707 .577 .707 r
F P
0 g
s
.79663 .70484 m .79494 .72397 L .76743 .72075 L p .707 .577 .707 r
F P
0 g
s
.76743 .72075 m .76912 .70162 L .79663 .70484 L p .707 .577 .707 r
F P
0 g
s
.71146 .6135 m .71445 .55646 L .74623 .55767 L p .707 .577 .707 r
F P
0 g
s
.67835 .67671 m .68164 .63844 L .71079 .64022 L p .707 .577 .707 r
F P
0 g
s
.71079 .64022 m .70751 .67848 L .67835 .67671 L p .707 .577 .707 r
F P
0 g
s
.74623 .55767 m .74324 .61471 L .71146 .6135 L p .707 .577 .707 r
F P
0 g
s
.67548 .71314 m .67717 .69401 L .70631 .69592 L p .707 .577 .707 r
F P
0 g
s
.70631 .69592 m .70463 .71506 L .67548 .71314 L p .707 .577 .707 r
F P
0 g
s
.29498 .59048 m .29796 .53343 L .29496 .52878 L p .707 .577 .707 r
F P
0 g
s
.77361 .64579 m .77033 .68406 L .7392 .68102 L p .707 .577 .707 r
F P
0 g
s
.7392 .68102 m .74249 .64275 L .77361 .64579 L p .707 .577 .707 r
F P
0 g
s
.48853 .62132 m .48525 .65958 L .49202 .65842 L p .707 .577 .707 r
F P
0 g
s
.49202 .65842 m .4953 .62015 L .48853 .62132 L p .707 .577 .707 r
F P
0 g
s
.70751 .67848 m .71079 .64022 L .74249 .64275 L p .707 .577 .707 r
F P
0 g
s
.76912 .70162 m .76743 .72075 L .73631 .71768 L p .707 .577 .707 r
F P
0 g
s
.73631 .71768 m .738 .69855 L .76912 .70162 L p .707 .577 .707 r
F P
0 g
s
.4841 .6765 m .48241 .69564 L .48916 .69467 L p .707 .577 .707 r
F P
0 g
s
.48916 .69467 m .49085 .67553 L .4841 .6765 L p .707 .577 .707 r
F P
0 g
s
.74249 .64275 m .7392 .68102 L .70751 .67848 L p .707 .577 .707 r
F P
0 g
s
.29496 .52878 m .29198 .58583 L .29498 .59048 L p .707 .577 .707 r
F P
0 g
s
.70463 .71506 m .70631 .69592 L .738 .69855 L p .707 .577 .707 r
F P
0 g
s
.738 .69855 m .73631 .71768 L .70463 .71506 L p .707 .577 .707 r
F P
0 g
s
.29193 .64243 m .29521 .60417 L .29203 .60212 L p .707 .577 .707 r
F P
0 g
s
.29203 .60212 m .28875 .64039 L .29193 .64243 L p .707 .577 .707 r
F P
0 g
s
.28912 .67811 m .29081 .65897 L .28761 .6571 L p .707 .577 .707 r
F P
0 g
s
.28761 .6571 m .28593 .67624 L .28912 .67811 L p .707 .577 .707 r
F P
0 g
s
.49863 .54105 m .49565 .5981 L .49265 .59345 L p .707 .577 .707 r
F P
0 g
s
.49265 .59345 m .49563 .53641 L .49863 .54105 L p .707 .577 .707 r
F P
0 g
s
.29198 .58583 m .29496 .52878 L .30193 .52474 L p .707 .577 .707 r
F P
0 g
s
.4953 .62015 m .49202 .65842 L .48884 .65637 L p .707 .577 .707 r
F P
0 g
s
.48884 .65637 m .49212 .6181 L .4953 .62015 L p .707 .577 .707 r
F P
0 g
s
.49085 .67553 m .48916 .69467 L .48597 .6928 L p .707 .577 .707 r
F P
0 g
s
.48597 .6928 m .48765 .67367 L .49085 .67553 L p .707 .577 .707 r
F P
0 g
s
.30193 .52474 m .29894 .58178 L .29198 .58583 L p .707 .577 .707 r
F P
0 g
s
.28875 .64039 m .29203 .60212 L .2988 .60095 L p .707 .577 .707 r
F P
0 g
s
.2988 .60095 m .29552 .63922 L .28875 .64039 L p .707 .577 .707 r
F P
0 g
s
.28593 .67624 m .28761 .6571 L .29436 .65614 L p .707 .577 .707 r
F P
0 g
s
.29436 .65614 m .29268 .67527 L .28593 .67624 L p .707 .577 .707 r
F P
0 g
s
.49563 .53641 m .49265 .59345 L .47997 .58866 L p .707 .577 .707 r
F P
0 g
s
.47997 .58866 m .48296 .53161 L .49563 .53641 L p .707 .577 .707 r
F P
0 g
s
.29894 .58178 m .30193 .52474 L .31819 .52169 L p .707 .577 .707 r
F P
0 g
s
.49212 .6181 m .48884 .65637 L .47602 .65364 L p .707 .577 .707 r
F P
0 g
s
.47602 .65364 m .47931 .61537 L .49212 .6181 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48765 .67367 m .48597 .6928 L .47314 .69021 L p .707 .577 .707 r
F P
0 g
s
.47314 .69021 m .47483 .67108 L .48765 .67367 L p .707 .577 .707 r
F P
0 g
s
.31819 .52169 m .3152 .57873 L .29894 .58178 L p .707 .577 .707 r
F P
0 g
s
.29552 .63922 m .2988 .60095 L .31486 .60078 L p .707 .577 .707 r
F P
0 g
s
.31486 .60078 m .31157 .63905 L .29552 .63922 L p .707 .577 .707 r
F P
0 g
s
.29268 .67527 m .29436 .65614 L .3104 .65617 L p .707 .577 .707 r
F P
0 g
s
.3104 .65617 m .30872 .6753 L .29268 .67527 L p .707 .577 .707 r
F P
0 g
s
.48296 .53161 m .47997 .58866 L .45886 .58419 L p .707 .577 .707 r
F P
0 g
s
.45886 .58419 m .46185 .52714 L .48296 .53161 L p .707 .577 .707 r
F P
0 g
s
.3152 .57873 m .31819 .52169 L .34214 .51993 L p .707 .577 .707 r
F P
0 g
s
.47931 .61537 m .47602 .65364 L .45482 .65049 L p .707 .577 .707 r
F P
0 g
s
.45482 .65049 m .45811 .61223 L .47931 .61537 L p .707 .577 .707 r
F P
0 g
s
.34214 .51993 m .33915 .57697 L .3152 .57873 L p .707 .577 .707 r
F P
0 g
s
.47483 .67108 m .47314 .69021 L .45193 .68716 L p .707 .577 .707 r
F P
0 g
s
.45193 .68716 m .45362 .66802 L .47483 .67108 L p .707 .577 .707 r
F P
0 g
s
.31157 .63905 m .31486 .60078 L .33863 .60163 L p .707 .577 .707 r
F P
0 g
s
.46185 .52714 m .45886 .58419 L .43139 .58048 L p .707 .577 .707 r
F P
0 g
s
.43139 .58048 m .43437 .52343 L .46185 .52714 L p .707 .577 .707 r
F P
0 g
s
.33863 .60163 m .33534 .63989 L .31157 .63905 L p .707 .577 .707 r
F P
0 g
s
.30872 .6753 m .3104 .65617 L .33416 .65719 L p .707 .577 .707 r
F P
0 g
s
.33416 .65719 m .33247 .67633 L .30872 .6753 L p .707 .577 .707 r
F P
0 g
s
.33915 .57697 m .34214 .51993 L .37144 .51964 L p .707 .577 .707 r
F P
0 g
s
.45811 .61223 m .45482 .65049 L .42732 .64724 L p .707 .577 .707 r
F P
0 g
s
.42732 .64724 m .4306 .60898 L .45811 .61223 L p .707 .577 .707 r
F P
0 g
s
.37144 .51964 m .36845 .57669 L .33915 .57697 L p .707 .577 .707 r
F P
0 g
s
.43437 .52343 m .43139 .58048 L .40023 .57789 L p .707 .577 .707 r
F P
0 g
s
.40023 .57789 m .40322 .52085 L .43437 .52343 L p .707 .577 .707 r
F P
0 g
s
.45362 .66802 m .45193 .68716 L .42442 .68394 L p .707 .577 .707 r
F P
0 g
s
.42442 .68394 m .42611 .6648 L .45362 .66802 L p .707 .577 .707 r
F P
0 g
s
.36845 .57669 m .37144 .51964 L .40322 .52085 L p .707 .577 .707 r
F P
0 g
s
.33534 .63989 m .33863 .60163 L .36778 .6034 L p .707 .577 .707 r
F P
0 g
s
.36778 .6034 m .3645 .64167 L .33534 .63989 L p .707 .577 .707 r
F P
0 g
s
.40322 .52085 m .40023 .57789 L .36845 .57669 L p .707 .577 .707 r
F P
0 g
s
.33247 .67633 m .33416 .65719 L .3633 .65911 L p .707 .577 .707 r
F P
0 g
s
.3633 .65911 m .36162 .67824 L .33247 .67633 L p .707 .577 .707 r
F P
0 g
s
.4306 .60898 m .42732 .64724 L .39619 .6442 L p .707 .577 .707 r
F P
0 g
s
.39619 .6442 m .39948 .60593 L .4306 .60898 L p .707 .577 .707 r
F P
0 g
s
.3645 .64167 m .36778 .6034 L .39948 .60593 L p .707 .577 .707 r
F P
0 g
s
.42611 .6648 m .42442 .68394 L .3933 .68087 L p .707 .577 .707 r
F P
0 g
s
.3933 .68087 m .39499 .66173 L .42611 .6648 L p .707 .577 .707 r
F P
0 g
s
.39948 .60593 m .39619 .6442 L .3645 .64167 L p .707 .577 .707 r
F P
0 g
s
.36162 .67824 m .3633 .65911 L .39499 .66173 L p .707 .577 .707 r
F P
0 g
s
.39499 .66173 m .3933 .68087 L .36162 .67824 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00O7oo4P00Sgoo001fOol60003FUH00`00FUIJEP0<FUH4002;
Ool0075oo`D000UJEP03001JEUYF011JEP@008Moo`00KWoo0`0000=JEP00FUH02eYF00<005YFFUH0
55YF0P00QGoo001/Ool20004FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20023
Ool006Uoo`<000IJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP80085oo`00Igoo
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH035YF0P00Ogoo001UOol3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001mOol006=oo`80
009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001oogoo07Yoo`00HGoo0P0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<007ooOol0NGoo001OOol20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomoo`1i
Ool005eoo`8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0007Yoo`00G7oo0P002UYF00<005YFFUH025YF00<005YFFUH02eYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH007Uoo`00Fgoo00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0007Qoo`00FWoo00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEWQoo`00FWoo
00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo07Eoo`00FGoo00<005YFFUH00UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0MGoo001HOol00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00Oomoo`1eOol005Moo`03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP8007Ioo`00Egoo00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00
EWoo0P001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00EWoo0P001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUIJEP8007Ioo`00EGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001f
Ool005Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1dOol005Ao
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007Eoo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2
001eOol005Eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001EOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Eoo`00EGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP04001JEUYFFUH2001eOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2001dOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00M7oo001EOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Aoo`00
EGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001dOol005Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00M7oo001FOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8007Aoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2001dOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
Oomoo`1bOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001cOol0
05Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Lgoo001FOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00EWoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001cOol005Moo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Lgoo001GOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00
Egoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001cOol005Moo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1aOol005Moo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo001GOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP80079oo`00Egoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH2001bOol005Moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo
001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80079oo`00F7oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH2001bOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000LWoo001HOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80075oo`00F7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001aOol005Qo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LGoo001IOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP80075oo`00FGoo00@005YFFUH000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH2001aOol005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00L7oo
001IOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80071oo`00FGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool005Uoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00L7oo001JOol01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP80071oo`00FWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool0
05Yoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000L7oo001JOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00FWoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001_Ool005Yoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Kgoo001KOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00
Fgoo00<005YFFUH040000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00F7oo1P000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF4@002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0KGoo001EOol30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00D005YFFUIJEP0006moo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006ioo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000UJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0K7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020009FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01@00FUIJEUYF0000KWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020009
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00002goo7P00AGoo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH8000m
Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P001Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEPL003Ioo`00Dgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04000bOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo001COol20002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`D000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0017oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005Ioo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00E7oo3@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00Oomoogoo001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP8002eoo`00Dgoo0P0015YF00@005YFFUIJEQ000003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000aJEP03001JEUYF00MJEP03001JEUYF00IJ
EP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eo
o`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF70000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP80009oo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo00<005YF000020001eYF00<005YF
FUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00<Goo1P00
0eYF00<005YFFUH01EYF00<005YFFUH00UYF300000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo0080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00=JEP8002ioo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
0003FUH0000002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<0
05YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH00008Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000h000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo
4`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000Aoo`00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ400003FUH0
05YF00IJEP04001JEUYFFUH6000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH2000017oo001JEP000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPd003Uoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF3`000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=goo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000EJEP00001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001oo`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP05000bOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEQ<000EJEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02@00FUIJEUYF001oo`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00003000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000UJ
EP03001JEUYF009JEQ80009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000<FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF3P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo
000/Ool20002FUHO0002FUHJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF6`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002mo
o`00;7oo1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2@000eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<005YF0000100000=JEP0000001P0015YF
00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00001EYF1`000eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP/000AJEP03001J
EP0000@0009JEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2000_Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF014000AJEP03001JEUYF00=JEPD0009JEP8000=JEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
15YF00@005YFFUIJEP800003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009J
EP8002moo`00;goo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00<000AJEP03
001JEUYF01<00003FUH0000000L000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUHJ
0006Ool@0003FUH01000FUIJEUYF1000;goo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH03UYF1P001UYF0P0000=JEP0000001`0025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000=Ool:000`Ool0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH5000<FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003moo`00@goo80000UYF00<005YFFUH01EYF
00<005YFFUH03eYF0`0015YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH025YF10001UYF
00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`00>7oo000]Ool@000UOol01000FUIJEP001eYF00<005YFFUH035YF0`00
1eYF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH035YF0P001EYF00D005YF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D003=oo`00;7oo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT001aoo`04001J
EUYF0007FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP0:FUH01000FUIJEUYF2`001eYF00@005YF
000000=JEP03001JEP00014000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000<002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@004goo00@005YFFUH000MJEP03001JEUYF00MJEP800003FUH005YF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF001JEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00@005YFFUIJEP8002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF3`0017oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP8000]JEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEPd0
00AJEP03001JEUYF00EJEQ4000=JEP03001JEUYF00=JEP03001JEUYF009JEP8002moo`00;7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P00
0eYF00<005YFFUH00eYF2`0015YF00<005YF000010000UYF00<005YFFUH015YF1P000eYF00@005YF
FUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF0P001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP0000000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000Woo2`000UYF00<005YF
FUH01EYF00<005YFFUH00UYF1@000UYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUH00006FUH20002FUH01@00FUIJEUYF00001UYF00<005YFFUH0
0UYF0`002Goo4P000eYF00<005YFFUH01000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF00006goo2P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP05FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP04001FOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001J
EUYF00AJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00@005YFFUIJEPH005Yoo`00:goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEUYFFUH0000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIoo`04
FUH01000FUIJEUYF2000H7oo000[OolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH2000;FUH2000;FUH00`00FUIJEP07FUH00`00OomJEP04FUH01000FUIJEP00Igoo000/Ool20000
0eYF001JEP04FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00gooFUH00009FUH00`00FUIJEP09FUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP02001VOol002ioo`@000=JEP03
001JEUYF00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP8000EJEP04001JEUYFFUH4001SOol0039oo`L000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03001JEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH5001NOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPD00003FUH00000009JEP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05001IOol0049ooa4000AJEP03001JEUYF00AJEP04001JEUYFFUH300001EYF
001JEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEP00
00<005Eoo`00Dgoo4P0000EJEP00FUIJEP0000IJEP03Ool005YF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol004Qoo`<001Uoo`<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol004Moo`D001Uoo`80009J
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001J
EUYF00MJEP03001JEUYF00AJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`T0
019oo`D001Uoo`03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00UJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP04001JEUYFFUH2001E
Ool002Yoo`<000AJEP04001JEUYFFUH@0002Ool5000IOol00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005Eoo`00:Woo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo00<005YFFUH00UYF00<005YF
FUH015YF00=oo`00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00
:Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF20003goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPH000Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03
001JEUYF009JEPH000AJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol002Yoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00P0009oo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF
0P00EWoo000ZOolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YF
FUH00UYF2@00EWoo000[Ool60003FUH00`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH02UYF00=oo`00FUH025YF00<005YFFUH02EYF00<005YF
FUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF6000EWoo000aOol70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<007ooOol0
K7oo000hOol90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P000goo
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF1000Kgoo0011Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
0003Ool01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH03eYF1@00Kgoo001:Ool@0003FUH01000FUIJEUYF100017oo00<005YF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF1@00Kgoo001J
Ool:0006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08001^Ool006]oo`80015JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP<000=JEP03001JEUYF009JEPP006Ioo`00KGoo0P001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEPL005mo
o`00Kgoo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH01EYF
0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00FWoo001aOol200000eYF001J
EP0EFUH00`00FUIJEP0:FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001FOol007=oo`<000UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEP0000/000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol007Ioo`@000EJEP03001JEUYF00UJEP03001JEUYF00MJEPD000AJEP03
001JEUYF00EJEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8005Ioo`00
NWoo100000=JEP00FUH02UYF00@005YFFUIJEP/000AJEP03001JEUYF00IJEP03001JEUYF00EJEPP0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2001GOol007iooa4000]oo`T000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000=JEP04001JEUYFFUH2001GOol00:=ooa4000AJEP03001JEUYF009JEPT0
05Moo`00]7oo4P00Egoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49193 .84878 m .43439 .4082 L .3905 .40746 L p .707 .577 .707 r
F P
0 g
s
.55648 .84817 m .55816 .82904 L .53065 .82582 L p .707 .577 .707 r
F P
0 g
s
.53065 .82582 m .52897 .84495 L .55648 .84817 L p .707 .577 .707 r
F P
0 g
s
.53175 .79367 m .53503 .7554 L .51383 .75226 L p .707 .577 .707 r
F P
0 g
s
.51383 .75226 m .51055 .79052 L .53175 .79367 L p .707 .577 .707 r
F P
0 g
s
.52897 .84495 m .53065 .82582 L .50944 .82276 L p .707 .577 .707 r
F P
0 g
s
.50944 .82276 m .50776 .8419 L .52897 .84495 L p .707 .577 .707 r
F P
0 g
s
.50377 .6688 m .50078 .72584 L .51346 .73063 L p .707 .577 .707 r
F P
0 g
s
.51055 .79052 m .51383 .75226 L .50102 .74953 L p .707 .577 .707 r
F P
0 g
s
.50102 .74953 m .49774 .78779 L .51055 .79052 L p .707 .577 .707 r
F P
0 g
s
.50776 .8419 m .50944 .82276 L .49661 .82017 L p .707 .577 .707 r
F P
0 g
s
.49661 .82017 m .49493 .83931 L .50776 .8419 L p .707 .577 .707 r
F P
0 g
s
.50078 .72584 m .50377 .6688 L .50077 .66415 L p .707 .577 .707 r
F P
0 g
s
.50077 .66415 m .49778 .72119 L .50078 .72584 L p .707 .577 .707 r
F P
0 g
s
.49774 .78779 m .50102 .74953 L .49784 .74748 L p .707 .577 .707 r
F P
0 g
s
.49784 .74748 m .49456 .78575 L .49774 .78779 L p .707 .577 .707 r
F P
0 g
s
.49493 .83931 m .49661 .82017 L .49342 .81831 L p .707 .577 .707 r
F P
0 g
s
.49342 .81831 m .49173 .83744 L .49493 .83931 L p .707 .577 .707 r
F P
0 g
s
.51346 .73063 m .51644 .67359 L .50377 .6688 L p .707 .577 .707 r
F P
0 g
s
.49778 .72119 m .50077 .66415 L .50774 .6601 L p .707 .577 .707 r
F P
0 g
s
.50774 .6601 m .50475 .71715 L .49778 .72119 L p .707 .577 .707 r
F P
0 g
s
.49456 .78575 m .49784 .74748 L .50461 .74631 L p .707 .577 .707 r
F P
0 g
s
.50461 .74631 m .50133 .78458 L .49456 .78575 L p .707 .577 .707 r
F P
0 g
s
.49173 .83744 m .49342 .81831 L .50017 .81734 L p .707 .577 .707 r
F P
0 g
s
.50017 .81734 m .49849 .83647 L .49173 .83744 L p .707 .577 .707 r
F P
0 g
s
.50475 .71715 m .50774 .6601 L .51142 .65941 L p .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .47899 .40146 L .45306 .40538 L p .707 .577 .707 r
F P
0 g
s
.56204 .73881 m .56503 .68177 L .53755 .67806 L p .707 .577 .707 r
F P
0 g
s
.53755 .67806 m .53457 .7351 L .56204 .73881 L p .707 .577 .707 r
F P
0 g
s
.56254 .75866 m .55926 .79692 L .59038 .79996 L p .707 .577 .707 r
F P
0 g
s
.55926 .79692 m .56254 .75866 L .53503 .7554 L p .707 .577 .707 r
F P
0 g
s
.53457 .7351 m .53755 .67806 L .51644 .67359 L p .707 .577 .707 r
F P
0 g
s
.51644 .67359 m .51346 .73063 L .53457 .7351 L p .707 .577 .707 r
F P
0 g
s
.47899 .40146 m .51433 .67207 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.55655 .73776 m .47899 .40146 L .52886 .70807 L .707 .577 .707 r
F
.52101 .71409 m .52172 .70041 L p .52544 .70441 L F P
0 g
s
.5876 .85124 m .58928 .83211 L .55816 .82904 L p .707 .577 .707 r
F P
0 g
s
.53503 .7554 m .53175 .79367 L .55926 .79692 L p .707 .577 .707 r
F P
0 g
s
.55816 .82904 m .55648 .84817 L .5876 .85124 L p .707 .577 .707 r
F P
0 g
s
.53362 .71317 m .52101 .71409 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .52066 .74615 L .54185 .7469 L p .707 .577 .707 r
F P
0 g
s
.54185 .7469 m .54443 .74699 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.51738 .78441 m .54185 .7469 L .54306 .74888 L .707 .577 .707 r
F
.50475 .71715 m .51142 .65941 L .51636 .6809 L F
.49664 .67262 m .51433 .67207 L .43439 .4082 L F
.52886 .70807 m .51433 .67207 L .52172 .70041 L F
.52399 .65705 m .52101 .71409 L .50475 .71715 L p F P
0 g
s
.50133 .78458 m .50461 .74631 L .52066 .74615 L p .707 .577 .707 r
F P
0 g
s
.52066 .74615 m .51738 .78441 L .50133 .78458 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .51738 .78441 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54443 .74699 m .54412 .75062 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.54412 .75062 m .54115 .78525 L p .54306 .74888 L .707 .577 .707 r
F P
0 g
s
.49849 .83647 m .50017 .81734 L .51621 .81737 L p .707 .577 .707 r
F P
0 g
s
.51621 .81737 m .51452 .8365 L .49849 .83647 L p .707 .577 .707 r
F P
0 g
s
.51452 .8365 m .51621 .81737 L .53996 .81839 L p .707 .577 .707 r
F P
0 g
s
.53996 .81839 m .53828 .83753 L .51452 .8365 L p .707 .577 .707 r
F P
0 g
s
.49193 .84878 m .53653 .84205 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.43439 .4082 m .46135 .61464 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.46135 .61464 m .49193 .84878 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.53653 .84205 m .51925 .70977 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.51925 .70977 m .51433 .67207 L p .49664 .67262 L .707 .577 .707 r
F P
0 g
s
.59038 .79996 m .59366 .7617 L .56254 .75866 L p .707 .577 .707 r
F P
0 g
s
.54115 .78525 m .54318 .76162 L p .57359 .74876 L .707 .577 .707 r
F P
0 g
s
.54318 .76162 m .54443 .74699 L .55319 .74752 L p .707 .577 .707 r
F P
0 g
s
.55319 .74752 m .57359 .74876 L p .54318 .76162 L .707 .577 .707 r
F P
0 g
s
.5932 .7414 m .59618 .68435 L .56503 .68177 L p .707 .577 .707 r
F P
0 g
s
.59618 .68435 m .5932 .7414 L .62498 .7426 L p .707 .577 .707 r
F P
0 g
s
.56503 .68177 m .56204 .73881 L .5932 .7414 L p .707 .577 .707 r
F P
0 g
s
.59366 .7617 m .59038 .79996 L .62207 .80249 L p .707 .577 .707 r
F P
0 g
s
.62207 .80249 m .62536 .76423 L .59366 .7617 L p .707 .577 .707 r
F P
0 g
s
.62498 .7426 m .62797 .68556 L .59618 .68435 L p .707 .577 .707 r
F P
0 g
s
.60903 .65621 m .60604 .71326 L .58378 .71241 L p .707 .577 .707 r
F P
0 g
s
.58378 .71241 m .57426 .71205 L p .58649 .6924 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .60903 .65621 L .58378 .71241 L .707 .577 .707 r
F
.62536 .76423 m .62207 .80249 L .65123 .80427 L p F P
0 g
s
.65123 .80427 m .65451 .766 L .62536 .76423 L p .707 .577 .707 r
F P
0 g
s
.62797 .68556 m .62498 .7426 L .65428 .74232 L p .707 .577 .707 r
F P
0 g
s
.65428 .74232 m .65727 .68527 L .62797 .68556 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .60671 .71331 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60669 .71221 m .63368 .66916 L .60671 .71331 L .707 .577 .707 r
F
.63368 .66916 m .64018 .6588 L .63371 .66934 L F
.63368 .66916 m .63371 .66934 L .60671 .71331 L F
.58483 .32212 m .57558 .3462 L p .60413 .52426 L F P
0 g
s
.60903 .65621 m .64018 .6588 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .6364 .75434 L .64646 .75552 L p .707 .577 .707 r
F P
0 g
s
.65451 .766 m .65123 .80427 L .675 .80511 L p .707 .577 .707 r
F P
0 g
s
.675 .80511 m .67828 .76685 L .65451 .766 L p .707 .577 .707 r
F P
0 g
s
.64646 .75552 m .66391 .75759 L p .64932 .77418 L .707 .577 .707 r
F P
0 g
s
.63312 .7926 m .64646 .75552 L .64932 .77418 L .707 .577 .707 r
F
.64236 .76271 m .6033 .46358 L p .60413 .52426 L F P
0 g
s
.6364 .75434 m .63312 .7926 L .60773 .79012 L p .707 .577 .707 r
F P
0 g
s
.60778 .78365 m .6364 .75434 L .60773 .79012 L .707 .577 .707 r
F
.602 .78956 m .60528 .7513 L .60802 .75156 L p F P
0 g
s
.60802 .75156 m .6364 .75434 L p .60778 .78365 L .707 .577 .707 r
F P
0 g
s
.602 .78956 m .60802 .75156 L .60778 .78365 L .707 .577 .707 r
F
.60475 .56956 m .60914 .60321 L p .60413 .52426 L F P
0 g
s
.60914 .60321 m .63311 .78679 L p .60938 .5718 L .707 .577 .707 r
F P
0 g
s
.60413 .52426 m .60914 .60321 L .60938 .5718 L .707 .577 .707 r
F
.63311 .78679 m .64236 .76271 L p .60948 .55766 L F P
0 g
s
.60948 .55766 m .60413 .52426 L .60938 .5718 L .707 .577 .707 r
F
.60948 .55766 m .60938 .5718 L .63311 .78679 L F
.60773 .79012 m .602 .78956 L p .60778 .78365 L F P
0 g
s
.64236 .76271 m .6376 .73959 L p .608 .50546 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .58483 .32212 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.608 .50546 m .59921 .43593 L .61078 .52349 L .707 .577 .707 r
F
.608 .50546 m .61078 .52349 L .64236 .76271 L F
.60604 .71326 m .60657 .70314 L p .60669 .71221 L F P
0 g
s
.60657 .70314 m .60903 .65621 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.58006 .299 m .58483 .32212 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6376 .73959 m .58831 .36214 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58831 .36214 m .58006 .299 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.58483 .32212 m .6033 .46358 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.6033 .46358 m .64236 .76271 L p .59921 .43593 L .707 .577 .707 r
F P
0 g
s
.64018 .6588 m .63808 .69891 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.63808 .69891 m .63719 .71584 L p .63371 .66934 L .707 .577 .707 r
F P
0 g
s
.60671 .71331 m .60604 .71326 L p .60669 .71221 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .60475 .56956 L p .60413 .52426 L .707 .577 .707 r
F P
0 g
s
.55322 .36887 m .59106 .65864 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57558 .3462 m .55322 .36887 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.58649 .6924 m .58753 .68473 L .60903 .65621 L .707 .577 .707 r
F
.59221 .65558 m .60903 .65621 L p .5748 .70161 L F P
0 g
s
.63311 .78679 m .60394 .56338 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.60394 .56338 m .57558 .3462 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .5748 .70161 L p .58753 .68473 L .707 .577 .707 r
F P
0 g
s
.57426 .71205 m .58753 .68473 L .58649 .6924 L .707 .577 .707 r
F
.51993 .38791 m .56346 .7212 L p .5829 .68019 L F P
0 g
s
.5748 .70161 m .57426 .71205 L .56873 .71211 L p .707 .577 .707 r
F P
0 g
s
.56346 .7212 m .56447 .72893 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.5829 .68019 m .56346 .7212 L .5748 .70161 L .707 .577 .707 r
F
.57359 .74876 m .57031 .78703 L .54115 .78525 L p F P
0 g
s
.57031 .78703 m .57359 .74876 L .58061 .74932 L p .707 .577 .707 r
F P
0 g
s
.58061 .74932 m .60528 .7513 L p .57445 .7828 L .707 .577 .707 r
F P
0 g
s
.57031 .78703 m .58061 .74932 L .57445 .7828 L .707 .577 .707 r
F
.60528 .7513 m .602 .78956 L .57031 .78703 L p F P
0 g
s
.61075 .80945 m .55322 .36887 L .51993 .38791 L p .707 .577 .707 r
F P
0 g
s
.5748 .70161 m .57724 .65501 L .59221 .65558 L p .707 .577 .707 r
F P
0 g
s
.59106 .65864 m .59365 .67849 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.59365 .67849 m .61075 .80945 L p .60053 .6411 L .707 .577 .707 r
F P
0 g
s
.59833 .60485 m .59365 .67849 L .60053 .6411 L .707 .577 .707 r
F
.56742 .83944 m .56911 .82031 L .60079 .82293 L p F P
0 g
s
.57747 .8285 m .51993 .38791 L .47899 .40146 L p .707 .577 .707 r
F P
0 g
s
.57724 .65501 m .5748 .70161 L p .54496 .71234 L .707 .577 .707 r
F P
0 g
s
.56873 .71211 m .54496 .71234 L p .5748 .70161 L .707 .577 .707 r
F P
0 g
s
.58712 .69976 m .5829 .68019 L .56477 .73123 L .707 .577 .707 r
F
.56447 .72893 m .56477 .73123 L p .5829 .68019 L F P
0 g
s
.61075 .80945 m .63311 .78679 L p .59833 .60485 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .61075 .80945 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.56477 .73123 m .57747 .8285 L p .58712 .69976 L .707 .577 .707 r
F P
0 g
s
.53828 .83753 m .53996 .81839 L .56911 .82031 L p .707 .577 .707 r
F P
0 g
s
.56911 .82031 m .56742 .83944 L .53828 .83753 L p .707 .577 .707 r
F P
0 g
s
.55691 .8353 m .57747 .8285 L p .52886 .70807 L .707 .577 .707 r
F P
0 g
s
.52886 .70807 m .52172 .70041 L .55691 .8353 L .707 .577 .707 r
F
.54794 .6553 m .54496 .71234 L .53362 .71317 L p F P
0 g
s
.52544 .70441 m .54794 .6553 L .53362 .71317 L .707 .577 .707 r
F
.52399 .65705 m .54794 .6553 L p .52544 .70441 L F P
0 g
s
.52172 .70041 m .52399 .65705 L p .52544 .70441 L .707 .577 .707 r
F P
0 g
s
.57747 .8285 m .55655 .73776 L .52886 .70807 L .707 .577 .707 r
F
.51636 .6809 m .51433 .67207 L .51651 .68043 L F
.51433 .67207 m .53653 .84205 L .55691 .8353 L p F P
0 g
s
.51142 .65941 m .52399 .65705 L p .51651 .68043 L .707 .577 .707 r
F P
0 g
s
.51433 .67207 m .51142 .65941 L .51651 .68043 L .707 .577 .707 r
F
.45306 .40538 m .43439 .4082 L p .51433 .67207 L F P
0 g
s
.44804 .84804 m .3905 .40746 L .35162 .39931 L p .707 .577 .707 r
F P
0 g
s
.3905 .40746 m .44804 .84804 L .49193 .84878 L p .707 .577 .707 r
F P
0 g
s
.40915 .8399 m .35162 .39931 L .32155 .38456 L p .707 .577 .707 r
F P
0 g
s
.35162 .39931 m .40915 .8399 L .44804 .84804 L p .707 .577 .707 r
F P
0 g
s
.65727 .68527 m .65428 .74232 L .67823 .74056 L p .707 .577 .707 r
F P
0 g
s
.67823 .74056 m .68122 .68352 L .65727 .68527 L p .707 .577 .707 r
F P
0 g
s
.58928 .83211 m .5876 .85124 L .61928 .85387 L p .707 .577 .707 r
F P
0 g
s
.61928 .85387 m .62096 .83473 L .58928 .83211 L p .707 .577 .707 r
F P
0 g
s
.62096 .83473 m .61928 .85387 L .64843 .85578 L p .707 .577 .707 r
F P
0 g
s
.64843 .85578 m .65011 .83665 L .62096 .83473 L p .707 .577 .707 r
F P
0 g
s
.68122 .68352 m .67823 .74056 L .69448 .73751 L p .707 .577 .707 r
F P
0 g
s
.69448 .73751 m .69747 .68047 L .68122 .68352 L p .707 .577 .707 r
F P
0 g
s
.65011 .83665 m .64843 .85578 L .67218 .85681 L p .707 .577 .707 r
F P
0 g
s
.67218 .85681 m .67386 .83767 L .65011 .83665 L p .707 .577 .707 r
F P
0 g
s
.35147 .70069 m .35446 .64365 L .33821 .6467 L p .707 .577 .707 r
F P
0 g
s
.35446 .64365 m .35147 .70069 L .35844 .69665 L p .707 .577 .707 r
F P
0 g
s
.35844 .69665 m .35916 .68297 L p .35446 .64365 L .707 .577 .707 r
F P
0 g
s
.37908 .82515 m .35999 .67891 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35689 .65518 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35999 .67891 m .35916 .68297 L .3626 .72506 L .707 .577 .707 r
F
.37908 .82515 m .40915 .8399 L p .34771 .52055 L F P
0 g
s
.35689 .65518 m .37908 .82515 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .36143 .6396 L .35604 .64273 L p .707 .577 .707 r
F P
0 g
s
.35604 .64273 m .35588 .64283 L p .35689 .65518 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35604 .64273 L .35689 .65518 L .707 .577 .707 r
F
.35588 .64283 m .35446 .64365 L p .35916 .68297 L F P
0 g
s
.32155 .38456 m .35689 .65518 L p .34771 .52055 L .707 .577 .707 r
F P
0 g
s
.35916 .68297 m .35844 .69665 L .35686 .6942 L p .707 .577 .707 r
F P
0 g
s
.32155 .38456 m .30323 .36465 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.35689 .65518 m .32155 .38456 L p .3626 .72506 L .707 .577 .707 r
F P
0 g
s
.33821 .6467 m .33522 .70374 L .35147 .70069 L p .707 .577 .707 r
F P
0 g
s
.34805 .76813 m .35133 .72986 L .33527 .73003 L p .707 .577 .707 r
F P
0 g
s
.35133 .72986 m .34805 .76813 L .35482 .76696 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .3581 .7287 L .35133 .72986 L p .707 .577 .707 r
F P
0 g
s
.35482 .76696 m .35164 .76491 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.3581 .7287 m .35618 .75107 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35618 .75107 m .35482 .76696 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.34546 .68996 m .30323 .36465 L .34444 .68365 L .707 .577 .707 r
F
.33527 .73003 m .33199 .7683 L .34805 .76813 L p F P
0 g
s
.33882 .76218 m .3421 .72392 L .35107 .72583 L p .707 .577 .707 r
F P
0 g
s
.35107 .72583 m .35492 .72665 L p .35221 .73263 L .707 .577 .707 r
F P
0 g
s
.33882 .76218 m .35107 .72583 L .35221 .73263 L .707 .577 .707 r
F
.35113 .73139 m .34807 .70797 L p .35054 .72912 L F P
0 g
s
.34807 .70797 m .34676 .69794 L p .34774 .70599 L .707 .577 .707 r
F P
0 g
s
.34807 .70797 m .34774 .70599 L .35054 .72912 L .707 .577 .707 r
F
.34676 .69794 m .30323 .36465 L p .34546 .68996 L F P
0 g
s
.34676 .69794 m .34546 .68996 L .35054 .72912 L .707 .577 .707 r
F
.30323 .36465 m .29847 .34152 L p .34444 .68365 L F P
0 g
s
.36077 .80524 m .37908 .82515 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.30323 .36465 m .34676 .69794 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .3581 .7287 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35164 .76491 m .35366 .74128 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35366 .74128 m .35492 .72665 L p .35496 .74631 L .707 .577 .707 r
F P
0 g
s
.35492 .72665 m .35164 .76491 L .33882 .76218 L p .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .36077 .80524 L p .35054 .72912 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .34332 .67676 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34516 .68811 m .34277 .68721 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.29847 .34152 m .30772 .31745 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.34277 .68721 m .33644 .68587 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.33522 .70374 m .33821 .6467 L .31426 .64846 L p .707 .577 .707 r
F P
0 g
s
.33636 .65067 m .33856 .64587 L .33644 .68587 L .707 .577 .707 r
F
.29847 .34152 m .33631 .63129 L p .34484 .68665 L F P
0 g
s
.34576 .63016 m .34332 .67676 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34277 .68721 L p .33856 .64587 L .707 .577 .707 r
F P
0 g
s
.35054 .72912 m .34484 .68665 L .34758 .71757 L .707 .577 .707 r
F
.33631 .63129 m .29847 .34152 L p .33622 .59168 L F P
0 g
s
.31426 .64846 m .31127 .7055 L .33522 .70374 L p .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .32465 .62569 L .3363 .62816 L p .707 .577 .707 r
F P
0 g
s
.3363 .62816 m .34576 .63016 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.32166 .68274 m .3363 .62816 L .33636 .65067 L .707 .577 .707 r
F
.34758 .71757 m .35601 .78211 L p .35054 .72912 L F P
0 g
s
.34676 .69794 m .36077 .80524 L p .35983 .70828 L .707 .577 .707 r
F P
0 g
s
.34576 .63016 m .35843 .63496 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.34332 .67676 m .34576 .63016 L p .34422 .68235 L .707 .577 .707 r
F P
0 g
s
.35843 .63496 m .35544 .692 L .34516 .68811 L p .707 .577 .707 r
F P
0 g
s
.34422 .68235 m .35843 .63496 L .34516 .68811 L .707 .577 .707 r
F
.35054 .72912 m .34546 .68996 L .34444 .68365 L F
.36077 .80524 m .35113 .73139 L p .35054 .72912 L F P
0 g
s
.36526 .75804 m .35601 .78211 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.30772 .31745 m .33608 .53463 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.36143 .6396 m .35916 .68297 L p .35544 .692 L .707 .577 .707 r
F P
0 g
s
.35686 .6942 m .35544 .692 L p .35916 .68297 L .707 .577 .707 r
F P
0 g
s
.35544 .692 m .35843 .63496 L .36143 .6396 L p .707 .577 .707 r
F P
0 g
s
.33608 .53463 m .36526 .75804 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33631 .63129 m .34758 .71757 L p .34484 .68665 L .707 .577 .707 r
F P
0 g
s
.35601 .78211 m .33631 .63129 L p .33622 .59168 L .707 .577 .707 r
F P
0 g
s
.33644 .68587 m .32166 .68274 L p .33636 .65067 L .707 .577 .707 r
F P
0 g
s
.67828 .76685 m .675 .80511 L .69106 .80494 L p .707 .577 .707 r
F P
0 g
s
.69106 .80494 m .69434 .76668 L .67828 .76685 L p .707 .577 .707 r
F P
0 g
s
.67386 .83767 m .67218 .85681 L .68822 .85684 L p .707 .577 .707 r
F P
0 g
s
.68822 .85684 m .6899 .8377 L .67386 .83767 L p .707 .577 .707 r
F P
0 g
s
.69747 .68047 m .69448 .73751 L .70145 .73346 L p .707 .577 .707 r
F P
0 g
s
.70145 .73346 m .70444 .67642 L .69747 .68047 L p .707 .577 .707 r
F P
0 g
s
.69434 .76668 m .69106 .80494 L .69783 .80378 L p .707 .577 .707 r
F P
0 g
s
.69783 .80378 m .70111 .76551 L .69434 .76668 L p .707 .577 .707 r
F P
0 g
s
.6899 .8377 m .68822 .85684 L .69497 .85587 L p .707 .577 .707 r
F P
0 g
s
.69497 .85587 m .69665 .83674 L .6899 .8377 L p .707 .577 .707 r
F P
0 g
s
.70444 .67642 m .70145 .73346 L .69845 .72881 L p .707 .577 .707 r
F P
0 g
s
.69845 .72881 m .70144 .67177 L .70444 .67642 L p .707 .577 .707 r
F P
0 g
s
.70111 .76551 m .69783 .80378 L .69465 .80173 L p .707 .577 .707 r
F P
0 g
s
.69465 .80173 m .69793 .76346 L .70111 .76551 L p .707 .577 .707 r
F P
0 g
s
.69665 .83674 m .69497 .85587 L .69177 .854 L p .707 .577 .707 r
F P
0 g
s
.69177 .854 m .69346 .83487 L .69665 .83674 L p .707 .577 .707 r
F P
0 g
s
.70144 .67177 m .69845 .72881 L .68578 .72402 L p .707 .577 .707 r
F P
0 g
s
.68578 .72402 m .68876 .66698 L .70144 .67177 L p .707 .577 .707 r
F P
0 g
s
.58006 .299 m .6376 .73959 L .61929 .71967 L p .707 .577 .707 r
F P
0 g
s
.61929 .71967 m .56175 .27909 L .58006 .299 L p .707 .577 .707 r
F P
0 g
s
.25019 .70458 m .25317 .64754 L .22202 .64495 L p .707 .577 .707 r
F P
0 g
s
.25317 .64754 m .25019 .70458 L .28197 .70579 L p .707 .577 .707 r
F P
0 g
s
.28197 .70579 m .28496 .64875 L .25317 .64754 L p .707 .577 .707 r
F P
0 g
s
.28496 .64875 m .28197 .70579 L .31127 .7055 L p .707 .577 .707 r
F P
0 g
s
.31127 .7055 m .31426 .64846 L .28496 .64875 L p .707 .577 .707 r
F P
0 g
s
.21903 .702 m .22202 .64495 L .19454 .64125 L p .707 .577 .707 r
F P
0 g
s
.22202 .64495 m .21903 .702 L .25019 .70458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69793 .76346 m .69465 .80173 L .68183 .799 L p .707 .577 .707 r
F P
0 g
s
.68183 .799 m .68511 .76073 L .69793 .76346 L p .707 .577 .707 r
F P
0 g
s
.19454 .64125 m .19156 .69829 L .21903 .702 L p .707 .577 .707 r
F P
0 g
s
.24737 .76315 m .25066 .72488 L .21953 .72184 L p .707 .577 .707 r
F P
0 g
s
.25066 .72488 m .24737 .76315 L .27906 .76568 L p .707 .577 .707 r
F P
0 g
s
.27906 .76568 m .28235 .72741 L .25066 .72488 L p .707 .577 .707 r
F P
0 g
s
.21953 .72184 m .21625 .76011 L .24737 .76315 L p .707 .577 .707 r
F P
0 g
s
.28235 .72741 m .27906 .76568 L .30822 .76745 L p .707 .577 .707 r
F P
0 g
s
.30822 .76745 m .3115 .72919 L .28235 .72741 L p .707 .577 .707 r
F P
0 g
s
.69346 .83487 m .69177 .854 L .67895 .85141 L p .707 .577 .707 r
F P
0 g
s
.67895 .85141 m .68063 .83228 L .69346 .83487 L p .707 .577 .707 r
F P
0 g
s
.21625 .76011 m .21953 .72184 L .19203 .71859 L p .707 .577 .707 r
F P
0 g
s
.19156 .69829 m .19454 .64125 L .17344 .63678 L p .707 .577 .707 r
F P
0 g
s
.24459 .81443 m .24627 .79529 L .21515 .79222 L p .707 .577 .707 r
F P
0 g
s
.24627 .79529 m .24459 .81443 L .27627 .81705 L p .707 .577 .707 r
F P
0 g
s
.27627 .81705 m .27796 .79792 L .24627 .79529 L p .707 .577 .707 r
F P
0 g
s
.68876 .66698 m .68578 .72402 L .66467 .71955 L p .707 .577 .707 r
F P
0 g
s
.66467 .71955 m .66766 .66251 L .68876 .66698 L p .707 .577 .707 r
F P
0 g
s
.19203 .71859 m .18874 .75685 L .21625 .76011 L p .707 .577 .707 r
F P
0 g
s
.21515 .79222 m .21347 .81136 L .24459 .81443 L p .707 .577 .707 r
F P
0 g
s
.36526 .75804 m .30772 .31745 L .33008 .29478 L p .707 .577 .707 r
F P
0 g
s
.27796 .79792 m .27627 .81705 L .30542 .81897 L p .707 .577 .707 r
F P
0 g
s
.30542 .81897 m .3071 .79983 L .27796 .79792 L p .707 .577 .707 r
F P
0 g
s
.21347 .81136 m .21515 .79222 L .18764 .789 L p .707 .577 .707 r
F P
0 g
s
.17344 .63678 m .17045 .69382 L .19156 .69829 L p .707 .577 .707 r
F P
0 g
s
.18764 .789 m .18596 .80814 L .21347 .81136 L p .707 .577 .707 r
F P
0 g
s
.3115 .72919 m .30822 .76745 L .33199 .7683 L p .707 .577 .707 r
F P
0 g
s
.33199 .7683 m .33527 .73003 L .3115 .72919 L p .707 .577 .707 r
F P
0 g
s
.56175 .27909 m .61929 .71967 L .58922 .70492 L p .707 .577 .707 r
F P
0 g
s
.58922 .70492 m .53168 .26434 L .56175 .27909 L p .707 .577 .707 r
F P
0 g
s
.18874 .75685 m .19203 .71859 L .17083 .71544 L p .707 .577 .707 r
F P
0 g
s
.3071 .79983 m .30542 .81897 L .32917 .81999 L p .707 .577 .707 r
F P
0 g
s
.32917 .81999 m .33086 .80086 L .3071 .79983 L p .707 .577 .707 r
F P
0 g
s
.17083 .71544 m .16754 .75371 L .18874 .75685 L p .707 .577 .707 r
F P
0 g
s
.68511 .76073 m .68183 .799 L .66063 .79585 L p .707 .577 .707 r
F P
0 g
s
.66063 .79585 m .66391 .75759 L .68511 .76073 L p .707 .577 .707 r
F P
0 g
s
.18596 .80814 m .18764 .789 L .16643 .78595 L p .707 .577 .707 r
F P
0 g
s
.17045 .69382 m .17344 .63678 L .16076 .63198 L p .707 .577 .707 r
F P
0 g
s
.16643 .78595 m .16475 .80508 L .18596 .80814 L p .707 .577 .707 r
F P
0 g
s
.66766 .66251 m .66467 .71955 L .63719 .71584 L p .707 .577 .707 r
F P
0 g
s
.63719 .71584 m .64018 .6588 L .66766 .66251 L p .707 .577 .707 r
F P
0 g
s
.68063 .83228 m .67895 .85141 L .65774 .84836 L p .707 .577 .707 r
F P
0 g
s
.65774 .84836 m .65942 .82922 L .68063 .83228 L p .707 .577 .707 r
F P
0 g
s
.54496 .71234 m .54794 .6553 L .57724 .65501 L p .707 .577 .707 r
F P
0 g
s
.16076 .63198 m .15777 .68903 L .17045 .69382 L p .707 .577 .707 r
F P
0 g
s
.33008 .29478 m .38762 .73537 L .36526 .75804 L p .707 .577 .707 r
F P
0 g
s
.38762 .73537 m .33008 .29478 L .36336 .27574 L p .707 .577 .707 r
F P
0 g
s
.33086 .80086 m .32917 .81999 L .34521 .82002 L p .707 .577 .707 r
F P
0 g
s
.34521 .82002 m .34689 .80089 L .33086 .80086 L p .707 .577 .707 r
F P
0 g
s
.16754 .75371 m .17083 .71544 L .15801 .71271 L p .707 .577 .707 r
F P
0 g
s
.53168 .26434 m .58922 .70492 L .55033 .69678 L p .707 .577 .707 r
F P
0 g
s
.55033 .69678 m .4928 .25619 L .53168 .26434 L p .707 .577 .707 r
F P
0 g
s
.15801 .71271 m .15473 .75098 L .16754 .75371 L p .707 .577 .707 r
F P
0 g
s
.66391 .75759 m .66063 .79585 L .63312 .7926 L p .707 .577 .707 r
F P
0 g
s
.16475 .80508 m .16643 .78595 L .15361 .78336 L p .707 .577 .707 r
F P
0 g
s
.15361 .78336 m .15192 .80249 L .16475 .80508 L p .707 .577 .707 r
F P
0 g
s
.65942 .82922 m .65774 .84836 L .63023 .84514 L p .707 .577 .707 r
F P
0 g
s
.63023 .84514 m .63191 .826 L .65942 .82922 L p .707 .577 .707 r
F P
0 g
s
.15777 .68903 m .16076 .63198 L .15776 .62733 L p .707 .577 .707 r
F P
0 g
s
.4209 .71633 m .36336 .27574 L .40431 .26219 L p .707 .577 .707 r
F P
0 g
s
.36336 .27574 m .4209 .71633 L .38762 .73537 L p .707 .577 .707 r
F P
0 g
s
.15776 .62733 m .15477 .68438 L .15777 .68903 L p .707 .577 .707 r
F P
0 g
s
.4928 .25619 m .55033 .69678 L .50644 .69604 L p .707 .577 .707 r
F P
0 g
s
.50644 .69604 m .44891 .25545 L .4928 .25619 L p .707 .577 .707 r
F P
0 g
s
.63191 .826 m .63023 .84514 L .59911 .84207 L p .707 .577 .707 r
F P
0 g
s
.59911 .84207 m .60079 .82293 L .63191 .826 L p .707 .577 .707 r
F P
0 g
s
.34689 .80089 m .34521 .82002 L .35196 .81906 L p .707 .577 .707 r
F P
0 g
s
.35196 .81906 m .35365 .79992 L .34689 .80089 L p .707 .577 .707 r
F P
0 g
s
.15473 .75098 m .15801 .71271 L .15483 .71067 L p .707 .577 .707 r
F P
0 g
s
.60079 .82293 m .59911 .84207 L .56742 .83944 L p .707 .577 .707 r
F P
0 g
s
.15483 .71067 m .15155 .74893 L .15473 .75098 L p .707 .577 .707 r
F P
0 g
s
.46184 .70278 m .40431 .26219 L .44891 .25545 L p .707 .577 .707 r
F P
0 g
s
.40431 .26219 m .46184 .70278 L .4209 .71633 L p .707 .577 .707 r
F P
0 g
s
.44891 .25545 m .50644 .69604 L .46184 .70278 L p .707 .577 .707 r
F P
0 g
s
.15192 .80249 m .15361 .78336 L .15041 .78149 L p .707 .577 .707 r
F P
0 g
s
.15041 .78149 m .14872 .80063 L .15192 .80249 L p .707 .577 .707 r
F P
0 g
s
.15477 .68438 m .15776 .62733 L .16473 .62329 L p .707 .577 .707 r
F P
0 g
s
.16473 .62329 m .16174 .68033 L .15477 .68438 L p .707 .577 .707 r
F P
0 g
s
.35365 .79992 m .35196 .81906 L .34877 .81719 L p .707 .577 .707 r
F P
0 g
s
.34877 .81719 m .35045 .79805 L .35365 .79992 L p .707 .577 .707 r
F P
0 g
s
.15155 .74893 m .15483 .71067 L .1616 .7095 L p .707 .577 .707 r
F P
0 g
s
.1616 .7095 m .15832 .74776 L .15155 .74893 L p .707 .577 .707 r
F P
0 g
s
.14872 .80063 m .15041 .78149 L .15716 .78052 L p .707 .577 .707 r
F P
0 g
s
.15716 .78052 m .15548 .79966 L .14872 .80063 L p .707 .577 .707 r
F P
0 g
s
.16174 .68033 m .16473 .62329 L .18098 .62024 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18098 .62024 m .178 .67728 L .16174 .68033 L p .707 .577 .707 r
F P
0 g
s
.35045 .79805 m .34877 .81719 L .33594 .8146 L p .707 .577 .707 r
F P
0 g
s
.33594 .8146 m .33762 .79546 L .35045 .79805 L p .707 .577 .707 r
F P
0 g
s
.15832 .74776 m .1616 .7095 L .17765 .70933 L p .707 .577 .707 r
F P
0 g
s
.17765 .70933 m .17437 .7476 L .15832 .74776 L p .707 .577 .707 r
F P
0 g
s
.15548 .79966 m .15716 .78052 L .1732 .78055 L p .707 .577 .707 r
F P
0 g
s
.1732 .78055 m .17151 .79969 L .15548 .79966 L p .707 .577 .707 r
F P
0 g
s
.178 .67728 m .18098 .62024 L .20493 .61848 L p .707 .577 .707 r
F P
0 g
s
.3421 .72392 m .33882 .76218 L .31762 .75904 L p .707 .577 .707 r
F P
0 g
s
.31762 .75904 m .3209 .72077 L .3421 .72392 L p .707 .577 .707 r
F P
0 g
s
.20493 .61848 m .20195 .67552 L .178 .67728 L p .707 .577 .707 r
F P
0 g
s
.32465 .62569 m .32166 .68274 L .29418 .67903 L p .707 .577 .707 r
F P
0 g
s
.29418 .67903 m .29717 .62198 L .32465 .62569 L p .707 .577 .707 r
F P
0 g
s
.33762 .79546 m .33594 .8146 L .31473 .81154 L p .707 .577 .707 r
F P
0 g
s
.31473 .81154 m .31641 .79241 L .33762 .79546 L p .707 .577 .707 r
F P
0 g
s
.17437 .7476 m .17765 .70933 L .20142 .71017 L p .707 .577 .707 r
F P
0 g
s
.20142 .71017 m .19814 .74844 L .17437 .7476 L p .707 .577 .707 r
F P
0 g
s
.20195 .67552 m .20493 .61848 L .23423 .61819 L p .707 .577 .707 r
F P
0 g
s
.17151 .79969 m .1732 .78055 L .19695 .78158 L p .707 .577 .707 r
F P
0 g
s
.19695 .78158 m .19527 .80071 L .17151 .79969 L p .707 .577 .707 r
F P
0 g
s
.23423 .61819 m .23125 .67524 L .20195 .67552 L p .707 .577 .707 r
F P
0 g
s
.29717 .62198 m .29418 .67903 L .26303 .67644 L p .707 .577 .707 r
F P
0 g
s
.26303 .67644 m .26602 .6194 L .29717 .62198 L p .707 .577 .707 r
F P
0 g
s
.3209 .72077 m .31762 .75904 L .29011 .75579 L p .707 .577 .707 r
F P
0 g
s
.29011 .75579 m .29339 .71752 L .3209 .72077 L p .707 .577 .707 r
F P
0 g
s
.7304 .64285 m .73339 .5858 L .70223 .58322 L p .707 .577 .707 r
F P
0 g
s
.73339 .5858 m .7304 .64285 L .76218 .64406 L p .707 .577 .707 r
F P
0 g
s
.76218 .64406 m .76517 .58701 L .73339 .5858 L p .707 .577 .707 r
F P
0 g
s
.23125 .67524 m .23423 .61819 L .26602 .6194 L p .707 .577 .707 r
F P
0 g
s
.76517 .58701 m .76218 .64406 L .79148 .64377 L p .707 .577 .707 r
F P
0 g
s
.79148 .64377 m .79447 .58672 L .76517 .58701 L p .707 .577 .707 r
F P
0 g
s
.26602 .6194 m .26303 .67644 L .23125 .67524 L p .707 .577 .707 r
F P
0 g
s
.19814 .74844 m .20142 .71017 L .23058 .71195 L p .707 .577 .707 r
F P
0 g
s
.69925 .64026 m .70223 .58322 L .67476 .57951 L p .707 .577 .707 r
F P
0 g
s
.70223 .58322 m .69925 .64026 L .7304 .64285 L p .707 .577 .707 r
F P
0 g
s
.31641 .79241 m .31473 .81154 L .28722 .80832 L p .707 .577 .707 r
F P
0 g
s
.28722 .80832 m .2889 .78919 L .31641 .79241 L p .707 .577 .707 r
F P
0 g
s
.23058 .71195 m .2273 .75021 L .19814 .74844 L p .707 .577 .707 r
F P
0 g
s
.72759 .69142 m .73087 .65315 L .69975 .65011 L p .707 .577 .707 r
F P
0 g
s
.73087 .65315 m .72759 .69142 L .75928 .69395 L p .707 .577 .707 r
F P
0 g
s
.75928 .69395 m .76256 .65568 L .73087 .65315 L p .707 .577 .707 r
F P
0 g
s
.19527 .80071 m .19695 .78158 L .2261 .78349 L p .707 .577 .707 r
F P
0 g
s
.69975 .65011 m .69646 .68838 L .72759 .69142 L p .707 .577 .707 r
F P
0 g
s
.67476 .57951 m .67177 .63656 L .69925 .64026 L p .707 .577 .707 r
F P
0 g
s
.2261 .78349 m .22441 .80263 L .19527 .80071 L p .707 .577 .707 r
F P
0 g
s
.76256 .65568 m .75928 .69395 L .78844 .69572 L p .707 .577 .707 r
F P
0 g
s
.78844 .69572 m .79172 .65746 L .76256 .65568 L p .707 .577 .707 r
F P
0 g
s
.29339 .71752 m .29011 .75579 L .25899 .75275 L p .707 .577 .707 r
F P
0 g
s
.25899 .75275 m .26227 .71448 L .29339 .71752 L p .707 .577 .707 r
F P
0 g
s
.79447 .58672 m .79148 .64377 L .81543 .64201 L p .707 .577 .707 r
F P
0 g
s
.81543 .64201 m .81842 .58497 L .79447 .58672 L p .707 .577 .707 r
F P
0 g
s
.7248 .72686 m .72649 .70772 L .69537 .70465 L p .707 .577 .707 r
F P
0 g
s
.72649 .70772 m .7248 .72686 L .75648 .72948 L p .707 .577 .707 r
F P
0 g
s
.75648 .72948 m .75817 .71035 L .72649 .70772 L p .707 .577 .707 r
F P
0 g
s
.69537 .70465 m .69368 .72379 L .7248 .72686 L p .707 .577 .707 r
F P
0 g
s
.69646 .68838 m .69975 .65011 L .67224 .64686 L p .707 .577 .707 r
F P
0 g
s
.2273 .75021 m .23058 .71195 L .26227 .71448 L p .707 .577 .707 r
F P
0 g
s
.75817 .71035 m .75648 .72948 L .78563 .7314 L p .707 .577 .707 r
F P
0 g
s
.78563 .7314 m .78731 .71226 L .75817 .71035 L p .707 .577 .707 r
F P
0 g
s
.67224 .64686 m .66896 .68513 L .69646 .68838 L p .707 .577 .707 r
F P
0 g
s
.26227 .71448 m .25899 .75275 L .2273 .75021 L p .707 .577 .707 r
F P
0 g
s
.67177 .63656 m .67476 .57951 L .65365 .57504 L p .707 .577 .707 r
F P
0 g
s
.69368 .72379 m .69537 .70465 L .66786 .70143 L p .707 .577 .707 r
F P
0 g
s
.66786 .70143 m .66617 .72057 L .69368 .72379 L p .707 .577 .707 r
F P
0 g
s
.2889 .78919 m .28722 .80832 L .2561 .80525 L p .707 .577 .707 r
F P
0 g
s
.2561 .80525 m .25778 .78612 L .2889 .78919 L p .707 .577 .707 r
F P
0 g
s
.22441 .80263 m .2261 .78349 L .25778 .78612 L p .707 .577 .707 r
F P
0 g
s
.25778 .78612 m .2561 .80525 L .22441 .80263 L p .707 .577 .707 r
F P
0 g
s
.79172 .65746 m .78844 .69572 L .81221 .69657 L p .707 .577 .707 r
F P
0 g
s
.81221 .69657 m .81549 .6583 L .79172 .65746 L p .707 .577 .707 r
F P
0 g
s
.65365 .57504 m .65066 .63209 L .67177 .63656 L p .707 .577 .707 r
F P
0 g
s
.78731 .71226 m .78563 .7314 L .80938 .73242 L p .707 .577 .707 r
F P
0 g
s
.80938 .73242 m .81107 .71329 L .78731 .71226 L p .707 .577 .707 r
F P
0 g
s
.66896 .68513 m .67224 .64686 L .65104 .64371 L p .707 .577 .707 r
F P
0 g
s
.65104 .64371 m .64776 .68198 L .66896 .68513 L p .707 .577 .707 r
F P
0 g
s
.81842 .58497 m .81543 .64201 L .83169 .63896 L p .707 .577 .707 r
F P
0 g
s
.83169 .63896 m .83467 .58192 L .81842 .58497 L p .707 .577 .707 r
F P
0 g
s
.66617 .72057 m .66786 .70143 L .64665 .69838 L p .707 .577 .707 r
F P
0 g
s
.64665 .69838 m .64496 .71751 L .66617 .72057 L p .707 .577 .707 r
F P
0 g
s
.65066 .63209 m .65365 .57504 L .64097 .57025 L p .707 .577 .707 r
F P
0 g
s
.81549 .6583 m .81221 .69657 L .82826 .6964 L p .707 .577 .707 r
F P
0 g
s
.82826 .6964 m .83154 .65813 L .81549 .6583 L p .707 .577 .707 r
F P
0 g
s
.81107 .71329 m .80938 .73242 L .82542 .73245 L p .707 .577 .707 r
F P
0 g
s
.82542 .73245 m .82711 .71332 L .81107 .71329 L p .707 .577 .707 r
F P
0 g
s
.64097 .57025 m .63799 .62729 L .65066 .63209 L p .707 .577 .707 r
F P
0 g
s
.64776 .68198 m .65104 .64371 L .63822 .64098 L p .707 .577 .707 r
F P
0 g
s
.63822 .64098 m .63494 .67925 L .64776 .68198 L p .707 .577 .707 r
F P
0 g
s
.64496 .71751 m .64665 .69838 L .63382 .69579 L p .707 .577 .707 r
F P
0 g
s
.63382 .69579 m .63213 .71492 L .64496 .71751 L p .707 .577 .707 r
F P
0 g
s
.83467 .58192 m .83169 .63896 L .83866 .63491 L p .707 .577 .707 r
F P
0 g
s
.83866 .63491 m .84164 .57787 L .83467 .58192 L p .707 .577 .707 r
F P
0 g
s
.63799 .62729 m .64097 .57025 L .63797 .5656 L p .707 .577 .707 r
F P
0 g
s
.83154 .65813 m .82826 .6964 L .83503 .69523 L p .707 .577 .707 r
F P
0 g
s
.83503 .69523 m .83831 .65697 L .83154 .65813 L p .707 .577 .707 r
F P
0 g
s
.82711 .71332 m .82542 .73245 L .83217 .73148 L p .707 .577 .707 r
F P
0 g
s
.83217 .73148 m .83386 .71235 L .82711 .71332 L p .707 .577 .707 r
F P
0 g
s
.63797 .5656 m .63499 .62264 L .63799 .62729 L p .707 .577 .707 r
F P
0 g
s
.63494 .67925 m .63822 .64098 L .63504 .63894 L p .707 .577 .707 r
F P
0 g
s
.63504 .63894 m .63176 .6772 L .63494 .67925 L p .707 .577 .707 r
F P
0 g
s
.63213 .71492 m .63382 .69579 L .63062 .69392 L p .707 .577 .707 r
F P
0 g
s
.63062 .69392 m .62894 .71305 L .63213 .71492 L p .707 .577 .707 r
F P
0 g
s
.84164 .57787 m .83866 .63491 L .83566 .63026 L p .707 .577 .707 r
F P
0 g
s
.83566 .63026 m .83864 .57322 L .84164 .57787 L p .707 .577 .707 r
F P
0 g
s
.63499 .62264 m .63797 .5656 L .64494 .56155 L p .707 .577 .707 r
F P
0 g
s
.83831 .65697 m .83503 .69523 L .83185 .69318 L p .707 .577 .707 r
F P
0 g
s
.83185 .69318 m .83513 .65492 L .83831 .65697 L p .707 .577 .707 r
F P
0 g
s
.83386 .71235 m .83217 .73148 L .82898 .72962 L p .707 .577 .707 r
F P
0 g
s
.82898 .72962 m .83066 .71048 L .83386 .71235 L p .707 .577 .707 r
F P
0 g
s
.64494 .56155 m .64196 .6186 L .63499 .62264 L p .707 .577 .707 r
F P
0 g
s
.63176 .6772 m .63504 .63894 L .64181 .63777 L p .707 .577 .707 r
F P
0 g
s
.64181 .63777 m .63853 .67603 L .63176 .6772 L p .707 .577 .707 r
F P
0 g
s
.62894 .71305 m .63062 .69392 L .63738 .69295 L p .707 .577 .707 r
F P
0 g
s
.63738 .69295 m .63569 .71209 L .62894 .71305 L p .707 .577 .707 r
F P
0 g
s
.83864 .57322 m .83566 .63026 L .82298 .62547 L p .707 .577 .707 r
F P
0 g
s
.82298 .62547 m .82597 .56843 L .83864 .57322 L p .707 .577 .707 r
F P
0 g
s
.38739 .60603 m .39038 .54899 L .35922 .5464 L p .707 .577 .707 r
F P
0 g
s
.39038 .54899 m .38739 .60603 L .41917 .60724 L p .707 .577 .707 r
F P
0 g
s
.41917 .60724 m .42216 .5502 L .39038 .54899 L p .707 .577 .707 r
F P
0 g
s
.42216 .5502 m .41917 .60724 L .44847 .60695 L p .707 .577 .707 r
F P
0 g
s
.44847 .60695 m .45146 .54991 L .42216 .5502 L p .707 .577 .707 r
F P
0 g
s
.64196 .6186 m .64494 .56155 L .6612 .5585 L p .707 .577 .707 r
F P
0 g
s
.35624 .60345 m .35922 .5464 L .33175 .5427 L p .707 .577 .707 r
F P
0 g
s
.35922 .5464 m .35624 .60345 L .38739 .60603 L p .707 .577 .707 r
F P
0 g
s
.83513 .65492 m .83185 .69318 L .81903 .69045 L p .707 .577 .707 r
F P
0 g
s
.81903 .69045 m .82232 .65219 L .83513 .65492 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83066 .71048 m .82898 .72962 L .81615 .72703 L p .707 .577 .707 r
F P
0 g
s
.81615 .72703 m .81784 .70789 L .83066 .71048 L p .707 .577 .707 r
F P
0 g
s
.38458 .6546 m .38786 .61634 L .35674 .6133 L p .707 .577 .707 r
F P
0 g
s
.38786 .61634 m .38458 .6546 L .41627 .65713 L p .707 .577 .707 r
F P
0 g
s
.41627 .65713 m .41955 .61887 L .38786 .61634 L p .707 .577 .707 r
F P
0 g
s
.6612 .5585 m .65821 .61555 L .64196 .6186 L p .707 .577 .707 r
F P
0 g
s
.35674 .6133 m .35345 .65156 L .38458 .6546 L p .707 .577 .707 r
F P
0 g
s
.33175 .5427 m .32876 .59974 L .35624 .60345 L p .707 .577 .707 r
F P
0 g
s
.41955 .61887 m .41627 .65713 L .44543 .65891 L p .707 .577 .707 r
F P
0 g
s
.44543 .65891 m .44871 .62064 L .41955 .61887 L p .707 .577 .707 r
F P
0 g
s
.45146 .54991 m .44847 .60695 L .47242 .6052 L p .707 .577 .707 r
F P
0 g
s
.47242 .6052 m .47541 .54815 L .45146 .54991 L p .707 .577 .707 r
F P
0 g
s
.38179 .69004 m .38348 .67091 L .35236 .66784 L p .707 .577 .707 r
F P
0 g
s
.38348 .67091 m .38179 .69004 L .41347 .69267 L p .707 .577 .707 r
F P
0 g
s
.41347 .69267 m .41516 .67353 L .38348 .67091 L p .707 .577 .707 r
F P
0 g
s
.35236 .66784 m .35067 .68697 L .38179 .69004 L p .707 .577 .707 r
F P
0 g
s
.63853 .67603 m .64181 .63777 L .65787 .6376 L p .707 .577 .707 r
F P
0 g
s
.35345 .65156 m .35674 .6133 L .32923 .61004 L p .707 .577 .707 r
F P
0 g
s
.41516 .67353 m .41347 .69267 L .44262 .69458 L p .707 .577 .707 r
F P
0 g
s
.44262 .69458 m .4443 .67545 L .41516 .67353 L p .707 .577 .707 r
F P
0 g
s
.65787 .6376 m .65458 .67587 L .63853 .67603 L p .707 .577 .707 r
F P
0 g
s
.32923 .61004 m .32595 .64831 L .35345 .65156 L p .707 .577 .707 r
F P
0 g
s
.63569 .71209 m .63738 .69295 L .65341 .69298 L p .707 .577 .707 r
F P
0 g
s
.32876 .59974 m .33175 .5427 L .31064 .53823 L p .707 .577 .707 r
F P
0 g
s
.35067 .68697 m .35236 .66784 L .32485 .66462 L p .707 .577 .707 r
F P
0 g
s
.65341 .69298 m .65173 .71212 L .63569 .71209 L p .707 .577 .707 r
F P
0 g
s
.32485 .66462 m .32316 .68375 L .35067 .68697 L p .707 .577 .707 r
F P
0 g
s
.82597 .56843 m .82298 .62547 L .80187 .621 L p .707 .577 .707 r
F P
0 g
s
.80187 .621 m .80486 .56396 L .82597 .56843 L p .707 .577 .707 r
F P
0 g
s
.44871 .62064 m .44543 .65891 L .4692 .65975 L p .707 .577 .707 r
F P
0 g
s
.4692 .65975 m .47248 .62149 L .44871 .62064 L p .707 .577 .707 r
F P
0 g
s
.31064 .53823 m .30765 .59527 L .32876 .59974 L p .707 .577 .707 r
F P
0 g
s
.4443 .67545 m .44262 .69458 L .46637 .69561 L p .707 .577 .707 r
F P
0 g
s
.46637 .69561 m .46806 .67647 L .4443 .67545 L p .707 .577 .707 r
F P
0 g
s
.65821 .61555 m .6612 .5585 L .68515 .55675 L p .707 .577 .707 r
F P
0 g
s
.32595 .64831 m .32923 .61004 L .30803 .6069 L p .707 .577 .707 r
F P
0 g
s
.30803 .6069 m .30475 .64516 L .32595 .64831 L p .707 .577 .707 r
F P
0 g
s
.47541 .54815 m .47242 .6052 L .48868 .60214 L p .707 .577 .707 r
F P
0 g
s
.48868 .60214 m .49166 .5451 L .47541 .54815 L p .707 .577 .707 r
F P
0 g
s
.82232 .65219 m .81903 .69045 L .79783 .68731 L p .707 .577 .707 r
F P
0 g
s
.79783 .68731 m .80112 .64904 L .82232 .65219 L p .707 .577 .707 r
F P
0 g
s
.32316 .68375 m .32485 .66462 L .30364 .66156 L p .707 .577 .707 r
F P
0 g
s
.30364 .66156 m .30195 .6807 L .32316 .68375 L p .707 .577 .707 r
F P
0 g
s
.68515 .55675 m .68216 .61379 L .65821 .61555 L p .707 .577 .707 r
F P
0 g
s
.81784 .70789 m .81615 .72703 L .79494 .72397 L p .707 .577 .707 r
F P
0 g
s
.79494 .72397 m .79663 .70484 L .81784 .70789 L p .707 .577 .707 r
F P
0 g
s
.65458 .67587 m .65787 .6376 L .68164 .63844 L p .707 .577 .707 r
F P
0 g
s
.30765 .59527 m .31064 .53823 L .29796 .53343 L p .707 .577 .707 r
F P
0 g
s
.80486 .56396 m .80187 .621 L .7744 .61729 L p .707 .577 .707 r
F P
0 g
s
.7744 .61729 m .77738 .56025 L .80486 .56396 L p .707 .577 .707 r
F P
0 g
s
.68164 .63844 m .67835 .67671 L .65458 .67587 L p .707 .577 .707 r
F P
0 g
s
.47248 .62149 m .4692 .65975 L .48525 .65958 L p .707 .577 .707 r
F P
0 g
s
.48525 .65958 m .48853 .62132 L .47248 .62149 L p .707 .577 .707 r
F P
0 g
s
.65173 .71212 m .65341 .69298 L .67717 .69401 L p .707 .577 .707 r
F P
0 g
s
.67717 .69401 m .67548 .71314 L .65173 .71212 L p .707 .577 .707 r
F P
0 g
s
.46806 .67647 m .46637 .69561 L .48241 .69564 L p .707 .577 .707 r
F P
0 g
s
.48241 .69564 m .4841 .6765 L .46806 .67647 L p .707 .577 .707 r
F P
0 g
s
.68216 .61379 m .68515 .55675 L .71445 .55646 L p .707 .577 .707 r
F P
0 g
s
.29796 .53343 m .29498 .59048 L .30765 .59527 L p .707 .577 .707 r
F P
0 g
s
.30475 .64516 m .30803 .6069 L .29521 .60417 L p .707 .577 .707 r
F P
0 g
s
.29521 .60417 m .29193 .64243 L .30475 .64516 L p .707 .577 .707 r
F P
0 g
s
.80112 .64904 m .79783 .68731 L .77033 .68406 L p .707 .577 .707 r
F P
0 g
s
.77033 .68406 m .77361 .64579 L .80112 .64904 L p .707 .577 .707 r
F P
0 g
s
.71445 .55646 m .71146 .6135 L .68216 .61379 L p .707 .577 .707 r
F P
0 g
s
.30195 .6807 m .30364 .66156 L .29081 .65897 L p .707 .577 .707 r
F P
0 g
s
.77738 .56025 m .7744 .61729 L .74324 .61471 L p .707 .577 .707 r
F P
0 g
s
.74324 .61471 m .74623 .55767 L .77738 .56025 L p .707 .577 .707 r
F P
0 g
s
.29081 .65897 m .28912 .67811 L .30195 .6807 L p .707 .577 .707 r
F P
0 g
s
.49166 .5451 m .48868 .60214 L .49565 .5981 L p .707 .577 .707 r
F P
0 g
s
.49565 .5981 m .49863 .54105 L .49166 .5451 L p .707 .577 .707 r
F P
0 g
s
.79663 .70484 m .79494 .72397 L .76743 .72075 L p .707 .577 .707 r
F P
0 g
s
.76743 .72075 m .76912 .70162 L .79663 .70484 L p .707 .577 .707 r
F P
0 g
s
.71146 .6135 m .71445 .55646 L .74623 .55767 L p .707 .577 .707 r
F P
0 g
s
.67835 .67671 m .68164 .63844 L .71079 .64022 L p .707 .577 .707 r
F P
0 g
s
.71079 .64022 m .70751 .67848 L .67835 .67671 L p .707 .577 .707 r
F P
0 g
s
.74623 .55767 m .74324 .61471 L .71146 .6135 L p .707 .577 .707 r
F P
0 g
s
.67548 .71314 m .67717 .69401 L .70631 .69592 L p .707 .577 .707 r
F P
0 g
s
.70631 .69592 m .70463 .71506 L .67548 .71314 L p .707 .577 .707 r
F P
0 g
s
.29498 .59048 m .29796 .53343 L .29496 .52878 L p .707 .577 .707 r
F P
0 g
s
.77361 .64579 m .77033 .68406 L .7392 .68102 L p .707 .577 .707 r
F P
0 g
s
.7392 .68102 m .74249 .64275 L .77361 .64579 L p .707 .577 .707 r
F P
0 g
s
.48853 .62132 m .48525 .65958 L .49202 .65842 L p .707 .577 .707 r
F P
0 g
s
.49202 .65842 m .4953 .62015 L .48853 .62132 L p .707 .577 .707 r
F P
0 g
s
.70751 .67848 m .71079 .64022 L .74249 .64275 L p .707 .577 .707 r
F P
0 g
s
.76912 .70162 m .76743 .72075 L .73631 .71768 L p .707 .577 .707 r
F P
0 g
s
.73631 .71768 m .738 .69855 L .76912 .70162 L p .707 .577 .707 r
F P
0 g
s
.4841 .6765 m .48241 .69564 L .48916 .69467 L p .707 .577 .707 r
F P
0 g
s
.48916 .69467 m .49085 .67553 L .4841 .6765 L p .707 .577 .707 r
F P
0 g
s
.74249 .64275 m .7392 .68102 L .70751 .67848 L p .707 .577 .707 r
F P
0 g
s
.29496 .52878 m .29198 .58583 L .29498 .59048 L p .707 .577 .707 r
F P
0 g
s
.70463 .71506 m .70631 .69592 L .738 .69855 L p .707 .577 .707 r
F P
0 g
s
.738 .69855 m .73631 .71768 L .70463 .71506 L p .707 .577 .707 r
F P
0 g
s
.29193 .64243 m .29521 .60417 L .29203 .60212 L p .707 .577 .707 r
F P
0 g
s
.29203 .60212 m .28875 .64039 L .29193 .64243 L p .707 .577 .707 r
F P
0 g
s
.28912 .67811 m .29081 .65897 L .28761 .6571 L p .707 .577 .707 r
F P
0 g
s
.28761 .6571 m .28593 .67624 L .28912 .67811 L p .707 .577 .707 r
F P
0 g
s
.49863 .54105 m .49565 .5981 L .49265 .59345 L p .707 .577 .707 r
F P
0 g
s
.49265 .59345 m .49563 .53641 L .49863 .54105 L p .707 .577 .707 r
F P
0 g
s
.29198 .58583 m .29496 .52878 L .30193 .52474 L p .707 .577 .707 r
F P
0 g
s
.4953 .62015 m .49202 .65842 L .48884 .65637 L p .707 .577 .707 r
F P
0 g
s
.48884 .65637 m .49212 .6181 L .4953 .62015 L p .707 .577 .707 r
F P
0 g
s
.49085 .67553 m .48916 .69467 L .48597 .6928 L p .707 .577 .707 r
F P
0 g
s
.48597 .6928 m .48765 .67367 L .49085 .67553 L p .707 .577 .707 r
F P
0 g
s
.30193 .52474 m .29894 .58178 L .29198 .58583 L p .707 .577 .707 r
F P
0 g
s
.28875 .64039 m .29203 .60212 L .2988 .60095 L p .707 .577 .707 r
F P
0 g
s
.2988 .60095 m .29552 .63922 L .28875 .64039 L p .707 .577 .707 r
F P
0 g
s
.28593 .67624 m .28761 .6571 L .29436 .65614 L p .707 .577 .707 r
F P
0 g
s
.29436 .65614 m .29268 .67527 L .28593 .67624 L p .707 .577 .707 r
F P
0 g
s
.49563 .53641 m .49265 .59345 L .47997 .58866 L p .707 .577 .707 r
F P
0 g
s
.47997 .58866 m .48296 .53161 L .49563 .53641 L p .707 .577 .707 r
F P
0 g
s
.29894 .58178 m .30193 .52474 L .31819 .52169 L p .707 .577 .707 r
F P
0 g
s
.49212 .6181 m .48884 .65637 L .47602 .65364 L p .707 .577 .707 r
F P
0 g
s
.47602 .65364 m .47931 .61537 L .49212 .6181 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48765 .67367 m .48597 .6928 L .47314 .69021 L p .707 .577 .707 r
F P
0 g
s
.47314 .69021 m .47483 .67108 L .48765 .67367 L p .707 .577 .707 r
F P
0 g
s
.31819 .52169 m .3152 .57873 L .29894 .58178 L p .707 .577 .707 r
F P
0 g
s
.29552 .63922 m .2988 .60095 L .31486 .60078 L p .707 .577 .707 r
F P
0 g
s
.31486 .60078 m .31157 .63905 L .29552 .63922 L p .707 .577 .707 r
F P
0 g
s
.29268 .67527 m .29436 .65614 L .3104 .65617 L p .707 .577 .707 r
F P
0 g
s
.3104 .65617 m .30872 .6753 L .29268 .67527 L p .707 .577 .707 r
F P
0 g
s
.48296 .53161 m .47997 .58866 L .45886 .58419 L p .707 .577 .707 r
F P
0 g
s
.45886 .58419 m .46185 .52714 L .48296 .53161 L p .707 .577 .707 r
F P
0 g
s
.3152 .57873 m .31819 .52169 L .34214 .51993 L p .707 .577 .707 r
F P
0 g
s
.47931 .61537 m .47602 .65364 L .45482 .65049 L p .707 .577 .707 r
F P
0 g
s
.45482 .65049 m .45811 .61223 L .47931 .61537 L p .707 .577 .707 r
F P
0 g
s
.34214 .51993 m .33915 .57697 L .3152 .57873 L p .707 .577 .707 r
F P
0 g
s
.47483 .67108 m .47314 .69021 L .45193 .68716 L p .707 .577 .707 r
F P
0 g
s
.45193 .68716 m .45362 .66802 L .47483 .67108 L p .707 .577 .707 r
F P
0 g
s
.31157 .63905 m .31486 .60078 L .33863 .60163 L p .707 .577 .707 r
F P
0 g
s
.46185 .52714 m .45886 .58419 L .43139 .58048 L p .707 .577 .707 r
F P
0 g
s
.43139 .58048 m .43437 .52343 L .46185 .52714 L p .707 .577 .707 r
F P
0 g
s
.33863 .60163 m .33534 .63989 L .31157 .63905 L p .707 .577 .707 r
F P
0 g
s
.30872 .6753 m .3104 .65617 L .33416 .65719 L p .707 .577 .707 r
F P
0 g
s
.33416 .65719 m .33247 .67633 L .30872 .6753 L p .707 .577 .707 r
F P
0 g
s
.33915 .57697 m .34214 .51993 L .37144 .51964 L p .707 .577 .707 r
F P
0 g
s
.45811 .61223 m .45482 .65049 L .42732 .64724 L p .707 .577 .707 r
F P
0 g
s
.42732 .64724 m .4306 .60898 L .45811 .61223 L p .707 .577 .707 r
F P
0 g
s
.37144 .51964 m .36845 .57669 L .33915 .57697 L p .707 .577 .707 r
F P
0 g
s
.43437 .52343 m .43139 .58048 L .40023 .57789 L p .707 .577 .707 r
F P
0 g
s
.40023 .57789 m .40322 .52085 L .43437 .52343 L p .707 .577 .707 r
F P
0 g
s
.45362 .66802 m .45193 .68716 L .42442 .68394 L p .707 .577 .707 r
F P
0 g
s
.42442 .68394 m .42611 .6648 L .45362 .66802 L p .707 .577 .707 r
F P
0 g
s
.36845 .57669 m .37144 .51964 L .40322 .52085 L p .707 .577 .707 r
F P
0 g
s
.33534 .63989 m .33863 .60163 L .36778 .6034 L p .707 .577 .707 r
F P
0 g
s
.36778 .6034 m .3645 .64167 L .33534 .63989 L p .707 .577 .707 r
F P
0 g
s
.40322 .52085 m .40023 .57789 L .36845 .57669 L p .707 .577 .707 r
F P
0 g
s
.33247 .67633 m .33416 .65719 L .3633 .65911 L p .707 .577 .707 r
F P
0 g
s
.3633 .65911 m .36162 .67824 L .33247 .67633 L p .707 .577 .707 r
F P
0 g
s
.4306 .60898 m .42732 .64724 L .39619 .6442 L p .707 .577 .707 r
F P
0 g
s
.39619 .6442 m .39948 .60593 L .4306 .60898 L p .707 .577 .707 r
F P
0 g
s
.3645 .64167 m .36778 .6034 L .39948 .60593 L p .707 .577 .707 r
F P
0 g
s
.42611 .6648 m .42442 .68394 L .3933 .68087 L p .707 .577 .707 r
F P
0 g
s
.3933 .68087 m .39499 .66173 L .42611 .6648 L p .707 .577 .707 r
F P
0 g
s
.39948 .60593 m .39619 .6442 L .3645 .64167 L p .707 .577 .707 r
F P
0 g
s
.36162 .67824 m .3633 .65911 L .39499 .66173 L p .707 .577 .707 r
F P
0 g
s
.39499 .66173 m .3933 .68087 L .36162 .67824 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00O7oo4P00Sgoo001fOol60003FUH00`00FUIJEP0<FUH4002;
Ool0075oo`D000UJEP03001JEUYF011JEP@008Moo`00KWoo0`0000=JEP00FUH02eYF00<005YFFUH0
55YF0P00QGoo001/Ool20004FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20023
Ool006Uoo`<000IJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP80085oo`00Igoo
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH035YF0P00Ogoo001UOol3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001mOol006=oo`80
009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001oogoo07Yoo`00HGoo0P0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<007ooOol0NGoo001OOol20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomoo`1i
Ool005eoo`8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0007Yoo`00G7oo0P002UYF00<005YFFUH025YF00<005YFFUH02eYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH007Uoo`00Fgoo00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0007Qoo`00FWoo00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEWQoo`00FWoo
00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo07Eoo`00FGoo00<005YFFUH00UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0MGoo001HOol00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00Oomoo`1eOol005Moo`03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP8007Ioo`00Egoo00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00
EWoo0P001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00EWoo0P001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUIJEP8007Ioo`00EGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001f
Ool005Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1dOol005Ao
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007Eoo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2
001eOol005Eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00MGoo001EOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007Eoo`00EGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP04001JEUYFFUH2001eOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2001dOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00M7oo001EOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Aoo`00
EGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001dOol005Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00M7oo001FOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8007Aoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH2001dOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
Oomoo`1bOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001cOol0
05Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Lgoo001FOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00EWoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001cOol005Moo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Lgoo001GOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8007=oo`00
Egoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001cOol005Moo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1aOol005Moo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo001GOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP80079oo`00Egoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH2001bOol005Moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LWoo
001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80079oo`00F7oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH2001bOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000LWoo001HOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80075oo`00F7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001aOol005Qo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00LGoo001IOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP80075oo`00FGoo00@005YFFUH000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH2001aOol005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`1_Ool005Uoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00L7oo
001IOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80071oo`00FGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool005Uoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00L7oo001JOol01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP80071oo`00FWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool0
05Yoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000L7oo001JOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00FWoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001_Ool005Yoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00Kgoo001KOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00
Fgoo00<005YFFUH040000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8006moo`00F7oo1P000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF4@002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0KGoo001EOol30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00D005YFFUIJEP0006moo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006ioo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001^
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000UJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0K7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020009FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01@00FUIJEUYF0000KWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020009
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00002goo7P00AGoo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH8000m
Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P001Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEPL003Ioo`00Dgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8000UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04000bOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo001COol20002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`D000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0017oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005Ioo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00E7oo3@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00Oomoogoo001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP8002eoo`00Dgoo0P0015YF00@005YFFUIJEQ000003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000aJEP03001JEUYF00MJEP03001JEUYF00IJ
EP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eo
o`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF70000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP80009oo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo00<005YF000020001eYF00<005YF
FUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00<Goo1P00
0eYF00<005YFFUH01EYF00<005YFFUH00UYF300000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo0080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00=JEP8002ioo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
0003FUH0000002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<0
05YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000Eoo`<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH00008Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000h000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo
4`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000Aoo`00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ400003FUH0
05YF00IJEP04001JEUYFFUH6000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH2000017oo001JEP000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPd003Uoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF3`000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=goo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000EJEP00001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001oo`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP05000bOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEQ<000EJEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02@00FUIJEUYF001oo`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00003000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000UJ
EP03001JEUYF009JEQ80009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000<FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF3P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo
000/Ool20002FUHO0002FUHJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF6`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002mo
o`00;7oo1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2@000eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<005YF0000100000=JEP0000001P0015YF
00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00001EYF1`000eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP/000AJEP03001J
EP0000@0009JEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2000_Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF014000AJEP03001JEUYF00=JEPD0009JEP8000=JEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
15YF00@005YFFUIJEP800003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009J
EP8002moo`00;goo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00<000AJEP03
001JEUYF01<00003FUH0000000L000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUHJ
0006Ool@0003FUH01000FUIJEUYF1000;goo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH03UYF1P001UYF0P0000=JEP0000001`0025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000=Ool:000`Ool0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH5000<FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003moo`00@goo80000UYF00<005YFFUH01EYF
00<005YFFUH03eYF0`0015YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH025YF10001UYF
00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`00>7oo000]Ool@000UOol01000FUIJEP001eYF00<005YFFUH035YF0`00
1eYF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH035YF0P001EYF00D005YF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D003=oo`00;7oo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT001aoo`04001J
EUYF0007FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP0:FUH01000FUIJEUYF2`001eYF00@005YF
000000=JEP03001JEP00014000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000<002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@004goo00@005YFFUH000MJEP03001JEUYF00MJEP800003FUH005YF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF001JEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00@005YFFUIJEP8002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF3`0017oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP8000]JEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEPd0
00AJEP03001JEUYF00EJEQ4000=JEP03001JEUYF00=JEP03001JEUYF009JEP8002moo`00;7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P00
0eYF00<005YFFUH00eYF2`0015YF00<005YF000010000UYF00<005YFFUH015YF1P000eYF00@005YF
FUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF0P001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP0000000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000Woo2`000UYF00<005YF
FUH01EYF00<005YFFUH00UYF1@000UYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUH00006FUH20002FUH01@00FUIJEUYF00001UYF00<005YFFUH0
0UYF0`002Goo4P000eYF00<005YFFUH01000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF00006goo2P00<7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP05FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP04001FOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001J
EUYF00AJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00@005YFFUIJEPH005Yoo`00:goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEUYFFUH0000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIoo`04
FUH01000FUIJEUYF2000H7oo000[OolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH2000;FUH2000;FUH00`00FUIJEP07FUH00`00OomJEP04FUH01000FUIJEP00Igoo000/Ool20000
0eYF001JEP04FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00gooFUH00009FUH00`00FUIJEP09FUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP02001VOol002ioo`@000=JEP03
001JEUYF00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP8000EJEP04001JEUYFFUH4001SOol0039oo`L000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03001JEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH5001NOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPD00003FUH00000009JEP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05001IOol0049ooa4000AJEP03001JEUYF00AJEP04001JEUYFFUH300001EYF
001JEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEP00
00<005Eoo`00Dgoo4P0000EJEP00FUIJEP0000IJEP03Ool005YF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol004Qoo`<001Uoo`<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol004Moo`D001Uoo`80009J
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001J
EUYF00MJEP03001JEUYF00AJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`T0
019oo`D001Uoo`03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00UJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJEP04001JEUYFFUH2001E
Ool002Yoo`<000AJEP04001JEUYFFUH@0002Ool5000IOol00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005Eoo`00:Woo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo00<005YFFUH00UYF00<005YF
FUH015YF00=oo`00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00
:Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF20003goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPH000Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03
001JEUYF009JEPH000AJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol002Yoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00P0009oo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF
0P00EWoo000ZOolA0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YF
FUH00UYF2@00EWoo000[Ool60003FUH00`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000=oo`00FUH02UYF00=oo`00FUH025YF00<005YFFUH02EYF00<005YF
FUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF6000EWoo000aOol70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<007ooOol0
K7oo000hOol90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P000goo
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF1000Kgoo0011Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
0003Ool01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH03eYF1@00Kgoo001:Ool@0003FUH01000FUIJEUYF100017oo00<005YF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF1@00Kgoo001J
Ool:0006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08001^Ool006]oo`80015JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP<000=JEP03001JEUYF009JEPP006Ioo`00KGoo0P001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEPL005mo
o`00Kgoo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH01EYF
0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00FWoo001aOol200000eYF001J
EP0EFUH00`00FUIJEP0:FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001FOol007=oo`<000UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEP0000/000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol007Ioo`@000EJEP03001JEUYF00UJEP03001JEUYF00MJEPD000AJEP03
001JEUYF00EJEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8005Ioo`00
NWoo100000=JEP00FUH02UYF00@005YFFUIJEP/000AJEP03001JEUYF00IJEP03001JEUYF00EJEPP0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2001GOol007iooa4000]oo`T000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000=JEP04001JEUYFFUH2001GOol00:=ooa4000AJEP03001JEUYF009JEPT0
05Moo`00]7oo4P00Egoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59423 .74459 m .59608 .68798 L .56491 .68566 L p .707 .577 .707 r
F P
0 g
s
.59608 .68798 m .59423 .74459 L .62605 .74504 L p .707 .577 .707 r
F P
0 g
s
.62605 .74504 m .6279 .68842 L .59608 .68798 L p .707 .577 .707 r
F P
0 g
s
.6279 .68842 m .62605 .74504 L .6554 .74356 L p .707 .577 .707 r
F P
0 g
s
.6554 .74356 m .65725 .68694 L .6279 .68842 L p .707 .577 .707 r
F P
0 g
s
.56307 .74227 m .56491 .68566 L .53745 .68169 L p .707 .577 .707 r
F P
0 g
s
.56491 .68566 m .56307 .74227 L .59423 .74459 L p .707 .577 .707 r
F P
0 g
s
.65725 .68694 m .6554 .74356 L .67941 .74031 L p .707 .577 .707 r
F P
0 g
s
.67941 .74031 m .68126 .68369 L .65725 .68694 L p .707 .577 .707 r
F P
0 g
s
.59234 .80394 m .59438 .7659 L .56323 .7633 L p .707 .577 .707 r
F P
0 g
s
.59438 .7659 m .59234 .80394 L .62412 .8052 L p .707 .577 .707 r
F P
0 g
s
.62412 .8052 m .62616 .76715 L .59438 .7659 L p .707 .577 .707 r
F P
0 g
s
.53745 .68169 m .5356 .7383 L .56307 .74227 L p .707 .577 .707 r
F P
0 g
s
.62616 .76715 m .62412 .8052 L .65342 .80498 L p .707 .577 .707 r
F P
0 g
s
.65342 .80498 m .65546 .76694 L .62616 .76715 L p .707 .577 .707 r
F P
0 g
s
.5356 .7383 m .53745 .68169 L .51637 .67645 L p .707 .577 .707 r
F P
0 g
s
.56323 .7633 m .56119 .80134 L .59234 .80394 L p .707 .577 .707 r
F P
0 g
s
.56119 .80134 m .56323 .7633 L .53575 .7596 L p .707 .577 .707 r
F P
0 g
s
.49099 .84163 m .45509 .37253 L .41113 .37108 L p .707 .577 .707 r
F P
0 g
s
.51637 .67645 m .51452 .73307 L .5356 .7383 L p .707 .577 .707 r
F P
0 g
s
.55946 .84894 m .56051 .82991 L .53303 .82624 L p .707 .577 .707 r
F P
0 g
s
.53303 .82624 m .53198 .84527 L .55946 .84894 L p .707 .577 .707 r
F P
0 g
s
.53371 .79765 m .53575 .7596 L .51464 .75518 L p .707 .577 .707 r
F P
0 g
s
.51464 .75518 m .5126 .79323 L .53371 .79765 L p .707 .577 .707 r
F P
0 g
s
.51452 .73307 m .51637 .67645 L .50375 .67047 L p .707 .577 .707 r
F P
0 g
s
.53198 .84527 m .53303 .82624 L .51192 .82187 L p .707 .577 .707 r
F P
0 g
s
.51192 .82187 m .51087 .8409 L .53198 .84527 L p .707 .577 .707 r
F P
0 g
s
.50375 .67047 m .5019 .72709 L .51452 .73307 L p .707 .577 .707 r
F P
0 g
s
.5126 .79323 m .51464 .75518 L .50196 .75047 L p .707 .577 .707 r
F P
0 g
s
.50196 .75047 m .49992 .78851 L .5126 .79323 L p .707 .577 .707 r
F P
0 g
s
.5019 .72709 m .50375 .67047 L .50081 .66432 L p .707 .577 .707 r
F P
0 g
s
.51087 .8409 m .51192 .82187 L .49923 .81724 L p .707 .577 .707 r
F P
0 g
s
.49923 .81724 m .49819 .83627 L .51087 .8409 L p .707 .577 .707 r
F P
0 g
s
.50081 .66432 m .49896 .72094 L .5019 .72709 L p .707 .577 .707 r
F P
0 g
s
.49992 .78851 m .50196 .75047 L .49896 .74591 L p .707 .577 .707 r
F P
0 g
s
.49896 .74591 m .49692 .78396 L .49992 .78851 L p .707 .577 .707 r
F P
0 g
s
.49819 .83627 m .49923 .81724 L .49622 .8128 L p .707 .577 .707 r
F P
0 g
s
.49896 .72094 m .50081 .66432 L .50785 .65861 L p .707 .577 .707 r
F P
0 g
s
.49622 .8128 m .49517 .83183 L .49819 .83627 L p .707 .577 .707 r
F P
0 g
s
.50785 .65861 m .506 .71523 L .49896 .72094 L p .707 .577 .707 r
F P
0 g
s
.49692 .78396 m .49896 .74591 L .50592 .74197 L p .707 .577 .707 r
F P
0 g
s
.50592 .74197 m .50388 .78002 L .49692 .78396 L p .707 .577 .707 r
F P
0 g
s
.49517 .83183 m .49622 .8128 L .50318 .80898 L p .707 .577 .707 r
F P
0 g
s
.506 .71523 m .50785 .65861 L .52418 .6539 L p .707 .577 .707 r
F P
0 g
s
.50318 .80898 m .50213 .82801 L .49517 .83183 L p .707 .577 .707 r
F P
0 g
s
.52418 .6539 m .52233 .71052 L .506 .71523 L p .707 .577 .707 r
F P
0 g
s
.50388 .78002 m .50592 .74197 L .52217 .73903 L p .707 .577 .707 r
F P
0 g
s
.52217 .73903 m .52013 .77707 L .50388 .78002 L p .707 .577 .707 r
F P
0 g
s
.50213 .82801 m .50318 .80898 L .51942 .80616 L p .707 .577 .707 r
F P
0 g
s
.51942 .80616 m .51837 .82519 L .50213 .82801 L p .707 .577 .707 r
F P
0 g
s
.52013 .77707 m .52217 .73903 L .54612 .73737 L p .707 .577 .707 r
F P
0 g
s
.53575 .7596 m .53371 .79765 L .56119 .80134 L p .707 .577 .707 r
F P
0 g
s
.54612 .73737 m .54408 .77541 L .52013 .77707 L p .707 .577 .707 r
F P
0 g
s
.51837 .82519 m .51942 .80616 L .54336 .80461 L p .707 .577 .707 r
F P
0 g
s
.54336 .80461 m .54231 .82364 L .51837 .82519 L p .707 .577 .707 r
F P
0 g
s
.45509 .37253 m .49099 .84163 L .5358 .83696 L p .707 .577 .707 r
F P
0 g
s
.52233 .71052 m .52418 .6539 L .52632 .65361 L p .707 .577 .707 r
F P
0 g
s
.59061 .85156 m .59166 .83253 L .56051 .82991 L p .707 .577 .707 r
F P
0 g
s
.56051 .82991 m .55946 .84894 L .59061 .85156 L p .707 .577 .707 r
F P
0 g
s
.5847 .69075 m .58798 .65242 L .60936 .64961 L .707 .577 .707 r
F
.57851 .64918 m .60936 .64961 L p .57739 .65381 L F P
0 g
s
.64052 .65193 m .63867 .70855 L .60954 .70638 L p .707 .577 .707 r
F P
0 g
s
.60954 .70638 m .60751 .70623 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60951 .70294 m .64052 .65193 L .60954 .70638 L .707 .577 .707 r
F
.60936 .64961 m .64052 .65193 L p .60951 .70294 L F P
0 g
s
.60751 .70623 m .60909 .65788 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.60909 .65788 m .60936 .64961 L p .60951 .70294 L .707 .577 .707 r
F P
0 g
s
.65546 .76694 m .65342 .80498 L .67737 .80333 L p .707 .577 .707 r
F P
0 g
s
.67737 .80333 m .6794 .76528 L .65546 .76694 L p .707 .577 .707 r
F P
0 g
s
.66582 .74471 m .66378 .78275 L .65334 .78135 L p .707 .577 .707 r
F P
0 g
s
.65334 .78135 m .63631 .77906 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.65133 .76157 m .66582 .74471 L .65334 .78135 L .707 .577 .707 r
F
.63631 .77906 m .63835 .74102 L .6494 .7425 L p F P
0 g
s
.6494 .7425 m .66582 .74471 L p .65133 .76157 L .707 .577 .707 r
F P
0 g
s
.63631 .77906 m .6494 .7425 L .65133 .76157 L .707 .577 .707 r
F
.60741 .30478 m .60585 .30792 L p .60794 .33385 L F P
0 g
s
.64331 .77388 m .60741 .30478 L .60794 .33385 L .707 .577 .707 r
F
.60585 .30792 m .5977 .32437 L p .60684 .41447 L F P
0 g
s
.64331 .77388 m .60585 .30792 L .60684 .41447 L .707 .577 .707 r
F
.60306 .28571 m .60741 .30478 L p .61283 .38218 L F P
0 g
s
.63835 .74102 m .63631 .77906 L .61015 .77687 L p .707 .577 .707 r
F P
0 g
s
.61017 .7711 m .63835 .74102 L .61015 .77687 L .707 .577 .707 r
F
.60515 .77646 m .60719 .73841 L .61029 .73867 L p F P
0 g
s
.61029 .73867 m .63835 .74102 L p .61017 .7711 L .707 .577 .707 r
F P
0 g
s
.60515 .77646 m .61029 .73867 L .61017 .7711 L .707 .577 .707 r
F
.60715 .44787 m .61115 .50016 L p .60684 .41447 L F P
0 g
s
.61115 .50016 m .63359 .79346 L p .61123 .47672 L .707 .577 .707 r
F P
0 g
s
.60684 .41447 m .61115 .50016 L .61123 .47672 L .707 .577 .707 r
F
.63359 .79346 m .64331 .77388 L p .6113 .45843 L F P
0 g
s
.6113 .45843 m .60684 .41447 L .61123 .47672 L .707 .577 .707 r
F
.6113 .45843 m .61123 .47672 L .63359 .79346 L F
.61015 .77687 m .60515 .77646 L p .61017 .7711 L F P
0 g
s
.63896 .75481 m .60311 .2863 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60311 .2863 m .60306 .28571 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.64331 .77388 m .63896 .75481 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.60741 .30478 m .61486 .4021 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.61486 .4021 m .64331 .77388 L p .61283 .38218 L .707 .577 .707 r
F P
0 g
s
.5977 .32437 m .60715 .44787 L p .60684 .41447 L .707 .577 .707 r
F P
0 g
s
.60936 .64961 m .60751 .70623 L .57569 .70578 L p .707 .577 .707 r
F P
0 g
s
.60338 .82483 m .60443 .8058 L .63558 .80842 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .63359 .79346 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57487 .34254 m .59357 .58692 L p .59877 .52608 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .57541 .73716 L .58182 .73741 L p .707 .577 .707 r
F P
0 g
s
.58182 .73741 m .60719 .73841 L p .578 .77017 L .707 .577 .707 r
F P
0 g
s
.57337 .7752 m .58182 .73741 L .578 .77017 L .707 .577 .707 r
F
.59357 .58692 m .59587 .61687 L p .59877 .52608 L F P
0 g
s
.60719 .73841 m .60515 .77646 L .57337 .7752 L p .707 .577 .707 r
F P
0 g
s
.59587 .61687 m .61077 .81164 L p .60081 .57448 L .707 .577 .707 r
F P
0 g
s
.59877 .52608 m .59587 .61687 L .60081 .57448 L .707 .577 .707 r
F
.57569 .70578 m .57739 .65381 L p .58798 .65242 L F P
0 g
s
.57569 .70578 m .58798 .65242 L .5847 .69075 L .707 .577 .707 r
F
.58302 .63055 m .54118 .35753 L .57739 .65381 L F
.57739 .65381 m .57754 .64917 L .57851 .64918 L p F P
0 g
s
.54118 .35753 m .56611 .6833 L p .57739 .65381 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .58302 .63055 L .57739 .65381 L .707 .577 .707 r
F
.5716 .82352 m .57265 .80449 L .60443 .8058 L p F P
0 g
s
.60443 .8058 m .60338 .82483 L .5716 .82352 L p .707 .577 .707 r
F P
0 g
s
.57707 .82662 m .61077 .81164 L p .58396 .63667 L .707 .577 .707 r
F P
0 g
s
.57569 .70578 m .55714 .70672 L p .56338 .69042 L .707 .577 .707 r
F P
0 g
s
.54634 .70726 m .55859 .68445 L .56338 .69042 L .707 .577 .707 r
F
.55714 .70672 m .54634 .70726 L p .56338 .69042 L F P
0 g
s
.57648 .68171 m .57569 .70578 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.54118 .35753 m .4999 .36786 L p .55329 .68527 L .707 .577 .707 r
F P
0 g
s
.5557 .6849 m .54118 .35753 L .55329 .68527 L .707 .577 .707 r
F
.54634 .70726 m .54703 .68623 L p .55859 .68445 L F P
0 g
s
.56971 .73036 m .54118 .35753 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .57754 .64917 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.55329 .68527 m .4999 .36786 L .54703 .68623 L .707 .577 .707 r
F
.54703 .68623 m .54819 .65065 L p .55859 .68445 L F P
0 g
s
.55658 .70482 m .5557 .6849 L .55329 .68527 L .707 .577 .707 r
F
.54408 .77541 m .5458 .74331 L p .57541 .73716 L F P
0 g
s
.5458 .74331 m .54612 .73737 L .5486 .73735 L p .707 .577 .707 r
F P
0 g
s
.5486 .73735 m .57541 .73716 L p .5458 .74331 L .707 .577 .707 r
F P
0 g
s
.57754 .64917 m .57739 .65381 L p .55859 .68445 L .707 .577 .707 r
F P
0 g
s
.57739 .65381 m .57648 .68171 L p .56611 .6833 L .707 .577 .707 r
F P
0 g
s
.55859 .68445 m .57739 .65381 L .56611 .6833 L .707 .577 .707 r
F
.56611 .6833 m .56721 .69773 L p .58396 .63667 L F P
0 g
s
.57541 .73716 m .57337 .7752 L .54408 .77541 L p .707 .577 .707 r
F P
0 g
s
.56721 .69773 m .57707 .82662 L p .58296 .66421 L .707 .577 .707 r
F P
0 g
s
.58396 .63667 m .56721 .69773 L .58296 .66421 L .707 .577 .707 r
F
.57707 .82662 m .56971 .73036 L p .55658 .70482 L F P
0 g
s
.54634 .70726 m .52233 .71052 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .52028 .63418 L p .54703 .68623 L .707 .577 .707 r
F P
0 g
s
.54819 .65065 m .54703 .68623 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.54703 .68623 m .54634 .70726 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.55658 .70482 m .55329 .68527 L .54703 .68623 L .707 .577 .707 r
F
.54231 .82364 m .54336 .80461 L .57265 .80449 L p F P
0 g
s
.57265 .80449 m .5716 .82352 L .54231 .82364 L p .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .57707 .82662 L p .55658 .70482 L .707 .577 .707 r
F P
0 g
s
.52632 .65361 m .53001 .65311 L p .53493 .68135 L .707 .577 .707 r
F P
0 g
s
.53493 .68135 m .53001 .65311 L .53931 .67121 L .707 .577 .707 r
F
.52233 .71052 m .52632 .65361 L .53493 .68135 L F
.52028 .63418 m .5358 .83696 L p .55658 .70482 L F P
0 g
s
.53001 .65311 m .54819 .65065 L p .53931 .67121 L .707 .577 .707 r
F P
0 g
s
.4999 .36786 m .45509 .37253 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.5358 .83696 m .52028 .63418 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.52028 .63418 m .4999 .36786 L p .47551 .49004 L .707 .577 .707 r
F P
0 g
s
.59166 .83253 m .59061 .85156 L .62239 .85287 L p .707 .577 .707 r
F P
0 g
s
.62239 .85287 m .62344 .83384 L .59166 .83253 L p .707 .577 .707 r
F P
0 g
s
.62344 .83384 m .62239 .85287 L .65168 .85275 L p .707 .577 .707 r
F P
0 g
s
.65168 .85275 m .65273 .83372 L .62344 .83384 L p .707 .577 .707 r
F P
0 g
s
.44702 .84018 m .41113 .37108 L .37232 .36365 L p .707 .577 .707 r
F P
0 g
s
.41113 .37108 m .44702 .84018 L .49099 .84163 L p .707 .577 .707 r
F P
0 g
s
.68126 .68369 m .67941 .74031 L .69574 .73559 L p .707 .577 .707 r
F P
0 g
s
.69574 .73559 m .69759 .67898 L .68126 .68369 L p .707 .577 .707 r
F P
0 g
s
.61077 .81164 m .57487 .34254 L .54118 .35753 L p .707 .577 .707 r
F P
0 g
s
.65273 .83372 m .65168 .85275 L .67562 .8512 L p .707 .577 .707 r
F P
0 g
s
.67562 .8512 m .67667 .83217 L .65273 .83372 L p .707 .577 .707 r
F P
0 g
s
.6794 .76528 m .67737 .80333 L .69361 .80038 L p .707 .577 .707 r
F P
0 g
s
.69361 .80038 m .69565 .76234 L .6794 .76528 L p .707 .577 .707 r
F P
0 g
s
.40821 .83275 m .37232 .36365 L .34246 .35097 L p .707 .577 .707 r
F P
0 g
s
.37232 .36365 m .40821 .83275 L .44702 .84018 L p .707 .577 .707 r
F P
0 g
s
.69759 .67898 m .69574 .73559 L .70277 .72988 L p .707 .577 .707 r
F P
0 g
s
.70277 .72988 m .70462 .67327 L .69759 .67898 L p .707 .577 .707 r
F P
0 g
s
.67667 .83217 m .67562 .8512 L .69186 .84838 L p .707 .577 .707 r
F P
0 g
s
.69186 .84838 m .69291 .82935 L .67667 .83217 L p .707 .577 .707 r
F P
0 g
s
.63359 .79346 m .5977 .32437 L .57487 .34254 L p .707 .577 .707 r
F P
0 g
s
.69565 .76234 m .69361 .80038 L .70058 .79644 L p .707 .577 .707 r
F P
0 g
s
.70058 .79644 m .70262 .7584 L .69565 .76234 L p .707 .577 .707 r
F P
0 g
s
.35977 .69307 m .36162 .63645 L .35458 .64216 L p .707 .577 .707 r
F P
0 g
s
.35458 .64216 m .35273 .69878 L .35977 .69307 L p .707 .577 .707 r
F P
0 g
s
.36162 .63645 m .35977 .69307 L .35683 .68692 L p .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35752 .66589 L p .36162 .63645 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .32448 .33427 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.36284 .61728 m .34246 .35097 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.3609 .63496 m .36162 .63645 L p .35752 .66589 L .707 .577 .707 r
F P
0 g
s
.33825 .64687 m .3364 .70349 L .35273 .69878 L p .707 .577 .707 r
F P
0 g
s
.35273 .69878 m .35458 .64216 L .33825 .64687 L p .707 .577 .707 r
F P
0 g
s
.35265 .72552 m .35061 .76357 L .35757 .75963 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35961 .72158 L .35265 .72552 L p .707 .577 .707 r
F P
0 g
s
.35757 .75963 m .35456 .75507 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35961 .72158 m .35904 .73221 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35904 .73221 m .35757 .75963 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .37836 .82006 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.32448 .33427 m .3494 .66004 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35683 .68692 m .35219 .68472 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35683 .68692 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.35219 .68472 m .34421 .68094 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.34962 .66199 m .35868 .63031 L .35219 .68472 L .707 .577 .707 r
F
.3566 .71703 m .35961 .72158 L p .35835 .72991 L F P
0 g
s
.35456 .75507 m .35628 .72297 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.35628 .72297 m .3566 .71703 L p .35835 .72991 L .707 .577 .707 r
F P
0 g
s
.3364 .72847 m .33436 .76651 L .35061 .76357 L p .707 .577 .707 r
F P
0 g
s
.35061 .76357 m .35265 .72552 L .3364 .72847 L p .707 .577 .707 r
F P
0 g
s
.3566 .71703 m .35456 .75507 L .34188 .75036 L p .707 .577 .707 r
F P
0 g
s
.34188 .75036 m .34392 .71231 L .3566 .71703 L p .707 .577 .707 r
F P
0 g
s
.35602 .78429 m .36037 .80337 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34799 .6475 m .32448 .33427 L .34624 .63197 L .707 .577 .707 r
F
.34421 .68094 m .3459 .62897 L p .34962 .66199 L F P
0 g
s
.35351 .71365 m .32448 .33427 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.34606 .62432 m .35868 .63031 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.32013 .3152 m .33883 .55958 L p .34624 .63197 L .707 .577 .707 r
F P
0 g
s
.31424 .65013 m .31239 .70674 L .3364 .70349 L p .707 .577 .707 r
F P
0 g
s
.3364 .70349 m .33825 .64687 L .31424 .65013 L p .707 .577 .707 r
F P
0 g
s
.34421 .68094 m .3391 .67967 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3391 .67967 m .32313 .67571 L p .33901 .64012 L .707 .577 .707 r
F P
0 g
s
.33901 .64012 m .34555 .62546 L .3391 .67967 L .707 .577 .707 r
F
.32448 .33427 m .32013 .3152 L p .34624 .63197 L F P
0 g
s
.32013 .3152 m .32984 .29562 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34421 .68094 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.34624 .63197 m .33883 .55958 L .3459 .62897 L .707 .577 .707 r
F
.32313 .67571 m .32498 .61909 L .34541 .62416 L p F P
0 g
s
.34541 .62416 m .34606 .62432 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.32313 .67571 m .34541 .62416 L .34555 .62546 L .707 .577 .707 r
F
.3404 .58009 m .34962 .7006 L p .34627 .63258 L F P
0 g
s
.34624 .63197 m .3459 .62897 L .34627 .63258 L .707 .577 .707 r
F
.3459 .62897 m .3404 .58009 L .34627 .63258 L F
.33883 .55958 m .3404 .58009 L p .3459 .62897 L F P
0 g
s
.34606 .62432 m .3459 .62897 L p .34555 .62546 L .707 .577 .707 r
F P
0 g
s
.3459 .62897 m .34606 .62432 L p .34962 .66199 L .707 .577 .707 r
F P
0 g
s
.35277 .71118 m .34624 .63197 L .34962 .7006 L .707 .577 .707 r
F
.34962 .7006 m .35602 .78429 L p .35277 .71118 L F P
0 g
s
.35277 .71118 m .34799 .6475 L .34624 .63197 L .707 .577 .707 r
F
.35602 .78429 m .33883 .55958 L p .3386 .4592 L F P
0 g
s
.33883 .55958 m .32013 .3152 L p .3386 .4592 L .707 .577 .707 r
F P
0 g
s
.3494 .66004 m .36037 .80337 L p .36158 .66882 L .707 .577 .707 r
F P
0 g
s
.35868 .63031 m .35752 .66589 L p .35468 .66384 L .707 .577 .707 r
F P
0 g
s
.36037 .80337 m .35351 .71365 L p .35277 .71118 L .707 .577 .707 r
F P
0 g
s
.35752 .66589 m .35868 .63031 L .3609 .63496 L p .707 .577 .707 r
F P
0 g
s
.37836 .82006 m .36284 .61728 L p .35937 .64892 L .707 .577 .707 r
F P
0 g
s
.34246 .35097 m .37836 .82006 L .40821 .83275 L p .707 .577 .707 r
F P
0 g
s
.69291 .82935 m .69186 .84838 L .69882 .84456 L p .707 .577 .707 r
F P
0 g
s
.69882 .84456 m .69987 .82553 L .69291 .82935 L p .707 .577 .707 r
F P
0 g
s
.70462 .67327 m .70277 .72988 L .69984 .72374 L p .707 .577 .707 r
F P
0 g
s
.69984 .72374 m .70169 .66712 L .70462 .67327 L p .707 .577 .707 r
F P
0 g
s
.70262 .7584 m .70058 .79644 L .69757 .79189 L p .707 .577 .707 r
F P
0 g
s
.69757 .79189 m .69961 .75385 L .70262 .7584 L p .707 .577 .707 r
F P
0 g
s
.69987 .82553 m .69882 .84456 L .69581 .84012 L p .707 .577 .707 r
F P
0 g
s
.69581 .84012 m .69686 .82109 L .69987 .82553 L p .707 .577 .707 r
F P
0 g
s
.70169 .66712 m .69984 .72374 L .68722 .71775 L p .707 .577 .707 r
F P
0 g
s
.68722 .71775 m .68907 .66114 L .70169 .66712 L p .707 .577 .707 r
F P
0 g
s
.25122 .70778 m .25307 .65116 L .22191 .64884 L p .707 .577 .707 r
F P
0 g
s
.25307 .65116 m .25122 .70778 L .28304 .70822 L p .707 .577 .707 r
F P
0 g
s
.28304 .70822 m .28489 .65161 L .25307 .65116 L p .707 .577 .707 r
F P
0 g
s
.28489 .65161 m .28304 .70822 L .31239 .70674 L p .707 .577 .707 r
F P
0 g
s
.31239 .70674 m .31424 .65013 L .28489 .65161 L p .707 .577 .707 r
F P
0 g
s
.22006 .70546 m .22191 .64884 L .19444 .64487 L p .707 .577 .707 r
F P
0 g
s
.22191 .64884 m .22006 .70546 L .25122 .70778 L p .707 .577 .707 r
F P
0 g
s
.69961 .75385 m .69757 .79189 L .68489 .78717 L p .707 .577 .707 r
F P
0 g
s
.68489 .78717 m .68693 .74913 L .69961 .75385 L p .707 .577 .707 r
F P
0 g
s
.24934 .76713 m .25138 .72908 L .22022 .72648 L p .707 .577 .707 r
F P
0 g
s
.25138 .72908 m .24934 .76713 L .28112 .76838 L p .707 .577 .707 r
F P
0 g
s
.28112 .76838 m .28316 .73034 L .25138 .72908 L p .707 .577 .707 r
F P
0 g
s
.19444 .64487 m .19259 .70149 L .22006 .70546 L p .707 .577 .707 r
F P
0 g
s
.28316 .73034 m .28112 .76838 L .31041 .76817 L p .707 .577 .707 r
F P
0 g
s
.31041 .76817 m .31245 .73013 L .28316 .73034 L p .707 .577 .707 r
F P
0 g
s
.68907 .66114 m .68722 .71775 L .66614 .71252 L p .707 .577 .707 r
F P
0 g
s
.66614 .71252 m .66799 .6559 L .68907 .66114 L p .707 .577 .707 r
F P
0 g
s
.19259 .70149 m .19444 .64487 L .17337 .63964 L p .707 .577 .707 r
F P
0 g
s
.22022 .72648 m .21818 .76452 L .24934 .76713 L p .707 .577 .707 r
F P
0 g
s
.69686 .82109 m .69581 .84012 L .68312 .83549 L p .707 .577 .707 r
F P
0 g
s
.68312 .83549 m .68417 .81646 L .69686 .82109 L p .707 .577 .707 r
F P
0 g
s
.21818 .76452 m .22022 .72648 L .19274 .72279 L p .707 .577 .707 r
F P
0 g
s
.2476 .81474 m .24865 .79571 L .2175 .79309 L p .707 .577 .707 r
F P
0 g
s
.24865 .79571 m .2476 .81474 L .27938 .81606 L p .707 .577 .707 r
F P
0 g
s
.27938 .81606 m .28043 .79703 L .24865 .79571 L p .707 .577 .707 r
F P
0 g
s
.19274 .72279 m .19071 .76083 L .21818 .76452 L p .707 .577 .707 r
F P
0 g
s
.2175 .79309 m .21645 .81212 L .2476 .81474 L p .707 .577 .707 r
F P
0 g
s
.28043 .79703 m .27938 .81606 L .30867 .81593 L p .707 .577 .707 r
F P
0 g
s
.30867 .81593 m .30972 .7969 L .28043 .79703 L p .707 .577 .707 r
F P
0 g
s
.31245 .73013 m .31041 .76817 L .33436 .76651 L p .707 .577 .707 r
F P
0 g
s
.33436 .76651 m .3364 .72847 L .31245 .73013 L p .707 .577 .707 r
F P
0 g
s
.17337 .63964 m .17152 .69625 L .19259 .70149 L p .707 .577 .707 r
F P
0 g
s
.21645 .81212 m .2175 .79309 L .19002 .78942 L p .707 .577 .707 r
F P
0 g
s
.19002 .78942 m .18897 .80845 L .21645 .81212 L p .707 .577 .707 r
F P
0 g
s
.19071 .76083 m .19274 .72279 L .17163 .71837 L p .707 .577 .707 r
F P
0 g
s
.68693 .74913 m .68489 .78717 L .66378 .78275 L p .707 .577 .707 r
F P
0 g
s
.66378 .78275 m .66582 .74471 L .68693 .74913 L p .707 .577 .707 r
F P
0 g
s
.30972 .7969 m .30867 .81593 L .33261 .81438 L p .707 .577 .707 r
F P
0 g
s
.33261 .81438 m .33366 .79535 L .30972 .7969 L p .707 .577 .707 r
F P
0 g
s
.17163 .71837 m .16959 .75641 L .19071 .76083 L p .707 .577 .707 r
F P
0 g
s
.66799 .6559 m .66614 .71252 L .63867 .70855 L p .707 .577 .707 r
F P
0 g
s
.63867 .70855 m .64052 .65193 L .66799 .6559 L p .707 .577 .707 r
F P
0 g
s
.17152 .69625 m .17337 .63964 L .16074 .63365 L p .707 .577 .707 r
F P
0 g
s
.18897 .80845 m .19002 .78942 L .16891 .78506 L p .707 .577 .707 r
F P
0 g
s
.60306 .28571 m .63896 .75481 L .62097 .73811 L p .707 .577 .707 r
F P
0 g
s
.62097 .73811 m .58508 .26902 L .60306 .28571 L p .707 .577 .707 r
F P
0 g
s
.68417 .81646 m .68312 .83549 L .66201 .83112 L p .707 .577 .707 r
F P
0 g
s
.66201 .83112 m .66306 .81209 L .68417 .81646 L p .707 .577 .707 r
F P
0 g
s
.16891 .78506 m .16786 .80409 L .18897 .80845 L p .707 .577 .707 r
F P
0 g
s
.16074 .63365 m .15889 .69027 L .17152 .69625 L p .707 .577 .707 r
F P
0 g
s
.16959 .75641 m .17163 .71837 L .15896 .71365 L p .707 .577 .707 r
F P
0 g
s
.33366 .79535 m .33261 .81438 L .34885 .81156 L p .707 .577 .707 r
F P
0 g
s
.34885 .81156 m .3499 .79253 L .33366 .79535 L p .707 .577 .707 r
F P
0 g
s
.15896 .71365 m .15692 .75169 L .16959 .75641 L p .707 .577 .707 r
F P
0 g
s
.15889 .69027 m .16074 .63365 L .15781 .62751 L p .707 .577 .707 r
F P
0 g
s
.16786 .80409 m .16891 .78506 L .15622 .78043 L p .707 .577 .707 r
F P
0 g
s
.36574 .76471 m .32984 .29562 L .35266 .27744 L p .707 .577 .707 r
F P
0 g
s
.32984 .29562 m .36574 .76471 L .35602 .78429 L p .707 .577 .707 r
F P
0 g
s
.66306 .81209 m .66201 .83112 L .63453 .82745 L p .707 .577 .707 r
F P
0 g
s
.63453 .82745 m .63558 .80842 L .66306 .81209 L p .707 .577 .707 r
F P
0 g
s
.15622 .78043 m .15518 .79946 L .16786 .80409 L p .707 .577 .707 r
F P
0 g
s
.15781 .62751 m .15596 .68412 L .15889 .69027 L p .707 .577 .707 r
F P
0 g
s
.58508 .26902 m .62097 .73811 L .59112 .72543 L p .707 .577 .707 r
F P
0 g
s
.59112 .72543 m .55522 .25633 L .58508 .26902 L p .707 .577 .707 r
F P
0 g
s
.63558 .80842 m .63453 .82745 L .60338 .82483 L p .707 .577 .707 r
F P
0 g
s
.15692 .75169 m .15896 .71365 L .15595 .7091 L p .707 .577 .707 r
F P
0 g
s
.3499 .79253 m .34885 .81156 L .35581 .80774 L p .707 .577 .707 r
F P
0 g
s
.35581 .80774 m .35686 .78871 L .3499 .79253 L p .707 .577 .707 r
F P
0 g
s
.15595 .7091 m .15391 .74714 L .15692 .75169 L p .707 .577 .707 r
F P
0 g
s
.15518 .79946 m .15622 .78043 L .15321 .77599 L p .707 .577 .707 r
F P
0 g
s
.15596 .68412 m .15781 .62751 L .16484 .6218 L p .707 .577 .707 r
F P
0 g
s
.15321 .77599 m .15217 .79502 L .15518 .79946 L p .707 .577 .707 r
F P
0 g
s
.35266 .27744 m .38856 .74654 L .36574 .76471 L p .707 .577 .707 r
F P
0 g
s
.38856 .74654 m .35266 .27744 L .38636 .26245 L p .707 .577 .707 r
F P
0 g
s
.16484 .6218 m .16299 .67841 L .15596 .68412 L p .707 .577 .707 r
F P
0 g
s
.55522 .25633 m .59112 .72543 L .55231 .71799 L p .707 .577 .707 r
F P
0 g
s
.55231 .71799 m .51641 .2489 L .55522 .25633 L p .707 .577 .707 r
F P
0 g
s
.15391 .74714 m .15595 .7091 L .16291 .70516 L p .707 .577 .707 r
F P
0 g
s
.35686 .78871 m .35581 .80774 L .3528 .8033 L p .707 .577 .707 r
F P
0 g
s
.3528 .8033 m .35385 .78427 L .35686 .78871 L p .707 .577 .707 r
F P
0 g
s
.16291 .70516 m .16087 .7432 L .15391 .74714 L p .707 .577 .707 r
F P
0 g
s
.15217 .79502 m .15321 .77599 L .16017 .77217 L p .707 .577 .707 r
F P
0 g
s
.42226 .73155 m .38636 .26245 L .42763 .25212 L p .707 .577 .707 r
F P
0 g
s
.38636 .26245 m .42226 .73155 L .38856 .74654 L p .707 .577 .707 r
F P
0 g
s
.16299 .67841 m .16484 .6218 L .18117 .61709 L p .707 .577 .707 r
F P
0 g
s
.16017 .77217 m .15912 .7912 L .15217 .79502 L p .707 .577 .707 r
F P
0 g
s
.51641 .2489 m .55231 .71799 L .50834 .71654 L p .707 .577 .707 r
F P
0 g
s
.50834 .71654 m .47245 .24745 L .51641 .2489 L p .707 .577 .707 r
F P
0 g
s
.18117 .61709 m .17932 .6737 L .16299 .67841 L p .707 .577 .707 r
F P
0 g
s
.46353 .72121 m .42763 .25212 L .47245 .24745 L p .707 .577 .707 r
F P
0 g
s
.42763 .25212 m .46353 .72121 L .42226 .73155 L p .707 .577 .707 r
F P
0 g
s
.47245 .24745 m .50834 .71654 L .46353 .72121 L p .707 .577 .707 r
F P
0 g
s
.16087 .7432 m .16291 .70516 L .17916 .70221 L p .707 .577 .707 r
F P
0 g
s
.35385 .78427 m .3528 .8033 L .34012 .79867 L p .707 .577 .707 r
F P
0 g
s
.34012 .79867 m .34116 .77964 L .35385 .78427 L p .707 .577 .707 r
F P
0 g
s
.17916 .70221 m .17712 .74026 L .16087 .7432 L p .707 .577 .707 r
F P
0 g
s
.17932 .6737 m .18117 .61709 L .20518 .61383 L p .707 .577 .707 r
F P
0 g
s
.15912 .7912 m .16017 .77217 L .17641 .76935 L p .707 .577 .707 r
F P
0 g
s
.17641 .76935 m .17536 .78838 L .15912 .7912 L p .707 .577 .707 r
F P
0 g
s
.34392 .71231 m .34188 .75036 L .32077 .74594 L p .707 .577 .707 r
F P
0 g
s
.32077 .74594 m .32281 .70789 L .34392 .71231 L p .707 .577 .707 r
F P
0 g
s
.20518 .61383 m .20333 .67045 L .17932 .6737 L p .707 .577 .707 r
F P
0 g
s
.32498 .61909 m .32313 .67571 L .29567 .67173 L p .707 .577 .707 r
F P
0 g
s
.29567 .67173 m .29752 .61512 L .32498 .61909 L p .707 .577 .707 r
F P
0 g
s
.17712 .74026 m .17916 .70221 L .20311 .70055 L p .707 .577 .707 r
F P
0 g
s
.20333 .67045 m .20518 .61383 L .23453 .61235 L p .707 .577 .707 r
F P
0 g
s
.34116 .77964 m .34012 .79867 L .319 .79431 L p .707 .577 .707 r
F P
0 g
s
.319 .79431 m .32005 .77528 L .34116 .77964 L p .707 .577 .707 r
F P
0 g
s
.20311 .70055 m .20107 .7386 L .17712 .74026 L p .707 .577 .707 r
F P
0 g
s
.29752 .61512 m .29567 .67173 L .2645 .66941 L p .707 .577 .707 r
F P
0 g
s
.2645 .66941 m .26635 .6128 L .29752 .61512 L p .707 .577 .707 r
F P
0 g
s
.17536 .78838 m .17641 .76935 L .20035 .7678 L p .707 .577 .707 r
F P
0 g
s
.23453 .61235 m .23268 .66897 L .20333 .67045 L p .707 .577 .707 r
F P
0 g
s
.20035 .7678 m .1993 .78683 L .17536 .78838 L p .707 .577 .707 r
F P
0 g
s
.32281 .70789 m .32077 .74594 L .2933 .74224 L p .707 .577 .707 r
F P
0 g
s
.2933 .74224 m .29534 .7042 L .32281 .70789 L p .707 .577 .707 r
F P
0 g
s
.73143 .64853 m .73328 .59192 L .70212 .5896 L p .707 .577 .707 r
F P
0 g
s
.73328 .59192 m .73143 .64853 L .76325 .64898 L p .707 .577 .707 r
F P
0 g
s
.76325 .64898 m .7651 .59236 L .73328 .59192 L p .707 .577 .707 r
F P
0 g
s
.23268 .66897 m .23453 .61235 L .26635 .6128 L p .707 .577 .707 r
F P
0 g
s
.7651 .59236 m .76325 .64898 L .7926 .6475 L p .707 .577 .707 r
F P
0 g
s
.7926 .6475 m .79445 .59088 L .7651 .59236 L p .707 .577 .707 r
F P
0 g
s
.26635 .6128 m .2645 .66941 L .23268 .66897 L p .707 .577 .707 r
F P
0 g
s
.20107 .7386 m .20311 .70055 L .2324 .70034 L p .707 .577 .707 r
F P
0 g
s
.70027 .64621 m .70212 .5896 L .67465 .58562 L p .707 .577 .707 r
F P
0 g
s
.70212 .5896 m .70027 .64621 L .73143 .64853 L p .707 .577 .707 r
F P
0 g
s
.32005 .77528 m .319 .79431 L .29152 .79063 L p .707 .577 .707 r
F P
0 g
s
.29152 .79063 m .29257 .7716 L .32005 .77528 L p .707 .577 .707 r
F P
0 g
s
.2324 .70034 m .23036 .73839 L .20107 .7386 L p .707 .577 .707 r
F P
0 g
s
.29534 .7042 m .2933 .74224 L .26214 .73964 L p .707 .577 .707 r
F P
0 g
s
.26214 .73964 m .26418 .7016 L .29534 .7042 L p .707 .577 .707 r
F P
0 g
s
.72955 .7017 m .73159 .66366 L .70043 .66106 L p .707 .577 .707 r
F P
0 g
s
.73159 .66366 m .72955 .7017 L .76133 .70296 L p .707 .577 .707 r
F P
0 g
s
.76133 .70296 m .76337 .66491 L .73159 .66366 L p .707 .577 .707 r
F P
0 g
s
.79445 .59088 m .7926 .6475 L .81661 .64424 L p .707 .577 .707 r
F P
0 g
s
.81661 .64424 m .81846 .58763 L .79445 .59088 L p .707 .577 .707 r
F P
0 g
s
.67465 .58562 m .6728 .64224 L .70027 .64621 L p .707 .577 .707 r
F P
0 g
s
.1993 .78683 m .20035 .7678 L .22964 .76767 L p .707 .577 .707 r
F P
0 g
s
.76337 .66491 m .76133 .70296 L .79063 .70275 L p .707 .577 .707 r
F P
0 g
s
.79063 .70275 m .79266 .6647 L .76337 .66491 L p .707 .577 .707 r
F P
0 g
s
.23036 .73839 m .2324 .70034 L .26418 .7016 L p .707 .577 .707 r
F P
0 g
s
.22964 .76767 m .22859 .7867 L .1993 .78683 L p .707 .577 .707 r
F P
0 g
s
.70043 .66106 m .6984 .6991 L .72955 .7017 L p .707 .577 .707 r
F P
0 g
s
.26418 .7016 m .26214 .73964 L .23036 .73839 L p .707 .577 .707 r
F P
0 g
s
.6984 .6991 m .70043 .66106 L .67296 .65736 L p .707 .577 .707 r
F P
0 g
s
.6728 .64224 m .67465 .58562 L .65358 .58039 L p .707 .577 .707 r
F P
0 g
s
.72782 .73953 m .72886 .7205 L .69771 .71788 L p .707 .577 .707 r
F P
0 g
s
.72886 .7205 m .72782 .73953 L .75959 .74084 L p .707 .577 .707 r
F P
0 g
s
.75959 .74084 m .76064 .72181 L .72886 .7205 L p .707 .577 .707 r
F P
0 g
s
.69771 .71788 m .69666 .73691 L .72782 .73953 L p .707 .577 .707 r
F P
0 g
s
.29257 .7716 m .29152 .79063 L .26037 .78801 L p .707 .577 .707 r
F P
0 g
s
.26037 .78801 m .26142 .76898 L .29257 .7716 L p .707 .577 .707 r
F P
0 g
s
.67296 .65736 m .67092 .69541 L .6984 .6991 L p .707 .577 .707 r
F P
0 g
s
.76064 .72181 m .75959 .74084 L .78889 .74072 L p .707 .577 .707 r
F P
0 g
s
.78889 .74072 m .78993 .72169 L .76064 .72181 L p .707 .577 .707 r
F P
0 g
s
.22859 .7867 m .22964 .76767 L .26142 .76898 L p .707 .577 .707 r
F P
0 g
s
.69666 .73691 m .69771 .71788 L .67023 .71421 L p .707 .577 .707 r
F P
0 g
s
.79266 .6647 m .79063 .70275 L .81457 .70109 L p .707 .577 .707 r
F P
0 g
s
.81457 .70109 m .81661 .66304 L .79266 .6647 L p .707 .577 .707 r
F P
0 g
s
.26142 .76898 m .26037 .78801 L .22859 .7867 L p .707 .577 .707 r
F P
0 g
s
.65358 .58039 m .65173 .63701 L .6728 .64224 L p .707 .577 .707 r
F P
0 g
s
.67023 .71421 m .66919 .73324 L .69666 .73691 L p .707 .577 .707 r
F P
0 g
s
.81846 .58763 m .81661 .64424 L .83294 .63953 L p .707 .577 .707 r
F P
0 g
s
.83294 .63953 m .83479 .58292 L .81846 .58763 L p .707 .577 .707 r
F P
0 g
s
.67092 .69541 m .67296 .65736 L .65185 .65294 L p .707 .577 .707 r
F P
0 g
s
.78993 .72169 m .78889 .74072 L .81282 .73917 L p .707 .577 .707 r
F P
0 g
s
.81282 .73917 m .81387 .72014 L .78993 .72169 L p .707 .577 .707 r
F P
0 g
s
.65185 .65294 m .64981 .69099 L .67092 .69541 L p .707 .577 .707 r
F P
0 g
s
.65173 .63701 m .65358 .58039 L .64095 .57441 L p .707 .577 .707 r
F P
0 g
s
.66919 .73324 m .67023 .71421 L .64912 .70984 L p .707 .577 .707 r
F P
0 g
s
.64912 .70984 m .64807 .72887 L .66919 .73324 L p .707 .577 .707 r
F P
0 g
s
.81661 .66304 m .81457 .70109 L .83082 .69814 L p .707 .577 .707 r
F P
0 g
s
.83082 .69814 m .83286 .6601 L .81661 .66304 L p .707 .577 .707 r
F P
0 g
s
.64095 .57441 m .6391 .63102 L .65173 .63701 L p .707 .577 .707 r
F P
0 g
s
.81387 .72014 m .81282 .73917 L .82907 .73635 L p .707 .577 .707 r
F P
0 g
s
.82907 .73635 m .83011 .71732 L .81387 .72014 L p .707 .577 .707 r
F P
0 g
s
.64981 .69099 m .65185 .65294 L .63917 .64823 L p .707 .577 .707 r
F P
0 g
s
.83479 .58292 m .83294 .63953 L .83998 .63382 L p .707 .577 .707 r
F P
0 g
s
.83998 .63382 m .84183 .57721 L .83479 .58292 L p .707 .577 .707 r
F P
0 g
s
.63917 .64823 m .63713 .68627 L .64981 .69099 L p .707 .577 .707 r
F P
0 g
s
.64807 .72887 m .64912 .70984 L .63644 .70521 L p .707 .577 .707 r
F P
0 g
s
.63644 .70521 m .63539 .72424 L .64807 .72887 L p .707 .577 .707 r
F P
0 g
s
.6391 .63102 m .64095 .57441 L .63802 .56826 L p .707 .577 .707 r
F P
0 g
s
.83286 .6601 m .83082 .69814 L .83778 .6942 L p .707 .577 .707 r
F P
0 g
s
.83778 .6942 m .83982 .65616 L .83286 .6601 L p .707 .577 .707 r
F P
0 g
s
.63802 .56826 m .63617 .62488 L .6391 .63102 L p .707 .577 .707 r
F P
0 g
s
.83011 .71732 m .82907 .73635 L .83602 .73253 L p .707 .577 .707 r
F P
0 g
s
.83602 .73253 m .83707 .7135 L .83011 .71732 L p .707 .577 .707 r
F P
0 g
s
.63713 .68627 m .63917 .64823 L .63616 .64367 L p .707 .577 .707 r
F P
0 g
s
.84183 .57721 m .83998 .63382 L .83704 .62767 L p .707 .577 .707 r
F P
0 g
s
.83704 .62767 m .83889 .57106 L .84183 .57721 L p .707 .577 .707 r
F P
0 g
s
.63616 .64367 m .63412 .68172 L .63713 .68627 L p .707 .577 .707 r
F P
0 g
s
.63539 .72424 m .63644 .70521 L .63343 .70077 L p .707 .577 .707 r
F P
0 g
s
.63343 .70077 m .63238 .7198 L .63539 .72424 L p .707 .577 .707 r
F P
0 g
s
.63617 .62488 m .63802 .56826 L .64506 .56255 L p .707 .577 .707 r
F P
0 g
s
.83982 .65616 m .83778 .6942 L .83478 .68965 L p .707 .577 .707 r
F P
0 g
s
.83478 .68965 m .83682 .65161 L .83982 .65616 L p .707 .577 .707 r
F P
0 g
s
.64506 .56255 m .64321 .61917 L .63617 .62488 L p .707 .577 .707 r
F P
0 g
s
.83707 .7135 m .83602 .73253 L .83301 .72809 L p .707 .577 .707 r
F P
0 g
s
.83301 .72809 m .83406 .70906 L .83707 .7135 L p .707 .577 .707 r
F P
0 g
s
.63412 .68172 m .63616 .64367 L .64313 .63973 L p .707 .577 .707 r
F P
0 g
s
.83889 .57106 m .83704 .62767 L .82442 .62169 L p .707 .577 .707 r
F P
0 g
s
.82442 .62169 m .82627 .56508 L .83889 .57106 L p .707 .577 .707 r
F P
0 g
s
.64313 .63973 m .64109 .67778 L .63412 .68172 L p .707 .577 .707 r
F P
0 g
s
.63238 .7198 m .63343 .70077 L .64038 .69695 L p .707 .577 .707 r
F P
0 g
s
.38842 .61172 m .39027 .5551 L .35911 .55278 L p .707 .577 .707 r
F P
0 g
s
.39027 .5551 m .38842 .61172 L .42024 .61216 L p .707 .577 .707 r
F P
0 g
s
.42024 .61216 m .42209 .55554 L .39027 .5551 L p .707 .577 .707 r
F P
0 g
s
.64038 .69695 m .63933 .71598 L .63238 .7198 L p .707 .577 .707 r
F P
0 g
s
.42209 .55554 m .42024 .61216 L .44959 .61068 L p .707 .577 .707 r
F P
0 g
s
.44959 .61068 m .45144 .55407 L .42209 .55554 L p .707 .577 .707 r
F P
0 g
s
.64321 .61917 m .64506 .56255 L .66138 .55784 L p .707 .577 .707 r
F P
0 g
s
.35726 .6094 m .35911 .55278 L .33164 .54881 L p .707 .577 .707 r
F P
0 g
s
.35911 .55278 m .35726 .6094 L .38842 .61172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83682 .65161 m .83478 .68965 L .8221 .68493 L p .707 .577 .707 r
F P
0 g
s
.8221 .68493 m .82414 .64689 L .83682 .65161 L p .707 .577 .707 r
F P
0 g
s
.66138 .55784 m .65953 .61445 L .64321 .61917 L p .707 .577 .707 r
F P
0 g
s
.38654 .66489 m .38858 .62684 L .35742 .62424 L p .707 .577 .707 r
F P
0 g
s
.38858 .62684 m .38654 .66489 L .41832 .66614 L p .707 .577 .707 r
F P
0 g
s
.41832 .66614 m .42036 .6281 L .38858 .62684 L p .707 .577 .707 r
F P
0 g
s
.45144 .55407 m .44959 .61068 L .4736 .60743 L p .707 .577 .707 r
F P
0 g
s
.4736 .60743 m .47545 .55081 L .45144 .55407 L p .707 .577 .707 r
F P
0 g
s
.33164 .54881 m .32979 .60542 L .35726 .6094 L p .707 .577 .707 r
F P
0 g
s
.42036 .6281 m .41832 .66614 L .44762 .66593 L p .707 .577 .707 r
F P
0 g
s
.44762 .66593 m .44965 .62789 L .42036 .6281 L p .707 .577 .707 r
F P
0 g
s
.83406 .70906 m .83301 .72809 L .82033 .72346 L p .707 .577 .707 r
F P
0 g
s
.82033 .72346 m .82138 .70443 L .83406 .70906 L p .707 .577 .707 r
F P
0 g
s
.35742 .62424 m .35539 .66228 L .38654 .66489 L p .707 .577 .707 r
F P
0 g
s
.64109 .67778 m .64313 .63973 L .65938 .63679 L p .707 .577 .707 r
F P
0 g
s
.82627 .56508 m .82442 .62169 L .80334 .61646 L p .707 .577 .707 r
F P
0 g
s
.80334 .61646 m .80519 .55984 L .82627 .56508 L p .707 .577 .707 r
F P
0 g
s
.35539 .66228 m .35742 .62424 L .32995 .62055 L p .707 .577 .707 r
F P
0 g
s
.32979 .60542 m .33164 .54881 L .31057 .54358 L p .707 .577 .707 r
F P
0 g
s
.38481 .70271 m .38585 .68368 L .3547 .68106 L p .707 .577 .707 r
F P
0 g
s
.38585 .68368 m .38481 .70271 L .41658 .70403 L p .707 .577 .707 r
F P
0 g
s
.41658 .70403 m .41763 .685 L .38585 .68368 L p .707 .577 .707 r
F P
0 g
s
.65938 .63679 m .65734 .67483 L .64109 .67778 L p .707 .577 .707 r
F P
0 g
s
.3547 .68106 m .35365 .70009 L .38481 .70271 L p .707 .577 .707 r
F P
0 g
s
.32995 .62055 m .32791 .65859 L .35539 .66228 L p .707 .577 .707 r
F P
0 g
s
.41763 .685 m .41658 .70403 L .44588 .7039 L p .707 .577 .707 r
F P
0 g
s
.44588 .7039 m .44692 .68487 L .41763 .685 L p .707 .577 .707 r
F P
0 g
s
.63933 .71598 m .64038 .69695 L .65662 .69413 L p .707 .577 .707 r
F P
0 g
s
.35365 .70009 m .3547 .68106 L .32722 .67739 L p .707 .577 .707 r
F P
0 g
s
.44965 .62789 m .44762 .66593 L .47156 .66427 L p .707 .577 .707 r
F P
0 g
s
.47156 .66427 m .4736 .62623 L .44965 .62789 L p .707 .577 .707 r
F P
0 g
s
.65953 .61445 m .66138 .55784 L .6854 .55458 L p .707 .577 .707 r
F P
0 g
s
.65662 .69413 m .65558 .71316 L .63933 .71598 L p .707 .577 .707 r
F P
0 g
s
.31057 .54358 m .30872 .60019 L .32979 .60542 L p .707 .577 .707 r
F P
0 g
s
.32722 .67739 m .32618 .69642 L .35365 .70009 L p .707 .577 .707 r
F P
0 g
s
.47545 .55081 m .4736 .60743 L .48993 .60272 L p .707 .577 .707 r
F P
0 g
s
.48993 .60272 m .49178 .5461 L .47545 .55081 L p .707 .577 .707 r
F P
0 g
s
.32791 .65859 m .32995 .62055 L .30884 .61613 L p .707 .577 .707 r
F P
0 g
s
.82414 .64689 m .8221 .68493 L .80099 .68051 L p .707 .577 .707 r
F P
0 g
s
.80099 .68051 m .80303 .64247 L .82414 .64689 L p .707 .577 .707 r
F P
0 g
s
.44692 .68487 m .44588 .7039 L .46981 .70235 L p .707 .577 .707 r
F P
0 g
s
.46981 .70235 m .47086 .68332 L .44692 .68487 L p .707 .577 .707 r
F P
0 g
s
.6854 .55458 m .68355 .6112 L .65953 .61445 L p .707 .577 .707 r
F P
0 g
s
.30884 .61613 m .3068 .65417 L .32791 .65859 L p .707 .577 .707 r
F P
0 g
s
.80519 .55984 m .80334 .61646 L .77588 .61249 L p .707 .577 .707 r
F P
0 g
s
.77588 .61249 m .77773 .55587 L .80519 .55984 L p .707 .577 .707 r
F P
0 g
s
.30872 .60019 m .31057 .54358 L .29794 .53759 L p .707 .577 .707 r
F P
0 g
s
.32618 .69642 m .32722 .67739 L .30611 .67303 L p .707 .577 .707 r
F P
0 g
s
.82138 .70443 m .82033 .72346 L .79922 .71909 L p .707 .577 .707 r
F P
0 g
s
.79922 .71909 m .80026 .70006 L .82138 .70443 L p .707 .577 .707 r
F P
0 g
s
.65734 .67483 m .65938 .63679 L .68332 .63513 L p .707 .577 .707 r
F P
0 g
s
.30611 .67303 m .30506 .69206 L .32618 .69642 L p .707 .577 .707 r
F P
0 g
s
.68355 .6112 m .6854 .55458 L .71475 .55311 L p .707 .577 .707 r
F P
0 g
s
.4736 .62623 m .47156 .66427 L .48781 .66133 L p .707 .577 .707 r
F P
0 g
s
.48781 .66133 m .48985 .62328 L .4736 .62623 L p .707 .577 .707 r
F P
0 g
s
.68332 .63513 m .68128 .67317 L .65734 .67483 L p .707 .577 .707 r
F P
0 g
s
.29794 .53759 m .29609 .59421 L .30872 .60019 L p .707 .577 .707 r
F P
0 g
s
.65558 .71316 m .65662 .69413 L .68056 .69258 L p .707 .577 .707 r
F P
0 g
s
.68056 .69258 m .67952 .71161 L .65558 .71316 L p .707 .577 .707 r
F P
0 g
s
.77773 .55587 m .77588 .61249 L .74471 .61017 L p .707 .577 .707 r
F P
0 g
s
.74471 .61017 m .74656 .55355 L .77773 .55587 L p .707 .577 .707 r
F P
0 g
s
.47086 .68332 m .46981 .70235 L .48606 .69953 L p .707 .577 .707 r
F P
0 g
s
.48606 .69953 m .4871 .6805 L .47086 .68332 L p .707 .577 .707 r
F P
0 g
s
.3068 .65417 m .30884 .61613 L .29616 .61141 L p .707 .577 .707 r
F P
0 g
s
.80303 .64247 m .80099 .68051 L .77351 .67682 L p .707 .577 .707 r
F P
0 g
s
.77351 .67682 m .77555 .63878 L .80303 .64247 L p .707 .577 .707 r
F P
0 g
s
.71475 .55311 m .7129 .60972 L .68355 .6112 L p .707 .577 .707 r
F P
0 g
s
.49178 .5461 m .48993 .60272 L .49697 .59701 L p .707 .577 .707 r
F P
0 g
s
.49697 .59701 m .49882 .54039 L .49178 .5461 L p .707 .577 .707 r
F P
0 g
s
.7129 .60972 m .71475 .55311 L .74656 .55355 L p .707 .577 .707 r
F P
0 g
s
.29616 .61141 m .29412 .64945 L .3068 .65417 L p .707 .577 .707 r
F P
0 g
s
.74656 .55355 m .74471 .61017 L .7129 .60972 L p .707 .577 .707 r
F P
0 g
s
.68128 .67317 m .68332 .63513 L .71262 .63492 L p .707 .577 .707 r
F P
0 g
s
.30506 .69206 m .30611 .67303 L .29343 .6684 L p .707 .577 .707 r
F P
0 g
s
.80026 .70006 m .79922 .71909 L .77174 .71542 L p .707 .577 .707 r
F P
0 g
s
.77174 .71542 m .77278 .69639 L .80026 .70006 L p .707 .577 .707 r
F P
0 g
s
.29343 .6684 m .29238 .68743 L .30506 .69206 L p .707 .577 .707 r
F P
0 g
s
.71262 .63492 m .71058 .67296 L .68128 .67317 L p .707 .577 .707 r
F P
0 g
s
.29609 .59421 m .29794 .53759 L .29501 .53144 L p .707 .577 .707 r
F P
0 g
s
.67952 .71161 m .68056 .69258 L .70986 .69246 L p .707 .577 .707 r
F P
0 g
s
.77555 .63878 m .77351 .67682 L .74236 .67422 L p .707 .577 .707 r
F P
0 g
s
.74236 .67422 m .7444 .63617 L .77555 .63878 L p .707 .577 .707 r
F P
0 g
s
.48985 .62328 m .48781 .66133 L .49477 .65739 L p .707 .577 .707 r
F P
0 g
s
.49477 .65739 m .49681 .61934 L .48985 .62328 L p .707 .577 .707 r
F P
0 g
s
.70986 .69246 m .70881 .71149 L .67952 .71161 L p .707 .577 .707 r
F P
0 g
s
.71058 .67296 m .71262 .63492 L .7444 .63617 L p .707 .577 .707 r
F P
0 g
s
.7444 .63617 m .74236 .67422 L .71058 .67296 L p .707 .577 .707 r
F P
0 g
s
.29501 .53144 m .29316 .58806 L .29609 .59421 L p .707 .577 .707 r
F P
0 g
s
.77278 .69639 m .77174 .71542 L .74058 .7128 L p .707 .577 .707 r
F P
0 g
s
.74058 .7128 m .74163 .69377 L .77278 .69639 L p .707 .577 .707 r
F P
0 g
s
.4871 .6805 m .48606 .69953 L .49301 .69571 L p .707 .577 .707 r
F P
0 g
s
.49301 .69571 m .49406 .67668 L .4871 .6805 L p .707 .577 .707 r
F P
0 g
s
.29412 .64945 m .29616 .61141 L .29315 .60686 L p .707 .577 .707 r
F P
0 g
s
.70881 .71149 m .70986 .69246 L .74163 .69377 L p .707 .577 .707 r
F P
0 g
s
.74163 .69377 m .74058 .7128 L .70881 .71149 L p .707 .577 .707 r
F P
0 g
s
.49882 .54039 m .49697 .59701 L .49403 .59086 L p .707 .577 .707 r
F P
0 g
s
.49403 .59086 m .49588 .53424 L .49882 .54039 L p .707 .577 .707 r
F P
0 g
s
.29315 .60686 m .29111 .6449 L .29412 .64945 L p .707 .577 .707 r
F P
0 g
s
.29238 .68743 m .29343 .6684 L .29042 .66396 L p .707 .577 .707 r
F P
0 g
s
.29042 .66396 m .28937 .68299 L .29238 .68743 L p .707 .577 .707 r
F P
0 g
s
.29316 .58806 m .29501 .53144 L .30205 .52574 L p .707 .577 .707 r
F P
0 g
s
.49681 .61934 m .49477 .65739 L .49177 .65283 L p .707 .577 .707 r
F P
0 g
s
.49177 .65283 m .49381 .61479 L .49681 .61934 L p .707 .577 .707 r
F P
0 g
s
.30205 .52574 m .3002 .58235 L .29316 .58806 L p .707 .577 .707 r
F P
0 g
s
.49406 .67668 m .49301 .69571 L .49 .69127 L p .707 .577 .707 r
F P
0 g
s
.49 .69127 m .49105 .67224 L .49406 .67668 L p .707 .577 .707 r
F P
0 g
s
.29111 .6449 m .29315 .60686 L .30012 .60292 L p .707 .577 .707 r
F P
0 g
s
.49588 .53424 m .49403 .59086 L .48141 .58488 L p .707 .577 .707 r
F P
0 g
s
.48141 .58488 m .48326 .52826 L .49588 .53424 L p .707 .577 .707 r
F P
0 g
s
.30012 .60292 m .29808 .64096 L .29111 .6449 L p .707 .577 .707 r
F P
0 g
s
.28937 .68299 m .29042 .66396 L .29737 .66014 L p .707 .577 .707 r
F P
0 g
s
.29737 .66014 m .29632 .67917 L .28937 .68299 L p .707 .577 .707 r
F P
0 g
s
.3002 .58235 m .30205 .52574 L .31837 .52102 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49381 .61479 m .49177 .65283 L .47909 .64812 L p .707 .577 .707 r
F P
0 g
s
.47909 .64812 m .48113 .61007 L .49381 .61479 L p .707 .577 .707 r
F P
0 g
s
.31837 .52102 m .31652 .57764 L .3002 .58235 L p .707 .577 .707 r
F P
0 g
s
.49105 .67224 m .49 .69127 L .47732 .68664 L p .707 .577 .707 r
F P
0 g
s
.47732 .68664 m .47837 .66761 L .49105 .67224 L p .707 .577 .707 r
F P
0 g
s
.29808 .64096 m .30012 .60292 L .31637 .59997 L p .707 .577 .707 r
F P
0 g
s
.48326 .52826 m .48141 .58488 L .46033 .57964 L p .707 .577 .707 r
F P
0 g
s
.46033 .57964 m .46218 .52303 L .48326 .52826 L p .707 .577 .707 r
F P
0 g
s
.31637 .59997 m .31433 .63802 L .29808 .64096 L p .707 .577 .707 r
F P
0 g
s
.29632 .67917 m .29737 .66014 L .31361 .65731 L p .707 .577 .707 r
F P
0 g
s
.31652 .57764 m .31837 .52102 L .34239 .51777 L p .707 .577 .707 r
F P
0 g
s
.31361 .65731 m .31257 .67634 L .29632 .67917 L p .707 .577 .707 r
F P
0 g
s
.48113 .61007 m .47909 .64812 L .45798 .6437 L p .707 .577 .707 r
F P
0 g
s
.45798 .6437 m .46002 .60565 L .48113 .61007 L p .707 .577 .707 r
F P
0 g
s
.34239 .51777 m .34054 .57438 L .31652 .57764 L p .707 .577 .707 r
F P
0 g
s
.46218 .52303 m .46033 .57964 L .43287 .57567 L p .707 .577 .707 r
F P
0 g
s
.43287 .57567 m .43472 .51905 L .46218 .52303 L p .707 .577 .707 r
F P
0 g
s
.47837 .66761 m .47732 .68664 L .4562 .68228 L p .707 .577 .707 r
F P
0 g
s
.4562 .68228 m .45725 .66325 L .47837 .66761 L p .707 .577 .707 r
F P
0 g
s
.31433 .63802 m .31637 .59997 L .34031 .59831 L p .707 .577 .707 r
F P
0 g
s
.34054 .57438 m .34239 .51777 L .37174 .51629 L p .707 .577 .707 r
F P
0 g
s
.34031 .59831 m .33827 .63636 L .31433 .63802 L p .707 .577 .707 r
F P
0 g
s
.31257 .67634 m .31361 .65731 L .33755 .65577 L p .707 .577 .707 r
F P
0 g
s
.33755 .65577 m .33651 .6748 L .31257 .67634 L p .707 .577 .707 r
F P
0 g
s
.43472 .51905 m .43287 .57567 L .4017 .57335 L p .707 .577 .707 r
F P
0 g
s
.4017 .57335 m .40355 .51673 L .43472 .51905 L p .707 .577 .707 r
F P
0 g
s
.46002 .60565 m .45798 .6437 L .4305 .64 L p .707 .577 .707 r
F P
0 g
s
.4305 .64 m .43254 .60196 L .46002 .60565 L p .707 .577 .707 r
F P
0 g
s
.37174 .51629 m .36989 .57291 L .34054 .57438 L p .707 .577 .707 r
F P
0 g
s
.36989 .57291 m .37174 .51629 L .40355 .51673 L p .707 .577 .707 r
F P
0 g
s
.40355 .51673 m .4017 .57335 L .36989 .57291 L p .707 .577 .707 r
F P
0 g
s
.33827 .63636 m .34031 .59831 L .36961 .5981 L p .707 .577 .707 r
F P
0 g
s
.45725 .66325 m .4562 .68228 L .42873 .6786 L p .707 .577 .707 r
F P
0 g
s
.42873 .6786 m .42977 .65957 L .45725 .66325 L p .707 .577 .707 r
F P
0 g
s
.36961 .5981 m .36757 .63615 L .33827 .63636 L p .707 .577 .707 r
F P
0 g
s
.33651 .6748 m .33755 .65577 L .36684 .65564 L p .707 .577 .707 r
F P
0 g
s
.43254 .60196 m .4305 .64 L .39935 .6374 L p .707 .577 .707 r
F P
0 g
s
.39935 .6374 m .40139 .59936 L .43254 .60196 L p .707 .577 .707 r
F P
0 g
s
.36684 .65564 m .3658 .67467 L .33651 .6748 L p .707 .577 .707 r
F P
0 g
s
.36757 .63615 m .36961 .5981 L .40139 .59936 L p .707 .577 .707 r
F P
0 g
s
.40139 .59936 m .39935 .6374 L .36757 .63615 L p .707 .577 .707 r
F P
0 g
s
.42977 .65957 m .42873 .6786 L .39757 .67598 L p .707 .577 .707 r
F P
0 g
s
.39757 .67598 m .39862 .65695 L .42977 .65957 L p .707 .577 .707 r
F P
0 g
s
.3658 .67467 m .36684 .65564 L .39862 .65695 L p .707 .577 .707 r
F P
0 g
s
.39862 .65695 m .39757 .67598 L .3658 .67467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolE0028Ool007Qoo`P000IJEP03001JEUYF00UJEP03001JEUYF00H0089oo`00M7oo
100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01UYF1000OWoo001`Ool40005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000O7oo001/Ool40009FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P00NWoo001ZOol200000eYF
001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001h
Ool006Qoo`8000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8007Ioo`00IWoo0P001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01eYF00<007ooOol0Lgoo001TOol20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00Oomo
o`1bOol006=oo`8000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001oogoo075oo`00HWoo00<005YF000025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02EYF00<007ooOol0L7oo001P
Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool005moo`03001JEUYF009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EW5oo`00GWoo00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYFLGoo001MOol00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005eoo`03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0KWoo001LOol20007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1^Ool005]oo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06io
o`00Fgoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0KWoo001KOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001_Ool005]oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00Kgoo001LOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Kgoo001LOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1]Ool005aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06eoo`00G7oo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0KGoo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00KWoo001LOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0KGoo001LOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YFKWoo001MOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVioo`00GGoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI^Ool005eoo`03
001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001^Ool005eoo`03001JEP0000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001oogoo06aoo`00GGoo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1/Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1/Ool0
05eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00KGoo001MOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<0
05YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP8006eoo`00GWoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1[Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]o
o`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06]oo`00GWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00K7oo001NOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8006aoo`00Ggoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo
001OOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005moo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Yoo`00Ggoo00@005YFFUH000=JEQ4000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo001HOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001EOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001[Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001[Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Jgoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1Y
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00]ooaX004Aoo`00Dgoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000fOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`02Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000bOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000=JEP04001JEUYFFUH8
00000eYF001JEP06FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005=oo`03001JEP00009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEPD000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
FUIJEP80009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2
0002Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEUYF0P000Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP05
001oo`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOolO00000eYF001JEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]
Ool005Eoo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80000
0eYF001JEP05FUH00`00FUIJEP030002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool0
05=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH;0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00Ool005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP050004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00Ool005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00=goo7@0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF008002ioo`00;Woo0`000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH300001EYF
000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF10000UYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJ
EP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YFFUIJEP800003Ool005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEP0000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEP00FUH00P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP80009oo`800003FUH005YF00AJEQX000QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002FUH70007FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`090003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80000
0eYF001JEP05FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Ool0000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL00003FUH0
05YF0080035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000<Woo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1@0000=JEP0000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF0000800025YF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH=0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000=JEP04001JEUYFFUHJ0002FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000UYF1P00
25YF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH00UYF00@005YFFUIJEQ0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000015YF001JEUYF7P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP00009JEPd00003FUH005YF00EJ
EPl000IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH40005
FUH01000FUIJEUYF200015YF00<005YF00000P001EYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF1`000eYF00@005YFFUIJEP8002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF009JEQ/000=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00;Woo000/
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH50002FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000^Ool002eoo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYFFUH40002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF000000020003FUH@00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000^Ool002moo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEP00008000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPT00003FUH005YF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02ioo`00<Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1@0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH01EYF00<005YFFUH01000;goo000aOolN00000eYF001JEP06FUH00`00FUIJEP04FUHC
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP/003=oo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEQ80009oo`04001JEUYF0006FUH00`00FUIJEP02FUH@0000
0eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH70005Ool01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;goo000/Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP060002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00MJEPT000IJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF
001JEP040004FUH5000015YF001JEUYF0P002Goo0`000goo200015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH025YF00<005YFFUH025YF00@005YFFUIJEPH000QJEPX000UJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUHC000:Ool70003FUH00`00FUIJEP02
000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00MJEPH000=JEP03001J
EUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUHE
0002FUH40002FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP004EYF00<0
05YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH02EYF0P000UYF1@001UYF00@005YFFUIJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUH005YF000AFUH00`00FUH00003000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20007FUH20004
FUH01000FUIJEUYF0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000@FUH30003FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH20008FUH400000eYF001JEP03FUH00`00FUIJEP02FUH80004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
02moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000>FUH20006FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH20008FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`00<7oo000[Ool00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000]JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP8000QJEP8000AJEP04001JEUYFFUH20003FUH01000FUIJEUYF1P001Woo8000<goo000[Ool00`00
FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJ
EP03FUH01000FUIJEP002eYF0`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P002EYF00<005YFFUH00eYF00D005YFFUH005YF00P005ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YF
FUH000UJEP80009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000MJEP03001JEP00008005]oo`00;7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEPD00003FUH005YF00IJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000MJEP03001JEUYF
009JEP<005Qoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EWoo000_Ool40003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF
00=JEP03001JEUYF008005Eoo`00<goo1`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP<000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0006FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol003Yoo`P000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH90002FUH01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF0P0025YF00<005YFFUH015YF00@005YF000000EJEP03001J
EUYF00AJEP03001JEUYF008005Eoo`00<7oo;0002Goo0UYF00@005YFFUH000QJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP03001JEUYF00AJEP04001J
EUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000]Ool30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000>Ool00eYF001JEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20008FUH0
0`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000[Ool30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0027oo00=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0100017oo00=JEP00FUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
0P0025YF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000Woo0P000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP0000001P000eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF00@005YF
FUIJEQ0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00@000=J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP@000=JEP8005Eoo`00:goo
00<005YF000030002goo4@0015YF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000005Eo
o`00:goo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPP001Aoo`H000AJEP04001JEUYFFUH30003
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3001EOol002]oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF009JEQd00003
FUH005YF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0005Eoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF0`0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP03001JEUYF00@005Ioo`00;Woo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF01<005Yoo`00<Woo1`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF
001oo`0000=JEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP80
00QJEP/006Eoo`00>Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH010000goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH6001OOol0049oo`T0
00AJEP03001JEUYF00EJEP04001JEUYFFUH60008Ool00`00FUH00008FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP05
FUH00`00FUH00002001LOol004]ooa0000moo`8000QJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF009JEP<000QJEP03001JEUYF00EJEP03001JEUYF
009JEP<005Uoo`00Jgoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00P000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000P00EWoo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo
001`Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH3000;
Ool80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo001cOol40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH01000FUIJEUYF1P000UYF2@002goo1`000eYF00<005YFFUH00P00EWoo001gOol6
0002FUH00`00FUIJEP09FUH00`00FUIJEP07FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@
0002FUH500000eYF0000001FOol007eoo`P000IJEP04001JEUYFFUH60002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
EWoo0025Ool:00000goo000000020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002DOol70004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00
Egoo002SOolP001JOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]1\[InvisibleSpace]"     "\
\[InvisibleSpace]1.3573695695536339`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 1, "     ", 1.3573695695536339, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59105 .74945 m .59567 .69457 L .56461 .69006 L p .707 .577 .707 r
F P
0 g
s
.59567 .69457 m .59105 .74945 L .62278 .75103 L p .707 .577 .707 r
F P
0 g
s
.62278 .75103 m .62741 .69615 L .59567 .69457 L p .707 .577 .707 r
F P
0 g
s
.62741 .69615 m .62278 .75103 L .65209 .74952 L p .707 .577 .707 r
F P
0 g
s
.65209 .74952 m .65671 .69464 L .62741 .69615 L p .707 .577 .707 r
F P
0 g
s
.55998 .74494 m .56461 .69006 L .53726 .68305 L p .707 .577 .707 r
F P
0 g
s
.56461 .69006 m .55998 .74494 L .59105 .74945 L p .707 .577 .707 r
F P
0 g
s
.65671 .69464 m .65209 .74952 L .67609 .74507 L p .707 .577 .707 r
F P
0 g
s
.67609 .74507 m .68071 .69019 L .65671 .69464 L p .707 .577 .707 r
F P
0 g
s
.53263 .73793 m .53726 .68305 L .5163 .67424 L p .707 .577 .707 r
F P
0 g
s
.53726 .68305 m .53263 .73793 L .55998 .74494 L p .707 .577 .707 r
F P
0 g
s
.58555 .80775 m .59065 .77162 L .55978 .76541 L p .707 .577 .707 r
F P
0 g
s
.59065 .77162 m .58555 .80775 L .61711 .81086 L p .707 .577 .707 r
F P
0 g
s
.61711 .81086 m .62221 .77474 L .59065 .77162 L p .707 .577 .707 r
F P
0 g
s
.62221 .77474 m .61711 .81086 L .64628 .81057 L p .707 .577 .707 r
F P
0 g
s
.64628 .81057 m .65138 .77444 L .62221 .77474 L p .707 .577 .707 r
F P
0 g
s
.55468 .80154 m .55978 .76541 L .53262 .75671 L p .707 .577 .707 r
F P
0 g
s
.55978 .76541 m .55468 .80154 L .58555 .80775 L p .707 .577 .707 r
F P
0 g
s
.68071 .69019 m .67609 .74507 L .69244 .73812 L p .707 .577 .707 r
F P
0 g
s
.69244 .73812 m .69706 .68324 L .68071 .69019 L p .707 .577 .707 r
F P
0 g
s
.5163 .67424 m .51168 .72912 L .53263 .73793 L p .707 .577 .707 r
F P
0 g
s
.65138 .77444 m .64628 .81057 L .6702 .8069 L p .707 .577 .707 r
F P
0 g
s
.6702 .8069 m .6753 .77077 L .65138 .77444 L p .707 .577 .707 r
F P
0 g
s
.53262 .75671 m .52752 .79284 L .55468 .80154 L p .707 .577 .707 r
F P
0 g
s
.58115 .8444 m .58377 .82636 L .55291 .82003 L p .707 .577 .707 r
F P
0 g
s
.58377 .82636 m .58115 .8444 L .6127 .84762 L p .707 .577 .707 r
F P
0 g
s
.6127 .84762 m .61532 .82957 L .58377 .82636 L p .707 .577 .707 r
F P
0 g
s
.52752 .79284 m .53262 .75671 L .51184 .74636 L p .707 .577 .707 r
F P
0 g
s
.51168 .72912 m .5163 .67424 L .50379 .66449 L p .707 .577 .707 r
F P
0 g
s
.61532 .82957 m .6127 .84762 L .64185 .84741 L p .707 .577 .707 r
F P
0 g
s
.64185 .84741 m .64447 .82936 L .61532 .82957 L p .707 .577 .707 r
F P
0 g
s
.55029 .83807 m .55291 .82003 L .52577 .81121 L p .707 .577 .707 r
F P
0 g
s
.55291 .82003 m .55029 .83807 L .58115 .8444 L p .707 .577 .707 r
F P
0 g
s
.52577 .81121 m .52315 .82926 L .55029 .83807 L p .707 .577 .707 r
F P
0 g
s
.51184 .74636 m .50674 .78249 L .52752 .79284 L p .707 .577 .707 r
F P
0 g
s
.64447 .82936 m .64185 .84741 L .66576 .8438 L p .707 .577 .707 r
F P
0 g
s
.66576 .8438 m .66838 .82575 L .64447 .82936 L p .707 .577 .707 r
F P
0 g
s
.50379 .66449 m .49916 .71936 L .51168 .72912 L p .707 .577 .707 r
F P
0 g
s
.6753 .77077 m .6702 .8069 L .68652 .80022 L p .707 .577 .707 r
F P
0 g
s
.68652 .80022 m .69162 .76409 L .6753 .77077 L p .707 .577 .707 r
F P
0 g
s
.52315 .82926 m .52577 .81121 L .505 .80076 L p .707 .577 .707 r
F P
0 g
s
.69706 .68324 m .69244 .73812 L .69954 .72934 L p .707 .577 .707 r
F P
0 g
s
.69954 .72934 m .70416 .67446 L .69706 .68324 L p .707 .577 .707 r
F P
0 g
s
.50674 .78249 m .51184 .74636 L .49946 .73539 L p .707 .577 .707 r
F P
0 g
s
.505 .80076 m .50238 .81881 L .52315 .82926 L p .707 .577 .707 r
F P
0 g
s
.49916 .71936 m .50379 .66449 L .50094 .65474 L p .707 .577 .707 r
F P
0 g
s
.49946 .73539 m .49436 .77152 L .50674 .78249 L p .707 .577 .707 r
F P
0 g
s
.66838 .82575 m .66576 .8438 L .68208 .83713 L p .707 .577 .707 r
F P
0 g
s
.68208 .83713 m .6847 .81908 L .66838 .82575 L p .707 .577 .707 r
F P
0 g
s
.50238 .81881 m .505 .80076 L .49264 .78971 L p .707 .577 .707 r
F P
0 g
s
.69162 .76409 m .68652 .80022 L .69365 .79117 L p .707 .577 .707 r
F P
0 g
s
.69365 .79117 m .69875 .75504 L .69162 .76409 L p .707 .577 .707 r
F P
0 g
s
.50094 .65474 m .49632 .70962 L .49916 .71936 L p .707 .577 .707 r
F P
0 g
s
.49264 .78971 m .49002 .80775 L .50238 .81881 L p .707 .577 .707 r
F P
0 g
s
.49436 .77152 m .49946 .73539 L .4967 .72487 L p .707 .577 .707 r
F P
0 g
s
.70416 .67446 m .69954 .72934 L .69669 .7196 L p .707 .577 .707 r
F P
0 g
s
.69669 .7196 m .70132 .66472 L .70416 .67446 L p .707 .577 .707 r
F P
0 g
s
.49632 .70962 m .50094 .65474 L .50804 .64596 L p .707 .577 .707 r
F P
0 g
s
.4967 .72487 m .4916 .761 L .49436 .77152 L p .707 .577 .707 r
F P
0 g
s
.6847 .81908 m .68208 .83713 L .68921 .82806 L p .707 .577 .707 r
F P
0 g
s
.68921 .82806 m .69183 .81002 L .6847 .81908 L p .707 .577 .707 r
F P
0 g
s
.49002 .80775 m .49264 .78971 L .48989 .77913 L p .707 .577 .707 r
F P
0 g
s
.48989 .77913 m .48727 .79718 L .49002 .80775 L p .707 .577 .707 r
F P
0 g
s
.69875 .75504 m .69365 .79117 L .69089 .78065 L p .707 .577 .707 r
F P
0 g
s
.69089 .78065 m .69599 .74452 L .69875 .75504 L p .707 .577 .707 r
F P
0 g
s
.50804 .64596 m .50342 .70084 L .49632 .70962 L p .707 .577 .707 r
F P
0 g
s
.4916 .761 m .4967 .72487 L .50383 .71582 L p .707 .577 .707 r
F P
0 g
s
.70132 .66472 m .69669 .7196 L .68418 .70984 L p .707 .577 .707 r
F P
0 g
s
.68418 .70984 m .6888 .65496 L .70132 .66472 L p .707 .577 .707 r
F P
0 g
s
.50342 .70084 m .50804 .64596 L .52439 .63901 L p .707 .577 .707 r
F P
0 g
s
.24804 .71668 m .25266 .6618 L .2216 .65729 L p .707 .577 .707 r
F P
0 g
s
.25266 .6618 m .24804 .71668 L .27977 .71826 L p .707 .577 .707 r
F P
0 g
s
.27977 .71826 m .2844 .66338 L .25266 .6618 L p .707 .577 .707 r
F P
0 g
s
.50383 .71582 m .49873 .75195 L .4916 .761 L p .707 .577 .707 r
F P
0 g
s
.48904 .80929 m .39889 .30652 L .35561 .31192 L p .707 .577 .707 r
F P
0 g
s
.48727 .79718 m .48989 .77913 L .49702 .77006 L p .707 .577 .707 r
F P
0 g
s
.49702 .77006 m .4944 .78811 L .48727 .79718 L p .707 .577 .707 r
F P
0 g
s
.52439 .63901 m .51977 .69389 L .50342 .70084 L p .707 .577 .707 r
F P
0 g
s
.49873 .75195 m .50383 .71582 L .52015 .70914 L p .707 .577 .707 r
F P
0 g
s
.52015 .70914 m .51505 .74527 L .49873 .75195 L p .707 .577 .707 r
F P
0 g
s
.4944 .78811 m .49702 .77006 L .51334 .7634 L p .707 .577 .707 r
F P
0 g
s
.51334 .7634 m .51072 .78144 L .4944 .78811 L p .707 .577 .707 r
F P
0 g
s
.51505 .74527 m .52015 .70914 L .54407 .70547 L p .707 .577 .707 r
F P
0 g
s
.54407 .70547 m .53897 .7416 L .51505 .74527 L p .707 .577 .707 r
F P
0 g
s
.51072 .78144 m .51334 .7634 L .53725 .75978 L p .707 .577 .707 r
F P
0 g
s
.53725 .75978 m .53463 .77783 L .51072 .78144 L p .707 .577 .707 r
F P
0 g
s
.39889 .30652 m .48904 .80929 L .53333 .8009 L p .707 .577 .707 r
F P
0 g
s
.53333 .8009 m .44318 .29813 L .39889 .30652 L p .707 .577 .707 r
F P
0 g
s
.69183 .81002 m .68921 .82806 L .68646 .81749 L p .707 .577 .707 r
F P
0 g
s
.68646 .81749 m .68908 .79944 L .69183 .81002 L p .707 .577 .707 r
F P
0 g
s
.2844 .66338 m .27977 .71826 L .30908 .71675 L p .707 .577 .707 r
F P
0 g
s
.30908 .71675 m .3137 .66187 L .2844 .66338 L p .707 .577 .707 r
F P
0 g
s
.51977 .69389 m .52439 .63901 L .54839 .63456 L p .707 .577 .707 r
F P
0 g
s
.54839 .63456 m .54377 .68944 L .51977 .69389 L p .707 .577 .707 r
F P
0 g
s
.54377 .68944 m .54839 .63456 L .5777 .63305 L p .707 .577 .707 r
F P
0 g
s
.5777 .63305 m .57308 .68793 L .54377 .68944 L p .707 .577 .707 r
F P
0 g
s
.53897 .7416 m .54407 .70547 L .57323 .70518 L p .707 .577 .707 r
F P
0 g
s
.57323 .70518 m .56813 .7413 L .53897 .7416 L p .707 .577 .707 r
F P
0 g
s
.53463 .77783 m .53725 .75978 L .5664 .75957 L p .707 .577 .707 r
F P
0 g
s
.5664 .75957 m .56378 .77762 L .53463 .77783 L p .707 .577 .707 r
F P
0 g
s
.56378 .77762 m .5664 .75957 L .59795 .76279 L p .707 .577 .707 r
F P
0 g
s
.59795 .76279 m .59533 .78084 L .56378 .77762 L p .707 .577 .707 r
F P
0 g
s
.44318 .29813 m .53333 .8009 L .5743 .79035 L p .707 .577 .707 r
F P
0 g
s
.5743 .79035 m .48414 .28758 L .44318 .29813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21697 .71216 m .2216 .65729 L .19425 .65028 L p .707 .577 .707 r
F P
0 g
s
.2216 .65729 m .21697 .71216 L .24804 .71668 L p .707 .577 .707 r
F P
0 g
s
.44576 .81469 m .35561 .31192 L .31757 .31379 L p .707 .577 .707 r
F P
0 g
s
.35561 .31192 m .44576 .81469 L .48904 .80929 L p .707 .577 .707 r
F P
0 g
s
.69599 .74452 m .69089 .78065 L .67851 .76968 L p .707 .577 .707 r
F P
0 g
s
.67851 .76968 m .68361 .73355 L .69599 .74452 L p .707 .577 .707 r
F P
0 g
s
.3137 .66187 m .30908 .71675 L .33308 .7123 L p .707 .577 .707 r
F P
0 g
s
.33308 .7123 m .3377 .65742 L .3137 .66187 L p .707 .577 .707 r
F P
0 g
s
.6888 .65496 m .68418 .70984 L .66322 .70103 L p .707 .577 .707 r
F P
0 g
s
.66322 .70103 m .66785 .64615 L .6888 .65496 L p .707 .577 .707 r
F P
0 g
s
.57308 .68793 m .5777 .63305 L .60944 .63463 L p .707 .577 .707 r
F P
0 g
s
.60944 .63463 m .60481 .68951 L .57308 .68793 L p .707 .577 .707 r
F P
0 g
s
.56813 .7413 m .57323 .70518 L .6048 .70829 L p .707 .577 .707 r
F P
0 g
s
.6048 .70829 m .5997 .74442 L .56813 .7413 L p .707 .577 .707 r
F P
0 g
s
.62881 .76912 m .62619 .78716 L .59533 .78084 L p .707 .577 .707 r
F P
0 g
s
.59533 .78084 m .59795 .76279 L .62881 .76912 L p .707 .577 .707 r
F P
0 g
s
.48414 .28758 m .5743 .79035 L .60792 .77866 L p .707 .577 .707 r
F P
0 g
s
.63567 .7145 m .63057 .75063 L .5997 .74442 L p .707 .577 .707 r
F P
0 g
s
.5997 .74442 m .6048 .70829 L .63567 .7145 L p .707 .577 .707 r
F P
0 g
s
.60792 .77866 m .51776 .27588 L .48414 .28758 L p .707 .577 .707 r
F P
0 g
s
.18962 .70516 m .19425 .65028 L .17329 .64147 L p .707 .577 .707 r
F P
0 g
s
.19425 .65028 m .18962 .70516 L .21697 .71216 L p .707 .577 .707 r
F P
0 g
s
.24254 .78119 m .24764 .74506 L .21677 .73885 L p .707 .577 .707 r
F P
0 g
s
.24764 .74506 m .24254 .78119 L .27411 .7843 L p .707 .577 .707 r
F P
0 g
s
.27411 .7843 m .27921 .74817 L .24764 .74506 L p .707 .577 .707 r
F P
0 g
s
.27921 .74817 m .27411 .7843 L .30327 .78401 L p .707 .577 .707 r
F P
0 g
s
.30327 .78401 m .30837 .74788 L .27921 .74817 L p .707 .577 .707 r
F P
0 g
s
.21167 .77497 m .21677 .73885 L .18961 .73014 L p .707 .577 .707 r
F P
0 g
s
.21677 .73885 m .21167 .77497 L .24254 .78119 L p .707 .577 .707 r
F P
0 g
s
.68908 .79944 m .68646 .81749 L .6741 .80643 L p .707 .577 .707 r
F P
0 g
s
.6741 .80643 m .67672 .78839 L .68908 .79944 L p .707 .577 .707 r
F P
0 g
s
.3377 .65742 m .33308 .7123 L .34943 .70535 L p .707 .577 .707 r
F P
0 g
s
.34943 .70535 m .35405 .65047 L .3377 .65742 L p .707 .577 .707 r
F P
0 g
s
.40772 .81657 m .31757 .31379 L .28849 .31197 L p .707 .577 .707 r
F P
0 g
s
.31757 .31379 m .40772 .81657 L .44576 .81469 L p .707 .577 .707 r
F P
0 g
s
.17329 .64147 m .16867 .69635 L .18962 .70516 L p .707 .577 .707 r
F P
0 g
s
.66785 .64615 m .66322 .70103 L .63587 .69403 L p .707 .577 .707 r
F P
0 g
s
.63587 .69403 m .6405 .63915 L .66785 .64615 L p .707 .577 .707 r
F P
0 g
s
.68361 .73355 m .67851 .76968 L .65773 .75933 L p .707 .577 .707 r
F P
0 g
s
.65773 .75933 m .66283 .7232 L .68361 .73355 L p .707 .577 .707 r
F P
0 g
s
.30837 .74788 m .30327 .78401 L .32719 .78034 L p .707 .577 .707 r
F P
0 g
s
.32719 .78034 m .33229 .74421 L .30837 .74788 L p .707 .577 .707 r
F P
0 g
s
.18961 .73014 m .18451 .76627 L .21167 .77497 L p .707 .577 .707 r
F P
0 g
s
.16867 .69635 m .17329 .64147 L .16078 .63171 L p .707 .577 .707 r
F P
0 g
s
.18451 .76627 m .18961 .73014 L .16883 .7198 L p .707 .577 .707 r
F P
0 g
s
.23814 .82767 m .24076 .80963 L .2099 .8033 L p .707 .577 .707 r
F P
0 g
s
.24076 .80963 m .23814 .82767 L .26969 .83089 L p .707 .577 .707 r
F P
0 g
s
.26969 .83089 m .27231 .81285 L .24076 .80963 L p .707 .577 .707 r
F P
0 g
s
.6405 .63915 m .63587 .69403 L .60481 .68951 L p .707 .577 .707 r
F P
0 g
s
.60481 .68951 m .60944 .63463 L .6405 .63915 L p .707 .577 .707 r
F P
0 g
s
.51776 .27588 m .60792 .77866 L .63091 .76697 L p .707 .577 .707 r
F P
0 g
s
.63091 .76697 m .54076 .2642 L .51776 .27588 L p .707 .577 .707 r
F P
0 g
s
.27231 .81285 m .26969 .83089 L .29884 .83068 L p .707 .577 .707 r
F P
0 g
s
.29884 .83068 m .30146 .81264 L .27231 .81285 L p .707 .577 .707 r
F P
0 g
s
.20728 .82135 m .2099 .8033 L .18276 .79448 L p .707 .577 .707 r
F P
0 g
s
.2099 .8033 m .20728 .82135 L .23814 .82767 L p .707 .577 .707 r
F P
0 g
s
.16883 .7198 m .16373 .75593 L .18451 .76627 L p .707 .577 .707 r
F P
0 g
s
.18276 .79448 m .18014 .81253 L .20728 .82135 L p .707 .577 .707 r
F P
0 g
s
.67672 .78839 m .6741 .80643 L .65333 .79598 L p .707 .577 .707 r
F P
0 g
s
.65333 .79598 m .65595 .77794 L .67672 .78839 L p .707 .577 .707 r
F P
0 g
s
.16078 .63171 m .15615 .68659 L .16867 .69635 L p .707 .577 .707 r
F P
0 g
s
.33229 .74421 m .32719 .78034 L .34351 .77365 L p .707 .577 .707 r
F P
0 g
s
.34351 .77365 m .34861 .73753 L .33229 .74421 L p .707 .577 .707 r
F P
0 g
s
.30146 .81264 m .29884 .83068 L .32275 .82707 L p .707 .577 .707 r
F P
0 g
s
.32275 .82707 m .32537 .80902 L .30146 .81264 L p .707 .577 .707 r
F P
0 g
s
.35405 .65047 m .34943 .70535 L .35653 .69657 L p .707 .577 .707 r
F P
0 g
s
.35653 .69657 m .36116 .64169 L .35405 .65047 L p .707 .577 .707 r
F P
0 g
s
.66283 .7232 m .65773 .75933 L .63057 .75063 L p .707 .577 .707 r
F P
0 g
s
.63057 .75063 m .63567 .7145 L .66283 .7232 L p .707 .577 .707 r
F P
0 g
s
.18014 .81253 m .18276 .79448 L .16199 .78403 L p .707 .577 .707 r
F P
0 g
s
.16373 .75593 m .16883 .7198 L .15645 .70883 L p .707 .577 .707 r
F P
0 g
s
.15615 .68659 m .16078 .63171 L .15793 .62197 L p .707 .577 .707 r
F P
0 g
s
.16199 .78403 m .15937 .80208 L .18014 .81253 L p .707 .577 .707 r
F P
0 g
s
.36116 .64169 m .35653 .69657 L .35369 .68683 L p .707 .577 .707 r
F P
0 g
s
.35369 .68683 m .35563 .66371 L p .36116 .64169 L .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .40772 .81657 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.28849 .31197 m .35114 .66131 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.36025 .61564 m .35114 .66131 L .3579 .63675 L .707 .577 .707 r
F
.28849 .31197 m .27124 .30663 L p .34559 .65836 L F P
0 g
s
.34117 .67707 m .34783 .65955 L .34833 .65982 L .707 .577 .707 r
F
.35369 .68683 m .3458 .68068 L p .35114 .66131 L F P
0 g
s
.3579 .63675 m .35563 .66371 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35563 .66371 m .35369 .68683 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .35114 .66131 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .28849 .31197 L p .34694 .65908 L .707 .577 .707 r
F P
0 g
s
.3458 .68068 m .34117 .67707 L p .34833 .65982 L .707 .577 .707 r
F P
0 g
s
.34833 .65982 m .3579 .63675 L .35114 .66131 L .707 .577 .707 r
F
.34833 .65982 m .35114 .66131 L .3458 .68068 L F
.35064 .76461 m .35353 .74413 L p .34861 .73753 L F P
0 g
s
.35353 .74413 m .35574 .72848 L .35234 .73279 L p .707 .577 .707 r
F P
0 g
s
.35234 .73279 m .34861 .73753 L p .35353 .74413 L .707 .577 .707 r
F P
0 g
s
.34861 .73753 m .34351 .77365 L .35064 .76461 L p .707 .577 .707 r
F P
0 g
s
.35064 .76461 m .34788 .75408 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35574 .72848 m .35353 .74413 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35353 .74413 m .35064 .76461 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3406 .70698 L .3452 .71106 L p .707 .577 .707 r
F P
0 g
s
.3452 .71106 m .35298 .71795 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3452 .71106 L .34813 .72493 L .707 .577 .707 r
F
.32484 .61338 m .3266 .61412 L p .32101 .66154 L F P
0 g
s
.32087 .66052 m .32484 .61338 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.3266 .61412 m .32977 .61545 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.27124 .30663 m .32248 .59241 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .32248 .59241 L .34287 .65691 L .707 .577 .707 r
F
.34694 .65908 m .28849 .31197 L .34559 .65836 L F
.32977 .61545 m .34579 .62219 L p .33694 .63814 L F P
0 g
s
.33263 .64591 m .32977 .61545 L .33694 .63814 L .707 .577 .707 r
F
.32021 .66826 m .3266 .61412 L .33263 .64591 L F
.34117 .67707 m .33831 .67587 L p .34154 .6527 L F P
0 g
s
.34287 .65691 m .34117 .67707 L p .34154 .6527 L .707 .577 .707 r
F P
0 g
s
.33831 .67587 m .32021 .66826 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.33263 .64591 m .34579 .62219 L .33831 .67587 L .707 .577 .707 r
F
.35298 .71795 m .35574 .72848 L p .3521 .74032 L F P
0 g
s
.34788 .75408 m .35045 .73589 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .35298 .71795 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.34788 .75408 m .3355 .74311 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35298 .71795 m .35045 .73589 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .34788 .75408 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35764 .80105 m .36139 .8094 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32484 .61338 m .32021 .66826 L .29287 .66125 L p .707 .577 .707 r
F P
0 g
s
.29287 .66125 m .29749 .60638 L .32484 .61338 L p .707 .577 .707 r
F P
0 g
s
.26748 .29828 m .32086 .59598 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32086 .59598 m .35764 .80105 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.35893 .79566 m .34614 .72434 L p .35901 .79643 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .27124 .30663 L p .34604 .72409 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .34604 .72409 L .35901 .79643 L .707 .577 .707 r
F
.34117 .67707 m .34579 .62219 L .35831 .63195 L p F P
0 g
s
.33312 .65172 m .36139 .8094 L p .34671 .66907 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .34287 .65691 L .34671 .66907 L .707 .577 .707 r
F
.34287 .65691 m .33312 .65172 L .34671 .66907 L F
.34579 .62219 m .34287 .65691 L p .34154 .6527 L F P
0 g
s
.33359 .65617 m .31801 .56883 L .33089 .64341 L .707 .577 .707 r
F
.31801 .56883 m .27124 .30663 L .31301 .54248 L F
.31801 .56883 m .31301 .54248 L .33089 .64341 L F
.32248 .59241 m .33312 .65172 L p .34287 .65691 L F P
0 g
s
.27124 .30663 m .26748 .29828 L p .2915 .42902 L .707 .577 .707 r
F P
0 g
s
.33089 .64341 m .31301 .54248 L .2915 .42902 L .707 .577 .707 r
F
.31301 .54248 m .27124 .30663 L .2915 .42902 L F
.3454 .72235 m .33359 .65617 L .33089 .64341 L F
.34604 .72409 m .27124 .30663 L .3454 .72235 L F
.35764 .80105 m .28085 .37286 L p .27759 .28775 L F P
0 g
s
.28085 .37286 m .26748 .29828 L .2701 .29555 L p .707 .577 .707 r
F P
0 g
s
.2701 .29555 m .27759 .28775 L p .28085 .37286 L .707 .577 .707 r
F P
0 g
s
.32021 .66826 m .32087 .66052 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.35901 .79643 m .34604 .72409 L .3454 .72235 L .707 .577 .707 r
F
.36139 .8094 m .35893 .79566 L p .35901 .79643 L F P
0 g
s
.36139 .8094 m .37865 .81474 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .34694 .65908 L .35162 .68689 L .707 .577 .707 r
F
.35162 .68689 m .34694 .65908 L .34559 .65836 L F
.35831 .63195 m .3579 .63675 L p .34833 .65982 L F P
0 g
s
.34783 .65955 m .35831 .63195 L .34833 .65982 L .707 .577 .707 r
F
.35114 .66131 m .35364 .67525 L p .3579 .63675 L F P
0 g
s
.35563 .66371 m .3579 .63675 L p .36008 .63801 L .707 .577 .707 r
F P
0 g
s
.3584 .63227 m .36008 .63801 L p .3579 .63675 L .707 .577 .707 r
F P
0 g
s
.36008 .63801 m .36116 .64169 L p .35563 .66371 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .37865 .81474 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.3579 .63675 m .35831 .63195 L .3584 .63227 L p .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .35364 .67525 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.15645 .70883 m .15135 .74496 L .16373 .75593 L p .707 .577 .707 r
F P
0 g
s
.65595 .77794 m .65333 .79598 L .62619 .78716 L p .707 .577 .707 r
F P
0 g
s
.62619 .78716 m .62881 .76912 L .65595 .77794 L p .707 .577 .707 r
F P
0 g
s
.32537 .80902 m .32275 .82707 L .33907 .8204 L p .707 .577 .707 r
F P
0 g
s
.33907 .8204 m .34169 .80236 L .32537 .80902 L p .707 .577 .707 r
F P
0 g
s
.54076 .2642 m .63091 .76697 L .64103 .75645 L p .707 .577 .707 r
F P
0 g
s
.64103 .75645 m .55087 .25367 L .54076 .2642 L p .707 .577 .707 r
F P
0 g
s
.15937 .80208 m .16199 .78403 L .14963 .77298 L p .707 .577 .707 r
F P
0 g
s
.15793 .62197 m .15331 .67685 L .15615 .68659 L p .707 .577 .707 r
F P
0 g
s
.14963 .77298 m .14701 .79103 L .15937 .80208 L p .707 .577 .707 r
F P
0 g
s
.15135 .74496 m .15645 .70883 L .15369 .69831 L p .707 .577 .707 r
F P
0 g
s
.15331 .67685 m .15793 .62197 L .16503 .61319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15369 .69831 m .14859 .73443 L .15135 .74496 L p .707 .577 .707 r
F P
0 g
s
.34169 .80236 m .33907 .8204 L .3462 .81134 L p .707 .577 .707 r
F P
0 g
s
.3462 .81134 m .34882 .79329 L .34169 .80236 L p .707 .577 .707 r
F P
0 g
s
.14701 .79103 m .14963 .77298 L .14688 .7624 L p .707 .577 .707 r
F P
0 g
s
.16503 .61319 m .16041 .66807 L .15331 .67685 L p .707 .577 .707 r
F P
0 g
s
.14688 .7624 m .14426 .78045 L .14701 .79103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14859 .73443 m .15369 .69831 L .16082 .68926 L p .707 .577 .707 r
F P
0 g
s
.55087 .25367 m .64103 .75645 L .63727 .7481 L p .707 .577 .707 r
F P
0 g
s
.63727 .7481 m .54712 .24533 L .55087 .25367 L p .707 .577 .707 r
F P
0 g
s
.16041 .66807 m .16503 .61319 L .18138 .60624 L p .707 .577 .707 r
F P
0 g
s
.16082 .68926 m .15572 .72539 L .14859 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34882 .79329 m .3462 .81134 L .34345 .80076 L p .707 .577 .707 r
F P
0 g
s
.34345 .80076 m .34607 .78271 L .34882 .79329 L p .707 .577 .707 r
F P
0 g
s
.14426 .78045 m .14688 .7624 L .15401 .75334 L p .707 .577 .707 r
F P
0 g
s
.18138 .60624 m .17676 .66112 L .16041 .66807 L p .707 .577 .707 r
F P
0 g
s
.15401 .75334 m .15139 .77138 L .14426 .78045 L p .707 .577 .707 r
F P
0 g
s
.15572 .72539 m .16082 .68926 L .17714 .68257 L p .707 .577 .707 r
F P
0 g
s
.17676 .66112 m .18138 .60624 L .20539 .60179 L p .707 .577 .707 r
F P
0 g
s
.17714 .68257 m .17204 .7187 L .15572 .72539 L p .707 .577 .707 r
F P
0 g
s
.34607 .78271 m .34345 .80076 L .33109 .7897 L p .707 .577 .707 r
F P
0 g
s
.33109 .7897 m .33371 .77166 L .34607 .78271 L p .707 .577 .707 r
F P
0 g
s
.54712 .24533 m .63727 .7481 L .62001 .74276 L p .707 .577 .707 r
F P
0 g
s
.62001 .74276 m .52986 .23998 L .54712 .24533 L p .707 .577 .707 r
F P
0 g
s
.15139 .77138 m .15401 .75334 L .17033 .74667 L p .707 .577 .707 r
F P
0 g
s
.20539 .60179 m .20076 .65667 L .17676 .66112 L p .707 .577 .707 r
F P
0 g
s
.3406 .70698 m .3355 .74311 L .31472 .73277 L p .707 .577 .707 r
F P
0 g
s
.31472 .73277 m .31982 .69664 L .3406 .70698 L p .707 .577 .707 r
F P
0 g
s
.20076 .65667 m .20539 .60179 L .23469 .60028 L p .707 .577 .707 r
F P
0 g
s
.17204 .7187 m .17714 .68257 L .20106 .67891 L p .707 .577 .707 r
F P
0 g
s
.17033 .74667 m .16771 .76472 L .15139 .77138 L p .707 .577 .707 r
F P
0 g
s
.29749 .60638 m .29287 .66125 L .2618 .65674 L p .707 .577 .707 r
F P
0 g
s
.2618 .65674 m .26643 .60186 L .29749 .60638 L p .707 .577 .707 r
F P
0 g
s
.23007 .65516 m .23469 .60028 L .26643 .60186 L p .707 .577 .707 r
F P
0 g
s
.23469 .60028 m .23007 .65516 L .20076 .65667 L p .707 .577 .707 r
F P
0 g
s
.20106 .67891 m .19596 .71503 L .17204 .7187 L p .707 .577 .707 r
F P
0 g
s
.26643 .60186 m .2618 .65674 L .23007 .65516 L p .707 .577 .707 r
F P
0 g
s
.72825 .65741 m .73287 .60253 L .70181 .59802 L p .707 .577 .707 r
F P
0 g
s
.73287 .60253 m .72825 .65741 L .75999 .65899 L p .707 .577 .707 r
F P
0 g
s
.75999 .65899 m .76461 .60411 L .73287 .60253 L p .707 .577 .707 r
F P
0 g
s
.33371 .77166 m .33109 .7897 L .31032 .77926 L p .707 .577 .707 r
F P
0 g
s
.31032 .77926 m .31294 .76121 L .33371 .77166 L p .707 .577 .707 r
F P
0 g
s
.31982 .69664 m .31472 .73277 L .28756 .72406 L p .707 .577 .707 r
F P
0 g
s
.28756 .72406 m .29266 .68794 L .31982 .69664 L p .707 .577 .707 r
F P
0 g
s
.76461 .60411 m .75999 .65899 L .78929 .65748 L p .707 .577 .707 r
F P
0 g
s
.78929 .65748 m .79391 .6026 L .76461 .60411 L p .707 .577 .707 r
F P
0 g
s
.36775 .79052 m .27759 .28775 L .30059 .27607 L p .707 .577 .707 r
F P
0 g
s
.27759 .28775 m .36775 .79052 L .35764 .80105 L p .707 .577 .707 r
F P
0 g
s
.16771 .76472 m .17033 .74667 L .19424 .74306 L p .707 .577 .707 r
F P
0 g
s
.19596 .71503 m .20106 .67891 L .23022 .67861 L p .707 .577 .707 r
F P
0 g
s
.69719 .6529 m .70181 .59802 L .67446 .59101 L p .707 .577 .707 r
F P
0 g
s
.70181 .59802 m .69719 .6529 L .72825 .65741 L p .707 .577 .707 r
F P
0 g
s
.19424 .74306 m .19162 .7611 L .16771 .76472 L p .707 .577 .707 r
F P
0 g
s
.52986 .23998 m .62001 .74276 L .59094 .74093 L p .707 .577 .707 r
F P
0 g
s
.59094 .74093 m .50079 .23816 L .52986 .23998 L p .707 .577 .707 r
F P
0 g
s
.79391 .6026 m .78929 .65748 L .81329 .65303 L p .707 .577 .707 r
F P
0 g
s
.81329 .65303 m .81792 .59816 L .79391 .6026 L p .707 .577 .707 r
F P
0 g
s
.29266 .68794 m .28756 .72406 L .25669 .71785 L p .707 .577 .707 r
F P
0 g
s
.25669 .71785 m .26179 .68173 L .29266 .68794 L p .707 .577 .707 r
F P
0 g
s
.23022 .67861 m .22512 .71474 L .19596 .71503 L p .707 .577 .707 r
F P
0 g
s
.22512 .71474 m .23022 .67861 L .26179 .68173 L p .707 .577 .707 r
F P
0 g
s
.66984 .64589 m .67446 .59101 L .6535 .5822 L p .707 .577 .707 r
F P
0 g
s
.67446 .59101 m .66984 .64589 L .69719 .6529 L p .707 .577 .707 r
F P
0 g
s
.26179 .68173 m .25669 .71785 L .22512 .71474 L p .707 .577 .707 r
F P
0 g
s
.31294 .76121 m .31032 .77926 L .28318 .77044 L p .707 .577 .707 r
F P
0 g
s
.28318 .77044 m .2858 .75239 L .31294 .76121 L p .707 .577 .707 r
F P
0 g
s
.72275 .71571 m .72785 .67958 L .69698 .67337 L p .707 .577 .707 r
F P
0 g
s
.72785 .67958 m .72275 .71571 L .75432 .71882 L p .707 .577 .707 r
F P
0 g
s
.75432 .71882 m .75942 .6827 L .72785 .67958 L p .707 .577 .707 r
F P
0 g
s
.19162 .7611 m .19424 .74306 L .22339 .74285 L p .707 .577 .707 r
F P
0 g
s
.75942 .6827 m .75432 .71882 L .78349 .71853 L p .707 .577 .707 r
F P
0 g
s
.78349 .71853 m .78859 .6824 L .75942 .6827 L p .707 .577 .707 r
F P
0 g
s
.69188 .7095 m .69698 .67337 L .66982 .66467 L p .707 .577 .707 r
F P
0 g
s
.69698 .67337 m .69188 .7095 L .72275 .71571 L p .707 .577 .707 r
F P
0 g
s
.22339 .74285 m .22077 .76089 L .19162 .7611 L p .707 .577 .707 r
F P
0 g
s
.81792 .59816 m .81329 .65303 L .82964 .64608 L p .707 .577 .707 r
F P
0 g
s
.82964 .64608 m .83427 .5912 L .81792 .59816 L p .707 .577 .707 r
F P
0 g
s
.2858 .75239 m .28318 .77044 L .25232 .76411 L p .707 .577 .707 r
F P
0 g
s
.25232 .76411 m .25494 .74606 L .2858 .75239 L p .707 .577 .707 r
F P
0 g
s
.6535 .5822 m .64888 .63708 L .66984 .64589 L p .707 .577 .707 r
F P
0 g
s
.22077 .76089 m .22339 .74285 L .25494 .74606 L p .707 .577 .707 r
F P
0 g
s
.30059 .27607 m .39074 .77884 L .36775 .79052 L p .707 .577 .707 r
F P
0 g
s
.39074 .77884 m .30059 .27607 L .33421 .26438 L p .707 .577 .707 r
F P
0 g
s
.78859 .6824 m .78349 .71853 L .8074 .71486 L p .707 .577 .707 r
F P
0 g
s
.8074 .71486 m .8125 .67874 L .78859 .6824 L p .707 .577 .707 r
F P
0 g
s
.66982 .66467 m .66472 .7008 L .69188 .7095 L p .707 .577 .707 r
F P
0 g
s
.71835 .75236 m .72097 .73432 L .69012 .72799 L p .707 .577 .707 r
F P
0 g
s
.72097 .73432 m .71835 .75236 L .7499 .75558 L p .707 .577 .707 r
F P
0 g
s
.7499 .75558 m .75252 .73754 L .72097 .73432 L p .707 .577 .707 r
F P
0 g
s
.25494 .74606 m .25232 .76411 L .22077 .76089 L p .707 .577 .707 r
F P
0 g
s
.66472 .7008 m .66982 .66467 L .64904 .65433 L p .707 .577 .707 r
F P
0 g
s
.64888 .63708 m .6535 .5822 L .64099 .57245 L p .707 .577 .707 r
F P
0 g
s
.75252 .73754 m .7499 .75558 L .77906 .75537 L p .707 .577 .707 r
F P
0 g
s
.77906 .75537 m .78168 .73733 L .75252 .73754 L p .707 .577 .707 r
F P
0 g
s
.6875 .74604 m .69012 .72799 L .66298 .71917 L p .707 .577 .707 r
F P
0 g
s
.69012 .72799 m .6875 .74604 L .71835 .75236 L p .707 .577 .707 r
F P
0 g
s
.50079 .23816 m .59094 .74093 L .5529 .74281 L p .707 .577 .707 r
F P
0 g
s
.5529 .74281 m .46275 .24004 L .50079 .23816 L p .707 .577 .707 r
F P
0 g
s
.66298 .71917 m .66036 .73722 L .6875 .74604 L p .707 .577 .707 r
F P
0 g
s
.64904 .65433 m .64394 .69045 L .66472 .7008 L p .707 .577 .707 r
F P
0 g
s
.78168 .73733 m .77906 .75537 L .80297 .75176 L p .707 .577 .707 r
F P
0 g
s
.80297 .75176 m .80558 .73371 L .78168 .73733 L p .707 .577 .707 r
F P
0 g
s
.64099 .57245 m .63637 .62733 L .64888 .63708 L p .707 .577 .707 r
F P
0 g
s
.8125 .67874 m .8074 .71486 L .82372 .70818 L p .707 .577 .707 r
F P
0 g
s
.82372 .70818 m .82882 .67205 L .8125 .67874 L p .707 .577 .707 r
F P
0 g
s
.66036 .73722 m .66298 .71917 L .64221 .70872 L p .707 .577 .707 r
F P
0 g
s
.83427 .5912 m .82964 .64608 L .83675 .6373 L p .707 .577 .707 r
F P
0 g
s
.83675 .6373 m .84137 .58242 L .83427 .5912 L p .707 .577 .707 r
F P
0 g
s
.64394 .69045 m .64904 .65433 L .63666 .64336 L p .707 .577 .707 r
F P
0 g
s
.64221 .70872 m .63959 .72677 L .66036 .73722 L p .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .38546 .55016 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .4216 .57134 L .39733 .57013 L p .707 .577 .707 r
F P
0 g
s
.46533 .7566 m .42437 .76715 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4216 .57134 m .41867 .60606 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .46533 .7566 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4216 .57134 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.44941 .57918 m .43782 .60317 L .44925 .57744 L .707 .577 .707 r
F
.46533 .7566 m .44032 .6171 L p .44941 .57918 L F P
0 g
s
.44032 .6171 m .43782 .60317 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4505 .57463 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.4505 .57463 m .4509 .56983 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .46533 .7566 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.45169 .56969 m .4509 .56983 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.41946 .24544 m .46652 .50784 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.46652 .50784 m .50962 .74821 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .47491 .56538 L .45169 .56969 L p .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .45169 .56969 L .45136 .57103 L .707 .577 .707 r
F
.44628 .62471 m .47028 .62026 L p .45136 .57103 L F P
0 g
s
.4505 .57463 m .44628 .62471 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.44628 .62471 m .4505 .57463 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .41946 .24544 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .37517 .25383 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .43782 .60317 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .44628 .62471 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .41698 .62622 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .41867 .60606 L p .38986 .56976 L .707 .577 .707 r
F P
0 g
s
.39733 .57013 m .38986 .56976 L p .41867 .60606 L .707 .577 .707 r
F P
0 g
s
.33421 .26438 m .37517 .25383 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .33421 .26438 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .39074 .77884 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .42437 .76715 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38986 .56976 m .38524 .62464 L .41264 .626 L p .707 .577 .707 r
F P
0 g
s
.41264 .626 m .41698 .62622 L p .40018 .59125 L .707 .577 .707 r
F P
0 g
s
.40018 .59125 m .38986 .56976 L .41264 .626 L .707 .577 .707 r
F
.33421 .26438 m .38546 .55016 L p .35684 .4703 L F P
0 g
s
.63637 .62733 m .64099 .57245 L .63814 .5627 L p .707 .577 .707 r
F P
0 g
s
.46275 .24004 m .5529 .74281 L .50962 .74821 L p .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .41946 .24544 L .46275 .24004 L p .707 .577 .707 r
F P
0 g
s
.63666 .64336 m .63156 .67948 L .64394 .69045 L p .707 .577 .707 r
F P
0 g
s
.80558 .73371 m .80297 .75176 L .81928 .74509 L p .707 .577 .707 r
F P
0 g
s
.81928 .74509 m .8219 .72704 L .80558 .73371 L p .707 .577 .707 r
F P
0 g
s
.63959 .72677 m .64221 .70872 L .62984 .69767 L p .707 .577 .707 r
F P
0 g
s
.82882 .67205 m .82372 .70818 L .83085 .69913 L p .707 .577 .707 r
F P
0 g
s
.83085 .69913 m .83595 .663 L .82882 .67205 L p .707 .577 .707 r
F P
0 g
s
.63814 .5627 m .63352 .61758 L .63637 .62733 L p .707 .577 .707 r
F P
0 g
s
.62984 .69767 m .62722 .71572 L .63959 .72677 L p .707 .577 .707 r
F P
0 g
s
.63156 .67948 m .63666 .64336 L .6339 .63283 L p .707 .577 .707 r
F P
0 g
s
.84137 .58242 m .83675 .6373 L .8339 .62756 L p .707 .577 .707 r
F P
0 g
s
.8339 .62756 m .83852 .57268 L .84137 .58242 L p .707 .577 .707 r
F P
0 g
s
.63352 .61758 m .63814 .5627 L .64524 .55393 L p .707 .577 .707 r
F P
0 g
s
.6339 .63283 m .6288 .66896 L .63156 .67948 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.8219 .72704 m .81928 .74509 L .82642 .73603 L p .707 .577 .707 r
F P
0 g
s
.82642 .73603 m .82904 .71798 L .8219 .72704 L p .707 .577 .707 r
F P
0 g
s
.62722 .71572 m .62984 .69767 L .62709 .68709 L p .707 .577 .707 r
F P
0 g
s
.62709 .68709 m .62447 .70514 L .62722 .71572 L p .707 .577 .707 r
F P
0 g
s
.83595 .663 m .83085 .69913 L .82809 .68861 L p .707 .577 .707 r
F P
0 g
s
.82809 .68861 m .83319 .65248 L .83595 .663 L p .707 .577 .707 r
F P
0 g
s
.64524 .55393 m .64062 .6088 L .63352 .61758 L p .707 .577 .707 r
F P
0 g
s
.6288 .66896 m .6339 .63283 L .64104 .62378 L p .707 .577 .707 r
F P
0 g
s
.83852 .57268 m .8339 .62756 L .82139 .6178 L p .707 .577 .707 r
F P
0 g
s
.82139 .6178 m .82601 .56293 L .83852 .57268 L p .707 .577 .707 r
F P
0 g
s
.64062 .6088 m .64524 .55393 L .6616 .54697 L p .707 .577 .707 r
F P
0 g
s
.38524 .62464 m .38986 .56976 L .3588 .56525 L p .707 .577 .707 r
F P
0 g
s
.64104 .62378 m .63593 .65991 L .6288 .66896 L p .707 .577 .707 r
F P
0 g
s
.82904 .71798 m .82642 .73603 L .82367 .72545 L p .707 .577 .707 r
F P
0 g
s
.82367 .72545 m .82629 .7074 L .82904 .71798 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35418 .62013 m .3588 .56525 L .33145 .55824 L p .707 .577 .707 r
F P
0 g
s
.3588 .56525 m .35418 .62013 L .38524 .62464 L p .707 .577 .707 r
F P
0 g
s
.62447 .70514 m .62709 .68709 L .63422 .67803 L p .707 .577 .707 r
F P
0 g
s
.63422 .67803 m .6316 .69607 L .62447 .70514 L p .707 .577 .707 r
F P
0 g
s
.83319 .65248 m .82809 .68861 L .81572 .67764 L p .707 .577 .707 r
F P
0 g
s
.81572 .67764 m .82082 .64151 L .83319 .65248 L p .707 .577 .707 r
F P
0 g
s
.6616 .54697 m .65697 .60185 L .64062 .6088 L p .707 .577 .707 r
F P
0 g
s
.82601 .56293 m .82139 .6178 L .80043 .60899 L p .707 .577 .707 r
F P
0 g
s
.80043 .60899 m .80505 .55411 L .82601 .56293 L p .707 .577 .707 r
F P
0 g
s
.63593 .65991 m .64104 .62378 L .65736 .6171 L p .707 .577 .707 r
F P
0 g
s
.32683 .61312 m .33145 .55824 L .31049 .54943 L p .707 .577 .707 r
F P
0 g
s
.33145 .55824 m .32683 .61312 L .35418 .62013 L p .707 .577 .707 r
F P
0 g
s
.65697 .60185 m .6616 .54697 L .6856 .54252 L p .707 .577 .707 r
F P
0 g
s
.37974 .68915 m .38484 .65302 L .35397 .64681 L p .707 .577 .707 r
F P
0 g
s
.38484 .65302 m .37974 .68915 L .41131 .69226 L p .707 .577 .707 r
F P
0 g
s
.41131 .69226 m .41641 .65613 L .38484 .65302 L p .707 .577 .707 r
F P
0 g
s
.41641 .65613 m .41131 .69226 L .44048 .69197 L p .707 .577 .707 r
F P
0 g
s
.44048 .69197 m .44558 .65584 L .41641 .65613 L p .707 .577 .707 r
F P
0 g
s
.34887 .68294 m .35397 .64681 L .32681 .63811 L p .707 .577 .707 r
F P
0 g
s
.35397 .64681 m .34887 .68294 L .37974 .68915 L p .707 .577 .707 r
F P
0 g
s
.65736 .6171 m .65226 .65323 L .63593 .65991 L p .707 .577 .707 r
F P
0 g
s
.82629 .7074 m .82367 .72545 L .8113 .71439 L p .707 .577 .707 r
F P
0 g
s
.8113 .71439 m .81392 .69635 L .82629 .7074 L p .707 .577 .707 r
F P
0 g
s
.47491 .56538 m .47028 .62026 L .48663 .61331 L p .707 .577 .707 r
F P
0 g
s
.48663 .61331 m .49126 .55843 L .47491 .56538 L p .707 .577 .707 r
F P
0 g
s
.6316 .69607 m .63422 .67803 L .65054 .67136 L p .707 .577 .707 r
F P
0 g
s
.31049 .54943 m .30587 .60431 L .32683 .61312 L p .707 .577 .707 r
F P
0 g
s
.80505 .55411 m .80043 .60899 L .77308 .60199 L p .707 .577 .707 r
F P
0 g
s
.77308 .60199 m .7777 .54711 L .80505 .55411 L p .707 .577 .707 r
F P
0 g
s
.6856 .54252 m .68098 .5974 L .65697 .60185 L p .707 .577 .707 r
F P
0 g
s
.82082 .64151 m .81572 .67764 L .79493 .66729 L p .707 .577 .707 r
F P
0 g
s
.79493 .66729 m .80003 .63117 L .82082 .64151 L p .707 .577 .707 r
F P
0 g
s
.44558 .65584 m .44048 .69197 L .46439 .6883 L p .707 .577 .707 r
F P
0 g
s
.46439 .6883 m .46949 .65217 L .44558 .65584 L p .707 .577 .707 r
F P
0 g
s
.32681 .63811 m .32171 .67423 L .34887 .68294 L p .707 .577 .707 r
F P
0 g
s
.65054 .67136 m .64792 .68941 L .6316 .69607 L p .707 .577 .707 r
F P
0 g
s
.30587 .60431 m .31049 .54943 L .29798 .53968 L p .707 .577 .707 r
F P
0 g
s
.32171 .67423 m .32681 .63811 L .30603 .62776 L p .707 .577 .707 r
F P
0 g
s
.68098 .5974 m .6856 .54252 L .7149 .54101 L p .707 .577 .707 r
F P
0 g
s
.65226 .65323 m .65736 .6171 L .68127 .61343 L p .707 .577 .707 r
F P
0 g
s
.37534 .73564 m .37796 .71759 L .34711 .71126 L p .707 .577 .707 r
F P
0 g
s
.37796 .71759 m .37534 .73564 L .40689 .73885 L p .707 .577 .707 r
F P
0 g
s
.40689 .73885 m .40951 .72081 L .37796 .71759 L p .707 .577 .707 r
F P
0 g
s
.40951 .72081 m .40689 .73885 L .43605 .73864 L p .707 .577 .707 r
F P
0 g
s
.43605 .73864 m .43867 .7206 L .40951 .72081 L p .707 .577 .707 r
F P
0 g
s
.34449 .72931 m .34711 .71126 L .31997 .70244 L p .707 .577 .707 r
F P
0 g
s
.34711 .71126 m .34449 .72931 L .37534 .73564 L p .707 .577 .707 r
F P
0 g
s
.7777 .54711 m .77308 .60199 L .74202 .59747 L p .707 .577 .707 r
F P
0 g
s
.74202 .59747 m .74664 .54259 L .7777 .54711 L p .707 .577 .707 r
F P
0 g
s
.30603 .62776 m .30093 .66389 L .32171 .67423 L p .707 .577 .707 r
F P
0 g
s
.31997 .70244 m .31735 .72049 L .34449 .72931 L p .707 .577 .707 r
F P
0 g
s
.71028 .59589 m .7149 .54101 L .74664 .54259 L p .707 .577 .707 r
F P
0 g
s
.7149 .54101 m .71028 .59589 L .68098 .5974 L p .707 .577 .707 r
F P
0 g
s
.68127 .61343 m .67617 .64956 L .65226 .65323 L p .707 .577 .707 r
F P
0 g
s
.81392 .69635 m .8113 .71439 L .79053 .70395 L p .707 .577 .707 r
F P
0 g
s
.79053 .70395 m .79315 .6859 L .81392 .69635 L p .707 .577 .707 r
F P
0 g
s
.29798 .53968 m .29336 .59455 L .30587 .60431 L p .707 .577 .707 r
F P
0 g
s
.74664 .54259 m .74202 .59747 L .71028 .59589 L p .707 .577 .707 r
F P
0 g
s
.46949 .65217 m .46439 .6883 L .48071 .68162 L p .707 .577 .707 r
F P
0 g
s
.48071 .68162 m .48581 .64549 L .46949 .65217 L p .707 .577 .707 r
F P
0 g
s
.43867 .7206 m .43605 .73864 L .45996 .73503 L p .707 .577 .707 r
F P
0 g
s
.45996 .73503 m .46257 .71698 L .43867 .7206 L p .707 .577 .707 r
F P
0 g
s
.49126 .55843 m .48663 .61331 L .49374 .60453 L p .707 .577 .707 r
F P
0 g
s
.49374 .60453 m .49836 .54965 L .49126 .55843 L p .707 .577 .707 r
F P
0 g
s
.64792 .68941 m .65054 .67136 L .67445 .66775 L p .707 .577 .707 r
F P
0 g
s
.80003 .63117 m .79493 .66729 L .76778 .65859 L p .707 .577 .707 r
F P
0 g
s
.76778 .65859 m .77288 .62246 L .80003 .63117 L p .707 .577 .707 r
F P
0 g
s
.31735 .72049 m .31997 .70244 L .2992 .692 L p .707 .577 .707 r
F P
0 g
s
.67617 .64956 m .68127 .61343 L .71044 .61314 L p .707 .577 .707 r
F P
0 g
s
.30093 .66389 m .30603 .62776 L .29365 .61679 L p .707 .577 .707 r
F P
0 g
s
.67445 .66775 m .67183 .68579 L .64792 .68941 L p .707 .577 .707 r
F P
0 g
s
.29336 .59455 m .29798 .53968 L .29513 .52993 L p .707 .577 .707 r
F P
0 g
s
.2992 .692 m .29658 .71004 L .31735 .72049 L p .707 .577 .707 r
F P
0 g
s
.77288 .62246 m .76778 .65859 L .7369 .65238 L p .707 .577 .707 r
F P
0 g
s
.7369 .65238 m .742 .61625 L .77288 .62246 L p .707 .577 .707 r
F P
0 g
s
.71044 .61314 m .70534 .64927 L .67617 .64956 L p .707 .577 .707 r
F P
0 g
s
.29365 .61679 m .28855 .65292 L .30093 .66389 L p .707 .577 .707 r
F P
0 g
s
.70534 .64927 m .71044 .61314 L .742 .61625 L p .707 .577 .707 r
F P
0 g
s
.79315 .6859 m .79053 .70395 L .76339 .69513 L p .707 .577 .707 r
F P
0 g
s
.76339 .69513 m .76601 .67708 L .79315 .6859 L p .707 .577 .707 r
F P
0 g
s
.742 .61625 m .7369 .65238 L .70534 .64927 L p .707 .577 .707 r
F P
0 g
s
.46257 .71698 m .45996 .73503 L .47627 .72836 L p .707 .577 .707 r
F P
0 g
s
.47627 .72836 m .47889 .71032 L .46257 .71698 L p .707 .577 .707 r
F P
0 g
s
.67183 .68579 m .67445 .66775 L .70361 .66754 L p .707 .577 .707 r
F P
0 g
s
.29658 .71004 m .2992 .692 L .28683 .68094 L p .707 .577 .707 r
F P
0 g
s
.29513 .52993 m .29051 .58481 L .29336 .59455 L p .707 .577 .707 r
F P
0 g
s
.48581 .64549 m .48071 .68162 L .48784 .67257 L p .707 .577 .707 r
F P
0 g
s
.48784 .67257 m .49294 .63644 L .48581 .64549 L p .707 .577 .707 r
F P
0 g
s
.70361 .66754 m .70099 .68558 L .67183 .68579 L p .707 .577 .707 r
F P
0 g
s
.49836 .54965 m .49374 .60453 L .49089 .59479 L p .707 .577 .707 r
F P
0 g
s
.49089 .59479 m .49551 .53991 L .49836 .54965 L p .707 .577 .707 r
F P
0 g
s
.28683 .68094 m .28421 .69899 L .29658 .71004 L p .707 .577 .707 r
F P
0 g
s
.28855 .65292 m .29365 .61679 L .29089 .60627 L p .707 .577 .707 r
F P
0 g
s
.76601 .67708 m .76339 .69513 L .73254 .6888 L p .707 .577 .707 r
F P
0 g
s
.73254 .6888 m .73516 .67075 L .76601 .67708 L p .707 .577 .707 r
F P
0 g
s
.70099 .68558 m .70361 .66754 L .73516 .67075 L p .707 .577 .707 r
F P
0 g
s
.29051 .58481 m .29513 .52993 L .30223 .52115 L p .707 .577 .707 r
F P
0 g
s
.73516 .67075 m .73254 .6888 L .70099 .68558 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29089 .60627 m .28579 .64239 L .28855 .65292 L p .707 .577 .707 r
F P
0 g
s
.47889 .71032 m .47627 .72836 L .48341 .7193 L p .707 .577 .707 r
F P
0 g
s
.48341 .7193 m .48603 .70125 L .47889 .71032 L p .707 .577 .707 r
F P
0 g
s
.28421 .69899 m .28683 .68094 L .28408 .67036 L p .707 .577 .707 r
F P
0 g
s
.30223 .52115 m .29761 .57603 L .29051 .58481 L p .707 .577 .707 r
F P
0 g
s
.49294 .63644 m .48784 .67257 L .48508 .66204 L p .707 .577 .707 r
F P
0 g
s
.48508 .66204 m .49018 .62592 L .49294 .63644 L p .707 .577 .707 r
F P
0 g
s
.28408 .67036 m .28146 .68841 L .28421 .69899 L p .707 .577 .707 r
F P
0 g
s
.49551 .53991 m .49089 .59479 L .47837 .58503 L p .707 .577 .707 r
F P
0 g
s
.47837 .58503 m .483 .53015 L .49551 .53991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28579 .64239 m .29089 .60627 L .29802 .59722 L p .707 .577 .707 r
F P
0 g
s
.29761 .57603 m .30223 .52115 L .31859 .5142 L p .707 .577 .707 r
F P
0 g
s
.29802 .59722 m .29292 .63335 L .28579 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48603 .70125 m .48341 .7193 L .48066 .70872 L p .707 .577 .707 r
F P
0 g
s
.48066 .70872 m .48328 .69067 L .48603 .70125 L p .707 .577 .707 r
F P
0 g
s
.28146 .68841 m .28408 .67036 L .29121 .6613 L p .707 .577 .707 r
F P
0 g
s
.31859 .5142 m .31396 .56908 L .29761 .57603 L p .707 .577 .707 r
F P
0 g
s
.49018 .62592 m .48508 .66204 L .47271 .65107 L p .707 .577 .707 r
F P
0 g
s
.47271 .65107 m .47781 .61495 L .49018 .62592 L p .707 .577 .707 r
F P
0 g
s
.483 .53015 m .47837 .58503 L .45742 .57622 L p .707 .577 .707 r
F P
0 g
s
.45742 .57622 m .46204 .52134 L .483 .53015 L p .707 .577 .707 r
F P
0 g
s
.29121 .6613 m .28859 .67934 L .28146 .68841 L p .707 .577 .707 r
F P
0 g
s
.29292 .63335 m .29802 .59722 L .31435 .59053 L p .707 .577 .707 r
F P
0 g
s
.31396 .56908 m .31859 .5142 L .34259 .50975 L p .707 .577 .707 r
F P
0 g
s
.31435 .59053 m .30925 .62666 L .29292 .63335 L p .707 .577 .707 r
F P
0 g
s
.48328 .69067 m .48066 .70872 L .46829 .69767 L p .707 .577 .707 r
F P
0 g
s
.46829 .69767 m .47091 .67962 L .48328 .69067 L p .707 .577 .707 r
F P
0 g
s
.46204 .52134 m .45742 .57622 L .43007 .56922 L p .707 .577 .707 r
F P
0 g
s
.43007 .56922 m .43469 .51434 L .46204 .52134 L p .707 .577 .707 r
F P
0 g
s
.28859 .67934 m .29121 .6613 L .30753 .65463 L p .707 .577 .707 r
F P
0 g
s
.34259 .50975 m .33796 .56463 L .31396 .56908 L p .707 .577 .707 r
F P
0 g
s
.47781 .61495 m .47271 .65107 L .45192 .64073 L p .707 .577 .707 r
F P
0 g
s
.45192 .64073 m .45702 .6046 L .47781 .61495 L p .707 .577 .707 r
F P
0 g
s
.33796 .56463 m .34259 .50975 L .37189 .50824 L p .707 .577 .707 r
F P
0 g
s
.30925 .62666 m .31435 .59053 L .33826 .58687 L p .707 .577 .707 r
F P
0 g
s
.30753 .65463 m .30491 .67268 L .28859 .67934 L p .707 .577 .707 r
F P
0 g
s
.43469 .51434 m .43007 .56922 L .39901 .5647 L p .707 .577 .707 r
F P
0 g
s
.39901 .5647 m .40363 .50982 L .43469 .51434 L p .707 .577 .707 r
F P
0 g
s
.36727 .56312 m .37189 .50824 L .40363 .50982 L p .707 .577 .707 r
F P
0 g
s
.37189 .50824 m .36727 .56312 L .33796 .56463 L p .707 .577 .707 r
F P
0 g
s
.33826 .58687 m .33316 .62299 L .30925 .62666 L p .707 .577 .707 r
F P
0 g
s
.40363 .50982 m .39901 .5647 L .36727 .56312 L p .707 .577 .707 r
F P
0 g
s
.47091 .67962 m .46829 .69767 L .44752 .68722 L p .707 .577 .707 r
F P
0 g
s
.44752 .68722 m .45014 .66917 L .47091 .67962 L p .707 .577 .707 r
F P
0 g
s
.45702 .6046 m .45192 .64073 L .42476 .63203 L p .707 .577 .707 r
F P
0 g
s
.42476 .63203 m .42986 .5959 L .45702 .6046 L p .707 .577 .707 r
F P
0 g
s
.30491 .67268 m .30753 .65463 L .33144 .65102 L p .707 .577 .707 r
F P
0 g
s
.33316 .62299 m .33826 .58687 L .36743 .58657 L p .707 .577 .707 r
F P
0 g
s
.33144 .65102 m .32882 .66906 L .30491 .67268 L p .707 .577 .707 r
F P
0 g
s
.42986 .5959 m .42476 .63203 L .39389 .62581 L p .707 .577 .707 r
F P
0 g
s
.39389 .62581 m .39899 .58969 L .42986 .5959 L p .707 .577 .707 r
F P
0 g
s
.36743 .58657 m .36233 .6227 L .33316 .62299 L p .707 .577 .707 r
F P
0 g
s
.36233 .6227 m .36743 .58657 L .39899 .58969 L p .707 .577 .707 r
F P
0 g
s
.39899 .58969 m .39389 .62581 L .36233 .6227 L p .707 .577 .707 r
F P
0 g
s
.45014 .66917 m .44752 .68722 L .42038 .6784 L p .707 .577 .707 r
F P
0 g
s
.42038 .6784 m .423 .66035 L .45014 .66917 L p .707 .577 .707 r
F P
0 g
s
.32882 .66906 m .33144 .65102 L .36059 .65081 L p .707 .577 .707 r
F P
0 g
s
.36059 .65081 m .35798 .66885 L .32882 .66906 L p .707 .577 .707 r
F P
0 g
s
.423 .66035 m .42038 .6784 L .38953 .67207 L p .707 .577 .707 r
F P
0 g
s
.38953 .67207 m .39214 .65402 L .423 .66035 L p .707 .577 .707 r
F P
0 g
s
.35798 .66885 m .36059 .65081 L .39214 .65402 L p .707 .577 .707 r
F P
0 g
s
.39214 .65402 m .38953 .67207 L .35798 .66885 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool9002;Ool007ioo`/0
00UJEPL008Aoo`00MGoo2@006eYF0`00PGoo001aOol40002FUH00`00FUIJEP0EFUH00`00FUIJEP0:
FUJ1Ool006eoo`@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo07ioo`00JGoo10002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0OWoo001UOol4000?FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1nOol0065oo`@001=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07ioo`00GWoo0`002UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Ogoo001KOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1mOol005Moo`@000AJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo07eoo`00E7oo0`002EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0OGoo001BOol200000eYF
001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1mOol0051oo`8000=JEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo07eoo`00CWoo0P001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00OWoo
001=Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OWoo001=Ool20007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001m
Ool004aoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001mOol004eoo`9JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001mOol004eoo`9JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07]oo`00CGoo0eYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Ngoo001=Ool3FUH00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1kOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001lOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00O7oo
001=Ool01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001=Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001>Ool3FUH0
0`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1jOol004ioo`=JEP03001J
EUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007]oo`00CWoo0eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Ngoo001>Ool01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8007]oo`00CWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Uo
o`00Cgoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Yoo`00Cgoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001jOol004moo`04001JEUYF0007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001iOol0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001i
Ool0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001@Ool01000FUIJ
EP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00N7oo001AOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP8007Qoo`00DGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Io
o`00DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00
DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00DGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04
001JEUYFFUH2001gOol0059oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1e
Ool0059oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001fOol005=oo`04
001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00MWoo001COol01000FUIJEP001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8007Eoo`00E7oo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8007Aoo`00EGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2001dOol005Eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1bOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1b
Ool005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1bOol0
05Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00Lgoo001FOol01000FUIJEP001UYF3P002EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol0
1P00FUIJEUYF001JEP@00003FUH005YF00IJEP03001JEUYF009JEPX000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo075oo`00EWoo00<005YFFUH0
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol300000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001bOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001bOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
071oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0L7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80075oo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001]oo`T004eoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH2000DOol70004FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`0=Ool50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`0;Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000jOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`09Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000hOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P002Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00P00=7oo001BOol00`00FUH00004FUH01000FUIJEUYF6@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00DWoo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH010000UYF1@000eYF1P001UYF
00<005YFFUH00eYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`06Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool0059oo`04001JEP00
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70007FUH00`00FUH000030002FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00H0
05YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40009FUH00`00FUIJEP02FUH30004
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF009JEP03001J
EUYF0080009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20007Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH30003FUH20008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1goo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF
400000=JEP00FUH02eYF00<005YFFUH00UYF00<005YFFUH00eYF0P000eYF0P0025YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol01Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YFFUIJEP8002eoo`00DWoo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001eYF
00D005YFFUIJEP0000IJEP03001JEP00009JEP8000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo00Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005=o
o`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0
00=JEP05001JEUYFFUH00005FUH01000FUIJEUYF100025YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Goo001COol30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool00`00FUH00003FUH00`00FUIJEP03FUHE0006FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003moo`P000aoo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJ
EP03001JEUYF009JEP<000UJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool0
0`00FUH00003FUH00`00FUH000030005FUH70004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JERioo`00=goo20000eYF00<005YFFUH00UYF2@000goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol00goo00<005YF00000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH^Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP8000YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00=oo`04001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF0P002UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000P001UYF00<005YFFUH01EYF00<005YF
FUH01UYF10001EYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8002ioo`00;Woo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH00eYF40000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF10002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0017oo00H005YFFUIJEP00FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0017oo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00D000MJEP03001JEUYF00AJEP03001JEP00009JEP8002ioo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YF
FUIJEQL000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool01000FUH000000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH015YF00<005YF
FUH00`00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH00003FUH400000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00002eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol00Woo0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH00UYF
0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH005YF1@000UYF00D005YFFUIJEP0000IJEP03001JEUYF00AJEPD000=J
EP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`02Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH2000_Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP000002FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50007
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEPD000UJEP<00003FUH0
05YF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEP0002moo`00;7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH0
0eYF00<005YF00000`001UYF00<005YFFUH015YF10002eYF0`001EYF00L005YFFUIJEP00FUH0000;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH00000031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1@0000=JEP00
FUH025YF00<005YFFUH02EYF00<005YFFUH00P000eYF00@005YFFUIJEP8000aJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo
000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH02EYF
0P000eYF0P0000=JEP00FUH00UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF0000<Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF600035YF00<005YFFUH0
1@000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP000000
0eYF1P000UYF0P000Woo1P000eYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YFFUH00eYF5@001UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH040000eYF00L005YF001JEP00FUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000005YF0`0015YF00<005YFFUH0
0UYF0P001Woo2@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YF00000`001eYF00<005YF00000`000Woo1@0000=o
o`0000000P000UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF100015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00000035YF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP80009JEP<0009JEP03001JEUYF00=JEP8000ioo`T000EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002]oo`03001JEP00009JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00=JEPl000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000aJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00<000EJEP04001JEP00
000EOol400000eYF001JEP05FUH01000FUIJEUYF0P00;goo000[Ool00`00FUH000030005FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40005FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`001UYF00@005YFFUIJEP800003FUH005YF00]J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH@000DOol2
0006FUH01000FUIJEUYF0P00;goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001EYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00
3goo0P000eYF00L005YFFUIJEP00FUH0000_Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEPL000IJEP03001JEUYF00AJEPT0
00AJEP03001JEUYF00EJEP<0009JEP09001JEUYFFUH005YF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@000eoo`800003FUH005YF009JEP03001JEP0002moo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF200000=JEP00FUH01eYF00@005YF001JEP80009JEP03001JEUYF009JEP80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPH000IJEP03001JEUYF00<000=JEP80009JEP8000aJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;Ool20003FUH00`00FUH0000_Ool002]oo`80
00=JEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEPL000=JEP04001JEP000004FUH00`00FUIJ
EP04FUH300000eYF001JEP06FUH01000FUIJEUYF0`000eYF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000007Ool50002FUH2000`Ool002aoo`05001JEUYF001JEP050003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP060005FUH00`00FUIJEP04FUH00`00FUIJEP050004FUH0
0`00FUIJEP0500000eYF001JEP05FUH300000eYF001JEP04FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF1`000UYF00<005YFFUH01000<7oo000/Ool00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
0eYF00000003FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF300000=JEP00FUH01eYF0`001EYF
00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP04001JEUYFFUH70002FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00EJEP05001JEUYFFUH00006FUH0
1000FUIJEUYF50000eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEPH00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0`00<7oo000/Ool20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40006FUH2
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF0`0000=JEP00FUH00UYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0009JEP80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00<000=J
EP03001JEP00031oo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00`000eYF00<005YF00000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH00P000eYF0P000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF1`0025YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`0000AJEP00FUH0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP05FUH200000eYF0000000aOol002]oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEP00
00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00=JEP800003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYF001JEP00FUH000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000aOol002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP04001JEUYFFUH30003FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH20004FUH200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01@00FUIJEUYF00001UYF
1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP05001JEUYFFUH0000bOol0
02]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF008000=JEP03001JEUYF00AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00003FUH300000eYF001JEP05FUH00`00FUH00002FUH50002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0`Ool002Yoo`03001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP06FUH0
0`00FUIJEP040003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH20004FUH00`00FUIJEP0;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00P001UYF00<005YF
FUH00`0017oo2@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP80035oo`00:Woo00<005YF
00000eYF100047oo2@0015YF00<005YFFUH01EYF0`001UYF00<005YFFUH015YF5`000eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000EJEP<0009JEP03001JEUYF009JEP8000Uooa8000Eoo`03001JEUYF0080035oo`00:Woo
00@005YF001JEPD001Eoo`<0009oo`H000IJEP03001JEUYF008000=JEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH00`00FUH000020004FUH20009
Ool5000COol4000aOol002Yoo`04001JEP000002FUH00`00FUIJEP02000BOol50007Ool20004FUH0
0`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006FUH01000FUIJEUYF0`0000AJEP00FUH000Uoo`D001=oo`@0035oo`00:Woo0P00
0eYF00<005YFFUH00eYF0P0047oo1@002Goo0`0000=JEP00FUH015YF1@001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP03001JEUYF00EJEPD000Uoo`<0019oo`80
0003FUH00000039oo`00:Woo0P000eYF00<005YFFUH00eYF00@005YF000000ioo`D000aoo`8000EJ
EP05001JEUYF001JEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF0P0000=JEP00FUH01eYF00@005YFFUIJEPT0015oo`@000=JEP80039oo`00:Woo0P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP<000aoo`<000moo`8000=JEP04001JEUYF0002FUH00`00FUIJEP07
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1@002eYF00<005YFFUH02eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF009JEQ40009J
EP07001JEUYFFUH005YF0000<Woo000[Ool01@00FUIJEUYF00001EYF00<005YFFUH015YF1P006Woo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00EJEP03001JEP0000l000AJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00=JEPT000AJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00<goo000[Ool01@00FUIJEUYF000015YF5`0047oo1@000UYF00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJEP`000MJEP03001JEP00
00H0009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=7oo000/Ool00`00FUH000050003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHG0003FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF20002UYF00<005YFFUH01UYF00<005YFFUH01EYF
10001EYF00<005YFFUH00eYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000003Eoo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH04EYF10001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH015YF00@005YFFUIJEP800003Ool0000000L000AJEP03001J
EUYF00EJEP04001JEUYFFUH5000gOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH03EYF10002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF00EJEP04001JEUYFFUH2000:
Ool@000lOol002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH30006FUH01000FUIJEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP00009oo`8000IJEP04001JEUYFFUH2001FOol002Uoo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH2
000:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005Ool20003FUH01`00FUIJEUYF001JEP0005Io
o`00:Goo00<005YF00000eYF1`001UYF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF0`000UYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04000:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20008Ool200000eYF
001JEP02FUH00`00FUH0001FOol002Uoo`04001JEP00FUH20007Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH30003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH400000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH2000;Ool20003FUH00`00FUH0001FOol002Uoo`04001JEP00000;Ool3
00000eYF001JEP07FUH00`00FUIJEP030003FUH40006FUH00`00FUIJEP02FUH20002FUH00`00Oomo
o`03FUH00`00FUIJEP0:FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`0000=JEP0000001goo1@000UYF0P00Egoo000YOol3000?Ool3
0006FUH00`00FUIJEP050002FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF0`000goo0eYF00<0
05YFFUH01eYF0`0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00@005YF0000009JEP04001JEUYFFUH70002FUH00`00FUIJEP04001GOol002Uoo`800003FUH0
0000011oo`@0009JEP03001JEUYF00D00003FUH005YF00MJEP<000EJEP04001JEP000002Ool01000
FUIJEP001UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF0P00Egoo000YOol00`00FUIJEP02
FUH00`00Oomoo`0AOol:00000eYF001JEP03FUH90003FUH01`00FUIJEUYF001oo`0000MJEP8000=J
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009J
EPD000AJEP03001JEUYF00IJEP<0009JEP04001JEUYFFUH3001GOol002Uoo`03001JEUYF009JEP<0
01Moo`X000Uoo`800003FUH005YF009JEP03001oo`0000EJEP8000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEP00008000EJEPH000MJEP03001JEUYF
00<000=JEP03001JEP0005Moo`00:Goo00<005YFFUH00UYF00<005YFFUH00P00:Woo0P000eYF0`00
0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00
00=JEP00FUH025YF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000Egoo000Z
Ool01000FUIJEP001EYF0P00:Woo00H005YF001JEP00Ool2FUH01000FUIJEP001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF100015YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0P0000=JEP000000F7oo000[Ool00`00FUH00005FUH01000
FUH00000:Goo0P0000EJEP00OomJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJ
EP03001JEP00008005Qoo`00;7oo0P001EYF00@005YFFUIJEP<002Moo`05001JEP00Ool00004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0FFUH400000goo000000030006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH000000eYF00D005YFFUIJEP0005Uoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF10008Woo0`000Woo00<005YFFUH00UYF00<005YFFUH07UYF00<005YFFUH0
15YF10002Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00UYF00<007ooOol0Egoo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20000
0eYF00000003Ool5FUH00`00FUIJEP0@FUH00`00FUIJEP0:FUH00`00FUIJEP06000@Ool70004FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@000eYF0P00F7oo000`Ool200000eYF001JEP06FUH00`00FUIJ
EP04FUH7000@Ool50003FUH20003Ool30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH:0005FUH3000COolA0005Ool00`00FUIJEP02001HOol0039oo`<000EJEP03001JEUYF00MJ
EP03001JEUYF009JEQ0000=JEP04001JEUYFFUH20007Ool60004FUH00`00FUIJEP03FUH<0008Ool2
0006FUH01000FUH0000047oo1@004goo1000F7oo000eOol400000eYF001JEP08FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P003Goo2P005Goo00<005YFFUH015YF
00@005YFFUIJEP<000eoo`D001=oo`@005Qoo`00>Goo10001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`8000=JEP03001JEUYF00EJEPD000Qoo`D0015o
o`800003FUH0000005Uoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF0000039oo`800003FUH005YF00MJEP04001JEUYFFUH<000>Ool40003FUH2001IOol0
045oo`L000AJEP03001JEUYF00EJEP04001JEUYFFUH5000fOol30007FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHA0002FUH01`00FUIJEUYF001JEP0005Uoo`00B7oo4000?Woo0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Yoo`00V7oo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Yoo`00Vgoo10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P00Fgoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00GGoo
002SOol70004FUH00`00FUIJEP02FUH7001SOol00:Yoo`T006Yoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5878 .7493 m .59527 .69506 L .56438 .68895 L p .707 .577 .707 r
F P
0 g
s
.59527 .69506 m .5878 .7493 L .61938 .75232 L p .707 .577 .707 r
F P
0 g
s
.61938 .75232 m .62685 .69808 L .59527 .69506 L p .707 .577 .707 r
F P
0 g
s
.62685 .69808 m .61938 .75232 L .64856 .75195 L p .707 .577 .707 r
F P
0 g
s
.64856 .75195 m .65602 .69771 L .62685 .69808 L p .707 .577 .707 r
F P
0 g
s
.55692 .74319 m .56438 .68895 L .53721 .68035 L p .707 .577 .707 r
F P
0 g
s
.56438 .68895 m .55692 .74319 L .5878 .7493 L p .707 .577 .707 r
F P
0 g
s
.65602 .69771 m .64856 .75195 L .67248 .74824 L p .707 .577 .707 r
F P
0 g
s
.67248 .74824 m .67994 .694 L .65602 .69771 L p .707 .577 .707 r
F P
0 g
s
.52974 .73459 m .53721 .68035 L .51641 .6701 L p .707 .577 .707 r
F P
0 g
s
.53721 .68035 m .52974 .73459 L .55692 .74319 L p .707 .577 .707 r
F P
0 g
s
.57874 .80619 m .58694 .77101 L .55656 .7622 L p .707 .577 .707 r
F P
0 g
s
.58694 .77101 m .57874 .80619 L .60986 .81164 L p .707 .577 .707 r
F P
0 g
s
.60986 .81164 m .61807 .77646 L .58694 .77101 L p .707 .577 .707 r
F P
0 g
s
.54835 .79739 m .55656 .7622 L .52988 .75091 L p .707 .577 .707 r
F P
0 g
s
.55656 .7622 m .54835 .79739 L .57874 .80619 L p .707 .577 .707 r
F P
0 g
s
.61807 .77646 m .60986 .81164 L .63869 .81321 L p .707 .577 .707 r
F P
0 g
s
.63869 .81321 m .64689 .77803 L .61807 .77646 L p .707 .577 .707 r
F P
0 g
s
.67994 .694 m .67248 .74824 L .6888 .74153 L p .707 .577 .707 r
F P
0 g
s
.6888 .74153 m .69627 .6873 L .67994 .694 L p .707 .577 .707 r
F P
0 g
s
.51641 .6701 m .50895 .72434 L .52974 .73459 L p .707 .577 .707 r
F P
0 g
s
.50895 .72434 m .51641 .6701 L .50402 .6592 L p .707 .577 .707 r
F P
0 g
s
.52988 .75091 m .52168 .78609 L .54835 .79739 L p .707 .577 .707 r
F P
0 g
s
.52168 .78609 m .52988 .75091 L .50953 .73822 L p .707 .577 .707 r
F P
0 g
s
.64689 .77803 m .63869 .81321 L .66238 .81073 L p .707 .577 .707 r
F P
0 g
s
.66238 .81073 m .67058 .77555 L .64689 .77803 L p .707 .577 .707 r
F P
0 g
s
.57159 .83972 m .5758 .82217 L .54546 .81318 L p .707 .577 .707 r
F P
0 g
s
.5758 .82217 m .57159 .83972 L .60268 .84534 L p .707 .577 .707 r
F P
0 g
s
.60268 .84534 m .60689 .82779 L .5758 .82217 L p .707 .577 .707 r
F P
0 g
s
.54125 .83073 m .54546 .81318 L .51883 .8017 L p .707 .577 .707 r
F P
0 g
s
.54546 .81318 m .54125 .83073 L .57159 .83972 L p .707 .577 .707 r
F P
0 g
s
.60689 .82779 m .60268 .84534 L .63147 .84703 L p .707 .577 .707 r
F P
0 g
s
.63147 .84703 m .63568 .82948 L .60689 .82779 L p .707 .577 .707 r
F P
0 g
s
.51883 .8017 m .51461 .81925 L .54125 .83073 L p .707 .577 .707 r
F P
0 g
s
.50953 .73822 m .50133 .77341 L .52168 .78609 L p .707 .577 .707 r
F P
0 g
s
.50402 .6592 m .49656 .71344 L .50895 .72434 L p .707 .577 .707 r
F P
0 g
s
.51461 .81925 m .51883 .8017 L .49852 .78886 L p .707 .577 .707 r
F P
0 g
s
.63568 .82948 m .63147 .84703 L .65514 .84464 L p .707 .577 .707 r
F P
0 g
s
.65514 .84464 m .65935 .82709 L .63568 .82948 L p .707 .577 .707 r
F P
0 g
s
.50133 .77341 m .50953 .73822 L .4975 .7254 L p .707 .577 .707 r
F P
0 g
s
.67058 .77555 m .66238 .81073 L .67862 .80446 L p .707 .577 .707 r
F P
0 g
s
.67862 .80446 m .68683 .76928 L .67058 .77555 L p .707 .577 .707 r
F P
0 g
s
.69627 .6873 m .6888 .74153 L .69593 .7325 L p .707 .577 .707 r
F P
0 g
s
.69593 .7325 m .7034 .67826 L .69627 .6873 L p .707 .577 .707 r
F P
0 g
s
.49852 .78886 m .49431 .80641 L .51461 .81925 L p .707 .577 .707 r
F P
0 g
s
.49656 .71344 m .50402 .6592 L .50126 .64873 L p .707 .577 .707 r
F P
0 g
s
.4975 .7254 m .4893 .76058 L .50133 .77341 L p .707 .577 .707 r
F P
0 g
s
.49431 .80641 m .49852 .78886 L .48652 .7759 L p .707 .577 .707 r
F P
0 g
s
.65935 .82709 m .65514 .84464 L .67138 .8384 L p .707 .577 .707 r
F P
0 g
s
.67138 .8384 m .67559 .82085 L .65935 .82709 L p .707 .577 .707 r
F P
0 g
s
.50126 .64873 m .49379 .70297 L .49656 .71344 L p .707 .577 .707 r
F P
0 g
s
.48652 .7759 m .48231 .79345 L .49431 .80641 L p .707 .577 .707 r
F P
0 g
s
.4893 .76058 m .4975 .7254 L .49497 .71368 L p .707 .577 .707 r
F P
0 g
s
.68683 .76928 m .67862 .80446 L .68583 .795 L p .707 .577 .707 r
F P
0 g
s
.68583 .795 m .69404 .75982 L .68683 .76928 L p .707 .577 .707 r
F P
0 g
s
.7034 .67826 m .69593 .7325 L .69317 .72203 L p .707 .577 .707 r
F P
0 g
s
.69317 .72203 m .70063 .66779 L .7034 .67826 L p .707 .577 .707 r
F P
0 g
s
.49379 .70297 m .50126 .64873 L .50839 .6397 L p .707 .577 .707 r
F P
0 g
s
.49497 .71368 m .48676 .74886 L .4893 .76058 L p .707 .577 .707 r
F P
0 g
s
.48231 .79345 m .48652 .7759 L .484 .7641 L p .707 .577 .707 r
F P
0 g
s
.67559 .82085 m .67138 .8384 L .67859 .82891 L p .707 .577 .707 r
F P
0 g
s
.67859 .82891 m .68281 .81136 L .67559 .82085 L p .707 .577 .707 r
F P
0 g
s
.484 .7641 m .47979 .78165 L .48231 .79345 L p .707 .577 .707 r
F P
0 g
s
.50839 .6397 m .50092 .69394 L .49379 .70297 L p .707 .577 .707 r
F P
0 g
s
.48676 .74886 m .49497 .71368 L .50217 .70422 L p .707 .577 .707 r
F P
0 g
s
.69404 .75982 m .68583 .795 L .68329 .78328 L p .707 .577 .707 r
F P
0 g
s
.68329 .78328 m .6915 .7481 L .69404 .75982 L p .707 .577 .707 r
F P
0 g
s
.70063 .66779 m .69317 .72203 L .68078 .71113 L p .707 .577 .707 r
F P
0 g
s
.68078 .71113 m .68824 .65689 L .70063 .66779 L p .707 .577 .707 r
F P
0 g
s
.50092 .69394 m .50839 .6397 L .52471 .633 L p .707 .577 .707 r
F P
0 g
s
.50217 .70422 m .49397 .7394 L .48676 .74886 L p .707 .577 .707 r
F P
0 g
s
.24479 .71903 m .25226 .66479 L .22137 .65868 L p .707 .577 .707 r
F P
0 g
s
.25226 .66479 m .24479 .71903 L .27637 .72205 L p .707 .577 .707 r
F P
0 g
s
.27637 .72205 m .28384 .66781 L .25226 .66479 L p .707 .577 .707 r
F P
0 g
s
.28384 .66781 m .27637 .72205 L .30555 .72168 L p .707 .577 .707 r
F P
0 g
s
.30555 .72168 m .31301 .66744 L .28384 .66781 L p .707 .577 .707 r
F P
0 g
s
.47979 .78165 m .484 .7641 L .49122 .75461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21391 .71292 m .22137 .65868 L .1942 .65008 L p .707 .577 .707 r
F P
0 g
s
.22137 .65868 m .21391 .71292 L .24479 .71903 L p .707 .577 .707 r
F P
0 g
s
.68281 .81136 m .67859 .82891 L .67608 .81711 L p .707 .577 .707 r
F P
0 g
s
.67608 .81711 m .68029 .79956 L .68281 .81136 L p .707 .577 .707 r
F P
0 g
s
.49122 .75461 m .487 .77216 L .47979 .78165 L p .707 .577 .707 r
F P
0 g
s
.52471 .633 m .51725 .68723 L .50092 .69394 L p .707 .577 .707 r
F P
0 g
s
.49397 .7394 m .50217 .70422 L .51842 .69795 L p .707 .577 .707 r
F P
0 g
s
.6915 .7481 m .68329 .78328 L .67126 .77046 L p .707 .577 .707 r
F P
0 g
s
.67126 .77046 m .67947 .73527 L .6915 .7481 L p .707 .577 .707 r
F P
0 g
s
.31301 .66744 m .30555 .72168 L .32947 .71796 L p .707 .577 .707 r
F P
0 g
s
.32947 .71796 m .33694 .66372 L .31301 .66744 L p .707 .577 .707 r
F P
0 g
s
.68824 .65689 m .68078 .71113 L .65998 .70088 L p .707 .577 .707 r
F P
0 g
s
.65998 .70088 m .66745 .64664 L .68824 .65689 L p .707 .577 .707 r
F P
0 g
s
.18674 .70432 m .1942 .65008 L .1734 .63983 L p .707 .577 .707 r
F P
0 g
s
.1942 .65008 m .18674 .70432 L .21391 .71292 L p .707 .577 .707 r
F P
0 g
s
.51725 .68723 m .52471 .633 L .54863 .62928 L p .707 .577 .707 r
F P
0 g
s
.48678 .79716 m .34228 .30268 L .30016 .31302 L p .707 .577 .707 r
F P
0 g
s
.51842 .69795 m .51021 .73313 L .49397 .7394 L p .707 .577 .707 r
F P
0 g
s
.487 .77216 m .49122 .75461 L .50746 .74836 L p .707 .577 .707 r
F P
0 g
s
.50746 .74836 m .50324 .76592 L .487 .77216 L p .707 .577 .707 r
F P
0 g
s
.50324 .76592 m .50746 .74836 L .53113 .74597 L p .707 .577 .707 r
F P
0 g
s
.53113 .74597 m .52691 .76353 L .50324 .76592 L p .707 .577 .707 r
F P
0 g
s
.34228 .30268 m .48678 .79716 L .53002 .78431 L p .707 .577 .707 r
F P
0 g
s
.51021 .73313 m .51842 .69795 L .54211 .69547 L p .707 .577 .707 r
F P
0 g
s
.54211 .69547 m .53391 .73065 L .51021 .73313 L p .707 .577 .707 r
F P
0 g
s
.53002 .78431 m .38552 .28983 L .34228 .30268 L p .707 .577 .707 r
F P
0 g
s
.54863 .62928 m .54117 .68352 L .51725 .68723 L p .707 .577 .707 r
F P
0 g
s
.53391 .73065 m .54211 .69547 L .57093 .69704 L p .707 .577 .707 r
F P
0 g
s
.57093 .69704 m .56273 .73222 L .53391 .73065 L p .707 .577 .707 r
F P
0 g
s
.52691 .76353 m .53113 .74597 L .55992 .74767 L p .707 .577 .707 r
F P
0 g
s
.55992 .74767 m .5557 .76522 L .52691 .76353 L p .707 .577 .707 r
F P
0 g
s
.5557 .76522 m .55992 .74767 L .59101 .75328 L p .707 .577 .707 r
F P
0 g
s
.59101 .75328 m .58679 .77084 L .5557 .76522 L p .707 .577 .707 r
F P
0 g
s
.38552 .28983 m .53002 .78431 L .57014 .77021 L p .707 .577 .707 r
F P
0 g
s
.54117 .68352 m .54863 .62928 L .57781 .62891 L p .707 .577 .707 r
F P
0 g
s
.57781 .62891 m .57035 .68315 L .54117 .68352 L p .707 .577 .707 r
F P
0 g
s
.57014 .77021 m .42565 .27573 L .38552 .28983 L p .707 .577 .707 r
F P
0 g
s
.23573 .78596 m .24393 .75078 L .21355 .74198 L p .707 .577 .707 r
F P
0 g
s
.24393 .75078 m .23573 .78596 L .26686 .79141 L p .707 .577 .707 r
F P
0 g
s
.26686 .79141 m .27506 .75623 L .24393 .75078 L p .707 .577 .707 r
F P
0 g
s
.20534 .77716 m .21355 .74198 L .18687 .73068 L p .707 .577 .707 r
F P
0 g
s
.21355 .74198 m .20534 .77716 L .23573 .78596 L p .707 .577 .707 r
F P
0 g
s
.27506 .75623 m .26686 .79141 L .29568 .79298 L p .707 .577 .707 r
F P
0 g
s
.29568 .79298 m .30388 .7578 L .27506 .75623 L p .707 .577 .707 r
F P
0 g
s
.68029 .79956 m .67608 .81711 L .66408 .80415 L p .707 .577 .707 r
F P
0 g
s
.66408 .80415 m .66829 .7866 L .68029 .79956 L p .707 .577 .707 r
F P
0 g
s
.44466 .80751 m .30016 .31302 L .26329 .31985 L p .707 .577 .707 r
F P
0 g
s
.30016 .31302 m .44466 .80751 L .48678 .79716 L p .707 .577 .707 r
F P
0 g
s
.33694 .66372 m .32947 .71796 L .34579 .71126 L p .707 .577 .707 r
F P
0 g
s
.34579 .71126 m .35326 .65702 L .33694 .66372 L p .707 .577 .707 r
F P
0 g
s
.1734 .63983 m .16594 .69407 L .18674 .70432 L p .707 .577 .707 r
F P
0 g
s
.66745 .64664 m .65998 .70088 L .63281 .69228 L p .707 .577 .707 r
F P
0 g
s
.63281 .69228 m .64027 .63804 L .66745 .64664 L p .707 .577 .707 r
F P
0 g
s
.57035 .68315 m .57781 .62891 L .60939 .63193 L p .707 .577 .707 r
F P
0 g
s
.60939 .63193 m .60192 .68617 L .57035 .68315 L p .707 .577 .707 r
F P
0 g
s
.56273 .73222 m .57093 .69704 L .60206 .70249 L p .707 .577 .707 r
F P
0 g
s
.63245 .71129 m .62424 .74648 L .59385 .73767 L p .707 .577 .707 r
F P
0 g
s
.59385 .73767 m .60206 .70249 L .63245 .71129 L p .707 .577 .707 r
F P
0 g
s
.60206 .70249 m .59385 .73767 L .56273 .73222 L p .707 .577 .707 r
F P
0 g
s
.58679 .77084 m .59101 .75328 L .62135 .76227 L p .707 .577 .707 r
F P
0 g
s
.42565 .27573 m .57014 .77021 L .60323 .75625 L p .707 .577 .707 r
F P
0 g
s
.60323 .75625 m .45874 .26176 L .42565 .27573 L p .707 .577 .707 r
F P
0 g
s
.16594 .69407 m .1734 .63983 L .16102 .62893 L p .707 .577 .707 r
F P
0 g
s
.67947 .73527 m .67126 .77046 L .65092 .75777 L p .707 .577 .707 r
F P
0 g
s
.65092 .75777 m .65912 .72259 L .67947 .73527 L p .707 .577 .707 r
F P
0 g
s
.18687 .73068 m .17867 .76586 L .20534 .77716 L p .707 .577 .707 r
F P
0 g
s
.17867 .76586 m .18687 .73068 L .16653 .71799 L p .707 .577 .707 r
F P
0 g
s
.30388 .7578 m .29568 .79298 L .31937 .7905 L p .707 .577 .707 r
F P
0 g
s
.31937 .7905 m .32758 .75532 L .30388 .7578 L p .707 .577 .707 r
F P
0 g
s
.22858 .83541 m .23279 .81786 L .20245 .80887 L p .707 .577 .707 r
F P
0 g
s
.23279 .81786 m .22858 .83541 L .25967 .84103 L p .707 .577 .707 r
F P
0 g
s
.25967 .84103 m .26388 .82347 L .23279 .81786 L p .707 .577 .707 r
F P
0 g
s
.64027 .63804 m .63281 .69228 L .60192 .68617 L p .707 .577 .707 r
F P
0 g
s
.60192 .68617 m .60939 .63193 L .64027 .63804 L p .707 .577 .707 r
F P
0 g
s
.19824 .82642 m .20245 .80887 L .17582 .79739 L p .707 .577 .707 r
F P
0 g
s
.20245 .80887 m .19824 .82642 L .22858 .83541 L p .707 .577 .707 r
F P
0 g
s
.26388 .82347 m .25967 .84103 L .28846 .84272 L p .707 .577 .707 r
F P
0 g
s
.28846 .84272 m .29267 .82517 L .26388 .82347 L p .707 .577 .707 r
F P
0 g
s
.16653 .71799 m .15832 .75318 L .17867 .76586 L p .707 .577 .707 r
F P
0 g
s
.16102 .62893 m .15355 .68317 L .16594 .69407 L p .707 .577 .707 r
F P
0 g
s
.35326 .65702 m .34579 .71126 L .35292 .70223 L p .707 .577 .707 r
F P
0 g
s
.35292 .70223 m .36039 .64799 L .35326 .65702 L p .707 .577 .707 r
F P
0 g
s
.36039 .64799 m .35292 .70223 L .35099 .6949 L p .707 .577 .707 r
F P
0 g
s
.35099 .6949 m .35016 .69175 L p .35376 .67633 L .707 .577 .707 r
F P
0 g
s
.35376 .67633 m .36039 .64799 L .35099 .6949 L .707 .577 .707 r
F
.40778 .81434 m .44466 .80751 L p .36584 .59557 L F P
0 g
s
.26329 .31985 m .3584 .64533 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.35016 .69175 m .3515 .68198 L p .36039 .64799 L .707 .577 .707 r
F P
0 g
s
.26329 .31985 m .23527 .32249 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .26329 .31985 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.35893 .64248 m .36039 .64799 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .40778 .81434 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .34459 .69663 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35016 .69175 L .34785 .68972 L p .707 .577 .707 r
F P
0 g
s
.34459 .69663 m .37976 .81698 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .21884 .32069 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .35371 .72782 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.35371 .72782 m .23527 .32249 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32778 .67594 m .32205 .67311 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.32205 .67311 m .31697 .67061 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .32155 .66348 L .32205 .67311 L .707 .577 .707 r
F
.21884 .32069 m .21562 .31462 L p .2962 .58767 L F P
0 g
s
.34282 .77477 m .35103 .73959 L .34382 .74905 L p .707 .577 .707 r
F P
0 g
s
.33561 .78423 m .34382 .74905 L .32758 .75532 L p .707 .577 .707 r
F P
0 g
s
.34382 .74905 m .33561 .78423 L .34282 .77477 L p .707 .577 .707 r
F P
0 g
s
.35103 .73959 m .34282 .77477 L .34028 .76306 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .34849 .72787 L .35103 .73959 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .32825 .75023 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34849 .72787 m .34439 .74544 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34439 .74544 m .34028 .76306 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .31873 .65783 L .32155 .66348 L .707 .577 .707 r
F
.31697 .67061 m .31832 .66079 L p .31991 .66604 L F P
0 g
s
.31832 .66079 m .31873 .65783 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .33646 .71505 L .34849 .72787 L p .707 .577 .707 r
F P
0 g
s
.31697 .67061 m .2898 .66201 L p .3106 .6346 L .707 .577 .707 r
F P
0 g
s
.3106 .6346 m .31136 .63718 L .31697 .67061 L .707 .577 .707 r
F
.31873 .65783 m .31697 .67061 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .21884 .32069 L p .26526 .48089 L .707 .577 .707 r
F P
0 g
s
.21884 .32069 m .30766 .62464 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.34558 .71155 m .30766 .62464 L .31873 .65783 L .707 .577 .707 r
F
.2898 .66201 m .29727 .60777 L .32444 .61637 L p F P
0 g
s
.31542 .6512 m .30766 .62464 L p .2962 .58767 L .707 .577 .707 r
F P
0 g
s
.30766 .62464 m .26526 .48089 L .2962 .58767 L .707 .577 .707 r
F
.3106 .6346 m .31087 .63425 L .31136 .63718 L F
.32444 .61637 m .31873 .65783 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .31542 .6512 L p .31873 .65783 L .707 .577 .707 r
F P
0 g
s
.21562 .31462 m .22592 .30488 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .32602 .74884 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.3214 .72691 m .33501 .71619 L .32602 .74884 L .707 .577 .707 r
F
.33646 .71505 m .33568 .7184 L p .33501 .71619 L F P
0 g
s
.33568 .7184 m .32825 .75023 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .31611 .70236 L .33424 .71366 L p .707 .577 .707 r
F P
0 g
s
.33424 .71366 m .33646 .71505 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .33424 .71366 L .33501 .71619 L .707 .577 .707 r
F
.27313 .51142 m .28343 .54666 L p .2962 .58767 L F P
0 g
s
.28343 .54666 m .36012 .8091 L p .30166 .60659 L .707 .577 .707 r
F P
0 g
s
.2962 .58767 m .28343 .54666 L .30166 .60659 L .707 .577 .707 r
F
.36012 .8091 m .36334 .81518 L p .30572 .61994 L F P
0 g
s
.30572 .61994 m .2962 .58767 L .30166 .60659 L .707 .577 .707 r
F
.30572 .61994 m .30166 .60659 L .36012 .8091 L F
.21562 .31462 m .27313 .51142 L p .2962 .58767 L F P
0 g
s
.325 .68525 m .31542 .6512 L .2962 .58767 L .707 .577 .707 r
F
.36334 .81518 m .32902 .69774 L p .325 .68525 L F P
0 g
s
.32902 .69774 m .31542 .6512 L p .325 .68525 L .707 .577 .707 r
F P
0 g
s
.31542 .6512 m .36334 .81518 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.31873 .65783 m .32444 .61637 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.36012 .8091 m .28343 .54666 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.28343 .54666 m .21562 .31462 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32602 .74884 m .30791 .73754 L p .3214 .72691 L .707 .577 .707 r
F P
0 g
s
.36334 .81518 m .37976 .81698 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32444 .61637 m .34523 .62662 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.34523 .62662 m .33777 .68086 L .32778 .67594 L p .707 .577 .707 r
F P
0 g
s
.32155 .66348 m .34523 .62662 L .32778 .67594 L .707 .577 .707 r
F
.35762 .63752 m .3515 .68198 L p .33777 .68086 L F P
0 g
s
.34785 .68972 m .33777 .68086 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35762 .63752 L .35893 .64248 L p .707 .577 .707 r
F P
0 g
s
.40778 .81434 m .3584 .64533 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .40778 .81434 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.17582 .79739 m .17161 .81494 L .19824 .82642 L p .707 .577 .707 r
F P
0 g
s
.66829 .7866 m .66408 .80415 L .64377 .7913 L p .707 .577 .707 r
F P
0 g
s
.64377 .7913 m .64798 .77375 L .66829 .7866 L p .707 .577 .707 r
F P
0 g
s
.65912 .72259 m .65092 .75777 L .62424 .74648 L p .707 .577 .707 r
F P
0 g
s
.62424 .74648 m .63245 .71129 L .65912 .72259 L p .707 .577 .707 r
F P
0 g
s
.15832 .75318 m .16653 .71799 L .15449 .70517 L p .707 .577 .707 r
F P
0 g
s
.32758 .75532 m .31937 .7905 L .33561 .78423 L p .707 .577 .707 r
F P
0 g
s
.45874 .26176 m .60323 .75625 L .62604 .74378 L p .707 .577 .707 r
F P
0 g
s
.62604 .74378 m .48155 .2493 L .45874 .26176 L p .707 .577 .707 r
F P
0 g
s
.17161 .81494 m .17582 .79739 L .15551 .78454 L p .707 .577 .707 r
F P
0 g
s
.29267 .82517 m .28846 .84272 L .31213 .84033 L p .707 .577 .707 r
F P
0 g
s
.31213 .84033 m .31634 .82278 L .29267 .82517 L p .707 .577 .707 r
F P
0 g
s
.15355 .68317 m .16102 .62893 L .15825 .61846 L p .707 .577 .707 r
F P
0 g
s
.15551 .78454 m .1513 .80209 L .17161 .81494 L p .707 .577 .707 r
F P
0 g
s
.15449 .70517 m .14629 .74035 L .15832 .75318 L p .707 .577 .707 r
F P
0 g
s
.64798 .77375 m .64377 .7913 L .61714 .77983 L p .707 .577 .707 r
F P
0 g
s
.61714 .77983 m .62135 .76227 L .64798 .77375 L p .707 .577 .707 r
F P
0 g
s
.15825 .61846 m .15078 .67269 L .15355 .68317 L p .707 .577 .707 r
F P
0 g
s
.1513 .80209 m .15551 .78454 L .14351 .77158 L p .707 .577 .707 r
F P
0 g
s
.31634 .82278 m .31213 .84033 L .32837 .83408 L p .707 .577 .707 r
F P
0 g
s
.32837 .83408 m .33258 .81653 L .31634 .82278 L p .707 .577 .707 r
F P
0 g
s
.14629 .74035 m .15449 .70517 L .15196 .69345 L p .707 .577 .707 r
F P
0 g
s
.14351 .77158 m .1393 .78914 L .1513 .80209 L p .707 .577 .707 r
F P
0 g
s
.62135 .76227 m .61714 .77983 L .58679 .77084 L p .707 .577 .707 r
F P
0 g
s
.15078 .67269 m .15825 .61846 L .16538 .60942 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.48155 .2493 m .62604 .74378 L .63634 .73404 L p .707 .577 .707 r
F P
0 g
s
.63634 .73404 m .49185 .23955 L .48155 .2493 L p .707 .577 .707 r
F P
0 g
s
.15196 .69345 m .14375 .72863 L .14629 .74035 L p .707 .577 .707 r
F P
0 g
s
.1393 .78914 m .14351 .77158 L .14099 .75978 L p .707 .577 .707 r
F P
0 g
s
.33258 .81653 m .32837 .83408 L .33558 .8246 L p .707 .577 .707 r
F P
0 g
s
.33558 .8246 m .3398 .80705 L .33258 .81653 L p .707 .577 .707 r
F P
0 g
s
.16538 .60942 m .15791 .66366 L .15078 .67269 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14375 .72863 m .15196 .69345 L .15917 .68399 L p .707 .577 .707 r
F P
0 g
s
.14099 .75978 m .13678 .77734 L .1393 .78914 L p .707 .577 .707 r
F P
0 g
s
.33777 .68086 m .34523 .62662 L .35762 .63752 L p .707 .577 .707 r
F P
0 g
s
.15791 .66366 m .16538 .60942 L .1817 .60272 L p .707 .577 .707 r
F P
0 g
s
.15917 .68399 m .15096 .71918 L .14375 .72863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13678 .77734 m .14099 .75978 L .14821 .7503 L p .707 .577 .707 r
F P
0 g
s
.49185 .23955 m .63634 .73404 L .63312 .72797 L p .707 .577 .707 r
F P
0 g
s
.63312 .72797 m .48863 .23348 L .49185 .23955 L p .707 .577 .707 r
F P
0 g
s
.3398 .80705 m .33558 .8246 L .33307 .8128 L p .707 .577 .707 r
F P
0 g
s
.33307 .8128 m .33728 .79525 L .3398 .80705 L p .707 .577 .707 r
F P
0 g
s
.1817 .60272 m .17424 .65696 L .15791 .66366 L p .707 .577 .707 r
F P
0 g
s
.14821 .7503 m .14399 .76785 L .13678 .77734 L p .707 .577 .707 r
F P
0 g
s
.15096 .71918 m .15917 .68399 L .17541 .67772 L p .707 .577 .707 r
F P
0 g
s
.17424 .65696 m .1817 .60272 L .20562 .59901 L p .707 .577 .707 r
F P
0 g
s
.17541 .67772 m .1672 .7129 L .15096 .71918 L p .707 .577 .707 r
F P
0 g
s
.20562 .59901 m .19816 .65325 L .17424 .65696 L p .707 .577 .707 r
F P
0 g
s
.14399 .76785 m .14821 .7503 L .16445 .74405 L p .707 .577 .707 r
F P
0 g
s
.33728 .79525 m .33307 .8128 L .32107 .79984 L p .707 .577 .707 r
F P
0 g
s
.32107 .79984 m .32528 .78229 L .33728 .79525 L p .707 .577 .707 r
F P
0 g
s
.19816 .65325 m .20562 .59901 L .2348 .59864 L p .707 .577 .707 r
F P
0 g
s
.1672 .7129 m .17541 .67772 L .1991 .67524 L p .707 .577 .707 r
F P
0 g
s
.16445 .74405 m .16023 .7616 L .14399 .76785 L p .707 .577 .707 r
F P
0 g
s
.29727 .60777 m .2898 .66201 L .25891 .6559 L p .707 .577 .707 r
F P
0 g
s
.25891 .6559 m .26638 .60166 L .29727 .60777 L p .707 .577 .707 r
F P
0 g
s
.22734 .65288 m .2348 .59864 L .26638 .60166 L p .707 .577 .707 r
F P
0 g
s
.2348 .59864 m .22734 .65288 L .19816 .65325 L p .707 .577 .707 r
F P
0 g
s
.48863 .23348 m .63312 .72797 L .6167 .72616 L p .707 .577 .707 r
F P
0 g
s
.6167 .72616 m .4722 .23168 L .48863 .23348 L p .707 .577 .707 r
F P
0 g
s
.1991 .67524 m .1909 .71043 L .1672 .7129 L p .707 .577 .707 r
F P
0 g
s
.26638 .60166 m .25891 .6559 L .22734 .65288 L p .707 .577 .707 r
F P
0 g
s
.72501 .65726 m .73247 .60302 L .70159 .59691 L p .707 .577 .707 r
F P
0 g
s
.73247 .60302 m .72501 .65726 L .75658 .66028 L p .707 .577 .707 r
F P
0 g
s
.75658 .66028 m .76405 .60604 L .73247 .60302 L p .707 .577 .707 r
F P
0 g
s
.76405 .60604 m .75658 .66028 L .78576 .65991 L p .707 .577 .707 r
F P
0 g
s
.78576 .65991 m .79323 .60567 L .76405 .60604 L p .707 .577 .707 r
F P
0 g
s
.1909 .71043 m .1991 .67524 L .22792 .67681 L p .707 .577 .707 r
F P
0 g
s
.31611 .70236 m .30791 .73754 L .28123 .72625 L p .707 .577 .707 r
F P
0 g
s
.28123 .72625 m .28944 .69107 L .31611 .70236 L p .707 .577 .707 r
F P
0 g
s
.69412 .65115 m .70159 .59691 L .67441 .58831 L p .707 .577 .707 r
F P
0 g
s
.70159 .59691 m .69412 .65115 L .72501 .65726 L p .707 .577 .707 r
F P
0 g
s
.16023 .7616 m .16445 .74405 L .18812 .74166 L p .707 .577 .707 r
F P
0 g
s
.32528 .78229 m .32107 .79984 L .30076 .78699 L p .707 .577 .707 r
F P
0 g
s
.30076 .78699 m .30497 .76944 L .32528 .78229 L p .707 .577 .707 r
F P
0 g
s
.18812 .74166 m .1839 .75921 L .16023 .7616 L p .707 .577 .707 r
F P
0 g
s
.79323 .60567 m .78576 .65991 L .80968 .6562 L p .707 .577 .707 r
F P
0 g
s
.80968 .6562 m .81715 .60196 L .79323 .60567 L p .707 .577 .707 r
F P
0 g
s
.22792 .67681 m .21972 .71199 L .1909 .71043 L p .707 .577 .707 r
F P
0 g
s
.21972 .71199 m .22792 .67681 L .25905 .68226 L p .707 .577 .707 r
F P
0 g
s
.28944 .69107 m .28123 .72625 L .25084 .71744 L p .707 .577 .707 r
F P
0 g
s
.25084 .71744 m .25905 .68226 L .28944 .69107 L p .707 .577 .707 r
F P
0 g
s
.66695 .64255 m .67441 .58831 L .65362 .57806 L p .707 .577 .707 r
F P
0 g
s
.67441 .58831 m .66695 .64255 L .69412 .65115 L p .707 .577 .707 r
F P
0 g
s
.25905 .68226 m .25084 .71744 L .21972 .71199 L p .707 .577 .707 r
F P
0 g
s
.71594 .71415 m .72415 .67897 L .69376 .67017 L p .707 .577 .707 r
F P
0 g
s
.72415 .67897 m .71594 .71415 L .74707 .7196 L p .707 .577 .707 r
F P
0 g
s
.74707 .7196 m .75528 .68442 L .72415 .67897 L p .707 .577 .707 r
F P
0 g
s
.1839 .75921 m .18812 .74166 L .21691 .74335 L p .707 .577 .707 r
F P
0 g
s
.30497 .76944 m .30076 .78699 L .27413 .77551 L p .707 .577 .707 r
F P
0 g
s
.27413 .77551 m .27834 .75796 L .30497 .76944 L p .707 .577 .707 r
F P
0 g
s
.68555 .70535 m .69376 .67017 L .66709 .65887 L p .707 .577 .707 r
F P
0 g
s
.69376 .67017 m .68555 .70535 L .71594 .71415 L p .707 .577 .707 r
F P
0 g
s
.37041 .79936 m .22592 .30488 L .24873 .29241 L p .707 .577 .707 r
F P
0 g
s
.22592 .30488 m .37041 .79936 L .36012 .8091 L p .707 .577 .707 r
F P
0 g
s
.75528 .68442 m .74707 .7196 L .77589 .72117 L p .707 .577 .707 r
F P
0 g
s
.77589 .72117 m .7841 .68599 L .75528 .68442 L p .707 .577 .707 r
F P
0 g
s
.21691 .74335 m .21269 .76091 L .1839 .75921 L p .707 .577 .707 r
F P
0 g
s
.4722 .23168 m .6167 .72616 L .58867 .72881 L p .707 .577 .707 r
F P
0 g
s
.58867 .72881 m .44418 .23432 L .4722 .23168 L p .707 .577 .707 r
F P
0 g
s
.81715 .60196 m .80968 .6562 L .82601 .6495 L p .707 .577 .707 r
F P
0 g
s
.82601 .6495 m .83347 .59526 L .81715 .60196 L p .707 .577 .707 r
F P
0 g
s
.65362 .57806 m .64615 .6323 L .66695 .64255 L p .707 .577 .707 r
F P
0 g
s
.21269 .76091 m .21691 .74335 L .248 .74897 L p .707 .577 .707 r
F P
0 g
s
.27834 .75796 m .27413 .77551 L .24378 .76652 L p .707 .577 .707 r
F P
0 g
s
.24378 .76652 m .248 .74897 L .27834 .75796 L p .707 .577 .707 r
F P
0 g
s
.64615 .6323 m .65362 .57806 L .64123 .56717 L p .707 .577 .707 r
F P
0 g
s
.66709 .65887 m .65888 .69405 L .68555 .70535 L p .707 .577 .707 r
F P
0 g
s
.65888 .69405 m .66709 .65887 L .64674 .64618 L p .707 .577 .707 r
F P
0 g
s
.7841 .68599 m .77589 .72117 L .79958 .71869 L p .707 .577 .707 r
F P
0 g
s
.79958 .71869 m .80779 .68351 L .7841 .68599 L p .707 .577 .707 r
F P
0 g
s
.70879 .74769 m .71301 .73013 L .68266 .72114 L p .707 .577 .707 r
F P
0 g
s
.71301 .73013 m .70879 .74769 L .73988 .7533 L p .707 .577 .707 r
F P
0 g
s
.73988 .7533 m .7441 .73575 L .71301 .73013 L p .707 .577 .707 r
F P
0 g
s
.248 .74897 m .24378 .76652 L .21269 .76091 L p .707 .577 .707 r
F P
0 g
s
.67845 .7387 m .68266 .72114 L .65603 .70966 L p .707 .577 .707 r
F P
0 g
s
.68266 .72114 m .67845 .7387 L .70879 .74769 L p .707 .577 .707 r
F P
0 g
s
.7441 .73575 m .73988 .7533 L .76867 .755 L p .707 .577 .707 r
F P
0 g
s
.76867 .755 m .77289 .73744 L .7441 .73575 L p .707 .577 .707 r
F P
0 g
s
.65603 .70966 m .65182 .72722 L .67845 .7387 L p .707 .577 .707 r
F P
0 g
s
.64674 .64618 m .63853 .68137 L .65888 .69405 L p .707 .577 .707 r
F P
0 g
s
.64123 .56717 m .63376 .6214 L .64615 .6323 L p .707 .577 .707 r
F P
0 g
s
.65182 .72722 m .65603 .70966 L .63572 .69682 L p .707 .577 .707 r
F P
0 g
s
.77289 .73744 m .76867 .755 L .79235 .75261 L p .707 .577 .707 r
F P
0 g
s
.79235 .75261 m .79656 .73505 L .77289 .73744 L p .707 .577 .707 r
F P
0 g
s
.63853 .68137 m .64674 .64618 L .63471 .63336 L p .707 .577 .707 r
F P
0 g
s
.80779 .68351 m .79958 .71869 L .81583 .71242 L p .707 .577 .707 r
F P
0 g
s
.81583 .71242 m .82403 .67724 L .80779 .68351 L p .707 .577 .707 r
F P
0 g
s
.83347 .59526 m .82601 .6495 L .83314 .64046 L p .707 .577 .707 r
F P
0 g
s
.83314 .64046 m .8406 .58623 L .83347 .59526 L p .707 .577 .707 r
F P
0 g
s
.24873 .29241 m .39322 .78689 L .37041 .79936 L p .707 .577 .707 r
F P
0 g
s
.39322 .78689 m .24873 .29241 L .28182 .27845 L p .707 .577 .707 r
F P
0 g
s
.63572 .69682 m .63151 .71437 L .65182 .72722 L p .707 .577 .707 r
F P
0 g
s
.63376 .6214 m .64123 .56717 L .63846 .55669 L p .707 .577 .707 r
F P
0 g
s
.44418 .23432 m .58867 .72881 L .5518 .73564 L p .707 .577 .707 r
F P
0 g
s
.5518 .73564 m .40731 .24115 L .44418 .23432 L p .707 .577 .707 r
F P
0 g
s
.63471 .63336 m .6265 .66854 L .63853 .68137 L p .707 .577 .707 r
F P
0 g
s
.63151 .71437 m .63572 .69682 L .62372 .68386 L p .707 .577 .707 r
F P
0 g
s
.79656 .73505 m .79235 .75261 L .80858 .74636 L p .707 .577 .707 r
F P
0 g
s
.80858 .74636 m .8128 .72881 L .79656 .73505 L p .707 .577 .707 r
F P
0 g
s
.63846 .55669 m .631 .61093 L .63376 .6214 L p .707 .577 .707 r
F P
0 g
s
.62372 .68386 m .61951 .70141 L .63151 .71437 L p .707 .577 .707 r
F P
0 g
s
.6265 .66854 m .63471 .63336 L .63217 .62164 L p .707 .577 .707 r
F P
0 g
s
.82403 .67724 m .81583 .71242 L .82303 .70296 L p .707 .577 .707 r
F P
0 g
s
.82303 .70296 m .83124 .66778 L .82403 .67724 L p .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .3784 .60896 L p .40363 .66239 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .37064 .58239 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38376 .6142 L .40363 .66239 L .707 .577 .707 r
F
.38946 .57275 m .38376 .6142 L p .41357 .63001 L F P
0 g
s
.39841 .62856 m .41357 .63001 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.38376 .6142 m .38946 .57275 L .36537 .56798 L p .707 .577 .707 r
F P
0 g
s
.37064 .58239 m .3784 .60896 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.38296 .62455 m .392 .65549 L p .37351 .61032 L .707 .577 .707 r
F P
0 g
s
.392 .65549 m .42631 .77293 L p .38722 .65254 L .707 .577 .707 r
F P
0 g
s
.37351 .61032 m .392 .65549 L .38722 .65254 L .707 .577 .707 r
F
.41357 .63001 m .42104 .57577 L .38946 .57275 L p F P
0 g
s
.42104 .57577 m .41357 .63001 L .43732 .62971 L p .707 .577 .707 r
F P
0 g
s
.44284 .64059 m .43127 .63848 L .43992 .62593 L .707 .577 .707 r
F
.46644 .75883 m .43455 .6497 L p .44284 .64059 L F P
0 g
s
.43455 .6497 m .43127 .63848 L p .44284 .64059 L .707 .577 .707 r
F P
0 g
s
.46644 .75883 m .42631 .77293 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .43455 .6497 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43455 .6497 m .46644 .75883 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .44109 .66576 L .42093 .66466 L p .707 .577 .707 r
F P
0 g
s
.42093 .66466 m .41227 .66419 L p .41573 .67038 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .42093 .66466 L .41573 .67038 L .707 .577 .707 r
F
.44076 .6247 m .42104 .57577 L .43732 .62971 L F
.50968 .74598 m .46644 .75883 L p .43992 .62593 L F P
0 g
s
.45022 .5754 m .42104 .57577 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .45022 .5754 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .46427 .59057 L p .4441 .61986 L .707 .577 .707 r
F P
0 g
s
.46427 .59057 m .50968 .74598 L p .44106 .6279 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4441 .61986 L .44106 .6279 L .707 .577 .707 r
F
.4441 .61986 m .46427 .59057 L .44106 .6279 L F
.36519 .2515 m .40731 .24115 L p .46782 .53955 L F P
0 g
s
.50968 .74598 m .4603 .57697 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.46095 .57374 m .45022 .5754 L p .4603 .57697 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .36519 .2515 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.45516 .59057 m .4603 .57697 L .45022 .5754 L .707 .577 .707 r
F
.46155 .57364 m .46095 .57374 L p .4603 .57697 L F P
0 g
s
.46667 .62592 m .47414 .57169 L .46155 .57364 L p .707 .577 .707 r
F P
0 g
s
.46667 .62592 m .46155 .57364 L .45516 .59057 L .707 .577 .707 r
F
.44275 .62964 m .46667 .62592 L p .45516 .59057 L F P
0 g
s
.45022 .5754 m .4441 .61986 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .44275 .62964 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.36519 .2515 m .4603 .57697 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4603 .57697 L .4441 .61986 L .707 .577 .707 r
F
.44275 .62964 m .4441 .61986 L p .44076 .6247 L F P
0 g
s
.43732 .62971 m .44275 .62964 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .36519 .2515 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43127 .63848 m .32195 .26435 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .43288 .70094 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41227 .66419 m .41148 .66755 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .40406 .69938 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .39322 .78689 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .41148 .66755 L p .38114 .65874 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .41227 .66419 L .40886 .6636 L p .707 .577 .707 r
F P
0 g
s
.40886 .6636 m .38114 .65874 L p .41148 .66755 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38296 .62455 L p .36684 .58978 L .707 .577 .707 r
F P
0 g
s
.36684 .58978 m .38296 .62455 L .37351 .61032 L .707 .577 .707 r
F
.31517 .43063 m .3784 .60896 L .36684 .58978 L F
.28182 .27845 m .32195 .26435 L p .39625 .62645 L F P
0 g
s
.40363 .66239 m .39041 .62072 L .39625 .62645 L .707 .577 .707 r
F
.39041 .62072 m .28182 .27845 L .39625 .62645 L F
.38376 .6142 m .36537 .56798 L .37064 .58239 L F
.37064 .58239 m .28182 .27845 L p .40363 .66239 L F P
0 g
s
.38376 .6142 m .38335 .61717 L p .39841 .62856 L .707 .577 .707 r
F P
0 g
s
.38335 .61717 m .382 .62699 L .38971 .62772 L p .707 .577 .707 r
F P
0 g
s
.38971 .62772 m .39841 .62856 L p .38335 .61717 L .707 .577 .707 r
F P
0 g
s
.36537 .56798 m .36463 .56784 L p .37064 .58239 L .707 .577 .707 r
F P
0 g
s
.28182 .27845 m .37064 .58239 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.382 .62699 m .38376 .6142 L p .35858 .56664 L .707 .577 .707 r
F P
0 g
s
.36463 .56784 m .35858 .56664 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.8406 .58623 m .83314 .64046 L .83037 .62999 L p .707 .577 .707 r
F P
0 g
s
.83037 .62999 m .83784 .57575 L .8406 .58623 L p .707 .577 .707 r
F P
0 g
s
.40731 .24115 m .5518 .73564 L .50968 .74598 L p .707 .577 .707 r
F P
0 g
s
.631 .61093 m .63846 .55669 L .64559 .54766 L p .707 .577 .707 r
F P
0 g
s
.63217 .62164 m .62396 .65682 L .6265 .66854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.61951 .70141 m .62372 .68386 L .62121 .67206 L p .707 .577 .707 r
F P
0 g
s
.8128 .72881 m .80858 .74636 L .8158 .73687 L p .707 .577 .707 r
F P
0 g
s
.8158 .73687 m .82001 .71932 L .8128 .72881 L p .707 .577 .707 r
F P
0 g
s
.62121 .67206 m .61699 .68961 L .61951 .70141 L p .707 .577 .707 r
F P
0 g
s
.64559 .54766 m .63813 .6019 L .631 .61093 L p .707 .577 .707 r
F P
0 g
s
.62396 .65682 m .63217 .62164 L .63938 .61218 L p .707 .577 .707 r
F P
0 g
s
.83124 .66778 m .82303 .70296 L .8205 .69125 L p .707 .577 .707 r
F P
0 g
s
.8205 .69125 m .82871 .65606 L .83124 .66778 L p .707 .577 .707 r
F P
0 g
s
.83784 .57575 m .83037 .62999 L .81798 .61909 L p .707 .577 .707 r
F P
0 g
s
.81798 .61909 m .82545 .56485 L .83784 .57575 L p .707 .577 .707 r
F P
0 g
s
.63813 .6019 m .64559 .54766 L .66192 .54096 L p .707 .577 .707 r
F P
0 g
s
.63938 .61218 m .63117 .64737 L .62396 .65682 L p .707 .577 .707 r
F P
0 g
s
.61699 .68961 m .62121 .67206 L .62842 .66257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35111 .62088 m .35858 .56664 L .3314 .55804 L p .707 .577 .707 r
F P
0 g
s
.35858 .56664 m .35111 .62088 L .382 .62699 L p .707 .577 .707 r
F P
0 g
s
.82001 .71932 m .8158 .73687 L .81328 .72507 L p .707 .577 .707 r
F P
0 g
s
.81328 .72507 m .8175 .70752 L .82001 .71932 L p .707 .577 .707 r
F P
0 g
s
.62842 .66257 m .62421 .68012 L .61699 .68961 L p .707 .577 .707 r
F P
0 g
s
.66192 .54096 m .65445 .5952 L .63813 .6019 L p .707 .577 .707 r
F P
0 g
s
.63117 .64737 m .63938 .61218 L .65562 .60591 L p .707 .577 .707 r
F P
0 g
s
.82871 .65606 m .8205 .69125 L .80847 .67842 L p .707 .577 .707 r
F P
0 g
s
.80847 .67842 m .81667 .64324 L .82871 .65606 L p .707 .577 .707 r
F P
0 g
s
.82545 .56485 m .81798 .61909 L .79719 .60884 L p .707 .577 .707 r
F P
0 g
s
.79719 .60884 m .80465 .5546 L .82545 .56485 L p .707 .577 .707 r
F P
0 g
s
.32394 .61228 m .3314 .55804 L .31061 .54779 L p .707 .577 .707 r
F P
0 g
s
.3314 .55804 m .32394 .61228 L .35111 .62088 L p .707 .577 .707 r
F P
0 g
s
.65445 .5952 m .66192 .54096 L .68584 .53724 L p .707 .577 .707 r
F P
0 g
s
.37293 .69392 m .38114 .65874 L .35075 .64994 L p .707 .577 .707 r
F P
0 g
s
.38114 .65874 m .37293 .69392 L .40406 .69938 L p .707 .577 .707 r
F P
0 g
s
.65562 .60591 m .64742 .64109 L .63117 .64737 L p .707 .577 .707 r
F P
0 g
s
.34254 .68512 m .35075 .64994 L .32408 .63864 L p .707 .577 .707 r
F P
0 g
s
.35075 .64994 m .34254 .68512 L .37293 .69392 L p .707 .577 .707 r
F P
0 g
s
.62421 .68012 m .62842 .66257 L .64466 .65633 L p .707 .577 .707 r
F P
0 g
s
.8175 .70752 m .81328 .72507 L .80128 .71211 L p .707 .577 .707 r
F P
0 g
s
.80128 .71211 m .8055 .69456 L .8175 .70752 L p .707 .577 .707 r
F P
0 g
s
.47414 .57169 m .46667 .62592 L .483 .61922 L p .707 .577 .707 r
F P
0 g
s
.483 .61922 m .49046 .56498 L .47414 .57169 L p .707 .577 .707 r
F P
0 g
s
.31061 .54779 m .30314 .60203 L .32394 .61228 L p .707 .577 .707 r
F P
0 g
s
.80465 .5546 m .79719 .60884 L .77001 .60024 L p .707 .577 .707 r
F P
0 g
s
.77001 .60024 m .77748 .546 L .80465 .5546 L p .707 .577 .707 r
F P
0 g
s
.68584 .53724 m .67837 .59148 L .65445 .5952 L p .707 .577 .707 r
F P
0 g
s
.64466 .65633 m .64045 .67388 L .62421 .68012 L p .707 .577 .707 r
F P
0 g
s
.30314 .60203 m .31061 .54779 L .29822 .53689 L p .707 .577 .707 r
F P
0 g
s
.64742 .64109 m .65562 .60591 L .67932 .60343 L p .707 .577 .707 r
F P
0 g
s
.67837 .59148 m .68584 .53724 L .71502 .53687 L p .707 .577 .707 r
F P
0 g
s
.81667 .64324 m .80847 .67842 L .78812 .66573 L p .707 .577 .707 r
F P
0 g
s
.78812 .66573 m .79633 .63055 L .81667 .64324 L p .707 .577 .707 r
F P
0 g
s
.32408 .63864 m .31587 .67382 L .34254 .68512 L p .707 .577 .707 r
F P
0 g
s
.31587 .67382 m .32408 .63864 L .30373 .62596 L p .707 .577 .707 r
F P
0 g
s
.44109 .66576 m .43288 .70094 L .45657 .69847 L p .707 .577 .707 r
F P
0 g
s
.45657 .69847 m .46478 .66328 L .44109 .66576 L p .707 .577 .707 r
F P
0 g
s
.36578 .74337 m .37 .72582 L .33965 .71683 L p .707 .577 .707 r
F P
0 g
s
.37 .72582 m .36578 .74337 L .39687 .74899 L p .707 .577 .707 r
F P
0 g
s
.39687 .74899 m .40109 .73144 L .37 .72582 L p .707 .577 .707 r
F P
0 g
s
.77748 .546 m .77001 .60024 L .73913 .59413 L p .707 .577 .707 r
F P
0 g
s
.73913 .59413 m .74659 .53989 L .77748 .546 L p .707 .577 .707 r
F P
0 g
s
.33544 .73438 m .33965 .71683 L .31302 .70535 L p .707 .577 .707 r
F P
0 g
s
.33965 .71683 m .33544 .73438 L .36578 .74337 L p .707 .577 .707 r
F P
0 g
s
.40109 .73144 m .39687 .74899 L .42566 .75068 L p .707 .577 .707 r
F P
0 g
s
.42566 .75068 m .42988 .73313 L .40109 .73144 L p .707 .577 .707 r
F P
0 g
s
.67932 .60343 m .67111 .63862 L .64742 .64109 L p .707 .577 .707 r
F P
0 g
s
.70755 .59111 m .71502 .53687 L .74659 .53989 L p .707 .577 .707 r
F P
0 g
s
.71502 .53687 m .70755 .59111 L .67837 .59148 L p .707 .577 .707 r
F P
0 g
s
.30373 .62596 m .29552 .66114 L .31587 .67382 L p .707 .577 .707 r
F P
0 g
s
.74659 .53989 m .73913 .59413 L .70755 .59111 L p .707 .577 .707 r
F P
0 g
s
.29822 .53689 m .29075 .59113 L .30314 .60203 L p .707 .577 .707 r
F P
0 g
s
.64045 .67388 m .64466 .65633 L .66833 .65393 L p .707 .577 .707 r
F P
0 g
s
.31302 .70535 m .30881 .7229 L .33544 .73438 L p .707 .577 .707 r
F P
0 g
s
.8055 .69456 m .80128 .71211 L .78097 .69927 L p .707 .577 .707 r
F P
0 g
s
.78097 .69927 m .78519 .68171 L .8055 .69456 L p .707 .577 .707 r
F P
0 g
s
.67111 .63862 m .67932 .60343 L .70814 .605 L p .707 .577 .707 r
F P
0 g
s
.79633 .63055 m .78812 .66573 L .76145 .65444 L p .707 .577 .707 r
F P
0 g
s
.76145 .65444 m .76965 .61925 L .79633 .63055 L p .707 .577 .707 r
F P
0 g
s
.49046 .56498 m .483 .61922 L .49013 .61019 L p .707 .577 .707 r
F P
0 g
s
.49013 .61019 m .49759 .55595 L .49046 .56498 L p .707 .577 .707 r
F P
0 g
s
.29552 .66114 m .30373 .62596 L .2917 .61313 L p .707 .577 .707 r
F P
0 g
s
.46478 .66328 m .45657 .69847 L .47282 .69219 L p .707 .577 .707 r
F P
0 g
s
.47282 .69219 m .48102 .65701 L .46478 .66328 L p .707 .577 .707 r
F P
0 g
s
.66833 .65393 m .66412 .67149 L .64045 .67388 L p .707 .577 .707 r
F P
0 g
s
.30881 .7229 m .31302 .70535 L .29271 .6925 L p .707 .577 .707 r
F P
0 g
s
.42988 .73313 m .42566 .75068 L .44934 .74829 L p .707 .577 .707 r
F P
0 g
s
.44934 .74829 m .45355 .73074 L .42988 .73313 L p .707 .577 .707 r
F P
0 g
s
.29075 .59113 m .29822 .53689 L .29545 .52642 L p .707 .577 .707 r
F P
0 g
s
.29271 .6925 m .2885 .71006 L .30881 .7229 L p .707 .577 .707 r
F P
0 g
s
.70814 .605 m .69993 .64018 L .67111 .63862 L p .707 .577 .707 r
F P
0 g
s
.69993 .64018 m .70814 .605 L .73926 .61045 L p .707 .577 .707 r
F P
0 g
s
.76965 .61925 m .76145 .65444 L .73106 .64563 L p .707 .577 .707 r
F P
0 g
s
.73106 .64563 m .73926 .61045 L .76965 .61925 L p .707 .577 .707 r
F P
0 g
s
.2917 .61313 m .28349 .64831 L .29552 .66114 L p .707 .577 .707 r
F P
0 g
s
.73926 .61045 m .73106 .64563 L .69993 .64018 L p .707 .577 .707 r
F P
0 g
s
.66412 .67149 m .66833 .65393 L .69712 .65563 L p .707 .577 .707 r
F P
0 g
s
.78519 .68171 m .78097 .69927 L .75434 .68779 L p .707 .577 .707 r
F P
0 g
s
.75434 .68779 m .75856 .67023 L .78519 .68171 L p .707 .577 .707 r
F P
0 g
s
.29545 .52642 m .28799 .58066 L .29075 .59113 L p .707 .577 .707 r
F P
0 g
s
.69712 .65563 m .69291 .67318 L .66412 .67149 L p .707 .577 .707 r
F P
0 g
s
.2885 .71006 m .29271 .6925 L .28071 .67955 L p .707 .577 .707 r
F P
0 g
s
.45355 .73074 m .44934 .74829 L .46557 .74205 L p .707 .577 .707 r
F P
0 g
s
.46557 .74205 m .46979 .72449 L .45355 .73074 L p .707 .577 .707 r
F P
0 g
s
.28349 .64831 m .2917 .61313 L .28916 .60141 L p .707 .577 .707 r
F P
0 g
s
.48102 .65701 m .47282 .69219 L .48002 .68273 L p .707 .577 .707 r
F P
0 g
s
.48002 .68273 m .48823 .64755 L .48102 .65701 L p .707 .577 .707 r
F P
0 g
s
.49759 .55595 m .49013 .61019 L .48736 .59972 L p .707 .577 .707 r
F P
0 g
s
.48736 .59972 m .49483 .54548 L .49759 .55595 L p .707 .577 .707 r
F P
0 g
s
.28071 .67955 m .2765 .6971 L .2885 .71006 L p .707 .577 .707 r
F P
0 g
s
.69291 .67318 m .69712 .65563 L .72821 .66125 L p .707 .577 .707 r
F P
0 g
s
.75856 .67023 m .75434 .68779 L .724 .6788 L p .707 .577 .707 r
F P
0 g
s
.724 .6788 m .72821 .66125 L .75856 .67023 L p .707 .577 .707 r
F P
0 g
s
.28799 .58066 m .29545 .52642 L .30258 .51739 L p .707 .577 .707 r
F P
0 g
s
.72821 .66125 m .724 .6788 L .69291 .67318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28916 .60141 m .28095 .6366 L .28349 .64831 L p .707 .577 .707 r
F P
0 g
s
.2765 .6971 m .28071 .67955 L .2782 .66775 L p .707 .577 .707 r
F P
0 g
s
.46979 .72449 m .46557 .74205 L .47279 .73256 L p .707 .577 .707 r
F P
0 g
s
.47279 .73256 m .477 .71501 L .46979 .72449 L p .707 .577 .707 r
F P
0 g
s
.30258 .51739 m .29512 .57162 L .28799 .58066 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28095 .6366 m .28916 .60141 L .29637 .59195 L p .707 .577 .707 r
F P
0 g
s
.2782 .66775 m .27398 .6853 L .2765 .6971 L p .707 .577 .707 r
F P
0 g
s
.48823 .64755 m .48002 .68273 L .47749 .67102 L p .707 .577 .707 r
F P
0 g
s
.47749 .67102 m .4857 .63583 L .48823 .64755 L p .707 .577 .707 r
F P
0 g
s
.49483 .54548 m .48736 .59972 L .47497 .58882 L p .707 .577 .707 r
F P
0 g
s
.47497 .58882 m .48244 .53458 L .49483 .54548 L p .707 .577 .707 r
F P
0 g
s
.29512 .57162 m .30258 .51739 L .31891 .51068 L p .707 .577 .707 r
F P
0 g
s
.29637 .59195 m .28816 .62714 L .28095 .6366 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27398 .6853 m .2782 .66775 L .28541 .65826 L p .707 .577 .707 r
F P
0 g
s
.477 .71501 m .47279 .73256 L .47027 .72076 L p .707 .577 .707 r
F P
0 g
s
.47027 .72076 m .47448 .70321 L .477 .71501 L p .707 .577 .707 r
F P
0 g
s
.31891 .51068 m .31144 .56492 L .29512 .57162 L p .707 .577 .707 r
F P
0 g
s
.48244 .53458 m .47497 .58882 L .45418 .57857 L p .707 .577 .707 r
F P
0 g
s
.45418 .57857 m .46164 .52433 L .48244 .53458 L p .707 .577 .707 r
F P
0 g
s
.28541 .65826 m .2812 .67581 L .27398 .6853 L p .707 .577 .707 r
F P
0 g
s
.28816 .62714 m .29637 .59195 L .31261 .58568 L p .707 .577 .707 r
F P
0 g
s
.4857 .63583 m .47749 .67102 L .46546 .65819 L p .707 .577 .707 r
F P
0 g
s
.46546 .65819 m .47366 .62301 L .4857 .63583 L p .707 .577 .707 r
F P
0 g
s
.31144 .56492 m .31891 .51068 L .34283 .50697 L p .707 .577 .707 r
F P
0 g
s
.31261 .58568 m .30441 .62086 L .28816 .62714 L p .707 .577 .707 r
F P
0 g
s
.46164 .52433 m .45418 .57857 L .427 .56997 L p .707 .577 .707 r
F P
0 g
s
.427 .56997 m .43447 .51573 L .46164 .52433 L p .707 .577 .707 r
F P
0 g
s
.34283 .50697 m .33536 .56121 L .31144 .56492 L p .707 .577 .707 r
F P
0 g
s
.2812 .67581 m .28541 .65826 L .30165 .65201 L p .707 .577 .707 r
F P
0 g
s
.47448 .70321 m .47027 .72076 L .45827 .7078 L p .707 .577 .707 r
F P
0 g
s
.45827 .7078 m .46248 .69025 L .47448 .70321 L p .707 .577 .707 r
F P
0 g
s
.33536 .56121 m .34283 .50697 L .372 .5066 L p .707 .577 .707 r
F P
0 g
s
.30441 .62086 m .31261 .58568 L .33631 .5832 L p .707 .577 .707 r
F P
0 g
s
.47366 .62301 m .46546 .65819 L .44511 .64551 L p .707 .577 .707 r
F P
0 g
s
.44511 .64551 m .45332 .61032 L .47366 .62301 L p .707 .577 .707 r
F P
0 g
s
.30165 .65201 m .29744 .66957 L .2812 .67581 L p .707 .577 .707 r
F P
0 g
s
.43447 .51573 m .427 .56997 L .39612 .56386 L p .707 .577 .707 r
F P
0 g
s
.39612 .56386 m .40358 .50962 L .43447 .51573 L p .707 .577 .707 r
F P
0 g
s
.36454 .56084 m .372 .5066 L .40358 .50962 L p .707 .577 .707 r
F P
0 g
s
.372 .5066 m .36454 .56084 L .33536 .56121 L p .707 .577 .707 r
F P
0 g
s
.33631 .5832 m .3281 .61839 L .30441 .62086 L p .707 .577 .707 r
F P
0 g
s
.40358 .50962 m .39612 .56386 L .36454 .56084 L p .707 .577 .707 r
F P
0 g
s
.3281 .61839 m .33631 .5832 L .36513 .58477 L p .707 .577 .707 r
F P
0 g
s
.45332 .61032 m .44511 .64551 L .41844 .63421 L p .707 .577 .707 r
F P
0 g
s
.41844 .63421 m .42664 .59903 L .45332 .61032 L p .707 .577 .707 r
F P
0 g
s
.29744 .66957 m .30165 .65201 L .32532 .64962 L p .707 .577 .707 r
F P
0 g
s
.46248 .69025 m .45827 .7078 L .43796 .69495 L p .707 .577 .707 r
F P
0 g
s
.43796 .69495 m .44218 .6774 L .46248 .69025 L p .707 .577 .707 r
F P
0 g
s
.32532 .64962 m .32111 .66717 L .29744 .66957 L p .707 .577 .707 r
F P
0 g
s
.36513 .58477 m .35692 .61995 L .3281 .61839 L p .707 .577 .707 r
F P
0 g
s
.35692 .61995 m .36513 .58477 L .39625 .59022 L p .707 .577 .707 r
F P
0 g
s
.42664 .59903 m .41844 .63421 L .38805 .6254 L p .707 .577 .707 r
F P
0 g
s
.38805 .6254 m .39625 .59022 L .42664 .59903 L p .707 .577 .707 r
F P
0 g
s
.39625 .59022 m .38805 .6254 L .35692 .61995 L p .707 .577 .707 r
F P
0 g
s
.32111 .66717 m .32532 .64962 L .35411 .65132 L p .707 .577 .707 r
F P
0 g
s
.44218 .6774 m .43796 .69495 L .41133 .68347 L p .707 .577 .707 r
F P
0 g
s
.41133 .68347 m .41555 .66592 L .44218 .6774 L p .707 .577 .707 r
F P
0 g
s
.35411 .65132 m .3499 .66887 L .32111 .66717 L p .707 .577 .707 r
F P
0 g
s
.3499 .66887 m .35411 .65132 L .3852 .65693 L p .707 .577 .707 r
F P
0 g
s
.41555 .66592 m .41133 .68347 L .38099 .67449 L p .707 .577 .707 r
F P
0 g
s
.38099 .67449 m .3852 .65693 L .41555 .66592 L p .707 .577 .707 r
F P
0 g
s
.3852 .65693 m .38099 .67449 L .3499 .66887 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol008=oo`D009Eoo`00O7oo1`001EYF0`00TWoo001fOol6
000;FUH01000FUIJEUYFTWoo001bOol40009FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001^
Ool400000eYF001JEP0:FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001ZOol40006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`2>Ool006Ioo`@000YJEP03001JEUYF015JEP05001J
EUYFFUH0002@Ool006=oo`<000iJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002@
Ool0061oo`<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002@Ool005eoo`<000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF
FUH0002?Ool005Yoo`<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001J
EUYFFUH0002?Ool005Moo`<001]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002?
Ool005Eoo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH2002>Ool0059oo`<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03Ool005YF
00UJEP03001JEUYF00IJEP05001JEUYFFUH0002>Ool004moo`<000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002>Ool004eoo`800003FUH0
05YF01QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2002=Ool0
04Yoo`<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008008eoo`00B7oo0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008eoo`00AWoo0P00
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00D005YFFUIJEP0008eoo`00A7oo0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00S7oo0012Ool20003FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000S7oo0010Ool20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
S7oo000oOol20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Rgoo000nOol01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Rgoo000mOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0008]oo`00?Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002;Ool003ioo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02002:Ool003ioo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RWoo000nOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Yoo`00?Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH20029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
0029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RGoo000oOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Uoo`00@7oo00@005YFFUH000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF008008Qoo`00@7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH00028Ool0041oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000R7oo0010Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8008Moo`00@Goo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008008Moo`00@Goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP05001JEUYFFUH00027Ool0045oo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00QWoo0012Ool01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00P00QWoo0012Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Ioo`00
@Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00026Ool0049oo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020025Ool004=oo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000QGoo0013Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D0
05YFFUIJEP0008Eoo`00@goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20024
Ool004Aoo`05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020024Ool004Aoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Q7oo0014Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Aoo`00A7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF008008=oo`00AGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0023Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Pgoo0015Ool0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80089oo`00AWoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF0080089oo`00AWoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH00022Ool004Ioo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00PGoo0016Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00PGoo0017
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00085oo`00Agoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00021Ool004Moo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00081o
o`00B7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001oOol004Qoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007moo`00BGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0001oOol004Uoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000Ogoo0019Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8007ioo`00BWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007ioo`00BWoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001nOol004Yoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OGoo001:Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02001mOol004]oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000OGoo001;Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007eo
o`00Bgoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007aoo`00C7oo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001lOol004aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000O7oo001<Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007]oo`00C7oo0P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P00Ngoo001=Ool01@00FUIJEUYF00001UYF00<005YFFUH00eYF5`001eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007]oo`00CGoo00D005YFFUIJEP0000IJEP03
001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000=JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001jOol004eoo`05001JEUYFFUH0
0006FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001jOol004ioo`05001JEUYFFUH00003FUH20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00H005YFFUIJEP00FUH3
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0`0025YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00@005YF
FUIJEP80009JEP04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001>
Ool20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001iOol004moo`07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH01EYF00D005YFFUIJEP0007Uoo`00Cgoo00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P006goo4000CGoo001?Ool01000
FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF00UJEP03001JEUYF00IJEP03001JEUYF
008001Ioo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00D7oo00<005YF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00000;FUH00`00FUIJEP05FUH01@00FUIJEUYF000057oo0P00
00=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00@goo001@Ool01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000]JEP03001JEUYF00EJEP05001JEUYFFUH0
000BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000oOol0051oo`05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YF
FUH01EYF00@005YFFUIJEP80011oo`8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<003]oo`00DGoo0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000YJEP03001JEUYF00IJEP03001JEUYF0080011oo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Qoo`00
DGoo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00EJEP05
001JEUYFFUH0000?Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0055oo`800003FUH005YF009JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]J
EP03001JEUYF00EJEP04001JEUYFFUH2000>Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02000dOol0055oo`<000=J
EPD0009JEP04001JEUYFFUH20004FUH01000FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00D005YFFUH005YF008000YJEP03001JEUYF00IJEP03001JEUYF008000ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP80039oo`00DGoo00@005YF001JEP<000IJEP03001JEUYF00=JEPD000EJEPT0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00003Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Goo001AOol01000FUH000000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00@005YFFUH000AJEPH00004FUH005YFFUH40006FUH00`00FUIJEP04FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P0037oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000002moo`00DGoo0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00@005YFFUH000IJEP<000=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF
0080009JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2000<Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF0`001EYF00@005YFFUIJEP80009JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000aoo`03001JEP0000AJEP03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DGoo00<005YFFUH00eYF00<005YFFUH00UYF1`0000=JEP00FUH0
0eYF00<005YFFUH02EYF00<005YFFUH02UYF0P000eYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0000<Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool0055oo`03001JEUYF00=JEPD000=JEP04001JEUYFFUH9000:FUH00`00
FUIJEP0;FUH200000eYF001JEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P002goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;7oo001B
Ool01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<005YFFUH035YF
0`000UYF00<005YF00000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P002goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00@005YF0000009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00eJEP08001JEUYF001J
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0000;Ool20004FUH01000
FUIJEUYF5P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00Dgoo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`003EYF00@0
05YFFUIJEP800003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000:
Ool00eYF001JEP02FUH500000eYF001JEP04FUH50007Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0`002UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P002Goo00@005YF001JEP8000IJEP03001JEUYF00EJEP03001J
EUYF00@0009oo`D000=oo`@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000008FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo00H005YF000005YF0005FUH70002FUH0
0`00FUIJEP04FUH70007Ool20004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000aOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH01`00FUIJEUYF
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00009Ool30002FUH60003
FUH01000FUIJEUYF2@000UYF4@0000=JEP00FUH015YF00<005YFFUH00UYF00<007ooOol0;Goo000_
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH20008Ool01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00
1EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF00<007ooOol0;Goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001J
EP03FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020008Ool01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEUYF
FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH2
0007FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10001eYF00@005YFFUIJEP800003
FUH005YF009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF00000UYF1P001UYF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00AJEP8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000P000eYF00<005YF
FUH01EYF00@005YFFUIJEPX000MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000Moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUH00002
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEPP000EJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0007Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`001UYF00<005YFFUH00`00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH30002FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH800000eYF001JEP07FUH00`00FUIJEP04FUH01000FUH000002EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00@005YFFUIJEP@000=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH2
000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00<000IJEP03001JEUYF00QJEPH0009JEP<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH300000eYF0000000200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0P00<7oo000/Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP08FUH50005FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030004
FUH00`00FUH00003FUH01000FUIJEUYF1P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`000UYF00<005YF0000<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH025YF100025YF0`0000=JEP00FUH01EYF00@005YFFUIJEP8000UJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH20003FUH80003FUH90004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000[Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH200000eYF001JEP09FUH01000FUIJEP002EYF00@0
05YF000000IJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001EYF00<005YF00000P000eYF0`0000=oo`00000015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01EYF00<005YFFUH015YF1000<Goo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF1`000UYF0`00
5UYF00<005YFFUH00`0015YF00@005YFFUIJEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF008000=JEP04001JEP000002FUH30003FUH300001Woo00000000FUH000QJEP03001JEUYF
00<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000bOol002]oo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00@005YFFUIJEPT000IJ
EP03001JEUYF00UJEP04001JEUYF0002FUH01000FUIJEP000eYF00<005YF00002UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP<000=JEP03001JEUYF00P0009oo`H000AJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYF000bOol002]oo`8000=J
EPD0009JEP04001JEUYFFUH20008Ool70006FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7
000<FUH00`00FUH00003FUH30003FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000UYF00<005YF00000UYF1@000UYF00<005YFFUH00UYF1P000Woo2@0015YF0`00
1eYF00<005YFFUH00eYF00D005YFFUIJEP00035oo`00:goo0P0000AJEP00000000IJEP03001JEUYF
00=JEP@000Ioo`T00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000UJEP03001JEUYF00EJEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YF00000`001goo2@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;goo000[
Ool00eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool50004Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40006FUH0
0`00FUIJEP02FUH50002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000;Ool300000eYF001J
EP04FUH00`00FUIJEP02FUH2000`Ool002Yoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00AJEP`000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH<0003
FUH01P00FUH00000FUH000aJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool20005
FUH01`00FUIJEUYF001JEP00031oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF1`001EYF2@0015YF00<005YFFUH01eYF00@005YF0000
00=JEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH0000000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40008Ool20003FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<005YFFUH00eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000001EYF0`00
1eYF00<005YFFUH00eYF1P001eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00H005YFFUIJEP00
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH50002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01eYF00@005YF000000Qoo`<000AJEP03001JEWoo031oo`00:Woo00<0
05YFFUH00eYF4`0015YF00<005YFFUH015YF0`001eYF00<005YFFUH00P0015YF00<005YFFUH01eYF
00<005YFFUH00P001EYF00<005YFFUH015YF0P001EYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH3000015YF000000001UYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH01eYF00@005YFFUIJEP<000Moo`03001JEUYF009JEP80035o
o`00:goo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP<000MJEP06001J
EUYFFUH005YF0`0000=JEP00FUH025YF00@005YFFUIJEP@00003FUH005YF00MJEP<0009JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH50000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20006Ool0
1000FUIJEUYF0P00<Goo000[Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF1@0000=JEP00FUH00P001UYF00D005YFFUIJEP0000=JEP@000QJEP03001JEUYF00P0
00MJEP06001JEUYF001JEP000eYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00@0009JEP03001JEUYF00IJEP800003Ool0000000@00003FUH00000039oo`00;7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00
FUH00P0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP<000AJEP04001JEUYFFUH60002FUH2
0004FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP050004FUH01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH015YF1000
1UYF00<005YFFUH00P000UYF00<005YFFUH00`00<Woo000/Ool01@00FUIJEUYF00001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH00004FUH01@00FUIJEUYF
00001EYF0`0000=JEP00FUH00UYF1@001EYF0`0000=JEP00FUH01EYF00@005YF000000AJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF001JEP040004FUH30007FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH00UYF00<005YF00000eYF0P00
<Woo000[Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH300000eYF001JEP03FUH01@00FUIJEUYF00001UYF00<005YF0000100000=J
EP0000000P0025YF0P001UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P000UYF00@007oo000000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF00EJEP04001JEUYFFUH3000bOol002]oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00
008000EJEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH90004FUH01000FUH0000015YF00<005YF
00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEPH00003
FUH005YF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP80009J
EP8003=oo`00:Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH000AJEP<000=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH01000FUIJ
EUYF2@000UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP04001JEUYF0003FUH30003FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30004FUH01000FUH005YF0P00<goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH400000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P0000=JEP00FUH00P000eYF
0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH2000dOol0
02Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000EJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP001EYF0P000eYF0P0000AJEP00FUIJEP<000AJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYFFUH30004FUH00`00Oomoo`0bOol002Uoo`03001JEP00009JEQ<000IJEP03
001JEUYF00IJEP04001JEUYF0004FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<000=JEP8000=JEPD00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo039oo`00:Goo0P0000AJEP000000
011oo`H0009JEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH40006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00P0000AJEP00FUH0009JEP80
00=oo`H00003FUH00000008000MJEP03001JEUYF00AJEP8000=JEP8003=oo`00:Goo0`000eYF00<0
07ooOol04Goo1P001eYF00<005YFFUH00eYF0P0025YF00<005YF00000P0015YF00<005YFFUH05EYF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF10000eYF00<005YFFUH00eYF0P000UYF0`002Woo200015YF00@005YFFUIJEPH00004FUH0
05YF000cOol002Uoo`8000AJEP<001Ioo`D0009JEP03001JEUYF00EJEP8000MJEP03001JEUYF009J
EP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF0P0000=JEP00FUH01UYF1@00
2Woo1@000goo20001Woo0P0000=JEP00Ool0<Woo000XOol30004FUH00`00FUIJEP02000COol50000
0goo000000020007FUH30004FUH00`00FUIJEP06FUH60007FUH00`00FUIJEP09FUH00`00FUH00003
0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP02FUH2
0008FUH00`00FUH000030008Ool5000BOol2000dOol002Qoo`03001JEP0000=JEP03001JEUYF00=J
EP<0011oo`D000Eoo`8000AJEP04001JEUYFFUH300000eYF001JEP08FUH00`00FUIJEP02FUH80008
FUH50002FUH2000DFUH00`00FUIJEP07FUH70004FUH50005FUH20005FUH00`00FUIJEP04FUH50004
Ool3000BOol3000dOol002Qoo`03001JEUYF00=JEP03001JEUYF00AJEP04001JEP00000>Ool50007
Ool300000eYF001JEP05FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00<005YFFUH0
0UYF0P0025YF00<005YFFUH02UYF00<005YFFUH01P0015YF00<005YFFUH015YF00D005YFFUIJEP00
00EJEP04001JEP000003FUH00`00FUIJEP06FUH00`00FUIJEP04000COol200000eYF001oo`0dOol0
02Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP8000eoo`<000]oo`8000IJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0009FUH00`00FUIJEP09FUH50009FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP<0
00UJEP03001JEUYF00AJEQ<0009JEP8003Eoo`00:Goo00<005YFFUH00UYF00@005YFFUIJEPL0009J
EP<001Yoo`8000AJEP03001JEP00009JEP<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP@000AJEP03001JEUYF00QJEP03001JEUYF
00AJEP8000MJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0000fOol002Yoo`04001JEUYFFUH40003FUH01000FUIJEUYF2@0067oo0P00
00EJEP00FUIJEP0000=JEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF00<000iJEP@000UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008003Ioo`00:goo10001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0057oo0P000eYF00D0
05YFFUIJEP0000IJEPP000AJEP04001JEUYFFUH600000eYF001JEP0:FUH5000<FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0003Moo`00:Woo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P004Woo00D005YFFUIJEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEPP000MJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF
00MJEP04001JEUYFFUH70004FUH00`00FUIJEP04FUH01@00FUIJEUYF00001goo10000UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000003Qoo`00:Goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0037oo1@0000=JEP0000000eYF00<005YFFUH0
15YF00<005YFFUH065YF100025YF00<005YFFUH02eYF00<005YFFUH01eYF0`001goo0`0000=JEP00
FUH015YF00<005YFFUH00UYF00<007ooOol02Goo4`00>Woo000YOol01@00FUIJEUYF00000eYF1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF30000eYF00H005YF000005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4000:
Ool20005FUH01`00FUIJEUYF001JEP0005Moo`00:7oo0P000UYF1`001EYF2@0015YF00<005YFFUH0
1eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH045YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P0015YF
0`002Goo00<005YFFUH00UYF00L005YFFUIJEP00FUH0001GOol002Qoo`04001JEP000006Ool20007
FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP02FUH200000eYF001JEP04FUH01`00FUIJEUYF001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00iJEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF009JEP8000QJEP<000Qoo`80009JEP07001JEUYFFUH005YF0000Egoo000WOol3000:
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH20005FUH01000FUIJ
EUYF0`000eYF00<005YFFUH04UYF0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF0000
0P002EYF00<005YFFUH00P0027oo0P0015YF0P00F7oo000WOol2000=Ool300000eYF001JEP08FUH0
1000FUIJEUYF100000=JEP00FUH01eYF0`000UYF00<005YFFUH00UYF0P0000=oo`00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01eYF100035YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<0
05YFFUH00eYF0P001goo00<005YFFUH00UYF0P00F7oo000VOol4000?Ool30008FUH00`00FUIJEP08
0007FUH01P00FUIJEP00FUH000=JEP05001JEP00Ool00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04
0002FUH00`00FUIJEP05FUH20002Ool50002FUH00`00FUH0001HOol002Ioo`05001JEP00FUH0000A
Ool30004FUH01000FUIJEUYF1P000UYF0P0015YF00<005YFFUH00UYF0P000eYF0P000Woo00D005YF
FUIJEP0000IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00=JEP<000QJEP03001JEUYF00AJEP<000QJEP<000=JEP03001JEP0000<005Uoo`009Woo00<005YF
FUH00UYF00<007ooOol04Goo0`0000=JEP00FUH00UYF1P0015YF0`0000=JEP00FUH01EYF00@005YF
000000Aoo`eJEP8000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP<000EJEP04001JEUYFFUH200000eYF001JEP02FUH2001IOol002Moo`03
001JEUYF009JEP03001oogoo01=oo`<000=JEP<00003FUH005YF00IJEP8000IJEP8000Ioo`05001J
EUYFFUH00006FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`009goo
00<005YFFUH00UYF0`005Woo10000UYF00<005YFFUH01UYF00@005YF000000AJEP8000Ioo`05001J
EUYFFUH00004FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP0AFUH400000goo00000004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH20002FUH3001IOol002Qoo`05001J
EUYFFUH00002FUH2000HOol@0002FUH01000FUIJEP001Woo0eYF00D005YFFUIJEP0000AJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00@000Moo`800003FUH005YF00QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00FUH2001JOol002Uoo`03001JEP0000EJEP03
001oogoo02Eoo`<000=JEP03001oogoo00=oo`EJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EPD0009JEP8000Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP<000=JEP04001JEUYFFUH3
001JOol002Yoo`8000EJEP<002Moo`05001JEUYFFUH00005Ool01000FUIJEUYF0P001eYF00<005YF
FUH045YF100000Aoo`00FUH000EJEP8000Uoo`<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00800003FUH005YF00=JEP03001oogoo05Uoo`00:goo00<005YFFUH00eYF00<005YFFUH0
0P009Woo00<005YFFUH00P0017oo00H005YFFUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP04
0006Ool20006FUH3000:Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00Oomoo`1IOol002aoo`80009JEP03001JEUYF00=JEP8002Aoo`05001JEP00FUH00005Ool0
0eYF001JEP09FUH00`00FUIJEP07FUH5000;Ool00`00FUIJEP04FUH00`00FUIJEP02000;Ool60004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2001JOol002ioo`<000MJEP@0025oo`800003
FUH007oo00Aoo`03001JEUYF00YJEP03001JEUYF00H0015oo`8000=JEP03001JEUYF00=JEP8000mo
o`P000AJEP04001JEUYFFUH6000015YF001JEP00FWoo000`Ool20007FUH00`00FUIJEP04000NOol0
0`00FUH00006Ool20002FUH00`00FUIJEP02FUH6000IOol200000eYF001JEP06FUH3000<Ool50003
Ool80006Ool200000eYF001oo`1IOol0039oo`8000AJEP03001JEUYF00EJEPD001Moo`@000Uoo`L0
025oo`8000QJEP03001JEP0000<000Qoo`D0019oo`8005]oo`00=7oo0`0000=JEP00FUH025YF00<0
05YFFUH010003Woo1@000UYF0P00<goo0P001EYF00<005YFFUH015YF1@000goo1@004Goo0`00Fgoo
000gOol30007FUH00`00FUIJEP05FUH>0002FUH00`00FUIJEP02FUH2000eOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP07000@Ool200000eYF001oo`1KOol003Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000hOol30009FUH00`00FUIJEP04FUHC0002
FUH2001LOol003aoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
009JEP8003Yoo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH0001MOol003moo`@000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<003ioo`@0
009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005eoo`00@goo
10000UYF00<005YFFUH01UYF00@005YFFUIJEPD004Eoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol004Moo`l004moo`@0009JEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001OOol00:Uooa<0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5878 .7493 m .59527 .69506 L .56438 .68895 L p .707 .577 .707 r
F P
0 g
s
.59527 .69506 m .5878 .7493 L .61938 .75232 L p .707 .577 .707 r
F P
0 g
s
.61938 .75232 m .62685 .69808 L .59527 .69506 L p .707 .577 .707 r
F P
0 g
s
.62685 .69808 m .61938 .75232 L .64856 .75195 L p .707 .577 .707 r
F P
0 g
s
.64856 .75195 m .65602 .69771 L .62685 .69808 L p .707 .577 .707 r
F P
0 g
s
.55692 .74319 m .56438 .68895 L .53721 .68035 L p .707 .577 .707 r
F P
0 g
s
.56438 .68895 m .55692 .74319 L .5878 .7493 L p .707 .577 .707 r
F P
0 g
s
.65602 .69771 m .64856 .75195 L .67248 .74824 L p .707 .577 .707 r
F P
0 g
s
.67248 .74824 m .67994 .694 L .65602 .69771 L p .707 .577 .707 r
F P
0 g
s
.52974 .73459 m .53721 .68035 L .51641 .6701 L p .707 .577 .707 r
F P
0 g
s
.53721 .68035 m .52974 .73459 L .55692 .74319 L p .707 .577 .707 r
F P
0 g
s
.57874 .80619 m .58694 .77101 L .55656 .7622 L p .707 .577 .707 r
F P
0 g
s
.58694 .77101 m .57874 .80619 L .60986 .81164 L p .707 .577 .707 r
F P
0 g
s
.60986 .81164 m .61807 .77646 L .58694 .77101 L p .707 .577 .707 r
F P
0 g
s
.54835 .79739 m .55656 .7622 L .52988 .75091 L p .707 .577 .707 r
F P
0 g
s
.55656 .7622 m .54835 .79739 L .57874 .80619 L p .707 .577 .707 r
F P
0 g
s
.61807 .77646 m .60986 .81164 L .63869 .81321 L p .707 .577 .707 r
F P
0 g
s
.63869 .81321 m .64689 .77803 L .61807 .77646 L p .707 .577 .707 r
F P
0 g
s
.67994 .694 m .67248 .74824 L .6888 .74153 L p .707 .577 .707 r
F P
0 g
s
.6888 .74153 m .69627 .6873 L .67994 .694 L p .707 .577 .707 r
F P
0 g
s
.51641 .6701 m .50895 .72434 L .52974 .73459 L p .707 .577 .707 r
F P
0 g
s
.50895 .72434 m .51641 .6701 L .50402 .6592 L p .707 .577 .707 r
F P
0 g
s
.52988 .75091 m .52168 .78609 L .54835 .79739 L p .707 .577 .707 r
F P
0 g
s
.52168 .78609 m .52988 .75091 L .50953 .73822 L p .707 .577 .707 r
F P
0 g
s
.64689 .77803 m .63869 .81321 L .66238 .81073 L p .707 .577 .707 r
F P
0 g
s
.66238 .81073 m .67058 .77555 L .64689 .77803 L p .707 .577 .707 r
F P
0 g
s
.57159 .83972 m .5758 .82217 L .54546 .81318 L p .707 .577 .707 r
F P
0 g
s
.5758 .82217 m .57159 .83972 L .60268 .84534 L p .707 .577 .707 r
F P
0 g
s
.60268 .84534 m .60689 .82779 L .5758 .82217 L p .707 .577 .707 r
F P
0 g
s
.54125 .83073 m .54546 .81318 L .51883 .8017 L p .707 .577 .707 r
F P
0 g
s
.54546 .81318 m .54125 .83073 L .57159 .83972 L p .707 .577 .707 r
F P
0 g
s
.60689 .82779 m .60268 .84534 L .63147 .84703 L p .707 .577 .707 r
F P
0 g
s
.63147 .84703 m .63568 .82948 L .60689 .82779 L p .707 .577 .707 r
F P
0 g
s
.51883 .8017 m .51461 .81925 L .54125 .83073 L p .707 .577 .707 r
F P
0 g
s
.50953 .73822 m .50133 .77341 L .52168 .78609 L p .707 .577 .707 r
F P
0 g
s
.50402 .6592 m .49656 .71344 L .50895 .72434 L p .707 .577 .707 r
F P
0 g
s
.51461 .81925 m .51883 .8017 L .49852 .78886 L p .707 .577 .707 r
F P
0 g
s
.63568 .82948 m .63147 .84703 L .65514 .84464 L p .707 .577 .707 r
F P
0 g
s
.65514 .84464 m .65935 .82709 L .63568 .82948 L p .707 .577 .707 r
F P
0 g
s
.50133 .77341 m .50953 .73822 L .4975 .7254 L p .707 .577 .707 r
F P
0 g
s
.67058 .77555 m .66238 .81073 L .67862 .80446 L p .707 .577 .707 r
F P
0 g
s
.67862 .80446 m .68683 .76928 L .67058 .77555 L p .707 .577 .707 r
F P
0 g
s
.69627 .6873 m .6888 .74153 L .69593 .7325 L p .707 .577 .707 r
F P
0 g
s
.69593 .7325 m .7034 .67826 L .69627 .6873 L p .707 .577 .707 r
F P
0 g
s
.49852 .78886 m .49431 .80641 L .51461 .81925 L p .707 .577 .707 r
F P
0 g
s
.49656 .71344 m .50402 .6592 L .50126 .64873 L p .707 .577 .707 r
F P
0 g
s
.4975 .7254 m .4893 .76058 L .50133 .77341 L p .707 .577 .707 r
F P
0 g
s
.49431 .80641 m .49852 .78886 L .48652 .7759 L p .707 .577 .707 r
F P
0 g
s
.65935 .82709 m .65514 .84464 L .67138 .8384 L p .707 .577 .707 r
F P
0 g
s
.67138 .8384 m .67559 .82085 L .65935 .82709 L p .707 .577 .707 r
F P
0 g
s
.50126 .64873 m .49379 .70297 L .49656 .71344 L p .707 .577 .707 r
F P
0 g
s
.48652 .7759 m .48231 .79345 L .49431 .80641 L p .707 .577 .707 r
F P
0 g
s
.4893 .76058 m .4975 .7254 L .49497 .71368 L p .707 .577 .707 r
F P
0 g
s
.68683 .76928 m .67862 .80446 L .68583 .795 L p .707 .577 .707 r
F P
0 g
s
.68583 .795 m .69404 .75982 L .68683 .76928 L p .707 .577 .707 r
F P
0 g
s
.7034 .67826 m .69593 .7325 L .69317 .72203 L p .707 .577 .707 r
F P
0 g
s
.69317 .72203 m .70063 .66779 L .7034 .67826 L p .707 .577 .707 r
F P
0 g
s
.49379 .70297 m .50126 .64873 L .50839 .6397 L p .707 .577 .707 r
F P
0 g
s
.49497 .71368 m .48676 .74886 L .4893 .76058 L p .707 .577 .707 r
F P
0 g
s
.48231 .79345 m .48652 .7759 L .484 .7641 L p .707 .577 .707 r
F P
0 g
s
.67559 .82085 m .67138 .8384 L .67859 .82891 L p .707 .577 .707 r
F P
0 g
s
.67859 .82891 m .68281 .81136 L .67559 .82085 L p .707 .577 .707 r
F P
0 g
s
.484 .7641 m .47979 .78165 L .48231 .79345 L p .707 .577 .707 r
F P
0 g
s
.50839 .6397 m .50092 .69394 L .49379 .70297 L p .707 .577 .707 r
F P
0 g
s
.48676 .74886 m .49497 .71368 L .50217 .70422 L p .707 .577 .707 r
F P
0 g
s
.69404 .75982 m .68583 .795 L .68329 .78328 L p .707 .577 .707 r
F P
0 g
s
.68329 .78328 m .6915 .7481 L .69404 .75982 L p .707 .577 .707 r
F P
0 g
s
.70063 .66779 m .69317 .72203 L .68078 .71113 L p .707 .577 .707 r
F P
0 g
s
.68078 .71113 m .68824 .65689 L .70063 .66779 L p .707 .577 .707 r
F P
0 g
s
.50092 .69394 m .50839 .6397 L .52471 .633 L p .707 .577 .707 r
F P
0 g
s
.50217 .70422 m .49397 .7394 L .48676 .74886 L p .707 .577 .707 r
F P
0 g
s
.24479 .71903 m .25226 .66479 L .22137 .65868 L p .707 .577 .707 r
F P
0 g
s
.25226 .66479 m .24479 .71903 L .27637 .72205 L p .707 .577 .707 r
F P
0 g
s
.27637 .72205 m .28384 .66781 L .25226 .66479 L p .707 .577 .707 r
F P
0 g
s
.28384 .66781 m .27637 .72205 L .30555 .72168 L p .707 .577 .707 r
F P
0 g
s
.30555 .72168 m .31301 .66744 L .28384 .66781 L p .707 .577 .707 r
F P
0 g
s
.47979 .78165 m .484 .7641 L .49122 .75461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21391 .71292 m .22137 .65868 L .1942 .65008 L p .707 .577 .707 r
F P
0 g
s
.22137 .65868 m .21391 .71292 L .24479 .71903 L p .707 .577 .707 r
F P
0 g
s
.68281 .81136 m .67859 .82891 L .67608 .81711 L p .707 .577 .707 r
F P
0 g
s
.67608 .81711 m .68029 .79956 L .68281 .81136 L p .707 .577 .707 r
F P
0 g
s
.49122 .75461 m .487 .77216 L .47979 .78165 L p .707 .577 .707 r
F P
0 g
s
.52471 .633 m .51725 .68723 L .50092 .69394 L p .707 .577 .707 r
F P
0 g
s
.49397 .7394 m .50217 .70422 L .51842 .69795 L p .707 .577 .707 r
F P
0 g
s
.6915 .7481 m .68329 .78328 L .67126 .77046 L p .707 .577 .707 r
F P
0 g
s
.67126 .77046 m .67947 .73527 L .6915 .7481 L p .707 .577 .707 r
F P
0 g
s
.31301 .66744 m .30555 .72168 L .32947 .71796 L p .707 .577 .707 r
F P
0 g
s
.32947 .71796 m .33694 .66372 L .31301 .66744 L p .707 .577 .707 r
F P
0 g
s
.68824 .65689 m .68078 .71113 L .65998 .70088 L p .707 .577 .707 r
F P
0 g
s
.65998 .70088 m .66745 .64664 L .68824 .65689 L p .707 .577 .707 r
F P
0 g
s
.18674 .70432 m .1942 .65008 L .1734 .63983 L p .707 .577 .707 r
F P
0 g
s
.1942 .65008 m .18674 .70432 L .21391 .71292 L p .707 .577 .707 r
F P
0 g
s
.51725 .68723 m .52471 .633 L .54863 .62928 L p .707 .577 .707 r
F P
0 g
s
.48678 .79716 m .34228 .30268 L .30016 .31302 L p .707 .577 .707 r
F P
0 g
s
.51842 .69795 m .51021 .73313 L .49397 .7394 L p .707 .577 .707 r
F P
0 g
s
.487 .77216 m .49122 .75461 L .50746 .74836 L p .707 .577 .707 r
F P
0 g
s
.50746 .74836 m .50324 .76592 L .487 .77216 L p .707 .577 .707 r
F P
0 g
s
.50324 .76592 m .50746 .74836 L .53113 .74597 L p .707 .577 .707 r
F P
0 g
s
.53113 .74597 m .52691 .76353 L .50324 .76592 L p .707 .577 .707 r
F P
0 g
s
.34228 .30268 m .48678 .79716 L .53002 .78431 L p .707 .577 .707 r
F P
0 g
s
.51021 .73313 m .51842 .69795 L .54211 .69547 L p .707 .577 .707 r
F P
0 g
s
.54211 .69547 m .53391 .73065 L .51021 .73313 L p .707 .577 .707 r
F P
0 g
s
.53002 .78431 m .38552 .28983 L .34228 .30268 L p .707 .577 .707 r
F P
0 g
s
.54863 .62928 m .54117 .68352 L .51725 .68723 L p .707 .577 .707 r
F P
0 g
s
.53391 .73065 m .54211 .69547 L .57093 .69704 L p .707 .577 .707 r
F P
0 g
s
.57093 .69704 m .56273 .73222 L .53391 .73065 L p .707 .577 .707 r
F P
0 g
s
.52691 .76353 m .53113 .74597 L .55992 .74767 L p .707 .577 .707 r
F P
0 g
s
.55992 .74767 m .5557 .76522 L .52691 .76353 L p .707 .577 .707 r
F P
0 g
s
.5557 .76522 m .55992 .74767 L .59101 .75328 L p .707 .577 .707 r
F P
0 g
s
.59101 .75328 m .58679 .77084 L .5557 .76522 L p .707 .577 .707 r
F P
0 g
s
.38552 .28983 m .53002 .78431 L .57014 .77021 L p .707 .577 .707 r
F P
0 g
s
.54117 .68352 m .54863 .62928 L .57781 .62891 L p .707 .577 .707 r
F P
0 g
s
.57781 .62891 m .57035 .68315 L .54117 .68352 L p .707 .577 .707 r
F P
0 g
s
.57014 .77021 m .42565 .27573 L .38552 .28983 L p .707 .577 .707 r
F P
0 g
s
.23573 .78596 m .24393 .75078 L .21355 .74198 L p .707 .577 .707 r
F P
0 g
s
.24393 .75078 m .23573 .78596 L .26686 .79141 L p .707 .577 .707 r
F P
0 g
s
.26686 .79141 m .27506 .75623 L .24393 .75078 L p .707 .577 .707 r
F P
0 g
s
.20534 .77716 m .21355 .74198 L .18687 .73068 L p .707 .577 .707 r
F P
0 g
s
.21355 .74198 m .20534 .77716 L .23573 .78596 L p .707 .577 .707 r
F P
0 g
s
.27506 .75623 m .26686 .79141 L .29568 .79298 L p .707 .577 .707 r
F P
0 g
s
.29568 .79298 m .30388 .7578 L .27506 .75623 L p .707 .577 .707 r
F P
0 g
s
.68029 .79956 m .67608 .81711 L .66408 .80415 L p .707 .577 .707 r
F P
0 g
s
.66408 .80415 m .66829 .7866 L .68029 .79956 L p .707 .577 .707 r
F P
0 g
s
.44466 .80751 m .30016 .31302 L .26329 .31985 L p .707 .577 .707 r
F P
0 g
s
.30016 .31302 m .44466 .80751 L .48678 .79716 L p .707 .577 .707 r
F P
0 g
s
.33694 .66372 m .32947 .71796 L .34579 .71126 L p .707 .577 .707 r
F P
0 g
s
.34579 .71126 m .35326 .65702 L .33694 .66372 L p .707 .577 .707 r
F P
0 g
s
.1734 .63983 m .16594 .69407 L .18674 .70432 L p .707 .577 .707 r
F P
0 g
s
.66745 .64664 m .65998 .70088 L .63281 .69228 L p .707 .577 .707 r
F P
0 g
s
.63281 .69228 m .64027 .63804 L .66745 .64664 L p .707 .577 .707 r
F P
0 g
s
.57035 .68315 m .57781 .62891 L .60939 .63193 L p .707 .577 .707 r
F P
0 g
s
.60939 .63193 m .60192 .68617 L .57035 .68315 L p .707 .577 .707 r
F P
0 g
s
.56273 .73222 m .57093 .69704 L .60206 .70249 L p .707 .577 .707 r
F P
0 g
s
.63245 .71129 m .62424 .74648 L .59385 .73767 L p .707 .577 .707 r
F P
0 g
s
.59385 .73767 m .60206 .70249 L .63245 .71129 L p .707 .577 .707 r
F P
0 g
s
.60206 .70249 m .59385 .73767 L .56273 .73222 L p .707 .577 .707 r
F P
0 g
s
.58679 .77084 m .59101 .75328 L .62135 .76227 L p .707 .577 .707 r
F P
0 g
s
.42565 .27573 m .57014 .77021 L .60323 .75625 L p .707 .577 .707 r
F P
0 g
s
.60323 .75625 m .45874 .26176 L .42565 .27573 L p .707 .577 .707 r
F P
0 g
s
.16594 .69407 m .1734 .63983 L .16102 .62893 L p .707 .577 .707 r
F P
0 g
s
.67947 .73527 m .67126 .77046 L .65092 .75777 L p .707 .577 .707 r
F P
0 g
s
.65092 .75777 m .65912 .72259 L .67947 .73527 L p .707 .577 .707 r
F P
0 g
s
.18687 .73068 m .17867 .76586 L .20534 .77716 L p .707 .577 .707 r
F P
0 g
s
.17867 .76586 m .18687 .73068 L .16653 .71799 L p .707 .577 .707 r
F P
0 g
s
.30388 .7578 m .29568 .79298 L .31937 .7905 L p .707 .577 .707 r
F P
0 g
s
.31937 .7905 m .32758 .75532 L .30388 .7578 L p .707 .577 .707 r
F P
0 g
s
.22858 .83541 m .23279 .81786 L .20245 .80887 L p .707 .577 .707 r
F P
0 g
s
.23279 .81786 m .22858 .83541 L .25967 .84103 L p .707 .577 .707 r
F P
0 g
s
.25967 .84103 m .26388 .82347 L .23279 .81786 L p .707 .577 .707 r
F P
0 g
s
.64027 .63804 m .63281 .69228 L .60192 .68617 L p .707 .577 .707 r
F P
0 g
s
.60192 .68617 m .60939 .63193 L .64027 .63804 L p .707 .577 .707 r
F P
0 g
s
.19824 .82642 m .20245 .80887 L .17582 .79739 L p .707 .577 .707 r
F P
0 g
s
.20245 .80887 m .19824 .82642 L .22858 .83541 L p .707 .577 .707 r
F P
0 g
s
.26388 .82347 m .25967 .84103 L .28846 .84272 L p .707 .577 .707 r
F P
0 g
s
.28846 .84272 m .29267 .82517 L .26388 .82347 L p .707 .577 .707 r
F P
0 g
s
.16653 .71799 m .15832 .75318 L .17867 .76586 L p .707 .577 .707 r
F P
0 g
s
.16102 .62893 m .15355 .68317 L .16594 .69407 L p .707 .577 .707 r
F P
0 g
s
.35326 .65702 m .34579 .71126 L .35292 .70223 L p .707 .577 .707 r
F P
0 g
s
.35292 .70223 m .36039 .64799 L .35326 .65702 L p .707 .577 .707 r
F P
0 g
s
.36039 .64799 m .35292 .70223 L .35099 .6949 L p .707 .577 .707 r
F P
0 g
s
.35099 .6949 m .35016 .69175 L p .35376 .67633 L .707 .577 .707 r
F P
0 g
s
.35376 .67633 m .36039 .64799 L .35099 .6949 L .707 .577 .707 r
F
.40778 .81434 m .44466 .80751 L p .36584 .59557 L F P
0 g
s
.26329 .31985 m .3584 .64533 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.35016 .69175 m .3515 .68198 L p .36039 .64799 L .707 .577 .707 r
F P
0 g
s
.26329 .31985 m .23527 .32249 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .26329 .31985 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.35893 .64248 m .36039 .64799 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .40778 .81434 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .34459 .69663 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35016 .69175 L .34785 .68972 L p .707 .577 .707 r
F P
0 g
s
.34459 .69663 m .37976 .81698 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .21884 .32069 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .35371 .72782 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.35371 .72782 m .23527 .32249 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32778 .67594 m .32205 .67311 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.32205 .67311 m .31697 .67061 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .32155 .66348 L .32205 .67311 L .707 .577 .707 r
F
.21884 .32069 m .21562 .31462 L p .2962 .58767 L F P
0 g
s
.34282 .77477 m .35103 .73959 L .34382 .74905 L p .707 .577 .707 r
F P
0 g
s
.33561 .78423 m .34382 .74905 L .32758 .75532 L p .707 .577 .707 r
F P
0 g
s
.34382 .74905 m .33561 .78423 L .34282 .77477 L p .707 .577 .707 r
F P
0 g
s
.35103 .73959 m .34282 .77477 L .34028 .76306 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .34849 .72787 L .35103 .73959 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .32825 .75023 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34849 .72787 m .34439 .74544 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34439 .74544 m .34028 .76306 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .31873 .65783 L .32155 .66348 L .707 .577 .707 r
F
.31697 .67061 m .31832 .66079 L p .31991 .66604 L F P
0 g
s
.31832 .66079 m .31873 .65783 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .33646 .71505 L .34849 .72787 L p .707 .577 .707 r
F P
0 g
s
.31697 .67061 m .2898 .66201 L p .3106 .6346 L .707 .577 .707 r
F P
0 g
s
.3106 .6346 m .31136 .63718 L .31697 .67061 L .707 .577 .707 r
F
.31873 .65783 m .31697 .67061 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .21884 .32069 L p .26526 .48089 L .707 .577 .707 r
F P
0 g
s
.21884 .32069 m .30766 .62464 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.34558 .71155 m .30766 .62464 L .31873 .65783 L .707 .577 .707 r
F
.2898 .66201 m .29727 .60777 L .32444 .61637 L p F P
0 g
s
.31542 .6512 m .30766 .62464 L p .2962 .58767 L .707 .577 .707 r
F P
0 g
s
.30766 .62464 m .26526 .48089 L .2962 .58767 L .707 .577 .707 r
F
.3106 .6346 m .31087 .63425 L .31136 .63718 L F
.32444 .61637 m .31873 .65783 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .31542 .6512 L p .31873 .65783 L .707 .577 .707 r
F P
0 g
s
.21562 .31462 m .22592 .30488 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .32602 .74884 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.3214 .72691 m .33501 .71619 L .32602 .74884 L .707 .577 .707 r
F
.33646 .71505 m .33568 .7184 L p .33501 .71619 L F P
0 g
s
.33568 .7184 m .32825 .75023 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .31611 .70236 L .33424 .71366 L p .707 .577 .707 r
F P
0 g
s
.33424 .71366 m .33646 .71505 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .33424 .71366 L .33501 .71619 L .707 .577 .707 r
F
.27313 .51142 m .28343 .54666 L p .2962 .58767 L F P
0 g
s
.28343 .54666 m .36012 .8091 L p .30166 .60659 L .707 .577 .707 r
F P
0 g
s
.2962 .58767 m .28343 .54666 L .30166 .60659 L .707 .577 .707 r
F
.36012 .8091 m .36334 .81518 L p .30572 .61994 L F P
0 g
s
.30572 .61994 m .2962 .58767 L .30166 .60659 L .707 .577 .707 r
F
.30572 .61994 m .30166 .60659 L .36012 .8091 L F
.21562 .31462 m .27313 .51142 L p .2962 .58767 L F P
0 g
s
.325 .68525 m .31542 .6512 L .2962 .58767 L .707 .577 .707 r
F
.36334 .81518 m .32902 .69774 L p .325 .68525 L F P
0 g
s
.32902 .69774 m .31542 .6512 L p .325 .68525 L .707 .577 .707 r
F P
0 g
s
.31542 .6512 m .36334 .81518 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.31873 .65783 m .32444 .61637 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.36012 .8091 m .28343 .54666 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.28343 .54666 m .21562 .31462 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32602 .74884 m .30791 .73754 L p .3214 .72691 L .707 .577 .707 r
F P
0 g
s
.36334 .81518 m .37976 .81698 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32444 .61637 m .34523 .62662 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.34523 .62662 m .33777 .68086 L .32778 .67594 L p .707 .577 .707 r
F P
0 g
s
.32155 .66348 m .34523 .62662 L .32778 .67594 L .707 .577 .707 r
F
.35762 .63752 m .3515 .68198 L p .33777 .68086 L F P
0 g
s
.34785 .68972 m .33777 .68086 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35762 .63752 L .35893 .64248 L p .707 .577 .707 r
F P
0 g
s
.40778 .81434 m .3584 .64533 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .40778 .81434 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.17582 .79739 m .17161 .81494 L .19824 .82642 L p .707 .577 .707 r
F P
0 g
s
.66829 .7866 m .66408 .80415 L .64377 .7913 L p .707 .577 .707 r
F P
0 g
s
.64377 .7913 m .64798 .77375 L .66829 .7866 L p .707 .577 .707 r
F P
0 g
s
.65912 .72259 m .65092 .75777 L .62424 .74648 L p .707 .577 .707 r
F P
0 g
s
.62424 .74648 m .63245 .71129 L .65912 .72259 L p .707 .577 .707 r
F P
0 g
s
.15832 .75318 m .16653 .71799 L .15449 .70517 L p .707 .577 .707 r
F P
0 g
s
.32758 .75532 m .31937 .7905 L .33561 .78423 L p .707 .577 .707 r
F P
0 g
s
.45874 .26176 m .60323 .75625 L .62604 .74378 L p .707 .577 .707 r
F P
0 g
s
.62604 .74378 m .48155 .2493 L .45874 .26176 L p .707 .577 .707 r
F P
0 g
s
.17161 .81494 m .17582 .79739 L .15551 .78454 L p .707 .577 .707 r
F P
0 g
s
.29267 .82517 m .28846 .84272 L .31213 .84033 L p .707 .577 .707 r
F P
0 g
s
.31213 .84033 m .31634 .82278 L .29267 .82517 L p .707 .577 .707 r
F P
0 g
s
.15355 .68317 m .16102 .62893 L .15825 .61846 L p .707 .577 .707 r
F P
0 g
s
.15551 .78454 m .1513 .80209 L .17161 .81494 L p .707 .577 .707 r
F P
0 g
s
.15449 .70517 m .14629 .74035 L .15832 .75318 L p .707 .577 .707 r
F P
0 g
s
.64798 .77375 m .64377 .7913 L .61714 .77983 L p .707 .577 .707 r
F P
0 g
s
.61714 .77983 m .62135 .76227 L .64798 .77375 L p .707 .577 .707 r
F P
0 g
s
.15825 .61846 m .15078 .67269 L .15355 .68317 L p .707 .577 .707 r
F P
0 g
s
.1513 .80209 m .15551 .78454 L .14351 .77158 L p .707 .577 .707 r
F P
0 g
s
.31634 .82278 m .31213 .84033 L .32837 .83408 L p .707 .577 .707 r
F P
0 g
s
.32837 .83408 m .33258 .81653 L .31634 .82278 L p .707 .577 .707 r
F P
0 g
s
.14629 .74035 m .15449 .70517 L .15196 .69345 L p .707 .577 .707 r
F P
0 g
s
.14351 .77158 m .1393 .78914 L .1513 .80209 L p .707 .577 .707 r
F P
0 g
s
.62135 .76227 m .61714 .77983 L .58679 .77084 L p .707 .577 .707 r
F P
0 g
s
.15078 .67269 m .15825 .61846 L .16538 .60942 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.48155 .2493 m .62604 .74378 L .63634 .73404 L p .707 .577 .707 r
F P
0 g
s
.63634 .73404 m .49185 .23955 L .48155 .2493 L p .707 .577 .707 r
F P
0 g
s
.15196 .69345 m .14375 .72863 L .14629 .74035 L p .707 .577 .707 r
F P
0 g
s
.1393 .78914 m .14351 .77158 L .14099 .75978 L p .707 .577 .707 r
F P
0 g
s
.33258 .81653 m .32837 .83408 L .33558 .8246 L p .707 .577 .707 r
F P
0 g
s
.33558 .8246 m .3398 .80705 L .33258 .81653 L p .707 .577 .707 r
F P
0 g
s
.16538 .60942 m .15791 .66366 L .15078 .67269 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14375 .72863 m .15196 .69345 L .15917 .68399 L p .707 .577 .707 r
F P
0 g
s
.14099 .75978 m .13678 .77734 L .1393 .78914 L p .707 .577 .707 r
F P
0 g
s
.33777 .68086 m .34523 .62662 L .35762 .63752 L p .707 .577 .707 r
F P
0 g
s
.15791 .66366 m .16538 .60942 L .1817 .60272 L p .707 .577 .707 r
F P
0 g
s
.15917 .68399 m .15096 .71918 L .14375 .72863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13678 .77734 m .14099 .75978 L .14821 .7503 L p .707 .577 .707 r
F P
0 g
s
.49185 .23955 m .63634 .73404 L .63312 .72797 L p .707 .577 .707 r
F P
0 g
s
.63312 .72797 m .48863 .23348 L .49185 .23955 L p .707 .577 .707 r
F P
0 g
s
.3398 .80705 m .33558 .8246 L .33307 .8128 L p .707 .577 .707 r
F P
0 g
s
.33307 .8128 m .33728 .79525 L .3398 .80705 L p .707 .577 .707 r
F P
0 g
s
.1817 .60272 m .17424 .65696 L .15791 .66366 L p .707 .577 .707 r
F P
0 g
s
.14821 .7503 m .14399 .76785 L .13678 .77734 L p .707 .577 .707 r
F P
0 g
s
.15096 .71918 m .15917 .68399 L .17541 .67772 L p .707 .577 .707 r
F P
0 g
s
.17424 .65696 m .1817 .60272 L .20562 .59901 L p .707 .577 .707 r
F P
0 g
s
.17541 .67772 m .1672 .7129 L .15096 .71918 L p .707 .577 .707 r
F P
0 g
s
.20562 .59901 m .19816 .65325 L .17424 .65696 L p .707 .577 .707 r
F P
0 g
s
.14399 .76785 m .14821 .7503 L .16445 .74405 L p .707 .577 .707 r
F P
0 g
s
.33728 .79525 m .33307 .8128 L .32107 .79984 L p .707 .577 .707 r
F P
0 g
s
.32107 .79984 m .32528 .78229 L .33728 .79525 L p .707 .577 .707 r
F P
0 g
s
.19816 .65325 m .20562 .59901 L .2348 .59864 L p .707 .577 .707 r
F P
0 g
s
.1672 .7129 m .17541 .67772 L .1991 .67524 L p .707 .577 .707 r
F P
0 g
s
.16445 .74405 m .16023 .7616 L .14399 .76785 L p .707 .577 .707 r
F P
0 g
s
.29727 .60777 m .2898 .66201 L .25891 .6559 L p .707 .577 .707 r
F P
0 g
s
.25891 .6559 m .26638 .60166 L .29727 .60777 L p .707 .577 .707 r
F P
0 g
s
.22734 .65288 m .2348 .59864 L .26638 .60166 L p .707 .577 .707 r
F P
0 g
s
.2348 .59864 m .22734 .65288 L .19816 .65325 L p .707 .577 .707 r
F P
0 g
s
.48863 .23348 m .63312 .72797 L .6167 .72616 L p .707 .577 .707 r
F P
0 g
s
.6167 .72616 m .4722 .23168 L .48863 .23348 L p .707 .577 .707 r
F P
0 g
s
.1991 .67524 m .1909 .71043 L .1672 .7129 L p .707 .577 .707 r
F P
0 g
s
.26638 .60166 m .25891 .6559 L .22734 .65288 L p .707 .577 .707 r
F P
0 g
s
.72501 .65726 m .73247 .60302 L .70159 .59691 L p .707 .577 .707 r
F P
0 g
s
.73247 .60302 m .72501 .65726 L .75658 .66028 L p .707 .577 .707 r
F P
0 g
s
.75658 .66028 m .76405 .60604 L .73247 .60302 L p .707 .577 .707 r
F P
0 g
s
.76405 .60604 m .75658 .66028 L .78576 .65991 L p .707 .577 .707 r
F P
0 g
s
.78576 .65991 m .79323 .60567 L .76405 .60604 L p .707 .577 .707 r
F P
0 g
s
.1909 .71043 m .1991 .67524 L .22792 .67681 L p .707 .577 .707 r
F P
0 g
s
.31611 .70236 m .30791 .73754 L .28123 .72625 L p .707 .577 .707 r
F P
0 g
s
.28123 .72625 m .28944 .69107 L .31611 .70236 L p .707 .577 .707 r
F P
0 g
s
.69412 .65115 m .70159 .59691 L .67441 .58831 L p .707 .577 .707 r
F P
0 g
s
.70159 .59691 m .69412 .65115 L .72501 .65726 L p .707 .577 .707 r
F P
0 g
s
.16023 .7616 m .16445 .74405 L .18812 .74166 L p .707 .577 .707 r
F P
0 g
s
.32528 .78229 m .32107 .79984 L .30076 .78699 L p .707 .577 .707 r
F P
0 g
s
.30076 .78699 m .30497 .76944 L .32528 .78229 L p .707 .577 .707 r
F P
0 g
s
.18812 .74166 m .1839 .75921 L .16023 .7616 L p .707 .577 .707 r
F P
0 g
s
.79323 .60567 m .78576 .65991 L .80968 .6562 L p .707 .577 .707 r
F P
0 g
s
.80968 .6562 m .81715 .60196 L .79323 .60567 L p .707 .577 .707 r
F P
0 g
s
.22792 .67681 m .21972 .71199 L .1909 .71043 L p .707 .577 .707 r
F P
0 g
s
.21972 .71199 m .22792 .67681 L .25905 .68226 L p .707 .577 .707 r
F P
0 g
s
.28944 .69107 m .28123 .72625 L .25084 .71744 L p .707 .577 .707 r
F P
0 g
s
.25084 .71744 m .25905 .68226 L .28944 .69107 L p .707 .577 .707 r
F P
0 g
s
.66695 .64255 m .67441 .58831 L .65362 .57806 L p .707 .577 .707 r
F P
0 g
s
.67441 .58831 m .66695 .64255 L .69412 .65115 L p .707 .577 .707 r
F P
0 g
s
.25905 .68226 m .25084 .71744 L .21972 .71199 L p .707 .577 .707 r
F P
0 g
s
.71594 .71415 m .72415 .67897 L .69376 .67017 L p .707 .577 .707 r
F P
0 g
s
.72415 .67897 m .71594 .71415 L .74707 .7196 L p .707 .577 .707 r
F P
0 g
s
.74707 .7196 m .75528 .68442 L .72415 .67897 L p .707 .577 .707 r
F P
0 g
s
.1839 .75921 m .18812 .74166 L .21691 .74335 L p .707 .577 .707 r
F P
0 g
s
.30497 .76944 m .30076 .78699 L .27413 .77551 L p .707 .577 .707 r
F P
0 g
s
.27413 .77551 m .27834 .75796 L .30497 .76944 L p .707 .577 .707 r
F P
0 g
s
.68555 .70535 m .69376 .67017 L .66709 .65887 L p .707 .577 .707 r
F P
0 g
s
.69376 .67017 m .68555 .70535 L .71594 .71415 L p .707 .577 .707 r
F P
0 g
s
.37041 .79936 m .22592 .30488 L .24873 .29241 L p .707 .577 .707 r
F P
0 g
s
.22592 .30488 m .37041 .79936 L .36012 .8091 L p .707 .577 .707 r
F P
0 g
s
.75528 .68442 m .74707 .7196 L .77589 .72117 L p .707 .577 .707 r
F P
0 g
s
.77589 .72117 m .7841 .68599 L .75528 .68442 L p .707 .577 .707 r
F P
0 g
s
.21691 .74335 m .21269 .76091 L .1839 .75921 L p .707 .577 .707 r
F P
0 g
s
.4722 .23168 m .6167 .72616 L .58867 .72881 L p .707 .577 .707 r
F P
0 g
s
.58867 .72881 m .44418 .23432 L .4722 .23168 L p .707 .577 .707 r
F P
0 g
s
.81715 .60196 m .80968 .6562 L .82601 .6495 L p .707 .577 .707 r
F P
0 g
s
.82601 .6495 m .83347 .59526 L .81715 .60196 L p .707 .577 .707 r
F P
0 g
s
.65362 .57806 m .64615 .6323 L .66695 .64255 L p .707 .577 .707 r
F P
0 g
s
.21269 .76091 m .21691 .74335 L .248 .74897 L p .707 .577 .707 r
F P
0 g
s
.27834 .75796 m .27413 .77551 L .24378 .76652 L p .707 .577 .707 r
F P
0 g
s
.24378 .76652 m .248 .74897 L .27834 .75796 L p .707 .577 .707 r
F P
0 g
s
.64615 .6323 m .65362 .57806 L .64123 .56717 L p .707 .577 .707 r
F P
0 g
s
.66709 .65887 m .65888 .69405 L .68555 .70535 L p .707 .577 .707 r
F P
0 g
s
.65888 .69405 m .66709 .65887 L .64674 .64618 L p .707 .577 .707 r
F P
0 g
s
.7841 .68599 m .77589 .72117 L .79958 .71869 L p .707 .577 .707 r
F P
0 g
s
.79958 .71869 m .80779 .68351 L .7841 .68599 L p .707 .577 .707 r
F P
0 g
s
.70879 .74769 m .71301 .73013 L .68266 .72114 L p .707 .577 .707 r
F P
0 g
s
.71301 .73013 m .70879 .74769 L .73988 .7533 L p .707 .577 .707 r
F P
0 g
s
.73988 .7533 m .7441 .73575 L .71301 .73013 L p .707 .577 .707 r
F P
0 g
s
.248 .74897 m .24378 .76652 L .21269 .76091 L p .707 .577 .707 r
F P
0 g
s
.67845 .7387 m .68266 .72114 L .65603 .70966 L p .707 .577 .707 r
F P
0 g
s
.68266 .72114 m .67845 .7387 L .70879 .74769 L p .707 .577 .707 r
F P
0 g
s
.7441 .73575 m .73988 .7533 L .76867 .755 L p .707 .577 .707 r
F P
0 g
s
.76867 .755 m .77289 .73744 L .7441 .73575 L p .707 .577 .707 r
F P
0 g
s
.65603 .70966 m .65182 .72722 L .67845 .7387 L p .707 .577 .707 r
F P
0 g
s
.64674 .64618 m .63853 .68137 L .65888 .69405 L p .707 .577 .707 r
F P
0 g
s
.64123 .56717 m .63376 .6214 L .64615 .6323 L p .707 .577 .707 r
F P
0 g
s
.65182 .72722 m .65603 .70966 L .63572 .69682 L p .707 .577 .707 r
F P
0 g
s
.77289 .73744 m .76867 .755 L .79235 .75261 L p .707 .577 .707 r
F P
0 g
s
.79235 .75261 m .79656 .73505 L .77289 .73744 L p .707 .577 .707 r
F P
0 g
s
.63853 .68137 m .64674 .64618 L .63471 .63336 L p .707 .577 .707 r
F P
0 g
s
.80779 .68351 m .79958 .71869 L .81583 .71242 L p .707 .577 .707 r
F P
0 g
s
.81583 .71242 m .82403 .67724 L .80779 .68351 L p .707 .577 .707 r
F P
0 g
s
.83347 .59526 m .82601 .6495 L .83314 .64046 L p .707 .577 .707 r
F P
0 g
s
.83314 .64046 m .8406 .58623 L .83347 .59526 L p .707 .577 .707 r
F P
0 g
s
.24873 .29241 m .39322 .78689 L .37041 .79936 L p .707 .577 .707 r
F P
0 g
s
.39322 .78689 m .24873 .29241 L .28182 .27845 L p .707 .577 .707 r
F P
0 g
s
.63572 .69682 m .63151 .71437 L .65182 .72722 L p .707 .577 .707 r
F P
0 g
s
.63376 .6214 m .64123 .56717 L .63846 .55669 L p .707 .577 .707 r
F P
0 g
s
.44418 .23432 m .58867 .72881 L .5518 .73564 L p .707 .577 .707 r
F P
0 g
s
.5518 .73564 m .40731 .24115 L .44418 .23432 L p .707 .577 .707 r
F P
0 g
s
.63471 .63336 m .6265 .66854 L .63853 .68137 L p .707 .577 .707 r
F P
0 g
s
.63151 .71437 m .63572 .69682 L .62372 .68386 L p .707 .577 .707 r
F P
0 g
s
.79656 .73505 m .79235 .75261 L .80858 .74636 L p .707 .577 .707 r
F P
0 g
s
.80858 .74636 m .8128 .72881 L .79656 .73505 L p .707 .577 .707 r
F P
0 g
s
.63846 .55669 m .631 .61093 L .63376 .6214 L p .707 .577 .707 r
F P
0 g
s
.62372 .68386 m .61951 .70141 L .63151 .71437 L p .707 .577 .707 r
F P
0 g
s
.6265 .66854 m .63471 .63336 L .63217 .62164 L p .707 .577 .707 r
F P
0 g
s
.82403 .67724 m .81583 .71242 L .82303 .70296 L p .707 .577 .707 r
F P
0 g
s
.82303 .70296 m .83124 .66778 L .82403 .67724 L p .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .3784 .60896 L p .40363 .66239 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .37064 .58239 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38376 .6142 L .40363 .66239 L .707 .577 .707 r
F
.38946 .57275 m .38376 .6142 L p .41357 .63001 L F P
0 g
s
.39841 .62856 m .41357 .63001 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.38376 .6142 m .38946 .57275 L .36537 .56798 L p .707 .577 .707 r
F P
0 g
s
.37064 .58239 m .3784 .60896 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.38296 .62455 m .392 .65549 L p .37351 .61032 L .707 .577 .707 r
F P
0 g
s
.392 .65549 m .42631 .77293 L p .38722 .65254 L .707 .577 .707 r
F P
0 g
s
.37351 .61032 m .392 .65549 L .38722 .65254 L .707 .577 .707 r
F
.41357 .63001 m .42104 .57577 L .38946 .57275 L p F P
0 g
s
.42104 .57577 m .41357 .63001 L .43732 .62971 L p .707 .577 .707 r
F P
0 g
s
.44284 .64059 m .43127 .63848 L .43992 .62593 L .707 .577 .707 r
F
.46644 .75883 m .43455 .6497 L p .44284 .64059 L F P
0 g
s
.43455 .6497 m .43127 .63848 L p .44284 .64059 L .707 .577 .707 r
F P
0 g
s
.46644 .75883 m .42631 .77293 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .43455 .6497 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43455 .6497 m .46644 .75883 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .44109 .66576 L .42093 .66466 L p .707 .577 .707 r
F P
0 g
s
.42093 .66466 m .41227 .66419 L p .41573 .67038 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .42093 .66466 L .41573 .67038 L .707 .577 .707 r
F
.44076 .6247 m .42104 .57577 L .43732 .62971 L F
.50968 .74598 m .46644 .75883 L p .43992 .62593 L F P
0 g
s
.45022 .5754 m .42104 .57577 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .45022 .5754 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .46427 .59057 L p .4441 .61986 L .707 .577 .707 r
F P
0 g
s
.46427 .59057 m .50968 .74598 L p .44106 .6279 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4441 .61986 L .44106 .6279 L .707 .577 .707 r
F
.4441 .61986 m .46427 .59057 L .44106 .6279 L F
.36519 .2515 m .40731 .24115 L p .46782 .53955 L F P
0 g
s
.50968 .74598 m .4603 .57697 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.46095 .57374 m .45022 .5754 L p .4603 .57697 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .36519 .2515 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.45516 .59057 m .4603 .57697 L .45022 .5754 L .707 .577 .707 r
F
.46155 .57364 m .46095 .57374 L p .4603 .57697 L F P
0 g
s
.46667 .62592 m .47414 .57169 L .46155 .57364 L p .707 .577 .707 r
F P
0 g
s
.46667 .62592 m .46155 .57364 L .45516 .59057 L .707 .577 .707 r
F
.44275 .62964 m .46667 .62592 L p .45516 .59057 L F P
0 g
s
.45022 .5754 m .4441 .61986 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .44275 .62964 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.36519 .2515 m .4603 .57697 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4603 .57697 L .4441 .61986 L .707 .577 .707 r
F
.44275 .62964 m .4441 .61986 L p .44076 .6247 L F P
0 g
s
.43732 .62971 m .44275 .62964 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .36519 .2515 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43127 .63848 m .32195 .26435 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .43288 .70094 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41227 .66419 m .41148 .66755 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .40406 .69938 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .39322 .78689 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .41148 .66755 L p .38114 .65874 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .41227 .66419 L .40886 .6636 L p .707 .577 .707 r
F P
0 g
s
.40886 .6636 m .38114 .65874 L p .41148 .66755 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38296 .62455 L p .36684 .58978 L .707 .577 .707 r
F P
0 g
s
.36684 .58978 m .38296 .62455 L .37351 .61032 L .707 .577 .707 r
F
.31517 .43063 m .3784 .60896 L .36684 .58978 L F
.28182 .27845 m .32195 .26435 L p .39625 .62645 L F P
0 g
s
.40363 .66239 m .39041 .62072 L .39625 .62645 L .707 .577 .707 r
F
.39041 .62072 m .28182 .27845 L .39625 .62645 L F
.38376 .6142 m .36537 .56798 L .37064 .58239 L F
.37064 .58239 m .28182 .27845 L p .40363 .66239 L F P
0 g
s
.38376 .6142 m .38335 .61717 L p .39841 .62856 L .707 .577 .707 r
F P
0 g
s
.38335 .61717 m .382 .62699 L .38971 .62772 L p .707 .577 .707 r
F P
0 g
s
.38971 .62772 m .39841 .62856 L p .38335 .61717 L .707 .577 .707 r
F P
0 g
s
.36537 .56798 m .36463 .56784 L p .37064 .58239 L .707 .577 .707 r
F P
0 g
s
.28182 .27845 m .37064 .58239 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.382 .62699 m .38376 .6142 L p .35858 .56664 L .707 .577 .707 r
F P
0 g
s
.36463 .56784 m .35858 .56664 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.8406 .58623 m .83314 .64046 L .83037 .62999 L p .707 .577 .707 r
F P
0 g
s
.83037 .62999 m .83784 .57575 L .8406 .58623 L p .707 .577 .707 r
F P
0 g
s
.40731 .24115 m .5518 .73564 L .50968 .74598 L p .707 .577 .707 r
F P
0 g
s
.631 .61093 m .63846 .55669 L .64559 .54766 L p .707 .577 .707 r
F P
0 g
s
.63217 .62164 m .62396 .65682 L .6265 .66854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.61951 .70141 m .62372 .68386 L .62121 .67206 L p .707 .577 .707 r
F P
0 g
s
.8128 .72881 m .80858 .74636 L .8158 .73687 L p .707 .577 .707 r
F P
0 g
s
.8158 .73687 m .82001 .71932 L .8128 .72881 L p .707 .577 .707 r
F P
0 g
s
.62121 .67206 m .61699 .68961 L .61951 .70141 L p .707 .577 .707 r
F P
0 g
s
.64559 .54766 m .63813 .6019 L .631 .61093 L p .707 .577 .707 r
F P
0 g
s
.62396 .65682 m .63217 .62164 L .63938 .61218 L p .707 .577 .707 r
F P
0 g
s
.83124 .66778 m .82303 .70296 L .8205 .69125 L p .707 .577 .707 r
F P
0 g
s
.8205 .69125 m .82871 .65606 L .83124 .66778 L p .707 .577 .707 r
F P
0 g
s
.83784 .57575 m .83037 .62999 L .81798 .61909 L p .707 .577 .707 r
F P
0 g
s
.81798 .61909 m .82545 .56485 L .83784 .57575 L p .707 .577 .707 r
F P
0 g
s
.63813 .6019 m .64559 .54766 L .66192 .54096 L p .707 .577 .707 r
F P
0 g
s
.63938 .61218 m .63117 .64737 L .62396 .65682 L p .707 .577 .707 r
F P
0 g
s
.61699 .68961 m .62121 .67206 L .62842 .66257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35111 .62088 m .35858 .56664 L .3314 .55804 L p .707 .577 .707 r
F P
0 g
s
.35858 .56664 m .35111 .62088 L .382 .62699 L p .707 .577 .707 r
F P
0 g
s
.82001 .71932 m .8158 .73687 L .81328 .72507 L p .707 .577 .707 r
F P
0 g
s
.81328 .72507 m .8175 .70752 L .82001 .71932 L p .707 .577 .707 r
F P
0 g
s
.62842 .66257 m .62421 .68012 L .61699 .68961 L p .707 .577 .707 r
F P
0 g
s
.66192 .54096 m .65445 .5952 L .63813 .6019 L p .707 .577 .707 r
F P
0 g
s
.63117 .64737 m .63938 .61218 L .65562 .60591 L p .707 .577 .707 r
F P
0 g
s
.82871 .65606 m .8205 .69125 L .80847 .67842 L p .707 .577 .707 r
F P
0 g
s
.80847 .67842 m .81667 .64324 L .82871 .65606 L p .707 .577 .707 r
F P
0 g
s
.82545 .56485 m .81798 .61909 L .79719 .60884 L p .707 .577 .707 r
F P
0 g
s
.79719 .60884 m .80465 .5546 L .82545 .56485 L p .707 .577 .707 r
F P
0 g
s
.32394 .61228 m .3314 .55804 L .31061 .54779 L p .707 .577 .707 r
F P
0 g
s
.3314 .55804 m .32394 .61228 L .35111 .62088 L p .707 .577 .707 r
F P
0 g
s
.65445 .5952 m .66192 .54096 L .68584 .53724 L p .707 .577 .707 r
F P
0 g
s
.37293 .69392 m .38114 .65874 L .35075 .64994 L p .707 .577 .707 r
F P
0 g
s
.38114 .65874 m .37293 .69392 L .40406 .69938 L p .707 .577 .707 r
F P
0 g
s
.65562 .60591 m .64742 .64109 L .63117 .64737 L p .707 .577 .707 r
F P
0 g
s
.34254 .68512 m .35075 .64994 L .32408 .63864 L p .707 .577 .707 r
F P
0 g
s
.35075 .64994 m .34254 .68512 L .37293 .69392 L p .707 .577 .707 r
F P
0 g
s
.62421 .68012 m .62842 .66257 L .64466 .65633 L p .707 .577 .707 r
F P
0 g
s
.8175 .70752 m .81328 .72507 L .80128 .71211 L p .707 .577 .707 r
F P
0 g
s
.80128 .71211 m .8055 .69456 L .8175 .70752 L p .707 .577 .707 r
F P
0 g
s
.47414 .57169 m .46667 .62592 L .483 .61922 L p .707 .577 .707 r
F P
0 g
s
.483 .61922 m .49046 .56498 L .47414 .57169 L p .707 .577 .707 r
F P
0 g
s
.31061 .54779 m .30314 .60203 L .32394 .61228 L p .707 .577 .707 r
F P
0 g
s
.80465 .5546 m .79719 .60884 L .77001 .60024 L p .707 .577 .707 r
F P
0 g
s
.77001 .60024 m .77748 .546 L .80465 .5546 L p .707 .577 .707 r
F P
0 g
s
.68584 .53724 m .67837 .59148 L .65445 .5952 L p .707 .577 .707 r
F P
0 g
s
.64466 .65633 m .64045 .67388 L .62421 .68012 L p .707 .577 .707 r
F P
0 g
s
.30314 .60203 m .31061 .54779 L .29822 .53689 L p .707 .577 .707 r
F P
0 g
s
.64742 .64109 m .65562 .60591 L .67932 .60343 L p .707 .577 .707 r
F P
0 g
s
.67837 .59148 m .68584 .53724 L .71502 .53687 L p .707 .577 .707 r
F P
0 g
s
.81667 .64324 m .80847 .67842 L .78812 .66573 L p .707 .577 .707 r
F P
0 g
s
.78812 .66573 m .79633 .63055 L .81667 .64324 L p .707 .577 .707 r
F P
0 g
s
.32408 .63864 m .31587 .67382 L .34254 .68512 L p .707 .577 .707 r
F P
0 g
s
.31587 .67382 m .32408 .63864 L .30373 .62596 L p .707 .577 .707 r
F P
0 g
s
.44109 .66576 m .43288 .70094 L .45657 .69847 L p .707 .577 .707 r
F P
0 g
s
.45657 .69847 m .46478 .66328 L .44109 .66576 L p .707 .577 .707 r
F P
0 g
s
.36578 .74337 m .37 .72582 L .33965 .71683 L p .707 .577 .707 r
F P
0 g
s
.37 .72582 m .36578 .74337 L .39687 .74899 L p .707 .577 .707 r
F P
0 g
s
.39687 .74899 m .40109 .73144 L .37 .72582 L p .707 .577 .707 r
F P
0 g
s
.77748 .546 m .77001 .60024 L .73913 .59413 L p .707 .577 .707 r
F P
0 g
s
.73913 .59413 m .74659 .53989 L .77748 .546 L p .707 .577 .707 r
F P
0 g
s
.33544 .73438 m .33965 .71683 L .31302 .70535 L p .707 .577 .707 r
F P
0 g
s
.33965 .71683 m .33544 .73438 L .36578 .74337 L p .707 .577 .707 r
F P
0 g
s
.40109 .73144 m .39687 .74899 L .42566 .75068 L p .707 .577 .707 r
F P
0 g
s
.42566 .75068 m .42988 .73313 L .40109 .73144 L p .707 .577 .707 r
F P
0 g
s
.67932 .60343 m .67111 .63862 L .64742 .64109 L p .707 .577 .707 r
F P
0 g
s
.70755 .59111 m .71502 .53687 L .74659 .53989 L p .707 .577 .707 r
F P
0 g
s
.71502 .53687 m .70755 .59111 L .67837 .59148 L p .707 .577 .707 r
F P
0 g
s
.30373 .62596 m .29552 .66114 L .31587 .67382 L p .707 .577 .707 r
F P
0 g
s
.74659 .53989 m .73913 .59413 L .70755 .59111 L p .707 .577 .707 r
F P
0 g
s
.29822 .53689 m .29075 .59113 L .30314 .60203 L p .707 .577 .707 r
F P
0 g
s
.64045 .67388 m .64466 .65633 L .66833 .65393 L p .707 .577 .707 r
F P
0 g
s
.31302 .70535 m .30881 .7229 L .33544 .73438 L p .707 .577 .707 r
F P
0 g
s
.8055 .69456 m .80128 .71211 L .78097 .69927 L p .707 .577 .707 r
F P
0 g
s
.78097 .69927 m .78519 .68171 L .8055 .69456 L p .707 .577 .707 r
F P
0 g
s
.67111 .63862 m .67932 .60343 L .70814 .605 L p .707 .577 .707 r
F P
0 g
s
.79633 .63055 m .78812 .66573 L .76145 .65444 L p .707 .577 .707 r
F P
0 g
s
.76145 .65444 m .76965 .61925 L .79633 .63055 L p .707 .577 .707 r
F P
0 g
s
.49046 .56498 m .483 .61922 L .49013 .61019 L p .707 .577 .707 r
F P
0 g
s
.49013 .61019 m .49759 .55595 L .49046 .56498 L p .707 .577 .707 r
F P
0 g
s
.29552 .66114 m .30373 .62596 L .2917 .61313 L p .707 .577 .707 r
F P
0 g
s
.46478 .66328 m .45657 .69847 L .47282 .69219 L p .707 .577 .707 r
F P
0 g
s
.47282 .69219 m .48102 .65701 L .46478 .66328 L p .707 .577 .707 r
F P
0 g
s
.66833 .65393 m .66412 .67149 L .64045 .67388 L p .707 .577 .707 r
F P
0 g
s
.30881 .7229 m .31302 .70535 L .29271 .6925 L p .707 .577 .707 r
F P
0 g
s
.42988 .73313 m .42566 .75068 L .44934 .74829 L p .707 .577 .707 r
F P
0 g
s
.44934 .74829 m .45355 .73074 L .42988 .73313 L p .707 .577 .707 r
F P
0 g
s
.29075 .59113 m .29822 .53689 L .29545 .52642 L p .707 .577 .707 r
F P
0 g
s
.29271 .6925 m .2885 .71006 L .30881 .7229 L p .707 .577 .707 r
F P
0 g
s
.70814 .605 m .69993 .64018 L .67111 .63862 L p .707 .577 .707 r
F P
0 g
s
.69993 .64018 m .70814 .605 L .73926 .61045 L p .707 .577 .707 r
F P
0 g
s
.76965 .61925 m .76145 .65444 L .73106 .64563 L p .707 .577 .707 r
F P
0 g
s
.73106 .64563 m .73926 .61045 L .76965 .61925 L p .707 .577 .707 r
F P
0 g
s
.2917 .61313 m .28349 .64831 L .29552 .66114 L p .707 .577 .707 r
F P
0 g
s
.73926 .61045 m .73106 .64563 L .69993 .64018 L p .707 .577 .707 r
F P
0 g
s
.66412 .67149 m .66833 .65393 L .69712 .65563 L p .707 .577 .707 r
F P
0 g
s
.78519 .68171 m .78097 .69927 L .75434 .68779 L p .707 .577 .707 r
F P
0 g
s
.75434 .68779 m .75856 .67023 L .78519 .68171 L p .707 .577 .707 r
F P
0 g
s
.29545 .52642 m .28799 .58066 L .29075 .59113 L p .707 .577 .707 r
F P
0 g
s
.69712 .65563 m .69291 .67318 L .66412 .67149 L p .707 .577 .707 r
F P
0 g
s
.2885 .71006 m .29271 .6925 L .28071 .67955 L p .707 .577 .707 r
F P
0 g
s
.45355 .73074 m .44934 .74829 L .46557 .74205 L p .707 .577 .707 r
F P
0 g
s
.46557 .74205 m .46979 .72449 L .45355 .73074 L p .707 .577 .707 r
F P
0 g
s
.28349 .64831 m .2917 .61313 L .28916 .60141 L p .707 .577 .707 r
F P
0 g
s
.48102 .65701 m .47282 .69219 L .48002 .68273 L p .707 .577 .707 r
F P
0 g
s
.48002 .68273 m .48823 .64755 L .48102 .65701 L p .707 .577 .707 r
F P
0 g
s
.49759 .55595 m .49013 .61019 L .48736 .59972 L p .707 .577 .707 r
F P
0 g
s
.48736 .59972 m .49483 .54548 L .49759 .55595 L p .707 .577 .707 r
F P
0 g
s
.28071 .67955 m .2765 .6971 L .2885 .71006 L p .707 .577 .707 r
F P
0 g
s
.69291 .67318 m .69712 .65563 L .72821 .66125 L p .707 .577 .707 r
F P
0 g
s
.75856 .67023 m .75434 .68779 L .724 .6788 L p .707 .577 .707 r
F P
0 g
s
.724 .6788 m .72821 .66125 L .75856 .67023 L p .707 .577 .707 r
F P
0 g
s
.28799 .58066 m .29545 .52642 L .30258 .51739 L p .707 .577 .707 r
F P
0 g
s
.72821 .66125 m .724 .6788 L .69291 .67318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28916 .60141 m .28095 .6366 L .28349 .64831 L p .707 .577 .707 r
F P
0 g
s
.2765 .6971 m .28071 .67955 L .2782 .66775 L p .707 .577 .707 r
F P
0 g
s
.46979 .72449 m .46557 .74205 L .47279 .73256 L p .707 .577 .707 r
F P
0 g
s
.47279 .73256 m .477 .71501 L .46979 .72449 L p .707 .577 .707 r
F P
0 g
s
.30258 .51739 m .29512 .57162 L .28799 .58066 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28095 .6366 m .28916 .60141 L .29637 .59195 L p .707 .577 .707 r
F P
0 g
s
.2782 .66775 m .27398 .6853 L .2765 .6971 L p .707 .577 .707 r
F P
0 g
s
.48823 .64755 m .48002 .68273 L .47749 .67102 L p .707 .577 .707 r
F P
0 g
s
.47749 .67102 m .4857 .63583 L .48823 .64755 L p .707 .577 .707 r
F P
0 g
s
.49483 .54548 m .48736 .59972 L .47497 .58882 L p .707 .577 .707 r
F P
0 g
s
.47497 .58882 m .48244 .53458 L .49483 .54548 L p .707 .577 .707 r
F P
0 g
s
.29512 .57162 m .30258 .51739 L .31891 .51068 L p .707 .577 .707 r
F P
0 g
s
.29637 .59195 m .28816 .62714 L .28095 .6366 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27398 .6853 m .2782 .66775 L .28541 .65826 L p .707 .577 .707 r
F P
0 g
s
.477 .71501 m .47279 .73256 L .47027 .72076 L p .707 .577 .707 r
F P
0 g
s
.47027 .72076 m .47448 .70321 L .477 .71501 L p .707 .577 .707 r
F P
0 g
s
.31891 .51068 m .31144 .56492 L .29512 .57162 L p .707 .577 .707 r
F P
0 g
s
.48244 .53458 m .47497 .58882 L .45418 .57857 L p .707 .577 .707 r
F P
0 g
s
.45418 .57857 m .46164 .52433 L .48244 .53458 L p .707 .577 .707 r
F P
0 g
s
.28541 .65826 m .2812 .67581 L .27398 .6853 L p .707 .577 .707 r
F P
0 g
s
.28816 .62714 m .29637 .59195 L .31261 .58568 L p .707 .577 .707 r
F P
0 g
s
.4857 .63583 m .47749 .67102 L .46546 .65819 L p .707 .577 .707 r
F P
0 g
s
.46546 .65819 m .47366 .62301 L .4857 .63583 L p .707 .577 .707 r
F P
0 g
s
.31144 .56492 m .31891 .51068 L .34283 .50697 L p .707 .577 .707 r
F P
0 g
s
.31261 .58568 m .30441 .62086 L .28816 .62714 L p .707 .577 .707 r
F P
0 g
s
.46164 .52433 m .45418 .57857 L .427 .56997 L p .707 .577 .707 r
F P
0 g
s
.427 .56997 m .43447 .51573 L .46164 .52433 L p .707 .577 .707 r
F P
0 g
s
.34283 .50697 m .33536 .56121 L .31144 .56492 L p .707 .577 .707 r
F P
0 g
s
.2812 .67581 m .28541 .65826 L .30165 .65201 L p .707 .577 .707 r
F P
0 g
s
.47448 .70321 m .47027 .72076 L .45827 .7078 L p .707 .577 .707 r
F P
0 g
s
.45827 .7078 m .46248 .69025 L .47448 .70321 L p .707 .577 .707 r
F P
0 g
s
.33536 .56121 m .34283 .50697 L .372 .5066 L p .707 .577 .707 r
F P
0 g
s
.30441 .62086 m .31261 .58568 L .33631 .5832 L p .707 .577 .707 r
F P
0 g
s
.47366 .62301 m .46546 .65819 L .44511 .64551 L p .707 .577 .707 r
F P
0 g
s
.44511 .64551 m .45332 .61032 L .47366 .62301 L p .707 .577 .707 r
F P
0 g
s
.30165 .65201 m .29744 .66957 L .2812 .67581 L p .707 .577 .707 r
F P
0 g
s
.43447 .51573 m .427 .56997 L .39612 .56386 L p .707 .577 .707 r
F P
0 g
s
.39612 .56386 m .40358 .50962 L .43447 .51573 L p .707 .577 .707 r
F P
0 g
s
.36454 .56084 m .372 .5066 L .40358 .50962 L p .707 .577 .707 r
F P
0 g
s
.372 .5066 m .36454 .56084 L .33536 .56121 L p .707 .577 .707 r
F P
0 g
s
.33631 .5832 m .3281 .61839 L .30441 .62086 L p .707 .577 .707 r
F P
0 g
s
.40358 .50962 m .39612 .56386 L .36454 .56084 L p .707 .577 .707 r
F P
0 g
s
.3281 .61839 m .33631 .5832 L .36513 .58477 L p .707 .577 .707 r
F P
0 g
s
.45332 .61032 m .44511 .64551 L .41844 .63421 L p .707 .577 .707 r
F P
0 g
s
.41844 .63421 m .42664 .59903 L .45332 .61032 L p .707 .577 .707 r
F P
0 g
s
.29744 .66957 m .30165 .65201 L .32532 .64962 L p .707 .577 .707 r
F P
0 g
s
.46248 .69025 m .45827 .7078 L .43796 .69495 L p .707 .577 .707 r
F P
0 g
s
.43796 .69495 m .44218 .6774 L .46248 .69025 L p .707 .577 .707 r
F P
0 g
s
.32532 .64962 m .32111 .66717 L .29744 .66957 L p .707 .577 .707 r
F P
0 g
s
.36513 .58477 m .35692 .61995 L .3281 .61839 L p .707 .577 .707 r
F P
0 g
s
.35692 .61995 m .36513 .58477 L .39625 .59022 L p .707 .577 .707 r
F P
0 g
s
.42664 .59903 m .41844 .63421 L .38805 .6254 L p .707 .577 .707 r
F P
0 g
s
.38805 .6254 m .39625 .59022 L .42664 .59903 L p .707 .577 .707 r
F P
0 g
s
.39625 .59022 m .38805 .6254 L .35692 .61995 L p .707 .577 .707 r
F P
0 g
s
.32111 .66717 m .32532 .64962 L .35411 .65132 L p .707 .577 .707 r
F P
0 g
s
.44218 .6774 m .43796 .69495 L .41133 .68347 L p .707 .577 .707 r
F P
0 g
s
.41133 .68347 m .41555 .66592 L .44218 .6774 L p .707 .577 .707 r
F P
0 g
s
.35411 .65132 m .3499 .66887 L .32111 .66717 L p .707 .577 .707 r
F P
0 g
s
.3499 .66887 m .35411 .65132 L .3852 .65693 L p .707 .577 .707 r
F P
0 g
s
.41555 .66592 m .41133 .68347 L .38099 .67449 L p .707 .577 .707 r
F P
0 g
s
.38099 .67449 m .3852 .65693 L .41555 .66592 L p .707 .577 .707 r
F P
0 g
s
.3852 .65693 m .38099 .67449 L .3499 .66887 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol008=oo`D009Eoo`00O7oo1`001EYF0`00TWoo001fOol6
000;FUH01000FUIJEUYFTWoo001bOol40009FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001^
Ool400000eYF001JEP0:FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001ZOol40006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`2>Ool006Ioo`@000YJEP03001JEUYF015JEP05001J
EUYFFUH0002@Ool006=oo`<000iJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002@
Ool0061oo`<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002@Ool005eoo`<000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF
FUH0002?Ool005Yoo`<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001J
EUYFFUH0002?Ool005Moo`<001]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002?
Ool005Eoo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH2002>Ool0059oo`<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03Ool005YF
00UJEP03001JEUYF00IJEP05001JEUYFFUH0002>Ool004moo`<000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002>Ool004eoo`800003FUH0
05YF01QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2002=Ool0
04Yoo`<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008008eoo`00B7oo0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008eoo`00AWoo0P00
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00D005YFFUIJEP0008eoo`00A7oo0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00S7oo0012Ool20003FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000S7oo0010Ool20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
S7oo000oOol20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Rgoo000nOol01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Rgoo000mOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0008]oo`00?Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002;Ool003ioo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02002:Ool003ioo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RWoo000nOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Yoo`00?Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH20029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
0029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RGoo000oOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Uoo`00@7oo00@005YFFUH000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF008008Qoo`00@7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH00028Ool0041oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000R7oo0010Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8008Moo`00@Goo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008008Moo`00@Goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP05001JEUYFFUH00027Ool0045oo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00QWoo0012Ool01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00P00QWoo0012Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Ioo`00
@Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00026Ool0049oo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020025Ool004=oo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000QGoo0013Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D0
05YFFUIJEP0008Eoo`00@goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20024
Ool004Aoo`05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020024Ool004Aoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Q7oo0014Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Aoo`00A7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF008008=oo`00AGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0023Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Pgoo0015Ool0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80089oo`00AWoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF0080089oo`00AWoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH00022Ool004Ioo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00PGoo0016Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00PGoo0017
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00085oo`00Agoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00021Ool004Moo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00081o
o`00B7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001oOol004Qoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007moo`00BGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0001oOol004Uoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000Ogoo0019Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8007ioo`00BWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007ioo`00BWoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001nOol004Yoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OGoo001:Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02001mOol004]oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000OGoo001;Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007eo
o`00Bgoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007aoo`00C7oo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001lOol004aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000O7oo001<Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007]oo`00C7oo0P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P00Ngoo001=Ool01@00FUIJEUYF00001UYF00<005YFFUH00eYF5`001eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007]oo`00CGoo00D005YFFUIJEP0000IJEP03
001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000=JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001jOol004eoo`05001JEUYFFUH0
0006FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001jOol004ioo`05001JEUYFFUH00003FUH20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00H005YFFUIJEP00FUH3
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0`0025YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00@005YF
FUIJEP80009JEP04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001>
Ool20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001iOol004moo`07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH01EYF00D005YFFUIJEP0007Uoo`00Cgoo00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P006goo4000CGoo001?Ool01000
FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF00UJEP03001JEUYF00IJEP03001JEUYF
008001Ioo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00D7oo00<005YF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00000;FUH00`00FUIJEP05FUH01@00FUIJEUYF000057oo0P00
00=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00@goo001@Ool01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000]JEP03001JEUYF00EJEP05001JEUYFFUH0
000BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000oOol0051oo`05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YF
FUH01EYF00@005YFFUIJEP80011oo`8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<003]oo`00DGoo0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000YJEP03001JEUYF00IJEP03001JEUYF0080011oo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Qoo`00
DGoo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00EJEP05
001JEUYFFUH0000?Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0055oo`800003FUH005YF009JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]J
EP03001JEUYF00EJEP04001JEUYFFUH2000>Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02000dOol0055oo`<000=J
EPD0009JEP04001JEUYFFUH20004FUH01000FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00D005YFFUH005YF008000YJEP03001JEUYF00IJEP03001JEUYF008000ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP80039oo`00DGoo00@005YF001JEP<000IJEP03001JEUYF00=JEPD000EJEPT0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00003Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Goo001AOol01000FUH000000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00@005YFFUH000AJEPH00004FUH005YFFUH40006FUH00`00FUIJEP04FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P0037oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000002moo`00DGoo0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00@005YFFUH000IJEP<000=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF
0080009JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2000<Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF0`001EYF00@005YFFUIJEP80009JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000aoo`03001JEP0000AJEP03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DGoo00<005YFFUH00eYF00<005YFFUH00UYF1`0000=JEP00FUH0
0eYF00<005YFFUH02EYF00<005YFFUH02UYF0P000eYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0000<Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool0055oo`03001JEUYF00=JEPD000=JEP04001JEUYFFUH9000:FUH00`00
FUIJEP0;FUH200000eYF001JEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P002goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;7oo001B
Ool01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<005YFFUH035YF
0`000UYF00<005YF00000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P002goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00@005YF0000009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00eJEP08001JEUYF001J
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0000;Ool20004FUH01000
FUIJEUYF5P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00Dgoo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`003EYF00@0
05YFFUIJEP800003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000:
Ool00eYF001JEP02FUH500000eYF001JEP04FUH50007Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0`002UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P002Goo00@005YF001JEP8000IJEP03001JEUYF00EJEP03001J
EUYF00@0009oo`D000=oo`@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000008FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo00H005YF000005YF0005FUH70002FUH0
0`00FUIJEP04FUH70007Ool20004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000aOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH01`00FUIJEUYF
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00009Ool30002FUH60003
FUH01000FUIJEUYF2@000UYF4@0000=JEP00FUH015YF00<005YFFUH00UYF00<007ooOol0;Goo000_
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH20008Ool01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00
1EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF00<007ooOol0;Goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001J
EP03FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020008Ool01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEUYF
FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH2
0007FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10001eYF00@005YFFUIJEP800003
FUH005YF009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF00000UYF1P001UYF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00AJEP8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000P000eYF00<005YF
FUH01EYF00@005YFFUIJEPX000MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000Moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUH00002
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEPP000EJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0007Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`001UYF00<005YFFUH00`00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH30002FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH800000eYF001JEP07FUH00`00FUIJEP04FUH01000FUH000002EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00@005YFFUIJEP@000=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH2
000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00<000IJEP03001JEUYF00QJEPH0009JEP<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH300000eYF0000000200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0P00<7oo000/Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP08FUH50005FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030004
FUH00`00FUH00003FUH01000FUIJEUYF1P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`000UYF00<005YF0000<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH025YF100025YF0`0000=JEP00FUH01EYF00@005YFFUIJEP8000UJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH20003FUH80003FUH90004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000[Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH200000eYF001JEP09FUH01000FUIJEP002EYF00@0
05YF000000IJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001EYF00<005YF00000P000eYF0`0000=oo`00000015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01EYF00<005YFFUH015YF1000<Goo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF1`000UYF0`00
5UYF00<005YFFUH00`0015YF00@005YFFUIJEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF008000=JEP04001JEP000002FUH30003FUH300001Woo00000000FUH000QJEP03001JEUYF
00<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000bOol002]oo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00@005YFFUIJEPT000IJ
EP03001JEUYF00UJEP04001JEUYF0002FUH01000FUIJEP000eYF00<005YF00002UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP<000=JEP03001JEUYF00P0009oo`H000AJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYF000bOol002]oo`8000=J
EPD0009JEP04001JEUYFFUH20008Ool70006FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7
000<FUH00`00FUH00003FUH30003FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000UYF00<005YF00000UYF1@000UYF00<005YFFUH00UYF1P000Woo2@0015YF0`00
1eYF00<005YFFUH00eYF00D005YFFUIJEP00035oo`00:goo0P0000AJEP00000000IJEP03001JEUYF
00=JEP@000Ioo`T00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000UJEP03001JEUYF00EJEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YF00000`001goo2@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;goo000[
Ool00eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool50004Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40006FUH0
0`00FUIJEP02FUH50002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000;Ool300000eYF001J
EP04FUH00`00FUIJEP02FUH2000`Ool002Yoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00AJEP`000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH<0003
FUH01P00FUH00000FUH000aJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool20005
FUH01`00FUIJEUYF001JEP00031oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF1`001EYF2@0015YF00<005YFFUH01eYF00@005YF0000
00=JEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH0000000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40008Ool20003FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<005YFFUH00eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000001EYF0`00
1eYF00<005YFFUH00eYF1P001eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00H005YFFUIJEP00
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH50002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01eYF00@005YF000000Qoo`<000AJEP03001JEWoo031oo`00:Woo00<0
05YFFUH00eYF4`0015YF00<005YFFUH015YF0`001eYF00<005YFFUH00P0015YF00<005YFFUH01eYF
00<005YFFUH00P001EYF00<005YFFUH015YF0P001EYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH3000015YF000000001UYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH01eYF00@005YFFUIJEP<000Moo`03001JEUYF009JEP80035o
o`00:goo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP<000MJEP06001J
EUYFFUH005YF0`0000=JEP00FUH025YF00@005YFFUIJEP@00003FUH005YF00MJEP<0009JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH50000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20006Ool0
1000FUIJEUYF0P00<Goo000[Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF1@0000=JEP00FUH00P001UYF00D005YFFUIJEP0000=JEP@000QJEP03001JEUYF00P0
00MJEP06001JEUYF001JEP000eYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00@0009JEP03001JEUYF00IJEP800003Ool0000000@00003FUH00000039oo`00;7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00
FUH00P0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP<000AJEP04001JEUYFFUH60002FUH2
0004FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP050004FUH01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH015YF1000
1UYF00<005YFFUH00P000UYF00<005YFFUH00`00<Woo000/Ool01@00FUIJEUYF00001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH00004FUH01@00FUIJEUYF
00001EYF0`0000=JEP00FUH00UYF1@001EYF0`0000=JEP00FUH01EYF00@005YF000000AJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF001JEP040004FUH30007FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH00UYF00<005YF00000eYF0P00
<Woo000[Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH300000eYF001JEP03FUH01@00FUIJEUYF00001UYF00<005YF0000100000=J
EP0000000P0025YF0P001UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P000UYF00@007oo000000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF00EJEP04001JEUYFFUH3000bOol002]oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00
008000EJEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH90004FUH01000FUH0000015YF00<005YF
00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEPH00003
FUH005YF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP80009J
EP8003=oo`00:Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH000AJEP<000=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH01000FUIJ
EUYF2@000UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP04001JEUYF0003FUH30003FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30004FUH01000FUH005YF0P00<goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH400000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P0000=JEP00FUH00P000eYF
0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH2000dOol0
02Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000EJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP001EYF0P000eYF0P0000AJEP00FUIJEP<000AJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYFFUH30004FUH00`00Oomoo`0bOol002Uoo`03001JEP00009JEQ<000IJEP03
001JEUYF00IJEP04001JEUYF0004FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<000=JEP8000=JEPD00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo039oo`00:Goo0P0000AJEP000000
011oo`H0009JEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH40006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00P0000AJEP00FUH0009JEP80
00=oo`H00003FUH00000008000MJEP03001JEUYF00AJEP8000=JEP8003=oo`00:Goo0`000eYF00<0
07ooOol04Goo1P001eYF00<005YFFUH00eYF0P0025YF00<005YF00000P0015YF00<005YFFUH05EYF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF10000eYF00<005YFFUH00eYF0P000UYF0`002Woo200015YF00@005YFFUIJEPH00004FUH0
05YF000cOol002Uoo`8000AJEP<001Ioo`D0009JEP03001JEUYF00EJEP8000MJEP03001JEUYF009J
EP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF0P0000=JEP00FUH01UYF1@00
2Woo1@000goo20001Woo0P0000=JEP00Ool0<Woo000XOol30004FUH00`00FUIJEP02000COol50000
0goo000000020007FUH30004FUH00`00FUIJEP06FUH60007FUH00`00FUIJEP09FUH00`00FUH00003
0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP02FUH2
0008FUH00`00FUH000030008Ool5000BOol2000dOol002Qoo`03001JEP0000=JEP03001JEUYF00=J
EP<0011oo`D000Eoo`8000AJEP04001JEUYFFUH300000eYF001JEP08FUH00`00FUIJEP02FUH80008
FUH50002FUH2000DFUH00`00FUIJEP07FUH70004FUH50005FUH20005FUH00`00FUIJEP04FUH50004
Ool3000BOol3000dOol002Qoo`03001JEUYF00=JEP03001JEUYF00AJEP04001JEP00000>Ool50007
Ool300000eYF001JEP05FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00<005YFFUH0
0UYF0P0025YF00<005YFFUH02UYF00<005YFFUH01P0015YF00<005YFFUH015YF00D005YFFUIJEP00
00EJEP04001JEP000003FUH00`00FUIJEP06FUH00`00FUIJEP04000COol200000eYF001oo`0dOol0
02Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP8000eoo`<000]oo`8000IJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0009FUH00`00FUIJEP09FUH50009FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP<0
00UJEP03001JEUYF00AJEQ<0009JEP8003Eoo`00:Goo00<005YFFUH00UYF00@005YFFUIJEPL0009J
EP<001Yoo`8000AJEP03001JEP00009JEP<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP@000AJEP03001JEUYF00QJEP03001JEUYF
00AJEP8000MJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0000fOol002Yoo`04001JEUYFFUH40003FUH01000FUIJEUYF2@0067oo0P00
00EJEP00FUIJEP0000=JEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF00<000iJEP@000UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008003Ioo`00:goo10001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0057oo0P000eYF00D0
05YFFUIJEP0000IJEPP000AJEP04001JEUYFFUH600000eYF001JEP0:FUH5000<FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0003Moo`00:Woo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P004Woo00D005YFFUIJEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEPP000MJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF
00MJEP04001JEUYFFUH70004FUH00`00FUIJEP04FUH01@00FUIJEUYF00001goo10000UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000003Qoo`00:Goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0037oo1@0000=JEP0000000eYF00<005YFFUH0
15YF00<005YFFUH065YF100025YF00<005YFFUH02eYF00<005YFFUH01eYF0`001goo0`0000=JEP00
FUH015YF00<005YFFUH00UYF00<007ooOol02Goo4`00>Woo000YOol01@00FUIJEUYF00000eYF1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF30000eYF00H005YF000005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4000:
Ool20005FUH01`00FUIJEUYF001JEP0005Moo`00:7oo0P000UYF1`001EYF2@0015YF00<005YFFUH0
1eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH045YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P0015YF
0`002Goo00<005YFFUH00UYF00L005YFFUIJEP00FUH0001GOol002Qoo`04001JEP000006Ool20007
FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP02FUH200000eYF001JEP04FUH01`00FUIJEUYF001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00iJEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF009JEP8000QJEP<000Qoo`80009JEP07001JEUYFFUH005YF0000Egoo000WOol3000:
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH20005FUH01000FUIJ
EUYF0`000eYF00<005YFFUH04UYF0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF0000
0P002EYF00<005YFFUH00P0027oo0P0015YF0P00F7oo000WOol2000=Ool300000eYF001JEP08FUH0
1000FUIJEUYF100000=JEP00FUH01eYF0`000UYF00<005YFFUH00UYF0P0000=oo`00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01eYF100035YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<0
05YFFUH00eYF0P001goo00<005YFFUH00UYF0P00F7oo000VOol4000?Ool30008FUH00`00FUIJEP08
0007FUH01P00FUIJEP00FUH000=JEP05001JEP00Ool00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04
0002FUH00`00FUIJEP05FUH20002Ool50002FUH00`00FUH0001HOol002Ioo`05001JEP00FUH0000A
Ool30004FUH01000FUIJEUYF1P000UYF0P0015YF00<005YFFUH00UYF0P000eYF0P000Woo00D005YF
FUIJEP0000IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00=JEP<000QJEP03001JEUYF00AJEP<000QJEP<000=JEP03001JEP0000<005Uoo`009Woo00<005YF
FUH00UYF00<007ooOol04Goo0`0000=JEP00FUH00UYF1P0015YF0`0000=JEP00FUH01EYF00@005YF
000000Aoo`eJEP8000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP<000EJEP04001JEUYFFUH200000eYF001JEP02FUH2001IOol002Moo`03
001JEUYF009JEP03001oogoo01=oo`<000=JEP<00003FUH005YF00IJEP8000IJEP8000Ioo`05001J
EUYFFUH00006FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`009goo
00<005YFFUH00UYF0`005Woo10000UYF00<005YFFUH01UYF00@005YF000000AJEP8000Ioo`05001J
EUYFFUH00004FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP0AFUH400000goo00000004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH20002FUH3001IOol002Qoo`05001J
EUYFFUH00002FUH2000HOol@0002FUH01000FUIJEP001Woo0eYF00D005YFFUIJEP0000AJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00@000Moo`800003FUH005YF00QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00FUH2001JOol002Uoo`03001JEP0000EJEP03
001oogoo02Eoo`<000=JEP03001oogoo00=oo`EJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EPD0009JEP8000Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP<000=JEP04001JEUYFFUH3
001JOol002Yoo`8000EJEP<002Moo`05001JEUYFFUH00005Ool01000FUIJEUYF0P001eYF00<005YF
FUH045YF100000Aoo`00FUH000EJEP8000Uoo`<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00800003FUH005YF00=JEP03001oogoo05Uoo`00:goo00<005YFFUH00eYF00<005YFFUH0
0P009Woo00<005YFFUH00P0017oo00H005YFFUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP04
0006Ool20006FUH3000:Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00Oomoo`1IOol002aoo`80009JEP03001JEUYF00=JEP8002Aoo`05001JEP00FUH00005Ool0
0eYF001JEP09FUH00`00FUIJEP07FUH5000;Ool00`00FUIJEP04FUH00`00FUIJEP02000;Ool60004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2001JOol002ioo`<000MJEP@0025oo`800003
FUH007oo00Aoo`03001JEUYF00YJEP03001JEUYF00H0015oo`8000=JEP03001JEUYF00=JEP8000mo
o`P000AJEP04001JEUYFFUH6000015YF001JEP00FWoo000`Ool20007FUH00`00FUIJEP04000NOol0
0`00FUH00006Ool20002FUH00`00FUIJEP02FUH6000IOol200000eYF001JEP06FUH3000<Ool50003
Ool80006Ool200000eYF001oo`1IOol0039oo`8000AJEP03001JEUYF00EJEPD001Moo`@000Uoo`L0
025oo`8000QJEP03001JEP0000<000Qoo`D0019oo`8005]oo`00=7oo0`0000=JEP00FUH025YF00<0
05YFFUH010003Woo1@000UYF0P00<goo0P001EYF00<005YFFUH015YF1@000goo1@004Goo0`00Fgoo
000gOol30007FUH00`00FUIJEP05FUH>0002FUH00`00FUIJEP02FUH2000eOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP07000@Ool200000eYF001oo`1KOol003Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000hOol30009FUH00`00FUIJEP04FUHC0002
FUH2001LOol003aoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
009JEP8003Yoo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH0001MOol003moo`@000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<003ioo`@0
009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005eoo`00@goo
10000UYF00<005YFFUH01UYF00@005YFFUIJEPD004Eoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol004Moo`l004moo`@0009JEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001OOol00:Uooa<0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59105 .74945 m .59567 .69457 L .56461 .69006 L p .707 .577 .707 r
F P
0 g
s
.59567 .69457 m .59105 .74945 L .62278 .75103 L p .707 .577 .707 r
F P
0 g
s
.62278 .75103 m .62741 .69615 L .59567 .69457 L p .707 .577 .707 r
F P
0 g
s
.62741 .69615 m .62278 .75103 L .65209 .74952 L p .707 .577 .707 r
F P
0 g
s
.65209 .74952 m .65671 .69464 L .62741 .69615 L p .707 .577 .707 r
F P
0 g
s
.55998 .74494 m .56461 .69006 L .53726 .68305 L p .707 .577 .707 r
F P
0 g
s
.56461 .69006 m .55998 .74494 L .59105 .74945 L p .707 .577 .707 r
F P
0 g
s
.65671 .69464 m .65209 .74952 L .67609 .74507 L p .707 .577 .707 r
F P
0 g
s
.67609 .74507 m .68071 .69019 L .65671 .69464 L p .707 .577 .707 r
F P
0 g
s
.53263 .73793 m .53726 .68305 L .5163 .67424 L p .707 .577 .707 r
F P
0 g
s
.53726 .68305 m .53263 .73793 L .55998 .74494 L p .707 .577 .707 r
F P
0 g
s
.58555 .80775 m .59065 .77162 L .55978 .76541 L p .707 .577 .707 r
F P
0 g
s
.59065 .77162 m .58555 .80775 L .61711 .81086 L p .707 .577 .707 r
F P
0 g
s
.61711 .81086 m .62221 .77474 L .59065 .77162 L p .707 .577 .707 r
F P
0 g
s
.62221 .77474 m .61711 .81086 L .64628 .81057 L p .707 .577 .707 r
F P
0 g
s
.64628 .81057 m .65138 .77444 L .62221 .77474 L p .707 .577 .707 r
F P
0 g
s
.55468 .80154 m .55978 .76541 L .53262 .75671 L p .707 .577 .707 r
F P
0 g
s
.55978 .76541 m .55468 .80154 L .58555 .80775 L p .707 .577 .707 r
F P
0 g
s
.68071 .69019 m .67609 .74507 L .69244 .73812 L p .707 .577 .707 r
F P
0 g
s
.69244 .73812 m .69706 .68324 L .68071 .69019 L p .707 .577 .707 r
F P
0 g
s
.5163 .67424 m .51168 .72912 L .53263 .73793 L p .707 .577 .707 r
F P
0 g
s
.65138 .77444 m .64628 .81057 L .6702 .8069 L p .707 .577 .707 r
F P
0 g
s
.6702 .8069 m .6753 .77077 L .65138 .77444 L p .707 .577 .707 r
F P
0 g
s
.53262 .75671 m .52752 .79284 L .55468 .80154 L p .707 .577 .707 r
F P
0 g
s
.58115 .8444 m .58377 .82636 L .55291 .82003 L p .707 .577 .707 r
F P
0 g
s
.58377 .82636 m .58115 .8444 L .6127 .84762 L p .707 .577 .707 r
F P
0 g
s
.6127 .84762 m .61532 .82957 L .58377 .82636 L p .707 .577 .707 r
F P
0 g
s
.52752 .79284 m .53262 .75671 L .51184 .74636 L p .707 .577 .707 r
F P
0 g
s
.51168 .72912 m .5163 .67424 L .50379 .66449 L p .707 .577 .707 r
F P
0 g
s
.61532 .82957 m .6127 .84762 L .64185 .84741 L p .707 .577 .707 r
F P
0 g
s
.64185 .84741 m .64447 .82936 L .61532 .82957 L p .707 .577 .707 r
F P
0 g
s
.55029 .83807 m .55291 .82003 L .52577 .81121 L p .707 .577 .707 r
F P
0 g
s
.55291 .82003 m .55029 .83807 L .58115 .8444 L p .707 .577 .707 r
F P
0 g
s
.52577 .81121 m .52315 .82926 L .55029 .83807 L p .707 .577 .707 r
F P
0 g
s
.51184 .74636 m .50674 .78249 L .52752 .79284 L p .707 .577 .707 r
F P
0 g
s
.64447 .82936 m .64185 .84741 L .66576 .8438 L p .707 .577 .707 r
F P
0 g
s
.66576 .8438 m .66838 .82575 L .64447 .82936 L p .707 .577 .707 r
F P
0 g
s
.50379 .66449 m .49916 .71936 L .51168 .72912 L p .707 .577 .707 r
F P
0 g
s
.6753 .77077 m .6702 .8069 L .68652 .80022 L p .707 .577 .707 r
F P
0 g
s
.68652 .80022 m .69162 .76409 L .6753 .77077 L p .707 .577 .707 r
F P
0 g
s
.52315 .82926 m .52577 .81121 L .505 .80076 L p .707 .577 .707 r
F P
0 g
s
.69706 .68324 m .69244 .73812 L .69954 .72934 L p .707 .577 .707 r
F P
0 g
s
.69954 .72934 m .70416 .67446 L .69706 .68324 L p .707 .577 .707 r
F P
0 g
s
.50674 .78249 m .51184 .74636 L .49946 .73539 L p .707 .577 .707 r
F P
0 g
s
.505 .80076 m .50238 .81881 L .52315 .82926 L p .707 .577 .707 r
F P
0 g
s
.49916 .71936 m .50379 .66449 L .50094 .65474 L p .707 .577 .707 r
F P
0 g
s
.49946 .73539 m .49436 .77152 L .50674 .78249 L p .707 .577 .707 r
F P
0 g
s
.66838 .82575 m .66576 .8438 L .68208 .83713 L p .707 .577 .707 r
F P
0 g
s
.68208 .83713 m .6847 .81908 L .66838 .82575 L p .707 .577 .707 r
F P
0 g
s
.50238 .81881 m .505 .80076 L .49264 .78971 L p .707 .577 .707 r
F P
0 g
s
.69162 .76409 m .68652 .80022 L .69365 .79117 L p .707 .577 .707 r
F P
0 g
s
.69365 .79117 m .69875 .75504 L .69162 .76409 L p .707 .577 .707 r
F P
0 g
s
.50094 .65474 m .49632 .70962 L .49916 .71936 L p .707 .577 .707 r
F P
0 g
s
.49264 .78971 m .49002 .80775 L .50238 .81881 L p .707 .577 .707 r
F P
0 g
s
.49436 .77152 m .49946 .73539 L .4967 .72487 L p .707 .577 .707 r
F P
0 g
s
.70416 .67446 m .69954 .72934 L .69669 .7196 L p .707 .577 .707 r
F P
0 g
s
.69669 .7196 m .70132 .66472 L .70416 .67446 L p .707 .577 .707 r
F P
0 g
s
.49632 .70962 m .50094 .65474 L .50804 .64596 L p .707 .577 .707 r
F P
0 g
s
.4967 .72487 m .4916 .761 L .49436 .77152 L p .707 .577 .707 r
F P
0 g
s
.6847 .81908 m .68208 .83713 L .68921 .82806 L p .707 .577 .707 r
F P
0 g
s
.68921 .82806 m .69183 .81002 L .6847 .81908 L p .707 .577 .707 r
F P
0 g
s
.49002 .80775 m .49264 .78971 L .48989 .77913 L p .707 .577 .707 r
F P
0 g
s
.48989 .77913 m .48727 .79718 L .49002 .80775 L p .707 .577 .707 r
F P
0 g
s
.69875 .75504 m .69365 .79117 L .69089 .78065 L p .707 .577 .707 r
F P
0 g
s
.69089 .78065 m .69599 .74452 L .69875 .75504 L p .707 .577 .707 r
F P
0 g
s
.50804 .64596 m .50342 .70084 L .49632 .70962 L p .707 .577 .707 r
F P
0 g
s
.4916 .761 m .4967 .72487 L .50383 .71582 L p .707 .577 .707 r
F P
0 g
s
.70132 .66472 m .69669 .7196 L .68418 .70984 L p .707 .577 .707 r
F P
0 g
s
.68418 .70984 m .6888 .65496 L .70132 .66472 L p .707 .577 .707 r
F P
0 g
s
.50342 .70084 m .50804 .64596 L .52439 .63901 L p .707 .577 .707 r
F P
0 g
s
.24804 .71668 m .25266 .6618 L .2216 .65729 L p .707 .577 .707 r
F P
0 g
s
.25266 .6618 m .24804 .71668 L .27977 .71826 L p .707 .577 .707 r
F P
0 g
s
.27977 .71826 m .2844 .66338 L .25266 .6618 L p .707 .577 .707 r
F P
0 g
s
.50383 .71582 m .49873 .75195 L .4916 .761 L p .707 .577 .707 r
F P
0 g
s
.48904 .80929 m .39889 .30652 L .35561 .31192 L p .707 .577 .707 r
F P
0 g
s
.48727 .79718 m .48989 .77913 L .49702 .77006 L p .707 .577 .707 r
F P
0 g
s
.49702 .77006 m .4944 .78811 L .48727 .79718 L p .707 .577 .707 r
F P
0 g
s
.52439 .63901 m .51977 .69389 L .50342 .70084 L p .707 .577 .707 r
F P
0 g
s
.49873 .75195 m .50383 .71582 L .52015 .70914 L p .707 .577 .707 r
F P
0 g
s
.52015 .70914 m .51505 .74527 L .49873 .75195 L p .707 .577 .707 r
F P
0 g
s
.4944 .78811 m .49702 .77006 L .51334 .7634 L p .707 .577 .707 r
F P
0 g
s
.51334 .7634 m .51072 .78144 L .4944 .78811 L p .707 .577 .707 r
F P
0 g
s
.51505 .74527 m .52015 .70914 L .54407 .70547 L p .707 .577 .707 r
F P
0 g
s
.54407 .70547 m .53897 .7416 L .51505 .74527 L p .707 .577 .707 r
F P
0 g
s
.51072 .78144 m .51334 .7634 L .53725 .75978 L p .707 .577 .707 r
F P
0 g
s
.53725 .75978 m .53463 .77783 L .51072 .78144 L p .707 .577 .707 r
F P
0 g
s
.39889 .30652 m .48904 .80929 L .53333 .8009 L p .707 .577 .707 r
F P
0 g
s
.53333 .8009 m .44318 .29813 L .39889 .30652 L p .707 .577 .707 r
F P
0 g
s
.69183 .81002 m .68921 .82806 L .68646 .81749 L p .707 .577 .707 r
F P
0 g
s
.68646 .81749 m .68908 .79944 L .69183 .81002 L p .707 .577 .707 r
F P
0 g
s
.2844 .66338 m .27977 .71826 L .30908 .71675 L p .707 .577 .707 r
F P
0 g
s
.30908 .71675 m .3137 .66187 L .2844 .66338 L p .707 .577 .707 r
F P
0 g
s
.51977 .69389 m .52439 .63901 L .54839 .63456 L p .707 .577 .707 r
F P
0 g
s
.54839 .63456 m .54377 .68944 L .51977 .69389 L p .707 .577 .707 r
F P
0 g
s
.54377 .68944 m .54839 .63456 L .5777 .63305 L p .707 .577 .707 r
F P
0 g
s
.5777 .63305 m .57308 .68793 L .54377 .68944 L p .707 .577 .707 r
F P
0 g
s
.53897 .7416 m .54407 .70547 L .57323 .70518 L p .707 .577 .707 r
F P
0 g
s
.57323 .70518 m .56813 .7413 L .53897 .7416 L p .707 .577 .707 r
F P
0 g
s
.53463 .77783 m .53725 .75978 L .5664 .75957 L p .707 .577 .707 r
F P
0 g
s
.5664 .75957 m .56378 .77762 L .53463 .77783 L p .707 .577 .707 r
F P
0 g
s
.56378 .77762 m .5664 .75957 L .59795 .76279 L p .707 .577 .707 r
F P
0 g
s
.59795 .76279 m .59533 .78084 L .56378 .77762 L p .707 .577 .707 r
F P
0 g
s
.44318 .29813 m .53333 .8009 L .5743 .79035 L p .707 .577 .707 r
F P
0 g
s
.5743 .79035 m .48414 .28758 L .44318 .29813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21697 .71216 m .2216 .65729 L .19425 .65028 L p .707 .577 .707 r
F P
0 g
s
.2216 .65729 m .21697 .71216 L .24804 .71668 L p .707 .577 .707 r
F P
0 g
s
.44576 .81469 m .35561 .31192 L .31757 .31379 L p .707 .577 .707 r
F P
0 g
s
.35561 .31192 m .44576 .81469 L .48904 .80929 L p .707 .577 .707 r
F P
0 g
s
.69599 .74452 m .69089 .78065 L .67851 .76968 L p .707 .577 .707 r
F P
0 g
s
.67851 .76968 m .68361 .73355 L .69599 .74452 L p .707 .577 .707 r
F P
0 g
s
.3137 .66187 m .30908 .71675 L .33308 .7123 L p .707 .577 .707 r
F P
0 g
s
.33308 .7123 m .3377 .65742 L .3137 .66187 L p .707 .577 .707 r
F P
0 g
s
.6888 .65496 m .68418 .70984 L .66322 .70103 L p .707 .577 .707 r
F P
0 g
s
.66322 .70103 m .66785 .64615 L .6888 .65496 L p .707 .577 .707 r
F P
0 g
s
.57308 .68793 m .5777 .63305 L .60944 .63463 L p .707 .577 .707 r
F P
0 g
s
.60944 .63463 m .60481 .68951 L .57308 .68793 L p .707 .577 .707 r
F P
0 g
s
.56813 .7413 m .57323 .70518 L .6048 .70829 L p .707 .577 .707 r
F P
0 g
s
.6048 .70829 m .5997 .74442 L .56813 .7413 L p .707 .577 .707 r
F P
0 g
s
.62881 .76912 m .62619 .78716 L .59533 .78084 L p .707 .577 .707 r
F P
0 g
s
.59533 .78084 m .59795 .76279 L .62881 .76912 L p .707 .577 .707 r
F P
0 g
s
.48414 .28758 m .5743 .79035 L .60792 .77866 L p .707 .577 .707 r
F P
0 g
s
.63567 .7145 m .63057 .75063 L .5997 .74442 L p .707 .577 .707 r
F P
0 g
s
.5997 .74442 m .6048 .70829 L .63567 .7145 L p .707 .577 .707 r
F P
0 g
s
.60792 .77866 m .51776 .27588 L .48414 .28758 L p .707 .577 .707 r
F P
0 g
s
.18962 .70516 m .19425 .65028 L .17329 .64147 L p .707 .577 .707 r
F P
0 g
s
.19425 .65028 m .18962 .70516 L .21697 .71216 L p .707 .577 .707 r
F P
0 g
s
.24254 .78119 m .24764 .74506 L .21677 .73885 L p .707 .577 .707 r
F P
0 g
s
.24764 .74506 m .24254 .78119 L .27411 .7843 L p .707 .577 .707 r
F P
0 g
s
.27411 .7843 m .27921 .74817 L .24764 .74506 L p .707 .577 .707 r
F P
0 g
s
.27921 .74817 m .27411 .7843 L .30327 .78401 L p .707 .577 .707 r
F P
0 g
s
.30327 .78401 m .30837 .74788 L .27921 .74817 L p .707 .577 .707 r
F P
0 g
s
.21167 .77497 m .21677 .73885 L .18961 .73014 L p .707 .577 .707 r
F P
0 g
s
.21677 .73885 m .21167 .77497 L .24254 .78119 L p .707 .577 .707 r
F P
0 g
s
.68908 .79944 m .68646 .81749 L .6741 .80643 L p .707 .577 .707 r
F P
0 g
s
.6741 .80643 m .67672 .78839 L .68908 .79944 L p .707 .577 .707 r
F P
0 g
s
.3377 .65742 m .33308 .7123 L .34943 .70535 L p .707 .577 .707 r
F P
0 g
s
.34943 .70535 m .35405 .65047 L .3377 .65742 L p .707 .577 .707 r
F P
0 g
s
.40772 .81657 m .31757 .31379 L .28849 .31197 L p .707 .577 .707 r
F P
0 g
s
.31757 .31379 m .40772 .81657 L .44576 .81469 L p .707 .577 .707 r
F P
0 g
s
.17329 .64147 m .16867 .69635 L .18962 .70516 L p .707 .577 .707 r
F P
0 g
s
.66785 .64615 m .66322 .70103 L .63587 .69403 L p .707 .577 .707 r
F P
0 g
s
.63587 .69403 m .6405 .63915 L .66785 .64615 L p .707 .577 .707 r
F P
0 g
s
.68361 .73355 m .67851 .76968 L .65773 .75933 L p .707 .577 .707 r
F P
0 g
s
.65773 .75933 m .66283 .7232 L .68361 .73355 L p .707 .577 .707 r
F P
0 g
s
.30837 .74788 m .30327 .78401 L .32719 .78034 L p .707 .577 .707 r
F P
0 g
s
.32719 .78034 m .33229 .74421 L .30837 .74788 L p .707 .577 .707 r
F P
0 g
s
.18961 .73014 m .18451 .76627 L .21167 .77497 L p .707 .577 .707 r
F P
0 g
s
.16867 .69635 m .17329 .64147 L .16078 .63171 L p .707 .577 .707 r
F P
0 g
s
.18451 .76627 m .18961 .73014 L .16883 .7198 L p .707 .577 .707 r
F P
0 g
s
.23814 .82767 m .24076 .80963 L .2099 .8033 L p .707 .577 .707 r
F P
0 g
s
.24076 .80963 m .23814 .82767 L .26969 .83089 L p .707 .577 .707 r
F P
0 g
s
.26969 .83089 m .27231 .81285 L .24076 .80963 L p .707 .577 .707 r
F P
0 g
s
.6405 .63915 m .63587 .69403 L .60481 .68951 L p .707 .577 .707 r
F P
0 g
s
.60481 .68951 m .60944 .63463 L .6405 .63915 L p .707 .577 .707 r
F P
0 g
s
.51776 .27588 m .60792 .77866 L .63091 .76697 L p .707 .577 .707 r
F P
0 g
s
.63091 .76697 m .54076 .2642 L .51776 .27588 L p .707 .577 .707 r
F P
0 g
s
.27231 .81285 m .26969 .83089 L .29884 .83068 L p .707 .577 .707 r
F P
0 g
s
.29884 .83068 m .30146 .81264 L .27231 .81285 L p .707 .577 .707 r
F P
0 g
s
.20728 .82135 m .2099 .8033 L .18276 .79448 L p .707 .577 .707 r
F P
0 g
s
.2099 .8033 m .20728 .82135 L .23814 .82767 L p .707 .577 .707 r
F P
0 g
s
.16883 .7198 m .16373 .75593 L .18451 .76627 L p .707 .577 .707 r
F P
0 g
s
.18276 .79448 m .18014 .81253 L .20728 .82135 L p .707 .577 .707 r
F P
0 g
s
.67672 .78839 m .6741 .80643 L .65333 .79598 L p .707 .577 .707 r
F P
0 g
s
.65333 .79598 m .65595 .77794 L .67672 .78839 L p .707 .577 .707 r
F P
0 g
s
.16078 .63171 m .15615 .68659 L .16867 .69635 L p .707 .577 .707 r
F P
0 g
s
.33229 .74421 m .32719 .78034 L .34351 .77365 L p .707 .577 .707 r
F P
0 g
s
.34351 .77365 m .34861 .73753 L .33229 .74421 L p .707 .577 .707 r
F P
0 g
s
.30146 .81264 m .29884 .83068 L .32275 .82707 L p .707 .577 .707 r
F P
0 g
s
.32275 .82707 m .32537 .80902 L .30146 .81264 L p .707 .577 .707 r
F P
0 g
s
.35405 .65047 m .34943 .70535 L .35653 .69657 L p .707 .577 .707 r
F P
0 g
s
.35653 .69657 m .36116 .64169 L .35405 .65047 L p .707 .577 .707 r
F P
0 g
s
.66283 .7232 m .65773 .75933 L .63057 .75063 L p .707 .577 .707 r
F P
0 g
s
.63057 .75063 m .63567 .7145 L .66283 .7232 L p .707 .577 .707 r
F P
0 g
s
.18014 .81253 m .18276 .79448 L .16199 .78403 L p .707 .577 .707 r
F P
0 g
s
.16373 .75593 m .16883 .7198 L .15645 .70883 L p .707 .577 .707 r
F P
0 g
s
.15615 .68659 m .16078 .63171 L .15793 .62197 L p .707 .577 .707 r
F P
0 g
s
.16199 .78403 m .15937 .80208 L .18014 .81253 L p .707 .577 .707 r
F P
0 g
s
.36116 .64169 m .35653 .69657 L .35369 .68683 L p .707 .577 .707 r
F P
0 g
s
.35369 .68683 m .35563 .66371 L p .36116 .64169 L .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .40772 .81657 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.28849 .31197 m .35114 .66131 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.36025 .61564 m .35114 .66131 L .3579 .63675 L .707 .577 .707 r
F
.28849 .31197 m .27124 .30663 L p .34559 .65836 L F P
0 g
s
.34117 .67707 m .34783 .65955 L .34833 .65982 L .707 .577 .707 r
F
.35369 .68683 m .3458 .68068 L p .35114 .66131 L F P
0 g
s
.3579 .63675 m .35563 .66371 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35563 .66371 m .35369 .68683 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .35114 .66131 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .28849 .31197 L p .34694 .65908 L .707 .577 .707 r
F P
0 g
s
.3458 .68068 m .34117 .67707 L p .34833 .65982 L .707 .577 .707 r
F P
0 g
s
.34833 .65982 m .3579 .63675 L .35114 .66131 L .707 .577 .707 r
F
.34833 .65982 m .35114 .66131 L .3458 .68068 L F
.35064 .76461 m .35353 .74413 L p .34861 .73753 L F P
0 g
s
.35353 .74413 m .35574 .72848 L .35234 .73279 L p .707 .577 .707 r
F P
0 g
s
.35234 .73279 m .34861 .73753 L p .35353 .74413 L .707 .577 .707 r
F P
0 g
s
.34861 .73753 m .34351 .77365 L .35064 .76461 L p .707 .577 .707 r
F P
0 g
s
.35064 .76461 m .34788 .75408 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35574 .72848 m .35353 .74413 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35353 .74413 m .35064 .76461 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3406 .70698 L .3452 .71106 L p .707 .577 .707 r
F P
0 g
s
.3452 .71106 m .35298 .71795 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3452 .71106 L .34813 .72493 L .707 .577 .707 r
F
.32484 .61338 m .3266 .61412 L p .32101 .66154 L F P
0 g
s
.32087 .66052 m .32484 .61338 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.3266 .61412 m .32977 .61545 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.27124 .30663 m .32248 .59241 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .32248 .59241 L .34287 .65691 L .707 .577 .707 r
F
.34694 .65908 m .28849 .31197 L .34559 .65836 L F
.32977 .61545 m .34579 .62219 L p .33694 .63814 L F P
0 g
s
.33263 .64591 m .32977 .61545 L .33694 .63814 L .707 .577 .707 r
F
.32021 .66826 m .3266 .61412 L .33263 .64591 L F
.34117 .67707 m .33831 .67587 L p .34154 .6527 L F P
0 g
s
.34287 .65691 m .34117 .67707 L p .34154 .6527 L .707 .577 .707 r
F P
0 g
s
.33831 .67587 m .32021 .66826 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.33263 .64591 m .34579 .62219 L .33831 .67587 L .707 .577 .707 r
F
.35298 .71795 m .35574 .72848 L p .3521 .74032 L F P
0 g
s
.34788 .75408 m .35045 .73589 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .35298 .71795 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.34788 .75408 m .3355 .74311 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35298 .71795 m .35045 .73589 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .34788 .75408 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35764 .80105 m .36139 .8094 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32484 .61338 m .32021 .66826 L .29287 .66125 L p .707 .577 .707 r
F P
0 g
s
.29287 .66125 m .29749 .60638 L .32484 .61338 L p .707 .577 .707 r
F P
0 g
s
.26748 .29828 m .32086 .59598 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32086 .59598 m .35764 .80105 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.35893 .79566 m .34614 .72434 L p .35901 .79643 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .27124 .30663 L p .34604 .72409 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .34604 .72409 L .35901 .79643 L .707 .577 .707 r
F
.34117 .67707 m .34579 .62219 L .35831 .63195 L p F P
0 g
s
.33312 .65172 m .36139 .8094 L p .34671 .66907 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .34287 .65691 L .34671 .66907 L .707 .577 .707 r
F
.34287 .65691 m .33312 .65172 L .34671 .66907 L F
.34579 .62219 m .34287 .65691 L p .34154 .6527 L F P
0 g
s
.33359 .65617 m .31801 .56883 L .33089 .64341 L .707 .577 .707 r
F
.31801 .56883 m .27124 .30663 L .31301 .54248 L F
.31801 .56883 m .31301 .54248 L .33089 .64341 L F
.32248 .59241 m .33312 .65172 L p .34287 .65691 L F P
0 g
s
.27124 .30663 m .26748 .29828 L p .2915 .42902 L .707 .577 .707 r
F P
0 g
s
.33089 .64341 m .31301 .54248 L .2915 .42902 L .707 .577 .707 r
F
.31301 .54248 m .27124 .30663 L .2915 .42902 L F
.3454 .72235 m .33359 .65617 L .33089 .64341 L F
.34604 .72409 m .27124 .30663 L .3454 .72235 L F
.35764 .80105 m .28085 .37286 L p .27759 .28775 L F P
0 g
s
.28085 .37286 m .26748 .29828 L .2701 .29555 L p .707 .577 .707 r
F P
0 g
s
.2701 .29555 m .27759 .28775 L p .28085 .37286 L .707 .577 .707 r
F P
0 g
s
.32021 .66826 m .32087 .66052 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.35901 .79643 m .34604 .72409 L .3454 .72235 L .707 .577 .707 r
F
.36139 .8094 m .35893 .79566 L p .35901 .79643 L F P
0 g
s
.36139 .8094 m .37865 .81474 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .34694 .65908 L .35162 .68689 L .707 .577 .707 r
F
.35162 .68689 m .34694 .65908 L .34559 .65836 L F
.35831 .63195 m .3579 .63675 L p .34833 .65982 L F P
0 g
s
.34783 .65955 m .35831 .63195 L .34833 .65982 L .707 .577 .707 r
F
.35114 .66131 m .35364 .67525 L p .3579 .63675 L F P
0 g
s
.35563 .66371 m .3579 .63675 L p .36008 .63801 L .707 .577 .707 r
F P
0 g
s
.3584 .63227 m .36008 .63801 L p .3579 .63675 L .707 .577 .707 r
F P
0 g
s
.36008 .63801 m .36116 .64169 L p .35563 .66371 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .37865 .81474 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.3579 .63675 m .35831 .63195 L .3584 .63227 L p .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .35364 .67525 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.15645 .70883 m .15135 .74496 L .16373 .75593 L p .707 .577 .707 r
F P
0 g
s
.65595 .77794 m .65333 .79598 L .62619 .78716 L p .707 .577 .707 r
F P
0 g
s
.62619 .78716 m .62881 .76912 L .65595 .77794 L p .707 .577 .707 r
F P
0 g
s
.32537 .80902 m .32275 .82707 L .33907 .8204 L p .707 .577 .707 r
F P
0 g
s
.33907 .8204 m .34169 .80236 L .32537 .80902 L p .707 .577 .707 r
F P
0 g
s
.54076 .2642 m .63091 .76697 L .64103 .75645 L p .707 .577 .707 r
F P
0 g
s
.64103 .75645 m .55087 .25367 L .54076 .2642 L p .707 .577 .707 r
F P
0 g
s
.15937 .80208 m .16199 .78403 L .14963 .77298 L p .707 .577 .707 r
F P
0 g
s
.15793 .62197 m .15331 .67685 L .15615 .68659 L p .707 .577 .707 r
F P
0 g
s
.14963 .77298 m .14701 .79103 L .15937 .80208 L p .707 .577 .707 r
F P
0 g
s
.15135 .74496 m .15645 .70883 L .15369 .69831 L p .707 .577 .707 r
F P
0 g
s
.15331 .67685 m .15793 .62197 L .16503 .61319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15369 .69831 m .14859 .73443 L .15135 .74496 L p .707 .577 .707 r
F P
0 g
s
.34169 .80236 m .33907 .8204 L .3462 .81134 L p .707 .577 .707 r
F P
0 g
s
.3462 .81134 m .34882 .79329 L .34169 .80236 L p .707 .577 .707 r
F P
0 g
s
.14701 .79103 m .14963 .77298 L .14688 .7624 L p .707 .577 .707 r
F P
0 g
s
.16503 .61319 m .16041 .66807 L .15331 .67685 L p .707 .577 .707 r
F P
0 g
s
.14688 .7624 m .14426 .78045 L .14701 .79103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14859 .73443 m .15369 .69831 L .16082 .68926 L p .707 .577 .707 r
F P
0 g
s
.55087 .25367 m .64103 .75645 L .63727 .7481 L p .707 .577 .707 r
F P
0 g
s
.63727 .7481 m .54712 .24533 L .55087 .25367 L p .707 .577 .707 r
F P
0 g
s
.16041 .66807 m .16503 .61319 L .18138 .60624 L p .707 .577 .707 r
F P
0 g
s
.16082 .68926 m .15572 .72539 L .14859 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34882 .79329 m .3462 .81134 L .34345 .80076 L p .707 .577 .707 r
F P
0 g
s
.34345 .80076 m .34607 .78271 L .34882 .79329 L p .707 .577 .707 r
F P
0 g
s
.14426 .78045 m .14688 .7624 L .15401 .75334 L p .707 .577 .707 r
F P
0 g
s
.18138 .60624 m .17676 .66112 L .16041 .66807 L p .707 .577 .707 r
F P
0 g
s
.15401 .75334 m .15139 .77138 L .14426 .78045 L p .707 .577 .707 r
F P
0 g
s
.15572 .72539 m .16082 .68926 L .17714 .68257 L p .707 .577 .707 r
F P
0 g
s
.17676 .66112 m .18138 .60624 L .20539 .60179 L p .707 .577 .707 r
F P
0 g
s
.17714 .68257 m .17204 .7187 L .15572 .72539 L p .707 .577 .707 r
F P
0 g
s
.34607 .78271 m .34345 .80076 L .33109 .7897 L p .707 .577 .707 r
F P
0 g
s
.33109 .7897 m .33371 .77166 L .34607 .78271 L p .707 .577 .707 r
F P
0 g
s
.54712 .24533 m .63727 .7481 L .62001 .74276 L p .707 .577 .707 r
F P
0 g
s
.62001 .74276 m .52986 .23998 L .54712 .24533 L p .707 .577 .707 r
F P
0 g
s
.15139 .77138 m .15401 .75334 L .17033 .74667 L p .707 .577 .707 r
F P
0 g
s
.20539 .60179 m .20076 .65667 L .17676 .66112 L p .707 .577 .707 r
F P
0 g
s
.3406 .70698 m .3355 .74311 L .31472 .73277 L p .707 .577 .707 r
F P
0 g
s
.31472 .73277 m .31982 .69664 L .3406 .70698 L p .707 .577 .707 r
F P
0 g
s
.20076 .65667 m .20539 .60179 L .23469 .60028 L p .707 .577 .707 r
F P
0 g
s
.17204 .7187 m .17714 .68257 L .20106 .67891 L p .707 .577 .707 r
F P
0 g
s
.17033 .74667 m .16771 .76472 L .15139 .77138 L p .707 .577 .707 r
F P
0 g
s
.29749 .60638 m .29287 .66125 L .2618 .65674 L p .707 .577 .707 r
F P
0 g
s
.2618 .65674 m .26643 .60186 L .29749 .60638 L p .707 .577 .707 r
F P
0 g
s
.23007 .65516 m .23469 .60028 L .26643 .60186 L p .707 .577 .707 r
F P
0 g
s
.23469 .60028 m .23007 .65516 L .20076 .65667 L p .707 .577 .707 r
F P
0 g
s
.20106 .67891 m .19596 .71503 L .17204 .7187 L p .707 .577 .707 r
F P
0 g
s
.26643 .60186 m .2618 .65674 L .23007 .65516 L p .707 .577 .707 r
F P
0 g
s
.72825 .65741 m .73287 .60253 L .70181 .59802 L p .707 .577 .707 r
F P
0 g
s
.73287 .60253 m .72825 .65741 L .75999 .65899 L p .707 .577 .707 r
F P
0 g
s
.75999 .65899 m .76461 .60411 L .73287 .60253 L p .707 .577 .707 r
F P
0 g
s
.33371 .77166 m .33109 .7897 L .31032 .77926 L p .707 .577 .707 r
F P
0 g
s
.31032 .77926 m .31294 .76121 L .33371 .77166 L p .707 .577 .707 r
F P
0 g
s
.31982 .69664 m .31472 .73277 L .28756 .72406 L p .707 .577 .707 r
F P
0 g
s
.28756 .72406 m .29266 .68794 L .31982 .69664 L p .707 .577 .707 r
F P
0 g
s
.76461 .60411 m .75999 .65899 L .78929 .65748 L p .707 .577 .707 r
F P
0 g
s
.78929 .65748 m .79391 .6026 L .76461 .60411 L p .707 .577 .707 r
F P
0 g
s
.36775 .79052 m .27759 .28775 L .30059 .27607 L p .707 .577 .707 r
F P
0 g
s
.27759 .28775 m .36775 .79052 L .35764 .80105 L p .707 .577 .707 r
F P
0 g
s
.16771 .76472 m .17033 .74667 L .19424 .74306 L p .707 .577 .707 r
F P
0 g
s
.19596 .71503 m .20106 .67891 L .23022 .67861 L p .707 .577 .707 r
F P
0 g
s
.69719 .6529 m .70181 .59802 L .67446 .59101 L p .707 .577 .707 r
F P
0 g
s
.70181 .59802 m .69719 .6529 L .72825 .65741 L p .707 .577 .707 r
F P
0 g
s
.19424 .74306 m .19162 .7611 L .16771 .76472 L p .707 .577 .707 r
F P
0 g
s
.52986 .23998 m .62001 .74276 L .59094 .74093 L p .707 .577 .707 r
F P
0 g
s
.59094 .74093 m .50079 .23816 L .52986 .23998 L p .707 .577 .707 r
F P
0 g
s
.79391 .6026 m .78929 .65748 L .81329 .65303 L p .707 .577 .707 r
F P
0 g
s
.81329 .65303 m .81792 .59816 L .79391 .6026 L p .707 .577 .707 r
F P
0 g
s
.29266 .68794 m .28756 .72406 L .25669 .71785 L p .707 .577 .707 r
F P
0 g
s
.25669 .71785 m .26179 .68173 L .29266 .68794 L p .707 .577 .707 r
F P
0 g
s
.23022 .67861 m .22512 .71474 L .19596 .71503 L p .707 .577 .707 r
F P
0 g
s
.22512 .71474 m .23022 .67861 L .26179 .68173 L p .707 .577 .707 r
F P
0 g
s
.66984 .64589 m .67446 .59101 L .6535 .5822 L p .707 .577 .707 r
F P
0 g
s
.67446 .59101 m .66984 .64589 L .69719 .6529 L p .707 .577 .707 r
F P
0 g
s
.26179 .68173 m .25669 .71785 L .22512 .71474 L p .707 .577 .707 r
F P
0 g
s
.31294 .76121 m .31032 .77926 L .28318 .77044 L p .707 .577 .707 r
F P
0 g
s
.28318 .77044 m .2858 .75239 L .31294 .76121 L p .707 .577 .707 r
F P
0 g
s
.72275 .71571 m .72785 .67958 L .69698 .67337 L p .707 .577 .707 r
F P
0 g
s
.72785 .67958 m .72275 .71571 L .75432 .71882 L p .707 .577 .707 r
F P
0 g
s
.75432 .71882 m .75942 .6827 L .72785 .67958 L p .707 .577 .707 r
F P
0 g
s
.19162 .7611 m .19424 .74306 L .22339 .74285 L p .707 .577 .707 r
F P
0 g
s
.75942 .6827 m .75432 .71882 L .78349 .71853 L p .707 .577 .707 r
F P
0 g
s
.78349 .71853 m .78859 .6824 L .75942 .6827 L p .707 .577 .707 r
F P
0 g
s
.69188 .7095 m .69698 .67337 L .66982 .66467 L p .707 .577 .707 r
F P
0 g
s
.69698 .67337 m .69188 .7095 L .72275 .71571 L p .707 .577 .707 r
F P
0 g
s
.22339 .74285 m .22077 .76089 L .19162 .7611 L p .707 .577 .707 r
F P
0 g
s
.81792 .59816 m .81329 .65303 L .82964 .64608 L p .707 .577 .707 r
F P
0 g
s
.82964 .64608 m .83427 .5912 L .81792 .59816 L p .707 .577 .707 r
F P
0 g
s
.2858 .75239 m .28318 .77044 L .25232 .76411 L p .707 .577 .707 r
F P
0 g
s
.25232 .76411 m .25494 .74606 L .2858 .75239 L p .707 .577 .707 r
F P
0 g
s
.6535 .5822 m .64888 .63708 L .66984 .64589 L p .707 .577 .707 r
F P
0 g
s
.22077 .76089 m .22339 .74285 L .25494 .74606 L p .707 .577 .707 r
F P
0 g
s
.30059 .27607 m .39074 .77884 L .36775 .79052 L p .707 .577 .707 r
F P
0 g
s
.39074 .77884 m .30059 .27607 L .33421 .26438 L p .707 .577 .707 r
F P
0 g
s
.78859 .6824 m .78349 .71853 L .8074 .71486 L p .707 .577 .707 r
F P
0 g
s
.8074 .71486 m .8125 .67874 L .78859 .6824 L p .707 .577 .707 r
F P
0 g
s
.66982 .66467 m .66472 .7008 L .69188 .7095 L p .707 .577 .707 r
F P
0 g
s
.71835 .75236 m .72097 .73432 L .69012 .72799 L p .707 .577 .707 r
F P
0 g
s
.72097 .73432 m .71835 .75236 L .7499 .75558 L p .707 .577 .707 r
F P
0 g
s
.7499 .75558 m .75252 .73754 L .72097 .73432 L p .707 .577 .707 r
F P
0 g
s
.25494 .74606 m .25232 .76411 L .22077 .76089 L p .707 .577 .707 r
F P
0 g
s
.66472 .7008 m .66982 .66467 L .64904 .65433 L p .707 .577 .707 r
F P
0 g
s
.64888 .63708 m .6535 .5822 L .64099 .57245 L p .707 .577 .707 r
F P
0 g
s
.75252 .73754 m .7499 .75558 L .77906 .75537 L p .707 .577 .707 r
F P
0 g
s
.77906 .75537 m .78168 .73733 L .75252 .73754 L p .707 .577 .707 r
F P
0 g
s
.6875 .74604 m .69012 .72799 L .66298 .71917 L p .707 .577 .707 r
F P
0 g
s
.69012 .72799 m .6875 .74604 L .71835 .75236 L p .707 .577 .707 r
F P
0 g
s
.50079 .23816 m .59094 .74093 L .5529 .74281 L p .707 .577 .707 r
F P
0 g
s
.5529 .74281 m .46275 .24004 L .50079 .23816 L p .707 .577 .707 r
F P
0 g
s
.66298 .71917 m .66036 .73722 L .6875 .74604 L p .707 .577 .707 r
F P
0 g
s
.64904 .65433 m .64394 .69045 L .66472 .7008 L p .707 .577 .707 r
F P
0 g
s
.78168 .73733 m .77906 .75537 L .80297 .75176 L p .707 .577 .707 r
F P
0 g
s
.80297 .75176 m .80558 .73371 L .78168 .73733 L p .707 .577 .707 r
F P
0 g
s
.64099 .57245 m .63637 .62733 L .64888 .63708 L p .707 .577 .707 r
F P
0 g
s
.8125 .67874 m .8074 .71486 L .82372 .70818 L p .707 .577 .707 r
F P
0 g
s
.82372 .70818 m .82882 .67205 L .8125 .67874 L p .707 .577 .707 r
F P
0 g
s
.66036 .73722 m .66298 .71917 L .64221 .70872 L p .707 .577 .707 r
F P
0 g
s
.83427 .5912 m .82964 .64608 L .83675 .6373 L p .707 .577 .707 r
F P
0 g
s
.83675 .6373 m .84137 .58242 L .83427 .5912 L p .707 .577 .707 r
F P
0 g
s
.64394 .69045 m .64904 .65433 L .63666 .64336 L p .707 .577 .707 r
F P
0 g
s
.64221 .70872 m .63959 .72677 L .66036 .73722 L p .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .38546 .55016 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .4216 .57134 L .39733 .57013 L p .707 .577 .707 r
F P
0 g
s
.46533 .7566 m .42437 .76715 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4216 .57134 m .41867 .60606 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .46533 .7566 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4216 .57134 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.44941 .57918 m .43782 .60317 L .44925 .57744 L .707 .577 .707 r
F
.46533 .7566 m .44032 .6171 L p .44941 .57918 L F P
0 g
s
.44032 .6171 m .43782 .60317 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4505 .57463 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.4505 .57463 m .4509 .56983 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .46533 .7566 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.45169 .56969 m .4509 .56983 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.41946 .24544 m .46652 .50784 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.46652 .50784 m .50962 .74821 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .47491 .56538 L .45169 .56969 L p .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .45169 .56969 L .45136 .57103 L .707 .577 .707 r
F
.44628 .62471 m .47028 .62026 L p .45136 .57103 L F P
0 g
s
.4505 .57463 m .44628 .62471 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.44628 .62471 m .4505 .57463 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .41946 .24544 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .37517 .25383 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .43782 .60317 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .44628 .62471 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .41698 .62622 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .41867 .60606 L p .38986 .56976 L .707 .577 .707 r
F P
0 g
s
.39733 .57013 m .38986 .56976 L p .41867 .60606 L .707 .577 .707 r
F P
0 g
s
.33421 .26438 m .37517 .25383 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .33421 .26438 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .39074 .77884 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .42437 .76715 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38986 .56976 m .38524 .62464 L .41264 .626 L p .707 .577 .707 r
F P
0 g
s
.41264 .626 m .41698 .62622 L p .40018 .59125 L .707 .577 .707 r
F P
0 g
s
.40018 .59125 m .38986 .56976 L .41264 .626 L .707 .577 .707 r
F
.33421 .26438 m .38546 .55016 L p .35684 .4703 L F P
0 g
s
.63637 .62733 m .64099 .57245 L .63814 .5627 L p .707 .577 .707 r
F P
0 g
s
.46275 .24004 m .5529 .74281 L .50962 .74821 L p .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .41946 .24544 L .46275 .24004 L p .707 .577 .707 r
F P
0 g
s
.63666 .64336 m .63156 .67948 L .64394 .69045 L p .707 .577 .707 r
F P
0 g
s
.80558 .73371 m .80297 .75176 L .81928 .74509 L p .707 .577 .707 r
F P
0 g
s
.81928 .74509 m .8219 .72704 L .80558 .73371 L p .707 .577 .707 r
F P
0 g
s
.63959 .72677 m .64221 .70872 L .62984 .69767 L p .707 .577 .707 r
F P
0 g
s
.82882 .67205 m .82372 .70818 L .83085 .69913 L p .707 .577 .707 r
F P
0 g
s
.83085 .69913 m .83595 .663 L .82882 .67205 L p .707 .577 .707 r
F P
0 g
s
.63814 .5627 m .63352 .61758 L .63637 .62733 L p .707 .577 .707 r
F P
0 g
s
.62984 .69767 m .62722 .71572 L .63959 .72677 L p .707 .577 .707 r
F P
0 g
s
.63156 .67948 m .63666 .64336 L .6339 .63283 L p .707 .577 .707 r
F P
0 g
s
.84137 .58242 m .83675 .6373 L .8339 .62756 L p .707 .577 .707 r
F P
0 g
s
.8339 .62756 m .83852 .57268 L .84137 .58242 L p .707 .577 .707 r
F P
0 g
s
.63352 .61758 m .63814 .5627 L .64524 .55393 L p .707 .577 .707 r
F P
0 g
s
.6339 .63283 m .6288 .66896 L .63156 .67948 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.8219 .72704 m .81928 .74509 L .82642 .73603 L p .707 .577 .707 r
F P
0 g
s
.82642 .73603 m .82904 .71798 L .8219 .72704 L p .707 .577 .707 r
F P
0 g
s
.62722 .71572 m .62984 .69767 L .62709 .68709 L p .707 .577 .707 r
F P
0 g
s
.62709 .68709 m .62447 .70514 L .62722 .71572 L p .707 .577 .707 r
F P
0 g
s
.83595 .663 m .83085 .69913 L .82809 .68861 L p .707 .577 .707 r
F P
0 g
s
.82809 .68861 m .83319 .65248 L .83595 .663 L p .707 .577 .707 r
F P
0 g
s
.64524 .55393 m .64062 .6088 L .63352 .61758 L p .707 .577 .707 r
F P
0 g
s
.6288 .66896 m .6339 .63283 L .64104 .62378 L p .707 .577 .707 r
F P
0 g
s
.83852 .57268 m .8339 .62756 L .82139 .6178 L p .707 .577 .707 r
F P
0 g
s
.82139 .6178 m .82601 .56293 L .83852 .57268 L p .707 .577 .707 r
F P
0 g
s
.64062 .6088 m .64524 .55393 L .6616 .54697 L p .707 .577 .707 r
F P
0 g
s
.38524 .62464 m .38986 .56976 L .3588 .56525 L p .707 .577 .707 r
F P
0 g
s
.64104 .62378 m .63593 .65991 L .6288 .66896 L p .707 .577 .707 r
F P
0 g
s
.82904 .71798 m .82642 .73603 L .82367 .72545 L p .707 .577 .707 r
F P
0 g
s
.82367 .72545 m .82629 .7074 L .82904 .71798 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35418 .62013 m .3588 .56525 L .33145 .55824 L p .707 .577 .707 r
F P
0 g
s
.3588 .56525 m .35418 .62013 L .38524 .62464 L p .707 .577 .707 r
F P
0 g
s
.62447 .70514 m .62709 .68709 L .63422 .67803 L p .707 .577 .707 r
F P
0 g
s
.63422 .67803 m .6316 .69607 L .62447 .70514 L p .707 .577 .707 r
F P
0 g
s
.83319 .65248 m .82809 .68861 L .81572 .67764 L p .707 .577 .707 r
F P
0 g
s
.81572 .67764 m .82082 .64151 L .83319 .65248 L p .707 .577 .707 r
F P
0 g
s
.6616 .54697 m .65697 .60185 L .64062 .6088 L p .707 .577 .707 r
F P
0 g
s
.82601 .56293 m .82139 .6178 L .80043 .60899 L p .707 .577 .707 r
F P
0 g
s
.80043 .60899 m .80505 .55411 L .82601 .56293 L p .707 .577 .707 r
F P
0 g
s
.63593 .65991 m .64104 .62378 L .65736 .6171 L p .707 .577 .707 r
F P
0 g
s
.32683 .61312 m .33145 .55824 L .31049 .54943 L p .707 .577 .707 r
F P
0 g
s
.33145 .55824 m .32683 .61312 L .35418 .62013 L p .707 .577 .707 r
F P
0 g
s
.65697 .60185 m .6616 .54697 L .6856 .54252 L p .707 .577 .707 r
F P
0 g
s
.37974 .68915 m .38484 .65302 L .35397 .64681 L p .707 .577 .707 r
F P
0 g
s
.38484 .65302 m .37974 .68915 L .41131 .69226 L p .707 .577 .707 r
F P
0 g
s
.41131 .69226 m .41641 .65613 L .38484 .65302 L p .707 .577 .707 r
F P
0 g
s
.41641 .65613 m .41131 .69226 L .44048 .69197 L p .707 .577 .707 r
F P
0 g
s
.44048 .69197 m .44558 .65584 L .41641 .65613 L p .707 .577 .707 r
F P
0 g
s
.34887 .68294 m .35397 .64681 L .32681 .63811 L p .707 .577 .707 r
F P
0 g
s
.35397 .64681 m .34887 .68294 L .37974 .68915 L p .707 .577 .707 r
F P
0 g
s
.65736 .6171 m .65226 .65323 L .63593 .65991 L p .707 .577 .707 r
F P
0 g
s
.82629 .7074 m .82367 .72545 L .8113 .71439 L p .707 .577 .707 r
F P
0 g
s
.8113 .71439 m .81392 .69635 L .82629 .7074 L p .707 .577 .707 r
F P
0 g
s
.47491 .56538 m .47028 .62026 L .48663 .61331 L p .707 .577 .707 r
F P
0 g
s
.48663 .61331 m .49126 .55843 L .47491 .56538 L p .707 .577 .707 r
F P
0 g
s
.6316 .69607 m .63422 .67803 L .65054 .67136 L p .707 .577 .707 r
F P
0 g
s
.31049 .54943 m .30587 .60431 L .32683 .61312 L p .707 .577 .707 r
F P
0 g
s
.80505 .55411 m .80043 .60899 L .77308 .60199 L p .707 .577 .707 r
F P
0 g
s
.77308 .60199 m .7777 .54711 L .80505 .55411 L p .707 .577 .707 r
F P
0 g
s
.6856 .54252 m .68098 .5974 L .65697 .60185 L p .707 .577 .707 r
F P
0 g
s
.82082 .64151 m .81572 .67764 L .79493 .66729 L p .707 .577 .707 r
F P
0 g
s
.79493 .66729 m .80003 .63117 L .82082 .64151 L p .707 .577 .707 r
F P
0 g
s
.44558 .65584 m .44048 .69197 L .46439 .6883 L p .707 .577 .707 r
F P
0 g
s
.46439 .6883 m .46949 .65217 L .44558 .65584 L p .707 .577 .707 r
F P
0 g
s
.32681 .63811 m .32171 .67423 L .34887 .68294 L p .707 .577 .707 r
F P
0 g
s
.65054 .67136 m .64792 .68941 L .6316 .69607 L p .707 .577 .707 r
F P
0 g
s
.30587 .60431 m .31049 .54943 L .29798 .53968 L p .707 .577 .707 r
F P
0 g
s
.32171 .67423 m .32681 .63811 L .30603 .62776 L p .707 .577 .707 r
F P
0 g
s
.68098 .5974 m .6856 .54252 L .7149 .54101 L p .707 .577 .707 r
F P
0 g
s
.65226 .65323 m .65736 .6171 L .68127 .61343 L p .707 .577 .707 r
F P
0 g
s
.37534 .73564 m .37796 .71759 L .34711 .71126 L p .707 .577 .707 r
F P
0 g
s
.37796 .71759 m .37534 .73564 L .40689 .73885 L p .707 .577 .707 r
F P
0 g
s
.40689 .73885 m .40951 .72081 L .37796 .71759 L p .707 .577 .707 r
F P
0 g
s
.40951 .72081 m .40689 .73885 L .43605 .73864 L p .707 .577 .707 r
F P
0 g
s
.43605 .73864 m .43867 .7206 L .40951 .72081 L p .707 .577 .707 r
F P
0 g
s
.34449 .72931 m .34711 .71126 L .31997 .70244 L p .707 .577 .707 r
F P
0 g
s
.34711 .71126 m .34449 .72931 L .37534 .73564 L p .707 .577 .707 r
F P
0 g
s
.7777 .54711 m .77308 .60199 L .74202 .59747 L p .707 .577 .707 r
F P
0 g
s
.74202 .59747 m .74664 .54259 L .7777 .54711 L p .707 .577 .707 r
F P
0 g
s
.30603 .62776 m .30093 .66389 L .32171 .67423 L p .707 .577 .707 r
F P
0 g
s
.31997 .70244 m .31735 .72049 L .34449 .72931 L p .707 .577 .707 r
F P
0 g
s
.71028 .59589 m .7149 .54101 L .74664 .54259 L p .707 .577 .707 r
F P
0 g
s
.7149 .54101 m .71028 .59589 L .68098 .5974 L p .707 .577 .707 r
F P
0 g
s
.68127 .61343 m .67617 .64956 L .65226 .65323 L p .707 .577 .707 r
F P
0 g
s
.81392 .69635 m .8113 .71439 L .79053 .70395 L p .707 .577 .707 r
F P
0 g
s
.79053 .70395 m .79315 .6859 L .81392 .69635 L p .707 .577 .707 r
F P
0 g
s
.29798 .53968 m .29336 .59455 L .30587 .60431 L p .707 .577 .707 r
F P
0 g
s
.74664 .54259 m .74202 .59747 L .71028 .59589 L p .707 .577 .707 r
F P
0 g
s
.46949 .65217 m .46439 .6883 L .48071 .68162 L p .707 .577 .707 r
F P
0 g
s
.48071 .68162 m .48581 .64549 L .46949 .65217 L p .707 .577 .707 r
F P
0 g
s
.43867 .7206 m .43605 .73864 L .45996 .73503 L p .707 .577 .707 r
F P
0 g
s
.45996 .73503 m .46257 .71698 L .43867 .7206 L p .707 .577 .707 r
F P
0 g
s
.49126 .55843 m .48663 .61331 L .49374 .60453 L p .707 .577 .707 r
F P
0 g
s
.49374 .60453 m .49836 .54965 L .49126 .55843 L p .707 .577 .707 r
F P
0 g
s
.64792 .68941 m .65054 .67136 L .67445 .66775 L p .707 .577 .707 r
F P
0 g
s
.80003 .63117 m .79493 .66729 L .76778 .65859 L p .707 .577 .707 r
F P
0 g
s
.76778 .65859 m .77288 .62246 L .80003 .63117 L p .707 .577 .707 r
F P
0 g
s
.31735 .72049 m .31997 .70244 L .2992 .692 L p .707 .577 .707 r
F P
0 g
s
.67617 .64956 m .68127 .61343 L .71044 .61314 L p .707 .577 .707 r
F P
0 g
s
.30093 .66389 m .30603 .62776 L .29365 .61679 L p .707 .577 .707 r
F P
0 g
s
.67445 .66775 m .67183 .68579 L .64792 .68941 L p .707 .577 .707 r
F P
0 g
s
.29336 .59455 m .29798 .53968 L .29513 .52993 L p .707 .577 .707 r
F P
0 g
s
.2992 .692 m .29658 .71004 L .31735 .72049 L p .707 .577 .707 r
F P
0 g
s
.77288 .62246 m .76778 .65859 L .7369 .65238 L p .707 .577 .707 r
F P
0 g
s
.7369 .65238 m .742 .61625 L .77288 .62246 L p .707 .577 .707 r
F P
0 g
s
.71044 .61314 m .70534 .64927 L .67617 .64956 L p .707 .577 .707 r
F P
0 g
s
.29365 .61679 m .28855 .65292 L .30093 .66389 L p .707 .577 .707 r
F P
0 g
s
.70534 .64927 m .71044 .61314 L .742 .61625 L p .707 .577 .707 r
F P
0 g
s
.79315 .6859 m .79053 .70395 L .76339 .69513 L p .707 .577 .707 r
F P
0 g
s
.76339 .69513 m .76601 .67708 L .79315 .6859 L p .707 .577 .707 r
F P
0 g
s
.742 .61625 m .7369 .65238 L .70534 .64927 L p .707 .577 .707 r
F P
0 g
s
.46257 .71698 m .45996 .73503 L .47627 .72836 L p .707 .577 .707 r
F P
0 g
s
.47627 .72836 m .47889 .71032 L .46257 .71698 L p .707 .577 .707 r
F P
0 g
s
.67183 .68579 m .67445 .66775 L .70361 .66754 L p .707 .577 .707 r
F P
0 g
s
.29658 .71004 m .2992 .692 L .28683 .68094 L p .707 .577 .707 r
F P
0 g
s
.29513 .52993 m .29051 .58481 L .29336 .59455 L p .707 .577 .707 r
F P
0 g
s
.48581 .64549 m .48071 .68162 L .48784 .67257 L p .707 .577 .707 r
F P
0 g
s
.48784 .67257 m .49294 .63644 L .48581 .64549 L p .707 .577 .707 r
F P
0 g
s
.70361 .66754 m .70099 .68558 L .67183 .68579 L p .707 .577 .707 r
F P
0 g
s
.49836 .54965 m .49374 .60453 L .49089 .59479 L p .707 .577 .707 r
F P
0 g
s
.49089 .59479 m .49551 .53991 L .49836 .54965 L p .707 .577 .707 r
F P
0 g
s
.28683 .68094 m .28421 .69899 L .29658 .71004 L p .707 .577 .707 r
F P
0 g
s
.28855 .65292 m .29365 .61679 L .29089 .60627 L p .707 .577 .707 r
F P
0 g
s
.76601 .67708 m .76339 .69513 L .73254 .6888 L p .707 .577 .707 r
F P
0 g
s
.73254 .6888 m .73516 .67075 L .76601 .67708 L p .707 .577 .707 r
F P
0 g
s
.70099 .68558 m .70361 .66754 L .73516 .67075 L p .707 .577 .707 r
F P
0 g
s
.29051 .58481 m .29513 .52993 L .30223 .52115 L p .707 .577 .707 r
F P
0 g
s
.73516 .67075 m .73254 .6888 L .70099 .68558 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29089 .60627 m .28579 .64239 L .28855 .65292 L p .707 .577 .707 r
F P
0 g
s
.47889 .71032 m .47627 .72836 L .48341 .7193 L p .707 .577 .707 r
F P
0 g
s
.48341 .7193 m .48603 .70125 L .47889 .71032 L p .707 .577 .707 r
F P
0 g
s
.28421 .69899 m .28683 .68094 L .28408 .67036 L p .707 .577 .707 r
F P
0 g
s
.30223 .52115 m .29761 .57603 L .29051 .58481 L p .707 .577 .707 r
F P
0 g
s
.49294 .63644 m .48784 .67257 L .48508 .66204 L p .707 .577 .707 r
F P
0 g
s
.48508 .66204 m .49018 .62592 L .49294 .63644 L p .707 .577 .707 r
F P
0 g
s
.28408 .67036 m .28146 .68841 L .28421 .69899 L p .707 .577 .707 r
F P
0 g
s
.49551 .53991 m .49089 .59479 L .47837 .58503 L p .707 .577 .707 r
F P
0 g
s
.47837 .58503 m .483 .53015 L .49551 .53991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28579 .64239 m .29089 .60627 L .29802 .59722 L p .707 .577 .707 r
F P
0 g
s
.29761 .57603 m .30223 .52115 L .31859 .5142 L p .707 .577 .707 r
F P
0 g
s
.29802 .59722 m .29292 .63335 L .28579 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48603 .70125 m .48341 .7193 L .48066 .70872 L p .707 .577 .707 r
F P
0 g
s
.48066 .70872 m .48328 .69067 L .48603 .70125 L p .707 .577 .707 r
F P
0 g
s
.28146 .68841 m .28408 .67036 L .29121 .6613 L p .707 .577 .707 r
F P
0 g
s
.31859 .5142 m .31396 .56908 L .29761 .57603 L p .707 .577 .707 r
F P
0 g
s
.49018 .62592 m .48508 .66204 L .47271 .65107 L p .707 .577 .707 r
F P
0 g
s
.47271 .65107 m .47781 .61495 L .49018 .62592 L p .707 .577 .707 r
F P
0 g
s
.483 .53015 m .47837 .58503 L .45742 .57622 L p .707 .577 .707 r
F P
0 g
s
.45742 .57622 m .46204 .52134 L .483 .53015 L p .707 .577 .707 r
F P
0 g
s
.29121 .6613 m .28859 .67934 L .28146 .68841 L p .707 .577 .707 r
F P
0 g
s
.29292 .63335 m .29802 .59722 L .31435 .59053 L p .707 .577 .707 r
F P
0 g
s
.31396 .56908 m .31859 .5142 L .34259 .50975 L p .707 .577 .707 r
F P
0 g
s
.31435 .59053 m .30925 .62666 L .29292 .63335 L p .707 .577 .707 r
F P
0 g
s
.48328 .69067 m .48066 .70872 L .46829 .69767 L p .707 .577 .707 r
F P
0 g
s
.46829 .69767 m .47091 .67962 L .48328 .69067 L p .707 .577 .707 r
F P
0 g
s
.46204 .52134 m .45742 .57622 L .43007 .56922 L p .707 .577 .707 r
F P
0 g
s
.43007 .56922 m .43469 .51434 L .46204 .52134 L p .707 .577 .707 r
F P
0 g
s
.28859 .67934 m .29121 .6613 L .30753 .65463 L p .707 .577 .707 r
F P
0 g
s
.34259 .50975 m .33796 .56463 L .31396 .56908 L p .707 .577 .707 r
F P
0 g
s
.47781 .61495 m .47271 .65107 L .45192 .64073 L p .707 .577 .707 r
F P
0 g
s
.45192 .64073 m .45702 .6046 L .47781 .61495 L p .707 .577 .707 r
F P
0 g
s
.33796 .56463 m .34259 .50975 L .37189 .50824 L p .707 .577 .707 r
F P
0 g
s
.30925 .62666 m .31435 .59053 L .33826 .58687 L p .707 .577 .707 r
F P
0 g
s
.30753 .65463 m .30491 .67268 L .28859 .67934 L p .707 .577 .707 r
F P
0 g
s
.43469 .51434 m .43007 .56922 L .39901 .5647 L p .707 .577 .707 r
F P
0 g
s
.39901 .5647 m .40363 .50982 L .43469 .51434 L p .707 .577 .707 r
F P
0 g
s
.36727 .56312 m .37189 .50824 L .40363 .50982 L p .707 .577 .707 r
F P
0 g
s
.37189 .50824 m .36727 .56312 L .33796 .56463 L p .707 .577 .707 r
F P
0 g
s
.33826 .58687 m .33316 .62299 L .30925 .62666 L p .707 .577 .707 r
F P
0 g
s
.40363 .50982 m .39901 .5647 L .36727 .56312 L p .707 .577 .707 r
F P
0 g
s
.47091 .67962 m .46829 .69767 L .44752 .68722 L p .707 .577 .707 r
F P
0 g
s
.44752 .68722 m .45014 .66917 L .47091 .67962 L p .707 .577 .707 r
F P
0 g
s
.45702 .6046 m .45192 .64073 L .42476 .63203 L p .707 .577 .707 r
F P
0 g
s
.42476 .63203 m .42986 .5959 L .45702 .6046 L p .707 .577 .707 r
F P
0 g
s
.30491 .67268 m .30753 .65463 L .33144 .65102 L p .707 .577 .707 r
F P
0 g
s
.33316 .62299 m .33826 .58687 L .36743 .58657 L p .707 .577 .707 r
F P
0 g
s
.33144 .65102 m .32882 .66906 L .30491 .67268 L p .707 .577 .707 r
F P
0 g
s
.42986 .5959 m .42476 .63203 L .39389 .62581 L p .707 .577 .707 r
F P
0 g
s
.39389 .62581 m .39899 .58969 L .42986 .5959 L p .707 .577 .707 r
F P
0 g
s
.36743 .58657 m .36233 .6227 L .33316 .62299 L p .707 .577 .707 r
F P
0 g
s
.36233 .6227 m .36743 .58657 L .39899 .58969 L p .707 .577 .707 r
F P
0 g
s
.39899 .58969 m .39389 .62581 L .36233 .6227 L p .707 .577 .707 r
F P
0 g
s
.45014 .66917 m .44752 .68722 L .42038 .6784 L p .707 .577 .707 r
F P
0 g
s
.42038 .6784 m .423 .66035 L .45014 .66917 L p .707 .577 .707 r
F P
0 g
s
.32882 .66906 m .33144 .65102 L .36059 .65081 L p .707 .577 .707 r
F P
0 g
s
.36059 .65081 m .35798 .66885 L .32882 .66906 L p .707 .577 .707 r
F P
0 g
s
.423 .66035 m .42038 .6784 L .38953 .67207 L p .707 .577 .707 r
F P
0 g
s
.38953 .67207 m .39214 .65402 L .423 .66035 L p .707 .577 .707 r
F P
0 g
s
.35798 .66885 m .36059 .65081 L .39214 .65402 L p .707 .577 .707 r
F P
0 g
s
.39214 .65402 m .38953 .67207 L .35798 .66885 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool9002;Ool007ioo`/0
00UJEPL008Aoo`00MGoo2@006eYF0`00PGoo001aOol40002FUH00`00FUIJEP0EFUH00`00FUIJEP0:
FUJ1Ool006eoo`@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo07ioo`00JGoo10002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0OWoo001UOol4000?FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1nOol0065oo`@001=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07ioo`00GWoo0`002UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Ogoo001KOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1mOol005Moo`@000AJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo07eoo`00E7oo0`002EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0OGoo001BOol200000eYF
001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1mOol0051oo`8000=JEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo07eoo`00CWoo0P001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00OWoo
001=Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OWoo001=Ool20007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001m
Ool004aoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001mOol004eoo`9JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001mOol004eoo`9JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07]oo`00CGoo0eYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Ngoo001=Ool3FUH00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1kOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001lOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00O7oo
001=Ool01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001=Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001>Ool3FUH0
0`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1jOol004ioo`=JEP03001J
EUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007]oo`00CWoo0eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Ngoo001>Ool01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8007]oo`00CWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Uo
o`00Cgoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Yoo`00Cgoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001jOol004moo`04001JEUYF0007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001iOol0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001i
Ool0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001@Ool01000FUIJ
EP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00N7oo001AOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP8007Qoo`00DGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Io
o`00DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00
DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00DGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04
001JEUYFFUH2001gOol0059oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1e
Ool0059oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001fOol005=oo`04
001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00MWoo001COol01000FUIJEP001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8007Eoo`00E7oo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8007Aoo`00EGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2001dOol005Eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1bOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1b
Ool005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1bOol0
05Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00Lgoo001FOol01000FUIJEP001UYF3P002EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol0
1P00FUIJEUYF001JEP@00003FUH005YF00IJEP03001JEUYF009JEPX000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo075oo`00EWoo00<005YFFUH0
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol300000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001bOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001bOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
071oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0L7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80075oo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001]oo`T004eoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH2000DOol70004FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`0=Ool50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`0;Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000jOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`09Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000hOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P002Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00P00=7oo001BOol00`00FUH00004FUH01000FUIJEUYF6@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00DWoo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH010000UYF1@000eYF1P001UYF
00<005YFFUH00eYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`06Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool0059oo`04001JEP00
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70007FUH00`00FUH000030002FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00H0
05YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40009FUH00`00FUIJEP02FUH30004
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF009JEP03001J
EUYF0080009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20007Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH30003FUH20008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1goo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF
400000=JEP00FUH02eYF00<005YFFUH00UYF00<005YFFUH00eYF0P000eYF0P0025YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol01Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YFFUIJEP8002eoo`00DWoo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001eYF
00D005YFFUIJEP0000IJEP03001JEP00009JEP8000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo00Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005=o
o`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0
00=JEP05001JEUYFFUH00005FUH01000FUIJEUYF100025YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Goo001COol30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool00`00FUH00003FUH00`00FUIJEP03FUHE0006FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003moo`P000aoo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJ
EP03001JEUYF009JEP<000UJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool0
0`00FUH00003FUH00`00FUH000030005FUH70004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JERioo`00=goo20000eYF00<005YFFUH00UYF2@000goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol00goo00<005YF00000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH^Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP8000YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00=oo`04001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF0P002UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000P001UYF00<005YFFUH01EYF00<005YF
FUH01UYF10001EYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8002ioo`00;Woo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH00eYF40000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF10002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0017oo00H005YFFUIJEP00FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0017oo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00D000MJEP03001JEUYF00AJEP03001JEP00009JEP8002ioo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YF
FUIJEQL000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool01000FUH000000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH015YF00<005YF
FUH00`00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH00003FUH400000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00002eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol00Woo0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH00UYF
0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH005YF1@000UYF00D005YFFUIJEP0000IJEP03001JEUYF00AJEPD000=J
EP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`02Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH2000_Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP000002FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50007
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEPD000UJEP<00003FUH0
05YF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEP0002moo`00;7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH0
0eYF00<005YF00000`001UYF00<005YFFUH015YF10002eYF0`001EYF00L005YFFUIJEP00FUH0000;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH00000031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1@0000=JEP00
FUH025YF00<005YFFUH02EYF00<005YFFUH00P000eYF00@005YFFUIJEP8000aJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo
000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH02EYF
0P000eYF0P0000=JEP00FUH00UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF0000<Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF600035YF00<005YFFUH0
1@000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP000000
0eYF1P000UYF0P000Woo1P000eYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YFFUH00eYF5@001UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH040000eYF00L005YF001JEP00FUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000005YF0`0015YF00<005YFFUH0
0UYF0P001Woo2@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YF00000`001eYF00<005YF00000`000Woo1@0000=o
o`0000000P000UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF100015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00000035YF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP80009JEP<0009JEP03001JEUYF00=JEP8000ioo`T000EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002]oo`03001JEP00009JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00=JEPl000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000aJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00<000EJEP04001JEP00
000EOol400000eYF001JEP05FUH01000FUIJEUYF0P00;goo000[Ool00`00FUH000030005FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40005FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`001UYF00@005YFFUIJEP800003FUH005YF00]J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH@000DOol2
0006FUH01000FUIJEUYF0P00;goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001EYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00
3goo0P000eYF00L005YFFUIJEP00FUH0000_Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEPL000IJEP03001JEUYF00AJEPT0
00AJEP03001JEUYF00EJEP<0009JEP09001JEUYFFUH005YF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@000eoo`800003FUH005YF009JEP03001JEP0002moo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF200000=JEP00FUH01eYF00@005YF001JEP80009JEP03001JEUYF009JEP80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPH000IJEP03001JEUYF00<000=JEP80009JEP8000aJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;Ool20003FUH00`00FUH0000_Ool002]oo`80
00=JEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEPL000=JEP04001JEP000004FUH00`00FUIJ
EP04FUH300000eYF001JEP06FUH01000FUIJEUYF0`000eYF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000007Ool50002FUH2000`Ool002aoo`05001JEUYF001JEP050003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP060005FUH00`00FUIJEP04FUH00`00FUIJEP050004FUH0
0`00FUIJEP0500000eYF001JEP05FUH300000eYF001JEP04FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF1`000UYF00<005YFFUH01000<7oo000/Ool00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
0eYF00000003FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF300000=JEP00FUH01eYF0`001EYF
00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP04001JEUYFFUH70002FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00EJEP05001JEUYFFUH00006FUH0
1000FUIJEUYF50000eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEPH00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0`00<7oo000/Ool20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40006FUH2
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF0`0000=JEP00FUH00UYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0009JEP80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00<000=J
EP03001JEP00031oo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00`000eYF00<005YF00000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH00P000eYF0P000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF1`0025YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`0000AJEP00FUH0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP05FUH200000eYF0000000aOol002]oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEP00
00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00=JEP800003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYF001JEP00FUH000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000aOol002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP04001JEUYFFUH30003FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH20004FUH200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01@00FUIJEUYF00001UYF
1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP05001JEUYFFUH0000bOol0
02]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF008000=JEP03001JEUYF00AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00003FUH300000eYF001JEP05FUH00`00FUH00002FUH50002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0`Ool002Yoo`03001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP06FUH0
0`00FUIJEP040003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH20004FUH00`00FUIJEP0;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00P001UYF00<005YF
FUH00`0017oo2@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP80035oo`00:Woo00<005YF
00000eYF100047oo2@0015YF00<005YFFUH01EYF0`001UYF00<005YFFUH015YF5`000eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000EJEP<0009JEP03001JEUYF009JEP8000Uooa8000Eoo`03001JEUYF0080035oo`00:Woo
00@005YF001JEPD001Eoo`<0009oo`H000IJEP03001JEUYF008000=JEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH00`00FUH000020004FUH20009
Ool5000COol4000aOol002Yoo`04001JEP000002FUH00`00FUIJEP02000BOol50007Ool20004FUH0
0`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006FUH01000FUIJEUYF0`0000AJEP00FUH000Uoo`D001=oo`@0035oo`00:Woo0P00
0eYF00<005YFFUH00eYF0P0047oo1@002Goo0`0000=JEP00FUH015YF1@001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP03001JEUYF00EJEPD000Uoo`<0019oo`80
0003FUH00000039oo`00:Woo0P000eYF00<005YFFUH00eYF00@005YF000000ioo`D000aoo`8000EJ
EP05001JEUYF001JEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF0P0000=JEP00FUH01eYF00@005YFFUIJEPT0015oo`@000=JEP80039oo`00:Woo0P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP<000aoo`<000moo`8000=JEP04001JEUYF0002FUH00`00FUIJEP07
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1@002eYF00<005YFFUH02eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF009JEQ40009J
EP07001JEUYFFUH005YF0000<Woo000[Ool01@00FUIJEUYF00001EYF00<005YFFUH015YF1P006Woo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00EJEP03001JEP0000l000AJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00=JEPT000AJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00<goo000[Ool01@00FUIJEUYF000015YF5`0047oo1@000UYF00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJEP`000MJEP03001JEP00
00H0009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=7oo000/Ool00`00FUH000050003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHG0003FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF20002UYF00<005YFFUH01UYF00<005YFFUH01EYF
10001EYF00<005YFFUH00eYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000003Eoo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH04EYF10001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH015YF00@005YFFUIJEP800003Ool0000000L000AJEP03001J
EUYF00EJEP04001JEUYFFUH5000gOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH03EYF10002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF00EJEP04001JEUYFFUH2000:
Ool@000lOol002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH30006FUH01000FUIJEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP00009oo`8000IJEP04001JEUYFFUH2001FOol002Uoo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH2
000:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005Ool20003FUH01`00FUIJEUYF001JEP0005Io
o`00:Goo00<005YF00000eYF1`001UYF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF0`000UYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04000:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20008Ool200000eYF
001JEP02FUH00`00FUH0001FOol002Uoo`04001JEP00FUH20007Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH30003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH400000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH2000;Ool20003FUH00`00FUH0001FOol002Uoo`04001JEP00000;Ool3
00000eYF001JEP07FUH00`00FUIJEP030003FUH40006FUH00`00FUIJEP02FUH20002FUH00`00Oomo
o`03FUH00`00FUIJEP0:FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`0000=JEP0000001goo1@000UYF0P00Egoo000YOol3000?Ool3
0006FUH00`00FUIJEP050002FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF0`000goo0eYF00<0
05YFFUH01eYF0`0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00@005YF0000009JEP04001JEUYFFUH70002FUH00`00FUIJEP04001GOol002Uoo`800003FUH0
0000011oo`@0009JEP03001JEUYF00D00003FUH005YF00MJEP<000EJEP04001JEP000002Ool01000
FUIJEP001UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF0P00Egoo000YOol00`00FUIJEP02
FUH00`00Oomoo`0AOol:00000eYF001JEP03FUH90003FUH01`00FUIJEUYF001oo`0000MJEP8000=J
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009J
EPD000AJEP03001JEUYF00IJEP<0009JEP04001JEUYFFUH3001GOol002Uoo`03001JEUYF009JEP<0
01Moo`X000Uoo`800003FUH005YF009JEP03001oo`0000EJEP8000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEP00008000EJEPH000MJEP03001JEUYF
00<000=JEP03001JEP0005Moo`00:Goo00<005YFFUH00UYF00<005YFFUH00P00:Woo0P000eYF0`00
0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00
00=JEP00FUH025YF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000Egoo000Z
Ool01000FUIJEP001EYF0P00:Woo00H005YF001JEP00Ool2FUH01000FUIJEP001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF100015YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0P0000=JEP000000F7oo000[Ool00`00FUH00005FUH01000
FUH00000:Goo0P0000EJEP00OomJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJ
EP03001JEP00008005Qoo`00;7oo0P001EYF00@005YFFUIJEP<002Moo`05001JEP00Ool00004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0FFUH400000goo000000030006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH000000eYF00D005YFFUIJEP0005Uoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF10008Woo0`000Woo00<005YFFUH00UYF00<005YFFUH07UYF00<005YFFUH0
15YF10002Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00UYF00<007ooOol0Egoo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20000
0eYF00000003Ool5FUH00`00FUIJEP0@FUH00`00FUIJEP0:FUH00`00FUIJEP06000@Ool70004FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@000eYF0P00F7oo000`Ool200000eYF001JEP06FUH00`00FUIJ
EP04FUH7000@Ool50003FUH20003Ool30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH:0005FUH3000COolA0005Ool00`00FUIJEP02001HOol0039oo`<000EJEP03001JEUYF00MJ
EP03001JEUYF009JEQ0000=JEP04001JEUYFFUH20007Ool60004FUH00`00FUIJEP03FUH<0008Ool2
0006FUH01000FUH0000047oo1@004goo1000F7oo000eOol400000eYF001JEP08FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P003Goo2P005Goo00<005YFFUH015YF
00@005YFFUIJEP<000eoo`D001=oo`@005Qoo`00>Goo10001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`8000=JEP03001JEUYF00EJEPD000Qoo`D0015o
o`800003FUH0000005Uoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF0000039oo`800003FUH005YF00MJEP04001JEUYFFUH<000>Ool40003FUH2001IOol0
045oo`L000AJEP03001JEUYF00EJEP04001JEUYFFUH5000fOol30007FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHA0002FUH01`00FUIJEUYF001JEP0005Uoo`00B7oo4000?Woo0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Yoo`00V7oo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Yoo`00Vgoo10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P00Fgoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00GGoo
002SOol70004FUH00`00FUIJEP02FUH7001SOol00:Yoo`T006Yoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60099 .74931 m .59637 .69344 L .5653 .69418 L p .707 .577 .707 r
F P
0 g
s
.59637 .69344 m .60099 .74931 L .63273 .74616 L p .707 .577 .707 r
F P
0 g
s
.63273 .74616 m .6281 .69028 L .59637 .69344 L p .707 .577 .707 r
F P
0 g
s
.6281 .69028 m .63273 .74616 L .66203 .74089 L p .707 .577 .707 r
F P
0 g
s
.66203 .74089 m .65741 .68502 L .6281 .69028 L p .707 .577 .707 r
F P
0 g
s
.56993 .75005 m .5653 .69418 L .53796 .69242 L p .707 .577 .707 r
F P
0 g
s
.5653 .69418 m .56993 .75005 L .60099 .74931 L p .707 .577 .707 r
F P
0 g
s
.65741 .68502 m .66203 .74089 L .68603 .73403 L p .707 .577 .707 r
F P
0 g
s
.68603 .73403 m .68141 .67816 L .65741 .68502 L p .707 .577 .707 r
F P
0 g
s
.6061 .81152 m .601 .7743 L .57013 .77677 L p .707 .577 .707 r
F P
0 g
s
.601 .7743 m .6061 .81152 L .63767 .8068 L p .707 .577 .707 r
F P
0 g
s
.63767 .8068 m .63257 .76957 L .601 .7743 L p .707 .577 .707 r
F P
0 g
s
.53796 .69242 m .54258 .74829 L .56993 .75005 L p .707 .577 .707 r
F P
0 g
s
.63257 .76957 m .63767 .8068 L .66684 .80028 L p .707 .577 .707 r
F P
0 g
s
.66684 .80028 m .66174 .76306 L .63257 .76957 L p .707 .577 .707 r
F P
0 g
s
.54258 .74829 m .53796 .69242 L .517 .68835 L p .707 .577 .707 r
F P
0 g
s
.57523 .814 m .57013 .77677 L .54297 .77676 L p .707 .577 .707 r
F P
0 g
s
.57013 .77677 m .57523 .814 L .6061 .81152 L p .707 .577 .707 r
F P
0 g
s
.66174 .76306 m .66684 .80028 L .69075 .79262 L p .707 .577 .707 r
F P
0 g
s
.69075 .79262 m .68565 .7554 L .66174 .76306 L p .707 .577 .707 r
F P
0 g
s
.68141 .67816 m .68603 .73403 L .70239 .72624 L p .707 .577 .707 r
F P
0 g
s
.70239 .72624 m .69776 .67037 L .68141 .67816 L p .707 .577 .707 r
F P
0 g
s
.61047 .85871 m .60785 .84011 L .577 .8427 L p .707 .577 .707 r
F P
0 g
s
.60785 .84011 m .61047 .85871 L .64202 .85388 L p .707 .577 .707 r
F P
0 g
s
.64202 .85388 m .6394 .83527 L .60785 .84011 L p .707 .577 .707 r
F P
0 g
s
.54297 .77676 m .54808 .81398 L .57523 .814 L p .707 .577 .707 r
F P
0 g
s
.517 .68835 m .52162 .74422 L .54258 .74829 L p .707 .577 .707 r
F P
0 g
s
.6394 .83527 m .64202 .85388 L .67118 .84728 L p .707 .577 .707 r
F P
0 g
s
.67118 .84728 m .66856 .82868 L .6394 .83527 L p .707 .577 .707 r
F P
0 g
s
.577 .8427 m .57962 .86131 L .61047 .85871 L p .707 .577 .707 r
F P
0 g
s
.57962 .86131 m .577 .8427 L .54986 .8428 L p .707 .577 .707 r
F P
0 g
s
.54808 .81398 m .54297 .77676 L .52219 .77425 L p .707 .577 .707 r
F P
0 g
s
.52162 .74422 m .517 .68835 L .50449 .68235 L p .707 .577 .707 r
F P
0 g
s
.54986 .8428 m .55248 .86141 L .57962 .86131 L p .707 .577 .707 r
F P
0 g
s
.66856 .82868 m .67118 .84728 L .69508 .83957 L p .707 .577 .707 r
F P
0 g
s
.69508 .83957 m .69246 .82096 L .66856 .82868 L p .707 .577 .707 r
F P
0 g
s
.68565 .7554 m .69075 .79262 L .70707 .78456 L p .707 .577 .707 r
F P
0 g
s
.70707 .78456 m .70197 .74734 L .68565 .7554 L p .707 .577 .707 r
F P
0 g
s
.52219 .77425 m .52729 .81147 L .54808 .81398 L p .707 .577 .707 r
F P
0 g
s
.69776 .67037 m .70239 .72624 L .70949 .71829 L p .707 .577 .707 r
F P
0 g
s
.70949 .71829 m .70486 .66242 L .69776 .67037 L p .707 .577 .707 r
F P
0 g
s
.55248 .86141 m .54986 .8428 L .52909 .84041 L p .707 .577 .707 r
F P
0 g
s
.50449 .68235 m .50911 .73822 L .52162 .74422 L p .707 .577 .707 r
F P
0 g
s
.52909 .84041 m .53171 .85901 L .55248 .86141 L p .707 .577 .707 r
F P
0 g
s
.69246 .82096 m .69508 .83957 L .7114 .83149 L p .707 .577 .707 r
F P
0 g
s
.7114 .83149 m .70878 .81288 L .69246 .82096 L p .707 .577 .707 r
F P
0 g
s
.52729 .81147 m .52219 .77425 L .50981 .7695 L p .707 .577 .707 r
F P
0 g
s
.50911 .73822 m .50449 .68235 L .50164 .67502 L p .707 .577 .707 r
F P
0 g
s
.50164 .67502 m .50626 .73089 L .50911 .73822 L p .707 .577 .707 r
F P
0 g
s
.50626 .73089 m .50164 .67502 L .50874 .66707 L p .707 .577 .707 r
F P
0 g
s
.50874 .66707 m .51336 .72294 L .50626 .73089 L p .707 .577 .707 r
F P
0 g
s
.51336 .72294 m .50874 .66707 L .52509 .65929 L p .707 .577 .707 r
F P
0 g
s
.49038 .82544 m .58053 .34202 L .53725 .33141 L p .707 .577 .707 r
F P
0 g
s
.50981 .7695 m .51491 .80672 L .52729 .81147 L p .707 .577 .707 r
F P
0 g
s
.51491 .80672 m .50981 .7695 L .50705 .76297 L p .707 .577 .707 r
F P
0 g
s
.50705 .76297 m .51215 .80019 L .51491 .80672 L p .707 .577 .707 r
F P
0 g
s
.51215 .80019 m .50705 .76297 L .51419 .7553 L p .707 .577 .707 r
F P
0 g
s
.51419 .7553 m .51929 .79252 L .51215 .80019 L p .707 .577 .707 r
F P
0 g
s
.53171 .85901 m .52909 .84041 L .51672 .83574 L p .707 .577 .707 r
F P
0 g
s
.51672 .83574 m .51934 .85435 L .53171 .85901 L p .707 .577 .707 r
F P
0 g
s
.51934 .85435 m .51672 .83574 L .51397 .82926 L p .707 .577 .707 r
F P
0 g
s
.51397 .82926 m .51659 .84787 L .51934 .85435 L p .707 .577 .707 r
F P
0 g
s
.51659 .84787 m .51397 .82926 L .5211 .82161 L p .707 .577 .707 r
F P
0 g
s
.5211 .82161 m .52372 .84022 L .51659 .84787 L p .707 .577 .707 r
F P
0 g
s
.52509 .65929 m .52971 .71516 L .51336 .72294 L p .707 .577 .707 r
F P
0 g
s
.51929 .79252 m .51419 .7553 L .53051 .74724 L p .707 .577 .707 r
F P
0 g
s
.52971 .71516 m .52509 .65929 L .54831 .65265 L p .707 .577 .707 r
F P
0 g
s
.58053 .34202 m .53348 .59432 L p .5495 .65731 L .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .55177 .68476 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .5495 .65731 L p .56218 .68396 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .56218 .68396 L .56292 .68551 L .707 .577 .707 r
F
.53742 .81353 m .54004 .83214 L .52372 .84022 L p F P
0 g
s
.55442 .73958 m .55952 .7768 L .53561 .78446 L p .707 .577 .707 r
F P
0 g
s
.58302 .70303 m .58132 .68251 L p .61013 .644 L .707 .577 .707 r
F P
0 g
s
.62482 .34807 m .56218 .68396 L p .58132 .68251 L .707 .577 .707 r
F P
0 g
s
.59294 .66196 m .62482 .34807 L .58132 .68251 L .707 .577 .707 r
F
.60267 .64474 m .61013 .644 L p .58132 .68251 L F P
0 g
s
.61476 .69987 m .61013 .644 L .6412 .64327 L p .707 .577 .707 r
F P
0 g
s
.61013 .644 m .61476 .69987 L .58736 .7026 L p .707 .577 .707 r
F P
0 g
s
.58736 .7026 m .58302 .70303 L p .59982 .66647 L .707 .577 .707 r
F P
0 g
s
.59982 .66647 m .61013 .644 L .58736 .7026 L .707 .577 .707 r
F
.6412 .64327 m .64582 .69914 L .61476 .69987 L p F P
0 g
s
.62025 .76556 m .61515 .72834 L .64602 .72586 L p .707 .577 .707 r
F P
0 g
s
.58869 .77029 m .58359 .73306 L .61515 .72834 L p .707 .577 .707 r
F P
0 g
s
.61515 .72834 m .62025 .76556 L .58869 .77029 L p .707 .577 .707 r
F P
0 g
s
.56395 .82442 m .56133 .80582 L .59049 .79922 L p .707 .577 .707 r
F P
0 g
s
.59049 .79922 m .5931 .81783 L .56395 .82442 L p .707 .577 .707 r
F P
0 g
s
.5931 .81783 m .59049 .79922 L .62203 .79439 L p .707 .577 .707 r
F P
0 g
s
.62203 .79439 m .62465 .81299 L .5931 .81783 L p .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .60925 .82806 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.66578 .34898 m .61454 .62375 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.58359 .73306 m .58869 .77029 L .55952 .7768 L p .707 .577 .707 r
F P
0 g
s
.61454 .62375 m .57563 .83239 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .66578 .34898 L .62482 .34807 L p .707 .577 .707 r
F P
0 g
s
.58132 .68251 m .5784 .64716 L .60267 .64474 L p .707 .577 .707 r
F P
0 g
s
.59093 .68177 m .59294 .66196 L .58132 .68251 L .707 .577 .707 r
F
.5784 .64716 m .58302 .70303 L .57218 .70498 L p F P
0 g
s
.57218 .70498 m .55372 .7083 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56292 .68551 m .5784 .64716 L .57218 .70498 L .707 .577 .707 r
F
.62482 .34807 m .58053 .34202 L p .55074 .65993 L F P
0 g
s
.52372 .84022 m .5211 .82161 L .53742 .81353 L p .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .52971 .71516 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.54909 .65242 m .5495 .65731 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.5495 .65731 m .55372 .7083 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .56218 .68396 L .55074 .65993 L .707 .577 .707 r
F
.53561 .78446 m .53051 .74724 L .55442 .73958 L p F P
0 g
s
.54004 .83214 m .53742 .81353 L .56133 .80582 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .55968 .69736 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.55968 .69736 m .56218 .68396 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .62482 .34807 L p .55074 .65993 L .707 .577 .707 r
F P
0 g
s
.56133 .80582 m .56395 .82442 L .54004 .83214 L p .707 .577 .707 r
F P
0 g
s
.55952 .7768 m .55442 .73958 L .58359 .73306 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .57563 .83239 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55074 .65993 m .58053 .34202 L .5495 .65731 L .707 .577 .707 r
F
.54909 .65242 m .5784 .64716 L p .56292 .68551 L F P
0 g
s
.5495 .65731 m .54909 .65242 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .53467 .83149 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .55074 .65993 L .5495 .65731 L .707 .577 .707 r
F
.54831 .65265 m .54909 .65242 L p .54863 .65391 L F P
0 g
s
.52971 .71516 m .54831 .65265 L .54863 .65391 L .707 .577 .707 r
F
.53051 .74724 m .53561 .78446 L .51929 .79252 L p F P
0 g
s
.49038 .82544 m .53467 .83149 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.53348 .59432 m .49038 .82544 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.44709 .81483 m .53725 .33141 L .49921 .31729 L p .707 .577 .707 r
F P
0 g
s
.53725 .33141 m .44709 .81483 L .49038 .82544 L p .707 .577 .707 r
F P
0 g
s
.70197 .74734 m .70707 .78456 L .7142 .77689 L p .707 .577 .707 r
F P
0 g
s
.7142 .77689 m .7091 .73967 L .70197 .74734 L p .707 .577 .707 r
F P
0 g
s
.70486 .66242 m .70949 .71829 L .70664 .71096 L p .707 .577 .707 r
F P
0 g
s
.70664 .71096 m .70202 .65509 L .70486 .66242 L p .707 .577 .707 r
F P
0 g
s
.70878 .81288 m .7114 .83149 L .71854 .82384 L p .707 .577 .707 r
F P
0 g
s
.71854 .82384 m .71592 .80523 L .70878 .81288 L p .707 .577 .707 r
F P
0 g
s
.64582 .69914 m .6412 .64327 L .66855 .64502 L p .707 .577 .707 r
F P
0 g
s
.64602 .72586 m .65113 .76309 L .62025 .76556 L p .707 .577 .707 r
F P
0 g
s
.60925 .82806 m .69941 .34464 L .66578 .34898 L p .707 .577 .707 r
F P
0 g
s
.40906 .8007 m .49921 .31729 L .47014 .30102 L p .707 .577 .707 r
F P
0 g
s
.49921 .31729 m .40906 .8007 L .44709 .81483 L p .707 .577 .707 r
F P
0 g
s
.7091 .73967 m .7142 .77689 L .71144 .77036 L p .707 .577 .707 r
F P
0 g
s
.71144 .77036 m .70634 .73314 L .7091 .73967 L p .707 .577 .707 r
F P
0 g
s
.70202 .65509 m .70664 .71096 L .69413 .70497 L p .707 .577 .707 r
F P
0 g
s
.69413 .70497 m .6895 .6491 L .70202 .65509 L p .707 .577 .707 r
F P
0 g
s
.66855 .64502 m .67317 .70089 L .64582 .69914 L p .707 .577 .707 r
F P
0 g
s
.65289 .79179 m .65551 .8104 L .62465 .81299 L p .707 .577 .707 r
F P
0 g
s
.62465 .81299 m .62203 .79439 L .65289 .79179 L p .707 .577 .707 r
F P
0 g
s
.69941 .34464 m .60925 .82806 L .63225 .81891 L p .707 .577 .707 r
F P
0 g
s
.65113 .76309 m .64602 .72586 L .67318 .72588 L p .707 .577 .707 r
F P
0 g
s
.63225 .81891 m .7224 .3355 L .69941 .34464 L p .707 .577 .707 r
F P
0 g
s
.71592 .80523 m .71854 .82384 L .71578 .81736 L p .707 .577 .707 r
F P
0 g
s
.71578 .81736 m .71317 .79875 L .71592 .80523 L p .707 .577 .707 r
F P
0 g
s
.37998 .78444 m .47014 .30102 L .45288 .28422 L p .707 .577 .707 r
F P
0 g
s
.47014 .30102 m .37998 .78444 L .40906 .8007 L p .707 .577 .707 r
F P
0 g
s
.25798 .70845 m .25336 .65258 L .2223 .65332 L p .707 .577 .707 r
F P
0 g
s
.25336 .65258 m .25798 .70845 L .28972 .7053 L p .707 .577 .707 r
F P
0 g
s
.28972 .7053 m .2851 .64943 L .25336 .65258 L p .707 .577 .707 r
F P
0 g
s
.2851 .64943 m .28972 .7053 L .31902 .70003 L p .707 .577 .707 r
F P
0 g
s
.31902 .70003 m .3144 .64416 L .2851 .64943 L p .707 .577 .707 r
F P
0 g
s
.22692 .70919 m .2223 .65332 L .19495 .65156 L p .707 .577 .707 r
F P
0 g
s
.2223 .65332 m .22692 .70919 L .25798 .70845 L p .707 .577 .707 r
F P
0 g
s
.70634 .73314 m .71144 .77036 L .69907 .76561 L p .707 .577 .707 r
F P
0 g
s
.69907 .76561 m .69397 .72839 L .70634 .73314 L p .707 .577 .707 r
F P
0 g
s
.3144 .64416 m .31902 .70003 L .34303 .69317 L p .707 .577 .707 r
F P
0 g
s
.34303 .69317 m .3384 .6373 L .3144 .64416 L p .707 .577 .707 r
F P
0 g
s
.2631 .76445 m .258 .72723 L .22712 .72971 L p .707 .577 .707 r
F P
0 g
s
.258 .72723 m .2631 .76445 L .29466 .75973 L p .707 .577 .707 r
F P
0 g
s
.29466 .75973 m .28956 .72251 L .258 .72723 L p .707 .577 .707 r
F P
0 g
s
.6895 .6491 m .69413 .70497 L .67317 .70089 L p .707 .577 .707 r
F P
0 g
s
.67317 .70089 m .66855 .64502 L .6895 .6491 L p .707 .577 .707 r
F P
0 g
s
.28956 .72251 m .29466 .75973 L .32383 .75322 L p .707 .577 .707 r
F P
0 g
s
.32383 .75322 m .31873 .716 L .28956 .72251 L p .707 .577 .707 r
F P
0 g
s
.19495 .65156 m .19957 .70743 L .22692 .70919 L p .707 .577 .707 r
F P
0 g
s
.19957 .70743 m .19495 .65156 L .17399 .64749 L p .707 .577 .707 r
F P
0 g
s
.71317 .79875 m .71578 .81736 L .70342 .81269 L p .707 .577 .707 r
F P
0 g
s
.70342 .81269 m .7008 .79409 L .71317 .79875 L p .707 .577 .707 r
F P
0 g
s
.23222 .76693 m .22712 .72971 L .19997 .72969 L p .707 .577 .707 r
F P
0 g
s
.22712 .72971 m .23222 .76693 L .2631 .76445 L p .707 .577 .707 r
F P
0 g
s
.26746 .80181 m .26484 .7832 L .23399 .7858 L p .707 .577 .707 r
F P
0 g
s
.26484 .7832 m .26746 .80181 L .29901 .79698 L p .707 .577 .707 r
F P
0 g
s
.29901 .79698 m .29639 .77837 L .26484 .7832 L p .707 .577 .707 r
F P
0 g
s
.31873 .716 m .32383 .75322 L .34774 .74556 L p .707 .577 .707 r
F P
0 g
s
.34774 .74556 m .34264 .70833 L .31873 .716 L p .707 .577 .707 r
F P
0 g
s
.7224 .3355 m .63225 .81891 L .64236 .80585 L p .707 .577 .707 r
F P
0 g
s
.64236 .80585 m .70862 .45058 L p .7224 .3355 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .71914 .39414 L p .7203 .37334 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .7203 .37334 L .7224 .3355 L .707 .577 .707 r
F
.68528 .72194 m .68018 .68472 L .67333 .68389 L p F P
0 g
s
.64236 .80585 m .63861 .79015 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67714 .61456 L .64236 .80585 L .707 .577 .707 r
F
.71914 .39414 m .64236 .80585 L p .7085 .44207 L F P
0 g
s
.71914 .39414 m .73252 .32243 L .7299 .32582 L p .707 .577 .707 r
F P
0 g
s
.7299 .32582 m .7224 .3355 L p .71914 .39414 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .73252 .32243 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .66428 .65248 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .62135 .77334 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .65713 .63165 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.64984 .64959 m .65713 .63165 L .63861 .79015 L .707 .577 .707 r
F
.67752 .58151 m .66688 .63854 L p .65713 .63165 L F P
0 g
s
.66688 .63854 m .63861 .79015 L p .65713 .63165 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .64169 .59031 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .6542 .59631 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .66306 .61706 L .66169 .65274 L .707 .577 .707 r
F
.66306 .61706 m .6542 .59631 L .65846 .62838 L F
.66306 .61706 m .65846 .62838 L .66169 .65274 L F
.6734 .60004 m .67023 .59942 L p .66737 .62717 L F P
0 g
s
.67023 .59942 m .6542 .59631 L p .66306 .61706 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .67023 .59942 L .66306 .61706 L .707 .577 .707 r
F
.64984 .64959 m .65337 .629 L .65441 .62973 L F
.64169 .59031 m .64209 .5952 L p .65217 .62816 L F P
0 g
s
.63815 .57735 m .64209 .5952 L .62135 .77334 L .707 .577 .707 r
F
.64886 .62582 m .64636 .63922 L p .64209 .5952 L F P
0 g
s
.64636 .63922 m .62135 .77334 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64812 .65381 m .7115 .28992 L .64984 .64959 L .707 .577 .707 r
F
.63984 .67417 m .64636 .63922 L p .64812 .65381 L F P
0 g
s
.65217 .62816 m .64209 .5952 L .64886 .62582 L .707 .577 .707 r
F
.64636 .63922 m .7115 .28992 L p .64812 .65381 L F P
0 g
s
.64631 .64618 m .64436 .62264 L p .63884 .58298 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64209 .5952 L p .6402 .58807 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .6402 .58807 L .63884 .58298 L .707 .577 .707 r
F
.64209 .5952 m .64169 .59031 L .6416 .59007 L p F P
0 g
s
.7115 .28992 m .64886 .62582 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.6416 .59007 m .63884 .58298 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64209 .5952 m .64436 .62264 L p .64886 .62582 L .707 .577 .707 r
F P
0 g
s
.62135 .77334 m .59228 .75708 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .67752 .58151 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.64631 .64618 m .65883 .65218 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64631 .64618 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.7115 .28992 m .72876 .30673 L p .65441 .62973 L .707 .577 .707 r
F P
0 g
s
.65337 .629 m .7115 .28992 L .65441 .62973 L .707 .577 .707 r
F
.62135 .77334 m .63984 .67417 L p .64984 .64959 L F P
0 g
s
.65883 .65218 m .65713 .63165 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65883 .65218 m .66169 .65274 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .65883 .65218 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .66449 .71944 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64702 .67746 m .64955 .69594 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64955 .69594 m .65212 .71468 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67752 .58151 L .7085 .44207 L .707 .577 .707 r
F
.66428 .65248 m .67752 .58151 L p .6691 .63825 L F P
0 g
s
.67752 .58151 m .72876 .30673 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .7085 .44207 L .67714 .61456 L .707 .577 .707 r
F
.66169 .65274 m .67978 .65625 L p .66737 .62717 L F P
0 g
s
.66449 .71944 m .65939 .68221 L .6548 .68045 L p .707 .577 .707 r
F P
0 g
s
.6548 .68045 m .64702 .67746 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.66449 .71944 m .6548 .68045 L .65186 .6891 L .707 .577 .707 r
F
.73252 .32243 m .71914 .39414 L p .7085 .44207 L F P
0 g
s
.67516 .60038 m .6734 .60004 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.6784 .65302 m .6734 .60004 L .66737 .62717 L .707 .577 .707 r
F
.67333 .68389 m .65939 .68221 L p .67091 .69989 L F P
0 g
s
.68528 .72194 m .67333 .68389 L .67091 .69989 L .707 .577 .707 r
F
.67978 .65625 m .67913 .64838 L p .6784 .65302 L F P
0 g
s
.67913 .64838 m .67516 .60038 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.29639 .77837 m .29901 .79698 L .32817 .79038 L p .707 .577 .707 r
F P
0 g
s
.32817 .79038 m .32555 .77177 L .29639 .77837 L p .707 .577 .707 r
F P
0 g
s
.3384 .6373 m .34303 .69317 L .35938 .68538 L p .707 .577 .707 r
F P
0 g
s
.35938 .68538 m .35475 .62951 L .3384 .6373 L p .707 .577 .707 r
F P
0 g
s
.36839 .77459 m .36577 .75598 L .34946 .76406 L p .707 .577 .707 r
F P
0 g
s
.35896 .70027 m .36406 .7375 L .37119 .72982 L p .707 .577 .707 r
F P
0 g
s
.37119 .72982 m .36609 .6926 L .35896 .70027 L p .707 .577 .707 r
F P
0 g
s
.36609 .6926 m .37119 .72982 L .36844 .72329 L p .707 .577 .707 r
F P
0 g
s
.36577 .75598 m .36839 .77459 L .37553 .76693 L p .707 .577 .707 r
F P
0 g
s
.37553 .76693 m .37291 .74833 L .36577 .75598 L p .707 .577 .707 r
F P
0 g
s
.37016 .74185 m .37278 .76046 L .36041 .75579 L p .707 .577 .707 r
F P
0 g
s
.34264 .70833 m .34774 .74556 L .36406 .7375 L p .707 .577 .707 r
F P
0 g
s
.36041 .75579 m .35779 .73718 L .37016 .74185 L p .707 .577 .707 r
F P
0 g
s
.36273 .76764 m .45288 .28422 L .44913 .26852 L p .707 .577 .707 r
F P
0 g
s
.37291 .74833 m .37553 .76693 L .37278 .76046 L p .707 .577 .707 r
F P
0 g
s
.37278 .76046 m .37016 .74185 L .37291 .74833 L p .707 .577 .707 r
F P
0 g
s
.45288 .28422 m .36273 .76764 L .37998 .78444 L p .707 .577 .707 r
F P
0 g
s
.19997 .72969 m .20507 .76691 L .23222 .76693 L p .707 .577 .707 r
F P
0 g
s
.23399 .7858 m .23661 .80441 L .26746 .80181 L p .707 .577 .707 r
F P
0 g
s
.17399 .64749 m .17861 .70336 L .19957 .70743 L p .707 .577 .707 r
F P
0 g
s
.69397 .72839 m .69907 .76561 L .67828 .7631 L p .707 .577 .707 r
F P
0 g
s
.67828 .7631 m .67318 .72588 L .69397 .72839 L p .707 .577 .707 r
F P
0 g
s
.23661 .80441 m .23399 .7858 L .20685 .7859 L p .707 .577 .707 r
F P
0 g
s
.20507 .76691 m .19997 .72969 L .17918 .72718 L p .707 .577 .707 r
F P
0 g
s
.20685 .7859 m .20947 .80451 L .23661 .80441 L p .707 .577 .707 r
F P
0 g
s
.32555 .77177 m .32817 .79038 L .35207 .78267 L p .707 .577 .707 r
F P
0 g
s
.35207 .78267 m .34946 .76406 L .32555 .77177 L p .707 .577 .707 r
F P
0 g
s
.17861 .70336 m .17399 .64749 L .16148 .64149 L p .707 .577 .707 r
F P
0 g
s
.36406 .7375 m .35896 .70027 L .34264 .70833 L p .707 .577 .707 r
F P
0 g
s
.17918 .72718 m .18428 .76441 L .20507 .76691 L p .707 .577 .707 r
F P
0 g
s
.7008 .79409 m .70342 .81269 L .68265 .8103 L p .707 .577 .707 r
F P
0 g
s
.68265 .8103 m .68003 .79169 L .7008 .79409 L p .707 .577 .707 r
F P
0 g
s
.20947 .80451 m .20685 .7859 L .18608 .7835 L p .707 .577 .707 r
F P
0 g
s
.35475 .62951 m .35938 .68538 L .36648 .67744 L p .707 .577 .707 r
F P
0 g
s
.36648 .67744 m .36185 .62156 L .35475 .62951 L p .707 .577 .707 r
F P
0 g
s
.18608 .7835 m .1887 .80211 L .20947 .80451 L p .707 .577 .707 r
F P
0 g
s
.16148 .64149 m .1661 .69736 L .17861 .70336 L p .707 .577 .707 r
F P
0 g
s
.67318 .72588 m .67828 .7631 L .65113 .76309 L p .707 .577 .707 r
F P
0 g
s
.34946 .76406 m .35207 .78267 L .36839 .77459 L p .707 .577 .707 r
F P
0 g
s
.18428 .76441 m .17918 .72718 L .1668 .72243 L p .707 .577 .707 r
F P
0 g
s
.1668 .72243 m .1719 .75966 L .18428 .76441 L p .707 .577 .707 r
F P
0 g
s
.1661 .69736 m .16148 .64149 L .15863 .63416 L p .707 .577 .707 r
F P
0 g
s
.36844 .72329 m .36334 .68607 L .36609 .6926 L p .707 .577 .707 r
F P
0 g
s
.36334 .68607 m .36844 .72329 L .35606 .71854 L p .707 .577 .707 r
F P
0 g
s
.35779 .73718 m .36041 .75579 L .33964 .75339 L p .707 .577 .707 r
F P
0 g
s
.44913 .26852 m .35897 .75194 L .36273 .76764 L p .707 .577 .707 r
F P
0 g
s
.35897 .75194 m .44913 .26852 L .45924 .25545 L p .707 .577 .707 r
F P
0 g
s
.68003 .79169 m .68265 .8103 L .65551 .8104 L p .707 .577 .707 r
F P
0 g
s
.65551 .8104 m .65289 .79179 L .68003 .79169 L p .707 .577 .707 r
F P
0 g
s
.1887 .80211 m .18608 .7835 L .17371 .77884 L p .707 .577 .707 r
F P
0 g
s
.17371 .77884 m .17633 .79745 L .1887 .80211 L p .707 .577 .707 r
F P
0 g
s
.15863 .63416 m .16325 .69003 L .1661 .69736 L p .707 .577 .707 r
F P
0 g
s
.36185 .62156 m .36648 .67744 L .36363 .67011 L p .707 .577 .707 r
F P
0 g
s
.36363 .67011 m .35901 .61423 L .36185 .62156 L p .707 .577 .707 r
F P
0 g
s
.1719 .75966 m .1668 .72243 L .16405 .7159 L p .707 .577 .707 r
F P
0 g
s
.16405 .7159 m .16915 .75312 L .1719 .75966 L p .707 .577 .707 r
F P
0 g
s
.16325 .69003 m .15863 .63416 L .16573 .62621 L p .707 .577 .707 r
F P
0 g
s
.17633 .79745 m .17371 .77884 L .17096 .77236 L p .707 .577 .707 r
F P
0 g
s
.17096 .77236 m .17358 .79097 L .17633 .79745 L p .707 .577 .707 r
F P
0 g
s
.36908 .73887 m .45924 .25545 L .48223 .24631 L p .707 .577 .707 r
F P
0 g
s
.45924 .25545 m .36908 .73887 L .35897 .75194 L p .707 .577 .707 r
F P
0 g
s
.16573 .62621 m .17035 .68208 L .16325 .69003 L p .707 .577 .707 r
F P
0 g
s
.35901 .61423 m .36363 .67011 L .35112 .66411 L p .707 .577 .707 r
F P
0 g
s
.35112 .66411 m .34649 .60824 L .35901 .61423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16915 .75312 m .16405 .7159 L .17118 .70823 L p .707 .577 .707 r
F P
0 g
s
.17118 .70823 m .17628 .74545 L .16915 .75312 L p .707 .577 .707 r
F P
0 g
s
.17035 .68208 m .16573 .62621 L .18208 .61843 L p .707 .577 .707 r
F P
0 g
s
.35606 .71854 m .35096 .68132 L .36334 .68607 L p .707 .577 .707 r
F P
0 g
s
.17358 .79097 m .17096 .77236 L .17809 .76471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17809 .76471 m .18071 .78332 L .17358 .79097 L p .707 .577 .707 r
F P
0 g
s
.34649 .60824 m .35112 .66411 L .33016 .66003 L p .707 .577 .707 r
F P
0 g
s
.33016 .66003 m .32554 .60416 L .34649 .60824 L p .707 .577 .707 r
F P
0 g
s
.18208 .61843 m .1867 .6743 L .17035 .68208 L p .707 .577 .707 r
F P
0 g
s
.59228 .75708 m .68243 .27366 L .7115 .28992 L p .707 .577 .707 r
F P
0 g
s
.48223 .24631 m .39208 .72973 L .36908 .73887 L p .707 .577 .707 r
F P
0 g
s
.39208 .72973 m .48223 .24631 L .51586 .24197 L p .707 .577 .707 r
F P
0 g
s
.17628 .74545 m .17118 .70823 L .1875 .70017 L p .707 .577 .707 r
F P
0 g
s
.1867 .6743 m .18208 .61843 L .20608 .61157 L p .707 .577 .707 r
F P
0 g
s
.1875 .70017 m .1926 .73739 L .17628 .74545 L p .707 .577 .707 r
F P
0 g
s
.35096 .68132 m .35606 .71854 L .33527 .71604 L p .707 .577 .707 r
F P
0 g
s
.33527 .71604 m .33017 .67881 L .35096 .68132 L p .707 .577 .707 r
F P
0 g
s
.18071 .78332 m .17809 .76471 L .19441 .75663 L p .707 .577 .707 r
F P
0 g
s
.32554 .60416 m .33016 .66003 L .30281 .65828 L p .707 .577 .707 r
F P
0 g
s
.30281 .65828 m .29819 .60241 L .32554 .60416 L p .707 .577 .707 r
F P
0 g
s
.19441 .75663 m .19703 .77524 L .18071 .78332 L p .707 .577 .707 r
F P
0 g
s
.20608 .61157 m .21071 .66744 L .1867 .6743 L p .707 .577 .707 r
F P
0 g
s
.33964 .75339 m .33702 .73479 L .35779 .73718 L p .707 .577 .707 r
F P
0 g
s
.21071 .66744 m .20608 .61157 L .23539 .6063 L p .707 .577 .707 r
F P
0 g
s
.1926 .73739 m .1875 .70017 L .21141 .69251 L p .707 .577 .707 r
F P
0 g
s
.68243 .27366 m .59228 .75708 L .55424 .74296 L p .707 .577 .707 r
F P
0 g
s
.55424 .74296 m .64439 .25954 L .68243 .27366 L p .707 .577 .707 r
F P
0 g
s
.4257 .72539 m .51586 .24197 L .55682 .24288 L p .707 .577 .707 r
F P
0 g
s
.51586 .24197 m .4257 .72539 L .39208 .72973 L p .707 .577 .707 r
F P
0 g
s
.29819 .60241 m .30281 .65828 L .27175 .65901 L p .707 .577 .707 r
F P
0 g
s
.27175 .65901 m .26713 .60314 L .29819 .60241 L p .707 .577 .707 r
F P
0 g
s
.33017 .67881 m .33527 .71604 L .30812 .71602 L p .707 .577 .707 r
F P
0 g
s
.30812 .71602 m .30302 .6788 L .33017 .67881 L p .707 .577 .707 r
F P
0 g
s
.21141 .69251 m .21651 .72973 L .1926 .73739 L p .707 .577 .707 r
F P
0 g
s
.24001 .66217 m .23539 .6063 L .26713 .60314 L p .707 .577 .707 r
F P
0 g
s
.23539 .6063 m .24001 .66217 L .21071 .66744 L p .707 .577 .707 r
F P
0 g
s
.19703 .77524 m .19441 .75663 L .21832 .74891 L p .707 .577 .707 r
F P
0 g
s
.26713 .60314 m .27175 .65901 L .24001 .66217 L p .707 .577 .707 r
F P
0 g
s
.7382 .65727 m .73357 .6014 L .70251 .60214 L p .707 .577 .707 r
F P
0 g
s
.73357 .6014 m .7382 .65727 L .76993 .65412 L p .707 .577 .707 r
F P
0 g
s
.76993 .65412 m .76531 .59825 L .73357 .6014 L p .707 .577 .707 r
F P
0 g
s
.21832 .74891 m .22094 .76752 L .19703 .77524 L p .707 .577 .707 r
F P
0 g
s
.76531 .59825 m .76993 .65412 L .79924 .64885 L p .707 .577 .707 r
F P
0 g
s
.79924 .64885 m .79461 .59298 L .76531 .59825 L p .707 .577 .707 r
F P
0 g
s
.21651 .72973 m .21141 .69251 L .24058 .686 L p .707 .577 .707 r
F P
0 g
s
.64439 .25954 m .55424 .74296 L .51095 .73235 L p .707 .577 .707 r
F P
0 g
s
.51095 .73235 m .60111 .24893 L .64439 .25954 L p .707 .577 .707 r
F P
0 g
s
.33702 .73479 m .33964 .75339 L .3125 .7535 L p .707 .577 .707 r
F P
0 g
s
.3125 .7535 m .30988 .73489 L .33702 .73479 L p .707 .577 .707 r
F P
0 g
s
.46666 .7263 m .55682 .24288 L .60111 .24893 L p .707 .577 .707 r
F P
0 g
s
.55682 .24288 m .46666 .7263 L .4257 .72539 L p .707 .577 .707 r
F P
0 g
s
.70713 .65801 m .70251 .60214 L .67516 .60038 L p .707 .577 .707 r
F P
0 g
s
.70251 .60214 m .70713 .65801 L .7382 .65727 L p .707 .577 .707 r
F P
0 g
s
.30302 .6788 m .30812 .71602 L .27724 .7185 L p .707 .577 .707 r
F P
0 g
s
.27724 .7185 m .27214 .68127 L .30302 .6788 L p .707 .577 .707 r
F P
0 g
s
.60111 .24893 m .51095 .73235 L .46666 .7263 L p .707 .577 .707 r
F P
0 g
s
.24058 .686 m .24568 .72322 L .21651 .72973 L p .707 .577 .707 r
F P
0 g
s
.79461 .59298 m .79924 .64885 L .82324 .64199 L p .707 .577 .707 r
F P
0 g
s
.82324 .64199 m .81862 .58612 L .79461 .59298 L p .707 .577 .707 r
F P
0 g
s
.24568 .72322 m .24058 .686 L .27214 .68127 L p .707 .577 .707 r
F P
0 g
s
.22094 .76752 m .21832 .74891 L .24748 .74232 L p .707 .577 .707 r
F P
0 g
s
.27214 .68127 m .27724 .7185 L .24568 .72322 L p .707 .577 .707 r
F P
0 g
s
.74331 .71948 m .73821 .68226 L .70734 .68474 L p .707 .577 .707 r
F P
0 g
s
.73821 .68226 m .74331 .71948 L .77487 .71476 L p .707 .577 .707 r
F P
0 g
s
.77487 .71476 m .76977 .67754 L .73821 .68226 L p .707 .577 .707 r
F P
0 g
s
.67516 .60038 m .67978 .65625 L .70713 .65801 L p .707 .577 .707 r
F P
0 g
s
.24748 .74232 m .25009 .76092 L .22094 .76752 L p .707 .577 .707 r
F P
0 g
s
.76977 .67754 m .77487 .71476 L .80404 .70825 L p .707 .577 .707 r
F P
0 g
s
.80404 .70825 m .79894 .67102 L .76977 .67754 L p .707 .577 .707 r
F P
0 g
s
.30988 .73489 m .3125 .7535 L .28164 .75609 L p .707 .577 .707 r
F P
0 g
s
.28164 .75609 m .27903 .73748 L .30988 .73489 L p .707 .577 .707 r
F P
0 g
s
.71244 .72196 m .70734 .68474 L .68018 .68472 L p .707 .577 .707 r
F P
0 g
s
.70734 .68474 m .71244 .72196 L .74331 .71948 L p .707 .577 .707 r
F P
0 g
s
.25009 .76092 m .24748 .74232 L .27903 .73748 L p .707 .577 .707 r
F P
0 g
s
.27903 .73748 m .28164 .75609 L .25009 .76092 L p .707 .577 .707 r
F P
0 g
s
.79894 .67102 m .80404 .70825 L .82796 .70059 L p .707 .577 .707 r
F P
0 g
s
.82796 .70059 m .82285 .66336 L .79894 .67102 L p .707 .577 .707 r
F P
0 g
s
.81862 .58612 m .82324 .64199 L .83959 .6342 L p .707 .577 .707 r
F P
0 g
s
.83959 .6342 m .83497 .57833 L .81862 .58612 L p .707 .577 .707 r
F P
0 g
s
.74768 .76668 m .74506 .74807 L .7142 .75066 L p .707 .577 .707 r
F P
0 g
s
.74506 .74807 m .74768 .76668 L .77923 .76184 L p .707 .577 .707 r
F P
0 g
s
.77923 .76184 m .77661 .74324 L .74506 .74807 L p .707 .577 .707 r
F P
0 g
s
.68018 .68472 m .68528 .72194 L .71244 .72196 L p .707 .577 .707 r
F P
0 g
s
.77661 .74324 m .77923 .76184 L .80838 .75525 L p .707 .577 .707 r
F P
0 g
s
.80838 .75525 m .80576 .73664 L .77661 .74324 L p .707 .577 .707 r
F P
0 g
s
.7142 .75066 m .71682 .76927 L .74768 .76668 L p .707 .577 .707 r
F P
0 g
s
.71682 .76927 m .7142 .75066 L .68706 .75077 L p .707 .577 .707 r
F P
0 g
s
.68706 .75077 m .68968 .76937 L .71682 .76927 L p .707 .577 .707 r
F P
0 g
s
.80576 .73664 m .80838 .75525 L .83229 .74753 L p .707 .577 .707 r
F P
0 g
s
.83229 .74753 m .82967 .72892 L .80576 .73664 L p .707 .577 .707 r
F P
0 g
s
.82285 .66336 m .82796 .70059 L .84428 .69252 L p .707 .577 .707 r
F P
0 g
s
.84428 .69252 m .83918 .6553 L .82285 .66336 L p .707 .577 .707 r
F P
0 g
s
.65939 .68221 m .66449 .71944 L .68528 .72194 L p .707 .577 .707 r
F P
0 g
s
.83497 .57833 m .83959 .6342 L .84669 .62626 L p .707 .577 .707 r
F P
0 g
s
.84669 .62626 m .84207 .57039 L .83497 .57833 L p .707 .577 .707 r
F P
0 g
s
.68968 .76937 m .68706 .75077 L .66629 .74837 L p .707 .577 .707 r
F P
0 g
s
.66629 .74837 m .66891 .76698 L .68968 .76937 L p .707 .577 .707 r
F P
0 g
s
.82967 .72892 m .83229 .74753 L .84861 .73945 L p .707 .577 .707 r
F P
0 g
s
.84861 .73945 m .84599 .72084 L .82967 .72892 L p .707 .577 .707 r
F P
0 g
s
.83918 .6553 m .84428 .69252 L .85141 .68485 L p .707 .577 .707 r
F P
0 g
s
.85141 .68485 m .84631 .64763 L .83918 .6553 L p .707 .577 .707 r
F P
0 g
s
.66891 .76698 m .66629 .74837 L .65393 .7437 L p .707 .577 .707 r
F P
0 g
s
.65393 .7437 m .65654 .76231 L .66891 .76698 L p .707 .577 .707 r
F P
0 g
s
.63884 .58298 m .64347 .63885 L .64631 .64618 L p .707 .577 .707 r
F P
0 g
s
.84207 .57039 m .84669 .62626 L .84385 .61893 L p .707 .577 .707 r
F P
0 g
s
.84385 .61893 m .83922 .56305 L .84207 .57039 L p .707 .577 .707 r
F P
0 g
s
.84599 .72084 m .84861 .73945 L .85574 .7318 L p .707 .577 .707 r
F P
0 g
s
.85574 .7318 m .85312 .71319 L .84599 .72084 L p .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .64702 .67746 L .64426 .67093 L p .707 .577 .707 r
F P
0 g
s
.64426 .67093 m .64936 .70815 L .65212 .71468 L p .707 .577 .707 r
F P
0 g
s
.64347 .63885 m .63884 .58298 L .64594 .57503 L p .707 .577 .707 r
F P
0 g
s
.84631 .64763 m .85141 .68485 L .84865 .67832 L p .707 .577 .707 r
F P
0 g
s
.84865 .67832 m .84355 .6411 L .84631 .64763 L p .707 .577 .707 r
F P
0 g
s
.65654 .76231 m .65393 .7437 L .65117 .73723 L p .707 .577 .707 r
F P
0 g
s
.65117 .73723 m .65379 .75583 L .65654 .76231 L p .707 .577 .707 r
F P
0 g
s
.64594 .57503 m .65057 .6309 L .64347 .63885 L p .707 .577 .707 r
F P
0 g
s
.83922 .56305 m .84385 .61893 L .83133 .61293 L p .707 .577 .707 r
F P
0 g
s
.83133 .61293 m .82671 .55706 L .83922 .56305 L p .707 .577 .707 r
F P
0 g
s
.85312 .71319 m .85574 .7318 L .85299 .72532 L p .707 .577 .707 r
F P
0 g
s
.85299 .72532 m .85037 .70671 L .85312 .71319 L p .707 .577 .707 r
F P
0 g
s
.64936 .70815 m .64426 .67093 L .65139 .66326 L p .707 .577 .707 r
F P
0 g
s
.39519 .61641 m .39056 .56054 L .3595 .56128 L p .707 .577 .707 r
F P
0 g
s
.39056 .56054 m .39519 .61641 L .42692 .61326 L p .707 .577 .707 r
F P
0 g
s
.42692 .61326 m .4223 .55739 L .39056 .56054 L p .707 .577 .707 r
F P
0 g
s
.4223 .55739 m .42692 .61326 L .45623 .60799 L p .707 .577 .707 r
F P
0 g
s
.45623 .60799 m .4516 .55212 L .4223 .55739 L p .707 .577 .707 r
F P
0 g
s
.65057 .6309 m .64594 .57503 L .6623 .56725 L p .707 .577 .707 r
F P
0 g
s
.65139 .66326 m .65649 .70048 L .64936 .70815 L p .707 .577 .707 r
F P
0 g
s
.36412 .61715 m .3595 .56128 L .33215 .55952 L p .707 .577 .707 r
F P
0 g
s
.3595 .56128 m .36412 .61715 L .39519 .61641 L p .707 .577 .707 r
F P
0 g
s
.84355 .6411 m .84865 .67832 L .83627 .67357 L p .707 .577 .707 r
F P
0 g
s
.83627 .67357 m .83117 .63635 L .84355 .6411 L p .707 .577 .707 r
F P
0 g
s
.4516 .55212 m .45623 .60799 L .48023 .60113 L p .707 .577 .707 r
F P
0 g
s
.48023 .60113 m .47561 .54526 L .4516 .55212 L p .707 .577 .707 r
F P
0 g
s
.65379 .75583 m .65117 .73723 L .65831 .72957 L p .707 .577 .707 r
F P
0 g
s
.65831 .72957 m .66093 .74818 L .65379 .75583 L p .707 .577 .707 r
F P
0 g
s
.4003 .67242 m .3952 .63519 L .36433 .63767 L p .707 .577 .707 r
F P
0 g
s
.3952 .63519 m .4003 .67242 L .43186 .66769 L p .707 .577 .707 r
F P
0 g
s
.43186 .66769 m .42676 .63047 L .3952 .63519 L p .707 .577 .707 r
F P
0 g
s
.82671 .55706 m .83133 .61293 L .81037 .60885 L p .707 .577 .707 r
F P
0 g
s
.81037 .60885 m .80575 .55298 L .82671 .55706 L p .707 .577 .707 r
F P
0 g
s
.6623 .56725 m .66692 .62312 L .65057 .6309 L p .707 .577 .707 r
F P
0 g
s
.42676 .63047 m .43186 .66769 L .46103 .66118 L p .707 .577 .707 r
F P
0 g
s
.46103 .66118 m .45593 .62396 L .42676 .63047 L p .707 .577 .707 r
F P
0 g
s
.33215 .55952 m .33677 .61539 L .36412 .61715 L p .707 .577 .707 r
F P
0 g
s
.33677 .61539 m .33215 .55952 L .31119 .55545 L p .707 .577 .707 r
F P
0 g
s
.85037 .70671 m .85299 .72532 L .84062 .72066 L p .707 .577 .707 r
F P
0 g
s
.84062 .72066 m .83801 .70205 L .85037 .70671 L p .707 .577 .707 r
F P
0 g
s
.36943 .67489 m .36433 .63767 L .33717 .63765 L p .707 .577 .707 r
F P
0 g
s
.36433 .63767 m .36943 .67489 L .4003 .67242 L p .707 .577 .707 r
F P
0 g
s
.65649 .70048 m .65139 .66326 L .66771 .6552 L p .707 .577 .707 r
F P
0 g
s
.40467 .70977 m .40205 .69117 L .37119 .69376 L p .707 .577 .707 r
F P
0 g
s
.40205 .69117 m .40467 .70977 L .43622 .70494 L p .707 .577 .707 r
F P
0 g
s
.43622 .70494 m .4336 .68633 L .40205 .69117 L p .707 .577 .707 r
F P
0 g
s
.45593 .62396 m .46103 .66118 L .48495 .65352 L p .707 .577 .707 r
F P
0 g
s
.48495 .65352 m .47985 .6163 L .45593 .62396 L p .707 .577 .707 r
F P
0 g
s
.66692 .62312 m .6623 .56725 L .6863 .56039 L p .707 .577 .707 r
F P
0 g
s
.4336 .68633 m .43622 .70494 L .46537 .69834 L p .707 .577 .707 r
F P
0 g
s
.46537 .69834 m .46275 .67974 L .4336 .68633 L p .707 .577 .707 r
F P
0 g
s
.47561 .54526 m .48023 .60113 L .49658 .59334 L p .707 .577 .707 r
F P
0 g
s
.49658 .59334 m .49196 .53747 L .47561 .54526 L p .707 .577 .707 r
F P
0 g
s
.33717 .63765 m .34227 .67487 L .36943 .67489 L p .707 .577 .707 r
F P
0 g
s
.37119 .69376 m .37381 .71237 L .40467 .70977 L p .707 .577 .707 r
F P
0 g
s
.66771 .6552 m .67281 .69242 L .65649 .70048 L p .707 .577 .707 r
F P
0 g
s
.31119 .55545 m .31582 .61132 L .33677 .61539 L p .707 .577 .707 r
F P
0 g
s
.83117 .63635 m .83627 .67357 L .81549 .67106 L p .707 .577 .707 r
F P
0 g
s
.81549 .67106 m .81039 .63384 L .83117 .63635 L p .707 .577 .707 r
F P
0 g
s
.37381 .71237 m .37119 .69376 L .34405 .69386 L p .707 .577 .707 r
F P
0 g
s
.80575 .55298 m .81037 .60885 L .78303 .6071 L p .707 .577 .707 r
F P
0 g
s
.78303 .6071 m .7784 .55123 L .80575 .55298 L p .707 .577 .707 r
F P
0 g
s
.34227 .67487 m .33717 .63765 L .31638 .63515 L p .707 .577 .707 r
F P
0 g
s
.34405 .69386 m .34667 .71247 L .37381 .71237 L p .707 .577 .707 r
F P
0 g
s
.66093 .74818 m .65831 .72957 L .67463 .72149 L p .707 .577 .707 r
F P
0 g
s
.46275 .67974 m .46537 .69834 L .48928 .69063 L p .707 .577 .707 r
F P
0 g
s
.48928 .69063 m .48666 .67202 L .46275 .67974 L p .707 .577 .707 r
F P
0 g
s
.6863 .56039 m .69092 .61626 L .66692 .62312 L p .707 .577 .707 r
F P
0 g
s
.31582 .61132 m .31119 .55545 L .29868 .54945 L p .707 .577 .707 r
F P
0 g
s
.67463 .72149 m .67725 .7401 L .66093 .74818 L p .707 .577 .707 r
F P
0 g
s
.47985 .6163 m .48495 .65352 L .50127 .64546 L p .707 .577 .707 r
F P
0 g
s
.50127 .64546 m .49617 .60824 L .47985 .6163 L p .707 .577 .707 r
F P
0 g
s
.31638 .63515 m .32148 .67237 L .34227 .67487 L p .707 .577 .707 r
F P
0 g
s
.69092 .61626 m .6863 .56039 L .7156 .55512 L p .707 .577 .707 r
F P
0 g
s
.83801 .70205 m .84062 .72066 L .81985 .71826 L p .707 .577 .707 r
F P
0 g
s
.81985 .71826 m .81724 .69965 L .83801 .70205 L p .707 .577 .707 r
F P
0 g
s
.67281 .69242 m .66771 .6552 L .69163 .64754 L p .707 .577 .707 r
F P
0 g
s
.34667 .71247 m .34405 .69386 L .32328 .69146 L p .707 .577 .707 r
F P
0 g
s
.7784 .55123 m .78303 .6071 L .75196 .60783 L p .707 .577 .707 r
F P
0 g
s
.75196 .60783 m .74734 .55196 L .7784 .55123 L p .707 .577 .707 r
F P
0 g
s
.49196 .53747 m .49658 .59334 L .50368 .5854 L p .707 .577 .707 r
F P
0 g
s
.50368 .5854 m .49906 .52953 L .49196 .53747 L p .707 .577 .707 r
F P
0 g
s
.32328 .69146 m .3259 .71007 L .34667 .71247 L p .707 .577 .707 r
F P
0 g
s
.29868 .54945 m .3033 .60532 L .31582 .61132 L p .707 .577 .707 r
F P
0 g
s
.81039 .63384 m .81549 .67106 L .78833 .67105 L p .707 .577 .707 r
F P
0 g
s
.78833 .67105 m .78323 .63383 L .81039 .63384 L p .707 .577 .707 r
F P
0 g
s
.69163 .64754 m .69673 .68476 L .67281 .69242 L p .707 .577 .707 r
F P
0 g
s
.48666 .67202 m .48928 .69063 L .5056 .68255 L p .707 .577 .707 r
F P
0 g
s
.5056 .68255 m .50298 .66394 L .48666 .67202 L p .707 .577 .707 r
F P
0 g
s
.72023 .61099 m .7156 .55512 L .74734 .55196 L p .707 .577 .707 r
F P
0 g
s
.7156 .55512 m .72023 .61099 L .69092 .61626 L p .707 .577 .707 r
F P
0 g
s
.74734 .55196 m .75196 .60783 L .72023 .61099 L p .707 .577 .707 r
F P
0 g
s
.32148 .67237 m .31638 .63515 L .30401 .63039 L p .707 .577 .707 r
F P
0 g
s
.67725 .7401 m .67463 .72149 L .69853 .71378 L p .707 .577 .707 r
F P
0 g
s
.69853 .71378 m .70115 .73239 L .67725 .7401 L p .707 .577 .707 r
F P
0 g
s
.69673 .68476 m .69163 .64754 L .72079 .64103 L p .707 .577 .707 r
F P
0 g
s
.30401 .63039 m .30911 .66762 L .32148 .67237 L p .707 .577 .707 r
F P
0 g
s
.3033 .60532 m .29868 .54945 L .29583 .54212 L p .707 .577 .707 r
F P
0 g
s
.49617 .60824 m .50127 .64546 L .5084 .63779 L p .707 .577 .707 r
F P
0 g
s
.5084 .63779 m .5033 .60056 L .49617 .60824 L p .707 .577 .707 r
F P
0 g
s
.81724 .69965 m .81985 .71826 L .79271 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .71836 m .79009 .69975 L .81724 .69965 L p .707 .577 .707 r
F P
0 g
s
.78323 .63383 m .78833 .67105 L .75746 .67352 L p .707 .577 .707 r
F P
0 g
s
.75746 .67352 m .75236 .6363 L .78323 .63383 L p .707 .577 .707 r
F P
0 g
s
.3259 .71007 m .32328 .69146 L .31091 .6868 L p .707 .577 .707 r
F P
0 g
s
.72079 .64103 m .72589 .67825 L .69673 .68476 L p .707 .577 .707 r
F P
0 g
s
.31091 .6868 m .31353 .70541 L .3259 .71007 L p .707 .577 .707 r
F P
0 g
s
.72589 .67825 m .72079 .64103 L .75236 .6363 L p .707 .577 .707 r
F P
0 g
s
.75236 .6363 m .75746 .67352 L .72589 .67825 L p .707 .577 .707 r
F P
0 g
s
.29583 .54212 m .30046 .59799 L .3033 .60532 L p .707 .577 .707 r
F P
0 g
s
.49906 .52953 m .50368 .5854 L .50084 .57807 L p .707 .577 .707 r
F P
0 g
s
.50084 .57807 m .49621 .5222 L .49906 .52953 L p .707 .577 .707 r
F P
0 g
s
.70115 .73239 m .69853 .71378 L .72769 .70718 L p .707 .577 .707 r
F P
0 g
s
.50298 .66394 m .5056 .68255 L .51273 .6749 L p .707 .577 .707 r
F P
0 g
s
.51273 .6749 m .51011 .65629 L .50298 .66394 L p .707 .577 .707 r
F P
0 g
s
.72769 .70718 m .73031 .72579 L .70115 .73239 L p .707 .577 .707 r
F P
0 g
s
.79009 .69975 m .79271 .71836 L .76186 .72096 L p .707 .577 .707 r
F P
0 g
s
.76186 .72096 m .75924 .70235 L .79009 .69975 L p .707 .577 .707 r
F P
0 g
s
.30911 .66762 m .30401 .63039 L .30125 .62386 L p .707 .577 .707 r
F P
0 g
s
.73031 .72579 m .72769 .70718 L .75924 .70235 L p .707 .577 .707 r
F P
0 g
s
.75924 .70235 m .76186 .72096 L .73031 .72579 L p .707 .577 .707 r
F P
0 g
s
.30125 .62386 m .30635 .66109 L .30911 .66762 L p .707 .577 .707 r
F P
0 g
s
.30046 .59799 m .29583 .54212 L .30293 .53417 L p .707 .577 .707 r
F P
0 g
s
.5033 .60056 m .5084 .63779 L .50564 .63126 L p .707 .577 .707 r
F P
0 g
s
.50564 .63126 m .50054 .59403 L .5033 .60056 L p .707 .577 .707 r
F P
0 g
s
.31353 .70541 m .31091 .6868 L .30816 .68032 L p .707 .577 .707 r
F P
0 g
s
.30816 .68032 m .31078 .69893 L .31353 .70541 L p .707 .577 .707 r
F P
0 g
s
.51011 .65629 m .51273 .6749 L .50998 .66842 L p .707 .577 .707 r
F P
0 g
s
.50998 .66842 m .50736 .64981 L .51011 .65629 L p .707 .577 .707 r
F P
0 g
s
.30293 .53417 m .30756 .59004 L .30046 .59799 L p .707 .577 .707 r
F P
0 g
s
.49621 .5222 m .50084 .57807 L .48832 .57207 L p .707 .577 .707 r
F P
0 g
s
.48832 .57207 m .4837 .5162 L .49621 .5222 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30635 .66109 m .30125 .62386 L .30838 .61619 L p .707 .577 .707 r
F P
0 g
s
.30838 .61619 m .31348 .65341 L .30635 .66109 L p .707 .577 .707 r
F P
0 g
s
.30756 .59004 m .30293 .53417 L .31928 .52639 L p .707 .577 .707 r
F P
0 g
s
.50054 .59403 m .50564 .63126 L .49326 .6265 L p .707 .577 .707 r
F P
0 g
s
.49326 .6265 m .48816 .58928 L .50054 .59403 L p .707 .577 .707 r
F P
0 g
s
.31078 .69893 m .30816 .68032 L .3153 .67267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3153 .67267 m .31792 .69128 L .31078 .69893 L p .707 .577 .707 r
F P
0 g
s
.4837 .5162 m .48832 .57207 L .46736 .56799 L p .707 .577 .707 r
F P
0 g
s
.46736 .56799 m .46274 .51212 L .4837 .5162 L p .707 .577 .707 r
F P
0 g
s
.31928 .52639 m .32391 .58226 L .30756 .59004 L p .707 .577 .707 r
F P
0 g
s
.50736 .64981 m .50998 .66842 L .49761 .66375 L p .707 .577 .707 r
F P
0 g
s
.49761 .66375 m .49499 .64515 L .50736 .64981 L p .707 .577 .707 r
F P
0 g
s
.31348 .65341 m .30838 .61619 L .3247 .60813 L p .707 .577 .707 r
F P
0 g
s
.32391 .58226 m .31928 .52639 L .34329 .51953 L p .707 .577 .707 r
F P
0 g
s
.3247 .60813 m .3298 .64535 L .31348 .65341 L p .707 .577 .707 r
F P
0 g
s
.48816 .58928 m .49326 .6265 L .47248 .624 L p .707 .577 .707 r
F P
0 g
s
.47248 .624 m .46738 .58677 L .48816 .58928 L p .707 .577 .707 r
F P
0 g
s
.31792 .69128 m .3153 .67267 L .33162 .66459 L p .707 .577 .707 r
F P
0 g
s
.46274 .51212 m .46736 .56799 L .44002 .56624 L p .707 .577 .707 r
F P
0 g
s
.44002 .56624 m .43539 .51037 L .46274 .51212 L p .707 .577 .707 r
F P
0 g
s
.33162 .66459 m .33424 .6832 L .31792 .69128 L p .707 .577 .707 r
F P
0 g
s
.34329 .51953 m .34791 .5754 L .32391 .58226 L p .707 .577 .707 r
F P
0 g
s
.49499 .64515 m .49761 .66375 L .47684 .66136 L p .707 .577 .707 r
F P
0 g
s
.47684 .66136 m .47423 .64275 L .49499 .64515 L p .707 .577 .707 r
F P
0 g
s
.34791 .5754 m .34329 .51953 L .37259 .51426 L p .707 .577 .707 r
F P
0 g
s
.3298 .64535 m .3247 .60813 L .34862 .60047 L p .707 .577 .707 r
F P
0 g
s
.43539 .51037 m .44002 .56624 L .40895 .56698 L p .707 .577 .707 r
F P
0 g
s
.40895 .56698 m .40433 .5111 L .43539 .51037 L p .707 .577 .707 r
F P
0 g
s
.46738 .58677 m .47248 .624 L .44532 .62398 L p .707 .577 .707 r
F P
0 g
s
.44532 .62398 m .44022 .58676 L .46738 .58677 L p .707 .577 .707 r
F P
0 g
s
.34862 .60047 m .35372 .63769 L .3298 .64535 L p .707 .577 .707 r
F P
0 g
s
.37721 .57013 m .37259 .51426 L .40433 .5111 L p .707 .577 .707 r
F P
0 g
s
.37259 .51426 m .37721 .57013 L .34791 .5754 L p .707 .577 .707 r
F P
0 g
s
.33424 .6832 m .33162 .66459 L .35552 .65687 L p .707 .577 .707 r
F P
0 g
s
.40433 .5111 m .40895 .56698 L .37721 .57013 L p .707 .577 .707 r
F P
0 g
s
.35552 .65687 m .35814 .67548 L .33424 .6832 L p .707 .577 .707 r
F P
0 g
s
.35372 .63769 m .34862 .60047 L .37778 .59396 L p .707 .577 .707 r
F P
0 g
s
.47423 .64275 m .47684 .66136 L .4497 .66146 L p .707 .577 .707 r
F P
0 g
s
.4497 .66146 m .44708 .64285 L .47423 .64275 L p .707 .577 .707 r
F P
0 g
s
.44022 .58676 m .44532 .62398 L .41445 .62646 L p .707 .577 .707 r
F P
0 g
s
.41445 .62646 m .40935 .58923 L .44022 .58676 L p .707 .577 .707 r
F P
0 g
s
.37778 .59396 m .38288 .63118 L .35372 .63769 L p .707 .577 .707 r
F P
0 g
s
.38288 .63118 m .37778 .59396 L .40935 .58923 L p .707 .577 .707 r
F P
0 g
s
.35814 .67548 m .35552 .65687 L .38468 .65028 L p .707 .577 .707 r
F P
0 g
s
.40935 .58923 m .41445 .62646 L .38288 .63118 L p .707 .577 .707 r
F P
0 g
s
.38468 .65028 m .3873 .66889 L .35814 .67548 L p .707 .577 .707 r
F P
0 g
s
.44708 .64285 m .4497 .66146 L .41885 .66405 L p .707 .577 .707 r
F P
0 g
s
.41885 .66405 m .41623 .64545 L .44708 .64285 L p .707 .577 .707 r
F P
0 g
s
.3873 .66889 m .38468 .65028 L .41623 .64545 L p .707 .577 .707 r
F P
0 g
s
.41623 .64545 m .41885 .66405 L .3873 .66889 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0091oo`P008Eo
o`00S7oo10000UYF00<005YFFUH00eYF3000NGoo0028Ool40006FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH9001`Ool008Aoo`@00003FUH005YF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@006aoo`00PWoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH015YF1000J7oo0021Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH4001TOol0081oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP04001JEP00001ROol0081oo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP04001JEUYFFUH3001OOol007moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF019JEP80
05eoo`00Ogoo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF0P00Fgoo001oOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH3001IOol007ioo`04001J
EUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP02001GOol007ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00eJEP8005Eoo`00OWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P00Dgoo001nOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00Oomoo`1@
Ool007ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001oogoo04moo`00OWoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH02EYF00<007ooOol0CWoo001mOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH02UYF00<007oo
Ool0CGoo001mOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`1<Ool0
07eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo04]oo`00OGoo00<0
05YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH03EYF00<007ooOol0Bgoo001mOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0=
FUH00`00Oomoo`1;Ool007aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001<Ool007aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004ao
o`00O7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000C7oo001lOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001<Ool007aoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00eJEP8004eoo`00O7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH035YF00<005YF0000
CGoo001kOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001=Ool007]o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004eoo`00Ngoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CGoo001kOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0=FUH2001>Ool007]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP03001JEP0004ioo`00
NWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<0
05YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CWoo001jOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001>Ool007Yoo`03001JEP0000IJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYF
0P00Cgoo001jOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001?Ool0
07Uoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004moo`00NGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Cgoo001iOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool007Uoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP80051oo`00NGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH035YF00<005YF
0000D7oo001hOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001@Ool0
07Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00051oo`00N7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000D7oo001hOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1@Ool007Qoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00aJEP03001JEUYF055oo`00N7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000DGoo001gOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001AOol007Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00055oo`00
Mgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0DGoo001gOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001BOol007Moo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00059oo`00MWoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000DWoo001fOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001BOol007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP00059oo`00MWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF0000Dgoo001fOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001C
Ool007Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005=oo`00MGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Dgoo001eOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001COol007Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8005Aoo`00MGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000E7oo001eOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001DOol007Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ao
o`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000E7oo001dOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001EOol007Aoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Eoo`00M7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000EGoo001dOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001EOol007=oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0005Eoo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000EGoo
001cOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001FOol007=oo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ioo`00Lgoo0P001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000EWoo001^OolH000:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001FOol006Io
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005Ioo`00
H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
0eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000Egoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001GOol005Yoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000Egoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EWoo0P000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EUYF05Qoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Qoo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0005Qoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000F7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;OolA
000lOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005Ool60004FUH00`00
FUIJEP06FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF00000Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008002ioo`00E7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF009JEQL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF00<005YFFUH015YF10000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUIJEP8002eoo`00EGoo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP0000002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
001EOol00`00FUH00004FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol00`00FUH00003
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YF001JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEPl00003FUH005YF00=JEP03001JEP0000UJEP03001JEUYF00UJ
EP03001JEUYF00UJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
001EOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0004FUH00`00FUIJEP04
FUH00`00FUIJEP0500000eYF00000009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00EGoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF00000P002EYF00<005YFFUH02UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000]Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;Goo0017Ool@0002FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000/Ool003moo`P000AJEP03001JEUYF00IJEP06001JEP00001JEP000UYF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00=JEP03001JEUYF008002aoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH70003
FUH00`00FUIJEP02000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@000UYF0P00;7oo000cOol20005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH4000/Ool0039oo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00<7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH00P001UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT0009J
EP@00003FUH005YF00EJEPH00003FUH0000000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEP00FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH800000eYF000000060005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH000020005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00@00003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0001/002ioo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF2@000UYF1@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUH000030004FUH00`00FUIJEP05FUH3
0007FUH00`00FUH0000>0004FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF0`00
1eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01P001eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYF001JEP020003FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YF000005YF008000AJEP03001JEP0000<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo000]Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP0000EJEP04001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH00UYF3P0000AJEP00FUH000EJEP@00003FUH005YF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH90008FUH00`00
FUIJEP03FUH01000FUIJEP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF6@000UYF0P00
0eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002aoo`00;Woo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF00@000=J
EPL000QJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000/Ool002ioo`03001JEP0000AJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00AJEP03001JEUYF00AJEPH0009JEP@000AJEP03001JEUYF00QJEP04001JEUYFFUH200000eYF
001JEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00D0
05YFFUIJEP0002]oo`00;Woo00<005YF00000eYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0300025YF00<005YFFUH0
25YF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=oo`0000000P000UYF00<005YFFUH015YF1@000UYF00<007ooOol0:Goo000^Ool01000FUH005YF
0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF
00<005YFFUH00UYF1@0000=oo`0000001UYF00<005YFFUH01eYF00<005YFFUH01UYF100000=JEP00
FUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000Eoo`D000IJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH03@0000=JEP00FUH015YF00<005YF00000P000UYF0P000Woo00=JEP00FUH00UYF100025YF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000Moo`@0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002]oo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P000UYF00@0
05YFFUIJEP<0009JEP@0009oo`03001JEP00009JEPD000QJEP03001JEUYF00@00003FUH005YF00IJ
EP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH00eYF3`001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000:goo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH7
0006FUH00`00FUIJEP06FUH20002FUH01000FUH000001EYF00<005YFFUH00P0000Aoo`00FUH0009J
EPD000AJEPL000EJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUH005YF1@001EYF00<005YFFUH00`0000AJEP00FUIJEPT000AJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000^Ool20002FUH00`00FUIJEP03FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH0009JEQ000003FUH00000
008000QJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF00000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH002ioo`00;goo00@005YF
FUH000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF100035YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHC000_Ool0031oo`<00004FUH000000005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00D002eoo`00
<Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF1`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002]oo`00;goo0P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF400000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH?0003FUH01@00FUIJEUYF00001UYF00<005YFFUH07eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF0`0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
2@000Woo100000=JEP00FUH01EYF1P000UYF00<005YFFUH03EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
0`000UYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4P000eYF00<007oo
Ool0:7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1`000goo1`001EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004Goo0`0000=JEP00Ool0
:Goo000_Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP0400000goo000000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP03FUHC
0009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
00050007FUH00`00FUIJEP04FUH6000HOol20002FUH4000YOol002moo`03001JEP0000AJEP03001J
EUYF00=JEPT0009JEPD000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF00AJEPL000=JEP03001JEUYF00QJEP03001JEUYF009JEPH000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`8000AJEP04001JEP00000YOol002moo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00AJEPD000IJEP03001JEP0000h000EJEP04001JEUYFFUH200000eYF001JEP06
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH5000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH00eYF10007Goo0`0000=JEP00FUH015YF00<005YF
0000:Goo000_Ool01000FUIJEP000eYF0`001eYF00<005YFFUH01EYF0`000UYF1`0015YF00<005YF
FUH015YF00<005YFFUH01@0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0000=JEP00FUH00eYF00<005YF00000`000UYF00<007ooOol067oo100015YF00<005YFFUH00eYF
0P00:Woo000_Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`000eYF00<005YFFUH00P005Goo1000
0UYF00<005YFFUH015YF00@005YFFUIJEP8002]oo`00;goo00<005YFFUH00P001EYF00<005YFFUH0
1EYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02EYF10002UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YF001JEP00FUH30005FUH01@00FUIJEUYF00003Woo1`001UYF
00<005YFFUH015YF00@005YF000002eoo`00<7oo00AJEP00FUH000EJEP04001JEUYFFUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030007FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1P0015YF00D005YFFUIJEP0000Ioo`P000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<002moo`00<7oo00AJEP00FUH000EJEP06001JEP00001JEP00
1eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF010000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0039oo`00<7oo00@005YFFUH000EJEP80
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<00003
FUH005YF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0031oo`06001JEUYFFUH005YF
0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P0037oo00<005YF00003EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00@003Uoo`00<7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
1`000eYF1`003Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF000000IJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD003eo
o`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH010000UYF20004goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP05001JEP00001JEP0200000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool0035oo`8000EJEP03001JEUYF009J
EPX001Moo`@00003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000=JEQ/004Ioo`00<7oo00<005YF00001EYF00<005YF00000P002goo0`0047oo0`00
1EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF0P001eYF0P001EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH00UYF1000DGoo000`Ool01000FUIJEP000eYF0`003Goo1@002goo100000=JEP00
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP8000AJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF001AOol0031oo`05001JEUYF001JEP02000@Ool50004Ool7
0005FUH00`00FUIJEP05FUH01000FUH000000Woo00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000eYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000DWoo000aOol00`00FUH00003000@
Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005Ool00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH02@00FUIJEUYF
001JEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol0035oo`800004FUH005YF
FUH@00000eYF000000020008FUH00`00FUIJEP06FUH00`00FUH000030009Ool00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000E7oo000aOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP04FUH01000FUH00000
EGoo000aOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04000COol2000?FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000000?001EOol0039oo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000IOol2000=FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000015YF001JEP001eYF
00<005YFFUH00eYF0`00Dgoo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000ROol3
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000eOolC
000^Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02001A
Ool007Uoo`80015JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080055oo`00Ngoo0`00
3UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
3`000UYF00D005YFFUIJEP00055oo`00OWoo0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00UYF0`003goo10000UYF00<007ooOol0Cgoo0021Ool4000CFUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`0@Ool200000eYF00000002001@
Ool008Eoo`@000mJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH2000@Ool30003FUH0
1000FUH00000D7oo0029Ool5000OFUH01000FUH000003goo0`0000=JEP00FUH015YF00<005YF0000
D7oo002>Ool6000EFUH6000=Ool40004FUH00`00FUIJEP03FUH2001AOol0099oo`03001JEP0001@0
00moo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH2001BOol0099oo`04001JEP00FUH2000IOol7
0006FUH00`00FUIJEP04FUH01000FUH00000E7oo002BOol00`00FUH00004000@Ool80004FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3001FOol0099oo`80009JEP03001JEUYF010000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<005Uoo`00TWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00GGoo002BOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001P
Ool009=oo`05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
001TOol009Aoo`800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
06Uoo`00UWoo6P00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60388 .74909 m .59641 .69325 L .56553 .69562 L p .707 .577 .707 r
F P
0 g
s
.59641 .69325 m .60388 .74909 L .63546 .74446 L p .707 .577 .707 r
F P
0 g
s
.63546 .74446 m .62799 .68862 L .59641 .69325 L p .707 .577 .707 r
F P
0 g
s
.62799 .68862 m .63546 .74446 L .66463 .73803 L p .707 .577 .707 r
F P
0 g
s
.66463 .73803 m .65717 .68218 L .62799 .68862 L p .707 .577 .707 r
F P
0 g
s
.57299 .75146 m .56553 .69562 L .53836 .69549 L p .707 .577 .707 r
F P
0 g
s
.56553 .69562 m .57299 .75146 L .60388 .74909 L p .707 .577 .707 r
F P
0 g
s
.65717 .68218 m .66463 .73803 L .68856 .73041 L p .707 .577 .707 r
F P
0 g
s
.68856 .73041 m .68109 .67457 L .65717 .68218 L p .707 .577 .707 r
F P
0 g
s
.61195 .81236 m .60374 .77542 L .57335 .78059 L p .707 .577 .707 r
F P
0 g
s
.60374 .77542 m .61195 .81236 L .64308 .80521 L p .707 .577 .707 r
F P
0 g
s
.64308 .80521 m .63487 .76826 L .60374 .77542 L p .707 .577 .707 r
F P
0 g
s
.53836 .69549 m .54582 .75134 L .57299 .75146 L p .707 .577 .707 r
F P
0 g
s
.63487 .76826 m .64308 .80521 L .6719 .79676 L p .707 .577 .707 r
F P
0 g
s
.6719 .79676 m .66369 .75982 L .63487 .76826 L p .707 .577 .707 r
F P
0 g
s
.54582 .75134 m .53836 .69549 L .51756 .69289 L p .707 .577 .707 r
F P
0 g
s
.57335 .78059 m .58156 .81754 L .61195 .81236 L p .707 .577 .707 r
F P
0 g
s
.58156 .81754 m .57335 .78059 L .54668 .78327 L p .707 .577 .707 r
F P
0 g
s
.66369 .75982 m .6719 .79676 L .69559 .78786 L p .707 .577 .707 r
F P
0 g
s
.69559 .78786 m .68738 .75092 L .66369 .75982 L p .707 .577 .707 r
F P
0 g
s
.68109 .67457 m .68856 .73041 L .70488 .72237 L p .707 .577 .707 r
F P
0 g
s
.70488 .72237 m .69741 .66653 L .68109 .67457 L p .707 .577 .707 r
F P
0 g
s
.61901 .86296 m .6148 .8445 L .58445 .84987 L p .707 .577 .707 r
F P
0 g
s
.6148 .8445 m .61901 .86296 L .6501 .85563 L p .707 .577 .707 r
F P
0 g
s
.6501 .85563 m .64589 .83717 L .6148 .8445 L p .707 .577 .707 r
F P
0 g
s
.54668 .78327 m .55489 .82022 L .58156 .81754 L p .707 .577 .707 r
F P
0 g
s
.64589 .83717 m .6501 .85563 L .67889 .84705 L p .707 .577 .707 r
F P
0 g
s
.67889 .84705 m .67467 .82859 L .64589 .83717 L p .707 .577 .707 r
F P
0 g
s
.51756 .69289 m .52502 .74873 L .54582 .75134 L p .707 .577 .707 r
F P
0 g
s
.58445 .84987 m .58867 .86833 L .61901 .86296 L p .707 .577 .707 r
F P
0 g
s
.58867 .86833 m .58445 .84987 L .55782 .85274 L p .707 .577 .707 r
F P
0 g
s
.55489 .82022 m .54668 .78327 L .52633 .7832 L p .707 .577 .707 r
F P
0 g
s
.55782 .85274 m .56203 .8712 L .58867 .86833 L p .707 .577 .707 r
F P
0 g
s
.67467 .82859 m .67889 .84705 L .70256 .83806 L p .707 .577 .707 r
F P
0 g
s
.70256 .83806 m .69835 .8196 L .67467 .82859 L p .707 .577 .707 r
F P
0 g
s
.52502 .74873 m .51756 .69289 L .50517 .68806 L p .707 .577 .707 r
F P
0 g
s
.68738 .75092 m .69559 .78786 L .71183 .77937 L p .707 .577 .707 r
F P
0 g
s
.71183 .77937 m .70363 .74243 L .68738 .75092 L p .707 .577 .707 r
F P
0 g
s
.52633 .7832 m .53454 .82015 L .55489 .82022 L p .707 .577 .707 r
F P
0 g
s
.50517 .68806 m .51264 .74391 L .52502 .74873 L p .707 .577 .707 r
F P
0 g
s
.51264 .74391 m .50517 .68806 L .50241 .68148 L p .707 .577 .707 r
F P
0 g
s
.50241 .68148 m .50987 .73733 L .51264 .74391 L p .707 .577 .707 r
F P
0 g
s
.50987 .73733 m .50241 .68148 L .50953 .6738 L p .707 .577 .707 r
F P
0 g
s
.50953 .6738 m .517 .72964 L .50987 .73733 L p .707 .577 .707 r
F P
0 g
s
.517 .72964 m .50953 .6738 L .52586 .66575 L p .707 .577 .707 r
F P
0 g
s
.52586 .66575 m .53332 .72159 L .517 .72964 L p .707 .577 .707 r
F P
0 g
s
.53454 .82015 m .52633 .7832 L .5143 .78038 L p .707 .577 .707 r
F P
0 g
s
.5143 .78038 m .52251 .81733 L .53454 .82015 L p .707 .577 .707 r
F P
0 g
s
.52251 .81733 m .5143 .78038 L .51177 .77509 L p .707 .577 .707 r
F P
0 g
s
.51177 .77509 m .51997 .81203 L .52251 .81733 L p .707 .577 .707 r
F P
0 g
s
.51997 .81203 m .51177 .77509 L .51897 .76785 L p .707 .577 .707 r
F P
0 g
s
.51897 .76785 m .52718 .80479 L .51997 .81203 L p .707 .577 .707 r
F P
0 g
s
.52718 .80479 m .51897 .76785 L .53522 .75936 L p .707 .577 .707 r
F P
0 g
s
.53522 .75936 m .54343 .7963 L .52718 .80479 L p .707 .577 .707 r
F P
0 g
s
.54343 .7963 m .53522 .75936 L .55891 .75046 L p .707 .577 .707 r
F P
0 g
s
.56268 .71278 m .55725 .71398 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .63481 .35973 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.55891 .75046 m .56712 .7874 L .54343 .7963 L p .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .55891 .75046 L .57907 .74455 L p .707 .577 .707 r
F P
0 g
s
.57907 .74455 m .58773 .74201 L p .58426 .74965 L .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .57907 .74455 L .58426 .74965 L .707 .577 .707 r
F
.55716 .72307 m .56872 .72068 L .56008 .70938 L F
.53356 .83349 m .56545 .7312 L p .55716 .72307 L F P
0 g
s
.56545 .7312 m .56872 .72068 L p .55716 .72307 L .707 .577 .707 r
F P
0 g
s
.56872 .72068 m .67805 .37002 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .5397 .66479 L p .5559 .70391 L .707 .577 .707 r
F P
0 g
s
.56008 .70938 m .63481 .35973 L .5559 .70391 L .707 .577 .707 r
F
.54978 .65814 m .57896 .65171 L p .55924 .70828 L F P
0 g
s
.55725 .71398 m .5559 .70391 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.5559 .70391 m .54978 .65814 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.54173 .8713 m .53751 .85284 L .52551 .85016 L p .707 .577 .707 r
F P
0 g
s
.53442 .8562 m .53021 .83774 L .54645 .82923 L p .707 .577 .707 r
F P
0 g
s
.56203 .8712 m .55782 .85274 L .53751 .85284 L p .707 .577 .707 r
F P
0 g
s
.53751 .85284 m .54173 .8713 L .56203 .8712 L p .707 .577 .707 r
F P
0 g
s
.54645 .82923 m .55066 .84768 L .53442 .8562 L p .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .55961 .74992 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61665 .69281 L p .60159 .70532 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .618 .70292 L .61029 .70405 L p .707 .577 .707 r
F P
0 g
s
.61029 .70405 m .60159 .70532 L p .61665 .69281 L .707 .577 .707 r
F P
0 g
s
.64889 .70055 m .64142 .64471 L .66859 .64483 L p .707 .577 .707 r
F P
0 g
s
.64142 .64471 m .64889 .70055 L .618 .70292 L p .707 .577 .707 r
F P
0 g
s
.57012 .82024 m .57433 .83869 L .55066 .84768 L p .707 .577 .707 r
F P
0 g
s
.62707 .7718 m .61886 .73486 L .64925 .72968 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .58851 .74554 L p .61886 .73486 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .58773 .74201 L .59113 .74123 L p .707 .577 .707 r
F P
0 g
s
.59113 .74123 m .61886 .73486 L p .58851 .74554 L .707 .577 .707 r
F P
0 g
s
.61886 .73486 m .62707 .7718 L .59935 .77817 L p .707 .577 .707 r
F P
0 g
s
.59935 .77817 m .59594 .77896 L p .61755 .73738 L .707 .577 .707 r
F P
0 g
s
.61755 .73738 m .61886 .73486 L .59935 .77817 L .707 .577 .707 r
F
.67606 .70067 m .66859 .64483 L .68939 .64743 L p F P
0 g
s
.66859 .64483 m .67606 .70067 L .64889 .70055 L p .707 .577 .707 r
F P
0 g
s
.65745 .76663 m .64925 .72968 L .67592 .727 L p .707 .577 .707 r
F P
0 g
s
.64925 .72968 m .65745 .76663 L .62707 .7718 L p .707 .577 .707 r
F P
0 g
s
.63421 .82278 m .63 .80432 L .66034 .79896 L p .707 .577 .707 r
F P
0 g
s
.60312 .83011 m .59891 .81166 L .63 .80432 L p .707 .577 .707 r
F P
0 g
s
.63 .80432 m .63421 .82278 L .61681 .82689 L p .707 .577 .707 r
F P
0 g
s
.61681 .82689 m .60312 .83011 L p .62194 .81206 L .707 .577 .707 r
F P
0 g
s
.62194 .81206 m .63 .80432 L .61681 .82689 L .707 .577 .707 r
F
.69741 .66653 m .70488 .72237 L .71201 .71468 L p F P
0 g
s
.71201 .71468 m .70454 .65884 L .69741 .66653 L p .707 .577 .707 r
F P
0 g
s
.69686 .70327 m .68939 .64743 L .70178 .65226 L p .707 .577 .707 r
F P
0 g
s
.68939 .64743 m .69686 .70327 L .67606 .70067 L p .707 .577 .707 r
F P
0 g
s
.68413 .76395 m .67592 .727 L .69627 .72708 L p .707 .577 .707 r
F P
0 g
s
.69209 .72818 m .68389 .69124 L .68375 .69124 L p .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .63988 .81337 L p .74256 .4693 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .74615 .45575 L .62958 .82718 L .707 .577 .707 r
F
.74692 .4508 m .62958 .82718 L p .75537 .42638 L F P
0 g
s
.60677 .83558 m .62958 .82718 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .77408 .36371 L .75127 .37211 L p .707 .577 .707 r
F P
0 g
s
.63988 .81337 m .78437 .3499 L .77408 .36371 L p .707 .577 .707 r
F P
0 g
s
.68346 .5896 m .60677 .83558 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.60677 .83558 m .75127 .37211 L .71818 .37429 L p .707 .577 .707 r
F P
0 g
s
.75127 .37211 m .68346 .5896 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.57433 .83869 m .57012 .82024 L .59891 .81166 L p .707 .577 .707 r
F P
0 g
s
.59891 .81166 m .60312 .83011 L .57433 .83869 L p .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .60677 .83558 L p .65482 .63664 L .707 .577 .707 r
F P
0 g
s
.68913 .62538 m .69234 .61692 L .67556 .60346 L .707 .577 .707 r
F
.7038 .59298 m .69234 .61692 L .78437 .3499 L F
.675 .67984 m .68002 .65644 L .69428 .6217 L F
.63666 .79551 m .67098 .68543 L p .675 .67984 L F P
0 g
s
.67098 .68543 m .68002 .65644 L p .675 .67984 L .707 .577 .707 r
F P
0 g
s
.63666 .79551 m .62847 .78545 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .68458 .64182 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.68458 .64182 m .63666 .79551 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.618 .70292 m .61665 .69281 L p .64142 .64471 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .62106 .68113 L .64142 .64471 L .707 .577 .707 r
F
.63536 .64517 m .64142 .64471 L p .61624 .68976 L F P
0 g
s
.65956 .61698 m .68483 .51236 L .6216 .68407 L .707 .577 .707 r
F
.71818 .37429 m .62936 .65917 L p .68483 .51236 L F P
0 g
s
.55066 .84768 m .54645 .82923 L .57012 .82024 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .56712 .7874 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58773 .74201 m .58851 .74554 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .59594 .77896 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.6216 .68407 m .608 .72768 L p .65956 .61698 L .707 .577 .707 r
F P
0 g
s
.608 .72768 m .57368 .83775 L p .62121 .71558 L .707 .577 .707 r
F P
0 g
s
.65956 .61698 m .608 .72768 L .62121 .71558 L .707 .577 .707 r
F
.59637 .73609 m .67805 .37002 L .55368 .83562 L F
.61267 .66304 m .61053 .64708 L .61633 .64663 L p F P
0 g
s
.61665 .69281 m .61624 .68976 L p .62106 .68113 L .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .71818 .37429 L .67805 .37002 L p .707 .577 .707 r
F P
0 g
s
.61633 .64663 m .63536 .64517 L p .61267 .66304 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61267 .66304 L p .63536 .64517 L .707 .577 .707 r
F P
0 g
s
.62936 .65917 m .6216 .68407 L p .68483 .51236 L .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .65476 .60085 L p .67844 .64982 L .707 .577 .707 r
F P
0 g
s
.67964 .64826 m .67556 .60346 L .67844 .64982 L .707 .577 .707 r
F
.62847 .78545 m .62024 .77534 L p .67579 .65329 L F P
0 g
s
.68127 .64614 m .67556 .60346 L p .67964 .64826 L .707 .577 .707 r
F P
0 g
s
.69428 .6217 m .68458 .64182 L .7038 .59298 L .707 .577 .707 r
F
.68002 .65644 m .68458 .64182 L p .69428 .6217 L F P
0 g
s
.68458 .64182 m .69234 .61692 L p .7038 .59298 L .707 .577 .707 r
F P
0 g
s
.675 .67984 m .69428 .6217 L .67958 .67349 L .707 .577 .707 r
F
.71657 .56739 m .63988 .81337 L p .69428 .6217 L F P
0 g
s
.70454 .65884 m .71201 .71468 L .70924 .7081 L p .707 .577 .707 r
F P
0 g
s
.70924 .7081 m .70178 .65226 L .70454 .65884 L p .707 .577 .707 r
F P
0 g
s
.70178 .65226 m .70924 .7081 L .69686 .70327 L p .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .68303 .6593 L .7102 .65942 L p .707 .577 .707 r
F P
0 g
s
.67579 .65329 m .68127 .64614 L .62847 .78545 L .707 .577 .707 r
F
.65482 .63664 m .65956 .61698 L .64679 .64983 L F
.65476 .60085 m .66223 .65669 L .67222 .65794 L p F P
0 g
s
.62024 .77534 m .65442 .68116 L .67579 .65329 L .707 .577 .707 r
F
.67222 .65794 m .68303 .6593 L p .67844 .64982 L F P
0 g
s
.67844 .64982 m .65476 .60085 L .67222 .65794 L .707 .577 .707 r
F
.69676 .60355 m .67556 .60346 L p .69234 .61692 L F P
0 g
s
.78115 .33204 m .69234 .61692 L p .67579 .65329 L .707 .577 .707 r
F P
0 g
s
.65442 .68116 m .78115 .33204 L .67579 .65329 L .707 .577 .707 r
F
.67579 .65329 m .69234 .61692 L .68127 .64614 L F
.68167 .64919 m .68127 .64614 L p .68009 .65322 L F P
0 g
s
.68127 .64614 m .67964 .64826 L .68009 .65322 L .707 .577 .707 r
F
.68009 .65322 m .67964 .64826 L .67844 .64982 L F
.63988 .81337 m .63666 .79551 L p .675 .67984 L F P
0 g
s
.675 .67984 m .67958 .67349 L .63988 .81337 L .707 .577 .707 r
F
.65971 .72529 m .67174 .72811 L p .6587 .70248 L F P
0 g
s
.66223 .65669 m .65476 .60085 L .64238 .59603 L p .707 .577 .707 r
F P
0 g
s
.65482 .63664 m .64679 .64983 L .57368 .83775 L .707 .577 .707 r
F
.64238 .59603 m .64849 .6418 L p .66223 .65669 L F P
0 g
s
.64284 .62484 m .64849 .6418 L .62024 .77534 L .707 .577 .707 r
F
.6554 .66254 m .65288 .67064 L p .64849 .6418 L F P
0 g
s
.65288 .67064 m .62024 .77534 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64238 .59603 L .64114 .59307 L p .707 .577 .707 r
F P
0 g
s
.61053 .64708 m .61624 .68976 L p .58642 .70755 L .707 .577 .707 r
F P
0 g
s
.60159 .70532 m .58642 .70755 L p .61624 .68976 L .707 .577 .707 r
F P
0 g
s
.55368 .83562 m .57368 .83775 L p .59637 .73609 L .707 .577 .707 r
F P
0 g
s
.6416 .59643 m .59222 .75484 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.64114 .59307 m .64106 .59291 L p .6416 .59643 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64114 .59307 L .6416 .59643 L .707 .577 .707 r
F
.53356 .83349 m .55368 .83562 L p .58329 .72476 L F P
0 g
s
.55961 .74992 m .53356 .83349 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.57896 .65171 m .58642 .70755 L .56268 .71278 L p .707 .577 .707 r
F P
0 g
s
.58642 .70755 m .57896 .65171 L .61053 .64708 L p .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .55534 .73602 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.73671 .29137 m .6416 .59643 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.65215 .65277 m .66223 .65669 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.76473 .31187 m .6554 .66254 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .73671 .29137 L .76473 .31187 L p .707 .577 .707 r
F P
0 g
s
.64984 .65187 m .64849 .6418 L p .63961 .58945 L .707 .577 .707 r
F P
0 g
s
.64106 .59291 m .63961 .58945 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64984 .65187 L .65215 .65277 L p .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .59222 .75484 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .76473 .31187 L .78115 .33204 L p .707 .577 .707 r
F P
0 g
s
.65151 .68834 m .6556 .70679 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.6556 .70679 m .65971 .72529 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.67592 .727 m .68413 .76395 L .65745 .76663 L p .707 .577 .707 r
F P
0 g
s
.67174 .72811 m .69209 .72818 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66354 .69116 m .66432 .69468 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .67174 .72811 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.68303 .6593 m .68167 .64919 L p .68009 .65322 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .75537 .42638 L .74615 .45575 L .707 .577 .707 r
F
.77408 .36371 m .74692 .4508 L p .75537 .42638 L F P
0 g
s
.78303 .34246 m .78437 .3499 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.6974 .60355 m .69676 .60355 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .78115 .33204 L .78303 .34246 L p .707 .577 .707 r
F P
0 g
s
.78437 .3499 m .71657 .56739 L p .69428 .6217 L .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .70273 .60358 L .6974 .60355 L p .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .6974 .60355 L .68913 .62538 L .707 .577 .707 r
F
.66354 .69116 m .65151 .68834 L p .6587 .70248 L F P
0 g
s
.67174 .72811 m .66432 .69468 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .66354 .69116 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.68375 .69124 m .66576 .69117 L p .6786 .71068 L .707 .577 .707 r
F P
0 g
s
.66576 .69117 m .66354 .69116 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.6786 .71068 m .66576 .69117 L .66499 .69305 L .707 .577 .707 r
F
.69209 .72818 m .68375 .69124 L .6786 .71068 L F
.55924 .70828 m .57896 .65171 L .56268 .71278 L F
.55943 .71243 m .56008 .70938 L .5559 .70391 L F
.49032 .82319 m .53356 .83349 L p .55943 .71243 L F P
0 g
s
.53332 .72159 m .52586 .66575 L .53844 .66175 L p .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53844 .66175 L .53892 .66291 L .707 .577 .707 r
F
.5397 .66479 m .63481 .35973 L p .53218 .62742 L F P
0 g
s
.53905 .66155 m .54978 .65814 L p .54335 .68292 L .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53905 .66155 L .54335 .68292 L .707 .577 .707 r
F
.54978 .65814 m .55725 .71398 L .53332 .72159 L p F P
0 g
s
.5397 .66479 m .49032 .82319 L p .55943 .71243 L .707 .577 .707 r
F P
0 g
s
.53844 .66175 m .53905 .66155 L p .53892 .66291 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .59269 .34442 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.49032 .82319 m .5397 .66479 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.4482 .80789 m .59269 .34442 L .55582 .3256 L p .707 .577 .707 r
F P
0 g
s
.59269 .34442 m .4482 .80789 L .49032 .82319 L p .707 .577 .707 r
F P
0 g
s
.69835 .8196 m .70256 .83806 L .7188 .82954 L p .707 .577 .707 r
F P
0 g
s
.7188 .82954 m .71459 .81109 L .69835 .8196 L p .707 .577 .707 r
F P
0 g
s
.41132 .78906 m .55582 .3256 L .52779 .3051 L p .707 .577 .707 r
F P
0 g
s
.55582 .3256 m .41132 .78906 L .4482 .80789 L p .707 .577 .707 r
F P
0 g
s
.70363 .74243 m .71183 .77937 L .71904 .77213 L p .707 .577 .707 r
F P
0 g
s
.71904 .77213 m .71084 .73519 L .70363 .74243 L p .707 .577 .707 r
F P
0 g
s
.52551 .85016 m .52973 .86862 L .54173 .8713 L p .707 .577 .707 r
F P
0 g
s
.71459 .81109 m .7188 .82954 L .72601 .82233 L p .707 .577 .707 r
F P
0 g
s
.72601 .82233 m .7218 .80387 L .71459 .81109 L p .707 .577 .707 r
F P
0 g
s
.3833 .76856 m .52779 .3051 L .51137 .28493 L p .707 .577 .707 r
F P
0 g
s
.52779 .3051 m .3833 .76856 L .41132 .78906 L p .707 .577 .707 r
F P
0 g
s
.71084 .73519 m .71904 .77213 L .71651 .76684 L p .707 .577 .707 r
F P
0 g
s
.71651 .76684 m .7083 .7299 L .71084 .73519 L p .707 .577 .707 r
F P
0 g
s
.52973 .86862 m .52551 .85016 L .523 .84496 L p .707 .577 .707 r
F P
0 g
s
.523 .84496 m .52721 .86341 L .52973 .86862 L p .707 .577 .707 r
F P
0 g
s
.7218 .80387 m .72601 .82233 L .7235 .81713 L p .707 .577 .707 r
F P
0 g
s
.7235 .81713 m .71928 .79867 L .7218 .80387 L p .707 .577 .707 r
F P
0 g
s
.26087 .70573 m .25341 .64989 L .22252 .65226 L p .707 .577 .707 r
F P
0 g
s
.25341 .64989 m .26087 .70573 L .29245 .7011 L p .707 .577 .707 r
F P
0 g
s
.29245 .7011 m .28498 .64526 L .25341 .64989 L p .707 .577 .707 r
F P
0 g
s
.28498 .64526 m .29245 .7011 L .32163 .69467 L p .707 .577 .707 r
F P
0 g
s
.32163 .69467 m .31416 .63883 L .28498 .64526 L p .707 .577 .707 r
F P
0 g
s
.22999 .7081 m .22252 .65226 L .19535 .65214 L p .707 .577 .707 r
F P
0 g
s
.22252 .65226 m .22999 .7081 L .26087 .70573 L p .707 .577 .707 r
F P
0 g
s
.7083 .7299 m .71651 .76684 L .70448 .76402 L p .707 .577 .707 r
F P
0 g
s
.70448 .76402 m .69627 .72708 L .7083 .7299 L p .707 .577 .707 r
F P
0 g
s
.37579 .76023 m .37158 .74177 L .35534 .75029 L p .707 .577 .707 r
F P
0 g
s
.36062 .68903 m .36883 .72597 L .37603 .71873 L p .707 .577 .707 r
F P
0 g
s
.37603 .71873 m .36783 .68178 L .36062 .68903 L p .707 .577 .707 r
F P
0 g
s
.36783 .68178 m .37603 .71873 L .3735 .71344 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .36883 .72597 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34437 .69752 m .34707 .70966 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34707 .70966 m .35258 .73446 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.3682 .74388 m .36427 .72667 L .3727 .72855 L p .707 .577 .707 r
F P
0 g
s
.3727 .72855 m .37627 .72935 L p .3682 .74388 L .707 .577 .707 r
F P
0 g
s
.36849 .74513 m .3682 .74388 L p .37627 .72935 L .707 .577 .707 r
F P
0 g
s
.36427 .72667 m .36849 .74513 L .34818 .74523 L p .707 .577 .707 r
F P
0 g
s
.36688 .7484 m .51137 .28493 L .50815 .26707 L p .707 .577 .707 r
F P
0 g
s
.36883 .72597 m .36062 .68903 L .34437 .69752 L p .707 .577 .707 r
F P
0 g
s
.3735 .71344 m .36714 .68482 L p .36783 .68178 L .707 .577 .707 r
F P
0 g
s
.36714 .68482 m .36529 .67649 L .3667 .67943 L p .707 .577 .707 r
F P
0 g
s
.3667 .67943 m .36783 .68178 L p .36714 .68482 L .707 .577 .707 r
F P
0 g
s
.36529 .67649 m .3735 .71344 L .36147 .71062 L p .707 .577 .707 r
F P
0 g
s
.50815 .26707 m .36366 .73053 L .36688 .7484 L p .707 .577 .707 r
F P
0 g
s
.51845 .25326 m .41181 .59531 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.41181 .59531 m .37396 .71673 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .37018 .72179 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37018 .72179 m .36366 .73053 L p .36943 .71272 L .707 .577 .707 r
F P
0 g
s
.36943 .71272 m .51845 .25326 L .37018 .72179 L .707 .577 .707 r
F
.50815 .26707 m .51845 .25326 L p .42068 .5547 L F P
0 g
s
.36366 .73053 m .41426 .56823 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.41426 .56823 m .50815 .26707 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.37158 .74177 m .37579 .76023 L .383 .75301 L p .707 .577 .707 r
F P
0 g
s
.383 .75301 m .37879 .73456 L .37158 .74177 L p .707 .577 .707 r
F P
0 g
s
.37879 .73456 m .383 .75301 L .38049 .74781 L p .707 .577 .707 r
F P
0 g
s
.38049 .74781 m .37627 .72935 L .37879 .73456 L p .707 .577 .707 r
F P
0 g
s
.37627 .72935 m .38049 .74781 L .36849 .74513 L p .707 .577 .707 r
F P
0 g
s
.51137 .28493 m .36688 .7484 L .3833 .76856 L p .707 .577 .707 r
F P
0 g
s
.31416 .63883 m .32163 .69467 L .34555 .68705 L p .707 .577 .707 r
F P
0 g
s
.34555 .68705 m .33808 .63121 L .31416 .63883 L p .707 .577 .707 r
F P
0 g
s
.52721 .86341 m .523 .84496 L .53021 .83774 L p .707 .577 .707 r
F P
0 g
s
.26894 .75896 m .26073 .72202 L .23035 .72719 L p .707 .577 .707 r
F P
0 g
s
.26073 .72202 m .26894 .75896 L .30007 .7518 L p .707 .577 .707 r
F P
0 g
s
.30007 .7518 m .29186 .71486 L .26073 .72202 L p .707 .577 .707 r
F P
0 g
s
.29186 .71486 m .30007 .7518 L .32889 .74336 L p .707 .577 .707 r
F P
0 g
s
.32889 .74336 m .32068 .70642 L .29186 .71486 L p .707 .577 .707 r
F P
0 g
s
.53021 .83774 m .53442 .8562 L .52721 .86341 L p .707 .577 .707 r
F P
0 g
s
.19535 .65214 m .20281 .70798 L .22999 .7081 L p .707 .577 .707 r
F P
0 g
s
.71928 .79867 m .7235 .81713 L .7115 .81444 L p .707 .577 .707 r
F P
0 g
s
.7115 .81444 m .70728 .79599 L .71928 .79867 L p .707 .577 .707 r
F P
0 g
s
.23035 .72719 m .23855 .76414 L .26894 .75896 L p .707 .577 .707 r
F P
0 g
s
.20281 .70798 m .19535 .65214 L .17455 .64953 L p .707 .577 .707 r
F P
0 g
s
.23855 .76414 m .23035 .72719 L .20367 .72987 L p .707 .577 .707 r
F P
0 g
s
.276 .79364 m .27179 .77519 L .24144 .78055 L p .707 .577 .707 r
F P
0 g
s
.27179 .77519 m .276 .79364 L .30709 .78631 L p .707 .577 .707 r
F P
0 g
s
.30709 .78631 m .30288 .76786 L .27179 .77519 L p .707 .577 .707 r
F P
0 g
s
.30288 .76786 m .30709 .78631 L .33588 .77773 L p .707 .577 .707 r
F P
0 g
s
.33588 .77773 m .33167 .75928 L .30288 .76786 L p .707 .577 .707 r
F P
0 g
s
.32068 .70642 m .32889 .74336 L .35258 .73446 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .34437 .69752 L .32068 .70642 L p .707 .577 .707 r
F P
0 g
s
.24144 .78055 m .24566 .79901 L .276 .79364 L p .707 .577 .707 r
F P
0 g
s
.20367 .72987 m .21188 .76682 L .23855 .76414 L p .707 .577 .707 r
F P
0 g
s
.33808 .63121 m .34555 .68705 L .36187 .67901 L p .707 .577 .707 r
F P
0 g
s
.36187 .67901 m .35441 .62317 L .33808 .63121 L p .707 .577 .707 r
F P
0 g
s
.24566 .79901 m .24144 .78055 L .21481 .78343 L p .707 .577 .707 r
F P
0 g
s
.17455 .64953 m .18202 .70537 L .20281 .70798 L p .707 .577 .707 r
F P
0 g
s
.69627 .72708 m .70448 .76402 L .68413 .76395 L p .707 .577 .707 r
F P
0 g
s
.21481 .78343 m .21903 .80188 L .24566 .79901 L p .707 .577 .707 r
F P
0 g
s
.33167 .75928 m .33588 .77773 L .35955 .76874 L p .707 .577 .707 r
F P
0 g
s
.35955 .76874 m .35534 .75029 L .33167 .75928 L p .707 .577 .707 r
F P
0 g
s
.21188 .76682 m .20367 .72987 L .18332 .7298 L p .707 .577 .707 r
F P
0 g
s
.18202 .70537 m .17455 .64953 L .16216 .64471 L p .707 .577 .707 r
F P
0 g
s
.18332 .7298 m .19153 .76674 L .21188 .76682 L p .707 .577 .707 r
F P
0 g
s
.21903 .80188 m .21481 .78343 L .1945 .78353 L p .707 .577 .707 r
F P
0 g
s
.70728 .79599 m .7115 .81444 L .69119 .81454 L p .707 .577 .707 r
F P
0 g
s
.69119 .81454 m .68697 .79609 L .70728 .79599 L p .707 .577 .707 r
F P
0 g
s
.1945 .78353 m .19872 .80198 L .21903 .80188 L p .707 .577 .707 r
F P
0 g
s
.35534 .75029 m .35955 .76874 L .37579 .76023 L p .707 .577 .707 r
F P
0 g
s
.35441 .62317 m .36187 .67901 L .369 .67132 L p .707 .577 .707 r
F P
0 g
s
.369 .67132 m .36153 .61548 L .35441 .62317 L p .707 .577 .707 r
F P
0 g
s
.16216 .64471 m .16963 .70055 L .18202 .70537 L p .707 .577 .707 r
F P
0 g
s
.19153 .76674 m .18332 .7298 L .17129 .72698 L p .707 .577 .707 r
F P
0 g
s
.17129 .72698 m .1795 .76392 L .19153 .76674 L p .707 .577 .707 r
F P
0 g
s
.19872 .80198 m .1945 .78353 L .1825 .78084 L p .707 .577 .707 r
F P
0 g
s
.16963 .70055 m .16216 .64471 L .1594 .63813 L p .707 .577 .707 r
F P
0 g
s
.68697 .79609 m .69119 .81454 L .66456 .81742 L p .707 .577 .707 r
F P
0 g
s
.66456 .81742 m .66034 .79896 L .68697 .79609 L p .707 .577 .707 r
F P
0 g
s
.1825 .78084 m .18672 .7993 L .19872 .80198 L p .707 .577 .707 r
F P
0 g
s
.36153 .61548 m .369 .67132 L .36623 .66474 L p .707 .577 .707 r
F P
0 g
s
.36623 .66474 m .35877 .6089 L .36153 .61548 L p .707 .577 .707 r
F P
0 g
s
.1594 .63813 m .16686 .69397 L .16963 .70055 L p .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .51845 .25326 L .54126 .24486 L p .707 .577 .707 r
F P
0 g
s
.66034 .79896 m .66456 .81742 L .63421 .82278 L p .707 .577 .707 r
F P
0 g
s
.1795 .76392 m .17129 .72698 L .16876 .72169 L p .707 .577 .707 r
F P
0 g
s
.16876 .72169 m .17696 .75863 L .1795 .76392 L p .707 .577 .707 r
F P
0 g
s
.18672 .7993 m .1825 .78084 L .17999 .77564 L p .707 .577 .707 r
F P
0 g
s
.16686 .69397 m .1594 .63813 L .16653 .63044 L p .707 .577 .707 r
F P
0 g
s
.17999 .77564 m .1842 .7941 L .18672 .7993 L p .707 .577 .707 r
F P
0 g
s
.35877 .6089 m .36623 .66474 L .35385 .65992 L p .707 .577 .707 r
F P
0 g
s
.35385 .65992 m .34638 .60407 L .35877 .6089 L p .707 .577 .707 r
F P
0 g
s
.16653 .63044 m .17399 .68628 L .16686 .69397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17696 .75863 m .16876 .72169 L .17596 .71444 L p .707 .577 .707 r
F P
0 g
s
.54126 .24486 m .39677 .70832 L .37396 .71673 L p .707 .577 .707 r
F P
0 g
s
.39677 .70832 m .54126 .24486 L .57435 .24268 L p .707 .577 .707 r
F P
0 g
s
.17596 .71444 m .18417 .75139 L .17696 .75863 L p .707 .577 .707 r
F P
0 g
s
.36147 .71062 m .35326 .67367 L .36529 .67649 L p .707 .577 .707 r
F P
0 g
s
.1842 .7941 m .17999 .77564 L .1872 .76843 L p .707 .577 .707 r
F P
0 g
s
.17399 .68628 m .16653 .63044 L .18285 .62239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1872 .76843 m .19141 .78688 L .1842 .7941 L p .707 .577 .707 r
F P
0 g
s
.34638 .60407 m .35385 .65992 L .33305 .65731 L p .707 .577 .707 r
F P
0 g
s
.33305 .65731 m .32558 .60147 L .34638 .60407 L p .707 .577 .707 r
F P
0 g
s
.18285 .62239 m .19031 .67824 L .17399 .68628 L p .707 .577 .707 r
F P
0 g
s
.18417 .75139 m .17596 .71444 L .19221 .70596 L p .707 .577 .707 r
F P
0 g
s
.42985 .70615 m .57435 .24268 L .61448 .24695 L p .707 .577 .707 r
F P
0 g
s
.57435 .24268 m .42985 .70615 L .39677 .70832 L p .707 .577 .707 r
F P
0 g
s
.19031 .67824 m .18285 .62239 L .20677 .61478 L p .707 .577 .707 r
F P
0 g
s
.19221 .70596 m .20042 .7429 L .18417 .75139 L p .707 .577 .707 r
F P
0 g
s
.35326 .67367 m .36147 .71062 L .34112 .71054 L p .707 .577 .707 r
F P
0 g
s
.34112 .71054 m .33291 .6736 L .35326 .67367 L p .707 .577 .707 r
F P
0 g
s
.55534 .73602 m .69983 .27255 L .73671 .29137 L p .707 .577 .707 r
F P
0 g
s
.19141 .78688 m .1872 .76843 L .20344 .75991 L p .707 .577 .707 r
F P
0 g
s
.20344 .75991 m .20765 .77837 L .19141 .78688 L p .707 .577 .707 r
F P
0 g
s
.32558 .60147 m .33305 .65731 L .30588 .65719 L p .707 .577 .707 r
F P
0 g
s
.30588 .65719 m .29841 .60135 L .32558 .60147 L p .707 .577 .707 r
F P
0 g
s
.34818 .74523 m .34397 .72677 L .36427 .72667 L p .707 .577 .707 r
F P
0 g
s
.20677 .61478 m .21424 .67062 L .19031 .67824 L p .707 .577 .707 r
F P
0 g
s
.46998 .71042 m .61448 .24695 L .65771 .25724 L p .707 .577 .707 r
F P
0 g
s
.61448 .24695 m .46998 .71042 L .42985 .70615 L p .707 .577 .707 r
F P
0 g
s
.20042 .7429 m .19221 .70596 L .2159 .69706 L p .707 .577 .707 r
F P
0 g
s
.21424 .67062 m .20677 .61478 L .23595 .60835 L p .707 .577 .707 r
F P
0 g
s
.69983 .27255 m .55534 .73602 L .51322 .72071 L p .707 .577 .707 r
F P
0 g
s
.51322 .72071 m .65771 .25724 L .69983 .27255 L p .707 .577 .707 r
F P
0 g
s
.29841 .60135 m .30588 .65719 L .27499 .65956 L p .707 .577 .707 r
F P
0 g
s
.27499 .65956 m .26753 .60372 L .29841 .60135 L p .707 .577 .707 r
F P
0 g
s
.33291 .6736 m .34112 .71054 L .31444 .71323 L p .707 .577 .707 r
F P
0 g
s
.31444 .71323 m .30624 .67628 L .33291 .6736 L p .707 .577 .707 r
F P
0 g
s
.65771 .25724 m .51322 .72071 L .46998 .71042 L p .707 .577 .707 r
F P
0 g
s
.2159 .69706 m .22411 .734 L .20042 .7429 L p .707 .577 .707 r
F P
0 g
s
.20765 .77837 m .20344 .75991 L .22711 .75092 L p .707 .577 .707 r
F P
0 g
s
.24341 .66419 m .23595 .60835 L .26753 .60372 L p .707 .577 .707 r
F P
0 g
s
.23595 .60835 m .24341 .66419 L .21424 .67062 L p .707 .577 .707 r
F P
0 g
s
.26753 .60372 m .27499 .65956 L .24341 .66419 L p .707 .577 .707 r
F P
0 g
s
.22711 .75092 m .23133 .76938 L .20765 .77837 L p .707 .577 .707 r
F P
0 g
s
.74108 .65705 m .73362 .60121 L .70273 .60358 L p .707 .577 .707 r
F P
0 g
s
.73362 .60121 m .74108 .65705 L .77266 .65242 L p .707 .577 .707 r
F P
0 g
s
.77266 .65242 m .7652 .59658 L .73362 .60121 L p .707 .577 .707 r
F P
0 g
s
.34397 .72677 m .34818 .74523 L .32155 .7481 L p .707 .577 .707 r
F P
0 g
s
.32155 .7481 m .31734 .72964 L .34397 .72677 L p .707 .577 .707 r
F P
0 g
s
.7652 .59658 m .77266 .65242 L .80184 .64599 L p .707 .577 .707 r
F P
0 g
s
.80184 .64599 m .79437 .59015 L .7652 .59658 L p .707 .577 .707 r
F P
0 g
s
.22411 .734 m .2159 .69706 L .24472 .68861 L p .707 .577 .707 r
F P
0 g
s
.70273 .60358 m .7102 .65942 L .74108 .65705 L p .707 .577 .707 r
F P
0 g
s
.30624 .67628 m .31444 .71323 L .28406 .7184 L p .707 .577 .707 r
F P
0 g
s
.28406 .7184 m .27585 .68145 L .30624 .67628 L p .707 .577 .707 r
F P
0 g
s
.24472 .68861 m .25293 .72556 L .22411 .734 L p .707 .577 .707 r
F P
0 g
s
.79437 .59015 m .80184 .64599 L .82576 .63837 L p .707 .577 .707 r
F P
0 g
s
.82576 .63837 m .8183 .58253 L .79437 .59015 L p .707 .577 .707 r
F P
0 g
s
.23133 .76938 m .22711 .75092 L .2559 .74234 L p .707 .577 .707 r
F P
0 g
s
.25293 .72556 m .24472 .68861 L .27585 .68145 L p .707 .577 .707 r
F P
0 g
s
.27585 .68145 m .28406 .7184 L .25293 .72556 L p .707 .577 .707 r
F P
0 g
s
.2559 .74234 m .26011 .7608 L .23133 .76938 L p .707 .577 .707 r
F P
0 g
s
.31734 .72964 m .32155 .7481 L .2912 .75346 L p .707 .577 .707 r
F P
0 g
s
.2912 .75346 m .28699 .73501 L .31734 .72964 L p .707 .577 .707 r
F P
0 g
s
.74915 .72033 m .74095 .68338 L .71056 .68856 L p .707 .577 .707 r
F P
0 g
s
.74095 .68338 m .74915 .72033 L .78028 .71317 L p .707 .577 .707 r
F P
0 g
s
.78028 .71317 m .77207 .67622 L .74095 .68338 L p .707 .577 .707 r
F P
0 g
s
.77207 .67622 m .78028 .71317 L .8091 .70473 L p .707 .577 .707 r
F P
0 g
s
.8091 .70473 m .8009 .66778 L .77207 .67622 L p .707 .577 .707 r
F P
0 g
s
.26011 .7608 m .2559 .74234 L .28699 .73501 L p .707 .577 .707 r
F P
0 g
s
.71056 .68856 m .71877 .7255 L .74915 .72033 L p .707 .577 .707 r
F P
0 g
s
.28699 .73501 m .2912 .75346 L .26011 .7608 L p .707 .577 .707 r
F P
0 g
s
.71877 .7255 m .71056 .68856 L .68389 .69124 L p .707 .577 .707 r
F P
0 g
s
.8009 .66778 m .8091 .70473 L .83279 .69582 L p .707 .577 .707 r
F P
0 g
s
.83279 .69582 m .82459 .65888 L .8009 .66778 L p .707 .577 .707 r
F P
0 g
s
.8183 .58253 m .82576 .63837 L .84209 .63033 L p .707 .577 .707 r
F P
0 g
s
.84209 .63033 m .83462 .57449 L .8183 .58253 L p .707 .577 .707 r
F P
0 g
s
.75621 .77092 m .752 .75247 L .72166 .75783 L p .707 .577 .707 r
F P
0 g
s
.752 .75247 m .75621 .77092 L .7873 .76359 L p .707 .577 .707 r
F P
0 g
s
.7873 .76359 m .78309 .74514 L .752 .75247 L p .707 .577 .707 r
F P
0 g
s
.68389 .69124 m .69209 .72818 L .71877 .7255 L p .707 .577 .707 r
F P
0 g
s
.78309 .74514 m .7873 .76359 L .81609 .75501 L p .707 .577 .707 r
F P
0 g
s
.81609 .75501 m .81188 .73656 L .78309 .74514 L p .707 .577 .707 r
F P
0 g
s
.72166 .75783 m .72587 .77629 L .75621 .77092 L p .707 .577 .707 r
F P
0 g
s
.72587 .77629 m .72166 .75783 L .69503 .7607 L p .707 .577 .707 r
F P
0 g
s
.69503 .7607 m .69924 .77916 L .72587 .77629 L p .707 .577 .707 r
F P
0 g
s
.81188 .73656 m .81609 .75501 L .83977 .74602 L p .707 .577 .707 r
F P
0 g
s
.83977 .74602 m .83555 .72757 L .81188 .73656 L p .707 .577 .707 r
F P
0 g
s
.82459 .65888 m .83279 .69582 L .84904 .68734 L p .707 .577 .707 r
F P
0 g
s
.84904 .68734 m .84083 .65039 L .82459 .65888 L p .707 .577 .707 r
F P
0 g
s
.83462 .57449 m .84209 .63033 L .84921 .62264 L p .707 .577 .707 r
F P
0 g
s
.84921 .62264 m .84175 .5668 L .83462 .57449 L p .707 .577 .707 r
F P
0 g
s
.69924 .77916 m .69503 .7607 L .67472 .7608 L p .707 .577 .707 r
F P
0 g
s
.67472 .7608 m .67893 .77926 L .69924 .77916 L p .707 .577 .707 r
F P
0 g
s
.83555 .72757 m .83977 .74602 L .856 .7375 L p .707 .577 .707 r
F P
0 g
s
.856 .7375 m .85179 .71905 L .83555 .72757 L p .707 .577 .707 r
F P
0 g
s
.84083 .65039 m .84904 .68734 L .85625 .68009 L p .707 .577 .707 r
F P
0 g
s
.85625 .68009 m .84804 .64315 L .84083 .65039 L p .707 .577 .707 r
F P
0 g
s
.67893 .77926 m .67472 .7608 L .66272 .75812 L p .707 .577 .707 r
F P
0 g
s
.66272 .75812 m .66693 .77658 L .67893 .77926 L p .707 .577 .707 r
F P
0 g
s
.84175 .5668 m .84921 .62264 L .84645 .61606 L p .707 .577 .707 r
F P
0 g
s
.84645 .61606 m .83898 .56022 L .84175 .5668 L p .707 .577 .707 r
F P
0 g
s
.63961 .58945 m .64708 .64529 L .64984 .65187 L p .707 .577 .707 r
F P
0 g
s
.85179 .71905 m .856 .7375 L .86322 .73029 L p .707 .577 .707 r
F P
0 g
s
.86322 .73029 m .859 .71183 L .85179 .71905 L p .707 .577 .707 r
F P
0 g
s
.65971 .72529 m .65151 .68834 L .64897 .68305 L p .707 .577 .707 r
F P
0 g
s
.64897 .68305 m .65718 .72 L .65971 .72529 L p .707 .577 .707 r
F P
0 g
s
.84804 .64315 m .85625 .68009 L .85371 .6748 L p .707 .577 .707 r
F P
0 g
s
.85371 .6748 m .8455 .63786 L .84804 .64315 L p .707 .577 .707 r
F P
0 g
s
.64708 .64529 m .63961 .58945 L .64674 .58176 L p .707 .577 .707 r
F P
0 g
s
.66693 .77658 m .66272 .75812 L .6602 .75292 L p .707 .577 .707 r
F P
0 g
s
.6602 .75292 m .66441 .77138 L .66693 .77658 L p .707 .577 .707 r
F P
0 g
s
.83898 .56022 m .84645 .61606 L .83406 .61124 L p .707 .577 .707 r
F P
0 g
s
.83406 .61124 m .8266 .55539 L .83898 .56022 L p .707 .577 .707 r
F P
0 g
s
.64674 .58176 m .6542 .6376 L .64708 .64529 L p .707 .577 .707 r
F P
0 g
s
.859 .71183 m .86322 .73029 L .8607 .72509 L p .707 .577 .707 r
F P
0 g
s
.8607 .72509 m .85649 .70663 L .859 .71183 L p .707 .577 .707 r
F P
0 g
s
.39807 .61369 m .39061 .55785 L .35972 .56022 L p .707 .577 .707 r
F P
0 g
s
.39061 .55785 m .39807 .61369 L .42965 .60906 L p .707 .577 .707 r
F P
0 g
s
.42965 .60906 m .42219 .55322 L .39061 .55785 L p .707 .577 .707 r
F P
0 g
s
.65718 .72 m .64897 .68305 L .65618 .67581 L p .707 .577 .707 r
F P
0 g
s
.42219 .55322 m .42965 .60906 L .45883 .60263 L p .707 .577 .707 r
F P
0 g
s
.45883 .60263 m .45136 .54679 L .42219 .55322 L p .707 .577 .707 r
F P
0 g
s
.65618 .67581 m .66438 .71275 L .65718 .72 L p .707 .577 .707 r
F P
0 g
s
.36719 .61606 m .35972 .56022 L .33255 .5601 L p .707 .577 .707 r
F P
0 g
s
.35972 .56022 m .36719 .61606 L .39807 .61369 L p .707 .577 .707 r
F P
0 g
s
.6542 .6376 m .64674 .58176 L .66306 .57371 L p .707 .577 .707 r
F P
0 g
s
.8455 .63786 m .85371 .6748 L .84168 .67198 L p .707 .577 .707 r
F P
0 g
s
.84168 .67198 m .83347 .63504 L .8455 .63786 L p .707 .577 .707 r
F P
0 g
s
.45136 .54679 m .45883 .60263 L .48275 .59502 L p .707 .577 .707 r
F P
0 g
s
.48275 .59502 m .47529 .53917 L .45136 .54679 L p .707 .577 .707 r
F P
0 g
s
.66441 .77138 m .6602 .75292 L .66742 .74571 L p .707 .577 .707 r
F P
0 g
s
.40614 .66692 m .39794 .62998 L .36755 .63515 L p .707 .577 .707 r
F P
0 g
s
.39794 .62998 m .40614 .66692 L .43727 .65977 L p .707 .577 .707 r
F P
0 g
s
.43727 .65977 m .42906 .62282 L .39794 .62998 L p .707 .577 .707 r
F P
0 g
s
.42906 .62282 m .43727 .65977 L .46609 .65132 L p .707 .577 .707 r
F P
0 g
s
.46609 .65132 m .45789 .61438 L .42906 .62282 L p .707 .577 .707 r
F P
0 g
s
.66742 .74571 m .67163 .76416 L .66441 .77138 L p .707 .577 .707 r
F P
0 g
s
.8266 .55539 m .83406 .61124 L .81326 .60863 L p .707 .577 .707 r
F P
0 g
s
.81326 .60863 m .8058 .55279 L .8266 .55539 L p .707 .577 .707 r
F P
0 g
s
.33255 .5601 m .34002 .61594 L .36719 .61606 L p .707 .577 .707 r
F P
0 g
s
.66306 .57371 m .67053 .62956 L .6542 .6376 L p .707 .577 .707 r
F P
0 g
s
.85649 .70663 m .8607 .72509 L .8487 .72241 L p .707 .577 .707 r
F P
0 g
s
.8487 .72241 m .84449 .70395 L .85649 .70663 L p .707 .577 .707 r
F P
0 g
s
.36755 .63515 m .37576 .6721 L .40614 .66692 L p .707 .577 .707 r
F P
0 g
s
.34002 .61594 m .33255 .5601 L .31175 .55749 L p .707 .577 .707 r
F P
0 g
s
.37576 .6721 m .36755 .63515 L .34088 .63783 L p .707 .577 .707 r
F P
0 g
s
.4132 .70161 m .40899 .68315 L .37865 .68851 L p .707 .577 .707 r
F P
0 g
s
.40899 .68315 m .4132 .70161 L .44429 .69428 L p .707 .577 .707 r
F P
0 g
s
.44429 .69428 m .44008 .67582 L .40899 .68315 L p .707 .577 .707 r
F P
0 g
s
.44008 .67582 m .44429 .69428 L .47308 .68569 L p .707 .577 .707 r
F P
0 g
s
.47308 .68569 m .46887 .66724 L .44008 .67582 L p .707 .577 .707 r
F P
0 g
s
.45789 .61438 m .46609 .65132 L .48978 .64242 L p .707 .577 .707 r
F P
0 g
s
.48978 .64242 m .48158 .60548 L .45789 .61438 L p .707 .577 .707 r
F P
0 g
s
.37865 .68851 m .38286 .70697 L .4132 .70161 L p .707 .577 .707 r
F P
0 g
s
.66438 .71275 m .65618 .67581 L .67242 .66732 L p .707 .577 .707 r
F P
0 g
s
.34088 .63783 m .34908 .67478 L .37576 .6721 L p .707 .577 .707 r
F P
0 g
s
.47529 .53917 m .48275 .59502 L .49908 .58697 L p .707 .577 .707 r
F P
0 g
s
.49908 .58697 m .49161 .53113 L .47529 .53917 L p .707 .577 .707 r
F P
0 g
s
.67053 .62956 m .66306 .57371 L .68698 .5661 L p .707 .577 .707 r
F P
0 g
s
.38286 .70697 m .37865 .68851 L .35202 .69139 L p .707 .577 .707 r
F P
0 g
s
.31175 .55749 m .31922 .61334 L .34002 .61594 L p .707 .577 .707 r
F P
0 g
s
.67242 .66732 m .68063 .70426 L .66438 .71275 L p .707 .577 .707 r
F P
0 g
s
.83347 .63504 m .84168 .67198 L .82133 .67191 L p .707 .577 .707 r
F P
0 g
s
.82133 .67191 m .81313 .63496 L .83347 .63504 L p .707 .577 .707 r
F P
0 g
s
.35202 .69139 m .35623 .70984 L .38286 .70697 L p .707 .577 .707 r
F P
0 g
s
.46887 .66724 m .47308 .68569 L .49676 .67671 L p .707 .577 .707 r
F P
0 g
s
.49676 .67671 m .49254 .65825 L .46887 .66724 L p .707 .577 .707 r
F P
0 g
s
.34908 .67478 m .34088 .63783 L .32053 .63776 L p .707 .577 .707 r
F P
0 g
s
.8058 .55279 m .81326 .60863 L .78609 .60851 L p .707 .577 .707 r
F P
0 g
s
.78609 .60851 m .77863 .55267 L .8058 .55279 L p .707 .577 .707 r
F P
0 g
s
.67163 .76416 m .66742 .74571 L .68365 .73719 L p .707 .577 .707 r
F P
0 g
s
.68698 .5661 m .69445 .62194 L .67053 .62956 L p .707 .577 .707 r
F P
0 g
s
.48158 .60548 m .48978 .64242 L .50603 .63393 L p .707 .577 .707 r
F P
0 g
s
.50603 .63393 m .49782 .59699 L .48158 .60548 L p .707 .577 .707 r
F P
0 g
s
.31922 .61334 m .31175 .55749 L .29937 .55267 L p .707 .577 .707 r
F P
0 g
s
.68365 .73719 m .68787 .75564 L .67163 .76416 L p .707 .577 .707 r
F P
0 g
s
.32053 .63776 m .32873 .6747 L .34908 .67478 L p .707 .577 .707 r
F P
0 g
s
.35623 .70984 m .35202 .69139 L .33171 .69149 L p .707 .577 .707 r
F P
0 g
s
.84449 .70395 m .8487 .72241 L .82839 .72251 L p .707 .577 .707 r
F P
0 g
s
.82839 .72251 m .82418 .70405 L .84449 .70395 L p .707 .577 .707 r
F P
0 g
s
.69445 .62194 m .68698 .5661 L .71616 .55967 L p .707 .577 .707 r
F P
0 g
s
.33171 .69149 m .33592 .70994 L .35623 .70984 L p .707 .577 .707 r
F P
0 g
s
.68063 .70426 m .67242 .66732 L .69612 .65842 L p .707 .577 .707 r
F P
0 g
s
.49254 .65825 m .49676 .67671 L .51299 .66819 L p .707 .577 .707 r
F P
0 g
s
.51299 .66819 m .50878 .64973 L .49254 .65825 L p .707 .577 .707 r
F P
0 g
s
.49161 .53113 m .49908 .58697 L .5062 .57928 L p .707 .577 .707 r
F P
0 g
s
.5062 .57928 m .49874 .52344 L .49161 .53113 L p .707 .577 .707 r
F P
0 g
s
.77863 .55267 m .78609 .60851 L .75521 .61088 L p .707 .577 .707 r
F P
0 g
s
.75521 .61088 m .74774 .55504 L .77863 .55267 L p .707 .577 .707 r
F P
0 g
s
.29937 .55267 m .30683 .60851 L .31922 .61334 L p .707 .577 .707 r
F P
0 g
s
.81313 .63496 m .82133 .67191 L .79466 .67459 L p .707 .577 .707 r
F P
0 g
s
.79466 .67459 m .78645 .63765 L .81313 .63496 L p .707 .577 .707 r
F P
0 g
s
.69612 .65842 m .70432 .69536 L .68063 .70426 L p .707 .577 .707 r
F P
0 g
s
.72363 .61551 m .71616 .55967 L .74774 .55504 L p .707 .577 .707 r
F P
0 g
s
.71616 .55967 m .72363 .61551 L .69445 .62194 L p .707 .577 .707 r
F P
0 g
s
.32873 .6747 m .32053 .63776 L .3085 .63494 L p .707 .577 .707 r
F P
0 g
s
.74774 .55504 m .75521 .61088 L .72363 .61551 L p .707 .577 .707 r
F P
0 g
s
.68787 .75564 m .68365 .73719 L .70733 .7282 L p .707 .577 .707 r
F P
0 g
s
.3085 .63494 m .3167 .67188 L .32873 .6747 L p .707 .577 .707 r
F P
0 g
s
.49782 .59699 m .50603 .63393 L .51324 .62669 L p .707 .577 .707 r
F P
0 g
s
.51324 .62669 m .50503 .58975 L .49782 .59699 L p .707 .577 .707 r
F P
0 g
s
.70733 .7282 m .71154 .74665 L .68787 .75564 L p .707 .577 .707 r
F P
0 g
s
.70432 .69536 m .69612 .65842 L .72494 .64998 L p .707 .577 .707 r
F P
0 g
s
.33592 .70994 m .33171 .69149 L .31971 .6888 L p .707 .577 .707 r
F P
0 g
s
.30683 .60851 m .29937 .55267 L .2966 .54609 L p .707 .577 .707 r
F P
0 g
s
.82418 .70405 m .82839 .72251 L .80176 .72538 L p .707 .577 .707 r
F P
0 g
s
.80176 .72538 m .79755 .70692 L .82418 .70405 L p .707 .577 .707 r
F P
0 g
s
.78645 .63765 m .79466 .67459 L .76427 .67976 L p .707 .577 .707 r
F P
0 g
s
.76427 .67976 m .75606 .64282 L .78645 .63765 L p .707 .577 .707 r
F P
0 g
s
.31971 .6888 m .32392 .70726 L .33592 .70994 L p .707 .577 .707 r
F P
0 g
s
.72494 .64998 m .73314 .68692 L .70432 .69536 L p .707 .577 .707 r
F P
0 g
s
.50878 .64973 m .51299 .66819 L .52021 .66097 L p .707 .577 .707 r
F P
0 g
s
.52021 .66097 m .51599 .64252 L .50878 .64973 L p .707 .577 .707 r
F P
0 g
s
.73314 .68692 m .72494 .64998 L .75606 .64282 L p .707 .577 .707 r
F P
0 g
s
.75606 .64282 m .76427 .67976 L .73314 .68692 L p .707 .577 .707 r
F P
0 g
s
.49874 .52344 m .5062 .57928 L .50344 .5727 L p .707 .577 .707 r
F P
0 g
s
.50344 .5727 m .49597 .51686 L .49874 .52344 L p .707 .577 .707 r
F P
0 g
s
.2966 .54609 m .30407 .60193 L .30683 .60851 L p .707 .577 .707 r
F P
0 g
s
.71154 .74665 m .70733 .7282 L .73612 .71962 L p .707 .577 .707 r
F P
0 g
s
.73612 .71962 m .74033 .73807 L .71154 .74665 L p .707 .577 .707 r
F P
0 g
s
.79755 .70692 m .80176 .72538 L .77142 .73074 L p .707 .577 .707 r
F P
0 g
s
.77142 .73074 m .7672 .71229 L .79755 .70692 L p .707 .577 .707 r
F P
0 g
s
.3167 .67188 m .3085 .63494 L .30596 .62965 L p .707 .577 .707 r
F P
0 g
s
.74033 .73807 m .73612 .71962 L .7672 .71229 L p .707 .577 .707 r
F P
0 g
s
.7672 .71229 m .77142 .73074 L .74033 .73807 L p .707 .577 .707 r
F P
0 g
s
.30596 .62965 m .31417 .66659 L .3167 .67188 L p .707 .577 .707 r
F P
0 g
s
.50503 .58975 m .51324 .62669 L .5107 .6214 L p .707 .577 .707 r
F P
0 g
s
.5107 .6214 m .50249 .58445 L .50503 .58975 L p .707 .577 .707 r
F P
0 g
s
.32392 .70726 m .31971 .6888 L .31719 .6836 L p .707 .577 .707 r
F P
0 g
s
.30407 .60193 m .2966 .54609 L .30373 .5384 L p .707 .577 .707 r
F P
0 g
s
.31719 .6836 m .3214 .70206 L .32392 .70726 L p .707 .577 .707 r
F P
0 g
s
.51599 .64252 m .52021 .66097 L .51769 .65577 L p .707 .577 .707 r
F P
0 g
s
.51769 .65577 m .51348 .63731 L .51599 .64252 L p .707 .577 .707 r
F P
0 g
s
.49597 .51686 m .50344 .5727 L .49105 .56788 L p .707 .577 .707 r
F P
0 g
s
.49105 .56788 m .48359 .51204 L .49597 .51686 L p .707 .577 .707 r
F P
0 g
s
.30373 .5384 m .31119 .59424 L .30407 .60193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31417 .66659 m .30596 .62965 L .31317 .62241 L p .707 .577 .707 r
F P
0 g
s
.31317 .62241 m .32137 .65935 L .31417 .66659 L p .707 .577 .707 r
F P
0 g
s
.50249 .58445 m .5107 .6214 L .49867 .61858 L p .707 .577 .707 r
F P
0 g
s
.49867 .61858 m .49046 .58163 L .50249 .58445 L p .707 .577 .707 r
F P
0 g
s
.3214 .70206 m .31719 .6836 L .3244 .67639 L p .707 .577 .707 r
F P
0 g
s
.31119 .59424 m .30373 .5384 L .32005 .53036 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3244 .67639 m .32862 .69485 L .3214 .70206 L p .707 .577 .707 r
F P
0 g
s
.51348 .63731 m .51769 .65577 L .50569 .65309 L p .707 .577 .707 r
F P
0 g
s
.50569 .65309 m .50148 .63463 L .51348 .63731 L p .707 .577 .707 r
F P
0 g
s
.48359 .51204 m .49105 .56788 L .47025 .56527 L p .707 .577 .707 r
F P
0 g
s
.47025 .56527 m .46279 .50943 L .48359 .51204 L p .707 .577 .707 r
F P
0 g
s
.32005 .53036 m .32752 .5862 L .31119 .59424 L p .707 .577 .707 r
F P
0 g
s
.32137 .65935 m .31317 .62241 L .32941 .61392 L p .707 .577 .707 r
F P
0 g
s
.32752 .5862 m .32005 .53036 L .34397 .52274 L p .707 .577 .707 r
F P
0 g
s
.32941 .61392 m .33762 .65086 L .32137 .65935 L p .707 .577 .707 r
F P
0 g
s
.49046 .58163 m .49867 .61858 L .47832 .61851 L p .707 .577 .707 r
F P
0 g
s
.47832 .61851 m .47012 .58156 L .49046 .58163 L p .707 .577 .707 r
F P
0 g
s
.32862 .69485 m .3244 .67639 L .34064 .66787 L p .707 .577 .707 r
F P
0 g
s
.34064 .66787 m .34486 .68633 L .32862 .69485 L p .707 .577 .707 r
F P
0 g
s
.46279 .50943 m .47025 .56527 L .44308 .56515 L p .707 .577 .707 r
F P
0 g
s
.44308 .56515 m .43562 .50931 L .46279 .50943 L p .707 .577 .707 r
F P
0 g
s
.50148 .63463 m .50569 .65309 L .48538 .65319 L p .707 .577 .707 r
F P
0 g
s
.48538 .65319 m .48117 .63473 L .50148 .63463 L p .707 .577 .707 r
F P
0 g
s
.34397 .52274 m .35144 .57858 L .32752 .5862 L p .707 .577 .707 r
F P
0 g
s
.33762 .65086 m .32941 .61392 L .3531 .60502 L p .707 .577 .707 r
F P
0 g
s
.35144 .57858 m .34397 .52274 L .37315 .51631 L p .707 .577 .707 r
F P
0 g
s
.43562 .50931 m .44308 .56515 L .41219 .56752 L p .707 .577 .707 r
F P
0 g
s
.41219 .56752 m .40473 .51168 L .43562 .50931 L p .707 .577 .707 r
F P
0 g
s
.47012 .58156 m .47832 .61851 L .45165 .62119 L p .707 .577 .707 r
F P
0 g
s
.45165 .62119 m .44344 .58424 L .47012 .58156 L p .707 .577 .707 r
F P
0 g
s
.3531 .60502 m .36131 .64196 L .33762 .65086 L p .707 .577 .707 r
F P
0 g
s
.34486 .68633 m .34064 .66787 L .36432 .65888 L p .707 .577 .707 r
F P
0 g
s
.38062 .57215 m .37315 .51631 L .40473 .51168 L p .707 .577 .707 r
F P
0 g
s
.37315 .51631 m .38062 .57215 L .35144 .57858 L p .707 .577 .707 r
F P
0 g
s
.40473 .51168 m .41219 .56752 L .38062 .57215 L p .707 .577 .707 r
F P
0 g
s
.36432 .65888 m .36853 .67734 L .34486 .68633 L p .707 .577 .707 r
F P
0 g
s
.48117 .63473 m .48538 .65319 L .45875 .65606 L p .707 .577 .707 r
F P
0 g
s
.45875 .65606 m .45454 .6376 L .48117 .63473 L p .707 .577 .707 r
F P
0 g
s
.36131 .64196 m .3531 .60502 L .38193 .59657 L p .707 .577 .707 r
F P
0 g
s
.44344 .58424 m .45165 .62119 L .42126 .62636 L p .707 .577 .707 r
F P
0 g
s
.42126 .62636 m .41305 .58942 L .44344 .58424 L p .707 .577 .707 r
F P
0 g
s
.38193 .59657 m .39013 .63352 L .36131 .64196 L p .707 .577 .707 r
F P
0 g
s
.36853 .67734 m .36432 .65888 L .39311 .6503 L p .707 .577 .707 r
F P
0 g
s
.39013 .63352 m .38193 .59657 L .41305 .58942 L p .707 .577 .707 r
F P
0 g
s
.41305 .58942 m .42126 .62636 L .39013 .63352 L p .707 .577 .707 r
F P
0 g
s
.39311 .6503 m .39732 .66876 L .36853 .67734 L p .707 .577 .707 r
F P
0 g
s
.45454 .6376 m .45875 .65606 L .42841 .66143 L p .707 .577 .707 r
F P
0 g
s
.42841 .66143 m .42419 .64297 L .45454 .6376 L p .707 .577 .707 r
F P
0 g
s
.39732 .66876 m .39311 .6503 L .42419 .64297 L p .707 .577 .707 r
F P
0 g
s
.42419 .64297 m .42841 .66143 L .39732 .66876 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
VGoo4000M7oo002GOol30009FUH00`00FUIJEP03FUH7001]Ool009Eoo`800003FUH005YF00QJEP03
001JEUYF00UJEP03001JEP0000<006Uoo`00Tgoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF1000IGoo002BOol20004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH4001QOol0095oo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEP00008005ioo`00TGoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH00eYF0`00Fgoo002@Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH3001HOol0091oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP<005Eoo`00Sgoo00<005YF000015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00@005YF000005=oo`00Sgoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH03eYF0P00
DGoo002?Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH2001?Ool008ioo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00IJEP8004eoo`00SWoo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
0P00Bgoo002>Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH2001:Ool008eoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00aJEP8004Qoo`00SGoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH00UYF00<007ooOol0AGoo002=Ool00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03
FUH00`00Oomoo`14Ool008eoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP8004Aoo`00S7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<007ooOol0@Goo002<Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH20012Ool0
08aoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP05001JEUYFFUH00010
Ool008]oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo03eoo`00RWoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0?7oo002:Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00Oomoo`0lOol008Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00=JEP8003ioo`00RGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
?Woo0029Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000nOol008Uoo`03001J
EP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0003ioo`00R7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000?Woo0028Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000oOol008Qoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0003moo`00Qgoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000?goo0027Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00gooFUH00009FUH00`00FUIJEP04FUH20010Ool008Mo
o`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00041oo`00QWoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000@7oo0026Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00010Ool008Ioo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP80045oo`00QWoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF0000@Goo0025Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00011
Ool008Eoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80049oo`00QGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000@Woo0024Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUH00012Ool008Aoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP8004=oo`00Q7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF0000@goo0023Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00013
Ool008=oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8004Aoo`00Pgoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000A7oo0022Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00014Ool0089oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP<004Aoo`00PWoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF0000AGoo0021Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00015Ool0085oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<004Eoo`00PGoo
00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000AWoo0020Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00016Ool0081oo`03001JEP0000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP<004Ioo`00P7oo00<005YF000015YF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF0000Agoo001oOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUH00017Ool007moo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0004Moo`00Ogoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000B7oo
001oOol00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00018Ool007ioo`03
001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Qoo`00OWoo00<005YF0000
15YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH004Qoo`00OWoo00<005YF000015YF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YF0000BGoo001mOol00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00019Ool007eoo`03001JEP0000AJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0004Uoo`00OGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF0000BWoo001lOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
001:Ool007aoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Yoo`00
O7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Bgoo001kOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001;Ool007]oo`03001JEP0000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004]oo`00Ngoo00<005YF000015YF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YFFUH004]oo`00N7oo3P001UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000C7oo001_Ool90003FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
001<Ool006Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000YJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00=JEP03OomJEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF001<Ool006Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001=Ool0061oo`@000IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0004eoo`00G7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001=Ool005Yoo`8000EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001>Ool005Uoo`8000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0001>Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00CWoo001FOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool005Eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0004moo`00E7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF001?Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00Cgoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001Goo6@00<Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001oo`040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000`Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001EOol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>
0003FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH002ioo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1@000UYF00@005YFFUH000]JEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
0003FUH005YF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00=JEP@00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
001JEP0]Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;Goo001EOol00`00
FUH00005FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<005YFFUH02UYF00<005YFFUH0
2UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00<005YF00001EYF00<005YF0000
0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3P0000=JEP00FUH02eYF00<0
05YFFUH02eYF00<005YFFUH02EYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo
00@005YFFUH000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEPT000=JEP03001JEUYF00=J
EP06001JEP00001JEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;7oo001EOol01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo
001FOol2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9JEP8000EJEP03001JEUYF
00EJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;7oo001FOol015YF001JEP001EYF00<005YFFUH01EYF00H005YF000005YF0009FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo001:Ool>
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00AWoo10000UYF00<005YFFUH0
1EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000oOol70006
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YF
FUH02UYF00<005YFFUH02UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH015YF6P000UYF00<007ooOol0:Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02eYF00<005YFFUH02EYF00D0
05YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00=goo0P0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YFFUIJEP/0009JEP03001JEUYF00IJEP03001JEUYF00]JEP04001JEUYF
0008FUH01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002]oo`00=Goo0P000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P001EYF00<005YFFUH00UYF1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00<goo
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00=J
EP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH01P00FUIJEP00
FUH000EJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000[Ool0035oo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD000UJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00]JEP03001JEUYF00UJEP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
;7oo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH01000FUIJEP000UYF00@005YFFUIJEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP04FUH60007FUH00`00FUIJEP06FUH00`00FUH0000:0009FUH00`00FUIJEP0:FUH01000
FUIJEP002EYF00<005YFFUH00eYF00@005YF000000]JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP/002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00P000=JEP03001JEUYF00=JEP04001JEP000006FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200000eYF001JEP0:FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH:0003FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009J
EP05001JEUYFFUH00006FUH40006FUH40003FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002eYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP03001JEUYF
00IJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0:goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF009JEP@000IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH20006FUH01000FUIJEUYF10001UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002]oo`00;Goo00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP04001JEUYFFUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP07
FUH01000FUIJEUYF2`000UYF00D005YFFUIJEP0000aJEP04001JEUYF0009FUH00`00FUIJEP04FUH2
00000eYF001JEP04FUH20006FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUH000000UYF00<005YFFUH0
1EYF0`000eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00<005YFFUH00P0000=JEP000000
0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH90005FUH00`00FUIJEP020005FUH01000FUIJEUYF0`001UYF00<005YFFUH01eYF00<0
05YFFUH010002UYF0`000eYF00@005YFFUH0009JEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEPP000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF100000=JEP00FUH00eYF0P000eYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000^Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF0P001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH015YF
0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
0P0015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002Yoo`00;Woo00<005YF00001EYF00<005YFFUH00UYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00@005YF000000MJEP03001J
EUYF00AJEPD000UJEP03001JEUYF009JEP800003FUH005YF00IJEP05001JEUYFFUH00003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH005YF0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Yo
o`00;Woo00<005YF00001EYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@000UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHD000YOol002ioo`04001JEUYF0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH900000eYF001JEP03FUH00`00FUIJEP04FUH300000goo00000005FUH00`00FUIJEP05FUH4
0007FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH3
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo000^Ool01000FUIJEP000UYF0P000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01`0015YF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP<0009oo`04001JEP00FUH40004FUH40002FUH00`00FUIJEP06FUH00`00FUH000030008FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00:Goo
000_Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000EJEP04001JEP000002FUH01@00Oomoo`00FUH02P001UYF00<005YFFUH01EYF0`00
35YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00:Woo000_Ool2FUH20005FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YF
FUH01eYF00<005YF00000UYF00@005YFFUIJEP<00004FUH005YFFUH;00000eYF001JEP08FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH01000FUIJEUYF0P00:goo000_Ool015YF001JEP001EYF00<005YFFUH01EYF
00H005YF000005YF0009FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH000080003FUH00`00
FUIJEP0500000eYF001JEP08FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP040003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000;Goo000_
Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00AJ
EP@000MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000_Ool002moo`80009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP05001JEP00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80039oo`00<7oo0P0000=JEP00FUH00eYF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00AJEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP800004FUH005YF0005FUH01000FUH000001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Aoo`00<Woo1P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@000=JEPL001EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYF0002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF4000:Goo000eOol20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP0J0005FUH00`00FUH000050002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH200001UYF001JEUYF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEP0000L000=JEP03001JEUYF00=JEP04001JEUYF000YOol003=o
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@00004FUH0
00000002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH20005FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF
1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:7oo000bOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00FUIJ
EP03FUH20003FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH70003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH00000:7oo000`Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Qoo`00;goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP<000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP8000UJEP03
001JEUYF00YJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP06
001JEP00001JEP002EYF00<005YFFUH01EYF00<005YFFUH00UYF2`0000=JEP0000009goo000_Ool0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<0
05YF00002P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF0`00
1eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF
FUH00UYF1@000eYF00<005YFFUH01eYF00<005YFFUH00UYF200017oo0`000eYF10009goo000`Ool0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`001eYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP04001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP0>0007FUH00`00FUIJEP04FUH7000:Ool200000eYF001JEP04FUH00`00FUH0000W
Ool0031oo`04001JEUYF0003FUH00`00FUIJEP04FUH40005FUH50007FUH50002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH200000eYF001JEP0;FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF100000=JEP00FUH01eYF00<005YFFUH010003goo0P000eYF00<005YFFUH00eYF0P00
:7oo000`Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP@000=JEPD000IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00IJEP<001AJEP03001JEUYF00=JEP04001JEUYF0004FUH30005
FUH00`00FUIJEP05FUH4000@Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0031oo`04001J
EUYF0004FUH01000FUH000001UYF00<005YFFUH01UYF10000UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02UYF0P0025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP<000MJEP03
001JEUYF009JEP80011oo`@00003FUH005YF00IJEP03001JEUYF008002Yoo`00<Goo00@005YFFUH0
00=JEP<000MJEP03001JEUYF009JEP@000IJEP03001JEUYF00MJEP04001JEUYFFUH:0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH40006FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUH00002000=Ool50005
FUH00`00FUIJEP05FUH3000/Ool0035oo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH50000
0eYF001JEP08FUH00`00FUIJEP04FUH60007Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH20003FUH2000=FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00EJEP03001JEUYF00=JEP<000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8002ioo`00
<Goo00<005YFFUH00P001EYF00@005YFFUIJEP@000EJEP03001JEUYF00MJEP03001JEUYF00@000]o
o`8000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00]JEP03001J
EUYF00UJEP8000EJEP800003FUH005YF00QJEP03001JEUYF00=JEP03001JEUYF00<000EJEP03001J
EP0000<00003FUH0000000Qoo`@000IJEP03001JEUYF00IJEP03001JEP0000<0031oo`00<Woo00AJ
EP00FUH000EJEP06001JEP00001JEP0025YF00<005YFFUH015YF1@002goo100000=JEP00FUH00UYF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF0P001eYF0P002EYF
00<005YFFUH01UYF00<005YF00001EYF0P000UYF00<005YFFUH00P0017oo100000=JEP00FUH01eYF
00<005YFFUH01EYF0`00=7oo000bOol01000FUIJEP001EYF0P000eYF00<005YFFUH01UYF00<005YF
FUH010003Goo0`001EYF00<005YFFUH00UYF00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00MJEP8000MJEP8000AJEP03001JEUYF0080009JEP03001J
EUYF008000AJEP03001JEUYF00H000EJEP03001JEUYF00MJEP03001JEUYF009JEP8003Moo`00<Woo
0P000UYF00<005YFFUH00P001UYF00<005YFFUH015YF10003goo0P0000=JEP00FUH01UYF00@005YF
FUIJEP800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP8000]J
EP8000EJEP03001JEUYF00=JEP03001JEUYF0080009JEP`000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008003Uoo`00<goo0P0000=JEP0000000P001eYF00<005YFFUH0100047oo0`00
0eYF00<005YFFUH01EYF00H005YF000007oo000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH2000;FUH00`00FUH00004FUH00`00FUIJEP06FUH300000eYF00000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol003Eoo`8000=JEP03001JEUYF00AJEP<0
011oo`@000IJEP03001JEUYF00AJEP<000Aoo`03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040010Ool0
03Aoo`8000AJEP03001JEUYF009JEP8000Moo`<000Eoo`@0009JEP03001JEUYF00IJEP04001JEUYF
FUH20008Ool00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP02FUH30005FUH01000FUIJEP000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00A7oo000cOol00`00FUH00005FUH01000FUH0000027oo2@001UYF00<0
05YFFUH01UYF00@005YF000000]oo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP8000]JEP03001JEUYF00AJEP03001JEUYF00YJEP800003FUH005YF00AJEP03001JEUYF009J
EPP004Yoo`00<goo00@005YFFUH000=JEP<000Aoo`/00003FUH005YF00QJEP03001JEUYF00AJEP<0
00moo`03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000/0059oo`00<goo
00D005YFFUH005YF00T000=JEP03001JEUYF00D00003FUH005YF00QJEP03001JEUYF00@001=oo`05
001JEUYFFUH0000;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00P00Dgoo000cOol20000
0eYF00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF1@0067oo0P00
3EYF00<005YFFUH02UYF00<005YFFUH02UYF0P002eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YFFUH00UYF00<005YFFUH01EYF0`00EGoo000dOol200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP04000OOol2000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEP002UYF00<005YFFUH00eYF0P00Egoo000dOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF1@009Goo0P0025YF00<005YFFUH02eYF00<0
05YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YF
00000`00FGoo000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04000/Ool2
0006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF3P00DWoo000eOol200000eYF001JEP04FUH01000FUIJEUYF1P00<Woo
0P0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEPP000=JEP03001JEUYF00=JEP04001JEP00001@Ool003Moo`/003Yoo`80
00mJEP03001JEUYF00UJEP8000]JEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001?Ool007ioo`<000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00EJEP8000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00001?Ool0085oo`8000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF001?Ool008=o
o`8000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF009JEP/00003FUH0000004ioo`00QGoo0`0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF20001Woo0P000UYF1000CWoo0028
Ool2000>FUH00`00FUIJEP0BFUH00`00FUIJEP03FUH6000<Ool20005FUH00`00FUH0001>Ool008Yo
o`@000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`@00003FUH005YF
00AJEP8004moo`00SWoo1P0045YF00<005YFFUH01UYF00@005YFFUIJEP8000]oo`<000EJEP03001J
EUYF00=JEP03001oogoo04ioo`00U7oo1P002UYF00<005YFFUH01eYF0`002goo0P0000=JEP00FUH0
1UYF00<005YFFUH00P00DGoo002GOol200000eYF000000040008FUH6000;Ool30003FUH00`00FUIJ
EP05FUH3001COol009Ioo`03001JEUYF009JEP03001JEUYF009JEPP000eoo`@000MJEP03001JEUYF
00=JEP8005Eoo`00UGoo0P001EYF00@005YFFUIJEP8000moo`@0009JEP03001JEUYF00IJEP03001J
EP0000<005Moo`00U7oo00<005YF00001EYF00@005YF000000]oo`H000IJEP03001JEUYF00EJEP<0
05]oo`00U7oo00@005YFFUH000=JEP<000Eoo`P000=JEP03001JEUYF00MJEP03001JEUYF009JEP80
05ioo`00U7oo00D005YFFUH005YF00X000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
0080061oo`00UGoo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@006=oo`00UGoo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1000Igoo002EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6001[Ool0
09Ioo`800003FUH005YF00AJEP03001JEUYF009JEPP0075oo`00V7oo3000NGoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60388 .74909 m .59641 .69325 L .56553 .69562 L p .707 .577 .707 r
F P
0 g
s
.59641 .69325 m .60388 .74909 L .63546 .74446 L p .707 .577 .707 r
F P
0 g
s
.63546 .74446 m .62799 .68862 L .59641 .69325 L p .707 .577 .707 r
F P
0 g
s
.62799 .68862 m .63546 .74446 L .66463 .73803 L p .707 .577 .707 r
F P
0 g
s
.66463 .73803 m .65717 .68218 L .62799 .68862 L p .707 .577 .707 r
F P
0 g
s
.57299 .75146 m .56553 .69562 L .53836 .69549 L p .707 .577 .707 r
F P
0 g
s
.56553 .69562 m .57299 .75146 L .60388 .74909 L p .707 .577 .707 r
F P
0 g
s
.65717 .68218 m .66463 .73803 L .68856 .73041 L p .707 .577 .707 r
F P
0 g
s
.68856 .73041 m .68109 .67457 L .65717 .68218 L p .707 .577 .707 r
F P
0 g
s
.61195 .81236 m .60374 .77542 L .57335 .78059 L p .707 .577 .707 r
F P
0 g
s
.60374 .77542 m .61195 .81236 L .64308 .80521 L p .707 .577 .707 r
F P
0 g
s
.64308 .80521 m .63487 .76826 L .60374 .77542 L p .707 .577 .707 r
F P
0 g
s
.53836 .69549 m .54582 .75134 L .57299 .75146 L p .707 .577 .707 r
F P
0 g
s
.63487 .76826 m .64308 .80521 L .6719 .79676 L p .707 .577 .707 r
F P
0 g
s
.6719 .79676 m .66369 .75982 L .63487 .76826 L p .707 .577 .707 r
F P
0 g
s
.54582 .75134 m .53836 .69549 L .51756 .69289 L p .707 .577 .707 r
F P
0 g
s
.57335 .78059 m .58156 .81754 L .61195 .81236 L p .707 .577 .707 r
F P
0 g
s
.58156 .81754 m .57335 .78059 L .54668 .78327 L p .707 .577 .707 r
F P
0 g
s
.66369 .75982 m .6719 .79676 L .69559 .78786 L p .707 .577 .707 r
F P
0 g
s
.69559 .78786 m .68738 .75092 L .66369 .75982 L p .707 .577 .707 r
F P
0 g
s
.68109 .67457 m .68856 .73041 L .70488 .72237 L p .707 .577 .707 r
F P
0 g
s
.70488 .72237 m .69741 .66653 L .68109 .67457 L p .707 .577 .707 r
F P
0 g
s
.61901 .86296 m .6148 .8445 L .58445 .84987 L p .707 .577 .707 r
F P
0 g
s
.6148 .8445 m .61901 .86296 L .6501 .85563 L p .707 .577 .707 r
F P
0 g
s
.6501 .85563 m .64589 .83717 L .6148 .8445 L p .707 .577 .707 r
F P
0 g
s
.54668 .78327 m .55489 .82022 L .58156 .81754 L p .707 .577 .707 r
F P
0 g
s
.64589 .83717 m .6501 .85563 L .67889 .84705 L p .707 .577 .707 r
F P
0 g
s
.67889 .84705 m .67467 .82859 L .64589 .83717 L p .707 .577 .707 r
F P
0 g
s
.51756 .69289 m .52502 .74873 L .54582 .75134 L p .707 .577 .707 r
F P
0 g
s
.58445 .84987 m .58867 .86833 L .61901 .86296 L p .707 .577 .707 r
F P
0 g
s
.58867 .86833 m .58445 .84987 L .55782 .85274 L p .707 .577 .707 r
F P
0 g
s
.55489 .82022 m .54668 .78327 L .52633 .7832 L p .707 .577 .707 r
F P
0 g
s
.55782 .85274 m .56203 .8712 L .58867 .86833 L p .707 .577 .707 r
F P
0 g
s
.67467 .82859 m .67889 .84705 L .70256 .83806 L p .707 .577 .707 r
F P
0 g
s
.70256 .83806 m .69835 .8196 L .67467 .82859 L p .707 .577 .707 r
F P
0 g
s
.52502 .74873 m .51756 .69289 L .50517 .68806 L p .707 .577 .707 r
F P
0 g
s
.68738 .75092 m .69559 .78786 L .71183 .77937 L p .707 .577 .707 r
F P
0 g
s
.71183 .77937 m .70363 .74243 L .68738 .75092 L p .707 .577 .707 r
F P
0 g
s
.52633 .7832 m .53454 .82015 L .55489 .82022 L p .707 .577 .707 r
F P
0 g
s
.50517 .68806 m .51264 .74391 L .52502 .74873 L p .707 .577 .707 r
F P
0 g
s
.51264 .74391 m .50517 .68806 L .50241 .68148 L p .707 .577 .707 r
F P
0 g
s
.50241 .68148 m .50987 .73733 L .51264 .74391 L p .707 .577 .707 r
F P
0 g
s
.50987 .73733 m .50241 .68148 L .50953 .6738 L p .707 .577 .707 r
F P
0 g
s
.50953 .6738 m .517 .72964 L .50987 .73733 L p .707 .577 .707 r
F P
0 g
s
.517 .72964 m .50953 .6738 L .52586 .66575 L p .707 .577 .707 r
F P
0 g
s
.52586 .66575 m .53332 .72159 L .517 .72964 L p .707 .577 .707 r
F P
0 g
s
.53454 .82015 m .52633 .7832 L .5143 .78038 L p .707 .577 .707 r
F P
0 g
s
.5143 .78038 m .52251 .81733 L .53454 .82015 L p .707 .577 .707 r
F P
0 g
s
.52251 .81733 m .5143 .78038 L .51177 .77509 L p .707 .577 .707 r
F P
0 g
s
.51177 .77509 m .51997 .81203 L .52251 .81733 L p .707 .577 .707 r
F P
0 g
s
.51997 .81203 m .51177 .77509 L .51897 .76785 L p .707 .577 .707 r
F P
0 g
s
.51897 .76785 m .52718 .80479 L .51997 .81203 L p .707 .577 .707 r
F P
0 g
s
.52718 .80479 m .51897 .76785 L .53522 .75936 L p .707 .577 .707 r
F P
0 g
s
.53522 .75936 m .54343 .7963 L .52718 .80479 L p .707 .577 .707 r
F P
0 g
s
.54343 .7963 m .53522 .75936 L .55891 .75046 L p .707 .577 .707 r
F P
0 g
s
.56268 .71278 m .55725 .71398 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .63481 .35973 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.55891 .75046 m .56712 .7874 L .54343 .7963 L p .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .55891 .75046 L .57907 .74455 L p .707 .577 .707 r
F P
0 g
s
.57907 .74455 m .58773 .74201 L p .58426 .74965 L .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .57907 .74455 L .58426 .74965 L .707 .577 .707 r
F
.55716 .72307 m .56872 .72068 L .56008 .70938 L F
.53356 .83349 m .56545 .7312 L p .55716 .72307 L F P
0 g
s
.56545 .7312 m .56872 .72068 L p .55716 .72307 L .707 .577 .707 r
F P
0 g
s
.56872 .72068 m .67805 .37002 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .5397 .66479 L p .5559 .70391 L .707 .577 .707 r
F P
0 g
s
.56008 .70938 m .63481 .35973 L .5559 .70391 L .707 .577 .707 r
F
.54978 .65814 m .57896 .65171 L p .55924 .70828 L F P
0 g
s
.55725 .71398 m .5559 .70391 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.5559 .70391 m .54978 .65814 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.54173 .8713 m .53751 .85284 L .52551 .85016 L p .707 .577 .707 r
F P
0 g
s
.53442 .8562 m .53021 .83774 L .54645 .82923 L p .707 .577 .707 r
F P
0 g
s
.56203 .8712 m .55782 .85274 L .53751 .85284 L p .707 .577 .707 r
F P
0 g
s
.53751 .85284 m .54173 .8713 L .56203 .8712 L p .707 .577 .707 r
F P
0 g
s
.54645 .82923 m .55066 .84768 L .53442 .8562 L p .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .55961 .74992 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61665 .69281 L p .60159 .70532 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .618 .70292 L .61029 .70405 L p .707 .577 .707 r
F P
0 g
s
.61029 .70405 m .60159 .70532 L p .61665 .69281 L .707 .577 .707 r
F P
0 g
s
.64889 .70055 m .64142 .64471 L .66859 .64483 L p .707 .577 .707 r
F P
0 g
s
.64142 .64471 m .64889 .70055 L .618 .70292 L p .707 .577 .707 r
F P
0 g
s
.57012 .82024 m .57433 .83869 L .55066 .84768 L p .707 .577 .707 r
F P
0 g
s
.62707 .7718 m .61886 .73486 L .64925 .72968 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .58851 .74554 L p .61886 .73486 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .58773 .74201 L .59113 .74123 L p .707 .577 .707 r
F P
0 g
s
.59113 .74123 m .61886 .73486 L p .58851 .74554 L .707 .577 .707 r
F P
0 g
s
.61886 .73486 m .62707 .7718 L .59935 .77817 L p .707 .577 .707 r
F P
0 g
s
.59935 .77817 m .59594 .77896 L p .61755 .73738 L .707 .577 .707 r
F P
0 g
s
.61755 .73738 m .61886 .73486 L .59935 .77817 L .707 .577 .707 r
F
.67606 .70067 m .66859 .64483 L .68939 .64743 L p F P
0 g
s
.66859 .64483 m .67606 .70067 L .64889 .70055 L p .707 .577 .707 r
F P
0 g
s
.65745 .76663 m .64925 .72968 L .67592 .727 L p .707 .577 .707 r
F P
0 g
s
.64925 .72968 m .65745 .76663 L .62707 .7718 L p .707 .577 .707 r
F P
0 g
s
.63421 .82278 m .63 .80432 L .66034 .79896 L p .707 .577 .707 r
F P
0 g
s
.60312 .83011 m .59891 .81166 L .63 .80432 L p .707 .577 .707 r
F P
0 g
s
.63 .80432 m .63421 .82278 L .61681 .82689 L p .707 .577 .707 r
F P
0 g
s
.61681 .82689 m .60312 .83011 L p .62194 .81206 L .707 .577 .707 r
F P
0 g
s
.62194 .81206 m .63 .80432 L .61681 .82689 L .707 .577 .707 r
F
.69741 .66653 m .70488 .72237 L .71201 .71468 L p F P
0 g
s
.71201 .71468 m .70454 .65884 L .69741 .66653 L p .707 .577 .707 r
F P
0 g
s
.69686 .70327 m .68939 .64743 L .70178 .65226 L p .707 .577 .707 r
F P
0 g
s
.68939 .64743 m .69686 .70327 L .67606 .70067 L p .707 .577 .707 r
F P
0 g
s
.68413 .76395 m .67592 .727 L .69627 .72708 L p .707 .577 .707 r
F P
0 g
s
.69209 .72818 m .68389 .69124 L .68375 .69124 L p .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .63988 .81337 L p .74256 .4693 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .74615 .45575 L .62958 .82718 L .707 .577 .707 r
F
.74692 .4508 m .62958 .82718 L p .75537 .42638 L F P
0 g
s
.60677 .83558 m .62958 .82718 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .77408 .36371 L .75127 .37211 L p .707 .577 .707 r
F P
0 g
s
.63988 .81337 m .78437 .3499 L .77408 .36371 L p .707 .577 .707 r
F P
0 g
s
.68346 .5896 m .60677 .83558 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.60677 .83558 m .75127 .37211 L .71818 .37429 L p .707 .577 .707 r
F P
0 g
s
.75127 .37211 m .68346 .5896 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.57433 .83869 m .57012 .82024 L .59891 .81166 L p .707 .577 .707 r
F P
0 g
s
.59891 .81166 m .60312 .83011 L .57433 .83869 L p .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .60677 .83558 L p .65482 .63664 L .707 .577 .707 r
F P
0 g
s
.68913 .62538 m .69234 .61692 L .67556 .60346 L .707 .577 .707 r
F
.7038 .59298 m .69234 .61692 L .78437 .3499 L F
.675 .67984 m .68002 .65644 L .69428 .6217 L F
.63666 .79551 m .67098 .68543 L p .675 .67984 L F P
0 g
s
.67098 .68543 m .68002 .65644 L p .675 .67984 L .707 .577 .707 r
F P
0 g
s
.63666 .79551 m .62847 .78545 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .68458 .64182 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.68458 .64182 m .63666 .79551 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.618 .70292 m .61665 .69281 L p .64142 .64471 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .62106 .68113 L .64142 .64471 L .707 .577 .707 r
F
.63536 .64517 m .64142 .64471 L p .61624 .68976 L F P
0 g
s
.65956 .61698 m .68483 .51236 L .6216 .68407 L .707 .577 .707 r
F
.71818 .37429 m .62936 .65917 L p .68483 .51236 L F P
0 g
s
.55066 .84768 m .54645 .82923 L .57012 .82024 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .56712 .7874 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58773 .74201 m .58851 .74554 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .59594 .77896 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.6216 .68407 m .608 .72768 L p .65956 .61698 L .707 .577 .707 r
F P
0 g
s
.608 .72768 m .57368 .83775 L p .62121 .71558 L .707 .577 .707 r
F P
0 g
s
.65956 .61698 m .608 .72768 L .62121 .71558 L .707 .577 .707 r
F
.59637 .73609 m .67805 .37002 L .55368 .83562 L F
.61267 .66304 m .61053 .64708 L .61633 .64663 L p F P
0 g
s
.61665 .69281 m .61624 .68976 L p .62106 .68113 L .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .71818 .37429 L .67805 .37002 L p .707 .577 .707 r
F P
0 g
s
.61633 .64663 m .63536 .64517 L p .61267 .66304 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61267 .66304 L p .63536 .64517 L .707 .577 .707 r
F P
0 g
s
.62936 .65917 m .6216 .68407 L p .68483 .51236 L .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .65476 .60085 L p .67844 .64982 L .707 .577 .707 r
F P
0 g
s
.67964 .64826 m .67556 .60346 L .67844 .64982 L .707 .577 .707 r
F
.62847 .78545 m .62024 .77534 L p .67579 .65329 L F P
0 g
s
.68127 .64614 m .67556 .60346 L p .67964 .64826 L .707 .577 .707 r
F P
0 g
s
.69428 .6217 m .68458 .64182 L .7038 .59298 L .707 .577 .707 r
F
.68002 .65644 m .68458 .64182 L p .69428 .6217 L F P
0 g
s
.68458 .64182 m .69234 .61692 L p .7038 .59298 L .707 .577 .707 r
F P
0 g
s
.675 .67984 m .69428 .6217 L .67958 .67349 L .707 .577 .707 r
F
.71657 .56739 m .63988 .81337 L p .69428 .6217 L F P
0 g
s
.70454 .65884 m .71201 .71468 L .70924 .7081 L p .707 .577 .707 r
F P
0 g
s
.70924 .7081 m .70178 .65226 L .70454 .65884 L p .707 .577 .707 r
F P
0 g
s
.70178 .65226 m .70924 .7081 L .69686 .70327 L p .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .68303 .6593 L .7102 .65942 L p .707 .577 .707 r
F P
0 g
s
.67579 .65329 m .68127 .64614 L .62847 .78545 L .707 .577 .707 r
F
.65482 .63664 m .65956 .61698 L .64679 .64983 L F
.65476 .60085 m .66223 .65669 L .67222 .65794 L p F P
0 g
s
.62024 .77534 m .65442 .68116 L .67579 .65329 L .707 .577 .707 r
F
.67222 .65794 m .68303 .6593 L p .67844 .64982 L F P
0 g
s
.67844 .64982 m .65476 .60085 L .67222 .65794 L .707 .577 .707 r
F
.69676 .60355 m .67556 .60346 L p .69234 .61692 L F P
0 g
s
.78115 .33204 m .69234 .61692 L p .67579 .65329 L .707 .577 .707 r
F P
0 g
s
.65442 .68116 m .78115 .33204 L .67579 .65329 L .707 .577 .707 r
F
.67579 .65329 m .69234 .61692 L .68127 .64614 L F
.68167 .64919 m .68127 .64614 L p .68009 .65322 L F P
0 g
s
.68127 .64614 m .67964 .64826 L .68009 .65322 L .707 .577 .707 r
F
.68009 .65322 m .67964 .64826 L .67844 .64982 L F
.63988 .81337 m .63666 .79551 L p .675 .67984 L F P
0 g
s
.675 .67984 m .67958 .67349 L .63988 .81337 L .707 .577 .707 r
F
.65971 .72529 m .67174 .72811 L p .6587 .70248 L F P
0 g
s
.66223 .65669 m .65476 .60085 L .64238 .59603 L p .707 .577 .707 r
F P
0 g
s
.65482 .63664 m .64679 .64983 L .57368 .83775 L .707 .577 .707 r
F
.64238 .59603 m .64849 .6418 L p .66223 .65669 L F P
0 g
s
.64284 .62484 m .64849 .6418 L .62024 .77534 L .707 .577 .707 r
F
.6554 .66254 m .65288 .67064 L p .64849 .6418 L F P
0 g
s
.65288 .67064 m .62024 .77534 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64238 .59603 L .64114 .59307 L p .707 .577 .707 r
F P
0 g
s
.61053 .64708 m .61624 .68976 L p .58642 .70755 L .707 .577 .707 r
F P
0 g
s
.60159 .70532 m .58642 .70755 L p .61624 .68976 L .707 .577 .707 r
F P
0 g
s
.55368 .83562 m .57368 .83775 L p .59637 .73609 L .707 .577 .707 r
F P
0 g
s
.6416 .59643 m .59222 .75484 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.64114 .59307 m .64106 .59291 L p .6416 .59643 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64114 .59307 L .6416 .59643 L .707 .577 .707 r
F
.53356 .83349 m .55368 .83562 L p .58329 .72476 L F P
0 g
s
.55961 .74992 m .53356 .83349 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.57896 .65171 m .58642 .70755 L .56268 .71278 L p .707 .577 .707 r
F P
0 g
s
.58642 .70755 m .57896 .65171 L .61053 .64708 L p .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .55534 .73602 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.73671 .29137 m .6416 .59643 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.65215 .65277 m .66223 .65669 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.76473 .31187 m .6554 .66254 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .73671 .29137 L .76473 .31187 L p .707 .577 .707 r
F P
0 g
s
.64984 .65187 m .64849 .6418 L p .63961 .58945 L .707 .577 .707 r
F P
0 g
s
.64106 .59291 m .63961 .58945 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64984 .65187 L .65215 .65277 L p .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .59222 .75484 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .76473 .31187 L .78115 .33204 L p .707 .577 .707 r
F P
0 g
s
.65151 .68834 m .6556 .70679 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.6556 .70679 m .65971 .72529 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.67592 .727 m .68413 .76395 L .65745 .76663 L p .707 .577 .707 r
F P
0 g
s
.67174 .72811 m .69209 .72818 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66354 .69116 m .66432 .69468 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .67174 .72811 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.68303 .6593 m .68167 .64919 L p .68009 .65322 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .75537 .42638 L .74615 .45575 L .707 .577 .707 r
F
.77408 .36371 m .74692 .4508 L p .75537 .42638 L F P
0 g
s
.78303 .34246 m .78437 .3499 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.6974 .60355 m .69676 .60355 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .78115 .33204 L .78303 .34246 L p .707 .577 .707 r
F P
0 g
s
.78437 .3499 m .71657 .56739 L p .69428 .6217 L .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .70273 .60358 L .6974 .60355 L p .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .6974 .60355 L .68913 .62538 L .707 .577 .707 r
F
.66354 .69116 m .65151 .68834 L p .6587 .70248 L F P
0 g
s
.67174 .72811 m .66432 .69468 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .66354 .69116 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.68375 .69124 m .66576 .69117 L p .6786 .71068 L .707 .577 .707 r
F P
0 g
s
.66576 .69117 m .66354 .69116 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.6786 .71068 m .66576 .69117 L .66499 .69305 L .707 .577 .707 r
F
.69209 .72818 m .68375 .69124 L .6786 .71068 L F
.55924 .70828 m .57896 .65171 L .56268 .71278 L F
.55943 .71243 m .56008 .70938 L .5559 .70391 L F
.49032 .82319 m .53356 .83349 L p .55943 .71243 L F P
0 g
s
.53332 .72159 m .52586 .66575 L .53844 .66175 L p .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53844 .66175 L .53892 .66291 L .707 .577 .707 r
F
.5397 .66479 m .63481 .35973 L p .53218 .62742 L F P
0 g
s
.53905 .66155 m .54978 .65814 L p .54335 .68292 L .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53905 .66155 L .54335 .68292 L .707 .577 .707 r
F
.54978 .65814 m .55725 .71398 L .53332 .72159 L p F P
0 g
s
.5397 .66479 m .49032 .82319 L p .55943 .71243 L .707 .577 .707 r
F P
0 g
s
.53844 .66175 m .53905 .66155 L p .53892 .66291 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .59269 .34442 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.49032 .82319 m .5397 .66479 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.4482 .80789 m .59269 .34442 L .55582 .3256 L p .707 .577 .707 r
F P
0 g
s
.59269 .34442 m .4482 .80789 L .49032 .82319 L p .707 .577 .707 r
F P
0 g
s
.69835 .8196 m .70256 .83806 L .7188 .82954 L p .707 .577 .707 r
F P
0 g
s
.7188 .82954 m .71459 .81109 L .69835 .8196 L p .707 .577 .707 r
F P
0 g
s
.41132 .78906 m .55582 .3256 L .52779 .3051 L p .707 .577 .707 r
F P
0 g
s
.55582 .3256 m .41132 .78906 L .4482 .80789 L p .707 .577 .707 r
F P
0 g
s
.70363 .74243 m .71183 .77937 L .71904 .77213 L p .707 .577 .707 r
F P
0 g
s
.71904 .77213 m .71084 .73519 L .70363 .74243 L p .707 .577 .707 r
F P
0 g
s
.52551 .85016 m .52973 .86862 L .54173 .8713 L p .707 .577 .707 r
F P
0 g
s
.71459 .81109 m .7188 .82954 L .72601 .82233 L p .707 .577 .707 r
F P
0 g
s
.72601 .82233 m .7218 .80387 L .71459 .81109 L p .707 .577 .707 r
F P
0 g
s
.3833 .76856 m .52779 .3051 L .51137 .28493 L p .707 .577 .707 r
F P
0 g
s
.52779 .3051 m .3833 .76856 L .41132 .78906 L p .707 .577 .707 r
F P
0 g
s
.71084 .73519 m .71904 .77213 L .71651 .76684 L p .707 .577 .707 r
F P
0 g
s
.71651 .76684 m .7083 .7299 L .71084 .73519 L p .707 .577 .707 r
F P
0 g
s
.52973 .86862 m .52551 .85016 L .523 .84496 L p .707 .577 .707 r
F P
0 g
s
.523 .84496 m .52721 .86341 L .52973 .86862 L p .707 .577 .707 r
F P
0 g
s
.7218 .80387 m .72601 .82233 L .7235 .81713 L p .707 .577 .707 r
F P
0 g
s
.7235 .81713 m .71928 .79867 L .7218 .80387 L p .707 .577 .707 r
F P
0 g
s
.26087 .70573 m .25341 .64989 L .22252 .65226 L p .707 .577 .707 r
F P
0 g
s
.25341 .64989 m .26087 .70573 L .29245 .7011 L p .707 .577 .707 r
F P
0 g
s
.29245 .7011 m .28498 .64526 L .25341 .64989 L p .707 .577 .707 r
F P
0 g
s
.28498 .64526 m .29245 .7011 L .32163 .69467 L p .707 .577 .707 r
F P
0 g
s
.32163 .69467 m .31416 .63883 L .28498 .64526 L p .707 .577 .707 r
F P
0 g
s
.22999 .7081 m .22252 .65226 L .19535 .65214 L p .707 .577 .707 r
F P
0 g
s
.22252 .65226 m .22999 .7081 L .26087 .70573 L p .707 .577 .707 r
F P
0 g
s
.7083 .7299 m .71651 .76684 L .70448 .76402 L p .707 .577 .707 r
F P
0 g
s
.70448 .76402 m .69627 .72708 L .7083 .7299 L p .707 .577 .707 r
F P
0 g
s
.37579 .76023 m .37158 .74177 L .35534 .75029 L p .707 .577 .707 r
F P
0 g
s
.36062 .68903 m .36883 .72597 L .37603 .71873 L p .707 .577 .707 r
F P
0 g
s
.37603 .71873 m .36783 .68178 L .36062 .68903 L p .707 .577 .707 r
F P
0 g
s
.36783 .68178 m .37603 .71873 L .3735 .71344 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .36883 .72597 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34437 .69752 m .34707 .70966 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34707 .70966 m .35258 .73446 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.3682 .74388 m .36427 .72667 L .3727 .72855 L p .707 .577 .707 r
F P
0 g
s
.3727 .72855 m .37627 .72935 L p .3682 .74388 L .707 .577 .707 r
F P
0 g
s
.36849 .74513 m .3682 .74388 L p .37627 .72935 L .707 .577 .707 r
F P
0 g
s
.36427 .72667 m .36849 .74513 L .34818 .74523 L p .707 .577 .707 r
F P
0 g
s
.36688 .7484 m .51137 .28493 L .50815 .26707 L p .707 .577 .707 r
F P
0 g
s
.36883 .72597 m .36062 .68903 L .34437 .69752 L p .707 .577 .707 r
F P
0 g
s
.3735 .71344 m .36714 .68482 L p .36783 .68178 L .707 .577 .707 r
F P
0 g
s
.36714 .68482 m .36529 .67649 L .3667 .67943 L p .707 .577 .707 r
F P
0 g
s
.3667 .67943 m .36783 .68178 L p .36714 .68482 L .707 .577 .707 r
F P
0 g
s
.36529 .67649 m .3735 .71344 L .36147 .71062 L p .707 .577 .707 r
F P
0 g
s
.50815 .26707 m .36366 .73053 L .36688 .7484 L p .707 .577 .707 r
F P
0 g
s
.51845 .25326 m .41181 .59531 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.41181 .59531 m .37396 .71673 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .37018 .72179 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37018 .72179 m .36366 .73053 L p .36943 .71272 L .707 .577 .707 r
F P
0 g
s
.36943 .71272 m .51845 .25326 L .37018 .72179 L .707 .577 .707 r
F
.50815 .26707 m .51845 .25326 L p .42068 .5547 L F P
0 g
s
.36366 .73053 m .41426 .56823 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.41426 .56823 m .50815 .26707 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.37158 .74177 m .37579 .76023 L .383 .75301 L p .707 .577 .707 r
F P
0 g
s
.383 .75301 m .37879 .73456 L .37158 .74177 L p .707 .577 .707 r
F P
0 g
s
.37879 .73456 m .383 .75301 L .38049 .74781 L p .707 .577 .707 r
F P
0 g
s
.38049 .74781 m .37627 .72935 L .37879 .73456 L p .707 .577 .707 r
F P
0 g
s
.37627 .72935 m .38049 .74781 L .36849 .74513 L p .707 .577 .707 r
F P
0 g
s
.51137 .28493 m .36688 .7484 L .3833 .76856 L p .707 .577 .707 r
F P
0 g
s
.31416 .63883 m .32163 .69467 L .34555 .68705 L p .707 .577 .707 r
F P
0 g
s
.34555 .68705 m .33808 .63121 L .31416 .63883 L p .707 .577 .707 r
F P
0 g
s
.52721 .86341 m .523 .84496 L .53021 .83774 L p .707 .577 .707 r
F P
0 g
s
.26894 .75896 m .26073 .72202 L .23035 .72719 L p .707 .577 .707 r
F P
0 g
s
.26073 .72202 m .26894 .75896 L .30007 .7518 L p .707 .577 .707 r
F P
0 g
s
.30007 .7518 m .29186 .71486 L .26073 .72202 L p .707 .577 .707 r
F P
0 g
s
.29186 .71486 m .30007 .7518 L .32889 .74336 L p .707 .577 .707 r
F P
0 g
s
.32889 .74336 m .32068 .70642 L .29186 .71486 L p .707 .577 .707 r
F P
0 g
s
.53021 .83774 m .53442 .8562 L .52721 .86341 L p .707 .577 .707 r
F P
0 g
s
.19535 .65214 m .20281 .70798 L .22999 .7081 L p .707 .577 .707 r
F P
0 g
s
.71928 .79867 m .7235 .81713 L .7115 .81444 L p .707 .577 .707 r
F P
0 g
s
.7115 .81444 m .70728 .79599 L .71928 .79867 L p .707 .577 .707 r
F P
0 g
s
.23035 .72719 m .23855 .76414 L .26894 .75896 L p .707 .577 .707 r
F P
0 g
s
.20281 .70798 m .19535 .65214 L .17455 .64953 L p .707 .577 .707 r
F P
0 g
s
.23855 .76414 m .23035 .72719 L .20367 .72987 L p .707 .577 .707 r
F P
0 g
s
.276 .79364 m .27179 .77519 L .24144 .78055 L p .707 .577 .707 r
F P
0 g
s
.27179 .77519 m .276 .79364 L .30709 .78631 L p .707 .577 .707 r
F P
0 g
s
.30709 .78631 m .30288 .76786 L .27179 .77519 L p .707 .577 .707 r
F P
0 g
s
.30288 .76786 m .30709 .78631 L .33588 .77773 L p .707 .577 .707 r
F P
0 g
s
.33588 .77773 m .33167 .75928 L .30288 .76786 L p .707 .577 .707 r
F P
0 g
s
.32068 .70642 m .32889 .74336 L .35258 .73446 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .34437 .69752 L .32068 .70642 L p .707 .577 .707 r
F P
0 g
s
.24144 .78055 m .24566 .79901 L .276 .79364 L p .707 .577 .707 r
F P
0 g
s
.20367 .72987 m .21188 .76682 L .23855 .76414 L p .707 .577 .707 r
F P
0 g
s
.33808 .63121 m .34555 .68705 L .36187 .67901 L p .707 .577 .707 r
F P
0 g
s
.36187 .67901 m .35441 .62317 L .33808 .63121 L p .707 .577 .707 r
F P
0 g
s
.24566 .79901 m .24144 .78055 L .21481 .78343 L p .707 .577 .707 r
F P
0 g
s
.17455 .64953 m .18202 .70537 L .20281 .70798 L p .707 .577 .707 r
F P
0 g
s
.69627 .72708 m .70448 .76402 L .68413 .76395 L p .707 .577 .707 r
F P
0 g
s
.21481 .78343 m .21903 .80188 L .24566 .79901 L p .707 .577 .707 r
F P
0 g
s
.33167 .75928 m .33588 .77773 L .35955 .76874 L p .707 .577 .707 r
F P
0 g
s
.35955 .76874 m .35534 .75029 L .33167 .75928 L p .707 .577 .707 r
F P
0 g
s
.21188 .76682 m .20367 .72987 L .18332 .7298 L p .707 .577 .707 r
F P
0 g
s
.18202 .70537 m .17455 .64953 L .16216 .64471 L p .707 .577 .707 r
F P
0 g
s
.18332 .7298 m .19153 .76674 L .21188 .76682 L p .707 .577 .707 r
F P
0 g
s
.21903 .80188 m .21481 .78343 L .1945 .78353 L p .707 .577 .707 r
F P
0 g
s
.70728 .79599 m .7115 .81444 L .69119 .81454 L p .707 .577 .707 r
F P
0 g
s
.69119 .81454 m .68697 .79609 L .70728 .79599 L p .707 .577 .707 r
F P
0 g
s
.1945 .78353 m .19872 .80198 L .21903 .80188 L p .707 .577 .707 r
F P
0 g
s
.35534 .75029 m .35955 .76874 L .37579 .76023 L p .707 .577 .707 r
F P
0 g
s
.35441 .62317 m .36187 .67901 L .369 .67132 L p .707 .577 .707 r
F P
0 g
s
.369 .67132 m .36153 .61548 L .35441 .62317 L p .707 .577 .707 r
F P
0 g
s
.16216 .64471 m .16963 .70055 L .18202 .70537 L p .707 .577 .707 r
F P
0 g
s
.19153 .76674 m .18332 .7298 L .17129 .72698 L p .707 .577 .707 r
F P
0 g
s
.17129 .72698 m .1795 .76392 L .19153 .76674 L p .707 .577 .707 r
F P
0 g
s
.19872 .80198 m .1945 .78353 L .1825 .78084 L p .707 .577 .707 r
F P
0 g
s
.16963 .70055 m .16216 .64471 L .1594 .63813 L p .707 .577 .707 r
F P
0 g
s
.68697 .79609 m .69119 .81454 L .66456 .81742 L p .707 .577 .707 r
F P
0 g
s
.66456 .81742 m .66034 .79896 L .68697 .79609 L p .707 .577 .707 r
F P
0 g
s
.1825 .78084 m .18672 .7993 L .19872 .80198 L p .707 .577 .707 r
F P
0 g
s
.36153 .61548 m .369 .67132 L .36623 .66474 L p .707 .577 .707 r
F P
0 g
s
.36623 .66474 m .35877 .6089 L .36153 .61548 L p .707 .577 .707 r
F P
0 g
s
.1594 .63813 m .16686 .69397 L .16963 .70055 L p .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .51845 .25326 L .54126 .24486 L p .707 .577 .707 r
F P
0 g
s
.66034 .79896 m .66456 .81742 L .63421 .82278 L p .707 .577 .707 r
F P
0 g
s
.1795 .76392 m .17129 .72698 L .16876 .72169 L p .707 .577 .707 r
F P
0 g
s
.16876 .72169 m .17696 .75863 L .1795 .76392 L p .707 .577 .707 r
F P
0 g
s
.18672 .7993 m .1825 .78084 L .17999 .77564 L p .707 .577 .707 r
F P
0 g
s
.16686 .69397 m .1594 .63813 L .16653 .63044 L p .707 .577 .707 r
F P
0 g
s
.17999 .77564 m .1842 .7941 L .18672 .7993 L p .707 .577 .707 r
F P
0 g
s
.35877 .6089 m .36623 .66474 L .35385 .65992 L p .707 .577 .707 r
F P
0 g
s
.35385 .65992 m .34638 .60407 L .35877 .6089 L p .707 .577 .707 r
F P
0 g
s
.16653 .63044 m .17399 .68628 L .16686 .69397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17696 .75863 m .16876 .72169 L .17596 .71444 L p .707 .577 .707 r
F P
0 g
s
.54126 .24486 m .39677 .70832 L .37396 .71673 L p .707 .577 .707 r
F P
0 g
s
.39677 .70832 m .54126 .24486 L .57435 .24268 L p .707 .577 .707 r
F P
0 g
s
.17596 .71444 m .18417 .75139 L .17696 .75863 L p .707 .577 .707 r
F P
0 g
s
.36147 .71062 m .35326 .67367 L .36529 .67649 L p .707 .577 .707 r
F P
0 g
s
.1842 .7941 m .17999 .77564 L .1872 .76843 L p .707 .577 .707 r
F P
0 g
s
.17399 .68628 m .16653 .63044 L .18285 .62239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1872 .76843 m .19141 .78688 L .1842 .7941 L p .707 .577 .707 r
F P
0 g
s
.34638 .60407 m .35385 .65992 L .33305 .65731 L p .707 .577 .707 r
F P
0 g
s
.33305 .65731 m .32558 .60147 L .34638 .60407 L p .707 .577 .707 r
F P
0 g
s
.18285 .62239 m .19031 .67824 L .17399 .68628 L p .707 .577 .707 r
F P
0 g
s
.18417 .75139 m .17596 .71444 L .19221 .70596 L p .707 .577 .707 r
F P
0 g
s
.42985 .70615 m .57435 .24268 L .61448 .24695 L p .707 .577 .707 r
F P
0 g
s
.57435 .24268 m .42985 .70615 L .39677 .70832 L p .707 .577 .707 r
F P
0 g
s
.19031 .67824 m .18285 .62239 L .20677 .61478 L p .707 .577 .707 r
F P
0 g
s
.19221 .70596 m .20042 .7429 L .18417 .75139 L p .707 .577 .707 r
F P
0 g
s
.35326 .67367 m .36147 .71062 L .34112 .71054 L p .707 .577 .707 r
F P
0 g
s
.34112 .71054 m .33291 .6736 L .35326 .67367 L p .707 .577 .707 r
F P
0 g
s
.55534 .73602 m .69983 .27255 L .73671 .29137 L p .707 .577 .707 r
F P
0 g
s
.19141 .78688 m .1872 .76843 L .20344 .75991 L p .707 .577 .707 r
F P
0 g
s
.20344 .75991 m .20765 .77837 L .19141 .78688 L p .707 .577 .707 r
F P
0 g
s
.32558 .60147 m .33305 .65731 L .30588 .65719 L p .707 .577 .707 r
F P
0 g
s
.30588 .65719 m .29841 .60135 L .32558 .60147 L p .707 .577 .707 r
F P
0 g
s
.34818 .74523 m .34397 .72677 L .36427 .72667 L p .707 .577 .707 r
F P
0 g
s
.20677 .61478 m .21424 .67062 L .19031 .67824 L p .707 .577 .707 r
F P
0 g
s
.46998 .71042 m .61448 .24695 L .65771 .25724 L p .707 .577 .707 r
F P
0 g
s
.61448 .24695 m .46998 .71042 L .42985 .70615 L p .707 .577 .707 r
F P
0 g
s
.20042 .7429 m .19221 .70596 L .2159 .69706 L p .707 .577 .707 r
F P
0 g
s
.21424 .67062 m .20677 .61478 L .23595 .60835 L p .707 .577 .707 r
F P
0 g
s
.69983 .27255 m .55534 .73602 L .51322 .72071 L p .707 .577 .707 r
F P
0 g
s
.51322 .72071 m .65771 .25724 L .69983 .27255 L p .707 .577 .707 r
F P
0 g
s
.29841 .60135 m .30588 .65719 L .27499 .65956 L p .707 .577 .707 r
F P
0 g
s
.27499 .65956 m .26753 .60372 L .29841 .60135 L p .707 .577 .707 r
F P
0 g
s
.33291 .6736 m .34112 .71054 L .31444 .71323 L p .707 .577 .707 r
F P
0 g
s
.31444 .71323 m .30624 .67628 L .33291 .6736 L p .707 .577 .707 r
F P
0 g
s
.65771 .25724 m .51322 .72071 L .46998 .71042 L p .707 .577 .707 r
F P
0 g
s
.2159 .69706 m .22411 .734 L .20042 .7429 L p .707 .577 .707 r
F P
0 g
s
.20765 .77837 m .20344 .75991 L .22711 .75092 L p .707 .577 .707 r
F P
0 g
s
.24341 .66419 m .23595 .60835 L .26753 .60372 L p .707 .577 .707 r
F P
0 g
s
.23595 .60835 m .24341 .66419 L .21424 .67062 L p .707 .577 .707 r
F P
0 g
s
.26753 .60372 m .27499 .65956 L .24341 .66419 L p .707 .577 .707 r
F P
0 g
s
.22711 .75092 m .23133 .76938 L .20765 .77837 L p .707 .577 .707 r
F P
0 g
s
.74108 .65705 m .73362 .60121 L .70273 .60358 L p .707 .577 .707 r
F P
0 g
s
.73362 .60121 m .74108 .65705 L .77266 .65242 L p .707 .577 .707 r
F P
0 g
s
.77266 .65242 m .7652 .59658 L .73362 .60121 L p .707 .577 .707 r
F P
0 g
s
.34397 .72677 m .34818 .74523 L .32155 .7481 L p .707 .577 .707 r
F P
0 g
s
.32155 .7481 m .31734 .72964 L .34397 .72677 L p .707 .577 .707 r
F P
0 g
s
.7652 .59658 m .77266 .65242 L .80184 .64599 L p .707 .577 .707 r
F P
0 g
s
.80184 .64599 m .79437 .59015 L .7652 .59658 L p .707 .577 .707 r
F P
0 g
s
.22411 .734 m .2159 .69706 L .24472 .68861 L p .707 .577 .707 r
F P
0 g
s
.70273 .60358 m .7102 .65942 L .74108 .65705 L p .707 .577 .707 r
F P
0 g
s
.30624 .67628 m .31444 .71323 L .28406 .7184 L p .707 .577 .707 r
F P
0 g
s
.28406 .7184 m .27585 .68145 L .30624 .67628 L p .707 .577 .707 r
F P
0 g
s
.24472 .68861 m .25293 .72556 L .22411 .734 L p .707 .577 .707 r
F P
0 g
s
.79437 .59015 m .80184 .64599 L .82576 .63837 L p .707 .577 .707 r
F P
0 g
s
.82576 .63837 m .8183 .58253 L .79437 .59015 L p .707 .577 .707 r
F P
0 g
s
.23133 .76938 m .22711 .75092 L .2559 .74234 L p .707 .577 .707 r
F P
0 g
s
.25293 .72556 m .24472 .68861 L .27585 .68145 L p .707 .577 .707 r
F P
0 g
s
.27585 .68145 m .28406 .7184 L .25293 .72556 L p .707 .577 .707 r
F P
0 g
s
.2559 .74234 m .26011 .7608 L .23133 .76938 L p .707 .577 .707 r
F P
0 g
s
.31734 .72964 m .32155 .7481 L .2912 .75346 L p .707 .577 .707 r
F P
0 g
s
.2912 .75346 m .28699 .73501 L .31734 .72964 L p .707 .577 .707 r
F P
0 g
s
.74915 .72033 m .74095 .68338 L .71056 .68856 L p .707 .577 .707 r
F P
0 g
s
.74095 .68338 m .74915 .72033 L .78028 .71317 L p .707 .577 .707 r
F P
0 g
s
.78028 .71317 m .77207 .67622 L .74095 .68338 L p .707 .577 .707 r
F P
0 g
s
.77207 .67622 m .78028 .71317 L .8091 .70473 L p .707 .577 .707 r
F P
0 g
s
.8091 .70473 m .8009 .66778 L .77207 .67622 L p .707 .577 .707 r
F P
0 g
s
.26011 .7608 m .2559 .74234 L .28699 .73501 L p .707 .577 .707 r
F P
0 g
s
.71056 .68856 m .71877 .7255 L .74915 .72033 L p .707 .577 .707 r
F P
0 g
s
.28699 .73501 m .2912 .75346 L .26011 .7608 L p .707 .577 .707 r
F P
0 g
s
.71877 .7255 m .71056 .68856 L .68389 .69124 L p .707 .577 .707 r
F P
0 g
s
.8009 .66778 m .8091 .70473 L .83279 .69582 L p .707 .577 .707 r
F P
0 g
s
.83279 .69582 m .82459 .65888 L .8009 .66778 L p .707 .577 .707 r
F P
0 g
s
.8183 .58253 m .82576 .63837 L .84209 .63033 L p .707 .577 .707 r
F P
0 g
s
.84209 .63033 m .83462 .57449 L .8183 .58253 L p .707 .577 .707 r
F P
0 g
s
.75621 .77092 m .752 .75247 L .72166 .75783 L p .707 .577 .707 r
F P
0 g
s
.752 .75247 m .75621 .77092 L .7873 .76359 L p .707 .577 .707 r
F P
0 g
s
.7873 .76359 m .78309 .74514 L .752 .75247 L p .707 .577 .707 r
F P
0 g
s
.68389 .69124 m .69209 .72818 L .71877 .7255 L p .707 .577 .707 r
F P
0 g
s
.78309 .74514 m .7873 .76359 L .81609 .75501 L p .707 .577 .707 r
F P
0 g
s
.81609 .75501 m .81188 .73656 L .78309 .74514 L p .707 .577 .707 r
F P
0 g
s
.72166 .75783 m .72587 .77629 L .75621 .77092 L p .707 .577 .707 r
F P
0 g
s
.72587 .77629 m .72166 .75783 L .69503 .7607 L p .707 .577 .707 r
F P
0 g
s
.69503 .7607 m .69924 .77916 L .72587 .77629 L p .707 .577 .707 r
F P
0 g
s
.81188 .73656 m .81609 .75501 L .83977 .74602 L p .707 .577 .707 r
F P
0 g
s
.83977 .74602 m .83555 .72757 L .81188 .73656 L p .707 .577 .707 r
F P
0 g
s
.82459 .65888 m .83279 .69582 L .84904 .68734 L p .707 .577 .707 r
F P
0 g
s
.84904 .68734 m .84083 .65039 L .82459 .65888 L p .707 .577 .707 r
F P
0 g
s
.83462 .57449 m .84209 .63033 L .84921 .62264 L p .707 .577 .707 r
F P
0 g
s
.84921 .62264 m .84175 .5668 L .83462 .57449 L p .707 .577 .707 r
F P
0 g
s
.69924 .77916 m .69503 .7607 L .67472 .7608 L p .707 .577 .707 r
F P
0 g
s
.67472 .7608 m .67893 .77926 L .69924 .77916 L p .707 .577 .707 r
F P
0 g
s
.83555 .72757 m .83977 .74602 L .856 .7375 L p .707 .577 .707 r
F P
0 g
s
.856 .7375 m .85179 .71905 L .83555 .72757 L p .707 .577 .707 r
F P
0 g
s
.84083 .65039 m .84904 .68734 L .85625 .68009 L p .707 .577 .707 r
F P
0 g
s
.85625 .68009 m .84804 .64315 L .84083 .65039 L p .707 .577 .707 r
F P
0 g
s
.67893 .77926 m .67472 .7608 L .66272 .75812 L p .707 .577 .707 r
F P
0 g
s
.66272 .75812 m .66693 .77658 L .67893 .77926 L p .707 .577 .707 r
F P
0 g
s
.84175 .5668 m .84921 .62264 L .84645 .61606 L p .707 .577 .707 r
F P
0 g
s
.84645 .61606 m .83898 .56022 L .84175 .5668 L p .707 .577 .707 r
F P
0 g
s
.63961 .58945 m .64708 .64529 L .64984 .65187 L p .707 .577 .707 r
F P
0 g
s
.85179 .71905 m .856 .7375 L .86322 .73029 L p .707 .577 .707 r
F P
0 g
s
.86322 .73029 m .859 .71183 L .85179 .71905 L p .707 .577 .707 r
F P
0 g
s
.65971 .72529 m .65151 .68834 L .64897 .68305 L p .707 .577 .707 r
F P
0 g
s
.64897 .68305 m .65718 .72 L .65971 .72529 L p .707 .577 .707 r
F P
0 g
s
.84804 .64315 m .85625 .68009 L .85371 .6748 L p .707 .577 .707 r
F P
0 g
s
.85371 .6748 m .8455 .63786 L .84804 .64315 L p .707 .577 .707 r
F P
0 g
s
.64708 .64529 m .63961 .58945 L .64674 .58176 L p .707 .577 .707 r
F P
0 g
s
.66693 .77658 m .66272 .75812 L .6602 .75292 L p .707 .577 .707 r
F P
0 g
s
.6602 .75292 m .66441 .77138 L .66693 .77658 L p .707 .577 .707 r
F P
0 g
s
.83898 .56022 m .84645 .61606 L .83406 .61124 L p .707 .577 .707 r
F P
0 g
s
.83406 .61124 m .8266 .55539 L .83898 .56022 L p .707 .577 .707 r
F P
0 g
s
.64674 .58176 m .6542 .6376 L .64708 .64529 L p .707 .577 .707 r
F P
0 g
s
.859 .71183 m .86322 .73029 L .8607 .72509 L p .707 .577 .707 r
F P
0 g
s
.8607 .72509 m .85649 .70663 L .859 .71183 L p .707 .577 .707 r
F P
0 g
s
.39807 .61369 m .39061 .55785 L .35972 .56022 L p .707 .577 .707 r
F P
0 g
s
.39061 .55785 m .39807 .61369 L .42965 .60906 L p .707 .577 .707 r
F P
0 g
s
.42965 .60906 m .42219 .55322 L .39061 .55785 L p .707 .577 .707 r
F P
0 g
s
.65718 .72 m .64897 .68305 L .65618 .67581 L p .707 .577 .707 r
F P
0 g
s
.42219 .55322 m .42965 .60906 L .45883 .60263 L p .707 .577 .707 r
F P
0 g
s
.45883 .60263 m .45136 .54679 L .42219 .55322 L p .707 .577 .707 r
F P
0 g
s
.65618 .67581 m .66438 .71275 L .65718 .72 L p .707 .577 .707 r
F P
0 g
s
.36719 .61606 m .35972 .56022 L .33255 .5601 L p .707 .577 .707 r
F P
0 g
s
.35972 .56022 m .36719 .61606 L .39807 .61369 L p .707 .577 .707 r
F P
0 g
s
.6542 .6376 m .64674 .58176 L .66306 .57371 L p .707 .577 .707 r
F P
0 g
s
.8455 .63786 m .85371 .6748 L .84168 .67198 L p .707 .577 .707 r
F P
0 g
s
.84168 .67198 m .83347 .63504 L .8455 .63786 L p .707 .577 .707 r
F P
0 g
s
.45136 .54679 m .45883 .60263 L .48275 .59502 L p .707 .577 .707 r
F P
0 g
s
.48275 .59502 m .47529 .53917 L .45136 .54679 L p .707 .577 .707 r
F P
0 g
s
.66441 .77138 m .6602 .75292 L .66742 .74571 L p .707 .577 .707 r
F P
0 g
s
.40614 .66692 m .39794 .62998 L .36755 .63515 L p .707 .577 .707 r
F P
0 g
s
.39794 .62998 m .40614 .66692 L .43727 .65977 L p .707 .577 .707 r
F P
0 g
s
.43727 .65977 m .42906 .62282 L .39794 .62998 L p .707 .577 .707 r
F P
0 g
s
.42906 .62282 m .43727 .65977 L .46609 .65132 L p .707 .577 .707 r
F P
0 g
s
.46609 .65132 m .45789 .61438 L .42906 .62282 L p .707 .577 .707 r
F P
0 g
s
.66742 .74571 m .67163 .76416 L .66441 .77138 L p .707 .577 .707 r
F P
0 g
s
.8266 .55539 m .83406 .61124 L .81326 .60863 L p .707 .577 .707 r
F P
0 g
s
.81326 .60863 m .8058 .55279 L .8266 .55539 L p .707 .577 .707 r
F P
0 g
s
.33255 .5601 m .34002 .61594 L .36719 .61606 L p .707 .577 .707 r
F P
0 g
s
.66306 .57371 m .67053 .62956 L .6542 .6376 L p .707 .577 .707 r
F P
0 g
s
.85649 .70663 m .8607 .72509 L .8487 .72241 L p .707 .577 .707 r
F P
0 g
s
.8487 .72241 m .84449 .70395 L .85649 .70663 L p .707 .577 .707 r
F P
0 g
s
.36755 .63515 m .37576 .6721 L .40614 .66692 L p .707 .577 .707 r
F P
0 g
s
.34002 .61594 m .33255 .5601 L .31175 .55749 L p .707 .577 .707 r
F P
0 g
s
.37576 .6721 m .36755 .63515 L .34088 .63783 L p .707 .577 .707 r
F P
0 g
s
.4132 .70161 m .40899 .68315 L .37865 .68851 L p .707 .577 .707 r
F P
0 g
s
.40899 .68315 m .4132 .70161 L .44429 .69428 L p .707 .577 .707 r
F P
0 g
s
.44429 .69428 m .44008 .67582 L .40899 .68315 L p .707 .577 .707 r
F P
0 g
s
.44008 .67582 m .44429 .69428 L .47308 .68569 L p .707 .577 .707 r
F P
0 g
s
.47308 .68569 m .46887 .66724 L .44008 .67582 L p .707 .577 .707 r
F P
0 g
s
.45789 .61438 m .46609 .65132 L .48978 .64242 L p .707 .577 .707 r
F P
0 g
s
.48978 .64242 m .48158 .60548 L .45789 .61438 L p .707 .577 .707 r
F P
0 g
s
.37865 .68851 m .38286 .70697 L .4132 .70161 L p .707 .577 .707 r
F P
0 g
s
.66438 .71275 m .65618 .67581 L .67242 .66732 L p .707 .577 .707 r
F P
0 g
s
.34088 .63783 m .34908 .67478 L .37576 .6721 L p .707 .577 .707 r
F P
0 g
s
.47529 .53917 m .48275 .59502 L .49908 .58697 L p .707 .577 .707 r
F P
0 g
s
.49908 .58697 m .49161 .53113 L .47529 .53917 L p .707 .577 .707 r
F P
0 g
s
.67053 .62956 m .66306 .57371 L .68698 .5661 L p .707 .577 .707 r
F P
0 g
s
.38286 .70697 m .37865 .68851 L .35202 .69139 L p .707 .577 .707 r
F P
0 g
s
.31175 .55749 m .31922 .61334 L .34002 .61594 L p .707 .577 .707 r
F P
0 g
s
.67242 .66732 m .68063 .70426 L .66438 .71275 L p .707 .577 .707 r
F P
0 g
s
.83347 .63504 m .84168 .67198 L .82133 .67191 L p .707 .577 .707 r
F P
0 g
s
.82133 .67191 m .81313 .63496 L .83347 .63504 L p .707 .577 .707 r
F P
0 g
s
.35202 .69139 m .35623 .70984 L .38286 .70697 L p .707 .577 .707 r
F P
0 g
s
.46887 .66724 m .47308 .68569 L .49676 .67671 L p .707 .577 .707 r
F P
0 g
s
.49676 .67671 m .49254 .65825 L .46887 .66724 L p .707 .577 .707 r
F P
0 g
s
.34908 .67478 m .34088 .63783 L .32053 .63776 L p .707 .577 .707 r
F P
0 g
s
.8058 .55279 m .81326 .60863 L .78609 .60851 L p .707 .577 .707 r
F P
0 g
s
.78609 .60851 m .77863 .55267 L .8058 .55279 L p .707 .577 .707 r
F P
0 g
s
.67163 .76416 m .66742 .74571 L .68365 .73719 L p .707 .577 .707 r
F P
0 g
s
.68698 .5661 m .69445 .62194 L .67053 .62956 L p .707 .577 .707 r
F P
0 g
s
.48158 .60548 m .48978 .64242 L .50603 .63393 L p .707 .577 .707 r
F P
0 g
s
.50603 .63393 m .49782 .59699 L .48158 .60548 L p .707 .577 .707 r
F P
0 g
s
.31922 .61334 m .31175 .55749 L .29937 .55267 L p .707 .577 .707 r
F P
0 g
s
.68365 .73719 m .68787 .75564 L .67163 .76416 L p .707 .577 .707 r
F P
0 g
s
.32053 .63776 m .32873 .6747 L .34908 .67478 L p .707 .577 .707 r
F P
0 g
s
.35623 .70984 m .35202 .69139 L .33171 .69149 L p .707 .577 .707 r
F P
0 g
s
.84449 .70395 m .8487 .72241 L .82839 .72251 L p .707 .577 .707 r
F P
0 g
s
.82839 .72251 m .82418 .70405 L .84449 .70395 L p .707 .577 .707 r
F P
0 g
s
.69445 .62194 m .68698 .5661 L .71616 .55967 L p .707 .577 .707 r
F P
0 g
s
.33171 .69149 m .33592 .70994 L .35623 .70984 L p .707 .577 .707 r
F P
0 g
s
.68063 .70426 m .67242 .66732 L .69612 .65842 L p .707 .577 .707 r
F P
0 g
s
.49254 .65825 m .49676 .67671 L .51299 .66819 L p .707 .577 .707 r
F P
0 g
s
.51299 .66819 m .50878 .64973 L .49254 .65825 L p .707 .577 .707 r
F P
0 g
s
.49161 .53113 m .49908 .58697 L .5062 .57928 L p .707 .577 .707 r
F P
0 g
s
.5062 .57928 m .49874 .52344 L .49161 .53113 L p .707 .577 .707 r
F P
0 g
s
.77863 .55267 m .78609 .60851 L .75521 .61088 L p .707 .577 .707 r
F P
0 g
s
.75521 .61088 m .74774 .55504 L .77863 .55267 L p .707 .577 .707 r
F P
0 g
s
.29937 .55267 m .30683 .60851 L .31922 .61334 L p .707 .577 .707 r
F P
0 g
s
.81313 .63496 m .82133 .67191 L .79466 .67459 L p .707 .577 .707 r
F P
0 g
s
.79466 .67459 m .78645 .63765 L .81313 .63496 L p .707 .577 .707 r
F P
0 g
s
.69612 .65842 m .70432 .69536 L .68063 .70426 L p .707 .577 .707 r
F P
0 g
s
.72363 .61551 m .71616 .55967 L .74774 .55504 L p .707 .577 .707 r
F P
0 g
s
.71616 .55967 m .72363 .61551 L .69445 .62194 L p .707 .577 .707 r
F P
0 g
s
.32873 .6747 m .32053 .63776 L .3085 .63494 L p .707 .577 .707 r
F P
0 g
s
.74774 .55504 m .75521 .61088 L .72363 .61551 L p .707 .577 .707 r
F P
0 g
s
.68787 .75564 m .68365 .73719 L .70733 .7282 L p .707 .577 .707 r
F P
0 g
s
.3085 .63494 m .3167 .67188 L .32873 .6747 L p .707 .577 .707 r
F P
0 g
s
.49782 .59699 m .50603 .63393 L .51324 .62669 L p .707 .577 .707 r
F P
0 g
s
.51324 .62669 m .50503 .58975 L .49782 .59699 L p .707 .577 .707 r
F P
0 g
s
.70733 .7282 m .71154 .74665 L .68787 .75564 L p .707 .577 .707 r
F P
0 g
s
.70432 .69536 m .69612 .65842 L .72494 .64998 L p .707 .577 .707 r
F P
0 g
s
.33592 .70994 m .33171 .69149 L .31971 .6888 L p .707 .577 .707 r
F P
0 g
s
.30683 .60851 m .29937 .55267 L .2966 .54609 L p .707 .577 .707 r
F P
0 g
s
.82418 .70405 m .82839 .72251 L .80176 .72538 L p .707 .577 .707 r
F P
0 g
s
.80176 .72538 m .79755 .70692 L .82418 .70405 L p .707 .577 .707 r
F P
0 g
s
.78645 .63765 m .79466 .67459 L .76427 .67976 L p .707 .577 .707 r
F P
0 g
s
.76427 .67976 m .75606 .64282 L .78645 .63765 L p .707 .577 .707 r
F P
0 g
s
.31971 .6888 m .32392 .70726 L .33592 .70994 L p .707 .577 .707 r
F P
0 g
s
.72494 .64998 m .73314 .68692 L .70432 .69536 L p .707 .577 .707 r
F P
0 g
s
.50878 .64973 m .51299 .66819 L .52021 .66097 L p .707 .577 .707 r
F P
0 g
s
.52021 .66097 m .51599 .64252 L .50878 .64973 L p .707 .577 .707 r
F P
0 g
s
.73314 .68692 m .72494 .64998 L .75606 .64282 L p .707 .577 .707 r
F P
0 g
s
.75606 .64282 m .76427 .67976 L .73314 .68692 L p .707 .577 .707 r
F P
0 g
s
.49874 .52344 m .5062 .57928 L .50344 .5727 L p .707 .577 .707 r
F P
0 g
s
.50344 .5727 m .49597 .51686 L .49874 .52344 L p .707 .577 .707 r
F P
0 g
s
.2966 .54609 m .30407 .60193 L .30683 .60851 L p .707 .577 .707 r
F P
0 g
s
.71154 .74665 m .70733 .7282 L .73612 .71962 L p .707 .577 .707 r
F P
0 g
s
.73612 .71962 m .74033 .73807 L .71154 .74665 L p .707 .577 .707 r
F P
0 g
s
.79755 .70692 m .80176 .72538 L .77142 .73074 L p .707 .577 .707 r
F P
0 g
s
.77142 .73074 m .7672 .71229 L .79755 .70692 L p .707 .577 .707 r
F P
0 g
s
.3167 .67188 m .3085 .63494 L .30596 .62965 L p .707 .577 .707 r
F P
0 g
s
.74033 .73807 m .73612 .71962 L .7672 .71229 L p .707 .577 .707 r
F P
0 g
s
.7672 .71229 m .77142 .73074 L .74033 .73807 L p .707 .577 .707 r
F P
0 g
s
.30596 .62965 m .31417 .66659 L .3167 .67188 L p .707 .577 .707 r
F P
0 g
s
.50503 .58975 m .51324 .62669 L .5107 .6214 L p .707 .577 .707 r
F P
0 g
s
.5107 .6214 m .50249 .58445 L .50503 .58975 L p .707 .577 .707 r
F P
0 g
s
.32392 .70726 m .31971 .6888 L .31719 .6836 L p .707 .577 .707 r
F P
0 g
s
.30407 .60193 m .2966 .54609 L .30373 .5384 L p .707 .577 .707 r
F P
0 g
s
.31719 .6836 m .3214 .70206 L .32392 .70726 L p .707 .577 .707 r
F P
0 g
s
.51599 .64252 m .52021 .66097 L .51769 .65577 L p .707 .577 .707 r
F P
0 g
s
.51769 .65577 m .51348 .63731 L .51599 .64252 L p .707 .577 .707 r
F P
0 g
s
.49597 .51686 m .50344 .5727 L .49105 .56788 L p .707 .577 .707 r
F P
0 g
s
.49105 .56788 m .48359 .51204 L .49597 .51686 L p .707 .577 .707 r
F P
0 g
s
.30373 .5384 m .31119 .59424 L .30407 .60193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31417 .66659 m .30596 .62965 L .31317 .62241 L p .707 .577 .707 r
F P
0 g
s
.31317 .62241 m .32137 .65935 L .31417 .66659 L p .707 .577 .707 r
F P
0 g
s
.50249 .58445 m .5107 .6214 L .49867 .61858 L p .707 .577 .707 r
F P
0 g
s
.49867 .61858 m .49046 .58163 L .50249 .58445 L p .707 .577 .707 r
F P
0 g
s
.3214 .70206 m .31719 .6836 L .3244 .67639 L p .707 .577 .707 r
F P
0 g
s
.31119 .59424 m .30373 .5384 L .32005 .53036 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3244 .67639 m .32862 .69485 L .3214 .70206 L p .707 .577 .707 r
F P
0 g
s
.51348 .63731 m .51769 .65577 L .50569 .65309 L p .707 .577 .707 r
F P
0 g
s
.50569 .65309 m .50148 .63463 L .51348 .63731 L p .707 .577 .707 r
F P
0 g
s
.48359 .51204 m .49105 .56788 L .47025 .56527 L p .707 .577 .707 r
F P
0 g
s
.47025 .56527 m .46279 .50943 L .48359 .51204 L p .707 .577 .707 r
F P
0 g
s
.32005 .53036 m .32752 .5862 L .31119 .59424 L p .707 .577 .707 r
F P
0 g
s
.32137 .65935 m .31317 .62241 L .32941 .61392 L p .707 .577 .707 r
F P
0 g
s
.32752 .5862 m .32005 .53036 L .34397 .52274 L p .707 .577 .707 r
F P
0 g
s
.32941 .61392 m .33762 .65086 L .32137 .65935 L p .707 .577 .707 r
F P
0 g
s
.49046 .58163 m .49867 .61858 L .47832 .61851 L p .707 .577 .707 r
F P
0 g
s
.47832 .61851 m .47012 .58156 L .49046 .58163 L p .707 .577 .707 r
F P
0 g
s
.32862 .69485 m .3244 .67639 L .34064 .66787 L p .707 .577 .707 r
F P
0 g
s
.34064 .66787 m .34486 .68633 L .32862 .69485 L p .707 .577 .707 r
F P
0 g
s
.46279 .50943 m .47025 .56527 L .44308 .56515 L p .707 .577 .707 r
F P
0 g
s
.44308 .56515 m .43562 .50931 L .46279 .50943 L p .707 .577 .707 r
F P
0 g
s
.50148 .63463 m .50569 .65309 L .48538 .65319 L p .707 .577 .707 r
F P
0 g
s
.48538 .65319 m .48117 .63473 L .50148 .63463 L p .707 .577 .707 r
F P
0 g
s
.34397 .52274 m .35144 .57858 L .32752 .5862 L p .707 .577 .707 r
F P
0 g
s
.33762 .65086 m .32941 .61392 L .3531 .60502 L p .707 .577 .707 r
F P
0 g
s
.35144 .57858 m .34397 .52274 L .37315 .51631 L p .707 .577 .707 r
F P
0 g
s
.43562 .50931 m .44308 .56515 L .41219 .56752 L p .707 .577 .707 r
F P
0 g
s
.41219 .56752 m .40473 .51168 L .43562 .50931 L p .707 .577 .707 r
F P
0 g
s
.47012 .58156 m .47832 .61851 L .45165 .62119 L p .707 .577 .707 r
F P
0 g
s
.45165 .62119 m .44344 .58424 L .47012 .58156 L p .707 .577 .707 r
F P
0 g
s
.3531 .60502 m .36131 .64196 L .33762 .65086 L p .707 .577 .707 r
F P
0 g
s
.34486 .68633 m .34064 .66787 L .36432 .65888 L p .707 .577 .707 r
F P
0 g
s
.38062 .57215 m .37315 .51631 L .40473 .51168 L p .707 .577 .707 r
F P
0 g
s
.37315 .51631 m .38062 .57215 L .35144 .57858 L p .707 .577 .707 r
F P
0 g
s
.40473 .51168 m .41219 .56752 L .38062 .57215 L p .707 .577 .707 r
F P
0 g
s
.36432 .65888 m .36853 .67734 L .34486 .68633 L p .707 .577 .707 r
F P
0 g
s
.48117 .63473 m .48538 .65319 L .45875 .65606 L p .707 .577 .707 r
F P
0 g
s
.45875 .65606 m .45454 .6376 L .48117 .63473 L p .707 .577 .707 r
F P
0 g
s
.36131 .64196 m .3531 .60502 L .38193 .59657 L p .707 .577 .707 r
F P
0 g
s
.44344 .58424 m .45165 .62119 L .42126 .62636 L p .707 .577 .707 r
F P
0 g
s
.42126 .62636 m .41305 .58942 L .44344 .58424 L p .707 .577 .707 r
F P
0 g
s
.38193 .59657 m .39013 .63352 L .36131 .64196 L p .707 .577 .707 r
F P
0 g
s
.36853 .67734 m .36432 .65888 L .39311 .6503 L p .707 .577 .707 r
F P
0 g
s
.39013 .63352 m .38193 .59657 L .41305 .58942 L p .707 .577 .707 r
F P
0 g
s
.41305 .58942 m .42126 .62636 L .39013 .63352 L p .707 .577 .707 r
F P
0 g
s
.39311 .6503 m .39732 .66876 L .36853 .67734 L p .707 .577 .707 r
F P
0 g
s
.45454 .6376 m .45875 .65606 L .42841 .66143 L p .707 .577 .707 r
F P
0 g
s
.42841 .66143 m .42419 .64297 L .45454 .6376 L p .707 .577 .707 r
F P
0 g
s
.39732 .66876 m .39311 .6503 L .42419 .64297 L p .707 .577 .707 r
F P
0 g
s
.42419 .64297 m .42841 .66143 L .39732 .66876 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
VGoo4000M7oo002GOol30009FUH00`00FUIJEP03FUH7001]Ool009Eoo`800003FUH005YF00QJEP03
001JEUYF00UJEP03001JEP0000<006Uoo`00Tgoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF1000IGoo002BOol20004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH4001QOol0095oo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEP00008005ioo`00TGoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH00eYF0`00Fgoo002@Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH3001HOol0091oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP<005Eoo`00Sgoo00<005YF000015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00@005YF000005=oo`00Sgoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH03eYF0P00
DGoo002?Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH2001?Ool008ioo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00IJEP8004eoo`00SWoo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
0P00Bgoo002>Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH2001:Ool008eoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00aJEP8004Qoo`00SGoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH00UYF00<007ooOol0AGoo002=Ool00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03
FUH00`00Oomoo`14Ool008eoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP8004Aoo`00S7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<007ooOol0@Goo002<Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH20012Ool0
08aoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP05001JEUYFFUH00010
Ool008]oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo03eoo`00RWoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0?7oo002:Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00Oomoo`0lOol008Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00=JEP8003ioo`00RGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
?Woo0029Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000nOol008Uoo`03001J
EP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0003ioo`00R7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000?Woo0028Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000oOol008Qoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0003moo`00Qgoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000?goo0027Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00gooFUH00009FUH00`00FUIJEP04FUH20010Ool008Mo
o`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00041oo`00QWoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000@7oo0026Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00010Ool008Ioo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP80045oo`00QWoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF0000@Goo0025Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00011
Ool008Eoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80049oo`00QGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000@Woo0024Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUH00012Ool008Aoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP8004=oo`00Q7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF0000@goo0023Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00013
Ool008=oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8004Aoo`00Pgoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000A7oo0022Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00014Ool0089oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP<004Aoo`00PWoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF0000AGoo0021Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00015Ool0085oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<004Eoo`00PGoo
00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000AWoo0020Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00016Ool0081oo`03001JEP0000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP<004Ioo`00P7oo00<005YF000015YF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF0000Agoo001oOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUH00017Ool007moo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0004Moo`00Ogoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000B7oo
001oOol00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00018Ool007ioo`03
001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Qoo`00OWoo00<005YF0000
15YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH004Qoo`00OWoo00<005YF000015YF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YF0000BGoo001mOol00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00019Ool007eoo`03001JEP0000AJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0004Uoo`00OGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF0000BWoo001lOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
001:Ool007aoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Yoo`00
O7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Bgoo001kOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001;Ool007]oo`03001JEP0000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004]oo`00Ngoo00<005YF000015YF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YFFUH004]oo`00N7oo3P001UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000C7oo001_Ool90003FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
001<Ool006Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000YJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00=JEP03OomJEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF001<Ool006Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001=Ool0061oo`@000IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0004eoo`00G7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001=Ool005Yoo`8000EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001>Ool005Uoo`8000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0001>Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00CWoo001FOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool005Eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0004moo`00E7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF001?Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00Cgoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001Goo6@00<Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001oo`040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000`Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001EOol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>
0003FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH002ioo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1@000UYF00@005YFFUH000]JEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
0003FUH005YF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00=JEP@00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
001JEP0]Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;Goo001EOol00`00
FUH00005FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<005YFFUH02UYF00<005YFFUH0
2UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00<005YF00001EYF00<005YF0000
0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3P0000=JEP00FUH02eYF00<0
05YFFUH02eYF00<005YFFUH02EYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo
00@005YFFUH000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEPT000=JEP03001JEUYF00=J
EP06001JEP00001JEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;7oo001EOol01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo
001FOol2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9JEP8000EJEP03001JEUYF
00EJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;7oo001FOol015YF001JEP001EYF00<005YFFUH01EYF00H005YF000005YF0009FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo001:Ool>
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00AWoo10000UYF00<005YFFUH0
1EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000oOol70006
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YF
FUH02UYF00<005YFFUH02UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH015YF6P000UYF00<007ooOol0:Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02eYF00<005YFFUH02EYF00D0
05YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00=goo0P0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YFFUIJEP/0009JEP03001JEUYF00IJEP03001JEUYF00]JEP04001JEUYF
0008FUH01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002]oo`00=Goo0P000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P001EYF00<005YFFUH00UYF1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00<goo
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00=J
EP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH01P00FUIJEP00
FUH000EJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000[Ool0035oo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD000UJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00]JEP03001JEUYF00UJEP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
;7oo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH01000FUIJEP000UYF00@005YFFUIJEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP04FUH60007FUH00`00FUIJEP06FUH00`00FUH0000:0009FUH00`00FUIJEP0:FUH01000
FUIJEP002EYF00<005YFFUH00eYF00@005YF000000]JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP/002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00P000=JEP03001JEUYF00=JEP04001JEP000006FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200000eYF001JEP0:FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH:0003FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009J
EP05001JEUYFFUH00006FUH40006FUH40003FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002eYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP03001JEUYF
00IJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0:goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF009JEP@000IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH20006FUH01000FUIJEUYF10001UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002]oo`00;Goo00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP04001JEUYFFUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP07
FUH01000FUIJEUYF2`000UYF00D005YFFUIJEP0000aJEP04001JEUYF0009FUH00`00FUIJEP04FUH2
00000eYF001JEP04FUH20006FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUH000000UYF00<005YFFUH0
1EYF0`000eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00<005YFFUH00P0000=JEP000000
0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH90005FUH00`00FUIJEP020005FUH01000FUIJEUYF0`001UYF00<005YFFUH01eYF00<0
05YFFUH010002UYF0`000eYF00@005YFFUH0009JEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEPP000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF100000=JEP00FUH00eYF0P000eYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000^Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF0P001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH015YF
0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
0P0015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002Yoo`00;Woo00<005YF00001EYF00<005YFFUH00UYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00@005YF000000MJEP03001J
EUYF00AJEPD000UJEP03001JEUYF009JEP800003FUH005YF00IJEP05001JEUYFFUH00003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH005YF0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Yo
o`00;Woo00<005YF00001EYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@000UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHD000YOol002ioo`04001JEUYF0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH900000eYF001JEP03FUH00`00FUIJEP04FUH300000goo00000005FUH00`00FUIJEP05FUH4
0007FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH3
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo000^Ool01000FUIJEP000UYF0P000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01`0015YF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP<0009oo`04001JEP00FUH40004FUH40002FUH00`00FUIJEP06FUH00`00FUH000030008FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00:Goo
000_Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000EJEP04001JEP000002FUH01@00Oomoo`00FUH02P001UYF00<005YFFUH01EYF0`00
35YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00:Woo000_Ool2FUH20005FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YF
FUH01eYF00<005YF00000UYF00@005YFFUIJEP<00004FUH005YFFUH;00000eYF001JEP08FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH01000FUIJEUYF0P00:goo000_Ool015YF001JEP001EYF00<005YFFUH01EYF
00H005YF000005YF0009FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH000080003FUH00`00
FUIJEP0500000eYF001JEP08FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP040003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000;Goo000_
Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00AJ
EP@000MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000_Ool002moo`80009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP05001JEP00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80039oo`00<7oo0P0000=JEP00FUH00eYF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00AJEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP800004FUH005YF0005FUH01000FUH000001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Aoo`00<Woo1P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@000=JEPL001EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYF0002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF4000:Goo000eOol20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP0J0005FUH00`00FUH000050002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH200001UYF001JEUYF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEP0000L000=JEP03001JEUYF00=JEP04001JEUYF000YOol003=o
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@00004FUH0
00000002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH20005FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF
1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:7oo000bOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00FUIJ
EP03FUH20003FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH70003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH00000:7oo000`Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Qoo`00;goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP<000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP8000UJEP03
001JEUYF00YJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP06
001JEP00001JEP002EYF00<005YFFUH01EYF00<005YFFUH00UYF2`0000=JEP0000009goo000_Ool0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<0
05YF00002P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF0`00
1eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF
FUH00UYF1@000eYF00<005YFFUH01eYF00<005YFFUH00UYF200017oo0`000eYF10009goo000`Ool0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`001eYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP04001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP0>0007FUH00`00FUIJEP04FUH7000:Ool200000eYF001JEP04FUH00`00FUH0000W
Ool0031oo`04001JEUYF0003FUH00`00FUIJEP04FUH40005FUH50007FUH50002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH200000eYF001JEP0;FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF100000=JEP00FUH01eYF00<005YFFUH010003goo0P000eYF00<005YFFUH00eYF0P00
:7oo000`Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP@000=JEPD000IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00IJEP<001AJEP03001JEUYF00=JEP04001JEUYF0004FUH30005
FUH00`00FUIJEP05FUH4000@Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0031oo`04001J
EUYF0004FUH01000FUH000001UYF00<005YFFUH01UYF10000UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02UYF0P0025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP<000MJEP03
001JEUYF009JEP80011oo`@00003FUH005YF00IJEP03001JEUYF008002Yoo`00<Goo00@005YFFUH0
00=JEP<000MJEP03001JEUYF009JEP@000IJEP03001JEUYF00MJEP04001JEUYFFUH:0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH40006FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUH00002000=Ool50005
FUH00`00FUIJEP05FUH3000/Ool0035oo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH50000
0eYF001JEP08FUH00`00FUIJEP04FUH60007Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH20003FUH2000=FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00EJEP03001JEUYF00=JEP<000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8002ioo`00
<Goo00<005YFFUH00P001EYF00@005YFFUIJEP@000EJEP03001JEUYF00MJEP03001JEUYF00@000]o
o`8000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00]JEP03001J
EUYF00UJEP8000EJEP800003FUH005YF00QJEP03001JEUYF00=JEP03001JEUYF00<000EJEP03001J
EP0000<00003FUH0000000Qoo`@000IJEP03001JEUYF00IJEP03001JEP0000<0031oo`00<Woo00AJ
EP00FUH000EJEP06001JEP00001JEP0025YF00<005YFFUH015YF1@002goo100000=JEP00FUH00UYF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF0P001eYF0P002EYF
00<005YFFUH01UYF00<005YF00001EYF0P000UYF00<005YFFUH00P0017oo100000=JEP00FUH01eYF
00<005YFFUH01EYF0`00=7oo000bOol01000FUIJEP001EYF0P000eYF00<005YFFUH01UYF00<005YF
FUH010003Goo0`001EYF00<005YFFUH00UYF00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00MJEP8000MJEP8000AJEP03001JEUYF0080009JEP03001J
EUYF008000AJEP03001JEUYF00H000EJEP03001JEUYF00MJEP03001JEUYF009JEP8003Moo`00<Woo
0P000UYF00<005YFFUH00P001UYF00<005YFFUH015YF10003goo0P0000=JEP00FUH01UYF00@005YF
FUIJEP800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP8000]J
EP8000EJEP03001JEUYF00=JEP03001JEUYF0080009JEP`000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008003Uoo`00<goo0P0000=JEP0000000P001eYF00<005YFFUH0100047oo0`00
0eYF00<005YFFUH01EYF00H005YF000007oo000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH2000;FUH00`00FUH00004FUH00`00FUIJEP06FUH300000eYF00000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol003Eoo`8000=JEP03001JEUYF00AJEP<0
011oo`@000IJEP03001JEUYF00AJEP<000Aoo`03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040010Ool0
03Aoo`8000AJEP03001JEUYF009JEP8000Moo`<000Eoo`@0009JEP03001JEUYF00IJEP04001JEUYF
FUH20008Ool00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP02FUH30005FUH01000FUIJEP000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00A7oo000cOol00`00FUH00005FUH01000FUH0000027oo2@001UYF00<0
05YFFUH01UYF00@005YF000000]oo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP8000]JEP03001JEUYF00AJEP03001JEUYF00YJEP800003FUH005YF00AJEP03001JEUYF009J
EPP004Yoo`00<goo00@005YFFUH000=JEP<000Aoo`/00003FUH005YF00QJEP03001JEUYF00AJEP<0
00moo`03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000/0059oo`00<goo
00D005YFFUH005YF00T000=JEP03001JEUYF00D00003FUH005YF00QJEP03001JEUYF00@001=oo`05
001JEUYFFUH0000;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00P00Dgoo000cOol20000
0eYF00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF1@0067oo0P00
3EYF00<005YFFUH02UYF00<005YFFUH02UYF0P002eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YFFUH00UYF00<005YFFUH01EYF0`00EGoo000dOol200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP04000OOol2000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEP002UYF00<005YFFUH00eYF0P00Egoo000dOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF1@009Goo0P0025YF00<005YFFUH02eYF00<0
05YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YF
00000`00FGoo000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04000/Ool2
0006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF3P00DWoo000eOol200000eYF001JEP04FUH01000FUIJEUYF1P00<Woo
0P0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEPP000=JEP03001JEUYF00=JEP04001JEP00001@Ool003Moo`/003Yoo`80
00mJEP03001JEUYF00UJEP8000]JEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001?Ool007ioo`<000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00EJEP8000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00001?Ool0085oo`8000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF001?Ool008=o
o`8000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF009JEP/00003FUH0000004ioo`00QGoo0`0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF20001Woo0P000UYF1000CWoo0028
Ool2000>FUH00`00FUIJEP0BFUH00`00FUIJEP03FUH6000<Ool20005FUH00`00FUH0001>Ool008Yo
o`@000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`@00003FUH005YF
00AJEP8004moo`00SWoo1P0045YF00<005YFFUH01UYF00@005YFFUIJEP8000]oo`<000EJEP03001J
EUYF00=JEP03001oogoo04ioo`00U7oo1P002UYF00<005YFFUH01eYF0`002goo0P0000=JEP00FUH0
1UYF00<005YFFUH00P00DGoo002GOol200000eYF000000040008FUH6000;Ool30003FUH00`00FUIJ
EP05FUH3001COol009Ioo`03001JEUYF009JEP03001JEUYF009JEPP000eoo`@000MJEP03001JEUYF
00=JEP8005Eoo`00UGoo0P001EYF00@005YFFUIJEP8000moo`@0009JEP03001JEUYF00IJEP03001J
EP0000<005Moo`00U7oo00<005YF00001EYF00@005YF000000]oo`H000IJEP03001JEUYF00EJEP<0
05]oo`00U7oo00@005YFFUH000=JEP<000Eoo`P000=JEP03001JEUYF00MJEP03001JEUYF009JEP80
05ioo`00U7oo00D005YFFUH005YF00X000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
0080061oo`00UGoo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@006=oo`00UGoo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1000Igoo002EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6001[Ool0
09Ioo`800003FUH005YF00AJEP03001JEUYF009JEPP0075oo`00V7oo3000NGoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60099 .74931 m .59637 .69344 L .5653 .69418 L p .707 .577 .707 r
F P
0 g
s
.59637 .69344 m .60099 .74931 L .63273 .74616 L p .707 .577 .707 r
F P
0 g
s
.63273 .74616 m .6281 .69028 L .59637 .69344 L p .707 .577 .707 r
F P
0 g
s
.6281 .69028 m .63273 .74616 L .66203 .74089 L p .707 .577 .707 r
F P
0 g
s
.66203 .74089 m .65741 .68502 L .6281 .69028 L p .707 .577 .707 r
F P
0 g
s
.56993 .75005 m .5653 .69418 L .53796 .69242 L p .707 .577 .707 r
F P
0 g
s
.5653 .69418 m .56993 .75005 L .60099 .74931 L p .707 .577 .707 r
F P
0 g
s
.65741 .68502 m .66203 .74089 L .68603 .73403 L p .707 .577 .707 r
F P
0 g
s
.68603 .73403 m .68141 .67816 L .65741 .68502 L p .707 .577 .707 r
F P
0 g
s
.6061 .81152 m .601 .7743 L .57013 .77677 L p .707 .577 .707 r
F P
0 g
s
.601 .7743 m .6061 .81152 L .63767 .8068 L p .707 .577 .707 r
F P
0 g
s
.63767 .8068 m .63257 .76957 L .601 .7743 L p .707 .577 .707 r
F P
0 g
s
.53796 .69242 m .54258 .74829 L .56993 .75005 L p .707 .577 .707 r
F P
0 g
s
.63257 .76957 m .63767 .8068 L .66684 .80028 L p .707 .577 .707 r
F P
0 g
s
.66684 .80028 m .66174 .76306 L .63257 .76957 L p .707 .577 .707 r
F P
0 g
s
.54258 .74829 m .53796 .69242 L .517 .68835 L p .707 .577 .707 r
F P
0 g
s
.57523 .814 m .57013 .77677 L .54297 .77676 L p .707 .577 .707 r
F P
0 g
s
.57013 .77677 m .57523 .814 L .6061 .81152 L p .707 .577 .707 r
F P
0 g
s
.66174 .76306 m .66684 .80028 L .69075 .79262 L p .707 .577 .707 r
F P
0 g
s
.69075 .79262 m .68565 .7554 L .66174 .76306 L p .707 .577 .707 r
F P
0 g
s
.68141 .67816 m .68603 .73403 L .70239 .72624 L p .707 .577 .707 r
F P
0 g
s
.70239 .72624 m .69776 .67037 L .68141 .67816 L p .707 .577 .707 r
F P
0 g
s
.61047 .85871 m .60785 .84011 L .577 .8427 L p .707 .577 .707 r
F P
0 g
s
.60785 .84011 m .61047 .85871 L .64202 .85388 L p .707 .577 .707 r
F P
0 g
s
.64202 .85388 m .6394 .83527 L .60785 .84011 L p .707 .577 .707 r
F P
0 g
s
.54297 .77676 m .54808 .81398 L .57523 .814 L p .707 .577 .707 r
F P
0 g
s
.517 .68835 m .52162 .74422 L .54258 .74829 L p .707 .577 .707 r
F P
0 g
s
.6394 .83527 m .64202 .85388 L .67118 .84728 L p .707 .577 .707 r
F P
0 g
s
.67118 .84728 m .66856 .82868 L .6394 .83527 L p .707 .577 .707 r
F P
0 g
s
.577 .8427 m .57962 .86131 L .61047 .85871 L p .707 .577 .707 r
F P
0 g
s
.57962 .86131 m .577 .8427 L .54986 .8428 L p .707 .577 .707 r
F P
0 g
s
.54808 .81398 m .54297 .77676 L .52219 .77425 L p .707 .577 .707 r
F P
0 g
s
.52162 .74422 m .517 .68835 L .50449 .68235 L p .707 .577 .707 r
F P
0 g
s
.54986 .8428 m .55248 .86141 L .57962 .86131 L p .707 .577 .707 r
F P
0 g
s
.66856 .82868 m .67118 .84728 L .69508 .83957 L p .707 .577 .707 r
F P
0 g
s
.69508 .83957 m .69246 .82096 L .66856 .82868 L p .707 .577 .707 r
F P
0 g
s
.68565 .7554 m .69075 .79262 L .70707 .78456 L p .707 .577 .707 r
F P
0 g
s
.70707 .78456 m .70197 .74734 L .68565 .7554 L p .707 .577 .707 r
F P
0 g
s
.52219 .77425 m .52729 .81147 L .54808 .81398 L p .707 .577 .707 r
F P
0 g
s
.69776 .67037 m .70239 .72624 L .70949 .71829 L p .707 .577 .707 r
F P
0 g
s
.70949 .71829 m .70486 .66242 L .69776 .67037 L p .707 .577 .707 r
F P
0 g
s
.55248 .86141 m .54986 .8428 L .52909 .84041 L p .707 .577 .707 r
F P
0 g
s
.50449 .68235 m .50911 .73822 L .52162 .74422 L p .707 .577 .707 r
F P
0 g
s
.52909 .84041 m .53171 .85901 L .55248 .86141 L p .707 .577 .707 r
F P
0 g
s
.69246 .82096 m .69508 .83957 L .7114 .83149 L p .707 .577 .707 r
F P
0 g
s
.7114 .83149 m .70878 .81288 L .69246 .82096 L p .707 .577 .707 r
F P
0 g
s
.52729 .81147 m .52219 .77425 L .50981 .7695 L p .707 .577 .707 r
F P
0 g
s
.50911 .73822 m .50449 .68235 L .50164 .67502 L p .707 .577 .707 r
F P
0 g
s
.50164 .67502 m .50626 .73089 L .50911 .73822 L p .707 .577 .707 r
F P
0 g
s
.50626 .73089 m .50164 .67502 L .50874 .66707 L p .707 .577 .707 r
F P
0 g
s
.50874 .66707 m .51336 .72294 L .50626 .73089 L p .707 .577 .707 r
F P
0 g
s
.51336 .72294 m .50874 .66707 L .52509 .65929 L p .707 .577 .707 r
F P
0 g
s
.49038 .82544 m .58053 .34202 L .53725 .33141 L p .707 .577 .707 r
F P
0 g
s
.50981 .7695 m .51491 .80672 L .52729 .81147 L p .707 .577 .707 r
F P
0 g
s
.51491 .80672 m .50981 .7695 L .50705 .76297 L p .707 .577 .707 r
F P
0 g
s
.50705 .76297 m .51215 .80019 L .51491 .80672 L p .707 .577 .707 r
F P
0 g
s
.51215 .80019 m .50705 .76297 L .51419 .7553 L p .707 .577 .707 r
F P
0 g
s
.51419 .7553 m .51929 .79252 L .51215 .80019 L p .707 .577 .707 r
F P
0 g
s
.53171 .85901 m .52909 .84041 L .51672 .83574 L p .707 .577 .707 r
F P
0 g
s
.51672 .83574 m .51934 .85435 L .53171 .85901 L p .707 .577 .707 r
F P
0 g
s
.51934 .85435 m .51672 .83574 L .51397 .82926 L p .707 .577 .707 r
F P
0 g
s
.51397 .82926 m .51659 .84787 L .51934 .85435 L p .707 .577 .707 r
F P
0 g
s
.51659 .84787 m .51397 .82926 L .5211 .82161 L p .707 .577 .707 r
F P
0 g
s
.5211 .82161 m .52372 .84022 L .51659 .84787 L p .707 .577 .707 r
F P
0 g
s
.52509 .65929 m .52971 .71516 L .51336 .72294 L p .707 .577 .707 r
F P
0 g
s
.51929 .79252 m .51419 .7553 L .53051 .74724 L p .707 .577 .707 r
F P
0 g
s
.52971 .71516 m .52509 .65929 L .54831 .65265 L p .707 .577 .707 r
F P
0 g
s
.58053 .34202 m .53348 .59432 L p .5495 .65731 L .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .55177 .68476 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .5495 .65731 L p .56218 .68396 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .56218 .68396 L .56292 .68551 L .707 .577 .707 r
F
.53742 .81353 m .54004 .83214 L .52372 .84022 L p F P
0 g
s
.55442 .73958 m .55952 .7768 L .53561 .78446 L p .707 .577 .707 r
F P
0 g
s
.58302 .70303 m .58132 .68251 L p .61013 .644 L .707 .577 .707 r
F P
0 g
s
.62482 .34807 m .56218 .68396 L p .58132 .68251 L .707 .577 .707 r
F P
0 g
s
.59294 .66196 m .62482 .34807 L .58132 .68251 L .707 .577 .707 r
F
.60267 .64474 m .61013 .644 L p .58132 .68251 L F P
0 g
s
.61476 .69987 m .61013 .644 L .6412 .64327 L p .707 .577 .707 r
F P
0 g
s
.61013 .644 m .61476 .69987 L .58736 .7026 L p .707 .577 .707 r
F P
0 g
s
.58736 .7026 m .58302 .70303 L p .59982 .66647 L .707 .577 .707 r
F P
0 g
s
.59982 .66647 m .61013 .644 L .58736 .7026 L .707 .577 .707 r
F
.6412 .64327 m .64582 .69914 L .61476 .69987 L p F P
0 g
s
.62025 .76556 m .61515 .72834 L .64602 .72586 L p .707 .577 .707 r
F P
0 g
s
.58869 .77029 m .58359 .73306 L .61515 .72834 L p .707 .577 .707 r
F P
0 g
s
.61515 .72834 m .62025 .76556 L .58869 .77029 L p .707 .577 .707 r
F P
0 g
s
.56395 .82442 m .56133 .80582 L .59049 .79922 L p .707 .577 .707 r
F P
0 g
s
.59049 .79922 m .5931 .81783 L .56395 .82442 L p .707 .577 .707 r
F P
0 g
s
.5931 .81783 m .59049 .79922 L .62203 .79439 L p .707 .577 .707 r
F P
0 g
s
.62203 .79439 m .62465 .81299 L .5931 .81783 L p .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .60925 .82806 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.66578 .34898 m .61454 .62375 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.58359 .73306 m .58869 .77029 L .55952 .7768 L p .707 .577 .707 r
F P
0 g
s
.61454 .62375 m .57563 .83239 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .66578 .34898 L .62482 .34807 L p .707 .577 .707 r
F P
0 g
s
.58132 .68251 m .5784 .64716 L .60267 .64474 L p .707 .577 .707 r
F P
0 g
s
.59093 .68177 m .59294 .66196 L .58132 .68251 L .707 .577 .707 r
F
.5784 .64716 m .58302 .70303 L .57218 .70498 L p F P
0 g
s
.57218 .70498 m .55372 .7083 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56292 .68551 m .5784 .64716 L .57218 .70498 L .707 .577 .707 r
F
.62482 .34807 m .58053 .34202 L p .55074 .65993 L F P
0 g
s
.52372 .84022 m .5211 .82161 L .53742 .81353 L p .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .52971 .71516 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.54909 .65242 m .5495 .65731 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.5495 .65731 m .55372 .7083 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .56218 .68396 L .55074 .65993 L .707 .577 .707 r
F
.53561 .78446 m .53051 .74724 L .55442 .73958 L p F P
0 g
s
.54004 .83214 m .53742 .81353 L .56133 .80582 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .55968 .69736 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.55968 .69736 m .56218 .68396 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .62482 .34807 L p .55074 .65993 L .707 .577 .707 r
F P
0 g
s
.56133 .80582 m .56395 .82442 L .54004 .83214 L p .707 .577 .707 r
F P
0 g
s
.55952 .7768 m .55442 .73958 L .58359 .73306 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .57563 .83239 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55074 .65993 m .58053 .34202 L .5495 .65731 L .707 .577 .707 r
F
.54909 .65242 m .5784 .64716 L p .56292 .68551 L F P
0 g
s
.5495 .65731 m .54909 .65242 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .53467 .83149 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .55074 .65993 L .5495 .65731 L .707 .577 .707 r
F
.54831 .65265 m .54909 .65242 L p .54863 .65391 L F P
0 g
s
.52971 .71516 m .54831 .65265 L .54863 .65391 L .707 .577 .707 r
F
.53051 .74724 m .53561 .78446 L .51929 .79252 L p F P
0 g
s
.49038 .82544 m .53467 .83149 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.53348 .59432 m .49038 .82544 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.44709 .81483 m .53725 .33141 L .49921 .31729 L p .707 .577 .707 r
F P
0 g
s
.53725 .33141 m .44709 .81483 L .49038 .82544 L p .707 .577 .707 r
F P
0 g
s
.70197 .74734 m .70707 .78456 L .7142 .77689 L p .707 .577 .707 r
F P
0 g
s
.7142 .77689 m .7091 .73967 L .70197 .74734 L p .707 .577 .707 r
F P
0 g
s
.70486 .66242 m .70949 .71829 L .70664 .71096 L p .707 .577 .707 r
F P
0 g
s
.70664 .71096 m .70202 .65509 L .70486 .66242 L p .707 .577 .707 r
F P
0 g
s
.70878 .81288 m .7114 .83149 L .71854 .82384 L p .707 .577 .707 r
F P
0 g
s
.71854 .82384 m .71592 .80523 L .70878 .81288 L p .707 .577 .707 r
F P
0 g
s
.64582 .69914 m .6412 .64327 L .66855 .64502 L p .707 .577 .707 r
F P
0 g
s
.64602 .72586 m .65113 .76309 L .62025 .76556 L p .707 .577 .707 r
F P
0 g
s
.60925 .82806 m .69941 .34464 L .66578 .34898 L p .707 .577 .707 r
F P
0 g
s
.40906 .8007 m .49921 .31729 L .47014 .30102 L p .707 .577 .707 r
F P
0 g
s
.49921 .31729 m .40906 .8007 L .44709 .81483 L p .707 .577 .707 r
F P
0 g
s
.7091 .73967 m .7142 .77689 L .71144 .77036 L p .707 .577 .707 r
F P
0 g
s
.71144 .77036 m .70634 .73314 L .7091 .73967 L p .707 .577 .707 r
F P
0 g
s
.70202 .65509 m .70664 .71096 L .69413 .70497 L p .707 .577 .707 r
F P
0 g
s
.69413 .70497 m .6895 .6491 L .70202 .65509 L p .707 .577 .707 r
F P
0 g
s
.66855 .64502 m .67317 .70089 L .64582 .69914 L p .707 .577 .707 r
F P
0 g
s
.65289 .79179 m .65551 .8104 L .62465 .81299 L p .707 .577 .707 r
F P
0 g
s
.62465 .81299 m .62203 .79439 L .65289 .79179 L p .707 .577 .707 r
F P
0 g
s
.69941 .34464 m .60925 .82806 L .63225 .81891 L p .707 .577 .707 r
F P
0 g
s
.65113 .76309 m .64602 .72586 L .67318 .72588 L p .707 .577 .707 r
F P
0 g
s
.63225 .81891 m .7224 .3355 L .69941 .34464 L p .707 .577 .707 r
F P
0 g
s
.71592 .80523 m .71854 .82384 L .71578 .81736 L p .707 .577 .707 r
F P
0 g
s
.71578 .81736 m .71317 .79875 L .71592 .80523 L p .707 .577 .707 r
F P
0 g
s
.37998 .78444 m .47014 .30102 L .45288 .28422 L p .707 .577 .707 r
F P
0 g
s
.47014 .30102 m .37998 .78444 L .40906 .8007 L p .707 .577 .707 r
F P
0 g
s
.25798 .70845 m .25336 .65258 L .2223 .65332 L p .707 .577 .707 r
F P
0 g
s
.25336 .65258 m .25798 .70845 L .28972 .7053 L p .707 .577 .707 r
F P
0 g
s
.28972 .7053 m .2851 .64943 L .25336 .65258 L p .707 .577 .707 r
F P
0 g
s
.2851 .64943 m .28972 .7053 L .31902 .70003 L p .707 .577 .707 r
F P
0 g
s
.31902 .70003 m .3144 .64416 L .2851 .64943 L p .707 .577 .707 r
F P
0 g
s
.22692 .70919 m .2223 .65332 L .19495 .65156 L p .707 .577 .707 r
F P
0 g
s
.2223 .65332 m .22692 .70919 L .25798 .70845 L p .707 .577 .707 r
F P
0 g
s
.70634 .73314 m .71144 .77036 L .69907 .76561 L p .707 .577 .707 r
F P
0 g
s
.69907 .76561 m .69397 .72839 L .70634 .73314 L p .707 .577 .707 r
F P
0 g
s
.3144 .64416 m .31902 .70003 L .34303 .69317 L p .707 .577 .707 r
F P
0 g
s
.34303 .69317 m .3384 .6373 L .3144 .64416 L p .707 .577 .707 r
F P
0 g
s
.2631 .76445 m .258 .72723 L .22712 .72971 L p .707 .577 .707 r
F P
0 g
s
.258 .72723 m .2631 .76445 L .29466 .75973 L p .707 .577 .707 r
F P
0 g
s
.29466 .75973 m .28956 .72251 L .258 .72723 L p .707 .577 .707 r
F P
0 g
s
.6895 .6491 m .69413 .70497 L .67317 .70089 L p .707 .577 .707 r
F P
0 g
s
.67317 .70089 m .66855 .64502 L .6895 .6491 L p .707 .577 .707 r
F P
0 g
s
.28956 .72251 m .29466 .75973 L .32383 .75322 L p .707 .577 .707 r
F P
0 g
s
.32383 .75322 m .31873 .716 L .28956 .72251 L p .707 .577 .707 r
F P
0 g
s
.19495 .65156 m .19957 .70743 L .22692 .70919 L p .707 .577 .707 r
F P
0 g
s
.19957 .70743 m .19495 .65156 L .17399 .64749 L p .707 .577 .707 r
F P
0 g
s
.71317 .79875 m .71578 .81736 L .70342 .81269 L p .707 .577 .707 r
F P
0 g
s
.70342 .81269 m .7008 .79409 L .71317 .79875 L p .707 .577 .707 r
F P
0 g
s
.23222 .76693 m .22712 .72971 L .19997 .72969 L p .707 .577 .707 r
F P
0 g
s
.22712 .72971 m .23222 .76693 L .2631 .76445 L p .707 .577 .707 r
F P
0 g
s
.26746 .80181 m .26484 .7832 L .23399 .7858 L p .707 .577 .707 r
F P
0 g
s
.26484 .7832 m .26746 .80181 L .29901 .79698 L p .707 .577 .707 r
F P
0 g
s
.29901 .79698 m .29639 .77837 L .26484 .7832 L p .707 .577 .707 r
F P
0 g
s
.31873 .716 m .32383 .75322 L .34774 .74556 L p .707 .577 .707 r
F P
0 g
s
.34774 .74556 m .34264 .70833 L .31873 .716 L p .707 .577 .707 r
F P
0 g
s
.7224 .3355 m .63225 .81891 L .64236 .80585 L p .707 .577 .707 r
F P
0 g
s
.64236 .80585 m .70862 .45058 L p .7224 .3355 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .71914 .39414 L p .7203 .37334 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .7203 .37334 L .7224 .3355 L .707 .577 .707 r
F
.68528 .72194 m .68018 .68472 L .67333 .68389 L p F P
0 g
s
.64236 .80585 m .63861 .79015 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67714 .61456 L .64236 .80585 L .707 .577 .707 r
F
.71914 .39414 m .64236 .80585 L p .7085 .44207 L F P
0 g
s
.71914 .39414 m .73252 .32243 L .7299 .32582 L p .707 .577 .707 r
F P
0 g
s
.7299 .32582 m .7224 .3355 L p .71914 .39414 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .73252 .32243 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .66428 .65248 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .62135 .77334 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .65713 .63165 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.64984 .64959 m .65713 .63165 L .63861 .79015 L .707 .577 .707 r
F
.67752 .58151 m .66688 .63854 L p .65713 .63165 L F P
0 g
s
.66688 .63854 m .63861 .79015 L p .65713 .63165 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .64169 .59031 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .6542 .59631 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .66306 .61706 L .66169 .65274 L .707 .577 .707 r
F
.66306 .61706 m .6542 .59631 L .65846 .62838 L F
.66306 .61706 m .65846 .62838 L .66169 .65274 L F
.6734 .60004 m .67023 .59942 L p .66737 .62717 L F P
0 g
s
.67023 .59942 m .6542 .59631 L p .66306 .61706 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .67023 .59942 L .66306 .61706 L .707 .577 .707 r
F
.64984 .64959 m .65337 .629 L .65441 .62973 L F
.64169 .59031 m .64209 .5952 L p .65217 .62816 L F P
0 g
s
.63815 .57735 m .64209 .5952 L .62135 .77334 L .707 .577 .707 r
F
.64886 .62582 m .64636 .63922 L p .64209 .5952 L F P
0 g
s
.64636 .63922 m .62135 .77334 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64812 .65381 m .7115 .28992 L .64984 .64959 L .707 .577 .707 r
F
.63984 .67417 m .64636 .63922 L p .64812 .65381 L F P
0 g
s
.65217 .62816 m .64209 .5952 L .64886 .62582 L .707 .577 .707 r
F
.64636 .63922 m .7115 .28992 L p .64812 .65381 L F P
0 g
s
.64631 .64618 m .64436 .62264 L p .63884 .58298 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64209 .5952 L p .6402 .58807 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .6402 .58807 L .63884 .58298 L .707 .577 .707 r
F
.64209 .5952 m .64169 .59031 L .6416 .59007 L p F P
0 g
s
.7115 .28992 m .64886 .62582 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.6416 .59007 m .63884 .58298 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64209 .5952 m .64436 .62264 L p .64886 .62582 L .707 .577 .707 r
F P
0 g
s
.62135 .77334 m .59228 .75708 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .67752 .58151 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.64631 .64618 m .65883 .65218 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64631 .64618 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.7115 .28992 m .72876 .30673 L p .65441 .62973 L .707 .577 .707 r
F P
0 g
s
.65337 .629 m .7115 .28992 L .65441 .62973 L .707 .577 .707 r
F
.62135 .77334 m .63984 .67417 L p .64984 .64959 L F P
0 g
s
.65883 .65218 m .65713 .63165 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65883 .65218 m .66169 .65274 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .65883 .65218 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .66449 .71944 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64702 .67746 m .64955 .69594 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64955 .69594 m .65212 .71468 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67752 .58151 L .7085 .44207 L .707 .577 .707 r
F
.66428 .65248 m .67752 .58151 L p .6691 .63825 L F P
0 g
s
.67752 .58151 m .72876 .30673 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .7085 .44207 L .67714 .61456 L .707 .577 .707 r
F
.66169 .65274 m .67978 .65625 L p .66737 .62717 L F P
0 g
s
.66449 .71944 m .65939 .68221 L .6548 .68045 L p .707 .577 .707 r
F P
0 g
s
.6548 .68045 m .64702 .67746 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.66449 .71944 m .6548 .68045 L .65186 .6891 L .707 .577 .707 r
F
.73252 .32243 m .71914 .39414 L p .7085 .44207 L F P
0 g
s
.67516 .60038 m .6734 .60004 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.6784 .65302 m .6734 .60004 L .66737 .62717 L .707 .577 .707 r
F
.67333 .68389 m .65939 .68221 L p .67091 .69989 L F P
0 g
s
.68528 .72194 m .67333 .68389 L .67091 .69989 L .707 .577 .707 r
F
.67978 .65625 m .67913 .64838 L p .6784 .65302 L F P
0 g
s
.67913 .64838 m .67516 .60038 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.29639 .77837 m .29901 .79698 L .32817 .79038 L p .707 .577 .707 r
F P
0 g
s
.32817 .79038 m .32555 .77177 L .29639 .77837 L p .707 .577 .707 r
F P
0 g
s
.3384 .6373 m .34303 .69317 L .35938 .68538 L p .707 .577 .707 r
F P
0 g
s
.35938 .68538 m .35475 .62951 L .3384 .6373 L p .707 .577 .707 r
F P
0 g
s
.36839 .77459 m .36577 .75598 L .34946 .76406 L p .707 .577 .707 r
F P
0 g
s
.35896 .70027 m .36406 .7375 L .37119 .72982 L p .707 .577 .707 r
F P
0 g
s
.37119 .72982 m .36609 .6926 L .35896 .70027 L p .707 .577 .707 r
F P
0 g
s
.36609 .6926 m .37119 .72982 L .36844 .72329 L p .707 .577 .707 r
F P
0 g
s
.36577 .75598 m .36839 .77459 L .37553 .76693 L p .707 .577 .707 r
F P
0 g
s
.37553 .76693 m .37291 .74833 L .36577 .75598 L p .707 .577 .707 r
F P
0 g
s
.37016 .74185 m .37278 .76046 L .36041 .75579 L p .707 .577 .707 r
F P
0 g
s
.34264 .70833 m .34774 .74556 L .36406 .7375 L p .707 .577 .707 r
F P
0 g
s
.36041 .75579 m .35779 .73718 L .37016 .74185 L p .707 .577 .707 r
F P
0 g
s
.36273 .76764 m .45288 .28422 L .44913 .26852 L p .707 .577 .707 r
F P
0 g
s
.37291 .74833 m .37553 .76693 L .37278 .76046 L p .707 .577 .707 r
F P
0 g
s
.37278 .76046 m .37016 .74185 L .37291 .74833 L p .707 .577 .707 r
F P
0 g
s
.45288 .28422 m .36273 .76764 L .37998 .78444 L p .707 .577 .707 r
F P
0 g
s
.19997 .72969 m .20507 .76691 L .23222 .76693 L p .707 .577 .707 r
F P
0 g
s
.23399 .7858 m .23661 .80441 L .26746 .80181 L p .707 .577 .707 r
F P
0 g
s
.17399 .64749 m .17861 .70336 L .19957 .70743 L p .707 .577 .707 r
F P
0 g
s
.69397 .72839 m .69907 .76561 L .67828 .7631 L p .707 .577 .707 r
F P
0 g
s
.67828 .7631 m .67318 .72588 L .69397 .72839 L p .707 .577 .707 r
F P
0 g
s
.23661 .80441 m .23399 .7858 L .20685 .7859 L p .707 .577 .707 r
F P
0 g
s
.20507 .76691 m .19997 .72969 L .17918 .72718 L p .707 .577 .707 r
F P
0 g
s
.20685 .7859 m .20947 .80451 L .23661 .80441 L p .707 .577 .707 r
F P
0 g
s
.32555 .77177 m .32817 .79038 L .35207 .78267 L p .707 .577 .707 r
F P
0 g
s
.35207 .78267 m .34946 .76406 L .32555 .77177 L p .707 .577 .707 r
F P
0 g
s
.17861 .70336 m .17399 .64749 L .16148 .64149 L p .707 .577 .707 r
F P
0 g
s
.36406 .7375 m .35896 .70027 L .34264 .70833 L p .707 .577 .707 r
F P
0 g
s
.17918 .72718 m .18428 .76441 L .20507 .76691 L p .707 .577 .707 r
F P
0 g
s
.7008 .79409 m .70342 .81269 L .68265 .8103 L p .707 .577 .707 r
F P
0 g
s
.68265 .8103 m .68003 .79169 L .7008 .79409 L p .707 .577 .707 r
F P
0 g
s
.20947 .80451 m .20685 .7859 L .18608 .7835 L p .707 .577 .707 r
F P
0 g
s
.35475 .62951 m .35938 .68538 L .36648 .67744 L p .707 .577 .707 r
F P
0 g
s
.36648 .67744 m .36185 .62156 L .35475 .62951 L p .707 .577 .707 r
F P
0 g
s
.18608 .7835 m .1887 .80211 L .20947 .80451 L p .707 .577 .707 r
F P
0 g
s
.16148 .64149 m .1661 .69736 L .17861 .70336 L p .707 .577 .707 r
F P
0 g
s
.67318 .72588 m .67828 .7631 L .65113 .76309 L p .707 .577 .707 r
F P
0 g
s
.34946 .76406 m .35207 .78267 L .36839 .77459 L p .707 .577 .707 r
F P
0 g
s
.18428 .76441 m .17918 .72718 L .1668 .72243 L p .707 .577 .707 r
F P
0 g
s
.1668 .72243 m .1719 .75966 L .18428 .76441 L p .707 .577 .707 r
F P
0 g
s
.1661 .69736 m .16148 .64149 L .15863 .63416 L p .707 .577 .707 r
F P
0 g
s
.36844 .72329 m .36334 .68607 L .36609 .6926 L p .707 .577 .707 r
F P
0 g
s
.36334 .68607 m .36844 .72329 L .35606 .71854 L p .707 .577 .707 r
F P
0 g
s
.35779 .73718 m .36041 .75579 L .33964 .75339 L p .707 .577 .707 r
F P
0 g
s
.44913 .26852 m .35897 .75194 L .36273 .76764 L p .707 .577 .707 r
F P
0 g
s
.35897 .75194 m .44913 .26852 L .45924 .25545 L p .707 .577 .707 r
F P
0 g
s
.68003 .79169 m .68265 .8103 L .65551 .8104 L p .707 .577 .707 r
F P
0 g
s
.65551 .8104 m .65289 .79179 L .68003 .79169 L p .707 .577 .707 r
F P
0 g
s
.1887 .80211 m .18608 .7835 L .17371 .77884 L p .707 .577 .707 r
F P
0 g
s
.17371 .77884 m .17633 .79745 L .1887 .80211 L p .707 .577 .707 r
F P
0 g
s
.15863 .63416 m .16325 .69003 L .1661 .69736 L p .707 .577 .707 r
F P
0 g
s
.36185 .62156 m .36648 .67744 L .36363 .67011 L p .707 .577 .707 r
F P
0 g
s
.36363 .67011 m .35901 .61423 L .36185 .62156 L p .707 .577 .707 r
F P
0 g
s
.1719 .75966 m .1668 .72243 L .16405 .7159 L p .707 .577 .707 r
F P
0 g
s
.16405 .7159 m .16915 .75312 L .1719 .75966 L p .707 .577 .707 r
F P
0 g
s
.16325 .69003 m .15863 .63416 L .16573 .62621 L p .707 .577 .707 r
F P
0 g
s
.17633 .79745 m .17371 .77884 L .17096 .77236 L p .707 .577 .707 r
F P
0 g
s
.17096 .77236 m .17358 .79097 L .17633 .79745 L p .707 .577 .707 r
F P
0 g
s
.36908 .73887 m .45924 .25545 L .48223 .24631 L p .707 .577 .707 r
F P
0 g
s
.45924 .25545 m .36908 .73887 L .35897 .75194 L p .707 .577 .707 r
F P
0 g
s
.16573 .62621 m .17035 .68208 L .16325 .69003 L p .707 .577 .707 r
F P
0 g
s
.35901 .61423 m .36363 .67011 L .35112 .66411 L p .707 .577 .707 r
F P
0 g
s
.35112 .66411 m .34649 .60824 L .35901 .61423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16915 .75312 m .16405 .7159 L .17118 .70823 L p .707 .577 .707 r
F P
0 g
s
.17118 .70823 m .17628 .74545 L .16915 .75312 L p .707 .577 .707 r
F P
0 g
s
.17035 .68208 m .16573 .62621 L .18208 .61843 L p .707 .577 .707 r
F P
0 g
s
.35606 .71854 m .35096 .68132 L .36334 .68607 L p .707 .577 .707 r
F P
0 g
s
.17358 .79097 m .17096 .77236 L .17809 .76471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17809 .76471 m .18071 .78332 L .17358 .79097 L p .707 .577 .707 r
F P
0 g
s
.34649 .60824 m .35112 .66411 L .33016 .66003 L p .707 .577 .707 r
F P
0 g
s
.33016 .66003 m .32554 .60416 L .34649 .60824 L p .707 .577 .707 r
F P
0 g
s
.18208 .61843 m .1867 .6743 L .17035 .68208 L p .707 .577 .707 r
F P
0 g
s
.59228 .75708 m .68243 .27366 L .7115 .28992 L p .707 .577 .707 r
F P
0 g
s
.48223 .24631 m .39208 .72973 L .36908 .73887 L p .707 .577 .707 r
F P
0 g
s
.39208 .72973 m .48223 .24631 L .51586 .24197 L p .707 .577 .707 r
F P
0 g
s
.17628 .74545 m .17118 .70823 L .1875 .70017 L p .707 .577 .707 r
F P
0 g
s
.1867 .6743 m .18208 .61843 L .20608 .61157 L p .707 .577 .707 r
F P
0 g
s
.1875 .70017 m .1926 .73739 L .17628 .74545 L p .707 .577 .707 r
F P
0 g
s
.35096 .68132 m .35606 .71854 L .33527 .71604 L p .707 .577 .707 r
F P
0 g
s
.33527 .71604 m .33017 .67881 L .35096 .68132 L p .707 .577 .707 r
F P
0 g
s
.18071 .78332 m .17809 .76471 L .19441 .75663 L p .707 .577 .707 r
F P
0 g
s
.32554 .60416 m .33016 .66003 L .30281 .65828 L p .707 .577 .707 r
F P
0 g
s
.30281 .65828 m .29819 .60241 L .32554 .60416 L p .707 .577 .707 r
F P
0 g
s
.19441 .75663 m .19703 .77524 L .18071 .78332 L p .707 .577 .707 r
F P
0 g
s
.20608 .61157 m .21071 .66744 L .1867 .6743 L p .707 .577 .707 r
F P
0 g
s
.33964 .75339 m .33702 .73479 L .35779 .73718 L p .707 .577 .707 r
F P
0 g
s
.21071 .66744 m .20608 .61157 L .23539 .6063 L p .707 .577 .707 r
F P
0 g
s
.1926 .73739 m .1875 .70017 L .21141 .69251 L p .707 .577 .707 r
F P
0 g
s
.68243 .27366 m .59228 .75708 L .55424 .74296 L p .707 .577 .707 r
F P
0 g
s
.55424 .74296 m .64439 .25954 L .68243 .27366 L p .707 .577 .707 r
F P
0 g
s
.4257 .72539 m .51586 .24197 L .55682 .24288 L p .707 .577 .707 r
F P
0 g
s
.51586 .24197 m .4257 .72539 L .39208 .72973 L p .707 .577 .707 r
F P
0 g
s
.29819 .60241 m .30281 .65828 L .27175 .65901 L p .707 .577 .707 r
F P
0 g
s
.27175 .65901 m .26713 .60314 L .29819 .60241 L p .707 .577 .707 r
F P
0 g
s
.33017 .67881 m .33527 .71604 L .30812 .71602 L p .707 .577 .707 r
F P
0 g
s
.30812 .71602 m .30302 .6788 L .33017 .67881 L p .707 .577 .707 r
F P
0 g
s
.21141 .69251 m .21651 .72973 L .1926 .73739 L p .707 .577 .707 r
F P
0 g
s
.24001 .66217 m .23539 .6063 L .26713 .60314 L p .707 .577 .707 r
F P
0 g
s
.23539 .6063 m .24001 .66217 L .21071 .66744 L p .707 .577 .707 r
F P
0 g
s
.19703 .77524 m .19441 .75663 L .21832 .74891 L p .707 .577 .707 r
F P
0 g
s
.26713 .60314 m .27175 .65901 L .24001 .66217 L p .707 .577 .707 r
F P
0 g
s
.7382 .65727 m .73357 .6014 L .70251 .60214 L p .707 .577 .707 r
F P
0 g
s
.73357 .6014 m .7382 .65727 L .76993 .65412 L p .707 .577 .707 r
F P
0 g
s
.76993 .65412 m .76531 .59825 L .73357 .6014 L p .707 .577 .707 r
F P
0 g
s
.21832 .74891 m .22094 .76752 L .19703 .77524 L p .707 .577 .707 r
F P
0 g
s
.76531 .59825 m .76993 .65412 L .79924 .64885 L p .707 .577 .707 r
F P
0 g
s
.79924 .64885 m .79461 .59298 L .76531 .59825 L p .707 .577 .707 r
F P
0 g
s
.21651 .72973 m .21141 .69251 L .24058 .686 L p .707 .577 .707 r
F P
0 g
s
.64439 .25954 m .55424 .74296 L .51095 .73235 L p .707 .577 .707 r
F P
0 g
s
.51095 .73235 m .60111 .24893 L .64439 .25954 L p .707 .577 .707 r
F P
0 g
s
.33702 .73479 m .33964 .75339 L .3125 .7535 L p .707 .577 .707 r
F P
0 g
s
.3125 .7535 m .30988 .73489 L .33702 .73479 L p .707 .577 .707 r
F P
0 g
s
.46666 .7263 m .55682 .24288 L .60111 .24893 L p .707 .577 .707 r
F P
0 g
s
.55682 .24288 m .46666 .7263 L .4257 .72539 L p .707 .577 .707 r
F P
0 g
s
.70713 .65801 m .70251 .60214 L .67516 .60038 L p .707 .577 .707 r
F P
0 g
s
.70251 .60214 m .70713 .65801 L .7382 .65727 L p .707 .577 .707 r
F P
0 g
s
.30302 .6788 m .30812 .71602 L .27724 .7185 L p .707 .577 .707 r
F P
0 g
s
.27724 .7185 m .27214 .68127 L .30302 .6788 L p .707 .577 .707 r
F P
0 g
s
.60111 .24893 m .51095 .73235 L .46666 .7263 L p .707 .577 .707 r
F P
0 g
s
.24058 .686 m .24568 .72322 L .21651 .72973 L p .707 .577 .707 r
F P
0 g
s
.79461 .59298 m .79924 .64885 L .82324 .64199 L p .707 .577 .707 r
F P
0 g
s
.82324 .64199 m .81862 .58612 L .79461 .59298 L p .707 .577 .707 r
F P
0 g
s
.24568 .72322 m .24058 .686 L .27214 .68127 L p .707 .577 .707 r
F P
0 g
s
.22094 .76752 m .21832 .74891 L .24748 .74232 L p .707 .577 .707 r
F P
0 g
s
.27214 .68127 m .27724 .7185 L .24568 .72322 L p .707 .577 .707 r
F P
0 g
s
.74331 .71948 m .73821 .68226 L .70734 .68474 L p .707 .577 .707 r
F P
0 g
s
.73821 .68226 m .74331 .71948 L .77487 .71476 L p .707 .577 .707 r
F P
0 g
s
.77487 .71476 m .76977 .67754 L .73821 .68226 L p .707 .577 .707 r
F P
0 g
s
.67516 .60038 m .67978 .65625 L .70713 .65801 L p .707 .577 .707 r
F P
0 g
s
.24748 .74232 m .25009 .76092 L .22094 .76752 L p .707 .577 .707 r
F P
0 g
s
.76977 .67754 m .77487 .71476 L .80404 .70825 L p .707 .577 .707 r
F P
0 g
s
.80404 .70825 m .79894 .67102 L .76977 .67754 L p .707 .577 .707 r
F P
0 g
s
.30988 .73489 m .3125 .7535 L .28164 .75609 L p .707 .577 .707 r
F P
0 g
s
.28164 .75609 m .27903 .73748 L .30988 .73489 L p .707 .577 .707 r
F P
0 g
s
.71244 .72196 m .70734 .68474 L .68018 .68472 L p .707 .577 .707 r
F P
0 g
s
.70734 .68474 m .71244 .72196 L .74331 .71948 L p .707 .577 .707 r
F P
0 g
s
.25009 .76092 m .24748 .74232 L .27903 .73748 L p .707 .577 .707 r
F P
0 g
s
.27903 .73748 m .28164 .75609 L .25009 .76092 L p .707 .577 .707 r
F P
0 g
s
.79894 .67102 m .80404 .70825 L .82796 .70059 L p .707 .577 .707 r
F P
0 g
s
.82796 .70059 m .82285 .66336 L .79894 .67102 L p .707 .577 .707 r
F P
0 g
s
.81862 .58612 m .82324 .64199 L .83959 .6342 L p .707 .577 .707 r
F P
0 g
s
.83959 .6342 m .83497 .57833 L .81862 .58612 L p .707 .577 .707 r
F P
0 g
s
.74768 .76668 m .74506 .74807 L .7142 .75066 L p .707 .577 .707 r
F P
0 g
s
.74506 .74807 m .74768 .76668 L .77923 .76184 L p .707 .577 .707 r
F P
0 g
s
.77923 .76184 m .77661 .74324 L .74506 .74807 L p .707 .577 .707 r
F P
0 g
s
.68018 .68472 m .68528 .72194 L .71244 .72196 L p .707 .577 .707 r
F P
0 g
s
.77661 .74324 m .77923 .76184 L .80838 .75525 L p .707 .577 .707 r
F P
0 g
s
.80838 .75525 m .80576 .73664 L .77661 .74324 L p .707 .577 .707 r
F P
0 g
s
.7142 .75066 m .71682 .76927 L .74768 .76668 L p .707 .577 .707 r
F P
0 g
s
.71682 .76927 m .7142 .75066 L .68706 .75077 L p .707 .577 .707 r
F P
0 g
s
.68706 .75077 m .68968 .76937 L .71682 .76927 L p .707 .577 .707 r
F P
0 g
s
.80576 .73664 m .80838 .75525 L .83229 .74753 L p .707 .577 .707 r
F P
0 g
s
.83229 .74753 m .82967 .72892 L .80576 .73664 L p .707 .577 .707 r
F P
0 g
s
.82285 .66336 m .82796 .70059 L .84428 .69252 L p .707 .577 .707 r
F P
0 g
s
.84428 .69252 m .83918 .6553 L .82285 .66336 L p .707 .577 .707 r
F P
0 g
s
.65939 .68221 m .66449 .71944 L .68528 .72194 L p .707 .577 .707 r
F P
0 g
s
.83497 .57833 m .83959 .6342 L .84669 .62626 L p .707 .577 .707 r
F P
0 g
s
.84669 .62626 m .84207 .57039 L .83497 .57833 L p .707 .577 .707 r
F P
0 g
s
.68968 .76937 m .68706 .75077 L .66629 .74837 L p .707 .577 .707 r
F P
0 g
s
.66629 .74837 m .66891 .76698 L .68968 .76937 L p .707 .577 .707 r
F P
0 g
s
.82967 .72892 m .83229 .74753 L .84861 .73945 L p .707 .577 .707 r
F P
0 g
s
.84861 .73945 m .84599 .72084 L .82967 .72892 L p .707 .577 .707 r
F P
0 g
s
.83918 .6553 m .84428 .69252 L .85141 .68485 L p .707 .577 .707 r
F P
0 g
s
.85141 .68485 m .84631 .64763 L .83918 .6553 L p .707 .577 .707 r
F P
0 g
s
.66891 .76698 m .66629 .74837 L .65393 .7437 L p .707 .577 .707 r
F P
0 g
s
.65393 .7437 m .65654 .76231 L .66891 .76698 L p .707 .577 .707 r
F P
0 g
s
.63884 .58298 m .64347 .63885 L .64631 .64618 L p .707 .577 .707 r
F P
0 g
s
.84207 .57039 m .84669 .62626 L .84385 .61893 L p .707 .577 .707 r
F P
0 g
s
.84385 .61893 m .83922 .56305 L .84207 .57039 L p .707 .577 .707 r
F P
0 g
s
.84599 .72084 m .84861 .73945 L .85574 .7318 L p .707 .577 .707 r
F P
0 g
s
.85574 .7318 m .85312 .71319 L .84599 .72084 L p .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .64702 .67746 L .64426 .67093 L p .707 .577 .707 r
F P
0 g
s
.64426 .67093 m .64936 .70815 L .65212 .71468 L p .707 .577 .707 r
F P
0 g
s
.64347 .63885 m .63884 .58298 L .64594 .57503 L p .707 .577 .707 r
F P
0 g
s
.84631 .64763 m .85141 .68485 L .84865 .67832 L p .707 .577 .707 r
F P
0 g
s
.84865 .67832 m .84355 .6411 L .84631 .64763 L p .707 .577 .707 r
F P
0 g
s
.65654 .76231 m .65393 .7437 L .65117 .73723 L p .707 .577 .707 r
F P
0 g
s
.65117 .73723 m .65379 .75583 L .65654 .76231 L p .707 .577 .707 r
F P
0 g
s
.64594 .57503 m .65057 .6309 L .64347 .63885 L p .707 .577 .707 r
F P
0 g
s
.83922 .56305 m .84385 .61893 L .83133 .61293 L p .707 .577 .707 r
F P
0 g
s
.83133 .61293 m .82671 .55706 L .83922 .56305 L p .707 .577 .707 r
F P
0 g
s
.85312 .71319 m .85574 .7318 L .85299 .72532 L p .707 .577 .707 r
F P
0 g
s
.85299 .72532 m .85037 .70671 L .85312 .71319 L p .707 .577 .707 r
F P
0 g
s
.64936 .70815 m .64426 .67093 L .65139 .66326 L p .707 .577 .707 r
F P
0 g
s
.39519 .61641 m .39056 .56054 L .3595 .56128 L p .707 .577 .707 r
F P
0 g
s
.39056 .56054 m .39519 .61641 L .42692 .61326 L p .707 .577 .707 r
F P
0 g
s
.42692 .61326 m .4223 .55739 L .39056 .56054 L p .707 .577 .707 r
F P
0 g
s
.4223 .55739 m .42692 .61326 L .45623 .60799 L p .707 .577 .707 r
F P
0 g
s
.45623 .60799 m .4516 .55212 L .4223 .55739 L p .707 .577 .707 r
F P
0 g
s
.65057 .6309 m .64594 .57503 L .6623 .56725 L p .707 .577 .707 r
F P
0 g
s
.65139 .66326 m .65649 .70048 L .64936 .70815 L p .707 .577 .707 r
F P
0 g
s
.36412 .61715 m .3595 .56128 L .33215 .55952 L p .707 .577 .707 r
F P
0 g
s
.3595 .56128 m .36412 .61715 L .39519 .61641 L p .707 .577 .707 r
F P
0 g
s
.84355 .6411 m .84865 .67832 L .83627 .67357 L p .707 .577 .707 r
F P
0 g
s
.83627 .67357 m .83117 .63635 L .84355 .6411 L p .707 .577 .707 r
F P
0 g
s
.4516 .55212 m .45623 .60799 L .48023 .60113 L p .707 .577 .707 r
F P
0 g
s
.48023 .60113 m .47561 .54526 L .4516 .55212 L p .707 .577 .707 r
F P
0 g
s
.65379 .75583 m .65117 .73723 L .65831 .72957 L p .707 .577 .707 r
F P
0 g
s
.65831 .72957 m .66093 .74818 L .65379 .75583 L p .707 .577 .707 r
F P
0 g
s
.4003 .67242 m .3952 .63519 L .36433 .63767 L p .707 .577 .707 r
F P
0 g
s
.3952 .63519 m .4003 .67242 L .43186 .66769 L p .707 .577 .707 r
F P
0 g
s
.43186 .66769 m .42676 .63047 L .3952 .63519 L p .707 .577 .707 r
F P
0 g
s
.82671 .55706 m .83133 .61293 L .81037 .60885 L p .707 .577 .707 r
F P
0 g
s
.81037 .60885 m .80575 .55298 L .82671 .55706 L p .707 .577 .707 r
F P
0 g
s
.6623 .56725 m .66692 .62312 L .65057 .6309 L p .707 .577 .707 r
F P
0 g
s
.42676 .63047 m .43186 .66769 L .46103 .66118 L p .707 .577 .707 r
F P
0 g
s
.46103 .66118 m .45593 .62396 L .42676 .63047 L p .707 .577 .707 r
F P
0 g
s
.33215 .55952 m .33677 .61539 L .36412 .61715 L p .707 .577 .707 r
F P
0 g
s
.33677 .61539 m .33215 .55952 L .31119 .55545 L p .707 .577 .707 r
F P
0 g
s
.85037 .70671 m .85299 .72532 L .84062 .72066 L p .707 .577 .707 r
F P
0 g
s
.84062 .72066 m .83801 .70205 L .85037 .70671 L p .707 .577 .707 r
F P
0 g
s
.36943 .67489 m .36433 .63767 L .33717 .63765 L p .707 .577 .707 r
F P
0 g
s
.36433 .63767 m .36943 .67489 L .4003 .67242 L p .707 .577 .707 r
F P
0 g
s
.65649 .70048 m .65139 .66326 L .66771 .6552 L p .707 .577 .707 r
F P
0 g
s
.40467 .70977 m .40205 .69117 L .37119 .69376 L p .707 .577 .707 r
F P
0 g
s
.40205 .69117 m .40467 .70977 L .43622 .70494 L p .707 .577 .707 r
F P
0 g
s
.43622 .70494 m .4336 .68633 L .40205 .69117 L p .707 .577 .707 r
F P
0 g
s
.45593 .62396 m .46103 .66118 L .48495 .65352 L p .707 .577 .707 r
F P
0 g
s
.48495 .65352 m .47985 .6163 L .45593 .62396 L p .707 .577 .707 r
F P
0 g
s
.66692 .62312 m .6623 .56725 L .6863 .56039 L p .707 .577 .707 r
F P
0 g
s
.4336 .68633 m .43622 .70494 L .46537 .69834 L p .707 .577 .707 r
F P
0 g
s
.46537 .69834 m .46275 .67974 L .4336 .68633 L p .707 .577 .707 r
F P
0 g
s
.47561 .54526 m .48023 .60113 L .49658 .59334 L p .707 .577 .707 r
F P
0 g
s
.49658 .59334 m .49196 .53747 L .47561 .54526 L p .707 .577 .707 r
F P
0 g
s
.33717 .63765 m .34227 .67487 L .36943 .67489 L p .707 .577 .707 r
F P
0 g
s
.37119 .69376 m .37381 .71237 L .40467 .70977 L p .707 .577 .707 r
F P
0 g
s
.66771 .6552 m .67281 .69242 L .65649 .70048 L p .707 .577 .707 r
F P
0 g
s
.31119 .55545 m .31582 .61132 L .33677 .61539 L p .707 .577 .707 r
F P
0 g
s
.83117 .63635 m .83627 .67357 L .81549 .67106 L p .707 .577 .707 r
F P
0 g
s
.81549 .67106 m .81039 .63384 L .83117 .63635 L p .707 .577 .707 r
F P
0 g
s
.37381 .71237 m .37119 .69376 L .34405 .69386 L p .707 .577 .707 r
F P
0 g
s
.80575 .55298 m .81037 .60885 L .78303 .6071 L p .707 .577 .707 r
F P
0 g
s
.78303 .6071 m .7784 .55123 L .80575 .55298 L p .707 .577 .707 r
F P
0 g
s
.34227 .67487 m .33717 .63765 L .31638 .63515 L p .707 .577 .707 r
F P
0 g
s
.34405 .69386 m .34667 .71247 L .37381 .71237 L p .707 .577 .707 r
F P
0 g
s
.66093 .74818 m .65831 .72957 L .67463 .72149 L p .707 .577 .707 r
F P
0 g
s
.46275 .67974 m .46537 .69834 L .48928 .69063 L p .707 .577 .707 r
F P
0 g
s
.48928 .69063 m .48666 .67202 L .46275 .67974 L p .707 .577 .707 r
F P
0 g
s
.6863 .56039 m .69092 .61626 L .66692 .62312 L p .707 .577 .707 r
F P
0 g
s
.31582 .61132 m .31119 .55545 L .29868 .54945 L p .707 .577 .707 r
F P
0 g
s
.67463 .72149 m .67725 .7401 L .66093 .74818 L p .707 .577 .707 r
F P
0 g
s
.47985 .6163 m .48495 .65352 L .50127 .64546 L p .707 .577 .707 r
F P
0 g
s
.50127 .64546 m .49617 .60824 L .47985 .6163 L p .707 .577 .707 r
F P
0 g
s
.31638 .63515 m .32148 .67237 L .34227 .67487 L p .707 .577 .707 r
F P
0 g
s
.69092 .61626 m .6863 .56039 L .7156 .55512 L p .707 .577 .707 r
F P
0 g
s
.83801 .70205 m .84062 .72066 L .81985 .71826 L p .707 .577 .707 r
F P
0 g
s
.81985 .71826 m .81724 .69965 L .83801 .70205 L p .707 .577 .707 r
F P
0 g
s
.67281 .69242 m .66771 .6552 L .69163 .64754 L p .707 .577 .707 r
F P
0 g
s
.34667 .71247 m .34405 .69386 L .32328 .69146 L p .707 .577 .707 r
F P
0 g
s
.7784 .55123 m .78303 .6071 L .75196 .60783 L p .707 .577 .707 r
F P
0 g
s
.75196 .60783 m .74734 .55196 L .7784 .55123 L p .707 .577 .707 r
F P
0 g
s
.49196 .53747 m .49658 .59334 L .50368 .5854 L p .707 .577 .707 r
F P
0 g
s
.50368 .5854 m .49906 .52953 L .49196 .53747 L p .707 .577 .707 r
F P
0 g
s
.32328 .69146 m .3259 .71007 L .34667 .71247 L p .707 .577 .707 r
F P
0 g
s
.29868 .54945 m .3033 .60532 L .31582 .61132 L p .707 .577 .707 r
F P
0 g
s
.81039 .63384 m .81549 .67106 L .78833 .67105 L p .707 .577 .707 r
F P
0 g
s
.78833 .67105 m .78323 .63383 L .81039 .63384 L p .707 .577 .707 r
F P
0 g
s
.69163 .64754 m .69673 .68476 L .67281 .69242 L p .707 .577 .707 r
F P
0 g
s
.48666 .67202 m .48928 .69063 L .5056 .68255 L p .707 .577 .707 r
F P
0 g
s
.5056 .68255 m .50298 .66394 L .48666 .67202 L p .707 .577 .707 r
F P
0 g
s
.72023 .61099 m .7156 .55512 L .74734 .55196 L p .707 .577 .707 r
F P
0 g
s
.7156 .55512 m .72023 .61099 L .69092 .61626 L p .707 .577 .707 r
F P
0 g
s
.74734 .55196 m .75196 .60783 L .72023 .61099 L p .707 .577 .707 r
F P
0 g
s
.32148 .67237 m .31638 .63515 L .30401 .63039 L p .707 .577 .707 r
F P
0 g
s
.67725 .7401 m .67463 .72149 L .69853 .71378 L p .707 .577 .707 r
F P
0 g
s
.69853 .71378 m .70115 .73239 L .67725 .7401 L p .707 .577 .707 r
F P
0 g
s
.69673 .68476 m .69163 .64754 L .72079 .64103 L p .707 .577 .707 r
F P
0 g
s
.30401 .63039 m .30911 .66762 L .32148 .67237 L p .707 .577 .707 r
F P
0 g
s
.3033 .60532 m .29868 .54945 L .29583 .54212 L p .707 .577 .707 r
F P
0 g
s
.49617 .60824 m .50127 .64546 L .5084 .63779 L p .707 .577 .707 r
F P
0 g
s
.5084 .63779 m .5033 .60056 L .49617 .60824 L p .707 .577 .707 r
F P
0 g
s
.81724 .69965 m .81985 .71826 L .79271 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .71836 m .79009 .69975 L .81724 .69965 L p .707 .577 .707 r
F P
0 g
s
.78323 .63383 m .78833 .67105 L .75746 .67352 L p .707 .577 .707 r
F P
0 g
s
.75746 .67352 m .75236 .6363 L .78323 .63383 L p .707 .577 .707 r
F P
0 g
s
.3259 .71007 m .32328 .69146 L .31091 .6868 L p .707 .577 .707 r
F P
0 g
s
.72079 .64103 m .72589 .67825 L .69673 .68476 L p .707 .577 .707 r
F P
0 g
s
.31091 .6868 m .31353 .70541 L .3259 .71007 L p .707 .577 .707 r
F P
0 g
s
.72589 .67825 m .72079 .64103 L .75236 .6363 L p .707 .577 .707 r
F P
0 g
s
.75236 .6363 m .75746 .67352 L .72589 .67825 L p .707 .577 .707 r
F P
0 g
s
.29583 .54212 m .30046 .59799 L .3033 .60532 L p .707 .577 .707 r
F P
0 g
s
.49906 .52953 m .50368 .5854 L .50084 .57807 L p .707 .577 .707 r
F P
0 g
s
.50084 .57807 m .49621 .5222 L .49906 .52953 L p .707 .577 .707 r
F P
0 g
s
.70115 .73239 m .69853 .71378 L .72769 .70718 L p .707 .577 .707 r
F P
0 g
s
.50298 .66394 m .5056 .68255 L .51273 .6749 L p .707 .577 .707 r
F P
0 g
s
.51273 .6749 m .51011 .65629 L .50298 .66394 L p .707 .577 .707 r
F P
0 g
s
.72769 .70718 m .73031 .72579 L .70115 .73239 L p .707 .577 .707 r
F P
0 g
s
.79009 .69975 m .79271 .71836 L .76186 .72096 L p .707 .577 .707 r
F P
0 g
s
.76186 .72096 m .75924 .70235 L .79009 .69975 L p .707 .577 .707 r
F P
0 g
s
.30911 .66762 m .30401 .63039 L .30125 .62386 L p .707 .577 .707 r
F P
0 g
s
.73031 .72579 m .72769 .70718 L .75924 .70235 L p .707 .577 .707 r
F P
0 g
s
.75924 .70235 m .76186 .72096 L .73031 .72579 L p .707 .577 .707 r
F P
0 g
s
.30125 .62386 m .30635 .66109 L .30911 .66762 L p .707 .577 .707 r
F P
0 g
s
.30046 .59799 m .29583 .54212 L .30293 .53417 L p .707 .577 .707 r
F P
0 g
s
.5033 .60056 m .5084 .63779 L .50564 .63126 L p .707 .577 .707 r
F P
0 g
s
.50564 .63126 m .50054 .59403 L .5033 .60056 L p .707 .577 .707 r
F P
0 g
s
.31353 .70541 m .31091 .6868 L .30816 .68032 L p .707 .577 .707 r
F P
0 g
s
.30816 .68032 m .31078 .69893 L .31353 .70541 L p .707 .577 .707 r
F P
0 g
s
.51011 .65629 m .51273 .6749 L .50998 .66842 L p .707 .577 .707 r
F P
0 g
s
.50998 .66842 m .50736 .64981 L .51011 .65629 L p .707 .577 .707 r
F P
0 g
s
.30293 .53417 m .30756 .59004 L .30046 .59799 L p .707 .577 .707 r
F P
0 g
s
.49621 .5222 m .50084 .57807 L .48832 .57207 L p .707 .577 .707 r
F P
0 g
s
.48832 .57207 m .4837 .5162 L .49621 .5222 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30635 .66109 m .30125 .62386 L .30838 .61619 L p .707 .577 .707 r
F P
0 g
s
.30838 .61619 m .31348 .65341 L .30635 .66109 L p .707 .577 .707 r
F P
0 g
s
.30756 .59004 m .30293 .53417 L .31928 .52639 L p .707 .577 .707 r
F P
0 g
s
.50054 .59403 m .50564 .63126 L .49326 .6265 L p .707 .577 .707 r
F P
0 g
s
.49326 .6265 m .48816 .58928 L .50054 .59403 L p .707 .577 .707 r
F P
0 g
s
.31078 .69893 m .30816 .68032 L .3153 .67267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3153 .67267 m .31792 .69128 L .31078 .69893 L p .707 .577 .707 r
F P
0 g
s
.4837 .5162 m .48832 .57207 L .46736 .56799 L p .707 .577 .707 r
F P
0 g
s
.46736 .56799 m .46274 .51212 L .4837 .5162 L p .707 .577 .707 r
F P
0 g
s
.31928 .52639 m .32391 .58226 L .30756 .59004 L p .707 .577 .707 r
F P
0 g
s
.50736 .64981 m .50998 .66842 L .49761 .66375 L p .707 .577 .707 r
F P
0 g
s
.49761 .66375 m .49499 .64515 L .50736 .64981 L p .707 .577 .707 r
F P
0 g
s
.31348 .65341 m .30838 .61619 L .3247 .60813 L p .707 .577 .707 r
F P
0 g
s
.32391 .58226 m .31928 .52639 L .34329 .51953 L p .707 .577 .707 r
F P
0 g
s
.3247 .60813 m .3298 .64535 L .31348 .65341 L p .707 .577 .707 r
F P
0 g
s
.48816 .58928 m .49326 .6265 L .47248 .624 L p .707 .577 .707 r
F P
0 g
s
.47248 .624 m .46738 .58677 L .48816 .58928 L p .707 .577 .707 r
F P
0 g
s
.31792 .69128 m .3153 .67267 L .33162 .66459 L p .707 .577 .707 r
F P
0 g
s
.46274 .51212 m .46736 .56799 L .44002 .56624 L p .707 .577 .707 r
F P
0 g
s
.44002 .56624 m .43539 .51037 L .46274 .51212 L p .707 .577 .707 r
F P
0 g
s
.33162 .66459 m .33424 .6832 L .31792 .69128 L p .707 .577 .707 r
F P
0 g
s
.34329 .51953 m .34791 .5754 L .32391 .58226 L p .707 .577 .707 r
F P
0 g
s
.49499 .64515 m .49761 .66375 L .47684 .66136 L p .707 .577 .707 r
F P
0 g
s
.47684 .66136 m .47423 .64275 L .49499 .64515 L p .707 .577 .707 r
F P
0 g
s
.34791 .5754 m .34329 .51953 L .37259 .51426 L p .707 .577 .707 r
F P
0 g
s
.3298 .64535 m .3247 .60813 L .34862 .60047 L p .707 .577 .707 r
F P
0 g
s
.43539 .51037 m .44002 .56624 L .40895 .56698 L p .707 .577 .707 r
F P
0 g
s
.40895 .56698 m .40433 .5111 L .43539 .51037 L p .707 .577 .707 r
F P
0 g
s
.46738 .58677 m .47248 .624 L .44532 .62398 L p .707 .577 .707 r
F P
0 g
s
.44532 .62398 m .44022 .58676 L .46738 .58677 L p .707 .577 .707 r
F P
0 g
s
.34862 .60047 m .35372 .63769 L .3298 .64535 L p .707 .577 .707 r
F P
0 g
s
.37721 .57013 m .37259 .51426 L .40433 .5111 L p .707 .577 .707 r
F P
0 g
s
.37259 .51426 m .37721 .57013 L .34791 .5754 L p .707 .577 .707 r
F P
0 g
s
.33424 .6832 m .33162 .66459 L .35552 .65687 L p .707 .577 .707 r
F P
0 g
s
.40433 .5111 m .40895 .56698 L .37721 .57013 L p .707 .577 .707 r
F P
0 g
s
.35552 .65687 m .35814 .67548 L .33424 .6832 L p .707 .577 .707 r
F P
0 g
s
.35372 .63769 m .34862 .60047 L .37778 .59396 L p .707 .577 .707 r
F P
0 g
s
.47423 .64275 m .47684 .66136 L .4497 .66146 L p .707 .577 .707 r
F P
0 g
s
.4497 .66146 m .44708 .64285 L .47423 .64275 L p .707 .577 .707 r
F P
0 g
s
.44022 .58676 m .44532 .62398 L .41445 .62646 L p .707 .577 .707 r
F P
0 g
s
.41445 .62646 m .40935 .58923 L .44022 .58676 L p .707 .577 .707 r
F P
0 g
s
.37778 .59396 m .38288 .63118 L .35372 .63769 L p .707 .577 .707 r
F P
0 g
s
.38288 .63118 m .37778 .59396 L .40935 .58923 L p .707 .577 .707 r
F P
0 g
s
.35814 .67548 m .35552 .65687 L .38468 .65028 L p .707 .577 .707 r
F P
0 g
s
.40935 .58923 m .41445 .62646 L .38288 .63118 L p .707 .577 .707 r
F P
0 g
s
.38468 .65028 m .3873 .66889 L .35814 .67548 L p .707 .577 .707 r
F P
0 g
s
.44708 .64285 m .4497 .66146 L .41885 .66405 L p .707 .577 .707 r
F P
0 g
s
.41885 .66405 m .41623 .64545 L .44708 .64285 L p .707 .577 .707 r
F P
0 g
s
.3873 .66889 m .38468 .65028 L .41623 .64545 L p .707 .577 .707 r
F P
0 g
s
.41623 .64545 m .41885 .66405 L .3873 .66889 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0091oo`P008Eo
o`00S7oo10000UYF00<005YFFUH00eYF3000NGoo0028Ool40006FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH9001`Ool008Aoo`@00003FUH005YF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@006aoo`00PWoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH015YF1000J7oo0021Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH4001TOol0081oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP04001JEP00001ROol0081oo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP04001JEUYFFUH3001OOol007moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF019JEP80
05eoo`00Ogoo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF0P00Fgoo001oOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH3001IOol007ioo`04001J
EUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP02001GOol007ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00eJEP8005Eoo`00OWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P00Dgoo001nOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00Oomoo`1@
Ool007ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001oogoo04moo`00OWoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH02EYF00<007ooOol0CWoo001mOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH02UYF00<007oo
Ool0CGoo001mOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`1<Ool0
07eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo04]oo`00OGoo00<0
05YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH03EYF00<007ooOol0Bgoo001mOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0=
FUH00`00Oomoo`1;Ool007aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001<Ool007aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004ao
o`00O7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000C7oo001lOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001<Ool007aoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00eJEP8004eoo`00O7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH035YF00<005YF0000
CGoo001kOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001=Ool007]o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004eoo`00Ngoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CGoo001kOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0=FUH2001>Ool007]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP03001JEP0004ioo`00
NWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<0
05YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CWoo001jOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001>Ool007Yoo`03001JEP0000IJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYF
0P00Cgoo001jOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001?Ool0
07Uoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004moo`00NGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Cgoo001iOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool007Uoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP80051oo`00NGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH035YF00<005YF
0000D7oo001hOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001@Ool0
07Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00051oo`00N7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000D7oo001hOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1@Ool007Qoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00aJEP03001JEUYF055oo`00N7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000DGoo001gOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001AOol007Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00055oo`00
Mgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0DGoo001gOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001BOol007Moo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00059oo`00MWoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000DWoo001fOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001BOol007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP00059oo`00MWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF0000Dgoo001fOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001C
Ool007Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005=oo`00MGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Dgoo001eOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001COol007Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8005Aoo`00MGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000E7oo001eOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001DOol007Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ao
o`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000E7oo001dOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001EOol007Aoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Eoo`00M7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000EGoo001dOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001EOol007=oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0005Eoo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000EGoo
001cOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001FOol007=oo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ioo`00Lgoo0P001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000EWoo001^OolH000:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001FOol006Io
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005Ioo`00
H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
0eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000Egoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001GOol005Yoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000Egoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EWoo0P000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EUYF05Qoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Qoo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0005Qoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000F7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;OolA
000lOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005Ool60004FUH00`00
FUIJEP06FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF00000Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008002ioo`00E7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF009JEQL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF00<005YFFUH015YF10000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUIJEP8002eoo`00EGoo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP0000002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
001EOol00`00FUH00004FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol00`00FUH00003
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YF001JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEPl00003FUH005YF00=JEP03001JEP0000UJEP03001JEUYF00UJ
EP03001JEUYF00UJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
001EOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0004FUH00`00FUIJEP04
FUH00`00FUIJEP0500000eYF00000009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00EGoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF00000P002EYF00<005YFFUH02UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000]Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;Goo0017Ool@0002FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000/Ool003moo`P000AJEP03001JEUYF00IJEP06001JEP00001JEP000UYF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00=JEP03001JEUYF008002aoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH70003
FUH00`00FUIJEP02000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@000UYF0P00;7oo000cOol20005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH4000/Ool0039oo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00<7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH00P001UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT0009J
EP@00003FUH005YF00EJEPH00003FUH0000000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEP00FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH800000eYF000000060005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH000020005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00@00003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0001/002ioo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF2@000UYF1@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUH000030004FUH00`00FUIJEP05FUH3
0007FUH00`00FUH0000>0004FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF0`00
1eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01P001eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYF001JEP020003FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YF000005YF008000AJEP03001JEP0000<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo000]Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP0000EJEP04001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH00UYF3P0000AJEP00FUH000EJEP@00003FUH005YF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH90008FUH00`00
FUIJEP03FUH01000FUIJEP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF6@000UYF0P00
0eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002aoo`00;Woo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF00@000=J
EPL000QJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000/Ool002ioo`03001JEP0000AJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00AJEP03001JEUYF00AJEPH0009JEP@000AJEP03001JEUYF00QJEP04001JEUYFFUH200000eYF
001JEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00D0
05YFFUIJEP0002]oo`00;Woo00<005YF00000eYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0300025YF00<005YFFUH0
25YF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=oo`0000000P000UYF00<005YFFUH015YF1@000UYF00<007ooOol0:Goo000^Ool01000FUH005YF
0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF
00<005YFFUH00UYF1@0000=oo`0000001UYF00<005YFFUH01eYF00<005YFFUH01UYF100000=JEP00
FUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000Eoo`D000IJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH03@0000=JEP00FUH015YF00<005YF00000P000UYF0P000Woo00=JEP00FUH00UYF100025YF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000Moo`@0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002]oo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P000UYF00@0
05YFFUIJEP<0009JEP@0009oo`03001JEP00009JEPD000QJEP03001JEUYF00@00003FUH005YF00IJ
EP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH00eYF3`001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000:goo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH7
0006FUH00`00FUIJEP06FUH20002FUH01000FUH000001EYF00<005YFFUH00P0000Aoo`00FUH0009J
EPD000AJEPL000EJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUH005YF1@001EYF00<005YFFUH00`0000AJEP00FUIJEPT000AJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000^Ool20002FUH00`00FUIJEP03FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH0009JEQ000003FUH00000
008000QJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF00000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH002ioo`00;goo00@005YF
FUH000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF100035YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHC000_Ool0031oo`<00004FUH000000005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00D002eoo`00
<Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF1`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002]oo`00;goo0P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF400000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH?0003FUH01@00FUIJEUYF00001UYF00<005YFFUH07eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF0`0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
2@000Woo100000=JEP00FUH01EYF1P000UYF00<005YFFUH03EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
0`000UYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4P000eYF00<007oo
Ool0:7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1`000goo1`001EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004Goo0`0000=JEP00Ool0
:Goo000_Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP0400000goo000000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP03FUHC
0009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
00050007FUH00`00FUIJEP04FUH6000HOol20002FUH4000YOol002moo`03001JEP0000AJEP03001J
EUYF00=JEPT0009JEPD000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF00AJEPL000=JEP03001JEUYF00QJEP03001JEUYF009JEPH000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`8000AJEP04001JEP00000YOol002moo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00AJEPD000IJEP03001JEP0000h000EJEP04001JEUYFFUH200000eYF001JEP06
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH5000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH00eYF10007Goo0`0000=JEP00FUH015YF00<005YF
0000:Goo000_Ool01000FUIJEP000eYF0`001eYF00<005YFFUH01EYF0`000UYF1`0015YF00<005YF
FUH015YF00<005YFFUH01@0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0000=JEP00FUH00eYF00<005YF00000`000UYF00<007ooOol067oo100015YF00<005YFFUH00eYF
0P00:Woo000_Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`000eYF00<005YFFUH00P005Goo1000
0UYF00<005YFFUH015YF00@005YFFUIJEP8002]oo`00;goo00<005YFFUH00P001EYF00<005YFFUH0
1EYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02EYF10002UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YF001JEP00FUH30005FUH01@00FUIJEUYF00003Woo1`001UYF
00<005YFFUH015YF00@005YF000002eoo`00<7oo00AJEP00FUH000EJEP04001JEUYFFUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030007FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1P0015YF00D005YFFUIJEP0000Ioo`P000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<002moo`00<7oo00AJEP00FUH000EJEP06001JEP00001JEP00
1eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF010000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0039oo`00<7oo00@005YFFUH000EJEP80
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<00003
FUH005YF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0031oo`06001JEUYFFUH005YF
0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P0037oo00<005YF00003EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00@003Uoo`00<7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
1`000eYF1`003Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF000000IJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD003eo
o`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH010000UYF20004goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP05001JEP00001JEP0200000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool0035oo`8000EJEP03001JEUYF009J
EPX001Moo`@00003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000=JEQ/004Ioo`00<7oo00<005YF00001EYF00<005YF00000P002goo0`0047oo0`00
1EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF0P001eYF0P001EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH00UYF1000DGoo000`Ool01000FUIJEP000eYF0`003Goo1@002goo100000=JEP00
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP8000AJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF001AOol0031oo`05001JEUYF001JEP02000@Ool50004Ool7
0005FUH00`00FUIJEP05FUH01000FUH000000Woo00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000eYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000DWoo000aOol00`00FUH00003000@
Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005Ool00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH02@00FUIJEUYF
001JEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol0035oo`800004FUH005YF
FUH@00000eYF000000020008FUH00`00FUIJEP06FUH00`00FUH000030009Ool00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000E7oo000aOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP04FUH01000FUH00000
EGoo000aOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04000COol2000?FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000000?001EOol0039oo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000IOol2000=FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000015YF001JEP001eYF
00<005YFFUH00eYF0`00Dgoo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000ROol3
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000eOolC
000^Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02001A
Ool007Uoo`80015JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080055oo`00Ngoo0`00
3UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
3`000UYF00D005YFFUIJEP00055oo`00OWoo0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00UYF0`003goo10000UYF00<007ooOol0Cgoo0021Ool4000CFUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`0@Ool200000eYF00000002001@
Ool008Eoo`@000mJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH2000@Ool30003FUH0
1000FUH00000D7oo0029Ool5000OFUH01000FUH000003goo0`0000=JEP00FUH015YF00<005YF0000
D7oo002>Ool6000EFUH6000=Ool40004FUH00`00FUIJEP03FUH2001AOol0099oo`03001JEP0001@0
00moo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH2001BOol0099oo`04001JEP00FUH2000IOol7
0006FUH00`00FUIJEP04FUH01000FUH00000E7oo002BOol00`00FUH00004000@Ool80004FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3001FOol0099oo`80009JEP03001JEUYF010000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<005Uoo`00TWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00GGoo002BOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001P
Ool009=oo`05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
001TOol009Aoo`800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
06Uoo`00UWoo6P00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59105 .74945 m .59567 .69457 L .56461 .69006 L p .707 .577 .707 r
F P
0 g
s
.59567 .69457 m .59105 .74945 L .62278 .75103 L p .707 .577 .707 r
F P
0 g
s
.62278 .75103 m .62741 .69615 L .59567 .69457 L p .707 .577 .707 r
F P
0 g
s
.62741 .69615 m .62278 .75103 L .65209 .74952 L p .707 .577 .707 r
F P
0 g
s
.65209 .74952 m .65671 .69464 L .62741 .69615 L p .707 .577 .707 r
F P
0 g
s
.55998 .74494 m .56461 .69006 L .53726 .68305 L p .707 .577 .707 r
F P
0 g
s
.56461 .69006 m .55998 .74494 L .59105 .74945 L p .707 .577 .707 r
F P
0 g
s
.65671 .69464 m .65209 .74952 L .67609 .74507 L p .707 .577 .707 r
F P
0 g
s
.67609 .74507 m .68071 .69019 L .65671 .69464 L p .707 .577 .707 r
F P
0 g
s
.53263 .73793 m .53726 .68305 L .5163 .67424 L p .707 .577 .707 r
F P
0 g
s
.53726 .68305 m .53263 .73793 L .55998 .74494 L p .707 .577 .707 r
F P
0 g
s
.58555 .80775 m .59065 .77162 L .55978 .76541 L p .707 .577 .707 r
F P
0 g
s
.59065 .77162 m .58555 .80775 L .61711 .81086 L p .707 .577 .707 r
F P
0 g
s
.61711 .81086 m .62221 .77474 L .59065 .77162 L p .707 .577 .707 r
F P
0 g
s
.62221 .77474 m .61711 .81086 L .64628 .81057 L p .707 .577 .707 r
F P
0 g
s
.64628 .81057 m .65138 .77444 L .62221 .77474 L p .707 .577 .707 r
F P
0 g
s
.55468 .80154 m .55978 .76541 L .53262 .75671 L p .707 .577 .707 r
F P
0 g
s
.55978 .76541 m .55468 .80154 L .58555 .80775 L p .707 .577 .707 r
F P
0 g
s
.68071 .69019 m .67609 .74507 L .69244 .73812 L p .707 .577 .707 r
F P
0 g
s
.69244 .73812 m .69706 .68324 L .68071 .69019 L p .707 .577 .707 r
F P
0 g
s
.5163 .67424 m .51168 .72912 L .53263 .73793 L p .707 .577 .707 r
F P
0 g
s
.65138 .77444 m .64628 .81057 L .6702 .8069 L p .707 .577 .707 r
F P
0 g
s
.6702 .8069 m .6753 .77077 L .65138 .77444 L p .707 .577 .707 r
F P
0 g
s
.53262 .75671 m .52752 .79284 L .55468 .80154 L p .707 .577 .707 r
F P
0 g
s
.58115 .8444 m .58377 .82636 L .55291 .82003 L p .707 .577 .707 r
F P
0 g
s
.58377 .82636 m .58115 .8444 L .6127 .84762 L p .707 .577 .707 r
F P
0 g
s
.6127 .84762 m .61532 .82957 L .58377 .82636 L p .707 .577 .707 r
F P
0 g
s
.52752 .79284 m .53262 .75671 L .51184 .74636 L p .707 .577 .707 r
F P
0 g
s
.51168 .72912 m .5163 .67424 L .50379 .66449 L p .707 .577 .707 r
F P
0 g
s
.61532 .82957 m .6127 .84762 L .64185 .84741 L p .707 .577 .707 r
F P
0 g
s
.64185 .84741 m .64447 .82936 L .61532 .82957 L p .707 .577 .707 r
F P
0 g
s
.55029 .83807 m .55291 .82003 L .52577 .81121 L p .707 .577 .707 r
F P
0 g
s
.55291 .82003 m .55029 .83807 L .58115 .8444 L p .707 .577 .707 r
F P
0 g
s
.52577 .81121 m .52315 .82926 L .55029 .83807 L p .707 .577 .707 r
F P
0 g
s
.51184 .74636 m .50674 .78249 L .52752 .79284 L p .707 .577 .707 r
F P
0 g
s
.64447 .82936 m .64185 .84741 L .66576 .8438 L p .707 .577 .707 r
F P
0 g
s
.66576 .8438 m .66838 .82575 L .64447 .82936 L p .707 .577 .707 r
F P
0 g
s
.50379 .66449 m .49916 .71936 L .51168 .72912 L p .707 .577 .707 r
F P
0 g
s
.6753 .77077 m .6702 .8069 L .68652 .80022 L p .707 .577 .707 r
F P
0 g
s
.68652 .80022 m .69162 .76409 L .6753 .77077 L p .707 .577 .707 r
F P
0 g
s
.52315 .82926 m .52577 .81121 L .505 .80076 L p .707 .577 .707 r
F P
0 g
s
.69706 .68324 m .69244 .73812 L .69954 .72934 L p .707 .577 .707 r
F P
0 g
s
.69954 .72934 m .70416 .67446 L .69706 .68324 L p .707 .577 .707 r
F P
0 g
s
.50674 .78249 m .51184 .74636 L .49946 .73539 L p .707 .577 .707 r
F P
0 g
s
.505 .80076 m .50238 .81881 L .52315 .82926 L p .707 .577 .707 r
F P
0 g
s
.49916 .71936 m .50379 .66449 L .50094 .65474 L p .707 .577 .707 r
F P
0 g
s
.49946 .73539 m .49436 .77152 L .50674 .78249 L p .707 .577 .707 r
F P
0 g
s
.66838 .82575 m .66576 .8438 L .68208 .83713 L p .707 .577 .707 r
F P
0 g
s
.68208 .83713 m .6847 .81908 L .66838 .82575 L p .707 .577 .707 r
F P
0 g
s
.50238 .81881 m .505 .80076 L .49264 .78971 L p .707 .577 .707 r
F P
0 g
s
.69162 .76409 m .68652 .80022 L .69365 .79117 L p .707 .577 .707 r
F P
0 g
s
.69365 .79117 m .69875 .75504 L .69162 .76409 L p .707 .577 .707 r
F P
0 g
s
.50094 .65474 m .49632 .70962 L .49916 .71936 L p .707 .577 .707 r
F P
0 g
s
.49264 .78971 m .49002 .80775 L .50238 .81881 L p .707 .577 .707 r
F P
0 g
s
.49436 .77152 m .49946 .73539 L .4967 .72487 L p .707 .577 .707 r
F P
0 g
s
.70416 .67446 m .69954 .72934 L .69669 .7196 L p .707 .577 .707 r
F P
0 g
s
.69669 .7196 m .70132 .66472 L .70416 .67446 L p .707 .577 .707 r
F P
0 g
s
.49632 .70962 m .50094 .65474 L .50804 .64596 L p .707 .577 .707 r
F P
0 g
s
.4967 .72487 m .4916 .761 L .49436 .77152 L p .707 .577 .707 r
F P
0 g
s
.6847 .81908 m .68208 .83713 L .68921 .82806 L p .707 .577 .707 r
F P
0 g
s
.68921 .82806 m .69183 .81002 L .6847 .81908 L p .707 .577 .707 r
F P
0 g
s
.49002 .80775 m .49264 .78971 L .48989 .77913 L p .707 .577 .707 r
F P
0 g
s
.48989 .77913 m .48727 .79718 L .49002 .80775 L p .707 .577 .707 r
F P
0 g
s
.69875 .75504 m .69365 .79117 L .69089 .78065 L p .707 .577 .707 r
F P
0 g
s
.69089 .78065 m .69599 .74452 L .69875 .75504 L p .707 .577 .707 r
F P
0 g
s
.50804 .64596 m .50342 .70084 L .49632 .70962 L p .707 .577 .707 r
F P
0 g
s
.4916 .761 m .4967 .72487 L .50383 .71582 L p .707 .577 .707 r
F P
0 g
s
.70132 .66472 m .69669 .7196 L .68418 .70984 L p .707 .577 .707 r
F P
0 g
s
.68418 .70984 m .6888 .65496 L .70132 .66472 L p .707 .577 .707 r
F P
0 g
s
.50342 .70084 m .50804 .64596 L .52439 .63901 L p .707 .577 .707 r
F P
0 g
s
.24804 .71668 m .25266 .6618 L .2216 .65729 L p .707 .577 .707 r
F P
0 g
s
.25266 .6618 m .24804 .71668 L .27977 .71826 L p .707 .577 .707 r
F P
0 g
s
.27977 .71826 m .2844 .66338 L .25266 .6618 L p .707 .577 .707 r
F P
0 g
s
.50383 .71582 m .49873 .75195 L .4916 .761 L p .707 .577 .707 r
F P
0 g
s
.48904 .80929 m .39889 .30652 L .35561 .31192 L p .707 .577 .707 r
F P
0 g
s
.48727 .79718 m .48989 .77913 L .49702 .77006 L p .707 .577 .707 r
F P
0 g
s
.49702 .77006 m .4944 .78811 L .48727 .79718 L p .707 .577 .707 r
F P
0 g
s
.52439 .63901 m .51977 .69389 L .50342 .70084 L p .707 .577 .707 r
F P
0 g
s
.49873 .75195 m .50383 .71582 L .52015 .70914 L p .707 .577 .707 r
F P
0 g
s
.52015 .70914 m .51505 .74527 L .49873 .75195 L p .707 .577 .707 r
F P
0 g
s
.4944 .78811 m .49702 .77006 L .51334 .7634 L p .707 .577 .707 r
F P
0 g
s
.51334 .7634 m .51072 .78144 L .4944 .78811 L p .707 .577 .707 r
F P
0 g
s
.51505 .74527 m .52015 .70914 L .54407 .70547 L p .707 .577 .707 r
F P
0 g
s
.54407 .70547 m .53897 .7416 L .51505 .74527 L p .707 .577 .707 r
F P
0 g
s
.51072 .78144 m .51334 .7634 L .53725 .75978 L p .707 .577 .707 r
F P
0 g
s
.53725 .75978 m .53463 .77783 L .51072 .78144 L p .707 .577 .707 r
F P
0 g
s
.39889 .30652 m .48904 .80929 L .53333 .8009 L p .707 .577 .707 r
F P
0 g
s
.53333 .8009 m .44318 .29813 L .39889 .30652 L p .707 .577 .707 r
F P
0 g
s
.69183 .81002 m .68921 .82806 L .68646 .81749 L p .707 .577 .707 r
F P
0 g
s
.68646 .81749 m .68908 .79944 L .69183 .81002 L p .707 .577 .707 r
F P
0 g
s
.2844 .66338 m .27977 .71826 L .30908 .71675 L p .707 .577 .707 r
F P
0 g
s
.30908 .71675 m .3137 .66187 L .2844 .66338 L p .707 .577 .707 r
F P
0 g
s
.51977 .69389 m .52439 .63901 L .54839 .63456 L p .707 .577 .707 r
F P
0 g
s
.54839 .63456 m .54377 .68944 L .51977 .69389 L p .707 .577 .707 r
F P
0 g
s
.54377 .68944 m .54839 .63456 L .5777 .63305 L p .707 .577 .707 r
F P
0 g
s
.5777 .63305 m .57308 .68793 L .54377 .68944 L p .707 .577 .707 r
F P
0 g
s
.53897 .7416 m .54407 .70547 L .57323 .70518 L p .707 .577 .707 r
F P
0 g
s
.57323 .70518 m .56813 .7413 L .53897 .7416 L p .707 .577 .707 r
F P
0 g
s
.53463 .77783 m .53725 .75978 L .5664 .75957 L p .707 .577 .707 r
F P
0 g
s
.5664 .75957 m .56378 .77762 L .53463 .77783 L p .707 .577 .707 r
F P
0 g
s
.56378 .77762 m .5664 .75957 L .59795 .76279 L p .707 .577 .707 r
F P
0 g
s
.59795 .76279 m .59533 .78084 L .56378 .77762 L p .707 .577 .707 r
F P
0 g
s
.44318 .29813 m .53333 .8009 L .5743 .79035 L p .707 .577 .707 r
F P
0 g
s
.5743 .79035 m .48414 .28758 L .44318 .29813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21697 .71216 m .2216 .65729 L .19425 .65028 L p .707 .577 .707 r
F P
0 g
s
.2216 .65729 m .21697 .71216 L .24804 .71668 L p .707 .577 .707 r
F P
0 g
s
.44576 .81469 m .35561 .31192 L .31757 .31379 L p .707 .577 .707 r
F P
0 g
s
.35561 .31192 m .44576 .81469 L .48904 .80929 L p .707 .577 .707 r
F P
0 g
s
.69599 .74452 m .69089 .78065 L .67851 .76968 L p .707 .577 .707 r
F P
0 g
s
.67851 .76968 m .68361 .73355 L .69599 .74452 L p .707 .577 .707 r
F P
0 g
s
.3137 .66187 m .30908 .71675 L .33308 .7123 L p .707 .577 .707 r
F P
0 g
s
.33308 .7123 m .3377 .65742 L .3137 .66187 L p .707 .577 .707 r
F P
0 g
s
.6888 .65496 m .68418 .70984 L .66322 .70103 L p .707 .577 .707 r
F P
0 g
s
.66322 .70103 m .66785 .64615 L .6888 .65496 L p .707 .577 .707 r
F P
0 g
s
.57308 .68793 m .5777 .63305 L .60944 .63463 L p .707 .577 .707 r
F P
0 g
s
.60944 .63463 m .60481 .68951 L .57308 .68793 L p .707 .577 .707 r
F P
0 g
s
.56813 .7413 m .57323 .70518 L .6048 .70829 L p .707 .577 .707 r
F P
0 g
s
.6048 .70829 m .5997 .74442 L .56813 .7413 L p .707 .577 .707 r
F P
0 g
s
.62881 .76912 m .62619 .78716 L .59533 .78084 L p .707 .577 .707 r
F P
0 g
s
.59533 .78084 m .59795 .76279 L .62881 .76912 L p .707 .577 .707 r
F P
0 g
s
.48414 .28758 m .5743 .79035 L .60792 .77866 L p .707 .577 .707 r
F P
0 g
s
.63567 .7145 m .63057 .75063 L .5997 .74442 L p .707 .577 .707 r
F P
0 g
s
.5997 .74442 m .6048 .70829 L .63567 .7145 L p .707 .577 .707 r
F P
0 g
s
.60792 .77866 m .51776 .27588 L .48414 .28758 L p .707 .577 .707 r
F P
0 g
s
.18962 .70516 m .19425 .65028 L .17329 .64147 L p .707 .577 .707 r
F P
0 g
s
.19425 .65028 m .18962 .70516 L .21697 .71216 L p .707 .577 .707 r
F P
0 g
s
.24254 .78119 m .24764 .74506 L .21677 .73885 L p .707 .577 .707 r
F P
0 g
s
.24764 .74506 m .24254 .78119 L .27411 .7843 L p .707 .577 .707 r
F P
0 g
s
.27411 .7843 m .27921 .74817 L .24764 .74506 L p .707 .577 .707 r
F P
0 g
s
.27921 .74817 m .27411 .7843 L .30327 .78401 L p .707 .577 .707 r
F P
0 g
s
.30327 .78401 m .30837 .74788 L .27921 .74817 L p .707 .577 .707 r
F P
0 g
s
.21167 .77497 m .21677 .73885 L .18961 .73014 L p .707 .577 .707 r
F P
0 g
s
.21677 .73885 m .21167 .77497 L .24254 .78119 L p .707 .577 .707 r
F P
0 g
s
.68908 .79944 m .68646 .81749 L .6741 .80643 L p .707 .577 .707 r
F P
0 g
s
.6741 .80643 m .67672 .78839 L .68908 .79944 L p .707 .577 .707 r
F P
0 g
s
.3377 .65742 m .33308 .7123 L .34943 .70535 L p .707 .577 .707 r
F P
0 g
s
.34943 .70535 m .35405 .65047 L .3377 .65742 L p .707 .577 .707 r
F P
0 g
s
.40772 .81657 m .31757 .31379 L .28849 .31197 L p .707 .577 .707 r
F P
0 g
s
.31757 .31379 m .40772 .81657 L .44576 .81469 L p .707 .577 .707 r
F P
0 g
s
.17329 .64147 m .16867 .69635 L .18962 .70516 L p .707 .577 .707 r
F P
0 g
s
.66785 .64615 m .66322 .70103 L .63587 .69403 L p .707 .577 .707 r
F P
0 g
s
.63587 .69403 m .6405 .63915 L .66785 .64615 L p .707 .577 .707 r
F P
0 g
s
.68361 .73355 m .67851 .76968 L .65773 .75933 L p .707 .577 .707 r
F P
0 g
s
.65773 .75933 m .66283 .7232 L .68361 .73355 L p .707 .577 .707 r
F P
0 g
s
.30837 .74788 m .30327 .78401 L .32719 .78034 L p .707 .577 .707 r
F P
0 g
s
.32719 .78034 m .33229 .74421 L .30837 .74788 L p .707 .577 .707 r
F P
0 g
s
.18961 .73014 m .18451 .76627 L .21167 .77497 L p .707 .577 .707 r
F P
0 g
s
.16867 .69635 m .17329 .64147 L .16078 .63171 L p .707 .577 .707 r
F P
0 g
s
.18451 .76627 m .18961 .73014 L .16883 .7198 L p .707 .577 .707 r
F P
0 g
s
.23814 .82767 m .24076 .80963 L .2099 .8033 L p .707 .577 .707 r
F P
0 g
s
.24076 .80963 m .23814 .82767 L .26969 .83089 L p .707 .577 .707 r
F P
0 g
s
.26969 .83089 m .27231 .81285 L .24076 .80963 L p .707 .577 .707 r
F P
0 g
s
.6405 .63915 m .63587 .69403 L .60481 .68951 L p .707 .577 .707 r
F P
0 g
s
.60481 .68951 m .60944 .63463 L .6405 .63915 L p .707 .577 .707 r
F P
0 g
s
.51776 .27588 m .60792 .77866 L .63091 .76697 L p .707 .577 .707 r
F P
0 g
s
.63091 .76697 m .54076 .2642 L .51776 .27588 L p .707 .577 .707 r
F P
0 g
s
.27231 .81285 m .26969 .83089 L .29884 .83068 L p .707 .577 .707 r
F P
0 g
s
.29884 .83068 m .30146 .81264 L .27231 .81285 L p .707 .577 .707 r
F P
0 g
s
.20728 .82135 m .2099 .8033 L .18276 .79448 L p .707 .577 .707 r
F P
0 g
s
.2099 .8033 m .20728 .82135 L .23814 .82767 L p .707 .577 .707 r
F P
0 g
s
.16883 .7198 m .16373 .75593 L .18451 .76627 L p .707 .577 .707 r
F P
0 g
s
.18276 .79448 m .18014 .81253 L .20728 .82135 L p .707 .577 .707 r
F P
0 g
s
.67672 .78839 m .6741 .80643 L .65333 .79598 L p .707 .577 .707 r
F P
0 g
s
.65333 .79598 m .65595 .77794 L .67672 .78839 L p .707 .577 .707 r
F P
0 g
s
.16078 .63171 m .15615 .68659 L .16867 .69635 L p .707 .577 .707 r
F P
0 g
s
.33229 .74421 m .32719 .78034 L .34351 .77365 L p .707 .577 .707 r
F P
0 g
s
.34351 .77365 m .34861 .73753 L .33229 .74421 L p .707 .577 .707 r
F P
0 g
s
.30146 .81264 m .29884 .83068 L .32275 .82707 L p .707 .577 .707 r
F P
0 g
s
.32275 .82707 m .32537 .80902 L .30146 .81264 L p .707 .577 .707 r
F P
0 g
s
.35405 .65047 m .34943 .70535 L .35653 .69657 L p .707 .577 .707 r
F P
0 g
s
.35653 .69657 m .36116 .64169 L .35405 .65047 L p .707 .577 .707 r
F P
0 g
s
.66283 .7232 m .65773 .75933 L .63057 .75063 L p .707 .577 .707 r
F P
0 g
s
.63057 .75063 m .63567 .7145 L .66283 .7232 L p .707 .577 .707 r
F P
0 g
s
.18014 .81253 m .18276 .79448 L .16199 .78403 L p .707 .577 .707 r
F P
0 g
s
.16373 .75593 m .16883 .7198 L .15645 .70883 L p .707 .577 .707 r
F P
0 g
s
.15615 .68659 m .16078 .63171 L .15793 .62197 L p .707 .577 .707 r
F P
0 g
s
.16199 .78403 m .15937 .80208 L .18014 .81253 L p .707 .577 .707 r
F P
0 g
s
.36116 .64169 m .35653 .69657 L .35369 .68683 L p .707 .577 .707 r
F P
0 g
s
.35369 .68683 m .35563 .66371 L p .36116 .64169 L .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .40772 .81657 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.28849 .31197 m .35114 .66131 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.36025 .61564 m .35114 .66131 L .3579 .63675 L .707 .577 .707 r
F
.28849 .31197 m .27124 .30663 L p .34559 .65836 L F P
0 g
s
.34117 .67707 m .34783 .65955 L .34833 .65982 L .707 .577 .707 r
F
.35369 .68683 m .3458 .68068 L p .35114 .66131 L F P
0 g
s
.3579 .63675 m .35563 .66371 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35563 .66371 m .35369 .68683 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .35114 .66131 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .28849 .31197 L p .34694 .65908 L .707 .577 .707 r
F P
0 g
s
.3458 .68068 m .34117 .67707 L p .34833 .65982 L .707 .577 .707 r
F P
0 g
s
.34833 .65982 m .3579 .63675 L .35114 .66131 L .707 .577 .707 r
F
.34833 .65982 m .35114 .66131 L .3458 .68068 L F
.35064 .76461 m .35353 .74413 L p .34861 .73753 L F P
0 g
s
.35353 .74413 m .35574 .72848 L .35234 .73279 L p .707 .577 .707 r
F P
0 g
s
.35234 .73279 m .34861 .73753 L p .35353 .74413 L .707 .577 .707 r
F P
0 g
s
.34861 .73753 m .34351 .77365 L .35064 .76461 L p .707 .577 .707 r
F P
0 g
s
.35064 .76461 m .34788 .75408 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35574 .72848 m .35353 .74413 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35353 .74413 m .35064 .76461 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3406 .70698 L .3452 .71106 L p .707 .577 .707 r
F P
0 g
s
.3452 .71106 m .35298 .71795 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3452 .71106 L .34813 .72493 L .707 .577 .707 r
F
.32484 .61338 m .3266 .61412 L p .32101 .66154 L F P
0 g
s
.32087 .66052 m .32484 .61338 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.3266 .61412 m .32977 .61545 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.27124 .30663 m .32248 .59241 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .32248 .59241 L .34287 .65691 L .707 .577 .707 r
F
.34694 .65908 m .28849 .31197 L .34559 .65836 L F
.32977 .61545 m .34579 .62219 L p .33694 .63814 L F P
0 g
s
.33263 .64591 m .32977 .61545 L .33694 .63814 L .707 .577 .707 r
F
.32021 .66826 m .3266 .61412 L .33263 .64591 L F
.34117 .67707 m .33831 .67587 L p .34154 .6527 L F P
0 g
s
.34287 .65691 m .34117 .67707 L p .34154 .6527 L .707 .577 .707 r
F P
0 g
s
.33831 .67587 m .32021 .66826 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.33263 .64591 m .34579 .62219 L .33831 .67587 L .707 .577 .707 r
F
.35298 .71795 m .35574 .72848 L p .3521 .74032 L F P
0 g
s
.34788 .75408 m .35045 .73589 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .35298 .71795 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.34788 .75408 m .3355 .74311 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35298 .71795 m .35045 .73589 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .34788 .75408 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35764 .80105 m .36139 .8094 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32484 .61338 m .32021 .66826 L .29287 .66125 L p .707 .577 .707 r
F P
0 g
s
.29287 .66125 m .29749 .60638 L .32484 .61338 L p .707 .577 .707 r
F P
0 g
s
.26748 .29828 m .32086 .59598 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32086 .59598 m .35764 .80105 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.35893 .79566 m .34614 .72434 L p .35901 .79643 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .27124 .30663 L p .34604 .72409 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .34604 .72409 L .35901 .79643 L .707 .577 .707 r
F
.34117 .67707 m .34579 .62219 L .35831 .63195 L p F P
0 g
s
.33312 .65172 m .36139 .8094 L p .34671 .66907 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .34287 .65691 L .34671 .66907 L .707 .577 .707 r
F
.34287 .65691 m .33312 .65172 L .34671 .66907 L F
.34579 .62219 m .34287 .65691 L p .34154 .6527 L F P
0 g
s
.33359 .65617 m .31801 .56883 L .33089 .64341 L .707 .577 .707 r
F
.31801 .56883 m .27124 .30663 L .31301 .54248 L F
.31801 .56883 m .31301 .54248 L .33089 .64341 L F
.32248 .59241 m .33312 .65172 L p .34287 .65691 L F P
0 g
s
.27124 .30663 m .26748 .29828 L p .2915 .42902 L .707 .577 .707 r
F P
0 g
s
.33089 .64341 m .31301 .54248 L .2915 .42902 L .707 .577 .707 r
F
.31301 .54248 m .27124 .30663 L .2915 .42902 L F
.3454 .72235 m .33359 .65617 L .33089 .64341 L F
.34604 .72409 m .27124 .30663 L .3454 .72235 L F
.35764 .80105 m .28085 .37286 L p .27759 .28775 L F P
0 g
s
.28085 .37286 m .26748 .29828 L .2701 .29555 L p .707 .577 .707 r
F P
0 g
s
.2701 .29555 m .27759 .28775 L p .28085 .37286 L .707 .577 .707 r
F P
0 g
s
.32021 .66826 m .32087 .66052 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.35901 .79643 m .34604 .72409 L .3454 .72235 L .707 .577 .707 r
F
.36139 .8094 m .35893 .79566 L p .35901 .79643 L F P
0 g
s
.36139 .8094 m .37865 .81474 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .34694 .65908 L .35162 .68689 L .707 .577 .707 r
F
.35162 .68689 m .34694 .65908 L .34559 .65836 L F
.35831 .63195 m .3579 .63675 L p .34833 .65982 L F P
0 g
s
.34783 .65955 m .35831 .63195 L .34833 .65982 L .707 .577 .707 r
F
.35114 .66131 m .35364 .67525 L p .3579 .63675 L F P
0 g
s
.35563 .66371 m .3579 .63675 L p .36008 .63801 L .707 .577 .707 r
F P
0 g
s
.3584 .63227 m .36008 .63801 L p .3579 .63675 L .707 .577 .707 r
F P
0 g
s
.36008 .63801 m .36116 .64169 L p .35563 .66371 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .37865 .81474 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.3579 .63675 m .35831 .63195 L .3584 .63227 L p .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .35364 .67525 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.15645 .70883 m .15135 .74496 L .16373 .75593 L p .707 .577 .707 r
F P
0 g
s
.65595 .77794 m .65333 .79598 L .62619 .78716 L p .707 .577 .707 r
F P
0 g
s
.62619 .78716 m .62881 .76912 L .65595 .77794 L p .707 .577 .707 r
F P
0 g
s
.32537 .80902 m .32275 .82707 L .33907 .8204 L p .707 .577 .707 r
F P
0 g
s
.33907 .8204 m .34169 .80236 L .32537 .80902 L p .707 .577 .707 r
F P
0 g
s
.54076 .2642 m .63091 .76697 L .64103 .75645 L p .707 .577 .707 r
F P
0 g
s
.64103 .75645 m .55087 .25367 L .54076 .2642 L p .707 .577 .707 r
F P
0 g
s
.15937 .80208 m .16199 .78403 L .14963 .77298 L p .707 .577 .707 r
F P
0 g
s
.15793 .62197 m .15331 .67685 L .15615 .68659 L p .707 .577 .707 r
F P
0 g
s
.14963 .77298 m .14701 .79103 L .15937 .80208 L p .707 .577 .707 r
F P
0 g
s
.15135 .74496 m .15645 .70883 L .15369 .69831 L p .707 .577 .707 r
F P
0 g
s
.15331 .67685 m .15793 .62197 L .16503 .61319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15369 .69831 m .14859 .73443 L .15135 .74496 L p .707 .577 .707 r
F P
0 g
s
.34169 .80236 m .33907 .8204 L .3462 .81134 L p .707 .577 .707 r
F P
0 g
s
.3462 .81134 m .34882 .79329 L .34169 .80236 L p .707 .577 .707 r
F P
0 g
s
.14701 .79103 m .14963 .77298 L .14688 .7624 L p .707 .577 .707 r
F P
0 g
s
.16503 .61319 m .16041 .66807 L .15331 .67685 L p .707 .577 .707 r
F P
0 g
s
.14688 .7624 m .14426 .78045 L .14701 .79103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14859 .73443 m .15369 .69831 L .16082 .68926 L p .707 .577 .707 r
F P
0 g
s
.55087 .25367 m .64103 .75645 L .63727 .7481 L p .707 .577 .707 r
F P
0 g
s
.63727 .7481 m .54712 .24533 L .55087 .25367 L p .707 .577 .707 r
F P
0 g
s
.16041 .66807 m .16503 .61319 L .18138 .60624 L p .707 .577 .707 r
F P
0 g
s
.16082 .68926 m .15572 .72539 L .14859 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34882 .79329 m .3462 .81134 L .34345 .80076 L p .707 .577 .707 r
F P
0 g
s
.34345 .80076 m .34607 .78271 L .34882 .79329 L p .707 .577 .707 r
F P
0 g
s
.14426 .78045 m .14688 .7624 L .15401 .75334 L p .707 .577 .707 r
F P
0 g
s
.18138 .60624 m .17676 .66112 L .16041 .66807 L p .707 .577 .707 r
F P
0 g
s
.15401 .75334 m .15139 .77138 L .14426 .78045 L p .707 .577 .707 r
F P
0 g
s
.15572 .72539 m .16082 .68926 L .17714 .68257 L p .707 .577 .707 r
F P
0 g
s
.17676 .66112 m .18138 .60624 L .20539 .60179 L p .707 .577 .707 r
F P
0 g
s
.17714 .68257 m .17204 .7187 L .15572 .72539 L p .707 .577 .707 r
F P
0 g
s
.34607 .78271 m .34345 .80076 L .33109 .7897 L p .707 .577 .707 r
F P
0 g
s
.33109 .7897 m .33371 .77166 L .34607 .78271 L p .707 .577 .707 r
F P
0 g
s
.54712 .24533 m .63727 .7481 L .62001 .74276 L p .707 .577 .707 r
F P
0 g
s
.62001 .74276 m .52986 .23998 L .54712 .24533 L p .707 .577 .707 r
F P
0 g
s
.15139 .77138 m .15401 .75334 L .17033 .74667 L p .707 .577 .707 r
F P
0 g
s
.20539 .60179 m .20076 .65667 L .17676 .66112 L p .707 .577 .707 r
F P
0 g
s
.3406 .70698 m .3355 .74311 L .31472 .73277 L p .707 .577 .707 r
F P
0 g
s
.31472 .73277 m .31982 .69664 L .3406 .70698 L p .707 .577 .707 r
F P
0 g
s
.20076 .65667 m .20539 .60179 L .23469 .60028 L p .707 .577 .707 r
F P
0 g
s
.17204 .7187 m .17714 .68257 L .20106 .67891 L p .707 .577 .707 r
F P
0 g
s
.17033 .74667 m .16771 .76472 L .15139 .77138 L p .707 .577 .707 r
F P
0 g
s
.29749 .60638 m .29287 .66125 L .2618 .65674 L p .707 .577 .707 r
F P
0 g
s
.2618 .65674 m .26643 .60186 L .29749 .60638 L p .707 .577 .707 r
F P
0 g
s
.23007 .65516 m .23469 .60028 L .26643 .60186 L p .707 .577 .707 r
F P
0 g
s
.23469 .60028 m .23007 .65516 L .20076 .65667 L p .707 .577 .707 r
F P
0 g
s
.20106 .67891 m .19596 .71503 L .17204 .7187 L p .707 .577 .707 r
F P
0 g
s
.26643 .60186 m .2618 .65674 L .23007 .65516 L p .707 .577 .707 r
F P
0 g
s
.72825 .65741 m .73287 .60253 L .70181 .59802 L p .707 .577 .707 r
F P
0 g
s
.73287 .60253 m .72825 .65741 L .75999 .65899 L p .707 .577 .707 r
F P
0 g
s
.75999 .65899 m .76461 .60411 L .73287 .60253 L p .707 .577 .707 r
F P
0 g
s
.33371 .77166 m .33109 .7897 L .31032 .77926 L p .707 .577 .707 r
F P
0 g
s
.31032 .77926 m .31294 .76121 L .33371 .77166 L p .707 .577 .707 r
F P
0 g
s
.31982 .69664 m .31472 .73277 L .28756 .72406 L p .707 .577 .707 r
F P
0 g
s
.28756 .72406 m .29266 .68794 L .31982 .69664 L p .707 .577 .707 r
F P
0 g
s
.76461 .60411 m .75999 .65899 L .78929 .65748 L p .707 .577 .707 r
F P
0 g
s
.78929 .65748 m .79391 .6026 L .76461 .60411 L p .707 .577 .707 r
F P
0 g
s
.36775 .79052 m .27759 .28775 L .30059 .27607 L p .707 .577 .707 r
F P
0 g
s
.27759 .28775 m .36775 .79052 L .35764 .80105 L p .707 .577 .707 r
F P
0 g
s
.16771 .76472 m .17033 .74667 L .19424 .74306 L p .707 .577 .707 r
F P
0 g
s
.19596 .71503 m .20106 .67891 L .23022 .67861 L p .707 .577 .707 r
F P
0 g
s
.69719 .6529 m .70181 .59802 L .67446 .59101 L p .707 .577 .707 r
F P
0 g
s
.70181 .59802 m .69719 .6529 L .72825 .65741 L p .707 .577 .707 r
F P
0 g
s
.19424 .74306 m .19162 .7611 L .16771 .76472 L p .707 .577 .707 r
F P
0 g
s
.52986 .23998 m .62001 .74276 L .59094 .74093 L p .707 .577 .707 r
F P
0 g
s
.59094 .74093 m .50079 .23816 L .52986 .23998 L p .707 .577 .707 r
F P
0 g
s
.79391 .6026 m .78929 .65748 L .81329 .65303 L p .707 .577 .707 r
F P
0 g
s
.81329 .65303 m .81792 .59816 L .79391 .6026 L p .707 .577 .707 r
F P
0 g
s
.29266 .68794 m .28756 .72406 L .25669 .71785 L p .707 .577 .707 r
F P
0 g
s
.25669 .71785 m .26179 .68173 L .29266 .68794 L p .707 .577 .707 r
F P
0 g
s
.23022 .67861 m .22512 .71474 L .19596 .71503 L p .707 .577 .707 r
F P
0 g
s
.22512 .71474 m .23022 .67861 L .26179 .68173 L p .707 .577 .707 r
F P
0 g
s
.66984 .64589 m .67446 .59101 L .6535 .5822 L p .707 .577 .707 r
F P
0 g
s
.67446 .59101 m .66984 .64589 L .69719 .6529 L p .707 .577 .707 r
F P
0 g
s
.26179 .68173 m .25669 .71785 L .22512 .71474 L p .707 .577 .707 r
F P
0 g
s
.31294 .76121 m .31032 .77926 L .28318 .77044 L p .707 .577 .707 r
F P
0 g
s
.28318 .77044 m .2858 .75239 L .31294 .76121 L p .707 .577 .707 r
F P
0 g
s
.72275 .71571 m .72785 .67958 L .69698 .67337 L p .707 .577 .707 r
F P
0 g
s
.72785 .67958 m .72275 .71571 L .75432 .71882 L p .707 .577 .707 r
F P
0 g
s
.75432 .71882 m .75942 .6827 L .72785 .67958 L p .707 .577 .707 r
F P
0 g
s
.19162 .7611 m .19424 .74306 L .22339 .74285 L p .707 .577 .707 r
F P
0 g
s
.75942 .6827 m .75432 .71882 L .78349 .71853 L p .707 .577 .707 r
F P
0 g
s
.78349 .71853 m .78859 .6824 L .75942 .6827 L p .707 .577 .707 r
F P
0 g
s
.69188 .7095 m .69698 .67337 L .66982 .66467 L p .707 .577 .707 r
F P
0 g
s
.69698 .67337 m .69188 .7095 L .72275 .71571 L p .707 .577 .707 r
F P
0 g
s
.22339 .74285 m .22077 .76089 L .19162 .7611 L p .707 .577 .707 r
F P
0 g
s
.81792 .59816 m .81329 .65303 L .82964 .64608 L p .707 .577 .707 r
F P
0 g
s
.82964 .64608 m .83427 .5912 L .81792 .59816 L p .707 .577 .707 r
F P
0 g
s
.2858 .75239 m .28318 .77044 L .25232 .76411 L p .707 .577 .707 r
F P
0 g
s
.25232 .76411 m .25494 .74606 L .2858 .75239 L p .707 .577 .707 r
F P
0 g
s
.6535 .5822 m .64888 .63708 L .66984 .64589 L p .707 .577 .707 r
F P
0 g
s
.22077 .76089 m .22339 .74285 L .25494 .74606 L p .707 .577 .707 r
F P
0 g
s
.30059 .27607 m .39074 .77884 L .36775 .79052 L p .707 .577 .707 r
F P
0 g
s
.39074 .77884 m .30059 .27607 L .33421 .26438 L p .707 .577 .707 r
F P
0 g
s
.78859 .6824 m .78349 .71853 L .8074 .71486 L p .707 .577 .707 r
F P
0 g
s
.8074 .71486 m .8125 .67874 L .78859 .6824 L p .707 .577 .707 r
F P
0 g
s
.66982 .66467 m .66472 .7008 L .69188 .7095 L p .707 .577 .707 r
F P
0 g
s
.71835 .75236 m .72097 .73432 L .69012 .72799 L p .707 .577 .707 r
F P
0 g
s
.72097 .73432 m .71835 .75236 L .7499 .75558 L p .707 .577 .707 r
F P
0 g
s
.7499 .75558 m .75252 .73754 L .72097 .73432 L p .707 .577 .707 r
F P
0 g
s
.25494 .74606 m .25232 .76411 L .22077 .76089 L p .707 .577 .707 r
F P
0 g
s
.66472 .7008 m .66982 .66467 L .64904 .65433 L p .707 .577 .707 r
F P
0 g
s
.64888 .63708 m .6535 .5822 L .64099 .57245 L p .707 .577 .707 r
F P
0 g
s
.75252 .73754 m .7499 .75558 L .77906 .75537 L p .707 .577 .707 r
F P
0 g
s
.77906 .75537 m .78168 .73733 L .75252 .73754 L p .707 .577 .707 r
F P
0 g
s
.6875 .74604 m .69012 .72799 L .66298 .71917 L p .707 .577 .707 r
F P
0 g
s
.69012 .72799 m .6875 .74604 L .71835 .75236 L p .707 .577 .707 r
F P
0 g
s
.50079 .23816 m .59094 .74093 L .5529 .74281 L p .707 .577 .707 r
F P
0 g
s
.5529 .74281 m .46275 .24004 L .50079 .23816 L p .707 .577 .707 r
F P
0 g
s
.66298 .71917 m .66036 .73722 L .6875 .74604 L p .707 .577 .707 r
F P
0 g
s
.64904 .65433 m .64394 .69045 L .66472 .7008 L p .707 .577 .707 r
F P
0 g
s
.78168 .73733 m .77906 .75537 L .80297 .75176 L p .707 .577 .707 r
F P
0 g
s
.80297 .75176 m .80558 .73371 L .78168 .73733 L p .707 .577 .707 r
F P
0 g
s
.64099 .57245 m .63637 .62733 L .64888 .63708 L p .707 .577 .707 r
F P
0 g
s
.8125 .67874 m .8074 .71486 L .82372 .70818 L p .707 .577 .707 r
F P
0 g
s
.82372 .70818 m .82882 .67205 L .8125 .67874 L p .707 .577 .707 r
F P
0 g
s
.66036 .73722 m .66298 .71917 L .64221 .70872 L p .707 .577 .707 r
F P
0 g
s
.83427 .5912 m .82964 .64608 L .83675 .6373 L p .707 .577 .707 r
F P
0 g
s
.83675 .6373 m .84137 .58242 L .83427 .5912 L p .707 .577 .707 r
F P
0 g
s
.64394 .69045 m .64904 .65433 L .63666 .64336 L p .707 .577 .707 r
F P
0 g
s
.64221 .70872 m .63959 .72677 L .66036 .73722 L p .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .38546 .55016 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .4216 .57134 L .39733 .57013 L p .707 .577 .707 r
F P
0 g
s
.46533 .7566 m .42437 .76715 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4216 .57134 m .41867 .60606 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .46533 .7566 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4216 .57134 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.44941 .57918 m .43782 .60317 L .44925 .57744 L .707 .577 .707 r
F
.46533 .7566 m .44032 .6171 L p .44941 .57918 L F P
0 g
s
.44032 .6171 m .43782 .60317 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4505 .57463 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.4505 .57463 m .4509 .56983 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .46533 .7566 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.45169 .56969 m .4509 .56983 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.41946 .24544 m .46652 .50784 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.46652 .50784 m .50962 .74821 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .47491 .56538 L .45169 .56969 L p .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .45169 .56969 L .45136 .57103 L .707 .577 .707 r
F
.44628 .62471 m .47028 .62026 L p .45136 .57103 L F P
0 g
s
.4505 .57463 m .44628 .62471 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.44628 .62471 m .4505 .57463 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .41946 .24544 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .37517 .25383 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .43782 .60317 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .44628 .62471 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .41698 .62622 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .41867 .60606 L p .38986 .56976 L .707 .577 .707 r
F P
0 g
s
.39733 .57013 m .38986 .56976 L p .41867 .60606 L .707 .577 .707 r
F P
0 g
s
.33421 .26438 m .37517 .25383 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .33421 .26438 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .39074 .77884 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .42437 .76715 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38986 .56976 m .38524 .62464 L .41264 .626 L p .707 .577 .707 r
F P
0 g
s
.41264 .626 m .41698 .62622 L p .40018 .59125 L .707 .577 .707 r
F P
0 g
s
.40018 .59125 m .38986 .56976 L .41264 .626 L .707 .577 .707 r
F
.33421 .26438 m .38546 .55016 L p .35684 .4703 L F P
0 g
s
.63637 .62733 m .64099 .57245 L .63814 .5627 L p .707 .577 .707 r
F P
0 g
s
.46275 .24004 m .5529 .74281 L .50962 .74821 L p .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .41946 .24544 L .46275 .24004 L p .707 .577 .707 r
F P
0 g
s
.63666 .64336 m .63156 .67948 L .64394 .69045 L p .707 .577 .707 r
F P
0 g
s
.80558 .73371 m .80297 .75176 L .81928 .74509 L p .707 .577 .707 r
F P
0 g
s
.81928 .74509 m .8219 .72704 L .80558 .73371 L p .707 .577 .707 r
F P
0 g
s
.63959 .72677 m .64221 .70872 L .62984 .69767 L p .707 .577 .707 r
F P
0 g
s
.82882 .67205 m .82372 .70818 L .83085 .69913 L p .707 .577 .707 r
F P
0 g
s
.83085 .69913 m .83595 .663 L .82882 .67205 L p .707 .577 .707 r
F P
0 g
s
.63814 .5627 m .63352 .61758 L .63637 .62733 L p .707 .577 .707 r
F P
0 g
s
.62984 .69767 m .62722 .71572 L .63959 .72677 L p .707 .577 .707 r
F P
0 g
s
.63156 .67948 m .63666 .64336 L .6339 .63283 L p .707 .577 .707 r
F P
0 g
s
.84137 .58242 m .83675 .6373 L .8339 .62756 L p .707 .577 .707 r
F P
0 g
s
.8339 .62756 m .83852 .57268 L .84137 .58242 L p .707 .577 .707 r
F P
0 g
s
.63352 .61758 m .63814 .5627 L .64524 .55393 L p .707 .577 .707 r
F P
0 g
s
.6339 .63283 m .6288 .66896 L .63156 .67948 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.8219 .72704 m .81928 .74509 L .82642 .73603 L p .707 .577 .707 r
F P
0 g
s
.82642 .73603 m .82904 .71798 L .8219 .72704 L p .707 .577 .707 r
F P
0 g
s
.62722 .71572 m .62984 .69767 L .62709 .68709 L p .707 .577 .707 r
F P
0 g
s
.62709 .68709 m .62447 .70514 L .62722 .71572 L p .707 .577 .707 r
F P
0 g
s
.83595 .663 m .83085 .69913 L .82809 .68861 L p .707 .577 .707 r
F P
0 g
s
.82809 .68861 m .83319 .65248 L .83595 .663 L p .707 .577 .707 r
F P
0 g
s
.64524 .55393 m .64062 .6088 L .63352 .61758 L p .707 .577 .707 r
F P
0 g
s
.6288 .66896 m .6339 .63283 L .64104 .62378 L p .707 .577 .707 r
F P
0 g
s
.83852 .57268 m .8339 .62756 L .82139 .6178 L p .707 .577 .707 r
F P
0 g
s
.82139 .6178 m .82601 .56293 L .83852 .57268 L p .707 .577 .707 r
F P
0 g
s
.64062 .6088 m .64524 .55393 L .6616 .54697 L p .707 .577 .707 r
F P
0 g
s
.38524 .62464 m .38986 .56976 L .3588 .56525 L p .707 .577 .707 r
F P
0 g
s
.64104 .62378 m .63593 .65991 L .6288 .66896 L p .707 .577 .707 r
F P
0 g
s
.82904 .71798 m .82642 .73603 L .82367 .72545 L p .707 .577 .707 r
F P
0 g
s
.82367 .72545 m .82629 .7074 L .82904 .71798 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35418 .62013 m .3588 .56525 L .33145 .55824 L p .707 .577 .707 r
F P
0 g
s
.3588 .56525 m .35418 .62013 L .38524 .62464 L p .707 .577 .707 r
F P
0 g
s
.62447 .70514 m .62709 .68709 L .63422 .67803 L p .707 .577 .707 r
F P
0 g
s
.63422 .67803 m .6316 .69607 L .62447 .70514 L p .707 .577 .707 r
F P
0 g
s
.83319 .65248 m .82809 .68861 L .81572 .67764 L p .707 .577 .707 r
F P
0 g
s
.81572 .67764 m .82082 .64151 L .83319 .65248 L p .707 .577 .707 r
F P
0 g
s
.6616 .54697 m .65697 .60185 L .64062 .6088 L p .707 .577 .707 r
F P
0 g
s
.82601 .56293 m .82139 .6178 L .80043 .60899 L p .707 .577 .707 r
F P
0 g
s
.80043 .60899 m .80505 .55411 L .82601 .56293 L p .707 .577 .707 r
F P
0 g
s
.63593 .65991 m .64104 .62378 L .65736 .6171 L p .707 .577 .707 r
F P
0 g
s
.32683 .61312 m .33145 .55824 L .31049 .54943 L p .707 .577 .707 r
F P
0 g
s
.33145 .55824 m .32683 .61312 L .35418 .62013 L p .707 .577 .707 r
F P
0 g
s
.65697 .60185 m .6616 .54697 L .6856 .54252 L p .707 .577 .707 r
F P
0 g
s
.37974 .68915 m .38484 .65302 L .35397 .64681 L p .707 .577 .707 r
F P
0 g
s
.38484 .65302 m .37974 .68915 L .41131 .69226 L p .707 .577 .707 r
F P
0 g
s
.41131 .69226 m .41641 .65613 L .38484 .65302 L p .707 .577 .707 r
F P
0 g
s
.41641 .65613 m .41131 .69226 L .44048 .69197 L p .707 .577 .707 r
F P
0 g
s
.44048 .69197 m .44558 .65584 L .41641 .65613 L p .707 .577 .707 r
F P
0 g
s
.34887 .68294 m .35397 .64681 L .32681 .63811 L p .707 .577 .707 r
F P
0 g
s
.35397 .64681 m .34887 .68294 L .37974 .68915 L p .707 .577 .707 r
F P
0 g
s
.65736 .6171 m .65226 .65323 L .63593 .65991 L p .707 .577 .707 r
F P
0 g
s
.82629 .7074 m .82367 .72545 L .8113 .71439 L p .707 .577 .707 r
F P
0 g
s
.8113 .71439 m .81392 .69635 L .82629 .7074 L p .707 .577 .707 r
F P
0 g
s
.47491 .56538 m .47028 .62026 L .48663 .61331 L p .707 .577 .707 r
F P
0 g
s
.48663 .61331 m .49126 .55843 L .47491 .56538 L p .707 .577 .707 r
F P
0 g
s
.6316 .69607 m .63422 .67803 L .65054 .67136 L p .707 .577 .707 r
F P
0 g
s
.31049 .54943 m .30587 .60431 L .32683 .61312 L p .707 .577 .707 r
F P
0 g
s
.80505 .55411 m .80043 .60899 L .77308 .60199 L p .707 .577 .707 r
F P
0 g
s
.77308 .60199 m .7777 .54711 L .80505 .55411 L p .707 .577 .707 r
F P
0 g
s
.6856 .54252 m .68098 .5974 L .65697 .60185 L p .707 .577 .707 r
F P
0 g
s
.82082 .64151 m .81572 .67764 L .79493 .66729 L p .707 .577 .707 r
F P
0 g
s
.79493 .66729 m .80003 .63117 L .82082 .64151 L p .707 .577 .707 r
F P
0 g
s
.44558 .65584 m .44048 .69197 L .46439 .6883 L p .707 .577 .707 r
F P
0 g
s
.46439 .6883 m .46949 .65217 L .44558 .65584 L p .707 .577 .707 r
F P
0 g
s
.32681 .63811 m .32171 .67423 L .34887 .68294 L p .707 .577 .707 r
F P
0 g
s
.65054 .67136 m .64792 .68941 L .6316 .69607 L p .707 .577 .707 r
F P
0 g
s
.30587 .60431 m .31049 .54943 L .29798 .53968 L p .707 .577 .707 r
F P
0 g
s
.32171 .67423 m .32681 .63811 L .30603 .62776 L p .707 .577 .707 r
F P
0 g
s
.68098 .5974 m .6856 .54252 L .7149 .54101 L p .707 .577 .707 r
F P
0 g
s
.65226 .65323 m .65736 .6171 L .68127 .61343 L p .707 .577 .707 r
F P
0 g
s
.37534 .73564 m .37796 .71759 L .34711 .71126 L p .707 .577 .707 r
F P
0 g
s
.37796 .71759 m .37534 .73564 L .40689 .73885 L p .707 .577 .707 r
F P
0 g
s
.40689 .73885 m .40951 .72081 L .37796 .71759 L p .707 .577 .707 r
F P
0 g
s
.40951 .72081 m .40689 .73885 L .43605 .73864 L p .707 .577 .707 r
F P
0 g
s
.43605 .73864 m .43867 .7206 L .40951 .72081 L p .707 .577 .707 r
F P
0 g
s
.34449 .72931 m .34711 .71126 L .31997 .70244 L p .707 .577 .707 r
F P
0 g
s
.34711 .71126 m .34449 .72931 L .37534 .73564 L p .707 .577 .707 r
F P
0 g
s
.7777 .54711 m .77308 .60199 L .74202 .59747 L p .707 .577 .707 r
F P
0 g
s
.74202 .59747 m .74664 .54259 L .7777 .54711 L p .707 .577 .707 r
F P
0 g
s
.30603 .62776 m .30093 .66389 L .32171 .67423 L p .707 .577 .707 r
F P
0 g
s
.31997 .70244 m .31735 .72049 L .34449 .72931 L p .707 .577 .707 r
F P
0 g
s
.71028 .59589 m .7149 .54101 L .74664 .54259 L p .707 .577 .707 r
F P
0 g
s
.7149 .54101 m .71028 .59589 L .68098 .5974 L p .707 .577 .707 r
F P
0 g
s
.68127 .61343 m .67617 .64956 L .65226 .65323 L p .707 .577 .707 r
F P
0 g
s
.81392 .69635 m .8113 .71439 L .79053 .70395 L p .707 .577 .707 r
F P
0 g
s
.79053 .70395 m .79315 .6859 L .81392 .69635 L p .707 .577 .707 r
F P
0 g
s
.29798 .53968 m .29336 .59455 L .30587 .60431 L p .707 .577 .707 r
F P
0 g
s
.74664 .54259 m .74202 .59747 L .71028 .59589 L p .707 .577 .707 r
F P
0 g
s
.46949 .65217 m .46439 .6883 L .48071 .68162 L p .707 .577 .707 r
F P
0 g
s
.48071 .68162 m .48581 .64549 L .46949 .65217 L p .707 .577 .707 r
F P
0 g
s
.43867 .7206 m .43605 .73864 L .45996 .73503 L p .707 .577 .707 r
F P
0 g
s
.45996 .73503 m .46257 .71698 L .43867 .7206 L p .707 .577 .707 r
F P
0 g
s
.49126 .55843 m .48663 .61331 L .49374 .60453 L p .707 .577 .707 r
F P
0 g
s
.49374 .60453 m .49836 .54965 L .49126 .55843 L p .707 .577 .707 r
F P
0 g
s
.64792 .68941 m .65054 .67136 L .67445 .66775 L p .707 .577 .707 r
F P
0 g
s
.80003 .63117 m .79493 .66729 L .76778 .65859 L p .707 .577 .707 r
F P
0 g
s
.76778 .65859 m .77288 .62246 L .80003 .63117 L p .707 .577 .707 r
F P
0 g
s
.31735 .72049 m .31997 .70244 L .2992 .692 L p .707 .577 .707 r
F P
0 g
s
.67617 .64956 m .68127 .61343 L .71044 .61314 L p .707 .577 .707 r
F P
0 g
s
.30093 .66389 m .30603 .62776 L .29365 .61679 L p .707 .577 .707 r
F P
0 g
s
.67445 .66775 m .67183 .68579 L .64792 .68941 L p .707 .577 .707 r
F P
0 g
s
.29336 .59455 m .29798 .53968 L .29513 .52993 L p .707 .577 .707 r
F P
0 g
s
.2992 .692 m .29658 .71004 L .31735 .72049 L p .707 .577 .707 r
F P
0 g
s
.77288 .62246 m .76778 .65859 L .7369 .65238 L p .707 .577 .707 r
F P
0 g
s
.7369 .65238 m .742 .61625 L .77288 .62246 L p .707 .577 .707 r
F P
0 g
s
.71044 .61314 m .70534 .64927 L .67617 .64956 L p .707 .577 .707 r
F P
0 g
s
.29365 .61679 m .28855 .65292 L .30093 .66389 L p .707 .577 .707 r
F P
0 g
s
.70534 .64927 m .71044 .61314 L .742 .61625 L p .707 .577 .707 r
F P
0 g
s
.79315 .6859 m .79053 .70395 L .76339 .69513 L p .707 .577 .707 r
F P
0 g
s
.76339 .69513 m .76601 .67708 L .79315 .6859 L p .707 .577 .707 r
F P
0 g
s
.742 .61625 m .7369 .65238 L .70534 .64927 L p .707 .577 .707 r
F P
0 g
s
.46257 .71698 m .45996 .73503 L .47627 .72836 L p .707 .577 .707 r
F P
0 g
s
.47627 .72836 m .47889 .71032 L .46257 .71698 L p .707 .577 .707 r
F P
0 g
s
.67183 .68579 m .67445 .66775 L .70361 .66754 L p .707 .577 .707 r
F P
0 g
s
.29658 .71004 m .2992 .692 L .28683 .68094 L p .707 .577 .707 r
F P
0 g
s
.29513 .52993 m .29051 .58481 L .29336 .59455 L p .707 .577 .707 r
F P
0 g
s
.48581 .64549 m .48071 .68162 L .48784 .67257 L p .707 .577 .707 r
F P
0 g
s
.48784 .67257 m .49294 .63644 L .48581 .64549 L p .707 .577 .707 r
F P
0 g
s
.70361 .66754 m .70099 .68558 L .67183 .68579 L p .707 .577 .707 r
F P
0 g
s
.49836 .54965 m .49374 .60453 L .49089 .59479 L p .707 .577 .707 r
F P
0 g
s
.49089 .59479 m .49551 .53991 L .49836 .54965 L p .707 .577 .707 r
F P
0 g
s
.28683 .68094 m .28421 .69899 L .29658 .71004 L p .707 .577 .707 r
F P
0 g
s
.28855 .65292 m .29365 .61679 L .29089 .60627 L p .707 .577 .707 r
F P
0 g
s
.76601 .67708 m .76339 .69513 L .73254 .6888 L p .707 .577 .707 r
F P
0 g
s
.73254 .6888 m .73516 .67075 L .76601 .67708 L p .707 .577 .707 r
F P
0 g
s
.70099 .68558 m .70361 .66754 L .73516 .67075 L p .707 .577 .707 r
F P
0 g
s
.29051 .58481 m .29513 .52993 L .30223 .52115 L p .707 .577 .707 r
F P
0 g
s
.73516 .67075 m .73254 .6888 L .70099 .68558 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29089 .60627 m .28579 .64239 L .28855 .65292 L p .707 .577 .707 r
F P
0 g
s
.47889 .71032 m .47627 .72836 L .48341 .7193 L p .707 .577 .707 r
F P
0 g
s
.48341 .7193 m .48603 .70125 L .47889 .71032 L p .707 .577 .707 r
F P
0 g
s
.28421 .69899 m .28683 .68094 L .28408 .67036 L p .707 .577 .707 r
F P
0 g
s
.30223 .52115 m .29761 .57603 L .29051 .58481 L p .707 .577 .707 r
F P
0 g
s
.49294 .63644 m .48784 .67257 L .48508 .66204 L p .707 .577 .707 r
F P
0 g
s
.48508 .66204 m .49018 .62592 L .49294 .63644 L p .707 .577 .707 r
F P
0 g
s
.28408 .67036 m .28146 .68841 L .28421 .69899 L p .707 .577 .707 r
F P
0 g
s
.49551 .53991 m .49089 .59479 L .47837 .58503 L p .707 .577 .707 r
F P
0 g
s
.47837 .58503 m .483 .53015 L .49551 .53991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28579 .64239 m .29089 .60627 L .29802 .59722 L p .707 .577 .707 r
F P
0 g
s
.29761 .57603 m .30223 .52115 L .31859 .5142 L p .707 .577 .707 r
F P
0 g
s
.29802 .59722 m .29292 .63335 L .28579 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48603 .70125 m .48341 .7193 L .48066 .70872 L p .707 .577 .707 r
F P
0 g
s
.48066 .70872 m .48328 .69067 L .48603 .70125 L p .707 .577 .707 r
F P
0 g
s
.28146 .68841 m .28408 .67036 L .29121 .6613 L p .707 .577 .707 r
F P
0 g
s
.31859 .5142 m .31396 .56908 L .29761 .57603 L p .707 .577 .707 r
F P
0 g
s
.49018 .62592 m .48508 .66204 L .47271 .65107 L p .707 .577 .707 r
F P
0 g
s
.47271 .65107 m .47781 .61495 L .49018 .62592 L p .707 .577 .707 r
F P
0 g
s
.483 .53015 m .47837 .58503 L .45742 .57622 L p .707 .577 .707 r
F P
0 g
s
.45742 .57622 m .46204 .52134 L .483 .53015 L p .707 .577 .707 r
F P
0 g
s
.29121 .6613 m .28859 .67934 L .28146 .68841 L p .707 .577 .707 r
F P
0 g
s
.29292 .63335 m .29802 .59722 L .31435 .59053 L p .707 .577 .707 r
F P
0 g
s
.31396 .56908 m .31859 .5142 L .34259 .50975 L p .707 .577 .707 r
F P
0 g
s
.31435 .59053 m .30925 .62666 L .29292 .63335 L p .707 .577 .707 r
F P
0 g
s
.48328 .69067 m .48066 .70872 L .46829 .69767 L p .707 .577 .707 r
F P
0 g
s
.46829 .69767 m .47091 .67962 L .48328 .69067 L p .707 .577 .707 r
F P
0 g
s
.46204 .52134 m .45742 .57622 L .43007 .56922 L p .707 .577 .707 r
F P
0 g
s
.43007 .56922 m .43469 .51434 L .46204 .52134 L p .707 .577 .707 r
F P
0 g
s
.28859 .67934 m .29121 .6613 L .30753 .65463 L p .707 .577 .707 r
F P
0 g
s
.34259 .50975 m .33796 .56463 L .31396 .56908 L p .707 .577 .707 r
F P
0 g
s
.47781 .61495 m .47271 .65107 L .45192 .64073 L p .707 .577 .707 r
F P
0 g
s
.45192 .64073 m .45702 .6046 L .47781 .61495 L p .707 .577 .707 r
F P
0 g
s
.33796 .56463 m .34259 .50975 L .37189 .50824 L p .707 .577 .707 r
F P
0 g
s
.30925 .62666 m .31435 .59053 L .33826 .58687 L p .707 .577 .707 r
F P
0 g
s
.30753 .65463 m .30491 .67268 L .28859 .67934 L p .707 .577 .707 r
F P
0 g
s
.43469 .51434 m .43007 .56922 L .39901 .5647 L p .707 .577 .707 r
F P
0 g
s
.39901 .5647 m .40363 .50982 L .43469 .51434 L p .707 .577 .707 r
F P
0 g
s
.36727 .56312 m .37189 .50824 L .40363 .50982 L p .707 .577 .707 r
F P
0 g
s
.37189 .50824 m .36727 .56312 L .33796 .56463 L p .707 .577 .707 r
F P
0 g
s
.33826 .58687 m .33316 .62299 L .30925 .62666 L p .707 .577 .707 r
F P
0 g
s
.40363 .50982 m .39901 .5647 L .36727 .56312 L p .707 .577 .707 r
F P
0 g
s
.47091 .67962 m .46829 .69767 L .44752 .68722 L p .707 .577 .707 r
F P
0 g
s
.44752 .68722 m .45014 .66917 L .47091 .67962 L p .707 .577 .707 r
F P
0 g
s
.45702 .6046 m .45192 .64073 L .42476 .63203 L p .707 .577 .707 r
F P
0 g
s
.42476 .63203 m .42986 .5959 L .45702 .6046 L p .707 .577 .707 r
F P
0 g
s
.30491 .67268 m .30753 .65463 L .33144 .65102 L p .707 .577 .707 r
F P
0 g
s
.33316 .62299 m .33826 .58687 L .36743 .58657 L p .707 .577 .707 r
F P
0 g
s
.33144 .65102 m .32882 .66906 L .30491 .67268 L p .707 .577 .707 r
F P
0 g
s
.42986 .5959 m .42476 .63203 L .39389 .62581 L p .707 .577 .707 r
F P
0 g
s
.39389 .62581 m .39899 .58969 L .42986 .5959 L p .707 .577 .707 r
F P
0 g
s
.36743 .58657 m .36233 .6227 L .33316 .62299 L p .707 .577 .707 r
F P
0 g
s
.36233 .6227 m .36743 .58657 L .39899 .58969 L p .707 .577 .707 r
F P
0 g
s
.39899 .58969 m .39389 .62581 L .36233 .6227 L p .707 .577 .707 r
F P
0 g
s
.45014 .66917 m .44752 .68722 L .42038 .6784 L p .707 .577 .707 r
F P
0 g
s
.42038 .6784 m .423 .66035 L .45014 .66917 L p .707 .577 .707 r
F P
0 g
s
.32882 .66906 m .33144 .65102 L .36059 .65081 L p .707 .577 .707 r
F P
0 g
s
.36059 .65081 m .35798 .66885 L .32882 .66906 L p .707 .577 .707 r
F P
0 g
s
.423 .66035 m .42038 .6784 L .38953 .67207 L p .707 .577 .707 r
F P
0 g
s
.38953 .67207 m .39214 .65402 L .423 .66035 L p .707 .577 .707 r
F P
0 g
s
.35798 .66885 m .36059 .65081 L .39214 .65402 L p .707 .577 .707 r
F P
0 g
s
.39214 .65402 m .38953 .67207 L .35798 .66885 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool9002;Ool007ioo`/0
00UJEPL008Aoo`00MGoo2@006eYF0`00PGoo001aOol40002FUH00`00FUIJEP0EFUH00`00FUIJEP0:
FUJ1Ool006eoo`@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo07ioo`00JGoo10002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0OWoo001UOol4000?FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1nOol0065oo`@001=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07ioo`00GWoo0`002UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Ogoo001KOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1mOol005Moo`@000AJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo07eoo`00E7oo0`002EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0OGoo001BOol200000eYF
001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1mOol0051oo`8000=JEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo07eoo`00CWoo0P001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00OWoo
001=Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OWoo001=Ool20007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001m
Ool004aoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001mOol004eoo`9JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001mOol004eoo`9JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07]oo`00CGoo0eYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Ngoo001=Ool3FUH00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1kOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001lOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00O7oo
001=Ool01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001=Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001>Ool3FUH0
0`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1jOol004ioo`=JEP03001J
EUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007]oo`00CWoo0eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Ngoo001>Ool01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8007]oo`00CWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Uo
o`00Cgoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Yoo`00Cgoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001jOol004moo`04001JEUYF0007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001iOol0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001i
Ool0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001@Ool01000FUIJ
EP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00N7oo001AOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP8007Qoo`00DGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Io
o`00DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00
DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00DGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04
001JEUYFFUH2001gOol0059oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1e
Ool0059oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001fOol005=oo`04
001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00MWoo001COol01000FUIJEP001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8007Eoo`00E7oo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8007Aoo`00EGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2001dOol005Eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1bOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1b
Ool005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1bOol0
05Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00Lgoo001FOol01000FUIJEP001UYF3P002EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol0
1P00FUIJEUYF001JEP@00003FUH005YF00IJEP03001JEUYF009JEPX000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo075oo`00EWoo00<005YFFUH0
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol300000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001bOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001bOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
071oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0L7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80075oo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001]oo`T004eoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH2000DOol70004FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`0=Ool50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`0;Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000jOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`09Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000hOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P002Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00P00=7oo001BOol00`00FUH00004FUH01000FUIJEUYF6@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00DWoo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH010000UYF1@000eYF1P001UYF
00<005YFFUH00eYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`06Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool0059oo`04001JEP00
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70007FUH00`00FUH000030002FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00H0
05YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40009FUH00`00FUIJEP02FUH30004
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF009JEP03001J
EUYF0080009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20007Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH30003FUH20008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1goo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF
400000=JEP00FUH02eYF00<005YFFUH00UYF00<005YFFUH00eYF0P000eYF0P0025YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol01Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YFFUIJEP8002eoo`00DWoo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001eYF
00D005YFFUIJEP0000IJEP03001JEP00009JEP8000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo00Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005=o
o`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0
00=JEP05001JEUYFFUH00005FUH01000FUIJEUYF100025YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Goo001COol30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool00`00FUH00003FUH00`00FUIJEP03FUHE0006FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003moo`P000aoo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJ
EP03001JEUYF009JEP<000UJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool0
0`00FUH00003FUH00`00FUH000030005FUH70004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JERioo`00=goo20000eYF00<005YFFUH00UYF2@000goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol00goo00<005YF00000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH^Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP8000YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00=oo`04001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF0P002UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000P001UYF00<005YFFUH01EYF00<005YF
FUH01UYF10001EYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8002ioo`00;Woo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH00eYF40000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF10002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0017oo00H005YFFUIJEP00FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0017oo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00D000MJEP03001JEUYF00AJEP03001JEP00009JEP8002ioo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YF
FUIJEQL000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool01000FUH000000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH015YF00<005YF
FUH00`00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH00003FUH400000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00002eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol00Woo0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH00UYF
0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH005YF1@000UYF00D005YFFUIJEP0000IJEP03001JEUYF00AJEPD000=J
EP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`02Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH2000_Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP000002FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50007
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEPD000UJEP<00003FUH0
05YF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEP0002moo`00;7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH0
0eYF00<005YF00000`001UYF00<005YFFUH015YF10002eYF0`001EYF00L005YFFUIJEP00FUH0000;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH00000031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1@0000=JEP00
FUH025YF00<005YFFUH02EYF00<005YFFUH00P000eYF00@005YFFUIJEP8000aJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo
000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH02EYF
0P000eYF0P0000=JEP00FUH00UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF0000<Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF600035YF00<005YFFUH0
1@000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP000000
0eYF1P000UYF0P000Woo1P000eYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YFFUH00eYF5@001UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH040000eYF00L005YF001JEP00FUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000005YF0`0015YF00<005YFFUH0
0UYF0P001Woo2@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YF00000`001eYF00<005YF00000`000Woo1@0000=o
o`0000000P000UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF100015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00000035YF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP80009JEP<0009JEP03001JEUYF00=JEP8000ioo`T000EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002]oo`03001JEP00009JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00=JEPl000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000aJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00<000EJEP04001JEP00
000EOol400000eYF001JEP05FUH01000FUIJEUYF0P00;goo000[Ool00`00FUH000030005FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40005FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`001UYF00@005YFFUIJEP800003FUH005YF00]J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH@000DOol2
0006FUH01000FUIJEUYF0P00;goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001EYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00
3goo0P000eYF00L005YFFUIJEP00FUH0000_Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEPL000IJEP03001JEUYF00AJEPT0
00AJEP03001JEUYF00EJEP<0009JEP09001JEUYFFUH005YF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@000eoo`800003FUH005YF009JEP03001JEP0002moo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF200000=JEP00FUH01eYF00@005YF001JEP80009JEP03001JEUYF009JEP80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPH000IJEP03001JEUYF00<000=JEP80009JEP8000aJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;Ool20003FUH00`00FUH0000_Ool002]oo`80
00=JEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEPL000=JEP04001JEP000004FUH00`00FUIJ
EP04FUH300000eYF001JEP06FUH01000FUIJEUYF0`000eYF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000007Ool50002FUH2000`Ool002aoo`05001JEUYF001JEP050003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP060005FUH00`00FUIJEP04FUH00`00FUIJEP050004FUH0
0`00FUIJEP0500000eYF001JEP05FUH300000eYF001JEP04FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF1`000UYF00<005YFFUH01000<7oo000/Ool00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
0eYF00000003FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF300000=JEP00FUH01eYF0`001EYF
00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP04001JEUYFFUH70002FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00EJEP05001JEUYFFUH00006FUH0
1000FUIJEUYF50000eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEPH00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0`00<7oo000/Ool20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40006FUH2
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF0`0000=JEP00FUH00UYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0009JEP80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00<000=J
EP03001JEP00031oo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00`000eYF00<005YF00000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH00P000eYF0P000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF1`0025YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`0000AJEP00FUH0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP05FUH200000eYF0000000aOol002]oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEP00
00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00=JEP800003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYF001JEP00FUH000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000aOol002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP04001JEUYFFUH30003FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH20004FUH200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01@00FUIJEUYF00001UYF
1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP05001JEUYFFUH0000bOol0
02]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF008000=JEP03001JEUYF00AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00003FUH300000eYF001JEP05FUH00`00FUH00002FUH50002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0`Ool002Yoo`03001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP06FUH0
0`00FUIJEP040003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH20004FUH00`00FUIJEP0;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00P001UYF00<005YF
FUH00`0017oo2@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP80035oo`00:Woo00<005YF
00000eYF100047oo2@0015YF00<005YFFUH01EYF0`001UYF00<005YFFUH015YF5`000eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000EJEP<0009JEP03001JEUYF009JEP8000Uooa8000Eoo`03001JEUYF0080035oo`00:Woo
00@005YF001JEPD001Eoo`<0009oo`H000IJEP03001JEUYF008000=JEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH00`00FUH000020004FUH20009
Ool5000COol4000aOol002Yoo`04001JEP000002FUH00`00FUIJEP02000BOol50007Ool20004FUH0
0`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006FUH01000FUIJEUYF0`0000AJEP00FUH000Uoo`D001=oo`@0035oo`00:Woo0P00
0eYF00<005YFFUH00eYF0P0047oo1@002Goo0`0000=JEP00FUH015YF1@001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP03001JEUYF00EJEPD000Uoo`<0019oo`80
0003FUH00000039oo`00:Woo0P000eYF00<005YFFUH00eYF00@005YF000000ioo`D000aoo`8000EJ
EP05001JEUYF001JEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF0P0000=JEP00FUH01eYF00@005YFFUIJEPT0015oo`@000=JEP80039oo`00:Woo0P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP<000aoo`<000moo`8000=JEP04001JEUYF0002FUH00`00FUIJEP07
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1@002eYF00<005YFFUH02eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF009JEQ40009J
EP07001JEUYFFUH005YF0000<Woo000[Ool01@00FUIJEUYF00001EYF00<005YFFUH015YF1P006Woo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00EJEP03001JEP0000l000AJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00=JEPT000AJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00<goo000[Ool01@00FUIJEUYF000015YF5`0047oo1@000UYF00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJEP`000MJEP03001JEP00
00H0009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=7oo000/Ool00`00FUH000050003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHG0003FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF20002UYF00<005YFFUH01UYF00<005YFFUH01EYF
10001EYF00<005YFFUH00eYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000003Eoo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH04EYF10001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH015YF00@005YFFUIJEP800003Ool0000000L000AJEP03001J
EUYF00EJEP04001JEUYFFUH5000gOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH03EYF10002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF00EJEP04001JEUYFFUH2000:
Ool@000lOol002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH30006FUH01000FUIJEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP00009oo`8000IJEP04001JEUYFFUH2001FOol002Uoo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH2
000:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005Ool20003FUH01`00FUIJEUYF001JEP0005Io
o`00:Goo00<005YF00000eYF1`001UYF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF0`000UYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04000:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20008Ool200000eYF
001JEP02FUH00`00FUH0001FOol002Uoo`04001JEP00FUH20007Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH30003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH400000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH2000;Ool20003FUH00`00FUH0001FOol002Uoo`04001JEP00000;Ool3
00000eYF001JEP07FUH00`00FUIJEP030003FUH40006FUH00`00FUIJEP02FUH20002FUH00`00Oomo
o`03FUH00`00FUIJEP0:FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`0000=JEP0000001goo1@000UYF0P00Egoo000YOol3000?Ool3
0006FUH00`00FUIJEP050002FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF0`000goo0eYF00<0
05YFFUH01eYF0`0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00@005YF0000009JEP04001JEUYFFUH70002FUH00`00FUIJEP04001GOol002Uoo`800003FUH0
0000011oo`@0009JEP03001JEUYF00D00003FUH005YF00MJEP<000EJEP04001JEP000002Ool01000
FUIJEP001UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF0P00Egoo000YOol00`00FUIJEP02
FUH00`00Oomoo`0AOol:00000eYF001JEP03FUH90003FUH01`00FUIJEUYF001oo`0000MJEP8000=J
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009J
EPD000AJEP03001JEUYF00IJEP<0009JEP04001JEUYFFUH3001GOol002Uoo`03001JEUYF009JEP<0
01Moo`X000Uoo`800003FUH005YF009JEP03001oo`0000EJEP8000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEP00008000EJEPH000MJEP03001JEUYF
00<000=JEP03001JEP0005Moo`00:Goo00<005YFFUH00UYF00<005YFFUH00P00:Woo0P000eYF0`00
0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00
00=JEP00FUH025YF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000Egoo000Z
Ool01000FUIJEP001EYF0P00:Woo00H005YF001JEP00Ool2FUH01000FUIJEP001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF100015YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0P0000=JEP000000F7oo000[Ool00`00FUH00005FUH01000
FUH00000:Goo0P0000EJEP00OomJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJ
EP03001JEP00008005Qoo`00;7oo0P001EYF00@005YFFUIJEP<002Moo`05001JEP00Ool00004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0FFUH400000goo000000030006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH000000eYF00D005YFFUIJEP0005Uoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF10008Woo0`000Woo00<005YFFUH00UYF00<005YFFUH07UYF00<005YFFUH0
15YF10002Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00UYF00<007ooOol0Egoo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20000
0eYF00000003Ool5FUH00`00FUIJEP0@FUH00`00FUIJEP0:FUH00`00FUIJEP06000@Ool70004FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@000eYF0P00F7oo000`Ool200000eYF001JEP06FUH00`00FUIJ
EP04FUH7000@Ool50003FUH20003Ool30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH:0005FUH3000COolA0005Ool00`00FUIJEP02001HOol0039oo`<000EJEP03001JEUYF00MJ
EP03001JEUYF009JEQ0000=JEP04001JEUYFFUH20007Ool60004FUH00`00FUIJEP03FUH<0008Ool2
0006FUH01000FUH0000047oo1@004goo1000F7oo000eOol400000eYF001JEP08FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P003Goo2P005Goo00<005YFFUH015YF
00@005YFFUIJEP<000eoo`D001=oo`@005Qoo`00>Goo10001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`8000=JEP03001JEUYF00EJEPD000Qoo`D0015o
o`800003FUH0000005Uoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF0000039oo`800003FUH005YF00MJEP04001JEUYFFUH<000>Ool40003FUH2001IOol0
045oo`L000AJEP03001JEUYF00EJEP04001JEUYFFUH5000fOol30007FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHA0002FUH01`00FUIJEUYF001JEP0005Uoo`00B7oo4000?Woo0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Yoo`00V7oo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Yoo`00Vgoo10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P00Fgoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00GGoo
002SOol70004FUH00`00FUIJEP02FUH7001SOol00:Yoo`T006Yoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5878 .7493 m .59527 .69506 L .56438 .68895 L p .707 .577 .707 r
F P
0 g
s
.59527 .69506 m .5878 .7493 L .61938 .75232 L p .707 .577 .707 r
F P
0 g
s
.61938 .75232 m .62685 .69808 L .59527 .69506 L p .707 .577 .707 r
F P
0 g
s
.62685 .69808 m .61938 .75232 L .64856 .75195 L p .707 .577 .707 r
F P
0 g
s
.64856 .75195 m .65602 .69771 L .62685 .69808 L p .707 .577 .707 r
F P
0 g
s
.55692 .74319 m .56438 .68895 L .53721 .68035 L p .707 .577 .707 r
F P
0 g
s
.56438 .68895 m .55692 .74319 L .5878 .7493 L p .707 .577 .707 r
F P
0 g
s
.65602 .69771 m .64856 .75195 L .67248 .74824 L p .707 .577 .707 r
F P
0 g
s
.67248 .74824 m .67994 .694 L .65602 .69771 L p .707 .577 .707 r
F P
0 g
s
.52974 .73459 m .53721 .68035 L .51641 .6701 L p .707 .577 .707 r
F P
0 g
s
.53721 .68035 m .52974 .73459 L .55692 .74319 L p .707 .577 .707 r
F P
0 g
s
.57874 .80619 m .58694 .77101 L .55656 .7622 L p .707 .577 .707 r
F P
0 g
s
.58694 .77101 m .57874 .80619 L .60986 .81164 L p .707 .577 .707 r
F P
0 g
s
.60986 .81164 m .61807 .77646 L .58694 .77101 L p .707 .577 .707 r
F P
0 g
s
.54835 .79739 m .55656 .7622 L .52988 .75091 L p .707 .577 .707 r
F P
0 g
s
.55656 .7622 m .54835 .79739 L .57874 .80619 L p .707 .577 .707 r
F P
0 g
s
.61807 .77646 m .60986 .81164 L .63869 .81321 L p .707 .577 .707 r
F P
0 g
s
.63869 .81321 m .64689 .77803 L .61807 .77646 L p .707 .577 .707 r
F P
0 g
s
.67994 .694 m .67248 .74824 L .6888 .74153 L p .707 .577 .707 r
F P
0 g
s
.6888 .74153 m .69627 .6873 L .67994 .694 L p .707 .577 .707 r
F P
0 g
s
.51641 .6701 m .50895 .72434 L .52974 .73459 L p .707 .577 .707 r
F P
0 g
s
.50895 .72434 m .51641 .6701 L .50402 .6592 L p .707 .577 .707 r
F P
0 g
s
.52988 .75091 m .52168 .78609 L .54835 .79739 L p .707 .577 .707 r
F P
0 g
s
.52168 .78609 m .52988 .75091 L .50953 .73822 L p .707 .577 .707 r
F P
0 g
s
.64689 .77803 m .63869 .81321 L .66238 .81073 L p .707 .577 .707 r
F P
0 g
s
.66238 .81073 m .67058 .77555 L .64689 .77803 L p .707 .577 .707 r
F P
0 g
s
.57159 .83972 m .5758 .82217 L .54546 .81318 L p .707 .577 .707 r
F P
0 g
s
.5758 .82217 m .57159 .83972 L .60268 .84534 L p .707 .577 .707 r
F P
0 g
s
.60268 .84534 m .60689 .82779 L .5758 .82217 L p .707 .577 .707 r
F P
0 g
s
.54125 .83073 m .54546 .81318 L .51883 .8017 L p .707 .577 .707 r
F P
0 g
s
.54546 .81318 m .54125 .83073 L .57159 .83972 L p .707 .577 .707 r
F P
0 g
s
.60689 .82779 m .60268 .84534 L .63147 .84703 L p .707 .577 .707 r
F P
0 g
s
.63147 .84703 m .63568 .82948 L .60689 .82779 L p .707 .577 .707 r
F P
0 g
s
.51883 .8017 m .51461 .81925 L .54125 .83073 L p .707 .577 .707 r
F P
0 g
s
.50953 .73822 m .50133 .77341 L .52168 .78609 L p .707 .577 .707 r
F P
0 g
s
.50402 .6592 m .49656 .71344 L .50895 .72434 L p .707 .577 .707 r
F P
0 g
s
.51461 .81925 m .51883 .8017 L .49852 .78886 L p .707 .577 .707 r
F P
0 g
s
.63568 .82948 m .63147 .84703 L .65514 .84464 L p .707 .577 .707 r
F P
0 g
s
.65514 .84464 m .65935 .82709 L .63568 .82948 L p .707 .577 .707 r
F P
0 g
s
.50133 .77341 m .50953 .73822 L .4975 .7254 L p .707 .577 .707 r
F P
0 g
s
.67058 .77555 m .66238 .81073 L .67862 .80446 L p .707 .577 .707 r
F P
0 g
s
.67862 .80446 m .68683 .76928 L .67058 .77555 L p .707 .577 .707 r
F P
0 g
s
.69627 .6873 m .6888 .74153 L .69593 .7325 L p .707 .577 .707 r
F P
0 g
s
.69593 .7325 m .7034 .67826 L .69627 .6873 L p .707 .577 .707 r
F P
0 g
s
.49852 .78886 m .49431 .80641 L .51461 .81925 L p .707 .577 .707 r
F P
0 g
s
.49656 .71344 m .50402 .6592 L .50126 .64873 L p .707 .577 .707 r
F P
0 g
s
.4975 .7254 m .4893 .76058 L .50133 .77341 L p .707 .577 .707 r
F P
0 g
s
.49431 .80641 m .49852 .78886 L .48652 .7759 L p .707 .577 .707 r
F P
0 g
s
.65935 .82709 m .65514 .84464 L .67138 .8384 L p .707 .577 .707 r
F P
0 g
s
.67138 .8384 m .67559 .82085 L .65935 .82709 L p .707 .577 .707 r
F P
0 g
s
.50126 .64873 m .49379 .70297 L .49656 .71344 L p .707 .577 .707 r
F P
0 g
s
.48652 .7759 m .48231 .79345 L .49431 .80641 L p .707 .577 .707 r
F P
0 g
s
.4893 .76058 m .4975 .7254 L .49497 .71368 L p .707 .577 .707 r
F P
0 g
s
.68683 .76928 m .67862 .80446 L .68583 .795 L p .707 .577 .707 r
F P
0 g
s
.68583 .795 m .69404 .75982 L .68683 .76928 L p .707 .577 .707 r
F P
0 g
s
.7034 .67826 m .69593 .7325 L .69317 .72203 L p .707 .577 .707 r
F P
0 g
s
.69317 .72203 m .70063 .66779 L .7034 .67826 L p .707 .577 .707 r
F P
0 g
s
.49379 .70297 m .50126 .64873 L .50839 .6397 L p .707 .577 .707 r
F P
0 g
s
.49497 .71368 m .48676 .74886 L .4893 .76058 L p .707 .577 .707 r
F P
0 g
s
.48231 .79345 m .48652 .7759 L .484 .7641 L p .707 .577 .707 r
F P
0 g
s
.67559 .82085 m .67138 .8384 L .67859 .82891 L p .707 .577 .707 r
F P
0 g
s
.67859 .82891 m .68281 .81136 L .67559 .82085 L p .707 .577 .707 r
F P
0 g
s
.484 .7641 m .47979 .78165 L .48231 .79345 L p .707 .577 .707 r
F P
0 g
s
.50839 .6397 m .50092 .69394 L .49379 .70297 L p .707 .577 .707 r
F P
0 g
s
.48676 .74886 m .49497 .71368 L .50217 .70422 L p .707 .577 .707 r
F P
0 g
s
.69404 .75982 m .68583 .795 L .68329 .78328 L p .707 .577 .707 r
F P
0 g
s
.68329 .78328 m .6915 .7481 L .69404 .75982 L p .707 .577 .707 r
F P
0 g
s
.70063 .66779 m .69317 .72203 L .68078 .71113 L p .707 .577 .707 r
F P
0 g
s
.68078 .71113 m .68824 .65689 L .70063 .66779 L p .707 .577 .707 r
F P
0 g
s
.50092 .69394 m .50839 .6397 L .52471 .633 L p .707 .577 .707 r
F P
0 g
s
.50217 .70422 m .49397 .7394 L .48676 .74886 L p .707 .577 .707 r
F P
0 g
s
.24479 .71903 m .25226 .66479 L .22137 .65868 L p .707 .577 .707 r
F P
0 g
s
.25226 .66479 m .24479 .71903 L .27637 .72205 L p .707 .577 .707 r
F P
0 g
s
.27637 .72205 m .28384 .66781 L .25226 .66479 L p .707 .577 .707 r
F P
0 g
s
.28384 .66781 m .27637 .72205 L .30555 .72168 L p .707 .577 .707 r
F P
0 g
s
.30555 .72168 m .31301 .66744 L .28384 .66781 L p .707 .577 .707 r
F P
0 g
s
.47979 .78165 m .484 .7641 L .49122 .75461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21391 .71292 m .22137 .65868 L .1942 .65008 L p .707 .577 .707 r
F P
0 g
s
.22137 .65868 m .21391 .71292 L .24479 .71903 L p .707 .577 .707 r
F P
0 g
s
.68281 .81136 m .67859 .82891 L .67608 .81711 L p .707 .577 .707 r
F P
0 g
s
.67608 .81711 m .68029 .79956 L .68281 .81136 L p .707 .577 .707 r
F P
0 g
s
.49122 .75461 m .487 .77216 L .47979 .78165 L p .707 .577 .707 r
F P
0 g
s
.52471 .633 m .51725 .68723 L .50092 .69394 L p .707 .577 .707 r
F P
0 g
s
.49397 .7394 m .50217 .70422 L .51842 .69795 L p .707 .577 .707 r
F P
0 g
s
.6915 .7481 m .68329 .78328 L .67126 .77046 L p .707 .577 .707 r
F P
0 g
s
.67126 .77046 m .67947 .73527 L .6915 .7481 L p .707 .577 .707 r
F P
0 g
s
.31301 .66744 m .30555 .72168 L .32947 .71796 L p .707 .577 .707 r
F P
0 g
s
.32947 .71796 m .33694 .66372 L .31301 .66744 L p .707 .577 .707 r
F P
0 g
s
.68824 .65689 m .68078 .71113 L .65998 .70088 L p .707 .577 .707 r
F P
0 g
s
.65998 .70088 m .66745 .64664 L .68824 .65689 L p .707 .577 .707 r
F P
0 g
s
.18674 .70432 m .1942 .65008 L .1734 .63983 L p .707 .577 .707 r
F P
0 g
s
.1942 .65008 m .18674 .70432 L .21391 .71292 L p .707 .577 .707 r
F P
0 g
s
.51725 .68723 m .52471 .633 L .54863 .62928 L p .707 .577 .707 r
F P
0 g
s
.48678 .79716 m .34228 .30268 L .30016 .31302 L p .707 .577 .707 r
F P
0 g
s
.51842 .69795 m .51021 .73313 L .49397 .7394 L p .707 .577 .707 r
F P
0 g
s
.487 .77216 m .49122 .75461 L .50746 .74836 L p .707 .577 .707 r
F P
0 g
s
.50746 .74836 m .50324 .76592 L .487 .77216 L p .707 .577 .707 r
F P
0 g
s
.50324 .76592 m .50746 .74836 L .53113 .74597 L p .707 .577 .707 r
F P
0 g
s
.53113 .74597 m .52691 .76353 L .50324 .76592 L p .707 .577 .707 r
F P
0 g
s
.34228 .30268 m .48678 .79716 L .53002 .78431 L p .707 .577 .707 r
F P
0 g
s
.51021 .73313 m .51842 .69795 L .54211 .69547 L p .707 .577 .707 r
F P
0 g
s
.54211 .69547 m .53391 .73065 L .51021 .73313 L p .707 .577 .707 r
F P
0 g
s
.53002 .78431 m .38552 .28983 L .34228 .30268 L p .707 .577 .707 r
F P
0 g
s
.54863 .62928 m .54117 .68352 L .51725 .68723 L p .707 .577 .707 r
F P
0 g
s
.53391 .73065 m .54211 .69547 L .57093 .69704 L p .707 .577 .707 r
F P
0 g
s
.57093 .69704 m .56273 .73222 L .53391 .73065 L p .707 .577 .707 r
F P
0 g
s
.52691 .76353 m .53113 .74597 L .55992 .74767 L p .707 .577 .707 r
F P
0 g
s
.55992 .74767 m .5557 .76522 L .52691 .76353 L p .707 .577 .707 r
F P
0 g
s
.5557 .76522 m .55992 .74767 L .59101 .75328 L p .707 .577 .707 r
F P
0 g
s
.59101 .75328 m .58679 .77084 L .5557 .76522 L p .707 .577 .707 r
F P
0 g
s
.38552 .28983 m .53002 .78431 L .57014 .77021 L p .707 .577 .707 r
F P
0 g
s
.54117 .68352 m .54863 .62928 L .57781 .62891 L p .707 .577 .707 r
F P
0 g
s
.57781 .62891 m .57035 .68315 L .54117 .68352 L p .707 .577 .707 r
F P
0 g
s
.57014 .77021 m .42565 .27573 L .38552 .28983 L p .707 .577 .707 r
F P
0 g
s
.23573 .78596 m .24393 .75078 L .21355 .74198 L p .707 .577 .707 r
F P
0 g
s
.24393 .75078 m .23573 .78596 L .26686 .79141 L p .707 .577 .707 r
F P
0 g
s
.26686 .79141 m .27506 .75623 L .24393 .75078 L p .707 .577 .707 r
F P
0 g
s
.20534 .77716 m .21355 .74198 L .18687 .73068 L p .707 .577 .707 r
F P
0 g
s
.21355 .74198 m .20534 .77716 L .23573 .78596 L p .707 .577 .707 r
F P
0 g
s
.27506 .75623 m .26686 .79141 L .29568 .79298 L p .707 .577 .707 r
F P
0 g
s
.29568 .79298 m .30388 .7578 L .27506 .75623 L p .707 .577 .707 r
F P
0 g
s
.68029 .79956 m .67608 .81711 L .66408 .80415 L p .707 .577 .707 r
F P
0 g
s
.66408 .80415 m .66829 .7866 L .68029 .79956 L p .707 .577 .707 r
F P
0 g
s
.44466 .80751 m .30016 .31302 L .26329 .31985 L p .707 .577 .707 r
F P
0 g
s
.30016 .31302 m .44466 .80751 L .48678 .79716 L p .707 .577 .707 r
F P
0 g
s
.33694 .66372 m .32947 .71796 L .34579 .71126 L p .707 .577 .707 r
F P
0 g
s
.34579 .71126 m .35326 .65702 L .33694 .66372 L p .707 .577 .707 r
F P
0 g
s
.1734 .63983 m .16594 .69407 L .18674 .70432 L p .707 .577 .707 r
F P
0 g
s
.66745 .64664 m .65998 .70088 L .63281 .69228 L p .707 .577 .707 r
F P
0 g
s
.63281 .69228 m .64027 .63804 L .66745 .64664 L p .707 .577 .707 r
F P
0 g
s
.57035 .68315 m .57781 .62891 L .60939 .63193 L p .707 .577 .707 r
F P
0 g
s
.60939 .63193 m .60192 .68617 L .57035 .68315 L p .707 .577 .707 r
F P
0 g
s
.56273 .73222 m .57093 .69704 L .60206 .70249 L p .707 .577 .707 r
F P
0 g
s
.63245 .71129 m .62424 .74648 L .59385 .73767 L p .707 .577 .707 r
F P
0 g
s
.59385 .73767 m .60206 .70249 L .63245 .71129 L p .707 .577 .707 r
F P
0 g
s
.60206 .70249 m .59385 .73767 L .56273 .73222 L p .707 .577 .707 r
F P
0 g
s
.58679 .77084 m .59101 .75328 L .62135 .76227 L p .707 .577 .707 r
F P
0 g
s
.42565 .27573 m .57014 .77021 L .60323 .75625 L p .707 .577 .707 r
F P
0 g
s
.60323 .75625 m .45874 .26176 L .42565 .27573 L p .707 .577 .707 r
F P
0 g
s
.16594 .69407 m .1734 .63983 L .16102 .62893 L p .707 .577 .707 r
F P
0 g
s
.67947 .73527 m .67126 .77046 L .65092 .75777 L p .707 .577 .707 r
F P
0 g
s
.65092 .75777 m .65912 .72259 L .67947 .73527 L p .707 .577 .707 r
F P
0 g
s
.18687 .73068 m .17867 .76586 L .20534 .77716 L p .707 .577 .707 r
F P
0 g
s
.17867 .76586 m .18687 .73068 L .16653 .71799 L p .707 .577 .707 r
F P
0 g
s
.30388 .7578 m .29568 .79298 L .31937 .7905 L p .707 .577 .707 r
F P
0 g
s
.31937 .7905 m .32758 .75532 L .30388 .7578 L p .707 .577 .707 r
F P
0 g
s
.22858 .83541 m .23279 .81786 L .20245 .80887 L p .707 .577 .707 r
F P
0 g
s
.23279 .81786 m .22858 .83541 L .25967 .84103 L p .707 .577 .707 r
F P
0 g
s
.25967 .84103 m .26388 .82347 L .23279 .81786 L p .707 .577 .707 r
F P
0 g
s
.64027 .63804 m .63281 .69228 L .60192 .68617 L p .707 .577 .707 r
F P
0 g
s
.60192 .68617 m .60939 .63193 L .64027 .63804 L p .707 .577 .707 r
F P
0 g
s
.19824 .82642 m .20245 .80887 L .17582 .79739 L p .707 .577 .707 r
F P
0 g
s
.20245 .80887 m .19824 .82642 L .22858 .83541 L p .707 .577 .707 r
F P
0 g
s
.26388 .82347 m .25967 .84103 L .28846 .84272 L p .707 .577 .707 r
F P
0 g
s
.28846 .84272 m .29267 .82517 L .26388 .82347 L p .707 .577 .707 r
F P
0 g
s
.16653 .71799 m .15832 .75318 L .17867 .76586 L p .707 .577 .707 r
F P
0 g
s
.16102 .62893 m .15355 .68317 L .16594 .69407 L p .707 .577 .707 r
F P
0 g
s
.35326 .65702 m .34579 .71126 L .35292 .70223 L p .707 .577 .707 r
F P
0 g
s
.35292 .70223 m .36039 .64799 L .35326 .65702 L p .707 .577 .707 r
F P
0 g
s
.36039 .64799 m .35292 .70223 L .35099 .6949 L p .707 .577 .707 r
F P
0 g
s
.35099 .6949 m .35016 .69175 L p .35376 .67633 L .707 .577 .707 r
F P
0 g
s
.35376 .67633 m .36039 .64799 L .35099 .6949 L .707 .577 .707 r
F
.40778 .81434 m .44466 .80751 L p .36584 .59557 L F P
0 g
s
.26329 .31985 m .3584 .64533 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.35016 .69175 m .3515 .68198 L p .36039 .64799 L .707 .577 .707 r
F P
0 g
s
.26329 .31985 m .23527 .32249 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .26329 .31985 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.35893 .64248 m .36039 .64799 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .40778 .81434 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .34459 .69663 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35016 .69175 L .34785 .68972 L p .707 .577 .707 r
F P
0 g
s
.34459 .69663 m .37976 .81698 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .21884 .32069 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .35371 .72782 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.35371 .72782 m .23527 .32249 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32778 .67594 m .32205 .67311 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.32205 .67311 m .31697 .67061 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .32155 .66348 L .32205 .67311 L .707 .577 .707 r
F
.21884 .32069 m .21562 .31462 L p .2962 .58767 L F P
0 g
s
.34282 .77477 m .35103 .73959 L .34382 .74905 L p .707 .577 .707 r
F P
0 g
s
.33561 .78423 m .34382 .74905 L .32758 .75532 L p .707 .577 .707 r
F P
0 g
s
.34382 .74905 m .33561 .78423 L .34282 .77477 L p .707 .577 .707 r
F P
0 g
s
.35103 .73959 m .34282 .77477 L .34028 .76306 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .34849 .72787 L .35103 .73959 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .32825 .75023 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34849 .72787 m .34439 .74544 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34439 .74544 m .34028 .76306 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .31873 .65783 L .32155 .66348 L .707 .577 .707 r
F
.31697 .67061 m .31832 .66079 L p .31991 .66604 L F P
0 g
s
.31832 .66079 m .31873 .65783 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .33646 .71505 L .34849 .72787 L p .707 .577 .707 r
F P
0 g
s
.31697 .67061 m .2898 .66201 L p .3106 .6346 L .707 .577 .707 r
F P
0 g
s
.3106 .6346 m .31136 .63718 L .31697 .67061 L .707 .577 .707 r
F
.31873 .65783 m .31697 .67061 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .21884 .32069 L p .26526 .48089 L .707 .577 .707 r
F P
0 g
s
.21884 .32069 m .30766 .62464 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.34558 .71155 m .30766 .62464 L .31873 .65783 L .707 .577 .707 r
F
.2898 .66201 m .29727 .60777 L .32444 .61637 L p F P
0 g
s
.31542 .6512 m .30766 .62464 L p .2962 .58767 L .707 .577 .707 r
F P
0 g
s
.30766 .62464 m .26526 .48089 L .2962 .58767 L .707 .577 .707 r
F
.3106 .6346 m .31087 .63425 L .31136 .63718 L F
.32444 .61637 m .31873 .65783 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .31542 .6512 L p .31873 .65783 L .707 .577 .707 r
F P
0 g
s
.21562 .31462 m .22592 .30488 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .32602 .74884 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.3214 .72691 m .33501 .71619 L .32602 .74884 L .707 .577 .707 r
F
.33646 .71505 m .33568 .7184 L p .33501 .71619 L F P
0 g
s
.33568 .7184 m .32825 .75023 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .31611 .70236 L .33424 .71366 L p .707 .577 .707 r
F P
0 g
s
.33424 .71366 m .33646 .71505 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .33424 .71366 L .33501 .71619 L .707 .577 .707 r
F
.27313 .51142 m .28343 .54666 L p .2962 .58767 L F P
0 g
s
.28343 .54666 m .36012 .8091 L p .30166 .60659 L .707 .577 .707 r
F P
0 g
s
.2962 .58767 m .28343 .54666 L .30166 .60659 L .707 .577 .707 r
F
.36012 .8091 m .36334 .81518 L p .30572 .61994 L F P
0 g
s
.30572 .61994 m .2962 .58767 L .30166 .60659 L .707 .577 .707 r
F
.30572 .61994 m .30166 .60659 L .36012 .8091 L F
.21562 .31462 m .27313 .51142 L p .2962 .58767 L F P
0 g
s
.325 .68525 m .31542 .6512 L .2962 .58767 L .707 .577 .707 r
F
.36334 .81518 m .32902 .69774 L p .325 .68525 L F P
0 g
s
.32902 .69774 m .31542 .6512 L p .325 .68525 L .707 .577 .707 r
F P
0 g
s
.31542 .6512 m .36334 .81518 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.31873 .65783 m .32444 .61637 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.36012 .8091 m .28343 .54666 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.28343 .54666 m .21562 .31462 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32602 .74884 m .30791 .73754 L p .3214 .72691 L .707 .577 .707 r
F P
0 g
s
.36334 .81518 m .37976 .81698 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32444 .61637 m .34523 .62662 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.34523 .62662 m .33777 .68086 L .32778 .67594 L p .707 .577 .707 r
F P
0 g
s
.32155 .66348 m .34523 .62662 L .32778 .67594 L .707 .577 .707 r
F
.35762 .63752 m .3515 .68198 L p .33777 .68086 L F P
0 g
s
.34785 .68972 m .33777 .68086 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35762 .63752 L .35893 .64248 L p .707 .577 .707 r
F P
0 g
s
.40778 .81434 m .3584 .64533 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .40778 .81434 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.17582 .79739 m .17161 .81494 L .19824 .82642 L p .707 .577 .707 r
F P
0 g
s
.66829 .7866 m .66408 .80415 L .64377 .7913 L p .707 .577 .707 r
F P
0 g
s
.64377 .7913 m .64798 .77375 L .66829 .7866 L p .707 .577 .707 r
F P
0 g
s
.65912 .72259 m .65092 .75777 L .62424 .74648 L p .707 .577 .707 r
F P
0 g
s
.62424 .74648 m .63245 .71129 L .65912 .72259 L p .707 .577 .707 r
F P
0 g
s
.15832 .75318 m .16653 .71799 L .15449 .70517 L p .707 .577 .707 r
F P
0 g
s
.32758 .75532 m .31937 .7905 L .33561 .78423 L p .707 .577 .707 r
F P
0 g
s
.45874 .26176 m .60323 .75625 L .62604 .74378 L p .707 .577 .707 r
F P
0 g
s
.62604 .74378 m .48155 .2493 L .45874 .26176 L p .707 .577 .707 r
F P
0 g
s
.17161 .81494 m .17582 .79739 L .15551 .78454 L p .707 .577 .707 r
F P
0 g
s
.29267 .82517 m .28846 .84272 L .31213 .84033 L p .707 .577 .707 r
F P
0 g
s
.31213 .84033 m .31634 .82278 L .29267 .82517 L p .707 .577 .707 r
F P
0 g
s
.15355 .68317 m .16102 .62893 L .15825 .61846 L p .707 .577 .707 r
F P
0 g
s
.15551 .78454 m .1513 .80209 L .17161 .81494 L p .707 .577 .707 r
F P
0 g
s
.15449 .70517 m .14629 .74035 L .15832 .75318 L p .707 .577 .707 r
F P
0 g
s
.64798 .77375 m .64377 .7913 L .61714 .77983 L p .707 .577 .707 r
F P
0 g
s
.61714 .77983 m .62135 .76227 L .64798 .77375 L p .707 .577 .707 r
F P
0 g
s
.15825 .61846 m .15078 .67269 L .15355 .68317 L p .707 .577 .707 r
F P
0 g
s
.1513 .80209 m .15551 .78454 L .14351 .77158 L p .707 .577 .707 r
F P
0 g
s
.31634 .82278 m .31213 .84033 L .32837 .83408 L p .707 .577 .707 r
F P
0 g
s
.32837 .83408 m .33258 .81653 L .31634 .82278 L p .707 .577 .707 r
F P
0 g
s
.14629 .74035 m .15449 .70517 L .15196 .69345 L p .707 .577 .707 r
F P
0 g
s
.14351 .77158 m .1393 .78914 L .1513 .80209 L p .707 .577 .707 r
F P
0 g
s
.62135 .76227 m .61714 .77983 L .58679 .77084 L p .707 .577 .707 r
F P
0 g
s
.15078 .67269 m .15825 .61846 L .16538 .60942 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.48155 .2493 m .62604 .74378 L .63634 .73404 L p .707 .577 .707 r
F P
0 g
s
.63634 .73404 m .49185 .23955 L .48155 .2493 L p .707 .577 .707 r
F P
0 g
s
.15196 .69345 m .14375 .72863 L .14629 .74035 L p .707 .577 .707 r
F P
0 g
s
.1393 .78914 m .14351 .77158 L .14099 .75978 L p .707 .577 .707 r
F P
0 g
s
.33258 .81653 m .32837 .83408 L .33558 .8246 L p .707 .577 .707 r
F P
0 g
s
.33558 .8246 m .3398 .80705 L .33258 .81653 L p .707 .577 .707 r
F P
0 g
s
.16538 .60942 m .15791 .66366 L .15078 .67269 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14375 .72863 m .15196 .69345 L .15917 .68399 L p .707 .577 .707 r
F P
0 g
s
.14099 .75978 m .13678 .77734 L .1393 .78914 L p .707 .577 .707 r
F P
0 g
s
.33777 .68086 m .34523 .62662 L .35762 .63752 L p .707 .577 .707 r
F P
0 g
s
.15791 .66366 m .16538 .60942 L .1817 .60272 L p .707 .577 .707 r
F P
0 g
s
.15917 .68399 m .15096 .71918 L .14375 .72863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13678 .77734 m .14099 .75978 L .14821 .7503 L p .707 .577 .707 r
F P
0 g
s
.49185 .23955 m .63634 .73404 L .63312 .72797 L p .707 .577 .707 r
F P
0 g
s
.63312 .72797 m .48863 .23348 L .49185 .23955 L p .707 .577 .707 r
F P
0 g
s
.3398 .80705 m .33558 .8246 L .33307 .8128 L p .707 .577 .707 r
F P
0 g
s
.33307 .8128 m .33728 .79525 L .3398 .80705 L p .707 .577 .707 r
F P
0 g
s
.1817 .60272 m .17424 .65696 L .15791 .66366 L p .707 .577 .707 r
F P
0 g
s
.14821 .7503 m .14399 .76785 L .13678 .77734 L p .707 .577 .707 r
F P
0 g
s
.15096 .71918 m .15917 .68399 L .17541 .67772 L p .707 .577 .707 r
F P
0 g
s
.17424 .65696 m .1817 .60272 L .20562 .59901 L p .707 .577 .707 r
F P
0 g
s
.17541 .67772 m .1672 .7129 L .15096 .71918 L p .707 .577 .707 r
F P
0 g
s
.20562 .59901 m .19816 .65325 L .17424 .65696 L p .707 .577 .707 r
F P
0 g
s
.14399 .76785 m .14821 .7503 L .16445 .74405 L p .707 .577 .707 r
F P
0 g
s
.33728 .79525 m .33307 .8128 L .32107 .79984 L p .707 .577 .707 r
F P
0 g
s
.32107 .79984 m .32528 .78229 L .33728 .79525 L p .707 .577 .707 r
F P
0 g
s
.19816 .65325 m .20562 .59901 L .2348 .59864 L p .707 .577 .707 r
F P
0 g
s
.1672 .7129 m .17541 .67772 L .1991 .67524 L p .707 .577 .707 r
F P
0 g
s
.16445 .74405 m .16023 .7616 L .14399 .76785 L p .707 .577 .707 r
F P
0 g
s
.29727 .60777 m .2898 .66201 L .25891 .6559 L p .707 .577 .707 r
F P
0 g
s
.25891 .6559 m .26638 .60166 L .29727 .60777 L p .707 .577 .707 r
F P
0 g
s
.22734 .65288 m .2348 .59864 L .26638 .60166 L p .707 .577 .707 r
F P
0 g
s
.2348 .59864 m .22734 .65288 L .19816 .65325 L p .707 .577 .707 r
F P
0 g
s
.48863 .23348 m .63312 .72797 L .6167 .72616 L p .707 .577 .707 r
F P
0 g
s
.6167 .72616 m .4722 .23168 L .48863 .23348 L p .707 .577 .707 r
F P
0 g
s
.1991 .67524 m .1909 .71043 L .1672 .7129 L p .707 .577 .707 r
F P
0 g
s
.26638 .60166 m .25891 .6559 L .22734 .65288 L p .707 .577 .707 r
F P
0 g
s
.72501 .65726 m .73247 .60302 L .70159 .59691 L p .707 .577 .707 r
F P
0 g
s
.73247 .60302 m .72501 .65726 L .75658 .66028 L p .707 .577 .707 r
F P
0 g
s
.75658 .66028 m .76405 .60604 L .73247 .60302 L p .707 .577 .707 r
F P
0 g
s
.76405 .60604 m .75658 .66028 L .78576 .65991 L p .707 .577 .707 r
F P
0 g
s
.78576 .65991 m .79323 .60567 L .76405 .60604 L p .707 .577 .707 r
F P
0 g
s
.1909 .71043 m .1991 .67524 L .22792 .67681 L p .707 .577 .707 r
F P
0 g
s
.31611 .70236 m .30791 .73754 L .28123 .72625 L p .707 .577 .707 r
F P
0 g
s
.28123 .72625 m .28944 .69107 L .31611 .70236 L p .707 .577 .707 r
F P
0 g
s
.69412 .65115 m .70159 .59691 L .67441 .58831 L p .707 .577 .707 r
F P
0 g
s
.70159 .59691 m .69412 .65115 L .72501 .65726 L p .707 .577 .707 r
F P
0 g
s
.16023 .7616 m .16445 .74405 L .18812 .74166 L p .707 .577 .707 r
F P
0 g
s
.32528 .78229 m .32107 .79984 L .30076 .78699 L p .707 .577 .707 r
F P
0 g
s
.30076 .78699 m .30497 .76944 L .32528 .78229 L p .707 .577 .707 r
F P
0 g
s
.18812 .74166 m .1839 .75921 L .16023 .7616 L p .707 .577 .707 r
F P
0 g
s
.79323 .60567 m .78576 .65991 L .80968 .6562 L p .707 .577 .707 r
F P
0 g
s
.80968 .6562 m .81715 .60196 L .79323 .60567 L p .707 .577 .707 r
F P
0 g
s
.22792 .67681 m .21972 .71199 L .1909 .71043 L p .707 .577 .707 r
F P
0 g
s
.21972 .71199 m .22792 .67681 L .25905 .68226 L p .707 .577 .707 r
F P
0 g
s
.28944 .69107 m .28123 .72625 L .25084 .71744 L p .707 .577 .707 r
F P
0 g
s
.25084 .71744 m .25905 .68226 L .28944 .69107 L p .707 .577 .707 r
F P
0 g
s
.66695 .64255 m .67441 .58831 L .65362 .57806 L p .707 .577 .707 r
F P
0 g
s
.67441 .58831 m .66695 .64255 L .69412 .65115 L p .707 .577 .707 r
F P
0 g
s
.25905 .68226 m .25084 .71744 L .21972 .71199 L p .707 .577 .707 r
F P
0 g
s
.71594 .71415 m .72415 .67897 L .69376 .67017 L p .707 .577 .707 r
F P
0 g
s
.72415 .67897 m .71594 .71415 L .74707 .7196 L p .707 .577 .707 r
F P
0 g
s
.74707 .7196 m .75528 .68442 L .72415 .67897 L p .707 .577 .707 r
F P
0 g
s
.1839 .75921 m .18812 .74166 L .21691 .74335 L p .707 .577 .707 r
F P
0 g
s
.30497 .76944 m .30076 .78699 L .27413 .77551 L p .707 .577 .707 r
F P
0 g
s
.27413 .77551 m .27834 .75796 L .30497 .76944 L p .707 .577 .707 r
F P
0 g
s
.68555 .70535 m .69376 .67017 L .66709 .65887 L p .707 .577 .707 r
F P
0 g
s
.69376 .67017 m .68555 .70535 L .71594 .71415 L p .707 .577 .707 r
F P
0 g
s
.37041 .79936 m .22592 .30488 L .24873 .29241 L p .707 .577 .707 r
F P
0 g
s
.22592 .30488 m .37041 .79936 L .36012 .8091 L p .707 .577 .707 r
F P
0 g
s
.75528 .68442 m .74707 .7196 L .77589 .72117 L p .707 .577 .707 r
F P
0 g
s
.77589 .72117 m .7841 .68599 L .75528 .68442 L p .707 .577 .707 r
F P
0 g
s
.21691 .74335 m .21269 .76091 L .1839 .75921 L p .707 .577 .707 r
F P
0 g
s
.4722 .23168 m .6167 .72616 L .58867 .72881 L p .707 .577 .707 r
F P
0 g
s
.58867 .72881 m .44418 .23432 L .4722 .23168 L p .707 .577 .707 r
F P
0 g
s
.81715 .60196 m .80968 .6562 L .82601 .6495 L p .707 .577 .707 r
F P
0 g
s
.82601 .6495 m .83347 .59526 L .81715 .60196 L p .707 .577 .707 r
F P
0 g
s
.65362 .57806 m .64615 .6323 L .66695 .64255 L p .707 .577 .707 r
F P
0 g
s
.21269 .76091 m .21691 .74335 L .248 .74897 L p .707 .577 .707 r
F P
0 g
s
.27834 .75796 m .27413 .77551 L .24378 .76652 L p .707 .577 .707 r
F P
0 g
s
.24378 .76652 m .248 .74897 L .27834 .75796 L p .707 .577 .707 r
F P
0 g
s
.64615 .6323 m .65362 .57806 L .64123 .56717 L p .707 .577 .707 r
F P
0 g
s
.66709 .65887 m .65888 .69405 L .68555 .70535 L p .707 .577 .707 r
F P
0 g
s
.65888 .69405 m .66709 .65887 L .64674 .64618 L p .707 .577 .707 r
F P
0 g
s
.7841 .68599 m .77589 .72117 L .79958 .71869 L p .707 .577 .707 r
F P
0 g
s
.79958 .71869 m .80779 .68351 L .7841 .68599 L p .707 .577 .707 r
F P
0 g
s
.70879 .74769 m .71301 .73013 L .68266 .72114 L p .707 .577 .707 r
F P
0 g
s
.71301 .73013 m .70879 .74769 L .73988 .7533 L p .707 .577 .707 r
F P
0 g
s
.73988 .7533 m .7441 .73575 L .71301 .73013 L p .707 .577 .707 r
F P
0 g
s
.248 .74897 m .24378 .76652 L .21269 .76091 L p .707 .577 .707 r
F P
0 g
s
.67845 .7387 m .68266 .72114 L .65603 .70966 L p .707 .577 .707 r
F P
0 g
s
.68266 .72114 m .67845 .7387 L .70879 .74769 L p .707 .577 .707 r
F P
0 g
s
.7441 .73575 m .73988 .7533 L .76867 .755 L p .707 .577 .707 r
F P
0 g
s
.76867 .755 m .77289 .73744 L .7441 .73575 L p .707 .577 .707 r
F P
0 g
s
.65603 .70966 m .65182 .72722 L .67845 .7387 L p .707 .577 .707 r
F P
0 g
s
.64674 .64618 m .63853 .68137 L .65888 .69405 L p .707 .577 .707 r
F P
0 g
s
.64123 .56717 m .63376 .6214 L .64615 .6323 L p .707 .577 .707 r
F P
0 g
s
.65182 .72722 m .65603 .70966 L .63572 .69682 L p .707 .577 .707 r
F P
0 g
s
.77289 .73744 m .76867 .755 L .79235 .75261 L p .707 .577 .707 r
F P
0 g
s
.79235 .75261 m .79656 .73505 L .77289 .73744 L p .707 .577 .707 r
F P
0 g
s
.63853 .68137 m .64674 .64618 L .63471 .63336 L p .707 .577 .707 r
F P
0 g
s
.80779 .68351 m .79958 .71869 L .81583 .71242 L p .707 .577 .707 r
F P
0 g
s
.81583 .71242 m .82403 .67724 L .80779 .68351 L p .707 .577 .707 r
F P
0 g
s
.83347 .59526 m .82601 .6495 L .83314 .64046 L p .707 .577 .707 r
F P
0 g
s
.83314 .64046 m .8406 .58623 L .83347 .59526 L p .707 .577 .707 r
F P
0 g
s
.24873 .29241 m .39322 .78689 L .37041 .79936 L p .707 .577 .707 r
F P
0 g
s
.39322 .78689 m .24873 .29241 L .28182 .27845 L p .707 .577 .707 r
F P
0 g
s
.63572 .69682 m .63151 .71437 L .65182 .72722 L p .707 .577 .707 r
F P
0 g
s
.63376 .6214 m .64123 .56717 L .63846 .55669 L p .707 .577 .707 r
F P
0 g
s
.44418 .23432 m .58867 .72881 L .5518 .73564 L p .707 .577 .707 r
F P
0 g
s
.5518 .73564 m .40731 .24115 L .44418 .23432 L p .707 .577 .707 r
F P
0 g
s
.63471 .63336 m .6265 .66854 L .63853 .68137 L p .707 .577 .707 r
F P
0 g
s
.63151 .71437 m .63572 .69682 L .62372 .68386 L p .707 .577 .707 r
F P
0 g
s
.79656 .73505 m .79235 .75261 L .80858 .74636 L p .707 .577 .707 r
F P
0 g
s
.80858 .74636 m .8128 .72881 L .79656 .73505 L p .707 .577 .707 r
F P
0 g
s
.63846 .55669 m .631 .61093 L .63376 .6214 L p .707 .577 .707 r
F P
0 g
s
.62372 .68386 m .61951 .70141 L .63151 .71437 L p .707 .577 .707 r
F P
0 g
s
.6265 .66854 m .63471 .63336 L .63217 .62164 L p .707 .577 .707 r
F P
0 g
s
.82403 .67724 m .81583 .71242 L .82303 .70296 L p .707 .577 .707 r
F P
0 g
s
.82303 .70296 m .83124 .66778 L .82403 .67724 L p .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .3784 .60896 L p .40363 .66239 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .37064 .58239 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38376 .6142 L .40363 .66239 L .707 .577 .707 r
F
.38946 .57275 m .38376 .6142 L p .41357 .63001 L F P
0 g
s
.39841 .62856 m .41357 .63001 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.38376 .6142 m .38946 .57275 L .36537 .56798 L p .707 .577 .707 r
F P
0 g
s
.37064 .58239 m .3784 .60896 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.38296 .62455 m .392 .65549 L p .37351 .61032 L .707 .577 .707 r
F P
0 g
s
.392 .65549 m .42631 .77293 L p .38722 .65254 L .707 .577 .707 r
F P
0 g
s
.37351 .61032 m .392 .65549 L .38722 .65254 L .707 .577 .707 r
F
.41357 .63001 m .42104 .57577 L .38946 .57275 L p F P
0 g
s
.42104 .57577 m .41357 .63001 L .43732 .62971 L p .707 .577 .707 r
F P
0 g
s
.44284 .64059 m .43127 .63848 L .43992 .62593 L .707 .577 .707 r
F
.46644 .75883 m .43455 .6497 L p .44284 .64059 L F P
0 g
s
.43455 .6497 m .43127 .63848 L p .44284 .64059 L .707 .577 .707 r
F P
0 g
s
.46644 .75883 m .42631 .77293 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .43455 .6497 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43455 .6497 m .46644 .75883 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .44109 .66576 L .42093 .66466 L p .707 .577 .707 r
F P
0 g
s
.42093 .66466 m .41227 .66419 L p .41573 .67038 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .42093 .66466 L .41573 .67038 L .707 .577 .707 r
F
.44076 .6247 m .42104 .57577 L .43732 .62971 L F
.50968 .74598 m .46644 .75883 L p .43992 .62593 L F P
0 g
s
.45022 .5754 m .42104 .57577 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .45022 .5754 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .46427 .59057 L p .4441 .61986 L .707 .577 .707 r
F P
0 g
s
.46427 .59057 m .50968 .74598 L p .44106 .6279 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4441 .61986 L .44106 .6279 L .707 .577 .707 r
F
.4441 .61986 m .46427 .59057 L .44106 .6279 L F
.36519 .2515 m .40731 .24115 L p .46782 .53955 L F P
0 g
s
.50968 .74598 m .4603 .57697 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.46095 .57374 m .45022 .5754 L p .4603 .57697 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .36519 .2515 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.45516 .59057 m .4603 .57697 L .45022 .5754 L .707 .577 .707 r
F
.46155 .57364 m .46095 .57374 L p .4603 .57697 L F P
0 g
s
.46667 .62592 m .47414 .57169 L .46155 .57364 L p .707 .577 .707 r
F P
0 g
s
.46667 .62592 m .46155 .57364 L .45516 .59057 L .707 .577 .707 r
F
.44275 .62964 m .46667 .62592 L p .45516 .59057 L F P
0 g
s
.45022 .5754 m .4441 .61986 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .44275 .62964 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.36519 .2515 m .4603 .57697 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4603 .57697 L .4441 .61986 L .707 .577 .707 r
F
.44275 .62964 m .4441 .61986 L p .44076 .6247 L F P
0 g
s
.43732 .62971 m .44275 .62964 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .36519 .2515 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43127 .63848 m .32195 .26435 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .43288 .70094 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41227 .66419 m .41148 .66755 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .40406 .69938 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .39322 .78689 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .41148 .66755 L p .38114 .65874 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .41227 .66419 L .40886 .6636 L p .707 .577 .707 r
F P
0 g
s
.40886 .6636 m .38114 .65874 L p .41148 .66755 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38296 .62455 L p .36684 .58978 L .707 .577 .707 r
F P
0 g
s
.36684 .58978 m .38296 .62455 L .37351 .61032 L .707 .577 .707 r
F
.31517 .43063 m .3784 .60896 L .36684 .58978 L F
.28182 .27845 m .32195 .26435 L p .39625 .62645 L F P
0 g
s
.40363 .66239 m .39041 .62072 L .39625 .62645 L .707 .577 .707 r
F
.39041 .62072 m .28182 .27845 L .39625 .62645 L F
.38376 .6142 m .36537 .56798 L .37064 .58239 L F
.37064 .58239 m .28182 .27845 L p .40363 .66239 L F P
0 g
s
.38376 .6142 m .38335 .61717 L p .39841 .62856 L .707 .577 .707 r
F P
0 g
s
.38335 .61717 m .382 .62699 L .38971 .62772 L p .707 .577 .707 r
F P
0 g
s
.38971 .62772 m .39841 .62856 L p .38335 .61717 L .707 .577 .707 r
F P
0 g
s
.36537 .56798 m .36463 .56784 L p .37064 .58239 L .707 .577 .707 r
F P
0 g
s
.28182 .27845 m .37064 .58239 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.382 .62699 m .38376 .6142 L p .35858 .56664 L .707 .577 .707 r
F P
0 g
s
.36463 .56784 m .35858 .56664 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.8406 .58623 m .83314 .64046 L .83037 .62999 L p .707 .577 .707 r
F P
0 g
s
.83037 .62999 m .83784 .57575 L .8406 .58623 L p .707 .577 .707 r
F P
0 g
s
.40731 .24115 m .5518 .73564 L .50968 .74598 L p .707 .577 .707 r
F P
0 g
s
.631 .61093 m .63846 .55669 L .64559 .54766 L p .707 .577 .707 r
F P
0 g
s
.63217 .62164 m .62396 .65682 L .6265 .66854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.61951 .70141 m .62372 .68386 L .62121 .67206 L p .707 .577 .707 r
F P
0 g
s
.8128 .72881 m .80858 .74636 L .8158 .73687 L p .707 .577 .707 r
F P
0 g
s
.8158 .73687 m .82001 .71932 L .8128 .72881 L p .707 .577 .707 r
F P
0 g
s
.62121 .67206 m .61699 .68961 L .61951 .70141 L p .707 .577 .707 r
F P
0 g
s
.64559 .54766 m .63813 .6019 L .631 .61093 L p .707 .577 .707 r
F P
0 g
s
.62396 .65682 m .63217 .62164 L .63938 .61218 L p .707 .577 .707 r
F P
0 g
s
.83124 .66778 m .82303 .70296 L .8205 .69125 L p .707 .577 .707 r
F P
0 g
s
.8205 .69125 m .82871 .65606 L .83124 .66778 L p .707 .577 .707 r
F P
0 g
s
.83784 .57575 m .83037 .62999 L .81798 .61909 L p .707 .577 .707 r
F P
0 g
s
.81798 .61909 m .82545 .56485 L .83784 .57575 L p .707 .577 .707 r
F P
0 g
s
.63813 .6019 m .64559 .54766 L .66192 .54096 L p .707 .577 .707 r
F P
0 g
s
.63938 .61218 m .63117 .64737 L .62396 .65682 L p .707 .577 .707 r
F P
0 g
s
.61699 .68961 m .62121 .67206 L .62842 .66257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35111 .62088 m .35858 .56664 L .3314 .55804 L p .707 .577 .707 r
F P
0 g
s
.35858 .56664 m .35111 .62088 L .382 .62699 L p .707 .577 .707 r
F P
0 g
s
.82001 .71932 m .8158 .73687 L .81328 .72507 L p .707 .577 .707 r
F P
0 g
s
.81328 .72507 m .8175 .70752 L .82001 .71932 L p .707 .577 .707 r
F P
0 g
s
.62842 .66257 m .62421 .68012 L .61699 .68961 L p .707 .577 .707 r
F P
0 g
s
.66192 .54096 m .65445 .5952 L .63813 .6019 L p .707 .577 .707 r
F P
0 g
s
.63117 .64737 m .63938 .61218 L .65562 .60591 L p .707 .577 .707 r
F P
0 g
s
.82871 .65606 m .8205 .69125 L .80847 .67842 L p .707 .577 .707 r
F P
0 g
s
.80847 .67842 m .81667 .64324 L .82871 .65606 L p .707 .577 .707 r
F P
0 g
s
.82545 .56485 m .81798 .61909 L .79719 .60884 L p .707 .577 .707 r
F P
0 g
s
.79719 .60884 m .80465 .5546 L .82545 .56485 L p .707 .577 .707 r
F P
0 g
s
.32394 .61228 m .3314 .55804 L .31061 .54779 L p .707 .577 .707 r
F P
0 g
s
.3314 .55804 m .32394 .61228 L .35111 .62088 L p .707 .577 .707 r
F P
0 g
s
.65445 .5952 m .66192 .54096 L .68584 .53724 L p .707 .577 .707 r
F P
0 g
s
.37293 .69392 m .38114 .65874 L .35075 .64994 L p .707 .577 .707 r
F P
0 g
s
.38114 .65874 m .37293 .69392 L .40406 .69938 L p .707 .577 .707 r
F P
0 g
s
.65562 .60591 m .64742 .64109 L .63117 .64737 L p .707 .577 .707 r
F P
0 g
s
.34254 .68512 m .35075 .64994 L .32408 .63864 L p .707 .577 .707 r
F P
0 g
s
.35075 .64994 m .34254 .68512 L .37293 .69392 L p .707 .577 .707 r
F P
0 g
s
.62421 .68012 m .62842 .66257 L .64466 .65633 L p .707 .577 .707 r
F P
0 g
s
.8175 .70752 m .81328 .72507 L .80128 .71211 L p .707 .577 .707 r
F P
0 g
s
.80128 .71211 m .8055 .69456 L .8175 .70752 L p .707 .577 .707 r
F P
0 g
s
.47414 .57169 m .46667 .62592 L .483 .61922 L p .707 .577 .707 r
F P
0 g
s
.483 .61922 m .49046 .56498 L .47414 .57169 L p .707 .577 .707 r
F P
0 g
s
.31061 .54779 m .30314 .60203 L .32394 .61228 L p .707 .577 .707 r
F P
0 g
s
.80465 .5546 m .79719 .60884 L .77001 .60024 L p .707 .577 .707 r
F P
0 g
s
.77001 .60024 m .77748 .546 L .80465 .5546 L p .707 .577 .707 r
F P
0 g
s
.68584 .53724 m .67837 .59148 L .65445 .5952 L p .707 .577 .707 r
F P
0 g
s
.64466 .65633 m .64045 .67388 L .62421 .68012 L p .707 .577 .707 r
F P
0 g
s
.30314 .60203 m .31061 .54779 L .29822 .53689 L p .707 .577 .707 r
F P
0 g
s
.64742 .64109 m .65562 .60591 L .67932 .60343 L p .707 .577 .707 r
F P
0 g
s
.67837 .59148 m .68584 .53724 L .71502 .53687 L p .707 .577 .707 r
F P
0 g
s
.81667 .64324 m .80847 .67842 L .78812 .66573 L p .707 .577 .707 r
F P
0 g
s
.78812 .66573 m .79633 .63055 L .81667 .64324 L p .707 .577 .707 r
F P
0 g
s
.32408 .63864 m .31587 .67382 L .34254 .68512 L p .707 .577 .707 r
F P
0 g
s
.31587 .67382 m .32408 .63864 L .30373 .62596 L p .707 .577 .707 r
F P
0 g
s
.44109 .66576 m .43288 .70094 L .45657 .69847 L p .707 .577 .707 r
F P
0 g
s
.45657 .69847 m .46478 .66328 L .44109 .66576 L p .707 .577 .707 r
F P
0 g
s
.36578 .74337 m .37 .72582 L .33965 .71683 L p .707 .577 .707 r
F P
0 g
s
.37 .72582 m .36578 .74337 L .39687 .74899 L p .707 .577 .707 r
F P
0 g
s
.39687 .74899 m .40109 .73144 L .37 .72582 L p .707 .577 .707 r
F P
0 g
s
.77748 .546 m .77001 .60024 L .73913 .59413 L p .707 .577 .707 r
F P
0 g
s
.73913 .59413 m .74659 .53989 L .77748 .546 L p .707 .577 .707 r
F P
0 g
s
.33544 .73438 m .33965 .71683 L .31302 .70535 L p .707 .577 .707 r
F P
0 g
s
.33965 .71683 m .33544 .73438 L .36578 .74337 L p .707 .577 .707 r
F P
0 g
s
.40109 .73144 m .39687 .74899 L .42566 .75068 L p .707 .577 .707 r
F P
0 g
s
.42566 .75068 m .42988 .73313 L .40109 .73144 L p .707 .577 .707 r
F P
0 g
s
.67932 .60343 m .67111 .63862 L .64742 .64109 L p .707 .577 .707 r
F P
0 g
s
.70755 .59111 m .71502 .53687 L .74659 .53989 L p .707 .577 .707 r
F P
0 g
s
.71502 .53687 m .70755 .59111 L .67837 .59148 L p .707 .577 .707 r
F P
0 g
s
.30373 .62596 m .29552 .66114 L .31587 .67382 L p .707 .577 .707 r
F P
0 g
s
.74659 .53989 m .73913 .59413 L .70755 .59111 L p .707 .577 .707 r
F P
0 g
s
.29822 .53689 m .29075 .59113 L .30314 .60203 L p .707 .577 .707 r
F P
0 g
s
.64045 .67388 m .64466 .65633 L .66833 .65393 L p .707 .577 .707 r
F P
0 g
s
.31302 .70535 m .30881 .7229 L .33544 .73438 L p .707 .577 .707 r
F P
0 g
s
.8055 .69456 m .80128 .71211 L .78097 .69927 L p .707 .577 .707 r
F P
0 g
s
.78097 .69927 m .78519 .68171 L .8055 .69456 L p .707 .577 .707 r
F P
0 g
s
.67111 .63862 m .67932 .60343 L .70814 .605 L p .707 .577 .707 r
F P
0 g
s
.79633 .63055 m .78812 .66573 L .76145 .65444 L p .707 .577 .707 r
F P
0 g
s
.76145 .65444 m .76965 .61925 L .79633 .63055 L p .707 .577 .707 r
F P
0 g
s
.49046 .56498 m .483 .61922 L .49013 .61019 L p .707 .577 .707 r
F P
0 g
s
.49013 .61019 m .49759 .55595 L .49046 .56498 L p .707 .577 .707 r
F P
0 g
s
.29552 .66114 m .30373 .62596 L .2917 .61313 L p .707 .577 .707 r
F P
0 g
s
.46478 .66328 m .45657 .69847 L .47282 .69219 L p .707 .577 .707 r
F P
0 g
s
.47282 .69219 m .48102 .65701 L .46478 .66328 L p .707 .577 .707 r
F P
0 g
s
.66833 .65393 m .66412 .67149 L .64045 .67388 L p .707 .577 .707 r
F P
0 g
s
.30881 .7229 m .31302 .70535 L .29271 .6925 L p .707 .577 .707 r
F P
0 g
s
.42988 .73313 m .42566 .75068 L .44934 .74829 L p .707 .577 .707 r
F P
0 g
s
.44934 .74829 m .45355 .73074 L .42988 .73313 L p .707 .577 .707 r
F P
0 g
s
.29075 .59113 m .29822 .53689 L .29545 .52642 L p .707 .577 .707 r
F P
0 g
s
.29271 .6925 m .2885 .71006 L .30881 .7229 L p .707 .577 .707 r
F P
0 g
s
.70814 .605 m .69993 .64018 L .67111 .63862 L p .707 .577 .707 r
F P
0 g
s
.69993 .64018 m .70814 .605 L .73926 .61045 L p .707 .577 .707 r
F P
0 g
s
.76965 .61925 m .76145 .65444 L .73106 .64563 L p .707 .577 .707 r
F P
0 g
s
.73106 .64563 m .73926 .61045 L .76965 .61925 L p .707 .577 .707 r
F P
0 g
s
.2917 .61313 m .28349 .64831 L .29552 .66114 L p .707 .577 .707 r
F P
0 g
s
.73926 .61045 m .73106 .64563 L .69993 .64018 L p .707 .577 .707 r
F P
0 g
s
.66412 .67149 m .66833 .65393 L .69712 .65563 L p .707 .577 .707 r
F P
0 g
s
.78519 .68171 m .78097 .69927 L .75434 .68779 L p .707 .577 .707 r
F P
0 g
s
.75434 .68779 m .75856 .67023 L .78519 .68171 L p .707 .577 .707 r
F P
0 g
s
.29545 .52642 m .28799 .58066 L .29075 .59113 L p .707 .577 .707 r
F P
0 g
s
.69712 .65563 m .69291 .67318 L .66412 .67149 L p .707 .577 .707 r
F P
0 g
s
.2885 .71006 m .29271 .6925 L .28071 .67955 L p .707 .577 .707 r
F P
0 g
s
.45355 .73074 m .44934 .74829 L .46557 .74205 L p .707 .577 .707 r
F P
0 g
s
.46557 .74205 m .46979 .72449 L .45355 .73074 L p .707 .577 .707 r
F P
0 g
s
.28349 .64831 m .2917 .61313 L .28916 .60141 L p .707 .577 .707 r
F P
0 g
s
.48102 .65701 m .47282 .69219 L .48002 .68273 L p .707 .577 .707 r
F P
0 g
s
.48002 .68273 m .48823 .64755 L .48102 .65701 L p .707 .577 .707 r
F P
0 g
s
.49759 .55595 m .49013 .61019 L .48736 .59972 L p .707 .577 .707 r
F P
0 g
s
.48736 .59972 m .49483 .54548 L .49759 .55595 L p .707 .577 .707 r
F P
0 g
s
.28071 .67955 m .2765 .6971 L .2885 .71006 L p .707 .577 .707 r
F P
0 g
s
.69291 .67318 m .69712 .65563 L .72821 .66125 L p .707 .577 .707 r
F P
0 g
s
.75856 .67023 m .75434 .68779 L .724 .6788 L p .707 .577 .707 r
F P
0 g
s
.724 .6788 m .72821 .66125 L .75856 .67023 L p .707 .577 .707 r
F P
0 g
s
.28799 .58066 m .29545 .52642 L .30258 .51739 L p .707 .577 .707 r
F P
0 g
s
.72821 .66125 m .724 .6788 L .69291 .67318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28916 .60141 m .28095 .6366 L .28349 .64831 L p .707 .577 .707 r
F P
0 g
s
.2765 .6971 m .28071 .67955 L .2782 .66775 L p .707 .577 .707 r
F P
0 g
s
.46979 .72449 m .46557 .74205 L .47279 .73256 L p .707 .577 .707 r
F P
0 g
s
.47279 .73256 m .477 .71501 L .46979 .72449 L p .707 .577 .707 r
F P
0 g
s
.30258 .51739 m .29512 .57162 L .28799 .58066 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28095 .6366 m .28916 .60141 L .29637 .59195 L p .707 .577 .707 r
F P
0 g
s
.2782 .66775 m .27398 .6853 L .2765 .6971 L p .707 .577 .707 r
F P
0 g
s
.48823 .64755 m .48002 .68273 L .47749 .67102 L p .707 .577 .707 r
F P
0 g
s
.47749 .67102 m .4857 .63583 L .48823 .64755 L p .707 .577 .707 r
F P
0 g
s
.49483 .54548 m .48736 .59972 L .47497 .58882 L p .707 .577 .707 r
F P
0 g
s
.47497 .58882 m .48244 .53458 L .49483 .54548 L p .707 .577 .707 r
F P
0 g
s
.29512 .57162 m .30258 .51739 L .31891 .51068 L p .707 .577 .707 r
F P
0 g
s
.29637 .59195 m .28816 .62714 L .28095 .6366 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27398 .6853 m .2782 .66775 L .28541 .65826 L p .707 .577 .707 r
F P
0 g
s
.477 .71501 m .47279 .73256 L .47027 .72076 L p .707 .577 .707 r
F P
0 g
s
.47027 .72076 m .47448 .70321 L .477 .71501 L p .707 .577 .707 r
F P
0 g
s
.31891 .51068 m .31144 .56492 L .29512 .57162 L p .707 .577 .707 r
F P
0 g
s
.48244 .53458 m .47497 .58882 L .45418 .57857 L p .707 .577 .707 r
F P
0 g
s
.45418 .57857 m .46164 .52433 L .48244 .53458 L p .707 .577 .707 r
F P
0 g
s
.28541 .65826 m .2812 .67581 L .27398 .6853 L p .707 .577 .707 r
F P
0 g
s
.28816 .62714 m .29637 .59195 L .31261 .58568 L p .707 .577 .707 r
F P
0 g
s
.4857 .63583 m .47749 .67102 L .46546 .65819 L p .707 .577 .707 r
F P
0 g
s
.46546 .65819 m .47366 .62301 L .4857 .63583 L p .707 .577 .707 r
F P
0 g
s
.31144 .56492 m .31891 .51068 L .34283 .50697 L p .707 .577 .707 r
F P
0 g
s
.31261 .58568 m .30441 .62086 L .28816 .62714 L p .707 .577 .707 r
F P
0 g
s
.46164 .52433 m .45418 .57857 L .427 .56997 L p .707 .577 .707 r
F P
0 g
s
.427 .56997 m .43447 .51573 L .46164 .52433 L p .707 .577 .707 r
F P
0 g
s
.34283 .50697 m .33536 .56121 L .31144 .56492 L p .707 .577 .707 r
F P
0 g
s
.2812 .67581 m .28541 .65826 L .30165 .65201 L p .707 .577 .707 r
F P
0 g
s
.47448 .70321 m .47027 .72076 L .45827 .7078 L p .707 .577 .707 r
F P
0 g
s
.45827 .7078 m .46248 .69025 L .47448 .70321 L p .707 .577 .707 r
F P
0 g
s
.33536 .56121 m .34283 .50697 L .372 .5066 L p .707 .577 .707 r
F P
0 g
s
.30441 .62086 m .31261 .58568 L .33631 .5832 L p .707 .577 .707 r
F P
0 g
s
.47366 .62301 m .46546 .65819 L .44511 .64551 L p .707 .577 .707 r
F P
0 g
s
.44511 .64551 m .45332 .61032 L .47366 .62301 L p .707 .577 .707 r
F P
0 g
s
.30165 .65201 m .29744 .66957 L .2812 .67581 L p .707 .577 .707 r
F P
0 g
s
.43447 .51573 m .427 .56997 L .39612 .56386 L p .707 .577 .707 r
F P
0 g
s
.39612 .56386 m .40358 .50962 L .43447 .51573 L p .707 .577 .707 r
F P
0 g
s
.36454 .56084 m .372 .5066 L .40358 .50962 L p .707 .577 .707 r
F P
0 g
s
.372 .5066 m .36454 .56084 L .33536 .56121 L p .707 .577 .707 r
F P
0 g
s
.33631 .5832 m .3281 .61839 L .30441 .62086 L p .707 .577 .707 r
F P
0 g
s
.40358 .50962 m .39612 .56386 L .36454 .56084 L p .707 .577 .707 r
F P
0 g
s
.3281 .61839 m .33631 .5832 L .36513 .58477 L p .707 .577 .707 r
F P
0 g
s
.45332 .61032 m .44511 .64551 L .41844 .63421 L p .707 .577 .707 r
F P
0 g
s
.41844 .63421 m .42664 .59903 L .45332 .61032 L p .707 .577 .707 r
F P
0 g
s
.29744 .66957 m .30165 .65201 L .32532 .64962 L p .707 .577 .707 r
F P
0 g
s
.46248 .69025 m .45827 .7078 L .43796 .69495 L p .707 .577 .707 r
F P
0 g
s
.43796 .69495 m .44218 .6774 L .46248 .69025 L p .707 .577 .707 r
F P
0 g
s
.32532 .64962 m .32111 .66717 L .29744 .66957 L p .707 .577 .707 r
F P
0 g
s
.36513 .58477 m .35692 .61995 L .3281 .61839 L p .707 .577 .707 r
F P
0 g
s
.35692 .61995 m .36513 .58477 L .39625 .59022 L p .707 .577 .707 r
F P
0 g
s
.42664 .59903 m .41844 .63421 L .38805 .6254 L p .707 .577 .707 r
F P
0 g
s
.38805 .6254 m .39625 .59022 L .42664 .59903 L p .707 .577 .707 r
F P
0 g
s
.39625 .59022 m .38805 .6254 L .35692 .61995 L p .707 .577 .707 r
F P
0 g
s
.32111 .66717 m .32532 .64962 L .35411 .65132 L p .707 .577 .707 r
F P
0 g
s
.44218 .6774 m .43796 .69495 L .41133 .68347 L p .707 .577 .707 r
F P
0 g
s
.41133 .68347 m .41555 .66592 L .44218 .6774 L p .707 .577 .707 r
F P
0 g
s
.35411 .65132 m .3499 .66887 L .32111 .66717 L p .707 .577 .707 r
F P
0 g
s
.3499 .66887 m .35411 .65132 L .3852 .65693 L p .707 .577 .707 r
F P
0 g
s
.41555 .66592 m .41133 .68347 L .38099 .67449 L p .707 .577 .707 r
F P
0 g
s
.38099 .67449 m .3852 .65693 L .41555 .66592 L p .707 .577 .707 r
F P
0 g
s
.3852 .65693 m .38099 .67449 L .3499 .66887 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol008=oo`D009Eoo`00O7oo1`001EYF0`00TWoo001fOol6
000;FUH01000FUIJEUYFTWoo001bOol40009FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001^
Ool400000eYF001JEP0:FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001ZOol40006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`2>Ool006Ioo`@000YJEP03001JEUYF015JEP05001J
EUYFFUH0002@Ool006=oo`<000iJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002@
Ool0061oo`<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002@Ool005eoo`<000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF
FUH0002?Ool005Yoo`<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001J
EUYFFUH0002?Ool005Moo`<001]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002?
Ool005Eoo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH2002>Ool0059oo`<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03Ool005YF
00UJEP03001JEUYF00IJEP05001JEUYFFUH0002>Ool004moo`<000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002>Ool004eoo`800003FUH0
05YF01QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2002=Ool0
04Yoo`<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008008eoo`00B7oo0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008eoo`00AWoo0P00
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00D005YFFUIJEP0008eoo`00A7oo0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00S7oo0012Ool20003FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000S7oo0010Ool20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
S7oo000oOol20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Rgoo000nOol01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Rgoo000mOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0008]oo`00?Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002;Ool003ioo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02002:Ool003ioo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RWoo000nOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Yoo`00?Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH20029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
0029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RGoo000oOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Uoo`00@7oo00@005YFFUH000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF008008Qoo`00@7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH00028Ool0041oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000R7oo0010Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8008Moo`00@Goo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008008Moo`00@Goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP05001JEUYFFUH00027Ool0045oo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00QWoo0012Ool01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00P00QWoo0012Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Ioo`00
@Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00026Ool0049oo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020025Ool004=oo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000QGoo0013Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D0
05YFFUIJEP0008Eoo`00@goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20024
Ool004Aoo`05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020024Ool004Aoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Q7oo0014Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Aoo`00A7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF008008=oo`00AGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0023Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Pgoo0015Ool0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80089oo`00AWoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF0080089oo`00AWoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH00022Ool004Ioo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00PGoo0016Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00PGoo0017
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00085oo`00Agoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00021Ool004Moo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00081o
o`00B7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001oOol004Qoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007moo`00BGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0001oOol004Uoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000Ogoo0019Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8007ioo`00BWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007ioo`00BWoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001nOol004Yoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OGoo001:Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02001mOol004]oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000OGoo001;Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007eo
o`00Bgoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007aoo`00C7oo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001lOol004aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000O7oo001<Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007]oo`00C7oo0P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P00Ngoo001=Ool01@00FUIJEUYF00001UYF00<005YFFUH00eYF5`001eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007]oo`00CGoo00D005YFFUIJEP0000IJEP03
001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000=JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001jOol004eoo`05001JEUYFFUH0
0006FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001jOol004ioo`05001JEUYFFUH00003FUH20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00H005YFFUIJEP00FUH3
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0`0025YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00@005YF
FUIJEP80009JEP04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001>
Ool20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001iOol004moo`07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH01EYF00D005YFFUIJEP0007Uoo`00Cgoo00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P006goo4000CGoo001?Ool01000
FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF00UJEP03001JEUYF00IJEP03001JEUYF
008001Ioo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00D7oo00<005YF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00000;FUH00`00FUIJEP05FUH01@00FUIJEUYF000057oo0P00
00=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00@goo001@Ool01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000]JEP03001JEUYF00EJEP05001JEUYFFUH0
000BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000oOol0051oo`05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YF
FUH01EYF00@005YFFUIJEP80011oo`8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<003]oo`00DGoo0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000YJEP03001JEUYF00IJEP03001JEUYF0080011oo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Qoo`00
DGoo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00EJEP05
001JEUYFFUH0000?Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0055oo`800003FUH005YF009JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]J
EP03001JEUYF00EJEP04001JEUYFFUH2000>Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02000dOol0055oo`<000=J
EPD0009JEP04001JEUYFFUH20004FUH01000FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00D005YFFUH005YF008000YJEP03001JEUYF00IJEP03001JEUYF008000ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP80039oo`00DGoo00@005YF001JEP<000IJEP03001JEUYF00=JEPD000EJEPT0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00003Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Goo001AOol01000FUH000000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00@005YFFUH000AJEPH00004FUH005YFFUH40006FUH00`00FUIJEP04FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P0037oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000002moo`00DGoo0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00@005YFFUH000IJEP<000=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF
0080009JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2000<Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF0`001EYF00@005YFFUIJEP80009JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000aoo`03001JEP0000AJEP03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DGoo00<005YFFUH00eYF00<005YFFUH00UYF1`0000=JEP00FUH0
0eYF00<005YFFUH02EYF00<005YFFUH02UYF0P000eYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0000<Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool0055oo`03001JEUYF00=JEPD000=JEP04001JEUYFFUH9000:FUH00`00
FUIJEP0;FUH200000eYF001JEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P002goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;7oo001B
Ool01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<005YFFUH035YF
0`000UYF00<005YF00000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P002goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00@005YF0000009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00eJEP08001JEUYF001J
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0000;Ool20004FUH01000
FUIJEUYF5P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00Dgoo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`003EYF00@0
05YFFUIJEP800003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000:
Ool00eYF001JEP02FUH500000eYF001JEP04FUH50007Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0`002UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P002Goo00@005YF001JEP8000IJEP03001JEUYF00EJEP03001J
EUYF00@0009oo`D000=oo`@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000008FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo00H005YF000005YF0005FUH70002FUH0
0`00FUIJEP04FUH70007Ool20004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000aOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH01`00FUIJEUYF
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00009Ool30002FUH60003
FUH01000FUIJEUYF2@000UYF4@0000=JEP00FUH015YF00<005YFFUH00UYF00<007ooOol0;Goo000_
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH20008Ool01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00
1EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF00<007ooOol0;Goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001J
EP03FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020008Ool01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEUYF
FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH2
0007FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10001eYF00@005YFFUIJEP800003
FUH005YF009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF00000UYF1P001UYF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00AJEP8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000P000eYF00<005YF
FUH01EYF00@005YFFUIJEPX000MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000Moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUH00002
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEPP000EJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0007Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`001UYF00<005YFFUH00`00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH30002FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH800000eYF001JEP07FUH00`00FUIJEP04FUH01000FUH000002EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00@005YFFUIJEP@000=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH2
000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00<000IJEP03001JEUYF00QJEPH0009JEP<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH300000eYF0000000200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0P00<7oo000/Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP08FUH50005FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030004
FUH00`00FUH00003FUH01000FUIJEUYF1P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`000UYF00<005YF0000<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH025YF100025YF0`0000=JEP00FUH01EYF00@005YFFUIJEP8000UJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH20003FUH80003FUH90004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000[Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH200000eYF001JEP09FUH01000FUIJEP002EYF00@0
05YF000000IJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001EYF00<005YF00000P000eYF0`0000=oo`00000015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01EYF00<005YFFUH015YF1000<Goo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF1`000UYF0`00
5UYF00<005YFFUH00`0015YF00@005YFFUIJEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF008000=JEP04001JEP000002FUH30003FUH300001Woo00000000FUH000QJEP03001JEUYF
00<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000bOol002]oo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00@005YFFUIJEPT000IJ
EP03001JEUYF00UJEP04001JEUYF0002FUH01000FUIJEP000eYF00<005YF00002UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP<000=JEP03001JEUYF00P0009oo`H000AJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYF000bOol002]oo`8000=J
EPD0009JEP04001JEUYFFUH20008Ool70006FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7
000<FUH00`00FUH00003FUH30003FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000UYF00<005YF00000UYF1@000UYF00<005YFFUH00UYF1P000Woo2@0015YF0`00
1eYF00<005YFFUH00eYF00D005YFFUIJEP00035oo`00:goo0P0000AJEP00000000IJEP03001JEUYF
00=JEP@000Ioo`T00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000UJEP03001JEUYF00EJEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YF00000`001goo2@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;goo000[
Ool00eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool50004Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40006FUH0
0`00FUIJEP02FUH50002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000;Ool300000eYF001J
EP04FUH00`00FUIJEP02FUH2000`Ool002Yoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00AJEP`000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH<0003
FUH01P00FUH00000FUH000aJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool20005
FUH01`00FUIJEUYF001JEP00031oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF1`001EYF2@0015YF00<005YFFUH01eYF00@005YF0000
00=JEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH0000000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40008Ool20003FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<005YFFUH00eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000001EYF0`00
1eYF00<005YFFUH00eYF1P001eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00H005YFFUIJEP00
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH50002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01eYF00@005YF000000Qoo`<000AJEP03001JEWoo031oo`00:Woo00<0
05YFFUH00eYF4`0015YF00<005YFFUH015YF0`001eYF00<005YFFUH00P0015YF00<005YFFUH01eYF
00<005YFFUH00P001EYF00<005YFFUH015YF0P001EYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH3000015YF000000001UYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH01eYF00@005YFFUIJEP<000Moo`03001JEUYF009JEP80035o
o`00:goo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP<000MJEP06001J
EUYFFUH005YF0`0000=JEP00FUH025YF00@005YFFUIJEP@00003FUH005YF00MJEP<0009JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH50000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20006Ool0
1000FUIJEUYF0P00<Goo000[Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF1@0000=JEP00FUH00P001UYF00D005YFFUIJEP0000=JEP@000QJEP03001JEUYF00P0
00MJEP06001JEUYF001JEP000eYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00@0009JEP03001JEUYF00IJEP800003Ool0000000@00003FUH00000039oo`00;7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00
FUH00P0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP<000AJEP04001JEUYFFUH60002FUH2
0004FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP050004FUH01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH015YF1000
1UYF00<005YFFUH00P000UYF00<005YFFUH00`00<Woo000/Ool01@00FUIJEUYF00001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH00004FUH01@00FUIJEUYF
00001EYF0`0000=JEP00FUH00UYF1@001EYF0`0000=JEP00FUH01EYF00@005YF000000AJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF001JEP040004FUH30007FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH00UYF00<005YF00000eYF0P00
<Woo000[Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH300000eYF001JEP03FUH01@00FUIJEUYF00001UYF00<005YF0000100000=J
EP0000000P0025YF0P001UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P000UYF00@007oo000000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF00EJEP04001JEUYFFUH3000bOol002]oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00
008000EJEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH90004FUH01000FUH0000015YF00<005YF
00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEPH00003
FUH005YF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP80009J
EP8003=oo`00:Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH000AJEP<000=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH01000FUIJ
EUYF2@000UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP04001JEUYF0003FUH30003FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30004FUH01000FUH005YF0P00<goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH400000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P0000=JEP00FUH00P000eYF
0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH2000dOol0
02Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000EJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP001EYF0P000eYF0P0000AJEP00FUIJEP<000AJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYFFUH30004FUH00`00Oomoo`0bOol002Uoo`03001JEP00009JEQ<000IJEP03
001JEUYF00IJEP04001JEUYF0004FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<000=JEP8000=JEPD00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo039oo`00:Goo0P0000AJEP000000
011oo`H0009JEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH40006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00P0000AJEP00FUH0009JEP80
00=oo`H00003FUH00000008000MJEP03001JEUYF00AJEP8000=JEP8003=oo`00:Goo0`000eYF00<0
07ooOol04Goo1P001eYF00<005YFFUH00eYF0P0025YF00<005YF00000P0015YF00<005YFFUH05EYF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF10000eYF00<005YFFUH00eYF0P000UYF0`002Woo200015YF00@005YFFUIJEPH00004FUH0
05YF000cOol002Uoo`8000AJEP<001Ioo`D0009JEP03001JEUYF00EJEP8000MJEP03001JEUYF009J
EP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF0P0000=JEP00FUH01UYF1@00
2Woo1@000goo20001Woo0P0000=JEP00Ool0<Woo000XOol30004FUH00`00FUIJEP02000COol50000
0goo000000020007FUH30004FUH00`00FUIJEP06FUH60007FUH00`00FUIJEP09FUH00`00FUH00003
0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP02FUH2
0008FUH00`00FUH000030008Ool5000BOol2000dOol002Qoo`03001JEP0000=JEP03001JEUYF00=J
EP<0011oo`D000Eoo`8000AJEP04001JEUYFFUH300000eYF001JEP08FUH00`00FUIJEP02FUH80008
FUH50002FUH2000DFUH00`00FUIJEP07FUH70004FUH50005FUH20005FUH00`00FUIJEP04FUH50004
Ool3000BOol3000dOol002Qoo`03001JEUYF00=JEP03001JEUYF00AJEP04001JEP00000>Ool50007
Ool300000eYF001JEP05FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00<005YFFUH0
0UYF0P0025YF00<005YFFUH02UYF00<005YFFUH01P0015YF00<005YFFUH015YF00D005YFFUIJEP00
00EJEP04001JEP000003FUH00`00FUIJEP06FUH00`00FUIJEP04000COol200000eYF001oo`0dOol0
02Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP8000eoo`<000]oo`8000IJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0009FUH00`00FUIJEP09FUH50009FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP<0
00UJEP03001JEUYF00AJEQ<0009JEP8003Eoo`00:Goo00<005YFFUH00UYF00@005YFFUIJEPL0009J
EP<001Yoo`8000AJEP03001JEP00009JEP<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP@000AJEP03001JEUYF00QJEP03001JEUYF
00AJEP8000MJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0000fOol002Yoo`04001JEUYFFUH40003FUH01000FUIJEUYF2@0067oo0P00
00EJEP00FUIJEP0000=JEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF00<000iJEP@000UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008003Ioo`00:goo10001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0057oo0P000eYF00D0
05YFFUIJEP0000IJEPP000AJEP04001JEUYFFUH600000eYF001JEP0:FUH5000<FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0003Moo`00:Woo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P004Woo00D005YFFUIJEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEPP000MJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF
00MJEP04001JEUYFFUH70004FUH00`00FUIJEP04FUH01@00FUIJEUYF00001goo10000UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000003Qoo`00:Goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0037oo1@0000=JEP0000000eYF00<005YFFUH0
15YF00<005YFFUH065YF100025YF00<005YFFUH02eYF00<005YFFUH01eYF0`001goo0`0000=JEP00
FUH015YF00<005YFFUH00UYF00<007ooOol02Goo4`00>Woo000YOol01@00FUIJEUYF00000eYF1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF30000eYF00H005YF000005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4000:
Ool20005FUH01`00FUIJEUYF001JEP0005Moo`00:7oo0P000UYF1`001EYF2@0015YF00<005YFFUH0
1eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH045YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P0015YF
0`002Goo00<005YFFUH00UYF00L005YFFUIJEP00FUH0001GOol002Qoo`04001JEP000006Ool20007
FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP02FUH200000eYF001JEP04FUH01`00FUIJEUYF001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00iJEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF009JEP8000QJEP<000Qoo`80009JEP07001JEUYFFUH005YF0000Egoo000WOol3000:
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH20005FUH01000FUIJ
EUYF0`000eYF00<005YFFUH04UYF0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF0000
0P002EYF00<005YFFUH00P0027oo0P0015YF0P00F7oo000WOol2000=Ool300000eYF001JEP08FUH0
1000FUIJEUYF100000=JEP00FUH01eYF0`000UYF00<005YFFUH00UYF0P0000=oo`00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01eYF100035YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<0
05YFFUH00eYF0P001goo00<005YFFUH00UYF0P00F7oo000VOol4000?Ool30008FUH00`00FUIJEP08
0007FUH01P00FUIJEP00FUH000=JEP05001JEP00Ool00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04
0002FUH00`00FUIJEP05FUH20002Ool50002FUH00`00FUH0001HOol002Ioo`05001JEP00FUH0000A
Ool30004FUH01000FUIJEUYF1P000UYF0P0015YF00<005YFFUH00UYF0P000eYF0P000Woo00D005YF
FUIJEP0000IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00=JEP<000QJEP03001JEUYF00AJEP<000QJEP<000=JEP03001JEP0000<005Uoo`009Woo00<005YF
FUH00UYF00<007ooOol04Goo0`0000=JEP00FUH00UYF1P0015YF0`0000=JEP00FUH01EYF00@005YF
000000Aoo`eJEP8000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP<000EJEP04001JEUYFFUH200000eYF001JEP02FUH2001IOol002Moo`03
001JEUYF009JEP03001oogoo01=oo`<000=JEP<00003FUH005YF00IJEP8000IJEP8000Ioo`05001J
EUYFFUH00006FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`009goo
00<005YFFUH00UYF0`005Woo10000UYF00<005YFFUH01UYF00@005YF000000AJEP8000Ioo`05001J
EUYFFUH00004FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP0AFUH400000goo00000004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH20002FUH3001IOol002Qoo`05001J
EUYFFUH00002FUH2000HOol@0002FUH01000FUIJEP001Woo0eYF00D005YFFUIJEP0000AJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00@000Moo`800003FUH005YF00QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00FUH2001JOol002Uoo`03001JEP0000EJEP03
001oogoo02Eoo`<000=JEP03001oogoo00=oo`EJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EPD0009JEP8000Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP<000=JEP04001JEUYFFUH3
001JOol002Yoo`8000EJEP<002Moo`05001JEUYFFUH00005Ool01000FUIJEUYF0P001eYF00<005YF
FUH045YF100000Aoo`00FUH000EJEP8000Uoo`<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00800003FUH005YF00=JEP03001oogoo05Uoo`00:goo00<005YFFUH00eYF00<005YFFUH0
0P009Woo00<005YFFUH00P0017oo00H005YFFUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP04
0006Ool20006FUH3000:Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00Oomoo`1IOol002aoo`80009JEP03001JEUYF00=JEP8002Aoo`05001JEP00FUH00005Ool0
0eYF001JEP09FUH00`00FUIJEP07FUH5000;Ool00`00FUIJEP04FUH00`00FUIJEP02000;Ool60004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2001JOol002ioo`<000MJEP@0025oo`800003
FUH007oo00Aoo`03001JEUYF00YJEP03001JEUYF00H0015oo`8000=JEP03001JEUYF00=JEP8000mo
o`P000AJEP04001JEUYFFUH6000015YF001JEP00FWoo000`Ool20007FUH00`00FUIJEP04000NOol0
0`00FUH00006Ool20002FUH00`00FUIJEP02FUH6000IOol200000eYF001JEP06FUH3000<Ool50003
Ool80006Ool200000eYF001oo`1IOol0039oo`8000AJEP03001JEUYF00EJEPD001Moo`@000Uoo`L0
025oo`8000QJEP03001JEP0000<000Qoo`D0019oo`8005]oo`00=7oo0`0000=JEP00FUH025YF00<0
05YFFUH010003Woo1@000UYF0P00<goo0P001EYF00<005YFFUH015YF1@000goo1@004Goo0`00Fgoo
000gOol30007FUH00`00FUIJEP05FUH>0002FUH00`00FUIJEP02FUH2000eOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP07000@Ool200000eYF001oo`1KOol003Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000hOol30009FUH00`00FUIJEP04FUHC0002
FUH2001LOol003aoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
009JEP8003Yoo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH0001MOol003moo`@000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<003ioo`@0
009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005eoo`00@goo
10000UYF00<005YFFUH01UYF00@005YFFUIJEPD004Eoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol004Moo`l004moo`@0009JEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001OOol00:Uooa<0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5878 .7493 m .59527 .69506 L .56438 .68895 L p .707 .577 .707 r
F P
0 g
s
.59527 .69506 m .5878 .7493 L .61938 .75232 L p .707 .577 .707 r
F P
0 g
s
.61938 .75232 m .62685 .69808 L .59527 .69506 L p .707 .577 .707 r
F P
0 g
s
.62685 .69808 m .61938 .75232 L .64856 .75195 L p .707 .577 .707 r
F P
0 g
s
.64856 .75195 m .65602 .69771 L .62685 .69808 L p .707 .577 .707 r
F P
0 g
s
.55692 .74319 m .56438 .68895 L .53721 .68035 L p .707 .577 .707 r
F P
0 g
s
.56438 .68895 m .55692 .74319 L .5878 .7493 L p .707 .577 .707 r
F P
0 g
s
.65602 .69771 m .64856 .75195 L .67248 .74824 L p .707 .577 .707 r
F P
0 g
s
.67248 .74824 m .67994 .694 L .65602 .69771 L p .707 .577 .707 r
F P
0 g
s
.52974 .73459 m .53721 .68035 L .51641 .6701 L p .707 .577 .707 r
F P
0 g
s
.53721 .68035 m .52974 .73459 L .55692 .74319 L p .707 .577 .707 r
F P
0 g
s
.57874 .80619 m .58694 .77101 L .55656 .7622 L p .707 .577 .707 r
F P
0 g
s
.58694 .77101 m .57874 .80619 L .60986 .81164 L p .707 .577 .707 r
F P
0 g
s
.60986 .81164 m .61807 .77646 L .58694 .77101 L p .707 .577 .707 r
F P
0 g
s
.54835 .79739 m .55656 .7622 L .52988 .75091 L p .707 .577 .707 r
F P
0 g
s
.55656 .7622 m .54835 .79739 L .57874 .80619 L p .707 .577 .707 r
F P
0 g
s
.61807 .77646 m .60986 .81164 L .63869 .81321 L p .707 .577 .707 r
F P
0 g
s
.63869 .81321 m .64689 .77803 L .61807 .77646 L p .707 .577 .707 r
F P
0 g
s
.67994 .694 m .67248 .74824 L .6888 .74153 L p .707 .577 .707 r
F P
0 g
s
.6888 .74153 m .69627 .6873 L .67994 .694 L p .707 .577 .707 r
F P
0 g
s
.51641 .6701 m .50895 .72434 L .52974 .73459 L p .707 .577 .707 r
F P
0 g
s
.50895 .72434 m .51641 .6701 L .50402 .6592 L p .707 .577 .707 r
F P
0 g
s
.52988 .75091 m .52168 .78609 L .54835 .79739 L p .707 .577 .707 r
F P
0 g
s
.52168 .78609 m .52988 .75091 L .50953 .73822 L p .707 .577 .707 r
F P
0 g
s
.64689 .77803 m .63869 .81321 L .66238 .81073 L p .707 .577 .707 r
F P
0 g
s
.66238 .81073 m .67058 .77555 L .64689 .77803 L p .707 .577 .707 r
F P
0 g
s
.57159 .83972 m .5758 .82217 L .54546 .81318 L p .707 .577 .707 r
F P
0 g
s
.5758 .82217 m .57159 .83972 L .60268 .84534 L p .707 .577 .707 r
F P
0 g
s
.60268 .84534 m .60689 .82779 L .5758 .82217 L p .707 .577 .707 r
F P
0 g
s
.54125 .83073 m .54546 .81318 L .51883 .8017 L p .707 .577 .707 r
F P
0 g
s
.54546 .81318 m .54125 .83073 L .57159 .83972 L p .707 .577 .707 r
F P
0 g
s
.60689 .82779 m .60268 .84534 L .63147 .84703 L p .707 .577 .707 r
F P
0 g
s
.63147 .84703 m .63568 .82948 L .60689 .82779 L p .707 .577 .707 r
F P
0 g
s
.51883 .8017 m .51461 .81925 L .54125 .83073 L p .707 .577 .707 r
F P
0 g
s
.50953 .73822 m .50133 .77341 L .52168 .78609 L p .707 .577 .707 r
F P
0 g
s
.50402 .6592 m .49656 .71344 L .50895 .72434 L p .707 .577 .707 r
F P
0 g
s
.51461 .81925 m .51883 .8017 L .49852 .78886 L p .707 .577 .707 r
F P
0 g
s
.63568 .82948 m .63147 .84703 L .65514 .84464 L p .707 .577 .707 r
F P
0 g
s
.65514 .84464 m .65935 .82709 L .63568 .82948 L p .707 .577 .707 r
F P
0 g
s
.50133 .77341 m .50953 .73822 L .4975 .7254 L p .707 .577 .707 r
F P
0 g
s
.67058 .77555 m .66238 .81073 L .67862 .80446 L p .707 .577 .707 r
F P
0 g
s
.67862 .80446 m .68683 .76928 L .67058 .77555 L p .707 .577 .707 r
F P
0 g
s
.69627 .6873 m .6888 .74153 L .69593 .7325 L p .707 .577 .707 r
F P
0 g
s
.69593 .7325 m .7034 .67826 L .69627 .6873 L p .707 .577 .707 r
F P
0 g
s
.49852 .78886 m .49431 .80641 L .51461 .81925 L p .707 .577 .707 r
F P
0 g
s
.49656 .71344 m .50402 .6592 L .50126 .64873 L p .707 .577 .707 r
F P
0 g
s
.4975 .7254 m .4893 .76058 L .50133 .77341 L p .707 .577 .707 r
F P
0 g
s
.49431 .80641 m .49852 .78886 L .48652 .7759 L p .707 .577 .707 r
F P
0 g
s
.65935 .82709 m .65514 .84464 L .67138 .8384 L p .707 .577 .707 r
F P
0 g
s
.67138 .8384 m .67559 .82085 L .65935 .82709 L p .707 .577 .707 r
F P
0 g
s
.50126 .64873 m .49379 .70297 L .49656 .71344 L p .707 .577 .707 r
F P
0 g
s
.48652 .7759 m .48231 .79345 L .49431 .80641 L p .707 .577 .707 r
F P
0 g
s
.4893 .76058 m .4975 .7254 L .49497 .71368 L p .707 .577 .707 r
F P
0 g
s
.68683 .76928 m .67862 .80446 L .68583 .795 L p .707 .577 .707 r
F P
0 g
s
.68583 .795 m .69404 .75982 L .68683 .76928 L p .707 .577 .707 r
F P
0 g
s
.7034 .67826 m .69593 .7325 L .69317 .72203 L p .707 .577 .707 r
F P
0 g
s
.69317 .72203 m .70063 .66779 L .7034 .67826 L p .707 .577 .707 r
F P
0 g
s
.49379 .70297 m .50126 .64873 L .50839 .6397 L p .707 .577 .707 r
F P
0 g
s
.49497 .71368 m .48676 .74886 L .4893 .76058 L p .707 .577 .707 r
F P
0 g
s
.48231 .79345 m .48652 .7759 L .484 .7641 L p .707 .577 .707 r
F P
0 g
s
.67559 .82085 m .67138 .8384 L .67859 .82891 L p .707 .577 .707 r
F P
0 g
s
.67859 .82891 m .68281 .81136 L .67559 .82085 L p .707 .577 .707 r
F P
0 g
s
.484 .7641 m .47979 .78165 L .48231 .79345 L p .707 .577 .707 r
F P
0 g
s
.50839 .6397 m .50092 .69394 L .49379 .70297 L p .707 .577 .707 r
F P
0 g
s
.48676 .74886 m .49497 .71368 L .50217 .70422 L p .707 .577 .707 r
F P
0 g
s
.69404 .75982 m .68583 .795 L .68329 .78328 L p .707 .577 .707 r
F P
0 g
s
.68329 .78328 m .6915 .7481 L .69404 .75982 L p .707 .577 .707 r
F P
0 g
s
.70063 .66779 m .69317 .72203 L .68078 .71113 L p .707 .577 .707 r
F P
0 g
s
.68078 .71113 m .68824 .65689 L .70063 .66779 L p .707 .577 .707 r
F P
0 g
s
.50092 .69394 m .50839 .6397 L .52471 .633 L p .707 .577 .707 r
F P
0 g
s
.50217 .70422 m .49397 .7394 L .48676 .74886 L p .707 .577 .707 r
F P
0 g
s
.24479 .71903 m .25226 .66479 L .22137 .65868 L p .707 .577 .707 r
F P
0 g
s
.25226 .66479 m .24479 .71903 L .27637 .72205 L p .707 .577 .707 r
F P
0 g
s
.27637 .72205 m .28384 .66781 L .25226 .66479 L p .707 .577 .707 r
F P
0 g
s
.28384 .66781 m .27637 .72205 L .30555 .72168 L p .707 .577 .707 r
F P
0 g
s
.30555 .72168 m .31301 .66744 L .28384 .66781 L p .707 .577 .707 r
F P
0 g
s
.47979 .78165 m .484 .7641 L .49122 .75461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21391 .71292 m .22137 .65868 L .1942 .65008 L p .707 .577 .707 r
F P
0 g
s
.22137 .65868 m .21391 .71292 L .24479 .71903 L p .707 .577 .707 r
F P
0 g
s
.68281 .81136 m .67859 .82891 L .67608 .81711 L p .707 .577 .707 r
F P
0 g
s
.67608 .81711 m .68029 .79956 L .68281 .81136 L p .707 .577 .707 r
F P
0 g
s
.49122 .75461 m .487 .77216 L .47979 .78165 L p .707 .577 .707 r
F P
0 g
s
.52471 .633 m .51725 .68723 L .50092 .69394 L p .707 .577 .707 r
F P
0 g
s
.49397 .7394 m .50217 .70422 L .51842 .69795 L p .707 .577 .707 r
F P
0 g
s
.6915 .7481 m .68329 .78328 L .67126 .77046 L p .707 .577 .707 r
F P
0 g
s
.67126 .77046 m .67947 .73527 L .6915 .7481 L p .707 .577 .707 r
F P
0 g
s
.31301 .66744 m .30555 .72168 L .32947 .71796 L p .707 .577 .707 r
F P
0 g
s
.32947 .71796 m .33694 .66372 L .31301 .66744 L p .707 .577 .707 r
F P
0 g
s
.68824 .65689 m .68078 .71113 L .65998 .70088 L p .707 .577 .707 r
F P
0 g
s
.65998 .70088 m .66745 .64664 L .68824 .65689 L p .707 .577 .707 r
F P
0 g
s
.18674 .70432 m .1942 .65008 L .1734 .63983 L p .707 .577 .707 r
F P
0 g
s
.1942 .65008 m .18674 .70432 L .21391 .71292 L p .707 .577 .707 r
F P
0 g
s
.51725 .68723 m .52471 .633 L .54863 .62928 L p .707 .577 .707 r
F P
0 g
s
.48678 .79716 m .34228 .30268 L .30016 .31302 L p .707 .577 .707 r
F P
0 g
s
.51842 .69795 m .51021 .73313 L .49397 .7394 L p .707 .577 .707 r
F P
0 g
s
.487 .77216 m .49122 .75461 L .50746 .74836 L p .707 .577 .707 r
F P
0 g
s
.50746 .74836 m .50324 .76592 L .487 .77216 L p .707 .577 .707 r
F P
0 g
s
.50324 .76592 m .50746 .74836 L .53113 .74597 L p .707 .577 .707 r
F P
0 g
s
.53113 .74597 m .52691 .76353 L .50324 .76592 L p .707 .577 .707 r
F P
0 g
s
.34228 .30268 m .48678 .79716 L .53002 .78431 L p .707 .577 .707 r
F P
0 g
s
.51021 .73313 m .51842 .69795 L .54211 .69547 L p .707 .577 .707 r
F P
0 g
s
.54211 .69547 m .53391 .73065 L .51021 .73313 L p .707 .577 .707 r
F P
0 g
s
.53002 .78431 m .38552 .28983 L .34228 .30268 L p .707 .577 .707 r
F P
0 g
s
.54863 .62928 m .54117 .68352 L .51725 .68723 L p .707 .577 .707 r
F P
0 g
s
.53391 .73065 m .54211 .69547 L .57093 .69704 L p .707 .577 .707 r
F P
0 g
s
.57093 .69704 m .56273 .73222 L .53391 .73065 L p .707 .577 .707 r
F P
0 g
s
.52691 .76353 m .53113 .74597 L .55992 .74767 L p .707 .577 .707 r
F P
0 g
s
.55992 .74767 m .5557 .76522 L .52691 .76353 L p .707 .577 .707 r
F P
0 g
s
.5557 .76522 m .55992 .74767 L .59101 .75328 L p .707 .577 .707 r
F P
0 g
s
.59101 .75328 m .58679 .77084 L .5557 .76522 L p .707 .577 .707 r
F P
0 g
s
.38552 .28983 m .53002 .78431 L .57014 .77021 L p .707 .577 .707 r
F P
0 g
s
.54117 .68352 m .54863 .62928 L .57781 .62891 L p .707 .577 .707 r
F P
0 g
s
.57781 .62891 m .57035 .68315 L .54117 .68352 L p .707 .577 .707 r
F P
0 g
s
.57014 .77021 m .42565 .27573 L .38552 .28983 L p .707 .577 .707 r
F P
0 g
s
.23573 .78596 m .24393 .75078 L .21355 .74198 L p .707 .577 .707 r
F P
0 g
s
.24393 .75078 m .23573 .78596 L .26686 .79141 L p .707 .577 .707 r
F P
0 g
s
.26686 .79141 m .27506 .75623 L .24393 .75078 L p .707 .577 .707 r
F P
0 g
s
.20534 .77716 m .21355 .74198 L .18687 .73068 L p .707 .577 .707 r
F P
0 g
s
.21355 .74198 m .20534 .77716 L .23573 .78596 L p .707 .577 .707 r
F P
0 g
s
.27506 .75623 m .26686 .79141 L .29568 .79298 L p .707 .577 .707 r
F P
0 g
s
.29568 .79298 m .30388 .7578 L .27506 .75623 L p .707 .577 .707 r
F P
0 g
s
.68029 .79956 m .67608 .81711 L .66408 .80415 L p .707 .577 .707 r
F P
0 g
s
.66408 .80415 m .66829 .7866 L .68029 .79956 L p .707 .577 .707 r
F P
0 g
s
.44466 .80751 m .30016 .31302 L .26329 .31985 L p .707 .577 .707 r
F P
0 g
s
.30016 .31302 m .44466 .80751 L .48678 .79716 L p .707 .577 .707 r
F P
0 g
s
.33694 .66372 m .32947 .71796 L .34579 .71126 L p .707 .577 .707 r
F P
0 g
s
.34579 .71126 m .35326 .65702 L .33694 .66372 L p .707 .577 .707 r
F P
0 g
s
.1734 .63983 m .16594 .69407 L .18674 .70432 L p .707 .577 .707 r
F P
0 g
s
.66745 .64664 m .65998 .70088 L .63281 .69228 L p .707 .577 .707 r
F P
0 g
s
.63281 .69228 m .64027 .63804 L .66745 .64664 L p .707 .577 .707 r
F P
0 g
s
.57035 .68315 m .57781 .62891 L .60939 .63193 L p .707 .577 .707 r
F P
0 g
s
.60939 .63193 m .60192 .68617 L .57035 .68315 L p .707 .577 .707 r
F P
0 g
s
.56273 .73222 m .57093 .69704 L .60206 .70249 L p .707 .577 .707 r
F P
0 g
s
.63245 .71129 m .62424 .74648 L .59385 .73767 L p .707 .577 .707 r
F P
0 g
s
.59385 .73767 m .60206 .70249 L .63245 .71129 L p .707 .577 .707 r
F P
0 g
s
.60206 .70249 m .59385 .73767 L .56273 .73222 L p .707 .577 .707 r
F P
0 g
s
.58679 .77084 m .59101 .75328 L .62135 .76227 L p .707 .577 .707 r
F P
0 g
s
.42565 .27573 m .57014 .77021 L .60323 .75625 L p .707 .577 .707 r
F P
0 g
s
.60323 .75625 m .45874 .26176 L .42565 .27573 L p .707 .577 .707 r
F P
0 g
s
.16594 .69407 m .1734 .63983 L .16102 .62893 L p .707 .577 .707 r
F P
0 g
s
.67947 .73527 m .67126 .77046 L .65092 .75777 L p .707 .577 .707 r
F P
0 g
s
.65092 .75777 m .65912 .72259 L .67947 .73527 L p .707 .577 .707 r
F P
0 g
s
.18687 .73068 m .17867 .76586 L .20534 .77716 L p .707 .577 .707 r
F P
0 g
s
.17867 .76586 m .18687 .73068 L .16653 .71799 L p .707 .577 .707 r
F P
0 g
s
.30388 .7578 m .29568 .79298 L .31937 .7905 L p .707 .577 .707 r
F P
0 g
s
.31937 .7905 m .32758 .75532 L .30388 .7578 L p .707 .577 .707 r
F P
0 g
s
.22858 .83541 m .23279 .81786 L .20245 .80887 L p .707 .577 .707 r
F P
0 g
s
.23279 .81786 m .22858 .83541 L .25967 .84103 L p .707 .577 .707 r
F P
0 g
s
.25967 .84103 m .26388 .82347 L .23279 .81786 L p .707 .577 .707 r
F P
0 g
s
.64027 .63804 m .63281 .69228 L .60192 .68617 L p .707 .577 .707 r
F P
0 g
s
.60192 .68617 m .60939 .63193 L .64027 .63804 L p .707 .577 .707 r
F P
0 g
s
.19824 .82642 m .20245 .80887 L .17582 .79739 L p .707 .577 .707 r
F P
0 g
s
.20245 .80887 m .19824 .82642 L .22858 .83541 L p .707 .577 .707 r
F P
0 g
s
.26388 .82347 m .25967 .84103 L .28846 .84272 L p .707 .577 .707 r
F P
0 g
s
.28846 .84272 m .29267 .82517 L .26388 .82347 L p .707 .577 .707 r
F P
0 g
s
.16653 .71799 m .15832 .75318 L .17867 .76586 L p .707 .577 .707 r
F P
0 g
s
.16102 .62893 m .15355 .68317 L .16594 .69407 L p .707 .577 .707 r
F P
0 g
s
.35326 .65702 m .34579 .71126 L .35292 .70223 L p .707 .577 .707 r
F P
0 g
s
.35292 .70223 m .36039 .64799 L .35326 .65702 L p .707 .577 .707 r
F P
0 g
s
.36039 .64799 m .35292 .70223 L .35099 .6949 L p .707 .577 .707 r
F P
0 g
s
.35099 .6949 m .35016 .69175 L p .35376 .67633 L .707 .577 .707 r
F P
0 g
s
.35376 .67633 m .36039 .64799 L .35099 .6949 L .707 .577 .707 r
F
.40778 .81434 m .44466 .80751 L p .36584 .59557 L F P
0 g
s
.26329 .31985 m .3584 .64533 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.35016 .69175 m .3515 .68198 L p .36039 .64799 L .707 .577 .707 r
F P
0 g
s
.26329 .31985 m .23527 .32249 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .26329 .31985 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.35893 .64248 m .36039 .64799 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .40778 .81434 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .34459 .69663 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35016 .69175 L .34785 .68972 L p .707 .577 .707 r
F P
0 g
s
.34459 .69663 m .37976 .81698 L p .35715 .66999 L .707 .577 .707 r
F P
0 g
s
.23527 .32249 m .21884 .32069 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.37976 .81698 m .35371 .72782 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.35371 .72782 m .23527 .32249 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32778 .67594 m .32205 .67311 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.32205 .67311 m .31697 .67061 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .32155 .66348 L .32205 .67311 L .707 .577 .707 r
F
.21884 .32069 m .21562 .31462 L p .2962 .58767 L F P
0 g
s
.34282 .77477 m .35103 .73959 L .34382 .74905 L p .707 .577 .707 r
F P
0 g
s
.33561 .78423 m .34382 .74905 L .32758 .75532 L p .707 .577 .707 r
F P
0 g
s
.34382 .74905 m .33561 .78423 L .34282 .77477 L p .707 .577 .707 r
F P
0 g
s
.35103 .73959 m .34282 .77477 L .34028 .76306 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .34849 .72787 L .35103 .73959 L p .707 .577 .707 r
F P
0 g
s
.34028 .76306 m .32825 .75023 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34849 .72787 m .34439 .74544 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.34439 .74544 m .34028 .76306 L p .34129 .73582 L .707 .577 .707 r
F P
0 g
s
.31991 .66604 m .31873 .65783 L .32155 .66348 L .707 .577 .707 r
F
.31697 .67061 m .31832 .66079 L p .31991 .66604 L F P
0 g
s
.31832 .66079 m .31873 .65783 L p .31991 .66604 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .33646 .71505 L .34849 .72787 L p .707 .577 .707 r
F P
0 g
s
.31697 .67061 m .2898 .66201 L p .3106 .6346 L .707 .577 .707 r
F P
0 g
s
.3106 .6346 m .31136 .63718 L .31697 .67061 L .707 .577 .707 r
F
.31873 .65783 m .31697 .67061 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .21884 .32069 L p .26526 .48089 L .707 .577 .707 r
F P
0 g
s
.21884 .32069 m .30766 .62464 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.34558 .71155 m .30766 .62464 L .31873 .65783 L .707 .577 .707 r
F
.2898 .66201 m .29727 .60777 L .32444 .61637 L p F P
0 g
s
.31542 .6512 m .30766 .62464 L p .2962 .58767 L .707 .577 .707 r
F P
0 g
s
.30766 .62464 m .26526 .48089 L .2962 .58767 L .707 .577 .707 r
F
.3106 .6346 m .31087 .63425 L .31136 .63718 L F
.32444 .61637 m .31873 .65783 L p .31087 .63425 L F P
0 g
s
.30766 .62464 m .31542 .6512 L p .31873 .65783 L .707 .577 .707 r
F P
0 g
s
.21562 .31462 m .22592 .30488 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32825 .75023 m .32602 .74884 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.3214 .72691 m .33501 .71619 L .32602 .74884 L .707 .577 .707 r
F
.33646 .71505 m .33568 .7184 L p .33501 .71619 L F P
0 g
s
.33568 .7184 m .32825 .75023 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .31611 .70236 L .33424 .71366 L p .707 .577 .707 r
F P
0 g
s
.33424 .71366 m .33646 .71505 L p .33501 .71619 L .707 .577 .707 r
F P
0 g
s
.30791 .73754 m .33424 .71366 L .33501 .71619 L .707 .577 .707 r
F
.27313 .51142 m .28343 .54666 L p .2962 .58767 L F P
0 g
s
.28343 .54666 m .36012 .8091 L p .30166 .60659 L .707 .577 .707 r
F P
0 g
s
.2962 .58767 m .28343 .54666 L .30166 .60659 L .707 .577 .707 r
F
.36012 .8091 m .36334 .81518 L p .30572 .61994 L F P
0 g
s
.30572 .61994 m .2962 .58767 L .30166 .60659 L .707 .577 .707 r
F
.30572 .61994 m .30166 .60659 L .36012 .8091 L F
.21562 .31462 m .27313 .51142 L p .2962 .58767 L F P
0 g
s
.325 .68525 m .31542 .6512 L .2962 .58767 L .707 .577 .707 r
F
.36334 .81518 m .32902 .69774 L p .325 .68525 L F P
0 g
s
.32902 .69774 m .31542 .6512 L p .325 .68525 L .707 .577 .707 r
F P
0 g
s
.31542 .6512 m .36334 .81518 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.31873 .65783 m .32444 .61637 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.36012 .8091 m .28343 .54666 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.28343 .54666 m .21562 .31462 L p .25743 .42328 L .707 .577 .707 r
F P
0 g
s
.32602 .74884 m .30791 .73754 L p .3214 .72691 L .707 .577 .707 r
F P
0 g
s
.36334 .81518 m .37976 .81698 L p .34558 .71155 L .707 .577 .707 r
F P
0 g
s
.32444 .61637 m .34523 .62662 L p .32155 .66348 L .707 .577 .707 r
F P
0 g
s
.34523 .62662 m .33777 .68086 L .32778 .67594 L p .707 .577 .707 r
F P
0 g
s
.32155 .66348 m .34523 .62662 L .32778 .67594 L .707 .577 .707 r
F
.35762 .63752 m .3515 .68198 L p .33777 .68086 L F P
0 g
s
.34785 .68972 m .33777 .68086 L p .3515 .68198 L .707 .577 .707 r
F P
0 g
s
.3515 .68198 m .35762 .63752 L .35893 .64248 L p .707 .577 .707 r
F P
0 g
s
.40778 .81434 m .3584 .64533 L p .35494 .66369 L .707 .577 .707 r
F P
0 g
s
.3584 .64533 m .40778 .81434 L p .36584 .59557 L .707 .577 .707 r
F P
0 g
s
.17582 .79739 m .17161 .81494 L .19824 .82642 L p .707 .577 .707 r
F P
0 g
s
.66829 .7866 m .66408 .80415 L .64377 .7913 L p .707 .577 .707 r
F P
0 g
s
.64377 .7913 m .64798 .77375 L .66829 .7866 L p .707 .577 .707 r
F P
0 g
s
.65912 .72259 m .65092 .75777 L .62424 .74648 L p .707 .577 .707 r
F P
0 g
s
.62424 .74648 m .63245 .71129 L .65912 .72259 L p .707 .577 .707 r
F P
0 g
s
.15832 .75318 m .16653 .71799 L .15449 .70517 L p .707 .577 .707 r
F P
0 g
s
.32758 .75532 m .31937 .7905 L .33561 .78423 L p .707 .577 .707 r
F P
0 g
s
.45874 .26176 m .60323 .75625 L .62604 .74378 L p .707 .577 .707 r
F P
0 g
s
.62604 .74378 m .48155 .2493 L .45874 .26176 L p .707 .577 .707 r
F P
0 g
s
.17161 .81494 m .17582 .79739 L .15551 .78454 L p .707 .577 .707 r
F P
0 g
s
.29267 .82517 m .28846 .84272 L .31213 .84033 L p .707 .577 .707 r
F P
0 g
s
.31213 .84033 m .31634 .82278 L .29267 .82517 L p .707 .577 .707 r
F P
0 g
s
.15355 .68317 m .16102 .62893 L .15825 .61846 L p .707 .577 .707 r
F P
0 g
s
.15551 .78454 m .1513 .80209 L .17161 .81494 L p .707 .577 .707 r
F P
0 g
s
.15449 .70517 m .14629 .74035 L .15832 .75318 L p .707 .577 .707 r
F P
0 g
s
.64798 .77375 m .64377 .7913 L .61714 .77983 L p .707 .577 .707 r
F P
0 g
s
.61714 .77983 m .62135 .76227 L .64798 .77375 L p .707 .577 .707 r
F P
0 g
s
.15825 .61846 m .15078 .67269 L .15355 .68317 L p .707 .577 .707 r
F P
0 g
s
.1513 .80209 m .15551 .78454 L .14351 .77158 L p .707 .577 .707 r
F P
0 g
s
.31634 .82278 m .31213 .84033 L .32837 .83408 L p .707 .577 .707 r
F P
0 g
s
.32837 .83408 m .33258 .81653 L .31634 .82278 L p .707 .577 .707 r
F P
0 g
s
.14629 .74035 m .15449 .70517 L .15196 .69345 L p .707 .577 .707 r
F P
0 g
s
.14351 .77158 m .1393 .78914 L .1513 .80209 L p .707 .577 .707 r
F P
0 g
s
.62135 .76227 m .61714 .77983 L .58679 .77084 L p .707 .577 .707 r
F P
0 g
s
.15078 .67269 m .15825 .61846 L .16538 .60942 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.48155 .2493 m .62604 .74378 L .63634 .73404 L p .707 .577 .707 r
F P
0 g
s
.63634 .73404 m .49185 .23955 L .48155 .2493 L p .707 .577 .707 r
F P
0 g
s
.15196 .69345 m .14375 .72863 L .14629 .74035 L p .707 .577 .707 r
F P
0 g
s
.1393 .78914 m .14351 .77158 L .14099 .75978 L p .707 .577 .707 r
F P
0 g
s
.33258 .81653 m .32837 .83408 L .33558 .8246 L p .707 .577 .707 r
F P
0 g
s
.33558 .8246 m .3398 .80705 L .33258 .81653 L p .707 .577 .707 r
F P
0 g
s
.16538 .60942 m .15791 .66366 L .15078 .67269 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14375 .72863 m .15196 .69345 L .15917 .68399 L p .707 .577 .707 r
F P
0 g
s
.14099 .75978 m .13678 .77734 L .1393 .78914 L p .707 .577 .707 r
F P
0 g
s
.33777 .68086 m .34523 .62662 L .35762 .63752 L p .707 .577 .707 r
F P
0 g
s
.15791 .66366 m .16538 .60942 L .1817 .60272 L p .707 .577 .707 r
F P
0 g
s
.15917 .68399 m .15096 .71918 L .14375 .72863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13678 .77734 m .14099 .75978 L .14821 .7503 L p .707 .577 .707 r
F P
0 g
s
.49185 .23955 m .63634 .73404 L .63312 .72797 L p .707 .577 .707 r
F P
0 g
s
.63312 .72797 m .48863 .23348 L .49185 .23955 L p .707 .577 .707 r
F P
0 g
s
.3398 .80705 m .33558 .8246 L .33307 .8128 L p .707 .577 .707 r
F P
0 g
s
.33307 .8128 m .33728 .79525 L .3398 .80705 L p .707 .577 .707 r
F P
0 g
s
.1817 .60272 m .17424 .65696 L .15791 .66366 L p .707 .577 .707 r
F P
0 g
s
.14821 .7503 m .14399 .76785 L .13678 .77734 L p .707 .577 .707 r
F P
0 g
s
.15096 .71918 m .15917 .68399 L .17541 .67772 L p .707 .577 .707 r
F P
0 g
s
.17424 .65696 m .1817 .60272 L .20562 .59901 L p .707 .577 .707 r
F P
0 g
s
.17541 .67772 m .1672 .7129 L .15096 .71918 L p .707 .577 .707 r
F P
0 g
s
.20562 .59901 m .19816 .65325 L .17424 .65696 L p .707 .577 .707 r
F P
0 g
s
.14399 .76785 m .14821 .7503 L .16445 .74405 L p .707 .577 .707 r
F P
0 g
s
.33728 .79525 m .33307 .8128 L .32107 .79984 L p .707 .577 .707 r
F P
0 g
s
.32107 .79984 m .32528 .78229 L .33728 .79525 L p .707 .577 .707 r
F P
0 g
s
.19816 .65325 m .20562 .59901 L .2348 .59864 L p .707 .577 .707 r
F P
0 g
s
.1672 .7129 m .17541 .67772 L .1991 .67524 L p .707 .577 .707 r
F P
0 g
s
.16445 .74405 m .16023 .7616 L .14399 .76785 L p .707 .577 .707 r
F P
0 g
s
.29727 .60777 m .2898 .66201 L .25891 .6559 L p .707 .577 .707 r
F P
0 g
s
.25891 .6559 m .26638 .60166 L .29727 .60777 L p .707 .577 .707 r
F P
0 g
s
.22734 .65288 m .2348 .59864 L .26638 .60166 L p .707 .577 .707 r
F P
0 g
s
.2348 .59864 m .22734 .65288 L .19816 .65325 L p .707 .577 .707 r
F P
0 g
s
.48863 .23348 m .63312 .72797 L .6167 .72616 L p .707 .577 .707 r
F P
0 g
s
.6167 .72616 m .4722 .23168 L .48863 .23348 L p .707 .577 .707 r
F P
0 g
s
.1991 .67524 m .1909 .71043 L .1672 .7129 L p .707 .577 .707 r
F P
0 g
s
.26638 .60166 m .25891 .6559 L .22734 .65288 L p .707 .577 .707 r
F P
0 g
s
.72501 .65726 m .73247 .60302 L .70159 .59691 L p .707 .577 .707 r
F P
0 g
s
.73247 .60302 m .72501 .65726 L .75658 .66028 L p .707 .577 .707 r
F P
0 g
s
.75658 .66028 m .76405 .60604 L .73247 .60302 L p .707 .577 .707 r
F P
0 g
s
.76405 .60604 m .75658 .66028 L .78576 .65991 L p .707 .577 .707 r
F P
0 g
s
.78576 .65991 m .79323 .60567 L .76405 .60604 L p .707 .577 .707 r
F P
0 g
s
.1909 .71043 m .1991 .67524 L .22792 .67681 L p .707 .577 .707 r
F P
0 g
s
.31611 .70236 m .30791 .73754 L .28123 .72625 L p .707 .577 .707 r
F P
0 g
s
.28123 .72625 m .28944 .69107 L .31611 .70236 L p .707 .577 .707 r
F P
0 g
s
.69412 .65115 m .70159 .59691 L .67441 .58831 L p .707 .577 .707 r
F P
0 g
s
.70159 .59691 m .69412 .65115 L .72501 .65726 L p .707 .577 .707 r
F P
0 g
s
.16023 .7616 m .16445 .74405 L .18812 .74166 L p .707 .577 .707 r
F P
0 g
s
.32528 .78229 m .32107 .79984 L .30076 .78699 L p .707 .577 .707 r
F P
0 g
s
.30076 .78699 m .30497 .76944 L .32528 .78229 L p .707 .577 .707 r
F P
0 g
s
.18812 .74166 m .1839 .75921 L .16023 .7616 L p .707 .577 .707 r
F P
0 g
s
.79323 .60567 m .78576 .65991 L .80968 .6562 L p .707 .577 .707 r
F P
0 g
s
.80968 .6562 m .81715 .60196 L .79323 .60567 L p .707 .577 .707 r
F P
0 g
s
.22792 .67681 m .21972 .71199 L .1909 .71043 L p .707 .577 .707 r
F P
0 g
s
.21972 .71199 m .22792 .67681 L .25905 .68226 L p .707 .577 .707 r
F P
0 g
s
.28944 .69107 m .28123 .72625 L .25084 .71744 L p .707 .577 .707 r
F P
0 g
s
.25084 .71744 m .25905 .68226 L .28944 .69107 L p .707 .577 .707 r
F P
0 g
s
.66695 .64255 m .67441 .58831 L .65362 .57806 L p .707 .577 .707 r
F P
0 g
s
.67441 .58831 m .66695 .64255 L .69412 .65115 L p .707 .577 .707 r
F P
0 g
s
.25905 .68226 m .25084 .71744 L .21972 .71199 L p .707 .577 .707 r
F P
0 g
s
.71594 .71415 m .72415 .67897 L .69376 .67017 L p .707 .577 .707 r
F P
0 g
s
.72415 .67897 m .71594 .71415 L .74707 .7196 L p .707 .577 .707 r
F P
0 g
s
.74707 .7196 m .75528 .68442 L .72415 .67897 L p .707 .577 .707 r
F P
0 g
s
.1839 .75921 m .18812 .74166 L .21691 .74335 L p .707 .577 .707 r
F P
0 g
s
.30497 .76944 m .30076 .78699 L .27413 .77551 L p .707 .577 .707 r
F P
0 g
s
.27413 .77551 m .27834 .75796 L .30497 .76944 L p .707 .577 .707 r
F P
0 g
s
.68555 .70535 m .69376 .67017 L .66709 .65887 L p .707 .577 .707 r
F P
0 g
s
.69376 .67017 m .68555 .70535 L .71594 .71415 L p .707 .577 .707 r
F P
0 g
s
.37041 .79936 m .22592 .30488 L .24873 .29241 L p .707 .577 .707 r
F P
0 g
s
.22592 .30488 m .37041 .79936 L .36012 .8091 L p .707 .577 .707 r
F P
0 g
s
.75528 .68442 m .74707 .7196 L .77589 .72117 L p .707 .577 .707 r
F P
0 g
s
.77589 .72117 m .7841 .68599 L .75528 .68442 L p .707 .577 .707 r
F P
0 g
s
.21691 .74335 m .21269 .76091 L .1839 .75921 L p .707 .577 .707 r
F P
0 g
s
.4722 .23168 m .6167 .72616 L .58867 .72881 L p .707 .577 .707 r
F P
0 g
s
.58867 .72881 m .44418 .23432 L .4722 .23168 L p .707 .577 .707 r
F P
0 g
s
.81715 .60196 m .80968 .6562 L .82601 .6495 L p .707 .577 .707 r
F P
0 g
s
.82601 .6495 m .83347 .59526 L .81715 .60196 L p .707 .577 .707 r
F P
0 g
s
.65362 .57806 m .64615 .6323 L .66695 .64255 L p .707 .577 .707 r
F P
0 g
s
.21269 .76091 m .21691 .74335 L .248 .74897 L p .707 .577 .707 r
F P
0 g
s
.27834 .75796 m .27413 .77551 L .24378 .76652 L p .707 .577 .707 r
F P
0 g
s
.24378 .76652 m .248 .74897 L .27834 .75796 L p .707 .577 .707 r
F P
0 g
s
.64615 .6323 m .65362 .57806 L .64123 .56717 L p .707 .577 .707 r
F P
0 g
s
.66709 .65887 m .65888 .69405 L .68555 .70535 L p .707 .577 .707 r
F P
0 g
s
.65888 .69405 m .66709 .65887 L .64674 .64618 L p .707 .577 .707 r
F P
0 g
s
.7841 .68599 m .77589 .72117 L .79958 .71869 L p .707 .577 .707 r
F P
0 g
s
.79958 .71869 m .80779 .68351 L .7841 .68599 L p .707 .577 .707 r
F P
0 g
s
.70879 .74769 m .71301 .73013 L .68266 .72114 L p .707 .577 .707 r
F P
0 g
s
.71301 .73013 m .70879 .74769 L .73988 .7533 L p .707 .577 .707 r
F P
0 g
s
.73988 .7533 m .7441 .73575 L .71301 .73013 L p .707 .577 .707 r
F P
0 g
s
.248 .74897 m .24378 .76652 L .21269 .76091 L p .707 .577 .707 r
F P
0 g
s
.67845 .7387 m .68266 .72114 L .65603 .70966 L p .707 .577 .707 r
F P
0 g
s
.68266 .72114 m .67845 .7387 L .70879 .74769 L p .707 .577 .707 r
F P
0 g
s
.7441 .73575 m .73988 .7533 L .76867 .755 L p .707 .577 .707 r
F P
0 g
s
.76867 .755 m .77289 .73744 L .7441 .73575 L p .707 .577 .707 r
F P
0 g
s
.65603 .70966 m .65182 .72722 L .67845 .7387 L p .707 .577 .707 r
F P
0 g
s
.64674 .64618 m .63853 .68137 L .65888 .69405 L p .707 .577 .707 r
F P
0 g
s
.64123 .56717 m .63376 .6214 L .64615 .6323 L p .707 .577 .707 r
F P
0 g
s
.65182 .72722 m .65603 .70966 L .63572 .69682 L p .707 .577 .707 r
F P
0 g
s
.77289 .73744 m .76867 .755 L .79235 .75261 L p .707 .577 .707 r
F P
0 g
s
.79235 .75261 m .79656 .73505 L .77289 .73744 L p .707 .577 .707 r
F P
0 g
s
.63853 .68137 m .64674 .64618 L .63471 .63336 L p .707 .577 .707 r
F P
0 g
s
.80779 .68351 m .79958 .71869 L .81583 .71242 L p .707 .577 .707 r
F P
0 g
s
.81583 .71242 m .82403 .67724 L .80779 .68351 L p .707 .577 .707 r
F P
0 g
s
.83347 .59526 m .82601 .6495 L .83314 .64046 L p .707 .577 .707 r
F P
0 g
s
.83314 .64046 m .8406 .58623 L .83347 .59526 L p .707 .577 .707 r
F P
0 g
s
.24873 .29241 m .39322 .78689 L .37041 .79936 L p .707 .577 .707 r
F P
0 g
s
.39322 .78689 m .24873 .29241 L .28182 .27845 L p .707 .577 .707 r
F P
0 g
s
.63572 .69682 m .63151 .71437 L .65182 .72722 L p .707 .577 .707 r
F P
0 g
s
.63376 .6214 m .64123 .56717 L .63846 .55669 L p .707 .577 .707 r
F P
0 g
s
.44418 .23432 m .58867 .72881 L .5518 .73564 L p .707 .577 .707 r
F P
0 g
s
.5518 .73564 m .40731 .24115 L .44418 .23432 L p .707 .577 .707 r
F P
0 g
s
.63471 .63336 m .6265 .66854 L .63853 .68137 L p .707 .577 .707 r
F P
0 g
s
.63151 .71437 m .63572 .69682 L .62372 .68386 L p .707 .577 .707 r
F P
0 g
s
.79656 .73505 m .79235 .75261 L .80858 .74636 L p .707 .577 .707 r
F P
0 g
s
.80858 .74636 m .8128 .72881 L .79656 .73505 L p .707 .577 .707 r
F P
0 g
s
.63846 .55669 m .631 .61093 L .63376 .6214 L p .707 .577 .707 r
F P
0 g
s
.62372 .68386 m .61951 .70141 L .63151 .71437 L p .707 .577 .707 r
F P
0 g
s
.6265 .66854 m .63471 .63336 L .63217 .62164 L p .707 .577 .707 r
F P
0 g
s
.82403 .67724 m .81583 .71242 L .82303 .70296 L p .707 .577 .707 r
F P
0 g
s
.82303 .70296 m .83124 .66778 L .82403 .67724 L p .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .3784 .60896 L p .40363 .66239 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .37064 .58239 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38376 .6142 L .40363 .66239 L .707 .577 .707 r
F
.38946 .57275 m .38376 .6142 L p .41357 .63001 L F P
0 g
s
.39841 .62856 m .41357 .63001 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.38376 .6142 m .38946 .57275 L .36537 .56798 L p .707 .577 .707 r
F P
0 g
s
.37064 .58239 m .3784 .60896 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.38296 .62455 m .392 .65549 L p .37351 .61032 L .707 .577 .707 r
F P
0 g
s
.392 .65549 m .42631 .77293 L p .38722 .65254 L .707 .577 .707 r
F P
0 g
s
.37351 .61032 m .392 .65549 L .38722 .65254 L .707 .577 .707 r
F
.41357 .63001 m .42104 .57577 L .38946 .57275 L p F P
0 g
s
.42104 .57577 m .41357 .63001 L .43732 .62971 L p .707 .577 .707 r
F P
0 g
s
.44284 .64059 m .43127 .63848 L .43992 .62593 L .707 .577 .707 r
F
.46644 .75883 m .43455 .6497 L p .44284 .64059 L F P
0 g
s
.43455 .6497 m .43127 .63848 L p .44284 .64059 L .707 .577 .707 r
F P
0 g
s
.46644 .75883 m .42631 .77293 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .43455 .6497 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43455 .6497 m .46644 .75883 L p .40194 .65414 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .44109 .66576 L .42093 .66466 L p .707 .577 .707 r
F P
0 g
s
.42093 .66466 m .41227 .66419 L p .41573 .67038 L .707 .577 .707 r
F P
0 g
s
.43288 .70094 m .42093 .66466 L .41573 .67038 L .707 .577 .707 r
F
.44076 .6247 m .42104 .57577 L .43732 .62971 L F
.50968 .74598 m .46644 .75883 L p .43992 .62593 L F P
0 g
s
.45022 .5754 m .42104 .57577 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .45022 .5754 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .46427 .59057 L p .4441 .61986 L .707 .577 .707 r
F P
0 g
s
.46427 .59057 m .50968 .74598 L p .44106 .6279 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4441 .61986 L .44106 .6279 L .707 .577 .707 r
F
.4441 .61986 m .46427 .59057 L .44106 .6279 L F
.36519 .2515 m .40731 .24115 L p .46782 .53955 L F P
0 g
s
.50968 .74598 m .4603 .57697 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.46095 .57374 m .45022 .5754 L p .4603 .57697 L .707 .577 .707 r
F P
0 g
s
.4603 .57697 m .36519 .2515 L p .46782 .53955 L .707 .577 .707 r
F P
0 g
s
.45516 .59057 m .4603 .57697 L .45022 .5754 L .707 .577 .707 r
F
.46155 .57364 m .46095 .57374 L p .4603 .57697 L F P
0 g
s
.46667 .62592 m .47414 .57169 L .46155 .57364 L p .707 .577 .707 r
F P
0 g
s
.46667 .62592 m .46155 .57364 L .45516 .59057 L .707 .577 .707 r
F
.44275 .62964 m .46667 .62592 L p .45516 .59057 L F P
0 g
s
.45022 .5754 m .4441 .61986 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.4441 .61986 m .44275 .62964 L p .45516 .59057 L .707 .577 .707 r
F P
0 g
s
.36519 .2515 m .4603 .57697 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43992 .62593 m .4603 .57697 L .4441 .61986 L .707 .577 .707 r
F
.44275 .62964 m .4441 .61986 L p .44076 .6247 L F P
0 g
s
.43732 .62971 m .44275 .62964 L p .44076 .6247 L .707 .577 .707 r
F P
0 g
s
.32195 .26435 m .36519 .2515 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.43127 .63848 m .32195 .26435 L p .43992 .62593 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .43288 .70094 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41227 .66419 m .41148 .66755 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .40406 .69938 L p .41556 .67007 L .707 .577 .707 r
F P
0 g
s
.42631 .77293 m .39322 .78689 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.40406 .69938 m .41148 .66755 L p .38114 .65874 L .707 .577 .707 r
F P
0 g
s
.41148 .66755 m .41227 .66419 L .40886 .6636 L p .707 .577 .707 r
F P
0 g
s
.40886 .6636 m .38114 .65874 L p .41148 .66755 L .707 .577 .707 r
F P
0 g
s
.3784 .60896 m .38296 .62455 L p .36684 .58978 L .707 .577 .707 r
F P
0 g
s
.36684 .58978 m .38296 .62455 L .37351 .61032 L .707 .577 .707 r
F
.31517 .43063 m .3784 .60896 L .36684 .58978 L F
.28182 .27845 m .32195 .26435 L p .39625 .62645 L F P
0 g
s
.40363 .66239 m .39041 .62072 L .39625 .62645 L .707 .577 .707 r
F
.39041 .62072 m .28182 .27845 L .39625 .62645 L F
.38376 .6142 m .36537 .56798 L .37064 .58239 L F
.37064 .58239 m .28182 .27845 L p .40363 .66239 L F P
0 g
s
.38376 .6142 m .38335 .61717 L p .39841 .62856 L .707 .577 .707 r
F P
0 g
s
.38335 .61717 m .382 .62699 L .38971 .62772 L p .707 .577 .707 r
F P
0 g
s
.38971 .62772 m .39841 .62856 L p .38335 .61717 L .707 .577 .707 r
F P
0 g
s
.36537 .56798 m .36463 .56784 L p .37064 .58239 L .707 .577 .707 r
F P
0 g
s
.28182 .27845 m .37064 .58239 L p .31517 .43063 L .707 .577 .707 r
F P
0 g
s
.382 .62699 m .38376 .6142 L p .35858 .56664 L .707 .577 .707 r
F P
0 g
s
.36463 .56784 m .35858 .56664 L p .38376 .6142 L .707 .577 .707 r
F P
0 g
s
.8406 .58623 m .83314 .64046 L .83037 .62999 L p .707 .577 .707 r
F P
0 g
s
.83037 .62999 m .83784 .57575 L .8406 .58623 L p .707 .577 .707 r
F P
0 g
s
.40731 .24115 m .5518 .73564 L .50968 .74598 L p .707 .577 .707 r
F P
0 g
s
.631 .61093 m .63846 .55669 L .64559 .54766 L p .707 .577 .707 r
F P
0 g
s
.63217 .62164 m .62396 .65682 L .6265 .66854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.61951 .70141 m .62372 .68386 L .62121 .67206 L p .707 .577 .707 r
F P
0 g
s
.8128 .72881 m .80858 .74636 L .8158 .73687 L p .707 .577 .707 r
F P
0 g
s
.8158 .73687 m .82001 .71932 L .8128 .72881 L p .707 .577 .707 r
F P
0 g
s
.62121 .67206 m .61699 .68961 L .61951 .70141 L p .707 .577 .707 r
F P
0 g
s
.64559 .54766 m .63813 .6019 L .631 .61093 L p .707 .577 .707 r
F P
0 g
s
.62396 .65682 m .63217 .62164 L .63938 .61218 L p .707 .577 .707 r
F P
0 g
s
.83124 .66778 m .82303 .70296 L .8205 .69125 L p .707 .577 .707 r
F P
0 g
s
.8205 .69125 m .82871 .65606 L .83124 .66778 L p .707 .577 .707 r
F P
0 g
s
.83784 .57575 m .83037 .62999 L .81798 .61909 L p .707 .577 .707 r
F P
0 g
s
.81798 .61909 m .82545 .56485 L .83784 .57575 L p .707 .577 .707 r
F P
0 g
s
.63813 .6019 m .64559 .54766 L .66192 .54096 L p .707 .577 .707 r
F P
0 g
s
.63938 .61218 m .63117 .64737 L .62396 .65682 L p .707 .577 .707 r
F P
0 g
s
.61699 .68961 m .62121 .67206 L .62842 .66257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35111 .62088 m .35858 .56664 L .3314 .55804 L p .707 .577 .707 r
F P
0 g
s
.35858 .56664 m .35111 .62088 L .382 .62699 L p .707 .577 .707 r
F P
0 g
s
.82001 .71932 m .8158 .73687 L .81328 .72507 L p .707 .577 .707 r
F P
0 g
s
.81328 .72507 m .8175 .70752 L .82001 .71932 L p .707 .577 .707 r
F P
0 g
s
.62842 .66257 m .62421 .68012 L .61699 .68961 L p .707 .577 .707 r
F P
0 g
s
.66192 .54096 m .65445 .5952 L .63813 .6019 L p .707 .577 .707 r
F P
0 g
s
.63117 .64737 m .63938 .61218 L .65562 .60591 L p .707 .577 .707 r
F P
0 g
s
.82871 .65606 m .8205 .69125 L .80847 .67842 L p .707 .577 .707 r
F P
0 g
s
.80847 .67842 m .81667 .64324 L .82871 .65606 L p .707 .577 .707 r
F P
0 g
s
.82545 .56485 m .81798 .61909 L .79719 .60884 L p .707 .577 .707 r
F P
0 g
s
.79719 .60884 m .80465 .5546 L .82545 .56485 L p .707 .577 .707 r
F P
0 g
s
.32394 .61228 m .3314 .55804 L .31061 .54779 L p .707 .577 .707 r
F P
0 g
s
.3314 .55804 m .32394 .61228 L .35111 .62088 L p .707 .577 .707 r
F P
0 g
s
.65445 .5952 m .66192 .54096 L .68584 .53724 L p .707 .577 .707 r
F P
0 g
s
.37293 .69392 m .38114 .65874 L .35075 .64994 L p .707 .577 .707 r
F P
0 g
s
.38114 .65874 m .37293 .69392 L .40406 .69938 L p .707 .577 .707 r
F P
0 g
s
.65562 .60591 m .64742 .64109 L .63117 .64737 L p .707 .577 .707 r
F P
0 g
s
.34254 .68512 m .35075 .64994 L .32408 .63864 L p .707 .577 .707 r
F P
0 g
s
.35075 .64994 m .34254 .68512 L .37293 .69392 L p .707 .577 .707 r
F P
0 g
s
.62421 .68012 m .62842 .66257 L .64466 .65633 L p .707 .577 .707 r
F P
0 g
s
.8175 .70752 m .81328 .72507 L .80128 .71211 L p .707 .577 .707 r
F P
0 g
s
.80128 .71211 m .8055 .69456 L .8175 .70752 L p .707 .577 .707 r
F P
0 g
s
.47414 .57169 m .46667 .62592 L .483 .61922 L p .707 .577 .707 r
F P
0 g
s
.483 .61922 m .49046 .56498 L .47414 .57169 L p .707 .577 .707 r
F P
0 g
s
.31061 .54779 m .30314 .60203 L .32394 .61228 L p .707 .577 .707 r
F P
0 g
s
.80465 .5546 m .79719 .60884 L .77001 .60024 L p .707 .577 .707 r
F P
0 g
s
.77001 .60024 m .77748 .546 L .80465 .5546 L p .707 .577 .707 r
F P
0 g
s
.68584 .53724 m .67837 .59148 L .65445 .5952 L p .707 .577 .707 r
F P
0 g
s
.64466 .65633 m .64045 .67388 L .62421 .68012 L p .707 .577 .707 r
F P
0 g
s
.30314 .60203 m .31061 .54779 L .29822 .53689 L p .707 .577 .707 r
F P
0 g
s
.64742 .64109 m .65562 .60591 L .67932 .60343 L p .707 .577 .707 r
F P
0 g
s
.67837 .59148 m .68584 .53724 L .71502 .53687 L p .707 .577 .707 r
F P
0 g
s
.81667 .64324 m .80847 .67842 L .78812 .66573 L p .707 .577 .707 r
F P
0 g
s
.78812 .66573 m .79633 .63055 L .81667 .64324 L p .707 .577 .707 r
F P
0 g
s
.32408 .63864 m .31587 .67382 L .34254 .68512 L p .707 .577 .707 r
F P
0 g
s
.31587 .67382 m .32408 .63864 L .30373 .62596 L p .707 .577 .707 r
F P
0 g
s
.44109 .66576 m .43288 .70094 L .45657 .69847 L p .707 .577 .707 r
F P
0 g
s
.45657 .69847 m .46478 .66328 L .44109 .66576 L p .707 .577 .707 r
F P
0 g
s
.36578 .74337 m .37 .72582 L .33965 .71683 L p .707 .577 .707 r
F P
0 g
s
.37 .72582 m .36578 .74337 L .39687 .74899 L p .707 .577 .707 r
F P
0 g
s
.39687 .74899 m .40109 .73144 L .37 .72582 L p .707 .577 .707 r
F P
0 g
s
.77748 .546 m .77001 .60024 L .73913 .59413 L p .707 .577 .707 r
F P
0 g
s
.73913 .59413 m .74659 .53989 L .77748 .546 L p .707 .577 .707 r
F P
0 g
s
.33544 .73438 m .33965 .71683 L .31302 .70535 L p .707 .577 .707 r
F P
0 g
s
.33965 .71683 m .33544 .73438 L .36578 .74337 L p .707 .577 .707 r
F P
0 g
s
.40109 .73144 m .39687 .74899 L .42566 .75068 L p .707 .577 .707 r
F P
0 g
s
.42566 .75068 m .42988 .73313 L .40109 .73144 L p .707 .577 .707 r
F P
0 g
s
.67932 .60343 m .67111 .63862 L .64742 .64109 L p .707 .577 .707 r
F P
0 g
s
.70755 .59111 m .71502 .53687 L .74659 .53989 L p .707 .577 .707 r
F P
0 g
s
.71502 .53687 m .70755 .59111 L .67837 .59148 L p .707 .577 .707 r
F P
0 g
s
.30373 .62596 m .29552 .66114 L .31587 .67382 L p .707 .577 .707 r
F P
0 g
s
.74659 .53989 m .73913 .59413 L .70755 .59111 L p .707 .577 .707 r
F P
0 g
s
.29822 .53689 m .29075 .59113 L .30314 .60203 L p .707 .577 .707 r
F P
0 g
s
.64045 .67388 m .64466 .65633 L .66833 .65393 L p .707 .577 .707 r
F P
0 g
s
.31302 .70535 m .30881 .7229 L .33544 .73438 L p .707 .577 .707 r
F P
0 g
s
.8055 .69456 m .80128 .71211 L .78097 .69927 L p .707 .577 .707 r
F P
0 g
s
.78097 .69927 m .78519 .68171 L .8055 .69456 L p .707 .577 .707 r
F P
0 g
s
.67111 .63862 m .67932 .60343 L .70814 .605 L p .707 .577 .707 r
F P
0 g
s
.79633 .63055 m .78812 .66573 L .76145 .65444 L p .707 .577 .707 r
F P
0 g
s
.76145 .65444 m .76965 .61925 L .79633 .63055 L p .707 .577 .707 r
F P
0 g
s
.49046 .56498 m .483 .61922 L .49013 .61019 L p .707 .577 .707 r
F P
0 g
s
.49013 .61019 m .49759 .55595 L .49046 .56498 L p .707 .577 .707 r
F P
0 g
s
.29552 .66114 m .30373 .62596 L .2917 .61313 L p .707 .577 .707 r
F P
0 g
s
.46478 .66328 m .45657 .69847 L .47282 .69219 L p .707 .577 .707 r
F P
0 g
s
.47282 .69219 m .48102 .65701 L .46478 .66328 L p .707 .577 .707 r
F P
0 g
s
.66833 .65393 m .66412 .67149 L .64045 .67388 L p .707 .577 .707 r
F P
0 g
s
.30881 .7229 m .31302 .70535 L .29271 .6925 L p .707 .577 .707 r
F P
0 g
s
.42988 .73313 m .42566 .75068 L .44934 .74829 L p .707 .577 .707 r
F P
0 g
s
.44934 .74829 m .45355 .73074 L .42988 .73313 L p .707 .577 .707 r
F P
0 g
s
.29075 .59113 m .29822 .53689 L .29545 .52642 L p .707 .577 .707 r
F P
0 g
s
.29271 .6925 m .2885 .71006 L .30881 .7229 L p .707 .577 .707 r
F P
0 g
s
.70814 .605 m .69993 .64018 L .67111 .63862 L p .707 .577 .707 r
F P
0 g
s
.69993 .64018 m .70814 .605 L .73926 .61045 L p .707 .577 .707 r
F P
0 g
s
.76965 .61925 m .76145 .65444 L .73106 .64563 L p .707 .577 .707 r
F P
0 g
s
.73106 .64563 m .73926 .61045 L .76965 .61925 L p .707 .577 .707 r
F P
0 g
s
.2917 .61313 m .28349 .64831 L .29552 .66114 L p .707 .577 .707 r
F P
0 g
s
.73926 .61045 m .73106 .64563 L .69993 .64018 L p .707 .577 .707 r
F P
0 g
s
.66412 .67149 m .66833 .65393 L .69712 .65563 L p .707 .577 .707 r
F P
0 g
s
.78519 .68171 m .78097 .69927 L .75434 .68779 L p .707 .577 .707 r
F P
0 g
s
.75434 .68779 m .75856 .67023 L .78519 .68171 L p .707 .577 .707 r
F P
0 g
s
.29545 .52642 m .28799 .58066 L .29075 .59113 L p .707 .577 .707 r
F P
0 g
s
.69712 .65563 m .69291 .67318 L .66412 .67149 L p .707 .577 .707 r
F P
0 g
s
.2885 .71006 m .29271 .6925 L .28071 .67955 L p .707 .577 .707 r
F P
0 g
s
.45355 .73074 m .44934 .74829 L .46557 .74205 L p .707 .577 .707 r
F P
0 g
s
.46557 .74205 m .46979 .72449 L .45355 .73074 L p .707 .577 .707 r
F P
0 g
s
.28349 .64831 m .2917 .61313 L .28916 .60141 L p .707 .577 .707 r
F P
0 g
s
.48102 .65701 m .47282 .69219 L .48002 .68273 L p .707 .577 .707 r
F P
0 g
s
.48002 .68273 m .48823 .64755 L .48102 .65701 L p .707 .577 .707 r
F P
0 g
s
.49759 .55595 m .49013 .61019 L .48736 .59972 L p .707 .577 .707 r
F P
0 g
s
.48736 .59972 m .49483 .54548 L .49759 .55595 L p .707 .577 .707 r
F P
0 g
s
.28071 .67955 m .2765 .6971 L .2885 .71006 L p .707 .577 .707 r
F P
0 g
s
.69291 .67318 m .69712 .65563 L .72821 .66125 L p .707 .577 .707 r
F P
0 g
s
.75856 .67023 m .75434 .68779 L .724 .6788 L p .707 .577 .707 r
F P
0 g
s
.724 .6788 m .72821 .66125 L .75856 .67023 L p .707 .577 .707 r
F P
0 g
s
.28799 .58066 m .29545 .52642 L .30258 .51739 L p .707 .577 .707 r
F P
0 g
s
.72821 .66125 m .724 .6788 L .69291 .67318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28916 .60141 m .28095 .6366 L .28349 .64831 L p .707 .577 .707 r
F P
0 g
s
.2765 .6971 m .28071 .67955 L .2782 .66775 L p .707 .577 .707 r
F P
0 g
s
.46979 .72449 m .46557 .74205 L .47279 .73256 L p .707 .577 .707 r
F P
0 g
s
.47279 .73256 m .477 .71501 L .46979 .72449 L p .707 .577 .707 r
F P
0 g
s
.30258 .51739 m .29512 .57162 L .28799 .58066 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28095 .6366 m .28916 .60141 L .29637 .59195 L p .707 .577 .707 r
F P
0 g
s
.2782 .66775 m .27398 .6853 L .2765 .6971 L p .707 .577 .707 r
F P
0 g
s
.48823 .64755 m .48002 .68273 L .47749 .67102 L p .707 .577 .707 r
F P
0 g
s
.47749 .67102 m .4857 .63583 L .48823 .64755 L p .707 .577 .707 r
F P
0 g
s
.49483 .54548 m .48736 .59972 L .47497 .58882 L p .707 .577 .707 r
F P
0 g
s
.47497 .58882 m .48244 .53458 L .49483 .54548 L p .707 .577 .707 r
F P
0 g
s
.29512 .57162 m .30258 .51739 L .31891 .51068 L p .707 .577 .707 r
F P
0 g
s
.29637 .59195 m .28816 .62714 L .28095 .6366 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27398 .6853 m .2782 .66775 L .28541 .65826 L p .707 .577 .707 r
F P
0 g
s
.477 .71501 m .47279 .73256 L .47027 .72076 L p .707 .577 .707 r
F P
0 g
s
.47027 .72076 m .47448 .70321 L .477 .71501 L p .707 .577 .707 r
F P
0 g
s
.31891 .51068 m .31144 .56492 L .29512 .57162 L p .707 .577 .707 r
F P
0 g
s
.48244 .53458 m .47497 .58882 L .45418 .57857 L p .707 .577 .707 r
F P
0 g
s
.45418 .57857 m .46164 .52433 L .48244 .53458 L p .707 .577 .707 r
F P
0 g
s
.28541 .65826 m .2812 .67581 L .27398 .6853 L p .707 .577 .707 r
F P
0 g
s
.28816 .62714 m .29637 .59195 L .31261 .58568 L p .707 .577 .707 r
F P
0 g
s
.4857 .63583 m .47749 .67102 L .46546 .65819 L p .707 .577 .707 r
F P
0 g
s
.46546 .65819 m .47366 .62301 L .4857 .63583 L p .707 .577 .707 r
F P
0 g
s
.31144 .56492 m .31891 .51068 L .34283 .50697 L p .707 .577 .707 r
F P
0 g
s
.31261 .58568 m .30441 .62086 L .28816 .62714 L p .707 .577 .707 r
F P
0 g
s
.46164 .52433 m .45418 .57857 L .427 .56997 L p .707 .577 .707 r
F P
0 g
s
.427 .56997 m .43447 .51573 L .46164 .52433 L p .707 .577 .707 r
F P
0 g
s
.34283 .50697 m .33536 .56121 L .31144 .56492 L p .707 .577 .707 r
F P
0 g
s
.2812 .67581 m .28541 .65826 L .30165 .65201 L p .707 .577 .707 r
F P
0 g
s
.47448 .70321 m .47027 .72076 L .45827 .7078 L p .707 .577 .707 r
F P
0 g
s
.45827 .7078 m .46248 .69025 L .47448 .70321 L p .707 .577 .707 r
F P
0 g
s
.33536 .56121 m .34283 .50697 L .372 .5066 L p .707 .577 .707 r
F P
0 g
s
.30441 .62086 m .31261 .58568 L .33631 .5832 L p .707 .577 .707 r
F P
0 g
s
.47366 .62301 m .46546 .65819 L .44511 .64551 L p .707 .577 .707 r
F P
0 g
s
.44511 .64551 m .45332 .61032 L .47366 .62301 L p .707 .577 .707 r
F P
0 g
s
.30165 .65201 m .29744 .66957 L .2812 .67581 L p .707 .577 .707 r
F P
0 g
s
.43447 .51573 m .427 .56997 L .39612 .56386 L p .707 .577 .707 r
F P
0 g
s
.39612 .56386 m .40358 .50962 L .43447 .51573 L p .707 .577 .707 r
F P
0 g
s
.36454 .56084 m .372 .5066 L .40358 .50962 L p .707 .577 .707 r
F P
0 g
s
.372 .5066 m .36454 .56084 L .33536 .56121 L p .707 .577 .707 r
F P
0 g
s
.33631 .5832 m .3281 .61839 L .30441 .62086 L p .707 .577 .707 r
F P
0 g
s
.40358 .50962 m .39612 .56386 L .36454 .56084 L p .707 .577 .707 r
F P
0 g
s
.3281 .61839 m .33631 .5832 L .36513 .58477 L p .707 .577 .707 r
F P
0 g
s
.45332 .61032 m .44511 .64551 L .41844 .63421 L p .707 .577 .707 r
F P
0 g
s
.41844 .63421 m .42664 .59903 L .45332 .61032 L p .707 .577 .707 r
F P
0 g
s
.29744 .66957 m .30165 .65201 L .32532 .64962 L p .707 .577 .707 r
F P
0 g
s
.46248 .69025 m .45827 .7078 L .43796 .69495 L p .707 .577 .707 r
F P
0 g
s
.43796 .69495 m .44218 .6774 L .46248 .69025 L p .707 .577 .707 r
F P
0 g
s
.32532 .64962 m .32111 .66717 L .29744 .66957 L p .707 .577 .707 r
F P
0 g
s
.36513 .58477 m .35692 .61995 L .3281 .61839 L p .707 .577 .707 r
F P
0 g
s
.35692 .61995 m .36513 .58477 L .39625 .59022 L p .707 .577 .707 r
F P
0 g
s
.42664 .59903 m .41844 .63421 L .38805 .6254 L p .707 .577 .707 r
F P
0 g
s
.38805 .6254 m .39625 .59022 L .42664 .59903 L p .707 .577 .707 r
F P
0 g
s
.39625 .59022 m .38805 .6254 L .35692 .61995 L p .707 .577 .707 r
F P
0 g
s
.32111 .66717 m .32532 .64962 L .35411 .65132 L p .707 .577 .707 r
F P
0 g
s
.44218 .6774 m .43796 .69495 L .41133 .68347 L p .707 .577 .707 r
F P
0 g
s
.41133 .68347 m .41555 .66592 L .44218 .6774 L p .707 .577 .707 r
F P
0 g
s
.35411 .65132 m .3499 .66887 L .32111 .66717 L p .707 .577 .707 r
F P
0 g
s
.3499 .66887 m .35411 .65132 L .3852 .65693 L p .707 .577 .707 r
F P
0 g
s
.41555 .66592 m .41133 .68347 L .38099 .67449 L p .707 .577 .707 r
F P
0 g
s
.38099 .67449 m .3852 .65693 L .41555 .66592 L p .707 .577 .707 r
F P
0 g
s
.3852 .65693 m .38099 .67449 L .3499 .66887 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol008=oo`D009Eoo`00O7oo1`001EYF0`00TWoo001fOol6
000;FUH01000FUIJEUYFTWoo001bOol40009FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001^
Ool400000eYF001JEP0:FUH00`00FUIJEP05FUH01@00FUIJEUYF0000TGoo001ZOol40006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00Oomoo`2>Ool006Ioo`@000YJEP03001JEUYF015JEP05001J
EUYFFUH0002@Ool006=oo`<000iJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002@
Ool0061oo`<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002@Ool005eoo`<000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF
FUH0002?Ool005Yoo`<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001J
EUYFFUH0002?Ool005Moo`<001]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002?
Ool005Eoo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH2002>Ool0059oo`<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03Ool005YF
00UJEP03001JEUYF00IJEP05001JEUYFFUH0002>Ool004moo`<000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0002>Ool004eoo`800003FUH0
05YF01QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2002=Ool0
04Yoo`<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008008eoo`00B7oo0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008eoo`00AWoo0P00
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00D005YFFUIJEP0008eoo`00A7oo0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00S7oo0012Ool20003FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000S7oo0010Ool20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
S7oo000oOol20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Rgoo000nOol01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Rgoo000mOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0008]oo`00?Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
002;Ool003ioo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02002:Ool003ioo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RWoo000nOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Yoo`00?Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH20029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
0029Ool003moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000RGoo000oOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Uoo`00@7oo00@005YFFUH000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF008008Qoo`00@7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH00028Ool0041oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000R7oo0010Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8008Moo`00@Goo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008008Moo`00@Goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP05001JEUYFFUH00027Ool0045oo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00QWoo0012Ool01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00P00QWoo0012Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008Ioo`00
@Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00026Ool0049oo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020025Ool004=oo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000QGoo0013Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D0
05YFFUIJEP0008Eoo`00@goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20024
Ool004Aoo`05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020024Ool004Aoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Q7oo0014Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00D005YFFUIJEP0008Aoo`00A7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF008008=oo`00AGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0023Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Pgoo0015Ool0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80089oo`00AWoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF0080089oo`00AWoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH00022Ool004Ioo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00PGoo0016Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00PGoo0017
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00085oo`00Agoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00021Ool004Moo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00P00P7oo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00081o
o`00B7oo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001oOol004Qoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007moo`00BGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0001oOol004Uoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000Ogoo0019Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8007ioo`00BWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007ioo`00BWoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001nOol004Yoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OGoo001:Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02001mOol004]oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000OGoo001;Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007eo
o`00Bgoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008007aoo`00C7oo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0001lOol004aoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000O7oo001<Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8007]oo`00C7oo0P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P00Ngoo001=Ool01@00FUIJEUYF00001UYF00<005YFFUH00eYF5`001eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007]oo`00CGoo00D005YFFUIJEP0000IJEP03
001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000=JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001jOol004eoo`05001JEUYFFUH0
0006FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001jOol004ioo`05001JEUYFFUH00003FUH20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00H005YFFUIJEP00FUH3
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0`0025YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007Yoo`00CWoo00@005YF
FUIJEP80009JEP04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001>
Ool20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001iOol004moo`07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH01EYF00D005YFFUIJEP0007Uoo`00Cgoo00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P006goo4000CGoo001?Ool01000
FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF00UJEP03001JEUYF00IJEP03001JEUYF
008001Ioo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00D7oo00<005YF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00000;FUH00`00FUIJEP05FUH01@00FUIJEUYF000057oo0P00
00=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00@goo001@Ool01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000]JEP03001JEUYF00EJEP05001JEUYFFUH0
000BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000oOol0051oo`05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YF
FUH01EYF00@005YFFUIJEP80011oo`8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<003]oo`00DGoo0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000YJEP03001JEUYF00IJEP03001JEUYF0080011oo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Qoo`00
DGoo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00EJEP05
001JEUYFFUH0000?Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0055oo`800003FUH005YF009JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]J
EP03001JEUYF00EJEP04001JEUYFFUH2000>Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02000dOol0055oo`<000=J
EPD0009JEP04001JEUYFFUH20004FUH01000FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00D005YFFUH005YF008000YJEP03001JEUYF00IJEP03001JEUYF008000ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP80039oo`00DGoo00@005YF001JEP<000IJEP03001JEUYF00=JEPD000EJEPT0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00003Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Goo001AOol01000FUH000000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00@005YFFUH000AJEPH00004FUH005YFFUH40006FUH00`00FUIJEP04FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP05FUH01000FUIJEUYF0P0037oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000002moo`00DGoo0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00@005YFFUH000IJEP<000=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF
0080009JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2000<Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF0`001EYF00@005YFFUIJEP80009JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000aoo`03001JEP0000AJEP03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DGoo00<005YFFUH00eYF00<005YFFUH00UYF1`0000=JEP00FUH0
0eYF00<005YFFUH02EYF00<005YFFUH02UYF0P000eYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH0000<Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool0055oo`03001JEUYF00=JEPD000=JEP04001JEUYFFUH9000:FUH00`00
FUIJEP0;FUH200000eYF001JEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P002goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;7oo001B
Ool01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<005YFFUH035YF
0`000UYF00<005YF00000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P002goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00@005YF0000009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00eJEP08001JEUYF001J
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0000;Ool20004FUH01000
FUIJEUYF5P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00Dgoo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`003EYF00@0
05YFFUIJEP800003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2000:
Ool00eYF001JEP02FUH500000eYF001JEP04FUH50007Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000gOol@000<Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0`002UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P002Goo00@005YF001JEP8000IJEP03001JEUYF00EJEP03001J
EUYF00@0009oo`D000=oo`@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000008FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo00H005YF000005YF0005FUH70002FUH0
0`00FUIJEP04FUH70007Ool20004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000aOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH01`00FUIJEUYF
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00009Ool30002FUH60003
FUH01000FUIJEUYF2@000UYF4@0000=JEP00FUH015YF00<005YFFUH00UYF00<007ooOol0;Goo000_
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH20008Ool01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00
1EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF00<007ooOol0;Goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001J
EP03FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020008Ool01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEUYF
FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH2
0007FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10001eYF00@005YFFUIJEP800003
FUH005YF009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF00000UYF1P001UYF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8000Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00AJEP8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000P000eYF00<005YF
FUH01EYF00@005YFFUIJEPX000MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000Moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUH00002
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEPP000EJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0
0007Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`001UYF00<005YFFUH00`00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH30002FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH800000eYF001JEP07FUH00`00FUIJEP04FUH01000FUH000002EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00@005YFFUIJEP@000=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH2
000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00<000IJEP03001JEUYF00QJEPH0009JEP<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH300000eYF0000000200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0P00<7oo000/Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP08FUH50005FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030004
FUH00`00FUH00003FUH01000FUIJEUYF1P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`000UYF00<005YF0000<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH025YF100025YF0`0000=JEP00FUH01EYF00@005YFFUIJEP8000UJEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH20003FUH80003FUH90004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000[Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH200000eYF001JEP09FUH01000FUIJEP002EYF00@0
05YF000000IJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001EYF00<005YF00000P000eYF0`0000=oo`00000015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01EYF00<005YFFUH015YF1000<Goo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF1`000UYF0`00
5UYF00<005YFFUH00`0015YF00@005YFFUIJEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF008000=JEP04001JEP000002FUH30003FUH300001Woo00000000FUH000QJEP03001JEUYF
00<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000bOol002]oo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00@005YFFUIJEPT000IJ
EP03001JEUYF00UJEP04001JEUYF0002FUH01000FUIJEP000eYF00<005YF00002UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP<000=JEP03001JEUYF00P0009oo`H000AJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYF000bOol002]oo`8000=J
EPD0009JEP04001JEUYFFUH20008Ool70006FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7
000<FUH00`00FUH00003FUH30003FUH00`00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000UYF00<005YF00000UYF1@000UYF00<005YFFUH00UYF1P000Woo2@0015YF0`00
1eYF00<005YFFUH00eYF00D005YFFUIJEP00035oo`00:goo0P0000AJEP00000000IJEP03001JEUYF
00=JEP@000Ioo`T00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000UJEP03001JEUYF00EJEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YF00000`001goo2@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;goo000[
Ool00eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool50004Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40006FUH0
0`00FUIJEP02FUH50002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000;Ool300000eYF001J
EP04FUH00`00FUIJEP02FUH2000`Ool002Yoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00AJEP`000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH<0003
FUH01P00FUH00000FUH000aJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool20005
FUH01`00FUIJEUYF001JEP00031oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF1`001EYF2@0015YF00<005YFFUH01eYF00@005YF0000
00=JEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH0000000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40008Ool20003FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<005YFFUH00eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000001EYF0`00
1eYF00<005YFFUH00eYF1P001eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00H005YFFUIJEP00
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH50002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01eYF00@005YF000000Qoo`<000AJEP03001JEWoo031oo`00:Woo00<0
05YFFUH00eYF4`0015YF00<005YFFUH015YF0`001eYF00<005YFFUH00P0015YF00<005YFFUH01eYF
00<005YFFUH00P001EYF00<005YFFUH015YF0P001EYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH3000015YF000000001UYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH01eYF00@005YFFUIJEP<000Moo`03001JEUYF009JEP80035o
o`00:goo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP<000MJEP06001J
EUYFFUH005YF0`0000=JEP00FUH025YF00@005YFFUIJEP@00003FUH005YF00MJEP<0009JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH50000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20006Ool0
1000FUIJEUYF0P00<Goo000[Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF1@0000=JEP00FUH00P001UYF00D005YFFUIJEP0000=JEP@000QJEP03001JEUYF00P0
00MJEP06001JEUYF001JEP000eYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00@0009JEP03001JEUYF00IJEP800003Ool0000000@00003FUH00000039oo`00;7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00
FUH00P0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP<000AJEP04001JEUYFFUH60002FUH2
0004FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP050004FUH01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH015YF1000
1UYF00<005YFFUH00P000UYF00<005YFFUH00`00<Woo000/Ool01@00FUIJEUYF00001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH00004FUH01@00FUIJEUYF
00001EYF0`0000=JEP00FUH00UYF1@001EYF0`0000=JEP00FUH01EYF00@005YF000000AJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF001JEP040004FUH30007FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH00UYF00<005YF00000eYF0P00
<Woo000[Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH300000eYF001JEP03FUH01@00FUIJEUYF00001UYF00<005YF0000100000=J
EP0000000P0025YF0P001UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P000UYF00@007oo000000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF00EJEP04001JEUYFFUH3000bOol002]oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00
008000EJEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH90004FUH01000FUH0000015YF00<005YF
00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEPH00003
FUH005YF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP80009J
EP8003=oo`00:Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH000AJEP<000=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH01000FUIJ
EUYF2@000UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP04001JEUYF0003FUH30003FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30004FUH01000FUH005YF0P00<goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH400000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P0000=JEP00FUH00P000eYF
0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH2000dOol0
02Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000EJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP001EYF0P000eYF0P0000AJEP00FUIJEP<000AJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYFFUH30004FUH00`00Oomoo`0bOol002Uoo`03001JEP00009JEQ<000IJEP03
001JEUYF00IJEP04001JEUYF0004FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<000=JEP8000=JEPD00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo039oo`00:Goo0P0000AJEP000000
011oo`H0009JEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH40006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00P0000AJEP00FUH0009JEP80
00=oo`H00003FUH00000008000MJEP03001JEUYF00AJEP8000=JEP8003=oo`00:Goo0`000eYF00<0
07ooOol04Goo1P001eYF00<005YFFUH00eYF0P0025YF00<005YF00000P0015YF00<005YFFUH05EYF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEUYF10000eYF00<005YFFUH00eYF0P000UYF0`002Woo200015YF00@005YFFUIJEPH00004FUH0
05YF000cOol002Uoo`8000AJEP<001Ioo`D0009JEP03001JEUYF00EJEP8000MJEP03001JEUYF009J
EP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF0P0000=JEP00FUH01UYF1@00
2Woo1@000goo20001Woo0P0000=JEP00Ool0<Woo000XOol30004FUH00`00FUIJEP02000COol50000
0goo000000020007FUH30004FUH00`00FUIJEP06FUH60007FUH00`00FUIJEP09FUH00`00FUH00003
0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP02FUH2
0008FUH00`00FUH000030008Ool5000BOol2000dOol002Qoo`03001JEP0000=JEP03001JEUYF00=J
EP<0011oo`D000Eoo`8000AJEP04001JEUYFFUH300000eYF001JEP08FUH00`00FUIJEP02FUH80008
FUH50002FUH2000DFUH00`00FUIJEP07FUH70004FUH50005FUH20005FUH00`00FUIJEP04FUH50004
Ool3000BOol3000dOol002Qoo`03001JEUYF00=JEP03001JEUYF00AJEP04001JEP00000>Ool50007
Ool300000eYF001JEP05FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00<005YFFUH0
0UYF0P0025YF00<005YFFUH02UYF00<005YFFUH01P0015YF00<005YFFUH015YF00D005YFFUIJEP00
00EJEP04001JEP000003FUH00`00FUIJEP06FUH00`00FUIJEP04000COol200000eYF001oo`0dOol0
02Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP8000eoo`<000]oo`8000IJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0009FUH00`00FUIJEP09FUH50009FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP<0
00UJEP03001JEUYF00AJEQ<0009JEP8003Eoo`00:Goo00<005YFFUH00UYF00@005YFFUIJEPL0009J
EP<001Yoo`8000AJEP03001JEP00009JEP<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP@000AJEP03001JEUYF00QJEP03001JEUYF
00AJEP8000MJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0000fOol002Yoo`04001JEUYFFUH40003FUH01000FUIJEUYF2@0067oo0P00
00EJEP00FUIJEP0000=JEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF00<000iJEP@000UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008003Ioo`00:goo10001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0057oo0P000eYF00D0
05YFFUIJEP0000IJEPP000AJEP04001JEUYFFUH600000eYF001JEP0:FUH5000<FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0003Moo`00:Woo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P004Woo00D005YFFUIJEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEPP000MJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF
00MJEP04001JEUYFFUH70004FUH00`00FUIJEP04FUH01@00FUIJEUYF00001goo10000UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000003Qoo`00:Goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0037oo1@0000=JEP0000000eYF00<005YFFUH0
15YF00<005YFFUH065YF100025YF00<005YFFUH02eYF00<005YFFUH01eYF0`001goo0`0000=JEP00
FUH015YF00<005YFFUH00UYF00<007ooOol02Goo4`00>Woo000YOol01@00FUIJEUYF00000eYF1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF30000eYF00H005YF000005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4000:
Ool20005FUH01`00FUIJEUYF001JEP0005Moo`00:7oo0P000UYF1`001EYF2@0015YF00<005YFFUH0
1eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH045YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P0015YF
0`002Goo00<005YFFUH00UYF00L005YFFUIJEP00FUH0001GOol002Qoo`04001JEP000006Ool20007
FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP02FUH200000eYF001JEP04FUH01`00FUIJEUYF001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00iJEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF009JEP8000QJEP<000Qoo`80009JEP07001JEUYFFUH005YF0000Egoo000WOol3000:
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH20005FUH01000FUIJ
EUYF0`000eYF00<005YFFUH04UYF0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF0000
0P002EYF00<005YFFUH00P0027oo0P0015YF0P00F7oo000WOol2000=Ool300000eYF001JEP08FUH0
1000FUIJEUYF100000=JEP00FUH01eYF0`000UYF00<005YFFUH00UYF0P0000=oo`00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01eYF100035YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<0
05YFFUH00eYF0P001goo00<005YFFUH00UYF0P00F7oo000VOol4000?Ool30008FUH00`00FUIJEP08
0007FUH01P00FUIJEP00FUH000=JEP05001JEP00Ool00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04
0002FUH00`00FUIJEP05FUH20002Ool50002FUH00`00FUH0001HOol002Ioo`05001JEP00FUH0000A
Ool30004FUH01000FUIJEUYF1P000UYF0P0015YF00<005YFFUH00UYF0P000eYF0P000Woo00D005YF
FUIJEP0000IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00=JEP<000QJEP03001JEUYF00AJEP<000QJEP<000=JEP03001JEP0000<005Uoo`009Woo00<005YF
FUH00UYF00<007ooOol04Goo0`0000=JEP00FUH00UYF1P0015YF0`0000=JEP00FUH01EYF00@005YF
000000Aoo`eJEP8000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP<000EJEP04001JEUYFFUH200000eYF001JEP02FUH2001IOol002Moo`03
001JEUYF009JEP03001oogoo01=oo`<000=JEP<00003FUH005YF00IJEP8000IJEP8000Ioo`05001J
EUYFFUH00006FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`009goo
00<005YFFUH00UYF0`005Woo10000UYF00<005YFFUH01UYF00@005YF000000AJEP8000Ioo`05001J
EUYFFUH00004FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP0AFUH400000goo00000004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH20002FUH3001IOol002Qoo`05001J
EUYFFUH00002FUH2000HOol@0002FUH01000FUIJEP001Woo0eYF00D005YFFUIJEP0000AJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00@000Moo`800003FUH005YF00QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00FUH2001JOol002Uoo`03001JEP0000EJEP03
001oogoo02Eoo`<000=JEP03001oogoo00=oo`EJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EPD0009JEP8000Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP<000=JEP04001JEUYFFUH3
001JOol002Yoo`8000EJEP<002Moo`05001JEUYFFUH00005Ool01000FUIJEUYF0P001eYF00<005YF
FUH045YF100000Aoo`00FUH000EJEP8000Uoo`<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00800003FUH005YF00=JEP03001oogoo05Uoo`00:goo00<005YFFUH00eYF00<005YFFUH0
0P009Woo00<005YFFUH00P0017oo00H005YFFUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP04
0006Ool20006FUH3000:Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00Oomoo`1IOol002aoo`80009JEP03001JEUYF00=JEP8002Aoo`05001JEP00FUH00005Ool0
0eYF001JEP09FUH00`00FUIJEP07FUH5000;Ool00`00FUIJEP04FUH00`00FUIJEP02000;Ool60004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2001JOol002ioo`<000MJEP@0025oo`800003
FUH007oo00Aoo`03001JEUYF00YJEP03001JEUYF00H0015oo`8000=JEP03001JEUYF00=JEP8000mo
o`P000AJEP04001JEUYFFUH6000015YF001JEP00FWoo000`Ool20007FUH00`00FUIJEP04000NOol0
0`00FUH00006Ool20002FUH00`00FUIJEP02FUH6000IOol200000eYF001JEP06FUH3000<Ool50003
Ool80006Ool200000eYF001oo`1IOol0039oo`8000AJEP03001JEUYF00EJEPD001Moo`@000Uoo`L0
025oo`8000QJEP03001JEP0000<000Qoo`D0019oo`8005]oo`00=7oo0`0000=JEP00FUH025YF00<0
05YFFUH010003Woo1@000UYF0P00<goo0P001EYF00<005YFFUH015YF1@000goo1@004Goo0`00Fgoo
000gOol30007FUH00`00FUIJEP05FUH>0002FUH00`00FUIJEP02FUH2000eOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP07000@Ool200000eYF001oo`1KOol003Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000hOol30009FUH00`00FUIJEP04FUHC0002
FUH2001LOol003aoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
009JEP8003Yoo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH0001MOol003moo`@000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<003ioo`@0
009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005eoo`00@goo
10000UYF00<005YFFUH01UYF00@005YFFUIJEPD004Eoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol004Moo`l004moo`@0009JEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001OOol00:Uooa<0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59105 .74945 m .59567 .69457 L .56461 .69006 L p .707 .577 .707 r
F P
0 g
s
.59567 .69457 m .59105 .74945 L .62278 .75103 L p .707 .577 .707 r
F P
0 g
s
.62278 .75103 m .62741 .69615 L .59567 .69457 L p .707 .577 .707 r
F P
0 g
s
.62741 .69615 m .62278 .75103 L .65209 .74952 L p .707 .577 .707 r
F P
0 g
s
.65209 .74952 m .65671 .69464 L .62741 .69615 L p .707 .577 .707 r
F P
0 g
s
.55998 .74494 m .56461 .69006 L .53726 .68305 L p .707 .577 .707 r
F P
0 g
s
.56461 .69006 m .55998 .74494 L .59105 .74945 L p .707 .577 .707 r
F P
0 g
s
.65671 .69464 m .65209 .74952 L .67609 .74507 L p .707 .577 .707 r
F P
0 g
s
.67609 .74507 m .68071 .69019 L .65671 .69464 L p .707 .577 .707 r
F P
0 g
s
.53263 .73793 m .53726 .68305 L .5163 .67424 L p .707 .577 .707 r
F P
0 g
s
.53726 .68305 m .53263 .73793 L .55998 .74494 L p .707 .577 .707 r
F P
0 g
s
.58555 .80775 m .59065 .77162 L .55978 .76541 L p .707 .577 .707 r
F P
0 g
s
.59065 .77162 m .58555 .80775 L .61711 .81086 L p .707 .577 .707 r
F P
0 g
s
.61711 .81086 m .62221 .77474 L .59065 .77162 L p .707 .577 .707 r
F P
0 g
s
.62221 .77474 m .61711 .81086 L .64628 .81057 L p .707 .577 .707 r
F P
0 g
s
.64628 .81057 m .65138 .77444 L .62221 .77474 L p .707 .577 .707 r
F P
0 g
s
.55468 .80154 m .55978 .76541 L .53262 .75671 L p .707 .577 .707 r
F P
0 g
s
.55978 .76541 m .55468 .80154 L .58555 .80775 L p .707 .577 .707 r
F P
0 g
s
.68071 .69019 m .67609 .74507 L .69244 .73812 L p .707 .577 .707 r
F P
0 g
s
.69244 .73812 m .69706 .68324 L .68071 .69019 L p .707 .577 .707 r
F P
0 g
s
.5163 .67424 m .51168 .72912 L .53263 .73793 L p .707 .577 .707 r
F P
0 g
s
.65138 .77444 m .64628 .81057 L .6702 .8069 L p .707 .577 .707 r
F P
0 g
s
.6702 .8069 m .6753 .77077 L .65138 .77444 L p .707 .577 .707 r
F P
0 g
s
.53262 .75671 m .52752 .79284 L .55468 .80154 L p .707 .577 .707 r
F P
0 g
s
.58115 .8444 m .58377 .82636 L .55291 .82003 L p .707 .577 .707 r
F P
0 g
s
.58377 .82636 m .58115 .8444 L .6127 .84762 L p .707 .577 .707 r
F P
0 g
s
.6127 .84762 m .61532 .82957 L .58377 .82636 L p .707 .577 .707 r
F P
0 g
s
.52752 .79284 m .53262 .75671 L .51184 .74636 L p .707 .577 .707 r
F P
0 g
s
.51168 .72912 m .5163 .67424 L .50379 .66449 L p .707 .577 .707 r
F P
0 g
s
.61532 .82957 m .6127 .84762 L .64185 .84741 L p .707 .577 .707 r
F P
0 g
s
.64185 .84741 m .64447 .82936 L .61532 .82957 L p .707 .577 .707 r
F P
0 g
s
.55029 .83807 m .55291 .82003 L .52577 .81121 L p .707 .577 .707 r
F P
0 g
s
.55291 .82003 m .55029 .83807 L .58115 .8444 L p .707 .577 .707 r
F P
0 g
s
.52577 .81121 m .52315 .82926 L .55029 .83807 L p .707 .577 .707 r
F P
0 g
s
.51184 .74636 m .50674 .78249 L .52752 .79284 L p .707 .577 .707 r
F P
0 g
s
.64447 .82936 m .64185 .84741 L .66576 .8438 L p .707 .577 .707 r
F P
0 g
s
.66576 .8438 m .66838 .82575 L .64447 .82936 L p .707 .577 .707 r
F P
0 g
s
.50379 .66449 m .49916 .71936 L .51168 .72912 L p .707 .577 .707 r
F P
0 g
s
.6753 .77077 m .6702 .8069 L .68652 .80022 L p .707 .577 .707 r
F P
0 g
s
.68652 .80022 m .69162 .76409 L .6753 .77077 L p .707 .577 .707 r
F P
0 g
s
.52315 .82926 m .52577 .81121 L .505 .80076 L p .707 .577 .707 r
F P
0 g
s
.69706 .68324 m .69244 .73812 L .69954 .72934 L p .707 .577 .707 r
F P
0 g
s
.69954 .72934 m .70416 .67446 L .69706 .68324 L p .707 .577 .707 r
F P
0 g
s
.50674 .78249 m .51184 .74636 L .49946 .73539 L p .707 .577 .707 r
F P
0 g
s
.505 .80076 m .50238 .81881 L .52315 .82926 L p .707 .577 .707 r
F P
0 g
s
.49916 .71936 m .50379 .66449 L .50094 .65474 L p .707 .577 .707 r
F P
0 g
s
.49946 .73539 m .49436 .77152 L .50674 .78249 L p .707 .577 .707 r
F P
0 g
s
.66838 .82575 m .66576 .8438 L .68208 .83713 L p .707 .577 .707 r
F P
0 g
s
.68208 .83713 m .6847 .81908 L .66838 .82575 L p .707 .577 .707 r
F P
0 g
s
.50238 .81881 m .505 .80076 L .49264 .78971 L p .707 .577 .707 r
F P
0 g
s
.69162 .76409 m .68652 .80022 L .69365 .79117 L p .707 .577 .707 r
F P
0 g
s
.69365 .79117 m .69875 .75504 L .69162 .76409 L p .707 .577 .707 r
F P
0 g
s
.50094 .65474 m .49632 .70962 L .49916 .71936 L p .707 .577 .707 r
F P
0 g
s
.49264 .78971 m .49002 .80775 L .50238 .81881 L p .707 .577 .707 r
F P
0 g
s
.49436 .77152 m .49946 .73539 L .4967 .72487 L p .707 .577 .707 r
F P
0 g
s
.70416 .67446 m .69954 .72934 L .69669 .7196 L p .707 .577 .707 r
F P
0 g
s
.69669 .7196 m .70132 .66472 L .70416 .67446 L p .707 .577 .707 r
F P
0 g
s
.49632 .70962 m .50094 .65474 L .50804 .64596 L p .707 .577 .707 r
F P
0 g
s
.4967 .72487 m .4916 .761 L .49436 .77152 L p .707 .577 .707 r
F P
0 g
s
.6847 .81908 m .68208 .83713 L .68921 .82806 L p .707 .577 .707 r
F P
0 g
s
.68921 .82806 m .69183 .81002 L .6847 .81908 L p .707 .577 .707 r
F P
0 g
s
.49002 .80775 m .49264 .78971 L .48989 .77913 L p .707 .577 .707 r
F P
0 g
s
.48989 .77913 m .48727 .79718 L .49002 .80775 L p .707 .577 .707 r
F P
0 g
s
.69875 .75504 m .69365 .79117 L .69089 .78065 L p .707 .577 .707 r
F P
0 g
s
.69089 .78065 m .69599 .74452 L .69875 .75504 L p .707 .577 .707 r
F P
0 g
s
.50804 .64596 m .50342 .70084 L .49632 .70962 L p .707 .577 .707 r
F P
0 g
s
.4916 .761 m .4967 .72487 L .50383 .71582 L p .707 .577 .707 r
F P
0 g
s
.70132 .66472 m .69669 .7196 L .68418 .70984 L p .707 .577 .707 r
F P
0 g
s
.68418 .70984 m .6888 .65496 L .70132 .66472 L p .707 .577 .707 r
F P
0 g
s
.50342 .70084 m .50804 .64596 L .52439 .63901 L p .707 .577 .707 r
F P
0 g
s
.24804 .71668 m .25266 .6618 L .2216 .65729 L p .707 .577 .707 r
F P
0 g
s
.25266 .6618 m .24804 .71668 L .27977 .71826 L p .707 .577 .707 r
F P
0 g
s
.27977 .71826 m .2844 .66338 L .25266 .6618 L p .707 .577 .707 r
F P
0 g
s
.50383 .71582 m .49873 .75195 L .4916 .761 L p .707 .577 .707 r
F P
0 g
s
.48904 .80929 m .39889 .30652 L .35561 .31192 L p .707 .577 .707 r
F P
0 g
s
.48727 .79718 m .48989 .77913 L .49702 .77006 L p .707 .577 .707 r
F P
0 g
s
.49702 .77006 m .4944 .78811 L .48727 .79718 L p .707 .577 .707 r
F P
0 g
s
.52439 .63901 m .51977 .69389 L .50342 .70084 L p .707 .577 .707 r
F P
0 g
s
.49873 .75195 m .50383 .71582 L .52015 .70914 L p .707 .577 .707 r
F P
0 g
s
.52015 .70914 m .51505 .74527 L .49873 .75195 L p .707 .577 .707 r
F P
0 g
s
.4944 .78811 m .49702 .77006 L .51334 .7634 L p .707 .577 .707 r
F P
0 g
s
.51334 .7634 m .51072 .78144 L .4944 .78811 L p .707 .577 .707 r
F P
0 g
s
.51505 .74527 m .52015 .70914 L .54407 .70547 L p .707 .577 .707 r
F P
0 g
s
.54407 .70547 m .53897 .7416 L .51505 .74527 L p .707 .577 .707 r
F P
0 g
s
.51072 .78144 m .51334 .7634 L .53725 .75978 L p .707 .577 .707 r
F P
0 g
s
.53725 .75978 m .53463 .77783 L .51072 .78144 L p .707 .577 .707 r
F P
0 g
s
.39889 .30652 m .48904 .80929 L .53333 .8009 L p .707 .577 .707 r
F P
0 g
s
.53333 .8009 m .44318 .29813 L .39889 .30652 L p .707 .577 .707 r
F P
0 g
s
.69183 .81002 m .68921 .82806 L .68646 .81749 L p .707 .577 .707 r
F P
0 g
s
.68646 .81749 m .68908 .79944 L .69183 .81002 L p .707 .577 .707 r
F P
0 g
s
.2844 .66338 m .27977 .71826 L .30908 .71675 L p .707 .577 .707 r
F P
0 g
s
.30908 .71675 m .3137 .66187 L .2844 .66338 L p .707 .577 .707 r
F P
0 g
s
.51977 .69389 m .52439 .63901 L .54839 .63456 L p .707 .577 .707 r
F P
0 g
s
.54839 .63456 m .54377 .68944 L .51977 .69389 L p .707 .577 .707 r
F P
0 g
s
.54377 .68944 m .54839 .63456 L .5777 .63305 L p .707 .577 .707 r
F P
0 g
s
.5777 .63305 m .57308 .68793 L .54377 .68944 L p .707 .577 .707 r
F P
0 g
s
.53897 .7416 m .54407 .70547 L .57323 .70518 L p .707 .577 .707 r
F P
0 g
s
.57323 .70518 m .56813 .7413 L .53897 .7416 L p .707 .577 .707 r
F P
0 g
s
.53463 .77783 m .53725 .75978 L .5664 .75957 L p .707 .577 .707 r
F P
0 g
s
.5664 .75957 m .56378 .77762 L .53463 .77783 L p .707 .577 .707 r
F P
0 g
s
.56378 .77762 m .5664 .75957 L .59795 .76279 L p .707 .577 .707 r
F P
0 g
s
.59795 .76279 m .59533 .78084 L .56378 .77762 L p .707 .577 .707 r
F P
0 g
s
.44318 .29813 m .53333 .8009 L .5743 .79035 L p .707 .577 .707 r
F P
0 g
s
.5743 .79035 m .48414 .28758 L .44318 .29813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21697 .71216 m .2216 .65729 L .19425 .65028 L p .707 .577 .707 r
F P
0 g
s
.2216 .65729 m .21697 .71216 L .24804 .71668 L p .707 .577 .707 r
F P
0 g
s
.44576 .81469 m .35561 .31192 L .31757 .31379 L p .707 .577 .707 r
F P
0 g
s
.35561 .31192 m .44576 .81469 L .48904 .80929 L p .707 .577 .707 r
F P
0 g
s
.69599 .74452 m .69089 .78065 L .67851 .76968 L p .707 .577 .707 r
F P
0 g
s
.67851 .76968 m .68361 .73355 L .69599 .74452 L p .707 .577 .707 r
F P
0 g
s
.3137 .66187 m .30908 .71675 L .33308 .7123 L p .707 .577 .707 r
F P
0 g
s
.33308 .7123 m .3377 .65742 L .3137 .66187 L p .707 .577 .707 r
F P
0 g
s
.6888 .65496 m .68418 .70984 L .66322 .70103 L p .707 .577 .707 r
F P
0 g
s
.66322 .70103 m .66785 .64615 L .6888 .65496 L p .707 .577 .707 r
F P
0 g
s
.57308 .68793 m .5777 .63305 L .60944 .63463 L p .707 .577 .707 r
F P
0 g
s
.60944 .63463 m .60481 .68951 L .57308 .68793 L p .707 .577 .707 r
F P
0 g
s
.56813 .7413 m .57323 .70518 L .6048 .70829 L p .707 .577 .707 r
F P
0 g
s
.6048 .70829 m .5997 .74442 L .56813 .7413 L p .707 .577 .707 r
F P
0 g
s
.62881 .76912 m .62619 .78716 L .59533 .78084 L p .707 .577 .707 r
F P
0 g
s
.59533 .78084 m .59795 .76279 L .62881 .76912 L p .707 .577 .707 r
F P
0 g
s
.48414 .28758 m .5743 .79035 L .60792 .77866 L p .707 .577 .707 r
F P
0 g
s
.63567 .7145 m .63057 .75063 L .5997 .74442 L p .707 .577 .707 r
F P
0 g
s
.5997 .74442 m .6048 .70829 L .63567 .7145 L p .707 .577 .707 r
F P
0 g
s
.60792 .77866 m .51776 .27588 L .48414 .28758 L p .707 .577 .707 r
F P
0 g
s
.18962 .70516 m .19425 .65028 L .17329 .64147 L p .707 .577 .707 r
F P
0 g
s
.19425 .65028 m .18962 .70516 L .21697 .71216 L p .707 .577 .707 r
F P
0 g
s
.24254 .78119 m .24764 .74506 L .21677 .73885 L p .707 .577 .707 r
F P
0 g
s
.24764 .74506 m .24254 .78119 L .27411 .7843 L p .707 .577 .707 r
F P
0 g
s
.27411 .7843 m .27921 .74817 L .24764 .74506 L p .707 .577 .707 r
F P
0 g
s
.27921 .74817 m .27411 .7843 L .30327 .78401 L p .707 .577 .707 r
F P
0 g
s
.30327 .78401 m .30837 .74788 L .27921 .74817 L p .707 .577 .707 r
F P
0 g
s
.21167 .77497 m .21677 .73885 L .18961 .73014 L p .707 .577 .707 r
F P
0 g
s
.21677 .73885 m .21167 .77497 L .24254 .78119 L p .707 .577 .707 r
F P
0 g
s
.68908 .79944 m .68646 .81749 L .6741 .80643 L p .707 .577 .707 r
F P
0 g
s
.6741 .80643 m .67672 .78839 L .68908 .79944 L p .707 .577 .707 r
F P
0 g
s
.3377 .65742 m .33308 .7123 L .34943 .70535 L p .707 .577 .707 r
F P
0 g
s
.34943 .70535 m .35405 .65047 L .3377 .65742 L p .707 .577 .707 r
F P
0 g
s
.40772 .81657 m .31757 .31379 L .28849 .31197 L p .707 .577 .707 r
F P
0 g
s
.31757 .31379 m .40772 .81657 L .44576 .81469 L p .707 .577 .707 r
F P
0 g
s
.17329 .64147 m .16867 .69635 L .18962 .70516 L p .707 .577 .707 r
F P
0 g
s
.66785 .64615 m .66322 .70103 L .63587 .69403 L p .707 .577 .707 r
F P
0 g
s
.63587 .69403 m .6405 .63915 L .66785 .64615 L p .707 .577 .707 r
F P
0 g
s
.68361 .73355 m .67851 .76968 L .65773 .75933 L p .707 .577 .707 r
F P
0 g
s
.65773 .75933 m .66283 .7232 L .68361 .73355 L p .707 .577 .707 r
F P
0 g
s
.30837 .74788 m .30327 .78401 L .32719 .78034 L p .707 .577 .707 r
F P
0 g
s
.32719 .78034 m .33229 .74421 L .30837 .74788 L p .707 .577 .707 r
F P
0 g
s
.18961 .73014 m .18451 .76627 L .21167 .77497 L p .707 .577 .707 r
F P
0 g
s
.16867 .69635 m .17329 .64147 L .16078 .63171 L p .707 .577 .707 r
F P
0 g
s
.18451 .76627 m .18961 .73014 L .16883 .7198 L p .707 .577 .707 r
F P
0 g
s
.23814 .82767 m .24076 .80963 L .2099 .8033 L p .707 .577 .707 r
F P
0 g
s
.24076 .80963 m .23814 .82767 L .26969 .83089 L p .707 .577 .707 r
F P
0 g
s
.26969 .83089 m .27231 .81285 L .24076 .80963 L p .707 .577 .707 r
F P
0 g
s
.6405 .63915 m .63587 .69403 L .60481 .68951 L p .707 .577 .707 r
F P
0 g
s
.60481 .68951 m .60944 .63463 L .6405 .63915 L p .707 .577 .707 r
F P
0 g
s
.51776 .27588 m .60792 .77866 L .63091 .76697 L p .707 .577 .707 r
F P
0 g
s
.63091 .76697 m .54076 .2642 L .51776 .27588 L p .707 .577 .707 r
F P
0 g
s
.27231 .81285 m .26969 .83089 L .29884 .83068 L p .707 .577 .707 r
F P
0 g
s
.29884 .83068 m .30146 .81264 L .27231 .81285 L p .707 .577 .707 r
F P
0 g
s
.20728 .82135 m .2099 .8033 L .18276 .79448 L p .707 .577 .707 r
F P
0 g
s
.2099 .8033 m .20728 .82135 L .23814 .82767 L p .707 .577 .707 r
F P
0 g
s
.16883 .7198 m .16373 .75593 L .18451 .76627 L p .707 .577 .707 r
F P
0 g
s
.18276 .79448 m .18014 .81253 L .20728 .82135 L p .707 .577 .707 r
F P
0 g
s
.67672 .78839 m .6741 .80643 L .65333 .79598 L p .707 .577 .707 r
F P
0 g
s
.65333 .79598 m .65595 .77794 L .67672 .78839 L p .707 .577 .707 r
F P
0 g
s
.16078 .63171 m .15615 .68659 L .16867 .69635 L p .707 .577 .707 r
F P
0 g
s
.33229 .74421 m .32719 .78034 L .34351 .77365 L p .707 .577 .707 r
F P
0 g
s
.34351 .77365 m .34861 .73753 L .33229 .74421 L p .707 .577 .707 r
F P
0 g
s
.30146 .81264 m .29884 .83068 L .32275 .82707 L p .707 .577 .707 r
F P
0 g
s
.32275 .82707 m .32537 .80902 L .30146 .81264 L p .707 .577 .707 r
F P
0 g
s
.35405 .65047 m .34943 .70535 L .35653 .69657 L p .707 .577 .707 r
F P
0 g
s
.35653 .69657 m .36116 .64169 L .35405 .65047 L p .707 .577 .707 r
F P
0 g
s
.66283 .7232 m .65773 .75933 L .63057 .75063 L p .707 .577 .707 r
F P
0 g
s
.63057 .75063 m .63567 .7145 L .66283 .7232 L p .707 .577 .707 r
F P
0 g
s
.18014 .81253 m .18276 .79448 L .16199 .78403 L p .707 .577 .707 r
F P
0 g
s
.16373 .75593 m .16883 .7198 L .15645 .70883 L p .707 .577 .707 r
F P
0 g
s
.15615 .68659 m .16078 .63171 L .15793 .62197 L p .707 .577 .707 r
F P
0 g
s
.16199 .78403 m .15937 .80208 L .18014 .81253 L p .707 .577 .707 r
F P
0 g
s
.36116 .64169 m .35653 .69657 L .35369 .68683 L p .707 .577 .707 r
F P
0 g
s
.35369 .68683 m .35563 .66371 L p .36116 .64169 L .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .40772 .81657 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.28849 .31197 m .35114 .66131 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.36025 .61564 m .35114 .66131 L .3579 .63675 L .707 .577 .707 r
F
.28849 .31197 m .27124 .30663 L p .34559 .65836 L F P
0 g
s
.34117 .67707 m .34783 .65955 L .34833 .65982 L .707 .577 .707 r
F
.35369 .68683 m .3458 .68068 L p .35114 .66131 L F P
0 g
s
.3579 .63675 m .35563 .66371 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35563 .66371 m .35369 .68683 L p .35114 .66131 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .35114 .66131 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .28849 .31197 L p .34694 .65908 L .707 .577 .707 r
F P
0 g
s
.3458 .68068 m .34117 .67707 L p .34833 .65982 L .707 .577 .707 r
F P
0 g
s
.34833 .65982 m .3579 .63675 L .35114 .66131 L .707 .577 .707 r
F
.34833 .65982 m .35114 .66131 L .3458 .68068 L F
.35064 .76461 m .35353 .74413 L p .34861 .73753 L F P
0 g
s
.35353 .74413 m .35574 .72848 L .35234 .73279 L p .707 .577 .707 r
F P
0 g
s
.35234 .73279 m .34861 .73753 L p .35353 .74413 L .707 .577 .707 r
F P
0 g
s
.34861 .73753 m .34351 .77365 L .35064 .76461 L p .707 .577 .707 r
F P
0 g
s
.35064 .76461 m .34788 .75408 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35574 .72848 m .35353 .74413 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35353 .74413 m .35064 .76461 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3406 .70698 L .3452 .71106 L p .707 .577 .707 r
F P
0 g
s
.3452 .71106 m .35298 .71795 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.3355 .74311 m .3452 .71106 L .34813 .72493 L .707 .577 .707 r
F
.32484 .61338 m .3266 .61412 L p .32101 .66154 L F P
0 g
s
.32087 .66052 m .32484 .61338 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.3266 .61412 m .32977 .61545 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.27124 .30663 m .32248 .59241 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .32248 .59241 L .34287 .65691 L .707 .577 .707 r
F
.34694 .65908 m .28849 .31197 L .34559 .65836 L F
.32977 .61545 m .34579 .62219 L p .33694 .63814 L F P
0 g
s
.33263 .64591 m .32977 .61545 L .33694 .63814 L .707 .577 .707 r
F
.32021 .66826 m .3266 .61412 L .33263 .64591 L F
.34117 .67707 m .33831 .67587 L p .34154 .6527 L F P
0 g
s
.34287 .65691 m .34117 .67707 L p .34154 .6527 L .707 .577 .707 r
F P
0 g
s
.33831 .67587 m .32021 .66826 L p .33263 .64591 L .707 .577 .707 r
F P
0 g
s
.33263 .64591 m .34579 .62219 L .33831 .67587 L .707 .577 .707 r
F
.35298 .71795 m .35574 .72848 L p .3521 .74032 L F P
0 g
s
.34788 .75408 m .35045 .73589 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .35298 .71795 L p .3521 .74032 L .707 .577 .707 r
F P
0 g
s
.34788 .75408 m .3355 .74311 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35298 .71795 m .35045 .73589 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35045 .73589 m .34788 .75408 L p .34813 .72493 L .707 .577 .707 r
F P
0 g
s
.35764 .80105 m .36139 .8094 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32484 .61338 m .32021 .66826 L .29287 .66125 L p .707 .577 .707 r
F P
0 g
s
.29287 .66125 m .29749 .60638 L .32484 .61338 L p .707 .577 .707 r
F P
0 g
s
.26748 .29828 m .32086 .59598 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.32086 .59598 m .35764 .80105 L p .33089 .64341 L .707 .577 .707 r
F P
0 g
s
.35893 .79566 m .34614 .72434 L p .35901 .79643 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .27124 .30663 L p .34604 .72409 L .707 .577 .707 r
F P
0 g
s
.34614 .72434 m .34604 .72409 L .35901 .79643 L .707 .577 .707 r
F
.34117 .67707 m .34579 .62219 L .35831 .63195 L p F P
0 g
s
.33312 .65172 m .36139 .8094 L p .34671 .66907 L .707 .577 .707 r
F P
0 g
s
.34559 .65836 m .34287 .65691 L .34671 .66907 L .707 .577 .707 r
F
.34287 .65691 m .33312 .65172 L .34671 .66907 L F
.34579 .62219 m .34287 .65691 L p .34154 .6527 L F P
0 g
s
.33359 .65617 m .31801 .56883 L .33089 .64341 L .707 .577 .707 r
F
.31801 .56883 m .27124 .30663 L .31301 .54248 L F
.31801 .56883 m .31301 .54248 L .33089 .64341 L F
.32248 .59241 m .33312 .65172 L p .34287 .65691 L F P
0 g
s
.27124 .30663 m .26748 .29828 L p .2915 .42902 L .707 .577 .707 r
F P
0 g
s
.33089 .64341 m .31301 .54248 L .2915 .42902 L .707 .577 .707 r
F
.31301 .54248 m .27124 .30663 L .2915 .42902 L F
.3454 .72235 m .33359 .65617 L .33089 .64341 L F
.34604 .72409 m .27124 .30663 L .3454 .72235 L F
.35764 .80105 m .28085 .37286 L p .27759 .28775 L F P
0 g
s
.28085 .37286 m .26748 .29828 L .2701 .29555 L p .707 .577 .707 r
F P
0 g
s
.2701 .29555 m .27759 .28775 L p .28085 .37286 L .707 .577 .707 r
F P
0 g
s
.32021 .66826 m .32087 .66052 L p .32101 .66154 L .707 .577 .707 r
F P
0 g
s
.35901 .79643 m .34604 .72409 L .3454 .72235 L .707 .577 .707 r
F
.36139 .8094 m .35893 .79566 L p .35901 .79643 L F P
0 g
s
.36139 .8094 m .37865 .81474 L p .34559 .65836 L .707 .577 .707 r
F P
0 g
s
.35114 .66131 m .34694 .65908 L .35162 .68689 L .707 .577 .707 r
F
.35162 .68689 m .34694 .65908 L .34559 .65836 L F
.35831 .63195 m .3579 .63675 L p .34833 .65982 L F P
0 g
s
.34783 .65955 m .35831 .63195 L .34833 .65982 L .707 .577 .707 r
F
.35114 .66131 m .35364 .67525 L p .3579 .63675 L F P
0 g
s
.35563 .66371 m .3579 .63675 L p .36008 .63801 L .707 .577 .707 r
F P
0 g
s
.3584 .63227 m .36008 .63801 L p .3579 .63675 L .707 .577 .707 r
F P
0 g
s
.36008 .63801 m .36116 .64169 L p .35563 .66371 L .707 .577 .707 r
F P
0 g
s
.35364 .67525 m .37865 .81474 L p .36025 .61564 L .707 .577 .707 r
F P
0 g
s
.3579 .63675 m .35831 .63195 L .3584 .63227 L p .707 .577 .707 r
F P
0 g
s
.37865 .81474 m .35364 .67525 L p .35162 .68689 L .707 .577 .707 r
F P
0 g
s
.15645 .70883 m .15135 .74496 L .16373 .75593 L p .707 .577 .707 r
F P
0 g
s
.65595 .77794 m .65333 .79598 L .62619 .78716 L p .707 .577 .707 r
F P
0 g
s
.62619 .78716 m .62881 .76912 L .65595 .77794 L p .707 .577 .707 r
F P
0 g
s
.32537 .80902 m .32275 .82707 L .33907 .8204 L p .707 .577 .707 r
F P
0 g
s
.33907 .8204 m .34169 .80236 L .32537 .80902 L p .707 .577 .707 r
F P
0 g
s
.54076 .2642 m .63091 .76697 L .64103 .75645 L p .707 .577 .707 r
F P
0 g
s
.64103 .75645 m .55087 .25367 L .54076 .2642 L p .707 .577 .707 r
F P
0 g
s
.15937 .80208 m .16199 .78403 L .14963 .77298 L p .707 .577 .707 r
F P
0 g
s
.15793 .62197 m .15331 .67685 L .15615 .68659 L p .707 .577 .707 r
F P
0 g
s
.14963 .77298 m .14701 .79103 L .15937 .80208 L p .707 .577 .707 r
F P
0 g
s
.15135 .74496 m .15645 .70883 L .15369 .69831 L p .707 .577 .707 r
F P
0 g
s
.15331 .67685 m .15793 .62197 L .16503 .61319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15369 .69831 m .14859 .73443 L .15135 .74496 L p .707 .577 .707 r
F P
0 g
s
.34169 .80236 m .33907 .8204 L .3462 .81134 L p .707 .577 .707 r
F P
0 g
s
.3462 .81134 m .34882 .79329 L .34169 .80236 L p .707 .577 .707 r
F P
0 g
s
.14701 .79103 m .14963 .77298 L .14688 .7624 L p .707 .577 .707 r
F P
0 g
s
.16503 .61319 m .16041 .66807 L .15331 .67685 L p .707 .577 .707 r
F P
0 g
s
.14688 .7624 m .14426 .78045 L .14701 .79103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14859 .73443 m .15369 .69831 L .16082 .68926 L p .707 .577 .707 r
F P
0 g
s
.55087 .25367 m .64103 .75645 L .63727 .7481 L p .707 .577 .707 r
F P
0 g
s
.63727 .7481 m .54712 .24533 L .55087 .25367 L p .707 .577 .707 r
F P
0 g
s
.16041 .66807 m .16503 .61319 L .18138 .60624 L p .707 .577 .707 r
F P
0 g
s
.16082 .68926 m .15572 .72539 L .14859 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34882 .79329 m .3462 .81134 L .34345 .80076 L p .707 .577 .707 r
F P
0 g
s
.34345 .80076 m .34607 .78271 L .34882 .79329 L p .707 .577 .707 r
F P
0 g
s
.14426 .78045 m .14688 .7624 L .15401 .75334 L p .707 .577 .707 r
F P
0 g
s
.18138 .60624 m .17676 .66112 L .16041 .66807 L p .707 .577 .707 r
F P
0 g
s
.15401 .75334 m .15139 .77138 L .14426 .78045 L p .707 .577 .707 r
F P
0 g
s
.15572 .72539 m .16082 .68926 L .17714 .68257 L p .707 .577 .707 r
F P
0 g
s
.17676 .66112 m .18138 .60624 L .20539 .60179 L p .707 .577 .707 r
F P
0 g
s
.17714 .68257 m .17204 .7187 L .15572 .72539 L p .707 .577 .707 r
F P
0 g
s
.34607 .78271 m .34345 .80076 L .33109 .7897 L p .707 .577 .707 r
F P
0 g
s
.33109 .7897 m .33371 .77166 L .34607 .78271 L p .707 .577 .707 r
F P
0 g
s
.54712 .24533 m .63727 .7481 L .62001 .74276 L p .707 .577 .707 r
F P
0 g
s
.62001 .74276 m .52986 .23998 L .54712 .24533 L p .707 .577 .707 r
F P
0 g
s
.15139 .77138 m .15401 .75334 L .17033 .74667 L p .707 .577 .707 r
F P
0 g
s
.20539 .60179 m .20076 .65667 L .17676 .66112 L p .707 .577 .707 r
F P
0 g
s
.3406 .70698 m .3355 .74311 L .31472 .73277 L p .707 .577 .707 r
F P
0 g
s
.31472 .73277 m .31982 .69664 L .3406 .70698 L p .707 .577 .707 r
F P
0 g
s
.20076 .65667 m .20539 .60179 L .23469 .60028 L p .707 .577 .707 r
F P
0 g
s
.17204 .7187 m .17714 .68257 L .20106 .67891 L p .707 .577 .707 r
F P
0 g
s
.17033 .74667 m .16771 .76472 L .15139 .77138 L p .707 .577 .707 r
F P
0 g
s
.29749 .60638 m .29287 .66125 L .2618 .65674 L p .707 .577 .707 r
F P
0 g
s
.2618 .65674 m .26643 .60186 L .29749 .60638 L p .707 .577 .707 r
F P
0 g
s
.23007 .65516 m .23469 .60028 L .26643 .60186 L p .707 .577 .707 r
F P
0 g
s
.23469 .60028 m .23007 .65516 L .20076 .65667 L p .707 .577 .707 r
F P
0 g
s
.20106 .67891 m .19596 .71503 L .17204 .7187 L p .707 .577 .707 r
F P
0 g
s
.26643 .60186 m .2618 .65674 L .23007 .65516 L p .707 .577 .707 r
F P
0 g
s
.72825 .65741 m .73287 .60253 L .70181 .59802 L p .707 .577 .707 r
F P
0 g
s
.73287 .60253 m .72825 .65741 L .75999 .65899 L p .707 .577 .707 r
F P
0 g
s
.75999 .65899 m .76461 .60411 L .73287 .60253 L p .707 .577 .707 r
F P
0 g
s
.33371 .77166 m .33109 .7897 L .31032 .77926 L p .707 .577 .707 r
F P
0 g
s
.31032 .77926 m .31294 .76121 L .33371 .77166 L p .707 .577 .707 r
F P
0 g
s
.31982 .69664 m .31472 .73277 L .28756 .72406 L p .707 .577 .707 r
F P
0 g
s
.28756 .72406 m .29266 .68794 L .31982 .69664 L p .707 .577 .707 r
F P
0 g
s
.76461 .60411 m .75999 .65899 L .78929 .65748 L p .707 .577 .707 r
F P
0 g
s
.78929 .65748 m .79391 .6026 L .76461 .60411 L p .707 .577 .707 r
F P
0 g
s
.36775 .79052 m .27759 .28775 L .30059 .27607 L p .707 .577 .707 r
F P
0 g
s
.27759 .28775 m .36775 .79052 L .35764 .80105 L p .707 .577 .707 r
F P
0 g
s
.16771 .76472 m .17033 .74667 L .19424 .74306 L p .707 .577 .707 r
F P
0 g
s
.19596 .71503 m .20106 .67891 L .23022 .67861 L p .707 .577 .707 r
F P
0 g
s
.69719 .6529 m .70181 .59802 L .67446 .59101 L p .707 .577 .707 r
F P
0 g
s
.70181 .59802 m .69719 .6529 L .72825 .65741 L p .707 .577 .707 r
F P
0 g
s
.19424 .74306 m .19162 .7611 L .16771 .76472 L p .707 .577 .707 r
F P
0 g
s
.52986 .23998 m .62001 .74276 L .59094 .74093 L p .707 .577 .707 r
F P
0 g
s
.59094 .74093 m .50079 .23816 L .52986 .23998 L p .707 .577 .707 r
F P
0 g
s
.79391 .6026 m .78929 .65748 L .81329 .65303 L p .707 .577 .707 r
F P
0 g
s
.81329 .65303 m .81792 .59816 L .79391 .6026 L p .707 .577 .707 r
F P
0 g
s
.29266 .68794 m .28756 .72406 L .25669 .71785 L p .707 .577 .707 r
F P
0 g
s
.25669 .71785 m .26179 .68173 L .29266 .68794 L p .707 .577 .707 r
F P
0 g
s
.23022 .67861 m .22512 .71474 L .19596 .71503 L p .707 .577 .707 r
F P
0 g
s
.22512 .71474 m .23022 .67861 L .26179 .68173 L p .707 .577 .707 r
F P
0 g
s
.66984 .64589 m .67446 .59101 L .6535 .5822 L p .707 .577 .707 r
F P
0 g
s
.67446 .59101 m .66984 .64589 L .69719 .6529 L p .707 .577 .707 r
F P
0 g
s
.26179 .68173 m .25669 .71785 L .22512 .71474 L p .707 .577 .707 r
F P
0 g
s
.31294 .76121 m .31032 .77926 L .28318 .77044 L p .707 .577 .707 r
F P
0 g
s
.28318 .77044 m .2858 .75239 L .31294 .76121 L p .707 .577 .707 r
F P
0 g
s
.72275 .71571 m .72785 .67958 L .69698 .67337 L p .707 .577 .707 r
F P
0 g
s
.72785 .67958 m .72275 .71571 L .75432 .71882 L p .707 .577 .707 r
F P
0 g
s
.75432 .71882 m .75942 .6827 L .72785 .67958 L p .707 .577 .707 r
F P
0 g
s
.19162 .7611 m .19424 .74306 L .22339 .74285 L p .707 .577 .707 r
F P
0 g
s
.75942 .6827 m .75432 .71882 L .78349 .71853 L p .707 .577 .707 r
F P
0 g
s
.78349 .71853 m .78859 .6824 L .75942 .6827 L p .707 .577 .707 r
F P
0 g
s
.69188 .7095 m .69698 .67337 L .66982 .66467 L p .707 .577 .707 r
F P
0 g
s
.69698 .67337 m .69188 .7095 L .72275 .71571 L p .707 .577 .707 r
F P
0 g
s
.22339 .74285 m .22077 .76089 L .19162 .7611 L p .707 .577 .707 r
F P
0 g
s
.81792 .59816 m .81329 .65303 L .82964 .64608 L p .707 .577 .707 r
F P
0 g
s
.82964 .64608 m .83427 .5912 L .81792 .59816 L p .707 .577 .707 r
F P
0 g
s
.2858 .75239 m .28318 .77044 L .25232 .76411 L p .707 .577 .707 r
F P
0 g
s
.25232 .76411 m .25494 .74606 L .2858 .75239 L p .707 .577 .707 r
F P
0 g
s
.6535 .5822 m .64888 .63708 L .66984 .64589 L p .707 .577 .707 r
F P
0 g
s
.22077 .76089 m .22339 .74285 L .25494 .74606 L p .707 .577 .707 r
F P
0 g
s
.30059 .27607 m .39074 .77884 L .36775 .79052 L p .707 .577 .707 r
F P
0 g
s
.39074 .77884 m .30059 .27607 L .33421 .26438 L p .707 .577 .707 r
F P
0 g
s
.78859 .6824 m .78349 .71853 L .8074 .71486 L p .707 .577 .707 r
F P
0 g
s
.8074 .71486 m .8125 .67874 L .78859 .6824 L p .707 .577 .707 r
F P
0 g
s
.66982 .66467 m .66472 .7008 L .69188 .7095 L p .707 .577 .707 r
F P
0 g
s
.71835 .75236 m .72097 .73432 L .69012 .72799 L p .707 .577 .707 r
F P
0 g
s
.72097 .73432 m .71835 .75236 L .7499 .75558 L p .707 .577 .707 r
F P
0 g
s
.7499 .75558 m .75252 .73754 L .72097 .73432 L p .707 .577 .707 r
F P
0 g
s
.25494 .74606 m .25232 .76411 L .22077 .76089 L p .707 .577 .707 r
F P
0 g
s
.66472 .7008 m .66982 .66467 L .64904 .65433 L p .707 .577 .707 r
F P
0 g
s
.64888 .63708 m .6535 .5822 L .64099 .57245 L p .707 .577 .707 r
F P
0 g
s
.75252 .73754 m .7499 .75558 L .77906 .75537 L p .707 .577 .707 r
F P
0 g
s
.77906 .75537 m .78168 .73733 L .75252 .73754 L p .707 .577 .707 r
F P
0 g
s
.6875 .74604 m .69012 .72799 L .66298 .71917 L p .707 .577 .707 r
F P
0 g
s
.69012 .72799 m .6875 .74604 L .71835 .75236 L p .707 .577 .707 r
F P
0 g
s
.50079 .23816 m .59094 .74093 L .5529 .74281 L p .707 .577 .707 r
F P
0 g
s
.5529 .74281 m .46275 .24004 L .50079 .23816 L p .707 .577 .707 r
F P
0 g
s
.66298 .71917 m .66036 .73722 L .6875 .74604 L p .707 .577 .707 r
F P
0 g
s
.64904 .65433 m .64394 .69045 L .66472 .7008 L p .707 .577 .707 r
F P
0 g
s
.78168 .73733 m .77906 .75537 L .80297 .75176 L p .707 .577 .707 r
F P
0 g
s
.80297 .75176 m .80558 .73371 L .78168 .73733 L p .707 .577 .707 r
F P
0 g
s
.64099 .57245 m .63637 .62733 L .64888 .63708 L p .707 .577 .707 r
F P
0 g
s
.8125 .67874 m .8074 .71486 L .82372 .70818 L p .707 .577 .707 r
F P
0 g
s
.82372 .70818 m .82882 .67205 L .8125 .67874 L p .707 .577 .707 r
F P
0 g
s
.66036 .73722 m .66298 .71917 L .64221 .70872 L p .707 .577 .707 r
F P
0 g
s
.83427 .5912 m .82964 .64608 L .83675 .6373 L p .707 .577 .707 r
F P
0 g
s
.83675 .6373 m .84137 .58242 L .83427 .5912 L p .707 .577 .707 r
F P
0 g
s
.64394 .69045 m .64904 .65433 L .63666 .64336 L p .707 .577 .707 r
F P
0 g
s
.64221 .70872 m .63959 .72677 L .66036 .73722 L p .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .38546 .55016 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .4216 .57134 L .39733 .57013 L p .707 .577 .707 r
F P
0 g
s
.46533 .7566 m .42437 .76715 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4216 .57134 m .41867 .60606 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .46533 .7566 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4216 .57134 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.44941 .57918 m .43782 .60317 L .44925 .57744 L .707 .577 .707 r
F
.46533 .7566 m .44032 .6171 L p .44941 .57918 L F P
0 g
s
.44032 .6171 m .43782 .60317 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.4509 .56983 m .4505 .57463 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.4505 .57463 m .4509 .56983 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .46533 .7566 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.45169 .56969 m .4509 .56983 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.41946 .24544 m .46652 .50784 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.46652 .50784 m .50962 .74821 L p .44941 .57918 L .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .47491 .56538 L .45169 .56969 L p .707 .577 .707 r
F P
0 g
s
.47028 .62026 m .45169 .56969 L .45136 .57103 L .707 .577 .707 r
F
.44628 .62471 m .47028 .62026 L p .45136 .57103 L F P
0 g
s
.4505 .57463 m .44628 .62471 L p .45136 .57103 L .707 .577 .707 r
F P
0 g
s
.44628 .62471 m .4505 .57463 L p .43708 .60482 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .41946 .24544 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.43782 .60317 m .37517 .25383 L p .44925 .57744 L .707 .577 .707 r
F P
0 g
s
.37517 .25383 m .43782 .60317 L p .40907 .60751 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .44628 .62471 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41867 .60606 m .41698 .62622 L p .43641 .60338 L .707 .577 .707 r
F P
0 g
s
.41698 .62622 m .41867 .60606 L p .38986 .56976 L .707 .577 .707 r
F P
0 g
s
.39733 .57013 m .38986 .56976 L p .41867 .60606 L .707 .577 .707 r
F P
0 g
s
.33421 .26438 m .37517 .25383 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .33421 .26438 L p .40706 .58651 L .707 .577 .707 r
F P
0 g
s
.42437 .76715 m .39074 .77884 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38546 .55016 m .42437 .76715 L p .35684 .4703 L .707 .577 .707 r
F P
0 g
s
.38986 .56976 m .38524 .62464 L .41264 .626 L p .707 .577 .707 r
F P
0 g
s
.41264 .626 m .41698 .62622 L p .40018 .59125 L .707 .577 .707 r
F P
0 g
s
.40018 .59125 m .38986 .56976 L .41264 .626 L .707 .577 .707 r
F
.33421 .26438 m .38546 .55016 L p .35684 .4703 L F P
0 g
s
.63637 .62733 m .64099 .57245 L .63814 .5627 L p .707 .577 .707 r
F P
0 g
s
.46275 .24004 m .5529 .74281 L .50962 .74821 L p .707 .577 .707 r
F P
0 g
s
.50962 .74821 m .41946 .24544 L .46275 .24004 L p .707 .577 .707 r
F P
0 g
s
.63666 .64336 m .63156 .67948 L .64394 .69045 L p .707 .577 .707 r
F P
0 g
s
.80558 .73371 m .80297 .75176 L .81928 .74509 L p .707 .577 .707 r
F P
0 g
s
.81928 .74509 m .8219 .72704 L .80558 .73371 L p .707 .577 .707 r
F P
0 g
s
.63959 .72677 m .64221 .70872 L .62984 .69767 L p .707 .577 .707 r
F P
0 g
s
.82882 .67205 m .82372 .70818 L .83085 .69913 L p .707 .577 .707 r
F P
0 g
s
.83085 .69913 m .83595 .663 L .82882 .67205 L p .707 .577 .707 r
F P
0 g
s
.63814 .5627 m .63352 .61758 L .63637 .62733 L p .707 .577 .707 r
F P
0 g
s
.62984 .69767 m .62722 .71572 L .63959 .72677 L p .707 .577 .707 r
F P
0 g
s
.63156 .67948 m .63666 .64336 L .6339 .63283 L p .707 .577 .707 r
F P
0 g
s
.84137 .58242 m .83675 .6373 L .8339 .62756 L p .707 .577 .707 r
F P
0 g
s
.8339 .62756 m .83852 .57268 L .84137 .58242 L p .707 .577 .707 r
F P
0 g
s
.63352 .61758 m .63814 .5627 L .64524 .55393 L p .707 .577 .707 r
F P
0 g
s
.6339 .63283 m .6288 .66896 L .63156 .67948 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.8219 .72704 m .81928 .74509 L .82642 .73603 L p .707 .577 .707 r
F P
0 g
s
.82642 .73603 m .82904 .71798 L .8219 .72704 L p .707 .577 .707 r
F P
0 g
s
.62722 .71572 m .62984 .69767 L .62709 .68709 L p .707 .577 .707 r
F P
0 g
s
.62709 .68709 m .62447 .70514 L .62722 .71572 L p .707 .577 .707 r
F P
0 g
s
.83595 .663 m .83085 .69913 L .82809 .68861 L p .707 .577 .707 r
F P
0 g
s
.82809 .68861 m .83319 .65248 L .83595 .663 L p .707 .577 .707 r
F P
0 g
s
.64524 .55393 m .64062 .6088 L .63352 .61758 L p .707 .577 .707 r
F P
0 g
s
.6288 .66896 m .6339 .63283 L .64104 .62378 L p .707 .577 .707 r
F P
0 g
s
.83852 .57268 m .8339 .62756 L .82139 .6178 L p .707 .577 .707 r
F P
0 g
s
.82139 .6178 m .82601 .56293 L .83852 .57268 L p .707 .577 .707 r
F P
0 g
s
.64062 .6088 m .64524 .55393 L .6616 .54697 L p .707 .577 .707 r
F P
0 g
s
.38524 .62464 m .38986 .56976 L .3588 .56525 L p .707 .577 .707 r
F P
0 g
s
.64104 .62378 m .63593 .65991 L .6288 .66896 L p .707 .577 .707 r
F P
0 g
s
.82904 .71798 m .82642 .73603 L .82367 .72545 L p .707 .577 .707 r
F P
0 g
s
.82367 .72545 m .82629 .7074 L .82904 .71798 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35418 .62013 m .3588 .56525 L .33145 .55824 L p .707 .577 .707 r
F P
0 g
s
.3588 .56525 m .35418 .62013 L .38524 .62464 L p .707 .577 .707 r
F P
0 g
s
.62447 .70514 m .62709 .68709 L .63422 .67803 L p .707 .577 .707 r
F P
0 g
s
.63422 .67803 m .6316 .69607 L .62447 .70514 L p .707 .577 .707 r
F P
0 g
s
.83319 .65248 m .82809 .68861 L .81572 .67764 L p .707 .577 .707 r
F P
0 g
s
.81572 .67764 m .82082 .64151 L .83319 .65248 L p .707 .577 .707 r
F P
0 g
s
.6616 .54697 m .65697 .60185 L .64062 .6088 L p .707 .577 .707 r
F P
0 g
s
.82601 .56293 m .82139 .6178 L .80043 .60899 L p .707 .577 .707 r
F P
0 g
s
.80043 .60899 m .80505 .55411 L .82601 .56293 L p .707 .577 .707 r
F P
0 g
s
.63593 .65991 m .64104 .62378 L .65736 .6171 L p .707 .577 .707 r
F P
0 g
s
.32683 .61312 m .33145 .55824 L .31049 .54943 L p .707 .577 .707 r
F P
0 g
s
.33145 .55824 m .32683 .61312 L .35418 .62013 L p .707 .577 .707 r
F P
0 g
s
.65697 .60185 m .6616 .54697 L .6856 .54252 L p .707 .577 .707 r
F P
0 g
s
.37974 .68915 m .38484 .65302 L .35397 .64681 L p .707 .577 .707 r
F P
0 g
s
.38484 .65302 m .37974 .68915 L .41131 .69226 L p .707 .577 .707 r
F P
0 g
s
.41131 .69226 m .41641 .65613 L .38484 .65302 L p .707 .577 .707 r
F P
0 g
s
.41641 .65613 m .41131 .69226 L .44048 .69197 L p .707 .577 .707 r
F P
0 g
s
.44048 .69197 m .44558 .65584 L .41641 .65613 L p .707 .577 .707 r
F P
0 g
s
.34887 .68294 m .35397 .64681 L .32681 .63811 L p .707 .577 .707 r
F P
0 g
s
.35397 .64681 m .34887 .68294 L .37974 .68915 L p .707 .577 .707 r
F P
0 g
s
.65736 .6171 m .65226 .65323 L .63593 .65991 L p .707 .577 .707 r
F P
0 g
s
.82629 .7074 m .82367 .72545 L .8113 .71439 L p .707 .577 .707 r
F P
0 g
s
.8113 .71439 m .81392 .69635 L .82629 .7074 L p .707 .577 .707 r
F P
0 g
s
.47491 .56538 m .47028 .62026 L .48663 .61331 L p .707 .577 .707 r
F P
0 g
s
.48663 .61331 m .49126 .55843 L .47491 .56538 L p .707 .577 .707 r
F P
0 g
s
.6316 .69607 m .63422 .67803 L .65054 .67136 L p .707 .577 .707 r
F P
0 g
s
.31049 .54943 m .30587 .60431 L .32683 .61312 L p .707 .577 .707 r
F P
0 g
s
.80505 .55411 m .80043 .60899 L .77308 .60199 L p .707 .577 .707 r
F P
0 g
s
.77308 .60199 m .7777 .54711 L .80505 .55411 L p .707 .577 .707 r
F P
0 g
s
.6856 .54252 m .68098 .5974 L .65697 .60185 L p .707 .577 .707 r
F P
0 g
s
.82082 .64151 m .81572 .67764 L .79493 .66729 L p .707 .577 .707 r
F P
0 g
s
.79493 .66729 m .80003 .63117 L .82082 .64151 L p .707 .577 .707 r
F P
0 g
s
.44558 .65584 m .44048 .69197 L .46439 .6883 L p .707 .577 .707 r
F P
0 g
s
.46439 .6883 m .46949 .65217 L .44558 .65584 L p .707 .577 .707 r
F P
0 g
s
.32681 .63811 m .32171 .67423 L .34887 .68294 L p .707 .577 .707 r
F P
0 g
s
.65054 .67136 m .64792 .68941 L .6316 .69607 L p .707 .577 .707 r
F P
0 g
s
.30587 .60431 m .31049 .54943 L .29798 .53968 L p .707 .577 .707 r
F P
0 g
s
.32171 .67423 m .32681 .63811 L .30603 .62776 L p .707 .577 .707 r
F P
0 g
s
.68098 .5974 m .6856 .54252 L .7149 .54101 L p .707 .577 .707 r
F P
0 g
s
.65226 .65323 m .65736 .6171 L .68127 .61343 L p .707 .577 .707 r
F P
0 g
s
.37534 .73564 m .37796 .71759 L .34711 .71126 L p .707 .577 .707 r
F P
0 g
s
.37796 .71759 m .37534 .73564 L .40689 .73885 L p .707 .577 .707 r
F P
0 g
s
.40689 .73885 m .40951 .72081 L .37796 .71759 L p .707 .577 .707 r
F P
0 g
s
.40951 .72081 m .40689 .73885 L .43605 .73864 L p .707 .577 .707 r
F P
0 g
s
.43605 .73864 m .43867 .7206 L .40951 .72081 L p .707 .577 .707 r
F P
0 g
s
.34449 .72931 m .34711 .71126 L .31997 .70244 L p .707 .577 .707 r
F P
0 g
s
.34711 .71126 m .34449 .72931 L .37534 .73564 L p .707 .577 .707 r
F P
0 g
s
.7777 .54711 m .77308 .60199 L .74202 .59747 L p .707 .577 .707 r
F P
0 g
s
.74202 .59747 m .74664 .54259 L .7777 .54711 L p .707 .577 .707 r
F P
0 g
s
.30603 .62776 m .30093 .66389 L .32171 .67423 L p .707 .577 .707 r
F P
0 g
s
.31997 .70244 m .31735 .72049 L .34449 .72931 L p .707 .577 .707 r
F P
0 g
s
.71028 .59589 m .7149 .54101 L .74664 .54259 L p .707 .577 .707 r
F P
0 g
s
.7149 .54101 m .71028 .59589 L .68098 .5974 L p .707 .577 .707 r
F P
0 g
s
.68127 .61343 m .67617 .64956 L .65226 .65323 L p .707 .577 .707 r
F P
0 g
s
.81392 .69635 m .8113 .71439 L .79053 .70395 L p .707 .577 .707 r
F P
0 g
s
.79053 .70395 m .79315 .6859 L .81392 .69635 L p .707 .577 .707 r
F P
0 g
s
.29798 .53968 m .29336 .59455 L .30587 .60431 L p .707 .577 .707 r
F P
0 g
s
.74664 .54259 m .74202 .59747 L .71028 .59589 L p .707 .577 .707 r
F P
0 g
s
.46949 .65217 m .46439 .6883 L .48071 .68162 L p .707 .577 .707 r
F P
0 g
s
.48071 .68162 m .48581 .64549 L .46949 .65217 L p .707 .577 .707 r
F P
0 g
s
.43867 .7206 m .43605 .73864 L .45996 .73503 L p .707 .577 .707 r
F P
0 g
s
.45996 .73503 m .46257 .71698 L .43867 .7206 L p .707 .577 .707 r
F P
0 g
s
.49126 .55843 m .48663 .61331 L .49374 .60453 L p .707 .577 .707 r
F P
0 g
s
.49374 .60453 m .49836 .54965 L .49126 .55843 L p .707 .577 .707 r
F P
0 g
s
.64792 .68941 m .65054 .67136 L .67445 .66775 L p .707 .577 .707 r
F P
0 g
s
.80003 .63117 m .79493 .66729 L .76778 .65859 L p .707 .577 .707 r
F P
0 g
s
.76778 .65859 m .77288 .62246 L .80003 .63117 L p .707 .577 .707 r
F P
0 g
s
.31735 .72049 m .31997 .70244 L .2992 .692 L p .707 .577 .707 r
F P
0 g
s
.67617 .64956 m .68127 .61343 L .71044 .61314 L p .707 .577 .707 r
F P
0 g
s
.30093 .66389 m .30603 .62776 L .29365 .61679 L p .707 .577 .707 r
F P
0 g
s
.67445 .66775 m .67183 .68579 L .64792 .68941 L p .707 .577 .707 r
F P
0 g
s
.29336 .59455 m .29798 .53968 L .29513 .52993 L p .707 .577 .707 r
F P
0 g
s
.2992 .692 m .29658 .71004 L .31735 .72049 L p .707 .577 .707 r
F P
0 g
s
.77288 .62246 m .76778 .65859 L .7369 .65238 L p .707 .577 .707 r
F P
0 g
s
.7369 .65238 m .742 .61625 L .77288 .62246 L p .707 .577 .707 r
F P
0 g
s
.71044 .61314 m .70534 .64927 L .67617 .64956 L p .707 .577 .707 r
F P
0 g
s
.29365 .61679 m .28855 .65292 L .30093 .66389 L p .707 .577 .707 r
F P
0 g
s
.70534 .64927 m .71044 .61314 L .742 .61625 L p .707 .577 .707 r
F P
0 g
s
.79315 .6859 m .79053 .70395 L .76339 .69513 L p .707 .577 .707 r
F P
0 g
s
.76339 .69513 m .76601 .67708 L .79315 .6859 L p .707 .577 .707 r
F P
0 g
s
.742 .61625 m .7369 .65238 L .70534 .64927 L p .707 .577 .707 r
F P
0 g
s
.46257 .71698 m .45996 .73503 L .47627 .72836 L p .707 .577 .707 r
F P
0 g
s
.47627 .72836 m .47889 .71032 L .46257 .71698 L p .707 .577 .707 r
F P
0 g
s
.67183 .68579 m .67445 .66775 L .70361 .66754 L p .707 .577 .707 r
F P
0 g
s
.29658 .71004 m .2992 .692 L .28683 .68094 L p .707 .577 .707 r
F P
0 g
s
.29513 .52993 m .29051 .58481 L .29336 .59455 L p .707 .577 .707 r
F P
0 g
s
.48581 .64549 m .48071 .68162 L .48784 .67257 L p .707 .577 .707 r
F P
0 g
s
.48784 .67257 m .49294 .63644 L .48581 .64549 L p .707 .577 .707 r
F P
0 g
s
.70361 .66754 m .70099 .68558 L .67183 .68579 L p .707 .577 .707 r
F P
0 g
s
.49836 .54965 m .49374 .60453 L .49089 .59479 L p .707 .577 .707 r
F P
0 g
s
.49089 .59479 m .49551 .53991 L .49836 .54965 L p .707 .577 .707 r
F P
0 g
s
.28683 .68094 m .28421 .69899 L .29658 .71004 L p .707 .577 .707 r
F P
0 g
s
.28855 .65292 m .29365 .61679 L .29089 .60627 L p .707 .577 .707 r
F P
0 g
s
.76601 .67708 m .76339 .69513 L .73254 .6888 L p .707 .577 .707 r
F P
0 g
s
.73254 .6888 m .73516 .67075 L .76601 .67708 L p .707 .577 .707 r
F P
0 g
s
.70099 .68558 m .70361 .66754 L .73516 .67075 L p .707 .577 .707 r
F P
0 g
s
.29051 .58481 m .29513 .52993 L .30223 .52115 L p .707 .577 .707 r
F P
0 g
s
.73516 .67075 m .73254 .6888 L .70099 .68558 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29089 .60627 m .28579 .64239 L .28855 .65292 L p .707 .577 .707 r
F P
0 g
s
.47889 .71032 m .47627 .72836 L .48341 .7193 L p .707 .577 .707 r
F P
0 g
s
.48341 .7193 m .48603 .70125 L .47889 .71032 L p .707 .577 .707 r
F P
0 g
s
.28421 .69899 m .28683 .68094 L .28408 .67036 L p .707 .577 .707 r
F P
0 g
s
.30223 .52115 m .29761 .57603 L .29051 .58481 L p .707 .577 .707 r
F P
0 g
s
.49294 .63644 m .48784 .67257 L .48508 .66204 L p .707 .577 .707 r
F P
0 g
s
.48508 .66204 m .49018 .62592 L .49294 .63644 L p .707 .577 .707 r
F P
0 g
s
.28408 .67036 m .28146 .68841 L .28421 .69899 L p .707 .577 .707 r
F P
0 g
s
.49551 .53991 m .49089 .59479 L .47837 .58503 L p .707 .577 .707 r
F P
0 g
s
.47837 .58503 m .483 .53015 L .49551 .53991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28579 .64239 m .29089 .60627 L .29802 .59722 L p .707 .577 .707 r
F P
0 g
s
.29761 .57603 m .30223 .52115 L .31859 .5142 L p .707 .577 .707 r
F P
0 g
s
.29802 .59722 m .29292 .63335 L .28579 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48603 .70125 m .48341 .7193 L .48066 .70872 L p .707 .577 .707 r
F P
0 g
s
.48066 .70872 m .48328 .69067 L .48603 .70125 L p .707 .577 .707 r
F P
0 g
s
.28146 .68841 m .28408 .67036 L .29121 .6613 L p .707 .577 .707 r
F P
0 g
s
.31859 .5142 m .31396 .56908 L .29761 .57603 L p .707 .577 .707 r
F P
0 g
s
.49018 .62592 m .48508 .66204 L .47271 .65107 L p .707 .577 .707 r
F P
0 g
s
.47271 .65107 m .47781 .61495 L .49018 .62592 L p .707 .577 .707 r
F P
0 g
s
.483 .53015 m .47837 .58503 L .45742 .57622 L p .707 .577 .707 r
F P
0 g
s
.45742 .57622 m .46204 .52134 L .483 .53015 L p .707 .577 .707 r
F P
0 g
s
.29121 .6613 m .28859 .67934 L .28146 .68841 L p .707 .577 .707 r
F P
0 g
s
.29292 .63335 m .29802 .59722 L .31435 .59053 L p .707 .577 .707 r
F P
0 g
s
.31396 .56908 m .31859 .5142 L .34259 .50975 L p .707 .577 .707 r
F P
0 g
s
.31435 .59053 m .30925 .62666 L .29292 .63335 L p .707 .577 .707 r
F P
0 g
s
.48328 .69067 m .48066 .70872 L .46829 .69767 L p .707 .577 .707 r
F P
0 g
s
.46829 .69767 m .47091 .67962 L .48328 .69067 L p .707 .577 .707 r
F P
0 g
s
.46204 .52134 m .45742 .57622 L .43007 .56922 L p .707 .577 .707 r
F P
0 g
s
.43007 .56922 m .43469 .51434 L .46204 .52134 L p .707 .577 .707 r
F P
0 g
s
.28859 .67934 m .29121 .6613 L .30753 .65463 L p .707 .577 .707 r
F P
0 g
s
.34259 .50975 m .33796 .56463 L .31396 .56908 L p .707 .577 .707 r
F P
0 g
s
.47781 .61495 m .47271 .65107 L .45192 .64073 L p .707 .577 .707 r
F P
0 g
s
.45192 .64073 m .45702 .6046 L .47781 .61495 L p .707 .577 .707 r
F P
0 g
s
.33796 .56463 m .34259 .50975 L .37189 .50824 L p .707 .577 .707 r
F P
0 g
s
.30925 .62666 m .31435 .59053 L .33826 .58687 L p .707 .577 .707 r
F P
0 g
s
.30753 .65463 m .30491 .67268 L .28859 .67934 L p .707 .577 .707 r
F P
0 g
s
.43469 .51434 m .43007 .56922 L .39901 .5647 L p .707 .577 .707 r
F P
0 g
s
.39901 .5647 m .40363 .50982 L .43469 .51434 L p .707 .577 .707 r
F P
0 g
s
.36727 .56312 m .37189 .50824 L .40363 .50982 L p .707 .577 .707 r
F P
0 g
s
.37189 .50824 m .36727 .56312 L .33796 .56463 L p .707 .577 .707 r
F P
0 g
s
.33826 .58687 m .33316 .62299 L .30925 .62666 L p .707 .577 .707 r
F P
0 g
s
.40363 .50982 m .39901 .5647 L .36727 .56312 L p .707 .577 .707 r
F P
0 g
s
.47091 .67962 m .46829 .69767 L .44752 .68722 L p .707 .577 .707 r
F P
0 g
s
.44752 .68722 m .45014 .66917 L .47091 .67962 L p .707 .577 .707 r
F P
0 g
s
.45702 .6046 m .45192 .64073 L .42476 .63203 L p .707 .577 .707 r
F P
0 g
s
.42476 .63203 m .42986 .5959 L .45702 .6046 L p .707 .577 .707 r
F P
0 g
s
.30491 .67268 m .30753 .65463 L .33144 .65102 L p .707 .577 .707 r
F P
0 g
s
.33316 .62299 m .33826 .58687 L .36743 .58657 L p .707 .577 .707 r
F P
0 g
s
.33144 .65102 m .32882 .66906 L .30491 .67268 L p .707 .577 .707 r
F P
0 g
s
.42986 .5959 m .42476 .63203 L .39389 .62581 L p .707 .577 .707 r
F P
0 g
s
.39389 .62581 m .39899 .58969 L .42986 .5959 L p .707 .577 .707 r
F P
0 g
s
.36743 .58657 m .36233 .6227 L .33316 .62299 L p .707 .577 .707 r
F P
0 g
s
.36233 .6227 m .36743 .58657 L .39899 .58969 L p .707 .577 .707 r
F P
0 g
s
.39899 .58969 m .39389 .62581 L .36233 .6227 L p .707 .577 .707 r
F P
0 g
s
.45014 .66917 m .44752 .68722 L .42038 .6784 L p .707 .577 .707 r
F P
0 g
s
.42038 .6784 m .423 .66035 L .45014 .66917 L p .707 .577 .707 r
F P
0 g
s
.32882 .66906 m .33144 .65102 L .36059 .65081 L p .707 .577 .707 r
F P
0 g
s
.36059 .65081 m .35798 .66885 L .32882 .66906 L p .707 .577 .707 r
F P
0 g
s
.423 .66035 m .42038 .6784 L .38953 .67207 L p .707 .577 .707 r
F P
0 g
s
.38953 .67207 m .39214 .65402 L .423 .66035 L p .707 .577 .707 r
F P
0 g
s
.35798 .66885 m .36059 .65081 L .39214 .65402 L p .707 .577 .707 r
F P
0 g
s
.39214 .65402 m .38953 .67207 L .35798 .66885 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool9002;Ool007ioo`/0
00UJEPL008Aoo`00MGoo2@006eYF0`00PGoo001aOol40002FUH00`00FUIJEP0EFUH00`00FUIJEP0:
FUJ1Ool006eoo`@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo07ioo`00JGoo10002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0OWoo001UOol4000?FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1nOol0065oo`@001=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07ioo`00GWoo0`002UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Ogoo001KOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1mOol005Moo`@000AJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo07eoo`00E7oo0`002EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0OGoo001BOol200000eYF
001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1mOol0051oo`8000=JEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo07eoo`00CWoo0P001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00OWoo
001=Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OWoo001=Ool20007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1lOol004aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001m
Ool004aoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001mOol004eoo`9JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001mOol004eoo`9JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07]oo`00CGoo0eYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Ngoo001=Ool3FUH00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1kOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001lOol004eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00O7oo
001=Ool01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001=Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0NWoo001>Ool3FUH0
0`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1jOol004ioo`=JEP03001J
EUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007]oo`00CWoo0eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Ngoo001>Ool01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8007]oo`00CWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
07Uoo`00CWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Uo
o`00Cgoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Yoo`00Cgoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001jOol004moo`04001JEUYF0007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1hOol004moo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001iOol0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001i
Ool0051oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NGoo001@Ool01000FUIJ
EP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Mgoo001@Ool01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00N7oo001AOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP8007Qoo`00DGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Io
o`00DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00
DGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07Ioo`00DGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8007Moo`00DWoo00@005YFFUH000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04
001JEUYFFUH2001gOol0059oo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1eOol0059oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1e
Ool0059oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001fOol005=oo`04
001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00MWoo001COol01000FUIJEP001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0M7oo001COol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00MGoo001DOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8007Eoo`00E7oo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo07=oo`00E7oo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8007Aoo`00EGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2001dOol005Eoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1bOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1b
Ool005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1bOol0
05Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001cOol005Ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00Lgoo001FOol01000FUIJEP001UYF3P002EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol0
1P00FUIJEUYF001JEP@00003FUH005YF00IJEP03001JEUYF009JEPX000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo075oo`00EWoo00<005YFFUH0
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0LGoo001FOol300000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001bOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001bOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
071oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0L7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1`Ool005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80075oo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001]oo`T004eoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH2000DOol70004FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`0=Ool50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`0;Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000jOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`09Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000hOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P002Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00P00=7oo001BOol00`00FUH00004FUH01000FUIJEUYF6@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00DWoo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH010000UYF1@000eYF1P001UYF
00<005YFFUH00eYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`06Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool0059oo`04001JEP00
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70007FUH00`00FUH000030002FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00H0
05YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40009FUH00`00FUIJEP02FUH30004
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Moo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF009JEP03001J
EUYF0080009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20007Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH30003FUH20008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1goo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF
400000=JEP00FUH02eYF00<005YFFUH00UYF00<005YFFUH00eYF0P000eYF0P0025YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol01Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YFFUIJEP8002eoo`00DWoo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001eYF
00D005YFFUIJEP0000IJEP03001JEP00009JEP8000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo00Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool005=o
o`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0
00=JEP05001JEUYFFUH00005FUH01000FUIJEUYF100025YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Goo001COol30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool00`00FUH00003FUH00`00FUIJEP03FUHE0006FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003moo`P000aoo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJ
EP03001JEUYF009JEP<000UJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool0
0`00FUH00003FUH00`00FUH000030005FUH70004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JERioo`00=goo20000eYF00<005YFFUH00UYF2@000goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol00goo00<005YF00000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH^Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP8000YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00=oo`04001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF0P002UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000P001UYF00<005YFFUH01EYF00<005YF
FUH01UYF10001EYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8002ioo`00;Woo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH00eYF40000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF10002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0017oo00H005YFFUIJEP00FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0017oo00@005YFFUIJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00D000MJEP03001JEUYF00AJEP03001JEP00009JEP8002ioo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YF
FUIJEQL000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool01000FUH000000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH015YF00<005YF
FUH00`00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH00003FUH400000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00002eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol00Woo0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH00UYF
0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH005YF1@000UYF00D005YFFUIJEP0000IJEP03001JEUYF00AJEPD000=J
EP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`02Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH2000_Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP000002FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50007
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUH0000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEPD000UJEP<00003FUH0
05YF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEP0002moo`00;7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH0
0eYF00<005YF00000`001UYF00<005YFFUH015YF10002eYF0`001EYF00L005YFFUIJEP00FUH0000;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH00000031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1@0000=JEP00
FUH025YF00<005YFFUH02EYF00<005YFFUH00P000eYF00@005YFFUIJEP8000aJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo
000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH02EYF
0P000eYF0P0000=JEP00FUH00UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF0000<Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF600035YF00<005YFFUH0
1@000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP000000
0eYF1P000UYF0P000Woo1P000eYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YFFUH00eYF5@001UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH040000eYF00L005YF001JEP00FUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000005YF0`0015YF00<005YFFUH0
0UYF0P001Woo2@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00031oo`00:goo00<005YF000015YF00<005YF00000`001eYF00<005YF00000`000Woo1@0000=o
o`0000000P000UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF100015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00000035YF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP80009JEP<0009JEP03001JEUYF00=JEP8000ioo`T000EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002]oo`03001JEP00009JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00=JEPl000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000aJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00<000EJEP04001JEP00
000EOol400000eYF001JEP05FUH01000FUIJEUYF0P00;goo000[Ool00`00FUH000030005FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40005FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`001UYF00@005YFFUIJEP800003FUH005YF00]J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH@000DOol2
0006FUH01000FUIJEUYF0P00;goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001EYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00
3goo0P000eYF00L005YFFUIJEP00FUH0000_Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEPL000IJEP03001JEUYF00AJEPT0
00AJEP03001JEUYF00EJEP<0009JEP09001JEUYFFUH005YF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@000eoo`800003FUH005YF009JEP03001JEP0002moo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF200000=JEP00FUH01eYF00@005YF001JEP80009JEP03001JEUYF009JEP80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPH000IJEP03001JEUYF00<000=JEP80009JEP8000aJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;Ool20003FUH00`00FUH0000_Ool002]oo`80
00=JEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEPL000=JEP04001JEP000004FUH00`00FUIJ
EP04FUH300000eYF001JEP06FUH01000FUIJEUYF0`000eYF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000007Ool50002FUH2000`Ool002aoo`05001JEUYF001JEP050003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP060005FUH00`00FUIJEP04FUH00`00FUIJEP050004FUH0
0`00FUIJEP0500000eYF001JEP05FUH300000eYF001JEP04FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF1`000UYF00<005YFFUH01000<7oo000/Ool00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
0eYF00000003FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF300000=JEP00FUH01eYF0`001EYF
00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP04001JEUYFFUH70002FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00EJEP05001JEUYFFUH00006FUH0
1000FUIJEUYF50000eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEPH00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH01000FUIJEUYF0`00<7oo000/Ool20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40006FUH2
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF0`0000=JEP00FUH00UYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0009JEP80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00<000=J
EP03001JEP00031oo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00`000eYF00<005YF00000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH00P000eYF0P000eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF1`0025YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`0000AJEP00FUH0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP05FUH200000eYF0000000aOol002]oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEP00
00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00=JEP800003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYF001JEP00FUH000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000aOol002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP04001JEUYFFUH30003FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH20004FUH200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01@00FUIJEUYF00001UYF
1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP05001JEUYFFUH0000bOol0
02]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF008000=JEP03001JEUYF00AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00800003FUH0000000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00003FUH300000eYF001JEP05FUH00`00FUH00002FUH50002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0`Ool002Yoo`03001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP06FUH0
0`00FUIJEP040003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH20004FUH00`00FUIJEP0;
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00P001UYF00<005YF
FUH00`0017oo2@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP80035oo`00:Woo00<005YF
00000eYF100047oo2@0015YF00<005YFFUH01EYF0`001UYF00<005YFFUH015YF5`000eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000EJEP<0009JEP03001JEUYF009JEP8000Uooa8000Eoo`03001JEUYF0080035oo`00:Woo
00@005YF001JEPD001Eoo`<0009oo`H000IJEP03001JEUYF008000=JEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH00`00FUH000020004FUH20009
Ool5000COol4000aOol002Yoo`04001JEP000002FUH00`00FUIJEP02000BOol50007Ool20004FUH0
0`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006FUH01000FUIJEUYF0`0000AJEP00FUH000Uoo`D001=oo`@0035oo`00:Woo0P00
0eYF00<005YFFUH00eYF0P0047oo1@002Goo0`0000=JEP00FUH015YF1@001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP03001JEUYF00EJEPD000Uoo`<0019oo`80
0003FUH00000039oo`00:Woo0P000eYF00<005YFFUH00eYF00@005YF000000ioo`D000aoo`8000EJ
EP05001JEUYF001JEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF0P0000=JEP00FUH01eYF00@005YFFUIJEPT0015oo`@000=JEP80039oo`00:Woo0P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP<000aoo`<000moo`8000=JEP04001JEUYF0002FUH00`00FUIJEP07
0004FUH00`00FUIJEP05FUH01000FUIJEUYF1@002eYF00<005YFFUH02eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF009JEQ40009J
EP07001JEUYFFUH005YF0000<Woo000[Ool01@00FUIJEUYF00001EYF00<005YFFUH015YF1P006Woo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00EJEP03001JEP0000l000AJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00=JEPT000AJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00<goo000[Ool01@00FUIJEUYF000015YF5`0047oo1@000UYF00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJEP`000MJEP03001JEP00
00H0009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=7oo000/Ool00`00FUH000050003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHG0003FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF20002UYF00<005YFFUH01UYF00<005YFFUH01EYF
10001EYF00<005YFFUH00eYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000003Eoo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH04EYF10001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH015YF00@005YFFUIJEP800003Ool0000000L000AJEP03001J
EUYF00EJEP04001JEUYFFUH5000gOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH03EYF10002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF00EJEP04001JEUYFFUH2000:
Ool@000lOol002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH30006FUH01000FUIJEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP00009oo`8000IJEP04001JEUYFFUH2001FOol002Uoo`03001JEP0000=J
EP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH2
000:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005Ool20003FUH01`00FUIJEUYF001JEP0005Io
o`00:Goo00<005YF00000eYF1`001UYF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF0`000UYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04000:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20008Ool200000eYF
001JEP02FUH00`00FUH0001FOol002Uoo`04001JEP00FUH20007Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH30003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH400000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH2000;Ool20003FUH00`00FUH0001FOol002Uoo`04001JEP00000;Ool3
00000eYF001JEP07FUH00`00FUIJEP030003FUH40006FUH00`00FUIJEP02FUH20002FUH00`00Oomo
o`03FUH00`00FUIJEP0:FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`0000=JEP0000001goo1@000UYF0P00Egoo000YOol3000?Ool3
0006FUH00`00FUIJEP050002FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF0`000goo0eYF00<0
05YFFUH01eYF0`0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00@005YF0000009JEP04001JEUYFFUH70002FUH00`00FUIJEP04001GOol002Uoo`800003FUH0
0000011oo`@0009JEP03001JEUYF00D00003FUH005YF00MJEP<000EJEP04001JEP000002Ool01000
FUIJEP001UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF0P00Egoo000YOol00`00FUIJEP02
FUH00`00Oomoo`0AOol:00000eYF001JEP03FUH90003FUH01`00FUIJEUYF001oo`0000MJEP8000=J
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009J
EPD000AJEP03001JEUYF00IJEP<0009JEP04001JEUYFFUH3001GOol002Uoo`03001JEUYF009JEP<0
01Moo`X000Uoo`800003FUH005YF009JEP03001oo`0000EJEP8000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEP00008000EJEPH000MJEP03001JEUYF
00<000=JEP03001JEP0005Moo`00:Goo00<005YFFUH00UYF00<005YFFUH00P00:Woo0P000eYF0`00
0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00
00=JEP00FUH025YF00<005YFFUH00P0015YF00<005YFFUH00eYF0P000UYF00<005YF0000Egoo000Z
Ool01000FUIJEP001EYF0P00:Woo00H005YF001JEP00Ool2FUH01000FUIJEP001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF100015YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0P0000=JEP000000F7oo000[Ool00`00FUH00005FUH01000
FUH00000:Goo0P0000EJEP00OomJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJ
EP03001JEP00008005Qoo`00;7oo0P001EYF00@005YFFUIJEP<002Moo`05001JEP00Ool00004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0FFUH400000goo000000030006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH000000eYF00D005YFFUIJEP0005Uoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF10008Woo0`000Woo00<005YFFUH00UYF00<005YFFUH07UYF00<005YFFUH0
15YF10002Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00UYF00<007ooOol0Egoo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20000
0eYF00000003Ool5FUH00`00FUIJEP0@FUH00`00FUIJEP0:FUH00`00FUIJEP06000@Ool70004FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@000eYF0P00F7oo000`Ool200000eYF001JEP06FUH00`00FUIJ
EP04FUH7000@Ool50003FUH20003Ool30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH:0005FUH3000COolA0005Ool00`00FUIJEP02001HOol0039oo`<000EJEP03001JEUYF00MJ
EP03001JEUYF009JEQ0000=JEP04001JEUYFFUH20007Ool60004FUH00`00FUIJEP03FUH<0008Ool2
0006FUH01000FUH0000047oo1@004goo1000F7oo000eOol400000eYF001JEP08FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P003Goo2P005Goo00<005YFFUH015YF
00@005YFFUIJEP<000eoo`D001=oo`@005Qoo`00>Goo10001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`8000=JEP03001JEUYF00EJEPD000Qoo`D0015o
o`800003FUH0000005Uoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF0000039oo`800003FUH005YF00MJEP04001JEUYFFUH<000>Ool40003FUH2001IOol0
045oo`L000AJEP03001JEUYF00EJEP04001JEUYFFUH5000fOol30007FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHA0002FUH01`00FUIJEUYF001JEP0005Uoo`00B7oo4000?Woo0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Yoo`00V7oo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Yoo`00Vgoo10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P00Fgoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00GGoo
002SOol70004FUH00`00FUIJEP02FUH7001SOol00:Yoo`T006Yoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60099 .74931 m .59637 .69344 L .5653 .69418 L p .707 .577 .707 r
F P
0 g
s
.59637 .69344 m .60099 .74931 L .63273 .74616 L p .707 .577 .707 r
F P
0 g
s
.63273 .74616 m .6281 .69028 L .59637 .69344 L p .707 .577 .707 r
F P
0 g
s
.6281 .69028 m .63273 .74616 L .66203 .74089 L p .707 .577 .707 r
F P
0 g
s
.66203 .74089 m .65741 .68502 L .6281 .69028 L p .707 .577 .707 r
F P
0 g
s
.56993 .75005 m .5653 .69418 L .53796 .69242 L p .707 .577 .707 r
F P
0 g
s
.5653 .69418 m .56993 .75005 L .60099 .74931 L p .707 .577 .707 r
F P
0 g
s
.65741 .68502 m .66203 .74089 L .68603 .73403 L p .707 .577 .707 r
F P
0 g
s
.68603 .73403 m .68141 .67816 L .65741 .68502 L p .707 .577 .707 r
F P
0 g
s
.6061 .81152 m .601 .7743 L .57013 .77677 L p .707 .577 .707 r
F P
0 g
s
.601 .7743 m .6061 .81152 L .63767 .8068 L p .707 .577 .707 r
F P
0 g
s
.63767 .8068 m .63257 .76957 L .601 .7743 L p .707 .577 .707 r
F P
0 g
s
.53796 .69242 m .54258 .74829 L .56993 .75005 L p .707 .577 .707 r
F P
0 g
s
.63257 .76957 m .63767 .8068 L .66684 .80028 L p .707 .577 .707 r
F P
0 g
s
.66684 .80028 m .66174 .76306 L .63257 .76957 L p .707 .577 .707 r
F P
0 g
s
.54258 .74829 m .53796 .69242 L .517 .68835 L p .707 .577 .707 r
F P
0 g
s
.57523 .814 m .57013 .77677 L .54297 .77676 L p .707 .577 .707 r
F P
0 g
s
.57013 .77677 m .57523 .814 L .6061 .81152 L p .707 .577 .707 r
F P
0 g
s
.66174 .76306 m .66684 .80028 L .69075 .79262 L p .707 .577 .707 r
F P
0 g
s
.69075 .79262 m .68565 .7554 L .66174 .76306 L p .707 .577 .707 r
F P
0 g
s
.68141 .67816 m .68603 .73403 L .70239 .72624 L p .707 .577 .707 r
F P
0 g
s
.70239 .72624 m .69776 .67037 L .68141 .67816 L p .707 .577 .707 r
F P
0 g
s
.61047 .85871 m .60785 .84011 L .577 .8427 L p .707 .577 .707 r
F P
0 g
s
.60785 .84011 m .61047 .85871 L .64202 .85388 L p .707 .577 .707 r
F P
0 g
s
.64202 .85388 m .6394 .83527 L .60785 .84011 L p .707 .577 .707 r
F P
0 g
s
.54297 .77676 m .54808 .81398 L .57523 .814 L p .707 .577 .707 r
F P
0 g
s
.517 .68835 m .52162 .74422 L .54258 .74829 L p .707 .577 .707 r
F P
0 g
s
.6394 .83527 m .64202 .85388 L .67118 .84728 L p .707 .577 .707 r
F P
0 g
s
.67118 .84728 m .66856 .82868 L .6394 .83527 L p .707 .577 .707 r
F P
0 g
s
.577 .8427 m .57962 .86131 L .61047 .85871 L p .707 .577 .707 r
F P
0 g
s
.57962 .86131 m .577 .8427 L .54986 .8428 L p .707 .577 .707 r
F P
0 g
s
.54808 .81398 m .54297 .77676 L .52219 .77425 L p .707 .577 .707 r
F P
0 g
s
.52162 .74422 m .517 .68835 L .50449 .68235 L p .707 .577 .707 r
F P
0 g
s
.54986 .8428 m .55248 .86141 L .57962 .86131 L p .707 .577 .707 r
F P
0 g
s
.66856 .82868 m .67118 .84728 L .69508 .83957 L p .707 .577 .707 r
F P
0 g
s
.69508 .83957 m .69246 .82096 L .66856 .82868 L p .707 .577 .707 r
F P
0 g
s
.68565 .7554 m .69075 .79262 L .70707 .78456 L p .707 .577 .707 r
F P
0 g
s
.70707 .78456 m .70197 .74734 L .68565 .7554 L p .707 .577 .707 r
F P
0 g
s
.52219 .77425 m .52729 .81147 L .54808 .81398 L p .707 .577 .707 r
F P
0 g
s
.69776 .67037 m .70239 .72624 L .70949 .71829 L p .707 .577 .707 r
F P
0 g
s
.70949 .71829 m .70486 .66242 L .69776 .67037 L p .707 .577 .707 r
F P
0 g
s
.55248 .86141 m .54986 .8428 L .52909 .84041 L p .707 .577 .707 r
F P
0 g
s
.50449 .68235 m .50911 .73822 L .52162 .74422 L p .707 .577 .707 r
F P
0 g
s
.52909 .84041 m .53171 .85901 L .55248 .86141 L p .707 .577 .707 r
F P
0 g
s
.69246 .82096 m .69508 .83957 L .7114 .83149 L p .707 .577 .707 r
F P
0 g
s
.7114 .83149 m .70878 .81288 L .69246 .82096 L p .707 .577 .707 r
F P
0 g
s
.52729 .81147 m .52219 .77425 L .50981 .7695 L p .707 .577 .707 r
F P
0 g
s
.50911 .73822 m .50449 .68235 L .50164 .67502 L p .707 .577 .707 r
F P
0 g
s
.50164 .67502 m .50626 .73089 L .50911 .73822 L p .707 .577 .707 r
F P
0 g
s
.50626 .73089 m .50164 .67502 L .50874 .66707 L p .707 .577 .707 r
F P
0 g
s
.50874 .66707 m .51336 .72294 L .50626 .73089 L p .707 .577 .707 r
F P
0 g
s
.51336 .72294 m .50874 .66707 L .52509 .65929 L p .707 .577 .707 r
F P
0 g
s
.49038 .82544 m .58053 .34202 L .53725 .33141 L p .707 .577 .707 r
F P
0 g
s
.50981 .7695 m .51491 .80672 L .52729 .81147 L p .707 .577 .707 r
F P
0 g
s
.51491 .80672 m .50981 .7695 L .50705 .76297 L p .707 .577 .707 r
F P
0 g
s
.50705 .76297 m .51215 .80019 L .51491 .80672 L p .707 .577 .707 r
F P
0 g
s
.51215 .80019 m .50705 .76297 L .51419 .7553 L p .707 .577 .707 r
F P
0 g
s
.51419 .7553 m .51929 .79252 L .51215 .80019 L p .707 .577 .707 r
F P
0 g
s
.53171 .85901 m .52909 .84041 L .51672 .83574 L p .707 .577 .707 r
F P
0 g
s
.51672 .83574 m .51934 .85435 L .53171 .85901 L p .707 .577 .707 r
F P
0 g
s
.51934 .85435 m .51672 .83574 L .51397 .82926 L p .707 .577 .707 r
F P
0 g
s
.51397 .82926 m .51659 .84787 L .51934 .85435 L p .707 .577 .707 r
F P
0 g
s
.51659 .84787 m .51397 .82926 L .5211 .82161 L p .707 .577 .707 r
F P
0 g
s
.5211 .82161 m .52372 .84022 L .51659 .84787 L p .707 .577 .707 r
F P
0 g
s
.52509 .65929 m .52971 .71516 L .51336 .72294 L p .707 .577 .707 r
F P
0 g
s
.51929 .79252 m .51419 .7553 L .53051 .74724 L p .707 .577 .707 r
F P
0 g
s
.52971 .71516 m .52509 .65929 L .54831 .65265 L p .707 .577 .707 r
F P
0 g
s
.58053 .34202 m .53348 .59432 L p .5495 .65731 L .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .55177 .68476 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .5495 .65731 L p .56218 .68396 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .56218 .68396 L .56292 .68551 L .707 .577 .707 r
F
.53742 .81353 m .54004 .83214 L .52372 .84022 L p F P
0 g
s
.55442 .73958 m .55952 .7768 L .53561 .78446 L p .707 .577 .707 r
F P
0 g
s
.58302 .70303 m .58132 .68251 L p .61013 .644 L .707 .577 .707 r
F P
0 g
s
.62482 .34807 m .56218 .68396 L p .58132 .68251 L .707 .577 .707 r
F P
0 g
s
.59294 .66196 m .62482 .34807 L .58132 .68251 L .707 .577 .707 r
F
.60267 .64474 m .61013 .644 L p .58132 .68251 L F P
0 g
s
.61476 .69987 m .61013 .644 L .6412 .64327 L p .707 .577 .707 r
F P
0 g
s
.61013 .644 m .61476 .69987 L .58736 .7026 L p .707 .577 .707 r
F P
0 g
s
.58736 .7026 m .58302 .70303 L p .59982 .66647 L .707 .577 .707 r
F P
0 g
s
.59982 .66647 m .61013 .644 L .58736 .7026 L .707 .577 .707 r
F
.6412 .64327 m .64582 .69914 L .61476 .69987 L p F P
0 g
s
.62025 .76556 m .61515 .72834 L .64602 .72586 L p .707 .577 .707 r
F P
0 g
s
.58869 .77029 m .58359 .73306 L .61515 .72834 L p .707 .577 .707 r
F P
0 g
s
.61515 .72834 m .62025 .76556 L .58869 .77029 L p .707 .577 .707 r
F P
0 g
s
.56395 .82442 m .56133 .80582 L .59049 .79922 L p .707 .577 .707 r
F P
0 g
s
.59049 .79922 m .5931 .81783 L .56395 .82442 L p .707 .577 .707 r
F P
0 g
s
.5931 .81783 m .59049 .79922 L .62203 .79439 L p .707 .577 .707 r
F P
0 g
s
.62203 .79439 m .62465 .81299 L .5931 .81783 L p .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .60925 .82806 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.66578 .34898 m .61454 .62375 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.58359 .73306 m .58869 .77029 L .55952 .7768 L p .707 .577 .707 r
F P
0 g
s
.61454 .62375 m .57563 .83239 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .66578 .34898 L .62482 .34807 L p .707 .577 .707 r
F P
0 g
s
.58132 .68251 m .5784 .64716 L .60267 .64474 L p .707 .577 .707 r
F P
0 g
s
.59093 .68177 m .59294 .66196 L .58132 .68251 L .707 .577 .707 r
F
.5784 .64716 m .58302 .70303 L .57218 .70498 L p F P
0 g
s
.57218 .70498 m .55372 .7083 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56292 .68551 m .5784 .64716 L .57218 .70498 L .707 .577 .707 r
F
.62482 .34807 m .58053 .34202 L p .55074 .65993 L F P
0 g
s
.52372 .84022 m .5211 .82161 L .53742 .81353 L p .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .52971 .71516 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.54909 .65242 m .5495 .65731 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.5495 .65731 m .55372 .7083 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .56218 .68396 L .55074 .65993 L .707 .577 .707 r
F
.53561 .78446 m .53051 .74724 L .55442 .73958 L p F P
0 g
s
.54004 .83214 m .53742 .81353 L .56133 .80582 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .55968 .69736 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.55968 .69736 m .56218 .68396 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .62482 .34807 L p .55074 .65993 L .707 .577 .707 r
F P
0 g
s
.56133 .80582 m .56395 .82442 L .54004 .83214 L p .707 .577 .707 r
F P
0 g
s
.55952 .7768 m .55442 .73958 L .58359 .73306 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .57563 .83239 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55074 .65993 m .58053 .34202 L .5495 .65731 L .707 .577 .707 r
F
.54909 .65242 m .5784 .64716 L p .56292 .68551 L F P
0 g
s
.5495 .65731 m .54909 .65242 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .53467 .83149 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .55074 .65993 L .5495 .65731 L .707 .577 .707 r
F
.54831 .65265 m .54909 .65242 L p .54863 .65391 L F P
0 g
s
.52971 .71516 m .54831 .65265 L .54863 .65391 L .707 .577 .707 r
F
.53051 .74724 m .53561 .78446 L .51929 .79252 L p F P
0 g
s
.49038 .82544 m .53467 .83149 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.53348 .59432 m .49038 .82544 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.44709 .81483 m .53725 .33141 L .49921 .31729 L p .707 .577 .707 r
F P
0 g
s
.53725 .33141 m .44709 .81483 L .49038 .82544 L p .707 .577 .707 r
F P
0 g
s
.70197 .74734 m .70707 .78456 L .7142 .77689 L p .707 .577 .707 r
F P
0 g
s
.7142 .77689 m .7091 .73967 L .70197 .74734 L p .707 .577 .707 r
F P
0 g
s
.70486 .66242 m .70949 .71829 L .70664 .71096 L p .707 .577 .707 r
F P
0 g
s
.70664 .71096 m .70202 .65509 L .70486 .66242 L p .707 .577 .707 r
F P
0 g
s
.70878 .81288 m .7114 .83149 L .71854 .82384 L p .707 .577 .707 r
F P
0 g
s
.71854 .82384 m .71592 .80523 L .70878 .81288 L p .707 .577 .707 r
F P
0 g
s
.64582 .69914 m .6412 .64327 L .66855 .64502 L p .707 .577 .707 r
F P
0 g
s
.64602 .72586 m .65113 .76309 L .62025 .76556 L p .707 .577 .707 r
F P
0 g
s
.60925 .82806 m .69941 .34464 L .66578 .34898 L p .707 .577 .707 r
F P
0 g
s
.40906 .8007 m .49921 .31729 L .47014 .30102 L p .707 .577 .707 r
F P
0 g
s
.49921 .31729 m .40906 .8007 L .44709 .81483 L p .707 .577 .707 r
F P
0 g
s
.7091 .73967 m .7142 .77689 L .71144 .77036 L p .707 .577 .707 r
F P
0 g
s
.71144 .77036 m .70634 .73314 L .7091 .73967 L p .707 .577 .707 r
F P
0 g
s
.70202 .65509 m .70664 .71096 L .69413 .70497 L p .707 .577 .707 r
F P
0 g
s
.69413 .70497 m .6895 .6491 L .70202 .65509 L p .707 .577 .707 r
F P
0 g
s
.66855 .64502 m .67317 .70089 L .64582 .69914 L p .707 .577 .707 r
F P
0 g
s
.65289 .79179 m .65551 .8104 L .62465 .81299 L p .707 .577 .707 r
F P
0 g
s
.62465 .81299 m .62203 .79439 L .65289 .79179 L p .707 .577 .707 r
F P
0 g
s
.69941 .34464 m .60925 .82806 L .63225 .81891 L p .707 .577 .707 r
F P
0 g
s
.65113 .76309 m .64602 .72586 L .67318 .72588 L p .707 .577 .707 r
F P
0 g
s
.63225 .81891 m .7224 .3355 L .69941 .34464 L p .707 .577 .707 r
F P
0 g
s
.71592 .80523 m .71854 .82384 L .71578 .81736 L p .707 .577 .707 r
F P
0 g
s
.71578 .81736 m .71317 .79875 L .71592 .80523 L p .707 .577 .707 r
F P
0 g
s
.37998 .78444 m .47014 .30102 L .45288 .28422 L p .707 .577 .707 r
F P
0 g
s
.47014 .30102 m .37998 .78444 L .40906 .8007 L p .707 .577 .707 r
F P
0 g
s
.25798 .70845 m .25336 .65258 L .2223 .65332 L p .707 .577 .707 r
F P
0 g
s
.25336 .65258 m .25798 .70845 L .28972 .7053 L p .707 .577 .707 r
F P
0 g
s
.28972 .7053 m .2851 .64943 L .25336 .65258 L p .707 .577 .707 r
F P
0 g
s
.2851 .64943 m .28972 .7053 L .31902 .70003 L p .707 .577 .707 r
F P
0 g
s
.31902 .70003 m .3144 .64416 L .2851 .64943 L p .707 .577 .707 r
F P
0 g
s
.22692 .70919 m .2223 .65332 L .19495 .65156 L p .707 .577 .707 r
F P
0 g
s
.2223 .65332 m .22692 .70919 L .25798 .70845 L p .707 .577 .707 r
F P
0 g
s
.70634 .73314 m .71144 .77036 L .69907 .76561 L p .707 .577 .707 r
F P
0 g
s
.69907 .76561 m .69397 .72839 L .70634 .73314 L p .707 .577 .707 r
F P
0 g
s
.3144 .64416 m .31902 .70003 L .34303 .69317 L p .707 .577 .707 r
F P
0 g
s
.34303 .69317 m .3384 .6373 L .3144 .64416 L p .707 .577 .707 r
F P
0 g
s
.2631 .76445 m .258 .72723 L .22712 .72971 L p .707 .577 .707 r
F P
0 g
s
.258 .72723 m .2631 .76445 L .29466 .75973 L p .707 .577 .707 r
F P
0 g
s
.29466 .75973 m .28956 .72251 L .258 .72723 L p .707 .577 .707 r
F P
0 g
s
.6895 .6491 m .69413 .70497 L .67317 .70089 L p .707 .577 .707 r
F P
0 g
s
.67317 .70089 m .66855 .64502 L .6895 .6491 L p .707 .577 .707 r
F P
0 g
s
.28956 .72251 m .29466 .75973 L .32383 .75322 L p .707 .577 .707 r
F P
0 g
s
.32383 .75322 m .31873 .716 L .28956 .72251 L p .707 .577 .707 r
F P
0 g
s
.19495 .65156 m .19957 .70743 L .22692 .70919 L p .707 .577 .707 r
F P
0 g
s
.19957 .70743 m .19495 .65156 L .17399 .64749 L p .707 .577 .707 r
F P
0 g
s
.71317 .79875 m .71578 .81736 L .70342 .81269 L p .707 .577 .707 r
F P
0 g
s
.70342 .81269 m .7008 .79409 L .71317 .79875 L p .707 .577 .707 r
F P
0 g
s
.23222 .76693 m .22712 .72971 L .19997 .72969 L p .707 .577 .707 r
F P
0 g
s
.22712 .72971 m .23222 .76693 L .2631 .76445 L p .707 .577 .707 r
F P
0 g
s
.26746 .80181 m .26484 .7832 L .23399 .7858 L p .707 .577 .707 r
F P
0 g
s
.26484 .7832 m .26746 .80181 L .29901 .79698 L p .707 .577 .707 r
F P
0 g
s
.29901 .79698 m .29639 .77837 L .26484 .7832 L p .707 .577 .707 r
F P
0 g
s
.31873 .716 m .32383 .75322 L .34774 .74556 L p .707 .577 .707 r
F P
0 g
s
.34774 .74556 m .34264 .70833 L .31873 .716 L p .707 .577 .707 r
F P
0 g
s
.7224 .3355 m .63225 .81891 L .64236 .80585 L p .707 .577 .707 r
F P
0 g
s
.64236 .80585 m .70862 .45058 L p .7224 .3355 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .71914 .39414 L p .7203 .37334 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .7203 .37334 L .7224 .3355 L .707 .577 .707 r
F
.68528 .72194 m .68018 .68472 L .67333 .68389 L p F P
0 g
s
.64236 .80585 m .63861 .79015 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67714 .61456 L .64236 .80585 L .707 .577 .707 r
F
.71914 .39414 m .64236 .80585 L p .7085 .44207 L F P
0 g
s
.71914 .39414 m .73252 .32243 L .7299 .32582 L p .707 .577 .707 r
F P
0 g
s
.7299 .32582 m .7224 .3355 L p .71914 .39414 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .73252 .32243 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .66428 .65248 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .62135 .77334 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .65713 .63165 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.64984 .64959 m .65713 .63165 L .63861 .79015 L .707 .577 .707 r
F
.67752 .58151 m .66688 .63854 L p .65713 .63165 L F P
0 g
s
.66688 .63854 m .63861 .79015 L p .65713 .63165 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .64169 .59031 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .6542 .59631 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .66306 .61706 L .66169 .65274 L .707 .577 .707 r
F
.66306 .61706 m .6542 .59631 L .65846 .62838 L F
.66306 .61706 m .65846 .62838 L .66169 .65274 L F
.6734 .60004 m .67023 .59942 L p .66737 .62717 L F P
0 g
s
.67023 .59942 m .6542 .59631 L p .66306 .61706 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .67023 .59942 L .66306 .61706 L .707 .577 .707 r
F
.64984 .64959 m .65337 .629 L .65441 .62973 L F
.64169 .59031 m .64209 .5952 L p .65217 .62816 L F P
0 g
s
.63815 .57735 m .64209 .5952 L .62135 .77334 L .707 .577 .707 r
F
.64886 .62582 m .64636 .63922 L p .64209 .5952 L F P
0 g
s
.64636 .63922 m .62135 .77334 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64812 .65381 m .7115 .28992 L .64984 .64959 L .707 .577 .707 r
F
.63984 .67417 m .64636 .63922 L p .64812 .65381 L F P
0 g
s
.65217 .62816 m .64209 .5952 L .64886 .62582 L .707 .577 .707 r
F
.64636 .63922 m .7115 .28992 L p .64812 .65381 L F P
0 g
s
.64631 .64618 m .64436 .62264 L p .63884 .58298 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64209 .5952 L p .6402 .58807 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .6402 .58807 L .63884 .58298 L .707 .577 .707 r
F
.64209 .5952 m .64169 .59031 L .6416 .59007 L p F P
0 g
s
.7115 .28992 m .64886 .62582 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.6416 .59007 m .63884 .58298 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64209 .5952 m .64436 .62264 L p .64886 .62582 L .707 .577 .707 r
F P
0 g
s
.62135 .77334 m .59228 .75708 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .67752 .58151 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.64631 .64618 m .65883 .65218 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64631 .64618 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.7115 .28992 m .72876 .30673 L p .65441 .62973 L .707 .577 .707 r
F P
0 g
s
.65337 .629 m .7115 .28992 L .65441 .62973 L .707 .577 .707 r
F
.62135 .77334 m .63984 .67417 L p .64984 .64959 L F P
0 g
s
.65883 .65218 m .65713 .63165 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65883 .65218 m .66169 .65274 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .65883 .65218 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .66449 .71944 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64702 .67746 m .64955 .69594 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64955 .69594 m .65212 .71468 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67752 .58151 L .7085 .44207 L .707 .577 .707 r
F
.66428 .65248 m .67752 .58151 L p .6691 .63825 L F P
0 g
s
.67752 .58151 m .72876 .30673 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .7085 .44207 L .67714 .61456 L .707 .577 .707 r
F
.66169 .65274 m .67978 .65625 L p .66737 .62717 L F P
0 g
s
.66449 .71944 m .65939 .68221 L .6548 .68045 L p .707 .577 .707 r
F P
0 g
s
.6548 .68045 m .64702 .67746 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.66449 .71944 m .6548 .68045 L .65186 .6891 L .707 .577 .707 r
F
.73252 .32243 m .71914 .39414 L p .7085 .44207 L F P
0 g
s
.67516 .60038 m .6734 .60004 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.6784 .65302 m .6734 .60004 L .66737 .62717 L .707 .577 .707 r
F
.67333 .68389 m .65939 .68221 L p .67091 .69989 L F P
0 g
s
.68528 .72194 m .67333 .68389 L .67091 .69989 L .707 .577 .707 r
F
.67978 .65625 m .67913 .64838 L p .6784 .65302 L F P
0 g
s
.67913 .64838 m .67516 .60038 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.29639 .77837 m .29901 .79698 L .32817 .79038 L p .707 .577 .707 r
F P
0 g
s
.32817 .79038 m .32555 .77177 L .29639 .77837 L p .707 .577 .707 r
F P
0 g
s
.3384 .6373 m .34303 .69317 L .35938 .68538 L p .707 .577 .707 r
F P
0 g
s
.35938 .68538 m .35475 .62951 L .3384 .6373 L p .707 .577 .707 r
F P
0 g
s
.36839 .77459 m .36577 .75598 L .34946 .76406 L p .707 .577 .707 r
F P
0 g
s
.35896 .70027 m .36406 .7375 L .37119 .72982 L p .707 .577 .707 r
F P
0 g
s
.37119 .72982 m .36609 .6926 L .35896 .70027 L p .707 .577 .707 r
F P
0 g
s
.36609 .6926 m .37119 .72982 L .36844 .72329 L p .707 .577 .707 r
F P
0 g
s
.36577 .75598 m .36839 .77459 L .37553 .76693 L p .707 .577 .707 r
F P
0 g
s
.37553 .76693 m .37291 .74833 L .36577 .75598 L p .707 .577 .707 r
F P
0 g
s
.37016 .74185 m .37278 .76046 L .36041 .75579 L p .707 .577 .707 r
F P
0 g
s
.34264 .70833 m .34774 .74556 L .36406 .7375 L p .707 .577 .707 r
F P
0 g
s
.36041 .75579 m .35779 .73718 L .37016 .74185 L p .707 .577 .707 r
F P
0 g
s
.36273 .76764 m .45288 .28422 L .44913 .26852 L p .707 .577 .707 r
F P
0 g
s
.37291 .74833 m .37553 .76693 L .37278 .76046 L p .707 .577 .707 r
F P
0 g
s
.37278 .76046 m .37016 .74185 L .37291 .74833 L p .707 .577 .707 r
F P
0 g
s
.45288 .28422 m .36273 .76764 L .37998 .78444 L p .707 .577 .707 r
F P
0 g
s
.19997 .72969 m .20507 .76691 L .23222 .76693 L p .707 .577 .707 r
F P
0 g
s
.23399 .7858 m .23661 .80441 L .26746 .80181 L p .707 .577 .707 r
F P
0 g
s
.17399 .64749 m .17861 .70336 L .19957 .70743 L p .707 .577 .707 r
F P
0 g
s
.69397 .72839 m .69907 .76561 L .67828 .7631 L p .707 .577 .707 r
F P
0 g
s
.67828 .7631 m .67318 .72588 L .69397 .72839 L p .707 .577 .707 r
F P
0 g
s
.23661 .80441 m .23399 .7858 L .20685 .7859 L p .707 .577 .707 r
F P
0 g
s
.20507 .76691 m .19997 .72969 L .17918 .72718 L p .707 .577 .707 r
F P
0 g
s
.20685 .7859 m .20947 .80451 L .23661 .80441 L p .707 .577 .707 r
F P
0 g
s
.32555 .77177 m .32817 .79038 L .35207 .78267 L p .707 .577 .707 r
F P
0 g
s
.35207 .78267 m .34946 .76406 L .32555 .77177 L p .707 .577 .707 r
F P
0 g
s
.17861 .70336 m .17399 .64749 L .16148 .64149 L p .707 .577 .707 r
F P
0 g
s
.36406 .7375 m .35896 .70027 L .34264 .70833 L p .707 .577 .707 r
F P
0 g
s
.17918 .72718 m .18428 .76441 L .20507 .76691 L p .707 .577 .707 r
F P
0 g
s
.7008 .79409 m .70342 .81269 L .68265 .8103 L p .707 .577 .707 r
F P
0 g
s
.68265 .8103 m .68003 .79169 L .7008 .79409 L p .707 .577 .707 r
F P
0 g
s
.20947 .80451 m .20685 .7859 L .18608 .7835 L p .707 .577 .707 r
F P
0 g
s
.35475 .62951 m .35938 .68538 L .36648 .67744 L p .707 .577 .707 r
F P
0 g
s
.36648 .67744 m .36185 .62156 L .35475 .62951 L p .707 .577 .707 r
F P
0 g
s
.18608 .7835 m .1887 .80211 L .20947 .80451 L p .707 .577 .707 r
F P
0 g
s
.16148 .64149 m .1661 .69736 L .17861 .70336 L p .707 .577 .707 r
F P
0 g
s
.67318 .72588 m .67828 .7631 L .65113 .76309 L p .707 .577 .707 r
F P
0 g
s
.34946 .76406 m .35207 .78267 L .36839 .77459 L p .707 .577 .707 r
F P
0 g
s
.18428 .76441 m .17918 .72718 L .1668 .72243 L p .707 .577 .707 r
F P
0 g
s
.1668 .72243 m .1719 .75966 L .18428 .76441 L p .707 .577 .707 r
F P
0 g
s
.1661 .69736 m .16148 .64149 L .15863 .63416 L p .707 .577 .707 r
F P
0 g
s
.36844 .72329 m .36334 .68607 L .36609 .6926 L p .707 .577 .707 r
F P
0 g
s
.36334 .68607 m .36844 .72329 L .35606 .71854 L p .707 .577 .707 r
F P
0 g
s
.35779 .73718 m .36041 .75579 L .33964 .75339 L p .707 .577 .707 r
F P
0 g
s
.44913 .26852 m .35897 .75194 L .36273 .76764 L p .707 .577 .707 r
F P
0 g
s
.35897 .75194 m .44913 .26852 L .45924 .25545 L p .707 .577 .707 r
F P
0 g
s
.68003 .79169 m .68265 .8103 L .65551 .8104 L p .707 .577 .707 r
F P
0 g
s
.65551 .8104 m .65289 .79179 L .68003 .79169 L p .707 .577 .707 r
F P
0 g
s
.1887 .80211 m .18608 .7835 L .17371 .77884 L p .707 .577 .707 r
F P
0 g
s
.17371 .77884 m .17633 .79745 L .1887 .80211 L p .707 .577 .707 r
F P
0 g
s
.15863 .63416 m .16325 .69003 L .1661 .69736 L p .707 .577 .707 r
F P
0 g
s
.36185 .62156 m .36648 .67744 L .36363 .67011 L p .707 .577 .707 r
F P
0 g
s
.36363 .67011 m .35901 .61423 L .36185 .62156 L p .707 .577 .707 r
F P
0 g
s
.1719 .75966 m .1668 .72243 L .16405 .7159 L p .707 .577 .707 r
F P
0 g
s
.16405 .7159 m .16915 .75312 L .1719 .75966 L p .707 .577 .707 r
F P
0 g
s
.16325 .69003 m .15863 .63416 L .16573 .62621 L p .707 .577 .707 r
F P
0 g
s
.17633 .79745 m .17371 .77884 L .17096 .77236 L p .707 .577 .707 r
F P
0 g
s
.17096 .77236 m .17358 .79097 L .17633 .79745 L p .707 .577 .707 r
F P
0 g
s
.36908 .73887 m .45924 .25545 L .48223 .24631 L p .707 .577 .707 r
F P
0 g
s
.45924 .25545 m .36908 .73887 L .35897 .75194 L p .707 .577 .707 r
F P
0 g
s
.16573 .62621 m .17035 .68208 L .16325 .69003 L p .707 .577 .707 r
F P
0 g
s
.35901 .61423 m .36363 .67011 L .35112 .66411 L p .707 .577 .707 r
F P
0 g
s
.35112 .66411 m .34649 .60824 L .35901 .61423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16915 .75312 m .16405 .7159 L .17118 .70823 L p .707 .577 .707 r
F P
0 g
s
.17118 .70823 m .17628 .74545 L .16915 .75312 L p .707 .577 .707 r
F P
0 g
s
.17035 .68208 m .16573 .62621 L .18208 .61843 L p .707 .577 .707 r
F P
0 g
s
.35606 .71854 m .35096 .68132 L .36334 .68607 L p .707 .577 .707 r
F P
0 g
s
.17358 .79097 m .17096 .77236 L .17809 .76471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17809 .76471 m .18071 .78332 L .17358 .79097 L p .707 .577 .707 r
F P
0 g
s
.34649 .60824 m .35112 .66411 L .33016 .66003 L p .707 .577 .707 r
F P
0 g
s
.33016 .66003 m .32554 .60416 L .34649 .60824 L p .707 .577 .707 r
F P
0 g
s
.18208 .61843 m .1867 .6743 L .17035 .68208 L p .707 .577 .707 r
F P
0 g
s
.59228 .75708 m .68243 .27366 L .7115 .28992 L p .707 .577 .707 r
F P
0 g
s
.48223 .24631 m .39208 .72973 L .36908 .73887 L p .707 .577 .707 r
F P
0 g
s
.39208 .72973 m .48223 .24631 L .51586 .24197 L p .707 .577 .707 r
F P
0 g
s
.17628 .74545 m .17118 .70823 L .1875 .70017 L p .707 .577 .707 r
F P
0 g
s
.1867 .6743 m .18208 .61843 L .20608 .61157 L p .707 .577 .707 r
F P
0 g
s
.1875 .70017 m .1926 .73739 L .17628 .74545 L p .707 .577 .707 r
F P
0 g
s
.35096 .68132 m .35606 .71854 L .33527 .71604 L p .707 .577 .707 r
F P
0 g
s
.33527 .71604 m .33017 .67881 L .35096 .68132 L p .707 .577 .707 r
F P
0 g
s
.18071 .78332 m .17809 .76471 L .19441 .75663 L p .707 .577 .707 r
F P
0 g
s
.32554 .60416 m .33016 .66003 L .30281 .65828 L p .707 .577 .707 r
F P
0 g
s
.30281 .65828 m .29819 .60241 L .32554 .60416 L p .707 .577 .707 r
F P
0 g
s
.19441 .75663 m .19703 .77524 L .18071 .78332 L p .707 .577 .707 r
F P
0 g
s
.20608 .61157 m .21071 .66744 L .1867 .6743 L p .707 .577 .707 r
F P
0 g
s
.33964 .75339 m .33702 .73479 L .35779 .73718 L p .707 .577 .707 r
F P
0 g
s
.21071 .66744 m .20608 .61157 L .23539 .6063 L p .707 .577 .707 r
F P
0 g
s
.1926 .73739 m .1875 .70017 L .21141 .69251 L p .707 .577 .707 r
F P
0 g
s
.68243 .27366 m .59228 .75708 L .55424 .74296 L p .707 .577 .707 r
F P
0 g
s
.55424 .74296 m .64439 .25954 L .68243 .27366 L p .707 .577 .707 r
F P
0 g
s
.4257 .72539 m .51586 .24197 L .55682 .24288 L p .707 .577 .707 r
F P
0 g
s
.51586 .24197 m .4257 .72539 L .39208 .72973 L p .707 .577 .707 r
F P
0 g
s
.29819 .60241 m .30281 .65828 L .27175 .65901 L p .707 .577 .707 r
F P
0 g
s
.27175 .65901 m .26713 .60314 L .29819 .60241 L p .707 .577 .707 r
F P
0 g
s
.33017 .67881 m .33527 .71604 L .30812 .71602 L p .707 .577 .707 r
F P
0 g
s
.30812 .71602 m .30302 .6788 L .33017 .67881 L p .707 .577 .707 r
F P
0 g
s
.21141 .69251 m .21651 .72973 L .1926 .73739 L p .707 .577 .707 r
F P
0 g
s
.24001 .66217 m .23539 .6063 L .26713 .60314 L p .707 .577 .707 r
F P
0 g
s
.23539 .6063 m .24001 .66217 L .21071 .66744 L p .707 .577 .707 r
F P
0 g
s
.19703 .77524 m .19441 .75663 L .21832 .74891 L p .707 .577 .707 r
F P
0 g
s
.26713 .60314 m .27175 .65901 L .24001 .66217 L p .707 .577 .707 r
F P
0 g
s
.7382 .65727 m .73357 .6014 L .70251 .60214 L p .707 .577 .707 r
F P
0 g
s
.73357 .6014 m .7382 .65727 L .76993 .65412 L p .707 .577 .707 r
F P
0 g
s
.76993 .65412 m .76531 .59825 L .73357 .6014 L p .707 .577 .707 r
F P
0 g
s
.21832 .74891 m .22094 .76752 L .19703 .77524 L p .707 .577 .707 r
F P
0 g
s
.76531 .59825 m .76993 .65412 L .79924 .64885 L p .707 .577 .707 r
F P
0 g
s
.79924 .64885 m .79461 .59298 L .76531 .59825 L p .707 .577 .707 r
F P
0 g
s
.21651 .72973 m .21141 .69251 L .24058 .686 L p .707 .577 .707 r
F P
0 g
s
.64439 .25954 m .55424 .74296 L .51095 .73235 L p .707 .577 .707 r
F P
0 g
s
.51095 .73235 m .60111 .24893 L .64439 .25954 L p .707 .577 .707 r
F P
0 g
s
.33702 .73479 m .33964 .75339 L .3125 .7535 L p .707 .577 .707 r
F P
0 g
s
.3125 .7535 m .30988 .73489 L .33702 .73479 L p .707 .577 .707 r
F P
0 g
s
.46666 .7263 m .55682 .24288 L .60111 .24893 L p .707 .577 .707 r
F P
0 g
s
.55682 .24288 m .46666 .7263 L .4257 .72539 L p .707 .577 .707 r
F P
0 g
s
.70713 .65801 m .70251 .60214 L .67516 .60038 L p .707 .577 .707 r
F P
0 g
s
.70251 .60214 m .70713 .65801 L .7382 .65727 L p .707 .577 .707 r
F P
0 g
s
.30302 .6788 m .30812 .71602 L .27724 .7185 L p .707 .577 .707 r
F P
0 g
s
.27724 .7185 m .27214 .68127 L .30302 .6788 L p .707 .577 .707 r
F P
0 g
s
.60111 .24893 m .51095 .73235 L .46666 .7263 L p .707 .577 .707 r
F P
0 g
s
.24058 .686 m .24568 .72322 L .21651 .72973 L p .707 .577 .707 r
F P
0 g
s
.79461 .59298 m .79924 .64885 L .82324 .64199 L p .707 .577 .707 r
F P
0 g
s
.82324 .64199 m .81862 .58612 L .79461 .59298 L p .707 .577 .707 r
F P
0 g
s
.24568 .72322 m .24058 .686 L .27214 .68127 L p .707 .577 .707 r
F P
0 g
s
.22094 .76752 m .21832 .74891 L .24748 .74232 L p .707 .577 .707 r
F P
0 g
s
.27214 .68127 m .27724 .7185 L .24568 .72322 L p .707 .577 .707 r
F P
0 g
s
.74331 .71948 m .73821 .68226 L .70734 .68474 L p .707 .577 .707 r
F P
0 g
s
.73821 .68226 m .74331 .71948 L .77487 .71476 L p .707 .577 .707 r
F P
0 g
s
.77487 .71476 m .76977 .67754 L .73821 .68226 L p .707 .577 .707 r
F P
0 g
s
.67516 .60038 m .67978 .65625 L .70713 .65801 L p .707 .577 .707 r
F P
0 g
s
.24748 .74232 m .25009 .76092 L .22094 .76752 L p .707 .577 .707 r
F P
0 g
s
.76977 .67754 m .77487 .71476 L .80404 .70825 L p .707 .577 .707 r
F P
0 g
s
.80404 .70825 m .79894 .67102 L .76977 .67754 L p .707 .577 .707 r
F P
0 g
s
.30988 .73489 m .3125 .7535 L .28164 .75609 L p .707 .577 .707 r
F P
0 g
s
.28164 .75609 m .27903 .73748 L .30988 .73489 L p .707 .577 .707 r
F P
0 g
s
.71244 .72196 m .70734 .68474 L .68018 .68472 L p .707 .577 .707 r
F P
0 g
s
.70734 .68474 m .71244 .72196 L .74331 .71948 L p .707 .577 .707 r
F P
0 g
s
.25009 .76092 m .24748 .74232 L .27903 .73748 L p .707 .577 .707 r
F P
0 g
s
.27903 .73748 m .28164 .75609 L .25009 .76092 L p .707 .577 .707 r
F P
0 g
s
.79894 .67102 m .80404 .70825 L .82796 .70059 L p .707 .577 .707 r
F P
0 g
s
.82796 .70059 m .82285 .66336 L .79894 .67102 L p .707 .577 .707 r
F P
0 g
s
.81862 .58612 m .82324 .64199 L .83959 .6342 L p .707 .577 .707 r
F P
0 g
s
.83959 .6342 m .83497 .57833 L .81862 .58612 L p .707 .577 .707 r
F P
0 g
s
.74768 .76668 m .74506 .74807 L .7142 .75066 L p .707 .577 .707 r
F P
0 g
s
.74506 .74807 m .74768 .76668 L .77923 .76184 L p .707 .577 .707 r
F P
0 g
s
.77923 .76184 m .77661 .74324 L .74506 .74807 L p .707 .577 .707 r
F P
0 g
s
.68018 .68472 m .68528 .72194 L .71244 .72196 L p .707 .577 .707 r
F P
0 g
s
.77661 .74324 m .77923 .76184 L .80838 .75525 L p .707 .577 .707 r
F P
0 g
s
.80838 .75525 m .80576 .73664 L .77661 .74324 L p .707 .577 .707 r
F P
0 g
s
.7142 .75066 m .71682 .76927 L .74768 .76668 L p .707 .577 .707 r
F P
0 g
s
.71682 .76927 m .7142 .75066 L .68706 .75077 L p .707 .577 .707 r
F P
0 g
s
.68706 .75077 m .68968 .76937 L .71682 .76927 L p .707 .577 .707 r
F P
0 g
s
.80576 .73664 m .80838 .75525 L .83229 .74753 L p .707 .577 .707 r
F P
0 g
s
.83229 .74753 m .82967 .72892 L .80576 .73664 L p .707 .577 .707 r
F P
0 g
s
.82285 .66336 m .82796 .70059 L .84428 .69252 L p .707 .577 .707 r
F P
0 g
s
.84428 .69252 m .83918 .6553 L .82285 .66336 L p .707 .577 .707 r
F P
0 g
s
.65939 .68221 m .66449 .71944 L .68528 .72194 L p .707 .577 .707 r
F P
0 g
s
.83497 .57833 m .83959 .6342 L .84669 .62626 L p .707 .577 .707 r
F P
0 g
s
.84669 .62626 m .84207 .57039 L .83497 .57833 L p .707 .577 .707 r
F P
0 g
s
.68968 .76937 m .68706 .75077 L .66629 .74837 L p .707 .577 .707 r
F P
0 g
s
.66629 .74837 m .66891 .76698 L .68968 .76937 L p .707 .577 .707 r
F P
0 g
s
.82967 .72892 m .83229 .74753 L .84861 .73945 L p .707 .577 .707 r
F P
0 g
s
.84861 .73945 m .84599 .72084 L .82967 .72892 L p .707 .577 .707 r
F P
0 g
s
.83918 .6553 m .84428 .69252 L .85141 .68485 L p .707 .577 .707 r
F P
0 g
s
.85141 .68485 m .84631 .64763 L .83918 .6553 L p .707 .577 .707 r
F P
0 g
s
.66891 .76698 m .66629 .74837 L .65393 .7437 L p .707 .577 .707 r
F P
0 g
s
.65393 .7437 m .65654 .76231 L .66891 .76698 L p .707 .577 .707 r
F P
0 g
s
.63884 .58298 m .64347 .63885 L .64631 .64618 L p .707 .577 .707 r
F P
0 g
s
.84207 .57039 m .84669 .62626 L .84385 .61893 L p .707 .577 .707 r
F P
0 g
s
.84385 .61893 m .83922 .56305 L .84207 .57039 L p .707 .577 .707 r
F P
0 g
s
.84599 .72084 m .84861 .73945 L .85574 .7318 L p .707 .577 .707 r
F P
0 g
s
.85574 .7318 m .85312 .71319 L .84599 .72084 L p .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .64702 .67746 L .64426 .67093 L p .707 .577 .707 r
F P
0 g
s
.64426 .67093 m .64936 .70815 L .65212 .71468 L p .707 .577 .707 r
F P
0 g
s
.64347 .63885 m .63884 .58298 L .64594 .57503 L p .707 .577 .707 r
F P
0 g
s
.84631 .64763 m .85141 .68485 L .84865 .67832 L p .707 .577 .707 r
F P
0 g
s
.84865 .67832 m .84355 .6411 L .84631 .64763 L p .707 .577 .707 r
F P
0 g
s
.65654 .76231 m .65393 .7437 L .65117 .73723 L p .707 .577 .707 r
F P
0 g
s
.65117 .73723 m .65379 .75583 L .65654 .76231 L p .707 .577 .707 r
F P
0 g
s
.64594 .57503 m .65057 .6309 L .64347 .63885 L p .707 .577 .707 r
F P
0 g
s
.83922 .56305 m .84385 .61893 L .83133 .61293 L p .707 .577 .707 r
F P
0 g
s
.83133 .61293 m .82671 .55706 L .83922 .56305 L p .707 .577 .707 r
F P
0 g
s
.85312 .71319 m .85574 .7318 L .85299 .72532 L p .707 .577 .707 r
F P
0 g
s
.85299 .72532 m .85037 .70671 L .85312 .71319 L p .707 .577 .707 r
F P
0 g
s
.64936 .70815 m .64426 .67093 L .65139 .66326 L p .707 .577 .707 r
F P
0 g
s
.39519 .61641 m .39056 .56054 L .3595 .56128 L p .707 .577 .707 r
F P
0 g
s
.39056 .56054 m .39519 .61641 L .42692 .61326 L p .707 .577 .707 r
F P
0 g
s
.42692 .61326 m .4223 .55739 L .39056 .56054 L p .707 .577 .707 r
F P
0 g
s
.4223 .55739 m .42692 .61326 L .45623 .60799 L p .707 .577 .707 r
F P
0 g
s
.45623 .60799 m .4516 .55212 L .4223 .55739 L p .707 .577 .707 r
F P
0 g
s
.65057 .6309 m .64594 .57503 L .6623 .56725 L p .707 .577 .707 r
F P
0 g
s
.65139 .66326 m .65649 .70048 L .64936 .70815 L p .707 .577 .707 r
F P
0 g
s
.36412 .61715 m .3595 .56128 L .33215 .55952 L p .707 .577 .707 r
F P
0 g
s
.3595 .56128 m .36412 .61715 L .39519 .61641 L p .707 .577 .707 r
F P
0 g
s
.84355 .6411 m .84865 .67832 L .83627 .67357 L p .707 .577 .707 r
F P
0 g
s
.83627 .67357 m .83117 .63635 L .84355 .6411 L p .707 .577 .707 r
F P
0 g
s
.4516 .55212 m .45623 .60799 L .48023 .60113 L p .707 .577 .707 r
F P
0 g
s
.48023 .60113 m .47561 .54526 L .4516 .55212 L p .707 .577 .707 r
F P
0 g
s
.65379 .75583 m .65117 .73723 L .65831 .72957 L p .707 .577 .707 r
F P
0 g
s
.65831 .72957 m .66093 .74818 L .65379 .75583 L p .707 .577 .707 r
F P
0 g
s
.4003 .67242 m .3952 .63519 L .36433 .63767 L p .707 .577 .707 r
F P
0 g
s
.3952 .63519 m .4003 .67242 L .43186 .66769 L p .707 .577 .707 r
F P
0 g
s
.43186 .66769 m .42676 .63047 L .3952 .63519 L p .707 .577 .707 r
F P
0 g
s
.82671 .55706 m .83133 .61293 L .81037 .60885 L p .707 .577 .707 r
F P
0 g
s
.81037 .60885 m .80575 .55298 L .82671 .55706 L p .707 .577 .707 r
F P
0 g
s
.6623 .56725 m .66692 .62312 L .65057 .6309 L p .707 .577 .707 r
F P
0 g
s
.42676 .63047 m .43186 .66769 L .46103 .66118 L p .707 .577 .707 r
F P
0 g
s
.46103 .66118 m .45593 .62396 L .42676 .63047 L p .707 .577 .707 r
F P
0 g
s
.33215 .55952 m .33677 .61539 L .36412 .61715 L p .707 .577 .707 r
F P
0 g
s
.33677 .61539 m .33215 .55952 L .31119 .55545 L p .707 .577 .707 r
F P
0 g
s
.85037 .70671 m .85299 .72532 L .84062 .72066 L p .707 .577 .707 r
F P
0 g
s
.84062 .72066 m .83801 .70205 L .85037 .70671 L p .707 .577 .707 r
F P
0 g
s
.36943 .67489 m .36433 .63767 L .33717 .63765 L p .707 .577 .707 r
F P
0 g
s
.36433 .63767 m .36943 .67489 L .4003 .67242 L p .707 .577 .707 r
F P
0 g
s
.65649 .70048 m .65139 .66326 L .66771 .6552 L p .707 .577 .707 r
F P
0 g
s
.40467 .70977 m .40205 .69117 L .37119 .69376 L p .707 .577 .707 r
F P
0 g
s
.40205 .69117 m .40467 .70977 L .43622 .70494 L p .707 .577 .707 r
F P
0 g
s
.43622 .70494 m .4336 .68633 L .40205 .69117 L p .707 .577 .707 r
F P
0 g
s
.45593 .62396 m .46103 .66118 L .48495 .65352 L p .707 .577 .707 r
F P
0 g
s
.48495 .65352 m .47985 .6163 L .45593 .62396 L p .707 .577 .707 r
F P
0 g
s
.66692 .62312 m .6623 .56725 L .6863 .56039 L p .707 .577 .707 r
F P
0 g
s
.4336 .68633 m .43622 .70494 L .46537 .69834 L p .707 .577 .707 r
F P
0 g
s
.46537 .69834 m .46275 .67974 L .4336 .68633 L p .707 .577 .707 r
F P
0 g
s
.47561 .54526 m .48023 .60113 L .49658 .59334 L p .707 .577 .707 r
F P
0 g
s
.49658 .59334 m .49196 .53747 L .47561 .54526 L p .707 .577 .707 r
F P
0 g
s
.33717 .63765 m .34227 .67487 L .36943 .67489 L p .707 .577 .707 r
F P
0 g
s
.37119 .69376 m .37381 .71237 L .40467 .70977 L p .707 .577 .707 r
F P
0 g
s
.66771 .6552 m .67281 .69242 L .65649 .70048 L p .707 .577 .707 r
F P
0 g
s
.31119 .55545 m .31582 .61132 L .33677 .61539 L p .707 .577 .707 r
F P
0 g
s
.83117 .63635 m .83627 .67357 L .81549 .67106 L p .707 .577 .707 r
F P
0 g
s
.81549 .67106 m .81039 .63384 L .83117 .63635 L p .707 .577 .707 r
F P
0 g
s
.37381 .71237 m .37119 .69376 L .34405 .69386 L p .707 .577 .707 r
F P
0 g
s
.80575 .55298 m .81037 .60885 L .78303 .6071 L p .707 .577 .707 r
F P
0 g
s
.78303 .6071 m .7784 .55123 L .80575 .55298 L p .707 .577 .707 r
F P
0 g
s
.34227 .67487 m .33717 .63765 L .31638 .63515 L p .707 .577 .707 r
F P
0 g
s
.34405 .69386 m .34667 .71247 L .37381 .71237 L p .707 .577 .707 r
F P
0 g
s
.66093 .74818 m .65831 .72957 L .67463 .72149 L p .707 .577 .707 r
F P
0 g
s
.46275 .67974 m .46537 .69834 L .48928 .69063 L p .707 .577 .707 r
F P
0 g
s
.48928 .69063 m .48666 .67202 L .46275 .67974 L p .707 .577 .707 r
F P
0 g
s
.6863 .56039 m .69092 .61626 L .66692 .62312 L p .707 .577 .707 r
F P
0 g
s
.31582 .61132 m .31119 .55545 L .29868 .54945 L p .707 .577 .707 r
F P
0 g
s
.67463 .72149 m .67725 .7401 L .66093 .74818 L p .707 .577 .707 r
F P
0 g
s
.47985 .6163 m .48495 .65352 L .50127 .64546 L p .707 .577 .707 r
F P
0 g
s
.50127 .64546 m .49617 .60824 L .47985 .6163 L p .707 .577 .707 r
F P
0 g
s
.31638 .63515 m .32148 .67237 L .34227 .67487 L p .707 .577 .707 r
F P
0 g
s
.69092 .61626 m .6863 .56039 L .7156 .55512 L p .707 .577 .707 r
F P
0 g
s
.83801 .70205 m .84062 .72066 L .81985 .71826 L p .707 .577 .707 r
F P
0 g
s
.81985 .71826 m .81724 .69965 L .83801 .70205 L p .707 .577 .707 r
F P
0 g
s
.67281 .69242 m .66771 .6552 L .69163 .64754 L p .707 .577 .707 r
F P
0 g
s
.34667 .71247 m .34405 .69386 L .32328 .69146 L p .707 .577 .707 r
F P
0 g
s
.7784 .55123 m .78303 .6071 L .75196 .60783 L p .707 .577 .707 r
F P
0 g
s
.75196 .60783 m .74734 .55196 L .7784 .55123 L p .707 .577 .707 r
F P
0 g
s
.49196 .53747 m .49658 .59334 L .50368 .5854 L p .707 .577 .707 r
F P
0 g
s
.50368 .5854 m .49906 .52953 L .49196 .53747 L p .707 .577 .707 r
F P
0 g
s
.32328 .69146 m .3259 .71007 L .34667 .71247 L p .707 .577 .707 r
F P
0 g
s
.29868 .54945 m .3033 .60532 L .31582 .61132 L p .707 .577 .707 r
F P
0 g
s
.81039 .63384 m .81549 .67106 L .78833 .67105 L p .707 .577 .707 r
F P
0 g
s
.78833 .67105 m .78323 .63383 L .81039 .63384 L p .707 .577 .707 r
F P
0 g
s
.69163 .64754 m .69673 .68476 L .67281 .69242 L p .707 .577 .707 r
F P
0 g
s
.48666 .67202 m .48928 .69063 L .5056 .68255 L p .707 .577 .707 r
F P
0 g
s
.5056 .68255 m .50298 .66394 L .48666 .67202 L p .707 .577 .707 r
F P
0 g
s
.72023 .61099 m .7156 .55512 L .74734 .55196 L p .707 .577 .707 r
F P
0 g
s
.7156 .55512 m .72023 .61099 L .69092 .61626 L p .707 .577 .707 r
F P
0 g
s
.74734 .55196 m .75196 .60783 L .72023 .61099 L p .707 .577 .707 r
F P
0 g
s
.32148 .67237 m .31638 .63515 L .30401 .63039 L p .707 .577 .707 r
F P
0 g
s
.67725 .7401 m .67463 .72149 L .69853 .71378 L p .707 .577 .707 r
F P
0 g
s
.69853 .71378 m .70115 .73239 L .67725 .7401 L p .707 .577 .707 r
F P
0 g
s
.69673 .68476 m .69163 .64754 L .72079 .64103 L p .707 .577 .707 r
F P
0 g
s
.30401 .63039 m .30911 .66762 L .32148 .67237 L p .707 .577 .707 r
F P
0 g
s
.3033 .60532 m .29868 .54945 L .29583 .54212 L p .707 .577 .707 r
F P
0 g
s
.49617 .60824 m .50127 .64546 L .5084 .63779 L p .707 .577 .707 r
F P
0 g
s
.5084 .63779 m .5033 .60056 L .49617 .60824 L p .707 .577 .707 r
F P
0 g
s
.81724 .69965 m .81985 .71826 L .79271 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .71836 m .79009 .69975 L .81724 .69965 L p .707 .577 .707 r
F P
0 g
s
.78323 .63383 m .78833 .67105 L .75746 .67352 L p .707 .577 .707 r
F P
0 g
s
.75746 .67352 m .75236 .6363 L .78323 .63383 L p .707 .577 .707 r
F P
0 g
s
.3259 .71007 m .32328 .69146 L .31091 .6868 L p .707 .577 .707 r
F P
0 g
s
.72079 .64103 m .72589 .67825 L .69673 .68476 L p .707 .577 .707 r
F P
0 g
s
.31091 .6868 m .31353 .70541 L .3259 .71007 L p .707 .577 .707 r
F P
0 g
s
.72589 .67825 m .72079 .64103 L .75236 .6363 L p .707 .577 .707 r
F P
0 g
s
.75236 .6363 m .75746 .67352 L .72589 .67825 L p .707 .577 .707 r
F P
0 g
s
.29583 .54212 m .30046 .59799 L .3033 .60532 L p .707 .577 .707 r
F P
0 g
s
.49906 .52953 m .50368 .5854 L .50084 .57807 L p .707 .577 .707 r
F P
0 g
s
.50084 .57807 m .49621 .5222 L .49906 .52953 L p .707 .577 .707 r
F P
0 g
s
.70115 .73239 m .69853 .71378 L .72769 .70718 L p .707 .577 .707 r
F P
0 g
s
.50298 .66394 m .5056 .68255 L .51273 .6749 L p .707 .577 .707 r
F P
0 g
s
.51273 .6749 m .51011 .65629 L .50298 .66394 L p .707 .577 .707 r
F P
0 g
s
.72769 .70718 m .73031 .72579 L .70115 .73239 L p .707 .577 .707 r
F P
0 g
s
.79009 .69975 m .79271 .71836 L .76186 .72096 L p .707 .577 .707 r
F P
0 g
s
.76186 .72096 m .75924 .70235 L .79009 .69975 L p .707 .577 .707 r
F P
0 g
s
.30911 .66762 m .30401 .63039 L .30125 .62386 L p .707 .577 .707 r
F P
0 g
s
.73031 .72579 m .72769 .70718 L .75924 .70235 L p .707 .577 .707 r
F P
0 g
s
.75924 .70235 m .76186 .72096 L .73031 .72579 L p .707 .577 .707 r
F P
0 g
s
.30125 .62386 m .30635 .66109 L .30911 .66762 L p .707 .577 .707 r
F P
0 g
s
.30046 .59799 m .29583 .54212 L .30293 .53417 L p .707 .577 .707 r
F P
0 g
s
.5033 .60056 m .5084 .63779 L .50564 .63126 L p .707 .577 .707 r
F P
0 g
s
.50564 .63126 m .50054 .59403 L .5033 .60056 L p .707 .577 .707 r
F P
0 g
s
.31353 .70541 m .31091 .6868 L .30816 .68032 L p .707 .577 .707 r
F P
0 g
s
.30816 .68032 m .31078 .69893 L .31353 .70541 L p .707 .577 .707 r
F P
0 g
s
.51011 .65629 m .51273 .6749 L .50998 .66842 L p .707 .577 .707 r
F P
0 g
s
.50998 .66842 m .50736 .64981 L .51011 .65629 L p .707 .577 .707 r
F P
0 g
s
.30293 .53417 m .30756 .59004 L .30046 .59799 L p .707 .577 .707 r
F P
0 g
s
.49621 .5222 m .50084 .57807 L .48832 .57207 L p .707 .577 .707 r
F P
0 g
s
.48832 .57207 m .4837 .5162 L .49621 .5222 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30635 .66109 m .30125 .62386 L .30838 .61619 L p .707 .577 .707 r
F P
0 g
s
.30838 .61619 m .31348 .65341 L .30635 .66109 L p .707 .577 .707 r
F P
0 g
s
.30756 .59004 m .30293 .53417 L .31928 .52639 L p .707 .577 .707 r
F P
0 g
s
.50054 .59403 m .50564 .63126 L .49326 .6265 L p .707 .577 .707 r
F P
0 g
s
.49326 .6265 m .48816 .58928 L .50054 .59403 L p .707 .577 .707 r
F P
0 g
s
.31078 .69893 m .30816 .68032 L .3153 .67267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3153 .67267 m .31792 .69128 L .31078 .69893 L p .707 .577 .707 r
F P
0 g
s
.4837 .5162 m .48832 .57207 L .46736 .56799 L p .707 .577 .707 r
F P
0 g
s
.46736 .56799 m .46274 .51212 L .4837 .5162 L p .707 .577 .707 r
F P
0 g
s
.31928 .52639 m .32391 .58226 L .30756 .59004 L p .707 .577 .707 r
F P
0 g
s
.50736 .64981 m .50998 .66842 L .49761 .66375 L p .707 .577 .707 r
F P
0 g
s
.49761 .66375 m .49499 .64515 L .50736 .64981 L p .707 .577 .707 r
F P
0 g
s
.31348 .65341 m .30838 .61619 L .3247 .60813 L p .707 .577 .707 r
F P
0 g
s
.32391 .58226 m .31928 .52639 L .34329 .51953 L p .707 .577 .707 r
F P
0 g
s
.3247 .60813 m .3298 .64535 L .31348 .65341 L p .707 .577 .707 r
F P
0 g
s
.48816 .58928 m .49326 .6265 L .47248 .624 L p .707 .577 .707 r
F P
0 g
s
.47248 .624 m .46738 .58677 L .48816 .58928 L p .707 .577 .707 r
F P
0 g
s
.31792 .69128 m .3153 .67267 L .33162 .66459 L p .707 .577 .707 r
F P
0 g
s
.46274 .51212 m .46736 .56799 L .44002 .56624 L p .707 .577 .707 r
F P
0 g
s
.44002 .56624 m .43539 .51037 L .46274 .51212 L p .707 .577 .707 r
F P
0 g
s
.33162 .66459 m .33424 .6832 L .31792 .69128 L p .707 .577 .707 r
F P
0 g
s
.34329 .51953 m .34791 .5754 L .32391 .58226 L p .707 .577 .707 r
F P
0 g
s
.49499 .64515 m .49761 .66375 L .47684 .66136 L p .707 .577 .707 r
F P
0 g
s
.47684 .66136 m .47423 .64275 L .49499 .64515 L p .707 .577 .707 r
F P
0 g
s
.34791 .5754 m .34329 .51953 L .37259 .51426 L p .707 .577 .707 r
F P
0 g
s
.3298 .64535 m .3247 .60813 L .34862 .60047 L p .707 .577 .707 r
F P
0 g
s
.43539 .51037 m .44002 .56624 L .40895 .56698 L p .707 .577 .707 r
F P
0 g
s
.40895 .56698 m .40433 .5111 L .43539 .51037 L p .707 .577 .707 r
F P
0 g
s
.46738 .58677 m .47248 .624 L .44532 .62398 L p .707 .577 .707 r
F P
0 g
s
.44532 .62398 m .44022 .58676 L .46738 .58677 L p .707 .577 .707 r
F P
0 g
s
.34862 .60047 m .35372 .63769 L .3298 .64535 L p .707 .577 .707 r
F P
0 g
s
.37721 .57013 m .37259 .51426 L .40433 .5111 L p .707 .577 .707 r
F P
0 g
s
.37259 .51426 m .37721 .57013 L .34791 .5754 L p .707 .577 .707 r
F P
0 g
s
.33424 .6832 m .33162 .66459 L .35552 .65687 L p .707 .577 .707 r
F P
0 g
s
.40433 .5111 m .40895 .56698 L .37721 .57013 L p .707 .577 .707 r
F P
0 g
s
.35552 .65687 m .35814 .67548 L .33424 .6832 L p .707 .577 .707 r
F P
0 g
s
.35372 .63769 m .34862 .60047 L .37778 .59396 L p .707 .577 .707 r
F P
0 g
s
.47423 .64275 m .47684 .66136 L .4497 .66146 L p .707 .577 .707 r
F P
0 g
s
.4497 .66146 m .44708 .64285 L .47423 .64275 L p .707 .577 .707 r
F P
0 g
s
.44022 .58676 m .44532 .62398 L .41445 .62646 L p .707 .577 .707 r
F P
0 g
s
.41445 .62646 m .40935 .58923 L .44022 .58676 L p .707 .577 .707 r
F P
0 g
s
.37778 .59396 m .38288 .63118 L .35372 .63769 L p .707 .577 .707 r
F P
0 g
s
.38288 .63118 m .37778 .59396 L .40935 .58923 L p .707 .577 .707 r
F P
0 g
s
.35814 .67548 m .35552 .65687 L .38468 .65028 L p .707 .577 .707 r
F P
0 g
s
.40935 .58923 m .41445 .62646 L .38288 .63118 L p .707 .577 .707 r
F P
0 g
s
.38468 .65028 m .3873 .66889 L .35814 .67548 L p .707 .577 .707 r
F P
0 g
s
.44708 .64285 m .4497 .66146 L .41885 .66405 L p .707 .577 .707 r
F P
0 g
s
.41885 .66405 m .41623 .64545 L .44708 .64285 L p .707 .577 .707 r
F P
0 g
s
.3873 .66889 m .38468 .65028 L .41623 .64545 L p .707 .577 .707 r
F P
0 g
s
.41623 .64545 m .41885 .66405 L .3873 .66889 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0091oo`P008Eo
o`00S7oo10000UYF00<005YFFUH00eYF3000NGoo0028Ool40006FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH9001`Ool008Aoo`@00003FUH005YF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@006aoo`00PWoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH015YF1000J7oo0021Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH4001TOol0081oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP04001JEP00001ROol0081oo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP04001JEUYFFUH3001OOol007moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF019JEP80
05eoo`00Ogoo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF0P00Fgoo001oOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH3001IOol007ioo`04001J
EUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP02001GOol007ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00eJEP8005Eoo`00OWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P00Dgoo001nOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00Oomoo`1@
Ool007ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001oogoo04moo`00OWoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH02EYF00<007ooOol0CWoo001mOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH02UYF00<007oo
Ool0CGoo001mOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`1<Ool0
07eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo04]oo`00OGoo00<0
05YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH03EYF00<007ooOol0Bgoo001mOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0=
FUH00`00Oomoo`1;Ool007aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001<Ool007aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004ao
o`00O7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000C7oo001lOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001<Ool007aoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00eJEP8004eoo`00O7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH035YF00<005YF0000
CGoo001kOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001=Ool007]o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004eoo`00Ngoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CGoo001kOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0=FUH2001>Ool007]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP03001JEP0004ioo`00
NWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<0
05YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CWoo001jOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001>Ool007Yoo`03001JEP0000IJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYF
0P00Cgoo001jOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001?Ool0
07Uoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004moo`00NGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Cgoo001iOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool007Uoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP80051oo`00NGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH035YF00<005YF
0000D7oo001hOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001@Ool0
07Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00051oo`00N7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000D7oo001hOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1@Ool007Qoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00aJEP03001JEUYF055oo`00N7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000DGoo001gOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001AOol007Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00055oo`00
Mgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0DGoo001gOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001BOol007Moo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00059oo`00MWoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000DWoo001fOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001BOol007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP00059oo`00MWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF0000Dgoo001fOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001C
Ool007Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005=oo`00MGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Dgoo001eOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001COol007Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8005Aoo`00MGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000E7oo001eOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001DOol007Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ao
o`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000E7oo001dOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001EOol007Aoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Eoo`00M7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000EGoo001dOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001EOol007=oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0005Eoo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000EGoo
001cOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001FOol007=oo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ioo`00Lgoo0P001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000EWoo001^OolH000:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001FOol006Io
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005Ioo`00
H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
0eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000Egoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001GOol005Yoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000Egoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EWoo0P000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EUYF05Qoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Qoo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0005Qoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000F7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;OolA
000lOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005Ool60004FUH00`00
FUIJEP06FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF00000Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008002ioo`00E7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF009JEQL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF00<005YFFUH015YF10000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUIJEP8002eoo`00EGoo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP0000002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
001EOol00`00FUH00004FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol00`00FUH00003
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YF001JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEPl00003FUH005YF00=JEP03001JEP0000UJEP03001JEUYF00UJ
EP03001JEUYF00UJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
001EOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0004FUH00`00FUIJEP04
FUH00`00FUIJEP0500000eYF00000009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00EGoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF00000P002EYF00<005YFFUH02UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000]Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;Goo0017Ool@0002FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000/Ool003moo`P000AJEP03001JEUYF00IJEP06001JEP00001JEP000UYF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00=JEP03001JEUYF008002aoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH70003
FUH00`00FUIJEP02000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@000UYF0P00;7oo000cOol20005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH4000/Ool0039oo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00<7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH00P001UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT0009J
EP@00003FUH005YF00EJEPH00003FUH0000000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEP00FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH800000eYF000000060005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH000020005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00@00003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0001/002ioo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF2@000UYF1@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUH000030004FUH00`00FUIJEP05FUH3
0007FUH00`00FUH0000>0004FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF0`00
1eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01P001eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYF001JEP020003FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YF000005YF008000AJEP03001JEP0000<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo000]Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP0000EJEP04001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH00UYF3P0000AJEP00FUH000EJEP@00003FUH005YF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH90008FUH00`00
FUIJEP03FUH01000FUIJEP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF6@000UYF0P00
0eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002aoo`00;Woo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF00@000=J
EPL000QJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000/Ool002ioo`03001JEP0000AJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00AJEP03001JEUYF00AJEPH0009JEP@000AJEP03001JEUYF00QJEP04001JEUYFFUH200000eYF
001JEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00D0
05YFFUIJEP0002]oo`00;Woo00<005YF00000eYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0300025YF00<005YFFUH0
25YF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=oo`0000000P000UYF00<005YFFUH015YF1@000UYF00<007ooOol0:Goo000^Ool01000FUH005YF
0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF
00<005YFFUH00UYF1@0000=oo`0000001UYF00<005YFFUH01eYF00<005YFFUH01UYF100000=JEP00
FUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000Eoo`D000IJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH03@0000=JEP00FUH015YF00<005YF00000P000UYF0P000Woo00=JEP00FUH00UYF100025YF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000Moo`@0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002]oo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P000UYF00@0
05YFFUIJEP<0009JEP@0009oo`03001JEP00009JEPD000QJEP03001JEUYF00@00003FUH005YF00IJ
EP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH00eYF3`001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000:goo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH7
0006FUH00`00FUIJEP06FUH20002FUH01000FUH000001EYF00<005YFFUH00P0000Aoo`00FUH0009J
EPD000AJEPL000EJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUH005YF1@001EYF00<005YFFUH00`0000AJEP00FUIJEPT000AJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000^Ool20002FUH00`00FUIJEP03FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH0009JEQ000003FUH00000
008000QJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF00000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH002ioo`00;goo00@005YF
FUH000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF100035YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHC000_Ool0031oo`<00004FUH000000005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00D002eoo`00
<Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF1`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002]oo`00;goo0P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF400000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH?0003FUH01@00FUIJEUYF00001UYF00<005YFFUH07eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF0`0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
2@000Woo100000=JEP00FUH01EYF1P000UYF00<005YFFUH03EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
0`000UYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4P000eYF00<007oo
Ool0:7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1`000goo1`001EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004Goo0`0000=JEP00Ool0
:Goo000_Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP0400000goo000000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP03FUHC
0009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
00050007FUH00`00FUIJEP04FUH6000HOol20002FUH4000YOol002moo`03001JEP0000AJEP03001J
EUYF00=JEPT0009JEPD000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF00AJEPL000=JEP03001JEUYF00QJEP03001JEUYF009JEPH000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`8000AJEP04001JEP00000YOol002moo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00AJEPD000IJEP03001JEP0000h000EJEP04001JEUYFFUH200000eYF001JEP06
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH5000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH00eYF10007Goo0`0000=JEP00FUH015YF00<005YF
0000:Goo000_Ool01000FUIJEP000eYF0`001eYF00<005YFFUH01EYF0`000UYF1`0015YF00<005YF
FUH015YF00<005YFFUH01@0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0000=JEP00FUH00eYF00<005YF00000`000UYF00<007ooOol067oo100015YF00<005YFFUH00eYF
0P00:Woo000_Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`000eYF00<005YFFUH00P005Goo1000
0UYF00<005YFFUH015YF00@005YFFUIJEP8002]oo`00;goo00<005YFFUH00P001EYF00<005YFFUH0
1EYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02EYF10002UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YF001JEP00FUH30005FUH01@00FUIJEUYF00003Woo1`001UYF
00<005YFFUH015YF00@005YF000002eoo`00<7oo00AJEP00FUH000EJEP04001JEUYFFUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030007FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1P0015YF00D005YFFUIJEP0000Ioo`P000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<002moo`00<7oo00AJEP00FUH000EJEP06001JEP00001JEP00
1eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF010000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0039oo`00<7oo00@005YFFUH000EJEP80
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<00003
FUH005YF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0031oo`06001JEUYFFUH005YF
0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P0037oo00<005YF00003EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00@003Uoo`00<7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
1`000eYF1`003Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF000000IJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD003eo
o`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH010000UYF20004goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP05001JEP00001JEP0200000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool0035oo`8000EJEP03001JEUYF009J
EPX001Moo`@00003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000=JEQ/004Ioo`00<7oo00<005YF00001EYF00<005YF00000P002goo0`0047oo0`00
1EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF0P001eYF0P001EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH00UYF1000DGoo000`Ool01000FUIJEP000eYF0`003Goo1@002goo100000=JEP00
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP8000AJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF001AOol0031oo`05001JEUYF001JEP02000@Ool50004Ool7
0005FUH00`00FUIJEP05FUH01000FUH000000Woo00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000eYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000DWoo000aOol00`00FUH00003000@
Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005Ool00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH02@00FUIJEUYF
001JEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol0035oo`800004FUH005YF
FUH@00000eYF000000020008FUH00`00FUIJEP06FUH00`00FUH000030009Ool00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000E7oo000aOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP04FUH01000FUH00000
EGoo000aOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04000COol2000?FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000000?001EOol0039oo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000IOol2000=FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000015YF001JEP001eYF
00<005YFFUH00eYF0`00Dgoo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000ROol3
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000eOolC
000^Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02001A
Ool007Uoo`80015JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080055oo`00Ngoo0`00
3UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
3`000UYF00D005YFFUIJEP00055oo`00OWoo0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00UYF0`003goo10000UYF00<007ooOol0Cgoo0021Ool4000CFUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`0@Ool200000eYF00000002001@
Ool008Eoo`@000mJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH2000@Ool30003FUH0
1000FUH00000D7oo0029Ool5000OFUH01000FUH000003goo0`0000=JEP00FUH015YF00<005YF0000
D7oo002>Ool6000EFUH6000=Ool40004FUH00`00FUIJEP03FUH2001AOol0099oo`03001JEP0001@0
00moo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH2001BOol0099oo`04001JEP00FUH2000IOol7
0006FUH00`00FUIJEP04FUH01000FUH00000E7oo002BOol00`00FUH00004000@Ool80004FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3001FOol0099oo`80009JEP03001JEUYF010000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<005Uoo`00TWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00GGoo002BOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001P
Ool009=oo`05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
001TOol009Aoo`800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
06Uoo`00UWoo6P00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60388 .74909 m .59641 .69325 L .56553 .69562 L p .707 .577 .707 r
F P
0 g
s
.59641 .69325 m .60388 .74909 L .63546 .74446 L p .707 .577 .707 r
F P
0 g
s
.63546 .74446 m .62799 .68862 L .59641 .69325 L p .707 .577 .707 r
F P
0 g
s
.62799 .68862 m .63546 .74446 L .66463 .73803 L p .707 .577 .707 r
F P
0 g
s
.66463 .73803 m .65717 .68218 L .62799 .68862 L p .707 .577 .707 r
F P
0 g
s
.57299 .75146 m .56553 .69562 L .53836 .69549 L p .707 .577 .707 r
F P
0 g
s
.56553 .69562 m .57299 .75146 L .60388 .74909 L p .707 .577 .707 r
F P
0 g
s
.65717 .68218 m .66463 .73803 L .68856 .73041 L p .707 .577 .707 r
F P
0 g
s
.68856 .73041 m .68109 .67457 L .65717 .68218 L p .707 .577 .707 r
F P
0 g
s
.61195 .81236 m .60374 .77542 L .57335 .78059 L p .707 .577 .707 r
F P
0 g
s
.60374 .77542 m .61195 .81236 L .64308 .80521 L p .707 .577 .707 r
F P
0 g
s
.64308 .80521 m .63487 .76826 L .60374 .77542 L p .707 .577 .707 r
F P
0 g
s
.53836 .69549 m .54582 .75134 L .57299 .75146 L p .707 .577 .707 r
F P
0 g
s
.63487 .76826 m .64308 .80521 L .6719 .79676 L p .707 .577 .707 r
F P
0 g
s
.6719 .79676 m .66369 .75982 L .63487 .76826 L p .707 .577 .707 r
F P
0 g
s
.54582 .75134 m .53836 .69549 L .51756 .69289 L p .707 .577 .707 r
F P
0 g
s
.57335 .78059 m .58156 .81754 L .61195 .81236 L p .707 .577 .707 r
F P
0 g
s
.58156 .81754 m .57335 .78059 L .54668 .78327 L p .707 .577 .707 r
F P
0 g
s
.66369 .75982 m .6719 .79676 L .69559 .78786 L p .707 .577 .707 r
F P
0 g
s
.69559 .78786 m .68738 .75092 L .66369 .75982 L p .707 .577 .707 r
F P
0 g
s
.68109 .67457 m .68856 .73041 L .70488 .72237 L p .707 .577 .707 r
F P
0 g
s
.70488 .72237 m .69741 .66653 L .68109 .67457 L p .707 .577 .707 r
F P
0 g
s
.61901 .86296 m .6148 .8445 L .58445 .84987 L p .707 .577 .707 r
F P
0 g
s
.6148 .8445 m .61901 .86296 L .6501 .85563 L p .707 .577 .707 r
F P
0 g
s
.6501 .85563 m .64589 .83717 L .6148 .8445 L p .707 .577 .707 r
F P
0 g
s
.54668 .78327 m .55489 .82022 L .58156 .81754 L p .707 .577 .707 r
F P
0 g
s
.64589 .83717 m .6501 .85563 L .67889 .84705 L p .707 .577 .707 r
F P
0 g
s
.67889 .84705 m .67467 .82859 L .64589 .83717 L p .707 .577 .707 r
F P
0 g
s
.51756 .69289 m .52502 .74873 L .54582 .75134 L p .707 .577 .707 r
F P
0 g
s
.58445 .84987 m .58867 .86833 L .61901 .86296 L p .707 .577 .707 r
F P
0 g
s
.58867 .86833 m .58445 .84987 L .55782 .85274 L p .707 .577 .707 r
F P
0 g
s
.55489 .82022 m .54668 .78327 L .52633 .7832 L p .707 .577 .707 r
F P
0 g
s
.55782 .85274 m .56203 .8712 L .58867 .86833 L p .707 .577 .707 r
F P
0 g
s
.67467 .82859 m .67889 .84705 L .70256 .83806 L p .707 .577 .707 r
F P
0 g
s
.70256 .83806 m .69835 .8196 L .67467 .82859 L p .707 .577 .707 r
F P
0 g
s
.52502 .74873 m .51756 .69289 L .50517 .68806 L p .707 .577 .707 r
F P
0 g
s
.68738 .75092 m .69559 .78786 L .71183 .77937 L p .707 .577 .707 r
F P
0 g
s
.71183 .77937 m .70363 .74243 L .68738 .75092 L p .707 .577 .707 r
F P
0 g
s
.52633 .7832 m .53454 .82015 L .55489 .82022 L p .707 .577 .707 r
F P
0 g
s
.50517 .68806 m .51264 .74391 L .52502 .74873 L p .707 .577 .707 r
F P
0 g
s
.51264 .74391 m .50517 .68806 L .50241 .68148 L p .707 .577 .707 r
F P
0 g
s
.50241 .68148 m .50987 .73733 L .51264 .74391 L p .707 .577 .707 r
F P
0 g
s
.50987 .73733 m .50241 .68148 L .50953 .6738 L p .707 .577 .707 r
F P
0 g
s
.50953 .6738 m .517 .72964 L .50987 .73733 L p .707 .577 .707 r
F P
0 g
s
.517 .72964 m .50953 .6738 L .52586 .66575 L p .707 .577 .707 r
F P
0 g
s
.52586 .66575 m .53332 .72159 L .517 .72964 L p .707 .577 .707 r
F P
0 g
s
.53454 .82015 m .52633 .7832 L .5143 .78038 L p .707 .577 .707 r
F P
0 g
s
.5143 .78038 m .52251 .81733 L .53454 .82015 L p .707 .577 .707 r
F P
0 g
s
.52251 .81733 m .5143 .78038 L .51177 .77509 L p .707 .577 .707 r
F P
0 g
s
.51177 .77509 m .51997 .81203 L .52251 .81733 L p .707 .577 .707 r
F P
0 g
s
.51997 .81203 m .51177 .77509 L .51897 .76785 L p .707 .577 .707 r
F P
0 g
s
.51897 .76785 m .52718 .80479 L .51997 .81203 L p .707 .577 .707 r
F P
0 g
s
.52718 .80479 m .51897 .76785 L .53522 .75936 L p .707 .577 .707 r
F P
0 g
s
.53522 .75936 m .54343 .7963 L .52718 .80479 L p .707 .577 .707 r
F P
0 g
s
.54343 .7963 m .53522 .75936 L .55891 .75046 L p .707 .577 .707 r
F P
0 g
s
.56268 .71278 m .55725 .71398 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .63481 .35973 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.55891 .75046 m .56712 .7874 L .54343 .7963 L p .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .55891 .75046 L .57907 .74455 L p .707 .577 .707 r
F P
0 g
s
.57907 .74455 m .58773 .74201 L p .58426 .74965 L .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .57907 .74455 L .58426 .74965 L .707 .577 .707 r
F
.55716 .72307 m .56872 .72068 L .56008 .70938 L F
.53356 .83349 m .56545 .7312 L p .55716 .72307 L F P
0 g
s
.56545 .7312 m .56872 .72068 L p .55716 .72307 L .707 .577 .707 r
F P
0 g
s
.56872 .72068 m .67805 .37002 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .5397 .66479 L p .5559 .70391 L .707 .577 .707 r
F P
0 g
s
.56008 .70938 m .63481 .35973 L .5559 .70391 L .707 .577 .707 r
F
.54978 .65814 m .57896 .65171 L p .55924 .70828 L F P
0 g
s
.55725 .71398 m .5559 .70391 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.5559 .70391 m .54978 .65814 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.54173 .8713 m .53751 .85284 L .52551 .85016 L p .707 .577 .707 r
F P
0 g
s
.53442 .8562 m .53021 .83774 L .54645 .82923 L p .707 .577 .707 r
F P
0 g
s
.56203 .8712 m .55782 .85274 L .53751 .85284 L p .707 .577 .707 r
F P
0 g
s
.53751 .85284 m .54173 .8713 L .56203 .8712 L p .707 .577 .707 r
F P
0 g
s
.54645 .82923 m .55066 .84768 L .53442 .8562 L p .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .55961 .74992 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61665 .69281 L p .60159 .70532 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .618 .70292 L .61029 .70405 L p .707 .577 .707 r
F P
0 g
s
.61029 .70405 m .60159 .70532 L p .61665 .69281 L .707 .577 .707 r
F P
0 g
s
.64889 .70055 m .64142 .64471 L .66859 .64483 L p .707 .577 .707 r
F P
0 g
s
.64142 .64471 m .64889 .70055 L .618 .70292 L p .707 .577 .707 r
F P
0 g
s
.57012 .82024 m .57433 .83869 L .55066 .84768 L p .707 .577 .707 r
F P
0 g
s
.62707 .7718 m .61886 .73486 L .64925 .72968 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .58851 .74554 L p .61886 .73486 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .58773 .74201 L .59113 .74123 L p .707 .577 .707 r
F P
0 g
s
.59113 .74123 m .61886 .73486 L p .58851 .74554 L .707 .577 .707 r
F P
0 g
s
.61886 .73486 m .62707 .7718 L .59935 .77817 L p .707 .577 .707 r
F P
0 g
s
.59935 .77817 m .59594 .77896 L p .61755 .73738 L .707 .577 .707 r
F P
0 g
s
.61755 .73738 m .61886 .73486 L .59935 .77817 L .707 .577 .707 r
F
.67606 .70067 m .66859 .64483 L .68939 .64743 L p F P
0 g
s
.66859 .64483 m .67606 .70067 L .64889 .70055 L p .707 .577 .707 r
F P
0 g
s
.65745 .76663 m .64925 .72968 L .67592 .727 L p .707 .577 .707 r
F P
0 g
s
.64925 .72968 m .65745 .76663 L .62707 .7718 L p .707 .577 .707 r
F P
0 g
s
.63421 .82278 m .63 .80432 L .66034 .79896 L p .707 .577 .707 r
F P
0 g
s
.60312 .83011 m .59891 .81166 L .63 .80432 L p .707 .577 .707 r
F P
0 g
s
.63 .80432 m .63421 .82278 L .61681 .82689 L p .707 .577 .707 r
F P
0 g
s
.61681 .82689 m .60312 .83011 L p .62194 .81206 L .707 .577 .707 r
F P
0 g
s
.62194 .81206 m .63 .80432 L .61681 .82689 L .707 .577 .707 r
F
.69741 .66653 m .70488 .72237 L .71201 .71468 L p F P
0 g
s
.71201 .71468 m .70454 .65884 L .69741 .66653 L p .707 .577 .707 r
F P
0 g
s
.69686 .70327 m .68939 .64743 L .70178 .65226 L p .707 .577 .707 r
F P
0 g
s
.68939 .64743 m .69686 .70327 L .67606 .70067 L p .707 .577 .707 r
F P
0 g
s
.68413 .76395 m .67592 .727 L .69627 .72708 L p .707 .577 .707 r
F P
0 g
s
.69209 .72818 m .68389 .69124 L .68375 .69124 L p .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .63988 .81337 L p .74256 .4693 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .74615 .45575 L .62958 .82718 L .707 .577 .707 r
F
.74692 .4508 m .62958 .82718 L p .75537 .42638 L F P
0 g
s
.60677 .83558 m .62958 .82718 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .77408 .36371 L .75127 .37211 L p .707 .577 .707 r
F P
0 g
s
.63988 .81337 m .78437 .3499 L .77408 .36371 L p .707 .577 .707 r
F P
0 g
s
.68346 .5896 m .60677 .83558 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.60677 .83558 m .75127 .37211 L .71818 .37429 L p .707 .577 .707 r
F P
0 g
s
.75127 .37211 m .68346 .5896 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.57433 .83869 m .57012 .82024 L .59891 .81166 L p .707 .577 .707 r
F P
0 g
s
.59891 .81166 m .60312 .83011 L .57433 .83869 L p .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .60677 .83558 L p .65482 .63664 L .707 .577 .707 r
F P
0 g
s
.68913 .62538 m .69234 .61692 L .67556 .60346 L .707 .577 .707 r
F
.7038 .59298 m .69234 .61692 L .78437 .3499 L F
.675 .67984 m .68002 .65644 L .69428 .6217 L F
.63666 .79551 m .67098 .68543 L p .675 .67984 L F P
0 g
s
.67098 .68543 m .68002 .65644 L p .675 .67984 L .707 .577 .707 r
F P
0 g
s
.63666 .79551 m .62847 .78545 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .68458 .64182 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.68458 .64182 m .63666 .79551 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.618 .70292 m .61665 .69281 L p .64142 .64471 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .62106 .68113 L .64142 .64471 L .707 .577 .707 r
F
.63536 .64517 m .64142 .64471 L p .61624 .68976 L F P
0 g
s
.65956 .61698 m .68483 .51236 L .6216 .68407 L .707 .577 .707 r
F
.71818 .37429 m .62936 .65917 L p .68483 .51236 L F P
0 g
s
.55066 .84768 m .54645 .82923 L .57012 .82024 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .56712 .7874 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58773 .74201 m .58851 .74554 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .59594 .77896 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.6216 .68407 m .608 .72768 L p .65956 .61698 L .707 .577 .707 r
F P
0 g
s
.608 .72768 m .57368 .83775 L p .62121 .71558 L .707 .577 .707 r
F P
0 g
s
.65956 .61698 m .608 .72768 L .62121 .71558 L .707 .577 .707 r
F
.59637 .73609 m .67805 .37002 L .55368 .83562 L F
.61267 .66304 m .61053 .64708 L .61633 .64663 L p F P
0 g
s
.61665 .69281 m .61624 .68976 L p .62106 .68113 L .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .71818 .37429 L .67805 .37002 L p .707 .577 .707 r
F P
0 g
s
.61633 .64663 m .63536 .64517 L p .61267 .66304 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61267 .66304 L p .63536 .64517 L .707 .577 .707 r
F P
0 g
s
.62936 .65917 m .6216 .68407 L p .68483 .51236 L .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .65476 .60085 L p .67844 .64982 L .707 .577 .707 r
F P
0 g
s
.67964 .64826 m .67556 .60346 L .67844 .64982 L .707 .577 .707 r
F
.62847 .78545 m .62024 .77534 L p .67579 .65329 L F P
0 g
s
.68127 .64614 m .67556 .60346 L p .67964 .64826 L .707 .577 .707 r
F P
0 g
s
.69428 .6217 m .68458 .64182 L .7038 .59298 L .707 .577 .707 r
F
.68002 .65644 m .68458 .64182 L p .69428 .6217 L F P
0 g
s
.68458 .64182 m .69234 .61692 L p .7038 .59298 L .707 .577 .707 r
F P
0 g
s
.675 .67984 m .69428 .6217 L .67958 .67349 L .707 .577 .707 r
F
.71657 .56739 m .63988 .81337 L p .69428 .6217 L F P
0 g
s
.70454 .65884 m .71201 .71468 L .70924 .7081 L p .707 .577 .707 r
F P
0 g
s
.70924 .7081 m .70178 .65226 L .70454 .65884 L p .707 .577 .707 r
F P
0 g
s
.70178 .65226 m .70924 .7081 L .69686 .70327 L p .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .68303 .6593 L .7102 .65942 L p .707 .577 .707 r
F P
0 g
s
.67579 .65329 m .68127 .64614 L .62847 .78545 L .707 .577 .707 r
F
.65482 .63664 m .65956 .61698 L .64679 .64983 L F
.65476 .60085 m .66223 .65669 L .67222 .65794 L p F P
0 g
s
.62024 .77534 m .65442 .68116 L .67579 .65329 L .707 .577 .707 r
F
.67222 .65794 m .68303 .6593 L p .67844 .64982 L F P
0 g
s
.67844 .64982 m .65476 .60085 L .67222 .65794 L .707 .577 .707 r
F
.69676 .60355 m .67556 .60346 L p .69234 .61692 L F P
0 g
s
.78115 .33204 m .69234 .61692 L p .67579 .65329 L .707 .577 .707 r
F P
0 g
s
.65442 .68116 m .78115 .33204 L .67579 .65329 L .707 .577 .707 r
F
.67579 .65329 m .69234 .61692 L .68127 .64614 L F
.68167 .64919 m .68127 .64614 L p .68009 .65322 L F P
0 g
s
.68127 .64614 m .67964 .64826 L .68009 .65322 L .707 .577 .707 r
F
.68009 .65322 m .67964 .64826 L .67844 .64982 L F
.63988 .81337 m .63666 .79551 L p .675 .67984 L F P
0 g
s
.675 .67984 m .67958 .67349 L .63988 .81337 L .707 .577 .707 r
F
.65971 .72529 m .67174 .72811 L p .6587 .70248 L F P
0 g
s
.66223 .65669 m .65476 .60085 L .64238 .59603 L p .707 .577 .707 r
F P
0 g
s
.65482 .63664 m .64679 .64983 L .57368 .83775 L .707 .577 .707 r
F
.64238 .59603 m .64849 .6418 L p .66223 .65669 L F P
0 g
s
.64284 .62484 m .64849 .6418 L .62024 .77534 L .707 .577 .707 r
F
.6554 .66254 m .65288 .67064 L p .64849 .6418 L F P
0 g
s
.65288 .67064 m .62024 .77534 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64238 .59603 L .64114 .59307 L p .707 .577 .707 r
F P
0 g
s
.61053 .64708 m .61624 .68976 L p .58642 .70755 L .707 .577 .707 r
F P
0 g
s
.60159 .70532 m .58642 .70755 L p .61624 .68976 L .707 .577 .707 r
F P
0 g
s
.55368 .83562 m .57368 .83775 L p .59637 .73609 L .707 .577 .707 r
F P
0 g
s
.6416 .59643 m .59222 .75484 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.64114 .59307 m .64106 .59291 L p .6416 .59643 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64114 .59307 L .6416 .59643 L .707 .577 .707 r
F
.53356 .83349 m .55368 .83562 L p .58329 .72476 L F P
0 g
s
.55961 .74992 m .53356 .83349 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.57896 .65171 m .58642 .70755 L .56268 .71278 L p .707 .577 .707 r
F P
0 g
s
.58642 .70755 m .57896 .65171 L .61053 .64708 L p .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .55534 .73602 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.73671 .29137 m .6416 .59643 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.65215 .65277 m .66223 .65669 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.76473 .31187 m .6554 .66254 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .73671 .29137 L .76473 .31187 L p .707 .577 .707 r
F P
0 g
s
.64984 .65187 m .64849 .6418 L p .63961 .58945 L .707 .577 .707 r
F P
0 g
s
.64106 .59291 m .63961 .58945 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64984 .65187 L .65215 .65277 L p .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .59222 .75484 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .76473 .31187 L .78115 .33204 L p .707 .577 .707 r
F P
0 g
s
.65151 .68834 m .6556 .70679 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.6556 .70679 m .65971 .72529 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.67592 .727 m .68413 .76395 L .65745 .76663 L p .707 .577 .707 r
F P
0 g
s
.67174 .72811 m .69209 .72818 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66354 .69116 m .66432 .69468 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .67174 .72811 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.68303 .6593 m .68167 .64919 L p .68009 .65322 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .75537 .42638 L .74615 .45575 L .707 .577 .707 r
F
.77408 .36371 m .74692 .4508 L p .75537 .42638 L F P
0 g
s
.78303 .34246 m .78437 .3499 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.6974 .60355 m .69676 .60355 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .78115 .33204 L .78303 .34246 L p .707 .577 .707 r
F P
0 g
s
.78437 .3499 m .71657 .56739 L p .69428 .6217 L .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .70273 .60358 L .6974 .60355 L p .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .6974 .60355 L .68913 .62538 L .707 .577 .707 r
F
.66354 .69116 m .65151 .68834 L p .6587 .70248 L F P
0 g
s
.67174 .72811 m .66432 .69468 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .66354 .69116 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.68375 .69124 m .66576 .69117 L p .6786 .71068 L .707 .577 .707 r
F P
0 g
s
.66576 .69117 m .66354 .69116 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.6786 .71068 m .66576 .69117 L .66499 .69305 L .707 .577 .707 r
F
.69209 .72818 m .68375 .69124 L .6786 .71068 L F
.55924 .70828 m .57896 .65171 L .56268 .71278 L F
.55943 .71243 m .56008 .70938 L .5559 .70391 L F
.49032 .82319 m .53356 .83349 L p .55943 .71243 L F P
0 g
s
.53332 .72159 m .52586 .66575 L .53844 .66175 L p .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53844 .66175 L .53892 .66291 L .707 .577 .707 r
F
.5397 .66479 m .63481 .35973 L p .53218 .62742 L F P
0 g
s
.53905 .66155 m .54978 .65814 L p .54335 .68292 L .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53905 .66155 L .54335 .68292 L .707 .577 .707 r
F
.54978 .65814 m .55725 .71398 L .53332 .72159 L p F P
0 g
s
.5397 .66479 m .49032 .82319 L p .55943 .71243 L .707 .577 .707 r
F P
0 g
s
.53844 .66175 m .53905 .66155 L p .53892 .66291 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .59269 .34442 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.49032 .82319 m .5397 .66479 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.4482 .80789 m .59269 .34442 L .55582 .3256 L p .707 .577 .707 r
F P
0 g
s
.59269 .34442 m .4482 .80789 L .49032 .82319 L p .707 .577 .707 r
F P
0 g
s
.69835 .8196 m .70256 .83806 L .7188 .82954 L p .707 .577 .707 r
F P
0 g
s
.7188 .82954 m .71459 .81109 L .69835 .8196 L p .707 .577 .707 r
F P
0 g
s
.41132 .78906 m .55582 .3256 L .52779 .3051 L p .707 .577 .707 r
F P
0 g
s
.55582 .3256 m .41132 .78906 L .4482 .80789 L p .707 .577 .707 r
F P
0 g
s
.70363 .74243 m .71183 .77937 L .71904 .77213 L p .707 .577 .707 r
F P
0 g
s
.71904 .77213 m .71084 .73519 L .70363 .74243 L p .707 .577 .707 r
F P
0 g
s
.52551 .85016 m .52973 .86862 L .54173 .8713 L p .707 .577 .707 r
F P
0 g
s
.71459 .81109 m .7188 .82954 L .72601 .82233 L p .707 .577 .707 r
F P
0 g
s
.72601 .82233 m .7218 .80387 L .71459 .81109 L p .707 .577 .707 r
F P
0 g
s
.3833 .76856 m .52779 .3051 L .51137 .28493 L p .707 .577 .707 r
F P
0 g
s
.52779 .3051 m .3833 .76856 L .41132 .78906 L p .707 .577 .707 r
F P
0 g
s
.71084 .73519 m .71904 .77213 L .71651 .76684 L p .707 .577 .707 r
F P
0 g
s
.71651 .76684 m .7083 .7299 L .71084 .73519 L p .707 .577 .707 r
F P
0 g
s
.52973 .86862 m .52551 .85016 L .523 .84496 L p .707 .577 .707 r
F P
0 g
s
.523 .84496 m .52721 .86341 L .52973 .86862 L p .707 .577 .707 r
F P
0 g
s
.7218 .80387 m .72601 .82233 L .7235 .81713 L p .707 .577 .707 r
F P
0 g
s
.7235 .81713 m .71928 .79867 L .7218 .80387 L p .707 .577 .707 r
F P
0 g
s
.26087 .70573 m .25341 .64989 L .22252 .65226 L p .707 .577 .707 r
F P
0 g
s
.25341 .64989 m .26087 .70573 L .29245 .7011 L p .707 .577 .707 r
F P
0 g
s
.29245 .7011 m .28498 .64526 L .25341 .64989 L p .707 .577 .707 r
F P
0 g
s
.28498 .64526 m .29245 .7011 L .32163 .69467 L p .707 .577 .707 r
F P
0 g
s
.32163 .69467 m .31416 .63883 L .28498 .64526 L p .707 .577 .707 r
F P
0 g
s
.22999 .7081 m .22252 .65226 L .19535 .65214 L p .707 .577 .707 r
F P
0 g
s
.22252 .65226 m .22999 .7081 L .26087 .70573 L p .707 .577 .707 r
F P
0 g
s
.7083 .7299 m .71651 .76684 L .70448 .76402 L p .707 .577 .707 r
F P
0 g
s
.70448 .76402 m .69627 .72708 L .7083 .7299 L p .707 .577 .707 r
F P
0 g
s
.37579 .76023 m .37158 .74177 L .35534 .75029 L p .707 .577 .707 r
F P
0 g
s
.36062 .68903 m .36883 .72597 L .37603 .71873 L p .707 .577 .707 r
F P
0 g
s
.37603 .71873 m .36783 .68178 L .36062 .68903 L p .707 .577 .707 r
F P
0 g
s
.36783 .68178 m .37603 .71873 L .3735 .71344 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .36883 .72597 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34437 .69752 m .34707 .70966 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34707 .70966 m .35258 .73446 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.3682 .74388 m .36427 .72667 L .3727 .72855 L p .707 .577 .707 r
F P
0 g
s
.3727 .72855 m .37627 .72935 L p .3682 .74388 L .707 .577 .707 r
F P
0 g
s
.36849 .74513 m .3682 .74388 L p .37627 .72935 L .707 .577 .707 r
F P
0 g
s
.36427 .72667 m .36849 .74513 L .34818 .74523 L p .707 .577 .707 r
F P
0 g
s
.36688 .7484 m .51137 .28493 L .50815 .26707 L p .707 .577 .707 r
F P
0 g
s
.36883 .72597 m .36062 .68903 L .34437 .69752 L p .707 .577 .707 r
F P
0 g
s
.3735 .71344 m .36714 .68482 L p .36783 .68178 L .707 .577 .707 r
F P
0 g
s
.36714 .68482 m .36529 .67649 L .3667 .67943 L p .707 .577 .707 r
F P
0 g
s
.3667 .67943 m .36783 .68178 L p .36714 .68482 L .707 .577 .707 r
F P
0 g
s
.36529 .67649 m .3735 .71344 L .36147 .71062 L p .707 .577 .707 r
F P
0 g
s
.50815 .26707 m .36366 .73053 L .36688 .7484 L p .707 .577 .707 r
F P
0 g
s
.51845 .25326 m .41181 .59531 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.41181 .59531 m .37396 .71673 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .37018 .72179 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37018 .72179 m .36366 .73053 L p .36943 .71272 L .707 .577 .707 r
F P
0 g
s
.36943 .71272 m .51845 .25326 L .37018 .72179 L .707 .577 .707 r
F
.50815 .26707 m .51845 .25326 L p .42068 .5547 L F P
0 g
s
.36366 .73053 m .41426 .56823 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.41426 .56823 m .50815 .26707 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.37158 .74177 m .37579 .76023 L .383 .75301 L p .707 .577 .707 r
F P
0 g
s
.383 .75301 m .37879 .73456 L .37158 .74177 L p .707 .577 .707 r
F P
0 g
s
.37879 .73456 m .383 .75301 L .38049 .74781 L p .707 .577 .707 r
F P
0 g
s
.38049 .74781 m .37627 .72935 L .37879 .73456 L p .707 .577 .707 r
F P
0 g
s
.37627 .72935 m .38049 .74781 L .36849 .74513 L p .707 .577 .707 r
F P
0 g
s
.51137 .28493 m .36688 .7484 L .3833 .76856 L p .707 .577 .707 r
F P
0 g
s
.31416 .63883 m .32163 .69467 L .34555 .68705 L p .707 .577 .707 r
F P
0 g
s
.34555 .68705 m .33808 .63121 L .31416 .63883 L p .707 .577 .707 r
F P
0 g
s
.52721 .86341 m .523 .84496 L .53021 .83774 L p .707 .577 .707 r
F P
0 g
s
.26894 .75896 m .26073 .72202 L .23035 .72719 L p .707 .577 .707 r
F P
0 g
s
.26073 .72202 m .26894 .75896 L .30007 .7518 L p .707 .577 .707 r
F P
0 g
s
.30007 .7518 m .29186 .71486 L .26073 .72202 L p .707 .577 .707 r
F P
0 g
s
.29186 .71486 m .30007 .7518 L .32889 .74336 L p .707 .577 .707 r
F P
0 g
s
.32889 .74336 m .32068 .70642 L .29186 .71486 L p .707 .577 .707 r
F P
0 g
s
.53021 .83774 m .53442 .8562 L .52721 .86341 L p .707 .577 .707 r
F P
0 g
s
.19535 .65214 m .20281 .70798 L .22999 .7081 L p .707 .577 .707 r
F P
0 g
s
.71928 .79867 m .7235 .81713 L .7115 .81444 L p .707 .577 .707 r
F P
0 g
s
.7115 .81444 m .70728 .79599 L .71928 .79867 L p .707 .577 .707 r
F P
0 g
s
.23035 .72719 m .23855 .76414 L .26894 .75896 L p .707 .577 .707 r
F P
0 g
s
.20281 .70798 m .19535 .65214 L .17455 .64953 L p .707 .577 .707 r
F P
0 g
s
.23855 .76414 m .23035 .72719 L .20367 .72987 L p .707 .577 .707 r
F P
0 g
s
.276 .79364 m .27179 .77519 L .24144 .78055 L p .707 .577 .707 r
F P
0 g
s
.27179 .77519 m .276 .79364 L .30709 .78631 L p .707 .577 .707 r
F P
0 g
s
.30709 .78631 m .30288 .76786 L .27179 .77519 L p .707 .577 .707 r
F P
0 g
s
.30288 .76786 m .30709 .78631 L .33588 .77773 L p .707 .577 .707 r
F P
0 g
s
.33588 .77773 m .33167 .75928 L .30288 .76786 L p .707 .577 .707 r
F P
0 g
s
.32068 .70642 m .32889 .74336 L .35258 .73446 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .34437 .69752 L .32068 .70642 L p .707 .577 .707 r
F P
0 g
s
.24144 .78055 m .24566 .79901 L .276 .79364 L p .707 .577 .707 r
F P
0 g
s
.20367 .72987 m .21188 .76682 L .23855 .76414 L p .707 .577 .707 r
F P
0 g
s
.33808 .63121 m .34555 .68705 L .36187 .67901 L p .707 .577 .707 r
F P
0 g
s
.36187 .67901 m .35441 .62317 L .33808 .63121 L p .707 .577 .707 r
F P
0 g
s
.24566 .79901 m .24144 .78055 L .21481 .78343 L p .707 .577 .707 r
F P
0 g
s
.17455 .64953 m .18202 .70537 L .20281 .70798 L p .707 .577 .707 r
F P
0 g
s
.69627 .72708 m .70448 .76402 L .68413 .76395 L p .707 .577 .707 r
F P
0 g
s
.21481 .78343 m .21903 .80188 L .24566 .79901 L p .707 .577 .707 r
F P
0 g
s
.33167 .75928 m .33588 .77773 L .35955 .76874 L p .707 .577 .707 r
F P
0 g
s
.35955 .76874 m .35534 .75029 L .33167 .75928 L p .707 .577 .707 r
F P
0 g
s
.21188 .76682 m .20367 .72987 L .18332 .7298 L p .707 .577 .707 r
F P
0 g
s
.18202 .70537 m .17455 .64953 L .16216 .64471 L p .707 .577 .707 r
F P
0 g
s
.18332 .7298 m .19153 .76674 L .21188 .76682 L p .707 .577 .707 r
F P
0 g
s
.21903 .80188 m .21481 .78343 L .1945 .78353 L p .707 .577 .707 r
F P
0 g
s
.70728 .79599 m .7115 .81444 L .69119 .81454 L p .707 .577 .707 r
F P
0 g
s
.69119 .81454 m .68697 .79609 L .70728 .79599 L p .707 .577 .707 r
F P
0 g
s
.1945 .78353 m .19872 .80198 L .21903 .80188 L p .707 .577 .707 r
F P
0 g
s
.35534 .75029 m .35955 .76874 L .37579 .76023 L p .707 .577 .707 r
F P
0 g
s
.35441 .62317 m .36187 .67901 L .369 .67132 L p .707 .577 .707 r
F P
0 g
s
.369 .67132 m .36153 .61548 L .35441 .62317 L p .707 .577 .707 r
F P
0 g
s
.16216 .64471 m .16963 .70055 L .18202 .70537 L p .707 .577 .707 r
F P
0 g
s
.19153 .76674 m .18332 .7298 L .17129 .72698 L p .707 .577 .707 r
F P
0 g
s
.17129 .72698 m .1795 .76392 L .19153 .76674 L p .707 .577 .707 r
F P
0 g
s
.19872 .80198 m .1945 .78353 L .1825 .78084 L p .707 .577 .707 r
F P
0 g
s
.16963 .70055 m .16216 .64471 L .1594 .63813 L p .707 .577 .707 r
F P
0 g
s
.68697 .79609 m .69119 .81454 L .66456 .81742 L p .707 .577 .707 r
F P
0 g
s
.66456 .81742 m .66034 .79896 L .68697 .79609 L p .707 .577 .707 r
F P
0 g
s
.1825 .78084 m .18672 .7993 L .19872 .80198 L p .707 .577 .707 r
F P
0 g
s
.36153 .61548 m .369 .67132 L .36623 .66474 L p .707 .577 .707 r
F P
0 g
s
.36623 .66474 m .35877 .6089 L .36153 .61548 L p .707 .577 .707 r
F P
0 g
s
.1594 .63813 m .16686 .69397 L .16963 .70055 L p .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .51845 .25326 L .54126 .24486 L p .707 .577 .707 r
F P
0 g
s
.66034 .79896 m .66456 .81742 L .63421 .82278 L p .707 .577 .707 r
F P
0 g
s
.1795 .76392 m .17129 .72698 L .16876 .72169 L p .707 .577 .707 r
F P
0 g
s
.16876 .72169 m .17696 .75863 L .1795 .76392 L p .707 .577 .707 r
F P
0 g
s
.18672 .7993 m .1825 .78084 L .17999 .77564 L p .707 .577 .707 r
F P
0 g
s
.16686 .69397 m .1594 .63813 L .16653 .63044 L p .707 .577 .707 r
F P
0 g
s
.17999 .77564 m .1842 .7941 L .18672 .7993 L p .707 .577 .707 r
F P
0 g
s
.35877 .6089 m .36623 .66474 L .35385 .65992 L p .707 .577 .707 r
F P
0 g
s
.35385 .65992 m .34638 .60407 L .35877 .6089 L p .707 .577 .707 r
F P
0 g
s
.16653 .63044 m .17399 .68628 L .16686 .69397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17696 .75863 m .16876 .72169 L .17596 .71444 L p .707 .577 .707 r
F P
0 g
s
.54126 .24486 m .39677 .70832 L .37396 .71673 L p .707 .577 .707 r
F P
0 g
s
.39677 .70832 m .54126 .24486 L .57435 .24268 L p .707 .577 .707 r
F P
0 g
s
.17596 .71444 m .18417 .75139 L .17696 .75863 L p .707 .577 .707 r
F P
0 g
s
.36147 .71062 m .35326 .67367 L .36529 .67649 L p .707 .577 .707 r
F P
0 g
s
.1842 .7941 m .17999 .77564 L .1872 .76843 L p .707 .577 .707 r
F P
0 g
s
.17399 .68628 m .16653 .63044 L .18285 .62239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1872 .76843 m .19141 .78688 L .1842 .7941 L p .707 .577 .707 r
F P
0 g
s
.34638 .60407 m .35385 .65992 L .33305 .65731 L p .707 .577 .707 r
F P
0 g
s
.33305 .65731 m .32558 .60147 L .34638 .60407 L p .707 .577 .707 r
F P
0 g
s
.18285 .62239 m .19031 .67824 L .17399 .68628 L p .707 .577 .707 r
F P
0 g
s
.18417 .75139 m .17596 .71444 L .19221 .70596 L p .707 .577 .707 r
F P
0 g
s
.42985 .70615 m .57435 .24268 L .61448 .24695 L p .707 .577 .707 r
F P
0 g
s
.57435 .24268 m .42985 .70615 L .39677 .70832 L p .707 .577 .707 r
F P
0 g
s
.19031 .67824 m .18285 .62239 L .20677 .61478 L p .707 .577 .707 r
F P
0 g
s
.19221 .70596 m .20042 .7429 L .18417 .75139 L p .707 .577 .707 r
F P
0 g
s
.35326 .67367 m .36147 .71062 L .34112 .71054 L p .707 .577 .707 r
F P
0 g
s
.34112 .71054 m .33291 .6736 L .35326 .67367 L p .707 .577 .707 r
F P
0 g
s
.55534 .73602 m .69983 .27255 L .73671 .29137 L p .707 .577 .707 r
F P
0 g
s
.19141 .78688 m .1872 .76843 L .20344 .75991 L p .707 .577 .707 r
F P
0 g
s
.20344 .75991 m .20765 .77837 L .19141 .78688 L p .707 .577 .707 r
F P
0 g
s
.32558 .60147 m .33305 .65731 L .30588 .65719 L p .707 .577 .707 r
F P
0 g
s
.30588 .65719 m .29841 .60135 L .32558 .60147 L p .707 .577 .707 r
F P
0 g
s
.34818 .74523 m .34397 .72677 L .36427 .72667 L p .707 .577 .707 r
F P
0 g
s
.20677 .61478 m .21424 .67062 L .19031 .67824 L p .707 .577 .707 r
F P
0 g
s
.46998 .71042 m .61448 .24695 L .65771 .25724 L p .707 .577 .707 r
F P
0 g
s
.61448 .24695 m .46998 .71042 L .42985 .70615 L p .707 .577 .707 r
F P
0 g
s
.20042 .7429 m .19221 .70596 L .2159 .69706 L p .707 .577 .707 r
F P
0 g
s
.21424 .67062 m .20677 .61478 L .23595 .60835 L p .707 .577 .707 r
F P
0 g
s
.69983 .27255 m .55534 .73602 L .51322 .72071 L p .707 .577 .707 r
F P
0 g
s
.51322 .72071 m .65771 .25724 L .69983 .27255 L p .707 .577 .707 r
F P
0 g
s
.29841 .60135 m .30588 .65719 L .27499 .65956 L p .707 .577 .707 r
F P
0 g
s
.27499 .65956 m .26753 .60372 L .29841 .60135 L p .707 .577 .707 r
F P
0 g
s
.33291 .6736 m .34112 .71054 L .31444 .71323 L p .707 .577 .707 r
F P
0 g
s
.31444 .71323 m .30624 .67628 L .33291 .6736 L p .707 .577 .707 r
F P
0 g
s
.65771 .25724 m .51322 .72071 L .46998 .71042 L p .707 .577 .707 r
F P
0 g
s
.2159 .69706 m .22411 .734 L .20042 .7429 L p .707 .577 .707 r
F P
0 g
s
.20765 .77837 m .20344 .75991 L .22711 .75092 L p .707 .577 .707 r
F P
0 g
s
.24341 .66419 m .23595 .60835 L .26753 .60372 L p .707 .577 .707 r
F P
0 g
s
.23595 .60835 m .24341 .66419 L .21424 .67062 L p .707 .577 .707 r
F P
0 g
s
.26753 .60372 m .27499 .65956 L .24341 .66419 L p .707 .577 .707 r
F P
0 g
s
.22711 .75092 m .23133 .76938 L .20765 .77837 L p .707 .577 .707 r
F P
0 g
s
.74108 .65705 m .73362 .60121 L .70273 .60358 L p .707 .577 .707 r
F P
0 g
s
.73362 .60121 m .74108 .65705 L .77266 .65242 L p .707 .577 .707 r
F P
0 g
s
.77266 .65242 m .7652 .59658 L .73362 .60121 L p .707 .577 .707 r
F P
0 g
s
.34397 .72677 m .34818 .74523 L .32155 .7481 L p .707 .577 .707 r
F P
0 g
s
.32155 .7481 m .31734 .72964 L .34397 .72677 L p .707 .577 .707 r
F P
0 g
s
.7652 .59658 m .77266 .65242 L .80184 .64599 L p .707 .577 .707 r
F P
0 g
s
.80184 .64599 m .79437 .59015 L .7652 .59658 L p .707 .577 .707 r
F P
0 g
s
.22411 .734 m .2159 .69706 L .24472 .68861 L p .707 .577 .707 r
F P
0 g
s
.70273 .60358 m .7102 .65942 L .74108 .65705 L p .707 .577 .707 r
F P
0 g
s
.30624 .67628 m .31444 .71323 L .28406 .7184 L p .707 .577 .707 r
F P
0 g
s
.28406 .7184 m .27585 .68145 L .30624 .67628 L p .707 .577 .707 r
F P
0 g
s
.24472 .68861 m .25293 .72556 L .22411 .734 L p .707 .577 .707 r
F P
0 g
s
.79437 .59015 m .80184 .64599 L .82576 .63837 L p .707 .577 .707 r
F P
0 g
s
.82576 .63837 m .8183 .58253 L .79437 .59015 L p .707 .577 .707 r
F P
0 g
s
.23133 .76938 m .22711 .75092 L .2559 .74234 L p .707 .577 .707 r
F P
0 g
s
.25293 .72556 m .24472 .68861 L .27585 .68145 L p .707 .577 .707 r
F P
0 g
s
.27585 .68145 m .28406 .7184 L .25293 .72556 L p .707 .577 .707 r
F P
0 g
s
.2559 .74234 m .26011 .7608 L .23133 .76938 L p .707 .577 .707 r
F P
0 g
s
.31734 .72964 m .32155 .7481 L .2912 .75346 L p .707 .577 .707 r
F P
0 g
s
.2912 .75346 m .28699 .73501 L .31734 .72964 L p .707 .577 .707 r
F P
0 g
s
.74915 .72033 m .74095 .68338 L .71056 .68856 L p .707 .577 .707 r
F P
0 g
s
.74095 .68338 m .74915 .72033 L .78028 .71317 L p .707 .577 .707 r
F P
0 g
s
.78028 .71317 m .77207 .67622 L .74095 .68338 L p .707 .577 .707 r
F P
0 g
s
.77207 .67622 m .78028 .71317 L .8091 .70473 L p .707 .577 .707 r
F P
0 g
s
.8091 .70473 m .8009 .66778 L .77207 .67622 L p .707 .577 .707 r
F P
0 g
s
.26011 .7608 m .2559 .74234 L .28699 .73501 L p .707 .577 .707 r
F P
0 g
s
.71056 .68856 m .71877 .7255 L .74915 .72033 L p .707 .577 .707 r
F P
0 g
s
.28699 .73501 m .2912 .75346 L .26011 .7608 L p .707 .577 .707 r
F P
0 g
s
.71877 .7255 m .71056 .68856 L .68389 .69124 L p .707 .577 .707 r
F P
0 g
s
.8009 .66778 m .8091 .70473 L .83279 .69582 L p .707 .577 .707 r
F P
0 g
s
.83279 .69582 m .82459 .65888 L .8009 .66778 L p .707 .577 .707 r
F P
0 g
s
.8183 .58253 m .82576 .63837 L .84209 .63033 L p .707 .577 .707 r
F P
0 g
s
.84209 .63033 m .83462 .57449 L .8183 .58253 L p .707 .577 .707 r
F P
0 g
s
.75621 .77092 m .752 .75247 L .72166 .75783 L p .707 .577 .707 r
F P
0 g
s
.752 .75247 m .75621 .77092 L .7873 .76359 L p .707 .577 .707 r
F P
0 g
s
.7873 .76359 m .78309 .74514 L .752 .75247 L p .707 .577 .707 r
F P
0 g
s
.68389 .69124 m .69209 .72818 L .71877 .7255 L p .707 .577 .707 r
F P
0 g
s
.78309 .74514 m .7873 .76359 L .81609 .75501 L p .707 .577 .707 r
F P
0 g
s
.81609 .75501 m .81188 .73656 L .78309 .74514 L p .707 .577 .707 r
F P
0 g
s
.72166 .75783 m .72587 .77629 L .75621 .77092 L p .707 .577 .707 r
F P
0 g
s
.72587 .77629 m .72166 .75783 L .69503 .7607 L p .707 .577 .707 r
F P
0 g
s
.69503 .7607 m .69924 .77916 L .72587 .77629 L p .707 .577 .707 r
F P
0 g
s
.81188 .73656 m .81609 .75501 L .83977 .74602 L p .707 .577 .707 r
F P
0 g
s
.83977 .74602 m .83555 .72757 L .81188 .73656 L p .707 .577 .707 r
F P
0 g
s
.82459 .65888 m .83279 .69582 L .84904 .68734 L p .707 .577 .707 r
F P
0 g
s
.84904 .68734 m .84083 .65039 L .82459 .65888 L p .707 .577 .707 r
F P
0 g
s
.83462 .57449 m .84209 .63033 L .84921 .62264 L p .707 .577 .707 r
F P
0 g
s
.84921 .62264 m .84175 .5668 L .83462 .57449 L p .707 .577 .707 r
F P
0 g
s
.69924 .77916 m .69503 .7607 L .67472 .7608 L p .707 .577 .707 r
F P
0 g
s
.67472 .7608 m .67893 .77926 L .69924 .77916 L p .707 .577 .707 r
F P
0 g
s
.83555 .72757 m .83977 .74602 L .856 .7375 L p .707 .577 .707 r
F P
0 g
s
.856 .7375 m .85179 .71905 L .83555 .72757 L p .707 .577 .707 r
F P
0 g
s
.84083 .65039 m .84904 .68734 L .85625 .68009 L p .707 .577 .707 r
F P
0 g
s
.85625 .68009 m .84804 .64315 L .84083 .65039 L p .707 .577 .707 r
F P
0 g
s
.67893 .77926 m .67472 .7608 L .66272 .75812 L p .707 .577 .707 r
F P
0 g
s
.66272 .75812 m .66693 .77658 L .67893 .77926 L p .707 .577 .707 r
F P
0 g
s
.84175 .5668 m .84921 .62264 L .84645 .61606 L p .707 .577 .707 r
F P
0 g
s
.84645 .61606 m .83898 .56022 L .84175 .5668 L p .707 .577 .707 r
F P
0 g
s
.63961 .58945 m .64708 .64529 L .64984 .65187 L p .707 .577 .707 r
F P
0 g
s
.85179 .71905 m .856 .7375 L .86322 .73029 L p .707 .577 .707 r
F P
0 g
s
.86322 .73029 m .859 .71183 L .85179 .71905 L p .707 .577 .707 r
F P
0 g
s
.65971 .72529 m .65151 .68834 L .64897 .68305 L p .707 .577 .707 r
F P
0 g
s
.64897 .68305 m .65718 .72 L .65971 .72529 L p .707 .577 .707 r
F P
0 g
s
.84804 .64315 m .85625 .68009 L .85371 .6748 L p .707 .577 .707 r
F P
0 g
s
.85371 .6748 m .8455 .63786 L .84804 .64315 L p .707 .577 .707 r
F P
0 g
s
.64708 .64529 m .63961 .58945 L .64674 .58176 L p .707 .577 .707 r
F P
0 g
s
.66693 .77658 m .66272 .75812 L .6602 .75292 L p .707 .577 .707 r
F P
0 g
s
.6602 .75292 m .66441 .77138 L .66693 .77658 L p .707 .577 .707 r
F P
0 g
s
.83898 .56022 m .84645 .61606 L .83406 .61124 L p .707 .577 .707 r
F P
0 g
s
.83406 .61124 m .8266 .55539 L .83898 .56022 L p .707 .577 .707 r
F P
0 g
s
.64674 .58176 m .6542 .6376 L .64708 .64529 L p .707 .577 .707 r
F P
0 g
s
.859 .71183 m .86322 .73029 L .8607 .72509 L p .707 .577 .707 r
F P
0 g
s
.8607 .72509 m .85649 .70663 L .859 .71183 L p .707 .577 .707 r
F P
0 g
s
.39807 .61369 m .39061 .55785 L .35972 .56022 L p .707 .577 .707 r
F P
0 g
s
.39061 .55785 m .39807 .61369 L .42965 .60906 L p .707 .577 .707 r
F P
0 g
s
.42965 .60906 m .42219 .55322 L .39061 .55785 L p .707 .577 .707 r
F P
0 g
s
.65718 .72 m .64897 .68305 L .65618 .67581 L p .707 .577 .707 r
F P
0 g
s
.42219 .55322 m .42965 .60906 L .45883 .60263 L p .707 .577 .707 r
F P
0 g
s
.45883 .60263 m .45136 .54679 L .42219 .55322 L p .707 .577 .707 r
F P
0 g
s
.65618 .67581 m .66438 .71275 L .65718 .72 L p .707 .577 .707 r
F P
0 g
s
.36719 .61606 m .35972 .56022 L .33255 .5601 L p .707 .577 .707 r
F P
0 g
s
.35972 .56022 m .36719 .61606 L .39807 .61369 L p .707 .577 .707 r
F P
0 g
s
.6542 .6376 m .64674 .58176 L .66306 .57371 L p .707 .577 .707 r
F P
0 g
s
.8455 .63786 m .85371 .6748 L .84168 .67198 L p .707 .577 .707 r
F P
0 g
s
.84168 .67198 m .83347 .63504 L .8455 .63786 L p .707 .577 .707 r
F P
0 g
s
.45136 .54679 m .45883 .60263 L .48275 .59502 L p .707 .577 .707 r
F P
0 g
s
.48275 .59502 m .47529 .53917 L .45136 .54679 L p .707 .577 .707 r
F P
0 g
s
.66441 .77138 m .6602 .75292 L .66742 .74571 L p .707 .577 .707 r
F P
0 g
s
.40614 .66692 m .39794 .62998 L .36755 .63515 L p .707 .577 .707 r
F P
0 g
s
.39794 .62998 m .40614 .66692 L .43727 .65977 L p .707 .577 .707 r
F P
0 g
s
.43727 .65977 m .42906 .62282 L .39794 .62998 L p .707 .577 .707 r
F P
0 g
s
.42906 .62282 m .43727 .65977 L .46609 .65132 L p .707 .577 .707 r
F P
0 g
s
.46609 .65132 m .45789 .61438 L .42906 .62282 L p .707 .577 .707 r
F P
0 g
s
.66742 .74571 m .67163 .76416 L .66441 .77138 L p .707 .577 .707 r
F P
0 g
s
.8266 .55539 m .83406 .61124 L .81326 .60863 L p .707 .577 .707 r
F P
0 g
s
.81326 .60863 m .8058 .55279 L .8266 .55539 L p .707 .577 .707 r
F P
0 g
s
.33255 .5601 m .34002 .61594 L .36719 .61606 L p .707 .577 .707 r
F P
0 g
s
.66306 .57371 m .67053 .62956 L .6542 .6376 L p .707 .577 .707 r
F P
0 g
s
.85649 .70663 m .8607 .72509 L .8487 .72241 L p .707 .577 .707 r
F P
0 g
s
.8487 .72241 m .84449 .70395 L .85649 .70663 L p .707 .577 .707 r
F P
0 g
s
.36755 .63515 m .37576 .6721 L .40614 .66692 L p .707 .577 .707 r
F P
0 g
s
.34002 .61594 m .33255 .5601 L .31175 .55749 L p .707 .577 .707 r
F P
0 g
s
.37576 .6721 m .36755 .63515 L .34088 .63783 L p .707 .577 .707 r
F P
0 g
s
.4132 .70161 m .40899 .68315 L .37865 .68851 L p .707 .577 .707 r
F P
0 g
s
.40899 .68315 m .4132 .70161 L .44429 .69428 L p .707 .577 .707 r
F P
0 g
s
.44429 .69428 m .44008 .67582 L .40899 .68315 L p .707 .577 .707 r
F P
0 g
s
.44008 .67582 m .44429 .69428 L .47308 .68569 L p .707 .577 .707 r
F P
0 g
s
.47308 .68569 m .46887 .66724 L .44008 .67582 L p .707 .577 .707 r
F P
0 g
s
.45789 .61438 m .46609 .65132 L .48978 .64242 L p .707 .577 .707 r
F P
0 g
s
.48978 .64242 m .48158 .60548 L .45789 .61438 L p .707 .577 .707 r
F P
0 g
s
.37865 .68851 m .38286 .70697 L .4132 .70161 L p .707 .577 .707 r
F P
0 g
s
.66438 .71275 m .65618 .67581 L .67242 .66732 L p .707 .577 .707 r
F P
0 g
s
.34088 .63783 m .34908 .67478 L .37576 .6721 L p .707 .577 .707 r
F P
0 g
s
.47529 .53917 m .48275 .59502 L .49908 .58697 L p .707 .577 .707 r
F P
0 g
s
.49908 .58697 m .49161 .53113 L .47529 .53917 L p .707 .577 .707 r
F P
0 g
s
.67053 .62956 m .66306 .57371 L .68698 .5661 L p .707 .577 .707 r
F P
0 g
s
.38286 .70697 m .37865 .68851 L .35202 .69139 L p .707 .577 .707 r
F P
0 g
s
.31175 .55749 m .31922 .61334 L .34002 .61594 L p .707 .577 .707 r
F P
0 g
s
.67242 .66732 m .68063 .70426 L .66438 .71275 L p .707 .577 .707 r
F P
0 g
s
.83347 .63504 m .84168 .67198 L .82133 .67191 L p .707 .577 .707 r
F P
0 g
s
.82133 .67191 m .81313 .63496 L .83347 .63504 L p .707 .577 .707 r
F P
0 g
s
.35202 .69139 m .35623 .70984 L .38286 .70697 L p .707 .577 .707 r
F P
0 g
s
.46887 .66724 m .47308 .68569 L .49676 .67671 L p .707 .577 .707 r
F P
0 g
s
.49676 .67671 m .49254 .65825 L .46887 .66724 L p .707 .577 .707 r
F P
0 g
s
.34908 .67478 m .34088 .63783 L .32053 .63776 L p .707 .577 .707 r
F P
0 g
s
.8058 .55279 m .81326 .60863 L .78609 .60851 L p .707 .577 .707 r
F P
0 g
s
.78609 .60851 m .77863 .55267 L .8058 .55279 L p .707 .577 .707 r
F P
0 g
s
.67163 .76416 m .66742 .74571 L .68365 .73719 L p .707 .577 .707 r
F P
0 g
s
.68698 .5661 m .69445 .62194 L .67053 .62956 L p .707 .577 .707 r
F P
0 g
s
.48158 .60548 m .48978 .64242 L .50603 .63393 L p .707 .577 .707 r
F P
0 g
s
.50603 .63393 m .49782 .59699 L .48158 .60548 L p .707 .577 .707 r
F P
0 g
s
.31922 .61334 m .31175 .55749 L .29937 .55267 L p .707 .577 .707 r
F P
0 g
s
.68365 .73719 m .68787 .75564 L .67163 .76416 L p .707 .577 .707 r
F P
0 g
s
.32053 .63776 m .32873 .6747 L .34908 .67478 L p .707 .577 .707 r
F P
0 g
s
.35623 .70984 m .35202 .69139 L .33171 .69149 L p .707 .577 .707 r
F P
0 g
s
.84449 .70395 m .8487 .72241 L .82839 .72251 L p .707 .577 .707 r
F P
0 g
s
.82839 .72251 m .82418 .70405 L .84449 .70395 L p .707 .577 .707 r
F P
0 g
s
.69445 .62194 m .68698 .5661 L .71616 .55967 L p .707 .577 .707 r
F P
0 g
s
.33171 .69149 m .33592 .70994 L .35623 .70984 L p .707 .577 .707 r
F P
0 g
s
.68063 .70426 m .67242 .66732 L .69612 .65842 L p .707 .577 .707 r
F P
0 g
s
.49254 .65825 m .49676 .67671 L .51299 .66819 L p .707 .577 .707 r
F P
0 g
s
.51299 .66819 m .50878 .64973 L .49254 .65825 L p .707 .577 .707 r
F P
0 g
s
.49161 .53113 m .49908 .58697 L .5062 .57928 L p .707 .577 .707 r
F P
0 g
s
.5062 .57928 m .49874 .52344 L .49161 .53113 L p .707 .577 .707 r
F P
0 g
s
.77863 .55267 m .78609 .60851 L .75521 .61088 L p .707 .577 .707 r
F P
0 g
s
.75521 .61088 m .74774 .55504 L .77863 .55267 L p .707 .577 .707 r
F P
0 g
s
.29937 .55267 m .30683 .60851 L .31922 .61334 L p .707 .577 .707 r
F P
0 g
s
.81313 .63496 m .82133 .67191 L .79466 .67459 L p .707 .577 .707 r
F P
0 g
s
.79466 .67459 m .78645 .63765 L .81313 .63496 L p .707 .577 .707 r
F P
0 g
s
.69612 .65842 m .70432 .69536 L .68063 .70426 L p .707 .577 .707 r
F P
0 g
s
.72363 .61551 m .71616 .55967 L .74774 .55504 L p .707 .577 .707 r
F P
0 g
s
.71616 .55967 m .72363 .61551 L .69445 .62194 L p .707 .577 .707 r
F P
0 g
s
.32873 .6747 m .32053 .63776 L .3085 .63494 L p .707 .577 .707 r
F P
0 g
s
.74774 .55504 m .75521 .61088 L .72363 .61551 L p .707 .577 .707 r
F P
0 g
s
.68787 .75564 m .68365 .73719 L .70733 .7282 L p .707 .577 .707 r
F P
0 g
s
.3085 .63494 m .3167 .67188 L .32873 .6747 L p .707 .577 .707 r
F P
0 g
s
.49782 .59699 m .50603 .63393 L .51324 .62669 L p .707 .577 .707 r
F P
0 g
s
.51324 .62669 m .50503 .58975 L .49782 .59699 L p .707 .577 .707 r
F P
0 g
s
.70733 .7282 m .71154 .74665 L .68787 .75564 L p .707 .577 .707 r
F P
0 g
s
.70432 .69536 m .69612 .65842 L .72494 .64998 L p .707 .577 .707 r
F P
0 g
s
.33592 .70994 m .33171 .69149 L .31971 .6888 L p .707 .577 .707 r
F P
0 g
s
.30683 .60851 m .29937 .55267 L .2966 .54609 L p .707 .577 .707 r
F P
0 g
s
.82418 .70405 m .82839 .72251 L .80176 .72538 L p .707 .577 .707 r
F P
0 g
s
.80176 .72538 m .79755 .70692 L .82418 .70405 L p .707 .577 .707 r
F P
0 g
s
.78645 .63765 m .79466 .67459 L .76427 .67976 L p .707 .577 .707 r
F P
0 g
s
.76427 .67976 m .75606 .64282 L .78645 .63765 L p .707 .577 .707 r
F P
0 g
s
.31971 .6888 m .32392 .70726 L .33592 .70994 L p .707 .577 .707 r
F P
0 g
s
.72494 .64998 m .73314 .68692 L .70432 .69536 L p .707 .577 .707 r
F P
0 g
s
.50878 .64973 m .51299 .66819 L .52021 .66097 L p .707 .577 .707 r
F P
0 g
s
.52021 .66097 m .51599 .64252 L .50878 .64973 L p .707 .577 .707 r
F P
0 g
s
.73314 .68692 m .72494 .64998 L .75606 .64282 L p .707 .577 .707 r
F P
0 g
s
.75606 .64282 m .76427 .67976 L .73314 .68692 L p .707 .577 .707 r
F P
0 g
s
.49874 .52344 m .5062 .57928 L .50344 .5727 L p .707 .577 .707 r
F P
0 g
s
.50344 .5727 m .49597 .51686 L .49874 .52344 L p .707 .577 .707 r
F P
0 g
s
.2966 .54609 m .30407 .60193 L .30683 .60851 L p .707 .577 .707 r
F P
0 g
s
.71154 .74665 m .70733 .7282 L .73612 .71962 L p .707 .577 .707 r
F P
0 g
s
.73612 .71962 m .74033 .73807 L .71154 .74665 L p .707 .577 .707 r
F P
0 g
s
.79755 .70692 m .80176 .72538 L .77142 .73074 L p .707 .577 .707 r
F P
0 g
s
.77142 .73074 m .7672 .71229 L .79755 .70692 L p .707 .577 .707 r
F P
0 g
s
.3167 .67188 m .3085 .63494 L .30596 .62965 L p .707 .577 .707 r
F P
0 g
s
.74033 .73807 m .73612 .71962 L .7672 .71229 L p .707 .577 .707 r
F P
0 g
s
.7672 .71229 m .77142 .73074 L .74033 .73807 L p .707 .577 .707 r
F P
0 g
s
.30596 .62965 m .31417 .66659 L .3167 .67188 L p .707 .577 .707 r
F P
0 g
s
.50503 .58975 m .51324 .62669 L .5107 .6214 L p .707 .577 .707 r
F P
0 g
s
.5107 .6214 m .50249 .58445 L .50503 .58975 L p .707 .577 .707 r
F P
0 g
s
.32392 .70726 m .31971 .6888 L .31719 .6836 L p .707 .577 .707 r
F P
0 g
s
.30407 .60193 m .2966 .54609 L .30373 .5384 L p .707 .577 .707 r
F P
0 g
s
.31719 .6836 m .3214 .70206 L .32392 .70726 L p .707 .577 .707 r
F P
0 g
s
.51599 .64252 m .52021 .66097 L .51769 .65577 L p .707 .577 .707 r
F P
0 g
s
.51769 .65577 m .51348 .63731 L .51599 .64252 L p .707 .577 .707 r
F P
0 g
s
.49597 .51686 m .50344 .5727 L .49105 .56788 L p .707 .577 .707 r
F P
0 g
s
.49105 .56788 m .48359 .51204 L .49597 .51686 L p .707 .577 .707 r
F P
0 g
s
.30373 .5384 m .31119 .59424 L .30407 .60193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31417 .66659 m .30596 .62965 L .31317 .62241 L p .707 .577 .707 r
F P
0 g
s
.31317 .62241 m .32137 .65935 L .31417 .66659 L p .707 .577 .707 r
F P
0 g
s
.50249 .58445 m .5107 .6214 L .49867 .61858 L p .707 .577 .707 r
F P
0 g
s
.49867 .61858 m .49046 .58163 L .50249 .58445 L p .707 .577 .707 r
F P
0 g
s
.3214 .70206 m .31719 .6836 L .3244 .67639 L p .707 .577 .707 r
F P
0 g
s
.31119 .59424 m .30373 .5384 L .32005 .53036 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3244 .67639 m .32862 .69485 L .3214 .70206 L p .707 .577 .707 r
F P
0 g
s
.51348 .63731 m .51769 .65577 L .50569 .65309 L p .707 .577 .707 r
F P
0 g
s
.50569 .65309 m .50148 .63463 L .51348 .63731 L p .707 .577 .707 r
F P
0 g
s
.48359 .51204 m .49105 .56788 L .47025 .56527 L p .707 .577 .707 r
F P
0 g
s
.47025 .56527 m .46279 .50943 L .48359 .51204 L p .707 .577 .707 r
F P
0 g
s
.32005 .53036 m .32752 .5862 L .31119 .59424 L p .707 .577 .707 r
F P
0 g
s
.32137 .65935 m .31317 .62241 L .32941 .61392 L p .707 .577 .707 r
F P
0 g
s
.32752 .5862 m .32005 .53036 L .34397 .52274 L p .707 .577 .707 r
F P
0 g
s
.32941 .61392 m .33762 .65086 L .32137 .65935 L p .707 .577 .707 r
F P
0 g
s
.49046 .58163 m .49867 .61858 L .47832 .61851 L p .707 .577 .707 r
F P
0 g
s
.47832 .61851 m .47012 .58156 L .49046 .58163 L p .707 .577 .707 r
F P
0 g
s
.32862 .69485 m .3244 .67639 L .34064 .66787 L p .707 .577 .707 r
F P
0 g
s
.34064 .66787 m .34486 .68633 L .32862 .69485 L p .707 .577 .707 r
F P
0 g
s
.46279 .50943 m .47025 .56527 L .44308 .56515 L p .707 .577 .707 r
F P
0 g
s
.44308 .56515 m .43562 .50931 L .46279 .50943 L p .707 .577 .707 r
F P
0 g
s
.50148 .63463 m .50569 .65309 L .48538 .65319 L p .707 .577 .707 r
F P
0 g
s
.48538 .65319 m .48117 .63473 L .50148 .63463 L p .707 .577 .707 r
F P
0 g
s
.34397 .52274 m .35144 .57858 L .32752 .5862 L p .707 .577 .707 r
F P
0 g
s
.33762 .65086 m .32941 .61392 L .3531 .60502 L p .707 .577 .707 r
F P
0 g
s
.35144 .57858 m .34397 .52274 L .37315 .51631 L p .707 .577 .707 r
F P
0 g
s
.43562 .50931 m .44308 .56515 L .41219 .56752 L p .707 .577 .707 r
F P
0 g
s
.41219 .56752 m .40473 .51168 L .43562 .50931 L p .707 .577 .707 r
F P
0 g
s
.47012 .58156 m .47832 .61851 L .45165 .62119 L p .707 .577 .707 r
F P
0 g
s
.45165 .62119 m .44344 .58424 L .47012 .58156 L p .707 .577 .707 r
F P
0 g
s
.3531 .60502 m .36131 .64196 L .33762 .65086 L p .707 .577 .707 r
F P
0 g
s
.34486 .68633 m .34064 .66787 L .36432 .65888 L p .707 .577 .707 r
F P
0 g
s
.38062 .57215 m .37315 .51631 L .40473 .51168 L p .707 .577 .707 r
F P
0 g
s
.37315 .51631 m .38062 .57215 L .35144 .57858 L p .707 .577 .707 r
F P
0 g
s
.40473 .51168 m .41219 .56752 L .38062 .57215 L p .707 .577 .707 r
F P
0 g
s
.36432 .65888 m .36853 .67734 L .34486 .68633 L p .707 .577 .707 r
F P
0 g
s
.48117 .63473 m .48538 .65319 L .45875 .65606 L p .707 .577 .707 r
F P
0 g
s
.45875 .65606 m .45454 .6376 L .48117 .63473 L p .707 .577 .707 r
F P
0 g
s
.36131 .64196 m .3531 .60502 L .38193 .59657 L p .707 .577 .707 r
F P
0 g
s
.44344 .58424 m .45165 .62119 L .42126 .62636 L p .707 .577 .707 r
F P
0 g
s
.42126 .62636 m .41305 .58942 L .44344 .58424 L p .707 .577 .707 r
F P
0 g
s
.38193 .59657 m .39013 .63352 L .36131 .64196 L p .707 .577 .707 r
F P
0 g
s
.36853 .67734 m .36432 .65888 L .39311 .6503 L p .707 .577 .707 r
F P
0 g
s
.39013 .63352 m .38193 .59657 L .41305 .58942 L p .707 .577 .707 r
F P
0 g
s
.41305 .58942 m .42126 .62636 L .39013 .63352 L p .707 .577 .707 r
F P
0 g
s
.39311 .6503 m .39732 .66876 L .36853 .67734 L p .707 .577 .707 r
F P
0 g
s
.45454 .6376 m .45875 .65606 L .42841 .66143 L p .707 .577 .707 r
F P
0 g
s
.42841 .66143 m .42419 .64297 L .45454 .6376 L p .707 .577 .707 r
F P
0 g
s
.39732 .66876 m .39311 .6503 L .42419 .64297 L p .707 .577 .707 r
F P
0 g
s
.42419 .64297 m .42841 .66143 L .39732 .66876 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
VGoo4000M7oo002GOol30009FUH00`00FUIJEP03FUH7001]Ool009Eoo`800003FUH005YF00QJEP03
001JEUYF00UJEP03001JEP0000<006Uoo`00Tgoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF1000IGoo002BOol20004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH4001QOol0095oo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEP00008005ioo`00TGoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH00eYF0`00Fgoo002@Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH3001HOol0091oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP<005Eoo`00Sgoo00<005YF000015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00@005YF000005=oo`00Sgoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH03eYF0P00
DGoo002?Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH2001?Ool008ioo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00IJEP8004eoo`00SWoo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
0P00Bgoo002>Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH2001:Ool008eoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00aJEP8004Qoo`00SGoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH00UYF00<007ooOol0AGoo002=Ool00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03
FUH00`00Oomoo`14Ool008eoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP8004Aoo`00S7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<007ooOol0@Goo002<Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH20012Ool0
08aoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP05001JEUYFFUH00010
Ool008]oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo03eoo`00RWoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0?7oo002:Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00Oomoo`0lOol008Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00=JEP8003ioo`00RGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
?Woo0029Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000nOol008Uoo`03001J
EP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0003ioo`00R7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000?Woo0028Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000oOol008Qoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0003moo`00Qgoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000?goo0027Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00gooFUH00009FUH00`00FUIJEP04FUH20010Ool008Mo
o`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00041oo`00QWoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000@7oo0026Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00010Ool008Ioo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP80045oo`00QWoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF0000@Goo0025Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00011
Ool008Eoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80049oo`00QGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000@Woo0024Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUH00012Ool008Aoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP8004=oo`00Q7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF0000@goo0023Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00013
Ool008=oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8004Aoo`00Pgoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000A7oo0022Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00014Ool0089oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP<004Aoo`00PWoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF0000AGoo0021Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00015Ool0085oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<004Eoo`00PGoo
00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000AWoo0020Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00016Ool0081oo`03001JEP0000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP<004Ioo`00P7oo00<005YF000015YF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF0000Agoo001oOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUH00017Ool007moo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0004Moo`00Ogoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000B7oo
001oOol00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00018Ool007ioo`03
001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Qoo`00OWoo00<005YF0000
15YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH004Qoo`00OWoo00<005YF000015YF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YF0000BGoo001mOol00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00019Ool007eoo`03001JEP0000AJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0004Uoo`00OGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF0000BWoo001lOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
001:Ool007aoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Yoo`00
O7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Bgoo001kOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001;Ool007]oo`03001JEP0000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004]oo`00Ngoo00<005YF000015YF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YFFUH004]oo`00N7oo3P001UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000C7oo001_Ool90003FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
001<Ool006Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000YJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00=JEP03OomJEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF001<Ool006Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001=Ool0061oo`@000IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0004eoo`00G7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001=Ool005Yoo`8000EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001>Ool005Uoo`8000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0001>Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00CWoo001FOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool005Eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0004moo`00E7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF001?Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00Cgoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001Goo6@00<Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001oo`040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000`Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001EOol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>
0003FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH002ioo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1@000UYF00@005YFFUH000]JEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
0003FUH005YF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00=JEP@00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
001JEP0]Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;Goo001EOol00`00
FUH00005FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<005YFFUH02UYF00<005YFFUH0
2UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00<005YF00001EYF00<005YF0000
0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3P0000=JEP00FUH02eYF00<0
05YFFUH02eYF00<005YFFUH02EYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo
00@005YFFUH000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEPT000=JEP03001JEUYF00=J
EP06001JEP00001JEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;7oo001EOol01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo
001FOol2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9JEP8000EJEP03001JEUYF
00EJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;7oo001FOol015YF001JEP001EYF00<005YFFUH01EYF00H005YF000005YF0009FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo001:Ool>
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00AWoo10000UYF00<005YFFUH0
1EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000oOol70006
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YF
FUH02UYF00<005YFFUH02UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH015YF6P000UYF00<007ooOol0:Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02eYF00<005YFFUH02EYF00D0
05YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00=goo0P0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YFFUIJEP/0009JEP03001JEUYF00IJEP03001JEUYF00]JEP04001JEUYF
0008FUH01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002]oo`00=Goo0P000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P001EYF00<005YFFUH00UYF1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00<goo
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00=J
EP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH01P00FUIJEP00
FUH000EJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000[Ool0035oo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD000UJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00]JEP03001JEUYF00UJEP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
;7oo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH01000FUIJEP000UYF00@005YFFUIJEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP04FUH60007FUH00`00FUIJEP06FUH00`00FUH0000:0009FUH00`00FUIJEP0:FUH01000
FUIJEP002EYF00<005YFFUH00eYF00@005YF000000]JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP/002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00P000=JEP03001JEUYF00=JEP04001JEP000006FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200000eYF001JEP0:FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH:0003FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009J
EP05001JEUYFFUH00006FUH40006FUH40003FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002eYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP03001JEUYF
00IJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0:goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF009JEP@000IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH20006FUH01000FUIJEUYF10001UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002]oo`00;Goo00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP04001JEUYFFUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP07
FUH01000FUIJEUYF2`000UYF00D005YFFUIJEP0000aJEP04001JEUYF0009FUH00`00FUIJEP04FUH2
00000eYF001JEP04FUH20006FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUH000000UYF00<005YFFUH0
1EYF0`000eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00<005YFFUH00P0000=JEP000000
0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH90005FUH00`00FUIJEP020005FUH01000FUIJEUYF0`001UYF00<005YFFUH01eYF00<0
05YFFUH010002UYF0`000eYF00@005YFFUH0009JEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEPP000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF100000=JEP00FUH00eYF0P000eYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000^Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF0P001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH015YF
0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
0P0015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002Yoo`00;Woo00<005YF00001EYF00<005YFFUH00UYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00@005YF000000MJEP03001J
EUYF00AJEPD000UJEP03001JEUYF009JEP800003FUH005YF00IJEP05001JEUYFFUH00003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH005YF0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Yo
o`00;Woo00<005YF00001EYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@000UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHD000YOol002ioo`04001JEUYF0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH900000eYF001JEP03FUH00`00FUIJEP04FUH300000goo00000005FUH00`00FUIJEP05FUH4
0007FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH3
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo000^Ool01000FUIJEP000UYF0P000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01`0015YF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP<0009oo`04001JEP00FUH40004FUH40002FUH00`00FUIJEP06FUH00`00FUH000030008FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00:Goo
000_Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000EJEP04001JEP000002FUH01@00Oomoo`00FUH02P001UYF00<005YFFUH01EYF0`00
35YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00:Woo000_Ool2FUH20005FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YF
FUH01eYF00<005YF00000UYF00@005YFFUIJEP<00004FUH005YFFUH;00000eYF001JEP08FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH01000FUIJEUYF0P00:goo000_Ool015YF001JEP001EYF00<005YFFUH01EYF
00H005YF000005YF0009FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH000080003FUH00`00
FUIJEP0500000eYF001JEP08FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP040003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000;Goo000_
Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00AJ
EP@000MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000_Ool002moo`80009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP05001JEP00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80039oo`00<7oo0P0000=JEP00FUH00eYF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00AJEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP800004FUH005YF0005FUH01000FUH000001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Aoo`00<Woo1P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@000=JEPL001EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYF0002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF4000:Goo000eOol20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP0J0005FUH00`00FUH000050002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH200001UYF001JEUYF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEP0000L000=JEP03001JEUYF00=JEP04001JEUYF000YOol003=o
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@00004FUH0
00000002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH20005FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF
1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:7oo000bOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00FUIJ
EP03FUH20003FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH70003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH00000:7oo000`Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Qoo`00;goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP<000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP8000UJEP03
001JEUYF00YJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP06
001JEP00001JEP002EYF00<005YFFUH01EYF00<005YFFUH00UYF2`0000=JEP0000009goo000_Ool0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<0
05YF00002P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF0`00
1eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF
FUH00UYF1@000eYF00<005YFFUH01eYF00<005YFFUH00UYF200017oo0`000eYF10009goo000`Ool0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`001eYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP04001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP0>0007FUH00`00FUIJEP04FUH7000:Ool200000eYF001JEP04FUH00`00FUH0000W
Ool0031oo`04001JEUYF0003FUH00`00FUIJEP04FUH40005FUH50007FUH50002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH200000eYF001JEP0;FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF100000=JEP00FUH01eYF00<005YFFUH010003goo0P000eYF00<005YFFUH00eYF0P00
:7oo000`Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP@000=JEPD000IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00IJEP<001AJEP03001JEUYF00=JEP04001JEUYF0004FUH30005
FUH00`00FUIJEP05FUH4000@Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0031oo`04001J
EUYF0004FUH01000FUH000001UYF00<005YFFUH01UYF10000UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02UYF0P0025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP<000MJEP03
001JEUYF009JEP80011oo`@00003FUH005YF00IJEP03001JEUYF008002Yoo`00<Goo00@005YFFUH0
00=JEP<000MJEP03001JEUYF009JEP@000IJEP03001JEUYF00MJEP04001JEUYFFUH:0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH40006FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUH00002000=Ool50005
FUH00`00FUIJEP05FUH3000/Ool0035oo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH50000
0eYF001JEP08FUH00`00FUIJEP04FUH60007Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH20003FUH2000=FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00EJEP03001JEUYF00=JEP<000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8002ioo`00
<Goo00<005YFFUH00P001EYF00@005YFFUIJEP@000EJEP03001JEUYF00MJEP03001JEUYF00@000]o
o`8000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00]JEP03001J
EUYF00UJEP8000EJEP800003FUH005YF00QJEP03001JEUYF00=JEP03001JEUYF00<000EJEP03001J
EP0000<00003FUH0000000Qoo`@000IJEP03001JEUYF00IJEP03001JEP0000<0031oo`00<Woo00AJ
EP00FUH000EJEP06001JEP00001JEP0025YF00<005YFFUH015YF1@002goo100000=JEP00FUH00UYF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF0P001eYF0P002EYF
00<005YFFUH01UYF00<005YF00001EYF0P000UYF00<005YFFUH00P0017oo100000=JEP00FUH01eYF
00<005YFFUH01EYF0`00=7oo000bOol01000FUIJEP001EYF0P000eYF00<005YFFUH01UYF00<005YF
FUH010003Goo0`001EYF00<005YFFUH00UYF00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00MJEP8000MJEP8000AJEP03001JEUYF0080009JEP03001J
EUYF008000AJEP03001JEUYF00H000EJEP03001JEUYF00MJEP03001JEUYF009JEP8003Moo`00<Woo
0P000UYF00<005YFFUH00P001UYF00<005YFFUH015YF10003goo0P0000=JEP00FUH01UYF00@005YF
FUIJEP800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP8000]J
EP8000EJEP03001JEUYF00=JEP03001JEUYF0080009JEP`000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008003Uoo`00<goo0P0000=JEP0000000P001eYF00<005YFFUH0100047oo0`00
0eYF00<005YFFUH01EYF00H005YF000007oo000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH2000;FUH00`00FUH00004FUH00`00FUIJEP06FUH300000eYF00000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol003Eoo`8000=JEP03001JEUYF00AJEP<0
011oo`@000IJEP03001JEUYF00AJEP<000Aoo`03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040010Ool0
03Aoo`8000AJEP03001JEUYF009JEP8000Moo`<000Eoo`@0009JEP03001JEUYF00IJEP04001JEUYF
FUH20008Ool00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP02FUH30005FUH01000FUIJEP000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00A7oo000cOol00`00FUH00005FUH01000FUH0000027oo2@001UYF00<0
05YFFUH01UYF00@005YF000000]oo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP8000]JEP03001JEUYF00AJEP03001JEUYF00YJEP800003FUH005YF00AJEP03001JEUYF009J
EPP004Yoo`00<goo00@005YFFUH000=JEP<000Aoo`/00003FUH005YF00QJEP03001JEUYF00AJEP<0
00moo`03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000/0059oo`00<goo
00D005YFFUH005YF00T000=JEP03001JEUYF00D00003FUH005YF00QJEP03001JEUYF00@001=oo`05
001JEUYFFUH0000;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00P00Dgoo000cOol20000
0eYF00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF1@0067oo0P00
3EYF00<005YFFUH02UYF00<005YFFUH02UYF0P002eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YFFUH00UYF00<005YFFUH01EYF0`00EGoo000dOol200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP04000OOol2000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEP002UYF00<005YFFUH00eYF0P00Egoo000dOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF1@009Goo0P0025YF00<005YFFUH02eYF00<0
05YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YF
00000`00FGoo000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04000/Ool2
0006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF3P00DWoo000eOol200000eYF001JEP04FUH01000FUIJEUYF1P00<Woo
0P0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEPP000=JEP03001JEUYF00=JEP04001JEP00001@Ool003Moo`/003Yoo`80
00mJEP03001JEUYF00UJEP8000]JEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001?Ool007ioo`<000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00EJEP8000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00001?Ool0085oo`8000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF001?Ool008=o
o`8000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF009JEP/00003FUH0000004ioo`00QGoo0`0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF20001Woo0P000UYF1000CWoo0028
Ool2000>FUH00`00FUIJEP0BFUH00`00FUIJEP03FUH6000<Ool20005FUH00`00FUH0001>Ool008Yo
o`@000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`@00003FUH005YF
00AJEP8004moo`00SWoo1P0045YF00<005YFFUH01UYF00@005YFFUIJEP8000]oo`<000EJEP03001J
EUYF00=JEP03001oogoo04ioo`00U7oo1P002UYF00<005YFFUH01eYF0`002goo0P0000=JEP00FUH0
1UYF00<005YFFUH00P00DGoo002GOol200000eYF000000040008FUH6000;Ool30003FUH00`00FUIJ
EP05FUH3001COol009Ioo`03001JEUYF009JEP03001JEUYF009JEPP000eoo`@000MJEP03001JEUYF
00=JEP8005Eoo`00UGoo0P001EYF00@005YFFUIJEP8000moo`@0009JEP03001JEUYF00IJEP03001J
EP0000<005Moo`00U7oo00<005YF00001EYF00@005YF000000]oo`H000IJEP03001JEUYF00EJEP<0
05]oo`00U7oo00@005YFFUH000=JEP<000Eoo`P000=JEP03001JEUYF00MJEP03001JEUYF009JEP80
05ioo`00U7oo00D005YFFUH005YF00X000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
0080061oo`00UGoo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@006=oo`00UGoo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1000Igoo002EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6001[Ool0
09Ioo`800003FUH005YF00AJEP03001JEUYF009JEPP0075oo`00V7oo3000NGoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60388 .74909 m .59641 .69325 L .56553 .69562 L p .707 .577 .707 r
F P
0 g
s
.59641 .69325 m .60388 .74909 L .63546 .74446 L p .707 .577 .707 r
F P
0 g
s
.63546 .74446 m .62799 .68862 L .59641 .69325 L p .707 .577 .707 r
F P
0 g
s
.62799 .68862 m .63546 .74446 L .66463 .73803 L p .707 .577 .707 r
F P
0 g
s
.66463 .73803 m .65717 .68218 L .62799 .68862 L p .707 .577 .707 r
F P
0 g
s
.57299 .75146 m .56553 .69562 L .53836 .69549 L p .707 .577 .707 r
F P
0 g
s
.56553 .69562 m .57299 .75146 L .60388 .74909 L p .707 .577 .707 r
F P
0 g
s
.65717 .68218 m .66463 .73803 L .68856 .73041 L p .707 .577 .707 r
F P
0 g
s
.68856 .73041 m .68109 .67457 L .65717 .68218 L p .707 .577 .707 r
F P
0 g
s
.61195 .81236 m .60374 .77542 L .57335 .78059 L p .707 .577 .707 r
F P
0 g
s
.60374 .77542 m .61195 .81236 L .64308 .80521 L p .707 .577 .707 r
F P
0 g
s
.64308 .80521 m .63487 .76826 L .60374 .77542 L p .707 .577 .707 r
F P
0 g
s
.53836 .69549 m .54582 .75134 L .57299 .75146 L p .707 .577 .707 r
F P
0 g
s
.63487 .76826 m .64308 .80521 L .6719 .79676 L p .707 .577 .707 r
F P
0 g
s
.6719 .79676 m .66369 .75982 L .63487 .76826 L p .707 .577 .707 r
F P
0 g
s
.54582 .75134 m .53836 .69549 L .51756 .69289 L p .707 .577 .707 r
F P
0 g
s
.57335 .78059 m .58156 .81754 L .61195 .81236 L p .707 .577 .707 r
F P
0 g
s
.58156 .81754 m .57335 .78059 L .54668 .78327 L p .707 .577 .707 r
F P
0 g
s
.66369 .75982 m .6719 .79676 L .69559 .78786 L p .707 .577 .707 r
F P
0 g
s
.69559 .78786 m .68738 .75092 L .66369 .75982 L p .707 .577 .707 r
F P
0 g
s
.68109 .67457 m .68856 .73041 L .70488 .72237 L p .707 .577 .707 r
F P
0 g
s
.70488 .72237 m .69741 .66653 L .68109 .67457 L p .707 .577 .707 r
F P
0 g
s
.61901 .86296 m .6148 .8445 L .58445 .84987 L p .707 .577 .707 r
F P
0 g
s
.6148 .8445 m .61901 .86296 L .6501 .85563 L p .707 .577 .707 r
F P
0 g
s
.6501 .85563 m .64589 .83717 L .6148 .8445 L p .707 .577 .707 r
F P
0 g
s
.54668 .78327 m .55489 .82022 L .58156 .81754 L p .707 .577 .707 r
F P
0 g
s
.64589 .83717 m .6501 .85563 L .67889 .84705 L p .707 .577 .707 r
F P
0 g
s
.67889 .84705 m .67467 .82859 L .64589 .83717 L p .707 .577 .707 r
F P
0 g
s
.51756 .69289 m .52502 .74873 L .54582 .75134 L p .707 .577 .707 r
F P
0 g
s
.58445 .84987 m .58867 .86833 L .61901 .86296 L p .707 .577 .707 r
F P
0 g
s
.58867 .86833 m .58445 .84987 L .55782 .85274 L p .707 .577 .707 r
F P
0 g
s
.55489 .82022 m .54668 .78327 L .52633 .7832 L p .707 .577 .707 r
F P
0 g
s
.55782 .85274 m .56203 .8712 L .58867 .86833 L p .707 .577 .707 r
F P
0 g
s
.67467 .82859 m .67889 .84705 L .70256 .83806 L p .707 .577 .707 r
F P
0 g
s
.70256 .83806 m .69835 .8196 L .67467 .82859 L p .707 .577 .707 r
F P
0 g
s
.52502 .74873 m .51756 .69289 L .50517 .68806 L p .707 .577 .707 r
F P
0 g
s
.68738 .75092 m .69559 .78786 L .71183 .77937 L p .707 .577 .707 r
F P
0 g
s
.71183 .77937 m .70363 .74243 L .68738 .75092 L p .707 .577 .707 r
F P
0 g
s
.52633 .7832 m .53454 .82015 L .55489 .82022 L p .707 .577 .707 r
F P
0 g
s
.50517 .68806 m .51264 .74391 L .52502 .74873 L p .707 .577 .707 r
F P
0 g
s
.51264 .74391 m .50517 .68806 L .50241 .68148 L p .707 .577 .707 r
F P
0 g
s
.50241 .68148 m .50987 .73733 L .51264 .74391 L p .707 .577 .707 r
F P
0 g
s
.50987 .73733 m .50241 .68148 L .50953 .6738 L p .707 .577 .707 r
F P
0 g
s
.50953 .6738 m .517 .72964 L .50987 .73733 L p .707 .577 .707 r
F P
0 g
s
.517 .72964 m .50953 .6738 L .52586 .66575 L p .707 .577 .707 r
F P
0 g
s
.52586 .66575 m .53332 .72159 L .517 .72964 L p .707 .577 .707 r
F P
0 g
s
.53454 .82015 m .52633 .7832 L .5143 .78038 L p .707 .577 .707 r
F P
0 g
s
.5143 .78038 m .52251 .81733 L .53454 .82015 L p .707 .577 .707 r
F P
0 g
s
.52251 .81733 m .5143 .78038 L .51177 .77509 L p .707 .577 .707 r
F P
0 g
s
.51177 .77509 m .51997 .81203 L .52251 .81733 L p .707 .577 .707 r
F P
0 g
s
.51997 .81203 m .51177 .77509 L .51897 .76785 L p .707 .577 .707 r
F P
0 g
s
.51897 .76785 m .52718 .80479 L .51997 .81203 L p .707 .577 .707 r
F P
0 g
s
.52718 .80479 m .51897 .76785 L .53522 .75936 L p .707 .577 .707 r
F P
0 g
s
.53522 .75936 m .54343 .7963 L .52718 .80479 L p .707 .577 .707 r
F P
0 g
s
.54343 .7963 m .53522 .75936 L .55891 .75046 L p .707 .577 .707 r
F P
0 g
s
.56268 .71278 m .55725 .71398 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .63481 .35973 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.55891 .75046 m .56712 .7874 L .54343 .7963 L p .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .55891 .75046 L .57907 .74455 L p .707 .577 .707 r
F P
0 g
s
.57907 .74455 m .58773 .74201 L p .58426 .74965 L .707 .577 .707 r
F P
0 g
s
.56712 .7874 m .57907 .74455 L .58426 .74965 L .707 .577 .707 r
F
.55716 .72307 m .56872 .72068 L .56008 .70938 L F
.53356 .83349 m .56545 .7312 L p .55716 .72307 L F P
0 g
s
.56545 .7312 m .56872 .72068 L p .55716 .72307 L .707 .577 .707 r
F P
0 g
s
.56872 .72068 m .67805 .37002 L p .56008 .70938 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .5397 .66479 L p .5559 .70391 L .707 .577 .707 r
F P
0 g
s
.56008 .70938 m .63481 .35973 L .5559 .70391 L .707 .577 .707 r
F
.54978 .65814 m .57896 .65171 L p .55924 .70828 L F P
0 g
s
.55725 .71398 m .5559 .70391 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.5559 .70391 m .54978 .65814 L p .55924 .70828 L .707 .577 .707 r
F P
0 g
s
.54173 .8713 m .53751 .85284 L .52551 .85016 L p .707 .577 .707 r
F P
0 g
s
.53442 .8562 m .53021 .83774 L .54645 .82923 L p .707 .577 .707 r
F P
0 g
s
.56203 .8712 m .55782 .85274 L .53751 .85284 L p .707 .577 .707 r
F P
0 g
s
.53751 .85284 m .54173 .8713 L .56203 .8712 L p .707 .577 .707 r
F P
0 g
s
.54645 .82923 m .55066 .84768 L .53442 .8562 L p .707 .577 .707 r
F P
0 g
s
.67805 .37002 m .55961 .74992 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61665 .69281 L p .60159 .70532 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .618 .70292 L .61029 .70405 L p .707 .577 .707 r
F P
0 g
s
.61029 .70405 m .60159 .70532 L p .61665 .69281 L .707 .577 .707 r
F P
0 g
s
.64889 .70055 m .64142 .64471 L .66859 .64483 L p .707 .577 .707 r
F P
0 g
s
.64142 .64471 m .64889 .70055 L .618 .70292 L p .707 .577 .707 r
F P
0 g
s
.57012 .82024 m .57433 .83869 L .55066 .84768 L p .707 .577 .707 r
F P
0 g
s
.62707 .7718 m .61886 .73486 L .64925 .72968 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .58851 .74554 L p .61886 .73486 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .58773 .74201 L .59113 .74123 L p .707 .577 .707 r
F P
0 g
s
.59113 .74123 m .61886 .73486 L p .58851 .74554 L .707 .577 .707 r
F P
0 g
s
.61886 .73486 m .62707 .7718 L .59935 .77817 L p .707 .577 .707 r
F P
0 g
s
.59935 .77817 m .59594 .77896 L p .61755 .73738 L .707 .577 .707 r
F P
0 g
s
.61755 .73738 m .61886 .73486 L .59935 .77817 L .707 .577 .707 r
F
.67606 .70067 m .66859 .64483 L .68939 .64743 L p F P
0 g
s
.66859 .64483 m .67606 .70067 L .64889 .70055 L p .707 .577 .707 r
F P
0 g
s
.65745 .76663 m .64925 .72968 L .67592 .727 L p .707 .577 .707 r
F P
0 g
s
.64925 .72968 m .65745 .76663 L .62707 .7718 L p .707 .577 .707 r
F P
0 g
s
.63421 .82278 m .63 .80432 L .66034 .79896 L p .707 .577 .707 r
F P
0 g
s
.60312 .83011 m .59891 .81166 L .63 .80432 L p .707 .577 .707 r
F P
0 g
s
.63 .80432 m .63421 .82278 L .61681 .82689 L p .707 .577 .707 r
F P
0 g
s
.61681 .82689 m .60312 .83011 L p .62194 .81206 L .707 .577 .707 r
F P
0 g
s
.62194 .81206 m .63 .80432 L .61681 .82689 L .707 .577 .707 r
F
.69741 .66653 m .70488 .72237 L .71201 .71468 L p F P
0 g
s
.71201 .71468 m .70454 .65884 L .69741 .66653 L p .707 .577 .707 r
F P
0 g
s
.69686 .70327 m .68939 .64743 L .70178 .65226 L p .707 .577 .707 r
F P
0 g
s
.68939 .64743 m .69686 .70327 L .67606 .70067 L p .707 .577 .707 r
F P
0 g
s
.68413 .76395 m .67592 .727 L .69627 .72708 L p .707 .577 .707 r
F P
0 g
s
.69209 .72818 m .68389 .69124 L .68375 .69124 L p .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .63988 .81337 L p .74256 .4693 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .74615 .45575 L .62958 .82718 L .707 .577 .707 r
F
.74692 .4508 m .62958 .82718 L p .75537 .42638 L F P
0 g
s
.60677 .83558 m .62958 .82718 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.62958 .82718 m .77408 .36371 L .75127 .37211 L p .707 .577 .707 r
F P
0 g
s
.63988 .81337 m .78437 .3499 L .77408 .36371 L p .707 .577 .707 r
F P
0 g
s
.68346 .5896 m .60677 .83558 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.60677 .83558 m .75127 .37211 L .71818 .37429 L p .707 .577 .707 r
F P
0 g
s
.75127 .37211 m .68346 .5896 L p .70756 .53557 L .707 .577 .707 r
F P
0 g
s
.57433 .83869 m .57012 .82024 L .59891 .81166 L p .707 .577 .707 r
F P
0 g
s
.59891 .81166 m .60312 .83011 L .57433 .83869 L p .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .60677 .83558 L p .65482 .63664 L .707 .577 .707 r
F P
0 g
s
.68913 .62538 m .69234 .61692 L .67556 .60346 L .707 .577 .707 r
F
.7038 .59298 m .69234 .61692 L .78437 .3499 L F
.675 .67984 m .68002 .65644 L .69428 .6217 L F
.63666 .79551 m .67098 .68543 L p .675 .67984 L F P
0 g
s
.67098 .68543 m .68002 .65644 L p .675 .67984 L .707 .577 .707 r
F P
0 g
s
.63666 .79551 m .62847 .78545 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .68458 .64182 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.68458 .64182 m .63666 .79551 L p .68127 .64614 L .707 .577 .707 r
F P
0 g
s
.618 .70292 m .61665 .69281 L p .64142 .64471 L .707 .577 .707 r
F P
0 g
s
.61665 .69281 m .62106 .68113 L .64142 .64471 L .707 .577 .707 r
F
.63536 .64517 m .64142 .64471 L p .61624 .68976 L F P
0 g
s
.65956 .61698 m .68483 .51236 L .6216 .68407 L .707 .577 .707 r
F
.71818 .37429 m .62936 .65917 L p .68483 .51236 L F P
0 g
s
.55066 .84768 m .54645 .82923 L .57012 .82024 L p .707 .577 .707 r
F P
0 g
s
.59594 .77896 m .56712 .7874 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58773 .74201 m .58851 .74554 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.58851 .74554 m .59594 .77896 L p .58444 .74927 L .707 .577 .707 r
F P
0 g
s
.6216 .68407 m .608 .72768 L p .65956 .61698 L .707 .577 .707 r
F P
0 g
s
.608 .72768 m .57368 .83775 L p .62121 .71558 L .707 .577 .707 r
F P
0 g
s
.65956 .61698 m .608 .72768 L .62121 .71558 L .707 .577 .707 r
F
.59637 .73609 m .67805 .37002 L .55368 .83562 L F
.61267 .66304 m .61053 .64708 L .61633 .64663 L p F P
0 g
s
.61665 .69281 m .61624 .68976 L p .62106 .68113 L .707 .577 .707 r
F P
0 g
s
.57368 .83775 m .71818 .37429 L .67805 .37002 L p .707 .577 .707 r
F P
0 g
s
.61633 .64663 m .63536 .64517 L p .61267 .66304 L .707 .577 .707 r
F P
0 g
s
.61624 .68976 m .61267 .66304 L p .63536 .64517 L .707 .577 .707 r
F P
0 g
s
.62936 .65917 m .6216 .68407 L p .68483 .51236 L .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .65476 .60085 L p .67844 .64982 L .707 .577 .707 r
F P
0 g
s
.67964 .64826 m .67556 .60346 L .67844 .64982 L .707 .577 .707 r
F
.62847 .78545 m .62024 .77534 L p .67579 .65329 L F P
0 g
s
.68127 .64614 m .67556 .60346 L p .67964 .64826 L .707 .577 .707 r
F P
0 g
s
.69428 .6217 m .68458 .64182 L .7038 .59298 L .707 .577 .707 r
F
.68002 .65644 m .68458 .64182 L p .69428 .6217 L F P
0 g
s
.68458 .64182 m .69234 .61692 L p .7038 .59298 L .707 .577 .707 r
F P
0 g
s
.675 .67984 m .69428 .6217 L .67958 .67349 L .707 .577 .707 r
F
.71657 .56739 m .63988 .81337 L p .69428 .6217 L F P
0 g
s
.70454 .65884 m .71201 .71468 L .70924 .7081 L p .707 .577 .707 r
F P
0 g
s
.70924 .7081 m .70178 .65226 L .70454 .65884 L p .707 .577 .707 r
F P
0 g
s
.70178 .65226 m .70924 .7081 L .69686 .70327 L p .707 .577 .707 r
F P
0 g
s
.67556 .60346 m .68303 .6593 L .7102 .65942 L p .707 .577 .707 r
F P
0 g
s
.67579 .65329 m .68127 .64614 L .62847 .78545 L .707 .577 .707 r
F
.65482 .63664 m .65956 .61698 L .64679 .64983 L F
.65476 .60085 m .66223 .65669 L .67222 .65794 L p F P
0 g
s
.62024 .77534 m .65442 .68116 L .67579 .65329 L .707 .577 .707 r
F
.67222 .65794 m .68303 .6593 L p .67844 .64982 L F P
0 g
s
.67844 .64982 m .65476 .60085 L .67222 .65794 L .707 .577 .707 r
F
.69676 .60355 m .67556 .60346 L p .69234 .61692 L F P
0 g
s
.78115 .33204 m .69234 .61692 L p .67579 .65329 L .707 .577 .707 r
F P
0 g
s
.65442 .68116 m .78115 .33204 L .67579 .65329 L .707 .577 .707 r
F
.67579 .65329 m .69234 .61692 L .68127 .64614 L F
.68167 .64919 m .68127 .64614 L p .68009 .65322 L F P
0 g
s
.68127 .64614 m .67964 .64826 L .68009 .65322 L .707 .577 .707 r
F
.68009 .65322 m .67964 .64826 L .67844 .64982 L F
.63988 .81337 m .63666 .79551 L p .675 .67984 L F P
0 g
s
.675 .67984 m .67958 .67349 L .63988 .81337 L .707 .577 .707 r
F
.65971 .72529 m .67174 .72811 L p .6587 .70248 L F P
0 g
s
.66223 .65669 m .65476 .60085 L .64238 .59603 L p .707 .577 .707 r
F P
0 g
s
.65482 .63664 m .64679 .64983 L .57368 .83775 L .707 .577 .707 r
F
.64238 .59603 m .64849 .6418 L p .66223 .65669 L F P
0 g
s
.64284 .62484 m .64849 .6418 L .62024 .77534 L .707 .577 .707 r
F
.6554 .66254 m .65288 .67064 L p .64849 .6418 L F P
0 g
s
.65288 .67064 m .62024 .77534 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64238 .59603 L .64114 .59307 L p .707 .577 .707 r
F P
0 g
s
.61053 .64708 m .61624 .68976 L p .58642 .70755 L .707 .577 .707 r
F P
0 g
s
.60159 .70532 m .58642 .70755 L p .61624 .68976 L .707 .577 .707 r
F P
0 g
s
.55368 .83562 m .57368 .83775 L p .59637 .73609 L .707 .577 .707 r
F P
0 g
s
.6416 .59643 m .59222 .75484 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.64114 .59307 m .64106 .59291 L p .6416 .59643 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64114 .59307 L .6416 .59643 L .707 .577 .707 r
F
.53356 .83349 m .55368 .83562 L p .58329 .72476 L F P
0 g
s
.55961 .74992 m .53356 .83349 L p .58329 .72476 L .707 .577 .707 r
F P
0 g
s
.57896 .65171 m .58642 .70755 L .56268 .71278 L p .707 .577 .707 r
F P
0 g
s
.58642 .70755 m .57896 .65171 L .61053 .64708 L p .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .55534 .73602 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.73671 .29137 m .6416 .59643 L p .63416 .54277 L .707 .577 .707 r
F P
0 g
s
.65215 .65277 m .66223 .65669 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.76473 .31187 m .6554 .66254 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.59222 .75484 m .73671 .29137 L .76473 .31187 L p .707 .577 .707 r
F P
0 g
s
.64984 .65187 m .64849 .6418 L p .63961 .58945 L .707 .577 .707 r
F P
0 g
s
.64106 .59291 m .63961 .58945 L p .64849 .6418 L .707 .577 .707 r
F P
0 g
s
.64849 .6418 m .64984 .65187 L .65215 .65277 L p .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .59222 .75484 L p .64284 .62484 L .707 .577 .707 r
F P
0 g
s
.62024 .77534 m .76473 .31187 L .78115 .33204 L p .707 .577 .707 r
F P
0 g
s
.65151 .68834 m .6556 .70679 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.6556 .70679 m .65971 .72529 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.67592 .727 m .68413 .76395 L .65745 .76663 L p .707 .577 .707 r
F P
0 g
s
.67174 .72811 m .69209 .72818 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66354 .69116 m .66432 .69468 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .67174 .72811 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.68303 .6593 m .68167 .64919 L p .68009 .65322 L .707 .577 .707 r
F P
0 g
s
.74256 .4693 m .75537 .42638 L .74615 .45575 L .707 .577 .707 r
F
.77408 .36371 m .74692 .4508 L p .75537 .42638 L F P
0 g
s
.78303 .34246 m .78437 .3499 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.6974 .60355 m .69676 .60355 L p .69234 .61692 L .707 .577 .707 r
F P
0 g
s
.69234 .61692 m .78115 .33204 L .78303 .34246 L p .707 .577 .707 r
F P
0 g
s
.78437 .3499 m .71657 .56739 L p .69428 .6217 L .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .70273 .60358 L .6974 .60355 L p .707 .577 .707 r
F P
0 g
s
.7102 .65942 m .6974 .60355 L .68913 .62538 L .707 .577 .707 r
F
.66354 .69116 m .65151 .68834 L p .6587 .70248 L F P
0 g
s
.67174 .72811 m .66432 .69468 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.66432 .69468 m .66354 .69116 L p .6587 .70248 L .707 .577 .707 r
F P
0 g
s
.68375 .69124 m .66576 .69117 L p .6786 .71068 L .707 .577 .707 r
F P
0 g
s
.66576 .69117 m .66354 .69116 L p .66499 .69305 L .707 .577 .707 r
F P
0 g
s
.6786 .71068 m .66576 .69117 L .66499 .69305 L .707 .577 .707 r
F
.69209 .72818 m .68375 .69124 L .6786 .71068 L F
.55924 .70828 m .57896 .65171 L .56268 .71278 L F
.55943 .71243 m .56008 .70938 L .5559 .70391 L F
.49032 .82319 m .53356 .83349 L p .55943 .71243 L F P
0 g
s
.53332 .72159 m .52586 .66575 L .53844 .66175 L p .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53844 .66175 L .53892 .66291 L .707 .577 .707 r
F
.5397 .66479 m .63481 .35973 L p .53218 .62742 L F P
0 g
s
.53905 .66155 m .54978 .65814 L p .54335 .68292 L .707 .577 .707 r
F P
0 g
s
.53332 .72159 m .53905 .66155 L .54335 .68292 L .707 .577 .707 r
F
.54978 .65814 m .55725 .71398 L .53332 .72159 L p F P
0 g
s
.5397 .66479 m .49032 .82319 L p .55943 .71243 L .707 .577 .707 r
F P
0 g
s
.53844 .66175 m .53905 .66155 L p .53892 .66291 L .707 .577 .707 r
F P
0 g
s
.63481 .35973 m .59269 .34442 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.49032 .82319 m .5397 .66479 L p .53218 .62742 L .707 .577 .707 r
F P
0 g
s
.4482 .80789 m .59269 .34442 L .55582 .3256 L p .707 .577 .707 r
F P
0 g
s
.59269 .34442 m .4482 .80789 L .49032 .82319 L p .707 .577 .707 r
F P
0 g
s
.69835 .8196 m .70256 .83806 L .7188 .82954 L p .707 .577 .707 r
F P
0 g
s
.7188 .82954 m .71459 .81109 L .69835 .8196 L p .707 .577 .707 r
F P
0 g
s
.41132 .78906 m .55582 .3256 L .52779 .3051 L p .707 .577 .707 r
F P
0 g
s
.55582 .3256 m .41132 .78906 L .4482 .80789 L p .707 .577 .707 r
F P
0 g
s
.70363 .74243 m .71183 .77937 L .71904 .77213 L p .707 .577 .707 r
F P
0 g
s
.71904 .77213 m .71084 .73519 L .70363 .74243 L p .707 .577 .707 r
F P
0 g
s
.52551 .85016 m .52973 .86862 L .54173 .8713 L p .707 .577 .707 r
F P
0 g
s
.71459 .81109 m .7188 .82954 L .72601 .82233 L p .707 .577 .707 r
F P
0 g
s
.72601 .82233 m .7218 .80387 L .71459 .81109 L p .707 .577 .707 r
F P
0 g
s
.3833 .76856 m .52779 .3051 L .51137 .28493 L p .707 .577 .707 r
F P
0 g
s
.52779 .3051 m .3833 .76856 L .41132 .78906 L p .707 .577 .707 r
F P
0 g
s
.71084 .73519 m .71904 .77213 L .71651 .76684 L p .707 .577 .707 r
F P
0 g
s
.71651 .76684 m .7083 .7299 L .71084 .73519 L p .707 .577 .707 r
F P
0 g
s
.52973 .86862 m .52551 .85016 L .523 .84496 L p .707 .577 .707 r
F P
0 g
s
.523 .84496 m .52721 .86341 L .52973 .86862 L p .707 .577 .707 r
F P
0 g
s
.7218 .80387 m .72601 .82233 L .7235 .81713 L p .707 .577 .707 r
F P
0 g
s
.7235 .81713 m .71928 .79867 L .7218 .80387 L p .707 .577 .707 r
F P
0 g
s
.26087 .70573 m .25341 .64989 L .22252 .65226 L p .707 .577 .707 r
F P
0 g
s
.25341 .64989 m .26087 .70573 L .29245 .7011 L p .707 .577 .707 r
F P
0 g
s
.29245 .7011 m .28498 .64526 L .25341 .64989 L p .707 .577 .707 r
F P
0 g
s
.28498 .64526 m .29245 .7011 L .32163 .69467 L p .707 .577 .707 r
F P
0 g
s
.32163 .69467 m .31416 .63883 L .28498 .64526 L p .707 .577 .707 r
F P
0 g
s
.22999 .7081 m .22252 .65226 L .19535 .65214 L p .707 .577 .707 r
F P
0 g
s
.22252 .65226 m .22999 .7081 L .26087 .70573 L p .707 .577 .707 r
F P
0 g
s
.7083 .7299 m .71651 .76684 L .70448 .76402 L p .707 .577 .707 r
F P
0 g
s
.70448 .76402 m .69627 .72708 L .7083 .7299 L p .707 .577 .707 r
F P
0 g
s
.37579 .76023 m .37158 .74177 L .35534 .75029 L p .707 .577 .707 r
F P
0 g
s
.36062 .68903 m .36883 .72597 L .37603 .71873 L p .707 .577 .707 r
F P
0 g
s
.37603 .71873 m .36783 .68178 L .36062 .68903 L p .707 .577 .707 r
F P
0 g
s
.36783 .68178 m .37603 .71873 L .3735 .71344 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .36883 .72597 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34437 .69752 m .34707 .70966 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.34707 .70966 m .35258 .73446 L p .34983 .70386 L .707 .577 .707 r
F P
0 g
s
.3682 .74388 m .36427 .72667 L .3727 .72855 L p .707 .577 .707 r
F P
0 g
s
.3727 .72855 m .37627 .72935 L p .3682 .74388 L .707 .577 .707 r
F P
0 g
s
.36849 .74513 m .3682 .74388 L p .37627 .72935 L .707 .577 .707 r
F P
0 g
s
.36427 .72667 m .36849 .74513 L .34818 .74523 L p .707 .577 .707 r
F P
0 g
s
.36688 .7484 m .51137 .28493 L .50815 .26707 L p .707 .577 .707 r
F P
0 g
s
.36883 .72597 m .36062 .68903 L .34437 .69752 L p .707 .577 .707 r
F P
0 g
s
.3735 .71344 m .36714 .68482 L p .36783 .68178 L .707 .577 .707 r
F P
0 g
s
.36714 .68482 m .36529 .67649 L .3667 .67943 L p .707 .577 .707 r
F P
0 g
s
.3667 .67943 m .36783 .68178 L p .36714 .68482 L .707 .577 .707 r
F P
0 g
s
.36529 .67649 m .3735 .71344 L .36147 .71062 L p .707 .577 .707 r
F P
0 g
s
.50815 .26707 m .36366 .73053 L .36688 .7484 L p .707 .577 .707 r
F P
0 g
s
.51845 .25326 m .41181 .59531 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.41181 .59531 m .37396 .71673 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .37018 .72179 L p .43233 .52539 L .707 .577 .707 r
F P
0 g
s
.37018 .72179 m .36366 .73053 L p .36943 .71272 L .707 .577 .707 r
F P
0 g
s
.36943 .71272 m .51845 .25326 L .37018 .72179 L .707 .577 .707 r
F
.50815 .26707 m .51845 .25326 L p .42068 .5547 L F P
0 g
s
.36366 .73053 m .41426 .56823 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.41426 .56823 m .50815 .26707 L p .42068 .5547 L .707 .577 .707 r
F P
0 g
s
.37158 .74177 m .37579 .76023 L .383 .75301 L p .707 .577 .707 r
F P
0 g
s
.383 .75301 m .37879 .73456 L .37158 .74177 L p .707 .577 .707 r
F P
0 g
s
.37879 .73456 m .383 .75301 L .38049 .74781 L p .707 .577 .707 r
F P
0 g
s
.38049 .74781 m .37627 .72935 L .37879 .73456 L p .707 .577 .707 r
F P
0 g
s
.37627 .72935 m .38049 .74781 L .36849 .74513 L p .707 .577 .707 r
F P
0 g
s
.51137 .28493 m .36688 .7484 L .3833 .76856 L p .707 .577 .707 r
F P
0 g
s
.31416 .63883 m .32163 .69467 L .34555 .68705 L p .707 .577 .707 r
F P
0 g
s
.34555 .68705 m .33808 .63121 L .31416 .63883 L p .707 .577 .707 r
F P
0 g
s
.52721 .86341 m .523 .84496 L .53021 .83774 L p .707 .577 .707 r
F P
0 g
s
.26894 .75896 m .26073 .72202 L .23035 .72719 L p .707 .577 .707 r
F P
0 g
s
.26073 .72202 m .26894 .75896 L .30007 .7518 L p .707 .577 .707 r
F P
0 g
s
.30007 .7518 m .29186 .71486 L .26073 .72202 L p .707 .577 .707 r
F P
0 g
s
.29186 .71486 m .30007 .7518 L .32889 .74336 L p .707 .577 .707 r
F P
0 g
s
.32889 .74336 m .32068 .70642 L .29186 .71486 L p .707 .577 .707 r
F P
0 g
s
.53021 .83774 m .53442 .8562 L .52721 .86341 L p .707 .577 .707 r
F P
0 g
s
.19535 .65214 m .20281 .70798 L .22999 .7081 L p .707 .577 .707 r
F P
0 g
s
.71928 .79867 m .7235 .81713 L .7115 .81444 L p .707 .577 .707 r
F P
0 g
s
.7115 .81444 m .70728 .79599 L .71928 .79867 L p .707 .577 .707 r
F P
0 g
s
.23035 .72719 m .23855 .76414 L .26894 .75896 L p .707 .577 .707 r
F P
0 g
s
.20281 .70798 m .19535 .65214 L .17455 .64953 L p .707 .577 .707 r
F P
0 g
s
.23855 .76414 m .23035 .72719 L .20367 .72987 L p .707 .577 .707 r
F P
0 g
s
.276 .79364 m .27179 .77519 L .24144 .78055 L p .707 .577 .707 r
F P
0 g
s
.27179 .77519 m .276 .79364 L .30709 .78631 L p .707 .577 .707 r
F P
0 g
s
.30709 .78631 m .30288 .76786 L .27179 .77519 L p .707 .577 .707 r
F P
0 g
s
.30288 .76786 m .30709 .78631 L .33588 .77773 L p .707 .577 .707 r
F P
0 g
s
.33588 .77773 m .33167 .75928 L .30288 .76786 L p .707 .577 .707 r
F P
0 g
s
.32068 .70642 m .32889 .74336 L .35258 .73446 L p .707 .577 .707 r
F P
0 g
s
.35258 .73446 m .34437 .69752 L .32068 .70642 L p .707 .577 .707 r
F P
0 g
s
.24144 .78055 m .24566 .79901 L .276 .79364 L p .707 .577 .707 r
F P
0 g
s
.20367 .72987 m .21188 .76682 L .23855 .76414 L p .707 .577 .707 r
F P
0 g
s
.33808 .63121 m .34555 .68705 L .36187 .67901 L p .707 .577 .707 r
F P
0 g
s
.36187 .67901 m .35441 .62317 L .33808 .63121 L p .707 .577 .707 r
F P
0 g
s
.24566 .79901 m .24144 .78055 L .21481 .78343 L p .707 .577 .707 r
F P
0 g
s
.17455 .64953 m .18202 .70537 L .20281 .70798 L p .707 .577 .707 r
F P
0 g
s
.69627 .72708 m .70448 .76402 L .68413 .76395 L p .707 .577 .707 r
F P
0 g
s
.21481 .78343 m .21903 .80188 L .24566 .79901 L p .707 .577 .707 r
F P
0 g
s
.33167 .75928 m .33588 .77773 L .35955 .76874 L p .707 .577 .707 r
F P
0 g
s
.35955 .76874 m .35534 .75029 L .33167 .75928 L p .707 .577 .707 r
F P
0 g
s
.21188 .76682 m .20367 .72987 L .18332 .7298 L p .707 .577 .707 r
F P
0 g
s
.18202 .70537 m .17455 .64953 L .16216 .64471 L p .707 .577 .707 r
F P
0 g
s
.18332 .7298 m .19153 .76674 L .21188 .76682 L p .707 .577 .707 r
F P
0 g
s
.21903 .80188 m .21481 .78343 L .1945 .78353 L p .707 .577 .707 r
F P
0 g
s
.70728 .79599 m .7115 .81444 L .69119 .81454 L p .707 .577 .707 r
F P
0 g
s
.69119 .81454 m .68697 .79609 L .70728 .79599 L p .707 .577 .707 r
F P
0 g
s
.1945 .78353 m .19872 .80198 L .21903 .80188 L p .707 .577 .707 r
F P
0 g
s
.35534 .75029 m .35955 .76874 L .37579 .76023 L p .707 .577 .707 r
F P
0 g
s
.35441 .62317 m .36187 .67901 L .369 .67132 L p .707 .577 .707 r
F P
0 g
s
.369 .67132 m .36153 .61548 L .35441 .62317 L p .707 .577 .707 r
F P
0 g
s
.16216 .64471 m .16963 .70055 L .18202 .70537 L p .707 .577 .707 r
F P
0 g
s
.19153 .76674 m .18332 .7298 L .17129 .72698 L p .707 .577 .707 r
F P
0 g
s
.17129 .72698 m .1795 .76392 L .19153 .76674 L p .707 .577 .707 r
F P
0 g
s
.19872 .80198 m .1945 .78353 L .1825 .78084 L p .707 .577 .707 r
F P
0 g
s
.16963 .70055 m .16216 .64471 L .1594 .63813 L p .707 .577 .707 r
F P
0 g
s
.68697 .79609 m .69119 .81454 L .66456 .81742 L p .707 .577 .707 r
F P
0 g
s
.66456 .81742 m .66034 .79896 L .68697 .79609 L p .707 .577 .707 r
F P
0 g
s
.1825 .78084 m .18672 .7993 L .19872 .80198 L p .707 .577 .707 r
F P
0 g
s
.36153 .61548 m .369 .67132 L .36623 .66474 L p .707 .577 .707 r
F P
0 g
s
.36623 .66474 m .35877 .6089 L .36153 .61548 L p .707 .577 .707 r
F P
0 g
s
.1594 .63813 m .16686 .69397 L .16963 .70055 L p .707 .577 .707 r
F P
0 g
s
.37396 .71673 m .51845 .25326 L .54126 .24486 L p .707 .577 .707 r
F P
0 g
s
.66034 .79896 m .66456 .81742 L .63421 .82278 L p .707 .577 .707 r
F P
0 g
s
.1795 .76392 m .17129 .72698 L .16876 .72169 L p .707 .577 .707 r
F P
0 g
s
.16876 .72169 m .17696 .75863 L .1795 .76392 L p .707 .577 .707 r
F P
0 g
s
.18672 .7993 m .1825 .78084 L .17999 .77564 L p .707 .577 .707 r
F P
0 g
s
.16686 .69397 m .1594 .63813 L .16653 .63044 L p .707 .577 .707 r
F P
0 g
s
.17999 .77564 m .1842 .7941 L .18672 .7993 L p .707 .577 .707 r
F P
0 g
s
.35877 .6089 m .36623 .66474 L .35385 .65992 L p .707 .577 .707 r
F P
0 g
s
.35385 .65992 m .34638 .60407 L .35877 .6089 L p .707 .577 .707 r
F P
0 g
s
.16653 .63044 m .17399 .68628 L .16686 .69397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17696 .75863 m .16876 .72169 L .17596 .71444 L p .707 .577 .707 r
F P
0 g
s
.54126 .24486 m .39677 .70832 L .37396 .71673 L p .707 .577 .707 r
F P
0 g
s
.39677 .70832 m .54126 .24486 L .57435 .24268 L p .707 .577 .707 r
F P
0 g
s
.17596 .71444 m .18417 .75139 L .17696 .75863 L p .707 .577 .707 r
F P
0 g
s
.36147 .71062 m .35326 .67367 L .36529 .67649 L p .707 .577 .707 r
F P
0 g
s
.1842 .7941 m .17999 .77564 L .1872 .76843 L p .707 .577 .707 r
F P
0 g
s
.17399 .68628 m .16653 .63044 L .18285 .62239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1872 .76843 m .19141 .78688 L .1842 .7941 L p .707 .577 .707 r
F P
0 g
s
.34638 .60407 m .35385 .65992 L .33305 .65731 L p .707 .577 .707 r
F P
0 g
s
.33305 .65731 m .32558 .60147 L .34638 .60407 L p .707 .577 .707 r
F P
0 g
s
.18285 .62239 m .19031 .67824 L .17399 .68628 L p .707 .577 .707 r
F P
0 g
s
.18417 .75139 m .17596 .71444 L .19221 .70596 L p .707 .577 .707 r
F P
0 g
s
.42985 .70615 m .57435 .24268 L .61448 .24695 L p .707 .577 .707 r
F P
0 g
s
.57435 .24268 m .42985 .70615 L .39677 .70832 L p .707 .577 .707 r
F P
0 g
s
.19031 .67824 m .18285 .62239 L .20677 .61478 L p .707 .577 .707 r
F P
0 g
s
.19221 .70596 m .20042 .7429 L .18417 .75139 L p .707 .577 .707 r
F P
0 g
s
.35326 .67367 m .36147 .71062 L .34112 .71054 L p .707 .577 .707 r
F P
0 g
s
.34112 .71054 m .33291 .6736 L .35326 .67367 L p .707 .577 .707 r
F P
0 g
s
.55534 .73602 m .69983 .27255 L .73671 .29137 L p .707 .577 .707 r
F P
0 g
s
.19141 .78688 m .1872 .76843 L .20344 .75991 L p .707 .577 .707 r
F P
0 g
s
.20344 .75991 m .20765 .77837 L .19141 .78688 L p .707 .577 .707 r
F P
0 g
s
.32558 .60147 m .33305 .65731 L .30588 .65719 L p .707 .577 .707 r
F P
0 g
s
.30588 .65719 m .29841 .60135 L .32558 .60147 L p .707 .577 .707 r
F P
0 g
s
.34818 .74523 m .34397 .72677 L .36427 .72667 L p .707 .577 .707 r
F P
0 g
s
.20677 .61478 m .21424 .67062 L .19031 .67824 L p .707 .577 .707 r
F P
0 g
s
.46998 .71042 m .61448 .24695 L .65771 .25724 L p .707 .577 .707 r
F P
0 g
s
.61448 .24695 m .46998 .71042 L .42985 .70615 L p .707 .577 .707 r
F P
0 g
s
.20042 .7429 m .19221 .70596 L .2159 .69706 L p .707 .577 .707 r
F P
0 g
s
.21424 .67062 m .20677 .61478 L .23595 .60835 L p .707 .577 .707 r
F P
0 g
s
.69983 .27255 m .55534 .73602 L .51322 .72071 L p .707 .577 .707 r
F P
0 g
s
.51322 .72071 m .65771 .25724 L .69983 .27255 L p .707 .577 .707 r
F P
0 g
s
.29841 .60135 m .30588 .65719 L .27499 .65956 L p .707 .577 .707 r
F P
0 g
s
.27499 .65956 m .26753 .60372 L .29841 .60135 L p .707 .577 .707 r
F P
0 g
s
.33291 .6736 m .34112 .71054 L .31444 .71323 L p .707 .577 .707 r
F P
0 g
s
.31444 .71323 m .30624 .67628 L .33291 .6736 L p .707 .577 .707 r
F P
0 g
s
.65771 .25724 m .51322 .72071 L .46998 .71042 L p .707 .577 .707 r
F P
0 g
s
.2159 .69706 m .22411 .734 L .20042 .7429 L p .707 .577 .707 r
F P
0 g
s
.20765 .77837 m .20344 .75991 L .22711 .75092 L p .707 .577 .707 r
F P
0 g
s
.24341 .66419 m .23595 .60835 L .26753 .60372 L p .707 .577 .707 r
F P
0 g
s
.23595 .60835 m .24341 .66419 L .21424 .67062 L p .707 .577 .707 r
F P
0 g
s
.26753 .60372 m .27499 .65956 L .24341 .66419 L p .707 .577 .707 r
F P
0 g
s
.22711 .75092 m .23133 .76938 L .20765 .77837 L p .707 .577 .707 r
F P
0 g
s
.74108 .65705 m .73362 .60121 L .70273 .60358 L p .707 .577 .707 r
F P
0 g
s
.73362 .60121 m .74108 .65705 L .77266 .65242 L p .707 .577 .707 r
F P
0 g
s
.77266 .65242 m .7652 .59658 L .73362 .60121 L p .707 .577 .707 r
F P
0 g
s
.34397 .72677 m .34818 .74523 L .32155 .7481 L p .707 .577 .707 r
F P
0 g
s
.32155 .7481 m .31734 .72964 L .34397 .72677 L p .707 .577 .707 r
F P
0 g
s
.7652 .59658 m .77266 .65242 L .80184 .64599 L p .707 .577 .707 r
F P
0 g
s
.80184 .64599 m .79437 .59015 L .7652 .59658 L p .707 .577 .707 r
F P
0 g
s
.22411 .734 m .2159 .69706 L .24472 .68861 L p .707 .577 .707 r
F P
0 g
s
.70273 .60358 m .7102 .65942 L .74108 .65705 L p .707 .577 .707 r
F P
0 g
s
.30624 .67628 m .31444 .71323 L .28406 .7184 L p .707 .577 .707 r
F P
0 g
s
.28406 .7184 m .27585 .68145 L .30624 .67628 L p .707 .577 .707 r
F P
0 g
s
.24472 .68861 m .25293 .72556 L .22411 .734 L p .707 .577 .707 r
F P
0 g
s
.79437 .59015 m .80184 .64599 L .82576 .63837 L p .707 .577 .707 r
F P
0 g
s
.82576 .63837 m .8183 .58253 L .79437 .59015 L p .707 .577 .707 r
F P
0 g
s
.23133 .76938 m .22711 .75092 L .2559 .74234 L p .707 .577 .707 r
F P
0 g
s
.25293 .72556 m .24472 .68861 L .27585 .68145 L p .707 .577 .707 r
F P
0 g
s
.27585 .68145 m .28406 .7184 L .25293 .72556 L p .707 .577 .707 r
F P
0 g
s
.2559 .74234 m .26011 .7608 L .23133 .76938 L p .707 .577 .707 r
F P
0 g
s
.31734 .72964 m .32155 .7481 L .2912 .75346 L p .707 .577 .707 r
F P
0 g
s
.2912 .75346 m .28699 .73501 L .31734 .72964 L p .707 .577 .707 r
F P
0 g
s
.74915 .72033 m .74095 .68338 L .71056 .68856 L p .707 .577 .707 r
F P
0 g
s
.74095 .68338 m .74915 .72033 L .78028 .71317 L p .707 .577 .707 r
F P
0 g
s
.78028 .71317 m .77207 .67622 L .74095 .68338 L p .707 .577 .707 r
F P
0 g
s
.77207 .67622 m .78028 .71317 L .8091 .70473 L p .707 .577 .707 r
F P
0 g
s
.8091 .70473 m .8009 .66778 L .77207 .67622 L p .707 .577 .707 r
F P
0 g
s
.26011 .7608 m .2559 .74234 L .28699 .73501 L p .707 .577 .707 r
F P
0 g
s
.71056 .68856 m .71877 .7255 L .74915 .72033 L p .707 .577 .707 r
F P
0 g
s
.28699 .73501 m .2912 .75346 L .26011 .7608 L p .707 .577 .707 r
F P
0 g
s
.71877 .7255 m .71056 .68856 L .68389 .69124 L p .707 .577 .707 r
F P
0 g
s
.8009 .66778 m .8091 .70473 L .83279 .69582 L p .707 .577 .707 r
F P
0 g
s
.83279 .69582 m .82459 .65888 L .8009 .66778 L p .707 .577 .707 r
F P
0 g
s
.8183 .58253 m .82576 .63837 L .84209 .63033 L p .707 .577 .707 r
F P
0 g
s
.84209 .63033 m .83462 .57449 L .8183 .58253 L p .707 .577 .707 r
F P
0 g
s
.75621 .77092 m .752 .75247 L .72166 .75783 L p .707 .577 .707 r
F P
0 g
s
.752 .75247 m .75621 .77092 L .7873 .76359 L p .707 .577 .707 r
F P
0 g
s
.7873 .76359 m .78309 .74514 L .752 .75247 L p .707 .577 .707 r
F P
0 g
s
.68389 .69124 m .69209 .72818 L .71877 .7255 L p .707 .577 .707 r
F P
0 g
s
.78309 .74514 m .7873 .76359 L .81609 .75501 L p .707 .577 .707 r
F P
0 g
s
.81609 .75501 m .81188 .73656 L .78309 .74514 L p .707 .577 .707 r
F P
0 g
s
.72166 .75783 m .72587 .77629 L .75621 .77092 L p .707 .577 .707 r
F P
0 g
s
.72587 .77629 m .72166 .75783 L .69503 .7607 L p .707 .577 .707 r
F P
0 g
s
.69503 .7607 m .69924 .77916 L .72587 .77629 L p .707 .577 .707 r
F P
0 g
s
.81188 .73656 m .81609 .75501 L .83977 .74602 L p .707 .577 .707 r
F P
0 g
s
.83977 .74602 m .83555 .72757 L .81188 .73656 L p .707 .577 .707 r
F P
0 g
s
.82459 .65888 m .83279 .69582 L .84904 .68734 L p .707 .577 .707 r
F P
0 g
s
.84904 .68734 m .84083 .65039 L .82459 .65888 L p .707 .577 .707 r
F P
0 g
s
.83462 .57449 m .84209 .63033 L .84921 .62264 L p .707 .577 .707 r
F P
0 g
s
.84921 .62264 m .84175 .5668 L .83462 .57449 L p .707 .577 .707 r
F P
0 g
s
.69924 .77916 m .69503 .7607 L .67472 .7608 L p .707 .577 .707 r
F P
0 g
s
.67472 .7608 m .67893 .77926 L .69924 .77916 L p .707 .577 .707 r
F P
0 g
s
.83555 .72757 m .83977 .74602 L .856 .7375 L p .707 .577 .707 r
F P
0 g
s
.856 .7375 m .85179 .71905 L .83555 .72757 L p .707 .577 .707 r
F P
0 g
s
.84083 .65039 m .84904 .68734 L .85625 .68009 L p .707 .577 .707 r
F P
0 g
s
.85625 .68009 m .84804 .64315 L .84083 .65039 L p .707 .577 .707 r
F P
0 g
s
.67893 .77926 m .67472 .7608 L .66272 .75812 L p .707 .577 .707 r
F P
0 g
s
.66272 .75812 m .66693 .77658 L .67893 .77926 L p .707 .577 .707 r
F P
0 g
s
.84175 .5668 m .84921 .62264 L .84645 .61606 L p .707 .577 .707 r
F P
0 g
s
.84645 .61606 m .83898 .56022 L .84175 .5668 L p .707 .577 .707 r
F P
0 g
s
.63961 .58945 m .64708 .64529 L .64984 .65187 L p .707 .577 .707 r
F P
0 g
s
.85179 .71905 m .856 .7375 L .86322 .73029 L p .707 .577 .707 r
F P
0 g
s
.86322 .73029 m .859 .71183 L .85179 .71905 L p .707 .577 .707 r
F P
0 g
s
.65971 .72529 m .65151 .68834 L .64897 .68305 L p .707 .577 .707 r
F P
0 g
s
.64897 .68305 m .65718 .72 L .65971 .72529 L p .707 .577 .707 r
F P
0 g
s
.84804 .64315 m .85625 .68009 L .85371 .6748 L p .707 .577 .707 r
F P
0 g
s
.85371 .6748 m .8455 .63786 L .84804 .64315 L p .707 .577 .707 r
F P
0 g
s
.64708 .64529 m .63961 .58945 L .64674 .58176 L p .707 .577 .707 r
F P
0 g
s
.66693 .77658 m .66272 .75812 L .6602 .75292 L p .707 .577 .707 r
F P
0 g
s
.6602 .75292 m .66441 .77138 L .66693 .77658 L p .707 .577 .707 r
F P
0 g
s
.83898 .56022 m .84645 .61606 L .83406 .61124 L p .707 .577 .707 r
F P
0 g
s
.83406 .61124 m .8266 .55539 L .83898 .56022 L p .707 .577 .707 r
F P
0 g
s
.64674 .58176 m .6542 .6376 L .64708 .64529 L p .707 .577 .707 r
F P
0 g
s
.859 .71183 m .86322 .73029 L .8607 .72509 L p .707 .577 .707 r
F P
0 g
s
.8607 .72509 m .85649 .70663 L .859 .71183 L p .707 .577 .707 r
F P
0 g
s
.39807 .61369 m .39061 .55785 L .35972 .56022 L p .707 .577 .707 r
F P
0 g
s
.39061 .55785 m .39807 .61369 L .42965 .60906 L p .707 .577 .707 r
F P
0 g
s
.42965 .60906 m .42219 .55322 L .39061 .55785 L p .707 .577 .707 r
F P
0 g
s
.65718 .72 m .64897 .68305 L .65618 .67581 L p .707 .577 .707 r
F P
0 g
s
.42219 .55322 m .42965 .60906 L .45883 .60263 L p .707 .577 .707 r
F P
0 g
s
.45883 .60263 m .45136 .54679 L .42219 .55322 L p .707 .577 .707 r
F P
0 g
s
.65618 .67581 m .66438 .71275 L .65718 .72 L p .707 .577 .707 r
F P
0 g
s
.36719 .61606 m .35972 .56022 L .33255 .5601 L p .707 .577 .707 r
F P
0 g
s
.35972 .56022 m .36719 .61606 L .39807 .61369 L p .707 .577 .707 r
F P
0 g
s
.6542 .6376 m .64674 .58176 L .66306 .57371 L p .707 .577 .707 r
F P
0 g
s
.8455 .63786 m .85371 .6748 L .84168 .67198 L p .707 .577 .707 r
F P
0 g
s
.84168 .67198 m .83347 .63504 L .8455 .63786 L p .707 .577 .707 r
F P
0 g
s
.45136 .54679 m .45883 .60263 L .48275 .59502 L p .707 .577 .707 r
F P
0 g
s
.48275 .59502 m .47529 .53917 L .45136 .54679 L p .707 .577 .707 r
F P
0 g
s
.66441 .77138 m .6602 .75292 L .66742 .74571 L p .707 .577 .707 r
F P
0 g
s
.40614 .66692 m .39794 .62998 L .36755 .63515 L p .707 .577 .707 r
F P
0 g
s
.39794 .62998 m .40614 .66692 L .43727 .65977 L p .707 .577 .707 r
F P
0 g
s
.43727 .65977 m .42906 .62282 L .39794 .62998 L p .707 .577 .707 r
F P
0 g
s
.42906 .62282 m .43727 .65977 L .46609 .65132 L p .707 .577 .707 r
F P
0 g
s
.46609 .65132 m .45789 .61438 L .42906 .62282 L p .707 .577 .707 r
F P
0 g
s
.66742 .74571 m .67163 .76416 L .66441 .77138 L p .707 .577 .707 r
F P
0 g
s
.8266 .55539 m .83406 .61124 L .81326 .60863 L p .707 .577 .707 r
F P
0 g
s
.81326 .60863 m .8058 .55279 L .8266 .55539 L p .707 .577 .707 r
F P
0 g
s
.33255 .5601 m .34002 .61594 L .36719 .61606 L p .707 .577 .707 r
F P
0 g
s
.66306 .57371 m .67053 .62956 L .6542 .6376 L p .707 .577 .707 r
F P
0 g
s
.85649 .70663 m .8607 .72509 L .8487 .72241 L p .707 .577 .707 r
F P
0 g
s
.8487 .72241 m .84449 .70395 L .85649 .70663 L p .707 .577 .707 r
F P
0 g
s
.36755 .63515 m .37576 .6721 L .40614 .66692 L p .707 .577 .707 r
F P
0 g
s
.34002 .61594 m .33255 .5601 L .31175 .55749 L p .707 .577 .707 r
F P
0 g
s
.37576 .6721 m .36755 .63515 L .34088 .63783 L p .707 .577 .707 r
F P
0 g
s
.4132 .70161 m .40899 .68315 L .37865 .68851 L p .707 .577 .707 r
F P
0 g
s
.40899 .68315 m .4132 .70161 L .44429 .69428 L p .707 .577 .707 r
F P
0 g
s
.44429 .69428 m .44008 .67582 L .40899 .68315 L p .707 .577 .707 r
F P
0 g
s
.44008 .67582 m .44429 .69428 L .47308 .68569 L p .707 .577 .707 r
F P
0 g
s
.47308 .68569 m .46887 .66724 L .44008 .67582 L p .707 .577 .707 r
F P
0 g
s
.45789 .61438 m .46609 .65132 L .48978 .64242 L p .707 .577 .707 r
F P
0 g
s
.48978 .64242 m .48158 .60548 L .45789 .61438 L p .707 .577 .707 r
F P
0 g
s
.37865 .68851 m .38286 .70697 L .4132 .70161 L p .707 .577 .707 r
F P
0 g
s
.66438 .71275 m .65618 .67581 L .67242 .66732 L p .707 .577 .707 r
F P
0 g
s
.34088 .63783 m .34908 .67478 L .37576 .6721 L p .707 .577 .707 r
F P
0 g
s
.47529 .53917 m .48275 .59502 L .49908 .58697 L p .707 .577 .707 r
F P
0 g
s
.49908 .58697 m .49161 .53113 L .47529 .53917 L p .707 .577 .707 r
F P
0 g
s
.67053 .62956 m .66306 .57371 L .68698 .5661 L p .707 .577 .707 r
F P
0 g
s
.38286 .70697 m .37865 .68851 L .35202 .69139 L p .707 .577 .707 r
F P
0 g
s
.31175 .55749 m .31922 .61334 L .34002 .61594 L p .707 .577 .707 r
F P
0 g
s
.67242 .66732 m .68063 .70426 L .66438 .71275 L p .707 .577 .707 r
F P
0 g
s
.83347 .63504 m .84168 .67198 L .82133 .67191 L p .707 .577 .707 r
F P
0 g
s
.82133 .67191 m .81313 .63496 L .83347 .63504 L p .707 .577 .707 r
F P
0 g
s
.35202 .69139 m .35623 .70984 L .38286 .70697 L p .707 .577 .707 r
F P
0 g
s
.46887 .66724 m .47308 .68569 L .49676 .67671 L p .707 .577 .707 r
F P
0 g
s
.49676 .67671 m .49254 .65825 L .46887 .66724 L p .707 .577 .707 r
F P
0 g
s
.34908 .67478 m .34088 .63783 L .32053 .63776 L p .707 .577 .707 r
F P
0 g
s
.8058 .55279 m .81326 .60863 L .78609 .60851 L p .707 .577 .707 r
F P
0 g
s
.78609 .60851 m .77863 .55267 L .8058 .55279 L p .707 .577 .707 r
F P
0 g
s
.67163 .76416 m .66742 .74571 L .68365 .73719 L p .707 .577 .707 r
F P
0 g
s
.68698 .5661 m .69445 .62194 L .67053 .62956 L p .707 .577 .707 r
F P
0 g
s
.48158 .60548 m .48978 .64242 L .50603 .63393 L p .707 .577 .707 r
F P
0 g
s
.50603 .63393 m .49782 .59699 L .48158 .60548 L p .707 .577 .707 r
F P
0 g
s
.31922 .61334 m .31175 .55749 L .29937 .55267 L p .707 .577 .707 r
F P
0 g
s
.68365 .73719 m .68787 .75564 L .67163 .76416 L p .707 .577 .707 r
F P
0 g
s
.32053 .63776 m .32873 .6747 L .34908 .67478 L p .707 .577 .707 r
F P
0 g
s
.35623 .70984 m .35202 .69139 L .33171 .69149 L p .707 .577 .707 r
F P
0 g
s
.84449 .70395 m .8487 .72241 L .82839 .72251 L p .707 .577 .707 r
F P
0 g
s
.82839 .72251 m .82418 .70405 L .84449 .70395 L p .707 .577 .707 r
F P
0 g
s
.69445 .62194 m .68698 .5661 L .71616 .55967 L p .707 .577 .707 r
F P
0 g
s
.33171 .69149 m .33592 .70994 L .35623 .70984 L p .707 .577 .707 r
F P
0 g
s
.68063 .70426 m .67242 .66732 L .69612 .65842 L p .707 .577 .707 r
F P
0 g
s
.49254 .65825 m .49676 .67671 L .51299 .66819 L p .707 .577 .707 r
F P
0 g
s
.51299 .66819 m .50878 .64973 L .49254 .65825 L p .707 .577 .707 r
F P
0 g
s
.49161 .53113 m .49908 .58697 L .5062 .57928 L p .707 .577 .707 r
F P
0 g
s
.5062 .57928 m .49874 .52344 L .49161 .53113 L p .707 .577 .707 r
F P
0 g
s
.77863 .55267 m .78609 .60851 L .75521 .61088 L p .707 .577 .707 r
F P
0 g
s
.75521 .61088 m .74774 .55504 L .77863 .55267 L p .707 .577 .707 r
F P
0 g
s
.29937 .55267 m .30683 .60851 L .31922 .61334 L p .707 .577 .707 r
F P
0 g
s
.81313 .63496 m .82133 .67191 L .79466 .67459 L p .707 .577 .707 r
F P
0 g
s
.79466 .67459 m .78645 .63765 L .81313 .63496 L p .707 .577 .707 r
F P
0 g
s
.69612 .65842 m .70432 .69536 L .68063 .70426 L p .707 .577 .707 r
F P
0 g
s
.72363 .61551 m .71616 .55967 L .74774 .55504 L p .707 .577 .707 r
F P
0 g
s
.71616 .55967 m .72363 .61551 L .69445 .62194 L p .707 .577 .707 r
F P
0 g
s
.32873 .6747 m .32053 .63776 L .3085 .63494 L p .707 .577 .707 r
F P
0 g
s
.74774 .55504 m .75521 .61088 L .72363 .61551 L p .707 .577 .707 r
F P
0 g
s
.68787 .75564 m .68365 .73719 L .70733 .7282 L p .707 .577 .707 r
F P
0 g
s
.3085 .63494 m .3167 .67188 L .32873 .6747 L p .707 .577 .707 r
F P
0 g
s
.49782 .59699 m .50603 .63393 L .51324 .62669 L p .707 .577 .707 r
F P
0 g
s
.51324 .62669 m .50503 .58975 L .49782 .59699 L p .707 .577 .707 r
F P
0 g
s
.70733 .7282 m .71154 .74665 L .68787 .75564 L p .707 .577 .707 r
F P
0 g
s
.70432 .69536 m .69612 .65842 L .72494 .64998 L p .707 .577 .707 r
F P
0 g
s
.33592 .70994 m .33171 .69149 L .31971 .6888 L p .707 .577 .707 r
F P
0 g
s
.30683 .60851 m .29937 .55267 L .2966 .54609 L p .707 .577 .707 r
F P
0 g
s
.82418 .70405 m .82839 .72251 L .80176 .72538 L p .707 .577 .707 r
F P
0 g
s
.80176 .72538 m .79755 .70692 L .82418 .70405 L p .707 .577 .707 r
F P
0 g
s
.78645 .63765 m .79466 .67459 L .76427 .67976 L p .707 .577 .707 r
F P
0 g
s
.76427 .67976 m .75606 .64282 L .78645 .63765 L p .707 .577 .707 r
F P
0 g
s
.31971 .6888 m .32392 .70726 L .33592 .70994 L p .707 .577 .707 r
F P
0 g
s
.72494 .64998 m .73314 .68692 L .70432 .69536 L p .707 .577 .707 r
F P
0 g
s
.50878 .64973 m .51299 .66819 L .52021 .66097 L p .707 .577 .707 r
F P
0 g
s
.52021 .66097 m .51599 .64252 L .50878 .64973 L p .707 .577 .707 r
F P
0 g
s
.73314 .68692 m .72494 .64998 L .75606 .64282 L p .707 .577 .707 r
F P
0 g
s
.75606 .64282 m .76427 .67976 L .73314 .68692 L p .707 .577 .707 r
F P
0 g
s
.49874 .52344 m .5062 .57928 L .50344 .5727 L p .707 .577 .707 r
F P
0 g
s
.50344 .5727 m .49597 .51686 L .49874 .52344 L p .707 .577 .707 r
F P
0 g
s
.2966 .54609 m .30407 .60193 L .30683 .60851 L p .707 .577 .707 r
F P
0 g
s
.71154 .74665 m .70733 .7282 L .73612 .71962 L p .707 .577 .707 r
F P
0 g
s
.73612 .71962 m .74033 .73807 L .71154 .74665 L p .707 .577 .707 r
F P
0 g
s
.79755 .70692 m .80176 .72538 L .77142 .73074 L p .707 .577 .707 r
F P
0 g
s
.77142 .73074 m .7672 .71229 L .79755 .70692 L p .707 .577 .707 r
F P
0 g
s
.3167 .67188 m .3085 .63494 L .30596 .62965 L p .707 .577 .707 r
F P
0 g
s
.74033 .73807 m .73612 .71962 L .7672 .71229 L p .707 .577 .707 r
F P
0 g
s
.7672 .71229 m .77142 .73074 L .74033 .73807 L p .707 .577 .707 r
F P
0 g
s
.30596 .62965 m .31417 .66659 L .3167 .67188 L p .707 .577 .707 r
F P
0 g
s
.50503 .58975 m .51324 .62669 L .5107 .6214 L p .707 .577 .707 r
F P
0 g
s
.5107 .6214 m .50249 .58445 L .50503 .58975 L p .707 .577 .707 r
F P
0 g
s
.32392 .70726 m .31971 .6888 L .31719 .6836 L p .707 .577 .707 r
F P
0 g
s
.30407 .60193 m .2966 .54609 L .30373 .5384 L p .707 .577 .707 r
F P
0 g
s
.31719 .6836 m .3214 .70206 L .32392 .70726 L p .707 .577 .707 r
F P
0 g
s
.51599 .64252 m .52021 .66097 L .51769 .65577 L p .707 .577 .707 r
F P
0 g
s
.51769 .65577 m .51348 .63731 L .51599 .64252 L p .707 .577 .707 r
F P
0 g
s
.49597 .51686 m .50344 .5727 L .49105 .56788 L p .707 .577 .707 r
F P
0 g
s
.49105 .56788 m .48359 .51204 L .49597 .51686 L p .707 .577 .707 r
F P
0 g
s
.30373 .5384 m .31119 .59424 L .30407 .60193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31417 .66659 m .30596 .62965 L .31317 .62241 L p .707 .577 .707 r
F P
0 g
s
.31317 .62241 m .32137 .65935 L .31417 .66659 L p .707 .577 .707 r
F P
0 g
s
.50249 .58445 m .5107 .6214 L .49867 .61858 L p .707 .577 .707 r
F P
0 g
s
.49867 .61858 m .49046 .58163 L .50249 .58445 L p .707 .577 .707 r
F P
0 g
s
.3214 .70206 m .31719 .6836 L .3244 .67639 L p .707 .577 .707 r
F P
0 g
s
.31119 .59424 m .30373 .5384 L .32005 .53036 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3244 .67639 m .32862 .69485 L .3214 .70206 L p .707 .577 .707 r
F P
0 g
s
.51348 .63731 m .51769 .65577 L .50569 .65309 L p .707 .577 .707 r
F P
0 g
s
.50569 .65309 m .50148 .63463 L .51348 .63731 L p .707 .577 .707 r
F P
0 g
s
.48359 .51204 m .49105 .56788 L .47025 .56527 L p .707 .577 .707 r
F P
0 g
s
.47025 .56527 m .46279 .50943 L .48359 .51204 L p .707 .577 .707 r
F P
0 g
s
.32005 .53036 m .32752 .5862 L .31119 .59424 L p .707 .577 .707 r
F P
0 g
s
.32137 .65935 m .31317 .62241 L .32941 .61392 L p .707 .577 .707 r
F P
0 g
s
.32752 .5862 m .32005 .53036 L .34397 .52274 L p .707 .577 .707 r
F P
0 g
s
.32941 .61392 m .33762 .65086 L .32137 .65935 L p .707 .577 .707 r
F P
0 g
s
.49046 .58163 m .49867 .61858 L .47832 .61851 L p .707 .577 .707 r
F P
0 g
s
.47832 .61851 m .47012 .58156 L .49046 .58163 L p .707 .577 .707 r
F P
0 g
s
.32862 .69485 m .3244 .67639 L .34064 .66787 L p .707 .577 .707 r
F P
0 g
s
.34064 .66787 m .34486 .68633 L .32862 .69485 L p .707 .577 .707 r
F P
0 g
s
.46279 .50943 m .47025 .56527 L .44308 .56515 L p .707 .577 .707 r
F P
0 g
s
.44308 .56515 m .43562 .50931 L .46279 .50943 L p .707 .577 .707 r
F P
0 g
s
.50148 .63463 m .50569 .65309 L .48538 .65319 L p .707 .577 .707 r
F P
0 g
s
.48538 .65319 m .48117 .63473 L .50148 .63463 L p .707 .577 .707 r
F P
0 g
s
.34397 .52274 m .35144 .57858 L .32752 .5862 L p .707 .577 .707 r
F P
0 g
s
.33762 .65086 m .32941 .61392 L .3531 .60502 L p .707 .577 .707 r
F P
0 g
s
.35144 .57858 m .34397 .52274 L .37315 .51631 L p .707 .577 .707 r
F P
0 g
s
.43562 .50931 m .44308 .56515 L .41219 .56752 L p .707 .577 .707 r
F P
0 g
s
.41219 .56752 m .40473 .51168 L .43562 .50931 L p .707 .577 .707 r
F P
0 g
s
.47012 .58156 m .47832 .61851 L .45165 .62119 L p .707 .577 .707 r
F P
0 g
s
.45165 .62119 m .44344 .58424 L .47012 .58156 L p .707 .577 .707 r
F P
0 g
s
.3531 .60502 m .36131 .64196 L .33762 .65086 L p .707 .577 .707 r
F P
0 g
s
.34486 .68633 m .34064 .66787 L .36432 .65888 L p .707 .577 .707 r
F P
0 g
s
.38062 .57215 m .37315 .51631 L .40473 .51168 L p .707 .577 .707 r
F P
0 g
s
.37315 .51631 m .38062 .57215 L .35144 .57858 L p .707 .577 .707 r
F P
0 g
s
.40473 .51168 m .41219 .56752 L .38062 .57215 L p .707 .577 .707 r
F P
0 g
s
.36432 .65888 m .36853 .67734 L .34486 .68633 L p .707 .577 .707 r
F P
0 g
s
.48117 .63473 m .48538 .65319 L .45875 .65606 L p .707 .577 .707 r
F P
0 g
s
.45875 .65606 m .45454 .6376 L .48117 .63473 L p .707 .577 .707 r
F P
0 g
s
.36131 .64196 m .3531 .60502 L .38193 .59657 L p .707 .577 .707 r
F P
0 g
s
.44344 .58424 m .45165 .62119 L .42126 .62636 L p .707 .577 .707 r
F P
0 g
s
.42126 .62636 m .41305 .58942 L .44344 .58424 L p .707 .577 .707 r
F P
0 g
s
.38193 .59657 m .39013 .63352 L .36131 .64196 L p .707 .577 .707 r
F P
0 g
s
.36853 .67734 m .36432 .65888 L .39311 .6503 L p .707 .577 .707 r
F P
0 g
s
.39013 .63352 m .38193 .59657 L .41305 .58942 L p .707 .577 .707 r
F P
0 g
s
.41305 .58942 m .42126 .62636 L .39013 .63352 L p .707 .577 .707 r
F P
0 g
s
.39311 .6503 m .39732 .66876 L .36853 .67734 L p .707 .577 .707 r
F P
0 g
s
.45454 .6376 m .45875 .65606 L .42841 .66143 L p .707 .577 .707 r
F P
0 g
s
.42841 .66143 m .42419 .64297 L .45454 .6376 L p .707 .577 .707 r
F P
0 g
s
.39732 .66876 m .39311 .6503 L .42419 .64297 L p .707 .577 .707 r
F P
0 g
s
.42419 .64297 m .42841 .66143 L .39732 .66876 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
VGoo4000M7oo002GOol30009FUH00`00FUIJEP03FUH7001]Ool009Eoo`800003FUH005YF00QJEP03
001JEUYF00UJEP03001JEP0000<006Uoo`00Tgoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF1000IGoo002BOol20004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH4001QOol0095oo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEP00008005ioo`00TGoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH00eYF0`00Fgoo002@Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH3001HOol0091oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP<005Eoo`00Sgoo00<005YF000015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00@005YF000005=oo`00Sgoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH03eYF0P00
DGoo002?Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH2001?Ool008ioo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00IJEP8004eoo`00SWoo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
0P00Bgoo002>Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH2001:Ool008eoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00aJEP8004Qoo`00SGoo00<0
05YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH00UYF00<007ooOol0AGoo002=Ool00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03
FUH00`00Oomoo`14Ool008eoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP8004Aoo`00S7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<007ooOol0@Goo002<Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH20012Ool0
08aoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYF0011Ool008]oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP05001JEUYFFUH00010
Ool008]oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo03eoo`00RWoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0?7oo002:Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00Oomoo`0lOol008Yoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00=JEP8003ioo`00RGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
?Woo0029Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000nOol008Uoo`03001J
EP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0003ioo`00R7oo00<005YF000015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000?Woo0028Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000oOol008Qoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0003moo`00Qgoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000?goo0027Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00gooFUH00009FUH00`00FUIJEP04FUH20010Ool008Mo
o`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00041oo`00QWoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000@7oo0026Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00010Ool008Ioo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP80045oo`00QWoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF0000@Goo0025Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00011
Ool008Eoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80049oo`00QGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000@Woo0024Ool00`00FUH00004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUH00012Ool008Aoo`03001JEP0000AJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP8004=oo`00Q7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF0000@goo0023Ool00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00013
Ool008=oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8004Aoo`00Pgoo00<005YF
000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000A7oo0022Ool00`00FUH00004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00014Ool0089oo`03001JEP0000AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP<004Aoo`00PWoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF0000AGoo0021Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00015Ool0085oo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<004Eoo`00PGoo
00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000AWoo0020Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00016Ool0081oo`03001JEP0000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP<004Ioo`00P7oo00<005YF000015YF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF0000Agoo001oOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUH00017Ool007moo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0004Moo`00Ogoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000B7oo
001oOol00`00FUH00004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00018Ool007ioo`03
001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Qoo`00OWoo00<005YF0000
15YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH004Qoo`00OWoo00<005YF000015YF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YF0000BGoo001mOol00`00FUH00004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00019Ool007eoo`03001JEP0000AJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0004Uoo`00OGoo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF0000BWoo001lOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
001:Ool007aoo`03001JEP0000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Yoo`00
O7oo00<005YF000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Bgoo001kOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001;Ool007]oo`03001JEP0000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004]oo`00Ngoo00<005YF000015YF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YFFUH004]oo`00N7oo3P001UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000C7oo001_Ool90003FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
001<Ool006Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000YJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00=JEP03OomJEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF001<Ool006Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001=Ool0061oo`@000IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0004eoo`00G7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001=Ool005Yoo`8000EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001>Ool005Uoo`8000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0001>Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00CWoo001FOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool005Eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0004moo`00E7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF001?Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00Cgoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001Goo6@00<Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001oo`040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000`Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001EOol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>
0003FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH002ioo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1@000UYF00@005YFFUH000]JEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
0003FUH005YF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00=JEP@00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
001JEP0]Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;Goo001EOol00`00
FUH00005FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<005YFFUH02UYF00<005YFFUH0
2UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00<005YF00001EYF00<005YF0000
0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3P0000=JEP00FUH02eYF00<0
05YFFUH02eYF00<005YFFUH02EYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo
00@005YFFUH000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEPT000=JEP03001JEUYF00=J
EP06001JEP00001JEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;7oo001EOol01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo
001FOol2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9JEP8000EJEP03001JEUYF
00EJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEP0035YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;7oo001FOol015YF001JEP001EYF00<005YFFUH01EYF00H005YF000005YF0009FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo001:Ool>
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00AWoo10000UYF00<005YFFUH0
1EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000oOol70006
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YF
FUH02UYF00<005YFFUH02UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH015YF6P000UYF00<007ooOol0:Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02eYF00<005YFFUH02EYF00D0
05YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00=goo0P0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YFFUIJEP/0009JEP03001JEUYF00IJEP03001JEUYF00]JEP04001JEUYF
0008FUH01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002]oo`00=Goo0P000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P001EYF00<005YFFUH00UYF1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00<goo
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00=J
EP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH01P00FUIJEP00
FUH000EJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000[Ool0035oo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD000UJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00]JEP03001JEUYF00UJEP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
;7oo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH01000FUIJEP000UYF00@005YFFUIJEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP04FUH60007FUH00`00FUIJEP06FUH00`00FUH0000:0009FUH00`00FUIJEP0:FUH01000
FUIJEP002EYF00<005YFFUH00eYF00@005YF000000]JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP/002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00P000=JEP03001JEUYF00=JEP04001JEP000006FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200000eYF001JEP0:FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH:0003FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009J
EP05001JEUYFFUH00006FUH40006FUH40003FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH01@00FUIJEUYF
00002eYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP03001JEUYF
00IJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0:goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF009JEP@000IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH20006FUH01000FUIJEUYF10001UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002]oo`00;Goo00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP04001JEUYFFUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP07
FUH01000FUIJEUYF2`000UYF00D005YFFUIJEP0000aJEP04001JEUYF0009FUH00`00FUIJEP04FUH2
00000eYF001JEP04FUH20006FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUH000000UYF00<005YFFUH0
1EYF0`000eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00<005YFFUH00P0000=JEP000000
0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH90005FUH00`00FUIJEP020005FUH01000FUIJEUYF0`001UYF00<005YFFUH01eYF00<0
05YFFUH010002UYF0`000eYF00@005YFFUH0009JEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEPP000QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF1`0025YF00<005YFFUH01EYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF100000=JEP00FUH00eYF0P000eYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000^Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF0P001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH015YF
0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
0P0015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002Yoo`00;Woo00<005YF00001EYF00<005YFFUH00UYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00@005YF000000MJEP03001J
EUYF00AJEPD000UJEP03001JEUYF009JEP800003FUH005YF00IJEP05001JEUYFFUH00003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH005YF0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Yo
o`00;Woo00<005YF00001EYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@000UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHD000YOol002ioo`04001JEUYF0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH900000eYF001JEP03FUH00`00FUIJEP04FUH300000goo00000005FUH00`00FUIJEP05FUH4
0007FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH3
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo000^Ool01000FUIJEP000UYF0P000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01`0015YF00@005YFFUIJEP8000AJEP03001JEUYF
009JEP<0009oo`04001JEP00FUH40004FUH40002FUH00`00FUIJEP06FUH00`00FUH000030008FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00:Goo
000_Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000EJEP04001JEP000002FUH01@00Oomoo`00FUH02P001UYF00<005YFFUH01EYF0`00
35YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00:Woo000_Ool2FUH20005FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YF
FUH01eYF00<005YF00000UYF00@005YFFUIJEP<00004FUH005YFFUH;00000eYF001JEP08FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH01000FUIJEUYF0P00:goo000_Ool015YF001JEP001EYF00<005YFFUH01EYF
00H005YF000005YF0009FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH000080003FUH00`00
FUIJEP0500000eYF001JEP08FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP040003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000;Goo000_
Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00AJ
EP@000MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000_Ool002moo`80009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP05001JEP00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80039oo`00<7oo0P0000=JEP00FUH00eYF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00AJEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00IJEP800004FUH005YF0005FUH01000FUH000001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Aoo`00<Woo1P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@000=JEPL001EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYF0002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF4000:Goo000eOol20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP0J0005FUH00`00FUH000050002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH200001UYF001JEUYF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEP0000L000=JEP03001JEUYF00=JEP04001JEUYF000YOol003=o
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@00004FUH0
00000002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH20005FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF
1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:7oo000bOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00FUIJ
EP03FUH20003FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH70003FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH00000:7oo000`Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Qoo`00;goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP<000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP8000UJEP03
001JEUYF00YJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP06
001JEP00001JEP002EYF00<005YFFUH01EYF00<005YFFUH00UYF2`0000=JEP0000009goo000_Ool0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<0
05YF00002P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02eYF0`00
1eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF
FUH00UYF1@000eYF00<005YFFUH01eYF00<005YFFUH00UYF200017oo0`000eYF10009goo000`Ool0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`001eYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP04001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP0>0007FUH00`00FUIJEP04FUH7000:Ool200000eYF001JEP04FUH00`00FUH0000W
Ool0031oo`04001JEUYF0003FUH00`00FUIJEP04FUH40005FUH50007FUH50002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH200000eYF001JEP0;FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF100000=JEP00FUH01eYF00<005YFFUH010003goo0P000eYF00<005YFFUH00eYF0P00
:7oo000`Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP@000=JEPD000IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00IJEP<001AJEP03001JEUYF00=JEP04001JEUYF0004FUH30005
FUH00`00FUIJEP05FUH4000@Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0031oo`04001J
EUYF0004FUH01000FUH000001UYF00<005YFFUH01UYF10000UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02UYF0P0025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP<000MJEP03
001JEUYF009JEP80011oo`@00003FUH005YF00IJEP03001JEUYF008002Yoo`00<Goo00@005YFFUH0
00=JEP<000MJEP03001JEUYF009JEP@000IJEP03001JEUYF00MJEP04001JEUYFFUH:0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH40006FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUH00002000=Ool50005
FUH00`00FUIJEP05FUH3000/Ool0035oo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH50000
0eYF001JEP08FUH00`00FUIJEP04FUH60007Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH20003FUH2000=FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00EJEP03001JEUYF00=JEP<000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8002ioo`00
<Goo00<005YFFUH00P001EYF00@005YFFUIJEP@000EJEP03001JEUYF00MJEP03001JEUYF00@000]o
o`8000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00]JEP03001J
EUYF00UJEP8000EJEP800003FUH005YF00QJEP03001JEUYF00=JEP03001JEUYF00<000EJEP03001J
EP0000<00003FUH0000000Qoo`@000IJEP03001JEUYF00IJEP03001JEP0000<0031oo`00<Woo00AJ
EP00FUH000EJEP06001JEP00001JEP0025YF00<005YFFUH015YF1@002goo100000=JEP00FUH00UYF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF0P001eYF0P002EYF
00<005YFFUH01UYF00<005YF00001EYF0P000UYF00<005YFFUH00P0017oo100000=JEP00FUH01eYF
00<005YFFUH01EYF0`00=7oo000bOol01000FUIJEP001EYF0P000eYF00<005YFFUH01UYF00<005YF
FUH010003Goo0`001EYF00<005YFFUH00UYF00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00MJEP8000MJEP8000AJEP03001JEUYF0080009JEP03001J
EUYF008000AJEP03001JEUYF00H000EJEP03001JEUYF00MJEP03001JEUYF009JEP8003Moo`00<Woo
0P000UYF00<005YFFUH00P001UYF00<005YFFUH015YF10003goo0P0000=JEP00FUH01UYF00@005YF
FUIJEP800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00UJEP8000]J
EP8000EJEP03001JEUYF00=JEP03001JEUYF0080009JEP`000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008003Uoo`00<goo0P0000=JEP0000000P001eYF00<005YFFUH0100047oo0`00
0eYF00<005YFFUH01EYF00H005YF000007oo000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH2000;FUH00`00FUH00004FUH00`00FUIJEP06FUH300000eYF00000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol003Eoo`8000=JEP03001JEUYF00AJEP<0
011oo`@000IJEP03001JEUYF00AJEP<000Aoo`03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040010Ool0
03Aoo`8000AJEP03001JEUYF009JEP8000Moo`<000Eoo`@0009JEP03001JEUYF00IJEP04001JEUYF
FUH20008Ool00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;
FUH00`00FUIJEP02FUH30005FUH01000FUIJEP000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00A7oo000cOol00`00FUH00005FUH01000FUH0000027oo2@001UYF00<0
05YFFUH01UYF00@005YF000000]oo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP8000]JEP03001JEUYF00AJEP03001JEUYF00YJEP800003FUH005YF00AJEP03001JEUYF009J
EPP004Yoo`00<goo00@005YFFUH000=JEP<000Aoo`/00003FUH005YF00QJEP03001JEUYF00AJEP<0
00moo`03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000/0059oo`00<goo
00D005YFFUH005YF00T000=JEP03001JEUYF00D00003FUH005YF00QJEP03001JEUYF00@001=oo`05
001JEUYFFUH0000;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00P00Dgoo000cOol20000
0eYF00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF1@0067oo0P00
3EYF00<005YFFUH02UYF00<005YFFUH02UYF0P002eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YFFUH00UYF00<005YFFUH01EYF0`00EGoo000dOol200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP04000OOol2000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEP002UYF00<005YFFUH00eYF0P00Egoo000dOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF1@009Goo0P0025YF00<005YFFUH02eYF00<0
05YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YF
00000`00FGoo000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04000/Ool2
0006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF3P00DWoo000eOol200000eYF001JEP04FUH01000FUIJEUYF1P00<Woo
0P0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEPP000=JEP03001JEUYF00=JEP04001JEP00001@Ool003Moo`/003Yoo`80
00mJEP03001JEUYF00UJEP8000]JEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001?Ool007ioo`<000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00EJEP8000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00001?Ool0085oo`8000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF001?Ool008=o
o`8000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF009JEP/00003FUH0000004ioo`00QGoo0`0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF20001Woo0P000UYF1000CWoo0028
Ool2000>FUH00`00FUIJEP0BFUH00`00FUIJEP03FUH6000<Ool20005FUH00`00FUH0001>Ool008Yo
o`@000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`@00003FUH005YF
00AJEP8004moo`00SWoo1P0045YF00<005YFFUH01UYF00@005YFFUIJEP8000]oo`<000EJEP03001J
EUYF00=JEP03001oogoo04ioo`00U7oo1P002UYF00<005YFFUH01eYF0`002goo0P0000=JEP00FUH0
1UYF00<005YFFUH00P00DGoo002GOol200000eYF000000040008FUH6000;Ool30003FUH00`00FUIJ
EP05FUH3001COol009Ioo`03001JEUYF009JEP03001JEUYF009JEPP000eoo`@000MJEP03001JEUYF
00=JEP8005Eoo`00UGoo0P001EYF00@005YFFUIJEP8000moo`@0009JEP03001JEUYF00IJEP03001J
EP0000<005Moo`00U7oo00<005YF00001EYF00@005YF000000]oo`H000IJEP03001JEUYF00EJEP<0
05]oo`00U7oo00@005YFFUH000=JEP<000Eoo`P000=JEP03001JEUYF00MJEP03001JEUYF009JEP80
05ioo`00U7oo00D005YFFUH005YF00X000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
0080061oo`00UGoo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@006=oo`00UGoo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1000Igoo002EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6001[Ool0
09Ioo`800003FUH005YF00AJEP03001JEUYF009JEPP0075oo`00V7oo3000NGoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60099 .74931 m .59637 .69344 L .5653 .69418 L p .707 .577 .707 r
F P
0 g
s
.59637 .69344 m .60099 .74931 L .63273 .74616 L p .707 .577 .707 r
F P
0 g
s
.63273 .74616 m .6281 .69028 L .59637 .69344 L p .707 .577 .707 r
F P
0 g
s
.6281 .69028 m .63273 .74616 L .66203 .74089 L p .707 .577 .707 r
F P
0 g
s
.66203 .74089 m .65741 .68502 L .6281 .69028 L p .707 .577 .707 r
F P
0 g
s
.56993 .75005 m .5653 .69418 L .53796 .69242 L p .707 .577 .707 r
F P
0 g
s
.5653 .69418 m .56993 .75005 L .60099 .74931 L p .707 .577 .707 r
F P
0 g
s
.65741 .68502 m .66203 .74089 L .68603 .73403 L p .707 .577 .707 r
F P
0 g
s
.68603 .73403 m .68141 .67816 L .65741 .68502 L p .707 .577 .707 r
F P
0 g
s
.6061 .81152 m .601 .7743 L .57013 .77677 L p .707 .577 .707 r
F P
0 g
s
.601 .7743 m .6061 .81152 L .63767 .8068 L p .707 .577 .707 r
F P
0 g
s
.63767 .8068 m .63257 .76957 L .601 .7743 L p .707 .577 .707 r
F P
0 g
s
.53796 .69242 m .54258 .74829 L .56993 .75005 L p .707 .577 .707 r
F P
0 g
s
.63257 .76957 m .63767 .8068 L .66684 .80028 L p .707 .577 .707 r
F P
0 g
s
.66684 .80028 m .66174 .76306 L .63257 .76957 L p .707 .577 .707 r
F P
0 g
s
.54258 .74829 m .53796 .69242 L .517 .68835 L p .707 .577 .707 r
F P
0 g
s
.57523 .814 m .57013 .77677 L .54297 .77676 L p .707 .577 .707 r
F P
0 g
s
.57013 .77677 m .57523 .814 L .6061 .81152 L p .707 .577 .707 r
F P
0 g
s
.66174 .76306 m .66684 .80028 L .69075 .79262 L p .707 .577 .707 r
F P
0 g
s
.69075 .79262 m .68565 .7554 L .66174 .76306 L p .707 .577 .707 r
F P
0 g
s
.68141 .67816 m .68603 .73403 L .70239 .72624 L p .707 .577 .707 r
F P
0 g
s
.70239 .72624 m .69776 .67037 L .68141 .67816 L p .707 .577 .707 r
F P
0 g
s
.61047 .85871 m .60785 .84011 L .577 .8427 L p .707 .577 .707 r
F P
0 g
s
.60785 .84011 m .61047 .85871 L .64202 .85388 L p .707 .577 .707 r
F P
0 g
s
.64202 .85388 m .6394 .83527 L .60785 .84011 L p .707 .577 .707 r
F P
0 g
s
.54297 .77676 m .54808 .81398 L .57523 .814 L p .707 .577 .707 r
F P
0 g
s
.517 .68835 m .52162 .74422 L .54258 .74829 L p .707 .577 .707 r
F P
0 g
s
.6394 .83527 m .64202 .85388 L .67118 .84728 L p .707 .577 .707 r
F P
0 g
s
.67118 .84728 m .66856 .82868 L .6394 .83527 L p .707 .577 .707 r
F P
0 g
s
.577 .8427 m .57962 .86131 L .61047 .85871 L p .707 .577 .707 r
F P
0 g
s
.57962 .86131 m .577 .8427 L .54986 .8428 L p .707 .577 .707 r
F P
0 g
s
.54808 .81398 m .54297 .77676 L .52219 .77425 L p .707 .577 .707 r
F P
0 g
s
.52162 .74422 m .517 .68835 L .50449 .68235 L p .707 .577 .707 r
F P
0 g
s
.54986 .8428 m .55248 .86141 L .57962 .86131 L p .707 .577 .707 r
F P
0 g
s
.66856 .82868 m .67118 .84728 L .69508 .83957 L p .707 .577 .707 r
F P
0 g
s
.69508 .83957 m .69246 .82096 L .66856 .82868 L p .707 .577 .707 r
F P
0 g
s
.68565 .7554 m .69075 .79262 L .70707 .78456 L p .707 .577 .707 r
F P
0 g
s
.70707 .78456 m .70197 .74734 L .68565 .7554 L p .707 .577 .707 r
F P
0 g
s
.52219 .77425 m .52729 .81147 L .54808 .81398 L p .707 .577 .707 r
F P
0 g
s
.69776 .67037 m .70239 .72624 L .70949 .71829 L p .707 .577 .707 r
F P
0 g
s
.70949 .71829 m .70486 .66242 L .69776 .67037 L p .707 .577 .707 r
F P
0 g
s
.55248 .86141 m .54986 .8428 L .52909 .84041 L p .707 .577 .707 r
F P
0 g
s
.50449 .68235 m .50911 .73822 L .52162 .74422 L p .707 .577 .707 r
F P
0 g
s
.52909 .84041 m .53171 .85901 L .55248 .86141 L p .707 .577 .707 r
F P
0 g
s
.69246 .82096 m .69508 .83957 L .7114 .83149 L p .707 .577 .707 r
F P
0 g
s
.7114 .83149 m .70878 .81288 L .69246 .82096 L p .707 .577 .707 r
F P
0 g
s
.52729 .81147 m .52219 .77425 L .50981 .7695 L p .707 .577 .707 r
F P
0 g
s
.50911 .73822 m .50449 .68235 L .50164 .67502 L p .707 .577 .707 r
F P
0 g
s
.50164 .67502 m .50626 .73089 L .50911 .73822 L p .707 .577 .707 r
F P
0 g
s
.50626 .73089 m .50164 .67502 L .50874 .66707 L p .707 .577 .707 r
F P
0 g
s
.50874 .66707 m .51336 .72294 L .50626 .73089 L p .707 .577 .707 r
F P
0 g
s
.51336 .72294 m .50874 .66707 L .52509 .65929 L p .707 .577 .707 r
F P
0 g
s
.49038 .82544 m .58053 .34202 L .53725 .33141 L p .707 .577 .707 r
F P
0 g
s
.50981 .7695 m .51491 .80672 L .52729 .81147 L p .707 .577 .707 r
F P
0 g
s
.51491 .80672 m .50981 .7695 L .50705 .76297 L p .707 .577 .707 r
F P
0 g
s
.50705 .76297 m .51215 .80019 L .51491 .80672 L p .707 .577 .707 r
F P
0 g
s
.51215 .80019 m .50705 .76297 L .51419 .7553 L p .707 .577 .707 r
F P
0 g
s
.51419 .7553 m .51929 .79252 L .51215 .80019 L p .707 .577 .707 r
F P
0 g
s
.53171 .85901 m .52909 .84041 L .51672 .83574 L p .707 .577 .707 r
F P
0 g
s
.51672 .83574 m .51934 .85435 L .53171 .85901 L p .707 .577 .707 r
F P
0 g
s
.51934 .85435 m .51672 .83574 L .51397 .82926 L p .707 .577 .707 r
F P
0 g
s
.51397 .82926 m .51659 .84787 L .51934 .85435 L p .707 .577 .707 r
F P
0 g
s
.51659 .84787 m .51397 .82926 L .5211 .82161 L p .707 .577 .707 r
F P
0 g
s
.5211 .82161 m .52372 .84022 L .51659 .84787 L p .707 .577 .707 r
F P
0 g
s
.52509 .65929 m .52971 .71516 L .51336 .72294 L p .707 .577 .707 r
F P
0 g
s
.51929 .79252 m .51419 .7553 L .53051 .74724 L p .707 .577 .707 r
F P
0 g
s
.52971 .71516 m .52509 .65929 L .54831 .65265 L p .707 .577 .707 r
F P
0 g
s
.58053 .34202 m .53348 .59432 L p .5495 .65731 L .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .55177 .68476 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .5495 .65731 L p .56218 .68396 L .707 .577 .707 r
F P
0 g
s
.55177 .68476 m .56218 .68396 L .56292 .68551 L .707 .577 .707 r
F
.53742 .81353 m .54004 .83214 L .52372 .84022 L p F P
0 g
s
.55442 .73958 m .55952 .7768 L .53561 .78446 L p .707 .577 .707 r
F P
0 g
s
.58302 .70303 m .58132 .68251 L p .61013 .644 L .707 .577 .707 r
F P
0 g
s
.62482 .34807 m .56218 .68396 L p .58132 .68251 L .707 .577 .707 r
F P
0 g
s
.59294 .66196 m .62482 .34807 L .58132 .68251 L .707 .577 .707 r
F
.60267 .64474 m .61013 .644 L p .58132 .68251 L F P
0 g
s
.61476 .69987 m .61013 .644 L .6412 .64327 L p .707 .577 .707 r
F P
0 g
s
.61013 .644 m .61476 .69987 L .58736 .7026 L p .707 .577 .707 r
F P
0 g
s
.58736 .7026 m .58302 .70303 L p .59982 .66647 L .707 .577 .707 r
F P
0 g
s
.59982 .66647 m .61013 .644 L .58736 .7026 L .707 .577 .707 r
F
.6412 .64327 m .64582 .69914 L .61476 .69987 L p F P
0 g
s
.62025 .76556 m .61515 .72834 L .64602 .72586 L p .707 .577 .707 r
F P
0 g
s
.58869 .77029 m .58359 .73306 L .61515 .72834 L p .707 .577 .707 r
F P
0 g
s
.61515 .72834 m .62025 .76556 L .58869 .77029 L p .707 .577 .707 r
F P
0 g
s
.56395 .82442 m .56133 .80582 L .59049 .79922 L p .707 .577 .707 r
F P
0 g
s
.59049 .79922 m .5931 .81783 L .56395 .82442 L p .707 .577 .707 r
F P
0 g
s
.5931 .81783 m .59049 .79922 L .62203 .79439 L p .707 .577 .707 r
F P
0 g
s
.62203 .79439 m .62465 .81299 L .5931 .81783 L p .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .60925 .82806 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.66578 .34898 m .61454 .62375 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.58359 .73306 m .58869 .77029 L .55952 .7768 L p .707 .577 .707 r
F P
0 g
s
.61454 .62375 m .57563 .83239 L p .64316 .54074 L .707 .577 .707 r
F P
0 g
s
.57563 .83239 m .66578 .34898 L .62482 .34807 L p .707 .577 .707 r
F P
0 g
s
.58132 .68251 m .5784 .64716 L .60267 .64474 L p .707 .577 .707 r
F P
0 g
s
.59093 .68177 m .59294 .66196 L .58132 .68251 L .707 .577 .707 r
F
.5784 .64716 m .58302 .70303 L .57218 .70498 L p F P
0 g
s
.57218 .70498 m .55372 .7083 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56292 .68551 m .5784 .64716 L .57218 .70498 L .707 .577 .707 r
F
.62482 .34807 m .58053 .34202 L p .55074 .65993 L F P
0 g
s
.52372 .84022 m .5211 .82161 L .53742 .81353 L p .707 .577 .707 r
F P
0 g
s
.55372 .7083 m .52971 .71516 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.54909 .65242 m .5495 .65731 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.5495 .65731 m .55372 .7083 L p .54863 .65391 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .56218 .68396 L .55074 .65993 L .707 .577 .707 r
F
.53561 .78446 m .53051 .74724 L .55442 .73958 L p F P
0 g
s
.54004 .83214 m .53742 .81353 L .56133 .80582 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .55968 .69736 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.55968 .69736 m .56218 .68396 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .62482 .34807 L p .55074 .65993 L .707 .577 .707 r
F P
0 g
s
.56133 .80582 m .56395 .82442 L .54004 .83214 L p .707 .577 .707 r
F P
0 g
s
.55952 .7768 m .55442 .73958 L .58359 .73306 L p .707 .577 .707 r
F P
0 g
s
.53467 .83149 m .57563 .83239 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55074 .65993 m .58053 .34202 L .5495 .65731 L .707 .577 .707 r
F
.54909 .65242 m .5784 .64716 L p .56292 .68551 L F P
0 g
s
.5495 .65731 m .54909 .65242 L p .56292 .68551 L .707 .577 .707 r
F P
0 g
s
.56218 .68396 m .53467 .83149 L p .59093 .68177 L .707 .577 .707 r
F P
0 g
s
.55059 .6616 m .55074 .65993 L .5495 .65731 L .707 .577 .707 r
F
.54831 .65265 m .54909 .65242 L p .54863 .65391 L F P
0 g
s
.52971 .71516 m .54831 .65265 L .54863 .65391 L .707 .577 .707 r
F
.53051 .74724 m .53561 .78446 L .51929 .79252 L p F P
0 g
s
.49038 .82544 m .53467 .83149 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.53348 .59432 m .49038 .82544 L p .55059 .6616 L .707 .577 .707 r
F P
0 g
s
.44709 .81483 m .53725 .33141 L .49921 .31729 L p .707 .577 .707 r
F P
0 g
s
.53725 .33141 m .44709 .81483 L .49038 .82544 L p .707 .577 .707 r
F P
0 g
s
.70197 .74734 m .70707 .78456 L .7142 .77689 L p .707 .577 .707 r
F P
0 g
s
.7142 .77689 m .7091 .73967 L .70197 .74734 L p .707 .577 .707 r
F P
0 g
s
.70486 .66242 m .70949 .71829 L .70664 .71096 L p .707 .577 .707 r
F P
0 g
s
.70664 .71096 m .70202 .65509 L .70486 .66242 L p .707 .577 .707 r
F P
0 g
s
.70878 .81288 m .7114 .83149 L .71854 .82384 L p .707 .577 .707 r
F P
0 g
s
.71854 .82384 m .71592 .80523 L .70878 .81288 L p .707 .577 .707 r
F P
0 g
s
.64582 .69914 m .6412 .64327 L .66855 .64502 L p .707 .577 .707 r
F P
0 g
s
.64602 .72586 m .65113 .76309 L .62025 .76556 L p .707 .577 .707 r
F P
0 g
s
.60925 .82806 m .69941 .34464 L .66578 .34898 L p .707 .577 .707 r
F P
0 g
s
.40906 .8007 m .49921 .31729 L .47014 .30102 L p .707 .577 .707 r
F P
0 g
s
.49921 .31729 m .40906 .8007 L .44709 .81483 L p .707 .577 .707 r
F P
0 g
s
.7091 .73967 m .7142 .77689 L .71144 .77036 L p .707 .577 .707 r
F P
0 g
s
.71144 .77036 m .70634 .73314 L .7091 .73967 L p .707 .577 .707 r
F P
0 g
s
.70202 .65509 m .70664 .71096 L .69413 .70497 L p .707 .577 .707 r
F P
0 g
s
.69413 .70497 m .6895 .6491 L .70202 .65509 L p .707 .577 .707 r
F P
0 g
s
.66855 .64502 m .67317 .70089 L .64582 .69914 L p .707 .577 .707 r
F P
0 g
s
.65289 .79179 m .65551 .8104 L .62465 .81299 L p .707 .577 .707 r
F P
0 g
s
.62465 .81299 m .62203 .79439 L .65289 .79179 L p .707 .577 .707 r
F P
0 g
s
.69941 .34464 m .60925 .82806 L .63225 .81891 L p .707 .577 .707 r
F P
0 g
s
.65113 .76309 m .64602 .72586 L .67318 .72588 L p .707 .577 .707 r
F P
0 g
s
.63225 .81891 m .7224 .3355 L .69941 .34464 L p .707 .577 .707 r
F P
0 g
s
.71592 .80523 m .71854 .82384 L .71578 .81736 L p .707 .577 .707 r
F P
0 g
s
.71578 .81736 m .71317 .79875 L .71592 .80523 L p .707 .577 .707 r
F P
0 g
s
.37998 .78444 m .47014 .30102 L .45288 .28422 L p .707 .577 .707 r
F P
0 g
s
.47014 .30102 m .37998 .78444 L .40906 .8007 L p .707 .577 .707 r
F P
0 g
s
.25798 .70845 m .25336 .65258 L .2223 .65332 L p .707 .577 .707 r
F P
0 g
s
.25336 .65258 m .25798 .70845 L .28972 .7053 L p .707 .577 .707 r
F P
0 g
s
.28972 .7053 m .2851 .64943 L .25336 .65258 L p .707 .577 .707 r
F P
0 g
s
.2851 .64943 m .28972 .7053 L .31902 .70003 L p .707 .577 .707 r
F P
0 g
s
.31902 .70003 m .3144 .64416 L .2851 .64943 L p .707 .577 .707 r
F P
0 g
s
.22692 .70919 m .2223 .65332 L .19495 .65156 L p .707 .577 .707 r
F P
0 g
s
.2223 .65332 m .22692 .70919 L .25798 .70845 L p .707 .577 .707 r
F P
0 g
s
.70634 .73314 m .71144 .77036 L .69907 .76561 L p .707 .577 .707 r
F P
0 g
s
.69907 .76561 m .69397 .72839 L .70634 .73314 L p .707 .577 .707 r
F P
0 g
s
.3144 .64416 m .31902 .70003 L .34303 .69317 L p .707 .577 .707 r
F P
0 g
s
.34303 .69317 m .3384 .6373 L .3144 .64416 L p .707 .577 .707 r
F P
0 g
s
.2631 .76445 m .258 .72723 L .22712 .72971 L p .707 .577 .707 r
F P
0 g
s
.258 .72723 m .2631 .76445 L .29466 .75973 L p .707 .577 .707 r
F P
0 g
s
.29466 .75973 m .28956 .72251 L .258 .72723 L p .707 .577 .707 r
F P
0 g
s
.6895 .6491 m .69413 .70497 L .67317 .70089 L p .707 .577 .707 r
F P
0 g
s
.67317 .70089 m .66855 .64502 L .6895 .6491 L p .707 .577 .707 r
F P
0 g
s
.28956 .72251 m .29466 .75973 L .32383 .75322 L p .707 .577 .707 r
F P
0 g
s
.32383 .75322 m .31873 .716 L .28956 .72251 L p .707 .577 .707 r
F P
0 g
s
.19495 .65156 m .19957 .70743 L .22692 .70919 L p .707 .577 .707 r
F P
0 g
s
.19957 .70743 m .19495 .65156 L .17399 .64749 L p .707 .577 .707 r
F P
0 g
s
.71317 .79875 m .71578 .81736 L .70342 .81269 L p .707 .577 .707 r
F P
0 g
s
.70342 .81269 m .7008 .79409 L .71317 .79875 L p .707 .577 .707 r
F P
0 g
s
.23222 .76693 m .22712 .72971 L .19997 .72969 L p .707 .577 .707 r
F P
0 g
s
.22712 .72971 m .23222 .76693 L .2631 .76445 L p .707 .577 .707 r
F P
0 g
s
.26746 .80181 m .26484 .7832 L .23399 .7858 L p .707 .577 .707 r
F P
0 g
s
.26484 .7832 m .26746 .80181 L .29901 .79698 L p .707 .577 .707 r
F P
0 g
s
.29901 .79698 m .29639 .77837 L .26484 .7832 L p .707 .577 .707 r
F P
0 g
s
.31873 .716 m .32383 .75322 L .34774 .74556 L p .707 .577 .707 r
F P
0 g
s
.34774 .74556 m .34264 .70833 L .31873 .716 L p .707 .577 .707 r
F P
0 g
s
.7224 .3355 m .63225 .81891 L .64236 .80585 L p .707 .577 .707 r
F P
0 g
s
.64236 .80585 m .70862 .45058 L p .7224 .3355 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .71914 .39414 L p .7203 .37334 L .707 .577 .707 r
F P
0 g
s
.70862 .45058 m .7203 .37334 L .7224 .3355 L .707 .577 .707 r
F
.68528 .72194 m .68018 .68472 L .67333 .68389 L p F P
0 g
s
.64236 .80585 m .63861 .79015 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67714 .61456 L .64236 .80585 L .707 .577 .707 r
F
.71914 .39414 m .64236 .80585 L p .7085 .44207 L F P
0 g
s
.71914 .39414 m .73252 .32243 L .7299 .32582 L p .707 .577 .707 r
F P
0 g
s
.7299 .32582 m .7224 .3355 L p .71914 .39414 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .73252 .32243 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .66428 .65248 L p .6691 .63825 L .707 .577 .707 r
F P
0 g
s
.63861 .79015 m .62135 .77334 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .65713 .63165 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.64984 .64959 m .65713 .63165 L .63861 .79015 L .707 .577 .707 r
F
.67752 .58151 m .66688 .63854 L p .65713 .63165 L F P
0 g
s
.66688 .63854 m .63861 .79015 L p .65713 .63165 L .707 .577 .707 r
F P
0 g
s
.6542 .59631 m .64169 .59031 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .6542 .59631 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .66306 .61706 L .66169 .65274 L .707 .577 .707 r
F
.66306 .61706 m .6542 .59631 L .65846 .62838 L F
.66306 .61706 m .65846 .62838 L .66169 .65274 L F
.6734 .60004 m .67023 .59942 L p .66737 .62717 L F P
0 g
s
.67023 .59942 m .6542 .59631 L p .66306 .61706 L .707 .577 .707 r
F P
0 g
s
.66737 .62717 m .67023 .59942 L .66306 .61706 L .707 .577 .707 r
F
.64984 .64959 m .65337 .629 L .65441 .62973 L F
.64169 .59031 m .64209 .5952 L p .65217 .62816 L F P
0 g
s
.63815 .57735 m .64209 .5952 L .62135 .77334 L .707 .577 .707 r
F
.64886 .62582 m .64636 .63922 L p .64209 .5952 L F P
0 g
s
.64636 .63922 m .62135 .77334 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64812 .65381 m .7115 .28992 L .64984 .64959 L .707 .577 .707 r
F
.63984 .67417 m .64636 .63922 L p .64812 .65381 L F P
0 g
s
.65217 .62816 m .64209 .5952 L .64886 .62582 L .707 .577 .707 r
F
.64636 .63922 m .7115 .28992 L p .64812 .65381 L F P
0 g
s
.64631 .64618 m .64436 .62264 L p .63884 .58298 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64209 .5952 L p .6402 .58807 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .6402 .58807 L .63884 .58298 L .707 .577 .707 r
F
.64209 .5952 m .64169 .59031 L .6416 .59007 L p F P
0 g
s
.7115 .28992 m .64886 .62582 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.6416 .59007 m .63884 .58298 L p .64209 .5952 L .707 .577 .707 r
F P
0 g
s
.64209 .5952 m .64436 .62264 L p .64886 .62582 L .707 .577 .707 r
F P
0 g
s
.62135 .77334 m .59228 .75708 L p .63815 .57735 L .707 .577 .707 r
F P
0 g
s
.72876 .30673 m .67752 .58151 L p .64984 .64959 L .707 .577 .707 r
F P
0 g
s
.64631 .64618 m .65883 .65218 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.64436 .62264 m .64631 .64618 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.7115 .28992 m .72876 .30673 L p .65441 .62973 L .707 .577 .707 r
F P
0 g
s
.65337 .629 m .7115 .28992 L .65441 .62973 L .707 .577 .707 r
F
.62135 .77334 m .63984 .67417 L p .64984 .64959 L F P
0 g
s
.65883 .65218 m .65713 .63165 L p .65217 .62816 L .707 .577 .707 r
F P
0 g
s
.65883 .65218 m .66169 .65274 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65713 .63165 m .65883 .65218 L p .65846 .62838 L .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .66449 .71944 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64702 .67746 m .64955 .69594 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.64955 .69594 m .65212 .71468 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .67752 .58151 L .7085 .44207 L .707 .577 .707 r
F
.66428 .65248 m .67752 .58151 L p .6691 .63825 L F P
0 g
s
.67752 .58151 m .72876 .30673 L p .7085 .44207 L .707 .577 .707 r
F P
0 g
s
.6691 .63825 m .7085 .44207 L .67714 .61456 L .707 .577 .707 r
F
.66169 .65274 m .67978 .65625 L p .66737 .62717 L F P
0 g
s
.66449 .71944 m .65939 .68221 L .6548 .68045 L p .707 .577 .707 r
F P
0 g
s
.6548 .68045 m .64702 .67746 L p .65186 .6891 L .707 .577 .707 r
F P
0 g
s
.66449 .71944 m .6548 .68045 L .65186 .6891 L .707 .577 .707 r
F
.73252 .32243 m .71914 .39414 L p .7085 .44207 L F P
0 g
s
.67516 .60038 m .6734 .60004 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.6784 .65302 m .6734 .60004 L .66737 .62717 L .707 .577 .707 r
F
.67333 .68389 m .65939 .68221 L p .67091 .69989 L F P
0 g
s
.68528 .72194 m .67333 .68389 L .67091 .69989 L .707 .577 .707 r
F
.67978 .65625 m .67913 .64838 L p .6784 .65302 L F P
0 g
s
.67913 .64838 m .67516 .60038 L p .6784 .65302 L .707 .577 .707 r
F P
0 g
s
.29639 .77837 m .29901 .79698 L .32817 .79038 L p .707 .577 .707 r
F P
0 g
s
.32817 .79038 m .32555 .77177 L .29639 .77837 L p .707 .577 .707 r
F P
0 g
s
.3384 .6373 m .34303 .69317 L .35938 .68538 L p .707 .577 .707 r
F P
0 g
s
.35938 .68538 m .35475 .62951 L .3384 .6373 L p .707 .577 .707 r
F P
0 g
s
.36839 .77459 m .36577 .75598 L .34946 .76406 L p .707 .577 .707 r
F P
0 g
s
.35896 .70027 m .36406 .7375 L .37119 .72982 L p .707 .577 .707 r
F P
0 g
s
.37119 .72982 m .36609 .6926 L .35896 .70027 L p .707 .577 .707 r
F P
0 g
s
.36609 .6926 m .37119 .72982 L .36844 .72329 L p .707 .577 .707 r
F P
0 g
s
.36577 .75598 m .36839 .77459 L .37553 .76693 L p .707 .577 .707 r
F P
0 g
s
.37553 .76693 m .37291 .74833 L .36577 .75598 L p .707 .577 .707 r
F P
0 g
s
.37016 .74185 m .37278 .76046 L .36041 .75579 L p .707 .577 .707 r
F P
0 g
s
.34264 .70833 m .34774 .74556 L .36406 .7375 L p .707 .577 .707 r
F P
0 g
s
.36041 .75579 m .35779 .73718 L .37016 .74185 L p .707 .577 .707 r
F P
0 g
s
.36273 .76764 m .45288 .28422 L .44913 .26852 L p .707 .577 .707 r
F P
0 g
s
.37291 .74833 m .37553 .76693 L .37278 .76046 L p .707 .577 .707 r
F P
0 g
s
.37278 .76046 m .37016 .74185 L .37291 .74833 L p .707 .577 .707 r
F P
0 g
s
.45288 .28422 m .36273 .76764 L .37998 .78444 L p .707 .577 .707 r
F P
0 g
s
.19997 .72969 m .20507 .76691 L .23222 .76693 L p .707 .577 .707 r
F P
0 g
s
.23399 .7858 m .23661 .80441 L .26746 .80181 L p .707 .577 .707 r
F P
0 g
s
.17399 .64749 m .17861 .70336 L .19957 .70743 L p .707 .577 .707 r
F P
0 g
s
.69397 .72839 m .69907 .76561 L .67828 .7631 L p .707 .577 .707 r
F P
0 g
s
.67828 .7631 m .67318 .72588 L .69397 .72839 L p .707 .577 .707 r
F P
0 g
s
.23661 .80441 m .23399 .7858 L .20685 .7859 L p .707 .577 .707 r
F P
0 g
s
.20507 .76691 m .19997 .72969 L .17918 .72718 L p .707 .577 .707 r
F P
0 g
s
.20685 .7859 m .20947 .80451 L .23661 .80441 L p .707 .577 .707 r
F P
0 g
s
.32555 .77177 m .32817 .79038 L .35207 .78267 L p .707 .577 .707 r
F P
0 g
s
.35207 .78267 m .34946 .76406 L .32555 .77177 L p .707 .577 .707 r
F P
0 g
s
.17861 .70336 m .17399 .64749 L .16148 .64149 L p .707 .577 .707 r
F P
0 g
s
.36406 .7375 m .35896 .70027 L .34264 .70833 L p .707 .577 .707 r
F P
0 g
s
.17918 .72718 m .18428 .76441 L .20507 .76691 L p .707 .577 .707 r
F P
0 g
s
.7008 .79409 m .70342 .81269 L .68265 .8103 L p .707 .577 .707 r
F P
0 g
s
.68265 .8103 m .68003 .79169 L .7008 .79409 L p .707 .577 .707 r
F P
0 g
s
.20947 .80451 m .20685 .7859 L .18608 .7835 L p .707 .577 .707 r
F P
0 g
s
.35475 .62951 m .35938 .68538 L .36648 .67744 L p .707 .577 .707 r
F P
0 g
s
.36648 .67744 m .36185 .62156 L .35475 .62951 L p .707 .577 .707 r
F P
0 g
s
.18608 .7835 m .1887 .80211 L .20947 .80451 L p .707 .577 .707 r
F P
0 g
s
.16148 .64149 m .1661 .69736 L .17861 .70336 L p .707 .577 .707 r
F P
0 g
s
.67318 .72588 m .67828 .7631 L .65113 .76309 L p .707 .577 .707 r
F P
0 g
s
.34946 .76406 m .35207 .78267 L .36839 .77459 L p .707 .577 .707 r
F P
0 g
s
.18428 .76441 m .17918 .72718 L .1668 .72243 L p .707 .577 .707 r
F P
0 g
s
.1668 .72243 m .1719 .75966 L .18428 .76441 L p .707 .577 .707 r
F P
0 g
s
.1661 .69736 m .16148 .64149 L .15863 .63416 L p .707 .577 .707 r
F P
0 g
s
.36844 .72329 m .36334 .68607 L .36609 .6926 L p .707 .577 .707 r
F P
0 g
s
.36334 .68607 m .36844 .72329 L .35606 .71854 L p .707 .577 .707 r
F P
0 g
s
.35779 .73718 m .36041 .75579 L .33964 .75339 L p .707 .577 .707 r
F P
0 g
s
.44913 .26852 m .35897 .75194 L .36273 .76764 L p .707 .577 .707 r
F P
0 g
s
.35897 .75194 m .44913 .26852 L .45924 .25545 L p .707 .577 .707 r
F P
0 g
s
.68003 .79169 m .68265 .8103 L .65551 .8104 L p .707 .577 .707 r
F P
0 g
s
.65551 .8104 m .65289 .79179 L .68003 .79169 L p .707 .577 .707 r
F P
0 g
s
.1887 .80211 m .18608 .7835 L .17371 .77884 L p .707 .577 .707 r
F P
0 g
s
.17371 .77884 m .17633 .79745 L .1887 .80211 L p .707 .577 .707 r
F P
0 g
s
.15863 .63416 m .16325 .69003 L .1661 .69736 L p .707 .577 .707 r
F P
0 g
s
.36185 .62156 m .36648 .67744 L .36363 .67011 L p .707 .577 .707 r
F P
0 g
s
.36363 .67011 m .35901 .61423 L .36185 .62156 L p .707 .577 .707 r
F P
0 g
s
.1719 .75966 m .1668 .72243 L .16405 .7159 L p .707 .577 .707 r
F P
0 g
s
.16405 .7159 m .16915 .75312 L .1719 .75966 L p .707 .577 .707 r
F P
0 g
s
.16325 .69003 m .15863 .63416 L .16573 .62621 L p .707 .577 .707 r
F P
0 g
s
.17633 .79745 m .17371 .77884 L .17096 .77236 L p .707 .577 .707 r
F P
0 g
s
.17096 .77236 m .17358 .79097 L .17633 .79745 L p .707 .577 .707 r
F P
0 g
s
.36908 .73887 m .45924 .25545 L .48223 .24631 L p .707 .577 .707 r
F P
0 g
s
.45924 .25545 m .36908 .73887 L .35897 .75194 L p .707 .577 .707 r
F P
0 g
s
.16573 .62621 m .17035 .68208 L .16325 .69003 L p .707 .577 .707 r
F P
0 g
s
.35901 .61423 m .36363 .67011 L .35112 .66411 L p .707 .577 .707 r
F P
0 g
s
.35112 .66411 m .34649 .60824 L .35901 .61423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16915 .75312 m .16405 .7159 L .17118 .70823 L p .707 .577 .707 r
F P
0 g
s
.17118 .70823 m .17628 .74545 L .16915 .75312 L p .707 .577 .707 r
F P
0 g
s
.17035 .68208 m .16573 .62621 L .18208 .61843 L p .707 .577 .707 r
F P
0 g
s
.35606 .71854 m .35096 .68132 L .36334 .68607 L p .707 .577 .707 r
F P
0 g
s
.17358 .79097 m .17096 .77236 L .17809 .76471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17809 .76471 m .18071 .78332 L .17358 .79097 L p .707 .577 .707 r
F P
0 g
s
.34649 .60824 m .35112 .66411 L .33016 .66003 L p .707 .577 .707 r
F P
0 g
s
.33016 .66003 m .32554 .60416 L .34649 .60824 L p .707 .577 .707 r
F P
0 g
s
.18208 .61843 m .1867 .6743 L .17035 .68208 L p .707 .577 .707 r
F P
0 g
s
.59228 .75708 m .68243 .27366 L .7115 .28992 L p .707 .577 .707 r
F P
0 g
s
.48223 .24631 m .39208 .72973 L .36908 .73887 L p .707 .577 .707 r
F P
0 g
s
.39208 .72973 m .48223 .24631 L .51586 .24197 L p .707 .577 .707 r
F P
0 g
s
.17628 .74545 m .17118 .70823 L .1875 .70017 L p .707 .577 .707 r
F P
0 g
s
.1867 .6743 m .18208 .61843 L .20608 .61157 L p .707 .577 .707 r
F P
0 g
s
.1875 .70017 m .1926 .73739 L .17628 .74545 L p .707 .577 .707 r
F P
0 g
s
.35096 .68132 m .35606 .71854 L .33527 .71604 L p .707 .577 .707 r
F P
0 g
s
.33527 .71604 m .33017 .67881 L .35096 .68132 L p .707 .577 .707 r
F P
0 g
s
.18071 .78332 m .17809 .76471 L .19441 .75663 L p .707 .577 .707 r
F P
0 g
s
.32554 .60416 m .33016 .66003 L .30281 .65828 L p .707 .577 .707 r
F P
0 g
s
.30281 .65828 m .29819 .60241 L .32554 .60416 L p .707 .577 .707 r
F P
0 g
s
.19441 .75663 m .19703 .77524 L .18071 .78332 L p .707 .577 .707 r
F P
0 g
s
.20608 .61157 m .21071 .66744 L .1867 .6743 L p .707 .577 .707 r
F P
0 g
s
.33964 .75339 m .33702 .73479 L .35779 .73718 L p .707 .577 .707 r
F P
0 g
s
.21071 .66744 m .20608 .61157 L .23539 .6063 L p .707 .577 .707 r
F P
0 g
s
.1926 .73739 m .1875 .70017 L .21141 .69251 L p .707 .577 .707 r
F P
0 g
s
.68243 .27366 m .59228 .75708 L .55424 .74296 L p .707 .577 .707 r
F P
0 g
s
.55424 .74296 m .64439 .25954 L .68243 .27366 L p .707 .577 .707 r
F P
0 g
s
.4257 .72539 m .51586 .24197 L .55682 .24288 L p .707 .577 .707 r
F P
0 g
s
.51586 .24197 m .4257 .72539 L .39208 .72973 L p .707 .577 .707 r
F P
0 g
s
.29819 .60241 m .30281 .65828 L .27175 .65901 L p .707 .577 .707 r
F P
0 g
s
.27175 .65901 m .26713 .60314 L .29819 .60241 L p .707 .577 .707 r
F P
0 g
s
.33017 .67881 m .33527 .71604 L .30812 .71602 L p .707 .577 .707 r
F P
0 g
s
.30812 .71602 m .30302 .6788 L .33017 .67881 L p .707 .577 .707 r
F P
0 g
s
.21141 .69251 m .21651 .72973 L .1926 .73739 L p .707 .577 .707 r
F P
0 g
s
.24001 .66217 m .23539 .6063 L .26713 .60314 L p .707 .577 .707 r
F P
0 g
s
.23539 .6063 m .24001 .66217 L .21071 .66744 L p .707 .577 .707 r
F P
0 g
s
.19703 .77524 m .19441 .75663 L .21832 .74891 L p .707 .577 .707 r
F P
0 g
s
.26713 .60314 m .27175 .65901 L .24001 .66217 L p .707 .577 .707 r
F P
0 g
s
.7382 .65727 m .73357 .6014 L .70251 .60214 L p .707 .577 .707 r
F P
0 g
s
.73357 .6014 m .7382 .65727 L .76993 .65412 L p .707 .577 .707 r
F P
0 g
s
.76993 .65412 m .76531 .59825 L .73357 .6014 L p .707 .577 .707 r
F P
0 g
s
.21832 .74891 m .22094 .76752 L .19703 .77524 L p .707 .577 .707 r
F P
0 g
s
.76531 .59825 m .76993 .65412 L .79924 .64885 L p .707 .577 .707 r
F P
0 g
s
.79924 .64885 m .79461 .59298 L .76531 .59825 L p .707 .577 .707 r
F P
0 g
s
.21651 .72973 m .21141 .69251 L .24058 .686 L p .707 .577 .707 r
F P
0 g
s
.64439 .25954 m .55424 .74296 L .51095 .73235 L p .707 .577 .707 r
F P
0 g
s
.51095 .73235 m .60111 .24893 L .64439 .25954 L p .707 .577 .707 r
F P
0 g
s
.33702 .73479 m .33964 .75339 L .3125 .7535 L p .707 .577 .707 r
F P
0 g
s
.3125 .7535 m .30988 .73489 L .33702 .73479 L p .707 .577 .707 r
F P
0 g
s
.46666 .7263 m .55682 .24288 L .60111 .24893 L p .707 .577 .707 r
F P
0 g
s
.55682 .24288 m .46666 .7263 L .4257 .72539 L p .707 .577 .707 r
F P
0 g
s
.70713 .65801 m .70251 .60214 L .67516 .60038 L p .707 .577 .707 r
F P
0 g
s
.70251 .60214 m .70713 .65801 L .7382 .65727 L p .707 .577 .707 r
F P
0 g
s
.30302 .6788 m .30812 .71602 L .27724 .7185 L p .707 .577 .707 r
F P
0 g
s
.27724 .7185 m .27214 .68127 L .30302 .6788 L p .707 .577 .707 r
F P
0 g
s
.60111 .24893 m .51095 .73235 L .46666 .7263 L p .707 .577 .707 r
F P
0 g
s
.24058 .686 m .24568 .72322 L .21651 .72973 L p .707 .577 .707 r
F P
0 g
s
.79461 .59298 m .79924 .64885 L .82324 .64199 L p .707 .577 .707 r
F P
0 g
s
.82324 .64199 m .81862 .58612 L .79461 .59298 L p .707 .577 .707 r
F P
0 g
s
.24568 .72322 m .24058 .686 L .27214 .68127 L p .707 .577 .707 r
F P
0 g
s
.22094 .76752 m .21832 .74891 L .24748 .74232 L p .707 .577 .707 r
F P
0 g
s
.27214 .68127 m .27724 .7185 L .24568 .72322 L p .707 .577 .707 r
F P
0 g
s
.74331 .71948 m .73821 .68226 L .70734 .68474 L p .707 .577 .707 r
F P
0 g
s
.73821 .68226 m .74331 .71948 L .77487 .71476 L p .707 .577 .707 r
F P
0 g
s
.77487 .71476 m .76977 .67754 L .73821 .68226 L p .707 .577 .707 r
F P
0 g
s
.67516 .60038 m .67978 .65625 L .70713 .65801 L p .707 .577 .707 r
F P
0 g
s
.24748 .74232 m .25009 .76092 L .22094 .76752 L p .707 .577 .707 r
F P
0 g
s
.76977 .67754 m .77487 .71476 L .80404 .70825 L p .707 .577 .707 r
F P
0 g
s
.80404 .70825 m .79894 .67102 L .76977 .67754 L p .707 .577 .707 r
F P
0 g
s
.30988 .73489 m .3125 .7535 L .28164 .75609 L p .707 .577 .707 r
F P
0 g
s
.28164 .75609 m .27903 .73748 L .30988 .73489 L p .707 .577 .707 r
F P
0 g
s
.71244 .72196 m .70734 .68474 L .68018 .68472 L p .707 .577 .707 r
F P
0 g
s
.70734 .68474 m .71244 .72196 L .74331 .71948 L p .707 .577 .707 r
F P
0 g
s
.25009 .76092 m .24748 .74232 L .27903 .73748 L p .707 .577 .707 r
F P
0 g
s
.27903 .73748 m .28164 .75609 L .25009 .76092 L p .707 .577 .707 r
F P
0 g
s
.79894 .67102 m .80404 .70825 L .82796 .70059 L p .707 .577 .707 r
F P
0 g
s
.82796 .70059 m .82285 .66336 L .79894 .67102 L p .707 .577 .707 r
F P
0 g
s
.81862 .58612 m .82324 .64199 L .83959 .6342 L p .707 .577 .707 r
F P
0 g
s
.83959 .6342 m .83497 .57833 L .81862 .58612 L p .707 .577 .707 r
F P
0 g
s
.74768 .76668 m .74506 .74807 L .7142 .75066 L p .707 .577 .707 r
F P
0 g
s
.74506 .74807 m .74768 .76668 L .77923 .76184 L p .707 .577 .707 r
F P
0 g
s
.77923 .76184 m .77661 .74324 L .74506 .74807 L p .707 .577 .707 r
F P
0 g
s
.68018 .68472 m .68528 .72194 L .71244 .72196 L p .707 .577 .707 r
F P
0 g
s
.77661 .74324 m .77923 .76184 L .80838 .75525 L p .707 .577 .707 r
F P
0 g
s
.80838 .75525 m .80576 .73664 L .77661 .74324 L p .707 .577 .707 r
F P
0 g
s
.7142 .75066 m .71682 .76927 L .74768 .76668 L p .707 .577 .707 r
F P
0 g
s
.71682 .76927 m .7142 .75066 L .68706 .75077 L p .707 .577 .707 r
F P
0 g
s
.68706 .75077 m .68968 .76937 L .71682 .76927 L p .707 .577 .707 r
F P
0 g
s
.80576 .73664 m .80838 .75525 L .83229 .74753 L p .707 .577 .707 r
F P
0 g
s
.83229 .74753 m .82967 .72892 L .80576 .73664 L p .707 .577 .707 r
F P
0 g
s
.82285 .66336 m .82796 .70059 L .84428 .69252 L p .707 .577 .707 r
F P
0 g
s
.84428 .69252 m .83918 .6553 L .82285 .66336 L p .707 .577 .707 r
F P
0 g
s
.65939 .68221 m .66449 .71944 L .68528 .72194 L p .707 .577 .707 r
F P
0 g
s
.83497 .57833 m .83959 .6342 L .84669 .62626 L p .707 .577 .707 r
F P
0 g
s
.84669 .62626 m .84207 .57039 L .83497 .57833 L p .707 .577 .707 r
F P
0 g
s
.68968 .76937 m .68706 .75077 L .66629 .74837 L p .707 .577 .707 r
F P
0 g
s
.66629 .74837 m .66891 .76698 L .68968 .76937 L p .707 .577 .707 r
F P
0 g
s
.82967 .72892 m .83229 .74753 L .84861 .73945 L p .707 .577 .707 r
F P
0 g
s
.84861 .73945 m .84599 .72084 L .82967 .72892 L p .707 .577 .707 r
F P
0 g
s
.83918 .6553 m .84428 .69252 L .85141 .68485 L p .707 .577 .707 r
F P
0 g
s
.85141 .68485 m .84631 .64763 L .83918 .6553 L p .707 .577 .707 r
F P
0 g
s
.66891 .76698 m .66629 .74837 L .65393 .7437 L p .707 .577 .707 r
F P
0 g
s
.65393 .7437 m .65654 .76231 L .66891 .76698 L p .707 .577 .707 r
F P
0 g
s
.63884 .58298 m .64347 .63885 L .64631 .64618 L p .707 .577 .707 r
F P
0 g
s
.84207 .57039 m .84669 .62626 L .84385 .61893 L p .707 .577 .707 r
F P
0 g
s
.84385 .61893 m .83922 .56305 L .84207 .57039 L p .707 .577 .707 r
F P
0 g
s
.84599 .72084 m .84861 .73945 L .85574 .7318 L p .707 .577 .707 r
F P
0 g
s
.85574 .7318 m .85312 .71319 L .84599 .72084 L p .707 .577 .707 r
F P
0 g
s
.65212 .71468 m .64702 .67746 L .64426 .67093 L p .707 .577 .707 r
F P
0 g
s
.64426 .67093 m .64936 .70815 L .65212 .71468 L p .707 .577 .707 r
F P
0 g
s
.64347 .63885 m .63884 .58298 L .64594 .57503 L p .707 .577 .707 r
F P
0 g
s
.84631 .64763 m .85141 .68485 L .84865 .67832 L p .707 .577 .707 r
F P
0 g
s
.84865 .67832 m .84355 .6411 L .84631 .64763 L p .707 .577 .707 r
F P
0 g
s
.65654 .76231 m .65393 .7437 L .65117 .73723 L p .707 .577 .707 r
F P
0 g
s
.65117 .73723 m .65379 .75583 L .65654 .76231 L p .707 .577 .707 r
F P
0 g
s
.64594 .57503 m .65057 .6309 L .64347 .63885 L p .707 .577 .707 r
F P
0 g
s
.83922 .56305 m .84385 .61893 L .83133 .61293 L p .707 .577 .707 r
F P
0 g
s
.83133 .61293 m .82671 .55706 L .83922 .56305 L p .707 .577 .707 r
F P
0 g
s
.85312 .71319 m .85574 .7318 L .85299 .72532 L p .707 .577 .707 r
F P
0 g
s
.85299 .72532 m .85037 .70671 L .85312 .71319 L p .707 .577 .707 r
F P
0 g
s
.64936 .70815 m .64426 .67093 L .65139 .66326 L p .707 .577 .707 r
F P
0 g
s
.39519 .61641 m .39056 .56054 L .3595 .56128 L p .707 .577 .707 r
F P
0 g
s
.39056 .56054 m .39519 .61641 L .42692 .61326 L p .707 .577 .707 r
F P
0 g
s
.42692 .61326 m .4223 .55739 L .39056 .56054 L p .707 .577 .707 r
F P
0 g
s
.4223 .55739 m .42692 .61326 L .45623 .60799 L p .707 .577 .707 r
F P
0 g
s
.45623 .60799 m .4516 .55212 L .4223 .55739 L p .707 .577 .707 r
F P
0 g
s
.65057 .6309 m .64594 .57503 L .6623 .56725 L p .707 .577 .707 r
F P
0 g
s
.65139 .66326 m .65649 .70048 L .64936 .70815 L p .707 .577 .707 r
F P
0 g
s
.36412 .61715 m .3595 .56128 L .33215 .55952 L p .707 .577 .707 r
F P
0 g
s
.3595 .56128 m .36412 .61715 L .39519 .61641 L p .707 .577 .707 r
F P
0 g
s
.84355 .6411 m .84865 .67832 L .83627 .67357 L p .707 .577 .707 r
F P
0 g
s
.83627 .67357 m .83117 .63635 L .84355 .6411 L p .707 .577 .707 r
F P
0 g
s
.4516 .55212 m .45623 .60799 L .48023 .60113 L p .707 .577 .707 r
F P
0 g
s
.48023 .60113 m .47561 .54526 L .4516 .55212 L p .707 .577 .707 r
F P
0 g
s
.65379 .75583 m .65117 .73723 L .65831 .72957 L p .707 .577 .707 r
F P
0 g
s
.65831 .72957 m .66093 .74818 L .65379 .75583 L p .707 .577 .707 r
F P
0 g
s
.4003 .67242 m .3952 .63519 L .36433 .63767 L p .707 .577 .707 r
F P
0 g
s
.3952 .63519 m .4003 .67242 L .43186 .66769 L p .707 .577 .707 r
F P
0 g
s
.43186 .66769 m .42676 .63047 L .3952 .63519 L p .707 .577 .707 r
F P
0 g
s
.82671 .55706 m .83133 .61293 L .81037 .60885 L p .707 .577 .707 r
F P
0 g
s
.81037 .60885 m .80575 .55298 L .82671 .55706 L p .707 .577 .707 r
F P
0 g
s
.6623 .56725 m .66692 .62312 L .65057 .6309 L p .707 .577 .707 r
F P
0 g
s
.42676 .63047 m .43186 .66769 L .46103 .66118 L p .707 .577 .707 r
F P
0 g
s
.46103 .66118 m .45593 .62396 L .42676 .63047 L p .707 .577 .707 r
F P
0 g
s
.33215 .55952 m .33677 .61539 L .36412 .61715 L p .707 .577 .707 r
F P
0 g
s
.33677 .61539 m .33215 .55952 L .31119 .55545 L p .707 .577 .707 r
F P
0 g
s
.85037 .70671 m .85299 .72532 L .84062 .72066 L p .707 .577 .707 r
F P
0 g
s
.84062 .72066 m .83801 .70205 L .85037 .70671 L p .707 .577 .707 r
F P
0 g
s
.36943 .67489 m .36433 .63767 L .33717 .63765 L p .707 .577 .707 r
F P
0 g
s
.36433 .63767 m .36943 .67489 L .4003 .67242 L p .707 .577 .707 r
F P
0 g
s
.65649 .70048 m .65139 .66326 L .66771 .6552 L p .707 .577 .707 r
F P
0 g
s
.40467 .70977 m .40205 .69117 L .37119 .69376 L p .707 .577 .707 r
F P
0 g
s
.40205 .69117 m .40467 .70977 L .43622 .70494 L p .707 .577 .707 r
F P
0 g
s
.43622 .70494 m .4336 .68633 L .40205 .69117 L p .707 .577 .707 r
F P
0 g
s
.45593 .62396 m .46103 .66118 L .48495 .65352 L p .707 .577 .707 r
F P
0 g
s
.48495 .65352 m .47985 .6163 L .45593 .62396 L p .707 .577 .707 r
F P
0 g
s
.66692 .62312 m .6623 .56725 L .6863 .56039 L p .707 .577 .707 r
F P
0 g
s
.4336 .68633 m .43622 .70494 L .46537 .69834 L p .707 .577 .707 r
F P
0 g
s
.46537 .69834 m .46275 .67974 L .4336 .68633 L p .707 .577 .707 r
F P
0 g
s
.47561 .54526 m .48023 .60113 L .49658 .59334 L p .707 .577 .707 r
F P
0 g
s
.49658 .59334 m .49196 .53747 L .47561 .54526 L p .707 .577 .707 r
F P
0 g
s
.33717 .63765 m .34227 .67487 L .36943 .67489 L p .707 .577 .707 r
F P
0 g
s
.37119 .69376 m .37381 .71237 L .40467 .70977 L p .707 .577 .707 r
F P
0 g
s
.66771 .6552 m .67281 .69242 L .65649 .70048 L p .707 .577 .707 r
F P
0 g
s
.31119 .55545 m .31582 .61132 L .33677 .61539 L p .707 .577 .707 r
F P
0 g
s
.83117 .63635 m .83627 .67357 L .81549 .67106 L p .707 .577 .707 r
F P
0 g
s
.81549 .67106 m .81039 .63384 L .83117 .63635 L p .707 .577 .707 r
F P
0 g
s
.37381 .71237 m .37119 .69376 L .34405 .69386 L p .707 .577 .707 r
F P
0 g
s
.80575 .55298 m .81037 .60885 L .78303 .6071 L p .707 .577 .707 r
F P
0 g
s
.78303 .6071 m .7784 .55123 L .80575 .55298 L p .707 .577 .707 r
F P
0 g
s
.34227 .67487 m .33717 .63765 L .31638 .63515 L p .707 .577 .707 r
F P
0 g
s
.34405 .69386 m .34667 .71247 L .37381 .71237 L p .707 .577 .707 r
F P
0 g
s
.66093 .74818 m .65831 .72957 L .67463 .72149 L p .707 .577 .707 r
F P
0 g
s
.46275 .67974 m .46537 .69834 L .48928 .69063 L p .707 .577 .707 r
F P
0 g
s
.48928 .69063 m .48666 .67202 L .46275 .67974 L p .707 .577 .707 r
F P
0 g
s
.6863 .56039 m .69092 .61626 L .66692 .62312 L p .707 .577 .707 r
F P
0 g
s
.31582 .61132 m .31119 .55545 L .29868 .54945 L p .707 .577 .707 r
F P
0 g
s
.67463 .72149 m .67725 .7401 L .66093 .74818 L p .707 .577 .707 r
F P
0 g
s
.47985 .6163 m .48495 .65352 L .50127 .64546 L p .707 .577 .707 r
F P
0 g
s
.50127 .64546 m .49617 .60824 L .47985 .6163 L p .707 .577 .707 r
F P
0 g
s
.31638 .63515 m .32148 .67237 L .34227 .67487 L p .707 .577 .707 r
F P
0 g
s
.69092 .61626 m .6863 .56039 L .7156 .55512 L p .707 .577 .707 r
F P
0 g
s
.83801 .70205 m .84062 .72066 L .81985 .71826 L p .707 .577 .707 r
F P
0 g
s
.81985 .71826 m .81724 .69965 L .83801 .70205 L p .707 .577 .707 r
F P
0 g
s
.67281 .69242 m .66771 .6552 L .69163 .64754 L p .707 .577 .707 r
F P
0 g
s
.34667 .71247 m .34405 .69386 L .32328 .69146 L p .707 .577 .707 r
F P
0 g
s
.7784 .55123 m .78303 .6071 L .75196 .60783 L p .707 .577 .707 r
F P
0 g
s
.75196 .60783 m .74734 .55196 L .7784 .55123 L p .707 .577 .707 r
F P
0 g
s
.49196 .53747 m .49658 .59334 L .50368 .5854 L p .707 .577 .707 r
F P
0 g
s
.50368 .5854 m .49906 .52953 L .49196 .53747 L p .707 .577 .707 r
F P
0 g
s
.32328 .69146 m .3259 .71007 L .34667 .71247 L p .707 .577 .707 r
F P
0 g
s
.29868 .54945 m .3033 .60532 L .31582 .61132 L p .707 .577 .707 r
F P
0 g
s
.81039 .63384 m .81549 .67106 L .78833 .67105 L p .707 .577 .707 r
F P
0 g
s
.78833 .67105 m .78323 .63383 L .81039 .63384 L p .707 .577 .707 r
F P
0 g
s
.69163 .64754 m .69673 .68476 L .67281 .69242 L p .707 .577 .707 r
F P
0 g
s
.48666 .67202 m .48928 .69063 L .5056 .68255 L p .707 .577 .707 r
F P
0 g
s
.5056 .68255 m .50298 .66394 L .48666 .67202 L p .707 .577 .707 r
F P
0 g
s
.72023 .61099 m .7156 .55512 L .74734 .55196 L p .707 .577 .707 r
F P
0 g
s
.7156 .55512 m .72023 .61099 L .69092 .61626 L p .707 .577 .707 r
F P
0 g
s
.74734 .55196 m .75196 .60783 L .72023 .61099 L p .707 .577 .707 r
F P
0 g
s
.32148 .67237 m .31638 .63515 L .30401 .63039 L p .707 .577 .707 r
F P
0 g
s
.67725 .7401 m .67463 .72149 L .69853 .71378 L p .707 .577 .707 r
F P
0 g
s
.69853 .71378 m .70115 .73239 L .67725 .7401 L p .707 .577 .707 r
F P
0 g
s
.69673 .68476 m .69163 .64754 L .72079 .64103 L p .707 .577 .707 r
F P
0 g
s
.30401 .63039 m .30911 .66762 L .32148 .67237 L p .707 .577 .707 r
F P
0 g
s
.3033 .60532 m .29868 .54945 L .29583 .54212 L p .707 .577 .707 r
F P
0 g
s
.49617 .60824 m .50127 .64546 L .5084 .63779 L p .707 .577 .707 r
F P
0 g
s
.5084 .63779 m .5033 .60056 L .49617 .60824 L p .707 .577 .707 r
F P
0 g
s
.81724 .69965 m .81985 .71826 L .79271 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .71836 m .79009 .69975 L .81724 .69965 L p .707 .577 .707 r
F P
0 g
s
.78323 .63383 m .78833 .67105 L .75746 .67352 L p .707 .577 .707 r
F P
0 g
s
.75746 .67352 m .75236 .6363 L .78323 .63383 L p .707 .577 .707 r
F P
0 g
s
.3259 .71007 m .32328 .69146 L .31091 .6868 L p .707 .577 .707 r
F P
0 g
s
.72079 .64103 m .72589 .67825 L .69673 .68476 L p .707 .577 .707 r
F P
0 g
s
.31091 .6868 m .31353 .70541 L .3259 .71007 L p .707 .577 .707 r
F P
0 g
s
.72589 .67825 m .72079 .64103 L .75236 .6363 L p .707 .577 .707 r
F P
0 g
s
.75236 .6363 m .75746 .67352 L .72589 .67825 L p .707 .577 .707 r
F P
0 g
s
.29583 .54212 m .30046 .59799 L .3033 .60532 L p .707 .577 .707 r
F P
0 g
s
.49906 .52953 m .50368 .5854 L .50084 .57807 L p .707 .577 .707 r
F P
0 g
s
.50084 .57807 m .49621 .5222 L .49906 .52953 L p .707 .577 .707 r
F P
0 g
s
.70115 .73239 m .69853 .71378 L .72769 .70718 L p .707 .577 .707 r
F P
0 g
s
.50298 .66394 m .5056 .68255 L .51273 .6749 L p .707 .577 .707 r
F P
0 g
s
.51273 .6749 m .51011 .65629 L .50298 .66394 L p .707 .577 .707 r
F P
0 g
s
.72769 .70718 m .73031 .72579 L .70115 .73239 L p .707 .577 .707 r
F P
0 g
s
.79009 .69975 m .79271 .71836 L .76186 .72096 L p .707 .577 .707 r
F P
0 g
s
.76186 .72096 m .75924 .70235 L .79009 .69975 L p .707 .577 .707 r
F P
0 g
s
.30911 .66762 m .30401 .63039 L .30125 .62386 L p .707 .577 .707 r
F P
0 g
s
.73031 .72579 m .72769 .70718 L .75924 .70235 L p .707 .577 .707 r
F P
0 g
s
.75924 .70235 m .76186 .72096 L .73031 .72579 L p .707 .577 .707 r
F P
0 g
s
.30125 .62386 m .30635 .66109 L .30911 .66762 L p .707 .577 .707 r
F P
0 g
s
.30046 .59799 m .29583 .54212 L .30293 .53417 L p .707 .577 .707 r
F P
0 g
s
.5033 .60056 m .5084 .63779 L .50564 .63126 L p .707 .577 .707 r
F P
0 g
s
.50564 .63126 m .50054 .59403 L .5033 .60056 L p .707 .577 .707 r
F P
0 g
s
.31353 .70541 m .31091 .6868 L .30816 .68032 L p .707 .577 .707 r
F P
0 g
s
.30816 .68032 m .31078 .69893 L .31353 .70541 L p .707 .577 .707 r
F P
0 g
s
.51011 .65629 m .51273 .6749 L .50998 .66842 L p .707 .577 .707 r
F P
0 g
s
.50998 .66842 m .50736 .64981 L .51011 .65629 L p .707 .577 .707 r
F P
0 g
s
.30293 .53417 m .30756 .59004 L .30046 .59799 L p .707 .577 .707 r
F P
0 g
s
.49621 .5222 m .50084 .57807 L .48832 .57207 L p .707 .577 .707 r
F P
0 g
s
.48832 .57207 m .4837 .5162 L .49621 .5222 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30635 .66109 m .30125 .62386 L .30838 .61619 L p .707 .577 .707 r
F P
0 g
s
.30838 .61619 m .31348 .65341 L .30635 .66109 L p .707 .577 .707 r
F P
0 g
s
.30756 .59004 m .30293 .53417 L .31928 .52639 L p .707 .577 .707 r
F P
0 g
s
.50054 .59403 m .50564 .63126 L .49326 .6265 L p .707 .577 .707 r
F P
0 g
s
.49326 .6265 m .48816 .58928 L .50054 .59403 L p .707 .577 .707 r
F P
0 g
s
.31078 .69893 m .30816 .68032 L .3153 .67267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3153 .67267 m .31792 .69128 L .31078 .69893 L p .707 .577 .707 r
F P
0 g
s
.4837 .5162 m .48832 .57207 L .46736 .56799 L p .707 .577 .707 r
F P
0 g
s
.46736 .56799 m .46274 .51212 L .4837 .5162 L p .707 .577 .707 r
F P
0 g
s
.31928 .52639 m .32391 .58226 L .30756 .59004 L p .707 .577 .707 r
F P
0 g
s
.50736 .64981 m .50998 .66842 L .49761 .66375 L p .707 .577 .707 r
F P
0 g
s
.49761 .66375 m .49499 .64515 L .50736 .64981 L p .707 .577 .707 r
F P
0 g
s
.31348 .65341 m .30838 .61619 L .3247 .60813 L p .707 .577 .707 r
F P
0 g
s
.32391 .58226 m .31928 .52639 L .34329 .51953 L p .707 .577 .707 r
F P
0 g
s
.3247 .60813 m .3298 .64535 L .31348 .65341 L p .707 .577 .707 r
F P
0 g
s
.48816 .58928 m .49326 .6265 L .47248 .624 L p .707 .577 .707 r
F P
0 g
s
.47248 .624 m .46738 .58677 L .48816 .58928 L p .707 .577 .707 r
F P
0 g
s
.31792 .69128 m .3153 .67267 L .33162 .66459 L p .707 .577 .707 r
F P
0 g
s
.46274 .51212 m .46736 .56799 L .44002 .56624 L p .707 .577 .707 r
F P
0 g
s
.44002 .56624 m .43539 .51037 L .46274 .51212 L p .707 .577 .707 r
F P
0 g
s
.33162 .66459 m .33424 .6832 L .31792 .69128 L p .707 .577 .707 r
F P
0 g
s
.34329 .51953 m .34791 .5754 L .32391 .58226 L p .707 .577 .707 r
F P
0 g
s
.49499 .64515 m .49761 .66375 L .47684 .66136 L p .707 .577 .707 r
F P
0 g
s
.47684 .66136 m .47423 .64275 L .49499 .64515 L p .707 .577 .707 r
F P
0 g
s
.34791 .5754 m .34329 .51953 L .37259 .51426 L p .707 .577 .707 r
F P
0 g
s
.3298 .64535 m .3247 .60813 L .34862 .60047 L p .707 .577 .707 r
F P
0 g
s
.43539 .51037 m .44002 .56624 L .40895 .56698 L p .707 .577 .707 r
F P
0 g
s
.40895 .56698 m .40433 .5111 L .43539 .51037 L p .707 .577 .707 r
F P
0 g
s
.46738 .58677 m .47248 .624 L .44532 .62398 L p .707 .577 .707 r
F P
0 g
s
.44532 .62398 m .44022 .58676 L .46738 .58677 L p .707 .577 .707 r
F P
0 g
s
.34862 .60047 m .35372 .63769 L .3298 .64535 L p .707 .577 .707 r
F P
0 g
s
.37721 .57013 m .37259 .51426 L .40433 .5111 L p .707 .577 .707 r
F P
0 g
s
.37259 .51426 m .37721 .57013 L .34791 .5754 L p .707 .577 .707 r
F P
0 g
s
.33424 .6832 m .33162 .66459 L .35552 .65687 L p .707 .577 .707 r
F P
0 g
s
.40433 .5111 m .40895 .56698 L .37721 .57013 L p .707 .577 .707 r
F P
0 g
s
.35552 .65687 m .35814 .67548 L .33424 .6832 L p .707 .577 .707 r
F P
0 g
s
.35372 .63769 m .34862 .60047 L .37778 .59396 L p .707 .577 .707 r
F P
0 g
s
.47423 .64275 m .47684 .66136 L .4497 .66146 L p .707 .577 .707 r
F P
0 g
s
.4497 .66146 m .44708 .64285 L .47423 .64275 L p .707 .577 .707 r
F P
0 g
s
.44022 .58676 m .44532 .62398 L .41445 .62646 L p .707 .577 .707 r
F P
0 g
s
.41445 .62646 m .40935 .58923 L .44022 .58676 L p .707 .577 .707 r
F P
0 g
s
.37778 .59396 m .38288 .63118 L .35372 .63769 L p .707 .577 .707 r
F P
0 g
s
.38288 .63118 m .37778 .59396 L .40935 .58923 L p .707 .577 .707 r
F P
0 g
s
.35814 .67548 m .35552 .65687 L .38468 .65028 L p .707 .577 .707 r
F P
0 g
s
.40935 .58923 m .41445 .62646 L .38288 .63118 L p .707 .577 .707 r
F P
0 g
s
.38468 .65028 m .3873 .66889 L .35814 .67548 L p .707 .577 .707 r
F P
0 g
s
.44708 .64285 m .4497 .66146 L .41885 .66405 L p .707 .577 .707 r
F P
0 g
s
.41885 .66405 m .41623 .64545 L .44708 .64285 L p .707 .577 .707 r
F P
0 g
s
.3873 .66889 m .38468 .65028 L .41623 .64545 L p .707 .577 .707 r
F P
0 g
s
.41623 .64545 m .41885 .66405 L .3873 .66889 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0091oo`P008Eo
o`00S7oo10000UYF00<005YFFUH00eYF3000NGoo0028Ool40006FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH9001`Ool008Aoo`@00003FUH005YF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@006aoo`00PWoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH015YF1000J7oo0021Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH4001TOol0081oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP04001JEP00001ROol0081oo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP04001JEUYFFUH3001OOol007moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF019JEP80
05eoo`00Ogoo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF0P00Fgoo001oOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH3001IOol007ioo`04001J
EUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP02001GOol007ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00eJEP8005Eoo`00OWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P00Dgoo001nOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00Oomoo`1@
Ool007ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001oogoo04moo`00OWoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF
00<005YFFUH02EYF00<007ooOol0CWoo001mOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH02UYF00<007oo
Ool0CGoo001mOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`1<Ool0
07eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo04]oo`00OGoo00<0
05YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH03EYF00<007ooOol0Bgoo001mOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0=
FUH00`00Oomoo`1;Ool007aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001<Ool007aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004ao
o`00O7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000C7oo001lOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001<Ool007aoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00eJEP8004eoo`00O7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH035YF00<005YF0000
CGoo001kOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001=Ool007]o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004eoo`00Ngoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CGoo001kOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0=FUH2001>Ool007]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00aJEP03001JEP0004ioo`00
NWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<0
05YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000CWoo001jOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001>Ool007Yoo`03001JEP0000IJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0004ioo`00NWoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH03EYF
0P00Cgoo001jOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001?Ool0
07Uoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0004moo`00NGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000Cgoo001iOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001?Ool007Uoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP80051oo`00NGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH035YF00<005YF
0000D7oo001hOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001@Ool0
07Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00051oo`00N7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000D7oo001hOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1@Ool007Qoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00aJEP03001JEUYF055oo`00N7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000DGoo001gOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001AOol007Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00055oo`00
Mgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0DGoo001gOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001BOol007Moo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00059oo`00MWoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000DWoo001fOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001BOol007Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP00059oo`00MWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF0000Dgoo001fOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001C
Ool007Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005=oo`00MGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Dgoo001eOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001COol007Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8005Aoo`00MGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000E7oo001eOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001DOol007Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ao
o`00M7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000E7oo001dOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001EOol007Aoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Eoo`00M7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000EGoo001dOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001EOol007=oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0005Eoo`00Lgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000EGoo
001cOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001FOol007=oo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Ioo`00Lgoo0P001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000EWoo001^OolH000:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001FOol006Io
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005Ioo`00
H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
0eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00<005YF0000Egoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001GOol005Yoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000Egoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EWoo0P000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0005Moo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EUYF05Qoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0005Qoo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0005Qoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000F7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;OolA
000lOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005Ool60004FUH00`00
FUIJEP06FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YF00000Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008002ioo`00E7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF009JEQL000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF00<005YFFUH015YF10000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUIJEP8002eoo`00EGoo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP0000002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
001EOol00`00FUH00004FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol00`00FUH00003
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YF001JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEPl00003FUH005YF00=JEP03001JEP0000UJEP03001JEUYF00UJ
EP03001JEUYF00UJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
001EOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0004FUH00`00FUIJEP04
FUH00`00FUIJEP0500000eYF00000009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00EGoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF00000P002EYF00<005YFFUH02UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000]Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;Goo0017Ool@0002FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000/Ool003moo`P000AJEP03001JEUYF00IJEP06001JEP00001JEP000UYF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00=JEP03001JEUYF008002aoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH70003
FUH00`00FUIJEP02000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@000UYF0P00;7oo000cOol20005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH4000/Ool0039oo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00<7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH00P001UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT0009J
EP@00003FUH005YF00EJEPH00003FUH0000000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEP00FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH800000eYF000000060005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH000020005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00@00003Ool0000000L000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0001/002ioo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF2@000UYF1@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUH000030004FUH00`00FUIJEP05FUH3
0007FUH00`00FUH0000>0004FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF0`00
1eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01P001eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYF001JEP020003FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00D005YF000005YF008000AJEP03001JEP0000<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo000]Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP0000EJEP04001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH00UYF3P0000AJEP00FUH000EJEP@00003FUH005YF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH90008FUH00`00
FUIJEP03FUH01000FUIJEP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF6@000UYF0P00
0eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002aoo`00;Woo00<005YF000015YF00<005YFFUH00UYF1P0025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF00@000=J
EPL000QJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000/Ool002ioo`03001JEP0000AJEP03
001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00AJEP03001JEUYF00AJEPH0009JEP@000AJEP03001JEUYF00QJEP04001JEUYFFUH200000eYF
001JEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00D0
05YFFUIJEP0002]oo`00;Woo00<005YF00000eYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0300025YF00<005YFFUH0
25YF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=oo`0000000P000UYF00<005YFFUH015YF1@000UYF00<007ooOol0:Goo000^Ool01000FUH005YF
0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF
00<005YFFUH00UYF1@0000=oo`0000001UYF00<005YFFUH01eYF00<005YFFUH01UYF100000=JEP00
FUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000Eoo`D000IJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH03@0000=JEP00FUH015YF00<005YF00000P000UYF0P000Woo00=JEP00FUH00UYF100025YF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000Moo`@0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002]oo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P000UYF00@0
05YFFUIJEP<0009JEP@0009oo`03001JEP00009JEPD000QJEP03001JEUYF00@00003FUH005YF00IJ
EP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH00eYF3`001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000:goo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH7
0006FUH00`00FUIJEP06FUH20002FUH01000FUH000001EYF00<005YFFUH00P0000Aoo`00FUH0009J
EPD000AJEPL000EJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUH005YF1@001EYF00<005YFFUH00`0000AJEP00FUIJEPT000AJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000^Ool20002FUH00`00FUIJEP03FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH0009JEQ000003FUH00000
008000QJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF00000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH002ioo`00;goo00@005YF
FUH000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF100035YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHC000_Ool0031oo`<00004FUH000000005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00D002eoo`00
<Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF1`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002]oo`00;goo0P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF400000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH?0003FUH01@00FUIJEUYF00001UYF00<005YFFUH07eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF0`0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P00:Woo000^Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
2@000Woo100000=JEP00FUH01EYF1P000UYF00<005YFFUH03EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
0`000UYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4P000eYF00<007oo
Ool0:7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1`000goo1`001EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004Goo0`0000=JEP00Ool0
:Goo000_Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP0400000goo000000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP03FUHC
0009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
00050007FUH00`00FUIJEP04FUH6000HOol20002FUH4000YOol002moo`03001JEP0000AJEP03001J
EUYF00=JEPT0009JEPD000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF00AJEPL000=JEP03001JEUYF00QJEP03001JEUYF009JEPH000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`8000AJEP04001JEP00000YOol002moo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00AJEPD000IJEP03001JEP0000h000EJEP04001JEUYFFUH200000eYF001JEP06
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH5000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH00eYF10007Goo0`0000=JEP00FUH015YF00<005YF
0000:Goo000_Ool01000FUIJEP000eYF0`001eYF00<005YFFUH01EYF0`000UYF1`0015YF00<005YF
FUH015YF00<005YFFUH01@0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0000=JEP00FUH00eYF00<005YF00000`000UYF00<007ooOol067oo100015YF00<005YFFUH00eYF
0P00:Woo000_Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`000eYF00<005YFFUH00P005Goo1000
0UYF00<005YFFUH015YF00@005YFFUIJEP8002]oo`00;goo00<005YFFUH00P001EYF00<005YFFUH0
1EYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02EYF10002UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YF001JEP00FUH30005FUH01@00FUIJEUYF00003Woo1`001UYF
00<005YFFUH015YF00@005YF000002eoo`00<7oo00AJEP00FUH000EJEP04001JEUYFFUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP030007FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1P0015YF00D005YFFUIJEP0000Ioo`P000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP<002moo`00<7oo00AJEP00FUH000EJEP06001JEP00001JEP00
1eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF010000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0039oo`00<7oo00@005YFFUH000EJEP80
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<00003
FUH005YF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000fOol0031oo`06001JEUYFFUH005YF
0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P0037oo00<005YF00003EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00@003Uoo`00<7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
1`000eYF1`003Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF000000IJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD003eo
o`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH010000UYF20004goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP05001JEP00001JEP0200000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool0035oo`8000EJEP03001JEUYF009J
EPX001Moo`@00003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000=JEQ/004Ioo`00<7oo00<005YF00001EYF00<005YF00000P002goo0`0047oo0`00
1EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF0P001eYF0P001EYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH00UYF1000DGoo000`Ool01000FUIJEP000eYF0`003Goo1@002goo100000=JEP00
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP8000AJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF001AOol0031oo`05001JEUYF001JEP02000@Ool50004Ool7
0005FUH00`00FUIJEP05FUH01000FUH000000Woo00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000eYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000DWoo000aOol00`00FUH00003000@
Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005Ool00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH02@00FUIJEUYF
001JEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol0035oo`800004FUH005YF
FUH@00000eYF000000020008FUH00`00FUIJEP06FUH00`00FUH000030009Ool00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000E7oo000aOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP04FUH01000FUH00000
EGoo000aOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04000COol2000?FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000000?001EOol0039oo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000IOol2000=FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000015YF001JEP001eYF
00<005YFFUH00eYF0`00Dgoo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000ROol3
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000eOolC
000^Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02001A
Ool007Uoo`80015JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080055oo`00Ngoo0`00
3UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
3`000UYF00D005YFFUIJEP00055oo`00OWoo0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00UYF0`003goo10000UYF00<007ooOol0Cgoo0021Ool4000CFUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`0@Ool200000eYF00000002001@
Ool008Eoo`@000mJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH2000@Ool30003FUH0
1000FUH00000D7oo0029Ool5000OFUH01000FUH000003goo0`0000=JEP00FUH015YF00<005YF0000
D7oo002>Ool6000EFUH6000=Ool40004FUH00`00FUIJEP03FUH2001AOol0099oo`03001JEP0001@0
00moo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH2001BOol0099oo`04001JEP00FUH2000IOol7
0006FUH00`00FUIJEP04FUH01000FUH00000E7oo002BOol00`00FUH00004000@Ool80004FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3001FOol0099oo`80009JEP03001JEUYF010000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<005Uoo`00TWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00GGoo002BOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001P
Ool009=oo`05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
001TOol009Aoo`800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
06Uoo`00UWoo6P00KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]2\[InvisibleSpace]"     "\
\[InvisibleSpace]1.3589970153897604`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 2, "     ", 1.3589970153897604, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60278 .75323 m .59733 .69857 L .56624 .69927 L p .707 .577 .707 r
F P
0 g
s
.59733 .69857 m .60278 .75323 L .63445 .7494 L p .707 .577 .707 r
F P
0 g
s
.63445 .7494 m .629 .69475 L .59733 .69857 L p .707 .577 .707 r
F P
0 g
s
.629 .69475 m .63445 .7494 L .6636 .74283 L p .707 .577 .707 r
F P
0 g
s
.6636 .74283 m .65815 .68818 L .629 .69475 L p .707 .577 .707 r
F P
0 g
s
.57169 .75393 m .56624 .69927 L .53878 .69678 L p .707 .577 .707 r
F P
0 g
s
.56624 .69927 m .57169 .75393 L .60278 .75323 L p .707 .577 .707 r
F P
0 g
s
.65815 .68818 m .6636 .74283 L .68739 .73415 L p .707 .577 .707 r
F P
0 g
s
.68739 .73415 m .68194 .6795 L .65815 .68818 L p .707 .577 .707 r
F P
0 g
s
.54423 .75144 m .53878 .69678 L .51764 .69134 L p .707 .577 .707 r
F P
0 g
s
.53878 .69678 m .54423 .75144 L .57169 .75393 L p .707 .577 .707 r
F P
0 g
s
.60991 .81555 m .60402 .77971 L .57309 .78206 L p .707 .577 .707 r
F P
0 g
s
.60402 .77971 m .60991 .81555 L .64131 .8098 L p .707 .577 .707 r
F P
0 g
s
.64131 .8098 m .63542 .77396 L .60402 .77971 L p .707 .577 .707 r
F P
0 g
s
.63542 .77396 m .64131 .8098 L .67011 .80122 L p .707 .577 .707 r
F P
0 g
s
.67011 .80122 m .66422 .76538 L .63542 .77396 L p .707 .577 .707 r
F P
0 g
s
.57898 .81791 m .57309 .78206 L .54566 .7808 L p .707 .577 .707 r
F P
0 g
s
.57309 .78206 m .57898 .81791 L .60991 .81555 L p .707 .577 .707 r
F P
0 g
s
.68194 .6795 m .68739 .73415 L .70348 .72422 L p .707 .577 .707 r
F P
0 g
s
.70348 .72422 m .69803 .66956 L .68194 .6795 L p .707 .577 .707 r
F P
0 g
s
.66422 .76538 m .67011 .80122 L .69349 .79065 L p .707 .577 .707 r
F P
0 g
s
.69349 .79065 m .6876 .7548 L .66422 .76538 L p .707 .577 .707 r
F P
0 g
s
.51764 .69134 m .52309 .746 L .54423 .75144 L p .707 .577 .707 r
F P
0 g
s
.61615 .85742 m .61299 .83958 L .582 .84242 L p .707 .577 .707 r
F P
0 g
s
.61299 .83958 m .61615 .85742 L .64742 .85114 L p .707 .577 .707 r
F P
0 g
s
.64742 .85114 m .64427 .8333 L .61299 .83958 L p .707 .577 .707 r
F P
0 g
s
.54566 .7808 m .55155 .81664 L .57898 .81791 L p .707 .577 .707 r
F P
0 g
s
.52309 .746 m .51764 .69134 L .50489 .68349 L p .707 .577 .707 r
F P
0 g
s
.64427 .8333 m .64742 .85114 L .67592 .84204 L p .707 .577 .707 r
F P
0 g
s
.67592 .84204 m .67276 .82419 L .64427 .8333 L p .707 .577 .707 r
F P
0 g
s
.55155 .81664 m .54566 .7808 L .52441 .77603 L p .707 .577 .707 r
F P
0 g
s
.582 .84242 m .58516 .86027 L .61615 .85742 L p .707 .577 .707 r
F P
0 g
s
.58516 .86027 m .582 .84242 L .55433 .84155 L p .707 .577 .707 r
F P
0 g
s
.6876 .7548 m .69349 .79065 L .70915 .77912 L p .707 .577 .707 r
F P
0 g
s
.70915 .77912 m .70326 .74327 L .6876 .7548 L p .707 .577 .707 r
F P
0 g
s
.67276 .82419 m .67592 .84204 L .69885 .83101 L p .707 .577 .707 r
F P
0 g
s
.69885 .83101 m .6957 .81316 L .67276 .82419 L p .707 .577 .707 r
F P
0 g
s
.55433 .84155 m .55749 .8594 L .58516 .86027 L p .707 .577 .707 r
F P
0 g
s
.69803 .66956 m .70348 .72422 L .7103 .714 L p .707 .577 .707 r
F P
0 g
s
.7103 .714 m .70484 .65934 L .69803 .66956 L p .707 .577 .707 r
F P
0 g
s
.52441 .77603 m .5303 .81187 L .55155 .81664 L p .707 .577 .707 r
F P
0 g
s
.50489 .68349 m .51034 .73814 L .52309 .746 L p .707 .577 .707 r
F P
0 g
s
.55749 .8594 m .55433 .84155 L .53269 .83705 L p .707 .577 .707 r
F P
0 g
s
.5303 .81187 m .52441 .77603 L .51143 .76822 L p .707 .577 .707 r
F P
0 g
s
.53269 .83705 m .53584 .8549 L .55749 .8594 L p .707 .577 .707 r
F P
0 g
s
.51034 .73814 m .50489 .68349 L .50176 .67398 L p .707 .577 .707 r
F P
0 g
s
.6957 .81316 m .69885 .83101 L .71397 .81913 L p .707 .577 .707 r
F P
0 g
s
.71397 .81913 m .71082 .80128 L .6957 .81316 L p .707 .577 .707 r
F P
0 g
s
.70326 .74327 m .70915 .77912 L .71557 .76776 L p .707 .577 .707 r
F P
0 g
s
.71557 .76776 m .70968 .73192 L .70326 .74327 L p .707 .577 .707 r
F P
0 g
s
.51143 .76822 m .51732 .80407 L .5303 .81187 L p .707 .577 .707 r
F P
0 g
s
.70484 .65934 m .7103 .714 L .70717 .70449 L p .707 .577 .707 r
F P
0 g
s
.70717 .70449 m .70172 .64984 L .70484 .65934 L p .707 .577 .707 r
F P
0 g
s
.53584 .8549 m .53269 .83705 L .51919 .82936 L p .707 .577 .707 r
F P
0 g
s
.50176 .67398 m .50721 .72864 L .51034 .73814 L p .707 .577 .707 r
F P
0 g
s
.51919 .82936 m .52234 .84721 L .53584 .8549 L p .707 .577 .707 r
F P
0 g
s
.51732 .80407 m .51143 .76822 L .50798 .75815 L p .707 .577 .707 r
F P
0 g
s
.50721 .72864 m .50176 .67398 L .50858 .66376 L p .707 .577 .707 r
F P
0 g
s
.50798 .75815 m .51387 .79399 L .51732 .80407 L p .707 .577 .707 r
F P
0 g
s
.50858 .66376 m .51403 .71842 L .50721 .72864 L p .707 .577 .707 r
F P
0 g
s
.51387 .79399 m .50798 .75815 L .5144 .74679 L p .707 .577 .707 r
F P
0 g
s
.51403 .71842 m .50858 .66376 L .52467 .65383 L p .707 .577 .707 r
F P
0 g
s
.51076 .82181 m .51076 .31993 L .46579 .31893 L p .707 .577 .707 r
F P
0 g
s
.52234 .84721 m .51919 .82936 L .51516 .81924 L p .707 .577 .707 r
F P
0 g
s
.51516 .81924 m .51831 .83708 L .52234 .84721 L p .707 .577 .707 r
F P
0 g
s
.5144 .74679 m .52029 .78264 L .51387 .79399 L p .707 .577 .707 r
F P
0 g
s
.51831 .83708 m .51516 .81924 L .52099 .80767 L p .707 .577 .707 r
F P
0 g
s
.52467 .65383 m .53012 .70848 L .51403 .71842 L p .707 .577 .707 r
F P
0 g
s
.52099 .80767 m .52414 .82551 L .51831 .83708 L p .707 .577 .707 r
F P
0 g
s
.52029 .78264 m .5144 .74679 L .53007 .73526 L p .707 .577 .707 r
F P
0 g
s
.53012 .70848 m .52467 .65383 L .54846 .64515 L p .707 .577 .707 r
F P
0 g
s
.53007 .73526 m .53596 .77111 L .52029 .78264 L p .707 .577 .707 r
F P
0 g
s
.54846 .64515 m .55391 .6998 L .53012 .70848 L p .707 .577 .707 r
F P
0 g
s
.52414 .82551 m .52099 .80767 L .53611 .79578 L p .707 .577 .707 r
F P
0 g
s
.53611 .79578 m .53927 .81363 L .52414 .82551 L p .707 .577 .707 r
F P
0 g
s
.53596 .77111 m .53007 .73526 L .55344 .72469 L p .707 .577 .707 r
F P
0 g
s
.55344 .72469 m .55933 .76053 L .53596 .77111 L p .707 .577 .707 r
F P
0 g
s
.53927 .81363 m .53611 .79578 L .55904 .78475 L p .707 .577 .707 r
F P
0 g
s
.55904 .78475 m .5622 .8026 L .53927 .81363 L p .707 .577 .707 r
F P
0 g
s
.51076 .31993 m .51076 .82181 L .55469 .81903 L p .707 .577 .707 r
F P
0 g
s
.55391 .6998 m .54846 .64515 L .57761 .63857 L p .707 .577 .707 r
F P
0 g
s
.57761 .63857 m .58306 .69323 L .55391 .6998 L p .707 .577 .707 r
F P
0 g
s
.55933 .76053 m .55344 .72469 L .58224 .71611 L p .707 .577 .707 r
F P
0 g
s
.55469 .81903 m .55469 .31715 L .51076 .31993 L p .707 .577 .707 r
F P
0 g
s
.71082 .80128 m .71397 .81913 L .71981 .80756 L p .707 .577 .707 r
F P
0 g
s
.71981 .80756 m .71665 .78971 L .71082 .80128 L p .707 .577 .707 r
F P
0 g
s
.46579 .82082 m .46579 .31893 L .42416 .31425 L p .707 .577 .707 r
F P
0 g
s
.46579 .31893 m .46579 .82082 L .51076 .82181 L p .707 .577 .707 r
F P
0 g
s
.58306 .69323 m .57761 .63857 L .60928 .63475 L p .707 .577 .707 r
F P
0 g
s
.60928 .63475 m .61473 .68941 L .58306 .69323 L p .707 .577 .707 r
F P
0 g
s
.58813 .75195 m .58224 .71611 L .61364 .71036 L p .707 .577 .707 r
F P
0 g
s
.58224 .71611 m .58813 .75195 L .55933 .76053 L p .707 .577 .707 r
F P
0 g
s
.61364 .71036 m .61953 .7462 L .58813 .75195 L p .707 .577 .707 r
F P
0 g
s
.5622 .8026 m .55904 .78475 L .58754 .77565 L p .707 .577 .707 r
F P
0 g
s
.58754 .77565 m .5907 .7935 L .5622 .8026 L p .707 .577 .707 r
F P
0 g
s
.5907 .7935 m .58754 .77565 L .61882 .76937 L p .707 .577 .707 r
F P
0 g
s
.61882 .76937 m .62197 .78722 L .5907 .7935 L p .707 .577 .707 r
F P
0 g
s
.55469 .31715 m .55469 .81903 L .59326 .81275 L p .707 .577 .707 r
F P
0 g
s
.59326 .81275 m .59326 .31086 L .55469 .31715 L p .707 .577 .707 r
F P
0 g
s
.70968 .73192 m .71557 .76776 L .71212 .75769 L p .707 .577 .707 r
F P
0 g
s
.71212 .75769 m .70623 .72184 L .70968 .73192 L p .707 .577 .707 r
F P
0 g
s
.70172 .64984 m .70717 .70449 L .69442 .69664 L p .707 .577 .707 r
F P
0 g
s
.69442 .69664 m .68897 .64198 L .70172 .64984 L p .707 .577 .707 r
F P
0 g
s
.42416 .81614 m .42416 .31425 L .38995 .30635 L p .707 .577 .707 r
F P
0 g
s
.42416 .31425 m .42416 .81614 L .46579 .82082 L p .707 .577 .707 r
F P
0 g
s
.25655 .70503 m .2542 .64828 L .223 .64833 L p .707 .577 .707 r
F P
0 g
s
.2542 .64828 m .25655 .70503 L .28833 .70319 L p .707 .577 .707 r
F P
0 g
s
.28833 .70319 m .28599 .64645 L .2542 .64828 L p .707 .577 .707 r
F P
0 g
s
.28599 .64645 m .28833 .70319 L .31758 .69974 L p .707 .577 .707 r
F P
0 g
s
.31758 .69974 m .31523 .643 L .28599 .64645 L p .707 .577 .707 r
F P
0 g
s
.71665 .78971 m .71981 .80756 L .71577 .79743 L p .707 .577 .707 r
F P
0 g
s
.71577 .79743 m .71262 .77958 L .71665 .78971 L p .707 .577 .707 r
F P
0 g
s
.64037 .63405 m .64582 .68871 L .61473 .68941 L p .707 .577 .707 r
F P
0 g
s
.61473 .68941 m .60928 .63475 L .64037 .63405 L p .707 .577 .707 r
F P
0 g
s
.61953 .7462 m .61364 .71036 L .64457 .708 L p .707 .577 .707 r
F P
0 g
s
.62197 .78722 m .61882 .76937 L .64981 .76653 L p .707 .577 .707 r
F P
0 g
s
.59326 .31086 m .59326 .81275 L .6227 .80357 L p .707 .577 .707 r
F P
0 g
s
.64457 .708 m .65046 .74384 L .61953 .7462 L p .707 .577 .707 r
F P
0 g
s
.64981 .76653 m .65296 .78437 L .62197 .78722 L p .707 .577 .707 r
F P
0 g
s
.6227 .80357 m .6227 .30168 L .59326 .31086 L p .707 .577 .707 r
F P
0 g
s
.22534 .70507 m .223 .64833 L .19541 .64659 L p .707 .577 .707 r
F P
0 g
s
.223 .64833 m .22534 .70507 L .25655 .70503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70623 .72184 m .71212 .75769 L .69914 .74988 L p .707 .577 .707 r
F P
0 g
s
.69914 .74988 m .69325 .71404 L .70623 .72184 L p .707 .577 .707 r
F P
0 g
s
.31523 .643 m .31758 .69974 L .34142 .69502 L p .707 .577 .707 r
F P
0 g
s
.34142 .69502 m .33907 .63828 L .31523 .643 L p .707 .577 .707 r
F P
0 g
s
.26049 .76122 m .25793 .72312 L .22668 .72442 L p .707 .577 .707 r
F P
0 g
s
.25793 .72312 m .26049 .76122 L .29218 .75869 L p .707 .577 .707 r
F P
0 g
s
.29218 .75869 m .28962 .72059 L .25793 .72312 L p .707 .577 .707 r
F P
0 g
s
.19541 .64659 m .19776 .70333 L .22534 .70507 L p .707 .577 .707 r
F P
0 g
s
.68897 .64198 m .69442 .69664 L .67328 .6912 L p .707 .577 .707 r
F P
0 g
s
.67328 .6912 m .66782 .63654 L .68897 .64198 L p .707 .577 .707 r
F P
0 g
s
.28962 .72059 m .29218 .75869 L .32121 .75517 L p .707 .577 .707 r
F P
0 g
s
.32121 .75517 m .31865 .71707 L .28962 .72059 L p .707 .577 .707 r
F P
0 g
s
.22668 .72442 m .22924 .76252 L .26049 .76122 L p .707 .577 .707 r
F P
0 g
s
.38995 .80824 m .38995 .30635 L .36652 .296 L p .707 .577 .707 r
F P
0 g
s
.38995 .30635 m .38995 .80824 L .42416 .81614 L p .707 .577 .707 r
F P
0 g
s
.22924 .76252 m .22668 .72442 L .19892 .72436 L p .707 .577 .707 r
F P
0 g
s
.19776 .70333 m .19541 .64659 L .17416 .64322 L p .707 .577 .707 r
F P
0 g
s
.26429 .80343 m .26291 .78437 L .23155 .78596 L p .707 .577 .707 r
F P
0 g
s
.26291 .78437 m .26429 .80343 L .29589 .80069 L p .707 .577 .707 r
F P
0 g
s
.29589 .80069 m .29451 .78163 L .26291 .78437 L p .707 .577 .707 r
F P
0 g
s
.19892 .72436 m .20148 .76246 L .22924 .76252 L p .707 .577 .707 r
F P
0 g
s
.23155 .78596 m .23293 .80502 L .26429 .80343 L p .707 .577 .707 r
F P
0 g
s
.29451 .78163 m .29589 .80069 L .32465 .79708 L p .707 .577 .707 r
F P
0 g
s
.32465 .79708 m .32327 .77802 L .29451 .78163 L p .707 .577 .707 r
F P
0 g
s
.23293 .80502 m .23155 .78596 L .20351 .78625 L p .707 .577 .707 r
F P
0 g
s
.31865 .71707 m .32121 .75517 L .34474 .751 L p .707 .577 .707 r
F P
0 g
s
.34474 .751 m .34218 .7129 L .31865 .71707 L p .707 .577 .707 r
F P
0 g
s
.17416 .64322 m .17651 .69996 L .19776 .70333 L p .707 .577 .707 r
F P
0 g
s
.20351 .78625 m .20489 .80531 L .23293 .80502 L p .707 .577 .707 r
F P
0 g
s
.71262 .77958 m .71577 .79743 L .70228 .78974 L p .707 .577 .707 r
F P
0 g
s
.70228 .78974 m .69912 .7719 L .71262 .77958 L p .707 .577 .707 r
F P
0 g
s
.33907 .63828 m .34142 .69502 L .35753 .68949 L p .707 .577 .707 r
F P
0 g
s
.35753 .68949 m .35518 .63275 L .33907 .63828 L p .707 .577 .707 r
F P
0 g
s
.6227 .30168 m .6227 .80357 L .64013 .7924 L p .707 .577 .707 r
F P
0 g
s
.64013 .7924 m .64013 .29051 L .6227 .30168 L p .707 .577 .707 r
F P
0 g
s
.20148 .76246 m .19892 .72436 L .17738 .72293 L p .707 .577 .707 r
F P
0 g
s
.69325 .71404 m .69914 .74988 L .67789 .74511 L p .707 .577 .707 r
F P
0 g
s
.67789 .74511 m .672 .70927 L .69325 .71404 L p .707 .577 .707 r
F P
0 g
s
.66782 .63654 m .67328 .6912 L .64582 .68871 L p .707 .577 .707 r
F P
0 g
s
.64582 .68871 m .64037 .63405 L .66782 .63654 L p .707 .577 .707 r
F P
0 g
s
.17738 .72293 m .17994 .76103 L .20148 .76246 L p .707 .577 .707 r
F P
0 g
s
.32327 .77802 m .32465 .79708 L .34776 .79293 L p .707 .577 .707 r
F P
0 g
s
.34776 .79293 m .34638 .77387 L .32327 .77802 L p .707 .577 .707 r
F P
0 g
s
.17651 .69996 m .17416 .64322 L .16132 .63855 L p .707 .577 .707 r
F P
0 g
s
.20489 .80531 m .20351 .78625 L .18153 .7852 L p .707 .577 .707 r
F P
0 g
s
.18153 .7852 m .18291 .80426 L .20489 .80531 L p .707 .577 .707 r
F P
0 g
s
.34218 .7129 m .34474 .751 L .36045 .7466 L p .707 .577 .707 r
F P
0 g
s
.36045 .7466 m .35789 .7085 L .34218 .7129 L p .707 .577 .707 r
F P
0 g
s
.16132 .63855 m .16367 .69529 L .17651 .69996 L p .707 .577 .707 r
F P
0 g
s
.35518 .63275 m .35753 .68949 L .36433 .68369 L p .707 .577 .707 r
F P
0 g
s
.36433 .68369 m .36198 .62695 L .35518 .63275 L p .707 .577 .707 r
F P
0 g
s
.35789 .7085 m .36045 .7466 L .36682 .74239 L p .707 .577 .707 r
F P
0 g
s
.36682 .74239 m .36426 .70429 L .35789 .7085 L p .707 .577 .707 r
F P
0 g
s
.36156 .76961 m .36294 .78867 L .36871 .7847 L p .707 .577 .707 r
F P
0 g
s
.36871 .7847 m .36733 .76564 L .36156 .76961 L p .707 .577 .707 r
F P
0 g
s
.36198 .62695 m .36433 .68369 L .36115 .67819 L p .707 .577 .707 r
F P
0 g
s
.36426 .70429 m .36682 .74239 L .36323 .73879 L p .707 .577 .707 r
F P
0 g
s
.36733 .76564 m .36871 .7847 L .36451 .78142 L p .707 .577 .707 r
F P
0 g
s
.36451 .78142 m .36313 .76236 L .36733 .76564 L p .707 .577 .707 r
F P
0 g
s
.36652 .79789 m .36652 .296 L .35616 .28422 L p .707 .577 .707 r
F P
0 g
s
.36652 .296 m .36652 .79789 L .38995 .80824 L p .707 .577 .707 r
F P
0 g
s
.17994 .76103 m .17738 .72293 L .16417 .72029 L p .707 .577 .707 r
F P
0 g
s
.69912 .7719 m .70228 .78974 L .68063 .78524 L p .707 .577 .707 r
F P
0 g
s
.68063 .78524 m .67748 .7674 L .69912 .7719 L p .707 .577 .707 r
F P
0 g
s
.34638 .77387 m .34776 .79293 L .36294 .78867 L p .707 .577 .707 r
F P
0 g
s
.36294 .78867 m .36156 .76961 L .34638 .77387 L p .707 .577 .707 r
F P
0 g
s
.672 .70927 m .67789 .74511 L .65046 .74384 L p .707 .577 .707 r
F P
0 g
s
.65046 .74384 m .64457 .708 L .672 .70927 L p .707 .577 .707 r
F P
0 g
s
.16417 .72029 m .16673 .75839 L .17994 .76103 L p .707 .577 .707 r
F P
0 g
s
.18291 .80426 m .18153 .7852 L .16777 .78292 L p .707 .577 .707 r
F P
0 g
s
.16777 .78292 m .16915 .80198 L .18291 .80426 L p .707 .577 .707 r
F P
0 g
s
.16367 .69529 m .16132 .63855 L .15814 .63305 L p .707 .577 .707 r
F P
0 g
s
.64013 .29051 m .64013 .7924 L .64384 .78033 L p .707 .577 .707 r
F P
0 g
s
.64384 .78033 m .64384 .27844 L .64013 .29051 L p .707 .577 .707 r
F P
0 g
s
.67748 .7674 m .68063 .78524 L .65296 .78437 L p .707 .577 .707 r
F P
0 g
s
.65296 .78437 m .64981 .76653 L .67748 .7674 L p .707 .577 .707 r
F P
0 g
s
.15814 .63305 m .16049 .68979 L .16367 .69529 L p .707 .577 .707 r
F P
0 g
s
.16673 .75839 m .16417 .72029 L .16057 .71669 L p .707 .577 .707 r
F P
0 g
s
.36115 .67819 m .3588 .62145 L .36198 .62695 L p .707 .577 .707 r
F P
0 g
s
.16057 .71669 m .16313 .75479 L .16673 .75839 L p .707 .577 .707 r
F P
0 g
s
.16915 .80198 m .16777 .78292 L .16357 .77964 L p .707 .577 .707 r
F P
0 g
s
.36323 .73879 m .36067 .70069 L .36426 .70429 L p .707 .577 .707 r
F P
0 g
s
.3588 .62145 m .36115 .67819 L .3483 .67353 L p .707 .577 .707 r
F P
0 g
s
.3483 .67353 m .34596 .61679 L .3588 .62145 L p .707 .577 .707 r
F P
0 g
s
.36067 .70069 m .36323 .73879 L .35001 .73615 L p .707 .577 .707 r
F P
0 g
s
.35001 .73615 m .34745 .69805 L .36067 .70069 L p .707 .577 .707 r
F P
0 g
s
.36313 .76236 m .36451 .78142 L .35075 .77914 L p .707 .577 .707 r
F P
0 g
s
.35075 .77914 m .34937 .76008 L .36313 .76236 L p .707 .577 .707 r
F P
0 g
s
.35616 .28422 m .35616 .78611 L .36652 .79789 L p .707 .577 .707 r
F P
0 g
s
.35616 .78611 m .35616 .28422 L .35987 .27215 L p .707 .577 .707 r
F P
0 g
s
.16357 .77964 m .16495 .7987 L .16915 .80198 L p .707 .577 .707 r
F P
0 g
s
.16049 .68979 m .15814 .63305 L .16493 .62725 L p .707 .577 .707 r
F P
0 g
s
.16493 .62725 m .16728 .684 L .16049 .68979 L p .707 .577 .707 r
F P
0 g
s
.64384 .27844 m .64384 .78033 L .63348 .76854 L p .707 .577 .707 r
F P
0 g
s
.63348 .76854 m .63348 .26666 L .64384 .27844 L p .707 .577 .707 r
F P
0 g
s
.16313 .75479 m .16057 .71669 L .16694 .71248 L p .707 .577 .707 r
F P
0 g
s
.16694 .71248 m .1695 .75058 L .16313 .75479 L p .707 .577 .707 r
F P
0 g
s
.16495 .7987 m .16357 .77964 L .16934 .77567 L p .707 .577 .707 r
F P
0 g
s
.16934 .77567 m .17073 .79473 L .16495 .7987 L p .707 .577 .707 r
F P
0 g
s
.16728 .684 m .16493 .62725 L .18104 .62172 L p .707 .577 .707 r
F P
0 g
s
.35987 .77404 m .35987 .27215 L .3773 .26098 L p .707 .577 .707 r
F P
0 g
s
.35987 .27215 m .35987 .77404 L .35616 .78611 L p .707 .577 .707 r
F P
0 g
s
.18104 .62172 m .18339 .67847 L .16728 .684 L p .707 .577 .707 r
F P
0 g
s
.1695 .75058 m .16694 .71248 L .18266 .70808 L p .707 .577 .707 r
F P
0 g
s
.34596 .61679 m .3483 .67353 L .32705 .67016 L p .707 .577 .707 r
F P
0 g
s
.32705 .67016 m .3247 .61342 L .34596 .61679 L p .707 .577 .707 r
F P
0 g
s
.18266 .70808 m .18522 .74618 L .1695 .75058 L p .707 .577 .707 r
F P
0 g
s
.17073 .79473 m .16934 .77567 L .18452 .77141 L p .707 .577 .707 r
F P
0 g
s
.63348 .26666 m .63348 .76854 L .61004 .75819 L p .707 .577 .707 r
F P
0 g
s
.61004 .75819 m .61004 .25631 L .63348 .26666 L p .707 .577 .707 r
F P
0 g
s
.18452 .77141 m .18591 .79047 L .17073 .79473 L p .707 .577 .707 r
F P
0 g
s
.18339 .67847 m .18104 .62172 L .20489 .61701 L p .707 .577 .707 r
F P
0 g
s
.34745 .69805 m .35001 .73615 L .32847 .73473 L p .707 .577 .707 r
F P
0 g
s
.32847 .73473 m .32591 .69663 L .34745 .69805 L p .707 .577 .707 r
F P
0 g
s
.20489 .61701 m .20724 .67375 L .18339 .67847 L p .707 .577 .707 r
F P
0 g
s
.3247 .61342 m .32705 .67016 L .29947 .66841 L p .707 .577 .707 r
F P
0 g
s
.29947 .66841 m .29712 .61167 L .3247 .61342 L p .707 .577 .707 r
F P
0 g
s
.18522 .74618 m .18266 .70808 L .20618 .70392 L p .707 .577 .707 r
F P
0 g
s
.3773 .26098 m .3773 .76287 L .35987 .77404 L p .707 .577 .707 r
F P
0 g
s
.3773 .76287 m .3773 .26098 L .40674 .2518 L p .707 .577 .707 r
F P
0 g
s
.34937 .76008 m .35075 .77914 L .32877 .77809 L p .707 .577 .707 r
F P
0 g
s
.32877 .77809 m .32739 .75903 L .34937 .76008 L p .707 .577 .707 r
F P
0 g
s
.20724 .67375 m .20489 .61701 L .23413 .61356 L p .707 .577 .707 r
F P
0 g
s
.20618 .70392 m .20874 .74201 L .18522 .74618 L p .707 .577 .707 r
F P
0 g
s
.18591 .79047 m .18452 .77141 L .20763 .76726 L p .707 .577 .707 r
F P
0 g
s
.20763 .76726 m .20901 .78633 L .18591 .79047 L p .707 .577 .707 r
F P
0 g
s
.29712 .61167 m .29947 .66841 L .26826 .66846 L p .707 .577 .707 r
F P
0 g
s
.26826 .66846 m .26591 .61172 L .29712 .61167 L p .707 .577 .707 r
F P
0 g
s
.23413 .61356 m .23648 .6703 L .20724 .67375 L p .707 .577 .707 r
F P
0 g
s
.32591 .69663 m .32847 .73473 L .30072 .73466 L p .707 .577 .707 r
F P
0 g
s
.30072 .73466 m .29816 .69656 L .32591 .69663 L p .707 .577 .707 r
F P
0 g
s
.23648 .6703 m .23413 .61356 L .26591 .61172 L p .707 .577 .707 r
F P
0 g
s
.61004 .25631 m .61004 .75819 L .57584 .7503 L p .707 .577 .707 r
F P
0 g
s
.57584 .7503 m .57584 .24841 L .61004 .25631 L p .707 .577 .707 r
F P
0 g
s
.26591 .61172 m .26826 .66846 L .23648 .6703 L p .707 .577 .707 r
F P
0 g
s
.20874 .74201 m .20618 .70392 L .23521 .70039 L p .707 .577 .707 r
F P
0 g
s
.73174 .66462 m .73408 .61078 L .70288 .60716 L p .707 .577 .707 r
F P
0 g
s
.73408 .61078 m .73174 .66462 L .76352 .6647 L p .707 .577 .707 r
F P
0 g
s
.76352 .6647 m .76587 .61085 L .73408 .61078 L p .707 .577 .707 r
F P
0 g
s
.23521 .70039 m .23777 .73849 L .20874 .74201 L p .707 .577 .707 r
F P
0 g
s
.32739 .75903 m .32877 .77809 L .30073 .77838 L p .707 .577 .707 r
F P
0 g
s
.30073 .77838 m .29935 .75932 L .32739 .75903 L p .707 .577 .707 r
F P
0 g
s
.76587 .61085 m .76352 .6647 L .79276 .66122 L p .707 .577 .707 r
F P
0 g
s
.79276 .66122 m .79511 .60737 L .76587 .61085 L p .707 .577 .707 r
F P
0 g
s
.70053 .66101 m .70288 .60716 L .6753 .60035 L p .707 .577 .707 r
F P
0 g
s
.70288 .60716 m .70053 .66101 L .73174 .66462 L p .707 .577 .707 r
F P
0 g
s
.20901 .78633 m .20763 .76726 L .23639 .76365 L p .707 .577 .707 r
F P
0 g
s
.29816 .69656 m .30072 .73466 L .26946 .73596 L p .707 .577 .707 r
F P
0 g
s
.26946 .73596 m .2669 .69786 L .29816 .69656 L p .707 .577 .707 r
F P
0 g
s
.23639 .76365 m .23777 .78271 L .20901 .78633 L p .707 .577 .707 r
F P
0 g
s
.23777 .73849 m .23521 .70039 L .2669 .69786 L p .707 .577 .707 r
F P
0 g
s
.40674 .75369 m .40674 .2518 L .44531 .24551 L p .707 .577 .707 r
F P
0 g
s
.40674 .2518 m .40674 .75369 L .3773 .76287 L p .707 .577 .707 r
F P
0 g
s
.2669 .69786 m .26946 .73596 L .23777 .73849 L p .707 .577 .707 r
F P
0 g
s
.79511 .60737 m .79276 .66122 L .81661 .65452 L p .707 .577 .707 r
F P
0 g
s
.81661 .65452 m .81895 .60068 L .79511 .60737 L p .707 .577 .707 r
F P
0 g
s
.29935 .75932 m .30073 .77838 L .26938 .77997 L p .707 .577 .707 r
F P
0 g
s
.26938 .77997 m .26799 .76091 L .29935 .75932 L p .707 .577 .707 r
F P
0 g
s
.23777 .78271 m .23639 .76365 L .26799 .76091 L p .707 .577 .707 r
F P
0 g
s
.67295 .65419 m .6753 .60035 L .65404 .59101 L p .707 .577 .707 r
F P
0 g
s
.6753 .60035 m .67295 .65419 L .70053 .66101 L p .707 .577 .707 r
F P
0 g
s
.26799 .76091 m .26938 .77997 L .23777 .78271 L p .707 .577 .707 r
F P
0 g
s
.57584 .24841 m .57584 .7503 L .53421 .74562 L p .707 .577 .707 r
F P
0 g
s
.53421 .74562 m .53421 .24373 L .57584 .24841 L p .707 .577 .707 r
F P
0 g
s
.73054 .72861 m .7331 .6936 L .70184 .68908 L p .707 .577 .707 r
F P
0 g
s
.7331 .6936 m .73054 .72861 L .76223 .72906 L p .707 .577 .707 r
F P
0 g
s
.76223 .72906 m .76479 .69405 L .7331 .6936 L p .707 .577 .707 r
F P
0 g
s
.76479 .69405 m .76223 .72906 L .79126 .7254 L p .707 .577 .707 r
F P
0 g
s
.79126 .7254 m .79382 .69039 L .76479 .69405 L p .707 .577 .707 r
F P
0 g
s
.69928 .72409 m .70184 .68908 L .67409 .68094 L p .707 .577 .707 r
F P
0 g
s
.70184 .68908 m .69928 .72409 L .73054 .72861 L p .707 .577 .707 r
F P
0 g
s
.44531 .7474 m .44531 .24551 L .48923 .24273 L p .707 .577 .707 r
F P
0 g
s
.44531 .24551 m .44531 .7474 L .40674 .75369 L p .707 .577 .707 r
F P
0 g
s
.81895 .60068 m .81661 .65452 L .83271 .64527 L p .707 .577 .707 r
F P
0 g
s
.83271 .64527 m .83506 .59143 L .81895 .60068 L p .707 .577 .707 r
F P
0 g
s
.65404 .59101 m .65169 .64486 L .67295 .65419 L p .707 .577 .707 r
F P
0 g
s
.53421 .24373 m .53421 .74562 L .48923 .74462 L p .707 .577 .707 r
F P
0 g
s
.48923 .74462 m .48923 .24273 L .53421 .24373 L p .707 .577 .707 r
F P
0 g
s
.65169 .64486 m .65404 .59101 L .6412 .58007 L p .707 .577 .707 r
F P
0 g
s
.48923 .24273 m .48923 .74462 L .44531 .7474 L p .707 .577 .707 r
F P
0 g
s
.79382 .69039 m .79126 .7254 L .81478 .71799 L p .707 .577 .707 r
F P
0 g
s
.81478 .71799 m .81734 .68298 L .79382 .69039 L p .707 .577 .707 r
F P
0 g
s
.67153 .71595 m .67409 .68094 L .65255 .66997 L p .707 .577 .707 r
F P
0 g
s
.67409 .68094 m .67153 .71595 L .69928 .72409 L p .707 .577 .707 r
F P
0 g
s
.73062 .77025 m .732 .75282 L .70065 .74835 L p .707 .577 .707 r
F P
0 g
s
.732 .75282 m .73062 .77025 L .76223 .77057 L p .707 .577 .707 r
F P
0 g
s
.76223 .77057 m .76361 .75313 L .732 .75282 L p .707 .577 .707 r
F P
0 g
s
.69926 .76579 m .70065 .74835 L .67261 .74017 L p .707 .577 .707 r
F P
0 g
s
.70065 .74835 m .69926 .76579 L .73062 .77025 L p .707 .577 .707 r
F P
0 g
s
.76361 .75313 m .76223 .77057 L .79099 .7667 L p .707 .577 .707 r
F P
0 g
s
.79099 .7667 m .79237 .74926 L .76361 .75313 L p .707 .577 .707 r
F P
0 g
s
.83506 .59143 m .83271 .64527 L .83951 .63437 L p .707 .577 .707 r
F P
0 g
s
.83951 .63437 m .84186 .58052 L .83506 .59143 L p .707 .577 .707 r
F P
0 g
s
.6412 .58007 m .63885 .63391 L .65169 .64486 L p .707 .577 .707 r
F P
0 g
s
.65255 .66997 m .64999 .70498 L .67153 .71595 L p .707 .577 .707 r
F P
0 g
s
.67261 .74017 m .67123 .75761 L .69926 .76579 L p .707 .577 .707 r
F P
0 g
s
.81734 .68298 m .81478 .71799 L .8305 .70755 L p .707 .577 .707 r
F P
0 g
s
.8305 .70755 m .83306 .67254 L .81734 .68298 L p .707 .577 .707 r
F P
0 g
s
.64999 .70498 m .65255 .66997 L .63933 .65724 L p .707 .577 .707 r
F P
0 g
s
.63885 .63391 m .6412 .58007 L .63802 .56858 L p .707 .577 .707 r
F P
0 g
s
.67123 .75761 m .67261 .74017 L .65063 .72908 L p .707 .577 .707 r
F P
0 g
s
.79237 .74926 m .79099 .7667 L .81409 .75903 L p .707 .577 .707 r
F P
0 g
s
.81409 .75903 m .81547 .74159 L .79237 .74926 L p .707 .577 .707 r
F P
0 g
s
.65063 .72908 m .64925 .74652 L .67123 .75761 L p .707 .577 .707 r
F P
0 g
s
.63933 .65724 m .63677 .69225 L .64999 .70498 L p .707 .577 .707 r
F P
0 g
s
.63802 .56858 m .63567 .62242 L .63885 .63391 L p .707 .577 .707 r
F P
0 g
s
.64925 .74652 m .65063 .72908 L .63687 .71616 L p .707 .577 .707 r
F P
0 g
s
.84186 .58052 m .83951 .63437 L .83633 .62288 L p .707 .577 .707 r
F P
0 g
s
.83633 .62288 m .83868 .56903 L .84186 .58052 L p .707 .577 .707 r
F P
0 g
s
.81547 .74159 m .81409 .75903 L .82927 .7483 L p .707 .577 .707 r
F P
0 g
s
.82927 .7483 m .83065 .73087 L .81547 .74159 L p .707 .577 .707 r
F P
0 g
s
.83306 .67254 m .8305 .70755 L .83687 .6951 L p .707 .577 .707 r
F P
0 g
s
.83687 .6951 m .83943 .66009 L .83306 .67254 L p .707 .577 .707 r
F P
0 g
s
.63677 .69225 m .63933 .65724 L .63573 .64401 L p .707 .577 .707 r
F P
0 g
s
.63687 .71616 m .63549 .73359 L .64925 .74652 L p .707 .577 .707 r
F P
0 g
s
.63567 .62242 m .63802 .56858 L .64482 .55767 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63573 .64401 m .63317 .67902 L .63677 .69225 L p .707 .577 .707 r
F P
0 g
s
.63549 .73359 m .63687 .71616 L .63267 .70267 L p .707 .577 .707 r
F P
0 g
s
.83065 .73087 m .82927 .7483 L .83505 .73557 L p .707 .577 .707 r
F P
0 g
s
.83505 .73557 m .83643 .71814 L .83065 .73087 L p .707 .577 .707 r
F P
0 g
s
.64482 .55767 m .64247 .61152 L .63567 .62242 L p .707 .577 .707 r
F P
0 g
s
.83868 .56903 m .83633 .62288 L .82349 .61193 L p .707 .577 .707 r
F P
0 g
s
.82349 .61193 m .82584 .55809 L .83868 .56903 L p .707 .577 .707 r
F P
0 g
s
.83943 .66009 m .83687 .6951 L .83327 .68187 L p .707 .577 .707 r
F P
0 g
s
.83327 .68187 m .83583 .64686 L .83943 .66009 L p .707 .577 .707 r
F P
0 g
s
.63317 .67902 m .63573 .64401 L .64211 .63156 L p .707 .577 .707 r
F P
0 g
s
.63267 .70267 m .63129 .72011 L .63549 .73359 L p .707 .577 .707 r
F P
0 g
s
.38526 .61658 m .39072 .56066 L .35963 .55623 L p .707 .577 .707 r
F P
0 g
s
.39072 .56066 m .38526 .61658 L .41694 .61879 L p .707 .577 .707 r
F P
0 g
s
.41694 .61879 m .42239 .56287 L .39072 .56066 L p .707 .577 .707 r
F P
0 g
s
.64247 .61152 m .64482 .55767 L .66093 .54842 L p .707 .577 .707 r
F P
0 g
s
.42239 .56287 m .41694 .61879 L .44609 .61855 L p .707 .577 .707 r
F P
0 g
s
.44609 .61855 m .45154 .56263 L .42239 .56287 L p .707 .577 .707 r
F P
0 g
s
.35418 .61214 m .35963 .55623 L .33217 .54999 L p .707 .577 .707 r
F P
0 g
s
.35963 .55623 m .35418 .61214 L .38526 .61658 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64211 .63156 m .63955 .66658 L .63317 .67902 L p .707 .577 .707 r
F P
0 g
s
.45154 .56263 m .44609 .61855 L .46988 .6159 L p .707 .577 .707 r
F P
0 g
s
.46988 .6159 m .47533 .55998 L .45154 .56263 L p .707 .577 .707 r
F P
0 g
s
.63129 .72011 m .63267 .70267 L .63844 .68994 L p .707 .577 .707 r
F P
0 g
s
.38047 .67469 m .38636 .63747 L .35543 .63146 L p .707 .577 .707 r
F P
0 g
s
.38636 .63747 m .38047 .67469 L .41187 .67875 L p .707 .577 .707 r
F P
0 g
s
.41187 .67875 m .41776 .64153 L .38636 .63747 L p .707 .577 .707 r
F P
0 g
s
.33217 .54999 m .32672 .60591 L .35418 .61214 L p .707 .577 .707 r
F P
0 g
s
.83643 .71814 m .83505 .73557 L .83085 .72209 L p .707 .577 .707 r
F P
0 g
s
.83085 .72209 m .83223 .70465 L .83643 .71814 L p .707 .577 .707 r
F P
0 g
s
.82584 .55809 m .82349 .61193 L .80224 .60259 L p .707 .577 .707 r
F P
0 g
s
.80224 .60259 m .80458 .54875 L .82584 .55809 L p .707 .577 .707 r
F P
0 g
s
.32672 .60591 m .33217 .54999 L .31103 .54258 L p .707 .577 .707 r
F P
0 g
s
.66093 .54842 m .65858 .60226 L .64247 .61152 L p .707 .577 .707 r
F P
0 g
s
.83583 .64686 m .83327 .68187 L .82006 .66914 L p .707 .577 .707 r
F P
0 g
s
.82006 .66914 m .82262 .63413 L .83583 .64686 L p .707 .577 .707 r
F P
0 g
s
.41776 .64153 m .41187 .67875 L .44067 .68046 L p .707 .577 .707 r
F P
0 g
s
.44067 .68046 m .44656 .64324 L .41776 .64153 L p .707 .577 .707 r
F P
0 g
s
.34954 .66868 m .35543 .63146 L .32799 .62409 L p .707 .577 .707 r
F P
0 g
s
.35543 .63146 m .34954 .66868 L .38047 .67469 L p .707 .577 .707 r
F P
0 g
s
.63955 .66658 m .64211 .63156 L .65782 .62112 L p .707 .577 .707 r
F P
0 g
s
.63844 .68994 m .63706 .70738 L .63129 .72011 L p .707 .577 .707 r
F P
0 g
s
.65858 .60226 m .66093 .54842 L .68477 .54173 L p .707 .577 .707 r
F P
0 g
s
.32799 .62409 m .3221 .66131 L .34954 .66868 L p .707 .577 .707 r
F P
0 g
s
.37803 .71673 m .38118 .69813 L .35019 .69192 L p .707 .577 .707 r
F P
0 g
s
.38118 .69813 m .37803 .71673 L .4093 .72103 L p .707 .577 .707 r
F P
0 g
s
.4093 .72103 m .41246 .70243 L .38118 .69813 L p .707 .577 .707 r
F P
0 g
s
.31103 .54258 m .30558 .5985 L .32672 .60591 L p .707 .577 .707 r
F P
0 g
s
.35019 .69192 m .34704 .71052 L .37803 .71673 L p .707 .577 .707 r
F P
0 g
s
.44656 .64324 m .44067 .68046 L .46404 .67965 L p .707 .577 .707 r
F P
0 g
s
.46404 .67965 m .46993 .64243 L .44656 .64324 L p .707 .577 .707 r
F P
0 g
s
.34704 .71052 m .35019 .69192 L .32252 .6844 L p .707 .577 .707 r
F P
0 g
s
.41246 .70243 m .4093 .72103 L .4378 .723 L p .707 .577 .707 r
F P
0 g
s
.4378 .723 m .44096 .7044 L .41246 .70243 L p .707 .577 .707 r
F P
0 g
s
.47533 .55998 m .46988 .6159 L .48597 .61108 L p .707 .577 .707 r
F P
0 g
s
.48597 .61108 m .49142 .55516 L .47533 .55998 L p .707 .577 .707 r
F P
0 g
s
.3221 .66131 m .32799 .62409 L .30675 .61607 L p .707 .577 .707 r
F P
0 g
s
.65782 .62112 m .65526 .65613 L .63955 .66658 L p .707 .577 .707 r
F P
0 g
s
.32252 .6844 m .31936 .703 L .34704 .71052 L p .707 .577 .707 r
F P
0 g
s
.80458 .54875 m .80224 .60259 L .77465 .59578 L p .707 .577 .707 r
F P
0 g
s
.77465 .59578 m .777 .54194 L .80458 .54875 L p .707 .577 .707 r
F P
0 g
s
.30558 .5985 m .31103 .54258 L .29827 .5347 L p .707 .577 .707 r
F P
0 g
s
.63706 .70738 m .63844 .68994 L .65362 .67922 L p .707 .577 .707 r
F P
0 g
s
.30675 .61607 m .30086 .6533 L .3221 .66131 L p .707 .577 .707 r
F P
0 g
s
.68242 .59557 m .68477 .54173 L .71401 .53825 L p .707 .577 .707 r
F P
0 g
s
.68477 .54173 m .68242 .59557 L .65858 .60226 L p .707 .577 .707 r
F P
0 g
s
.83223 .70465 m .83085 .72209 L .81708 .70917 L p .707 .577 .707 r
F P
0 g
s
.81708 .70917 m .81847 .69173 L .83223 .70465 L p .707 .577 .707 r
F P
0 g
s
.82262 .63413 m .82006 .66914 L .79852 .65817 L p .707 .577 .707 r
F P
0 g
s
.79852 .65817 m .80108 .62316 L .82262 .63413 L p .707 .577 .707 r
F P
0 g
s
.65526 .65613 m .65782 .62112 L .68135 .61371 L p .707 .577 .707 r
F P
0 g
s
.31936 .703 m .32252 .6844 L .30088 .67631 L p .707 .577 .707 r
F P
0 g
s
.44096 .7044 m .4378 .723 L .46073 .72244 L p .707 .577 .707 r
F P
0 g
s
.46073 .72244 m .46389 .70384 L .44096 .7044 L p .707 .577 .707 r
F P
0 g
s
.65362 .67922 m .65224 .69666 L .63706 .70738 L p .707 .577 .707 r
F P
0 g
s
.30088 .67631 m .29772 .69492 L .31936 .703 L p .707 .577 .707 r
F P
0 g
s
.29827 .5347 m .29282 .59062 L .30558 .5985 L p .707 .577 .707 r
F P
0 g
s
.777 .54194 m .77465 .59578 L .74345 .59216 L p .707 .577 .707 r
F P
0 g
s
.74345 .59216 m .74579 .53832 L .777 .54194 L p .707 .577 .707 r
F P
0 g
s
.46993 .64243 m .46404 .67965 L .47971 .67641 L p .707 .577 .707 r
F P
0 g
s
.47971 .67641 m .4856 .63919 L .46993 .64243 L p .707 .577 .707 r
F P
0 g
s
.71166 .59209 m .71401 .53825 L .74579 .53832 L p .707 .577 .707 r
F P
0 g
s
.71401 .53825 m .71166 .59209 L .68242 .59557 L p .707 .577 .707 r
F P
0 g
s
.30086 .6533 m .30675 .61607 L .29376 .6082 L p .707 .577 .707 r
F P
0 g
s
.74579 .53832 m .74345 .59216 L .71166 .59209 L p .707 .577 .707 r
F P
0 g
s
.49142 .55516 m .48597 .61108 L .49278 .60457 L p .707 .577 .707 r
F P
0 g
s
.49278 .60457 m .49823 .54865 L .49142 .55516 L p .707 .577 .707 r
F P
0 g
s
.68135 .61371 m .67879 .64872 L .65526 .65613 L p .707 .577 .707 r
F P
0 g
s
.29376 .6082 m .28787 .64542 L .30086 .6533 L p .707 .577 .707 r
F P
0 g
s
.80108 .62316 m .79852 .65817 L .77076 .65003 L p .707 .577 .707 r
F P
0 g
s
.77076 .65003 m .77332 .61502 L .80108 .62316 L p .707 .577 .707 r
F P
0 g
s
.67879 .64872 m .68135 .61371 L .71038 .61005 L p .707 .577 .707 r
F P
0 g
s
.29282 .59062 m .29827 .5347 L .29515 .52714 L p .707 .577 .707 r
F P
0 g
s
.65224 .69666 m .65362 .67922 L .67672 .67155 L p .707 .577 .707 r
F P
0 g
s
.29772 .69492 m .30088 .67631 L .28738 .66845 L p .707 .577 .707 r
F P
0 g
s
.81847 .69173 m .81708 .70917 L .79511 .69807 L p .707 .577 .707 r
F P
0 g
s
.79511 .69807 m .79649 .68064 L .81847 .69173 L p .707 .577 .707 r
F P
0 g
s
.46389 .70384 m .46073 .72244 L .47585 .71942 L p .707 .577 .707 r
F P
0 g
s
.47585 .71942 m .47901 .70081 L .46389 .70384 L p .707 .577 .707 r
F P
0 g
s
.28738 .66845 m .28422 .68705 L .29772 .69492 L p .707 .577 .707 r
F P
0 g
s
.67672 .67155 m .67534 .68898 L .65224 .69666 L p .707 .577 .707 r
F P
0 g
s
.77332 .61502 m .77076 .65003 L .73951 .64551 L p .707 .577 .707 r
F P
0 g
s
.73951 .64551 m .74207 .6105 L .77332 .61502 L p .707 .577 .707 r
F P
0 g
s
.70782 .64506 m .71038 .61005 L .74207 .6105 L p .707 .577 .707 r
F P
0 g
s
.71038 .61005 m .70782 .64506 L .67879 .64872 L p .707 .577 .707 r
F P
0 g
s
.29515 .52714 m .2897 .58306 L .29282 .59062 L p .707 .577 .707 r
F P
0 g
s
.4856 .63919 m .47971 .67641 L .48613 .67104 L p .707 .577 .707 r
F P
0 g
s
.48613 .67104 m .49202 .63382 L .4856 .63919 L p .707 .577 .707 r
F P
0 g
s
.74207 .6105 m .73951 .64551 L .70782 .64506 L p .707 .577 .707 r
F P
0 g
s
.28787 .64542 m .29376 .6082 L .29031 .60124 L p .707 .577 .707 r
F P
0 g
s
.67534 .68898 m .67672 .67155 L .70549 .66768 L p .707 .577 .707 r
F P
0 g
s
.79649 .68064 m .79511 .69807 L .76707 .68989 L p .707 .577 .707 r
F P
0 g
s
.76707 .68989 m .76845 .67246 L .79649 .68064 L p .707 .577 .707 r
F P
0 g
s
.49823 .54865 m .49278 .60457 L .48966 .59701 L p .707 .577 .707 r
F P
0 g
s
.48966 .59701 m .49511 .54109 L .49823 .54865 L p .707 .577 .707 r
F P
0 g
s
.29031 .60124 m .28442 .63846 L .28787 .64542 L p .707 .577 .707 r
F P
0 g
s
.70549 .66768 m .70411 .68511 L .67534 .68898 L p .707 .577 .707 r
F P
0 g
s
.28422 .68705 m .28738 .66845 L .28335 .66158 L p .707 .577 .707 r
F P
0 g
s
.47901 .70081 m .47585 .71942 L .48169 .71421 L p .707 .577 .707 r
F P
0 g
s
.48169 .71421 m .48484 .69561 L .47901 .70081 L p .707 .577 .707 r
F P
0 g
s
.2897 .58306 m .29515 .52714 L .30197 .52063 L p .707 .577 .707 r
F P
0 g
s
.28335 .66158 m .28019 .68019 L .28422 .68705 L p .707 .577 .707 r
F P
0 g
s
.70411 .68511 m .70549 .66768 L .73709 .66799 L p .707 .577 .707 r
F P
0 g
s
.76845 .67246 m .76707 .68989 L .73571 .68543 L p .707 .577 .707 r
F P
0 g
s
.73571 .68543 m .73709 .66799 L .76845 .67246 L p .707 .577 .707 r
F P
0 g
s
.73709 .66799 m .73571 .68543 L .70411 .68511 L p .707 .577 .707 r
F P
0 g
s
.30197 .52063 m .29652 .57655 L .2897 .58306 L p .707 .577 .707 r
F P
0 g
s
.49202 .63382 m .48613 .67104 L .48268 .66408 L p .707 .577 .707 r
F P
0 g
s
.48268 .66408 m .48857 .62686 L .49202 .63382 L p .707 .577 .707 r
F P
0 g
s
.28442 .63846 m .29031 .60124 L .29674 .59587 L p .707 .577 .707 r
F P
0 g
s
.49511 .54109 m .48966 .59701 L .47691 .58913 L p .707 .577 .707 r
F P
0 g
s
.47691 .58913 m .48236 .53321 L .49511 .54109 L p .707 .577 .707 r
F P
0 g
s
.29674 .59587 m .29084 .6331 L .28442 .63846 L p .707 .577 .707 r
F P
0 g
s
.28019 .68019 m .28335 .66158 L .28918 .65638 L p .707 .577 .707 r
F P
0 g
s
.48484 .69561 m .48169 .71421 L .47765 .70734 L p .707 .577 .707 r
F P
0 g
s
.47765 .70734 m .48081 .68874 L .48484 .69561 L p .707 .577 .707 r
F P
0 g
s
.29652 .57655 m .30197 .52063 L .31806 .51581 L p .707 .577 .707 r
F P
0 g
s
.28918 .65638 m .28602 .67498 L .28019 .68019 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31806 .51581 m .31261 .57173 L .29652 .57655 L p .707 .577 .707 r
F P
0 g
s
.48857 .62686 m .48268 .66408 L .4697 .65621 L p .707 .577 .707 r
F P
0 g
s
.4697 .65621 m .47559 .61899 L .48857 .62686 L p .707 .577 .707 r
F P
0 g
s
.29084 .6331 m .29674 .59587 L .3124 .59263 L p .707 .577 .707 r
F P
0 g
s
.48236 .53321 m .47691 .58913 L .45576 .58172 L p .707 .577 .707 r
F P
0 g
s
.45576 .58172 m .46121 .5258 L .48236 .53321 L p .707 .577 .707 r
F P
0 g
s
.3124 .59263 m .30651 .62985 L .29084 .6331 L p .707 .577 .707 r
F P
0 g
s
.31261 .57173 m .31806 .51581 L .34184 .51316 L p .707 .577 .707 r
F P
0 g
s
.28602 .67498 m .28918 .65638 L .3043 .65335 L p .707 .577 .707 r
F P
0 g
s
.48081 .68874 m .47765 .70734 L .46416 .69948 L p .707 .577 .707 r
F P
0 g
s
.46416 .69948 m .46731 .68088 L .48081 .68874 L p .707 .577 .707 r
F P
0 g
s
.3043 .65335 m .30114 .67195 L .28602 .67498 L p .707 .577 .707 r
F P
0 g
s
.34184 .51316 m .33639 .56908 L .31261 .57173 L p .707 .577 .707 r
F P
0 g
s
.47559 .61899 m .4697 .65621 L .44845 .6482 L p .707 .577 .707 r
F P
0 g
s
.44845 .6482 m .45434 .61097 L .47559 .61899 L p .707 .577 .707 r
F P
0 g
s
.46121 .5258 m .45576 .58172 L .42831 .57548 L p .707 .577 .707 r
F P
0 g
s
.42831 .57548 m .43376 .51957 L .46121 .5258 L p .707 .577 .707 r
F P
0 g
s
.30651 .62985 m .3124 .59263 L .33578 .59182 L p .707 .577 .707 r
F P
0 g
s
.33639 .56908 m .34184 .51316 L .371 .51292 L p .707 .577 .707 r
F P
0 g
s
.33578 .59182 m .32989 .62905 L .30651 .62985 L p .707 .577 .707 r
F P
0 g
s
.30114 .67195 m .3043 .65335 L .32723 .65279 L p .707 .577 .707 r
F P
0 g
s
.46731 .68088 m .46416 .69948 L .44251 .6914 L p .707 .577 .707 r
F P
0 g
s
.44251 .6914 m .44567 .67279 L .46731 .68088 L p .707 .577 .707 r
F P
0 g
s
.43376 .51957 m .42831 .57548 L .39722 .57105 L p .707 .577 .707 r
F P
0 g
s
.39722 .57105 m .40267 .51513 L .43376 .51957 L p .707 .577 .707 r
F P
0 g
s
.36555 .56884 m .371 .51292 L .40267 .51513 L p .707 .577 .707 r
F P
0 g
s
.371 .51292 m .36555 .56884 L .33639 .56908 L p .707 .577 .707 r
F P
0 g
s
.32723 .65279 m .32408 .6714 L .30114 .67195 L p .707 .577 .707 r
F P
0 g
s
.40267 .51513 m .39722 .57105 L .36555 .56884 L p .707 .577 .707 r
F P
0 g
s
.45434 .61097 m .44845 .6482 L .42102 .64082 L p .707 .577 .707 r
F P
0 g
s
.42102 .64082 m .42691 .6036 L .45434 .61097 L p .707 .577 .707 r
F P
0 g
s
.32989 .62905 m .33578 .59182 L .36458 .59353 L p .707 .577 .707 r
F P
0 g
s
.36458 .59353 m .35869 .63075 L .32989 .62905 L p .707 .577 .707 r
F P
0 g
s
.42691 .6036 m .42102 .64082 L .39009 .63481 L p .707 .577 .707 r
F P
0 g
s
.39009 .63481 m .39598 .59759 L .42691 .6036 L p .707 .577 .707 r
F P
0 g
s
.32408 .6714 m .32723 .65279 L .35573 .65476 L p .707 .577 .707 r
F P
0 g
s
.44567 .67279 m .44251 .6914 L .41484 .68388 L p .707 .577 .707 r
F P
0 g
s
.41484 .68388 m .418 .66527 L .44567 .67279 L p .707 .577 .707 r
F P
0 g
s
.35869 .63075 m .36458 .59353 L .39598 .59759 L p .707 .577 .707 r
F P
0 g
s
.35573 .65476 m .35258 .67336 L .32408 .6714 L p .707 .577 .707 r
F P
0 g
s
.39598 .59759 m .39009 .63481 L .35869 .63075 L p .707 .577 .707 r
F P
0 g
s
.35258 .67336 m .35573 .65476 L .38701 .65906 L p .707 .577 .707 r
F P
0 g
s
.418 .66527 m .41484 .68388 L .38385 .67766 L p .707 .577 .707 r
F P
0 g
s
.38385 .67766 m .38701 .65906 L .418 .66527 L p .707 .577 .707 r
F P
0 g
s
.38701 .65906 m .38385 .67766 L .35258 .67336 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
O7oo8@00P7oo001fOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH9001g
Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
079oo`00L7oo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF1000KWoo001]Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH00000K7oo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Moo`80009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8006Moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P00Igoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001VOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005iooa0000EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol005Uoo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`<000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001U
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
3goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP002UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF009JEPH003moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000kOol005=oo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP000Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF1000=goo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
=7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000aOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00DWoo00<005YF0000
0eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYF001JEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF00000UYF1@0000=JEP00FUH0
1UYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0009
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001BOol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH0000^Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0059oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0P000eYF0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00005@000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008000YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF009J
EQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0004FUH00`00FUIJEP02FUH6000;Ool30004Ool60006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
02eoo`00DWoo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@001eYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000moo`D000Uoo`@0009JEP03001JEUYF00=J
EP06001JEUYF001JEP00;Goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH30002FUH0
0`00FUH00003000;Ool5000=Ool30005FUH01P00FUIJEP00FUH002eoo`00DWoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001UYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF001J
EP8000EJEP03001JEUYF00=JEPL000Aoo`D000Uoo`D0009JEP8000=JEP06001JEUYF001JEP00;Goo
0017Ool;00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00H005YF000005YF0005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJ
EP03FUH2000015YF001JEUYF0P00;Woo000oOol80004FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP020002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP03FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH0
0`00FUIJEP04FUH30002FUH2000^Ool003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P00;Woo000bOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20003
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF
00@005YFFUIJEP<002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP<002ioo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF008000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800005
FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01000FUIJEUYF0`00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH60002FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEP0002ioo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF00002@001UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0002ioo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF2P000UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF1P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1P001EYF00<0
05YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00`0000=JEP00FUH00UYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF0P0015YF00<005YF00000`001eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP00
00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP04001JEUYFFUH90002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004FUH20002FUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000
FUIJEUYF0P00;Woo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF000005YF00<000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF009JEPH000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00IJEP03001J
EUYF00AJEP04001JEUYFFUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH000020006FUH00`00FUIJEP03FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF1@0000=oo`0000000eYF00H005YFFUH005YF000^Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP03FUHJ0008Ool200001eYF001JEUYF001JEP0002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4`000eYF00@005YFFUIJEPL000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP06001JEUYFFUH005YF
0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF
1`000eYF00<005YFFUH01UYF00<005YFFUH0100047oo0P000UYF00<005YF0000;Woo000]Ool00`00
FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH015YF00<005YF00001`0000=JEP00FUH015YF
2@0015YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF0`0000EJEP00001JEP00
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@000ioo`05001JEP00FUH0000^Ool002eoo`03001J
EP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH60006FUH00`00FUIJEP06FUH00`00FUH000030002FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH01000FUH00000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002goo0`00;goo
000]Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF0P00
15YF00<005YF00000`001UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30006Ool200000eYF0000000_Ool002eoo`06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0`0015YF00@005YFFUIJ
EP8000AJEP03001JEUYF00T000IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP8000EJEP03001JEUYF009JEQ0000IJEP03
001JEUYF00EJEP<0009oo`8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEP0000@000=JEP80
00AJEP03001JEUYF00H000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP001EYF1@00
00=JEP0000000`002Woo10000UYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF0P00
;goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH200000eYF001JEP05FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP060007FUH40004FUH00`00
FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
0eYF00@005YFFUIJEP<000MJEP03001JEUYF00@000Yoo`@000EJEP03001JEUYF00=JEP8000=JEP80
02moo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF009JEP<00003FUH0
05YF00UJEP@00003FUH005YF00=JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP04001JEP000002FUH00`00FUIJEP05FUH00`00FUIJEP04FUHB0000
0eYF001JEP05FUH20002FUH2000_Ool002moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ800003FUH005YF00MJEP03001JEUYF00AJEPL0009JEP03001JEUYF00QJEP04001JEUYF
FUH20003FUH01@00FUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`001EYF00@005YF001JEP8002moo`00<Goo10000eYF00<005YFFUH015YF200015YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF0080031oo`00=Goo2P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00@0
05YFFUIJEQ00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH200000eYF001JEP02FUH00`00Oomoo`0^Ool0039oo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0P000eYF00<007ooOol0;Woo000_Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001o
ogoo02ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH02@001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP000000;goo000]Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000P001eYF1@000UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000goo0`00;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH015YF4`001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000P001eYF00<005YFFUH00UYF1@001UYF1P000eYF00<005YFFUH01EYF
00<005YF00000`001Woo0P00;goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH01@000UYF1P000eYF00<005YFFUH00UYF1@002Woo0P00;goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
00IJEP03001JEUYF009JEP03001JEUYF008000=ooa0000moo`8002moo`00;Goo00@005YFFUH000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP04001J
EP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
009JEP05001JEUYFFUH0000POol4000_Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEPl00003FUH005YF00MJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP80009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEP007Woo0P000UYF0P00
;goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF00001EYF0`001EYF00@005YFFUH001eoo`04001JEUYFFUH2000`Ool002ioo`03
001JEP0000=JEP04001JEUYFFUH60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020006
FUH00`00FUH00003000015YF001JEUYF0P006Woo0`000eYF0P00<7oo000^Ool00`00FUH00002FUH5
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH9000<FUH<0006FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH6000HOol20002FUH01@00
FUIJEUYF0000<Goo000^Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF200015YF00<005YFFUH01EYF00<005YFFUH01P00
25YF00<005YFFUH02UYF00<005YFFUH02EYF2@001eYF00<005YFFUH015YF00D005YFFUH007oo0080
00=JEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP04001JEUYF000bOol002ioo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Ioo`8000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPD0009JEP03001JEUYF00AJEP04001JEUYF0003Ool200000eYF001J
EP07FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH3000cOol002moo`80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ4000Eoo`8000AJEP03001JEUYF
00@000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00@000EJEP04001JEUYF0005Ool30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000eOol0035oob0000AJEP03001JEUYF00EJEP03001JEUYF00L000AJ
EP@000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP8000=JEP04001JEUYF0006Ool60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00=goo0010Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH000000eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<00004FUH005YFFUH70006FUH5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000>Goo000hOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH00000FUH00P0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P000UYF0P000eYF1`0000=JEP00FUH00UYF1@000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1@00>goo000cOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH010000UYF0P000Woo4000@7oo000`Ool3
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000MJ
EP03001JEUYF00=JEPD0059oo`00;Woo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF7`0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000MJ
EP03001JEUYF009JEP03001JEUYF0080059oo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF20001goo2@000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
001BOol002ioo`03001JEP0000=JEP04001JEUYFFUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`000eYF00<0
05YFFUH00P00DGoo000^Ool00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH00`00Oomoo`1?
Ool002ioo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH50002Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo0P0000=JEP00Ool0D7oo000^Ool30003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008Ool00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030008FUH01000FUH0000027oo0P00DGoo000^Ool0
0`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
000@Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH3000:Ool3001@Ool002moob40
01]oo`800003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000aoo`800003FUH007oo04moo`00
KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH00UYF0P001eYF00<005YF00000P0037oo0P0000AJEP00FUH0051oo`00L7oo0`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`0015YF
1P003Woo00@005YFFUIJEP80055oo`00Lgoo100000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF3`004goo00<005YFFUH00UYF0P00DGoo001gOol70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUHF000EOol30004FUH00`00Oomoo`1@Ool007iooaX0015oo`D001=oo`80
009JEP05001JEUYFFUH0001COol0099oo`03001JEP0001Eoo`<0015oo`<000EJEP03001JEP0005Ao
o`00TWoo00<005YF00009Goo100000=JEP00FUH01EYF0P00EGoo002COol2000POol50005FUH00`00
FUIJEP04FUH00`00Oomoo`1DOol009=oo`04001JEP00000JOol40002FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00Egoo002COol20002FUH3000@Ool70006FUH00`00FUIJEP06FUH01000FUH00000FGoo
002COol20002FUH00`00FUIJEP0@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001KOol009Ao
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH2001NOol009Eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00002001POol009Ioo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPH006=oo`00V7oo0`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@00JGoo002KOol@001b
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60684 .75534 m .59803 .70156 L .56714 .70382 L p .707 .577 .707 r
F P
0 g
s
.59803 .70156 m .60684 .75534 L .63826 .74968 L p .707 .577 .707 r
F P
0 g
s
.63826 .74968 m .62945 .69589 L .59803 .70156 L p .707 .577 .707 r
F P
0 g
s
.62945 .69589 m .63826 .74968 L .66715 .74118 L p .707 .577 .707 r
F P
0 g
s
.66715 .74118 m .65835 .68739 L .62945 .69589 L p .707 .577 .707 r
F P
0 g
s
.57595 .75761 m .56714 .70382 L .53982 .70248 L p .707 .577 .707 r
F P
0 g
s
.56714 .70382 m .57595 .75761 L .60684 .75534 L p .707 .577 .707 r
F P
0 g
s
.65835 .68739 m .66715 .74118 L .69068 .73067 L p .707 .577 .707 r
F P
0 g
s
.69068 .73067 m .68188 .67688 L .65835 .68739 L p .707 .577 .707 r
F P
0 g
s
.54863 .75626 m .53982 .70248 L .51874 .69764 L p .707 .577 .707 r
F P
0 g
s
.53982 .70248 m .54863 .75626 L .57595 .75761 L p .707 .577 .707 r
F P
0 g
s
.61829 .81867 m .6088 .7841 L .5784 .78897 L p .707 .577 .707 r
F P
0 g
s
.6088 .7841 m .61829 .81867 L .64905 .80998 L p .707 .577 .707 r
F P
0 g
s
.64905 .80998 m .63955 .77541 L .6088 .7841 L p .707 .577 .707 r
F P
0 g
s
.63955 .77541 m .64905 .80998 L .67716 .79831 L p .707 .577 .707 r
F P
0 g
s
.67716 .79831 m .66766 .76374 L .63955 .77541 L p .707 .577 .707 r
F P
0 g
s
.68188 .67688 m .69068 .73067 L .70655 .71917 L p .707 .577 .707 r
F P
0 g
s
.70655 .71917 m .69774 .66539 L .68188 .67688 L p .707 .577 .707 r
F P
0 g
s
.5879 .82354 m .5784 .78897 L .55135 .78954 L p .707 .577 .707 r
F P
0 g
s
.5784 .78897 m .5879 .82354 L .61829 .81867 L p .707 .577 .707 r
F P
0 g
s
.66766 .76374 m .67716 .79831 L .69987 .78482 L p .707 .577 .707 r
F P
0 g
s
.69987 .78482 m .69037 .75025 L .66766 .76374 L p .707 .577 .707 r
F P
0 g
s
.51874 .69764 m .52755 .75143 L .54863 .75626 L p .707 .577 .707 r
F P
0 g
s
.52755 .75143 m .51874 .69764 L .50596 .6898 L p .707 .577 .707 r
F P
0 g
s
.62837 .86056 m .62327 .84346 L .59286 .84915 L p .707 .577 .707 r
F P
0 g
s
.62327 .84346 m .62837 .86056 L .65885 .85099 L p .707 .577 .707 r
F P
0 g
s
.65885 .85099 m .65375 .83388 L .62327 .84346 L p .707 .577 .707 r
F P
0 g
s
.55135 .78954 m .56084 .82411 L .5879 .82354 L p .707 .577 .707 r
F P
0 g
s
.65375 .83388 m .65885 .85099 L .68641 .83847 L p .707 .577 .707 r
F P
0 g
s
.68641 .83847 m .68131 .82137 L .65375 .83388 L p .707 .577 .707 r
F P
0 g
s
.56084 .82411 m .55135 .78954 L .53028 .78575 L p .707 .577 .707 r
F P
0 g
s
.69037 .75025 m .69987 .78482 L .71496 .77081 L p .707 .577 .707 r
F P
0 g
s
.71496 .77081 m .70546 .73624 L .69037 .75025 L p .707 .577 .707 r
F P
0 g
s
.59286 .84915 m .59796 .86625 L .62837 .86056 L p .707 .577 .707 r
F P
0 g
s
.69774 .66539 m .70655 .71917 L .71319 .70783 L p .707 .577 .707 r
F P
0 g
s
.71319 .70783 m .70438 .65404 L .69774 .66539 L p .707 .577 .707 r
F P
0 g
s
.59796 .86625 m .59286 .84915 L .56549 .8504 L p .707 .577 .707 r
F P
0 g
s
.68131 .82137 m .68641 .83847 L .70835 .82424 L p .707 .577 .707 r
F P
0 g
s
.70835 .82424 m .70325 .80713 L .68131 .82137 L p .707 .577 .707 r
F P
0 g
s
.56549 .8504 m .57059 .86751 L .59796 .86625 L p .707 .577 .707 r
F P
0 g
s
.53028 .78575 m .53978 .82032 L .56084 .82411 L p .707 .577 .707 r
F P
0 g
s
.50596 .6898 m .51477 .74358 L .52755 .75143 L p .707 .577 .707 r
F P
0 g
s
.57059 .86751 m .56549 .8504 L .54385 .8471 L p .707 .577 .707 r
F P
0 g
s
.51477 .74358 m .50596 .6898 L .50273 .67971 L p .707 .577 .707 r
F P
0 g
s
.53978 .82032 m .53028 .78575 L .51726 .77798 L p .707 .577 .707 r
F P
0 g
s
.70325 .80713 m .70835 .82424 L .72253 .80968 L p .707 .577 .707 r
F P
0 g
s
.72253 .80968 m .71744 .79257 L .70325 .80713 L p .707 .577 .707 r
F P
0 g
s
.70546 .73624 m .71496 .77081 L .72095 .75767 L p .707 .577 .707 r
F P
0 g
s
.72095 .75767 m .71145 .7231 L .70546 .73624 L p .707 .577 .707 r
F P
0 g
s
.54385 .8471 m .54894 .8642 L .57059 .86751 L p .707 .577 .707 r
F P
0 g
s
.70438 .65404 m .71319 .70783 L .70996 .69774 L p .707 .577 .707 r
F P
0 g
s
.70996 .69774 m .70116 .64395 L .70438 .65404 L p .707 .577 .707 r
F P
0 g
s
.51726 .77798 m .52676 .81255 L .53978 .82032 L p .707 .577 .707 r
F P
0 g
s
.50273 .67971 m .51154 .73349 L .51477 .74358 L p .707 .577 .707 r
F P
0 g
s
.54894 .8642 m .54385 .8471 L .53004 .83955 L p .707 .577 .707 r
F P
0 g
s
.47812 .82147 m .47812 .31959 L .43513 .3159 L p .707 .577 .707 r
F P
0 g
s
.52676 .81255 m .51726 .77798 L .51357 .76698 L p .707 .578 .707 r
F P
0 g
s
.51154 .73349 m .50273 .67971 L .50938 .66836 L p .707 .577 .707 r
F P
0 g
s
.51357 .76698 m .52307 .80155 L .52676 .81255 L p .707 .578 .707 r
F P
0 g
s
.50938 .66836 m .51819 .72215 L .51154 .73349 L p .707 .577 .707 r
F P
0 g
s
.52307 .80155 m .51357 .76698 L .51956 .75384 L p .707 .577 .707 r
F P
0 g
s
.51819 .72215 m .50938 .66836 L .52524 .65687 L p .707 .577 .707 r
F P
0 g
s
.47812 .31959 m .47812 .82147 L .52324 .82142 L p .707 .577 .707 r
F P
0 g
s
.51956 .75384 m .52906 .78841 L .52307 .80155 L p .707 .577 .707 r
F P
0 g
s
.52524 .65687 m .53405 .71066 L .51819 .72215 L p .707 .577 .707 r
F P
0 g
s
.52906 .78841 m .51956 .75384 L .53465 .73983 L p .707 .577 .707 r
F P
0 g
s
.52324 .82142 m .52324 .31953 L .47812 .31959 L p .707 .577 .707 r
F P
0 g
s
.53004 .83955 m .53513 .85666 L .54894 .8642 L p .707 .577 .707 r
F P
0 g
s
.53513 .85666 m .53004 .83955 L .52542 .82851 L p .707 .577 .707 r
F P
0 g
s
.52542 .82851 m .53052 .84561 L .53513 .85666 L p .707 .577 .707 r
F P
0 g
s
.53052 .84561 m .52542 .82851 L .53045 .81505 L p .707 .577 .707 r
F P
0 g
s
.53405 .71066 m .52524 .65687 L .54877 .64636 L p .707 .577 .707 r
F P
0 g
s
.53045 .81505 m .53555 .83215 L .53052 .84561 L p .707 .577 .707 r
F P
0 g
s
.53465 .73983 m .54415 .7744 L .52906 .78841 L p .707 .577 .707 r
F P
0 g
s
.55758 .70014 m .54877 .64636 L .57766 .63785 L p .707 .577 .707 r
F P
0 g
s
.54877 .64636 m .55758 .70014 L .53405 .71066 L p .707 .577 .707 r
F P
0 g
s
.53555 .83215 m .53045 .81505 L .54463 .80048 L p .707 .577 .707 r
F P
0 g
s
.54415 .7744 m .53465 .73983 L .55736 .72633 L p .707 .577 .707 r
F P
0 g
s
.54463 .80048 m .54973 .81759 L .53555 .83215 L p .707 .577 .707 r
F P
0 g
s
.55736 .72633 m .56686 .7609 L .54415 .7744 L p .707 .577 .707 r
F P
0 g
s
.56686 .7609 m .55736 .72633 L .58547 .71467 L p .707 .577 .707 r
F P
0 g
s
.54973 .81759 m .54463 .80048 L .56658 .78625 L p .707 .577 .707 r
F P
0 g
s
.56658 .78625 m .57167 .80335 L .54973 .81759 L p .707 .577 .707 r
F P
0 g
s
.52324 .31953 m .52324 .82142 L .5661 .81762 L p .707 .577 .707 r
F P
0 g
s
.57766 .63785 m .58647 .69164 L .55758 .70014 L p .707 .577 .707 r
F P
0 g
s
.5661 .81762 m .5661 .31573 L .52324 .31953 L p .707 .577 .707 r
F P
0 g
s
.71744 .79257 m .72253 .80968 L .72756 .79621 L p .707 .577 .707 r
F P
0 g
s
.72756 .79621 m .72246 .77911 L .71744 .79257 L p .707 .577 .707 r
F P
0 g
s
.71145 .7231 m .72095 .75767 L .71725 .74667 L p .707 .578 .707 r
F P
0 g
s
.71725 .74667 m .70776 .7121 L .71145 .7231 L p .707 .578 .707 r
F P
0 g
s
.43513 .81779 m .43513 .3159 L .39849 .30883 L p .707 .577 .707 r
F P
0 g
s
.43513 .3159 m .43513 .81779 L .47812 .82147 L p .707 .577 .707 r
F P
0 g
s
.58647 .69164 m .57766 .63785 L .60909 .63219 L p .707 .577 .707 r
F P
0 g
s
.60909 .63219 m .6179 .68598 L .58647 .69164 L p .707 .577 .707 r
F P
0 g
s
.59497 .74924 m .58547 .71467 L .61623 .70598 L p .707 .577 .707 r
F P
0 g
s
.58547 .71467 m .59497 .74924 L .56686 .7609 L p .707 .577 .707 r
F P
0 g
s
.61623 .70598 m .62572 .74055 L .59497 .74924 L p .707 .577 .707 r
F P
0 g
s
.57167 .80335 m .56658 .78625 L .59414 .77373 L p .707 .577 .707 r
F P
0 g
s
.59414 .77373 m .59923 .79084 L .57167 .80335 L p .707 .577 .707 r
F P
0 g
s
.59923 .79084 m .59414 .77373 L .62461 .76416 L p .707 .577 .707 r
F P
0 g
s
.62461 .76416 m .62971 .78126 L .59923 .79084 L p .707 .577 .707 r
F P
0 g
s
.5661 .31573 m .5661 .81762 L .60248 .81046 L p .707 .577 .707 r
F P
0 g
s
.60248 .81046 m .60248 .30857 L .5661 .31573 L p .707 .577 .707 r
F P
0 g
s
.70116 .64395 m .70996 .69774 L .69719 .68989 L p .707 .577 .707 r
F P
0 g
s
.69719 .68989 m .68838 .63611 L .70116 .64395 L p .707 .577 .707 r
F P
0 g
s
.25876 .70008 m .25494 .64293 L .22374 .64419 L p .707 .577 .707 r
F P
0 g
s
.25494 .64293 m .25876 .70008 L .29048 .69759 L p .707 .577 .707 r
F P
0 g
s
.29048 .69759 m .28666 .64044 L .25494 .64293 L p .707 .577 .707 r
F P
0 g
s
.28666 .64044 m .29048 .69759 L .3196 .6941 L p .707 .577 .707 r
F P
0 g
s
.3196 .6941 m .31578 .63695 L .28666 .64044 L p .707 .577 .707 r
F P
0 g
s
.72246 .77911 m .72756 .79621 L .72294 .78517 L p .707 .577 .707 r
F P
0 g
s
.72294 .78517 m .71785 .76807 L .72246 .77911 L p .707 .577 .707 r
F P
0 g
s
.22755 .70134 m .22374 .64419 L .19609 .64409 L p .707 .577 .707 r
F P
0 g
s
.22374 .64419 m .22755 .70134 L .25876 .70008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26526 .75359 m .26108 .71537 L .22984 .71861 L p .707 .577 .707 r
F P
0 g
s
.26108 .71537 m .26526 .75359 L .29678 .75001 L p .707 .577 .707 r
F P
0 g
s
.29678 .75001 m .29259 .71179 L .26108 .71537 L p .707 .577 .707 r
F P
0 g
s
.70776 .7121 m .71725 .74667 L .70424 .7389 L p .707 .577 .707 r
F P
0 g
s
.70424 .7389 m .69474 .70433 L .70776 .7121 L p .707 .577 .707 r
F P
0 g
s
.39849 .81072 m .39849 .30883 L .37179 .29907 L p .707 .577 .707 r
F P
0 g
s
.39849 .30883 m .39849 .81072 L .43513 .81779 L p .707 .577 .707 r
F P
0 g
s
.22984 .71861 m .23403 .75683 L .26526 .75359 L p .707 .577 .707 r
F P
0 g
s
.19609 .64409 m .19991 .70125 L .22755 .70134 L p .707 .577 .707 r
F P
0 g
s
.63998 .62992 m .64878 .68371 L .6179 .68598 L p .707 .577 .707 r
F P
0 g
s
.6179 .68598 m .60909 .63219 L .63998 .62992 L p .707 .577 .707 r
F P
0 g
s
.62572 .74055 m .61623 .70598 L .64662 .70111 L p .707 .577 .707 r
F P
0 g
s
.62971 .78126 m .62461 .76416 L .65502 .75847 L p .707 .577 .707 r
F P
0 g
s
.60248 .30857 m .60248 .81046 L .62883 .80062 L p .707 .577 .707 r
F P
0 g
s
.64662 .70111 m .65612 .73568 L .62572 .74055 L p .707 .577 .707 r
F P
0 g
s
.62883 .80062 m .62883 .29874 L .60248 .30857 L p .707 .577 .707 r
F P
0 g
s
.31578 .63695 m .3196 .6941 L .34328 .68997 L p .707 .577 .707 r
F P
0 g
s
.34328 .68997 m .33946 .63281 L .31578 .63695 L p .707 .577 .707 r
F P
0 g
s
.29259 .71179 m .29678 .75001 L .32549 .74645 L p .707 .577 .707 r
F P
0 g
s
.32549 .74645 m .3213 .70823 L .29259 .71179 L p .707 .577 .707 r
F P
0 g
s
.68838 .63611 m .69719 .68989 L .6761 .68506 L p .707 .577 .707 r
F P
0 g
s
.6761 .68506 m .6673 .63127 L .68838 .63611 L p .707 .577 .707 r
F P
0 g
s
.27142 .79622 m .26915 .77712 L .23779 .78075 L p .707 .577 .707 r
F P
0 g
s
.26915 .77712 m .27142 .79622 L .30276 .79238 L p .707 .577 .707 r
F P
0 g
s
.30276 .79238 m .30049 .77329 L .26915 .77712 L p .707 .577 .707 r
F P
0 g
s
.23403 .75683 m .22984 .71861 L .20195 .72119 L p .707 .577 .707 r
F P
0 g
s
.23779 .78075 m .24006 .79985 L .27142 .79622 L p .707 .577 .707 r
F P
0 g
s
.20195 .72119 m .20614 .75941 L .23403 .75683 L p .707 .577 .707 r
F P
0 g
s
.19991 .70125 m .19609 .64409 L .17472 .64265 L p .707 .577 .707 r
F P
0 g
s
.24006 .79985 m .23779 .78075 L .20946 .78383 L p .707 .577 .707 r
F P
0 g
s
.30049 .77329 m .30276 .79238 L .331 .78872 L p .707 .577 .707 r
F P
0 g
s
.331 .78872 m .32873 .76963 L .30049 .77329 L p .707 .577 .707 r
F P
0 g
s
.20946 .78383 m .21173 .80292 L .24006 .79985 L p .707 .577 .707 r
F P
0 g
s
.17472 .64265 m .17854 .6998 L .19991 .70125 L p .707 .577 .707 r
F P
0 g
s
.3213 .70823 m .32549 .74645 L .34859 .74324 L p .707 .577 .707 r
F P
0 g
s
.34859 .74324 m .3444 .70502 L .3213 .70823 L p .707 .577 .707 r
F P
0 g
s
.20614 .75941 m .20195 .72119 L .18013 .72286 L p .707 .577 .707 r
F P
0 g
s
.18013 .72286 m .18431 .76108 L .20614 .75941 L p .707 .577 .707 r
F P
0 g
s
.71785 .76807 m .72294 .78517 L .70914 .77763 L p .707 .577 .707 r
F P
0 g
s
.70914 .77763 m .70404 .76052 L .71785 .76807 L p .707 .577 .707 r
F P
0 g
s
.33946 .63281 m .34328 .68997 L .35919 .68559 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .35538 .62843 L .33946 .63281 L p .707 .577 .707 r
F P
0 g
s
.21173 .80292 m .20946 .78383 L .18695 .78604 L p .707 .577 .707 r
F P
0 g
s
.32873 .76963 m .331 .78872 L .35339 .78559 L p .707 .577 .707 r
F P
0 g
s
.35339 .78559 m .35111 .76649 L .32873 .76963 L p .707 .577 .707 r
F P
0 g
s
.18695 .78604 m .18923 .80513 L .21173 .80292 L p .707 .577 .707 r
F P
0 g
s
.69474 .70433 m .70424 .7389 L .68317 .73511 L p .707 .577 .707 r
F P
0 g
s
.68317 .73511 m .67367 .70054 L .69474 .70433 L p .707 .577 .707 r
F P
0 g
s
.6673 .63127 m .6761 .68506 L .64878 .68371 L p .707 .577 .707 r
F P
0 g
s
.64878 .68371 m .63998 .62992 L .6673 .63127 L p .707 .577 .707 r
F P
0 g
s
.17854 .6998 m .17472 .64265 L .16171 .63999 L p .707 .577 .707 r
F P
0 g
s
.36545 .7642 m .36772 .78329 L .3726 .78206 L p .707 .577 .707 r
F P
0 g
s
.3726 .78206 m .37032 .76296 L .36545 .7642 L p .707 .577 .707 r
F P
0 g
s
.36772 .78329 m .36545 .7642 L .35111 .76649 L p .707 .577 .707 r
F P
0 g
s
.37032 .76296 m .3726 .78206 L .36754 .782 L p .707 .577 .707 r
F P
0 g
s
.37179 .80095 m .37179 .29907 L .35764 .28757 L p .707 .577 .707 r
F P
0 g
s
.37179 .29907 m .37179 .80095 L .39849 .81072 L p .707 .577 .707 r
F P
0 g
s
.65502 .75847 m .66012 .77557 L .62971 .78126 L p .707 .577 .707 r
F P
0 g
s
.62883 .29874 m .62883 .80062 L .64257 .78909 L p .707 .577 .707 r
F P
0 g
s
.64257 .78909 m .64257 .2872 L .62883 .29874 L p .707 .577 .707 r
F P
0 g
s
.3444 .70502 m .34859 .74324 L .36381 .74071 L p .707 .577 .707 r
F P
0 g
s
.36381 .74071 m .35962 .70249 L .3444 .70502 L p .707 .577 .707 r
F P
0 g
s
.16171 .63999 m .16553 .69715 L .17854 .6998 L p .707 .577 .707 r
F P
0 g
s
.18431 .76108 m .18013 .72286 L .16651 .72346 L p .707 .577 .707 r
F P
0 g
s
.16651 .72346 m .17069 .76168 L .18431 .76108 L p .707 .577 .707 r
F P
0 g
s
.18923 .80513 m .18695 .78604 L .17246 .78717 L p .707 .577 .707 r
F P
0 g
s
.35111 .76649 m .35339 .78559 L .36772 .78329 L p .707 .577 .707 r
F P
0 g
s
.17246 .78717 m .17474 .80627 L .18923 .80513 L p .707 .577 .707 r
F P
0 g
s
.70404 .76052 m .70914 .77763 L .68749 .77432 L p .707 .577 .707 r
F P
0 g
s
.68749 .77432 m .68239 .75721 L .70404 .76052 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35742 .27546 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35538 .62843 m .35822 .67104 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.36579 .68139 m .36197 .62424 L .35538 .62843 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .36579 .68139 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35822 .67104 m .35919 .68559 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35859 .62064 m .36241 .67779 L .3494 .67514 L p .707 .577 .707 r
F P
0 g
s
.3494 .67514 m .34558 .61798 L .35859 .62064 L p .707 .577 .707 r
F P
0 g
s
.35962 .70249 m .36381 .74071 L .36967 .7391 L p .707 .577 .707 r
F P
0 g
s
.36967 .7391 m .36548 .70088 L .35962 .70249 L p .707 .577 .707 r
F P
0 g
s
.3614 .70035 m .36559 .73857 L .35197 .73917 L p .707 .577 .707 r
F P
0 g
s
.35197 .73917 m .34778 .70095 L .3614 .70035 L p .707 .577 .707 r
F P
0 g
s
.36527 .76291 m .36754 .782 L .35305 .78314 L p .707 .577 .707 r
F P
0 g
s
.35305 .78314 m .35078 .76405 L .36527 .76291 L p .707 .577 .707 r
F P
0 g
s
.35764 .78946 m .35764 .39217 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35764 .39217 m .35764 .28757 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.67367 .70054 m .68317 .73511 L .65612 .73568 L p .707 .577 .707 r
F P
0 g
s
.65612 .73568 m .64662 .70111 L .67367 .70054 L p .707 .577 .707 r
F P
0 g
s
.16553 .69715 m .16171 .63999 L .15834 .63639 L p .707 .577 .707 r
F P
0 g
s
.15834 .63639 m .16215 .69354 L .16553 .69715 L p .707 .577 .707 r
F P
0 g
s
.17069 .76168 m .16651 .72346 L .16243 .72293 L p .707 .577 .707 r
F P
0 g
s
.68239 .75721 m .68749 .77432 L .66012 .77557 L p .707 .577 .707 r
F P
0 g
s
.66012 .77557 m .65502 .75847 L .68239 .75721 L p .707 .577 .707 r
F P
0 g
s
.16243 .72293 m .16661 .76115 L .17069 .76168 L p .707 .577 .707 r
F P
0 g
s
.17474 .80627 m .17246 .78717 L .16741 .78712 L p .707 .577 .707 r
F P
0 g
s
.16741 .78712 m .16968 .80621 L .17474 .80627 L p .707 .577 .707 r
F P
0 g
s
.36197 .62424 m .36579 .68139 L .36241 .67779 L p .707 .577 .707 r
F P
0 g
s
.36241 .67779 m .35859 .62064 L .36197 .62424 L p .707 .577 .707 r
F P
0 g
s
.36548 .70088 m .36967 .7391 L .36559 .73857 L p .707 .577 .707 r
F P
0 g
s
.36559 .73857 m .3614 .70035 L .36548 .70088 L p .707 .577 .707 r
F P
0 g
s
.36754 .782 m .36527 .76291 L .37032 .76296 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35764 .78946 L .37179 .80095 L p .707 .577 .707 r
F P
0 g
s
.64257 .2872 m .64257 .78909 L .64236 .77698 L p .708 .578 .707 r
F P
0 g
s
.64236 .77698 m .64236 .27509 L .64257 .2872 L p .708 .578 .707 r
F P
0 g
s
.16215 .69354 m .15834 .63639 L .16493 .6322 L p .707 .577 .707 r
F P
0 g
s
.16493 .6322 m .16875 .68935 L .16215 .69354 L p .707 .577 .707 r
F P
0 g
s
.16661 .76115 m .16243 .72293 L .16828 .72132 L p .707 .577 .707 r
F P
0 g
s
.16828 .72132 m .17247 .75953 L .16661 .76115 L p .707 .577 .707 r
F P
0 g
s
.16968 .80621 m .16741 .78712 L .17229 .78589 L p .707 .577 .707 r
F P
0 g
s
.17229 .78589 m .17456 .80498 L .16968 .80621 L p .707 .577 .707 r
F P
0 g
s
.35742 .27546 m .35742 .77735 L .35764 .78946 L p .708 .578 .707 r
F P
0 g
s
.35742 .77735 m .35742 .27546 L .37116 .26392 L p .707 .577 .707 r
F P
0 g
s
.64236 .27509 m .64236 .77698 L .62821 .76548 L p .707 .577 .707 r
F P
0 g
s
.62821 .76548 m .62821 .26359 L .64236 .27509 L p .707 .577 .707 r
F P
0 g
s
.16875 .68935 m .16493 .6322 L .18084 .62782 L p .707 .577 .707 r
F P
0 g
s
.18084 .62782 m .18466 .68497 L .16875 .68935 L p .707 .577 .707 r
F P
0 g
s
.17247 .75953 m .16828 .72132 L .18351 .71878 L p .707 .577 .707 r
F P
0 g
s
.18351 .71878 m .18769 .757 L .17247 .75953 L p .707 .577 .707 r
F P
0 g
s
.17456 .80498 m .17229 .78589 L .18662 .78359 L p .707 .577 .707 r
F P
0 g
s
.18662 .78359 m .18889 .80268 L .17456 .80498 L p .707 .577 .707 r
F P
0 g
s
.34558 .61798 m .3494 .67514 L .32803 .67369 L p .707 .577 .707 r
F P
0 g
s
.32803 .67369 m .32421 .61654 L .34558 .61798 L p .707 .577 .707 r
F P
0 g
s
.18466 .68497 m .18084 .62782 L .20452 .62368 L p .707 .577 .707 r
F P
0 g
s
.34778 .70095 m .35197 .73917 L .33014 .74084 L p .707 .577 .707 r
F P
0 g
s
.33014 .74084 m .32595 .70262 L .34778 .70095 L p .707 .577 .707 r
F P
0 g
s
.20452 .62368 m .20834 .68083 L .18466 .68497 L p .707 .577 .707 r
F P
0 g
s
.37116 .26392 m .37116 .76581 L .35742 .77735 L p .707 .577 .707 r
F P
0 g
s
.37116 .76581 m .37116 .26392 L .39752 .25409 L p .707 .577 .707 r
F P
0 g
s
.62821 .26359 m .62821 .76548 L .60151 .75572 L p .707 .577 .707 r
F P
0 g
s
.60151 .75572 m .60151 .25383 L .62821 .26359 L p .707 .577 .707 r
F P
0 g
s
.18769 .757 m .18351 .71878 L .2066 .71558 L p .707 .577 .707 r
F P
0 g
s
.2066 .71558 m .21079 .7538 L .18769 .757 L p .707 .577 .707 r
F P
0 g
s
.32421 .61654 m .32803 .67369 L .30039 .67359 L p .707 .577 .707 r
F P
0 g
s
.30039 .67359 m .29657 .61644 L .32421 .61654 L p .707 .577 .707 r
F P
0 g
s
.18889 .80268 m .18662 .78359 L .209 .78046 L p .707 .577 .707 r
F P
0 g
s
.35078 .76405 m .35305 .78314 L .33054 .78535 L p .707 .577 .707 r
F P
0 g
s
.33054 .78535 m .32827 .76626 L .35078 .76405 L p .707 .577 .707 r
F P
0 g
s
.209 .78046 m .21127 .79955 L .18889 .80268 L p .707 .577 .707 r
F P
0 g
s
.20834 .68083 m .20452 .62368 L .23364 .62019 L p .707 .577 .707 r
F P
0 g
s
.23364 .62019 m .23746 .67735 L .20834 .68083 L p .707 .577 .707 r
F P
0 g
s
.32595 .70262 m .33014 .74084 L .30225 .74342 L p .707 .577 .707 r
F P
0 g
s
.30225 .74342 m .29806 .7052 L .32595 .70262 L p .707 .577 .707 r
F P
0 g
s
.29657 .61644 m .30039 .67359 L .26918 .67485 L p .707 .577 .707 r
F P
0 g
s
.26918 .67485 m .26536 .6177 L .29657 .61644 L p .707 .577 .707 r
F P
0 g
s
.21079 .7538 m .2066 .71558 L .23531 .71201 L p .707 .577 .707 r
F P
0 g
s
.23746 .67735 m .23364 .62019 L .26536 .6177 L p .707 .577 .707 r
F P
0 g
s
.23531 .71201 m .2395 .75023 L .21079 .7538 L p .707 .577 .707 r
F P
0 g
s
.26536 .6177 m .26918 .67485 L .23746 .67735 L p .707 .577 .707 r
F P
0 g
s
.21127 .79955 m .209 .78046 L .23724 .77679 L p .707 .577 .707 r
F P
0 g
s
.32827 .76626 m .33054 .78535 L .30222 .78842 L p .707 .577 .707 r
F P
0 g
s
.30222 .78842 m .29995 .76933 L .32827 .76626 L p .707 .577 .707 r
F P
0 g
s
.23724 .77679 m .23952 .79589 L .21127 .79955 L p .707 .577 .707 r
F P
0 g
s
.73082 .66875 m .73464 .61625 L .70343 .61165 L p .707 .577 .707 r
F P
0 g
s
.73464 .61625 m .73082 .66875 L .76254 .66928 L p .707 .577 .707 r
F P
0 g
s
.76254 .66928 m .76636 .61678 L .73464 .61625 L p .707 .577 .707 r
F P
0 g
s
.39752 .75598 m .39752 .25409 L .4339 .24693 L p .707 .577 .707 r
F P
0 g
s
.39752 .25409 m .39752 .75598 L .37116 .76581 L p .707 .577 .707 r
F P
0 g
s
.60151 .25383 m .60151 .75572 L .56487 .74865 L p .707 .577 .707 r
F P
0 g
s
.56487 .74865 m .56487 .24676 L .60151 .25383 L p .707 .577 .707 r
F P
0 g
s
.29806 .7052 m .30225 .74342 L .27102 .74665 L p .707 .577 .707 r
F P
0 g
s
.27102 .74665 m .26683 .70844 L .29806 .7052 L p .707 .577 .707 r
F P
0 g
s
.76636 .61678 m .76254 .66928 L .79166 .6657 L p .707 .577 .707 r
F P
0 g
s
.79166 .6657 m .79548 .61319 L .76636 .61678 L p .707 .577 .707 r
F P
0 g
s
.2395 .75023 m .23531 .71201 L .26683 .70844 L p .707 .577 .707 r
F P
0 g
s
.69961 .66416 m .70343 .61165 L .67579 .60344 L p .707 .577 .707 r
F P
0 g
s
.70343 .61165 m .69961 .66416 L .73082 .66875 L p .707 .577 .707 r
F P
0 g
s
.26683 .70844 m .27102 .74665 L .2395 .75023 L p .707 .577 .707 r
F P
0 g
s
.23952 .79589 m .23724 .77679 L .26858 .77296 L p .707 .577 .707 r
F P
0 g
s
.29995 .76933 m .30222 .78842 L .27085 .79205 L p .707 .577 .707 r
F P
0 g
s
.27085 .79205 m .26858 .77296 L .29995 .76933 L p .707 .577 .707 r
F P
0 g
s
.26858 .77296 m .27085 .79205 L .23952 .79589 L p .707 .577 .707 r
F P
0 g
s
.79548 .61319 m .79166 .6657 L .81534 .65834 L p .707 .577 .707 r
F P
0 g
s
.81534 .65834 m .81916 .60584 L .79548 .61319 L p .707 .577 .707 r
F P
0 g
s
.67197 .65594 m .67579 .60344 L .65441 .59241 L p .707 .577 .707 r
F P
0 g
s
.67579 .60344 m .67197 .65594 L .69961 .66416 L p .707 .577 .707 r
F P
0 g
s
.4339 .74882 m .4339 .24693 L .47675 .24313 L p .707 .577 .707 r
F P
0 g
s
.4339 .24693 m .4339 .74882 L .39752 .75598 L p .707 .577 .707 r
F P
0 g
s
.56487 .24676 m .56487 .74865 L .52188 .74496 L p .707 .577 .707 r
F P
0 g
s
.52188 .74496 m .52188 .24307 L .56487 .24676 L p .707 .577 .707 r
F P
0 g
s
.72898 .73455 m .73317 .70122 L .70194 .69535 L p .707 .577 .707 r
F P
0 g
s
.73317 .70122 m .72898 .73455 L .7605 .73554 L p .707 .577 .707 r
F P
0 g
s
.7605 .73554 m .76468 .70222 L .73317 .70122 L p .707 .577 .707 r
F P
0 g
s
.81916 .60584 m .81534 .65834 L .83125 .64794 L p .707 .577 .707 r
F P
0 g
s
.83125 .64794 m .83507 .59543 L .81916 .60584 L p .707 .577 .707 r
F P
0 g
s
.69775 .72868 m .70194 .69535 L .67404 .68518 L p .707 .577 .707 r
F P
0 g
s
.70194 .69535 m .69775 .72868 L .72898 .73455 L p .707 .577 .707 r
F P
0 g
s
.65059 .64491 m .65441 .59241 L .6414 .57965 L p .707 .577 .707 r
F P
0 g
s
.65441 .59241 m .65059 .64491 L .67197 .65594 L p .707 .577 .707 r
F P
0 g
s
.76468 .70222 m .7605 .73554 L .78921 .73157 L p .707 .577 .707 r
F P
0 g
s
.78921 .73157 m .79339 .69824 L .76468 .70222 L p .707 .577 .707 r
F P
0 g
s
.47675 .74502 m .47675 .24313 L .52188 .24307 L p .707 .577 .707 r
F P
0 g
s
.47675 .24313 m .47675 .74502 L .4339 .74882 L p .707 .577 .707 r
F P
0 g
s
.52188 .24307 m .52188 .74496 L .47675 .74502 L p .707 .577 .707 r
F P
0 g
s
.66986 .71851 m .67404 .68518 L .65222 .67171 L p .707 .577 .707 r
F P
0 g
s
.67404 .68518 m .66986 .71851 L .69775 .72868 L p .707 .577 .707 r
F P
0 g
s
.79339 .69824 m .78921 .73157 L .8123 .72301 L p .707 .577 .707 r
F P
0 g
s
.8123 .72301 m .81649 .68968 L .79339 .69824 L p .707 .577 .707 r
F P
0 g
s
.83507 .59543 m .83125 .64794 L .83784 .6355 L p .707 .577 .707 r
F P
0 g
s
.83784 .6355 m .84166 .583 L .83507 .59543 L p .707 .577 .707 r
F P
0 g
s
.72914 .77601 m .73142 .75946 L .70005 .75377 L p .707 .577 .707 r
F P
0 g
s
.73142 .75946 m .72914 .77601 L .76048 .7767 L p .707 .577 .707 r
F P
0 g
s
.76048 .7767 m .76276 .76015 L .73142 .75946 L p .707 .577 .707 r
F P
0 g
s
.6414 .57965 m .63758 .63215 L .65059 .64491 L p .707 .577 .707 r
F P
0 g
s
.69778 .77032 m .70005 .75377 L .67173 .74365 L p .707 .577 .707 r
F P
0 g
s
.70005 .75377 m .69778 .77032 L .72914 .77601 L p .707 .577 .707 r
F P
0 g
s
.63758 .63215 m .6414 .57965 L .63803 .5664 L p .707 .577 .707 r
F P
0 g
s
.65222 .67171 m .64803 .70503 L .66986 .71851 L p .707 .577 .707 r
F P
0 g
s
.64803 .70503 m .65222 .67171 L .6386 .65625 L p .707 .577 .707 r
F P
0 g
s
.76276 .76015 m .76048 .7767 L .78873 .77233 L p .707 .577 .707 r
F P
0 g
s
.78873 .77233 m .791 .75578 L .76276 .76015 L p .707 .577 .707 r
F P
0 g
s
.81649 .68968 m .8123 .72301 L .82753 .7107 L p .707 .577 .707 r
F P
0 g
s
.82753 .7107 m .83171 .67738 L .81649 .68968 L p .707 .577 .707 r
F P
0 g
s
.67173 .74365 m .66945 .7602 L .69778 .77032 L p .707 .577 .707 r
F P
0 g
s
.66945 .7602 m .67173 .74365 L .64922 .73008 L p .707 .577 .707 r
F P
0 g
s
.791 .75578 m .78873 .77233 L .81111 .76332 L p .707 .577 .707 r
F P
0 g
s
.81111 .76332 m .81338 .74677 L .791 .75578 L p .707 .577 .707 r
F P
0 g
s
.64922 .73008 m .64695 .74662 L .66945 .7602 L p .707 .577 .707 r
F P
0 g
s
.6386 .65625 m .63441 .68957 L .64803 .70503 L p .707 .577 .707 r
F P
0 g
s
.63803 .5664 m .63421 .6189 L .63758 .63215 L p .707 .577 .707 r
F P
0 g
s
.84166 .583 m .83784 .6355 L .83447 .62226 L p .707 .577 .707 r
F P
0 g
s
.83447 .62226 m .83829 .56976 L .84166 .583 L p .707 .577 .707 r
F P
0 g
s
.63441 .68957 m .6386 .65625 L .63452 .64031 L p .707 .577 .707 r
F P
0 g
s
.64695 .74662 m .64922 .73008 L .63473 .71438 L p .707 .577 .707 r
F P
0 g
s
.63421 .6189 m .63803 .5664 L .64462 .55397 L p .707 .577 .707 r
F P
0 g
s
.83171 .67738 m .82753 .7107 L .83338 .69586 L p .707 .577 .707 r
F P
0 g
s
.83338 .69586 m .83757 .66253 L .83171 .67738 L p .707 .577 .707 r
F P
0 g
s
.63473 .71438 m .63246 .73093 L .64695 .74662 L p .707 .577 .707 r
F P
0 g
s
.81338 .74677 m .81111 .76332 L .82544 .75056 L p .707 .577 .707 r
F P
0 g
s
.82544 .75056 m .82771 .73402 L .81338 .74677 L p .707 .577 .707 r
F P
0 g
s
.63452 .64031 m .63033 .67364 L .63441 .68957 L p .707 .577 .707 r
F P
0 g
s
.63246 .73093 m .63473 .71438 L .62968 .69811 L p .707 .577 .707 r
F P
0 g
s
.64462 .55397 m .6408 .60647 L .63421 .6189 L p .707 .577 .707 r
F P
0 g
s
.83829 .56976 m .83447 .62226 L .82146 .6095 L p .707 .577 .707 r
F P
0 g
s
.82146 .6095 m .82528 .55699 L .83829 .56976 L p .707 .577 .707 r
F P
0 g
s
.63033 .67364 m .63452 .64031 L .64038 .62547 L p .707 .577 .707 r
F P
0 g
s
.6408 .60647 m .64462 .55397 L .66054 .54356 L p .707 .577 .707 r
F P
0 g
s
.3821 .61391 m .39091 .55808 L .36002 .55204 L p .707 .577 .707 r
F P
0 g
s
.39091 .55808 m .3821 .61391 L .41353 .61799 L p .707 .577 .707 r
F P
0 g
s
.41353 .61799 m .42234 .56216 L .39091 .55808 L p .707 .577 .707 r
F P
0 g
s
.83757 .66253 m .83338 .69586 L .8293 .67992 L p .707 .577 .707 r
F P
0 g
s
.8293 .67992 m .83349 .6466 L .83757 .66253 L p .707 .577 .707 r
F P
0 g
s
.62968 .69811 m .6274 .71466 L .63246 .73093 L p .707 .577 .707 r
F P
0 g
s
.42234 .56216 m .41353 .61799 L .44242 .61973 L p .707 .577 .707 r
F P
0 g
s
.44242 .61973 m .45123 .5639 L .42234 .56216 L p .707 .577 .707 r
F P
0 g
s
.35121 .60787 m .36002 .55204 L .3327 .54464 L p .707 .577 .707 r
F P
0 g
s
.36002 .55204 m .35121 .60787 L .3821 .61391 L p .707 .577 .707 r
F P
0 g
s
.82771 .73402 m .82544 .75056 L .83032 .7353 L p .707 .577 .707 r
F P
0 g
s
.83032 .7353 m .83259 .71875 L .82771 .73402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64038 .62547 m .63619 .65879 L .63033 .67364 L p .707 .577 .707 r
F P
0 g
s
.3327 .54464 m .32389 .60047 L .35121 .60787 L p .707 .577 .707 r
F P
0 g
s
.37427 .6705 m .38377 .63371 L .35338 .62508 L p .707 .577 .707 r
F P
0 g
s
.38377 .63371 m .37427 .6705 L .40503 .67763 L p .707 .577 .707 r
F P
0 g
s
.40503 .67763 m .41453 .64083 L .38377 .63371 L p .707 .577 .707 r
F P
0 g
s
.45123 .5639 m .44242 .61973 L .46595 .61895 L p .707 .577 .707 r
F P
0 g
s
.46595 .61895 m .47476 .56312 L .45123 .5639 L p .707 .577 .707 r
F P
0 g
s
.32389 .60047 m .3327 .54464 L .31162 .53661 L p .707 .577 .707 r
F P
0 g
s
.6274 .71466 m .62968 .69811 L .63455 .68285 L p .707 .577 .707 r
F P
0 g
s
.82528 .55699 m .82146 .6095 L .80009 .59847 L p .707 .577 .707 r
F P
0 g
s
.80009 .59847 m .80391 .54597 L .82528 .55699 L p .707 .577 .707 r
F P
0 g
s
.34388 .66188 m .35338 .62508 L .32632 .61579 L p .707 .577 .707 r
F P
0 g
s
.35338 .62508 m .34388 .66188 L .37427 .6705 L p .707 .577 .707 r
F P
0 g
s
.41453 .64083 m .40503 .67763 L .43314 .68256 L p .707 .577 .707 r
F P
0 g
s
.43314 .68256 m .44264 .64576 L .41453 .64083 L p .707 .577 .707 r
F P
0 g
s
.66054 .54356 m .65672 .59607 L .6408 .60647 L p .707 .577 .707 r
F P
0 g
s
.63619 .65879 m .64038 .62547 L .6556 .61316 L p .707 .577 .707 r
F P
0 g
s
.65672 .59607 m .66054 .54356 L .68421 .53621 L p .707 .577 .707 r
F P
0 g
s
.32632 .61579 m .31683 .65259 L .34388 .66188 L p .707 .577 .707 r
F P
0 g
s
.37029 .71285 m .37538 .6945 L .34497 .68547 L p .707 .577 .707 r
F P
0 g
s
.37538 .6945 m .37029 .71285 L .40077 .72043 L p .707 .577 .707 r
F P
0 g
s
.40077 .72043 m .40586 .70208 L .37538 .6945 L p .707 .577 .707 r
F P
0 g
s
.83349 .6466 m .8293 .67992 L .81569 .66446 L p .707 .577 .707 r
F P
0 g
s
.81569 .66446 m .81987 .63114 L .83349 .6466 L p .707 .577 .707 r
F P
0 g
s
.63455 .68285 m .63228 .6994 L .6274 .71466 L p .707 .577 .707 r
F P
0 g
s
.31162 .53661 m .30281 .59244 L .32389 .60047 L p .707 .577 .707 r
F P
0 g
s
.34497 .68547 m .33988 .70382 L .37029 .71285 L p .707 .577 .707 r
F P
0 g
s
.33988 .70382 m .34497 .68547 L .3176 .67588 L p .707 .577 .707 r
F P
0 g
s
.83259 .71875 m .83032 .7353 L .82526 .71903 L p .707 .577 .707 r
F P
0 g
s
.82526 .71903 m .82754 .70248 L .83259 .71875 L p .707 .577 .707 r
F P
0 g
s
.40586 .70208 m .40077 .72043 L .42833 .72583 L p .707 .577 .707 r
F P
0 g
s
.42833 .72583 m .43342 .70748 L .40586 .70208 L p .707 .577 .707 r
F P
0 g
s
.3176 .67588 m .31251 .69423 L .33988 .70382 L p .707 .577 .707 r
F P
0 g
s
.31683 .65259 m .32632 .61579 L .30526 .60676 L p .707 .577 .707 r
F P
0 g
s
.44264 .64576 m .43314 .68256 L .45585 .68481 L p .707 .577 .707 r
F P
0 g
s
.45585 .68481 m .46535 .64801 L .44264 .64576 L p .707 .577 .707 r
F P
0 g
s
.47476 .56312 m .46595 .61895 L .48181 .61573 L p .707 .577 .707 r
F P
0 g
s
.48181 .61573 m .49062 .5599 L .47476 .56312 L p .707 .577 .707 r
F P
0 g
s
.30526 .60676 m .29576 .64356 L .31683 .65259 L p .707 .577 .707 r
F P
0 g
s
.80391 .54597 m .80009 .59847 L .77244 .59025 L p .707 .577 .707 r
F P
0 g
s
.77244 .59025 m .77626 .53775 L .80391 .54597 L p .707 .577 .707 r
F P
0 g
s
.30281 .59244 m .31162 .53661 L .29884 .52873 L p .707 .577 .707 r
F P
0 g
s
.6556 .61316 m .65141 .64649 L .63619 .65879 L p .707 .577 .707 r
F P
0 g
s
.6804 .58871 m .68421 .53621 L .71334 .53262 L p .707 .577 .707 r
F P
0 g
s
.68421 .53621 m .6804 .58871 L .65672 .59607 L p .707 .577 .707 r
F P
0 g
s
.31251 .69423 m .3176 .67588 L .29596 .66668 L p .707 .577 .707 r
F P
0 g
s
.63228 .6994 m .63455 .68285 L .64888 .67009 L p .707 .577 .707 r
F P
0 g
s
.29596 .66668 m .29086 .68502 L .31251 .69423 L p .707 .577 .707 r
F P
0 g
s
.65141 .64649 m .6556 .61316 L .6787 .6046 L p .707 .577 .707 r
F P
0 g
s
.43342 .70748 m .42833 .72583 L .45027 .72852 L p .707 .577 .707 r
F P
0 g
s
.45027 .72852 m .45537 .71017 L .43342 .70748 L p .707 .577 .707 r
F P
0 g
s
.81987 .63114 m .81569 .66446 L .79386 .65099 L p .707 .577 .707 r
F P
0 g
s
.79386 .65099 m .79805 .61766 L .81987 .63114 L p .707 .577 .707 r
F P
0 g
s
.29884 .52873 m .29003 .58456 L .30281 .59244 L p .707 .577 .707 r
F P
0 g
s
.77626 .53775 m .77244 .59025 L .74124 .58566 L p .707 .577 .707 r
F P
0 g
s
.74124 .58566 m .74505 .53315 L .77626 .53775 L p .707 .577 .707 r
F P
0 g
s
.70952 .58512 m .71334 .53262 L .74505 .53315 L p .707 .577 .707 r
F P
0 g
s
.71334 .53262 m .70952 .58512 L .6804 .58871 L p .707 .577 .707 r
F P
0 g
s
.64888 .67009 m .64661 .68664 L .63228 .6994 L p .707 .577 .707 r
F P
0 g
s
.29576 .64356 m .30526 .60676 L .29224 .59886 L p .707 .577 .707 r
F P
0 g
s
.46535 .64801 m .45585 .68481 L .47094 .68416 L p .707 .577 .707 r
F P
0 g
s
.47094 .68416 m .48044 .64736 L .46535 .64801 L p .707 .577 .707 r
F P
0 g
s
.82754 .70248 m .82526 .71903 L .81077 .70334 L p .707 .577 .707 r
F P
0 g
s
.81077 .70334 m .81305 .68679 L .82754 .70248 L p .707 .577 .707 r
F P
0 g
s
.74505 .53315 m .74124 .58566 L .70952 .58512 L p .707 .577 .707 r
F P
0 g
s
.29224 .59886 m .28274 .63566 L .29576 .64356 L p .707 .577 .707 r
F P
0 g
s
.49062 .5599 m .48181 .61573 L .48846 .61038 L p .707 .577 .707 r
F P
0 g
s
.48846 .61038 m .49726 .55455 L .49062 .5599 L p .707 .577 .707 r
F P
0 g
s
.29086 .68502 m .29596 .66668 L .28215 .65875 L p .707 .577 .707 r
F P
0 g
s
.6787 .6046 m .67451 .63793 L .65141 .64649 L p .707 .577 .707 r
F P
0 g
s
.67451 .63793 m .6787 .6046 L .70741 .60062 L p .707 .577 .707 r
F P
0 g
s
.28215 .65875 m .27705 .6771 L .29086 .68502 L p .707 .577 .707 r
F P
0 g
s
.29003 .58456 m .29884 .52873 L .29561 .52178 L p .707 .577 .707 r
F P
0 g
s
.79805 .61766 m .79386 .65099 L .76597 .64082 L p .707 .577 .707 r
F P
0 g
s
.76597 .64082 m .77016 .60749 L .79805 .61766 L p .707 .577 .707 r
F P
0 g
s
.45537 .71017 m .45027 .72852 L .46445 .72823 L p .707 .577 .707 r
F P
0 g
s
.46445 .72823 m .46955 .70988 L .45537 .71017 L p .707 .577 .707 r
F P
0 g
s
.64661 .68664 m .64888 .67009 L .67127 .66108 L p .707 .577 .707 r
F P
0 g
s
.29561 .52178 m .28681 .57761 L .29003 .58456 L p .707 .577 .707 r
F P
0 g
s
.70322 .63395 m .70741 .60062 L .73892 .60162 L p .707 .577 .707 r
F P
0 g
s
.70741 .60062 m .70322 .63395 L .67451 .63793 L p .707 .577 .707 r
F P
0 g
s
.67127 .66108 m .66899 .67763 L .64661 .68664 L p .707 .577 .707 r
F P
0 g
s
.81305 .68679 m .81077 .70334 L .78826 .68976 L p .707 .577 .707 r
F P
0 g
s
.78826 .68976 m .79054 .67321 L .81305 .68679 L p .707 .577 .707 r
F P
0 g
s
.77016 .60749 m .76597 .64082 L .73474 .63495 L p .707 .577 .707 r
F P
0 g
s
.73474 .63495 m .73892 .60162 L .77016 .60749 L p .707 .577 .707 r
F P
0 g
s
.28274 .63566 m .29224 .59886 L .28854 .59288 L p .707 .577 .707 r
F P
0 g
s
.48044 .64736 m .47094 .68416 L .47693 .68067 L p .707 .577 .707 r
F P
0 g
s
.47693 .68067 m .48643 .64387 L .48044 .64736 L p .707 .577 .707 r
F P
0 g
s
.73892 .60162 m .73474 .63495 L .70322 .63395 L p .707 .577 .707 r
F P
0 g
s
.28854 .59288 m .27905 .62968 L .28274 .63566 L p .707 .577 .707 r
F P
0 g
s
.66899 .67763 m .67127 .66108 L .69951 .65671 L p .707 .577 .707 r
F P
0 g
s
.27705 .6771 m .28215 .65875 L .27753 .65288 L p .707 .577 .707 r
F P
0 g
s
.49726 .55455 m .48846 .61038 L .48523 .60342 L p .707 .577 .707 r
F P
0 g
s
.48523 .60342 m .49404 .54759 L .49726 .55455 L p .707 .577 .707 r
F P
0 g
s
.27753 .65288 m .27244 .67123 L .27705 .6771 L p .707 .577 .707 r
F P
0 g
s
.46955 .70988 m .46445 .72823 L .46948 .72499 L p .707 .577 .707 r
F P
0 g
s
.46948 .72499 m .47457 .70664 L .46955 .70988 L p .707 .577 .707 r
F P
0 g
s
.28681 .57761 m .29561 .52178 L .30226 .51642 L p .707 .577 .707 r
F P
0 g
s
.79054 .67321 m .78826 .68976 L .75994 .67964 L p .707 .577 .707 r
F P
0 g
s
.75994 .67964 m .76221 .66309 L .79054 .67321 L p .707 .577 .707 r
F P
0 g
s
.69951 .65671 m .69724 .67326 L .66899 .67763 L p .707 .577 .707 r
F P
0 g
s
.69724 .67326 m .69951 .65671 L .73085 .6574 L p .707 .577 .707 r
F P
0 g
s
.76221 .66309 m .75994 .67964 L .72857 .67395 L p .707 .577 .707 r
F P
0 g
s
.72857 .67395 m .73085 .6574 L .76221 .66309 L p .707 .577 .707 r
F P
0 g
s
.30226 .51642 m .29345 .57225 L .28681 .57761 L p .707 .577 .707 r
F P
0 g
s
.73085 .6574 m .72857 .67395 L .69724 .67326 L p .707 .577 .707 r
F P
0 g
s
.27905 .62968 m .28854 .59288 L .29453 .58939 L p .707 .577 .707 r
F P
0 g
s
.48643 .64387 m .47693 .68067 L .47324 .67468 L p .707 .577 .707 r
F P
0 g
s
.47324 .67468 m .48273 .63788 L .48643 .64387 L p .707 .577 .707 r
F P
0 g
s
.29453 .58939 m .28504 .62619 L .27905 .62968 L p .707 .577 .707 r
F P
0 g
s
.27244 .67123 m .27753 .65288 L .28256 .64964 L p .707 .577 .707 r
F P
0 g
s
.49404 .54759 m .48523 .60342 L .47245 .59554 L p .707 .577 .707 r
F P
0 g
s
.47245 .59554 m .48126 .53971 L .49404 .54759 L p .707 .577 .707 r
F P
0 g
s
.28256 .64964 m .27747 .66799 L .27244 .67123 L p .707 .577 .707 r
F P
0 g
s
.29345 .57225 m .30226 .51642 L .31812 .5132 L p .707 .577 .707 r
F P
0 g
s
.47457 .70664 m .46948 .72499 L .46486 .71912 L p .707 .577 .707 r
F P
0 g
s
.46486 .71912 m .46996 .70077 L .47457 .70664 L p .707 .577 .707 r
F P
0 g
s
.31812 .5132 m .30931 .56903 L .29345 .57225 L p .707 .577 .707 r
F P
0 g
s
.28504 .62619 m .29453 .58939 L .30962 .58874 L p .707 .577 .707 r
F P
0 g
s
.48273 .63788 m .47324 .67468 L .46022 .66678 L p .707 .577 .707 r
F P
0 g
s
.46022 .66678 m .46972 .62999 L .48273 .63788 L p .707 .577 .707 r
F P
0 g
s
.30962 .58874 m .30013 .62553 L .28504 .62619 L p .707 .577 .707 r
F P
0 g
s
.48126 .53971 m .47245 .59554 L .45137 .58751 L p .707 .577 .707 r
F P
0 g
s
.45137 .58751 m .46018 .53168 L .48126 .53971 L p .707 .577 .707 r
F P
0 g
s
.27747 .66799 m .28256 .64964 L .29674 .64935 L p .707 .577 .707 r
F P
0 g
s
.30931 .56903 m .31812 .5132 L .34165 .51242 L p .707 .577 .707 r
F P
0 g
s
.29674 .64935 m .29165 .6677 L .27747 .66799 L p .707 .577 .707 r
F P
0 g
s
.46996 .70077 m .46486 .71912 L .45106 .71119 L p .707 .577 .707 r
F P
0 g
s
.45106 .71119 m .45615 .69284 L .46996 .70077 L p .707 .577 .707 r
F P
0 g
s
.34165 .51242 m .33284 .56825 L .30931 .56903 L p .707 .577 .707 r
F P
0 g
s
.30013 .62553 m .30962 .58874 L .33233 .59098 L p .707 .577 .707 r
F P
0 g
s
.46972 .62999 m .46022 .66678 L .43915 .65775 L p .707 .577 .707 r
F P
0 g
s
.43915 .65775 m .44865 .62095 L .46972 .62999 L p .707 .577 .707 r
F P
0 g
s
.46018 .53168 m .45137 .58751 L .42405 .58012 L p .707 .577 .707 r
F P
0 g
s
.42405 .58012 m .43286 .52429 L .46018 .53168 L p .707 .577 .707 r
F P
0 g
s
.33284 .56825 m .34165 .51242 L .37054 .51416 L p .707 .577 .707 r
F P
0 g
s
.33233 .59098 m .32284 .62778 L .30013 .62553 L p .707 .577 .707 r
F P
0 g
s
.29165 .6677 m .29674 .64935 L .31869 .65203 L p .707 .577 .707 r
F P
0 g
s
.31869 .65203 m .31359 .67038 L .29165 .6677 L p .707 .577 .707 r
F P
0 g
s
.45615 .69284 m .45106 .71119 L .42941 .70198 L p .707 .577 .707 r
F P
0 g
s
.42941 .70198 m .4345 .68363 L .45615 .69284 L p .707 .577 .707 r
F P
0 g
s
.37054 .51416 m .36173 .56999 L .33284 .56825 L p .707 .577 .707 r
F P
0 g
s
.43286 .52429 m .42405 .58012 L .39316 .57408 L p .707 .577 .707 r
F P
0 g
s
.39316 .57408 m .40197 .51825 L .43286 .52429 L p .707 .577 .707 r
F P
0 g
s
.36173 .56999 m .37054 .51416 L .40197 .51825 L p .707 .577 .707 r
F P
0 g
s
.32284 .62778 m .33233 .59098 L .36044 .59591 L p .707 .577 .707 r
F P
0 g
s
.40197 .51825 m .39316 .57408 L .36173 .56999 L p .707 .577 .707 r
F P
0 g
s
.44865 .62095 m .43915 .65775 L .4121 .64847 L p .707 .577 .707 r
F P
0 g
s
.4121 .64847 m .42159 .61167 L .44865 .62095 L p .707 .577 .707 r
F P
0 g
s
.36044 .59591 m .35095 .63271 L .32284 .62778 L p .707 .577 .707 r
F P
0 g
s
.31359 .67038 m .31869 .65203 L .34624 .65743 L p .707 .577 .707 r
F P
0 g
s
.34624 .65743 m .34115 .67578 L .31359 .67038 L p .707 .577 .707 r
F P
0 g
s
.4345 .68363 m .42941 .70198 L .40204 .69239 L p .707 .577 .707 r
F P
0 g
s
.40204 .69239 m .40713 .67405 L .4345 .68363 L p .707 .577 .707 r
F P
0 g
s
.35095 .63271 m .36044 .59591 L .3912 .60304 L p .707 .577 .707 r
F P
0 g
s
.42159 .61167 m .4121 .64847 L .38171 .63984 L p .707 .577 .707 r
F P
0 g
s
.38171 .63984 m .3912 .60304 L .42159 .61167 L p .707 .577 .707 r
F P
0 g
s
.3912 .60304 m .38171 .63984 L .35095 .63271 L p .707 .577 .707 r
F P
0 g
s
.34115 .67578 m .34624 .65743 L .37672 .66502 L p .707 .577 .707 r
F P
0 g
s
.40713 .67405 m .40204 .69239 L .37163 .68337 L p .707 .577 .707 r
F P
0 g
s
.37163 .68337 m .37672 .66502 L .40713 .67405 L p .707 .577 .707 r
F P
0 g
s
.37672 .66502 m .37163 .68337 L .34115 .67578 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007Aoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00L7oo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001^
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000Kgoo001[Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`00K7oo001YOol20006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2001ZOol006Qoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8006Uoo`00IWoo0P0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000006Moo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol005Qoo`h000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool005Eoo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00003
0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000047oo4@00AGoo001COol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Woo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P00?goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Woo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00Dgoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000j
Ool005=oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000hOol0059oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<003Ioo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008003Aoo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000a
Ool0059oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
031oo`00DWoo00AJEP00FUIJEP`000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000_Ool0055oo`03001JEP00
00800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0055oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00H0
05YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60006FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06
001JEUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0059oo`05001J
EUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001COol800000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH01000FUIJEUYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF1P004Goo
1P001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20004FUH00`00FUIJEP070002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH0
0UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF
00<005YF00000`007Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20003
FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF0P000UYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000=JEP<0029oo`<00003FUH005YF00AJEP07001JEUYFFUH005YF0000;Goo001A
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF0P001Woo2@0057oo0P001EYF00L005YFFUIJ
EP00FUH0000]Ool0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUH005YF0`0000=JEP00FUH00eYF1P0015YF00<005YFFUH0
0UYF20003Woo0P000eYF00L005YFFUIJEP00FUH0000]Ool0055oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00
FUH00002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP06FUH01000FUIJEUYF1P002Woo0P0000=J
EP00FUH00UYF00<005YF0000;Goo001AOol00eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJ
EP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001Woo0`00
00=JEP0000000eYF0P00;Woo001@Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00@005YFFUIJEP80
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH30004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YF0000
0UYF0P00;Woo0017Ool:00000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH00P002eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00@002ioo`00?goo2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEPX000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEP00001JEP0200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP02FUH2000^Ool003Moo`P000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF009JEP<002ioo`00
<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH3000015YF001JEUYF
1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP<002ioo`00;Woo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`0035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJEP03
001JEUYF00EJEP03001JEUYF00EJEP800004FUH005YF000^Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF009J
EPH0009JEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP80
0003FUH0000002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEP0000800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUH000000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH015YF00D005YFFUIJEP00031oo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPT00003FUH005YF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF0000<7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000020003FUH00`00FUIJEP070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUH005YF0P000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP8002moo`00;Goo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF
FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01`00FUIJEUYF001J
EP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00008000IJEP<0
00EJEPd000IJEP03001JEUYF00IJEP<000=JEP03001JEUYF009JEP8002moo`00;Goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP07001J
EUYFFUH005YF00002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF1P001eYF1P00
00=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH0
0eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP07FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP04FUH40005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40007FUH00`00FUH000040003FUH01000FUIJEP00;Woo000^Ool00eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH30007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH2000015YF001JEP000UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF000005YF00H000Eoo`04001JEUYF0002FUH00`00Oomoo`0/
Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP800003
FUH005YF00=JEPL000IJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00=JEP<00004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
000015YF001JEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000Yoo`03001JEP00009JEP03001oogoo02aoo`00;Woo00=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEPP00003FUH005YF00QJEP03
001JEUYF00AJEP@000MJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP8000EJEP03001JEUYF009JEPl000IJEP03
001JEUYF00AJEP8000Qoo`05001JEP00FUH0000_Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF009JEPP00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00=JEP<000=JEP@0
00MJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000AJEP00FUH000AJEPH0009JEP03001J
EUYF008000Qoo`@0009JEP03001JEUYF00EJEP<000Moo`800003FUH007oo02ioo`00;Woo00=JEP00
FUH00eYF00@005YFFUIJEPT000QJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEP0000<0
0003FUH005YF00@0009JEP03001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF
009JEP<0009JEP03001JEUYF009JEP03001JEUYF008000aoo`@000IJEP03001JEUYF008000Ioo`03
001JEP0002moo`00;Woo00=JEP00FUH00UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1UYF00<005YFFUH015YF100000=JEP00FUH01@001UYF00<005YFFUH01EYF3P0035YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00@005YF000000=JEP@000AJEP04
001JEP00000@Ool20004FUH00`00FUIJEP02FUH20003Ool200000eYF001oo`0^Ool002ioo`03FUH0
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF
00IJEP04001JEP000003FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30002FUH30005FUH00`00FUH00003
00001EYF001JEUYF00004Woo0`0000=JEP00FUH01EYF00@007oo001JEP80031oo`00;Woo00EJEP00
001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00MJEP03001JEUYF009JEP@000IJEP@000MJEP03001JEUYF008000MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP04001J
EUYFFUH40002FUH00`00Oomoo`0COol20006FUH20003FUH00`00Oomoo`0^Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00MJEP03001JEUYF00EJEP@000AJEP03001JEUYF008000AJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@0009JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@001Moo`8000AJEP04001JEP00FUH2000`Ool002moo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000=oo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00D000AJEP<00003FUH005YF00EJEP<000=JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00@0011oo`H0009JEP04001JEUYFFUH3000`Ool0035ooad000]oo`H00003FUH005YF00QJEP03
001JEUYF00AJEP@000AJEP8000IJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP80009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00<000AJEP80031oo`00D7oo2@000eYF00<005YFFUH010001UYF00<005YFFUH0
1eYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0`0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF0P000UYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<007ooOol0;goo0017Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP03FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002
FUH00`00FUH000020003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<Goo000oOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH005YF10001eYF00<005YFFUH01UYF00@005YFFUIJEP80
00=JEP04001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUH0
05YF001JEP00009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000hOol70003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUH000030002FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300001EYF000005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00L005YF001JEP00FUH00003FUH30007FUH00`00FUIJEP07FUH40005FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001oo`0_Ool0039oo`H0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000=JEP03001JEUYF00=JEP@000MJEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00AJEP8000IJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<00004Ool0
05YF000`Ool002ioo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001J
EP0000<0009JEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH01000FUIJEP001UYF0P0015YF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00L007ooOomoo`00FUH0000`Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00=JEPD000=JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80
00=JEP03001JEP0000MJEP@00003FUH005YF00MJEPH000=JEP03001JEUYF00EJEP04001JEUYFFUH2
0005Ool2000`Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00MJEPX0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000AJEP8000MJEP04001JEUYFFUH60004FUH00`00FUH000020004FUH00`00FUIJEP05FUH0
1000FUH000001goo0P00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003FUH30007FUH00`00FUIJEP02FUH00`00FUIJEP0:0004
FUH00`00FUIJEP02FUH50009Ool2000`Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP0:0003FUH01000FUH0
000027oo2@003Goo0`00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH<0003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP<000Ioo`@0009JEP03001oogoo01]oo`03001JEP00035oo`00
;goo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF20000UYF00@005YFFUIJEPH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20006FUH20006Ool00`00FUIJ
EP03000LOol01000FUH00000<Goo000_Ool00eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP02FUH70005Ool01@00FUIJEUYF00001eYF00<005YF
FUH01EYF2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@001eYF00<005YFFUH01EYF00@005YF
FUIJEP8000IJEP04001JEP000003Ool01`00FUIJEUYF001JEP0001Yoo`80009JEP03001oogoo031o
o`00;goo0UYF00D005YFFUIJEP0000EJEP03001JEUYF009JEPT0009JEP03001JEUYF009JEPT000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP050002FUH00`00FUIJEP05FUH01P00FUIJEUYF001oo`8000AJEP04001J
EUYFFUH30004FUH01000FUH000005Goo100000EJEP00FUIJEP00039oo`00;goo0UYF00D005YFFUIJ
EP0000=JEPL0009JEP03001JEUYF009JEPT001Eoo`05001JEUYFFUH00006FUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40006FUH01@00FUIJEUYF0000
0goo0P000UYF00<005YFFUH015YF1P0000=JEP00Ool04Goo0`001EYF00<005YF0000<goo000_Ool2
FUHF000NOol01@00FUIJEUYF000015YF0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF0`0015YF00H005YFFUIJEP00Ool70007FUH00`00FUIJ
EP02FUH90007Ool400000eYF001JEP04FUH00`00FUH0000dOol002moo`T002eoo`06001JEUYFFUH0
05YF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH00`0000=JEP00FUH00UYF0P000UYF00@005YFFUIJEP8000IJEP03001J
EUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF00=JEP8003Eoo`00FWoo30000eYF0P001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000EJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003Ioo`00DGoo2@000eYF00<005YFFUH00eYF00<0
05YF00000UYF0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00>7oo0018Ool90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUH005YF001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEP00008000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003]oo`00@7oo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF00D005YFFUIJEP00009JEPd000=JEP03001JEP000140
041oo`00>Goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP<000EJEP03001JEUYF00EJ
EP@000=JEP03001oogoo04eoo`00<goo1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05
001JEUYFFUH00007FUH00`00FUIJEP05FUH20002Ool200000eYF001oo`1>Ool002moo`@0009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPL0
0003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00
FUIJEP04FUH00`00Oomoo`03Ool2001?Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH0000000D000=oo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000025YF00<005YFFUH00UYF0P001Goo00@005YF000004ioo`00
;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4P002goo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF008000QJEP05001JEUYFFUH00007Ool01000FUIJEP00CWoo
000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA000EOol30007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH30002FUH00`00FUIJEP06FUH30007Ool20002FUH00`00Oomoo`1<Ool0031oo`03FUH005YF
009JEP04001JEUYFFUH@000POol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP05FUH20008
Ool01P00FUIJEP00FUH004ioo`00<7oo00=JEP0000003P00:Woo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP8000IJ
EP03001JEUYF00=JEP8000Uoo`04001JEUYFFUH2001?Ool0031oo`@003Uoo`<00003FUH005YF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000009
FUH00`00FUH00002000:Ool00`00FUIJEP03FUH00`00Oomoo`1=Ool0071oo`@000MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP@0
00]oo`<000EJEP03001oogoo04eoo`00M7oo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02`0000AJEP00FUIJEP@000ioo`05001JEUYFFUH00003FUH00`00Oomo
o`1>Ool007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000=JEP03001JEUYF00T0011o
o`8000AJEP04001JEUYF001AOol0085ooa/000=JEP03001JEUYF00EJEP03001JEP0000@001=oo`03
001JEUYF00EJEP80059oo`00UGoo00<005YF00000UYF00<007oo000040004Woo0`001eYF00<007oo
Ool0DGoo002EOol00`00FUIJEP02000SOol20003FUH00`00FUIJEP02FUH2001DOol009Eoo`04001J
EUYF000ROol20005FUH01@00FUIJEUYF0000EWoo002EOol00`00FUH0000POol30008FUH3001GOol0
09Ioo`03FUH007oo01]oo`@00003FUH005YF00MJEP8005Uoo`00UWoo0`005Woo1@001UYF00<005YF
FUH00eYF0P00Fgoo002FOol200000eYF00000002000>Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP03001MOol009Moo`04001JEUYF0002FUH>0006FUH00`00FUIJEP06FUH3001POol009Moo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<006=oo`00V7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008006Ioo`00VGoo0P00
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF1000JGoo002KOol40003FUH00`00FUIJ
EP04FUH00`00FUIJEP04001]Ool009moo`d0075oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60684 .75534 m .59803 .70156 L .56714 .70382 L p .707 .577 .707 r
F P
0 g
s
.59803 .70156 m .60684 .75534 L .63826 .74968 L p .707 .577 .707 r
F P
0 g
s
.63826 .74968 m .62945 .69589 L .59803 .70156 L p .707 .577 .707 r
F P
0 g
s
.62945 .69589 m .63826 .74968 L .66715 .74118 L p .707 .577 .707 r
F P
0 g
s
.66715 .74118 m .65835 .68739 L .62945 .69589 L p .707 .577 .707 r
F P
0 g
s
.57595 .75761 m .56714 .70382 L .53982 .70248 L p .707 .577 .707 r
F P
0 g
s
.56714 .70382 m .57595 .75761 L .60684 .75534 L p .707 .577 .707 r
F P
0 g
s
.65835 .68739 m .66715 .74118 L .69068 .73067 L p .707 .577 .707 r
F P
0 g
s
.69068 .73067 m .68188 .67688 L .65835 .68739 L p .707 .577 .707 r
F P
0 g
s
.54863 .75626 m .53982 .70248 L .51874 .69764 L p .707 .577 .707 r
F P
0 g
s
.53982 .70248 m .54863 .75626 L .57595 .75761 L p .707 .577 .707 r
F P
0 g
s
.61829 .81867 m .6088 .7841 L .5784 .78897 L p .707 .577 .707 r
F P
0 g
s
.6088 .7841 m .61829 .81867 L .64905 .80998 L p .707 .577 .707 r
F P
0 g
s
.64905 .80998 m .63955 .77541 L .6088 .7841 L p .707 .577 .707 r
F P
0 g
s
.63955 .77541 m .64905 .80998 L .67716 .79831 L p .707 .577 .707 r
F P
0 g
s
.67716 .79831 m .66766 .76374 L .63955 .77541 L p .707 .577 .707 r
F P
0 g
s
.68188 .67688 m .69068 .73067 L .70655 .71917 L p .707 .577 .707 r
F P
0 g
s
.70655 .71917 m .69774 .66539 L .68188 .67688 L p .707 .577 .707 r
F P
0 g
s
.5879 .82354 m .5784 .78897 L .55135 .78954 L p .707 .577 .707 r
F P
0 g
s
.5784 .78897 m .5879 .82354 L .61829 .81867 L p .707 .577 .707 r
F P
0 g
s
.66766 .76374 m .67716 .79831 L .69987 .78482 L p .707 .577 .707 r
F P
0 g
s
.69987 .78482 m .69037 .75025 L .66766 .76374 L p .707 .577 .707 r
F P
0 g
s
.51874 .69764 m .52755 .75143 L .54863 .75626 L p .707 .577 .707 r
F P
0 g
s
.52755 .75143 m .51874 .69764 L .50596 .6898 L p .707 .577 .707 r
F P
0 g
s
.62837 .86056 m .62327 .84346 L .59286 .84915 L p .707 .577 .707 r
F P
0 g
s
.62327 .84346 m .62837 .86056 L .65885 .85099 L p .707 .577 .707 r
F P
0 g
s
.65885 .85099 m .65375 .83388 L .62327 .84346 L p .707 .577 .707 r
F P
0 g
s
.55135 .78954 m .56084 .82411 L .5879 .82354 L p .707 .577 .707 r
F P
0 g
s
.65375 .83388 m .65885 .85099 L .68641 .83847 L p .707 .577 .707 r
F P
0 g
s
.68641 .83847 m .68131 .82137 L .65375 .83388 L p .707 .577 .707 r
F P
0 g
s
.56084 .82411 m .55135 .78954 L .53028 .78575 L p .707 .577 .707 r
F P
0 g
s
.69037 .75025 m .69987 .78482 L .71496 .77081 L p .707 .577 .707 r
F P
0 g
s
.71496 .77081 m .70546 .73624 L .69037 .75025 L p .707 .577 .707 r
F P
0 g
s
.59286 .84915 m .59796 .86625 L .62837 .86056 L p .707 .577 .707 r
F P
0 g
s
.69774 .66539 m .70655 .71917 L .71319 .70783 L p .707 .577 .707 r
F P
0 g
s
.71319 .70783 m .70438 .65404 L .69774 .66539 L p .707 .577 .707 r
F P
0 g
s
.59796 .86625 m .59286 .84915 L .56549 .8504 L p .707 .577 .707 r
F P
0 g
s
.68131 .82137 m .68641 .83847 L .70835 .82424 L p .707 .577 .707 r
F P
0 g
s
.70835 .82424 m .70325 .80713 L .68131 .82137 L p .707 .577 .707 r
F P
0 g
s
.56549 .8504 m .57059 .86751 L .59796 .86625 L p .707 .577 .707 r
F P
0 g
s
.53028 .78575 m .53978 .82032 L .56084 .82411 L p .707 .577 .707 r
F P
0 g
s
.50596 .6898 m .51477 .74358 L .52755 .75143 L p .707 .577 .707 r
F P
0 g
s
.57059 .86751 m .56549 .8504 L .54385 .8471 L p .707 .577 .707 r
F P
0 g
s
.51477 .74358 m .50596 .6898 L .50273 .67971 L p .707 .577 .707 r
F P
0 g
s
.53978 .82032 m .53028 .78575 L .51726 .77798 L p .707 .577 .707 r
F P
0 g
s
.70325 .80713 m .70835 .82424 L .72253 .80968 L p .707 .577 .707 r
F P
0 g
s
.72253 .80968 m .71744 .79257 L .70325 .80713 L p .707 .577 .707 r
F P
0 g
s
.70546 .73624 m .71496 .77081 L .72095 .75767 L p .707 .577 .707 r
F P
0 g
s
.72095 .75767 m .71145 .7231 L .70546 .73624 L p .707 .577 .707 r
F P
0 g
s
.54385 .8471 m .54894 .8642 L .57059 .86751 L p .707 .577 .707 r
F P
0 g
s
.70438 .65404 m .71319 .70783 L .70996 .69774 L p .707 .577 .707 r
F P
0 g
s
.70996 .69774 m .70116 .64395 L .70438 .65404 L p .707 .577 .707 r
F P
0 g
s
.51726 .77798 m .52676 .81255 L .53978 .82032 L p .707 .577 .707 r
F P
0 g
s
.50273 .67971 m .51154 .73349 L .51477 .74358 L p .707 .577 .707 r
F P
0 g
s
.54894 .8642 m .54385 .8471 L .53004 .83955 L p .707 .577 .707 r
F P
0 g
s
.47812 .82147 m .47812 .31959 L .43513 .3159 L p .707 .577 .707 r
F P
0 g
s
.52676 .81255 m .51726 .77798 L .51357 .76698 L p .707 .578 .707 r
F P
0 g
s
.51154 .73349 m .50273 .67971 L .50938 .66836 L p .707 .577 .707 r
F P
0 g
s
.51357 .76698 m .52307 .80155 L .52676 .81255 L p .707 .578 .707 r
F P
0 g
s
.50938 .66836 m .51819 .72215 L .51154 .73349 L p .707 .577 .707 r
F P
0 g
s
.52307 .80155 m .51357 .76698 L .51956 .75384 L p .707 .577 .707 r
F P
0 g
s
.51819 .72215 m .50938 .66836 L .52524 .65687 L p .707 .577 .707 r
F P
0 g
s
.47812 .31959 m .47812 .82147 L .52324 .82142 L p .707 .577 .707 r
F P
0 g
s
.51956 .75384 m .52906 .78841 L .52307 .80155 L p .707 .577 .707 r
F P
0 g
s
.52524 .65687 m .53405 .71066 L .51819 .72215 L p .707 .577 .707 r
F P
0 g
s
.52906 .78841 m .51956 .75384 L .53465 .73983 L p .707 .577 .707 r
F P
0 g
s
.52324 .82142 m .52324 .31953 L .47812 .31959 L p .707 .577 .707 r
F P
0 g
s
.53004 .83955 m .53513 .85666 L .54894 .8642 L p .707 .577 .707 r
F P
0 g
s
.53513 .85666 m .53004 .83955 L .52542 .82851 L p .707 .577 .707 r
F P
0 g
s
.52542 .82851 m .53052 .84561 L .53513 .85666 L p .707 .577 .707 r
F P
0 g
s
.53052 .84561 m .52542 .82851 L .53045 .81505 L p .707 .577 .707 r
F P
0 g
s
.53405 .71066 m .52524 .65687 L .54877 .64636 L p .707 .577 .707 r
F P
0 g
s
.53045 .81505 m .53555 .83215 L .53052 .84561 L p .707 .577 .707 r
F P
0 g
s
.53465 .73983 m .54415 .7744 L .52906 .78841 L p .707 .577 .707 r
F P
0 g
s
.55758 .70014 m .54877 .64636 L .57766 .63785 L p .707 .577 .707 r
F P
0 g
s
.54877 .64636 m .55758 .70014 L .53405 .71066 L p .707 .577 .707 r
F P
0 g
s
.53555 .83215 m .53045 .81505 L .54463 .80048 L p .707 .577 .707 r
F P
0 g
s
.54415 .7744 m .53465 .73983 L .55736 .72633 L p .707 .577 .707 r
F P
0 g
s
.54463 .80048 m .54973 .81759 L .53555 .83215 L p .707 .577 .707 r
F P
0 g
s
.55736 .72633 m .56686 .7609 L .54415 .7744 L p .707 .577 .707 r
F P
0 g
s
.56686 .7609 m .55736 .72633 L .58547 .71467 L p .707 .577 .707 r
F P
0 g
s
.54973 .81759 m .54463 .80048 L .56658 .78625 L p .707 .577 .707 r
F P
0 g
s
.56658 .78625 m .57167 .80335 L .54973 .81759 L p .707 .577 .707 r
F P
0 g
s
.52324 .31953 m .52324 .82142 L .5661 .81762 L p .707 .577 .707 r
F P
0 g
s
.57766 .63785 m .58647 .69164 L .55758 .70014 L p .707 .577 .707 r
F P
0 g
s
.5661 .81762 m .5661 .31573 L .52324 .31953 L p .707 .577 .707 r
F P
0 g
s
.71744 .79257 m .72253 .80968 L .72756 .79621 L p .707 .577 .707 r
F P
0 g
s
.72756 .79621 m .72246 .77911 L .71744 .79257 L p .707 .577 .707 r
F P
0 g
s
.71145 .7231 m .72095 .75767 L .71725 .74667 L p .707 .578 .707 r
F P
0 g
s
.71725 .74667 m .70776 .7121 L .71145 .7231 L p .707 .578 .707 r
F P
0 g
s
.43513 .81779 m .43513 .3159 L .39849 .30883 L p .707 .577 .707 r
F P
0 g
s
.43513 .3159 m .43513 .81779 L .47812 .82147 L p .707 .577 .707 r
F P
0 g
s
.58647 .69164 m .57766 .63785 L .60909 .63219 L p .707 .577 .707 r
F P
0 g
s
.60909 .63219 m .6179 .68598 L .58647 .69164 L p .707 .577 .707 r
F P
0 g
s
.59497 .74924 m .58547 .71467 L .61623 .70598 L p .707 .577 .707 r
F P
0 g
s
.58547 .71467 m .59497 .74924 L .56686 .7609 L p .707 .577 .707 r
F P
0 g
s
.61623 .70598 m .62572 .74055 L .59497 .74924 L p .707 .577 .707 r
F P
0 g
s
.57167 .80335 m .56658 .78625 L .59414 .77373 L p .707 .577 .707 r
F P
0 g
s
.59414 .77373 m .59923 .79084 L .57167 .80335 L p .707 .577 .707 r
F P
0 g
s
.59923 .79084 m .59414 .77373 L .62461 .76416 L p .707 .577 .707 r
F P
0 g
s
.62461 .76416 m .62971 .78126 L .59923 .79084 L p .707 .577 .707 r
F P
0 g
s
.5661 .31573 m .5661 .81762 L .60248 .81046 L p .707 .577 .707 r
F P
0 g
s
.60248 .81046 m .60248 .30857 L .5661 .31573 L p .707 .577 .707 r
F P
0 g
s
.70116 .64395 m .70996 .69774 L .69719 .68989 L p .707 .577 .707 r
F P
0 g
s
.69719 .68989 m .68838 .63611 L .70116 .64395 L p .707 .577 .707 r
F P
0 g
s
.25876 .70008 m .25494 .64293 L .22374 .64419 L p .707 .577 .707 r
F P
0 g
s
.25494 .64293 m .25876 .70008 L .29048 .69759 L p .707 .577 .707 r
F P
0 g
s
.29048 .69759 m .28666 .64044 L .25494 .64293 L p .707 .577 .707 r
F P
0 g
s
.28666 .64044 m .29048 .69759 L .3196 .6941 L p .707 .577 .707 r
F P
0 g
s
.3196 .6941 m .31578 .63695 L .28666 .64044 L p .707 .577 .707 r
F P
0 g
s
.72246 .77911 m .72756 .79621 L .72294 .78517 L p .707 .577 .707 r
F P
0 g
s
.72294 .78517 m .71785 .76807 L .72246 .77911 L p .707 .577 .707 r
F P
0 g
s
.22755 .70134 m .22374 .64419 L .19609 .64409 L p .707 .577 .707 r
F P
0 g
s
.22374 .64419 m .22755 .70134 L .25876 .70008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26526 .75359 m .26108 .71537 L .22984 .71861 L p .707 .577 .707 r
F P
0 g
s
.26108 .71537 m .26526 .75359 L .29678 .75001 L p .707 .577 .707 r
F P
0 g
s
.29678 .75001 m .29259 .71179 L .26108 .71537 L p .707 .577 .707 r
F P
0 g
s
.70776 .7121 m .71725 .74667 L .70424 .7389 L p .707 .577 .707 r
F P
0 g
s
.70424 .7389 m .69474 .70433 L .70776 .7121 L p .707 .577 .707 r
F P
0 g
s
.39849 .81072 m .39849 .30883 L .37179 .29907 L p .707 .577 .707 r
F P
0 g
s
.39849 .30883 m .39849 .81072 L .43513 .81779 L p .707 .577 .707 r
F P
0 g
s
.22984 .71861 m .23403 .75683 L .26526 .75359 L p .707 .577 .707 r
F P
0 g
s
.19609 .64409 m .19991 .70125 L .22755 .70134 L p .707 .577 .707 r
F P
0 g
s
.63998 .62992 m .64878 .68371 L .6179 .68598 L p .707 .577 .707 r
F P
0 g
s
.6179 .68598 m .60909 .63219 L .63998 .62992 L p .707 .577 .707 r
F P
0 g
s
.62572 .74055 m .61623 .70598 L .64662 .70111 L p .707 .577 .707 r
F P
0 g
s
.62971 .78126 m .62461 .76416 L .65502 .75847 L p .707 .577 .707 r
F P
0 g
s
.60248 .30857 m .60248 .81046 L .62883 .80062 L p .707 .577 .707 r
F P
0 g
s
.64662 .70111 m .65612 .73568 L .62572 .74055 L p .707 .577 .707 r
F P
0 g
s
.62883 .80062 m .62883 .29874 L .60248 .30857 L p .707 .577 .707 r
F P
0 g
s
.31578 .63695 m .3196 .6941 L .34328 .68997 L p .707 .577 .707 r
F P
0 g
s
.34328 .68997 m .33946 .63281 L .31578 .63695 L p .707 .577 .707 r
F P
0 g
s
.29259 .71179 m .29678 .75001 L .32549 .74645 L p .707 .577 .707 r
F P
0 g
s
.32549 .74645 m .3213 .70823 L .29259 .71179 L p .707 .577 .707 r
F P
0 g
s
.68838 .63611 m .69719 .68989 L .6761 .68506 L p .707 .577 .707 r
F P
0 g
s
.6761 .68506 m .6673 .63127 L .68838 .63611 L p .707 .577 .707 r
F P
0 g
s
.27142 .79622 m .26915 .77712 L .23779 .78075 L p .707 .577 .707 r
F P
0 g
s
.26915 .77712 m .27142 .79622 L .30276 .79238 L p .707 .577 .707 r
F P
0 g
s
.30276 .79238 m .30049 .77329 L .26915 .77712 L p .707 .577 .707 r
F P
0 g
s
.23403 .75683 m .22984 .71861 L .20195 .72119 L p .707 .577 .707 r
F P
0 g
s
.23779 .78075 m .24006 .79985 L .27142 .79622 L p .707 .577 .707 r
F P
0 g
s
.20195 .72119 m .20614 .75941 L .23403 .75683 L p .707 .577 .707 r
F P
0 g
s
.19991 .70125 m .19609 .64409 L .17472 .64265 L p .707 .577 .707 r
F P
0 g
s
.24006 .79985 m .23779 .78075 L .20946 .78383 L p .707 .577 .707 r
F P
0 g
s
.30049 .77329 m .30276 .79238 L .331 .78872 L p .707 .577 .707 r
F P
0 g
s
.331 .78872 m .32873 .76963 L .30049 .77329 L p .707 .577 .707 r
F P
0 g
s
.20946 .78383 m .21173 .80292 L .24006 .79985 L p .707 .577 .707 r
F P
0 g
s
.17472 .64265 m .17854 .6998 L .19991 .70125 L p .707 .577 .707 r
F P
0 g
s
.3213 .70823 m .32549 .74645 L .34859 .74324 L p .707 .577 .707 r
F P
0 g
s
.34859 .74324 m .3444 .70502 L .3213 .70823 L p .707 .577 .707 r
F P
0 g
s
.20614 .75941 m .20195 .72119 L .18013 .72286 L p .707 .577 .707 r
F P
0 g
s
.18013 .72286 m .18431 .76108 L .20614 .75941 L p .707 .577 .707 r
F P
0 g
s
.71785 .76807 m .72294 .78517 L .70914 .77763 L p .707 .577 .707 r
F P
0 g
s
.70914 .77763 m .70404 .76052 L .71785 .76807 L p .707 .577 .707 r
F P
0 g
s
.33946 .63281 m .34328 .68997 L .35919 .68559 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .35538 .62843 L .33946 .63281 L p .707 .577 .707 r
F P
0 g
s
.21173 .80292 m .20946 .78383 L .18695 .78604 L p .707 .577 .707 r
F P
0 g
s
.32873 .76963 m .331 .78872 L .35339 .78559 L p .707 .577 .707 r
F P
0 g
s
.35339 .78559 m .35111 .76649 L .32873 .76963 L p .707 .577 .707 r
F P
0 g
s
.18695 .78604 m .18923 .80513 L .21173 .80292 L p .707 .577 .707 r
F P
0 g
s
.69474 .70433 m .70424 .7389 L .68317 .73511 L p .707 .577 .707 r
F P
0 g
s
.68317 .73511 m .67367 .70054 L .69474 .70433 L p .707 .577 .707 r
F P
0 g
s
.6673 .63127 m .6761 .68506 L .64878 .68371 L p .707 .577 .707 r
F P
0 g
s
.64878 .68371 m .63998 .62992 L .6673 .63127 L p .707 .577 .707 r
F P
0 g
s
.17854 .6998 m .17472 .64265 L .16171 .63999 L p .707 .577 .707 r
F P
0 g
s
.36545 .7642 m .36772 .78329 L .3726 .78206 L p .707 .577 .707 r
F P
0 g
s
.3726 .78206 m .37032 .76296 L .36545 .7642 L p .707 .577 .707 r
F P
0 g
s
.36772 .78329 m .36545 .7642 L .35111 .76649 L p .707 .577 .707 r
F P
0 g
s
.37032 .76296 m .3726 .78206 L .36754 .782 L p .707 .577 .707 r
F P
0 g
s
.37179 .80095 m .37179 .29907 L .35764 .28757 L p .707 .577 .707 r
F P
0 g
s
.37179 .29907 m .37179 .80095 L .39849 .81072 L p .707 .577 .707 r
F P
0 g
s
.65502 .75847 m .66012 .77557 L .62971 .78126 L p .707 .577 .707 r
F P
0 g
s
.62883 .29874 m .62883 .80062 L .64257 .78909 L p .707 .577 .707 r
F P
0 g
s
.64257 .78909 m .64257 .2872 L .62883 .29874 L p .707 .577 .707 r
F P
0 g
s
.3444 .70502 m .34859 .74324 L .36381 .74071 L p .707 .577 .707 r
F P
0 g
s
.36381 .74071 m .35962 .70249 L .3444 .70502 L p .707 .577 .707 r
F P
0 g
s
.16171 .63999 m .16553 .69715 L .17854 .6998 L p .707 .577 .707 r
F P
0 g
s
.18431 .76108 m .18013 .72286 L .16651 .72346 L p .707 .577 .707 r
F P
0 g
s
.16651 .72346 m .17069 .76168 L .18431 .76108 L p .707 .577 .707 r
F P
0 g
s
.18923 .80513 m .18695 .78604 L .17246 .78717 L p .707 .577 .707 r
F P
0 g
s
.35111 .76649 m .35339 .78559 L .36772 .78329 L p .707 .577 .707 r
F P
0 g
s
.17246 .78717 m .17474 .80627 L .18923 .80513 L p .707 .577 .707 r
F P
0 g
s
.70404 .76052 m .70914 .77763 L .68749 .77432 L p .707 .577 .707 r
F P
0 g
s
.68749 .77432 m .68239 .75721 L .70404 .76052 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35742 .27546 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35538 .62843 m .35822 .67104 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.36579 .68139 m .36197 .62424 L .35538 .62843 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .36579 .68139 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35822 .67104 m .35919 .68559 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35859 .62064 m .36241 .67779 L .3494 .67514 L p .707 .577 .707 r
F P
0 g
s
.3494 .67514 m .34558 .61798 L .35859 .62064 L p .707 .577 .707 r
F P
0 g
s
.35962 .70249 m .36381 .74071 L .36967 .7391 L p .707 .577 .707 r
F P
0 g
s
.36967 .7391 m .36548 .70088 L .35962 .70249 L p .707 .577 .707 r
F P
0 g
s
.3614 .70035 m .36559 .73857 L .35197 .73917 L p .707 .577 .707 r
F P
0 g
s
.35197 .73917 m .34778 .70095 L .3614 .70035 L p .707 .577 .707 r
F P
0 g
s
.36527 .76291 m .36754 .782 L .35305 .78314 L p .707 .577 .707 r
F P
0 g
s
.35305 .78314 m .35078 .76405 L .36527 .76291 L p .707 .577 .707 r
F P
0 g
s
.35764 .78946 m .35764 .39217 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35764 .39217 m .35764 .28757 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.67367 .70054 m .68317 .73511 L .65612 .73568 L p .707 .577 .707 r
F P
0 g
s
.65612 .73568 m .64662 .70111 L .67367 .70054 L p .707 .577 .707 r
F P
0 g
s
.16553 .69715 m .16171 .63999 L .15834 .63639 L p .707 .577 .707 r
F P
0 g
s
.15834 .63639 m .16215 .69354 L .16553 .69715 L p .707 .577 .707 r
F P
0 g
s
.17069 .76168 m .16651 .72346 L .16243 .72293 L p .707 .577 .707 r
F P
0 g
s
.68239 .75721 m .68749 .77432 L .66012 .77557 L p .707 .577 .707 r
F P
0 g
s
.66012 .77557 m .65502 .75847 L .68239 .75721 L p .707 .577 .707 r
F P
0 g
s
.16243 .72293 m .16661 .76115 L .17069 .76168 L p .707 .577 .707 r
F P
0 g
s
.17474 .80627 m .17246 .78717 L .16741 .78712 L p .707 .577 .707 r
F P
0 g
s
.16741 .78712 m .16968 .80621 L .17474 .80627 L p .707 .577 .707 r
F P
0 g
s
.36197 .62424 m .36579 .68139 L .36241 .67779 L p .707 .577 .707 r
F P
0 g
s
.36241 .67779 m .35859 .62064 L .36197 .62424 L p .707 .577 .707 r
F P
0 g
s
.36548 .70088 m .36967 .7391 L .36559 .73857 L p .707 .577 .707 r
F P
0 g
s
.36559 .73857 m .3614 .70035 L .36548 .70088 L p .707 .577 .707 r
F P
0 g
s
.36754 .782 m .36527 .76291 L .37032 .76296 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35764 .78946 L .37179 .80095 L p .707 .577 .707 r
F P
0 g
s
.64257 .2872 m .64257 .78909 L .64236 .77698 L p .708 .578 .707 r
F P
0 g
s
.64236 .77698 m .64236 .27509 L .64257 .2872 L p .708 .578 .707 r
F P
0 g
s
.16215 .69354 m .15834 .63639 L .16493 .6322 L p .707 .577 .707 r
F P
0 g
s
.16493 .6322 m .16875 .68935 L .16215 .69354 L p .707 .577 .707 r
F P
0 g
s
.16661 .76115 m .16243 .72293 L .16828 .72132 L p .707 .577 .707 r
F P
0 g
s
.16828 .72132 m .17247 .75953 L .16661 .76115 L p .707 .577 .707 r
F P
0 g
s
.16968 .80621 m .16741 .78712 L .17229 .78589 L p .707 .577 .707 r
F P
0 g
s
.17229 .78589 m .17456 .80498 L .16968 .80621 L p .707 .577 .707 r
F P
0 g
s
.35742 .27546 m .35742 .77735 L .35764 .78946 L p .708 .578 .707 r
F P
0 g
s
.35742 .77735 m .35742 .27546 L .37116 .26392 L p .707 .577 .707 r
F P
0 g
s
.64236 .27509 m .64236 .77698 L .62821 .76548 L p .707 .577 .707 r
F P
0 g
s
.62821 .76548 m .62821 .26359 L .64236 .27509 L p .707 .577 .707 r
F P
0 g
s
.16875 .68935 m .16493 .6322 L .18084 .62782 L p .707 .577 .707 r
F P
0 g
s
.18084 .62782 m .18466 .68497 L .16875 .68935 L p .707 .577 .707 r
F P
0 g
s
.17247 .75953 m .16828 .72132 L .18351 .71878 L p .707 .577 .707 r
F P
0 g
s
.18351 .71878 m .18769 .757 L .17247 .75953 L p .707 .577 .707 r
F P
0 g
s
.17456 .80498 m .17229 .78589 L .18662 .78359 L p .707 .577 .707 r
F P
0 g
s
.18662 .78359 m .18889 .80268 L .17456 .80498 L p .707 .577 .707 r
F P
0 g
s
.34558 .61798 m .3494 .67514 L .32803 .67369 L p .707 .577 .707 r
F P
0 g
s
.32803 .67369 m .32421 .61654 L .34558 .61798 L p .707 .577 .707 r
F P
0 g
s
.18466 .68497 m .18084 .62782 L .20452 .62368 L p .707 .577 .707 r
F P
0 g
s
.34778 .70095 m .35197 .73917 L .33014 .74084 L p .707 .577 .707 r
F P
0 g
s
.33014 .74084 m .32595 .70262 L .34778 .70095 L p .707 .577 .707 r
F P
0 g
s
.20452 .62368 m .20834 .68083 L .18466 .68497 L p .707 .577 .707 r
F P
0 g
s
.37116 .26392 m .37116 .76581 L .35742 .77735 L p .707 .577 .707 r
F P
0 g
s
.37116 .76581 m .37116 .26392 L .39752 .25409 L p .707 .577 .707 r
F P
0 g
s
.62821 .26359 m .62821 .76548 L .60151 .75572 L p .707 .577 .707 r
F P
0 g
s
.60151 .75572 m .60151 .25383 L .62821 .26359 L p .707 .577 .707 r
F P
0 g
s
.18769 .757 m .18351 .71878 L .2066 .71558 L p .707 .577 .707 r
F P
0 g
s
.2066 .71558 m .21079 .7538 L .18769 .757 L p .707 .577 .707 r
F P
0 g
s
.32421 .61654 m .32803 .67369 L .30039 .67359 L p .707 .577 .707 r
F P
0 g
s
.30039 .67359 m .29657 .61644 L .32421 .61654 L p .707 .577 .707 r
F P
0 g
s
.18889 .80268 m .18662 .78359 L .209 .78046 L p .707 .577 .707 r
F P
0 g
s
.35078 .76405 m .35305 .78314 L .33054 .78535 L p .707 .577 .707 r
F P
0 g
s
.33054 .78535 m .32827 .76626 L .35078 .76405 L p .707 .577 .707 r
F P
0 g
s
.209 .78046 m .21127 .79955 L .18889 .80268 L p .707 .577 .707 r
F P
0 g
s
.20834 .68083 m .20452 .62368 L .23364 .62019 L p .707 .577 .707 r
F P
0 g
s
.23364 .62019 m .23746 .67735 L .20834 .68083 L p .707 .577 .707 r
F P
0 g
s
.32595 .70262 m .33014 .74084 L .30225 .74342 L p .707 .577 .707 r
F P
0 g
s
.30225 .74342 m .29806 .7052 L .32595 .70262 L p .707 .577 .707 r
F P
0 g
s
.29657 .61644 m .30039 .67359 L .26918 .67485 L p .707 .577 .707 r
F P
0 g
s
.26918 .67485 m .26536 .6177 L .29657 .61644 L p .707 .577 .707 r
F P
0 g
s
.21079 .7538 m .2066 .71558 L .23531 .71201 L p .707 .577 .707 r
F P
0 g
s
.23746 .67735 m .23364 .62019 L .26536 .6177 L p .707 .577 .707 r
F P
0 g
s
.23531 .71201 m .2395 .75023 L .21079 .7538 L p .707 .577 .707 r
F P
0 g
s
.26536 .6177 m .26918 .67485 L .23746 .67735 L p .707 .577 .707 r
F P
0 g
s
.21127 .79955 m .209 .78046 L .23724 .77679 L p .707 .577 .707 r
F P
0 g
s
.32827 .76626 m .33054 .78535 L .30222 .78842 L p .707 .577 .707 r
F P
0 g
s
.30222 .78842 m .29995 .76933 L .32827 .76626 L p .707 .577 .707 r
F P
0 g
s
.23724 .77679 m .23952 .79589 L .21127 .79955 L p .707 .577 .707 r
F P
0 g
s
.73082 .66875 m .73464 .61625 L .70343 .61165 L p .707 .577 .707 r
F P
0 g
s
.73464 .61625 m .73082 .66875 L .76254 .66928 L p .707 .577 .707 r
F P
0 g
s
.76254 .66928 m .76636 .61678 L .73464 .61625 L p .707 .577 .707 r
F P
0 g
s
.39752 .75598 m .39752 .25409 L .4339 .24693 L p .707 .577 .707 r
F P
0 g
s
.39752 .25409 m .39752 .75598 L .37116 .76581 L p .707 .577 .707 r
F P
0 g
s
.60151 .25383 m .60151 .75572 L .56487 .74865 L p .707 .577 .707 r
F P
0 g
s
.56487 .74865 m .56487 .24676 L .60151 .25383 L p .707 .577 .707 r
F P
0 g
s
.29806 .7052 m .30225 .74342 L .27102 .74665 L p .707 .577 .707 r
F P
0 g
s
.27102 .74665 m .26683 .70844 L .29806 .7052 L p .707 .577 .707 r
F P
0 g
s
.76636 .61678 m .76254 .66928 L .79166 .6657 L p .707 .577 .707 r
F P
0 g
s
.79166 .6657 m .79548 .61319 L .76636 .61678 L p .707 .577 .707 r
F P
0 g
s
.2395 .75023 m .23531 .71201 L .26683 .70844 L p .707 .577 .707 r
F P
0 g
s
.69961 .66416 m .70343 .61165 L .67579 .60344 L p .707 .577 .707 r
F P
0 g
s
.70343 .61165 m .69961 .66416 L .73082 .66875 L p .707 .577 .707 r
F P
0 g
s
.26683 .70844 m .27102 .74665 L .2395 .75023 L p .707 .577 .707 r
F P
0 g
s
.23952 .79589 m .23724 .77679 L .26858 .77296 L p .707 .577 .707 r
F P
0 g
s
.29995 .76933 m .30222 .78842 L .27085 .79205 L p .707 .577 .707 r
F P
0 g
s
.27085 .79205 m .26858 .77296 L .29995 .76933 L p .707 .577 .707 r
F P
0 g
s
.26858 .77296 m .27085 .79205 L .23952 .79589 L p .707 .577 .707 r
F P
0 g
s
.79548 .61319 m .79166 .6657 L .81534 .65834 L p .707 .577 .707 r
F P
0 g
s
.81534 .65834 m .81916 .60584 L .79548 .61319 L p .707 .577 .707 r
F P
0 g
s
.67197 .65594 m .67579 .60344 L .65441 .59241 L p .707 .577 .707 r
F P
0 g
s
.67579 .60344 m .67197 .65594 L .69961 .66416 L p .707 .577 .707 r
F P
0 g
s
.4339 .74882 m .4339 .24693 L .47675 .24313 L p .707 .577 .707 r
F P
0 g
s
.4339 .24693 m .4339 .74882 L .39752 .75598 L p .707 .577 .707 r
F P
0 g
s
.56487 .24676 m .56487 .74865 L .52188 .74496 L p .707 .577 .707 r
F P
0 g
s
.52188 .74496 m .52188 .24307 L .56487 .24676 L p .707 .577 .707 r
F P
0 g
s
.72898 .73455 m .73317 .70122 L .70194 .69535 L p .707 .577 .707 r
F P
0 g
s
.73317 .70122 m .72898 .73455 L .7605 .73554 L p .707 .577 .707 r
F P
0 g
s
.7605 .73554 m .76468 .70222 L .73317 .70122 L p .707 .577 .707 r
F P
0 g
s
.81916 .60584 m .81534 .65834 L .83125 .64794 L p .707 .577 .707 r
F P
0 g
s
.83125 .64794 m .83507 .59543 L .81916 .60584 L p .707 .577 .707 r
F P
0 g
s
.69775 .72868 m .70194 .69535 L .67404 .68518 L p .707 .577 .707 r
F P
0 g
s
.70194 .69535 m .69775 .72868 L .72898 .73455 L p .707 .577 .707 r
F P
0 g
s
.65059 .64491 m .65441 .59241 L .6414 .57965 L p .707 .577 .707 r
F P
0 g
s
.65441 .59241 m .65059 .64491 L .67197 .65594 L p .707 .577 .707 r
F P
0 g
s
.76468 .70222 m .7605 .73554 L .78921 .73157 L p .707 .577 .707 r
F P
0 g
s
.78921 .73157 m .79339 .69824 L .76468 .70222 L p .707 .577 .707 r
F P
0 g
s
.47675 .74502 m .47675 .24313 L .52188 .24307 L p .707 .577 .707 r
F P
0 g
s
.47675 .24313 m .47675 .74502 L .4339 .74882 L p .707 .577 .707 r
F P
0 g
s
.52188 .24307 m .52188 .74496 L .47675 .74502 L p .707 .577 .707 r
F P
0 g
s
.66986 .71851 m .67404 .68518 L .65222 .67171 L p .707 .577 .707 r
F P
0 g
s
.67404 .68518 m .66986 .71851 L .69775 .72868 L p .707 .577 .707 r
F P
0 g
s
.79339 .69824 m .78921 .73157 L .8123 .72301 L p .707 .577 .707 r
F P
0 g
s
.8123 .72301 m .81649 .68968 L .79339 .69824 L p .707 .577 .707 r
F P
0 g
s
.83507 .59543 m .83125 .64794 L .83784 .6355 L p .707 .577 .707 r
F P
0 g
s
.83784 .6355 m .84166 .583 L .83507 .59543 L p .707 .577 .707 r
F P
0 g
s
.72914 .77601 m .73142 .75946 L .70005 .75377 L p .707 .577 .707 r
F P
0 g
s
.73142 .75946 m .72914 .77601 L .76048 .7767 L p .707 .577 .707 r
F P
0 g
s
.76048 .7767 m .76276 .76015 L .73142 .75946 L p .707 .577 .707 r
F P
0 g
s
.6414 .57965 m .63758 .63215 L .65059 .64491 L p .707 .577 .707 r
F P
0 g
s
.69778 .77032 m .70005 .75377 L .67173 .74365 L p .707 .577 .707 r
F P
0 g
s
.70005 .75377 m .69778 .77032 L .72914 .77601 L p .707 .577 .707 r
F P
0 g
s
.63758 .63215 m .6414 .57965 L .63803 .5664 L p .707 .577 .707 r
F P
0 g
s
.65222 .67171 m .64803 .70503 L .66986 .71851 L p .707 .577 .707 r
F P
0 g
s
.64803 .70503 m .65222 .67171 L .6386 .65625 L p .707 .577 .707 r
F P
0 g
s
.76276 .76015 m .76048 .7767 L .78873 .77233 L p .707 .577 .707 r
F P
0 g
s
.78873 .77233 m .791 .75578 L .76276 .76015 L p .707 .577 .707 r
F P
0 g
s
.81649 .68968 m .8123 .72301 L .82753 .7107 L p .707 .577 .707 r
F P
0 g
s
.82753 .7107 m .83171 .67738 L .81649 .68968 L p .707 .577 .707 r
F P
0 g
s
.67173 .74365 m .66945 .7602 L .69778 .77032 L p .707 .577 .707 r
F P
0 g
s
.66945 .7602 m .67173 .74365 L .64922 .73008 L p .707 .577 .707 r
F P
0 g
s
.791 .75578 m .78873 .77233 L .81111 .76332 L p .707 .577 .707 r
F P
0 g
s
.81111 .76332 m .81338 .74677 L .791 .75578 L p .707 .577 .707 r
F P
0 g
s
.64922 .73008 m .64695 .74662 L .66945 .7602 L p .707 .577 .707 r
F P
0 g
s
.6386 .65625 m .63441 .68957 L .64803 .70503 L p .707 .577 .707 r
F P
0 g
s
.63803 .5664 m .63421 .6189 L .63758 .63215 L p .707 .577 .707 r
F P
0 g
s
.84166 .583 m .83784 .6355 L .83447 .62226 L p .707 .577 .707 r
F P
0 g
s
.83447 .62226 m .83829 .56976 L .84166 .583 L p .707 .577 .707 r
F P
0 g
s
.63441 .68957 m .6386 .65625 L .63452 .64031 L p .707 .577 .707 r
F P
0 g
s
.64695 .74662 m .64922 .73008 L .63473 .71438 L p .707 .577 .707 r
F P
0 g
s
.63421 .6189 m .63803 .5664 L .64462 .55397 L p .707 .577 .707 r
F P
0 g
s
.83171 .67738 m .82753 .7107 L .83338 .69586 L p .707 .577 .707 r
F P
0 g
s
.83338 .69586 m .83757 .66253 L .83171 .67738 L p .707 .577 .707 r
F P
0 g
s
.63473 .71438 m .63246 .73093 L .64695 .74662 L p .707 .577 .707 r
F P
0 g
s
.81338 .74677 m .81111 .76332 L .82544 .75056 L p .707 .577 .707 r
F P
0 g
s
.82544 .75056 m .82771 .73402 L .81338 .74677 L p .707 .577 .707 r
F P
0 g
s
.63452 .64031 m .63033 .67364 L .63441 .68957 L p .707 .577 .707 r
F P
0 g
s
.63246 .73093 m .63473 .71438 L .62968 .69811 L p .707 .577 .707 r
F P
0 g
s
.64462 .55397 m .6408 .60647 L .63421 .6189 L p .707 .577 .707 r
F P
0 g
s
.83829 .56976 m .83447 .62226 L .82146 .6095 L p .707 .577 .707 r
F P
0 g
s
.82146 .6095 m .82528 .55699 L .83829 .56976 L p .707 .577 .707 r
F P
0 g
s
.63033 .67364 m .63452 .64031 L .64038 .62547 L p .707 .577 .707 r
F P
0 g
s
.6408 .60647 m .64462 .55397 L .66054 .54356 L p .707 .577 .707 r
F P
0 g
s
.3821 .61391 m .39091 .55808 L .36002 .55204 L p .707 .577 .707 r
F P
0 g
s
.39091 .55808 m .3821 .61391 L .41353 .61799 L p .707 .577 .707 r
F P
0 g
s
.41353 .61799 m .42234 .56216 L .39091 .55808 L p .707 .577 .707 r
F P
0 g
s
.83757 .66253 m .83338 .69586 L .8293 .67992 L p .707 .577 .707 r
F P
0 g
s
.8293 .67992 m .83349 .6466 L .83757 .66253 L p .707 .577 .707 r
F P
0 g
s
.62968 .69811 m .6274 .71466 L .63246 .73093 L p .707 .577 .707 r
F P
0 g
s
.42234 .56216 m .41353 .61799 L .44242 .61973 L p .707 .577 .707 r
F P
0 g
s
.44242 .61973 m .45123 .5639 L .42234 .56216 L p .707 .577 .707 r
F P
0 g
s
.35121 .60787 m .36002 .55204 L .3327 .54464 L p .707 .577 .707 r
F P
0 g
s
.36002 .55204 m .35121 .60787 L .3821 .61391 L p .707 .577 .707 r
F P
0 g
s
.82771 .73402 m .82544 .75056 L .83032 .7353 L p .707 .577 .707 r
F P
0 g
s
.83032 .7353 m .83259 .71875 L .82771 .73402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64038 .62547 m .63619 .65879 L .63033 .67364 L p .707 .577 .707 r
F P
0 g
s
.3327 .54464 m .32389 .60047 L .35121 .60787 L p .707 .577 .707 r
F P
0 g
s
.37427 .6705 m .38377 .63371 L .35338 .62508 L p .707 .577 .707 r
F P
0 g
s
.38377 .63371 m .37427 .6705 L .40503 .67763 L p .707 .577 .707 r
F P
0 g
s
.40503 .67763 m .41453 .64083 L .38377 .63371 L p .707 .577 .707 r
F P
0 g
s
.45123 .5639 m .44242 .61973 L .46595 .61895 L p .707 .577 .707 r
F P
0 g
s
.46595 .61895 m .47476 .56312 L .45123 .5639 L p .707 .577 .707 r
F P
0 g
s
.32389 .60047 m .3327 .54464 L .31162 .53661 L p .707 .577 .707 r
F P
0 g
s
.6274 .71466 m .62968 .69811 L .63455 .68285 L p .707 .577 .707 r
F P
0 g
s
.82528 .55699 m .82146 .6095 L .80009 .59847 L p .707 .577 .707 r
F P
0 g
s
.80009 .59847 m .80391 .54597 L .82528 .55699 L p .707 .577 .707 r
F P
0 g
s
.34388 .66188 m .35338 .62508 L .32632 .61579 L p .707 .577 .707 r
F P
0 g
s
.35338 .62508 m .34388 .66188 L .37427 .6705 L p .707 .577 .707 r
F P
0 g
s
.41453 .64083 m .40503 .67763 L .43314 .68256 L p .707 .577 .707 r
F P
0 g
s
.43314 .68256 m .44264 .64576 L .41453 .64083 L p .707 .577 .707 r
F P
0 g
s
.66054 .54356 m .65672 .59607 L .6408 .60647 L p .707 .577 .707 r
F P
0 g
s
.63619 .65879 m .64038 .62547 L .6556 .61316 L p .707 .577 .707 r
F P
0 g
s
.65672 .59607 m .66054 .54356 L .68421 .53621 L p .707 .577 .707 r
F P
0 g
s
.32632 .61579 m .31683 .65259 L .34388 .66188 L p .707 .577 .707 r
F P
0 g
s
.37029 .71285 m .37538 .6945 L .34497 .68547 L p .707 .577 .707 r
F P
0 g
s
.37538 .6945 m .37029 .71285 L .40077 .72043 L p .707 .577 .707 r
F P
0 g
s
.40077 .72043 m .40586 .70208 L .37538 .6945 L p .707 .577 .707 r
F P
0 g
s
.83349 .6466 m .8293 .67992 L .81569 .66446 L p .707 .577 .707 r
F P
0 g
s
.81569 .66446 m .81987 .63114 L .83349 .6466 L p .707 .577 .707 r
F P
0 g
s
.63455 .68285 m .63228 .6994 L .6274 .71466 L p .707 .577 .707 r
F P
0 g
s
.31162 .53661 m .30281 .59244 L .32389 .60047 L p .707 .577 .707 r
F P
0 g
s
.34497 .68547 m .33988 .70382 L .37029 .71285 L p .707 .577 .707 r
F P
0 g
s
.33988 .70382 m .34497 .68547 L .3176 .67588 L p .707 .577 .707 r
F P
0 g
s
.83259 .71875 m .83032 .7353 L .82526 .71903 L p .707 .577 .707 r
F P
0 g
s
.82526 .71903 m .82754 .70248 L .83259 .71875 L p .707 .577 .707 r
F P
0 g
s
.40586 .70208 m .40077 .72043 L .42833 .72583 L p .707 .577 .707 r
F P
0 g
s
.42833 .72583 m .43342 .70748 L .40586 .70208 L p .707 .577 .707 r
F P
0 g
s
.3176 .67588 m .31251 .69423 L .33988 .70382 L p .707 .577 .707 r
F P
0 g
s
.31683 .65259 m .32632 .61579 L .30526 .60676 L p .707 .577 .707 r
F P
0 g
s
.44264 .64576 m .43314 .68256 L .45585 .68481 L p .707 .577 .707 r
F P
0 g
s
.45585 .68481 m .46535 .64801 L .44264 .64576 L p .707 .577 .707 r
F P
0 g
s
.47476 .56312 m .46595 .61895 L .48181 .61573 L p .707 .577 .707 r
F P
0 g
s
.48181 .61573 m .49062 .5599 L .47476 .56312 L p .707 .577 .707 r
F P
0 g
s
.30526 .60676 m .29576 .64356 L .31683 .65259 L p .707 .577 .707 r
F P
0 g
s
.80391 .54597 m .80009 .59847 L .77244 .59025 L p .707 .577 .707 r
F P
0 g
s
.77244 .59025 m .77626 .53775 L .80391 .54597 L p .707 .577 .707 r
F P
0 g
s
.30281 .59244 m .31162 .53661 L .29884 .52873 L p .707 .577 .707 r
F P
0 g
s
.6556 .61316 m .65141 .64649 L .63619 .65879 L p .707 .577 .707 r
F P
0 g
s
.6804 .58871 m .68421 .53621 L .71334 .53262 L p .707 .577 .707 r
F P
0 g
s
.68421 .53621 m .6804 .58871 L .65672 .59607 L p .707 .577 .707 r
F P
0 g
s
.31251 .69423 m .3176 .67588 L .29596 .66668 L p .707 .577 .707 r
F P
0 g
s
.63228 .6994 m .63455 .68285 L .64888 .67009 L p .707 .577 .707 r
F P
0 g
s
.29596 .66668 m .29086 .68502 L .31251 .69423 L p .707 .577 .707 r
F P
0 g
s
.65141 .64649 m .6556 .61316 L .6787 .6046 L p .707 .577 .707 r
F P
0 g
s
.43342 .70748 m .42833 .72583 L .45027 .72852 L p .707 .577 .707 r
F P
0 g
s
.45027 .72852 m .45537 .71017 L .43342 .70748 L p .707 .577 .707 r
F P
0 g
s
.81987 .63114 m .81569 .66446 L .79386 .65099 L p .707 .577 .707 r
F P
0 g
s
.79386 .65099 m .79805 .61766 L .81987 .63114 L p .707 .577 .707 r
F P
0 g
s
.29884 .52873 m .29003 .58456 L .30281 .59244 L p .707 .577 .707 r
F P
0 g
s
.77626 .53775 m .77244 .59025 L .74124 .58566 L p .707 .577 .707 r
F P
0 g
s
.74124 .58566 m .74505 .53315 L .77626 .53775 L p .707 .577 .707 r
F P
0 g
s
.70952 .58512 m .71334 .53262 L .74505 .53315 L p .707 .577 .707 r
F P
0 g
s
.71334 .53262 m .70952 .58512 L .6804 .58871 L p .707 .577 .707 r
F P
0 g
s
.64888 .67009 m .64661 .68664 L .63228 .6994 L p .707 .577 .707 r
F P
0 g
s
.29576 .64356 m .30526 .60676 L .29224 .59886 L p .707 .577 .707 r
F P
0 g
s
.46535 .64801 m .45585 .68481 L .47094 .68416 L p .707 .577 .707 r
F P
0 g
s
.47094 .68416 m .48044 .64736 L .46535 .64801 L p .707 .577 .707 r
F P
0 g
s
.82754 .70248 m .82526 .71903 L .81077 .70334 L p .707 .577 .707 r
F P
0 g
s
.81077 .70334 m .81305 .68679 L .82754 .70248 L p .707 .577 .707 r
F P
0 g
s
.74505 .53315 m .74124 .58566 L .70952 .58512 L p .707 .577 .707 r
F P
0 g
s
.29224 .59886 m .28274 .63566 L .29576 .64356 L p .707 .577 .707 r
F P
0 g
s
.49062 .5599 m .48181 .61573 L .48846 .61038 L p .707 .577 .707 r
F P
0 g
s
.48846 .61038 m .49726 .55455 L .49062 .5599 L p .707 .577 .707 r
F P
0 g
s
.29086 .68502 m .29596 .66668 L .28215 .65875 L p .707 .577 .707 r
F P
0 g
s
.6787 .6046 m .67451 .63793 L .65141 .64649 L p .707 .577 .707 r
F P
0 g
s
.67451 .63793 m .6787 .6046 L .70741 .60062 L p .707 .577 .707 r
F P
0 g
s
.28215 .65875 m .27705 .6771 L .29086 .68502 L p .707 .577 .707 r
F P
0 g
s
.29003 .58456 m .29884 .52873 L .29561 .52178 L p .707 .577 .707 r
F P
0 g
s
.79805 .61766 m .79386 .65099 L .76597 .64082 L p .707 .577 .707 r
F P
0 g
s
.76597 .64082 m .77016 .60749 L .79805 .61766 L p .707 .577 .707 r
F P
0 g
s
.45537 .71017 m .45027 .72852 L .46445 .72823 L p .707 .577 .707 r
F P
0 g
s
.46445 .72823 m .46955 .70988 L .45537 .71017 L p .707 .577 .707 r
F P
0 g
s
.64661 .68664 m .64888 .67009 L .67127 .66108 L p .707 .577 .707 r
F P
0 g
s
.29561 .52178 m .28681 .57761 L .29003 .58456 L p .707 .577 .707 r
F P
0 g
s
.70322 .63395 m .70741 .60062 L .73892 .60162 L p .707 .577 .707 r
F P
0 g
s
.70741 .60062 m .70322 .63395 L .67451 .63793 L p .707 .577 .707 r
F P
0 g
s
.67127 .66108 m .66899 .67763 L .64661 .68664 L p .707 .577 .707 r
F P
0 g
s
.81305 .68679 m .81077 .70334 L .78826 .68976 L p .707 .577 .707 r
F P
0 g
s
.78826 .68976 m .79054 .67321 L .81305 .68679 L p .707 .577 .707 r
F P
0 g
s
.77016 .60749 m .76597 .64082 L .73474 .63495 L p .707 .577 .707 r
F P
0 g
s
.73474 .63495 m .73892 .60162 L .77016 .60749 L p .707 .577 .707 r
F P
0 g
s
.28274 .63566 m .29224 .59886 L .28854 .59288 L p .707 .577 .707 r
F P
0 g
s
.48044 .64736 m .47094 .68416 L .47693 .68067 L p .707 .577 .707 r
F P
0 g
s
.47693 .68067 m .48643 .64387 L .48044 .64736 L p .707 .577 .707 r
F P
0 g
s
.73892 .60162 m .73474 .63495 L .70322 .63395 L p .707 .577 .707 r
F P
0 g
s
.28854 .59288 m .27905 .62968 L .28274 .63566 L p .707 .577 .707 r
F P
0 g
s
.66899 .67763 m .67127 .66108 L .69951 .65671 L p .707 .577 .707 r
F P
0 g
s
.27705 .6771 m .28215 .65875 L .27753 .65288 L p .707 .577 .707 r
F P
0 g
s
.49726 .55455 m .48846 .61038 L .48523 .60342 L p .707 .577 .707 r
F P
0 g
s
.48523 .60342 m .49404 .54759 L .49726 .55455 L p .707 .577 .707 r
F P
0 g
s
.27753 .65288 m .27244 .67123 L .27705 .6771 L p .707 .577 .707 r
F P
0 g
s
.46955 .70988 m .46445 .72823 L .46948 .72499 L p .707 .577 .707 r
F P
0 g
s
.46948 .72499 m .47457 .70664 L .46955 .70988 L p .707 .577 .707 r
F P
0 g
s
.28681 .57761 m .29561 .52178 L .30226 .51642 L p .707 .577 .707 r
F P
0 g
s
.79054 .67321 m .78826 .68976 L .75994 .67964 L p .707 .577 .707 r
F P
0 g
s
.75994 .67964 m .76221 .66309 L .79054 .67321 L p .707 .577 .707 r
F P
0 g
s
.69951 .65671 m .69724 .67326 L .66899 .67763 L p .707 .577 .707 r
F P
0 g
s
.69724 .67326 m .69951 .65671 L .73085 .6574 L p .707 .577 .707 r
F P
0 g
s
.76221 .66309 m .75994 .67964 L .72857 .67395 L p .707 .577 .707 r
F P
0 g
s
.72857 .67395 m .73085 .6574 L .76221 .66309 L p .707 .577 .707 r
F P
0 g
s
.30226 .51642 m .29345 .57225 L .28681 .57761 L p .707 .577 .707 r
F P
0 g
s
.73085 .6574 m .72857 .67395 L .69724 .67326 L p .707 .577 .707 r
F P
0 g
s
.27905 .62968 m .28854 .59288 L .29453 .58939 L p .707 .577 .707 r
F P
0 g
s
.48643 .64387 m .47693 .68067 L .47324 .67468 L p .707 .577 .707 r
F P
0 g
s
.47324 .67468 m .48273 .63788 L .48643 .64387 L p .707 .577 .707 r
F P
0 g
s
.29453 .58939 m .28504 .62619 L .27905 .62968 L p .707 .577 .707 r
F P
0 g
s
.27244 .67123 m .27753 .65288 L .28256 .64964 L p .707 .577 .707 r
F P
0 g
s
.49404 .54759 m .48523 .60342 L .47245 .59554 L p .707 .577 .707 r
F P
0 g
s
.47245 .59554 m .48126 .53971 L .49404 .54759 L p .707 .577 .707 r
F P
0 g
s
.28256 .64964 m .27747 .66799 L .27244 .67123 L p .707 .577 .707 r
F P
0 g
s
.29345 .57225 m .30226 .51642 L .31812 .5132 L p .707 .577 .707 r
F P
0 g
s
.47457 .70664 m .46948 .72499 L .46486 .71912 L p .707 .577 .707 r
F P
0 g
s
.46486 .71912 m .46996 .70077 L .47457 .70664 L p .707 .577 .707 r
F P
0 g
s
.31812 .5132 m .30931 .56903 L .29345 .57225 L p .707 .577 .707 r
F P
0 g
s
.28504 .62619 m .29453 .58939 L .30962 .58874 L p .707 .577 .707 r
F P
0 g
s
.48273 .63788 m .47324 .67468 L .46022 .66678 L p .707 .577 .707 r
F P
0 g
s
.46022 .66678 m .46972 .62999 L .48273 .63788 L p .707 .577 .707 r
F P
0 g
s
.30962 .58874 m .30013 .62553 L .28504 .62619 L p .707 .577 .707 r
F P
0 g
s
.48126 .53971 m .47245 .59554 L .45137 .58751 L p .707 .577 .707 r
F P
0 g
s
.45137 .58751 m .46018 .53168 L .48126 .53971 L p .707 .577 .707 r
F P
0 g
s
.27747 .66799 m .28256 .64964 L .29674 .64935 L p .707 .577 .707 r
F P
0 g
s
.30931 .56903 m .31812 .5132 L .34165 .51242 L p .707 .577 .707 r
F P
0 g
s
.29674 .64935 m .29165 .6677 L .27747 .66799 L p .707 .577 .707 r
F P
0 g
s
.46996 .70077 m .46486 .71912 L .45106 .71119 L p .707 .577 .707 r
F P
0 g
s
.45106 .71119 m .45615 .69284 L .46996 .70077 L p .707 .577 .707 r
F P
0 g
s
.34165 .51242 m .33284 .56825 L .30931 .56903 L p .707 .577 .707 r
F P
0 g
s
.30013 .62553 m .30962 .58874 L .33233 .59098 L p .707 .577 .707 r
F P
0 g
s
.46972 .62999 m .46022 .66678 L .43915 .65775 L p .707 .577 .707 r
F P
0 g
s
.43915 .65775 m .44865 .62095 L .46972 .62999 L p .707 .577 .707 r
F P
0 g
s
.46018 .53168 m .45137 .58751 L .42405 .58012 L p .707 .577 .707 r
F P
0 g
s
.42405 .58012 m .43286 .52429 L .46018 .53168 L p .707 .577 .707 r
F P
0 g
s
.33284 .56825 m .34165 .51242 L .37054 .51416 L p .707 .577 .707 r
F P
0 g
s
.33233 .59098 m .32284 .62778 L .30013 .62553 L p .707 .577 .707 r
F P
0 g
s
.29165 .6677 m .29674 .64935 L .31869 .65203 L p .707 .577 .707 r
F P
0 g
s
.31869 .65203 m .31359 .67038 L .29165 .6677 L p .707 .577 .707 r
F P
0 g
s
.45615 .69284 m .45106 .71119 L .42941 .70198 L p .707 .577 .707 r
F P
0 g
s
.42941 .70198 m .4345 .68363 L .45615 .69284 L p .707 .577 .707 r
F P
0 g
s
.37054 .51416 m .36173 .56999 L .33284 .56825 L p .707 .577 .707 r
F P
0 g
s
.43286 .52429 m .42405 .58012 L .39316 .57408 L p .707 .577 .707 r
F P
0 g
s
.39316 .57408 m .40197 .51825 L .43286 .52429 L p .707 .577 .707 r
F P
0 g
s
.36173 .56999 m .37054 .51416 L .40197 .51825 L p .707 .577 .707 r
F P
0 g
s
.32284 .62778 m .33233 .59098 L .36044 .59591 L p .707 .577 .707 r
F P
0 g
s
.40197 .51825 m .39316 .57408 L .36173 .56999 L p .707 .577 .707 r
F P
0 g
s
.44865 .62095 m .43915 .65775 L .4121 .64847 L p .707 .577 .707 r
F P
0 g
s
.4121 .64847 m .42159 .61167 L .44865 .62095 L p .707 .577 .707 r
F P
0 g
s
.36044 .59591 m .35095 .63271 L .32284 .62778 L p .707 .577 .707 r
F P
0 g
s
.31359 .67038 m .31869 .65203 L .34624 .65743 L p .707 .577 .707 r
F P
0 g
s
.34624 .65743 m .34115 .67578 L .31359 .67038 L p .707 .577 .707 r
F P
0 g
s
.4345 .68363 m .42941 .70198 L .40204 .69239 L p .707 .577 .707 r
F P
0 g
s
.40204 .69239 m .40713 .67405 L .4345 .68363 L p .707 .577 .707 r
F P
0 g
s
.35095 .63271 m .36044 .59591 L .3912 .60304 L p .707 .577 .707 r
F P
0 g
s
.42159 .61167 m .4121 .64847 L .38171 .63984 L p .707 .577 .707 r
F P
0 g
s
.38171 .63984 m .3912 .60304 L .42159 .61167 L p .707 .577 .707 r
F P
0 g
s
.3912 .60304 m .38171 .63984 L .35095 .63271 L p .707 .577 .707 r
F P
0 g
s
.34115 .67578 m .34624 .65743 L .37672 .66502 L p .707 .577 .707 r
F P
0 g
s
.40713 .67405 m .40204 .69239 L .37163 .68337 L p .707 .577 .707 r
F P
0 g
s
.37163 .68337 m .37672 .66502 L .40713 .67405 L p .707 .577 .707 r
F P
0 g
s
.37672 .66502 m .37163 .68337 L .34115 .67578 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007Aoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00L7oo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001^
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000Kgoo001[Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`00K7oo001YOol20006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2001ZOol006Qoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8006Uoo`00IWoo0P0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000006Moo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol005Qoo`h000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool005Eoo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00003
0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000047oo4@00AGoo001COol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Woo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P00?goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Woo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00Dgoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000j
Ool005=oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000hOol0059oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<003Ioo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008003Aoo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000a
Ool0059oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
031oo`00DWoo00AJEP00FUIJEP`000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000_Ool0055oo`03001JEP00
00800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0055oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00H0
05YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60006FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06
001JEUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0059oo`05001J
EUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001COol800000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH01000FUIJEUYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF1P004Goo
1P001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20004FUH00`00FUIJEP070002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH0
0UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF
00<005YF00000`007Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20003
FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF0P000UYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000=JEP<0029oo`<00003FUH005YF00AJEP07001JEUYFFUH005YF0000;Goo001A
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF0P001Woo2@0057oo0P001EYF00L005YFFUIJ
EP00FUH0000]Ool0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUH005YF0`0000=JEP00FUH00eYF1P0015YF00<005YFFUH0
0UYF20003Woo0P000eYF00L005YFFUIJEP00FUH0000]Ool0055oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00
FUH00002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP06FUH01000FUIJEUYF1P002Woo0P0000=J
EP00FUH00UYF00<005YF0000;Goo001AOol00eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJ
EP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001Woo0`00
00=JEP0000000eYF0P00;Woo001@Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00@005YFFUIJEP80
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH30004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YF0000
0UYF0P00;Woo0017Ool:00000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH00P002eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00@002ioo`00?goo2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEPX000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEP00001JEP0200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP02FUH2000^Ool003Moo`P000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF009JEP<002ioo`00
<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH3000015YF001JEUYF
1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP<002ioo`00;Woo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`0035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJEP03
001JEUYF00EJEP03001JEUYF00EJEP800004FUH005YF000^Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF009J
EPH0009JEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP80
0003FUH0000002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEP0000800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUH000000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH015YF00D005YFFUIJEP00031oo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPT00003FUH005YF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF0000<7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000020003FUH00`00FUIJEP070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUH005YF0P000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP8002moo`00;Goo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF
FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01`00FUIJEUYF001J
EP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00008000IJEP<0
00EJEPd000IJEP03001JEUYF00IJEP<000=JEP03001JEUYF009JEP8002moo`00;Goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP07001J
EUYFFUH005YF00002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF1P001eYF1P00
00=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH0
0eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP07FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP04FUH40005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40007FUH00`00FUH000040003FUH01000FUIJEP00;Woo000^Ool00eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH30007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH2000015YF001JEP000UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF000005YF00H000Eoo`04001JEUYF0002FUH00`00Oomoo`0/
Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP800003
FUH005YF00=JEPL000IJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00=JEP<00004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
000015YF001JEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000Yoo`03001JEP00009JEP03001oogoo02aoo`00;Woo00=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEPP00003FUH005YF00QJEP03
001JEUYF00AJEP@000MJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP8000EJEP03001JEUYF009JEPl000IJEP03
001JEUYF00AJEP8000Qoo`05001JEP00FUH0000_Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF009JEPP00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00=JEP<000=JEP@0
00MJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000AJEP00FUH000AJEPH0009JEP03001J
EUYF008000Qoo`@0009JEP03001JEUYF00EJEP<000Moo`800003FUH007oo02ioo`00;Woo00=JEP00
FUH00eYF00@005YFFUIJEPT000QJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEP0000<0
0003FUH005YF00@0009JEP03001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF
009JEP<0009JEP03001JEUYF009JEP03001JEUYF008000aoo`@000IJEP03001JEUYF008000Ioo`03
001JEP0002moo`00;Woo00=JEP00FUH00UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1UYF00<005YFFUH015YF100000=JEP00FUH01@001UYF00<005YFFUH01EYF3P0035YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00@005YF000000=JEP@000AJEP04
001JEP00000@Ool20004FUH00`00FUIJEP02FUH20003Ool200000eYF001oo`0^Ool002ioo`03FUH0
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF
00IJEP04001JEP000003FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30002FUH30005FUH00`00FUH00003
00001EYF001JEUYF00004Woo0`0000=JEP00FUH01EYF00@007oo001JEP80031oo`00;Woo00EJEP00
001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00MJEP03001JEUYF009JEP@000IJEP@000MJEP03001JEUYF008000MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP04001J
EUYFFUH40002FUH00`00Oomoo`0COol20006FUH20003FUH00`00Oomoo`0^Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00MJEP03001JEUYF00EJEP@000AJEP03001JEUYF008000AJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@0009JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@001Moo`8000AJEP04001JEP00FUH2000`Ool002moo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000=oo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00D000AJEP<00003FUH005YF00EJEP<000=JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00@0011oo`H0009JEP04001JEUYFFUH3000`Ool0035ooad000]oo`H00003FUH005YF00QJEP03
001JEUYF00AJEP@000AJEP8000IJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP80009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00<000AJEP80031oo`00D7oo2@000eYF00<005YFFUH010001UYF00<005YFFUH0
1eYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0`0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF0P000UYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<007ooOol0;goo0017Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP03FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002
FUH00`00FUH000020003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<Goo000oOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH005YF10001eYF00<005YFFUH01UYF00@005YFFUIJEP80
00=JEP04001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUH0
05YF001JEP00009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000hOol70003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUH000030002FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300001EYF000005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00L005YF001JEP00FUH00003FUH30007FUH00`00FUIJEP07FUH40005FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001oo`0_Ool0039oo`H0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000=JEP03001JEUYF00=JEP@000MJEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00AJEP8000IJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<00004Ool0
05YF000`Ool002ioo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001J
EP0000<0009JEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH01000FUIJEP001UYF0P0015YF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00L007ooOomoo`00FUH0000`Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00=JEPD000=JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80
00=JEP03001JEP0000MJEP@00003FUH005YF00MJEPH000=JEP03001JEUYF00EJEP04001JEUYFFUH2
0005Ool2000`Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00MJEPX0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000AJEP8000MJEP04001JEUYFFUH60004FUH00`00FUH000020004FUH00`00FUIJEP05FUH0
1000FUH000001goo0P00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003FUH30007FUH00`00FUIJEP02FUH00`00FUIJEP0:0004
FUH00`00FUIJEP02FUH50009Ool2000`Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP0:0003FUH01000FUH0
000027oo2@003Goo0`00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH<0003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP<000Ioo`@0009JEP03001oogoo01]oo`03001JEP00035oo`00
;goo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF20000UYF00@005YFFUIJEPH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20006FUH20006Ool00`00FUIJ
EP03000LOol01000FUH00000<Goo000_Ool00eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP02FUH70005Ool01@00FUIJEUYF00001eYF00<005YF
FUH01EYF2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@001eYF00<005YFFUH01EYF00@005YF
FUIJEP8000IJEP04001JEP000003Ool01`00FUIJEUYF001JEP0001Yoo`80009JEP03001oogoo031o
o`00;goo0UYF00D005YFFUIJEP0000EJEP03001JEUYF009JEPT0009JEP03001JEUYF009JEPT000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP050002FUH00`00FUIJEP05FUH01P00FUIJEUYF001oo`8000AJEP04001J
EUYFFUH30004FUH01000FUH000005Goo100000EJEP00FUIJEP00039oo`00;goo0UYF00D005YFFUIJ
EP0000=JEPL0009JEP03001JEUYF009JEPT001Eoo`05001JEUYFFUH00006FUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40006FUH01@00FUIJEUYF0000
0goo0P000UYF00<005YFFUH015YF1P0000=JEP00Ool04Goo0`001EYF00<005YF0000<goo000_Ool2
FUHF000NOol01@00FUIJEUYF000015YF0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF0`0015YF00H005YFFUIJEP00Ool70007FUH00`00FUIJ
EP02FUH90007Ool400000eYF001JEP04FUH00`00FUH0000dOol002moo`T002eoo`06001JEUYFFUH0
05YF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH00`0000=JEP00FUH00UYF0P000UYF00@005YFFUIJEP8000IJEP03001J
EUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF00=JEP8003Eoo`00FWoo30000eYF0P001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000EJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003Ioo`00DGoo2@000eYF00<005YFFUH00eYF00<0
05YF00000UYF0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00>7oo0018Ool90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUH005YF001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEP00008000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003]oo`00@7oo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF00D005YFFUIJEP00009JEPd000=JEP03001JEP000140
041oo`00>Goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP<000EJEP03001JEUYF00EJ
EP@000=JEP03001oogoo04eoo`00<goo1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05
001JEUYFFUH00007FUH00`00FUIJEP05FUH20002Ool200000eYF001oo`1>Ool002moo`@0009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPL0
0003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00
FUIJEP04FUH00`00Oomoo`03Ool2001?Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH0000000D000=oo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000025YF00<005YFFUH00UYF0P001Goo00@005YF000004ioo`00
;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4P002goo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF008000QJEP05001JEUYFFUH00007Ool01000FUIJEP00CWoo
000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA000EOol30007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH30002FUH00`00FUIJEP06FUH30007Ool20002FUH00`00Oomoo`1<Ool0031oo`03FUH005YF
009JEP04001JEUYFFUH@000POol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP05FUH20008
Ool01P00FUIJEP00FUH004ioo`00<7oo00=JEP0000003P00:Woo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP8000IJ
EP03001JEUYF00=JEP8000Uoo`04001JEUYFFUH2001?Ool0031oo`@003Uoo`<00003FUH005YF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000009
FUH00`00FUH00002000:Ool00`00FUIJEP03FUH00`00Oomoo`1=Ool0071oo`@000MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP@0
00]oo`<000EJEP03001oogoo04eoo`00M7oo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02`0000AJEP00FUIJEP@000ioo`05001JEUYFFUH00003FUH00`00Oomo
o`1>Ool007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000=JEP03001JEUYF00T0011o
o`8000AJEP04001JEUYF001AOol0085ooa/000=JEP03001JEUYF00EJEP03001JEP0000@001=oo`03
001JEUYF00EJEP80059oo`00UGoo00<005YF00000UYF00<007oo000040004Woo0`001eYF00<007oo
Ool0DGoo002EOol00`00FUIJEP02000SOol20003FUH00`00FUIJEP02FUH2001DOol009Eoo`04001J
EUYF000ROol20005FUH01@00FUIJEUYF0000EWoo002EOol00`00FUH0000POol30008FUH3001GOol0
09Ioo`03FUH007oo01]oo`@00003FUH005YF00MJEP8005Uoo`00UWoo0`005Woo1@001UYF00<005YF
FUH00eYF0P00Fgoo002FOol200000eYF00000002000>Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP03001MOol009Moo`04001JEUYF0002FUH>0006FUH00`00FUIJEP06FUH3001POol009Moo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<006=oo`00V7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008006Ioo`00VGoo0P00
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF1000JGoo002KOol40003FUH00`00FUIJ
EP04FUH00`00FUIJEP04001]Ool009moo`d0075oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60278 .75323 m .59733 .69857 L .56624 .69927 L p .707 .577 .707 r
F P
0 g
s
.59733 .69857 m .60278 .75323 L .63445 .7494 L p .707 .577 .707 r
F P
0 g
s
.63445 .7494 m .629 .69475 L .59733 .69857 L p .707 .577 .707 r
F P
0 g
s
.629 .69475 m .63445 .7494 L .6636 .74283 L p .707 .577 .707 r
F P
0 g
s
.6636 .74283 m .65815 .68818 L .629 .69475 L p .707 .577 .707 r
F P
0 g
s
.57169 .75393 m .56624 .69927 L .53878 .69678 L p .707 .577 .707 r
F P
0 g
s
.56624 .69927 m .57169 .75393 L .60278 .75323 L p .707 .577 .707 r
F P
0 g
s
.65815 .68818 m .6636 .74283 L .68739 .73415 L p .707 .577 .707 r
F P
0 g
s
.68739 .73415 m .68194 .6795 L .65815 .68818 L p .707 .577 .707 r
F P
0 g
s
.54423 .75144 m .53878 .69678 L .51764 .69134 L p .707 .577 .707 r
F P
0 g
s
.53878 .69678 m .54423 .75144 L .57169 .75393 L p .707 .577 .707 r
F P
0 g
s
.60991 .81555 m .60402 .77971 L .57309 .78206 L p .707 .577 .707 r
F P
0 g
s
.60402 .77971 m .60991 .81555 L .64131 .8098 L p .707 .577 .707 r
F P
0 g
s
.64131 .8098 m .63542 .77396 L .60402 .77971 L p .707 .577 .707 r
F P
0 g
s
.63542 .77396 m .64131 .8098 L .67011 .80122 L p .707 .577 .707 r
F P
0 g
s
.67011 .80122 m .66422 .76538 L .63542 .77396 L p .707 .577 .707 r
F P
0 g
s
.57898 .81791 m .57309 .78206 L .54566 .7808 L p .707 .577 .707 r
F P
0 g
s
.57309 .78206 m .57898 .81791 L .60991 .81555 L p .707 .577 .707 r
F P
0 g
s
.68194 .6795 m .68739 .73415 L .70348 .72422 L p .707 .577 .707 r
F P
0 g
s
.70348 .72422 m .69803 .66956 L .68194 .6795 L p .707 .577 .707 r
F P
0 g
s
.66422 .76538 m .67011 .80122 L .69349 .79065 L p .707 .577 .707 r
F P
0 g
s
.69349 .79065 m .6876 .7548 L .66422 .76538 L p .707 .577 .707 r
F P
0 g
s
.51764 .69134 m .52309 .746 L .54423 .75144 L p .707 .577 .707 r
F P
0 g
s
.61615 .85742 m .61299 .83958 L .582 .84242 L p .707 .577 .707 r
F P
0 g
s
.61299 .83958 m .61615 .85742 L .64742 .85114 L p .707 .577 .707 r
F P
0 g
s
.64742 .85114 m .64427 .8333 L .61299 .83958 L p .707 .577 .707 r
F P
0 g
s
.54566 .7808 m .55155 .81664 L .57898 .81791 L p .707 .577 .707 r
F P
0 g
s
.52309 .746 m .51764 .69134 L .50489 .68349 L p .707 .577 .707 r
F P
0 g
s
.64427 .8333 m .64742 .85114 L .67592 .84204 L p .707 .577 .707 r
F P
0 g
s
.67592 .84204 m .67276 .82419 L .64427 .8333 L p .707 .577 .707 r
F P
0 g
s
.55155 .81664 m .54566 .7808 L .52441 .77603 L p .707 .577 .707 r
F P
0 g
s
.582 .84242 m .58516 .86027 L .61615 .85742 L p .707 .577 .707 r
F P
0 g
s
.58516 .86027 m .582 .84242 L .55433 .84155 L p .707 .577 .707 r
F P
0 g
s
.6876 .7548 m .69349 .79065 L .70915 .77912 L p .707 .577 .707 r
F P
0 g
s
.70915 .77912 m .70326 .74327 L .6876 .7548 L p .707 .577 .707 r
F P
0 g
s
.67276 .82419 m .67592 .84204 L .69885 .83101 L p .707 .577 .707 r
F P
0 g
s
.69885 .83101 m .6957 .81316 L .67276 .82419 L p .707 .577 .707 r
F P
0 g
s
.55433 .84155 m .55749 .8594 L .58516 .86027 L p .707 .577 .707 r
F P
0 g
s
.69803 .66956 m .70348 .72422 L .7103 .714 L p .707 .577 .707 r
F P
0 g
s
.7103 .714 m .70484 .65934 L .69803 .66956 L p .707 .577 .707 r
F P
0 g
s
.52441 .77603 m .5303 .81187 L .55155 .81664 L p .707 .577 .707 r
F P
0 g
s
.50489 .68349 m .51034 .73814 L .52309 .746 L p .707 .577 .707 r
F P
0 g
s
.55749 .8594 m .55433 .84155 L .53269 .83705 L p .707 .577 .707 r
F P
0 g
s
.5303 .81187 m .52441 .77603 L .51143 .76822 L p .707 .577 .707 r
F P
0 g
s
.53269 .83705 m .53584 .8549 L .55749 .8594 L p .707 .577 .707 r
F P
0 g
s
.51034 .73814 m .50489 .68349 L .50176 .67398 L p .707 .577 .707 r
F P
0 g
s
.6957 .81316 m .69885 .83101 L .71397 .81913 L p .707 .577 .707 r
F P
0 g
s
.71397 .81913 m .71082 .80128 L .6957 .81316 L p .707 .577 .707 r
F P
0 g
s
.70326 .74327 m .70915 .77912 L .71557 .76776 L p .707 .577 .707 r
F P
0 g
s
.71557 .76776 m .70968 .73192 L .70326 .74327 L p .707 .577 .707 r
F P
0 g
s
.51143 .76822 m .51732 .80407 L .5303 .81187 L p .707 .577 .707 r
F P
0 g
s
.70484 .65934 m .7103 .714 L .70717 .70449 L p .707 .577 .707 r
F P
0 g
s
.70717 .70449 m .70172 .64984 L .70484 .65934 L p .707 .577 .707 r
F P
0 g
s
.53584 .8549 m .53269 .83705 L .51919 .82936 L p .707 .577 .707 r
F P
0 g
s
.50176 .67398 m .50721 .72864 L .51034 .73814 L p .707 .577 .707 r
F P
0 g
s
.51919 .82936 m .52234 .84721 L .53584 .8549 L p .707 .577 .707 r
F P
0 g
s
.51732 .80407 m .51143 .76822 L .50798 .75815 L p .707 .577 .707 r
F P
0 g
s
.50721 .72864 m .50176 .67398 L .50858 .66376 L p .707 .577 .707 r
F P
0 g
s
.50798 .75815 m .51387 .79399 L .51732 .80407 L p .707 .577 .707 r
F P
0 g
s
.50858 .66376 m .51403 .71842 L .50721 .72864 L p .707 .577 .707 r
F P
0 g
s
.51387 .79399 m .50798 .75815 L .5144 .74679 L p .707 .577 .707 r
F P
0 g
s
.51403 .71842 m .50858 .66376 L .52467 .65383 L p .707 .577 .707 r
F P
0 g
s
.51076 .82181 m .51076 .31993 L .46579 .31893 L p .707 .577 .707 r
F P
0 g
s
.52234 .84721 m .51919 .82936 L .51516 .81924 L p .707 .577 .707 r
F P
0 g
s
.51516 .81924 m .51831 .83708 L .52234 .84721 L p .707 .577 .707 r
F P
0 g
s
.5144 .74679 m .52029 .78264 L .51387 .79399 L p .707 .577 .707 r
F P
0 g
s
.51831 .83708 m .51516 .81924 L .52099 .80767 L p .707 .577 .707 r
F P
0 g
s
.52467 .65383 m .53012 .70848 L .51403 .71842 L p .707 .577 .707 r
F P
0 g
s
.52099 .80767 m .52414 .82551 L .51831 .83708 L p .707 .577 .707 r
F P
0 g
s
.52029 .78264 m .5144 .74679 L .53007 .73526 L p .707 .577 .707 r
F P
0 g
s
.53012 .70848 m .52467 .65383 L .54846 .64515 L p .707 .577 .707 r
F P
0 g
s
.53007 .73526 m .53596 .77111 L .52029 .78264 L p .707 .577 .707 r
F P
0 g
s
.54846 .64515 m .55391 .6998 L .53012 .70848 L p .707 .577 .707 r
F P
0 g
s
.52414 .82551 m .52099 .80767 L .53611 .79578 L p .707 .577 .707 r
F P
0 g
s
.53611 .79578 m .53927 .81363 L .52414 .82551 L p .707 .577 .707 r
F P
0 g
s
.53596 .77111 m .53007 .73526 L .55344 .72469 L p .707 .577 .707 r
F P
0 g
s
.55344 .72469 m .55933 .76053 L .53596 .77111 L p .707 .577 .707 r
F P
0 g
s
.53927 .81363 m .53611 .79578 L .55904 .78475 L p .707 .577 .707 r
F P
0 g
s
.55904 .78475 m .5622 .8026 L .53927 .81363 L p .707 .577 .707 r
F P
0 g
s
.51076 .31993 m .51076 .82181 L .55469 .81903 L p .707 .577 .707 r
F P
0 g
s
.55391 .6998 m .54846 .64515 L .57761 .63857 L p .707 .577 .707 r
F P
0 g
s
.57761 .63857 m .58306 .69323 L .55391 .6998 L p .707 .577 .707 r
F P
0 g
s
.55933 .76053 m .55344 .72469 L .58224 .71611 L p .707 .577 .707 r
F P
0 g
s
.55469 .81903 m .55469 .31715 L .51076 .31993 L p .707 .577 .707 r
F P
0 g
s
.71082 .80128 m .71397 .81913 L .71981 .80756 L p .707 .577 .707 r
F P
0 g
s
.71981 .80756 m .71665 .78971 L .71082 .80128 L p .707 .577 .707 r
F P
0 g
s
.46579 .82082 m .46579 .31893 L .42416 .31425 L p .707 .577 .707 r
F P
0 g
s
.46579 .31893 m .46579 .82082 L .51076 .82181 L p .707 .577 .707 r
F P
0 g
s
.58306 .69323 m .57761 .63857 L .60928 .63475 L p .707 .577 .707 r
F P
0 g
s
.60928 .63475 m .61473 .68941 L .58306 .69323 L p .707 .577 .707 r
F P
0 g
s
.58813 .75195 m .58224 .71611 L .61364 .71036 L p .707 .577 .707 r
F P
0 g
s
.58224 .71611 m .58813 .75195 L .55933 .76053 L p .707 .577 .707 r
F P
0 g
s
.61364 .71036 m .61953 .7462 L .58813 .75195 L p .707 .577 .707 r
F P
0 g
s
.5622 .8026 m .55904 .78475 L .58754 .77565 L p .707 .577 .707 r
F P
0 g
s
.58754 .77565 m .5907 .7935 L .5622 .8026 L p .707 .577 .707 r
F P
0 g
s
.5907 .7935 m .58754 .77565 L .61882 .76937 L p .707 .577 .707 r
F P
0 g
s
.61882 .76937 m .62197 .78722 L .5907 .7935 L p .707 .577 .707 r
F P
0 g
s
.55469 .31715 m .55469 .81903 L .59326 .81275 L p .707 .577 .707 r
F P
0 g
s
.59326 .81275 m .59326 .31086 L .55469 .31715 L p .707 .577 .707 r
F P
0 g
s
.70968 .73192 m .71557 .76776 L .71212 .75769 L p .707 .577 .707 r
F P
0 g
s
.71212 .75769 m .70623 .72184 L .70968 .73192 L p .707 .577 .707 r
F P
0 g
s
.70172 .64984 m .70717 .70449 L .69442 .69664 L p .707 .577 .707 r
F P
0 g
s
.69442 .69664 m .68897 .64198 L .70172 .64984 L p .707 .577 .707 r
F P
0 g
s
.42416 .81614 m .42416 .31425 L .38995 .30635 L p .707 .577 .707 r
F P
0 g
s
.42416 .31425 m .42416 .81614 L .46579 .82082 L p .707 .577 .707 r
F P
0 g
s
.25655 .70503 m .2542 .64828 L .223 .64833 L p .707 .577 .707 r
F P
0 g
s
.2542 .64828 m .25655 .70503 L .28833 .70319 L p .707 .577 .707 r
F P
0 g
s
.28833 .70319 m .28599 .64645 L .2542 .64828 L p .707 .577 .707 r
F P
0 g
s
.28599 .64645 m .28833 .70319 L .31758 .69974 L p .707 .577 .707 r
F P
0 g
s
.31758 .69974 m .31523 .643 L .28599 .64645 L p .707 .577 .707 r
F P
0 g
s
.71665 .78971 m .71981 .80756 L .71577 .79743 L p .707 .577 .707 r
F P
0 g
s
.71577 .79743 m .71262 .77958 L .71665 .78971 L p .707 .577 .707 r
F P
0 g
s
.64037 .63405 m .64582 .68871 L .61473 .68941 L p .707 .577 .707 r
F P
0 g
s
.61473 .68941 m .60928 .63475 L .64037 .63405 L p .707 .577 .707 r
F P
0 g
s
.61953 .7462 m .61364 .71036 L .64457 .708 L p .707 .577 .707 r
F P
0 g
s
.62197 .78722 m .61882 .76937 L .64981 .76653 L p .707 .577 .707 r
F P
0 g
s
.59326 .31086 m .59326 .81275 L .6227 .80357 L p .707 .577 .707 r
F P
0 g
s
.64457 .708 m .65046 .74384 L .61953 .7462 L p .707 .577 .707 r
F P
0 g
s
.64981 .76653 m .65296 .78437 L .62197 .78722 L p .707 .577 .707 r
F P
0 g
s
.6227 .80357 m .6227 .30168 L .59326 .31086 L p .707 .577 .707 r
F P
0 g
s
.22534 .70507 m .223 .64833 L .19541 .64659 L p .707 .577 .707 r
F P
0 g
s
.223 .64833 m .22534 .70507 L .25655 .70503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70623 .72184 m .71212 .75769 L .69914 .74988 L p .707 .577 .707 r
F P
0 g
s
.69914 .74988 m .69325 .71404 L .70623 .72184 L p .707 .577 .707 r
F P
0 g
s
.31523 .643 m .31758 .69974 L .34142 .69502 L p .707 .577 .707 r
F P
0 g
s
.34142 .69502 m .33907 .63828 L .31523 .643 L p .707 .577 .707 r
F P
0 g
s
.26049 .76122 m .25793 .72312 L .22668 .72442 L p .707 .577 .707 r
F P
0 g
s
.25793 .72312 m .26049 .76122 L .29218 .75869 L p .707 .577 .707 r
F P
0 g
s
.29218 .75869 m .28962 .72059 L .25793 .72312 L p .707 .577 .707 r
F P
0 g
s
.19541 .64659 m .19776 .70333 L .22534 .70507 L p .707 .577 .707 r
F P
0 g
s
.68897 .64198 m .69442 .69664 L .67328 .6912 L p .707 .577 .707 r
F P
0 g
s
.67328 .6912 m .66782 .63654 L .68897 .64198 L p .707 .577 .707 r
F P
0 g
s
.28962 .72059 m .29218 .75869 L .32121 .75517 L p .707 .577 .707 r
F P
0 g
s
.32121 .75517 m .31865 .71707 L .28962 .72059 L p .707 .577 .707 r
F P
0 g
s
.22668 .72442 m .22924 .76252 L .26049 .76122 L p .707 .577 .707 r
F P
0 g
s
.38995 .80824 m .38995 .30635 L .36652 .296 L p .707 .577 .707 r
F P
0 g
s
.38995 .30635 m .38995 .80824 L .42416 .81614 L p .707 .577 .707 r
F P
0 g
s
.22924 .76252 m .22668 .72442 L .19892 .72436 L p .707 .577 .707 r
F P
0 g
s
.19776 .70333 m .19541 .64659 L .17416 .64322 L p .707 .577 .707 r
F P
0 g
s
.26429 .80343 m .26291 .78437 L .23155 .78596 L p .707 .577 .707 r
F P
0 g
s
.26291 .78437 m .26429 .80343 L .29589 .80069 L p .707 .577 .707 r
F P
0 g
s
.29589 .80069 m .29451 .78163 L .26291 .78437 L p .707 .577 .707 r
F P
0 g
s
.19892 .72436 m .20148 .76246 L .22924 .76252 L p .707 .577 .707 r
F P
0 g
s
.23155 .78596 m .23293 .80502 L .26429 .80343 L p .707 .577 .707 r
F P
0 g
s
.29451 .78163 m .29589 .80069 L .32465 .79708 L p .707 .577 .707 r
F P
0 g
s
.32465 .79708 m .32327 .77802 L .29451 .78163 L p .707 .577 .707 r
F P
0 g
s
.23293 .80502 m .23155 .78596 L .20351 .78625 L p .707 .577 .707 r
F P
0 g
s
.31865 .71707 m .32121 .75517 L .34474 .751 L p .707 .577 .707 r
F P
0 g
s
.34474 .751 m .34218 .7129 L .31865 .71707 L p .707 .577 .707 r
F P
0 g
s
.17416 .64322 m .17651 .69996 L .19776 .70333 L p .707 .577 .707 r
F P
0 g
s
.20351 .78625 m .20489 .80531 L .23293 .80502 L p .707 .577 .707 r
F P
0 g
s
.71262 .77958 m .71577 .79743 L .70228 .78974 L p .707 .577 .707 r
F P
0 g
s
.70228 .78974 m .69912 .7719 L .71262 .77958 L p .707 .577 .707 r
F P
0 g
s
.33907 .63828 m .34142 .69502 L .35753 .68949 L p .707 .577 .707 r
F P
0 g
s
.35753 .68949 m .35518 .63275 L .33907 .63828 L p .707 .577 .707 r
F P
0 g
s
.6227 .30168 m .6227 .80357 L .64013 .7924 L p .707 .577 .707 r
F P
0 g
s
.64013 .7924 m .64013 .29051 L .6227 .30168 L p .707 .577 .707 r
F P
0 g
s
.20148 .76246 m .19892 .72436 L .17738 .72293 L p .707 .577 .707 r
F P
0 g
s
.69325 .71404 m .69914 .74988 L .67789 .74511 L p .707 .577 .707 r
F P
0 g
s
.67789 .74511 m .672 .70927 L .69325 .71404 L p .707 .577 .707 r
F P
0 g
s
.66782 .63654 m .67328 .6912 L .64582 .68871 L p .707 .577 .707 r
F P
0 g
s
.64582 .68871 m .64037 .63405 L .66782 .63654 L p .707 .577 .707 r
F P
0 g
s
.17738 .72293 m .17994 .76103 L .20148 .76246 L p .707 .577 .707 r
F P
0 g
s
.32327 .77802 m .32465 .79708 L .34776 .79293 L p .707 .577 .707 r
F P
0 g
s
.34776 .79293 m .34638 .77387 L .32327 .77802 L p .707 .577 .707 r
F P
0 g
s
.17651 .69996 m .17416 .64322 L .16132 .63855 L p .707 .577 .707 r
F P
0 g
s
.20489 .80531 m .20351 .78625 L .18153 .7852 L p .707 .577 .707 r
F P
0 g
s
.18153 .7852 m .18291 .80426 L .20489 .80531 L p .707 .577 .707 r
F P
0 g
s
.34218 .7129 m .34474 .751 L .36045 .7466 L p .707 .577 .707 r
F P
0 g
s
.36045 .7466 m .35789 .7085 L .34218 .7129 L p .707 .577 .707 r
F P
0 g
s
.16132 .63855 m .16367 .69529 L .17651 .69996 L p .707 .577 .707 r
F P
0 g
s
.35518 .63275 m .35753 .68949 L .36433 .68369 L p .707 .577 .707 r
F P
0 g
s
.36433 .68369 m .36198 .62695 L .35518 .63275 L p .707 .577 .707 r
F P
0 g
s
.35789 .7085 m .36045 .7466 L .36682 .74239 L p .707 .577 .707 r
F P
0 g
s
.36682 .74239 m .36426 .70429 L .35789 .7085 L p .707 .577 .707 r
F P
0 g
s
.36156 .76961 m .36294 .78867 L .36871 .7847 L p .707 .577 .707 r
F P
0 g
s
.36871 .7847 m .36733 .76564 L .36156 .76961 L p .707 .577 .707 r
F P
0 g
s
.36198 .62695 m .36433 .68369 L .36115 .67819 L p .707 .577 .707 r
F P
0 g
s
.36426 .70429 m .36682 .74239 L .36323 .73879 L p .707 .577 .707 r
F P
0 g
s
.36733 .76564 m .36871 .7847 L .36451 .78142 L p .707 .577 .707 r
F P
0 g
s
.36451 .78142 m .36313 .76236 L .36733 .76564 L p .707 .577 .707 r
F P
0 g
s
.36652 .79789 m .36652 .296 L .35616 .28422 L p .707 .577 .707 r
F P
0 g
s
.36652 .296 m .36652 .79789 L .38995 .80824 L p .707 .577 .707 r
F P
0 g
s
.17994 .76103 m .17738 .72293 L .16417 .72029 L p .707 .577 .707 r
F P
0 g
s
.69912 .7719 m .70228 .78974 L .68063 .78524 L p .707 .577 .707 r
F P
0 g
s
.68063 .78524 m .67748 .7674 L .69912 .7719 L p .707 .577 .707 r
F P
0 g
s
.34638 .77387 m .34776 .79293 L .36294 .78867 L p .707 .577 .707 r
F P
0 g
s
.36294 .78867 m .36156 .76961 L .34638 .77387 L p .707 .577 .707 r
F P
0 g
s
.672 .70927 m .67789 .74511 L .65046 .74384 L p .707 .577 .707 r
F P
0 g
s
.65046 .74384 m .64457 .708 L .672 .70927 L p .707 .577 .707 r
F P
0 g
s
.16417 .72029 m .16673 .75839 L .17994 .76103 L p .707 .577 .707 r
F P
0 g
s
.18291 .80426 m .18153 .7852 L .16777 .78292 L p .707 .577 .707 r
F P
0 g
s
.16777 .78292 m .16915 .80198 L .18291 .80426 L p .707 .577 .707 r
F P
0 g
s
.16367 .69529 m .16132 .63855 L .15814 .63305 L p .707 .577 .707 r
F P
0 g
s
.64013 .29051 m .64013 .7924 L .64384 .78033 L p .707 .577 .707 r
F P
0 g
s
.64384 .78033 m .64384 .27844 L .64013 .29051 L p .707 .577 .707 r
F P
0 g
s
.67748 .7674 m .68063 .78524 L .65296 .78437 L p .707 .577 .707 r
F P
0 g
s
.65296 .78437 m .64981 .76653 L .67748 .7674 L p .707 .577 .707 r
F P
0 g
s
.15814 .63305 m .16049 .68979 L .16367 .69529 L p .707 .577 .707 r
F P
0 g
s
.16673 .75839 m .16417 .72029 L .16057 .71669 L p .707 .577 .707 r
F P
0 g
s
.36115 .67819 m .3588 .62145 L .36198 .62695 L p .707 .577 .707 r
F P
0 g
s
.16057 .71669 m .16313 .75479 L .16673 .75839 L p .707 .577 .707 r
F P
0 g
s
.16915 .80198 m .16777 .78292 L .16357 .77964 L p .707 .577 .707 r
F P
0 g
s
.36323 .73879 m .36067 .70069 L .36426 .70429 L p .707 .577 .707 r
F P
0 g
s
.3588 .62145 m .36115 .67819 L .3483 .67353 L p .707 .577 .707 r
F P
0 g
s
.3483 .67353 m .34596 .61679 L .3588 .62145 L p .707 .577 .707 r
F P
0 g
s
.36067 .70069 m .36323 .73879 L .35001 .73615 L p .707 .577 .707 r
F P
0 g
s
.35001 .73615 m .34745 .69805 L .36067 .70069 L p .707 .577 .707 r
F P
0 g
s
.36313 .76236 m .36451 .78142 L .35075 .77914 L p .707 .577 .707 r
F P
0 g
s
.35075 .77914 m .34937 .76008 L .36313 .76236 L p .707 .577 .707 r
F P
0 g
s
.35616 .28422 m .35616 .78611 L .36652 .79789 L p .707 .577 .707 r
F P
0 g
s
.35616 .78611 m .35616 .28422 L .35987 .27215 L p .707 .577 .707 r
F P
0 g
s
.16357 .77964 m .16495 .7987 L .16915 .80198 L p .707 .577 .707 r
F P
0 g
s
.16049 .68979 m .15814 .63305 L .16493 .62725 L p .707 .577 .707 r
F P
0 g
s
.16493 .62725 m .16728 .684 L .16049 .68979 L p .707 .577 .707 r
F P
0 g
s
.64384 .27844 m .64384 .78033 L .63348 .76854 L p .707 .577 .707 r
F P
0 g
s
.63348 .76854 m .63348 .26666 L .64384 .27844 L p .707 .577 .707 r
F P
0 g
s
.16313 .75479 m .16057 .71669 L .16694 .71248 L p .707 .577 .707 r
F P
0 g
s
.16694 .71248 m .1695 .75058 L .16313 .75479 L p .707 .577 .707 r
F P
0 g
s
.16495 .7987 m .16357 .77964 L .16934 .77567 L p .707 .577 .707 r
F P
0 g
s
.16934 .77567 m .17073 .79473 L .16495 .7987 L p .707 .577 .707 r
F P
0 g
s
.16728 .684 m .16493 .62725 L .18104 .62172 L p .707 .577 .707 r
F P
0 g
s
.35987 .77404 m .35987 .27215 L .3773 .26098 L p .707 .577 .707 r
F P
0 g
s
.35987 .27215 m .35987 .77404 L .35616 .78611 L p .707 .577 .707 r
F P
0 g
s
.18104 .62172 m .18339 .67847 L .16728 .684 L p .707 .577 .707 r
F P
0 g
s
.1695 .75058 m .16694 .71248 L .18266 .70808 L p .707 .577 .707 r
F P
0 g
s
.34596 .61679 m .3483 .67353 L .32705 .67016 L p .707 .577 .707 r
F P
0 g
s
.32705 .67016 m .3247 .61342 L .34596 .61679 L p .707 .577 .707 r
F P
0 g
s
.18266 .70808 m .18522 .74618 L .1695 .75058 L p .707 .577 .707 r
F P
0 g
s
.17073 .79473 m .16934 .77567 L .18452 .77141 L p .707 .577 .707 r
F P
0 g
s
.63348 .26666 m .63348 .76854 L .61004 .75819 L p .707 .577 .707 r
F P
0 g
s
.61004 .75819 m .61004 .25631 L .63348 .26666 L p .707 .577 .707 r
F P
0 g
s
.18452 .77141 m .18591 .79047 L .17073 .79473 L p .707 .577 .707 r
F P
0 g
s
.18339 .67847 m .18104 .62172 L .20489 .61701 L p .707 .577 .707 r
F P
0 g
s
.34745 .69805 m .35001 .73615 L .32847 .73473 L p .707 .577 .707 r
F P
0 g
s
.32847 .73473 m .32591 .69663 L .34745 .69805 L p .707 .577 .707 r
F P
0 g
s
.20489 .61701 m .20724 .67375 L .18339 .67847 L p .707 .577 .707 r
F P
0 g
s
.3247 .61342 m .32705 .67016 L .29947 .66841 L p .707 .577 .707 r
F P
0 g
s
.29947 .66841 m .29712 .61167 L .3247 .61342 L p .707 .577 .707 r
F P
0 g
s
.18522 .74618 m .18266 .70808 L .20618 .70392 L p .707 .577 .707 r
F P
0 g
s
.3773 .26098 m .3773 .76287 L .35987 .77404 L p .707 .577 .707 r
F P
0 g
s
.3773 .76287 m .3773 .26098 L .40674 .2518 L p .707 .577 .707 r
F P
0 g
s
.34937 .76008 m .35075 .77914 L .32877 .77809 L p .707 .577 .707 r
F P
0 g
s
.32877 .77809 m .32739 .75903 L .34937 .76008 L p .707 .577 .707 r
F P
0 g
s
.20724 .67375 m .20489 .61701 L .23413 .61356 L p .707 .577 .707 r
F P
0 g
s
.20618 .70392 m .20874 .74201 L .18522 .74618 L p .707 .577 .707 r
F P
0 g
s
.18591 .79047 m .18452 .77141 L .20763 .76726 L p .707 .577 .707 r
F P
0 g
s
.20763 .76726 m .20901 .78633 L .18591 .79047 L p .707 .577 .707 r
F P
0 g
s
.29712 .61167 m .29947 .66841 L .26826 .66846 L p .707 .577 .707 r
F P
0 g
s
.26826 .66846 m .26591 .61172 L .29712 .61167 L p .707 .577 .707 r
F P
0 g
s
.23413 .61356 m .23648 .6703 L .20724 .67375 L p .707 .577 .707 r
F P
0 g
s
.32591 .69663 m .32847 .73473 L .30072 .73466 L p .707 .577 .707 r
F P
0 g
s
.30072 .73466 m .29816 .69656 L .32591 .69663 L p .707 .577 .707 r
F P
0 g
s
.23648 .6703 m .23413 .61356 L .26591 .61172 L p .707 .577 .707 r
F P
0 g
s
.61004 .25631 m .61004 .75819 L .57584 .7503 L p .707 .577 .707 r
F P
0 g
s
.57584 .7503 m .57584 .24841 L .61004 .25631 L p .707 .577 .707 r
F P
0 g
s
.26591 .61172 m .26826 .66846 L .23648 .6703 L p .707 .577 .707 r
F P
0 g
s
.20874 .74201 m .20618 .70392 L .23521 .70039 L p .707 .577 .707 r
F P
0 g
s
.73174 .66462 m .73408 .61078 L .70288 .60716 L p .707 .577 .707 r
F P
0 g
s
.73408 .61078 m .73174 .66462 L .76352 .6647 L p .707 .577 .707 r
F P
0 g
s
.76352 .6647 m .76587 .61085 L .73408 .61078 L p .707 .577 .707 r
F P
0 g
s
.23521 .70039 m .23777 .73849 L .20874 .74201 L p .707 .577 .707 r
F P
0 g
s
.32739 .75903 m .32877 .77809 L .30073 .77838 L p .707 .577 .707 r
F P
0 g
s
.30073 .77838 m .29935 .75932 L .32739 .75903 L p .707 .577 .707 r
F P
0 g
s
.76587 .61085 m .76352 .6647 L .79276 .66122 L p .707 .577 .707 r
F P
0 g
s
.79276 .66122 m .79511 .60737 L .76587 .61085 L p .707 .577 .707 r
F P
0 g
s
.70053 .66101 m .70288 .60716 L .6753 .60035 L p .707 .577 .707 r
F P
0 g
s
.70288 .60716 m .70053 .66101 L .73174 .66462 L p .707 .577 .707 r
F P
0 g
s
.20901 .78633 m .20763 .76726 L .23639 .76365 L p .707 .577 .707 r
F P
0 g
s
.29816 .69656 m .30072 .73466 L .26946 .73596 L p .707 .577 .707 r
F P
0 g
s
.26946 .73596 m .2669 .69786 L .29816 .69656 L p .707 .577 .707 r
F P
0 g
s
.23639 .76365 m .23777 .78271 L .20901 .78633 L p .707 .577 .707 r
F P
0 g
s
.23777 .73849 m .23521 .70039 L .2669 .69786 L p .707 .577 .707 r
F P
0 g
s
.40674 .75369 m .40674 .2518 L .44531 .24551 L p .707 .577 .707 r
F P
0 g
s
.40674 .2518 m .40674 .75369 L .3773 .76287 L p .707 .577 .707 r
F P
0 g
s
.2669 .69786 m .26946 .73596 L .23777 .73849 L p .707 .577 .707 r
F P
0 g
s
.79511 .60737 m .79276 .66122 L .81661 .65452 L p .707 .577 .707 r
F P
0 g
s
.81661 .65452 m .81895 .60068 L .79511 .60737 L p .707 .577 .707 r
F P
0 g
s
.29935 .75932 m .30073 .77838 L .26938 .77997 L p .707 .577 .707 r
F P
0 g
s
.26938 .77997 m .26799 .76091 L .29935 .75932 L p .707 .577 .707 r
F P
0 g
s
.23777 .78271 m .23639 .76365 L .26799 .76091 L p .707 .577 .707 r
F P
0 g
s
.67295 .65419 m .6753 .60035 L .65404 .59101 L p .707 .577 .707 r
F P
0 g
s
.6753 .60035 m .67295 .65419 L .70053 .66101 L p .707 .577 .707 r
F P
0 g
s
.26799 .76091 m .26938 .77997 L .23777 .78271 L p .707 .577 .707 r
F P
0 g
s
.57584 .24841 m .57584 .7503 L .53421 .74562 L p .707 .577 .707 r
F P
0 g
s
.53421 .74562 m .53421 .24373 L .57584 .24841 L p .707 .577 .707 r
F P
0 g
s
.73054 .72861 m .7331 .6936 L .70184 .68908 L p .707 .577 .707 r
F P
0 g
s
.7331 .6936 m .73054 .72861 L .76223 .72906 L p .707 .577 .707 r
F P
0 g
s
.76223 .72906 m .76479 .69405 L .7331 .6936 L p .707 .577 .707 r
F P
0 g
s
.76479 .69405 m .76223 .72906 L .79126 .7254 L p .707 .577 .707 r
F P
0 g
s
.79126 .7254 m .79382 .69039 L .76479 .69405 L p .707 .577 .707 r
F P
0 g
s
.69928 .72409 m .70184 .68908 L .67409 .68094 L p .707 .577 .707 r
F P
0 g
s
.70184 .68908 m .69928 .72409 L .73054 .72861 L p .707 .577 .707 r
F P
0 g
s
.44531 .7474 m .44531 .24551 L .48923 .24273 L p .707 .577 .707 r
F P
0 g
s
.44531 .24551 m .44531 .7474 L .40674 .75369 L p .707 .577 .707 r
F P
0 g
s
.81895 .60068 m .81661 .65452 L .83271 .64527 L p .707 .577 .707 r
F P
0 g
s
.83271 .64527 m .83506 .59143 L .81895 .60068 L p .707 .577 .707 r
F P
0 g
s
.65404 .59101 m .65169 .64486 L .67295 .65419 L p .707 .577 .707 r
F P
0 g
s
.53421 .24373 m .53421 .74562 L .48923 .74462 L p .707 .577 .707 r
F P
0 g
s
.48923 .74462 m .48923 .24273 L .53421 .24373 L p .707 .577 .707 r
F P
0 g
s
.65169 .64486 m .65404 .59101 L .6412 .58007 L p .707 .577 .707 r
F P
0 g
s
.48923 .24273 m .48923 .74462 L .44531 .7474 L p .707 .577 .707 r
F P
0 g
s
.79382 .69039 m .79126 .7254 L .81478 .71799 L p .707 .577 .707 r
F P
0 g
s
.81478 .71799 m .81734 .68298 L .79382 .69039 L p .707 .577 .707 r
F P
0 g
s
.67153 .71595 m .67409 .68094 L .65255 .66997 L p .707 .577 .707 r
F P
0 g
s
.67409 .68094 m .67153 .71595 L .69928 .72409 L p .707 .577 .707 r
F P
0 g
s
.73062 .77025 m .732 .75282 L .70065 .74835 L p .707 .577 .707 r
F P
0 g
s
.732 .75282 m .73062 .77025 L .76223 .77057 L p .707 .577 .707 r
F P
0 g
s
.76223 .77057 m .76361 .75313 L .732 .75282 L p .707 .577 .707 r
F P
0 g
s
.69926 .76579 m .70065 .74835 L .67261 .74017 L p .707 .577 .707 r
F P
0 g
s
.70065 .74835 m .69926 .76579 L .73062 .77025 L p .707 .577 .707 r
F P
0 g
s
.76361 .75313 m .76223 .77057 L .79099 .7667 L p .707 .577 .707 r
F P
0 g
s
.79099 .7667 m .79237 .74926 L .76361 .75313 L p .707 .577 .707 r
F P
0 g
s
.83506 .59143 m .83271 .64527 L .83951 .63437 L p .707 .577 .707 r
F P
0 g
s
.83951 .63437 m .84186 .58052 L .83506 .59143 L p .707 .577 .707 r
F P
0 g
s
.6412 .58007 m .63885 .63391 L .65169 .64486 L p .707 .577 .707 r
F P
0 g
s
.65255 .66997 m .64999 .70498 L .67153 .71595 L p .707 .577 .707 r
F P
0 g
s
.67261 .74017 m .67123 .75761 L .69926 .76579 L p .707 .577 .707 r
F P
0 g
s
.81734 .68298 m .81478 .71799 L .8305 .70755 L p .707 .577 .707 r
F P
0 g
s
.8305 .70755 m .83306 .67254 L .81734 .68298 L p .707 .577 .707 r
F P
0 g
s
.64999 .70498 m .65255 .66997 L .63933 .65724 L p .707 .577 .707 r
F P
0 g
s
.63885 .63391 m .6412 .58007 L .63802 .56858 L p .707 .577 .707 r
F P
0 g
s
.67123 .75761 m .67261 .74017 L .65063 .72908 L p .707 .577 .707 r
F P
0 g
s
.79237 .74926 m .79099 .7667 L .81409 .75903 L p .707 .577 .707 r
F P
0 g
s
.81409 .75903 m .81547 .74159 L .79237 .74926 L p .707 .577 .707 r
F P
0 g
s
.65063 .72908 m .64925 .74652 L .67123 .75761 L p .707 .577 .707 r
F P
0 g
s
.63933 .65724 m .63677 .69225 L .64999 .70498 L p .707 .577 .707 r
F P
0 g
s
.63802 .56858 m .63567 .62242 L .63885 .63391 L p .707 .577 .707 r
F P
0 g
s
.64925 .74652 m .65063 .72908 L .63687 .71616 L p .707 .577 .707 r
F P
0 g
s
.84186 .58052 m .83951 .63437 L .83633 .62288 L p .707 .577 .707 r
F P
0 g
s
.83633 .62288 m .83868 .56903 L .84186 .58052 L p .707 .577 .707 r
F P
0 g
s
.81547 .74159 m .81409 .75903 L .82927 .7483 L p .707 .577 .707 r
F P
0 g
s
.82927 .7483 m .83065 .73087 L .81547 .74159 L p .707 .577 .707 r
F P
0 g
s
.83306 .67254 m .8305 .70755 L .83687 .6951 L p .707 .577 .707 r
F P
0 g
s
.83687 .6951 m .83943 .66009 L .83306 .67254 L p .707 .577 .707 r
F P
0 g
s
.63677 .69225 m .63933 .65724 L .63573 .64401 L p .707 .577 .707 r
F P
0 g
s
.63687 .71616 m .63549 .73359 L .64925 .74652 L p .707 .577 .707 r
F P
0 g
s
.63567 .62242 m .63802 .56858 L .64482 .55767 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63573 .64401 m .63317 .67902 L .63677 .69225 L p .707 .577 .707 r
F P
0 g
s
.63549 .73359 m .63687 .71616 L .63267 .70267 L p .707 .577 .707 r
F P
0 g
s
.83065 .73087 m .82927 .7483 L .83505 .73557 L p .707 .577 .707 r
F P
0 g
s
.83505 .73557 m .83643 .71814 L .83065 .73087 L p .707 .577 .707 r
F P
0 g
s
.64482 .55767 m .64247 .61152 L .63567 .62242 L p .707 .577 .707 r
F P
0 g
s
.83868 .56903 m .83633 .62288 L .82349 .61193 L p .707 .577 .707 r
F P
0 g
s
.82349 .61193 m .82584 .55809 L .83868 .56903 L p .707 .577 .707 r
F P
0 g
s
.83943 .66009 m .83687 .6951 L .83327 .68187 L p .707 .577 .707 r
F P
0 g
s
.83327 .68187 m .83583 .64686 L .83943 .66009 L p .707 .577 .707 r
F P
0 g
s
.63317 .67902 m .63573 .64401 L .64211 .63156 L p .707 .577 .707 r
F P
0 g
s
.63267 .70267 m .63129 .72011 L .63549 .73359 L p .707 .577 .707 r
F P
0 g
s
.38526 .61658 m .39072 .56066 L .35963 .55623 L p .707 .577 .707 r
F P
0 g
s
.39072 .56066 m .38526 .61658 L .41694 .61879 L p .707 .577 .707 r
F P
0 g
s
.41694 .61879 m .42239 .56287 L .39072 .56066 L p .707 .577 .707 r
F P
0 g
s
.64247 .61152 m .64482 .55767 L .66093 .54842 L p .707 .577 .707 r
F P
0 g
s
.42239 .56287 m .41694 .61879 L .44609 .61855 L p .707 .577 .707 r
F P
0 g
s
.44609 .61855 m .45154 .56263 L .42239 .56287 L p .707 .577 .707 r
F P
0 g
s
.35418 .61214 m .35963 .55623 L .33217 .54999 L p .707 .577 .707 r
F P
0 g
s
.35963 .55623 m .35418 .61214 L .38526 .61658 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64211 .63156 m .63955 .66658 L .63317 .67902 L p .707 .577 .707 r
F P
0 g
s
.45154 .56263 m .44609 .61855 L .46988 .6159 L p .707 .577 .707 r
F P
0 g
s
.46988 .6159 m .47533 .55998 L .45154 .56263 L p .707 .577 .707 r
F P
0 g
s
.63129 .72011 m .63267 .70267 L .63844 .68994 L p .707 .577 .707 r
F P
0 g
s
.38047 .67469 m .38636 .63747 L .35543 .63146 L p .707 .577 .707 r
F P
0 g
s
.38636 .63747 m .38047 .67469 L .41187 .67875 L p .707 .577 .707 r
F P
0 g
s
.41187 .67875 m .41776 .64153 L .38636 .63747 L p .707 .577 .707 r
F P
0 g
s
.33217 .54999 m .32672 .60591 L .35418 .61214 L p .707 .577 .707 r
F P
0 g
s
.83643 .71814 m .83505 .73557 L .83085 .72209 L p .707 .577 .707 r
F P
0 g
s
.83085 .72209 m .83223 .70465 L .83643 .71814 L p .707 .577 .707 r
F P
0 g
s
.82584 .55809 m .82349 .61193 L .80224 .60259 L p .707 .577 .707 r
F P
0 g
s
.80224 .60259 m .80458 .54875 L .82584 .55809 L p .707 .577 .707 r
F P
0 g
s
.32672 .60591 m .33217 .54999 L .31103 .54258 L p .707 .577 .707 r
F P
0 g
s
.66093 .54842 m .65858 .60226 L .64247 .61152 L p .707 .577 .707 r
F P
0 g
s
.83583 .64686 m .83327 .68187 L .82006 .66914 L p .707 .577 .707 r
F P
0 g
s
.82006 .66914 m .82262 .63413 L .83583 .64686 L p .707 .577 .707 r
F P
0 g
s
.41776 .64153 m .41187 .67875 L .44067 .68046 L p .707 .577 .707 r
F P
0 g
s
.44067 .68046 m .44656 .64324 L .41776 .64153 L p .707 .577 .707 r
F P
0 g
s
.34954 .66868 m .35543 .63146 L .32799 .62409 L p .707 .577 .707 r
F P
0 g
s
.35543 .63146 m .34954 .66868 L .38047 .67469 L p .707 .577 .707 r
F P
0 g
s
.63955 .66658 m .64211 .63156 L .65782 .62112 L p .707 .577 .707 r
F P
0 g
s
.63844 .68994 m .63706 .70738 L .63129 .72011 L p .707 .577 .707 r
F P
0 g
s
.65858 .60226 m .66093 .54842 L .68477 .54173 L p .707 .577 .707 r
F P
0 g
s
.32799 .62409 m .3221 .66131 L .34954 .66868 L p .707 .577 .707 r
F P
0 g
s
.37803 .71673 m .38118 .69813 L .35019 .69192 L p .707 .577 .707 r
F P
0 g
s
.38118 .69813 m .37803 .71673 L .4093 .72103 L p .707 .577 .707 r
F P
0 g
s
.4093 .72103 m .41246 .70243 L .38118 .69813 L p .707 .577 .707 r
F P
0 g
s
.31103 .54258 m .30558 .5985 L .32672 .60591 L p .707 .577 .707 r
F P
0 g
s
.35019 .69192 m .34704 .71052 L .37803 .71673 L p .707 .577 .707 r
F P
0 g
s
.44656 .64324 m .44067 .68046 L .46404 .67965 L p .707 .577 .707 r
F P
0 g
s
.46404 .67965 m .46993 .64243 L .44656 .64324 L p .707 .577 .707 r
F P
0 g
s
.34704 .71052 m .35019 .69192 L .32252 .6844 L p .707 .577 .707 r
F P
0 g
s
.41246 .70243 m .4093 .72103 L .4378 .723 L p .707 .577 .707 r
F P
0 g
s
.4378 .723 m .44096 .7044 L .41246 .70243 L p .707 .577 .707 r
F P
0 g
s
.47533 .55998 m .46988 .6159 L .48597 .61108 L p .707 .577 .707 r
F P
0 g
s
.48597 .61108 m .49142 .55516 L .47533 .55998 L p .707 .577 .707 r
F P
0 g
s
.3221 .66131 m .32799 .62409 L .30675 .61607 L p .707 .577 .707 r
F P
0 g
s
.65782 .62112 m .65526 .65613 L .63955 .66658 L p .707 .577 .707 r
F P
0 g
s
.32252 .6844 m .31936 .703 L .34704 .71052 L p .707 .577 .707 r
F P
0 g
s
.80458 .54875 m .80224 .60259 L .77465 .59578 L p .707 .577 .707 r
F P
0 g
s
.77465 .59578 m .777 .54194 L .80458 .54875 L p .707 .577 .707 r
F P
0 g
s
.30558 .5985 m .31103 .54258 L .29827 .5347 L p .707 .577 .707 r
F P
0 g
s
.63706 .70738 m .63844 .68994 L .65362 .67922 L p .707 .577 .707 r
F P
0 g
s
.30675 .61607 m .30086 .6533 L .3221 .66131 L p .707 .577 .707 r
F P
0 g
s
.68242 .59557 m .68477 .54173 L .71401 .53825 L p .707 .577 .707 r
F P
0 g
s
.68477 .54173 m .68242 .59557 L .65858 .60226 L p .707 .577 .707 r
F P
0 g
s
.83223 .70465 m .83085 .72209 L .81708 .70917 L p .707 .577 .707 r
F P
0 g
s
.81708 .70917 m .81847 .69173 L .83223 .70465 L p .707 .577 .707 r
F P
0 g
s
.82262 .63413 m .82006 .66914 L .79852 .65817 L p .707 .577 .707 r
F P
0 g
s
.79852 .65817 m .80108 .62316 L .82262 .63413 L p .707 .577 .707 r
F P
0 g
s
.65526 .65613 m .65782 .62112 L .68135 .61371 L p .707 .577 .707 r
F P
0 g
s
.31936 .703 m .32252 .6844 L .30088 .67631 L p .707 .577 .707 r
F P
0 g
s
.44096 .7044 m .4378 .723 L .46073 .72244 L p .707 .577 .707 r
F P
0 g
s
.46073 .72244 m .46389 .70384 L .44096 .7044 L p .707 .577 .707 r
F P
0 g
s
.65362 .67922 m .65224 .69666 L .63706 .70738 L p .707 .577 .707 r
F P
0 g
s
.30088 .67631 m .29772 .69492 L .31936 .703 L p .707 .577 .707 r
F P
0 g
s
.29827 .5347 m .29282 .59062 L .30558 .5985 L p .707 .577 .707 r
F P
0 g
s
.777 .54194 m .77465 .59578 L .74345 .59216 L p .707 .577 .707 r
F P
0 g
s
.74345 .59216 m .74579 .53832 L .777 .54194 L p .707 .577 .707 r
F P
0 g
s
.46993 .64243 m .46404 .67965 L .47971 .67641 L p .707 .577 .707 r
F P
0 g
s
.47971 .67641 m .4856 .63919 L .46993 .64243 L p .707 .577 .707 r
F P
0 g
s
.71166 .59209 m .71401 .53825 L .74579 .53832 L p .707 .577 .707 r
F P
0 g
s
.71401 .53825 m .71166 .59209 L .68242 .59557 L p .707 .577 .707 r
F P
0 g
s
.30086 .6533 m .30675 .61607 L .29376 .6082 L p .707 .577 .707 r
F P
0 g
s
.74579 .53832 m .74345 .59216 L .71166 .59209 L p .707 .577 .707 r
F P
0 g
s
.49142 .55516 m .48597 .61108 L .49278 .60457 L p .707 .577 .707 r
F P
0 g
s
.49278 .60457 m .49823 .54865 L .49142 .55516 L p .707 .577 .707 r
F P
0 g
s
.68135 .61371 m .67879 .64872 L .65526 .65613 L p .707 .577 .707 r
F P
0 g
s
.29376 .6082 m .28787 .64542 L .30086 .6533 L p .707 .577 .707 r
F P
0 g
s
.80108 .62316 m .79852 .65817 L .77076 .65003 L p .707 .577 .707 r
F P
0 g
s
.77076 .65003 m .77332 .61502 L .80108 .62316 L p .707 .577 .707 r
F P
0 g
s
.67879 .64872 m .68135 .61371 L .71038 .61005 L p .707 .577 .707 r
F P
0 g
s
.29282 .59062 m .29827 .5347 L .29515 .52714 L p .707 .577 .707 r
F P
0 g
s
.65224 .69666 m .65362 .67922 L .67672 .67155 L p .707 .577 .707 r
F P
0 g
s
.29772 .69492 m .30088 .67631 L .28738 .66845 L p .707 .577 .707 r
F P
0 g
s
.81847 .69173 m .81708 .70917 L .79511 .69807 L p .707 .577 .707 r
F P
0 g
s
.79511 .69807 m .79649 .68064 L .81847 .69173 L p .707 .577 .707 r
F P
0 g
s
.46389 .70384 m .46073 .72244 L .47585 .71942 L p .707 .577 .707 r
F P
0 g
s
.47585 .71942 m .47901 .70081 L .46389 .70384 L p .707 .577 .707 r
F P
0 g
s
.28738 .66845 m .28422 .68705 L .29772 .69492 L p .707 .577 .707 r
F P
0 g
s
.67672 .67155 m .67534 .68898 L .65224 .69666 L p .707 .577 .707 r
F P
0 g
s
.77332 .61502 m .77076 .65003 L .73951 .64551 L p .707 .577 .707 r
F P
0 g
s
.73951 .64551 m .74207 .6105 L .77332 .61502 L p .707 .577 .707 r
F P
0 g
s
.70782 .64506 m .71038 .61005 L .74207 .6105 L p .707 .577 .707 r
F P
0 g
s
.71038 .61005 m .70782 .64506 L .67879 .64872 L p .707 .577 .707 r
F P
0 g
s
.29515 .52714 m .2897 .58306 L .29282 .59062 L p .707 .577 .707 r
F P
0 g
s
.4856 .63919 m .47971 .67641 L .48613 .67104 L p .707 .577 .707 r
F P
0 g
s
.48613 .67104 m .49202 .63382 L .4856 .63919 L p .707 .577 .707 r
F P
0 g
s
.74207 .6105 m .73951 .64551 L .70782 .64506 L p .707 .577 .707 r
F P
0 g
s
.28787 .64542 m .29376 .6082 L .29031 .60124 L p .707 .577 .707 r
F P
0 g
s
.67534 .68898 m .67672 .67155 L .70549 .66768 L p .707 .577 .707 r
F P
0 g
s
.79649 .68064 m .79511 .69807 L .76707 .68989 L p .707 .577 .707 r
F P
0 g
s
.76707 .68989 m .76845 .67246 L .79649 .68064 L p .707 .577 .707 r
F P
0 g
s
.49823 .54865 m .49278 .60457 L .48966 .59701 L p .707 .577 .707 r
F P
0 g
s
.48966 .59701 m .49511 .54109 L .49823 .54865 L p .707 .577 .707 r
F P
0 g
s
.29031 .60124 m .28442 .63846 L .28787 .64542 L p .707 .577 .707 r
F P
0 g
s
.70549 .66768 m .70411 .68511 L .67534 .68898 L p .707 .577 .707 r
F P
0 g
s
.28422 .68705 m .28738 .66845 L .28335 .66158 L p .707 .577 .707 r
F P
0 g
s
.47901 .70081 m .47585 .71942 L .48169 .71421 L p .707 .577 .707 r
F P
0 g
s
.48169 .71421 m .48484 .69561 L .47901 .70081 L p .707 .577 .707 r
F P
0 g
s
.2897 .58306 m .29515 .52714 L .30197 .52063 L p .707 .577 .707 r
F P
0 g
s
.28335 .66158 m .28019 .68019 L .28422 .68705 L p .707 .577 .707 r
F P
0 g
s
.70411 .68511 m .70549 .66768 L .73709 .66799 L p .707 .577 .707 r
F P
0 g
s
.76845 .67246 m .76707 .68989 L .73571 .68543 L p .707 .577 .707 r
F P
0 g
s
.73571 .68543 m .73709 .66799 L .76845 .67246 L p .707 .577 .707 r
F P
0 g
s
.73709 .66799 m .73571 .68543 L .70411 .68511 L p .707 .577 .707 r
F P
0 g
s
.30197 .52063 m .29652 .57655 L .2897 .58306 L p .707 .577 .707 r
F P
0 g
s
.49202 .63382 m .48613 .67104 L .48268 .66408 L p .707 .577 .707 r
F P
0 g
s
.48268 .66408 m .48857 .62686 L .49202 .63382 L p .707 .577 .707 r
F P
0 g
s
.28442 .63846 m .29031 .60124 L .29674 .59587 L p .707 .577 .707 r
F P
0 g
s
.49511 .54109 m .48966 .59701 L .47691 .58913 L p .707 .577 .707 r
F P
0 g
s
.47691 .58913 m .48236 .53321 L .49511 .54109 L p .707 .577 .707 r
F P
0 g
s
.29674 .59587 m .29084 .6331 L .28442 .63846 L p .707 .577 .707 r
F P
0 g
s
.28019 .68019 m .28335 .66158 L .28918 .65638 L p .707 .577 .707 r
F P
0 g
s
.48484 .69561 m .48169 .71421 L .47765 .70734 L p .707 .577 .707 r
F P
0 g
s
.47765 .70734 m .48081 .68874 L .48484 .69561 L p .707 .577 .707 r
F P
0 g
s
.29652 .57655 m .30197 .52063 L .31806 .51581 L p .707 .577 .707 r
F P
0 g
s
.28918 .65638 m .28602 .67498 L .28019 .68019 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31806 .51581 m .31261 .57173 L .29652 .57655 L p .707 .577 .707 r
F P
0 g
s
.48857 .62686 m .48268 .66408 L .4697 .65621 L p .707 .577 .707 r
F P
0 g
s
.4697 .65621 m .47559 .61899 L .48857 .62686 L p .707 .577 .707 r
F P
0 g
s
.29084 .6331 m .29674 .59587 L .3124 .59263 L p .707 .577 .707 r
F P
0 g
s
.48236 .53321 m .47691 .58913 L .45576 .58172 L p .707 .577 .707 r
F P
0 g
s
.45576 .58172 m .46121 .5258 L .48236 .53321 L p .707 .577 .707 r
F P
0 g
s
.3124 .59263 m .30651 .62985 L .29084 .6331 L p .707 .577 .707 r
F P
0 g
s
.31261 .57173 m .31806 .51581 L .34184 .51316 L p .707 .577 .707 r
F P
0 g
s
.28602 .67498 m .28918 .65638 L .3043 .65335 L p .707 .577 .707 r
F P
0 g
s
.48081 .68874 m .47765 .70734 L .46416 .69948 L p .707 .577 .707 r
F P
0 g
s
.46416 .69948 m .46731 .68088 L .48081 .68874 L p .707 .577 .707 r
F P
0 g
s
.3043 .65335 m .30114 .67195 L .28602 .67498 L p .707 .577 .707 r
F P
0 g
s
.34184 .51316 m .33639 .56908 L .31261 .57173 L p .707 .577 .707 r
F P
0 g
s
.47559 .61899 m .4697 .65621 L .44845 .6482 L p .707 .577 .707 r
F P
0 g
s
.44845 .6482 m .45434 .61097 L .47559 .61899 L p .707 .577 .707 r
F P
0 g
s
.46121 .5258 m .45576 .58172 L .42831 .57548 L p .707 .577 .707 r
F P
0 g
s
.42831 .57548 m .43376 .51957 L .46121 .5258 L p .707 .577 .707 r
F P
0 g
s
.30651 .62985 m .3124 .59263 L .33578 .59182 L p .707 .577 .707 r
F P
0 g
s
.33639 .56908 m .34184 .51316 L .371 .51292 L p .707 .577 .707 r
F P
0 g
s
.33578 .59182 m .32989 .62905 L .30651 .62985 L p .707 .577 .707 r
F P
0 g
s
.30114 .67195 m .3043 .65335 L .32723 .65279 L p .707 .577 .707 r
F P
0 g
s
.46731 .68088 m .46416 .69948 L .44251 .6914 L p .707 .577 .707 r
F P
0 g
s
.44251 .6914 m .44567 .67279 L .46731 .68088 L p .707 .577 .707 r
F P
0 g
s
.43376 .51957 m .42831 .57548 L .39722 .57105 L p .707 .577 .707 r
F P
0 g
s
.39722 .57105 m .40267 .51513 L .43376 .51957 L p .707 .577 .707 r
F P
0 g
s
.36555 .56884 m .371 .51292 L .40267 .51513 L p .707 .577 .707 r
F P
0 g
s
.371 .51292 m .36555 .56884 L .33639 .56908 L p .707 .577 .707 r
F P
0 g
s
.32723 .65279 m .32408 .6714 L .30114 .67195 L p .707 .577 .707 r
F P
0 g
s
.40267 .51513 m .39722 .57105 L .36555 .56884 L p .707 .577 .707 r
F P
0 g
s
.45434 .61097 m .44845 .6482 L .42102 .64082 L p .707 .577 .707 r
F P
0 g
s
.42102 .64082 m .42691 .6036 L .45434 .61097 L p .707 .577 .707 r
F P
0 g
s
.32989 .62905 m .33578 .59182 L .36458 .59353 L p .707 .577 .707 r
F P
0 g
s
.36458 .59353 m .35869 .63075 L .32989 .62905 L p .707 .577 .707 r
F P
0 g
s
.42691 .6036 m .42102 .64082 L .39009 .63481 L p .707 .577 .707 r
F P
0 g
s
.39009 .63481 m .39598 .59759 L .42691 .6036 L p .707 .577 .707 r
F P
0 g
s
.32408 .6714 m .32723 .65279 L .35573 .65476 L p .707 .577 .707 r
F P
0 g
s
.44567 .67279 m .44251 .6914 L .41484 .68388 L p .707 .577 .707 r
F P
0 g
s
.41484 .68388 m .418 .66527 L .44567 .67279 L p .707 .577 .707 r
F P
0 g
s
.35869 .63075 m .36458 .59353 L .39598 .59759 L p .707 .577 .707 r
F P
0 g
s
.35573 .65476 m .35258 .67336 L .32408 .6714 L p .707 .577 .707 r
F P
0 g
s
.39598 .59759 m .39009 .63481 L .35869 .63075 L p .707 .577 .707 r
F P
0 g
s
.35258 .67336 m .35573 .65476 L .38701 .65906 L p .707 .577 .707 r
F P
0 g
s
.418 .66527 m .41484 .68388 L .38385 .67766 L p .707 .577 .707 r
F P
0 g
s
.38385 .67766 m .38701 .65906 L .418 .66527 L p .707 .577 .707 r
F P
0 g
s
.38701 .65906 m .38385 .67766 L .35258 .67336 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
O7oo8@00P7oo001fOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH9001g
Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
079oo`00L7oo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF1000KWoo001]Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH00000K7oo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Moo`80009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8006Moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P00Igoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001VOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005iooa0000EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol005Uoo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`<000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001U
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
3goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP002UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF009JEPH003moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000kOol005=oo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP000Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF1000=goo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
=7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000aOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00DWoo00<005YF0000
0eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYF001JEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF00000UYF1@0000=JEP00FUH0
1UYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0009
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001BOol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH0000^Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0059oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0P000eYF0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00005@000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008000YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF009J
EQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0004FUH00`00FUIJEP02FUH6000;Ool30004Ool60006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
02eoo`00DWoo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@001eYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000moo`D000Uoo`@0009JEP03001JEUYF00=J
EP06001JEUYF001JEP00;Goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH30002FUH0
0`00FUH00003000;Ool5000=Ool30005FUH01P00FUIJEP00FUH002eoo`00DWoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001UYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF001J
EP8000EJEP03001JEUYF00=JEPL000Aoo`D000Uoo`D0009JEP8000=JEP06001JEUYF001JEP00;Goo
0017Ool;00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00H005YF000005YF0005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJ
EP03FUH2000015YF001JEUYF0P00;Woo000oOol80004FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP020002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP03FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH0
0`00FUIJEP04FUH30002FUH2000^Ool003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P00;Woo000bOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20003
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF
00@005YFFUIJEP<002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP<002ioo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF008000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800005
FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01000FUIJEUYF0`00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH60002FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEP0002ioo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF00002@001UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0002ioo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF2P000UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF1P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1P001EYF00<0
05YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00`0000=JEP00FUH00UYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF0P0015YF00<005YF00000`001eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP00
00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP04001JEUYFFUH90002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004FUH20002FUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000
FUIJEUYF0P00;Woo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF000005YF00<000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF009JEPH000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00IJEP03001J
EUYF00AJEP04001JEUYFFUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH000020006FUH00`00FUIJEP03FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF1@0000=oo`0000000eYF00H005YFFUH005YF000^Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP03FUHJ0008Ool200001eYF001JEUYF001JEP0002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4`000eYF00@005YFFUIJEPL000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP06001JEUYFFUH005YF
0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF
1`000eYF00<005YFFUH01UYF00<005YFFUH0100047oo0P000UYF00<005YF0000;Woo000]Ool00`00
FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH015YF00<005YF00001`0000=JEP00FUH015YF
2@0015YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF0`0000EJEP00001JEP00
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@000ioo`05001JEP00FUH0000^Ool002eoo`03001J
EP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH60006FUH00`00FUIJEP06FUH00`00FUH000030002FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH01000FUH00000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002goo0`00;goo
000]Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF0P00
15YF00<005YF00000`001UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30006Ool200000eYF0000000_Ool002eoo`06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0`0015YF00@005YFFUIJ
EP8000AJEP03001JEUYF00T000IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP8000EJEP03001JEUYF009JEQ0000IJEP03
001JEUYF00EJEP<0009oo`8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEP0000@000=JEP80
00AJEP03001JEUYF00H000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP001EYF1@00
00=JEP0000000`002Woo10000UYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF0P00
;goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH200000eYF001JEP05FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP060007FUH40004FUH00`00
FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
0eYF00@005YFFUIJEP<000MJEP03001JEUYF00@000Yoo`@000EJEP03001JEUYF00=JEP8000=JEP80
02moo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF009JEP<00003FUH0
05YF00UJEP@00003FUH005YF00=JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP04001JEP000002FUH00`00FUIJEP05FUH00`00FUIJEP04FUHB0000
0eYF001JEP05FUH20002FUH2000_Ool002moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ800003FUH005YF00MJEP03001JEUYF00AJEPL0009JEP03001JEUYF00QJEP04001JEUYF
FUH20003FUH01@00FUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`001EYF00@005YF001JEP8002moo`00<Goo10000eYF00<005YFFUH015YF200015YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF0080031oo`00=Goo2P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00@0
05YFFUIJEQ00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH200000eYF001JEP02FUH00`00Oomoo`0^Ool0039oo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0P000eYF00<007ooOol0;Woo000_Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001o
ogoo02ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH02@001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP000000;goo000]Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000P001eYF1@000UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000goo0`00;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH015YF4`001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000P001eYF00<005YFFUH00UYF1@001UYF1P000eYF00<005YFFUH01EYF
00<005YF00000`001Woo0P00;goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH01@000UYF1P000eYF00<005YFFUH00UYF1@002Woo0P00;goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
00IJEP03001JEUYF009JEP03001JEUYF008000=ooa0000moo`8002moo`00;Goo00@005YFFUH000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP04001J
EP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
009JEP05001JEUYFFUH0000POol4000_Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEPl00003FUH005YF00MJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP80009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEP007Woo0P000UYF0P00
;goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF00001EYF0`001EYF00@005YFFUH001eoo`04001JEUYFFUH2000`Ool002ioo`03
001JEP0000=JEP04001JEUYFFUH60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020006
FUH00`00FUH00003000015YF001JEUYF0P006Woo0`000eYF0P00<7oo000^Ool00`00FUH00002FUH5
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH9000<FUH<0006FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH6000HOol20002FUH01@00
FUIJEUYF0000<Goo000^Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF200015YF00<005YFFUH01EYF00<005YFFUH01P00
25YF00<005YFFUH02UYF00<005YFFUH02EYF2@001eYF00<005YFFUH015YF00D005YFFUH007oo0080
00=JEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP04001JEUYF000bOol002ioo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Ioo`8000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPD0009JEP03001JEUYF00AJEP04001JEUYF0003Ool200000eYF001J
EP07FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH3000cOol002moo`80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ4000Eoo`8000AJEP03001JEUYF
00@000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00@000EJEP04001JEUYF0005Ool30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000eOol0035oob0000AJEP03001JEUYF00EJEP03001JEUYF00L000AJ
EP@000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP8000=JEP04001JEUYF0006Ool60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00=goo0010Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH000000eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<00004FUH005YFFUH70006FUH5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000>Goo000hOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH00000FUH00P0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P000UYF0P000eYF1`0000=JEP00FUH00UYF1@000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1@00>goo000cOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH010000UYF0P000Woo4000@7oo000`Ool3
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000MJ
EP03001JEUYF00=JEPD0059oo`00;Woo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF7`0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000MJ
EP03001JEUYF009JEP03001JEUYF0080059oo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF20001goo2@000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
001BOol002ioo`03001JEP0000=JEP04001JEUYFFUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`000eYF00<0
05YFFUH00P00DGoo000^Ool00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH00`00Oomoo`1?
Ool002ioo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH50002Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo0P0000=JEP00Ool0D7oo000^Ool30003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008Ool00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030008FUH01000FUH0000027oo0P00DGoo000^Ool0
0`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
000@Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH3000:Ool3001@Ool002moob40
01]oo`800003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000aoo`800003FUH007oo04moo`00
KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH00UYF0P001eYF00<005YF00000P0037oo0P0000AJEP00FUH0051oo`00L7oo0`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`0015YF
1P003Woo00@005YFFUIJEP80055oo`00Lgoo100000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF3`004goo00<005YFFUH00UYF0P00DGoo001gOol70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUHF000EOol30004FUH00`00Oomoo`1@Ool007iooaX0015oo`D001=oo`80
009JEP05001JEUYFFUH0001COol0099oo`03001JEP0001Eoo`<0015oo`<000EJEP03001JEP0005Ao
o`00TWoo00<005YF00009Goo100000=JEP00FUH01EYF0P00EGoo002COol2000POol50005FUH00`00
FUIJEP04FUH00`00Oomoo`1DOol009=oo`04001JEP00000JOol40002FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00Egoo002COol20002FUH3000@Ool70006FUH00`00FUIJEP06FUH01000FUH00000FGoo
002COol20002FUH00`00FUIJEP0@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001KOol009Ao
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH2001NOol009Eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00002001POol009Ioo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPH006=oo`00V7oo0`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@00JGoo002KOol@001b
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5894 .74536 m .59483 .68946 L .56386 .68492 L p .707 .577 .707 r
F P
0 g
s
.59483 .68946 m .5894 .74536 L .62112 .74768 L p .707 .577 .707 r
F P
0 g
s
.62112 .74768 m .62655 .69177 L .59483 .68946 L p .707 .577 .707 r
F P
0 g
s
.62655 .69177 m .62112 .74768 L .65049 .74754 L p .707 .577 .707 r
F P
0 g
s
.65049 .74754 m .65591 .69164 L .62655 .69177 L p .707 .577 .707 r
F P
0 g
s
.55843 .74082 m .56386 .68492 L .53667 .6786 L p .707 .577 .707 r
F P
0 g
s
.56386 .68492 m .55843 .74082 L .5894 .74536 L p .707 .577 .707 r
F P
0 g
s
.65591 .69164 m .65049 .74754 L .67462 .74498 L p .707 .577 .707 r
F P
0 g
s
.67462 .74498 m .68005 .68907 L .65591 .69164 L p .707 .577 .707 r
F P
0 g
s
.58215 .80331 m .58797 .76611 L .55733 .75991 L p .707 .577 .707 r
F P
0 g
s
.58797 .76611 m .58215 .80331 L .61368 .80758 L p .707 .577 .707 r
F P
0 g
s
.61368 .80758 m .6195 .77039 L .58797 .76611 L p .707 .577 .707 r
F P
0 g
s
.53667 .6786 m .53125 .73451 L .55843 .74082 L p .707 .577 .707 r
F P
0 g
s
.53125 .73451 m .53667 .6786 L .51592 .67113 L p .707 .577 .707 r
F P
0 g
s
.6195 .77039 m .61368 .80758 L .64299 .80951 L p .707 .577 .707 r
F P
0 g
s
.64299 .80951 m .64882 .77231 L .6195 .77039 L p .707 .577 .707 r
F P
0 g
s
.5515 .79711 m .55733 .75991 L .53056 .75239 L p .707 .577 .707 r
F P
0 g
s
.55733 .75991 m .5515 .79711 L .58215 .80331 L p .707 .577 .707 r
F P
0 g
s
.57589 .84513 m .57898 .82655 L .54853 .81998 L p .707 .577 .707 r
F P
0 g
s
.57898 .82655 m .57589 .84513 L .60741 .84982 L p .707 .577 .707 r
F P
0 g
s
.60741 .84982 m .61049 .83124 L .57898 .82655 L p .707 .577 .707 r
F P
0 g
s
.53056 .75239 m .52473 .78959 L .5515 .79711 L p .707 .577 .707 r
F P
0 g
s
.64882 .77231 m .64299 .80951 L .66723 .8089 L p .707 .577 .707 r
F P
0 g
s
.66723 .8089 m .67305 .7717 L .64882 .77231 L p .707 .577 .707 r
F P
0 g
s
.51592 .67113 m .5105 .72703 L .53125 .73451 L p .707 .577 .707 r
F P
0 g
s
.61049 .83124 m .60741 .84982 L .6369 .85219 L p .707 .577 .707 r
F P
0 g
s
.6369 .85219 m .63999 .83361 L .61049 .83124 L p .707 .577 .707 r
F P
0 g
s
.68005 .68907 m .67462 .74498 L .69116 .74022 L p .707 .577 .707 r
F P
0 g
s
.69116 .74022 m .69659 .68432 L .68005 .68907 L p .707 .577 .707 r
F P
0 g
s
.54853 .81998 m .54544 .83856 L .57589 .84513 L p .707 .577 .707 r
F P
0 g
s
.54544 .83856 m .54853 .81998 L .52213 .81219 L p .707 .577 .707 r
F P
0 g
s
.52473 .78959 m .53056 .75239 L .51028 .74427 L p .707 .577 .707 r
F P
0 g
s
.52213 .81219 m .51904 .83077 L .54544 .83856 L p .707 .577 .707 r
F P
0 g
s
.5105 .72703 m .51592 .67113 L .50365 .66322 L p .707 .577 .707 r
F P
0 g
s
.63999 .83361 m .6369 .85219 L .66149 .852 L p .707 .577 .707 r
F P
0 g
s
.66149 .852 m .66458 .83341 L .63999 .83361 L p .707 .577 .707 r
F P
0 g
s
.51028 .74427 m .50446 .78147 L .52473 .78959 L p .707 .577 .707 r
F P
0 g
s
.67305 .7717 m .66723 .8089 L .68402 .80581 L p .707 .577 .707 r
F P
0 g
s
.68402 .80581 m .68984 .76861 L .67305 .7717 L p .707 .577 .707 r
F P
0 g
s
.51904 .83077 m .52213 .81219 L .50235 .80394 L p .707 .577 .707 r
F P
0 g
s
.50365 .66322 m .49823 .71913 L .5105 .72703 L p .707 .577 .707 r
F P
0 g
s
.50235 .80394 m .49927 .82252 L .51904 .83077 L p .707 .577 .707 r
F P
0 g
s
.69659 .68432 m .69116 .74022 L .69849 .73375 L p .707 .577 .707 r
F P
0 g
s
.69849 .73375 m .70392 .67785 L .69659 .68432 L p .707 .577 .707 r
F P
0 g
s
.50446 .78147 m .51028 .74427 L .49849 .73637 L p .707 .577 .707 r
F P
0 g
s
.66458 .83341 m .66149 .852 L .67877 .84926 L p .707 .577 .707 r
F P
0 g
s
.67877 .84926 m .68185 .83068 L .66458 .83341 L p .707 .577 .707 r
F P
0 g
s
.49849 .73637 m .49267 .77357 L .50446 .78147 L p .707 .577 .707 r
F P
0 g
s
.49823 .71913 m .50365 .66322 L .50105 .65567 L p .707 .577 .707 r
F P
0 g
s
.49927 .82252 m .50235 .80394 L .49115 .79603 L p .707 .577 .707 r
F P
0 g
s
.68984 .76861 m .68402 .80581 L .69171 .80054 L p .707 .577 .707 r
F P
0 g
s
.69171 .80054 m .69754 .76334 L .68984 .76861 L p .707 .577 .707 r
F P
0 g
s
.49115 .79603 m .48806 .81461 L .49927 .82252 L p .707 .577 .707 r
F P
0 g
s
.50105 .65567 m .49563 .71157 L .49823 .71913 L p .707 .577 .707 r
F P
0 g
s
.49267 .77357 m .49849 .73637 L .49634 .72945 L p .707 .577 .707 r
F P
0 g
s
.70392 .67785 m .69849 .73375 L .6959 .72619 L p .707 .577 .707 r
F P
0 g
s
.6959 .72619 m .70132 .67029 L .70392 .67785 L p .707 .577 .707 r
F P
0 g
s
.68185 .83068 m .67877 .84926 L .68704 .84426 L p .707 .577 .707 r
F P
0 g
s
.68704 .84426 m .69013 .82568 L .68185 .83068 L p .707 .577 .707 r
F P
0 g
s
.49634 .72945 m .49052 .76665 L .49267 .77357 L p .707 .577 .707 r
F P
0 g
s
.49563 .71157 m .50105 .65567 L .50838 .64919 L p .707 .577 .707 r
F P
0 g
s
.50838 .64919 m .50296 .7051 L .49563 .71157 L p .707 .577 .707 r
F P
0 g
s
.50296 .7051 m .50838 .64919 L .52493 .64444 L p .707 .577 .707 r
F P
0 g
s
.52493 .64444 m .5195 .70035 L .50296 .7051 L p .707 .577 .707 r
F P
0 g
s
.49821 .76138 m .50403 .72418 L .52082 .7211 L p .707 .577 .707 r
F P
0 g
s
.52082 .7211 m .515 .75829 L .49821 .76138 L p .707 .577 .707 r
F P
0 g
s
.49479 .80282 m .49788 .78424 L .51515 .78151 L p .707 .577 .707 r
F P
0 g
s
.51515 .78151 m .51207 .80009 L .49479 .80282 L p .707 .577 .707 r
F P
0 g
s
.515 .75829 m .52082 .7211 L .54506 .72048 L p .707 .577 .707 r
F P
0 g
s
.54506 .72048 m .53924 .75768 L .515 .75829 L p .707 .577 .707 r
F P
0 g
s
.51207 .80009 m .51515 .78151 L .53974 .78131 L p .707 .577 .707 r
F P
0 g
s
.53974 .78131 m .53665 .79989 L .51207 .80009 L p .707 .577 .707 r
F P
0 g
s
.51537 .8217 m .51537 .31981 L .4703 .31921 L p .707 .577 .707 r
F P
0 g
s
.5195 .70035 m .52493 .64444 L .54906 .64187 L p .707 .577 .707 r
F P
0 g
s
.54906 .64187 m .54364 .69778 L .5195 .70035 L p .707 .577 .707 r
F P
0 g
s
.54364 .69778 m .54906 .64187 L .57842 .64174 L p .707 .577 .707 r
F P
0 g
s
.57842 .64174 m .573 .69765 L .54364 .69778 L p .707 .577 .707 r
F P
0 g
s
.53924 .75768 m .54506 .72048 L .57438 .72241 L p .707 .577 .707 r
F P
0 g
s
.57438 .72241 m .56856 .75961 L .53924 .75768 L p .707 .577 .707 r
F P
0 g
s
.53665 .79989 m .53974 .78131 L .56924 .78368 L p .707 .577 .707 r
F P
0 g
s
.56924 .78368 m .56615 .80226 L .53665 .79989 L p .707 .577 .707 r
F P
0 g
s
.51537 .31981 m .51537 .8217 L .55894 .81854 L p .707 .577 .707 r
F P
0 g
s
.55894 .81854 m .55894 .31666 L .51537 .31981 L p .707 .577 .707 r
F P
0 g
s
.4703 .82109 m .4703 .31921 L .42813 .31489 L p .707 .577 .707 r
F P
0 g
s
.48806 .81461 m .49115 .79603 L .48961 .78924 L p .707 .577 .707 r
F P
0 g
s
.48961 .78924 m .48652 .80782 L .48806 .81461 L p .707 .577 .707 r
F P
0 g
s
.49052 .76665 m .49634 .72945 L .50403 .72418 L p .707 .577 .707 r
F P
0 g
s
.50403 .72418 m .49821 .76138 L .49052 .76665 L p .707 .577 .707 r
F P
0 g
s
.48652 .80782 m .48961 .78924 L .49788 .78424 L p .707 .577 .707 r
F P
0 g
s
.49788 .78424 m .49479 .80282 L .48652 .80782 L p .707 .577 .707 r
F P
0 g
s
.4703 .31921 m .4703 .82109 L .51537 .8217 L p .707 .577 .707 r
F P
0 g
s
.69754 .76334 m .69171 .80054 L .68956 .79362 L p .707 .577 .707 r
F P
0 g
s
.68956 .79362 m .69538 .75642 L .69754 .76334 L p .707 .577 .707 r
F P
0 g
s
.573 .69765 m .57842 .64174 L .61014 .64406 L p .707 .577 .707 r
F P
0 g
s
.61014 .64406 m .60472 .69996 L .573 .69765 L p .707 .577 .707 r
F P
0 g
s
.56856 .75961 m .57438 .72241 L .6059 .72668 L p .707 .577 .707 r
F P
0 g
s
.6059 .72668 m .60008 .76388 L .56856 .75961 L p .707 .577 .707 r
F P
0 g
s
.56615 .80226 m .56924 .78368 L .60075 .78837 L p .707 .577 .707 r
F P
0 g
s
.60075 .78837 m .59767 .80695 L .56615 .80226 L p .707 .577 .707 r
F P
0 g
s
.55894 .31666 m .55894 .81854 L .59674 .81193 L p .707 .577 .707 r
F P
0 g
s
.59674 .81193 m .59674 .31004 L .55894 .31666 L p .707 .577 .707 r
F P
0 g
s
.42813 .81678 m .42813 .31489 L .393 .30729 L p .707 .577 .707 r
F P
0 g
s
.42813 .31489 m .42813 .81678 L .4703 .82109 L p .707 .577 .707 r
F P
0 g
s
.70132 .67029 m .6959 .72619 L .68362 .71829 L p .707 .577 .707 r
F P
0 g
s
.68362 .71829 m .68905 .66238 L .70132 .67029 L p .707 .577 .707 r
F P
0 g
s
.69013 .82568 m .68704 .84426 L .6855 .83747 L p .707 .577 .707 r
F P
0 g
s
.6855 .83747 m .68858 .81889 L .69013 .82568 L p .707 .577 .707 r
F P
0 g
s
.24986 .71984 m .25218 .66602 L .22109 .66223 L p .707 .577 .707 r
F P
0 g
s
.25218 .66602 m .24986 .71984 L .28169 .72009 L p .707 .577 .707 r
F P
0 g
s
.28169 .72009 m .28401 .66627 L .25218 .66602 L p .707 .577 .707 r
F P
0 g
s
.64111 .64859 m .63569 .7045 L .60472 .69996 L p .707 .577 .707 r
F P
0 g
s
.60472 .69996 m .61014 .64406 L .64111 .64859 L p .707 .577 .707 r
F P
0 g
s
.63655 .73288 m .63073 .77008 L .60008 .76388 L p .707 .577 .707 r
F P
0 g
s
.60008 .76388 m .6059 .72668 L .63655 .73288 L p .707 .577 .707 r
F P
0 g
s
.6312 .79494 m .62811 .81352 L .59767 .80695 L p .707 .577 .707 r
F P
0 g
s
.59767 .80695 m .60075 .78837 L .6312 .79494 L p .707 .577 .707 r
F P
0 g
s
.59674 .31004 m .59674 .81193 L .62507 .8025 L p .707 .577 .707 r
F P
0 g
s
.62507 .8025 m .62507 .30061 L .59674 .31004 L p .707 .577 .707 r
F P
0 g
s
.28401 .66627 m .28169 .72009 L .31114 .71676 L p .707 .577 .707 r
F P
0 g
s
.31114 .71676 m .31346 .66294 L .28401 .66627 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21876 .71605 m .22109 .66223 L .19378 .65526 L p .707 .577 .707 r
F P
0 g
s
.22109 .66223 m .21876 .71605 L .24986 .71984 L p .707 .577 .707 r
F P
0 g
s
.69538 .75642 m .68956 .79362 L .67777 .78572 L p .707 .577 .707 r
F P
0 g
s
.67777 .78572 m .68359 .74852 L .69538 .75642 L p .707 .577 .707 r
F P
0 g
s
.393 .80918 m .393 .30729 L .36835 .29714 L p .707 .577 .707 r
F P
0 g
s
.393 .30729 m .393 .80918 L .42813 .81678 L p .707 .577 .707 r
F P
0 g
s
.31346 .66294 m .31114 .71676 L .33533 .71019 L p .707 .577 .707 r
F P
0 g
s
.33533 .71019 m .33765 .65637 L .31346 .66294 L p .707 .577 .707 r
F P
0 g
s
.68905 .66238 m .68362 .71829 L .66288 .71082 L p .707 .577 .707 r
F P
0 g
s
.66288 .71082 m .6683 .65491 L .68905 .66238 L p .707 .577 .707 r
F P
0 g
s
.68858 .81889 m .6855 .83747 L .67429 .82956 L p .707 .577 .707 r
F P
0 g
s
.67429 .82956 m .67738 .81098 L .68858 .81889 L p .707 .577 .707 r
F P
0 g
s
.19145 .70908 m .19378 .65526 L .17292 .6458 L p .707 .577 .707 r
F P
0 g
s
.19378 .65526 m .19145 .70908 L .21876 .71605 L p .707 .577 .707 r
F P
0 g
s
.2462 .78387 m .24869 .74892 L .21772 .74392 L p .707 .577 .707 r
F P
0 g
s
.24869 .74892 m .2462 .78387 L .27802 .78479 L p .707 .577 .707 r
F P
0 g
s
.27802 .78479 m .28051 .74985 L .24869 .74892 L p .707 .577 .707 r
F P
0 g
s
.28051 .74985 m .27802 .78479 L .30757 .78155 L p .707 .577 .707 r
F P
0 g
s
.30757 .78155 m .31006 .74661 L .28051 .74985 L p .707 .577 .707 r
F P
0 g
s
.33765 .65637 m .33533 .71019 L .35189 .70102 L p .707 .577 .707 r
F P
0 g
s
.35189 .70102 m .35422 .64719 L .33765 .65637 L p .707 .577 .707 r
F P
0 g
s
.6683 .65491 m .66288 .71082 L .63569 .7045 L p .707 .577 .707 r
F P
0 g
s
.63569 .7045 m .64111 .64859 L .6683 .65491 L p .707 .577 .707 r
F P
0 g
s
.66332 .74041 m .6575 .77761 L .63073 .77008 L p .707 .577 .707 r
F P
0 g
s
.63073 .77008 m .63655 .73288 L .66332 .74041 L p .707 .577 .707 r
F P
0 g
s
.62811 .81352 m .6312 .79494 L .6576 .80273 L p .707 .577 .707 r
F P
0 g
s
.62507 .30061 m .62507 .8025 L .64115 .79119 L p .707 .577 .707 r
F P
0 g
s
.64115 .79119 m .64115 .2893 L .62507 .30061 L p .707 .577 .707 r
F P
0 g
s
.21523 .77887 m .21772 .74392 L .19063 .73534 L p .707 .577 .707 r
F P
0 g
s
.21772 .74392 m .21523 .77887 L .2462 .78387 L p .707 .577 .707 r
F P
0 g
s
.68359 .74852 m .67777 .78572 L .6575 .77761 L p .707 .577 .707 r
F P
0 g
s
.6575 .77761 m .66332 .74041 L .68359 .74852 L p .707 .577 .707 r
F P
0 g
s
.17292 .6458 m .17059 .69962 L .19145 .70908 L p .707 .577 .707 r
F P
0 g
s
.17059 .69962 m .17292 .6458 L .16056 .63477 L p .707 .577 .707 r
F P
0 g
s
.31006 .74661 m .30757 .78155 L .33195 .77447 L p .707 .577 .707 r
F P
0 g
s
.33195 .77447 m .33445 .73952 L .31006 .74661 L p .707 .577 .707 r
F P
0 g
s
.36834 .79903 m .36835 .29714 L .35658 .28545 L p .707 .577 .707 r
F P
0 g
s
.36835 .29714 m .36834 .79903 L .393 .80918 L p .707 .577 .707 r
F P
0 g
s
.67738 .81098 m .67429 .82956 L .65452 .82131 L p .707 .577 .707 r
F P
0 g
s
.65452 .82131 m .6576 .80273 L .67738 .81098 L p .707 .577 .707 r
F P
0 g
s
.18814 .77028 m .19063 .73534 L .17007 .72401 L p .707 .577 .707 r
F P
0 g
s
.19063 .73534 m .18814 .77028 L .21523 .77887 L p .707 .577 .707 r
F P
0 g
s
.24247 .82559 m .24378 .80822 L .21296 .80281 L p .707 .577 .707 r
F P
0 g
s
.24378 .80822 m .24247 .82559 L .27432 .82683 L p .707 .577 .707 r
F P
0 g
s
.27432 .82683 m .27563 .80946 L .24378 .80822 L p .707 .577 .707 r
F P
0 g
s
.27563 .80946 m .27432 .82683 L .30407 .82378 L p .707 .577 .707 r
F P
0 g
s
.30407 .82378 m .30539 .80642 L .27563 .80946 L p .707 .577 .707 r
F P
0 g
s
.21165 .82018 m .21296 .80281 L .18619 .79377 L p .707 .577 .707 r
F P
0 g
s
.21296 .80281 m .21165 .82018 L .24247 .82559 L p .707 .577 .707 r
F P
0 g
s
.35422 .64719 m .35189 .70102 L .3592 .69014 L p .707 .577 .707 r
F P
0 g
s
.3592 .69014 m .36153 .63632 L .35422 .64719 L p .707 .577 .707 r
F P
0 g
s
.33445 .73952 m .33195 .77447 L .34879 .76423 L p .707 .577 .707 r
F P
0 g
s
.34879 .76423 m .35128 .72929 L .33445 .73952 L p .707 .577 .707 r
F P
0 g
s
.16056 .63477 m .15823 .68859 L .17059 .69962 L p .707 .577 .707 r
F P
0 g
s
.17007 .72401 m .16757 .75896 L .18814 .77028 L p .707 .577 .707 r
F P
0 g
s
.30539 .80642 m .30407 .82378 L .32883 .81675 L p .707 .577 .707 r
F P
0 g
s
.32883 .81675 m .33014 .79938 L .30539 .80642 L p .707 .577 .707 r
F P
0 g
s
.18619 .79377 m .18488 .81114 L .21165 .82018 L p .707 .577 .707 r
F P
0 g
s
.15823 .68859 m .16056 .63477 L .1579 .62325 L p .707 .577 .707 r
F P
0 g
s
.16757 .75896 m .17007 .72401 L .15805 .71105 L p .707 .577 .707 r
F P
0 g
s
.6576 .80273 m .65452 .82131 L .62811 .81352 L p .707 .577 .707 r
F P
0 g
s
.18488 .81114 m .18619 .79377 L .16609 .78197 L p .707 .577 .707 r
F P
0 g
s
.64115 .2893 m .64115 .79119 L .64342 .77909 L p .707 .577 .707 r
F P
0 g
s
.64342 .77909 m .64342 .2772 L .64115 .2893 L p .707 .577 .707 r
F P
0 g
s
.16609 .78197 m .16478 .79934 L .18488 .81114 L p .707 .577 .707 r
F P
0 g
s
.33014 .79938 m .32883 .81675 L .34617 .80641 L p .707 .577 .707 r
F P
0 g
s
.34617 .80641 m .34748 .78904 L .33014 .79938 L p .707 .577 .707 r
F P
0 g
s
.15805 .71105 m .15555 .74599 L .16757 .75896 L p .707 .577 .707 r
F P
0 g
s
.35128 .72929 m .34879 .76423 L .35644 .75184 L p .707 .577 .707 r
F P
0 g
s
.35644 .75184 m .35893 .71689 L .35128 .72929 L p .707 .577 .707 r
F P
0 g
s
.36153 .63632 m .3592 .69014 L .35655 .67862 L p .707 .577 .707 r
F P
0 g
s
.35655 .67862 m .35887 .6248 L .36153 .63632 L p .707 .577 .707 r
F P
0 g
s
.35893 .71689 m .35644 .75184 L .35413 .73851 L p .707 .577 .707 r
F P
0 g
s
.35413 .73851 m .35663 .70356 L .35893 .71689 L p .707 .577 .707 r
F P
0 g
s
.35887 .6248 m .35655 .67862 L .34419 .66759 L p .707 .577 .707 r
F P
0 g
s
.34419 .66759 m .34651 .61377 L .35887 .6248 L p .707 .577 .707 r
F P
0 g
s
.35663 .70356 m .35413 .73851 L .34211 .72555 L p .707 .577 .707 r
F P
0 g
s
.34211 .72555 m .3446 .6906 L .35663 .70356 L p .707 .577 .707 r
F P
0 g
s
.35658 .28545 m .35657 .78734 L .36834 .79903 L p .707 .577 .707 r
F P
0 g
s
.35657 .78734 m .35658 .28545 L .35884 .27336 L p .707 .577 .707 r
F P
0 g
s
.1579 .62325 m .15558 .67707 L .15823 .68859 L p .707 .577 .707 r
F P
0 g
s
.16478 .79934 m .16609 .78197 L .15462 .76858 L p .707 .577 .707 r
F P
0 g
s
.15555 .74599 m .15805 .71105 L .15574 .69772 L p .707 .577 .707 r
F P
0 g
s
.15558 .67707 m .1579 .62325 L .16521 .61237 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15462 .76858 m .15331 .78595 L .16478 .79934 L p .707 .577 .707 r
F P
0 g
s
.34748 .78904 m .34617 .80641 L .35438 .79379 L p .707 .577 .707 r
F P
0 g
s
.35438 .79379 m .35569 .77642 L .34748 .78904 L p .707 .577 .707 r
F P
0 g
s
.15574 .69772 m .15325 .73266 L .15555 .74599 L p .707 .577 .707 r
F P
0 g
s
.64342 .2772 m .64342 .77909 L .63165 .7674 L p .707 .577 .707 r
F P
0 g
s
.63165 .7674 m .63165 .26551 L .64342 .2772 L p .707 .577 .707 r
F P
0 g
s
.16521 .61237 m .16289 .66619 L .15558 .67707 L p .707 .577 .707 r
F P
0 g
s
.15331 .78595 m .15462 .76858 L .15291 .75491 L p .707 .577 .707 r
F P
0 g
s
.15325 .73266 m .15574 .69772 L .16339 .68533 L p .707 .577 .707 r
F P
0 g
s
.16289 .66619 m .16521 .61237 L .18177 .6032 L p .707 .577 .707 r
F P
0 g
s
.15291 .75491 m .1516 .77227 L .15331 .78595 L p .707 .577 .707 r
F P
0 g
s
.35884 .77525 m .35884 .27336 L .37493 .26205 L p .707 .577 .707 r
F P
0 g
s
.35884 .27336 m .35884 .77525 L .35657 .78734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35569 .77642 m .35438 .79379 L .35267 .78011 L p .707 .577 .707 r
F P
0 g
s
.35267 .78011 m .35398 .76274 L .35569 .77642 L p .707 .577 .707 r
F P
0 g
s
.16339 .68533 m .16089 .72027 L .15325 .73266 L p .707 .577 .707 r
F P
0 g
s
.34651 .61377 m .34419 .66759 L .32333 .65813 L p .707 .577 .707 r
F P
0 g
s
.32333 .65813 m .32565 .60431 L .34651 .61377 L p .707 .577 .707 r
F P
0 g
s
.18177 .6032 m .17945 .65702 L .16289 .66619 L p .707 .577 .707 r
F P
0 g
s
.1516 .77227 m .15291 .75491 L .16112 .74228 L p .707 .577 .707 r
F P
0 g
s
.17945 .65702 m .18177 .6032 L .20596 .59663 L p .707 .577 .707 r
F P
0 g
s
.16089 .72027 m .16339 .68533 L .18022 .67509 L p .707 .577 .707 r
F P
0 g
s
.16112 .74228 m .15981 .75965 L .1516 .77227 L p .707 .577 .707 r
F P
0 g
s
.63165 .26551 m .63165 .7674 L .607 .75726 L p .707 .577 .707 r
F P
0 g
s
.607 .75726 m .607 .25537 L .63165 .26551 L p .707 .577 .707 r
F P
0 g
s
.35398 .76274 m .35267 .78011 L .3412 .76672 L p .707 .577 .707 r
F P
0 g
s
.3412 .76672 m .34251 .74935 L .35398 .76274 L p .707 .577 .707 r
F P
0 g
s
.32565 .60431 m .32333 .65813 L .29602 .65116 L p .707 .577 .707 r
F P
0 g
s
.29602 .65116 m .29834 .59734 L .32565 .60431 L p .707 .577 .707 r
F P
0 g
s
.18022 .67509 m .17773 .71003 L .16089 .72027 L p .707 .577 .707 r
F P
0 g
s
.3446 .6906 m .34211 .72555 L .32155 .71422 L p .707 .577 .707 r
F P
0 g
s
.32155 .71422 m .32404 .67927 L .3446 .6906 L p .707 .577 .707 r
F P
0 g
s
.37493 .76393 m .37493 .26205 L .40326 .25262 L p .707 .577 .707 r
F P
0 g
s
.37493 .26205 m .37493 .76393 L .35884 .77525 L p .707 .577 .707 r
F P
0 g
s
.20364 .65045 m .20596 .59663 L .23542 .5933 L p .707 .577 .707 r
F P
0 g
s
.20596 .59663 m .20364 .65045 L .17945 .65702 L p .707 .577 .707 r
F P
0 g
s
.15981 .75965 m .16112 .74228 L .17845 .73195 L p .707 .577 .707 r
F P
0 g
s
.17773 .71003 m .18022 .67509 L .20461 .668 L p .707 .577 .707 r
F P
0 g
s
.29834 .59734 m .29602 .65116 L .26492 .64737 L p .707 .577 .707 r
F P
0 g
s
.26492 .64737 m .26725 .59355 L .29834 .59734 L p .707 .577 .707 r
F P
0 g
s
.23309 .64712 m .23542 .5933 L .26725 .59355 L p .707 .577 .707 r
F P
0 g
s
.23542 .5933 m .23309 .64712 L .20364 .65045 L p .707 .577 .707 r
F P
0 g
s
.17845 .73195 m .17714 .74931 L .15981 .75965 L p .707 .577 .707 r
F P
0 g
s
.26725 .59355 m .26492 .64737 L .23309 .64712 L p .707 .577 .707 r
F P
0 g
s
.73507 .64974 m .73275 .59299 L .70166 .59294 L p .707 .577 .707 r
F P
0 g
s
.73275 .59299 m .73507 .64974 L .7669 .64801 L p .707 .577 .707 r
F P
0 g
s
.7669 .64801 m .76458 .59126 L .73275 .59299 L p .707 .577 .707 r
F P
0 g
s
.32404 .67927 m .32155 .71422 L .29445 .70563 L p .707 .577 .707 r
F P
0 g
s
.29445 .70563 m .29695 .67069 L .32404 .67927 L p .707 .577 .707 r
F P
0 g
s
.76458 .59126 m .7669 .64801 L .79636 .64467 L p .707 .577 .707 r
F P
0 g
s
.79636 .64467 m .79403 .58791 L .76458 .59126 L p .707 .577 .707 r
F P
0 g
s
.34251 .74935 m .3412 .76672 L .32109 .75492 L p .707 .577 .707 r
F P
0 g
s
.32109 .75492 m .32241 .73756 L .34251 .74935 L p .707 .577 .707 r
F P
0 g
s
.20461 .668 m .20212 .70295 L .17773 .71003 L p .707 .577 .707 r
F P
0 g
s
.607 .25537 m .607 .75726 L .57187 .74966 L p .707 .577 .707 r
F P
0 g
s
.57187 .74966 m .57186 .24777 L .607 .25537 L p .707 .577 .707 r
F P
0 g
s
.70398 .64969 m .70166 .59294 L .67435 .5911 L p .707 .577 .707 r
F P
0 g
s
.70166 .59294 m .70398 .64969 L .73507 .64974 L p .707 .577 .707 r
F P
0 g
s
.20212 .70295 m .20461 .668 L .23416 .66476 L p .707 .577 .707 r
F P
0 g
s
.17714 .74931 m .17845 .73195 L .20321 .72491 L p .707 .577 .707 r
F P
0 g
s
.79403 .58791 m .79636 .64467 L .82055 .64004 L p .707 .577 .707 r
F P
0 g
s
.82055 .64004 m .81822 .58328 L .79403 .58791 L p .707 .577 .707 r
F P
0 g
s
.40326 .25262 m .40326 .75451 L .37493 .76393 L p .707 .577 .707 r
F P
0 g
s
.40326 .75451 m .40326 .25262 L .44106 .246 L p .707 .577 .707 r
F P
0 g
s
.73651 .70579 m .73402 .66767 L .70305 .66877 L p .707 .577 .707 r
F P
0 g
s
.73402 .66767 m .73651 .70579 L .76833 .70347 L p .707 .577 .707 r
F P
0 g
s
.76833 .70347 m .76584 .66535 L .73402 .66767 L p .707 .577 .707 r
F P
0 g
s
.29695 .67069 m .29445 .70563 L .26348 .70063 L p .707 .577 .707 r
F P
0 g
s
.26348 .70063 m .26598 .66569 L .29695 .67069 L p .707 .577 .707 r
F P
0 g
s
.67435 .5911 m .67667 .64786 L .70398 .64969 L p .707 .577 .707 r
F P
0 g
s
.76584 .66535 m .76833 .70347 L .79788 .70016 L p .707 .577 .707 r
F P
0 g
s
.79788 .70016 m .79539 .66204 L .76584 .66535 L p .707 .577 .707 r
F P
0 g
s
.23167 .69971 m .23416 .66476 L .26598 .66569 L p .707 .577 .707 r
F P
0 g
s
.23416 .66476 m .23167 .69971 L .20212 .70295 L p .707 .577 .707 r
F P
0 g
s
.70305 .66877 m .70554 .7069 L .73651 .70579 L p .707 .577 .707 r
F P
0 g
s
.20321 .72491 m .2019 .74228 L .17714 .74931 L p .707 .577 .707 r
F P
0 g
s
.26598 .66569 m .26348 .70063 L .23167 .69971 L p .707 .577 .707 r
F P
0 g
s
.70554 .7069 m .70305 .66877 L .67596 .66855 L p .707 .577 .707 r
F P
0 g
s
.67667 .64786 m .67435 .5911 L .65349 .58768 L p .707 .577 .707 r
F P
0 g
s
.32241 .73756 m .32109 .75492 L .29432 .74588 L p .707 .577 .707 r
F P
0 g
s
.29432 .74588 m .29564 .72851 L .32241 .73756 L p .707 .577 .707 r
F P
0 g
s
.73649 .74777 m .73518 .72869 L .70436 .72993 L p .707 .577 .707 r
F P
0 g
s
.73518 .72869 m .73649 .74777 L .76834 .74543 L p .707 .577 .707 r
F P
0 g
s
.76834 .74543 m .76703 .72634 L .73518 .72869 L p .707 .577 .707 r
F P
0 g
s
.76703 .72634 m .76834 .74543 L .7981 .74221 L p .707 .577 .707 r
F P
0 g
s
.7981 .74221 m .79678 .72313 L .76703 .72634 L p .707 .577 .707 r
F P
0 g
s
.70436 .72993 m .70567 .74901 L .73649 .74777 L p .707 .577 .707 r
F P
0 g
s
.67596 .66855 m .67845 .70668 L .70554 .7069 L p .707 .577 .707 r
F P
0 g
s
.79539 .66204 m .79788 .70016 L .82227 .69619 L p .707 .577 .707 r
F P
0 g
s
.82227 .69619 m .81977 .65807 L .79539 .66204 L p .707 .577 .707 r
F P
0 g
s
.2019 .74228 m .20321 .72491 L .23297 .72186 L p .707 .577 .707 r
F P
0 g
s
.57186 .24777 m .57187 .74966 L .5297 .74534 L p .707 .577 .707 r
F P
0 g
s
.5297 .74534 m .5297 .24345 L .57186 .24777 L p .707 .577 .707 r
F P
0 g
s
.65349 .58768 m .65581 .64443 L .67667 .64786 L p .707 .577 .707 r
F P
0 g
s
.70567 .74901 m .70436 .72993 L .67759 .72994 L p .707 .577 .707 r
F P
0 g
s
.81822 .58328 m .82055 .64004 L .83711 .63457 L p .707 .577 .707 r
F P
0 g
s
.83711 .63457 m .83479 .57782 L .81822 .58328 L p .707 .577 .707 r
F P
0 g
s
.67759 .72994 m .6789 .74903 L .70567 .74901 L p .707 .577 .707 r
F P
0 g
s
.79678 .72313 m .7981 .74221 L .82286 .73843 L p .707 .577 .707 r
F P
0 g
s
.82286 .73843 m .82154 .71935 L .79678 .72313 L p .707 .577 .707 r
F P
0 g
s
.44106 .74789 m .44106 .246 L .48463 .24284 L p .707 .577 .707 r
F P
0 g
s
.44106 .246 m .44106 .74789 L .40326 .75451 L p .707 .577 .707 r
F P
0 g
s
.29564 .72851 m .29432 .74588 L .26351 .74047 L p .707 .577 .707 r
F P
0 g
s
.26351 .74047 m .26482 .72311 L .29564 .72851 L p .707 .577 .707 r
F P
0 g
s
.23297 .72186 m .23166 .73923 L .2019 .74228 L p .707 .577 .707 r
F P
0 g
s
.67845 .70668 m .67596 .66855 L .65539 .66703 L p .707 .577 .707 r
F P
0 g
s
.23166 .73923 m .23297 .72186 L .26482 .72311 L p .707 .577 .707 r
F P
0 g
s
.65539 .66703 m .65789 .70516 L .67845 .70668 L p .707 .577 .707 r
F P
0 g
s
.26482 .72311 m .26351 .74047 L .23166 .73923 L p .707 .577 .707 r
F P
0 g
s
.65581 .64443 m .65349 .58768 L .64113 .58298 L p .707 .577 .707 r
F P
0 g
s
.5297 .24345 m .5297 .74534 L .48463 .74473 L p .707 .577 .707 r
F P
0 g
s
.48463 .74473 m .48463 .24284 L .5297 .24345 L p .707 .577 .707 r
F P
0 g
s
.81977 .65807 m .82227 .69619 L .8391 .69194 L p .707 .577 .707 r
F P
0 g
s
.8391 .69194 m .83661 .65382 L .81977 .65807 L p .707 .577 .707 r
F P
0 g
s
.48463 .24284 m .48463 .74473 L .44106 .74789 L p .707 .577 .707 r
F P
0 g
s
.6789 .74903 m .67759 .72994 L .65749 .72873 L p .707 .577 .707 r
F P
0 g
s
.65749 .72873 m .6588 .74781 L .6789 .74903 L p .707 .577 .707 r
F P
0 g
s
.64113 .58298 m .64345 .63974 L .65581 .64443 L p .707 .577 .707 r
F P
0 g
s
.82154 .71935 m .82286 .73843 L .84019 .73446 L p .707 .577 .707 r
F P
0 g
s
.84019 .73446 m .83888 .71538 L .82154 .71935 L p .707 .577 .707 r
F P
0 g
s
.83479 .57782 m .83711 .63457 L .84442 .62881 L p .707 .577 .707 r
F P
0 g
s
.84442 .62881 m .8421 .57206 L .83479 .57782 L p .707 .577 .707 r
F P
0 g
s
.65789 .70516 m .65539 .66703 L .64337 .66436 L p .707 .577 .707 r
F P
0 g
s
.64337 .66436 m .64586 .70249 L .65789 .70516 L p .707 .577 .707 r
F P
0 g
s
.6588 .74781 m .65749 .72873 L .64602 .72641 L p .707 .577 .707 r
F P
0 g
s
.83661 .65382 m .8391 .69194 L .84675 .68784 L p .707 .577 .707 r
F P
0 g
s
.84675 .68784 m .84426 .64971 L .83661 .65382 L p .707 .577 .707 r
F P
0 g
s
.64345 .63974 m .64113 .58298 L .63847 .57749 L p .707 .577 .707 r
F P
0 g
s
.64602 .72641 m .64733 .74549 L .6588 .74781 L p .707 .577 .707 r
F P
0 g
s
.83888 .71538 m .84019 .73446 L .8484 .73069 L p .707 .577 .707 r
F P
0 g
s
.8484 .73069 m .84709 .71161 L .83888 .71538 L p .707 .577 .707 r
F P
0 g
s
.63847 .57749 m .6408 .63424 L .64345 .63974 L p .707 .577 .707 r
F P
0 g
s
.8421 .57206 m .84442 .62881 L .84177 .62332 L p .707 .577 .707 r
F P
0 g
s
.84177 .62332 m .83944 .56656 L .8421 .57206 L p .707 .577 .707 r
F P
0 g
s
.64586 .70249 m .64337 .66436 L .64107 .6608 L p .707 .577 .707 r
F P
0 g
s
.64107 .6608 m .64356 .69892 L .64586 .70249 L p .707 .577 .707 r
F P
0 g
s
.64733 .74549 m .64602 .72641 L .64431 .7232 L p .707 .577 .707 r
F P
0 g
s
.84426 .64971 m .84675 .68784 L .84445 .68427 L p .707 .577 .707 r
F P
0 g
s
.84445 .68427 m .84195 .64615 L .84426 .64971 L p .707 .577 .707 r
F P
0 g
s
.64431 .7232 m .64562 .74229 L .64733 .74549 L p .707 .577 .707 r
F P
0 g
s
.6408 .63424 m .63847 .57749 L .64578 .57173 L p .707 .577 .707 r
F P
0 g
s
.84709 .71161 m .8484 .73069 L .84669 .72749 L p .707 .577 .707 r
F P
0 g
s
.84669 .72749 m .84538 .7084 L .84709 .71161 L p .707 .577 .707 r
F P
0 g
s
.64578 .57173 m .64811 .62848 L .6408 .63424 L p .707 .577 .707 r
F P
0 g
s
.83944 .56656 m .84177 .62332 L .8294 .61862 L p .707 .577 .707 r
F P
0 g
s
.8294 .61862 m .82708 .56187 L .83944 .56656 L p .707 .577 .707 r
F P
0 g
s
.64356 .69892 m .64107 .6608 L .64871 .65669 L p .707 .577 .707 r
F P
0 g
s
.64871 .65669 m .65121 .69482 L .64356 .69892 L p .707 .577 .707 r
F P
0 g
s
.39528 .62439 m .38985 .56971 L .35888 .57024 L p .707 .577 .707 r
F P
0 g
s
.38985 .56971 m .39528 .62439 L .427 .62074 L p .707 .577 .707 r
F P
0 g
s
.427 .62074 m .42157 .56606 L .38985 .56971 L p .707 .577 .707 r
F P
0 g
s
.42157 .56606 m .427 .62074 L .45636 .61432 L p .707 .577 .707 r
F P
0 g
s
.45636 .61432 m .45094 .55964 L .42157 .56606 L p .707 .577 .707 r
F P
0 g
s
.64562 .74229 m .64431 .7232 L .65252 .71943 L p .707 .577 .707 r
F P
0 g
s
.64811 .62848 m .64578 .57173 L .66234 .56626 L p .707 .577 .707 r
F P
0 g
s
.84195 .64615 m .84445 .68427 L .83242 .6816 L p .707 .577 .707 r
F P
0 g
s
.83242 .6816 m .82993 .64348 L .84195 .64615 L p .707 .577 .707 r
F P
0 g
s
.65252 .71943 m .65383 .73852 L .64562 .74229 L p .707 .577 .707 r
F P
0 g
s
.36431 .62492 m .35888 .57024 L .3317 .56759 L p .707 .577 .707 r
F P
0 g
s
.35888 .57024 m .36431 .62492 L .39528 .62439 L p .707 .577 .707 r
F P
0 g
s
.84538 .7084 m .84669 .72749 L .83522 .72517 L p .707 .577 .707 r
F P
0 g
s
.83522 .72517 m .83391 .70608 L .84538 .7084 L p .707 .577 .707 r
F P
0 g
s
.45094 .55964 m .45636 .61432 L .4805 .60577 L p .707 .577 .707 r
F P
0 g
s
.4805 .60577 m .47507 .55109 L .45094 .55964 L p .707 .577 .707 r
F P
0 g
s
.66234 .56626 m .66467 .62302 L .64811 .62848 L p .707 .577 .707 r
F P
0 g
s
.82708 .56187 m .8294 .61862 L .80855 .6152 L p .707 .577 .707 r
F P
0 g
s
.80855 .6152 m .80622 .55844 L .82708 .56187 L p .707 .577 .707 r
F P
0 g
s
.65121 .69482 m .64871 .65669 L .66555 .65245 L p .707 .577 .707 r
F P
0 g
s
.33712 .62227 m .3317 .56759 L .31095 .56203 L p .707 .577 .707 r
F P
0 g
s
.3317 .56759 m .33712 .62227 L .36431 .62492 L p .707 .577 .707 r
F P
0 g
s
.66555 .65245 m .66804 .69057 L .65121 .69482 L p .707 .577 .707 r
F P
0 g
s
.39992 .6868 m .39409 .65089 L .36345 .65276 L p .707 .577 .707 r
F P
0 g
s
.39409 .65089 m .39992 .6868 L .43144 .68152 L p .707 .577 .707 r
F P
0 g
s
.43144 .68152 m .42562 .64561 L .39409 .65089 L p .707 .577 .707 r
F P
0 g
s
.42562 .64561 m .43144 .68152 L .46076 .67336 L p .707 .577 .707 r
F P
0 g
s
.46076 .67336 m .45494 .63745 L .42562 .64561 L p .707 .577 .707 r
F P
0 g
s
.66467 .62302 m .66234 .56626 L .68654 .56163 L p .707 .577 .707 r
F P
0 g
s
.47507 .55109 m .4805 .60577 L .49704 .59591 L p .707 .577 .707 r
F P
0 g
s
.49704 .59591 m .49161 .54123 L .47507 .55109 L p .707 .577 .707 r
F P
0 g
s
.82993 .64348 m .83242 .6816 L .81186 .68008 L p .707 .577 .707 r
F P
0 g
s
.81186 .68008 m .80937 .64196 L .82993 .64348 L p .707 .577 .707 r
F P
0 g
s
.65383 .73852 m .65252 .71943 L .66985 .71546 L p .707 .577 .707 r
F P
0 g
s
.36927 .68867 m .36345 .65276 L .33668 .65105 L p .707 .577 .707 r
F P
0 g
s
.36345 .65276 m .36927 .68867 L .39992 .6868 L p .707 .577 .707 r
F P
0 g
s
.66985 .71546 m .67117 .73455 L .65383 .73852 L p .707 .577 .707 r
F P
0 g
s
.45494 .63745 m .46076 .67336 L .485 .66312 L p .707 .577 .707 r
F P
0 g
s
.485 .66312 m .47917 .62721 L .45494 .63745 L p .707 .577 .707 r
F P
0 g
s
.68654 .56163 m .68886 .61839 L .66467 .62302 L p .707 .577 .707 r
F P
0 g
s
.80622 .55844 m .80855 .6152 L .78124 .61336 L p .707 .577 .707 r
F P
0 g
s
.78124 .61336 m .77891 .55661 L .80622 .55844 L p .707 .577 .707 r
F P
0 g
s
.83391 .70608 m .83522 .72517 L .81512 .72395 L p .707 .577 .707 r
F P
0 g
s
.81512 .72395 m .8138 .70487 L .83391 .70608 L p .707 .577 .707 r
F P
0 g
s
.31095 .56203 m .31637 .6167 L .33712 .62227 L p .707 .577 .707 r
F P
0 g
s
.43385 .7234 m .43076 .70548 L .39925 .71083 L p .707 .577 .707 r
F P
0 g
s
.43076 .70548 m .43385 .7234 L .46334 .71512 L p .707 .577 .707 r
F P
0 g
s
.46334 .71512 m .46026 .6972 L .43076 .70548 L p .707 .577 .707 r
F P
0 g
s
.40233 .72875 m .39925 .71083 L .3688 .71274 L p .707 .577 .707 r
F P
0 g
s
.39925 .71083 m .40233 .72875 L .43385 .7234 L p .707 .577 .707 r
F P
0 g
s
.33668 .65105 m .3425 .68696 L .36927 .68867 L p .707 .577 .707 r
F P
0 g
s
.66804 .69057 m .66555 .65245 L .68994 .64847 L p .707 .577 .707 r
F P
0 g
s
.31637 .6167 m .31095 .56203 L .29868 .55409 L p .707 .577 .707 r
F P
0 g
s
.68886 .61839 m .68654 .56163 L .71599 .55829 L p .707 .577 .707 r
F P
0 g
s
.3425 .68696 m .33668 .65105 L .3164 .64593 L p .707 .577 .707 r
F P
0 g
s
.3688 .71274 m .37188 .73065 L .40233 .72875 L p .707 .577 .707 r
F P
0 g
s
.68994 .64847 m .69243 .6866 L .66804 .69057 L p .707 .577 .707 r
F P
0 g
s
.47917 .62721 m .485 .66312 L .50179 .65179 L p .707 .577 .707 r
F P
0 g
s
.50179 .65179 m .49596 .61588 L .47917 .62721 L p .707 .577 .707 r
F P
0 g
s
.46026 .6972 m .46334 .71512 L .48793 .70472 L p .707 .577 .707 r
F P
0 g
s
.48793 .70472 m .48485 .68681 L .46026 .6972 L p .707 .577 .707 r
F P
0 g
s
.37188 .73065 m .3688 .71274 L .34239 .711 L p .707 .577 .707 r
F P
0 g
s
.77891 .55661 m .78124 .61336 L .75014 .61331 L p .707 .577 .707 r
F P
0 g
s
.75014 .61331 m .74782 .55656 L .77891 .55661 L p .707 .577 .707 r
F P
0 g
s
.80937 .64196 m .81186 .68008 L .78477 .67986 L p .707 .577 .707 r
F P
0 g
s
.78477 .67986 m .78228 .64174 L .80937 .64196 L p .707 .577 .707 r
F P
0 g
s
.49161 .54123 m .49704 .59591 L .50437 .58571 L p .707 .577 .707 r
F P
0 g
s
.50437 .58571 m .49894 .53104 L .49161 .54123 L p .707 .577 .707 r
F P
0 g
s
.67117 .73455 m .66985 .71546 L .69461 .71169 L p .707 .577 .707 r
F P
0 g
s
.71599 .55829 m .71831 .61504 L .68886 .61839 L p .707 .577 .707 r
F P
0 g
s
.69461 .71169 m .69592 .73077 L .67117 .73455 L p .707 .577 .707 r
F P
0 g
s
.34239 .711 m .34548 .72892 L .37188 .73065 L p .707 .577 .707 r
F P
0 g
s
.71831 .61504 m .71599 .55829 L .74782 .55656 L p .707 .577 .707 r
F P
0 g
s
.3164 .64593 m .32223 .68184 L .3425 .68696 L p .707 .577 .707 r
F P
0 g
s
.74782 .55656 m .75014 .61331 L .71831 .61504 L p .707 .577 .707 r
F P
0 g
s
.29868 .55409 m .3041 .60877 L .31637 .6167 L p .707 .577 .707 r
F P
0 g
s
.8138 .70487 m .81512 .72395 L .78835 .72397 L p .707 .577 .707 r
F P
0 g
s
.78835 .72397 m .78703 .70488 L .8138 .70487 L p .707 .577 .707 r
F P
0 g
s
.69243 .6866 m .68994 .64847 L .71949 .64517 L p .707 .577 .707 r
F P
0 g
s
.48485 .68681 m .48793 .70472 L .50521 .69323 L p .707 .577 .707 r
F P
0 g
s
.50521 .69323 m .50212 .67531 L .48485 .68681 L p .707 .577 .707 r
F P
0 g
s
.71949 .64517 m .72198 .68329 L .69243 .6866 L p .707 .577 .707 r
F P
0 g
s
.34548 .72892 m .34239 .711 L .32262 .7058 L p .707 .577 .707 r
F P
0 g
s
.78228 .64174 m .78477 .67986 L .7538 .68097 L p .707 .577 .707 r
F P
0 g
s
.7538 .68097 m .7513 .64285 L .78228 .64174 L p .707 .577 .707 r
F P
0 g
s
.32223 .68184 m .3164 .64593 L .30461 .63788 L p .707 .577 .707 r
F P
0 g
s
.3041 .60877 m .29868 .55409 L .29608 .54456 L p .707 .577 .707 r
F P
0 g
s
.49596 .61588 m .50179 .65179 L .50948 .64049 L p .707 .577 .707 r
F P
0 g
s
.50948 .64049 m .50366 .60458 L .49596 .61588 L p .707 .577 .707 r
F P
0 g
s
.69592 .73077 m .69461 .71169 L .72437 .70847 L p .707 .577 .707 r
F P
0 g
s
.32262 .7058 m .32571 .72372 L .34548 .72892 L p .707 .577 .707 r
F P
0 g
s
.72198 .68329 m .71949 .64517 L .7513 .64285 L p .707 .577 .707 r
F P
0 g
s
.72437 .70847 m .72568 .72755 L .69592 .73077 L p .707 .577 .707 r
F P
0 g
s
.7513 .64285 m .7538 .68097 L .72198 .68329 L p .707 .577 .707 r
F P
0 g
s
.78703 .70488 m .78835 .72397 L .75753 .72521 L p .707 .577 .707 r
F P
0 g
s
.75753 .72521 m .75622 .70612 L .78703 .70488 L p .707 .577 .707 r
F P
0 g
s
.49894 .53104 m .50437 .58571 L .50177 .57618 L p .707 .577 .707 r
F P
0 g
s
.50177 .57618 m .49635 .5215 L .49894 .53104 L p .707 .577 .707 r
F P
0 g
s
.30461 .63788 m .31044 .67379 L .32223 .68184 L p .707 .577 .707 r
F P
0 g
s
.72568 .72755 m .72437 .70847 L .75622 .70612 L p .707 .577 .707 r
F P
0 g
s
.75622 .70612 m .75753 .72521 L .72568 .72755 L p .707 .577 .707 r
F P
0 g
s
.29608 .54456 m .3015 .59923 L .3041 .60877 L p .707 .577 .707 r
F P
0 g
s
.50212 .67531 m .50521 .69323 L .51348 .68176 L p .707 .577 .707 r
F P
0 g
s
.51348 .68176 m .51039 .66385 L .50212 .67531 L p .707 .577 .707 r
F P
0 g
s
.32571 .72372 m .32262 .7058 L .31141 .69764 L p .707 .577 .707 r
F P
0 g
s
.31141 .69764 m .3145 .71556 L .32571 .72372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.31044 .67379 m .30461 .63788 L .30246 .62771 L p .708 .578 .707 r
F P
0 g
s
.3015 .59923 m .29608 .54456 L .30341 .53436 L p .707 .577 .707 r
F P
0 g
s
.50366 .60458 m .50948 .64049 L .50733 .63032 L p .708 .578 .707 r
F P
0 g
s
.50733 .63032 m .5015 .59441 L .50366 .60458 L p .708 .578 .707 r
F P
0 g
s
.49635 .5215 m .50177 .57618 L .4895 .56824 L p .707 .577 .707 r
F P
0 g
s
.4895 .56824 m .48407 .51357 L .49635 .5215 L p .707 .577 .707 r
F P
0 g
s
.30246 .62771 m .30828 .66362 L .31044 .67379 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30341 .53436 m .30883 .58904 L .3015 .59923 L p .707 .577 .707 r
F P
0 g
s
.51039 .66385 m .51348 .68176 L .51194 .67145 L p .706 .577 .707 r
F P
0 g
s
.51194 .67145 m .50885 .65353 L .51039 .66385 L p .706 .577 .707 r
F P
0 g
s
.3145 .71556 m .31141 .69764 L .30987 .68732 L p .706 .577 .707 r
F P
0 g
s
.30987 .68732 m .31296 .70524 L .3145 .71556 L p .706 .577 .707 r
F P
0 g
s
.30828 .66362 m .30246 .62771 L .31015 .61641 L p .707 .577 .707 r
F P
0 g
s
.30883 .58904 m .30341 .53436 L .31995 .52451 L p .707 .577 .707 r
F P
0 g
s
.5015 .59441 m .50733 .63032 L .49554 .62228 L p .707 .577 .707 r
F P
0 g
s
.49554 .62228 m .48971 .58637 L .5015 .59441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48407 .51357 m .4895 .56824 L .46875 .56268 L p .707 .577 .707 r
F P
0 g
s
.46875 .56268 m .46333 .508 L .48407 .51357 L p .707 .577 .707 r
F P
0 g
s
.31015 .61641 m .31598 .65232 L .30828 .66362 L p .707 .577 .707 r
F P
0 g
s
.31995 .52451 m .32538 .57918 L .30883 .58904 L p .707 .577 .707 r
F P
0 g
s
.50885 .65353 m .51194 .67145 L .50073 .66329 L p .707 .577 .707 r
F P
0 g
s
.50073 .66329 m .49764 .64537 L .50885 .65353 L p .707 .577 .707 r
F P
0 g
s
.31296 .70524 m .30987 .68732 L .31814 .67586 L p .707 .577 .707 r
F P
0 g
s
.32538 .57918 m .31995 .52451 L .34408 .51595 L p .707 .577 .707 r
F P
0 g
s
.31814 .67586 m .32123 .69377 L .31296 .70524 L p .707 .577 .707 r
F P
0 g
s
.31598 .65232 m .31015 .61641 L .32694 .60508 L p .707 .577 .707 r
F P
0 g
s
.48971 .58637 m .49554 .62228 L .47526 .61715 L p .707 .577 .707 r
F P
0 g
s
.47526 .61715 m .46944 .58124 L .48971 .58637 L p .707 .577 .707 r
F P
0 g
s
.46333 .508 m .46875 .56268 L .44156 .56003 L p .707 .577 .707 r
F P
0 g
s
.44156 .56003 m .43614 .50535 L .46333 .508 L p .707 .577 .707 r
F P
0 g
s
.32694 .60508 m .33276 .64099 L .31598 .65232 L p .707 .577 .707 r
F P
0 g
s
.34408 .51595 m .34951 .57063 L .32538 .57918 L p .707 .577 .707 r
F P
0 g
s
.34951 .57063 m .34408 .51595 L .37345 .50953 L p .707 .577 .707 r
F P
0 g
s
.49764 .64537 m .50073 .66329 L .48096 .65809 L p .707 .577 .707 r
F P
0 g
s
.48096 .65809 m .47787 .64017 L .49764 .64537 L p .707 .577 .707 r
F P
0 g
s
.32123 .69377 m .31814 .67586 L .33542 .66436 L p .707 .577 .707 r
F P
0 g
s
.43614 .50535 m .44156 .56003 L .41059 .56056 L p .707 .577 .707 r
F P
0 g
s
.41059 .56056 m .40517 .50588 L .43614 .50535 L p .707 .577 .707 r
F P
0 g
s
.33276 .64099 m .32694 .60508 L .35118 .59484 L p .707 .577 .707 r
F P
0 g
s
.46944 .58124 m .47526 .61715 L .44849 .61544 L p .707 .577 .707 r
F P
0 g
s
.44849 .61544 m .44267 .57953 L .46944 .58124 L p .707 .577 .707 r
F P
0 g
s
.33542 .66436 m .3385 .68228 L .32123 .69377 L p .707 .577 .707 r
F P
0 g
s
.37887 .56421 m .37345 .50953 L .40517 .50588 L p .707 .577 .707 r
F P
0 g
s
.37345 .50953 m .37887 .56421 L .34951 .57063 L p .707 .577 .707 r
F P
0 g
s
.40517 .50588 m .41059 .56056 L .37887 .56421 L p .707 .577 .707 r
F P
0 g
s
.35118 .59484 m .357 .63075 L .33276 .64099 L p .707 .577 .707 r
F P
0 g
s
.357 .63075 m .35118 .59484 L .3805 .58668 L p .707 .577 .707 r
F P
0 g
s
.44267 .57953 m .44849 .61544 L .41785 .61731 L p .707 .577 .707 r
F P
0 g
s
.41785 .61731 m .41202 .5814 L .44267 .57953 L p .707 .577 .707 r
F P
0 g
s
.47787 .64017 m .48096 .65809 L .45455 .65635 L p .707 .577 .707 r
F P
0 g
s
.45455 .65635 m .45147 .63844 L .47787 .64017 L p .707 .577 .707 r
F P
0 g
s
.3385 .68228 m .33542 .66436 L .36001 .65397 L p .707 .577 .707 r
F P
0 g
s
.36001 .65397 m .36309 .67189 L .3385 .68228 L p .707 .577 .707 r
F P
0 g
s
.38632 .62259 m .3805 .58668 L .41202 .5814 L p .707 .577 .707 r
F P
0 g
s
.3805 .58668 m .38632 .62259 L .357 .63075 L p .707 .577 .707 r
F P
0 g
s
.41202 .5814 m .41785 .61731 L .38632 .62259 L p .707 .577 .707 r
F P
0 g
s
.45147 .63844 m .45455 .65635 L .4241 .65825 L p .707 .577 .707 r
F P
0 g
s
.4241 .65825 m .42102 .64034 L .45147 .63844 L p .707 .577 .707 r
F P
0 g
s
.36309 .67189 m .36001 .65397 L .3895 .64569 L p .707 .577 .707 r
F P
0 g
s
.3895 .64569 m .39259 .66361 L .36309 .67189 L p .707 .577 .707 r
F P
0 g
s
.42102 .64034 m .4241 .65825 L .39259 .66361 L p .707 .577 .707 r
F P
0 g
s
.39259 .66361 m .3895 .64569 L .42102 .64034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Q7oo6000PGoo001hOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001hOol0075oo`L000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007=oo`00Kgoo0P00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1000Kgoo001/Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUH00000KGoo001ZOol20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00Jgoo001Y
Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2001YOol006Moo`800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP80
06Qoo`00IWoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Moo`00IWoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF009JEQ0000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol006Eoo`800003FUH0000000D000AJEP03001JEUYF00EJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001TOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUH0000200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001POol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
IWoo001NOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP00IWoo001LOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP020008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUIJEP00IWoo001JOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00F7oo0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000QJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol005Ioo`80009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP00IWoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00EGoo0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP004Goo8000=Goo001DOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJ
EP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUH000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
035oo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPT0009JEPL000AJEPP0
00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01@000eYF
1`000UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=oo`@000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005Ao
o`04001JEUYF0004FUH00`00FUIJEP03FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00EJEP@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000IJEP03001JEUYF009JEP04001JEP000006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001EOol00`00FUH00002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP090003FUH01000FUIJEUYF20000eYF00@005YFFUH000IJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool005Eoo`03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF0006FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo001EOol01000FUH000001EYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
?goo4@001Goo0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP03001JEUYF00=JEP03
001JEUYF00<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000a
Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00
FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001J
EP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H0
05YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01000FUIJEUYF0P00
;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF5P000UYF
00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000eYF0P00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
00000eYF0000000500000eYF001JEP0:FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000=JEP03001JEP0000<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000QJEP03001J
EUYF00UJEP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010000eYF10002UYF00<005YFFUH01eYF0P00
15YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001J
EUYF00AJEP@0009JEP04001JEUYFFUH5000:FUH00`00FUIJEP05FUH200000eYF001JEP03FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH0000000=JEP04001JEUYFFUH5000:FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02
FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009J
EP03001JEP000080009JEP8000=JEP04001JEUYFFUH50009FUH80004FUH00`00FUIJEP02FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP800003FUH0
05YF009JEP8000=JEP03001JEUYF009JEPd000AJEP04001JEUYFFUH60003FUH01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF7@00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH01P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009o
o`@000=JEP03001JEUYF00EJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008002eoo`00;7oo00<005YF000015YF00<005YFFUH00UYF600015YF00<005YF0000
0UYF1@000eYF00@005YFFUIJEP80009JEP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000Eoo``000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP000080011oo`<000Eo
o`L0009JEP03001JEUYF009JEP/000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEP00FUH02@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00<005YF000015YF0P0000AJ
EP00000000ioo`D000Yoo`<00003FUH005YF00=JEP04001JEUYFFUH200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002eoo`00;7oo00<005YF00000UYF0P0015YF00<005YF00000`002Woo1@002goo0P00
00=JEP00FUH00eYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001J
EUYF00H000=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005
FUH00`00FUIJEP03FUH60004Ool50009Ool30002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF000000020002FUH00`00FUIJEP02
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYF000]Ool002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEP0001/0
009JEP800003FUH005YF009JEP8000MJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP04FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
02aoo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0002FUH01000FUH005YF0P0000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002aoo`00;7oo0P000UYF00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P000UYF00D005YFFUIJEP0000IJEP<000QJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ao
o`00;7oo00@005YFFUIJEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30005FUH01000FUIJEUYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00;7oo
00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001EYF00@005YF000000AJEP03001JEUYF00AJEP<000IJEPH000]JEP03
001JEUYF00<0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00UYF70000UYF
00<007ooOol0:Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20005FUH20006FUH00`00FUIJEP03FUH500000eYF
000000020005FUH00`00FUIJEP09FUH30002FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH0009JEQH000UJEP03001JEUYF00QJEP8000EJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;7oo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030003FUH00`00FUIJEP030003FUH01000FUIJEUYF1@002UYF00<005YFFUH01UYF
0P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YFFUH0009JEP03001JEUYF00D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0P0015YF0P0000AJEP00000000=JEP03001JEUYF009JEP@000YJEP03001JEUYF00AJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYF001JEP040004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH4000aOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000030003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH01000FUIJEUYF0`001UYF00<005YFFUH00P001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Goo000/Ool20004FUH00`00FUIJEP03FUH70007FUH90004FUH00`00FUIJEP02FUH40005FUH00`00
FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH400000eYF001JEP06FUH30009FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000iOol002aoo`8000AJ
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP04FUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF2`0015YF
00<005YFFUH00UYF8P00;Woo000/Ool20004FUH2000017oo000000001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000IJEP00001JEP00FUH300000eYF001JEP02FUH20003FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00eYF00<0
05YF00003@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ao
o`00;7oo0P000UYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`0000=JEP00FUH00eYF50001UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0002FUH50004FUH80003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo
000[Ool00`00FUH00002000<Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH002aoo`00:goo00<005YF00000P004goo4P001Goo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010001eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEP<0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF000/Ool002]oo`8000=JEP03001oogoo00]ooa0000ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP03001JEUYF008002]oo`00:goo
0P000eYF0`001Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0100037oo0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH00UYF5@000eYF00<005YFFUH015YF2@00:goo000[Ool20003FUH00`00FUIJEP05
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;OolD0008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP03FUH01000FUIJEUYF500015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YF000002]oo`00:goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000<000Qoo`03001JEP00008000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH005YF009JEPD000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00:goo0P000eYF0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo0P00
00=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH0
0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF1000<Goo000[Ool200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006
FUH00`00FUIJEP05FUH50003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000/Ool20004FUH00`00FUIJEP03FUH:000;Ool40002FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04
FUHE0009FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>000iOol002aoo`8000AJEP03001JEP00
00<000EJEP03001JEUYF009JEPT000Ioo`@000IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
00<005YFFUH01EYF00<005YFFUH01UYF2@0000=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEQd004Moo`00;7oo0P0015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YFFUH0
0eYF00@005YF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00H000YJEP03001JEUYF00YJEP03
001JEUYF00UJEPL000MJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH2001IOol0
02]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP@000EJEPH000=JEP03001JEUYF00AJEP@000AJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD0009JEP03001JEUYF00AJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUH0001HOol002]oo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH00`00FUH000030003
FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH50005FUH01000FUIJEP0015YF00<005YFFUH00eYF00D005YFFUIJEP0005Moo`00:goo
00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P000eYF
00@005YFFUH000AJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol002]oo`8000Eoo`04001JEUYF
0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH3
0003FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH200001EYF001JEUYF000015YF00<005YFFUH00eYF00@005YF
FUIJEP8005Ioo`00:goo0P001Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00H005YFFUH005YF001FOol002]oo`8000Qoo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEPD0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00H005YFFUH005YF001F
Ool002]oo`03001JEP0000Uoo`@0009JEP03001JEUYF00EJEP03001JEP0000@000=JEP03001JEUYF
00EJEP03001JEUYF00=JEP8000=oo`D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF001JEP05FUH00`00FUIJEP02001GOol002]oo`04001JEUYF000<Ool60004FUH00`00FUH0
00040003FUH00`00FUIJEP05FUH00`00FUH000030007Ool300000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUIJEUYF0P00Egoo000[Ool01@00FUIJEUYF
00004Goo2`000eYF00<005YFFUH00UYF1@002Woo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF0`0000=JEP00FUH00UYF0P00Egoo000[Ool01000FUIJEUYF0`005Woo
30003goo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF0`000UYF
00<005YF0000Egoo000/Ool01000FUIJEP000UYF0P00;Woo00L005YF001oo`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0300000eYF001oo`1FOol002aoo`03001J
EP0000EJEP8002Yoo`<00006FUH007oo001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0006FUH00`00FUIJEP02FUH2001HOol002eoo`8000EJEP04001JEP00000VOol20002FUH20003Ool2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00F7oo
000^Ool00`00FUIJEP03FUH01000FUIJEUYF0`008Goo0P0015YF0P0017oo0P001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0`0000=JEP0000000P001EYF00L005YFFUIJEP00FUH0001HOol002moo`8000=JEP03001JEUYF
00AJEPH001Moo`@00003FUH005YF00=JEP03001oogoo00Eoo`8000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP800003
FUH005YF00AJEP<00003FUH005YF00=JEP8005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
0UYF2@002Goo1@001EYF00<005YFFUH00UYF00<007ooOol01goo0P0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH010000UYF00<0
05YFFUH01EYF00<005YF00000P0000AJEP00000005Yoo`00<goo0`001UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0037oo10001eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF2@000UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00G7oo000fOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH3000BOol50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP060002Ool50002Ool40006FUH00`00FUIJEP03FUH3001JOol003Qoo`<00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP8001Uoo`P000IJEP03001JEUYF
00YJEP03001JEUYF00AJEPP000Qoo`D000Ioo`@0009JEP03001JEUYF00=JEP04001JEUYF001IOol0
03]oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<002=ooaX00003FUH00000
008000]oo`D000Yoo`@000=JEP05001JEUYFFUH0001IOol0041oo`T000AJEP03001JEUYF009JEPH0
03Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00@000Qoo`<000moo`800003FUH005YF009JEP80
05Qoo`00BGoo2@00?Woo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`005Goo0P000UYF00<005YF
0000F7oo002BOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool8000015YF001JEP00
F7oo002EOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YF
FUH00UYF0`00FGoo002IOol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001IOol009eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00FGoo002QOol70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1P00FUIJEUYF001JEP8005Uoo`00Z7oo2@0015YF00<005YFFUH015YF00<005YFFUH00`00Fgoo002a
Ool>001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58523 .7426 m .59397 .6868 L .56327 .68063 L p .707 .577 .707 r
F P
0 g
s
.59397 .6868 m .58523 .7426 L .61673 .74683 L p .707 .577 .707 r
F P
0 g
s
.61673 .74683 m .62547 .69103 L .59397 .6868 L p .707 .577 .707 r
F P
0 g
s
.62547 .69103 m .61673 .74683 L .64596 .74871 L p .707 .577 .707 r
F P
0 g
s
.64596 .74871 m .65471 .69291 L .62547 .69103 L p .707 .577 .707 r
F P
0 g
s
.55452 .73644 m .56327 .68063 L .53638 .67314 L p .707 .577 .707 r
F P
0 g
s
.56327 .68063 m .55452 .73644 L .58523 .7426 L p .707 .577 .707 r
F P
0 g
s
.65471 .69291 m .64596 .74871 L .67006 .74806 L p .707 .577 .707 r
F P
0 g
s
.67006 .74806 m .6788 .69225 L .65471 .69291 L p .707 .577 .707 r
F P
0 g
s
.57346 .79883 m .58278 .76206 L .55283 .75327 L p .707 .577 .707 r
F P
0 g
s
.58278 .76206 m .57346 .79883 L .60444 .80617 L p .707 .577 .707 r
F P
0 g
s
.60444 .80617 m .61376 .7694 L .58278 .76206 L p .707 .577 .707 r
F P
0 g
s
.53638 .67314 m .52764 .72894 L .55452 .73644 L p .707 .577 .707 r
F P
0 g
s
.61376 .7694 m .60444 .80617 L .6334 .81134 L p .707 .577 .707 r
F P
0 g
s
.6334 .81134 m .64272 .77457 L .61376 .7694 L p .707 .577 .707 r
F P
0 g
s
.52764 .72894 m .53638 .67314 L .51593 .66504 L p .707 .577 .707 r
F P
0 g
s
.55283 .75327 m .54351 .79004 L .57346 .79883 L p .707 .577 .707 r
F P
0 g
s
.54351 .79004 m .55283 .75327 L .52683 .74389 L p .707 .577 .707 r
F P
0 g
s
.56333 .84066 m .56824 .82233 L .53867 .81305 L p .707 .577 .707 r
F P
0 g
s
.56824 .82233 m .56333 .84066 L .59422 .8486 L p .707 .577 .707 r
F P
0 g
s
.59422 .8486 m .59914 .83028 L .56824 .82233 L p .707 .577 .707 r
F P
0 g
s
.52683 .74389 m .51751 .78066 L .54351 .79004 L p .707 .577 .707 r
F P
0 g
s
.59914 .83028 m .59422 .8486 L .62342 .85442 L p .707 .577 .707 r
F P
0 g
s
.62342 .85442 m .62834 .8361 L .59914 .83028 L p .707 .577 .707 r
F P
0 g
s
.53867 .81305 m .53375 .83137 L .56333 .84066 L p .707 .577 .707 r
F P
0 g
s
.64272 .77457 m .6334 .81134 L .65751 .81383 L p .707 .577 .707 r
F P
0 g
s
.65751 .81383 m .66683 .77706 L .64272 .77457 L p .707 .577 .707 r
F P
0 g
s
.51593 .66504 m .50719 .72085 L .52764 .72894 L p .707 .577 .707 r
F P
0 g
s
.6788 .69225 m .67006 .74806 L .68665 .74494 L p .707 .577 .707 r
F P
0 g
s
.68665 .74494 m .69539 .68913 L .6788 .69225 L p .707 .577 .707 r
F P
0 g
s
.53375 .83137 m .53867 .81305 L .51331 .80333 L p .707 .577 .707 r
F P
0 g
s
.51751 .78066 m .52683 .74389 L .50733 .73484 L p .707 .577 .707 r
F P
0 g
s
.51331 .80333 m .5084 .82165 L .53375 .83137 L p .707 .577 .707 r
F P
0 g
s
.62834 .8361 m .62342 .85442 L .64806 .85756 L p .707 .577 .707 r
F P
0 g
s
.64806 .85756 m .65298 .83924 L .62834 .8361 L p .707 .577 .707 r
F P
0 g
s
.50719 .72085 m .51593 .66504 L .50393 .65714 L p .707 .577 .707 r
F P
0 g
s
.50733 .73484 m .49801 .77161 L .51751 .78066 L p .707 .577 .707 r
F P
0 g
s
.66683 .77706 m .65751 .81383 L .67442 .81341 L p .707 .577 .707 r
F P
0 g
s
.67442 .81341 m .68374 .77664 L .66683 .77706 L p .707 .577 .707 r
F P
0 g
s
.5084 .82165 m .51331 .80333 L .49466 .79413 L p .707 .577 .707 r
F P
0 g
s
.50393 .65714 m .49519 .71295 L .50719 .72085 L p .707 .577 .707 r
F P
0 g
s
.49466 .79413 m .48974 .81245 L .5084 .82165 L p .707 .577 .707 r
F P
0 g
s
.65298 .83924 m .64806 .85756 L .66573 .8577 L p .707 .577 .707 r
F P
0 g
s
.66573 .8577 m .67065 .83937 L .65298 .83924 L p .707 .577 .707 r
F P
0 g
s
.49801 .77161 m .50733 .73484 L .49623 .727 L p .707 .577 .707 r
F P
0 g
s
.69539 .68913 m .68665 .74494 L .69413 .73965 L p .707 .577 .707 r
F P
0 g
s
.69413 .73965 m .70287 .68384 L .69539 .68913 L p .707 .577 .707 r
F P
0 g
s
.49623 .727 m .48691 .76377 L .49801 .77161 L p .707 .577 .707 r
F P
0 g
s
.49519 .71295 m .50393 .65714 L .50155 .65021 L p .707 .577 .707 r
F P
0 g
s
.48974 .81245 m .49466 .79413 L .48453 .78635 L p .707 .577 .707 r
F P
0 g
s
.68374 .77664 m .67442 .81341 L .68246 .81011 L p .707 .577 .707 r
F P
0 g
s
.68246 .81011 m .69178 .77334 L .68374 .77664 L p .707 .577 .707 r
F P
0 g
s
.48453 .78635 m .47961 .80467 L .48974 .81245 L p .707 .577 .707 r
F P
0 g
s
.50155 .65021 m .49281 .70602 L .49519 .71295 L p .707 .577 .707 r
F P
0 g
s
.67065 .83937 m .66573 .8577 L .6747 .85483 L p .707 .577 .707 r
F P
0 g
s
.6747 .85483 m .67962 .8365 L .67065 .83937 L p .707 .577 .707 r
F P
0 g
s
.48691 .76377 m .49623 .727 L .49462 .72115 L p .707 .577 .707 r
F P
0 g
s
.70287 .68384 m .69413 .73965 L .69175 .73272 L p .707 .577 .707 r
F P
0 g
s
.69175 .73272 m .70049 .67691 L .70287 .68384 L p .707 .577 .707 r
F P
0 g
s
.49462 .72115 m .4853 .75792 L .48691 .76377 L p .707 .577 .707 r
F P
0 g
s
.49281 .70602 m .50155 .65021 L .50903 .64493 L p .707 .577 .707 r
F P
0 g
s
.50903 .64493 m .50029 .70073 L .49281 .70602 L p .707 .577 .707 r
F P
0 g
s
.4853 .75792 m .49462 .72115 L .50267 .71784 L p .707 .577 .707 r
F P
0 g
s
.50267 .71784 m .49335 .75461 L .4853 .75792 L p .707 .577 .707 r
F P
0 g
s
.50029 .70073 m .50903 .64493 L .52562 .6418 L p .707 .577 .707 r
F P
0 g
s
.52562 .6418 m .51688 .69761 L .50029 .70073 L p .707 .577 .707 r
F P
0 g
s
.49335 .75461 m .50267 .71784 L .51958 .71742 L p .707 .577 .707 r
F P
0 g
s
.51958 .71742 m .51025 .75419 L .49335 .75461 L p .707 .577 .707 r
F P
0 g
s
.48797 .7962 m .49289 .77788 L .51056 .77801 L p .707 .577 .707 r
F P
0 g
s
.51056 .77801 m .50564 .79634 L .48797 .7962 L p .707 .577 .707 r
F P
0 g
s
.50283 .82192 m .50283 .32003 L .45812 .31837 L p .707 .577 .707 r
F P
0 g
s
.51688 .69761 m .52562 .6418 L .54972 .64115 L p .707 .577 .707 r
F P
0 g
s
.54972 .64115 m .54098 .69696 L .51688 .69761 L p .707 .577 .707 r
F P
0 g
s
.51025 .75419 m .51958 .71742 L .54369 .71991 L p .707 .577 .707 r
F P
0 g
s
.54369 .71991 m .53437 .75668 L .51025 .75419 L p .707 .577 .707 r
F P
0 g
s
.50564 .79634 m .51056 .77801 L .5352 .78115 L p .707 .577 .707 r
F P
0 g
s
.5352 .78115 m .53028 .79947 L .50564 .79634 L p .707 .577 .707 r
F P
0 g
s
.53437 .75668 m .54369 .71991 L .57265 .72508 L p .707 .577 .707 r
F P
0 g
s
.57265 .72508 m .56333 .76185 L .53437 .75668 L p .707 .577 .707 r
F P
0 g
s
.53028 .79947 m .5352 .78115 L .5644 .78697 L p .707 .577 .707 r
F P
0 g
s
.5644 .78697 m .55948 .8053 L .53028 .79947 L p .707 .577 .707 r
F P
0 g
s
.50283 .32003 m .50283 .82192 L .54725 .81979 L p .707 .577 .707 r
F P
0 g
s
.54098 .69696 m .54972 .64115 L .57895 .64303 L p .707 .577 .707 r
F P
0 g
s
.57895 .64303 m .57021 .69884 L .54098 .69696 L p .707 .577 .707 r
F P
0 g
s
.54725 .81979 m .54725 .3179 L .50283 .32003 L p .707 .577 .707 r
F P
0 g
s
.47961 .80467 m .48453 .78635 L .48392 .78075 L p .707 .577 .707 r
F P
0 g
s
.45812 .82026 m .45812 .31837 L .41752 .31308 L p .707 .577 .707 r
F P
0 g
s
.48392 .78075 m .47901 .79907 L .47961 .80467 L p .707 .577 .707 r
F P
0 g
s
.47901 .79907 m .48392 .78075 L .49289 .77788 L p .707 .577 .707 r
F P
0 g
s
.49289 .77788 m .48797 .7962 L .47901 .79907 L p .707 .577 .707 r
F P
0 g
s
.45812 .31837 m .45812 .82026 L .50283 .82192 L p .707 .577 .707 r
F P
0 g
s
.57021 .69884 m .57895 .64303 L .61046 .64726 L p .707 .577 .707 r
F P
0 g
s
.61046 .64726 m .60171 .70307 L .57021 .69884 L p .707 .577 .707 r
F P
0 g
s
.56333 .76185 m .57265 .72508 L .60362 .73242 L p .707 .577 .707 r
F P
0 g
s
.60362 .73242 m .5943 .76919 L .56333 .76185 L p .707 .577 .707 r
F P
0 g
s
.55948 .8053 m .5644 .78697 L .5953 .79492 L p .707 .577 .707 r
F P
0 g
s
.5953 .79492 m .59038 .81324 L .55948 .8053 L p .707 .577 .707 r
F P
0 g
s
.54725 .3179 m .54725 .81979 L .58706 .81408 L p .707 .577 .707 r
F P
0 g
s
.58706 .81408 m .58706 .31219 L .54725 .3179 L p .707 .577 .707 r
F P
0 g
s
.69178 .77334 m .68246 .81011 L .68086 .80425 L p .707 .577 .707 r
F P
0 g
s
.68086 .80425 m .69018 .76748 L .69178 .77334 L p .707 .577 .707 r
F P
0 g
s
.67962 .8365 m .6747 .85483 L .67409 .84923 L p .707 .577 .707 r
F P
0 g
s
.67409 .84923 m .67901 .8309 L .67962 .8365 L p .707 .577 .707 r
F P
0 g
s
.70049 .67691 m .69175 .73272 L .67975 .72482 L p .707 .577 .707 r
F P
0 g
s
.67975 .72482 m .68849 .66901 L .70049 .67691 L p .707 .577 .707 r
F P
0 g
s
.41752 .81497 m .41752 .31308 L .38499 .30469 L p .707 .577 .707 r
F P
0 g
s
.41752 .31308 m .41752 .81497 L .45812 .82026 L p .707 .577 .707 r
F P
0 g
s
.64116 .65342 m .63242 .70923 L .60171 .70307 L p .707 .577 .707 r
F P
0 g
s
.60171 .70307 m .61046 .64726 L .64116 .65342 L p .707 .577 .707 r
F P
0 g
s
.63358 .74121 m .62426 .77798 L .5943 .76919 L p .707 .577 .707 r
F P
0 g
s
.5943 .76919 m .60362 .73242 L .63358 .74121 L p .707 .577 .707 r
F P
0 g
s
.59038 .81324 m .5953 .79492 L .62487 .8042 L p .707 .577 .707 r
F P
0 g
s
.58706 .31219 m .58706 .81408 L .61834 .80535 L p .707 .577 .707 r
F P
0 g
s
.61834 .80535 m .61834 .30346 L .58706 .31219 L p .707 .577 .707 r
F P
0 g
s
.24793 .72399 m .25168 .67155 L .22065 .66664 L p .707 .577 .707 r
F P
0 g
s
.25168 .67155 m .24793 .72399 L .27972 .72483 L p .707 .577 .707 r
F P
0 g
s
.27972 .72483 m .28348 .67239 L .25168 .67155 L p .707 .577 .707 r
F P
0 g
s
.69018 .76748 m .68086 .80425 L .66976 .79641 L p .707 .577 .707 r
F P
0 g
s
.66976 .79641 m .67908 .75964 L .69018 .76748 L p .707 .577 .707 r
F P
0 g
s
.28348 .67239 m .27972 .72483 L .30919 .72152 L p .707 .577 .707 r
F P
0 g
s
.30919 .72152 m .31294 .66908 L .28348 .67239 L p .707 .577 .707 r
F P
0 g
s
.2169 .71907 m .22065 .66664 L .19344 .65813 L p .707 .577 .707 r
F P
0 g
s
.22065 .66664 m .2169 .71907 L .24793 .72399 L p .707 .577 .707 r
F P
0 g
s
.67901 .8309 m .67409 .84923 L .66397 .84144 L p .707 .577 .707 r
F P
0 g
s
.66397 .84144 m .66888 .82312 L .67901 .8309 L p .707 .577 .707 r
F P
0 g
s
.68849 .66901 m .67975 .72482 L .65931 .71673 L p .707 .577 .707 r
F P
0 g
s
.65931 .71673 m .66805 .66092 L .68849 .66901 L p .707 .577 .707 r
F P
0 g
s
.31294 .66908 m .30919 .72152 L .33343 .71437 L p .707 .577 .707 r
F P
0 g
s
.33343 .71437 m .33718 .66194 L .31294 .66908 L p .707 .577 .707 r
F P
0 g
s
.38499 .80658 m .38499 .30469 L .36371 .29401 L p .707 .577 .707 r
F P
0 g
s
.38499 .30469 m .38499 .80658 L .41752 .81497 L p .707 .577 .707 r
F P
0 g
s
.18969 .71057 m .19344 .65813 L .17271 .64687 L p .707 .577 .707 r
F P
0 g
s
.19344 .65813 m .18969 .71057 L .2169 .71907 L p .707 .577 .707 r
F P
0 g
s
.66805 .66092 m .65931 .71673 L .63242 .70923 L p .707 .577 .707 r
F P
0 g
s
.63242 .70923 m .64116 .65342 L .66805 .66092 L p .707 .577 .707 r
F P
0 g
s
.65958 .75059 m .65026 .78736 L .62426 .77798 L p .707 .577 .707 r
F P
0 g
s
.62426 .77798 m .63358 .74121 L .65958 .75059 L p .707 .577 .707 r
F P
0 g
s
.61834 .30346 m .61834 .80535 L .63803 .79445 L p .707 .577 .707 r
F P
0 g
s
.63803 .79445 m .63803 .29257 L .61834 .30346 L p .707 .577 .707 r
F P
0 g
s
.67908 .75964 m .66976 .79641 L .65026 .78736 L p .707 .577 .707 r
F P
0 g
s
.65026 .78736 m .65958 .75059 L .67908 .75964 L p .707 .577 .707 r
F P
0 g
s
.33718 .66194 m .33343 .71437 L .35007 .7041 L p .707 .577 .707 r
F P
0 g
s
.35007 .7041 m .35383 .65166 L .33718 .66194 L p .707 .577 .707 r
F P
0 g
s
.24215 .7899 m .24617 .75678 L .21537 .75001 L p .707 .577 .707 r
F P
0 g
s
.24617 .75678 m .24215 .7899 L .27388 .79178 L p .707 .577 .707 r
F P
0 g
s
.27388 .79178 m .2779 .75866 L .24617 .75678 L p .707 .577 .707 r
F P
0 g
s
.2779 .75866 m .27388 .79178 L .30345 .78858 L p .707 .577 .707 r
F P
0 g
s
.30345 .78858 m .30746 .75546 L .2779 .75866 L p .707 .577 .707 r
F P
0 g
s
.21136 .78313 m .21537 .75001 L .18853 .73899 L p .707 .577 .707 r
F P
0 g
s
.21537 .75001 m .21136 .78313 L .24215 .7899 L p .707 .577 .707 r
F P
0 g
s
.66888 .82312 m .66397 .84144 L .64531 .83224 L p .707 .577 .707 r
F P
0 g
s
.64531 .83224 m .65023 .81392 L .66888 .82312 L p .707 .577 .707 r
F P
0 g
s
.16896 .69931 m .17271 .64687 L .16048 .63395 L p .707 .577 .707 r
F P
0 g
s
.17271 .64687 m .16896 .69931 L .18969 .71057 L p .707 .577 .707 r
F P
0 g
s
.30746 .75546 m .30345 .78858 L .32795 .78061 L p .707 .577 .707 r
F P
0 g
s
.32795 .78061 m .33196 .74749 L .30746 .75546 L p .707 .577 .707 r
F P
0 g
s
.18452 .77211 m .18853 .73899 L .16827 .72483 L p .707 .577 .707 r
F P
0 g
s
.18853 .73899 m .18452 .77211 L .21136 .78313 L p .707 .577 .707 r
F P
0 g
s
.36371 .7959 m .36371 .29401 L .35578 .28209 L p .707 .577 .707 r
F P
0 g
s
.36371 .29401 m .36371 .7959 L .38499 .80658 L p .707 .577 .707 r
F P
0 g
s
.35383 .65166 m .35007 .7041 L .3575 .69171 L p .707 .577 .707 r
F P
0 g
s
.3575 .69171 m .36125 .63927 L .35383 .65166 L p .707 .577 .707 r
F P
0 g
s
.63803 .29257 m .63803 .79445 L .64422 .78246 L p .707 .577 .707 r
F P
0 g
s
.64422 .78246 m .64422 .28057 L .63803 .29257 L p .707 .577 .707 r
F P
0 g
s
.23616 .83161 m .23826 .81528 L .20773 .80781 L p .707 .577 .707 r
F P
0 g
s
.23826 .81528 m .23616 .83161 L .26792 .83404 L p .707 .577 .707 r
F P
0 g
s
.26792 .83404 m .27002 .8177 L .23826 .81528 L p .707 .577 .707 r
F P
0 g
s
.16048 .63395 m .15673 .68639 L .16896 .69931 L p .707 .577 .707 r
F P
0 g
s
.65023 .81392 m .64531 .83224 L .61996 .82253 L p .707 .577 .707 r
F P
0 g
s
.61996 .82253 m .62487 .8042 L .65023 .81392 L p .707 .577 .707 r
F P
0 g
s
.27002 .8177 m .26792 .83404 L .2978 .83118 L p .707 .577 .707 r
F P
0 g
s
.2978 .83118 m .2999 .81485 L .27002 .8177 L p .707 .577 .707 r
F P
0 g
s
.15673 .68639 m .16048 .63395 L .15795 .62065 L p .707 .577 .707 r
F P
0 g
s
.33196 .74749 m .32795 .78061 L .34498 .76865 L p .707 .577 .707 r
F P
0 g
s
.34498 .76865 m .349 .73553 L .33196 .74749 L p .707 .577 .707 r
F P
0 g
s
.20563 .82415 m .20773 .80781 L .18142 .79603 L p .707 .577 .707 r
F P
0 g
s
.20773 .80781 m .20563 .82415 L .23616 .83161 L p .707 .577 .707 r
F P
0 g
s
.16827 .72483 m .16426 .75795 L .18452 .77211 L p .707 .577 .707 r
F P
0 g
s
.16426 .75795 m .16827 .72483 L .15657 .70889 L p .707 .577 .707 r
F P
0 g
s
.2999 .81485 m .2978 .83118 L .32288 .82333 L p .707 .577 .707 r
F P
0 g
s
.32288 .82333 m .32498 .80699 L .2999 .81485 L p .707 .577 .707 r
F P
0 g
s
.18142 .79603 m .17932 .81237 L .20563 .82415 L p .707 .577 .707 r
F P
0 g
s
.62487 .8042 m .61996 .82253 L .59038 .81324 L p .707 .577 .707 r
F P
0 g
s
.17932 .81237 m .18142 .79603 L .1619 .78109 L p .707 .577 .707 r
F P
0 g
s
.36125 .63927 m .3575 .69171 L .35497 .6784 L p .707 .577 .707 r
F P
0 g
s
.35497 .6784 m .35872 .62596 L .36125 .63927 L p .707 .577 .707 r
F P
0 g
s
.15795 .62065 m .1542 .67308 L .15673 .68639 L p .707 .577 .707 r
F P
0 g
s
.15657 .70889 m .15256 .74201 L .16426 .75795 L p .707 .577 .707 r
F P
0 g
s
.349 .73553 m .34498 .76865 L .3529 .75387 L p .707 .577 .707 r
F P
0 g
s
.3529 .75387 m .35691 .72075 L .349 .73553 L p .707 .577 .707 r
F P
0 g
s
.1619 .78109 m .15981 .79743 L .17932 .81237 L p .707 .577 .707 r
F P
0 g
s
.32498 .80699 m .32288 .82333 L .3407 .81124 L p .707 .577 .707 r
F P
0 g
s
.3407 .81124 m .3428 .7949 L .32498 .80699 L p .707 .577 .707 r
F P
0 g
s
.1542 .67308 m .15795 .62065 L .16537 .60825 L p .707 .577 .707 r
F P
0 g
s
.15256 .74201 m .15657 .70889 L .15458 .69274 L p .707 .577 .707 r
F P
0 g
s
.35872 .62596 m .35497 .6784 L .34274 .66548 L p .707 .577 .707 r
F P
0 g
s
.34274 .66548 m .34649 .61304 L .35872 .62596 L p .707 .577 .707 r
F P
0 g
s
.35691 .72075 m .3529 .75387 L .35091 .73773 L p .707 .577 .707 r
F P
0 g
s
.35091 .73773 m .35492 .70461 L .35691 .72075 L p .707 .577 .707 r
F P
0 g
s
.35578 .28209 m .35578 .78398 L .36371 .7959 L p .707 .577 .707 r
F P
0 g
s
.35578 .78398 m .35578 .28209 L .36197 .27009 L p .707 .577 .707 r
F P
0 g
s
.15981 .79743 m .1619 .78109 L .15109 .76446 L p .707 .577 .707 r
F P
0 g
s
.64422 .28057 m .64422 .78246 L .63628 .77054 L p .707 .577 .707 r
F P
0 g
s
.63628 .77054 m .63628 .26865 L .64422 .28057 L p .707 .577 .707 r
F P
0 g
s
.15109 .76446 m .149 .78079 L .15981 .79743 L p .707 .577 .707 r
F P
0 g
s
.15458 .69274 m .15057 .72586 L .15256 .74201 L p .707 .577 .707 r
F P
0 g
s
.3428 .7949 m .3407 .81124 L .34952 .7961 L p .707 .577 .707 r
F P
0 g
s
.34952 .7961 m .35161 .77977 L .3428 .7949 L p .707 .577 .707 r
F P
0 g
s
.16537 .60825 m .16162 .66069 L .1542 .67308 L p .707 .577 .707 r
F P
0 g
s
.16162 .66069 m .16537 .60825 L .18202 .59798 L p .707 .577 .707 r
F P
0 g
s
.15057 .72586 m .15458 .69274 L .16249 .67796 L p .707 .577 .707 r
F P
0 g
s
.149 .78079 m .15109 .76446 L .15004 .74776 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15004 .74776 m .14795 .76409 L .149 .78079 L p .707 .577 .707 r
F P
0 g
s
.36197 .77198 m .36197 .27009 L .38166 .2592 L p .707 .577 .707 r
F P
0 g
s
.36197 .27009 m .36197 .77198 L .35578 .78398 L p .707 .577 .707 r
F P
0 g
s
.34649 .61304 m .34274 .66548 L .322 .65422 L p .707 .577 .707 r
F P
0 g
s
.322 .65422 m .32576 .60178 L .34649 .61304 L p .707 .577 .707 r
F P
0 g
s
.16249 .67796 m .15848 .71108 L .15057 .72586 L p .707 .577 .707 r
F P
0 g
s
.35161 .77977 m .34952 .7961 L .34847 .7794 L p .707 .577 .707 r
F P
0 g
s
.34847 .7794 m .35057 .76306 L .35161 .77977 L p .707 .577 .707 r
F P
0 g
s
.63628 .26865 m .63628 .77054 L .61501 .75986 L p .707 .577 .707 r
F P
0 g
s
.61501 .75986 m .61501 .25797 L .63628 .26865 L p .707 .577 .707 r
F P
0 g
s
.35492 .70461 m .35091 .73773 L .33921 .72179 L p .707 .577 .707 r
F P
0 g
s
.33921 .72179 m .34322 .68867 L .35492 .70461 L p .707 .577 .707 r
F P
0 g
s
.18202 .59798 m .17827 .65042 L .16162 .66069 L p .707 .577 .707 r
F P
0 g
s
.17827 .65042 m .18202 .59798 L .20626 .59084 L p .707 .577 .707 r
F P
0 g
s
.15848 .71108 m .16249 .67796 L .17953 .66601 L p .707 .577 .707 r
F P
0 g
s
.14795 .76409 m .15004 .74776 L .15886 .73262 L p .707 .577 .707 r
F P
0 g
s
.32576 .60178 m .322 .65422 L .29479 .64572 L p .707 .577 .707 r
F P
0 g
s
.29479 .64572 m .29855 .59328 L .32576 .60178 L p .707 .577 .707 r
F P
0 g
s
.15886 .73262 m .15677 .74895 L .14795 .76409 L p .707 .577 .707 r
F P
0 g
s
.20251 .64327 m .20626 .59084 L .23572 .58752 L p .707 .577 .707 r
F P
0 g
s
.20626 .59084 m .20251 .64327 L .17827 .65042 L p .707 .577 .707 r
F P
0 g
s
.17953 .66601 m .17552 .69913 L .15848 .71108 L p .707 .577 .707 r
F P
0 g
s
.34322 .68867 m .33921 .72179 L .31895 .70762 L p .707 .577 .707 r
F P
0 g
s
.31895 .70762 m .32296 .6745 L .34322 .68867 L p .707 .577 .707 r
F P
0 g
s
.35057 .76306 m .34847 .7794 L .33766 .76276 L p .707 .577 .707 r
F P
0 g
s
.33766 .76276 m .33976 .74643 L .35057 .76306 L p .707 .577 .707 r
F P
0 g
s
.17552 .69913 m .17953 .66601 L .20403 .65803 L p .707 .577 .707 r
F P
0 g
s
.29855 .59328 m .29479 .64572 L .26377 .6408 L p .707 .577 .707 r
F P
0 g
s
.26377 .6408 m .26752 .58836 L .29855 .59328 L p .707 .577 .707 r
F P
0 g
s
.38166 .76109 m .38166 .2592 L .41294 .25047 L p .707 .577 .707 r
F P
0 g
s
.38166 .2592 m .38166 .76109 L .36197 .77198 L p .707 .577 .707 r
F P
0 g
s
.23197 .63996 m .23572 .58752 L .26752 .58836 L p .707 .577 .707 r
F P
0 g
s
.23572 .58752 m .23197 .63996 L .20251 .64327 L p .707 .577 .707 r
F P
0 g
s
.15677 .74895 m .15886 .73262 L .17668 .72053 L p .707 .577 .707 r
F P
0 g
s
.61501 .25797 m .61501 .75986 L .58248 .75147 L p .707 .577 .707 r
F P
0 g
s
.58248 .75147 m .58248 .24958 L .61501 .25797 L p .707 .577 .707 r
F P
0 g
s
.26752 .58836 m .26377 .6408 L .23197 .63996 L p .707 .577 .707 r
F P
0 g
s
.73623 .64473 m .73248 .58755 L .70145 .58868 L p .707 .577 .707 r
F P
0 g
s
.73248 .58755 m .73623 .64473 L .76803 .64237 L p .707 .577 .707 r
F P
0 g
s
.76803 .64237 m .76428 .58519 L .73248 .58755 L p .707 .577 .707 r
F P
0 g
s
.76428 .58519 m .76803 .64237 L .79749 .63903 L p .707 .577 .707 r
F P
0 g
s
.79749 .63903 m .79374 .58185 L .76428 .58519 L p .707 .577 .707 r
F P
0 g
s
.17668 .72053 m .17459 .73686 L .15677 .74895 L p .707 .577 .707 r
F P
0 g
s
.32296 .6745 m .31895 .70762 L .2921 .69661 L p .707 .577 .707 r
F P
0 g
s
.2921 .69661 m .29612 .66349 L .32296 .6745 L p .707 .577 .707 r
F P
0 g
s
.70145 .58868 m .7052 .64586 L .73623 .64473 L p .707 .577 .707 r
F P
0 g
s
.7052 .64586 m .70145 .58868 L .67424 .58849 L p .707 .577 .707 r
F P
0 g
s
.20002 .69115 m .20403 .65803 L .23359 .65483 L p .707 .577 .707 r
F P
0 g
s
.20403 .65803 m .20002 .69115 L .17552 .69913 L p .707 .577 .707 r
F P
0 g
s
.33976 .74643 m .33766 .76276 L .31815 .74782 L p .707 .577 .707 r
F P
0 g
s
.31815 .74782 m .32024 .73149 L .33976 .74643 L p .707 .577 .707 r
F P
0 g
s
.73869 .69787 m .73467 .65962 L .70388 .6627 L p .707 .577 .707 r
F P
0 g
s
.73467 .65962 m .73869 .69787 L .77042 .6945 L p .707 .577 .707 r
F P
0 g
s
.77042 .6945 m .7664 .65626 L .73467 .65962 L p .707 .577 .707 r
F P
0 g
s
.70388 .6627 m .70789 .70095 L .73869 .69787 L p .707 .577 .707 r
F P
0 g
s
.79374 .58185 m .79749 .63903 L .82173 .63502 L p .707 .577 .707 r
F P
0 g
s
.82173 .63502 m .81798 .57784 L .79374 .58185 L p .707 .577 .707 r
F P
0 g
s
.67424 .58849 m .67799 .64566 L .7052 .64586 L p .707 .577 .707 r
F P
0 g
s
.7664 .65626 m .77042 .6945 L .79998 .69118 L p .707 .577 .707 r
F P
0 g
s
.79998 .69118 m .79597 .65293 L .7664 .65626 L p .707 .577 .707 r
F P
0 g
s
.17459 .73686 m .17668 .72053 L .20176 .71267 L p .707 .577 .707 r
F P
0 g
s
.29612 .66349 m .2921 .69661 L .26131 .68983 L p .707 .577 .707 r
F P
0 g
s
.26131 .68983 m .26532 .65671 L .29612 .66349 L p .707 .577 .707 r
F P
0 g
s
.70607 .72423 m .70816 .74335 L .73869 .73997 L p .707 .577 .707 r
F P
0 g
s
.73869 .73997 m .73659 .72086 L .70607 .72423 L p .707 .577 .707 r
F P
0 g
s
.73659 .72086 m .73869 .73997 L .77045 .7365 L p .707 .577 .707 r
F P
0 g
s
.77045 .7365 m .76835 .71738 L .73659 .72086 L p .707 .577 .707 r
F P
0 g
s
.76835 .71738 m .77045 .7365 L .80033 .73326 L p .707 .577 .707 r
F P
0 g
s
.22958 .68795 m .23359 .65483 L .26532 .65671 L p .707 .577 .707 r
F P
0 g
s
.23359 .65483 m .22958 .68795 L .20002 .69115 L p .707 .577 .707 r
F P
0 g
s
.80033 .73326 m .79824 .71414 L .76835 .71738 L p .707 .577 .707 r
F P
0 g
s
.70789 .70095 m .70388 .6627 L .67704 .66518 L p .707 .577 .707 r
F P
0 g
s
.67704 .66518 m .68105 .70343 L .70789 .70095 L p .707 .577 .707 r
F P
0 g
s
.26532 .65671 m .26131 .68983 L .22958 .68795 L p .707 .577 .707 r
F P
0 g
s
.41294 .25047 m .41294 .75236 L .38166 .76109 L p .707 .577 .707 r
F P
0 g
s
.41294 .75236 m .41294 .25047 L .45274 .24476 L p .707 .577 .707 r
F P
0 g
s
.67799 .64566 m .67424 .58849 L .65351 .58698 L p .707 .577 .707 r
F P
0 g
s
.79597 .65293 m .79998 .69118 L .82448 .68822 L p .707 .577 .707 r
F P
0 g
s
.82448 .68822 m .82047 .64997 L .79597 .65293 L p .707 .577 .707 r
F P
0 g
s
.58248 .24958 m .58248 .75147 L .54188 .74618 L p .707 .577 .707 r
F P
0 g
s
.54188 .74618 m .54188 .24429 L .58248 .24958 L p .707 .577 .707 r
F P
0 g
s
.67976 .72717 m .68185 .74629 L .70816 .74335 L p .707 .577 .707 r
F P
0 g
s
.70816 .74335 m .70607 .72423 L .67976 .72717 L p .707 .577 .707 r
F P
0 g
s
.20176 .71267 m .19967 .72901 L .17459 .73686 L p .707 .577 .707 r
F P
0 g
s
.32024 .73149 m .31815 .74782 L .29184 .73604 L p .707 .577 .707 r
F P
0 g
s
.29184 .73604 m .29393 .71971 L .32024 .73149 L p .707 .577 .707 r
F P
0 g
s
.79824 .71414 m .80033 .73326 L .82541 .73058 L p .707 .577 .707 r
F P
0 g
s
.82541 .73058 m .82331 .71146 L .79824 .71414 L p .707 .577 .707 r
F P
0 g
s
.65351 .58698 m .65726 .64415 L .67799 .64566 L p .707 .577 .707 r
F P
0 g
s
.81798 .57784 m .82173 .63502 L .83838 .63074 L p .707 .577 .707 r
F P
0 g
s
.83838 .63074 m .83462 .57356 L .81798 .57784 L p .707 .577 .707 r
F P
0 g
s
.19967 .72901 m .20176 .71267 L .23164 .70982 L p .707 .577 .707 r
F P
0 g
s
.68105 .70343 m .67704 .66518 L .65678 .66683 L p .707 .577 .707 r
F P
0 g
s
.65678 .66683 m .66079 .70508 L .68105 .70343 L p .707 .577 .707 r
F P
0 g
s
.29393 .71971 m .29184 .73604 L .26131 .72858 L p .707 .577 .707 r
F P
0 g
s
.26131 .72858 m .2634 .71224 L .29393 .71971 L p .707 .577 .707 r
F P
0 g
s
.45274 .74665 m .45274 .24476 L .49717 .24263 L p .707 .577 .707 r
F P
0 g
s
.45274 .24476 m .45274 .74665 L .41294 .75236 L p .707 .577 .707 r
F P
0 g
s
.66024 .72939 m .66234 .74851 L .68185 .74629 L p .707 .577 .707 r
F P
0 g
s
.68185 .74629 m .67976 .72717 L .66024 .72939 L p .707 .577 .707 r
F P
0 g
s
.23164 .70982 m .22955 .72615 L .19967 .72901 L p .707 .577 .707 r
F P
0 g
s
.54188 .24429 m .54188 .74618 L .49717 .74452 L p .707 .577 .707 r
F P
0 g
s
.49717 .74452 m .49717 .24263 L .54188 .24429 L p .707 .577 .707 r
F P
0 g
s
.82047 .64997 m .82448 .68822 L .84152 .68591 L p .707 .577 .707 r
F P
0 g
s
.84152 .68591 m .83751 .64767 L .82047 .64997 L p .707 .577 .707 r
F P
0 g
s
.22955 .72615 m .23164 .70982 L .2634 .71224 L p .707 .577 .707 r
F P
0 g
s
.65726 .64415 m .65351 .58698 L .64128 .5843 L p .707 .577 .707 r
F P
0 g
s
.2634 .71224 m .26131 .72858 L .22955 .72615 L p .707 .577 .707 r
F P
0 g
s
.82331 .71146 m .82541 .73058 L .84323 .72871 L p .707 .577 .707 r
F P
0 g
s
.84323 .72871 m .84114 .70959 L .82331 .71146 L p .707 .577 .707 r
F P
0 g
s
.49717 .24263 m .49717 .74452 L .45274 .74665 L p .707 .577 .707 r
F P
0 g
s
.64128 .5843 m .64503 .64148 L .65726 .64415 L p .707 .577 .707 r
F P
0 g
s
.83462 .57356 m .83838 .63074 L .8458 .62661 L p .707 .577 .707 r
F P
0 g
s
.8458 .62661 m .84205 .56943 L .83462 .57356 L p .707 .577 .707 r
F P
0 g
s
.66079 .70508 m .65678 .66683 L .64508 .66749 L p .707 .577 .707 r
F P
0 g
s
.64508 .66749 m .64909 .70574 L .66079 .70508 L p .707 .577 .707 r
F P
0 g
s
.64943 .73067 m .65153 .74979 L .66234 .74851 L p .707 .577 .707 r
F P
0 g
s
.66234 .74851 m .66024 .72939 L .64943 .73067 L p .707 .577 .707 r
F P
0 g
s
.83751 .64767 m .84152 .68591 L .84943 .68449 L p .707 .577 .707 r
F P
0 g
s
.84943 .68449 m .84542 .64624 L .83751 .64767 L p .707 .577 .707 r
F P
0 g
s
.84114 .70959 m .84323 .72871 L .85205 .72784 L p .707 .577 .707 r
F P
0 g
s
.85205 .72784 m .84995 .70873 L .84114 .70959 L p .707 .577 .707 r
F P
0 g
s
.64503 .64148 m .64128 .5843 L .63875 .58073 L p .707 .577 .707 r
F P
0 g
s
.63875 .58073 m .6425 .6379 L .64503 .64148 L p .707 .577 .707 r
F P
0 g
s
.84205 .56943 m .8458 .62661 L .84327 .62303 L p .707 .577 .707 r
F P
0 g
s
.84327 .62303 m .83952 .56586 L .84205 .56943 L p .707 .577 .707 r
F P
0 g
s
.64909 .70574 m .64508 .66749 L .64309 .66709 L p .707 .577 .707 r
F P
0 g
s
.64309 .66709 m .6471 .70534 L .64909 .70574 L p .707 .577 .707 r
F P
0 g
s
.64838 .73089 m .65048 .75001 L .65153 .74979 L p .707 .577 .707 r
F P
0 g
s
.65153 .74979 m .64943 .73067 L .64838 .73089 L p .707 .577 .707 r
F P
0 g
s
.84542 .64624 m .84943 .68449 L .84744 .68409 L p .707 .577 .707 r
F P
0 g
s
.84744 .68409 m .84343 .64584 L .84542 .64624 L p .707 .577 .707 r
F P
0 g
s
.84995 .70873 m .85205 .72784 L .851 .72806 L p .707 .577 .707 r
F P
0 g
s
.851 .72806 m .84891 .70894 L .84995 .70873 L p .707 .577 .707 r
F P
0 g
s
.6425 .6379 m .63875 .58073 L .64617 .5766 L p .707 .577 .707 r
F P
0 g
s
.64617 .5766 m .64992 .63377 L .6425 .6379 L p .707 .577 .707 r
F P
0 g
s
.83952 .56586 m .84327 .62303 L .83104 .62036 L p .707 .577 .707 r
F P
0 g
s
.83104 .62036 m .82729 .56318 L .83952 .56586 L p .707 .577 .707 r
F P
0 g
s
.6471 .70534 m .64309 .66709 L .651 .66566 L p .707 .577 .707 r
F P
0 g
s
.651 .66566 m .65501 .70391 L .6471 .70534 L p .707 .577 .707 r
F P
0 g
s
.6572 .73002 m .6593 .74914 L .65048 .75001 L p .707 .577 .707 r
F P
0 g
s
.65048 .75001 m .64838 .73089 L .6572 .73002 L p .707 .577 .707 r
F P
0 g
s
.84343 .64584 m .84744 .68409 L .83574 .68474 L p .707 .577 .707 r
F P
0 g
s
.83574 .68474 m .83173 .6465 L .84343 .64584 L p .707 .577 .707 r
F P
0 g
s
.39828 .62657 m .38954 .57271 L .35884 .57467 L p .707 .577 .707 r
F P
0 g
s
.38954 .57271 m .39828 .62657 L .42979 .62121 L p .707 .577 .707 r
F P
0 g
s
.42979 .62121 m .42105 .56736 L .38954 .57271 L p .707 .577 .707 r
F P
0 g
s
.42105 .56736 m .42979 .62121 L .45902 .61299 L p .707 .577 .707 r
F P
0 g
s
.45902 .61299 m .45028 .55913 L .42105 .56736 L p .707 .577 .707 r
F P
0 g
s
.84891 .70894 m .851 .72806 L .84019 .72934 L p .707 .577 .707 r
F P
0 g
s
.84019 .72934 m .8381 .71022 L .84891 .70894 L p .707 .577 .707 r
F P
0 g
s
.64992 .63377 m .64617 .5766 L .66282 .57232 L p .707 .577 .707 r
F P
0 g
s
.36758 .62852 m .35884 .57467 L .33195 .57303 L p .707 .577 .707 r
F P
0 g
s
.35884 .57467 m .36758 .62852 L .39828 .62657 L p .707 .577 .707 r
F P
0 g
s
.66282 .57232 m .66657 .6295 L .64992 .63377 L p .707 .577 .707 r
F P
0 g
s
.45028 .55913 m .45902 .61299 L .48311 .60269 L p .707 .577 .707 r
F P
0 g
s
.48311 .60269 m .47437 .54884 L .45028 .55913 L p .707 .577 .707 r
F P
0 g
s
.82729 .56318 m .83104 .62036 L .81031 .61885 L p .707 .577 .707 r
F P
0 g
s
.81031 .61885 m .80656 .56167 L .82729 .56318 L p .707 .577 .707 r
F P
0 g
s
.65501 .70391 m .651 .66566 L .66804 .66336 L p .707 .577 .707 r
F P
0 g
s
.66804 .66336 m .67205 .70161 L .65501 .70391 L p .707 .577 .707 r
F P
0 g
s
.67502 .72815 m .67712 .74727 L .6593 .74914 L p .707 .577 .707 r
F P
0 g
s
.6593 .74914 m .6572 .73002 L .67502 .72815 L p .707 .577 .707 r
F P
0 g
s
.34069 .62688 m .33195 .57303 L .31151 .56796 L p .707 .577 .707 r
F P
0 g
s
.33195 .57303 m .34069 .62688 L .36758 .62852 L p .707 .577 .707 r
F P
0 g
s
.43667 .68235 m .42735 .64757 L .39637 .65538 L p .707 .577 .707 r
F P
0 g
s
.42735 .64757 m .43667 .68235 L .46563 .67146 L p .707 .577 .707 r
F P
0 g
s
.46563 .67146 m .45631 .63668 L .42735 .64757 L p .707 .577 .707 r
F P
0 g
s
.40569 .69015 m .39637 .65538 L .36642 .65934 L p .707 .577 .707 r
F P
0 g
s
.39637 .65538 m .40569 .69015 L .43667 .68235 L p .707 .577 .707 r
F P
0 g
s
.83173 .6465 m .83574 .68474 L .81548 .6864 L p .707 .577 .707 r
F P
0 g
s
.81548 .6864 m .81147 .64815 L .83173 .6465 L p .707 .577 .707 r
F P
0 g
s
.47437 .54884 m .48311 .60269 L .49971 .59133 L p .707 .577 .707 r
F P
0 g
s
.49971 .59133 m .49097 .53748 L .47437 .54884 L p .707 .577 .707 r
F P
0 g
s
.66657 .6295 m .66282 .57232 L .68706 .56831 L p .707 .577 .707 r
F P
0 g
s
.8381 .71022 m .84019 .72934 L .82068 .73156 L p .707 .577 .707 r
F P
0 g
s
.82068 .73156 m .81858 .71244 L .8381 .71022 L p .707 .577 .707 r
F P
0 g
s
.45631 .63668 m .46563 .67146 L .48974 .65855 L p .707 .577 .707 r
F P
0 g
s
.48974 .65855 m .48042 .62377 L .45631 .63668 L p .707 .577 .707 r
F P
0 g
s
.68706 .56831 m .69081 .62549 L .66657 .6295 L p .707 .577 .707 r
F P
0 g
s
.37574 .69412 m .36642 .65934 L .34042 .65907 L p .707 .577 .707 r
F P
0 g
s
.36642 .65934 m .37574 .69412 L .40569 .69015 L p .707 .577 .707 r
F P
0 g
s
.80656 .56167 m .81031 .61885 L .7831 .61865 L p .707 .577 .707 r
F P
0 g
s
.7831 .61865 m .77935 .56148 L .80656 .56167 L p .707 .577 .707 r
F P
0 g
s
.67205 .70161 m .66804 .66336 L .69254 .6604 L p .707 .577 .707 r
F P
0 g
s
.69254 .6604 m .69655 .69865 L .67205 .70161 L p .707 .577 .707 r
F P
0 g
s
.31151 .56796 m .32025 .62181 L .34069 .62688 L p .707 .577 .707 r
F P
0 g
s
.44051 .72447 m .4356 .70715 L .4047 .71499 L p .707 .577 .707 r
F P
0 g
s
.4356 .70715 m .44051 .72447 L .46971 .71347 L p .707 .577 .707 r
F P
0 g
s
.46971 .71347 m .4648 .69615 L .4356 .70715 L p .707 .577 .707 r
F P
0 g
s
.69081 .62549 m .68706 .56831 L .71652 .56497 L p .707 .577 .707 r
F P
0 g
s
.32025 .62181 m .31151 .56796 L .29951 .55996 L p .707 .577 .707 r
F P
0 g
s
.40962 .73231 m .4047 .71499 L .37512 .7189 L p .707 .577 .707 r
F P
0 g
s
.4047 .71499 m .40962 .73231 L .44051 .72447 L p .707 .577 .707 r
F P
0 g
s
.48042 .62377 m .48974 .65855 L .50665 .64489 L p .707 .577 .707 r
F P
0 g
s
.50665 .64489 m .49733 .61011 L .48042 .62377 L p .707 .577 .707 r
F P
0 g
s
.7001 .72547 m .7022 .74459 L .67712 .74727 L p .707 .577 .707 r
F P
0 g
s
.67712 .74727 m .67502 .72815 L .7001 .72547 L p .707 .577 .707 r
F P
0 g
s
.34042 .65907 m .34974 .69384 L .37574 .69412 L p .707 .577 .707 r
F P
0 g
s
.81147 .64815 m .81548 .6864 L .78864 .68888 L p .707 .577 .707 r
F P
0 g
s
.78864 .68888 m .78463 .65063 L .81147 .64815 L p .707 .577 .707 r
F P
0 g
s
.49097 .53748 m .49971 .59133 L .50718 .58002 L p .707 .577 .707 r
F P
0 g
s
.50718 .58002 m .49844 .52617 L .49097 .53748 L p .707 .577 .707 r
F P
0 g
s
.4648 .69615 m .46971 .71347 L .49435 .70038 L p .707 .577 .707 r
F P
0 g
s
.49435 .70038 m .48944 .68306 L .4648 .69615 L p .707 .577 .707 r
F P
0 g
s
.77935 .56148 m .7831 .61865 L .75207 .61979 L p .707 .577 .707 r
F P
0 g
s
.75207 .61979 m .74832 .56261 L .77935 .56148 L p .707 .577 .707 r
F P
0 g
s
.71652 .56497 m .72027 .62214 L .69081 .62549 L p .707 .577 .707 r
F P
0 g
s
.81858 .71244 m .82068 .73156 L .79437 .7345 L p .707 .577 .707 r
F P
0 g
s
.79437 .7345 m .79227 .71538 L .81858 .71244 L p .707 .577 .707 r
F P
0 g
s
.37512 .7189 m .38004 .73622 L .40962 .73231 L p .707 .577 .707 r
F P
0 g
s
.34974 .69384 m .34042 .65907 L .32092 .65459 L p .707 .577 .707 r
F P
0 g
s
.72027 .62214 m .71652 .56497 L .74832 .56261 L p .707 .577 .707 r
F P
0 g
s
.38004 .73622 m .37512 .7189 L .34977 .7185 L p .707 .577 .707 r
F P
0 g
s
.74832 .56261 m .75207 .61979 L .72027 .62214 L p .707 .577 .707 r
F P
0 g
s
.69655 .69865 m .69254 .6604 L .7221 .65707 L p .707 .577 .707 r
F P
0 g
s
.7221 .65707 m .72612 .69532 L .69655 .69865 L p .707 .577 .707 r
F P
0 g
s
.34977 .7185 m .35469 .73582 L .38004 .73622 L p .707 .577 .707 r
F P
0 g
s
.29951 .55996 m .30825 .61381 L .32025 .62181 L p .707 .577 .707 r
F P
0 g
s
.78463 .65063 m .78864 .68888 L .75785 .69196 L p .707 .577 .707 r
F P
0 g
s
.75785 .69196 m .75383 .65371 L .78463 .65063 L p .707 .577 .707 r
F P
0 g
s
.48944 .68306 m .49435 .70038 L .51202 .68649 L p .707 .577 .707 r
F P
0 g
s
.51202 .68649 m .50711 .66917 L .48944 .68306 L p .707 .577 .707 r
F P
0 g
s
.32092 .65459 m .33024 .68936 L .34974 .69384 L p .707 .577 .707 r
F P
0 g
s
.72998 .72223 m .73208 .74135 L .7022 .74459 L p .707 .577 .707 r
F P
0 g
s
.7022 .74459 m .7001 .72547 L .72998 .72223 L p .707 .577 .707 r
F P
0 g
s
.79227 .71538 m .79437 .7345 L .76384 .73788 L p .707 .577 .707 r
F P
0 g
s
.76384 .73788 m .76174 .71876 L .79227 .71538 L p .707 .577 .707 r
F P
0 g
s
.49733 .61011 m .50665 .64489 L .51469 .63181 L p .707 .577 .707 r
F P
0 g
s
.51469 .63181 m .50537 .59704 L .49733 .61011 L p .707 .577 .707 r
F P
0 g
s
.72612 .69532 m .7221 .65707 L .75383 .65371 L p .707 .577 .707 r
F P
0 g
s
.75383 .65371 m .75785 .69196 L .72612 .69532 L p .707 .577 .707 r
F P
0 g
s
.30825 .61381 m .29951 .55996 L .29713 .54981 L p .707 .578 .707 r
F P
0 g
s
.35469 .73582 m .34977 .7185 L .33111 .71382 L p .707 .577 .707 r
F P
0 g
s
.33024 .68936 m .32092 .65459 L .30982 .64634 L p .707 .577 .707 r
F P
0 g
s
.76174 .71876 m .76384 .73788 L .73208 .74135 L p .707 .577 .707 r
F P
0 g
s
.73208 .74135 m .72998 .72223 L .76174 .71876 L p .707 .577 .707 r
F P
0 g
s
.49844 .52617 m .50718 .58002 L .50481 .56987 L p .707 .578 .707 r
F P
0 g
s
.50481 .56987 m .49606 .51601 L .49844 .52617 L p .707 .578 .707 r
F P
0 g
s
.33111 .71382 m .33603 .73114 L .35469 .73582 L p .707 .577 .707 r
F P
0 g
s
.50711 .66917 m .51202 .68649 L .52099 .67315 L p .707 .577 .707 r
F P
0 g
s
.52099 .67315 m .51608 .65583 L .50711 .66917 L p .707 .577 .707 r
F P
0 g
s
.30982 .64634 m .31914 .68111 L .33024 .68936 L p .707 .577 .707 r
F P
0 g
s
.29713 .54981 m .30587 .60366 L .30825 .61381 L p .707 .578 .707 r
F P
0 g
s
.50537 .59704 m .51469 .63181 L .51309 .6206 L p .707 .577 .707 r
F P
0 g
s
.51309 .6206 m .50377 .58583 L .50537 .59704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.33603 .73114 m .33111 .71382 L .32099 .70533 L p .707 .577 .707 r
F P
0 g
s
.30587 .60366 m .29713 .54981 L .3046 .5385 L p .707 .577 .707 r
F P
0 g
s
.31914 .68111 m .30982 .64634 L .30821 .63513 L p .707 .577 .707 r
F P
0 g
s
.49606 .51601 m .50481 .56987 L .49281 .56186 L p .707 .577 .707 r
F P
0 g
s
.49281 .56186 m .48407 .50801 L .49606 .51601 L p .707 .577 .707 r
F P
0 g
s
.32099 .70533 m .3259 .72265 L .33603 .73114 L p .707 .577 .707 r
F P
0 g
s
.51608 .65583 m .52099 .67315 L .52038 .66168 L p .707 .577 .707 r
F P
0 g
s
.52038 .66168 m .51547 .64436 L .51608 .65583 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30821 .63513 m .31753 .6699 L .31914 .68111 L p .707 .577 .707 r
F P
0 g
s
.3046 .5385 m .31334 .59235 L .30587 .60366 L p .707 .577 .707 r
F P
0 g
s
.50377 .58583 m .51309 .6206 L .50199 .61235 L p .707 .577 .707 r
F P
0 g
s
.50199 .61235 m .49267 .57758 L .50377 .58583 L p .707 .577 .707 r
F P
0 g
s
.3259 .72265 m .32099 .70533 L .32038 .69386 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31334 .59235 m .3046 .5385 L .3212 .52714 L p .707 .577 .707 r
F P
0 g
s
.31753 .6699 m .30821 .63513 L .31626 .62205 L p .707 .577 .707 r
F P
0 g
s
.48407 .50801 m .49281 .56186 L .47236 .5568 L p .707 .577 .707 r
F P
0 g
s
.47236 .5568 m .46362 .50295 L .48407 .50801 L p .707 .577 .707 r
F P
0 g
s
.32038 .69386 m .3253 .71118 L .3259 .72265 L p .707 .577 .707 r
F P
0 g
s
.51547 .64436 m .52038 .66168 L .51026 .65319 L p .707 .577 .707 r
F P
0 g
s
.51026 .65319 m .50534 .63587 L .51547 .64436 L p .707 .577 .707 r
F P
0 g
s
.31626 .62205 m .32558 .65683 L .31753 .6699 L p .707 .577 .707 r
F P
0 g
s
.3212 .52714 m .32994 .58099 L .31334 .59235 L p .707 .577 .707 r
F P
0 g
s
.49267 .57758 m .50199 .61235 L .48249 .60787 L p .707 .577 .707 r
F P
0 g
s
.48249 .60787 m .47317 .5731 L .49267 .57758 L p .707 .577 .707 r
F P
0 g
s
.32994 .58099 m .3212 .52714 L .34529 .51684 L p .707 .577 .707 r
F P
0 g
s
.3253 .71118 m .32038 .69386 L .32935 .68053 L p .707 .577 .707 r
F P
0 g
s
.46362 .50295 m .47236 .5568 L .44547 .55516 L p .707 .577 .707 r
F P
0 g
s
.44547 .55516 m .43673 .50131 L .46362 .50295 L p .707 .577 .707 r
F P
0 g
s
.32558 .65683 m .31626 .62205 L .33317 .60839 L p .707 .577 .707 r
F P
0 g
s
.32935 .68053 m .33426 .69785 L .3253 .71118 L p .707 .577 .707 r
F P
0 g
s
.50534 .63587 m .51026 .65319 L .4916 .64852 L p .707 .577 .707 r
F P
0 g
s
.4916 .64852 m .48669 .6312 L .50534 .63587 L p .707 .577 .707 r
F P
0 g
s
.35403 .57069 m .34529 .51684 L .37452 .50861 L p .707 .577 .707 r
F P
0 g
s
.34529 .51684 m .35403 .57069 L .32994 .58099 L p .707 .577 .707 r
F P
0 g
s
.33317 .60839 m .34249 .64317 L .32558 .65683 L p .707 .577 .707 r
F P
0 g
s
.43673 .50131 m .44547 .55516 L .41477 .55711 L p .707 .577 .707 r
F P
0 g
s
.41477 .55711 m .40603 .50326 L .43673 .50131 L p .707 .577 .707 r
F P
0 g
s
.47317 .5731 m .48249 .60787 L .45649 .6076 L p .707 .577 .707 r
F P
0 g
s
.45649 .6076 m .44717 .57282 L .47317 .5731 L p .707 .577 .707 r
F P
0 g
s
.38326 .56246 m .37452 .50861 L .40603 .50326 L p .707 .577 .707 r
F P
0 g
s
.37452 .50861 m .38326 .56246 L .35403 .57069 L p .707 .577 .707 r
F P
0 g
s
.40603 .50326 m .41477 .55711 L .38326 .56246 L p .707 .577 .707 r
F P
0 g
s
.34249 .64317 m .33317 .60839 L .35728 .59548 L p .707 .577 .707 r
F P
0 g
s
.33426 .69785 m .32935 .68053 L .34702 .66663 L p .707 .577 .707 r
F P
0 g
s
.34702 .66663 m .35193 .68396 L .33426 .69785 L p .707 .577 .707 r
F P
0 g
s
.44717 .57282 m .45649 .6076 L .42653 .61156 L p .707 .577 .707 r
F P
0 g
s
.42653 .61156 m .41721 .57679 L .44717 .57282 L p .707 .577 .707 r
F P
0 g
s
.48669 .6312 m .4916 .64852 L .46625 .64812 L p .707 .577 .707 r
F P
0 g
s
.46625 .64812 m .46133 .6308 L .48669 .6312 L p .707 .577 .707 r
F P
0 g
s
.35728 .59548 m .3666 .63026 L .34249 .64317 L p .707 .577 .707 r
F P
0 g
s
.3666 .63026 m .35728 .59548 L .38624 .58459 L p .707 .577 .707 r
F P
0 g
s
.41721 .57679 m .42653 .61156 L .39556 .61937 L p .707 .577 .707 r
F P
0 g
s
.39556 .61937 m .38624 .58459 L .41721 .57679 L p .707 .577 .707 r
F P
0 g
s
.35193 .68396 m .34702 .66663 L .37166 .65355 L p .707 .577 .707 r
F P
0 g
s
.38624 .58459 m .39556 .61937 L .3666 .63026 L p .707 .577 .707 r
F P
0 g
s
.37166 .65355 m .37657 .67087 L .35193 .68396 L p .707 .577 .707 r
F P
0 g
s
.46133 .6308 m .46625 .64812 L .43667 .65203 L p .707 .577 .707 r
F P
0 g
s
.43667 .65203 m .43176 .63471 L .46133 .6308 L p .707 .577 .707 r
F P
0 g
s
.37657 .67087 m .37166 .65355 L .40086 .64255 L p .707 .577 .707 r
F P
0 g
s
.43176 .63471 m .43667 .65203 L .40577 .65987 L p .707 .577 .707 r
F P
0 g
s
.40577 .65987 m .40086 .64255 L .43176 .63471 L p .707 .577 .707 r
F P
0 g
s
.40086 .64255 m .40577 .65987 L .37657 .67087 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo7`00P7oo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000LGoo001/Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001^Ool006Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006aoo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JWoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Moo`00IGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP090004
FUH01000FUIJEUYF1P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00IGoo0P000UYF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00IGoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00I7oo0`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00HGoo0`001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYF001UOol005eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001KOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FWoo0P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Qo
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001GOol01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001EOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EGoo0P001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00E7oo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=J
EP04001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1UYF2@000eYF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP06FUH30006FUH00`00FUH000030002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP008Goo3`00=Goo001EOol00`00FUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP050002FUH00`00FUIJEP02FUH400000eYF001J
EP06FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0047oo4@0015YF00<005YFFUH01EYF00<005YFFUH01`00;Woo001EOol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF00002`001EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH000Qoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00=JEP@000AJEPP0
00AJEP03001JEUYF00=JEP/000EJEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol01000FUIJEP00
15YF00@005YFFUIJEPX000=JEP@000EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEP00
0080009JEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH01000
FUH000001EYF00<005YFFUH01EYF00<005YFFUH00eYF1@001UYF00<005YFFUH01EYF00@005YFFUIJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH20007FUH0
0`00FUIJEP06FUH50002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool005Eoo`05001JEUYFFUH00002FUH00`00FUH00007FUH00`00FUIJEP03
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000oOolA0005Ool01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YF
FUH00P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000iOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000eOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000cOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP<000QJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000/Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000002FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002aoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEPd000=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH60004FUH0
1000FUH000001EYF0P0000AJEP00FUH000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP<000QJ
EP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP040009FUH20002FUH4
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH0
0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3
0006FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ8000MJEP03001JEUYF00AJEPD00003FUH0000002aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH0100025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00EJEP03001JEP0000T00003FUH005YF00UJEP03001JEUYF00=JEP<000EJEP05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH015YF0`000UYF00<005YF000010000UYF00<005YFFUH01eYF3P000UYF00@005YFFUH000MJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP04000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005
FUH00`00FUH000040002FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF
001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0
035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP0000<000EJEP03001JEP0000@00003
FUH000000080009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000gOol002aoo`03001J
EP0000=JEP03001JEUYF00=JEPH000Qoo`T000AJEP03001JEUYF009JEP04001JEUYF0005FUH20002
FUH20005FUH00`00FUIJEP050007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000nOol002aoo`03001JEP00
00=JEP03001JEP0000<001Moo`H000=JEP04001JEUYF0004FUH20003FUH20005FUH01P00FUH00000
FUH000UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001oo`0M000DOol7000/Ool002]o
o`03001JEP0000AJEP80025oo`800005FUH005YFFUH00002FUH200000eYF001JEP02FUH20004FUH3
0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0003FUH20007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00:goo1`000UYF00<005YFFUH00P00;7oo000[Ool00`00
FUH00002FUH20002FUH00`00Oomoo`0POol20003FUH20003FUH00`00FUIJEP030002FUH20007FUH0
0`00FUIJEP05FUH700000eYF001JEP06FUH00`00FUIJEP060007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP006Woo4@000eYF00<005YFFUH00eYF00<005YFFUH00P00
;7oo000[Ool00`00FUH0000200000eYF001JEP02FUH20008Ool?000;Ool00`00FUIJEP020003FUH0
0`00FUIJEP060009FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH30004FUH20006FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05000=Ool90004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002]oo`03001JEP0000=JEP03
001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00@000Moo`03001JEP00009JEPT000=J
EP03001JEUYF00EJEP@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF009JEP<0
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH20003Ool8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002]oo`8000AJEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003Ool00`00FUH00004FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0
02]oo`8000AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUH00000Ool00P0000=JEP00FUH00eYF0P0025YF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01eYF00@005YF000000EJEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000500000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000[
Ool002]oo`8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP03FUH20008FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo0P000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF00000UYF0P000UYF00<005YFFUH00eYF0P001UYF00<005YFFUH01eYF00<005YFFUH0
15YF0P002EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00:goo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP04001JEUYFFUH30008FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000;FUH200001EYF001JEUYF00001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00P00:goo000[Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF0`000UYF00<005YFFUH00eYF10002EYF00<0
05YF00000P002eYF00<005YFFUH00UYF0P001eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP02FUH00`00FUIJEP02FUH50007FUH40002FUH00`00
FUIJEP07FUH20005FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1`00:goo000/Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH01000FUIJEUYF1P000UYF10001UYF00<005YFFUH01EYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHE000/
Ool002]oo`04001JEUYF0002FUH00`00FUIJEP03FUH600000eYF001JEP06FUH70006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP030006FUH01000FUIJEUYF20002UYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH8
000fOol002]oo`03001JEP0000=JEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00=J
EP@0009JEP03001JEUYF00AJEP8000=JEQ<000=JEP03001JEUYF00QJEP03001JEUYF00<000IJEP04
001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF2@000eYF2@00?Woo000[Ool00`00FUH0
0003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH50005FUH20003FUH0
1000FUH005YF10001EYF00<005YFFUH01UYF00<005YFFUH025YF0`0000=JEP00FUH01UYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH70004FUH80017Ool002]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP80009JEP07001JEUYF001JEP00
Ool00P001EYF00<005YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00H000=J
EPP004moo`00:goo00D005YF001JEP00009oo`800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP800003FUH000000080009JEP04001JEUYFFUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20006FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH04000EWoo000ZOol00`00FUIJEP020005
Ool20007FUH:0008FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEUYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02000UOol6000[Ool002Yoo`04001JEUYF0007Ool200000eYF000000040003FUH00`00FUIJEP02
FUH70002FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000=JEP<000EJEP03001JEUYF
00IJEPD00003FUH005YF00QJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00=JEP04001JEUYFFUH2000NOol70002
FUH01000FUIJEP00:goo000ZOol01000FUH000001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF001JEP80009JEP<000EJEP03001JEUYF00L0
00IJEP03001JEUYF00AJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF0P005Woo20000eYF00<005YFFUH0
0eYF00@005YFFUH002]oo`00:Woo0`0000=JEP00Ool00Woo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0`000eYF00<005YF00000`0000=JEP00FUH00UYF3@0015YF00<005YF
FUH01UYF00<005YFFUH00UYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH20003FUH01000FUIJEUYF0P001Woo400015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:Woo000ZOol3000015YF001oogoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH200000eYF001JEP02
FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol0
02Yoo`8000=JEP800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF008000Eoo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH0
05YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF008000IJEP`000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF008002Yoo`00:Woo0P000UYF00@005YFFUH000EJEPH000Uoo`H000IJEP03001J
EUYF00=JEP8000Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF00`000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00H002]oo`00:Woo0P0000=JEP00FUH00UYF00<005YF00000`005Goo10000UYF00<0
05YFFUH01EYF0P001Goo0P0000=JEP00FUH01UYF00<005YFFUH00UYF1P002EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
3P00<Goo000[Ool30003FUH4000KOol40007FUH20006Ool>0004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000nOol0
02]oo`80009JEP8000AJEP8001eoo`8000AJEP03001JEUYF0080009oo`H000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF009J
EPX004Moo`00:goo10001UYF00@005YF000001eoo`<00003FUH005YF00=JEP80009JEP@000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF009JEP04001JEUYFFUH:001?Ool0
02Yoo`05001JEP00FUH00006FUH01000FUIJEUYF0`007Goo0P001EYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH00eYF30001eYF00<005YFFUH00eYF30001EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02000Egoo000ZOol01@00FUH005YF00001UYF
00<005YFFUH015YF0`006Woo0`0015YF0P0000=JEP0000000P001EYF00<005YFFUH01EYF1`001eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00UYF1`001eYF00<005YFFUH00eYF00<005YF
FUH01`00Ggoo000ZOol200000goo00000006FUH00`00FUIJEP05FUH00`00FUH00003000AOol50003
FUH200000eYF001JEP02000015YF000000001EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF100015YF00<005YFFUH00eYF00@005YF
FUH000=JEP<005moo`00:Woo0P000Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF
4@000eYF00<005YFFUH015YF0P000UYF0P0000=oo`0000001EYF00<005YF00000P001EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<00003FUH0
05YF00AJEP04001JEUYF0002FUH01000FUIJEUYF0P00GGoo000ZOol00`00Oomoo`02Ool20003FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH01000Ool000001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP8005]o
o`00:Woo00<007ooOol017oo00@005YFFUH000QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000Ool000000eYF0P0000=JEP00FUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0P000eYF00@005YFFUH0009JEP03001JEUYF00AJEP<005Uoo`00:Woo0P001Woo0`001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUIJEP00FUH007oo
0P0000=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0002FUH00`00FUH00006FUH01@00
FUIJEUYF0000F7oo000ZOol00`00FUH00007Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001oo`030005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YF00001UYF00D005YFFUIJEP0005Qoo`00:Woo00<005YF
00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000Woo0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH0
0006FUH00`00FUIJEP02001HOol002Yoo`04001JEUYF000:Ool300000eYF001JEP06FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool01@00Ool005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00D005YFFUIJEP0005Uoo`00:Woo00D005YF
FUIJEP0000aoo`<000IJEP03001JEUYF00D0009JEP03001JEUYF00EJEP04001JEUYFFUH20007Ool0
1@00Ool005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000IJEP05001JEUYF
FUH0001IOol002]oo`03001JEUYF008000ioo`@0009JEP04001JEUYFFUH30002FUH00`00FUIJEP06
FUH01000FUH0000027oo0P0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF008005Uoo`00:goo00<005YF00000UYF0P0047oo1`0015YF00<005YFFUH00UYF1P00
2Woo0P000Woo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH0
0P00FGoo000/Ool20004FUH00`00Oomoo`0DOol9000?Ool00`00FUH00002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00Oomoo`1HOol002eo
o`03001JEUYF00=JEP8002aoo`03001JEP0000=oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30005FUH01000FUH000000eYF00<007ooOol0F7oo000^Ool00`00FUIJEP02FUH01000FUH0
0000:7oo10001Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP04001J
EUYFFUH4001JOol002moo`800003FUH005YF00=JEP<002=oo`800003FUH0000000Qoo`800003FUH0
05YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP@00003FUH005YF00EJEP03001JEUYF009JEP<005Yoo`00<Goo0P001eYF0`007Woo0P00
0eYF0P002Woo10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF00H005YFFUIJEP00FUH20006FUH00`00FUIJEP02FUH2001KOol0039oo`03
001JEUYF00IJEP03001JEP0000<001Ioo`@00003FUH005YF009JEP03001oogoo00eoo`@0009JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF008000IJ
EP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUH0001KOol003=oo`8000IJEP03001JEUYF
00=JEPL000Uoo`H000EJEP04001JEUYF000DOol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60006FUH00`00FUIJEP04FUH:001LOol003Eoo`8000=JEP03001JEUYF00IJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP04001JEP00000JOol60003FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP060006Ool40002FUH00`00FUIJEP05FUH3001ROol003Moo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80029ooal00003FUH0
0000008000]oo`@000IJEP03001JEUYF0080061oo`00>Goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00=Woo0P0015YF00<005YFFUH01UYF00<005YF00000P0037oo0P00
0eYF00<005YFFUH00eYF0P00GWoo000mOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000jOol200000eYF001JEP08FUH00`00FUIJEP02FUH3000;Ool200000eYF001JEP05FUH3
001LOol0045oo`L000AJEP03001JEUYF009JEPD0041oo`<000MJEP03001JEUYF00IJEPD000Qoo`80
00EJEP05001JEUYFFUH0001KOol004Qoo`T004Qoo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH8
0002Ool20003FUH01@00FUIJEUYF0000Fgoo002LOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF0P00Fgoo002OOol30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<007ooOol0FWoo002ROol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF1000G7oo002VOol70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000G7oo
002]Ool80003FUH00`00FUIJEP02FUH00`00FUH0001MOol00;Eoo`/005eoo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58523 .7426 m .59397 .6868 L .56327 .68063 L p .707 .577 .707 r
F P
0 g
s
.59397 .6868 m .58523 .7426 L .61673 .74683 L p .707 .577 .707 r
F P
0 g
s
.61673 .74683 m .62547 .69103 L .59397 .6868 L p .707 .577 .707 r
F P
0 g
s
.62547 .69103 m .61673 .74683 L .64596 .74871 L p .707 .577 .707 r
F P
0 g
s
.64596 .74871 m .65471 .69291 L .62547 .69103 L p .707 .577 .707 r
F P
0 g
s
.55452 .73644 m .56327 .68063 L .53638 .67314 L p .707 .577 .707 r
F P
0 g
s
.56327 .68063 m .55452 .73644 L .58523 .7426 L p .707 .577 .707 r
F P
0 g
s
.65471 .69291 m .64596 .74871 L .67006 .74806 L p .707 .577 .707 r
F P
0 g
s
.67006 .74806 m .6788 .69225 L .65471 .69291 L p .707 .577 .707 r
F P
0 g
s
.57346 .79883 m .58278 .76206 L .55283 .75327 L p .707 .577 .707 r
F P
0 g
s
.58278 .76206 m .57346 .79883 L .60444 .80617 L p .707 .577 .707 r
F P
0 g
s
.60444 .80617 m .61376 .7694 L .58278 .76206 L p .707 .577 .707 r
F P
0 g
s
.53638 .67314 m .52764 .72894 L .55452 .73644 L p .707 .577 .707 r
F P
0 g
s
.61376 .7694 m .60444 .80617 L .6334 .81134 L p .707 .577 .707 r
F P
0 g
s
.6334 .81134 m .64272 .77457 L .61376 .7694 L p .707 .577 .707 r
F P
0 g
s
.52764 .72894 m .53638 .67314 L .51593 .66504 L p .707 .577 .707 r
F P
0 g
s
.55283 .75327 m .54351 .79004 L .57346 .79883 L p .707 .577 .707 r
F P
0 g
s
.54351 .79004 m .55283 .75327 L .52683 .74389 L p .707 .577 .707 r
F P
0 g
s
.56333 .84066 m .56824 .82233 L .53867 .81305 L p .707 .577 .707 r
F P
0 g
s
.56824 .82233 m .56333 .84066 L .59422 .8486 L p .707 .577 .707 r
F P
0 g
s
.59422 .8486 m .59914 .83028 L .56824 .82233 L p .707 .577 .707 r
F P
0 g
s
.52683 .74389 m .51751 .78066 L .54351 .79004 L p .707 .577 .707 r
F P
0 g
s
.59914 .83028 m .59422 .8486 L .62342 .85442 L p .707 .577 .707 r
F P
0 g
s
.62342 .85442 m .62834 .8361 L .59914 .83028 L p .707 .577 .707 r
F P
0 g
s
.53867 .81305 m .53375 .83137 L .56333 .84066 L p .707 .577 .707 r
F P
0 g
s
.64272 .77457 m .6334 .81134 L .65751 .81383 L p .707 .577 .707 r
F P
0 g
s
.65751 .81383 m .66683 .77706 L .64272 .77457 L p .707 .577 .707 r
F P
0 g
s
.51593 .66504 m .50719 .72085 L .52764 .72894 L p .707 .577 .707 r
F P
0 g
s
.6788 .69225 m .67006 .74806 L .68665 .74494 L p .707 .577 .707 r
F P
0 g
s
.68665 .74494 m .69539 .68913 L .6788 .69225 L p .707 .577 .707 r
F P
0 g
s
.53375 .83137 m .53867 .81305 L .51331 .80333 L p .707 .577 .707 r
F P
0 g
s
.51751 .78066 m .52683 .74389 L .50733 .73484 L p .707 .577 .707 r
F P
0 g
s
.51331 .80333 m .5084 .82165 L .53375 .83137 L p .707 .577 .707 r
F P
0 g
s
.62834 .8361 m .62342 .85442 L .64806 .85756 L p .707 .577 .707 r
F P
0 g
s
.64806 .85756 m .65298 .83924 L .62834 .8361 L p .707 .577 .707 r
F P
0 g
s
.50719 .72085 m .51593 .66504 L .50393 .65714 L p .707 .577 .707 r
F P
0 g
s
.50733 .73484 m .49801 .77161 L .51751 .78066 L p .707 .577 .707 r
F P
0 g
s
.66683 .77706 m .65751 .81383 L .67442 .81341 L p .707 .577 .707 r
F P
0 g
s
.67442 .81341 m .68374 .77664 L .66683 .77706 L p .707 .577 .707 r
F P
0 g
s
.5084 .82165 m .51331 .80333 L .49466 .79413 L p .707 .577 .707 r
F P
0 g
s
.50393 .65714 m .49519 .71295 L .50719 .72085 L p .707 .577 .707 r
F P
0 g
s
.49466 .79413 m .48974 .81245 L .5084 .82165 L p .707 .577 .707 r
F P
0 g
s
.65298 .83924 m .64806 .85756 L .66573 .8577 L p .707 .577 .707 r
F P
0 g
s
.66573 .8577 m .67065 .83937 L .65298 .83924 L p .707 .577 .707 r
F P
0 g
s
.49801 .77161 m .50733 .73484 L .49623 .727 L p .707 .577 .707 r
F P
0 g
s
.69539 .68913 m .68665 .74494 L .69413 .73965 L p .707 .577 .707 r
F P
0 g
s
.69413 .73965 m .70287 .68384 L .69539 .68913 L p .707 .577 .707 r
F P
0 g
s
.49623 .727 m .48691 .76377 L .49801 .77161 L p .707 .577 .707 r
F P
0 g
s
.49519 .71295 m .50393 .65714 L .50155 .65021 L p .707 .577 .707 r
F P
0 g
s
.48974 .81245 m .49466 .79413 L .48453 .78635 L p .707 .577 .707 r
F P
0 g
s
.68374 .77664 m .67442 .81341 L .68246 .81011 L p .707 .577 .707 r
F P
0 g
s
.68246 .81011 m .69178 .77334 L .68374 .77664 L p .707 .577 .707 r
F P
0 g
s
.48453 .78635 m .47961 .80467 L .48974 .81245 L p .707 .577 .707 r
F P
0 g
s
.50155 .65021 m .49281 .70602 L .49519 .71295 L p .707 .577 .707 r
F P
0 g
s
.67065 .83937 m .66573 .8577 L .6747 .85483 L p .707 .577 .707 r
F P
0 g
s
.6747 .85483 m .67962 .8365 L .67065 .83937 L p .707 .577 .707 r
F P
0 g
s
.48691 .76377 m .49623 .727 L .49462 .72115 L p .707 .577 .707 r
F P
0 g
s
.70287 .68384 m .69413 .73965 L .69175 .73272 L p .707 .577 .707 r
F P
0 g
s
.69175 .73272 m .70049 .67691 L .70287 .68384 L p .707 .577 .707 r
F P
0 g
s
.49462 .72115 m .4853 .75792 L .48691 .76377 L p .707 .577 .707 r
F P
0 g
s
.49281 .70602 m .50155 .65021 L .50903 .64493 L p .707 .577 .707 r
F P
0 g
s
.50903 .64493 m .50029 .70073 L .49281 .70602 L p .707 .577 .707 r
F P
0 g
s
.4853 .75792 m .49462 .72115 L .50267 .71784 L p .707 .577 .707 r
F P
0 g
s
.50267 .71784 m .49335 .75461 L .4853 .75792 L p .707 .577 .707 r
F P
0 g
s
.50029 .70073 m .50903 .64493 L .52562 .6418 L p .707 .577 .707 r
F P
0 g
s
.52562 .6418 m .51688 .69761 L .50029 .70073 L p .707 .577 .707 r
F P
0 g
s
.49335 .75461 m .50267 .71784 L .51958 .71742 L p .707 .577 .707 r
F P
0 g
s
.51958 .71742 m .51025 .75419 L .49335 .75461 L p .707 .577 .707 r
F P
0 g
s
.48797 .7962 m .49289 .77788 L .51056 .77801 L p .707 .577 .707 r
F P
0 g
s
.51056 .77801 m .50564 .79634 L .48797 .7962 L p .707 .577 .707 r
F P
0 g
s
.50283 .82192 m .50283 .32003 L .45812 .31837 L p .707 .577 .707 r
F P
0 g
s
.51688 .69761 m .52562 .6418 L .54972 .64115 L p .707 .577 .707 r
F P
0 g
s
.54972 .64115 m .54098 .69696 L .51688 .69761 L p .707 .577 .707 r
F P
0 g
s
.51025 .75419 m .51958 .71742 L .54369 .71991 L p .707 .577 .707 r
F P
0 g
s
.54369 .71991 m .53437 .75668 L .51025 .75419 L p .707 .577 .707 r
F P
0 g
s
.50564 .79634 m .51056 .77801 L .5352 .78115 L p .707 .577 .707 r
F P
0 g
s
.5352 .78115 m .53028 .79947 L .50564 .79634 L p .707 .577 .707 r
F P
0 g
s
.53437 .75668 m .54369 .71991 L .57265 .72508 L p .707 .577 .707 r
F P
0 g
s
.57265 .72508 m .56333 .76185 L .53437 .75668 L p .707 .577 .707 r
F P
0 g
s
.53028 .79947 m .5352 .78115 L .5644 .78697 L p .707 .577 .707 r
F P
0 g
s
.5644 .78697 m .55948 .8053 L .53028 .79947 L p .707 .577 .707 r
F P
0 g
s
.50283 .32003 m .50283 .82192 L .54725 .81979 L p .707 .577 .707 r
F P
0 g
s
.54098 .69696 m .54972 .64115 L .57895 .64303 L p .707 .577 .707 r
F P
0 g
s
.57895 .64303 m .57021 .69884 L .54098 .69696 L p .707 .577 .707 r
F P
0 g
s
.54725 .81979 m .54725 .3179 L .50283 .32003 L p .707 .577 .707 r
F P
0 g
s
.47961 .80467 m .48453 .78635 L .48392 .78075 L p .707 .577 .707 r
F P
0 g
s
.45812 .82026 m .45812 .31837 L .41752 .31308 L p .707 .577 .707 r
F P
0 g
s
.48392 .78075 m .47901 .79907 L .47961 .80467 L p .707 .577 .707 r
F P
0 g
s
.47901 .79907 m .48392 .78075 L .49289 .77788 L p .707 .577 .707 r
F P
0 g
s
.49289 .77788 m .48797 .7962 L .47901 .79907 L p .707 .577 .707 r
F P
0 g
s
.45812 .31837 m .45812 .82026 L .50283 .82192 L p .707 .577 .707 r
F P
0 g
s
.57021 .69884 m .57895 .64303 L .61046 .64726 L p .707 .577 .707 r
F P
0 g
s
.61046 .64726 m .60171 .70307 L .57021 .69884 L p .707 .577 .707 r
F P
0 g
s
.56333 .76185 m .57265 .72508 L .60362 .73242 L p .707 .577 .707 r
F P
0 g
s
.60362 .73242 m .5943 .76919 L .56333 .76185 L p .707 .577 .707 r
F P
0 g
s
.55948 .8053 m .5644 .78697 L .5953 .79492 L p .707 .577 .707 r
F P
0 g
s
.5953 .79492 m .59038 .81324 L .55948 .8053 L p .707 .577 .707 r
F P
0 g
s
.54725 .3179 m .54725 .81979 L .58706 .81408 L p .707 .577 .707 r
F P
0 g
s
.58706 .81408 m .58706 .31219 L .54725 .3179 L p .707 .577 .707 r
F P
0 g
s
.69178 .77334 m .68246 .81011 L .68086 .80425 L p .707 .577 .707 r
F P
0 g
s
.68086 .80425 m .69018 .76748 L .69178 .77334 L p .707 .577 .707 r
F P
0 g
s
.67962 .8365 m .6747 .85483 L .67409 .84923 L p .707 .577 .707 r
F P
0 g
s
.67409 .84923 m .67901 .8309 L .67962 .8365 L p .707 .577 .707 r
F P
0 g
s
.70049 .67691 m .69175 .73272 L .67975 .72482 L p .707 .577 .707 r
F P
0 g
s
.67975 .72482 m .68849 .66901 L .70049 .67691 L p .707 .577 .707 r
F P
0 g
s
.41752 .81497 m .41752 .31308 L .38499 .30469 L p .707 .577 .707 r
F P
0 g
s
.41752 .31308 m .41752 .81497 L .45812 .82026 L p .707 .577 .707 r
F P
0 g
s
.64116 .65342 m .63242 .70923 L .60171 .70307 L p .707 .577 .707 r
F P
0 g
s
.60171 .70307 m .61046 .64726 L .64116 .65342 L p .707 .577 .707 r
F P
0 g
s
.63358 .74121 m .62426 .77798 L .5943 .76919 L p .707 .577 .707 r
F P
0 g
s
.5943 .76919 m .60362 .73242 L .63358 .74121 L p .707 .577 .707 r
F P
0 g
s
.59038 .81324 m .5953 .79492 L .62487 .8042 L p .707 .577 .707 r
F P
0 g
s
.58706 .31219 m .58706 .81408 L .61834 .80535 L p .707 .577 .707 r
F P
0 g
s
.61834 .80535 m .61834 .30346 L .58706 .31219 L p .707 .577 .707 r
F P
0 g
s
.24793 .72399 m .25168 .67155 L .22065 .66664 L p .707 .577 .707 r
F P
0 g
s
.25168 .67155 m .24793 .72399 L .27972 .72483 L p .707 .577 .707 r
F P
0 g
s
.27972 .72483 m .28348 .67239 L .25168 .67155 L p .707 .577 .707 r
F P
0 g
s
.69018 .76748 m .68086 .80425 L .66976 .79641 L p .707 .577 .707 r
F P
0 g
s
.66976 .79641 m .67908 .75964 L .69018 .76748 L p .707 .577 .707 r
F P
0 g
s
.28348 .67239 m .27972 .72483 L .30919 .72152 L p .707 .577 .707 r
F P
0 g
s
.30919 .72152 m .31294 .66908 L .28348 .67239 L p .707 .577 .707 r
F P
0 g
s
.2169 .71907 m .22065 .66664 L .19344 .65813 L p .707 .577 .707 r
F P
0 g
s
.22065 .66664 m .2169 .71907 L .24793 .72399 L p .707 .577 .707 r
F P
0 g
s
.67901 .8309 m .67409 .84923 L .66397 .84144 L p .707 .577 .707 r
F P
0 g
s
.66397 .84144 m .66888 .82312 L .67901 .8309 L p .707 .577 .707 r
F P
0 g
s
.68849 .66901 m .67975 .72482 L .65931 .71673 L p .707 .577 .707 r
F P
0 g
s
.65931 .71673 m .66805 .66092 L .68849 .66901 L p .707 .577 .707 r
F P
0 g
s
.31294 .66908 m .30919 .72152 L .33343 .71437 L p .707 .577 .707 r
F P
0 g
s
.33343 .71437 m .33718 .66194 L .31294 .66908 L p .707 .577 .707 r
F P
0 g
s
.38499 .80658 m .38499 .30469 L .36371 .29401 L p .707 .577 .707 r
F P
0 g
s
.38499 .30469 m .38499 .80658 L .41752 .81497 L p .707 .577 .707 r
F P
0 g
s
.18969 .71057 m .19344 .65813 L .17271 .64687 L p .707 .577 .707 r
F P
0 g
s
.19344 .65813 m .18969 .71057 L .2169 .71907 L p .707 .577 .707 r
F P
0 g
s
.66805 .66092 m .65931 .71673 L .63242 .70923 L p .707 .577 .707 r
F P
0 g
s
.63242 .70923 m .64116 .65342 L .66805 .66092 L p .707 .577 .707 r
F P
0 g
s
.65958 .75059 m .65026 .78736 L .62426 .77798 L p .707 .577 .707 r
F P
0 g
s
.62426 .77798 m .63358 .74121 L .65958 .75059 L p .707 .577 .707 r
F P
0 g
s
.61834 .30346 m .61834 .80535 L .63803 .79445 L p .707 .577 .707 r
F P
0 g
s
.63803 .79445 m .63803 .29257 L .61834 .30346 L p .707 .577 .707 r
F P
0 g
s
.67908 .75964 m .66976 .79641 L .65026 .78736 L p .707 .577 .707 r
F P
0 g
s
.65026 .78736 m .65958 .75059 L .67908 .75964 L p .707 .577 .707 r
F P
0 g
s
.33718 .66194 m .33343 .71437 L .35007 .7041 L p .707 .577 .707 r
F P
0 g
s
.35007 .7041 m .35383 .65166 L .33718 .66194 L p .707 .577 .707 r
F P
0 g
s
.24215 .7899 m .24617 .75678 L .21537 .75001 L p .707 .577 .707 r
F P
0 g
s
.24617 .75678 m .24215 .7899 L .27388 .79178 L p .707 .577 .707 r
F P
0 g
s
.27388 .79178 m .2779 .75866 L .24617 .75678 L p .707 .577 .707 r
F P
0 g
s
.2779 .75866 m .27388 .79178 L .30345 .78858 L p .707 .577 .707 r
F P
0 g
s
.30345 .78858 m .30746 .75546 L .2779 .75866 L p .707 .577 .707 r
F P
0 g
s
.21136 .78313 m .21537 .75001 L .18853 .73899 L p .707 .577 .707 r
F P
0 g
s
.21537 .75001 m .21136 .78313 L .24215 .7899 L p .707 .577 .707 r
F P
0 g
s
.66888 .82312 m .66397 .84144 L .64531 .83224 L p .707 .577 .707 r
F P
0 g
s
.64531 .83224 m .65023 .81392 L .66888 .82312 L p .707 .577 .707 r
F P
0 g
s
.16896 .69931 m .17271 .64687 L .16048 .63395 L p .707 .577 .707 r
F P
0 g
s
.17271 .64687 m .16896 .69931 L .18969 .71057 L p .707 .577 .707 r
F P
0 g
s
.30746 .75546 m .30345 .78858 L .32795 .78061 L p .707 .577 .707 r
F P
0 g
s
.32795 .78061 m .33196 .74749 L .30746 .75546 L p .707 .577 .707 r
F P
0 g
s
.18452 .77211 m .18853 .73899 L .16827 .72483 L p .707 .577 .707 r
F P
0 g
s
.18853 .73899 m .18452 .77211 L .21136 .78313 L p .707 .577 .707 r
F P
0 g
s
.36371 .7959 m .36371 .29401 L .35578 .28209 L p .707 .577 .707 r
F P
0 g
s
.36371 .29401 m .36371 .7959 L .38499 .80658 L p .707 .577 .707 r
F P
0 g
s
.35383 .65166 m .35007 .7041 L .3575 .69171 L p .707 .577 .707 r
F P
0 g
s
.3575 .69171 m .36125 .63927 L .35383 .65166 L p .707 .577 .707 r
F P
0 g
s
.63803 .29257 m .63803 .79445 L .64422 .78246 L p .707 .577 .707 r
F P
0 g
s
.64422 .78246 m .64422 .28057 L .63803 .29257 L p .707 .577 .707 r
F P
0 g
s
.23616 .83161 m .23826 .81528 L .20773 .80781 L p .707 .577 .707 r
F P
0 g
s
.23826 .81528 m .23616 .83161 L .26792 .83404 L p .707 .577 .707 r
F P
0 g
s
.26792 .83404 m .27002 .8177 L .23826 .81528 L p .707 .577 .707 r
F P
0 g
s
.16048 .63395 m .15673 .68639 L .16896 .69931 L p .707 .577 .707 r
F P
0 g
s
.65023 .81392 m .64531 .83224 L .61996 .82253 L p .707 .577 .707 r
F P
0 g
s
.61996 .82253 m .62487 .8042 L .65023 .81392 L p .707 .577 .707 r
F P
0 g
s
.27002 .8177 m .26792 .83404 L .2978 .83118 L p .707 .577 .707 r
F P
0 g
s
.2978 .83118 m .2999 .81485 L .27002 .8177 L p .707 .577 .707 r
F P
0 g
s
.15673 .68639 m .16048 .63395 L .15795 .62065 L p .707 .577 .707 r
F P
0 g
s
.33196 .74749 m .32795 .78061 L .34498 .76865 L p .707 .577 .707 r
F P
0 g
s
.34498 .76865 m .349 .73553 L .33196 .74749 L p .707 .577 .707 r
F P
0 g
s
.20563 .82415 m .20773 .80781 L .18142 .79603 L p .707 .577 .707 r
F P
0 g
s
.20773 .80781 m .20563 .82415 L .23616 .83161 L p .707 .577 .707 r
F P
0 g
s
.16827 .72483 m .16426 .75795 L .18452 .77211 L p .707 .577 .707 r
F P
0 g
s
.16426 .75795 m .16827 .72483 L .15657 .70889 L p .707 .577 .707 r
F P
0 g
s
.2999 .81485 m .2978 .83118 L .32288 .82333 L p .707 .577 .707 r
F P
0 g
s
.32288 .82333 m .32498 .80699 L .2999 .81485 L p .707 .577 .707 r
F P
0 g
s
.18142 .79603 m .17932 .81237 L .20563 .82415 L p .707 .577 .707 r
F P
0 g
s
.62487 .8042 m .61996 .82253 L .59038 .81324 L p .707 .577 .707 r
F P
0 g
s
.17932 .81237 m .18142 .79603 L .1619 .78109 L p .707 .577 .707 r
F P
0 g
s
.36125 .63927 m .3575 .69171 L .35497 .6784 L p .707 .577 .707 r
F P
0 g
s
.35497 .6784 m .35872 .62596 L .36125 .63927 L p .707 .577 .707 r
F P
0 g
s
.15795 .62065 m .1542 .67308 L .15673 .68639 L p .707 .577 .707 r
F P
0 g
s
.15657 .70889 m .15256 .74201 L .16426 .75795 L p .707 .577 .707 r
F P
0 g
s
.349 .73553 m .34498 .76865 L .3529 .75387 L p .707 .577 .707 r
F P
0 g
s
.3529 .75387 m .35691 .72075 L .349 .73553 L p .707 .577 .707 r
F P
0 g
s
.1619 .78109 m .15981 .79743 L .17932 .81237 L p .707 .577 .707 r
F P
0 g
s
.32498 .80699 m .32288 .82333 L .3407 .81124 L p .707 .577 .707 r
F P
0 g
s
.3407 .81124 m .3428 .7949 L .32498 .80699 L p .707 .577 .707 r
F P
0 g
s
.1542 .67308 m .15795 .62065 L .16537 .60825 L p .707 .577 .707 r
F P
0 g
s
.15256 .74201 m .15657 .70889 L .15458 .69274 L p .707 .577 .707 r
F P
0 g
s
.35872 .62596 m .35497 .6784 L .34274 .66548 L p .707 .577 .707 r
F P
0 g
s
.34274 .66548 m .34649 .61304 L .35872 .62596 L p .707 .577 .707 r
F P
0 g
s
.35691 .72075 m .3529 .75387 L .35091 .73773 L p .707 .577 .707 r
F P
0 g
s
.35091 .73773 m .35492 .70461 L .35691 .72075 L p .707 .577 .707 r
F P
0 g
s
.35578 .28209 m .35578 .78398 L .36371 .7959 L p .707 .577 .707 r
F P
0 g
s
.35578 .78398 m .35578 .28209 L .36197 .27009 L p .707 .577 .707 r
F P
0 g
s
.15981 .79743 m .1619 .78109 L .15109 .76446 L p .707 .577 .707 r
F P
0 g
s
.64422 .28057 m .64422 .78246 L .63628 .77054 L p .707 .577 .707 r
F P
0 g
s
.63628 .77054 m .63628 .26865 L .64422 .28057 L p .707 .577 .707 r
F P
0 g
s
.15109 .76446 m .149 .78079 L .15981 .79743 L p .707 .577 .707 r
F P
0 g
s
.15458 .69274 m .15057 .72586 L .15256 .74201 L p .707 .577 .707 r
F P
0 g
s
.3428 .7949 m .3407 .81124 L .34952 .7961 L p .707 .577 .707 r
F P
0 g
s
.34952 .7961 m .35161 .77977 L .3428 .7949 L p .707 .577 .707 r
F P
0 g
s
.16537 .60825 m .16162 .66069 L .1542 .67308 L p .707 .577 .707 r
F P
0 g
s
.16162 .66069 m .16537 .60825 L .18202 .59798 L p .707 .577 .707 r
F P
0 g
s
.15057 .72586 m .15458 .69274 L .16249 .67796 L p .707 .577 .707 r
F P
0 g
s
.149 .78079 m .15109 .76446 L .15004 .74776 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15004 .74776 m .14795 .76409 L .149 .78079 L p .707 .577 .707 r
F P
0 g
s
.36197 .77198 m .36197 .27009 L .38166 .2592 L p .707 .577 .707 r
F P
0 g
s
.36197 .27009 m .36197 .77198 L .35578 .78398 L p .707 .577 .707 r
F P
0 g
s
.34649 .61304 m .34274 .66548 L .322 .65422 L p .707 .577 .707 r
F P
0 g
s
.322 .65422 m .32576 .60178 L .34649 .61304 L p .707 .577 .707 r
F P
0 g
s
.16249 .67796 m .15848 .71108 L .15057 .72586 L p .707 .577 .707 r
F P
0 g
s
.35161 .77977 m .34952 .7961 L .34847 .7794 L p .707 .577 .707 r
F P
0 g
s
.34847 .7794 m .35057 .76306 L .35161 .77977 L p .707 .577 .707 r
F P
0 g
s
.63628 .26865 m .63628 .77054 L .61501 .75986 L p .707 .577 .707 r
F P
0 g
s
.61501 .75986 m .61501 .25797 L .63628 .26865 L p .707 .577 .707 r
F P
0 g
s
.35492 .70461 m .35091 .73773 L .33921 .72179 L p .707 .577 .707 r
F P
0 g
s
.33921 .72179 m .34322 .68867 L .35492 .70461 L p .707 .577 .707 r
F P
0 g
s
.18202 .59798 m .17827 .65042 L .16162 .66069 L p .707 .577 .707 r
F P
0 g
s
.17827 .65042 m .18202 .59798 L .20626 .59084 L p .707 .577 .707 r
F P
0 g
s
.15848 .71108 m .16249 .67796 L .17953 .66601 L p .707 .577 .707 r
F P
0 g
s
.14795 .76409 m .15004 .74776 L .15886 .73262 L p .707 .577 .707 r
F P
0 g
s
.32576 .60178 m .322 .65422 L .29479 .64572 L p .707 .577 .707 r
F P
0 g
s
.29479 .64572 m .29855 .59328 L .32576 .60178 L p .707 .577 .707 r
F P
0 g
s
.15886 .73262 m .15677 .74895 L .14795 .76409 L p .707 .577 .707 r
F P
0 g
s
.20251 .64327 m .20626 .59084 L .23572 .58752 L p .707 .577 .707 r
F P
0 g
s
.20626 .59084 m .20251 .64327 L .17827 .65042 L p .707 .577 .707 r
F P
0 g
s
.17953 .66601 m .17552 .69913 L .15848 .71108 L p .707 .577 .707 r
F P
0 g
s
.34322 .68867 m .33921 .72179 L .31895 .70762 L p .707 .577 .707 r
F P
0 g
s
.31895 .70762 m .32296 .6745 L .34322 .68867 L p .707 .577 .707 r
F P
0 g
s
.35057 .76306 m .34847 .7794 L .33766 .76276 L p .707 .577 .707 r
F P
0 g
s
.33766 .76276 m .33976 .74643 L .35057 .76306 L p .707 .577 .707 r
F P
0 g
s
.17552 .69913 m .17953 .66601 L .20403 .65803 L p .707 .577 .707 r
F P
0 g
s
.29855 .59328 m .29479 .64572 L .26377 .6408 L p .707 .577 .707 r
F P
0 g
s
.26377 .6408 m .26752 .58836 L .29855 .59328 L p .707 .577 .707 r
F P
0 g
s
.38166 .76109 m .38166 .2592 L .41294 .25047 L p .707 .577 .707 r
F P
0 g
s
.38166 .2592 m .38166 .76109 L .36197 .77198 L p .707 .577 .707 r
F P
0 g
s
.23197 .63996 m .23572 .58752 L .26752 .58836 L p .707 .577 .707 r
F P
0 g
s
.23572 .58752 m .23197 .63996 L .20251 .64327 L p .707 .577 .707 r
F P
0 g
s
.15677 .74895 m .15886 .73262 L .17668 .72053 L p .707 .577 .707 r
F P
0 g
s
.61501 .25797 m .61501 .75986 L .58248 .75147 L p .707 .577 .707 r
F P
0 g
s
.58248 .75147 m .58248 .24958 L .61501 .25797 L p .707 .577 .707 r
F P
0 g
s
.26752 .58836 m .26377 .6408 L .23197 .63996 L p .707 .577 .707 r
F P
0 g
s
.73623 .64473 m .73248 .58755 L .70145 .58868 L p .707 .577 .707 r
F P
0 g
s
.73248 .58755 m .73623 .64473 L .76803 .64237 L p .707 .577 .707 r
F P
0 g
s
.76803 .64237 m .76428 .58519 L .73248 .58755 L p .707 .577 .707 r
F P
0 g
s
.76428 .58519 m .76803 .64237 L .79749 .63903 L p .707 .577 .707 r
F P
0 g
s
.79749 .63903 m .79374 .58185 L .76428 .58519 L p .707 .577 .707 r
F P
0 g
s
.17668 .72053 m .17459 .73686 L .15677 .74895 L p .707 .577 .707 r
F P
0 g
s
.32296 .6745 m .31895 .70762 L .2921 .69661 L p .707 .577 .707 r
F P
0 g
s
.2921 .69661 m .29612 .66349 L .32296 .6745 L p .707 .577 .707 r
F P
0 g
s
.70145 .58868 m .7052 .64586 L .73623 .64473 L p .707 .577 .707 r
F P
0 g
s
.7052 .64586 m .70145 .58868 L .67424 .58849 L p .707 .577 .707 r
F P
0 g
s
.20002 .69115 m .20403 .65803 L .23359 .65483 L p .707 .577 .707 r
F P
0 g
s
.20403 .65803 m .20002 .69115 L .17552 .69913 L p .707 .577 .707 r
F P
0 g
s
.33976 .74643 m .33766 .76276 L .31815 .74782 L p .707 .577 .707 r
F P
0 g
s
.31815 .74782 m .32024 .73149 L .33976 .74643 L p .707 .577 .707 r
F P
0 g
s
.73869 .69787 m .73467 .65962 L .70388 .6627 L p .707 .577 .707 r
F P
0 g
s
.73467 .65962 m .73869 .69787 L .77042 .6945 L p .707 .577 .707 r
F P
0 g
s
.77042 .6945 m .7664 .65626 L .73467 .65962 L p .707 .577 .707 r
F P
0 g
s
.70388 .6627 m .70789 .70095 L .73869 .69787 L p .707 .577 .707 r
F P
0 g
s
.79374 .58185 m .79749 .63903 L .82173 .63502 L p .707 .577 .707 r
F P
0 g
s
.82173 .63502 m .81798 .57784 L .79374 .58185 L p .707 .577 .707 r
F P
0 g
s
.67424 .58849 m .67799 .64566 L .7052 .64586 L p .707 .577 .707 r
F P
0 g
s
.7664 .65626 m .77042 .6945 L .79998 .69118 L p .707 .577 .707 r
F P
0 g
s
.79998 .69118 m .79597 .65293 L .7664 .65626 L p .707 .577 .707 r
F P
0 g
s
.17459 .73686 m .17668 .72053 L .20176 .71267 L p .707 .577 .707 r
F P
0 g
s
.29612 .66349 m .2921 .69661 L .26131 .68983 L p .707 .577 .707 r
F P
0 g
s
.26131 .68983 m .26532 .65671 L .29612 .66349 L p .707 .577 .707 r
F P
0 g
s
.70607 .72423 m .70816 .74335 L .73869 .73997 L p .707 .577 .707 r
F P
0 g
s
.73869 .73997 m .73659 .72086 L .70607 .72423 L p .707 .577 .707 r
F P
0 g
s
.73659 .72086 m .73869 .73997 L .77045 .7365 L p .707 .577 .707 r
F P
0 g
s
.77045 .7365 m .76835 .71738 L .73659 .72086 L p .707 .577 .707 r
F P
0 g
s
.76835 .71738 m .77045 .7365 L .80033 .73326 L p .707 .577 .707 r
F P
0 g
s
.22958 .68795 m .23359 .65483 L .26532 .65671 L p .707 .577 .707 r
F P
0 g
s
.23359 .65483 m .22958 .68795 L .20002 .69115 L p .707 .577 .707 r
F P
0 g
s
.80033 .73326 m .79824 .71414 L .76835 .71738 L p .707 .577 .707 r
F P
0 g
s
.70789 .70095 m .70388 .6627 L .67704 .66518 L p .707 .577 .707 r
F P
0 g
s
.67704 .66518 m .68105 .70343 L .70789 .70095 L p .707 .577 .707 r
F P
0 g
s
.26532 .65671 m .26131 .68983 L .22958 .68795 L p .707 .577 .707 r
F P
0 g
s
.41294 .25047 m .41294 .75236 L .38166 .76109 L p .707 .577 .707 r
F P
0 g
s
.41294 .75236 m .41294 .25047 L .45274 .24476 L p .707 .577 .707 r
F P
0 g
s
.67799 .64566 m .67424 .58849 L .65351 .58698 L p .707 .577 .707 r
F P
0 g
s
.79597 .65293 m .79998 .69118 L .82448 .68822 L p .707 .577 .707 r
F P
0 g
s
.82448 .68822 m .82047 .64997 L .79597 .65293 L p .707 .577 .707 r
F P
0 g
s
.58248 .24958 m .58248 .75147 L .54188 .74618 L p .707 .577 .707 r
F P
0 g
s
.54188 .74618 m .54188 .24429 L .58248 .24958 L p .707 .577 .707 r
F P
0 g
s
.67976 .72717 m .68185 .74629 L .70816 .74335 L p .707 .577 .707 r
F P
0 g
s
.70816 .74335 m .70607 .72423 L .67976 .72717 L p .707 .577 .707 r
F P
0 g
s
.20176 .71267 m .19967 .72901 L .17459 .73686 L p .707 .577 .707 r
F P
0 g
s
.32024 .73149 m .31815 .74782 L .29184 .73604 L p .707 .577 .707 r
F P
0 g
s
.29184 .73604 m .29393 .71971 L .32024 .73149 L p .707 .577 .707 r
F P
0 g
s
.79824 .71414 m .80033 .73326 L .82541 .73058 L p .707 .577 .707 r
F P
0 g
s
.82541 .73058 m .82331 .71146 L .79824 .71414 L p .707 .577 .707 r
F P
0 g
s
.65351 .58698 m .65726 .64415 L .67799 .64566 L p .707 .577 .707 r
F P
0 g
s
.81798 .57784 m .82173 .63502 L .83838 .63074 L p .707 .577 .707 r
F P
0 g
s
.83838 .63074 m .83462 .57356 L .81798 .57784 L p .707 .577 .707 r
F P
0 g
s
.19967 .72901 m .20176 .71267 L .23164 .70982 L p .707 .577 .707 r
F P
0 g
s
.68105 .70343 m .67704 .66518 L .65678 .66683 L p .707 .577 .707 r
F P
0 g
s
.65678 .66683 m .66079 .70508 L .68105 .70343 L p .707 .577 .707 r
F P
0 g
s
.29393 .71971 m .29184 .73604 L .26131 .72858 L p .707 .577 .707 r
F P
0 g
s
.26131 .72858 m .2634 .71224 L .29393 .71971 L p .707 .577 .707 r
F P
0 g
s
.45274 .74665 m .45274 .24476 L .49717 .24263 L p .707 .577 .707 r
F P
0 g
s
.45274 .24476 m .45274 .74665 L .41294 .75236 L p .707 .577 .707 r
F P
0 g
s
.66024 .72939 m .66234 .74851 L .68185 .74629 L p .707 .577 .707 r
F P
0 g
s
.68185 .74629 m .67976 .72717 L .66024 .72939 L p .707 .577 .707 r
F P
0 g
s
.23164 .70982 m .22955 .72615 L .19967 .72901 L p .707 .577 .707 r
F P
0 g
s
.54188 .24429 m .54188 .74618 L .49717 .74452 L p .707 .577 .707 r
F P
0 g
s
.49717 .74452 m .49717 .24263 L .54188 .24429 L p .707 .577 .707 r
F P
0 g
s
.82047 .64997 m .82448 .68822 L .84152 .68591 L p .707 .577 .707 r
F P
0 g
s
.84152 .68591 m .83751 .64767 L .82047 .64997 L p .707 .577 .707 r
F P
0 g
s
.22955 .72615 m .23164 .70982 L .2634 .71224 L p .707 .577 .707 r
F P
0 g
s
.65726 .64415 m .65351 .58698 L .64128 .5843 L p .707 .577 .707 r
F P
0 g
s
.2634 .71224 m .26131 .72858 L .22955 .72615 L p .707 .577 .707 r
F P
0 g
s
.82331 .71146 m .82541 .73058 L .84323 .72871 L p .707 .577 .707 r
F P
0 g
s
.84323 .72871 m .84114 .70959 L .82331 .71146 L p .707 .577 .707 r
F P
0 g
s
.49717 .24263 m .49717 .74452 L .45274 .74665 L p .707 .577 .707 r
F P
0 g
s
.64128 .5843 m .64503 .64148 L .65726 .64415 L p .707 .577 .707 r
F P
0 g
s
.83462 .57356 m .83838 .63074 L .8458 .62661 L p .707 .577 .707 r
F P
0 g
s
.8458 .62661 m .84205 .56943 L .83462 .57356 L p .707 .577 .707 r
F P
0 g
s
.66079 .70508 m .65678 .66683 L .64508 .66749 L p .707 .577 .707 r
F P
0 g
s
.64508 .66749 m .64909 .70574 L .66079 .70508 L p .707 .577 .707 r
F P
0 g
s
.64943 .73067 m .65153 .74979 L .66234 .74851 L p .707 .577 .707 r
F P
0 g
s
.66234 .74851 m .66024 .72939 L .64943 .73067 L p .707 .577 .707 r
F P
0 g
s
.83751 .64767 m .84152 .68591 L .84943 .68449 L p .707 .577 .707 r
F P
0 g
s
.84943 .68449 m .84542 .64624 L .83751 .64767 L p .707 .577 .707 r
F P
0 g
s
.84114 .70959 m .84323 .72871 L .85205 .72784 L p .707 .577 .707 r
F P
0 g
s
.85205 .72784 m .84995 .70873 L .84114 .70959 L p .707 .577 .707 r
F P
0 g
s
.64503 .64148 m .64128 .5843 L .63875 .58073 L p .707 .577 .707 r
F P
0 g
s
.63875 .58073 m .6425 .6379 L .64503 .64148 L p .707 .577 .707 r
F P
0 g
s
.84205 .56943 m .8458 .62661 L .84327 .62303 L p .707 .577 .707 r
F P
0 g
s
.84327 .62303 m .83952 .56586 L .84205 .56943 L p .707 .577 .707 r
F P
0 g
s
.64909 .70574 m .64508 .66749 L .64309 .66709 L p .707 .577 .707 r
F P
0 g
s
.64309 .66709 m .6471 .70534 L .64909 .70574 L p .707 .577 .707 r
F P
0 g
s
.64838 .73089 m .65048 .75001 L .65153 .74979 L p .707 .577 .707 r
F P
0 g
s
.65153 .74979 m .64943 .73067 L .64838 .73089 L p .707 .577 .707 r
F P
0 g
s
.84542 .64624 m .84943 .68449 L .84744 .68409 L p .707 .577 .707 r
F P
0 g
s
.84744 .68409 m .84343 .64584 L .84542 .64624 L p .707 .577 .707 r
F P
0 g
s
.84995 .70873 m .85205 .72784 L .851 .72806 L p .707 .577 .707 r
F P
0 g
s
.851 .72806 m .84891 .70894 L .84995 .70873 L p .707 .577 .707 r
F P
0 g
s
.6425 .6379 m .63875 .58073 L .64617 .5766 L p .707 .577 .707 r
F P
0 g
s
.64617 .5766 m .64992 .63377 L .6425 .6379 L p .707 .577 .707 r
F P
0 g
s
.83952 .56586 m .84327 .62303 L .83104 .62036 L p .707 .577 .707 r
F P
0 g
s
.83104 .62036 m .82729 .56318 L .83952 .56586 L p .707 .577 .707 r
F P
0 g
s
.6471 .70534 m .64309 .66709 L .651 .66566 L p .707 .577 .707 r
F P
0 g
s
.651 .66566 m .65501 .70391 L .6471 .70534 L p .707 .577 .707 r
F P
0 g
s
.6572 .73002 m .6593 .74914 L .65048 .75001 L p .707 .577 .707 r
F P
0 g
s
.65048 .75001 m .64838 .73089 L .6572 .73002 L p .707 .577 .707 r
F P
0 g
s
.84343 .64584 m .84744 .68409 L .83574 .68474 L p .707 .577 .707 r
F P
0 g
s
.83574 .68474 m .83173 .6465 L .84343 .64584 L p .707 .577 .707 r
F P
0 g
s
.39828 .62657 m .38954 .57271 L .35884 .57467 L p .707 .577 .707 r
F P
0 g
s
.38954 .57271 m .39828 .62657 L .42979 .62121 L p .707 .577 .707 r
F P
0 g
s
.42979 .62121 m .42105 .56736 L .38954 .57271 L p .707 .577 .707 r
F P
0 g
s
.42105 .56736 m .42979 .62121 L .45902 .61299 L p .707 .577 .707 r
F P
0 g
s
.45902 .61299 m .45028 .55913 L .42105 .56736 L p .707 .577 .707 r
F P
0 g
s
.84891 .70894 m .851 .72806 L .84019 .72934 L p .707 .577 .707 r
F P
0 g
s
.84019 .72934 m .8381 .71022 L .84891 .70894 L p .707 .577 .707 r
F P
0 g
s
.64992 .63377 m .64617 .5766 L .66282 .57232 L p .707 .577 .707 r
F P
0 g
s
.36758 .62852 m .35884 .57467 L .33195 .57303 L p .707 .577 .707 r
F P
0 g
s
.35884 .57467 m .36758 .62852 L .39828 .62657 L p .707 .577 .707 r
F P
0 g
s
.66282 .57232 m .66657 .6295 L .64992 .63377 L p .707 .577 .707 r
F P
0 g
s
.45028 .55913 m .45902 .61299 L .48311 .60269 L p .707 .577 .707 r
F P
0 g
s
.48311 .60269 m .47437 .54884 L .45028 .55913 L p .707 .577 .707 r
F P
0 g
s
.82729 .56318 m .83104 .62036 L .81031 .61885 L p .707 .577 .707 r
F P
0 g
s
.81031 .61885 m .80656 .56167 L .82729 .56318 L p .707 .577 .707 r
F P
0 g
s
.65501 .70391 m .651 .66566 L .66804 .66336 L p .707 .577 .707 r
F P
0 g
s
.66804 .66336 m .67205 .70161 L .65501 .70391 L p .707 .577 .707 r
F P
0 g
s
.67502 .72815 m .67712 .74727 L .6593 .74914 L p .707 .577 .707 r
F P
0 g
s
.6593 .74914 m .6572 .73002 L .67502 .72815 L p .707 .577 .707 r
F P
0 g
s
.34069 .62688 m .33195 .57303 L .31151 .56796 L p .707 .577 .707 r
F P
0 g
s
.33195 .57303 m .34069 .62688 L .36758 .62852 L p .707 .577 .707 r
F P
0 g
s
.43667 .68235 m .42735 .64757 L .39637 .65538 L p .707 .577 .707 r
F P
0 g
s
.42735 .64757 m .43667 .68235 L .46563 .67146 L p .707 .577 .707 r
F P
0 g
s
.46563 .67146 m .45631 .63668 L .42735 .64757 L p .707 .577 .707 r
F P
0 g
s
.40569 .69015 m .39637 .65538 L .36642 .65934 L p .707 .577 .707 r
F P
0 g
s
.39637 .65538 m .40569 .69015 L .43667 .68235 L p .707 .577 .707 r
F P
0 g
s
.83173 .6465 m .83574 .68474 L .81548 .6864 L p .707 .577 .707 r
F P
0 g
s
.81548 .6864 m .81147 .64815 L .83173 .6465 L p .707 .577 .707 r
F P
0 g
s
.47437 .54884 m .48311 .60269 L .49971 .59133 L p .707 .577 .707 r
F P
0 g
s
.49971 .59133 m .49097 .53748 L .47437 .54884 L p .707 .577 .707 r
F P
0 g
s
.66657 .6295 m .66282 .57232 L .68706 .56831 L p .707 .577 .707 r
F P
0 g
s
.8381 .71022 m .84019 .72934 L .82068 .73156 L p .707 .577 .707 r
F P
0 g
s
.82068 .73156 m .81858 .71244 L .8381 .71022 L p .707 .577 .707 r
F P
0 g
s
.45631 .63668 m .46563 .67146 L .48974 .65855 L p .707 .577 .707 r
F P
0 g
s
.48974 .65855 m .48042 .62377 L .45631 .63668 L p .707 .577 .707 r
F P
0 g
s
.68706 .56831 m .69081 .62549 L .66657 .6295 L p .707 .577 .707 r
F P
0 g
s
.37574 .69412 m .36642 .65934 L .34042 .65907 L p .707 .577 .707 r
F P
0 g
s
.36642 .65934 m .37574 .69412 L .40569 .69015 L p .707 .577 .707 r
F P
0 g
s
.80656 .56167 m .81031 .61885 L .7831 .61865 L p .707 .577 .707 r
F P
0 g
s
.7831 .61865 m .77935 .56148 L .80656 .56167 L p .707 .577 .707 r
F P
0 g
s
.67205 .70161 m .66804 .66336 L .69254 .6604 L p .707 .577 .707 r
F P
0 g
s
.69254 .6604 m .69655 .69865 L .67205 .70161 L p .707 .577 .707 r
F P
0 g
s
.31151 .56796 m .32025 .62181 L .34069 .62688 L p .707 .577 .707 r
F P
0 g
s
.44051 .72447 m .4356 .70715 L .4047 .71499 L p .707 .577 .707 r
F P
0 g
s
.4356 .70715 m .44051 .72447 L .46971 .71347 L p .707 .577 .707 r
F P
0 g
s
.46971 .71347 m .4648 .69615 L .4356 .70715 L p .707 .577 .707 r
F P
0 g
s
.69081 .62549 m .68706 .56831 L .71652 .56497 L p .707 .577 .707 r
F P
0 g
s
.32025 .62181 m .31151 .56796 L .29951 .55996 L p .707 .577 .707 r
F P
0 g
s
.40962 .73231 m .4047 .71499 L .37512 .7189 L p .707 .577 .707 r
F P
0 g
s
.4047 .71499 m .40962 .73231 L .44051 .72447 L p .707 .577 .707 r
F P
0 g
s
.48042 .62377 m .48974 .65855 L .50665 .64489 L p .707 .577 .707 r
F P
0 g
s
.50665 .64489 m .49733 .61011 L .48042 .62377 L p .707 .577 .707 r
F P
0 g
s
.7001 .72547 m .7022 .74459 L .67712 .74727 L p .707 .577 .707 r
F P
0 g
s
.67712 .74727 m .67502 .72815 L .7001 .72547 L p .707 .577 .707 r
F P
0 g
s
.34042 .65907 m .34974 .69384 L .37574 .69412 L p .707 .577 .707 r
F P
0 g
s
.81147 .64815 m .81548 .6864 L .78864 .68888 L p .707 .577 .707 r
F P
0 g
s
.78864 .68888 m .78463 .65063 L .81147 .64815 L p .707 .577 .707 r
F P
0 g
s
.49097 .53748 m .49971 .59133 L .50718 .58002 L p .707 .577 .707 r
F P
0 g
s
.50718 .58002 m .49844 .52617 L .49097 .53748 L p .707 .577 .707 r
F P
0 g
s
.4648 .69615 m .46971 .71347 L .49435 .70038 L p .707 .577 .707 r
F P
0 g
s
.49435 .70038 m .48944 .68306 L .4648 .69615 L p .707 .577 .707 r
F P
0 g
s
.77935 .56148 m .7831 .61865 L .75207 .61979 L p .707 .577 .707 r
F P
0 g
s
.75207 .61979 m .74832 .56261 L .77935 .56148 L p .707 .577 .707 r
F P
0 g
s
.71652 .56497 m .72027 .62214 L .69081 .62549 L p .707 .577 .707 r
F P
0 g
s
.81858 .71244 m .82068 .73156 L .79437 .7345 L p .707 .577 .707 r
F P
0 g
s
.79437 .7345 m .79227 .71538 L .81858 .71244 L p .707 .577 .707 r
F P
0 g
s
.37512 .7189 m .38004 .73622 L .40962 .73231 L p .707 .577 .707 r
F P
0 g
s
.34974 .69384 m .34042 .65907 L .32092 .65459 L p .707 .577 .707 r
F P
0 g
s
.72027 .62214 m .71652 .56497 L .74832 .56261 L p .707 .577 .707 r
F P
0 g
s
.38004 .73622 m .37512 .7189 L .34977 .7185 L p .707 .577 .707 r
F P
0 g
s
.74832 .56261 m .75207 .61979 L .72027 .62214 L p .707 .577 .707 r
F P
0 g
s
.69655 .69865 m .69254 .6604 L .7221 .65707 L p .707 .577 .707 r
F P
0 g
s
.7221 .65707 m .72612 .69532 L .69655 .69865 L p .707 .577 .707 r
F P
0 g
s
.34977 .7185 m .35469 .73582 L .38004 .73622 L p .707 .577 .707 r
F P
0 g
s
.29951 .55996 m .30825 .61381 L .32025 .62181 L p .707 .577 .707 r
F P
0 g
s
.78463 .65063 m .78864 .68888 L .75785 .69196 L p .707 .577 .707 r
F P
0 g
s
.75785 .69196 m .75383 .65371 L .78463 .65063 L p .707 .577 .707 r
F P
0 g
s
.48944 .68306 m .49435 .70038 L .51202 .68649 L p .707 .577 .707 r
F P
0 g
s
.51202 .68649 m .50711 .66917 L .48944 .68306 L p .707 .577 .707 r
F P
0 g
s
.32092 .65459 m .33024 .68936 L .34974 .69384 L p .707 .577 .707 r
F P
0 g
s
.72998 .72223 m .73208 .74135 L .7022 .74459 L p .707 .577 .707 r
F P
0 g
s
.7022 .74459 m .7001 .72547 L .72998 .72223 L p .707 .577 .707 r
F P
0 g
s
.79227 .71538 m .79437 .7345 L .76384 .73788 L p .707 .577 .707 r
F P
0 g
s
.76384 .73788 m .76174 .71876 L .79227 .71538 L p .707 .577 .707 r
F P
0 g
s
.49733 .61011 m .50665 .64489 L .51469 .63181 L p .707 .577 .707 r
F P
0 g
s
.51469 .63181 m .50537 .59704 L .49733 .61011 L p .707 .577 .707 r
F P
0 g
s
.72612 .69532 m .7221 .65707 L .75383 .65371 L p .707 .577 .707 r
F P
0 g
s
.75383 .65371 m .75785 .69196 L .72612 .69532 L p .707 .577 .707 r
F P
0 g
s
.30825 .61381 m .29951 .55996 L .29713 .54981 L p .707 .578 .707 r
F P
0 g
s
.35469 .73582 m .34977 .7185 L .33111 .71382 L p .707 .577 .707 r
F P
0 g
s
.33024 .68936 m .32092 .65459 L .30982 .64634 L p .707 .577 .707 r
F P
0 g
s
.76174 .71876 m .76384 .73788 L .73208 .74135 L p .707 .577 .707 r
F P
0 g
s
.73208 .74135 m .72998 .72223 L .76174 .71876 L p .707 .577 .707 r
F P
0 g
s
.49844 .52617 m .50718 .58002 L .50481 .56987 L p .707 .578 .707 r
F P
0 g
s
.50481 .56987 m .49606 .51601 L .49844 .52617 L p .707 .578 .707 r
F P
0 g
s
.33111 .71382 m .33603 .73114 L .35469 .73582 L p .707 .577 .707 r
F P
0 g
s
.50711 .66917 m .51202 .68649 L .52099 .67315 L p .707 .577 .707 r
F P
0 g
s
.52099 .67315 m .51608 .65583 L .50711 .66917 L p .707 .577 .707 r
F P
0 g
s
.30982 .64634 m .31914 .68111 L .33024 .68936 L p .707 .577 .707 r
F P
0 g
s
.29713 .54981 m .30587 .60366 L .30825 .61381 L p .707 .578 .707 r
F P
0 g
s
.50537 .59704 m .51469 .63181 L .51309 .6206 L p .707 .577 .707 r
F P
0 g
s
.51309 .6206 m .50377 .58583 L .50537 .59704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.33603 .73114 m .33111 .71382 L .32099 .70533 L p .707 .577 .707 r
F P
0 g
s
.30587 .60366 m .29713 .54981 L .3046 .5385 L p .707 .577 .707 r
F P
0 g
s
.31914 .68111 m .30982 .64634 L .30821 .63513 L p .707 .577 .707 r
F P
0 g
s
.49606 .51601 m .50481 .56987 L .49281 .56186 L p .707 .577 .707 r
F P
0 g
s
.49281 .56186 m .48407 .50801 L .49606 .51601 L p .707 .577 .707 r
F P
0 g
s
.32099 .70533 m .3259 .72265 L .33603 .73114 L p .707 .577 .707 r
F P
0 g
s
.51608 .65583 m .52099 .67315 L .52038 .66168 L p .707 .577 .707 r
F P
0 g
s
.52038 .66168 m .51547 .64436 L .51608 .65583 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30821 .63513 m .31753 .6699 L .31914 .68111 L p .707 .577 .707 r
F P
0 g
s
.3046 .5385 m .31334 .59235 L .30587 .60366 L p .707 .577 .707 r
F P
0 g
s
.50377 .58583 m .51309 .6206 L .50199 .61235 L p .707 .577 .707 r
F P
0 g
s
.50199 .61235 m .49267 .57758 L .50377 .58583 L p .707 .577 .707 r
F P
0 g
s
.3259 .72265 m .32099 .70533 L .32038 .69386 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31334 .59235 m .3046 .5385 L .3212 .52714 L p .707 .577 .707 r
F P
0 g
s
.31753 .6699 m .30821 .63513 L .31626 .62205 L p .707 .577 .707 r
F P
0 g
s
.48407 .50801 m .49281 .56186 L .47236 .5568 L p .707 .577 .707 r
F P
0 g
s
.47236 .5568 m .46362 .50295 L .48407 .50801 L p .707 .577 .707 r
F P
0 g
s
.32038 .69386 m .3253 .71118 L .3259 .72265 L p .707 .577 .707 r
F P
0 g
s
.51547 .64436 m .52038 .66168 L .51026 .65319 L p .707 .577 .707 r
F P
0 g
s
.51026 .65319 m .50534 .63587 L .51547 .64436 L p .707 .577 .707 r
F P
0 g
s
.31626 .62205 m .32558 .65683 L .31753 .6699 L p .707 .577 .707 r
F P
0 g
s
.3212 .52714 m .32994 .58099 L .31334 .59235 L p .707 .577 .707 r
F P
0 g
s
.49267 .57758 m .50199 .61235 L .48249 .60787 L p .707 .577 .707 r
F P
0 g
s
.48249 .60787 m .47317 .5731 L .49267 .57758 L p .707 .577 .707 r
F P
0 g
s
.32994 .58099 m .3212 .52714 L .34529 .51684 L p .707 .577 .707 r
F P
0 g
s
.3253 .71118 m .32038 .69386 L .32935 .68053 L p .707 .577 .707 r
F P
0 g
s
.46362 .50295 m .47236 .5568 L .44547 .55516 L p .707 .577 .707 r
F P
0 g
s
.44547 .55516 m .43673 .50131 L .46362 .50295 L p .707 .577 .707 r
F P
0 g
s
.32558 .65683 m .31626 .62205 L .33317 .60839 L p .707 .577 .707 r
F P
0 g
s
.32935 .68053 m .33426 .69785 L .3253 .71118 L p .707 .577 .707 r
F P
0 g
s
.50534 .63587 m .51026 .65319 L .4916 .64852 L p .707 .577 .707 r
F P
0 g
s
.4916 .64852 m .48669 .6312 L .50534 .63587 L p .707 .577 .707 r
F P
0 g
s
.35403 .57069 m .34529 .51684 L .37452 .50861 L p .707 .577 .707 r
F P
0 g
s
.34529 .51684 m .35403 .57069 L .32994 .58099 L p .707 .577 .707 r
F P
0 g
s
.33317 .60839 m .34249 .64317 L .32558 .65683 L p .707 .577 .707 r
F P
0 g
s
.43673 .50131 m .44547 .55516 L .41477 .55711 L p .707 .577 .707 r
F P
0 g
s
.41477 .55711 m .40603 .50326 L .43673 .50131 L p .707 .577 .707 r
F P
0 g
s
.47317 .5731 m .48249 .60787 L .45649 .6076 L p .707 .577 .707 r
F P
0 g
s
.45649 .6076 m .44717 .57282 L .47317 .5731 L p .707 .577 .707 r
F P
0 g
s
.38326 .56246 m .37452 .50861 L .40603 .50326 L p .707 .577 .707 r
F P
0 g
s
.37452 .50861 m .38326 .56246 L .35403 .57069 L p .707 .577 .707 r
F P
0 g
s
.40603 .50326 m .41477 .55711 L .38326 .56246 L p .707 .577 .707 r
F P
0 g
s
.34249 .64317 m .33317 .60839 L .35728 .59548 L p .707 .577 .707 r
F P
0 g
s
.33426 .69785 m .32935 .68053 L .34702 .66663 L p .707 .577 .707 r
F P
0 g
s
.34702 .66663 m .35193 .68396 L .33426 .69785 L p .707 .577 .707 r
F P
0 g
s
.44717 .57282 m .45649 .6076 L .42653 .61156 L p .707 .577 .707 r
F P
0 g
s
.42653 .61156 m .41721 .57679 L .44717 .57282 L p .707 .577 .707 r
F P
0 g
s
.48669 .6312 m .4916 .64852 L .46625 .64812 L p .707 .577 .707 r
F P
0 g
s
.46625 .64812 m .46133 .6308 L .48669 .6312 L p .707 .577 .707 r
F P
0 g
s
.35728 .59548 m .3666 .63026 L .34249 .64317 L p .707 .577 .707 r
F P
0 g
s
.3666 .63026 m .35728 .59548 L .38624 .58459 L p .707 .577 .707 r
F P
0 g
s
.41721 .57679 m .42653 .61156 L .39556 .61937 L p .707 .577 .707 r
F P
0 g
s
.39556 .61937 m .38624 .58459 L .41721 .57679 L p .707 .577 .707 r
F P
0 g
s
.35193 .68396 m .34702 .66663 L .37166 .65355 L p .707 .577 .707 r
F P
0 g
s
.38624 .58459 m .39556 .61937 L .3666 .63026 L p .707 .577 .707 r
F P
0 g
s
.37166 .65355 m .37657 .67087 L .35193 .68396 L p .707 .577 .707 r
F P
0 g
s
.46133 .6308 m .46625 .64812 L .43667 .65203 L p .707 .577 .707 r
F P
0 g
s
.43667 .65203 m .43176 .63471 L .46133 .6308 L p .707 .577 .707 r
F P
0 g
s
.37657 .67087 m .37166 .65355 L .40086 .64255 L p .707 .577 .707 r
F P
0 g
s
.43176 .63471 m .43667 .65203 L .40577 .65987 L p .707 .577 .707 r
F P
0 g
s
.40577 .65987 m .40086 .64255 L .43176 .63471 L p .707 .577 .707 r
F P
0 g
s
.40086 .64255 m .40577 .65987 L .37657 .67087 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo7`00P7oo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000LGoo001/Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001^Ool006Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006aoo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JWoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Moo`00IGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP090004
FUH01000FUIJEUYF1P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00IGoo0P000UYF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00IGoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00I7oo0`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00HGoo0`001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYF001UOol005eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001KOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FWoo0P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Qo
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001GOol01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001EOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EGoo0P001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00E7oo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=J
EP04001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1UYF2@000eYF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP06FUH30006FUH00`00FUH000030002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP008Goo3`00=Goo001EOol00`00FUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP050002FUH00`00FUIJEP02FUH400000eYF001J
EP06FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0047oo4@0015YF00<005YFFUH01EYF00<005YFFUH01`00;Woo001EOol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF00002`001EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH000Qoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00=JEP@000AJEPP0
00AJEP03001JEUYF00=JEP/000EJEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol01000FUIJEP00
15YF00@005YFFUIJEPX000=JEP@000EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEP00
0080009JEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH01000
FUH000001EYF00<005YFFUH01EYF00<005YFFUH00eYF1@001UYF00<005YFFUH01EYF00@005YFFUIJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH20007FUH0
0`00FUIJEP06FUH50002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool005Eoo`05001JEUYFFUH00002FUH00`00FUH00007FUH00`00FUIJEP03
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000oOolA0005Ool01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YF
FUH00P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000iOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000eOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000cOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP<000QJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000/Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000002FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002aoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEPd000=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH60004FUH0
1000FUH000001EYF0P0000AJEP00FUH000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP<000QJ
EP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP040009FUH20002FUH4
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH0
0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3
0006FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ8000MJEP03001JEUYF00AJEPD00003FUH0000002aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH0100025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00EJEP03001JEP0000T00003FUH005YF00UJEP03001JEUYF00=JEP<000EJEP05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH015YF0`000UYF00<005YF000010000UYF00<005YFFUH01eYF3P000UYF00@005YFFUH000MJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP04000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005
FUH00`00FUH000040002FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF
001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0
035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP0000<000EJEP03001JEP0000@00003
FUH000000080009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000gOol002aoo`03001J
EP0000=JEP03001JEUYF00=JEPH000Qoo`T000AJEP03001JEUYF009JEP04001JEUYF0005FUH20002
FUH20005FUH00`00FUIJEP050007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000nOol002aoo`03001JEP00
00=JEP03001JEP0000<001Moo`H000=JEP04001JEUYF0004FUH20003FUH20005FUH01P00FUH00000
FUH000UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001oo`0M000DOol7000/Ool002]o
o`03001JEP0000AJEP80025oo`800005FUH005YFFUH00002FUH200000eYF001JEP02FUH20004FUH3
0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0003FUH20007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00:goo1`000UYF00<005YFFUH00P00;7oo000[Ool00`00
FUH00002FUH20002FUH00`00Oomoo`0POol20003FUH20003FUH00`00FUIJEP030002FUH20007FUH0
0`00FUIJEP05FUH700000eYF001JEP06FUH00`00FUIJEP060007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP006Woo4@000eYF00<005YFFUH00eYF00<005YFFUH00P00
;7oo000[Ool00`00FUH0000200000eYF001JEP02FUH20008Ool?000;Ool00`00FUIJEP020003FUH0
0`00FUIJEP060009FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH30004FUH20006FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05000=Ool90004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002]oo`03001JEP0000=JEP03
001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00@000Moo`03001JEP00009JEPT000=J
EP03001JEUYF00EJEP@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF009JEP<0
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH20003Ool8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002]oo`8000AJEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003Ool00`00FUH00004FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0
02]oo`8000AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUH00000Ool00P0000=JEP00FUH00eYF0P0025YF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01eYF00@005YF000000EJEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000500000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000[
Ool002]oo`8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP03FUH20008FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo0P000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF00000UYF0P000UYF00<005YFFUH00eYF0P001UYF00<005YFFUH01eYF00<005YFFUH0
15YF0P002EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00:goo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP04001JEUYFFUH30008FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000;FUH200001EYF001JEUYF00001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00P00:goo000[Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF0`000UYF00<005YFFUH00eYF10002EYF00<0
05YF00000P002eYF00<005YFFUH00UYF0P001eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP02FUH00`00FUIJEP02FUH50007FUH40002FUH00`00
FUIJEP07FUH20005FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1`00:goo000/Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH01000FUIJEUYF1P000UYF10001UYF00<005YFFUH01EYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHE000/
Ool002]oo`04001JEUYF0002FUH00`00FUIJEP03FUH600000eYF001JEP06FUH70006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP030006FUH01000FUIJEUYF20002UYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH8
000fOol002]oo`03001JEP0000=JEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00=J
EP@0009JEP03001JEUYF00AJEP8000=JEQ<000=JEP03001JEUYF00QJEP03001JEUYF00<000IJEP04
001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF2@000eYF2@00?Woo000[Ool00`00FUH0
0003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH50005FUH20003FUH0
1000FUH005YF10001EYF00<005YFFUH01UYF00<005YFFUH025YF0`0000=JEP00FUH01UYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH70004FUH80017Ool002]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP80009JEP07001JEUYF001JEP00
Ool00P001EYF00<005YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00H000=J
EPP004moo`00:goo00D005YF001JEP00009oo`800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP800003FUH000000080009JEP04001JEUYFFUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20006FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH04000EWoo000ZOol00`00FUIJEP020005
Ool20007FUH:0008FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEUYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02000UOol6000[Ool002Yoo`04001JEUYF0007Ool200000eYF000000040003FUH00`00FUIJEP02
FUH70002FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000=JEP<000EJEP03001JEUYF
00IJEPD00003FUH005YF00QJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00=JEP04001JEUYFFUH2000NOol70002
FUH01000FUIJEP00:goo000ZOol01000FUH000001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF001JEP80009JEP<000EJEP03001JEUYF00L0
00IJEP03001JEUYF00AJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF0P005Woo20000eYF00<005YFFUH0
0eYF00@005YFFUH002]oo`00:Woo0`0000=JEP00Ool00Woo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0`000eYF00<005YF00000`0000=JEP00FUH00UYF3@0015YF00<005YF
FUH01UYF00<005YFFUH00UYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH20003FUH01000FUIJEUYF0P001Woo400015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:Woo000ZOol3000015YF001oogoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH200000eYF001JEP02
FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol0
02Yoo`8000=JEP800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF008000Eoo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH0
05YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF008000IJEP`000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF008002Yoo`00:Woo0P000UYF00@005YFFUH000EJEPH000Uoo`H000IJEP03001J
EUYF00=JEP8000Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF00`000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00H002]oo`00:Woo0P0000=JEP00FUH00UYF00<005YF00000`005Goo10000UYF00<0
05YFFUH01EYF0P001Goo0P0000=JEP00FUH01UYF00<005YFFUH00UYF1P002EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
3P00<Goo000[Ool30003FUH4000KOol40007FUH20006Ool>0004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000nOol0
02]oo`80009JEP8000AJEP8001eoo`8000AJEP03001JEUYF0080009oo`H000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF009J
EPX004Moo`00:goo10001UYF00@005YF000001eoo`<00003FUH005YF00=JEP80009JEP@000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF009JEP04001JEUYFFUH:001?Ool0
02Yoo`05001JEP00FUH00006FUH01000FUIJEUYF0`007Goo0P001EYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH00eYF30001eYF00<005YFFUH00eYF30001EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02000Egoo000ZOol01@00FUH005YF00001UYF
00<005YFFUH015YF0`006Woo0`0015YF0P0000=JEP0000000P001EYF00<005YFFUH01EYF1`001eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00UYF1`001eYF00<005YFFUH00eYF00<005YF
FUH01`00Ggoo000ZOol200000goo00000006FUH00`00FUIJEP05FUH00`00FUH00003000AOol50003
FUH200000eYF001JEP02000015YF000000001EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF100015YF00<005YFFUH00eYF00@005YF
FUH000=JEP<005moo`00:Woo0P000Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF
4@000eYF00<005YFFUH015YF0P000UYF0P0000=oo`0000001EYF00<005YF00000P001EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<00003FUH0
05YF00AJEP04001JEUYF0002FUH01000FUIJEUYF0P00GGoo000ZOol00`00Oomoo`02Ool20003FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH01000Ool000001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP8005]o
o`00:Woo00<007ooOol017oo00@005YFFUH000QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000Ool000000eYF0P0000=JEP00FUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0P000eYF00@005YFFUH0009JEP03001JEUYF00AJEP<005Uoo`00:Woo0P001Woo0`001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUIJEP00FUH007oo
0P0000=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0002FUH00`00FUH00006FUH01@00
FUIJEUYF0000F7oo000ZOol00`00FUH00007Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001oo`030005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YF00001UYF00D005YFFUIJEP0005Qoo`00:Woo00<005YF
00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000Woo0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH0
0006FUH00`00FUIJEP02001HOol002Yoo`04001JEUYF000:Ool300000eYF001JEP06FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool01@00Ool005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00D005YFFUIJEP0005Uoo`00:Woo00D005YF
FUIJEP0000aoo`<000IJEP03001JEUYF00D0009JEP03001JEUYF00EJEP04001JEUYFFUH20007Ool0
1@00Ool005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000IJEP05001JEUYF
FUH0001IOol002]oo`03001JEUYF008000ioo`@0009JEP04001JEUYFFUH30002FUH00`00FUIJEP06
FUH01000FUH0000027oo0P0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF008005Uoo`00:goo00<005YF00000UYF0P0047oo1`0015YF00<005YFFUH00UYF1P00
2Woo0P000Woo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH0
0P00FGoo000/Ool20004FUH00`00Oomoo`0DOol9000?Ool00`00FUH00002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00Oomoo`1HOol002eo
o`03001JEUYF00=JEP8002aoo`03001JEP0000=oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30005FUH01000FUH000000eYF00<007ooOol0F7oo000^Ool00`00FUIJEP02FUH01000FUH0
0000:7oo10001Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP04001J
EUYFFUH4001JOol002moo`800003FUH005YF00=JEP<002=oo`800003FUH0000000Qoo`800003FUH0
05YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP@00003FUH005YF00EJEP03001JEUYF009JEP<005Yoo`00<Goo0P001eYF0`007Woo0P00
0eYF0P002Woo10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF00H005YFFUIJEP00FUH20006FUH00`00FUIJEP02FUH2001KOol0039oo`03
001JEUYF00IJEP03001JEP0000<001Ioo`@00003FUH005YF009JEP03001oogoo00eoo`@0009JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF008000IJ
EP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUH0001KOol003=oo`8000IJEP03001JEUYF
00=JEPL000Uoo`H000EJEP04001JEUYF000DOol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60006FUH00`00FUIJEP04FUH:001LOol003Eoo`8000=JEP03001JEUYF00IJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP04001JEP00000JOol60003FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP060006Ool40002FUH00`00FUIJEP05FUH3001ROol003Moo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80029ooal00003FUH0
0000008000]oo`@000IJEP03001JEUYF0080061oo`00>Goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00=Woo0P0015YF00<005YFFUH01UYF00<005YF00000P0037oo0P00
0eYF00<005YFFUH00eYF0P00GWoo000mOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000jOol200000eYF001JEP08FUH00`00FUIJEP02FUH3000;Ool200000eYF001JEP05FUH3
001LOol0045oo`L000AJEP03001JEUYF009JEPD0041oo`<000MJEP03001JEUYF00IJEPD000Qoo`80
00EJEP05001JEUYFFUH0001KOol004Qoo`T004Qoo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH8
0002Ool20003FUH01@00FUIJEUYF0000Fgoo002LOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF0P00Fgoo002OOol30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<007ooOol0FWoo002ROol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF1000G7oo002VOol70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000G7oo
002]Ool80003FUH00`00FUIJEP02FUH00`00FUH0001MOol00;Eoo`/005eoo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5894 .74536 m .59483 .68946 L .56386 .68492 L p .707 .577 .707 r
F P
0 g
s
.59483 .68946 m .5894 .74536 L .62112 .74768 L p .707 .577 .707 r
F P
0 g
s
.62112 .74768 m .62655 .69177 L .59483 .68946 L p .707 .577 .707 r
F P
0 g
s
.62655 .69177 m .62112 .74768 L .65049 .74754 L p .707 .577 .707 r
F P
0 g
s
.65049 .74754 m .65591 .69164 L .62655 .69177 L p .707 .577 .707 r
F P
0 g
s
.55843 .74082 m .56386 .68492 L .53667 .6786 L p .707 .577 .707 r
F P
0 g
s
.56386 .68492 m .55843 .74082 L .5894 .74536 L p .707 .577 .707 r
F P
0 g
s
.65591 .69164 m .65049 .74754 L .67462 .74498 L p .707 .577 .707 r
F P
0 g
s
.67462 .74498 m .68005 .68907 L .65591 .69164 L p .707 .577 .707 r
F P
0 g
s
.58215 .80331 m .58797 .76611 L .55733 .75991 L p .707 .577 .707 r
F P
0 g
s
.58797 .76611 m .58215 .80331 L .61368 .80758 L p .707 .577 .707 r
F P
0 g
s
.61368 .80758 m .6195 .77039 L .58797 .76611 L p .707 .577 .707 r
F P
0 g
s
.53667 .6786 m .53125 .73451 L .55843 .74082 L p .707 .577 .707 r
F P
0 g
s
.53125 .73451 m .53667 .6786 L .51592 .67113 L p .707 .577 .707 r
F P
0 g
s
.6195 .77039 m .61368 .80758 L .64299 .80951 L p .707 .577 .707 r
F P
0 g
s
.64299 .80951 m .64882 .77231 L .6195 .77039 L p .707 .577 .707 r
F P
0 g
s
.5515 .79711 m .55733 .75991 L .53056 .75239 L p .707 .577 .707 r
F P
0 g
s
.55733 .75991 m .5515 .79711 L .58215 .80331 L p .707 .577 .707 r
F P
0 g
s
.57589 .84513 m .57898 .82655 L .54853 .81998 L p .707 .577 .707 r
F P
0 g
s
.57898 .82655 m .57589 .84513 L .60741 .84982 L p .707 .577 .707 r
F P
0 g
s
.60741 .84982 m .61049 .83124 L .57898 .82655 L p .707 .577 .707 r
F P
0 g
s
.53056 .75239 m .52473 .78959 L .5515 .79711 L p .707 .577 .707 r
F P
0 g
s
.64882 .77231 m .64299 .80951 L .66723 .8089 L p .707 .577 .707 r
F P
0 g
s
.66723 .8089 m .67305 .7717 L .64882 .77231 L p .707 .577 .707 r
F P
0 g
s
.51592 .67113 m .5105 .72703 L .53125 .73451 L p .707 .577 .707 r
F P
0 g
s
.61049 .83124 m .60741 .84982 L .6369 .85219 L p .707 .577 .707 r
F P
0 g
s
.6369 .85219 m .63999 .83361 L .61049 .83124 L p .707 .577 .707 r
F P
0 g
s
.68005 .68907 m .67462 .74498 L .69116 .74022 L p .707 .577 .707 r
F P
0 g
s
.69116 .74022 m .69659 .68432 L .68005 .68907 L p .707 .577 .707 r
F P
0 g
s
.54853 .81998 m .54544 .83856 L .57589 .84513 L p .707 .577 .707 r
F P
0 g
s
.54544 .83856 m .54853 .81998 L .52213 .81219 L p .707 .577 .707 r
F P
0 g
s
.52473 .78959 m .53056 .75239 L .51028 .74427 L p .707 .577 .707 r
F P
0 g
s
.52213 .81219 m .51904 .83077 L .54544 .83856 L p .707 .577 .707 r
F P
0 g
s
.5105 .72703 m .51592 .67113 L .50365 .66322 L p .707 .577 .707 r
F P
0 g
s
.63999 .83361 m .6369 .85219 L .66149 .852 L p .707 .577 .707 r
F P
0 g
s
.66149 .852 m .66458 .83341 L .63999 .83361 L p .707 .577 .707 r
F P
0 g
s
.51028 .74427 m .50446 .78147 L .52473 .78959 L p .707 .577 .707 r
F P
0 g
s
.67305 .7717 m .66723 .8089 L .68402 .80581 L p .707 .577 .707 r
F P
0 g
s
.68402 .80581 m .68984 .76861 L .67305 .7717 L p .707 .577 .707 r
F P
0 g
s
.51904 .83077 m .52213 .81219 L .50235 .80394 L p .707 .577 .707 r
F P
0 g
s
.50365 .66322 m .49823 .71913 L .5105 .72703 L p .707 .577 .707 r
F P
0 g
s
.50235 .80394 m .49927 .82252 L .51904 .83077 L p .707 .577 .707 r
F P
0 g
s
.69659 .68432 m .69116 .74022 L .69849 .73375 L p .707 .577 .707 r
F P
0 g
s
.69849 .73375 m .70392 .67785 L .69659 .68432 L p .707 .577 .707 r
F P
0 g
s
.50446 .78147 m .51028 .74427 L .49849 .73637 L p .707 .577 .707 r
F P
0 g
s
.66458 .83341 m .66149 .852 L .67877 .84926 L p .707 .577 .707 r
F P
0 g
s
.67877 .84926 m .68185 .83068 L .66458 .83341 L p .707 .577 .707 r
F P
0 g
s
.49849 .73637 m .49267 .77357 L .50446 .78147 L p .707 .577 .707 r
F P
0 g
s
.49823 .71913 m .50365 .66322 L .50105 .65567 L p .707 .577 .707 r
F P
0 g
s
.49927 .82252 m .50235 .80394 L .49115 .79603 L p .707 .577 .707 r
F P
0 g
s
.68984 .76861 m .68402 .80581 L .69171 .80054 L p .707 .577 .707 r
F P
0 g
s
.69171 .80054 m .69754 .76334 L .68984 .76861 L p .707 .577 .707 r
F P
0 g
s
.49115 .79603 m .48806 .81461 L .49927 .82252 L p .707 .577 .707 r
F P
0 g
s
.50105 .65567 m .49563 .71157 L .49823 .71913 L p .707 .577 .707 r
F P
0 g
s
.49267 .77357 m .49849 .73637 L .49634 .72945 L p .707 .577 .707 r
F P
0 g
s
.70392 .67785 m .69849 .73375 L .6959 .72619 L p .707 .577 .707 r
F P
0 g
s
.6959 .72619 m .70132 .67029 L .70392 .67785 L p .707 .577 .707 r
F P
0 g
s
.68185 .83068 m .67877 .84926 L .68704 .84426 L p .707 .577 .707 r
F P
0 g
s
.68704 .84426 m .69013 .82568 L .68185 .83068 L p .707 .577 .707 r
F P
0 g
s
.49634 .72945 m .49052 .76665 L .49267 .77357 L p .707 .577 .707 r
F P
0 g
s
.49563 .71157 m .50105 .65567 L .50838 .64919 L p .707 .577 .707 r
F P
0 g
s
.50838 .64919 m .50296 .7051 L .49563 .71157 L p .707 .577 .707 r
F P
0 g
s
.50296 .7051 m .50838 .64919 L .52493 .64444 L p .707 .577 .707 r
F P
0 g
s
.52493 .64444 m .5195 .70035 L .50296 .7051 L p .707 .577 .707 r
F P
0 g
s
.49821 .76138 m .50403 .72418 L .52082 .7211 L p .707 .577 .707 r
F P
0 g
s
.52082 .7211 m .515 .75829 L .49821 .76138 L p .707 .577 .707 r
F P
0 g
s
.49479 .80282 m .49788 .78424 L .51515 .78151 L p .707 .577 .707 r
F P
0 g
s
.51515 .78151 m .51207 .80009 L .49479 .80282 L p .707 .577 .707 r
F P
0 g
s
.515 .75829 m .52082 .7211 L .54506 .72048 L p .707 .577 .707 r
F P
0 g
s
.54506 .72048 m .53924 .75768 L .515 .75829 L p .707 .577 .707 r
F P
0 g
s
.51207 .80009 m .51515 .78151 L .53974 .78131 L p .707 .577 .707 r
F P
0 g
s
.53974 .78131 m .53665 .79989 L .51207 .80009 L p .707 .577 .707 r
F P
0 g
s
.51537 .8217 m .51537 .31981 L .4703 .31921 L p .707 .577 .707 r
F P
0 g
s
.5195 .70035 m .52493 .64444 L .54906 .64187 L p .707 .577 .707 r
F P
0 g
s
.54906 .64187 m .54364 .69778 L .5195 .70035 L p .707 .577 .707 r
F P
0 g
s
.54364 .69778 m .54906 .64187 L .57842 .64174 L p .707 .577 .707 r
F P
0 g
s
.57842 .64174 m .573 .69765 L .54364 .69778 L p .707 .577 .707 r
F P
0 g
s
.53924 .75768 m .54506 .72048 L .57438 .72241 L p .707 .577 .707 r
F P
0 g
s
.57438 .72241 m .56856 .75961 L .53924 .75768 L p .707 .577 .707 r
F P
0 g
s
.53665 .79989 m .53974 .78131 L .56924 .78368 L p .707 .577 .707 r
F P
0 g
s
.56924 .78368 m .56615 .80226 L .53665 .79989 L p .707 .577 .707 r
F P
0 g
s
.51537 .31981 m .51537 .8217 L .55894 .81854 L p .707 .577 .707 r
F P
0 g
s
.55894 .81854 m .55894 .31666 L .51537 .31981 L p .707 .577 .707 r
F P
0 g
s
.4703 .82109 m .4703 .31921 L .42813 .31489 L p .707 .577 .707 r
F P
0 g
s
.48806 .81461 m .49115 .79603 L .48961 .78924 L p .707 .577 .707 r
F P
0 g
s
.48961 .78924 m .48652 .80782 L .48806 .81461 L p .707 .577 .707 r
F P
0 g
s
.49052 .76665 m .49634 .72945 L .50403 .72418 L p .707 .577 .707 r
F P
0 g
s
.50403 .72418 m .49821 .76138 L .49052 .76665 L p .707 .577 .707 r
F P
0 g
s
.48652 .80782 m .48961 .78924 L .49788 .78424 L p .707 .577 .707 r
F P
0 g
s
.49788 .78424 m .49479 .80282 L .48652 .80782 L p .707 .577 .707 r
F P
0 g
s
.4703 .31921 m .4703 .82109 L .51537 .8217 L p .707 .577 .707 r
F P
0 g
s
.69754 .76334 m .69171 .80054 L .68956 .79362 L p .707 .577 .707 r
F P
0 g
s
.68956 .79362 m .69538 .75642 L .69754 .76334 L p .707 .577 .707 r
F P
0 g
s
.573 .69765 m .57842 .64174 L .61014 .64406 L p .707 .577 .707 r
F P
0 g
s
.61014 .64406 m .60472 .69996 L .573 .69765 L p .707 .577 .707 r
F P
0 g
s
.56856 .75961 m .57438 .72241 L .6059 .72668 L p .707 .577 .707 r
F P
0 g
s
.6059 .72668 m .60008 .76388 L .56856 .75961 L p .707 .577 .707 r
F P
0 g
s
.56615 .80226 m .56924 .78368 L .60075 .78837 L p .707 .577 .707 r
F P
0 g
s
.60075 .78837 m .59767 .80695 L .56615 .80226 L p .707 .577 .707 r
F P
0 g
s
.55894 .31666 m .55894 .81854 L .59674 .81193 L p .707 .577 .707 r
F P
0 g
s
.59674 .81193 m .59674 .31004 L .55894 .31666 L p .707 .577 .707 r
F P
0 g
s
.42813 .81678 m .42813 .31489 L .393 .30729 L p .707 .577 .707 r
F P
0 g
s
.42813 .31489 m .42813 .81678 L .4703 .82109 L p .707 .577 .707 r
F P
0 g
s
.70132 .67029 m .6959 .72619 L .68362 .71829 L p .707 .577 .707 r
F P
0 g
s
.68362 .71829 m .68905 .66238 L .70132 .67029 L p .707 .577 .707 r
F P
0 g
s
.69013 .82568 m .68704 .84426 L .6855 .83747 L p .707 .577 .707 r
F P
0 g
s
.6855 .83747 m .68858 .81889 L .69013 .82568 L p .707 .577 .707 r
F P
0 g
s
.24986 .71984 m .25218 .66602 L .22109 .66223 L p .707 .577 .707 r
F P
0 g
s
.25218 .66602 m .24986 .71984 L .28169 .72009 L p .707 .577 .707 r
F P
0 g
s
.28169 .72009 m .28401 .66627 L .25218 .66602 L p .707 .577 .707 r
F P
0 g
s
.64111 .64859 m .63569 .7045 L .60472 .69996 L p .707 .577 .707 r
F P
0 g
s
.60472 .69996 m .61014 .64406 L .64111 .64859 L p .707 .577 .707 r
F P
0 g
s
.63655 .73288 m .63073 .77008 L .60008 .76388 L p .707 .577 .707 r
F P
0 g
s
.60008 .76388 m .6059 .72668 L .63655 .73288 L p .707 .577 .707 r
F P
0 g
s
.6312 .79494 m .62811 .81352 L .59767 .80695 L p .707 .577 .707 r
F P
0 g
s
.59767 .80695 m .60075 .78837 L .6312 .79494 L p .707 .577 .707 r
F P
0 g
s
.59674 .31004 m .59674 .81193 L .62507 .8025 L p .707 .577 .707 r
F P
0 g
s
.62507 .8025 m .62507 .30061 L .59674 .31004 L p .707 .577 .707 r
F P
0 g
s
.28401 .66627 m .28169 .72009 L .31114 .71676 L p .707 .577 .707 r
F P
0 g
s
.31114 .71676 m .31346 .66294 L .28401 .66627 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21876 .71605 m .22109 .66223 L .19378 .65526 L p .707 .577 .707 r
F P
0 g
s
.22109 .66223 m .21876 .71605 L .24986 .71984 L p .707 .577 .707 r
F P
0 g
s
.69538 .75642 m .68956 .79362 L .67777 .78572 L p .707 .577 .707 r
F P
0 g
s
.67777 .78572 m .68359 .74852 L .69538 .75642 L p .707 .577 .707 r
F P
0 g
s
.393 .80918 m .393 .30729 L .36835 .29714 L p .707 .577 .707 r
F P
0 g
s
.393 .30729 m .393 .80918 L .42813 .81678 L p .707 .577 .707 r
F P
0 g
s
.31346 .66294 m .31114 .71676 L .33533 .71019 L p .707 .577 .707 r
F P
0 g
s
.33533 .71019 m .33765 .65637 L .31346 .66294 L p .707 .577 .707 r
F P
0 g
s
.68905 .66238 m .68362 .71829 L .66288 .71082 L p .707 .577 .707 r
F P
0 g
s
.66288 .71082 m .6683 .65491 L .68905 .66238 L p .707 .577 .707 r
F P
0 g
s
.68858 .81889 m .6855 .83747 L .67429 .82956 L p .707 .577 .707 r
F P
0 g
s
.67429 .82956 m .67738 .81098 L .68858 .81889 L p .707 .577 .707 r
F P
0 g
s
.19145 .70908 m .19378 .65526 L .17292 .6458 L p .707 .577 .707 r
F P
0 g
s
.19378 .65526 m .19145 .70908 L .21876 .71605 L p .707 .577 .707 r
F P
0 g
s
.2462 .78387 m .24869 .74892 L .21772 .74392 L p .707 .577 .707 r
F P
0 g
s
.24869 .74892 m .2462 .78387 L .27802 .78479 L p .707 .577 .707 r
F P
0 g
s
.27802 .78479 m .28051 .74985 L .24869 .74892 L p .707 .577 .707 r
F P
0 g
s
.28051 .74985 m .27802 .78479 L .30757 .78155 L p .707 .577 .707 r
F P
0 g
s
.30757 .78155 m .31006 .74661 L .28051 .74985 L p .707 .577 .707 r
F P
0 g
s
.33765 .65637 m .33533 .71019 L .35189 .70102 L p .707 .577 .707 r
F P
0 g
s
.35189 .70102 m .35422 .64719 L .33765 .65637 L p .707 .577 .707 r
F P
0 g
s
.6683 .65491 m .66288 .71082 L .63569 .7045 L p .707 .577 .707 r
F P
0 g
s
.63569 .7045 m .64111 .64859 L .6683 .65491 L p .707 .577 .707 r
F P
0 g
s
.66332 .74041 m .6575 .77761 L .63073 .77008 L p .707 .577 .707 r
F P
0 g
s
.63073 .77008 m .63655 .73288 L .66332 .74041 L p .707 .577 .707 r
F P
0 g
s
.62811 .81352 m .6312 .79494 L .6576 .80273 L p .707 .577 .707 r
F P
0 g
s
.62507 .30061 m .62507 .8025 L .64115 .79119 L p .707 .577 .707 r
F P
0 g
s
.64115 .79119 m .64115 .2893 L .62507 .30061 L p .707 .577 .707 r
F P
0 g
s
.21523 .77887 m .21772 .74392 L .19063 .73534 L p .707 .577 .707 r
F P
0 g
s
.21772 .74392 m .21523 .77887 L .2462 .78387 L p .707 .577 .707 r
F P
0 g
s
.68359 .74852 m .67777 .78572 L .6575 .77761 L p .707 .577 .707 r
F P
0 g
s
.6575 .77761 m .66332 .74041 L .68359 .74852 L p .707 .577 .707 r
F P
0 g
s
.17292 .6458 m .17059 .69962 L .19145 .70908 L p .707 .577 .707 r
F P
0 g
s
.17059 .69962 m .17292 .6458 L .16056 .63477 L p .707 .577 .707 r
F P
0 g
s
.31006 .74661 m .30757 .78155 L .33195 .77447 L p .707 .577 .707 r
F P
0 g
s
.33195 .77447 m .33445 .73952 L .31006 .74661 L p .707 .577 .707 r
F P
0 g
s
.36834 .79903 m .36835 .29714 L .35658 .28545 L p .707 .577 .707 r
F P
0 g
s
.36835 .29714 m .36834 .79903 L .393 .80918 L p .707 .577 .707 r
F P
0 g
s
.67738 .81098 m .67429 .82956 L .65452 .82131 L p .707 .577 .707 r
F P
0 g
s
.65452 .82131 m .6576 .80273 L .67738 .81098 L p .707 .577 .707 r
F P
0 g
s
.18814 .77028 m .19063 .73534 L .17007 .72401 L p .707 .577 .707 r
F P
0 g
s
.19063 .73534 m .18814 .77028 L .21523 .77887 L p .707 .577 .707 r
F P
0 g
s
.24247 .82559 m .24378 .80822 L .21296 .80281 L p .707 .577 .707 r
F P
0 g
s
.24378 .80822 m .24247 .82559 L .27432 .82683 L p .707 .577 .707 r
F P
0 g
s
.27432 .82683 m .27563 .80946 L .24378 .80822 L p .707 .577 .707 r
F P
0 g
s
.27563 .80946 m .27432 .82683 L .30407 .82378 L p .707 .577 .707 r
F P
0 g
s
.30407 .82378 m .30539 .80642 L .27563 .80946 L p .707 .577 .707 r
F P
0 g
s
.21165 .82018 m .21296 .80281 L .18619 .79377 L p .707 .577 .707 r
F P
0 g
s
.21296 .80281 m .21165 .82018 L .24247 .82559 L p .707 .577 .707 r
F P
0 g
s
.35422 .64719 m .35189 .70102 L .3592 .69014 L p .707 .577 .707 r
F P
0 g
s
.3592 .69014 m .36153 .63632 L .35422 .64719 L p .707 .577 .707 r
F P
0 g
s
.33445 .73952 m .33195 .77447 L .34879 .76423 L p .707 .577 .707 r
F P
0 g
s
.34879 .76423 m .35128 .72929 L .33445 .73952 L p .707 .577 .707 r
F P
0 g
s
.16056 .63477 m .15823 .68859 L .17059 .69962 L p .707 .577 .707 r
F P
0 g
s
.17007 .72401 m .16757 .75896 L .18814 .77028 L p .707 .577 .707 r
F P
0 g
s
.30539 .80642 m .30407 .82378 L .32883 .81675 L p .707 .577 .707 r
F P
0 g
s
.32883 .81675 m .33014 .79938 L .30539 .80642 L p .707 .577 .707 r
F P
0 g
s
.18619 .79377 m .18488 .81114 L .21165 .82018 L p .707 .577 .707 r
F P
0 g
s
.15823 .68859 m .16056 .63477 L .1579 .62325 L p .707 .577 .707 r
F P
0 g
s
.16757 .75896 m .17007 .72401 L .15805 .71105 L p .707 .577 .707 r
F P
0 g
s
.6576 .80273 m .65452 .82131 L .62811 .81352 L p .707 .577 .707 r
F P
0 g
s
.18488 .81114 m .18619 .79377 L .16609 .78197 L p .707 .577 .707 r
F P
0 g
s
.64115 .2893 m .64115 .79119 L .64342 .77909 L p .707 .577 .707 r
F P
0 g
s
.64342 .77909 m .64342 .2772 L .64115 .2893 L p .707 .577 .707 r
F P
0 g
s
.16609 .78197 m .16478 .79934 L .18488 .81114 L p .707 .577 .707 r
F P
0 g
s
.33014 .79938 m .32883 .81675 L .34617 .80641 L p .707 .577 .707 r
F P
0 g
s
.34617 .80641 m .34748 .78904 L .33014 .79938 L p .707 .577 .707 r
F P
0 g
s
.15805 .71105 m .15555 .74599 L .16757 .75896 L p .707 .577 .707 r
F P
0 g
s
.35128 .72929 m .34879 .76423 L .35644 .75184 L p .707 .577 .707 r
F P
0 g
s
.35644 .75184 m .35893 .71689 L .35128 .72929 L p .707 .577 .707 r
F P
0 g
s
.36153 .63632 m .3592 .69014 L .35655 .67862 L p .707 .577 .707 r
F P
0 g
s
.35655 .67862 m .35887 .6248 L .36153 .63632 L p .707 .577 .707 r
F P
0 g
s
.35893 .71689 m .35644 .75184 L .35413 .73851 L p .707 .577 .707 r
F P
0 g
s
.35413 .73851 m .35663 .70356 L .35893 .71689 L p .707 .577 .707 r
F P
0 g
s
.35887 .6248 m .35655 .67862 L .34419 .66759 L p .707 .577 .707 r
F P
0 g
s
.34419 .66759 m .34651 .61377 L .35887 .6248 L p .707 .577 .707 r
F P
0 g
s
.35663 .70356 m .35413 .73851 L .34211 .72555 L p .707 .577 .707 r
F P
0 g
s
.34211 .72555 m .3446 .6906 L .35663 .70356 L p .707 .577 .707 r
F P
0 g
s
.35658 .28545 m .35657 .78734 L .36834 .79903 L p .707 .577 .707 r
F P
0 g
s
.35657 .78734 m .35658 .28545 L .35884 .27336 L p .707 .577 .707 r
F P
0 g
s
.1579 .62325 m .15558 .67707 L .15823 .68859 L p .707 .577 .707 r
F P
0 g
s
.16478 .79934 m .16609 .78197 L .15462 .76858 L p .707 .577 .707 r
F P
0 g
s
.15555 .74599 m .15805 .71105 L .15574 .69772 L p .707 .577 .707 r
F P
0 g
s
.15558 .67707 m .1579 .62325 L .16521 .61237 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15462 .76858 m .15331 .78595 L .16478 .79934 L p .707 .577 .707 r
F P
0 g
s
.34748 .78904 m .34617 .80641 L .35438 .79379 L p .707 .577 .707 r
F P
0 g
s
.35438 .79379 m .35569 .77642 L .34748 .78904 L p .707 .577 .707 r
F P
0 g
s
.15574 .69772 m .15325 .73266 L .15555 .74599 L p .707 .577 .707 r
F P
0 g
s
.64342 .2772 m .64342 .77909 L .63165 .7674 L p .707 .577 .707 r
F P
0 g
s
.63165 .7674 m .63165 .26551 L .64342 .2772 L p .707 .577 .707 r
F P
0 g
s
.16521 .61237 m .16289 .66619 L .15558 .67707 L p .707 .577 .707 r
F P
0 g
s
.15331 .78595 m .15462 .76858 L .15291 .75491 L p .707 .577 .707 r
F P
0 g
s
.15325 .73266 m .15574 .69772 L .16339 .68533 L p .707 .577 .707 r
F P
0 g
s
.16289 .66619 m .16521 .61237 L .18177 .6032 L p .707 .577 .707 r
F P
0 g
s
.15291 .75491 m .1516 .77227 L .15331 .78595 L p .707 .577 .707 r
F P
0 g
s
.35884 .77525 m .35884 .27336 L .37493 .26205 L p .707 .577 .707 r
F P
0 g
s
.35884 .27336 m .35884 .77525 L .35657 .78734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35569 .77642 m .35438 .79379 L .35267 .78011 L p .707 .577 .707 r
F P
0 g
s
.35267 .78011 m .35398 .76274 L .35569 .77642 L p .707 .577 .707 r
F P
0 g
s
.16339 .68533 m .16089 .72027 L .15325 .73266 L p .707 .577 .707 r
F P
0 g
s
.34651 .61377 m .34419 .66759 L .32333 .65813 L p .707 .577 .707 r
F P
0 g
s
.32333 .65813 m .32565 .60431 L .34651 .61377 L p .707 .577 .707 r
F P
0 g
s
.18177 .6032 m .17945 .65702 L .16289 .66619 L p .707 .577 .707 r
F P
0 g
s
.1516 .77227 m .15291 .75491 L .16112 .74228 L p .707 .577 .707 r
F P
0 g
s
.17945 .65702 m .18177 .6032 L .20596 .59663 L p .707 .577 .707 r
F P
0 g
s
.16089 .72027 m .16339 .68533 L .18022 .67509 L p .707 .577 .707 r
F P
0 g
s
.16112 .74228 m .15981 .75965 L .1516 .77227 L p .707 .577 .707 r
F P
0 g
s
.63165 .26551 m .63165 .7674 L .607 .75726 L p .707 .577 .707 r
F P
0 g
s
.607 .75726 m .607 .25537 L .63165 .26551 L p .707 .577 .707 r
F P
0 g
s
.35398 .76274 m .35267 .78011 L .3412 .76672 L p .707 .577 .707 r
F P
0 g
s
.3412 .76672 m .34251 .74935 L .35398 .76274 L p .707 .577 .707 r
F P
0 g
s
.32565 .60431 m .32333 .65813 L .29602 .65116 L p .707 .577 .707 r
F P
0 g
s
.29602 .65116 m .29834 .59734 L .32565 .60431 L p .707 .577 .707 r
F P
0 g
s
.18022 .67509 m .17773 .71003 L .16089 .72027 L p .707 .577 .707 r
F P
0 g
s
.3446 .6906 m .34211 .72555 L .32155 .71422 L p .707 .577 .707 r
F P
0 g
s
.32155 .71422 m .32404 .67927 L .3446 .6906 L p .707 .577 .707 r
F P
0 g
s
.37493 .76393 m .37493 .26205 L .40326 .25262 L p .707 .577 .707 r
F P
0 g
s
.37493 .26205 m .37493 .76393 L .35884 .77525 L p .707 .577 .707 r
F P
0 g
s
.20364 .65045 m .20596 .59663 L .23542 .5933 L p .707 .577 .707 r
F P
0 g
s
.20596 .59663 m .20364 .65045 L .17945 .65702 L p .707 .577 .707 r
F P
0 g
s
.15981 .75965 m .16112 .74228 L .17845 .73195 L p .707 .577 .707 r
F P
0 g
s
.17773 .71003 m .18022 .67509 L .20461 .668 L p .707 .577 .707 r
F P
0 g
s
.29834 .59734 m .29602 .65116 L .26492 .64737 L p .707 .577 .707 r
F P
0 g
s
.26492 .64737 m .26725 .59355 L .29834 .59734 L p .707 .577 .707 r
F P
0 g
s
.23309 .64712 m .23542 .5933 L .26725 .59355 L p .707 .577 .707 r
F P
0 g
s
.23542 .5933 m .23309 .64712 L .20364 .65045 L p .707 .577 .707 r
F P
0 g
s
.17845 .73195 m .17714 .74931 L .15981 .75965 L p .707 .577 .707 r
F P
0 g
s
.26725 .59355 m .26492 .64737 L .23309 .64712 L p .707 .577 .707 r
F P
0 g
s
.73507 .64974 m .73275 .59299 L .70166 .59294 L p .707 .577 .707 r
F P
0 g
s
.73275 .59299 m .73507 .64974 L .7669 .64801 L p .707 .577 .707 r
F P
0 g
s
.7669 .64801 m .76458 .59126 L .73275 .59299 L p .707 .577 .707 r
F P
0 g
s
.32404 .67927 m .32155 .71422 L .29445 .70563 L p .707 .577 .707 r
F P
0 g
s
.29445 .70563 m .29695 .67069 L .32404 .67927 L p .707 .577 .707 r
F P
0 g
s
.76458 .59126 m .7669 .64801 L .79636 .64467 L p .707 .577 .707 r
F P
0 g
s
.79636 .64467 m .79403 .58791 L .76458 .59126 L p .707 .577 .707 r
F P
0 g
s
.34251 .74935 m .3412 .76672 L .32109 .75492 L p .707 .577 .707 r
F P
0 g
s
.32109 .75492 m .32241 .73756 L .34251 .74935 L p .707 .577 .707 r
F P
0 g
s
.20461 .668 m .20212 .70295 L .17773 .71003 L p .707 .577 .707 r
F P
0 g
s
.607 .25537 m .607 .75726 L .57187 .74966 L p .707 .577 .707 r
F P
0 g
s
.57187 .74966 m .57186 .24777 L .607 .25537 L p .707 .577 .707 r
F P
0 g
s
.70398 .64969 m .70166 .59294 L .67435 .5911 L p .707 .577 .707 r
F P
0 g
s
.70166 .59294 m .70398 .64969 L .73507 .64974 L p .707 .577 .707 r
F P
0 g
s
.20212 .70295 m .20461 .668 L .23416 .66476 L p .707 .577 .707 r
F P
0 g
s
.17714 .74931 m .17845 .73195 L .20321 .72491 L p .707 .577 .707 r
F P
0 g
s
.79403 .58791 m .79636 .64467 L .82055 .64004 L p .707 .577 .707 r
F P
0 g
s
.82055 .64004 m .81822 .58328 L .79403 .58791 L p .707 .577 .707 r
F P
0 g
s
.40326 .25262 m .40326 .75451 L .37493 .76393 L p .707 .577 .707 r
F P
0 g
s
.40326 .75451 m .40326 .25262 L .44106 .246 L p .707 .577 .707 r
F P
0 g
s
.73651 .70579 m .73402 .66767 L .70305 .66877 L p .707 .577 .707 r
F P
0 g
s
.73402 .66767 m .73651 .70579 L .76833 .70347 L p .707 .577 .707 r
F P
0 g
s
.76833 .70347 m .76584 .66535 L .73402 .66767 L p .707 .577 .707 r
F P
0 g
s
.29695 .67069 m .29445 .70563 L .26348 .70063 L p .707 .577 .707 r
F P
0 g
s
.26348 .70063 m .26598 .66569 L .29695 .67069 L p .707 .577 .707 r
F P
0 g
s
.67435 .5911 m .67667 .64786 L .70398 .64969 L p .707 .577 .707 r
F P
0 g
s
.76584 .66535 m .76833 .70347 L .79788 .70016 L p .707 .577 .707 r
F P
0 g
s
.79788 .70016 m .79539 .66204 L .76584 .66535 L p .707 .577 .707 r
F P
0 g
s
.23167 .69971 m .23416 .66476 L .26598 .66569 L p .707 .577 .707 r
F P
0 g
s
.23416 .66476 m .23167 .69971 L .20212 .70295 L p .707 .577 .707 r
F P
0 g
s
.70305 .66877 m .70554 .7069 L .73651 .70579 L p .707 .577 .707 r
F P
0 g
s
.20321 .72491 m .2019 .74228 L .17714 .74931 L p .707 .577 .707 r
F P
0 g
s
.26598 .66569 m .26348 .70063 L .23167 .69971 L p .707 .577 .707 r
F P
0 g
s
.70554 .7069 m .70305 .66877 L .67596 .66855 L p .707 .577 .707 r
F P
0 g
s
.67667 .64786 m .67435 .5911 L .65349 .58768 L p .707 .577 .707 r
F P
0 g
s
.32241 .73756 m .32109 .75492 L .29432 .74588 L p .707 .577 .707 r
F P
0 g
s
.29432 .74588 m .29564 .72851 L .32241 .73756 L p .707 .577 .707 r
F P
0 g
s
.73649 .74777 m .73518 .72869 L .70436 .72993 L p .707 .577 .707 r
F P
0 g
s
.73518 .72869 m .73649 .74777 L .76834 .74543 L p .707 .577 .707 r
F P
0 g
s
.76834 .74543 m .76703 .72634 L .73518 .72869 L p .707 .577 .707 r
F P
0 g
s
.76703 .72634 m .76834 .74543 L .7981 .74221 L p .707 .577 .707 r
F P
0 g
s
.7981 .74221 m .79678 .72313 L .76703 .72634 L p .707 .577 .707 r
F P
0 g
s
.70436 .72993 m .70567 .74901 L .73649 .74777 L p .707 .577 .707 r
F P
0 g
s
.67596 .66855 m .67845 .70668 L .70554 .7069 L p .707 .577 .707 r
F P
0 g
s
.79539 .66204 m .79788 .70016 L .82227 .69619 L p .707 .577 .707 r
F P
0 g
s
.82227 .69619 m .81977 .65807 L .79539 .66204 L p .707 .577 .707 r
F P
0 g
s
.2019 .74228 m .20321 .72491 L .23297 .72186 L p .707 .577 .707 r
F P
0 g
s
.57186 .24777 m .57187 .74966 L .5297 .74534 L p .707 .577 .707 r
F P
0 g
s
.5297 .74534 m .5297 .24345 L .57186 .24777 L p .707 .577 .707 r
F P
0 g
s
.65349 .58768 m .65581 .64443 L .67667 .64786 L p .707 .577 .707 r
F P
0 g
s
.70567 .74901 m .70436 .72993 L .67759 .72994 L p .707 .577 .707 r
F P
0 g
s
.81822 .58328 m .82055 .64004 L .83711 .63457 L p .707 .577 .707 r
F P
0 g
s
.83711 .63457 m .83479 .57782 L .81822 .58328 L p .707 .577 .707 r
F P
0 g
s
.67759 .72994 m .6789 .74903 L .70567 .74901 L p .707 .577 .707 r
F P
0 g
s
.79678 .72313 m .7981 .74221 L .82286 .73843 L p .707 .577 .707 r
F P
0 g
s
.82286 .73843 m .82154 .71935 L .79678 .72313 L p .707 .577 .707 r
F P
0 g
s
.44106 .74789 m .44106 .246 L .48463 .24284 L p .707 .577 .707 r
F P
0 g
s
.44106 .246 m .44106 .74789 L .40326 .75451 L p .707 .577 .707 r
F P
0 g
s
.29564 .72851 m .29432 .74588 L .26351 .74047 L p .707 .577 .707 r
F P
0 g
s
.26351 .74047 m .26482 .72311 L .29564 .72851 L p .707 .577 .707 r
F P
0 g
s
.23297 .72186 m .23166 .73923 L .2019 .74228 L p .707 .577 .707 r
F P
0 g
s
.67845 .70668 m .67596 .66855 L .65539 .66703 L p .707 .577 .707 r
F P
0 g
s
.23166 .73923 m .23297 .72186 L .26482 .72311 L p .707 .577 .707 r
F P
0 g
s
.65539 .66703 m .65789 .70516 L .67845 .70668 L p .707 .577 .707 r
F P
0 g
s
.26482 .72311 m .26351 .74047 L .23166 .73923 L p .707 .577 .707 r
F P
0 g
s
.65581 .64443 m .65349 .58768 L .64113 .58298 L p .707 .577 .707 r
F P
0 g
s
.5297 .24345 m .5297 .74534 L .48463 .74473 L p .707 .577 .707 r
F P
0 g
s
.48463 .74473 m .48463 .24284 L .5297 .24345 L p .707 .577 .707 r
F P
0 g
s
.81977 .65807 m .82227 .69619 L .8391 .69194 L p .707 .577 .707 r
F P
0 g
s
.8391 .69194 m .83661 .65382 L .81977 .65807 L p .707 .577 .707 r
F P
0 g
s
.48463 .24284 m .48463 .74473 L .44106 .74789 L p .707 .577 .707 r
F P
0 g
s
.6789 .74903 m .67759 .72994 L .65749 .72873 L p .707 .577 .707 r
F P
0 g
s
.65749 .72873 m .6588 .74781 L .6789 .74903 L p .707 .577 .707 r
F P
0 g
s
.64113 .58298 m .64345 .63974 L .65581 .64443 L p .707 .577 .707 r
F P
0 g
s
.82154 .71935 m .82286 .73843 L .84019 .73446 L p .707 .577 .707 r
F P
0 g
s
.84019 .73446 m .83888 .71538 L .82154 .71935 L p .707 .577 .707 r
F P
0 g
s
.83479 .57782 m .83711 .63457 L .84442 .62881 L p .707 .577 .707 r
F P
0 g
s
.84442 .62881 m .8421 .57206 L .83479 .57782 L p .707 .577 .707 r
F P
0 g
s
.65789 .70516 m .65539 .66703 L .64337 .66436 L p .707 .577 .707 r
F P
0 g
s
.64337 .66436 m .64586 .70249 L .65789 .70516 L p .707 .577 .707 r
F P
0 g
s
.6588 .74781 m .65749 .72873 L .64602 .72641 L p .707 .577 .707 r
F P
0 g
s
.83661 .65382 m .8391 .69194 L .84675 .68784 L p .707 .577 .707 r
F P
0 g
s
.84675 .68784 m .84426 .64971 L .83661 .65382 L p .707 .577 .707 r
F P
0 g
s
.64345 .63974 m .64113 .58298 L .63847 .57749 L p .707 .577 .707 r
F P
0 g
s
.64602 .72641 m .64733 .74549 L .6588 .74781 L p .707 .577 .707 r
F P
0 g
s
.83888 .71538 m .84019 .73446 L .8484 .73069 L p .707 .577 .707 r
F P
0 g
s
.8484 .73069 m .84709 .71161 L .83888 .71538 L p .707 .577 .707 r
F P
0 g
s
.63847 .57749 m .6408 .63424 L .64345 .63974 L p .707 .577 .707 r
F P
0 g
s
.8421 .57206 m .84442 .62881 L .84177 .62332 L p .707 .577 .707 r
F P
0 g
s
.84177 .62332 m .83944 .56656 L .8421 .57206 L p .707 .577 .707 r
F P
0 g
s
.64586 .70249 m .64337 .66436 L .64107 .6608 L p .707 .577 .707 r
F P
0 g
s
.64107 .6608 m .64356 .69892 L .64586 .70249 L p .707 .577 .707 r
F P
0 g
s
.64733 .74549 m .64602 .72641 L .64431 .7232 L p .707 .577 .707 r
F P
0 g
s
.84426 .64971 m .84675 .68784 L .84445 .68427 L p .707 .577 .707 r
F P
0 g
s
.84445 .68427 m .84195 .64615 L .84426 .64971 L p .707 .577 .707 r
F P
0 g
s
.64431 .7232 m .64562 .74229 L .64733 .74549 L p .707 .577 .707 r
F P
0 g
s
.6408 .63424 m .63847 .57749 L .64578 .57173 L p .707 .577 .707 r
F P
0 g
s
.84709 .71161 m .8484 .73069 L .84669 .72749 L p .707 .577 .707 r
F P
0 g
s
.84669 .72749 m .84538 .7084 L .84709 .71161 L p .707 .577 .707 r
F P
0 g
s
.64578 .57173 m .64811 .62848 L .6408 .63424 L p .707 .577 .707 r
F P
0 g
s
.83944 .56656 m .84177 .62332 L .8294 .61862 L p .707 .577 .707 r
F P
0 g
s
.8294 .61862 m .82708 .56187 L .83944 .56656 L p .707 .577 .707 r
F P
0 g
s
.64356 .69892 m .64107 .6608 L .64871 .65669 L p .707 .577 .707 r
F P
0 g
s
.64871 .65669 m .65121 .69482 L .64356 .69892 L p .707 .577 .707 r
F P
0 g
s
.39528 .62439 m .38985 .56971 L .35888 .57024 L p .707 .577 .707 r
F P
0 g
s
.38985 .56971 m .39528 .62439 L .427 .62074 L p .707 .577 .707 r
F P
0 g
s
.427 .62074 m .42157 .56606 L .38985 .56971 L p .707 .577 .707 r
F P
0 g
s
.42157 .56606 m .427 .62074 L .45636 .61432 L p .707 .577 .707 r
F P
0 g
s
.45636 .61432 m .45094 .55964 L .42157 .56606 L p .707 .577 .707 r
F P
0 g
s
.64562 .74229 m .64431 .7232 L .65252 .71943 L p .707 .577 .707 r
F P
0 g
s
.64811 .62848 m .64578 .57173 L .66234 .56626 L p .707 .577 .707 r
F P
0 g
s
.84195 .64615 m .84445 .68427 L .83242 .6816 L p .707 .577 .707 r
F P
0 g
s
.83242 .6816 m .82993 .64348 L .84195 .64615 L p .707 .577 .707 r
F P
0 g
s
.65252 .71943 m .65383 .73852 L .64562 .74229 L p .707 .577 .707 r
F P
0 g
s
.36431 .62492 m .35888 .57024 L .3317 .56759 L p .707 .577 .707 r
F P
0 g
s
.35888 .57024 m .36431 .62492 L .39528 .62439 L p .707 .577 .707 r
F P
0 g
s
.84538 .7084 m .84669 .72749 L .83522 .72517 L p .707 .577 .707 r
F P
0 g
s
.83522 .72517 m .83391 .70608 L .84538 .7084 L p .707 .577 .707 r
F P
0 g
s
.45094 .55964 m .45636 .61432 L .4805 .60577 L p .707 .577 .707 r
F P
0 g
s
.4805 .60577 m .47507 .55109 L .45094 .55964 L p .707 .577 .707 r
F P
0 g
s
.66234 .56626 m .66467 .62302 L .64811 .62848 L p .707 .577 .707 r
F P
0 g
s
.82708 .56187 m .8294 .61862 L .80855 .6152 L p .707 .577 .707 r
F P
0 g
s
.80855 .6152 m .80622 .55844 L .82708 .56187 L p .707 .577 .707 r
F P
0 g
s
.65121 .69482 m .64871 .65669 L .66555 .65245 L p .707 .577 .707 r
F P
0 g
s
.33712 .62227 m .3317 .56759 L .31095 .56203 L p .707 .577 .707 r
F P
0 g
s
.3317 .56759 m .33712 .62227 L .36431 .62492 L p .707 .577 .707 r
F P
0 g
s
.66555 .65245 m .66804 .69057 L .65121 .69482 L p .707 .577 .707 r
F P
0 g
s
.39992 .6868 m .39409 .65089 L .36345 .65276 L p .707 .577 .707 r
F P
0 g
s
.39409 .65089 m .39992 .6868 L .43144 .68152 L p .707 .577 .707 r
F P
0 g
s
.43144 .68152 m .42562 .64561 L .39409 .65089 L p .707 .577 .707 r
F P
0 g
s
.42562 .64561 m .43144 .68152 L .46076 .67336 L p .707 .577 .707 r
F P
0 g
s
.46076 .67336 m .45494 .63745 L .42562 .64561 L p .707 .577 .707 r
F P
0 g
s
.66467 .62302 m .66234 .56626 L .68654 .56163 L p .707 .577 .707 r
F P
0 g
s
.47507 .55109 m .4805 .60577 L .49704 .59591 L p .707 .577 .707 r
F P
0 g
s
.49704 .59591 m .49161 .54123 L .47507 .55109 L p .707 .577 .707 r
F P
0 g
s
.82993 .64348 m .83242 .6816 L .81186 .68008 L p .707 .577 .707 r
F P
0 g
s
.81186 .68008 m .80937 .64196 L .82993 .64348 L p .707 .577 .707 r
F P
0 g
s
.65383 .73852 m .65252 .71943 L .66985 .71546 L p .707 .577 .707 r
F P
0 g
s
.36927 .68867 m .36345 .65276 L .33668 .65105 L p .707 .577 .707 r
F P
0 g
s
.36345 .65276 m .36927 .68867 L .39992 .6868 L p .707 .577 .707 r
F P
0 g
s
.66985 .71546 m .67117 .73455 L .65383 .73852 L p .707 .577 .707 r
F P
0 g
s
.45494 .63745 m .46076 .67336 L .485 .66312 L p .707 .577 .707 r
F P
0 g
s
.485 .66312 m .47917 .62721 L .45494 .63745 L p .707 .577 .707 r
F P
0 g
s
.68654 .56163 m .68886 .61839 L .66467 .62302 L p .707 .577 .707 r
F P
0 g
s
.80622 .55844 m .80855 .6152 L .78124 .61336 L p .707 .577 .707 r
F P
0 g
s
.78124 .61336 m .77891 .55661 L .80622 .55844 L p .707 .577 .707 r
F P
0 g
s
.83391 .70608 m .83522 .72517 L .81512 .72395 L p .707 .577 .707 r
F P
0 g
s
.81512 .72395 m .8138 .70487 L .83391 .70608 L p .707 .577 .707 r
F P
0 g
s
.31095 .56203 m .31637 .6167 L .33712 .62227 L p .707 .577 .707 r
F P
0 g
s
.43385 .7234 m .43076 .70548 L .39925 .71083 L p .707 .577 .707 r
F P
0 g
s
.43076 .70548 m .43385 .7234 L .46334 .71512 L p .707 .577 .707 r
F P
0 g
s
.46334 .71512 m .46026 .6972 L .43076 .70548 L p .707 .577 .707 r
F P
0 g
s
.40233 .72875 m .39925 .71083 L .3688 .71274 L p .707 .577 .707 r
F P
0 g
s
.39925 .71083 m .40233 .72875 L .43385 .7234 L p .707 .577 .707 r
F P
0 g
s
.33668 .65105 m .3425 .68696 L .36927 .68867 L p .707 .577 .707 r
F P
0 g
s
.66804 .69057 m .66555 .65245 L .68994 .64847 L p .707 .577 .707 r
F P
0 g
s
.31637 .6167 m .31095 .56203 L .29868 .55409 L p .707 .577 .707 r
F P
0 g
s
.68886 .61839 m .68654 .56163 L .71599 .55829 L p .707 .577 .707 r
F P
0 g
s
.3425 .68696 m .33668 .65105 L .3164 .64593 L p .707 .577 .707 r
F P
0 g
s
.3688 .71274 m .37188 .73065 L .40233 .72875 L p .707 .577 .707 r
F P
0 g
s
.68994 .64847 m .69243 .6866 L .66804 .69057 L p .707 .577 .707 r
F P
0 g
s
.47917 .62721 m .485 .66312 L .50179 .65179 L p .707 .577 .707 r
F P
0 g
s
.50179 .65179 m .49596 .61588 L .47917 .62721 L p .707 .577 .707 r
F P
0 g
s
.46026 .6972 m .46334 .71512 L .48793 .70472 L p .707 .577 .707 r
F P
0 g
s
.48793 .70472 m .48485 .68681 L .46026 .6972 L p .707 .577 .707 r
F P
0 g
s
.37188 .73065 m .3688 .71274 L .34239 .711 L p .707 .577 .707 r
F P
0 g
s
.77891 .55661 m .78124 .61336 L .75014 .61331 L p .707 .577 .707 r
F P
0 g
s
.75014 .61331 m .74782 .55656 L .77891 .55661 L p .707 .577 .707 r
F P
0 g
s
.80937 .64196 m .81186 .68008 L .78477 .67986 L p .707 .577 .707 r
F P
0 g
s
.78477 .67986 m .78228 .64174 L .80937 .64196 L p .707 .577 .707 r
F P
0 g
s
.49161 .54123 m .49704 .59591 L .50437 .58571 L p .707 .577 .707 r
F P
0 g
s
.50437 .58571 m .49894 .53104 L .49161 .54123 L p .707 .577 .707 r
F P
0 g
s
.67117 .73455 m .66985 .71546 L .69461 .71169 L p .707 .577 .707 r
F P
0 g
s
.71599 .55829 m .71831 .61504 L .68886 .61839 L p .707 .577 .707 r
F P
0 g
s
.69461 .71169 m .69592 .73077 L .67117 .73455 L p .707 .577 .707 r
F P
0 g
s
.34239 .711 m .34548 .72892 L .37188 .73065 L p .707 .577 .707 r
F P
0 g
s
.71831 .61504 m .71599 .55829 L .74782 .55656 L p .707 .577 .707 r
F P
0 g
s
.3164 .64593 m .32223 .68184 L .3425 .68696 L p .707 .577 .707 r
F P
0 g
s
.74782 .55656 m .75014 .61331 L .71831 .61504 L p .707 .577 .707 r
F P
0 g
s
.29868 .55409 m .3041 .60877 L .31637 .6167 L p .707 .577 .707 r
F P
0 g
s
.8138 .70487 m .81512 .72395 L .78835 .72397 L p .707 .577 .707 r
F P
0 g
s
.78835 .72397 m .78703 .70488 L .8138 .70487 L p .707 .577 .707 r
F P
0 g
s
.69243 .6866 m .68994 .64847 L .71949 .64517 L p .707 .577 .707 r
F P
0 g
s
.48485 .68681 m .48793 .70472 L .50521 .69323 L p .707 .577 .707 r
F P
0 g
s
.50521 .69323 m .50212 .67531 L .48485 .68681 L p .707 .577 .707 r
F P
0 g
s
.71949 .64517 m .72198 .68329 L .69243 .6866 L p .707 .577 .707 r
F P
0 g
s
.34548 .72892 m .34239 .711 L .32262 .7058 L p .707 .577 .707 r
F P
0 g
s
.78228 .64174 m .78477 .67986 L .7538 .68097 L p .707 .577 .707 r
F P
0 g
s
.7538 .68097 m .7513 .64285 L .78228 .64174 L p .707 .577 .707 r
F P
0 g
s
.32223 .68184 m .3164 .64593 L .30461 .63788 L p .707 .577 .707 r
F P
0 g
s
.3041 .60877 m .29868 .55409 L .29608 .54456 L p .707 .577 .707 r
F P
0 g
s
.49596 .61588 m .50179 .65179 L .50948 .64049 L p .707 .577 .707 r
F P
0 g
s
.50948 .64049 m .50366 .60458 L .49596 .61588 L p .707 .577 .707 r
F P
0 g
s
.69592 .73077 m .69461 .71169 L .72437 .70847 L p .707 .577 .707 r
F P
0 g
s
.32262 .7058 m .32571 .72372 L .34548 .72892 L p .707 .577 .707 r
F P
0 g
s
.72198 .68329 m .71949 .64517 L .7513 .64285 L p .707 .577 .707 r
F P
0 g
s
.72437 .70847 m .72568 .72755 L .69592 .73077 L p .707 .577 .707 r
F P
0 g
s
.7513 .64285 m .7538 .68097 L .72198 .68329 L p .707 .577 .707 r
F P
0 g
s
.78703 .70488 m .78835 .72397 L .75753 .72521 L p .707 .577 .707 r
F P
0 g
s
.75753 .72521 m .75622 .70612 L .78703 .70488 L p .707 .577 .707 r
F P
0 g
s
.49894 .53104 m .50437 .58571 L .50177 .57618 L p .707 .577 .707 r
F P
0 g
s
.50177 .57618 m .49635 .5215 L .49894 .53104 L p .707 .577 .707 r
F P
0 g
s
.30461 .63788 m .31044 .67379 L .32223 .68184 L p .707 .577 .707 r
F P
0 g
s
.72568 .72755 m .72437 .70847 L .75622 .70612 L p .707 .577 .707 r
F P
0 g
s
.75622 .70612 m .75753 .72521 L .72568 .72755 L p .707 .577 .707 r
F P
0 g
s
.29608 .54456 m .3015 .59923 L .3041 .60877 L p .707 .577 .707 r
F P
0 g
s
.50212 .67531 m .50521 .69323 L .51348 .68176 L p .707 .577 .707 r
F P
0 g
s
.51348 .68176 m .51039 .66385 L .50212 .67531 L p .707 .577 .707 r
F P
0 g
s
.32571 .72372 m .32262 .7058 L .31141 .69764 L p .707 .577 .707 r
F P
0 g
s
.31141 .69764 m .3145 .71556 L .32571 .72372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.31044 .67379 m .30461 .63788 L .30246 .62771 L p .708 .578 .707 r
F P
0 g
s
.3015 .59923 m .29608 .54456 L .30341 .53436 L p .707 .577 .707 r
F P
0 g
s
.50366 .60458 m .50948 .64049 L .50733 .63032 L p .708 .578 .707 r
F P
0 g
s
.50733 .63032 m .5015 .59441 L .50366 .60458 L p .708 .578 .707 r
F P
0 g
s
.49635 .5215 m .50177 .57618 L .4895 .56824 L p .707 .577 .707 r
F P
0 g
s
.4895 .56824 m .48407 .51357 L .49635 .5215 L p .707 .577 .707 r
F P
0 g
s
.30246 .62771 m .30828 .66362 L .31044 .67379 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30341 .53436 m .30883 .58904 L .3015 .59923 L p .707 .577 .707 r
F P
0 g
s
.51039 .66385 m .51348 .68176 L .51194 .67145 L p .706 .577 .707 r
F P
0 g
s
.51194 .67145 m .50885 .65353 L .51039 .66385 L p .706 .577 .707 r
F P
0 g
s
.3145 .71556 m .31141 .69764 L .30987 .68732 L p .706 .577 .707 r
F P
0 g
s
.30987 .68732 m .31296 .70524 L .3145 .71556 L p .706 .577 .707 r
F P
0 g
s
.30828 .66362 m .30246 .62771 L .31015 .61641 L p .707 .577 .707 r
F P
0 g
s
.30883 .58904 m .30341 .53436 L .31995 .52451 L p .707 .577 .707 r
F P
0 g
s
.5015 .59441 m .50733 .63032 L .49554 .62228 L p .707 .577 .707 r
F P
0 g
s
.49554 .62228 m .48971 .58637 L .5015 .59441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48407 .51357 m .4895 .56824 L .46875 .56268 L p .707 .577 .707 r
F P
0 g
s
.46875 .56268 m .46333 .508 L .48407 .51357 L p .707 .577 .707 r
F P
0 g
s
.31015 .61641 m .31598 .65232 L .30828 .66362 L p .707 .577 .707 r
F P
0 g
s
.31995 .52451 m .32538 .57918 L .30883 .58904 L p .707 .577 .707 r
F P
0 g
s
.50885 .65353 m .51194 .67145 L .50073 .66329 L p .707 .577 .707 r
F P
0 g
s
.50073 .66329 m .49764 .64537 L .50885 .65353 L p .707 .577 .707 r
F P
0 g
s
.31296 .70524 m .30987 .68732 L .31814 .67586 L p .707 .577 .707 r
F P
0 g
s
.32538 .57918 m .31995 .52451 L .34408 .51595 L p .707 .577 .707 r
F P
0 g
s
.31814 .67586 m .32123 .69377 L .31296 .70524 L p .707 .577 .707 r
F P
0 g
s
.31598 .65232 m .31015 .61641 L .32694 .60508 L p .707 .577 .707 r
F P
0 g
s
.48971 .58637 m .49554 .62228 L .47526 .61715 L p .707 .577 .707 r
F P
0 g
s
.47526 .61715 m .46944 .58124 L .48971 .58637 L p .707 .577 .707 r
F P
0 g
s
.46333 .508 m .46875 .56268 L .44156 .56003 L p .707 .577 .707 r
F P
0 g
s
.44156 .56003 m .43614 .50535 L .46333 .508 L p .707 .577 .707 r
F P
0 g
s
.32694 .60508 m .33276 .64099 L .31598 .65232 L p .707 .577 .707 r
F P
0 g
s
.34408 .51595 m .34951 .57063 L .32538 .57918 L p .707 .577 .707 r
F P
0 g
s
.34951 .57063 m .34408 .51595 L .37345 .50953 L p .707 .577 .707 r
F P
0 g
s
.49764 .64537 m .50073 .66329 L .48096 .65809 L p .707 .577 .707 r
F P
0 g
s
.48096 .65809 m .47787 .64017 L .49764 .64537 L p .707 .577 .707 r
F P
0 g
s
.32123 .69377 m .31814 .67586 L .33542 .66436 L p .707 .577 .707 r
F P
0 g
s
.43614 .50535 m .44156 .56003 L .41059 .56056 L p .707 .577 .707 r
F P
0 g
s
.41059 .56056 m .40517 .50588 L .43614 .50535 L p .707 .577 .707 r
F P
0 g
s
.33276 .64099 m .32694 .60508 L .35118 .59484 L p .707 .577 .707 r
F P
0 g
s
.46944 .58124 m .47526 .61715 L .44849 .61544 L p .707 .577 .707 r
F P
0 g
s
.44849 .61544 m .44267 .57953 L .46944 .58124 L p .707 .577 .707 r
F P
0 g
s
.33542 .66436 m .3385 .68228 L .32123 .69377 L p .707 .577 .707 r
F P
0 g
s
.37887 .56421 m .37345 .50953 L .40517 .50588 L p .707 .577 .707 r
F P
0 g
s
.37345 .50953 m .37887 .56421 L .34951 .57063 L p .707 .577 .707 r
F P
0 g
s
.40517 .50588 m .41059 .56056 L .37887 .56421 L p .707 .577 .707 r
F P
0 g
s
.35118 .59484 m .357 .63075 L .33276 .64099 L p .707 .577 .707 r
F P
0 g
s
.357 .63075 m .35118 .59484 L .3805 .58668 L p .707 .577 .707 r
F P
0 g
s
.44267 .57953 m .44849 .61544 L .41785 .61731 L p .707 .577 .707 r
F P
0 g
s
.41785 .61731 m .41202 .5814 L .44267 .57953 L p .707 .577 .707 r
F P
0 g
s
.47787 .64017 m .48096 .65809 L .45455 .65635 L p .707 .577 .707 r
F P
0 g
s
.45455 .65635 m .45147 .63844 L .47787 .64017 L p .707 .577 .707 r
F P
0 g
s
.3385 .68228 m .33542 .66436 L .36001 .65397 L p .707 .577 .707 r
F P
0 g
s
.36001 .65397 m .36309 .67189 L .3385 .68228 L p .707 .577 .707 r
F P
0 g
s
.38632 .62259 m .3805 .58668 L .41202 .5814 L p .707 .577 .707 r
F P
0 g
s
.3805 .58668 m .38632 .62259 L .357 .63075 L p .707 .577 .707 r
F P
0 g
s
.41202 .5814 m .41785 .61731 L .38632 .62259 L p .707 .577 .707 r
F P
0 g
s
.45147 .63844 m .45455 .65635 L .4241 .65825 L p .707 .577 .707 r
F P
0 g
s
.4241 .65825 m .42102 .64034 L .45147 .63844 L p .707 .577 .707 r
F P
0 g
s
.36309 .67189 m .36001 .65397 L .3895 .64569 L p .707 .577 .707 r
F P
0 g
s
.3895 .64569 m .39259 .66361 L .36309 .67189 L p .707 .577 .707 r
F P
0 g
s
.42102 .64034 m .4241 .65825 L .39259 .66361 L p .707 .577 .707 r
F P
0 g
s
.39259 .66361 m .3895 .64569 L .42102 .64034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Q7oo6000PGoo001hOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001hOol0075oo`L000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007=oo`00Kgoo0P00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1000Kgoo001/Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUH00000KGoo001ZOol20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00Jgoo001Y
Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2001YOol006Moo`800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP80
06Qoo`00IWoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Moo`00IWoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF009JEQ0000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol006Eoo`800003FUH0000000D000AJEP03001JEUYF00EJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001TOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUH0000200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001POol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
IWoo001NOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP00IWoo001LOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP020008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUIJEP00IWoo001JOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00F7oo0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000QJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol005Ioo`80009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP00IWoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00EGoo0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP004Goo8000=Goo001DOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJ
EP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUH000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
035oo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPT0009JEPL000AJEPP0
00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01@000eYF
1`000UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=oo`@000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005Ao
o`04001JEUYF0004FUH00`00FUIJEP03FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00EJEP@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000IJEP03001JEUYF009JEP04001JEP000006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001EOol00`00FUH00002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP090003FUH01000FUIJEUYF20000eYF00@005YFFUH000IJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool005Eoo`03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF0006FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo001EOol01000FUH000001EYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
?goo4@001Goo0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP03001JEUYF00=JEP03
001JEUYF00<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000a
Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00
FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001J
EP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H0
05YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01000FUIJEUYF0P00
;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF5P000UYF
00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000eYF0P00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
00000eYF0000000500000eYF001JEP0:FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000=JEP03001JEP0000<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000QJEP03001J
EUYF00UJEP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010000eYF10002UYF00<005YFFUH01eYF0P00
15YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001J
EUYF00AJEP@0009JEP04001JEUYFFUH5000:FUH00`00FUIJEP05FUH200000eYF001JEP03FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH0000000=JEP04001JEUYFFUH5000:FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02
FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009J
EP03001JEP000080009JEP8000=JEP04001JEUYFFUH50009FUH80004FUH00`00FUIJEP02FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP800003FUH0
05YF009JEP8000=JEP03001JEUYF009JEPd000AJEP04001JEUYFFUH60003FUH01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF7@00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH01P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009o
o`@000=JEP03001JEUYF00EJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008002eoo`00;7oo00<005YF000015YF00<005YFFUH00UYF600015YF00<005YF0000
0UYF1@000eYF00@005YFFUIJEP80009JEP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000Eoo``000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP000080011oo`<000Eo
o`L0009JEP03001JEUYF009JEP/000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEP00FUH02@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00<005YF000015YF0P0000AJ
EP00000000ioo`D000Yoo`<00003FUH005YF00=JEP04001JEUYFFUH200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002eoo`00;7oo00<005YF00000UYF0P0015YF00<005YF00000`002Woo1@002goo0P00
00=JEP00FUH00eYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001J
EUYF00H000=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005
FUH00`00FUIJEP03FUH60004Ool50009Ool30002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF000000020002FUH00`00FUIJEP02
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYF000]Ool002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEP0001/0
009JEP800003FUH005YF009JEP8000MJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP04FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
02aoo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0002FUH01000FUH005YF0P0000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002aoo`00;7oo0P000UYF00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P000UYF00D005YFFUIJEP0000IJEP<000QJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ao
o`00;7oo00@005YFFUIJEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30005FUH01000FUIJEUYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00;7oo
00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001EYF00@005YF000000AJEP03001JEUYF00AJEP<000IJEPH000]JEP03
001JEUYF00<0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00UYF70000UYF
00<007ooOol0:Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20005FUH20006FUH00`00FUIJEP03FUH500000eYF
000000020005FUH00`00FUIJEP09FUH30002FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH0009JEQH000UJEP03001JEUYF00QJEP8000EJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;7oo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030003FUH00`00FUIJEP030003FUH01000FUIJEUYF1@002UYF00<005YFFUH01UYF
0P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YFFUH0009JEP03001JEUYF00D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0P0015YF0P0000AJEP00000000=JEP03001JEUYF009JEP@000YJEP03001JEUYF00AJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYF001JEP040004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH4000aOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000030003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH01000FUIJEUYF0`001UYF00<005YFFUH00P001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Goo000/Ool20004FUH00`00FUIJEP03FUH70007FUH90004FUH00`00FUIJEP02FUH40005FUH00`00
FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH400000eYF001JEP06FUH30009FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000iOol002aoo`8000AJ
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP04FUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF2`0015YF
00<005YFFUH00UYF8P00;Woo000/Ool20004FUH2000017oo000000001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000IJEP00001JEP00FUH300000eYF001JEP02FUH20003FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00eYF00<0
05YF00003@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ao
o`00;7oo0P000UYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`0000=JEP00FUH00eYF50001UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0002FUH50004FUH80003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo
000[Ool00`00FUH00002000<Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH002aoo`00:goo00<005YF00000P004goo4P001Goo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010001eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEP<0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF000/Ool002]oo`8000=JEP03001oogoo00]ooa0000ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP03001JEUYF008002]oo`00:goo
0P000eYF0`001Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0100037oo0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH00UYF5@000eYF00<005YFFUH015YF2@00:goo000[Ool20003FUH00`00FUIJEP05
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;OolD0008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP03FUH01000FUIJEUYF500015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YF000002]oo`00:goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000<000Qoo`03001JEP00008000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH005YF009JEPD000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00:goo0P000eYF0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo0P00
00=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH0
0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF1000<Goo000[Ool200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006
FUH00`00FUIJEP05FUH50003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000/Ool20004FUH00`00FUIJEP03FUH:000;Ool40002FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04
FUHE0009FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>000iOol002aoo`8000AJEP03001JEP00
00<000EJEP03001JEUYF009JEPT000Ioo`@000IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
00<005YFFUH01EYF00<005YFFUH01UYF2@0000=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEQd004Moo`00;7oo0P0015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YFFUH0
0eYF00@005YF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00H000YJEP03001JEUYF00YJEP03
001JEUYF00UJEPL000MJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH2001IOol0
02]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP@000EJEPH000=JEP03001JEUYF00AJEP@000AJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD0009JEP03001JEUYF00AJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUH0001HOol002]oo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH00`00FUH000030003
FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH50005FUH01000FUIJEP0015YF00<005YFFUH00eYF00D005YFFUIJEP0005Moo`00:goo
00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P000eYF
00@005YFFUH000AJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol002]oo`8000Eoo`04001JEUYF
0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH3
0003FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH200001EYF001JEUYF000015YF00<005YFFUH00eYF00@005YF
FUIJEP8005Ioo`00:goo0P001Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00H005YFFUH005YF001FOol002]oo`8000Qoo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEPD0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00H005YFFUH005YF001F
Ool002]oo`03001JEP0000Uoo`@0009JEP03001JEUYF00EJEP03001JEP0000@000=JEP03001JEUYF
00EJEP03001JEUYF00=JEP8000=oo`D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF001JEP05FUH00`00FUIJEP02001GOol002]oo`04001JEUYF000<Ool60004FUH00`00FUH0
00040003FUH00`00FUIJEP05FUH00`00FUH000030007Ool300000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUIJEUYF0P00Egoo000[Ool01@00FUIJEUYF
00004Goo2`000eYF00<005YFFUH00UYF1@002Woo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF0`0000=JEP00FUH00UYF0P00Egoo000[Ool01000FUIJEUYF0`005Woo
30003goo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF0`000UYF
00<005YF0000Egoo000/Ool01000FUIJEP000UYF0P00;Woo00L005YF001oo`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0300000eYF001oo`1FOol002aoo`03001J
EP0000EJEP8002Yoo`<00006FUH007oo001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0006FUH00`00FUIJEP02FUH2001HOol002eoo`8000EJEP04001JEP00000VOol20002FUH20003Ool2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00F7oo
000^Ool00`00FUIJEP03FUH01000FUIJEUYF0`008Goo0P0015YF0P0017oo0P001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0`0000=JEP0000000P001EYF00L005YFFUIJEP00FUH0001HOol002moo`8000=JEP03001JEUYF
00AJEPH001Moo`@00003FUH005YF00=JEP03001oogoo00Eoo`8000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP800003
FUH005YF00AJEP<00003FUH005YF00=JEP8005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
0UYF2@002Goo1@001EYF00<005YFFUH00UYF00<007ooOol01goo0P0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH010000UYF00<0
05YFFUH01EYF00<005YF00000P0000AJEP00000005Yoo`00<goo0`001UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0037oo10001eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF2@000UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00G7oo000fOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH3000BOol50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP060002Ool50002Ool40006FUH00`00FUIJEP03FUH3001JOol003Qoo`<00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP8001Uoo`P000IJEP03001JEUYF
00YJEP03001JEUYF00AJEPP000Qoo`D000Ioo`@0009JEP03001JEUYF00=JEP04001JEUYF001IOol0
03]oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<002=ooaX00003FUH00000
008000]oo`D000Yoo`@000=JEP05001JEUYFFUH0001IOol0041oo`T000AJEP03001JEUYF009JEPH0
03Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00@000Qoo`<000moo`800003FUH005YF009JEP80
05Qoo`00BGoo2@00?Woo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`005Goo0P000UYF00<005YF
0000F7oo002BOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool8000015YF001JEP00
F7oo002EOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YF
FUH00UYF0`00FGoo002IOol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001IOol009eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00FGoo002QOol70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1P00FUIJEUYF001JEP8005Uoo`00Z7oo2@0015YF00<005YFFUH015YF00<005YFFUH00`00Fgoo002a
Ool>001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60278 .75323 m .59733 .69857 L .56624 .69927 L p .707 .577 .707 r
F P
0 g
s
.59733 .69857 m .60278 .75323 L .63445 .7494 L p .707 .577 .707 r
F P
0 g
s
.63445 .7494 m .629 .69475 L .59733 .69857 L p .707 .577 .707 r
F P
0 g
s
.629 .69475 m .63445 .7494 L .6636 .74283 L p .707 .577 .707 r
F P
0 g
s
.6636 .74283 m .65815 .68818 L .629 .69475 L p .707 .577 .707 r
F P
0 g
s
.57169 .75393 m .56624 .69927 L .53878 .69678 L p .707 .577 .707 r
F P
0 g
s
.56624 .69927 m .57169 .75393 L .60278 .75323 L p .707 .577 .707 r
F P
0 g
s
.65815 .68818 m .6636 .74283 L .68739 .73415 L p .707 .577 .707 r
F P
0 g
s
.68739 .73415 m .68194 .6795 L .65815 .68818 L p .707 .577 .707 r
F P
0 g
s
.54423 .75144 m .53878 .69678 L .51764 .69134 L p .707 .577 .707 r
F P
0 g
s
.53878 .69678 m .54423 .75144 L .57169 .75393 L p .707 .577 .707 r
F P
0 g
s
.60991 .81555 m .60402 .77971 L .57309 .78206 L p .707 .577 .707 r
F P
0 g
s
.60402 .77971 m .60991 .81555 L .64131 .8098 L p .707 .577 .707 r
F P
0 g
s
.64131 .8098 m .63542 .77396 L .60402 .77971 L p .707 .577 .707 r
F P
0 g
s
.63542 .77396 m .64131 .8098 L .67011 .80122 L p .707 .577 .707 r
F P
0 g
s
.67011 .80122 m .66422 .76538 L .63542 .77396 L p .707 .577 .707 r
F P
0 g
s
.57898 .81791 m .57309 .78206 L .54566 .7808 L p .707 .577 .707 r
F P
0 g
s
.57309 .78206 m .57898 .81791 L .60991 .81555 L p .707 .577 .707 r
F P
0 g
s
.68194 .6795 m .68739 .73415 L .70348 .72422 L p .707 .577 .707 r
F P
0 g
s
.70348 .72422 m .69803 .66956 L .68194 .6795 L p .707 .577 .707 r
F P
0 g
s
.66422 .76538 m .67011 .80122 L .69349 .79065 L p .707 .577 .707 r
F P
0 g
s
.69349 .79065 m .6876 .7548 L .66422 .76538 L p .707 .577 .707 r
F P
0 g
s
.51764 .69134 m .52309 .746 L .54423 .75144 L p .707 .577 .707 r
F P
0 g
s
.61615 .85742 m .61299 .83958 L .582 .84242 L p .707 .577 .707 r
F P
0 g
s
.61299 .83958 m .61615 .85742 L .64742 .85114 L p .707 .577 .707 r
F P
0 g
s
.64742 .85114 m .64427 .8333 L .61299 .83958 L p .707 .577 .707 r
F P
0 g
s
.54566 .7808 m .55155 .81664 L .57898 .81791 L p .707 .577 .707 r
F P
0 g
s
.52309 .746 m .51764 .69134 L .50489 .68349 L p .707 .577 .707 r
F P
0 g
s
.64427 .8333 m .64742 .85114 L .67592 .84204 L p .707 .577 .707 r
F P
0 g
s
.67592 .84204 m .67276 .82419 L .64427 .8333 L p .707 .577 .707 r
F P
0 g
s
.55155 .81664 m .54566 .7808 L .52441 .77603 L p .707 .577 .707 r
F P
0 g
s
.582 .84242 m .58516 .86027 L .61615 .85742 L p .707 .577 .707 r
F P
0 g
s
.58516 .86027 m .582 .84242 L .55433 .84155 L p .707 .577 .707 r
F P
0 g
s
.6876 .7548 m .69349 .79065 L .70915 .77912 L p .707 .577 .707 r
F P
0 g
s
.70915 .77912 m .70326 .74327 L .6876 .7548 L p .707 .577 .707 r
F P
0 g
s
.67276 .82419 m .67592 .84204 L .69885 .83101 L p .707 .577 .707 r
F P
0 g
s
.69885 .83101 m .6957 .81316 L .67276 .82419 L p .707 .577 .707 r
F P
0 g
s
.55433 .84155 m .55749 .8594 L .58516 .86027 L p .707 .577 .707 r
F P
0 g
s
.69803 .66956 m .70348 .72422 L .7103 .714 L p .707 .577 .707 r
F P
0 g
s
.7103 .714 m .70484 .65934 L .69803 .66956 L p .707 .577 .707 r
F P
0 g
s
.52441 .77603 m .5303 .81187 L .55155 .81664 L p .707 .577 .707 r
F P
0 g
s
.50489 .68349 m .51034 .73814 L .52309 .746 L p .707 .577 .707 r
F P
0 g
s
.55749 .8594 m .55433 .84155 L .53269 .83705 L p .707 .577 .707 r
F P
0 g
s
.5303 .81187 m .52441 .77603 L .51143 .76822 L p .707 .577 .707 r
F P
0 g
s
.53269 .83705 m .53584 .8549 L .55749 .8594 L p .707 .577 .707 r
F P
0 g
s
.51034 .73814 m .50489 .68349 L .50176 .67398 L p .707 .577 .707 r
F P
0 g
s
.6957 .81316 m .69885 .83101 L .71397 .81913 L p .707 .577 .707 r
F P
0 g
s
.71397 .81913 m .71082 .80128 L .6957 .81316 L p .707 .577 .707 r
F P
0 g
s
.70326 .74327 m .70915 .77912 L .71557 .76776 L p .707 .577 .707 r
F P
0 g
s
.71557 .76776 m .70968 .73192 L .70326 .74327 L p .707 .577 .707 r
F P
0 g
s
.51143 .76822 m .51732 .80407 L .5303 .81187 L p .707 .577 .707 r
F P
0 g
s
.70484 .65934 m .7103 .714 L .70717 .70449 L p .707 .577 .707 r
F P
0 g
s
.70717 .70449 m .70172 .64984 L .70484 .65934 L p .707 .577 .707 r
F P
0 g
s
.53584 .8549 m .53269 .83705 L .51919 .82936 L p .707 .577 .707 r
F P
0 g
s
.50176 .67398 m .50721 .72864 L .51034 .73814 L p .707 .577 .707 r
F P
0 g
s
.51919 .82936 m .52234 .84721 L .53584 .8549 L p .707 .577 .707 r
F P
0 g
s
.51732 .80407 m .51143 .76822 L .50798 .75815 L p .707 .577 .707 r
F P
0 g
s
.50721 .72864 m .50176 .67398 L .50858 .66376 L p .707 .577 .707 r
F P
0 g
s
.50798 .75815 m .51387 .79399 L .51732 .80407 L p .707 .577 .707 r
F P
0 g
s
.50858 .66376 m .51403 .71842 L .50721 .72864 L p .707 .577 .707 r
F P
0 g
s
.51387 .79399 m .50798 .75815 L .5144 .74679 L p .707 .577 .707 r
F P
0 g
s
.51403 .71842 m .50858 .66376 L .52467 .65383 L p .707 .577 .707 r
F P
0 g
s
.51076 .82181 m .51076 .31993 L .46579 .31893 L p .707 .577 .707 r
F P
0 g
s
.52234 .84721 m .51919 .82936 L .51516 .81924 L p .707 .577 .707 r
F P
0 g
s
.51516 .81924 m .51831 .83708 L .52234 .84721 L p .707 .577 .707 r
F P
0 g
s
.5144 .74679 m .52029 .78264 L .51387 .79399 L p .707 .577 .707 r
F P
0 g
s
.51831 .83708 m .51516 .81924 L .52099 .80767 L p .707 .577 .707 r
F P
0 g
s
.52467 .65383 m .53012 .70848 L .51403 .71842 L p .707 .577 .707 r
F P
0 g
s
.52099 .80767 m .52414 .82551 L .51831 .83708 L p .707 .577 .707 r
F P
0 g
s
.52029 .78264 m .5144 .74679 L .53007 .73526 L p .707 .577 .707 r
F P
0 g
s
.53012 .70848 m .52467 .65383 L .54846 .64515 L p .707 .577 .707 r
F P
0 g
s
.53007 .73526 m .53596 .77111 L .52029 .78264 L p .707 .577 .707 r
F P
0 g
s
.54846 .64515 m .55391 .6998 L .53012 .70848 L p .707 .577 .707 r
F P
0 g
s
.52414 .82551 m .52099 .80767 L .53611 .79578 L p .707 .577 .707 r
F P
0 g
s
.53611 .79578 m .53927 .81363 L .52414 .82551 L p .707 .577 .707 r
F P
0 g
s
.53596 .77111 m .53007 .73526 L .55344 .72469 L p .707 .577 .707 r
F P
0 g
s
.55344 .72469 m .55933 .76053 L .53596 .77111 L p .707 .577 .707 r
F P
0 g
s
.53927 .81363 m .53611 .79578 L .55904 .78475 L p .707 .577 .707 r
F P
0 g
s
.55904 .78475 m .5622 .8026 L .53927 .81363 L p .707 .577 .707 r
F P
0 g
s
.51076 .31993 m .51076 .82181 L .55469 .81903 L p .707 .577 .707 r
F P
0 g
s
.55391 .6998 m .54846 .64515 L .57761 .63857 L p .707 .577 .707 r
F P
0 g
s
.57761 .63857 m .58306 .69323 L .55391 .6998 L p .707 .577 .707 r
F P
0 g
s
.55933 .76053 m .55344 .72469 L .58224 .71611 L p .707 .577 .707 r
F P
0 g
s
.55469 .81903 m .55469 .31715 L .51076 .31993 L p .707 .577 .707 r
F P
0 g
s
.71082 .80128 m .71397 .81913 L .71981 .80756 L p .707 .577 .707 r
F P
0 g
s
.71981 .80756 m .71665 .78971 L .71082 .80128 L p .707 .577 .707 r
F P
0 g
s
.46579 .82082 m .46579 .31893 L .42416 .31425 L p .707 .577 .707 r
F P
0 g
s
.46579 .31893 m .46579 .82082 L .51076 .82181 L p .707 .577 .707 r
F P
0 g
s
.58306 .69323 m .57761 .63857 L .60928 .63475 L p .707 .577 .707 r
F P
0 g
s
.60928 .63475 m .61473 .68941 L .58306 .69323 L p .707 .577 .707 r
F P
0 g
s
.58813 .75195 m .58224 .71611 L .61364 .71036 L p .707 .577 .707 r
F P
0 g
s
.58224 .71611 m .58813 .75195 L .55933 .76053 L p .707 .577 .707 r
F P
0 g
s
.61364 .71036 m .61953 .7462 L .58813 .75195 L p .707 .577 .707 r
F P
0 g
s
.5622 .8026 m .55904 .78475 L .58754 .77565 L p .707 .577 .707 r
F P
0 g
s
.58754 .77565 m .5907 .7935 L .5622 .8026 L p .707 .577 .707 r
F P
0 g
s
.5907 .7935 m .58754 .77565 L .61882 .76937 L p .707 .577 .707 r
F P
0 g
s
.61882 .76937 m .62197 .78722 L .5907 .7935 L p .707 .577 .707 r
F P
0 g
s
.55469 .31715 m .55469 .81903 L .59326 .81275 L p .707 .577 .707 r
F P
0 g
s
.59326 .81275 m .59326 .31086 L .55469 .31715 L p .707 .577 .707 r
F P
0 g
s
.70968 .73192 m .71557 .76776 L .71212 .75769 L p .707 .577 .707 r
F P
0 g
s
.71212 .75769 m .70623 .72184 L .70968 .73192 L p .707 .577 .707 r
F P
0 g
s
.70172 .64984 m .70717 .70449 L .69442 .69664 L p .707 .577 .707 r
F P
0 g
s
.69442 .69664 m .68897 .64198 L .70172 .64984 L p .707 .577 .707 r
F P
0 g
s
.42416 .81614 m .42416 .31425 L .38995 .30635 L p .707 .577 .707 r
F P
0 g
s
.42416 .31425 m .42416 .81614 L .46579 .82082 L p .707 .577 .707 r
F P
0 g
s
.25655 .70503 m .2542 .64828 L .223 .64833 L p .707 .577 .707 r
F P
0 g
s
.2542 .64828 m .25655 .70503 L .28833 .70319 L p .707 .577 .707 r
F P
0 g
s
.28833 .70319 m .28599 .64645 L .2542 .64828 L p .707 .577 .707 r
F P
0 g
s
.28599 .64645 m .28833 .70319 L .31758 .69974 L p .707 .577 .707 r
F P
0 g
s
.31758 .69974 m .31523 .643 L .28599 .64645 L p .707 .577 .707 r
F P
0 g
s
.71665 .78971 m .71981 .80756 L .71577 .79743 L p .707 .577 .707 r
F P
0 g
s
.71577 .79743 m .71262 .77958 L .71665 .78971 L p .707 .577 .707 r
F P
0 g
s
.64037 .63405 m .64582 .68871 L .61473 .68941 L p .707 .577 .707 r
F P
0 g
s
.61473 .68941 m .60928 .63475 L .64037 .63405 L p .707 .577 .707 r
F P
0 g
s
.61953 .7462 m .61364 .71036 L .64457 .708 L p .707 .577 .707 r
F P
0 g
s
.62197 .78722 m .61882 .76937 L .64981 .76653 L p .707 .577 .707 r
F P
0 g
s
.59326 .31086 m .59326 .81275 L .6227 .80357 L p .707 .577 .707 r
F P
0 g
s
.64457 .708 m .65046 .74384 L .61953 .7462 L p .707 .577 .707 r
F P
0 g
s
.64981 .76653 m .65296 .78437 L .62197 .78722 L p .707 .577 .707 r
F P
0 g
s
.6227 .80357 m .6227 .30168 L .59326 .31086 L p .707 .577 .707 r
F P
0 g
s
.22534 .70507 m .223 .64833 L .19541 .64659 L p .707 .577 .707 r
F P
0 g
s
.223 .64833 m .22534 .70507 L .25655 .70503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70623 .72184 m .71212 .75769 L .69914 .74988 L p .707 .577 .707 r
F P
0 g
s
.69914 .74988 m .69325 .71404 L .70623 .72184 L p .707 .577 .707 r
F P
0 g
s
.31523 .643 m .31758 .69974 L .34142 .69502 L p .707 .577 .707 r
F P
0 g
s
.34142 .69502 m .33907 .63828 L .31523 .643 L p .707 .577 .707 r
F P
0 g
s
.26049 .76122 m .25793 .72312 L .22668 .72442 L p .707 .577 .707 r
F P
0 g
s
.25793 .72312 m .26049 .76122 L .29218 .75869 L p .707 .577 .707 r
F P
0 g
s
.29218 .75869 m .28962 .72059 L .25793 .72312 L p .707 .577 .707 r
F P
0 g
s
.19541 .64659 m .19776 .70333 L .22534 .70507 L p .707 .577 .707 r
F P
0 g
s
.68897 .64198 m .69442 .69664 L .67328 .6912 L p .707 .577 .707 r
F P
0 g
s
.67328 .6912 m .66782 .63654 L .68897 .64198 L p .707 .577 .707 r
F P
0 g
s
.28962 .72059 m .29218 .75869 L .32121 .75517 L p .707 .577 .707 r
F P
0 g
s
.32121 .75517 m .31865 .71707 L .28962 .72059 L p .707 .577 .707 r
F P
0 g
s
.22668 .72442 m .22924 .76252 L .26049 .76122 L p .707 .577 .707 r
F P
0 g
s
.38995 .80824 m .38995 .30635 L .36652 .296 L p .707 .577 .707 r
F P
0 g
s
.38995 .30635 m .38995 .80824 L .42416 .81614 L p .707 .577 .707 r
F P
0 g
s
.22924 .76252 m .22668 .72442 L .19892 .72436 L p .707 .577 .707 r
F P
0 g
s
.19776 .70333 m .19541 .64659 L .17416 .64322 L p .707 .577 .707 r
F P
0 g
s
.26429 .80343 m .26291 .78437 L .23155 .78596 L p .707 .577 .707 r
F P
0 g
s
.26291 .78437 m .26429 .80343 L .29589 .80069 L p .707 .577 .707 r
F P
0 g
s
.29589 .80069 m .29451 .78163 L .26291 .78437 L p .707 .577 .707 r
F P
0 g
s
.19892 .72436 m .20148 .76246 L .22924 .76252 L p .707 .577 .707 r
F P
0 g
s
.23155 .78596 m .23293 .80502 L .26429 .80343 L p .707 .577 .707 r
F P
0 g
s
.29451 .78163 m .29589 .80069 L .32465 .79708 L p .707 .577 .707 r
F P
0 g
s
.32465 .79708 m .32327 .77802 L .29451 .78163 L p .707 .577 .707 r
F P
0 g
s
.23293 .80502 m .23155 .78596 L .20351 .78625 L p .707 .577 .707 r
F P
0 g
s
.31865 .71707 m .32121 .75517 L .34474 .751 L p .707 .577 .707 r
F P
0 g
s
.34474 .751 m .34218 .7129 L .31865 .71707 L p .707 .577 .707 r
F P
0 g
s
.17416 .64322 m .17651 .69996 L .19776 .70333 L p .707 .577 .707 r
F P
0 g
s
.20351 .78625 m .20489 .80531 L .23293 .80502 L p .707 .577 .707 r
F P
0 g
s
.71262 .77958 m .71577 .79743 L .70228 .78974 L p .707 .577 .707 r
F P
0 g
s
.70228 .78974 m .69912 .7719 L .71262 .77958 L p .707 .577 .707 r
F P
0 g
s
.33907 .63828 m .34142 .69502 L .35753 .68949 L p .707 .577 .707 r
F P
0 g
s
.35753 .68949 m .35518 .63275 L .33907 .63828 L p .707 .577 .707 r
F P
0 g
s
.6227 .30168 m .6227 .80357 L .64013 .7924 L p .707 .577 .707 r
F P
0 g
s
.64013 .7924 m .64013 .29051 L .6227 .30168 L p .707 .577 .707 r
F P
0 g
s
.20148 .76246 m .19892 .72436 L .17738 .72293 L p .707 .577 .707 r
F P
0 g
s
.69325 .71404 m .69914 .74988 L .67789 .74511 L p .707 .577 .707 r
F P
0 g
s
.67789 .74511 m .672 .70927 L .69325 .71404 L p .707 .577 .707 r
F P
0 g
s
.66782 .63654 m .67328 .6912 L .64582 .68871 L p .707 .577 .707 r
F P
0 g
s
.64582 .68871 m .64037 .63405 L .66782 .63654 L p .707 .577 .707 r
F P
0 g
s
.17738 .72293 m .17994 .76103 L .20148 .76246 L p .707 .577 .707 r
F P
0 g
s
.32327 .77802 m .32465 .79708 L .34776 .79293 L p .707 .577 .707 r
F P
0 g
s
.34776 .79293 m .34638 .77387 L .32327 .77802 L p .707 .577 .707 r
F P
0 g
s
.17651 .69996 m .17416 .64322 L .16132 .63855 L p .707 .577 .707 r
F P
0 g
s
.20489 .80531 m .20351 .78625 L .18153 .7852 L p .707 .577 .707 r
F P
0 g
s
.18153 .7852 m .18291 .80426 L .20489 .80531 L p .707 .577 .707 r
F P
0 g
s
.34218 .7129 m .34474 .751 L .36045 .7466 L p .707 .577 .707 r
F P
0 g
s
.36045 .7466 m .35789 .7085 L .34218 .7129 L p .707 .577 .707 r
F P
0 g
s
.16132 .63855 m .16367 .69529 L .17651 .69996 L p .707 .577 .707 r
F P
0 g
s
.35518 .63275 m .35753 .68949 L .36433 .68369 L p .707 .577 .707 r
F P
0 g
s
.36433 .68369 m .36198 .62695 L .35518 .63275 L p .707 .577 .707 r
F P
0 g
s
.35789 .7085 m .36045 .7466 L .36682 .74239 L p .707 .577 .707 r
F P
0 g
s
.36682 .74239 m .36426 .70429 L .35789 .7085 L p .707 .577 .707 r
F P
0 g
s
.36156 .76961 m .36294 .78867 L .36871 .7847 L p .707 .577 .707 r
F P
0 g
s
.36871 .7847 m .36733 .76564 L .36156 .76961 L p .707 .577 .707 r
F P
0 g
s
.36198 .62695 m .36433 .68369 L .36115 .67819 L p .707 .577 .707 r
F P
0 g
s
.36426 .70429 m .36682 .74239 L .36323 .73879 L p .707 .577 .707 r
F P
0 g
s
.36733 .76564 m .36871 .7847 L .36451 .78142 L p .707 .577 .707 r
F P
0 g
s
.36451 .78142 m .36313 .76236 L .36733 .76564 L p .707 .577 .707 r
F P
0 g
s
.36652 .79789 m .36652 .296 L .35616 .28422 L p .707 .577 .707 r
F P
0 g
s
.36652 .296 m .36652 .79789 L .38995 .80824 L p .707 .577 .707 r
F P
0 g
s
.17994 .76103 m .17738 .72293 L .16417 .72029 L p .707 .577 .707 r
F P
0 g
s
.69912 .7719 m .70228 .78974 L .68063 .78524 L p .707 .577 .707 r
F P
0 g
s
.68063 .78524 m .67748 .7674 L .69912 .7719 L p .707 .577 .707 r
F P
0 g
s
.34638 .77387 m .34776 .79293 L .36294 .78867 L p .707 .577 .707 r
F P
0 g
s
.36294 .78867 m .36156 .76961 L .34638 .77387 L p .707 .577 .707 r
F P
0 g
s
.672 .70927 m .67789 .74511 L .65046 .74384 L p .707 .577 .707 r
F P
0 g
s
.65046 .74384 m .64457 .708 L .672 .70927 L p .707 .577 .707 r
F P
0 g
s
.16417 .72029 m .16673 .75839 L .17994 .76103 L p .707 .577 .707 r
F P
0 g
s
.18291 .80426 m .18153 .7852 L .16777 .78292 L p .707 .577 .707 r
F P
0 g
s
.16777 .78292 m .16915 .80198 L .18291 .80426 L p .707 .577 .707 r
F P
0 g
s
.16367 .69529 m .16132 .63855 L .15814 .63305 L p .707 .577 .707 r
F P
0 g
s
.64013 .29051 m .64013 .7924 L .64384 .78033 L p .707 .577 .707 r
F P
0 g
s
.64384 .78033 m .64384 .27844 L .64013 .29051 L p .707 .577 .707 r
F P
0 g
s
.67748 .7674 m .68063 .78524 L .65296 .78437 L p .707 .577 .707 r
F P
0 g
s
.65296 .78437 m .64981 .76653 L .67748 .7674 L p .707 .577 .707 r
F P
0 g
s
.15814 .63305 m .16049 .68979 L .16367 .69529 L p .707 .577 .707 r
F P
0 g
s
.16673 .75839 m .16417 .72029 L .16057 .71669 L p .707 .577 .707 r
F P
0 g
s
.36115 .67819 m .3588 .62145 L .36198 .62695 L p .707 .577 .707 r
F P
0 g
s
.16057 .71669 m .16313 .75479 L .16673 .75839 L p .707 .577 .707 r
F P
0 g
s
.16915 .80198 m .16777 .78292 L .16357 .77964 L p .707 .577 .707 r
F P
0 g
s
.36323 .73879 m .36067 .70069 L .36426 .70429 L p .707 .577 .707 r
F P
0 g
s
.3588 .62145 m .36115 .67819 L .3483 .67353 L p .707 .577 .707 r
F P
0 g
s
.3483 .67353 m .34596 .61679 L .3588 .62145 L p .707 .577 .707 r
F P
0 g
s
.36067 .70069 m .36323 .73879 L .35001 .73615 L p .707 .577 .707 r
F P
0 g
s
.35001 .73615 m .34745 .69805 L .36067 .70069 L p .707 .577 .707 r
F P
0 g
s
.36313 .76236 m .36451 .78142 L .35075 .77914 L p .707 .577 .707 r
F P
0 g
s
.35075 .77914 m .34937 .76008 L .36313 .76236 L p .707 .577 .707 r
F P
0 g
s
.35616 .28422 m .35616 .78611 L .36652 .79789 L p .707 .577 .707 r
F P
0 g
s
.35616 .78611 m .35616 .28422 L .35987 .27215 L p .707 .577 .707 r
F P
0 g
s
.16357 .77964 m .16495 .7987 L .16915 .80198 L p .707 .577 .707 r
F P
0 g
s
.16049 .68979 m .15814 .63305 L .16493 .62725 L p .707 .577 .707 r
F P
0 g
s
.16493 .62725 m .16728 .684 L .16049 .68979 L p .707 .577 .707 r
F P
0 g
s
.64384 .27844 m .64384 .78033 L .63348 .76854 L p .707 .577 .707 r
F P
0 g
s
.63348 .76854 m .63348 .26666 L .64384 .27844 L p .707 .577 .707 r
F P
0 g
s
.16313 .75479 m .16057 .71669 L .16694 .71248 L p .707 .577 .707 r
F P
0 g
s
.16694 .71248 m .1695 .75058 L .16313 .75479 L p .707 .577 .707 r
F P
0 g
s
.16495 .7987 m .16357 .77964 L .16934 .77567 L p .707 .577 .707 r
F P
0 g
s
.16934 .77567 m .17073 .79473 L .16495 .7987 L p .707 .577 .707 r
F P
0 g
s
.16728 .684 m .16493 .62725 L .18104 .62172 L p .707 .577 .707 r
F P
0 g
s
.35987 .77404 m .35987 .27215 L .3773 .26098 L p .707 .577 .707 r
F P
0 g
s
.35987 .27215 m .35987 .77404 L .35616 .78611 L p .707 .577 .707 r
F P
0 g
s
.18104 .62172 m .18339 .67847 L .16728 .684 L p .707 .577 .707 r
F P
0 g
s
.1695 .75058 m .16694 .71248 L .18266 .70808 L p .707 .577 .707 r
F P
0 g
s
.34596 .61679 m .3483 .67353 L .32705 .67016 L p .707 .577 .707 r
F P
0 g
s
.32705 .67016 m .3247 .61342 L .34596 .61679 L p .707 .577 .707 r
F P
0 g
s
.18266 .70808 m .18522 .74618 L .1695 .75058 L p .707 .577 .707 r
F P
0 g
s
.17073 .79473 m .16934 .77567 L .18452 .77141 L p .707 .577 .707 r
F P
0 g
s
.63348 .26666 m .63348 .76854 L .61004 .75819 L p .707 .577 .707 r
F P
0 g
s
.61004 .75819 m .61004 .25631 L .63348 .26666 L p .707 .577 .707 r
F P
0 g
s
.18452 .77141 m .18591 .79047 L .17073 .79473 L p .707 .577 .707 r
F P
0 g
s
.18339 .67847 m .18104 .62172 L .20489 .61701 L p .707 .577 .707 r
F P
0 g
s
.34745 .69805 m .35001 .73615 L .32847 .73473 L p .707 .577 .707 r
F P
0 g
s
.32847 .73473 m .32591 .69663 L .34745 .69805 L p .707 .577 .707 r
F P
0 g
s
.20489 .61701 m .20724 .67375 L .18339 .67847 L p .707 .577 .707 r
F P
0 g
s
.3247 .61342 m .32705 .67016 L .29947 .66841 L p .707 .577 .707 r
F P
0 g
s
.29947 .66841 m .29712 .61167 L .3247 .61342 L p .707 .577 .707 r
F P
0 g
s
.18522 .74618 m .18266 .70808 L .20618 .70392 L p .707 .577 .707 r
F P
0 g
s
.3773 .26098 m .3773 .76287 L .35987 .77404 L p .707 .577 .707 r
F P
0 g
s
.3773 .76287 m .3773 .26098 L .40674 .2518 L p .707 .577 .707 r
F P
0 g
s
.34937 .76008 m .35075 .77914 L .32877 .77809 L p .707 .577 .707 r
F P
0 g
s
.32877 .77809 m .32739 .75903 L .34937 .76008 L p .707 .577 .707 r
F P
0 g
s
.20724 .67375 m .20489 .61701 L .23413 .61356 L p .707 .577 .707 r
F P
0 g
s
.20618 .70392 m .20874 .74201 L .18522 .74618 L p .707 .577 .707 r
F P
0 g
s
.18591 .79047 m .18452 .77141 L .20763 .76726 L p .707 .577 .707 r
F P
0 g
s
.20763 .76726 m .20901 .78633 L .18591 .79047 L p .707 .577 .707 r
F P
0 g
s
.29712 .61167 m .29947 .66841 L .26826 .66846 L p .707 .577 .707 r
F P
0 g
s
.26826 .66846 m .26591 .61172 L .29712 .61167 L p .707 .577 .707 r
F P
0 g
s
.23413 .61356 m .23648 .6703 L .20724 .67375 L p .707 .577 .707 r
F P
0 g
s
.32591 .69663 m .32847 .73473 L .30072 .73466 L p .707 .577 .707 r
F P
0 g
s
.30072 .73466 m .29816 .69656 L .32591 .69663 L p .707 .577 .707 r
F P
0 g
s
.23648 .6703 m .23413 .61356 L .26591 .61172 L p .707 .577 .707 r
F P
0 g
s
.61004 .25631 m .61004 .75819 L .57584 .7503 L p .707 .577 .707 r
F P
0 g
s
.57584 .7503 m .57584 .24841 L .61004 .25631 L p .707 .577 .707 r
F P
0 g
s
.26591 .61172 m .26826 .66846 L .23648 .6703 L p .707 .577 .707 r
F P
0 g
s
.20874 .74201 m .20618 .70392 L .23521 .70039 L p .707 .577 .707 r
F P
0 g
s
.73174 .66462 m .73408 .61078 L .70288 .60716 L p .707 .577 .707 r
F P
0 g
s
.73408 .61078 m .73174 .66462 L .76352 .6647 L p .707 .577 .707 r
F P
0 g
s
.76352 .6647 m .76587 .61085 L .73408 .61078 L p .707 .577 .707 r
F P
0 g
s
.23521 .70039 m .23777 .73849 L .20874 .74201 L p .707 .577 .707 r
F P
0 g
s
.32739 .75903 m .32877 .77809 L .30073 .77838 L p .707 .577 .707 r
F P
0 g
s
.30073 .77838 m .29935 .75932 L .32739 .75903 L p .707 .577 .707 r
F P
0 g
s
.76587 .61085 m .76352 .6647 L .79276 .66122 L p .707 .577 .707 r
F P
0 g
s
.79276 .66122 m .79511 .60737 L .76587 .61085 L p .707 .577 .707 r
F P
0 g
s
.70053 .66101 m .70288 .60716 L .6753 .60035 L p .707 .577 .707 r
F P
0 g
s
.70288 .60716 m .70053 .66101 L .73174 .66462 L p .707 .577 .707 r
F P
0 g
s
.20901 .78633 m .20763 .76726 L .23639 .76365 L p .707 .577 .707 r
F P
0 g
s
.29816 .69656 m .30072 .73466 L .26946 .73596 L p .707 .577 .707 r
F P
0 g
s
.26946 .73596 m .2669 .69786 L .29816 .69656 L p .707 .577 .707 r
F P
0 g
s
.23639 .76365 m .23777 .78271 L .20901 .78633 L p .707 .577 .707 r
F P
0 g
s
.23777 .73849 m .23521 .70039 L .2669 .69786 L p .707 .577 .707 r
F P
0 g
s
.40674 .75369 m .40674 .2518 L .44531 .24551 L p .707 .577 .707 r
F P
0 g
s
.40674 .2518 m .40674 .75369 L .3773 .76287 L p .707 .577 .707 r
F P
0 g
s
.2669 .69786 m .26946 .73596 L .23777 .73849 L p .707 .577 .707 r
F P
0 g
s
.79511 .60737 m .79276 .66122 L .81661 .65452 L p .707 .577 .707 r
F P
0 g
s
.81661 .65452 m .81895 .60068 L .79511 .60737 L p .707 .577 .707 r
F P
0 g
s
.29935 .75932 m .30073 .77838 L .26938 .77997 L p .707 .577 .707 r
F P
0 g
s
.26938 .77997 m .26799 .76091 L .29935 .75932 L p .707 .577 .707 r
F P
0 g
s
.23777 .78271 m .23639 .76365 L .26799 .76091 L p .707 .577 .707 r
F P
0 g
s
.67295 .65419 m .6753 .60035 L .65404 .59101 L p .707 .577 .707 r
F P
0 g
s
.6753 .60035 m .67295 .65419 L .70053 .66101 L p .707 .577 .707 r
F P
0 g
s
.26799 .76091 m .26938 .77997 L .23777 .78271 L p .707 .577 .707 r
F P
0 g
s
.57584 .24841 m .57584 .7503 L .53421 .74562 L p .707 .577 .707 r
F P
0 g
s
.53421 .74562 m .53421 .24373 L .57584 .24841 L p .707 .577 .707 r
F P
0 g
s
.73054 .72861 m .7331 .6936 L .70184 .68908 L p .707 .577 .707 r
F P
0 g
s
.7331 .6936 m .73054 .72861 L .76223 .72906 L p .707 .577 .707 r
F P
0 g
s
.76223 .72906 m .76479 .69405 L .7331 .6936 L p .707 .577 .707 r
F P
0 g
s
.76479 .69405 m .76223 .72906 L .79126 .7254 L p .707 .577 .707 r
F P
0 g
s
.79126 .7254 m .79382 .69039 L .76479 .69405 L p .707 .577 .707 r
F P
0 g
s
.69928 .72409 m .70184 .68908 L .67409 .68094 L p .707 .577 .707 r
F P
0 g
s
.70184 .68908 m .69928 .72409 L .73054 .72861 L p .707 .577 .707 r
F P
0 g
s
.44531 .7474 m .44531 .24551 L .48923 .24273 L p .707 .577 .707 r
F P
0 g
s
.44531 .24551 m .44531 .7474 L .40674 .75369 L p .707 .577 .707 r
F P
0 g
s
.81895 .60068 m .81661 .65452 L .83271 .64527 L p .707 .577 .707 r
F P
0 g
s
.83271 .64527 m .83506 .59143 L .81895 .60068 L p .707 .577 .707 r
F P
0 g
s
.65404 .59101 m .65169 .64486 L .67295 .65419 L p .707 .577 .707 r
F P
0 g
s
.53421 .24373 m .53421 .74562 L .48923 .74462 L p .707 .577 .707 r
F P
0 g
s
.48923 .74462 m .48923 .24273 L .53421 .24373 L p .707 .577 .707 r
F P
0 g
s
.65169 .64486 m .65404 .59101 L .6412 .58007 L p .707 .577 .707 r
F P
0 g
s
.48923 .24273 m .48923 .74462 L .44531 .7474 L p .707 .577 .707 r
F P
0 g
s
.79382 .69039 m .79126 .7254 L .81478 .71799 L p .707 .577 .707 r
F P
0 g
s
.81478 .71799 m .81734 .68298 L .79382 .69039 L p .707 .577 .707 r
F P
0 g
s
.67153 .71595 m .67409 .68094 L .65255 .66997 L p .707 .577 .707 r
F P
0 g
s
.67409 .68094 m .67153 .71595 L .69928 .72409 L p .707 .577 .707 r
F P
0 g
s
.73062 .77025 m .732 .75282 L .70065 .74835 L p .707 .577 .707 r
F P
0 g
s
.732 .75282 m .73062 .77025 L .76223 .77057 L p .707 .577 .707 r
F P
0 g
s
.76223 .77057 m .76361 .75313 L .732 .75282 L p .707 .577 .707 r
F P
0 g
s
.69926 .76579 m .70065 .74835 L .67261 .74017 L p .707 .577 .707 r
F P
0 g
s
.70065 .74835 m .69926 .76579 L .73062 .77025 L p .707 .577 .707 r
F P
0 g
s
.76361 .75313 m .76223 .77057 L .79099 .7667 L p .707 .577 .707 r
F P
0 g
s
.79099 .7667 m .79237 .74926 L .76361 .75313 L p .707 .577 .707 r
F P
0 g
s
.83506 .59143 m .83271 .64527 L .83951 .63437 L p .707 .577 .707 r
F P
0 g
s
.83951 .63437 m .84186 .58052 L .83506 .59143 L p .707 .577 .707 r
F P
0 g
s
.6412 .58007 m .63885 .63391 L .65169 .64486 L p .707 .577 .707 r
F P
0 g
s
.65255 .66997 m .64999 .70498 L .67153 .71595 L p .707 .577 .707 r
F P
0 g
s
.67261 .74017 m .67123 .75761 L .69926 .76579 L p .707 .577 .707 r
F P
0 g
s
.81734 .68298 m .81478 .71799 L .8305 .70755 L p .707 .577 .707 r
F P
0 g
s
.8305 .70755 m .83306 .67254 L .81734 .68298 L p .707 .577 .707 r
F P
0 g
s
.64999 .70498 m .65255 .66997 L .63933 .65724 L p .707 .577 .707 r
F P
0 g
s
.63885 .63391 m .6412 .58007 L .63802 .56858 L p .707 .577 .707 r
F P
0 g
s
.67123 .75761 m .67261 .74017 L .65063 .72908 L p .707 .577 .707 r
F P
0 g
s
.79237 .74926 m .79099 .7667 L .81409 .75903 L p .707 .577 .707 r
F P
0 g
s
.81409 .75903 m .81547 .74159 L .79237 .74926 L p .707 .577 .707 r
F P
0 g
s
.65063 .72908 m .64925 .74652 L .67123 .75761 L p .707 .577 .707 r
F P
0 g
s
.63933 .65724 m .63677 .69225 L .64999 .70498 L p .707 .577 .707 r
F P
0 g
s
.63802 .56858 m .63567 .62242 L .63885 .63391 L p .707 .577 .707 r
F P
0 g
s
.64925 .74652 m .65063 .72908 L .63687 .71616 L p .707 .577 .707 r
F P
0 g
s
.84186 .58052 m .83951 .63437 L .83633 .62288 L p .707 .577 .707 r
F P
0 g
s
.83633 .62288 m .83868 .56903 L .84186 .58052 L p .707 .577 .707 r
F P
0 g
s
.81547 .74159 m .81409 .75903 L .82927 .7483 L p .707 .577 .707 r
F P
0 g
s
.82927 .7483 m .83065 .73087 L .81547 .74159 L p .707 .577 .707 r
F P
0 g
s
.83306 .67254 m .8305 .70755 L .83687 .6951 L p .707 .577 .707 r
F P
0 g
s
.83687 .6951 m .83943 .66009 L .83306 .67254 L p .707 .577 .707 r
F P
0 g
s
.63677 .69225 m .63933 .65724 L .63573 .64401 L p .707 .577 .707 r
F P
0 g
s
.63687 .71616 m .63549 .73359 L .64925 .74652 L p .707 .577 .707 r
F P
0 g
s
.63567 .62242 m .63802 .56858 L .64482 .55767 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63573 .64401 m .63317 .67902 L .63677 .69225 L p .707 .577 .707 r
F P
0 g
s
.63549 .73359 m .63687 .71616 L .63267 .70267 L p .707 .577 .707 r
F P
0 g
s
.83065 .73087 m .82927 .7483 L .83505 .73557 L p .707 .577 .707 r
F P
0 g
s
.83505 .73557 m .83643 .71814 L .83065 .73087 L p .707 .577 .707 r
F P
0 g
s
.64482 .55767 m .64247 .61152 L .63567 .62242 L p .707 .577 .707 r
F P
0 g
s
.83868 .56903 m .83633 .62288 L .82349 .61193 L p .707 .577 .707 r
F P
0 g
s
.82349 .61193 m .82584 .55809 L .83868 .56903 L p .707 .577 .707 r
F P
0 g
s
.83943 .66009 m .83687 .6951 L .83327 .68187 L p .707 .577 .707 r
F P
0 g
s
.83327 .68187 m .83583 .64686 L .83943 .66009 L p .707 .577 .707 r
F P
0 g
s
.63317 .67902 m .63573 .64401 L .64211 .63156 L p .707 .577 .707 r
F P
0 g
s
.63267 .70267 m .63129 .72011 L .63549 .73359 L p .707 .577 .707 r
F P
0 g
s
.38526 .61658 m .39072 .56066 L .35963 .55623 L p .707 .577 .707 r
F P
0 g
s
.39072 .56066 m .38526 .61658 L .41694 .61879 L p .707 .577 .707 r
F P
0 g
s
.41694 .61879 m .42239 .56287 L .39072 .56066 L p .707 .577 .707 r
F P
0 g
s
.64247 .61152 m .64482 .55767 L .66093 .54842 L p .707 .577 .707 r
F P
0 g
s
.42239 .56287 m .41694 .61879 L .44609 .61855 L p .707 .577 .707 r
F P
0 g
s
.44609 .61855 m .45154 .56263 L .42239 .56287 L p .707 .577 .707 r
F P
0 g
s
.35418 .61214 m .35963 .55623 L .33217 .54999 L p .707 .577 .707 r
F P
0 g
s
.35963 .55623 m .35418 .61214 L .38526 .61658 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64211 .63156 m .63955 .66658 L .63317 .67902 L p .707 .577 .707 r
F P
0 g
s
.45154 .56263 m .44609 .61855 L .46988 .6159 L p .707 .577 .707 r
F P
0 g
s
.46988 .6159 m .47533 .55998 L .45154 .56263 L p .707 .577 .707 r
F P
0 g
s
.63129 .72011 m .63267 .70267 L .63844 .68994 L p .707 .577 .707 r
F P
0 g
s
.38047 .67469 m .38636 .63747 L .35543 .63146 L p .707 .577 .707 r
F P
0 g
s
.38636 .63747 m .38047 .67469 L .41187 .67875 L p .707 .577 .707 r
F P
0 g
s
.41187 .67875 m .41776 .64153 L .38636 .63747 L p .707 .577 .707 r
F P
0 g
s
.33217 .54999 m .32672 .60591 L .35418 .61214 L p .707 .577 .707 r
F P
0 g
s
.83643 .71814 m .83505 .73557 L .83085 .72209 L p .707 .577 .707 r
F P
0 g
s
.83085 .72209 m .83223 .70465 L .83643 .71814 L p .707 .577 .707 r
F P
0 g
s
.82584 .55809 m .82349 .61193 L .80224 .60259 L p .707 .577 .707 r
F P
0 g
s
.80224 .60259 m .80458 .54875 L .82584 .55809 L p .707 .577 .707 r
F P
0 g
s
.32672 .60591 m .33217 .54999 L .31103 .54258 L p .707 .577 .707 r
F P
0 g
s
.66093 .54842 m .65858 .60226 L .64247 .61152 L p .707 .577 .707 r
F P
0 g
s
.83583 .64686 m .83327 .68187 L .82006 .66914 L p .707 .577 .707 r
F P
0 g
s
.82006 .66914 m .82262 .63413 L .83583 .64686 L p .707 .577 .707 r
F P
0 g
s
.41776 .64153 m .41187 .67875 L .44067 .68046 L p .707 .577 .707 r
F P
0 g
s
.44067 .68046 m .44656 .64324 L .41776 .64153 L p .707 .577 .707 r
F P
0 g
s
.34954 .66868 m .35543 .63146 L .32799 .62409 L p .707 .577 .707 r
F P
0 g
s
.35543 .63146 m .34954 .66868 L .38047 .67469 L p .707 .577 .707 r
F P
0 g
s
.63955 .66658 m .64211 .63156 L .65782 .62112 L p .707 .577 .707 r
F P
0 g
s
.63844 .68994 m .63706 .70738 L .63129 .72011 L p .707 .577 .707 r
F P
0 g
s
.65858 .60226 m .66093 .54842 L .68477 .54173 L p .707 .577 .707 r
F P
0 g
s
.32799 .62409 m .3221 .66131 L .34954 .66868 L p .707 .577 .707 r
F P
0 g
s
.37803 .71673 m .38118 .69813 L .35019 .69192 L p .707 .577 .707 r
F P
0 g
s
.38118 .69813 m .37803 .71673 L .4093 .72103 L p .707 .577 .707 r
F P
0 g
s
.4093 .72103 m .41246 .70243 L .38118 .69813 L p .707 .577 .707 r
F P
0 g
s
.31103 .54258 m .30558 .5985 L .32672 .60591 L p .707 .577 .707 r
F P
0 g
s
.35019 .69192 m .34704 .71052 L .37803 .71673 L p .707 .577 .707 r
F P
0 g
s
.44656 .64324 m .44067 .68046 L .46404 .67965 L p .707 .577 .707 r
F P
0 g
s
.46404 .67965 m .46993 .64243 L .44656 .64324 L p .707 .577 .707 r
F P
0 g
s
.34704 .71052 m .35019 .69192 L .32252 .6844 L p .707 .577 .707 r
F P
0 g
s
.41246 .70243 m .4093 .72103 L .4378 .723 L p .707 .577 .707 r
F P
0 g
s
.4378 .723 m .44096 .7044 L .41246 .70243 L p .707 .577 .707 r
F P
0 g
s
.47533 .55998 m .46988 .6159 L .48597 .61108 L p .707 .577 .707 r
F P
0 g
s
.48597 .61108 m .49142 .55516 L .47533 .55998 L p .707 .577 .707 r
F P
0 g
s
.3221 .66131 m .32799 .62409 L .30675 .61607 L p .707 .577 .707 r
F P
0 g
s
.65782 .62112 m .65526 .65613 L .63955 .66658 L p .707 .577 .707 r
F P
0 g
s
.32252 .6844 m .31936 .703 L .34704 .71052 L p .707 .577 .707 r
F P
0 g
s
.80458 .54875 m .80224 .60259 L .77465 .59578 L p .707 .577 .707 r
F P
0 g
s
.77465 .59578 m .777 .54194 L .80458 .54875 L p .707 .577 .707 r
F P
0 g
s
.30558 .5985 m .31103 .54258 L .29827 .5347 L p .707 .577 .707 r
F P
0 g
s
.63706 .70738 m .63844 .68994 L .65362 .67922 L p .707 .577 .707 r
F P
0 g
s
.30675 .61607 m .30086 .6533 L .3221 .66131 L p .707 .577 .707 r
F P
0 g
s
.68242 .59557 m .68477 .54173 L .71401 .53825 L p .707 .577 .707 r
F P
0 g
s
.68477 .54173 m .68242 .59557 L .65858 .60226 L p .707 .577 .707 r
F P
0 g
s
.83223 .70465 m .83085 .72209 L .81708 .70917 L p .707 .577 .707 r
F P
0 g
s
.81708 .70917 m .81847 .69173 L .83223 .70465 L p .707 .577 .707 r
F P
0 g
s
.82262 .63413 m .82006 .66914 L .79852 .65817 L p .707 .577 .707 r
F P
0 g
s
.79852 .65817 m .80108 .62316 L .82262 .63413 L p .707 .577 .707 r
F P
0 g
s
.65526 .65613 m .65782 .62112 L .68135 .61371 L p .707 .577 .707 r
F P
0 g
s
.31936 .703 m .32252 .6844 L .30088 .67631 L p .707 .577 .707 r
F P
0 g
s
.44096 .7044 m .4378 .723 L .46073 .72244 L p .707 .577 .707 r
F P
0 g
s
.46073 .72244 m .46389 .70384 L .44096 .7044 L p .707 .577 .707 r
F P
0 g
s
.65362 .67922 m .65224 .69666 L .63706 .70738 L p .707 .577 .707 r
F P
0 g
s
.30088 .67631 m .29772 .69492 L .31936 .703 L p .707 .577 .707 r
F P
0 g
s
.29827 .5347 m .29282 .59062 L .30558 .5985 L p .707 .577 .707 r
F P
0 g
s
.777 .54194 m .77465 .59578 L .74345 .59216 L p .707 .577 .707 r
F P
0 g
s
.74345 .59216 m .74579 .53832 L .777 .54194 L p .707 .577 .707 r
F P
0 g
s
.46993 .64243 m .46404 .67965 L .47971 .67641 L p .707 .577 .707 r
F P
0 g
s
.47971 .67641 m .4856 .63919 L .46993 .64243 L p .707 .577 .707 r
F P
0 g
s
.71166 .59209 m .71401 .53825 L .74579 .53832 L p .707 .577 .707 r
F P
0 g
s
.71401 .53825 m .71166 .59209 L .68242 .59557 L p .707 .577 .707 r
F P
0 g
s
.30086 .6533 m .30675 .61607 L .29376 .6082 L p .707 .577 .707 r
F P
0 g
s
.74579 .53832 m .74345 .59216 L .71166 .59209 L p .707 .577 .707 r
F P
0 g
s
.49142 .55516 m .48597 .61108 L .49278 .60457 L p .707 .577 .707 r
F P
0 g
s
.49278 .60457 m .49823 .54865 L .49142 .55516 L p .707 .577 .707 r
F P
0 g
s
.68135 .61371 m .67879 .64872 L .65526 .65613 L p .707 .577 .707 r
F P
0 g
s
.29376 .6082 m .28787 .64542 L .30086 .6533 L p .707 .577 .707 r
F P
0 g
s
.80108 .62316 m .79852 .65817 L .77076 .65003 L p .707 .577 .707 r
F P
0 g
s
.77076 .65003 m .77332 .61502 L .80108 .62316 L p .707 .577 .707 r
F P
0 g
s
.67879 .64872 m .68135 .61371 L .71038 .61005 L p .707 .577 .707 r
F P
0 g
s
.29282 .59062 m .29827 .5347 L .29515 .52714 L p .707 .577 .707 r
F P
0 g
s
.65224 .69666 m .65362 .67922 L .67672 .67155 L p .707 .577 .707 r
F P
0 g
s
.29772 .69492 m .30088 .67631 L .28738 .66845 L p .707 .577 .707 r
F P
0 g
s
.81847 .69173 m .81708 .70917 L .79511 .69807 L p .707 .577 .707 r
F P
0 g
s
.79511 .69807 m .79649 .68064 L .81847 .69173 L p .707 .577 .707 r
F P
0 g
s
.46389 .70384 m .46073 .72244 L .47585 .71942 L p .707 .577 .707 r
F P
0 g
s
.47585 .71942 m .47901 .70081 L .46389 .70384 L p .707 .577 .707 r
F P
0 g
s
.28738 .66845 m .28422 .68705 L .29772 .69492 L p .707 .577 .707 r
F P
0 g
s
.67672 .67155 m .67534 .68898 L .65224 .69666 L p .707 .577 .707 r
F P
0 g
s
.77332 .61502 m .77076 .65003 L .73951 .64551 L p .707 .577 .707 r
F P
0 g
s
.73951 .64551 m .74207 .6105 L .77332 .61502 L p .707 .577 .707 r
F P
0 g
s
.70782 .64506 m .71038 .61005 L .74207 .6105 L p .707 .577 .707 r
F P
0 g
s
.71038 .61005 m .70782 .64506 L .67879 .64872 L p .707 .577 .707 r
F P
0 g
s
.29515 .52714 m .2897 .58306 L .29282 .59062 L p .707 .577 .707 r
F P
0 g
s
.4856 .63919 m .47971 .67641 L .48613 .67104 L p .707 .577 .707 r
F P
0 g
s
.48613 .67104 m .49202 .63382 L .4856 .63919 L p .707 .577 .707 r
F P
0 g
s
.74207 .6105 m .73951 .64551 L .70782 .64506 L p .707 .577 .707 r
F P
0 g
s
.28787 .64542 m .29376 .6082 L .29031 .60124 L p .707 .577 .707 r
F P
0 g
s
.67534 .68898 m .67672 .67155 L .70549 .66768 L p .707 .577 .707 r
F P
0 g
s
.79649 .68064 m .79511 .69807 L .76707 .68989 L p .707 .577 .707 r
F P
0 g
s
.76707 .68989 m .76845 .67246 L .79649 .68064 L p .707 .577 .707 r
F P
0 g
s
.49823 .54865 m .49278 .60457 L .48966 .59701 L p .707 .577 .707 r
F P
0 g
s
.48966 .59701 m .49511 .54109 L .49823 .54865 L p .707 .577 .707 r
F P
0 g
s
.29031 .60124 m .28442 .63846 L .28787 .64542 L p .707 .577 .707 r
F P
0 g
s
.70549 .66768 m .70411 .68511 L .67534 .68898 L p .707 .577 .707 r
F P
0 g
s
.28422 .68705 m .28738 .66845 L .28335 .66158 L p .707 .577 .707 r
F P
0 g
s
.47901 .70081 m .47585 .71942 L .48169 .71421 L p .707 .577 .707 r
F P
0 g
s
.48169 .71421 m .48484 .69561 L .47901 .70081 L p .707 .577 .707 r
F P
0 g
s
.2897 .58306 m .29515 .52714 L .30197 .52063 L p .707 .577 .707 r
F P
0 g
s
.28335 .66158 m .28019 .68019 L .28422 .68705 L p .707 .577 .707 r
F P
0 g
s
.70411 .68511 m .70549 .66768 L .73709 .66799 L p .707 .577 .707 r
F P
0 g
s
.76845 .67246 m .76707 .68989 L .73571 .68543 L p .707 .577 .707 r
F P
0 g
s
.73571 .68543 m .73709 .66799 L .76845 .67246 L p .707 .577 .707 r
F P
0 g
s
.73709 .66799 m .73571 .68543 L .70411 .68511 L p .707 .577 .707 r
F P
0 g
s
.30197 .52063 m .29652 .57655 L .2897 .58306 L p .707 .577 .707 r
F P
0 g
s
.49202 .63382 m .48613 .67104 L .48268 .66408 L p .707 .577 .707 r
F P
0 g
s
.48268 .66408 m .48857 .62686 L .49202 .63382 L p .707 .577 .707 r
F P
0 g
s
.28442 .63846 m .29031 .60124 L .29674 .59587 L p .707 .577 .707 r
F P
0 g
s
.49511 .54109 m .48966 .59701 L .47691 .58913 L p .707 .577 .707 r
F P
0 g
s
.47691 .58913 m .48236 .53321 L .49511 .54109 L p .707 .577 .707 r
F P
0 g
s
.29674 .59587 m .29084 .6331 L .28442 .63846 L p .707 .577 .707 r
F P
0 g
s
.28019 .68019 m .28335 .66158 L .28918 .65638 L p .707 .577 .707 r
F P
0 g
s
.48484 .69561 m .48169 .71421 L .47765 .70734 L p .707 .577 .707 r
F P
0 g
s
.47765 .70734 m .48081 .68874 L .48484 .69561 L p .707 .577 .707 r
F P
0 g
s
.29652 .57655 m .30197 .52063 L .31806 .51581 L p .707 .577 .707 r
F P
0 g
s
.28918 .65638 m .28602 .67498 L .28019 .68019 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31806 .51581 m .31261 .57173 L .29652 .57655 L p .707 .577 .707 r
F P
0 g
s
.48857 .62686 m .48268 .66408 L .4697 .65621 L p .707 .577 .707 r
F P
0 g
s
.4697 .65621 m .47559 .61899 L .48857 .62686 L p .707 .577 .707 r
F P
0 g
s
.29084 .6331 m .29674 .59587 L .3124 .59263 L p .707 .577 .707 r
F P
0 g
s
.48236 .53321 m .47691 .58913 L .45576 .58172 L p .707 .577 .707 r
F P
0 g
s
.45576 .58172 m .46121 .5258 L .48236 .53321 L p .707 .577 .707 r
F P
0 g
s
.3124 .59263 m .30651 .62985 L .29084 .6331 L p .707 .577 .707 r
F P
0 g
s
.31261 .57173 m .31806 .51581 L .34184 .51316 L p .707 .577 .707 r
F P
0 g
s
.28602 .67498 m .28918 .65638 L .3043 .65335 L p .707 .577 .707 r
F P
0 g
s
.48081 .68874 m .47765 .70734 L .46416 .69948 L p .707 .577 .707 r
F P
0 g
s
.46416 .69948 m .46731 .68088 L .48081 .68874 L p .707 .577 .707 r
F P
0 g
s
.3043 .65335 m .30114 .67195 L .28602 .67498 L p .707 .577 .707 r
F P
0 g
s
.34184 .51316 m .33639 .56908 L .31261 .57173 L p .707 .577 .707 r
F P
0 g
s
.47559 .61899 m .4697 .65621 L .44845 .6482 L p .707 .577 .707 r
F P
0 g
s
.44845 .6482 m .45434 .61097 L .47559 .61899 L p .707 .577 .707 r
F P
0 g
s
.46121 .5258 m .45576 .58172 L .42831 .57548 L p .707 .577 .707 r
F P
0 g
s
.42831 .57548 m .43376 .51957 L .46121 .5258 L p .707 .577 .707 r
F P
0 g
s
.30651 .62985 m .3124 .59263 L .33578 .59182 L p .707 .577 .707 r
F P
0 g
s
.33639 .56908 m .34184 .51316 L .371 .51292 L p .707 .577 .707 r
F P
0 g
s
.33578 .59182 m .32989 .62905 L .30651 .62985 L p .707 .577 .707 r
F P
0 g
s
.30114 .67195 m .3043 .65335 L .32723 .65279 L p .707 .577 .707 r
F P
0 g
s
.46731 .68088 m .46416 .69948 L .44251 .6914 L p .707 .577 .707 r
F P
0 g
s
.44251 .6914 m .44567 .67279 L .46731 .68088 L p .707 .577 .707 r
F P
0 g
s
.43376 .51957 m .42831 .57548 L .39722 .57105 L p .707 .577 .707 r
F P
0 g
s
.39722 .57105 m .40267 .51513 L .43376 .51957 L p .707 .577 .707 r
F P
0 g
s
.36555 .56884 m .371 .51292 L .40267 .51513 L p .707 .577 .707 r
F P
0 g
s
.371 .51292 m .36555 .56884 L .33639 .56908 L p .707 .577 .707 r
F P
0 g
s
.32723 .65279 m .32408 .6714 L .30114 .67195 L p .707 .577 .707 r
F P
0 g
s
.40267 .51513 m .39722 .57105 L .36555 .56884 L p .707 .577 .707 r
F P
0 g
s
.45434 .61097 m .44845 .6482 L .42102 .64082 L p .707 .577 .707 r
F P
0 g
s
.42102 .64082 m .42691 .6036 L .45434 .61097 L p .707 .577 .707 r
F P
0 g
s
.32989 .62905 m .33578 .59182 L .36458 .59353 L p .707 .577 .707 r
F P
0 g
s
.36458 .59353 m .35869 .63075 L .32989 .62905 L p .707 .577 .707 r
F P
0 g
s
.42691 .6036 m .42102 .64082 L .39009 .63481 L p .707 .577 .707 r
F P
0 g
s
.39009 .63481 m .39598 .59759 L .42691 .6036 L p .707 .577 .707 r
F P
0 g
s
.32408 .6714 m .32723 .65279 L .35573 .65476 L p .707 .577 .707 r
F P
0 g
s
.44567 .67279 m .44251 .6914 L .41484 .68388 L p .707 .577 .707 r
F P
0 g
s
.41484 .68388 m .418 .66527 L .44567 .67279 L p .707 .577 .707 r
F P
0 g
s
.35869 .63075 m .36458 .59353 L .39598 .59759 L p .707 .577 .707 r
F P
0 g
s
.35573 .65476 m .35258 .67336 L .32408 .6714 L p .707 .577 .707 r
F P
0 g
s
.39598 .59759 m .39009 .63481 L .35869 .63075 L p .707 .577 .707 r
F P
0 g
s
.35258 .67336 m .35573 .65476 L .38701 .65906 L p .707 .577 .707 r
F P
0 g
s
.418 .66527 m .41484 .68388 L .38385 .67766 L p .707 .577 .707 r
F P
0 g
s
.38385 .67766 m .38701 .65906 L .418 .66527 L p .707 .577 .707 r
F P
0 g
s
.38701 .65906 m .38385 .67766 L .35258 .67336 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
O7oo8@00P7oo001fOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH9001g
Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
079oo`00L7oo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF1000KWoo001]Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH00000K7oo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Moo`80009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8006Moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P00Igoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001VOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005iooa0000EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol005Uoo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`<000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001U
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
3goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP002UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF009JEPH003moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000kOol005=oo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP000Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF1000=goo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
=7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000aOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00DWoo00<005YF0000
0eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYF001JEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF00000UYF1@0000=JEP00FUH0
1UYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0009
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001BOol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH0000^Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0059oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0P000eYF0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00005@000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008000YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF009J
EQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0004FUH00`00FUIJEP02FUH6000;Ool30004Ool60006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
02eoo`00DWoo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@001eYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000moo`D000Uoo`@0009JEP03001JEUYF00=J
EP06001JEUYF001JEP00;Goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH30002FUH0
0`00FUH00003000;Ool5000=Ool30005FUH01P00FUIJEP00FUH002eoo`00DWoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001UYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF001J
EP8000EJEP03001JEUYF00=JEPL000Aoo`D000Uoo`D0009JEP8000=JEP06001JEUYF001JEP00;Goo
0017Ool;00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00H005YF000005YF0005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJ
EP03FUH2000015YF001JEUYF0P00;Woo000oOol80004FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP020002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP03FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH0
0`00FUIJEP04FUH30002FUH2000^Ool003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P00;Woo000bOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20003
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF
00@005YFFUIJEP<002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP<002ioo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF008000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800005
FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01000FUIJEUYF0`00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH60002FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEP0002ioo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF00002@001UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0002ioo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF2P000UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF1P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1P001EYF00<0
05YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00`0000=JEP00FUH00UYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF0P0015YF00<005YF00000`001eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP00
00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP04001JEUYFFUH90002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004FUH20002FUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000
FUIJEUYF0P00;Woo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF000005YF00<000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF009JEPH000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00IJEP03001J
EUYF00AJEP04001JEUYFFUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH000020006FUH00`00FUIJEP03FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF1@0000=oo`0000000eYF00H005YFFUH005YF000^Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP03FUHJ0008Ool200001eYF001JEUYF001JEP0002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4`000eYF00@005YFFUIJEPL000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP06001JEUYFFUH005YF
0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF
1`000eYF00<005YFFUH01UYF00<005YFFUH0100047oo0P000UYF00<005YF0000;Woo000]Ool00`00
FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH015YF00<005YF00001`0000=JEP00FUH015YF
2@0015YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF0`0000EJEP00001JEP00
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@000ioo`05001JEP00FUH0000^Ool002eoo`03001J
EP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH60006FUH00`00FUIJEP06FUH00`00FUH000030002FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH01000FUH00000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002goo0`00;goo
000]Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF0P00
15YF00<005YF00000`001UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30006Ool200000eYF0000000_Ool002eoo`06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0`0015YF00@005YFFUIJ
EP8000AJEP03001JEUYF00T000IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP8000EJEP03001JEUYF009JEQ0000IJEP03
001JEUYF00EJEP<0009oo`8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEP0000@000=JEP80
00AJEP03001JEUYF00H000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP001EYF1@00
00=JEP0000000`002Woo10000UYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF0P00
;goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH200000eYF001JEP05FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP060007FUH40004FUH00`00
FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
0eYF00@005YFFUIJEP<000MJEP03001JEUYF00@000Yoo`@000EJEP03001JEUYF00=JEP8000=JEP80
02moo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF009JEP<00003FUH0
05YF00UJEP@00003FUH005YF00=JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP04001JEP000002FUH00`00FUIJEP05FUH00`00FUIJEP04FUHB0000
0eYF001JEP05FUH20002FUH2000_Ool002moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ800003FUH005YF00MJEP03001JEUYF00AJEPL0009JEP03001JEUYF00QJEP04001JEUYF
FUH20003FUH01@00FUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`001EYF00@005YF001JEP8002moo`00<Goo10000eYF00<005YFFUH015YF200015YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF0080031oo`00=Goo2P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00@0
05YFFUIJEQ00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH200000eYF001JEP02FUH00`00Oomoo`0^Ool0039oo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0P000eYF00<007ooOol0;Woo000_Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001o
ogoo02ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH02@001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP000000;goo000]Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000P001eYF1@000UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000goo0`00;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH015YF4`001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000P001eYF00<005YFFUH00UYF1@001UYF1P000eYF00<005YFFUH01EYF
00<005YF00000`001Woo0P00;goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH01@000UYF1P000eYF00<005YFFUH00UYF1@002Woo0P00;goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
00IJEP03001JEUYF009JEP03001JEUYF008000=ooa0000moo`8002moo`00;Goo00@005YFFUH000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP04001J
EP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
009JEP05001JEUYFFUH0000POol4000_Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEPl00003FUH005YF00MJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP80009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEP007Woo0P000UYF0P00
;goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF00001EYF0`001EYF00@005YFFUH001eoo`04001JEUYFFUH2000`Ool002ioo`03
001JEP0000=JEP04001JEUYFFUH60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020006
FUH00`00FUH00003000015YF001JEUYF0P006Woo0`000eYF0P00<7oo000^Ool00`00FUH00002FUH5
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH9000<FUH<0006FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH6000HOol20002FUH01@00
FUIJEUYF0000<Goo000^Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF200015YF00<005YFFUH01EYF00<005YFFUH01P00
25YF00<005YFFUH02UYF00<005YFFUH02EYF2@001eYF00<005YFFUH015YF00D005YFFUH007oo0080
00=JEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP04001JEUYF000bOol002ioo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Ioo`8000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPD0009JEP03001JEUYF00AJEP04001JEUYF0003Ool200000eYF001J
EP07FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH3000cOol002moo`80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ4000Eoo`8000AJEP03001JEUYF
00@000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00@000EJEP04001JEUYF0005Ool30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000eOol0035oob0000AJEP03001JEUYF00EJEP03001JEUYF00L000AJ
EP@000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP8000=JEP04001JEUYF0006Ool60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00=goo0010Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH000000eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<00004FUH005YFFUH70006FUH5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000>Goo000hOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH00000FUH00P0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P000UYF0P000eYF1`0000=JEP00FUH00UYF1@000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1@00>goo000cOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH010000UYF0P000Woo4000@7oo000`Ool3
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000MJ
EP03001JEUYF00=JEPD0059oo`00;Woo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF7`0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000MJ
EP03001JEUYF009JEP03001JEUYF0080059oo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF20001goo2@000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
001BOol002ioo`03001JEP0000=JEP04001JEUYFFUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`000eYF00<0
05YFFUH00P00DGoo000^Ool00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH00`00Oomoo`1?
Ool002ioo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH50002Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo0P0000=JEP00Ool0D7oo000^Ool30003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008Ool00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030008FUH01000FUH0000027oo0P00DGoo000^Ool0
0`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
000@Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH3000:Ool3001@Ool002moob40
01]oo`800003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000aoo`800003FUH007oo04moo`00
KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH00UYF0P001eYF00<005YF00000P0037oo0P0000AJEP00FUH0051oo`00L7oo0`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`0015YF
1P003Woo00@005YFFUIJEP80055oo`00Lgoo100000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF3`004goo00<005YFFUH00UYF0P00DGoo001gOol70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUHF000EOol30004FUH00`00Oomoo`1@Ool007iooaX0015oo`D001=oo`80
009JEP05001JEUYFFUH0001COol0099oo`03001JEP0001Eoo`<0015oo`<000EJEP03001JEP0005Ao
o`00TWoo00<005YF00009Goo100000=JEP00FUH01EYF0P00EGoo002COol2000POol50005FUH00`00
FUIJEP04FUH00`00Oomoo`1DOol009=oo`04001JEP00000JOol40002FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00Egoo002COol20002FUH3000@Ool70006FUH00`00FUIJEP06FUH01000FUH00000FGoo
002COol20002FUH00`00FUIJEP0@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001KOol009Ao
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH2001NOol009Eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00002001POol009Ioo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPH006=oo`00V7oo0`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@00JGoo002KOol@001b
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60684 .75534 m .59803 .70156 L .56714 .70382 L p .707 .577 .707 r
F P
0 g
s
.59803 .70156 m .60684 .75534 L .63826 .74968 L p .707 .577 .707 r
F P
0 g
s
.63826 .74968 m .62945 .69589 L .59803 .70156 L p .707 .577 .707 r
F P
0 g
s
.62945 .69589 m .63826 .74968 L .66715 .74118 L p .707 .577 .707 r
F P
0 g
s
.66715 .74118 m .65835 .68739 L .62945 .69589 L p .707 .577 .707 r
F P
0 g
s
.57595 .75761 m .56714 .70382 L .53982 .70248 L p .707 .577 .707 r
F P
0 g
s
.56714 .70382 m .57595 .75761 L .60684 .75534 L p .707 .577 .707 r
F P
0 g
s
.65835 .68739 m .66715 .74118 L .69068 .73067 L p .707 .577 .707 r
F P
0 g
s
.69068 .73067 m .68188 .67688 L .65835 .68739 L p .707 .577 .707 r
F P
0 g
s
.54863 .75626 m .53982 .70248 L .51874 .69764 L p .707 .577 .707 r
F P
0 g
s
.53982 .70248 m .54863 .75626 L .57595 .75761 L p .707 .577 .707 r
F P
0 g
s
.61829 .81867 m .6088 .7841 L .5784 .78897 L p .707 .577 .707 r
F P
0 g
s
.6088 .7841 m .61829 .81867 L .64905 .80998 L p .707 .577 .707 r
F P
0 g
s
.64905 .80998 m .63955 .77541 L .6088 .7841 L p .707 .577 .707 r
F P
0 g
s
.63955 .77541 m .64905 .80998 L .67716 .79831 L p .707 .577 .707 r
F P
0 g
s
.67716 .79831 m .66766 .76374 L .63955 .77541 L p .707 .577 .707 r
F P
0 g
s
.68188 .67688 m .69068 .73067 L .70655 .71917 L p .707 .577 .707 r
F P
0 g
s
.70655 .71917 m .69774 .66539 L .68188 .67688 L p .707 .577 .707 r
F P
0 g
s
.5879 .82354 m .5784 .78897 L .55135 .78954 L p .707 .577 .707 r
F P
0 g
s
.5784 .78897 m .5879 .82354 L .61829 .81867 L p .707 .577 .707 r
F P
0 g
s
.66766 .76374 m .67716 .79831 L .69987 .78482 L p .707 .577 .707 r
F P
0 g
s
.69987 .78482 m .69037 .75025 L .66766 .76374 L p .707 .577 .707 r
F P
0 g
s
.51874 .69764 m .52755 .75143 L .54863 .75626 L p .707 .577 .707 r
F P
0 g
s
.52755 .75143 m .51874 .69764 L .50596 .6898 L p .707 .577 .707 r
F P
0 g
s
.62837 .86056 m .62327 .84346 L .59286 .84915 L p .707 .577 .707 r
F P
0 g
s
.62327 .84346 m .62837 .86056 L .65885 .85099 L p .707 .577 .707 r
F P
0 g
s
.65885 .85099 m .65375 .83388 L .62327 .84346 L p .707 .577 .707 r
F P
0 g
s
.55135 .78954 m .56084 .82411 L .5879 .82354 L p .707 .577 .707 r
F P
0 g
s
.65375 .83388 m .65885 .85099 L .68641 .83847 L p .707 .577 .707 r
F P
0 g
s
.68641 .83847 m .68131 .82137 L .65375 .83388 L p .707 .577 .707 r
F P
0 g
s
.56084 .82411 m .55135 .78954 L .53028 .78575 L p .707 .577 .707 r
F P
0 g
s
.69037 .75025 m .69987 .78482 L .71496 .77081 L p .707 .577 .707 r
F P
0 g
s
.71496 .77081 m .70546 .73624 L .69037 .75025 L p .707 .577 .707 r
F P
0 g
s
.59286 .84915 m .59796 .86625 L .62837 .86056 L p .707 .577 .707 r
F P
0 g
s
.69774 .66539 m .70655 .71917 L .71319 .70783 L p .707 .577 .707 r
F P
0 g
s
.71319 .70783 m .70438 .65404 L .69774 .66539 L p .707 .577 .707 r
F P
0 g
s
.59796 .86625 m .59286 .84915 L .56549 .8504 L p .707 .577 .707 r
F P
0 g
s
.68131 .82137 m .68641 .83847 L .70835 .82424 L p .707 .577 .707 r
F P
0 g
s
.70835 .82424 m .70325 .80713 L .68131 .82137 L p .707 .577 .707 r
F P
0 g
s
.56549 .8504 m .57059 .86751 L .59796 .86625 L p .707 .577 .707 r
F P
0 g
s
.53028 .78575 m .53978 .82032 L .56084 .82411 L p .707 .577 .707 r
F P
0 g
s
.50596 .6898 m .51477 .74358 L .52755 .75143 L p .707 .577 .707 r
F P
0 g
s
.57059 .86751 m .56549 .8504 L .54385 .8471 L p .707 .577 .707 r
F P
0 g
s
.51477 .74358 m .50596 .6898 L .50273 .67971 L p .707 .577 .707 r
F P
0 g
s
.53978 .82032 m .53028 .78575 L .51726 .77798 L p .707 .577 .707 r
F P
0 g
s
.70325 .80713 m .70835 .82424 L .72253 .80968 L p .707 .577 .707 r
F P
0 g
s
.72253 .80968 m .71744 .79257 L .70325 .80713 L p .707 .577 .707 r
F P
0 g
s
.70546 .73624 m .71496 .77081 L .72095 .75767 L p .707 .577 .707 r
F P
0 g
s
.72095 .75767 m .71145 .7231 L .70546 .73624 L p .707 .577 .707 r
F P
0 g
s
.54385 .8471 m .54894 .8642 L .57059 .86751 L p .707 .577 .707 r
F P
0 g
s
.70438 .65404 m .71319 .70783 L .70996 .69774 L p .707 .577 .707 r
F P
0 g
s
.70996 .69774 m .70116 .64395 L .70438 .65404 L p .707 .577 .707 r
F P
0 g
s
.51726 .77798 m .52676 .81255 L .53978 .82032 L p .707 .577 .707 r
F P
0 g
s
.50273 .67971 m .51154 .73349 L .51477 .74358 L p .707 .577 .707 r
F P
0 g
s
.54894 .8642 m .54385 .8471 L .53004 .83955 L p .707 .577 .707 r
F P
0 g
s
.47812 .82147 m .47812 .31959 L .43513 .3159 L p .707 .577 .707 r
F P
0 g
s
.52676 .81255 m .51726 .77798 L .51357 .76698 L p .707 .578 .707 r
F P
0 g
s
.51154 .73349 m .50273 .67971 L .50938 .66836 L p .707 .577 .707 r
F P
0 g
s
.51357 .76698 m .52307 .80155 L .52676 .81255 L p .707 .578 .707 r
F P
0 g
s
.50938 .66836 m .51819 .72215 L .51154 .73349 L p .707 .577 .707 r
F P
0 g
s
.52307 .80155 m .51357 .76698 L .51956 .75384 L p .707 .577 .707 r
F P
0 g
s
.51819 .72215 m .50938 .66836 L .52524 .65687 L p .707 .577 .707 r
F P
0 g
s
.47812 .31959 m .47812 .82147 L .52324 .82142 L p .707 .577 .707 r
F P
0 g
s
.51956 .75384 m .52906 .78841 L .52307 .80155 L p .707 .577 .707 r
F P
0 g
s
.52524 .65687 m .53405 .71066 L .51819 .72215 L p .707 .577 .707 r
F P
0 g
s
.52906 .78841 m .51956 .75384 L .53465 .73983 L p .707 .577 .707 r
F P
0 g
s
.52324 .82142 m .52324 .31953 L .47812 .31959 L p .707 .577 .707 r
F P
0 g
s
.53004 .83955 m .53513 .85666 L .54894 .8642 L p .707 .577 .707 r
F P
0 g
s
.53513 .85666 m .53004 .83955 L .52542 .82851 L p .707 .577 .707 r
F P
0 g
s
.52542 .82851 m .53052 .84561 L .53513 .85666 L p .707 .577 .707 r
F P
0 g
s
.53052 .84561 m .52542 .82851 L .53045 .81505 L p .707 .577 .707 r
F P
0 g
s
.53405 .71066 m .52524 .65687 L .54877 .64636 L p .707 .577 .707 r
F P
0 g
s
.53045 .81505 m .53555 .83215 L .53052 .84561 L p .707 .577 .707 r
F P
0 g
s
.53465 .73983 m .54415 .7744 L .52906 .78841 L p .707 .577 .707 r
F P
0 g
s
.55758 .70014 m .54877 .64636 L .57766 .63785 L p .707 .577 .707 r
F P
0 g
s
.54877 .64636 m .55758 .70014 L .53405 .71066 L p .707 .577 .707 r
F P
0 g
s
.53555 .83215 m .53045 .81505 L .54463 .80048 L p .707 .577 .707 r
F P
0 g
s
.54415 .7744 m .53465 .73983 L .55736 .72633 L p .707 .577 .707 r
F P
0 g
s
.54463 .80048 m .54973 .81759 L .53555 .83215 L p .707 .577 .707 r
F P
0 g
s
.55736 .72633 m .56686 .7609 L .54415 .7744 L p .707 .577 .707 r
F P
0 g
s
.56686 .7609 m .55736 .72633 L .58547 .71467 L p .707 .577 .707 r
F P
0 g
s
.54973 .81759 m .54463 .80048 L .56658 .78625 L p .707 .577 .707 r
F P
0 g
s
.56658 .78625 m .57167 .80335 L .54973 .81759 L p .707 .577 .707 r
F P
0 g
s
.52324 .31953 m .52324 .82142 L .5661 .81762 L p .707 .577 .707 r
F P
0 g
s
.57766 .63785 m .58647 .69164 L .55758 .70014 L p .707 .577 .707 r
F P
0 g
s
.5661 .81762 m .5661 .31573 L .52324 .31953 L p .707 .577 .707 r
F P
0 g
s
.71744 .79257 m .72253 .80968 L .72756 .79621 L p .707 .577 .707 r
F P
0 g
s
.72756 .79621 m .72246 .77911 L .71744 .79257 L p .707 .577 .707 r
F P
0 g
s
.71145 .7231 m .72095 .75767 L .71725 .74667 L p .707 .578 .707 r
F P
0 g
s
.71725 .74667 m .70776 .7121 L .71145 .7231 L p .707 .578 .707 r
F P
0 g
s
.43513 .81779 m .43513 .3159 L .39849 .30883 L p .707 .577 .707 r
F P
0 g
s
.43513 .3159 m .43513 .81779 L .47812 .82147 L p .707 .577 .707 r
F P
0 g
s
.58647 .69164 m .57766 .63785 L .60909 .63219 L p .707 .577 .707 r
F P
0 g
s
.60909 .63219 m .6179 .68598 L .58647 .69164 L p .707 .577 .707 r
F P
0 g
s
.59497 .74924 m .58547 .71467 L .61623 .70598 L p .707 .577 .707 r
F P
0 g
s
.58547 .71467 m .59497 .74924 L .56686 .7609 L p .707 .577 .707 r
F P
0 g
s
.61623 .70598 m .62572 .74055 L .59497 .74924 L p .707 .577 .707 r
F P
0 g
s
.57167 .80335 m .56658 .78625 L .59414 .77373 L p .707 .577 .707 r
F P
0 g
s
.59414 .77373 m .59923 .79084 L .57167 .80335 L p .707 .577 .707 r
F P
0 g
s
.59923 .79084 m .59414 .77373 L .62461 .76416 L p .707 .577 .707 r
F P
0 g
s
.62461 .76416 m .62971 .78126 L .59923 .79084 L p .707 .577 .707 r
F P
0 g
s
.5661 .31573 m .5661 .81762 L .60248 .81046 L p .707 .577 .707 r
F P
0 g
s
.60248 .81046 m .60248 .30857 L .5661 .31573 L p .707 .577 .707 r
F P
0 g
s
.70116 .64395 m .70996 .69774 L .69719 .68989 L p .707 .577 .707 r
F P
0 g
s
.69719 .68989 m .68838 .63611 L .70116 .64395 L p .707 .577 .707 r
F P
0 g
s
.25876 .70008 m .25494 .64293 L .22374 .64419 L p .707 .577 .707 r
F P
0 g
s
.25494 .64293 m .25876 .70008 L .29048 .69759 L p .707 .577 .707 r
F P
0 g
s
.29048 .69759 m .28666 .64044 L .25494 .64293 L p .707 .577 .707 r
F P
0 g
s
.28666 .64044 m .29048 .69759 L .3196 .6941 L p .707 .577 .707 r
F P
0 g
s
.3196 .6941 m .31578 .63695 L .28666 .64044 L p .707 .577 .707 r
F P
0 g
s
.72246 .77911 m .72756 .79621 L .72294 .78517 L p .707 .577 .707 r
F P
0 g
s
.72294 .78517 m .71785 .76807 L .72246 .77911 L p .707 .577 .707 r
F P
0 g
s
.22755 .70134 m .22374 .64419 L .19609 .64409 L p .707 .577 .707 r
F P
0 g
s
.22374 .64419 m .22755 .70134 L .25876 .70008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26526 .75359 m .26108 .71537 L .22984 .71861 L p .707 .577 .707 r
F P
0 g
s
.26108 .71537 m .26526 .75359 L .29678 .75001 L p .707 .577 .707 r
F P
0 g
s
.29678 .75001 m .29259 .71179 L .26108 .71537 L p .707 .577 .707 r
F P
0 g
s
.70776 .7121 m .71725 .74667 L .70424 .7389 L p .707 .577 .707 r
F P
0 g
s
.70424 .7389 m .69474 .70433 L .70776 .7121 L p .707 .577 .707 r
F P
0 g
s
.39849 .81072 m .39849 .30883 L .37179 .29907 L p .707 .577 .707 r
F P
0 g
s
.39849 .30883 m .39849 .81072 L .43513 .81779 L p .707 .577 .707 r
F P
0 g
s
.22984 .71861 m .23403 .75683 L .26526 .75359 L p .707 .577 .707 r
F P
0 g
s
.19609 .64409 m .19991 .70125 L .22755 .70134 L p .707 .577 .707 r
F P
0 g
s
.63998 .62992 m .64878 .68371 L .6179 .68598 L p .707 .577 .707 r
F P
0 g
s
.6179 .68598 m .60909 .63219 L .63998 .62992 L p .707 .577 .707 r
F P
0 g
s
.62572 .74055 m .61623 .70598 L .64662 .70111 L p .707 .577 .707 r
F P
0 g
s
.62971 .78126 m .62461 .76416 L .65502 .75847 L p .707 .577 .707 r
F P
0 g
s
.60248 .30857 m .60248 .81046 L .62883 .80062 L p .707 .577 .707 r
F P
0 g
s
.64662 .70111 m .65612 .73568 L .62572 .74055 L p .707 .577 .707 r
F P
0 g
s
.62883 .80062 m .62883 .29874 L .60248 .30857 L p .707 .577 .707 r
F P
0 g
s
.31578 .63695 m .3196 .6941 L .34328 .68997 L p .707 .577 .707 r
F P
0 g
s
.34328 .68997 m .33946 .63281 L .31578 .63695 L p .707 .577 .707 r
F P
0 g
s
.29259 .71179 m .29678 .75001 L .32549 .74645 L p .707 .577 .707 r
F P
0 g
s
.32549 .74645 m .3213 .70823 L .29259 .71179 L p .707 .577 .707 r
F P
0 g
s
.68838 .63611 m .69719 .68989 L .6761 .68506 L p .707 .577 .707 r
F P
0 g
s
.6761 .68506 m .6673 .63127 L .68838 .63611 L p .707 .577 .707 r
F P
0 g
s
.27142 .79622 m .26915 .77712 L .23779 .78075 L p .707 .577 .707 r
F P
0 g
s
.26915 .77712 m .27142 .79622 L .30276 .79238 L p .707 .577 .707 r
F P
0 g
s
.30276 .79238 m .30049 .77329 L .26915 .77712 L p .707 .577 .707 r
F P
0 g
s
.23403 .75683 m .22984 .71861 L .20195 .72119 L p .707 .577 .707 r
F P
0 g
s
.23779 .78075 m .24006 .79985 L .27142 .79622 L p .707 .577 .707 r
F P
0 g
s
.20195 .72119 m .20614 .75941 L .23403 .75683 L p .707 .577 .707 r
F P
0 g
s
.19991 .70125 m .19609 .64409 L .17472 .64265 L p .707 .577 .707 r
F P
0 g
s
.24006 .79985 m .23779 .78075 L .20946 .78383 L p .707 .577 .707 r
F P
0 g
s
.30049 .77329 m .30276 .79238 L .331 .78872 L p .707 .577 .707 r
F P
0 g
s
.331 .78872 m .32873 .76963 L .30049 .77329 L p .707 .577 .707 r
F P
0 g
s
.20946 .78383 m .21173 .80292 L .24006 .79985 L p .707 .577 .707 r
F P
0 g
s
.17472 .64265 m .17854 .6998 L .19991 .70125 L p .707 .577 .707 r
F P
0 g
s
.3213 .70823 m .32549 .74645 L .34859 .74324 L p .707 .577 .707 r
F P
0 g
s
.34859 .74324 m .3444 .70502 L .3213 .70823 L p .707 .577 .707 r
F P
0 g
s
.20614 .75941 m .20195 .72119 L .18013 .72286 L p .707 .577 .707 r
F P
0 g
s
.18013 .72286 m .18431 .76108 L .20614 .75941 L p .707 .577 .707 r
F P
0 g
s
.71785 .76807 m .72294 .78517 L .70914 .77763 L p .707 .577 .707 r
F P
0 g
s
.70914 .77763 m .70404 .76052 L .71785 .76807 L p .707 .577 .707 r
F P
0 g
s
.33946 .63281 m .34328 .68997 L .35919 .68559 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .35538 .62843 L .33946 .63281 L p .707 .577 .707 r
F P
0 g
s
.21173 .80292 m .20946 .78383 L .18695 .78604 L p .707 .577 .707 r
F P
0 g
s
.32873 .76963 m .331 .78872 L .35339 .78559 L p .707 .577 .707 r
F P
0 g
s
.35339 .78559 m .35111 .76649 L .32873 .76963 L p .707 .577 .707 r
F P
0 g
s
.18695 .78604 m .18923 .80513 L .21173 .80292 L p .707 .577 .707 r
F P
0 g
s
.69474 .70433 m .70424 .7389 L .68317 .73511 L p .707 .577 .707 r
F P
0 g
s
.68317 .73511 m .67367 .70054 L .69474 .70433 L p .707 .577 .707 r
F P
0 g
s
.6673 .63127 m .6761 .68506 L .64878 .68371 L p .707 .577 .707 r
F P
0 g
s
.64878 .68371 m .63998 .62992 L .6673 .63127 L p .707 .577 .707 r
F P
0 g
s
.17854 .6998 m .17472 .64265 L .16171 .63999 L p .707 .577 .707 r
F P
0 g
s
.36545 .7642 m .36772 .78329 L .3726 .78206 L p .707 .577 .707 r
F P
0 g
s
.3726 .78206 m .37032 .76296 L .36545 .7642 L p .707 .577 .707 r
F P
0 g
s
.36772 .78329 m .36545 .7642 L .35111 .76649 L p .707 .577 .707 r
F P
0 g
s
.37032 .76296 m .3726 .78206 L .36754 .782 L p .707 .577 .707 r
F P
0 g
s
.37179 .80095 m .37179 .29907 L .35764 .28757 L p .707 .577 .707 r
F P
0 g
s
.37179 .29907 m .37179 .80095 L .39849 .81072 L p .707 .577 .707 r
F P
0 g
s
.65502 .75847 m .66012 .77557 L .62971 .78126 L p .707 .577 .707 r
F P
0 g
s
.62883 .29874 m .62883 .80062 L .64257 .78909 L p .707 .577 .707 r
F P
0 g
s
.64257 .78909 m .64257 .2872 L .62883 .29874 L p .707 .577 .707 r
F P
0 g
s
.3444 .70502 m .34859 .74324 L .36381 .74071 L p .707 .577 .707 r
F P
0 g
s
.36381 .74071 m .35962 .70249 L .3444 .70502 L p .707 .577 .707 r
F P
0 g
s
.16171 .63999 m .16553 .69715 L .17854 .6998 L p .707 .577 .707 r
F P
0 g
s
.18431 .76108 m .18013 .72286 L .16651 .72346 L p .707 .577 .707 r
F P
0 g
s
.16651 .72346 m .17069 .76168 L .18431 .76108 L p .707 .577 .707 r
F P
0 g
s
.18923 .80513 m .18695 .78604 L .17246 .78717 L p .707 .577 .707 r
F P
0 g
s
.35111 .76649 m .35339 .78559 L .36772 .78329 L p .707 .577 .707 r
F P
0 g
s
.17246 .78717 m .17474 .80627 L .18923 .80513 L p .707 .577 .707 r
F P
0 g
s
.70404 .76052 m .70914 .77763 L .68749 .77432 L p .707 .577 .707 r
F P
0 g
s
.68749 .77432 m .68239 .75721 L .70404 .76052 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35742 .27546 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35538 .62843 m .35822 .67104 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.36579 .68139 m .36197 .62424 L .35538 .62843 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .36579 .68139 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35822 .67104 m .35919 .68559 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35859 .62064 m .36241 .67779 L .3494 .67514 L p .707 .577 .707 r
F P
0 g
s
.3494 .67514 m .34558 .61798 L .35859 .62064 L p .707 .577 .707 r
F P
0 g
s
.35962 .70249 m .36381 .74071 L .36967 .7391 L p .707 .577 .707 r
F P
0 g
s
.36967 .7391 m .36548 .70088 L .35962 .70249 L p .707 .577 .707 r
F P
0 g
s
.3614 .70035 m .36559 .73857 L .35197 .73917 L p .707 .577 .707 r
F P
0 g
s
.35197 .73917 m .34778 .70095 L .3614 .70035 L p .707 .577 .707 r
F P
0 g
s
.36527 .76291 m .36754 .782 L .35305 .78314 L p .707 .577 .707 r
F P
0 g
s
.35305 .78314 m .35078 .76405 L .36527 .76291 L p .707 .577 .707 r
F P
0 g
s
.35764 .78946 m .35764 .39217 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35764 .39217 m .35764 .28757 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.67367 .70054 m .68317 .73511 L .65612 .73568 L p .707 .577 .707 r
F P
0 g
s
.65612 .73568 m .64662 .70111 L .67367 .70054 L p .707 .577 .707 r
F P
0 g
s
.16553 .69715 m .16171 .63999 L .15834 .63639 L p .707 .577 .707 r
F P
0 g
s
.15834 .63639 m .16215 .69354 L .16553 .69715 L p .707 .577 .707 r
F P
0 g
s
.17069 .76168 m .16651 .72346 L .16243 .72293 L p .707 .577 .707 r
F P
0 g
s
.68239 .75721 m .68749 .77432 L .66012 .77557 L p .707 .577 .707 r
F P
0 g
s
.66012 .77557 m .65502 .75847 L .68239 .75721 L p .707 .577 .707 r
F P
0 g
s
.16243 .72293 m .16661 .76115 L .17069 .76168 L p .707 .577 .707 r
F P
0 g
s
.17474 .80627 m .17246 .78717 L .16741 .78712 L p .707 .577 .707 r
F P
0 g
s
.16741 .78712 m .16968 .80621 L .17474 .80627 L p .707 .577 .707 r
F P
0 g
s
.36197 .62424 m .36579 .68139 L .36241 .67779 L p .707 .577 .707 r
F P
0 g
s
.36241 .67779 m .35859 .62064 L .36197 .62424 L p .707 .577 .707 r
F P
0 g
s
.36548 .70088 m .36967 .7391 L .36559 .73857 L p .707 .577 .707 r
F P
0 g
s
.36559 .73857 m .3614 .70035 L .36548 .70088 L p .707 .577 .707 r
F P
0 g
s
.36754 .782 m .36527 .76291 L .37032 .76296 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35764 .78946 L .37179 .80095 L p .707 .577 .707 r
F P
0 g
s
.64257 .2872 m .64257 .78909 L .64236 .77698 L p .708 .578 .707 r
F P
0 g
s
.64236 .77698 m .64236 .27509 L .64257 .2872 L p .708 .578 .707 r
F P
0 g
s
.16215 .69354 m .15834 .63639 L .16493 .6322 L p .707 .577 .707 r
F P
0 g
s
.16493 .6322 m .16875 .68935 L .16215 .69354 L p .707 .577 .707 r
F P
0 g
s
.16661 .76115 m .16243 .72293 L .16828 .72132 L p .707 .577 .707 r
F P
0 g
s
.16828 .72132 m .17247 .75953 L .16661 .76115 L p .707 .577 .707 r
F P
0 g
s
.16968 .80621 m .16741 .78712 L .17229 .78589 L p .707 .577 .707 r
F P
0 g
s
.17229 .78589 m .17456 .80498 L .16968 .80621 L p .707 .577 .707 r
F P
0 g
s
.35742 .27546 m .35742 .77735 L .35764 .78946 L p .708 .578 .707 r
F P
0 g
s
.35742 .77735 m .35742 .27546 L .37116 .26392 L p .707 .577 .707 r
F P
0 g
s
.64236 .27509 m .64236 .77698 L .62821 .76548 L p .707 .577 .707 r
F P
0 g
s
.62821 .76548 m .62821 .26359 L .64236 .27509 L p .707 .577 .707 r
F P
0 g
s
.16875 .68935 m .16493 .6322 L .18084 .62782 L p .707 .577 .707 r
F P
0 g
s
.18084 .62782 m .18466 .68497 L .16875 .68935 L p .707 .577 .707 r
F P
0 g
s
.17247 .75953 m .16828 .72132 L .18351 .71878 L p .707 .577 .707 r
F P
0 g
s
.18351 .71878 m .18769 .757 L .17247 .75953 L p .707 .577 .707 r
F P
0 g
s
.17456 .80498 m .17229 .78589 L .18662 .78359 L p .707 .577 .707 r
F P
0 g
s
.18662 .78359 m .18889 .80268 L .17456 .80498 L p .707 .577 .707 r
F P
0 g
s
.34558 .61798 m .3494 .67514 L .32803 .67369 L p .707 .577 .707 r
F P
0 g
s
.32803 .67369 m .32421 .61654 L .34558 .61798 L p .707 .577 .707 r
F P
0 g
s
.18466 .68497 m .18084 .62782 L .20452 .62368 L p .707 .577 .707 r
F P
0 g
s
.34778 .70095 m .35197 .73917 L .33014 .74084 L p .707 .577 .707 r
F P
0 g
s
.33014 .74084 m .32595 .70262 L .34778 .70095 L p .707 .577 .707 r
F P
0 g
s
.20452 .62368 m .20834 .68083 L .18466 .68497 L p .707 .577 .707 r
F P
0 g
s
.37116 .26392 m .37116 .76581 L .35742 .77735 L p .707 .577 .707 r
F P
0 g
s
.37116 .76581 m .37116 .26392 L .39752 .25409 L p .707 .577 .707 r
F P
0 g
s
.62821 .26359 m .62821 .76548 L .60151 .75572 L p .707 .577 .707 r
F P
0 g
s
.60151 .75572 m .60151 .25383 L .62821 .26359 L p .707 .577 .707 r
F P
0 g
s
.18769 .757 m .18351 .71878 L .2066 .71558 L p .707 .577 .707 r
F P
0 g
s
.2066 .71558 m .21079 .7538 L .18769 .757 L p .707 .577 .707 r
F P
0 g
s
.32421 .61654 m .32803 .67369 L .30039 .67359 L p .707 .577 .707 r
F P
0 g
s
.30039 .67359 m .29657 .61644 L .32421 .61654 L p .707 .577 .707 r
F P
0 g
s
.18889 .80268 m .18662 .78359 L .209 .78046 L p .707 .577 .707 r
F P
0 g
s
.35078 .76405 m .35305 .78314 L .33054 .78535 L p .707 .577 .707 r
F P
0 g
s
.33054 .78535 m .32827 .76626 L .35078 .76405 L p .707 .577 .707 r
F P
0 g
s
.209 .78046 m .21127 .79955 L .18889 .80268 L p .707 .577 .707 r
F P
0 g
s
.20834 .68083 m .20452 .62368 L .23364 .62019 L p .707 .577 .707 r
F P
0 g
s
.23364 .62019 m .23746 .67735 L .20834 .68083 L p .707 .577 .707 r
F P
0 g
s
.32595 .70262 m .33014 .74084 L .30225 .74342 L p .707 .577 .707 r
F P
0 g
s
.30225 .74342 m .29806 .7052 L .32595 .70262 L p .707 .577 .707 r
F P
0 g
s
.29657 .61644 m .30039 .67359 L .26918 .67485 L p .707 .577 .707 r
F P
0 g
s
.26918 .67485 m .26536 .6177 L .29657 .61644 L p .707 .577 .707 r
F P
0 g
s
.21079 .7538 m .2066 .71558 L .23531 .71201 L p .707 .577 .707 r
F P
0 g
s
.23746 .67735 m .23364 .62019 L .26536 .6177 L p .707 .577 .707 r
F P
0 g
s
.23531 .71201 m .2395 .75023 L .21079 .7538 L p .707 .577 .707 r
F P
0 g
s
.26536 .6177 m .26918 .67485 L .23746 .67735 L p .707 .577 .707 r
F P
0 g
s
.21127 .79955 m .209 .78046 L .23724 .77679 L p .707 .577 .707 r
F P
0 g
s
.32827 .76626 m .33054 .78535 L .30222 .78842 L p .707 .577 .707 r
F P
0 g
s
.30222 .78842 m .29995 .76933 L .32827 .76626 L p .707 .577 .707 r
F P
0 g
s
.23724 .77679 m .23952 .79589 L .21127 .79955 L p .707 .577 .707 r
F P
0 g
s
.73082 .66875 m .73464 .61625 L .70343 .61165 L p .707 .577 .707 r
F P
0 g
s
.73464 .61625 m .73082 .66875 L .76254 .66928 L p .707 .577 .707 r
F P
0 g
s
.76254 .66928 m .76636 .61678 L .73464 .61625 L p .707 .577 .707 r
F P
0 g
s
.39752 .75598 m .39752 .25409 L .4339 .24693 L p .707 .577 .707 r
F P
0 g
s
.39752 .25409 m .39752 .75598 L .37116 .76581 L p .707 .577 .707 r
F P
0 g
s
.60151 .25383 m .60151 .75572 L .56487 .74865 L p .707 .577 .707 r
F P
0 g
s
.56487 .74865 m .56487 .24676 L .60151 .25383 L p .707 .577 .707 r
F P
0 g
s
.29806 .7052 m .30225 .74342 L .27102 .74665 L p .707 .577 .707 r
F P
0 g
s
.27102 .74665 m .26683 .70844 L .29806 .7052 L p .707 .577 .707 r
F P
0 g
s
.76636 .61678 m .76254 .66928 L .79166 .6657 L p .707 .577 .707 r
F P
0 g
s
.79166 .6657 m .79548 .61319 L .76636 .61678 L p .707 .577 .707 r
F P
0 g
s
.2395 .75023 m .23531 .71201 L .26683 .70844 L p .707 .577 .707 r
F P
0 g
s
.69961 .66416 m .70343 .61165 L .67579 .60344 L p .707 .577 .707 r
F P
0 g
s
.70343 .61165 m .69961 .66416 L .73082 .66875 L p .707 .577 .707 r
F P
0 g
s
.26683 .70844 m .27102 .74665 L .2395 .75023 L p .707 .577 .707 r
F P
0 g
s
.23952 .79589 m .23724 .77679 L .26858 .77296 L p .707 .577 .707 r
F P
0 g
s
.29995 .76933 m .30222 .78842 L .27085 .79205 L p .707 .577 .707 r
F P
0 g
s
.27085 .79205 m .26858 .77296 L .29995 .76933 L p .707 .577 .707 r
F P
0 g
s
.26858 .77296 m .27085 .79205 L .23952 .79589 L p .707 .577 .707 r
F P
0 g
s
.79548 .61319 m .79166 .6657 L .81534 .65834 L p .707 .577 .707 r
F P
0 g
s
.81534 .65834 m .81916 .60584 L .79548 .61319 L p .707 .577 .707 r
F P
0 g
s
.67197 .65594 m .67579 .60344 L .65441 .59241 L p .707 .577 .707 r
F P
0 g
s
.67579 .60344 m .67197 .65594 L .69961 .66416 L p .707 .577 .707 r
F P
0 g
s
.4339 .74882 m .4339 .24693 L .47675 .24313 L p .707 .577 .707 r
F P
0 g
s
.4339 .24693 m .4339 .74882 L .39752 .75598 L p .707 .577 .707 r
F P
0 g
s
.56487 .24676 m .56487 .74865 L .52188 .74496 L p .707 .577 .707 r
F P
0 g
s
.52188 .74496 m .52188 .24307 L .56487 .24676 L p .707 .577 .707 r
F P
0 g
s
.72898 .73455 m .73317 .70122 L .70194 .69535 L p .707 .577 .707 r
F P
0 g
s
.73317 .70122 m .72898 .73455 L .7605 .73554 L p .707 .577 .707 r
F P
0 g
s
.7605 .73554 m .76468 .70222 L .73317 .70122 L p .707 .577 .707 r
F P
0 g
s
.81916 .60584 m .81534 .65834 L .83125 .64794 L p .707 .577 .707 r
F P
0 g
s
.83125 .64794 m .83507 .59543 L .81916 .60584 L p .707 .577 .707 r
F P
0 g
s
.69775 .72868 m .70194 .69535 L .67404 .68518 L p .707 .577 .707 r
F P
0 g
s
.70194 .69535 m .69775 .72868 L .72898 .73455 L p .707 .577 .707 r
F P
0 g
s
.65059 .64491 m .65441 .59241 L .6414 .57965 L p .707 .577 .707 r
F P
0 g
s
.65441 .59241 m .65059 .64491 L .67197 .65594 L p .707 .577 .707 r
F P
0 g
s
.76468 .70222 m .7605 .73554 L .78921 .73157 L p .707 .577 .707 r
F P
0 g
s
.78921 .73157 m .79339 .69824 L .76468 .70222 L p .707 .577 .707 r
F P
0 g
s
.47675 .74502 m .47675 .24313 L .52188 .24307 L p .707 .577 .707 r
F P
0 g
s
.47675 .24313 m .47675 .74502 L .4339 .74882 L p .707 .577 .707 r
F P
0 g
s
.52188 .24307 m .52188 .74496 L .47675 .74502 L p .707 .577 .707 r
F P
0 g
s
.66986 .71851 m .67404 .68518 L .65222 .67171 L p .707 .577 .707 r
F P
0 g
s
.67404 .68518 m .66986 .71851 L .69775 .72868 L p .707 .577 .707 r
F P
0 g
s
.79339 .69824 m .78921 .73157 L .8123 .72301 L p .707 .577 .707 r
F P
0 g
s
.8123 .72301 m .81649 .68968 L .79339 .69824 L p .707 .577 .707 r
F P
0 g
s
.83507 .59543 m .83125 .64794 L .83784 .6355 L p .707 .577 .707 r
F P
0 g
s
.83784 .6355 m .84166 .583 L .83507 .59543 L p .707 .577 .707 r
F P
0 g
s
.72914 .77601 m .73142 .75946 L .70005 .75377 L p .707 .577 .707 r
F P
0 g
s
.73142 .75946 m .72914 .77601 L .76048 .7767 L p .707 .577 .707 r
F P
0 g
s
.76048 .7767 m .76276 .76015 L .73142 .75946 L p .707 .577 .707 r
F P
0 g
s
.6414 .57965 m .63758 .63215 L .65059 .64491 L p .707 .577 .707 r
F P
0 g
s
.69778 .77032 m .70005 .75377 L .67173 .74365 L p .707 .577 .707 r
F P
0 g
s
.70005 .75377 m .69778 .77032 L .72914 .77601 L p .707 .577 .707 r
F P
0 g
s
.63758 .63215 m .6414 .57965 L .63803 .5664 L p .707 .577 .707 r
F P
0 g
s
.65222 .67171 m .64803 .70503 L .66986 .71851 L p .707 .577 .707 r
F P
0 g
s
.64803 .70503 m .65222 .67171 L .6386 .65625 L p .707 .577 .707 r
F P
0 g
s
.76276 .76015 m .76048 .7767 L .78873 .77233 L p .707 .577 .707 r
F P
0 g
s
.78873 .77233 m .791 .75578 L .76276 .76015 L p .707 .577 .707 r
F P
0 g
s
.81649 .68968 m .8123 .72301 L .82753 .7107 L p .707 .577 .707 r
F P
0 g
s
.82753 .7107 m .83171 .67738 L .81649 .68968 L p .707 .577 .707 r
F P
0 g
s
.67173 .74365 m .66945 .7602 L .69778 .77032 L p .707 .577 .707 r
F P
0 g
s
.66945 .7602 m .67173 .74365 L .64922 .73008 L p .707 .577 .707 r
F P
0 g
s
.791 .75578 m .78873 .77233 L .81111 .76332 L p .707 .577 .707 r
F P
0 g
s
.81111 .76332 m .81338 .74677 L .791 .75578 L p .707 .577 .707 r
F P
0 g
s
.64922 .73008 m .64695 .74662 L .66945 .7602 L p .707 .577 .707 r
F P
0 g
s
.6386 .65625 m .63441 .68957 L .64803 .70503 L p .707 .577 .707 r
F P
0 g
s
.63803 .5664 m .63421 .6189 L .63758 .63215 L p .707 .577 .707 r
F P
0 g
s
.84166 .583 m .83784 .6355 L .83447 .62226 L p .707 .577 .707 r
F P
0 g
s
.83447 .62226 m .83829 .56976 L .84166 .583 L p .707 .577 .707 r
F P
0 g
s
.63441 .68957 m .6386 .65625 L .63452 .64031 L p .707 .577 .707 r
F P
0 g
s
.64695 .74662 m .64922 .73008 L .63473 .71438 L p .707 .577 .707 r
F P
0 g
s
.63421 .6189 m .63803 .5664 L .64462 .55397 L p .707 .577 .707 r
F P
0 g
s
.83171 .67738 m .82753 .7107 L .83338 .69586 L p .707 .577 .707 r
F P
0 g
s
.83338 .69586 m .83757 .66253 L .83171 .67738 L p .707 .577 .707 r
F P
0 g
s
.63473 .71438 m .63246 .73093 L .64695 .74662 L p .707 .577 .707 r
F P
0 g
s
.81338 .74677 m .81111 .76332 L .82544 .75056 L p .707 .577 .707 r
F P
0 g
s
.82544 .75056 m .82771 .73402 L .81338 .74677 L p .707 .577 .707 r
F P
0 g
s
.63452 .64031 m .63033 .67364 L .63441 .68957 L p .707 .577 .707 r
F P
0 g
s
.63246 .73093 m .63473 .71438 L .62968 .69811 L p .707 .577 .707 r
F P
0 g
s
.64462 .55397 m .6408 .60647 L .63421 .6189 L p .707 .577 .707 r
F P
0 g
s
.83829 .56976 m .83447 .62226 L .82146 .6095 L p .707 .577 .707 r
F P
0 g
s
.82146 .6095 m .82528 .55699 L .83829 .56976 L p .707 .577 .707 r
F P
0 g
s
.63033 .67364 m .63452 .64031 L .64038 .62547 L p .707 .577 .707 r
F P
0 g
s
.6408 .60647 m .64462 .55397 L .66054 .54356 L p .707 .577 .707 r
F P
0 g
s
.3821 .61391 m .39091 .55808 L .36002 .55204 L p .707 .577 .707 r
F P
0 g
s
.39091 .55808 m .3821 .61391 L .41353 .61799 L p .707 .577 .707 r
F P
0 g
s
.41353 .61799 m .42234 .56216 L .39091 .55808 L p .707 .577 .707 r
F P
0 g
s
.83757 .66253 m .83338 .69586 L .8293 .67992 L p .707 .577 .707 r
F P
0 g
s
.8293 .67992 m .83349 .6466 L .83757 .66253 L p .707 .577 .707 r
F P
0 g
s
.62968 .69811 m .6274 .71466 L .63246 .73093 L p .707 .577 .707 r
F P
0 g
s
.42234 .56216 m .41353 .61799 L .44242 .61973 L p .707 .577 .707 r
F P
0 g
s
.44242 .61973 m .45123 .5639 L .42234 .56216 L p .707 .577 .707 r
F P
0 g
s
.35121 .60787 m .36002 .55204 L .3327 .54464 L p .707 .577 .707 r
F P
0 g
s
.36002 .55204 m .35121 .60787 L .3821 .61391 L p .707 .577 .707 r
F P
0 g
s
.82771 .73402 m .82544 .75056 L .83032 .7353 L p .707 .577 .707 r
F P
0 g
s
.83032 .7353 m .83259 .71875 L .82771 .73402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64038 .62547 m .63619 .65879 L .63033 .67364 L p .707 .577 .707 r
F P
0 g
s
.3327 .54464 m .32389 .60047 L .35121 .60787 L p .707 .577 .707 r
F P
0 g
s
.37427 .6705 m .38377 .63371 L .35338 .62508 L p .707 .577 .707 r
F P
0 g
s
.38377 .63371 m .37427 .6705 L .40503 .67763 L p .707 .577 .707 r
F P
0 g
s
.40503 .67763 m .41453 .64083 L .38377 .63371 L p .707 .577 .707 r
F P
0 g
s
.45123 .5639 m .44242 .61973 L .46595 .61895 L p .707 .577 .707 r
F P
0 g
s
.46595 .61895 m .47476 .56312 L .45123 .5639 L p .707 .577 .707 r
F P
0 g
s
.32389 .60047 m .3327 .54464 L .31162 .53661 L p .707 .577 .707 r
F P
0 g
s
.6274 .71466 m .62968 .69811 L .63455 .68285 L p .707 .577 .707 r
F P
0 g
s
.82528 .55699 m .82146 .6095 L .80009 .59847 L p .707 .577 .707 r
F P
0 g
s
.80009 .59847 m .80391 .54597 L .82528 .55699 L p .707 .577 .707 r
F P
0 g
s
.34388 .66188 m .35338 .62508 L .32632 .61579 L p .707 .577 .707 r
F P
0 g
s
.35338 .62508 m .34388 .66188 L .37427 .6705 L p .707 .577 .707 r
F P
0 g
s
.41453 .64083 m .40503 .67763 L .43314 .68256 L p .707 .577 .707 r
F P
0 g
s
.43314 .68256 m .44264 .64576 L .41453 .64083 L p .707 .577 .707 r
F P
0 g
s
.66054 .54356 m .65672 .59607 L .6408 .60647 L p .707 .577 .707 r
F P
0 g
s
.63619 .65879 m .64038 .62547 L .6556 .61316 L p .707 .577 .707 r
F P
0 g
s
.65672 .59607 m .66054 .54356 L .68421 .53621 L p .707 .577 .707 r
F P
0 g
s
.32632 .61579 m .31683 .65259 L .34388 .66188 L p .707 .577 .707 r
F P
0 g
s
.37029 .71285 m .37538 .6945 L .34497 .68547 L p .707 .577 .707 r
F P
0 g
s
.37538 .6945 m .37029 .71285 L .40077 .72043 L p .707 .577 .707 r
F P
0 g
s
.40077 .72043 m .40586 .70208 L .37538 .6945 L p .707 .577 .707 r
F P
0 g
s
.83349 .6466 m .8293 .67992 L .81569 .66446 L p .707 .577 .707 r
F P
0 g
s
.81569 .66446 m .81987 .63114 L .83349 .6466 L p .707 .577 .707 r
F P
0 g
s
.63455 .68285 m .63228 .6994 L .6274 .71466 L p .707 .577 .707 r
F P
0 g
s
.31162 .53661 m .30281 .59244 L .32389 .60047 L p .707 .577 .707 r
F P
0 g
s
.34497 .68547 m .33988 .70382 L .37029 .71285 L p .707 .577 .707 r
F P
0 g
s
.33988 .70382 m .34497 .68547 L .3176 .67588 L p .707 .577 .707 r
F P
0 g
s
.83259 .71875 m .83032 .7353 L .82526 .71903 L p .707 .577 .707 r
F P
0 g
s
.82526 .71903 m .82754 .70248 L .83259 .71875 L p .707 .577 .707 r
F P
0 g
s
.40586 .70208 m .40077 .72043 L .42833 .72583 L p .707 .577 .707 r
F P
0 g
s
.42833 .72583 m .43342 .70748 L .40586 .70208 L p .707 .577 .707 r
F P
0 g
s
.3176 .67588 m .31251 .69423 L .33988 .70382 L p .707 .577 .707 r
F P
0 g
s
.31683 .65259 m .32632 .61579 L .30526 .60676 L p .707 .577 .707 r
F P
0 g
s
.44264 .64576 m .43314 .68256 L .45585 .68481 L p .707 .577 .707 r
F P
0 g
s
.45585 .68481 m .46535 .64801 L .44264 .64576 L p .707 .577 .707 r
F P
0 g
s
.47476 .56312 m .46595 .61895 L .48181 .61573 L p .707 .577 .707 r
F P
0 g
s
.48181 .61573 m .49062 .5599 L .47476 .56312 L p .707 .577 .707 r
F P
0 g
s
.30526 .60676 m .29576 .64356 L .31683 .65259 L p .707 .577 .707 r
F P
0 g
s
.80391 .54597 m .80009 .59847 L .77244 .59025 L p .707 .577 .707 r
F P
0 g
s
.77244 .59025 m .77626 .53775 L .80391 .54597 L p .707 .577 .707 r
F P
0 g
s
.30281 .59244 m .31162 .53661 L .29884 .52873 L p .707 .577 .707 r
F P
0 g
s
.6556 .61316 m .65141 .64649 L .63619 .65879 L p .707 .577 .707 r
F P
0 g
s
.6804 .58871 m .68421 .53621 L .71334 .53262 L p .707 .577 .707 r
F P
0 g
s
.68421 .53621 m .6804 .58871 L .65672 .59607 L p .707 .577 .707 r
F P
0 g
s
.31251 .69423 m .3176 .67588 L .29596 .66668 L p .707 .577 .707 r
F P
0 g
s
.63228 .6994 m .63455 .68285 L .64888 .67009 L p .707 .577 .707 r
F P
0 g
s
.29596 .66668 m .29086 .68502 L .31251 .69423 L p .707 .577 .707 r
F P
0 g
s
.65141 .64649 m .6556 .61316 L .6787 .6046 L p .707 .577 .707 r
F P
0 g
s
.43342 .70748 m .42833 .72583 L .45027 .72852 L p .707 .577 .707 r
F P
0 g
s
.45027 .72852 m .45537 .71017 L .43342 .70748 L p .707 .577 .707 r
F P
0 g
s
.81987 .63114 m .81569 .66446 L .79386 .65099 L p .707 .577 .707 r
F P
0 g
s
.79386 .65099 m .79805 .61766 L .81987 .63114 L p .707 .577 .707 r
F P
0 g
s
.29884 .52873 m .29003 .58456 L .30281 .59244 L p .707 .577 .707 r
F P
0 g
s
.77626 .53775 m .77244 .59025 L .74124 .58566 L p .707 .577 .707 r
F P
0 g
s
.74124 .58566 m .74505 .53315 L .77626 .53775 L p .707 .577 .707 r
F P
0 g
s
.70952 .58512 m .71334 .53262 L .74505 .53315 L p .707 .577 .707 r
F P
0 g
s
.71334 .53262 m .70952 .58512 L .6804 .58871 L p .707 .577 .707 r
F P
0 g
s
.64888 .67009 m .64661 .68664 L .63228 .6994 L p .707 .577 .707 r
F P
0 g
s
.29576 .64356 m .30526 .60676 L .29224 .59886 L p .707 .577 .707 r
F P
0 g
s
.46535 .64801 m .45585 .68481 L .47094 .68416 L p .707 .577 .707 r
F P
0 g
s
.47094 .68416 m .48044 .64736 L .46535 .64801 L p .707 .577 .707 r
F P
0 g
s
.82754 .70248 m .82526 .71903 L .81077 .70334 L p .707 .577 .707 r
F P
0 g
s
.81077 .70334 m .81305 .68679 L .82754 .70248 L p .707 .577 .707 r
F P
0 g
s
.74505 .53315 m .74124 .58566 L .70952 .58512 L p .707 .577 .707 r
F P
0 g
s
.29224 .59886 m .28274 .63566 L .29576 .64356 L p .707 .577 .707 r
F P
0 g
s
.49062 .5599 m .48181 .61573 L .48846 .61038 L p .707 .577 .707 r
F P
0 g
s
.48846 .61038 m .49726 .55455 L .49062 .5599 L p .707 .577 .707 r
F P
0 g
s
.29086 .68502 m .29596 .66668 L .28215 .65875 L p .707 .577 .707 r
F P
0 g
s
.6787 .6046 m .67451 .63793 L .65141 .64649 L p .707 .577 .707 r
F P
0 g
s
.67451 .63793 m .6787 .6046 L .70741 .60062 L p .707 .577 .707 r
F P
0 g
s
.28215 .65875 m .27705 .6771 L .29086 .68502 L p .707 .577 .707 r
F P
0 g
s
.29003 .58456 m .29884 .52873 L .29561 .52178 L p .707 .577 .707 r
F P
0 g
s
.79805 .61766 m .79386 .65099 L .76597 .64082 L p .707 .577 .707 r
F P
0 g
s
.76597 .64082 m .77016 .60749 L .79805 .61766 L p .707 .577 .707 r
F P
0 g
s
.45537 .71017 m .45027 .72852 L .46445 .72823 L p .707 .577 .707 r
F P
0 g
s
.46445 .72823 m .46955 .70988 L .45537 .71017 L p .707 .577 .707 r
F P
0 g
s
.64661 .68664 m .64888 .67009 L .67127 .66108 L p .707 .577 .707 r
F P
0 g
s
.29561 .52178 m .28681 .57761 L .29003 .58456 L p .707 .577 .707 r
F P
0 g
s
.70322 .63395 m .70741 .60062 L .73892 .60162 L p .707 .577 .707 r
F P
0 g
s
.70741 .60062 m .70322 .63395 L .67451 .63793 L p .707 .577 .707 r
F P
0 g
s
.67127 .66108 m .66899 .67763 L .64661 .68664 L p .707 .577 .707 r
F P
0 g
s
.81305 .68679 m .81077 .70334 L .78826 .68976 L p .707 .577 .707 r
F P
0 g
s
.78826 .68976 m .79054 .67321 L .81305 .68679 L p .707 .577 .707 r
F P
0 g
s
.77016 .60749 m .76597 .64082 L .73474 .63495 L p .707 .577 .707 r
F P
0 g
s
.73474 .63495 m .73892 .60162 L .77016 .60749 L p .707 .577 .707 r
F P
0 g
s
.28274 .63566 m .29224 .59886 L .28854 .59288 L p .707 .577 .707 r
F P
0 g
s
.48044 .64736 m .47094 .68416 L .47693 .68067 L p .707 .577 .707 r
F P
0 g
s
.47693 .68067 m .48643 .64387 L .48044 .64736 L p .707 .577 .707 r
F P
0 g
s
.73892 .60162 m .73474 .63495 L .70322 .63395 L p .707 .577 .707 r
F P
0 g
s
.28854 .59288 m .27905 .62968 L .28274 .63566 L p .707 .577 .707 r
F P
0 g
s
.66899 .67763 m .67127 .66108 L .69951 .65671 L p .707 .577 .707 r
F P
0 g
s
.27705 .6771 m .28215 .65875 L .27753 .65288 L p .707 .577 .707 r
F P
0 g
s
.49726 .55455 m .48846 .61038 L .48523 .60342 L p .707 .577 .707 r
F P
0 g
s
.48523 .60342 m .49404 .54759 L .49726 .55455 L p .707 .577 .707 r
F P
0 g
s
.27753 .65288 m .27244 .67123 L .27705 .6771 L p .707 .577 .707 r
F P
0 g
s
.46955 .70988 m .46445 .72823 L .46948 .72499 L p .707 .577 .707 r
F P
0 g
s
.46948 .72499 m .47457 .70664 L .46955 .70988 L p .707 .577 .707 r
F P
0 g
s
.28681 .57761 m .29561 .52178 L .30226 .51642 L p .707 .577 .707 r
F P
0 g
s
.79054 .67321 m .78826 .68976 L .75994 .67964 L p .707 .577 .707 r
F P
0 g
s
.75994 .67964 m .76221 .66309 L .79054 .67321 L p .707 .577 .707 r
F P
0 g
s
.69951 .65671 m .69724 .67326 L .66899 .67763 L p .707 .577 .707 r
F P
0 g
s
.69724 .67326 m .69951 .65671 L .73085 .6574 L p .707 .577 .707 r
F P
0 g
s
.76221 .66309 m .75994 .67964 L .72857 .67395 L p .707 .577 .707 r
F P
0 g
s
.72857 .67395 m .73085 .6574 L .76221 .66309 L p .707 .577 .707 r
F P
0 g
s
.30226 .51642 m .29345 .57225 L .28681 .57761 L p .707 .577 .707 r
F P
0 g
s
.73085 .6574 m .72857 .67395 L .69724 .67326 L p .707 .577 .707 r
F P
0 g
s
.27905 .62968 m .28854 .59288 L .29453 .58939 L p .707 .577 .707 r
F P
0 g
s
.48643 .64387 m .47693 .68067 L .47324 .67468 L p .707 .577 .707 r
F P
0 g
s
.47324 .67468 m .48273 .63788 L .48643 .64387 L p .707 .577 .707 r
F P
0 g
s
.29453 .58939 m .28504 .62619 L .27905 .62968 L p .707 .577 .707 r
F P
0 g
s
.27244 .67123 m .27753 .65288 L .28256 .64964 L p .707 .577 .707 r
F P
0 g
s
.49404 .54759 m .48523 .60342 L .47245 .59554 L p .707 .577 .707 r
F P
0 g
s
.47245 .59554 m .48126 .53971 L .49404 .54759 L p .707 .577 .707 r
F P
0 g
s
.28256 .64964 m .27747 .66799 L .27244 .67123 L p .707 .577 .707 r
F P
0 g
s
.29345 .57225 m .30226 .51642 L .31812 .5132 L p .707 .577 .707 r
F P
0 g
s
.47457 .70664 m .46948 .72499 L .46486 .71912 L p .707 .577 .707 r
F P
0 g
s
.46486 .71912 m .46996 .70077 L .47457 .70664 L p .707 .577 .707 r
F P
0 g
s
.31812 .5132 m .30931 .56903 L .29345 .57225 L p .707 .577 .707 r
F P
0 g
s
.28504 .62619 m .29453 .58939 L .30962 .58874 L p .707 .577 .707 r
F P
0 g
s
.48273 .63788 m .47324 .67468 L .46022 .66678 L p .707 .577 .707 r
F P
0 g
s
.46022 .66678 m .46972 .62999 L .48273 .63788 L p .707 .577 .707 r
F P
0 g
s
.30962 .58874 m .30013 .62553 L .28504 .62619 L p .707 .577 .707 r
F P
0 g
s
.48126 .53971 m .47245 .59554 L .45137 .58751 L p .707 .577 .707 r
F P
0 g
s
.45137 .58751 m .46018 .53168 L .48126 .53971 L p .707 .577 .707 r
F P
0 g
s
.27747 .66799 m .28256 .64964 L .29674 .64935 L p .707 .577 .707 r
F P
0 g
s
.30931 .56903 m .31812 .5132 L .34165 .51242 L p .707 .577 .707 r
F P
0 g
s
.29674 .64935 m .29165 .6677 L .27747 .66799 L p .707 .577 .707 r
F P
0 g
s
.46996 .70077 m .46486 .71912 L .45106 .71119 L p .707 .577 .707 r
F P
0 g
s
.45106 .71119 m .45615 .69284 L .46996 .70077 L p .707 .577 .707 r
F P
0 g
s
.34165 .51242 m .33284 .56825 L .30931 .56903 L p .707 .577 .707 r
F P
0 g
s
.30013 .62553 m .30962 .58874 L .33233 .59098 L p .707 .577 .707 r
F P
0 g
s
.46972 .62999 m .46022 .66678 L .43915 .65775 L p .707 .577 .707 r
F P
0 g
s
.43915 .65775 m .44865 .62095 L .46972 .62999 L p .707 .577 .707 r
F P
0 g
s
.46018 .53168 m .45137 .58751 L .42405 .58012 L p .707 .577 .707 r
F P
0 g
s
.42405 .58012 m .43286 .52429 L .46018 .53168 L p .707 .577 .707 r
F P
0 g
s
.33284 .56825 m .34165 .51242 L .37054 .51416 L p .707 .577 .707 r
F P
0 g
s
.33233 .59098 m .32284 .62778 L .30013 .62553 L p .707 .577 .707 r
F P
0 g
s
.29165 .6677 m .29674 .64935 L .31869 .65203 L p .707 .577 .707 r
F P
0 g
s
.31869 .65203 m .31359 .67038 L .29165 .6677 L p .707 .577 .707 r
F P
0 g
s
.45615 .69284 m .45106 .71119 L .42941 .70198 L p .707 .577 .707 r
F P
0 g
s
.42941 .70198 m .4345 .68363 L .45615 .69284 L p .707 .577 .707 r
F P
0 g
s
.37054 .51416 m .36173 .56999 L .33284 .56825 L p .707 .577 .707 r
F P
0 g
s
.43286 .52429 m .42405 .58012 L .39316 .57408 L p .707 .577 .707 r
F P
0 g
s
.39316 .57408 m .40197 .51825 L .43286 .52429 L p .707 .577 .707 r
F P
0 g
s
.36173 .56999 m .37054 .51416 L .40197 .51825 L p .707 .577 .707 r
F P
0 g
s
.32284 .62778 m .33233 .59098 L .36044 .59591 L p .707 .577 .707 r
F P
0 g
s
.40197 .51825 m .39316 .57408 L .36173 .56999 L p .707 .577 .707 r
F P
0 g
s
.44865 .62095 m .43915 .65775 L .4121 .64847 L p .707 .577 .707 r
F P
0 g
s
.4121 .64847 m .42159 .61167 L .44865 .62095 L p .707 .577 .707 r
F P
0 g
s
.36044 .59591 m .35095 .63271 L .32284 .62778 L p .707 .577 .707 r
F P
0 g
s
.31359 .67038 m .31869 .65203 L .34624 .65743 L p .707 .577 .707 r
F P
0 g
s
.34624 .65743 m .34115 .67578 L .31359 .67038 L p .707 .577 .707 r
F P
0 g
s
.4345 .68363 m .42941 .70198 L .40204 .69239 L p .707 .577 .707 r
F P
0 g
s
.40204 .69239 m .40713 .67405 L .4345 .68363 L p .707 .577 .707 r
F P
0 g
s
.35095 .63271 m .36044 .59591 L .3912 .60304 L p .707 .577 .707 r
F P
0 g
s
.42159 .61167 m .4121 .64847 L .38171 .63984 L p .707 .577 .707 r
F P
0 g
s
.38171 .63984 m .3912 .60304 L .42159 .61167 L p .707 .577 .707 r
F P
0 g
s
.3912 .60304 m .38171 .63984 L .35095 .63271 L p .707 .577 .707 r
F P
0 g
s
.34115 .67578 m .34624 .65743 L .37672 .66502 L p .707 .577 .707 r
F P
0 g
s
.40713 .67405 m .40204 .69239 L .37163 .68337 L p .707 .577 .707 r
F P
0 g
s
.37163 .68337 m .37672 .66502 L .40713 .67405 L p .707 .577 .707 r
F P
0 g
s
.37672 .66502 m .37163 .68337 L .34115 .67578 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007Aoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00L7oo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001^
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000Kgoo001[Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`00K7oo001YOol20006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2001ZOol006Qoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8006Uoo`00IWoo0P0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000006Moo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol005Qoo`h000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool005Eoo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00003
0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000047oo4@00AGoo001COol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Woo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P00?goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Woo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00Dgoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000j
Ool005=oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000hOol0059oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<003Ioo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008003Aoo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000a
Ool0059oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
031oo`00DWoo00AJEP00FUIJEP`000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000_Ool0055oo`03001JEP00
00800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0055oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00H0
05YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60006FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06
001JEUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0059oo`05001J
EUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001COol800000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH01000FUIJEUYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF1P004Goo
1P001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20004FUH00`00FUIJEP070002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH0
0UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF
00<005YF00000`007Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20003
FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF0P000UYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000=JEP<0029oo`<00003FUH005YF00AJEP07001JEUYFFUH005YF0000;Goo001A
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF0P001Woo2@0057oo0P001EYF00L005YFFUIJ
EP00FUH0000]Ool0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUH005YF0`0000=JEP00FUH00eYF1P0015YF00<005YFFUH0
0UYF20003Woo0P000eYF00L005YFFUIJEP00FUH0000]Ool0055oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00
FUH00002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP06FUH01000FUIJEUYF1P002Woo0P0000=J
EP00FUH00UYF00<005YF0000;Goo001AOol00eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJ
EP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001Woo0`00
00=JEP0000000eYF0P00;Woo001@Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00@005YFFUIJEP80
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH30004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YF0000
0UYF0P00;Woo0017Ool:00000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH00P002eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00@002ioo`00?goo2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEPX000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEP00001JEP0200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP02FUH2000^Ool003Moo`P000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF009JEP<002ioo`00
<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH3000015YF001JEUYF
1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP<002ioo`00;Woo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`0035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJEP03
001JEUYF00EJEP03001JEUYF00EJEP800004FUH005YF000^Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF009J
EPH0009JEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP80
0003FUH0000002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEP0000800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUH000000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH015YF00D005YFFUIJEP00031oo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPT00003FUH005YF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF0000<7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000020003FUH00`00FUIJEP070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUH005YF0P000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP8002moo`00;Goo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF
FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01`00FUIJEUYF001J
EP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00008000IJEP<0
00EJEPd000IJEP03001JEUYF00IJEP<000=JEP03001JEUYF009JEP8002moo`00;Goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP07001J
EUYFFUH005YF00002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF1P001eYF1P00
00=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH0
0eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP07FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP04FUH40005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40007FUH00`00FUH000040003FUH01000FUIJEP00;Woo000^Ool00eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH30007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH2000015YF001JEP000UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF000005YF00H000Eoo`04001JEUYF0002FUH00`00Oomoo`0/
Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP800003
FUH005YF00=JEPL000IJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00=JEP<00004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
000015YF001JEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000Yoo`03001JEP00009JEP03001oogoo02aoo`00;Woo00=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEPP00003FUH005YF00QJEP03
001JEUYF00AJEP@000MJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP8000EJEP03001JEUYF009JEPl000IJEP03
001JEUYF00AJEP8000Qoo`05001JEP00FUH0000_Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF009JEPP00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00=JEP<000=JEP@0
00MJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000AJEP00FUH000AJEPH0009JEP03001J
EUYF008000Qoo`@0009JEP03001JEUYF00EJEP<000Moo`800003FUH007oo02ioo`00;Woo00=JEP00
FUH00eYF00@005YFFUIJEPT000QJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEP0000<0
0003FUH005YF00@0009JEP03001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF
009JEP<0009JEP03001JEUYF009JEP03001JEUYF008000aoo`@000IJEP03001JEUYF008000Ioo`03
001JEP0002moo`00;Woo00=JEP00FUH00UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1UYF00<005YFFUH015YF100000=JEP00FUH01@001UYF00<005YFFUH01EYF3P0035YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00@005YF000000=JEP@000AJEP04
001JEP00000@Ool20004FUH00`00FUIJEP02FUH20003Ool200000eYF001oo`0^Ool002ioo`03FUH0
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF
00IJEP04001JEP000003FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30002FUH30005FUH00`00FUH00003
00001EYF001JEUYF00004Woo0`0000=JEP00FUH01EYF00@007oo001JEP80031oo`00;Woo00EJEP00
001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00MJEP03001JEUYF009JEP@000IJEP@000MJEP03001JEUYF008000MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP04001J
EUYFFUH40002FUH00`00Oomoo`0COol20006FUH20003FUH00`00Oomoo`0^Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00MJEP03001JEUYF00EJEP@000AJEP03001JEUYF008000AJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@0009JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@001Moo`8000AJEP04001JEP00FUH2000`Ool002moo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000=oo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00D000AJEP<00003FUH005YF00EJEP<000=JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00@0011oo`H0009JEP04001JEUYFFUH3000`Ool0035ooad000]oo`H00003FUH005YF00QJEP03
001JEUYF00AJEP@000AJEP8000IJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP80009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00<000AJEP80031oo`00D7oo2@000eYF00<005YFFUH010001UYF00<005YFFUH0
1eYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0`0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF0P000UYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<007ooOol0;goo0017Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP03FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002
FUH00`00FUH000020003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<Goo000oOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH005YF10001eYF00<005YFFUH01UYF00@005YFFUIJEP80
00=JEP04001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUH0
05YF001JEP00009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000hOol70003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUH000030002FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300001EYF000005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00L005YF001JEP00FUH00003FUH30007FUH00`00FUIJEP07FUH40005FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001oo`0_Ool0039oo`H0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000=JEP03001JEUYF00=JEP@000MJEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00AJEP8000IJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<00004Ool0
05YF000`Ool002ioo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001J
EP0000<0009JEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH01000FUIJEP001UYF0P0015YF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00L007ooOomoo`00FUH0000`Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00=JEPD000=JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80
00=JEP03001JEP0000MJEP@00003FUH005YF00MJEPH000=JEP03001JEUYF00EJEP04001JEUYFFUH2
0005Ool2000`Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00MJEPX0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000AJEP8000MJEP04001JEUYFFUH60004FUH00`00FUH000020004FUH00`00FUIJEP05FUH0
1000FUH000001goo0P00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003FUH30007FUH00`00FUIJEP02FUH00`00FUIJEP0:0004
FUH00`00FUIJEP02FUH50009Ool2000`Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP0:0003FUH01000FUH0
000027oo2@003Goo0`00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH<0003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP<000Ioo`@0009JEP03001oogoo01]oo`03001JEP00035oo`00
;goo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF20000UYF00@005YFFUIJEPH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20006FUH20006Ool00`00FUIJ
EP03000LOol01000FUH00000<Goo000_Ool00eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP02FUH70005Ool01@00FUIJEUYF00001eYF00<005YF
FUH01EYF2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@001eYF00<005YFFUH01EYF00@005YF
FUIJEP8000IJEP04001JEP000003Ool01`00FUIJEUYF001JEP0001Yoo`80009JEP03001oogoo031o
o`00;goo0UYF00D005YFFUIJEP0000EJEP03001JEUYF009JEPT0009JEP03001JEUYF009JEPT000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP050002FUH00`00FUIJEP05FUH01P00FUIJEUYF001oo`8000AJEP04001J
EUYFFUH30004FUH01000FUH000005Goo100000EJEP00FUIJEP00039oo`00;goo0UYF00D005YFFUIJ
EP0000=JEPL0009JEP03001JEUYF009JEPT001Eoo`05001JEUYFFUH00006FUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40006FUH01@00FUIJEUYF0000
0goo0P000UYF00<005YFFUH015YF1P0000=JEP00Ool04Goo0`001EYF00<005YF0000<goo000_Ool2
FUHF000NOol01@00FUIJEUYF000015YF0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF0`0015YF00H005YFFUIJEP00Ool70007FUH00`00FUIJ
EP02FUH90007Ool400000eYF001JEP04FUH00`00FUH0000dOol002moo`T002eoo`06001JEUYFFUH0
05YF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH00`0000=JEP00FUH00UYF0P000UYF00@005YFFUIJEP8000IJEP03001J
EUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF00=JEP8003Eoo`00FWoo30000eYF0P001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000EJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003Ioo`00DGoo2@000eYF00<005YFFUH00eYF00<0
05YF00000UYF0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00>7oo0018Ool90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUH005YF001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEP00008000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003]oo`00@7oo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF00D005YFFUIJEP00009JEPd000=JEP03001JEP000140
041oo`00>Goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP<000EJEP03001JEUYF00EJ
EP@000=JEP03001oogoo04eoo`00<goo1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05
001JEUYFFUH00007FUH00`00FUIJEP05FUH20002Ool200000eYF001oo`1>Ool002moo`@0009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPL0
0003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00
FUIJEP04FUH00`00Oomoo`03Ool2001?Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH0000000D000=oo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000025YF00<005YFFUH00UYF0P001Goo00@005YF000004ioo`00
;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4P002goo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF008000QJEP05001JEUYFFUH00007Ool01000FUIJEP00CWoo
000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA000EOol30007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH30002FUH00`00FUIJEP06FUH30007Ool20002FUH00`00Oomoo`1<Ool0031oo`03FUH005YF
009JEP04001JEUYFFUH@000POol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP05FUH20008
Ool01P00FUIJEP00FUH004ioo`00<7oo00=JEP0000003P00:Woo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP8000IJ
EP03001JEUYF00=JEP8000Uoo`04001JEUYFFUH2001?Ool0031oo`@003Uoo`<00003FUH005YF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000009
FUH00`00FUH00002000:Ool00`00FUIJEP03FUH00`00Oomoo`1=Ool0071oo`@000MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP@0
00]oo`<000EJEP03001oogoo04eoo`00M7oo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02`0000AJEP00FUIJEP@000ioo`05001JEUYFFUH00003FUH00`00Oomo
o`1>Ool007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000=JEP03001JEUYF00T0011o
o`8000AJEP04001JEUYF001AOol0085ooa/000=JEP03001JEUYF00EJEP03001JEP0000@001=oo`03
001JEUYF00EJEP80059oo`00UGoo00<005YF00000UYF00<007oo000040004Woo0`001eYF00<007oo
Ool0DGoo002EOol00`00FUIJEP02000SOol20003FUH00`00FUIJEP02FUH2001DOol009Eoo`04001J
EUYF000ROol20005FUH01@00FUIJEUYF0000EWoo002EOol00`00FUH0000POol30008FUH3001GOol0
09Ioo`03FUH007oo01]oo`@00003FUH005YF00MJEP8005Uoo`00UWoo0`005Woo1@001UYF00<005YF
FUH00eYF0P00Fgoo002FOol200000eYF00000002000>Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP03001MOol009Moo`04001JEUYF0002FUH>0006FUH00`00FUIJEP06FUH3001POol009Moo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<006=oo`00V7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008006Ioo`00VGoo0P00
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF1000JGoo002KOol40003FUH00`00FUIJ
EP04FUH00`00FUIJEP04001]Ool009moo`d0075oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60684 .75534 m .59803 .70156 L .56714 .70382 L p .707 .577 .707 r
F P
0 g
s
.59803 .70156 m .60684 .75534 L .63826 .74968 L p .707 .577 .707 r
F P
0 g
s
.63826 .74968 m .62945 .69589 L .59803 .70156 L p .707 .577 .707 r
F P
0 g
s
.62945 .69589 m .63826 .74968 L .66715 .74118 L p .707 .577 .707 r
F P
0 g
s
.66715 .74118 m .65835 .68739 L .62945 .69589 L p .707 .577 .707 r
F P
0 g
s
.57595 .75761 m .56714 .70382 L .53982 .70248 L p .707 .577 .707 r
F P
0 g
s
.56714 .70382 m .57595 .75761 L .60684 .75534 L p .707 .577 .707 r
F P
0 g
s
.65835 .68739 m .66715 .74118 L .69068 .73067 L p .707 .577 .707 r
F P
0 g
s
.69068 .73067 m .68188 .67688 L .65835 .68739 L p .707 .577 .707 r
F P
0 g
s
.54863 .75626 m .53982 .70248 L .51874 .69764 L p .707 .577 .707 r
F P
0 g
s
.53982 .70248 m .54863 .75626 L .57595 .75761 L p .707 .577 .707 r
F P
0 g
s
.61829 .81867 m .6088 .7841 L .5784 .78897 L p .707 .577 .707 r
F P
0 g
s
.6088 .7841 m .61829 .81867 L .64905 .80998 L p .707 .577 .707 r
F P
0 g
s
.64905 .80998 m .63955 .77541 L .6088 .7841 L p .707 .577 .707 r
F P
0 g
s
.63955 .77541 m .64905 .80998 L .67716 .79831 L p .707 .577 .707 r
F P
0 g
s
.67716 .79831 m .66766 .76374 L .63955 .77541 L p .707 .577 .707 r
F P
0 g
s
.68188 .67688 m .69068 .73067 L .70655 .71917 L p .707 .577 .707 r
F P
0 g
s
.70655 .71917 m .69774 .66539 L .68188 .67688 L p .707 .577 .707 r
F P
0 g
s
.5879 .82354 m .5784 .78897 L .55135 .78954 L p .707 .577 .707 r
F P
0 g
s
.5784 .78897 m .5879 .82354 L .61829 .81867 L p .707 .577 .707 r
F P
0 g
s
.66766 .76374 m .67716 .79831 L .69987 .78482 L p .707 .577 .707 r
F P
0 g
s
.69987 .78482 m .69037 .75025 L .66766 .76374 L p .707 .577 .707 r
F P
0 g
s
.51874 .69764 m .52755 .75143 L .54863 .75626 L p .707 .577 .707 r
F P
0 g
s
.52755 .75143 m .51874 .69764 L .50596 .6898 L p .707 .577 .707 r
F P
0 g
s
.62837 .86056 m .62327 .84346 L .59286 .84915 L p .707 .577 .707 r
F P
0 g
s
.62327 .84346 m .62837 .86056 L .65885 .85099 L p .707 .577 .707 r
F P
0 g
s
.65885 .85099 m .65375 .83388 L .62327 .84346 L p .707 .577 .707 r
F P
0 g
s
.55135 .78954 m .56084 .82411 L .5879 .82354 L p .707 .577 .707 r
F P
0 g
s
.65375 .83388 m .65885 .85099 L .68641 .83847 L p .707 .577 .707 r
F P
0 g
s
.68641 .83847 m .68131 .82137 L .65375 .83388 L p .707 .577 .707 r
F P
0 g
s
.56084 .82411 m .55135 .78954 L .53028 .78575 L p .707 .577 .707 r
F P
0 g
s
.69037 .75025 m .69987 .78482 L .71496 .77081 L p .707 .577 .707 r
F P
0 g
s
.71496 .77081 m .70546 .73624 L .69037 .75025 L p .707 .577 .707 r
F P
0 g
s
.59286 .84915 m .59796 .86625 L .62837 .86056 L p .707 .577 .707 r
F P
0 g
s
.69774 .66539 m .70655 .71917 L .71319 .70783 L p .707 .577 .707 r
F P
0 g
s
.71319 .70783 m .70438 .65404 L .69774 .66539 L p .707 .577 .707 r
F P
0 g
s
.59796 .86625 m .59286 .84915 L .56549 .8504 L p .707 .577 .707 r
F P
0 g
s
.68131 .82137 m .68641 .83847 L .70835 .82424 L p .707 .577 .707 r
F P
0 g
s
.70835 .82424 m .70325 .80713 L .68131 .82137 L p .707 .577 .707 r
F P
0 g
s
.56549 .8504 m .57059 .86751 L .59796 .86625 L p .707 .577 .707 r
F P
0 g
s
.53028 .78575 m .53978 .82032 L .56084 .82411 L p .707 .577 .707 r
F P
0 g
s
.50596 .6898 m .51477 .74358 L .52755 .75143 L p .707 .577 .707 r
F P
0 g
s
.57059 .86751 m .56549 .8504 L .54385 .8471 L p .707 .577 .707 r
F P
0 g
s
.51477 .74358 m .50596 .6898 L .50273 .67971 L p .707 .577 .707 r
F P
0 g
s
.53978 .82032 m .53028 .78575 L .51726 .77798 L p .707 .577 .707 r
F P
0 g
s
.70325 .80713 m .70835 .82424 L .72253 .80968 L p .707 .577 .707 r
F P
0 g
s
.72253 .80968 m .71744 .79257 L .70325 .80713 L p .707 .577 .707 r
F P
0 g
s
.70546 .73624 m .71496 .77081 L .72095 .75767 L p .707 .577 .707 r
F P
0 g
s
.72095 .75767 m .71145 .7231 L .70546 .73624 L p .707 .577 .707 r
F P
0 g
s
.54385 .8471 m .54894 .8642 L .57059 .86751 L p .707 .577 .707 r
F P
0 g
s
.70438 .65404 m .71319 .70783 L .70996 .69774 L p .707 .577 .707 r
F P
0 g
s
.70996 .69774 m .70116 .64395 L .70438 .65404 L p .707 .577 .707 r
F P
0 g
s
.51726 .77798 m .52676 .81255 L .53978 .82032 L p .707 .577 .707 r
F P
0 g
s
.50273 .67971 m .51154 .73349 L .51477 .74358 L p .707 .577 .707 r
F P
0 g
s
.54894 .8642 m .54385 .8471 L .53004 .83955 L p .707 .577 .707 r
F P
0 g
s
.47812 .82147 m .47812 .31959 L .43513 .3159 L p .707 .577 .707 r
F P
0 g
s
.52676 .81255 m .51726 .77798 L .51357 .76698 L p .707 .578 .707 r
F P
0 g
s
.51154 .73349 m .50273 .67971 L .50938 .66836 L p .707 .577 .707 r
F P
0 g
s
.51357 .76698 m .52307 .80155 L .52676 .81255 L p .707 .578 .707 r
F P
0 g
s
.50938 .66836 m .51819 .72215 L .51154 .73349 L p .707 .577 .707 r
F P
0 g
s
.52307 .80155 m .51357 .76698 L .51956 .75384 L p .707 .577 .707 r
F P
0 g
s
.51819 .72215 m .50938 .66836 L .52524 .65687 L p .707 .577 .707 r
F P
0 g
s
.47812 .31959 m .47812 .82147 L .52324 .82142 L p .707 .577 .707 r
F P
0 g
s
.51956 .75384 m .52906 .78841 L .52307 .80155 L p .707 .577 .707 r
F P
0 g
s
.52524 .65687 m .53405 .71066 L .51819 .72215 L p .707 .577 .707 r
F P
0 g
s
.52906 .78841 m .51956 .75384 L .53465 .73983 L p .707 .577 .707 r
F P
0 g
s
.52324 .82142 m .52324 .31953 L .47812 .31959 L p .707 .577 .707 r
F P
0 g
s
.53004 .83955 m .53513 .85666 L .54894 .8642 L p .707 .577 .707 r
F P
0 g
s
.53513 .85666 m .53004 .83955 L .52542 .82851 L p .707 .577 .707 r
F P
0 g
s
.52542 .82851 m .53052 .84561 L .53513 .85666 L p .707 .577 .707 r
F P
0 g
s
.53052 .84561 m .52542 .82851 L .53045 .81505 L p .707 .577 .707 r
F P
0 g
s
.53405 .71066 m .52524 .65687 L .54877 .64636 L p .707 .577 .707 r
F P
0 g
s
.53045 .81505 m .53555 .83215 L .53052 .84561 L p .707 .577 .707 r
F P
0 g
s
.53465 .73983 m .54415 .7744 L .52906 .78841 L p .707 .577 .707 r
F P
0 g
s
.55758 .70014 m .54877 .64636 L .57766 .63785 L p .707 .577 .707 r
F P
0 g
s
.54877 .64636 m .55758 .70014 L .53405 .71066 L p .707 .577 .707 r
F P
0 g
s
.53555 .83215 m .53045 .81505 L .54463 .80048 L p .707 .577 .707 r
F P
0 g
s
.54415 .7744 m .53465 .73983 L .55736 .72633 L p .707 .577 .707 r
F P
0 g
s
.54463 .80048 m .54973 .81759 L .53555 .83215 L p .707 .577 .707 r
F P
0 g
s
.55736 .72633 m .56686 .7609 L .54415 .7744 L p .707 .577 .707 r
F P
0 g
s
.56686 .7609 m .55736 .72633 L .58547 .71467 L p .707 .577 .707 r
F P
0 g
s
.54973 .81759 m .54463 .80048 L .56658 .78625 L p .707 .577 .707 r
F P
0 g
s
.56658 .78625 m .57167 .80335 L .54973 .81759 L p .707 .577 .707 r
F P
0 g
s
.52324 .31953 m .52324 .82142 L .5661 .81762 L p .707 .577 .707 r
F P
0 g
s
.57766 .63785 m .58647 .69164 L .55758 .70014 L p .707 .577 .707 r
F P
0 g
s
.5661 .81762 m .5661 .31573 L .52324 .31953 L p .707 .577 .707 r
F P
0 g
s
.71744 .79257 m .72253 .80968 L .72756 .79621 L p .707 .577 .707 r
F P
0 g
s
.72756 .79621 m .72246 .77911 L .71744 .79257 L p .707 .577 .707 r
F P
0 g
s
.71145 .7231 m .72095 .75767 L .71725 .74667 L p .707 .578 .707 r
F P
0 g
s
.71725 .74667 m .70776 .7121 L .71145 .7231 L p .707 .578 .707 r
F P
0 g
s
.43513 .81779 m .43513 .3159 L .39849 .30883 L p .707 .577 .707 r
F P
0 g
s
.43513 .3159 m .43513 .81779 L .47812 .82147 L p .707 .577 .707 r
F P
0 g
s
.58647 .69164 m .57766 .63785 L .60909 .63219 L p .707 .577 .707 r
F P
0 g
s
.60909 .63219 m .6179 .68598 L .58647 .69164 L p .707 .577 .707 r
F P
0 g
s
.59497 .74924 m .58547 .71467 L .61623 .70598 L p .707 .577 .707 r
F P
0 g
s
.58547 .71467 m .59497 .74924 L .56686 .7609 L p .707 .577 .707 r
F P
0 g
s
.61623 .70598 m .62572 .74055 L .59497 .74924 L p .707 .577 .707 r
F P
0 g
s
.57167 .80335 m .56658 .78625 L .59414 .77373 L p .707 .577 .707 r
F P
0 g
s
.59414 .77373 m .59923 .79084 L .57167 .80335 L p .707 .577 .707 r
F P
0 g
s
.59923 .79084 m .59414 .77373 L .62461 .76416 L p .707 .577 .707 r
F P
0 g
s
.62461 .76416 m .62971 .78126 L .59923 .79084 L p .707 .577 .707 r
F P
0 g
s
.5661 .31573 m .5661 .81762 L .60248 .81046 L p .707 .577 .707 r
F P
0 g
s
.60248 .81046 m .60248 .30857 L .5661 .31573 L p .707 .577 .707 r
F P
0 g
s
.70116 .64395 m .70996 .69774 L .69719 .68989 L p .707 .577 .707 r
F P
0 g
s
.69719 .68989 m .68838 .63611 L .70116 .64395 L p .707 .577 .707 r
F P
0 g
s
.25876 .70008 m .25494 .64293 L .22374 .64419 L p .707 .577 .707 r
F P
0 g
s
.25494 .64293 m .25876 .70008 L .29048 .69759 L p .707 .577 .707 r
F P
0 g
s
.29048 .69759 m .28666 .64044 L .25494 .64293 L p .707 .577 .707 r
F P
0 g
s
.28666 .64044 m .29048 .69759 L .3196 .6941 L p .707 .577 .707 r
F P
0 g
s
.3196 .6941 m .31578 .63695 L .28666 .64044 L p .707 .577 .707 r
F P
0 g
s
.72246 .77911 m .72756 .79621 L .72294 .78517 L p .707 .577 .707 r
F P
0 g
s
.72294 .78517 m .71785 .76807 L .72246 .77911 L p .707 .577 .707 r
F P
0 g
s
.22755 .70134 m .22374 .64419 L .19609 .64409 L p .707 .577 .707 r
F P
0 g
s
.22374 .64419 m .22755 .70134 L .25876 .70008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26526 .75359 m .26108 .71537 L .22984 .71861 L p .707 .577 .707 r
F P
0 g
s
.26108 .71537 m .26526 .75359 L .29678 .75001 L p .707 .577 .707 r
F P
0 g
s
.29678 .75001 m .29259 .71179 L .26108 .71537 L p .707 .577 .707 r
F P
0 g
s
.70776 .7121 m .71725 .74667 L .70424 .7389 L p .707 .577 .707 r
F P
0 g
s
.70424 .7389 m .69474 .70433 L .70776 .7121 L p .707 .577 .707 r
F P
0 g
s
.39849 .81072 m .39849 .30883 L .37179 .29907 L p .707 .577 .707 r
F P
0 g
s
.39849 .30883 m .39849 .81072 L .43513 .81779 L p .707 .577 .707 r
F P
0 g
s
.22984 .71861 m .23403 .75683 L .26526 .75359 L p .707 .577 .707 r
F P
0 g
s
.19609 .64409 m .19991 .70125 L .22755 .70134 L p .707 .577 .707 r
F P
0 g
s
.63998 .62992 m .64878 .68371 L .6179 .68598 L p .707 .577 .707 r
F P
0 g
s
.6179 .68598 m .60909 .63219 L .63998 .62992 L p .707 .577 .707 r
F P
0 g
s
.62572 .74055 m .61623 .70598 L .64662 .70111 L p .707 .577 .707 r
F P
0 g
s
.62971 .78126 m .62461 .76416 L .65502 .75847 L p .707 .577 .707 r
F P
0 g
s
.60248 .30857 m .60248 .81046 L .62883 .80062 L p .707 .577 .707 r
F P
0 g
s
.64662 .70111 m .65612 .73568 L .62572 .74055 L p .707 .577 .707 r
F P
0 g
s
.62883 .80062 m .62883 .29874 L .60248 .30857 L p .707 .577 .707 r
F P
0 g
s
.31578 .63695 m .3196 .6941 L .34328 .68997 L p .707 .577 .707 r
F P
0 g
s
.34328 .68997 m .33946 .63281 L .31578 .63695 L p .707 .577 .707 r
F P
0 g
s
.29259 .71179 m .29678 .75001 L .32549 .74645 L p .707 .577 .707 r
F P
0 g
s
.32549 .74645 m .3213 .70823 L .29259 .71179 L p .707 .577 .707 r
F P
0 g
s
.68838 .63611 m .69719 .68989 L .6761 .68506 L p .707 .577 .707 r
F P
0 g
s
.6761 .68506 m .6673 .63127 L .68838 .63611 L p .707 .577 .707 r
F P
0 g
s
.27142 .79622 m .26915 .77712 L .23779 .78075 L p .707 .577 .707 r
F P
0 g
s
.26915 .77712 m .27142 .79622 L .30276 .79238 L p .707 .577 .707 r
F P
0 g
s
.30276 .79238 m .30049 .77329 L .26915 .77712 L p .707 .577 .707 r
F P
0 g
s
.23403 .75683 m .22984 .71861 L .20195 .72119 L p .707 .577 .707 r
F P
0 g
s
.23779 .78075 m .24006 .79985 L .27142 .79622 L p .707 .577 .707 r
F P
0 g
s
.20195 .72119 m .20614 .75941 L .23403 .75683 L p .707 .577 .707 r
F P
0 g
s
.19991 .70125 m .19609 .64409 L .17472 .64265 L p .707 .577 .707 r
F P
0 g
s
.24006 .79985 m .23779 .78075 L .20946 .78383 L p .707 .577 .707 r
F P
0 g
s
.30049 .77329 m .30276 .79238 L .331 .78872 L p .707 .577 .707 r
F P
0 g
s
.331 .78872 m .32873 .76963 L .30049 .77329 L p .707 .577 .707 r
F P
0 g
s
.20946 .78383 m .21173 .80292 L .24006 .79985 L p .707 .577 .707 r
F P
0 g
s
.17472 .64265 m .17854 .6998 L .19991 .70125 L p .707 .577 .707 r
F P
0 g
s
.3213 .70823 m .32549 .74645 L .34859 .74324 L p .707 .577 .707 r
F P
0 g
s
.34859 .74324 m .3444 .70502 L .3213 .70823 L p .707 .577 .707 r
F P
0 g
s
.20614 .75941 m .20195 .72119 L .18013 .72286 L p .707 .577 .707 r
F P
0 g
s
.18013 .72286 m .18431 .76108 L .20614 .75941 L p .707 .577 .707 r
F P
0 g
s
.71785 .76807 m .72294 .78517 L .70914 .77763 L p .707 .577 .707 r
F P
0 g
s
.70914 .77763 m .70404 .76052 L .71785 .76807 L p .707 .577 .707 r
F P
0 g
s
.33946 .63281 m .34328 .68997 L .35919 .68559 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .35538 .62843 L .33946 .63281 L p .707 .577 .707 r
F P
0 g
s
.21173 .80292 m .20946 .78383 L .18695 .78604 L p .707 .577 .707 r
F P
0 g
s
.32873 .76963 m .331 .78872 L .35339 .78559 L p .707 .577 .707 r
F P
0 g
s
.35339 .78559 m .35111 .76649 L .32873 .76963 L p .707 .577 .707 r
F P
0 g
s
.18695 .78604 m .18923 .80513 L .21173 .80292 L p .707 .577 .707 r
F P
0 g
s
.69474 .70433 m .70424 .7389 L .68317 .73511 L p .707 .577 .707 r
F P
0 g
s
.68317 .73511 m .67367 .70054 L .69474 .70433 L p .707 .577 .707 r
F P
0 g
s
.6673 .63127 m .6761 .68506 L .64878 .68371 L p .707 .577 .707 r
F P
0 g
s
.64878 .68371 m .63998 .62992 L .6673 .63127 L p .707 .577 .707 r
F P
0 g
s
.17854 .6998 m .17472 .64265 L .16171 .63999 L p .707 .577 .707 r
F P
0 g
s
.36545 .7642 m .36772 .78329 L .3726 .78206 L p .707 .577 .707 r
F P
0 g
s
.3726 .78206 m .37032 .76296 L .36545 .7642 L p .707 .577 .707 r
F P
0 g
s
.36772 .78329 m .36545 .7642 L .35111 .76649 L p .707 .577 .707 r
F P
0 g
s
.37032 .76296 m .3726 .78206 L .36754 .782 L p .707 .577 .707 r
F P
0 g
s
.37179 .80095 m .37179 .29907 L .35764 .28757 L p .707 .577 .707 r
F P
0 g
s
.37179 .29907 m .37179 .80095 L .39849 .81072 L p .707 .577 .707 r
F P
0 g
s
.65502 .75847 m .66012 .77557 L .62971 .78126 L p .707 .577 .707 r
F P
0 g
s
.62883 .29874 m .62883 .80062 L .64257 .78909 L p .707 .577 .707 r
F P
0 g
s
.64257 .78909 m .64257 .2872 L .62883 .29874 L p .707 .577 .707 r
F P
0 g
s
.3444 .70502 m .34859 .74324 L .36381 .74071 L p .707 .577 .707 r
F P
0 g
s
.36381 .74071 m .35962 .70249 L .3444 .70502 L p .707 .577 .707 r
F P
0 g
s
.16171 .63999 m .16553 .69715 L .17854 .6998 L p .707 .577 .707 r
F P
0 g
s
.18431 .76108 m .18013 .72286 L .16651 .72346 L p .707 .577 .707 r
F P
0 g
s
.16651 .72346 m .17069 .76168 L .18431 .76108 L p .707 .577 .707 r
F P
0 g
s
.18923 .80513 m .18695 .78604 L .17246 .78717 L p .707 .577 .707 r
F P
0 g
s
.35111 .76649 m .35339 .78559 L .36772 .78329 L p .707 .577 .707 r
F P
0 g
s
.17246 .78717 m .17474 .80627 L .18923 .80513 L p .707 .577 .707 r
F P
0 g
s
.70404 .76052 m .70914 .77763 L .68749 .77432 L p .707 .577 .707 r
F P
0 g
s
.68749 .77432 m .68239 .75721 L .70404 .76052 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35742 .27546 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35538 .62843 m .35822 .67104 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.36579 .68139 m .36197 .62424 L .35538 .62843 L p .707 .577 .707 r
F P
0 g
s
.35919 .68559 m .36579 .68139 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35822 .67104 m .35919 .68559 L p .35816 .64261 L .707 .577 .707 r
F P
0 g
s
.35859 .62064 m .36241 .67779 L .3494 .67514 L p .707 .577 .707 r
F P
0 g
s
.3494 .67514 m .34558 .61798 L .35859 .62064 L p .707 .577 .707 r
F P
0 g
s
.35962 .70249 m .36381 .74071 L .36967 .7391 L p .707 .577 .707 r
F P
0 g
s
.36967 .7391 m .36548 .70088 L .35962 .70249 L p .707 .577 .707 r
F P
0 g
s
.3614 .70035 m .36559 .73857 L .35197 .73917 L p .707 .577 .707 r
F P
0 g
s
.35197 .73917 m .34778 .70095 L .3614 .70035 L p .707 .577 .707 r
F P
0 g
s
.36527 .76291 m .36754 .782 L .35305 .78314 L p .707 .577 .707 r
F P
0 g
s
.35305 .78314 m .35078 .76405 L .36527 .76291 L p .707 .577 .707 r
F P
0 g
s
.35764 .78946 m .35764 .39217 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.35764 .39217 m .35764 .28757 L p .35743 .29239 L .708 .578 .707 r
F P
0 g
s
.67367 .70054 m .68317 .73511 L .65612 .73568 L p .707 .577 .707 r
F P
0 g
s
.65612 .73568 m .64662 .70111 L .67367 .70054 L p .707 .577 .707 r
F P
0 g
s
.16553 .69715 m .16171 .63999 L .15834 .63639 L p .707 .577 .707 r
F P
0 g
s
.15834 .63639 m .16215 .69354 L .16553 .69715 L p .707 .577 .707 r
F P
0 g
s
.17069 .76168 m .16651 .72346 L .16243 .72293 L p .707 .577 .707 r
F P
0 g
s
.68239 .75721 m .68749 .77432 L .66012 .77557 L p .707 .577 .707 r
F P
0 g
s
.66012 .77557 m .65502 .75847 L .68239 .75721 L p .707 .577 .707 r
F P
0 g
s
.16243 .72293 m .16661 .76115 L .17069 .76168 L p .707 .577 .707 r
F P
0 g
s
.17474 .80627 m .17246 .78717 L .16741 .78712 L p .707 .577 .707 r
F P
0 g
s
.16741 .78712 m .16968 .80621 L .17474 .80627 L p .707 .577 .707 r
F P
0 g
s
.36197 .62424 m .36579 .68139 L .36241 .67779 L p .707 .577 .707 r
F P
0 g
s
.36241 .67779 m .35859 .62064 L .36197 .62424 L p .707 .577 .707 r
F P
0 g
s
.36548 .70088 m .36967 .7391 L .36559 .73857 L p .707 .577 .707 r
F P
0 g
s
.36559 .73857 m .3614 .70035 L .36548 .70088 L p .707 .577 .707 r
F P
0 g
s
.36754 .782 m .36527 .76291 L .37032 .76296 L p .707 .577 .707 r
F P
0 g
s
.35764 .28757 m .35764 .78946 L .37179 .80095 L p .707 .577 .707 r
F P
0 g
s
.64257 .2872 m .64257 .78909 L .64236 .77698 L p .708 .578 .707 r
F P
0 g
s
.64236 .77698 m .64236 .27509 L .64257 .2872 L p .708 .578 .707 r
F P
0 g
s
.16215 .69354 m .15834 .63639 L .16493 .6322 L p .707 .577 .707 r
F P
0 g
s
.16493 .6322 m .16875 .68935 L .16215 .69354 L p .707 .577 .707 r
F P
0 g
s
.16661 .76115 m .16243 .72293 L .16828 .72132 L p .707 .577 .707 r
F P
0 g
s
.16828 .72132 m .17247 .75953 L .16661 .76115 L p .707 .577 .707 r
F P
0 g
s
.16968 .80621 m .16741 .78712 L .17229 .78589 L p .707 .577 .707 r
F P
0 g
s
.17229 .78589 m .17456 .80498 L .16968 .80621 L p .707 .577 .707 r
F P
0 g
s
.35742 .27546 m .35742 .77735 L .35764 .78946 L p .708 .578 .707 r
F P
0 g
s
.35742 .77735 m .35742 .27546 L .37116 .26392 L p .707 .577 .707 r
F P
0 g
s
.64236 .27509 m .64236 .77698 L .62821 .76548 L p .707 .577 .707 r
F P
0 g
s
.62821 .76548 m .62821 .26359 L .64236 .27509 L p .707 .577 .707 r
F P
0 g
s
.16875 .68935 m .16493 .6322 L .18084 .62782 L p .707 .577 .707 r
F P
0 g
s
.18084 .62782 m .18466 .68497 L .16875 .68935 L p .707 .577 .707 r
F P
0 g
s
.17247 .75953 m .16828 .72132 L .18351 .71878 L p .707 .577 .707 r
F P
0 g
s
.18351 .71878 m .18769 .757 L .17247 .75953 L p .707 .577 .707 r
F P
0 g
s
.17456 .80498 m .17229 .78589 L .18662 .78359 L p .707 .577 .707 r
F P
0 g
s
.18662 .78359 m .18889 .80268 L .17456 .80498 L p .707 .577 .707 r
F P
0 g
s
.34558 .61798 m .3494 .67514 L .32803 .67369 L p .707 .577 .707 r
F P
0 g
s
.32803 .67369 m .32421 .61654 L .34558 .61798 L p .707 .577 .707 r
F P
0 g
s
.18466 .68497 m .18084 .62782 L .20452 .62368 L p .707 .577 .707 r
F P
0 g
s
.34778 .70095 m .35197 .73917 L .33014 .74084 L p .707 .577 .707 r
F P
0 g
s
.33014 .74084 m .32595 .70262 L .34778 .70095 L p .707 .577 .707 r
F P
0 g
s
.20452 .62368 m .20834 .68083 L .18466 .68497 L p .707 .577 .707 r
F P
0 g
s
.37116 .26392 m .37116 .76581 L .35742 .77735 L p .707 .577 .707 r
F P
0 g
s
.37116 .76581 m .37116 .26392 L .39752 .25409 L p .707 .577 .707 r
F P
0 g
s
.62821 .26359 m .62821 .76548 L .60151 .75572 L p .707 .577 .707 r
F P
0 g
s
.60151 .75572 m .60151 .25383 L .62821 .26359 L p .707 .577 .707 r
F P
0 g
s
.18769 .757 m .18351 .71878 L .2066 .71558 L p .707 .577 .707 r
F P
0 g
s
.2066 .71558 m .21079 .7538 L .18769 .757 L p .707 .577 .707 r
F P
0 g
s
.32421 .61654 m .32803 .67369 L .30039 .67359 L p .707 .577 .707 r
F P
0 g
s
.30039 .67359 m .29657 .61644 L .32421 .61654 L p .707 .577 .707 r
F P
0 g
s
.18889 .80268 m .18662 .78359 L .209 .78046 L p .707 .577 .707 r
F P
0 g
s
.35078 .76405 m .35305 .78314 L .33054 .78535 L p .707 .577 .707 r
F P
0 g
s
.33054 .78535 m .32827 .76626 L .35078 .76405 L p .707 .577 .707 r
F P
0 g
s
.209 .78046 m .21127 .79955 L .18889 .80268 L p .707 .577 .707 r
F P
0 g
s
.20834 .68083 m .20452 .62368 L .23364 .62019 L p .707 .577 .707 r
F P
0 g
s
.23364 .62019 m .23746 .67735 L .20834 .68083 L p .707 .577 .707 r
F P
0 g
s
.32595 .70262 m .33014 .74084 L .30225 .74342 L p .707 .577 .707 r
F P
0 g
s
.30225 .74342 m .29806 .7052 L .32595 .70262 L p .707 .577 .707 r
F P
0 g
s
.29657 .61644 m .30039 .67359 L .26918 .67485 L p .707 .577 .707 r
F P
0 g
s
.26918 .67485 m .26536 .6177 L .29657 .61644 L p .707 .577 .707 r
F P
0 g
s
.21079 .7538 m .2066 .71558 L .23531 .71201 L p .707 .577 .707 r
F P
0 g
s
.23746 .67735 m .23364 .62019 L .26536 .6177 L p .707 .577 .707 r
F P
0 g
s
.23531 .71201 m .2395 .75023 L .21079 .7538 L p .707 .577 .707 r
F P
0 g
s
.26536 .6177 m .26918 .67485 L .23746 .67735 L p .707 .577 .707 r
F P
0 g
s
.21127 .79955 m .209 .78046 L .23724 .77679 L p .707 .577 .707 r
F P
0 g
s
.32827 .76626 m .33054 .78535 L .30222 .78842 L p .707 .577 .707 r
F P
0 g
s
.30222 .78842 m .29995 .76933 L .32827 .76626 L p .707 .577 .707 r
F P
0 g
s
.23724 .77679 m .23952 .79589 L .21127 .79955 L p .707 .577 .707 r
F P
0 g
s
.73082 .66875 m .73464 .61625 L .70343 .61165 L p .707 .577 .707 r
F P
0 g
s
.73464 .61625 m .73082 .66875 L .76254 .66928 L p .707 .577 .707 r
F P
0 g
s
.76254 .66928 m .76636 .61678 L .73464 .61625 L p .707 .577 .707 r
F P
0 g
s
.39752 .75598 m .39752 .25409 L .4339 .24693 L p .707 .577 .707 r
F P
0 g
s
.39752 .25409 m .39752 .75598 L .37116 .76581 L p .707 .577 .707 r
F P
0 g
s
.60151 .25383 m .60151 .75572 L .56487 .74865 L p .707 .577 .707 r
F P
0 g
s
.56487 .74865 m .56487 .24676 L .60151 .25383 L p .707 .577 .707 r
F P
0 g
s
.29806 .7052 m .30225 .74342 L .27102 .74665 L p .707 .577 .707 r
F P
0 g
s
.27102 .74665 m .26683 .70844 L .29806 .7052 L p .707 .577 .707 r
F P
0 g
s
.76636 .61678 m .76254 .66928 L .79166 .6657 L p .707 .577 .707 r
F P
0 g
s
.79166 .6657 m .79548 .61319 L .76636 .61678 L p .707 .577 .707 r
F P
0 g
s
.2395 .75023 m .23531 .71201 L .26683 .70844 L p .707 .577 .707 r
F P
0 g
s
.69961 .66416 m .70343 .61165 L .67579 .60344 L p .707 .577 .707 r
F P
0 g
s
.70343 .61165 m .69961 .66416 L .73082 .66875 L p .707 .577 .707 r
F P
0 g
s
.26683 .70844 m .27102 .74665 L .2395 .75023 L p .707 .577 .707 r
F P
0 g
s
.23952 .79589 m .23724 .77679 L .26858 .77296 L p .707 .577 .707 r
F P
0 g
s
.29995 .76933 m .30222 .78842 L .27085 .79205 L p .707 .577 .707 r
F P
0 g
s
.27085 .79205 m .26858 .77296 L .29995 .76933 L p .707 .577 .707 r
F P
0 g
s
.26858 .77296 m .27085 .79205 L .23952 .79589 L p .707 .577 .707 r
F P
0 g
s
.79548 .61319 m .79166 .6657 L .81534 .65834 L p .707 .577 .707 r
F P
0 g
s
.81534 .65834 m .81916 .60584 L .79548 .61319 L p .707 .577 .707 r
F P
0 g
s
.67197 .65594 m .67579 .60344 L .65441 .59241 L p .707 .577 .707 r
F P
0 g
s
.67579 .60344 m .67197 .65594 L .69961 .66416 L p .707 .577 .707 r
F P
0 g
s
.4339 .74882 m .4339 .24693 L .47675 .24313 L p .707 .577 .707 r
F P
0 g
s
.4339 .24693 m .4339 .74882 L .39752 .75598 L p .707 .577 .707 r
F P
0 g
s
.56487 .24676 m .56487 .74865 L .52188 .74496 L p .707 .577 .707 r
F P
0 g
s
.52188 .74496 m .52188 .24307 L .56487 .24676 L p .707 .577 .707 r
F P
0 g
s
.72898 .73455 m .73317 .70122 L .70194 .69535 L p .707 .577 .707 r
F P
0 g
s
.73317 .70122 m .72898 .73455 L .7605 .73554 L p .707 .577 .707 r
F P
0 g
s
.7605 .73554 m .76468 .70222 L .73317 .70122 L p .707 .577 .707 r
F P
0 g
s
.81916 .60584 m .81534 .65834 L .83125 .64794 L p .707 .577 .707 r
F P
0 g
s
.83125 .64794 m .83507 .59543 L .81916 .60584 L p .707 .577 .707 r
F P
0 g
s
.69775 .72868 m .70194 .69535 L .67404 .68518 L p .707 .577 .707 r
F P
0 g
s
.70194 .69535 m .69775 .72868 L .72898 .73455 L p .707 .577 .707 r
F P
0 g
s
.65059 .64491 m .65441 .59241 L .6414 .57965 L p .707 .577 .707 r
F P
0 g
s
.65441 .59241 m .65059 .64491 L .67197 .65594 L p .707 .577 .707 r
F P
0 g
s
.76468 .70222 m .7605 .73554 L .78921 .73157 L p .707 .577 .707 r
F P
0 g
s
.78921 .73157 m .79339 .69824 L .76468 .70222 L p .707 .577 .707 r
F P
0 g
s
.47675 .74502 m .47675 .24313 L .52188 .24307 L p .707 .577 .707 r
F P
0 g
s
.47675 .24313 m .47675 .74502 L .4339 .74882 L p .707 .577 .707 r
F P
0 g
s
.52188 .24307 m .52188 .74496 L .47675 .74502 L p .707 .577 .707 r
F P
0 g
s
.66986 .71851 m .67404 .68518 L .65222 .67171 L p .707 .577 .707 r
F P
0 g
s
.67404 .68518 m .66986 .71851 L .69775 .72868 L p .707 .577 .707 r
F P
0 g
s
.79339 .69824 m .78921 .73157 L .8123 .72301 L p .707 .577 .707 r
F P
0 g
s
.8123 .72301 m .81649 .68968 L .79339 .69824 L p .707 .577 .707 r
F P
0 g
s
.83507 .59543 m .83125 .64794 L .83784 .6355 L p .707 .577 .707 r
F P
0 g
s
.83784 .6355 m .84166 .583 L .83507 .59543 L p .707 .577 .707 r
F P
0 g
s
.72914 .77601 m .73142 .75946 L .70005 .75377 L p .707 .577 .707 r
F P
0 g
s
.73142 .75946 m .72914 .77601 L .76048 .7767 L p .707 .577 .707 r
F P
0 g
s
.76048 .7767 m .76276 .76015 L .73142 .75946 L p .707 .577 .707 r
F P
0 g
s
.6414 .57965 m .63758 .63215 L .65059 .64491 L p .707 .577 .707 r
F P
0 g
s
.69778 .77032 m .70005 .75377 L .67173 .74365 L p .707 .577 .707 r
F P
0 g
s
.70005 .75377 m .69778 .77032 L .72914 .77601 L p .707 .577 .707 r
F P
0 g
s
.63758 .63215 m .6414 .57965 L .63803 .5664 L p .707 .577 .707 r
F P
0 g
s
.65222 .67171 m .64803 .70503 L .66986 .71851 L p .707 .577 .707 r
F P
0 g
s
.64803 .70503 m .65222 .67171 L .6386 .65625 L p .707 .577 .707 r
F P
0 g
s
.76276 .76015 m .76048 .7767 L .78873 .77233 L p .707 .577 .707 r
F P
0 g
s
.78873 .77233 m .791 .75578 L .76276 .76015 L p .707 .577 .707 r
F P
0 g
s
.81649 .68968 m .8123 .72301 L .82753 .7107 L p .707 .577 .707 r
F P
0 g
s
.82753 .7107 m .83171 .67738 L .81649 .68968 L p .707 .577 .707 r
F P
0 g
s
.67173 .74365 m .66945 .7602 L .69778 .77032 L p .707 .577 .707 r
F P
0 g
s
.66945 .7602 m .67173 .74365 L .64922 .73008 L p .707 .577 .707 r
F P
0 g
s
.791 .75578 m .78873 .77233 L .81111 .76332 L p .707 .577 .707 r
F P
0 g
s
.81111 .76332 m .81338 .74677 L .791 .75578 L p .707 .577 .707 r
F P
0 g
s
.64922 .73008 m .64695 .74662 L .66945 .7602 L p .707 .577 .707 r
F P
0 g
s
.6386 .65625 m .63441 .68957 L .64803 .70503 L p .707 .577 .707 r
F P
0 g
s
.63803 .5664 m .63421 .6189 L .63758 .63215 L p .707 .577 .707 r
F P
0 g
s
.84166 .583 m .83784 .6355 L .83447 .62226 L p .707 .577 .707 r
F P
0 g
s
.83447 .62226 m .83829 .56976 L .84166 .583 L p .707 .577 .707 r
F P
0 g
s
.63441 .68957 m .6386 .65625 L .63452 .64031 L p .707 .577 .707 r
F P
0 g
s
.64695 .74662 m .64922 .73008 L .63473 .71438 L p .707 .577 .707 r
F P
0 g
s
.63421 .6189 m .63803 .5664 L .64462 .55397 L p .707 .577 .707 r
F P
0 g
s
.83171 .67738 m .82753 .7107 L .83338 .69586 L p .707 .577 .707 r
F P
0 g
s
.83338 .69586 m .83757 .66253 L .83171 .67738 L p .707 .577 .707 r
F P
0 g
s
.63473 .71438 m .63246 .73093 L .64695 .74662 L p .707 .577 .707 r
F P
0 g
s
.81338 .74677 m .81111 .76332 L .82544 .75056 L p .707 .577 .707 r
F P
0 g
s
.82544 .75056 m .82771 .73402 L .81338 .74677 L p .707 .577 .707 r
F P
0 g
s
.63452 .64031 m .63033 .67364 L .63441 .68957 L p .707 .577 .707 r
F P
0 g
s
.63246 .73093 m .63473 .71438 L .62968 .69811 L p .707 .577 .707 r
F P
0 g
s
.64462 .55397 m .6408 .60647 L .63421 .6189 L p .707 .577 .707 r
F P
0 g
s
.83829 .56976 m .83447 .62226 L .82146 .6095 L p .707 .577 .707 r
F P
0 g
s
.82146 .6095 m .82528 .55699 L .83829 .56976 L p .707 .577 .707 r
F P
0 g
s
.63033 .67364 m .63452 .64031 L .64038 .62547 L p .707 .577 .707 r
F P
0 g
s
.6408 .60647 m .64462 .55397 L .66054 .54356 L p .707 .577 .707 r
F P
0 g
s
.3821 .61391 m .39091 .55808 L .36002 .55204 L p .707 .577 .707 r
F P
0 g
s
.39091 .55808 m .3821 .61391 L .41353 .61799 L p .707 .577 .707 r
F P
0 g
s
.41353 .61799 m .42234 .56216 L .39091 .55808 L p .707 .577 .707 r
F P
0 g
s
.83757 .66253 m .83338 .69586 L .8293 .67992 L p .707 .577 .707 r
F P
0 g
s
.8293 .67992 m .83349 .6466 L .83757 .66253 L p .707 .577 .707 r
F P
0 g
s
.62968 .69811 m .6274 .71466 L .63246 .73093 L p .707 .577 .707 r
F P
0 g
s
.42234 .56216 m .41353 .61799 L .44242 .61973 L p .707 .577 .707 r
F P
0 g
s
.44242 .61973 m .45123 .5639 L .42234 .56216 L p .707 .577 .707 r
F P
0 g
s
.35121 .60787 m .36002 .55204 L .3327 .54464 L p .707 .577 .707 r
F P
0 g
s
.36002 .55204 m .35121 .60787 L .3821 .61391 L p .707 .577 .707 r
F P
0 g
s
.82771 .73402 m .82544 .75056 L .83032 .7353 L p .707 .577 .707 r
F P
0 g
s
.83032 .7353 m .83259 .71875 L .82771 .73402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64038 .62547 m .63619 .65879 L .63033 .67364 L p .707 .577 .707 r
F P
0 g
s
.3327 .54464 m .32389 .60047 L .35121 .60787 L p .707 .577 .707 r
F P
0 g
s
.37427 .6705 m .38377 .63371 L .35338 .62508 L p .707 .577 .707 r
F P
0 g
s
.38377 .63371 m .37427 .6705 L .40503 .67763 L p .707 .577 .707 r
F P
0 g
s
.40503 .67763 m .41453 .64083 L .38377 .63371 L p .707 .577 .707 r
F P
0 g
s
.45123 .5639 m .44242 .61973 L .46595 .61895 L p .707 .577 .707 r
F P
0 g
s
.46595 .61895 m .47476 .56312 L .45123 .5639 L p .707 .577 .707 r
F P
0 g
s
.32389 .60047 m .3327 .54464 L .31162 .53661 L p .707 .577 .707 r
F P
0 g
s
.6274 .71466 m .62968 .69811 L .63455 .68285 L p .707 .577 .707 r
F P
0 g
s
.82528 .55699 m .82146 .6095 L .80009 .59847 L p .707 .577 .707 r
F P
0 g
s
.80009 .59847 m .80391 .54597 L .82528 .55699 L p .707 .577 .707 r
F P
0 g
s
.34388 .66188 m .35338 .62508 L .32632 .61579 L p .707 .577 .707 r
F P
0 g
s
.35338 .62508 m .34388 .66188 L .37427 .6705 L p .707 .577 .707 r
F P
0 g
s
.41453 .64083 m .40503 .67763 L .43314 .68256 L p .707 .577 .707 r
F P
0 g
s
.43314 .68256 m .44264 .64576 L .41453 .64083 L p .707 .577 .707 r
F P
0 g
s
.66054 .54356 m .65672 .59607 L .6408 .60647 L p .707 .577 .707 r
F P
0 g
s
.63619 .65879 m .64038 .62547 L .6556 .61316 L p .707 .577 .707 r
F P
0 g
s
.65672 .59607 m .66054 .54356 L .68421 .53621 L p .707 .577 .707 r
F P
0 g
s
.32632 .61579 m .31683 .65259 L .34388 .66188 L p .707 .577 .707 r
F P
0 g
s
.37029 .71285 m .37538 .6945 L .34497 .68547 L p .707 .577 .707 r
F P
0 g
s
.37538 .6945 m .37029 .71285 L .40077 .72043 L p .707 .577 .707 r
F P
0 g
s
.40077 .72043 m .40586 .70208 L .37538 .6945 L p .707 .577 .707 r
F P
0 g
s
.83349 .6466 m .8293 .67992 L .81569 .66446 L p .707 .577 .707 r
F P
0 g
s
.81569 .66446 m .81987 .63114 L .83349 .6466 L p .707 .577 .707 r
F P
0 g
s
.63455 .68285 m .63228 .6994 L .6274 .71466 L p .707 .577 .707 r
F P
0 g
s
.31162 .53661 m .30281 .59244 L .32389 .60047 L p .707 .577 .707 r
F P
0 g
s
.34497 .68547 m .33988 .70382 L .37029 .71285 L p .707 .577 .707 r
F P
0 g
s
.33988 .70382 m .34497 .68547 L .3176 .67588 L p .707 .577 .707 r
F P
0 g
s
.83259 .71875 m .83032 .7353 L .82526 .71903 L p .707 .577 .707 r
F P
0 g
s
.82526 .71903 m .82754 .70248 L .83259 .71875 L p .707 .577 .707 r
F P
0 g
s
.40586 .70208 m .40077 .72043 L .42833 .72583 L p .707 .577 .707 r
F P
0 g
s
.42833 .72583 m .43342 .70748 L .40586 .70208 L p .707 .577 .707 r
F P
0 g
s
.3176 .67588 m .31251 .69423 L .33988 .70382 L p .707 .577 .707 r
F P
0 g
s
.31683 .65259 m .32632 .61579 L .30526 .60676 L p .707 .577 .707 r
F P
0 g
s
.44264 .64576 m .43314 .68256 L .45585 .68481 L p .707 .577 .707 r
F P
0 g
s
.45585 .68481 m .46535 .64801 L .44264 .64576 L p .707 .577 .707 r
F P
0 g
s
.47476 .56312 m .46595 .61895 L .48181 .61573 L p .707 .577 .707 r
F P
0 g
s
.48181 .61573 m .49062 .5599 L .47476 .56312 L p .707 .577 .707 r
F P
0 g
s
.30526 .60676 m .29576 .64356 L .31683 .65259 L p .707 .577 .707 r
F P
0 g
s
.80391 .54597 m .80009 .59847 L .77244 .59025 L p .707 .577 .707 r
F P
0 g
s
.77244 .59025 m .77626 .53775 L .80391 .54597 L p .707 .577 .707 r
F P
0 g
s
.30281 .59244 m .31162 .53661 L .29884 .52873 L p .707 .577 .707 r
F P
0 g
s
.6556 .61316 m .65141 .64649 L .63619 .65879 L p .707 .577 .707 r
F P
0 g
s
.6804 .58871 m .68421 .53621 L .71334 .53262 L p .707 .577 .707 r
F P
0 g
s
.68421 .53621 m .6804 .58871 L .65672 .59607 L p .707 .577 .707 r
F P
0 g
s
.31251 .69423 m .3176 .67588 L .29596 .66668 L p .707 .577 .707 r
F P
0 g
s
.63228 .6994 m .63455 .68285 L .64888 .67009 L p .707 .577 .707 r
F P
0 g
s
.29596 .66668 m .29086 .68502 L .31251 .69423 L p .707 .577 .707 r
F P
0 g
s
.65141 .64649 m .6556 .61316 L .6787 .6046 L p .707 .577 .707 r
F P
0 g
s
.43342 .70748 m .42833 .72583 L .45027 .72852 L p .707 .577 .707 r
F P
0 g
s
.45027 .72852 m .45537 .71017 L .43342 .70748 L p .707 .577 .707 r
F P
0 g
s
.81987 .63114 m .81569 .66446 L .79386 .65099 L p .707 .577 .707 r
F P
0 g
s
.79386 .65099 m .79805 .61766 L .81987 .63114 L p .707 .577 .707 r
F P
0 g
s
.29884 .52873 m .29003 .58456 L .30281 .59244 L p .707 .577 .707 r
F P
0 g
s
.77626 .53775 m .77244 .59025 L .74124 .58566 L p .707 .577 .707 r
F P
0 g
s
.74124 .58566 m .74505 .53315 L .77626 .53775 L p .707 .577 .707 r
F P
0 g
s
.70952 .58512 m .71334 .53262 L .74505 .53315 L p .707 .577 .707 r
F P
0 g
s
.71334 .53262 m .70952 .58512 L .6804 .58871 L p .707 .577 .707 r
F P
0 g
s
.64888 .67009 m .64661 .68664 L .63228 .6994 L p .707 .577 .707 r
F P
0 g
s
.29576 .64356 m .30526 .60676 L .29224 .59886 L p .707 .577 .707 r
F P
0 g
s
.46535 .64801 m .45585 .68481 L .47094 .68416 L p .707 .577 .707 r
F P
0 g
s
.47094 .68416 m .48044 .64736 L .46535 .64801 L p .707 .577 .707 r
F P
0 g
s
.82754 .70248 m .82526 .71903 L .81077 .70334 L p .707 .577 .707 r
F P
0 g
s
.81077 .70334 m .81305 .68679 L .82754 .70248 L p .707 .577 .707 r
F P
0 g
s
.74505 .53315 m .74124 .58566 L .70952 .58512 L p .707 .577 .707 r
F P
0 g
s
.29224 .59886 m .28274 .63566 L .29576 .64356 L p .707 .577 .707 r
F P
0 g
s
.49062 .5599 m .48181 .61573 L .48846 .61038 L p .707 .577 .707 r
F P
0 g
s
.48846 .61038 m .49726 .55455 L .49062 .5599 L p .707 .577 .707 r
F P
0 g
s
.29086 .68502 m .29596 .66668 L .28215 .65875 L p .707 .577 .707 r
F P
0 g
s
.6787 .6046 m .67451 .63793 L .65141 .64649 L p .707 .577 .707 r
F P
0 g
s
.67451 .63793 m .6787 .6046 L .70741 .60062 L p .707 .577 .707 r
F P
0 g
s
.28215 .65875 m .27705 .6771 L .29086 .68502 L p .707 .577 .707 r
F P
0 g
s
.29003 .58456 m .29884 .52873 L .29561 .52178 L p .707 .577 .707 r
F P
0 g
s
.79805 .61766 m .79386 .65099 L .76597 .64082 L p .707 .577 .707 r
F P
0 g
s
.76597 .64082 m .77016 .60749 L .79805 .61766 L p .707 .577 .707 r
F P
0 g
s
.45537 .71017 m .45027 .72852 L .46445 .72823 L p .707 .577 .707 r
F P
0 g
s
.46445 .72823 m .46955 .70988 L .45537 .71017 L p .707 .577 .707 r
F P
0 g
s
.64661 .68664 m .64888 .67009 L .67127 .66108 L p .707 .577 .707 r
F P
0 g
s
.29561 .52178 m .28681 .57761 L .29003 .58456 L p .707 .577 .707 r
F P
0 g
s
.70322 .63395 m .70741 .60062 L .73892 .60162 L p .707 .577 .707 r
F P
0 g
s
.70741 .60062 m .70322 .63395 L .67451 .63793 L p .707 .577 .707 r
F P
0 g
s
.67127 .66108 m .66899 .67763 L .64661 .68664 L p .707 .577 .707 r
F P
0 g
s
.81305 .68679 m .81077 .70334 L .78826 .68976 L p .707 .577 .707 r
F P
0 g
s
.78826 .68976 m .79054 .67321 L .81305 .68679 L p .707 .577 .707 r
F P
0 g
s
.77016 .60749 m .76597 .64082 L .73474 .63495 L p .707 .577 .707 r
F P
0 g
s
.73474 .63495 m .73892 .60162 L .77016 .60749 L p .707 .577 .707 r
F P
0 g
s
.28274 .63566 m .29224 .59886 L .28854 .59288 L p .707 .577 .707 r
F P
0 g
s
.48044 .64736 m .47094 .68416 L .47693 .68067 L p .707 .577 .707 r
F P
0 g
s
.47693 .68067 m .48643 .64387 L .48044 .64736 L p .707 .577 .707 r
F P
0 g
s
.73892 .60162 m .73474 .63495 L .70322 .63395 L p .707 .577 .707 r
F P
0 g
s
.28854 .59288 m .27905 .62968 L .28274 .63566 L p .707 .577 .707 r
F P
0 g
s
.66899 .67763 m .67127 .66108 L .69951 .65671 L p .707 .577 .707 r
F P
0 g
s
.27705 .6771 m .28215 .65875 L .27753 .65288 L p .707 .577 .707 r
F P
0 g
s
.49726 .55455 m .48846 .61038 L .48523 .60342 L p .707 .577 .707 r
F P
0 g
s
.48523 .60342 m .49404 .54759 L .49726 .55455 L p .707 .577 .707 r
F P
0 g
s
.27753 .65288 m .27244 .67123 L .27705 .6771 L p .707 .577 .707 r
F P
0 g
s
.46955 .70988 m .46445 .72823 L .46948 .72499 L p .707 .577 .707 r
F P
0 g
s
.46948 .72499 m .47457 .70664 L .46955 .70988 L p .707 .577 .707 r
F P
0 g
s
.28681 .57761 m .29561 .52178 L .30226 .51642 L p .707 .577 .707 r
F P
0 g
s
.79054 .67321 m .78826 .68976 L .75994 .67964 L p .707 .577 .707 r
F P
0 g
s
.75994 .67964 m .76221 .66309 L .79054 .67321 L p .707 .577 .707 r
F P
0 g
s
.69951 .65671 m .69724 .67326 L .66899 .67763 L p .707 .577 .707 r
F P
0 g
s
.69724 .67326 m .69951 .65671 L .73085 .6574 L p .707 .577 .707 r
F P
0 g
s
.76221 .66309 m .75994 .67964 L .72857 .67395 L p .707 .577 .707 r
F P
0 g
s
.72857 .67395 m .73085 .6574 L .76221 .66309 L p .707 .577 .707 r
F P
0 g
s
.30226 .51642 m .29345 .57225 L .28681 .57761 L p .707 .577 .707 r
F P
0 g
s
.73085 .6574 m .72857 .67395 L .69724 .67326 L p .707 .577 .707 r
F P
0 g
s
.27905 .62968 m .28854 .59288 L .29453 .58939 L p .707 .577 .707 r
F P
0 g
s
.48643 .64387 m .47693 .68067 L .47324 .67468 L p .707 .577 .707 r
F P
0 g
s
.47324 .67468 m .48273 .63788 L .48643 .64387 L p .707 .577 .707 r
F P
0 g
s
.29453 .58939 m .28504 .62619 L .27905 .62968 L p .707 .577 .707 r
F P
0 g
s
.27244 .67123 m .27753 .65288 L .28256 .64964 L p .707 .577 .707 r
F P
0 g
s
.49404 .54759 m .48523 .60342 L .47245 .59554 L p .707 .577 .707 r
F P
0 g
s
.47245 .59554 m .48126 .53971 L .49404 .54759 L p .707 .577 .707 r
F P
0 g
s
.28256 .64964 m .27747 .66799 L .27244 .67123 L p .707 .577 .707 r
F P
0 g
s
.29345 .57225 m .30226 .51642 L .31812 .5132 L p .707 .577 .707 r
F P
0 g
s
.47457 .70664 m .46948 .72499 L .46486 .71912 L p .707 .577 .707 r
F P
0 g
s
.46486 .71912 m .46996 .70077 L .47457 .70664 L p .707 .577 .707 r
F P
0 g
s
.31812 .5132 m .30931 .56903 L .29345 .57225 L p .707 .577 .707 r
F P
0 g
s
.28504 .62619 m .29453 .58939 L .30962 .58874 L p .707 .577 .707 r
F P
0 g
s
.48273 .63788 m .47324 .67468 L .46022 .66678 L p .707 .577 .707 r
F P
0 g
s
.46022 .66678 m .46972 .62999 L .48273 .63788 L p .707 .577 .707 r
F P
0 g
s
.30962 .58874 m .30013 .62553 L .28504 .62619 L p .707 .577 .707 r
F P
0 g
s
.48126 .53971 m .47245 .59554 L .45137 .58751 L p .707 .577 .707 r
F P
0 g
s
.45137 .58751 m .46018 .53168 L .48126 .53971 L p .707 .577 .707 r
F P
0 g
s
.27747 .66799 m .28256 .64964 L .29674 .64935 L p .707 .577 .707 r
F P
0 g
s
.30931 .56903 m .31812 .5132 L .34165 .51242 L p .707 .577 .707 r
F P
0 g
s
.29674 .64935 m .29165 .6677 L .27747 .66799 L p .707 .577 .707 r
F P
0 g
s
.46996 .70077 m .46486 .71912 L .45106 .71119 L p .707 .577 .707 r
F P
0 g
s
.45106 .71119 m .45615 .69284 L .46996 .70077 L p .707 .577 .707 r
F P
0 g
s
.34165 .51242 m .33284 .56825 L .30931 .56903 L p .707 .577 .707 r
F P
0 g
s
.30013 .62553 m .30962 .58874 L .33233 .59098 L p .707 .577 .707 r
F P
0 g
s
.46972 .62999 m .46022 .66678 L .43915 .65775 L p .707 .577 .707 r
F P
0 g
s
.43915 .65775 m .44865 .62095 L .46972 .62999 L p .707 .577 .707 r
F P
0 g
s
.46018 .53168 m .45137 .58751 L .42405 .58012 L p .707 .577 .707 r
F P
0 g
s
.42405 .58012 m .43286 .52429 L .46018 .53168 L p .707 .577 .707 r
F P
0 g
s
.33284 .56825 m .34165 .51242 L .37054 .51416 L p .707 .577 .707 r
F P
0 g
s
.33233 .59098 m .32284 .62778 L .30013 .62553 L p .707 .577 .707 r
F P
0 g
s
.29165 .6677 m .29674 .64935 L .31869 .65203 L p .707 .577 .707 r
F P
0 g
s
.31869 .65203 m .31359 .67038 L .29165 .6677 L p .707 .577 .707 r
F P
0 g
s
.45615 .69284 m .45106 .71119 L .42941 .70198 L p .707 .577 .707 r
F P
0 g
s
.42941 .70198 m .4345 .68363 L .45615 .69284 L p .707 .577 .707 r
F P
0 g
s
.37054 .51416 m .36173 .56999 L .33284 .56825 L p .707 .577 .707 r
F P
0 g
s
.43286 .52429 m .42405 .58012 L .39316 .57408 L p .707 .577 .707 r
F P
0 g
s
.39316 .57408 m .40197 .51825 L .43286 .52429 L p .707 .577 .707 r
F P
0 g
s
.36173 .56999 m .37054 .51416 L .40197 .51825 L p .707 .577 .707 r
F P
0 g
s
.32284 .62778 m .33233 .59098 L .36044 .59591 L p .707 .577 .707 r
F P
0 g
s
.40197 .51825 m .39316 .57408 L .36173 .56999 L p .707 .577 .707 r
F P
0 g
s
.44865 .62095 m .43915 .65775 L .4121 .64847 L p .707 .577 .707 r
F P
0 g
s
.4121 .64847 m .42159 .61167 L .44865 .62095 L p .707 .577 .707 r
F P
0 g
s
.36044 .59591 m .35095 .63271 L .32284 .62778 L p .707 .577 .707 r
F P
0 g
s
.31359 .67038 m .31869 .65203 L .34624 .65743 L p .707 .577 .707 r
F P
0 g
s
.34624 .65743 m .34115 .67578 L .31359 .67038 L p .707 .577 .707 r
F P
0 g
s
.4345 .68363 m .42941 .70198 L .40204 .69239 L p .707 .577 .707 r
F P
0 g
s
.40204 .69239 m .40713 .67405 L .4345 .68363 L p .707 .577 .707 r
F P
0 g
s
.35095 .63271 m .36044 .59591 L .3912 .60304 L p .707 .577 .707 r
F P
0 g
s
.42159 .61167 m .4121 .64847 L .38171 .63984 L p .707 .577 .707 r
F P
0 g
s
.38171 .63984 m .3912 .60304 L .42159 .61167 L p .707 .577 .707 r
F P
0 g
s
.3912 .60304 m .38171 .63984 L .35095 .63271 L p .707 .577 .707 r
F P
0 g
s
.34115 .67578 m .34624 .65743 L .37672 .66502 L p .707 .577 .707 r
F P
0 g
s
.40713 .67405 m .40204 .69239 L .37163 .68337 L p .707 .577 .707 r
F P
0 g
s
.37163 .68337 m .37672 .66502 L .40713 .67405 L p .707 .577 .707 r
F P
0 g
s
.37672 .66502 m .37163 .68337 L .34115 .67578 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007Aoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00L7oo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001^
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000Kgoo001[Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`00K7oo001YOol20006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2001ZOol006Qoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8006Uoo`00IWoo0P0000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000006Moo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol005Qoo`h000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool005Eoo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00003
0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000047oo4@00AGoo001COol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00002Woo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P00?goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00001Woo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00Dgoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000j
Ool005=oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000hOol0059oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<003Ioo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008003Aoo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000a
Ool0059oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
031oo`00DWoo00AJEP00FUIJEP`000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000_Ool0055oo`03001JEP00
00800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0055oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00H0
05YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001AOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60006FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06
001JEUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0059oo`05001J
EUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001COol800000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH01000FUIJEUYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF1P004Goo
1P001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20004FUH00`00FUIJEP070002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH0
0UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF
00<005YF00000`007Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001BOol20003
FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF0P000UYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000=JEP<0029oo`<00003FUH005YF00AJEP07001JEUYFFUH005YF0000;Goo001A
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF0P001Woo2@0057oo0P001EYF00L005YFFUIJ
EP00FUH0000]Ool0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUH005YF0`0000=JEP00FUH00eYF1P0015YF00<005YFFUH0
0UYF20003Woo0P000eYF00L005YFFUIJEP00FUH0000]Ool0055oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00
FUH00002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP06FUH01000FUIJEUYF1P002Woo0P0000=J
EP00FUH00UYF00<005YF0000;Goo001AOol00eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJ
EP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001Woo0`00
00=JEP0000000eYF0P00;Woo001@Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00@005YFFUIJEP80
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH30004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YF0000
0UYF0P00;Woo0017Ool:00000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH00P002eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00@002ioo`00?goo2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEPX000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEP00001JEP0200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP02FUH2000^Ool003Moo`P000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF009JEP<002ioo`00
<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUIJEP00FUH3000015YF001JEUYF
1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP<002ioo`00;Woo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`0035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJEP03
001JEUYF00EJEP03001JEUYF00EJEP800004FUH005YF000^Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF009J
EPH0009JEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP80
0003FUH0000002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEP0000800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUH000000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH015YF00D005YFFUIJEP00031oo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPT00003FUH005YF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF0000<7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000020003FUH00`00FUIJEP070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUH005YF0P000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP8002moo`00;Goo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF
FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01`00FUIJEUYF001J
EP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00008000IJEP<0
00EJEPd000IJEP03001JEUYF00IJEP<000=JEP03001JEUYF009JEP8002moo`00;Goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP07001J
EUYFFUH005YF00002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF1P001eYF1P00
00=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH0
0eYF00<005YF0000;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP07FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP04FUH40005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40007FUH00`00FUH000040003FUH01000FUIJEP00;Woo000^Ool00eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH30007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH2000015YF001JEP000UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF000005YF00H000Eoo`04001JEUYF0002FUH00`00Oomoo`0/
Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP800003
FUH005YF00=JEPL000IJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00=JEP<00004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
000015YF001JEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000Yoo`03001JEP00009JEP03001oogoo02aoo`00;Woo00=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEPP00003FUH005YF00QJEP03
001JEUYF00AJEP@000MJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP8000EJEP03001JEUYF009JEPl000IJEP03
001JEUYF00AJEP8000Qoo`05001JEP00FUH0000_Ool002ioo`03FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF009JEPP00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00=JEP<000=JEP@0
00MJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000AJEP00FUH000AJEPH0009JEP03001J
EUYF008000Qoo`@0009JEP03001JEUYF00EJEP<000Moo`800003FUH007oo02ioo`00;Woo00=JEP00
FUH00eYF00@005YFFUIJEPT000QJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEP0000<0
0003FUH005YF00@0009JEP03001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF
009JEP<0009JEP03001JEUYF009JEP03001JEUYF008000aoo`@000IJEP03001JEUYF008000Ioo`03
001JEP0002moo`00;Woo00=JEP00FUH00UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1UYF00<005YFFUH015YF100000=JEP00FUH01@001UYF00<005YFFUH01EYF3P0035YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00@005YF000000=JEP@000AJEP04
001JEP00000@Ool20004FUH00`00FUIJEP02FUH20003Ool200000eYF001oo`0^Ool002ioo`03FUH0
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF
00IJEP04001JEP000003FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30002FUH30005FUH00`00FUH00003
00001EYF001JEUYF00004Woo0`0000=JEP00FUH01EYF00@007oo001JEP80031oo`00;Woo00EJEP00
001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00MJEP03001JEUYF009JEP@000IJEP@000MJEP03001JEUYF008000MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP04001J
EUYFFUH40002FUH00`00Oomoo`0COol20006FUH20003FUH00`00Oomoo`0^Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00MJEP03001JEUYF00EJEP@000AJEP03001JEUYF008000AJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP@0009JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@001Moo`8000AJEP04001JEP00FUH2000`Ool002moo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000=oo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00D000AJEP<00003FUH005YF00EJEP<000=JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00@0011oo`H0009JEP04001JEUYFFUH3000`Ool0035ooad000]oo`H00003FUH005YF00QJEP03
001JEUYF00AJEP@000AJEP8000IJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP80009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00<000AJEP80031oo`00D7oo2@000eYF00<005YFFUH010001UYF00<005YFFUH0
1eYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0`0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF0P000UYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<007ooOol0;goo0017Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP03FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002
FUH00`00FUH000020003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<Goo000oOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH005YF10001eYF00<005YFFUH01UYF00@005YFFUIJEP80
00=JEP04001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUH0
05YF001JEP00009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF001JEP00<7oo000hOol70003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUH000030002FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300001EYF000005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00L005YF001JEP00FUH00003FUH30007FUH00`00FUIJEP07FUH40005FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001oo`0_Ool0039oo`H0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000=JEP03001JEUYF00=JEP@000MJEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00AJEP8000IJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<00004Ool0
05YF000`Ool002ioo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001J
EP0000<0009JEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH01000FUIJEP001UYF0P0015YF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00L007ooOomoo`00FUH0000`Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00=JEPD000=JEP03001J
EUYF009JEP800003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80
00=JEP03001JEP0000MJEP@00003FUH005YF00MJEPH000=JEP03001JEUYF00EJEP04001JEUYFFUH2
0005Ool2000`Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00MJEPX0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000AJEP8000MJEP04001JEUYFFUH60004FUH00`00FUH000020004FUH00`00FUIJEP05FUH0
1000FUH000001goo0P00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003FUH30007FUH00`00FUIJEP02FUH00`00FUIJEP0:0004
FUH00`00FUIJEP02FUH50009Ool2000`Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP0:0003FUH01000FUH0
000027oo2@003Goo0`00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH<0003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP<000Ioo`@0009JEP03001oogoo01]oo`03001JEP00035oo`00
;goo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF20000UYF00@005YFFUIJEPH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20006FUH20006Ool00`00FUIJ
EP03000LOol01000FUH00000<Goo000_Ool00eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP02FUH70005Ool01@00FUIJEUYF00001eYF00<005YF
FUH01EYF2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@001eYF00<005YFFUH01EYF00@005YF
FUIJEP8000IJEP04001JEP000003Ool01`00FUIJEUYF001JEP0001Yoo`80009JEP03001oogoo031o
o`00;goo0UYF00D005YFFUIJEP0000EJEP03001JEUYF009JEPT0009JEP03001JEUYF009JEPT000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP050002FUH00`00FUIJEP05FUH01P00FUIJEUYF001oo`8000AJEP04001J
EUYFFUH30004FUH01000FUH000005Goo100000EJEP00FUIJEP00039oo`00;goo0UYF00D005YFFUIJ
EP0000=JEPL0009JEP03001JEUYF009JEPT001Eoo`05001JEUYFFUH00006FUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40006FUH01@00FUIJEUYF0000
0goo0P000UYF00<005YFFUH015YF1P0000=JEP00Ool04Goo0`001EYF00<005YF0000<goo000_Ool2
FUHF000NOol01@00FUIJEUYF000015YF0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF0`0015YF00H005YFFUIJEP00Ool70007FUH00`00FUIJ
EP02FUH90007Ool400000eYF001JEP04FUH00`00FUH0000dOol002moo`T002eoo`06001JEUYFFUH0
05YF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH00`0000=JEP00FUH00UYF0P000UYF00@005YFFUIJEP8000IJEP03001J
EUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF00=JEP8003Eoo`00FWoo30000eYF0P001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000EJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003Ioo`00DGoo2@000eYF00<005YFFUH00eYF00<0
05YF00000UYF0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00>7oo0018Ool90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUH005YF001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEP00008000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003]oo`00@7oo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH015YF00D005YFFUIJEP00009JEPd000=JEP03001JEP000140
041oo`00>Goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP<000EJEP03001JEUYF00EJ
EP@000=JEP03001oogoo04eoo`00<goo1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05
001JEUYFFUH00007FUH00`00FUIJEP05FUH20002Ool200000eYF001oo`1>Ool002moo`@0009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPL0
0003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00
FUIJEP04FUH00`00Oomoo`03Ool2001?Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH0000000D000=oo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000025YF00<005YFFUH00UYF0P001Goo00@005YF000004ioo`00
;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4P002goo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF008000QJEP05001JEUYFFUH00007Ool01000FUIJEP00CWoo
000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA000EOol30007FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH30002FUH00`00FUIJEP06FUH30007Ool20002FUH00`00Oomoo`1<Ool0031oo`03FUH005YF
009JEP04001JEUYFFUH@000POol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP05FUH20008
Ool01P00FUIJEP00FUH004ioo`00<7oo00=JEP0000003P00:Woo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP8000IJ
EP03001JEUYF00=JEP8000Uoo`04001JEUYFFUH2001?Ool0031oo`@003Uoo`<00003FUH005YF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000009
FUH00`00FUH00002000:Ool00`00FUIJEP03FUH00`00Oomoo`1=Ool0071oo`@000MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP@0
00]oo`<000EJEP03001oogoo04eoo`00M7oo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02`0000AJEP00FUIJEP@000ioo`05001JEUYFFUH00003FUH00`00Oomo
o`1>Ool007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000=JEP03001JEUYF00T0011o
o`8000AJEP04001JEUYF001AOol0085ooa/000=JEP03001JEUYF00EJEP03001JEP0000@001=oo`03
001JEUYF00EJEP80059oo`00UGoo00<005YF00000UYF00<007oo000040004Woo0`001eYF00<007oo
Ool0DGoo002EOol00`00FUIJEP02000SOol20003FUH00`00FUIJEP02FUH2001DOol009Eoo`04001J
EUYF000ROol20005FUH01@00FUIJEUYF0000EWoo002EOol00`00FUH0000POol30008FUH3001GOol0
09Ioo`03FUH007oo01]oo`@00003FUH005YF00MJEP8005Uoo`00UWoo0`005Woo1@001UYF00<005YF
FUH00eYF0P00Fgoo002FOol200000eYF00000002000>Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP03001MOol009Moo`04001JEUYF0002FUH>0006FUH00`00FUIJEP06FUH3001POol009Moo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<006=oo`00V7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008006Ioo`00VGoo0P00
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF1000JGoo002KOol40003FUH00`00FUIJ
EP04FUH00`00FUIJEP04001]Ool009moo`d0075oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60278 .75323 m .59733 .69857 L .56624 .69927 L p .707 .577 .707 r
F P
0 g
s
.59733 .69857 m .60278 .75323 L .63445 .7494 L p .707 .577 .707 r
F P
0 g
s
.63445 .7494 m .629 .69475 L .59733 .69857 L p .707 .577 .707 r
F P
0 g
s
.629 .69475 m .63445 .7494 L .6636 .74283 L p .707 .577 .707 r
F P
0 g
s
.6636 .74283 m .65815 .68818 L .629 .69475 L p .707 .577 .707 r
F P
0 g
s
.57169 .75393 m .56624 .69927 L .53878 .69678 L p .707 .577 .707 r
F P
0 g
s
.56624 .69927 m .57169 .75393 L .60278 .75323 L p .707 .577 .707 r
F P
0 g
s
.65815 .68818 m .6636 .74283 L .68739 .73415 L p .707 .577 .707 r
F P
0 g
s
.68739 .73415 m .68194 .6795 L .65815 .68818 L p .707 .577 .707 r
F P
0 g
s
.54423 .75144 m .53878 .69678 L .51764 .69134 L p .707 .577 .707 r
F P
0 g
s
.53878 .69678 m .54423 .75144 L .57169 .75393 L p .707 .577 .707 r
F P
0 g
s
.60991 .81555 m .60402 .77971 L .57309 .78206 L p .707 .577 .707 r
F P
0 g
s
.60402 .77971 m .60991 .81555 L .64131 .8098 L p .707 .577 .707 r
F P
0 g
s
.64131 .8098 m .63542 .77396 L .60402 .77971 L p .707 .577 .707 r
F P
0 g
s
.63542 .77396 m .64131 .8098 L .67011 .80122 L p .707 .577 .707 r
F P
0 g
s
.67011 .80122 m .66422 .76538 L .63542 .77396 L p .707 .577 .707 r
F P
0 g
s
.57898 .81791 m .57309 .78206 L .54566 .7808 L p .707 .577 .707 r
F P
0 g
s
.57309 .78206 m .57898 .81791 L .60991 .81555 L p .707 .577 .707 r
F P
0 g
s
.68194 .6795 m .68739 .73415 L .70348 .72422 L p .707 .577 .707 r
F P
0 g
s
.70348 .72422 m .69803 .66956 L .68194 .6795 L p .707 .577 .707 r
F P
0 g
s
.66422 .76538 m .67011 .80122 L .69349 .79065 L p .707 .577 .707 r
F P
0 g
s
.69349 .79065 m .6876 .7548 L .66422 .76538 L p .707 .577 .707 r
F P
0 g
s
.51764 .69134 m .52309 .746 L .54423 .75144 L p .707 .577 .707 r
F P
0 g
s
.61615 .85742 m .61299 .83958 L .582 .84242 L p .707 .577 .707 r
F P
0 g
s
.61299 .83958 m .61615 .85742 L .64742 .85114 L p .707 .577 .707 r
F P
0 g
s
.64742 .85114 m .64427 .8333 L .61299 .83958 L p .707 .577 .707 r
F P
0 g
s
.54566 .7808 m .55155 .81664 L .57898 .81791 L p .707 .577 .707 r
F P
0 g
s
.52309 .746 m .51764 .69134 L .50489 .68349 L p .707 .577 .707 r
F P
0 g
s
.64427 .8333 m .64742 .85114 L .67592 .84204 L p .707 .577 .707 r
F P
0 g
s
.67592 .84204 m .67276 .82419 L .64427 .8333 L p .707 .577 .707 r
F P
0 g
s
.55155 .81664 m .54566 .7808 L .52441 .77603 L p .707 .577 .707 r
F P
0 g
s
.582 .84242 m .58516 .86027 L .61615 .85742 L p .707 .577 .707 r
F P
0 g
s
.58516 .86027 m .582 .84242 L .55433 .84155 L p .707 .577 .707 r
F P
0 g
s
.6876 .7548 m .69349 .79065 L .70915 .77912 L p .707 .577 .707 r
F P
0 g
s
.70915 .77912 m .70326 .74327 L .6876 .7548 L p .707 .577 .707 r
F P
0 g
s
.67276 .82419 m .67592 .84204 L .69885 .83101 L p .707 .577 .707 r
F P
0 g
s
.69885 .83101 m .6957 .81316 L .67276 .82419 L p .707 .577 .707 r
F P
0 g
s
.55433 .84155 m .55749 .8594 L .58516 .86027 L p .707 .577 .707 r
F P
0 g
s
.69803 .66956 m .70348 .72422 L .7103 .714 L p .707 .577 .707 r
F P
0 g
s
.7103 .714 m .70484 .65934 L .69803 .66956 L p .707 .577 .707 r
F P
0 g
s
.52441 .77603 m .5303 .81187 L .55155 .81664 L p .707 .577 .707 r
F P
0 g
s
.50489 .68349 m .51034 .73814 L .52309 .746 L p .707 .577 .707 r
F P
0 g
s
.55749 .8594 m .55433 .84155 L .53269 .83705 L p .707 .577 .707 r
F P
0 g
s
.5303 .81187 m .52441 .77603 L .51143 .76822 L p .707 .577 .707 r
F P
0 g
s
.53269 .83705 m .53584 .8549 L .55749 .8594 L p .707 .577 .707 r
F P
0 g
s
.51034 .73814 m .50489 .68349 L .50176 .67398 L p .707 .577 .707 r
F P
0 g
s
.6957 .81316 m .69885 .83101 L .71397 .81913 L p .707 .577 .707 r
F P
0 g
s
.71397 .81913 m .71082 .80128 L .6957 .81316 L p .707 .577 .707 r
F P
0 g
s
.70326 .74327 m .70915 .77912 L .71557 .76776 L p .707 .577 .707 r
F P
0 g
s
.71557 .76776 m .70968 .73192 L .70326 .74327 L p .707 .577 .707 r
F P
0 g
s
.51143 .76822 m .51732 .80407 L .5303 .81187 L p .707 .577 .707 r
F P
0 g
s
.70484 .65934 m .7103 .714 L .70717 .70449 L p .707 .577 .707 r
F P
0 g
s
.70717 .70449 m .70172 .64984 L .70484 .65934 L p .707 .577 .707 r
F P
0 g
s
.53584 .8549 m .53269 .83705 L .51919 .82936 L p .707 .577 .707 r
F P
0 g
s
.50176 .67398 m .50721 .72864 L .51034 .73814 L p .707 .577 .707 r
F P
0 g
s
.51919 .82936 m .52234 .84721 L .53584 .8549 L p .707 .577 .707 r
F P
0 g
s
.51732 .80407 m .51143 .76822 L .50798 .75815 L p .707 .577 .707 r
F P
0 g
s
.50721 .72864 m .50176 .67398 L .50858 .66376 L p .707 .577 .707 r
F P
0 g
s
.50798 .75815 m .51387 .79399 L .51732 .80407 L p .707 .577 .707 r
F P
0 g
s
.50858 .66376 m .51403 .71842 L .50721 .72864 L p .707 .577 .707 r
F P
0 g
s
.51387 .79399 m .50798 .75815 L .5144 .74679 L p .707 .577 .707 r
F P
0 g
s
.51403 .71842 m .50858 .66376 L .52467 .65383 L p .707 .577 .707 r
F P
0 g
s
.51076 .82181 m .51076 .31993 L .46579 .31893 L p .707 .577 .707 r
F P
0 g
s
.52234 .84721 m .51919 .82936 L .51516 .81924 L p .707 .577 .707 r
F P
0 g
s
.51516 .81924 m .51831 .83708 L .52234 .84721 L p .707 .577 .707 r
F P
0 g
s
.5144 .74679 m .52029 .78264 L .51387 .79399 L p .707 .577 .707 r
F P
0 g
s
.51831 .83708 m .51516 .81924 L .52099 .80767 L p .707 .577 .707 r
F P
0 g
s
.52467 .65383 m .53012 .70848 L .51403 .71842 L p .707 .577 .707 r
F P
0 g
s
.52099 .80767 m .52414 .82551 L .51831 .83708 L p .707 .577 .707 r
F P
0 g
s
.52029 .78264 m .5144 .74679 L .53007 .73526 L p .707 .577 .707 r
F P
0 g
s
.53012 .70848 m .52467 .65383 L .54846 .64515 L p .707 .577 .707 r
F P
0 g
s
.53007 .73526 m .53596 .77111 L .52029 .78264 L p .707 .577 .707 r
F P
0 g
s
.54846 .64515 m .55391 .6998 L .53012 .70848 L p .707 .577 .707 r
F P
0 g
s
.52414 .82551 m .52099 .80767 L .53611 .79578 L p .707 .577 .707 r
F P
0 g
s
.53611 .79578 m .53927 .81363 L .52414 .82551 L p .707 .577 .707 r
F P
0 g
s
.53596 .77111 m .53007 .73526 L .55344 .72469 L p .707 .577 .707 r
F P
0 g
s
.55344 .72469 m .55933 .76053 L .53596 .77111 L p .707 .577 .707 r
F P
0 g
s
.53927 .81363 m .53611 .79578 L .55904 .78475 L p .707 .577 .707 r
F P
0 g
s
.55904 .78475 m .5622 .8026 L .53927 .81363 L p .707 .577 .707 r
F P
0 g
s
.51076 .31993 m .51076 .82181 L .55469 .81903 L p .707 .577 .707 r
F P
0 g
s
.55391 .6998 m .54846 .64515 L .57761 .63857 L p .707 .577 .707 r
F P
0 g
s
.57761 .63857 m .58306 .69323 L .55391 .6998 L p .707 .577 .707 r
F P
0 g
s
.55933 .76053 m .55344 .72469 L .58224 .71611 L p .707 .577 .707 r
F P
0 g
s
.55469 .81903 m .55469 .31715 L .51076 .31993 L p .707 .577 .707 r
F P
0 g
s
.71082 .80128 m .71397 .81913 L .71981 .80756 L p .707 .577 .707 r
F P
0 g
s
.71981 .80756 m .71665 .78971 L .71082 .80128 L p .707 .577 .707 r
F P
0 g
s
.46579 .82082 m .46579 .31893 L .42416 .31425 L p .707 .577 .707 r
F P
0 g
s
.46579 .31893 m .46579 .82082 L .51076 .82181 L p .707 .577 .707 r
F P
0 g
s
.58306 .69323 m .57761 .63857 L .60928 .63475 L p .707 .577 .707 r
F P
0 g
s
.60928 .63475 m .61473 .68941 L .58306 .69323 L p .707 .577 .707 r
F P
0 g
s
.58813 .75195 m .58224 .71611 L .61364 .71036 L p .707 .577 .707 r
F P
0 g
s
.58224 .71611 m .58813 .75195 L .55933 .76053 L p .707 .577 .707 r
F P
0 g
s
.61364 .71036 m .61953 .7462 L .58813 .75195 L p .707 .577 .707 r
F P
0 g
s
.5622 .8026 m .55904 .78475 L .58754 .77565 L p .707 .577 .707 r
F P
0 g
s
.58754 .77565 m .5907 .7935 L .5622 .8026 L p .707 .577 .707 r
F P
0 g
s
.5907 .7935 m .58754 .77565 L .61882 .76937 L p .707 .577 .707 r
F P
0 g
s
.61882 .76937 m .62197 .78722 L .5907 .7935 L p .707 .577 .707 r
F P
0 g
s
.55469 .31715 m .55469 .81903 L .59326 .81275 L p .707 .577 .707 r
F P
0 g
s
.59326 .81275 m .59326 .31086 L .55469 .31715 L p .707 .577 .707 r
F P
0 g
s
.70968 .73192 m .71557 .76776 L .71212 .75769 L p .707 .577 .707 r
F P
0 g
s
.71212 .75769 m .70623 .72184 L .70968 .73192 L p .707 .577 .707 r
F P
0 g
s
.70172 .64984 m .70717 .70449 L .69442 .69664 L p .707 .577 .707 r
F P
0 g
s
.69442 .69664 m .68897 .64198 L .70172 .64984 L p .707 .577 .707 r
F P
0 g
s
.42416 .81614 m .42416 .31425 L .38995 .30635 L p .707 .577 .707 r
F P
0 g
s
.42416 .31425 m .42416 .81614 L .46579 .82082 L p .707 .577 .707 r
F P
0 g
s
.25655 .70503 m .2542 .64828 L .223 .64833 L p .707 .577 .707 r
F P
0 g
s
.2542 .64828 m .25655 .70503 L .28833 .70319 L p .707 .577 .707 r
F P
0 g
s
.28833 .70319 m .28599 .64645 L .2542 .64828 L p .707 .577 .707 r
F P
0 g
s
.28599 .64645 m .28833 .70319 L .31758 .69974 L p .707 .577 .707 r
F P
0 g
s
.31758 .69974 m .31523 .643 L .28599 .64645 L p .707 .577 .707 r
F P
0 g
s
.71665 .78971 m .71981 .80756 L .71577 .79743 L p .707 .577 .707 r
F P
0 g
s
.71577 .79743 m .71262 .77958 L .71665 .78971 L p .707 .577 .707 r
F P
0 g
s
.64037 .63405 m .64582 .68871 L .61473 .68941 L p .707 .577 .707 r
F P
0 g
s
.61473 .68941 m .60928 .63475 L .64037 .63405 L p .707 .577 .707 r
F P
0 g
s
.61953 .7462 m .61364 .71036 L .64457 .708 L p .707 .577 .707 r
F P
0 g
s
.62197 .78722 m .61882 .76937 L .64981 .76653 L p .707 .577 .707 r
F P
0 g
s
.59326 .31086 m .59326 .81275 L .6227 .80357 L p .707 .577 .707 r
F P
0 g
s
.64457 .708 m .65046 .74384 L .61953 .7462 L p .707 .577 .707 r
F P
0 g
s
.64981 .76653 m .65296 .78437 L .62197 .78722 L p .707 .577 .707 r
F P
0 g
s
.6227 .80357 m .6227 .30168 L .59326 .31086 L p .707 .577 .707 r
F P
0 g
s
.22534 .70507 m .223 .64833 L .19541 .64659 L p .707 .577 .707 r
F P
0 g
s
.223 .64833 m .22534 .70507 L .25655 .70503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70623 .72184 m .71212 .75769 L .69914 .74988 L p .707 .577 .707 r
F P
0 g
s
.69914 .74988 m .69325 .71404 L .70623 .72184 L p .707 .577 .707 r
F P
0 g
s
.31523 .643 m .31758 .69974 L .34142 .69502 L p .707 .577 .707 r
F P
0 g
s
.34142 .69502 m .33907 .63828 L .31523 .643 L p .707 .577 .707 r
F P
0 g
s
.26049 .76122 m .25793 .72312 L .22668 .72442 L p .707 .577 .707 r
F P
0 g
s
.25793 .72312 m .26049 .76122 L .29218 .75869 L p .707 .577 .707 r
F P
0 g
s
.29218 .75869 m .28962 .72059 L .25793 .72312 L p .707 .577 .707 r
F P
0 g
s
.19541 .64659 m .19776 .70333 L .22534 .70507 L p .707 .577 .707 r
F P
0 g
s
.68897 .64198 m .69442 .69664 L .67328 .6912 L p .707 .577 .707 r
F P
0 g
s
.67328 .6912 m .66782 .63654 L .68897 .64198 L p .707 .577 .707 r
F P
0 g
s
.28962 .72059 m .29218 .75869 L .32121 .75517 L p .707 .577 .707 r
F P
0 g
s
.32121 .75517 m .31865 .71707 L .28962 .72059 L p .707 .577 .707 r
F P
0 g
s
.22668 .72442 m .22924 .76252 L .26049 .76122 L p .707 .577 .707 r
F P
0 g
s
.38995 .80824 m .38995 .30635 L .36652 .296 L p .707 .577 .707 r
F P
0 g
s
.38995 .30635 m .38995 .80824 L .42416 .81614 L p .707 .577 .707 r
F P
0 g
s
.22924 .76252 m .22668 .72442 L .19892 .72436 L p .707 .577 .707 r
F P
0 g
s
.19776 .70333 m .19541 .64659 L .17416 .64322 L p .707 .577 .707 r
F P
0 g
s
.26429 .80343 m .26291 .78437 L .23155 .78596 L p .707 .577 .707 r
F P
0 g
s
.26291 .78437 m .26429 .80343 L .29589 .80069 L p .707 .577 .707 r
F P
0 g
s
.29589 .80069 m .29451 .78163 L .26291 .78437 L p .707 .577 .707 r
F P
0 g
s
.19892 .72436 m .20148 .76246 L .22924 .76252 L p .707 .577 .707 r
F P
0 g
s
.23155 .78596 m .23293 .80502 L .26429 .80343 L p .707 .577 .707 r
F P
0 g
s
.29451 .78163 m .29589 .80069 L .32465 .79708 L p .707 .577 .707 r
F P
0 g
s
.32465 .79708 m .32327 .77802 L .29451 .78163 L p .707 .577 .707 r
F P
0 g
s
.23293 .80502 m .23155 .78596 L .20351 .78625 L p .707 .577 .707 r
F P
0 g
s
.31865 .71707 m .32121 .75517 L .34474 .751 L p .707 .577 .707 r
F P
0 g
s
.34474 .751 m .34218 .7129 L .31865 .71707 L p .707 .577 .707 r
F P
0 g
s
.17416 .64322 m .17651 .69996 L .19776 .70333 L p .707 .577 .707 r
F P
0 g
s
.20351 .78625 m .20489 .80531 L .23293 .80502 L p .707 .577 .707 r
F P
0 g
s
.71262 .77958 m .71577 .79743 L .70228 .78974 L p .707 .577 .707 r
F P
0 g
s
.70228 .78974 m .69912 .7719 L .71262 .77958 L p .707 .577 .707 r
F P
0 g
s
.33907 .63828 m .34142 .69502 L .35753 .68949 L p .707 .577 .707 r
F P
0 g
s
.35753 .68949 m .35518 .63275 L .33907 .63828 L p .707 .577 .707 r
F P
0 g
s
.6227 .30168 m .6227 .80357 L .64013 .7924 L p .707 .577 .707 r
F P
0 g
s
.64013 .7924 m .64013 .29051 L .6227 .30168 L p .707 .577 .707 r
F P
0 g
s
.20148 .76246 m .19892 .72436 L .17738 .72293 L p .707 .577 .707 r
F P
0 g
s
.69325 .71404 m .69914 .74988 L .67789 .74511 L p .707 .577 .707 r
F P
0 g
s
.67789 .74511 m .672 .70927 L .69325 .71404 L p .707 .577 .707 r
F P
0 g
s
.66782 .63654 m .67328 .6912 L .64582 .68871 L p .707 .577 .707 r
F P
0 g
s
.64582 .68871 m .64037 .63405 L .66782 .63654 L p .707 .577 .707 r
F P
0 g
s
.17738 .72293 m .17994 .76103 L .20148 .76246 L p .707 .577 .707 r
F P
0 g
s
.32327 .77802 m .32465 .79708 L .34776 .79293 L p .707 .577 .707 r
F P
0 g
s
.34776 .79293 m .34638 .77387 L .32327 .77802 L p .707 .577 .707 r
F P
0 g
s
.17651 .69996 m .17416 .64322 L .16132 .63855 L p .707 .577 .707 r
F P
0 g
s
.20489 .80531 m .20351 .78625 L .18153 .7852 L p .707 .577 .707 r
F P
0 g
s
.18153 .7852 m .18291 .80426 L .20489 .80531 L p .707 .577 .707 r
F P
0 g
s
.34218 .7129 m .34474 .751 L .36045 .7466 L p .707 .577 .707 r
F P
0 g
s
.36045 .7466 m .35789 .7085 L .34218 .7129 L p .707 .577 .707 r
F P
0 g
s
.16132 .63855 m .16367 .69529 L .17651 .69996 L p .707 .577 .707 r
F P
0 g
s
.35518 .63275 m .35753 .68949 L .36433 .68369 L p .707 .577 .707 r
F P
0 g
s
.36433 .68369 m .36198 .62695 L .35518 .63275 L p .707 .577 .707 r
F P
0 g
s
.35789 .7085 m .36045 .7466 L .36682 .74239 L p .707 .577 .707 r
F P
0 g
s
.36682 .74239 m .36426 .70429 L .35789 .7085 L p .707 .577 .707 r
F P
0 g
s
.36156 .76961 m .36294 .78867 L .36871 .7847 L p .707 .577 .707 r
F P
0 g
s
.36871 .7847 m .36733 .76564 L .36156 .76961 L p .707 .577 .707 r
F P
0 g
s
.36198 .62695 m .36433 .68369 L .36115 .67819 L p .707 .577 .707 r
F P
0 g
s
.36426 .70429 m .36682 .74239 L .36323 .73879 L p .707 .577 .707 r
F P
0 g
s
.36733 .76564 m .36871 .7847 L .36451 .78142 L p .707 .577 .707 r
F P
0 g
s
.36451 .78142 m .36313 .76236 L .36733 .76564 L p .707 .577 .707 r
F P
0 g
s
.36652 .79789 m .36652 .296 L .35616 .28422 L p .707 .577 .707 r
F P
0 g
s
.36652 .296 m .36652 .79789 L .38995 .80824 L p .707 .577 .707 r
F P
0 g
s
.17994 .76103 m .17738 .72293 L .16417 .72029 L p .707 .577 .707 r
F P
0 g
s
.69912 .7719 m .70228 .78974 L .68063 .78524 L p .707 .577 .707 r
F P
0 g
s
.68063 .78524 m .67748 .7674 L .69912 .7719 L p .707 .577 .707 r
F P
0 g
s
.34638 .77387 m .34776 .79293 L .36294 .78867 L p .707 .577 .707 r
F P
0 g
s
.36294 .78867 m .36156 .76961 L .34638 .77387 L p .707 .577 .707 r
F P
0 g
s
.672 .70927 m .67789 .74511 L .65046 .74384 L p .707 .577 .707 r
F P
0 g
s
.65046 .74384 m .64457 .708 L .672 .70927 L p .707 .577 .707 r
F P
0 g
s
.16417 .72029 m .16673 .75839 L .17994 .76103 L p .707 .577 .707 r
F P
0 g
s
.18291 .80426 m .18153 .7852 L .16777 .78292 L p .707 .577 .707 r
F P
0 g
s
.16777 .78292 m .16915 .80198 L .18291 .80426 L p .707 .577 .707 r
F P
0 g
s
.16367 .69529 m .16132 .63855 L .15814 .63305 L p .707 .577 .707 r
F P
0 g
s
.64013 .29051 m .64013 .7924 L .64384 .78033 L p .707 .577 .707 r
F P
0 g
s
.64384 .78033 m .64384 .27844 L .64013 .29051 L p .707 .577 .707 r
F P
0 g
s
.67748 .7674 m .68063 .78524 L .65296 .78437 L p .707 .577 .707 r
F P
0 g
s
.65296 .78437 m .64981 .76653 L .67748 .7674 L p .707 .577 .707 r
F P
0 g
s
.15814 .63305 m .16049 .68979 L .16367 .69529 L p .707 .577 .707 r
F P
0 g
s
.16673 .75839 m .16417 .72029 L .16057 .71669 L p .707 .577 .707 r
F P
0 g
s
.36115 .67819 m .3588 .62145 L .36198 .62695 L p .707 .577 .707 r
F P
0 g
s
.16057 .71669 m .16313 .75479 L .16673 .75839 L p .707 .577 .707 r
F P
0 g
s
.16915 .80198 m .16777 .78292 L .16357 .77964 L p .707 .577 .707 r
F P
0 g
s
.36323 .73879 m .36067 .70069 L .36426 .70429 L p .707 .577 .707 r
F P
0 g
s
.3588 .62145 m .36115 .67819 L .3483 .67353 L p .707 .577 .707 r
F P
0 g
s
.3483 .67353 m .34596 .61679 L .3588 .62145 L p .707 .577 .707 r
F P
0 g
s
.36067 .70069 m .36323 .73879 L .35001 .73615 L p .707 .577 .707 r
F P
0 g
s
.35001 .73615 m .34745 .69805 L .36067 .70069 L p .707 .577 .707 r
F P
0 g
s
.36313 .76236 m .36451 .78142 L .35075 .77914 L p .707 .577 .707 r
F P
0 g
s
.35075 .77914 m .34937 .76008 L .36313 .76236 L p .707 .577 .707 r
F P
0 g
s
.35616 .28422 m .35616 .78611 L .36652 .79789 L p .707 .577 .707 r
F P
0 g
s
.35616 .78611 m .35616 .28422 L .35987 .27215 L p .707 .577 .707 r
F P
0 g
s
.16357 .77964 m .16495 .7987 L .16915 .80198 L p .707 .577 .707 r
F P
0 g
s
.16049 .68979 m .15814 .63305 L .16493 .62725 L p .707 .577 .707 r
F P
0 g
s
.16493 .62725 m .16728 .684 L .16049 .68979 L p .707 .577 .707 r
F P
0 g
s
.64384 .27844 m .64384 .78033 L .63348 .76854 L p .707 .577 .707 r
F P
0 g
s
.63348 .76854 m .63348 .26666 L .64384 .27844 L p .707 .577 .707 r
F P
0 g
s
.16313 .75479 m .16057 .71669 L .16694 .71248 L p .707 .577 .707 r
F P
0 g
s
.16694 .71248 m .1695 .75058 L .16313 .75479 L p .707 .577 .707 r
F P
0 g
s
.16495 .7987 m .16357 .77964 L .16934 .77567 L p .707 .577 .707 r
F P
0 g
s
.16934 .77567 m .17073 .79473 L .16495 .7987 L p .707 .577 .707 r
F P
0 g
s
.16728 .684 m .16493 .62725 L .18104 .62172 L p .707 .577 .707 r
F P
0 g
s
.35987 .77404 m .35987 .27215 L .3773 .26098 L p .707 .577 .707 r
F P
0 g
s
.35987 .27215 m .35987 .77404 L .35616 .78611 L p .707 .577 .707 r
F P
0 g
s
.18104 .62172 m .18339 .67847 L .16728 .684 L p .707 .577 .707 r
F P
0 g
s
.1695 .75058 m .16694 .71248 L .18266 .70808 L p .707 .577 .707 r
F P
0 g
s
.34596 .61679 m .3483 .67353 L .32705 .67016 L p .707 .577 .707 r
F P
0 g
s
.32705 .67016 m .3247 .61342 L .34596 .61679 L p .707 .577 .707 r
F P
0 g
s
.18266 .70808 m .18522 .74618 L .1695 .75058 L p .707 .577 .707 r
F P
0 g
s
.17073 .79473 m .16934 .77567 L .18452 .77141 L p .707 .577 .707 r
F P
0 g
s
.63348 .26666 m .63348 .76854 L .61004 .75819 L p .707 .577 .707 r
F P
0 g
s
.61004 .75819 m .61004 .25631 L .63348 .26666 L p .707 .577 .707 r
F P
0 g
s
.18452 .77141 m .18591 .79047 L .17073 .79473 L p .707 .577 .707 r
F P
0 g
s
.18339 .67847 m .18104 .62172 L .20489 .61701 L p .707 .577 .707 r
F P
0 g
s
.34745 .69805 m .35001 .73615 L .32847 .73473 L p .707 .577 .707 r
F P
0 g
s
.32847 .73473 m .32591 .69663 L .34745 .69805 L p .707 .577 .707 r
F P
0 g
s
.20489 .61701 m .20724 .67375 L .18339 .67847 L p .707 .577 .707 r
F P
0 g
s
.3247 .61342 m .32705 .67016 L .29947 .66841 L p .707 .577 .707 r
F P
0 g
s
.29947 .66841 m .29712 .61167 L .3247 .61342 L p .707 .577 .707 r
F P
0 g
s
.18522 .74618 m .18266 .70808 L .20618 .70392 L p .707 .577 .707 r
F P
0 g
s
.3773 .26098 m .3773 .76287 L .35987 .77404 L p .707 .577 .707 r
F P
0 g
s
.3773 .76287 m .3773 .26098 L .40674 .2518 L p .707 .577 .707 r
F P
0 g
s
.34937 .76008 m .35075 .77914 L .32877 .77809 L p .707 .577 .707 r
F P
0 g
s
.32877 .77809 m .32739 .75903 L .34937 .76008 L p .707 .577 .707 r
F P
0 g
s
.20724 .67375 m .20489 .61701 L .23413 .61356 L p .707 .577 .707 r
F P
0 g
s
.20618 .70392 m .20874 .74201 L .18522 .74618 L p .707 .577 .707 r
F P
0 g
s
.18591 .79047 m .18452 .77141 L .20763 .76726 L p .707 .577 .707 r
F P
0 g
s
.20763 .76726 m .20901 .78633 L .18591 .79047 L p .707 .577 .707 r
F P
0 g
s
.29712 .61167 m .29947 .66841 L .26826 .66846 L p .707 .577 .707 r
F P
0 g
s
.26826 .66846 m .26591 .61172 L .29712 .61167 L p .707 .577 .707 r
F P
0 g
s
.23413 .61356 m .23648 .6703 L .20724 .67375 L p .707 .577 .707 r
F P
0 g
s
.32591 .69663 m .32847 .73473 L .30072 .73466 L p .707 .577 .707 r
F P
0 g
s
.30072 .73466 m .29816 .69656 L .32591 .69663 L p .707 .577 .707 r
F P
0 g
s
.23648 .6703 m .23413 .61356 L .26591 .61172 L p .707 .577 .707 r
F P
0 g
s
.61004 .25631 m .61004 .75819 L .57584 .7503 L p .707 .577 .707 r
F P
0 g
s
.57584 .7503 m .57584 .24841 L .61004 .25631 L p .707 .577 .707 r
F P
0 g
s
.26591 .61172 m .26826 .66846 L .23648 .6703 L p .707 .577 .707 r
F P
0 g
s
.20874 .74201 m .20618 .70392 L .23521 .70039 L p .707 .577 .707 r
F P
0 g
s
.73174 .66462 m .73408 .61078 L .70288 .60716 L p .707 .577 .707 r
F P
0 g
s
.73408 .61078 m .73174 .66462 L .76352 .6647 L p .707 .577 .707 r
F P
0 g
s
.76352 .6647 m .76587 .61085 L .73408 .61078 L p .707 .577 .707 r
F P
0 g
s
.23521 .70039 m .23777 .73849 L .20874 .74201 L p .707 .577 .707 r
F P
0 g
s
.32739 .75903 m .32877 .77809 L .30073 .77838 L p .707 .577 .707 r
F P
0 g
s
.30073 .77838 m .29935 .75932 L .32739 .75903 L p .707 .577 .707 r
F P
0 g
s
.76587 .61085 m .76352 .6647 L .79276 .66122 L p .707 .577 .707 r
F P
0 g
s
.79276 .66122 m .79511 .60737 L .76587 .61085 L p .707 .577 .707 r
F P
0 g
s
.70053 .66101 m .70288 .60716 L .6753 .60035 L p .707 .577 .707 r
F P
0 g
s
.70288 .60716 m .70053 .66101 L .73174 .66462 L p .707 .577 .707 r
F P
0 g
s
.20901 .78633 m .20763 .76726 L .23639 .76365 L p .707 .577 .707 r
F P
0 g
s
.29816 .69656 m .30072 .73466 L .26946 .73596 L p .707 .577 .707 r
F P
0 g
s
.26946 .73596 m .2669 .69786 L .29816 .69656 L p .707 .577 .707 r
F P
0 g
s
.23639 .76365 m .23777 .78271 L .20901 .78633 L p .707 .577 .707 r
F P
0 g
s
.23777 .73849 m .23521 .70039 L .2669 .69786 L p .707 .577 .707 r
F P
0 g
s
.40674 .75369 m .40674 .2518 L .44531 .24551 L p .707 .577 .707 r
F P
0 g
s
.40674 .2518 m .40674 .75369 L .3773 .76287 L p .707 .577 .707 r
F P
0 g
s
.2669 .69786 m .26946 .73596 L .23777 .73849 L p .707 .577 .707 r
F P
0 g
s
.79511 .60737 m .79276 .66122 L .81661 .65452 L p .707 .577 .707 r
F P
0 g
s
.81661 .65452 m .81895 .60068 L .79511 .60737 L p .707 .577 .707 r
F P
0 g
s
.29935 .75932 m .30073 .77838 L .26938 .77997 L p .707 .577 .707 r
F P
0 g
s
.26938 .77997 m .26799 .76091 L .29935 .75932 L p .707 .577 .707 r
F P
0 g
s
.23777 .78271 m .23639 .76365 L .26799 .76091 L p .707 .577 .707 r
F P
0 g
s
.67295 .65419 m .6753 .60035 L .65404 .59101 L p .707 .577 .707 r
F P
0 g
s
.6753 .60035 m .67295 .65419 L .70053 .66101 L p .707 .577 .707 r
F P
0 g
s
.26799 .76091 m .26938 .77997 L .23777 .78271 L p .707 .577 .707 r
F P
0 g
s
.57584 .24841 m .57584 .7503 L .53421 .74562 L p .707 .577 .707 r
F P
0 g
s
.53421 .74562 m .53421 .24373 L .57584 .24841 L p .707 .577 .707 r
F P
0 g
s
.73054 .72861 m .7331 .6936 L .70184 .68908 L p .707 .577 .707 r
F P
0 g
s
.7331 .6936 m .73054 .72861 L .76223 .72906 L p .707 .577 .707 r
F P
0 g
s
.76223 .72906 m .76479 .69405 L .7331 .6936 L p .707 .577 .707 r
F P
0 g
s
.76479 .69405 m .76223 .72906 L .79126 .7254 L p .707 .577 .707 r
F P
0 g
s
.79126 .7254 m .79382 .69039 L .76479 .69405 L p .707 .577 .707 r
F P
0 g
s
.69928 .72409 m .70184 .68908 L .67409 .68094 L p .707 .577 .707 r
F P
0 g
s
.70184 .68908 m .69928 .72409 L .73054 .72861 L p .707 .577 .707 r
F P
0 g
s
.44531 .7474 m .44531 .24551 L .48923 .24273 L p .707 .577 .707 r
F P
0 g
s
.44531 .24551 m .44531 .7474 L .40674 .75369 L p .707 .577 .707 r
F P
0 g
s
.81895 .60068 m .81661 .65452 L .83271 .64527 L p .707 .577 .707 r
F P
0 g
s
.83271 .64527 m .83506 .59143 L .81895 .60068 L p .707 .577 .707 r
F P
0 g
s
.65404 .59101 m .65169 .64486 L .67295 .65419 L p .707 .577 .707 r
F P
0 g
s
.53421 .24373 m .53421 .74562 L .48923 .74462 L p .707 .577 .707 r
F P
0 g
s
.48923 .74462 m .48923 .24273 L .53421 .24373 L p .707 .577 .707 r
F P
0 g
s
.65169 .64486 m .65404 .59101 L .6412 .58007 L p .707 .577 .707 r
F P
0 g
s
.48923 .24273 m .48923 .74462 L .44531 .7474 L p .707 .577 .707 r
F P
0 g
s
.79382 .69039 m .79126 .7254 L .81478 .71799 L p .707 .577 .707 r
F P
0 g
s
.81478 .71799 m .81734 .68298 L .79382 .69039 L p .707 .577 .707 r
F P
0 g
s
.67153 .71595 m .67409 .68094 L .65255 .66997 L p .707 .577 .707 r
F P
0 g
s
.67409 .68094 m .67153 .71595 L .69928 .72409 L p .707 .577 .707 r
F P
0 g
s
.73062 .77025 m .732 .75282 L .70065 .74835 L p .707 .577 .707 r
F P
0 g
s
.732 .75282 m .73062 .77025 L .76223 .77057 L p .707 .577 .707 r
F P
0 g
s
.76223 .77057 m .76361 .75313 L .732 .75282 L p .707 .577 .707 r
F P
0 g
s
.69926 .76579 m .70065 .74835 L .67261 .74017 L p .707 .577 .707 r
F P
0 g
s
.70065 .74835 m .69926 .76579 L .73062 .77025 L p .707 .577 .707 r
F P
0 g
s
.76361 .75313 m .76223 .77057 L .79099 .7667 L p .707 .577 .707 r
F P
0 g
s
.79099 .7667 m .79237 .74926 L .76361 .75313 L p .707 .577 .707 r
F P
0 g
s
.83506 .59143 m .83271 .64527 L .83951 .63437 L p .707 .577 .707 r
F P
0 g
s
.83951 .63437 m .84186 .58052 L .83506 .59143 L p .707 .577 .707 r
F P
0 g
s
.6412 .58007 m .63885 .63391 L .65169 .64486 L p .707 .577 .707 r
F P
0 g
s
.65255 .66997 m .64999 .70498 L .67153 .71595 L p .707 .577 .707 r
F P
0 g
s
.67261 .74017 m .67123 .75761 L .69926 .76579 L p .707 .577 .707 r
F P
0 g
s
.81734 .68298 m .81478 .71799 L .8305 .70755 L p .707 .577 .707 r
F P
0 g
s
.8305 .70755 m .83306 .67254 L .81734 .68298 L p .707 .577 .707 r
F P
0 g
s
.64999 .70498 m .65255 .66997 L .63933 .65724 L p .707 .577 .707 r
F P
0 g
s
.63885 .63391 m .6412 .58007 L .63802 .56858 L p .707 .577 .707 r
F P
0 g
s
.67123 .75761 m .67261 .74017 L .65063 .72908 L p .707 .577 .707 r
F P
0 g
s
.79237 .74926 m .79099 .7667 L .81409 .75903 L p .707 .577 .707 r
F P
0 g
s
.81409 .75903 m .81547 .74159 L .79237 .74926 L p .707 .577 .707 r
F P
0 g
s
.65063 .72908 m .64925 .74652 L .67123 .75761 L p .707 .577 .707 r
F P
0 g
s
.63933 .65724 m .63677 .69225 L .64999 .70498 L p .707 .577 .707 r
F P
0 g
s
.63802 .56858 m .63567 .62242 L .63885 .63391 L p .707 .577 .707 r
F P
0 g
s
.64925 .74652 m .65063 .72908 L .63687 .71616 L p .707 .577 .707 r
F P
0 g
s
.84186 .58052 m .83951 .63437 L .83633 .62288 L p .707 .577 .707 r
F P
0 g
s
.83633 .62288 m .83868 .56903 L .84186 .58052 L p .707 .577 .707 r
F P
0 g
s
.81547 .74159 m .81409 .75903 L .82927 .7483 L p .707 .577 .707 r
F P
0 g
s
.82927 .7483 m .83065 .73087 L .81547 .74159 L p .707 .577 .707 r
F P
0 g
s
.83306 .67254 m .8305 .70755 L .83687 .6951 L p .707 .577 .707 r
F P
0 g
s
.83687 .6951 m .83943 .66009 L .83306 .67254 L p .707 .577 .707 r
F P
0 g
s
.63677 .69225 m .63933 .65724 L .63573 .64401 L p .707 .577 .707 r
F P
0 g
s
.63687 .71616 m .63549 .73359 L .64925 .74652 L p .707 .577 .707 r
F P
0 g
s
.63567 .62242 m .63802 .56858 L .64482 .55767 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63573 .64401 m .63317 .67902 L .63677 .69225 L p .707 .577 .707 r
F P
0 g
s
.63549 .73359 m .63687 .71616 L .63267 .70267 L p .707 .577 .707 r
F P
0 g
s
.83065 .73087 m .82927 .7483 L .83505 .73557 L p .707 .577 .707 r
F P
0 g
s
.83505 .73557 m .83643 .71814 L .83065 .73087 L p .707 .577 .707 r
F P
0 g
s
.64482 .55767 m .64247 .61152 L .63567 .62242 L p .707 .577 .707 r
F P
0 g
s
.83868 .56903 m .83633 .62288 L .82349 .61193 L p .707 .577 .707 r
F P
0 g
s
.82349 .61193 m .82584 .55809 L .83868 .56903 L p .707 .577 .707 r
F P
0 g
s
.83943 .66009 m .83687 .6951 L .83327 .68187 L p .707 .577 .707 r
F P
0 g
s
.83327 .68187 m .83583 .64686 L .83943 .66009 L p .707 .577 .707 r
F P
0 g
s
.63317 .67902 m .63573 .64401 L .64211 .63156 L p .707 .577 .707 r
F P
0 g
s
.63267 .70267 m .63129 .72011 L .63549 .73359 L p .707 .577 .707 r
F P
0 g
s
.38526 .61658 m .39072 .56066 L .35963 .55623 L p .707 .577 .707 r
F P
0 g
s
.39072 .56066 m .38526 .61658 L .41694 .61879 L p .707 .577 .707 r
F P
0 g
s
.41694 .61879 m .42239 .56287 L .39072 .56066 L p .707 .577 .707 r
F P
0 g
s
.64247 .61152 m .64482 .55767 L .66093 .54842 L p .707 .577 .707 r
F P
0 g
s
.42239 .56287 m .41694 .61879 L .44609 .61855 L p .707 .577 .707 r
F P
0 g
s
.44609 .61855 m .45154 .56263 L .42239 .56287 L p .707 .577 .707 r
F P
0 g
s
.35418 .61214 m .35963 .55623 L .33217 .54999 L p .707 .577 .707 r
F P
0 g
s
.35963 .55623 m .35418 .61214 L .38526 .61658 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64211 .63156 m .63955 .66658 L .63317 .67902 L p .707 .577 .707 r
F P
0 g
s
.45154 .56263 m .44609 .61855 L .46988 .6159 L p .707 .577 .707 r
F P
0 g
s
.46988 .6159 m .47533 .55998 L .45154 .56263 L p .707 .577 .707 r
F P
0 g
s
.63129 .72011 m .63267 .70267 L .63844 .68994 L p .707 .577 .707 r
F P
0 g
s
.38047 .67469 m .38636 .63747 L .35543 .63146 L p .707 .577 .707 r
F P
0 g
s
.38636 .63747 m .38047 .67469 L .41187 .67875 L p .707 .577 .707 r
F P
0 g
s
.41187 .67875 m .41776 .64153 L .38636 .63747 L p .707 .577 .707 r
F P
0 g
s
.33217 .54999 m .32672 .60591 L .35418 .61214 L p .707 .577 .707 r
F P
0 g
s
.83643 .71814 m .83505 .73557 L .83085 .72209 L p .707 .577 .707 r
F P
0 g
s
.83085 .72209 m .83223 .70465 L .83643 .71814 L p .707 .577 .707 r
F P
0 g
s
.82584 .55809 m .82349 .61193 L .80224 .60259 L p .707 .577 .707 r
F P
0 g
s
.80224 .60259 m .80458 .54875 L .82584 .55809 L p .707 .577 .707 r
F P
0 g
s
.32672 .60591 m .33217 .54999 L .31103 .54258 L p .707 .577 .707 r
F P
0 g
s
.66093 .54842 m .65858 .60226 L .64247 .61152 L p .707 .577 .707 r
F P
0 g
s
.83583 .64686 m .83327 .68187 L .82006 .66914 L p .707 .577 .707 r
F P
0 g
s
.82006 .66914 m .82262 .63413 L .83583 .64686 L p .707 .577 .707 r
F P
0 g
s
.41776 .64153 m .41187 .67875 L .44067 .68046 L p .707 .577 .707 r
F P
0 g
s
.44067 .68046 m .44656 .64324 L .41776 .64153 L p .707 .577 .707 r
F P
0 g
s
.34954 .66868 m .35543 .63146 L .32799 .62409 L p .707 .577 .707 r
F P
0 g
s
.35543 .63146 m .34954 .66868 L .38047 .67469 L p .707 .577 .707 r
F P
0 g
s
.63955 .66658 m .64211 .63156 L .65782 .62112 L p .707 .577 .707 r
F P
0 g
s
.63844 .68994 m .63706 .70738 L .63129 .72011 L p .707 .577 .707 r
F P
0 g
s
.65858 .60226 m .66093 .54842 L .68477 .54173 L p .707 .577 .707 r
F P
0 g
s
.32799 .62409 m .3221 .66131 L .34954 .66868 L p .707 .577 .707 r
F P
0 g
s
.37803 .71673 m .38118 .69813 L .35019 .69192 L p .707 .577 .707 r
F P
0 g
s
.38118 .69813 m .37803 .71673 L .4093 .72103 L p .707 .577 .707 r
F P
0 g
s
.4093 .72103 m .41246 .70243 L .38118 .69813 L p .707 .577 .707 r
F P
0 g
s
.31103 .54258 m .30558 .5985 L .32672 .60591 L p .707 .577 .707 r
F P
0 g
s
.35019 .69192 m .34704 .71052 L .37803 .71673 L p .707 .577 .707 r
F P
0 g
s
.44656 .64324 m .44067 .68046 L .46404 .67965 L p .707 .577 .707 r
F P
0 g
s
.46404 .67965 m .46993 .64243 L .44656 .64324 L p .707 .577 .707 r
F P
0 g
s
.34704 .71052 m .35019 .69192 L .32252 .6844 L p .707 .577 .707 r
F P
0 g
s
.41246 .70243 m .4093 .72103 L .4378 .723 L p .707 .577 .707 r
F P
0 g
s
.4378 .723 m .44096 .7044 L .41246 .70243 L p .707 .577 .707 r
F P
0 g
s
.47533 .55998 m .46988 .6159 L .48597 .61108 L p .707 .577 .707 r
F P
0 g
s
.48597 .61108 m .49142 .55516 L .47533 .55998 L p .707 .577 .707 r
F P
0 g
s
.3221 .66131 m .32799 .62409 L .30675 .61607 L p .707 .577 .707 r
F P
0 g
s
.65782 .62112 m .65526 .65613 L .63955 .66658 L p .707 .577 .707 r
F P
0 g
s
.32252 .6844 m .31936 .703 L .34704 .71052 L p .707 .577 .707 r
F P
0 g
s
.80458 .54875 m .80224 .60259 L .77465 .59578 L p .707 .577 .707 r
F P
0 g
s
.77465 .59578 m .777 .54194 L .80458 .54875 L p .707 .577 .707 r
F P
0 g
s
.30558 .5985 m .31103 .54258 L .29827 .5347 L p .707 .577 .707 r
F P
0 g
s
.63706 .70738 m .63844 .68994 L .65362 .67922 L p .707 .577 .707 r
F P
0 g
s
.30675 .61607 m .30086 .6533 L .3221 .66131 L p .707 .577 .707 r
F P
0 g
s
.68242 .59557 m .68477 .54173 L .71401 .53825 L p .707 .577 .707 r
F P
0 g
s
.68477 .54173 m .68242 .59557 L .65858 .60226 L p .707 .577 .707 r
F P
0 g
s
.83223 .70465 m .83085 .72209 L .81708 .70917 L p .707 .577 .707 r
F P
0 g
s
.81708 .70917 m .81847 .69173 L .83223 .70465 L p .707 .577 .707 r
F P
0 g
s
.82262 .63413 m .82006 .66914 L .79852 .65817 L p .707 .577 .707 r
F P
0 g
s
.79852 .65817 m .80108 .62316 L .82262 .63413 L p .707 .577 .707 r
F P
0 g
s
.65526 .65613 m .65782 .62112 L .68135 .61371 L p .707 .577 .707 r
F P
0 g
s
.31936 .703 m .32252 .6844 L .30088 .67631 L p .707 .577 .707 r
F P
0 g
s
.44096 .7044 m .4378 .723 L .46073 .72244 L p .707 .577 .707 r
F P
0 g
s
.46073 .72244 m .46389 .70384 L .44096 .7044 L p .707 .577 .707 r
F P
0 g
s
.65362 .67922 m .65224 .69666 L .63706 .70738 L p .707 .577 .707 r
F P
0 g
s
.30088 .67631 m .29772 .69492 L .31936 .703 L p .707 .577 .707 r
F P
0 g
s
.29827 .5347 m .29282 .59062 L .30558 .5985 L p .707 .577 .707 r
F P
0 g
s
.777 .54194 m .77465 .59578 L .74345 .59216 L p .707 .577 .707 r
F P
0 g
s
.74345 .59216 m .74579 .53832 L .777 .54194 L p .707 .577 .707 r
F P
0 g
s
.46993 .64243 m .46404 .67965 L .47971 .67641 L p .707 .577 .707 r
F P
0 g
s
.47971 .67641 m .4856 .63919 L .46993 .64243 L p .707 .577 .707 r
F P
0 g
s
.71166 .59209 m .71401 .53825 L .74579 .53832 L p .707 .577 .707 r
F P
0 g
s
.71401 .53825 m .71166 .59209 L .68242 .59557 L p .707 .577 .707 r
F P
0 g
s
.30086 .6533 m .30675 .61607 L .29376 .6082 L p .707 .577 .707 r
F P
0 g
s
.74579 .53832 m .74345 .59216 L .71166 .59209 L p .707 .577 .707 r
F P
0 g
s
.49142 .55516 m .48597 .61108 L .49278 .60457 L p .707 .577 .707 r
F P
0 g
s
.49278 .60457 m .49823 .54865 L .49142 .55516 L p .707 .577 .707 r
F P
0 g
s
.68135 .61371 m .67879 .64872 L .65526 .65613 L p .707 .577 .707 r
F P
0 g
s
.29376 .6082 m .28787 .64542 L .30086 .6533 L p .707 .577 .707 r
F P
0 g
s
.80108 .62316 m .79852 .65817 L .77076 .65003 L p .707 .577 .707 r
F P
0 g
s
.77076 .65003 m .77332 .61502 L .80108 .62316 L p .707 .577 .707 r
F P
0 g
s
.67879 .64872 m .68135 .61371 L .71038 .61005 L p .707 .577 .707 r
F P
0 g
s
.29282 .59062 m .29827 .5347 L .29515 .52714 L p .707 .577 .707 r
F P
0 g
s
.65224 .69666 m .65362 .67922 L .67672 .67155 L p .707 .577 .707 r
F P
0 g
s
.29772 .69492 m .30088 .67631 L .28738 .66845 L p .707 .577 .707 r
F P
0 g
s
.81847 .69173 m .81708 .70917 L .79511 .69807 L p .707 .577 .707 r
F P
0 g
s
.79511 .69807 m .79649 .68064 L .81847 .69173 L p .707 .577 .707 r
F P
0 g
s
.46389 .70384 m .46073 .72244 L .47585 .71942 L p .707 .577 .707 r
F P
0 g
s
.47585 .71942 m .47901 .70081 L .46389 .70384 L p .707 .577 .707 r
F P
0 g
s
.28738 .66845 m .28422 .68705 L .29772 .69492 L p .707 .577 .707 r
F P
0 g
s
.67672 .67155 m .67534 .68898 L .65224 .69666 L p .707 .577 .707 r
F P
0 g
s
.77332 .61502 m .77076 .65003 L .73951 .64551 L p .707 .577 .707 r
F P
0 g
s
.73951 .64551 m .74207 .6105 L .77332 .61502 L p .707 .577 .707 r
F P
0 g
s
.70782 .64506 m .71038 .61005 L .74207 .6105 L p .707 .577 .707 r
F P
0 g
s
.71038 .61005 m .70782 .64506 L .67879 .64872 L p .707 .577 .707 r
F P
0 g
s
.29515 .52714 m .2897 .58306 L .29282 .59062 L p .707 .577 .707 r
F P
0 g
s
.4856 .63919 m .47971 .67641 L .48613 .67104 L p .707 .577 .707 r
F P
0 g
s
.48613 .67104 m .49202 .63382 L .4856 .63919 L p .707 .577 .707 r
F P
0 g
s
.74207 .6105 m .73951 .64551 L .70782 .64506 L p .707 .577 .707 r
F P
0 g
s
.28787 .64542 m .29376 .6082 L .29031 .60124 L p .707 .577 .707 r
F P
0 g
s
.67534 .68898 m .67672 .67155 L .70549 .66768 L p .707 .577 .707 r
F P
0 g
s
.79649 .68064 m .79511 .69807 L .76707 .68989 L p .707 .577 .707 r
F P
0 g
s
.76707 .68989 m .76845 .67246 L .79649 .68064 L p .707 .577 .707 r
F P
0 g
s
.49823 .54865 m .49278 .60457 L .48966 .59701 L p .707 .577 .707 r
F P
0 g
s
.48966 .59701 m .49511 .54109 L .49823 .54865 L p .707 .577 .707 r
F P
0 g
s
.29031 .60124 m .28442 .63846 L .28787 .64542 L p .707 .577 .707 r
F P
0 g
s
.70549 .66768 m .70411 .68511 L .67534 .68898 L p .707 .577 .707 r
F P
0 g
s
.28422 .68705 m .28738 .66845 L .28335 .66158 L p .707 .577 .707 r
F P
0 g
s
.47901 .70081 m .47585 .71942 L .48169 .71421 L p .707 .577 .707 r
F P
0 g
s
.48169 .71421 m .48484 .69561 L .47901 .70081 L p .707 .577 .707 r
F P
0 g
s
.2897 .58306 m .29515 .52714 L .30197 .52063 L p .707 .577 .707 r
F P
0 g
s
.28335 .66158 m .28019 .68019 L .28422 .68705 L p .707 .577 .707 r
F P
0 g
s
.70411 .68511 m .70549 .66768 L .73709 .66799 L p .707 .577 .707 r
F P
0 g
s
.76845 .67246 m .76707 .68989 L .73571 .68543 L p .707 .577 .707 r
F P
0 g
s
.73571 .68543 m .73709 .66799 L .76845 .67246 L p .707 .577 .707 r
F P
0 g
s
.73709 .66799 m .73571 .68543 L .70411 .68511 L p .707 .577 .707 r
F P
0 g
s
.30197 .52063 m .29652 .57655 L .2897 .58306 L p .707 .577 .707 r
F P
0 g
s
.49202 .63382 m .48613 .67104 L .48268 .66408 L p .707 .577 .707 r
F P
0 g
s
.48268 .66408 m .48857 .62686 L .49202 .63382 L p .707 .577 .707 r
F P
0 g
s
.28442 .63846 m .29031 .60124 L .29674 .59587 L p .707 .577 .707 r
F P
0 g
s
.49511 .54109 m .48966 .59701 L .47691 .58913 L p .707 .577 .707 r
F P
0 g
s
.47691 .58913 m .48236 .53321 L .49511 .54109 L p .707 .577 .707 r
F P
0 g
s
.29674 .59587 m .29084 .6331 L .28442 .63846 L p .707 .577 .707 r
F P
0 g
s
.28019 .68019 m .28335 .66158 L .28918 .65638 L p .707 .577 .707 r
F P
0 g
s
.48484 .69561 m .48169 .71421 L .47765 .70734 L p .707 .577 .707 r
F P
0 g
s
.47765 .70734 m .48081 .68874 L .48484 .69561 L p .707 .577 .707 r
F P
0 g
s
.29652 .57655 m .30197 .52063 L .31806 .51581 L p .707 .577 .707 r
F P
0 g
s
.28918 .65638 m .28602 .67498 L .28019 .68019 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31806 .51581 m .31261 .57173 L .29652 .57655 L p .707 .577 .707 r
F P
0 g
s
.48857 .62686 m .48268 .66408 L .4697 .65621 L p .707 .577 .707 r
F P
0 g
s
.4697 .65621 m .47559 .61899 L .48857 .62686 L p .707 .577 .707 r
F P
0 g
s
.29084 .6331 m .29674 .59587 L .3124 .59263 L p .707 .577 .707 r
F P
0 g
s
.48236 .53321 m .47691 .58913 L .45576 .58172 L p .707 .577 .707 r
F P
0 g
s
.45576 .58172 m .46121 .5258 L .48236 .53321 L p .707 .577 .707 r
F P
0 g
s
.3124 .59263 m .30651 .62985 L .29084 .6331 L p .707 .577 .707 r
F P
0 g
s
.31261 .57173 m .31806 .51581 L .34184 .51316 L p .707 .577 .707 r
F P
0 g
s
.28602 .67498 m .28918 .65638 L .3043 .65335 L p .707 .577 .707 r
F P
0 g
s
.48081 .68874 m .47765 .70734 L .46416 .69948 L p .707 .577 .707 r
F P
0 g
s
.46416 .69948 m .46731 .68088 L .48081 .68874 L p .707 .577 .707 r
F P
0 g
s
.3043 .65335 m .30114 .67195 L .28602 .67498 L p .707 .577 .707 r
F P
0 g
s
.34184 .51316 m .33639 .56908 L .31261 .57173 L p .707 .577 .707 r
F P
0 g
s
.47559 .61899 m .4697 .65621 L .44845 .6482 L p .707 .577 .707 r
F P
0 g
s
.44845 .6482 m .45434 .61097 L .47559 .61899 L p .707 .577 .707 r
F P
0 g
s
.46121 .5258 m .45576 .58172 L .42831 .57548 L p .707 .577 .707 r
F P
0 g
s
.42831 .57548 m .43376 .51957 L .46121 .5258 L p .707 .577 .707 r
F P
0 g
s
.30651 .62985 m .3124 .59263 L .33578 .59182 L p .707 .577 .707 r
F P
0 g
s
.33639 .56908 m .34184 .51316 L .371 .51292 L p .707 .577 .707 r
F P
0 g
s
.33578 .59182 m .32989 .62905 L .30651 .62985 L p .707 .577 .707 r
F P
0 g
s
.30114 .67195 m .3043 .65335 L .32723 .65279 L p .707 .577 .707 r
F P
0 g
s
.46731 .68088 m .46416 .69948 L .44251 .6914 L p .707 .577 .707 r
F P
0 g
s
.44251 .6914 m .44567 .67279 L .46731 .68088 L p .707 .577 .707 r
F P
0 g
s
.43376 .51957 m .42831 .57548 L .39722 .57105 L p .707 .577 .707 r
F P
0 g
s
.39722 .57105 m .40267 .51513 L .43376 .51957 L p .707 .577 .707 r
F P
0 g
s
.36555 .56884 m .371 .51292 L .40267 .51513 L p .707 .577 .707 r
F P
0 g
s
.371 .51292 m .36555 .56884 L .33639 .56908 L p .707 .577 .707 r
F P
0 g
s
.32723 .65279 m .32408 .6714 L .30114 .67195 L p .707 .577 .707 r
F P
0 g
s
.40267 .51513 m .39722 .57105 L .36555 .56884 L p .707 .577 .707 r
F P
0 g
s
.45434 .61097 m .44845 .6482 L .42102 .64082 L p .707 .577 .707 r
F P
0 g
s
.42102 .64082 m .42691 .6036 L .45434 .61097 L p .707 .577 .707 r
F P
0 g
s
.32989 .62905 m .33578 .59182 L .36458 .59353 L p .707 .577 .707 r
F P
0 g
s
.36458 .59353 m .35869 .63075 L .32989 .62905 L p .707 .577 .707 r
F P
0 g
s
.42691 .6036 m .42102 .64082 L .39009 .63481 L p .707 .577 .707 r
F P
0 g
s
.39009 .63481 m .39598 .59759 L .42691 .6036 L p .707 .577 .707 r
F P
0 g
s
.32408 .6714 m .32723 .65279 L .35573 .65476 L p .707 .577 .707 r
F P
0 g
s
.44567 .67279 m .44251 .6914 L .41484 .68388 L p .707 .577 .707 r
F P
0 g
s
.41484 .68388 m .418 .66527 L .44567 .67279 L p .707 .577 .707 r
F P
0 g
s
.35869 .63075 m .36458 .59353 L .39598 .59759 L p .707 .577 .707 r
F P
0 g
s
.35573 .65476 m .35258 .67336 L .32408 .6714 L p .707 .577 .707 r
F P
0 g
s
.39598 .59759 m .39009 .63481 L .35869 .63075 L p .707 .577 .707 r
F P
0 g
s
.35258 .67336 m .35573 .65476 L .38701 .65906 L p .707 .577 .707 r
F P
0 g
s
.418 .66527 m .41484 .68388 L .38385 .67766 L p .707 .577 .707 r
F P
0 g
s
.38385 .67766 m .38701 .65906 L .418 .66527 L p .707 .577 .707 r
F P
0 g
s
.38701 .65906 m .38385 .67766 L .35258 .67336 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
O7oo8@00P7oo001fOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH9001g
Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
079oo`00L7oo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF1000KWoo001]Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH00000K7oo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Moo`80009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8006Moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P00Igoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001VOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol0
06Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005iooa0000EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001UOol005Uoo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`<000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001U
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYF001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
3goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP002UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF009JEPH003moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000kOol005=oo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP000Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF1000=goo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
=7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000aOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00DWoo00<005YF0000
0eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYF001JEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF00000UYF1@0000=JEP00FUH0
1UYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0009
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001BOol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH0000^Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0059oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0P000eYF0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00005@000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008000YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP03001JEUYF009J
EQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0004FUH00`00FUIJEP02FUH6000;Ool30004Ool60006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
02eoo`00DWoo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@001eYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEP0000<000moo`D000Uoo`@0009JEP03001JEUYF00=J
EP06001JEUYF001JEP00;Goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH30002FUH0
0`00FUH00003000;Ool5000=Ool30005FUH01P00FUIJEP00FUH002eoo`00DWoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001UYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF001J
EP8000EJEP03001JEUYF00=JEPL000Aoo`D000Uoo`D0009JEP8000=JEP06001JEUYF001JEP00;Goo
0017Ool;00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH30003FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00H005YF000005YF0005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJ
EP03FUH2000015YF001JEUYF0P00;Woo000oOol80004FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP020002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP03FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH0
0`00FUIJEP04FUH30002FUH2000^Ool003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P00;Woo000bOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20003
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF
00@005YFFUIJEP<002ioo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP<002ioo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF008000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800005
FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01000FUIJEUYF0`00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH60002FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEP0002ioo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF00002@001UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0002ioo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF2P000UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00D005YFFUIJEP0000EJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF1P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1P001EYF00<0
05YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00`0000=JEP00FUH00UYF0`002eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF0P0015YF00<005YF00000`001eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP00
00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP04001JEUYFFUH90002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004FUH20002FUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000
FUIJEUYF0P00;Woo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF000005YF00<000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF009JEPH000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00IJEP03001J
EUYF00AJEP04001JEUYFFUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH000020006FUH00`00FUIJEP03FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF1@0000=oo`0000000eYF00H005YFFUH005YF000^Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP03FUHJ0008Ool200001eYF001JEUYF001JEP0002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4`000eYF00@005YFFUIJEPL000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP06001JEUYFFUH005YF
0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF
1`000eYF00<005YFFUH01UYF00<005YFFUH0100047oo0P000UYF00<005YF0000;Woo000]Ool00`00
FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH015YF00<005YF00001`0000=JEP00FUH015YF
2@0015YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF0`0000EJEP00001JEP00
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@000ioo`05001JEP00FUH0000^Ool002eoo`03001J
EP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH60006FUH00`00FUIJEP06FUH00`00FUH000030002FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH01000FUH00000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002goo0`00;goo
000]Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF0P00
15YF00<005YF00000`001UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30006Ool200000eYF0000000_Ool002eoo`06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF0`0015YF00@005YFFUIJ
EP8000AJEP03001JEUYF00T000IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP8000EJEP03001JEUYF009JEQ0000IJEP03
001JEUYF00EJEP<0009oo`8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEP0000@000=JEP80
00AJEP03001JEUYF00H000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP001EYF1@00
00=JEP0000000`002Woo10000UYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF0P00
;goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH200000eYF001JEP05FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP060007FUH40004FUH00`00
FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
0eYF00@005YFFUIJEP<000MJEP03001JEUYF00@000Yoo`@000EJEP03001JEUYF00=JEP8000=JEP80
02moo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF009JEP<00003FUH0
05YF00UJEP@00003FUH005YF00=JEP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP04001JEP000002FUH00`00FUIJEP05FUH00`00FUIJEP04FUHB0000
0eYF001JEP05FUH20002FUH2000_Ool002moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ800003FUH005YF00MJEP03001JEUYF00AJEPL0009JEP03001JEUYF00QJEP04001JEUYF
FUH20003FUH01@00FUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`001EYF00@005YF001JEP8002moo`00<Goo10000eYF00<005YFFUH015YF200015YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF0080031oo`00=Goo2P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00@0
05YFFUIJEQ00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH200000eYF001JEP02FUH00`00Oomoo`0^Ool0039oo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0P000eYF00<007ooOol0;Woo000_Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP03001o
ogoo02ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH02@001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP000000;goo000]Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000P001eYF1@000UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000goo0`00;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH015YF4`001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000P001eYF00<005YFFUH00UYF1@001UYF1P000eYF00<005YFFUH01EYF
00<005YF00000`001Woo0P00;goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH01@000UYF1P000eYF00<005YFFUH00UYF1@002Woo0P00;goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
00IJEP03001JEUYF009JEP03001JEUYF008000=ooa0000moo`8002moo`00;Goo00@005YFFUH000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP04001J
EP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
009JEP05001JEUYFFUH0000POol4000_Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEPl00003FUH005YF00MJEP03001JEUYF009JEPL000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP80009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEP007Woo0P000UYF0P00
;goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF00001EYF0`001EYF00@005YFFUH001eoo`04001JEUYFFUH2000`Ool002ioo`03
001JEP0000=JEP04001JEUYFFUH60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020006
FUH00`00FUH00003000015YF001JEUYF0P006Woo0`000eYF0P00<7oo000^Ool00`00FUH00002FUH5
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH9000<FUH<0006FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH6000HOol20002FUH01@00
FUIJEUYF0000<Goo000^Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF200015YF00<005YFFUH01EYF00<005YFFUH01P00
25YF00<005YFFUH02UYF00<005YFFUH02EYF2@001eYF00<005YFFUH015YF00D005YFFUH007oo0080
00=JEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP04001JEUYF000bOol002ioo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Ioo`8000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPD0009JEP03001JEUYF00AJEP04001JEUYF0003Ool200000eYF001J
EP07FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH3000cOol002moo`80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ4000Eoo`8000AJEP03001JEUYF
00@000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00@000EJEP04001JEUYF0005Ool30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000eOol0035oob0000AJEP03001JEUYF00EJEP03001JEUYF00L000AJ
EP@000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP8000=JEP04001JEUYF0006Ool60002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00=goo0010Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH000000eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<00004FUH005YFFUH70006FUH5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000>Goo000hOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH00000FUH00P0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P000UYF0P000eYF1`0000=JEP00FUH00UYF1@000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1@00>goo000cOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH010000UYF0P000Woo4000@7oo000`Ool3
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000MJ
EP03001JEUYF00=JEPD0059oo`00;Woo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF7`0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000MJ
EP03001JEUYF009JEP03001JEUYF0080059oo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF20001goo2@000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
001BOol002ioo`03001JEP0000=JEP04001JEUYFFUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`000eYF00<0
05YFFUH00P00DGoo000^Ool00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH00`00Oomoo`1?
Ool002ioo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH50002Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo0P0000=JEP00Ool0D7oo000^Ool30003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008Ool00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030008FUH01000FUH0000027oo0P00DGoo000^Ool0
0`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
000@Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH3000:Ool3001@Ool002moob40
01]oo`800003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000aoo`800003FUH007oo04moo`00
KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH00UYF0P001eYF00<005YF00000P0037oo0P0000AJEP00FUH0051oo`00L7oo0`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`0015YF
1P003Woo00@005YFFUIJEP80055oo`00Lgoo100000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF3`004goo00<005YFFUH00UYF0P00DGoo001gOol70006FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUHF000EOol30004FUH00`00Oomoo`1@Ool007iooaX0015oo`D001=oo`80
009JEP05001JEUYFFUH0001COol0099oo`03001JEP0001Eoo`<0015oo`<000EJEP03001JEP0005Ao
o`00TWoo00<005YF00009Goo100000=JEP00FUH01EYF0P00EGoo002COol2000POol50005FUH00`00
FUIJEP04FUH00`00Oomoo`1DOol009=oo`04001JEP00000JOol40002FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00Egoo002COol20002FUH3000@Ool70006FUH00`00FUIJEP06FUH01000FUH00000FGoo
002COol20002FUH00`00FUIJEP0@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001KOol009Ao
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH2001NOol009Eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00002001POol009Ioo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPH006=oo`00V7oo0`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@00JGoo002KOol@001b
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5894 .74536 m .59483 .68946 L .56386 .68492 L p .707 .577 .707 r
F P
0 g
s
.59483 .68946 m .5894 .74536 L .62112 .74768 L p .707 .577 .707 r
F P
0 g
s
.62112 .74768 m .62655 .69177 L .59483 .68946 L p .707 .577 .707 r
F P
0 g
s
.62655 .69177 m .62112 .74768 L .65049 .74754 L p .707 .577 .707 r
F P
0 g
s
.65049 .74754 m .65591 .69164 L .62655 .69177 L p .707 .577 .707 r
F P
0 g
s
.55843 .74082 m .56386 .68492 L .53667 .6786 L p .707 .577 .707 r
F P
0 g
s
.56386 .68492 m .55843 .74082 L .5894 .74536 L p .707 .577 .707 r
F P
0 g
s
.65591 .69164 m .65049 .74754 L .67462 .74498 L p .707 .577 .707 r
F P
0 g
s
.67462 .74498 m .68005 .68907 L .65591 .69164 L p .707 .577 .707 r
F P
0 g
s
.58215 .80331 m .58797 .76611 L .55733 .75991 L p .707 .577 .707 r
F P
0 g
s
.58797 .76611 m .58215 .80331 L .61368 .80758 L p .707 .577 .707 r
F P
0 g
s
.61368 .80758 m .6195 .77039 L .58797 .76611 L p .707 .577 .707 r
F P
0 g
s
.53667 .6786 m .53125 .73451 L .55843 .74082 L p .707 .577 .707 r
F P
0 g
s
.53125 .73451 m .53667 .6786 L .51592 .67113 L p .707 .577 .707 r
F P
0 g
s
.6195 .77039 m .61368 .80758 L .64299 .80951 L p .707 .577 .707 r
F P
0 g
s
.64299 .80951 m .64882 .77231 L .6195 .77039 L p .707 .577 .707 r
F P
0 g
s
.5515 .79711 m .55733 .75991 L .53056 .75239 L p .707 .577 .707 r
F P
0 g
s
.55733 .75991 m .5515 .79711 L .58215 .80331 L p .707 .577 .707 r
F P
0 g
s
.57589 .84513 m .57898 .82655 L .54853 .81998 L p .707 .577 .707 r
F P
0 g
s
.57898 .82655 m .57589 .84513 L .60741 .84982 L p .707 .577 .707 r
F P
0 g
s
.60741 .84982 m .61049 .83124 L .57898 .82655 L p .707 .577 .707 r
F P
0 g
s
.53056 .75239 m .52473 .78959 L .5515 .79711 L p .707 .577 .707 r
F P
0 g
s
.64882 .77231 m .64299 .80951 L .66723 .8089 L p .707 .577 .707 r
F P
0 g
s
.66723 .8089 m .67305 .7717 L .64882 .77231 L p .707 .577 .707 r
F P
0 g
s
.51592 .67113 m .5105 .72703 L .53125 .73451 L p .707 .577 .707 r
F P
0 g
s
.61049 .83124 m .60741 .84982 L .6369 .85219 L p .707 .577 .707 r
F P
0 g
s
.6369 .85219 m .63999 .83361 L .61049 .83124 L p .707 .577 .707 r
F P
0 g
s
.68005 .68907 m .67462 .74498 L .69116 .74022 L p .707 .577 .707 r
F P
0 g
s
.69116 .74022 m .69659 .68432 L .68005 .68907 L p .707 .577 .707 r
F P
0 g
s
.54853 .81998 m .54544 .83856 L .57589 .84513 L p .707 .577 .707 r
F P
0 g
s
.54544 .83856 m .54853 .81998 L .52213 .81219 L p .707 .577 .707 r
F P
0 g
s
.52473 .78959 m .53056 .75239 L .51028 .74427 L p .707 .577 .707 r
F P
0 g
s
.52213 .81219 m .51904 .83077 L .54544 .83856 L p .707 .577 .707 r
F P
0 g
s
.5105 .72703 m .51592 .67113 L .50365 .66322 L p .707 .577 .707 r
F P
0 g
s
.63999 .83361 m .6369 .85219 L .66149 .852 L p .707 .577 .707 r
F P
0 g
s
.66149 .852 m .66458 .83341 L .63999 .83361 L p .707 .577 .707 r
F P
0 g
s
.51028 .74427 m .50446 .78147 L .52473 .78959 L p .707 .577 .707 r
F P
0 g
s
.67305 .7717 m .66723 .8089 L .68402 .80581 L p .707 .577 .707 r
F P
0 g
s
.68402 .80581 m .68984 .76861 L .67305 .7717 L p .707 .577 .707 r
F P
0 g
s
.51904 .83077 m .52213 .81219 L .50235 .80394 L p .707 .577 .707 r
F P
0 g
s
.50365 .66322 m .49823 .71913 L .5105 .72703 L p .707 .577 .707 r
F P
0 g
s
.50235 .80394 m .49927 .82252 L .51904 .83077 L p .707 .577 .707 r
F P
0 g
s
.69659 .68432 m .69116 .74022 L .69849 .73375 L p .707 .577 .707 r
F P
0 g
s
.69849 .73375 m .70392 .67785 L .69659 .68432 L p .707 .577 .707 r
F P
0 g
s
.50446 .78147 m .51028 .74427 L .49849 .73637 L p .707 .577 .707 r
F P
0 g
s
.66458 .83341 m .66149 .852 L .67877 .84926 L p .707 .577 .707 r
F P
0 g
s
.67877 .84926 m .68185 .83068 L .66458 .83341 L p .707 .577 .707 r
F P
0 g
s
.49849 .73637 m .49267 .77357 L .50446 .78147 L p .707 .577 .707 r
F P
0 g
s
.49823 .71913 m .50365 .66322 L .50105 .65567 L p .707 .577 .707 r
F P
0 g
s
.49927 .82252 m .50235 .80394 L .49115 .79603 L p .707 .577 .707 r
F P
0 g
s
.68984 .76861 m .68402 .80581 L .69171 .80054 L p .707 .577 .707 r
F P
0 g
s
.69171 .80054 m .69754 .76334 L .68984 .76861 L p .707 .577 .707 r
F P
0 g
s
.49115 .79603 m .48806 .81461 L .49927 .82252 L p .707 .577 .707 r
F P
0 g
s
.50105 .65567 m .49563 .71157 L .49823 .71913 L p .707 .577 .707 r
F P
0 g
s
.49267 .77357 m .49849 .73637 L .49634 .72945 L p .707 .577 .707 r
F P
0 g
s
.70392 .67785 m .69849 .73375 L .6959 .72619 L p .707 .577 .707 r
F P
0 g
s
.6959 .72619 m .70132 .67029 L .70392 .67785 L p .707 .577 .707 r
F P
0 g
s
.68185 .83068 m .67877 .84926 L .68704 .84426 L p .707 .577 .707 r
F P
0 g
s
.68704 .84426 m .69013 .82568 L .68185 .83068 L p .707 .577 .707 r
F P
0 g
s
.49634 .72945 m .49052 .76665 L .49267 .77357 L p .707 .577 .707 r
F P
0 g
s
.49563 .71157 m .50105 .65567 L .50838 .64919 L p .707 .577 .707 r
F P
0 g
s
.50838 .64919 m .50296 .7051 L .49563 .71157 L p .707 .577 .707 r
F P
0 g
s
.50296 .7051 m .50838 .64919 L .52493 .64444 L p .707 .577 .707 r
F P
0 g
s
.52493 .64444 m .5195 .70035 L .50296 .7051 L p .707 .577 .707 r
F P
0 g
s
.49821 .76138 m .50403 .72418 L .52082 .7211 L p .707 .577 .707 r
F P
0 g
s
.52082 .7211 m .515 .75829 L .49821 .76138 L p .707 .577 .707 r
F P
0 g
s
.49479 .80282 m .49788 .78424 L .51515 .78151 L p .707 .577 .707 r
F P
0 g
s
.51515 .78151 m .51207 .80009 L .49479 .80282 L p .707 .577 .707 r
F P
0 g
s
.515 .75829 m .52082 .7211 L .54506 .72048 L p .707 .577 .707 r
F P
0 g
s
.54506 .72048 m .53924 .75768 L .515 .75829 L p .707 .577 .707 r
F P
0 g
s
.51207 .80009 m .51515 .78151 L .53974 .78131 L p .707 .577 .707 r
F P
0 g
s
.53974 .78131 m .53665 .79989 L .51207 .80009 L p .707 .577 .707 r
F P
0 g
s
.51537 .8217 m .51537 .31981 L .4703 .31921 L p .707 .577 .707 r
F P
0 g
s
.5195 .70035 m .52493 .64444 L .54906 .64187 L p .707 .577 .707 r
F P
0 g
s
.54906 .64187 m .54364 .69778 L .5195 .70035 L p .707 .577 .707 r
F P
0 g
s
.54364 .69778 m .54906 .64187 L .57842 .64174 L p .707 .577 .707 r
F P
0 g
s
.57842 .64174 m .573 .69765 L .54364 .69778 L p .707 .577 .707 r
F P
0 g
s
.53924 .75768 m .54506 .72048 L .57438 .72241 L p .707 .577 .707 r
F P
0 g
s
.57438 .72241 m .56856 .75961 L .53924 .75768 L p .707 .577 .707 r
F P
0 g
s
.53665 .79989 m .53974 .78131 L .56924 .78368 L p .707 .577 .707 r
F P
0 g
s
.56924 .78368 m .56615 .80226 L .53665 .79989 L p .707 .577 .707 r
F P
0 g
s
.51537 .31981 m .51537 .8217 L .55894 .81854 L p .707 .577 .707 r
F P
0 g
s
.55894 .81854 m .55894 .31666 L .51537 .31981 L p .707 .577 .707 r
F P
0 g
s
.4703 .82109 m .4703 .31921 L .42813 .31489 L p .707 .577 .707 r
F P
0 g
s
.48806 .81461 m .49115 .79603 L .48961 .78924 L p .707 .577 .707 r
F P
0 g
s
.48961 .78924 m .48652 .80782 L .48806 .81461 L p .707 .577 .707 r
F P
0 g
s
.49052 .76665 m .49634 .72945 L .50403 .72418 L p .707 .577 .707 r
F P
0 g
s
.50403 .72418 m .49821 .76138 L .49052 .76665 L p .707 .577 .707 r
F P
0 g
s
.48652 .80782 m .48961 .78924 L .49788 .78424 L p .707 .577 .707 r
F P
0 g
s
.49788 .78424 m .49479 .80282 L .48652 .80782 L p .707 .577 .707 r
F P
0 g
s
.4703 .31921 m .4703 .82109 L .51537 .8217 L p .707 .577 .707 r
F P
0 g
s
.69754 .76334 m .69171 .80054 L .68956 .79362 L p .707 .577 .707 r
F P
0 g
s
.68956 .79362 m .69538 .75642 L .69754 .76334 L p .707 .577 .707 r
F P
0 g
s
.573 .69765 m .57842 .64174 L .61014 .64406 L p .707 .577 .707 r
F P
0 g
s
.61014 .64406 m .60472 .69996 L .573 .69765 L p .707 .577 .707 r
F P
0 g
s
.56856 .75961 m .57438 .72241 L .6059 .72668 L p .707 .577 .707 r
F P
0 g
s
.6059 .72668 m .60008 .76388 L .56856 .75961 L p .707 .577 .707 r
F P
0 g
s
.56615 .80226 m .56924 .78368 L .60075 .78837 L p .707 .577 .707 r
F P
0 g
s
.60075 .78837 m .59767 .80695 L .56615 .80226 L p .707 .577 .707 r
F P
0 g
s
.55894 .31666 m .55894 .81854 L .59674 .81193 L p .707 .577 .707 r
F P
0 g
s
.59674 .81193 m .59674 .31004 L .55894 .31666 L p .707 .577 .707 r
F P
0 g
s
.42813 .81678 m .42813 .31489 L .393 .30729 L p .707 .577 .707 r
F P
0 g
s
.42813 .31489 m .42813 .81678 L .4703 .82109 L p .707 .577 .707 r
F P
0 g
s
.70132 .67029 m .6959 .72619 L .68362 .71829 L p .707 .577 .707 r
F P
0 g
s
.68362 .71829 m .68905 .66238 L .70132 .67029 L p .707 .577 .707 r
F P
0 g
s
.69013 .82568 m .68704 .84426 L .6855 .83747 L p .707 .577 .707 r
F P
0 g
s
.6855 .83747 m .68858 .81889 L .69013 .82568 L p .707 .577 .707 r
F P
0 g
s
.24986 .71984 m .25218 .66602 L .22109 .66223 L p .707 .577 .707 r
F P
0 g
s
.25218 .66602 m .24986 .71984 L .28169 .72009 L p .707 .577 .707 r
F P
0 g
s
.28169 .72009 m .28401 .66627 L .25218 .66602 L p .707 .577 .707 r
F P
0 g
s
.64111 .64859 m .63569 .7045 L .60472 .69996 L p .707 .577 .707 r
F P
0 g
s
.60472 .69996 m .61014 .64406 L .64111 .64859 L p .707 .577 .707 r
F P
0 g
s
.63655 .73288 m .63073 .77008 L .60008 .76388 L p .707 .577 .707 r
F P
0 g
s
.60008 .76388 m .6059 .72668 L .63655 .73288 L p .707 .577 .707 r
F P
0 g
s
.6312 .79494 m .62811 .81352 L .59767 .80695 L p .707 .577 .707 r
F P
0 g
s
.59767 .80695 m .60075 .78837 L .6312 .79494 L p .707 .577 .707 r
F P
0 g
s
.59674 .31004 m .59674 .81193 L .62507 .8025 L p .707 .577 .707 r
F P
0 g
s
.62507 .8025 m .62507 .30061 L .59674 .31004 L p .707 .577 .707 r
F P
0 g
s
.28401 .66627 m .28169 .72009 L .31114 .71676 L p .707 .577 .707 r
F P
0 g
s
.31114 .71676 m .31346 .66294 L .28401 .66627 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21876 .71605 m .22109 .66223 L .19378 .65526 L p .707 .577 .707 r
F P
0 g
s
.22109 .66223 m .21876 .71605 L .24986 .71984 L p .707 .577 .707 r
F P
0 g
s
.69538 .75642 m .68956 .79362 L .67777 .78572 L p .707 .577 .707 r
F P
0 g
s
.67777 .78572 m .68359 .74852 L .69538 .75642 L p .707 .577 .707 r
F P
0 g
s
.393 .80918 m .393 .30729 L .36835 .29714 L p .707 .577 .707 r
F P
0 g
s
.393 .30729 m .393 .80918 L .42813 .81678 L p .707 .577 .707 r
F P
0 g
s
.31346 .66294 m .31114 .71676 L .33533 .71019 L p .707 .577 .707 r
F P
0 g
s
.33533 .71019 m .33765 .65637 L .31346 .66294 L p .707 .577 .707 r
F P
0 g
s
.68905 .66238 m .68362 .71829 L .66288 .71082 L p .707 .577 .707 r
F P
0 g
s
.66288 .71082 m .6683 .65491 L .68905 .66238 L p .707 .577 .707 r
F P
0 g
s
.68858 .81889 m .6855 .83747 L .67429 .82956 L p .707 .577 .707 r
F P
0 g
s
.67429 .82956 m .67738 .81098 L .68858 .81889 L p .707 .577 .707 r
F P
0 g
s
.19145 .70908 m .19378 .65526 L .17292 .6458 L p .707 .577 .707 r
F P
0 g
s
.19378 .65526 m .19145 .70908 L .21876 .71605 L p .707 .577 .707 r
F P
0 g
s
.2462 .78387 m .24869 .74892 L .21772 .74392 L p .707 .577 .707 r
F P
0 g
s
.24869 .74892 m .2462 .78387 L .27802 .78479 L p .707 .577 .707 r
F P
0 g
s
.27802 .78479 m .28051 .74985 L .24869 .74892 L p .707 .577 .707 r
F P
0 g
s
.28051 .74985 m .27802 .78479 L .30757 .78155 L p .707 .577 .707 r
F P
0 g
s
.30757 .78155 m .31006 .74661 L .28051 .74985 L p .707 .577 .707 r
F P
0 g
s
.33765 .65637 m .33533 .71019 L .35189 .70102 L p .707 .577 .707 r
F P
0 g
s
.35189 .70102 m .35422 .64719 L .33765 .65637 L p .707 .577 .707 r
F P
0 g
s
.6683 .65491 m .66288 .71082 L .63569 .7045 L p .707 .577 .707 r
F P
0 g
s
.63569 .7045 m .64111 .64859 L .6683 .65491 L p .707 .577 .707 r
F P
0 g
s
.66332 .74041 m .6575 .77761 L .63073 .77008 L p .707 .577 .707 r
F P
0 g
s
.63073 .77008 m .63655 .73288 L .66332 .74041 L p .707 .577 .707 r
F P
0 g
s
.62811 .81352 m .6312 .79494 L .6576 .80273 L p .707 .577 .707 r
F P
0 g
s
.62507 .30061 m .62507 .8025 L .64115 .79119 L p .707 .577 .707 r
F P
0 g
s
.64115 .79119 m .64115 .2893 L .62507 .30061 L p .707 .577 .707 r
F P
0 g
s
.21523 .77887 m .21772 .74392 L .19063 .73534 L p .707 .577 .707 r
F P
0 g
s
.21772 .74392 m .21523 .77887 L .2462 .78387 L p .707 .577 .707 r
F P
0 g
s
.68359 .74852 m .67777 .78572 L .6575 .77761 L p .707 .577 .707 r
F P
0 g
s
.6575 .77761 m .66332 .74041 L .68359 .74852 L p .707 .577 .707 r
F P
0 g
s
.17292 .6458 m .17059 .69962 L .19145 .70908 L p .707 .577 .707 r
F P
0 g
s
.17059 .69962 m .17292 .6458 L .16056 .63477 L p .707 .577 .707 r
F P
0 g
s
.31006 .74661 m .30757 .78155 L .33195 .77447 L p .707 .577 .707 r
F P
0 g
s
.33195 .77447 m .33445 .73952 L .31006 .74661 L p .707 .577 .707 r
F P
0 g
s
.36834 .79903 m .36835 .29714 L .35658 .28545 L p .707 .577 .707 r
F P
0 g
s
.36835 .29714 m .36834 .79903 L .393 .80918 L p .707 .577 .707 r
F P
0 g
s
.67738 .81098 m .67429 .82956 L .65452 .82131 L p .707 .577 .707 r
F P
0 g
s
.65452 .82131 m .6576 .80273 L .67738 .81098 L p .707 .577 .707 r
F P
0 g
s
.18814 .77028 m .19063 .73534 L .17007 .72401 L p .707 .577 .707 r
F P
0 g
s
.19063 .73534 m .18814 .77028 L .21523 .77887 L p .707 .577 .707 r
F P
0 g
s
.24247 .82559 m .24378 .80822 L .21296 .80281 L p .707 .577 .707 r
F P
0 g
s
.24378 .80822 m .24247 .82559 L .27432 .82683 L p .707 .577 .707 r
F P
0 g
s
.27432 .82683 m .27563 .80946 L .24378 .80822 L p .707 .577 .707 r
F P
0 g
s
.27563 .80946 m .27432 .82683 L .30407 .82378 L p .707 .577 .707 r
F P
0 g
s
.30407 .82378 m .30539 .80642 L .27563 .80946 L p .707 .577 .707 r
F P
0 g
s
.21165 .82018 m .21296 .80281 L .18619 .79377 L p .707 .577 .707 r
F P
0 g
s
.21296 .80281 m .21165 .82018 L .24247 .82559 L p .707 .577 .707 r
F P
0 g
s
.35422 .64719 m .35189 .70102 L .3592 .69014 L p .707 .577 .707 r
F P
0 g
s
.3592 .69014 m .36153 .63632 L .35422 .64719 L p .707 .577 .707 r
F P
0 g
s
.33445 .73952 m .33195 .77447 L .34879 .76423 L p .707 .577 .707 r
F P
0 g
s
.34879 .76423 m .35128 .72929 L .33445 .73952 L p .707 .577 .707 r
F P
0 g
s
.16056 .63477 m .15823 .68859 L .17059 .69962 L p .707 .577 .707 r
F P
0 g
s
.17007 .72401 m .16757 .75896 L .18814 .77028 L p .707 .577 .707 r
F P
0 g
s
.30539 .80642 m .30407 .82378 L .32883 .81675 L p .707 .577 .707 r
F P
0 g
s
.32883 .81675 m .33014 .79938 L .30539 .80642 L p .707 .577 .707 r
F P
0 g
s
.18619 .79377 m .18488 .81114 L .21165 .82018 L p .707 .577 .707 r
F P
0 g
s
.15823 .68859 m .16056 .63477 L .1579 .62325 L p .707 .577 .707 r
F P
0 g
s
.16757 .75896 m .17007 .72401 L .15805 .71105 L p .707 .577 .707 r
F P
0 g
s
.6576 .80273 m .65452 .82131 L .62811 .81352 L p .707 .577 .707 r
F P
0 g
s
.18488 .81114 m .18619 .79377 L .16609 .78197 L p .707 .577 .707 r
F P
0 g
s
.64115 .2893 m .64115 .79119 L .64342 .77909 L p .707 .577 .707 r
F P
0 g
s
.64342 .77909 m .64342 .2772 L .64115 .2893 L p .707 .577 .707 r
F P
0 g
s
.16609 .78197 m .16478 .79934 L .18488 .81114 L p .707 .577 .707 r
F P
0 g
s
.33014 .79938 m .32883 .81675 L .34617 .80641 L p .707 .577 .707 r
F P
0 g
s
.34617 .80641 m .34748 .78904 L .33014 .79938 L p .707 .577 .707 r
F P
0 g
s
.15805 .71105 m .15555 .74599 L .16757 .75896 L p .707 .577 .707 r
F P
0 g
s
.35128 .72929 m .34879 .76423 L .35644 .75184 L p .707 .577 .707 r
F P
0 g
s
.35644 .75184 m .35893 .71689 L .35128 .72929 L p .707 .577 .707 r
F P
0 g
s
.36153 .63632 m .3592 .69014 L .35655 .67862 L p .707 .577 .707 r
F P
0 g
s
.35655 .67862 m .35887 .6248 L .36153 .63632 L p .707 .577 .707 r
F P
0 g
s
.35893 .71689 m .35644 .75184 L .35413 .73851 L p .707 .577 .707 r
F P
0 g
s
.35413 .73851 m .35663 .70356 L .35893 .71689 L p .707 .577 .707 r
F P
0 g
s
.35887 .6248 m .35655 .67862 L .34419 .66759 L p .707 .577 .707 r
F P
0 g
s
.34419 .66759 m .34651 .61377 L .35887 .6248 L p .707 .577 .707 r
F P
0 g
s
.35663 .70356 m .35413 .73851 L .34211 .72555 L p .707 .577 .707 r
F P
0 g
s
.34211 .72555 m .3446 .6906 L .35663 .70356 L p .707 .577 .707 r
F P
0 g
s
.35658 .28545 m .35657 .78734 L .36834 .79903 L p .707 .577 .707 r
F P
0 g
s
.35657 .78734 m .35658 .28545 L .35884 .27336 L p .707 .577 .707 r
F P
0 g
s
.1579 .62325 m .15558 .67707 L .15823 .68859 L p .707 .577 .707 r
F P
0 g
s
.16478 .79934 m .16609 .78197 L .15462 .76858 L p .707 .577 .707 r
F P
0 g
s
.15555 .74599 m .15805 .71105 L .15574 .69772 L p .707 .577 .707 r
F P
0 g
s
.15558 .67707 m .1579 .62325 L .16521 .61237 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15462 .76858 m .15331 .78595 L .16478 .79934 L p .707 .577 .707 r
F P
0 g
s
.34748 .78904 m .34617 .80641 L .35438 .79379 L p .707 .577 .707 r
F P
0 g
s
.35438 .79379 m .35569 .77642 L .34748 .78904 L p .707 .577 .707 r
F P
0 g
s
.15574 .69772 m .15325 .73266 L .15555 .74599 L p .707 .577 .707 r
F P
0 g
s
.64342 .2772 m .64342 .77909 L .63165 .7674 L p .707 .577 .707 r
F P
0 g
s
.63165 .7674 m .63165 .26551 L .64342 .2772 L p .707 .577 .707 r
F P
0 g
s
.16521 .61237 m .16289 .66619 L .15558 .67707 L p .707 .577 .707 r
F P
0 g
s
.15331 .78595 m .15462 .76858 L .15291 .75491 L p .707 .577 .707 r
F P
0 g
s
.15325 .73266 m .15574 .69772 L .16339 .68533 L p .707 .577 .707 r
F P
0 g
s
.16289 .66619 m .16521 .61237 L .18177 .6032 L p .707 .577 .707 r
F P
0 g
s
.15291 .75491 m .1516 .77227 L .15331 .78595 L p .707 .577 .707 r
F P
0 g
s
.35884 .77525 m .35884 .27336 L .37493 .26205 L p .707 .577 .707 r
F P
0 g
s
.35884 .27336 m .35884 .77525 L .35657 .78734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35569 .77642 m .35438 .79379 L .35267 .78011 L p .707 .577 .707 r
F P
0 g
s
.35267 .78011 m .35398 .76274 L .35569 .77642 L p .707 .577 .707 r
F P
0 g
s
.16339 .68533 m .16089 .72027 L .15325 .73266 L p .707 .577 .707 r
F P
0 g
s
.34651 .61377 m .34419 .66759 L .32333 .65813 L p .707 .577 .707 r
F P
0 g
s
.32333 .65813 m .32565 .60431 L .34651 .61377 L p .707 .577 .707 r
F P
0 g
s
.18177 .6032 m .17945 .65702 L .16289 .66619 L p .707 .577 .707 r
F P
0 g
s
.1516 .77227 m .15291 .75491 L .16112 .74228 L p .707 .577 .707 r
F P
0 g
s
.17945 .65702 m .18177 .6032 L .20596 .59663 L p .707 .577 .707 r
F P
0 g
s
.16089 .72027 m .16339 .68533 L .18022 .67509 L p .707 .577 .707 r
F P
0 g
s
.16112 .74228 m .15981 .75965 L .1516 .77227 L p .707 .577 .707 r
F P
0 g
s
.63165 .26551 m .63165 .7674 L .607 .75726 L p .707 .577 .707 r
F P
0 g
s
.607 .75726 m .607 .25537 L .63165 .26551 L p .707 .577 .707 r
F P
0 g
s
.35398 .76274 m .35267 .78011 L .3412 .76672 L p .707 .577 .707 r
F P
0 g
s
.3412 .76672 m .34251 .74935 L .35398 .76274 L p .707 .577 .707 r
F P
0 g
s
.32565 .60431 m .32333 .65813 L .29602 .65116 L p .707 .577 .707 r
F P
0 g
s
.29602 .65116 m .29834 .59734 L .32565 .60431 L p .707 .577 .707 r
F P
0 g
s
.18022 .67509 m .17773 .71003 L .16089 .72027 L p .707 .577 .707 r
F P
0 g
s
.3446 .6906 m .34211 .72555 L .32155 .71422 L p .707 .577 .707 r
F P
0 g
s
.32155 .71422 m .32404 .67927 L .3446 .6906 L p .707 .577 .707 r
F P
0 g
s
.37493 .76393 m .37493 .26205 L .40326 .25262 L p .707 .577 .707 r
F P
0 g
s
.37493 .26205 m .37493 .76393 L .35884 .77525 L p .707 .577 .707 r
F P
0 g
s
.20364 .65045 m .20596 .59663 L .23542 .5933 L p .707 .577 .707 r
F P
0 g
s
.20596 .59663 m .20364 .65045 L .17945 .65702 L p .707 .577 .707 r
F P
0 g
s
.15981 .75965 m .16112 .74228 L .17845 .73195 L p .707 .577 .707 r
F P
0 g
s
.17773 .71003 m .18022 .67509 L .20461 .668 L p .707 .577 .707 r
F P
0 g
s
.29834 .59734 m .29602 .65116 L .26492 .64737 L p .707 .577 .707 r
F P
0 g
s
.26492 .64737 m .26725 .59355 L .29834 .59734 L p .707 .577 .707 r
F P
0 g
s
.23309 .64712 m .23542 .5933 L .26725 .59355 L p .707 .577 .707 r
F P
0 g
s
.23542 .5933 m .23309 .64712 L .20364 .65045 L p .707 .577 .707 r
F P
0 g
s
.17845 .73195 m .17714 .74931 L .15981 .75965 L p .707 .577 .707 r
F P
0 g
s
.26725 .59355 m .26492 .64737 L .23309 .64712 L p .707 .577 .707 r
F P
0 g
s
.73507 .64974 m .73275 .59299 L .70166 .59294 L p .707 .577 .707 r
F P
0 g
s
.73275 .59299 m .73507 .64974 L .7669 .64801 L p .707 .577 .707 r
F P
0 g
s
.7669 .64801 m .76458 .59126 L .73275 .59299 L p .707 .577 .707 r
F P
0 g
s
.32404 .67927 m .32155 .71422 L .29445 .70563 L p .707 .577 .707 r
F P
0 g
s
.29445 .70563 m .29695 .67069 L .32404 .67927 L p .707 .577 .707 r
F P
0 g
s
.76458 .59126 m .7669 .64801 L .79636 .64467 L p .707 .577 .707 r
F P
0 g
s
.79636 .64467 m .79403 .58791 L .76458 .59126 L p .707 .577 .707 r
F P
0 g
s
.34251 .74935 m .3412 .76672 L .32109 .75492 L p .707 .577 .707 r
F P
0 g
s
.32109 .75492 m .32241 .73756 L .34251 .74935 L p .707 .577 .707 r
F P
0 g
s
.20461 .668 m .20212 .70295 L .17773 .71003 L p .707 .577 .707 r
F P
0 g
s
.607 .25537 m .607 .75726 L .57187 .74966 L p .707 .577 .707 r
F P
0 g
s
.57187 .74966 m .57186 .24777 L .607 .25537 L p .707 .577 .707 r
F P
0 g
s
.70398 .64969 m .70166 .59294 L .67435 .5911 L p .707 .577 .707 r
F P
0 g
s
.70166 .59294 m .70398 .64969 L .73507 .64974 L p .707 .577 .707 r
F P
0 g
s
.20212 .70295 m .20461 .668 L .23416 .66476 L p .707 .577 .707 r
F P
0 g
s
.17714 .74931 m .17845 .73195 L .20321 .72491 L p .707 .577 .707 r
F P
0 g
s
.79403 .58791 m .79636 .64467 L .82055 .64004 L p .707 .577 .707 r
F P
0 g
s
.82055 .64004 m .81822 .58328 L .79403 .58791 L p .707 .577 .707 r
F P
0 g
s
.40326 .25262 m .40326 .75451 L .37493 .76393 L p .707 .577 .707 r
F P
0 g
s
.40326 .75451 m .40326 .25262 L .44106 .246 L p .707 .577 .707 r
F P
0 g
s
.73651 .70579 m .73402 .66767 L .70305 .66877 L p .707 .577 .707 r
F P
0 g
s
.73402 .66767 m .73651 .70579 L .76833 .70347 L p .707 .577 .707 r
F P
0 g
s
.76833 .70347 m .76584 .66535 L .73402 .66767 L p .707 .577 .707 r
F P
0 g
s
.29695 .67069 m .29445 .70563 L .26348 .70063 L p .707 .577 .707 r
F P
0 g
s
.26348 .70063 m .26598 .66569 L .29695 .67069 L p .707 .577 .707 r
F P
0 g
s
.67435 .5911 m .67667 .64786 L .70398 .64969 L p .707 .577 .707 r
F P
0 g
s
.76584 .66535 m .76833 .70347 L .79788 .70016 L p .707 .577 .707 r
F P
0 g
s
.79788 .70016 m .79539 .66204 L .76584 .66535 L p .707 .577 .707 r
F P
0 g
s
.23167 .69971 m .23416 .66476 L .26598 .66569 L p .707 .577 .707 r
F P
0 g
s
.23416 .66476 m .23167 .69971 L .20212 .70295 L p .707 .577 .707 r
F P
0 g
s
.70305 .66877 m .70554 .7069 L .73651 .70579 L p .707 .577 .707 r
F P
0 g
s
.20321 .72491 m .2019 .74228 L .17714 .74931 L p .707 .577 .707 r
F P
0 g
s
.26598 .66569 m .26348 .70063 L .23167 .69971 L p .707 .577 .707 r
F P
0 g
s
.70554 .7069 m .70305 .66877 L .67596 .66855 L p .707 .577 .707 r
F P
0 g
s
.67667 .64786 m .67435 .5911 L .65349 .58768 L p .707 .577 .707 r
F P
0 g
s
.32241 .73756 m .32109 .75492 L .29432 .74588 L p .707 .577 .707 r
F P
0 g
s
.29432 .74588 m .29564 .72851 L .32241 .73756 L p .707 .577 .707 r
F P
0 g
s
.73649 .74777 m .73518 .72869 L .70436 .72993 L p .707 .577 .707 r
F P
0 g
s
.73518 .72869 m .73649 .74777 L .76834 .74543 L p .707 .577 .707 r
F P
0 g
s
.76834 .74543 m .76703 .72634 L .73518 .72869 L p .707 .577 .707 r
F P
0 g
s
.76703 .72634 m .76834 .74543 L .7981 .74221 L p .707 .577 .707 r
F P
0 g
s
.7981 .74221 m .79678 .72313 L .76703 .72634 L p .707 .577 .707 r
F P
0 g
s
.70436 .72993 m .70567 .74901 L .73649 .74777 L p .707 .577 .707 r
F P
0 g
s
.67596 .66855 m .67845 .70668 L .70554 .7069 L p .707 .577 .707 r
F P
0 g
s
.79539 .66204 m .79788 .70016 L .82227 .69619 L p .707 .577 .707 r
F P
0 g
s
.82227 .69619 m .81977 .65807 L .79539 .66204 L p .707 .577 .707 r
F P
0 g
s
.2019 .74228 m .20321 .72491 L .23297 .72186 L p .707 .577 .707 r
F P
0 g
s
.57186 .24777 m .57187 .74966 L .5297 .74534 L p .707 .577 .707 r
F P
0 g
s
.5297 .74534 m .5297 .24345 L .57186 .24777 L p .707 .577 .707 r
F P
0 g
s
.65349 .58768 m .65581 .64443 L .67667 .64786 L p .707 .577 .707 r
F P
0 g
s
.70567 .74901 m .70436 .72993 L .67759 .72994 L p .707 .577 .707 r
F P
0 g
s
.81822 .58328 m .82055 .64004 L .83711 .63457 L p .707 .577 .707 r
F P
0 g
s
.83711 .63457 m .83479 .57782 L .81822 .58328 L p .707 .577 .707 r
F P
0 g
s
.67759 .72994 m .6789 .74903 L .70567 .74901 L p .707 .577 .707 r
F P
0 g
s
.79678 .72313 m .7981 .74221 L .82286 .73843 L p .707 .577 .707 r
F P
0 g
s
.82286 .73843 m .82154 .71935 L .79678 .72313 L p .707 .577 .707 r
F P
0 g
s
.44106 .74789 m .44106 .246 L .48463 .24284 L p .707 .577 .707 r
F P
0 g
s
.44106 .246 m .44106 .74789 L .40326 .75451 L p .707 .577 .707 r
F P
0 g
s
.29564 .72851 m .29432 .74588 L .26351 .74047 L p .707 .577 .707 r
F P
0 g
s
.26351 .74047 m .26482 .72311 L .29564 .72851 L p .707 .577 .707 r
F P
0 g
s
.23297 .72186 m .23166 .73923 L .2019 .74228 L p .707 .577 .707 r
F P
0 g
s
.67845 .70668 m .67596 .66855 L .65539 .66703 L p .707 .577 .707 r
F P
0 g
s
.23166 .73923 m .23297 .72186 L .26482 .72311 L p .707 .577 .707 r
F P
0 g
s
.65539 .66703 m .65789 .70516 L .67845 .70668 L p .707 .577 .707 r
F P
0 g
s
.26482 .72311 m .26351 .74047 L .23166 .73923 L p .707 .577 .707 r
F P
0 g
s
.65581 .64443 m .65349 .58768 L .64113 .58298 L p .707 .577 .707 r
F P
0 g
s
.5297 .24345 m .5297 .74534 L .48463 .74473 L p .707 .577 .707 r
F P
0 g
s
.48463 .74473 m .48463 .24284 L .5297 .24345 L p .707 .577 .707 r
F P
0 g
s
.81977 .65807 m .82227 .69619 L .8391 .69194 L p .707 .577 .707 r
F P
0 g
s
.8391 .69194 m .83661 .65382 L .81977 .65807 L p .707 .577 .707 r
F P
0 g
s
.48463 .24284 m .48463 .74473 L .44106 .74789 L p .707 .577 .707 r
F P
0 g
s
.6789 .74903 m .67759 .72994 L .65749 .72873 L p .707 .577 .707 r
F P
0 g
s
.65749 .72873 m .6588 .74781 L .6789 .74903 L p .707 .577 .707 r
F P
0 g
s
.64113 .58298 m .64345 .63974 L .65581 .64443 L p .707 .577 .707 r
F P
0 g
s
.82154 .71935 m .82286 .73843 L .84019 .73446 L p .707 .577 .707 r
F P
0 g
s
.84019 .73446 m .83888 .71538 L .82154 .71935 L p .707 .577 .707 r
F P
0 g
s
.83479 .57782 m .83711 .63457 L .84442 .62881 L p .707 .577 .707 r
F P
0 g
s
.84442 .62881 m .8421 .57206 L .83479 .57782 L p .707 .577 .707 r
F P
0 g
s
.65789 .70516 m .65539 .66703 L .64337 .66436 L p .707 .577 .707 r
F P
0 g
s
.64337 .66436 m .64586 .70249 L .65789 .70516 L p .707 .577 .707 r
F P
0 g
s
.6588 .74781 m .65749 .72873 L .64602 .72641 L p .707 .577 .707 r
F P
0 g
s
.83661 .65382 m .8391 .69194 L .84675 .68784 L p .707 .577 .707 r
F P
0 g
s
.84675 .68784 m .84426 .64971 L .83661 .65382 L p .707 .577 .707 r
F P
0 g
s
.64345 .63974 m .64113 .58298 L .63847 .57749 L p .707 .577 .707 r
F P
0 g
s
.64602 .72641 m .64733 .74549 L .6588 .74781 L p .707 .577 .707 r
F P
0 g
s
.83888 .71538 m .84019 .73446 L .8484 .73069 L p .707 .577 .707 r
F P
0 g
s
.8484 .73069 m .84709 .71161 L .83888 .71538 L p .707 .577 .707 r
F P
0 g
s
.63847 .57749 m .6408 .63424 L .64345 .63974 L p .707 .577 .707 r
F P
0 g
s
.8421 .57206 m .84442 .62881 L .84177 .62332 L p .707 .577 .707 r
F P
0 g
s
.84177 .62332 m .83944 .56656 L .8421 .57206 L p .707 .577 .707 r
F P
0 g
s
.64586 .70249 m .64337 .66436 L .64107 .6608 L p .707 .577 .707 r
F P
0 g
s
.64107 .6608 m .64356 .69892 L .64586 .70249 L p .707 .577 .707 r
F P
0 g
s
.64733 .74549 m .64602 .72641 L .64431 .7232 L p .707 .577 .707 r
F P
0 g
s
.84426 .64971 m .84675 .68784 L .84445 .68427 L p .707 .577 .707 r
F P
0 g
s
.84445 .68427 m .84195 .64615 L .84426 .64971 L p .707 .577 .707 r
F P
0 g
s
.64431 .7232 m .64562 .74229 L .64733 .74549 L p .707 .577 .707 r
F P
0 g
s
.6408 .63424 m .63847 .57749 L .64578 .57173 L p .707 .577 .707 r
F P
0 g
s
.84709 .71161 m .8484 .73069 L .84669 .72749 L p .707 .577 .707 r
F P
0 g
s
.84669 .72749 m .84538 .7084 L .84709 .71161 L p .707 .577 .707 r
F P
0 g
s
.64578 .57173 m .64811 .62848 L .6408 .63424 L p .707 .577 .707 r
F P
0 g
s
.83944 .56656 m .84177 .62332 L .8294 .61862 L p .707 .577 .707 r
F P
0 g
s
.8294 .61862 m .82708 .56187 L .83944 .56656 L p .707 .577 .707 r
F P
0 g
s
.64356 .69892 m .64107 .6608 L .64871 .65669 L p .707 .577 .707 r
F P
0 g
s
.64871 .65669 m .65121 .69482 L .64356 .69892 L p .707 .577 .707 r
F P
0 g
s
.39528 .62439 m .38985 .56971 L .35888 .57024 L p .707 .577 .707 r
F P
0 g
s
.38985 .56971 m .39528 .62439 L .427 .62074 L p .707 .577 .707 r
F P
0 g
s
.427 .62074 m .42157 .56606 L .38985 .56971 L p .707 .577 .707 r
F P
0 g
s
.42157 .56606 m .427 .62074 L .45636 .61432 L p .707 .577 .707 r
F P
0 g
s
.45636 .61432 m .45094 .55964 L .42157 .56606 L p .707 .577 .707 r
F P
0 g
s
.64562 .74229 m .64431 .7232 L .65252 .71943 L p .707 .577 .707 r
F P
0 g
s
.64811 .62848 m .64578 .57173 L .66234 .56626 L p .707 .577 .707 r
F P
0 g
s
.84195 .64615 m .84445 .68427 L .83242 .6816 L p .707 .577 .707 r
F P
0 g
s
.83242 .6816 m .82993 .64348 L .84195 .64615 L p .707 .577 .707 r
F P
0 g
s
.65252 .71943 m .65383 .73852 L .64562 .74229 L p .707 .577 .707 r
F P
0 g
s
.36431 .62492 m .35888 .57024 L .3317 .56759 L p .707 .577 .707 r
F P
0 g
s
.35888 .57024 m .36431 .62492 L .39528 .62439 L p .707 .577 .707 r
F P
0 g
s
.84538 .7084 m .84669 .72749 L .83522 .72517 L p .707 .577 .707 r
F P
0 g
s
.83522 .72517 m .83391 .70608 L .84538 .7084 L p .707 .577 .707 r
F P
0 g
s
.45094 .55964 m .45636 .61432 L .4805 .60577 L p .707 .577 .707 r
F P
0 g
s
.4805 .60577 m .47507 .55109 L .45094 .55964 L p .707 .577 .707 r
F P
0 g
s
.66234 .56626 m .66467 .62302 L .64811 .62848 L p .707 .577 .707 r
F P
0 g
s
.82708 .56187 m .8294 .61862 L .80855 .6152 L p .707 .577 .707 r
F P
0 g
s
.80855 .6152 m .80622 .55844 L .82708 .56187 L p .707 .577 .707 r
F P
0 g
s
.65121 .69482 m .64871 .65669 L .66555 .65245 L p .707 .577 .707 r
F P
0 g
s
.33712 .62227 m .3317 .56759 L .31095 .56203 L p .707 .577 .707 r
F P
0 g
s
.3317 .56759 m .33712 .62227 L .36431 .62492 L p .707 .577 .707 r
F P
0 g
s
.66555 .65245 m .66804 .69057 L .65121 .69482 L p .707 .577 .707 r
F P
0 g
s
.39992 .6868 m .39409 .65089 L .36345 .65276 L p .707 .577 .707 r
F P
0 g
s
.39409 .65089 m .39992 .6868 L .43144 .68152 L p .707 .577 .707 r
F P
0 g
s
.43144 .68152 m .42562 .64561 L .39409 .65089 L p .707 .577 .707 r
F P
0 g
s
.42562 .64561 m .43144 .68152 L .46076 .67336 L p .707 .577 .707 r
F P
0 g
s
.46076 .67336 m .45494 .63745 L .42562 .64561 L p .707 .577 .707 r
F P
0 g
s
.66467 .62302 m .66234 .56626 L .68654 .56163 L p .707 .577 .707 r
F P
0 g
s
.47507 .55109 m .4805 .60577 L .49704 .59591 L p .707 .577 .707 r
F P
0 g
s
.49704 .59591 m .49161 .54123 L .47507 .55109 L p .707 .577 .707 r
F P
0 g
s
.82993 .64348 m .83242 .6816 L .81186 .68008 L p .707 .577 .707 r
F P
0 g
s
.81186 .68008 m .80937 .64196 L .82993 .64348 L p .707 .577 .707 r
F P
0 g
s
.65383 .73852 m .65252 .71943 L .66985 .71546 L p .707 .577 .707 r
F P
0 g
s
.36927 .68867 m .36345 .65276 L .33668 .65105 L p .707 .577 .707 r
F P
0 g
s
.36345 .65276 m .36927 .68867 L .39992 .6868 L p .707 .577 .707 r
F P
0 g
s
.66985 .71546 m .67117 .73455 L .65383 .73852 L p .707 .577 .707 r
F P
0 g
s
.45494 .63745 m .46076 .67336 L .485 .66312 L p .707 .577 .707 r
F P
0 g
s
.485 .66312 m .47917 .62721 L .45494 .63745 L p .707 .577 .707 r
F P
0 g
s
.68654 .56163 m .68886 .61839 L .66467 .62302 L p .707 .577 .707 r
F P
0 g
s
.80622 .55844 m .80855 .6152 L .78124 .61336 L p .707 .577 .707 r
F P
0 g
s
.78124 .61336 m .77891 .55661 L .80622 .55844 L p .707 .577 .707 r
F P
0 g
s
.83391 .70608 m .83522 .72517 L .81512 .72395 L p .707 .577 .707 r
F P
0 g
s
.81512 .72395 m .8138 .70487 L .83391 .70608 L p .707 .577 .707 r
F P
0 g
s
.31095 .56203 m .31637 .6167 L .33712 .62227 L p .707 .577 .707 r
F P
0 g
s
.43385 .7234 m .43076 .70548 L .39925 .71083 L p .707 .577 .707 r
F P
0 g
s
.43076 .70548 m .43385 .7234 L .46334 .71512 L p .707 .577 .707 r
F P
0 g
s
.46334 .71512 m .46026 .6972 L .43076 .70548 L p .707 .577 .707 r
F P
0 g
s
.40233 .72875 m .39925 .71083 L .3688 .71274 L p .707 .577 .707 r
F P
0 g
s
.39925 .71083 m .40233 .72875 L .43385 .7234 L p .707 .577 .707 r
F P
0 g
s
.33668 .65105 m .3425 .68696 L .36927 .68867 L p .707 .577 .707 r
F P
0 g
s
.66804 .69057 m .66555 .65245 L .68994 .64847 L p .707 .577 .707 r
F P
0 g
s
.31637 .6167 m .31095 .56203 L .29868 .55409 L p .707 .577 .707 r
F P
0 g
s
.68886 .61839 m .68654 .56163 L .71599 .55829 L p .707 .577 .707 r
F P
0 g
s
.3425 .68696 m .33668 .65105 L .3164 .64593 L p .707 .577 .707 r
F P
0 g
s
.3688 .71274 m .37188 .73065 L .40233 .72875 L p .707 .577 .707 r
F P
0 g
s
.68994 .64847 m .69243 .6866 L .66804 .69057 L p .707 .577 .707 r
F P
0 g
s
.47917 .62721 m .485 .66312 L .50179 .65179 L p .707 .577 .707 r
F P
0 g
s
.50179 .65179 m .49596 .61588 L .47917 .62721 L p .707 .577 .707 r
F P
0 g
s
.46026 .6972 m .46334 .71512 L .48793 .70472 L p .707 .577 .707 r
F P
0 g
s
.48793 .70472 m .48485 .68681 L .46026 .6972 L p .707 .577 .707 r
F P
0 g
s
.37188 .73065 m .3688 .71274 L .34239 .711 L p .707 .577 .707 r
F P
0 g
s
.77891 .55661 m .78124 .61336 L .75014 .61331 L p .707 .577 .707 r
F P
0 g
s
.75014 .61331 m .74782 .55656 L .77891 .55661 L p .707 .577 .707 r
F P
0 g
s
.80937 .64196 m .81186 .68008 L .78477 .67986 L p .707 .577 .707 r
F P
0 g
s
.78477 .67986 m .78228 .64174 L .80937 .64196 L p .707 .577 .707 r
F P
0 g
s
.49161 .54123 m .49704 .59591 L .50437 .58571 L p .707 .577 .707 r
F P
0 g
s
.50437 .58571 m .49894 .53104 L .49161 .54123 L p .707 .577 .707 r
F P
0 g
s
.67117 .73455 m .66985 .71546 L .69461 .71169 L p .707 .577 .707 r
F P
0 g
s
.71599 .55829 m .71831 .61504 L .68886 .61839 L p .707 .577 .707 r
F P
0 g
s
.69461 .71169 m .69592 .73077 L .67117 .73455 L p .707 .577 .707 r
F P
0 g
s
.34239 .711 m .34548 .72892 L .37188 .73065 L p .707 .577 .707 r
F P
0 g
s
.71831 .61504 m .71599 .55829 L .74782 .55656 L p .707 .577 .707 r
F P
0 g
s
.3164 .64593 m .32223 .68184 L .3425 .68696 L p .707 .577 .707 r
F P
0 g
s
.74782 .55656 m .75014 .61331 L .71831 .61504 L p .707 .577 .707 r
F P
0 g
s
.29868 .55409 m .3041 .60877 L .31637 .6167 L p .707 .577 .707 r
F P
0 g
s
.8138 .70487 m .81512 .72395 L .78835 .72397 L p .707 .577 .707 r
F P
0 g
s
.78835 .72397 m .78703 .70488 L .8138 .70487 L p .707 .577 .707 r
F P
0 g
s
.69243 .6866 m .68994 .64847 L .71949 .64517 L p .707 .577 .707 r
F P
0 g
s
.48485 .68681 m .48793 .70472 L .50521 .69323 L p .707 .577 .707 r
F P
0 g
s
.50521 .69323 m .50212 .67531 L .48485 .68681 L p .707 .577 .707 r
F P
0 g
s
.71949 .64517 m .72198 .68329 L .69243 .6866 L p .707 .577 .707 r
F P
0 g
s
.34548 .72892 m .34239 .711 L .32262 .7058 L p .707 .577 .707 r
F P
0 g
s
.78228 .64174 m .78477 .67986 L .7538 .68097 L p .707 .577 .707 r
F P
0 g
s
.7538 .68097 m .7513 .64285 L .78228 .64174 L p .707 .577 .707 r
F P
0 g
s
.32223 .68184 m .3164 .64593 L .30461 .63788 L p .707 .577 .707 r
F P
0 g
s
.3041 .60877 m .29868 .55409 L .29608 .54456 L p .707 .577 .707 r
F P
0 g
s
.49596 .61588 m .50179 .65179 L .50948 .64049 L p .707 .577 .707 r
F P
0 g
s
.50948 .64049 m .50366 .60458 L .49596 .61588 L p .707 .577 .707 r
F P
0 g
s
.69592 .73077 m .69461 .71169 L .72437 .70847 L p .707 .577 .707 r
F P
0 g
s
.32262 .7058 m .32571 .72372 L .34548 .72892 L p .707 .577 .707 r
F P
0 g
s
.72198 .68329 m .71949 .64517 L .7513 .64285 L p .707 .577 .707 r
F P
0 g
s
.72437 .70847 m .72568 .72755 L .69592 .73077 L p .707 .577 .707 r
F P
0 g
s
.7513 .64285 m .7538 .68097 L .72198 .68329 L p .707 .577 .707 r
F P
0 g
s
.78703 .70488 m .78835 .72397 L .75753 .72521 L p .707 .577 .707 r
F P
0 g
s
.75753 .72521 m .75622 .70612 L .78703 .70488 L p .707 .577 .707 r
F P
0 g
s
.49894 .53104 m .50437 .58571 L .50177 .57618 L p .707 .577 .707 r
F P
0 g
s
.50177 .57618 m .49635 .5215 L .49894 .53104 L p .707 .577 .707 r
F P
0 g
s
.30461 .63788 m .31044 .67379 L .32223 .68184 L p .707 .577 .707 r
F P
0 g
s
.72568 .72755 m .72437 .70847 L .75622 .70612 L p .707 .577 .707 r
F P
0 g
s
.75622 .70612 m .75753 .72521 L .72568 .72755 L p .707 .577 .707 r
F P
0 g
s
.29608 .54456 m .3015 .59923 L .3041 .60877 L p .707 .577 .707 r
F P
0 g
s
.50212 .67531 m .50521 .69323 L .51348 .68176 L p .707 .577 .707 r
F P
0 g
s
.51348 .68176 m .51039 .66385 L .50212 .67531 L p .707 .577 .707 r
F P
0 g
s
.32571 .72372 m .32262 .7058 L .31141 .69764 L p .707 .577 .707 r
F P
0 g
s
.31141 .69764 m .3145 .71556 L .32571 .72372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.31044 .67379 m .30461 .63788 L .30246 .62771 L p .708 .578 .707 r
F P
0 g
s
.3015 .59923 m .29608 .54456 L .30341 .53436 L p .707 .577 .707 r
F P
0 g
s
.50366 .60458 m .50948 .64049 L .50733 .63032 L p .708 .578 .707 r
F P
0 g
s
.50733 .63032 m .5015 .59441 L .50366 .60458 L p .708 .578 .707 r
F P
0 g
s
.49635 .5215 m .50177 .57618 L .4895 .56824 L p .707 .577 .707 r
F P
0 g
s
.4895 .56824 m .48407 .51357 L .49635 .5215 L p .707 .577 .707 r
F P
0 g
s
.30246 .62771 m .30828 .66362 L .31044 .67379 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30341 .53436 m .30883 .58904 L .3015 .59923 L p .707 .577 .707 r
F P
0 g
s
.51039 .66385 m .51348 .68176 L .51194 .67145 L p .706 .577 .707 r
F P
0 g
s
.51194 .67145 m .50885 .65353 L .51039 .66385 L p .706 .577 .707 r
F P
0 g
s
.3145 .71556 m .31141 .69764 L .30987 .68732 L p .706 .577 .707 r
F P
0 g
s
.30987 .68732 m .31296 .70524 L .3145 .71556 L p .706 .577 .707 r
F P
0 g
s
.30828 .66362 m .30246 .62771 L .31015 .61641 L p .707 .577 .707 r
F P
0 g
s
.30883 .58904 m .30341 .53436 L .31995 .52451 L p .707 .577 .707 r
F P
0 g
s
.5015 .59441 m .50733 .63032 L .49554 .62228 L p .707 .577 .707 r
F P
0 g
s
.49554 .62228 m .48971 .58637 L .5015 .59441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48407 .51357 m .4895 .56824 L .46875 .56268 L p .707 .577 .707 r
F P
0 g
s
.46875 .56268 m .46333 .508 L .48407 .51357 L p .707 .577 .707 r
F P
0 g
s
.31015 .61641 m .31598 .65232 L .30828 .66362 L p .707 .577 .707 r
F P
0 g
s
.31995 .52451 m .32538 .57918 L .30883 .58904 L p .707 .577 .707 r
F P
0 g
s
.50885 .65353 m .51194 .67145 L .50073 .66329 L p .707 .577 .707 r
F P
0 g
s
.50073 .66329 m .49764 .64537 L .50885 .65353 L p .707 .577 .707 r
F P
0 g
s
.31296 .70524 m .30987 .68732 L .31814 .67586 L p .707 .577 .707 r
F P
0 g
s
.32538 .57918 m .31995 .52451 L .34408 .51595 L p .707 .577 .707 r
F P
0 g
s
.31814 .67586 m .32123 .69377 L .31296 .70524 L p .707 .577 .707 r
F P
0 g
s
.31598 .65232 m .31015 .61641 L .32694 .60508 L p .707 .577 .707 r
F P
0 g
s
.48971 .58637 m .49554 .62228 L .47526 .61715 L p .707 .577 .707 r
F P
0 g
s
.47526 .61715 m .46944 .58124 L .48971 .58637 L p .707 .577 .707 r
F P
0 g
s
.46333 .508 m .46875 .56268 L .44156 .56003 L p .707 .577 .707 r
F P
0 g
s
.44156 .56003 m .43614 .50535 L .46333 .508 L p .707 .577 .707 r
F P
0 g
s
.32694 .60508 m .33276 .64099 L .31598 .65232 L p .707 .577 .707 r
F P
0 g
s
.34408 .51595 m .34951 .57063 L .32538 .57918 L p .707 .577 .707 r
F P
0 g
s
.34951 .57063 m .34408 .51595 L .37345 .50953 L p .707 .577 .707 r
F P
0 g
s
.49764 .64537 m .50073 .66329 L .48096 .65809 L p .707 .577 .707 r
F P
0 g
s
.48096 .65809 m .47787 .64017 L .49764 .64537 L p .707 .577 .707 r
F P
0 g
s
.32123 .69377 m .31814 .67586 L .33542 .66436 L p .707 .577 .707 r
F P
0 g
s
.43614 .50535 m .44156 .56003 L .41059 .56056 L p .707 .577 .707 r
F P
0 g
s
.41059 .56056 m .40517 .50588 L .43614 .50535 L p .707 .577 .707 r
F P
0 g
s
.33276 .64099 m .32694 .60508 L .35118 .59484 L p .707 .577 .707 r
F P
0 g
s
.46944 .58124 m .47526 .61715 L .44849 .61544 L p .707 .577 .707 r
F P
0 g
s
.44849 .61544 m .44267 .57953 L .46944 .58124 L p .707 .577 .707 r
F P
0 g
s
.33542 .66436 m .3385 .68228 L .32123 .69377 L p .707 .577 .707 r
F P
0 g
s
.37887 .56421 m .37345 .50953 L .40517 .50588 L p .707 .577 .707 r
F P
0 g
s
.37345 .50953 m .37887 .56421 L .34951 .57063 L p .707 .577 .707 r
F P
0 g
s
.40517 .50588 m .41059 .56056 L .37887 .56421 L p .707 .577 .707 r
F P
0 g
s
.35118 .59484 m .357 .63075 L .33276 .64099 L p .707 .577 .707 r
F P
0 g
s
.357 .63075 m .35118 .59484 L .3805 .58668 L p .707 .577 .707 r
F P
0 g
s
.44267 .57953 m .44849 .61544 L .41785 .61731 L p .707 .577 .707 r
F P
0 g
s
.41785 .61731 m .41202 .5814 L .44267 .57953 L p .707 .577 .707 r
F P
0 g
s
.47787 .64017 m .48096 .65809 L .45455 .65635 L p .707 .577 .707 r
F P
0 g
s
.45455 .65635 m .45147 .63844 L .47787 .64017 L p .707 .577 .707 r
F P
0 g
s
.3385 .68228 m .33542 .66436 L .36001 .65397 L p .707 .577 .707 r
F P
0 g
s
.36001 .65397 m .36309 .67189 L .3385 .68228 L p .707 .577 .707 r
F P
0 g
s
.38632 .62259 m .3805 .58668 L .41202 .5814 L p .707 .577 .707 r
F P
0 g
s
.3805 .58668 m .38632 .62259 L .357 .63075 L p .707 .577 .707 r
F P
0 g
s
.41202 .5814 m .41785 .61731 L .38632 .62259 L p .707 .577 .707 r
F P
0 g
s
.45147 .63844 m .45455 .65635 L .4241 .65825 L p .707 .577 .707 r
F P
0 g
s
.4241 .65825 m .42102 .64034 L .45147 .63844 L p .707 .577 .707 r
F P
0 g
s
.36309 .67189 m .36001 .65397 L .3895 .64569 L p .707 .577 .707 r
F P
0 g
s
.3895 .64569 m .39259 .66361 L .36309 .67189 L p .707 .577 .707 r
F P
0 g
s
.42102 .64034 m .4241 .65825 L .39259 .66361 L p .707 .577 .707 r
F P
0 g
s
.39259 .66361 m .3895 .64569 L .42102 .64034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Q7oo6000PGoo001hOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001hOol0075oo`L000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007=oo`00Kgoo0P00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1000Kgoo001/Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUH00000KGoo001ZOol20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00Jgoo001Y
Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2001YOol006Moo`800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP80
06Qoo`00IWoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Moo`00IWoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF009JEQ0000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol006Eoo`800003FUH0000000D000AJEP03001JEUYF00EJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001TOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUH0000200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001POol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
IWoo001NOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP00IWoo001LOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP020008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUIJEP00IWoo001JOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00F7oo0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000QJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol005Ioo`80009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP00IWoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00EGoo0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP004Goo8000=Goo001DOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJ
EP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUH000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
035oo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPT0009JEPL000AJEPP0
00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01@000eYF
1`000UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=oo`@000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005Ao
o`04001JEUYF0004FUH00`00FUIJEP03FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00EJEP@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000IJEP03001JEUYF009JEP04001JEP000006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001EOol00`00FUH00002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP090003FUH01000FUIJEUYF20000eYF00@005YFFUH000IJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool005Eoo`03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF0006FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo001EOol01000FUH000001EYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
?goo4@001Goo0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP03001JEUYF00=JEP03
001JEUYF00<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000a
Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00
FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001J
EP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H0
05YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01000FUIJEUYF0P00
;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF5P000UYF
00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000eYF0P00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
00000eYF0000000500000eYF001JEP0:FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000=JEP03001JEP0000<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000QJEP03001J
EUYF00UJEP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010000eYF10002UYF00<005YFFUH01eYF0P00
15YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001J
EUYF00AJEP@0009JEP04001JEUYFFUH5000:FUH00`00FUIJEP05FUH200000eYF001JEP03FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH0000000=JEP04001JEUYFFUH5000:FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02
FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009J
EP03001JEP000080009JEP8000=JEP04001JEUYFFUH50009FUH80004FUH00`00FUIJEP02FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP800003FUH0
05YF009JEP8000=JEP03001JEUYF009JEPd000AJEP04001JEUYFFUH60003FUH01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF7@00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH01P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009o
o`@000=JEP03001JEUYF00EJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008002eoo`00;7oo00<005YF000015YF00<005YFFUH00UYF600015YF00<005YF0000
0UYF1@000eYF00@005YFFUIJEP80009JEP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000Eoo``000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP000080011oo`<000Eo
o`L0009JEP03001JEUYF009JEP/000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEP00FUH02@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00<005YF000015YF0P0000AJ
EP00000000ioo`D000Yoo`<00003FUH005YF00=JEP04001JEUYFFUH200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002eoo`00;7oo00<005YF00000UYF0P0015YF00<005YF00000`002Woo1@002goo0P00
00=JEP00FUH00eYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001J
EUYF00H000=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005
FUH00`00FUIJEP03FUH60004Ool50009Ool30002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF000000020002FUH00`00FUIJEP02
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYF000]Ool002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEP0001/0
009JEP800003FUH005YF009JEP8000MJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP04FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
02aoo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0002FUH01000FUH005YF0P0000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002aoo`00;7oo0P000UYF00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P000UYF00D005YFFUIJEP0000IJEP<000QJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ao
o`00;7oo00@005YFFUIJEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30005FUH01000FUIJEUYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00;7oo
00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001EYF00@005YF000000AJEP03001JEUYF00AJEP<000IJEPH000]JEP03
001JEUYF00<0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00UYF70000UYF
00<007ooOol0:Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20005FUH20006FUH00`00FUIJEP03FUH500000eYF
000000020005FUH00`00FUIJEP09FUH30002FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH0009JEQH000UJEP03001JEUYF00QJEP8000EJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;7oo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030003FUH00`00FUIJEP030003FUH01000FUIJEUYF1@002UYF00<005YFFUH01UYF
0P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YFFUH0009JEP03001JEUYF00D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0P0015YF0P0000AJEP00000000=JEP03001JEUYF009JEP@000YJEP03001JEUYF00AJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYF001JEP040004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH4000aOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000030003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH01000FUIJEUYF0`001UYF00<005YFFUH00P001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Goo000/Ool20004FUH00`00FUIJEP03FUH70007FUH90004FUH00`00FUIJEP02FUH40005FUH00`00
FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH400000eYF001JEP06FUH30009FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000iOol002aoo`8000AJ
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP04FUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF2`0015YF
00<005YFFUH00UYF8P00;Woo000/Ool20004FUH2000017oo000000001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000IJEP00001JEP00FUH300000eYF001JEP02FUH20003FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00eYF00<0
05YF00003@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ao
o`00;7oo0P000UYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`0000=JEP00FUH00eYF50001UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0002FUH50004FUH80003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo
000[Ool00`00FUH00002000<Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH002aoo`00:goo00<005YF00000P004goo4P001Goo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010001eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEP<0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF000/Ool002]oo`8000=JEP03001oogoo00]ooa0000ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP03001JEUYF008002]oo`00:goo
0P000eYF0`001Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0100037oo0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH00UYF5@000eYF00<005YFFUH015YF2@00:goo000[Ool20003FUH00`00FUIJEP05
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;OolD0008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP03FUH01000FUIJEUYF500015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YF000002]oo`00:goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000<000Qoo`03001JEP00008000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH005YF009JEPD000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00:goo0P000eYF0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo0P00
00=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH0
0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF1000<Goo000[Ool200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006
FUH00`00FUIJEP05FUH50003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000/Ool20004FUH00`00FUIJEP03FUH:000;Ool40002FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04
FUHE0009FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>000iOol002aoo`8000AJEP03001JEP00
00<000EJEP03001JEUYF009JEPT000Ioo`@000IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
00<005YFFUH01EYF00<005YFFUH01UYF2@0000=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEQd004Moo`00;7oo0P0015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YFFUH0
0eYF00@005YF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00H000YJEP03001JEUYF00YJEP03
001JEUYF00UJEPL000MJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH2001IOol0
02]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP@000EJEPH000=JEP03001JEUYF00AJEP@000AJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD0009JEP03001JEUYF00AJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUH0001HOol002]oo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH00`00FUH000030003
FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH50005FUH01000FUIJEP0015YF00<005YFFUH00eYF00D005YFFUIJEP0005Moo`00:goo
00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P000eYF
00@005YFFUH000AJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol002]oo`8000Eoo`04001JEUYF
0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH3
0003FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH200001EYF001JEUYF000015YF00<005YFFUH00eYF00@005YF
FUIJEP8005Ioo`00:goo0P001Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00H005YFFUH005YF001FOol002]oo`8000Qoo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEPD0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00H005YFFUH005YF001F
Ool002]oo`03001JEP0000Uoo`@0009JEP03001JEUYF00EJEP03001JEP0000@000=JEP03001JEUYF
00EJEP03001JEUYF00=JEP8000=oo`D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF001JEP05FUH00`00FUIJEP02001GOol002]oo`04001JEUYF000<Ool60004FUH00`00FUH0
00040003FUH00`00FUIJEP05FUH00`00FUH000030007Ool300000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUIJEUYF0P00Egoo000[Ool01@00FUIJEUYF
00004Goo2`000eYF00<005YFFUH00UYF1@002Woo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF0`0000=JEP00FUH00UYF0P00Egoo000[Ool01000FUIJEUYF0`005Woo
30003goo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF0`000UYF
00<005YF0000Egoo000/Ool01000FUIJEP000UYF0P00;Woo00L005YF001oo`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0300000eYF001oo`1FOol002aoo`03001J
EP0000EJEP8002Yoo`<00006FUH007oo001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0006FUH00`00FUIJEP02FUH2001HOol002eoo`8000EJEP04001JEP00000VOol20002FUH20003Ool2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00F7oo
000^Ool00`00FUIJEP03FUH01000FUIJEUYF0`008Goo0P0015YF0P0017oo0P001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0`0000=JEP0000000P001EYF00L005YFFUIJEP00FUH0001HOol002moo`8000=JEP03001JEUYF
00AJEPH001Moo`@00003FUH005YF00=JEP03001oogoo00Eoo`8000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP800003
FUH005YF00AJEP<00003FUH005YF00=JEP8005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
0UYF2@002Goo1@001EYF00<005YFFUH00UYF00<007ooOol01goo0P0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH010000UYF00<0
05YFFUH01EYF00<005YF00000P0000AJEP00000005Yoo`00<goo0`001UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0037oo10001eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF2@000UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00G7oo000fOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH3000BOol50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP060002Ool50002Ool40006FUH00`00FUIJEP03FUH3001JOol003Qoo`<00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP8001Uoo`P000IJEP03001JEUYF
00YJEP03001JEUYF00AJEPP000Qoo`D000Ioo`@0009JEP03001JEUYF00=JEP04001JEUYF001IOol0
03]oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<002=ooaX00003FUH00000
008000]oo`D000Yoo`@000=JEP05001JEUYFFUH0001IOol0041oo`T000AJEP03001JEUYF009JEPH0
03Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00@000Qoo`<000moo`800003FUH005YF009JEP80
05Qoo`00BGoo2@00?Woo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`005Goo0P000UYF00<005YF
0000F7oo002BOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool8000015YF001JEP00
F7oo002EOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YF
FUH00UYF0`00FGoo002IOol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001IOol009eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00FGoo002QOol70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1P00FUIJEUYF001JEP8005Uoo`00Z7oo2@0015YF00<005YFFUH015YF00<005YFFUH00`00Fgoo002a
Ool>001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58523 .7426 m .59397 .6868 L .56327 .68063 L p .707 .577 .707 r
F P
0 g
s
.59397 .6868 m .58523 .7426 L .61673 .74683 L p .707 .577 .707 r
F P
0 g
s
.61673 .74683 m .62547 .69103 L .59397 .6868 L p .707 .577 .707 r
F P
0 g
s
.62547 .69103 m .61673 .74683 L .64596 .74871 L p .707 .577 .707 r
F P
0 g
s
.64596 .74871 m .65471 .69291 L .62547 .69103 L p .707 .577 .707 r
F P
0 g
s
.55452 .73644 m .56327 .68063 L .53638 .67314 L p .707 .577 .707 r
F P
0 g
s
.56327 .68063 m .55452 .73644 L .58523 .7426 L p .707 .577 .707 r
F P
0 g
s
.65471 .69291 m .64596 .74871 L .67006 .74806 L p .707 .577 .707 r
F P
0 g
s
.67006 .74806 m .6788 .69225 L .65471 .69291 L p .707 .577 .707 r
F P
0 g
s
.57346 .79883 m .58278 .76206 L .55283 .75327 L p .707 .577 .707 r
F P
0 g
s
.58278 .76206 m .57346 .79883 L .60444 .80617 L p .707 .577 .707 r
F P
0 g
s
.60444 .80617 m .61376 .7694 L .58278 .76206 L p .707 .577 .707 r
F P
0 g
s
.53638 .67314 m .52764 .72894 L .55452 .73644 L p .707 .577 .707 r
F P
0 g
s
.61376 .7694 m .60444 .80617 L .6334 .81134 L p .707 .577 .707 r
F P
0 g
s
.6334 .81134 m .64272 .77457 L .61376 .7694 L p .707 .577 .707 r
F P
0 g
s
.52764 .72894 m .53638 .67314 L .51593 .66504 L p .707 .577 .707 r
F P
0 g
s
.55283 .75327 m .54351 .79004 L .57346 .79883 L p .707 .577 .707 r
F P
0 g
s
.54351 .79004 m .55283 .75327 L .52683 .74389 L p .707 .577 .707 r
F P
0 g
s
.56333 .84066 m .56824 .82233 L .53867 .81305 L p .707 .577 .707 r
F P
0 g
s
.56824 .82233 m .56333 .84066 L .59422 .8486 L p .707 .577 .707 r
F P
0 g
s
.59422 .8486 m .59914 .83028 L .56824 .82233 L p .707 .577 .707 r
F P
0 g
s
.52683 .74389 m .51751 .78066 L .54351 .79004 L p .707 .577 .707 r
F P
0 g
s
.59914 .83028 m .59422 .8486 L .62342 .85442 L p .707 .577 .707 r
F P
0 g
s
.62342 .85442 m .62834 .8361 L .59914 .83028 L p .707 .577 .707 r
F P
0 g
s
.53867 .81305 m .53375 .83137 L .56333 .84066 L p .707 .577 .707 r
F P
0 g
s
.64272 .77457 m .6334 .81134 L .65751 .81383 L p .707 .577 .707 r
F P
0 g
s
.65751 .81383 m .66683 .77706 L .64272 .77457 L p .707 .577 .707 r
F P
0 g
s
.51593 .66504 m .50719 .72085 L .52764 .72894 L p .707 .577 .707 r
F P
0 g
s
.6788 .69225 m .67006 .74806 L .68665 .74494 L p .707 .577 .707 r
F P
0 g
s
.68665 .74494 m .69539 .68913 L .6788 .69225 L p .707 .577 .707 r
F P
0 g
s
.53375 .83137 m .53867 .81305 L .51331 .80333 L p .707 .577 .707 r
F P
0 g
s
.51751 .78066 m .52683 .74389 L .50733 .73484 L p .707 .577 .707 r
F P
0 g
s
.51331 .80333 m .5084 .82165 L .53375 .83137 L p .707 .577 .707 r
F P
0 g
s
.62834 .8361 m .62342 .85442 L .64806 .85756 L p .707 .577 .707 r
F P
0 g
s
.64806 .85756 m .65298 .83924 L .62834 .8361 L p .707 .577 .707 r
F P
0 g
s
.50719 .72085 m .51593 .66504 L .50393 .65714 L p .707 .577 .707 r
F P
0 g
s
.50733 .73484 m .49801 .77161 L .51751 .78066 L p .707 .577 .707 r
F P
0 g
s
.66683 .77706 m .65751 .81383 L .67442 .81341 L p .707 .577 .707 r
F P
0 g
s
.67442 .81341 m .68374 .77664 L .66683 .77706 L p .707 .577 .707 r
F P
0 g
s
.5084 .82165 m .51331 .80333 L .49466 .79413 L p .707 .577 .707 r
F P
0 g
s
.50393 .65714 m .49519 .71295 L .50719 .72085 L p .707 .577 .707 r
F P
0 g
s
.49466 .79413 m .48974 .81245 L .5084 .82165 L p .707 .577 .707 r
F P
0 g
s
.65298 .83924 m .64806 .85756 L .66573 .8577 L p .707 .577 .707 r
F P
0 g
s
.66573 .8577 m .67065 .83937 L .65298 .83924 L p .707 .577 .707 r
F P
0 g
s
.49801 .77161 m .50733 .73484 L .49623 .727 L p .707 .577 .707 r
F P
0 g
s
.69539 .68913 m .68665 .74494 L .69413 .73965 L p .707 .577 .707 r
F P
0 g
s
.69413 .73965 m .70287 .68384 L .69539 .68913 L p .707 .577 .707 r
F P
0 g
s
.49623 .727 m .48691 .76377 L .49801 .77161 L p .707 .577 .707 r
F P
0 g
s
.49519 .71295 m .50393 .65714 L .50155 .65021 L p .707 .577 .707 r
F P
0 g
s
.48974 .81245 m .49466 .79413 L .48453 .78635 L p .707 .577 .707 r
F P
0 g
s
.68374 .77664 m .67442 .81341 L .68246 .81011 L p .707 .577 .707 r
F P
0 g
s
.68246 .81011 m .69178 .77334 L .68374 .77664 L p .707 .577 .707 r
F P
0 g
s
.48453 .78635 m .47961 .80467 L .48974 .81245 L p .707 .577 .707 r
F P
0 g
s
.50155 .65021 m .49281 .70602 L .49519 .71295 L p .707 .577 .707 r
F P
0 g
s
.67065 .83937 m .66573 .8577 L .6747 .85483 L p .707 .577 .707 r
F P
0 g
s
.6747 .85483 m .67962 .8365 L .67065 .83937 L p .707 .577 .707 r
F P
0 g
s
.48691 .76377 m .49623 .727 L .49462 .72115 L p .707 .577 .707 r
F P
0 g
s
.70287 .68384 m .69413 .73965 L .69175 .73272 L p .707 .577 .707 r
F P
0 g
s
.69175 .73272 m .70049 .67691 L .70287 .68384 L p .707 .577 .707 r
F P
0 g
s
.49462 .72115 m .4853 .75792 L .48691 .76377 L p .707 .577 .707 r
F P
0 g
s
.49281 .70602 m .50155 .65021 L .50903 .64493 L p .707 .577 .707 r
F P
0 g
s
.50903 .64493 m .50029 .70073 L .49281 .70602 L p .707 .577 .707 r
F P
0 g
s
.4853 .75792 m .49462 .72115 L .50267 .71784 L p .707 .577 .707 r
F P
0 g
s
.50267 .71784 m .49335 .75461 L .4853 .75792 L p .707 .577 .707 r
F P
0 g
s
.50029 .70073 m .50903 .64493 L .52562 .6418 L p .707 .577 .707 r
F P
0 g
s
.52562 .6418 m .51688 .69761 L .50029 .70073 L p .707 .577 .707 r
F P
0 g
s
.49335 .75461 m .50267 .71784 L .51958 .71742 L p .707 .577 .707 r
F P
0 g
s
.51958 .71742 m .51025 .75419 L .49335 .75461 L p .707 .577 .707 r
F P
0 g
s
.48797 .7962 m .49289 .77788 L .51056 .77801 L p .707 .577 .707 r
F P
0 g
s
.51056 .77801 m .50564 .79634 L .48797 .7962 L p .707 .577 .707 r
F P
0 g
s
.50283 .82192 m .50283 .32003 L .45812 .31837 L p .707 .577 .707 r
F P
0 g
s
.51688 .69761 m .52562 .6418 L .54972 .64115 L p .707 .577 .707 r
F P
0 g
s
.54972 .64115 m .54098 .69696 L .51688 .69761 L p .707 .577 .707 r
F P
0 g
s
.51025 .75419 m .51958 .71742 L .54369 .71991 L p .707 .577 .707 r
F P
0 g
s
.54369 .71991 m .53437 .75668 L .51025 .75419 L p .707 .577 .707 r
F P
0 g
s
.50564 .79634 m .51056 .77801 L .5352 .78115 L p .707 .577 .707 r
F P
0 g
s
.5352 .78115 m .53028 .79947 L .50564 .79634 L p .707 .577 .707 r
F P
0 g
s
.53437 .75668 m .54369 .71991 L .57265 .72508 L p .707 .577 .707 r
F P
0 g
s
.57265 .72508 m .56333 .76185 L .53437 .75668 L p .707 .577 .707 r
F P
0 g
s
.53028 .79947 m .5352 .78115 L .5644 .78697 L p .707 .577 .707 r
F P
0 g
s
.5644 .78697 m .55948 .8053 L .53028 .79947 L p .707 .577 .707 r
F P
0 g
s
.50283 .32003 m .50283 .82192 L .54725 .81979 L p .707 .577 .707 r
F P
0 g
s
.54098 .69696 m .54972 .64115 L .57895 .64303 L p .707 .577 .707 r
F P
0 g
s
.57895 .64303 m .57021 .69884 L .54098 .69696 L p .707 .577 .707 r
F P
0 g
s
.54725 .81979 m .54725 .3179 L .50283 .32003 L p .707 .577 .707 r
F P
0 g
s
.47961 .80467 m .48453 .78635 L .48392 .78075 L p .707 .577 .707 r
F P
0 g
s
.45812 .82026 m .45812 .31837 L .41752 .31308 L p .707 .577 .707 r
F P
0 g
s
.48392 .78075 m .47901 .79907 L .47961 .80467 L p .707 .577 .707 r
F P
0 g
s
.47901 .79907 m .48392 .78075 L .49289 .77788 L p .707 .577 .707 r
F P
0 g
s
.49289 .77788 m .48797 .7962 L .47901 .79907 L p .707 .577 .707 r
F P
0 g
s
.45812 .31837 m .45812 .82026 L .50283 .82192 L p .707 .577 .707 r
F P
0 g
s
.57021 .69884 m .57895 .64303 L .61046 .64726 L p .707 .577 .707 r
F P
0 g
s
.61046 .64726 m .60171 .70307 L .57021 .69884 L p .707 .577 .707 r
F P
0 g
s
.56333 .76185 m .57265 .72508 L .60362 .73242 L p .707 .577 .707 r
F P
0 g
s
.60362 .73242 m .5943 .76919 L .56333 .76185 L p .707 .577 .707 r
F P
0 g
s
.55948 .8053 m .5644 .78697 L .5953 .79492 L p .707 .577 .707 r
F P
0 g
s
.5953 .79492 m .59038 .81324 L .55948 .8053 L p .707 .577 .707 r
F P
0 g
s
.54725 .3179 m .54725 .81979 L .58706 .81408 L p .707 .577 .707 r
F P
0 g
s
.58706 .81408 m .58706 .31219 L .54725 .3179 L p .707 .577 .707 r
F P
0 g
s
.69178 .77334 m .68246 .81011 L .68086 .80425 L p .707 .577 .707 r
F P
0 g
s
.68086 .80425 m .69018 .76748 L .69178 .77334 L p .707 .577 .707 r
F P
0 g
s
.67962 .8365 m .6747 .85483 L .67409 .84923 L p .707 .577 .707 r
F P
0 g
s
.67409 .84923 m .67901 .8309 L .67962 .8365 L p .707 .577 .707 r
F P
0 g
s
.70049 .67691 m .69175 .73272 L .67975 .72482 L p .707 .577 .707 r
F P
0 g
s
.67975 .72482 m .68849 .66901 L .70049 .67691 L p .707 .577 .707 r
F P
0 g
s
.41752 .81497 m .41752 .31308 L .38499 .30469 L p .707 .577 .707 r
F P
0 g
s
.41752 .31308 m .41752 .81497 L .45812 .82026 L p .707 .577 .707 r
F P
0 g
s
.64116 .65342 m .63242 .70923 L .60171 .70307 L p .707 .577 .707 r
F P
0 g
s
.60171 .70307 m .61046 .64726 L .64116 .65342 L p .707 .577 .707 r
F P
0 g
s
.63358 .74121 m .62426 .77798 L .5943 .76919 L p .707 .577 .707 r
F P
0 g
s
.5943 .76919 m .60362 .73242 L .63358 .74121 L p .707 .577 .707 r
F P
0 g
s
.59038 .81324 m .5953 .79492 L .62487 .8042 L p .707 .577 .707 r
F P
0 g
s
.58706 .31219 m .58706 .81408 L .61834 .80535 L p .707 .577 .707 r
F P
0 g
s
.61834 .80535 m .61834 .30346 L .58706 .31219 L p .707 .577 .707 r
F P
0 g
s
.24793 .72399 m .25168 .67155 L .22065 .66664 L p .707 .577 .707 r
F P
0 g
s
.25168 .67155 m .24793 .72399 L .27972 .72483 L p .707 .577 .707 r
F P
0 g
s
.27972 .72483 m .28348 .67239 L .25168 .67155 L p .707 .577 .707 r
F P
0 g
s
.69018 .76748 m .68086 .80425 L .66976 .79641 L p .707 .577 .707 r
F P
0 g
s
.66976 .79641 m .67908 .75964 L .69018 .76748 L p .707 .577 .707 r
F P
0 g
s
.28348 .67239 m .27972 .72483 L .30919 .72152 L p .707 .577 .707 r
F P
0 g
s
.30919 .72152 m .31294 .66908 L .28348 .67239 L p .707 .577 .707 r
F P
0 g
s
.2169 .71907 m .22065 .66664 L .19344 .65813 L p .707 .577 .707 r
F P
0 g
s
.22065 .66664 m .2169 .71907 L .24793 .72399 L p .707 .577 .707 r
F P
0 g
s
.67901 .8309 m .67409 .84923 L .66397 .84144 L p .707 .577 .707 r
F P
0 g
s
.66397 .84144 m .66888 .82312 L .67901 .8309 L p .707 .577 .707 r
F P
0 g
s
.68849 .66901 m .67975 .72482 L .65931 .71673 L p .707 .577 .707 r
F P
0 g
s
.65931 .71673 m .66805 .66092 L .68849 .66901 L p .707 .577 .707 r
F P
0 g
s
.31294 .66908 m .30919 .72152 L .33343 .71437 L p .707 .577 .707 r
F P
0 g
s
.33343 .71437 m .33718 .66194 L .31294 .66908 L p .707 .577 .707 r
F P
0 g
s
.38499 .80658 m .38499 .30469 L .36371 .29401 L p .707 .577 .707 r
F P
0 g
s
.38499 .30469 m .38499 .80658 L .41752 .81497 L p .707 .577 .707 r
F P
0 g
s
.18969 .71057 m .19344 .65813 L .17271 .64687 L p .707 .577 .707 r
F P
0 g
s
.19344 .65813 m .18969 .71057 L .2169 .71907 L p .707 .577 .707 r
F P
0 g
s
.66805 .66092 m .65931 .71673 L .63242 .70923 L p .707 .577 .707 r
F P
0 g
s
.63242 .70923 m .64116 .65342 L .66805 .66092 L p .707 .577 .707 r
F P
0 g
s
.65958 .75059 m .65026 .78736 L .62426 .77798 L p .707 .577 .707 r
F P
0 g
s
.62426 .77798 m .63358 .74121 L .65958 .75059 L p .707 .577 .707 r
F P
0 g
s
.61834 .30346 m .61834 .80535 L .63803 .79445 L p .707 .577 .707 r
F P
0 g
s
.63803 .79445 m .63803 .29257 L .61834 .30346 L p .707 .577 .707 r
F P
0 g
s
.67908 .75964 m .66976 .79641 L .65026 .78736 L p .707 .577 .707 r
F P
0 g
s
.65026 .78736 m .65958 .75059 L .67908 .75964 L p .707 .577 .707 r
F P
0 g
s
.33718 .66194 m .33343 .71437 L .35007 .7041 L p .707 .577 .707 r
F P
0 g
s
.35007 .7041 m .35383 .65166 L .33718 .66194 L p .707 .577 .707 r
F P
0 g
s
.24215 .7899 m .24617 .75678 L .21537 .75001 L p .707 .577 .707 r
F P
0 g
s
.24617 .75678 m .24215 .7899 L .27388 .79178 L p .707 .577 .707 r
F P
0 g
s
.27388 .79178 m .2779 .75866 L .24617 .75678 L p .707 .577 .707 r
F P
0 g
s
.2779 .75866 m .27388 .79178 L .30345 .78858 L p .707 .577 .707 r
F P
0 g
s
.30345 .78858 m .30746 .75546 L .2779 .75866 L p .707 .577 .707 r
F P
0 g
s
.21136 .78313 m .21537 .75001 L .18853 .73899 L p .707 .577 .707 r
F P
0 g
s
.21537 .75001 m .21136 .78313 L .24215 .7899 L p .707 .577 .707 r
F P
0 g
s
.66888 .82312 m .66397 .84144 L .64531 .83224 L p .707 .577 .707 r
F P
0 g
s
.64531 .83224 m .65023 .81392 L .66888 .82312 L p .707 .577 .707 r
F P
0 g
s
.16896 .69931 m .17271 .64687 L .16048 .63395 L p .707 .577 .707 r
F P
0 g
s
.17271 .64687 m .16896 .69931 L .18969 .71057 L p .707 .577 .707 r
F P
0 g
s
.30746 .75546 m .30345 .78858 L .32795 .78061 L p .707 .577 .707 r
F P
0 g
s
.32795 .78061 m .33196 .74749 L .30746 .75546 L p .707 .577 .707 r
F P
0 g
s
.18452 .77211 m .18853 .73899 L .16827 .72483 L p .707 .577 .707 r
F P
0 g
s
.18853 .73899 m .18452 .77211 L .21136 .78313 L p .707 .577 .707 r
F P
0 g
s
.36371 .7959 m .36371 .29401 L .35578 .28209 L p .707 .577 .707 r
F P
0 g
s
.36371 .29401 m .36371 .7959 L .38499 .80658 L p .707 .577 .707 r
F P
0 g
s
.35383 .65166 m .35007 .7041 L .3575 .69171 L p .707 .577 .707 r
F P
0 g
s
.3575 .69171 m .36125 .63927 L .35383 .65166 L p .707 .577 .707 r
F P
0 g
s
.63803 .29257 m .63803 .79445 L .64422 .78246 L p .707 .577 .707 r
F P
0 g
s
.64422 .78246 m .64422 .28057 L .63803 .29257 L p .707 .577 .707 r
F P
0 g
s
.23616 .83161 m .23826 .81528 L .20773 .80781 L p .707 .577 .707 r
F P
0 g
s
.23826 .81528 m .23616 .83161 L .26792 .83404 L p .707 .577 .707 r
F P
0 g
s
.26792 .83404 m .27002 .8177 L .23826 .81528 L p .707 .577 .707 r
F P
0 g
s
.16048 .63395 m .15673 .68639 L .16896 .69931 L p .707 .577 .707 r
F P
0 g
s
.65023 .81392 m .64531 .83224 L .61996 .82253 L p .707 .577 .707 r
F P
0 g
s
.61996 .82253 m .62487 .8042 L .65023 .81392 L p .707 .577 .707 r
F P
0 g
s
.27002 .8177 m .26792 .83404 L .2978 .83118 L p .707 .577 .707 r
F P
0 g
s
.2978 .83118 m .2999 .81485 L .27002 .8177 L p .707 .577 .707 r
F P
0 g
s
.15673 .68639 m .16048 .63395 L .15795 .62065 L p .707 .577 .707 r
F P
0 g
s
.33196 .74749 m .32795 .78061 L .34498 .76865 L p .707 .577 .707 r
F P
0 g
s
.34498 .76865 m .349 .73553 L .33196 .74749 L p .707 .577 .707 r
F P
0 g
s
.20563 .82415 m .20773 .80781 L .18142 .79603 L p .707 .577 .707 r
F P
0 g
s
.20773 .80781 m .20563 .82415 L .23616 .83161 L p .707 .577 .707 r
F P
0 g
s
.16827 .72483 m .16426 .75795 L .18452 .77211 L p .707 .577 .707 r
F P
0 g
s
.16426 .75795 m .16827 .72483 L .15657 .70889 L p .707 .577 .707 r
F P
0 g
s
.2999 .81485 m .2978 .83118 L .32288 .82333 L p .707 .577 .707 r
F P
0 g
s
.32288 .82333 m .32498 .80699 L .2999 .81485 L p .707 .577 .707 r
F P
0 g
s
.18142 .79603 m .17932 .81237 L .20563 .82415 L p .707 .577 .707 r
F P
0 g
s
.62487 .8042 m .61996 .82253 L .59038 .81324 L p .707 .577 .707 r
F P
0 g
s
.17932 .81237 m .18142 .79603 L .1619 .78109 L p .707 .577 .707 r
F P
0 g
s
.36125 .63927 m .3575 .69171 L .35497 .6784 L p .707 .577 .707 r
F P
0 g
s
.35497 .6784 m .35872 .62596 L .36125 .63927 L p .707 .577 .707 r
F P
0 g
s
.15795 .62065 m .1542 .67308 L .15673 .68639 L p .707 .577 .707 r
F P
0 g
s
.15657 .70889 m .15256 .74201 L .16426 .75795 L p .707 .577 .707 r
F P
0 g
s
.349 .73553 m .34498 .76865 L .3529 .75387 L p .707 .577 .707 r
F P
0 g
s
.3529 .75387 m .35691 .72075 L .349 .73553 L p .707 .577 .707 r
F P
0 g
s
.1619 .78109 m .15981 .79743 L .17932 .81237 L p .707 .577 .707 r
F P
0 g
s
.32498 .80699 m .32288 .82333 L .3407 .81124 L p .707 .577 .707 r
F P
0 g
s
.3407 .81124 m .3428 .7949 L .32498 .80699 L p .707 .577 .707 r
F P
0 g
s
.1542 .67308 m .15795 .62065 L .16537 .60825 L p .707 .577 .707 r
F P
0 g
s
.15256 .74201 m .15657 .70889 L .15458 .69274 L p .707 .577 .707 r
F P
0 g
s
.35872 .62596 m .35497 .6784 L .34274 .66548 L p .707 .577 .707 r
F P
0 g
s
.34274 .66548 m .34649 .61304 L .35872 .62596 L p .707 .577 .707 r
F P
0 g
s
.35691 .72075 m .3529 .75387 L .35091 .73773 L p .707 .577 .707 r
F P
0 g
s
.35091 .73773 m .35492 .70461 L .35691 .72075 L p .707 .577 .707 r
F P
0 g
s
.35578 .28209 m .35578 .78398 L .36371 .7959 L p .707 .577 .707 r
F P
0 g
s
.35578 .78398 m .35578 .28209 L .36197 .27009 L p .707 .577 .707 r
F P
0 g
s
.15981 .79743 m .1619 .78109 L .15109 .76446 L p .707 .577 .707 r
F P
0 g
s
.64422 .28057 m .64422 .78246 L .63628 .77054 L p .707 .577 .707 r
F P
0 g
s
.63628 .77054 m .63628 .26865 L .64422 .28057 L p .707 .577 .707 r
F P
0 g
s
.15109 .76446 m .149 .78079 L .15981 .79743 L p .707 .577 .707 r
F P
0 g
s
.15458 .69274 m .15057 .72586 L .15256 .74201 L p .707 .577 .707 r
F P
0 g
s
.3428 .7949 m .3407 .81124 L .34952 .7961 L p .707 .577 .707 r
F P
0 g
s
.34952 .7961 m .35161 .77977 L .3428 .7949 L p .707 .577 .707 r
F P
0 g
s
.16537 .60825 m .16162 .66069 L .1542 .67308 L p .707 .577 .707 r
F P
0 g
s
.16162 .66069 m .16537 .60825 L .18202 .59798 L p .707 .577 .707 r
F P
0 g
s
.15057 .72586 m .15458 .69274 L .16249 .67796 L p .707 .577 .707 r
F P
0 g
s
.149 .78079 m .15109 .76446 L .15004 .74776 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15004 .74776 m .14795 .76409 L .149 .78079 L p .707 .577 .707 r
F P
0 g
s
.36197 .77198 m .36197 .27009 L .38166 .2592 L p .707 .577 .707 r
F P
0 g
s
.36197 .27009 m .36197 .77198 L .35578 .78398 L p .707 .577 .707 r
F P
0 g
s
.34649 .61304 m .34274 .66548 L .322 .65422 L p .707 .577 .707 r
F P
0 g
s
.322 .65422 m .32576 .60178 L .34649 .61304 L p .707 .577 .707 r
F P
0 g
s
.16249 .67796 m .15848 .71108 L .15057 .72586 L p .707 .577 .707 r
F P
0 g
s
.35161 .77977 m .34952 .7961 L .34847 .7794 L p .707 .577 .707 r
F P
0 g
s
.34847 .7794 m .35057 .76306 L .35161 .77977 L p .707 .577 .707 r
F P
0 g
s
.63628 .26865 m .63628 .77054 L .61501 .75986 L p .707 .577 .707 r
F P
0 g
s
.61501 .75986 m .61501 .25797 L .63628 .26865 L p .707 .577 .707 r
F P
0 g
s
.35492 .70461 m .35091 .73773 L .33921 .72179 L p .707 .577 .707 r
F P
0 g
s
.33921 .72179 m .34322 .68867 L .35492 .70461 L p .707 .577 .707 r
F P
0 g
s
.18202 .59798 m .17827 .65042 L .16162 .66069 L p .707 .577 .707 r
F P
0 g
s
.17827 .65042 m .18202 .59798 L .20626 .59084 L p .707 .577 .707 r
F P
0 g
s
.15848 .71108 m .16249 .67796 L .17953 .66601 L p .707 .577 .707 r
F P
0 g
s
.14795 .76409 m .15004 .74776 L .15886 .73262 L p .707 .577 .707 r
F P
0 g
s
.32576 .60178 m .322 .65422 L .29479 .64572 L p .707 .577 .707 r
F P
0 g
s
.29479 .64572 m .29855 .59328 L .32576 .60178 L p .707 .577 .707 r
F P
0 g
s
.15886 .73262 m .15677 .74895 L .14795 .76409 L p .707 .577 .707 r
F P
0 g
s
.20251 .64327 m .20626 .59084 L .23572 .58752 L p .707 .577 .707 r
F P
0 g
s
.20626 .59084 m .20251 .64327 L .17827 .65042 L p .707 .577 .707 r
F P
0 g
s
.17953 .66601 m .17552 .69913 L .15848 .71108 L p .707 .577 .707 r
F P
0 g
s
.34322 .68867 m .33921 .72179 L .31895 .70762 L p .707 .577 .707 r
F P
0 g
s
.31895 .70762 m .32296 .6745 L .34322 .68867 L p .707 .577 .707 r
F P
0 g
s
.35057 .76306 m .34847 .7794 L .33766 .76276 L p .707 .577 .707 r
F P
0 g
s
.33766 .76276 m .33976 .74643 L .35057 .76306 L p .707 .577 .707 r
F P
0 g
s
.17552 .69913 m .17953 .66601 L .20403 .65803 L p .707 .577 .707 r
F P
0 g
s
.29855 .59328 m .29479 .64572 L .26377 .6408 L p .707 .577 .707 r
F P
0 g
s
.26377 .6408 m .26752 .58836 L .29855 .59328 L p .707 .577 .707 r
F P
0 g
s
.38166 .76109 m .38166 .2592 L .41294 .25047 L p .707 .577 .707 r
F P
0 g
s
.38166 .2592 m .38166 .76109 L .36197 .77198 L p .707 .577 .707 r
F P
0 g
s
.23197 .63996 m .23572 .58752 L .26752 .58836 L p .707 .577 .707 r
F P
0 g
s
.23572 .58752 m .23197 .63996 L .20251 .64327 L p .707 .577 .707 r
F P
0 g
s
.15677 .74895 m .15886 .73262 L .17668 .72053 L p .707 .577 .707 r
F P
0 g
s
.61501 .25797 m .61501 .75986 L .58248 .75147 L p .707 .577 .707 r
F P
0 g
s
.58248 .75147 m .58248 .24958 L .61501 .25797 L p .707 .577 .707 r
F P
0 g
s
.26752 .58836 m .26377 .6408 L .23197 .63996 L p .707 .577 .707 r
F P
0 g
s
.73623 .64473 m .73248 .58755 L .70145 .58868 L p .707 .577 .707 r
F P
0 g
s
.73248 .58755 m .73623 .64473 L .76803 .64237 L p .707 .577 .707 r
F P
0 g
s
.76803 .64237 m .76428 .58519 L .73248 .58755 L p .707 .577 .707 r
F P
0 g
s
.76428 .58519 m .76803 .64237 L .79749 .63903 L p .707 .577 .707 r
F P
0 g
s
.79749 .63903 m .79374 .58185 L .76428 .58519 L p .707 .577 .707 r
F P
0 g
s
.17668 .72053 m .17459 .73686 L .15677 .74895 L p .707 .577 .707 r
F P
0 g
s
.32296 .6745 m .31895 .70762 L .2921 .69661 L p .707 .577 .707 r
F P
0 g
s
.2921 .69661 m .29612 .66349 L .32296 .6745 L p .707 .577 .707 r
F P
0 g
s
.70145 .58868 m .7052 .64586 L .73623 .64473 L p .707 .577 .707 r
F P
0 g
s
.7052 .64586 m .70145 .58868 L .67424 .58849 L p .707 .577 .707 r
F P
0 g
s
.20002 .69115 m .20403 .65803 L .23359 .65483 L p .707 .577 .707 r
F P
0 g
s
.20403 .65803 m .20002 .69115 L .17552 .69913 L p .707 .577 .707 r
F P
0 g
s
.33976 .74643 m .33766 .76276 L .31815 .74782 L p .707 .577 .707 r
F P
0 g
s
.31815 .74782 m .32024 .73149 L .33976 .74643 L p .707 .577 .707 r
F P
0 g
s
.73869 .69787 m .73467 .65962 L .70388 .6627 L p .707 .577 .707 r
F P
0 g
s
.73467 .65962 m .73869 .69787 L .77042 .6945 L p .707 .577 .707 r
F P
0 g
s
.77042 .6945 m .7664 .65626 L .73467 .65962 L p .707 .577 .707 r
F P
0 g
s
.70388 .6627 m .70789 .70095 L .73869 .69787 L p .707 .577 .707 r
F P
0 g
s
.79374 .58185 m .79749 .63903 L .82173 .63502 L p .707 .577 .707 r
F P
0 g
s
.82173 .63502 m .81798 .57784 L .79374 .58185 L p .707 .577 .707 r
F P
0 g
s
.67424 .58849 m .67799 .64566 L .7052 .64586 L p .707 .577 .707 r
F P
0 g
s
.7664 .65626 m .77042 .6945 L .79998 .69118 L p .707 .577 .707 r
F P
0 g
s
.79998 .69118 m .79597 .65293 L .7664 .65626 L p .707 .577 .707 r
F P
0 g
s
.17459 .73686 m .17668 .72053 L .20176 .71267 L p .707 .577 .707 r
F P
0 g
s
.29612 .66349 m .2921 .69661 L .26131 .68983 L p .707 .577 .707 r
F P
0 g
s
.26131 .68983 m .26532 .65671 L .29612 .66349 L p .707 .577 .707 r
F P
0 g
s
.70607 .72423 m .70816 .74335 L .73869 .73997 L p .707 .577 .707 r
F P
0 g
s
.73869 .73997 m .73659 .72086 L .70607 .72423 L p .707 .577 .707 r
F P
0 g
s
.73659 .72086 m .73869 .73997 L .77045 .7365 L p .707 .577 .707 r
F P
0 g
s
.77045 .7365 m .76835 .71738 L .73659 .72086 L p .707 .577 .707 r
F P
0 g
s
.76835 .71738 m .77045 .7365 L .80033 .73326 L p .707 .577 .707 r
F P
0 g
s
.22958 .68795 m .23359 .65483 L .26532 .65671 L p .707 .577 .707 r
F P
0 g
s
.23359 .65483 m .22958 .68795 L .20002 .69115 L p .707 .577 .707 r
F P
0 g
s
.80033 .73326 m .79824 .71414 L .76835 .71738 L p .707 .577 .707 r
F P
0 g
s
.70789 .70095 m .70388 .6627 L .67704 .66518 L p .707 .577 .707 r
F P
0 g
s
.67704 .66518 m .68105 .70343 L .70789 .70095 L p .707 .577 .707 r
F P
0 g
s
.26532 .65671 m .26131 .68983 L .22958 .68795 L p .707 .577 .707 r
F P
0 g
s
.41294 .25047 m .41294 .75236 L .38166 .76109 L p .707 .577 .707 r
F P
0 g
s
.41294 .75236 m .41294 .25047 L .45274 .24476 L p .707 .577 .707 r
F P
0 g
s
.67799 .64566 m .67424 .58849 L .65351 .58698 L p .707 .577 .707 r
F P
0 g
s
.79597 .65293 m .79998 .69118 L .82448 .68822 L p .707 .577 .707 r
F P
0 g
s
.82448 .68822 m .82047 .64997 L .79597 .65293 L p .707 .577 .707 r
F P
0 g
s
.58248 .24958 m .58248 .75147 L .54188 .74618 L p .707 .577 .707 r
F P
0 g
s
.54188 .74618 m .54188 .24429 L .58248 .24958 L p .707 .577 .707 r
F P
0 g
s
.67976 .72717 m .68185 .74629 L .70816 .74335 L p .707 .577 .707 r
F P
0 g
s
.70816 .74335 m .70607 .72423 L .67976 .72717 L p .707 .577 .707 r
F P
0 g
s
.20176 .71267 m .19967 .72901 L .17459 .73686 L p .707 .577 .707 r
F P
0 g
s
.32024 .73149 m .31815 .74782 L .29184 .73604 L p .707 .577 .707 r
F P
0 g
s
.29184 .73604 m .29393 .71971 L .32024 .73149 L p .707 .577 .707 r
F P
0 g
s
.79824 .71414 m .80033 .73326 L .82541 .73058 L p .707 .577 .707 r
F P
0 g
s
.82541 .73058 m .82331 .71146 L .79824 .71414 L p .707 .577 .707 r
F P
0 g
s
.65351 .58698 m .65726 .64415 L .67799 .64566 L p .707 .577 .707 r
F P
0 g
s
.81798 .57784 m .82173 .63502 L .83838 .63074 L p .707 .577 .707 r
F P
0 g
s
.83838 .63074 m .83462 .57356 L .81798 .57784 L p .707 .577 .707 r
F P
0 g
s
.19967 .72901 m .20176 .71267 L .23164 .70982 L p .707 .577 .707 r
F P
0 g
s
.68105 .70343 m .67704 .66518 L .65678 .66683 L p .707 .577 .707 r
F P
0 g
s
.65678 .66683 m .66079 .70508 L .68105 .70343 L p .707 .577 .707 r
F P
0 g
s
.29393 .71971 m .29184 .73604 L .26131 .72858 L p .707 .577 .707 r
F P
0 g
s
.26131 .72858 m .2634 .71224 L .29393 .71971 L p .707 .577 .707 r
F P
0 g
s
.45274 .74665 m .45274 .24476 L .49717 .24263 L p .707 .577 .707 r
F P
0 g
s
.45274 .24476 m .45274 .74665 L .41294 .75236 L p .707 .577 .707 r
F P
0 g
s
.66024 .72939 m .66234 .74851 L .68185 .74629 L p .707 .577 .707 r
F P
0 g
s
.68185 .74629 m .67976 .72717 L .66024 .72939 L p .707 .577 .707 r
F P
0 g
s
.23164 .70982 m .22955 .72615 L .19967 .72901 L p .707 .577 .707 r
F P
0 g
s
.54188 .24429 m .54188 .74618 L .49717 .74452 L p .707 .577 .707 r
F P
0 g
s
.49717 .74452 m .49717 .24263 L .54188 .24429 L p .707 .577 .707 r
F P
0 g
s
.82047 .64997 m .82448 .68822 L .84152 .68591 L p .707 .577 .707 r
F P
0 g
s
.84152 .68591 m .83751 .64767 L .82047 .64997 L p .707 .577 .707 r
F P
0 g
s
.22955 .72615 m .23164 .70982 L .2634 .71224 L p .707 .577 .707 r
F P
0 g
s
.65726 .64415 m .65351 .58698 L .64128 .5843 L p .707 .577 .707 r
F P
0 g
s
.2634 .71224 m .26131 .72858 L .22955 .72615 L p .707 .577 .707 r
F P
0 g
s
.82331 .71146 m .82541 .73058 L .84323 .72871 L p .707 .577 .707 r
F P
0 g
s
.84323 .72871 m .84114 .70959 L .82331 .71146 L p .707 .577 .707 r
F P
0 g
s
.49717 .24263 m .49717 .74452 L .45274 .74665 L p .707 .577 .707 r
F P
0 g
s
.64128 .5843 m .64503 .64148 L .65726 .64415 L p .707 .577 .707 r
F P
0 g
s
.83462 .57356 m .83838 .63074 L .8458 .62661 L p .707 .577 .707 r
F P
0 g
s
.8458 .62661 m .84205 .56943 L .83462 .57356 L p .707 .577 .707 r
F P
0 g
s
.66079 .70508 m .65678 .66683 L .64508 .66749 L p .707 .577 .707 r
F P
0 g
s
.64508 .66749 m .64909 .70574 L .66079 .70508 L p .707 .577 .707 r
F P
0 g
s
.64943 .73067 m .65153 .74979 L .66234 .74851 L p .707 .577 .707 r
F P
0 g
s
.66234 .74851 m .66024 .72939 L .64943 .73067 L p .707 .577 .707 r
F P
0 g
s
.83751 .64767 m .84152 .68591 L .84943 .68449 L p .707 .577 .707 r
F P
0 g
s
.84943 .68449 m .84542 .64624 L .83751 .64767 L p .707 .577 .707 r
F P
0 g
s
.84114 .70959 m .84323 .72871 L .85205 .72784 L p .707 .577 .707 r
F P
0 g
s
.85205 .72784 m .84995 .70873 L .84114 .70959 L p .707 .577 .707 r
F P
0 g
s
.64503 .64148 m .64128 .5843 L .63875 .58073 L p .707 .577 .707 r
F P
0 g
s
.63875 .58073 m .6425 .6379 L .64503 .64148 L p .707 .577 .707 r
F P
0 g
s
.84205 .56943 m .8458 .62661 L .84327 .62303 L p .707 .577 .707 r
F P
0 g
s
.84327 .62303 m .83952 .56586 L .84205 .56943 L p .707 .577 .707 r
F P
0 g
s
.64909 .70574 m .64508 .66749 L .64309 .66709 L p .707 .577 .707 r
F P
0 g
s
.64309 .66709 m .6471 .70534 L .64909 .70574 L p .707 .577 .707 r
F P
0 g
s
.64838 .73089 m .65048 .75001 L .65153 .74979 L p .707 .577 .707 r
F P
0 g
s
.65153 .74979 m .64943 .73067 L .64838 .73089 L p .707 .577 .707 r
F P
0 g
s
.84542 .64624 m .84943 .68449 L .84744 .68409 L p .707 .577 .707 r
F P
0 g
s
.84744 .68409 m .84343 .64584 L .84542 .64624 L p .707 .577 .707 r
F P
0 g
s
.84995 .70873 m .85205 .72784 L .851 .72806 L p .707 .577 .707 r
F P
0 g
s
.851 .72806 m .84891 .70894 L .84995 .70873 L p .707 .577 .707 r
F P
0 g
s
.6425 .6379 m .63875 .58073 L .64617 .5766 L p .707 .577 .707 r
F P
0 g
s
.64617 .5766 m .64992 .63377 L .6425 .6379 L p .707 .577 .707 r
F P
0 g
s
.83952 .56586 m .84327 .62303 L .83104 .62036 L p .707 .577 .707 r
F P
0 g
s
.83104 .62036 m .82729 .56318 L .83952 .56586 L p .707 .577 .707 r
F P
0 g
s
.6471 .70534 m .64309 .66709 L .651 .66566 L p .707 .577 .707 r
F P
0 g
s
.651 .66566 m .65501 .70391 L .6471 .70534 L p .707 .577 .707 r
F P
0 g
s
.6572 .73002 m .6593 .74914 L .65048 .75001 L p .707 .577 .707 r
F P
0 g
s
.65048 .75001 m .64838 .73089 L .6572 .73002 L p .707 .577 .707 r
F P
0 g
s
.84343 .64584 m .84744 .68409 L .83574 .68474 L p .707 .577 .707 r
F P
0 g
s
.83574 .68474 m .83173 .6465 L .84343 .64584 L p .707 .577 .707 r
F P
0 g
s
.39828 .62657 m .38954 .57271 L .35884 .57467 L p .707 .577 .707 r
F P
0 g
s
.38954 .57271 m .39828 .62657 L .42979 .62121 L p .707 .577 .707 r
F P
0 g
s
.42979 .62121 m .42105 .56736 L .38954 .57271 L p .707 .577 .707 r
F P
0 g
s
.42105 .56736 m .42979 .62121 L .45902 .61299 L p .707 .577 .707 r
F P
0 g
s
.45902 .61299 m .45028 .55913 L .42105 .56736 L p .707 .577 .707 r
F P
0 g
s
.84891 .70894 m .851 .72806 L .84019 .72934 L p .707 .577 .707 r
F P
0 g
s
.84019 .72934 m .8381 .71022 L .84891 .70894 L p .707 .577 .707 r
F P
0 g
s
.64992 .63377 m .64617 .5766 L .66282 .57232 L p .707 .577 .707 r
F P
0 g
s
.36758 .62852 m .35884 .57467 L .33195 .57303 L p .707 .577 .707 r
F P
0 g
s
.35884 .57467 m .36758 .62852 L .39828 .62657 L p .707 .577 .707 r
F P
0 g
s
.66282 .57232 m .66657 .6295 L .64992 .63377 L p .707 .577 .707 r
F P
0 g
s
.45028 .55913 m .45902 .61299 L .48311 .60269 L p .707 .577 .707 r
F P
0 g
s
.48311 .60269 m .47437 .54884 L .45028 .55913 L p .707 .577 .707 r
F P
0 g
s
.82729 .56318 m .83104 .62036 L .81031 .61885 L p .707 .577 .707 r
F P
0 g
s
.81031 .61885 m .80656 .56167 L .82729 .56318 L p .707 .577 .707 r
F P
0 g
s
.65501 .70391 m .651 .66566 L .66804 .66336 L p .707 .577 .707 r
F P
0 g
s
.66804 .66336 m .67205 .70161 L .65501 .70391 L p .707 .577 .707 r
F P
0 g
s
.67502 .72815 m .67712 .74727 L .6593 .74914 L p .707 .577 .707 r
F P
0 g
s
.6593 .74914 m .6572 .73002 L .67502 .72815 L p .707 .577 .707 r
F P
0 g
s
.34069 .62688 m .33195 .57303 L .31151 .56796 L p .707 .577 .707 r
F P
0 g
s
.33195 .57303 m .34069 .62688 L .36758 .62852 L p .707 .577 .707 r
F P
0 g
s
.43667 .68235 m .42735 .64757 L .39637 .65538 L p .707 .577 .707 r
F P
0 g
s
.42735 .64757 m .43667 .68235 L .46563 .67146 L p .707 .577 .707 r
F P
0 g
s
.46563 .67146 m .45631 .63668 L .42735 .64757 L p .707 .577 .707 r
F P
0 g
s
.40569 .69015 m .39637 .65538 L .36642 .65934 L p .707 .577 .707 r
F P
0 g
s
.39637 .65538 m .40569 .69015 L .43667 .68235 L p .707 .577 .707 r
F P
0 g
s
.83173 .6465 m .83574 .68474 L .81548 .6864 L p .707 .577 .707 r
F P
0 g
s
.81548 .6864 m .81147 .64815 L .83173 .6465 L p .707 .577 .707 r
F P
0 g
s
.47437 .54884 m .48311 .60269 L .49971 .59133 L p .707 .577 .707 r
F P
0 g
s
.49971 .59133 m .49097 .53748 L .47437 .54884 L p .707 .577 .707 r
F P
0 g
s
.66657 .6295 m .66282 .57232 L .68706 .56831 L p .707 .577 .707 r
F P
0 g
s
.8381 .71022 m .84019 .72934 L .82068 .73156 L p .707 .577 .707 r
F P
0 g
s
.82068 .73156 m .81858 .71244 L .8381 .71022 L p .707 .577 .707 r
F P
0 g
s
.45631 .63668 m .46563 .67146 L .48974 .65855 L p .707 .577 .707 r
F P
0 g
s
.48974 .65855 m .48042 .62377 L .45631 .63668 L p .707 .577 .707 r
F P
0 g
s
.68706 .56831 m .69081 .62549 L .66657 .6295 L p .707 .577 .707 r
F P
0 g
s
.37574 .69412 m .36642 .65934 L .34042 .65907 L p .707 .577 .707 r
F P
0 g
s
.36642 .65934 m .37574 .69412 L .40569 .69015 L p .707 .577 .707 r
F P
0 g
s
.80656 .56167 m .81031 .61885 L .7831 .61865 L p .707 .577 .707 r
F P
0 g
s
.7831 .61865 m .77935 .56148 L .80656 .56167 L p .707 .577 .707 r
F P
0 g
s
.67205 .70161 m .66804 .66336 L .69254 .6604 L p .707 .577 .707 r
F P
0 g
s
.69254 .6604 m .69655 .69865 L .67205 .70161 L p .707 .577 .707 r
F P
0 g
s
.31151 .56796 m .32025 .62181 L .34069 .62688 L p .707 .577 .707 r
F P
0 g
s
.44051 .72447 m .4356 .70715 L .4047 .71499 L p .707 .577 .707 r
F P
0 g
s
.4356 .70715 m .44051 .72447 L .46971 .71347 L p .707 .577 .707 r
F P
0 g
s
.46971 .71347 m .4648 .69615 L .4356 .70715 L p .707 .577 .707 r
F P
0 g
s
.69081 .62549 m .68706 .56831 L .71652 .56497 L p .707 .577 .707 r
F P
0 g
s
.32025 .62181 m .31151 .56796 L .29951 .55996 L p .707 .577 .707 r
F P
0 g
s
.40962 .73231 m .4047 .71499 L .37512 .7189 L p .707 .577 .707 r
F P
0 g
s
.4047 .71499 m .40962 .73231 L .44051 .72447 L p .707 .577 .707 r
F P
0 g
s
.48042 .62377 m .48974 .65855 L .50665 .64489 L p .707 .577 .707 r
F P
0 g
s
.50665 .64489 m .49733 .61011 L .48042 .62377 L p .707 .577 .707 r
F P
0 g
s
.7001 .72547 m .7022 .74459 L .67712 .74727 L p .707 .577 .707 r
F P
0 g
s
.67712 .74727 m .67502 .72815 L .7001 .72547 L p .707 .577 .707 r
F P
0 g
s
.34042 .65907 m .34974 .69384 L .37574 .69412 L p .707 .577 .707 r
F P
0 g
s
.81147 .64815 m .81548 .6864 L .78864 .68888 L p .707 .577 .707 r
F P
0 g
s
.78864 .68888 m .78463 .65063 L .81147 .64815 L p .707 .577 .707 r
F P
0 g
s
.49097 .53748 m .49971 .59133 L .50718 .58002 L p .707 .577 .707 r
F P
0 g
s
.50718 .58002 m .49844 .52617 L .49097 .53748 L p .707 .577 .707 r
F P
0 g
s
.4648 .69615 m .46971 .71347 L .49435 .70038 L p .707 .577 .707 r
F P
0 g
s
.49435 .70038 m .48944 .68306 L .4648 .69615 L p .707 .577 .707 r
F P
0 g
s
.77935 .56148 m .7831 .61865 L .75207 .61979 L p .707 .577 .707 r
F P
0 g
s
.75207 .61979 m .74832 .56261 L .77935 .56148 L p .707 .577 .707 r
F P
0 g
s
.71652 .56497 m .72027 .62214 L .69081 .62549 L p .707 .577 .707 r
F P
0 g
s
.81858 .71244 m .82068 .73156 L .79437 .7345 L p .707 .577 .707 r
F P
0 g
s
.79437 .7345 m .79227 .71538 L .81858 .71244 L p .707 .577 .707 r
F P
0 g
s
.37512 .7189 m .38004 .73622 L .40962 .73231 L p .707 .577 .707 r
F P
0 g
s
.34974 .69384 m .34042 .65907 L .32092 .65459 L p .707 .577 .707 r
F P
0 g
s
.72027 .62214 m .71652 .56497 L .74832 .56261 L p .707 .577 .707 r
F P
0 g
s
.38004 .73622 m .37512 .7189 L .34977 .7185 L p .707 .577 .707 r
F P
0 g
s
.74832 .56261 m .75207 .61979 L .72027 .62214 L p .707 .577 .707 r
F P
0 g
s
.69655 .69865 m .69254 .6604 L .7221 .65707 L p .707 .577 .707 r
F P
0 g
s
.7221 .65707 m .72612 .69532 L .69655 .69865 L p .707 .577 .707 r
F P
0 g
s
.34977 .7185 m .35469 .73582 L .38004 .73622 L p .707 .577 .707 r
F P
0 g
s
.29951 .55996 m .30825 .61381 L .32025 .62181 L p .707 .577 .707 r
F P
0 g
s
.78463 .65063 m .78864 .68888 L .75785 .69196 L p .707 .577 .707 r
F P
0 g
s
.75785 .69196 m .75383 .65371 L .78463 .65063 L p .707 .577 .707 r
F P
0 g
s
.48944 .68306 m .49435 .70038 L .51202 .68649 L p .707 .577 .707 r
F P
0 g
s
.51202 .68649 m .50711 .66917 L .48944 .68306 L p .707 .577 .707 r
F P
0 g
s
.32092 .65459 m .33024 .68936 L .34974 .69384 L p .707 .577 .707 r
F P
0 g
s
.72998 .72223 m .73208 .74135 L .7022 .74459 L p .707 .577 .707 r
F P
0 g
s
.7022 .74459 m .7001 .72547 L .72998 .72223 L p .707 .577 .707 r
F P
0 g
s
.79227 .71538 m .79437 .7345 L .76384 .73788 L p .707 .577 .707 r
F P
0 g
s
.76384 .73788 m .76174 .71876 L .79227 .71538 L p .707 .577 .707 r
F P
0 g
s
.49733 .61011 m .50665 .64489 L .51469 .63181 L p .707 .577 .707 r
F P
0 g
s
.51469 .63181 m .50537 .59704 L .49733 .61011 L p .707 .577 .707 r
F P
0 g
s
.72612 .69532 m .7221 .65707 L .75383 .65371 L p .707 .577 .707 r
F P
0 g
s
.75383 .65371 m .75785 .69196 L .72612 .69532 L p .707 .577 .707 r
F P
0 g
s
.30825 .61381 m .29951 .55996 L .29713 .54981 L p .707 .578 .707 r
F P
0 g
s
.35469 .73582 m .34977 .7185 L .33111 .71382 L p .707 .577 .707 r
F P
0 g
s
.33024 .68936 m .32092 .65459 L .30982 .64634 L p .707 .577 .707 r
F P
0 g
s
.76174 .71876 m .76384 .73788 L .73208 .74135 L p .707 .577 .707 r
F P
0 g
s
.73208 .74135 m .72998 .72223 L .76174 .71876 L p .707 .577 .707 r
F P
0 g
s
.49844 .52617 m .50718 .58002 L .50481 .56987 L p .707 .578 .707 r
F P
0 g
s
.50481 .56987 m .49606 .51601 L .49844 .52617 L p .707 .578 .707 r
F P
0 g
s
.33111 .71382 m .33603 .73114 L .35469 .73582 L p .707 .577 .707 r
F P
0 g
s
.50711 .66917 m .51202 .68649 L .52099 .67315 L p .707 .577 .707 r
F P
0 g
s
.52099 .67315 m .51608 .65583 L .50711 .66917 L p .707 .577 .707 r
F P
0 g
s
.30982 .64634 m .31914 .68111 L .33024 .68936 L p .707 .577 .707 r
F P
0 g
s
.29713 .54981 m .30587 .60366 L .30825 .61381 L p .707 .578 .707 r
F P
0 g
s
.50537 .59704 m .51469 .63181 L .51309 .6206 L p .707 .577 .707 r
F P
0 g
s
.51309 .6206 m .50377 .58583 L .50537 .59704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.33603 .73114 m .33111 .71382 L .32099 .70533 L p .707 .577 .707 r
F P
0 g
s
.30587 .60366 m .29713 .54981 L .3046 .5385 L p .707 .577 .707 r
F P
0 g
s
.31914 .68111 m .30982 .64634 L .30821 .63513 L p .707 .577 .707 r
F P
0 g
s
.49606 .51601 m .50481 .56987 L .49281 .56186 L p .707 .577 .707 r
F P
0 g
s
.49281 .56186 m .48407 .50801 L .49606 .51601 L p .707 .577 .707 r
F P
0 g
s
.32099 .70533 m .3259 .72265 L .33603 .73114 L p .707 .577 .707 r
F P
0 g
s
.51608 .65583 m .52099 .67315 L .52038 .66168 L p .707 .577 .707 r
F P
0 g
s
.52038 .66168 m .51547 .64436 L .51608 .65583 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30821 .63513 m .31753 .6699 L .31914 .68111 L p .707 .577 .707 r
F P
0 g
s
.3046 .5385 m .31334 .59235 L .30587 .60366 L p .707 .577 .707 r
F P
0 g
s
.50377 .58583 m .51309 .6206 L .50199 .61235 L p .707 .577 .707 r
F P
0 g
s
.50199 .61235 m .49267 .57758 L .50377 .58583 L p .707 .577 .707 r
F P
0 g
s
.3259 .72265 m .32099 .70533 L .32038 .69386 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31334 .59235 m .3046 .5385 L .3212 .52714 L p .707 .577 .707 r
F P
0 g
s
.31753 .6699 m .30821 .63513 L .31626 .62205 L p .707 .577 .707 r
F P
0 g
s
.48407 .50801 m .49281 .56186 L .47236 .5568 L p .707 .577 .707 r
F P
0 g
s
.47236 .5568 m .46362 .50295 L .48407 .50801 L p .707 .577 .707 r
F P
0 g
s
.32038 .69386 m .3253 .71118 L .3259 .72265 L p .707 .577 .707 r
F P
0 g
s
.51547 .64436 m .52038 .66168 L .51026 .65319 L p .707 .577 .707 r
F P
0 g
s
.51026 .65319 m .50534 .63587 L .51547 .64436 L p .707 .577 .707 r
F P
0 g
s
.31626 .62205 m .32558 .65683 L .31753 .6699 L p .707 .577 .707 r
F P
0 g
s
.3212 .52714 m .32994 .58099 L .31334 .59235 L p .707 .577 .707 r
F P
0 g
s
.49267 .57758 m .50199 .61235 L .48249 .60787 L p .707 .577 .707 r
F P
0 g
s
.48249 .60787 m .47317 .5731 L .49267 .57758 L p .707 .577 .707 r
F P
0 g
s
.32994 .58099 m .3212 .52714 L .34529 .51684 L p .707 .577 .707 r
F P
0 g
s
.3253 .71118 m .32038 .69386 L .32935 .68053 L p .707 .577 .707 r
F P
0 g
s
.46362 .50295 m .47236 .5568 L .44547 .55516 L p .707 .577 .707 r
F P
0 g
s
.44547 .55516 m .43673 .50131 L .46362 .50295 L p .707 .577 .707 r
F P
0 g
s
.32558 .65683 m .31626 .62205 L .33317 .60839 L p .707 .577 .707 r
F P
0 g
s
.32935 .68053 m .33426 .69785 L .3253 .71118 L p .707 .577 .707 r
F P
0 g
s
.50534 .63587 m .51026 .65319 L .4916 .64852 L p .707 .577 .707 r
F P
0 g
s
.4916 .64852 m .48669 .6312 L .50534 .63587 L p .707 .577 .707 r
F P
0 g
s
.35403 .57069 m .34529 .51684 L .37452 .50861 L p .707 .577 .707 r
F P
0 g
s
.34529 .51684 m .35403 .57069 L .32994 .58099 L p .707 .577 .707 r
F P
0 g
s
.33317 .60839 m .34249 .64317 L .32558 .65683 L p .707 .577 .707 r
F P
0 g
s
.43673 .50131 m .44547 .55516 L .41477 .55711 L p .707 .577 .707 r
F P
0 g
s
.41477 .55711 m .40603 .50326 L .43673 .50131 L p .707 .577 .707 r
F P
0 g
s
.47317 .5731 m .48249 .60787 L .45649 .6076 L p .707 .577 .707 r
F P
0 g
s
.45649 .6076 m .44717 .57282 L .47317 .5731 L p .707 .577 .707 r
F P
0 g
s
.38326 .56246 m .37452 .50861 L .40603 .50326 L p .707 .577 .707 r
F P
0 g
s
.37452 .50861 m .38326 .56246 L .35403 .57069 L p .707 .577 .707 r
F P
0 g
s
.40603 .50326 m .41477 .55711 L .38326 .56246 L p .707 .577 .707 r
F P
0 g
s
.34249 .64317 m .33317 .60839 L .35728 .59548 L p .707 .577 .707 r
F P
0 g
s
.33426 .69785 m .32935 .68053 L .34702 .66663 L p .707 .577 .707 r
F P
0 g
s
.34702 .66663 m .35193 .68396 L .33426 .69785 L p .707 .577 .707 r
F P
0 g
s
.44717 .57282 m .45649 .6076 L .42653 .61156 L p .707 .577 .707 r
F P
0 g
s
.42653 .61156 m .41721 .57679 L .44717 .57282 L p .707 .577 .707 r
F P
0 g
s
.48669 .6312 m .4916 .64852 L .46625 .64812 L p .707 .577 .707 r
F P
0 g
s
.46625 .64812 m .46133 .6308 L .48669 .6312 L p .707 .577 .707 r
F P
0 g
s
.35728 .59548 m .3666 .63026 L .34249 .64317 L p .707 .577 .707 r
F P
0 g
s
.3666 .63026 m .35728 .59548 L .38624 .58459 L p .707 .577 .707 r
F P
0 g
s
.41721 .57679 m .42653 .61156 L .39556 .61937 L p .707 .577 .707 r
F P
0 g
s
.39556 .61937 m .38624 .58459 L .41721 .57679 L p .707 .577 .707 r
F P
0 g
s
.35193 .68396 m .34702 .66663 L .37166 .65355 L p .707 .577 .707 r
F P
0 g
s
.38624 .58459 m .39556 .61937 L .3666 .63026 L p .707 .577 .707 r
F P
0 g
s
.37166 .65355 m .37657 .67087 L .35193 .68396 L p .707 .577 .707 r
F P
0 g
s
.46133 .6308 m .46625 .64812 L .43667 .65203 L p .707 .577 .707 r
F P
0 g
s
.43667 .65203 m .43176 .63471 L .46133 .6308 L p .707 .577 .707 r
F P
0 g
s
.37657 .67087 m .37166 .65355 L .40086 .64255 L p .707 .577 .707 r
F P
0 g
s
.43176 .63471 m .43667 .65203 L .40577 .65987 L p .707 .577 .707 r
F P
0 g
s
.40577 .65987 m .40086 .64255 L .43176 .63471 L p .707 .577 .707 r
F P
0 g
s
.40086 .64255 m .40577 .65987 L .37657 .67087 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo7`00P7oo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000LGoo001/Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001^Ool006Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006aoo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JWoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Moo`00IGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP090004
FUH01000FUIJEUYF1P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00IGoo0P000UYF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00IGoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00I7oo0`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00HGoo0`001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYF001UOol005eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001KOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FWoo0P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Qo
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001GOol01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001EOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EGoo0P001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00E7oo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=J
EP04001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1UYF2@000eYF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP06FUH30006FUH00`00FUH000030002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP008Goo3`00=Goo001EOol00`00FUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP050002FUH00`00FUIJEP02FUH400000eYF001J
EP06FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0047oo4@0015YF00<005YFFUH01EYF00<005YFFUH01`00;Woo001EOol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF00002`001EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH000Qoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00=JEP@000AJEPP0
00AJEP03001JEUYF00=JEP/000EJEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol01000FUIJEP00
15YF00@005YFFUIJEPX000=JEP@000EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEP00
0080009JEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH01000
FUH000001EYF00<005YFFUH01EYF00<005YFFUH00eYF1@001UYF00<005YFFUH01EYF00@005YFFUIJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH20007FUH0
0`00FUIJEP06FUH50002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool005Eoo`05001JEUYFFUH00002FUH00`00FUH00007FUH00`00FUIJEP03
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000oOolA0005Ool01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YF
FUH00P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000iOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000eOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000cOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP<000QJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000/Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000002FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002aoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEPd000=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH60004FUH0
1000FUH000001EYF0P0000AJEP00FUH000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP<000QJ
EP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP040009FUH20002FUH4
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH0
0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3
0006FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ8000MJEP03001JEUYF00AJEPD00003FUH0000002aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH0100025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00EJEP03001JEP0000T00003FUH005YF00UJEP03001JEUYF00=JEP<000EJEP05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH015YF0`000UYF00<005YF000010000UYF00<005YFFUH01eYF3P000UYF00@005YFFUH000MJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP04000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005
FUH00`00FUH000040002FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF
001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0
035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP0000<000EJEP03001JEP0000@00003
FUH000000080009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000gOol002aoo`03001J
EP0000=JEP03001JEUYF00=JEPH000Qoo`T000AJEP03001JEUYF009JEP04001JEUYF0005FUH20002
FUH20005FUH00`00FUIJEP050007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000nOol002aoo`03001JEP00
00=JEP03001JEP0000<001Moo`H000=JEP04001JEUYF0004FUH20003FUH20005FUH01P00FUH00000
FUH000UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001oo`0M000DOol7000/Ool002]o
o`03001JEP0000AJEP80025oo`800005FUH005YFFUH00002FUH200000eYF001JEP02FUH20004FUH3
0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0003FUH20007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00:goo1`000UYF00<005YFFUH00P00;7oo000[Ool00`00
FUH00002FUH20002FUH00`00Oomoo`0POol20003FUH20003FUH00`00FUIJEP030002FUH20007FUH0
0`00FUIJEP05FUH700000eYF001JEP06FUH00`00FUIJEP060007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP006Woo4@000eYF00<005YFFUH00eYF00<005YFFUH00P00
;7oo000[Ool00`00FUH0000200000eYF001JEP02FUH20008Ool?000;Ool00`00FUIJEP020003FUH0
0`00FUIJEP060009FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH30004FUH20006FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05000=Ool90004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002]oo`03001JEP0000=JEP03
001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00@000Moo`03001JEP00009JEPT000=J
EP03001JEUYF00EJEP@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF009JEP<0
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH20003Ool8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002]oo`8000AJEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003Ool00`00FUH00004FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0
02]oo`8000AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUH00000Ool00P0000=JEP00FUH00eYF0P0025YF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01eYF00@005YF000000EJEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000500000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000[
Ool002]oo`8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP03FUH20008FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo0P000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF00000UYF0P000UYF00<005YFFUH00eYF0P001UYF00<005YFFUH01eYF00<005YFFUH0
15YF0P002EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00:goo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP04001JEUYFFUH30008FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000;FUH200001EYF001JEUYF00001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00P00:goo000[Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF0`000UYF00<005YFFUH00eYF10002EYF00<0
05YF00000P002eYF00<005YFFUH00UYF0P001eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP02FUH00`00FUIJEP02FUH50007FUH40002FUH00`00
FUIJEP07FUH20005FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1`00:goo000/Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH01000FUIJEUYF1P000UYF10001UYF00<005YFFUH01EYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHE000/
Ool002]oo`04001JEUYF0002FUH00`00FUIJEP03FUH600000eYF001JEP06FUH70006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP030006FUH01000FUIJEUYF20002UYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH8
000fOol002]oo`03001JEP0000=JEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00=J
EP@0009JEP03001JEUYF00AJEP8000=JEQ<000=JEP03001JEUYF00QJEP03001JEUYF00<000IJEP04
001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF2@000eYF2@00?Woo000[Ool00`00FUH0
0003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH50005FUH20003FUH0
1000FUH005YF10001EYF00<005YFFUH01UYF00<005YFFUH025YF0`0000=JEP00FUH01UYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH70004FUH80017Ool002]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP80009JEP07001JEUYF001JEP00
Ool00P001EYF00<005YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00H000=J
EPP004moo`00:goo00D005YF001JEP00009oo`800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP800003FUH000000080009JEP04001JEUYFFUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20006FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH04000EWoo000ZOol00`00FUIJEP020005
Ool20007FUH:0008FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEUYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02000UOol6000[Ool002Yoo`04001JEUYF0007Ool200000eYF000000040003FUH00`00FUIJEP02
FUH70002FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000=JEP<000EJEP03001JEUYF
00IJEPD00003FUH005YF00QJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00=JEP04001JEUYFFUH2000NOol70002
FUH01000FUIJEP00:goo000ZOol01000FUH000001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF001JEP80009JEP<000EJEP03001JEUYF00L0
00IJEP03001JEUYF00AJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF0P005Woo20000eYF00<005YFFUH0
0eYF00@005YFFUH002]oo`00:Woo0`0000=JEP00Ool00Woo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0`000eYF00<005YF00000`0000=JEP00FUH00UYF3@0015YF00<005YF
FUH01UYF00<005YFFUH00UYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH20003FUH01000FUIJEUYF0P001Woo400015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:Woo000ZOol3000015YF001oogoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH200000eYF001JEP02
FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol0
02Yoo`8000=JEP800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF008000Eoo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH0
05YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF008000IJEP`000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF008002Yoo`00:Woo0P000UYF00@005YFFUH000EJEPH000Uoo`H000IJEP03001J
EUYF00=JEP8000Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF00`000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00H002]oo`00:Woo0P0000=JEP00FUH00UYF00<005YF00000`005Goo10000UYF00<0
05YFFUH01EYF0P001Goo0P0000=JEP00FUH01UYF00<005YFFUH00UYF1P002EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
3P00<Goo000[Ool30003FUH4000KOol40007FUH20006Ool>0004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000nOol0
02]oo`80009JEP8000AJEP8001eoo`8000AJEP03001JEUYF0080009oo`H000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF009J
EPX004Moo`00:goo10001UYF00@005YF000001eoo`<00003FUH005YF00=JEP80009JEP@000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF009JEP04001JEUYFFUH:001?Ool0
02Yoo`05001JEP00FUH00006FUH01000FUIJEUYF0`007Goo0P001EYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH00eYF30001eYF00<005YFFUH00eYF30001EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02000Egoo000ZOol01@00FUH005YF00001UYF
00<005YFFUH015YF0`006Woo0`0015YF0P0000=JEP0000000P001EYF00<005YFFUH01EYF1`001eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00UYF1`001eYF00<005YFFUH00eYF00<005YF
FUH01`00Ggoo000ZOol200000goo00000006FUH00`00FUIJEP05FUH00`00FUH00003000AOol50003
FUH200000eYF001JEP02000015YF000000001EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF100015YF00<005YFFUH00eYF00@005YF
FUH000=JEP<005moo`00:Woo0P000Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF
4@000eYF00<005YFFUH015YF0P000UYF0P0000=oo`0000001EYF00<005YF00000P001EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<00003FUH0
05YF00AJEP04001JEUYF0002FUH01000FUIJEUYF0P00GGoo000ZOol00`00Oomoo`02Ool20003FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH01000Ool000001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP8005]o
o`00:Woo00<007ooOol017oo00@005YFFUH000QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000Ool000000eYF0P0000=JEP00FUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0P000eYF00@005YFFUH0009JEP03001JEUYF00AJEP<005Uoo`00:Woo0P001Woo0`001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUIJEP00FUH007oo
0P0000=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0002FUH00`00FUH00006FUH01@00
FUIJEUYF0000F7oo000ZOol00`00FUH00007Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001oo`030005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YF00001UYF00D005YFFUIJEP0005Qoo`00:Woo00<005YF
00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000Woo0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH0
0006FUH00`00FUIJEP02001HOol002Yoo`04001JEUYF000:Ool300000eYF001JEP06FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool01@00Ool005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00D005YFFUIJEP0005Uoo`00:Woo00D005YF
FUIJEP0000aoo`<000IJEP03001JEUYF00D0009JEP03001JEUYF00EJEP04001JEUYFFUH20007Ool0
1@00Ool005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000IJEP05001JEUYF
FUH0001IOol002]oo`03001JEUYF008000ioo`@0009JEP04001JEUYFFUH30002FUH00`00FUIJEP06
FUH01000FUH0000027oo0P0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF008005Uoo`00:goo00<005YF00000UYF0P0047oo1`0015YF00<005YFFUH00UYF1P00
2Woo0P000Woo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH0
0P00FGoo000/Ool20004FUH00`00Oomoo`0DOol9000?Ool00`00FUH00002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00Oomoo`1HOol002eo
o`03001JEUYF00=JEP8002aoo`03001JEP0000=oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30005FUH01000FUH000000eYF00<007ooOol0F7oo000^Ool00`00FUIJEP02FUH01000FUH0
0000:7oo10001Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP04001J
EUYFFUH4001JOol002moo`800003FUH005YF00=JEP<002=oo`800003FUH0000000Qoo`800003FUH0
05YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP@00003FUH005YF00EJEP03001JEUYF009JEP<005Yoo`00<Goo0P001eYF0`007Woo0P00
0eYF0P002Woo10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF00H005YFFUIJEP00FUH20006FUH00`00FUIJEP02FUH2001KOol0039oo`03
001JEUYF00IJEP03001JEP0000<001Ioo`@00003FUH005YF009JEP03001oogoo00eoo`@0009JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF008000IJ
EP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUH0001KOol003=oo`8000IJEP03001JEUYF
00=JEPL000Uoo`H000EJEP04001JEUYF000DOol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60006FUH00`00FUIJEP04FUH:001LOol003Eoo`8000=JEP03001JEUYF00IJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP04001JEP00000JOol60003FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP060006Ool40002FUH00`00FUIJEP05FUH3001ROol003Moo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80029ooal00003FUH0
0000008000]oo`@000IJEP03001JEUYF0080061oo`00>Goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00=Woo0P0015YF00<005YFFUH01UYF00<005YF00000P0037oo0P00
0eYF00<005YFFUH00eYF0P00GWoo000mOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000jOol200000eYF001JEP08FUH00`00FUIJEP02FUH3000;Ool200000eYF001JEP05FUH3
001LOol0045oo`L000AJEP03001JEUYF009JEPD0041oo`<000MJEP03001JEUYF00IJEPD000Qoo`80
00EJEP05001JEUYFFUH0001KOol004Qoo`T004Qoo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH8
0002Ool20003FUH01@00FUIJEUYF0000Fgoo002LOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF0P00Fgoo002OOol30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<007ooOol0FWoo002ROol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF1000G7oo002VOol70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000G7oo
002]Ool80003FUH00`00FUIJEP02FUH00`00FUH0001MOol00;Eoo`/005eoo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58523 .7426 m .59397 .6868 L .56327 .68063 L p .707 .577 .707 r
F P
0 g
s
.59397 .6868 m .58523 .7426 L .61673 .74683 L p .707 .577 .707 r
F P
0 g
s
.61673 .74683 m .62547 .69103 L .59397 .6868 L p .707 .577 .707 r
F P
0 g
s
.62547 .69103 m .61673 .74683 L .64596 .74871 L p .707 .577 .707 r
F P
0 g
s
.64596 .74871 m .65471 .69291 L .62547 .69103 L p .707 .577 .707 r
F P
0 g
s
.55452 .73644 m .56327 .68063 L .53638 .67314 L p .707 .577 .707 r
F P
0 g
s
.56327 .68063 m .55452 .73644 L .58523 .7426 L p .707 .577 .707 r
F P
0 g
s
.65471 .69291 m .64596 .74871 L .67006 .74806 L p .707 .577 .707 r
F P
0 g
s
.67006 .74806 m .6788 .69225 L .65471 .69291 L p .707 .577 .707 r
F P
0 g
s
.57346 .79883 m .58278 .76206 L .55283 .75327 L p .707 .577 .707 r
F P
0 g
s
.58278 .76206 m .57346 .79883 L .60444 .80617 L p .707 .577 .707 r
F P
0 g
s
.60444 .80617 m .61376 .7694 L .58278 .76206 L p .707 .577 .707 r
F P
0 g
s
.53638 .67314 m .52764 .72894 L .55452 .73644 L p .707 .577 .707 r
F P
0 g
s
.61376 .7694 m .60444 .80617 L .6334 .81134 L p .707 .577 .707 r
F P
0 g
s
.6334 .81134 m .64272 .77457 L .61376 .7694 L p .707 .577 .707 r
F P
0 g
s
.52764 .72894 m .53638 .67314 L .51593 .66504 L p .707 .577 .707 r
F P
0 g
s
.55283 .75327 m .54351 .79004 L .57346 .79883 L p .707 .577 .707 r
F P
0 g
s
.54351 .79004 m .55283 .75327 L .52683 .74389 L p .707 .577 .707 r
F P
0 g
s
.56333 .84066 m .56824 .82233 L .53867 .81305 L p .707 .577 .707 r
F P
0 g
s
.56824 .82233 m .56333 .84066 L .59422 .8486 L p .707 .577 .707 r
F P
0 g
s
.59422 .8486 m .59914 .83028 L .56824 .82233 L p .707 .577 .707 r
F P
0 g
s
.52683 .74389 m .51751 .78066 L .54351 .79004 L p .707 .577 .707 r
F P
0 g
s
.59914 .83028 m .59422 .8486 L .62342 .85442 L p .707 .577 .707 r
F P
0 g
s
.62342 .85442 m .62834 .8361 L .59914 .83028 L p .707 .577 .707 r
F P
0 g
s
.53867 .81305 m .53375 .83137 L .56333 .84066 L p .707 .577 .707 r
F P
0 g
s
.64272 .77457 m .6334 .81134 L .65751 .81383 L p .707 .577 .707 r
F P
0 g
s
.65751 .81383 m .66683 .77706 L .64272 .77457 L p .707 .577 .707 r
F P
0 g
s
.51593 .66504 m .50719 .72085 L .52764 .72894 L p .707 .577 .707 r
F P
0 g
s
.6788 .69225 m .67006 .74806 L .68665 .74494 L p .707 .577 .707 r
F P
0 g
s
.68665 .74494 m .69539 .68913 L .6788 .69225 L p .707 .577 .707 r
F P
0 g
s
.53375 .83137 m .53867 .81305 L .51331 .80333 L p .707 .577 .707 r
F P
0 g
s
.51751 .78066 m .52683 .74389 L .50733 .73484 L p .707 .577 .707 r
F P
0 g
s
.51331 .80333 m .5084 .82165 L .53375 .83137 L p .707 .577 .707 r
F P
0 g
s
.62834 .8361 m .62342 .85442 L .64806 .85756 L p .707 .577 .707 r
F P
0 g
s
.64806 .85756 m .65298 .83924 L .62834 .8361 L p .707 .577 .707 r
F P
0 g
s
.50719 .72085 m .51593 .66504 L .50393 .65714 L p .707 .577 .707 r
F P
0 g
s
.50733 .73484 m .49801 .77161 L .51751 .78066 L p .707 .577 .707 r
F P
0 g
s
.66683 .77706 m .65751 .81383 L .67442 .81341 L p .707 .577 .707 r
F P
0 g
s
.67442 .81341 m .68374 .77664 L .66683 .77706 L p .707 .577 .707 r
F P
0 g
s
.5084 .82165 m .51331 .80333 L .49466 .79413 L p .707 .577 .707 r
F P
0 g
s
.50393 .65714 m .49519 .71295 L .50719 .72085 L p .707 .577 .707 r
F P
0 g
s
.49466 .79413 m .48974 .81245 L .5084 .82165 L p .707 .577 .707 r
F P
0 g
s
.65298 .83924 m .64806 .85756 L .66573 .8577 L p .707 .577 .707 r
F P
0 g
s
.66573 .8577 m .67065 .83937 L .65298 .83924 L p .707 .577 .707 r
F P
0 g
s
.49801 .77161 m .50733 .73484 L .49623 .727 L p .707 .577 .707 r
F P
0 g
s
.69539 .68913 m .68665 .74494 L .69413 .73965 L p .707 .577 .707 r
F P
0 g
s
.69413 .73965 m .70287 .68384 L .69539 .68913 L p .707 .577 .707 r
F P
0 g
s
.49623 .727 m .48691 .76377 L .49801 .77161 L p .707 .577 .707 r
F P
0 g
s
.49519 .71295 m .50393 .65714 L .50155 .65021 L p .707 .577 .707 r
F P
0 g
s
.48974 .81245 m .49466 .79413 L .48453 .78635 L p .707 .577 .707 r
F P
0 g
s
.68374 .77664 m .67442 .81341 L .68246 .81011 L p .707 .577 .707 r
F P
0 g
s
.68246 .81011 m .69178 .77334 L .68374 .77664 L p .707 .577 .707 r
F P
0 g
s
.48453 .78635 m .47961 .80467 L .48974 .81245 L p .707 .577 .707 r
F P
0 g
s
.50155 .65021 m .49281 .70602 L .49519 .71295 L p .707 .577 .707 r
F P
0 g
s
.67065 .83937 m .66573 .8577 L .6747 .85483 L p .707 .577 .707 r
F P
0 g
s
.6747 .85483 m .67962 .8365 L .67065 .83937 L p .707 .577 .707 r
F P
0 g
s
.48691 .76377 m .49623 .727 L .49462 .72115 L p .707 .577 .707 r
F P
0 g
s
.70287 .68384 m .69413 .73965 L .69175 .73272 L p .707 .577 .707 r
F P
0 g
s
.69175 .73272 m .70049 .67691 L .70287 .68384 L p .707 .577 .707 r
F P
0 g
s
.49462 .72115 m .4853 .75792 L .48691 .76377 L p .707 .577 .707 r
F P
0 g
s
.49281 .70602 m .50155 .65021 L .50903 .64493 L p .707 .577 .707 r
F P
0 g
s
.50903 .64493 m .50029 .70073 L .49281 .70602 L p .707 .577 .707 r
F P
0 g
s
.4853 .75792 m .49462 .72115 L .50267 .71784 L p .707 .577 .707 r
F P
0 g
s
.50267 .71784 m .49335 .75461 L .4853 .75792 L p .707 .577 .707 r
F P
0 g
s
.50029 .70073 m .50903 .64493 L .52562 .6418 L p .707 .577 .707 r
F P
0 g
s
.52562 .6418 m .51688 .69761 L .50029 .70073 L p .707 .577 .707 r
F P
0 g
s
.49335 .75461 m .50267 .71784 L .51958 .71742 L p .707 .577 .707 r
F P
0 g
s
.51958 .71742 m .51025 .75419 L .49335 .75461 L p .707 .577 .707 r
F P
0 g
s
.48797 .7962 m .49289 .77788 L .51056 .77801 L p .707 .577 .707 r
F P
0 g
s
.51056 .77801 m .50564 .79634 L .48797 .7962 L p .707 .577 .707 r
F P
0 g
s
.50283 .82192 m .50283 .32003 L .45812 .31837 L p .707 .577 .707 r
F P
0 g
s
.51688 .69761 m .52562 .6418 L .54972 .64115 L p .707 .577 .707 r
F P
0 g
s
.54972 .64115 m .54098 .69696 L .51688 .69761 L p .707 .577 .707 r
F P
0 g
s
.51025 .75419 m .51958 .71742 L .54369 .71991 L p .707 .577 .707 r
F P
0 g
s
.54369 .71991 m .53437 .75668 L .51025 .75419 L p .707 .577 .707 r
F P
0 g
s
.50564 .79634 m .51056 .77801 L .5352 .78115 L p .707 .577 .707 r
F P
0 g
s
.5352 .78115 m .53028 .79947 L .50564 .79634 L p .707 .577 .707 r
F P
0 g
s
.53437 .75668 m .54369 .71991 L .57265 .72508 L p .707 .577 .707 r
F P
0 g
s
.57265 .72508 m .56333 .76185 L .53437 .75668 L p .707 .577 .707 r
F P
0 g
s
.53028 .79947 m .5352 .78115 L .5644 .78697 L p .707 .577 .707 r
F P
0 g
s
.5644 .78697 m .55948 .8053 L .53028 .79947 L p .707 .577 .707 r
F P
0 g
s
.50283 .32003 m .50283 .82192 L .54725 .81979 L p .707 .577 .707 r
F P
0 g
s
.54098 .69696 m .54972 .64115 L .57895 .64303 L p .707 .577 .707 r
F P
0 g
s
.57895 .64303 m .57021 .69884 L .54098 .69696 L p .707 .577 .707 r
F P
0 g
s
.54725 .81979 m .54725 .3179 L .50283 .32003 L p .707 .577 .707 r
F P
0 g
s
.47961 .80467 m .48453 .78635 L .48392 .78075 L p .707 .577 .707 r
F P
0 g
s
.45812 .82026 m .45812 .31837 L .41752 .31308 L p .707 .577 .707 r
F P
0 g
s
.48392 .78075 m .47901 .79907 L .47961 .80467 L p .707 .577 .707 r
F P
0 g
s
.47901 .79907 m .48392 .78075 L .49289 .77788 L p .707 .577 .707 r
F P
0 g
s
.49289 .77788 m .48797 .7962 L .47901 .79907 L p .707 .577 .707 r
F P
0 g
s
.45812 .31837 m .45812 .82026 L .50283 .82192 L p .707 .577 .707 r
F P
0 g
s
.57021 .69884 m .57895 .64303 L .61046 .64726 L p .707 .577 .707 r
F P
0 g
s
.61046 .64726 m .60171 .70307 L .57021 .69884 L p .707 .577 .707 r
F P
0 g
s
.56333 .76185 m .57265 .72508 L .60362 .73242 L p .707 .577 .707 r
F P
0 g
s
.60362 .73242 m .5943 .76919 L .56333 .76185 L p .707 .577 .707 r
F P
0 g
s
.55948 .8053 m .5644 .78697 L .5953 .79492 L p .707 .577 .707 r
F P
0 g
s
.5953 .79492 m .59038 .81324 L .55948 .8053 L p .707 .577 .707 r
F P
0 g
s
.54725 .3179 m .54725 .81979 L .58706 .81408 L p .707 .577 .707 r
F P
0 g
s
.58706 .81408 m .58706 .31219 L .54725 .3179 L p .707 .577 .707 r
F P
0 g
s
.69178 .77334 m .68246 .81011 L .68086 .80425 L p .707 .577 .707 r
F P
0 g
s
.68086 .80425 m .69018 .76748 L .69178 .77334 L p .707 .577 .707 r
F P
0 g
s
.67962 .8365 m .6747 .85483 L .67409 .84923 L p .707 .577 .707 r
F P
0 g
s
.67409 .84923 m .67901 .8309 L .67962 .8365 L p .707 .577 .707 r
F P
0 g
s
.70049 .67691 m .69175 .73272 L .67975 .72482 L p .707 .577 .707 r
F P
0 g
s
.67975 .72482 m .68849 .66901 L .70049 .67691 L p .707 .577 .707 r
F P
0 g
s
.41752 .81497 m .41752 .31308 L .38499 .30469 L p .707 .577 .707 r
F P
0 g
s
.41752 .31308 m .41752 .81497 L .45812 .82026 L p .707 .577 .707 r
F P
0 g
s
.64116 .65342 m .63242 .70923 L .60171 .70307 L p .707 .577 .707 r
F P
0 g
s
.60171 .70307 m .61046 .64726 L .64116 .65342 L p .707 .577 .707 r
F P
0 g
s
.63358 .74121 m .62426 .77798 L .5943 .76919 L p .707 .577 .707 r
F P
0 g
s
.5943 .76919 m .60362 .73242 L .63358 .74121 L p .707 .577 .707 r
F P
0 g
s
.59038 .81324 m .5953 .79492 L .62487 .8042 L p .707 .577 .707 r
F P
0 g
s
.58706 .31219 m .58706 .81408 L .61834 .80535 L p .707 .577 .707 r
F P
0 g
s
.61834 .80535 m .61834 .30346 L .58706 .31219 L p .707 .577 .707 r
F P
0 g
s
.24793 .72399 m .25168 .67155 L .22065 .66664 L p .707 .577 .707 r
F P
0 g
s
.25168 .67155 m .24793 .72399 L .27972 .72483 L p .707 .577 .707 r
F P
0 g
s
.27972 .72483 m .28348 .67239 L .25168 .67155 L p .707 .577 .707 r
F P
0 g
s
.69018 .76748 m .68086 .80425 L .66976 .79641 L p .707 .577 .707 r
F P
0 g
s
.66976 .79641 m .67908 .75964 L .69018 .76748 L p .707 .577 .707 r
F P
0 g
s
.28348 .67239 m .27972 .72483 L .30919 .72152 L p .707 .577 .707 r
F P
0 g
s
.30919 .72152 m .31294 .66908 L .28348 .67239 L p .707 .577 .707 r
F P
0 g
s
.2169 .71907 m .22065 .66664 L .19344 .65813 L p .707 .577 .707 r
F P
0 g
s
.22065 .66664 m .2169 .71907 L .24793 .72399 L p .707 .577 .707 r
F P
0 g
s
.67901 .8309 m .67409 .84923 L .66397 .84144 L p .707 .577 .707 r
F P
0 g
s
.66397 .84144 m .66888 .82312 L .67901 .8309 L p .707 .577 .707 r
F P
0 g
s
.68849 .66901 m .67975 .72482 L .65931 .71673 L p .707 .577 .707 r
F P
0 g
s
.65931 .71673 m .66805 .66092 L .68849 .66901 L p .707 .577 .707 r
F P
0 g
s
.31294 .66908 m .30919 .72152 L .33343 .71437 L p .707 .577 .707 r
F P
0 g
s
.33343 .71437 m .33718 .66194 L .31294 .66908 L p .707 .577 .707 r
F P
0 g
s
.38499 .80658 m .38499 .30469 L .36371 .29401 L p .707 .577 .707 r
F P
0 g
s
.38499 .30469 m .38499 .80658 L .41752 .81497 L p .707 .577 .707 r
F P
0 g
s
.18969 .71057 m .19344 .65813 L .17271 .64687 L p .707 .577 .707 r
F P
0 g
s
.19344 .65813 m .18969 .71057 L .2169 .71907 L p .707 .577 .707 r
F P
0 g
s
.66805 .66092 m .65931 .71673 L .63242 .70923 L p .707 .577 .707 r
F P
0 g
s
.63242 .70923 m .64116 .65342 L .66805 .66092 L p .707 .577 .707 r
F P
0 g
s
.65958 .75059 m .65026 .78736 L .62426 .77798 L p .707 .577 .707 r
F P
0 g
s
.62426 .77798 m .63358 .74121 L .65958 .75059 L p .707 .577 .707 r
F P
0 g
s
.61834 .30346 m .61834 .80535 L .63803 .79445 L p .707 .577 .707 r
F P
0 g
s
.63803 .79445 m .63803 .29257 L .61834 .30346 L p .707 .577 .707 r
F P
0 g
s
.67908 .75964 m .66976 .79641 L .65026 .78736 L p .707 .577 .707 r
F P
0 g
s
.65026 .78736 m .65958 .75059 L .67908 .75964 L p .707 .577 .707 r
F P
0 g
s
.33718 .66194 m .33343 .71437 L .35007 .7041 L p .707 .577 .707 r
F P
0 g
s
.35007 .7041 m .35383 .65166 L .33718 .66194 L p .707 .577 .707 r
F P
0 g
s
.24215 .7899 m .24617 .75678 L .21537 .75001 L p .707 .577 .707 r
F P
0 g
s
.24617 .75678 m .24215 .7899 L .27388 .79178 L p .707 .577 .707 r
F P
0 g
s
.27388 .79178 m .2779 .75866 L .24617 .75678 L p .707 .577 .707 r
F P
0 g
s
.2779 .75866 m .27388 .79178 L .30345 .78858 L p .707 .577 .707 r
F P
0 g
s
.30345 .78858 m .30746 .75546 L .2779 .75866 L p .707 .577 .707 r
F P
0 g
s
.21136 .78313 m .21537 .75001 L .18853 .73899 L p .707 .577 .707 r
F P
0 g
s
.21537 .75001 m .21136 .78313 L .24215 .7899 L p .707 .577 .707 r
F P
0 g
s
.66888 .82312 m .66397 .84144 L .64531 .83224 L p .707 .577 .707 r
F P
0 g
s
.64531 .83224 m .65023 .81392 L .66888 .82312 L p .707 .577 .707 r
F P
0 g
s
.16896 .69931 m .17271 .64687 L .16048 .63395 L p .707 .577 .707 r
F P
0 g
s
.17271 .64687 m .16896 .69931 L .18969 .71057 L p .707 .577 .707 r
F P
0 g
s
.30746 .75546 m .30345 .78858 L .32795 .78061 L p .707 .577 .707 r
F P
0 g
s
.32795 .78061 m .33196 .74749 L .30746 .75546 L p .707 .577 .707 r
F P
0 g
s
.18452 .77211 m .18853 .73899 L .16827 .72483 L p .707 .577 .707 r
F P
0 g
s
.18853 .73899 m .18452 .77211 L .21136 .78313 L p .707 .577 .707 r
F P
0 g
s
.36371 .7959 m .36371 .29401 L .35578 .28209 L p .707 .577 .707 r
F P
0 g
s
.36371 .29401 m .36371 .7959 L .38499 .80658 L p .707 .577 .707 r
F P
0 g
s
.35383 .65166 m .35007 .7041 L .3575 .69171 L p .707 .577 .707 r
F P
0 g
s
.3575 .69171 m .36125 .63927 L .35383 .65166 L p .707 .577 .707 r
F P
0 g
s
.63803 .29257 m .63803 .79445 L .64422 .78246 L p .707 .577 .707 r
F P
0 g
s
.64422 .78246 m .64422 .28057 L .63803 .29257 L p .707 .577 .707 r
F P
0 g
s
.23616 .83161 m .23826 .81528 L .20773 .80781 L p .707 .577 .707 r
F P
0 g
s
.23826 .81528 m .23616 .83161 L .26792 .83404 L p .707 .577 .707 r
F P
0 g
s
.26792 .83404 m .27002 .8177 L .23826 .81528 L p .707 .577 .707 r
F P
0 g
s
.16048 .63395 m .15673 .68639 L .16896 .69931 L p .707 .577 .707 r
F P
0 g
s
.65023 .81392 m .64531 .83224 L .61996 .82253 L p .707 .577 .707 r
F P
0 g
s
.61996 .82253 m .62487 .8042 L .65023 .81392 L p .707 .577 .707 r
F P
0 g
s
.27002 .8177 m .26792 .83404 L .2978 .83118 L p .707 .577 .707 r
F P
0 g
s
.2978 .83118 m .2999 .81485 L .27002 .8177 L p .707 .577 .707 r
F P
0 g
s
.15673 .68639 m .16048 .63395 L .15795 .62065 L p .707 .577 .707 r
F P
0 g
s
.33196 .74749 m .32795 .78061 L .34498 .76865 L p .707 .577 .707 r
F P
0 g
s
.34498 .76865 m .349 .73553 L .33196 .74749 L p .707 .577 .707 r
F P
0 g
s
.20563 .82415 m .20773 .80781 L .18142 .79603 L p .707 .577 .707 r
F P
0 g
s
.20773 .80781 m .20563 .82415 L .23616 .83161 L p .707 .577 .707 r
F P
0 g
s
.16827 .72483 m .16426 .75795 L .18452 .77211 L p .707 .577 .707 r
F P
0 g
s
.16426 .75795 m .16827 .72483 L .15657 .70889 L p .707 .577 .707 r
F P
0 g
s
.2999 .81485 m .2978 .83118 L .32288 .82333 L p .707 .577 .707 r
F P
0 g
s
.32288 .82333 m .32498 .80699 L .2999 .81485 L p .707 .577 .707 r
F P
0 g
s
.18142 .79603 m .17932 .81237 L .20563 .82415 L p .707 .577 .707 r
F P
0 g
s
.62487 .8042 m .61996 .82253 L .59038 .81324 L p .707 .577 .707 r
F P
0 g
s
.17932 .81237 m .18142 .79603 L .1619 .78109 L p .707 .577 .707 r
F P
0 g
s
.36125 .63927 m .3575 .69171 L .35497 .6784 L p .707 .577 .707 r
F P
0 g
s
.35497 .6784 m .35872 .62596 L .36125 .63927 L p .707 .577 .707 r
F P
0 g
s
.15795 .62065 m .1542 .67308 L .15673 .68639 L p .707 .577 .707 r
F P
0 g
s
.15657 .70889 m .15256 .74201 L .16426 .75795 L p .707 .577 .707 r
F P
0 g
s
.349 .73553 m .34498 .76865 L .3529 .75387 L p .707 .577 .707 r
F P
0 g
s
.3529 .75387 m .35691 .72075 L .349 .73553 L p .707 .577 .707 r
F P
0 g
s
.1619 .78109 m .15981 .79743 L .17932 .81237 L p .707 .577 .707 r
F P
0 g
s
.32498 .80699 m .32288 .82333 L .3407 .81124 L p .707 .577 .707 r
F P
0 g
s
.3407 .81124 m .3428 .7949 L .32498 .80699 L p .707 .577 .707 r
F P
0 g
s
.1542 .67308 m .15795 .62065 L .16537 .60825 L p .707 .577 .707 r
F P
0 g
s
.15256 .74201 m .15657 .70889 L .15458 .69274 L p .707 .577 .707 r
F P
0 g
s
.35872 .62596 m .35497 .6784 L .34274 .66548 L p .707 .577 .707 r
F P
0 g
s
.34274 .66548 m .34649 .61304 L .35872 .62596 L p .707 .577 .707 r
F P
0 g
s
.35691 .72075 m .3529 .75387 L .35091 .73773 L p .707 .577 .707 r
F P
0 g
s
.35091 .73773 m .35492 .70461 L .35691 .72075 L p .707 .577 .707 r
F P
0 g
s
.35578 .28209 m .35578 .78398 L .36371 .7959 L p .707 .577 .707 r
F P
0 g
s
.35578 .78398 m .35578 .28209 L .36197 .27009 L p .707 .577 .707 r
F P
0 g
s
.15981 .79743 m .1619 .78109 L .15109 .76446 L p .707 .577 .707 r
F P
0 g
s
.64422 .28057 m .64422 .78246 L .63628 .77054 L p .707 .577 .707 r
F P
0 g
s
.63628 .77054 m .63628 .26865 L .64422 .28057 L p .707 .577 .707 r
F P
0 g
s
.15109 .76446 m .149 .78079 L .15981 .79743 L p .707 .577 .707 r
F P
0 g
s
.15458 .69274 m .15057 .72586 L .15256 .74201 L p .707 .577 .707 r
F P
0 g
s
.3428 .7949 m .3407 .81124 L .34952 .7961 L p .707 .577 .707 r
F P
0 g
s
.34952 .7961 m .35161 .77977 L .3428 .7949 L p .707 .577 .707 r
F P
0 g
s
.16537 .60825 m .16162 .66069 L .1542 .67308 L p .707 .577 .707 r
F P
0 g
s
.16162 .66069 m .16537 .60825 L .18202 .59798 L p .707 .577 .707 r
F P
0 g
s
.15057 .72586 m .15458 .69274 L .16249 .67796 L p .707 .577 .707 r
F P
0 g
s
.149 .78079 m .15109 .76446 L .15004 .74776 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15004 .74776 m .14795 .76409 L .149 .78079 L p .707 .577 .707 r
F P
0 g
s
.36197 .77198 m .36197 .27009 L .38166 .2592 L p .707 .577 .707 r
F P
0 g
s
.36197 .27009 m .36197 .77198 L .35578 .78398 L p .707 .577 .707 r
F P
0 g
s
.34649 .61304 m .34274 .66548 L .322 .65422 L p .707 .577 .707 r
F P
0 g
s
.322 .65422 m .32576 .60178 L .34649 .61304 L p .707 .577 .707 r
F P
0 g
s
.16249 .67796 m .15848 .71108 L .15057 .72586 L p .707 .577 .707 r
F P
0 g
s
.35161 .77977 m .34952 .7961 L .34847 .7794 L p .707 .577 .707 r
F P
0 g
s
.34847 .7794 m .35057 .76306 L .35161 .77977 L p .707 .577 .707 r
F P
0 g
s
.63628 .26865 m .63628 .77054 L .61501 .75986 L p .707 .577 .707 r
F P
0 g
s
.61501 .75986 m .61501 .25797 L .63628 .26865 L p .707 .577 .707 r
F P
0 g
s
.35492 .70461 m .35091 .73773 L .33921 .72179 L p .707 .577 .707 r
F P
0 g
s
.33921 .72179 m .34322 .68867 L .35492 .70461 L p .707 .577 .707 r
F P
0 g
s
.18202 .59798 m .17827 .65042 L .16162 .66069 L p .707 .577 .707 r
F P
0 g
s
.17827 .65042 m .18202 .59798 L .20626 .59084 L p .707 .577 .707 r
F P
0 g
s
.15848 .71108 m .16249 .67796 L .17953 .66601 L p .707 .577 .707 r
F P
0 g
s
.14795 .76409 m .15004 .74776 L .15886 .73262 L p .707 .577 .707 r
F P
0 g
s
.32576 .60178 m .322 .65422 L .29479 .64572 L p .707 .577 .707 r
F P
0 g
s
.29479 .64572 m .29855 .59328 L .32576 .60178 L p .707 .577 .707 r
F P
0 g
s
.15886 .73262 m .15677 .74895 L .14795 .76409 L p .707 .577 .707 r
F P
0 g
s
.20251 .64327 m .20626 .59084 L .23572 .58752 L p .707 .577 .707 r
F P
0 g
s
.20626 .59084 m .20251 .64327 L .17827 .65042 L p .707 .577 .707 r
F P
0 g
s
.17953 .66601 m .17552 .69913 L .15848 .71108 L p .707 .577 .707 r
F P
0 g
s
.34322 .68867 m .33921 .72179 L .31895 .70762 L p .707 .577 .707 r
F P
0 g
s
.31895 .70762 m .32296 .6745 L .34322 .68867 L p .707 .577 .707 r
F P
0 g
s
.35057 .76306 m .34847 .7794 L .33766 .76276 L p .707 .577 .707 r
F P
0 g
s
.33766 .76276 m .33976 .74643 L .35057 .76306 L p .707 .577 .707 r
F P
0 g
s
.17552 .69913 m .17953 .66601 L .20403 .65803 L p .707 .577 .707 r
F P
0 g
s
.29855 .59328 m .29479 .64572 L .26377 .6408 L p .707 .577 .707 r
F P
0 g
s
.26377 .6408 m .26752 .58836 L .29855 .59328 L p .707 .577 .707 r
F P
0 g
s
.38166 .76109 m .38166 .2592 L .41294 .25047 L p .707 .577 .707 r
F P
0 g
s
.38166 .2592 m .38166 .76109 L .36197 .77198 L p .707 .577 .707 r
F P
0 g
s
.23197 .63996 m .23572 .58752 L .26752 .58836 L p .707 .577 .707 r
F P
0 g
s
.23572 .58752 m .23197 .63996 L .20251 .64327 L p .707 .577 .707 r
F P
0 g
s
.15677 .74895 m .15886 .73262 L .17668 .72053 L p .707 .577 .707 r
F P
0 g
s
.61501 .25797 m .61501 .75986 L .58248 .75147 L p .707 .577 .707 r
F P
0 g
s
.58248 .75147 m .58248 .24958 L .61501 .25797 L p .707 .577 .707 r
F P
0 g
s
.26752 .58836 m .26377 .6408 L .23197 .63996 L p .707 .577 .707 r
F P
0 g
s
.73623 .64473 m .73248 .58755 L .70145 .58868 L p .707 .577 .707 r
F P
0 g
s
.73248 .58755 m .73623 .64473 L .76803 .64237 L p .707 .577 .707 r
F P
0 g
s
.76803 .64237 m .76428 .58519 L .73248 .58755 L p .707 .577 .707 r
F P
0 g
s
.76428 .58519 m .76803 .64237 L .79749 .63903 L p .707 .577 .707 r
F P
0 g
s
.79749 .63903 m .79374 .58185 L .76428 .58519 L p .707 .577 .707 r
F P
0 g
s
.17668 .72053 m .17459 .73686 L .15677 .74895 L p .707 .577 .707 r
F P
0 g
s
.32296 .6745 m .31895 .70762 L .2921 .69661 L p .707 .577 .707 r
F P
0 g
s
.2921 .69661 m .29612 .66349 L .32296 .6745 L p .707 .577 .707 r
F P
0 g
s
.70145 .58868 m .7052 .64586 L .73623 .64473 L p .707 .577 .707 r
F P
0 g
s
.7052 .64586 m .70145 .58868 L .67424 .58849 L p .707 .577 .707 r
F P
0 g
s
.20002 .69115 m .20403 .65803 L .23359 .65483 L p .707 .577 .707 r
F P
0 g
s
.20403 .65803 m .20002 .69115 L .17552 .69913 L p .707 .577 .707 r
F P
0 g
s
.33976 .74643 m .33766 .76276 L .31815 .74782 L p .707 .577 .707 r
F P
0 g
s
.31815 .74782 m .32024 .73149 L .33976 .74643 L p .707 .577 .707 r
F P
0 g
s
.73869 .69787 m .73467 .65962 L .70388 .6627 L p .707 .577 .707 r
F P
0 g
s
.73467 .65962 m .73869 .69787 L .77042 .6945 L p .707 .577 .707 r
F P
0 g
s
.77042 .6945 m .7664 .65626 L .73467 .65962 L p .707 .577 .707 r
F P
0 g
s
.70388 .6627 m .70789 .70095 L .73869 .69787 L p .707 .577 .707 r
F P
0 g
s
.79374 .58185 m .79749 .63903 L .82173 .63502 L p .707 .577 .707 r
F P
0 g
s
.82173 .63502 m .81798 .57784 L .79374 .58185 L p .707 .577 .707 r
F P
0 g
s
.67424 .58849 m .67799 .64566 L .7052 .64586 L p .707 .577 .707 r
F P
0 g
s
.7664 .65626 m .77042 .6945 L .79998 .69118 L p .707 .577 .707 r
F P
0 g
s
.79998 .69118 m .79597 .65293 L .7664 .65626 L p .707 .577 .707 r
F P
0 g
s
.17459 .73686 m .17668 .72053 L .20176 .71267 L p .707 .577 .707 r
F P
0 g
s
.29612 .66349 m .2921 .69661 L .26131 .68983 L p .707 .577 .707 r
F P
0 g
s
.26131 .68983 m .26532 .65671 L .29612 .66349 L p .707 .577 .707 r
F P
0 g
s
.70607 .72423 m .70816 .74335 L .73869 .73997 L p .707 .577 .707 r
F P
0 g
s
.73869 .73997 m .73659 .72086 L .70607 .72423 L p .707 .577 .707 r
F P
0 g
s
.73659 .72086 m .73869 .73997 L .77045 .7365 L p .707 .577 .707 r
F P
0 g
s
.77045 .7365 m .76835 .71738 L .73659 .72086 L p .707 .577 .707 r
F P
0 g
s
.76835 .71738 m .77045 .7365 L .80033 .73326 L p .707 .577 .707 r
F P
0 g
s
.22958 .68795 m .23359 .65483 L .26532 .65671 L p .707 .577 .707 r
F P
0 g
s
.23359 .65483 m .22958 .68795 L .20002 .69115 L p .707 .577 .707 r
F P
0 g
s
.80033 .73326 m .79824 .71414 L .76835 .71738 L p .707 .577 .707 r
F P
0 g
s
.70789 .70095 m .70388 .6627 L .67704 .66518 L p .707 .577 .707 r
F P
0 g
s
.67704 .66518 m .68105 .70343 L .70789 .70095 L p .707 .577 .707 r
F P
0 g
s
.26532 .65671 m .26131 .68983 L .22958 .68795 L p .707 .577 .707 r
F P
0 g
s
.41294 .25047 m .41294 .75236 L .38166 .76109 L p .707 .577 .707 r
F P
0 g
s
.41294 .75236 m .41294 .25047 L .45274 .24476 L p .707 .577 .707 r
F P
0 g
s
.67799 .64566 m .67424 .58849 L .65351 .58698 L p .707 .577 .707 r
F P
0 g
s
.79597 .65293 m .79998 .69118 L .82448 .68822 L p .707 .577 .707 r
F P
0 g
s
.82448 .68822 m .82047 .64997 L .79597 .65293 L p .707 .577 .707 r
F P
0 g
s
.58248 .24958 m .58248 .75147 L .54188 .74618 L p .707 .577 .707 r
F P
0 g
s
.54188 .74618 m .54188 .24429 L .58248 .24958 L p .707 .577 .707 r
F P
0 g
s
.67976 .72717 m .68185 .74629 L .70816 .74335 L p .707 .577 .707 r
F P
0 g
s
.70816 .74335 m .70607 .72423 L .67976 .72717 L p .707 .577 .707 r
F P
0 g
s
.20176 .71267 m .19967 .72901 L .17459 .73686 L p .707 .577 .707 r
F P
0 g
s
.32024 .73149 m .31815 .74782 L .29184 .73604 L p .707 .577 .707 r
F P
0 g
s
.29184 .73604 m .29393 .71971 L .32024 .73149 L p .707 .577 .707 r
F P
0 g
s
.79824 .71414 m .80033 .73326 L .82541 .73058 L p .707 .577 .707 r
F P
0 g
s
.82541 .73058 m .82331 .71146 L .79824 .71414 L p .707 .577 .707 r
F P
0 g
s
.65351 .58698 m .65726 .64415 L .67799 .64566 L p .707 .577 .707 r
F P
0 g
s
.81798 .57784 m .82173 .63502 L .83838 .63074 L p .707 .577 .707 r
F P
0 g
s
.83838 .63074 m .83462 .57356 L .81798 .57784 L p .707 .577 .707 r
F P
0 g
s
.19967 .72901 m .20176 .71267 L .23164 .70982 L p .707 .577 .707 r
F P
0 g
s
.68105 .70343 m .67704 .66518 L .65678 .66683 L p .707 .577 .707 r
F P
0 g
s
.65678 .66683 m .66079 .70508 L .68105 .70343 L p .707 .577 .707 r
F P
0 g
s
.29393 .71971 m .29184 .73604 L .26131 .72858 L p .707 .577 .707 r
F P
0 g
s
.26131 .72858 m .2634 .71224 L .29393 .71971 L p .707 .577 .707 r
F P
0 g
s
.45274 .74665 m .45274 .24476 L .49717 .24263 L p .707 .577 .707 r
F P
0 g
s
.45274 .24476 m .45274 .74665 L .41294 .75236 L p .707 .577 .707 r
F P
0 g
s
.66024 .72939 m .66234 .74851 L .68185 .74629 L p .707 .577 .707 r
F P
0 g
s
.68185 .74629 m .67976 .72717 L .66024 .72939 L p .707 .577 .707 r
F P
0 g
s
.23164 .70982 m .22955 .72615 L .19967 .72901 L p .707 .577 .707 r
F P
0 g
s
.54188 .24429 m .54188 .74618 L .49717 .74452 L p .707 .577 .707 r
F P
0 g
s
.49717 .74452 m .49717 .24263 L .54188 .24429 L p .707 .577 .707 r
F P
0 g
s
.82047 .64997 m .82448 .68822 L .84152 .68591 L p .707 .577 .707 r
F P
0 g
s
.84152 .68591 m .83751 .64767 L .82047 .64997 L p .707 .577 .707 r
F P
0 g
s
.22955 .72615 m .23164 .70982 L .2634 .71224 L p .707 .577 .707 r
F P
0 g
s
.65726 .64415 m .65351 .58698 L .64128 .5843 L p .707 .577 .707 r
F P
0 g
s
.2634 .71224 m .26131 .72858 L .22955 .72615 L p .707 .577 .707 r
F P
0 g
s
.82331 .71146 m .82541 .73058 L .84323 .72871 L p .707 .577 .707 r
F P
0 g
s
.84323 .72871 m .84114 .70959 L .82331 .71146 L p .707 .577 .707 r
F P
0 g
s
.49717 .24263 m .49717 .74452 L .45274 .74665 L p .707 .577 .707 r
F P
0 g
s
.64128 .5843 m .64503 .64148 L .65726 .64415 L p .707 .577 .707 r
F P
0 g
s
.83462 .57356 m .83838 .63074 L .8458 .62661 L p .707 .577 .707 r
F P
0 g
s
.8458 .62661 m .84205 .56943 L .83462 .57356 L p .707 .577 .707 r
F P
0 g
s
.66079 .70508 m .65678 .66683 L .64508 .66749 L p .707 .577 .707 r
F P
0 g
s
.64508 .66749 m .64909 .70574 L .66079 .70508 L p .707 .577 .707 r
F P
0 g
s
.64943 .73067 m .65153 .74979 L .66234 .74851 L p .707 .577 .707 r
F P
0 g
s
.66234 .74851 m .66024 .72939 L .64943 .73067 L p .707 .577 .707 r
F P
0 g
s
.83751 .64767 m .84152 .68591 L .84943 .68449 L p .707 .577 .707 r
F P
0 g
s
.84943 .68449 m .84542 .64624 L .83751 .64767 L p .707 .577 .707 r
F P
0 g
s
.84114 .70959 m .84323 .72871 L .85205 .72784 L p .707 .577 .707 r
F P
0 g
s
.85205 .72784 m .84995 .70873 L .84114 .70959 L p .707 .577 .707 r
F P
0 g
s
.64503 .64148 m .64128 .5843 L .63875 .58073 L p .707 .577 .707 r
F P
0 g
s
.63875 .58073 m .6425 .6379 L .64503 .64148 L p .707 .577 .707 r
F P
0 g
s
.84205 .56943 m .8458 .62661 L .84327 .62303 L p .707 .577 .707 r
F P
0 g
s
.84327 .62303 m .83952 .56586 L .84205 .56943 L p .707 .577 .707 r
F P
0 g
s
.64909 .70574 m .64508 .66749 L .64309 .66709 L p .707 .577 .707 r
F P
0 g
s
.64309 .66709 m .6471 .70534 L .64909 .70574 L p .707 .577 .707 r
F P
0 g
s
.64838 .73089 m .65048 .75001 L .65153 .74979 L p .707 .577 .707 r
F P
0 g
s
.65153 .74979 m .64943 .73067 L .64838 .73089 L p .707 .577 .707 r
F P
0 g
s
.84542 .64624 m .84943 .68449 L .84744 .68409 L p .707 .577 .707 r
F P
0 g
s
.84744 .68409 m .84343 .64584 L .84542 .64624 L p .707 .577 .707 r
F P
0 g
s
.84995 .70873 m .85205 .72784 L .851 .72806 L p .707 .577 .707 r
F P
0 g
s
.851 .72806 m .84891 .70894 L .84995 .70873 L p .707 .577 .707 r
F P
0 g
s
.6425 .6379 m .63875 .58073 L .64617 .5766 L p .707 .577 .707 r
F P
0 g
s
.64617 .5766 m .64992 .63377 L .6425 .6379 L p .707 .577 .707 r
F P
0 g
s
.83952 .56586 m .84327 .62303 L .83104 .62036 L p .707 .577 .707 r
F P
0 g
s
.83104 .62036 m .82729 .56318 L .83952 .56586 L p .707 .577 .707 r
F P
0 g
s
.6471 .70534 m .64309 .66709 L .651 .66566 L p .707 .577 .707 r
F P
0 g
s
.651 .66566 m .65501 .70391 L .6471 .70534 L p .707 .577 .707 r
F P
0 g
s
.6572 .73002 m .6593 .74914 L .65048 .75001 L p .707 .577 .707 r
F P
0 g
s
.65048 .75001 m .64838 .73089 L .6572 .73002 L p .707 .577 .707 r
F P
0 g
s
.84343 .64584 m .84744 .68409 L .83574 .68474 L p .707 .577 .707 r
F P
0 g
s
.83574 .68474 m .83173 .6465 L .84343 .64584 L p .707 .577 .707 r
F P
0 g
s
.39828 .62657 m .38954 .57271 L .35884 .57467 L p .707 .577 .707 r
F P
0 g
s
.38954 .57271 m .39828 .62657 L .42979 .62121 L p .707 .577 .707 r
F P
0 g
s
.42979 .62121 m .42105 .56736 L .38954 .57271 L p .707 .577 .707 r
F P
0 g
s
.42105 .56736 m .42979 .62121 L .45902 .61299 L p .707 .577 .707 r
F P
0 g
s
.45902 .61299 m .45028 .55913 L .42105 .56736 L p .707 .577 .707 r
F P
0 g
s
.84891 .70894 m .851 .72806 L .84019 .72934 L p .707 .577 .707 r
F P
0 g
s
.84019 .72934 m .8381 .71022 L .84891 .70894 L p .707 .577 .707 r
F P
0 g
s
.64992 .63377 m .64617 .5766 L .66282 .57232 L p .707 .577 .707 r
F P
0 g
s
.36758 .62852 m .35884 .57467 L .33195 .57303 L p .707 .577 .707 r
F P
0 g
s
.35884 .57467 m .36758 .62852 L .39828 .62657 L p .707 .577 .707 r
F P
0 g
s
.66282 .57232 m .66657 .6295 L .64992 .63377 L p .707 .577 .707 r
F P
0 g
s
.45028 .55913 m .45902 .61299 L .48311 .60269 L p .707 .577 .707 r
F P
0 g
s
.48311 .60269 m .47437 .54884 L .45028 .55913 L p .707 .577 .707 r
F P
0 g
s
.82729 .56318 m .83104 .62036 L .81031 .61885 L p .707 .577 .707 r
F P
0 g
s
.81031 .61885 m .80656 .56167 L .82729 .56318 L p .707 .577 .707 r
F P
0 g
s
.65501 .70391 m .651 .66566 L .66804 .66336 L p .707 .577 .707 r
F P
0 g
s
.66804 .66336 m .67205 .70161 L .65501 .70391 L p .707 .577 .707 r
F P
0 g
s
.67502 .72815 m .67712 .74727 L .6593 .74914 L p .707 .577 .707 r
F P
0 g
s
.6593 .74914 m .6572 .73002 L .67502 .72815 L p .707 .577 .707 r
F P
0 g
s
.34069 .62688 m .33195 .57303 L .31151 .56796 L p .707 .577 .707 r
F P
0 g
s
.33195 .57303 m .34069 .62688 L .36758 .62852 L p .707 .577 .707 r
F P
0 g
s
.43667 .68235 m .42735 .64757 L .39637 .65538 L p .707 .577 .707 r
F P
0 g
s
.42735 .64757 m .43667 .68235 L .46563 .67146 L p .707 .577 .707 r
F P
0 g
s
.46563 .67146 m .45631 .63668 L .42735 .64757 L p .707 .577 .707 r
F P
0 g
s
.40569 .69015 m .39637 .65538 L .36642 .65934 L p .707 .577 .707 r
F P
0 g
s
.39637 .65538 m .40569 .69015 L .43667 .68235 L p .707 .577 .707 r
F P
0 g
s
.83173 .6465 m .83574 .68474 L .81548 .6864 L p .707 .577 .707 r
F P
0 g
s
.81548 .6864 m .81147 .64815 L .83173 .6465 L p .707 .577 .707 r
F P
0 g
s
.47437 .54884 m .48311 .60269 L .49971 .59133 L p .707 .577 .707 r
F P
0 g
s
.49971 .59133 m .49097 .53748 L .47437 .54884 L p .707 .577 .707 r
F P
0 g
s
.66657 .6295 m .66282 .57232 L .68706 .56831 L p .707 .577 .707 r
F P
0 g
s
.8381 .71022 m .84019 .72934 L .82068 .73156 L p .707 .577 .707 r
F P
0 g
s
.82068 .73156 m .81858 .71244 L .8381 .71022 L p .707 .577 .707 r
F P
0 g
s
.45631 .63668 m .46563 .67146 L .48974 .65855 L p .707 .577 .707 r
F P
0 g
s
.48974 .65855 m .48042 .62377 L .45631 .63668 L p .707 .577 .707 r
F P
0 g
s
.68706 .56831 m .69081 .62549 L .66657 .6295 L p .707 .577 .707 r
F P
0 g
s
.37574 .69412 m .36642 .65934 L .34042 .65907 L p .707 .577 .707 r
F P
0 g
s
.36642 .65934 m .37574 .69412 L .40569 .69015 L p .707 .577 .707 r
F P
0 g
s
.80656 .56167 m .81031 .61885 L .7831 .61865 L p .707 .577 .707 r
F P
0 g
s
.7831 .61865 m .77935 .56148 L .80656 .56167 L p .707 .577 .707 r
F P
0 g
s
.67205 .70161 m .66804 .66336 L .69254 .6604 L p .707 .577 .707 r
F P
0 g
s
.69254 .6604 m .69655 .69865 L .67205 .70161 L p .707 .577 .707 r
F P
0 g
s
.31151 .56796 m .32025 .62181 L .34069 .62688 L p .707 .577 .707 r
F P
0 g
s
.44051 .72447 m .4356 .70715 L .4047 .71499 L p .707 .577 .707 r
F P
0 g
s
.4356 .70715 m .44051 .72447 L .46971 .71347 L p .707 .577 .707 r
F P
0 g
s
.46971 .71347 m .4648 .69615 L .4356 .70715 L p .707 .577 .707 r
F P
0 g
s
.69081 .62549 m .68706 .56831 L .71652 .56497 L p .707 .577 .707 r
F P
0 g
s
.32025 .62181 m .31151 .56796 L .29951 .55996 L p .707 .577 .707 r
F P
0 g
s
.40962 .73231 m .4047 .71499 L .37512 .7189 L p .707 .577 .707 r
F P
0 g
s
.4047 .71499 m .40962 .73231 L .44051 .72447 L p .707 .577 .707 r
F P
0 g
s
.48042 .62377 m .48974 .65855 L .50665 .64489 L p .707 .577 .707 r
F P
0 g
s
.50665 .64489 m .49733 .61011 L .48042 .62377 L p .707 .577 .707 r
F P
0 g
s
.7001 .72547 m .7022 .74459 L .67712 .74727 L p .707 .577 .707 r
F P
0 g
s
.67712 .74727 m .67502 .72815 L .7001 .72547 L p .707 .577 .707 r
F P
0 g
s
.34042 .65907 m .34974 .69384 L .37574 .69412 L p .707 .577 .707 r
F P
0 g
s
.81147 .64815 m .81548 .6864 L .78864 .68888 L p .707 .577 .707 r
F P
0 g
s
.78864 .68888 m .78463 .65063 L .81147 .64815 L p .707 .577 .707 r
F P
0 g
s
.49097 .53748 m .49971 .59133 L .50718 .58002 L p .707 .577 .707 r
F P
0 g
s
.50718 .58002 m .49844 .52617 L .49097 .53748 L p .707 .577 .707 r
F P
0 g
s
.4648 .69615 m .46971 .71347 L .49435 .70038 L p .707 .577 .707 r
F P
0 g
s
.49435 .70038 m .48944 .68306 L .4648 .69615 L p .707 .577 .707 r
F P
0 g
s
.77935 .56148 m .7831 .61865 L .75207 .61979 L p .707 .577 .707 r
F P
0 g
s
.75207 .61979 m .74832 .56261 L .77935 .56148 L p .707 .577 .707 r
F P
0 g
s
.71652 .56497 m .72027 .62214 L .69081 .62549 L p .707 .577 .707 r
F P
0 g
s
.81858 .71244 m .82068 .73156 L .79437 .7345 L p .707 .577 .707 r
F P
0 g
s
.79437 .7345 m .79227 .71538 L .81858 .71244 L p .707 .577 .707 r
F P
0 g
s
.37512 .7189 m .38004 .73622 L .40962 .73231 L p .707 .577 .707 r
F P
0 g
s
.34974 .69384 m .34042 .65907 L .32092 .65459 L p .707 .577 .707 r
F P
0 g
s
.72027 .62214 m .71652 .56497 L .74832 .56261 L p .707 .577 .707 r
F P
0 g
s
.38004 .73622 m .37512 .7189 L .34977 .7185 L p .707 .577 .707 r
F P
0 g
s
.74832 .56261 m .75207 .61979 L .72027 .62214 L p .707 .577 .707 r
F P
0 g
s
.69655 .69865 m .69254 .6604 L .7221 .65707 L p .707 .577 .707 r
F P
0 g
s
.7221 .65707 m .72612 .69532 L .69655 .69865 L p .707 .577 .707 r
F P
0 g
s
.34977 .7185 m .35469 .73582 L .38004 .73622 L p .707 .577 .707 r
F P
0 g
s
.29951 .55996 m .30825 .61381 L .32025 .62181 L p .707 .577 .707 r
F P
0 g
s
.78463 .65063 m .78864 .68888 L .75785 .69196 L p .707 .577 .707 r
F P
0 g
s
.75785 .69196 m .75383 .65371 L .78463 .65063 L p .707 .577 .707 r
F P
0 g
s
.48944 .68306 m .49435 .70038 L .51202 .68649 L p .707 .577 .707 r
F P
0 g
s
.51202 .68649 m .50711 .66917 L .48944 .68306 L p .707 .577 .707 r
F P
0 g
s
.32092 .65459 m .33024 .68936 L .34974 .69384 L p .707 .577 .707 r
F P
0 g
s
.72998 .72223 m .73208 .74135 L .7022 .74459 L p .707 .577 .707 r
F P
0 g
s
.7022 .74459 m .7001 .72547 L .72998 .72223 L p .707 .577 .707 r
F P
0 g
s
.79227 .71538 m .79437 .7345 L .76384 .73788 L p .707 .577 .707 r
F P
0 g
s
.76384 .73788 m .76174 .71876 L .79227 .71538 L p .707 .577 .707 r
F P
0 g
s
.49733 .61011 m .50665 .64489 L .51469 .63181 L p .707 .577 .707 r
F P
0 g
s
.51469 .63181 m .50537 .59704 L .49733 .61011 L p .707 .577 .707 r
F P
0 g
s
.72612 .69532 m .7221 .65707 L .75383 .65371 L p .707 .577 .707 r
F P
0 g
s
.75383 .65371 m .75785 .69196 L .72612 .69532 L p .707 .577 .707 r
F P
0 g
s
.30825 .61381 m .29951 .55996 L .29713 .54981 L p .707 .578 .707 r
F P
0 g
s
.35469 .73582 m .34977 .7185 L .33111 .71382 L p .707 .577 .707 r
F P
0 g
s
.33024 .68936 m .32092 .65459 L .30982 .64634 L p .707 .577 .707 r
F P
0 g
s
.76174 .71876 m .76384 .73788 L .73208 .74135 L p .707 .577 .707 r
F P
0 g
s
.73208 .74135 m .72998 .72223 L .76174 .71876 L p .707 .577 .707 r
F P
0 g
s
.49844 .52617 m .50718 .58002 L .50481 .56987 L p .707 .578 .707 r
F P
0 g
s
.50481 .56987 m .49606 .51601 L .49844 .52617 L p .707 .578 .707 r
F P
0 g
s
.33111 .71382 m .33603 .73114 L .35469 .73582 L p .707 .577 .707 r
F P
0 g
s
.50711 .66917 m .51202 .68649 L .52099 .67315 L p .707 .577 .707 r
F P
0 g
s
.52099 .67315 m .51608 .65583 L .50711 .66917 L p .707 .577 .707 r
F P
0 g
s
.30982 .64634 m .31914 .68111 L .33024 .68936 L p .707 .577 .707 r
F P
0 g
s
.29713 .54981 m .30587 .60366 L .30825 .61381 L p .707 .578 .707 r
F P
0 g
s
.50537 .59704 m .51469 .63181 L .51309 .6206 L p .707 .577 .707 r
F P
0 g
s
.51309 .6206 m .50377 .58583 L .50537 .59704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.33603 .73114 m .33111 .71382 L .32099 .70533 L p .707 .577 .707 r
F P
0 g
s
.30587 .60366 m .29713 .54981 L .3046 .5385 L p .707 .577 .707 r
F P
0 g
s
.31914 .68111 m .30982 .64634 L .30821 .63513 L p .707 .577 .707 r
F P
0 g
s
.49606 .51601 m .50481 .56987 L .49281 .56186 L p .707 .577 .707 r
F P
0 g
s
.49281 .56186 m .48407 .50801 L .49606 .51601 L p .707 .577 .707 r
F P
0 g
s
.32099 .70533 m .3259 .72265 L .33603 .73114 L p .707 .577 .707 r
F P
0 g
s
.51608 .65583 m .52099 .67315 L .52038 .66168 L p .707 .577 .707 r
F P
0 g
s
.52038 .66168 m .51547 .64436 L .51608 .65583 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30821 .63513 m .31753 .6699 L .31914 .68111 L p .707 .577 .707 r
F P
0 g
s
.3046 .5385 m .31334 .59235 L .30587 .60366 L p .707 .577 .707 r
F P
0 g
s
.50377 .58583 m .51309 .6206 L .50199 .61235 L p .707 .577 .707 r
F P
0 g
s
.50199 .61235 m .49267 .57758 L .50377 .58583 L p .707 .577 .707 r
F P
0 g
s
.3259 .72265 m .32099 .70533 L .32038 .69386 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31334 .59235 m .3046 .5385 L .3212 .52714 L p .707 .577 .707 r
F P
0 g
s
.31753 .6699 m .30821 .63513 L .31626 .62205 L p .707 .577 .707 r
F P
0 g
s
.48407 .50801 m .49281 .56186 L .47236 .5568 L p .707 .577 .707 r
F P
0 g
s
.47236 .5568 m .46362 .50295 L .48407 .50801 L p .707 .577 .707 r
F P
0 g
s
.32038 .69386 m .3253 .71118 L .3259 .72265 L p .707 .577 .707 r
F P
0 g
s
.51547 .64436 m .52038 .66168 L .51026 .65319 L p .707 .577 .707 r
F P
0 g
s
.51026 .65319 m .50534 .63587 L .51547 .64436 L p .707 .577 .707 r
F P
0 g
s
.31626 .62205 m .32558 .65683 L .31753 .6699 L p .707 .577 .707 r
F P
0 g
s
.3212 .52714 m .32994 .58099 L .31334 .59235 L p .707 .577 .707 r
F P
0 g
s
.49267 .57758 m .50199 .61235 L .48249 .60787 L p .707 .577 .707 r
F P
0 g
s
.48249 .60787 m .47317 .5731 L .49267 .57758 L p .707 .577 .707 r
F P
0 g
s
.32994 .58099 m .3212 .52714 L .34529 .51684 L p .707 .577 .707 r
F P
0 g
s
.3253 .71118 m .32038 .69386 L .32935 .68053 L p .707 .577 .707 r
F P
0 g
s
.46362 .50295 m .47236 .5568 L .44547 .55516 L p .707 .577 .707 r
F P
0 g
s
.44547 .55516 m .43673 .50131 L .46362 .50295 L p .707 .577 .707 r
F P
0 g
s
.32558 .65683 m .31626 .62205 L .33317 .60839 L p .707 .577 .707 r
F P
0 g
s
.32935 .68053 m .33426 .69785 L .3253 .71118 L p .707 .577 .707 r
F P
0 g
s
.50534 .63587 m .51026 .65319 L .4916 .64852 L p .707 .577 .707 r
F P
0 g
s
.4916 .64852 m .48669 .6312 L .50534 .63587 L p .707 .577 .707 r
F P
0 g
s
.35403 .57069 m .34529 .51684 L .37452 .50861 L p .707 .577 .707 r
F P
0 g
s
.34529 .51684 m .35403 .57069 L .32994 .58099 L p .707 .577 .707 r
F P
0 g
s
.33317 .60839 m .34249 .64317 L .32558 .65683 L p .707 .577 .707 r
F P
0 g
s
.43673 .50131 m .44547 .55516 L .41477 .55711 L p .707 .577 .707 r
F P
0 g
s
.41477 .55711 m .40603 .50326 L .43673 .50131 L p .707 .577 .707 r
F P
0 g
s
.47317 .5731 m .48249 .60787 L .45649 .6076 L p .707 .577 .707 r
F P
0 g
s
.45649 .6076 m .44717 .57282 L .47317 .5731 L p .707 .577 .707 r
F P
0 g
s
.38326 .56246 m .37452 .50861 L .40603 .50326 L p .707 .577 .707 r
F P
0 g
s
.37452 .50861 m .38326 .56246 L .35403 .57069 L p .707 .577 .707 r
F P
0 g
s
.40603 .50326 m .41477 .55711 L .38326 .56246 L p .707 .577 .707 r
F P
0 g
s
.34249 .64317 m .33317 .60839 L .35728 .59548 L p .707 .577 .707 r
F P
0 g
s
.33426 .69785 m .32935 .68053 L .34702 .66663 L p .707 .577 .707 r
F P
0 g
s
.34702 .66663 m .35193 .68396 L .33426 .69785 L p .707 .577 .707 r
F P
0 g
s
.44717 .57282 m .45649 .6076 L .42653 .61156 L p .707 .577 .707 r
F P
0 g
s
.42653 .61156 m .41721 .57679 L .44717 .57282 L p .707 .577 .707 r
F P
0 g
s
.48669 .6312 m .4916 .64852 L .46625 .64812 L p .707 .577 .707 r
F P
0 g
s
.46625 .64812 m .46133 .6308 L .48669 .6312 L p .707 .577 .707 r
F P
0 g
s
.35728 .59548 m .3666 .63026 L .34249 .64317 L p .707 .577 .707 r
F P
0 g
s
.3666 .63026 m .35728 .59548 L .38624 .58459 L p .707 .577 .707 r
F P
0 g
s
.41721 .57679 m .42653 .61156 L .39556 .61937 L p .707 .577 .707 r
F P
0 g
s
.39556 .61937 m .38624 .58459 L .41721 .57679 L p .707 .577 .707 r
F P
0 g
s
.35193 .68396 m .34702 .66663 L .37166 .65355 L p .707 .577 .707 r
F P
0 g
s
.38624 .58459 m .39556 .61937 L .3666 .63026 L p .707 .577 .707 r
F P
0 g
s
.37166 .65355 m .37657 .67087 L .35193 .68396 L p .707 .577 .707 r
F P
0 g
s
.46133 .6308 m .46625 .64812 L .43667 .65203 L p .707 .577 .707 r
F P
0 g
s
.43667 .65203 m .43176 .63471 L .46133 .6308 L p .707 .577 .707 r
F P
0 g
s
.37657 .67087 m .37166 .65355 L .40086 .64255 L p .707 .577 .707 r
F P
0 g
s
.43176 .63471 m .43667 .65203 L .40577 .65987 L p .707 .577 .707 r
F P
0 g
s
.40577 .65987 m .40086 .64255 L .43176 .63471 L p .707 .577 .707 r
F P
0 g
s
.40086 .64255 m .40577 .65987 L .37657 .67087 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo7`00P7oo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000LGoo001/Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001^Ool006Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006aoo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JWoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Moo`00IGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP090004
FUH01000FUIJEUYF1P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00IGoo0P000UYF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00IGoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00I7oo0`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00HGoo0`001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYF001UOol005eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001KOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FWoo0P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Qo
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001GOol01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001EOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EGoo0P001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00E7oo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=J
EP04001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1UYF2@000eYF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP06FUH30006FUH00`00FUH000030002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP008Goo3`00=Goo001EOol00`00FUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP050002FUH00`00FUIJEP02FUH400000eYF001J
EP06FUH00`00FUIJEP02FUH200000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0047oo4@0015YF00<005YFFUH01EYF00<005YFFUH01`00;Woo001EOol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YF00000P000eYF00<005YF00002`001EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH000Qoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00=JEP@000AJEPP0
00AJEP03001JEUYF00=JEP/000EJEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol01000FUIJEP00
15YF00@005YFFUIJEPX000=JEP@000EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEP00
0080009JEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH01000
FUH000001EYF00<005YFFUH01EYF00<005YFFUH00eYF1@001UYF00<005YFFUH01EYF00@005YFFUIJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH20007FUH0
0`00FUIJEP06FUH50002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool005Eoo`05001JEUYFFUH00002FUH00`00FUH00007FUH00`00FUIJEP03
FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000oOolA0005Ool01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YF
FUH00P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000iOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000eOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000cOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP<000QJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000/Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEP000002FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002aoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEPd000=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH60004FUH0
1000FUH000001EYF0P0000AJEP00FUH000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP<000QJ
EP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP040009FUH20002FUH4
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`000eYF00<005YFFUH0
0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3
0006FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ8000MJEP03001JEUYF00AJEPD00003FUH0000002aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH0100025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00EJEP03001JEP0000T00003FUH005YF00UJEP03001JEUYF00=JEP<000EJEP05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH015YF0`000UYF00<005YF000010000UYF00<005YFFUH01eYF3P000UYF00@005YFFUH000MJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP04000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005
FUH00`00FUH000040002FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF
001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0
035oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP0000<000EJEP03001JEP0000@00003
FUH000000080009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000gOol002aoo`03001J
EP0000=JEP03001JEUYF00=JEPH000Qoo`T000AJEP03001JEUYF009JEP04001JEUYF0005FUH20002
FUH20005FUH00`00FUIJEP050007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000nOol002aoo`03001JEP00
00=JEP03001JEP0000<001Moo`H000=JEP04001JEUYF0004FUH20003FUH20005FUH01P00FUH00000
FUH000UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001oo`0M000DOol7000/Ool002]o
o`03001JEP0000AJEP80025oo`800005FUH005YFFUH00002FUH200000eYF001JEP02FUH20004FUH3
0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0003FUH20007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00:goo1`000UYF00<005YFFUH00P00;7oo000[Ool00`00
FUH00002FUH20002FUH00`00Oomoo`0POol20003FUH20003FUH00`00FUIJEP030002FUH20007FUH0
0`00FUIJEP05FUH700000eYF001JEP06FUH00`00FUIJEP060007FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP006Woo4@000eYF00<005YFFUH00eYF00<005YFFUH00P00
;7oo000[Ool00`00FUH0000200000eYF001JEP02FUH20008Ool?000;Ool00`00FUIJEP020003FUH0
0`00FUIJEP060009FUH00`00FUIJEP050008FUH00`00FUIJEP05FUH30004FUH20006FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05000=Ool90004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002]oo`03001JEP0000=JEP03
001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00@000Moo`03001JEP00009JEPT000=J
EP03001JEUYF00EJEP@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF009JEP<0
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH20003Ool8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002]oo`8000AJEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003Ool00`00FUH00004FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0
02]oo`8000AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUH00000Ool00P0000=JEP00FUH00eYF0P0025YF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01eYF00@005YF000000EJEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000500000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000[
Ool002]oo`8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP03FUH20008FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo0P000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF00000UYF0P000UYF00<005YFFUH00eYF0P001UYF00<005YFFUH01eYF00<005YFFUH0
15YF0P002EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00:goo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP04001JEUYFFUH30008FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000;FUH200001EYF001JEUYF00001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00P00:goo000[Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF0`000UYF00<005YFFUH00eYF10002EYF00<0
05YF00000P002eYF00<005YFFUH00UYF0P001eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP02FUH00`00FUIJEP02FUH50007FUH40002FUH00`00
FUIJEP07FUH20005FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1`00:goo000/Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH01000FUIJEUYF1P000UYF10001UYF00<005YFFUH01EYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHE000/
Ool002]oo`04001JEUYF0002FUH00`00FUIJEP03FUH600000eYF001JEP06FUH70006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP030006FUH01000FUIJEUYF20002UYF00<005YFFUH00eYF0P000eYF
00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH8
000fOol002]oo`03001JEP0000=JEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00=J
EP@0009JEP03001JEUYF00AJEP8000=JEQ<000=JEP03001JEUYF00QJEP03001JEUYF00<000IJEP04
001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF2@000eYF2@00?Woo000[Ool00`00FUH0
0003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH50005FUH20003FUH0
1000FUH005YF10001EYF00<005YFFUH01UYF00<005YFFUH025YF0`0000=JEP00FUH01UYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH70004FUH80017Ool002]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP80009JEP07001JEUYF001JEP00
Ool00P001EYF00<005YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00H000=J
EPP004moo`00:goo00D005YF001JEP00009oo`800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP800003FUH000000080009JEP04001JEUYFFUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20006FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH04000EWoo000ZOol00`00FUIJEP020005
Ool20007FUH:0008FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEUYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02000UOol6000[Ool002Yoo`04001JEUYF0007Ool200000eYF000000040003FUH00`00FUIJEP02
FUH70002FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000AJEP00000000=JEP<000EJEP03001JEUYF
00IJEPD00003FUH005YF00QJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00=JEP04001JEUYFFUH2000NOol70002
FUH01000FUIJEP00:goo000ZOol01000FUH000001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF001JEP80009JEP<000EJEP03001JEUYF00L0
00IJEP03001JEUYF00AJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF0P005Woo20000eYF00<005YFFUH0
0eYF00@005YFFUH002]oo`00:Woo0`0000=JEP00Ool00Woo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0`000eYF00<005YF00000`0000=JEP00FUH00UYF3@0015YF00<005YF
FUH01UYF00<005YFFUH00UYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH20003FUH01000FUIJEUYF0P001Woo400015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:Woo000ZOol3000015YF001oogoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000<FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH200000eYF001JEP02
FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol0
02Yoo`8000=JEP800003FUH005YF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF008000Eoo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH0
05YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF008000IJEP`000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF008002Yoo`00:Woo0P000UYF00@005YFFUH000EJEPH000Uoo`H000IJEP03001J
EUYF00=JEP8000Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF00`000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00H002]oo`00:Woo0P0000=JEP00FUH00UYF00<005YF00000`005Goo10000UYF00<0
05YFFUH01EYF0P001Goo0P0000=JEP00FUH01UYF00<005YFFUH00UYF1P002EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
3P00<Goo000[Ool30003FUH4000KOol40007FUH20006Ool>0004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:000nOol0
02]oo`80009JEP8000AJEP8001eoo`8000AJEP03001JEUYF0080009oo`H000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF009J
EPX004Moo`00:goo10001UYF00@005YF000001eoo`<00003FUH005YF00=JEP80009JEP@000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF009JEP04001JEUYFFUH:001?Ool0
02Yoo`05001JEP00FUH00006FUH01000FUIJEUYF0`007Goo0P001EYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH00eYF30001eYF00<005YFFUH00eYF30001EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02000Egoo000ZOol01@00FUH005YF00001UYF
00<005YFFUH015YF0`006Woo0`0015YF0P0000=JEP0000000P001EYF00<005YFFUH01EYF1`001eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00UYF1`001eYF00<005YFFUH00eYF00<005YF
FUH01`00Ggoo000ZOol200000goo00000006FUH00`00FUIJEP05FUH00`00FUH00003000AOol50003
FUH200000eYF001JEP02000015YF000000001EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF100015YF00<005YFFUH00eYF00@005YF
FUH000=JEP<005moo`00:Woo0P000Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF
4@000eYF00<005YFFUH015YF0P000UYF0P0000=oo`0000001EYF00<005YF00000P001EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<00003FUH0
05YF00AJEP04001JEUYF0002FUH01000FUIJEUYF0P00GGoo000ZOol00`00Oomoo`02Ool20003FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH01000Ool000001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP8005]o
o`00:Woo00<007ooOol017oo00@005YFFUH000QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000Ool000000eYF0P0000=JEP00FUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0P000eYF00@005YFFUH0009JEP03001JEUYF00AJEP<005Uoo`00:Woo0P001Woo0`001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUIJEP00FUH007oo
0P0000=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0002FUH00`00FUH00006FUH01@00
FUIJEUYF0000F7oo000ZOol00`00FUH00007Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001oo`030005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YF00001UYF00D005YFFUIJEP0005Qoo`00:Woo00<005YF
00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000Woo0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00FUH0
0006FUH00`00FUIJEP02001HOol002Yoo`04001JEUYF000:Ool300000eYF001JEP06FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool01@00Ool005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00D005YFFUIJEP0005Uoo`00:Woo00D005YF
FUIJEP0000aoo`<000IJEP03001JEUYF00D0009JEP03001JEUYF00EJEP04001JEUYFFUH20007Ool0
1@00Ool005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000IJEP05001JEUYF
FUH0001IOol002]oo`03001JEUYF008000ioo`@0009JEP04001JEUYFFUH30002FUH00`00FUIJEP06
FUH01000FUH0000027oo0P0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000IJ
EP03001JEUYF008005Uoo`00:goo00<005YF00000UYF0P0047oo1`0015YF00<005YFFUH00UYF1P00
2Woo0P000Woo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH0
0P00FGoo000/Ool20004FUH00`00Oomoo`0DOol9000?Ool00`00FUH00002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00Oomoo`1HOol002eo
o`03001JEUYF00=JEP8002aoo`03001JEP0000=oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30005FUH01000FUH000000eYF00<007ooOol0F7oo000^Ool00`00FUIJEP02FUH01000FUH0
0000:7oo10001Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP04001J
EUYFFUH4001JOol002moo`800003FUH005YF00=JEP<002=oo`800003FUH0000000Qoo`800003FUH0
05YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP@00003FUH005YF00EJEP03001JEUYF009JEP<005Yoo`00<Goo0P001eYF0`007Woo0P00
0eYF0P002Woo10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF00H005YFFUIJEP00FUH20006FUH00`00FUIJEP02FUH2001KOol0039oo`03
001JEUYF00IJEP03001JEP0000<001Ioo`@00003FUH005YF009JEP03001oogoo00eoo`@0009JEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF008000IJ
EP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUH0001KOol003=oo`8000IJEP03001JEUYF
00=JEPL000Uoo`H000EJEP04001JEUYF000DOol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60006FUH00`00FUIJEP04FUH:001LOol003Eoo`8000=JEP03001JEUYF00IJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP04001JEP00000JOol60003FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP060006Ool40002FUH00`00FUIJEP05FUH3001ROol003Moo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80029ooal00003FUH0
0000008000]oo`@000IJEP03001JEUYF0080061oo`00>Goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00=Woo0P0015YF00<005YFFUH01UYF00<005YF00000P0037oo0P00
0eYF00<005YFFUH00eYF0P00GWoo000mOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000jOol200000eYF001JEP08FUH00`00FUIJEP02FUH3000;Ool200000eYF001JEP05FUH3
001LOol0045oo`L000AJEP03001JEUYF009JEPD0041oo`<000MJEP03001JEUYF00IJEPD000Qoo`80
00EJEP05001JEUYFFUH0001KOol004Qoo`T004Qoo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH8
0002Ool20003FUH01@00FUIJEUYF0000Fgoo002LOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF0P00Fgoo002OOol30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<007ooOol0FWoo002ROol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF1000G7oo002VOol70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000G7oo
002]Ool80003FUH00`00FUIJEP02FUH00`00FUH0001MOol00;Eoo`/005eoo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5894 .74536 m .59483 .68946 L .56386 .68492 L p .707 .577 .707 r
F P
0 g
s
.59483 .68946 m .5894 .74536 L .62112 .74768 L p .707 .577 .707 r
F P
0 g
s
.62112 .74768 m .62655 .69177 L .59483 .68946 L p .707 .577 .707 r
F P
0 g
s
.62655 .69177 m .62112 .74768 L .65049 .74754 L p .707 .577 .707 r
F P
0 g
s
.65049 .74754 m .65591 .69164 L .62655 .69177 L p .707 .577 .707 r
F P
0 g
s
.55843 .74082 m .56386 .68492 L .53667 .6786 L p .707 .577 .707 r
F P
0 g
s
.56386 .68492 m .55843 .74082 L .5894 .74536 L p .707 .577 .707 r
F P
0 g
s
.65591 .69164 m .65049 .74754 L .67462 .74498 L p .707 .577 .707 r
F P
0 g
s
.67462 .74498 m .68005 .68907 L .65591 .69164 L p .707 .577 .707 r
F P
0 g
s
.58215 .80331 m .58797 .76611 L .55733 .75991 L p .707 .577 .707 r
F P
0 g
s
.58797 .76611 m .58215 .80331 L .61368 .80758 L p .707 .577 .707 r
F P
0 g
s
.61368 .80758 m .6195 .77039 L .58797 .76611 L p .707 .577 .707 r
F P
0 g
s
.53667 .6786 m .53125 .73451 L .55843 .74082 L p .707 .577 .707 r
F P
0 g
s
.53125 .73451 m .53667 .6786 L .51592 .67113 L p .707 .577 .707 r
F P
0 g
s
.6195 .77039 m .61368 .80758 L .64299 .80951 L p .707 .577 .707 r
F P
0 g
s
.64299 .80951 m .64882 .77231 L .6195 .77039 L p .707 .577 .707 r
F P
0 g
s
.5515 .79711 m .55733 .75991 L .53056 .75239 L p .707 .577 .707 r
F P
0 g
s
.55733 .75991 m .5515 .79711 L .58215 .80331 L p .707 .577 .707 r
F P
0 g
s
.57589 .84513 m .57898 .82655 L .54853 .81998 L p .707 .577 .707 r
F P
0 g
s
.57898 .82655 m .57589 .84513 L .60741 .84982 L p .707 .577 .707 r
F P
0 g
s
.60741 .84982 m .61049 .83124 L .57898 .82655 L p .707 .577 .707 r
F P
0 g
s
.53056 .75239 m .52473 .78959 L .5515 .79711 L p .707 .577 .707 r
F P
0 g
s
.64882 .77231 m .64299 .80951 L .66723 .8089 L p .707 .577 .707 r
F P
0 g
s
.66723 .8089 m .67305 .7717 L .64882 .77231 L p .707 .577 .707 r
F P
0 g
s
.51592 .67113 m .5105 .72703 L .53125 .73451 L p .707 .577 .707 r
F P
0 g
s
.61049 .83124 m .60741 .84982 L .6369 .85219 L p .707 .577 .707 r
F P
0 g
s
.6369 .85219 m .63999 .83361 L .61049 .83124 L p .707 .577 .707 r
F P
0 g
s
.68005 .68907 m .67462 .74498 L .69116 .74022 L p .707 .577 .707 r
F P
0 g
s
.69116 .74022 m .69659 .68432 L .68005 .68907 L p .707 .577 .707 r
F P
0 g
s
.54853 .81998 m .54544 .83856 L .57589 .84513 L p .707 .577 .707 r
F P
0 g
s
.54544 .83856 m .54853 .81998 L .52213 .81219 L p .707 .577 .707 r
F P
0 g
s
.52473 .78959 m .53056 .75239 L .51028 .74427 L p .707 .577 .707 r
F P
0 g
s
.52213 .81219 m .51904 .83077 L .54544 .83856 L p .707 .577 .707 r
F P
0 g
s
.5105 .72703 m .51592 .67113 L .50365 .66322 L p .707 .577 .707 r
F P
0 g
s
.63999 .83361 m .6369 .85219 L .66149 .852 L p .707 .577 .707 r
F P
0 g
s
.66149 .852 m .66458 .83341 L .63999 .83361 L p .707 .577 .707 r
F P
0 g
s
.51028 .74427 m .50446 .78147 L .52473 .78959 L p .707 .577 .707 r
F P
0 g
s
.67305 .7717 m .66723 .8089 L .68402 .80581 L p .707 .577 .707 r
F P
0 g
s
.68402 .80581 m .68984 .76861 L .67305 .7717 L p .707 .577 .707 r
F P
0 g
s
.51904 .83077 m .52213 .81219 L .50235 .80394 L p .707 .577 .707 r
F P
0 g
s
.50365 .66322 m .49823 .71913 L .5105 .72703 L p .707 .577 .707 r
F P
0 g
s
.50235 .80394 m .49927 .82252 L .51904 .83077 L p .707 .577 .707 r
F P
0 g
s
.69659 .68432 m .69116 .74022 L .69849 .73375 L p .707 .577 .707 r
F P
0 g
s
.69849 .73375 m .70392 .67785 L .69659 .68432 L p .707 .577 .707 r
F P
0 g
s
.50446 .78147 m .51028 .74427 L .49849 .73637 L p .707 .577 .707 r
F P
0 g
s
.66458 .83341 m .66149 .852 L .67877 .84926 L p .707 .577 .707 r
F P
0 g
s
.67877 .84926 m .68185 .83068 L .66458 .83341 L p .707 .577 .707 r
F P
0 g
s
.49849 .73637 m .49267 .77357 L .50446 .78147 L p .707 .577 .707 r
F P
0 g
s
.49823 .71913 m .50365 .66322 L .50105 .65567 L p .707 .577 .707 r
F P
0 g
s
.49927 .82252 m .50235 .80394 L .49115 .79603 L p .707 .577 .707 r
F P
0 g
s
.68984 .76861 m .68402 .80581 L .69171 .80054 L p .707 .577 .707 r
F P
0 g
s
.69171 .80054 m .69754 .76334 L .68984 .76861 L p .707 .577 .707 r
F P
0 g
s
.49115 .79603 m .48806 .81461 L .49927 .82252 L p .707 .577 .707 r
F P
0 g
s
.50105 .65567 m .49563 .71157 L .49823 .71913 L p .707 .577 .707 r
F P
0 g
s
.49267 .77357 m .49849 .73637 L .49634 .72945 L p .707 .577 .707 r
F P
0 g
s
.70392 .67785 m .69849 .73375 L .6959 .72619 L p .707 .577 .707 r
F P
0 g
s
.6959 .72619 m .70132 .67029 L .70392 .67785 L p .707 .577 .707 r
F P
0 g
s
.68185 .83068 m .67877 .84926 L .68704 .84426 L p .707 .577 .707 r
F P
0 g
s
.68704 .84426 m .69013 .82568 L .68185 .83068 L p .707 .577 .707 r
F P
0 g
s
.49634 .72945 m .49052 .76665 L .49267 .77357 L p .707 .577 .707 r
F P
0 g
s
.49563 .71157 m .50105 .65567 L .50838 .64919 L p .707 .577 .707 r
F P
0 g
s
.50838 .64919 m .50296 .7051 L .49563 .71157 L p .707 .577 .707 r
F P
0 g
s
.50296 .7051 m .50838 .64919 L .52493 .64444 L p .707 .577 .707 r
F P
0 g
s
.52493 .64444 m .5195 .70035 L .50296 .7051 L p .707 .577 .707 r
F P
0 g
s
.49821 .76138 m .50403 .72418 L .52082 .7211 L p .707 .577 .707 r
F P
0 g
s
.52082 .7211 m .515 .75829 L .49821 .76138 L p .707 .577 .707 r
F P
0 g
s
.49479 .80282 m .49788 .78424 L .51515 .78151 L p .707 .577 .707 r
F P
0 g
s
.51515 .78151 m .51207 .80009 L .49479 .80282 L p .707 .577 .707 r
F P
0 g
s
.515 .75829 m .52082 .7211 L .54506 .72048 L p .707 .577 .707 r
F P
0 g
s
.54506 .72048 m .53924 .75768 L .515 .75829 L p .707 .577 .707 r
F P
0 g
s
.51207 .80009 m .51515 .78151 L .53974 .78131 L p .707 .577 .707 r
F P
0 g
s
.53974 .78131 m .53665 .79989 L .51207 .80009 L p .707 .577 .707 r
F P
0 g
s
.51537 .8217 m .51537 .31981 L .4703 .31921 L p .707 .577 .707 r
F P
0 g
s
.5195 .70035 m .52493 .64444 L .54906 .64187 L p .707 .577 .707 r
F P
0 g
s
.54906 .64187 m .54364 .69778 L .5195 .70035 L p .707 .577 .707 r
F P
0 g
s
.54364 .69778 m .54906 .64187 L .57842 .64174 L p .707 .577 .707 r
F P
0 g
s
.57842 .64174 m .573 .69765 L .54364 .69778 L p .707 .577 .707 r
F P
0 g
s
.53924 .75768 m .54506 .72048 L .57438 .72241 L p .707 .577 .707 r
F P
0 g
s
.57438 .72241 m .56856 .75961 L .53924 .75768 L p .707 .577 .707 r
F P
0 g
s
.53665 .79989 m .53974 .78131 L .56924 .78368 L p .707 .577 .707 r
F P
0 g
s
.56924 .78368 m .56615 .80226 L .53665 .79989 L p .707 .577 .707 r
F P
0 g
s
.51537 .31981 m .51537 .8217 L .55894 .81854 L p .707 .577 .707 r
F P
0 g
s
.55894 .81854 m .55894 .31666 L .51537 .31981 L p .707 .577 .707 r
F P
0 g
s
.4703 .82109 m .4703 .31921 L .42813 .31489 L p .707 .577 .707 r
F P
0 g
s
.48806 .81461 m .49115 .79603 L .48961 .78924 L p .707 .577 .707 r
F P
0 g
s
.48961 .78924 m .48652 .80782 L .48806 .81461 L p .707 .577 .707 r
F P
0 g
s
.49052 .76665 m .49634 .72945 L .50403 .72418 L p .707 .577 .707 r
F P
0 g
s
.50403 .72418 m .49821 .76138 L .49052 .76665 L p .707 .577 .707 r
F P
0 g
s
.48652 .80782 m .48961 .78924 L .49788 .78424 L p .707 .577 .707 r
F P
0 g
s
.49788 .78424 m .49479 .80282 L .48652 .80782 L p .707 .577 .707 r
F P
0 g
s
.4703 .31921 m .4703 .82109 L .51537 .8217 L p .707 .577 .707 r
F P
0 g
s
.69754 .76334 m .69171 .80054 L .68956 .79362 L p .707 .577 .707 r
F P
0 g
s
.68956 .79362 m .69538 .75642 L .69754 .76334 L p .707 .577 .707 r
F P
0 g
s
.573 .69765 m .57842 .64174 L .61014 .64406 L p .707 .577 .707 r
F P
0 g
s
.61014 .64406 m .60472 .69996 L .573 .69765 L p .707 .577 .707 r
F P
0 g
s
.56856 .75961 m .57438 .72241 L .6059 .72668 L p .707 .577 .707 r
F P
0 g
s
.6059 .72668 m .60008 .76388 L .56856 .75961 L p .707 .577 .707 r
F P
0 g
s
.56615 .80226 m .56924 .78368 L .60075 .78837 L p .707 .577 .707 r
F P
0 g
s
.60075 .78837 m .59767 .80695 L .56615 .80226 L p .707 .577 .707 r
F P
0 g
s
.55894 .31666 m .55894 .81854 L .59674 .81193 L p .707 .577 .707 r
F P
0 g
s
.59674 .81193 m .59674 .31004 L .55894 .31666 L p .707 .577 .707 r
F P
0 g
s
.42813 .81678 m .42813 .31489 L .393 .30729 L p .707 .577 .707 r
F P
0 g
s
.42813 .31489 m .42813 .81678 L .4703 .82109 L p .707 .577 .707 r
F P
0 g
s
.70132 .67029 m .6959 .72619 L .68362 .71829 L p .707 .577 .707 r
F P
0 g
s
.68362 .71829 m .68905 .66238 L .70132 .67029 L p .707 .577 .707 r
F P
0 g
s
.69013 .82568 m .68704 .84426 L .6855 .83747 L p .707 .577 .707 r
F P
0 g
s
.6855 .83747 m .68858 .81889 L .69013 .82568 L p .707 .577 .707 r
F P
0 g
s
.24986 .71984 m .25218 .66602 L .22109 .66223 L p .707 .577 .707 r
F P
0 g
s
.25218 .66602 m .24986 .71984 L .28169 .72009 L p .707 .577 .707 r
F P
0 g
s
.28169 .72009 m .28401 .66627 L .25218 .66602 L p .707 .577 .707 r
F P
0 g
s
.64111 .64859 m .63569 .7045 L .60472 .69996 L p .707 .577 .707 r
F P
0 g
s
.60472 .69996 m .61014 .64406 L .64111 .64859 L p .707 .577 .707 r
F P
0 g
s
.63655 .73288 m .63073 .77008 L .60008 .76388 L p .707 .577 .707 r
F P
0 g
s
.60008 .76388 m .6059 .72668 L .63655 .73288 L p .707 .577 .707 r
F P
0 g
s
.6312 .79494 m .62811 .81352 L .59767 .80695 L p .707 .577 .707 r
F P
0 g
s
.59767 .80695 m .60075 .78837 L .6312 .79494 L p .707 .577 .707 r
F P
0 g
s
.59674 .31004 m .59674 .81193 L .62507 .8025 L p .707 .577 .707 r
F P
0 g
s
.62507 .8025 m .62507 .30061 L .59674 .31004 L p .707 .577 .707 r
F P
0 g
s
.28401 .66627 m .28169 .72009 L .31114 .71676 L p .707 .577 .707 r
F P
0 g
s
.31114 .71676 m .31346 .66294 L .28401 .66627 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21876 .71605 m .22109 .66223 L .19378 .65526 L p .707 .577 .707 r
F P
0 g
s
.22109 .66223 m .21876 .71605 L .24986 .71984 L p .707 .577 .707 r
F P
0 g
s
.69538 .75642 m .68956 .79362 L .67777 .78572 L p .707 .577 .707 r
F P
0 g
s
.67777 .78572 m .68359 .74852 L .69538 .75642 L p .707 .577 .707 r
F P
0 g
s
.393 .80918 m .393 .30729 L .36835 .29714 L p .707 .577 .707 r
F P
0 g
s
.393 .30729 m .393 .80918 L .42813 .81678 L p .707 .577 .707 r
F P
0 g
s
.31346 .66294 m .31114 .71676 L .33533 .71019 L p .707 .577 .707 r
F P
0 g
s
.33533 .71019 m .33765 .65637 L .31346 .66294 L p .707 .577 .707 r
F P
0 g
s
.68905 .66238 m .68362 .71829 L .66288 .71082 L p .707 .577 .707 r
F P
0 g
s
.66288 .71082 m .6683 .65491 L .68905 .66238 L p .707 .577 .707 r
F P
0 g
s
.68858 .81889 m .6855 .83747 L .67429 .82956 L p .707 .577 .707 r
F P
0 g
s
.67429 .82956 m .67738 .81098 L .68858 .81889 L p .707 .577 .707 r
F P
0 g
s
.19145 .70908 m .19378 .65526 L .17292 .6458 L p .707 .577 .707 r
F P
0 g
s
.19378 .65526 m .19145 .70908 L .21876 .71605 L p .707 .577 .707 r
F P
0 g
s
.2462 .78387 m .24869 .74892 L .21772 .74392 L p .707 .577 .707 r
F P
0 g
s
.24869 .74892 m .2462 .78387 L .27802 .78479 L p .707 .577 .707 r
F P
0 g
s
.27802 .78479 m .28051 .74985 L .24869 .74892 L p .707 .577 .707 r
F P
0 g
s
.28051 .74985 m .27802 .78479 L .30757 .78155 L p .707 .577 .707 r
F P
0 g
s
.30757 .78155 m .31006 .74661 L .28051 .74985 L p .707 .577 .707 r
F P
0 g
s
.33765 .65637 m .33533 .71019 L .35189 .70102 L p .707 .577 .707 r
F P
0 g
s
.35189 .70102 m .35422 .64719 L .33765 .65637 L p .707 .577 .707 r
F P
0 g
s
.6683 .65491 m .66288 .71082 L .63569 .7045 L p .707 .577 .707 r
F P
0 g
s
.63569 .7045 m .64111 .64859 L .6683 .65491 L p .707 .577 .707 r
F P
0 g
s
.66332 .74041 m .6575 .77761 L .63073 .77008 L p .707 .577 .707 r
F P
0 g
s
.63073 .77008 m .63655 .73288 L .66332 .74041 L p .707 .577 .707 r
F P
0 g
s
.62811 .81352 m .6312 .79494 L .6576 .80273 L p .707 .577 .707 r
F P
0 g
s
.62507 .30061 m .62507 .8025 L .64115 .79119 L p .707 .577 .707 r
F P
0 g
s
.64115 .79119 m .64115 .2893 L .62507 .30061 L p .707 .577 .707 r
F P
0 g
s
.21523 .77887 m .21772 .74392 L .19063 .73534 L p .707 .577 .707 r
F P
0 g
s
.21772 .74392 m .21523 .77887 L .2462 .78387 L p .707 .577 .707 r
F P
0 g
s
.68359 .74852 m .67777 .78572 L .6575 .77761 L p .707 .577 .707 r
F P
0 g
s
.6575 .77761 m .66332 .74041 L .68359 .74852 L p .707 .577 .707 r
F P
0 g
s
.17292 .6458 m .17059 .69962 L .19145 .70908 L p .707 .577 .707 r
F P
0 g
s
.17059 .69962 m .17292 .6458 L .16056 .63477 L p .707 .577 .707 r
F P
0 g
s
.31006 .74661 m .30757 .78155 L .33195 .77447 L p .707 .577 .707 r
F P
0 g
s
.33195 .77447 m .33445 .73952 L .31006 .74661 L p .707 .577 .707 r
F P
0 g
s
.36834 .79903 m .36835 .29714 L .35658 .28545 L p .707 .577 .707 r
F P
0 g
s
.36835 .29714 m .36834 .79903 L .393 .80918 L p .707 .577 .707 r
F P
0 g
s
.67738 .81098 m .67429 .82956 L .65452 .82131 L p .707 .577 .707 r
F P
0 g
s
.65452 .82131 m .6576 .80273 L .67738 .81098 L p .707 .577 .707 r
F P
0 g
s
.18814 .77028 m .19063 .73534 L .17007 .72401 L p .707 .577 .707 r
F P
0 g
s
.19063 .73534 m .18814 .77028 L .21523 .77887 L p .707 .577 .707 r
F P
0 g
s
.24247 .82559 m .24378 .80822 L .21296 .80281 L p .707 .577 .707 r
F P
0 g
s
.24378 .80822 m .24247 .82559 L .27432 .82683 L p .707 .577 .707 r
F P
0 g
s
.27432 .82683 m .27563 .80946 L .24378 .80822 L p .707 .577 .707 r
F P
0 g
s
.27563 .80946 m .27432 .82683 L .30407 .82378 L p .707 .577 .707 r
F P
0 g
s
.30407 .82378 m .30539 .80642 L .27563 .80946 L p .707 .577 .707 r
F P
0 g
s
.21165 .82018 m .21296 .80281 L .18619 .79377 L p .707 .577 .707 r
F P
0 g
s
.21296 .80281 m .21165 .82018 L .24247 .82559 L p .707 .577 .707 r
F P
0 g
s
.35422 .64719 m .35189 .70102 L .3592 .69014 L p .707 .577 .707 r
F P
0 g
s
.3592 .69014 m .36153 .63632 L .35422 .64719 L p .707 .577 .707 r
F P
0 g
s
.33445 .73952 m .33195 .77447 L .34879 .76423 L p .707 .577 .707 r
F P
0 g
s
.34879 .76423 m .35128 .72929 L .33445 .73952 L p .707 .577 .707 r
F P
0 g
s
.16056 .63477 m .15823 .68859 L .17059 .69962 L p .707 .577 .707 r
F P
0 g
s
.17007 .72401 m .16757 .75896 L .18814 .77028 L p .707 .577 .707 r
F P
0 g
s
.30539 .80642 m .30407 .82378 L .32883 .81675 L p .707 .577 .707 r
F P
0 g
s
.32883 .81675 m .33014 .79938 L .30539 .80642 L p .707 .577 .707 r
F P
0 g
s
.18619 .79377 m .18488 .81114 L .21165 .82018 L p .707 .577 .707 r
F P
0 g
s
.15823 .68859 m .16056 .63477 L .1579 .62325 L p .707 .577 .707 r
F P
0 g
s
.16757 .75896 m .17007 .72401 L .15805 .71105 L p .707 .577 .707 r
F P
0 g
s
.6576 .80273 m .65452 .82131 L .62811 .81352 L p .707 .577 .707 r
F P
0 g
s
.18488 .81114 m .18619 .79377 L .16609 .78197 L p .707 .577 .707 r
F P
0 g
s
.64115 .2893 m .64115 .79119 L .64342 .77909 L p .707 .577 .707 r
F P
0 g
s
.64342 .77909 m .64342 .2772 L .64115 .2893 L p .707 .577 .707 r
F P
0 g
s
.16609 .78197 m .16478 .79934 L .18488 .81114 L p .707 .577 .707 r
F P
0 g
s
.33014 .79938 m .32883 .81675 L .34617 .80641 L p .707 .577 .707 r
F P
0 g
s
.34617 .80641 m .34748 .78904 L .33014 .79938 L p .707 .577 .707 r
F P
0 g
s
.15805 .71105 m .15555 .74599 L .16757 .75896 L p .707 .577 .707 r
F P
0 g
s
.35128 .72929 m .34879 .76423 L .35644 .75184 L p .707 .577 .707 r
F P
0 g
s
.35644 .75184 m .35893 .71689 L .35128 .72929 L p .707 .577 .707 r
F P
0 g
s
.36153 .63632 m .3592 .69014 L .35655 .67862 L p .707 .577 .707 r
F P
0 g
s
.35655 .67862 m .35887 .6248 L .36153 .63632 L p .707 .577 .707 r
F P
0 g
s
.35893 .71689 m .35644 .75184 L .35413 .73851 L p .707 .577 .707 r
F P
0 g
s
.35413 .73851 m .35663 .70356 L .35893 .71689 L p .707 .577 .707 r
F P
0 g
s
.35887 .6248 m .35655 .67862 L .34419 .66759 L p .707 .577 .707 r
F P
0 g
s
.34419 .66759 m .34651 .61377 L .35887 .6248 L p .707 .577 .707 r
F P
0 g
s
.35663 .70356 m .35413 .73851 L .34211 .72555 L p .707 .577 .707 r
F P
0 g
s
.34211 .72555 m .3446 .6906 L .35663 .70356 L p .707 .577 .707 r
F P
0 g
s
.35658 .28545 m .35657 .78734 L .36834 .79903 L p .707 .577 .707 r
F P
0 g
s
.35657 .78734 m .35658 .28545 L .35884 .27336 L p .707 .577 .707 r
F P
0 g
s
.1579 .62325 m .15558 .67707 L .15823 .68859 L p .707 .577 .707 r
F P
0 g
s
.16478 .79934 m .16609 .78197 L .15462 .76858 L p .707 .577 .707 r
F P
0 g
s
.15555 .74599 m .15805 .71105 L .15574 .69772 L p .707 .577 .707 r
F P
0 g
s
.15558 .67707 m .1579 .62325 L .16521 .61237 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15462 .76858 m .15331 .78595 L .16478 .79934 L p .707 .577 .707 r
F P
0 g
s
.34748 .78904 m .34617 .80641 L .35438 .79379 L p .707 .577 .707 r
F P
0 g
s
.35438 .79379 m .35569 .77642 L .34748 .78904 L p .707 .577 .707 r
F P
0 g
s
.15574 .69772 m .15325 .73266 L .15555 .74599 L p .707 .577 .707 r
F P
0 g
s
.64342 .2772 m .64342 .77909 L .63165 .7674 L p .707 .577 .707 r
F P
0 g
s
.63165 .7674 m .63165 .26551 L .64342 .2772 L p .707 .577 .707 r
F P
0 g
s
.16521 .61237 m .16289 .66619 L .15558 .67707 L p .707 .577 .707 r
F P
0 g
s
.15331 .78595 m .15462 .76858 L .15291 .75491 L p .707 .577 .707 r
F P
0 g
s
.15325 .73266 m .15574 .69772 L .16339 .68533 L p .707 .577 .707 r
F P
0 g
s
.16289 .66619 m .16521 .61237 L .18177 .6032 L p .707 .577 .707 r
F P
0 g
s
.15291 .75491 m .1516 .77227 L .15331 .78595 L p .707 .577 .707 r
F P
0 g
s
.35884 .77525 m .35884 .27336 L .37493 .26205 L p .707 .577 .707 r
F P
0 g
s
.35884 .27336 m .35884 .77525 L .35657 .78734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35569 .77642 m .35438 .79379 L .35267 .78011 L p .707 .577 .707 r
F P
0 g
s
.35267 .78011 m .35398 .76274 L .35569 .77642 L p .707 .577 .707 r
F P
0 g
s
.16339 .68533 m .16089 .72027 L .15325 .73266 L p .707 .577 .707 r
F P
0 g
s
.34651 .61377 m .34419 .66759 L .32333 .65813 L p .707 .577 .707 r
F P
0 g
s
.32333 .65813 m .32565 .60431 L .34651 .61377 L p .707 .577 .707 r
F P
0 g
s
.18177 .6032 m .17945 .65702 L .16289 .66619 L p .707 .577 .707 r
F P
0 g
s
.1516 .77227 m .15291 .75491 L .16112 .74228 L p .707 .577 .707 r
F P
0 g
s
.17945 .65702 m .18177 .6032 L .20596 .59663 L p .707 .577 .707 r
F P
0 g
s
.16089 .72027 m .16339 .68533 L .18022 .67509 L p .707 .577 .707 r
F P
0 g
s
.16112 .74228 m .15981 .75965 L .1516 .77227 L p .707 .577 .707 r
F P
0 g
s
.63165 .26551 m .63165 .7674 L .607 .75726 L p .707 .577 .707 r
F P
0 g
s
.607 .75726 m .607 .25537 L .63165 .26551 L p .707 .577 .707 r
F P
0 g
s
.35398 .76274 m .35267 .78011 L .3412 .76672 L p .707 .577 .707 r
F P
0 g
s
.3412 .76672 m .34251 .74935 L .35398 .76274 L p .707 .577 .707 r
F P
0 g
s
.32565 .60431 m .32333 .65813 L .29602 .65116 L p .707 .577 .707 r
F P
0 g
s
.29602 .65116 m .29834 .59734 L .32565 .60431 L p .707 .577 .707 r
F P
0 g
s
.18022 .67509 m .17773 .71003 L .16089 .72027 L p .707 .577 .707 r
F P
0 g
s
.3446 .6906 m .34211 .72555 L .32155 .71422 L p .707 .577 .707 r
F P
0 g
s
.32155 .71422 m .32404 .67927 L .3446 .6906 L p .707 .577 .707 r
F P
0 g
s
.37493 .76393 m .37493 .26205 L .40326 .25262 L p .707 .577 .707 r
F P
0 g
s
.37493 .26205 m .37493 .76393 L .35884 .77525 L p .707 .577 .707 r
F P
0 g
s
.20364 .65045 m .20596 .59663 L .23542 .5933 L p .707 .577 .707 r
F P
0 g
s
.20596 .59663 m .20364 .65045 L .17945 .65702 L p .707 .577 .707 r
F P
0 g
s
.15981 .75965 m .16112 .74228 L .17845 .73195 L p .707 .577 .707 r
F P
0 g
s
.17773 .71003 m .18022 .67509 L .20461 .668 L p .707 .577 .707 r
F P
0 g
s
.29834 .59734 m .29602 .65116 L .26492 .64737 L p .707 .577 .707 r
F P
0 g
s
.26492 .64737 m .26725 .59355 L .29834 .59734 L p .707 .577 .707 r
F P
0 g
s
.23309 .64712 m .23542 .5933 L .26725 .59355 L p .707 .577 .707 r
F P
0 g
s
.23542 .5933 m .23309 .64712 L .20364 .65045 L p .707 .577 .707 r
F P
0 g
s
.17845 .73195 m .17714 .74931 L .15981 .75965 L p .707 .577 .707 r
F P
0 g
s
.26725 .59355 m .26492 .64737 L .23309 .64712 L p .707 .577 .707 r
F P
0 g
s
.73507 .64974 m .73275 .59299 L .70166 .59294 L p .707 .577 .707 r
F P
0 g
s
.73275 .59299 m .73507 .64974 L .7669 .64801 L p .707 .577 .707 r
F P
0 g
s
.7669 .64801 m .76458 .59126 L .73275 .59299 L p .707 .577 .707 r
F P
0 g
s
.32404 .67927 m .32155 .71422 L .29445 .70563 L p .707 .577 .707 r
F P
0 g
s
.29445 .70563 m .29695 .67069 L .32404 .67927 L p .707 .577 .707 r
F P
0 g
s
.76458 .59126 m .7669 .64801 L .79636 .64467 L p .707 .577 .707 r
F P
0 g
s
.79636 .64467 m .79403 .58791 L .76458 .59126 L p .707 .577 .707 r
F P
0 g
s
.34251 .74935 m .3412 .76672 L .32109 .75492 L p .707 .577 .707 r
F P
0 g
s
.32109 .75492 m .32241 .73756 L .34251 .74935 L p .707 .577 .707 r
F P
0 g
s
.20461 .668 m .20212 .70295 L .17773 .71003 L p .707 .577 .707 r
F P
0 g
s
.607 .25537 m .607 .75726 L .57187 .74966 L p .707 .577 .707 r
F P
0 g
s
.57187 .74966 m .57186 .24777 L .607 .25537 L p .707 .577 .707 r
F P
0 g
s
.70398 .64969 m .70166 .59294 L .67435 .5911 L p .707 .577 .707 r
F P
0 g
s
.70166 .59294 m .70398 .64969 L .73507 .64974 L p .707 .577 .707 r
F P
0 g
s
.20212 .70295 m .20461 .668 L .23416 .66476 L p .707 .577 .707 r
F P
0 g
s
.17714 .74931 m .17845 .73195 L .20321 .72491 L p .707 .577 .707 r
F P
0 g
s
.79403 .58791 m .79636 .64467 L .82055 .64004 L p .707 .577 .707 r
F P
0 g
s
.82055 .64004 m .81822 .58328 L .79403 .58791 L p .707 .577 .707 r
F P
0 g
s
.40326 .25262 m .40326 .75451 L .37493 .76393 L p .707 .577 .707 r
F P
0 g
s
.40326 .75451 m .40326 .25262 L .44106 .246 L p .707 .577 .707 r
F P
0 g
s
.73651 .70579 m .73402 .66767 L .70305 .66877 L p .707 .577 .707 r
F P
0 g
s
.73402 .66767 m .73651 .70579 L .76833 .70347 L p .707 .577 .707 r
F P
0 g
s
.76833 .70347 m .76584 .66535 L .73402 .66767 L p .707 .577 .707 r
F P
0 g
s
.29695 .67069 m .29445 .70563 L .26348 .70063 L p .707 .577 .707 r
F P
0 g
s
.26348 .70063 m .26598 .66569 L .29695 .67069 L p .707 .577 .707 r
F P
0 g
s
.67435 .5911 m .67667 .64786 L .70398 .64969 L p .707 .577 .707 r
F P
0 g
s
.76584 .66535 m .76833 .70347 L .79788 .70016 L p .707 .577 .707 r
F P
0 g
s
.79788 .70016 m .79539 .66204 L .76584 .66535 L p .707 .577 .707 r
F P
0 g
s
.23167 .69971 m .23416 .66476 L .26598 .66569 L p .707 .577 .707 r
F P
0 g
s
.23416 .66476 m .23167 .69971 L .20212 .70295 L p .707 .577 .707 r
F P
0 g
s
.70305 .66877 m .70554 .7069 L .73651 .70579 L p .707 .577 .707 r
F P
0 g
s
.20321 .72491 m .2019 .74228 L .17714 .74931 L p .707 .577 .707 r
F P
0 g
s
.26598 .66569 m .26348 .70063 L .23167 .69971 L p .707 .577 .707 r
F P
0 g
s
.70554 .7069 m .70305 .66877 L .67596 .66855 L p .707 .577 .707 r
F P
0 g
s
.67667 .64786 m .67435 .5911 L .65349 .58768 L p .707 .577 .707 r
F P
0 g
s
.32241 .73756 m .32109 .75492 L .29432 .74588 L p .707 .577 .707 r
F P
0 g
s
.29432 .74588 m .29564 .72851 L .32241 .73756 L p .707 .577 .707 r
F P
0 g
s
.73649 .74777 m .73518 .72869 L .70436 .72993 L p .707 .577 .707 r
F P
0 g
s
.73518 .72869 m .73649 .74777 L .76834 .74543 L p .707 .577 .707 r
F P
0 g
s
.76834 .74543 m .76703 .72634 L .73518 .72869 L p .707 .577 .707 r
F P
0 g
s
.76703 .72634 m .76834 .74543 L .7981 .74221 L p .707 .577 .707 r
F P
0 g
s
.7981 .74221 m .79678 .72313 L .76703 .72634 L p .707 .577 .707 r
F P
0 g
s
.70436 .72993 m .70567 .74901 L .73649 .74777 L p .707 .577 .707 r
F P
0 g
s
.67596 .66855 m .67845 .70668 L .70554 .7069 L p .707 .577 .707 r
F P
0 g
s
.79539 .66204 m .79788 .70016 L .82227 .69619 L p .707 .577 .707 r
F P
0 g
s
.82227 .69619 m .81977 .65807 L .79539 .66204 L p .707 .577 .707 r
F P
0 g
s
.2019 .74228 m .20321 .72491 L .23297 .72186 L p .707 .577 .707 r
F P
0 g
s
.57186 .24777 m .57187 .74966 L .5297 .74534 L p .707 .577 .707 r
F P
0 g
s
.5297 .74534 m .5297 .24345 L .57186 .24777 L p .707 .577 .707 r
F P
0 g
s
.65349 .58768 m .65581 .64443 L .67667 .64786 L p .707 .577 .707 r
F P
0 g
s
.70567 .74901 m .70436 .72993 L .67759 .72994 L p .707 .577 .707 r
F P
0 g
s
.81822 .58328 m .82055 .64004 L .83711 .63457 L p .707 .577 .707 r
F P
0 g
s
.83711 .63457 m .83479 .57782 L .81822 .58328 L p .707 .577 .707 r
F P
0 g
s
.67759 .72994 m .6789 .74903 L .70567 .74901 L p .707 .577 .707 r
F P
0 g
s
.79678 .72313 m .7981 .74221 L .82286 .73843 L p .707 .577 .707 r
F P
0 g
s
.82286 .73843 m .82154 .71935 L .79678 .72313 L p .707 .577 .707 r
F P
0 g
s
.44106 .74789 m .44106 .246 L .48463 .24284 L p .707 .577 .707 r
F P
0 g
s
.44106 .246 m .44106 .74789 L .40326 .75451 L p .707 .577 .707 r
F P
0 g
s
.29564 .72851 m .29432 .74588 L .26351 .74047 L p .707 .577 .707 r
F P
0 g
s
.26351 .74047 m .26482 .72311 L .29564 .72851 L p .707 .577 .707 r
F P
0 g
s
.23297 .72186 m .23166 .73923 L .2019 .74228 L p .707 .577 .707 r
F P
0 g
s
.67845 .70668 m .67596 .66855 L .65539 .66703 L p .707 .577 .707 r
F P
0 g
s
.23166 .73923 m .23297 .72186 L .26482 .72311 L p .707 .577 .707 r
F P
0 g
s
.65539 .66703 m .65789 .70516 L .67845 .70668 L p .707 .577 .707 r
F P
0 g
s
.26482 .72311 m .26351 .74047 L .23166 .73923 L p .707 .577 .707 r
F P
0 g
s
.65581 .64443 m .65349 .58768 L .64113 .58298 L p .707 .577 .707 r
F P
0 g
s
.5297 .24345 m .5297 .74534 L .48463 .74473 L p .707 .577 .707 r
F P
0 g
s
.48463 .74473 m .48463 .24284 L .5297 .24345 L p .707 .577 .707 r
F P
0 g
s
.81977 .65807 m .82227 .69619 L .8391 .69194 L p .707 .577 .707 r
F P
0 g
s
.8391 .69194 m .83661 .65382 L .81977 .65807 L p .707 .577 .707 r
F P
0 g
s
.48463 .24284 m .48463 .74473 L .44106 .74789 L p .707 .577 .707 r
F P
0 g
s
.6789 .74903 m .67759 .72994 L .65749 .72873 L p .707 .577 .707 r
F P
0 g
s
.65749 .72873 m .6588 .74781 L .6789 .74903 L p .707 .577 .707 r
F P
0 g
s
.64113 .58298 m .64345 .63974 L .65581 .64443 L p .707 .577 .707 r
F P
0 g
s
.82154 .71935 m .82286 .73843 L .84019 .73446 L p .707 .577 .707 r
F P
0 g
s
.84019 .73446 m .83888 .71538 L .82154 .71935 L p .707 .577 .707 r
F P
0 g
s
.83479 .57782 m .83711 .63457 L .84442 .62881 L p .707 .577 .707 r
F P
0 g
s
.84442 .62881 m .8421 .57206 L .83479 .57782 L p .707 .577 .707 r
F P
0 g
s
.65789 .70516 m .65539 .66703 L .64337 .66436 L p .707 .577 .707 r
F P
0 g
s
.64337 .66436 m .64586 .70249 L .65789 .70516 L p .707 .577 .707 r
F P
0 g
s
.6588 .74781 m .65749 .72873 L .64602 .72641 L p .707 .577 .707 r
F P
0 g
s
.83661 .65382 m .8391 .69194 L .84675 .68784 L p .707 .577 .707 r
F P
0 g
s
.84675 .68784 m .84426 .64971 L .83661 .65382 L p .707 .577 .707 r
F P
0 g
s
.64345 .63974 m .64113 .58298 L .63847 .57749 L p .707 .577 .707 r
F P
0 g
s
.64602 .72641 m .64733 .74549 L .6588 .74781 L p .707 .577 .707 r
F P
0 g
s
.83888 .71538 m .84019 .73446 L .8484 .73069 L p .707 .577 .707 r
F P
0 g
s
.8484 .73069 m .84709 .71161 L .83888 .71538 L p .707 .577 .707 r
F P
0 g
s
.63847 .57749 m .6408 .63424 L .64345 .63974 L p .707 .577 .707 r
F P
0 g
s
.8421 .57206 m .84442 .62881 L .84177 .62332 L p .707 .577 .707 r
F P
0 g
s
.84177 .62332 m .83944 .56656 L .8421 .57206 L p .707 .577 .707 r
F P
0 g
s
.64586 .70249 m .64337 .66436 L .64107 .6608 L p .707 .577 .707 r
F P
0 g
s
.64107 .6608 m .64356 .69892 L .64586 .70249 L p .707 .577 .707 r
F P
0 g
s
.64733 .74549 m .64602 .72641 L .64431 .7232 L p .707 .577 .707 r
F P
0 g
s
.84426 .64971 m .84675 .68784 L .84445 .68427 L p .707 .577 .707 r
F P
0 g
s
.84445 .68427 m .84195 .64615 L .84426 .64971 L p .707 .577 .707 r
F P
0 g
s
.64431 .7232 m .64562 .74229 L .64733 .74549 L p .707 .577 .707 r
F P
0 g
s
.6408 .63424 m .63847 .57749 L .64578 .57173 L p .707 .577 .707 r
F P
0 g
s
.84709 .71161 m .8484 .73069 L .84669 .72749 L p .707 .577 .707 r
F P
0 g
s
.84669 .72749 m .84538 .7084 L .84709 .71161 L p .707 .577 .707 r
F P
0 g
s
.64578 .57173 m .64811 .62848 L .6408 .63424 L p .707 .577 .707 r
F P
0 g
s
.83944 .56656 m .84177 .62332 L .8294 .61862 L p .707 .577 .707 r
F P
0 g
s
.8294 .61862 m .82708 .56187 L .83944 .56656 L p .707 .577 .707 r
F P
0 g
s
.64356 .69892 m .64107 .6608 L .64871 .65669 L p .707 .577 .707 r
F P
0 g
s
.64871 .65669 m .65121 .69482 L .64356 .69892 L p .707 .577 .707 r
F P
0 g
s
.39528 .62439 m .38985 .56971 L .35888 .57024 L p .707 .577 .707 r
F P
0 g
s
.38985 .56971 m .39528 .62439 L .427 .62074 L p .707 .577 .707 r
F P
0 g
s
.427 .62074 m .42157 .56606 L .38985 .56971 L p .707 .577 .707 r
F P
0 g
s
.42157 .56606 m .427 .62074 L .45636 .61432 L p .707 .577 .707 r
F P
0 g
s
.45636 .61432 m .45094 .55964 L .42157 .56606 L p .707 .577 .707 r
F P
0 g
s
.64562 .74229 m .64431 .7232 L .65252 .71943 L p .707 .577 .707 r
F P
0 g
s
.64811 .62848 m .64578 .57173 L .66234 .56626 L p .707 .577 .707 r
F P
0 g
s
.84195 .64615 m .84445 .68427 L .83242 .6816 L p .707 .577 .707 r
F P
0 g
s
.83242 .6816 m .82993 .64348 L .84195 .64615 L p .707 .577 .707 r
F P
0 g
s
.65252 .71943 m .65383 .73852 L .64562 .74229 L p .707 .577 .707 r
F P
0 g
s
.36431 .62492 m .35888 .57024 L .3317 .56759 L p .707 .577 .707 r
F P
0 g
s
.35888 .57024 m .36431 .62492 L .39528 .62439 L p .707 .577 .707 r
F P
0 g
s
.84538 .7084 m .84669 .72749 L .83522 .72517 L p .707 .577 .707 r
F P
0 g
s
.83522 .72517 m .83391 .70608 L .84538 .7084 L p .707 .577 .707 r
F P
0 g
s
.45094 .55964 m .45636 .61432 L .4805 .60577 L p .707 .577 .707 r
F P
0 g
s
.4805 .60577 m .47507 .55109 L .45094 .55964 L p .707 .577 .707 r
F P
0 g
s
.66234 .56626 m .66467 .62302 L .64811 .62848 L p .707 .577 .707 r
F P
0 g
s
.82708 .56187 m .8294 .61862 L .80855 .6152 L p .707 .577 .707 r
F P
0 g
s
.80855 .6152 m .80622 .55844 L .82708 .56187 L p .707 .577 .707 r
F P
0 g
s
.65121 .69482 m .64871 .65669 L .66555 .65245 L p .707 .577 .707 r
F P
0 g
s
.33712 .62227 m .3317 .56759 L .31095 .56203 L p .707 .577 .707 r
F P
0 g
s
.3317 .56759 m .33712 .62227 L .36431 .62492 L p .707 .577 .707 r
F P
0 g
s
.66555 .65245 m .66804 .69057 L .65121 .69482 L p .707 .577 .707 r
F P
0 g
s
.39992 .6868 m .39409 .65089 L .36345 .65276 L p .707 .577 .707 r
F P
0 g
s
.39409 .65089 m .39992 .6868 L .43144 .68152 L p .707 .577 .707 r
F P
0 g
s
.43144 .68152 m .42562 .64561 L .39409 .65089 L p .707 .577 .707 r
F P
0 g
s
.42562 .64561 m .43144 .68152 L .46076 .67336 L p .707 .577 .707 r
F P
0 g
s
.46076 .67336 m .45494 .63745 L .42562 .64561 L p .707 .577 .707 r
F P
0 g
s
.66467 .62302 m .66234 .56626 L .68654 .56163 L p .707 .577 .707 r
F P
0 g
s
.47507 .55109 m .4805 .60577 L .49704 .59591 L p .707 .577 .707 r
F P
0 g
s
.49704 .59591 m .49161 .54123 L .47507 .55109 L p .707 .577 .707 r
F P
0 g
s
.82993 .64348 m .83242 .6816 L .81186 .68008 L p .707 .577 .707 r
F P
0 g
s
.81186 .68008 m .80937 .64196 L .82993 .64348 L p .707 .577 .707 r
F P
0 g
s
.65383 .73852 m .65252 .71943 L .66985 .71546 L p .707 .577 .707 r
F P
0 g
s
.36927 .68867 m .36345 .65276 L .33668 .65105 L p .707 .577 .707 r
F P
0 g
s
.36345 .65276 m .36927 .68867 L .39992 .6868 L p .707 .577 .707 r
F P
0 g
s
.66985 .71546 m .67117 .73455 L .65383 .73852 L p .707 .577 .707 r
F P
0 g
s
.45494 .63745 m .46076 .67336 L .485 .66312 L p .707 .577 .707 r
F P
0 g
s
.485 .66312 m .47917 .62721 L .45494 .63745 L p .707 .577 .707 r
F P
0 g
s
.68654 .56163 m .68886 .61839 L .66467 .62302 L p .707 .577 .707 r
F P
0 g
s
.80622 .55844 m .80855 .6152 L .78124 .61336 L p .707 .577 .707 r
F P
0 g
s
.78124 .61336 m .77891 .55661 L .80622 .55844 L p .707 .577 .707 r
F P
0 g
s
.83391 .70608 m .83522 .72517 L .81512 .72395 L p .707 .577 .707 r
F P
0 g
s
.81512 .72395 m .8138 .70487 L .83391 .70608 L p .707 .577 .707 r
F P
0 g
s
.31095 .56203 m .31637 .6167 L .33712 .62227 L p .707 .577 .707 r
F P
0 g
s
.43385 .7234 m .43076 .70548 L .39925 .71083 L p .707 .577 .707 r
F P
0 g
s
.43076 .70548 m .43385 .7234 L .46334 .71512 L p .707 .577 .707 r
F P
0 g
s
.46334 .71512 m .46026 .6972 L .43076 .70548 L p .707 .577 .707 r
F P
0 g
s
.40233 .72875 m .39925 .71083 L .3688 .71274 L p .707 .577 .707 r
F P
0 g
s
.39925 .71083 m .40233 .72875 L .43385 .7234 L p .707 .577 .707 r
F P
0 g
s
.33668 .65105 m .3425 .68696 L .36927 .68867 L p .707 .577 .707 r
F P
0 g
s
.66804 .69057 m .66555 .65245 L .68994 .64847 L p .707 .577 .707 r
F P
0 g
s
.31637 .6167 m .31095 .56203 L .29868 .55409 L p .707 .577 .707 r
F P
0 g
s
.68886 .61839 m .68654 .56163 L .71599 .55829 L p .707 .577 .707 r
F P
0 g
s
.3425 .68696 m .33668 .65105 L .3164 .64593 L p .707 .577 .707 r
F P
0 g
s
.3688 .71274 m .37188 .73065 L .40233 .72875 L p .707 .577 .707 r
F P
0 g
s
.68994 .64847 m .69243 .6866 L .66804 .69057 L p .707 .577 .707 r
F P
0 g
s
.47917 .62721 m .485 .66312 L .50179 .65179 L p .707 .577 .707 r
F P
0 g
s
.50179 .65179 m .49596 .61588 L .47917 .62721 L p .707 .577 .707 r
F P
0 g
s
.46026 .6972 m .46334 .71512 L .48793 .70472 L p .707 .577 .707 r
F P
0 g
s
.48793 .70472 m .48485 .68681 L .46026 .6972 L p .707 .577 .707 r
F P
0 g
s
.37188 .73065 m .3688 .71274 L .34239 .711 L p .707 .577 .707 r
F P
0 g
s
.77891 .55661 m .78124 .61336 L .75014 .61331 L p .707 .577 .707 r
F P
0 g
s
.75014 .61331 m .74782 .55656 L .77891 .55661 L p .707 .577 .707 r
F P
0 g
s
.80937 .64196 m .81186 .68008 L .78477 .67986 L p .707 .577 .707 r
F P
0 g
s
.78477 .67986 m .78228 .64174 L .80937 .64196 L p .707 .577 .707 r
F P
0 g
s
.49161 .54123 m .49704 .59591 L .50437 .58571 L p .707 .577 .707 r
F P
0 g
s
.50437 .58571 m .49894 .53104 L .49161 .54123 L p .707 .577 .707 r
F P
0 g
s
.67117 .73455 m .66985 .71546 L .69461 .71169 L p .707 .577 .707 r
F P
0 g
s
.71599 .55829 m .71831 .61504 L .68886 .61839 L p .707 .577 .707 r
F P
0 g
s
.69461 .71169 m .69592 .73077 L .67117 .73455 L p .707 .577 .707 r
F P
0 g
s
.34239 .711 m .34548 .72892 L .37188 .73065 L p .707 .577 .707 r
F P
0 g
s
.71831 .61504 m .71599 .55829 L .74782 .55656 L p .707 .577 .707 r
F P
0 g
s
.3164 .64593 m .32223 .68184 L .3425 .68696 L p .707 .577 .707 r
F P
0 g
s
.74782 .55656 m .75014 .61331 L .71831 .61504 L p .707 .577 .707 r
F P
0 g
s
.29868 .55409 m .3041 .60877 L .31637 .6167 L p .707 .577 .707 r
F P
0 g
s
.8138 .70487 m .81512 .72395 L .78835 .72397 L p .707 .577 .707 r
F P
0 g
s
.78835 .72397 m .78703 .70488 L .8138 .70487 L p .707 .577 .707 r
F P
0 g
s
.69243 .6866 m .68994 .64847 L .71949 .64517 L p .707 .577 .707 r
F P
0 g
s
.48485 .68681 m .48793 .70472 L .50521 .69323 L p .707 .577 .707 r
F P
0 g
s
.50521 .69323 m .50212 .67531 L .48485 .68681 L p .707 .577 .707 r
F P
0 g
s
.71949 .64517 m .72198 .68329 L .69243 .6866 L p .707 .577 .707 r
F P
0 g
s
.34548 .72892 m .34239 .711 L .32262 .7058 L p .707 .577 .707 r
F P
0 g
s
.78228 .64174 m .78477 .67986 L .7538 .68097 L p .707 .577 .707 r
F P
0 g
s
.7538 .68097 m .7513 .64285 L .78228 .64174 L p .707 .577 .707 r
F P
0 g
s
.32223 .68184 m .3164 .64593 L .30461 .63788 L p .707 .577 .707 r
F P
0 g
s
.3041 .60877 m .29868 .55409 L .29608 .54456 L p .707 .577 .707 r
F P
0 g
s
.49596 .61588 m .50179 .65179 L .50948 .64049 L p .707 .577 .707 r
F P
0 g
s
.50948 .64049 m .50366 .60458 L .49596 .61588 L p .707 .577 .707 r
F P
0 g
s
.69592 .73077 m .69461 .71169 L .72437 .70847 L p .707 .577 .707 r
F P
0 g
s
.32262 .7058 m .32571 .72372 L .34548 .72892 L p .707 .577 .707 r
F P
0 g
s
.72198 .68329 m .71949 .64517 L .7513 .64285 L p .707 .577 .707 r
F P
0 g
s
.72437 .70847 m .72568 .72755 L .69592 .73077 L p .707 .577 .707 r
F P
0 g
s
.7513 .64285 m .7538 .68097 L .72198 .68329 L p .707 .577 .707 r
F P
0 g
s
.78703 .70488 m .78835 .72397 L .75753 .72521 L p .707 .577 .707 r
F P
0 g
s
.75753 .72521 m .75622 .70612 L .78703 .70488 L p .707 .577 .707 r
F P
0 g
s
.49894 .53104 m .50437 .58571 L .50177 .57618 L p .707 .577 .707 r
F P
0 g
s
.50177 .57618 m .49635 .5215 L .49894 .53104 L p .707 .577 .707 r
F P
0 g
s
.30461 .63788 m .31044 .67379 L .32223 .68184 L p .707 .577 .707 r
F P
0 g
s
.72568 .72755 m .72437 .70847 L .75622 .70612 L p .707 .577 .707 r
F P
0 g
s
.75622 .70612 m .75753 .72521 L .72568 .72755 L p .707 .577 .707 r
F P
0 g
s
.29608 .54456 m .3015 .59923 L .3041 .60877 L p .707 .577 .707 r
F P
0 g
s
.50212 .67531 m .50521 .69323 L .51348 .68176 L p .707 .577 .707 r
F P
0 g
s
.51348 .68176 m .51039 .66385 L .50212 .67531 L p .707 .577 .707 r
F P
0 g
s
.32571 .72372 m .32262 .7058 L .31141 .69764 L p .707 .577 .707 r
F P
0 g
s
.31141 .69764 m .3145 .71556 L .32571 .72372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.31044 .67379 m .30461 .63788 L .30246 .62771 L p .708 .578 .707 r
F P
0 g
s
.3015 .59923 m .29608 .54456 L .30341 .53436 L p .707 .577 .707 r
F P
0 g
s
.50366 .60458 m .50948 .64049 L .50733 .63032 L p .708 .578 .707 r
F P
0 g
s
.50733 .63032 m .5015 .59441 L .50366 .60458 L p .708 .578 .707 r
F P
0 g
s
.49635 .5215 m .50177 .57618 L .4895 .56824 L p .707 .577 .707 r
F P
0 g
s
.4895 .56824 m .48407 .51357 L .49635 .5215 L p .707 .577 .707 r
F P
0 g
s
.30246 .62771 m .30828 .66362 L .31044 .67379 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30341 .53436 m .30883 .58904 L .3015 .59923 L p .707 .577 .707 r
F P
0 g
s
.51039 .66385 m .51348 .68176 L .51194 .67145 L p .706 .577 .707 r
F P
0 g
s
.51194 .67145 m .50885 .65353 L .51039 .66385 L p .706 .577 .707 r
F P
0 g
s
.3145 .71556 m .31141 .69764 L .30987 .68732 L p .706 .577 .707 r
F P
0 g
s
.30987 .68732 m .31296 .70524 L .3145 .71556 L p .706 .577 .707 r
F P
0 g
s
.30828 .66362 m .30246 .62771 L .31015 .61641 L p .707 .577 .707 r
F P
0 g
s
.30883 .58904 m .30341 .53436 L .31995 .52451 L p .707 .577 .707 r
F P
0 g
s
.5015 .59441 m .50733 .63032 L .49554 .62228 L p .707 .577 .707 r
F P
0 g
s
.49554 .62228 m .48971 .58637 L .5015 .59441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48407 .51357 m .4895 .56824 L .46875 .56268 L p .707 .577 .707 r
F P
0 g
s
.46875 .56268 m .46333 .508 L .48407 .51357 L p .707 .577 .707 r
F P
0 g
s
.31015 .61641 m .31598 .65232 L .30828 .66362 L p .707 .577 .707 r
F P
0 g
s
.31995 .52451 m .32538 .57918 L .30883 .58904 L p .707 .577 .707 r
F P
0 g
s
.50885 .65353 m .51194 .67145 L .50073 .66329 L p .707 .577 .707 r
F P
0 g
s
.50073 .66329 m .49764 .64537 L .50885 .65353 L p .707 .577 .707 r
F P
0 g
s
.31296 .70524 m .30987 .68732 L .31814 .67586 L p .707 .577 .707 r
F P
0 g
s
.32538 .57918 m .31995 .52451 L .34408 .51595 L p .707 .577 .707 r
F P
0 g
s
.31814 .67586 m .32123 .69377 L .31296 .70524 L p .707 .577 .707 r
F P
0 g
s
.31598 .65232 m .31015 .61641 L .32694 .60508 L p .707 .577 .707 r
F P
0 g
s
.48971 .58637 m .49554 .62228 L .47526 .61715 L p .707 .577 .707 r
F P
0 g
s
.47526 .61715 m .46944 .58124 L .48971 .58637 L p .707 .577 .707 r
F P
0 g
s
.46333 .508 m .46875 .56268 L .44156 .56003 L p .707 .577 .707 r
F P
0 g
s
.44156 .56003 m .43614 .50535 L .46333 .508 L p .707 .577 .707 r
F P
0 g
s
.32694 .60508 m .33276 .64099 L .31598 .65232 L p .707 .577 .707 r
F P
0 g
s
.34408 .51595 m .34951 .57063 L .32538 .57918 L p .707 .577 .707 r
F P
0 g
s
.34951 .57063 m .34408 .51595 L .37345 .50953 L p .707 .577 .707 r
F P
0 g
s
.49764 .64537 m .50073 .66329 L .48096 .65809 L p .707 .577 .707 r
F P
0 g
s
.48096 .65809 m .47787 .64017 L .49764 .64537 L p .707 .577 .707 r
F P
0 g
s
.32123 .69377 m .31814 .67586 L .33542 .66436 L p .707 .577 .707 r
F P
0 g
s
.43614 .50535 m .44156 .56003 L .41059 .56056 L p .707 .577 .707 r
F P
0 g
s
.41059 .56056 m .40517 .50588 L .43614 .50535 L p .707 .577 .707 r
F P
0 g
s
.33276 .64099 m .32694 .60508 L .35118 .59484 L p .707 .577 .707 r
F P
0 g
s
.46944 .58124 m .47526 .61715 L .44849 .61544 L p .707 .577 .707 r
F P
0 g
s
.44849 .61544 m .44267 .57953 L .46944 .58124 L p .707 .577 .707 r
F P
0 g
s
.33542 .66436 m .3385 .68228 L .32123 .69377 L p .707 .577 .707 r
F P
0 g
s
.37887 .56421 m .37345 .50953 L .40517 .50588 L p .707 .577 .707 r
F P
0 g
s
.37345 .50953 m .37887 .56421 L .34951 .57063 L p .707 .577 .707 r
F P
0 g
s
.40517 .50588 m .41059 .56056 L .37887 .56421 L p .707 .577 .707 r
F P
0 g
s
.35118 .59484 m .357 .63075 L .33276 .64099 L p .707 .577 .707 r
F P
0 g
s
.357 .63075 m .35118 .59484 L .3805 .58668 L p .707 .577 .707 r
F P
0 g
s
.44267 .57953 m .44849 .61544 L .41785 .61731 L p .707 .577 .707 r
F P
0 g
s
.41785 .61731 m .41202 .5814 L .44267 .57953 L p .707 .577 .707 r
F P
0 g
s
.47787 .64017 m .48096 .65809 L .45455 .65635 L p .707 .577 .707 r
F P
0 g
s
.45455 .65635 m .45147 .63844 L .47787 .64017 L p .707 .577 .707 r
F P
0 g
s
.3385 .68228 m .33542 .66436 L .36001 .65397 L p .707 .577 .707 r
F P
0 g
s
.36001 .65397 m .36309 .67189 L .3385 .68228 L p .707 .577 .707 r
F P
0 g
s
.38632 .62259 m .3805 .58668 L .41202 .5814 L p .707 .577 .707 r
F P
0 g
s
.3805 .58668 m .38632 .62259 L .357 .63075 L p .707 .577 .707 r
F P
0 g
s
.41202 .5814 m .41785 .61731 L .38632 .62259 L p .707 .577 .707 r
F P
0 g
s
.45147 .63844 m .45455 .65635 L .4241 .65825 L p .707 .577 .707 r
F P
0 g
s
.4241 .65825 m .42102 .64034 L .45147 .63844 L p .707 .577 .707 r
F P
0 g
s
.36309 .67189 m .36001 .65397 L .3895 .64569 L p .707 .577 .707 r
F P
0 g
s
.3895 .64569 m .39259 .66361 L .36309 .67189 L p .707 .577 .707 r
F P
0 g
s
.42102 .64034 m .4241 .65825 L .39259 .66361 L p .707 .577 .707 r
F P
0 g
s
.39259 .66361 m .3895 .64569 L .42102 .64034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Q7oo6000PGoo001hOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001hOol0075oo`L000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007=oo`00Kgoo0P00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1000Kgoo001/Ool30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUH00000KGoo001ZOol20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00Jgoo001Y
Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2001YOol006Moo`800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP80
06Qoo`00IWoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Moo`00IWoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYF001VOol006Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol0
06Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol006Eoo`8000=JEP03
001JEUYF009JEQ0000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol006Eoo`800003FUH0000000D000AJEP03001JEUYF00EJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001TOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUH0000200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001POol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
IWoo001NOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP00IWoo001LOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP020008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUIJEP00IWoo001JOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00F7oo0`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000QJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF001VOol005Ioo`80009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP00IWoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00EGoo0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH006Ioo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEUYF001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP004Goo8000=Goo001DOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJ
EP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUH000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
035oo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPT0009JEPL000AJEPP0
00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01@000eYF
1`000UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=oo`@000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005Ao
o`04001JEUYF0004FUH00`00FUIJEP03FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP03001JEP0000<0
00AJEP03001JEUYF00EJEP@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00L000IJEP03001JEUYF009JEP04001JEP000006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001EOol00`00FUH00002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP090003FUH01000FUIJEUYF20000eYF00@005YFFUH000IJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool005Eoo`03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF0006FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo001EOol01000FUH000001EYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
?goo4@001Goo0P000UYF00<005YFFUH00UYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP03001JEUYF00=JEP03
001JEUYF00<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
009JEP03001JEUYF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000a
Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00
FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001J
EP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H0
05YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01000FUIJEUYF0P00
;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF5P000UYF
00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000eYF0P00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
00000eYF0000000500000eYF001JEP0:FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000=JEP03001JEP0000<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000QJEP03001J
EUYF00UJEP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010000eYF10002UYF00<005YFFUH01eYF0P00
15YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001J
EUYF00AJEP@0009JEP04001JEUYFFUH5000:FUH00`00FUIJEP05FUH200000eYF001JEP03FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH0000000=JEP04001JEUYFFUH5000:FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02
FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009J
EP03001JEP000080009JEP8000=JEP04001JEUYFFUH50009FUH80004FUH00`00FUIJEP02FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP800003FUH0
05YF009JEP8000=JEP03001JEUYF009JEPd000AJEP04001JEUYFFUH60003FUH01000FUIJEP001EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF7@00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020003
FUH01000FUIJEUYF0P000eYF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH01P001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009o
o`@000=JEP03001JEUYF00EJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008002eoo`00;7oo00<005YF000015YF00<005YFFUH00UYF600015YF00<005YF0000
0UYF1@000eYF00@005YFFUIJEP80009JEP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000Eoo``000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP000080011oo`<000Eo
o`L0009JEP03001JEUYF009JEP/000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEP00FUH02@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00<005YF000015YF0P0000AJ
EP00000000ioo`D000Yoo`<00003FUH005YF00=JEP04001JEUYFFUH200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002eoo`00;7oo00<005YF00000UYF0P0015YF00<005YF00000`002Woo1@002goo0P00
00=JEP00FUH00eYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001J
EUYF00H000=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005
FUH00`00FUIJEP03FUH60004Ool50009Ool30002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF000000020002FUH00`00FUIJEP02
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYF000]Ool002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEP0001/0
009JEP800003FUH005YF009JEP8000MJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP04FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
02aoo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0002FUH01000FUH005YF0P0000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002aoo`00;7oo0P000UYF00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P000UYF00D005YFFUIJEP0000IJEP<000QJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ao
o`00;7oo00@005YFFUIJEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30005FUH01000FUIJEUYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00;7oo
00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001EYF00@005YF000000AJEP03001JEUYF00AJEP<000IJEPH000]JEP03
001JEUYF00<0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00UYF70000UYF
00<007ooOol0:Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20005FUH20006FUH00`00FUIJEP03FUH500000eYF
000000020005FUH00`00FUIJEP09FUH30002FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPT0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH0009JEQH000UJEP03001JEUYF00QJEP8000EJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;7oo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030003FUH00`00FUIJEP030003FUH01000FUIJEUYF1@002UYF00<005YFFUH01UYF
0P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YFFUH0009JEP03001JEUYF00D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0P0015YF0P0000AJEP00000000=JEP03001JEUYF009JEP@000YJEP03001JEUYF00AJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYF001JEP040004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH4000aOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000005FUH00`00FUH000030003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH01000FUIJEUYF0`001UYF00<005YFFUH00P001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Goo000/Ool20004FUH00`00FUIJEP03FUH70007FUH90004FUH00`00FUIJEP02FUH40005FUH00`00
FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH400000eYF001JEP06FUH30009FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000iOol002aoo`8000AJ
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP04FUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF2`0015YF
00<005YFFUH00UYF8P00;Woo000/Ool20004FUH2000017oo000000001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000IJEP00001JEP00FUH300000eYF001JEP02FUH20003FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00eYF00<0
05YF00003@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ao
o`00;7oo0P000UYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0`0000=JEP00FUH00eYF50001UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0002FUH50004FUH80003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo
000[Ool00`00FUH00002000<Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH002aoo`00:goo00<005YF00000P004goo4P001Goo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010001eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEP<0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF000/Ool002]oo`8000=JEP03001oogoo00]ooa0000ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP03001JEUYF008002]oo`00:goo
0P000eYF0`001Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0100037oo0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH00UYF5@000eYF00<005YFFUH015YF2@00:goo000[Ool20003FUH00`00FUIJEP05
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;OolD0008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP03FUH01000FUIJEUYF500015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YF000002]oo`00:goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000<000Qoo`03001JEP00008000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH005YF009JEPD000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00:goo0P000eYF0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo0P00
00=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH0
0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF1000<Goo000[Ool200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006
FUH00`00FUIJEP05FUH50003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000/Ool20004FUH00`00FUIJEP03FUH:000;Ool40002FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04
FUHE0009FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>000iOol002aoo`8000AJEP03001JEP00
00<000EJEP03001JEUYF009JEPT000Ioo`@000IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
00<005YFFUH01EYF00<005YFFUH01UYF2@0000=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEQd004Moo`00;7oo0P0015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YFFUH0
0eYF00@005YF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00H000YJEP03001JEUYF00YJEP03
001JEUYF00UJEPL000MJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH2001IOol0
02]oo`03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP@000EJEPH000=JEP03001JEUYF00AJEP@000AJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD0009JEP03001JEUYF00AJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUH0001HOol002]oo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH00`00FUH000030003
FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH50005FUH01000FUIJEP0015YF00<005YFFUH00eYF00D005YFFUIJEP0005Moo`00:goo
00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P000eYF
00@005YFFUH000AJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol002]oo`8000Eoo`04001JEUYF
0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH3
0003FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH200001EYF001JEUYF000015YF00<005YFFUH00eYF00@005YF
FUIJEP8005Ioo`00:goo0P001Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00H005YFFUH005YF001FOol002]oo`8000Qoo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEPD0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00H005YFFUH005YF001F
Ool002]oo`03001JEP0000Uoo`@0009JEP03001JEUYF00EJEP03001JEP0000@000=JEP03001JEUYF
00EJEP03001JEUYF00=JEP8000=oo`D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF001JEP05FUH00`00FUIJEP02001GOol002]oo`04001JEUYF000<Ool60004FUH00`00FUH0
00040003FUH00`00FUIJEP05FUH00`00FUH000030007Ool300000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUIJEUYF0P00Egoo000[Ool01@00FUIJEUYF
00004Goo2`000eYF00<005YFFUH00UYF1@002Woo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF0`0000=JEP00FUH00UYF0P00Egoo000[Ool01000FUIJEUYF0`005Woo
30003goo0`000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF0`000UYF
00<005YF0000Egoo000/Ool01000FUIJEP000UYF0P00;Woo00L005YF001oo`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0300000eYF001oo`1FOol002aoo`03001J
EP0000EJEP8002Yoo`<00006FUH007oo001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0006FUH00`00FUIJEP02FUH2001HOol002eoo`8000EJEP04001JEP00000VOol20002FUH20003Ool2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00F7oo
000^Ool00`00FUIJEP03FUH01000FUIJEUYF0`008Goo0P0015YF0P0017oo0P001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0`0000=JEP0000000P001EYF00L005YFFUIJEP00FUH0001HOol002moo`8000=JEP03001JEUYF
00AJEPH001Moo`@00003FUH005YF00=JEP03001oogoo00Eoo`8000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP800003
FUH005YF00AJEP<00003FUH005YF00=JEP8005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
0UYF2@002Goo1@001EYF00<005YFFUH00UYF00<007ooOol01goo0P0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH010000UYF00<0
05YFFUH01EYF00<005YF00000P0000AJEP00000005Yoo`00<goo0`001UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0037oo10001eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF2@000UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P00G7oo000fOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH3000BOol50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP060002Ool50002Ool40006FUH00`00FUIJEP03FUH3001JOol003Qoo`<00003FUH005YF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP8001Uoo`P000IJEP03001JEUYF
00YJEP03001JEUYF00AJEPP000Qoo`D000Ioo`@0009JEP03001JEUYF00=JEP04001JEUYF001IOol0
03]oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<002=ooaX00003FUH00000
008000]oo`D000Yoo`@000=JEP05001JEUYFFUH0001IOol0041oo`T000AJEP03001JEUYF009JEPH0
03Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00@000Qoo`<000moo`800003FUH005YF009JEP80
05Qoo`00BGoo2@00?Woo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`005Goo0P000UYF00<005YF
0000F7oo002BOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool8000015YF001JEP00
F7oo002EOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YF
FUH00UYF0`00FGoo002IOol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001IOol009eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00FGoo002QOol70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1P00FUIJEUYF001JEP8005Uoo`00Z7oo2@0015YF00<005YFFUH015YF00<005YFFUH00`00Fgoo002a
Ool>001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]3\[InvisibleSpace]"     "\
\[InvisibleSpace]2.258504055131208`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 3, "     ", 2.2585040551312079, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59389 .73986 m .59607 .6831 L .56491 .6807 L p .707 .577 .707 r
F P
0 g
s
.59607 .6831 m .59389 .73986 L .6257 .74053 L p .707 .577 .707 r
F P
0 g
s
.6257 .74053 m .62788 .68377 L .59607 .6831 L p .707 .577 .707 r
F P
0 g
s
.62788 .68377 m .6257 .74053 L .65503 .7394 L p .707 .577 .707 r
F P
0 g
s
.65503 .7394 m .65722 .68264 L .62788 .68377 L p .707 .577 .707 r
F P
0 g
s
.56273 .73746 m .56491 .6807 L .53744 .67681 L p .707 .577 .707 r
F P
0 g
s
.56491 .6807 m .56273 .73746 L .59389 .73986 L p .707 .577 .707 r
F P
0 g
s
.59183 .7936 m .5942 .75547 L .56305 .75275 L p .707 .577 .707 r
F P
0 g
s
.5942 .75547 m .59183 .7936 L .62359 .79519 L p .707 .577 .707 r
F P
0 g
s
.62359 .79519 m .62596 .75706 L .5942 .75547 L p .707 .577 .707 r
F P
0 g
s
.65722 .68264 m .65503 .7394 L .67903 .73658 L p .707 .577 .707 r
F P
0 g
s
.67903 .73658 m .68122 .67983 L .65722 .68264 L p .707 .577 .707 r
F P
0 g
s
.53744 .67681 m .53526 .73356 L .56273 .73746 L p .707 .577 .707 r
F P
0 g
s
.62596 .75706 m .62359 .79519 L .65286 .7955 L p .707 .577 .707 r
F P
0 g
s
.65286 .7955 m .65522 .75737 L .62596 .75706 L p .707 .577 .707 r
F P
0 g
s
.56305 .75275 m .56068 .79088 L .59183 .7936 L p .707 .577 .707 r
F P
0 g
s
.56068 .79088 m .56305 .75275 L .53557 .74918 L p .707 .577 .707 r
F P
0 g
s
.53526 .73356 m .53744 .67681 L .51636 .6718 L p .707 .577 .707 r
F P
0 g
s
.59024 .83212 m .59156 .81303 L .56042 .81022 L p .707 .577 .707 r
F P
0 g
s
.59156 .81303 m .59024 .83212 L .62198 .83399 L p .707 .577 .707 r
F P
0 g
s
.62198 .83399 m .6233 .81489 L .59156 .81303 L p .707 .577 .707 r
F P
0 g
s
.56042 .81022 m .5591 .82931 L .59024 .83212 L p .707 .577 .707 r
F P
0 g
s
.53557 .74918 m .5332 .78731 L .56068 .79088 L p .707 .577 .707 r
F P
0 g
s
.6233 .81489 m .62198 .83399 L .65122 .83472 L p .707 .577 .707 r
F P
0 g
s
.65122 .83472 m .65254 .81563 L .6233 .81489 L p .707 .577 .707 r
F P
0 g
s
.5591 .82931 m .56042 .81022 L .53293 .80673 L p .707 .577 .707 r
F P
0 g
s
.65522 .75737 m .65286 .7955 L .67676 .79449 L p .707 .577 .707 r
F P
0 g
s
.67676 .79449 m .67913 .75636 L .65522 .75737 L p .707 .577 .707 r
F P
0 g
s
.51636 .6718 m .51417 .72856 L .53526 .73356 L p .707 .577 .707 r
F P
0 g
s
.53293 .80673 m .53161 .82583 L .5591 .82931 L p .707 .577 .707 r
F P
0 g
s
.68122 .67983 m .67903 .73658 L .69534 .73236 L p .707 .577 .707 r
F P
0 g
s
.69534 .73236 m .69753 .6756 L .68122 .67983 L p .707 .577 .707 r
F P
0 g
s
.5332 .78731 m .53557 .74918 L .51444 .74509 L p .707 .577 .707 r
F P
0 g
s
.65254 .81563 m .65122 .83472 L .67509 .83426 L p .707 .577 .707 r
F P
0 g
s
.67509 .83426 m .67641 .81517 L .65254 .81563 L p .707 .577 .707 r
F P
0 g
s
.51444 .74509 m .51207 .78322 L .5332 .78731 L p .707 .577 .707 r
F P
0 g
s
.51417 .72856 m .51636 .6718 L .50372 .66616 L p .707 .577 .707 r
F P
0 g
s
.53161 .82583 m .53293 .80673 L .51178 .80292 L p .707 .577 .707 r
F P
0 g
s
.51178 .80292 m .51046 .82202 L .53161 .82583 L p .707 .577 .707 r
F P
0 g
s
.67913 .75636 m .67676 .79449 L .69297 .79227 L p .707 .577 .707 r
F P
0 g
s
.69297 .79227 m .69534 .75414 L .67913 .75636 L p .707 .577 .707 r
F P
0 g
s
.50372 .66616 m .50154 .72292 L .51417 .72856 L p .707 .577 .707 r
F P
0 g
s
.51207 .78322 m .51444 .74509 L .50173 .74089 L p .707 .577 .707 r
F P
0 g
s
.67641 .81517 m .67509 .83426 L .69126 .83264 L p .707 .577 .707 r
F P
0 g
s
.69126 .83264 m .69258 .81355 L .67641 .81517 L p .707 .577 .707 r
F P
0 g
s
.69753 .6756 m .69534 .73236 L .70236 .72714 L p .707 .577 .707 r
F P
0 g
s
.70236 .72714 m .70455 .67038 L .69753 .6756 L p .707 .577 .707 r
F P
0 g
s
.50173 .74089 m .49936 .77902 L .51207 .78322 L p .707 .577 .707 r
F P
0 g
s
.51046 .82202 m .51178 .80292 L .49904 .79916 L p .707 .577 .707 r
F P
0 g
s
.49904 .79916 m .49772 .81825 L .51046 .82202 L p .707 .577 .707 r
F P
0 g
s
.50154 .72292 m .50372 .66616 L .50077 .66046 L p .707 .577 .707 r
F P
0 g
s
.69534 .75414 m .69297 .79227 L .69989 .78906 L p .707 .577 .707 r
F P
0 g
s
.69989 .78906 m .70226 .75093 L .69534 .75414 L p .707 .577 .707 r
F P
0 g
s
.50077 .66046 m .49859 .71722 L .50154 .72292 L p .707 .577 .707 r
F P
0 g
s
.69258 .81355 m .69126 .83264 L .69814 .83003 L p .707 .577 .707 r
F P
0 g
s
.69814 .83003 m .69946 .81094 L .69258 .81355 L p .707 .577 .707 r
F P
0 g
s
.49936 .77902 m .50173 .74089 L .49869 .73699 L p .707 .577 .707 r
F P
0 g
s
.70455 .67038 m .70236 .72714 L .69941 .72144 L p .707 .577 .707 r
F P
0 g
s
.69941 .72144 m .7016 .66468 L .70455 .67038 L p .707 .577 .707 r
F P
0 g
s
.49869 .73699 m .49632 .77512 L .49936 .77902 L p .707 .577 .707 r
F P
0 g
s
.49772 .81825 m .49904 .79916 L .49596 .7958 L p .707 .577 .707 r
F P
0 g
s
.49596 .7958 m .49465 .81489 L .49772 .81825 L p .707 .577 .707 r
F P
0 g
s
.49859 .71722 m .50077 .66046 L .50779 .65524 L p .707 .577 .707 r
F P
0 g
s
.70226 .75093 m .69989 .78906 L .69685 .78516 L p .707 .577 .707 r
F P
0 g
s
.69685 .78516 m .69922 .74703 L .70226 .75093 L p .707 .577 .707 r
F P
0 g
s
.50779 .65524 m .50561 .712 L .49859 .71722 L p .707 .577 .707 r
F P
0 g
s
.69946 .81094 m .69814 .83003 L .69506 .82667 L p .707 .577 .707 r
F P
0 g
s
.69506 .82667 m .69638 .80758 L .69946 .81094 L p .707 .577 .707 r
F P
0 g
s
.49632 .77512 m .49869 .73699 L .50561 .73378 L p .707 .577 .707 r
F P
0 g
s
.48023 .8138 m .50009 .30124 L .45609 .29785 L p .707 .577 .707 r
F P
0 g
s
.50561 .73378 m .50324 .77191 L .49632 .77512 L p .707 .577 .707 r
F P
0 g
s
.49465 .81489 m .49596 .7958 L .50285 .79319 L p .707 .577 .707 r
F P
0 g
s
.50285 .79319 m .50153 .81228 L .49465 .81489 L p .707 .577 .707 r
F P
0 g
s
.50561 .712 m .50779 .65524 L .5241 .65102 L p .707 .577 .707 r
F P
0 g
s
.5241 .65102 m .52192 .70777 L .50561 .712 L p .707 .577 .707 r
F P
0 g
s
.50324 .77191 m .50561 .73378 L .52181 .73156 L p .707 .577 .707 r
F P
0 g
s
.52181 .73156 m .51945 .76969 L .50324 .77191 L p .707 .577 .707 r
F P
0 g
s
.50153 .81228 m .50285 .79319 L .51901 .79157 L p .707 .577 .707 r
F P
0 g
s
.51901 .79157 m .51769 .81066 L .50153 .81228 L p .707 .577 .707 r
F P
0 g
s
.51945 .76969 m .52181 .73156 L .54572 .73056 L p .707 .577 .707 r
F P
0 g
s
.54572 .73056 m .54335 .76869 L .51945 .76969 L p .707 .577 .707 r
F P
0 g
s
.51769 .81066 m .51901 .79157 L .54288 .79111 L p .707 .577 .707 r
F P
0 g
s
.54288 .79111 m .54157 .8102 L .51769 .81066 L p .707 .577 .707 r
F P
0 g
s
.50009 .30124 m .48023 .8138 L .52514 .81475 L p .707 .577 .707 r
F P
0 g
s
.52192 .70777 m .5241 .65102 L .5481 .6482 L p .707 .577 .707 r
F P
0 g
s
.5481 .6482 m .54591 .70496 L .52192 .70777 L p .707 .577 .707 r
F P
0 g
s
.52514 .81475 m .54499 .3022 L .50009 .30124 L p .707 .577 .707 r
F P
0 g
s
.7016 .66468 m .69941 .72144 L .68677 .7158 L p .707 .577 .707 r
F P
0 g
s
.68677 .7158 m .68896 .65904 L .7016 .66468 L p .707 .577 .707 r
F P
0 g
s
.54591 .70496 m .5481 .6482 L .57744 .64707 L p .707 .577 .707 r
F P
0 g
s
.57744 .64707 m .57525 .70383 L .54591 .70496 L p .707 .577 .707 r
F P
0 g
s
.54335 .76869 m .54555 .73329 L p .57499 .73086 L .707 .577 .707 r
F P
0 g
s
.54555 .73329 m .54572 .73056 L .54596 .73056 L p .707 .577 .707 r
F P
0 g
s
.54596 .73056 m .57499 .73086 L p .54555 .73329 L .707 .577 .707 r
F P
0 g
s
.57525 .70383 m .57744 .64707 L .60925 .64774 L p .707 .577 .707 r
F P
0 g
s
.60925 .64774 m .60706 .7045 L .57525 .70383 L p .707 .577 .707 r
F P
0 g
s
.57499 .73086 m .57262 .76899 L .54335 .76869 L p .707 .577 .707 r
F P
0 g
s
.54157 .8102 m .54288 .79111 L .57212 .79184 L p .707 .577 .707 r
F P
0 g
s
.57212 .79184 m .5708 .81094 L .54157 .8102 L p .707 .577 .707 r
F P
0 g
s
.57262 .76899 m .57499 .73086 L .60675 .73245 L p .707 .577 .707 r
F P
0 g
s
.60675 .73245 m .60438 .77058 L .57262 .76899 L p .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57212 .79184 L .57817 .7922 L p .707 .577 .707 r
F P
0 g
s
.57817 .7922 m .60386 .79371 L p .57684 .80779 L .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57817 .7922 L .57684 .80779 L .707 .577 .707 r
F
.64041 .65014 m .63822 .7069 L .60706 .7045 L p F P
0 g
s
.60706 .7045 m .60925 .64774 L .64041 .65014 L p .707 .577 .707 r
F P
0 g
s
.63789 .73517 m .63553 .7733 L .60438 .77058 L p .707 .577 .707 r
F P
0 g
s
.60438 .77058 m .60675 .73245 L .63789 .73517 L p .707 .577 .707 r
F P
0 g
s
.63501 .79652 m .63369 .81561 L .60255 .8128 L p .707 .577 .707 r
F P
0 g
s
.60255 .8128 m .60386 .79371 L .63501 .79652 L p .707 .577 .707 r
F P
0 g
s
.60386 .79371 m .60255 .8128 L .5708 .81094 L p .707 .577 .707 r
F P
0 g
s
.60044 .80923 m .62346 .80329 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62029 .29667 m .62022 .29825 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62022 .29825 m .60044 .80923 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .60044 .80923 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.58641 .30062 m .57816 .51356 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.57816 .51356 m .56656 .81318 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.54499 .3022 m .52514 .81475 L .56656 .81318 L p .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .58641 .30062 L .54499 .3022 L p .707 .577 .707 r
F P
0 g
s
.25088 .70304 m .25307 .64628 L .2219 .64389 L p .707 .577 .707 r
F P
0 g
s
.25307 .64628 m .25088 .70304 L .28269 .70371 L p .707 .577 .707 r
F P
0 g
s
.28269 .70371 m .28487 .64695 L .25307 .64628 L p .707 .577 .707 r
F P
0 g
s
.43624 .81041 m .45609 .29785 L .41731 .29236 L p .707 .577 .707 r
F P
0 g
s
.45609 .29785 m .43624 .81041 L .48023 .8138 L p .707 .577 .707 r
F P
0 g
s
.28487 .64695 m .28269 .70371 L .31203 .70258 L p .707 .577 .707 r
F P
0 g
s
.31203 .70258 m .31421 .64582 L .28487 .64695 L p .707 .577 .707 r
F P
0 g
s
.21972 .70064 m .2219 .64389 L .19444 .63999 L p .707 .577 .707 r
F P
0 g
s
.2219 .64389 m .21972 .70064 L .25088 .70304 L p .707 .577 .707 r
F P
0 g
s
.69922 .74703 m .69685 .78516 L .68414 .78096 L p .707 .577 .707 r
F P
0 g
s
.68414 .78096 m .68651 .74283 L .69922 .74703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60044 .80923 m .62029 .29667 L .58641 .30062 L p .707 .577 .707 r
F P
0 g
s
.24882 .75679 m .25119 .71865 L .22004 .71594 L p .707 .577 .707 r
F P
0 g
s
.25119 .71865 m .24882 .75679 L .28058 .75837 L p .707 .577 .707 r
F P
0 g
s
.28058 .75837 m .28295 .72024 L .25119 .71865 L p .707 .577 .707 r
F P
0 g
s
.31421 .64582 m .31203 .70258 L .33602 .69977 L p .707 .577 .707 r
F P
0 g
s
.33602 .69977 m .33821 .64301 L .31421 .64582 L p .707 .577 .707 r
F P
0 g
s
.19444 .63999 m .19225 .69675 L .21972 .70064 L p .707 .577 .707 r
F P
0 g
s
.28295 .72024 m .28058 .75837 L .30985 .75868 L p .707 .577 .707 r
F P
0 g
s
.30985 .75868 m .31222 .72055 L .28295 .72024 L p .707 .577 .707 r
F P
0 g
s
.22004 .71594 m .21767 .75407 L .24882 .75679 L p .707 .577 .707 r
F P
0 g
s
.69638 .80758 m .69506 .82667 L .68232 .82291 L p .707 .577 .707 r
F P
0 g
s
.68232 .82291 m .68364 .80381 L .69638 .80758 L p .707 .577 .707 r
F P
0 g
s
.21767 .75407 m .22004 .71594 L .19256 .71236 L p .707 .577 .707 r
F P
0 g
s
.68896 .65904 m .68677 .7158 L .66569 .71079 L p .707 .577 .707 r
F P
0 g
s
.66569 .71079 m .66788 .65403 L .68896 .65904 L p .707 .577 .707 r
F P
0 g
s
.19225 .69675 m .19444 .63999 L .17335 .63498 L p .707 .577 .707 r
F P
0 g
s
.39746 .80491 m .41731 .29236 L .38755 .2853 L p .707 .577 .707 r
F P
0 g
s
.41731 .29236 m .39746 .80491 L .43624 .81041 L p .707 .577 .707 r
F P
0 g
s
.24723 .7953 m .24855 .77621 L .21741 .7734 L p .707 .577 .707 r
F P
0 g
s
.24855 .77621 m .24723 .7953 L .27897 .79717 L p .707 .577 .707 r
F P
0 g
s
.27897 .79717 m .28029 .77808 L .24855 .77621 L p .707 .577 .707 r
F P
0 g
s
.21741 .7734 m .21609 .79249 L .24723 .7953 L p .707 .577 .707 r
F P
0 g
s
.19256 .71236 m .19019 .75049 L .21767 .75407 L p .707 .577 .707 r
F P
0 g
s
.28029 .77808 m .27897 .79717 L .30821 .79791 L p .707 .577 .707 r
F P
0 g
s
.30821 .79791 m .30953 .77881 L .28029 .77808 L p .707 .577 .707 r
F P
0 g
s
.21609 .79249 m .21741 .7734 L .18992 .76992 L p .707 .577 .707 r
F P
0 g
s
.31222 .72055 m .30985 .75868 L .33376 .75768 L p .707 .577 .707 r
F P
0 g
s
.33376 .75768 m .33612 .71955 L .31222 .72055 L p .707 .577 .707 r
F P
0 g
s
.17335 .63498 m .17117 .69174 L .19225 .69675 L p .707 .577 .707 r
F P
0 g
s
.18992 .76992 m .1886 .78901 L .21609 .79249 L p .707 .577 .707 r
F P
0 g
s
.33821 .64301 m .33602 .69977 L .35233 .69555 L p .707 .577 .707 r
F P
0 g
s
.35233 .69555 m .35452 .63879 L .33821 .64301 L p .707 .577 .707 r
F P
0 g
s
.19019 .75049 m .19256 .71236 L .17143 .70827 L p .707 .577 .707 r
F P
0 g
s
.68651 .74283 m .68414 .78096 L .66301 .77688 L p .707 .577 .707 r
F P
0 g
s
.66301 .77688 m .66538 .73874 L .68651 .74283 L p .707 .577 .707 r
F P
0 g
s
.30953 .77881 m .30821 .79791 L .33208 .79745 L p .707 .577 .707 r
F P
0 g
s
.33208 .79745 m .3334 .77835 L .30953 .77881 L p .707 .577 .707 r
F P
0 g
s
.17143 .70827 m .16906 .7464 L .19019 .75049 L p .707 .577 .707 r
F P
0 g
s
.62346 .80329 m .64331 .29074 L .62029 .29667 L p .707 .577 .707 r
F P
0 g
s
.66788 .65403 m .66569 .71079 L .63822 .7069 L p .707 .577 .707 r
F P
0 g
s
.63822 .7069 m .64041 .65014 L .66788 .65403 L p .707 .577 .707 r
F P
0 g
s
.17117 .69174 m .17335 .63498 L .16072 .62935 L p .707 .577 .707 r
F P
0 g
s
.1886 .78901 m .18992 .76992 L .16877 .76611 L p .707 .577 .707 r
F P
0 g
s
.16877 .76611 m .16745 .7852 L .1886 .78901 L p .707 .577 .707 r
F P
0 g
s
.68364 .80381 m .68232 .82291 L .66118 .8191 L p .707 .577 .707 r
F P
0 g
s
.66118 .8191 m .6625 .8 L .68364 .80381 L p .707 .577 .707 r
F P
0 g
s
.33612 .71955 m .33376 .75768 L .34996 .75546 L p .707 .577 .707 r
F P
0 g
s
.34996 .75546 m .35233 .71733 L .33612 .71955 L p .707 .577 .707 r
F P
0 g
s
.16072 .62935 m .15853 .68611 L .17117 .69174 L p .707 .577 .707 r
F P
0 g
s
.3677 .79785 m .38755 .2853 L .36971 .27736 L p .707 .577 .707 r
F P
0 g
s
.38755 .2853 m .3677 .79785 L .39746 .80491 L p .707 .577 .707 r
F P
0 g
s
.16906 .7464 m .17143 .70827 L .15872 .70408 L p .707 .577 .707 r
F P
0 g
s
.3334 .77835 m .33208 .79745 L .34825 .79583 L p .707 .577 .707 r
F P
0 g
s
.34825 .79583 m .34957 .77673 L .3334 .77835 L p .707 .577 .707 r
F P
0 g
s
.66538 .73874 m .66301 .77688 L .63553 .7733 L p .707 .577 .707 r
F P
0 g
s
.63553 .7733 m .63789 .73517 L .66538 .73874 L p .707 .577 .707 r
F P
0 g
s
.35452 .63879 m .35233 .69555 L .35935 .69033 L p .707 .577 .707 r
F P
0 g
s
.35935 .69033 m .36154 .63357 L .35452 .63879 L p .707 .577 .707 r
F P
0 g
s
.15872 .70408 m .15635 .74221 L .16906 .7464 L p .707 .577 .707 r
F P
0 g
s
.16745 .7852 m .16877 .76611 L .15603 .76234 L p .707 .577 .707 r
F P
0 g
s
.15603 .76234 m .15471 .78143 L .16745 .7852 L p .707 .577 .707 r
F P
0 g
s
.6625 .8 m .66118 .8191 L .63369 .81561 L p .707 .577 .707 r
F P
0 g
s
.63369 .81561 m .63501 .79652 L .6625 .8 L p .707 .577 .707 r
F P
0 g
s
.15853 .68611 m .16072 .62935 L .15776 .62364 L p .707 .577 .707 r
F P
0 g
s
.35233 .71733 m .34996 .75546 L .35688 .75224 L p .707 .577 .707 r
F P
0 g
s
.35688 .75224 m .35925 .71411 L .35233 .71733 L p .707 .577 .707 r
F P
0 g
s
.64331 .29074 m .62346 .80329 L .63337 .79595 L p .707 .577 .707 r
F P
0 g
s
.63337 .79595 m .65322 .28339 L .64331 .29074 L p .707 .577 .707 r
F P
0 g
s
.15776 .62364 m .15558 .6804 L .15853 .68611 L p .707 .577 .707 r
F P
0 g
s
.34957 .77673 m .34825 .79583 L .35513 .79321 L p .707 .577 .707 r
F P
0 g
s
.35513 .79321 m .35645 .77412 L .34957 .77673 L p .707 .577 .707 r
F P
0 g
s
.15635 .74221 m .15872 .70408 L .15568 .70018 L p .707 .577 .707 r
F P
0 g
s
.36154 .63357 m .35935 .69033 L .3564 .68462 L p .707 .577 .707 r
F P
0 g
s
.3564 .68462 m .35859 .62786 L .36154 .63357 L p .707 .577 .707 r
F P
0 g
s
.15568 .70018 m .15331 .73831 L .15635 .74221 L p .707 .577 .707 r
F P
0 g
s
.35859 .62786 m .3564 .68462 L .34376 .67899 L p .707 .577 .707 r
F P
0 g
s
.34376 .67899 m .34595 .62223 L .35859 .62786 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .34113 .74415 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35621 .71021 m .35604 .71295 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35604 .71295 m .35384 .74835 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.34113 .74415 m .3435 .70602 L .35621 .71021 L p .707 .577 .707 r
F P
0 g
s
.35337 .77077 m .35205 .78986 L .33932 .78609 L p .707 .577 .707 r
F P
0 g
s
.33932 .78609 m .34063 .767 L .35337 .77077 L p .707 .577 .707 r
F P
0 g
s
.34986 .78992 m .36146 .4903 L p .36554 .26933 L .707 .577 .707 r
F P
0 g
s
.36146 .4903 m .36971 .27736 L .36678 .27173 L p .707 .577 .707 r
F P
0 g
s
.36678 .27173 m .36554 .26933 L p .36146 .4903 L .707 .577 .707 r
F P
0 g
s
.35925 .71411 m .35688 .75224 L .35384 .74835 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .35621 .71021 L .35925 .71411 L p .707 .577 .707 r
F P
0 g
s
.35645 .77412 m .35513 .79321 L .35205 .78986 L p .707 .577 .707 r
F P
0 g
s
.35205 .78986 m .35337 .77077 L .35645 .77412 L p .707 .577 .707 r
F P
0 g
s
.36971 .27736 m .34986 .78992 L .3677 .79785 L p .707 .577 .707 r
F P
0 g
s
.15471 .78143 m .15603 .76234 L .15295 .75898 L p .707 .577 .707 r
F P
0 g
s
.15295 .75898 m .15164 .77808 L .15471 .78143 L p .707 .577 .707 r
F P
0 g
s
.15558 .6804 m .15776 .62364 L .16479 .61842 L p .707 .577 .707 r
F P
0 g
s
.16479 .61842 m .1626 .67518 L .15558 .6804 L p .707 .577 .707 r
F P
0 g
s
.15331 .73831 m .15568 .70018 L .1626 .69696 L p .707 .577 .707 r
F P
0 g
s
.65322 .28339 m .63337 .79595 L .6292 .78791 L p .707 .577 .707 r
F P
0 g
s
.6292 .78791 m .64905 .27536 L .65322 .28339 L p .707 .577 .707 r
F P
0 g
s
.1626 .69696 m .16023 .73509 L .15331 .73831 L p .707 .577 .707 r
F P
0 g
s
.15164 .77808 m .15295 .75898 L .15984 .75637 L p .707 .577 .707 r
F P
0 g
s
.15984 .75637 m .15852 .77546 L .15164 .77808 L p .707 .577 .707 r
F P
0 g
s
.1626 .67518 m .16479 .61842 L .18109 .6142 L p .707 .577 .707 r
F P
0 g
s
.36554 .26933 m .34569 .78189 L .34986 .78992 L p .707 .577 .707 r
F P
0 g
s
.34569 .78189 m .36554 .26933 L .37545 .26199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18109 .6142 m .17891 .67096 L .1626 .67518 L p .707 .577 .707 r
F P
0 g
s
.16023 .73509 m .1626 .69696 L .1788 .69474 L p .707 .577 .707 r
F P
0 g
s
.34595 .62223 m .34376 .67899 L .32268 .67398 L p .707 .577 .707 r
F P
0 g
s
.32268 .67398 m .32487 .61722 L .34595 .62223 L p .707 .577 .707 r
F P
0 g
s
.1788 .69474 m .17644 .73288 L .16023 .73509 L p .707 .577 .707 r
F P
0 g
s
.15852 .77546 m .15984 .75637 L .176 .75475 L p .707 .577 .707 r
F P
0 g
s
.17891 .67096 m .18109 .6142 L .20509 .61139 L p .707 .577 .707 r
F P
0 g
s
.176 .75475 m .17468 .77385 L .15852 .77546 L p .707 .577 .707 r
F P
0 g
s
.64905 .27536 m .6292 .78791 L .61136 .77998 L p .707 .577 .707 r
F P
0 g
s
.61136 .77998 m .63121 .26742 L .64905 .27536 L p .707 .577 .707 r
F P
0 g
s
.3435 .70602 m .34113 .74415 L .32 .74006 L p .707 .577 .707 r
F P
0 g
s
.32 .74006 m .32237 .70193 L .3435 .70602 L p .707 .577 .707 r
F P
0 g
s
.20509 .61139 m .2029 .66815 L .17891 .67096 L p .707 .577 .707 r
F P
0 g
s
.32487 .61722 m .32268 .67398 L .29521 .67008 L p .707 .577 .707 r
F P
0 g
s
.29521 .67008 m .2974 .61333 L .32487 .61722 L p .707 .577 .707 r
F P
0 g
s
.17644 .73288 m .1788 .69474 L .20271 .69374 L p .707 .577 .707 r
F P
0 g
s
.34063 .767 m .33932 .78609 L .31817 .78228 L p .707 .577 .707 r
F P
0 g
s
.31817 .78228 m .31949 .76319 L .34063 .767 L p .707 .577 .707 r
F P
0 g
s
.2029 .66815 m .20509 .61139 L .23443 .61026 L p .707 .577 .707 r
F P
0 g
s
.20271 .69374 m .20034 .73187 L .17644 .73288 L p .707 .577 .707 r
F P
0 g
s
.3556 .77454 m .37545 .26199 L .39847 .25605 L p .707 .577 .707 r
F P
0 g
s
.37545 .26199 m .3556 .77454 L .34569 .78189 L p .707 .577 .707 r
F P
0 g
s
.17468 .77385 m .176 .75475 L .19987 .75429 L p .707 .577 .707 r
F P
0 g
s
.19987 .75429 m .19856 .77338 L .17468 .77385 L p .707 .577 .707 r
F P
0 g
s
.2974 .61333 m .29521 .67008 L .26405 .66769 L p .707 .577 .707 r
F P
0 g
s
.26405 .66769 m .26624 .61093 L .2974 .61333 L p .707 .577 .707 r
F P
0 g
s
.23443 .61026 m .23224 .66702 L .2029 .66815 L p .707 .577 .707 r
F P
0 g
s
.32237 .70193 m .32 .74006 L .29252 .73648 L p .707 .577 .707 r
F P
0 g
s
.29252 .73648 m .29489 .69835 L .32237 .70193 L p .707 .577 .707 r
F P
0 g
s
.23224 .66702 m .23443 .61026 L .26624 .61093 L p .707 .577 .707 r
F P
0 g
s
.73109 .65071 m .73328 .59395 L .70212 .59155 L p .707 .577 .707 r
F P
0 g
s
.73328 .59395 m .73109 .65071 L .7629 .65138 L p .707 .577 .707 r
F P
0 g
s
.7629 .65138 m .76509 .59462 L .73328 .59395 L p .707 .577 .707 r
F P
0 g
s
.26624 .61093 m .26405 .66769 L .23224 .66702 L p .707 .577 .707 r
F P
0 g
s
.20034 .73187 m .20271 .69374 L .23198 .69405 L p .707 .577 .707 r
F P
0 g
s
.76509 .59462 m .7629 .65138 L .79224 .65025 L p .707 .577 .707 r
F P
0 g
s
.79224 .65025 m .79442 .59349 L .76509 .59462 L p .707 .577 .707 r
F P
0 g
s
.31949 .76319 m .31817 .78228 L .29068 .7788 L p .707 .577 .707 r
F P
0 g
s
.29068 .7788 m .292 .75971 L .31949 .76319 L p .707 .577 .707 r
F P
0 g
s
.69993 .64831 m .70212 .59155 L .67465 .58766 L p .707 .577 .707 r
F P
0 g
s
.70212 .59155 m .69993 .64831 L .73109 .65071 L p .707 .577 .707 r
F P
0 g
s
.23198 .69405 m .22961 .73218 L .20034 .73187 L p .707 .577 .707 r
F P
0 g
s
.63121 .26742 m .61136 .77998 L .5816 .77292 L p .707 .577 .707 r
F P
0 g
s
.5816 .77292 m .60145 .26036 L .63121 .26742 L p .707 .577 .707 r
F P
0 g
s
.29489 .69835 m .29252 .73648 L .26137 .73377 L p .707 .577 .707 r
F P
0 g
s
.26137 .73377 m .26374 .69564 L .29489 .69835 L p .707 .577 .707 r
F P
0 g
s
.19856 .77338 m .19987 .75429 L .22911 .75503 L p .707 .577 .707 r
F P
0 g
s
.22911 .75503 m .22779 .77412 L .19856 .77338 L p .707 .577 .707 r
F P
0 g
s
.22961 .73218 m .23198 .69405 L .26374 .69564 L p .707 .577 .707 r
F P
0 g
s
.79442 .59349 m .79224 .65025 L .81624 .64743 L p .707 .577 .707 r
F P
0 g
s
.81624 .64743 m .81842 .59068 L .79442 .59349 L p .707 .577 .707 r
F P
0 g
s
.72903 .70831 m .7314 .67018 L .70026 .66746 L p .707 .577 .707 r
F P
0 g
s
.7314 .67018 m .72903 .70831 L .7608 .7099 L p .707 .577 .707 r
F P
0 g
s
.7608 .7099 m .76316 .67177 L .7314 .67018 L p .707 .577 .707 r
F P
0 g
s
.67465 .58766 m .67246 .64441 L .69993 .64831 L p .707 .577 .707 r
F P
0 g
s
.26374 .69564 m .26137 .73377 L .22961 .73218 L p .707 .577 .707 r
F P
0 g
s
.76316 .67177 m .7608 .7099 L .79006 .7102 L p .707 .577 .707 r
F P
0 g
s
.79006 .7102 m .79243 .67207 L .76316 .67177 L p .707 .577 .707 r
F P
0 g
s
.70026 .66746 m .69789 .70559 L .72903 .70831 L p .707 .577 .707 r
F P
0 g
s
.292 .75971 m .29068 .7788 L .25954 .77599 L p .707 .577 .707 r
F P
0 g
s
.25954 .77599 m .26086 .75689 L .292 .75971 L p .707 .577 .707 r
F P
0 g
s
.67246 .64441 m .67465 .58766 L .65356 .58265 L p .707 .577 .707 r
F P
0 g
s
.69789 .70559 m .70026 .66746 L .67277 .66388 L p .707 .577 .707 r
F P
0 g
s
.39847 .25605 m .37862 .76861 L .3556 .77454 L p .707 .577 .707 r
F P
0 g
s
.37862 .76861 m .39847 .25605 L .43235 .2521 L p .707 .577 .707 r
F P
0 g
s
.22779 .77412 m .22911 .75503 L .26086 .75689 L p .707 .577 .707 r
F P
0 g
s
.72744 .75225 m .72876 .73315 L .69762 .73034 L p .707 .577 .707 r
F P
0 g
s
.72876 .73315 m .72744 .75225 L .75919 .75411 L p .707 .577 .707 r
F P
0 g
s
.75919 .75411 m .7605 .73502 L .72876 .73315 L p .707 .577 .707 r
F P
0 g
s
.26086 .75689 m .25954 .77599 L .22779 .77412 L p .707 .577 .707 r
F P
0 g
s
.67277 .66388 m .6704 .70201 L .69789 .70559 L p .707 .577 .707 r
F P
0 g
s
.69762 .73034 m .6963 .74944 L .72744 .75225 L p .707 .577 .707 r
F P
0 g
s
.7605 .73502 m .75919 .75411 L .78842 .75485 L p .707 .577 .707 r
F P
0 g
s
.78842 .75485 m .78974 .73576 L .7605 .73502 L p .707 .577 .707 r
F P
0 g
s
.79243 .67207 m .79006 .7102 L .81397 .7092 L p .707 .577 .707 r
F P
0 g
s
.81397 .7092 m .81634 .67107 L .79243 .67207 L p .707 .577 .707 r
F P
0 g
s
.65356 .58265 m .65138 .63941 L .67246 .64441 L p .707 .577 .707 r
F P
0 g
s
.6963 .74944 m .69762 .73034 L .67013 .72686 L p .707 .577 .707 r
F P
0 g
s
.67013 .72686 m .66881 .74596 L .6963 .74944 L p .707 .577 .707 r
F P
0 g
s
.81842 .59068 m .81624 .64743 L .83254 .64321 L p .707 .577 .707 r
F P
0 g
s
.83254 .64321 m .83473 .58645 L .81842 .59068 L p .707 .577 .707 r
F P
0 g
s
.6704 .70201 m .67277 .66388 L .65164 .6598 L p .707 .577 .707 r
F P
0 g
s
.78974 .73576 m .78842 .75485 L .8123 .75439 L p .707 .577 .707 r
F P
0 g
s
.8123 .75439 m .81361 .7353 L .78974 .73576 L p .707 .577 .707 r
F P
0 g
s
.65164 .6598 m .64927 .69793 L .6704 .70201 L p .707 .577 .707 r
F P
0 g
s
.60145 .26036 m .5816 .77292 L .54282 .76743 L p .707 .577 .707 r
F P
0 g
s
.54282 .76743 m .56267 .25487 L .60145 .26036 L p .707 .577 .707 r
F P
0 g
s
.65138 .63941 m .65356 .58265 L .64093 .57701 L p .707 .577 .707 r
F P
0 g
s
.66881 .74596 m .67013 .72686 L .64898 .72305 L p .707 .577 .707 r
F P
0 g
s
.64898 .72305 m .64766 .74214 L .66881 .74596 L p .707 .577 .707 r
F P
0 g
s
.81634 .67107 m .81397 .7092 L .83018 .70698 L p .707 .577 .707 r
F P
0 g
s
.83018 .70698 m .83254 .66885 L .81634 .67107 L p .707 .577 .707 r
F P
0 g
s
.4125 .76466 m .43235 .2521 L .47377 .25052 L p .707 .577 .707 r
F P
0 g
s
.43235 .2521 m .4125 .76466 L .37862 .76861 L p .707 .577 .707 r
F P
0 g
s
.64093 .57701 m .63874 .63377 L .65138 .63941 L p .707 .577 .707 r
F P
0 g
s
.64927 .69793 m .65164 .6598 L .63893 .6556 L p .707 .577 .707 r
F P
0 g
s
.83473 .58645 m .83254 .64321 L .83957 .63799 L p .707 .577 .707 r
F P
0 g
s
.83957 .63799 m .84175 .58123 L .83473 .58645 L p .707 .577 .707 r
F P
0 g
s
.81361 .7353 m .8123 .75439 L .82846 .75277 L p .707 .577 .707 r
F P
0 g
s
.82846 .75277 m .82978 .73368 L .81361 .7353 L p .707 .577 .707 r
F P
0 g
s
.63893 .6556 m .63657 .69373 L .64927 .69793 L p .707 .577 .707 r
F P
0 g
s
.56267 .25487 m .54282 .76743 L .49882 .76404 L p .707 .577 .707 r
F P
0 g
s
.49882 .76404 m .51867 .25148 L .56267 .25487 L p .707 .577 .707 r
F P
0 g
s
.45392 .76308 m .47377 .25052 L .51867 .25148 L p .707 .577 .707 r
F P
0 g
s
.47377 .25052 m .45392 .76308 L .4125 .76466 L p .707 .577 .707 r
F P
0 g
s
.64766 .74214 m .64898 .72305 L .63625 .71928 L p .707 .577 .707 r
F P
0 g
s
.63874 .63377 m .64093 .57701 L .63798 .57131 L p .707 .577 .707 r
F P
0 g
s
.63625 .71928 m .63493 .73838 L .64766 .74214 L p .707 .577 .707 r
F P
0 g
s
.51867 .25148 m .49882 .76404 L .45392 .76308 L p .707 .577 .707 r
F P
0 g
s
.83254 .66885 m .83018 .70698 L .8371 .70376 L p .707 .577 .707 r
F P
0 g
s
.8371 .70376 m .83946 .66563 L .83254 .66885 L p .707 .577 .707 r
F P
0 g
s
.63798 .57131 m .63579 .62807 L .63874 .63377 L p .707 .577 .707 r
F P
0 g
s
.63657 .69373 m .63893 .6556 L .63589 .6517 L p .707 .577 .707 r
F P
0 g
s
.82978 .73368 m .82846 .75277 L .83534 .75016 L p .707 .577 .707 r
F P
0 g
s
.83534 .75016 m .83666 .73106 L .82978 .73368 L p .707 .577 .707 r
F P
0 g
s
.84175 .58123 m .83957 .63799 L .83662 .63229 L p .707 .577 .707 r
F P
0 g
s
.83662 .63229 m .8388 .57553 L .84175 .58123 L p .707 .577 .707 r
F P
0 g
s
.63589 .6517 m .63352 .68983 L .63657 .69373 L p .707 .577 .707 r
F P
0 g
s
.63493 .73838 m .63625 .71928 L .63317 .71593 L p .707 .577 .707 r
F P
0 g
s
.63317 .71593 m .63185 .73502 L .63493 .73838 L p .707 .577 .707 r
F P
0 g
s
.63579 .62807 m .63798 .57131 L .645 .56609 L p .707 .577 .707 r
F P
0 g
s
.83946 .66563 m .8371 .70376 L .83405 .69987 L p .707 .577 .707 r
F P
0 g
s
.83405 .69987 m .83642 .66174 L .83946 .66563 L p .707 .577 .707 r
F P
0 g
s
.645 .56609 m .64281 .62285 L .63579 .62807 L p .707 .577 .707 r
F P
0 g
s
.83666 .73106 m .83534 .75016 L .83227 .7468 L p .707 .577 .707 r
F P
0 g
s
.83227 .7468 m .83358 .72771 L .83666 .73106 L p .707 .577 .707 r
F P
0 g
s
.63352 .68983 m .63589 .6517 L .64281 .64848 L p .707 .577 .707 r
F P
0 g
s
.8388 .57553 m .83662 .63229 L .82398 .62665 L p .707 .577 .707 r
F P
0 g
s
.82398 .62665 m .82617 .56989 L .8388 .57553 L p .707 .577 .707 r
F P
0 g
s
.64281 .64848 m .64044 .68662 L .63352 .68983 L p .707 .577 .707 r
F P
0 g
s
.38808 .61389 m .39027 .55713 L .35911 .55473 L p .707 .577 .707 r
F P
0 g
s
.39027 .55713 m .38808 .61389 L .41989 .61456 L p .707 .577 .707 r
F P
0 g
s
.41989 .61456 m .42208 .5578 L .39027 .55713 L p .707 .577 .707 r
F P
0 g
s
.63185 .73502 m .63317 .71593 L .64005 .71331 L p .707 .577 .707 r
F P
0 g
s
.42208 .5578 m .41989 .61456 L .44923 .61343 L p .707 .577 .707 r
F P
0 g
s
.44923 .61343 m .45142 .55667 L .42208 .5578 L p .707 .577 .707 r
F P
0 g
s
.64005 .71331 m .63873 .73241 L .63185 .73502 L p .707 .577 .707 r
F P
0 g
s
.64281 .62285 m .645 .56609 L .66131 .56186 L p .707 .577 .707 r
F P
0 g
s
.35692 .61149 m .35911 .55473 L .33164 .55084 L p .707 .577 .707 r
F P
0 g
s
.35911 .55473 m .35692 .61149 L .38808 .61389 L p .707 .577 .707 r
F P
0 g
s
.83642 .66174 m .83405 .69987 L .82135 .69567 L p .707 .577 .707 r
F P
0 g
s
.82135 .69567 m .82371 .65754 L .83642 .66174 L p .707 .577 .707 r
F P
0 g
s
.66131 .56186 m .65912 .61862 L .64281 .62285 L p .707 .577 .707 r
F P
0 g
s
.45142 .55667 m .44923 .61343 L .47323 .61062 L p .707 .577 .707 r
F P
0 g
s
.47323 .61062 m .47541 .55386 L .45142 .55667 L p .707 .577 .707 r
F P
0 g
s
.38602 .67149 m .38839 .63336 L .35725 .63064 L p .707 .577 .707 r
F P
0 g
s
.38839 .63336 m .38602 .67149 L .41779 .67308 L p .707 .577 .707 r
F P
0 g
s
.41779 .67308 m .42015 .63495 L .38839 .63336 L p .707 .577 .707 r
F P
0 g
s
.33164 .55084 m .32945 .6076 L .35692 .61149 L p .707 .577 .707 r
F P
0 g
s
.42015 .63495 m .41779 .67308 L .44705 .67339 L p .707 .577 .707 r
F P
0 g
s
.44705 .67339 m .44942 .63526 L .42015 .63495 L p .707 .577 .707 r
F P
0 g
s
.35725 .63064 m .35488 .66877 L .38602 .67149 L p .707 .577 .707 r
F P
0 g
s
.64044 .68662 m .64281 .64848 L .65902 .64627 L p .707 .577 .707 r
F P
0 g
s
.82617 .56989 m .82398 .62665 L .8029 .62164 L p .707 .577 .707 r
F P
0 g
s
.8029 .62164 m .80508 .56488 L .82617 .56989 L p .707 .577 .707 r
F P
0 g
s
.32945 .6076 m .33164 .55084 L .31055 .54583 L p .707 .577 .707 r
F P
0 g
s
.83358 .72771 m .83227 .7468 L .81953 .74303 L p .707 .577 .707 r
F P
0 g
s
.81953 .74303 m .82085 .72394 L .83358 .72771 L p .707 .577 .707 r
F P
0 g
s
.35488 .66877 m .35725 .63064 L .32976 .62707 L p .707 .577 .707 r
F P
0 g
s
.65902 .64627 m .65665 .6844 L .64044 .68662 L p .707 .577 .707 r
F P
0 g
s
.38443 .71543 m .38575 .69634 L .35461 .69353 L p .707 .577 .707 r
F P
0 g
s
.38575 .69634 m .38443 .71543 L .41618 .7173 L p .707 .577 .707 r
F P
0 g
s
.41618 .7173 m .41749 .69821 L .38575 .69634 L p .707 .577 .707 r
F P
0 g
s
.32976 .62707 m .32739 .6652 L .35488 .66877 L p .707 .577 .707 r
F P
0 g
s
.35461 .69353 m .35329 .71262 L .38443 .71543 L p .707 .577 .707 r
F P
0 g
s
.41749 .69821 m .41618 .7173 L .44541 .71804 L p .707 .577 .707 r
F P
0 g
s
.44541 .71804 m .44673 .69894 L .41749 .69821 L p .707 .577 .707 r
F P
0 g
s
.65912 .61862 m .66131 .56186 L .6853 .55905 L p .707 .577 .707 r
F P
0 g
s
.44942 .63526 m .44705 .67339 L .47096 .67238 L p .707 .577 .707 r
F P
0 g
s
.47096 .67238 m .47333 .63425 L .44942 .63526 L p .707 .577 .707 r
F P
0 g
s
.31055 .54583 m .30837 .60259 L .32945 .6076 L p .707 .577 .707 r
F P
0 g
s
.63873 .73241 m .64005 .71331 L .65622 .7117 L p .707 .577 .707 r
F P
0 g
s
.35329 .71262 m .35461 .69353 L .32712 .69005 L p .707 .577 .707 r
F P
0 g
s
.65622 .7117 m .6549 .73079 L .63873 .73241 L p .707 .577 .707 r
F P
0 g
s
.32712 .69005 m .3258 .70914 L .35329 .71262 L p .707 .577 .707 r
F P
0 g
s
.47541 .55386 m .47323 .61062 L .48953 .6064 L p .707 .577 .707 r
F P
0 g
s
.48953 .6064 m .49172 .54964 L .47541 .55386 L p .707 .577 .707 r
F P
0 g
s
.32739 .6652 m .32976 .62707 L .30863 .62298 L p .707 .577 .707 r
F P
0 g
s
.82371 .65754 m .82135 .69567 L .80022 .69158 L p .707 .577 .707 r
F P
0 g
s
.80022 .69158 m .80258 .65345 L .82371 .65754 L p .707 .577 .707 r
F P
0 g
s
.6853 .55905 m .68312 .61581 L .65912 .61862 L p .707 .577 .707 r
F P
0 g
s
.44673 .69894 m .44541 .71804 L .46929 .71757 L p .707 .577 .707 r
F P
0 g
s
.46929 .71757 m .4706 .69848 L .44673 .69894 L p .707 .577 .707 r
F P
0 g
s
.30863 .62298 m .30626 .66111 L .32739 .6652 L p .707 .577 .707 r
F P
0 g
s
.80508 .56488 m .8029 .62164 L .77543 .61775 L p .707 .577 .707 r
F P
0 g
s
.77543 .61775 m .77761 .56099 L .80508 .56488 L p .707 .577 .707 r
F P
0 g
s
.30837 .60259 m .31055 .54583 L .29792 .5402 L p .707 .577 .707 r
F P
0 g
s
.65665 .6844 m .65902 .64627 L .68292 .64526 L p .707 .577 .707 r
F P
0 g
s
.3258 .70914 m .32712 .69005 L .30597 .68624 L p .707 .577 .707 r
F P
0 g
s
.30597 .68624 m .30465 .70533 L .3258 .70914 L p .707 .577 .707 r
F P
0 g
s
.82085 .72394 m .81953 .74303 L .79838 .73922 L p .707 .577 .707 r
F P
0 g
s
.79838 .73922 m .7997 .72013 L .82085 .72394 L p .707 .577 .707 r
F P
0 g
s
.68312 .61581 m .6853 .55905 L .71464 .55792 L p .707 .577 .707 r
F P
0 g
s
.47333 .63425 m .47096 .67238 L .48717 .67016 L p .707 .577 .707 r
F P
0 g
s
.48717 .67016 m .48953 .63203 L .47333 .63425 L p .707 .577 .707 r
F P
0 g
s
.68292 .64526 m .68056 .68339 L .65665 .6844 L p .707 .577 .707 r
F P
0 g
s
.29792 .5402 m .29573 .59696 L .30837 .60259 L p .707 .577 .707 r
F P
0 g
s
.6549 .73079 m .65622 .7117 L .68009 .71123 L p .707 .577 .707 r
F P
0 g
s
.77761 .56099 m .77543 .61775 L .74426 .61535 L p .707 .577 .707 r
F P
0 g
s
.74426 .61535 m .74645 .55859 L .77761 .56099 L p .707 .577 .707 r
F P
0 g
s
.68009 .71123 m .67877 .73033 L .6549 .73079 L p .707 .577 .707 r
F P
0 g
s
.30626 .66111 m .30863 .62298 L .29592 .61878 L p .707 .577 .707 r
F P
0 g
s
.71464 .55792 m .71246 .61468 L .68312 .61581 L p .707 .577 .707 r
F P
0 g
s
.49172 .54964 m .48953 .6064 L .49656 .60118 L p .707 .577 .707 r
F P
0 g
s
.49656 .60118 m .49874 .54442 L .49172 .54964 L p .707 .577 .707 r
F P
0 g
s
.80258 .65345 m .80022 .69158 L .77273 .688 L p .707 .577 .707 r
F P
0 g
s
.77273 .688 m .7751 .64987 L .80258 .65345 L p .707 .577 .707 r
F P
0 g
s
.4706 .69848 m .46929 .71757 L .48545 .71596 L p .707 .577 .707 r
F P
0 g
s
.48545 .71596 m .48677 .69686 L .4706 .69848 L p .707 .577 .707 r
F P
0 g
s
.71246 .61468 m .71464 .55792 L .74645 .55859 L p .707 .577 .707 r
F P
0 g
s
.29592 .61878 m .29356 .65691 L .30626 .66111 L p .707 .577 .707 r
F P
0 g
s
.74645 .55859 m .74426 .61535 L .71246 .61468 L p .707 .577 .707 r
F P
0 g
s
.68056 .68339 m .68292 .64526 L .71219 .64557 L p .707 .577 .707 r
F P
0 g
s
.30465 .70533 m .30597 .68624 L .29324 .68247 L p .707 .577 .707 r
F P
0 g
s
.29573 .59696 m .29792 .5402 L .29497 .53449 L p .707 .577 .707 r
F P
0 g
s
.29324 .68247 m .29192 .70156 L .30465 .70533 L p .707 .577 .707 r
F P
0 g
s
.71219 .64557 m .70982 .6837 L .68056 .68339 L p .707 .577 .707 r
F P
0 g
s
.7997 .72013 m .79838 .73922 L .77089 .73574 L p .707 .577 .707 r
F P
0 g
s
.77089 .73574 m .77221 .71665 L .7997 .72013 L p .707 .577 .707 r
F P
0 g
s
.7751 .64987 m .77273 .688 L .74159 .68529 L p .707 .577 .707 r
F P
0 g
s
.74159 .68529 m .74395 .64716 L .7751 .64987 L p .707 .577 .707 r
F P
0 g
s
.48953 .63203 m .48717 .67016 L .49409 .66695 L p .707 .577 .707 r
F P
0 g
s
.49409 .66695 m .49645 .62882 L .48953 .63203 L p .707 .577 .707 r
F P
0 g
s
.67877 .73033 m .68009 .71123 L .70933 .71197 L p .707 .577 .707 r
F P
0 g
s
.70982 .6837 m .71219 .64557 L .74395 .64716 L p .707 .577 .707 r
F P
0 g
s
.70933 .71197 m .70801 .73107 L .67877 .73033 L p .707 .577 .707 r
F P
0 g
s
.29497 .53449 m .29278 .59125 L .29573 .59696 L p .707 .577 .707 r
F P
0 g
s
.74395 .64716 m .74159 .68529 L .70982 .6837 L p .707 .577 .707 r
F P
0 g
s
.77221 .71665 m .77089 .73574 L .73975 .73293 L p .707 .577 .707 r
F P
0 g
s
.73975 .73293 m .74107 .71384 L .77221 .71665 L p .707 .577 .707 r
F P
0 g
s
.29356 .65691 m .29592 .61878 L .29288 .61488 L p .707 .577 .707 r
F P
0 g
s
.48677 .69686 m .48545 .71596 L .49233 .71334 L p .707 .577 .707 r
F P
0 g
s
.49233 .71334 m .49365 .69425 L .48677 .69686 L p .707 .577 .707 r
F P
0 g
s
.49874 .54442 m .49656 .60118 L .4936 .59547 L p .707 .577 .707 r
F P
0 g
s
.4936 .59547 m .49579 .53871 L .49874 .54442 L p .707 .577 .707 r
F P
0 g
s
.70801 .73107 m .70933 .71197 L .74107 .71384 L p .707 .577 .707 r
F P
0 g
s
.29288 .61488 m .29051 .65302 L .29356 .65691 L p .707 .577 .707 r
F P
0 g
s
.74107 .71384 m .73975 .73293 L .70801 .73107 L p .707 .577 .707 r
F P
0 g
s
.29192 .70156 m .29324 .68247 L .29016 .67911 L p .707 .577 .707 r
F P
0 g
s
.29016 .67911 m .28884 .69821 L .29192 .70156 L p .707 .577 .707 r
F P
0 g
s
.29278 .59125 m .29497 .53449 L .30199 .52927 L p .707 .577 .707 r
F P
0 g
s
.49645 .62882 m .49409 .66695 L .49104 .66305 L p .707 .577 .707 r
F P
0 g
s
.49104 .66305 m .49341 .62492 L .49645 .62882 L p .707 .577 .707 r
F P
0 g
s
.30199 .52927 m .2998 .58603 L .29278 .59125 L p .707 .577 .707 r
F P
0 g
s
.49365 .69425 m .49233 .71334 L .48926 .70999 L p .707 .577 .707 r
F P
0 g
s
.48926 .70999 m .49057 .69089 L .49365 .69425 L p .707 .577 .707 r
F P
0 g
s
.29051 .65302 m .29288 .61488 L .2998 .61167 L p .707 .577 .707 r
F P
0 g
s
.49579 .53871 m .4936 .59547 L .48097 .58984 L p .707 .577 .707 r
F P
0 g
s
.48097 .58984 m .48315 .53308 L .49579 .53871 L p .707 .577 .707 r
F P
0 g
s
.2998 .61167 m .29743 .6498 L .29051 .65302 L p .707 .577 .707 r
F P
0 g
s
.28884 .69821 m .29016 .67911 L .29704 .6765 L p .707 .577 .707 r
F P
0 g
s
.29704 .6765 m .29572 .69559 L .28884 .69821 L p .707 .577 .707 r
F P
0 g
s
.2998 .58603 m .30199 .52927 L .3183 .52505 L p .707 .577 .707 r
F P
0 g
s
.49341 .62492 m .49104 .66305 L .47834 .65885 L p .707 .577 .707 r
F P
0 g
s
.47834 .65885 m .4807 .62072 L .49341 .62492 L p .707 .577 .707 r
F P
0 g
s
.3183 .52505 m .31611 .58181 L .2998 .58603 L p .707 .577 .707 r
F P
0 g
s
.29743 .6498 m .2998 .61167 L .31601 .60945 L p .707 .577 .707 r
F P
0 g
s
.48315 .53308 m .48097 .58984 L .45988 .58483 L p .707 .577 .707 r
F P
0 g
s
.45988 .58483 m .46207 .52807 L .48315 .53308 L p .707 .577 .707 r
F P
0 g
s
.49057 .69089 m .48926 .70999 L .47652 .70622 L p .707 .577 .707 r
F P
0 g
s
.47652 .70622 m .47784 .68713 L .49057 .69089 L p .707 .577 .707 r
F P
0 g
s
.31601 .60945 m .31364 .64758 L .29743 .6498 L p .707 .577 .707 r
F P
0 g
s
.31611 .58181 m .3183 .52505 L .34229 .52224 L p .707 .577 .707 r
F P
0 g
s
.29572 .69559 m .29704 .6765 L .31321 .67488 L p .707 .577 .707 r
F P
0 g
s
.31321 .67488 m .31189 .69397 L .29572 .69559 L p .707 .577 .707 r
F P
0 g
s
.4807 .62072 m .47834 .65885 L .45721 .65477 L p .707 .577 .707 r
F P
0 g
s
.45721 .65477 m .45957 .61664 L .4807 .62072 L p .707 .577 .707 r
F P
0 g
s
.34229 .52224 m .34011 .57899 L .31611 .58181 L p .707 .577 .707 r
F P
0 g
s
.46207 .52807 m .45988 .58483 L .43242 .58093 L p .707 .577 .707 r
F P
0 g
s
.43242 .58093 m .4346 .52417 L .46207 .52807 L p .707 .577 .707 r
F P
0 g
s
.31364 .64758 m .31601 .60945 L .33991 .60845 L p .707 .577 .707 r
F P
0 g
s
.47784 .68713 m .47652 .70622 L .45537 .70241 L p .707 .577 .707 r
F P
0 g
s
.45537 .70241 m .45669 .68331 L .47784 .68713 L p .707 .577 .707 r
F P
0 g
s
.34011 .57899 m .34229 .52224 L .37163 .52111 L p .707 .577 .707 r
F P
0 g
s
.33991 .60845 m .33755 .64658 L .31364 .64758 L p .707 .577 .707 r
F P
0 g
s
.31189 .69397 m .31321 .67488 L .33708 .67442 L p .707 .577 .707 r
F P
0 g
s
.4346 .52417 m .43242 .58093 L .40125 .57853 L p .707 .577 .707 r
F P
0 g
s
.40125 .57853 m .40344 .52178 L .4346 .52417 L p .707 .577 .707 r
F P
0 g
s
.33708 .67442 m .33576 .69351 L .31189 .69397 L p .707 .577 .707 r
F P
0 g
s
.37163 .52111 m .36945 .57787 L .34011 .57899 L p .707 .577 .707 r
F P
0 g
s
.45957 .61664 m .45721 .65477 L .42972 .65119 L p .707 .577 .707 r
F P
0 g
s
.42972 .65119 m .43209 .61306 L .45957 .61664 L p .707 .577 .707 r
F P
0 g
s
.36945 .57787 m .37163 .52111 L .40344 .52178 L p .707 .577 .707 r
F P
0 g
s
.40344 .52178 m .40125 .57853 L .36945 .57787 L p .707 .577 .707 r
F P
0 g
s
.33755 .64658 m .33991 .60845 L .36918 .60875 L p .707 .577 .707 r
F P
0 g
s
.36918 .60875 m .36681 .64688 L .33755 .64658 L p .707 .577 .707 r
F P
0 g
s
.45669 .68331 m .45537 .70241 L .42788 .69893 L p .707 .577 .707 r
F P
0 g
s
.42788 .69893 m .4292 .67983 L .45669 .68331 L p .707 .577 .707 r
F P
0 g
s
.43209 .61306 m .42972 .65119 L .39857 .64847 L p .707 .577 .707 r
F P
0 g
s
.39857 .64847 m .40094 .61034 L .43209 .61306 L p .707 .577 .707 r
F P
0 g
s
.33576 .69351 m .33708 .67442 L .36632 .67516 L p .707 .577 .707 r
F P
0 g
s
.36681 .64688 m .36918 .60875 L .40094 .61034 L p .707 .577 .707 r
F P
0 g
s
.36632 .67516 m .365 .69425 L .33576 .69351 L p .707 .577 .707 r
F P
0 g
s
.40094 .61034 m .39857 .64847 L .36681 .64688 L p .707 .577 .707 r
F P
0 g
s
.4292 .67983 m .42788 .69893 L .39674 .69612 L p .707 .577 .707 r
F P
0 g
s
.39674 .69612 m .39806 .67702 L .4292 .67983 L p .707 .577 .707 r
F P
0 g
s
.365 .69425 m .36632 .67516 L .39806 .67702 L p .707 .577 .707 r
F P
0 g
s
.39806 .67702 m .39674 .69612 L .365 .69425 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Ioob<008Aoo`00L7oo1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF2@00Ngoo001/Ool400000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol006Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00J7oo0`001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01000K7oo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000J7oo001WOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YF000006Ioo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001TOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001NOolJ000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Qoo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0047oo4P00A7oo001COol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo300015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP<0035oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00008002ioo`00Dgoo00<005YF00000eYF00@005YFFUIJEQT000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1`000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH00000FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00EGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo001J
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00=goo6@001Goo8@0000=JEP00
FUH01UYF00@005YFFUIJEPH000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00<Goo1P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3@0035YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1`002UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF3P001eYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP050005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1P0015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH000020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF0000000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000@000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003OolG0008FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000090007FUH00`00FUIJEP05FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF6`00<goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00;7oo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@00003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ40
00AJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ao
o`03001JEP0000=JEP`00003FUH005YF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEQ40
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00;7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEPd0009JEP03001JEUYF00=JEP03001JEUYF00=JEQH000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF008002ioo`00;7oo00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEUYF
009JEQ<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
FUIJEQh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`800003
FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP050005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00;goo0`0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=J
EP05001JEUYFFUH0000_Ool0035ooah00005FUH005YF001JEP0Q0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<007ooOol0;Goo000^Ool300000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHD0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP00Ool0;Woo000/Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1@000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<0
05YFFUH00eYF00<005YFFUH00P000goo8P00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000240
04Ioo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH04@0015YF
00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=goo000[Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEP00000`Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEQH000AJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002moo`00:goo00<005YF0000
0UYF7`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF
300015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00:goo1P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF20000eYF00<005YFFUH00eYF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2`000eYF00<005YFFUH00eYF00@005YFFUIJ
EP8002moo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;goo000/Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF0P00;goo000^Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000EJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4000_Ool003=oo`L000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH00UYF4@0015YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;goo000`OolG0008FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP03FUH00`00FUIJEP02000;OolJ000`Ool0
02]oo`D0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ/00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00FUIJ
EP02001EOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP04FUH00`00FUIJEP02001EOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60005Ool01000FUIJEP00
1EYF00<005YFFUH00eYF30002UYF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH01P000UYF00<005YFFUH00UYF1`002eYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Eoo`00:goo00<005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEP00008000IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol002]oo`03001JEP0000L0
0003FUH005YF00AJEQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP@0009JEP03001JEUYF009JEP03001JEP0000=JEPH000AJEP05001JEUYFFUH0001FOol002]oo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP03
001JEP00008000]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP03001JEP0000AJEP03001JEUYF009JEP<00003FUH005YF009JEP03
001oogoo05Aoo`00:goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1P00
0eYF00<005YFFUH015YF1`000eYF00<005YF00003EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP0000AJ
EP03001JEUYF00AJEP@0009JEP03001oogoo05Aoo`00;Goo1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1P003EYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000=JEP00FUH00eYF00<005YFFUH015YF00@005YFFUIJEP<005Ioo`00<Woo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EWoo
000iOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
0009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YFFUIJEPT005Moo`00@Woo8P000goo0`00
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH02@00H7oo001ZOol40002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH7
001NOol006ioo`D000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00D005Uoo`00Lgoo1P000eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Moo`00NGoo2@001UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00UYF1`001eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH00P00EWoo0022Oolf0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EWoo002=Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH60003
FUH01000FUIJEUYF0P00EWoo002?Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH2001FOol009Aoo`L000=JEP03001JEUYF00IJEP03
001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003FUH0000005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0`00EWoo002SOol90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05001FOol00:ao
oaH005]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5927 .73367 m .59623 .67648 L .56508 .67377 L p .707 .577 .707 r
F P
0 g
s
.59623 .67648 m .5927 .73367 L .62446 .73524 L p .707 .577 .707 r
F P
0 g
s
.62446 .73524 m .62799 .67805 L .59623 .67648 L p .707 .577 .707 r
F P
0 g
s
.62799 .67805 m .62446 .73524 L .65373 .73553 L p .707 .577 .707 r
F P
0 g
s
.65373 .73553 m .65725 .67834 L .62799 .67805 L p .707 .577 .707 r
F P
0 g
s
.56155 .73096 m .56508 .67377 L .53759 .67019 L p .707 .577 .707 r
F P
0 g
s
.56508 .67377 m .56155 .73096 L .5927 .73367 L p .707 .577 .707 r
F P
0 g
s
.58968 .78315 m .59348 .74488 L .56238 .74165 L p .707 .577 .707 r
F P
0 g
s
.59348 .74488 m .58968 .78315 L .62132 .78622 L p .707 .577 .707 r
F P
0 g
s
.62132 .78622 m .62513 .74795 L .59348 .74488 L p .707 .577 .707 r
F P
0 g
s
.56238 .74165 m .55858 .77992 L .58968 .78315 L p .707 .577 .707 r
F P
0 g
s
.53759 .67019 m .53407 .72738 L .56155 .73096 L p .707 .577 .707 r
F P
0 g
s
.62513 .74795 m .62132 .78622 L .6504 .78884 L p .707 .577 .707 r
F P
0 g
s
.6504 .78884 m .65421 .75057 L .62513 .74795 L p .707 .577 .707 r
F P
0 g
s
.65725 .67834 m .65373 .73553 L .67764 .73449 L p .707 .577 .707 r
F P
0 g
s
.67764 .73449 m .68116 .6773 L .65725 .67834 L p .707 .577 .707 r
F P
0 g
s
.55825 .79721 m .55613 .81633 L .58722 .81971 L p .707 .577 .707 r
F P
0 g
s
.58722 .81971 m .58934 .80059 L .55825 .79721 L p .707 .577 .707 r
F P
0 g
s
.58934 .80059 m .58722 .81971 L .61882 .82323 L p .707 .577 .707 r
F P
0 g
s
.61882 .82323 m .62093 .80411 L .58934 .80059 L p .707 .577 .707 r
F P
0 g
s
.55858 .77992 m .56238 .74165 L .53485 .73858 L p .707 .577 .707 r
F P
0 g
s
.53485 .73858 m .53105 .77685 L .55858 .77992 L p .707 .577 .707 r
F P
0 g
s
.62093 .80411 m .61882 .82323 L .64782 .82655 L p .707 .577 .707 r
F P
0 g
s
.64782 .82655 m .64994 .80743 L .62093 .80411 L p .707 .577 .707 r
F P
0 g
s
.53407 .72738 m .53759 .67019 L .51647 .66608 L p .707 .577 .707 r
F P
0 g
s
.53071 .7943 m .52859 .81342 L .55613 .81633 L p .707 .577 .707 r
F P
0 g
s
.55613 .81633 m .55825 .79721 L .53071 .7943 L p .707 .577 .707 r
F P
0 g
s
.65421 .75057 m .6504 .78884 L .67407 .79075 L p .707 .577 .707 r
F P
0 g
s
.67407 .79075 m .67788 .75248 L .65421 .75057 L p .707 .577 .707 r
F P
0 g
s
.51647 .66608 m .51294 .72327 L .53407 .72738 L p .707 .577 .707 r
F P
0 g
s
.64994 .80743 m .64782 .82655 L .6714 .82933 L p .707 .577 .707 r
F P
0 g
s
.6714 .82933 m .67351 .81022 L .64994 .80743 L p .707 .577 .707 r
F P
0 g
s
.53105 .77685 m .53485 .73858 L .5136 .73598 L p .707 .577 .707 r
F P
0 g
s
.5136 .73598 m .5098 .77425 L .53105 .77685 L p .707 .577 .707 r
F P
0 g
s
.68116 .6773 m .67764 .73449 L .69384 .73224 L p .707 .577 .707 r
F P
0 g
s
.69384 .73224 m .69737 .67505 L .68116 .6773 L p .707 .577 .707 r
F P
0 g
s
.50941 .79214 m .50729 .81126 L .52859 .81342 L p .707 .577 .707 r
F P
0 g
s
.52859 .81342 m .53071 .7943 L .50941 .79214 L p .707 .577 .707 r
F P
0 g
s
.51294 .72327 m .51647 .66608 L .50376 .66186 L p .707 .577 .707 r
F P
0 g
s
.67788 .75248 m .67407 .79075 L .69002 .79176 L p .707 .577 .707 r
F P
0 g
s
.69002 .79176 m .69382 .75349 L .67788 .75248 L p .707 .577 .707 r
F P
0 g
s
.50376 .66186 m .50023 .71905 L .51294 .72327 L p .707 .577 .707 r
F P
0 g
s
.67351 .81022 m .6714 .82933 L .68725 .83132 L p .707 .577 .707 r
F P
0 g
s
.68725 .83132 m .68936 .8122 L .67351 .81022 L p .707 .577 .707 r
F P
0 g
s
.5098 .77425 m .5136 .73598 L .50071 .73409 L p .707 .577 .707 r
F P
0 g
s
.50071 .73409 m .49691 .77236 L .5098 .77425 L p .707 .577 .707 r
F P
0 g
s
.49644 .79096 m .49433 .81007 L .50729 .81126 L p .707 .577 .707 r
F P
0 g
s
.50729 .81126 m .50941 .79214 L .49644 .79096 L p .707 .577 .707 r
F P
0 g
s
.69737 .67505 m .69384 .73224 L .70077 .72899 L p .707 .577 .707 r
F P
0 g
s
.70077 .72899 m .7043 .6718 L .69737 .67505 L p .707 .577 .707 r
F P
0 g
s
.50023 .71905 m .50376 .66186 L .50072 .65793 L p .707 .577 .707 r
F P
0 g
s
.69382 .75349 m .69002 .79176 L .69668 .79177 L p .707 .577 .707 r
F P
0 g
s
.69668 .79177 m .70048 .7535 L .69382 .75349 L p .707 .577 .707 r
F P
0 g
s
.68936 .8122 m .68725 .83132 L .6938 .83231 L p .707 .577 .707 r
F P
0 g
s
.50072 .65793 m .49719 .71512 L .50023 .71905 L p .707 .577 .707 r
F P
0 g
s
.6938 .83231 m .69592 .81319 L .68936 .8122 L p .707 .577 .707 r
F P
0 g
s
.49691 .77236 m .50071 .73409 L .49743 .73311 L p .707 .577 .707 r
F P
0 g
s
.49743 .73311 m .49363 .77138 L .49691 .77236 L p .707 .577 .707 r
F P
0 g
s
.49307 .79085 m .49096 .80997 L .49433 .81007 L p .707 .577 .707 r
F P
0 g
s
.49433 .81007 m .49644 .79096 L .49307 .79085 L p .707 .577 .707 r
F P
0 g
s
.7043 .6718 m .70077 .72899 L .69773 .72506 L p .707 .577 .707 r
F P
0 g
s
.69773 .72506 m .70125 .66787 L .7043 .6718 L p .707 .577 .707 r
F P
0 g
s
.49719 .71512 m .50072 .65793 L .50764 .65468 L p .707 .577 .707 r
F P
0 g
s
.70048 .7535 m .69668 .79177 L .6934 .79079 L p .707 .577 .707 r
F P
0 g
s
.6934 .79079 m .69721 .75252 L .70048 .7535 L p .707 .577 .707 r
F P
0 g
s
.69592 .81319 m .6938 .83231 L .69043 .8322 L p .707 .577 .707 r
F P
0 g
s
.69043 .8322 m .69255 .81309 L .69592 .81319 L p .707 .577 .707 r
F P
0 g
s
.50764 .65468 m .50411 .71187 L .49719 .71512 L p .707 .577 .707 r
F P
0 g
s
.49363 .77138 m .49743 .73311 L .50409 .73312 L p .707 .577 .707 r
F P
0 g
s
.50409 .73312 m .50029 .77139 L .49363 .77138 L p .707 .577 .707 r
F P
0 g
s
.49963 .79184 m .49751 .81096 L .49096 .80997 L p .707 .577 .707 r
F P
0 g
s
.49096 .80997 m .49307 .79085 L .49963 .79184 L p .707 .577 .707 r
F P
0 g
s
.70125 .66787 m .69773 .72506 L .68502 .72084 L p .707 .577 .707 r
F P
0 g
s
.68502 .72084 m .68855 .66365 L .70125 .66787 L p .707 .577 .707 r
F P
0 g
s
.24969 .69686 m .25322 .63967 L .22207 .63695 L p .707 .577 .707 r
F P
0 g
s
.25322 .63967 m .24969 .69686 L .28145 .69843 L p .707 .577 .707 r
F P
0 g
s
.28145 .69843 m .28498 .64124 L .25322 .63967 L p .707 .577 .707 r
F P
0 g
s
.28498 .64124 m .28145 .69843 L .31072 .69871 L p .707 .577 .707 r
F P
0 g
s
.31072 .69871 m .31425 .64152 L .28498 .64124 L p .707 .577 .707 r
F P
0 g
s
.50411 .71187 m .50764 .65468 L .52385 .65243 L p .707 .577 .707 r
F P
0 g
s
.21854 .69415 m .22207 .63695 L .19459 .63337 L p .707 .577 .707 r
F P
0 g
s
.22207 .63695 m .21854 .69415 L .24969 .69686 L p .707 .577 .707 r
F P
0 g
s
.47424 .80736 m .50627 .29091 L .4623 .28708 L p .707 .577 .707 r
F P
0 g
s
.52385 .65243 m .52032 .70962 L .50411 .71187 L p .707 .577 .707 r
F P
0 g
s
.50029 .77139 m .50409 .73312 L .52004 .73413 L p .707 .577 .707 r
F P
0 g
s
.52004 .73413 m .51624 .7724 L .50029 .77139 L p .707 .577 .707 r
F P
0 g
s
.51547 .79383 m .51336 .81294 L .49751 .81096 L p .707 .577 .707 r
F P
0 g
s
.49751 .81096 m .49963 .79184 L .51547 .79383 L p .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .52004 .73413 L .54137 .73585 L p .707 .577 .707 r
F P
0 g
s
.54137 .73585 m .54371 .73604 L p .54143 .73906 L .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .54137 .73585 L .54143 .73906 L .707 .577 .707 r
F
.52032 .70962 m .52385 .65243 L .54776 .65139 L p F P
0 g
s
.54776 .65139 m .54423 .70858 L .52032 .70962 L p .707 .577 .707 r
F P
0 g
s
.54371 .73604 m .53991 .77431 L .51624 .7724 L p .707 .577 .707 r
F P
0 g
s
.53905 .79661 m .53694 .81573 L .51336 .81294 L p .707 .577 .707 r
F P
0 g
s
.51336 .81294 m .51547 .79383 L .53905 .79661 L p .707 .577 .707 r
F P
0 g
s
.51908 .8096 m .53749 .51285 L p .50627 .29091 L .707 .577 .707 r
F P
0 g
s
.53749 .51285 m .55111 .29315 L .53364 .29228 L p .707 .577 .707 r
F P
0 g
s
.53364 .29228 m .50627 .29091 L p .53749 .51285 L .707 .577 .707 r
F P
0 g
s
.50627 .29091 m .47424 .80736 L .51908 .8096 L p .707 .577 .707 r
F P
0 g
s
.69721 .75252 m .6934 .79079 L .68051 .7889 L p .707 .577 .707 r
F P
0 g
s
.68051 .7889 m .68431 .75063 L .69721 .75252 L p .707 .577 .707 r
F P
0 g
s
.54423 .70858 m .54776 .65139 L .57703 .65168 L p .707 .577 .707 r
F P
0 g
s
.57703 .65168 m .5735 .70887 L .54423 .70858 L p .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .54371 .73604 L .55393 .73696 L p .707 .577 .707 r
F P
0 g
s
.55393 .73696 m .57279 .73866 L p .54676 .76688 L .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .55393 .73696 L .54676 .76688 L .707 .577 .707 r
F
.5735 .70887 m .57703 .65168 L .60879 .65325 L p F P
0 g
s
.57279 .73866 m .56899 .77693 L .53991 .77431 L p .707 .577 .707 r
F P
0 g
s
.60879 .65325 m .60526 .71044 L .5735 .70887 L p .707 .577 .707 r
F P
0 g
s
.56806 .79993 m .56594 .81905 L .5404 .81612 L p .707 .577 .707 r
F P
0 g
s
.5404 .81612 m .53694 .81573 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.54114 .81359 m .56806 .79993 L .5404 .81612 L .707 .577 .707 r
F
.53694 .81573 m .53905 .79661 L .54591 .7974 L p F P
0 g
s
.54591 .7974 m .56806 .79993 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.53694 .81573 m .54591 .7974 L .54114 .81359 L .707 .577 .707 r
F
.56877 .67508 m .56526 .73162 L p .59336 .57251 L F P
0 g
s
.56526 .73162 m .5604 .81003 L p .57665 .69291 L .707 .577 .707 r
F P
0 g
s
.59336 .57251 m .56526 .73162 L .57665 .69291 L .707 .577 .707 r
F
.56899 .77693 m .57279 .73866 L .5805 .73941 L p F P
0 g
s
.5805 .73941 m .60443 .74173 L p .57697 .769 L .707 .577 .707 r
F P
0 g
s
.56899 .77693 m .5805 .73941 L .57697 .769 L .707 .577 .707 r
F
.63994 .65596 m .63641 .71315 L .60526 .71044 L p F P
0 g
s
.60526 .71044 m .60879 .65325 L .63994 .65596 L p .707 .577 .707 r
F P
0 g
s
.63554 .74496 m .63173 .78323 L .60063 .78 L p .707 .577 .707 r
F P
0 g
s
.60063 .78 m .60443 .74173 L .63554 .74496 L p .707 .577 .707 r
F P
0 g
s
.60443 .74173 m .60063 .78 L .56899 .77693 L p .707 .577 .707 r
F P
0 g
s
.59754 .82257 m .59965 .80345 L .63074 .80683 L p .707 .577 .707 r
F P
0 g
s
.59965 .80345 m .59754 .82257 L .57266 .81979 L p .707 .577 .707 r
F P
0 g
s
.57266 .81979 m .56594 .81905 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.57322 .81568 m .59965 .80345 L .57266 .81979 L .707 .577 .707 r
F
.56594 .81905 m .56806 .79993 L .57526 .80073 L p F P
0 g
s
.57526 .80073 m .59965 .80345 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.56594 .81905 m .57526 .80073 L .57322 .81568 L .707 .577 .707 r
F
.61785 .42651 m .61074 .54113 L p .62483 .36803 L F P
0 g
s
.61074 .54113 m .59415 .80861 L p .61489 .51076 L .707 .577 .707 r
F P
0 g
s
.62483 .36803 m .61074 .54113 L .61489 .51076 L .707 .577 .707 r
F
.59415 .80861 m .61703 .80546 L p .62339 .44854 L F P
0 g
s
.62339 .44854 m .62483 .36803 L .61489 .51076 L .707 .577 .707 r
F
.62339 .44854 m .61489 .51076 L .59415 .80861 L F
.62618 .29216 m .61785 .42651 L p .62483 .36803 L F P
0 g
s
.5604 .81003 m .59415 .80861 L p .59357 .63541 L .707 .577 .707 r
F P
0 g
s
.59357 .63541 m .59336 .57251 L .57665 .69291 L .707 .577 .707 r
F
.59357 .63541 m .57665 .69291 L .5604 .81003 L F
.59243 .29358 m .56877 .67508 L p .59336 .57251 L F P
0 g
s
.55111 .29315 m .51908 .8096 L .5604 .81003 L p .707 .577 .707 r
F P
0 g
s
.5604 .81003 m .59243 .29358 L .55111 .29315 L p .707 .577 .707 r
F P
0 g
s
.24667 .74633 m .25048 .70806 L .21937 .70483 L p .707 .577 .707 r
F P
0 g
s
.25048 .70806 m .24667 .74633 L .27832 .7494 L p .707 .577 .707 r
F P
0 g
s
.27832 .7494 m .28212 .71114 L .25048 .70806 L p .707 .577 .707 r
F P
0 g
s
.21937 .70483 m .21557 .7431 L .24667 .74633 L p .707 .577 .707 r
F P
0 g
s
.69255 .81309 m .69043 .8322 L .67746 .83102 L p .707 .577 .707 r
F P
0 g
s
.67746 .83102 m .67958 .8119 L .69255 .81309 L p .707 .577 .707 r
F P
0 g
s
.19459 .63337 m .19106 .69056 L .21854 .69415 L p .707 .577 .707 r
F P
0 g
s
.28212 .71114 m .27832 .7494 L .30739 .75202 L p .707 .577 .707 r
F P
0 g
s
.30739 .75202 m .3112 .71375 L .28212 .71114 L p .707 .577 .707 r
F P
0 g
s
.31425 .64152 m .31072 .69871 L .33463 .69768 L p .707 .577 .707 r
F P
0 g
s
.33463 .69768 m .33815 .64049 L .31425 .64152 L p .707 .577 .707 r
F P
0 g
s
.43027 .80353 m .4623 .28708 L .4235 .28203 L p .707 .577 .707 r
F P
0 g
s
.4623 .28708 m .43027 .80353 L .47424 .80736 L p .707 .577 .707 r
F P
0 g
s
.21524 .7604 m .21312 .77951 L .24421 .78289 L p .707 .577 .707 r
F P
0 g
s
.24421 .78289 m .24633 .76378 L .21524 .7604 L p .707 .577 .707 r
F P
0 g
s
.24633 .76378 m .24421 .78289 L .27581 .78641 L p .707 .577 .707 r
F P
0 g
s
.27581 .78641 m .27792 .7673 L .24633 .76378 L p .707 .577 .707 r
F P
0 g
s
.21557 .7431 m .21937 .70483 L .19185 .70177 L p .707 .577 .707 r
F P
0 g
s
.19185 .70177 m .18804 .74004 L .21557 .7431 L p .707 .577 .707 r
F P
0 g
s
.27792 .7673 m .27581 .78641 L .30481 .78973 L p .707 .577 .707 r
F P
0 g
s
.30481 .78973 m .30693 .77062 L .27792 .7673 L p .707 .577 .707 r
F P
0 g
s
.19106 .69056 m .19459 .63337 L .17346 .62927 L p .707 .577 .707 r
F P
0 g
s
.1877 .75748 m .18558 .7766 L .21312 .77951 L p .707 .577 .707 r
F P
0 g
s
.21312 .77951 m .21524 .7604 L .1877 .75748 L p .707 .577 .707 r
F P
0 g
s
.68855 .66365 m .68502 .72084 L .66389 .71673 L p .707 .577 .707 r
F P
0 g
s
.66389 .71673 m .66742 .65954 L .68855 .66365 L p .707 .577 .707 r
F P
0 g
s
.3112 .71375 m .30739 .75202 L .33107 .75393 L p .707 .577 .707 r
F P
0 g
s
.33107 .75393 m .33487 .71566 L .3112 .71375 L p .707 .577 .707 r
F P
0 g
s
.17346 .62927 m .16993 .68646 L .19106 .69056 L p .707 .577 .707 r
F P
0 g
s
.59415 .80861 m .62618 .29216 L .59243 .29358 L p .707 .577 .707 r
F P
0 g
s
.30693 .77062 m .30481 .78973 L .32839 .79252 L p .707 .577 .707 r
F P
0 g
s
.32839 .79252 m .33051 .7734 L .30693 .77062 L p .707 .577 .707 r
F P
0 g
s
.18804 .74004 m .19185 .70177 L .1706 .69917 L p .707 .577 .707 r
F P
0 g
s
.1706 .69917 m .16679 .73743 L .18804 .74004 L p .707 .577 .707 r
F P
0 g
s
.33815 .64049 m .33463 .69768 L .35084 .69542 L p .707 .577 .707 r
F P
0 g
s
.35084 .69542 m .35436 .63823 L .33815 .64049 L p .707 .577 .707 r
F P
0 g
s
.68431 .75063 m .68051 .7889 L .65926 .7863 L p .707 .577 .707 r
F P
0 g
s
.65926 .7863 m .66306 .74803 L .68431 .75063 L p .707 .577 .707 r
F P
0 g
s
.39147 .79848 m .4235 .28203 L .39367 .27625 L p .707 .577 .707 r
F P
0 g
s
.4235 .28203 m .39147 .79848 L .43027 .80353 L p .707 .577 .707 r
F P
0 g
s
.1664 .75533 m .16429 .77445 L .18558 .7766 L p .707 .577 .707 r
F P
0 g
s
.18558 .7766 m .1877 .75748 L .1664 .75533 L p .707 .577 .707 r
F P
0 g
s
.67958 .8119 m .67746 .83102 L .65617 .82886 L p .707 .577 .707 r
F P
0 g
s
.65617 .82886 m .65828 .80974 L .67958 .8119 L p .707 .577 .707 r
F P
0 g
s
.16993 .68646 m .17346 .62927 L .16075 .62505 L p .707 .577 .707 r
F P
0 g
s
.66742 .65954 m .66389 .71673 L .63641 .71315 L p .707 .577 .707 r
F P
0 g
s
.63641 .71315 m .63994 .65596 L .66742 .65954 L p .707 .577 .707 r
F P
0 g
s
.33487 .71566 m .33107 .75393 L .34701 .75494 L p .707 .577 .707 r
F P
0 g
s
.34701 .75494 m .35081 .71667 L .33487 .71566 L p .707 .577 .707 r
F P
0 g
s
.16075 .62505 m .15722 .68224 L .16993 .68646 L p .707 .577 .707 r
F P
0 g
s
.33051 .7734 m .32839 .79252 L .34424 .7945 L p .707 .577 .707 r
F P
0 g
s
.34424 .7945 m .34635 .77539 L .33051 .7734 L p .707 .577 .707 r
F P
0 g
s
.16679 .73743 m .1706 .69917 L .1577 .69728 L p .707 .577 .707 r
F P
0 g
s
.1577 .69728 m .1539 .73555 L .16679 .73743 L p .707 .577 .707 r
F P
0 g
s
.61703 .80546 m .64906 .28901 L .62618 .29216 L p .707 .577 .707 r
F P
0 g
s
.66306 .74803 m .65926 .7863 L .63173 .78323 L p .707 .577 .707 r
F P
0 g
s
.63173 .78323 m .63554 .74496 L .66306 .74803 L p .707 .577 .707 r
F P
0 g
s
.15343 .75414 m .15132 .77326 L .16429 .77445 L p .707 .577 .707 r
F P
0 g
s
.16429 .77445 m .1664 .75533 L .15343 .75414 L p .707 .577 .707 r
F P
0 g
s
.35436 .63823 m .35084 .69542 L .35776 .69217 L p .707 .577 .707 r
F P
0 g
s
.35776 .69217 m .36129 .63498 L .35436 .63823 L p .707 .577 .707 r
F P
0 g
s
.65828 .80974 m .65617 .82886 L .62863 .82595 L p .707 .577 .707 r
F P
0 g
s
.62863 .82595 m .63074 .80683 L .65828 .80974 L p .707 .577 .707 r
F P
0 g
s
.36164 .7927 m .39367 .27625 L .37573 .27032 L p .707 .577 .707 r
F P
0 g
s
.39367 .27625 m .36164 .7927 L .39147 .79848 L p .707 .577 .707 r
F P
0 g
s
.15722 .68224 m .16075 .62505 L .15771 .62112 L p .707 .577 .707 r
F P
0 g
s
.35081 .71667 m .34701 .75494 L .35367 .75495 L p .707 .577 .707 r
F P
0 g
s
.35367 .75495 m .35747 .71669 L .35081 .71667 L p .707 .577 .707 r
F P
0 g
s
.63074 .80683 m .62863 .82595 L .59754 .82257 L p .707 .577 .707 r
F P
0 g
s
.34635 .77539 m .34424 .7945 L .35079 .79549 L p .707 .577 .707 r
F P
0 g
s
.15771 .62112 m .15418 .67831 L .15722 .68224 L p .707 .577 .707 r
F P
0 g
s
.35079 .79549 m .35291 .77638 L .34635 .77539 L p .707 .577 .707 r
F P
0 g
s
.1539 .73555 m .1577 .69728 L .15442 .69629 L p .707 .577 .707 r
F P
0 g
s
.15442 .69629 m .15062 .73456 L .1539 .73555 L p .707 .577 .707 r
F P
0 g
s
.15006 .75404 m .14795 .77315 L .15132 .77326 L p .707 .577 .707 r
F P
0 g
s
.15132 .77326 m .15343 .75414 L .15006 .75404 L p .707 .577 .707 r
F P
0 g
s
.36129 .63498 m .35776 .69217 L .35472 .68824 L p .707 .577 .707 r
F P
0 g
s
.35472 .68824 m .35825 .63105 L .36129 .63498 L p .707 .577 .707 r
F P
0 g
s
.64906 .28901 m .61703 .80546 L .6268 .80092 L p .707 .577 .707 r
F P
0 g
s
.6268 .80092 m .65883 .28447 L .64906 .28901 L p .707 .577 .707 r
F P
0 g
s
.15418 .67831 m .15771 .62112 L .16463 .61787 L p .707 .577 .707 r
F P
0 g
s
.35747 .71669 m .35367 .75495 L .35039 .75397 L p .707 .577 .707 r
F P
0 g
s
.35039 .75397 m .3542 .7157 L .35747 .71669 L p .707 .577 .707 r
F P
0 g
s
.35825 .63105 m .35472 .68824 L .34201 .68402 L p .707 .577 .707 r
F P
0 g
s
.34201 .68402 m .34554 .62683 L .35825 .63105 L p .707 .577 .707 r
F P
0 g
s
.3542 .7157 m .35039 .75397 L .34819 .75365 L p .707 .577 .707 r
F P
0 g
s
.34819 .75365 m .3375 .75208 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.34923 .72653 m .3542 .7157 L .34819 .75365 L .707 .577 .707 r
F
.37573 .27032 m .37143 .26481 L p .35509 .57235 L F P
0 g
s
.3375 .75208 m .3413 .71381 L .34966 .71504 L p .707 .577 .707 r
F P
0 g
s
.34966 .71504 m .3542 .7157 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.3375 .75208 m .34966 .71504 L .34923 .72653 L .707 .577 .707 r
F
.34954 .77627 m .34742 .79539 L .34588 .79525 L p F P
0 g
s
.34588 .79525 m .33446 .7942 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.34635 .78007 m .34954 .77627 L .34588 .79525 L .707 .577 .707 r
F
.33446 .7942 m .33657 .77508 L .34647 .77599 L p F P
0 g
s
.34647 .77599 m .34954 .77627 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.33446 .7942 m .34647 .77599 L .34635 .78007 L .707 .577 .707 r
F
.35943 .45836 m .35317 .55933 L p .35509 .57235 L F P
0 g
s
.35317 .55933 m .3394 .78126 L p .35114 .625 L .707 .577 .707 r
F P
0 g
s
.35509 .57235 m .35317 .55933 L .35114 .625 L .707 .577 .707 r
F
.3394 .78126 m .3437 .78677 L p .34953 .67702 L F P
0 g
s
.34953 .67702 m .35509 .57235 L .35114 .625 L .707 .577 .707 r
F
.34953 .67702 m .35114 .625 L .3394 .78126 L F
.37143 .26481 m .35943 .45836 L p .35509 .57235 L F P
0 g
s
.3437 .78677 m .35207 .65182 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35207 .65182 m .37573 .27032 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35291 .77638 m .35079 .79549 L .34742 .79539 L p .707 .577 .707 r
F P
0 g
s
.34742 .79539 m .34954 .77627 L .35291 .77638 L p .707 .577 .707 r
F P
0 g
s
.37573 .27032 m .3437 .78677 L .36164 .7927 L p .707 .577 .707 r
F P
0 g
s
.16463 .61787 m .1611 .67506 L .15418 .67831 L p .707 .577 .707 r
F P
0 g
s
.15062 .73456 m .15442 .69629 L .16108 .69631 L p .707 .577 .707 r
F P
0 g
s
.16108 .69631 m .15728 .73458 L .15062 .73456 L p .707 .577 .707 r
F P
0 g
s
.15662 .75503 m .1545 .77414 L .14795 .77315 L p .707 .577 .707 r
F P
0 g
s
.14795 .77315 m .15006 .75404 L .15662 .75503 L p .707 .577 .707 r
F P
0 g
s
.1611 .67506 m .16463 .61787 L .18084 .61561 L p .707 .577 .707 r
F P
0 g
s
.65883 .28447 m .6268 .80092 L .62251 .79541 L p .707 .577 .707 r
F P
0 g
s
.62251 .79541 m .65454 .27896 L .65883 .28447 L p .707 .577 .707 r
F P
0 g
s
.18084 .61561 m .17731 .6728 L .1611 .67506 L p .707 .577 .707 r
F P
0 g
s
.15728 .73458 m .16108 .69631 L .17703 .69732 L p .707 .577 .707 r
F P
0 g
s
.17703 .69732 m .17323 .73559 L .15728 .73458 L p .707 .577 .707 r
F P
0 g
s
.17246 .75701 m .17035 .77613 L .1545 .77414 L p .707 .577 .707 r
F P
0 g
s
.1545 .77414 m .15662 .75503 L .17246 .75701 L p .707 .577 .707 r
F P
0 g
s
.34554 .62683 m .34201 .68402 L .32088 .67992 L p .707 .577 .707 r
F P
0 g
s
.32088 .67992 m .32441 .62273 L .34554 .62683 L p .707 .577 .707 r
F P
0 g
s
.3394 .78126 m .37143 .26481 L .3812 .26026 L p .707 .577 .707 r
F P
0 g
s
.17731 .6728 m .18084 .61561 L .20475 .61458 L p .707 .577 .707 r
F P
0 g
s
.3413 .71381 m .3375 .75208 L .31625 .74948 L p .707 .577 .707 r
F P
0 g
s
.31625 .74948 m .32005 .71121 L .3413 .71381 L p .707 .577 .707 r
F P
0 g
s
.20475 .61458 m .20122 .67177 L .17731 .6728 L p .707 .577 .707 r
F P
0 g
s
.33657 .77508 m .33446 .7942 L .31316 .79205 L p .707 .577 .707 r
F P
0 g
s
.31316 .79205 m .31527 .77293 L .33657 .77508 L p .707 .577 .707 r
F P
0 g
s
.17323 .73559 m .17703 .69732 L .2007 .69923 L p .707 .577 .707 r
F P
0 g
s
.2007 .69923 m .1969 .7375 L .17323 .73559 L p .707 .577 .707 r
F P
0 g
s
.32441 .62273 m .32088 .67992 L .2934 .67634 L p .707 .577 .707 r
F P
0 g
s
.2934 .67634 m .29693 .61915 L .32441 .62273 L p .707 .577 .707 r
F P
0 g
s
.19604 .7598 m .19393 .77891 L .17035 .77613 L p .707 .577 .707 r
F P
0 g
s
.17035 .77613 m .17246 .75701 L .19604 .7598 L p .707 .577 .707 r
F P
0 g
s
.20122 .67177 m .20475 .61458 L .23402 .61486 L p .707 .577 .707 r
F P
0 g
s
.65454 .27896 m .62251 .79541 L .60457 .78948 L p .707 .577 .707 r
F P
0 g
s
.60457 .78948 m .6366 .27302 L .65454 .27896 L p .707 .577 .707 r
F P
0 g
s
.23402 .61486 m .23049 .67205 L .20122 .67177 L p .707 .577 .707 r
F P
0 g
s
.32005 .71121 m .31625 .74948 L .28872 .74642 L p .707 .577 .707 r
F P
0 g
s
.28872 .74642 m .29253 .70815 L .32005 .71121 L p .707 .577 .707 r
F P
0 g
s
.29693 .61915 m .2934 .67634 L .26225 .67362 L p .707 .577 .707 r
F P
0 g
s
.26225 .67362 m .26578 .61643 L .29693 .61915 L p .707 .577 .707 r
F P
0 g
s
.31527 .77293 m .31316 .79205 L .28562 .78913 L p .707 .577 .707 r
F P
0 g
s
.28562 .78913 m .28773 .77002 L .31527 .77293 L p .707 .577 .707 r
F P
0 g
s
.23049 .67205 m .23402 .61486 L .26578 .61643 L p .707 .577 .707 r
F P
0 g
s
.7299 .64631 m .73343 .58912 L .70228 .58641 L p .707 .577 .707 r
F P
0 g
s
.73343 .58912 m .7299 .64631 L .76166 .64788 L p .707 .577 .707 r
F P
0 g
s
.76166 .64788 m .76519 .59069 L .73343 .58912 L p .707 .577 .707 r
F P
0 g
s
.1969 .7375 m .2007 .69923 L .22978 .70185 L p .707 .577 .707 r
F P
0 g
s
.22978 .70185 m .22598 .74011 L .1969 .7375 L p .707 .577 .707 r
F P
0 g
s
.34918 .77672 m .3812 .26026 L .40408 .25712 L p .707 .577 .707 r
F P
0 g
s
.3812 .26026 m .34918 .77672 L .3394 .78126 L p .707 .577 .707 r
F P
0 g
s
.26578 .61643 m .26225 .67362 L .23049 .67205 L p .707 .577 .707 r
F P
0 g
s
.76519 .59069 m .76166 .64788 L .79093 .64816 L p .707 .577 .707 r
F P
0 g
s
.79093 .64816 m .79446 .59097 L .76519 .59069 L p .707 .577 .707 r
F P
0 g
s
.22505 .76311 m .22293 .78223 L .19393 .77891 L p .707 .577 .707 r
F P
0 g
s
.19393 .77891 m .19604 .7598 L .22505 .76311 L p .707 .577 .707 r
F P
0 g
s
.69875 .6436 m .70228 .58641 L .6748 .58282 L p .707 .577 .707 r
F P
0 g
s
.70228 .58641 m .69875 .6436 L .7299 .64631 L p .707 .577 .707 r
F P
0 g
s
.29253 .70815 m .28872 .74642 L .25762 .74319 L p .707 .577 .707 r
F P
0 g
s
.25762 .74319 m .26142 .70492 L .29253 .70815 L p .707 .577 .707 r
F P
0 g
s
.22598 .74011 m .22978 .70185 L .26142 .70492 L p .707 .577 .707 r
F P
0 g
s
.6748 .58282 m .67127 .64001 L .69875 .6436 L p .707 .577 .707 r
F P
0 g
s
.72689 .70202 m .73069 .66375 L .69958 .66052 L p .707 .577 .707 r
F P
0 g
s
.73069 .66375 m .72689 .70202 L .75853 .70509 L p .707 .577 .707 r
F P
0 g
s
.75853 .70509 m .76233 .66682 L .73069 .66375 L p .707 .577 .707 r
F P
0 g
s
.26142 .70492 m .25762 .74319 L .22598 .74011 L p .707 .577 .707 r
F P
0 g
s
.28773 .77002 m .28562 .78913 L .25453 .78575 L p .707 .577 .707 r
F P
0 g
s
.69958 .66052 m .69578 .69879 L .72689 .70202 L p .707 .577 .707 r
F P
0 g
s
.25453 .78575 m .25664 .76664 L .28773 .77002 L p .707 .577 .707 r
F P
0 g
s
.79446 .59097 m .79093 .64816 L .81484 .64713 L p .707 .577 .707 r
F P
0 g
s
.81484 .64713 m .81837 .58994 L .79446 .59097 L p .707 .577 .707 r
F P
0 g
s
.76233 .66682 m .75853 .70509 L .78761 .70771 L p .707 .577 .707 r
F P
0 g
s
.78761 .70771 m .79141 .66944 L .76233 .66682 L p .707 .577 .707 r
F P
0 g
s
.25664 .76664 m .25453 .78575 L .22293 .78223 L p .707 .577 .707 r
F P
0 g
s
.22293 .78223 m .22505 .76311 L .25664 .76664 L p .707 .577 .707 r
F P
0 g
s
.69578 .69879 m .69958 .66052 L .67206 .65746 L p .707 .577 .707 r
F P
0 g
s
.69545 .72486 m .69334 .74397 L .72443 .74736 L p .707 .577 .707 r
F P
0 g
s
.72443 .74736 m .72654 .72824 L .69545 .72486 L p .707 .577 .707 r
F P
0 g
s
.72654 .72824 m .72443 .74736 L .75602 .75088 L p .707 .577 .707 r
F P
0 g
s
.75602 .75088 m .75813 .73176 L .72654 .72824 L p .707 .577 .707 r
F P
0 g
s
.67206 .65746 m .66826 .69573 L .69578 .69879 L p .707 .577 .707 r
F P
0 g
s
.67127 .64001 m .6748 .58282 L .65367 .57872 L p .707 .577 .707 r
F P
0 g
s
.75813 .73176 m .75602 .75088 L .78503 .75419 L p .707 .577 .707 r
F P
0 g
s
.78503 .75419 m .78714 .73508 L .75813 .73176 L p .707 .577 .707 r
F P
0 g
s
.66791 .72195 m .6658 .74106 L .69334 .74397 L p .707 .577 .707 r
F P
0 g
s
.69334 .74397 m .69545 .72486 L .66791 .72195 L p .707 .577 .707 r
F P
0 g
s
.6366 .27302 m .60457 .78948 L .57474 .7837 L p .707 .577 .707 r
F P
0 g
s
.57474 .7837 m .60676 .26725 L .6366 .27302 L p .707 .577 .707 r
F P
0 g
s
.65367 .57872 m .65014 .63591 L .67127 .64001 L p .707 .577 .707 r
F P
0 g
s
.79141 .66944 m .78761 .70771 L .81128 .70962 L p .707 .577 .707 r
F P
0 g
s
.81128 .70962 m .81508 .67135 L .79141 .66944 L p .707 .577 .707 r
F P
0 g
s
.66826 .69573 m .67206 .65746 L .65081 .65485 L p .707 .577 .707 r
F P
0 g
s
.65081 .65485 m .64701 .69312 L .66826 .69573 L p .707 .577 .707 r
F P
0 g
s
.78714 .73508 m .78503 .75419 L .80861 .75698 L p .707 .577 .707 r
F P
0 g
s
.80861 .75698 m .81072 .73787 L .78714 .73508 L p .707 .577 .707 r
F P
0 g
s
.81837 .58994 m .81484 .64713 L .83105 .64487 L p .707 .577 .707 r
F P
0 g
s
.83105 .64487 m .83458 .58768 L .81837 .58994 L p .707 .577 .707 r
F P
0 g
s
.40408 .25712 m .37206 .77357 L .34918 .77672 L p .707 .577 .707 r
F P
0 g
s
.37206 .77357 m .40408 .25712 L .43784 .2557 L p .707 .577 .707 r
F P
0 g
s
.64661 .71979 m .6445 .73891 L .6658 .74106 L p .707 .577 .707 r
F P
0 g
s
.6658 .74106 m .66791 .72195 L .64661 .71979 L p .707 .577 .707 r
F P
0 g
s
.65014 .63591 m .65367 .57872 L .64096 .5745 L p .707 .577 .707 r
F P
0 g
s
.81508 .67135 m .81128 .70962 L .82723 .71063 L p .707 .577 .707 r
F P
0 g
s
.82723 .71063 m .83103 .67236 L .81508 .67135 L p .707 .577 .707 r
F P
0 g
s
.64096 .5745 m .63744 .63169 L .65014 .63591 L p .707 .577 .707 r
F P
0 g
s
.81072 .73787 m .80861 .75698 L .82445 .75897 L p .707 .577 .707 r
F P
0 g
s
.82445 .75897 m .82656 .73985 L .81072 .73787 L p .707 .577 .707 r
F P
0 g
s
.64701 .69312 m .65081 .65485 L .63791 .65297 L p .707 .577 .707 r
F P
0 g
s
.63791 .65297 m .63411 .69124 L .64701 .69312 L p .707 .577 .707 r
F P
0 g
s
.60676 .26725 m .57474 .7837 L .53594 .77865 L p .707 .577 .707 r
F P
0 g
s
.53594 .77865 m .56796 .2622 L .60676 .26725 L p .707 .577 .707 r
F P
0 g
s
.83458 .58768 m .83105 .64487 L .83797 .64162 L p .707 .577 .707 r
F P
0 g
s
.83797 .64162 m .8415 .58443 L .83458 .58768 L p .707 .577 .707 r
F P
0 g
s
.63364 .7186 m .63153 .73772 L .6445 .73891 L p .707 .577 .707 r
F P
0 g
s
.6445 .73891 m .64661 .71979 L .63364 .7186 L p .707 .577 .707 r
F P
0 g
s
.40581 .77215 m .43784 .2557 L .47915 .25613 L p .707 .577 .707 r
F P
0 g
s
.43784 .2557 m .40581 .77215 L .37206 .77357 L p .707 .577 .707 r
F P
0 g
s
.63744 .63169 m .64096 .5745 L .63792 .57057 L p .707 .577 .707 r
F P
0 g
s
.83103 .67236 m .82723 .71063 L .83389 .71064 L p .707 .577 .707 r
F P
0 g
s
.83389 .71064 m .83769 .67237 L .83103 .67236 L p .707 .577 .707 r
F P
0 g
s
.63792 .57057 m .63439 .62776 L .63744 .63169 L p .707 .577 .707 r
F P
0 g
s
.56796 .2622 m .53594 .77865 L .49196 .77482 L p .707 .577 .707 r
F P
0 g
s
.49196 .77482 m .52399 .25837 L .56796 .2622 L p .707 .577 .707 r
F P
0 g
s
.82656 .73985 m .82445 .75897 L .83101 .75996 L p .707 .577 .707 r
F P
0 g
s
.83101 .75996 m .83312 .74084 L .82656 .73985 L p .707 .577 .707 r
F P
0 g
s
.44712 .77258 m .47915 .25613 L .52399 .25837 L p .707 .577 .707 r
F P
0 g
s
.47915 .25613 m .44712 .77258 L .40581 .77215 L p .707 .577 .707 r
F P
0 g
s
.63411 .69124 m .63791 .65297 L .63464 .65198 L p .707 .577 .707 r
F P
0 g
s
.63464 .65198 m .63083 .69025 L .63411 .69124 L p .707 .577 .707 r
F P
0 g
s
.52399 .25837 m .49196 .77482 L .44712 .77258 L p .707 .577 .707 r
F P
0 g
s
.8415 .58443 m .83797 .64162 L .83493 .63769 L p .707 .577 .707 r
F P
0 g
s
.83493 .63769 m .83846 .5805 L .8415 .58443 L p .707 .577 .707 r
F P
0 g
s
.63027 .7185 m .62816 .73762 L .63153 .73772 L p .707 .577 .707 r
F P
0 g
s
.63153 .73772 m .63364 .7186 L .63027 .7185 L p .707 .577 .707 r
F P
0 g
s
.63439 .62776 m .63792 .57057 L .64485 .56732 L p .707 .577 .707 r
F P
0 g
s
.83769 .67237 m .83389 .71064 L .83061 .70966 L p .707 .577 .707 r
F P
0 g
s
.83061 .70966 m .83441 .67139 L .83769 .67237 L p .707 .577 .707 r
F P
0 g
s
.64485 .56732 m .64132 .62451 L .63439 .62776 L p .707 .577 .707 r
F P
0 g
s
.83312 .74084 m .83101 .75996 L .82764 .75985 L p .707 .577 .707 r
F P
0 g
s
.82764 .75985 m .82975 .74074 L .83312 .74084 L p .707 .577 .707 r
F P
0 g
s
.63083 .69025 m .63464 .65198 L .6413 .652 L p .707 .577 .707 r
F P
0 g
s
.6413 .652 m .63749 .69027 L .63083 .69025 L p .707 .577 .707 r
F P
0 g
s
.83846 .5805 m .83493 .63769 L .82223 .63347 L p .707 .577 .707 r
F P
0 g
s
.82223 .63347 m .82575 .57628 L .83846 .5805 L p .707 .577 .707 r
F P
0 g
s
.63683 .71949 m .63472 .7386 L .62816 .73762 L p .707 .577 .707 r
F P
0 g
s
.62816 .73762 m .63027 .7185 L .63683 .71949 L p .707 .577 .707 r
F P
0 g
s
.38689 .60949 m .39042 .5523 L .35927 .54959 L p .707 .577 .707 r
F P
0 g
s
.39042 .5523 m .38689 .60949 L .41865 .61106 L p .707 .577 .707 r
F P
0 g
s
.41865 .61106 m .42218 .55387 L .39042 .5523 L p .707 .577 .707 r
F P
0 g
s
.42218 .55387 m .41865 .61106 L .44792 .61135 L p .707 .577 .707 r
F P
0 g
s
.44792 .61135 m .45145 .55416 L .42218 .55387 L p .707 .577 .707 r
F P
0 g
s
.64132 .62451 m .64485 .56732 L .66105 .56506 L p .707 .577 .707 r
F P
0 g
s
.35574 .60678 m .35927 .54959 L .33179 .54601 L p .707 .577 .707 r
F P
0 g
s
.35927 .54959 m .35574 .60678 L .38689 .60949 L p .707 .577 .707 r
F P
0 g
s
.83441 .67139 m .83061 .70966 L .81771 .70777 L p .707 .577 .707 r
F P
0 g
s
.81771 .70777 m .82152 .6695 L .83441 .67139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66105 .56506 m .65753 .62225 L .64132 .62451 L p .707 .577 .707 r
F P
0 g
s
.33179 .54601 m .32826 .6032 L .35574 .60678 L p .707 .577 .707 r
F P
0 g
s
.38388 .6652 m .38768 .62694 L .35657 .62371 L p .707 .577 .707 r
F P
0 g
s
.38768 .62694 m .38388 .6652 L .41552 .66828 L p .707 .577 .707 r
F P
0 g
s
.41552 .66828 m .41932 .63001 L .38768 .62694 L p .707 .577 .707 r
F P
0 g
s
.35657 .62371 m .35277 .66198 L .38388 .6652 L p .707 .577 .707 r
F P
0 g
s
.45145 .55416 m .44792 .61135 L .47183 .61031 L p .707 .577 .707 r
F P
0 g
s
.47183 .61031 m .47536 .55312 L .45145 .55416 L p .707 .577 .707 r
F P
0 g
s
.41932 .63001 m .41552 .66828 L .4446 .6709 L p .707 .577 .707 r
F P
0 g
s
.4446 .6709 m .4484 .63263 L .41932 .63001 L p .707 .577 .707 r
F P
0 g
s
.82975 .74074 m .82764 .75985 L .81467 .75866 L p .707 .577 .707 r
F P
0 g
s
.81467 .75866 m .81678 .73955 L .82975 .74074 L p .707 .577 .707 r
F P
0 g
s
.63749 .69027 m .6413 .652 L .65724 .65301 L p .707 .577 .707 r
F P
0 g
s
.35277 .66198 m .35657 .62371 L .32905 .62064 L p .707 .577 .707 r
F P
0 g
s
.35244 .68804 m .35033 .70716 L .38142 .71054 L p .707 .577 .707 r
F P
0 g
s
.38142 .71054 m .38353 .69142 L .35244 .68804 L p .707 .577 .707 r
F P
0 g
s
.38353 .69142 m .38142 .71054 L .41301 .71406 L p .707 .577 .707 r
F P
0 g
s
.65724 .65301 m .65344 .69128 L .63749 .69027 L p .707 .577 .707 r
F P
0 g
s
.41301 .71406 m .41512 .69495 L .38353 .69142 L p .707 .577 .707 r
F P
0 g
s
.32905 .62064 m .32525 .65891 L .35277 .66198 L p .707 .577 .707 r
F P
0 g
s
.32826 .6032 m .33179 .54601 L .31066 .5419 L p .707 .577 .707 r
F P
0 g
s
.41512 .69495 m .41301 .71406 L .44202 .71738 L p .707 .577 .707 r
F P
0 g
s
.44202 .71738 m .44413 .69826 L .41512 .69495 L p .707 .577 .707 r
F P
0 g
s
.82575 .57628 m .82223 .63347 L .8011 .62937 L p .707 .577 .707 r
F P
0 g
s
.8011 .62937 m .80462 .57218 L .82575 .57628 L p .707 .577 .707 r
F P
0 g
s
.65268 .72147 m .65056 .74059 L .63472 .7386 L p .707 .577 .707 r
F P
0 g
s
.63472 .7386 m .63683 .71949 L .65268 .72147 L p .707 .577 .707 r
F P
0 g
s
.3249 .68513 m .32279 .70425 L .35033 .70716 L p .707 .577 .707 r
F P
0 g
s
.35033 .70716 m .35244 .68804 L .3249 .68513 L p .707 .577 .707 r
F P
0 g
s
.31066 .5419 m .30713 .59909 L .32826 .6032 L p .707 .577 .707 r
F P
0 g
s
.4484 .63263 m .4446 .6709 L .46827 .6728 L p .707 .577 .707 r
F P
0 g
s
.46827 .6728 m .47207 .63454 L .4484 .63263 L p .707 .577 .707 r
F P
0 g
s
.65753 .62225 m .66105 .56506 L .68496 .56403 L p .707 .577 .707 r
F P
0 g
s
.32525 .65891 m .32905 .62064 L .3078 .61804 L p .707 .577 .707 r
F P
0 g
s
.3078 .61804 m .304 .65631 L .32525 .65891 L p .707 .577 .707 r
F P
0 g
s
.44413 .69826 m .44202 .71738 L .4656 .72017 L p .707 .577 .707 r
F P
0 g
s
.4656 .72017 m .46771 .70105 L .44413 .69826 L p .707 .577 .707 r
F P
0 g
s
.47536 .55312 m .47183 .61031 L .48804 .60806 L p .707 .577 .707 r
F P
0 g
s
.48804 .60806 m .49157 .55087 L .47536 .55312 L p .707 .577 .707 r
F P
0 g
s
.82152 .6695 m .81771 .70777 L .79646 .70517 L p .707 .577 .707 r
F P
0 g
s
.79646 .70517 m .80027 .6669 L .82152 .6695 L p .707 .577 .707 r
F P
0 g
s
.68496 .56403 m .68144 .62122 L .65753 .62225 L p .707 .577 .707 r
F P
0 g
s
.3036 .68298 m .30149 .70209 L .32279 .70425 L p .707 .577 .707 r
F P
0 g
s
.32279 .70425 m .3249 .68513 L .3036 .68298 L p .707 .577 .707 r
F P
0 g
s
.30713 .59909 m .31066 .5419 L .29795 .53768 L p .707 .577 .707 r
F P
0 g
s
.81678 .73955 m .81467 .75866 L .79337 .75651 L p .707 .577 .707 r
F P
0 g
s
.79337 .75651 m .79549 .73739 L .81678 .73955 L p .707 .577 .707 r
F P
0 g
s
.65344 .69128 m .65724 .65301 L .68091 .65492 L p .707 .577 .707 r
F P
0 g
s
.80462 .57218 m .8011 .62937 L .77361 .62579 L p .707 .577 .707 r
F P
0 g
s
.77361 .62579 m .77714 .5686 L .80462 .57218 L p .707 .577 .707 r
F P
0 g
s
.68091 .65492 m .67711 .69318 L .65344 .69128 L p .707 .577 .707 r
F P
0 g
s
.47207 .63454 m .46827 .6728 L .48422 .67381 L p .707 .577 .707 r
F P
0 g
s
.48422 .67381 m .48802 .63555 L .47207 .63454 L p .707 .577 .707 r
F P
0 g
s
.29795 .53768 m .29442 .59487 L .30713 .59909 L p .707 .577 .707 r
F P
0 g
s
.68144 .62122 m .68496 .56403 L .71423 .56431 L p .707 .577 .707 r
F P
0 g
s
.67625 .72426 m .67414 .74338 L .65056 .74059 L p .707 .577 .707 r
F P
0 g
s
.65056 .74059 m .65268 .72147 L .67625 .72426 L p .707 .577 .707 r
F P
0 g
s
.46771 .70105 m .4656 .72017 L .48144 .72215 L p .707 .577 .707 r
F P
0 g
s
.48144 .72215 m .48355 .70304 L .46771 .70105 L p .707 .577 .707 r
F P
0 g
s
.304 .65631 m .3078 .61804 L .2949 .61615 L p .707 .577 .707 r
F P
0 g
s
.2949 .61615 m .2911 .65442 L .304 .65631 L p .707 .577 .707 r
F P
0 g
s
.71423 .56431 m .7107 .6215 L .68144 .62122 L p .707 .577 .707 r
F P
0 g
s
.80027 .6669 m .79646 .70517 L .76894 .7021 L p .707 .577 .707 r
F P
0 g
s
.76894 .7021 m .77274 .66384 L .80027 .6669 L p .707 .577 .707 r
F P
0 g
s
.77714 .5686 m .77361 .62579 L .74247 .62307 L p .707 .577 .707 r
F P
0 g
s
.74247 .62307 m .74599 .56588 L .77714 .5686 L p .707 .577 .707 r
F P
0 g
s
.49157 .55087 m .48804 .60806 L .49496 .60481 L p .707 .577 .707 r
F P
0 g
s
.49496 .60481 m .49849 .54762 L .49157 .55087 L p .707 .577 .707 r
F P
0 g
s
.29063 .68179 m .28852 .7009 L .30149 .70209 L p .707 .577 .707 r
F P
0 g
s
.30149 .70209 m .3036 .68298 L .29063 .68179 L p .707 .577 .707 r
F P
0 g
s
.7107 .6215 m .71423 .56431 L .74599 .56588 L p .707 .577 .707 r
F P
0 g
s
.67711 .69318 m .68091 .65492 L .70999 .65753 L p .707 .577 .707 r
F P
0 g
s
.70999 .65753 m .70619 .6958 L .67711 .69318 L p .707 .577 .707 r
F P
0 g
s
.79549 .73739 m .79337 .75651 L .76583 .7536 L p .707 .577 .707 r
F P
0 g
s
.76583 .7536 m .76794 .73448 L .79549 .73739 L p .707 .577 .707 r
F P
0 g
s
.74599 .56588 m .74247 .62307 L .7107 .6215 L p .707 .577 .707 r
F P
0 g
s
.29442 .59487 m .29795 .53768 L .29491 .53375 L p .707 .577 .707 r
F P
0 g
s
.70526 .72758 m .70315 .74669 L .67414 .74338 L p .707 .577 .707 r
F P
0 g
s
.67414 .74338 m .67625 .72426 L .70526 .72758 L p .707 .577 .707 r
F P
0 g
s
.77274 .66384 m .76894 .7021 L .73783 .69888 L p .707 .577 .707 r
F P
0 g
s
.73783 .69888 m .74163 .66061 L .77274 .66384 L p .707 .577 .707 r
F P
0 g
s
.48802 .63555 m .48422 .67381 L .49088 .67383 L p .707 .577 .707 r
F P
0 g
s
.49088 .67383 m .49468 .63556 L .48802 .63555 L p .707 .577 .707 r
F P
0 g
s
.29491 .53375 m .29138 .59094 L .29442 .59487 L p .707 .577 .707 r
F P
0 g
s
.70619 .6958 m .70999 .65753 L .74163 .66061 L p .707 .577 .707 r
F P
0 g
s
.74163 .66061 m .73783 .69888 L .70619 .6958 L p .707 .577 .707 r
F P
0 g
s
.76794 .73448 m .76583 .7536 L .73474 .75022 L p .707 .577 .707 r
F P
0 g
s
.73474 .75022 m .73686 .7311 L .76794 .73448 L p .707 .577 .707 r
F P
0 g
s
.48355 .70304 m .48144 .72215 L .488 .72314 L p .707 .577 .707 r
F P
0 g
s
.488 .72314 m .49011 .70403 L .48355 .70304 L p .707 .577 .707 r
F P
0 g
s
.2911 .65442 m .2949 .61615 L .29163 .61517 L p .707 .577 .707 r
F P
0 g
s
.73686 .7311 m .73474 .75022 L .70315 .74669 L p .707 .577 .707 r
F P
0 g
s
.70315 .74669 m .70526 .72758 L .73686 .7311 L p .707 .577 .707 r
F P
0 g
s
.29163 .61517 m .28782 .65344 L .2911 .65442 L p .707 .577 .707 r
F P
0 g
s
.49849 .54762 m .49496 .60481 L .49192 .60088 L p .707 .577 .707 r
F P
0 g
s
.49192 .60088 m .49545 .54369 L .49849 .54762 L p .707 .577 .707 r
F P
0 g
s
.28726 .68168 m .28515 .7008 L .28852 .7009 L p .707 .577 .707 r
F P
0 g
s
.28852 .7009 m .29063 .68179 L .28726 .68168 L p .707 .577 .707 r
F P
0 g
s
.29138 .59094 m .29491 .53375 L .30183 .5305 L p .707 .577 .707 r
F P
0 g
s
.49468 .63556 m .49088 .67383 L .4876 .67284 L p .707 .577 .707 r
F P
0 g
s
.4876 .67284 m .4914 .63457 L .49468 .63556 L p .707 .577 .707 r
F P
0 g
s
.30183 .5305 m .29831 .58769 L .29138 .59094 L p .707 .577 .707 r
F P
0 g
s
.49011 .70403 m .488 .72314 L .48463 .72304 L p .707 .577 .707 r
F P
0 g
s
.48463 .72304 m .48674 .70392 L .49011 .70403 L p .707 .577 .707 r
F P
0 g
s
.28782 .65344 m .29163 .61517 L .29829 .61518 L p .707 .577 .707 r
F P
0 g
s
.29829 .61518 m .29448 .65345 L .28782 .65344 L p .707 .577 .707 r
F P
0 g
s
.49545 .54369 m .49192 .60088 L .47921 .59666 L p .707 .577 .707 r
F P
0 g
s
.47921 .59666 m .48274 .53947 L .49545 .54369 L p .707 .577 .707 r
F P
0 g
s
.29382 .68267 m .29171 .70179 L .28515 .7008 L p .707 .577 .707 r
F P
0 g
s
.28515 .7008 m .28726 .68168 L .29382 .68267 L p .707 .577 .707 r
F P
0 g
s
.29831 .58769 m .30183 .5305 L .31804 .52825 L p .707 .577 .707 r
F P
0 g
s
.4914 .63457 m .4876 .67284 L .4747 .67096 L p .707 .577 .707 r
F P
0 g
s
.4747 .67096 m .4785 .63269 L .4914 .63457 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31804 .52825 m .31452 .58544 L .29831 .58769 L p .707 .577 .707 r
F P
0 g
s
.48674 .70392 m .48463 .72304 L .47166 .72185 L p .707 .577 .707 r
F P
0 g
s
.47166 .72185 m .47377 .70273 L .48674 .70392 L p .707 .577 .707 r
F P
0 g
s
.29448 .65345 m .29829 .61518 L .31423 .61619 L p .707 .577 .707 r
F P
0 g
s
.31423 .61619 m .31043 .65446 L .29448 .65345 L p .707 .577 .707 r
F P
0 g
s
.48274 .53947 m .47921 .59666 L .45809 .59255 L p .707 .577 .707 r
F P
0 g
s
.45809 .59255 m .46161 .53536 L .48274 .53947 L p .707 .577 .707 r
F P
0 g
s
.30966 .68466 m .30755 .70377 L .29171 .70179 L p .707 .577 .707 r
F P
0 g
s
.29171 .70179 m .29382 .68267 L .30966 .68466 L p .707 .577 .707 r
F P
0 g
s
.31452 .58544 m .31804 .52825 L .34195 .52721 L p .707 .577 .707 r
F P
0 g
s
.4785 .63269 m .4747 .67096 L .45345 .66835 L p .707 .577 .707 r
F P
0 g
s
.45345 .66835 m .45725 .63009 L .4785 .63269 L p .707 .577 .707 r
F P
0 g
s
.34195 .52721 m .33842 .5844 L .31452 .58544 L p .707 .577 .707 r
F P
0 g
s
.47377 .70273 m .47166 .72185 L .45036 .71969 L p .707 .577 .707 r
F P
0 g
s
.45036 .71969 m .45248 .70058 L .47377 .70273 L p .707 .577 .707 r
F P
0 g
s
.31043 .65446 m .31423 .61619 L .3379 .6181 L p .707 .577 .707 r
F P
0 g
s
.46161 .53536 m .45809 .59255 L .4306 .58897 L p .707 .577 .707 r
F P
0 g
s
.4306 .58897 m .43413 .53178 L .46161 .53536 L p .707 .577 .707 r
F P
0 g
s
.3379 .6181 m .3341 .65637 L .31043 .65446 L p .707 .577 .707 r
F P
0 g
s
.33842 .5844 m .34195 .52721 L .37122 .5275 L p .707 .577 .707 r
F P
0 g
s
.33324 .68745 m .33113 .70656 L .30755 .70377 L p .707 .577 .707 r
F P
0 g
s
.30755 .70377 m .30966 .68466 L .33324 .68745 L p .707 .577 .707 r
F P
0 g
s
.37122 .5275 m .36769 .58469 L .33842 .5844 L p .707 .577 .707 r
F P
0 g
s
.45725 .63009 m .45345 .66835 L .42593 .66529 L p .707 .577 .707 r
F P
0 g
s
.42593 .66529 m .42973 .62702 L .45725 .63009 L p .707 .577 .707 r
F P
0 g
s
.43413 .53178 m .4306 .58897 L .39945 .58626 L p .707 .577 .707 r
F P
0 g
s
.39945 .58626 m .40298 .52907 L .43413 .53178 L p .707 .577 .707 r
F P
0 g
s
.36769 .58469 m .37122 .5275 L .40298 .52907 L p .707 .577 .707 r
F P
0 g
s
.3341 .65637 m .3379 .6181 L .36698 .62072 L p .707 .577 .707 r
F P
0 g
s
.36698 .62072 m .36318 .65899 L .3341 .65637 L p .707 .577 .707 r
F P
0 g
s
.45248 .70058 m .45036 .71969 L .42282 .71678 L p .707 .577 .707 r
F P
0 g
s
.42282 .71678 m .42493 .69767 L .45248 .70058 L p .707 .577 .707 r
F P
0 g
s
.40298 .52907 m .39945 .58626 L .36769 .58469 L p .707 .577 .707 r
F P
0 g
s
.36225 .69076 m .36014 .70988 L .33113 .70656 L p .707 .577 .707 r
F P
0 g
s
.33113 .70656 m .33324 .68745 L .36225 .69076 L p .707 .577 .707 r
F P
0 g
s
.42973 .62702 m .42593 .66529 L .39482 .66206 L p .707 .577 .707 r
F P
0 g
s
.39482 .66206 m .39862 .62379 L .42973 .62702 L p .707 .577 .707 r
F P
0 g
s
.36318 .65899 m .36698 .62072 L .39862 .62379 L p .707 .577 .707 r
F P
0 g
s
.39862 .62379 m .39482 .66206 L .36318 .65899 L p .707 .577 .707 r
F P
0 g
s
.42493 .69767 m .42282 .71678 L .39173 .7134 L p .707 .577 .707 r
F P
0 g
s
.39173 .7134 m .39384 .69428 L .42493 .69767 L p .707 .577 .707 r
F P
0 g
s
.39384 .69428 m .39173 .7134 L .36014 .70988 L p .707 .577 .707 r
F P
0 g
s
.36014 .70988 m .36225 .69076 L .39384 .69428 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00N7oo5P00Sgoo001`Ool80004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH=0022Ool006]oo`D0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEPT007Uoo`00JGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Lgoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF
1P00KGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEPH006Moo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEP00008006Aoo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80069oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065o
o`00JGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HGoo
001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00HGoo001XOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HWoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIo
o`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1ROol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001NOol70002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Eoo`T000=JEP04001JEUYFFUHC000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`<000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo7P00AGoo
001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP003eoo`00DWoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPL003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF008000eJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0
039oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5
00001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo1@000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool005Yoo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
001QOol80004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP040000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool006=oo`04001JEUYF0002FUHP0005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0002eoo`00=goo40002goo1@0037oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02ioo`T000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`03001JEP00009JEPd0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000^Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP04001JEUYFFUH90009FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF001JEUYF5P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EQ0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000AJEP04
001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH<0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000`003EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000017oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000Moo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000aooa80
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0001iooaH003=oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP/005moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF4@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@0
05YFFUIJEQ0004moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@00AWoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH90004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0002FUH01000FUIJEUYF2@000eYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000gOol0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEQH0
009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP08000_Ool002]oo`03001JEP00024000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP/00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP@000=JEPL000=JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH30003FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUHC0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo000^Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH200000eYF001JEP03FUH00`00FUIJEP0>00000eYF001JEP02FUH500000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000cOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF4@0000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF2`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool003Yoo`P000AJEP03001JEUYF00MJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUHG0004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[OolB0005
OolA0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP02FUH90003FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@002goo10000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPh0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000MJ
EP03001JEUYF00=JEP04001JEUYFFUH20002Ool90003FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH90006Ool=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P002goo20000eYF1`000eYF00@005YFFUIJEP8002mo
o`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200027oo300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000COolC000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH01000FUIJ
EUYF300015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000QOol5000_Ool002Yoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00
FUIJEP04FUH;0004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH70003FUH01000FUIJEUYF0P002Goo0`00BGoo
000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH00UYF2P000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001P001EYF10000eYF0P0027oo1@00B7oo000ZOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0800000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00
FUH005YF001JEPh00003FUH0000000Qoo`D004Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00AJEP04001JEUYFFUH90003Ool50018Ool002Yoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004Moo`00:Woo1@000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?goo000[OolA
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF2P00=Goo000bOol7
0003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000020000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH02000<7oo000iOol90003FUH90004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040004Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02000`Ool0049oo`T000=JEPP000=JEP03001JEUYF00=JEP05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF1`0017oo2@0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo001;OolF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH0
20001Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80031oo`00:Woo2000
:Goo1P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000=Ool80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo
000ZOol00`00FUH00002FUH:000WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000MJEP03001JEUYF00=JEP04001JEUYFFUH2000EOol<0002FUH2000`Ool002Yoo`03
001JEP0000AJEP03001JEUYF010001aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP80025oo`@0031oo`00:Woo0P001EYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@004goo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00EGoo000ZOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30000UYF00@005YFFUIJEQh000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0005Eoo`00:goo2@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@000UYF100025YF00<005YFFUH025YF00<0
05YFFUH025YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol003Aoo`L000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00EWoo000kOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH70006FUH00`00FUIJEP02FUH00`00FUH000040004FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00EWoo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000035YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF
00<005YFFUH00UYF00@005YF000000=JEPL000=JEP04001JEUYFFUH2001FOol004eoo`P000AJEP03
001JEUYF00=JEP03001JEUYF00<000YJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEPD000=JEP04001JEP00OolC001FOol005Eoo``00004FUH0
0000Ool40006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP003goo1@00EWoo001QOol30005Ool40002
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH200000eYF001oo`1YOol006eoo`P000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00001ZOol007Eoo`/0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD006Uoo`00
P7oo3@001UYF00<005YFFUH02EYF00<005YFFUH00UYF6000HGoo002;OolI0006FUH00`00FUIJEP06
FUH01000FUIJEUYF3@00FGoo002?Ool90008FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00002001GOol009Uoo`P000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF008005Moo`00XGoo3@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Moo`00Zgoo2`0015YF00<005YFFUH00eYF00@005YFFUIJEP80
05Moo`00]7oo2@000eYF00@005YFFUIJEP8005Moo`00_Goo2@00Egoo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5927 .73367 m .59623 .67648 L .56508 .67377 L p .707 .577 .707 r
F P
0 g
s
.59623 .67648 m .5927 .73367 L .62446 .73524 L p .707 .577 .707 r
F P
0 g
s
.62446 .73524 m .62799 .67805 L .59623 .67648 L p .707 .577 .707 r
F P
0 g
s
.62799 .67805 m .62446 .73524 L .65373 .73553 L p .707 .577 .707 r
F P
0 g
s
.65373 .73553 m .65725 .67834 L .62799 .67805 L p .707 .577 .707 r
F P
0 g
s
.56155 .73096 m .56508 .67377 L .53759 .67019 L p .707 .577 .707 r
F P
0 g
s
.56508 .67377 m .56155 .73096 L .5927 .73367 L p .707 .577 .707 r
F P
0 g
s
.58968 .78315 m .59348 .74488 L .56238 .74165 L p .707 .577 .707 r
F P
0 g
s
.59348 .74488 m .58968 .78315 L .62132 .78622 L p .707 .577 .707 r
F P
0 g
s
.62132 .78622 m .62513 .74795 L .59348 .74488 L p .707 .577 .707 r
F P
0 g
s
.56238 .74165 m .55858 .77992 L .58968 .78315 L p .707 .577 .707 r
F P
0 g
s
.53759 .67019 m .53407 .72738 L .56155 .73096 L p .707 .577 .707 r
F P
0 g
s
.62513 .74795 m .62132 .78622 L .6504 .78884 L p .707 .577 .707 r
F P
0 g
s
.6504 .78884 m .65421 .75057 L .62513 .74795 L p .707 .577 .707 r
F P
0 g
s
.65725 .67834 m .65373 .73553 L .67764 .73449 L p .707 .577 .707 r
F P
0 g
s
.67764 .73449 m .68116 .6773 L .65725 .67834 L p .707 .577 .707 r
F P
0 g
s
.55825 .79721 m .55613 .81633 L .58722 .81971 L p .707 .577 .707 r
F P
0 g
s
.58722 .81971 m .58934 .80059 L .55825 .79721 L p .707 .577 .707 r
F P
0 g
s
.58934 .80059 m .58722 .81971 L .61882 .82323 L p .707 .577 .707 r
F P
0 g
s
.61882 .82323 m .62093 .80411 L .58934 .80059 L p .707 .577 .707 r
F P
0 g
s
.55858 .77992 m .56238 .74165 L .53485 .73858 L p .707 .577 .707 r
F P
0 g
s
.53485 .73858 m .53105 .77685 L .55858 .77992 L p .707 .577 .707 r
F P
0 g
s
.62093 .80411 m .61882 .82323 L .64782 .82655 L p .707 .577 .707 r
F P
0 g
s
.64782 .82655 m .64994 .80743 L .62093 .80411 L p .707 .577 .707 r
F P
0 g
s
.53407 .72738 m .53759 .67019 L .51647 .66608 L p .707 .577 .707 r
F P
0 g
s
.53071 .7943 m .52859 .81342 L .55613 .81633 L p .707 .577 .707 r
F P
0 g
s
.55613 .81633 m .55825 .79721 L .53071 .7943 L p .707 .577 .707 r
F P
0 g
s
.65421 .75057 m .6504 .78884 L .67407 .79075 L p .707 .577 .707 r
F P
0 g
s
.67407 .79075 m .67788 .75248 L .65421 .75057 L p .707 .577 .707 r
F P
0 g
s
.51647 .66608 m .51294 .72327 L .53407 .72738 L p .707 .577 .707 r
F P
0 g
s
.64994 .80743 m .64782 .82655 L .6714 .82933 L p .707 .577 .707 r
F P
0 g
s
.6714 .82933 m .67351 .81022 L .64994 .80743 L p .707 .577 .707 r
F P
0 g
s
.53105 .77685 m .53485 .73858 L .5136 .73598 L p .707 .577 .707 r
F P
0 g
s
.5136 .73598 m .5098 .77425 L .53105 .77685 L p .707 .577 .707 r
F P
0 g
s
.68116 .6773 m .67764 .73449 L .69384 .73224 L p .707 .577 .707 r
F P
0 g
s
.69384 .73224 m .69737 .67505 L .68116 .6773 L p .707 .577 .707 r
F P
0 g
s
.50941 .79214 m .50729 .81126 L .52859 .81342 L p .707 .577 .707 r
F P
0 g
s
.52859 .81342 m .53071 .7943 L .50941 .79214 L p .707 .577 .707 r
F P
0 g
s
.51294 .72327 m .51647 .66608 L .50376 .66186 L p .707 .577 .707 r
F P
0 g
s
.67788 .75248 m .67407 .79075 L .69002 .79176 L p .707 .577 .707 r
F P
0 g
s
.69002 .79176 m .69382 .75349 L .67788 .75248 L p .707 .577 .707 r
F P
0 g
s
.50376 .66186 m .50023 .71905 L .51294 .72327 L p .707 .577 .707 r
F P
0 g
s
.67351 .81022 m .6714 .82933 L .68725 .83132 L p .707 .577 .707 r
F P
0 g
s
.68725 .83132 m .68936 .8122 L .67351 .81022 L p .707 .577 .707 r
F P
0 g
s
.5098 .77425 m .5136 .73598 L .50071 .73409 L p .707 .577 .707 r
F P
0 g
s
.50071 .73409 m .49691 .77236 L .5098 .77425 L p .707 .577 .707 r
F P
0 g
s
.49644 .79096 m .49433 .81007 L .50729 .81126 L p .707 .577 .707 r
F P
0 g
s
.50729 .81126 m .50941 .79214 L .49644 .79096 L p .707 .577 .707 r
F P
0 g
s
.69737 .67505 m .69384 .73224 L .70077 .72899 L p .707 .577 .707 r
F P
0 g
s
.70077 .72899 m .7043 .6718 L .69737 .67505 L p .707 .577 .707 r
F P
0 g
s
.50023 .71905 m .50376 .66186 L .50072 .65793 L p .707 .577 .707 r
F P
0 g
s
.69382 .75349 m .69002 .79176 L .69668 .79177 L p .707 .577 .707 r
F P
0 g
s
.69668 .79177 m .70048 .7535 L .69382 .75349 L p .707 .577 .707 r
F P
0 g
s
.68936 .8122 m .68725 .83132 L .6938 .83231 L p .707 .577 .707 r
F P
0 g
s
.50072 .65793 m .49719 .71512 L .50023 .71905 L p .707 .577 .707 r
F P
0 g
s
.6938 .83231 m .69592 .81319 L .68936 .8122 L p .707 .577 .707 r
F P
0 g
s
.49691 .77236 m .50071 .73409 L .49743 .73311 L p .707 .577 .707 r
F P
0 g
s
.49743 .73311 m .49363 .77138 L .49691 .77236 L p .707 .577 .707 r
F P
0 g
s
.49307 .79085 m .49096 .80997 L .49433 .81007 L p .707 .577 .707 r
F P
0 g
s
.49433 .81007 m .49644 .79096 L .49307 .79085 L p .707 .577 .707 r
F P
0 g
s
.7043 .6718 m .70077 .72899 L .69773 .72506 L p .707 .577 .707 r
F P
0 g
s
.69773 .72506 m .70125 .66787 L .7043 .6718 L p .707 .577 .707 r
F P
0 g
s
.49719 .71512 m .50072 .65793 L .50764 .65468 L p .707 .577 .707 r
F P
0 g
s
.70048 .7535 m .69668 .79177 L .6934 .79079 L p .707 .577 .707 r
F P
0 g
s
.6934 .79079 m .69721 .75252 L .70048 .7535 L p .707 .577 .707 r
F P
0 g
s
.69592 .81319 m .6938 .83231 L .69043 .8322 L p .707 .577 .707 r
F P
0 g
s
.69043 .8322 m .69255 .81309 L .69592 .81319 L p .707 .577 .707 r
F P
0 g
s
.50764 .65468 m .50411 .71187 L .49719 .71512 L p .707 .577 .707 r
F P
0 g
s
.49363 .77138 m .49743 .73311 L .50409 .73312 L p .707 .577 .707 r
F P
0 g
s
.50409 .73312 m .50029 .77139 L .49363 .77138 L p .707 .577 .707 r
F P
0 g
s
.49963 .79184 m .49751 .81096 L .49096 .80997 L p .707 .577 .707 r
F P
0 g
s
.49096 .80997 m .49307 .79085 L .49963 .79184 L p .707 .577 .707 r
F P
0 g
s
.70125 .66787 m .69773 .72506 L .68502 .72084 L p .707 .577 .707 r
F P
0 g
s
.68502 .72084 m .68855 .66365 L .70125 .66787 L p .707 .577 .707 r
F P
0 g
s
.24969 .69686 m .25322 .63967 L .22207 .63695 L p .707 .577 .707 r
F P
0 g
s
.25322 .63967 m .24969 .69686 L .28145 .69843 L p .707 .577 .707 r
F P
0 g
s
.28145 .69843 m .28498 .64124 L .25322 .63967 L p .707 .577 .707 r
F P
0 g
s
.28498 .64124 m .28145 .69843 L .31072 .69871 L p .707 .577 .707 r
F P
0 g
s
.31072 .69871 m .31425 .64152 L .28498 .64124 L p .707 .577 .707 r
F P
0 g
s
.50411 .71187 m .50764 .65468 L .52385 .65243 L p .707 .577 .707 r
F P
0 g
s
.21854 .69415 m .22207 .63695 L .19459 .63337 L p .707 .577 .707 r
F P
0 g
s
.22207 .63695 m .21854 .69415 L .24969 .69686 L p .707 .577 .707 r
F P
0 g
s
.47424 .80736 m .50627 .29091 L .4623 .28708 L p .707 .577 .707 r
F P
0 g
s
.52385 .65243 m .52032 .70962 L .50411 .71187 L p .707 .577 .707 r
F P
0 g
s
.50029 .77139 m .50409 .73312 L .52004 .73413 L p .707 .577 .707 r
F P
0 g
s
.52004 .73413 m .51624 .7724 L .50029 .77139 L p .707 .577 .707 r
F P
0 g
s
.51547 .79383 m .51336 .81294 L .49751 .81096 L p .707 .577 .707 r
F P
0 g
s
.49751 .81096 m .49963 .79184 L .51547 .79383 L p .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .52004 .73413 L .54137 .73585 L p .707 .577 .707 r
F P
0 g
s
.54137 .73585 m .54371 .73604 L p .54143 .73906 L .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .54137 .73585 L .54143 .73906 L .707 .577 .707 r
F
.52032 .70962 m .52385 .65243 L .54776 .65139 L p F P
0 g
s
.54776 .65139 m .54423 .70858 L .52032 .70962 L p .707 .577 .707 r
F P
0 g
s
.54371 .73604 m .53991 .77431 L .51624 .7724 L p .707 .577 .707 r
F P
0 g
s
.53905 .79661 m .53694 .81573 L .51336 .81294 L p .707 .577 .707 r
F P
0 g
s
.51336 .81294 m .51547 .79383 L .53905 .79661 L p .707 .577 .707 r
F P
0 g
s
.51908 .8096 m .53749 .51285 L p .50627 .29091 L .707 .577 .707 r
F P
0 g
s
.53749 .51285 m .55111 .29315 L .53364 .29228 L p .707 .577 .707 r
F P
0 g
s
.53364 .29228 m .50627 .29091 L p .53749 .51285 L .707 .577 .707 r
F P
0 g
s
.50627 .29091 m .47424 .80736 L .51908 .8096 L p .707 .577 .707 r
F P
0 g
s
.69721 .75252 m .6934 .79079 L .68051 .7889 L p .707 .577 .707 r
F P
0 g
s
.68051 .7889 m .68431 .75063 L .69721 .75252 L p .707 .577 .707 r
F P
0 g
s
.54423 .70858 m .54776 .65139 L .57703 .65168 L p .707 .577 .707 r
F P
0 g
s
.57703 .65168 m .5735 .70887 L .54423 .70858 L p .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .54371 .73604 L .55393 .73696 L p .707 .577 .707 r
F P
0 g
s
.55393 .73696 m .57279 .73866 L p .54676 .76688 L .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .55393 .73696 L .54676 .76688 L .707 .577 .707 r
F
.5735 .70887 m .57703 .65168 L .60879 .65325 L p F P
0 g
s
.57279 .73866 m .56899 .77693 L .53991 .77431 L p .707 .577 .707 r
F P
0 g
s
.60879 .65325 m .60526 .71044 L .5735 .70887 L p .707 .577 .707 r
F P
0 g
s
.56806 .79993 m .56594 .81905 L .5404 .81612 L p .707 .577 .707 r
F P
0 g
s
.5404 .81612 m .53694 .81573 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.54114 .81359 m .56806 .79993 L .5404 .81612 L .707 .577 .707 r
F
.53694 .81573 m .53905 .79661 L .54591 .7974 L p F P
0 g
s
.54591 .7974 m .56806 .79993 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.53694 .81573 m .54591 .7974 L .54114 .81359 L .707 .577 .707 r
F
.56877 .67508 m .56526 .73162 L p .59336 .57251 L F P
0 g
s
.56526 .73162 m .5604 .81003 L p .57665 .69291 L .707 .577 .707 r
F P
0 g
s
.59336 .57251 m .56526 .73162 L .57665 .69291 L .707 .577 .707 r
F
.56899 .77693 m .57279 .73866 L .5805 .73941 L p F P
0 g
s
.5805 .73941 m .60443 .74173 L p .57697 .769 L .707 .577 .707 r
F P
0 g
s
.56899 .77693 m .5805 .73941 L .57697 .769 L .707 .577 .707 r
F
.63994 .65596 m .63641 .71315 L .60526 .71044 L p F P
0 g
s
.60526 .71044 m .60879 .65325 L .63994 .65596 L p .707 .577 .707 r
F P
0 g
s
.63554 .74496 m .63173 .78323 L .60063 .78 L p .707 .577 .707 r
F P
0 g
s
.60063 .78 m .60443 .74173 L .63554 .74496 L p .707 .577 .707 r
F P
0 g
s
.60443 .74173 m .60063 .78 L .56899 .77693 L p .707 .577 .707 r
F P
0 g
s
.59754 .82257 m .59965 .80345 L .63074 .80683 L p .707 .577 .707 r
F P
0 g
s
.59965 .80345 m .59754 .82257 L .57266 .81979 L p .707 .577 .707 r
F P
0 g
s
.57266 .81979 m .56594 .81905 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.57322 .81568 m .59965 .80345 L .57266 .81979 L .707 .577 .707 r
F
.56594 .81905 m .56806 .79993 L .57526 .80073 L p F P
0 g
s
.57526 .80073 m .59965 .80345 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.56594 .81905 m .57526 .80073 L .57322 .81568 L .707 .577 .707 r
F
.61785 .42651 m .61074 .54113 L p .62483 .36803 L F P
0 g
s
.61074 .54113 m .59415 .80861 L p .61489 .51076 L .707 .577 .707 r
F P
0 g
s
.62483 .36803 m .61074 .54113 L .61489 .51076 L .707 .577 .707 r
F
.59415 .80861 m .61703 .80546 L p .62339 .44854 L F P
0 g
s
.62339 .44854 m .62483 .36803 L .61489 .51076 L .707 .577 .707 r
F
.62339 .44854 m .61489 .51076 L .59415 .80861 L F
.62618 .29216 m .61785 .42651 L p .62483 .36803 L F P
0 g
s
.5604 .81003 m .59415 .80861 L p .59357 .63541 L .707 .577 .707 r
F P
0 g
s
.59357 .63541 m .59336 .57251 L .57665 .69291 L .707 .577 .707 r
F
.59357 .63541 m .57665 .69291 L .5604 .81003 L F
.59243 .29358 m .56877 .67508 L p .59336 .57251 L F P
0 g
s
.55111 .29315 m .51908 .8096 L .5604 .81003 L p .707 .577 .707 r
F P
0 g
s
.5604 .81003 m .59243 .29358 L .55111 .29315 L p .707 .577 .707 r
F P
0 g
s
.24667 .74633 m .25048 .70806 L .21937 .70483 L p .707 .577 .707 r
F P
0 g
s
.25048 .70806 m .24667 .74633 L .27832 .7494 L p .707 .577 .707 r
F P
0 g
s
.27832 .7494 m .28212 .71114 L .25048 .70806 L p .707 .577 .707 r
F P
0 g
s
.21937 .70483 m .21557 .7431 L .24667 .74633 L p .707 .577 .707 r
F P
0 g
s
.69255 .81309 m .69043 .8322 L .67746 .83102 L p .707 .577 .707 r
F P
0 g
s
.67746 .83102 m .67958 .8119 L .69255 .81309 L p .707 .577 .707 r
F P
0 g
s
.19459 .63337 m .19106 .69056 L .21854 .69415 L p .707 .577 .707 r
F P
0 g
s
.28212 .71114 m .27832 .7494 L .30739 .75202 L p .707 .577 .707 r
F P
0 g
s
.30739 .75202 m .3112 .71375 L .28212 .71114 L p .707 .577 .707 r
F P
0 g
s
.31425 .64152 m .31072 .69871 L .33463 .69768 L p .707 .577 .707 r
F P
0 g
s
.33463 .69768 m .33815 .64049 L .31425 .64152 L p .707 .577 .707 r
F P
0 g
s
.43027 .80353 m .4623 .28708 L .4235 .28203 L p .707 .577 .707 r
F P
0 g
s
.4623 .28708 m .43027 .80353 L .47424 .80736 L p .707 .577 .707 r
F P
0 g
s
.21524 .7604 m .21312 .77951 L .24421 .78289 L p .707 .577 .707 r
F P
0 g
s
.24421 .78289 m .24633 .76378 L .21524 .7604 L p .707 .577 .707 r
F P
0 g
s
.24633 .76378 m .24421 .78289 L .27581 .78641 L p .707 .577 .707 r
F P
0 g
s
.27581 .78641 m .27792 .7673 L .24633 .76378 L p .707 .577 .707 r
F P
0 g
s
.21557 .7431 m .21937 .70483 L .19185 .70177 L p .707 .577 .707 r
F P
0 g
s
.19185 .70177 m .18804 .74004 L .21557 .7431 L p .707 .577 .707 r
F P
0 g
s
.27792 .7673 m .27581 .78641 L .30481 .78973 L p .707 .577 .707 r
F P
0 g
s
.30481 .78973 m .30693 .77062 L .27792 .7673 L p .707 .577 .707 r
F P
0 g
s
.19106 .69056 m .19459 .63337 L .17346 .62927 L p .707 .577 .707 r
F P
0 g
s
.1877 .75748 m .18558 .7766 L .21312 .77951 L p .707 .577 .707 r
F P
0 g
s
.21312 .77951 m .21524 .7604 L .1877 .75748 L p .707 .577 .707 r
F P
0 g
s
.68855 .66365 m .68502 .72084 L .66389 .71673 L p .707 .577 .707 r
F P
0 g
s
.66389 .71673 m .66742 .65954 L .68855 .66365 L p .707 .577 .707 r
F P
0 g
s
.3112 .71375 m .30739 .75202 L .33107 .75393 L p .707 .577 .707 r
F P
0 g
s
.33107 .75393 m .33487 .71566 L .3112 .71375 L p .707 .577 .707 r
F P
0 g
s
.17346 .62927 m .16993 .68646 L .19106 .69056 L p .707 .577 .707 r
F P
0 g
s
.59415 .80861 m .62618 .29216 L .59243 .29358 L p .707 .577 .707 r
F P
0 g
s
.30693 .77062 m .30481 .78973 L .32839 .79252 L p .707 .577 .707 r
F P
0 g
s
.32839 .79252 m .33051 .7734 L .30693 .77062 L p .707 .577 .707 r
F P
0 g
s
.18804 .74004 m .19185 .70177 L .1706 .69917 L p .707 .577 .707 r
F P
0 g
s
.1706 .69917 m .16679 .73743 L .18804 .74004 L p .707 .577 .707 r
F P
0 g
s
.33815 .64049 m .33463 .69768 L .35084 .69542 L p .707 .577 .707 r
F P
0 g
s
.35084 .69542 m .35436 .63823 L .33815 .64049 L p .707 .577 .707 r
F P
0 g
s
.68431 .75063 m .68051 .7889 L .65926 .7863 L p .707 .577 .707 r
F P
0 g
s
.65926 .7863 m .66306 .74803 L .68431 .75063 L p .707 .577 .707 r
F P
0 g
s
.39147 .79848 m .4235 .28203 L .39367 .27625 L p .707 .577 .707 r
F P
0 g
s
.4235 .28203 m .39147 .79848 L .43027 .80353 L p .707 .577 .707 r
F P
0 g
s
.1664 .75533 m .16429 .77445 L .18558 .7766 L p .707 .577 .707 r
F P
0 g
s
.18558 .7766 m .1877 .75748 L .1664 .75533 L p .707 .577 .707 r
F P
0 g
s
.67958 .8119 m .67746 .83102 L .65617 .82886 L p .707 .577 .707 r
F P
0 g
s
.65617 .82886 m .65828 .80974 L .67958 .8119 L p .707 .577 .707 r
F P
0 g
s
.16993 .68646 m .17346 .62927 L .16075 .62505 L p .707 .577 .707 r
F P
0 g
s
.66742 .65954 m .66389 .71673 L .63641 .71315 L p .707 .577 .707 r
F P
0 g
s
.63641 .71315 m .63994 .65596 L .66742 .65954 L p .707 .577 .707 r
F P
0 g
s
.33487 .71566 m .33107 .75393 L .34701 .75494 L p .707 .577 .707 r
F P
0 g
s
.34701 .75494 m .35081 .71667 L .33487 .71566 L p .707 .577 .707 r
F P
0 g
s
.16075 .62505 m .15722 .68224 L .16993 .68646 L p .707 .577 .707 r
F P
0 g
s
.33051 .7734 m .32839 .79252 L .34424 .7945 L p .707 .577 .707 r
F P
0 g
s
.34424 .7945 m .34635 .77539 L .33051 .7734 L p .707 .577 .707 r
F P
0 g
s
.16679 .73743 m .1706 .69917 L .1577 .69728 L p .707 .577 .707 r
F P
0 g
s
.1577 .69728 m .1539 .73555 L .16679 .73743 L p .707 .577 .707 r
F P
0 g
s
.61703 .80546 m .64906 .28901 L .62618 .29216 L p .707 .577 .707 r
F P
0 g
s
.66306 .74803 m .65926 .7863 L .63173 .78323 L p .707 .577 .707 r
F P
0 g
s
.63173 .78323 m .63554 .74496 L .66306 .74803 L p .707 .577 .707 r
F P
0 g
s
.15343 .75414 m .15132 .77326 L .16429 .77445 L p .707 .577 .707 r
F P
0 g
s
.16429 .77445 m .1664 .75533 L .15343 .75414 L p .707 .577 .707 r
F P
0 g
s
.35436 .63823 m .35084 .69542 L .35776 .69217 L p .707 .577 .707 r
F P
0 g
s
.35776 .69217 m .36129 .63498 L .35436 .63823 L p .707 .577 .707 r
F P
0 g
s
.65828 .80974 m .65617 .82886 L .62863 .82595 L p .707 .577 .707 r
F P
0 g
s
.62863 .82595 m .63074 .80683 L .65828 .80974 L p .707 .577 .707 r
F P
0 g
s
.36164 .7927 m .39367 .27625 L .37573 .27032 L p .707 .577 .707 r
F P
0 g
s
.39367 .27625 m .36164 .7927 L .39147 .79848 L p .707 .577 .707 r
F P
0 g
s
.15722 .68224 m .16075 .62505 L .15771 .62112 L p .707 .577 .707 r
F P
0 g
s
.35081 .71667 m .34701 .75494 L .35367 .75495 L p .707 .577 .707 r
F P
0 g
s
.35367 .75495 m .35747 .71669 L .35081 .71667 L p .707 .577 .707 r
F P
0 g
s
.63074 .80683 m .62863 .82595 L .59754 .82257 L p .707 .577 .707 r
F P
0 g
s
.34635 .77539 m .34424 .7945 L .35079 .79549 L p .707 .577 .707 r
F P
0 g
s
.15771 .62112 m .15418 .67831 L .15722 .68224 L p .707 .577 .707 r
F P
0 g
s
.35079 .79549 m .35291 .77638 L .34635 .77539 L p .707 .577 .707 r
F P
0 g
s
.1539 .73555 m .1577 .69728 L .15442 .69629 L p .707 .577 .707 r
F P
0 g
s
.15442 .69629 m .15062 .73456 L .1539 .73555 L p .707 .577 .707 r
F P
0 g
s
.15006 .75404 m .14795 .77315 L .15132 .77326 L p .707 .577 .707 r
F P
0 g
s
.15132 .77326 m .15343 .75414 L .15006 .75404 L p .707 .577 .707 r
F P
0 g
s
.36129 .63498 m .35776 .69217 L .35472 .68824 L p .707 .577 .707 r
F P
0 g
s
.35472 .68824 m .35825 .63105 L .36129 .63498 L p .707 .577 .707 r
F P
0 g
s
.64906 .28901 m .61703 .80546 L .6268 .80092 L p .707 .577 .707 r
F P
0 g
s
.6268 .80092 m .65883 .28447 L .64906 .28901 L p .707 .577 .707 r
F P
0 g
s
.15418 .67831 m .15771 .62112 L .16463 .61787 L p .707 .577 .707 r
F P
0 g
s
.35747 .71669 m .35367 .75495 L .35039 .75397 L p .707 .577 .707 r
F P
0 g
s
.35039 .75397 m .3542 .7157 L .35747 .71669 L p .707 .577 .707 r
F P
0 g
s
.35825 .63105 m .35472 .68824 L .34201 .68402 L p .707 .577 .707 r
F P
0 g
s
.34201 .68402 m .34554 .62683 L .35825 .63105 L p .707 .577 .707 r
F P
0 g
s
.3542 .7157 m .35039 .75397 L .34819 .75365 L p .707 .577 .707 r
F P
0 g
s
.34819 .75365 m .3375 .75208 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.34923 .72653 m .3542 .7157 L .34819 .75365 L .707 .577 .707 r
F
.37573 .27032 m .37143 .26481 L p .35509 .57235 L F P
0 g
s
.3375 .75208 m .3413 .71381 L .34966 .71504 L p .707 .577 .707 r
F P
0 g
s
.34966 .71504 m .3542 .7157 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.3375 .75208 m .34966 .71504 L .34923 .72653 L .707 .577 .707 r
F
.34954 .77627 m .34742 .79539 L .34588 .79525 L p F P
0 g
s
.34588 .79525 m .33446 .7942 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.34635 .78007 m .34954 .77627 L .34588 .79525 L .707 .577 .707 r
F
.33446 .7942 m .33657 .77508 L .34647 .77599 L p F P
0 g
s
.34647 .77599 m .34954 .77627 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.33446 .7942 m .34647 .77599 L .34635 .78007 L .707 .577 .707 r
F
.35943 .45836 m .35317 .55933 L p .35509 .57235 L F P
0 g
s
.35317 .55933 m .3394 .78126 L p .35114 .625 L .707 .577 .707 r
F P
0 g
s
.35509 .57235 m .35317 .55933 L .35114 .625 L .707 .577 .707 r
F
.3394 .78126 m .3437 .78677 L p .34953 .67702 L F P
0 g
s
.34953 .67702 m .35509 .57235 L .35114 .625 L .707 .577 .707 r
F
.34953 .67702 m .35114 .625 L .3394 .78126 L F
.37143 .26481 m .35943 .45836 L p .35509 .57235 L F P
0 g
s
.3437 .78677 m .35207 .65182 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35207 .65182 m .37573 .27032 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35291 .77638 m .35079 .79549 L .34742 .79539 L p .707 .577 .707 r
F P
0 g
s
.34742 .79539 m .34954 .77627 L .35291 .77638 L p .707 .577 .707 r
F P
0 g
s
.37573 .27032 m .3437 .78677 L .36164 .7927 L p .707 .577 .707 r
F P
0 g
s
.16463 .61787 m .1611 .67506 L .15418 .67831 L p .707 .577 .707 r
F P
0 g
s
.15062 .73456 m .15442 .69629 L .16108 .69631 L p .707 .577 .707 r
F P
0 g
s
.16108 .69631 m .15728 .73458 L .15062 .73456 L p .707 .577 .707 r
F P
0 g
s
.15662 .75503 m .1545 .77414 L .14795 .77315 L p .707 .577 .707 r
F P
0 g
s
.14795 .77315 m .15006 .75404 L .15662 .75503 L p .707 .577 .707 r
F P
0 g
s
.1611 .67506 m .16463 .61787 L .18084 .61561 L p .707 .577 .707 r
F P
0 g
s
.65883 .28447 m .6268 .80092 L .62251 .79541 L p .707 .577 .707 r
F P
0 g
s
.62251 .79541 m .65454 .27896 L .65883 .28447 L p .707 .577 .707 r
F P
0 g
s
.18084 .61561 m .17731 .6728 L .1611 .67506 L p .707 .577 .707 r
F P
0 g
s
.15728 .73458 m .16108 .69631 L .17703 .69732 L p .707 .577 .707 r
F P
0 g
s
.17703 .69732 m .17323 .73559 L .15728 .73458 L p .707 .577 .707 r
F P
0 g
s
.17246 .75701 m .17035 .77613 L .1545 .77414 L p .707 .577 .707 r
F P
0 g
s
.1545 .77414 m .15662 .75503 L .17246 .75701 L p .707 .577 .707 r
F P
0 g
s
.34554 .62683 m .34201 .68402 L .32088 .67992 L p .707 .577 .707 r
F P
0 g
s
.32088 .67992 m .32441 .62273 L .34554 .62683 L p .707 .577 .707 r
F P
0 g
s
.3394 .78126 m .37143 .26481 L .3812 .26026 L p .707 .577 .707 r
F P
0 g
s
.17731 .6728 m .18084 .61561 L .20475 .61458 L p .707 .577 .707 r
F P
0 g
s
.3413 .71381 m .3375 .75208 L .31625 .74948 L p .707 .577 .707 r
F P
0 g
s
.31625 .74948 m .32005 .71121 L .3413 .71381 L p .707 .577 .707 r
F P
0 g
s
.20475 .61458 m .20122 .67177 L .17731 .6728 L p .707 .577 .707 r
F P
0 g
s
.33657 .77508 m .33446 .7942 L .31316 .79205 L p .707 .577 .707 r
F P
0 g
s
.31316 .79205 m .31527 .77293 L .33657 .77508 L p .707 .577 .707 r
F P
0 g
s
.17323 .73559 m .17703 .69732 L .2007 .69923 L p .707 .577 .707 r
F P
0 g
s
.2007 .69923 m .1969 .7375 L .17323 .73559 L p .707 .577 .707 r
F P
0 g
s
.32441 .62273 m .32088 .67992 L .2934 .67634 L p .707 .577 .707 r
F P
0 g
s
.2934 .67634 m .29693 .61915 L .32441 .62273 L p .707 .577 .707 r
F P
0 g
s
.19604 .7598 m .19393 .77891 L .17035 .77613 L p .707 .577 .707 r
F P
0 g
s
.17035 .77613 m .17246 .75701 L .19604 .7598 L p .707 .577 .707 r
F P
0 g
s
.20122 .67177 m .20475 .61458 L .23402 .61486 L p .707 .577 .707 r
F P
0 g
s
.65454 .27896 m .62251 .79541 L .60457 .78948 L p .707 .577 .707 r
F P
0 g
s
.60457 .78948 m .6366 .27302 L .65454 .27896 L p .707 .577 .707 r
F P
0 g
s
.23402 .61486 m .23049 .67205 L .20122 .67177 L p .707 .577 .707 r
F P
0 g
s
.32005 .71121 m .31625 .74948 L .28872 .74642 L p .707 .577 .707 r
F P
0 g
s
.28872 .74642 m .29253 .70815 L .32005 .71121 L p .707 .577 .707 r
F P
0 g
s
.29693 .61915 m .2934 .67634 L .26225 .67362 L p .707 .577 .707 r
F P
0 g
s
.26225 .67362 m .26578 .61643 L .29693 .61915 L p .707 .577 .707 r
F P
0 g
s
.31527 .77293 m .31316 .79205 L .28562 .78913 L p .707 .577 .707 r
F P
0 g
s
.28562 .78913 m .28773 .77002 L .31527 .77293 L p .707 .577 .707 r
F P
0 g
s
.23049 .67205 m .23402 .61486 L .26578 .61643 L p .707 .577 .707 r
F P
0 g
s
.7299 .64631 m .73343 .58912 L .70228 .58641 L p .707 .577 .707 r
F P
0 g
s
.73343 .58912 m .7299 .64631 L .76166 .64788 L p .707 .577 .707 r
F P
0 g
s
.76166 .64788 m .76519 .59069 L .73343 .58912 L p .707 .577 .707 r
F P
0 g
s
.1969 .7375 m .2007 .69923 L .22978 .70185 L p .707 .577 .707 r
F P
0 g
s
.22978 .70185 m .22598 .74011 L .1969 .7375 L p .707 .577 .707 r
F P
0 g
s
.34918 .77672 m .3812 .26026 L .40408 .25712 L p .707 .577 .707 r
F P
0 g
s
.3812 .26026 m .34918 .77672 L .3394 .78126 L p .707 .577 .707 r
F P
0 g
s
.26578 .61643 m .26225 .67362 L .23049 .67205 L p .707 .577 .707 r
F P
0 g
s
.76519 .59069 m .76166 .64788 L .79093 .64816 L p .707 .577 .707 r
F P
0 g
s
.79093 .64816 m .79446 .59097 L .76519 .59069 L p .707 .577 .707 r
F P
0 g
s
.22505 .76311 m .22293 .78223 L .19393 .77891 L p .707 .577 .707 r
F P
0 g
s
.19393 .77891 m .19604 .7598 L .22505 .76311 L p .707 .577 .707 r
F P
0 g
s
.69875 .6436 m .70228 .58641 L .6748 .58282 L p .707 .577 .707 r
F P
0 g
s
.70228 .58641 m .69875 .6436 L .7299 .64631 L p .707 .577 .707 r
F P
0 g
s
.29253 .70815 m .28872 .74642 L .25762 .74319 L p .707 .577 .707 r
F P
0 g
s
.25762 .74319 m .26142 .70492 L .29253 .70815 L p .707 .577 .707 r
F P
0 g
s
.22598 .74011 m .22978 .70185 L .26142 .70492 L p .707 .577 .707 r
F P
0 g
s
.6748 .58282 m .67127 .64001 L .69875 .6436 L p .707 .577 .707 r
F P
0 g
s
.72689 .70202 m .73069 .66375 L .69958 .66052 L p .707 .577 .707 r
F P
0 g
s
.73069 .66375 m .72689 .70202 L .75853 .70509 L p .707 .577 .707 r
F P
0 g
s
.75853 .70509 m .76233 .66682 L .73069 .66375 L p .707 .577 .707 r
F P
0 g
s
.26142 .70492 m .25762 .74319 L .22598 .74011 L p .707 .577 .707 r
F P
0 g
s
.28773 .77002 m .28562 .78913 L .25453 .78575 L p .707 .577 .707 r
F P
0 g
s
.69958 .66052 m .69578 .69879 L .72689 .70202 L p .707 .577 .707 r
F P
0 g
s
.25453 .78575 m .25664 .76664 L .28773 .77002 L p .707 .577 .707 r
F P
0 g
s
.79446 .59097 m .79093 .64816 L .81484 .64713 L p .707 .577 .707 r
F P
0 g
s
.81484 .64713 m .81837 .58994 L .79446 .59097 L p .707 .577 .707 r
F P
0 g
s
.76233 .66682 m .75853 .70509 L .78761 .70771 L p .707 .577 .707 r
F P
0 g
s
.78761 .70771 m .79141 .66944 L .76233 .66682 L p .707 .577 .707 r
F P
0 g
s
.25664 .76664 m .25453 .78575 L .22293 .78223 L p .707 .577 .707 r
F P
0 g
s
.22293 .78223 m .22505 .76311 L .25664 .76664 L p .707 .577 .707 r
F P
0 g
s
.69578 .69879 m .69958 .66052 L .67206 .65746 L p .707 .577 .707 r
F P
0 g
s
.69545 .72486 m .69334 .74397 L .72443 .74736 L p .707 .577 .707 r
F P
0 g
s
.72443 .74736 m .72654 .72824 L .69545 .72486 L p .707 .577 .707 r
F P
0 g
s
.72654 .72824 m .72443 .74736 L .75602 .75088 L p .707 .577 .707 r
F P
0 g
s
.75602 .75088 m .75813 .73176 L .72654 .72824 L p .707 .577 .707 r
F P
0 g
s
.67206 .65746 m .66826 .69573 L .69578 .69879 L p .707 .577 .707 r
F P
0 g
s
.67127 .64001 m .6748 .58282 L .65367 .57872 L p .707 .577 .707 r
F P
0 g
s
.75813 .73176 m .75602 .75088 L .78503 .75419 L p .707 .577 .707 r
F P
0 g
s
.78503 .75419 m .78714 .73508 L .75813 .73176 L p .707 .577 .707 r
F P
0 g
s
.66791 .72195 m .6658 .74106 L .69334 .74397 L p .707 .577 .707 r
F P
0 g
s
.69334 .74397 m .69545 .72486 L .66791 .72195 L p .707 .577 .707 r
F P
0 g
s
.6366 .27302 m .60457 .78948 L .57474 .7837 L p .707 .577 .707 r
F P
0 g
s
.57474 .7837 m .60676 .26725 L .6366 .27302 L p .707 .577 .707 r
F P
0 g
s
.65367 .57872 m .65014 .63591 L .67127 .64001 L p .707 .577 .707 r
F P
0 g
s
.79141 .66944 m .78761 .70771 L .81128 .70962 L p .707 .577 .707 r
F P
0 g
s
.81128 .70962 m .81508 .67135 L .79141 .66944 L p .707 .577 .707 r
F P
0 g
s
.66826 .69573 m .67206 .65746 L .65081 .65485 L p .707 .577 .707 r
F P
0 g
s
.65081 .65485 m .64701 .69312 L .66826 .69573 L p .707 .577 .707 r
F P
0 g
s
.78714 .73508 m .78503 .75419 L .80861 .75698 L p .707 .577 .707 r
F P
0 g
s
.80861 .75698 m .81072 .73787 L .78714 .73508 L p .707 .577 .707 r
F P
0 g
s
.81837 .58994 m .81484 .64713 L .83105 .64487 L p .707 .577 .707 r
F P
0 g
s
.83105 .64487 m .83458 .58768 L .81837 .58994 L p .707 .577 .707 r
F P
0 g
s
.40408 .25712 m .37206 .77357 L .34918 .77672 L p .707 .577 .707 r
F P
0 g
s
.37206 .77357 m .40408 .25712 L .43784 .2557 L p .707 .577 .707 r
F P
0 g
s
.64661 .71979 m .6445 .73891 L .6658 .74106 L p .707 .577 .707 r
F P
0 g
s
.6658 .74106 m .66791 .72195 L .64661 .71979 L p .707 .577 .707 r
F P
0 g
s
.65014 .63591 m .65367 .57872 L .64096 .5745 L p .707 .577 .707 r
F P
0 g
s
.81508 .67135 m .81128 .70962 L .82723 .71063 L p .707 .577 .707 r
F P
0 g
s
.82723 .71063 m .83103 .67236 L .81508 .67135 L p .707 .577 .707 r
F P
0 g
s
.64096 .5745 m .63744 .63169 L .65014 .63591 L p .707 .577 .707 r
F P
0 g
s
.81072 .73787 m .80861 .75698 L .82445 .75897 L p .707 .577 .707 r
F P
0 g
s
.82445 .75897 m .82656 .73985 L .81072 .73787 L p .707 .577 .707 r
F P
0 g
s
.64701 .69312 m .65081 .65485 L .63791 .65297 L p .707 .577 .707 r
F P
0 g
s
.63791 .65297 m .63411 .69124 L .64701 .69312 L p .707 .577 .707 r
F P
0 g
s
.60676 .26725 m .57474 .7837 L .53594 .77865 L p .707 .577 .707 r
F P
0 g
s
.53594 .77865 m .56796 .2622 L .60676 .26725 L p .707 .577 .707 r
F P
0 g
s
.83458 .58768 m .83105 .64487 L .83797 .64162 L p .707 .577 .707 r
F P
0 g
s
.83797 .64162 m .8415 .58443 L .83458 .58768 L p .707 .577 .707 r
F P
0 g
s
.63364 .7186 m .63153 .73772 L .6445 .73891 L p .707 .577 .707 r
F P
0 g
s
.6445 .73891 m .64661 .71979 L .63364 .7186 L p .707 .577 .707 r
F P
0 g
s
.40581 .77215 m .43784 .2557 L .47915 .25613 L p .707 .577 .707 r
F P
0 g
s
.43784 .2557 m .40581 .77215 L .37206 .77357 L p .707 .577 .707 r
F P
0 g
s
.63744 .63169 m .64096 .5745 L .63792 .57057 L p .707 .577 .707 r
F P
0 g
s
.83103 .67236 m .82723 .71063 L .83389 .71064 L p .707 .577 .707 r
F P
0 g
s
.83389 .71064 m .83769 .67237 L .83103 .67236 L p .707 .577 .707 r
F P
0 g
s
.63792 .57057 m .63439 .62776 L .63744 .63169 L p .707 .577 .707 r
F P
0 g
s
.56796 .2622 m .53594 .77865 L .49196 .77482 L p .707 .577 .707 r
F P
0 g
s
.49196 .77482 m .52399 .25837 L .56796 .2622 L p .707 .577 .707 r
F P
0 g
s
.82656 .73985 m .82445 .75897 L .83101 .75996 L p .707 .577 .707 r
F P
0 g
s
.83101 .75996 m .83312 .74084 L .82656 .73985 L p .707 .577 .707 r
F P
0 g
s
.44712 .77258 m .47915 .25613 L .52399 .25837 L p .707 .577 .707 r
F P
0 g
s
.47915 .25613 m .44712 .77258 L .40581 .77215 L p .707 .577 .707 r
F P
0 g
s
.63411 .69124 m .63791 .65297 L .63464 .65198 L p .707 .577 .707 r
F P
0 g
s
.63464 .65198 m .63083 .69025 L .63411 .69124 L p .707 .577 .707 r
F P
0 g
s
.52399 .25837 m .49196 .77482 L .44712 .77258 L p .707 .577 .707 r
F P
0 g
s
.8415 .58443 m .83797 .64162 L .83493 .63769 L p .707 .577 .707 r
F P
0 g
s
.83493 .63769 m .83846 .5805 L .8415 .58443 L p .707 .577 .707 r
F P
0 g
s
.63027 .7185 m .62816 .73762 L .63153 .73772 L p .707 .577 .707 r
F P
0 g
s
.63153 .73772 m .63364 .7186 L .63027 .7185 L p .707 .577 .707 r
F P
0 g
s
.63439 .62776 m .63792 .57057 L .64485 .56732 L p .707 .577 .707 r
F P
0 g
s
.83769 .67237 m .83389 .71064 L .83061 .70966 L p .707 .577 .707 r
F P
0 g
s
.83061 .70966 m .83441 .67139 L .83769 .67237 L p .707 .577 .707 r
F P
0 g
s
.64485 .56732 m .64132 .62451 L .63439 .62776 L p .707 .577 .707 r
F P
0 g
s
.83312 .74084 m .83101 .75996 L .82764 .75985 L p .707 .577 .707 r
F P
0 g
s
.82764 .75985 m .82975 .74074 L .83312 .74084 L p .707 .577 .707 r
F P
0 g
s
.63083 .69025 m .63464 .65198 L .6413 .652 L p .707 .577 .707 r
F P
0 g
s
.6413 .652 m .63749 .69027 L .63083 .69025 L p .707 .577 .707 r
F P
0 g
s
.83846 .5805 m .83493 .63769 L .82223 .63347 L p .707 .577 .707 r
F P
0 g
s
.82223 .63347 m .82575 .57628 L .83846 .5805 L p .707 .577 .707 r
F P
0 g
s
.63683 .71949 m .63472 .7386 L .62816 .73762 L p .707 .577 .707 r
F P
0 g
s
.62816 .73762 m .63027 .7185 L .63683 .71949 L p .707 .577 .707 r
F P
0 g
s
.38689 .60949 m .39042 .5523 L .35927 .54959 L p .707 .577 .707 r
F P
0 g
s
.39042 .5523 m .38689 .60949 L .41865 .61106 L p .707 .577 .707 r
F P
0 g
s
.41865 .61106 m .42218 .55387 L .39042 .5523 L p .707 .577 .707 r
F P
0 g
s
.42218 .55387 m .41865 .61106 L .44792 .61135 L p .707 .577 .707 r
F P
0 g
s
.44792 .61135 m .45145 .55416 L .42218 .55387 L p .707 .577 .707 r
F P
0 g
s
.64132 .62451 m .64485 .56732 L .66105 .56506 L p .707 .577 .707 r
F P
0 g
s
.35574 .60678 m .35927 .54959 L .33179 .54601 L p .707 .577 .707 r
F P
0 g
s
.35927 .54959 m .35574 .60678 L .38689 .60949 L p .707 .577 .707 r
F P
0 g
s
.83441 .67139 m .83061 .70966 L .81771 .70777 L p .707 .577 .707 r
F P
0 g
s
.81771 .70777 m .82152 .6695 L .83441 .67139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66105 .56506 m .65753 .62225 L .64132 .62451 L p .707 .577 .707 r
F P
0 g
s
.33179 .54601 m .32826 .6032 L .35574 .60678 L p .707 .577 .707 r
F P
0 g
s
.38388 .6652 m .38768 .62694 L .35657 .62371 L p .707 .577 .707 r
F P
0 g
s
.38768 .62694 m .38388 .6652 L .41552 .66828 L p .707 .577 .707 r
F P
0 g
s
.41552 .66828 m .41932 .63001 L .38768 .62694 L p .707 .577 .707 r
F P
0 g
s
.35657 .62371 m .35277 .66198 L .38388 .6652 L p .707 .577 .707 r
F P
0 g
s
.45145 .55416 m .44792 .61135 L .47183 .61031 L p .707 .577 .707 r
F P
0 g
s
.47183 .61031 m .47536 .55312 L .45145 .55416 L p .707 .577 .707 r
F P
0 g
s
.41932 .63001 m .41552 .66828 L .4446 .6709 L p .707 .577 .707 r
F P
0 g
s
.4446 .6709 m .4484 .63263 L .41932 .63001 L p .707 .577 .707 r
F P
0 g
s
.82975 .74074 m .82764 .75985 L .81467 .75866 L p .707 .577 .707 r
F P
0 g
s
.81467 .75866 m .81678 .73955 L .82975 .74074 L p .707 .577 .707 r
F P
0 g
s
.63749 .69027 m .6413 .652 L .65724 .65301 L p .707 .577 .707 r
F P
0 g
s
.35277 .66198 m .35657 .62371 L .32905 .62064 L p .707 .577 .707 r
F P
0 g
s
.35244 .68804 m .35033 .70716 L .38142 .71054 L p .707 .577 .707 r
F P
0 g
s
.38142 .71054 m .38353 .69142 L .35244 .68804 L p .707 .577 .707 r
F P
0 g
s
.38353 .69142 m .38142 .71054 L .41301 .71406 L p .707 .577 .707 r
F P
0 g
s
.65724 .65301 m .65344 .69128 L .63749 .69027 L p .707 .577 .707 r
F P
0 g
s
.41301 .71406 m .41512 .69495 L .38353 .69142 L p .707 .577 .707 r
F P
0 g
s
.32905 .62064 m .32525 .65891 L .35277 .66198 L p .707 .577 .707 r
F P
0 g
s
.32826 .6032 m .33179 .54601 L .31066 .5419 L p .707 .577 .707 r
F P
0 g
s
.41512 .69495 m .41301 .71406 L .44202 .71738 L p .707 .577 .707 r
F P
0 g
s
.44202 .71738 m .44413 .69826 L .41512 .69495 L p .707 .577 .707 r
F P
0 g
s
.82575 .57628 m .82223 .63347 L .8011 .62937 L p .707 .577 .707 r
F P
0 g
s
.8011 .62937 m .80462 .57218 L .82575 .57628 L p .707 .577 .707 r
F P
0 g
s
.65268 .72147 m .65056 .74059 L .63472 .7386 L p .707 .577 .707 r
F P
0 g
s
.63472 .7386 m .63683 .71949 L .65268 .72147 L p .707 .577 .707 r
F P
0 g
s
.3249 .68513 m .32279 .70425 L .35033 .70716 L p .707 .577 .707 r
F P
0 g
s
.35033 .70716 m .35244 .68804 L .3249 .68513 L p .707 .577 .707 r
F P
0 g
s
.31066 .5419 m .30713 .59909 L .32826 .6032 L p .707 .577 .707 r
F P
0 g
s
.4484 .63263 m .4446 .6709 L .46827 .6728 L p .707 .577 .707 r
F P
0 g
s
.46827 .6728 m .47207 .63454 L .4484 .63263 L p .707 .577 .707 r
F P
0 g
s
.65753 .62225 m .66105 .56506 L .68496 .56403 L p .707 .577 .707 r
F P
0 g
s
.32525 .65891 m .32905 .62064 L .3078 .61804 L p .707 .577 .707 r
F P
0 g
s
.3078 .61804 m .304 .65631 L .32525 .65891 L p .707 .577 .707 r
F P
0 g
s
.44413 .69826 m .44202 .71738 L .4656 .72017 L p .707 .577 .707 r
F P
0 g
s
.4656 .72017 m .46771 .70105 L .44413 .69826 L p .707 .577 .707 r
F P
0 g
s
.47536 .55312 m .47183 .61031 L .48804 .60806 L p .707 .577 .707 r
F P
0 g
s
.48804 .60806 m .49157 .55087 L .47536 .55312 L p .707 .577 .707 r
F P
0 g
s
.82152 .6695 m .81771 .70777 L .79646 .70517 L p .707 .577 .707 r
F P
0 g
s
.79646 .70517 m .80027 .6669 L .82152 .6695 L p .707 .577 .707 r
F P
0 g
s
.68496 .56403 m .68144 .62122 L .65753 .62225 L p .707 .577 .707 r
F P
0 g
s
.3036 .68298 m .30149 .70209 L .32279 .70425 L p .707 .577 .707 r
F P
0 g
s
.32279 .70425 m .3249 .68513 L .3036 .68298 L p .707 .577 .707 r
F P
0 g
s
.30713 .59909 m .31066 .5419 L .29795 .53768 L p .707 .577 .707 r
F P
0 g
s
.81678 .73955 m .81467 .75866 L .79337 .75651 L p .707 .577 .707 r
F P
0 g
s
.79337 .75651 m .79549 .73739 L .81678 .73955 L p .707 .577 .707 r
F P
0 g
s
.65344 .69128 m .65724 .65301 L .68091 .65492 L p .707 .577 .707 r
F P
0 g
s
.80462 .57218 m .8011 .62937 L .77361 .62579 L p .707 .577 .707 r
F P
0 g
s
.77361 .62579 m .77714 .5686 L .80462 .57218 L p .707 .577 .707 r
F P
0 g
s
.68091 .65492 m .67711 .69318 L .65344 .69128 L p .707 .577 .707 r
F P
0 g
s
.47207 .63454 m .46827 .6728 L .48422 .67381 L p .707 .577 .707 r
F P
0 g
s
.48422 .67381 m .48802 .63555 L .47207 .63454 L p .707 .577 .707 r
F P
0 g
s
.29795 .53768 m .29442 .59487 L .30713 .59909 L p .707 .577 .707 r
F P
0 g
s
.68144 .62122 m .68496 .56403 L .71423 .56431 L p .707 .577 .707 r
F P
0 g
s
.67625 .72426 m .67414 .74338 L .65056 .74059 L p .707 .577 .707 r
F P
0 g
s
.65056 .74059 m .65268 .72147 L .67625 .72426 L p .707 .577 .707 r
F P
0 g
s
.46771 .70105 m .4656 .72017 L .48144 .72215 L p .707 .577 .707 r
F P
0 g
s
.48144 .72215 m .48355 .70304 L .46771 .70105 L p .707 .577 .707 r
F P
0 g
s
.304 .65631 m .3078 .61804 L .2949 .61615 L p .707 .577 .707 r
F P
0 g
s
.2949 .61615 m .2911 .65442 L .304 .65631 L p .707 .577 .707 r
F P
0 g
s
.71423 .56431 m .7107 .6215 L .68144 .62122 L p .707 .577 .707 r
F P
0 g
s
.80027 .6669 m .79646 .70517 L .76894 .7021 L p .707 .577 .707 r
F P
0 g
s
.76894 .7021 m .77274 .66384 L .80027 .6669 L p .707 .577 .707 r
F P
0 g
s
.77714 .5686 m .77361 .62579 L .74247 .62307 L p .707 .577 .707 r
F P
0 g
s
.74247 .62307 m .74599 .56588 L .77714 .5686 L p .707 .577 .707 r
F P
0 g
s
.49157 .55087 m .48804 .60806 L .49496 .60481 L p .707 .577 .707 r
F P
0 g
s
.49496 .60481 m .49849 .54762 L .49157 .55087 L p .707 .577 .707 r
F P
0 g
s
.29063 .68179 m .28852 .7009 L .30149 .70209 L p .707 .577 .707 r
F P
0 g
s
.30149 .70209 m .3036 .68298 L .29063 .68179 L p .707 .577 .707 r
F P
0 g
s
.7107 .6215 m .71423 .56431 L .74599 .56588 L p .707 .577 .707 r
F P
0 g
s
.67711 .69318 m .68091 .65492 L .70999 .65753 L p .707 .577 .707 r
F P
0 g
s
.70999 .65753 m .70619 .6958 L .67711 .69318 L p .707 .577 .707 r
F P
0 g
s
.79549 .73739 m .79337 .75651 L .76583 .7536 L p .707 .577 .707 r
F P
0 g
s
.76583 .7536 m .76794 .73448 L .79549 .73739 L p .707 .577 .707 r
F P
0 g
s
.74599 .56588 m .74247 .62307 L .7107 .6215 L p .707 .577 .707 r
F P
0 g
s
.29442 .59487 m .29795 .53768 L .29491 .53375 L p .707 .577 .707 r
F P
0 g
s
.70526 .72758 m .70315 .74669 L .67414 .74338 L p .707 .577 .707 r
F P
0 g
s
.67414 .74338 m .67625 .72426 L .70526 .72758 L p .707 .577 .707 r
F P
0 g
s
.77274 .66384 m .76894 .7021 L .73783 .69888 L p .707 .577 .707 r
F P
0 g
s
.73783 .69888 m .74163 .66061 L .77274 .66384 L p .707 .577 .707 r
F P
0 g
s
.48802 .63555 m .48422 .67381 L .49088 .67383 L p .707 .577 .707 r
F P
0 g
s
.49088 .67383 m .49468 .63556 L .48802 .63555 L p .707 .577 .707 r
F P
0 g
s
.29491 .53375 m .29138 .59094 L .29442 .59487 L p .707 .577 .707 r
F P
0 g
s
.70619 .6958 m .70999 .65753 L .74163 .66061 L p .707 .577 .707 r
F P
0 g
s
.74163 .66061 m .73783 .69888 L .70619 .6958 L p .707 .577 .707 r
F P
0 g
s
.76794 .73448 m .76583 .7536 L .73474 .75022 L p .707 .577 .707 r
F P
0 g
s
.73474 .75022 m .73686 .7311 L .76794 .73448 L p .707 .577 .707 r
F P
0 g
s
.48355 .70304 m .48144 .72215 L .488 .72314 L p .707 .577 .707 r
F P
0 g
s
.488 .72314 m .49011 .70403 L .48355 .70304 L p .707 .577 .707 r
F P
0 g
s
.2911 .65442 m .2949 .61615 L .29163 .61517 L p .707 .577 .707 r
F P
0 g
s
.73686 .7311 m .73474 .75022 L .70315 .74669 L p .707 .577 .707 r
F P
0 g
s
.70315 .74669 m .70526 .72758 L .73686 .7311 L p .707 .577 .707 r
F P
0 g
s
.29163 .61517 m .28782 .65344 L .2911 .65442 L p .707 .577 .707 r
F P
0 g
s
.49849 .54762 m .49496 .60481 L .49192 .60088 L p .707 .577 .707 r
F P
0 g
s
.49192 .60088 m .49545 .54369 L .49849 .54762 L p .707 .577 .707 r
F P
0 g
s
.28726 .68168 m .28515 .7008 L .28852 .7009 L p .707 .577 .707 r
F P
0 g
s
.28852 .7009 m .29063 .68179 L .28726 .68168 L p .707 .577 .707 r
F P
0 g
s
.29138 .59094 m .29491 .53375 L .30183 .5305 L p .707 .577 .707 r
F P
0 g
s
.49468 .63556 m .49088 .67383 L .4876 .67284 L p .707 .577 .707 r
F P
0 g
s
.4876 .67284 m .4914 .63457 L .49468 .63556 L p .707 .577 .707 r
F P
0 g
s
.30183 .5305 m .29831 .58769 L .29138 .59094 L p .707 .577 .707 r
F P
0 g
s
.49011 .70403 m .488 .72314 L .48463 .72304 L p .707 .577 .707 r
F P
0 g
s
.48463 .72304 m .48674 .70392 L .49011 .70403 L p .707 .577 .707 r
F P
0 g
s
.28782 .65344 m .29163 .61517 L .29829 .61518 L p .707 .577 .707 r
F P
0 g
s
.29829 .61518 m .29448 .65345 L .28782 .65344 L p .707 .577 .707 r
F P
0 g
s
.49545 .54369 m .49192 .60088 L .47921 .59666 L p .707 .577 .707 r
F P
0 g
s
.47921 .59666 m .48274 .53947 L .49545 .54369 L p .707 .577 .707 r
F P
0 g
s
.29382 .68267 m .29171 .70179 L .28515 .7008 L p .707 .577 .707 r
F P
0 g
s
.28515 .7008 m .28726 .68168 L .29382 .68267 L p .707 .577 .707 r
F P
0 g
s
.29831 .58769 m .30183 .5305 L .31804 .52825 L p .707 .577 .707 r
F P
0 g
s
.4914 .63457 m .4876 .67284 L .4747 .67096 L p .707 .577 .707 r
F P
0 g
s
.4747 .67096 m .4785 .63269 L .4914 .63457 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31804 .52825 m .31452 .58544 L .29831 .58769 L p .707 .577 .707 r
F P
0 g
s
.48674 .70392 m .48463 .72304 L .47166 .72185 L p .707 .577 .707 r
F P
0 g
s
.47166 .72185 m .47377 .70273 L .48674 .70392 L p .707 .577 .707 r
F P
0 g
s
.29448 .65345 m .29829 .61518 L .31423 .61619 L p .707 .577 .707 r
F P
0 g
s
.31423 .61619 m .31043 .65446 L .29448 .65345 L p .707 .577 .707 r
F P
0 g
s
.48274 .53947 m .47921 .59666 L .45809 .59255 L p .707 .577 .707 r
F P
0 g
s
.45809 .59255 m .46161 .53536 L .48274 .53947 L p .707 .577 .707 r
F P
0 g
s
.30966 .68466 m .30755 .70377 L .29171 .70179 L p .707 .577 .707 r
F P
0 g
s
.29171 .70179 m .29382 .68267 L .30966 .68466 L p .707 .577 .707 r
F P
0 g
s
.31452 .58544 m .31804 .52825 L .34195 .52721 L p .707 .577 .707 r
F P
0 g
s
.4785 .63269 m .4747 .67096 L .45345 .66835 L p .707 .577 .707 r
F P
0 g
s
.45345 .66835 m .45725 .63009 L .4785 .63269 L p .707 .577 .707 r
F P
0 g
s
.34195 .52721 m .33842 .5844 L .31452 .58544 L p .707 .577 .707 r
F P
0 g
s
.47377 .70273 m .47166 .72185 L .45036 .71969 L p .707 .577 .707 r
F P
0 g
s
.45036 .71969 m .45248 .70058 L .47377 .70273 L p .707 .577 .707 r
F P
0 g
s
.31043 .65446 m .31423 .61619 L .3379 .6181 L p .707 .577 .707 r
F P
0 g
s
.46161 .53536 m .45809 .59255 L .4306 .58897 L p .707 .577 .707 r
F P
0 g
s
.4306 .58897 m .43413 .53178 L .46161 .53536 L p .707 .577 .707 r
F P
0 g
s
.3379 .6181 m .3341 .65637 L .31043 .65446 L p .707 .577 .707 r
F P
0 g
s
.33842 .5844 m .34195 .52721 L .37122 .5275 L p .707 .577 .707 r
F P
0 g
s
.33324 .68745 m .33113 .70656 L .30755 .70377 L p .707 .577 .707 r
F P
0 g
s
.30755 .70377 m .30966 .68466 L .33324 .68745 L p .707 .577 .707 r
F P
0 g
s
.37122 .5275 m .36769 .58469 L .33842 .5844 L p .707 .577 .707 r
F P
0 g
s
.45725 .63009 m .45345 .66835 L .42593 .66529 L p .707 .577 .707 r
F P
0 g
s
.42593 .66529 m .42973 .62702 L .45725 .63009 L p .707 .577 .707 r
F P
0 g
s
.43413 .53178 m .4306 .58897 L .39945 .58626 L p .707 .577 .707 r
F P
0 g
s
.39945 .58626 m .40298 .52907 L .43413 .53178 L p .707 .577 .707 r
F P
0 g
s
.36769 .58469 m .37122 .5275 L .40298 .52907 L p .707 .577 .707 r
F P
0 g
s
.3341 .65637 m .3379 .6181 L .36698 .62072 L p .707 .577 .707 r
F P
0 g
s
.36698 .62072 m .36318 .65899 L .3341 .65637 L p .707 .577 .707 r
F P
0 g
s
.45248 .70058 m .45036 .71969 L .42282 .71678 L p .707 .577 .707 r
F P
0 g
s
.42282 .71678 m .42493 .69767 L .45248 .70058 L p .707 .577 .707 r
F P
0 g
s
.40298 .52907 m .39945 .58626 L .36769 .58469 L p .707 .577 .707 r
F P
0 g
s
.36225 .69076 m .36014 .70988 L .33113 .70656 L p .707 .577 .707 r
F P
0 g
s
.33113 .70656 m .33324 .68745 L .36225 .69076 L p .707 .577 .707 r
F P
0 g
s
.42973 .62702 m .42593 .66529 L .39482 .66206 L p .707 .577 .707 r
F P
0 g
s
.39482 .66206 m .39862 .62379 L .42973 .62702 L p .707 .577 .707 r
F P
0 g
s
.36318 .65899 m .36698 .62072 L .39862 .62379 L p .707 .577 .707 r
F P
0 g
s
.39862 .62379 m .39482 .66206 L .36318 .65899 L p .707 .577 .707 r
F P
0 g
s
.42493 .69767 m .42282 .71678 L .39173 .7134 L p .707 .577 .707 r
F P
0 g
s
.39173 .7134 m .39384 .69428 L .42493 .69767 L p .707 .577 .707 r
F P
0 g
s
.39384 .69428 m .39173 .7134 L .36014 .70988 L p .707 .577 .707 r
F P
0 g
s
.36014 .70988 m .36225 .69076 L .39384 .69428 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00N7oo5P00Sgoo001`Ool80004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH=0022Ool006]oo`D0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEPT007Uoo`00JGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Lgoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF
1P00KGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEPH006Moo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEP00008006Aoo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80069oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065o
o`00JGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HGoo
001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00HGoo001XOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HWoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIo
o`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1ROol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001NOol70002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Eoo`T000=JEP04001JEUYFFUHC000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`<000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo7P00AGoo
001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP003eoo`00DWoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPL003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF008000eJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0
039oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5
00001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo1@000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool005Yoo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
001QOol80004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP040000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool006=oo`04001JEUYF0002FUHP0005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0002eoo`00=goo40002goo1@0037oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02ioo`T000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`03001JEP00009JEPd0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000^Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP04001JEUYFFUH90009FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF001JEUYF5P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EQ0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000AJEP04
001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH<0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000`003EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000017oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000Moo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000aooa80
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0001iooaH003=oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP/005moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF4@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@0
05YFFUIJEQ0004moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@00AWoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH90004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0002FUH01000FUIJEUYF2@000eYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000gOol0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEQH0
009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP08000_Ool002]oo`03001JEP00024000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP/00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP@000=JEPL000=JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH30003FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUHC0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo000^Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH200000eYF001JEP03FUH00`00FUIJEP0>00000eYF001JEP02FUH500000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000cOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF4@0000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF2`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool003Yoo`P000AJEP03001JEUYF00MJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUHG0004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[OolB0005
OolA0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP02FUH90003FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@002goo10000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPh0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000MJ
EP03001JEUYF00=JEP04001JEUYFFUH20002Ool90003FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH90006Ool=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P002goo20000eYF1`000eYF00@005YFFUIJEP8002mo
o`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200027oo300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000COolC000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH01000FUIJ
EUYF300015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000QOol5000_Ool002Yoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00
FUIJEP04FUH;0004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH70003FUH01000FUIJEUYF0P002Goo0`00BGoo
000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH00UYF2P000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001P001EYF10000eYF0P0027oo1@00B7oo000ZOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0800000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00
FUH005YF001JEPh00003FUH0000000Qoo`D004Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00AJEP04001JEUYFFUH90003Ool50018Ool002Yoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004Moo`00:Woo1@000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?goo000[OolA
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF2P00=Goo000bOol7
0003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000020000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH02000<7oo000iOol90003FUH90004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040004Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02000`Ool0049oo`T000=JEPP000=JEP03001JEUYF00=JEP05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF1`0017oo2@0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo001;OolF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH0
20001Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80031oo`00:Woo2000
:Goo1P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000=Ool80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo
000ZOol00`00FUH00002FUH:000WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000MJEP03001JEUYF00=JEP04001JEUYFFUH2000EOol<0002FUH2000`Ool002Yoo`03
001JEP0000AJEP03001JEUYF010001aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP80025oo`@0031oo`00:Woo0P001EYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@004goo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00EGoo000ZOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30000UYF00@005YFFUIJEQh000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0005Eoo`00:goo2@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@000UYF100025YF00<005YFFUH025YF00<0
05YFFUH025YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol003Aoo`L000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00EWoo000kOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH70006FUH00`00FUIJEP02FUH00`00FUH000040004FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00EWoo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000035YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF
00<005YFFUH00UYF00@005YF000000=JEPL000=JEP04001JEUYFFUH2001FOol004eoo`P000AJEP03
001JEUYF00=JEP03001JEUYF00<000YJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEPD000=JEP04001JEP00OolC001FOol005Eoo``00004FUH0
0000Ool40006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP003goo1@00EWoo001QOol30005Ool40002
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH200000eYF001oo`1YOol006eoo`P000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00001ZOol007Eoo`/0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD006Uoo`00
P7oo3@001UYF00<005YFFUH02EYF00<005YFFUH00UYF6000HGoo002;OolI0006FUH00`00FUIJEP06
FUH01000FUIJEUYF3@00FGoo002?Ool90008FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00002001GOol009Uoo`P000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF008005Moo`00XGoo3@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Moo`00Zgoo2`0015YF00<005YFFUH00eYF00@005YFFUIJEP80
05Moo`00]7oo2@000eYF00@005YFFUIJEP8005Moo`00_Goo2@00Egoo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59389 .73986 m .59607 .6831 L .56491 .6807 L p .707 .577 .707 r
F P
0 g
s
.59607 .6831 m .59389 .73986 L .6257 .74053 L p .707 .577 .707 r
F P
0 g
s
.6257 .74053 m .62788 .68377 L .59607 .6831 L p .707 .577 .707 r
F P
0 g
s
.62788 .68377 m .6257 .74053 L .65503 .7394 L p .707 .577 .707 r
F P
0 g
s
.65503 .7394 m .65722 .68264 L .62788 .68377 L p .707 .577 .707 r
F P
0 g
s
.56273 .73746 m .56491 .6807 L .53744 .67681 L p .707 .577 .707 r
F P
0 g
s
.56491 .6807 m .56273 .73746 L .59389 .73986 L p .707 .577 .707 r
F P
0 g
s
.59183 .7936 m .5942 .75547 L .56305 .75275 L p .707 .577 .707 r
F P
0 g
s
.5942 .75547 m .59183 .7936 L .62359 .79519 L p .707 .577 .707 r
F P
0 g
s
.62359 .79519 m .62596 .75706 L .5942 .75547 L p .707 .577 .707 r
F P
0 g
s
.65722 .68264 m .65503 .7394 L .67903 .73658 L p .707 .577 .707 r
F P
0 g
s
.67903 .73658 m .68122 .67983 L .65722 .68264 L p .707 .577 .707 r
F P
0 g
s
.53744 .67681 m .53526 .73356 L .56273 .73746 L p .707 .577 .707 r
F P
0 g
s
.62596 .75706 m .62359 .79519 L .65286 .7955 L p .707 .577 .707 r
F P
0 g
s
.65286 .7955 m .65522 .75737 L .62596 .75706 L p .707 .577 .707 r
F P
0 g
s
.56305 .75275 m .56068 .79088 L .59183 .7936 L p .707 .577 .707 r
F P
0 g
s
.56068 .79088 m .56305 .75275 L .53557 .74918 L p .707 .577 .707 r
F P
0 g
s
.53526 .73356 m .53744 .67681 L .51636 .6718 L p .707 .577 .707 r
F P
0 g
s
.59024 .83212 m .59156 .81303 L .56042 .81022 L p .707 .577 .707 r
F P
0 g
s
.59156 .81303 m .59024 .83212 L .62198 .83399 L p .707 .577 .707 r
F P
0 g
s
.62198 .83399 m .6233 .81489 L .59156 .81303 L p .707 .577 .707 r
F P
0 g
s
.56042 .81022 m .5591 .82931 L .59024 .83212 L p .707 .577 .707 r
F P
0 g
s
.53557 .74918 m .5332 .78731 L .56068 .79088 L p .707 .577 .707 r
F P
0 g
s
.6233 .81489 m .62198 .83399 L .65122 .83472 L p .707 .577 .707 r
F P
0 g
s
.65122 .83472 m .65254 .81563 L .6233 .81489 L p .707 .577 .707 r
F P
0 g
s
.5591 .82931 m .56042 .81022 L .53293 .80673 L p .707 .577 .707 r
F P
0 g
s
.65522 .75737 m .65286 .7955 L .67676 .79449 L p .707 .577 .707 r
F P
0 g
s
.67676 .79449 m .67913 .75636 L .65522 .75737 L p .707 .577 .707 r
F P
0 g
s
.51636 .6718 m .51417 .72856 L .53526 .73356 L p .707 .577 .707 r
F P
0 g
s
.53293 .80673 m .53161 .82583 L .5591 .82931 L p .707 .577 .707 r
F P
0 g
s
.68122 .67983 m .67903 .73658 L .69534 .73236 L p .707 .577 .707 r
F P
0 g
s
.69534 .73236 m .69753 .6756 L .68122 .67983 L p .707 .577 .707 r
F P
0 g
s
.5332 .78731 m .53557 .74918 L .51444 .74509 L p .707 .577 .707 r
F P
0 g
s
.65254 .81563 m .65122 .83472 L .67509 .83426 L p .707 .577 .707 r
F P
0 g
s
.67509 .83426 m .67641 .81517 L .65254 .81563 L p .707 .577 .707 r
F P
0 g
s
.51444 .74509 m .51207 .78322 L .5332 .78731 L p .707 .577 .707 r
F P
0 g
s
.51417 .72856 m .51636 .6718 L .50372 .66616 L p .707 .577 .707 r
F P
0 g
s
.53161 .82583 m .53293 .80673 L .51178 .80292 L p .707 .577 .707 r
F P
0 g
s
.51178 .80292 m .51046 .82202 L .53161 .82583 L p .707 .577 .707 r
F P
0 g
s
.67913 .75636 m .67676 .79449 L .69297 .79227 L p .707 .577 .707 r
F P
0 g
s
.69297 .79227 m .69534 .75414 L .67913 .75636 L p .707 .577 .707 r
F P
0 g
s
.50372 .66616 m .50154 .72292 L .51417 .72856 L p .707 .577 .707 r
F P
0 g
s
.51207 .78322 m .51444 .74509 L .50173 .74089 L p .707 .577 .707 r
F P
0 g
s
.67641 .81517 m .67509 .83426 L .69126 .83264 L p .707 .577 .707 r
F P
0 g
s
.69126 .83264 m .69258 .81355 L .67641 .81517 L p .707 .577 .707 r
F P
0 g
s
.69753 .6756 m .69534 .73236 L .70236 .72714 L p .707 .577 .707 r
F P
0 g
s
.70236 .72714 m .70455 .67038 L .69753 .6756 L p .707 .577 .707 r
F P
0 g
s
.50173 .74089 m .49936 .77902 L .51207 .78322 L p .707 .577 .707 r
F P
0 g
s
.51046 .82202 m .51178 .80292 L .49904 .79916 L p .707 .577 .707 r
F P
0 g
s
.49904 .79916 m .49772 .81825 L .51046 .82202 L p .707 .577 .707 r
F P
0 g
s
.50154 .72292 m .50372 .66616 L .50077 .66046 L p .707 .577 .707 r
F P
0 g
s
.69534 .75414 m .69297 .79227 L .69989 .78906 L p .707 .577 .707 r
F P
0 g
s
.69989 .78906 m .70226 .75093 L .69534 .75414 L p .707 .577 .707 r
F P
0 g
s
.50077 .66046 m .49859 .71722 L .50154 .72292 L p .707 .577 .707 r
F P
0 g
s
.69258 .81355 m .69126 .83264 L .69814 .83003 L p .707 .577 .707 r
F P
0 g
s
.69814 .83003 m .69946 .81094 L .69258 .81355 L p .707 .577 .707 r
F P
0 g
s
.49936 .77902 m .50173 .74089 L .49869 .73699 L p .707 .577 .707 r
F P
0 g
s
.70455 .67038 m .70236 .72714 L .69941 .72144 L p .707 .577 .707 r
F P
0 g
s
.69941 .72144 m .7016 .66468 L .70455 .67038 L p .707 .577 .707 r
F P
0 g
s
.49869 .73699 m .49632 .77512 L .49936 .77902 L p .707 .577 .707 r
F P
0 g
s
.49772 .81825 m .49904 .79916 L .49596 .7958 L p .707 .577 .707 r
F P
0 g
s
.49596 .7958 m .49465 .81489 L .49772 .81825 L p .707 .577 .707 r
F P
0 g
s
.49859 .71722 m .50077 .66046 L .50779 .65524 L p .707 .577 .707 r
F P
0 g
s
.70226 .75093 m .69989 .78906 L .69685 .78516 L p .707 .577 .707 r
F P
0 g
s
.69685 .78516 m .69922 .74703 L .70226 .75093 L p .707 .577 .707 r
F P
0 g
s
.50779 .65524 m .50561 .712 L .49859 .71722 L p .707 .577 .707 r
F P
0 g
s
.69946 .81094 m .69814 .83003 L .69506 .82667 L p .707 .577 .707 r
F P
0 g
s
.69506 .82667 m .69638 .80758 L .69946 .81094 L p .707 .577 .707 r
F P
0 g
s
.49632 .77512 m .49869 .73699 L .50561 .73378 L p .707 .577 .707 r
F P
0 g
s
.48023 .8138 m .50009 .30124 L .45609 .29785 L p .707 .577 .707 r
F P
0 g
s
.50561 .73378 m .50324 .77191 L .49632 .77512 L p .707 .577 .707 r
F P
0 g
s
.49465 .81489 m .49596 .7958 L .50285 .79319 L p .707 .577 .707 r
F P
0 g
s
.50285 .79319 m .50153 .81228 L .49465 .81489 L p .707 .577 .707 r
F P
0 g
s
.50561 .712 m .50779 .65524 L .5241 .65102 L p .707 .577 .707 r
F P
0 g
s
.5241 .65102 m .52192 .70777 L .50561 .712 L p .707 .577 .707 r
F P
0 g
s
.50324 .77191 m .50561 .73378 L .52181 .73156 L p .707 .577 .707 r
F P
0 g
s
.52181 .73156 m .51945 .76969 L .50324 .77191 L p .707 .577 .707 r
F P
0 g
s
.50153 .81228 m .50285 .79319 L .51901 .79157 L p .707 .577 .707 r
F P
0 g
s
.51901 .79157 m .51769 .81066 L .50153 .81228 L p .707 .577 .707 r
F P
0 g
s
.51945 .76969 m .52181 .73156 L .54572 .73056 L p .707 .577 .707 r
F P
0 g
s
.54572 .73056 m .54335 .76869 L .51945 .76969 L p .707 .577 .707 r
F P
0 g
s
.51769 .81066 m .51901 .79157 L .54288 .79111 L p .707 .577 .707 r
F P
0 g
s
.54288 .79111 m .54157 .8102 L .51769 .81066 L p .707 .577 .707 r
F P
0 g
s
.50009 .30124 m .48023 .8138 L .52514 .81475 L p .707 .577 .707 r
F P
0 g
s
.52192 .70777 m .5241 .65102 L .5481 .6482 L p .707 .577 .707 r
F P
0 g
s
.5481 .6482 m .54591 .70496 L .52192 .70777 L p .707 .577 .707 r
F P
0 g
s
.52514 .81475 m .54499 .3022 L .50009 .30124 L p .707 .577 .707 r
F P
0 g
s
.7016 .66468 m .69941 .72144 L .68677 .7158 L p .707 .577 .707 r
F P
0 g
s
.68677 .7158 m .68896 .65904 L .7016 .66468 L p .707 .577 .707 r
F P
0 g
s
.54591 .70496 m .5481 .6482 L .57744 .64707 L p .707 .577 .707 r
F P
0 g
s
.57744 .64707 m .57525 .70383 L .54591 .70496 L p .707 .577 .707 r
F P
0 g
s
.54335 .76869 m .54555 .73329 L p .57499 .73086 L .707 .577 .707 r
F P
0 g
s
.54555 .73329 m .54572 .73056 L .54596 .73056 L p .707 .577 .707 r
F P
0 g
s
.54596 .73056 m .57499 .73086 L p .54555 .73329 L .707 .577 .707 r
F P
0 g
s
.57525 .70383 m .57744 .64707 L .60925 .64774 L p .707 .577 .707 r
F P
0 g
s
.60925 .64774 m .60706 .7045 L .57525 .70383 L p .707 .577 .707 r
F P
0 g
s
.57499 .73086 m .57262 .76899 L .54335 .76869 L p .707 .577 .707 r
F P
0 g
s
.54157 .8102 m .54288 .79111 L .57212 .79184 L p .707 .577 .707 r
F P
0 g
s
.57212 .79184 m .5708 .81094 L .54157 .8102 L p .707 .577 .707 r
F P
0 g
s
.57262 .76899 m .57499 .73086 L .60675 .73245 L p .707 .577 .707 r
F P
0 g
s
.60675 .73245 m .60438 .77058 L .57262 .76899 L p .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57212 .79184 L .57817 .7922 L p .707 .577 .707 r
F P
0 g
s
.57817 .7922 m .60386 .79371 L p .57684 .80779 L .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57817 .7922 L .57684 .80779 L .707 .577 .707 r
F
.64041 .65014 m .63822 .7069 L .60706 .7045 L p F P
0 g
s
.60706 .7045 m .60925 .64774 L .64041 .65014 L p .707 .577 .707 r
F P
0 g
s
.63789 .73517 m .63553 .7733 L .60438 .77058 L p .707 .577 .707 r
F P
0 g
s
.60438 .77058 m .60675 .73245 L .63789 .73517 L p .707 .577 .707 r
F P
0 g
s
.63501 .79652 m .63369 .81561 L .60255 .8128 L p .707 .577 .707 r
F P
0 g
s
.60255 .8128 m .60386 .79371 L .63501 .79652 L p .707 .577 .707 r
F P
0 g
s
.60386 .79371 m .60255 .8128 L .5708 .81094 L p .707 .577 .707 r
F P
0 g
s
.60044 .80923 m .62346 .80329 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62029 .29667 m .62022 .29825 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62022 .29825 m .60044 .80923 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .60044 .80923 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.58641 .30062 m .57816 .51356 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.57816 .51356 m .56656 .81318 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.54499 .3022 m .52514 .81475 L .56656 .81318 L p .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .58641 .30062 L .54499 .3022 L p .707 .577 .707 r
F P
0 g
s
.25088 .70304 m .25307 .64628 L .2219 .64389 L p .707 .577 .707 r
F P
0 g
s
.25307 .64628 m .25088 .70304 L .28269 .70371 L p .707 .577 .707 r
F P
0 g
s
.28269 .70371 m .28487 .64695 L .25307 .64628 L p .707 .577 .707 r
F P
0 g
s
.43624 .81041 m .45609 .29785 L .41731 .29236 L p .707 .577 .707 r
F P
0 g
s
.45609 .29785 m .43624 .81041 L .48023 .8138 L p .707 .577 .707 r
F P
0 g
s
.28487 .64695 m .28269 .70371 L .31203 .70258 L p .707 .577 .707 r
F P
0 g
s
.31203 .70258 m .31421 .64582 L .28487 .64695 L p .707 .577 .707 r
F P
0 g
s
.21972 .70064 m .2219 .64389 L .19444 .63999 L p .707 .577 .707 r
F P
0 g
s
.2219 .64389 m .21972 .70064 L .25088 .70304 L p .707 .577 .707 r
F P
0 g
s
.69922 .74703 m .69685 .78516 L .68414 .78096 L p .707 .577 .707 r
F P
0 g
s
.68414 .78096 m .68651 .74283 L .69922 .74703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60044 .80923 m .62029 .29667 L .58641 .30062 L p .707 .577 .707 r
F P
0 g
s
.24882 .75679 m .25119 .71865 L .22004 .71594 L p .707 .577 .707 r
F P
0 g
s
.25119 .71865 m .24882 .75679 L .28058 .75837 L p .707 .577 .707 r
F P
0 g
s
.28058 .75837 m .28295 .72024 L .25119 .71865 L p .707 .577 .707 r
F P
0 g
s
.31421 .64582 m .31203 .70258 L .33602 .69977 L p .707 .577 .707 r
F P
0 g
s
.33602 .69977 m .33821 .64301 L .31421 .64582 L p .707 .577 .707 r
F P
0 g
s
.19444 .63999 m .19225 .69675 L .21972 .70064 L p .707 .577 .707 r
F P
0 g
s
.28295 .72024 m .28058 .75837 L .30985 .75868 L p .707 .577 .707 r
F P
0 g
s
.30985 .75868 m .31222 .72055 L .28295 .72024 L p .707 .577 .707 r
F P
0 g
s
.22004 .71594 m .21767 .75407 L .24882 .75679 L p .707 .577 .707 r
F P
0 g
s
.69638 .80758 m .69506 .82667 L .68232 .82291 L p .707 .577 .707 r
F P
0 g
s
.68232 .82291 m .68364 .80381 L .69638 .80758 L p .707 .577 .707 r
F P
0 g
s
.21767 .75407 m .22004 .71594 L .19256 .71236 L p .707 .577 .707 r
F P
0 g
s
.68896 .65904 m .68677 .7158 L .66569 .71079 L p .707 .577 .707 r
F P
0 g
s
.66569 .71079 m .66788 .65403 L .68896 .65904 L p .707 .577 .707 r
F P
0 g
s
.19225 .69675 m .19444 .63999 L .17335 .63498 L p .707 .577 .707 r
F P
0 g
s
.39746 .80491 m .41731 .29236 L .38755 .2853 L p .707 .577 .707 r
F P
0 g
s
.41731 .29236 m .39746 .80491 L .43624 .81041 L p .707 .577 .707 r
F P
0 g
s
.24723 .7953 m .24855 .77621 L .21741 .7734 L p .707 .577 .707 r
F P
0 g
s
.24855 .77621 m .24723 .7953 L .27897 .79717 L p .707 .577 .707 r
F P
0 g
s
.27897 .79717 m .28029 .77808 L .24855 .77621 L p .707 .577 .707 r
F P
0 g
s
.21741 .7734 m .21609 .79249 L .24723 .7953 L p .707 .577 .707 r
F P
0 g
s
.19256 .71236 m .19019 .75049 L .21767 .75407 L p .707 .577 .707 r
F P
0 g
s
.28029 .77808 m .27897 .79717 L .30821 .79791 L p .707 .577 .707 r
F P
0 g
s
.30821 .79791 m .30953 .77881 L .28029 .77808 L p .707 .577 .707 r
F P
0 g
s
.21609 .79249 m .21741 .7734 L .18992 .76992 L p .707 .577 .707 r
F P
0 g
s
.31222 .72055 m .30985 .75868 L .33376 .75768 L p .707 .577 .707 r
F P
0 g
s
.33376 .75768 m .33612 .71955 L .31222 .72055 L p .707 .577 .707 r
F P
0 g
s
.17335 .63498 m .17117 .69174 L .19225 .69675 L p .707 .577 .707 r
F P
0 g
s
.18992 .76992 m .1886 .78901 L .21609 .79249 L p .707 .577 .707 r
F P
0 g
s
.33821 .64301 m .33602 .69977 L .35233 .69555 L p .707 .577 .707 r
F P
0 g
s
.35233 .69555 m .35452 .63879 L .33821 .64301 L p .707 .577 .707 r
F P
0 g
s
.19019 .75049 m .19256 .71236 L .17143 .70827 L p .707 .577 .707 r
F P
0 g
s
.68651 .74283 m .68414 .78096 L .66301 .77688 L p .707 .577 .707 r
F P
0 g
s
.66301 .77688 m .66538 .73874 L .68651 .74283 L p .707 .577 .707 r
F P
0 g
s
.30953 .77881 m .30821 .79791 L .33208 .79745 L p .707 .577 .707 r
F P
0 g
s
.33208 .79745 m .3334 .77835 L .30953 .77881 L p .707 .577 .707 r
F P
0 g
s
.17143 .70827 m .16906 .7464 L .19019 .75049 L p .707 .577 .707 r
F P
0 g
s
.62346 .80329 m .64331 .29074 L .62029 .29667 L p .707 .577 .707 r
F P
0 g
s
.66788 .65403 m .66569 .71079 L .63822 .7069 L p .707 .577 .707 r
F P
0 g
s
.63822 .7069 m .64041 .65014 L .66788 .65403 L p .707 .577 .707 r
F P
0 g
s
.17117 .69174 m .17335 .63498 L .16072 .62935 L p .707 .577 .707 r
F P
0 g
s
.1886 .78901 m .18992 .76992 L .16877 .76611 L p .707 .577 .707 r
F P
0 g
s
.16877 .76611 m .16745 .7852 L .1886 .78901 L p .707 .577 .707 r
F P
0 g
s
.68364 .80381 m .68232 .82291 L .66118 .8191 L p .707 .577 .707 r
F P
0 g
s
.66118 .8191 m .6625 .8 L .68364 .80381 L p .707 .577 .707 r
F P
0 g
s
.33612 .71955 m .33376 .75768 L .34996 .75546 L p .707 .577 .707 r
F P
0 g
s
.34996 .75546 m .35233 .71733 L .33612 .71955 L p .707 .577 .707 r
F P
0 g
s
.16072 .62935 m .15853 .68611 L .17117 .69174 L p .707 .577 .707 r
F P
0 g
s
.3677 .79785 m .38755 .2853 L .36971 .27736 L p .707 .577 .707 r
F P
0 g
s
.38755 .2853 m .3677 .79785 L .39746 .80491 L p .707 .577 .707 r
F P
0 g
s
.16906 .7464 m .17143 .70827 L .15872 .70408 L p .707 .577 .707 r
F P
0 g
s
.3334 .77835 m .33208 .79745 L .34825 .79583 L p .707 .577 .707 r
F P
0 g
s
.34825 .79583 m .34957 .77673 L .3334 .77835 L p .707 .577 .707 r
F P
0 g
s
.66538 .73874 m .66301 .77688 L .63553 .7733 L p .707 .577 .707 r
F P
0 g
s
.63553 .7733 m .63789 .73517 L .66538 .73874 L p .707 .577 .707 r
F P
0 g
s
.35452 .63879 m .35233 .69555 L .35935 .69033 L p .707 .577 .707 r
F P
0 g
s
.35935 .69033 m .36154 .63357 L .35452 .63879 L p .707 .577 .707 r
F P
0 g
s
.15872 .70408 m .15635 .74221 L .16906 .7464 L p .707 .577 .707 r
F P
0 g
s
.16745 .7852 m .16877 .76611 L .15603 .76234 L p .707 .577 .707 r
F P
0 g
s
.15603 .76234 m .15471 .78143 L .16745 .7852 L p .707 .577 .707 r
F P
0 g
s
.6625 .8 m .66118 .8191 L .63369 .81561 L p .707 .577 .707 r
F P
0 g
s
.63369 .81561 m .63501 .79652 L .6625 .8 L p .707 .577 .707 r
F P
0 g
s
.15853 .68611 m .16072 .62935 L .15776 .62364 L p .707 .577 .707 r
F P
0 g
s
.35233 .71733 m .34996 .75546 L .35688 .75224 L p .707 .577 .707 r
F P
0 g
s
.35688 .75224 m .35925 .71411 L .35233 .71733 L p .707 .577 .707 r
F P
0 g
s
.64331 .29074 m .62346 .80329 L .63337 .79595 L p .707 .577 .707 r
F P
0 g
s
.63337 .79595 m .65322 .28339 L .64331 .29074 L p .707 .577 .707 r
F P
0 g
s
.15776 .62364 m .15558 .6804 L .15853 .68611 L p .707 .577 .707 r
F P
0 g
s
.34957 .77673 m .34825 .79583 L .35513 .79321 L p .707 .577 .707 r
F P
0 g
s
.35513 .79321 m .35645 .77412 L .34957 .77673 L p .707 .577 .707 r
F P
0 g
s
.15635 .74221 m .15872 .70408 L .15568 .70018 L p .707 .577 .707 r
F P
0 g
s
.36154 .63357 m .35935 .69033 L .3564 .68462 L p .707 .577 .707 r
F P
0 g
s
.3564 .68462 m .35859 .62786 L .36154 .63357 L p .707 .577 .707 r
F P
0 g
s
.15568 .70018 m .15331 .73831 L .15635 .74221 L p .707 .577 .707 r
F P
0 g
s
.35859 .62786 m .3564 .68462 L .34376 .67899 L p .707 .577 .707 r
F P
0 g
s
.34376 .67899 m .34595 .62223 L .35859 .62786 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .34113 .74415 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35621 .71021 m .35604 .71295 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35604 .71295 m .35384 .74835 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.34113 .74415 m .3435 .70602 L .35621 .71021 L p .707 .577 .707 r
F P
0 g
s
.35337 .77077 m .35205 .78986 L .33932 .78609 L p .707 .577 .707 r
F P
0 g
s
.33932 .78609 m .34063 .767 L .35337 .77077 L p .707 .577 .707 r
F P
0 g
s
.34986 .78992 m .36146 .4903 L p .36554 .26933 L .707 .577 .707 r
F P
0 g
s
.36146 .4903 m .36971 .27736 L .36678 .27173 L p .707 .577 .707 r
F P
0 g
s
.36678 .27173 m .36554 .26933 L p .36146 .4903 L .707 .577 .707 r
F P
0 g
s
.35925 .71411 m .35688 .75224 L .35384 .74835 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .35621 .71021 L .35925 .71411 L p .707 .577 .707 r
F P
0 g
s
.35645 .77412 m .35513 .79321 L .35205 .78986 L p .707 .577 .707 r
F P
0 g
s
.35205 .78986 m .35337 .77077 L .35645 .77412 L p .707 .577 .707 r
F P
0 g
s
.36971 .27736 m .34986 .78992 L .3677 .79785 L p .707 .577 .707 r
F P
0 g
s
.15471 .78143 m .15603 .76234 L .15295 .75898 L p .707 .577 .707 r
F P
0 g
s
.15295 .75898 m .15164 .77808 L .15471 .78143 L p .707 .577 .707 r
F P
0 g
s
.15558 .6804 m .15776 .62364 L .16479 .61842 L p .707 .577 .707 r
F P
0 g
s
.16479 .61842 m .1626 .67518 L .15558 .6804 L p .707 .577 .707 r
F P
0 g
s
.15331 .73831 m .15568 .70018 L .1626 .69696 L p .707 .577 .707 r
F P
0 g
s
.65322 .28339 m .63337 .79595 L .6292 .78791 L p .707 .577 .707 r
F P
0 g
s
.6292 .78791 m .64905 .27536 L .65322 .28339 L p .707 .577 .707 r
F P
0 g
s
.1626 .69696 m .16023 .73509 L .15331 .73831 L p .707 .577 .707 r
F P
0 g
s
.15164 .77808 m .15295 .75898 L .15984 .75637 L p .707 .577 .707 r
F P
0 g
s
.15984 .75637 m .15852 .77546 L .15164 .77808 L p .707 .577 .707 r
F P
0 g
s
.1626 .67518 m .16479 .61842 L .18109 .6142 L p .707 .577 .707 r
F P
0 g
s
.36554 .26933 m .34569 .78189 L .34986 .78992 L p .707 .577 .707 r
F P
0 g
s
.34569 .78189 m .36554 .26933 L .37545 .26199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18109 .6142 m .17891 .67096 L .1626 .67518 L p .707 .577 .707 r
F P
0 g
s
.16023 .73509 m .1626 .69696 L .1788 .69474 L p .707 .577 .707 r
F P
0 g
s
.34595 .62223 m .34376 .67899 L .32268 .67398 L p .707 .577 .707 r
F P
0 g
s
.32268 .67398 m .32487 .61722 L .34595 .62223 L p .707 .577 .707 r
F P
0 g
s
.1788 .69474 m .17644 .73288 L .16023 .73509 L p .707 .577 .707 r
F P
0 g
s
.15852 .77546 m .15984 .75637 L .176 .75475 L p .707 .577 .707 r
F P
0 g
s
.17891 .67096 m .18109 .6142 L .20509 .61139 L p .707 .577 .707 r
F P
0 g
s
.176 .75475 m .17468 .77385 L .15852 .77546 L p .707 .577 .707 r
F P
0 g
s
.64905 .27536 m .6292 .78791 L .61136 .77998 L p .707 .577 .707 r
F P
0 g
s
.61136 .77998 m .63121 .26742 L .64905 .27536 L p .707 .577 .707 r
F P
0 g
s
.3435 .70602 m .34113 .74415 L .32 .74006 L p .707 .577 .707 r
F P
0 g
s
.32 .74006 m .32237 .70193 L .3435 .70602 L p .707 .577 .707 r
F P
0 g
s
.20509 .61139 m .2029 .66815 L .17891 .67096 L p .707 .577 .707 r
F P
0 g
s
.32487 .61722 m .32268 .67398 L .29521 .67008 L p .707 .577 .707 r
F P
0 g
s
.29521 .67008 m .2974 .61333 L .32487 .61722 L p .707 .577 .707 r
F P
0 g
s
.17644 .73288 m .1788 .69474 L .20271 .69374 L p .707 .577 .707 r
F P
0 g
s
.34063 .767 m .33932 .78609 L .31817 .78228 L p .707 .577 .707 r
F P
0 g
s
.31817 .78228 m .31949 .76319 L .34063 .767 L p .707 .577 .707 r
F P
0 g
s
.2029 .66815 m .20509 .61139 L .23443 .61026 L p .707 .577 .707 r
F P
0 g
s
.20271 .69374 m .20034 .73187 L .17644 .73288 L p .707 .577 .707 r
F P
0 g
s
.3556 .77454 m .37545 .26199 L .39847 .25605 L p .707 .577 .707 r
F P
0 g
s
.37545 .26199 m .3556 .77454 L .34569 .78189 L p .707 .577 .707 r
F P
0 g
s
.17468 .77385 m .176 .75475 L .19987 .75429 L p .707 .577 .707 r
F P
0 g
s
.19987 .75429 m .19856 .77338 L .17468 .77385 L p .707 .577 .707 r
F P
0 g
s
.2974 .61333 m .29521 .67008 L .26405 .66769 L p .707 .577 .707 r
F P
0 g
s
.26405 .66769 m .26624 .61093 L .2974 .61333 L p .707 .577 .707 r
F P
0 g
s
.23443 .61026 m .23224 .66702 L .2029 .66815 L p .707 .577 .707 r
F P
0 g
s
.32237 .70193 m .32 .74006 L .29252 .73648 L p .707 .577 .707 r
F P
0 g
s
.29252 .73648 m .29489 .69835 L .32237 .70193 L p .707 .577 .707 r
F P
0 g
s
.23224 .66702 m .23443 .61026 L .26624 .61093 L p .707 .577 .707 r
F P
0 g
s
.73109 .65071 m .73328 .59395 L .70212 .59155 L p .707 .577 .707 r
F P
0 g
s
.73328 .59395 m .73109 .65071 L .7629 .65138 L p .707 .577 .707 r
F P
0 g
s
.7629 .65138 m .76509 .59462 L .73328 .59395 L p .707 .577 .707 r
F P
0 g
s
.26624 .61093 m .26405 .66769 L .23224 .66702 L p .707 .577 .707 r
F P
0 g
s
.20034 .73187 m .20271 .69374 L .23198 .69405 L p .707 .577 .707 r
F P
0 g
s
.76509 .59462 m .7629 .65138 L .79224 .65025 L p .707 .577 .707 r
F P
0 g
s
.79224 .65025 m .79442 .59349 L .76509 .59462 L p .707 .577 .707 r
F P
0 g
s
.31949 .76319 m .31817 .78228 L .29068 .7788 L p .707 .577 .707 r
F P
0 g
s
.29068 .7788 m .292 .75971 L .31949 .76319 L p .707 .577 .707 r
F P
0 g
s
.69993 .64831 m .70212 .59155 L .67465 .58766 L p .707 .577 .707 r
F P
0 g
s
.70212 .59155 m .69993 .64831 L .73109 .65071 L p .707 .577 .707 r
F P
0 g
s
.23198 .69405 m .22961 .73218 L .20034 .73187 L p .707 .577 .707 r
F P
0 g
s
.63121 .26742 m .61136 .77998 L .5816 .77292 L p .707 .577 .707 r
F P
0 g
s
.5816 .77292 m .60145 .26036 L .63121 .26742 L p .707 .577 .707 r
F P
0 g
s
.29489 .69835 m .29252 .73648 L .26137 .73377 L p .707 .577 .707 r
F P
0 g
s
.26137 .73377 m .26374 .69564 L .29489 .69835 L p .707 .577 .707 r
F P
0 g
s
.19856 .77338 m .19987 .75429 L .22911 .75503 L p .707 .577 .707 r
F P
0 g
s
.22911 .75503 m .22779 .77412 L .19856 .77338 L p .707 .577 .707 r
F P
0 g
s
.22961 .73218 m .23198 .69405 L .26374 .69564 L p .707 .577 .707 r
F P
0 g
s
.79442 .59349 m .79224 .65025 L .81624 .64743 L p .707 .577 .707 r
F P
0 g
s
.81624 .64743 m .81842 .59068 L .79442 .59349 L p .707 .577 .707 r
F P
0 g
s
.72903 .70831 m .7314 .67018 L .70026 .66746 L p .707 .577 .707 r
F P
0 g
s
.7314 .67018 m .72903 .70831 L .7608 .7099 L p .707 .577 .707 r
F P
0 g
s
.7608 .7099 m .76316 .67177 L .7314 .67018 L p .707 .577 .707 r
F P
0 g
s
.67465 .58766 m .67246 .64441 L .69993 .64831 L p .707 .577 .707 r
F P
0 g
s
.26374 .69564 m .26137 .73377 L .22961 .73218 L p .707 .577 .707 r
F P
0 g
s
.76316 .67177 m .7608 .7099 L .79006 .7102 L p .707 .577 .707 r
F P
0 g
s
.79006 .7102 m .79243 .67207 L .76316 .67177 L p .707 .577 .707 r
F P
0 g
s
.70026 .66746 m .69789 .70559 L .72903 .70831 L p .707 .577 .707 r
F P
0 g
s
.292 .75971 m .29068 .7788 L .25954 .77599 L p .707 .577 .707 r
F P
0 g
s
.25954 .77599 m .26086 .75689 L .292 .75971 L p .707 .577 .707 r
F P
0 g
s
.67246 .64441 m .67465 .58766 L .65356 .58265 L p .707 .577 .707 r
F P
0 g
s
.69789 .70559 m .70026 .66746 L .67277 .66388 L p .707 .577 .707 r
F P
0 g
s
.39847 .25605 m .37862 .76861 L .3556 .77454 L p .707 .577 .707 r
F P
0 g
s
.37862 .76861 m .39847 .25605 L .43235 .2521 L p .707 .577 .707 r
F P
0 g
s
.22779 .77412 m .22911 .75503 L .26086 .75689 L p .707 .577 .707 r
F P
0 g
s
.72744 .75225 m .72876 .73315 L .69762 .73034 L p .707 .577 .707 r
F P
0 g
s
.72876 .73315 m .72744 .75225 L .75919 .75411 L p .707 .577 .707 r
F P
0 g
s
.75919 .75411 m .7605 .73502 L .72876 .73315 L p .707 .577 .707 r
F P
0 g
s
.26086 .75689 m .25954 .77599 L .22779 .77412 L p .707 .577 .707 r
F P
0 g
s
.67277 .66388 m .6704 .70201 L .69789 .70559 L p .707 .577 .707 r
F P
0 g
s
.69762 .73034 m .6963 .74944 L .72744 .75225 L p .707 .577 .707 r
F P
0 g
s
.7605 .73502 m .75919 .75411 L .78842 .75485 L p .707 .577 .707 r
F P
0 g
s
.78842 .75485 m .78974 .73576 L .7605 .73502 L p .707 .577 .707 r
F P
0 g
s
.79243 .67207 m .79006 .7102 L .81397 .7092 L p .707 .577 .707 r
F P
0 g
s
.81397 .7092 m .81634 .67107 L .79243 .67207 L p .707 .577 .707 r
F P
0 g
s
.65356 .58265 m .65138 .63941 L .67246 .64441 L p .707 .577 .707 r
F P
0 g
s
.6963 .74944 m .69762 .73034 L .67013 .72686 L p .707 .577 .707 r
F P
0 g
s
.67013 .72686 m .66881 .74596 L .6963 .74944 L p .707 .577 .707 r
F P
0 g
s
.81842 .59068 m .81624 .64743 L .83254 .64321 L p .707 .577 .707 r
F P
0 g
s
.83254 .64321 m .83473 .58645 L .81842 .59068 L p .707 .577 .707 r
F P
0 g
s
.6704 .70201 m .67277 .66388 L .65164 .6598 L p .707 .577 .707 r
F P
0 g
s
.78974 .73576 m .78842 .75485 L .8123 .75439 L p .707 .577 .707 r
F P
0 g
s
.8123 .75439 m .81361 .7353 L .78974 .73576 L p .707 .577 .707 r
F P
0 g
s
.65164 .6598 m .64927 .69793 L .6704 .70201 L p .707 .577 .707 r
F P
0 g
s
.60145 .26036 m .5816 .77292 L .54282 .76743 L p .707 .577 .707 r
F P
0 g
s
.54282 .76743 m .56267 .25487 L .60145 .26036 L p .707 .577 .707 r
F P
0 g
s
.65138 .63941 m .65356 .58265 L .64093 .57701 L p .707 .577 .707 r
F P
0 g
s
.66881 .74596 m .67013 .72686 L .64898 .72305 L p .707 .577 .707 r
F P
0 g
s
.64898 .72305 m .64766 .74214 L .66881 .74596 L p .707 .577 .707 r
F P
0 g
s
.81634 .67107 m .81397 .7092 L .83018 .70698 L p .707 .577 .707 r
F P
0 g
s
.83018 .70698 m .83254 .66885 L .81634 .67107 L p .707 .577 .707 r
F P
0 g
s
.4125 .76466 m .43235 .2521 L .47377 .25052 L p .707 .577 .707 r
F P
0 g
s
.43235 .2521 m .4125 .76466 L .37862 .76861 L p .707 .577 .707 r
F P
0 g
s
.64093 .57701 m .63874 .63377 L .65138 .63941 L p .707 .577 .707 r
F P
0 g
s
.64927 .69793 m .65164 .6598 L .63893 .6556 L p .707 .577 .707 r
F P
0 g
s
.83473 .58645 m .83254 .64321 L .83957 .63799 L p .707 .577 .707 r
F P
0 g
s
.83957 .63799 m .84175 .58123 L .83473 .58645 L p .707 .577 .707 r
F P
0 g
s
.81361 .7353 m .8123 .75439 L .82846 .75277 L p .707 .577 .707 r
F P
0 g
s
.82846 .75277 m .82978 .73368 L .81361 .7353 L p .707 .577 .707 r
F P
0 g
s
.63893 .6556 m .63657 .69373 L .64927 .69793 L p .707 .577 .707 r
F P
0 g
s
.56267 .25487 m .54282 .76743 L .49882 .76404 L p .707 .577 .707 r
F P
0 g
s
.49882 .76404 m .51867 .25148 L .56267 .25487 L p .707 .577 .707 r
F P
0 g
s
.45392 .76308 m .47377 .25052 L .51867 .25148 L p .707 .577 .707 r
F P
0 g
s
.47377 .25052 m .45392 .76308 L .4125 .76466 L p .707 .577 .707 r
F P
0 g
s
.64766 .74214 m .64898 .72305 L .63625 .71928 L p .707 .577 .707 r
F P
0 g
s
.63874 .63377 m .64093 .57701 L .63798 .57131 L p .707 .577 .707 r
F P
0 g
s
.63625 .71928 m .63493 .73838 L .64766 .74214 L p .707 .577 .707 r
F P
0 g
s
.51867 .25148 m .49882 .76404 L .45392 .76308 L p .707 .577 .707 r
F P
0 g
s
.83254 .66885 m .83018 .70698 L .8371 .70376 L p .707 .577 .707 r
F P
0 g
s
.8371 .70376 m .83946 .66563 L .83254 .66885 L p .707 .577 .707 r
F P
0 g
s
.63798 .57131 m .63579 .62807 L .63874 .63377 L p .707 .577 .707 r
F P
0 g
s
.63657 .69373 m .63893 .6556 L .63589 .6517 L p .707 .577 .707 r
F P
0 g
s
.82978 .73368 m .82846 .75277 L .83534 .75016 L p .707 .577 .707 r
F P
0 g
s
.83534 .75016 m .83666 .73106 L .82978 .73368 L p .707 .577 .707 r
F P
0 g
s
.84175 .58123 m .83957 .63799 L .83662 .63229 L p .707 .577 .707 r
F P
0 g
s
.83662 .63229 m .8388 .57553 L .84175 .58123 L p .707 .577 .707 r
F P
0 g
s
.63589 .6517 m .63352 .68983 L .63657 .69373 L p .707 .577 .707 r
F P
0 g
s
.63493 .73838 m .63625 .71928 L .63317 .71593 L p .707 .577 .707 r
F P
0 g
s
.63317 .71593 m .63185 .73502 L .63493 .73838 L p .707 .577 .707 r
F P
0 g
s
.63579 .62807 m .63798 .57131 L .645 .56609 L p .707 .577 .707 r
F P
0 g
s
.83946 .66563 m .8371 .70376 L .83405 .69987 L p .707 .577 .707 r
F P
0 g
s
.83405 .69987 m .83642 .66174 L .83946 .66563 L p .707 .577 .707 r
F P
0 g
s
.645 .56609 m .64281 .62285 L .63579 .62807 L p .707 .577 .707 r
F P
0 g
s
.83666 .73106 m .83534 .75016 L .83227 .7468 L p .707 .577 .707 r
F P
0 g
s
.83227 .7468 m .83358 .72771 L .83666 .73106 L p .707 .577 .707 r
F P
0 g
s
.63352 .68983 m .63589 .6517 L .64281 .64848 L p .707 .577 .707 r
F P
0 g
s
.8388 .57553 m .83662 .63229 L .82398 .62665 L p .707 .577 .707 r
F P
0 g
s
.82398 .62665 m .82617 .56989 L .8388 .57553 L p .707 .577 .707 r
F P
0 g
s
.64281 .64848 m .64044 .68662 L .63352 .68983 L p .707 .577 .707 r
F P
0 g
s
.38808 .61389 m .39027 .55713 L .35911 .55473 L p .707 .577 .707 r
F P
0 g
s
.39027 .55713 m .38808 .61389 L .41989 .61456 L p .707 .577 .707 r
F P
0 g
s
.41989 .61456 m .42208 .5578 L .39027 .55713 L p .707 .577 .707 r
F P
0 g
s
.63185 .73502 m .63317 .71593 L .64005 .71331 L p .707 .577 .707 r
F P
0 g
s
.42208 .5578 m .41989 .61456 L .44923 .61343 L p .707 .577 .707 r
F P
0 g
s
.44923 .61343 m .45142 .55667 L .42208 .5578 L p .707 .577 .707 r
F P
0 g
s
.64005 .71331 m .63873 .73241 L .63185 .73502 L p .707 .577 .707 r
F P
0 g
s
.64281 .62285 m .645 .56609 L .66131 .56186 L p .707 .577 .707 r
F P
0 g
s
.35692 .61149 m .35911 .55473 L .33164 .55084 L p .707 .577 .707 r
F P
0 g
s
.35911 .55473 m .35692 .61149 L .38808 .61389 L p .707 .577 .707 r
F P
0 g
s
.83642 .66174 m .83405 .69987 L .82135 .69567 L p .707 .577 .707 r
F P
0 g
s
.82135 .69567 m .82371 .65754 L .83642 .66174 L p .707 .577 .707 r
F P
0 g
s
.66131 .56186 m .65912 .61862 L .64281 .62285 L p .707 .577 .707 r
F P
0 g
s
.45142 .55667 m .44923 .61343 L .47323 .61062 L p .707 .577 .707 r
F P
0 g
s
.47323 .61062 m .47541 .55386 L .45142 .55667 L p .707 .577 .707 r
F P
0 g
s
.38602 .67149 m .38839 .63336 L .35725 .63064 L p .707 .577 .707 r
F P
0 g
s
.38839 .63336 m .38602 .67149 L .41779 .67308 L p .707 .577 .707 r
F P
0 g
s
.41779 .67308 m .42015 .63495 L .38839 .63336 L p .707 .577 .707 r
F P
0 g
s
.33164 .55084 m .32945 .6076 L .35692 .61149 L p .707 .577 .707 r
F P
0 g
s
.42015 .63495 m .41779 .67308 L .44705 .67339 L p .707 .577 .707 r
F P
0 g
s
.44705 .67339 m .44942 .63526 L .42015 .63495 L p .707 .577 .707 r
F P
0 g
s
.35725 .63064 m .35488 .66877 L .38602 .67149 L p .707 .577 .707 r
F P
0 g
s
.64044 .68662 m .64281 .64848 L .65902 .64627 L p .707 .577 .707 r
F P
0 g
s
.82617 .56989 m .82398 .62665 L .8029 .62164 L p .707 .577 .707 r
F P
0 g
s
.8029 .62164 m .80508 .56488 L .82617 .56989 L p .707 .577 .707 r
F P
0 g
s
.32945 .6076 m .33164 .55084 L .31055 .54583 L p .707 .577 .707 r
F P
0 g
s
.83358 .72771 m .83227 .7468 L .81953 .74303 L p .707 .577 .707 r
F P
0 g
s
.81953 .74303 m .82085 .72394 L .83358 .72771 L p .707 .577 .707 r
F P
0 g
s
.35488 .66877 m .35725 .63064 L .32976 .62707 L p .707 .577 .707 r
F P
0 g
s
.65902 .64627 m .65665 .6844 L .64044 .68662 L p .707 .577 .707 r
F P
0 g
s
.38443 .71543 m .38575 .69634 L .35461 .69353 L p .707 .577 .707 r
F P
0 g
s
.38575 .69634 m .38443 .71543 L .41618 .7173 L p .707 .577 .707 r
F P
0 g
s
.41618 .7173 m .41749 .69821 L .38575 .69634 L p .707 .577 .707 r
F P
0 g
s
.32976 .62707 m .32739 .6652 L .35488 .66877 L p .707 .577 .707 r
F P
0 g
s
.35461 .69353 m .35329 .71262 L .38443 .71543 L p .707 .577 .707 r
F P
0 g
s
.41749 .69821 m .41618 .7173 L .44541 .71804 L p .707 .577 .707 r
F P
0 g
s
.44541 .71804 m .44673 .69894 L .41749 .69821 L p .707 .577 .707 r
F P
0 g
s
.65912 .61862 m .66131 .56186 L .6853 .55905 L p .707 .577 .707 r
F P
0 g
s
.44942 .63526 m .44705 .67339 L .47096 .67238 L p .707 .577 .707 r
F P
0 g
s
.47096 .67238 m .47333 .63425 L .44942 .63526 L p .707 .577 .707 r
F P
0 g
s
.31055 .54583 m .30837 .60259 L .32945 .6076 L p .707 .577 .707 r
F P
0 g
s
.63873 .73241 m .64005 .71331 L .65622 .7117 L p .707 .577 .707 r
F P
0 g
s
.35329 .71262 m .35461 .69353 L .32712 .69005 L p .707 .577 .707 r
F P
0 g
s
.65622 .7117 m .6549 .73079 L .63873 .73241 L p .707 .577 .707 r
F P
0 g
s
.32712 .69005 m .3258 .70914 L .35329 .71262 L p .707 .577 .707 r
F P
0 g
s
.47541 .55386 m .47323 .61062 L .48953 .6064 L p .707 .577 .707 r
F P
0 g
s
.48953 .6064 m .49172 .54964 L .47541 .55386 L p .707 .577 .707 r
F P
0 g
s
.32739 .6652 m .32976 .62707 L .30863 .62298 L p .707 .577 .707 r
F P
0 g
s
.82371 .65754 m .82135 .69567 L .80022 .69158 L p .707 .577 .707 r
F P
0 g
s
.80022 .69158 m .80258 .65345 L .82371 .65754 L p .707 .577 .707 r
F P
0 g
s
.6853 .55905 m .68312 .61581 L .65912 .61862 L p .707 .577 .707 r
F P
0 g
s
.44673 .69894 m .44541 .71804 L .46929 .71757 L p .707 .577 .707 r
F P
0 g
s
.46929 .71757 m .4706 .69848 L .44673 .69894 L p .707 .577 .707 r
F P
0 g
s
.30863 .62298 m .30626 .66111 L .32739 .6652 L p .707 .577 .707 r
F P
0 g
s
.80508 .56488 m .8029 .62164 L .77543 .61775 L p .707 .577 .707 r
F P
0 g
s
.77543 .61775 m .77761 .56099 L .80508 .56488 L p .707 .577 .707 r
F P
0 g
s
.30837 .60259 m .31055 .54583 L .29792 .5402 L p .707 .577 .707 r
F P
0 g
s
.65665 .6844 m .65902 .64627 L .68292 .64526 L p .707 .577 .707 r
F P
0 g
s
.3258 .70914 m .32712 .69005 L .30597 .68624 L p .707 .577 .707 r
F P
0 g
s
.30597 .68624 m .30465 .70533 L .3258 .70914 L p .707 .577 .707 r
F P
0 g
s
.82085 .72394 m .81953 .74303 L .79838 .73922 L p .707 .577 .707 r
F P
0 g
s
.79838 .73922 m .7997 .72013 L .82085 .72394 L p .707 .577 .707 r
F P
0 g
s
.68312 .61581 m .6853 .55905 L .71464 .55792 L p .707 .577 .707 r
F P
0 g
s
.47333 .63425 m .47096 .67238 L .48717 .67016 L p .707 .577 .707 r
F P
0 g
s
.48717 .67016 m .48953 .63203 L .47333 .63425 L p .707 .577 .707 r
F P
0 g
s
.68292 .64526 m .68056 .68339 L .65665 .6844 L p .707 .577 .707 r
F P
0 g
s
.29792 .5402 m .29573 .59696 L .30837 .60259 L p .707 .577 .707 r
F P
0 g
s
.6549 .73079 m .65622 .7117 L .68009 .71123 L p .707 .577 .707 r
F P
0 g
s
.77761 .56099 m .77543 .61775 L .74426 .61535 L p .707 .577 .707 r
F P
0 g
s
.74426 .61535 m .74645 .55859 L .77761 .56099 L p .707 .577 .707 r
F P
0 g
s
.68009 .71123 m .67877 .73033 L .6549 .73079 L p .707 .577 .707 r
F P
0 g
s
.30626 .66111 m .30863 .62298 L .29592 .61878 L p .707 .577 .707 r
F P
0 g
s
.71464 .55792 m .71246 .61468 L .68312 .61581 L p .707 .577 .707 r
F P
0 g
s
.49172 .54964 m .48953 .6064 L .49656 .60118 L p .707 .577 .707 r
F P
0 g
s
.49656 .60118 m .49874 .54442 L .49172 .54964 L p .707 .577 .707 r
F P
0 g
s
.80258 .65345 m .80022 .69158 L .77273 .688 L p .707 .577 .707 r
F P
0 g
s
.77273 .688 m .7751 .64987 L .80258 .65345 L p .707 .577 .707 r
F P
0 g
s
.4706 .69848 m .46929 .71757 L .48545 .71596 L p .707 .577 .707 r
F P
0 g
s
.48545 .71596 m .48677 .69686 L .4706 .69848 L p .707 .577 .707 r
F P
0 g
s
.71246 .61468 m .71464 .55792 L .74645 .55859 L p .707 .577 .707 r
F P
0 g
s
.29592 .61878 m .29356 .65691 L .30626 .66111 L p .707 .577 .707 r
F P
0 g
s
.74645 .55859 m .74426 .61535 L .71246 .61468 L p .707 .577 .707 r
F P
0 g
s
.68056 .68339 m .68292 .64526 L .71219 .64557 L p .707 .577 .707 r
F P
0 g
s
.30465 .70533 m .30597 .68624 L .29324 .68247 L p .707 .577 .707 r
F P
0 g
s
.29573 .59696 m .29792 .5402 L .29497 .53449 L p .707 .577 .707 r
F P
0 g
s
.29324 .68247 m .29192 .70156 L .30465 .70533 L p .707 .577 .707 r
F P
0 g
s
.71219 .64557 m .70982 .6837 L .68056 .68339 L p .707 .577 .707 r
F P
0 g
s
.7997 .72013 m .79838 .73922 L .77089 .73574 L p .707 .577 .707 r
F P
0 g
s
.77089 .73574 m .77221 .71665 L .7997 .72013 L p .707 .577 .707 r
F P
0 g
s
.7751 .64987 m .77273 .688 L .74159 .68529 L p .707 .577 .707 r
F P
0 g
s
.74159 .68529 m .74395 .64716 L .7751 .64987 L p .707 .577 .707 r
F P
0 g
s
.48953 .63203 m .48717 .67016 L .49409 .66695 L p .707 .577 .707 r
F P
0 g
s
.49409 .66695 m .49645 .62882 L .48953 .63203 L p .707 .577 .707 r
F P
0 g
s
.67877 .73033 m .68009 .71123 L .70933 .71197 L p .707 .577 .707 r
F P
0 g
s
.70982 .6837 m .71219 .64557 L .74395 .64716 L p .707 .577 .707 r
F P
0 g
s
.70933 .71197 m .70801 .73107 L .67877 .73033 L p .707 .577 .707 r
F P
0 g
s
.29497 .53449 m .29278 .59125 L .29573 .59696 L p .707 .577 .707 r
F P
0 g
s
.74395 .64716 m .74159 .68529 L .70982 .6837 L p .707 .577 .707 r
F P
0 g
s
.77221 .71665 m .77089 .73574 L .73975 .73293 L p .707 .577 .707 r
F P
0 g
s
.73975 .73293 m .74107 .71384 L .77221 .71665 L p .707 .577 .707 r
F P
0 g
s
.29356 .65691 m .29592 .61878 L .29288 .61488 L p .707 .577 .707 r
F P
0 g
s
.48677 .69686 m .48545 .71596 L .49233 .71334 L p .707 .577 .707 r
F P
0 g
s
.49233 .71334 m .49365 .69425 L .48677 .69686 L p .707 .577 .707 r
F P
0 g
s
.49874 .54442 m .49656 .60118 L .4936 .59547 L p .707 .577 .707 r
F P
0 g
s
.4936 .59547 m .49579 .53871 L .49874 .54442 L p .707 .577 .707 r
F P
0 g
s
.70801 .73107 m .70933 .71197 L .74107 .71384 L p .707 .577 .707 r
F P
0 g
s
.29288 .61488 m .29051 .65302 L .29356 .65691 L p .707 .577 .707 r
F P
0 g
s
.74107 .71384 m .73975 .73293 L .70801 .73107 L p .707 .577 .707 r
F P
0 g
s
.29192 .70156 m .29324 .68247 L .29016 .67911 L p .707 .577 .707 r
F P
0 g
s
.29016 .67911 m .28884 .69821 L .29192 .70156 L p .707 .577 .707 r
F P
0 g
s
.29278 .59125 m .29497 .53449 L .30199 .52927 L p .707 .577 .707 r
F P
0 g
s
.49645 .62882 m .49409 .66695 L .49104 .66305 L p .707 .577 .707 r
F P
0 g
s
.49104 .66305 m .49341 .62492 L .49645 .62882 L p .707 .577 .707 r
F P
0 g
s
.30199 .52927 m .2998 .58603 L .29278 .59125 L p .707 .577 .707 r
F P
0 g
s
.49365 .69425 m .49233 .71334 L .48926 .70999 L p .707 .577 .707 r
F P
0 g
s
.48926 .70999 m .49057 .69089 L .49365 .69425 L p .707 .577 .707 r
F P
0 g
s
.29051 .65302 m .29288 .61488 L .2998 .61167 L p .707 .577 .707 r
F P
0 g
s
.49579 .53871 m .4936 .59547 L .48097 .58984 L p .707 .577 .707 r
F P
0 g
s
.48097 .58984 m .48315 .53308 L .49579 .53871 L p .707 .577 .707 r
F P
0 g
s
.2998 .61167 m .29743 .6498 L .29051 .65302 L p .707 .577 .707 r
F P
0 g
s
.28884 .69821 m .29016 .67911 L .29704 .6765 L p .707 .577 .707 r
F P
0 g
s
.29704 .6765 m .29572 .69559 L .28884 .69821 L p .707 .577 .707 r
F P
0 g
s
.2998 .58603 m .30199 .52927 L .3183 .52505 L p .707 .577 .707 r
F P
0 g
s
.49341 .62492 m .49104 .66305 L .47834 .65885 L p .707 .577 .707 r
F P
0 g
s
.47834 .65885 m .4807 .62072 L .49341 .62492 L p .707 .577 .707 r
F P
0 g
s
.3183 .52505 m .31611 .58181 L .2998 .58603 L p .707 .577 .707 r
F P
0 g
s
.29743 .6498 m .2998 .61167 L .31601 .60945 L p .707 .577 .707 r
F P
0 g
s
.48315 .53308 m .48097 .58984 L .45988 .58483 L p .707 .577 .707 r
F P
0 g
s
.45988 .58483 m .46207 .52807 L .48315 .53308 L p .707 .577 .707 r
F P
0 g
s
.49057 .69089 m .48926 .70999 L .47652 .70622 L p .707 .577 .707 r
F P
0 g
s
.47652 .70622 m .47784 .68713 L .49057 .69089 L p .707 .577 .707 r
F P
0 g
s
.31601 .60945 m .31364 .64758 L .29743 .6498 L p .707 .577 .707 r
F P
0 g
s
.31611 .58181 m .3183 .52505 L .34229 .52224 L p .707 .577 .707 r
F P
0 g
s
.29572 .69559 m .29704 .6765 L .31321 .67488 L p .707 .577 .707 r
F P
0 g
s
.31321 .67488 m .31189 .69397 L .29572 .69559 L p .707 .577 .707 r
F P
0 g
s
.4807 .62072 m .47834 .65885 L .45721 .65477 L p .707 .577 .707 r
F P
0 g
s
.45721 .65477 m .45957 .61664 L .4807 .62072 L p .707 .577 .707 r
F P
0 g
s
.34229 .52224 m .34011 .57899 L .31611 .58181 L p .707 .577 .707 r
F P
0 g
s
.46207 .52807 m .45988 .58483 L .43242 .58093 L p .707 .577 .707 r
F P
0 g
s
.43242 .58093 m .4346 .52417 L .46207 .52807 L p .707 .577 .707 r
F P
0 g
s
.31364 .64758 m .31601 .60945 L .33991 .60845 L p .707 .577 .707 r
F P
0 g
s
.47784 .68713 m .47652 .70622 L .45537 .70241 L p .707 .577 .707 r
F P
0 g
s
.45537 .70241 m .45669 .68331 L .47784 .68713 L p .707 .577 .707 r
F P
0 g
s
.34011 .57899 m .34229 .52224 L .37163 .52111 L p .707 .577 .707 r
F P
0 g
s
.33991 .60845 m .33755 .64658 L .31364 .64758 L p .707 .577 .707 r
F P
0 g
s
.31189 .69397 m .31321 .67488 L .33708 .67442 L p .707 .577 .707 r
F P
0 g
s
.4346 .52417 m .43242 .58093 L .40125 .57853 L p .707 .577 .707 r
F P
0 g
s
.40125 .57853 m .40344 .52178 L .4346 .52417 L p .707 .577 .707 r
F P
0 g
s
.33708 .67442 m .33576 .69351 L .31189 .69397 L p .707 .577 .707 r
F P
0 g
s
.37163 .52111 m .36945 .57787 L .34011 .57899 L p .707 .577 .707 r
F P
0 g
s
.45957 .61664 m .45721 .65477 L .42972 .65119 L p .707 .577 .707 r
F P
0 g
s
.42972 .65119 m .43209 .61306 L .45957 .61664 L p .707 .577 .707 r
F P
0 g
s
.36945 .57787 m .37163 .52111 L .40344 .52178 L p .707 .577 .707 r
F P
0 g
s
.40344 .52178 m .40125 .57853 L .36945 .57787 L p .707 .577 .707 r
F P
0 g
s
.33755 .64658 m .33991 .60845 L .36918 .60875 L p .707 .577 .707 r
F P
0 g
s
.36918 .60875 m .36681 .64688 L .33755 .64658 L p .707 .577 .707 r
F P
0 g
s
.45669 .68331 m .45537 .70241 L .42788 .69893 L p .707 .577 .707 r
F P
0 g
s
.42788 .69893 m .4292 .67983 L .45669 .68331 L p .707 .577 .707 r
F P
0 g
s
.43209 .61306 m .42972 .65119 L .39857 .64847 L p .707 .577 .707 r
F P
0 g
s
.39857 .64847 m .40094 .61034 L .43209 .61306 L p .707 .577 .707 r
F P
0 g
s
.33576 .69351 m .33708 .67442 L .36632 .67516 L p .707 .577 .707 r
F P
0 g
s
.36681 .64688 m .36918 .60875 L .40094 .61034 L p .707 .577 .707 r
F P
0 g
s
.36632 .67516 m .365 .69425 L .33576 .69351 L p .707 .577 .707 r
F P
0 g
s
.40094 .61034 m .39857 .64847 L .36681 .64688 L p .707 .577 .707 r
F P
0 g
s
.4292 .67983 m .42788 .69893 L .39674 .69612 L p .707 .577 .707 r
F P
0 g
s
.39674 .69612 m .39806 .67702 L .4292 .67983 L p .707 .577 .707 r
F P
0 g
s
.365 .69425 m .36632 .67516 L .39806 .67702 L p .707 .577 .707 r
F P
0 g
s
.39806 .67702 m .39674 .69612 L .365 .69425 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Ioob<008Aoo`00L7oo1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF2@00Ngoo001/Ool400000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol006Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00J7oo0`001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01000K7oo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000J7oo001WOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YF000006Ioo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001TOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001NOolJ000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Qoo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0047oo4P00A7oo001COol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo300015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP<0035oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00008002ioo`00Dgoo00<005YF00000eYF00@005YFFUIJEQT000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1`000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH00000FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00EGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo001J
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00=goo6@001Goo8@0000=JEP00
FUH01UYF00@005YFFUIJEPH000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00<Goo1P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3@0035YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1`002UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF3P001eYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP050005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1P0015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH000020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF0000000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000@000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003OolG0008FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000090007FUH00`00FUIJEP05FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF6`00<goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00;7oo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@00003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ40
00AJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ao
o`03001JEP0000=JEP`00003FUH005YF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEQ40
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00;7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEPd0009JEP03001JEUYF00=JEP03001JEUYF00=JEQH000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF008002ioo`00;7oo00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEUYF
009JEQ<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
FUIJEQh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`800003
FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP050005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00;goo0`0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=J
EP05001JEUYFFUH0000_Ool0035ooah00005FUH005YF001JEP0Q0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<007ooOol0;Goo000^Ool300000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHD0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP00Ool0;Woo000/Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1@000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<0
05YFFUH00eYF00<005YFFUH00P000goo8P00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000240
04Ioo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH04@0015YF
00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=goo000[Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEP00000`Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEQH000AJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002moo`00:goo00<005YF0000
0UYF7`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF
300015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00:goo1P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF20000eYF00<005YFFUH00eYF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2`000eYF00<005YFFUH00eYF00@005YFFUIJ
EP8002moo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;goo000/Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF0P00;goo000^Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000EJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4000_Ool003=oo`L000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH00UYF4@0015YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;goo000`OolG0008FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP03FUH00`00FUIJEP02000;OolJ000`Ool0
02]oo`D0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ/00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00FUIJ
EP02001EOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP04FUH00`00FUIJEP02001EOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60005Ool01000FUIJEP00
1EYF00<005YFFUH00eYF30002UYF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH01P000UYF00<005YFFUH00UYF1`002eYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Eoo`00:goo00<005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEP00008000IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol002]oo`03001JEP0000L0
0003FUH005YF00AJEQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP@0009JEP03001JEUYF009JEP03001JEP0000=JEPH000AJEP05001JEUYFFUH0001FOol002]oo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP03
001JEP00008000]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP03001JEP0000AJEP03001JEUYF009JEP<00003FUH005YF009JEP03
001oogoo05Aoo`00:goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1P00
0eYF00<005YFFUH015YF1`000eYF00<005YF00003EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP0000AJ
EP03001JEUYF00AJEP@0009JEP03001oogoo05Aoo`00;Goo1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1P003EYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000=JEP00FUH00eYF00<005YFFUH015YF00@005YFFUIJEP<005Ioo`00<Woo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EWoo
000iOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
0009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YFFUIJEPT005Moo`00@Woo8P000goo0`00
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH02@00H7oo001ZOol40002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH7
001NOol006ioo`D000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00D005Uoo`00Lgoo1P000eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Moo`00NGoo2@001UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00UYF1`001eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH00P00EWoo0022Oolf0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EWoo002=Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH60003
FUH01000FUIJEUYF0P00EWoo002?Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH2001FOol009Aoo`L000=JEP03001JEUYF00IJEP03
001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003FUH0000005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0`00EWoo002SOol90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05001FOol00:ao
oaH005]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59874 .75859 m .59656 .70477 L .56539 .70335 L p .707 .577 .707 r
F P
0 g
s
.59656 .70477 m .59874 .75859 L .63055 .75641 L p .707 .577 .707 r
F P
0 g
s
.63055 .75641 m .62836 .70258 L .59656 .70477 L p .707 .577 .707 r
F P
0 g
s
.62836 .70258 m .63055 .75641 L .65989 .75084 L p .707 .577 .707 r
F P
0 g
s
.65989 .75084 m .6577 .69701 L .62836 .70258 L p .707 .577 .707 r
F P
0 g
s
.56758 .75718 m .56539 .70335 L .53793 .69847 L p .707 .577 .707 r
F P
0 g
s
.56539 .70335 m .56758 .75718 L .59874 .75859 L p .707 .577 .707 r
F P
0 g
s
.6577 .69701 m .65989 .75084 L .68389 .74242 L p .707 .577 .707 r
F P
0 g
s
.68389 .74242 m .6817 .6886 L .6577 .69701 L p .707 .577 .707 r
F P
0 g
s
.54011 .7523 m .53793 .69847 L .51684 .69061 L p .707 .577 .707 r
F P
0 g
s
.53793 .69847 m .54011 .7523 L .56758 .75718 L p .707 .577 .707 r
F P
0 g
s
.60142 .82493 m .59906 .78998 L .56791 .78886 L p .707 .577 .707 r
F P
0 g
s
.59906 .78998 m .60142 .82493 L .63318 .82189 L p .707 .577 .707 r
F P
0 g
s
.63318 .82189 m .63082 .78694 L .59906 .78998 L p .707 .577 .707 r
F P
0 g
s
.63082 .78694 m .63318 .82189 L .66245 .81498 L p .707 .577 .707 r
F P
0 g
s
.66245 .81498 m .66008 .78003 L .63082 .78694 L p .707 .577 .707 r
F P
0 g
s
.6817 .6886 m .68389 .74242 L .70019 .73199 L p .707 .577 .707 r
F P
0 g
s
.70019 .73199 m .69801 .67817 L .6817 .6886 L p .707 .577 .707 r
F P
0 g
s
.57028 .82381 m .56791 .78886 L .54042 .78369 L p .707 .577 .707 r
F P
0 g
s
.56791 .78886 m .57028 .82381 L .60142 .82493 L p .707 .577 .707 r
F P
0 g
s
.66008 .78003 m .66245 .81498 L .68636 .80488 L p .707 .577 .707 r
F P
0 g
s
.68636 .80488 m .68399 .76993 L .66008 .78003 L p .707 .577 .707 r
F P
0 g
s
.51684 .69061 m .51903 .74444 L .54011 .7523 L p .707 .577 .707 r
F P
0 g
s
.51903 .74444 m .51684 .69061 L .50421 .68053 L p .707 .577 .707 r
F P
0 g
s
.54279 .81864 m .54042 .78369 L .51929 .77497 L p .707 .577 .707 r
F P
0 g
s
.54042 .78369 m .54279 .81864 L .57028 .82381 L p .707 .577 .707 r
F P
0 g
s
.60326 .87011 m .60194 .85279 L .5708 .85176 L p .707 .577 .707 r
F P
0 g
s
.60194 .85279 m .60326 .87011 L .635 .86682 L p .707 .577 .707 r
F P
0 g
s
.635 .86682 m .63368 .84949 L .60194 .85279 L p .707 .577 .707 r
F P
0 g
s
.63368 .84949 m .635 .86682 L .66424 .85952 L p .707 .577 .707 r
F P
0 g
s
.66424 .85952 m .66292 .84219 L .63368 .84949 L p .707 .577 .707 r
F P
0 g
s
.69801 .67817 m .70019 .73199 L .70722 .72057 L p .707 .577 .707 r
F P
0 g
s
.70722 .72057 m .70503 .66674 L .69801 .67817 L p .707 .577 .707 r
F P
0 g
s
.68399 .76993 m .68636 .80488 L .70256 .79258 L p .707 .577 .707 r
F P
0 g
s
.70256 .79258 m .7002 .75763 L .68399 .76993 L p .707 .577 .707 r
F P
0 g
s
.57212 .86908 m .5708 .85176 L .54331 .8465 L p .707 .577 .707 r
F P
0 g
s
.5708 .85176 m .57212 .86908 L .60326 .87011 L p .707 .577 .707 r
F P
0 g
s
.50421 .68053 m .50639 .73436 L .51903 .74444 L p .707 .577 .707 r
F P
0 g
s
.66292 .84219 m .66424 .85952 L .68811 .84892 L p .707 .577 .707 r
F P
0 g
s
.68811 .84892 m .68679 .8316 L .66292 .84219 L p .707 .577 .707 r
F P
0 g
s
.51929 .77497 m .52166 .80992 L .54279 .81864 L p .707 .577 .707 r
F P
0 g
s
.54331 .8465 m .54463 .86382 L .57212 .86908 L p .707 .577 .707 r
F P
0 g
s
.50639 .73436 m .50421 .68053 L .50125 .66923 L p .707 .577 .707 r
F P
0 g
s
.52166 .80992 m .51929 .77497 L .50659 .76355 L p .707 .577 .707 r
F P
0 g
s
.54463 .86382 m .54331 .8465 L .52216 .83752 L p .707 .577 .707 r
F P
0 g
s
.50117 .82687 m .48132 .34094 L .43733 .33895 L p .707 .577 .707 r
F P
0 g
s
.50659 .76355 m .50895 .79851 L .52166 .80992 L p .707 .577 .707 r
F P
0 g
s
.50125 .66923 m .50344 .72306 L .50639 .73436 L p .707 .577 .707 r
F P
0 g
s
.52348 .85485 m .52216 .83752 L .50942 .82572 L p .707 .577 .707 r
F P
0 g
s
.50895 .79851 m .50659 .76355 L .50354 .75056 L p .707 .577 .707 r
F P
0 g
s
.50344 .72306 m .50125 .66923 L .50828 .6578 L p .707 .577 .707 r
F P
0 g
s
.50942 .82572 m .51074 .84304 L .52348 .85485 L p .707 .577 .707 r
F P
0 g
s
.50354 .75056 m .50591 .78551 L .50895 .79851 L p .707 .577 .707 r
F P
0 g
s
.50828 .6578 m .51046 .71163 L .50344 .72306 L p .707 .577 .707 r
F P
0 g
s
.51074 .84304 m .50942 .82572 L .50634 .81223 L p .707 .577 .707 r
F P
0 g
s
.50591 .78551 m .50354 .75056 L .51046 .73726 L p .707 .577 .707 r
F P
0 g
s
.51046 .71163 m .50828 .6578 L .52458 .64737 L p .707 .577 .707 r
F P
0 g
s
.50634 .81223 m .50766 .82956 L .51074 .84304 L p .707 .577 .707 r
F P
0 g
s
.51046 .73726 m .51283 .77222 L .50591 .78551 L p .707 .577 .707 r
F P
0 g
s
.52458 .64737 m .52677 .7012 L .51046 .71163 L p .707 .577 .707 r
F P
0 g
s
.50766 .82956 m .50634 .81223 L .51323 .79839 L p .707 .577 .707 r
F P
0 g
s
.52677 .7012 m .52458 .64737 L .54858 .63896 L p .707 .577 .707 r
F P
0 g
s
.51283 .77222 m .51046 .73726 L .52667 .72497 L p .707 .577 .707 r
F P
0 g
s
.51323 .79839 m .51454 .81571 L .50766 .82956 L p .707 .577 .707 r
F P
0 g
s
.52667 .72497 m .52904 .75992 L .51283 .77222 L p .707 .577 .707 r
F P
0 g
s
.54858 .63896 m .55077 .69279 L .52677 .7012 L p .707 .577 .707 r
F P
0 g
s
.51454 .81571 m .51323 .79839 L .52939 .78554 L p .707 .577 .707 r
F P
0 g
s
.52904 .75992 m .52667 .72497 L .55058 .71487 L p .707 .577 .707 r
F P
0 g
s
.52939 .78554 m .53071 .80287 L .51454 .81571 L p .707 .577 .707 r
F P
0 g
s
.55058 .71487 m .55295 .74982 L .52904 .75992 L p .707 .577 .707 r
F P
0 g
s
.53071 .80287 m .52939 .78554 L .55326 .77495 L p .707 .577 .707 r
F P
0 g
s
.55326 .77495 m .55458 .79227 L .53071 .80287 L p .707 .577 .707 r
F P
0 g
s
.48132 .34094 m .50117 .82687 L .54608 .82377 L p .707 .577 .707 r
F P
0 g
s
.54608 .82377 m .52623 .33785 L .48132 .34094 L p .707 .577 .707 r
F P
0 g
s
.55077 .69279 m .54858 .63896 L .57792 .63339 L p .707 .577 .707 r
F P
0 g
s
.57792 .63339 m .58011 .68722 L .55077 .69279 L p .707 .577 .707 r
F P
0 g
s
.55295 .74982 m .55058 .71487 L .57984 .70796 L p .707 .577 .707 r
F P
0 g
s
.57984 .70796 m .58221 .74291 L .55295 .74982 L p .707 .577 .707 r
F P
0 g
s
.55458 .79227 m .55326 .77495 L .5825 .76765 L p .707 .577 .707 r
F P
0 g
s
.5825 .76765 m .58382 .78497 L .55458 .79227 L p .707 .577 .707 r
F P
0 g
s
.52623 .33785 m .54608 .82377 L .5875 .81589 L p .707 .577 .707 r
F P
0 g
s
.58011 .68722 m .57792 .63339 L .60973 .63121 L p .707 .577 .707 r
F P
0 g
s
.60973 .63121 m .61191 .68503 L .58011 .68722 L p .707 .577 .707 r
F P
0 g
s
.58221 .74291 m .57984 .70796 L .61161 .70491 L p .707 .577 .707 r
F P
0 g
s
.61161 .70491 m .61397 .73987 L .58221 .74291 L p .707 .577 .707 r
F P
0 g
s
.58382 .78497 m .5825 .76765 L .61425 .76435 L p .707 .577 .707 r
F P
0 g
s
.61425 .76435 m .61556 .78167 L .58382 .78497 L p .707 .577 .707 r
F P
0 g
s
.5875 .81589 m .56765 .32997 L .52623 .33785 L p .707 .577 .707 r
F P
0 g
s
.52216 .83752 m .52348 .85485 L .54463 .86382 L p .707 .577 .707 r
F P
0 g
s
.68679 .8316 m .68811 .84892 L .70428 .83608 L p .707 .577 .707 r
F P
0 g
s
.70428 .83608 m .70296 .81875 L .68679 .8316 L p .707 .577 .707 r
F P
0 g
s
.7002 .75763 m .70256 .79258 L .70948 .77929 L p .707 .577 .707 r
F P
0 g
s
.70948 .77929 m .70712 .74433 L .7002 .75763 L p .707 .577 .707 r
F P
0 g
s
.70503 .66674 m .70722 .72057 L .70426 .70926 L p .707 .577 .707 r
F P
0 g
s
.70426 .70926 m .70208 .65544 L .70503 .66674 L p .707 .577 .707 r
F P
0 g
s
.45718 .82487 m .43733 .33895 L .39855 .33206 L p .707 .577 .707 r
F P
0 g
s
.43733 .33895 m .45718 .82487 L .50117 .82687 L p .707 .577 .707 r
F P
0 g
s
.64275 .70603 m .64512 .74099 L .61397 .73987 L p .707 .577 .707 r
F P
0 g
s
.61397 .73987 m .61161 .70491 L .64275 .70603 L p .707 .577 .707 r
F P
0 g
s
.64539 .76538 m .6467 .78271 L .61556 .78167 L p .707 .577 .707 r
F P
0 g
s
.61556 .78167 m .61425 .76435 L .64539 .76538 L p .707 .577 .707 r
F P
0 g
s
.56765 .32997 m .5875 .81589 L .62138 .80399 L p .707 .577 .707 r
F P
0 g
s
.64089 .63262 m .64308 .68645 L .61191 .68503 L p .707 .577 .707 r
F P
0 g
s
.61191 .68503 m .60973 .63121 L .64089 .63262 L p .707 .577 .707 r
F P
0 g
s
.62138 .80399 m .60152 .31807 L .56765 .32997 L p .707 .577 .707 r
F P
0 g
s
.70296 .81875 m .70428 .83608 L .71116 .82223 L p .707 .577 .707 r
F P
0 g
s
.71116 .82223 m .70984 .80491 L .70296 .81875 L p .707 .577 .707 r
F P
0 g
s
.4184 .81798 m .39855 .33206 L .36879 .32095 L p .707 .577 .707 r
F P
0 g
s
.39855 .33206 m .4184 .81798 L .45718 .82487 L p .707 .577 .707 r
F P
0 g
s
.70712 .74433 m .70948 .77929 L .70644 .7663 L p .707 .577 .707 r
F P
0 g
s
.70644 .7663 m .70407 .73134 L .70712 .74433 L p .707 .577 .707 r
F P
0 g
s
.70208 .65544 m .70426 .70926 L .69163 .69919 L p .707 .577 .707 r
F P
0 g
s
.69163 .69919 m .68944 .64536 L .70208 .65544 L p .707 .577 .707 r
F P
0 g
s
.60152 .31807 m .62138 .80399 L .6444 .78925 L p .707 .577 .707 r
F P
0 g
s
.6444 .78925 m .62455 .30332 L .60152 .31807 L p .707 .577 .707 r
F P
0 g
s
.25573 .72178 m .25355 .66795 L .22239 .66653 L p .707 .577 .707 r
F P
0 g
s
.25355 .66795 m .25573 .72178 L .28754 .71959 L p .707 .577 .707 r
F P
0 g
s
.28754 .71959 m .28536 .66577 L .25355 .66795 L p .707 .577 .707 r
F P
0 g
s
.28536 .66577 m .28754 .71959 L .31688 .71402 L p .707 .577 .707 r
F P
0 g
s
.31688 .71402 m .31469 .66019 L .28536 .66577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70984 .80491 m .71116 .82223 L .70808 .80875 L p .707 .577 .707 r
F P
0 g
s
.70808 .80875 m .70676 .79142 L .70984 .80491 L p .707 .577 .707 r
F P
0 g
s
.22457 .72036 m .22239 .66653 L .19492 .66166 L p .707 .577 .707 r
F P
0 g
s
.22239 .66653 m .22457 .72036 L .25573 .72178 L p .707 .577 .707 r
F P
0 g
s
.38864 .80687 m .36879 .32095 L .35095 .30671 L p .707 .577 .707 r
F P
0 g
s
.36879 .32095 m .38864 .80687 L .4184 .81798 L p .707 .577 .707 r
F P
0 g
s
.70407 .73134 m .70644 .7663 L .69373 .75488 L p .707 .577 .707 r
F P
0 g
s
.69373 .75488 m .69137 .71993 L .70407 .73134 L p .707 .577 .707 r
F P
0 g
s
.68944 .64536 m .69163 .69919 L .67054 .69132 L p .707 .577 .707 r
F P
0 g
s
.67054 .69132 m .66836 .6375 L .68944 .64536 L p .707 .577 .707 r
F P
0 g
s
.31469 .66019 m .31688 .71402 L .34088 .70561 L p .707 .577 .707 r
F P
0 g
s
.34088 .70561 m .33869 .65178 L .31469 .66019 L p .707 .577 .707 r
F P
0 g
s
.1971 .71548 m .19492 .66166 L .17383 .6538 L p .707 .577 .707 r
F P
0 g
s
.19492 .66166 m .1971 .71548 L .22457 .72036 L p .707 .577 .707 r
F P
0 g
s
.66836 .6375 m .67054 .69132 L .64308 .68645 L p .707 .577 .707 r
F P
0 g
s
.64308 .68645 m .64089 .63262 L .66836 .6375 L p .707 .577 .707 r
F P
0 g
s
.67024 .71121 m .6726 .74616 L .64512 .74099 L p .707 .577 .707 r
F P
0 g
s
.64512 .74099 m .64275 .70603 L .67024 .71121 L p .707 .577 .707 r
F P
0 g
s
.67288 .77064 m .67419 .78797 L .6467 .78271 L p .707 .577 .707 r
F P
0 g
s
.6467 .78271 m .64539 .76538 L .67288 .77064 L p .707 .577 .707 r
F P
0 g
s
.62455 .30332 m .6444 .78925 L .65431 .77309 L p .707 .577 .707 r
F P
0 g
s
.65431 .77309 m .63446 .28717 L .62455 .30332 L p .707 .577 .707 r
F P
0 g
s
.25841 .78812 m .25605 .75316 L .2249 .75204 L p .707 .577 .707 r
F P
0 g
s
.25605 .75316 m .25841 .78812 L .29017 .78507 L p .707 .577 .707 r
F P
0 g
s
.29017 .78507 m .28781 .75012 L .25605 .75316 L p .707 .577 .707 r
F P
0 g
s
.28781 .75012 m .29017 .78507 L .31944 .77817 L p .707 .577 .707 r
F P
0 g
s
.31944 .77817 m .31707 .74321 L .28781 .75012 L p .707 .577 .707 r
F P
0 g
s
.33869 .65178 m .34088 .70561 L .35719 .69518 L p .707 .577 .707 r
F P
0 g
s
.35719 .69518 m .355 .64135 L .33869 .65178 L p .707 .577 .707 r
F P
0 g
s
.70676 .79142 m .70808 .80875 L .69534 .79694 L p .707 .577 .707 r
F P
0 g
s
.69534 .79694 m .69402 .77962 L .70676 .79142 L p .707 .577 .707 r
F P
0 g
s
.22727 .787 m .2249 .75204 L .19742 .74687 L p .707 .577 .707 r
F P
0 g
s
.2249 .75204 m .22727 .787 L .25841 .78812 L p .707 .577 .707 r
F P
0 g
s
.69137 .71993 m .69373 .75488 L .6726 .74616 L p .707 .577 .707 r
F P
0 g
s
.6726 .74616 m .67024 .71121 L .69137 .71993 L p .707 .577 .707 r
F P
0 g
s
.31707 .74321 m .31944 .77817 L .34335 .76807 L p .707 .577 .707 r
F P
0 g
s
.34335 .76807 m .34098 .73311 L .31707 .74321 L p .707 .577 .707 r
F P
0 g
s
.17383 .6538 m .17602 .70762 L .1971 .71548 L p .707 .577 .707 r
F P
0 g
s
.17602 .70762 m .17383 .6538 L .1612 .64372 L p .707 .577 .707 r
F P
0 g
s
.3708 .79263 m .35095 .30671 L .34678 .29073 L p .707 .577 .707 r
F P
0 g
s
.35095 .30671 m .3708 .79263 L .38864 .80687 L p .707 .577 .707 r
F P
0 g
s
.19978 .78183 m .19742 .74687 L .17629 .73815 L p .707 .577 .707 r
F P
0 g
s
.19742 .74687 m .19978 .78183 L .22727 .787 L p .707 .577 .707 r
F P
0 g
s
.26025 .8333 m .25893 .81598 L .22779 .81494 L p .707 .577 .707 r
F P
0 g
s
.25893 .81598 m .26025 .8333 L .29199 .83 L p .707 .577 .707 r
F P
0 g
s
.29199 .83 m .29067 .81268 L .25893 .81598 L p .707 .577 .707 r
F P
0 g
s
.29067 .81268 m .29199 .83 L .32123 .8227 L p .707 .577 .707 r
F P
0 g
s
.32123 .8227 m .31991 .80538 L .29067 .81268 L p .707 .577 .707 r
F P
0 g
s
.355 .64135 m .35719 .69518 L .36421 .68375 L p .707 .577 .707 r
F P
0 g
s
.36421 .68375 m .36202 .62993 L .355 .64135 L p .707 .577 .707 r
F P
0 g
s
.34098 .73311 m .34335 .76807 L .35955 .75577 L p .707 .577 .707 r
F P
0 g
s
.35955 .75577 m .35719 .72081 L .34098 .73311 L p .707 .577 .707 r
F P
0 g
s
.69402 .77962 m .69534 .79694 L .67419 .78797 L p .707 .577 .707 r
F P
0 g
s
.67419 .78797 m .67288 .77064 L .69402 .77962 L p .707 .577 .707 r
F P
0 g
s
.22911 .83227 m .22779 .81494 L .2003 .80968 L p .707 .577 .707 r
F P
0 g
s
.22779 .81494 m .22911 .83227 L .26025 .8333 L p .707 .577 .707 r
F P
0 g
s
.1612 .64372 m .16338 .69755 L .17602 .70762 L p .707 .577 .707 r
F P
0 g
s
.31991 .80538 m .32123 .8227 L .3451 .81211 L p .707 .577 .707 r
F P
0 g
s
.3451 .81211 m .34378 .79478 L .31991 .80538 L p .707 .577 .707 r
F P
0 g
s
.17629 .73815 m .17865 .77311 L .19978 .78183 L p .707 .577 .707 r
F P
0 g
s
.2003 .80968 m .20162 .82701 L .22911 .83227 L p .707 .577 .707 r
F P
0 g
s
.63446 .28717 m .65431 .77309 L .65014 .75711 L p .707 .577 .707 r
F P
0 g
s
.65014 .75711 m .63854 .47306 L p .63446 .28717 L .707 .577 .707 r
F P
0 g
s
.63029 .27118 m .65014 .75711 L .6323 .74287 L p .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .6565 .67618 L .64389 .66486 L p .707 .577 .707 r
F P
0 g
s
.64389 .66486 m .64379 .66477 L p .6439 .6651 L .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .64389 .66486 L .6439 .6651 L .707 .577 .707 r
F
.63854 .47306 m .63029 .27118 L .63321 .2824 L p F P
0 g
s
.63321 .2824 m .63446 .28717 L p .63854 .47306 L .707 .577 .707 r
F P
0 g
s
.16338 .69755 m .1612 .64372 L .15825 .63241 L p .707 .577 .707 r
F P
0 g
s
.17865 .77311 m .17629 .73815 L .16358 .72674 L p .707 .577 .707 r
F P
0 g
s
.20162 .82701 m .2003 .80968 L .17915 .80071 L p .707 .577 .707 r
F P
0 g
s
.17915 .80071 m .18047 .81803 L .20162 .82701 L p .707 .577 .707 r
F P
0 g
s
.34378 .79478 m .3451 .81211 L .36127 .79926 L p .707 .577 .707 r
F P
0 g
s
.36127 .79926 m .35995 .78194 L .34378 .79478 L p .707 .577 .707 r
F P
0 g
s
.35719 .72081 m .35955 .75577 L .36648 .74247 L p .707 .577 .707 r
F P
0 g
s
.36648 .74247 m .36411 .70752 L .35719 .72081 L p .707 .577 .707 r
F P
0 g
s
.36202 .62993 m .36421 .68375 L .36126 .67245 L p .707 .577 .707 r
F P
0 g
s
.36126 .67245 m .35907 .61862 L .36202 .62993 L p .707 .577 .707 r
F P
0 g
s
.16358 .72674 m .16594 .76169 L .17865 .77311 L p .707 .577 .707 r
F P
0 g
s
.36815 .78542 m .36683 .76809 L .35995 .78194 L p .707 .577 .707 r
F P
0 g
s
.36411 .70752 m .36648 .74247 L .36343 .72948 L p .707 .577 .707 r
F P
0 g
s
.36343 .72948 m .36107 .69453 L .36411 .70752 L p .707 .577 .707 r
F P
0 g
s
.36683 .76809 m .36815 .78542 L .36507 .77193 L p .707 .577 .707 r
F P
0 g
s
.36507 .77193 m .36375 .75461 L .36683 .76809 L p .707 .577 .707 r
F P
0 g
s
.34678 .29073 m .36663 .77665 L .3708 .79263 L p .707 .577 .707 r
F P
0 g
s
.36663 .77665 m .34678 .29073 L .35669 .27457 L p .707 .577 .707 r
F P
0 g
s
.15825 .63241 m .16043 .68624 L .16338 .69755 L p .707 .577 .707 r
F P
0 g
s
.18047 .81803 m .17915 .80071 L .16641 .7889 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16594 .76169 m .16358 .72674 L .16053 .71375 L p .707 .577 .707 r
F P
0 g
s
.16043 .68624 m .15825 .63241 L .16527 .62099 L p .707 .577 .707 r
F P
0 g
s
.16641 .7889 m .16773 .80623 L .18047 .81803 L p .707 .577 .707 r
F P
0 g
s
.35995 .78194 m .36127 .79926 L .36815 .78542 L p .707 .577 .707 r
F P
0 g
s
.6323 .74287 m .61245 .25694 L .63029 .27118 L p .707 .577 .707 r
F P
0 g
s
.35907 .61862 m .36126 .67245 L .34862 .66237 L p .707 .577 .707 r
F P
0 g
s
.34862 .66237 m .34643 .60854 L .35907 .61862 L p .707 .577 .707 r
F P
0 g
s
.16053 .71375 m .1629 .7487 L .16594 .76169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16527 .62099 m .16745 .67481 L .16043 .68624 L p .707 .577 .707 r
F P
0 g
s
.16773 .80623 m .16641 .7889 L .16334 .77542 L p .707 .577 .707 r
F P
0 g
s
.1629 .7487 m .16053 .71375 L .16745 .70045 L p .707 .577 .707 r
F P
0 g
s
.16745 .67481 m .16527 .62099 L .18158 .61056 L p .707 .577 .707 r
F P
0 g
s
.37654 .7605 m .35669 .27457 L .37971 .25982 L p .707 .577 .707 r
F P
0 g
s
.35669 .27457 m .37654 .7605 L .36663 .77665 L p .707 .577 .707 r
F P
0 g
s
.16334 .77542 m .16465 .79274 L .16773 .80623 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36107 .69453 m .36343 .72948 L .35072 .71807 L p .707 .577 .707 r
F P
0 g
s
.35072 .71807 m .34836 .68311 L .36107 .69453 L p .707 .577 .707 r
F P
0 g
s
.34643 .60854 m .34862 .66237 L .32754 .65451 L p .707 .577 .707 r
F P
0 g
s
.32754 .65451 m .32535 .60068 L .34643 .60854 L p .707 .577 .707 r
F P
0 g
s
.16745 .70045 m .16982 .7354 L .1629 .7487 L p .707 .577 .707 r
F P
0 g
s
.61245 .25694 m .6323 .74287 L .60254 .73176 L p .707 .577 .707 r
F P
0 g
s
.60254 .73176 m .58268 .24583 L .61245 .25694 L p .707 .577 .707 r
F P
0 g
s
.18158 .61056 m .18376 .66438 L .16745 .67481 L p .707 .577 .707 r
F P
0 g
s
.16465 .79274 m .16334 .77542 L .17022 .76157 L p .707 .577 .707 r
F P
0 g
s
.18376 .66438 m .18158 .61056 L .20557 .60215 L p .707 .577 .707 r
F P
0 g
s
.16982 .7354 m .16745 .70045 L .18366 .68815 L p .707 .577 .707 r
F P
0 g
s
.17022 .76157 m .17154 .7789 L .16465 .79274 L p .707 .577 .707 r
F P
0 g
s
.36375 .75461 m .36507 .77193 L .35233 .76013 L p .707 .577 .707 r
F P
0 g
s
.35233 .76013 m .35102 .7428 L .36375 .75461 L p .707 .577 .707 r
F P
0 g
s
.32535 .60068 m .32754 .65451 L .30007 .64963 L p .707 .577 .707 r
F P
0 g
s
.30007 .64963 m .29788 .59581 L .32535 .60068 L p .707 .577 .707 r
F P
0 g
s
.37971 .25982 m .39956 .74575 L .37654 .7605 L p .707 .577 .707 r
F P
0 g
s
.39956 .74575 m .37971 .25982 L .41359 .24793 L p .707 .577 .707 r
F P
0 g
s
.34836 .68311 m .35072 .71807 L .32959 .70935 L p .707 .577 .707 r
F P
0 g
s
.32959 .70935 m .32723 .67439 L .34836 .68311 L p .707 .577 .707 r
F P
0 g
s
.18366 .68815 m .18603 .7231 L .16982 .7354 L p .707 .577 .707 r
F P
0 g
s
.20776 .65597 m .20557 .60215 L .23491 .59658 L p .707 .577 .707 r
F P
0 g
s
.20557 .60215 m .20776 .65597 L .18376 .66438 L p .707 .577 .707 r
F P
0 g
s
.29788 .59581 m .30007 .64963 L .2689 .64822 L p .707 .577 .707 r
F P
0 g
s
.2689 .64822 m .26672 .59439 L .29788 .59581 L p .707 .577 .707 r
F P
0 g
s
.17154 .7789 m .17022 .76157 L .18638 .74873 L p .707 .577 .707 r
F P
0 g
s
.58268 .24583 m .60254 .73176 L .56376 .72487 L p .707 .577 .707 r
F P
0 g
s
.56376 .72487 m .54391 .23894 L .58268 .24583 L p .707 .577 .707 r
F P
0 g
s
.18603 .7231 m .18366 .68815 L .20757 .67805 L p .707 .577 .707 r
F P
0 g
s
.2371 .6504 m .23491 .59658 L .26672 .59439 L p .707 .577 .707 r
F P
0 g
s
.23491 .59658 m .2371 .6504 L .20776 .65597 L p .707 .577 .707 r
F P
0 g
s
.26672 .59439 m .2689 .64822 L .2371 .6504 L p .707 .577 .707 r
F P
0 g
s
.18638 .74873 m .1877 .76605 L .17154 .7789 L p .707 .577 .707 r
F P
0 g
s
.32723 .67439 m .32959 .70935 L .30211 .70417 L p .707 .577 .707 r
F P
0 g
s
.30211 .70417 m .29974 .66922 L .32723 .67439 L p .707 .577 .707 r
F P
0 g
s
.35102 .7428 m .35233 .76013 L .33119 .75115 L p .707 .577 .707 r
F P
0 g
s
.33119 .75115 m .32987 .73383 L .35102 .7428 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .41359 .24793 L .45501 .24004 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .39956 .74575 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.42184 .4498 m .43344 .73385 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.45501 .24004 m .47486 .72597 L .43344 .73385 L p .707 .577 .707 r
F P
0 g
s
.45664 .67938 m .45445 .64693 L p .42501 .65134 L .707 .577 .707 r
F P
0 g
s
.45445 .64693 m .45428 .64443 L .45404 .64448 L p .707 .577 .707 r
F P
0 g
s
.45404 .64448 m .42501 .65134 L p .45445 .64693 L .707 .577 .707 r
F P
0 g
s
.41359 .24793 m .42184 .4498 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.73595 .66366 m .73376 .60984 L .7026 .60842 L p .707 .577 .707 r
F P
0 g
s
.73376 .60984 m .73595 .66366 L .76775 .66148 L p .707 .577 .707 r
F P
0 g
s
.76775 .66148 m .76557 .60765 L .73376 .60984 L p .707 .577 .707 r
F P
0 g
s
.76557 .60765 m .76775 .66148 L .79709 .65591 L p .707 .577 .707 r
F P
0 g
s
.79709 .65591 m .79491 .60208 L .76557 .60765 L p .707 .577 .707 r
F P
0 g
s
.20757 .67805 m .20994 .71301 L .18603 .7231 L p .707 .577 .707 r
F P
0 g
s
.20994 .71301 m .20757 .67805 L .23683 .67114 L p .707 .577 .707 r
F P
0 g
s
.70478 .66225 m .7026 .60842 L .67513 .60355 L p .707 .577 .707 r
F P
0 g
s
.7026 .60842 m .70478 .66225 L .73595 .66366 L p .707 .577 .707 r
F P
0 g
s
.54391 .23894 m .56376 .72487 L .51976 .72287 L p .707 .577 .707 r
F P
0 g
s
.51976 .72287 m .49991 .23695 L .54391 .23894 L p .707 .577 .707 r
F P
0 g
s
.1877 .76605 m .18638 .74873 L .21026 .73813 L p .707 .577 .707 r
F P
0 g
s
.29974 .66922 m .30211 .70417 L .27096 .70305 L p .707 .577 .707 r
F P
0 g
s
.27096 .70305 m .2686 .6681 L .29974 .66922 L p .707 .577 .707 r
F P
0 g
s
.79491 .60208 m .79709 .65591 L .82109 .6475 L p .707 .577 .707 r
F P
0 g
s
.82109 .6475 m .8189 .59367 L .79491 .60208 L p .707 .577 .707 r
F P
0 g
s
.47486 .72597 m .45501 .24004 L .49991 .23695 L p .707 .577 .707 r
F P
0 g
s
.2392 .7061 m .23683 .67114 L .2686 .6681 L p .707 .577 .707 r
F P
0 g
s
.23683 .67114 m .2392 .7061 L .20994 .71301 L p .707 .577 .707 r
F P
0 g
s
.2686 .6681 m .27096 .70305 L .2392 .7061 L p .707 .577 .707 r
F P
0 g
s
.49991 .23695 m .51976 .72287 L .47486 .72597 L p .707 .577 .707 r
F P
0 g
s
.21026 .73813 m .21157 .75546 L .1877 .76605 L p .707 .577 .707 r
F P
0 g
s
.32987 .73383 m .33119 .75115 L .3037 .74589 L p .707 .577 .707 r
F P
0 g
s
.3037 .74589 m .30238 .72857 L .32987 .73383 L p .707 .577 .707 r
F P
0 g
s
.67732 .65737 m .67513 .60355 L .65405 .59568 L p .707 .577 .707 r
F P
0 g
s
.67513 .60355 m .67732 .65737 L .70478 .66225 L p .707 .577 .707 r
F P
0 g
s
.21157 .75546 m .21026 .73813 L .23949 .73083 L p .707 .577 .707 r
F P
0 g
s
.73863 .72615 m .73626 .6912 L .70511 .69008 L p .707 .577 .707 r
F P
0 g
s
.73626 .6912 m .73863 .72615 L .77039 .72311 L p .707 .577 .707 r
F P
0 g
s
.77039 .72311 m .76802 .68815 L .73626 .6912 L p .707 .577 .707 r
F P
0 g
s
.76802 .68815 m .77039 .72311 L .79965 .7162 L p .707 .577 .707 r
F P
0 g
s
.79965 .7162 m .79729 .68124 L .76802 .68815 L p .707 .577 .707 r
F P
0 g
s
.8189 .59367 m .82109 .6475 L .8374 .63707 L p .707 .577 .707 r
F P
0 g
s
.8374 .63707 m .83521 .58324 L .8189 .59367 L p .707 .577 .707 r
F P
0 g
s
.30238 .72857 m .3037 .74589 L .27255 .74486 L p .707 .577 .707 r
F P
0 g
s
.27255 .74486 m .27124 .72754 L .30238 .72857 L p .707 .577 .707 r
F P
0 g
s
.70748 .72503 m .70511 .69008 L .67763 .6849 L p .707 .577 .707 r
F P
0 g
s
.70511 .69008 m .70748 .72503 L .73863 .72615 L p .707 .577 .707 r
F P
0 g
s
.23949 .73083 m .24081 .74816 L .21157 .75546 L p .707 .577 .707 r
F P
0 g
s
.24081 .74816 m .23949 .73083 L .27124 .72754 L p .707 .577 .707 r
F P
0 g
s
.27124 .72754 m .27255 .74486 L .24081 .74816 L p .707 .577 .707 r
F P
0 g
s
.79729 .68124 m .79965 .7162 L .82356 .7061 L p .707 .577 .707 r
F P
0 g
s
.82356 .7061 m .82119 .67115 L .79729 .68124 L p .707 .577 .707 r
F P
0 g
s
.65405 .59568 m .65623 .64951 L .67732 .65737 L p .707 .577 .707 r
F P
0 g
s
.65623 .64951 m .65405 .59568 L .64141 .58561 L p .707 .577 .707 r
F P
0 g
s
.68 .71986 m .67763 .6849 L .6565 .67618 L p .707 .577 .707 r
F P
0 g
s
.67763 .6849 m .68 .71986 L .70748 .72503 L p .707 .577 .707 r
F P
0 g
s
.74046 .76591 m .73914 .74859 L .708 .74755 L p .707 .577 .707 r
F P
0 g
s
.73914 .74859 m .74046 .76591 L .7722 .76261 L p .707 .577 .707 r
F P
0 g
s
.7722 .76261 m .77089 .74529 L .73914 .74859 L p .707 .577 .707 r
F P
0 g
s
.77089 .74529 m .7722 .76261 L .80144 .75531 L p .707 .577 .707 r
F P
0 g
s
.80144 .75531 m .80012 .73799 L .77089 .74529 L p .707 .577 .707 r
F P
0 g
s
.83521 .58324 m .8374 .63707 L .84442 .62564 L p .707 .577 .707 r
F P
0 g
s
.84442 .62564 m .84223 .57181 L .83521 .58324 L p .707 .577 .707 r
F P
0 g
s
.70932 .76488 m .708 .74755 L .68051 .74229 L p .707 .577 .707 r
F P
0 g
s
.708 .74755 m .70932 .76488 L .74046 .76591 L p .707 .577 .707 r
F P
0 g
s
.82119 .67115 m .82356 .7061 L .83977 .6938 L p .707 .577 .707 r
F P
0 g
s
.83977 .6938 m .8374 .65885 L .82119 .67115 L p .707 .577 .707 r
F P
0 g
s
.80012 .73799 m .80144 .75531 L .82531 .74472 L p .707 .577 .707 r
F P
0 g
s
.82531 .74472 m .82399 .7274 L .80012 .73799 L p .707 .577 .707 r
F P
0 g
s
.64141 .58561 m .6436 .63943 L .65623 .64951 L p .707 .577 .707 r
F P
0 g
s
.6565 .67618 m .65887 .71114 L .68 .71986 L p .707 .577 .707 r
F P
0 g
s
.68051 .74229 m .68183 .75962 L .70932 .76488 L p .707 .577 .707 r
F P
0 g
s
.6436 .63943 m .64141 .58561 L .63846 .5743 L p .707 .577 .707 r
F P
0 g
s
.68183 .75962 m .68051 .74229 L .65936 .73332 L p .707 .577 .707 r
F P
0 g
s
.65936 .73332 m .66068 .75064 L .68183 .75962 L p .707 .577 .707 r
F P
0 g
s
.82399 .7274 m .82531 .74472 L .84148 .73187 L p .707 .577 .707 r
F P
0 g
s
.84148 .73187 m .84016 .71455 L .82399 .7274 L p .707 .577 .707 r
F P
0 g
s
.8374 .65885 m .83977 .6938 L .84669 .6805 L p .707 .577 .707 r
F P
0 g
s
.84669 .6805 m .84432 .64555 L .8374 .65885 L p .707 .577 .707 r
F P
0 g
s
.84223 .57181 m .84442 .62564 L .84147 .61434 L p .707 .577 .707 r
F P
0 g
s
.84147 .61434 m .83928 .56051 L .84223 .57181 L p .707 .577 .707 r
F P
0 g
s
.64379 .66477 m .64616 .69972 L .65887 .71114 L p .707 .577 .707 r
F P
0 g
s
.63846 .5743 m .64065 .62813 L .6436 .63943 L p .707 .577 .707 r
F P
0 g
s
.66068 .75064 m .65936 .73332 L .64663 .72151 L p .707 .577 .707 r
F P
0 g
s
.64616 .69972 m .64379 .66477 L .64075 .65178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64065 .62813 m .63846 .5743 L .64548 .56288 L p .707 .577 .707 r
F P
0 g
s
.64663 .72151 m .64795 .73884 L .66068 .75064 L p .707 .577 .707 r
F P
0 g
s
.84016 .71455 m .84148 .73187 L .84836 .71803 L p .707 .577 .707 r
F P
0 g
s
.84836 .71803 m .84704 .7007 L .84016 .71455 L p .707 .577 .707 r
F P
0 g
s
.84432 .64555 m .84669 .6805 L .84365 .66751 L p .707 .577 .707 r
F P
0 g
s
.84365 .66751 m .84128 .63256 L .84432 .64555 L p .707 .577 .707 r
F P
0 g
s
.64075 .65178 m .64311 .68673 L .64616 .69972 L p .707 .577 .707 r
F P
0 g
s
.83928 .56051 m .84147 .61434 L .82883 .60426 L p .707 .577 .707 r
F P
0 g
s
.82883 .60426 m .82665 .55043 L .83928 .56051 L p .707 .577 .707 r
F P
0 g
s
.64548 .56288 m .64767 .6167 L .64065 .62813 L p .707 .577 .707 r
F P
0 g
s
.64795 .73884 m .64663 .72151 L .64355 .70803 L p .707 .577 .707 r
F P
0 g
s
.64311 .68673 m .64075 .65178 L .64767 .63848 L p .707 .577 .707 r
F P
0 g
s
.64767 .6167 m .64548 .56288 L .66179 .55245 L p .707 .577 .707 r
F P
0 g
s
.39294 .62685 m .39075 .57302 L .35959 .57161 L p .707 .577 .707 r
F P
0 g
s
.39075 .57302 m .39294 .62685 L .42474 .62466 L p .707 .577 .707 r
F P
0 g
s
.42474 .62466 m .42256 .57084 L .39075 .57302 L p .707 .577 .707 r
F P
0 g
s
.64355 .70803 m .64487 .72535 L .64795 .73884 L p .707 .577 .707 r
F P
0 g
s
.42256 .57084 m .42474 .62466 L .45408 .61909 L p .707 .577 .707 r
F P
0 g
s
.45408 .61909 m .4519 .56527 L .42256 .57084 L p .707 .577 .707 r
F P
0 g
s
.84704 .7007 m .84836 .71803 L .84528 .70454 L p .707 .577 .707 r
F P
0 g
s
.84528 .70454 m .84397 .68722 L .84704 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36177 .62543 m .35959 .57161 L .33212 .56673 L p .707 .577 .707 r
F P
0 g
s
.35959 .57161 m .36177 .62543 L .39294 .62685 L p .707 .577 .707 r
F P
0 g
s
.84128 .63256 m .84365 .66751 L .83094 .6561 L p .707 .577 .707 r
F P
0 g
s
.83094 .6561 m .82857 .62114 L .84128 .63256 L p .707 .577 .707 r
F P
0 g
s
.82665 .55043 m .82883 .60426 L .80775 .5964 L p .707 .577 .707 r
F P
0 g
s
.80775 .5964 m .80556 .54257 L .82665 .55043 L p .707 .577 .707 r
F P
0 g
s
.4519 .56527 m .45408 .61909 L .47808 .61068 L p .707 .577 .707 r
F P
0 g
s
.47808 .61068 m .47589 .55686 L .4519 .56527 L p .707 .577 .707 r
F P
0 g
s
.64767 .63848 m .65004 .67344 L .64311 .68673 L p .707 .577 .707 r
F P
0 g
s
.66179 .55245 m .66398 .60627 L .64767 .6167 L p .707 .577 .707 r
F P
0 g
s
.64487 .72535 m .64355 .70803 L .65043 .69418 L p .707 .577 .707 r
F P
0 g
s
.33431 .62056 m .33212 .56673 L .31104 .55887 L p .707 .577 .707 r
F P
0 g
s
.33212 .56673 m .33431 .62056 L .36177 .62543 L p .707 .577 .707 r
F P
0 g
s
.66398 .60627 m .66179 .55245 L .68579 .54403 L p .707 .577 .707 r
F P
0 g
s
.65004 .67344 m .64767 .63848 L .66388 .62618 L p .707 .577 .707 r
F P
0 g
s
.39562 .68934 m .39325 .65438 L .3621 .65326 L p .707 .577 .707 r
F P
0 g
s
.39325 .65438 m .39562 .68934 L .42738 .68629 L p .707 .577 .707 r
F P
0 g
s
.42738 .68629 m .42501 .65134 L .39325 .65438 L p .707 .577 .707 r
F P
0 g
s
.65043 .69418 m .65175 .71151 L .64487 .72535 L p .707 .577 .707 r
F P
0 g
s
.42501 .65134 m .42738 .68629 L .45664 .67938 L p .707 .577 .707 r
F P
0 g
s
.84397 .68722 m .84528 .70454 L .83255 .69274 L p .707 .577 .707 r
F P
0 g
s
.83255 .69274 m .83123 .67541 L .84397 .68722 L p .707 .577 .707 r
F P
0 g
s
.47589 .55686 m .47808 .61068 L .49439 .60025 L p .707 .577 .707 r
F P
0 g
s
.49439 .60025 m .4922 .54643 L .47589 .55686 L p .707 .577 .707 r
F P
0 g
s
.80556 .54257 m .80775 .5964 L .78028 .59152 L p .707 .577 .707 r
F P
0 g
s
.78028 .59152 m .7781 .53769 L .80556 .54257 L p .707 .577 .707 r
F P
0 g
s
.36447 .68822 m .3621 .65326 L .33462 .64809 L p .707 .577 .707 r
F P
0 g
s
.3621 .65326 m .36447 .68822 L .39562 .68934 L p .707 .577 .707 r
F P
0 g
s
.82857 .62114 m .83094 .6561 L .80981 .64738 L p .707 .577 .707 r
F P
0 g
s
.80981 .64738 m .80744 .61242 L .82857 .62114 L p .707 .577 .707 r
F P
0 g
s
.45428 .64443 m .45664 .67938 L .48055 .66928 L p .707 .577 .707 r
F P
0 g
s
.48055 .66928 m .47818 .63433 L .45428 .64443 L p .707 .577 .707 r
F P
0 g
s
.66388 .62618 m .66624 .66114 L .65004 .67344 L p .707 .577 .707 r
F P
0 g
s
.31104 .55887 m .31322 .61269 L .33431 .62056 L p .707 .577 .707 r
F P
0 g
s
.68797 .59786 m .68579 .54403 L .71513 .53846 L p .707 .577 .707 r
F P
0 g
s
.68579 .54403 m .68797 .59786 L .66398 .60627 L p .707 .577 .707 r
F P
0 g
s
.31322 .61269 m .31104 .55887 L .2984 .54879 L p .707 .577 .707 r
F P
0 g
s
.65175 .71151 m .65043 .69418 L .6666 .68134 L p .707 .577 .707 r
F P
0 g
s
.66624 .66114 m .66388 .62618 L .68778 .61608 L p .707 .577 .707 r
F P
0 g
s
.7781 .53769 m .78028 .59152 L .74912 .5901 L p .707 .577 .707 r
F P
0 g
s
.74912 .5901 m .74693 .53628 L .7781 .53769 L p .707 .577 .707 r
F P
0 g
s
.33699 .68304 m .33462 .64809 L .31349 .63937 L p .707 .577 .707 r
F P
0 g
s
.33462 .64809 m .33699 .68304 L .36447 .68822 L p .707 .577 .707 r
F P
0 g
s
.39745 .7291 m .39613 .71177 L .36499 .71074 L p .707 .577 .707 r
F P
0 g
s
.39613 .71177 m .39745 .7291 L .42919 .7258 L p .707 .577 .707 r
F P
0 g
s
.42919 .7258 m .42788 .70847 L .39613 .71177 L p .707 .577 .707 r
F P
0 g
s
.42788 .70847 m .42919 .7258 L .45843 .7185 L p .707 .577 .707 r
F P
0 g
s
.45843 .7185 m .45711 .70117 L .42788 .70847 L p .707 .577 .707 r
F P
0 g
s
.71731 .59229 m .71513 .53846 L .74693 .53628 L p .707 .577 .707 r
F P
0 g
s
.71513 .53846 m .71731 .59229 L .68797 .59786 L p .707 .577 .707 r
F P
0 g
s
.6666 .68134 m .66792 .69866 L .65175 .71151 L p .707 .577 .707 r
F P
0 g
s
.74693 .53628 m .74912 .5901 L .71731 .59229 L p .707 .577 .707 r
F P
0 g
s
.4922 .54643 m .49439 .60025 L .50141 .58882 L p .707 .577 .707 r
F P
0 g
s
.50141 .58882 m .49922 .535 L .4922 .54643 L p .707 .577 .707 r
F P
0 g
s
.83123 .67541 m .83255 .69274 L .8114 .68376 L p .707 .577 .707 r
F P
0 g
s
.8114 .68376 m .81008 .66644 L .83123 .67541 L p .707 .577 .707 r
F P
0 g
s
.80744 .61242 m .80981 .64738 L .78232 .64221 L p .707 .577 .707 r
F P
0 g
s
.78232 .64221 m .77996 .60725 L .80744 .61242 L p .707 .577 .707 r
F P
0 g
s
.36631 .72806 m .36499 .71074 L .3375 .70548 L p .707 .577 .707 r
F P
0 g
s
.36499 .71074 m .36631 .72806 L .39745 .7291 L p .707 .577 .707 r
F P
0 g
s
.47818 .63433 m .48055 .66928 L .49676 .65699 L p .707 .577 .707 r
F P
0 g
s
.49676 .65699 m .49439 .62203 L .47818 .63433 L p .707 .577 .707 r
F P
0 g
s
.45711 .70117 m .45843 .7185 L .4823 .7079 L p .707 .577 .707 r
F P
0 g
s
.4823 .7079 m .48098 .69058 L .45711 .70117 L p .707 .577 .707 r
F P
0 g
s
.2984 .54879 m .30059 .60262 L .31322 .61269 L p .707 .577 .707 r
F P
0 g
s
.68778 .61608 m .69015 .65104 L .66624 .66114 L p .707 .577 .707 r
F P
0 g
s
.31349 .63937 m .31586 .67432 L .33699 .68304 L p .707 .577 .707 r
F P
0 g
s
.3375 .70548 m .33882 .7228 L .36631 .72806 L p .707 .577 .707 r
F P
0 g
s
.69015 .65104 m .68778 .61608 L .71705 .60918 L p .707 .577 .707 r
F P
0 g
s
.30059 .60262 m .2984 .54879 L .29545 .53749 L p .707 .577 .707 r
F P
0 g
s
.66792 .69866 m .6666 .68134 L .69047 .67074 L p .707 .577 .707 r
F P
0 g
s
.31586 .67432 m .31349 .63937 L .30078 .62795 L p .707 .577 .707 r
F P
0 g
s
.33882 .7228 m .3375 .70548 L .31635 .69651 L p .707 .577 .707 r
F P
0 g
s
.77996 .60725 m .78232 .64221 L .75118 .64109 L p .707 .577 .707 r
F P
0 g
s
.75118 .64109 m .74881 .60613 L .77996 .60725 L p .707 .577 .707 r
F P
0 g
s
.71942 .64413 m .71705 .60918 L .74881 .60613 L p .707 .577 .707 r
F P
0 g
s
.71705 .60918 m .71942 .64413 L .69015 .65104 L p .707 .577 .707 r
F P
0 g
s
.69047 .67074 m .69179 .68807 L .66792 .69866 L p .707 .577 .707 r
F P
0 g
s
.81008 .66644 m .8114 .68376 L .78391 .6785 L p .707 .577 .707 r
F P
0 g
s
.78391 .6785 m .78259 .66118 L .81008 .66644 L p .707 .577 .707 r
F P
0 g
s
.74881 .60613 m .75118 .64109 L .71942 .64413 L p .707 .577 .707 r
F P
0 g
s
.31635 .69651 m .31767 .71383 L .33882 .7228 L p .707 .577 .707 r
F P
0 g
s
.48098 .69058 m .4823 .7079 L .49847 .69506 L p .707 .577 .707 r
F P
0 g
s
.49847 .69506 m .49715 .67773 L .48098 .69058 L p .707 .577 .707 r
F P
0 g
s
.49439 .62203 m .49676 .65699 L .50368 .64369 L p .707 .577 .707 r
F P
0 g
s
.50368 .64369 m .50131 .60873 L .49439 .62203 L p .707 .577 .707 r
F P
0 g
s
.49922 .535 m .50141 .58882 L .49846 .57752 L p .707 .577 .707 r
F P
0 g
s
.49846 .57752 m .49627 .52369 L .49922 .535 L p .707 .577 .707 r
F P
0 g
s
.30078 .62795 m .30315 .66291 L .31586 .67432 L p .707 .577 .707 r
F P
0 g
s
.69179 .68807 m .69047 .67074 L .71971 .66344 L p .707 .577 .707 r
F P
0 g
s
.29545 .53749 m .29763 .59131 L .30059 .60262 L p .707 .577 .707 r
F P
0 g
s
.78259 .66118 m .78391 .6785 L .75277 .67747 L p .707 .577 .707 r
F P
0 g
s
.75277 .67747 m .75145 .66015 L .78259 .66118 L p .707 .577 .707 r
F P
0 g
s
.31767 .71383 m .31635 .69651 L .30362 .6847 L p .707 .577 .707 r
F P
0 g
s
.71971 .66344 m .72103 .68077 L .69179 .68807 L p .707 .577 .707 r
F P
0 g
s
.30315 .66291 m .30078 .62795 L .29774 .61496 L p .707 .577 .707 r
F P
0 g
s
.72103 .68077 m .71971 .66344 L .75145 .66015 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29763 .59131 m .29545 .53749 L .30247 .52606 L p .707 .577 .707 r
F P
0 g
s
.75145 .66015 m .75277 .67747 L .72103 .68077 L p .707 .577 .707 r
F P
0 g
s
.30362 .6847 m .30494 .70202 L .31767 .71383 L p .707 .577 .707 r
F P
0 g
s
.49715 .67773 m .49847 .69506 L .50535 .68121 L p .707 .577 .707 r
F P
0 g
s
.50535 .68121 m .50403 .66389 L .49715 .67773 L p .707 .577 .707 r
F P
0 g
s
.50131 .60873 m .50368 .64369 L .50064 .6307 L p .707 .577 .707 r
F P
0 g
s
.50064 .6307 m .49827 .59574 L .50131 .60873 L p .707 .577 .707 r
F P
0 g
s
.29774 .61496 m .3001 .64992 L .30315 .66291 L p .707 .577 .707 r
F P
0 g
s
.49627 .52369 m .49846 .57752 L .48582 .56744 L p .707 .577 .707 r
F P
0 g
s
.48582 .56744 m .48364 .51362 L .49627 .52369 L p .707 .577 .707 r
F P
0 g
s
.30247 .52606 m .30466 .57989 L .29763 .59131 L p .707 .577 .707 r
F P
0 g
s
.30494 .70202 m .30362 .6847 L .30054 .67121 L p .707 .577 .707 r
F P
0 g
s
.3001 .64992 m .29774 .61496 L .30466 .60167 L p .707 .577 .707 r
F P
0 g
s
.30466 .57989 m .30247 .52606 L .31878 .51563 L p .707 .577 .707 r
F P
0 g
s
.30054 .67121 m .30186 .68854 L .30494 .70202 L p .707 .577 .707 r
F P
0 g
s
.50403 .66389 m .50535 .68121 L .50227 .66773 L p .707 .577 .707 r
F P
0 g
s
.50227 .66773 m .50096 .6504 L .50403 .66389 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49827 .59574 m .50064 .6307 L .48793 .61928 L p .707 .577 .707 r
F P
0 g
s
.48793 .61928 m .48556 .58433 L .49827 .59574 L p .707 .577 .707 r
F P
0 g
s
.48364 .51362 m .48582 .56744 L .46474 .55958 L p .707 .577 .707 r
F P
0 g
s
.46474 .55958 m .46255 .50576 L .48364 .51362 L p .707 .577 .707 r
F P
0 g
s
.30466 .60167 m .30703 .63662 L .3001 .64992 L p .707 .577 .707 r
F P
0 g
s
.31878 .51563 m .32096 .56946 L .30466 .57989 L p .707 .577 .707 r
F P
0 g
s
.30186 .68854 m .30054 .67121 L .30742 .65737 L p .707 .577 .707 r
F P
0 g
s
.32096 .56946 m .31878 .51563 L .34278 .50722 L p .707 .577 .707 r
F P
0 g
s
.30703 .63662 m .30466 .60167 L .32087 .58937 L p .707 .577 .707 r
F P
0 g
s
.30742 .65737 m .30874 .67469 L .30186 .68854 L p .707 .577 .707 r
F P
0 g
s
.50096 .6504 m .50227 .66773 L .48954 .65592 L p .707 .577 .707 r
F P
0 g
s
.48954 .65592 m .48822 .6386 L .50096 .6504 L p .707 .577 .707 r
F P
0 g
s
.46255 .50576 m .46474 .55958 L .43727 .5547 L p .707 .577 .707 r
F P
0 g
s
.43727 .5547 m .43508 .50088 L .46255 .50576 L p .707 .577 .707 r
F P
0 g
s
.48556 .58433 m .48793 .61928 L .4668 .61056 L p .707 .577 .707 r
F P
0 g
s
.4668 .61056 m .46443 .57561 L .48556 .58433 L p .707 .577 .707 r
F P
0 g
s
.32087 .58937 m .32323 .62432 L .30703 .63662 L p .707 .577 .707 r
F P
0 g
s
.34496 .56104 m .34278 .50722 L .37211 .50165 L p .707 .577 .707 r
F P
0 g
s
.34278 .50722 m .34496 .56104 L .32096 .56946 L p .707 .577 .707 r
F P
0 g
s
.30874 .67469 m .30742 .65737 L .32359 .64452 L p .707 .577 .707 r
F P
0 g
s
.32323 .62432 m .32087 .58937 L .34477 .57927 L p .707 .577 .707 r
F P
0 g
s
.43508 .50088 m .43727 .5547 L .40611 .55329 L p .707 .577 .707 r
F P
0 g
s
.40611 .55329 m .40392 .49946 L .43508 .50088 L p .707 .577 .707 r
F P
0 g
s
.3743 .55547 m .37211 .50165 L .40392 .49946 L p .707 .577 .707 r
F P
0 g
s
.37211 .50165 m .3743 .55547 L .34496 .56104 L p .707 .577 .707 r
F P
0 g
s
.32359 .64452 m .32491 .66185 L .30874 .67469 L p .707 .577 .707 r
F P
0 g
s
.40392 .49946 m .40611 .55329 L .3743 .55547 L p .707 .577 .707 r
F P
0 g
s
.48822 .6386 m .48954 .65592 L .46839 .64695 L p .707 .577 .707 r
F P
0 g
s
.46839 .64695 m .46707 .62962 L .48822 .6386 L p .707 .577 .707 r
F P
0 g
s
.46443 .57561 m .4668 .61056 L .43931 .60539 L p .707 .577 .707 r
F P
0 g
s
.43931 .60539 m .43695 .57044 L .46443 .57561 L p .707 .577 .707 r
F P
0 g
s
.34477 .57927 m .34714 .61422 L .32323 .62432 L p .707 .577 .707 r
F P
0 g
s
.34714 .61422 m .34477 .57927 L .37404 .57236 L p .707 .577 .707 r
F P
0 g
s
.32491 .66185 m .32359 .64452 L .34746 .63393 L p .707 .577 .707 r
F P
0 g
s
.43695 .57044 m .43931 .60539 L .40817 .60427 L p .707 .577 .707 r
F P
0 g
s
.40817 .60427 m .4058 .56932 L .43695 .57044 L p .707 .577 .707 r
F P
0 g
s
.37641 .60731 m .37404 .57236 L .4058 .56932 L p .707 .577 .707 r
F P
0 g
s
.37404 .57236 m .37641 .60731 L .34714 .61422 L p .707 .577 .707 r
F P
0 g
s
.34746 .63393 m .34878 .65125 L .32491 .66185 L p .707 .577 .707 r
F P
0 g
s
.46707 .62962 m .46839 .64695 L .4409 .64169 L p .707 .577 .707 r
F P
0 g
s
.4409 .64169 m .43958 .62436 L .46707 .62962 L p .707 .577 .707 r
F P
0 g
s
.4058 .56932 m .40817 .60427 L .37641 .60731 L p .707 .577 .707 r
F P
0 g
s
.34878 .65125 m .34746 .63393 L .3767 .62663 L p .707 .577 .707 r
F P
0 g
s
.43958 .62436 m .4409 .64169 L .40976 .64065 L p .707 .577 .707 r
F P
0 g
s
.40976 .64065 m .40844 .62333 L .43958 .62436 L p .707 .577 .707 r
F P
0 g
s
.3767 .62663 m .37802 .64395 L .34878 .65125 L p .707 .577 .707 r
F P
0 g
s
.37802 .64395 m .3767 .62663 L .40844 .62333 L p .707 .577 .707 r
F P
0 g
s
.40844 .62333 m .40976 .64065 L .37802 .64395 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0028Ool<0029Ool007moo`T0
00IJEP03001JEUYF00=JEP`007eoo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MWoo001dOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000M7oo001aOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LWoo001]Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001`Ool006]oo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006io
o`00JWoo0P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0P00KGoo001YOol00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH00000Jgoo001WOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01@00FUIJEUYF0000JWoo001VOol00`00FUIJEP02FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1WOol006Eoo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo
001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000EJEP03
001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP80
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJ7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVQoo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF
J7oo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol0069oo`05001JEUYFFUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00Hgoo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIWOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVMoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEUYF01L000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001VOol0061oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
05aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001V
Ool005Yoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0067oo3`00?Woo001COol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P003goo2@0015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0027oo
0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001C
Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Woo0P000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
035oo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00MJ
EP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001C
Ool01000FUIJEP0015YF00<005YFFUH00eYF1@000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
1UYF100015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF0004
FUH00`00FUH000030004Ool01@00FUIJEUYF000015YF1@001UYF00<005YFFUH00eYF0`0015YF0`00
00AJEP00FUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEPL000=o
o`05001JEUYFFUH00004FUH:00000eYF001JEP0400000eYF001JEP05FUH01000FUH000000UYF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF0P000eYF00@005YFFUIJEPd0
00AJEP03001JEUYF009JEPT000IJEP06001JEUYFFUH005YF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
02eoo`00E7oo00<005YF00000P001EYF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00E7oo00D005YF001JEP0000EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH0
0`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol2
0003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol20003
FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP04FUH60009Ool80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Goo0011OolE0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP05001JEUYF
FUH00006FUH00`00FUIJEP040007Ool3000=Ool60004FUH01@00FUIJEUYF0000;Goo000mOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP05001JEUYF
FUH00005FUH4000:Ool5000>Ool20002FUH300000eYF001JEP02FUH2000/Ool003Uoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEP0000<000ioo`D0
00Uoo`D000EJEP04001JEP000003FUH2000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJEPP000AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF0P0000=JEP00FUH010002goo3`000UYF00<005YFFUH015YF00D005YF
FUIJEP00009JEP8002aoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00002FUH01@00FUIJEUYF00001EYF2`0015YF00<005YFFUH01UYF00<005YF0000
0`001EYF00<005YFFUH00UYF1000;7oo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH00`00FUIJEP04FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP04FUH3000/Ool002moo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH0000200001EYF000005YF00000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P001EYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0015YF0`00;7oo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH0
00050003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUIJEUYF
0P000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20000
0eYF001JEP04FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH20005FUH90004
FUH?0007FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00;7oo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00<005YF00001EYF00D005YFFUIJEP00009JEPL000AJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002eo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00UYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000AJEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020003FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`8000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP800003FUH005YF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Goo0P00
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`00
00=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000AJ
EP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04
001JEUYF000]Ool002eoo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP04001JEP000006FUH00`00FUIJEP04FUH70009FUH00`00FUIJEP02FUH7
0004FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00AJEQD0009JEP<000MJEP03001JEUYF00D000EJEP03001JEUYF00MJEPD0009JEP03001J
EUYF009JEP8000=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00@000Ioo`<000Yoo`800005FUH00000FUH00006FUH90005FUH01000
FUIJEUYF1`001UYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001P0000EJEP00FUIJEP0002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF10002Goo1@002Goo0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01@00
FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH01000
FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001goo0P000UYF
00<007ooOol0:goo000]Ool00`00FUH00004FUH00`00FUH00003000=Ool5000:Ool20004FUH01000
FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H0
05YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000AJEP05001JEP00001JEP040002FUH00`00FUIJEP06FUH:0002FUH4000<Ool00`00
FUH0000]Ool002eoo`03001JEP0000AJEPL000aoo`D000Qoo`@000AJEP800003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP03
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP8000AJEP03001JEUYF00/000AJEP03001JEUYF009JEPP000Yoo`@002eoo`00;Goo00<005YF0000
0UYF0P000eYF00@005YFFUIJEQT00004FUH005YF0002FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00009JEP800003FUH005YF
00=JEP04001JEUYFFUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000goo0P00
0UYF0`00;7oo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP02FUH5000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUIJEP00FUH30003FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH3000/Ool002eoo`05001JEP00FUH00005FUH0
0`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUH005YF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00P000eYF0`00;7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF0P000UYF0`000eYF00<005YF
FUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJEP00FUH002aoo`00;Goo0P00
0UYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF00<000EJEP03001JEUYF00AJEPH000moo`@0009JEP03001JEUYF00=JEP<0
0003FUH007oo02]oo`00;Goo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000IJ
EP04001JEUYFFUH200000eYF00000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`0000=JEP00FUH00P001UYF00<005YFFUH010004Woo100000=JEP00FUH01000
15YF00@005YF000002eoo`00;Goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000EJEP03001JEUYF00=JEPT0009JEPD0009JEPL000YJEP04001JEUYF
0003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P0000=JEP00FUH015YF100000=JEP00Ool037oo1`001EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0002eoo`00;Goo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00eYF00<005YF00000P000UYF00<005YF000020001EYF00<005YFFUH0
2EYF0`0015YF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF009JEP04001JEUYFFUH20003FUH@0004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH30002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF00800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF009JEP<000QJEP8000UJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEP04
001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH200000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001oo`0[Ool002moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF009JEPP000AJEP80009JEP03001JEP00008000EJEP03001JEUYF0080009JEP03001JEUYF
00=JEP03001JEUYF00QJEP03001JEUYF009JEP<000IJEP03001JEP0000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH01@00FUIJEUYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo0P00;7oo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008FUH700000eYF001JEP03FUH30002FUH00`00
FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP08FUH500000eYF001JEP06FUH20008FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
17oo0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH00`00FUH0000300000eYF00000002FUH00`00FUIJEP04FUH01000FUIJ
EUYF1`001EYF00<005YFFUH015YF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH20006Ool2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool01000FUH00000:goo000]Ool0
0`00FUH00004FUH01000FUIJEUYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH300000eYF001JEP06FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP04FUH40009Ool01000
FUIJEP00:goo000]Ool00`00FUH00004FUH01000FUH0000017oo200015YF00<005YFFUH00UYF2@00
1goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00EJEP03001JEP00008000IJEP03001JEUYF00AJEPD000EJEP03001JEUYF00@000aoo`80009JEP03
001oogoo02Uoo`00;Goo00@005YFFUH000=JEP8000ioo`T0019oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH500000eYF
00000005000>Ool2000015YF001JEP00;7oo000]Ool01000FUIJEP000UYF00<007ooOol04Goo2P00
4Goo10000UYF00<005YFFUH01EYF00<005YFFUH00eYF1`001eYF2P0035YF2@0025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEP0000l001=oo`8000AJEP8002aoo`00
;Goo00H005YFFUH005YF000?Ool70004FUH01000FUIJEUYF200027oo00@005YFFUIJEQ4000EJEP03
001JEUYF00H000UJEP03001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP06001J
EUYFFUH005YF0P000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`<001=oo`800003FUH005YF
00=JEP03001oogoo02]oo`00;Woo00@005YF000000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH50002Ool00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF
FUIJEP80009JEP05001JEUYFFUH00004FUH01@00FUIJEUYF000077oo0P000eYF00<005YFFUH00UYF
00<007ooOol0:goo000^Ool01@00FUH005YF00001goo10001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF100015YF00<005YF00002EYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00<0
05YFFUH00`0000=JEP00FUH00eYF00D005YFFUIJEP0001Uoo`<000EJEP03001JEUYF008002ioo`00
;Woo0P000UYF0`000goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P0015YF00<005YFFUH025YF00@005YFFUIJEP<000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<00003FUH005YF00=JEP04001JEUYF
0002FUH20005FUH01000FUIJEP005Goo100000=JEP00FUH01EYF0`00<7oo000^Ool20002FUH00`00
FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH025YF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00P0015YF0P0000=JEP00FUH00eYF1P000UYF
00<007ooOol037oo1`001EYF00<005YFFUH00eYF0P00<Woo000^Ool20002FUH01000FUH000001UYF
00<005YFFUH015YF1P002Goo200015YF00<005YFFUH00UYF0P0000=JEP0000002EYF0P000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF00@005YFFUIJEP@000EJEP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00=7oo000^Ool20002FUH30007FUH00`00FUIJEP050009Ool70006FUH50004FUH00`00FUH0
00020007FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=Woo000^Ool20002FUH00`00
FUH00006FUH50004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEP00
1UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH01EYF0`000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo000_Ool00`00FUH00003FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP0000AJEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Aoo`800003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@003]oo`00;goo0P0015YF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01`00
FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPL003moo`00;goo0P0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0P000Woo00<005YF00000UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH015YF0`002Goo5000AWoo000_Ool20003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000`0017oo0P0015YF0`00Dgoo000^Ool01000FUH005YF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00@005YFFUIJEP80
00Moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP@00003FUH0
05YF00=JEP<005=oo`00;Woo00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000IJEP03001JEUYF00EJEP04001JEP000009Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUH000020003FUH00`00FUH0001COol002ioo`03001JEP0000Aoo`80
0003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<000Yoo`@000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEP800004FUH005YF001COol002ioo`80
00Moo`D000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000eoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH4001DOol002ioo`8000aoo`T000=J
EP<000=JEPL000moo`<00003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00<0009JEP03001JEUYF00=JEP@005Aoo`00;Woo0P005Goo2@0057oo0P000UYF0P0000=oo`00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00FUH40004FUH00`00FUH0001EOol0
02ioo`<0031oo`03001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP8000AJEP03001JEUYF00=JEP<00005FUH005YFFUH0001DOol002ioo`800003FUH007oo02aoo`<0
00AJEP05001oogooOol00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP020006FUH00`00FUIJEP05FUH3
0002FUH00`00Oomoo`1BOol002ioo`80009JEP03001oogoo02Qoo`80009JEP03001JEUYF009JEP03
001oogoo009oo`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000QJEP03001JEUYF00AJEP@00003FUH0000005=oo`00
;goo00<005YFFUH00`009Woo0P001EYF00@005YFFUH000Moo`8000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=oo`<005=oo`00;goo00@005YFFUH0009JEP80029oo`8000MJEP<000Uo
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20006Ool2001COol0031oo`04001JEUYF
0003FUH5000IOol400000eYF001JEP05FUH2000=Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040006FUH00`00FUIJEP06FUH01000FUH0
000027oo0P00Dgoo000aOol30004FUH01000FUIJEUYF2@002Goo1`001EYF00<005YFFUH00UYF0P00
4Goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF0`0000=J
EP0000000`001EYF00<005YFFUH015YF10002Goo00@005YF0000059oo`00<goo00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000001Ioo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP@000AJEPD000EJEP03001JEUYF00@0
00eoo`04001JEUYF001BOol003Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<001aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP00
00<00003FUH005YF00EJEPD00003FUH0000000D0011oo`80009JEP03001oogoo051oo`00=Woo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P009Goo2@001UYF
00<005YFFUH015YF20000goo3`005Woo00D005YF001JEP0005=oo`00>7oo1@0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YF00000P00<7oo3@00;goo00@005YFFUIJEP8005=oo`00?Goo6000
>goo00<005YF0000;goo0P0015YF00<007ooOol0DWoo002@Ool200000eYF001oo`0[Ool200000eYF
001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF008002Qoo`8000=JEP05001JEUYFFUH0001E
Ool0095oo`05001JEUYF001JEP03000ROol30005FUH01000FUH00000EWoo002BOol00`00FUH00004
FUH3000KOol400000eYF001JEP05FUH2001HOol0099oo`03001JEP0000EJEP03001JEP0000<0011o
o`L000EJEP03001JEUYF00=JEP8005Uoo`00Tgoo0P001EYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00@005YFFUIJEP8005]oo`00U7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF000005eoo`00UWoo0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00Ggoo002IOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04001ROol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF009J
EPL006Ioo`00X7oo4000KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60054 .7639 m .59701 .71144 L .56587 .71032 L p .707 .577 .707 r
F P
0 g
s
.59701 .71144 m .60054 .7639 L .6323 .76087 L p .707 .577 .707 r
F P
0 g
s
.6323 .76087 m .62878 .70841 L .59701 .71144 L p .707 .577 .707 r
F P
0 g
s
.62878 .70841 m .6323 .76087 L .66157 .75399 L p .707 .577 .707 r
F P
0 g
s
.66157 .75399 m .65804 .70153 L .62878 .70841 L p .707 .577 .707 r
F P
0 g
s
.56939 .76278 m .56587 .71032 L .53838 .70515 L p .707 .577 .707 r
F P
0 g
s
.56587 .71032 m .56939 .76278 L .60054 .7639 L p .707 .577 .707 r
F P
0 g
s
.65804 .70153 m .66157 .75399 L .68548 .74392 L p .707 .577 .707 r
F P
0 g
s
.68548 .74392 m .68195 .69146 L .65804 .70153 L p .707 .577 .707 r
F P
0 g
s
.54191 .75761 m .53838 .70515 L .51726 .69645 L p .707 .577 .707 r
F P
0 g
s
.53838 .70515 m .54191 .75761 L .56939 .76278 L p .707 .577 .707 r
F P
0 g
s
.68195 .69146 m .68548 .74392 L .70169 .73165 L p .707 .577 .707 r
F P
0 g
s
.70169 .73165 m .69816 .67919 L .68195 .69146 L p .707 .577 .707 r
F P
0 g
s
.60517 .83349 m .60137 .80032 L .57027 .79966 L p .707 .577 .707 r
F P
0 g
s
.60137 .80032 m .60517 .83349 L .63682 .82912 L p .707 .577 .707 r
F P
0 g
s
.63682 .82912 m .63301 .79595 L .60137 .80032 L p .707 .577 .707 r
F P
0 g
s
.63301 .79595 m .63682 .82912 L .6659 .82015 L p .707 .577 .707 r
F P
0 g
s
.6659 .82015 m .66209 .78698 L .63301 .79595 L p .707 .577 .707 r
F P
0 g
s
.57407 .83282 m .57027 .79966 L .54274 .79403 L p .707 .577 .707 r
F P
0 g
s
.57027 .79966 m .57407 .83282 L .60517 .83349 L p .707 .577 .707 r
F P
0 g
s
.52078 .7489 m .51726 .69645 L .50455 .68505 L p .707 .577 .707 r
F P
0 g
s
.51726 .69645 m .52078 .7489 L .54191 .75761 L p .707 .577 .707 r
F P
0 g
s
.66209 .78698 m .6659 .82015 L .68957 .80745 L p .707 .577 .707 r
F P
0 g
s
.68957 .80745 m .68576 .77429 L .66209 .78698 L p .707 .577 .707 r
F P
0 g
s
.69816 .67919 m .70169 .73165 L .70861 .71838 L p .707 .577 .707 r
F P
0 g
s
.70861 .71838 m .70508 .66593 L .69816 .67919 L p .707 .577 .707 r
F P
0 g
s
.54654 .8272 m .54274 .79403 L .52149 .78398 L p .707 .577 .707 r
F P
0 g
s
.54274 .79403 m .54654 .8272 L .57407 .83282 L p .707 .577 .707 r
F P
0 g
s
.68576 .77429 m .68957 .80745 L .70551 .79228 L p .707 .577 .707 r
F P
0 g
s
.70551 .79228 m .70171 .75911 L .68576 .77429 L p .707 .577 .707 r
F P
0 g
s
.60827 .88068 m .60615 .8644 L .57506 .86387 L p .707 .577 .707 r
F P
0 g
s
.60615 .8644 m .60827 .88068 L .63986 .87593 L p .707 .577 .707 r
F P
0 g
s
.63986 .87593 m .63775 .85965 L .60615 .8644 L p .707 .577 .707 r
F P
0 g
s
.50803 .82845 m .47601 .35497 L .43203 .35338 L p .707 .577 .707 r
F P
0 g
s
.50455 .68505 m .50808 .73751 L .52078 .7489 L p .707 .577 .707 r
F P
0 g
s
.50808 .73751 m .50455 .68505 L .50151 .67209 L p .707 .577 .707 r
F P
0 g
s
.52149 .78398 m .52529 .81715 L .54654 .8272 L p .707 .577 .707 r
F P
0 g
s
.52529 .81715 m .52149 .78398 L .5086 .77051 L p .707 .577 .707 r
F P
0 g
s
.50151 .67209 m .50503 .72455 L .50808 .73751 L p .707 .577 .707 r
F P
0 g
s
.5086 .77051 m .5124 .80368 L .52529 .81715 L p .707 .577 .707 r
F P
0 g
s
.50503 .72455 m .50151 .67209 L .50843 .65883 L p .707 .577 .707 r
F P
0 g
s
.5124 .80368 m .5086 .77051 L .50532 .75492 L p .707 .577 .707 r
F P
0 g
s
.50843 .65883 m .51196 .71128 L .50503 .72455 L p .707 .577 .707 r
F P
0 g
s
.50532 .75492 m .50912 .78809 L .5124 .80368 L p .707 .577 .707 r
F P
0 g
s
.51196 .71128 m .50843 .65883 L .52464 .64656 L p .707 .577 .707 r
F P
0 g
s
.50912 .78809 m .50532 .75492 L .51198 .73874 L p .707 .577 .707 r
F P
0 g
s
.51537 .84988 m .51326 .8336 L .50989 .81726 L p .707 .577 .707 r
F P
0 g
s
.50989 .81726 m .512 .83354 L .51537 .84988 L p .707 .577 .707 r
F P
0 g
s
.52464 .64656 m .52817 .69902 L .51196 .71128 L p .707 .577 .707 r
F P
0 g
s
.51198 .73874 m .51578 .77191 L .50912 .78809 L p .707 .577 .707 r
F P
0 g
s
.52817 .69902 m .52464 .64656 L .54855 .63649 L p .707 .577 .707 r
F P
0 g
s
.51578 .77191 m .51198 .73874 L .52793 .72357 L p .707 .577 .707 r
F P
0 g
s
.512 .83354 m .50989 .81726 L .51644 .80025 L p .707 .577 .707 r
F P
0 g
s
.54855 .63649 m .55208 .68895 L .52817 .69902 L p .707 .577 .707 r
F P
0 g
s
.51644 .80025 m .51856 .81653 L .512 .83354 L p .707 .577 .707 r
F P
0 g
s
.52793 .72357 m .53173 .75673 L .51578 .77191 L p .707 .577 .707 r
F P
0 g
s
.53173 .75673 m .52793 .72357 L .5516 .71087 L p .707 .577 .707 r
F P
0 g
s
.51856 .81653 m .51644 .80025 L .53229 .78423 L p .707 .577 .707 r
F P
0 g
s
.53229 .78423 m .5344 .80051 L .51856 .81653 L p .707 .577 .707 r
F P
0 g
s
.5516 .71087 m .5554 .74404 L .53173 .75673 L p .707 .577 .707 r
F P
0 g
s
.5344 .80051 m .53229 .78423 L .55587 .77078 L p .707 .577 .707 r
F P
0 g
s
.55587 .77078 m .55798 .78706 L .5344 .80051 L p .707 .577 .707 r
F P
0 g
s
.47601 .35497 m .50803 .82845 L .55287 .82415 L p .707 .577 .707 r
F P
0 g
s
.55287 .82415 m .52084 .35067 L .47601 .35497 L p .707 .577 .707 r
F P
0 g
s
.63775 .85965 m .63986 .87593 L .66887 .86636 L p .707 .577 .707 r
F P
0 g
s
.66887 .86636 m .66675 .85008 L .63775 .85965 L p .707 .577 .707 r
F P
0 g
s
.55208 .68895 m .54855 .63649 L .57782 .6296 L p .707 .577 .707 r
F P
0 g
s
.57782 .6296 m .58134 .68206 L .55208 .68895 L p .707 .577 .707 r
F P
0 g
s
.5554 .74404 m .5516 .71087 L .58068 .7019 L p .707 .577 .707 r
F P
0 g
s
.58068 .7019 m .58448 .73507 L .5554 .74404 L p .707 .577 .707 r
F P
0 g
s
.55798 .78706 m .55587 .77078 L .58487 .76121 L p .707 .577 .707 r
F P
0 g
s
.58699 .77749 m .58487 .76121 L .61647 .75646 L p .707 .577 .707 r
F P
0 g
s
.58487 .76121 m .58699 .77749 L .55798 .78706 L p .707 .577 .707 r
F P
0 g
s
.61647 .75646 m .61858 .77274 L .58699 .77749 L p .707 .577 .707 r
F P
0 g
s
.52084 .35067 m .55287 .82415 L .59419 .8144 L p .707 .577 .707 r
F P
0 g
s
.58134 .68206 m .57782 .6296 L .60958 .62657 L p .707 .577 .707 r
F P
0 g
s
.60958 .62657 m .61311 .67903 L .58134 .68206 L p .707 .577 .707 r
F P
0 g
s
.58448 .73507 m .58068 .7019 L .61232 .69753 L p .707 .577 .707 r
F P
0 g
s
.61232 .69753 m .61612 .7307 L .58448 .73507 L p .707 .577 .707 r
F P
0 g
s
.59419 .8144 m .56216 .34092 L .52084 .35067 L p .707 .577 .707 r
F P
0 g
s
.57718 .88015 m .57506 .86387 L .54752 .85811 L p .707 .577 .707 r
F P
0 g
s
.57506 .86387 m .57718 .88015 L .60827 .88068 L p .707 .577 .707 r
F P
0 g
s
.46406 .82686 m .43203 .35338 L .39323 .34608 L p .707 .577 .707 r
F P
0 g
s
.43203 .35338 m .46406 .82686 L .50803 .82845 L p .707 .577 .707 r
F P
0 g
s
.66675 .85008 m .66887 .86636 L .69245 .8529 L p .707 .577 .707 r
F P
0 g
s
.69245 .8529 m .69033 .83663 L .66675 .85008 L p .707 .577 .707 r
F P
0 g
s
.54752 .85811 m .54964 .87439 L .57718 .88015 L p .707 .577 .707 r
F P
0 g
s
.70508 .66593 m .70861 .71838 L .70557 .70542 L p .707 .577 .707 r
F P
0 g
s
.70557 .70542 m .70204 .65296 L .70508 .66593 L p .707 .577 .707 r
F P
0 g
s
.64342 .6982 m .64723 .73136 L .61612 .7307 L p .707 .577 .707 r
F P
0 g
s
.61612 .7307 m .61232 .69753 L .64342 .6982 L p .707 .577 .707 r
F P
0 g
s
.64756 .75699 m .64967 .77327 L .61858 .77274 L p .707 .577 .707 r
F P
0 g
s
.61858 .77274 m .61647 .75646 L .64756 .75699 L p .707 .577 .707 r
F P
0 g
s
.56216 .34092 m .59419 .8144 L .62794 .80015 L p .707 .577 .707 r
F P
0 g
s
.64072 .6277 m .64425 .68016 L .61311 .67903 L p .707 .577 .707 r
F P
0 g
s
.61311 .67903 m .60958 .62657 L .64072 .6277 L p .707 .577 .707 r
F P
0 g
s
.62794 .80015 m .59591 .32667 L .56216 .34092 L p .707 .577 .707 r
F P
0 g
s
.70171 .75911 m .70551 .79228 L .71217 .7761 L p .707 .577 .707 r
F P
0 g
s
.71217 .7761 m .70837 .74293 L .70171 .75911 L p .707 .577 .707 r
F P
0 g
s
.54964 .87439 m .54752 .85811 L .52622 .84768 L p .707 .577 .707 r
F P
0 g
s
.69033 .83663 m .69245 .8529 L .70829 .83689 L p .707 .577 .707 r
F P
0 g
s
.70829 .83689 m .70618 .82061 L .69033 .83663 L p .707 .577 .707 r
F P
0 g
s
.42526 .81956 m .39323 .34608 L .3634 .33377 L p .707 .577 .707 r
F P
0 g
s
.39323 .34608 m .42526 .81956 L .46406 .82686 L p .707 .577 .707 r
F P
0 g
s
.52622 .84768 m .52834 .86396 L .54964 .87439 L p .707 .577 .707 r
F P
0 g
s
.52834 .86396 m .52622 .84768 L .51326 .8336 L p .707 .577 .707 r
F P
0 g
s
.6751 .76275 m .67721 .77903 L .64967 .77327 L p .707 .577 .707 r
F P
0 g
s
.64967 .77327 m .64756 .75699 L .6751 .76275 L p .707 .577 .707 r
F P
0 g
s
.59591 .32667 m .62794 .80015 L .65082 .7828 L p .707 .577 .707 r
F P
0 g
s
.67095 .70383 m .67475 .73699 L .64723 .73136 L p .707 .577 .707 r
F P
0 g
s
.64723 .73136 m .64342 .6982 L .67095 .70383 L p .707 .577 .707 r
F P
0 g
s
.65082 .7828 m .61879 .30932 L .59591 .32667 L p .707 .577 .707 r
F P
0 g
s
.70204 .65296 m .70557 .70542 L .69286 .69403 L p .707 .577 .707 r
F P
0 g
s
.69286 .69403 m .68934 .64157 L .70204 .65296 L p .707 .577 .707 r
F P
0 g
s
.70837 .74293 m .71217 .7761 L .7089 .76051 L p .707 .577 .707 r
F P
0 g
s
.7089 .76051 m .70509 .72735 L .70837 .74293 L p .707 .577 .707 r
F P
0 g
s
.70618 .82061 m .70829 .83689 L .71485 .81988 L p .707 .577 .707 r
F P
0 g
s
.71485 .81988 m .71273 .8036 L .70618 .82061 L p .707 .577 .707 r
F P
0 g
s
.51326 .8336 m .51537 .84988 L .52834 .86396 L p .707 .577 .707 r
F P
0 g
s
.39543 .80725 m .3634 .33377 L .34546 .31766 L p .707 .577 .707 r
F P
0 g
s
.3634 .33377 m .39543 .80725 L .42526 .81956 L p .707 .577 .707 r
F P
0 g
s
.25753 .72709 m .25401 .67463 L .22286 .6735 L p .707 .577 .707 r
F P
0 g
s
.25401 .67463 m .25753 .72709 L .2893 .72406 L p .707 .577 .707 r
F P
0 g
s
.2893 .72406 m .28577 .6716 L .25401 .67463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28577 .6716 m .2893 .72406 L .31856 .71717 L p .707 .577 .707 r
F P
0 g
s
.31856 .71717 m .31504 .66471 L .28577 .6716 L p .707 .577 .707 r
F P
0 g
s
.22639 .72596 m .22286 .6735 L .19538 .66834 L p .707 .577 .707 r
F P
0 g
s
.22286 .6735 m .22639 .72596 L .25753 .72709 L p .707 .577 .707 r
F P
0 g
s
.68934 .64157 m .69286 .69403 L .67174 .68532 L p .707 .577 .707 r
F P
0 g
s
.67174 .68532 m .66821 .63287 L .68934 .64157 L p .707 .577 .707 r
F P
0 g
s
.70509 .72735 m .7089 .76051 L .696 .74704 L p .707 .577 .707 r
F P
0 g
s
.696 .74704 m .6922 .71387 L .70509 .72735 L p .707 .577 .707 r
F P
0 g
s
.71273 .8036 m .71485 .81988 L .71148 .80353 L p .707 .577 .707 r
F P
0 g
s
.71148 .80353 m .70936 .78725 L .71273 .8036 L p .707 .577 .707 r
F P
0 g
s
.31504 .66471 m .31856 .71717 L .34247 .7071 L p .707 .577 .707 r
F P
0 g
s
.34247 .7071 m .33894 .65464 L .31504 .66471 L p .707 .577 .707 r
F P
0 g
s
.66821 .63287 m .67174 .68532 L .64425 .68016 L p .707 .577 .707 r
F P
0 g
s
.64425 .68016 m .64072 .6277 L .66821 .63287 L p .707 .577 .707 r
F P
0 g
s
.61879 .30932 m .65082 .7828 L .66059 .76403 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .62857 .29055 L .61879 .30932 L p .707 .577 .707 r
F P
0 g
s
.1989 .72079 m .19538 .66834 L .17425 .65963 L p .707 .577 .707 r
F P
0 g
s
.19538 .66834 m .1989 .72079 L .22639 .72596 L p .707 .577 .707 r
F P
0 g
s
.33894 .65464 m .34247 .7071 L .35868 .69483 L p .707 .577 .707 r
F P
0 g
s
.35868 .69483 m .35515 .64238 L .33894 .65464 L p .707 .577 .707 r
F P
0 g
s
.6922 .71387 m .696 .74704 L .67475 .73699 L p .707 .577 .707 r
F P
0 g
s
.67475 .73699 m .67095 .70383 L .6922 .71387 L p .707 .577 .707 r
F P
0 g
s
.37749 .79114 m .34546 .31766 L .34117 .29933 L p .707 .577 .707 r
F P
0 g
s
.34546 .31766 m .37749 .79114 L .39543 .80725 L p .707 .577 .707 r
F P
0 g
s
.26217 .79667 m .25836 .7635 L .22726 .76284 L p .707 .577 .707 r
F P
0 g
s
.25836 .7635 m .26217 .79667 L .29381 .79231 L p .707 .577 .707 r
F P
0 g
s
.29381 .79231 m .29001 .75914 L .25836 .7635 L p .707 .577 .707 r
F P
0 g
s
.29001 .75914 m .29381 .79231 L .32289 .78334 L p .707 .577 .707 r
F P
0 g
s
.32289 .78334 m .31908 .75017 L .29001 .75914 L p .707 .577 .707 r
F P
0 g
s
.70936 .78725 m .71148 .80353 L .69851 .78946 L p .707 .577 .707 r
F P
0 g
s
.69851 .78946 m .69639 .77318 L .70936 .78725 L p .707 .577 .707 r
F P
0 g
s
.23106 .79601 m .22726 .76284 L .19973 .75721 L p .707 .577 .707 r
F P
0 g
s
.22726 .76284 m .23106 .79601 L .26217 .79667 L p .707 .577 .707 r
F P
0 g
s
.17777 .71209 m .17425 .65963 L .16154 .64824 L p .707 .577 .707 r
F P
0 g
s
.17425 .65963 m .17777 .71209 L .1989 .72079 L p .707 .577 .707 r
F P
0 g
s
.31908 .75017 m .32289 .78334 L .34656 .77064 L p .707 .577 .707 r
F P
0 g
s
.34656 .77064 m .34276 .73747 L .31908 .75017 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .6563 .7457 L p .65047 .65 L .707 .577 .707 r
F P
0 g
s
.65047 .65 m .64491 .55872 L .64886 .61047 L .707 .577 .707 r
F
.65047 .65 m .64886 .61047 L .66059 .76403 L F
.64057 .468 m .66059 .76403 L p .64491 .55872 L F P
0 g
s
.62427 .27222 m .62857 .29055 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.6563 .7457 m .64793 .62198 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.64793 .62198 m .62427 .27222 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.62427 .27222 m .6563 .7457 L .63836 .72959 L p .707 .577 .707 r
F P
0 g
s
.6458 .66756 m .6496 .70073 L .6518 .70302 L p .707 .577 .707 r
F P
0 g
s
.6518 .70302 m .6625 .7142 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.65077 .68144 m .6458 .66756 L .6518 .70302 L .707 .577 .707 r
F
.66554 .75223 m .66343 .73595 L .65353 .72521 L p F P
0 g
s
.65353 .72521 m .65046 .72188 L p .65365 .7283 L .707 .577 .707 r
F P
0 g
s
.66554 .75223 m .65353 .72521 L .65365 .7283 L .707 .577 .707 r
F
.6625 .7142 m .6587 .68103 L .65033 .67229 L p F P
0 g
s
.65033 .67229 m .6458 .66756 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.6625 .7142 m .65033 .67229 L .65077 .68144 L .707 .577 .707 r
F
.62857 .29055 m .64057 .468 L p .64491 .55872 L F P
0 g
s
.35515 .64238 m .35868 .69483 L .3656 .68157 L p .707 .577 .707 r
F P
0 g
s
.3656 .68157 m .36208 .62911 L .35515 .64238 L p .707 .577 .707 r
F P
0 g
s
.20354 .79038 m .19973 .75721 L .17848 .74717 L p .707 .577 .707 r
F P
0 g
s
.19973 .75721 m .20354 .79038 L .23106 .79601 L p .707 .577 .707 r
F P
0 g
s
.69639 .77318 m .69851 .78946 L .67721 .77903 L p .707 .577 .707 r
F P
0 g
s
.67721 .77903 m .6751 .76275 L .69639 .77318 L p .707 .577 .707 r
F P
0 g
s
.34276 .73747 m .34656 .77064 L .3625 .75546 L p .707 .577 .707 r
F P
0 g
s
.3625 .75546 m .3587 .72229 L .34276 .73747 L p .707 .577 .707 r
F P
0 g
s
.26526 .84386 m .26314 .82758 L .23205 .82705 L p .707 .577 .707 r
F P
0 g
s
.26314 .82758 m .26526 .84386 L .29685 .83911 L p .707 .577 .707 r
F P
0 g
s
.29685 .83911 m .29474 .82283 L .26314 .82758 L p .707 .577 .707 r
F P
0 g
s
.29474 .82283 m .29685 .83911 L .32586 .82954 L p .707 .577 .707 r
F P
0 g
s
.32586 .82954 m .32374 .81326 L .29474 .82283 L p .707 .577 .707 r
F P
0 g
s
.16154 .64824 m .16507 .7007 L .17777 .71209 L p .707 .577 .707 r
F P
0 g
s
.16507 .7007 m .16154 .64824 L .1585 .63528 L p .707 .577 .707 r
F P
0 g
s
.23417 .84333 m .23205 .82705 L .20451 .82129 L p .707 .577 .707 r
F P
0 g
s
.23205 .82705 m .23417 .84333 L .26526 .84386 L p .707 .577 .707 r
F P
0 g
s
.32374 .81326 m .32586 .82954 L .34944 .81609 L p .707 .577 .707 r
F P
0 g
s
.34944 .81609 m .34732 .79981 L .32374 .81326 L p .707 .577 .707 r
F P
0 g
s
.34117 .29933 m .37319 .77281 L .37749 .79114 L p .707 .577 .707 r
F P
0 g
s
.37319 .77281 m .34117 .29933 L .35094 .28057 L p .707 .577 .707 r
F P
0 g
s
.17848 .74717 m .18229 .78034 L .20354 .79038 L p .707 .577 .707 r
F P
0 g
s
.18229 .78034 m .17848 .74717 L .16559 .73369 L p .707 .577 .707 r
F P
0 g
s
.20451 .82129 m .20663 .83757 L .23417 .84333 L p .707 .577 .707 r
F P
0 g
s
.36208 .62911 m .3656 .68157 L .36256 .66861 L p .707 .577 .707 r
F P
0 g
s
.36256 .66861 m .35904 .61615 L .36208 .62911 L p .707 .577 .707 r
F P
0 g
s
.3587 .72229 m .3625 .75546 L .36916 .73929 L p .707 .577 .707 r
F P
0 g
s
.36916 .73929 m .36536 .70612 L .3587 .72229 L p .707 .577 .707 r
F P
0 g
s
.20663 .83757 m .20451 .82129 L .18322 .81086 L p .707 .577 .707 r
F P
0 g
s
.34732 .79981 m .34944 .81609 L .36528 .80007 L p .707 .577 .707 r
F P
0 g
s
.36528 .80007 m .36317 .78379 L .34732 .79981 L p .707 .577 .707 r
F P
0 g
s
.63836 .72959 m .60633 .25611 L .62427 .27222 L p .707 .577 .707 r
F P
0 g
s
.1585 .63528 m .16203 .68773 L .16507 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18322 .81086 m .18533 .82714 L .20663 .83757 L p .707 .577 .707 r
F P
0 g
s
.16559 .73369 m .16939 .76686 L .18229 .78034 L p .707 .577 .707 r
F P
0 g
s
.16203 .68773 m .1585 .63528 L .16542 .62201 L p .707 .577 .707 r
F P
0 g
s
.16939 .76686 m .16559 .73369 L .16231 .7181 L p .707 .577 .707 r
F P
0 g
s
.18533 .82714 m .18322 .81086 L .17025 .79679 L p .707 .577 .707 r
F P
0 g
s
.35904 .61615 m .36256 .66861 L .34986 .65722 L p .707 .577 .707 r
F P
0 g
s
.34986 .65722 m .34633 .60476 L .35904 .61615 L p .707 .577 .707 r
F P
0 g
s
.36536 .70612 m .36916 .73929 L .36589 .7237 L p .707 .577 .707 r
F P
0 g
s
.36589 .7237 m .36208 .69053 L .36536 .70612 L p .707 .577 .707 r
F P
0 g
s
.36317 .78379 m .36528 .80007 L .37184 .78306 L p .707 .577 .707 r
F P
0 g
s
.37184 .78306 m .36972 .76678 L .36317 .78379 L p .707 .577 .707 r
F P
0 g
s
.38297 .75405 m .35094 .28057 L .37382 .26321 L p .707 .577 .707 r
F P
0 g
s
.35094 .28057 m .38297 .75405 L .37319 .77281 L p .707 .577 .707 r
F P
0 g
s
.17025 .79679 m .17236 .81307 L .18533 .82714 L p .707 .577 .707 r
F P
0 g
s
.16542 .62201 m .16895 .67447 L .16203 .68773 L p .707 .577 .707 r
F P
0 g
s
.16231 .7181 m .16611 .75127 L .16939 .76686 L p .707 .577 .707 r
F P
0 g
s
.16895 .67447 m .16542 .62201 L .18163 .60974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.60633 .25611 m .63836 .72959 L .60853 .71728 L p .707 .577 .707 r
F P
0 g
s
.60853 .71728 m .5765 .2438 L .60633 .25611 L p .707 .577 .707 r
F P
0 g
s
.16611 .75127 m .16231 .7181 L .16897 .70193 L p .707 .577 .707 r
F P
0 g
s
.17236 .81307 m .17025 .79679 L .16688 .78044 L p .707 .577 .707 r
F P
0 g
s
.34633 .60476 m .34986 .65722 L .32873 .64851 L p .707 .577 .707 r
F P
0 g
s
.32873 .64851 m .3252 .59605 L .34633 .60476 L p .707 .577 .707 r
F P
0 g
s
.36208 .69053 m .36589 .7237 L .35299 .71022 L p .707 .577 .707 r
F P
0 g
s
.35299 .71022 m .34919 .67705 L .36208 .69053 L p .707 .577 .707 r
F P
0 g
s
.36972 .76678 m .37184 .78306 L .36847 .76672 L p .707 .577 .707 r
F P
0 g
s
.36847 .76672 m .36635 .75044 L .36972 .76678 L p .707 .577 .707 r
F P
0 g
s
.16688 .78044 m .16899 .79672 L .17236 .81307 L p .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .38297 .75405 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.38215 .38639 m .40585 .73669 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .37382 .26321 L .40757 .24896 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40585 .73669 L p .40643 .57268 L .707 .577 .707 r
F P
0 g
s
.40643 .57268 m .42334 .61922 L .4396 .72244 L .707 .577 .707 r
F
.43123 .59872 m .43473 .65055 L p .40664 .51311 L F P
0 g
s
.43473 .65055 m .4396 .72244 L p .42334 .61922 L .707 .577 .707 r
F P
0 g
s
.40664 .51311 m .43473 .65055 L .42334 .61922 L .707 .577 .707 r
F
.44889 .23921 m .48092 .71269 L .4396 .72244 L p F P
0 g
s
.46306 .71782 m .46095 .70154 L .45409 .7038 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40757 .24896 L .44889 .23921 L p .707 .577 .707 r
F P
0 g
s
.45409 .7038 m .43194 .71111 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.46306 .71782 m .45409 .7038 L .45886 .71691 L .707 .577 .707 r
F
.43194 .71111 m .43405 .72739 L .4596 .71896 L p F P
0 g
s
.4596 .71896 m .46306 .71782 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.45886 .71691 m .43194 .71111 L .4596 .71896 L .707 .577 .707 r
F
.40643 .57268 m .40664 .51311 L .42334 .61922 L F
.40757 .24896 m .43123 .59872 L p .40664 .51311 L F P
0 g
s
.42721 .65619 m .43101 .68936 L .45513 .68192 L p .707 .577 .707 r
F P
0 g
s
.45513 .68192 m .46009 .68038 L p .45324 .67534 L .707 .577 .707 r
F P
0 g
s
.45324 .67534 m .42721 .65619 L .45513 .68192 L .707 .577 .707 r
F
.39557 .66055 m .39937 .69372 L .42406 .69032 L p F P
0 g
s
.42406 .69032 m .43101 .68936 L p .42303 .68287 L .707 .577 .707 r
F P
0 g
s
.42303 .68287 m .39557 .66055 L .42406 .69032 L .707 .577 .707 r
F
.37382 .26321 m .38215 .38639 L p .37517 .33577 L F P
0 g
s
.18163 .60974 m .18516 .6622 L .16895 .67447 L p .707 .577 .707 r
F P
0 g
s
.16897 .70193 m .17277 .7351 L .16611 .75127 L p .707 .577 .707 r
F P
0 g
s
.18516 .6622 m .18163 .60974 L .20554 .59967 L p .707 .577 .707 r
F P
0 g
s
.17277 .7351 m .16897 .70193 L .18492 .68675 L p .707 .577 .707 r
F P
0 g
s
.3252 .59605 m .32873 .64851 L .30124 .64334 L p .707 .577 .707 r
F P
0 g
s
.30124 .64334 m .29772 .59088 L .3252 .59605 L p .707 .577 .707 r
F P
0 g
s
.16899 .79672 m .16688 .78044 L .17343 .76343 L p .707 .577 .707 r
F P
0 g
s
.5765 .2438 m .60853 .71728 L .56973 .70998 L p .707 .577 .707 r
F P
0 g
s
.56973 .70998 m .5377 .2365 L .5765 .2438 L p .707 .577 .707 r
F P
0 g
s
.34919 .67705 m .35299 .71022 L .33174 .70018 L p .707 .577 .707 r
F P
0 g
s
.33174 .70018 m .32794 .66701 L .34919 .67705 L p .707 .577 .707 r
F P
0 g
s
.36635 .75044 m .36847 .76672 L .3555 .75264 L p .707 .577 .707 r
F P
0 g
s
.3555 .75264 m .35339 .73636 L .36635 .75044 L p .707 .577 .707 r
F P
0 g
s
.20907 .65213 m .20554 .59967 L .23481 .59279 L p .707 .577 .707 r
F P
0 g
s
.20554 .59967 m .20907 .65213 L .18516 .6622 L p .707 .577 .707 r
F P
0 g
s
.17343 .76343 m .17555 .77971 L .16899 .79672 L p .707 .577 .707 r
F P
0 g
s
.29772 .59088 m .30124 .64334 L .2701 .64222 L p .707 .577 .707 r
F P
0 g
s
.2701 .64222 m .26657 .58976 L .29772 .59088 L p .707 .577 .707 r
F P
0 g
s
.18492 .68675 m .18872 .71992 L .17277 .7351 L p .707 .577 .707 r
F P
0 g
s
.23833 .64525 m .23481 .59279 L .26657 .58976 L p .707 .577 .707 r
F P
0 g
s
.23481 .59279 m .23833 .64525 L .20907 .65213 L p .707 .577 .707 r
F P
0 g
s
.18872 .71992 m .18492 .68675 L .20859 .67405 L p .707 .577 .707 r
F P
0 g
s
.26657 .58976 m .2701 .64222 L .23833 .64525 L p .707 .577 .707 r
F P
0 g
s
.5377 .2365 m .56973 .70998 L .52575 .7084 L p .707 .577 .707 r
F P
0 g
s
.52575 .7084 m .49373 .23492 L .5377 .2365 L p .707 .577 .707 r
F P
0 g
s
.17555 .77971 m .17343 .76343 L .18928 .74741 L p .707 .577 .707 r
F P
0 g
s
.32794 .66701 m .33174 .70018 L .30422 .69455 L p .707 .577 .707 r
F P
0 g
s
.30422 .69455 m .30041 .66138 L .32794 .66701 L p .707 .577 .707 r
F P
0 g
s
.48092 .71269 m .46251 .44063 L p .49373 .23492 L .707 .577 .707 r
F P
0 g
s
.49373 .23492 m .52575 .7084 L .48092 .71269 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .48376 .66769 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45629 .64722 m .45828 .66455 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45828 .66455 m .46009 .68038 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.46251 .44063 m .44889 .23921 L .46635 .23754 L p .707 .577 .707 r
F P
0 g
s
.46635 .23754 m .49373 .23492 L p .46251 .44063 L .707 .577 .707 r
F P
0 g
s
.35339 .73636 m .3555 .75264 L .3342 .74221 L p .707 .577 .707 r
F P
0 g
s
.3342 .74221 m .33209 .72593 L .35339 .73636 L p .707 .577 .707 r
F P
0 g
s
.73775 .66719 m .73422 .61473 L .70307 .61361 L p .707 .577 .707 r
F P
0 g
s
.73422 .61473 m .73775 .66719 L .76951 .66416 L p .707 .577 .707 r
F P
0 g
s
.76951 .66416 m .76598 .6117 L .73422 .61473 L p .707 .577 .707 r
F P
0 g
s
.76598 .6117 m .76951 .66416 L .79878 .65727 L p .707 .577 .707 r
F P
0 g
s
.79878 .65727 m .79525 .60482 L .76598 .6117 L p .707 .577 .707 r
F P
0 g
s
.18928 .74741 m .19139 .76369 L .17555 .77971 L p .707 .577 .707 r
F P
0 g
s
.21239 .70722 m .20859 .67405 L .23767 .66508 L p .707 .577 .707 r
F P
0 g
s
.20859 .67405 m .21239 .70722 L .18872 .71992 L p .707 .577 .707 r
F P
0 g
s
.7066 .66607 m .70307 .61361 L .67559 .60844 L p .707 .577 .707 r
F P
0 g
s
.70307 .61361 m .7066 .66607 L .73775 .66719 L p .707 .577 .707 r
F P
0 g
s
.30041 .66138 m .30422 .69455 L .27311 .69389 L p .707 .577 .707 r
F P
0 g
s
.27311 .69389 m .26931 .66072 L .30041 .66138 L p .707 .577 .707 r
F P
0 g
s
.79525 .60482 m .79878 .65727 L .82268 .6472 L p .707 .577 .707 r
F P
0 g
s
.82268 .6472 m .81916 .59475 L .79525 .60482 L p .707 .577 .707 r
F P
0 g
s
.24147 .69825 m .23767 .66508 L .26931 .66072 L p .707 .577 .707 r
F P
0 g
s
.23767 .66508 m .24147 .69825 L .21239 .70722 L p .707 .577 .707 r
F P
0 g
s
.19139 .76369 m .18928 .74741 L .21286 .73396 L p .707 .577 .707 r
F P
0 g
s
.26931 .66072 m .27311 .69389 L .24147 .69825 L p .707 .577 .707 r
F P
0 g
s
.33209 .72593 m .3342 .74221 L .30666 .73645 L p .707 .577 .707 r
F P
0 g
s
.30666 .73645 m .30455 .72017 L .33209 .72593 L p .707 .577 .707 r
F P
0 g
s
.67912 .6609 m .67559 .60844 L .65446 .59973 L p .707 .577 .707 r
F P
0 g
s
.67559 .60844 m .67912 .6609 L .7066 .66607 L p .707 .577 .707 r
F P
0 g
s
.21286 .73396 m .21497 .75024 L .19139 .76369 L p .707 .577 .707 r
F P
0 g
s
.81916 .59475 m .82268 .6472 L .83889 .63494 L p .707 .577 .707 r
F P
0 g
s
.83889 .63494 m .83537 .58248 L .81916 .59475 L p .707 .577 .707 r
F P
0 g
s
.21497 .75024 m .21286 .73396 L .24186 .72439 L p .707 .577 .707 r
F P
0 g
s
.74238 .73054 m .73858 .69737 L .70747 .69671 L p .707 .577 .707 r
F P
0 g
s
.73858 .69737 m .74238 .73054 L .77402 .72617 L p .707 .577 .707 r
F P
0 g
s
.77402 .72617 m .77022 .693 L .73858 .69737 L p .707 .577 .707 r
F P
0 g
s
.30455 .72017 m .30666 .73645 L .27557 .73592 L p .707 .577 .707 r
F P
0 g
s
.27557 .73592 m .27346 .71964 L .30455 .72017 L p .707 .577 .707 r
F P
0 g
s
.77022 .693 m .77402 .72617 L .8031 .7172 L p .707 .577 .707 r
F P
0 g
s
.8031 .7172 m .7993 .68403 L .77022 .693 L p .707 .577 .707 r
F P
0 g
s
.24398 .74067 m .24186 .72439 L .27346 .71964 L p .707 .577 .707 r
F P
0 g
s
.24186 .72439 m .24398 .74067 L .21497 .75024 L p .707 .577 .707 r
F P
0 g
s
.71127 .72987 m .70747 .69671 L .67995 .69108 L p .707 .577 .707 r
F P
0 g
s
.70747 .69671 m .71127 .72987 L .74238 .73054 L p .707 .577 .707 r
F P
0 g
s
.27346 .71964 m .27557 .73592 L .24398 .74067 L p .707 .577 .707 r
F P
0 g
s
.65799 .65219 m .65446 .59973 L .64175 .58834 L p .707 .577 .707 r
F P
0 g
s
.65446 .59973 m .65799 .65219 L .67912 .6609 L p .707 .577 .707 r
F P
0 g
s
.7993 .68403 m .8031 .7172 L .82677 .7045 L p .707 .577 .707 r
F P
0 g
s
.82677 .7045 m .82297 .67134 L .7993 .68403 L p .707 .577 .707 r
F P
0 g
s
.83537 .58248 m .83889 .63494 L .84582 .62167 L p .707 .577 .707 r
F P
0 g
s
.84582 .62167 m .84229 .56922 L .83537 .58248 L p .707 .577 .707 r
F P
0 g
s
.68375 .72425 m .67995 .69108 L .6587 .68103 L p .707 .577 .707 r
F P
0 g
s
.67995 .69108 m .68375 .72425 L .71127 .72987 L p .707 .577 .707 r
F P
0 g
s
.74547 .76896 m .74336 .75268 L .71227 .75214 L p .707 .577 .707 r
F P
0 g
s
.74336 .75268 m .74547 .76896 L .77706 .7642 L p .707 .577 .707 r
F P
0 g
s
.77706 .7642 m .77495 .74792 L .74336 .75268 L p .707 .577 .707 r
F P
0 g
s
.82297 .67134 m .82677 .7045 L .84272 .68933 L p .707 .577 .707 r
F P
0 g
s
.84272 .68933 m .83892 .65616 L .82297 .67134 L p .707 .577 .707 r
F P
0 g
s
.77495 .74792 m .77706 .7642 L .80607 .75463 L p .707 .577 .707 r
F P
0 g
s
.80607 .75463 m .80396 .73835 L .77495 .74792 L p .707 .577 .707 r
F P
0 g
s
.64175 .58834 m .64528 .6408 L .65799 .65219 L p .707 .577 .707 r
F P
0 g
s
.71438 .76842 m .71227 .75214 L .68473 .74638 L p .707 .577 .707 r
F P
0 g
s
.71227 .75214 m .71438 .76842 L .74547 .76896 L p .707 .577 .707 r
F P
0 g
s
.64528 .6408 m .64175 .58834 L .63871 .57538 L p .707 .577 .707 r
F P
0 g
s
.80396 .73835 m .80607 .75463 L .82965 .74118 L p .707 .577 .707 r
F P
0 g
s
.82965 .74118 m .82754 .7249 L .80396 .73835 L p .707 .577 .707 r
F P
0 g
s
.6587 .68103 m .6625 .7142 L .68375 .72425 L p .707 .577 .707 r
F P
0 g
s
.68473 .74638 m .68684 .76266 L .71438 .76842 L p .707 .577 .707 r
F P
0 g
s
.84229 .56922 m .84582 .62167 L .84278 .60871 L p .707 .577 .707 r
F P
0 g
s
.84278 .60871 m .83925 .55625 L .84229 .56922 L p .707 .577 .707 r
F P
0 g
s
.68684 .76266 m .68473 .74638 L .66343 .73595 L p .707 .577 .707 r
F P
0 g
s
.83892 .65616 m .84272 .68933 L .84938 .67315 L p .707 .577 .707 r
F P
0 g
s
.84938 .67315 m .84558 .63998 L .83892 .65616 L p .707 .577 .707 r
F P
0 g
s
.82754 .7249 m .82965 .74118 L .84549 .72517 L p .707 .577 .707 r
F P
0 g
s
.84549 .72517 m .84338 .70889 L .82754 .7249 L p .707 .577 .707 r
F P
0 g
s
.66343 .73595 m .66554 .75223 L .68684 .76266 L p .707 .577 .707 r
F P
0 g
s
.63871 .57538 m .64224 .62784 L .64528 .6408 L p .707 .577 .707 r
F P
0 g
s
.64224 .62784 m .63871 .57538 L .64563 .56212 L p .707 .577 .707 r
F P
0 g
s
.6496 .70073 m .6458 .66756 L .64252 .65197 L p .707 .577 .707 r
F P
0 g
s
.84338 .70889 m .84549 .72517 L .85205 .70815 L p .707 .577 .707 r
F P
0 g
s
.85205 .70815 m .84994 .69187 L .84338 .70889 L p .707 .577 .707 r
F P
0 g
s
.84558 .63998 m .84938 .67315 L .8461 .65756 L p .707 .577 .707 r
F P
0 g
s
.8461 .65756 m .8423 .62439 L .84558 .63998 L p .707 .577 .707 r
F P
0 g
s
.83925 .55625 m .84278 .60871 L .83007 .59732 L p .707 .577 .707 r
F P
0 g
s
.83007 .59732 m .82654 .54486 L .83925 .55625 L p .707 .577 .707 r
F P
0 g
s
.65046 .72188 m .65257 .73816 L .66554 .75223 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64252 .65197 m .64633 .68514 L .6496 .70073 L p .707 .577 .707 r
F P
0 g
s
.64563 .56212 m .64916 .61457 L .64224 .62784 L p .707 .577 .707 r
F P
0 g
s
.64916 .61457 m .64563 .56212 L .66184 .54985 L p .707 .577 .707 r
F P
0 g
s
.65257 .73816 m .65046 .72188 L .64709 .70553 L p .707 .577 .707 r
F P
0 g
s
.39474 .63037 m .39121 .57792 L .36006 .57679 L p .707 .577 .707 r
F P
0 g
s
.39121 .57792 m .39474 .63037 L .4265 .62735 L p .707 .577 .707 r
F P
0 g
s
.4265 .62735 m .42297 .57489 L .39121 .57792 L p .707 .577 .707 r
F P
0 g
s
.64633 .68514 m .64252 .65197 L .64918 .63579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42297 .57489 m .4265 .62735 L .45577 .62046 L p .707 .577 .707 r
F P
0 g
s
.45577 .62046 m .45224 .568 L .42297 .57489 L p .707 .577 .707 r
F P
0 g
s
.84994 .69187 m .85205 .70815 L .84868 .69181 L p .707 .577 .707 r
F P
0 g
s
.84868 .69181 m .84657 .67553 L .84994 .69187 L p .707 .577 .707 r
F P
0 g
s
.36359 .62925 m .36006 .57679 L .33258 .57162 L p .707 .577 .707 r
F P
0 g
s
.36006 .57679 m .36359 .62925 L .39474 .63037 L p .707 .577 .707 r
F P
0 g
s
.8423 .62439 m .8461 .65756 L .83321 .64409 L p .707 .577 .707 r
F P
0 g
s
.83321 .64409 m .8294 .61092 L .8423 .62439 L p .707 .577 .707 r
F P
0 g
s
.82654 .54486 m .83007 .59732 L .80894 .58861 L p .707 .577 .707 r
F P
0 g
s
.80894 .58861 m .80541 .53615 L .82654 .54486 L p .707 .577 .707 r
F P
0 g
s
.64709 .70553 m .6492 .72181 L .65257 .73816 L p .707 .577 .707 r
F P
0 g
s
.45224 .568 m .45577 .62046 L .47967 .61039 L p .707 .577 .707 r
F P
0 g
s
.47967 .61039 m .47615 .55793 L .45224 .568 L p .707 .577 .707 r
F P
0 g
s
.64918 .63579 m .65299 .66896 L .64633 .68514 L p .707 .577 .707 r
F P
0 g
s
.66184 .54985 m .66537 .60231 L .64916 .61457 L p .707 .577 .707 r
F P
0 g
s
.66537 .60231 m .66184 .54985 L .68575 .53978 L p .707 .577 .707 r
F P
0 g
s
.33611 .62408 m .33258 .57162 L .31145 .56292 L p .707 .577 .707 r
F P
0 g
s
.33258 .57162 m .33611 .62408 L .36359 .62925 L p .707 .577 .707 r
F P
0 g
s
.65299 .66896 m .64918 .63579 L .66513 .62062 L p .707 .577 .707 r
F P
0 g
s
.6492 .72181 m .64709 .70553 L .65365 .68852 L p .707 .577 .707 r
F P
0 g
s
.80541 .53615 m .80894 .58861 L .78146 .58344 L p .707 .577 .707 r
F P
0 g
s
.78146 .58344 m .77793 .53099 L .80541 .53615 L p .707 .577 .707 r
F P
0 g
s
.47615 .55793 m .47967 .61039 L .49588 .59812 L p .707 .577 .707 r
F P
0 g
s
.49588 .59812 m .49236 .54566 L .47615 .55793 L p .707 .577 .707 r
F P
0 g
s
.84657 .67553 m .84868 .69181 L .83571 .67773 L p .707 .577 .707 r
F P
0 g
s
.83571 .67773 m .8336 .66145 L .84657 .67553 L p .707 .577 .707 r
F P
0 g
s
.8294 .61092 m .83321 .64409 L .81196 .63404 L p .707 .577 .707 r
F P
0 g
s
.81196 .63404 m .80815 .60087 L .8294 .61092 L p .707 .577 .707 r
F P
0 g
s
.39937 .69372 m .39557 .66055 L .36446 .65989 L p .707 .577 .707 r
F P
0 g
s
.43101 .68936 m .42721 .65619 L .39557 .66055 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .45629 .64722 L .42721 .65619 L p .707 .577 .707 r
F P
0 g
s
.65365 .68852 m .65576 .7048 L .6492 .72181 L p .707 .577 .707 r
F P
0 g
s
.68928 .59224 m .68575 .53978 L .71502 .53289 L p .707 .577 .707 r
F P
0 g
s
.68575 .53978 m .68928 .59224 L .66537 .60231 L p .707 .577 .707 r
F P
0 g
s
.36826 .69306 m .36446 .65989 L .33694 .65426 L p .707 .577 .707 r
F P
0 g
s
.36446 .65989 m .36826 .69306 L .39937 .69372 L p .707 .577 .707 r
F P
0 g
s
.31498 .61538 m .31145 .56292 L .29874 .55153 L p .707 .577 .707 r
F P
0 g
s
.31145 .56292 m .31498 .61538 L .33611 .62408 L p .707 .577 .707 r
F P
0 g
s
.48376 .66769 m .47996 .63452 L .45629 .64722 L p .707 .577 .707 r
F P
0 g
s
.66513 .62062 m .66893 .65378 L .65299 .66896 L p .707 .577 .707 r
F P
0 g
s
.77793 .53099 m .78146 .58344 L .75031 .58232 L p .707 .577 .707 r
F P
0 g
s
.75031 .58232 m .74678 .52986 L .77793 .53099 L p .707 .577 .707 r
F P
0 g
s
.66893 .65378 m .66513 .62062 L .6888 .60792 L p .707 .577 .707 r
F P
0 g
s
.71855 .58535 m .71502 .53289 L .74678 .52986 L p .707 .577 .707 r
F P
0 g
s
.71502 .53289 m .71855 .58535 L .68928 .59224 L p .707 .577 .707 r
F P
0 g
s
.65576 .7048 m .65365 .68852 L .66949 .67251 L p .707 .577 .707 r
F P
0 g
s
.74678 .52986 m .75031 .58232 L .71855 .58535 L p .707 .577 .707 r
F P
0 g
s
.80815 .60087 m .81196 .63404 L .78443 .62841 L p .707 .577 .707 r
F P
0 g
s
.78443 .62841 m .78063 .59524 L .80815 .60087 L p .707 .577 .707 r
F P
0 g
s
.49236 .54566 m .49588 .59812 L .50281 .58486 L p .707 .577 .707 r
F P
0 g
s
.50281 .58486 m .49928 .5324 L .49236 .54566 L p .707 .577 .707 r
F P
0 g
s
.34074 .68743 m .33694 .65426 L .31569 .64422 L p .707 .577 .707 r
F P
0 g
s
.33694 .65426 m .34074 .68743 L .36826 .69306 L p .707 .577 .707 r
F P
0 g
s
.8336 .66145 m .83571 .67773 L .81442 .6673 L p .707 .577 .707 r
F P
0 g
s
.81442 .6673 m .8123 .65102 L .8336 .66145 L p .707 .577 .707 r
F P
0 g
s
.40246 .73214 m .40035 .71586 L .36926 .71533 L p .707 .577 .707 r
F P
0 g
s
.40035 .71586 m .40246 .73214 L .43405 .72739 L p .707 .577 .707 r
F P
0 g
s
.43405 .72739 m .43194 .71111 L .40035 .71586 L p .707 .577 .707 r
F P
0 g
s
.47996 .63452 m .48376 .66769 L .49971 .65251 L p .707 .577 .707 r
F P
0 g
s
.49971 .65251 m .49591 .61934 L .47996 .63452 L p .707 .577 .707 r
F P
0 g
s
.66949 .67251 m .67161 .68879 L .65576 .7048 L p .707 .577 .707 r
F P
0 g
s
.6926 .64109 m .6888 .60792 L .71788 .59895 L p .707 .577 .707 r
F P
0 g
s
.6888 .60792 m .6926 .64109 L .66893 .65378 L p .707 .577 .707 r
F P
0 g
s
.29874 .55153 m .30227 .60398 L .31498 .61538 L p .707 .577 .707 r
F P
0 g
s
.37137 .73161 m .36926 .71533 L .34172 .70957 L p .707 .577 .707 r
F P
0 g
s
.36926 .71533 m .37137 .73161 L .40246 .73214 L p .707 .577 .707 r
F P
0 g
s
.78063 .59524 m .78443 .62841 L .75332 .62775 L p .707 .577 .707 r
F P
0 g
s
.75332 .62775 m .74952 .59458 L .78063 .59524 L p .707 .577 .707 r
F P
0 g
s
.30227 .60398 m .29874 .55153 L .2957 .53856 L p .707 .577 .707 r
F P
0 g
s
.46095 .70154 m .46306 .71782 L .48664 .70437 L p .707 .577 .707 r
F P
0 g
s
.48664 .70437 m .48453 .68809 L .46095 .70154 L p .707 .577 .707 r
F P
0 g
s
.67161 .68879 m .66949 .67251 L .69307 .65905 L p .707 .577 .707 r
F P
0 g
s
.31569 .64422 m .31949 .67739 L .34074 .68743 L p .707 .577 .707 r
F P
0 g
s
.72168 .63212 m .71788 .59895 L .74952 .59458 L p .707 .577 .707 r
F P
0 g
s
.71788 .59895 m .72168 .63212 L .6926 .64109 L p .707 .577 .707 r
F P
0 g
s
.74952 .59458 m .75332 .62775 L .72168 .63212 L p .707 .577 .707 r
F P
0 g
s
.31949 .67739 m .31569 .64422 L .30279 .63074 L p .707 .577 .707 r
F P
0 g
s
.34172 .70957 m .34383 .72585 L .37137 .73161 L p .707 .577 .707 r
F P
0 g
s
.8123 .65102 m .81442 .6673 L .78688 .66154 L p .707 .577 .707 r
F P
0 g
s
.78688 .66154 m .78476 .64526 L .8123 .65102 L p .707 .577 .707 r
F P
0 g
s
.49928 .5324 m .50281 .58486 L .49977 .57189 L p .707 .577 .707 r
F P
0 g
s
.49977 .57189 m .49624 .51944 L .49928 .5324 L p .707 .577 .707 r
F P
0 g
s
.34383 .72585 m .34172 .70957 L .32042 .69914 L p .707 .577 .707 r
F P
0 g
s
.69307 .65905 m .69519 .67533 L .67161 .68879 L p .707 .577 .707 r
F P
0 g
s
.49591 .61934 m .49971 .65251 L .50637 .63634 L p .707 .577 .707 r
F P
0 g
s
.50637 .63634 m .50257 .60317 L .49591 .61934 L p .707 .577 .707 r
F P
0 g
s
.48453 .68809 m .48664 .70437 L .50248 .68835 L p .707 .577 .707 r
F P
0 g
s
.50248 .68835 m .50037 .67207 L .48453 .68809 L p .707 .577 .707 r
F P
0 g
s
.69519 .67533 m .69307 .65905 L .72208 .64948 L p .707 .577 .707 r
F P
0 g
s
.32042 .69914 m .32253 .71542 L .34383 .72585 L p .707 .577 .707 r
F P
0 g
s
.2957 .53856 m .29923 .59102 L .30227 .60398 L p .707 .577 .707 r
F P
0 g
s
.78476 .64526 m .78688 .66154 L .75579 .66101 L p .707 .577 .707 r
F P
0 g
s
.75579 .66101 m .75367 .64473 L .78476 .64526 L p .707 .577 .707 r
F P
0 g
s
.30279 .63074 m .30659 .66391 L .31949 .67739 L p .707 .577 .707 r
F P
0 g
s
.29923 .59102 m .2957 .53856 L .30262 .5253 L p .707 .577 .707 r
F P
0 g
s
.72419 .66576 m .72208 .64948 L .75367 .64473 L p .707 .577 .707 r
F P
0 g
s
.72208 .64948 m .72419 .66576 L .69519 .67533 L p .707 .577 .707 r
F P
0 g
s
.75367 .64473 m .75579 .66101 L .72419 .66576 L p .707 .577 .707 r
F P
0 g
s
.30659 .66391 m .30279 .63074 L .29951 .61515 L p .707 .577 .707 r
F P
0 g
s
.32253 .71542 m .32042 .69914 L .30745 .68506 L p .707 .577 .707 r
F P
0 g
s
.50037 .67207 m .50248 .68835 L .50904 .67134 L p .707 .577 .707 r
F P
0 g
s
.50904 .67134 m .50693 .65506 L .50037 .67207 L p .707 .577 .707 r
F P
0 g
s
.50257 .60317 m .50637 .63634 L .50309 .62075 L p .707 .577 .707 r
F P
0 g
s
.50309 .62075 m .49929 .58758 L .50257 .60317 L p .707 .577 .707 r
F P
0 g
s
.49624 .51944 m .49977 .57189 L .48706 .5605 L p .707 .577 .707 r
F P
0 g
s
.48706 .5605 m .48353 .50805 L .49624 .51944 L p .707 .577 .707 r
F P
0 g
s
.30745 .68506 m .30956 .70134 L .32253 .71542 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29951 .61515 m .30331 .64832 L .30659 .66391 L p .707 .577 .707 r
F P
0 g
s
.30262 .5253 m .30615 .57776 L .29923 .59102 L p .707 .577 .707 r
F P
0 g
s
.30615 .57776 m .30262 .5253 L .31883 .51303 L p .707 .577 .707 r
F P
0 g
s
.30956 .70134 m .30745 .68506 L .30408 .66872 L p .707 .577 .707 r
F P
0 g
s
.30331 .64832 m .29951 .61515 L .30617 .59898 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50693 .65506 m .50904 .67134 L .50567 .65499 L p .707 .577 .707 r
F P
0 g
s
.50567 .65499 m .50356 .63871 L .50693 .65506 L p .707 .577 .707 r
F P
0 g
s
.49929 .58758 m .50309 .62075 L .49019 .60727 L p .707 .577 .707 r
F P
0 g
s
.49019 .60727 m .48639 .5741 L .49929 .58758 L p .707 .577 .707 r
F P
0 g
s
.48353 .50805 m .48706 .5605 L .46593 .5518 L p .707 .577 .707 r
F P
0 g
s
.46593 .5518 m .4624 .49934 L .48353 .50805 L p .707 .577 .707 r
F P
0 g
s
.30408 .66872 m .30619 .685 L .30956 .70134 L p .707 .577 .707 r
F P
0 g
s
.30617 .59898 m .30998 .63215 L .30331 .64832 L p .707 .577 .707 r
F P
0 g
s
.31883 .51303 m .32236 .56549 L .30615 .57776 L p .707 .577 .707 r
F P
0 g
s
.32236 .56549 m .31883 .51303 L .34274 .50296 L p .707 .577 .707 r
F P
0 g
s
.30998 .63215 m .30617 .59898 L .32212 .5838 L p .707 .577 .707 r
F P
0 g
s
.30619 .685 m .30408 .66872 L .31064 .65171 L p .707 .577 .707 r
F P
0 g
s
.4624 .49934 m .46593 .5518 L .43845 .54663 L p .707 .577 .707 r
F P
0 g
s
.43845 .54663 m .43492 .49417 L .4624 .49934 L p .707 .577 .707 r
F P
0 g
s
.50356 .63871 m .50567 .65499 L .4927 .64092 L p .707 .577 .707 r
F P
0 g
s
.4927 .64092 m .49059 .62464 L .50356 .63871 L p .707 .577 .707 r
F P
0 g
s
.48639 .5741 m .49019 .60727 L .46894 .59723 L p .707 .577 .707 r
F P
0 g
s
.46894 .59723 m .46514 .56406 L .48639 .5741 L p .707 .577 .707 r
F P
0 g
s
.31064 .65171 m .31275 .66799 L .30619 .685 L p .707 .577 .707 r
F P
0 g
s
.34627 .55542 m .34274 .50296 L .37201 .49608 L p .707 .577 .707 r
F P
0 g
s
.34274 .50296 m .34627 .55542 L .32236 .56549 L p .707 .577 .707 r
F P
0 g
s
.32212 .5838 m .32592 .61697 L .30998 .63215 L p .707 .577 .707 r
F P
0 g
s
.43492 .49417 m .43845 .54663 L .4073 .5455 L p .707 .577 .707 r
F P
0 g
s
.4073 .5455 m .40377 .49305 L .43492 .49417 L p .707 .577 .707 r
F P
0 g
s
.32592 .61697 m .32212 .5838 L .34579 .5711 L p .707 .577 .707 r
F P
0 g
s
.37554 .54853 m .37201 .49608 L .40377 .49305 L p .707 .577 .707 r
F P
0 g
s
.37201 .49608 m .37554 .54853 L .34627 .55542 L p .707 .577 .707 r
F P
0 g
s
.31275 .66799 m .31064 .65171 L .32648 .63569 L p .707 .577 .707 r
F P
0 g
s
.40377 .49305 m .4073 .5455 L .37554 .54853 L p .707 .577 .707 r
F P
0 g
s
.46514 .56406 m .46894 .59723 L .44142 .5916 L p .707 .577 .707 r
F P
0 g
s
.44142 .5916 m .43762 .55843 L .46514 .56406 L p .707 .577 .707 r
F P
0 g
s
.49059 .62464 m .4927 .64092 L .47141 .63049 L p .707 .577 .707 r
F P
0 g
s
.47141 .63049 m .46929 .61421 L .49059 .62464 L p .707 .577 .707 r
F P
0 g
s
.32648 .63569 m .3286 .65197 L .31275 .66799 L p .707 .577 .707 r
F P
0 g
s
.34959 .60427 m .34579 .5711 L .37487 .56213 L p .707 .577 .707 r
F P
0 g
s
.34579 .5711 m .34959 .60427 L .32592 .61697 L p .707 .577 .707 r
F P
0 g
s
.43762 .55843 m .44142 .5916 L .41031 .59093 L p .707 .577 .707 r
F P
0 g
s
.41031 .59093 m .40651 .55777 L .43762 .55843 L p .707 .577 .707 r
F P
0 g
s
.3286 .65197 m .32648 .63569 L .35006 .62224 L p .707 .577 .707 r
F P
0 g
s
.37867 .5953 m .37487 .56213 L .40651 .55777 L p .707 .577 .707 r
F P
0 g
s
.37487 .56213 m .37867 .5953 L .34959 .60427 L p .707 .577 .707 r
F P
0 g
s
.40651 .55777 m .41031 .59093 L .37867 .5953 L p .707 .577 .707 r
F P
0 g
s
.46929 .61421 m .47141 .63049 L .44386 .62473 L p .707 .577 .707 r
F P
0 g
s
.44386 .62473 m .44175 .60845 L .46929 .61421 L p .707 .577 .707 r
F P
0 g
s
.35006 .62224 m .35217 .63852 L .3286 .65197 L p .707 .577 .707 r
F P
0 g
s
.35217 .63852 m .35006 .62224 L .37907 .61267 L p .707 .577 .707 r
F P
0 g
s
.44175 .60845 m .44386 .62473 L .41278 .6242 L p .707 .577 .707 r
F P
0 g
s
.41278 .6242 m .41066 .60792 L .44175 .60845 L p .707 .577 .707 r
F P
0 g
s
.38118 .62895 m .37907 .61267 L .41066 .60792 L p .707 .577 .707 r
F P
0 g
s
.37907 .61267 m .38118 .62895 L .35217 .63852 L p .707 .577 .707 r
F P
0 g
s
.41066 .60792 m .41278 .6242 L .38118 .62895 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00RGoo2@00Rgoo0022Ool70003FUH00`00
FUIJEP03FUH90022Ool007eoo`D000YJEP03001JEUYF00UJEP03001JEUYF00H007aoo`00Mgoo1P00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000N7oo001bOol50008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001eOol0071oo`800003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0079o
o`00KWoo0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00L7oo001/Ool20005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001_Ool006Yoo`8000MJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0006ioo`00
J7oo0`0025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUH006eoo`00Igoo00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH0001/Ool006Io
o`05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1YOol006Aoo`8000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEV]oo`00Hgoo00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
Jgoo001ROol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0069oo`8000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00HGoo00<005YF00001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0J7oo001QOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0
061oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061o
o`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061oo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065o
o`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Moo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP8000aJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00Igoo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001W
Ool006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00Hgoo00@005YFFUH0
00IJEP8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH3001VOol006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`00IWoo001SOol01000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF3`001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIVOol006Aoo`03001JEUYF
00L000AJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0006Eoo`00H7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP<006Eoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001IOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001HOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001GOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOol90014Ool0
05Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000AOol70004FUH00`00FUIJEP02FUH8000lOol005Ao
o`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1@00=goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0027oo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Ioo`80009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@002EYF00<005YFFUH015YF1@00
1EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUH0000`Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP03FUH6
00000eYF001JEP05FUH20008FUH00`00FUIJEP09FUH20003FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000_Ool005Aoo`04001JEUYF0003FUH01000FUIJEUYF0P0017oo00@005YFFUH000IJEPl000MJEP@0
0003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00@005YFFUH000=JEP04001J
EP000007Ool00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUH000030002FUH200000eYF001J
EP020003FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003FUH20009Ool30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH01@00FUIJEUYF00000UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo001DOol2000015YF001JEUYF0`001goo0`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool0
05Aoo`800004FUH005YF0003FUH30002Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020002FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ao
o`800003FUH0000000EJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo
00@005YF000000EJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol2
00000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPl000EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP05001J
EUYFFUH0000]Ool004Moo`T000Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001J
EUYF00=JEP03001JEUYF00@001Yoo`<000AJEP05001JEUYFFUH0000]Ool0045oo`H000AJEP03001J
EUYF009JEPH000=JEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH3000QOol300000eYF001JEP02FUH00`00Oomo
o`0[Ool003eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP80009JEP04001JEUYF0007FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP06FUH50005FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP8000io
oa0000Moo`04001JEP000003FUH2000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH01000FUH000002Goo1`0015YF00<0
05YFFUH01EYF00@005YFFUIJEPP000=JEP03001JEUYF008002aoo`00=goo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<005YFFUH015YF100025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0P001goo10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF100015YF00@005YF000002aoo`00=Goo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00IJEP03001JEP0000L000MJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF100017oo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P000eYF1000;7oo
000cOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03
FUH00`00FUIJEP020006FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH90005FUH20003FUH0
0`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0
0`0015YF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0`00;7oo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP03FUH40007FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
1UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00P005YFFUH0
05YF001JEP001EYF00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP800004FUH00000000/Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH4
00000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH01000FUH000000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YFFUIJEP80
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEP00001JEP00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP<00003FUH005YF009JEP<000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00H005YFFUH005YF000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`0025YF00<005YFFUH00UYF3`001UYF00@0
05YFFUIJEP<0009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP020002FUH01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YF0000
009JEP03001JEUYF00EJEPL000=JEPL000AJEP@0009JEP03001JEUYF009JEP80009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF0P001EYF00<005YFFUH00UYF0P0000=JEP0000001`001EYF00<005YF
FUH01eYF0`0015YF00D005YF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEPH000MJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF009J
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEPD000MJEP03001JEUYF00YJEP8000=J
EP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH4
0005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP8000MJEP@0009JEP04001JEUYFFUH50007FUH0
0`00FUIJEP09FUH500001EYF001JEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00=JEP03001JEP00008000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ400004FUH005YF0005FUH20002FUH2
0002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP020002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH6000>Ool00`00FUIJEP020002FUH00`00FUIJEP0200000eYF001JEP02FUH0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP04
001JEUYFFUH20004FUH00`00FUIJEP06FUH@0002FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0Z
Ool002eoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000DOol200000eYF001JEP02
FUH30003FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYF001JEP001EYF00@005YF000000IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030003FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<0
05YFFUH00eYF10002Woo0`002goo0`0015YF00<007oo00000P0000=JEP00FUH00UYF00@005YFFUH0
00IJEP03001JEUYF00MJEPD00003FUH005YF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00005FUH200000eYF001JEP05FUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006Ool3000/Ool002eoo`04001JEUYF
0003FUH01000FUIJEUYF0P003Goo1@002Woo0`000eYF00<005YF00001@000eYF0P0000=JEP00FUH0
1EYF00@005YFFUIJEPL000EJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP<00003FUH005YF
00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Eoo`03001JEP00
02aoo`00;Goo00@005YFFUH000=JEP04001JEP00000?Ool:0006Ool200000eYF00000003FUH01000
FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF0000009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP07001JEUYF001JEP00FUH0
0`0000=JEP0000001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF00<005YFFUH00P000Woo
0P0000=JEP000000:goo000]Ool200000eYF001JEP02FUH2000@Ool40002FUH00`00FUIJEP02FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH2
0004FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00002FUH01000FUIJEUYF0`0025YF00<005YFFUH010000UYF3@0015YF00@005YFFUIJEP80
0003FUH005YF008002]oo`00;Goo0P0000AJEP00FUIJEP<000aoo`@000IJEP03001JEUYF00IJEP80
0004FUH005YF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUH00002FUH20003FUH01000FUIJEP000UYF00<005YFFUH01EYF2P003Goo1@00
15YF0`000UYF00<007ooOol0:Goo000]Ool2000015YF000000000eYF1@000goo100000=JEP00FUH0
1eYF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEP0000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0`0015YF00<005YFFUH00UYF
0P0017oo1@004goo0P000UYF00<005YF00000UYF00<007ooOol0:Goo000]Ool200000eYF00000005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00000000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000IJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00AJEP03001JEUYF00AJEP03001JEP00008000Ioo`D0019oo`D00006FUH005YF001JEP00:goo000^
Ool200000eYF001JEP04FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH20005FUH50007Ool5000AOol01000FUIJEP000UYF0P000UYF0P00:goo
000^Ool200000eYF001JEP04FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP03FUH30004
FUH01000FUIJEUYF0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUH000=JEP800003FUH005YF009JEP<000=JEP03001oogoo00Ioo`<0011oo`8000=J
EP03001JEUYF009JEP03001JEP0002aoo`00;Woo00@005YFFUH000=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP800003FUH005YF00IJEP03001JEUYF00=JEPD0
00MJEP04001JEUYFFUH20007FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00@005YFFUH0009JEP06001JEUYFFUH005YF0P000UYF00D005YF
FUIJEP0001Uoo`8000EJEP03001JEUYF00=JEP8002aoo`00;Woo00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30005FUH40006FUH00`00FUIJEP03FUH5
0007FUH01000FUH000002UYF0P0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00`0015YF0`000eYF00D005YFFUIJEP0001Ioo`<00003FUH005YF
00AJEP03001JEUYF00=JEP<002]oo`00;Woo00@005YFFUIJEP<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH50002FUH7000;FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`0AOol3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Ool0000[Ool002ioo`07001JEUYFFUH005YF
00001eYF00<005YFFUH01EYF00<005YFFUH00UYF400000=JEP00FUH00UYF00<005YFFUH00eYF00<0
05YF00003P001UYF00<005YFFUH025YF00@005YFFUH0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02FUH00`00FUH0
000300000eYF0000000<Ool60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000Woo00<007ooOol0
:Goo000^Ool01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH015YF1P002EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEP00Ool00002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH20004FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP03FUH?0004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000Woo0P00:goo000^Ool00`00FUH00003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05
0004FUH01@00FUIJEP00Ool00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH015YF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000Aoo`03001JEP0002Yoo`00;goo0P0015YF00<005YFFUH015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF1@0000UJEP00FUIJEP00Ool0
05YF00001UYF00<005YFFUH01eYF00@005YFFUIJEP@000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo009o
o`04001JEUYF000ZOol002moo`8000AJEP03001JEUYF00=JEP<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEPD0009JEP05001oo`00FUH00006FUH00`00FUIJ
EP07FUH40003FUH00`00FUIJEP02FUH20005FUHE0008FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001Goo00@005YFFUH002Yoo`00;goo0P0015YF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEP0000@00004Ool005YF000:
FUH60007FUH00`00FUIJEP09000<FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP06FUH01000FUH0
05YF10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000000Ioo`80009JEP03001oogoo02Qoo`00;Woo00<005YF000015YF00@005YF000000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP03001JEUYF00=JEPl000AJEP03
001JEUYF00IJEP@000MJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH40007FUH00`00
FUIJEP0300000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP05
FUH30007Ool01@00FUH005YF0000:goo000^Ool00`00FUH00004FUH50006FUH00`00FUIJEP06FUH@
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP030003
FUH300000eYF001JEP06FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP02FUH2000:Ool00`00FUIJ
EP02000[Ool002ioo`04001JEUYF0002FUH00`00Oomoo`03Ool40002FUH00`00FUIJEP060004FUH0
0`00FUIJEP06FUH00`00FUH000030002Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH01P00FUIJEP00FUH000AJEP03001JEP00008000IJEP03001JEUYF00=JEPD000MJEP03001JEP00
008000]oo`05001JEUYFFUH0000/Ool002ioo`06001JEUYF001JEP002Woo1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0000Aoo`00000000IJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP<0
0004FUH005YFFUH30004FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH50003FUH6000<Ool2
0004FUH00`00Oomoo`0ZOol002ioo`06001JEUYF001JEP002Woo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF0`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH0100025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH00P00
0UYF00<005YF000015YF00<005YFFUH00UYF00@005YFFUIJEQ00011oo`800003FUH005YF009JEP03
001oogoo02]oo`00;Woo00<005YFFUH00P002Goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00P000eYF4@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH00UYF00D005YFFUH005YF0080009JEP03001JEUYF
00=JEP04001JEUYF000MOol20003FUH01000FUH00000;Woo000_Ool00`00FUH00008Ool30008FUH0
0`00FUIJEP02FUH?0006FUH01000FUIJEUYF0P0000=JEP00FUH00P002EYF0P0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF10001EYF00<005YFFUH00P006Goo0`001EYF0P00<7oo000_Ool20007Ool20002
FUH00`00FUIJEP05FUH6000?Ool40002FUH00`00FUIJEP02FUH300000eYF00000007FUH20003FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH200000eYF001JEP0300000eYF00000003FUH00`00FUIJEP02000GOol200000eYF
001JEP05FUH00`00Oomoo`0_Ool002moo`<000Aoo`8000EJEP03001JEUYF009JEP8001Uoo`<000AJ
EP04001JEP00FUH20006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030002FUH20000
1EYF000005YF00000UYF0P0057oo0`000eYF00<005YFFUH00UYF0P00<Woo000_Ool01000FUIJEP00
0Woo00<005YFFUH01EYF00<005YF00000P006Goo0P000eYF0P000eYF00D005YF001oo`0000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00@000=JEPD000=JEP03001oogoo00ioo`@000MJ
EP04001JEUYF000dOol002moo`03001JEUYF00@000MJEP8001Yoo`8000IJEP<00006FUH005YFFUH0
07oo0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0100015YF00@005YFFUIJEPT000Moo`@0009J
EP03001JEUYF00IJEP<003Eoo`00;goo0P0000EJEP00001JEP0000EJEP8001Qoo`@00003FUH005YF
00EJEP03001JEUYF0080009JEP05001ooeYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP060002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH2000g
Ool002moo`800003FUH00000009JEP03001JEUYF00<001Aoo`D000EJEP03001JEUYF00EJEP08001J
EUYFFUH005YF001oo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0017oo0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00>Goo000`Ool00`00
FUH00003FUH30003FUH90007Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
00001EYF000005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH01@000Woo0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00?7oo000`Ool20004FUH00`00FUH0
0007FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002Ool3
00000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000eYF0`000goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?goo000`Ool20003FUH01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0017oo10000eYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00`000UYF00<005YF00003P00
AGoo000`Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0005FUH01000FUIJEUYF0P0000EJEP00FUIJEP00059oo`00;goo00<005YF00000P001EYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@000]JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00=JEPH0009JEP03001JEUYF009JEP<0009JEP03001oogoo051oo`00;goo00D005YF001o
o`0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000MJEP03001JEUYF00EJEP04001JEP000008
Ool00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004Ool30004FUH01P00FUH00000FUH0059oo`00
;goo00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF1@001eYF00<005YFFUH0
15YF0`002Woo00D005YF001oo`0000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00=JEP03001oogoo00=o
o`800003FUH0000000=JEP04001JEP00001COol002moo`03001JEP0000Aoo`800003FUH005YF00IJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF009JEP8000aoo`800004FUH007oo0004FUH00`00FUIJ
EP04FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP02FUH01000Oomoogoo0`001EYF0P0000EJEP00FUIJEP0005=oo`00<7oo00<0
07ooOol01Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003Goo00@005YF
0000009oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP06001JEUYFFUH007oo0`0000=JEP00FUH01EYF
00@005YF0000009JEP03001oogoo055oo`00<7oo00<007ooOol027oo10000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P003goo00<005YFFUH00P000goo00D005YFFUIJEP00015JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000Dgoo000`Ool00`00Oomoo`0<Ool@000DOol01@00FUIJEUYF0000
1Goo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP<000MJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`1AOol0
031oo`80031oo`03001JEUYF009JEP03001oogoo00Aoo`03001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP<000QJEP03001JEUYF
00EJEP03001JEP00009oo`80059oo`00<7oo00<005YF0000;Goo0`000eYF00<007ooOol01Woo0P00
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P000UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0017oo00<007ooOol0D7oo000aOol00`00
FUH0000[Ool01000FUIJEP000UYF00<007ooOol027oo00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001oogoo00=oo`03001oogoo051oo`00<Goo00@005YFFUH002Qoo`8000AJ
EP03001JEP0000]oo`8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`80059oo`00
<Goo00<005YFFUH00`008goo0`001UYF0P003Woo0P000eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF1`001UYF00<005YFFUH01UYF00<005YFFUH00P001goo00<0
05YF0000DGoo000bOol00`00FUH00002FUH2000MOol40002FUH00`00FUIJEP03FUH2000AOol20000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH40002FUH50006FUH0
0`00FUIJEP06FUH30008Ool01000FUIJEP00DGoo000bOol00`00FUH00004FUH3000EOol50006FUH0
1000FUIJEUYF0P005Goo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF000010001EYF
1@001eYF00<005YFFUH015YF0P002Woo00@005YFFUH0055oo`00<goo0P001EYF00<005YF00000`00
3Goo10000UYF00<005YFFUH01UYF00@005YF000001]oo`H0009JEP03001JEUYF00YJEP03001JEUYF
00AJEPP000AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00@000]oo`800003FUH007oo055oo`00
=7oo00<005YFFUH00eYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0`008goo5P000goo1@00
15YF00<005YFFUH01UYF00<005YFFUH00UYF1`003Woo00D005YF001JEP00059oo`00=Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00=Woo00<007oo
Ool02goo4P0057oo00D005YFFUIJEP0005=oo`00=goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000P00>7oo00<007ooOol0<7oo00<005YFFUH00UYF00<007ooOol0
DGoo000iOol50004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000kOol2000_Ool30003FUH00`00
Oomoo`1BOol003iooa80045oo`03001JEP0002aoo`80009JEP04001JEUYF001EOol0099oo`03001J
EP0002Uoo`8000AJEP03001JEP0005Ioo`00TWoo00<005YFFUH00P009Goo0P001UYF0P00Egoo002C
Ool01000FUH005YF0`0087oo0P0000=JEP00FUH01EYF00<007ooOol0EWoo002DOol20004FUH3000J
Ool30003FUH00`00FUIJEP02FUH2001IOol009Eoo`8000AJEP03001JEP0000<0011oo`H000MJEP04
001JEUYF001KOol009Ioo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP<0
05aoo`00Ugoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P00GWoo002IOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH3001POol009]oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006=o
o`00WWoo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00IWoo002ROol?001/Ool00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60054 .7639 m .59701 .71144 L .56587 .71032 L p .707 .577 .707 r
F P
0 g
s
.59701 .71144 m .60054 .7639 L .6323 .76087 L p .707 .577 .707 r
F P
0 g
s
.6323 .76087 m .62878 .70841 L .59701 .71144 L p .707 .577 .707 r
F P
0 g
s
.62878 .70841 m .6323 .76087 L .66157 .75399 L p .707 .577 .707 r
F P
0 g
s
.66157 .75399 m .65804 .70153 L .62878 .70841 L p .707 .577 .707 r
F P
0 g
s
.56939 .76278 m .56587 .71032 L .53838 .70515 L p .707 .577 .707 r
F P
0 g
s
.56587 .71032 m .56939 .76278 L .60054 .7639 L p .707 .577 .707 r
F P
0 g
s
.65804 .70153 m .66157 .75399 L .68548 .74392 L p .707 .577 .707 r
F P
0 g
s
.68548 .74392 m .68195 .69146 L .65804 .70153 L p .707 .577 .707 r
F P
0 g
s
.54191 .75761 m .53838 .70515 L .51726 .69645 L p .707 .577 .707 r
F P
0 g
s
.53838 .70515 m .54191 .75761 L .56939 .76278 L p .707 .577 .707 r
F P
0 g
s
.68195 .69146 m .68548 .74392 L .70169 .73165 L p .707 .577 .707 r
F P
0 g
s
.70169 .73165 m .69816 .67919 L .68195 .69146 L p .707 .577 .707 r
F P
0 g
s
.60517 .83349 m .60137 .80032 L .57027 .79966 L p .707 .577 .707 r
F P
0 g
s
.60137 .80032 m .60517 .83349 L .63682 .82912 L p .707 .577 .707 r
F P
0 g
s
.63682 .82912 m .63301 .79595 L .60137 .80032 L p .707 .577 .707 r
F P
0 g
s
.63301 .79595 m .63682 .82912 L .6659 .82015 L p .707 .577 .707 r
F P
0 g
s
.6659 .82015 m .66209 .78698 L .63301 .79595 L p .707 .577 .707 r
F P
0 g
s
.57407 .83282 m .57027 .79966 L .54274 .79403 L p .707 .577 .707 r
F P
0 g
s
.57027 .79966 m .57407 .83282 L .60517 .83349 L p .707 .577 .707 r
F P
0 g
s
.52078 .7489 m .51726 .69645 L .50455 .68505 L p .707 .577 .707 r
F P
0 g
s
.51726 .69645 m .52078 .7489 L .54191 .75761 L p .707 .577 .707 r
F P
0 g
s
.66209 .78698 m .6659 .82015 L .68957 .80745 L p .707 .577 .707 r
F P
0 g
s
.68957 .80745 m .68576 .77429 L .66209 .78698 L p .707 .577 .707 r
F P
0 g
s
.69816 .67919 m .70169 .73165 L .70861 .71838 L p .707 .577 .707 r
F P
0 g
s
.70861 .71838 m .70508 .66593 L .69816 .67919 L p .707 .577 .707 r
F P
0 g
s
.54654 .8272 m .54274 .79403 L .52149 .78398 L p .707 .577 .707 r
F P
0 g
s
.54274 .79403 m .54654 .8272 L .57407 .83282 L p .707 .577 .707 r
F P
0 g
s
.68576 .77429 m .68957 .80745 L .70551 .79228 L p .707 .577 .707 r
F P
0 g
s
.70551 .79228 m .70171 .75911 L .68576 .77429 L p .707 .577 .707 r
F P
0 g
s
.60827 .88068 m .60615 .8644 L .57506 .86387 L p .707 .577 .707 r
F P
0 g
s
.60615 .8644 m .60827 .88068 L .63986 .87593 L p .707 .577 .707 r
F P
0 g
s
.63986 .87593 m .63775 .85965 L .60615 .8644 L p .707 .577 .707 r
F P
0 g
s
.50803 .82845 m .47601 .35497 L .43203 .35338 L p .707 .577 .707 r
F P
0 g
s
.50455 .68505 m .50808 .73751 L .52078 .7489 L p .707 .577 .707 r
F P
0 g
s
.50808 .73751 m .50455 .68505 L .50151 .67209 L p .707 .577 .707 r
F P
0 g
s
.52149 .78398 m .52529 .81715 L .54654 .8272 L p .707 .577 .707 r
F P
0 g
s
.52529 .81715 m .52149 .78398 L .5086 .77051 L p .707 .577 .707 r
F P
0 g
s
.50151 .67209 m .50503 .72455 L .50808 .73751 L p .707 .577 .707 r
F P
0 g
s
.5086 .77051 m .5124 .80368 L .52529 .81715 L p .707 .577 .707 r
F P
0 g
s
.50503 .72455 m .50151 .67209 L .50843 .65883 L p .707 .577 .707 r
F P
0 g
s
.5124 .80368 m .5086 .77051 L .50532 .75492 L p .707 .577 .707 r
F P
0 g
s
.50843 .65883 m .51196 .71128 L .50503 .72455 L p .707 .577 .707 r
F P
0 g
s
.50532 .75492 m .50912 .78809 L .5124 .80368 L p .707 .577 .707 r
F P
0 g
s
.51196 .71128 m .50843 .65883 L .52464 .64656 L p .707 .577 .707 r
F P
0 g
s
.50912 .78809 m .50532 .75492 L .51198 .73874 L p .707 .577 .707 r
F P
0 g
s
.51537 .84988 m .51326 .8336 L .50989 .81726 L p .707 .577 .707 r
F P
0 g
s
.50989 .81726 m .512 .83354 L .51537 .84988 L p .707 .577 .707 r
F P
0 g
s
.52464 .64656 m .52817 .69902 L .51196 .71128 L p .707 .577 .707 r
F P
0 g
s
.51198 .73874 m .51578 .77191 L .50912 .78809 L p .707 .577 .707 r
F P
0 g
s
.52817 .69902 m .52464 .64656 L .54855 .63649 L p .707 .577 .707 r
F P
0 g
s
.51578 .77191 m .51198 .73874 L .52793 .72357 L p .707 .577 .707 r
F P
0 g
s
.512 .83354 m .50989 .81726 L .51644 .80025 L p .707 .577 .707 r
F P
0 g
s
.54855 .63649 m .55208 .68895 L .52817 .69902 L p .707 .577 .707 r
F P
0 g
s
.51644 .80025 m .51856 .81653 L .512 .83354 L p .707 .577 .707 r
F P
0 g
s
.52793 .72357 m .53173 .75673 L .51578 .77191 L p .707 .577 .707 r
F P
0 g
s
.53173 .75673 m .52793 .72357 L .5516 .71087 L p .707 .577 .707 r
F P
0 g
s
.51856 .81653 m .51644 .80025 L .53229 .78423 L p .707 .577 .707 r
F P
0 g
s
.53229 .78423 m .5344 .80051 L .51856 .81653 L p .707 .577 .707 r
F P
0 g
s
.5516 .71087 m .5554 .74404 L .53173 .75673 L p .707 .577 .707 r
F P
0 g
s
.5344 .80051 m .53229 .78423 L .55587 .77078 L p .707 .577 .707 r
F P
0 g
s
.55587 .77078 m .55798 .78706 L .5344 .80051 L p .707 .577 .707 r
F P
0 g
s
.47601 .35497 m .50803 .82845 L .55287 .82415 L p .707 .577 .707 r
F P
0 g
s
.55287 .82415 m .52084 .35067 L .47601 .35497 L p .707 .577 .707 r
F P
0 g
s
.63775 .85965 m .63986 .87593 L .66887 .86636 L p .707 .577 .707 r
F P
0 g
s
.66887 .86636 m .66675 .85008 L .63775 .85965 L p .707 .577 .707 r
F P
0 g
s
.55208 .68895 m .54855 .63649 L .57782 .6296 L p .707 .577 .707 r
F P
0 g
s
.57782 .6296 m .58134 .68206 L .55208 .68895 L p .707 .577 .707 r
F P
0 g
s
.5554 .74404 m .5516 .71087 L .58068 .7019 L p .707 .577 .707 r
F P
0 g
s
.58068 .7019 m .58448 .73507 L .5554 .74404 L p .707 .577 .707 r
F P
0 g
s
.55798 .78706 m .55587 .77078 L .58487 .76121 L p .707 .577 .707 r
F P
0 g
s
.58699 .77749 m .58487 .76121 L .61647 .75646 L p .707 .577 .707 r
F P
0 g
s
.58487 .76121 m .58699 .77749 L .55798 .78706 L p .707 .577 .707 r
F P
0 g
s
.61647 .75646 m .61858 .77274 L .58699 .77749 L p .707 .577 .707 r
F P
0 g
s
.52084 .35067 m .55287 .82415 L .59419 .8144 L p .707 .577 .707 r
F P
0 g
s
.58134 .68206 m .57782 .6296 L .60958 .62657 L p .707 .577 .707 r
F P
0 g
s
.60958 .62657 m .61311 .67903 L .58134 .68206 L p .707 .577 .707 r
F P
0 g
s
.58448 .73507 m .58068 .7019 L .61232 .69753 L p .707 .577 .707 r
F P
0 g
s
.61232 .69753 m .61612 .7307 L .58448 .73507 L p .707 .577 .707 r
F P
0 g
s
.59419 .8144 m .56216 .34092 L .52084 .35067 L p .707 .577 .707 r
F P
0 g
s
.57718 .88015 m .57506 .86387 L .54752 .85811 L p .707 .577 .707 r
F P
0 g
s
.57506 .86387 m .57718 .88015 L .60827 .88068 L p .707 .577 .707 r
F P
0 g
s
.46406 .82686 m .43203 .35338 L .39323 .34608 L p .707 .577 .707 r
F P
0 g
s
.43203 .35338 m .46406 .82686 L .50803 .82845 L p .707 .577 .707 r
F P
0 g
s
.66675 .85008 m .66887 .86636 L .69245 .8529 L p .707 .577 .707 r
F P
0 g
s
.69245 .8529 m .69033 .83663 L .66675 .85008 L p .707 .577 .707 r
F P
0 g
s
.54752 .85811 m .54964 .87439 L .57718 .88015 L p .707 .577 .707 r
F P
0 g
s
.70508 .66593 m .70861 .71838 L .70557 .70542 L p .707 .577 .707 r
F P
0 g
s
.70557 .70542 m .70204 .65296 L .70508 .66593 L p .707 .577 .707 r
F P
0 g
s
.64342 .6982 m .64723 .73136 L .61612 .7307 L p .707 .577 .707 r
F P
0 g
s
.61612 .7307 m .61232 .69753 L .64342 .6982 L p .707 .577 .707 r
F P
0 g
s
.64756 .75699 m .64967 .77327 L .61858 .77274 L p .707 .577 .707 r
F P
0 g
s
.61858 .77274 m .61647 .75646 L .64756 .75699 L p .707 .577 .707 r
F P
0 g
s
.56216 .34092 m .59419 .8144 L .62794 .80015 L p .707 .577 .707 r
F P
0 g
s
.64072 .6277 m .64425 .68016 L .61311 .67903 L p .707 .577 .707 r
F P
0 g
s
.61311 .67903 m .60958 .62657 L .64072 .6277 L p .707 .577 .707 r
F P
0 g
s
.62794 .80015 m .59591 .32667 L .56216 .34092 L p .707 .577 .707 r
F P
0 g
s
.70171 .75911 m .70551 .79228 L .71217 .7761 L p .707 .577 .707 r
F P
0 g
s
.71217 .7761 m .70837 .74293 L .70171 .75911 L p .707 .577 .707 r
F P
0 g
s
.54964 .87439 m .54752 .85811 L .52622 .84768 L p .707 .577 .707 r
F P
0 g
s
.69033 .83663 m .69245 .8529 L .70829 .83689 L p .707 .577 .707 r
F P
0 g
s
.70829 .83689 m .70618 .82061 L .69033 .83663 L p .707 .577 .707 r
F P
0 g
s
.42526 .81956 m .39323 .34608 L .3634 .33377 L p .707 .577 .707 r
F P
0 g
s
.39323 .34608 m .42526 .81956 L .46406 .82686 L p .707 .577 .707 r
F P
0 g
s
.52622 .84768 m .52834 .86396 L .54964 .87439 L p .707 .577 .707 r
F P
0 g
s
.52834 .86396 m .52622 .84768 L .51326 .8336 L p .707 .577 .707 r
F P
0 g
s
.6751 .76275 m .67721 .77903 L .64967 .77327 L p .707 .577 .707 r
F P
0 g
s
.64967 .77327 m .64756 .75699 L .6751 .76275 L p .707 .577 .707 r
F P
0 g
s
.59591 .32667 m .62794 .80015 L .65082 .7828 L p .707 .577 .707 r
F P
0 g
s
.67095 .70383 m .67475 .73699 L .64723 .73136 L p .707 .577 .707 r
F P
0 g
s
.64723 .73136 m .64342 .6982 L .67095 .70383 L p .707 .577 .707 r
F P
0 g
s
.65082 .7828 m .61879 .30932 L .59591 .32667 L p .707 .577 .707 r
F P
0 g
s
.70204 .65296 m .70557 .70542 L .69286 .69403 L p .707 .577 .707 r
F P
0 g
s
.69286 .69403 m .68934 .64157 L .70204 .65296 L p .707 .577 .707 r
F P
0 g
s
.70837 .74293 m .71217 .7761 L .7089 .76051 L p .707 .577 .707 r
F P
0 g
s
.7089 .76051 m .70509 .72735 L .70837 .74293 L p .707 .577 .707 r
F P
0 g
s
.70618 .82061 m .70829 .83689 L .71485 .81988 L p .707 .577 .707 r
F P
0 g
s
.71485 .81988 m .71273 .8036 L .70618 .82061 L p .707 .577 .707 r
F P
0 g
s
.51326 .8336 m .51537 .84988 L .52834 .86396 L p .707 .577 .707 r
F P
0 g
s
.39543 .80725 m .3634 .33377 L .34546 .31766 L p .707 .577 .707 r
F P
0 g
s
.3634 .33377 m .39543 .80725 L .42526 .81956 L p .707 .577 .707 r
F P
0 g
s
.25753 .72709 m .25401 .67463 L .22286 .6735 L p .707 .577 .707 r
F P
0 g
s
.25401 .67463 m .25753 .72709 L .2893 .72406 L p .707 .577 .707 r
F P
0 g
s
.2893 .72406 m .28577 .6716 L .25401 .67463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28577 .6716 m .2893 .72406 L .31856 .71717 L p .707 .577 .707 r
F P
0 g
s
.31856 .71717 m .31504 .66471 L .28577 .6716 L p .707 .577 .707 r
F P
0 g
s
.22639 .72596 m .22286 .6735 L .19538 .66834 L p .707 .577 .707 r
F P
0 g
s
.22286 .6735 m .22639 .72596 L .25753 .72709 L p .707 .577 .707 r
F P
0 g
s
.68934 .64157 m .69286 .69403 L .67174 .68532 L p .707 .577 .707 r
F P
0 g
s
.67174 .68532 m .66821 .63287 L .68934 .64157 L p .707 .577 .707 r
F P
0 g
s
.70509 .72735 m .7089 .76051 L .696 .74704 L p .707 .577 .707 r
F P
0 g
s
.696 .74704 m .6922 .71387 L .70509 .72735 L p .707 .577 .707 r
F P
0 g
s
.71273 .8036 m .71485 .81988 L .71148 .80353 L p .707 .577 .707 r
F P
0 g
s
.71148 .80353 m .70936 .78725 L .71273 .8036 L p .707 .577 .707 r
F P
0 g
s
.31504 .66471 m .31856 .71717 L .34247 .7071 L p .707 .577 .707 r
F P
0 g
s
.34247 .7071 m .33894 .65464 L .31504 .66471 L p .707 .577 .707 r
F P
0 g
s
.66821 .63287 m .67174 .68532 L .64425 .68016 L p .707 .577 .707 r
F P
0 g
s
.64425 .68016 m .64072 .6277 L .66821 .63287 L p .707 .577 .707 r
F P
0 g
s
.61879 .30932 m .65082 .7828 L .66059 .76403 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .62857 .29055 L .61879 .30932 L p .707 .577 .707 r
F P
0 g
s
.1989 .72079 m .19538 .66834 L .17425 .65963 L p .707 .577 .707 r
F P
0 g
s
.19538 .66834 m .1989 .72079 L .22639 .72596 L p .707 .577 .707 r
F P
0 g
s
.33894 .65464 m .34247 .7071 L .35868 .69483 L p .707 .577 .707 r
F P
0 g
s
.35868 .69483 m .35515 .64238 L .33894 .65464 L p .707 .577 .707 r
F P
0 g
s
.6922 .71387 m .696 .74704 L .67475 .73699 L p .707 .577 .707 r
F P
0 g
s
.67475 .73699 m .67095 .70383 L .6922 .71387 L p .707 .577 .707 r
F P
0 g
s
.37749 .79114 m .34546 .31766 L .34117 .29933 L p .707 .577 .707 r
F P
0 g
s
.34546 .31766 m .37749 .79114 L .39543 .80725 L p .707 .577 .707 r
F P
0 g
s
.26217 .79667 m .25836 .7635 L .22726 .76284 L p .707 .577 .707 r
F P
0 g
s
.25836 .7635 m .26217 .79667 L .29381 .79231 L p .707 .577 .707 r
F P
0 g
s
.29381 .79231 m .29001 .75914 L .25836 .7635 L p .707 .577 .707 r
F P
0 g
s
.29001 .75914 m .29381 .79231 L .32289 .78334 L p .707 .577 .707 r
F P
0 g
s
.32289 .78334 m .31908 .75017 L .29001 .75914 L p .707 .577 .707 r
F P
0 g
s
.70936 .78725 m .71148 .80353 L .69851 .78946 L p .707 .577 .707 r
F P
0 g
s
.69851 .78946 m .69639 .77318 L .70936 .78725 L p .707 .577 .707 r
F P
0 g
s
.23106 .79601 m .22726 .76284 L .19973 .75721 L p .707 .577 .707 r
F P
0 g
s
.22726 .76284 m .23106 .79601 L .26217 .79667 L p .707 .577 .707 r
F P
0 g
s
.17777 .71209 m .17425 .65963 L .16154 .64824 L p .707 .577 .707 r
F P
0 g
s
.17425 .65963 m .17777 .71209 L .1989 .72079 L p .707 .577 .707 r
F P
0 g
s
.31908 .75017 m .32289 .78334 L .34656 .77064 L p .707 .577 .707 r
F P
0 g
s
.34656 .77064 m .34276 .73747 L .31908 .75017 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .6563 .7457 L p .65047 .65 L .707 .577 .707 r
F P
0 g
s
.65047 .65 m .64491 .55872 L .64886 .61047 L .707 .577 .707 r
F
.65047 .65 m .64886 .61047 L .66059 .76403 L F
.64057 .468 m .66059 .76403 L p .64491 .55872 L F P
0 g
s
.62427 .27222 m .62857 .29055 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.6563 .7457 m .64793 .62198 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.64793 .62198 m .62427 .27222 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.62427 .27222 m .6563 .7457 L .63836 .72959 L p .707 .577 .707 r
F P
0 g
s
.6458 .66756 m .6496 .70073 L .6518 .70302 L p .707 .577 .707 r
F P
0 g
s
.6518 .70302 m .6625 .7142 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.65077 .68144 m .6458 .66756 L .6518 .70302 L .707 .577 .707 r
F
.66554 .75223 m .66343 .73595 L .65353 .72521 L p F P
0 g
s
.65353 .72521 m .65046 .72188 L p .65365 .7283 L .707 .577 .707 r
F P
0 g
s
.66554 .75223 m .65353 .72521 L .65365 .7283 L .707 .577 .707 r
F
.6625 .7142 m .6587 .68103 L .65033 .67229 L p F P
0 g
s
.65033 .67229 m .6458 .66756 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.6625 .7142 m .65033 .67229 L .65077 .68144 L .707 .577 .707 r
F
.62857 .29055 m .64057 .468 L p .64491 .55872 L F P
0 g
s
.35515 .64238 m .35868 .69483 L .3656 .68157 L p .707 .577 .707 r
F P
0 g
s
.3656 .68157 m .36208 .62911 L .35515 .64238 L p .707 .577 .707 r
F P
0 g
s
.20354 .79038 m .19973 .75721 L .17848 .74717 L p .707 .577 .707 r
F P
0 g
s
.19973 .75721 m .20354 .79038 L .23106 .79601 L p .707 .577 .707 r
F P
0 g
s
.69639 .77318 m .69851 .78946 L .67721 .77903 L p .707 .577 .707 r
F P
0 g
s
.67721 .77903 m .6751 .76275 L .69639 .77318 L p .707 .577 .707 r
F P
0 g
s
.34276 .73747 m .34656 .77064 L .3625 .75546 L p .707 .577 .707 r
F P
0 g
s
.3625 .75546 m .3587 .72229 L .34276 .73747 L p .707 .577 .707 r
F P
0 g
s
.26526 .84386 m .26314 .82758 L .23205 .82705 L p .707 .577 .707 r
F P
0 g
s
.26314 .82758 m .26526 .84386 L .29685 .83911 L p .707 .577 .707 r
F P
0 g
s
.29685 .83911 m .29474 .82283 L .26314 .82758 L p .707 .577 .707 r
F P
0 g
s
.29474 .82283 m .29685 .83911 L .32586 .82954 L p .707 .577 .707 r
F P
0 g
s
.32586 .82954 m .32374 .81326 L .29474 .82283 L p .707 .577 .707 r
F P
0 g
s
.16154 .64824 m .16507 .7007 L .17777 .71209 L p .707 .577 .707 r
F P
0 g
s
.16507 .7007 m .16154 .64824 L .1585 .63528 L p .707 .577 .707 r
F P
0 g
s
.23417 .84333 m .23205 .82705 L .20451 .82129 L p .707 .577 .707 r
F P
0 g
s
.23205 .82705 m .23417 .84333 L .26526 .84386 L p .707 .577 .707 r
F P
0 g
s
.32374 .81326 m .32586 .82954 L .34944 .81609 L p .707 .577 .707 r
F P
0 g
s
.34944 .81609 m .34732 .79981 L .32374 .81326 L p .707 .577 .707 r
F P
0 g
s
.34117 .29933 m .37319 .77281 L .37749 .79114 L p .707 .577 .707 r
F P
0 g
s
.37319 .77281 m .34117 .29933 L .35094 .28057 L p .707 .577 .707 r
F P
0 g
s
.17848 .74717 m .18229 .78034 L .20354 .79038 L p .707 .577 .707 r
F P
0 g
s
.18229 .78034 m .17848 .74717 L .16559 .73369 L p .707 .577 .707 r
F P
0 g
s
.20451 .82129 m .20663 .83757 L .23417 .84333 L p .707 .577 .707 r
F P
0 g
s
.36208 .62911 m .3656 .68157 L .36256 .66861 L p .707 .577 .707 r
F P
0 g
s
.36256 .66861 m .35904 .61615 L .36208 .62911 L p .707 .577 .707 r
F P
0 g
s
.3587 .72229 m .3625 .75546 L .36916 .73929 L p .707 .577 .707 r
F P
0 g
s
.36916 .73929 m .36536 .70612 L .3587 .72229 L p .707 .577 .707 r
F P
0 g
s
.20663 .83757 m .20451 .82129 L .18322 .81086 L p .707 .577 .707 r
F P
0 g
s
.34732 .79981 m .34944 .81609 L .36528 .80007 L p .707 .577 .707 r
F P
0 g
s
.36528 .80007 m .36317 .78379 L .34732 .79981 L p .707 .577 .707 r
F P
0 g
s
.63836 .72959 m .60633 .25611 L .62427 .27222 L p .707 .577 .707 r
F P
0 g
s
.1585 .63528 m .16203 .68773 L .16507 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18322 .81086 m .18533 .82714 L .20663 .83757 L p .707 .577 .707 r
F P
0 g
s
.16559 .73369 m .16939 .76686 L .18229 .78034 L p .707 .577 .707 r
F P
0 g
s
.16203 .68773 m .1585 .63528 L .16542 .62201 L p .707 .577 .707 r
F P
0 g
s
.16939 .76686 m .16559 .73369 L .16231 .7181 L p .707 .577 .707 r
F P
0 g
s
.18533 .82714 m .18322 .81086 L .17025 .79679 L p .707 .577 .707 r
F P
0 g
s
.35904 .61615 m .36256 .66861 L .34986 .65722 L p .707 .577 .707 r
F P
0 g
s
.34986 .65722 m .34633 .60476 L .35904 .61615 L p .707 .577 .707 r
F P
0 g
s
.36536 .70612 m .36916 .73929 L .36589 .7237 L p .707 .577 .707 r
F P
0 g
s
.36589 .7237 m .36208 .69053 L .36536 .70612 L p .707 .577 .707 r
F P
0 g
s
.36317 .78379 m .36528 .80007 L .37184 .78306 L p .707 .577 .707 r
F P
0 g
s
.37184 .78306 m .36972 .76678 L .36317 .78379 L p .707 .577 .707 r
F P
0 g
s
.38297 .75405 m .35094 .28057 L .37382 .26321 L p .707 .577 .707 r
F P
0 g
s
.35094 .28057 m .38297 .75405 L .37319 .77281 L p .707 .577 .707 r
F P
0 g
s
.17025 .79679 m .17236 .81307 L .18533 .82714 L p .707 .577 .707 r
F P
0 g
s
.16542 .62201 m .16895 .67447 L .16203 .68773 L p .707 .577 .707 r
F P
0 g
s
.16231 .7181 m .16611 .75127 L .16939 .76686 L p .707 .577 .707 r
F P
0 g
s
.16895 .67447 m .16542 .62201 L .18163 .60974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.60633 .25611 m .63836 .72959 L .60853 .71728 L p .707 .577 .707 r
F P
0 g
s
.60853 .71728 m .5765 .2438 L .60633 .25611 L p .707 .577 .707 r
F P
0 g
s
.16611 .75127 m .16231 .7181 L .16897 .70193 L p .707 .577 .707 r
F P
0 g
s
.17236 .81307 m .17025 .79679 L .16688 .78044 L p .707 .577 .707 r
F P
0 g
s
.34633 .60476 m .34986 .65722 L .32873 .64851 L p .707 .577 .707 r
F P
0 g
s
.32873 .64851 m .3252 .59605 L .34633 .60476 L p .707 .577 .707 r
F P
0 g
s
.36208 .69053 m .36589 .7237 L .35299 .71022 L p .707 .577 .707 r
F P
0 g
s
.35299 .71022 m .34919 .67705 L .36208 .69053 L p .707 .577 .707 r
F P
0 g
s
.36972 .76678 m .37184 .78306 L .36847 .76672 L p .707 .577 .707 r
F P
0 g
s
.36847 .76672 m .36635 .75044 L .36972 .76678 L p .707 .577 .707 r
F P
0 g
s
.16688 .78044 m .16899 .79672 L .17236 .81307 L p .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .38297 .75405 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.38215 .38639 m .40585 .73669 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .37382 .26321 L .40757 .24896 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40585 .73669 L p .40643 .57268 L .707 .577 .707 r
F P
0 g
s
.40643 .57268 m .42334 .61922 L .4396 .72244 L .707 .577 .707 r
F
.43123 .59872 m .43473 .65055 L p .40664 .51311 L F P
0 g
s
.43473 .65055 m .4396 .72244 L p .42334 .61922 L .707 .577 .707 r
F P
0 g
s
.40664 .51311 m .43473 .65055 L .42334 .61922 L .707 .577 .707 r
F
.44889 .23921 m .48092 .71269 L .4396 .72244 L p F P
0 g
s
.46306 .71782 m .46095 .70154 L .45409 .7038 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40757 .24896 L .44889 .23921 L p .707 .577 .707 r
F P
0 g
s
.45409 .7038 m .43194 .71111 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.46306 .71782 m .45409 .7038 L .45886 .71691 L .707 .577 .707 r
F
.43194 .71111 m .43405 .72739 L .4596 .71896 L p F P
0 g
s
.4596 .71896 m .46306 .71782 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.45886 .71691 m .43194 .71111 L .4596 .71896 L .707 .577 .707 r
F
.40643 .57268 m .40664 .51311 L .42334 .61922 L F
.40757 .24896 m .43123 .59872 L p .40664 .51311 L F P
0 g
s
.42721 .65619 m .43101 .68936 L .45513 .68192 L p .707 .577 .707 r
F P
0 g
s
.45513 .68192 m .46009 .68038 L p .45324 .67534 L .707 .577 .707 r
F P
0 g
s
.45324 .67534 m .42721 .65619 L .45513 .68192 L .707 .577 .707 r
F
.39557 .66055 m .39937 .69372 L .42406 .69032 L p F P
0 g
s
.42406 .69032 m .43101 .68936 L p .42303 .68287 L .707 .577 .707 r
F P
0 g
s
.42303 .68287 m .39557 .66055 L .42406 .69032 L .707 .577 .707 r
F
.37382 .26321 m .38215 .38639 L p .37517 .33577 L F P
0 g
s
.18163 .60974 m .18516 .6622 L .16895 .67447 L p .707 .577 .707 r
F P
0 g
s
.16897 .70193 m .17277 .7351 L .16611 .75127 L p .707 .577 .707 r
F P
0 g
s
.18516 .6622 m .18163 .60974 L .20554 .59967 L p .707 .577 .707 r
F P
0 g
s
.17277 .7351 m .16897 .70193 L .18492 .68675 L p .707 .577 .707 r
F P
0 g
s
.3252 .59605 m .32873 .64851 L .30124 .64334 L p .707 .577 .707 r
F P
0 g
s
.30124 .64334 m .29772 .59088 L .3252 .59605 L p .707 .577 .707 r
F P
0 g
s
.16899 .79672 m .16688 .78044 L .17343 .76343 L p .707 .577 .707 r
F P
0 g
s
.5765 .2438 m .60853 .71728 L .56973 .70998 L p .707 .577 .707 r
F P
0 g
s
.56973 .70998 m .5377 .2365 L .5765 .2438 L p .707 .577 .707 r
F P
0 g
s
.34919 .67705 m .35299 .71022 L .33174 .70018 L p .707 .577 .707 r
F P
0 g
s
.33174 .70018 m .32794 .66701 L .34919 .67705 L p .707 .577 .707 r
F P
0 g
s
.36635 .75044 m .36847 .76672 L .3555 .75264 L p .707 .577 .707 r
F P
0 g
s
.3555 .75264 m .35339 .73636 L .36635 .75044 L p .707 .577 .707 r
F P
0 g
s
.20907 .65213 m .20554 .59967 L .23481 .59279 L p .707 .577 .707 r
F P
0 g
s
.20554 .59967 m .20907 .65213 L .18516 .6622 L p .707 .577 .707 r
F P
0 g
s
.17343 .76343 m .17555 .77971 L .16899 .79672 L p .707 .577 .707 r
F P
0 g
s
.29772 .59088 m .30124 .64334 L .2701 .64222 L p .707 .577 .707 r
F P
0 g
s
.2701 .64222 m .26657 .58976 L .29772 .59088 L p .707 .577 .707 r
F P
0 g
s
.18492 .68675 m .18872 .71992 L .17277 .7351 L p .707 .577 .707 r
F P
0 g
s
.23833 .64525 m .23481 .59279 L .26657 .58976 L p .707 .577 .707 r
F P
0 g
s
.23481 .59279 m .23833 .64525 L .20907 .65213 L p .707 .577 .707 r
F P
0 g
s
.18872 .71992 m .18492 .68675 L .20859 .67405 L p .707 .577 .707 r
F P
0 g
s
.26657 .58976 m .2701 .64222 L .23833 .64525 L p .707 .577 .707 r
F P
0 g
s
.5377 .2365 m .56973 .70998 L .52575 .7084 L p .707 .577 .707 r
F P
0 g
s
.52575 .7084 m .49373 .23492 L .5377 .2365 L p .707 .577 .707 r
F P
0 g
s
.17555 .77971 m .17343 .76343 L .18928 .74741 L p .707 .577 .707 r
F P
0 g
s
.32794 .66701 m .33174 .70018 L .30422 .69455 L p .707 .577 .707 r
F P
0 g
s
.30422 .69455 m .30041 .66138 L .32794 .66701 L p .707 .577 .707 r
F P
0 g
s
.48092 .71269 m .46251 .44063 L p .49373 .23492 L .707 .577 .707 r
F P
0 g
s
.49373 .23492 m .52575 .7084 L .48092 .71269 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .48376 .66769 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45629 .64722 m .45828 .66455 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45828 .66455 m .46009 .68038 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.46251 .44063 m .44889 .23921 L .46635 .23754 L p .707 .577 .707 r
F P
0 g
s
.46635 .23754 m .49373 .23492 L p .46251 .44063 L .707 .577 .707 r
F P
0 g
s
.35339 .73636 m .3555 .75264 L .3342 .74221 L p .707 .577 .707 r
F P
0 g
s
.3342 .74221 m .33209 .72593 L .35339 .73636 L p .707 .577 .707 r
F P
0 g
s
.73775 .66719 m .73422 .61473 L .70307 .61361 L p .707 .577 .707 r
F P
0 g
s
.73422 .61473 m .73775 .66719 L .76951 .66416 L p .707 .577 .707 r
F P
0 g
s
.76951 .66416 m .76598 .6117 L .73422 .61473 L p .707 .577 .707 r
F P
0 g
s
.76598 .6117 m .76951 .66416 L .79878 .65727 L p .707 .577 .707 r
F P
0 g
s
.79878 .65727 m .79525 .60482 L .76598 .6117 L p .707 .577 .707 r
F P
0 g
s
.18928 .74741 m .19139 .76369 L .17555 .77971 L p .707 .577 .707 r
F P
0 g
s
.21239 .70722 m .20859 .67405 L .23767 .66508 L p .707 .577 .707 r
F P
0 g
s
.20859 .67405 m .21239 .70722 L .18872 .71992 L p .707 .577 .707 r
F P
0 g
s
.7066 .66607 m .70307 .61361 L .67559 .60844 L p .707 .577 .707 r
F P
0 g
s
.70307 .61361 m .7066 .66607 L .73775 .66719 L p .707 .577 .707 r
F P
0 g
s
.30041 .66138 m .30422 .69455 L .27311 .69389 L p .707 .577 .707 r
F P
0 g
s
.27311 .69389 m .26931 .66072 L .30041 .66138 L p .707 .577 .707 r
F P
0 g
s
.79525 .60482 m .79878 .65727 L .82268 .6472 L p .707 .577 .707 r
F P
0 g
s
.82268 .6472 m .81916 .59475 L .79525 .60482 L p .707 .577 .707 r
F P
0 g
s
.24147 .69825 m .23767 .66508 L .26931 .66072 L p .707 .577 .707 r
F P
0 g
s
.23767 .66508 m .24147 .69825 L .21239 .70722 L p .707 .577 .707 r
F P
0 g
s
.19139 .76369 m .18928 .74741 L .21286 .73396 L p .707 .577 .707 r
F P
0 g
s
.26931 .66072 m .27311 .69389 L .24147 .69825 L p .707 .577 .707 r
F P
0 g
s
.33209 .72593 m .3342 .74221 L .30666 .73645 L p .707 .577 .707 r
F P
0 g
s
.30666 .73645 m .30455 .72017 L .33209 .72593 L p .707 .577 .707 r
F P
0 g
s
.67912 .6609 m .67559 .60844 L .65446 .59973 L p .707 .577 .707 r
F P
0 g
s
.67559 .60844 m .67912 .6609 L .7066 .66607 L p .707 .577 .707 r
F P
0 g
s
.21286 .73396 m .21497 .75024 L .19139 .76369 L p .707 .577 .707 r
F P
0 g
s
.81916 .59475 m .82268 .6472 L .83889 .63494 L p .707 .577 .707 r
F P
0 g
s
.83889 .63494 m .83537 .58248 L .81916 .59475 L p .707 .577 .707 r
F P
0 g
s
.21497 .75024 m .21286 .73396 L .24186 .72439 L p .707 .577 .707 r
F P
0 g
s
.74238 .73054 m .73858 .69737 L .70747 .69671 L p .707 .577 .707 r
F P
0 g
s
.73858 .69737 m .74238 .73054 L .77402 .72617 L p .707 .577 .707 r
F P
0 g
s
.77402 .72617 m .77022 .693 L .73858 .69737 L p .707 .577 .707 r
F P
0 g
s
.30455 .72017 m .30666 .73645 L .27557 .73592 L p .707 .577 .707 r
F P
0 g
s
.27557 .73592 m .27346 .71964 L .30455 .72017 L p .707 .577 .707 r
F P
0 g
s
.77022 .693 m .77402 .72617 L .8031 .7172 L p .707 .577 .707 r
F P
0 g
s
.8031 .7172 m .7993 .68403 L .77022 .693 L p .707 .577 .707 r
F P
0 g
s
.24398 .74067 m .24186 .72439 L .27346 .71964 L p .707 .577 .707 r
F P
0 g
s
.24186 .72439 m .24398 .74067 L .21497 .75024 L p .707 .577 .707 r
F P
0 g
s
.71127 .72987 m .70747 .69671 L .67995 .69108 L p .707 .577 .707 r
F P
0 g
s
.70747 .69671 m .71127 .72987 L .74238 .73054 L p .707 .577 .707 r
F P
0 g
s
.27346 .71964 m .27557 .73592 L .24398 .74067 L p .707 .577 .707 r
F P
0 g
s
.65799 .65219 m .65446 .59973 L .64175 .58834 L p .707 .577 .707 r
F P
0 g
s
.65446 .59973 m .65799 .65219 L .67912 .6609 L p .707 .577 .707 r
F P
0 g
s
.7993 .68403 m .8031 .7172 L .82677 .7045 L p .707 .577 .707 r
F P
0 g
s
.82677 .7045 m .82297 .67134 L .7993 .68403 L p .707 .577 .707 r
F P
0 g
s
.83537 .58248 m .83889 .63494 L .84582 .62167 L p .707 .577 .707 r
F P
0 g
s
.84582 .62167 m .84229 .56922 L .83537 .58248 L p .707 .577 .707 r
F P
0 g
s
.68375 .72425 m .67995 .69108 L .6587 .68103 L p .707 .577 .707 r
F P
0 g
s
.67995 .69108 m .68375 .72425 L .71127 .72987 L p .707 .577 .707 r
F P
0 g
s
.74547 .76896 m .74336 .75268 L .71227 .75214 L p .707 .577 .707 r
F P
0 g
s
.74336 .75268 m .74547 .76896 L .77706 .7642 L p .707 .577 .707 r
F P
0 g
s
.77706 .7642 m .77495 .74792 L .74336 .75268 L p .707 .577 .707 r
F P
0 g
s
.82297 .67134 m .82677 .7045 L .84272 .68933 L p .707 .577 .707 r
F P
0 g
s
.84272 .68933 m .83892 .65616 L .82297 .67134 L p .707 .577 .707 r
F P
0 g
s
.77495 .74792 m .77706 .7642 L .80607 .75463 L p .707 .577 .707 r
F P
0 g
s
.80607 .75463 m .80396 .73835 L .77495 .74792 L p .707 .577 .707 r
F P
0 g
s
.64175 .58834 m .64528 .6408 L .65799 .65219 L p .707 .577 .707 r
F P
0 g
s
.71438 .76842 m .71227 .75214 L .68473 .74638 L p .707 .577 .707 r
F P
0 g
s
.71227 .75214 m .71438 .76842 L .74547 .76896 L p .707 .577 .707 r
F P
0 g
s
.64528 .6408 m .64175 .58834 L .63871 .57538 L p .707 .577 .707 r
F P
0 g
s
.80396 .73835 m .80607 .75463 L .82965 .74118 L p .707 .577 .707 r
F P
0 g
s
.82965 .74118 m .82754 .7249 L .80396 .73835 L p .707 .577 .707 r
F P
0 g
s
.6587 .68103 m .6625 .7142 L .68375 .72425 L p .707 .577 .707 r
F P
0 g
s
.68473 .74638 m .68684 .76266 L .71438 .76842 L p .707 .577 .707 r
F P
0 g
s
.84229 .56922 m .84582 .62167 L .84278 .60871 L p .707 .577 .707 r
F P
0 g
s
.84278 .60871 m .83925 .55625 L .84229 .56922 L p .707 .577 .707 r
F P
0 g
s
.68684 .76266 m .68473 .74638 L .66343 .73595 L p .707 .577 .707 r
F P
0 g
s
.83892 .65616 m .84272 .68933 L .84938 .67315 L p .707 .577 .707 r
F P
0 g
s
.84938 .67315 m .84558 .63998 L .83892 .65616 L p .707 .577 .707 r
F P
0 g
s
.82754 .7249 m .82965 .74118 L .84549 .72517 L p .707 .577 .707 r
F P
0 g
s
.84549 .72517 m .84338 .70889 L .82754 .7249 L p .707 .577 .707 r
F P
0 g
s
.66343 .73595 m .66554 .75223 L .68684 .76266 L p .707 .577 .707 r
F P
0 g
s
.63871 .57538 m .64224 .62784 L .64528 .6408 L p .707 .577 .707 r
F P
0 g
s
.64224 .62784 m .63871 .57538 L .64563 .56212 L p .707 .577 .707 r
F P
0 g
s
.6496 .70073 m .6458 .66756 L .64252 .65197 L p .707 .577 .707 r
F P
0 g
s
.84338 .70889 m .84549 .72517 L .85205 .70815 L p .707 .577 .707 r
F P
0 g
s
.85205 .70815 m .84994 .69187 L .84338 .70889 L p .707 .577 .707 r
F P
0 g
s
.84558 .63998 m .84938 .67315 L .8461 .65756 L p .707 .577 .707 r
F P
0 g
s
.8461 .65756 m .8423 .62439 L .84558 .63998 L p .707 .577 .707 r
F P
0 g
s
.83925 .55625 m .84278 .60871 L .83007 .59732 L p .707 .577 .707 r
F P
0 g
s
.83007 .59732 m .82654 .54486 L .83925 .55625 L p .707 .577 .707 r
F P
0 g
s
.65046 .72188 m .65257 .73816 L .66554 .75223 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64252 .65197 m .64633 .68514 L .6496 .70073 L p .707 .577 .707 r
F P
0 g
s
.64563 .56212 m .64916 .61457 L .64224 .62784 L p .707 .577 .707 r
F P
0 g
s
.64916 .61457 m .64563 .56212 L .66184 .54985 L p .707 .577 .707 r
F P
0 g
s
.65257 .73816 m .65046 .72188 L .64709 .70553 L p .707 .577 .707 r
F P
0 g
s
.39474 .63037 m .39121 .57792 L .36006 .57679 L p .707 .577 .707 r
F P
0 g
s
.39121 .57792 m .39474 .63037 L .4265 .62735 L p .707 .577 .707 r
F P
0 g
s
.4265 .62735 m .42297 .57489 L .39121 .57792 L p .707 .577 .707 r
F P
0 g
s
.64633 .68514 m .64252 .65197 L .64918 .63579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42297 .57489 m .4265 .62735 L .45577 .62046 L p .707 .577 .707 r
F P
0 g
s
.45577 .62046 m .45224 .568 L .42297 .57489 L p .707 .577 .707 r
F P
0 g
s
.84994 .69187 m .85205 .70815 L .84868 .69181 L p .707 .577 .707 r
F P
0 g
s
.84868 .69181 m .84657 .67553 L .84994 .69187 L p .707 .577 .707 r
F P
0 g
s
.36359 .62925 m .36006 .57679 L .33258 .57162 L p .707 .577 .707 r
F P
0 g
s
.36006 .57679 m .36359 .62925 L .39474 .63037 L p .707 .577 .707 r
F P
0 g
s
.8423 .62439 m .8461 .65756 L .83321 .64409 L p .707 .577 .707 r
F P
0 g
s
.83321 .64409 m .8294 .61092 L .8423 .62439 L p .707 .577 .707 r
F P
0 g
s
.82654 .54486 m .83007 .59732 L .80894 .58861 L p .707 .577 .707 r
F P
0 g
s
.80894 .58861 m .80541 .53615 L .82654 .54486 L p .707 .577 .707 r
F P
0 g
s
.64709 .70553 m .6492 .72181 L .65257 .73816 L p .707 .577 .707 r
F P
0 g
s
.45224 .568 m .45577 .62046 L .47967 .61039 L p .707 .577 .707 r
F P
0 g
s
.47967 .61039 m .47615 .55793 L .45224 .568 L p .707 .577 .707 r
F P
0 g
s
.64918 .63579 m .65299 .66896 L .64633 .68514 L p .707 .577 .707 r
F P
0 g
s
.66184 .54985 m .66537 .60231 L .64916 .61457 L p .707 .577 .707 r
F P
0 g
s
.66537 .60231 m .66184 .54985 L .68575 .53978 L p .707 .577 .707 r
F P
0 g
s
.33611 .62408 m .33258 .57162 L .31145 .56292 L p .707 .577 .707 r
F P
0 g
s
.33258 .57162 m .33611 .62408 L .36359 .62925 L p .707 .577 .707 r
F P
0 g
s
.65299 .66896 m .64918 .63579 L .66513 .62062 L p .707 .577 .707 r
F P
0 g
s
.6492 .72181 m .64709 .70553 L .65365 .68852 L p .707 .577 .707 r
F P
0 g
s
.80541 .53615 m .80894 .58861 L .78146 .58344 L p .707 .577 .707 r
F P
0 g
s
.78146 .58344 m .77793 .53099 L .80541 .53615 L p .707 .577 .707 r
F P
0 g
s
.47615 .55793 m .47967 .61039 L .49588 .59812 L p .707 .577 .707 r
F P
0 g
s
.49588 .59812 m .49236 .54566 L .47615 .55793 L p .707 .577 .707 r
F P
0 g
s
.84657 .67553 m .84868 .69181 L .83571 .67773 L p .707 .577 .707 r
F P
0 g
s
.83571 .67773 m .8336 .66145 L .84657 .67553 L p .707 .577 .707 r
F P
0 g
s
.8294 .61092 m .83321 .64409 L .81196 .63404 L p .707 .577 .707 r
F P
0 g
s
.81196 .63404 m .80815 .60087 L .8294 .61092 L p .707 .577 .707 r
F P
0 g
s
.39937 .69372 m .39557 .66055 L .36446 .65989 L p .707 .577 .707 r
F P
0 g
s
.43101 .68936 m .42721 .65619 L .39557 .66055 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .45629 .64722 L .42721 .65619 L p .707 .577 .707 r
F P
0 g
s
.65365 .68852 m .65576 .7048 L .6492 .72181 L p .707 .577 .707 r
F P
0 g
s
.68928 .59224 m .68575 .53978 L .71502 .53289 L p .707 .577 .707 r
F P
0 g
s
.68575 .53978 m .68928 .59224 L .66537 .60231 L p .707 .577 .707 r
F P
0 g
s
.36826 .69306 m .36446 .65989 L .33694 .65426 L p .707 .577 .707 r
F P
0 g
s
.36446 .65989 m .36826 .69306 L .39937 .69372 L p .707 .577 .707 r
F P
0 g
s
.31498 .61538 m .31145 .56292 L .29874 .55153 L p .707 .577 .707 r
F P
0 g
s
.31145 .56292 m .31498 .61538 L .33611 .62408 L p .707 .577 .707 r
F P
0 g
s
.48376 .66769 m .47996 .63452 L .45629 .64722 L p .707 .577 .707 r
F P
0 g
s
.66513 .62062 m .66893 .65378 L .65299 .66896 L p .707 .577 .707 r
F P
0 g
s
.77793 .53099 m .78146 .58344 L .75031 .58232 L p .707 .577 .707 r
F P
0 g
s
.75031 .58232 m .74678 .52986 L .77793 .53099 L p .707 .577 .707 r
F P
0 g
s
.66893 .65378 m .66513 .62062 L .6888 .60792 L p .707 .577 .707 r
F P
0 g
s
.71855 .58535 m .71502 .53289 L .74678 .52986 L p .707 .577 .707 r
F P
0 g
s
.71502 .53289 m .71855 .58535 L .68928 .59224 L p .707 .577 .707 r
F P
0 g
s
.65576 .7048 m .65365 .68852 L .66949 .67251 L p .707 .577 .707 r
F P
0 g
s
.74678 .52986 m .75031 .58232 L .71855 .58535 L p .707 .577 .707 r
F P
0 g
s
.80815 .60087 m .81196 .63404 L .78443 .62841 L p .707 .577 .707 r
F P
0 g
s
.78443 .62841 m .78063 .59524 L .80815 .60087 L p .707 .577 .707 r
F P
0 g
s
.49236 .54566 m .49588 .59812 L .50281 .58486 L p .707 .577 .707 r
F P
0 g
s
.50281 .58486 m .49928 .5324 L .49236 .54566 L p .707 .577 .707 r
F P
0 g
s
.34074 .68743 m .33694 .65426 L .31569 .64422 L p .707 .577 .707 r
F P
0 g
s
.33694 .65426 m .34074 .68743 L .36826 .69306 L p .707 .577 .707 r
F P
0 g
s
.8336 .66145 m .83571 .67773 L .81442 .6673 L p .707 .577 .707 r
F P
0 g
s
.81442 .6673 m .8123 .65102 L .8336 .66145 L p .707 .577 .707 r
F P
0 g
s
.40246 .73214 m .40035 .71586 L .36926 .71533 L p .707 .577 .707 r
F P
0 g
s
.40035 .71586 m .40246 .73214 L .43405 .72739 L p .707 .577 .707 r
F P
0 g
s
.43405 .72739 m .43194 .71111 L .40035 .71586 L p .707 .577 .707 r
F P
0 g
s
.47996 .63452 m .48376 .66769 L .49971 .65251 L p .707 .577 .707 r
F P
0 g
s
.49971 .65251 m .49591 .61934 L .47996 .63452 L p .707 .577 .707 r
F P
0 g
s
.66949 .67251 m .67161 .68879 L .65576 .7048 L p .707 .577 .707 r
F P
0 g
s
.6926 .64109 m .6888 .60792 L .71788 .59895 L p .707 .577 .707 r
F P
0 g
s
.6888 .60792 m .6926 .64109 L .66893 .65378 L p .707 .577 .707 r
F P
0 g
s
.29874 .55153 m .30227 .60398 L .31498 .61538 L p .707 .577 .707 r
F P
0 g
s
.37137 .73161 m .36926 .71533 L .34172 .70957 L p .707 .577 .707 r
F P
0 g
s
.36926 .71533 m .37137 .73161 L .40246 .73214 L p .707 .577 .707 r
F P
0 g
s
.78063 .59524 m .78443 .62841 L .75332 .62775 L p .707 .577 .707 r
F P
0 g
s
.75332 .62775 m .74952 .59458 L .78063 .59524 L p .707 .577 .707 r
F P
0 g
s
.30227 .60398 m .29874 .55153 L .2957 .53856 L p .707 .577 .707 r
F P
0 g
s
.46095 .70154 m .46306 .71782 L .48664 .70437 L p .707 .577 .707 r
F P
0 g
s
.48664 .70437 m .48453 .68809 L .46095 .70154 L p .707 .577 .707 r
F P
0 g
s
.67161 .68879 m .66949 .67251 L .69307 .65905 L p .707 .577 .707 r
F P
0 g
s
.31569 .64422 m .31949 .67739 L .34074 .68743 L p .707 .577 .707 r
F P
0 g
s
.72168 .63212 m .71788 .59895 L .74952 .59458 L p .707 .577 .707 r
F P
0 g
s
.71788 .59895 m .72168 .63212 L .6926 .64109 L p .707 .577 .707 r
F P
0 g
s
.74952 .59458 m .75332 .62775 L .72168 .63212 L p .707 .577 .707 r
F P
0 g
s
.31949 .67739 m .31569 .64422 L .30279 .63074 L p .707 .577 .707 r
F P
0 g
s
.34172 .70957 m .34383 .72585 L .37137 .73161 L p .707 .577 .707 r
F P
0 g
s
.8123 .65102 m .81442 .6673 L .78688 .66154 L p .707 .577 .707 r
F P
0 g
s
.78688 .66154 m .78476 .64526 L .8123 .65102 L p .707 .577 .707 r
F P
0 g
s
.49928 .5324 m .50281 .58486 L .49977 .57189 L p .707 .577 .707 r
F P
0 g
s
.49977 .57189 m .49624 .51944 L .49928 .5324 L p .707 .577 .707 r
F P
0 g
s
.34383 .72585 m .34172 .70957 L .32042 .69914 L p .707 .577 .707 r
F P
0 g
s
.69307 .65905 m .69519 .67533 L .67161 .68879 L p .707 .577 .707 r
F P
0 g
s
.49591 .61934 m .49971 .65251 L .50637 .63634 L p .707 .577 .707 r
F P
0 g
s
.50637 .63634 m .50257 .60317 L .49591 .61934 L p .707 .577 .707 r
F P
0 g
s
.48453 .68809 m .48664 .70437 L .50248 .68835 L p .707 .577 .707 r
F P
0 g
s
.50248 .68835 m .50037 .67207 L .48453 .68809 L p .707 .577 .707 r
F P
0 g
s
.69519 .67533 m .69307 .65905 L .72208 .64948 L p .707 .577 .707 r
F P
0 g
s
.32042 .69914 m .32253 .71542 L .34383 .72585 L p .707 .577 .707 r
F P
0 g
s
.2957 .53856 m .29923 .59102 L .30227 .60398 L p .707 .577 .707 r
F P
0 g
s
.78476 .64526 m .78688 .66154 L .75579 .66101 L p .707 .577 .707 r
F P
0 g
s
.75579 .66101 m .75367 .64473 L .78476 .64526 L p .707 .577 .707 r
F P
0 g
s
.30279 .63074 m .30659 .66391 L .31949 .67739 L p .707 .577 .707 r
F P
0 g
s
.29923 .59102 m .2957 .53856 L .30262 .5253 L p .707 .577 .707 r
F P
0 g
s
.72419 .66576 m .72208 .64948 L .75367 .64473 L p .707 .577 .707 r
F P
0 g
s
.72208 .64948 m .72419 .66576 L .69519 .67533 L p .707 .577 .707 r
F P
0 g
s
.75367 .64473 m .75579 .66101 L .72419 .66576 L p .707 .577 .707 r
F P
0 g
s
.30659 .66391 m .30279 .63074 L .29951 .61515 L p .707 .577 .707 r
F P
0 g
s
.32253 .71542 m .32042 .69914 L .30745 .68506 L p .707 .577 .707 r
F P
0 g
s
.50037 .67207 m .50248 .68835 L .50904 .67134 L p .707 .577 .707 r
F P
0 g
s
.50904 .67134 m .50693 .65506 L .50037 .67207 L p .707 .577 .707 r
F P
0 g
s
.50257 .60317 m .50637 .63634 L .50309 .62075 L p .707 .577 .707 r
F P
0 g
s
.50309 .62075 m .49929 .58758 L .50257 .60317 L p .707 .577 .707 r
F P
0 g
s
.49624 .51944 m .49977 .57189 L .48706 .5605 L p .707 .577 .707 r
F P
0 g
s
.48706 .5605 m .48353 .50805 L .49624 .51944 L p .707 .577 .707 r
F P
0 g
s
.30745 .68506 m .30956 .70134 L .32253 .71542 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29951 .61515 m .30331 .64832 L .30659 .66391 L p .707 .577 .707 r
F P
0 g
s
.30262 .5253 m .30615 .57776 L .29923 .59102 L p .707 .577 .707 r
F P
0 g
s
.30615 .57776 m .30262 .5253 L .31883 .51303 L p .707 .577 .707 r
F P
0 g
s
.30956 .70134 m .30745 .68506 L .30408 .66872 L p .707 .577 .707 r
F P
0 g
s
.30331 .64832 m .29951 .61515 L .30617 .59898 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50693 .65506 m .50904 .67134 L .50567 .65499 L p .707 .577 .707 r
F P
0 g
s
.50567 .65499 m .50356 .63871 L .50693 .65506 L p .707 .577 .707 r
F P
0 g
s
.49929 .58758 m .50309 .62075 L .49019 .60727 L p .707 .577 .707 r
F P
0 g
s
.49019 .60727 m .48639 .5741 L .49929 .58758 L p .707 .577 .707 r
F P
0 g
s
.48353 .50805 m .48706 .5605 L .46593 .5518 L p .707 .577 .707 r
F P
0 g
s
.46593 .5518 m .4624 .49934 L .48353 .50805 L p .707 .577 .707 r
F P
0 g
s
.30408 .66872 m .30619 .685 L .30956 .70134 L p .707 .577 .707 r
F P
0 g
s
.30617 .59898 m .30998 .63215 L .30331 .64832 L p .707 .577 .707 r
F P
0 g
s
.31883 .51303 m .32236 .56549 L .30615 .57776 L p .707 .577 .707 r
F P
0 g
s
.32236 .56549 m .31883 .51303 L .34274 .50296 L p .707 .577 .707 r
F P
0 g
s
.30998 .63215 m .30617 .59898 L .32212 .5838 L p .707 .577 .707 r
F P
0 g
s
.30619 .685 m .30408 .66872 L .31064 .65171 L p .707 .577 .707 r
F P
0 g
s
.4624 .49934 m .46593 .5518 L .43845 .54663 L p .707 .577 .707 r
F P
0 g
s
.43845 .54663 m .43492 .49417 L .4624 .49934 L p .707 .577 .707 r
F P
0 g
s
.50356 .63871 m .50567 .65499 L .4927 .64092 L p .707 .577 .707 r
F P
0 g
s
.4927 .64092 m .49059 .62464 L .50356 .63871 L p .707 .577 .707 r
F P
0 g
s
.48639 .5741 m .49019 .60727 L .46894 .59723 L p .707 .577 .707 r
F P
0 g
s
.46894 .59723 m .46514 .56406 L .48639 .5741 L p .707 .577 .707 r
F P
0 g
s
.31064 .65171 m .31275 .66799 L .30619 .685 L p .707 .577 .707 r
F P
0 g
s
.34627 .55542 m .34274 .50296 L .37201 .49608 L p .707 .577 .707 r
F P
0 g
s
.34274 .50296 m .34627 .55542 L .32236 .56549 L p .707 .577 .707 r
F P
0 g
s
.32212 .5838 m .32592 .61697 L .30998 .63215 L p .707 .577 .707 r
F P
0 g
s
.43492 .49417 m .43845 .54663 L .4073 .5455 L p .707 .577 .707 r
F P
0 g
s
.4073 .5455 m .40377 .49305 L .43492 .49417 L p .707 .577 .707 r
F P
0 g
s
.32592 .61697 m .32212 .5838 L .34579 .5711 L p .707 .577 .707 r
F P
0 g
s
.37554 .54853 m .37201 .49608 L .40377 .49305 L p .707 .577 .707 r
F P
0 g
s
.37201 .49608 m .37554 .54853 L .34627 .55542 L p .707 .577 .707 r
F P
0 g
s
.31275 .66799 m .31064 .65171 L .32648 .63569 L p .707 .577 .707 r
F P
0 g
s
.40377 .49305 m .4073 .5455 L .37554 .54853 L p .707 .577 .707 r
F P
0 g
s
.46514 .56406 m .46894 .59723 L .44142 .5916 L p .707 .577 .707 r
F P
0 g
s
.44142 .5916 m .43762 .55843 L .46514 .56406 L p .707 .577 .707 r
F P
0 g
s
.49059 .62464 m .4927 .64092 L .47141 .63049 L p .707 .577 .707 r
F P
0 g
s
.47141 .63049 m .46929 .61421 L .49059 .62464 L p .707 .577 .707 r
F P
0 g
s
.32648 .63569 m .3286 .65197 L .31275 .66799 L p .707 .577 .707 r
F P
0 g
s
.34959 .60427 m .34579 .5711 L .37487 .56213 L p .707 .577 .707 r
F P
0 g
s
.34579 .5711 m .34959 .60427 L .32592 .61697 L p .707 .577 .707 r
F P
0 g
s
.43762 .55843 m .44142 .5916 L .41031 .59093 L p .707 .577 .707 r
F P
0 g
s
.41031 .59093 m .40651 .55777 L .43762 .55843 L p .707 .577 .707 r
F P
0 g
s
.3286 .65197 m .32648 .63569 L .35006 .62224 L p .707 .577 .707 r
F P
0 g
s
.37867 .5953 m .37487 .56213 L .40651 .55777 L p .707 .577 .707 r
F P
0 g
s
.37487 .56213 m .37867 .5953 L .34959 .60427 L p .707 .577 .707 r
F P
0 g
s
.40651 .55777 m .41031 .59093 L .37867 .5953 L p .707 .577 .707 r
F P
0 g
s
.46929 .61421 m .47141 .63049 L .44386 .62473 L p .707 .577 .707 r
F P
0 g
s
.44386 .62473 m .44175 .60845 L .46929 .61421 L p .707 .577 .707 r
F P
0 g
s
.35006 .62224 m .35217 .63852 L .3286 .65197 L p .707 .577 .707 r
F P
0 g
s
.35217 .63852 m .35006 .62224 L .37907 .61267 L p .707 .577 .707 r
F P
0 g
s
.44175 .60845 m .44386 .62473 L .41278 .6242 L p .707 .577 .707 r
F P
0 g
s
.41278 .6242 m .41066 .60792 L .44175 .60845 L p .707 .577 .707 r
F P
0 g
s
.38118 .62895 m .37907 .61267 L .41066 .60792 L p .707 .577 .707 r
F P
0 g
s
.37907 .61267 m .38118 .62895 L .35217 .63852 L p .707 .577 .707 r
F P
0 g
s
.41066 .60792 m .41278 .6242 L .38118 .62895 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00RGoo2@00Rgoo0022Ool70003FUH00`00
FUIJEP03FUH90022Ool007eoo`D000YJEP03001JEUYF00UJEP03001JEUYF00H007aoo`00Mgoo1P00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000N7oo001bOol50008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001eOol0071oo`800003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0079o
o`00KWoo0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00L7oo001/Ool20005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001_Ool006Yoo`8000MJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0006ioo`00
J7oo0`0025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUH006eoo`00Igoo00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH0001/Ool006Io
o`05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1YOol006Aoo`8000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEV]oo`00Hgoo00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
Jgoo001ROol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0069oo`8000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00HGoo00<005YF00001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0J7oo001QOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0
061oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061o
o`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061oo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065o
o`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Moo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP8000aJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00Igoo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001W
Ool006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00Hgoo00@005YFFUH0
00IJEP8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH3001VOol006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`00IWoo001SOol01000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF3`001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIVOol006Aoo`03001JEUYF
00L000AJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0006Eoo`00H7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP<006Eoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001IOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001HOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001GOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOol90014Ool0
05Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000AOol70004FUH00`00FUIJEP02FUH8000lOol005Ao
o`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1@00=goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0027oo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Ioo`80009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@002EYF00<005YFFUH015YF1@00
1EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUH0000`Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP03FUH6
00000eYF001JEP05FUH20008FUH00`00FUIJEP09FUH20003FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000_Ool005Aoo`04001JEUYF0003FUH01000FUIJEUYF0P0017oo00@005YFFUH000IJEPl000MJEP@0
0003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00@005YFFUH000=JEP04001J
EP000007Ool00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUH000030002FUH200000eYF001J
EP020003FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003FUH20009Ool30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH01@00FUIJEUYF00000UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo001DOol2000015YF001JEUYF0`001goo0`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool0
05Aoo`800004FUH005YF0003FUH30002Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020002FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ao
o`800003FUH0000000EJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo
00@005YF000000EJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol2
00000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPl000EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP05001J
EUYFFUH0000]Ool004Moo`T000Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001J
EUYF00=JEP03001JEUYF00@001Yoo`<000AJEP05001JEUYFFUH0000]Ool0045oo`H000AJEP03001J
EUYF009JEPH000=JEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH3000QOol300000eYF001JEP02FUH00`00Oomo
o`0[Ool003eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP80009JEP04001JEUYF0007FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP06FUH50005FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP8000io
oa0000Moo`04001JEP000003FUH2000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH01000FUH000002Goo1`0015YF00<0
05YFFUH01EYF00@005YFFUIJEPP000=JEP03001JEUYF008002aoo`00=goo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<005YFFUH015YF100025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0P001goo10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF100015YF00@005YF000002aoo`00=Goo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00IJEP03001JEP0000L000MJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF100017oo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P000eYF1000;7oo
000cOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03
FUH00`00FUIJEP020006FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH90005FUH20003FUH0
0`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0
0`0015YF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0`00;7oo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP03FUH40007FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
1UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00P005YFFUH0
05YF001JEP001EYF00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP800004FUH00000000/Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH4
00000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH01000FUH000000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YFFUIJEP80
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEP00001JEP00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP<00003FUH005YF009JEP<000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00H005YFFUH005YF000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`0025YF00<005YFFUH00UYF3`001UYF00@0
05YFFUIJEP<0009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP020002FUH01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YF0000
009JEP03001JEUYF00EJEPL000=JEPL000AJEP@0009JEP03001JEUYF009JEP80009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF0P001EYF00<005YFFUH00UYF0P0000=JEP0000001`001EYF00<005YF
FUH01eYF0`0015YF00D005YF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEPH000MJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF009J
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEPD000MJEP03001JEUYF00YJEP8000=J
EP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH4
0005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP8000MJEP@0009JEP04001JEUYFFUH50007FUH0
0`00FUIJEP09FUH500001EYF001JEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00=JEP03001JEP00008000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ400004FUH005YF0005FUH20002FUH2
0002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP020002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH6000>Ool00`00FUIJEP020002FUH00`00FUIJEP0200000eYF001JEP02FUH0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP04
001JEUYFFUH20004FUH00`00FUIJEP06FUH@0002FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0Z
Ool002eoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000DOol200000eYF001JEP02
FUH30003FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYF001JEP001EYF00@005YF000000IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030003FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<0
05YFFUH00eYF10002Woo0`002goo0`0015YF00<007oo00000P0000=JEP00FUH00UYF00@005YFFUH0
00IJEP03001JEUYF00MJEPD00003FUH005YF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00005FUH200000eYF001JEP05FUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006Ool3000/Ool002eoo`04001JEUYF
0003FUH01000FUIJEUYF0P003Goo1@002Woo0`000eYF00<005YF00001@000eYF0P0000=JEP00FUH0
1EYF00@005YFFUIJEPL000EJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP<00003FUH005YF
00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Eoo`03001JEP00
02aoo`00;Goo00@005YFFUH000=JEP04001JEP00000?Ool:0006Ool200000eYF00000003FUH01000
FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF0000009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP07001JEUYF001JEP00FUH0
0`0000=JEP0000001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF00<005YFFUH00P000Woo
0P0000=JEP000000:goo000]Ool200000eYF001JEP02FUH2000@Ool40002FUH00`00FUIJEP02FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH2
0004FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00002FUH01000FUIJEUYF0`0025YF00<005YFFUH010000UYF3@0015YF00@005YFFUIJEP80
0003FUH005YF008002]oo`00;Goo0P0000AJEP00FUIJEP<000aoo`@000IJEP03001JEUYF00IJEP80
0004FUH005YF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUH00002FUH20003FUH01000FUIJEP000UYF00<005YFFUH01EYF2P003Goo1@00
15YF0`000UYF00<007ooOol0:Goo000]Ool2000015YF000000000eYF1@000goo100000=JEP00FUH0
1eYF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEP0000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0`0015YF00<005YFFUH00UYF
0P0017oo1@004goo0P000UYF00<005YF00000UYF00<007ooOol0:Goo000]Ool200000eYF00000005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00000000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000IJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00AJEP03001JEUYF00AJEP03001JEP00008000Ioo`D0019oo`D00006FUH005YF001JEP00:goo000^
Ool200000eYF001JEP04FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH20005FUH50007Ool5000AOol01000FUIJEP000UYF0P000UYF0P00:goo
000^Ool200000eYF001JEP04FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP03FUH30004
FUH01000FUIJEUYF0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUH000=JEP800003FUH005YF009JEP<000=JEP03001oogoo00Ioo`<0011oo`8000=J
EP03001JEUYF009JEP03001JEP0002aoo`00;Woo00@005YFFUH000=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP800003FUH005YF00IJEP03001JEUYF00=JEPD0
00MJEP04001JEUYFFUH20007FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00@005YFFUH0009JEP06001JEUYFFUH005YF0P000UYF00D005YF
FUIJEP0001Uoo`8000EJEP03001JEUYF00=JEP8002aoo`00;Woo00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30005FUH40006FUH00`00FUIJEP03FUH5
0007FUH01000FUH000002UYF0P0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00`0015YF0`000eYF00D005YFFUIJEP0001Ioo`<00003FUH005YF
00AJEP03001JEUYF00=JEP<002]oo`00;Woo00@005YFFUIJEP<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH50002FUH7000;FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`0AOol3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Ool0000[Ool002ioo`07001JEUYFFUH005YF
00001eYF00<005YFFUH01EYF00<005YFFUH00UYF400000=JEP00FUH00UYF00<005YFFUH00eYF00<0
05YF00003P001UYF00<005YFFUH025YF00@005YFFUH0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02FUH00`00FUH0
000300000eYF0000000<Ool60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000Woo00<007ooOol0
:Goo000^Ool01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH015YF1P002EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEP00Ool00002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH20004FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP03FUH?0004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000Woo0P00:goo000^Ool00`00FUH00003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05
0004FUH01@00FUIJEP00Ool00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH015YF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000Aoo`03001JEP0002Yoo`00;goo0P0015YF00<005YFFUH015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF1@0000UJEP00FUIJEP00Ool0
05YF00001UYF00<005YFFUH01eYF00@005YFFUIJEP@000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo009o
o`04001JEUYF000ZOol002moo`8000AJEP03001JEUYF00=JEP<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEPD0009JEP05001oo`00FUH00006FUH00`00FUIJ
EP07FUH40003FUH00`00FUIJEP02FUH20005FUHE0008FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001Goo00@005YFFUH002Yoo`00;goo0P0015YF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEP0000@00004Ool005YF000:
FUH60007FUH00`00FUIJEP09000<FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP06FUH01000FUH0
05YF10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000000Ioo`80009JEP03001oogoo02Qoo`00;Woo00<005YF000015YF00@005YF000000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP03001JEUYF00=JEPl000AJEP03
001JEUYF00IJEP@000MJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH40007FUH00`00
FUIJEP0300000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP05
FUH30007Ool01@00FUH005YF0000:goo000^Ool00`00FUH00004FUH50006FUH00`00FUIJEP06FUH@
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP030003
FUH300000eYF001JEP06FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP02FUH2000:Ool00`00FUIJ
EP02000[Ool002ioo`04001JEUYF0002FUH00`00Oomoo`03Ool40002FUH00`00FUIJEP060004FUH0
0`00FUIJEP06FUH00`00FUH000030002Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH01P00FUIJEP00FUH000AJEP03001JEP00008000IJEP03001JEUYF00=JEPD000MJEP03001JEP00
008000]oo`05001JEUYFFUH0000/Ool002ioo`06001JEUYF001JEP002Woo1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0000Aoo`00000000IJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP<0
0004FUH005YFFUH30004FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH50003FUH6000<Ool2
0004FUH00`00Oomoo`0ZOol002ioo`06001JEUYF001JEP002Woo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF0`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH0100025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH00P00
0UYF00<005YF000015YF00<005YFFUH00UYF00@005YFFUIJEQ00011oo`800003FUH005YF009JEP03
001oogoo02]oo`00;Woo00<005YFFUH00P002Goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00P000eYF4@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH00UYF00D005YFFUH005YF0080009JEP03001JEUYF
00=JEP04001JEUYF000MOol20003FUH01000FUH00000;Woo000_Ool00`00FUH00008Ool30008FUH0
0`00FUIJEP02FUH?0006FUH01000FUIJEUYF0P0000=JEP00FUH00P002EYF0P0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF10001EYF00<005YFFUH00P006Goo0`001EYF0P00<7oo000_Ool20007Ool20002
FUH00`00FUIJEP05FUH6000?Ool40002FUH00`00FUIJEP02FUH300000eYF00000007FUH20003FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH200000eYF001JEP0300000eYF00000003FUH00`00FUIJEP02000GOol200000eYF
001JEP05FUH00`00Oomoo`0_Ool002moo`<000Aoo`8000EJEP03001JEUYF009JEP8001Uoo`<000AJ
EP04001JEP00FUH20006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030002FUH20000
1EYF000005YF00000UYF0P0057oo0`000eYF00<005YFFUH00UYF0P00<Woo000_Ool01000FUIJEP00
0Woo00<005YFFUH01EYF00<005YF00000P006Goo0P000eYF0P000eYF00D005YF001oo`0000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00@000=JEPD000=JEP03001oogoo00ioo`@000MJ
EP04001JEUYF000dOol002moo`03001JEUYF00@000MJEP8001Yoo`8000IJEP<00006FUH005YFFUH0
07oo0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0100015YF00@005YFFUIJEPT000Moo`@0009J
EP03001JEUYF00IJEP<003Eoo`00;goo0P0000EJEP00001JEP0000EJEP8001Qoo`@00003FUH005YF
00EJEP03001JEUYF0080009JEP05001ooeYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP060002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH2000g
Ool002moo`800003FUH00000009JEP03001JEUYF00<001Aoo`D000EJEP03001JEUYF00EJEP08001J
EUYFFUH005YF001oo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0017oo0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00>Goo000`Ool00`00
FUH00003FUH30003FUH90007Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
00001EYF000005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH01@000Woo0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00?7oo000`Ool20004FUH00`00FUH0
0007FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002Ool3
00000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000eYF0`000goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?goo000`Ool20003FUH01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0017oo10000eYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00`000UYF00<005YF00003P00
AGoo000`Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0005FUH01000FUIJEUYF0P0000EJEP00FUIJEP00059oo`00;goo00<005YF00000P001EYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@000]JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00=JEPH0009JEP03001JEUYF009JEP<0009JEP03001oogoo051oo`00;goo00D005YF001o
o`0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000MJEP03001JEUYF00EJEP04001JEP000008
Ool00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004Ool30004FUH01P00FUH00000FUH0059oo`00
;goo00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF1@001eYF00<005YFFUH0
15YF0`002Woo00D005YF001oo`0000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00=JEP03001oogoo00=o
o`800003FUH0000000=JEP04001JEP00001COol002moo`03001JEP0000Aoo`800003FUH005YF00IJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF009JEP8000aoo`800004FUH007oo0004FUH00`00FUIJ
EP04FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP02FUH01000Oomoogoo0`001EYF0P0000EJEP00FUIJEP0005=oo`00<7oo00<0
07ooOol01Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003Goo00@005YF
0000009oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP06001JEUYFFUH007oo0`0000=JEP00FUH01EYF
00@005YF0000009JEP03001oogoo055oo`00<7oo00<007ooOol027oo10000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P003goo00<005YFFUH00P000goo00D005YFFUIJEP00015JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000Dgoo000`Ool00`00Oomoo`0<Ool@000DOol01@00FUIJEUYF0000
1Goo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP<000MJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`1AOol0
031oo`80031oo`03001JEUYF009JEP03001oogoo00Aoo`03001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP<000QJEP03001JEUYF
00EJEP03001JEP00009oo`80059oo`00<7oo00<005YF0000;Goo0`000eYF00<007ooOol01Woo0P00
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P000UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0017oo00<007ooOol0D7oo000aOol00`00
FUH0000[Ool01000FUIJEP000UYF00<007ooOol027oo00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001oogoo00=oo`03001oogoo051oo`00<Goo00@005YFFUH002Qoo`8000AJ
EP03001JEP0000]oo`8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`80059oo`00
<Goo00<005YFFUH00`008goo0`001UYF0P003Woo0P000eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF1`001UYF00<005YFFUH01UYF00<005YFFUH00P001goo00<0
05YF0000DGoo000bOol00`00FUH00002FUH2000MOol40002FUH00`00FUIJEP03FUH2000AOol20000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH40002FUH50006FUH0
0`00FUIJEP06FUH30008Ool01000FUIJEP00DGoo000bOol00`00FUH00004FUH3000EOol50006FUH0
1000FUIJEUYF0P005Goo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF000010001EYF
1@001eYF00<005YFFUH015YF0P002Woo00@005YFFUH0055oo`00<goo0P001EYF00<005YF00000`00
3Goo10000UYF00<005YFFUH01UYF00@005YF000001]oo`H0009JEP03001JEUYF00YJEP03001JEUYF
00AJEPP000AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00@000]oo`800003FUH007oo055oo`00
=7oo00<005YFFUH00eYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0`008goo5P000goo1@00
15YF00<005YFFUH01UYF00<005YFFUH00UYF1`003Woo00D005YF001JEP00059oo`00=Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00=Woo00<007oo
Ool02goo4P0057oo00D005YFFUIJEP0005=oo`00=goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000P00>7oo00<007ooOol0<7oo00<005YFFUH00UYF00<007ooOol0
DGoo000iOol50004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000kOol2000_Ool30003FUH00`00
Oomoo`1BOol003iooa80045oo`03001JEP0002aoo`80009JEP04001JEUYF001EOol0099oo`03001J
EP0002Uoo`8000AJEP03001JEP0005Ioo`00TWoo00<005YFFUH00P009Goo0P001UYF0P00Egoo002C
Ool01000FUH005YF0`0087oo0P0000=JEP00FUH01EYF00<007ooOol0EWoo002DOol20004FUH3000J
Ool30003FUH00`00FUIJEP02FUH2001IOol009Eoo`8000AJEP03001JEP0000<0011oo`H000MJEP04
001JEUYF001KOol009Ioo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP<0
05aoo`00Ugoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P00GWoo002IOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH3001POol009]oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006=o
o`00WWoo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00IWoo002ROol?001/Ool00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59874 .75859 m .59656 .70477 L .56539 .70335 L p .707 .577 .707 r
F P
0 g
s
.59656 .70477 m .59874 .75859 L .63055 .75641 L p .707 .577 .707 r
F P
0 g
s
.63055 .75641 m .62836 .70258 L .59656 .70477 L p .707 .577 .707 r
F P
0 g
s
.62836 .70258 m .63055 .75641 L .65989 .75084 L p .707 .577 .707 r
F P
0 g
s
.65989 .75084 m .6577 .69701 L .62836 .70258 L p .707 .577 .707 r
F P
0 g
s
.56758 .75718 m .56539 .70335 L .53793 .69847 L p .707 .577 .707 r
F P
0 g
s
.56539 .70335 m .56758 .75718 L .59874 .75859 L p .707 .577 .707 r
F P
0 g
s
.6577 .69701 m .65989 .75084 L .68389 .74242 L p .707 .577 .707 r
F P
0 g
s
.68389 .74242 m .6817 .6886 L .6577 .69701 L p .707 .577 .707 r
F P
0 g
s
.54011 .7523 m .53793 .69847 L .51684 .69061 L p .707 .577 .707 r
F P
0 g
s
.53793 .69847 m .54011 .7523 L .56758 .75718 L p .707 .577 .707 r
F P
0 g
s
.60142 .82493 m .59906 .78998 L .56791 .78886 L p .707 .577 .707 r
F P
0 g
s
.59906 .78998 m .60142 .82493 L .63318 .82189 L p .707 .577 .707 r
F P
0 g
s
.63318 .82189 m .63082 .78694 L .59906 .78998 L p .707 .577 .707 r
F P
0 g
s
.63082 .78694 m .63318 .82189 L .66245 .81498 L p .707 .577 .707 r
F P
0 g
s
.66245 .81498 m .66008 .78003 L .63082 .78694 L p .707 .577 .707 r
F P
0 g
s
.6817 .6886 m .68389 .74242 L .70019 .73199 L p .707 .577 .707 r
F P
0 g
s
.70019 .73199 m .69801 .67817 L .6817 .6886 L p .707 .577 .707 r
F P
0 g
s
.57028 .82381 m .56791 .78886 L .54042 .78369 L p .707 .577 .707 r
F P
0 g
s
.56791 .78886 m .57028 .82381 L .60142 .82493 L p .707 .577 .707 r
F P
0 g
s
.66008 .78003 m .66245 .81498 L .68636 .80488 L p .707 .577 .707 r
F P
0 g
s
.68636 .80488 m .68399 .76993 L .66008 .78003 L p .707 .577 .707 r
F P
0 g
s
.51684 .69061 m .51903 .74444 L .54011 .7523 L p .707 .577 .707 r
F P
0 g
s
.51903 .74444 m .51684 .69061 L .50421 .68053 L p .707 .577 .707 r
F P
0 g
s
.54279 .81864 m .54042 .78369 L .51929 .77497 L p .707 .577 .707 r
F P
0 g
s
.54042 .78369 m .54279 .81864 L .57028 .82381 L p .707 .577 .707 r
F P
0 g
s
.60326 .87011 m .60194 .85279 L .5708 .85176 L p .707 .577 .707 r
F P
0 g
s
.60194 .85279 m .60326 .87011 L .635 .86682 L p .707 .577 .707 r
F P
0 g
s
.635 .86682 m .63368 .84949 L .60194 .85279 L p .707 .577 .707 r
F P
0 g
s
.63368 .84949 m .635 .86682 L .66424 .85952 L p .707 .577 .707 r
F P
0 g
s
.66424 .85952 m .66292 .84219 L .63368 .84949 L p .707 .577 .707 r
F P
0 g
s
.69801 .67817 m .70019 .73199 L .70722 .72057 L p .707 .577 .707 r
F P
0 g
s
.70722 .72057 m .70503 .66674 L .69801 .67817 L p .707 .577 .707 r
F P
0 g
s
.68399 .76993 m .68636 .80488 L .70256 .79258 L p .707 .577 .707 r
F P
0 g
s
.70256 .79258 m .7002 .75763 L .68399 .76993 L p .707 .577 .707 r
F P
0 g
s
.57212 .86908 m .5708 .85176 L .54331 .8465 L p .707 .577 .707 r
F P
0 g
s
.5708 .85176 m .57212 .86908 L .60326 .87011 L p .707 .577 .707 r
F P
0 g
s
.50421 .68053 m .50639 .73436 L .51903 .74444 L p .707 .577 .707 r
F P
0 g
s
.66292 .84219 m .66424 .85952 L .68811 .84892 L p .707 .577 .707 r
F P
0 g
s
.68811 .84892 m .68679 .8316 L .66292 .84219 L p .707 .577 .707 r
F P
0 g
s
.51929 .77497 m .52166 .80992 L .54279 .81864 L p .707 .577 .707 r
F P
0 g
s
.54331 .8465 m .54463 .86382 L .57212 .86908 L p .707 .577 .707 r
F P
0 g
s
.50639 .73436 m .50421 .68053 L .50125 .66923 L p .707 .577 .707 r
F P
0 g
s
.52166 .80992 m .51929 .77497 L .50659 .76355 L p .707 .577 .707 r
F P
0 g
s
.54463 .86382 m .54331 .8465 L .52216 .83752 L p .707 .577 .707 r
F P
0 g
s
.50117 .82687 m .48132 .34094 L .43733 .33895 L p .707 .577 .707 r
F P
0 g
s
.50659 .76355 m .50895 .79851 L .52166 .80992 L p .707 .577 .707 r
F P
0 g
s
.50125 .66923 m .50344 .72306 L .50639 .73436 L p .707 .577 .707 r
F P
0 g
s
.52348 .85485 m .52216 .83752 L .50942 .82572 L p .707 .577 .707 r
F P
0 g
s
.50895 .79851 m .50659 .76355 L .50354 .75056 L p .707 .577 .707 r
F P
0 g
s
.50344 .72306 m .50125 .66923 L .50828 .6578 L p .707 .577 .707 r
F P
0 g
s
.50942 .82572 m .51074 .84304 L .52348 .85485 L p .707 .577 .707 r
F P
0 g
s
.50354 .75056 m .50591 .78551 L .50895 .79851 L p .707 .577 .707 r
F P
0 g
s
.50828 .6578 m .51046 .71163 L .50344 .72306 L p .707 .577 .707 r
F P
0 g
s
.51074 .84304 m .50942 .82572 L .50634 .81223 L p .707 .577 .707 r
F P
0 g
s
.50591 .78551 m .50354 .75056 L .51046 .73726 L p .707 .577 .707 r
F P
0 g
s
.51046 .71163 m .50828 .6578 L .52458 .64737 L p .707 .577 .707 r
F P
0 g
s
.50634 .81223 m .50766 .82956 L .51074 .84304 L p .707 .577 .707 r
F P
0 g
s
.51046 .73726 m .51283 .77222 L .50591 .78551 L p .707 .577 .707 r
F P
0 g
s
.52458 .64737 m .52677 .7012 L .51046 .71163 L p .707 .577 .707 r
F P
0 g
s
.50766 .82956 m .50634 .81223 L .51323 .79839 L p .707 .577 .707 r
F P
0 g
s
.52677 .7012 m .52458 .64737 L .54858 .63896 L p .707 .577 .707 r
F P
0 g
s
.51283 .77222 m .51046 .73726 L .52667 .72497 L p .707 .577 .707 r
F P
0 g
s
.51323 .79839 m .51454 .81571 L .50766 .82956 L p .707 .577 .707 r
F P
0 g
s
.52667 .72497 m .52904 .75992 L .51283 .77222 L p .707 .577 .707 r
F P
0 g
s
.54858 .63896 m .55077 .69279 L .52677 .7012 L p .707 .577 .707 r
F P
0 g
s
.51454 .81571 m .51323 .79839 L .52939 .78554 L p .707 .577 .707 r
F P
0 g
s
.52904 .75992 m .52667 .72497 L .55058 .71487 L p .707 .577 .707 r
F P
0 g
s
.52939 .78554 m .53071 .80287 L .51454 .81571 L p .707 .577 .707 r
F P
0 g
s
.55058 .71487 m .55295 .74982 L .52904 .75992 L p .707 .577 .707 r
F P
0 g
s
.53071 .80287 m .52939 .78554 L .55326 .77495 L p .707 .577 .707 r
F P
0 g
s
.55326 .77495 m .55458 .79227 L .53071 .80287 L p .707 .577 .707 r
F P
0 g
s
.48132 .34094 m .50117 .82687 L .54608 .82377 L p .707 .577 .707 r
F P
0 g
s
.54608 .82377 m .52623 .33785 L .48132 .34094 L p .707 .577 .707 r
F P
0 g
s
.55077 .69279 m .54858 .63896 L .57792 .63339 L p .707 .577 .707 r
F P
0 g
s
.57792 .63339 m .58011 .68722 L .55077 .69279 L p .707 .577 .707 r
F P
0 g
s
.55295 .74982 m .55058 .71487 L .57984 .70796 L p .707 .577 .707 r
F P
0 g
s
.57984 .70796 m .58221 .74291 L .55295 .74982 L p .707 .577 .707 r
F P
0 g
s
.55458 .79227 m .55326 .77495 L .5825 .76765 L p .707 .577 .707 r
F P
0 g
s
.5825 .76765 m .58382 .78497 L .55458 .79227 L p .707 .577 .707 r
F P
0 g
s
.52623 .33785 m .54608 .82377 L .5875 .81589 L p .707 .577 .707 r
F P
0 g
s
.58011 .68722 m .57792 .63339 L .60973 .63121 L p .707 .577 .707 r
F P
0 g
s
.60973 .63121 m .61191 .68503 L .58011 .68722 L p .707 .577 .707 r
F P
0 g
s
.58221 .74291 m .57984 .70796 L .61161 .70491 L p .707 .577 .707 r
F P
0 g
s
.61161 .70491 m .61397 .73987 L .58221 .74291 L p .707 .577 .707 r
F P
0 g
s
.58382 .78497 m .5825 .76765 L .61425 .76435 L p .707 .577 .707 r
F P
0 g
s
.61425 .76435 m .61556 .78167 L .58382 .78497 L p .707 .577 .707 r
F P
0 g
s
.5875 .81589 m .56765 .32997 L .52623 .33785 L p .707 .577 .707 r
F P
0 g
s
.52216 .83752 m .52348 .85485 L .54463 .86382 L p .707 .577 .707 r
F P
0 g
s
.68679 .8316 m .68811 .84892 L .70428 .83608 L p .707 .577 .707 r
F P
0 g
s
.70428 .83608 m .70296 .81875 L .68679 .8316 L p .707 .577 .707 r
F P
0 g
s
.7002 .75763 m .70256 .79258 L .70948 .77929 L p .707 .577 .707 r
F P
0 g
s
.70948 .77929 m .70712 .74433 L .7002 .75763 L p .707 .577 .707 r
F P
0 g
s
.70503 .66674 m .70722 .72057 L .70426 .70926 L p .707 .577 .707 r
F P
0 g
s
.70426 .70926 m .70208 .65544 L .70503 .66674 L p .707 .577 .707 r
F P
0 g
s
.45718 .82487 m .43733 .33895 L .39855 .33206 L p .707 .577 .707 r
F P
0 g
s
.43733 .33895 m .45718 .82487 L .50117 .82687 L p .707 .577 .707 r
F P
0 g
s
.64275 .70603 m .64512 .74099 L .61397 .73987 L p .707 .577 .707 r
F P
0 g
s
.61397 .73987 m .61161 .70491 L .64275 .70603 L p .707 .577 .707 r
F P
0 g
s
.64539 .76538 m .6467 .78271 L .61556 .78167 L p .707 .577 .707 r
F P
0 g
s
.61556 .78167 m .61425 .76435 L .64539 .76538 L p .707 .577 .707 r
F P
0 g
s
.56765 .32997 m .5875 .81589 L .62138 .80399 L p .707 .577 .707 r
F P
0 g
s
.64089 .63262 m .64308 .68645 L .61191 .68503 L p .707 .577 .707 r
F P
0 g
s
.61191 .68503 m .60973 .63121 L .64089 .63262 L p .707 .577 .707 r
F P
0 g
s
.62138 .80399 m .60152 .31807 L .56765 .32997 L p .707 .577 .707 r
F P
0 g
s
.70296 .81875 m .70428 .83608 L .71116 .82223 L p .707 .577 .707 r
F P
0 g
s
.71116 .82223 m .70984 .80491 L .70296 .81875 L p .707 .577 .707 r
F P
0 g
s
.4184 .81798 m .39855 .33206 L .36879 .32095 L p .707 .577 .707 r
F P
0 g
s
.39855 .33206 m .4184 .81798 L .45718 .82487 L p .707 .577 .707 r
F P
0 g
s
.70712 .74433 m .70948 .77929 L .70644 .7663 L p .707 .577 .707 r
F P
0 g
s
.70644 .7663 m .70407 .73134 L .70712 .74433 L p .707 .577 .707 r
F P
0 g
s
.70208 .65544 m .70426 .70926 L .69163 .69919 L p .707 .577 .707 r
F P
0 g
s
.69163 .69919 m .68944 .64536 L .70208 .65544 L p .707 .577 .707 r
F P
0 g
s
.60152 .31807 m .62138 .80399 L .6444 .78925 L p .707 .577 .707 r
F P
0 g
s
.6444 .78925 m .62455 .30332 L .60152 .31807 L p .707 .577 .707 r
F P
0 g
s
.25573 .72178 m .25355 .66795 L .22239 .66653 L p .707 .577 .707 r
F P
0 g
s
.25355 .66795 m .25573 .72178 L .28754 .71959 L p .707 .577 .707 r
F P
0 g
s
.28754 .71959 m .28536 .66577 L .25355 .66795 L p .707 .577 .707 r
F P
0 g
s
.28536 .66577 m .28754 .71959 L .31688 .71402 L p .707 .577 .707 r
F P
0 g
s
.31688 .71402 m .31469 .66019 L .28536 .66577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70984 .80491 m .71116 .82223 L .70808 .80875 L p .707 .577 .707 r
F P
0 g
s
.70808 .80875 m .70676 .79142 L .70984 .80491 L p .707 .577 .707 r
F P
0 g
s
.22457 .72036 m .22239 .66653 L .19492 .66166 L p .707 .577 .707 r
F P
0 g
s
.22239 .66653 m .22457 .72036 L .25573 .72178 L p .707 .577 .707 r
F P
0 g
s
.38864 .80687 m .36879 .32095 L .35095 .30671 L p .707 .577 .707 r
F P
0 g
s
.36879 .32095 m .38864 .80687 L .4184 .81798 L p .707 .577 .707 r
F P
0 g
s
.70407 .73134 m .70644 .7663 L .69373 .75488 L p .707 .577 .707 r
F P
0 g
s
.69373 .75488 m .69137 .71993 L .70407 .73134 L p .707 .577 .707 r
F P
0 g
s
.68944 .64536 m .69163 .69919 L .67054 .69132 L p .707 .577 .707 r
F P
0 g
s
.67054 .69132 m .66836 .6375 L .68944 .64536 L p .707 .577 .707 r
F P
0 g
s
.31469 .66019 m .31688 .71402 L .34088 .70561 L p .707 .577 .707 r
F P
0 g
s
.34088 .70561 m .33869 .65178 L .31469 .66019 L p .707 .577 .707 r
F P
0 g
s
.1971 .71548 m .19492 .66166 L .17383 .6538 L p .707 .577 .707 r
F P
0 g
s
.19492 .66166 m .1971 .71548 L .22457 .72036 L p .707 .577 .707 r
F P
0 g
s
.66836 .6375 m .67054 .69132 L .64308 .68645 L p .707 .577 .707 r
F P
0 g
s
.64308 .68645 m .64089 .63262 L .66836 .6375 L p .707 .577 .707 r
F P
0 g
s
.67024 .71121 m .6726 .74616 L .64512 .74099 L p .707 .577 .707 r
F P
0 g
s
.64512 .74099 m .64275 .70603 L .67024 .71121 L p .707 .577 .707 r
F P
0 g
s
.67288 .77064 m .67419 .78797 L .6467 .78271 L p .707 .577 .707 r
F P
0 g
s
.6467 .78271 m .64539 .76538 L .67288 .77064 L p .707 .577 .707 r
F P
0 g
s
.62455 .30332 m .6444 .78925 L .65431 .77309 L p .707 .577 .707 r
F P
0 g
s
.65431 .77309 m .63446 .28717 L .62455 .30332 L p .707 .577 .707 r
F P
0 g
s
.25841 .78812 m .25605 .75316 L .2249 .75204 L p .707 .577 .707 r
F P
0 g
s
.25605 .75316 m .25841 .78812 L .29017 .78507 L p .707 .577 .707 r
F P
0 g
s
.29017 .78507 m .28781 .75012 L .25605 .75316 L p .707 .577 .707 r
F P
0 g
s
.28781 .75012 m .29017 .78507 L .31944 .77817 L p .707 .577 .707 r
F P
0 g
s
.31944 .77817 m .31707 .74321 L .28781 .75012 L p .707 .577 .707 r
F P
0 g
s
.33869 .65178 m .34088 .70561 L .35719 .69518 L p .707 .577 .707 r
F P
0 g
s
.35719 .69518 m .355 .64135 L .33869 .65178 L p .707 .577 .707 r
F P
0 g
s
.70676 .79142 m .70808 .80875 L .69534 .79694 L p .707 .577 .707 r
F P
0 g
s
.69534 .79694 m .69402 .77962 L .70676 .79142 L p .707 .577 .707 r
F P
0 g
s
.22727 .787 m .2249 .75204 L .19742 .74687 L p .707 .577 .707 r
F P
0 g
s
.2249 .75204 m .22727 .787 L .25841 .78812 L p .707 .577 .707 r
F P
0 g
s
.69137 .71993 m .69373 .75488 L .6726 .74616 L p .707 .577 .707 r
F P
0 g
s
.6726 .74616 m .67024 .71121 L .69137 .71993 L p .707 .577 .707 r
F P
0 g
s
.31707 .74321 m .31944 .77817 L .34335 .76807 L p .707 .577 .707 r
F P
0 g
s
.34335 .76807 m .34098 .73311 L .31707 .74321 L p .707 .577 .707 r
F P
0 g
s
.17383 .6538 m .17602 .70762 L .1971 .71548 L p .707 .577 .707 r
F P
0 g
s
.17602 .70762 m .17383 .6538 L .1612 .64372 L p .707 .577 .707 r
F P
0 g
s
.3708 .79263 m .35095 .30671 L .34678 .29073 L p .707 .577 .707 r
F P
0 g
s
.35095 .30671 m .3708 .79263 L .38864 .80687 L p .707 .577 .707 r
F P
0 g
s
.19978 .78183 m .19742 .74687 L .17629 .73815 L p .707 .577 .707 r
F P
0 g
s
.19742 .74687 m .19978 .78183 L .22727 .787 L p .707 .577 .707 r
F P
0 g
s
.26025 .8333 m .25893 .81598 L .22779 .81494 L p .707 .577 .707 r
F P
0 g
s
.25893 .81598 m .26025 .8333 L .29199 .83 L p .707 .577 .707 r
F P
0 g
s
.29199 .83 m .29067 .81268 L .25893 .81598 L p .707 .577 .707 r
F P
0 g
s
.29067 .81268 m .29199 .83 L .32123 .8227 L p .707 .577 .707 r
F P
0 g
s
.32123 .8227 m .31991 .80538 L .29067 .81268 L p .707 .577 .707 r
F P
0 g
s
.355 .64135 m .35719 .69518 L .36421 .68375 L p .707 .577 .707 r
F P
0 g
s
.36421 .68375 m .36202 .62993 L .355 .64135 L p .707 .577 .707 r
F P
0 g
s
.34098 .73311 m .34335 .76807 L .35955 .75577 L p .707 .577 .707 r
F P
0 g
s
.35955 .75577 m .35719 .72081 L .34098 .73311 L p .707 .577 .707 r
F P
0 g
s
.69402 .77962 m .69534 .79694 L .67419 .78797 L p .707 .577 .707 r
F P
0 g
s
.67419 .78797 m .67288 .77064 L .69402 .77962 L p .707 .577 .707 r
F P
0 g
s
.22911 .83227 m .22779 .81494 L .2003 .80968 L p .707 .577 .707 r
F P
0 g
s
.22779 .81494 m .22911 .83227 L .26025 .8333 L p .707 .577 .707 r
F P
0 g
s
.1612 .64372 m .16338 .69755 L .17602 .70762 L p .707 .577 .707 r
F P
0 g
s
.31991 .80538 m .32123 .8227 L .3451 .81211 L p .707 .577 .707 r
F P
0 g
s
.3451 .81211 m .34378 .79478 L .31991 .80538 L p .707 .577 .707 r
F P
0 g
s
.17629 .73815 m .17865 .77311 L .19978 .78183 L p .707 .577 .707 r
F P
0 g
s
.2003 .80968 m .20162 .82701 L .22911 .83227 L p .707 .577 .707 r
F P
0 g
s
.63446 .28717 m .65431 .77309 L .65014 .75711 L p .707 .577 .707 r
F P
0 g
s
.65014 .75711 m .63854 .47306 L p .63446 .28717 L .707 .577 .707 r
F P
0 g
s
.63029 .27118 m .65014 .75711 L .6323 .74287 L p .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .6565 .67618 L .64389 .66486 L p .707 .577 .707 r
F P
0 g
s
.64389 .66486 m .64379 .66477 L p .6439 .6651 L .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .64389 .66486 L .6439 .6651 L .707 .577 .707 r
F
.63854 .47306 m .63029 .27118 L .63321 .2824 L p F P
0 g
s
.63321 .2824 m .63446 .28717 L p .63854 .47306 L .707 .577 .707 r
F P
0 g
s
.16338 .69755 m .1612 .64372 L .15825 .63241 L p .707 .577 .707 r
F P
0 g
s
.17865 .77311 m .17629 .73815 L .16358 .72674 L p .707 .577 .707 r
F P
0 g
s
.20162 .82701 m .2003 .80968 L .17915 .80071 L p .707 .577 .707 r
F P
0 g
s
.17915 .80071 m .18047 .81803 L .20162 .82701 L p .707 .577 .707 r
F P
0 g
s
.34378 .79478 m .3451 .81211 L .36127 .79926 L p .707 .577 .707 r
F P
0 g
s
.36127 .79926 m .35995 .78194 L .34378 .79478 L p .707 .577 .707 r
F P
0 g
s
.35719 .72081 m .35955 .75577 L .36648 .74247 L p .707 .577 .707 r
F P
0 g
s
.36648 .74247 m .36411 .70752 L .35719 .72081 L p .707 .577 .707 r
F P
0 g
s
.36202 .62993 m .36421 .68375 L .36126 .67245 L p .707 .577 .707 r
F P
0 g
s
.36126 .67245 m .35907 .61862 L .36202 .62993 L p .707 .577 .707 r
F P
0 g
s
.16358 .72674 m .16594 .76169 L .17865 .77311 L p .707 .577 .707 r
F P
0 g
s
.36815 .78542 m .36683 .76809 L .35995 .78194 L p .707 .577 .707 r
F P
0 g
s
.36411 .70752 m .36648 .74247 L .36343 .72948 L p .707 .577 .707 r
F P
0 g
s
.36343 .72948 m .36107 .69453 L .36411 .70752 L p .707 .577 .707 r
F P
0 g
s
.36683 .76809 m .36815 .78542 L .36507 .77193 L p .707 .577 .707 r
F P
0 g
s
.36507 .77193 m .36375 .75461 L .36683 .76809 L p .707 .577 .707 r
F P
0 g
s
.34678 .29073 m .36663 .77665 L .3708 .79263 L p .707 .577 .707 r
F P
0 g
s
.36663 .77665 m .34678 .29073 L .35669 .27457 L p .707 .577 .707 r
F P
0 g
s
.15825 .63241 m .16043 .68624 L .16338 .69755 L p .707 .577 .707 r
F P
0 g
s
.18047 .81803 m .17915 .80071 L .16641 .7889 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16594 .76169 m .16358 .72674 L .16053 .71375 L p .707 .577 .707 r
F P
0 g
s
.16043 .68624 m .15825 .63241 L .16527 .62099 L p .707 .577 .707 r
F P
0 g
s
.16641 .7889 m .16773 .80623 L .18047 .81803 L p .707 .577 .707 r
F P
0 g
s
.35995 .78194 m .36127 .79926 L .36815 .78542 L p .707 .577 .707 r
F P
0 g
s
.6323 .74287 m .61245 .25694 L .63029 .27118 L p .707 .577 .707 r
F P
0 g
s
.35907 .61862 m .36126 .67245 L .34862 .66237 L p .707 .577 .707 r
F P
0 g
s
.34862 .66237 m .34643 .60854 L .35907 .61862 L p .707 .577 .707 r
F P
0 g
s
.16053 .71375 m .1629 .7487 L .16594 .76169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16527 .62099 m .16745 .67481 L .16043 .68624 L p .707 .577 .707 r
F P
0 g
s
.16773 .80623 m .16641 .7889 L .16334 .77542 L p .707 .577 .707 r
F P
0 g
s
.1629 .7487 m .16053 .71375 L .16745 .70045 L p .707 .577 .707 r
F P
0 g
s
.16745 .67481 m .16527 .62099 L .18158 .61056 L p .707 .577 .707 r
F P
0 g
s
.37654 .7605 m .35669 .27457 L .37971 .25982 L p .707 .577 .707 r
F P
0 g
s
.35669 .27457 m .37654 .7605 L .36663 .77665 L p .707 .577 .707 r
F P
0 g
s
.16334 .77542 m .16465 .79274 L .16773 .80623 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36107 .69453 m .36343 .72948 L .35072 .71807 L p .707 .577 .707 r
F P
0 g
s
.35072 .71807 m .34836 .68311 L .36107 .69453 L p .707 .577 .707 r
F P
0 g
s
.34643 .60854 m .34862 .66237 L .32754 .65451 L p .707 .577 .707 r
F P
0 g
s
.32754 .65451 m .32535 .60068 L .34643 .60854 L p .707 .577 .707 r
F P
0 g
s
.16745 .70045 m .16982 .7354 L .1629 .7487 L p .707 .577 .707 r
F P
0 g
s
.61245 .25694 m .6323 .74287 L .60254 .73176 L p .707 .577 .707 r
F P
0 g
s
.60254 .73176 m .58268 .24583 L .61245 .25694 L p .707 .577 .707 r
F P
0 g
s
.18158 .61056 m .18376 .66438 L .16745 .67481 L p .707 .577 .707 r
F P
0 g
s
.16465 .79274 m .16334 .77542 L .17022 .76157 L p .707 .577 .707 r
F P
0 g
s
.18376 .66438 m .18158 .61056 L .20557 .60215 L p .707 .577 .707 r
F P
0 g
s
.16982 .7354 m .16745 .70045 L .18366 .68815 L p .707 .577 .707 r
F P
0 g
s
.17022 .76157 m .17154 .7789 L .16465 .79274 L p .707 .577 .707 r
F P
0 g
s
.36375 .75461 m .36507 .77193 L .35233 .76013 L p .707 .577 .707 r
F P
0 g
s
.35233 .76013 m .35102 .7428 L .36375 .75461 L p .707 .577 .707 r
F P
0 g
s
.32535 .60068 m .32754 .65451 L .30007 .64963 L p .707 .577 .707 r
F P
0 g
s
.30007 .64963 m .29788 .59581 L .32535 .60068 L p .707 .577 .707 r
F P
0 g
s
.37971 .25982 m .39956 .74575 L .37654 .7605 L p .707 .577 .707 r
F P
0 g
s
.39956 .74575 m .37971 .25982 L .41359 .24793 L p .707 .577 .707 r
F P
0 g
s
.34836 .68311 m .35072 .71807 L .32959 .70935 L p .707 .577 .707 r
F P
0 g
s
.32959 .70935 m .32723 .67439 L .34836 .68311 L p .707 .577 .707 r
F P
0 g
s
.18366 .68815 m .18603 .7231 L .16982 .7354 L p .707 .577 .707 r
F P
0 g
s
.20776 .65597 m .20557 .60215 L .23491 .59658 L p .707 .577 .707 r
F P
0 g
s
.20557 .60215 m .20776 .65597 L .18376 .66438 L p .707 .577 .707 r
F P
0 g
s
.29788 .59581 m .30007 .64963 L .2689 .64822 L p .707 .577 .707 r
F P
0 g
s
.2689 .64822 m .26672 .59439 L .29788 .59581 L p .707 .577 .707 r
F P
0 g
s
.17154 .7789 m .17022 .76157 L .18638 .74873 L p .707 .577 .707 r
F P
0 g
s
.58268 .24583 m .60254 .73176 L .56376 .72487 L p .707 .577 .707 r
F P
0 g
s
.56376 .72487 m .54391 .23894 L .58268 .24583 L p .707 .577 .707 r
F P
0 g
s
.18603 .7231 m .18366 .68815 L .20757 .67805 L p .707 .577 .707 r
F P
0 g
s
.2371 .6504 m .23491 .59658 L .26672 .59439 L p .707 .577 .707 r
F P
0 g
s
.23491 .59658 m .2371 .6504 L .20776 .65597 L p .707 .577 .707 r
F P
0 g
s
.26672 .59439 m .2689 .64822 L .2371 .6504 L p .707 .577 .707 r
F P
0 g
s
.18638 .74873 m .1877 .76605 L .17154 .7789 L p .707 .577 .707 r
F P
0 g
s
.32723 .67439 m .32959 .70935 L .30211 .70417 L p .707 .577 .707 r
F P
0 g
s
.30211 .70417 m .29974 .66922 L .32723 .67439 L p .707 .577 .707 r
F P
0 g
s
.35102 .7428 m .35233 .76013 L .33119 .75115 L p .707 .577 .707 r
F P
0 g
s
.33119 .75115 m .32987 .73383 L .35102 .7428 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .41359 .24793 L .45501 .24004 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .39956 .74575 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.42184 .4498 m .43344 .73385 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.45501 .24004 m .47486 .72597 L .43344 .73385 L p .707 .577 .707 r
F P
0 g
s
.45664 .67938 m .45445 .64693 L p .42501 .65134 L .707 .577 .707 r
F P
0 g
s
.45445 .64693 m .45428 .64443 L .45404 .64448 L p .707 .577 .707 r
F P
0 g
s
.45404 .64448 m .42501 .65134 L p .45445 .64693 L .707 .577 .707 r
F P
0 g
s
.41359 .24793 m .42184 .4498 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.73595 .66366 m .73376 .60984 L .7026 .60842 L p .707 .577 .707 r
F P
0 g
s
.73376 .60984 m .73595 .66366 L .76775 .66148 L p .707 .577 .707 r
F P
0 g
s
.76775 .66148 m .76557 .60765 L .73376 .60984 L p .707 .577 .707 r
F P
0 g
s
.76557 .60765 m .76775 .66148 L .79709 .65591 L p .707 .577 .707 r
F P
0 g
s
.79709 .65591 m .79491 .60208 L .76557 .60765 L p .707 .577 .707 r
F P
0 g
s
.20757 .67805 m .20994 .71301 L .18603 .7231 L p .707 .577 .707 r
F P
0 g
s
.20994 .71301 m .20757 .67805 L .23683 .67114 L p .707 .577 .707 r
F P
0 g
s
.70478 .66225 m .7026 .60842 L .67513 .60355 L p .707 .577 .707 r
F P
0 g
s
.7026 .60842 m .70478 .66225 L .73595 .66366 L p .707 .577 .707 r
F P
0 g
s
.54391 .23894 m .56376 .72487 L .51976 .72287 L p .707 .577 .707 r
F P
0 g
s
.51976 .72287 m .49991 .23695 L .54391 .23894 L p .707 .577 .707 r
F P
0 g
s
.1877 .76605 m .18638 .74873 L .21026 .73813 L p .707 .577 .707 r
F P
0 g
s
.29974 .66922 m .30211 .70417 L .27096 .70305 L p .707 .577 .707 r
F P
0 g
s
.27096 .70305 m .2686 .6681 L .29974 .66922 L p .707 .577 .707 r
F P
0 g
s
.79491 .60208 m .79709 .65591 L .82109 .6475 L p .707 .577 .707 r
F P
0 g
s
.82109 .6475 m .8189 .59367 L .79491 .60208 L p .707 .577 .707 r
F P
0 g
s
.47486 .72597 m .45501 .24004 L .49991 .23695 L p .707 .577 .707 r
F P
0 g
s
.2392 .7061 m .23683 .67114 L .2686 .6681 L p .707 .577 .707 r
F P
0 g
s
.23683 .67114 m .2392 .7061 L .20994 .71301 L p .707 .577 .707 r
F P
0 g
s
.2686 .6681 m .27096 .70305 L .2392 .7061 L p .707 .577 .707 r
F P
0 g
s
.49991 .23695 m .51976 .72287 L .47486 .72597 L p .707 .577 .707 r
F P
0 g
s
.21026 .73813 m .21157 .75546 L .1877 .76605 L p .707 .577 .707 r
F P
0 g
s
.32987 .73383 m .33119 .75115 L .3037 .74589 L p .707 .577 .707 r
F P
0 g
s
.3037 .74589 m .30238 .72857 L .32987 .73383 L p .707 .577 .707 r
F P
0 g
s
.67732 .65737 m .67513 .60355 L .65405 .59568 L p .707 .577 .707 r
F P
0 g
s
.67513 .60355 m .67732 .65737 L .70478 .66225 L p .707 .577 .707 r
F P
0 g
s
.21157 .75546 m .21026 .73813 L .23949 .73083 L p .707 .577 .707 r
F P
0 g
s
.73863 .72615 m .73626 .6912 L .70511 .69008 L p .707 .577 .707 r
F P
0 g
s
.73626 .6912 m .73863 .72615 L .77039 .72311 L p .707 .577 .707 r
F P
0 g
s
.77039 .72311 m .76802 .68815 L .73626 .6912 L p .707 .577 .707 r
F P
0 g
s
.76802 .68815 m .77039 .72311 L .79965 .7162 L p .707 .577 .707 r
F P
0 g
s
.79965 .7162 m .79729 .68124 L .76802 .68815 L p .707 .577 .707 r
F P
0 g
s
.8189 .59367 m .82109 .6475 L .8374 .63707 L p .707 .577 .707 r
F P
0 g
s
.8374 .63707 m .83521 .58324 L .8189 .59367 L p .707 .577 .707 r
F P
0 g
s
.30238 .72857 m .3037 .74589 L .27255 .74486 L p .707 .577 .707 r
F P
0 g
s
.27255 .74486 m .27124 .72754 L .30238 .72857 L p .707 .577 .707 r
F P
0 g
s
.70748 .72503 m .70511 .69008 L .67763 .6849 L p .707 .577 .707 r
F P
0 g
s
.70511 .69008 m .70748 .72503 L .73863 .72615 L p .707 .577 .707 r
F P
0 g
s
.23949 .73083 m .24081 .74816 L .21157 .75546 L p .707 .577 .707 r
F P
0 g
s
.24081 .74816 m .23949 .73083 L .27124 .72754 L p .707 .577 .707 r
F P
0 g
s
.27124 .72754 m .27255 .74486 L .24081 .74816 L p .707 .577 .707 r
F P
0 g
s
.79729 .68124 m .79965 .7162 L .82356 .7061 L p .707 .577 .707 r
F P
0 g
s
.82356 .7061 m .82119 .67115 L .79729 .68124 L p .707 .577 .707 r
F P
0 g
s
.65405 .59568 m .65623 .64951 L .67732 .65737 L p .707 .577 .707 r
F P
0 g
s
.65623 .64951 m .65405 .59568 L .64141 .58561 L p .707 .577 .707 r
F P
0 g
s
.68 .71986 m .67763 .6849 L .6565 .67618 L p .707 .577 .707 r
F P
0 g
s
.67763 .6849 m .68 .71986 L .70748 .72503 L p .707 .577 .707 r
F P
0 g
s
.74046 .76591 m .73914 .74859 L .708 .74755 L p .707 .577 .707 r
F P
0 g
s
.73914 .74859 m .74046 .76591 L .7722 .76261 L p .707 .577 .707 r
F P
0 g
s
.7722 .76261 m .77089 .74529 L .73914 .74859 L p .707 .577 .707 r
F P
0 g
s
.77089 .74529 m .7722 .76261 L .80144 .75531 L p .707 .577 .707 r
F P
0 g
s
.80144 .75531 m .80012 .73799 L .77089 .74529 L p .707 .577 .707 r
F P
0 g
s
.83521 .58324 m .8374 .63707 L .84442 .62564 L p .707 .577 .707 r
F P
0 g
s
.84442 .62564 m .84223 .57181 L .83521 .58324 L p .707 .577 .707 r
F P
0 g
s
.70932 .76488 m .708 .74755 L .68051 .74229 L p .707 .577 .707 r
F P
0 g
s
.708 .74755 m .70932 .76488 L .74046 .76591 L p .707 .577 .707 r
F P
0 g
s
.82119 .67115 m .82356 .7061 L .83977 .6938 L p .707 .577 .707 r
F P
0 g
s
.83977 .6938 m .8374 .65885 L .82119 .67115 L p .707 .577 .707 r
F P
0 g
s
.80012 .73799 m .80144 .75531 L .82531 .74472 L p .707 .577 .707 r
F P
0 g
s
.82531 .74472 m .82399 .7274 L .80012 .73799 L p .707 .577 .707 r
F P
0 g
s
.64141 .58561 m .6436 .63943 L .65623 .64951 L p .707 .577 .707 r
F P
0 g
s
.6565 .67618 m .65887 .71114 L .68 .71986 L p .707 .577 .707 r
F P
0 g
s
.68051 .74229 m .68183 .75962 L .70932 .76488 L p .707 .577 .707 r
F P
0 g
s
.6436 .63943 m .64141 .58561 L .63846 .5743 L p .707 .577 .707 r
F P
0 g
s
.68183 .75962 m .68051 .74229 L .65936 .73332 L p .707 .577 .707 r
F P
0 g
s
.65936 .73332 m .66068 .75064 L .68183 .75962 L p .707 .577 .707 r
F P
0 g
s
.82399 .7274 m .82531 .74472 L .84148 .73187 L p .707 .577 .707 r
F P
0 g
s
.84148 .73187 m .84016 .71455 L .82399 .7274 L p .707 .577 .707 r
F P
0 g
s
.8374 .65885 m .83977 .6938 L .84669 .6805 L p .707 .577 .707 r
F P
0 g
s
.84669 .6805 m .84432 .64555 L .8374 .65885 L p .707 .577 .707 r
F P
0 g
s
.84223 .57181 m .84442 .62564 L .84147 .61434 L p .707 .577 .707 r
F P
0 g
s
.84147 .61434 m .83928 .56051 L .84223 .57181 L p .707 .577 .707 r
F P
0 g
s
.64379 .66477 m .64616 .69972 L .65887 .71114 L p .707 .577 .707 r
F P
0 g
s
.63846 .5743 m .64065 .62813 L .6436 .63943 L p .707 .577 .707 r
F P
0 g
s
.66068 .75064 m .65936 .73332 L .64663 .72151 L p .707 .577 .707 r
F P
0 g
s
.64616 .69972 m .64379 .66477 L .64075 .65178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64065 .62813 m .63846 .5743 L .64548 .56288 L p .707 .577 .707 r
F P
0 g
s
.64663 .72151 m .64795 .73884 L .66068 .75064 L p .707 .577 .707 r
F P
0 g
s
.84016 .71455 m .84148 .73187 L .84836 .71803 L p .707 .577 .707 r
F P
0 g
s
.84836 .71803 m .84704 .7007 L .84016 .71455 L p .707 .577 .707 r
F P
0 g
s
.84432 .64555 m .84669 .6805 L .84365 .66751 L p .707 .577 .707 r
F P
0 g
s
.84365 .66751 m .84128 .63256 L .84432 .64555 L p .707 .577 .707 r
F P
0 g
s
.64075 .65178 m .64311 .68673 L .64616 .69972 L p .707 .577 .707 r
F P
0 g
s
.83928 .56051 m .84147 .61434 L .82883 .60426 L p .707 .577 .707 r
F P
0 g
s
.82883 .60426 m .82665 .55043 L .83928 .56051 L p .707 .577 .707 r
F P
0 g
s
.64548 .56288 m .64767 .6167 L .64065 .62813 L p .707 .577 .707 r
F P
0 g
s
.64795 .73884 m .64663 .72151 L .64355 .70803 L p .707 .577 .707 r
F P
0 g
s
.64311 .68673 m .64075 .65178 L .64767 .63848 L p .707 .577 .707 r
F P
0 g
s
.64767 .6167 m .64548 .56288 L .66179 .55245 L p .707 .577 .707 r
F P
0 g
s
.39294 .62685 m .39075 .57302 L .35959 .57161 L p .707 .577 .707 r
F P
0 g
s
.39075 .57302 m .39294 .62685 L .42474 .62466 L p .707 .577 .707 r
F P
0 g
s
.42474 .62466 m .42256 .57084 L .39075 .57302 L p .707 .577 .707 r
F P
0 g
s
.64355 .70803 m .64487 .72535 L .64795 .73884 L p .707 .577 .707 r
F P
0 g
s
.42256 .57084 m .42474 .62466 L .45408 .61909 L p .707 .577 .707 r
F P
0 g
s
.45408 .61909 m .4519 .56527 L .42256 .57084 L p .707 .577 .707 r
F P
0 g
s
.84704 .7007 m .84836 .71803 L .84528 .70454 L p .707 .577 .707 r
F P
0 g
s
.84528 .70454 m .84397 .68722 L .84704 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36177 .62543 m .35959 .57161 L .33212 .56673 L p .707 .577 .707 r
F P
0 g
s
.35959 .57161 m .36177 .62543 L .39294 .62685 L p .707 .577 .707 r
F P
0 g
s
.84128 .63256 m .84365 .66751 L .83094 .6561 L p .707 .577 .707 r
F P
0 g
s
.83094 .6561 m .82857 .62114 L .84128 .63256 L p .707 .577 .707 r
F P
0 g
s
.82665 .55043 m .82883 .60426 L .80775 .5964 L p .707 .577 .707 r
F P
0 g
s
.80775 .5964 m .80556 .54257 L .82665 .55043 L p .707 .577 .707 r
F P
0 g
s
.4519 .56527 m .45408 .61909 L .47808 .61068 L p .707 .577 .707 r
F P
0 g
s
.47808 .61068 m .47589 .55686 L .4519 .56527 L p .707 .577 .707 r
F P
0 g
s
.64767 .63848 m .65004 .67344 L .64311 .68673 L p .707 .577 .707 r
F P
0 g
s
.66179 .55245 m .66398 .60627 L .64767 .6167 L p .707 .577 .707 r
F P
0 g
s
.64487 .72535 m .64355 .70803 L .65043 .69418 L p .707 .577 .707 r
F P
0 g
s
.33431 .62056 m .33212 .56673 L .31104 .55887 L p .707 .577 .707 r
F P
0 g
s
.33212 .56673 m .33431 .62056 L .36177 .62543 L p .707 .577 .707 r
F P
0 g
s
.66398 .60627 m .66179 .55245 L .68579 .54403 L p .707 .577 .707 r
F P
0 g
s
.65004 .67344 m .64767 .63848 L .66388 .62618 L p .707 .577 .707 r
F P
0 g
s
.39562 .68934 m .39325 .65438 L .3621 .65326 L p .707 .577 .707 r
F P
0 g
s
.39325 .65438 m .39562 .68934 L .42738 .68629 L p .707 .577 .707 r
F P
0 g
s
.42738 .68629 m .42501 .65134 L .39325 .65438 L p .707 .577 .707 r
F P
0 g
s
.65043 .69418 m .65175 .71151 L .64487 .72535 L p .707 .577 .707 r
F P
0 g
s
.42501 .65134 m .42738 .68629 L .45664 .67938 L p .707 .577 .707 r
F P
0 g
s
.84397 .68722 m .84528 .70454 L .83255 .69274 L p .707 .577 .707 r
F P
0 g
s
.83255 .69274 m .83123 .67541 L .84397 .68722 L p .707 .577 .707 r
F P
0 g
s
.47589 .55686 m .47808 .61068 L .49439 .60025 L p .707 .577 .707 r
F P
0 g
s
.49439 .60025 m .4922 .54643 L .47589 .55686 L p .707 .577 .707 r
F P
0 g
s
.80556 .54257 m .80775 .5964 L .78028 .59152 L p .707 .577 .707 r
F P
0 g
s
.78028 .59152 m .7781 .53769 L .80556 .54257 L p .707 .577 .707 r
F P
0 g
s
.36447 .68822 m .3621 .65326 L .33462 .64809 L p .707 .577 .707 r
F P
0 g
s
.3621 .65326 m .36447 .68822 L .39562 .68934 L p .707 .577 .707 r
F P
0 g
s
.82857 .62114 m .83094 .6561 L .80981 .64738 L p .707 .577 .707 r
F P
0 g
s
.80981 .64738 m .80744 .61242 L .82857 .62114 L p .707 .577 .707 r
F P
0 g
s
.45428 .64443 m .45664 .67938 L .48055 .66928 L p .707 .577 .707 r
F P
0 g
s
.48055 .66928 m .47818 .63433 L .45428 .64443 L p .707 .577 .707 r
F P
0 g
s
.66388 .62618 m .66624 .66114 L .65004 .67344 L p .707 .577 .707 r
F P
0 g
s
.31104 .55887 m .31322 .61269 L .33431 .62056 L p .707 .577 .707 r
F P
0 g
s
.68797 .59786 m .68579 .54403 L .71513 .53846 L p .707 .577 .707 r
F P
0 g
s
.68579 .54403 m .68797 .59786 L .66398 .60627 L p .707 .577 .707 r
F P
0 g
s
.31322 .61269 m .31104 .55887 L .2984 .54879 L p .707 .577 .707 r
F P
0 g
s
.65175 .71151 m .65043 .69418 L .6666 .68134 L p .707 .577 .707 r
F P
0 g
s
.66624 .66114 m .66388 .62618 L .68778 .61608 L p .707 .577 .707 r
F P
0 g
s
.7781 .53769 m .78028 .59152 L .74912 .5901 L p .707 .577 .707 r
F P
0 g
s
.74912 .5901 m .74693 .53628 L .7781 .53769 L p .707 .577 .707 r
F P
0 g
s
.33699 .68304 m .33462 .64809 L .31349 .63937 L p .707 .577 .707 r
F P
0 g
s
.33462 .64809 m .33699 .68304 L .36447 .68822 L p .707 .577 .707 r
F P
0 g
s
.39745 .7291 m .39613 .71177 L .36499 .71074 L p .707 .577 .707 r
F P
0 g
s
.39613 .71177 m .39745 .7291 L .42919 .7258 L p .707 .577 .707 r
F P
0 g
s
.42919 .7258 m .42788 .70847 L .39613 .71177 L p .707 .577 .707 r
F P
0 g
s
.42788 .70847 m .42919 .7258 L .45843 .7185 L p .707 .577 .707 r
F P
0 g
s
.45843 .7185 m .45711 .70117 L .42788 .70847 L p .707 .577 .707 r
F P
0 g
s
.71731 .59229 m .71513 .53846 L .74693 .53628 L p .707 .577 .707 r
F P
0 g
s
.71513 .53846 m .71731 .59229 L .68797 .59786 L p .707 .577 .707 r
F P
0 g
s
.6666 .68134 m .66792 .69866 L .65175 .71151 L p .707 .577 .707 r
F P
0 g
s
.74693 .53628 m .74912 .5901 L .71731 .59229 L p .707 .577 .707 r
F P
0 g
s
.4922 .54643 m .49439 .60025 L .50141 .58882 L p .707 .577 .707 r
F P
0 g
s
.50141 .58882 m .49922 .535 L .4922 .54643 L p .707 .577 .707 r
F P
0 g
s
.83123 .67541 m .83255 .69274 L .8114 .68376 L p .707 .577 .707 r
F P
0 g
s
.8114 .68376 m .81008 .66644 L .83123 .67541 L p .707 .577 .707 r
F P
0 g
s
.80744 .61242 m .80981 .64738 L .78232 .64221 L p .707 .577 .707 r
F P
0 g
s
.78232 .64221 m .77996 .60725 L .80744 .61242 L p .707 .577 .707 r
F P
0 g
s
.36631 .72806 m .36499 .71074 L .3375 .70548 L p .707 .577 .707 r
F P
0 g
s
.36499 .71074 m .36631 .72806 L .39745 .7291 L p .707 .577 .707 r
F P
0 g
s
.47818 .63433 m .48055 .66928 L .49676 .65699 L p .707 .577 .707 r
F P
0 g
s
.49676 .65699 m .49439 .62203 L .47818 .63433 L p .707 .577 .707 r
F P
0 g
s
.45711 .70117 m .45843 .7185 L .4823 .7079 L p .707 .577 .707 r
F P
0 g
s
.4823 .7079 m .48098 .69058 L .45711 .70117 L p .707 .577 .707 r
F P
0 g
s
.2984 .54879 m .30059 .60262 L .31322 .61269 L p .707 .577 .707 r
F P
0 g
s
.68778 .61608 m .69015 .65104 L .66624 .66114 L p .707 .577 .707 r
F P
0 g
s
.31349 .63937 m .31586 .67432 L .33699 .68304 L p .707 .577 .707 r
F P
0 g
s
.3375 .70548 m .33882 .7228 L .36631 .72806 L p .707 .577 .707 r
F P
0 g
s
.69015 .65104 m .68778 .61608 L .71705 .60918 L p .707 .577 .707 r
F P
0 g
s
.30059 .60262 m .2984 .54879 L .29545 .53749 L p .707 .577 .707 r
F P
0 g
s
.66792 .69866 m .6666 .68134 L .69047 .67074 L p .707 .577 .707 r
F P
0 g
s
.31586 .67432 m .31349 .63937 L .30078 .62795 L p .707 .577 .707 r
F P
0 g
s
.33882 .7228 m .3375 .70548 L .31635 .69651 L p .707 .577 .707 r
F P
0 g
s
.77996 .60725 m .78232 .64221 L .75118 .64109 L p .707 .577 .707 r
F P
0 g
s
.75118 .64109 m .74881 .60613 L .77996 .60725 L p .707 .577 .707 r
F P
0 g
s
.71942 .64413 m .71705 .60918 L .74881 .60613 L p .707 .577 .707 r
F P
0 g
s
.71705 .60918 m .71942 .64413 L .69015 .65104 L p .707 .577 .707 r
F P
0 g
s
.69047 .67074 m .69179 .68807 L .66792 .69866 L p .707 .577 .707 r
F P
0 g
s
.81008 .66644 m .8114 .68376 L .78391 .6785 L p .707 .577 .707 r
F P
0 g
s
.78391 .6785 m .78259 .66118 L .81008 .66644 L p .707 .577 .707 r
F P
0 g
s
.74881 .60613 m .75118 .64109 L .71942 .64413 L p .707 .577 .707 r
F P
0 g
s
.31635 .69651 m .31767 .71383 L .33882 .7228 L p .707 .577 .707 r
F P
0 g
s
.48098 .69058 m .4823 .7079 L .49847 .69506 L p .707 .577 .707 r
F P
0 g
s
.49847 .69506 m .49715 .67773 L .48098 .69058 L p .707 .577 .707 r
F P
0 g
s
.49439 .62203 m .49676 .65699 L .50368 .64369 L p .707 .577 .707 r
F P
0 g
s
.50368 .64369 m .50131 .60873 L .49439 .62203 L p .707 .577 .707 r
F P
0 g
s
.49922 .535 m .50141 .58882 L .49846 .57752 L p .707 .577 .707 r
F P
0 g
s
.49846 .57752 m .49627 .52369 L .49922 .535 L p .707 .577 .707 r
F P
0 g
s
.30078 .62795 m .30315 .66291 L .31586 .67432 L p .707 .577 .707 r
F P
0 g
s
.69179 .68807 m .69047 .67074 L .71971 .66344 L p .707 .577 .707 r
F P
0 g
s
.29545 .53749 m .29763 .59131 L .30059 .60262 L p .707 .577 .707 r
F P
0 g
s
.78259 .66118 m .78391 .6785 L .75277 .67747 L p .707 .577 .707 r
F P
0 g
s
.75277 .67747 m .75145 .66015 L .78259 .66118 L p .707 .577 .707 r
F P
0 g
s
.31767 .71383 m .31635 .69651 L .30362 .6847 L p .707 .577 .707 r
F P
0 g
s
.71971 .66344 m .72103 .68077 L .69179 .68807 L p .707 .577 .707 r
F P
0 g
s
.30315 .66291 m .30078 .62795 L .29774 .61496 L p .707 .577 .707 r
F P
0 g
s
.72103 .68077 m .71971 .66344 L .75145 .66015 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29763 .59131 m .29545 .53749 L .30247 .52606 L p .707 .577 .707 r
F P
0 g
s
.75145 .66015 m .75277 .67747 L .72103 .68077 L p .707 .577 .707 r
F P
0 g
s
.30362 .6847 m .30494 .70202 L .31767 .71383 L p .707 .577 .707 r
F P
0 g
s
.49715 .67773 m .49847 .69506 L .50535 .68121 L p .707 .577 .707 r
F P
0 g
s
.50535 .68121 m .50403 .66389 L .49715 .67773 L p .707 .577 .707 r
F P
0 g
s
.50131 .60873 m .50368 .64369 L .50064 .6307 L p .707 .577 .707 r
F P
0 g
s
.50064 .6307 m .49827 .59574 L .50131 .60873 L p .707 .577 .707 r
F P
0 g
s
.29774 .61496 m .3001 .64992 L .30315 .66291 L p .707 .577 .707 r
F P
0 g
s
.49627 .52369 m .49846 .57752 L .48582 .56744 L p .707 .577 .707 r
F P
0 g
s
.48582 .56744 m .48364 .51362 L .49627 .52369 L p .707 .577 .707 r
F P
0 g
s
.30247 .52606 m .30466 .57989 L .29763 .59131 L p .707 .577 .707 r
F P
0 g
s
.30494 .70202 m .30362 .6847 L .30054 .67121 L p .707 .577 .707 r
F P
0 g
s
.3001 .64992 m .29774 .61496 L .30466 .60167 L p .707 .577 .707 r
F P
0 g
s
.30466 .57989 m .30247 .52606 L .31878 .51563 L p .707 .577 .707 r
F P
0 g
s
.30054 .67121 m .30186 .68854 L .30494 .70202 L p .707 .577 .707 r
F P
0 g
s
.50403 .66389 m .50535 .68121 L .50227 .66773 L p .707 .577 .707 r
F P
0 g
s
.50227 .66773 m .50096 .6504 L .50403 .66389 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49827 .59574 m .50064 .6307 L .48793 .61928 L p .707 .577 .707 r
F P
0 g
s
.48793 .61928 m .48556 .58433 L .49827 .59574 L p .707 .577 .707 r
F P
0 g
s
.48364 .51362 m .48582 .56744 L .46474 .55958 L p .707 .577 .707 r
F P
0 g
s
.46474 .55958 m .46255 .50576 L .48364 .51362 L p .707 .577 .707 r
F P
0 g
s
.30466 .60167 m .30703 .63662 L .3001 .64992 L p .707 .577 .707 r
F P
0 g
s
.31878 .51563 m .32096 .56946 L .30466 .57989 L p .707 .577 .707 r
F P
0 g
s
.30186 .68854 m .30054 .67121 L .30742 .65737 L p .707 .577 .707 r
F P
0 g
s
.32096 .56946 m .31878 .51563 L .34278 .50722 L p .707 .577 .707 r
F P
0 g
s
.30703 .63662 m .30466 .60167 L .32087 .58937 L p .707 .577 .707 r
F P
0 g
s
.30742 .65737 m .30874 .67469 L .30186 .68854 L p .707 .577 .707 r
F P
0 g
s
.50096 .6504 m .50227 .66773 L .48954 .65592 L p .707 .577 .707 r
F P
0 g
s
.48954 .65592 m .48822 .6386 L .50096 .6504 L p .707 .577 .707 r
F P
0 g
s
.46255 .50576 m .46474 .55958 L .43727 .5547 L p .707 .577 .707 r
F P
0 g
s
.43727 .5547 m .43508 .50088 L .46255 .50576 L p .707 .577 .707 r
F P
0 g
s
.48556 .58433 m .48793 .61928 L .4668 .61056 L p .707 .577 .707 r
F P
0 g
s
.4668 .61056 m .46443 .57561 L .48556 .58433 L p .707 .577 .707 r
F P
0 g
s
.32087 .58937 m .32323 .62432 L .30703 .63662 L p .707 .577 .707 r
F P
0 g
s
.34496 .56104 m .34278 .50722 L .37211 .50165 L p .707 .577 .707 r
F P
0 g
s
.34278 .50722 m .34496 .56104 L .32096 .56946 L p .707 .577 .707 r
F P
0 g
s
.30874 .67469 m .30742 .65737 L .32359 .64452 L p .707 .577 .707 r
F P
0 g
s
.32323 .62432 m .32087 .58937 L .34477 .57927 L p .707 .577 .707 r
F P
0 g
s
.43508 .50088 m .43727 .5547 L .40611 .55329 L p .707 .577 .707 r
F P
0 g
s
.40611 .55329 m .40392 .49946 L .43508 .50088 L p .707 .577 .707 r
F P
0 g
s
.3743 .55547 m .37211 .50165 L .40392 .49946 L p .707 .577 .707 r
F P
0 g
s
.37211 .50165 m .3743 .55547 L .34496 .56104 L p .707 .577 .707 r
F P
0 g
s
.32359 .64452 m .32491 .66185 L .30874 .67469 L p .707 .577 .707 r
F P
0 g
s
.40392 .49946 m .40611 .55329 L .3743 .55547 L p .707 .577 .707 r
F P
0 g
s
.48822 .6386 m .48954 .65592 L .46839 .64695 L p .707 .577 .707 r
F P
0 g
s
.46839 .64695 m .46707 .62962 L .48822 .6386 L p .707 .577 .707 r
F P
0 g
s
.46443 .57561 m .4668 .61056 L .43931 .60539 L p .707 .577 .707 r
F P
0 g
s
.43931 .60539 m .43695 .57044 L .46443 .57561 L p .707 .577 .707 r
F P
0 g
s
.34477 .57927 m .34714 .61422 L .32323 .62432 L p .707 .577 .707 r
F P
0 g
s
.34714 .61422 m .34477 .57927 L .37404 .57236 L p .707 .577 .707 r
F P
0 g
s
.32491 .66185 m .32359 .64452 L .34746 .63393 L p .707 .577 .707 r
F P
0 g
s
.43695 .57044 m .43931 .60539 L .40817 .60427 L p .707 .577 .707 r
F P
0 g
s
.40817 .60427 m .4058 .56932 L .43695 .57044 L p .707 .577 .707 r
F P
0 g
s
.37641 .60731 m .37404 .57236 L .4058 .56932 L p .707 .577 .707 r
F P
0 g
s
.37404 .57236 m .37641 .60731 L .34714 .61422 L p .707 .577 .707 r
F P
0 g
s
.34746 .63393 m .34878 .65125 L .32491 .66185 L p .707 .577 .707 r
F P
0 g
s
.46707 .62962 m .46839 .64695 L .4409 .64169 L p .707 .577 .707 r
F P
0 g
s
.4409 .64169 m .43958 .62436 L .46707 .62962 L p .707 .577 .707 r
F P
0 g
s
.4058 .56932 m .40817 .60427 L .37641 .60731 L p .707 .577 .707 r
F P
0 g
s
.34878 .65125 m .34746 .63393 L .3767 .62663 L p .707 .577 .707 r
F P
0 g
s
.43958 .62436 m .4409 .64169 L .40976 .64065 L p .707 .577 .707 r
F P
0 g
s
.40976 .64065 m .40844 .62333 L .43958 .62436 L p .707 .577 .707 r
F P
0 g
s
.3767 .62663 m .37802 .64395 L .34878 .65125 L p .707 .577 .707 r
F P
0 g
s
.37802 .64395 m .3767 .62663 L .40844 .62333 L p .707 .577 .707 r
F P
0 g
s
.40844 .62333 m .40976 .64065 L .37802 .64395 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0028Ool<0029Ool007moo`T0
00IJEP03001JEUYF00=JEP`007eoo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MWoo001dOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000M7oo001aOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LWoo001]Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001`Ool006]oo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006io
o`00JWoo0P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0P00KGoo001YOol00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH00000Jgoo001WOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01@00FUIJEUYF0000JWoo001VOol00`00FUIJEP02FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1WOol006Eoo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo
001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000EJEP03
001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP80
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJ7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVQoo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF
J7oo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol0069oo`05001JEUYFFUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00Hgoo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIWOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVMoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEUYF01L000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001VOol0061oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
05aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001V
Ool005Yoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0067oo3`00?Woo001COol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P003goo2@0015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0027oo
0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001C
Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Woo0P000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
035oo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00MJ
EP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001C
Ool01000FUIJEP0015YF00<005YFFUH00eYF1@000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
1UYF100015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF0004
FUH00`00FUH000030004Ool01@00FUIJEUYF000015YF1@001UYF00<005YFFUH00eYF0`0015YF0`00
00AJEP00FUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEPL000=o
o`05001JEUYFFUH00004FUH:00000eYF001JEP0400000eYF001JEP05FUH01000FUH000000UYF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF0P000eYF00@005YFFUIJEPd0
00AJEP03001JEUYF009JEPT000IJEP06001JEUYFFUH005YF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
02eoo`00E7oo00<005YF00000P001EYF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00E7oo00D005YF001JEP0000EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH0
0`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol2
0003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol20003
FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP04FUH60009Ool80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Goo0011OolE0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP05001JEUYF
FUH00006FUH00`00FUIJEP040007Ool3000=Ool60004FUH01@00FUIJEUYF0000;Goo000mOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP05001JEUYF
FUH00005FUH4000:Ool5000>Ool20002FUH300000eYF001JEP02FUH2000/Ool003Uoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEP0000<000ioo`D0
00Uoo`D000EJEP04001JEP000003FUH2000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJEPP000AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF0P0000=JEP00FUH010002goo3`000UYF00<005YFFUH015YF00D005YF
FUIJEP00009JEP8002aoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00002FUH01@00FUIJEUYF00001EYF2`0015YF00<005YFFUH01UYF00<005YF0000
0`001EYF00<005YFFUH00UYF1000;7oo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH00`00FUIJEP04FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP04FUH3000/Ool002moo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH0000200001EYF000005YF00000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P001EYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0015YF0`00;7oo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH0
00050003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUIJEUYF
0P000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20000
0eYF001JEP04FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH20005FUH90004
FUH?0007FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00;7oo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00<005YF00001EYF00D005YFFUIJEP00009JEPL000AJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002eo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00UYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000AJEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020003FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`8000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP800003FUH005YF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Goo0P00
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`00
00=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000AJ
EP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04
001JEUYF000]Ool002eoo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP04001JEP000006FUH00`00FUIJEP04FUH70009FUH00`00FUIJEP02FUH7
0004FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00AJEQD0009JEP<000MJEP03001JEUYF00D000EJEP03001JEUYF00MJEPD0009JEP03001J
EUYF009JEP8000=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00@000Ioo`<000Yoo`800005FUH00000FUH00006FUH90005FUH01000
FUIJEUYF1`001UYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001P0000EJEP00FUIJEP0002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF10002Goo1@002Goo0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01@00
FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH01000
FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001goo0P000UYF
00<007ooOol0:goo000]Ool00`00FUH00004FUH00`00FUH00003000=Ool5000:Ool20004FUH01000
FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H0
05YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000AJEP05001JEP00001JEP040002FUH00`00FUIJEP06FUH:0002FUH4000<Ool00`00
FUH0000]Ool002eoo`03001JEP0000AJEPL000aoo`D000Qoo`@000AJEP800003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP03
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP8000AJEP03001JEUYF00/000AJEP03001JEUYF009JEPP000Yoo`@002eoo`00;Goo00<005YF0000
0UYF0P000eYF00@005YFFUIJEQT00004FUH005YF0002FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00009JEP800003FUH005YF
00=JEP04001JEUYFFUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000goo0P00
0UYF0`00;7oo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP02FUH5000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUIJEP00FUH30003FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH3000/Ool002eoo`05001JEP00FUH00005FUH0
0`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUH005YF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00P000eYF0`00;7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF0P000UYF0`000eYF00<005YF
FUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJEP00FUH002aoo`00;Goo0P00
0UYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF00<000EJEP03001JEUYF00AJEPH000moo`@0009JEP03001JEUYF00=JEP<0
0003FUH007oo02]oo`00;Goo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000IJ
EP04001JEUYFFUH200000eYF00000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`0000=JEP00FUH00P001UYF00<005YFFUH010004Woo100000=JEP00FUH01000
15YF00@005YF000002eoo`00;Goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000EJEP03001JEUYF00=JEPT0009JEPD0009JEPL000YJEP04001JEUYF
0003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P0000=JEP00FUH015YF100000=JEP00Ool037oo1`001EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0002eoo`00;Goo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00eYF00<005YF00000P000UYF00<005YF000020001EYF00<005YFFUH0
2EYF0`0015YF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF009JEP04001JEUYFFUH20003FUH@0004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH30002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF00800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF009JEP<000QJEP8000UJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEP04
001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH200000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001oo`0[Ool002moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF009JEPP000AJEP80009JEP03001JEP00008000EJEP03001JEUYF0080009JEP03001JEUYF
00=JEP03001JEUYF00QJEP03001JEUYF009JEP<000IJEP03001JEP0000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH01@00FUIJEUYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo0P00;7oo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008FUH700000eYF001JEP03FUH30002FUH00`00
FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP08FUH500000eYF001JEP06FUH20008FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
17oo0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH00`00FUH0000300000eYF00000002FUH00`00FUIJEP04FUH01000FUIJ
EUYF1`001EYF00<005YFFUH015YF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH20006Ool2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool01000FUH00000:goo000]Ool0
0`00FUH00004FUH01000FUIJEUYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH300000eYF001JEP06FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP04FUH40009Ool01000
FUIJEP00:goo000]Ool00`00FUH00004FUH01000FUH0000017oo200015YF00<005YFFUH00UYF2@00
1goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00EJEP03001JEP00008000IJEP03001JEUYF00AJEPD000EJEP03001JEUYF00@000aoo`80009JEP03
001oogoo02Uoo`00;Goo00@005YFFUH000=JEP8000ioo`T0019oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH500000eYF
00000005000>Ool2000015YF001JEP00;7oo000]Ool01000FUIJEP000UYF00<007ooOol04Goo2P00
4Goo10000UYF00<005YFFUH01EYF00<005YFFUH00eYF1`001eYF2P0035YF2@0025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEP0000l001=oo`8000AJEP8002aoo`00
;Goo00H005YFFUH005YF000?Ool70004FUH01000FUIJEUYF200027oo00@005YFFUIJEQ4000EJEP03
001JEUYF00H000UJEP03001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP06001J
EUYFFUH005YF0P000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`<001=oo`800003FUH005YF
00=JEP03001oogoo02]oo`00;Woo00@005YF000000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH50002Ool00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF
FUIJEP80009JEP05001JEUYFFUH00004FUH01@00FUIJEUYF000077oo0P000eYF00<005YFFUH00UYF
00<007ooOol0:goo000^Ool01@00FUH005YF00001goo10001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF100015YF00<005YF00002EYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00<0
05YFFUH00`0000=JEP00FUH00eYF00D005YFFUIJEP0001Uoo`<000EJEP03001JEUYF008002ioo`00
;Woo0P000UYF0`000goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P0015YF00<005YFFUH025YF00@005YFFUIJEP<000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<00003FUH005YF00=JEP04001JEUYF
0002FUH20005FUH01000FUIJEP005Goo100000=JEP00FUH01EYF0`00<7oo000^Ool20002FUH00`00
FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH025YF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00P0015YF0P0000=JEP00FUH00eYF1P000UYF
00<007ooOol037oo1`001EYF00<005YFFUH00eYF0P00<Woo000^Ool20002FUH01000FUH000001UYF
00<005YFFUH015YF1P002Goo200015YF00<005YFFUH00UYF0P0000=JEP0000002EYF0P000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF00@005YFFUIJEP@000EJEP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00=7oo000^Ool20002FUH30007FUH00`00FUIJEP050009Ool70006FUH50004FUH00`00FUH0
00020007FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=Woo000^Ool20002FUH00`00
FUH00006FUH50004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEP00
1UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH01EYF0`000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo000_Ool00`00FUH00003FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP0000AJEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Aoo`800003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@003]oo`00;goo0P0015YF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01`00
FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPL003moo`00;goo0P0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0P000Woo00<005YF00000UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH015YF0`002Goo5000AWoo000_Ool20003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000`0017oo0P0015YF0`00Dgoo000^Ool01000FUH005YF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00@005YFFUIJEP80
00Moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP@00003FUH0
05YF00=JEP<005=oo`00;Woo00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000IJEP03001JEUYF00EJEP04001JEP000009Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUH000020003FUH00`00FUH0001COol002ioo`03001JEP0000Aoo`80
0003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<000Yoo`@000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEP800004FUH005YF001COol002ioo`80
00Moo`D000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000eoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH4001DOol002ioo`8000aoo`T000=J
EP<000=JEPL000moo`<00003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00<0009JEP03001JEUYF00=JEP@005Aoo`00;Woo0P005Goo2@0057oo0P000UYF0P0000=oo`00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00FUH40004FUH00`00FUH0001EOol0
02ioo`<0031oo`03001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP8000AJEP03001JEUYF00=JEP<00005FUH005YFFUH0001DOol002ioo`800003FUH007oo02aoo`<0
00AJEP05001oogooOol00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP020006FUH00`00FUIJEP05FUH3
0002FUH00`00Oomoo`1BOol002ioo`80009JEP03001oogoo02Qoo`80009JEP03001JEUYF009JEP03
001oogoo009oo`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000QJEP03001JEUYF00AJEP@00003FUH0000005=oo`00
;goo00<005YFFUH00`009Woo0P001EYF00@005YFFUH000Moo`8000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=oo`<005=oo`00;goo00@005YFFUH0009JEP80029oo`8000MJEP<000Uo
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20006Ool2001COol0031oo`04001JEUYF
0003FUH5000IOol400000eYF001JEP05FUH2000=Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040006FUH00`00FUIJEP06FUH01000FUH0
000027oo0P00Dgoo000aOol30004FUH01000FUIJEUYF2@002Goo1`001EYF00<005YFFUH00UYF0P00
4Goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF0`0000=J
EP0000000`001EYF00<005YFFUH015YF10002Goo00@005YF0000059oo`00<goo00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000001Ioo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP@000AJEPD000EJEP03001JEUYF00@0
00eoo`04001JEUYF001BOol003Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<001aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP00
00<00003FUH005YF00EJEPD00003FUH0000000D0011oo`80009JEP03001oogoo051oo`00=Woo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P009Goo2@001UYF
00<005YFFUH015YF20000goo3`005Woo00D005YF001JEP0005=oo`00>7oo1@0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YF00000P00<7oo3@00;goo00@005YFFUIJEP8005=oo`00?Goo6000
>goo00<005YF0000;goo0P0015YF00<007ooOol0DWoo002@Ool200000eYF001oo`0[Ool200000eYF
001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF008002Qoo`8000=JEP05001JEUYFFUH0001E
Ool0095oo`05001JEUYF001JEP03000ROol30005FUH01000FUH00000EWoo002BOol00`00FUH00004
FUH3000KOol400000eYF001JEP05FUH2001HOol0099oo`03001JEP0000EJEP03001JEP0000<0011o
o`L000EJEP03001JEUYF00=JEP8005Uoo`00Tgoo0P001EYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00@005YFFUIJEP8005]oo`00U7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF000005eoo`00UWoo0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00Ggoo002IOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04001ROol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF009J
EPL006Ioo`00X7oo4000KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59389 .73986 m .59607 .6831 L .56491 .6807 L p .707 .577 .707 r
F P
0 g
s
.59607 .6831 m .59389 .73986 L .6257 .74053 L p .707 .577 .707 r
F P
0 g
s
.6257 .74053 m .62788 .68377 L .59607 .6831 L p .707 .577 .707 r
F P
0 g
s
.62788 .68377 m .6257 .74053 L .65503 .7394 L p .707 .577 .707 r
F P
0 g
s
.65503 .7394 m .65722 .68264 L .62788 .68377 L p .707 .577 .707 r
F P
0 g
s
.56273 .73746 m .56491 .6807 L .53744 .67681 L p .707 .577 .707 r
F P
0 g
s
.56491 .6807 m .56273 .73746 L .59389 .73986 L p .707 .577 .707 r
F P
0 g
s
.59183 .7936 m .5942 .75547 L .56305 .75275 L p .707 .577 .707 r
F P
0 g
s
.5942 .75547 m .59183 .7936 L .62359 .79519 L p .707 .577 .707 r
F P
0 g
s
.62359 .79519 m .62596 .75706 L .5942 .75547 L p .707 .577 .707 r
F P
0 g
s
.65722 .68264 m .65503 .7394 L .67903 .73658 L p .707 .577 .707 r
F P
0 g
s
.67903 .73658 m .68122 .67983 L .65722 .68264 L p .707 .577 .707 r
F P
0 g
s
.53744 .67681 m .53526 .73356 L .56273 .73746 L p .707 .577 .707 r
F P
0 g
s
.62596 .75706 m .62359 .79519 L .65286 .7955 L p .707 .577 .707 r
F P
0 g
s
.65286 .7955 m .65522 .75737 L .62596 .75706 L p .707 .577 .707 r
F P
0 g
s
.56305 .75275 m .56068 .79088 L .59183 .7936 L p .707 .577 .707 r
F P
0 g
s
.56068 .79088 m .56305 .75275 L .53557 .74918 L p .707 .577 .707 r
F P
0 g
s
.53526 .73356 m .53744 .67681 L .51636 .6718 L p .707 .577 .707 r
F P
0 g
s
.59024 .83212 m .59156 .81303 L .56042 .81022 L p .707 .577 .707 r
F P
0 g
s
.59156 .81303 m .59024 .83212 L .62198 .83399 L p .707 .577 .707 r
F P
0 g
s
.62198 .83399 m .6233 .81489 L .59156 .81303 L p .707 .577 .707 r
F P
0 g
s
.56042 .81022 m .5591 .82931 L .59024 .83212 L p .707 .577 .707 r
F P
0 g
s
.53557 .74918 m .5332 .78731 L .56068 .79088 L p .707 .577 .707 r
F P
0 g
s
.6233 .81489 m .62198 .83399 L .65122 .83472 L p .707 .577 .707 r
F P
0 g
s
.65122 .83472 m .65254 .81563 L .6233 .81489 L p .707 .577 .707 r
F P
0 g
s
.5591 .82931 m .56042 .81022 L .53293 .80673 L p .707 .577 .707 r
F P
0 g
s
.65522 .75737 m .65286 .7955 L .67676 .79449 L p .707 .577 .707 r
F P
0 g
s
.67676 .79449 m .67913 .75636 L .65522 .75737 L p .707 .577 .707 r
F P
0 g
s
.51636 .6718 m .51417 .72856 L .53526 .73356 L p .707 .577 .707 r
F P
0 g
s
.53293 .80673 m .53161 .82583 L .5591 .82931 L p .707 .577 .707 r
F P
0 g
s
.68122 .67983 m .67903 .73658 L .69534 .73236 L p .707 .577 .707 r
F P
0 g
s
.69534 .73236 m .69753 .6756 L .68122 .67983 L p .707 .577 .707 r
F P
0 g
s
.5332 .78731 m .53557 .74918 L .51444 .74509 L p .707 .577 .707 r
F P
0 g
s
.65254 .81563 m .65122 .83472 L .67509 .83426 L p .707 .577 .707 r
F P
0 g
s
.67509 .83426 m .67641 .81517 L .65254 .81563 L p .707 .577 .707 r
F P
0 g
s
.51444 .74509 m .51207 .78322 L .5332 .78731 L p .707 .577 .707 r
F P
0 g
s
.51417 .72856 m .51636 .6718 L .50372 .66616 L p .707 .577 .707 r
F P
0 g
s
.53161 .82583 m .53293 .80673 L .51178 .80292 L p .707 .577 .707 r
F P
0 g
s
.51178 .80292 m .51046 .82202 L .53161 .82583 L p .707 .577 .707 r
F P
0 g
s
.67913 .75636 m .67676 .79449 L .69297 .79227 L p .707 .577 .707 r
F P
0 g
s
.69297 .79227 m .69534 .75414 L .67913 .75636 L p .707 .577 .707 r
F P
0 g
s
.50372 .66616 m .50154 .72292 L .51417 .72856 L p .707 .577 .707 r
F P
0 g
s
.51207 .78322 m .51444 .74509 L .50173 .74089 L p .707 .577 .707 r
F P
0 g
s
.67641 .81517 m .67509 .83426 L .69126 .83264 L p .707 .577 .707 r
F P
0 g
s
.69126 .83264 m .69258 .81355 L .67641 .81517 L p .707 .577 .707 r
F P
0 g
s
.69753 .6756 m .69534 .73236 L .70236 .72714 L p .707 .577 .707 r
F P
0 g
s
.70236 .72714 m .70455 .67038 L .69753 .6756 L p .707 .577 .707 r
F P
0 g
s
.50173 .74089 m .49936 .77902 L .51207 .78322 L p .707 .577 .707 r
F P
0 g
s
.51046 .82202 m .51178 .80292 L .49904 .79916 L p .707 .577 .707 r
F P
0 g
s
.49904 .79916 m .49772 .81825 L .51046 .82202 L p .707 .577 .707 r
F P
0 g
s
.50154 .72292 m .50372 .66616 L .50077 .66046 L p .707 .577 .707 r
F P
0 g
s
.69534 .75414 m .69297 .79227 L .69989 .78906 L p .707 .577 .707 r
F P
0 g
s
.69989 .78906 m .70226 .75093 L .69534 .75414 L p .707 .577 .707 r
F P
0 g
s
.50077 .66046 m .49859 .71722 L .50154 .72292 L p .707 .577 .707 r
F P
0 g
s
.69258 .81355 m .69126 .83264 L .69814 .83003 L p .707 .577 .707 r
F P
0 g
s
.69814 .83003 m .69946 .81094 L .69258 .81355 L p .707 .577 .707 r
F P
0 g
s
.49936 .77902 m .50173 .74089 L .49869 .73699 L p .707 .577 .707 r
F P
0 g
s
.70455 .67038 m .70236 .72714 L .69941 .72144 L p .707 .577 .707 r
F P
0 g
s
.69941 .72144 m .7016 .66468 L .70455 .67038 L p .707 .577 .707 r
F P
0 g
s
.49869 .73699 m .49632 .77512 L .49936 .77902 L p .707 .577 .707 r
F P
0 g
s
.49772 .81825 m .49904 .79916 L .49596 .7958 L p .707 .577 .707 r
F P
0 g
s
.49596 .7958 m .49465 .81489 L .49772 .81825 L p .707 .577 .707 r
F P
0 g
s
.49859 .71722 m .50077 .66046 L .50779 .65524 L p .707 .577 .707 r
F P
0 g
s
.70226 .75093 m .69989 .78906 L .69685 .78516 L p .707 .577 .707 r
F P
0 g
s
.69685 .78516 m .69922 .74703 L .70226 .75093 L p .707 .577 .707 r
F P
0 g
s
.50779 .65524 m .50561 .712 L .49859 .71722 L p .707 .577 .707 r
F P
0 g
s
.69946 .81094 m .69814 .83003 L .69506 .82667 L p .707 .577 .707 r
F P
0 g
s
.69506 .82667 m .69638 .80758 L .69946 .81094 L p .707 .577 .707 r
F P
0 g
s
.49632 .77512 m .49869 .73699 L .50561 .73378 L p .707 .577 .707 r
F P
0 g
s
.48023 .8138 m .50009 .30124 L .45609 .29785 L p .707 .577 .707 r
F P
0 g
s
.50561 .73378 m .50324 .77191 L .49632 .77512 L p .707 .577 .707 r
F P
0 g
s
.49465 .81489 m .49596 .7958 L .50285 .79319 L p .707 .577 .707 r
F P
0 g
s
.50285 .79319 m .50153 .81228 L .49465 .81489 L p .707 .577 .707 r
F P
0 g
s
.50561 .712 m .50779 .65524 L .5241 .65102 L p .707 .577 .707 r
F P
0 g
s
.5241 .65102 m .52192 .70777 L .50561 .712 L p .707 .577 .707 r
F P
0 g
s
.50324 .77191 m .50561 .73378 L .52181 .73156 L p .707 .577 .707 r
F P
0 g
s
.52181 .73156 m .51945 .76969 L .50324 .77191 L p .707 .577 .707 r
F P
0 g
s
.50153 .81228 m .50285 .79319 L .51901 .79157 L p .707 .577 .707 r
F P
0 g
s
.51901 .79157 m .51769 .81066 L .50153 .81228 L p .707 .577 .707 r
F P
0 g
s
.51945 .76969 m .52181 .73156 L .54572 .73056 L p .707 .577 .707 r
F P
0 g
s
.54572 .73056 m .54335 .76869 L .51945 .76969 L p .707 .577 .707 r
F P
0 g
s
.51769 .81066 m .51901 .79157 L .54288 .79111 L p .707 .577 .707 r
F P
0 g
s
.54288 .79111 m .54157 .8102 L .51769 .81066 L p .707 .577 .707 r
F P
0 g
s
.50009 .30124 m .48023 .8138 L .52514 .81475 L p .707 .577 .707 r
F P
0 g
s
.52192 .70777 m .5241 .65102 L .5481 .6482 L p .707 .577 .707 r
F P
0 g
s
.5481 .6482 m .54591 .70496 L .52192 .70777 L p .707 .577 .707 r
F P
0 g
s
.52514 .81475 m .54499 .3022 L .50009 .30124 L p .707 .577 .707 r
F P
0 g
s
.7016 .66468 m .69941 .72144 L .68677 .7158 L p .707 .577 .707 r
F P
0 g
s
.68677 .7158 m .68896 .65904 L .7016 .66468 L p .707 .577 .707 r
F P
0 g
s
.54591 .70496 m .5481 .6482 L .57744 .64707 L p .707 .577 .707 r
F P
0 g
s
.57744 .64707 m .57525 .70383 L .54591 .70496 L p .707 .577 .707 r
F P
0 g
s
.54335 .76869 m .54555 .73329 L p .57499 .73086 L .707 .577 .707 r
F P
0 g
s
.54555 .73329 m .54572 .73056 L .54596 .73056 L p .707 .577 .707 r
F P
0 g
s
.54596 .73056 m .57499 .73086 L p .54555 .73329 L .707 .577 .707 r
F P
0 g
s
.57525 .70383 m .57744 .64707 L .60925 .64774 L p .707 .577 .707 r
F P
0 g
s
.60925 .64774 m .60706 .7045 L .57525 .70383 L p .707 .577 .707 r
F P
0 g
s
.57499 .73086 m .57262 .76899 L .54335 .76869 L p .707 .577 .707 r
F P
0 g
s
.54157 .8102 m .54288 .79111 L .57212 .79184 L p .707 .577 .707 r
F P
0 g
s
.57212 .79184 m .5708 .81094 L .54157 .8102 L p .707 .577 .707 r
F P
0 g
s
.57262 .76899 m .57499 .73086 L .60675 .73245 L p .707 .577 .707 r
F P
0 g
s
.60675 .73245 m .60438 .77058 L .57262 .76899 L p .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57212 .79184 L .57817 .7922 L p .707 .577 .707 r
F P
0 g
s
.57817 .7922 m .60386 .79371 L p .57684 .80779 L .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57817 .7922 L .57684 .80779 L .707 .577 .707 r
F
.64041 .65014 m .63822 .7069 L .60706 .7045 L p F P
0 g
s
.60706 .7045 m .60925 .64774 L .64041 .65014 L p .707 .577 .707 r
F P
0 g
s
.63789 .73517 m .63553 .7733 L .60438 .77058 L p .707 .577 .707 r
F P
0 g
s
.60438 .77058 m .60675 .73245 L .63789 .73517 L p .707 .577 .707 r
F P
0 g
s
.63501 .79652 m .63369 .81561 L .60255 .8128 L p .707 .577 .707 r
F P
0 g
s
.60255 .8128 m .60386 .79371 L .63501 .79652 L p .707 .577 .707 r
F P
0 g
s
.60386 .79371 m .60255 .8128 L .5708 .81094 L p .707 .577 .707 r
F P
0 g
s
.60044 .80923 m .62346 .80329 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62029 .29667 m .62022 .29825 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62022 .29825 m .60044 .80923 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .60044 .80923 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.58641 .30062 m .57816 .51356 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.57816 .51356 m .56656 .81318 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.54499 .3022 m .52514 .81475 L .56656 .81318 L p .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .58641 .30062 L .54499 .3022 L p .707 .577 .707 r
F P
0 g
s
.25088 .70304 m .25307 .64628 L .2219 .64389 L p .707 .577 .707 r
F P
0 g
s
.25307 .64628 m .25088 .70304 L .28269 .70371 L p .707 .577 .707 r
F P
0 g
s
.28269 .70371 m .28487 .64695 L .25307 .64628 L p .707 .577 .707 r
F P
0 g
s
.43624 .81041 m .45609 .29785 L .41731 .29236 L p .707 .577 .707 r
F P
0 g
s
.45609 .29785 m .43624 .81041 L .48023 .8138 L p .707 .577 .707 r
F P
0 g
s
.28487 .64695 m .28269 .70371 L .31203 .70258 L p .707 .577 .707 r
F P
0 g
s
.31203 .70258 m .31421 .64582 L .28487 .64695 L p .707 .577 .707 r
F P
0 g
s
.21972 .70064 m .2219 .64389 L .19444 .63999 L p .707 .577 .707 r
F P
0 g
s
.2219 .64389 m .21972 .70064 L .25088 .70304 L p .707 .577 .707 r
F P
0 g
s
.69922 .74703 m .69685 .78516 L .68414 .78096 L p .707 .577 .707 r
F P
0 g
s
.68414 .78096 m .68651 .74283 L .69922 .74703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60044 .80923 m .62029 .29667 L .58641 .30062 L p .707 .577 .707 r
F P
0 g
s
.24882 .75679 m .25119 .71865 L .22004 .71594 L p .707 .577 .707 r
F P
0 g
s
.25119 .71865 m .24882 .75679 L .28058 .75837 L p .707 .577 .707 r
F P
0 g
s
.28058 .75837 m .28295 .72024 L .25119 .71865 L p .707 .577 .707 r
F P
0 g
s
.31421 .64582 m .31203 .70258 L .33602 .69977 L p .707 .577 .707 r
F P
0 g
s
.33602 .69977 m .33821 .64301 L .31421 .64582 L p .707 .577 .707 r
F P
0 g
s
.19444 .63999 m .19225 .69675 L .21972 .70064 L p .707 .577 .707 r
F P
0 g
s
.28295 .72024 m .28058 .75837 L .30985 .75868 L p .707 .577 .707 r
F P
0 g
s
.30985 .75868 m .31222 .72055 L .28295 .72024 L p .707 .577 .707 r
F P
0 g
s
.22004 .71594 m .21767 .75407 L .24882 .75679 L p .707 .577 .707 r
F P
0 g
s
.69638 .80758 m .69506 .82667 L .68232 .82291 L p .707 .577 .707 r
F P
0 g
s
.68232 .82291 m .68364 .80381 L .69638 .80758 L p .707 .577 .707 r
F P
0 g
s
.21767 .75407 m .22004 .71594 L .19256 .71236 L p .707 .577 .707 r
F P
0 g
s
.68896 .65904 m .68677 .7158 L .66569 .71079 L p .707 .577 .707 r
F P
0 g
s
.66569 .71079 m .66788 .65403 L .68896 .65904 L p .707 .577 .707 r
F P
0 g
s
.19225 .69675 m .19444 .63999 L .17335 .63498 L p .707 .577 .707 r
F P
0 g
s
.39746 .80491 m .41731 .29236 L .38755 .2853 L p .707 .577 .707 r
F P
0 g
s
.41731 .29236 m .39746 .80491 L .43624 .81041 L p .707 .577 .707 r
F P
0 g
s
.24723 .7953 m .24855 .77621 L .21741 .7734 L p .707 .577 .707 r
F P
0 g
s
.24855 .77621 m .24723 .7953 L .27897 .79717 L p .707 .577 .707 r
F P
0 g
s
.27897 .79717 m .28029 .77808 L .24855 .77621 L p .707 .577 .707 r
F P
0 g
s
.21741 .7734 m .21609 .79249 L .24723 .7953 L p .707 .577 .707 r
F P
0 g
s
.19256 .71236 m .19019 .75049 L .21767 .75407 L p .707 .577 .707 r
F P
0 g
s
.28029 .77808 m .27897 .79717 L .30821 .79791 L p .707 .577 .707 r
F P
0 g
s
.30821 .79791 m .30953 .77881 L .28029 .77808 L p .707 .577 .707 r
F P
0 g
s
.21609 .79249 m .21741 .7734 L .18992 .76992 L p .707 .577 .707 r
F P
0 g
s
.31222 .72055 m .30985 .75868 L .33376 .75768 L p .707 .577 .707 r
F P
0 g
s
.33376 .75768 m .33612 .71955 L .31222 .72055 L p .707 .577 .707 r
F P
0 g
s
.17335 .63498 m .17117 .69174 L .19225 .69675 L p .707 .577 .707 r
F P
0 g
s
.18992 .76992 m .1886 .78901 L .21609 .79249 L p .707 .577 .707 r
F P
0 g
s
.33821 .64301 m .33602 .69977 L .35233 .69555 L p .707 .577 .707 r
F P
0 g
s
.35233 .69555 m .35452 .63879 L .33821 .64301 L p .707 .577 .707 r
F P
0 g
s
.19019 .75049 m .19256 .71236 L .17143 .70827 L p .707 .577 .707 r
F P
0 g
s
.68651 .74283 m .68414 .78096 L .66301 .77688 L p .707 .577 .707 r
F P
0 g
s
.66301 .77688 m .66538 .73874 L .68651 .74283 L p .707 .577 .707 r
F P
0 g
s
.30953 .77881 m .30821 .79791 L .33208 .79745 L p .707 .577 .707 r
F P
0 g
s
.33208 .79745 m .3334 .77835 L .30953 .77881 L p .707 .577 .707 r
F P
0 g
s
.17143 .70827 m .16906 .7464 L .19019 .75049 L p .707 .577 .707 r
F P
0 g
s
.62346 .80329 m .64331 .29074 L .62029 .29667 L p .707 .577 .707 r
F P
0 g
s
.66788 .65403 m .66569 .71079 L .63822 .7069 L p .707 .577 .707 r
F P
0 g
s
.63822 .7069 m .64041 .65014 L .66788 .65403 L p .707 .577 .707 r
F P
0 g
s
.17117 .69174 m .17335 .63498 L .16072 .62935 L p .707 .577 .707 r
F P
0 g
s
.1886 .78901 m .18992 .76992 L .16877 .76611 L p .707 .577 .707 r
F P
0 g
s
.16877 .76611 m .16745 .7852 L .1886 .78901 L p .707 .577 .707 r
F P
0 g
s
.68364 .80381 m .68232 .82291 L .66118 .8191 L p .707 .577 .707 r
F P
0 g
s
.66118 .8191 m .6625 .8 L .68364 .80381 L p .707 .577 .707 r
F P
0 g
s
.33612 .71955 m .33376 .75768 L .34996 .75546 L p .707 .577 .707 r
F P
0 g
s
.34996 .75546 m .35233 .71733 L .33612 .71955 L p .707 .577 .707 r
F P
0 g
s
.16072 .62935 m .15853 .68611 L .17117 .69174 L p .707 .577 .707 r
F P
0 g
s
.3677 .79785 m .38755 .2853 L .36971 .27736 L p .707 .577 .707 r
F P
0 g
s
.38755 .2853 m .3677 .79785 L .39746 .80491 L p .707 .577 .707 r
F P
0 g
s
.16906 .7464 m .17143 .70827 L .15872 .70408 L p .707 .577 .707 r
F P
0 g
s
.3334 .77835 m .33208 .79745 L .34825 .79583 L p .707 .577 .707 r
F P
0 g
s
.34825 .79583 m .34957 .77673 L .3334 .77835 L p .707 .577 .707 r
F P
0 g
s
.66538 .73874 m .66301 .77688 L .63553 .7733 L p .707 .577 .707 r
F P
0 g
s
.63553 .7733 m .63789 .73517 L .66538 .73874 L p .707 .577 .707 r
F P
0 g
s
.35452 .63879 m .35233 .69555 L .35935 .69033 L p .707 .577 .707 r
F P
0 g
s
.35935 .69033 m .36154 .63357 L .35452 .63879 L p .707 .577 .707 r
F P
0 g
s
.15872 .70408 m .15635 .74221 L .16906 .7464 L p .707 .577 .707 r
F P
0 g
s
.16745 .7852 m .16877 .76611 L .15603 .76234 L p .707 .577 .707 r
F P
0 g
s
.15603 .76234 m .15471 .78143 L .16745 .7852 L p .707 .577 .707 r
F P
0 g
s
.6625 .8 m .66118 .8191 L .63369 .81561 L p .707 .577 .707 r
F P
0 g
s
.63369 .81561 m .63501 .79652 L .6625 .8 L p .707 .577 .707 r
F P
0 g
s
.15853 .68611 m .16072 .62935 L .15776 .62364 L p .707 .577 .707 r
F P
0 g
s
.35233 .71733 m .34996 .75546 L .35688 .75224 L p .707 .577 .707 r
F P
0 g
s
.35688 .75224 m .35925 .71411 L .35233 .71733 L p .707 .577 .707 r
F P
0 g
s
.64331 .29074 m .62346 .80329 L .63337 .79595 L p .707 .577 .707 r
F P
0 g
s
.63337 .79595 m .65322 .28339 L .64331 .29074 L p .707 .577 .707 r
F P
0 g
s
.15776 .62364 m .15558 .6804 L .15853 .68611 L p .707 .577 .707 r
F P
0 g
s
.34957 .77673 m .34825 .79583 L .35513 .79321 L p .707 .577 .707 r
F P
0 g
s
.35513 .79321 m .35645 .77412 L .34957 .77673 L p .707 .577 .707 r
F P
0 g
s
.15635 .74221 m .15872 .70408 L .15568 .70018 L p .707 .577 .707 r
F P
0 g
s
.36154 .63357 m .35935 .69033 L .3564 .68462 L p .707 .577 .707 r
F P
0 g
s
.3564 .68462 m .35859 .62786 L .36154 .63357 L p .707 .577 .707 r
F P
0 g
s
.15568 .70018 m .15331 .73831 L .15635 .74221 L p .707 .577 .707 r
F P
0 g
s
.35859 .62786 m .3564 .68462 L .34376 .67899 L p .707 .577 .707 r
F P
0 g
s
.34376 .67899 m .34595 .62223 L .35859 .62786 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .34113 .74415 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35621 .71021 m .35604 .71295 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35604 .71295 m .35384 .74835 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.34113 .74415 m .3435 .70602 L .35621 .71021 L p .707 .577 .707 r
F P
0 g
s
.35337 .77077 m .35205 .78986 L .33932 .78609 L p .707 .577 .707 r
F P
0 g
s
.33932 .78609 m .34063 .767 L .35337 .77077 L p .707 .577 .707 r
F P
0 g
s
.34986 .78992 m .36146 .4903 L p .36554 .26933 L .707 .577 .707 r
F P
0 g
s
.36146 .4903 m .36971 .27736 L .36678 .27173 L p .707 .577 .707 r
F P
0 g
s
.36678 .27173 m .36554 .26933 L p .36146 .4903 L .707 .577 .707 r
F P
0 g
s
.35925 .71411 m .35688 .75224 L .35384 .74835 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .35621 .71021 L .35925 .71411 L p .707 .577 .707 r
F P
0 g
s
.35645 .77412 m .35513 .79321 L .35205 .78986 L p .707 .577 .707 r
F P
0 g
s
.35205 .78986 m .35337 .77077 L .35645 .77412 L p .707 .577 .707 r
F P
0 g
s
.36971 .27736 m .34986 .78992 L .3677 .79785 L p .707 .577 .707 r
F P
0 g
s
.15471 .78143 m .15603 .76234 L .15295 .75898 L p .707 .577 .707 r
F P
0 g
s
.15295 .75898 m .15164 .77808 L .15471 .78143 L p .707 .577 .707 r
F P
0 g
s
.15558 .6804 m .15776 .62364 L .16479 .61842 L p .707 .577 .707 r
F P
0 g
s
.16479 .61842 m .1626 .67518 L .15558 .6804 L p .707 .577 .707 r
F P
0 g
s
.15331 .73831 m .15568 .70018 L .1626 .69696 L p .707 .577 .707 r
F P
0 g
s
.65322 .28339 m .63337 .79595 L .6292 .78791 L p .707 .577 .707 r
F P
0 g
s
.6292 .78791 m .64905 .27536 L .65322 .28339 L p .707 .577 .707 r
F P
0 g
s
.1626 .69696 m .16023 .73509 L .15331 .73831 L p .707 .577 .707 r
F P
0 g
s
.15164 .77808 m .15295 .75898 L .15984 .75637 L p .707 .577 .707 r
F P
0 g
s
.15984 .75637 m .15852 .77546 L .15164 .77808 L p .707 .577 .707 r
F P
0 g
s
.1626 .67518 m .16479 .61842 L .18109 .6142 L p .707 .577 .707 r
F P
0 g
s
.36554 .26933 m .34569 .78189 L .34986 .78992 L p .707 .577 .707 r
F P
0 g
s
.34569 .78189 m .36554 .26933 L .37545 .26199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18109 .6142 m .17891 .67096 L .1626 .67518 L p .707 .577 .707 r
F P
0 g
s
.16023 .73509 m .1626 .69696 L .1788 .69474 L p .707 .577 .707 r
F P
0 g
s
.34595 .62223 m .34376 .67899 L .32268 .67398 L p .707 .577 .707 r
F P
0 g
s
.32268 .67398 m .32487 .61722 L .34595 .62223 L p .707 .577 .707 r
F P
0 g
s
.1788 .69474 m .17644 .73288 L .16023 .73509 L p .707 .577 .707 r
F P
0 g
s
.15852 .77546 m .15984 .75637 L .176 .75475 L p .707 .577 .707 r
F P
0 g
s
.17891 .67096 m .18109 .6142 L .20509 .61139 L p .707 .577 .707 r
F P
0 g
s
.176 .75475 m .17468 .77385 L .15852 .77546 L p .707 .577 .707 r
F P
0 g
s
.64905 .27536 m .6292 .78791 L .61136 .77998 L p .707 .577 .707 r
F P
0 g
s
.61136 .77998 m .63121 .26742 L .64905 .27536 L p .707 .577 .707 r
F P
0 g
s
.3435 .70602 m .34113 .74415 L .32 .74006 L p .707 .577 .707 r
F P
0 g
s
.32 .74006 m .32237 .70193 L .3435 .70602 L p .707 .577 .707 r
F P
0 g
s
.20509 .61139 m .2029 .66815 L .17891 .67096 L p .707 .577 .707 r
F P
0 g
s
.32487 .61722 m .32268 .67398 L .29521 .67008 L p .707 .577 .707 r
F P
0 g
s
.29521 .67008 m .2974 .61333 L .32487 .61722 L p .707 .577 .707 r
F P
0 g
s
.17644 .73288 m .1788 .69474 L .20271 .69374 L p .707 .577 .707 r
F P
0 g
s
.34063 .767 m .33932 .78609 L .31817 .78228 L p .707 .577 .707 r
F P
0 g
s
.31817 .78228 m .31949 .76319 L .34063 .767 L p .707 .577 .707 r
F P
0 g
s
.2029 .66815 m .20509 .61139 L .23443 .61026 L p .707 .577 .707 r
F P
0 g
s
.20271 .69374 m .20034 .73187 L .17644 .73288 L p .707 .577 .707 r
F P
0 g
s
.3556 .77454 m .37545 .26199 L .39847 .25605 L p .707 .577 .707 r
F P
0 g
s
.37545 .26199 m .3556 .77454 L .34569 .78189 L p .707 .577 .707 r
F P
0 g
s
.17468 .77385 m .176 .75475 L .19987 .75429 L p .707 .577 .707 r
F P
0 g
s
.19987 .75429 m .19856 .77338 L .17468 .77385 L p .707 .577 .707 r
F P
0 g
s
.2974 .61333 m .29521 .67008 L .26405 .66769 L p .707 .577 .707 r
F P
0 g
s
.26405 .66769 m .26624 .61093 L .2974 .61333 L p .707 .577 .707 r
F P
0 g
s
.23443 .61026 m .23224 .66702 L .2029 .66815 L p .707 .577 .707 r
F P
0 g
s
.32237 .70193 m .32 .74006 L .29252 .73648 L p .707 .577 .707 r
F P
0 g
s
.29252 .73648 m .29489 .69835 L .32237 .70193 L p .707 .577 .707 r
F P
0 g
s
.23224 .66702 m .23443 .61026 L .26624 .61093 L p .707 .577 .707 r
F P
0 g
s
.73109 .65071 m .73328 .59395 L .70212 .59155 L p .707 .577 .707 r
F P
0 g
s
.73328 .59395 m .73109 .65071 L .7629 .65138 L p .707 .577 .707 r
F P
0 g
s
.7629 .65138 m .76509 .59462 L .73328 .59395 L p .707 .577 .707 r
F P
0 g
s
.26624 .61093 m .26405 .66769 L .23224 .66702 L p .707 .577 .707 r
F P
0 g
s
.20034 .73187 m .20271 .69374 L .23198 .69405 L p .707 .577 .707 r
F P
0 g
s
.76509 .59462 m .7629 .65138 L .79224 .65025 L p .707 .577 .707 r
F P
0 g
s
.79224 .65025 m .79442 .59349 L .76509 .59462 L p .707 .577 .707 r
F P
0 g
s
.31949 .76319 m .31817 .78228 L .29068 .7788 L p .707 .577 .707 r
F P
0 g
s
.29068 .7788 m .292 .75971 L .31949 .76319 L p .707 .577 .707 r
F P
0 g
s
.69993 .64831 m .70212 .59155 L .67465 .58766 L p .707 .577 .707 r
F P
0 g
s
.70212 .59155 m .69993 .64831 L .73109 .65071 L p .707 .577 .707 r
F P
0 g
s
.23198 .69405 m .22961 .73218 L .20034 .73187 L p .707 .577 .707 r
F P
0 g
s
.63121 .26742 m .61136 .77998 L .5816 .77292 L p .707 .577 .707 r
F P
0 g
s
.5816 .77292 m .60145 .26036 L .63121 .26742 L p .707 .577 .707 r
F P
0 g
s
.29489 .69835 m .29252 .73648 L .26137 .73377 L p .707 .577 .707 r
F P
0 g
s
.26137 .73377 m .26374 .69564 L .29489 .69835 L p .707 .577 .707 r
F P
0 g
s
.19856 .77338 m .19987 .75429 L .22911 .75503 L p .707 .577 .707 r
F P
0 g
s
.22911 .75503 m .22779 .77412 L .19856 .77338 L p .707 .577 .707 r
F P
0 g
s
.22961 .73218 m .23198 .69405 L .26374 .69564 L p .707 .577 .707 r
F P
0 g
s
.79442 .59349 m .79224 .65025 L .81624 .64743 L p .707 .577 .707 r
F P
0 g
s
.81624 .64743 m .81842 .59068 L .79442 .59349 L p .707 .577 .707 r
F P
0 g
s
.72903 .70831 m .7314 .67018 L .70026 .66746 L p .707 .577 .707 r
F P
0 g
s
.7314 .67018 m .72903 .70831 L .7608 .7099 L p .707 .577 .707 r
F P
0 g
s
.7608 .7099 m .76316 .67177 L .7314 .67018 L p .707 .577 .707 r
F P
0 g
s
.67465 .58766 m .67246 .64441 L .69993 .64831 L p .707 .577 .707 r
F P
0 g
s
.26374 .69564 m .26137 .73377 L .22961 .73218 L p .707 .577 .707 r
F P
0 g
s
.76316 .67177 m .7608 .7099 L .79006 .7102 L p .707 .577 .707 r
F P
0 g
s
.79006 .7102 m .79243 .67207 L .76316 .67177 L p .707 .577 .707 r
F P
0 g
s
.70026 .66746 m .69789 .70559 L .72903 .70831 L p .707 .577 .707 r
F P
0 g
s
.292 .75971 m .29068 .7788 L .25954 .77599 L p .707 .577 .707 r
F P
0 g
s
.25954 .77599 m .26086 .75689 L .292 .75971 L p .707 .577 .707 r
F P
0 g
s
.67246 .64441 m .67465 .58766 L .65356 .58265 L p .707 .577 .707 r
F P
0 g
s
.69789 .70559 m .70026 .66746 L .67277 .66388 L p .707 .577 .707 r
F P
0 g
s
.39847 .25605 m .37862 .76861 L .3556 .77454 L p .707 .577 .707 r
F P
0 g
s
.37862 .76861 m .39847 .25605 L .43235 .2521 L p .707 .577 .707 r
F P
0 g
s
.22779 .77412 m .22911 .75503 L .26086 .75689 L p .707 .577 .707 r
F P
0 g
s
.72744 .75225 m .72876 .73315 L .69762 .73034 L p .707 .577 .707 r
F P
0 g
s
.72876 .73315 m .72744 .75225 L .75919 .75411 L p .707 .577 .707 r
F P
0 g
s
.75919 .75411 m .7605 .73502 L .72876 .73315 L p .707 .577 .707 r
F P
0 g
s
.26086 .75689 m .25954 .77599 L .22779 .77412 L p .707 .577 .707 r
F P
0 g
s
.67277 .66388 m .6704 .70201 L .69789 .70559 L p .707 .577 .707 r
F P
0 g
s
.69762 .73034 m .6963 .74944 L .72744 .75225 L p .707 .577 .707 r
F P
0 g
s
.7605 .73502 m .75919 .75411 L .78842 .75485 L p .707 .577 .707 r
F P
0 g
s
.78842 .75485 m .78974 .73576 L .7605 .73502 L p .707 .577 .707 r
F P
0 g
s
.79243 .67207 m .79006 .7102 L .81397 .7092 L p .707 .577 .707 r
F P
0 g
s
.81397 .7092 m .81634 .67107 L .79243 .67207 L p .707 .577 .707 r
F P
0 g
s
.65356 .58265 m .65138 .63941 L .67246 .64441 L p .707 .577 .707 r
F P
0 g
s
.6963 .74944 m .69762 .73034 L .67013 .72686 L p .707 .577 .707 r
F P
0 g
s
.67013 .72686 m .66881 .74596 L .6963 .74944 L p .707 .577 .707 r
F P
0 g
s
.81842 .59068 m .81624 .64743 L .83254 .64321 L p .707 .577 .707 r
F P
0 g
s
.83254 .64321 m .83473 .58645 L .81842 .59068 L p .707 .577 .707 r
F P
0 g
s
.6704 .70201 m .67277 .66388 L .65164 .6598 L p .707 .577 .707 r
F P
0 g
s
.78974 .73576 m .78842 .75485 L .8123 .75439 L p .707 .577 .707 r
F P
0 g
s
.8123 .75439 m .81361 .7353 L .78974 .73576 L p .707 .577 .707 r
F P
0 g
s
.65164 .6598 m .64927 .69793 L .6704 .70201 L p .707 .577 .707 r
F P
0 g
s
.60145 .26036 m .5816 .77292 L .54282 .76743 L p .707 .577 .707 r
F P
0 g
s
.54282 .76743 m .56267 .25487 L .60145 .26036 L p .707 .577 .707 r
F P
0 g
s
.65138 .63941 m .65356 .58265 L .64093 .57701 L p .707 .577 .707 r
F P
0 g
s
.66881 .74596 m .67013 .72686 L .64898 .72305 L p .707 .577 .707 r
F P
0 g
s
.64898 .72305 m .64766 .74214 L .66881 .74596 L p .707 .577 .707 r
F P
0 g
s
.81634 .67107 m .81397 .7092 L .83018 .70698 L p .707 .577 .707 r
F P
0 g
s
.83018 .70698 m .83254 .66885 L .81634 .67107 L p .707 .577 .707 r
F P
0 g
s
.4125 .76466 m .43235 .2521 L .47377 .25052 L p .707 .577 .707 r
F P
0 g
s
.43235 .2521 m .4125 .76466 L .37862 .76861 L p .707 .577 .707 r
F P
0 g
s
.64093 .57701 m .63874 .63377 L .65138 .63941 L p .707 .577 .707 r
F P
0 g
s
.64927 .69793 m .65164 .6598 L .63893 .6556 L p .707 .577 .707 r
F P
0 g
s
.83473 .58645 m .83254 .64321 L .83957 .63799 L p .707 .577 .707 r
F P
0 g
s
.83957 .63799 m .84175 .58123 L .83473 .58645 L p .707 .577 .707 r
F P
0 g
s
.81361 .7353 m .8123 .75439 L .82846 .75277 L p .707 .577 .707 r
F P
0 g
s
.82846 .75277 m .82978 .73368 L .81361 .7353 L p .707 .577 .707 r
F P
0 g
s
.63893 .6556 m .63657 .69373 L .64927 .69793 L p .707 .577 .707 r
F P
0 g
s
.56267 .25487 m .54282 .76743 L .49882 .76404 L p .707 .577 .707 r
F P
0 g
s
.49882 .76404 m .51867 .25148 L .56267 .25487 L p .707 .577 .707 r
F P
0 g
s
.45392 .76308 m .47377 .25052 L .51867 .25148 L p .707 .577 .707 r
F P
0 g
s
.47377 .25052 m .45392 .76308 L .4125 .76466 L p .707 .577 .707 r
F P
0 g
s
.64766 .74214 m .64898 .72305 L .63625 .71928 L p .707 .577 .707 r
F P
0 g
s
.63874 .63377 m .64093 .57701 L .63798 .57131 L p .707 .577 .707 r
F P
0 g
s
.63625 .71928 m .63493 .73838 L .64766 .74214 L p .707 .577 .707 r
F P
0 g
s
.51867 .25148 m .49882 .76404 L .45392 .76308 L p .707 .577 .707 r
F P
0 g
s
.83254 .66885 m .83018 .70698 L .8371 .70376 L p .707 .577 .707 r
F P
0 g
s
.8371 .70376 m .83946 .66563 L .83254 .66885 L p .707 .577 .707 r
F P
0 g
s
.63798 .57131 m .63579 .62807 L .63874 .63377 L p .707 .577 .707 r
F P
0 g
s
.63657 .69373 m .63893 .6556 L .63589 .6517 L p .707 .577 .707 r
F P
0 g
s
.82978 .73368 m .82846 .75277 L .83534 .75016 L p .707 .577 .707 r
F P
0 g
s
.83534 .75016 m .83666 .73106 L .82978 .73368 L p .707 .577 .707 r
F P
0 g
s
.84175 .58123 m .83957 .63799 L .83662 .63229 L p .707 .577 .707 r
F P
0 g
s
.83662 .63229 m .8388 .57553 L .84175 .58123 L p .707 .577 .707 r
F P
0 g
s
.63589 .6517 m .63352 .68983 L .63657 .69373 L p .707 .577 .707 r
F P
0 g
s
.63493 .73838 m .63625 .71928 L .63317 .71593 L p .707 .577 .707 r
F P
0 g
s
.63317 .71593 m .63185 .73502 L .63493 .73838 L p .707 .577 .707 r
F P
0 g
s
.63579 .62807 m .63798 .57131 L .645 .56609 L p .707 .577 .707 r
F P
0 g
s
.83946 .66563 m .8371 .70376 L .83405 .69987 L p .707 .577 .707 r
F P
0 g
s
.83405 .69987 m .83642 .66174 L .83946 .66563 L p .707 .577 .707 r
F P
0 g
s
.645 .56609 m .64281 .62285 L .63579 .62807 L p .707 .577 .707 r
F P
0 g
s
.83666 .73106 m .83534 .75016 L .83227 .7468 L p .707 .577 .707 r
F P
0 g
s
.83227 .7468 m .83358 .72771 L .83666 .73106 L p .707 .577 .707 r
F P
0 g
s
.63352 .68983 m .63589 .6517 L .64281 .64848 L p .707 .577 .707 r
F P
0 g
s
.8388 .57553 m .83662 .63229 L .82398 .62665 L p .707 .577 .707 r
F P
0 g
s
.82398 .62665 m .82617 .56989 L .8388 .57553 L p .707 .577 .707 r
F P
0 g
s
.64281 .64848 m .64044 .68662 L .63352 .68983 L p .707 .577 .707 r
F P
0 g
s
.38808 .61389 m .39027 .55713 L .35911 .55473 L p .707 .577 .707 r
F P
0 g
s
.39027 .55713 m .38808 .61389 L .41989 .61456 L p .707 .577 .707 r
F P
0 g
s
.41989 .61456 m .42208 .5578 L .39027 .55713 L p .707 .577 .707 r
F P
0 g
s
.63185 .73502 m .63317 .71593 L .64005 .71331 L p .707 .577 .707 r
F P
0 g
s
.42208 .5578 m .41989 .61456 L .44923 .61343 L p .707 .577 .707 r
F P
0 g
s
.44923 .61343 m .45142 .55667 L .42208 .5578 L p .707 .577 .707 r
F P
0 g
s
.64005 .71331 m .63873 .73241 L .63185 .73502 L p .707 .577 .707 r
F P
0 g
s
.64281 .62285 m .645 .56609 L .66131 .56186 L p .707 .577 .707 r
F P
0 g
s
.35692 .61149 m .35911 .55473 L .33164 .55084 L p .707 .577 .707 r
F P
0 g
s
.35911 .55473 m .35692 .61149 L .38808 .61389 L p .707 .577 .707 r
F P
0 g
s
.83642 .66174 m .83405 .69987 L .82135 .69567 L p .707 .577 .707 r
F P
0 g
s
.82135 .69567 m .82371 .65754 L .83642 .66174 L p .707 .577 .707 r
F P
0 g
s
.66131 .56186 m .65912 .61862 L .64281 .62285 L p .707 .577 .707 r
F P
0 g
s
.45142 .55667 m .44923 .61343 L .47323 .61062 L p .707 .577 .707 r
F P
0 g
s
.47323 .61062 m .47541 .55386 L .45142 .55667 L p .707 .577 .707 r
F P
0 g
s
.38602 .67149 m .38839 .63336 L .35725 .63064 L p .707 .577 .707 r
F P
0 g
s
.38839 .63336 m .38602 .67149 L .41779 .67308 L p .707 .577 .707 r
F P
0 g
s
.41779 .67308 m .42015 .63495 L .38839 .63336 L p .707 .577 .707 r
F P
0 g
s
.33164 .55084 m .32945 .6076 L .35692 .61149 L p .707 .577 .707 r
F P
0 g
s
.42015 .63495 m .41779 .67308 L .44705 .67339 L p .707 .577 .707 r
F P
0 g
s
.44705 .67339 m .44942 .63526 L .42015 .63495 L p .707 .577 .707 r
F P
0 g
s
.35725 .63064 m .35488 .66877 L .38602 .67149 L p .707 .577 .707 r
F P
0 g
s
.64044 .68662 m .64281 .64848 L .65902 .64627 L p .707 .577 .707 r
F P
0 g
s
.82617 .56989 m .82398 .62665 L .8029 .62164 L p .707 .577 .707 r
F P
0 g
s
.8029 .62164 m .80508 .56488 L .82617 .56989 L p .707 .577 .707 r
F P
0 g
s
.32945 .6076 m .33164 .55084 L .31055 .54583 L p .707 .577 .707 r
F P
0 g
s
.83358 .72771 m .83227 .7468 L .81953 .74303 L p .707 .577 .707 r
F P
0 g
s
.81953 .74303 m .82085 .72394 L .83358 .72771 L p .707 .577 .707 r
F P
0 g
s
.35488 .66877 m .35725 .63064 L .32976 .62707 L p .707 .577 .707 r
F P
0 g
s
.65902 .64627 m .65665 .6844 L .64044 .68662 L p .707 .577 .707 r
F P
0 g
s
.38443 .71543 m .38575 .69634 L .35461 .69353 L p .707 .577 .707 r
F P
0 g
s
.38575 .69634 m .38443 .71543 L .41618 .7173 L p .707 .577 .707 r
F P
0 g
s
.41618 .7173 m .41749 .69821 L .38575 .69634 L p .707 .577 .707 r
F P
0 g
s
.32976 .62707 m .32739 .6652 L .35488 .66877 L p .707 .577 .707 r
F P
0 g
s
.35461 .69353 m .35329 .71262 L .38443 .71543 L p .707 .577 .707 r
F P
0 g
s
.41749 .69821 m .41618 .7173 L .44541 .71804 L p .707 .577 .707 r
F P
0 g
s
.44541 .71804 m .44673 .69894 L .41749 .69821 L p .707 .577 .707 r
F P
0 g
s
.65912 .61862 m .66131 .56186 L .6853 .55905 L p .707 .577 .707 r
F P
0 g
s
.44942 .63526 m .44705 .67339 L .47096 .67238 L p .707 .577 .707 r
F P
0 g
s
.47096 .67238 m .47333 .63425 L .44942 .63526 L p .707 .577 .707 r
F P
0 g
s
.31055 .54583 m .30837 .60259 L .32945 .6076 L p .707 .577 .707 r
F P
0 g
s
.63873 .73241 m .64005 .71331 L .65622 .7117 L p .707 .577 .707 r
F P
0 g
s
.35329 .71262 m .35461 .69353 L .32712 .69005 L p .707 .577 .707 r
F P
0 g
s
.65622 .7117 m .6549 .73079 L .63873 .73241 L p .707 .577 .707 r
F P
0 g
s
.32712 .69005 m .3258 .70914 L .35329 .71262 L p .707 .577 .707 r
F P
0 g
s
.47541 .55386 m .47323 .61062 L .48953 .6064 L p .707 .577 .707 r
F P
0 g
s
.48953 .6064 m .49172 .54964 L .47541 .55386 L p .707 .577 .707 r
F P
0 g
s
.32739 .6652 m .32976 .62707 L .30863 .62298 L p .707 .577 .707 r
F P
0 g
s
.82371 .65754 m .82135 .69567 L .80022 .69158 L p .707 .577 .707 r
F P
0 g
s
.80022 .69158 m .80258 .65345 L .82371 .65754 L p .707 .577 .707 r
F P
0 g
s
.6853 .55905 m .68312 .61581 L .65912 .61862 L p .707 .577 .707 r
F P
0 g
s
.44673 .69894 m .44541 .71804 L .46929 .71757 L p .707 .577 .707 r
F P
0 g
s
.46929 .71757 m .4706 .69848 L .44673 .69894 L p .707 .577 .707 r
F P
0 g
s
.30863 .62298 m .30626 .66111 L .32739 .6652 L p .707 .577 .707 r
F P
0 g
s
.80508 .56488 m .8029 .62164 L .77543 .61775 L p .707 .577 .707 r
F P
0 g
s
.77543 .61775 m .77761 .56099 L .80508 .56488 L p .707 .577 .707 r
F P
0 g
s
.30837 .60259 m .31055 .54583 L .29792 .5402 L p .707 .577 .707 r
F P
0 g
s
.65665 .6844 m .65902 .64627 L .68292 .64526 L p .707 .577 .707 r
F P
0 g
s
.3258 .70914 m .32712 .69005 L .30597 .68624 L p .707 .577 .707 r
F P
0 g
s
.30597 .68624 m .30465 .70533 L .3258 .70914 L p .707 .577 .707 r
F P
0 g
s
.82085 .72394 m .81953 .74303 L .79838 .73922 L p .707 .577 .707 r
F P
0 g
s
.79838 .73922 m .7997 .72013 L .82085 .72394 L p .707 .577 .707 r
F P
0 g
s
.68312 .61581 m .6853 .55905 L .71464 .55792 L p .707 .577 .707 r
F P
0 g
s
.47333 .63425 m .47096 .67238 L .48717 .67016 L p .707 .577 .707 r
F P
0 g
s
.48717 .67016 m .48953 .63203 L .47333 .63425 L p .707 .577 .707 r
F P
0 g
s
.68292 .64526 m .68056 .68339 L .65665 .6844 L p .707 .577 .707 r
F P
0 g
s
.29792 .5402 m .29573 .59696 L .30837 .60259 L p .707 .577 .707 r
F P
0 g
s
.6549 .73079 m .65622 .7117 L .68009 .71123 L p .707 .577 .707 r
F P
0 g
s
.77761 .56099 m .77543 .61775 L .74426 .61535 L p .707 .577 .707 r
F P
0 g
s
.74426 .61535 m .74645 .55859 L .77761 .56099 L p .707 .577 .707 r
F P
0 g
s
.68009 .71123 m .67877 .73033 L .6549 .73079 L p .707 .577 .707 r
F P
0 g
s
.30626 .66111 m .30863 .62298 L .29592 .61878 L p .707 .577 .707 r
F P
0 g
s
.71464 .55792 m .71246 .61468 L .68312 .61581 L p .707 .577 .707 r
F P
0 g
s
.49172 .54964 m .48953 .6064 L .49656 .60118 L p .707 .577 .707 r
F P
0 g
s
.49656 .60118 m .49874 .54442 L .49172 .54964 L p .707 .577 .707 r
F P
0 g
s
.80258 .65345 m .80022 .69158 L .77273 .688 L p .707 .577 .707 r
F P
0 g
s
.77273 .688 m .7751 .64987 L .80258 .65345 L p .707 .577 .707 r
F P
0 g
s
.4706 .69848 m .46929 .71757 L .48545 .71596 L p .707 .577 .707 r
F P
0 g
s
.48545 .71596 m .48677 .69686 L .4706 .69848 L p .707 .577 .707 r
F P
0 g
s
.71246 .61468 m .71464 .55792 L .74645 .55859 L p .707 .577 .707 r
F P
0 g
s
.29592 .61878 m .29356 .65691 L .30626 .66111 L p .707 .577 .707 r
F P
0 g
s
.74645 .55859 m .74426 .61535 L .71246 .61468 L p .707 .577 .707 r
F P
0 g
s
.68056 .68339 m .68292 .64526 L .71219 .64557 L p .707 .577 .707 r
F P
0 g
s
.30465 .70533 m .30597 .68624 L .29324 .68247 L p .707 .577 .707 r
F P
0 g
s
.29573 .59696 m .29792 .5402 L .29497 .53449 L p .707 .577 .707 r
F P
0 g
s
.29324 .68247 m .29192 .70156 L .30465 .70533 L p .707 .577 .707 r
F P
0 g
s
.71219 .64557 m .70982 .6837 L .68056 .68339 L p .707 .577 .707 r
F P
0 g
s
.7997 .72013 m .79838 .73922 L .77089 .73574 L p .707 .577 .707 r
F P
0 g
s
.77089 .73574 m .77221 .71665 L .7997 .72013 L p .707 .577 .707 r
F P
0 g
s
.7751 .64987 m .77273 .688 L .74159 .68529 L p .707 .577 .707 r
F P
0 g
s
.74159 .68529 m .74395 .64716 L .7751 .64987 L p .707 .577 .707 r
F P
0 g
s
.48953 .63203 m .48717 .67016 L .49409 .66695 L p .707 .577 .707 r
F P
0 g
s
.49409 .66695 m .49645 .62882 L .48953 .63203 L p .707 .577 .707 r
F P
0 g
s
.67877 .73033 m .68009 .71123 L .70933 .71197 L p .707 .577 .707 r
F P
0 g
s
.70982 .6837 m .71219 .64557 L .74395 .64716 L p .707 .577 .707 r
F P
0 g
s
.70933 .71197 m .70801 .73107 L .67877 .73033 L p .707 .577 .707 r
F P
0 g
s
.29497 .53449 m .29278 .59125 L .29573 .59696 L p .707 .577 .707 r
F P
0 g
s
.74395 .64716 m .74159 .68529 L .70982 .6837 L p .707 .577 .707 r
F P
0 g
s
.77221 .71665 m .77089 .73574 L .73975 .73293 L p .707 .577 .707 r
F P
0 g
s
.73975 .73293 m .74107 .71384 L .77221 .71665 L p .707 .577 .707 r
F P
0 g
s
.29356 .65691 m .29592 .61878 L .29288 .61488 L p .707 .577 .707 r
F P
0 g
s
.48677 .69686 m .48545 .71596 L .49233 .71334 L p .707 .577 .707 r
F P
0 g
s
.49233 .71334 m .49365 .69425 L .48677 .69686 L p .707 .577 .707 r
F P
0 g
s
.49874 .54442 m .49656 .60118 L .4936 .59547 L p .707 .577 .707 r
F P
0 g
s
.4936 .59547 m .49579 .53871 L .49874 .54442 L p .707 .577 .707 r
F P
0 g
s
.70801 .73107 m .70933 .71197 L .74107 .71384 L p .707 .577 .707 r
F P
0 g
s
.29288 .61488 m .29051 .65302 L .29356 .65691 L p .707 .577 .707 r
F P
0 g
s
.74107 .71384 m .73975 .73293 L .70801 .73107 L p .707 .577 .707 r
F P
0 g
s
.29192 .70156 m .29324 .68247 L .29016 .67911 L p .707 .577 .707 r
F P
0 g
s
.29016 .67911 m .28884 .69821 L .29192 .70156 L p .707 .577 .707 r
F P
0 g
s
.29278 .59125 m .29497 .53449 L .30199 .52927 L p .707 .577 .707 r
F P
0 g
s
.49645 .62882 m .49409 .66695 L .49104 .66305 L p .707 .577 .707 r
F P
0 g
s
.49104 .66305 m .49341 .62492 L .49645 .62882 L p .707 .577 .707 r
F P
0 g
s
.30199 .52927 m .2998 .58603 L .29278 .59125 L p .707 .577 .707 r
F P
0 g
s
.49365 .69425 m .49233 .71334 L .48926 .70999 L p .707 .577 .707 r
F P
0 g
s
.48926 .70999 m .49057 .69089 L .49365 .69425 L p .707 .577 .707 r
F P
0 g
s
.29051 .65302 m .29288 .61488 L .2998 .61167 L p .707 .577 .707 r
F P
0 g
s
.49579 .53871 m .4936 .59547 L .48097 .58984 L p .707 .577 .707 r
F P
0 g
s
.48097 .58984 m .48315 .53308 L .49579 .53871 L p .707 .577 .707 r
F P
0 g
s
.2998 .61167 m .29743 .6498 L .29051 .65302 L p .707 .577 .707 r
F P
0 g
s
.28884 .69821 m .29016 .67911 L .29704 .6765 L p .707 .577 .707 r
F P
0 g
s
.29704 .6765 m .29572 .69559 L .28884 .69821 L p .707 .577 .707 r
F P
0 g
s
.2998 .58603 m .30199 .52927 L .3183 .52505 L p .707 .577 .707 r
F P
0 g
s
.49341 .62492 m .49104 .66305 L .47834 .65885 L p .707 .577 .707 r
F P
0 g
s
.47834 .65885 m .4807 .62072 L .49341 .62492 L p .707 .577 .707 r
F P
0 g
s
.3183 .52505 m .31611 .58181 L .2998 .58603 L p .707 .577 .707 r
F P
0 g
s
.29743 .6498 m .2998 .61167 L .31601 .60945 L p .707 .577 .707 r
F P
0 g
s
.48315 .53308 m .48097 .58984 L .45988 .58483 L p .707 .577 .707 r
F P
0 g
s
.45988 .58483 m .46207 .52807 L .48315 .53308 L p .707 .577 .707 r
F P
0 g
s
.49057 .69089 m .48926 .70999 L .47652 .70622 L p .707 .577 .707 r
F P
0 g
s
.47652 .70622 m .47784 .68713 L .49057 .69089 L p .707 .577 .707 r
F P
0 g
s
.31601 .60945 m .31364 .64758 L .29743 .6498 L p .707 .577 .707 r
F P
0 g
s
.31611 .58181 m .3183 .52505 L .34229 .52224 L p .707 .577 .707 r
F P
0 g
s
.29572 .69559 m .29704 .6765 L .31321 .67488 L p .707 .577 .707 r
F P
0 g
s
.31321 .67488 m .31189 .69397 L .29572 .69559 L p .707 .577 .707 r
F P
0 g
s
.4807 .62072 m .47834 .65885 L .45721 .65477 L p .707 .577 .707 r
F P
0 g
s
.45721 .65477 m .45957 .61664 L .4807 .62072 L p .707 .577 .707 r
F P
0 g
s
.34229 .52224 m .34011 .57899 L .31611 .58181 L p .707 .577 .707 r
F P
0 g
s
.46207 .52807 m .45988 .58483 L .43242 .58093 L p .707 .577 .707 r
F P
0 g
s
.43242 .58093 m .4346 .52417 L .46207 .52807 L p .707 .577 .707 r
F P
0 g
s
.31364 .64758 m .31601 .60945 L .33991 .60845 L p .707 .577 .707 r
F P
0 g
s
.47784 .68713 m .47652 .70622 L .45537 .70241 L p .707 .577 .707 r
F P
0 g
s
.45537 .70241 m .45669 .68331 L .47784 .68713 L p .707 .577 .707 r
F P
0 g
s
.34011 .57899 m .34229 .52224 L .37163 .52111 L p .707 .577 .707 r
F P
0 g
s
.33991 .60845 m .33755 .64658 L .31364 .64758 L p .707 .577 .707 r
F P
0 g
s
.31189 .69397 m .31321 .67488 L .33708 .67442 L p .707 .577 .707 r
F P
0 g
s
.4346 .52417 m .43242 .58093 L .40125 .57853 L p .707 .577 .707 r
F P
0 g
s
.40125 .57853 m .40344 .52178 L .4346 .52417 L p .707 .577 .707 r
F P
0 g
s
.33708 .67442 m .33576 .69351 L .31189 .69397 L p .707 .577 .707 r
F P
0 g
s
.37163 .52111 m .36945 .57787 L .34011 .57899 L p .707 .577 .707 r
F P
0 g
s
.45957 .61664 m .45721 .65477 L .42972 .65119 L p .707 .577 .707 r
F P
0 g
s
.42972 .65119 m .43209 .61306 L .45957 .61664 L p .707 .577 .707 r
F P
0 g
s
.36945 .57787 m .37163 .52111 L .40344 .52178 L p .707 .577 .707 r
F P
0 g
s
.40344 .52178 m .40125 .57853 L .36945 .57787 L p .707 .577 .707 r
F P
0 g
s
.33755 .64658 m .33991 .60845 L .36918 .60875 L p .707 .577 .707 r
F P
0 g
s
.36918 .60875 m .36681 .64688 L .33755 .64658 L p .707 .577 .707 r
F P
0 g
s
.45669 .68331 m .45537 .70241 L .42788 .69893 L p .707 .577 .707 r
F P
0 g
s
.42788 .69893 m .4292 .67983 L .45669 .68331 L p .707 .577 .707 r
F P
0 g
s
.43209 .61306 m .42972 .65119 L .39857 .64847 L p .707 .577 .707 r
F P
0 g
s
.39857 .64847 m .40094 .61034 L .43209 .61306 L p .707 .577 .707 r
F P
0 g
s
.33576 .69351 m .33708 .67442 L .36632 .67516 L p .707 .577 .707 r
F P
0 g
s
.36681 .64688 m .36918 .60875 L .40094 .61034 L p .707 .577 .707 r
F P
0 g
s
.36632 .67516 m .365 .69425 L .33576 .69351 L p .707 .577 .707 r
F P
0 g
s
.40094 .61034 m .39857 .64847 L .36681 .64688 L p .707 .577 .707 r
F P
0 g
s
.4292 .67983 m .42788 .69893 L .39674 .69612 L p .707 .577 .707 r
F P
0 g
s
.39674 .69612 m .39806 .67702 L .4292 .67983 L p .707 .577 .707 r
F P
0 g
s
.365 .69425 m .36632 .67516 L .39806 .67702 L p .707 .577 .707 r
F P
0 g
s
.39806 .67702 m .39674 .69612 L .365 .69425 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Ioob<008Aoo`00L7oo1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF2@00Ngoo001/Ool400000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol006Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00J7oo0`001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01000K7oo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000J7oo001WOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YF000006Ioo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001TOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001NOolJ000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Qoo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0047oo4P00A7oo001COol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo300015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP<0035oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00008002ioo`00Dgoo00<005YF00000eYF00@005YFFUIJEQT000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1`000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH00000FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00EGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo001J
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00=goo6@001Goo8@0000=JEP00
FUH01UYF00@005YFFUIJEPH000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00<Goo1P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3@0035YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1`002UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF3P001eYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP050005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1P0015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH000020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF0000000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000@000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003OolG0008FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000090007FUH00`00FUIJEP05FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF6`00<goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00;7oo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@00003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ40
00AJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ao
o`03001JEP0000=JEP`00003FUH005YF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEQ40
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00;7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEPd0009JEP03001JEUYF00=JEP03001JEUYF00=JEQH000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF008002ioo`00;7oo00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEUYF
009JEQ<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
FUIJEQh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`800003
FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP050005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00;goo0`0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=J
EP05001JEUYFFUH0000_Ool0035ooah00005FUH005YF001JEP0Q0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<007ooOol0;Goo000^Ool300000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHD0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP00Ool0;Woo000/Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1@000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<0
05YFFUH00eYF00<005YFFUH00P000goo8P00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000240
04Ioo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH04@0015YF
00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=goo000[Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEP00000`Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEQH000AJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002moo`00:goo00<005YF0000
0UYF7`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF
300015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00:goo1P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF20000eYF00<005YFFUH00eYF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2`000eYF00<005YFFUH00eYF00@005YFFUIJ
EP8002moo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;goo000/Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF0P00;goo000^Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000EJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4000_Ool003=oo`L000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH00UYF4@0015YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;goo000`OolG0008FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP03FUH00`00FUIJEP02000;OolJ000`Ool0
02]oo`D0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ/00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00FUIJ
EP02001EOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP04FUH00`00FUIJEP02001EOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60005Ool01000FUIJEP00
1EYF00<005YFFUH00eYF30002UYF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH01P000UYF00<005YFFUH00UYF1`002eYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Eoo`00:goo00<005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEP00008000IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol002]oo`03001JEP0000L0
0003FUH005YF00AJEQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP@0009JEP03001JEUYF009JEP03001JEP0000=JEPH000AJEP05001JEUYFFUH0001FOol002]oo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP03
001JEP00008000]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP03001JEP0000AJEP03001JEUYF009JEP<00003FUH005YF009JEP03
001oogoo05Aoo`00:goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1P00
0eYF00<005YFFUH015YF1`000eYF00<005YF00003EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP0000AJ
EP03001JEUYF00AJEP@0009JEP03001oogoo05Aoo`00;Goo1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1P003EYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000=JEP00FUH00eYF00<005YFFUH015YF00@005YFFUIJEP<005Ioo`00<Woo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EWoo
000iOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
0009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YFFUIJEPT005Moo`00@Woo8P000goo0`00
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH02@00H7oo001ZOol40002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH7
001NOol006ioo`D000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00D005Uoo`00Lgoo1P000eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Moo`00NGoo2@001UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00UYF1`001eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH00P00EWoo0022Oolf0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EWoo002=Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH60003
FUH01000FUIJEUYF0P00EWoo002?Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH2001FOol009Aoo`L000=JEP03001JEUYF00IJEP03
001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003FUH0000005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0`00EWoo002SOol90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05001FOol00:ao
oaH005]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5927 .73367 m .59623 .67648 L .56508 .67377 L p .707 .577 .707 r
F P
0 g
s
.59623 .67648 m .5927 .73367 L .62446 .73524 L p .707 .577 .707 r
F P
0 g
s
.62446 .73524 m .62799 .67805 L .59623 .67648 L p .707 .577 .707 r
F P
0 g
s
.62799 .67805 m .62446 .73524 L .65373 .73553 L p .707 .577 .707 r
F P
0 g
s
.65373 .73553 m .65725 .67834 L .62799 .67805 L p .707 .577 .707 r
F P
0 g
s
.56155 .73096 m .56508 .67377 L .53759 .67019 L p .707 .577 .707 r
F P
0 g
s
.56508 .67377 m .56155 .73096 L .5927 .73367 L p .707 .577 .707 r
F P
0 g
s
.58968 .78315 m .59348 .74488 L .56238 .74165 L p .707 .577 .707 r
F P
0 g
s
.59348 .74488 m .58968 .78315 L .62132 .78622 L p .707 .577 .707 r
F P
0 g
s
.62132 .78622 m .62513 .74795 L .59348 .74488 L p .707 .577 .707 r
F P
0 g
s
.56238 .74165 m .55858 .77992 L .58968 .78315 L p .707 .577 .707 r
F P
0 g
s
.53759 .67019 m .53407 .72738 L .56155 .73096 L p .707 .577 .707 r
F P
0 g
s
.62513 .74795 m .62132 .78622 L .6504 .78884 L p .707 .577 .707 r
F P
0 g
s
.6504 .78884 m .65421 .75057 L .62513 .74795 L p .707 .577 .707 r
F P
0 g
s
.65725 .67834 m .65373 .73553 L .67764 .73449 L p .707 .577 .707 r
F P
0 g
s
.67764 .73449 m .68116 .6773 L .65725 .67834 L p .707 .577 .707 r
F P
0 g
s
.55825 .79721 m .55613 .81633 L .58722 .81971 L p .707 .577 .707 r
F P
0 g
s
.58722 .81971 m .58934 .80059 L .55825 .79721 L p .707 .577 .707 r
F P
0 g
s
.58934 .80059 m .58722 .81971 L .61882 .82323 L p .707 .577 .707 r
F P
0 g
s
.61882 .82323 m .62093 .80411 L .58934 .80059 L p .707 .577 .707 r
F P
0 g
s
.55858 .77992 m .56238 .74165 L .53485 .73858 L p .707 .577 .707 r
F P
0 g
s
.53485 .73858 m .53105 .77685 L .55858 .77992 L p .707 .577 .707 r
F P
0 g
s
.62093 .80411 m .61882 .82323 L .64782 .82655 L p .707 .577 .707 r
F P
0 g
s
.64782 .82655 m .64994 .80743 L .62093 .80411 L p .707 .577 .707 r
F P
0 g
s
.53407 .72738 m .53759 .67019 L .51647 .66608 L p .707 .577 .707 r
F P
0 g
s
.53071 .7943 m .52859 .81342 L .55613 .81633 L p .707 .577 .707 r
F P
0 g
s
.55613 .81633 m .55825 .79721 L .53071 .7943 L p .707 .577 .707 r
F P
0 g
s
.65421 .75057 m .6504 .78884 L .67407 .79075 L p .707 .577 .707 r
F P
0 g
s
.67407 .79075 m .67788 .75248 L .65421 .75057 L p .707 .577 .707 r
F P
0 g
s
.51647 .66608 m .51294 .72327 L .53407 .72738 L p .707 .577 .707 r
F P
0 g
s
.64994 .80743 m .64782 .82655 L .6714 .82933 L p .707 .577 .707 r
F P
0 g
s
.6714 .82933 m .67351 .81022 L .64994 .80743 L p .707 .577 .707 r
F P
0 g
s
.53105 .77685 m .53485 .73858 L .5136 .73598 L p .707 .577 .707 r
F P
0 g
s
.5136 .73598 m .5098 .77425 L .53105 .77685 L p .707 .577 .707 r
F P
0 g
s
.68116 .6773 m .67764 .73449 L .69384 .73224 L p .707 .577 .707 r
F P
0 g
s
.69384 .73224 m .69737 .67505 L .68116 .6773 L p .707 .577 .707 r
F P
0 g
s
.50941 .79214 m .50729 .81126 L .52859 .81342 L p .707 .577 .707 r
F P
0 g
s
.52859 .81342 m .53071 .7943 L .50941 .79214 L p .707 .577 .707 r
F P
0 g
s
.51294 .72327 m .51647 .66608 L .50376 .66186 L p .707 .577 .707 r
F P
0 g
s
.67788 .75248 m .67407 .79075 L .69002 .79176 L p .707 .577 .707 r
F P
0 g
s
.69002 .79176 m .69382 .75349 L .67788 .75248 L p .707 .577 .707 r
F P
0 g
s
.50376 .66186 m .50023 .71905 L .51294 .72327 L p .707 .577 .707 r
F P
0 g
s
.67351 .81022 m .6714 .82933 L .68725 .83132 L p .707 .577 .707 r
F P
0 g
s
.68725 .83132 m .68936 .8122 L .67351 .81022 L p .707 .577 .707 r
F P
0 g
s
.5098 .77425 m .5136 .73598 L .50071 .73409 L p .707 .577 .707 r
F P
0 g
s
.50071 .73409 m .49691 .77236 L .5098 .77425 L p .707 .577 .707 r
F P
0 g
s
.49644 .79096 m .49433 .81007 L .50729 .81126 L p .707 .577 .707 r
F P
0 g
s
.50729 .81126 m .50941 .79214 L .49644 .79096 L p .707 .577 .707 r
F P
0 g
s
.69737 .67505 m .69384 .73224 L .70077 .72899 L p .707 .577 .707 r
F P
0 g
s
.70077 .72899 m .7043 .6718 L .69737 .67505 L p .707 .577 .707 r
F P
0 g
s
.50023 .71905 m .50376 .66186 L .50072 .65793 L p .707 .577 .707 r
F P
0 g
s
.69382 .75349 m .69002 .79176 L .69668 .79177 L p .707 .577 .707 r
F P
0 g
s
.69668 .79177 m .70048 .7535 L .69382 .75349 L p .707 .577 .707 r
F P
0 g
s
.68936 .8122 m .68725 .83132 L .6938 .83231 L p .707 .577 .707 r
F P
0 g
s
.50072 .65793 m .49719 .71512 L .50023 .71905 L p .707 .577 .707 r
F P
0 g
s
.6938 .83231 m .69592 .81319 L .68936 .8122 L p .707 .577 .707 r
F P
0 g
s
.49691 .77236 m .50071 .73409 L .49743 .73311 L p .707 .577 .707 r
F P
0 g
s
.49743 .73311 m .49363 .77138 L .49691 .77236 L p .707 .577 .707 r
F P
0 g
s
.49307 .79085 m .49096 .80997 L .49433 .81007 L p .707 .577 .707 r
F P
0 g
s
.49433 .81007 m .49644 .79096 L .49307 .79085 L p .707 .577 .707 r
F P
0 g
s
.7043 .6718 m .70077 .72899 L .69773 .72506 L p .707 .577 .707 r
F P
0 g
s
.69773 .72506 m .70125 .66787 L .7043 .6718 L p .707 .577 .707 r
F P
0 g
s
.49719 .71512 m .50072 .65793 L .50764 .65468 L p .707 .577 .707 r
F P
0 g
s
.70048 .7535 m .69668 .79177 L .6934 .79079 L p .707 .577 .707 r
F P
0 g
s
.6934 .79079 m .69721 .75252 L .70048 .7535 L p .707 .577 .707 r
F P
0 g
s
.69592 .81319 m .6938 .83231 L .69043 .8322 L p .707 .577 .707 r
F P
0 g
s
.69043 .8322 m .69255 .81309 L .69592 .81319 L p .707 .577 .707 r
F P
0 g
s
.50764 .65468 m .50411 .71187 L .49719 .71512 L p .707 .577 .707 r
F P
0 g
s
.49363 .77138 m .49743 .73311 L .50409 .73312 L p .707 .577 .707 r
F P
0 g
s
.50409 .73312 m .50029 .77139 L .49363 .77138 L p .707 .577 .707 r
F P
0 g
s
.49963 .79184 m .49751 .81096 L .49096 .80997 L p .707 .577 .707 r
F P
0 g
s
.49096 .80997 m .49307 .79085 L .49963 .79184 L p .707 .577 .707 r
F P
0 g
s
.70125 .66787 m .69773 .72506 L .68502 .72084 L p .707 .577 .707 r
F P
0 g
s
.68502 .72084 m .68855 .66365 L .70125 .66787 L p .707 .577 .707 r
F P
0 g
s
.24969 .69686 m .25322 .63967 L .22207 .63695 L p .707 .577 .707 r
F P
0 g
s
.25322 .63967 m .24969 .69686 L .28145 .69843 L p .707 .577 .707 r
F P
0 g
s
.28145 .69843 m .28498 .64124 L .25322 .63967 L p .707 .577 .707 r
F P
0 g
s
.28498 .64124 m .28145 .69843 L .31072 .69871 L p .707 .577 .707 r
F P
0 g
s
.31072 .69871 m .31425 .64152 L .28498 .64124 L p .707 .577 .707 r
F P
0 g
s
.50411 .71187 m .50764 .65468 L .52385 .65243 L p .707 .577 .707 r
F P
0 g
s
.21854 .69415 m .22207 .63695 L .19459 .63337 L p .707 .577 .707 r
F P
0 g
s
.22207 .63695 m .21854 .69415 L .24969 .69686 L p .707 .577 .707 r
F P
0 g
s
.47424 .80736 m .50627 .29091 L .4623 .28708 L p .707 .577 .707 r
F P
0 g
s
.52385 .65243 m .52032 .70962 L .50411 .71187 L p .707 .577 .707 r
F P
0 g
s
.50029 .77139 m .50409 .73312 L .52004 .73413 L p .707 .577 .707 r
F P
0 g
s
.52004 .73413 m .51624 .7724 L .50029 .77139 L p .707 .577 .707 r
F P
0 g
s
.51547 .79383 m .51336 .81294 L .49751 .81096 L p .707 .577 .707 r
F P
0 g
s
.49751 .81096 m .49963 .79184 L .51547 .79383 L p .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .52004 .73413 L .54137 .73585 L p .707 .577 .707 r
F P
0 g
s
.54137 .73585 m .54371 .73604 L p .54143 .73906 L .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .54137 .73585 L .54143 .73906 L .707 .577 .707 r
F
.52032 .70962 m .52385 .65243 L .54776 .65139 L p F P
0 g
s
.54776 .65139 m .54423 .70858 L .52032 .70962 L p .707 .577 .707 r
F P
0 g
s
.54371 .73604 m .53991 .77431 L .51624 .7724 L p .707 .577 .707 r
F P
0 g
s
.53905 .79661 m .53694 .81573 L .51336 .81294 L p .707 .577 .707 r
F P
0 g
s
.51336 .81294 m .51547 .79383 L .53905 .79661 L p .707 .577 .707 r
F P
0 g
s
.51908 .8096 m .53749 .51285 L p .50627 .29091 L .707 .577 .707 r
F P
0 g
s
.53749 .51285 m .55111 .29315 L .53364 .29228 L p .707 .577 .707 r
F P
0 g
s
.53364 .29228 m .50627 .29091 L p .53749 .51285 L .707 .577 .707 r
F P
0 g
s
.50627 .29091 m .47424 .80736 L .51908 .8096 L p .707 .577 .707 r
F P
0 g
s
.69721 .75252 m .6934 .79079 L .68051 .7889 L p .707 .577 .707 r
F P
0 g
s
.68051 .7889 m .68431 .75063 L .69721 .75252 L p .707 .577 .707 r
F P
0 g
s
.54423 .70858 m .54776 .65139 L .57703 .65168 L p .707 .577 .707 r
F P
0 g
s
.57703 .65168 m .5735 .70887 L .54423 .70858 L p .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .54371 .73604 L .55393 .73696 L p .707 .577 .707 r
F P
0 g
s
.55393 .73696 m .57279 .73866 L p .54676 .76688 L .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .55393 .73696 L .54676 .76688 L .707 .577 .707 r
F
.5735 .70887 m .57703 .65168 L .60879 .65325 L p F P
0 g
s
.57279 .73866 m .56899 .77693 L .53991 .77431 L p .707 .577 .707 r
F P
0 g
s
.60879 .65325 m .60526 .71044 L .5735 .70887 L p .707 .577 .707 r
F P
0 g
s
.56806 .79993 m .56594 .81905 L .5404 .81612 L p .707 .577 .707 r
F P
0 g
s
.5404 .81612 m .53694 .81573 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.54114 .81359 m .56806 .79993 L .5404 .81612 L .707 .577 .707 r
F
.53694 .81573 m .53905 .79661 L .54591 .7974 L p F P
0 g
s
.54591 .7974 m .56806 .79993 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.53694 .81573 m .54591 .7974 L .54114 .81359 L .707 .577 .707 r
F
.56877 .67508 m .56526 .73162 L p .59336 .57251 L F P
0 g
s
.56526 .73162 m .5604 .81003 L p .57665 .69291 L .707 .577 .707 r
F P
0 g
s
.59336 .57251 m .56526 .73162 L .57665 .69291 L .707 .577 .707 r
F
.56899 .77693 m .57279 .73866 L .5805 .73941 L p F P
0 g
s
.5805 .73941 m .60443 .74173 L p .57697 .769 L .707 .577 .707 r
F P
0 g
s
.56899 .77693 m .5805 .73941 L .57697 .769 L .707 .577 .707 r
F
.63994 .65596 m .63641 .71315 L .60526 .71044 L p F P
0 g
s
.60526 .71044 m .60879 .65325 L .63994 .65596 L p .707 .577 .707 r
F P
0 g
s
.63554 .74496 m .63173 .78323 L .60063 .78 L p .707 .577 .707 r
F P
0 g
s
.60063 .78 m .60443 .74173 L .63554 .74496 L p .707 .577 .707 r
F P
0 g
s
.60443 .74173 m .60063 .78 L .56899 .77693 L p .707 .577 .707 r
F P
0 g
s
.59754 .82257 m .59965 .80345 L .63074 .80683 L p .707 .577 .707 r
F P
0 g
s
.59965 .80345 m .59754 .82257 L .57266 .81979 L p .707 .577 .707 r
F P
0 g
s
.57266 .81979 m .56594 .81905 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.57322 .81568 m .59965 .80345 L .57266 .81979 L .707 .577 .707 r
F
.56594 .81905 m .56806 .79993 L .57526 .80073 L p F P
0 g
s
.57526 .80073 m .59965 .80345 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.56594 .81905 m .57526 .80073 L .57322 .81568 L .707 .577 .707 r
F
.61785 .42651 m .61074 .54113 L p .62483 .36803 L F P
0 g
s
.61074 .54113 m .59415 .80861 L p .61489 .51076 L .707 .577 .707 r
F P
0 g
s
.62483 .36803 m .61074 .54113 L .61489 .51076 L .707 .577 .707 r
F
.59415 .80861 m .61703 .80546 L p .62339 .44854 L F P
0 g
s
.62339 .44854 m .62483 .36803 L .61489 .51076 L .707 .577 .707 r
F
.62339 .44854 m .61489 .51076 L .59415 .80861 L F
.62618 .29216 m .61785 .42651 L p .62483 .36803 L F P
0 g
s
.5604 .81003 m .59415 .80861 L p .59357 .63541 L .707 .577 .707 r
F P
0 g
s
.59357 .63541 m .59336 .57251 L .57665 .69291 L .707 .577 .707 r
F
.59357 .63541 m .57665 .69291 L .5604 .81003 L F
.59243 .29358 m .56877 .67508 L p .59336 .57251 L F P
0 g
s
.55111 .29315 m .51908 .8096 L .5604 .81003 L p .707 .577 .707 r
F P
0 g
s
.5604 .81003 m .59243 .29358 L .55111 .29315 L p .707 .577 .707 r
F P
0 g
s
.24667 .74633 m .25048 .70806 L .21937 .70483 L p .707 .577 .707 r
F P
0 g
s
.25048 .70806 m .24667 .74633 L .27832 .7494 L p .707 .577 .707 r
F P
0 g
s
.27832 .7494 m .28212 .71114 L .25048 .70806 L p .707 .577 .707 r
F P
0 g
s
.21937 .70483 m .21557 .7431 L .24667 .74633 L p .707 .577 .707 r
F P
0 g
s
.69255 .81309 m .69043 .8322 L .67746 .83102 L p .707 .577 .707 r
F P
0 g
s
.67746 .83102 m .67958 .8119 L .69255 .81309 L p .707 .577 .707 r
F P
0 g
s
.19459 .63337 m .19106 .69056 L .21854 .69415 L p .707 .577 .707 r
F P
0 g
s
.28212 .71114 m .27832 .7494 L .30739 .75202 L p .707 .577 .707 r
F P
0 g
s
.30739 .75202 m .3112 .71375 L .28212 .71114 L p .707 .577 .707 r
F P
0 g
s
.31425 .64152 m .31072 .69871 L .33463 .69768 L p .707 .577 .707 r
F P
0 g
s
.33463 .69768 m .33815 .64049 L .31425 .64152 L p .707 .577 .707 r
F P
0 g
s
.43027 .80353 m .4623 .28708 L .4235 .28203 L p .707 .577 .707 r
F P
0 g
s
.4623 .28708 m .43027 .80353 L .47424 .80736 L p .707 .577 .707 r
F P
0 g
s
.21524 .7604 m .21312 .77951 L .24421 .78289 L p .707 .577 .707 r
F P
0 g
s
.24421 .78289 m .24633 .76378 L .21524 .7604 L p .707 .577 .707 r
F P
0 g
s
.24633 .76378 m .24421 .78289 L .27581 .78641 L p .707 .577 .707 r
F P
0 g
s
.27581 .78641 m .27792 .7673 L .24633 .76378 L p .707 .577 .707 r
F P
0 g
s
.21557 .7431 m .21937 .70483 L .19185 .70177 L p .707 .577 .707 r
F P
0 g
s
.19185 .70177 m .18804 .74004 L .21557 .7431 L p .707 .577 .707 r
F P
0 g
s
.27792 .7673 m .27581 .78641 L .30481 .78973 L p .707 .577 .707 r
F P
0 g
s
.30481 .78973 m .30693 .77062 L .27792 .7673 L p .707 .577 .707 r
F P
0 g
s
.19106 .69056 m .19459 .63337 L .17346 .62927 L p .707 .577 .707 r
F P
0 g
s
.1877 .75748 m .18558 .7766 L .21312 .77951 L p .707 .577 .707 r
F P
0 g
s
.21312 .77951 m .21524 .7604 L .1877 .75748 L p .707 .577 .707 r
F P
0 g
s
.68855 .66365 m .68502 .72084 L .66389 .71673 L p .707 .577 .707 r
F P
0 g
s
.66389 .71673 m .66742 .65954 L .68855 .66365 L p .707 .577 .707 r
F P
0 g
s
.3112 .71375 m .30739 .75202 L .33107 .75393 L p .707 .577 .707 r
F P
0 g
s
.33107 .75393 m .33487 .71566 L .3112 .71375 L p .707 .577 .707 r
F P
0 g
s
.17346 .62927 m .16993 .68646 L .19106 .69056 L p .707 .577 .707 r
F P
0 g
s
.59415 .80861 m .62618 .29216 L .59243 .29358 L p .707 .577 .707 r
F P
0 g
s
.30693 .77062 m .30481 .78973 L .32839 .79252 L p .707 .577 .707 r
F P
0 g
s
.32839 .79252 m .33051 .7734 L .30693 .77062 L p .707 .577 .707 r
F P
0 g
s
.18804 .74004 m .19185 .70177 L .1706 .69917 L p .707 .577 .707 r
F P
0 g
s
.1706 .69917 m .16679 .73743 L .18804 .74004 L p .707 .577 .707 r
F P
0 g
s
.33815 .64049 m .33463 .69768 L .35084 .69542 L p .707 .577 .707 r
F P
0 g
s
.35084 .69542 m .35436 .63823 L .33815 .64049 L p .707 .577 .707 r
F P
0 g
s
.68431 .75063 m .68051 .7889 L .65926 .7863 L p .707 .577 .707 r
F P
0 g
s
.65926 .7863 m .66306 .74803 L .68431 .75063 L p .707 .577 .707 r
F P
0 g
s
.39147 .79848 m .4235 .28203 L .39367 .27625 L p .707 .577 .707 r
F P
0 g
s
.4235 .28203 m .39147 .79848 L .43027 .80353 L p .707 .577 .707 r
F P
0 g
s
.1664 .75533 m .16429 .77445 L .18558 .7766 L p .707 .577 .707 r
F P
0 g
s
.18558 .7766 m .1877 .75748 L .1664 .75533 L p .707 .577 .707 r
F P
0 g
s
.67958 .8119 m .67746 .83102 L .65617 .82886 L p .707 .577 .707 r
F P
0 g
s
.65617 .82886 m .65828 .80974 L .67958 .8119 L p .707 .577 .707 r
F P
0 g
s
.16993 .68646 m .17346 .62927 L .16075 .62505 L p .707 .577 .707 r
F P
0 g
s
.66742 .65954 m .66389 .71673 L .63641 .71315 L p .707 .577 .707 r
F P
0 g
s
.63641 .71315 m .63994 .65596 L .66742 .65954 L p .707 .577 .707 r
F P
0 g
s
.33487 .71566 m .33107 .75393 L .34701 .75494 L p .707 .577 .707 r
F P
0 g
s
.34701 .75494 m .35081 .71667 L .33487 .71566 L p .707 .577 .707 r
F P
0 g
s
.16075 .62505 m .15722 .68224 L .16993 .68646 L p .707 .577 .707 r
F P
0 g
s
.33051 .7734 m .32839 .79252 L .34424 .7945 L p .707 .577 .707 r
F P
0 g
s
.34424 .7945 m .34635 .77539 L .33051 .7734 L p .707 .577 .707 r
F P
0 g
s
.16679 .73743 m .1706 .69917 L .1577 .69728 L p .707 .577 .707 r
F P
0 g
s
.1577 .69728 m .1539 .73555 L .16679 .73743 L p .707 .577 .707 r
F P
0 g
s
.61703 .80546 m .64906 .28901 L .62618 .29216 L p .707 .577 .707 r
F P
0 g
s
.66306 .74803 m .65926 .7863 L .63173 .78323 L p .707 .577 .707 r
F P
0 g
s
.63173 .78323 m .63554 .74496 L .66306 .74803 L p .707 .577 .707 r
F P
0 g
s
.15343 .75414 m .15132 .77326 L .16429 .77445 L p .707 .577 .707 r
F P
0 g
s
.16429 .77445 m .1664 .75533 L .15343 .75414 L p .707 .577 .707 r
F P
0 g
s
.35436 .63823 m .35084 .69542 L .35776 .69217 L p .707 .577 .707 r
F P
0 g
s
.35776 .69217 m .36129 .63498 L .35436 .63823 L p .707 .577 .707 r
F P
0 g
s
.65828 .80974 m .65617 .82886 L .62863 .82595 L p .707 .577 .707 r
F P
0 g
s
.62863 .82595 m .63074 .80683 L .65828 .80974 L p .707 .577 .707 r
F P
0 g
s
.36164 .7927 m .39367 .27625 L .37573 .27032 L p .707 .577 .707 r
F P
0 g
s
.39367 .27625 m .36164 .7927 L .39147 .79848 L p .707 .577 .707 r
F P
0 g
s
.15722 .68224 m .16075 .62505 L .15771 .62112 L p .707 .577 .707 r
F P
0 g
s
.35081 .71667 m .34701 .75494 L .35367 .75495 L p .707 .577 .707 r
F P
0 g
s
.35367 .75495 m .35747 .71669 L .35081 .71667 L p .707 .577 .707 r
F P
0 g
s
.63074 .80683 m .62863 .82595 L .59754 .82257 L p .707 .577 .707 r
F P
0 g
s
.34635 .77539 m .34424 .7945 L .35079 .79549 L p .707 .577 .707 r
F P
0 g
s
.15771 .62112 m .15418 .67831 L .15722 .68224 L p .707 .577 .707 r
F P
0 g
s
.35079 .79549 m .35291 .77638 L .34635 .77539 L p .707 .577 .707 r
F P
0 g
s
.1539 .73555 m .1577 .69728 L .15442 .69629 L p .707 .577 .707 r
F P
0 g
s
.15442 .69629 m .15062 .73456 L .1539 .73555 L p .707 .577 .707 r
F P
0 g
s
.15006 .75404 m .14795 .77315 L .15132 .77326 L p .707 .577 .707 r
F P
0 g
s
.15132 .77326 m .15343 .75414 L .15006 .75404 L p .707 .577 .707 r
F P
0 g
s
.36129 .63498 m .35776 .69217 L .35472 .68824 L p .707 .577 .707 r
F P
0 g
s
.35472 .68824 m .35825 .63105 L .36129 .63498 L p .707 .577 .707 r
F P
0 g
s
.64906 .28901 m .61703 .80546 L .6268 .80092 L p .707 .577 .707 r
F P
0 g
s
.6268 .80092 m .65883 .28447 L .64906 .28901 L p .707 .577 .707 r
F P
0 g
s
.15418 .67831 m .15771 .62112 L .16463 .61787 L p .707 .577 .707 r
F P
0 g
s
.35747 .71669 m .35367 .75495 L .35039 .75397 L p .707 .577 .707 r
F P
0 g
s
.35039 .75397 m .3542 .7157 L .35747 .71669 L p .707 .577 .707 r
F P
0 g
s
.35825 .63105 m .35472 .68824 L .34201 .68402 L p .707 .577 .707 r
F P
0 g
s
.34201 .68402 m .34554 .62683 L .35825 .63105 L p .707 .577 .707 r
F P
0 g
s
.3542 .7157 m .35039 .75397 L .34819 .75365 L p .707 .577 .707 r
F P
0 g
s
.34819 .75365 m .3375 .75208 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.34923 .72653 m .3542 .7157 L .34819 .75365 L .707 .577 .707 r
F
.37573 .27032 m .37143 .26481 L p .35509 .57235 L F P
0 g
s
.3375 .75208 m .3413 .71381 L .34966 .71504 L p .707 .577 .707 r
F P
0 g
s
.34966 .71504 m .3542 .7157 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.3375 .75208 m .34966 .71504 L .34923 .72653 L .707 .577 .707 r
F
.34954 .77627 m .34742 .79539 L .34588 .79525 L p F P
0 g
s
.34588 .79525 m .33446 .7942 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.34635 .78007 m .34954 .77627 L .34588 .79525 L .707 .577 .707 r
F
.33446 .7942 m .33657 .77508 L .34647 .77599 L p F P
0 g
s
.34647 .77599 m .34954 .77627 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.33446 .7942 m .34647 .77599 L .34635 .78007 L .707 .577 .707 r
F
.35943 .45836 m .35317 .55933 L p .35509 .57235 L F P
0 g
s
.35317 .55933 m .3394 .78126 L p .35114 .625 L .707 .577 .707 r
F P
0 g
s
.35509 .57235 m .35317 .55933 L .35114 .625 L .707 .577 .707 r
F
.3394 .78126 m .3437 .78677 L p .34953 .67702 L F P
0 g
s
.34953 .67702 m .35509 .57235 L .35114 .625 L .707 .577 .707 r
F
.34953 .67702 m .35114 .625 L .3394 .78126 L F
.37143 .26481 m .35943 .45836 L p .35509 .57235 L F P
0 g
s
.3437 .78677 m .35207 .65182 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35207 .65182 m .37573 .27032 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35291 .77638 m .35079 .79549 L .34742 .79539 L p .707 .577 .707 r
F P
0 g
s
.34742 .79539 m .34954 .77627 L .35291 .77638 L p .707 .577 .707 r
F P
0 g
s
.37573 .27032 m .3437 .78677 L .36164 .7927 L p .707 .577 .707 r
F P
0 g
s
.16463 .61787 m .1611 .67506 L .15418 .67831 L p .707 .577 .707 r
F P
0 g
s
.15062 .73456 m .15442 .69629 L .16108 .69631 L p .707 .577 .707 r
F P
0 g
s
.16108 .69631 m .15728 .73458 L .15062 .73456 L p .707 .577 .707 r
F P
0 g
s
.15662 .75503 m .1545 .77414 L .14795 .77315 L p .707 .577 .707 r
F P
0 g
s
.14795 .77315 m .15006 .75404 L .15662 .75503 L p .707 .577 .707 r
F P
0 g
s
.1611 .67506 m .16463 .61787 L .18084 .61561 L p .707 .577 .707 r
F P
0 g
s
.65883 .28447 m .6268 .80092 L .62251 .79541 L p .707 .577 .707 r
F P
0 g
s
.62251 .79541 m .65454 .27896 L .65883 .28447 L p .707 .577 .707 r
F P
0 g
s
.18084 .61561 m .17731 .6728 L .1611 .67506 L p .707 .577 .707 r
F P
0 g
s
.15728 .73458 m .16108 .69631 L .17703 .69732 L p .707 .577 .707 r
F P
0 g
s
.17703 .69732 m .17323 .73559 L .15728 .73458 L p .707 .577 .707 r
F P
0 g
s
.17246 .75701 m .17035 .77613 L .1545 .77414 L p .707 .577 .707 r
F P
0 g
s
.1545 .77414 m .15662 .75503 L .17246 .75701 L p .707 .577 .707 r
F P
0 g
s
.34554 .62683 m .34201 .68402 L .32088 .67992 L p .707 .577 .707 r
F P
0 g
s
.32088 .67992 m .32441 .62273 L .34554 .62683 L p .707 .577 .707 r
F P
0 g
s
.3394 .78126 m .37143 .26481 L .3812 .26026 L p .707 .577 .707 r
F P
0 g
s
.17731 .6728 m .18084 .61561 L .20475 .61458 L p .707 .577 .707 r
F P
0 g
s
.3413 .71381 m .3375 .75208 L .31625 .74948 L p .707 .577 .707 r
F P
0 g
s
.31625 .74948 m .32005 .71121 L .3413 .71381 L p .707 .577 .707 r
F P
0 g
s
.20475 .61458 m .20122 .67177 L .17731 .6728 L p .707 .577 .707 r
F P
0 g
s
.33657 .77508 m .33446 .7942 L .31316 .79205 L p .707 .577 .707 r
F P
0 g
s
.31316 .79205 m .31527 .77293 L .33657 .77508 L p .707 .577 .707 r
F P
0 g
s
.17323 .73559 m .17703 .69732 L .2007 .69923 L p .707 .577 .707 r
F P
0 g
s
.2007 .69923 m .1969 .7375 L .17323 .73559 L p .707 .577 .707 r
F P
0 g
s
.32441 .62273 m .32088 .67992 L .2934 .67634 L p .707 .577 .707 r
F P
0 g
s
.2934 .67634 m .29693 .61915 L .32441 .62273 L p .707 .577 .707 r
F P
0 g
s
.19604 .7598 m .19393 .77891 L .17035 .77613 L p .707 .577 .707 r
F P
0 g
s
.17035 .77613 m .17246 .75701 L .19604 .7598 L p .707 .577 .707 r
F P
0 g
s
.20122 .67177 m .20475 .61458 L .23402 .61486 L p .707 .577 .707 r
F P
0 g
s
.65454 .27896 m .62251 .79541 L .60457 .78948 L p .707 .577 .707 r
F P
0 g
s
.60457 .78948 m .6366 .27302 L .65454 .27896 L p .707 .577 .707 r
F P
0 g
s
.23402 .61486 m .23049 .67205 L .20122 .67177 L p .707 .577 .707 r
F P
0 g
s
.32005 .71121 m .31625 .74948 L .28872 .74642 L p .707 .577 .707 r
F P
0 g
s
.28872 .74642 m .29253 .70815 L .32005 .71121 L p .707 .577 .707 r
F P
0 g
s
.29693 .61915 m .2934 .67634 L .26225 .67362 L p .707 .577 .707 r
F P
0 g
s
.26225 .67362 m .26578 .61643 L .29693 .61915 L p .707 .577 .707 r
F P
0 g
s
.31527 .77293 m .31316 .79205 L .28562 .78913 L p .707 .577 .707 r
F P
0 g
s
.28562 .78913 m .28773 .77002 L .31527 .77293 L p .707 .577 .707 r
F P
0 g
s
.23049 .67205 m .23402 .61486 L .26578 .61643 L p .707 .577 .707 r
F P
0 g
s
.7299 .64631 m .73343 .58912 L .70228 .58641 L p .707 .577 .707 r
F P
0 g
s
.73343 .58912 m .7299 .64631 L .76166 .64788 L p .707 .577 .707 r
F P
0 g
s
.76166 .64788 m .76519 .59069 L .73343 .58912 L p .707 .577 .707 r
F P
0 g
s
.1969 .7375 m .2007 .69923 L .22978 .70185 L p .707 .577 .707 r
F P
0 g
s
.22978 .70185 m .22598 .74011 L .1969 .7375 L p .707 .577 .707 r
F P
0 g
s
.34918 .77672 m .3812 .26026 L .40408 .25712 L p .707 .577 .707 r
F P
0 g
s
.3812 .26026 m .34918 .77672 L .3394 .78126 L p .707 .577 .707 r
F P
0 g
s
.26578 .61643 m .26225 .67362 L .23049 .67205 L p .707 .577 .707 r
F P
0 g
s
.76519 .59069 m .76166 .64788 L .79093 .64816 L p .707 .577 .707 r
F P
0 g
s
.79093 .64816 m .79446 .59097 L .76519 .59069 L p .707 .577 .707 r
F P
0 g
s
.22505 .76311 m .22293 .78223 L .19393 .77891 L p .707 .577 .707 r
F P
0 g
s
.19393 .77891 m .19604 .7598 L .22505 .76311 L p .707 .577 .707 r
F P
0 g
s
.69875 .6436 m .70228 .58641 L .6748 .58282 L p .707 .577 .707 r
F P
0 g
s
.70228 .58641 m .69875 .6436 L .7299 .64631 L p .707 .577 .707 r
F P
0 g
s
.29253 .70815 m .28872 .74642 L .25762 .74319 L p .707 .577 .707 r
F P
0 g
s
.25762 .74319 m .26142 .70492 L .29253 .70815 L p .707 .577 .707 r
F P
0 g
s
.22598 .74011 m .22978 .70185 L .26142 .70492 L p .707 .577 .707 r
F P
0 g
s
.6748 .58282 m .67127 .64001 L .69875 .6436 L p .707 .577 .707 r
F P
0 g
s
.72689 .70202 m .73069 .66375 L .69958 .66052 L p .707 .577 .707 r
F P
0 g
s
.73069 .66375 m .72689 .70202 L .75853 .70509 L p .707 .577 .707 r
F P
0 g
s
.75853 .70509 m .76233 .66682 L .73069 .66375 L p .707 .577 .707 r
F P
0 g
s
.26142 .70492 m .25762 .74319 L .22598 .74011 L p .707 .577 .707 r
F P
0 g
s
.28773 .77002 m .28562 .78913 L .25453 .78575 L p .707 .577 .707 r
F P
0 g
s
.69958 .66052 m .69578 .69879 L .72689 .70202 L p .707 .577 .707 r
F P
0 g
s
.25453 .78575 m .25664 .76664 L .28773 .77002 L p .707 .577 .707 r
F P
0 g
s
.79446 .59097 m .79093 .64816 L .81484 .64713 L p .707 .577 .707 r
F P
0 g
s
.81484 .64713 m .81837 .58994 L .79446 .59097 L p .707 .577 .707 r
F P
0 g
s
.76233 .66682 m .75853 .70509 L .78761 .70771 L p .707 .577 .707 r
F P
0 g
s
.78761 .70771 m .79141 .66944 L .76233 .66682 L p .707 .577 .707 r
F P
0 g
s
.25664 .76664 m .25453 .78575 L .22293 .78223 L p .707 .577 .707 r
F P
0 g
s
.22293 .78223 m .22505 .76311 L .25664 .76664 L p .707 .577 .707 r
F P
0 g
s
.69578 .69879 m .69958 .66052 L .67206 .65746 L p .707 .577 .707 r
F P
0 g
s
.69545 .72486 m .69334 .74397 L .72443 .74736 L p .707 .577 .707 r
F P
0 g
s
.72443 .74736 m .72654 .72824 L .69545 .72486 L p .707 .577 .707 r
F P
0 g
s
.72654 .72824 m .72443 .74736 L .75602 .75088 L p .707 .577 .707 r
F P
0 g
s
.75602 .75088 m .75813 .73176 L .72654 .72824 L p .707 .577 .707 r
F P
0 g
s
.67206 .65746 m .66826 .69573 L .69578 .69879 L p .707 .577 .707 r
F P
0 g
s
.67127 .64001 m .6748 .58282 L .65367 .57872 L p .707 .577 .707 r
F P
0 g
s
.75813 .73176 m .75602 .75088 L .78503 .75419 L p .707 .577 .707 r
F P
0 g
s
.78503 .75419 m .78714 .73508 L .75813 .73176 L p .707 .577 .707 r
F P
0 g
s
.66791 .72195 m .6658 .74106 L .69334 .74397 L p .707 .577 .707 r
F P
0 g
s
.69334 .74397 m .69545 .72486 L .66791 .72195 L p .707 .577 .707 r
F P
0 g
s
.6366 .27302 m .60457 .78948 L .57474 .7837 L p .707 .577 .707 r
F P
0 g
s
.57474 .7837 m .60676 .26725 L .6366 .27302 L p .707 .577 .707 r
F P
0 g
s
.65367 .57872 m .65014 .63591 L .67127 .64001 L p .707 .577 .707 r
F P
0 g
s
.79141 .66944 m .78761 .70771 L .81128 .70962 L p .707 .577 .707 r
F P
0 g
s
.81128 .70962 m .81508 .67135 L .79141 .66944 L p .707 .577 .707 r
F P
0 g
s
.66826 .69573 m .67206 .65746 L .65081 .65485 L p .707 .577 .707 r
F P
0 g
s
.65081 .65485 m .64701 .69312 L .66826 .69573 L p .707 .577 .707 r
F P
0 g
s
.78714 .73508 m .78503 .75419 L .80861 .75698 L p .707 .577 .707 r
F P
0 g
s
.80861 .75698 m .81072 .73787 L .78714 .73508 L p .707 .577 .707 r
F P
0 g
s
.81837 .58994 m .81484 .64713 L .83105 .64487 L p .707 .577 .707 r
F P
0 g
s
.83105 .64487 m .83458 .58768 L .81837 .58994 L p .707 .577 .707 r
F P
0 g
s
.40408 .25712 m .37206 .77357 L .34918 .77672 L p .707 .577 .707 r
F P
0 g
s
.37206 .77357 m .40408 .25712 L .43784 .2557 L p .707 .577 .707 r
F P
0 g
s
.64661 .71979 m .6445 .73891 L .6658 .74106 L p .707 .577 .707 r
F P
0 g
s
.6658 .74106 m .66791 .72195 L .64661 .71979 L p .707 .577 .707 r
F P
0 g
s
.65014 .63591 m .65367 .57872 L .64096 .5745 L p .707 .577 .707 r
F P
0 g
s
.81508 .67135 m .81128 .70962 L .82723 .71063 L p .707 .577 .707 r
F P
0 g
s
.82723 .71063 m .83103 .67236 L .81508 .67135 L p .707 .577 .707 r
F P
0 g
s
.64096 .5745 m .63744 .63169 L .65014 .63591 L p .707 .577 .707 r
F P
0 g
s
.81072 .73787 m .80861 .75698 L .82445 .75897 L p .707 .577 .707 r
F P
0 g
s
.82445 .75897 m .82656 .73985 L .81072 .73787 L p .707 .577 .707 r
F P
0 g
s
.64701 .69312 m .65081 .65485 L .63791 .65297 L p .707 .577 .707 r
F P
0 g
s
.63791 .65297 m .63411 .69124 L .64701 .69312 L p .707 .577 .707 r
F P
0 g
s
.60676 .26725 m .57474 .7837 L .53594 .77865 L p .707 .577 .707 r
F P
0 g
s
.53594 .77865 m .56796 .2622 L .60676 .26725 L p .707 .577 .707 r
F P
0 g
s
.83458 .58768 m .83105 .64487 L .83797 .64162 L p .707 .577 .707 r
F P
0 g
s
.83797 .64162 m .8415 .58443 L .83458 .58768 L p .707 .577 .707 r
F P
0 g
s
.63364 .7186 m .63153 .73772 L .6445 .73891 L p .707 .577 .707 r
F P
0 g
s
.6445 .73891 m .64661 .71979 L .63364 .7186 L p .707 .577 .707 r
F P
0 g
s
.40581 .77215 m .43784 .2557 L .47915 .25613 L p .707 .577 .707 r
F P
0 g
s
.43784 .2557 m .40581 .77215 L .37206 .77357 L p .707 .577 .707 r
F P
0 g
s
.63744 .63169 m .64096 .5745 L .63792 .57057 L p .707 .577 .707 r
F P
0 g
s
.83103 .67236 m .82723 .71063 L .83389 .71064 L p .707 .577 .707 r
F P
0 g
s
.83389 .71064 m .83769 .67237 L .83103 .67236 L p .707 .577 .707 r
F P
0 g
s
.63792 .57057 m .63439 .62776 L .63744 .63169 L p .707 .577 .707 r
F P
0 g
s
.56796 .2622 m .53594 .77865 L .49196 .77482 L p .707 .577 .707 r
F P
0 g
s
.49196 .77482 m .52399 .25837 L .56796 .2622 L p .707 .577 .707 r
F P
0 g
s
.82656 .73985 m .82445 .75897 L .83101 .75996 L p .707 .577 .707 r
F P
0 g
s
.83101 .75996 m .83312 .74084 L .82656 .73985 L p .707 .577 .707 r
F P
0 g
s
.44712 .77258 m .47915 .25613 L .52399 .25837 L p .707 .577 .707 r
F P
0 g
s
.47915 .25613 m .44712 .77258 L .40581 .77215 L p .707 .577 .707 r
F P
0 g
s
.63411 .69124 m .63791 .65297 L .63464 .65198 L p .707 .577 .707 r
F P
0 g
s
.63464 .65198 m .63083 .69025 L .63411 .69124 L p .707 .577 .707 r
F P
0 g
s
.52399 .25837 m .49196 .77482 L .44712 .77258 L p .707 .577 .707 r
F P
0 g
s
.8415 .58443 m .83797 .64162 L .83493 .63769 L p .707 .577 .707 r
F P
0 g
s
.83493 .63769 m .83846 .5805 L .8415 .58443 L p .707 .577 .707 r
F P
0 g
s
.63027 .7185 m .62816 .73762 L .63153 .73772 L p .707 .577 .707 r
F P
0 g
s
.63153 .73772 m .63364 .7186 L .63027 .7185 L p .707 .577 .707 r
F P
0 g
s
.63439 .62776 m .63792 .57057 L .64485 .56732 L p .707 .577 .707 r
F P
0 g
s
.83769 .67237 m .83389 .71064 L .83061 .70966 L p .707 .577 .707 r
F P
0 g
s
.83061 .70966 m .83441 .67139 L .83769 .67237 L p .707 .577 .707 r
F P
0 g
s
.64485 .56732 m .64132 .62451 L .63439 .62776 L p .707 .577 .707 r
F P
0 g
s
.83312 .74084 m .83101 .75996 L .82764 .75985 L p .707 .577 .707 r
F P
0 g
s
.82764 .75985 m .82975 .74074 L .83312 .74084 L p .707 .577 .707 r
F P
0 g
s
.63083 .69025 m .63464 .65198 L .6413 .652 L p .707 .577 .707 r
F P
0 g
s
.6413 .652 m .63749 .69027 L .63083 .69025 L p .707 .577 .707 r
F P
0 g
s
.83846 .5805 m .83493 .63769 L .82223 .63347 L p .707 .577 .707 r
F P
0 g
s
.82223 .63347 m .82575 .57628 L .83846 .5805 L p .707 .577 .707 r
F P
0 g
s
.63683 .71949 m .63472 .7386 L .62816 .73762 L p .707 .577 .707 r
F P
0 g
s
.62816 .73762 m .63027 .7185 L .63683 .71949 L p .707 .577 .707 r
F P
0 g
s
.38689 .60949 m .39042 .5523 L .35927 .54959 L p .707 .577 .707 r
F P
0 g
s
.39042 .5523 m .38689 .60949 L .41865 .61106 L p .707 .577 .707 r
F P
0 g
s
.41865 .61106 m .42218 .55387 L .39042 .5523 L p .707 .577 .707 r
F P
0 g
s
.42218 .55387 m .41865 .61106 L .44792 .61135 L p .707 .577 .707 r
F P
0 g
s
.44792 .61135 m .45145 .55416 L .42218 .55387 L p .707 .577 .707 r
F P
0 g
s
.64132 .62451 m .64485 .56732 L .66105 .56506 L p .707 .577 .707 r
F P
0 g
s
.35574 .60678 m .35927 .54959 L .33179 .54601 L p .707 .577 .707 r
F P
0 g
s
.35927 .54959 m .35574 .60678 L .38689 .60949 L p .707 .577 .707 r
F P
0 g
s
.83441 .67139 m .83061 .70966 L .81771 .70777 L p .707 .577 .707 r
F P
0 g
s
.81771 .70777 m .82152 .6695 L .83441 .67139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66105 .56506 m .65753 .62225 L .64132 .62451 L p .707 .577 .707 r
F P
0 g
s
.33179 .54601 m .32826 .6032 L .35574 .60678 L p .707 .577 .707 r
F P
0 g
s
.38388 .6652 m .38768 .62694 L .35657 .62371 L p .707 .577 .707 r
F P
0 g
s
.38768 .62694 m .38388 .6652 L .41552 .66828 L p .707 .577 .707 r
F P
0 g
s
.41552 .66828 m .41932 .63001 L .38768 .62694 L p .707 .577 .707 r
F P
0 g
s
.35657 .62371 m .35277 .66198 L .38388 .6652 L p .707 .577 .707 r
F P
0 g
s
.45145 .55416 m .44792 .61135 L .47183 .61031 L p .707 .577 .707 r
F P
0 g
s
.47183 .61031 m .47536 .55312 L .45145 .55416 L p .707 .577 .707 r
F P
0 g
s
.41932 .63001 m .41552 .66828 L .4446 .6709 L p .707 .577 .707 r
F P
0 g
s
.4446 .6709 m .4484 .63263 L .41932 .63001 L p .707 .577 .707 r
F P
0 g
s
.82975 .74074 m .82764 .75985 L .81467 .75866 L p .707 .577 .707 r
F P
0 g
s
.81467 .75866 m .81678 .73955 L .82975 .74074 L p .707 .577 .707 r
F P
0 g
s
.63749 .69027 m .6413 .652 L .65724 .65301 L p .707 .577 .707 r
F P
0 g
s
.35277 .66198 m .35657 .62371 L .32905 .62064 L p .707 .577 .707 r
F P
0 g
s
.35244 .68804 m .35033 .70716 L .38142 .71054 L p .707 .577 .707 r
F P
0 g
s
.38142 .71054 m .38353 .69142 L .35244 .68804 L p .707 .577 .707 r
F P
0 g
s
.38353 .69142 m .38142 .71054 L .41301 .71406 L p .707 .577 .707 r
F P
0 g
s
.65724 .65301 m .65344 .69128 L .63749 .69027 L p .707 .577 .707 r
F P
0 g
s
.41301 .71406 m .41512 .69495 L .38353 .69142 L p .707 .577 .707 r
F P
0 g
s
.32905 .62064 m .32525 .65891 L .35277 .66198 L p .707 .577 .707 r
F P
0 g
s
.32826 .6032 m .33179 .54601 L .31066 .5419 L p .707 .577 .707 r
F P
0 g
s
.41512 .69495 m .41301 .71406 L .44202 .71738 L p .707 .577 .707 r
F P
0 g
s
.44202 .71738 m .44413 .69826 L .41512 .69495 L p .707 .577 .707 r
F P
0 g
s
.82575 .57628 m .82223 .63347 L .8011 .62937 L p .707 .577 .707 r
F P
0 g
s
.8011 .62937 m .80462 .57218 L .82575 .57628 L p .707 .577 .707 r
F P
0 g
s
.65268 .72147 m .65056 .74059 L .63472 .7386 L p .707 .577 .707 r
F P
0 g
s
.63472 .7386 m .63683 .71949 L .65268 .72147 L p .707 .577 .707 r
F P
0 g
s
.3249 .68513 m .32279 .70425 L .35033 .70716 L p .707 .577 .707 r
F P
0 g
s
.35033 .70716 m .35244 .68804 L .3249 .68513 L p .707 .577 .707 r
F P
0 g
s
.31066 .5419 m .30713 .59909 L .32826 .6032 L p .707 .577 .707 r
F P
0 g
s
.4484 .63263 m .4446 .6709 L .46827 .6728 L p .707 .577 .707 r
F P
0 g
s
.46827 .6728 m .47207 .63454 L .4484 .63263 L p .707 .577 .707 r
F P
0 g
s
.65753 .62225 m .66105 .56506 L .68496 .56403 L p .707 .577 .707 r
F P
0 g
s
.32525 .65891 m .32905 .62064 L .3078 .61804 L p .707 .577 .707 r
F P
0 g
s
.3078 .61804 m .304 .65631 L .32525 .65891 L p .707 .577 .707 r
F P
0 g
s
.44413 .69826 m .44202 .71738 L .4656 .72017 L p .707 .577 .707 r
F P
0 g
s
.4656 .72017 m .46771 .70105 L .44413 .69826 L p .707 .577 .707 r
F P
0 g
s
.47536 .55312 m .47183 .61031 L .48804 .60806 L p .707 .577 .707 r
F P
0 g
s
.48804 .60806 m .49157 .55087 L .47536 .55312 L p .707 .577 .707 r
F P
0 g
s
.82152 .6695 m .81771 .70777 L .79646 .70517 L p .707 .577 .707 r
F P
0 g
s
.79646 .70517 m .80027 .6669 L .82152 .6695 L p .707 .577 .707 r
F P
0 g
s
.68496 .56403 m .68144 .62122 L .65753 .62225 L p .707 .577 .707 r
F P
0 g
s
.3036 .68298 m .30149 .70209 L .32279 .70425 L p .707 .577 .707 r
F P
0 g
s
.32279 .70425 m .3249 .68513 L .3036 .68298 L p .707 .577 .707 r
F P
0 g
s
.30713 .59909 m .31066 .5419 L .29795 .53768 L p .707 .577 .707 r
F P
0 g
s
.81678 .73955 m .81467 .75866 L .79337 .75651 L p .707 .577 .707 r
F P
0 g
s
.79337 .75651 m .79549 .73739 L .81678 .73955 L p .707 .577 .707 r
F P
0 g
s
.65344 .69128 m .65724 .65301 L .68091 .65492 L p .707 .577 .707 r
F P
0 g
s
.80462 .57218 m .8011 .62937 L .77361 .62579 L p .707 .577 .707 r
F P
0 g
s
.77361 .62579 m .77714 .5686 L .80462 .57218 L p .707 .577 .707 r
F P
0 g
s
.68091 .65492 m .67711 .69318 L .65344 .69128 L p .707 .577 .707 r
F P
0 g
s
.47207 .63454 m .46827 .6728 L .48422 .67381 L p .707 .577 .707 r
F P
0 g
s
.48422 .67381 m .48802 .63555 L .47207 .63454 L p .707 .577 .707 r
F P
0 g
s
.29795 .53768 m .29442 .59487 L .30713 .59909 L p .707 .577 .707 r
F P
0 g
s
.68144 .62122 m .68496 .56403 L .71423 .56431 L p .707 .577 .707 r
F P
0 g
s
.67625 .72426 m .67414 .74338 L .65056 .74059 L p .707 .577 .707 r
F P
0 g
s
.65056 .74059 m .65268 .72147 L .67625 .72426 L p .707 .577 .707 r
F P
0 g
s
.46771 .70105 m .4656 .72017 L .48144 .72215 L p .707 .577 .707 r
F P
0 g
s
.48144 .72215 m .48355 .70304 L .46771 .70105 L p .707 .577 .707 r
F P
0 g
s
.304 .65631 m .3078 .61804 L .2949 .61615 L p .707 .577 .707 r
F P
0 g
s
.2949 .61615 m .2911 .65442 L .304 .65631 L p .707 .577 .707 r
F P
0 g
s
.71423 .56431 m .7107 .6215 L .68144 .62122 L p .707 .577 .707 r
F P
0 g
s
.80027 .6669 m .79646 .70517 L .76894 .7021 L p .707 .577 .707 r
F P
0 g
s
.76894 .7021 m .77274 .66384 L .80027 .6669 L p .707 .577 .707 r
F P
0 g
s
.77714 .5686 m .77361 .62579 L .74247 .62307 L p .707 .577 .707 r
F P
0 g
s
.74247 .62307 m .74599 .56588 L .77714 .5686 L p .707 .577 .707 r
F P
0 g
s
.49157 .55087 m .48804 .60806 L .49496 .60481 L p .707 .577 .707 r
F P
0 g
s
.49496 .60481 m .49849 .54762 L .49157 .55087 L p .707 .577 .707 r
F P
0 g
s
.29063 .68179 m .28852 .7009 L .30149 .70209 L p .707 .577 .707 r
F P
0 g
s
.30149 .70209 m .3036 .68298 L .29063 .68179 L p .707 .577 .707 r
F P
0 g
s
.7107 .6215 m .71423 .56431 L .74599 .56588 L p .707 .577 .707 r
F P
0 g
s
.67711 .69318 m .68091 .65492 L .70999 .65753 L p .707 .577 .707 r
F P
0 g
s
.70999 .65753 m .70619 .6958 L .67711 .69318 L p .707 .577 .707 r
F P
0 g
s
.79549 .73739 m .79337 .75651 L .76583 .7536 L p .707 .577 .707 r
F P
0 g
s
.76583 .7536 m .76794 .73448 L .79549 .73739 L p .707 .577 .707 r
F P
0 g
s
.74599 .56588 m .74247 .62307 L .7107 .6215 L p .707 .577 .707 r
F P
0 g
s
.29442 .59487 m .29795 .53768 L .29491 .53375 L p .707 .577 .707 r
F P
0 g
s
.70526 .72758 m .70315 .74669 L .67414 .74338 L p .707 .577 .707 r
F P
0 g
s
.67414 .74338 m .67625 .72426 L .70526 .72758 L p .707 .577 .707 r
F P
0 g
s
.77274 .66384 m .76894 .7021 L .73783 .69888 L p .707 .577 .707 r
F P
0 g
s
.73783 .69888 m .74163 .66061 L .77274 .66384 L p .707 .577 .707 r
F P
0 g
s
.48802 .63555 m .48422 .67381 L .49088 .67383 L p .707 .577 .707 r
F P
0 g
s
.49088 .67383 m .49468 .63556 L .48802 .63555 L p .707 .577 .707 r
F P
0 g
s
.29491 .53375 m .29138 .59094 L .29442 .59487 L p .707 .577 .707 r
F P
0 g
s
.70619 .6958 m .70999 .65753 L .74163 .66061 L p .707 .577 .707 r
F P
0 g
s
.74163 .66061 m .73783 .69888 L .70619 .6958 L p .707 .577 .707 r
F P
0 g
s
.76794 .73448 m .76583 .7536 L .73474 .75022 L p .707 .577 .707 r
F P
0 g
s
.73474 .75022 m .73686 .7311 L .76794 .73448 L p .707 .577 .707 r
F P
0 g
s
.48355 .70304 m .48144 .72215 L .488 .72314 L p .707 .577 .707 r
F P
0 g
s
.488 .72314 m .49011 .70403 L .48355 .70304 L p .707 .577 .707 r
F P
0 g
s
.2911 .65442 m .2949 .61615 L .29163 .61517 L p .707 .577 .707 r
F P
0 g
s
.73686 .7311 m .73474 .75022 L .70315 .74669 L p .707 .577 .707 r
F P
0 g
s
.70315 .74669 m .70526 .72758 L .73686 .7311 L p .707 .577 .707 r
F P
0 g
s
.29163 .61517 m .28782 .65344 L .2911 .65442 L p .707 .577 .707 r
F P
0 g
s
.49849 .54762 m .49496 .60481 L .49192 .60088 L p .707 .577 .707 r
F P
0 g
s
.49192 .60088 m .49545 .54369 L .49849 .54762 L p .707 .577 .707 r
F P
0 g
s
.28726 .68168 m .28515 .7008 L .28852 .7009 L p .707 .577 .707 r
F P
0 g
s
.28852 .7009 m .29063 .68179 L .28726 .68168 L p .707 .577 .707 r
F P
0 g
s
.29138 .59094 m .29491 .53375 L .30183 .5305 L p .707 .577 .707 r
F P
0 g
s
.49468 .63556 m .49088 .67383 L .4876 .67284 L p .707 .577 .707 r
F P
0 g
s
.4876 .67284 m .4914 .63457 L .49468 .63556 L p .707 .577 .707 r
F P
0 g
s
.30183 .5305 m .29831 .58769 L .29138 .59094 L p .707 .577 .707 r
F P
0 g
s
.49011 .70403 m .488 .72314 L .48463 .72304 L p .707 .577 .707 r
F P
0 g
s
.48463 .72304 m .48674 .70392 L .49011 .70403 L p .707 .577 .707 r
F P
0 g
s
.28782 .65344 m .29163 .61517 L .29829 .61518 L p .707 .577 .707 r
F P
0 g
s
.29829 .61518 m .29448 .65345 L .28782 .65344 L p .707 .577 .707 r
F P
0 g
s
.49545 .54369 m .49192 .60088 L .47921 .59666 L p .707 .577 .707 r
F P
0 g
s
.47921 .59666 m .48274 .53947 L .49545 .54369 L p .707 .577 .707 r
F P
0 g
s
.29382 .68267 m .29171 .70179 L .28515 .7008 L p .707 .577 .707 r
F P
0 g
s
.28515 .7008 m .28726 .68168 L .29382 .68267 L p .707 .577 .707 r
F P
0 g
s
.29831 .58769 m .30183 .5305 L .31804 .52825 L p .707 .577 .707 r
F P
0 g
s
.4914 .63457 m .4876 .67284 L .4747 .67096 L p .707 .577 .707 r
F P
0 g
s
.4747 .67096 m .4785 .63269 L .4914 .63457 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31804 .52825 m .31452 .58544 L .29831 .58769 L p .707 .577 .707 r
F P
0 g
s
.48674 .70392 m .48463 .72304 L .47166 .72185 L p .707 .577 .707 r
F P
0 g
s
.47166 .72185 m .47377 .70273 L .48674 .70392 L p .707 .577 .707 r
F P
0 g
s
.29448 .65345 m .29829 .61518 L .31423 .61619 L p .707 .577 .707 r
F P
0 g
s
.31423 .61619 m .31043 .65446 L .29448 .65345 L p .707 .577 .707 r
F P
0 g
s
.48274 .53947 m .47921 .59666 L .45809 .59255 L p .707 .577 .707 r
F P
0 g
s
.45809 .59255 m .46161 .53536 L .48274 .53947 L p .707 .577 .707 r
F P
0 g
s
.30966 .68466 m .30755 .70377 L .29171 .70179 L p .707 .577 .707 r
F P
0 g
s
.29171 .70179 m .29382 .68267 L .30966 .68466 L p .707 .577 .707 r
F P
0 g
s
.31452 .58544 m .31804 .52825 L .34195 .52721 L p .707 .577 .707 r
F P
0 g
s
.4785 .63269 m .4747 .67096 L .45345 .66835 L p .707 .577 .707 r
F P
0 g
s
.45345 .66835 m .45725 .63009 L .4785 .63269 L p .707 .577 .707 r
F P
0 g
s
.34195 .52721 m .33842 .5844 L .31452 .58544 L p .707 .577 .707 r
F P
0 g
s
.47377 .70273 m .47166 .72185 L .45036 .71969 L p .707 .577 .707 r
F P
0 g
s
.45036 .71969 m .45248 .70058 L .47377 .70273 L p .707 .577 .707 r
F P
0 g
s
.31043 .65446 m .31423 .61619 L .3379 .6181 L p .707 .577 .707 r
F P
0 g
s
.46161 .53536 m .45809 .59255 L .4306 .58897 L p .707 .577 .707 r
F P
0 g
s
.4306 .58897 m .43413 .53178 L .46161 .53536 L p .707 .577 .707 r
F P
0 g
s
.3379 .6181 m .3341 .65637 L .31043 .65446 L p .707 .577 .707 r
F P
0 g
s
.33842 .5844 m .34195 .52721 L .37122 .5275 L p .707 .577 .707 r
F P
0 g
s
.33324 .68745 m .33113 .70656 L .30755 .70377 L p .707 .577 .707 r
F P
0 g
s
.30755 .70377 m .30966 .68466 L .33324 .68745 L p .707 .577 .707 r
F P
0 g
s
.37122 .5275 m .36769 .58469 L .33842 .5844 L p .707 .577 .707 r
F P
0 g
s
.45725 .63009 m .45345 .66835 L .42593 .66529 L p .707 .577 .707 r
F P
0 g
s
.42593 .66529 m .42973 .62702 L .45725 .63009 L p .707 .577 .707 r
F P
0 g
s
.43413 .53178 m .4306 .58897 L .39945 .58626 L p .707 .577 .707 r
F P
0 g
s
.39945 .58626 m .40298 .52907 L .43413 .53178 L p .707 .577 .707 r
F P
0 g
s
.36769 .58469 m .37122 .5275 L .40298 .52907 L p .707 .577 .707 r
F P
0 g
s
.3341 .65637 m .3379 .6181 L .36698 .62072 L p .707 .577 .707 r
F P
0 g
s
.36698 .62072 m .36318 .65899 L .3341 .65637 L p .707 .577 .707 r
F P
0 g
s
.45248 .70058 m .45036 .71969 L .42282 .71678 L p .707 .577 .707 r
F P
0 g
s
.42282 .71678 m .42493 .69767 L .45248 .70058 L p .707 .577 .707 r
F P
0 g
s
.40298 .52907 m .39945 .58626 L .36769 .58469 L p .707 .577 .707 r
F P
0 g
s
.36225 .69076 m .36014 .70988 L .33113 .70656 L p .707 .577 .707 r
F P
0 g
s
.33113 .70656 m .33324 .68745 L .36225 .69076 L p .707 .577 .707 r
F P
0 g
s
.42973 .62702 m .42593 .66529 L .39482 .66206 L p .707 .577 .707 r
F P
0 g
s
.39482 .66206 m .39862 .62379 L .42973 .62702 L p .707 .577 .707 r
F P
0 g
s
.36318 .65899 m .36698 .62072 L .39862 .62379 L p .707 .577 .707 r
F P
0 g
s
.39862 .62379 m .39482 .66206 L .36318 .65899 L p .707 .577 .707 r
F P
0 g
s
.42493 .69767 m .42282 .71678 L .39173 .7134 L p .707 .577 .707 r
F P
0 g
s
.39173 .7134 m .39384 .69428 L .42493 .69767 L p .707 .577 .707 r
F P
0 g
s
.39384 .69428 m .39173 .7134 L .36014 .70988 L p .707 .577 .707 r
F P
0 g
s
.36014 .70988 m .36225 .69076 L .39384 .69428 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00N7oo5P00Sgoo001`Ool80004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH=0022Ool006]oo`D0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEPT007Uoo`00JGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Lgoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF
1P00KGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEPH006Moo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEP00008006Aoo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80069oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065o
o`00JGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HGoo
001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00HGoo001XOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HWoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIo
o`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1ROol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001NOol70002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Eoo`T000=JEP04001JEUYFFUHC000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`<000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo7P00AGoo
001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP003eoo`00DWoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPL003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF008000eJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0
039oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5
00001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo1@000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool005Yoo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
001QOol80004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP040000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool006=oo`04001JEUYF0002FUHP0005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0002eoo`00=goo40002goo1@0037oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02ioo`T000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`03001JEP00009JEPd0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000^Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP04001JEUYFFUH90009FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF001JEUYF5P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EQ0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000AJEP04
001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH<0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000`003EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000017oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000Moo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000aooa80
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0001iooaH003=oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP/005moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF4@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@0
05YFFUIJEQ0004moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@00AWoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH90004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0002FUH01000FUIJEUYF2@000eYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000gOol0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEQH0
009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP08000_Ool002]oo`03001JEP00024000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP/00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP@000=JEPL000=JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH30003FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUHC0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo000^Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH200000eYF001JEP03FUH00`00FUIJEP0>00000eYF001JEP02FUH500000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000cOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF4@0000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF2`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool003Yoo`P000AJEP03001JEUYF00MJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUHG0004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[OolB0005
OolA0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP02FUH90003FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@002goo10000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPh0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000MJ
EP03001JEUYF00=JEP04001JEUYFFUH20002Ool90003FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH90006Ool=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P002goo20000eYF1`000eYF00@005YFFUIJEP8002mo
o`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200027oo300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000COolC000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH01000FUIJ
EUYF300015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000QOol5000_Ool002Yoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00
FUIJEP04FUH;0004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH70003FUH01000FUIJEUYF0P002Goo0`00BGoo
000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH00UYF2P000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001P001EYF10000eYF0P0027oo1@00B7oo000ZOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0800000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00
FUH005YF001JEPh00003FUH0000000Qoo`D004Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00AJEP04001JEUYFFUH90003Ool50018Ool002Yoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004Moo`00:Woo1@000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?goo000[OolA
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF2P00=Goo000bOol7
0003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000020000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH02000<7oo000iOol90003FUH90004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040004Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02000`Ool0049oo`T000=JEPP000=JEP03001JEUYF00=JEP05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF1`0017oo2@0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo001;OolF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH0
20001Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80031oo`00:Woo2000
:Goo1P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000=Ool80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo
000ZOol00`00FUH00002FUH:000WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000MJEP03001JEUYF00=JEP04001JEUYFFUH2000EOol<0002FUH2000`Ool002Yoo`03
001JEP0000AJEP03001JEUYF010001aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP80025oo`@0031oo`00:Woo0P001EYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@004goo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00EGoo000ZOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30000UYF00@005YFFUIJEQh000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0005Eoo`00:goo2@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@000UYF100025YF00<005YFFUH025YF00<0
05YFFUH025YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol003Aoo`L000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00EWoo000kOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH70006FUH00`00FUIJEP02FUH00`00FUH000040004FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00EWoo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000035YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF
00<005YFFUH00UYF00@005YF000000=JEPL000=JEP04001JEUYFFUH2001FOol004eoo`P000AJEP03
001JEUYF00=JEP03001JEUYF00<000YJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEPD000=JEP04001JEP00OolC001FOol005Eoo``00004FUH0
0000Ool40006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP003goo1@00EWoo001QOol30005Ool40002
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH200000eYF001oo`1YOol006eoo`P000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00001ZOol007Eoo`/0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD006Uoo`00
P7oo3@001UYF00<005YFFUH02EYF00<005YFFUH00UYF6000HGoo002;OolI0006FUH00`00FUIJEP06
FUH01000FUIJEUYF3@00FGoo002?Ool90008FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00002001GOol009Uoo`P000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF008005Moo`00XGoo3@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Moo`00Zgoo2`0015YF00<005YFFUH00eYF00@005YFFUIJEP80
05Moo`00]7oo2@000eYF00@005YFFUIJEP8005Moo`00_Goo2@00Egoo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5927 .73367 m .59623 .67648 L .56508 .67377 L p .707 .577 .707 r
F P
0 g
s
.59623 .67648 m .5927 .73367 L .62446 .73524 L p .707 .577 .707 r
F P
0 g
s
.62446 .73524 m .62799 .67805 L .59623 .67648 L p .707 .577 .707 r
F P
0 g
s
.62799 .67805 m .62446 .73524 L .65373 .73553 L p .707 .577 .707 r
F P
0 g
s
.65373 .73553 m .65725 .67834 L .62799 .67805 L p .707 .577 .707 r
F P
0 g
s
.56155 .73096 m .56508 .67377 L .53759 .67019 L p .707 .577 .707 r
F P
0 g
s
.56508 .67377 m .56155 .73096 L .5927 .73367 L p .707 .577 .707 r
F P
0 g
s
.58968 .78315 m .59348 .74488 L .56238 .74165 L p .707 .577 .707 r
F P
0 g
s
.59348 .74488 m .58968 .78315 L .62132 .78622 L p .707 .577 .707 r
F P
0 g
s
.62132 .78622 m .62513 .74795 L .59348 .74488 L p .707 .577 .707 r
F P
0 g
s
.56238 .74165 m .55858 .77992 L .58968 .78315 L p .707 .577 .707 r
F P
0 g
s
.53759 .67019 m .53407 .72738 L .56155 .73096 L p .707 .577 .707 r
F P
0 g
s
.62513 .74795 m .62132 .78622 L .6504 .78884 L p .707 .577 .707 r
F P
0 g
s
.6504 .78884 m .65421 .75057 L .62513 .74795 L p .707 .577 .707 r
F P
0 g
s
.65725 .67834 m .65373 .73553 L .67764 .73449 L p .707 .577 .707 r
F P
0 g
s
.67764 .73449 m .68116 .6773 L .65725 .67834 L p .707 .577 .707 r
F P
0 g
s
.55825 .79721 m .55613 .81633 L .58722 .81971 L p .707 .577 .707 r
F P
0 g
s
.58722 .81971 m .58934 .80059 L .55825 .79721 L p .707 .577 .707 r
F P
0 g
s
.58934 .80059 m .58722 .81971 L .61882 .82323 L p .707 .577 .707 r
F P
0 g
s
.61882 .82323 m .62093 .80411 L .58934 .80059 L p .707 .577 .707 r
F P
0 g
s
.55858 .77992 m .56238 .74165 L .53485 .73858 L p .707 .577 .707 r
F P
0 g
s
.53485 .73858 m .53105 .77685 L .55858 .77992 L p .707 .577 .707 r
F P
0 g
s
.62093 .80411 m .61882 .82323 L .64782 .82655 L p .707 .577 .707 r
F P
0 g
s
.64782 .82655 m .64994 .80743 L .62093 .80411 L p .707 .577 .707 r
F P
0 g
s
.53407 .72738 m .53759 .67019 L .51647 .66608 L p .707 .577 .707 r
F P
0 g
s
.53071 .7943 m .52859 .81342 L .55613 .81633 L p .707 .577 .707 r
F P
0 g
s
.55613 .81633 m .55825 .79721 L .53071 .7943 L p .707 .577 .707 r
F P
0 g
s
.65421 .75057 m .6504 .78884 L .67407 .79075 L p .707 .577 .707 r
F P
0 g
s
.67407 .79075 m .67788 .75248 L .65421 .75057 L p .707 .577 .707 r
F P
0 g
s
.51647 .66608 m .51294 .72327 L .53407 .72738 L p .707 .577 .707 r
F P
0 g
s
.64994 .80743 m .64782 .82655 L .6714 .82933 L p .707 .577 .707 r
F P
0 g
s
.6714 .82933 m .67351 .81022 L .64994 .80743 L p .707 .577 .707 r
F P
0 g
s
.53105 .77685 m .53485 .73858 L .5136 .73598 L p .707 .577 .707 r
F P
0 g
s
.5136 .73598 m .5098 .77425 L .53105 .77685 L p .707 .577 .707 r
F P
0 g
s
.68116 .6773 m .67764 .73449 L .69384 .73224 L p .707 .577 .707 r
F P
0 g
s
.69384 .73224 m .69737 .67505 L .68116 .6773 L p .707 .577 .707 r
F P
0 g
s
.50941 .79214 m .50729 .81126 L .52859 .81342 L p .707 .577 .707 r
F P
0 g
s
.52859 .81342 m .53071 .7943 L .50941 .79214 L p .707 .577 .707 r
F P
0 g
s
.51294 .72327 m .51647 .66608 L .50376 .66186 L p .707 .577 .707 r
F P
0 g
s
.67788 .75248 m .67407 .79075 L .69002 .79176 L p .707 .577 .707 r
F P
0 g
s
.69002 .79176 m .69382 .75349 L .67788 .75248 L p .707 .577 .707 r
F P
0 g
s
.50376 .66186 m .50023 .71905 L .51294 .72327 L p .707 .577 .707 r
F P
0 g
s
.67351 .81022 m .6714 .82933 L .68725 .83132 L p .707 .577 .707 r
F P
0 g
s
.68725 .83132 m .68936 .8122 L .67351 .81022 L p .707 .577 .707 r
F P
0 g
s
.5098 .77425 m .5136 .73598 L .50071 .73409 L p .707 .577 .707 r
F P
0 g
s
.50071 .73409 m .49691 .77236 L .5098 .77425 L p .707 .577 .707 r
F P
0 g
s
.49644 .79096 m .49433 .81007 L .50729 .81126 L p .707 .577 .707 r
F P
0 g
s
.50729 .81126 m .50941 .79214 L .49644 .79096 L p .707 .577 .707 r
F P
0 g
s
.69737 .67505 m .69384 .73224 L .70077 .72899 L p .707 .577 .707 r
F P
0 g
s
.70077 .72899 m .7043 .6718 L .69737 .67505 L p .707 .577 .707 r
F P
0 g
s
.50023 .71905 m .50376 .66186 L .50072 .65793 L p .707 .577 .707 r
F P
0 g
s
.69382 .75349 m .69002 .79176 L .69668 .79177 L p .707 .577 .707 r
F P
0 g
s
.69668 .79177 m .70048 .7535 L .69382 .75349 L p .707 .577 .707 r
F P
0 g
s
.68936 .8122 m .68725 .83132 L .6938 .83231 L p .707 .577 .707 r
F P
0 g
s
.50072 .65793 m .49719 .71512 L .50023 .71905 L p .707 .577 .707 r
F P
0 g
s
.6938 .83231 m .69592 .81319 L .68936 .8122 L p .707 .577 .707 r
F P
0 g
s
.49691 .77236 m .50071 .73409 L .49743 .73311 L p .707 .577 .707 r
F P
0 g
s
.49743 .73311 m .49363 .77138 L .49691 .77236 L p .707 .577 .707 r
F P
0 g
s
.49307 .79085 m .49096 .80997 L .49433 .81007 L p .707 .577 .707 r
F P
0 g
s
.49433 .81007 m .49644 .79096 L .49307 .79085 L p .707 .577 .707 r
F P
0 g
s
.7043 .6718 m .70077 .72899 L .69773 .72506 L p .707 .577 .707 r
F P
0 g
s
.69773 .72506 m .70125 .66787 L .7043 .6718 L p .707 .577 .707 r
F P
0 g
s
.49719 .71512 m .50072 .65793 L .50764 .65468 L p .707 .577 .707 r
F P
0 g
s
.70048 .7535 m .69668 .79177 L .6934 .79079 L p .707 .577 .707 r
F P
0 g
s
.6934 .79079 m .69721 .75252 L .70048 .7535 L p .707 .577 .707 r
F P
0 g
s
.69592 .81319 m .6938 .83231 L .69043 .8322 L p .707 .577 .707 r
F P
0 g
s
.69043 .8322 m .69255 .81309 L .69592 .81319 L p .707 .577 .707 r
F P
0 g
s
.50764 .65468 m .50411 .71187 L .49719 .71512 L p .707 .577 .707 r
F P
0 g
s
.49363 .77138 m .49743 .73311 L .50409 .73312 L p .707 .577 .707 r
F P
0 g
s
.50409 .73312 m .50029 .77139 L .49363 .77138 L p .707 .577 .707 r
F P
0 g
s
.49963 .79184 m .49751 .81096 L .49096 .80997 L p .707 .577 .707 r
F P
0 g
s
.49096 .80997 m .49307 .79085 L .49963 .79184 L p .707 .577 .707 r
F P
0 g
s
.70125 .66787 m .69773 .72506 L .68502 .72084 L p .707 .577 .707 r
F P
0 g
s
.68502 .72084 m .68855 .66365 L .70125 .66787 L p .707 .577 .707 r
F P
0 g
s
.24969 .69686 m .25322 .63967 L .22207 .63695 L p .707 .577 .707 r
F P
0 g
s
.25322 .63967 m .24969 .69686 L .28145 .69843 L p .707 .577 .707 r
F P
0 g
s
.28145 .69843 m .28498 .64124 L .25322 .63967 L p .707 .577 .707 r
F P
0 g
s
.28498 .64124 m .28145 .69843 L .31072 .69871 L p .707 .577 .707 r
F P
0 g
s
.31072 .69871 m .31425 .64152 L .28498 .64124 L p .707 .577 .707 r
F P
0 g
s
.50411 .71187 m .50764 .65468 L .52385 .65243 L p .707 .577 .707 r
F P
0 g
s
.21854 .69415 m .22207 .63695 L .19459 .63337 L p .707 .577 .707 r
F P
0 g
s
.22207 .63695 m .21854 .69415 L .24969 .69686 L p .707 .577 .707 r
F P
0 g
s
.47424 .80736 m .50627 .29091 L .4623 .28708 L p .707 .577 .707 r
F P
0 g
s
.52385 .65243 m .52032 .70962 L .50411 .71187 L p .707 .577 .707 r
F P
0 g
s
.50029 .77139 m .50409 .73312 L .52004 .73413 L p .707 .577 .707 r
F P
0 g
s
.52004 .73413 m .51624 .7724 L .50029 .77139 L p .707 .577 .707 r
F P
0 g
s
.51547 .79383 m .51336 .81294 L .49751 .81096 L p .707 .577 .707 r
F P
0 g
s
.49751 .81096 m .49963 .79184 L .51547 .79383 L p .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .52004 .73413 L .54137 .73585 L p .707 .577 .707 r
F P
0 g
s
.54137 .73585 m .54371 .73604 L p .54143 .73906 L .707 .577 .707 r
F P
0 g
s
.51624 .7724 m .54137 .73585 L .54143 .73906 L .707 .577 .707 r
F
.52032 .70962 m .52385 .65243 L .54776 .65139 L p F P
0 g
s
.54776 .65139 m .54423 .70858 L .52032 .70962 L p .707 .577 .707 r
F P
0 g
s
.54371 .73604 m .53991 .77431 L .51624 .7724 L p .707 .577 .707 r
F P
0 g
s
.53905 .79661 m .53694 .81573 L .51336 .81294 L p .707 .577 .707 r
F P
0 g
s
.51336 .81294 m .51547 .79383 L .53905 .79661 L p .707 .577 .707 r
F P
0 g
s
.51908 .8096 m .53749 .51285 L p .50627 .29091 L .707 .577 .707 r
F P
0 g
s
.53749 .51285 m .55111 .29315 L .53364 .29228 L p .707 .577 .707 r
F P
0 g
s
.53364 .29228 m .50627 .29091 L p .53749 .51285 L .707 .577 .707 r
F P
0 g
s
.50627 .29091 m .47424 .80736 L .51908 .8096 L p .707 .577 .707 r
F P
0 g
s
.69721 .75252 m .6934 .79079 L .68051 .7889 L p .707 .577 .707 r
F P
0 g
s
.68051 .7889 m .68431 .75063 L .69721 .75252 L p .707 .577 .707 r
F P
0 g
s
.54423 .70858 m .54776 .65139 L .57703 .65168 L p .707 .577 .707 r
F P
0 g
s
.57703 .65168 m .5735 .70887 L .54423 .70858 L p .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .54371 .73604 L .55393 .73696 L p .707 .577 .707 r
F P
0 g
s
.55393 .73696 m .57279 .73866 L p .54676 .76688 L .707 .577 .707 r
F P
0 g
s
.53991 .77431 m .55393 .73696 L .54676 .76688 L .707 .577 .707 r
F
.5735 .70887 m .57703 .65168 L .60879 .65325 L p F P
0 g
s
.57279 .73866 m .56899 .77693 L .53991 .77431 L p .707 .577 .707 r
F P
0 g
s
.60879 .65325 m .60526 .71044 L .5735 .70887 L p .707 .577 .707 r
F P
0 g
s
.56806 .79993 m .56594 .81905 L .5404 .81612 L p .707 .577 .707 r
F P
0 g
s
.5404 .81612 m .53694 .81573 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.54114 .81359 m .56806 .79993 L .5404 .81612 L .707 .577 .707 r
F
.53694 .81573 m .53905 .79661 L .54591 .7974 L p F P
0 g
s
.54591 .7974 m .56806 .79993 L p .54114 .81359 L .707 .577 .707 r
F P
0 g
s
.53694 .81573 m .54591 .7974 L .54114 .81359 L .707 .577 .707 r
F
.56877 .67508 m .56526 .73162 L p .59336 .57251 L F P
0 g
s
.56526 .73162 m .5604 .81003 L p .57665 .69291 L .707 .577 .707 r
F P
0 g
s
.59336 .57251 m .56526 .73162 L .57665 .69291 L .707 .577 .707 r
F
.56899 .77693 m .57279 .73866 L .5805 .73941 L p F P
0 g
s
.5805 .73941 m .60443 .74173 L p .57697 .769 L .707 .577 .707 r
F P
0 g
s
.56899 .77693 m .5805 .73941 L .57697 .769 L .707 .577 .707 r
F
.63994 .65596 m .63641 .71315 L .60526 .71044 L p F P
0 g
s
.60526 .71044 m .60879 .65325 L .63994 .65596 L p .707 .577 .707 r
F P
0 g
s
.63554 .74496 m .63173 .78323 L .60063 .78 L p .707 .577 .707 r
F P
0 g
s
.60063 .78 m .60443 .74173 L .63554 .74496 L p .707 .577 .707 r
F P
0 g
s
.60443 .74173 m .60063 .78 L .56899 .77693 L p .707 .577 .707 r
F P
0 g
s
.59754 .82257 m .59965 .80345 L .63074 .80683 L p .707 .577 .707 r
F P
0 g
s
.59965 .80345 m .59754 .82257 L .57266 .81979 L p .707 .577 .707 r
F P
0 g
s
.57266 .81979 m .56594 .81905 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.57322 .81568 m .59965 .80345 L .57266 .81979 L .707 .577 .707 r
F
.56594 .81905 m .56806 .79993 L .57526 .80073 L p F P
0 g
s
.57526 .80073 m .59965 .80345 L p .57322 .81568 L .707 .577 .707 r
F P
0 g
s
.56594 .81905 m .57526 .80073 L .57322 .81568 L .707 .577 .707 r
F
.61785 .42651 m .61074 .54113 L p .62483 .36803 L F P
0 g
s
.61074 .54113 m .59415 .80861 L p .61489 .51076 L .707 .577 .707 r
F P
0 g
s
.62483 .36803 m .61074 .54113 L .61489 .51076 L .707 .577 .707 r
F
.59415 .80861 m .61703 .80546 L p .62339 .44854 L F P
0 g
s
.62339 .44854 m .62483 .36803 L .61489 .51076 L .707 .577 .707 r
F
.62339 .44854 m .61489 .51076 L .59415 .80861 L F
.62618 .29216 m .61785 .42651 L p .62483 .36803 L F P
0 g
s
.5604 .81003 m .59415 .80861 L p .59357 .63541 L .707 .577 .707 r
F P
0 g
s
.59357 .63541 m .59336 .57251 L .57665 .69291 L .707 .577 .707 r
F
.59357 .63541 m .57665 .69291 L .5604 .81003 L F
.59243 .29358 m .56877 .67508 L p .59336 .57251 L F P
0 g
s
.55111 .29315 m .51908 .8096 L .5604 .81003 L p .707 .577 .707 r
F P
0 g
s
.5604 .81003 m .59243 .29358 L .55111 .29315 L p .707 .577 .707 r
F P
0 g
s
.24667 .74633 m .25048 .70806 L .21937 .70483 L p .707 .577 .707 r
F P
0 g
s
.25048 .70806 m .24667 .74633 L .27832 .7494 L p .707 .577 .707 r
F P
0 g
s
.27832 .7494 m .28212 .71114 L .25048 .70806 L p .707 .577 .707 r
F P
0 g
s
.21937 .70483 m .21557 .7431 L .24667 .74633 L p .707 .577 .707 r
F P
0 g
s
.69255 .81309 m .69043 .8322 L .67746 .83102 L p .707 .577 .707 r
F P
0 g
s
.67746 .83102 m .67958 .8119 L .69255 .81309 L p .707 .577 .707 r
F P
0 g
s
.19459 .63337 m .19106 .69056 L .21854 .69415 L p .707 .577 .707 r
F P
0 g
s
.28212 .71114 m .27832 .7494 L .30739 .75202 L p .707 .577 .707 r
F P
0 g
s
.30739 .75202 m .3112 .71375 L .28212 .71114 L p .707 .577 .707 r
F P
0 g
s
.31425 .64152 m .31072 .69871 L .33463 .69768 L p .707 .577 .707 r
F P
0 g
s
.33463 .69768 m .33815 .64049 L .31425 .64152 L p .707 .577 .707 r
F P
0 g
s
.43027 .80353 m .4623 .28708 L .4235 .28203 L p .707 .577 .707 r
F P
0 g
s
.4623 .28708 m .43027 .80353 L .47424 .80736 L p .707 .577 .707 r
F P
0 g
s
.21524 .7604 m .21312 .77951 L .24421 .78289 L p .707 .577 .707 r
F P
0 g
s
.24421 .78289 m .24633 .76378 L .21524 .7604 L p .707 .577 .707 r
F P
0 g
s
.24633 .76378 m .24421 .78289 L .27581 .78641 L p .707 .577 .707 r
F P
0 g
s
.27581 .78641 m .27792 .7673 L .24633 .76378 L p .707 .577 .707 r
F P
0 g
s
.21557 .7431 m .21937 .70483 L .19185 .70177 L p .707 .577 .707 r
F P
0 g
s
.19185 .70177 m .18804 .74004 L .21557 .7431 L p .707 .577 .707 r
F P
0 g
s
.27792 .7673 m .27581 .78641 L .30481 .78973 L p .707 .577 .707 r
F P
0 g
s
.30481 .78973 m .30693 .77062 L .27792 .7673 L p .707 .577 .707 r
F P
0 g
s
.19106 .69056 m .19459 .63337 L .17346 .62927 L p .707 .577 .707 r
F P
0 g
s
.1877 .75748 m .18558 .7766 L .21312 .77951 L p .707 .577 .707 r
F P
0 g
s
.21312 .77951 m .21524 .7604 L .1877 .75748 L p .707 .577 .707 r
F P
0 g
s
.68855 .66365 m .68502 .72084 L .66389 .71673 L p .707 .577 .707 r
F P
0 g
s
.66389 .71673 m .66742 .65954 L .68855 .66365 L p .707 .577 .707 r
F P
0 g
s
.3112 .71375 m .30739 .75202 L .33107 .75393 L p .707 .577 .707 r
F P
0 g
s
.33107 .75393 m .33487 .71566 L .3112 .71375 L p .707 .577 .707 r
F P
0 g
s
.17346 .62927 m .16993 .68646 L .19106 .69056 L p .707 .577 .707 r
F P
0 g
s
.59415 .80861 m .62618 .29216 L .59243 .29358 L p .707 .577 .707 r
F P
0 g
s
.30693 .77062 m .30481 .78973 L .32839 .79252 L p .707 .577 .707 r
F P
0 g
s
.32839 .79252 m .33051 .7734 L .30693 .77062 L p .707 .577 .707 r
F P
0 g
s
.18804 .74004 m .19185 .70177 L .1706 .69917 L p .707 .577 .707 r
F P
0 g
s
.1706 .69917 m .16679 .73743 L .18804 .74004 L p .707 .577 .707 r
F P
0 g
s
.33815 .64049 m .33463 .69768 L .35084 .69542 L p .707 .577 .707 r
F P
0 g
s
.35084 .69542 m .35436 .63823 L .33815 .64049 L p .707 .577 .707 r
F P
0 g
s
.68431 .75063 m .68051 .7889 L .65926 .7863 L p .707 .577 .707 r
F P
0 g
s
.65926 .7863 m .66306 .74803 L .68431 .75063 L p .707 .577 .707 r
F P
0 g
s
.39147 .79848 m .4235 .28203 L .39367 .27625 L p .707 .577 .707 r
F P
0 g
s
.4235 .28203 m .39147 .79848 L .43027 .80353 L p .707 .577 .707 r
F P
0 g
s
.1664 .75533 m .16429 .77445 L .18558 .7766 L p .707 .577 .707 r
F P
0 g
s
.18558 .7766 m .1877 .75748 L .1664 .75533 L p .707 .577 .707 r
F P
0 g
s
.67958 .8119 m .67746 .83102 L .65617 .82886 L p .707 .577 .707 r
F P
0 g
s
.65617 .82886 m .65828 .80974 L .67958 .8119 L p .707 .577 .707 r
F P
0 g
s
.16993 .68646 m .17346 .62927 L .16075 .62505 L p .707 .577 .707 r
F P
0 g
s
.66742 .65954 m .66389 .71673 L .63641 .71315 L p .707 .577 .707 r
F P
0 g
s
.63641 .71315 m .63994 .65596 L .66742 .65954 L p .707 .577 .707 r
F P
0 g
s
.33487 .71566 m .33107 .75393 L .34701 .75494 L p .707 .577 .707 r
F P
0 g
s
.34701 .75494 m .35081 .71667 L .33487 .71566 L p .707 .577 .707 r
F P
0 g
s
.16075 .62505 m .15722 .68224 L .16993 .68646 L p .707 .577 .707 r
F P
0 g
s
.33051 .7734 m .32839 .79252 L .34424 .7945 L p .707 .577 .707 r
F P
0 g
s
.34424 .7945 m .34635 .77539 L .33051 .7734 L p .707 .577 .707 r
F P
0 g
s
.16679 .73743 m .1706 .69917 L .1577 .69728 L p .707 .577 .707 r
F P
0 g
s
.1577 .69728 m .1539 .73555 L .16679 .73743 L p .707 .577 .707 r
F P
0 g
s
.61703 .80546 m .64906 .28901 L .62618 .29216 L p .707 .577 .707 r
F P
0 g
s
.66306 .74803 m .65926 .7863 L .63173 .78323 L p .707 .577 .707 r
F P
0 g
s
.63173 .78323 m .63554 .74496 L .66306 .74803 L p .707 .577 .707 r
F P
0 g
s
.15343 .75414 m .15132 .77326 L .16429 .77445 L p .707 .577 .707 r
F P
0 g
s
.16429 .77445 m .1664 .75533 L .15343 .75414 L p .707 .577 .707 r
F P
0 g
s
.35436 .63823 m .35084 .69542 L .35776 .69217 L p .707 .577 .707 r
F P
0 g
s
.35776 .69217 m .36129 .63498 L .35436 .63823 L p .707 .577 .707 r
F P
0 g
s
.65828 .80974 m .65617 .82886 L .62863 .82595 L p .707 .577 .707 r
F P
0 g
s
.62863 .82595 m .63074 .80683 L .65828 .80974 L p .707 .577 .707 r
F P
0 g
s
.36164 .7927 m .39367 .27625 L .37573 .27032 L p .707 .577 .707 r
F P
0 g
s
.39367 .27625 m .36164 .7927 L .39147 .79848 L p .707 .577 .707 r
F P
0 g
s
.15722 .68224 m .16075 .62505 L .15771 .62112 L p .707 .577 .707 r
F P
0 g
s
.35081 .71667 m .34701 .75494 L .35367 .75495 L p .707 .577 .707 r
F P
0 g
s
.35367 .75495 m .35747 .71669 L .35081 .71667 L p .707 .577 .707 r
F P
0 g
s
.63074 .80683 m .62863 .82595 L .59754 .82257 L p .707 .577 .707 r
F P
0 g
s
.34635 .77539 m .34424 .7945 L .35079 .79549 L p .707 .577 .707 r
F P
0 g
s
.15771 .62112 m .15418 .67831 L .15722 .68224 L p .707 .577 .707 r
F P
0 g
s
.35079 .79549 m .35291 .77638 L .34635 .77539 L p .707 .577 .707 r
F P
0 g
s
.1539 .73555 m .1577 .69728 L .15442 .69629 L p .707 .577 .707 r
F P
0 g
s
.15442 .69629 m .15062 .73456 L .1539 .73555 L p .707 .577 .707 r
F P
0 g
s
.15006 .75404 m .14795 .77315 L .15132 .77326 L p .707 .577 .707 r
F P
0 g
s
.15132 .77326 m .15343 .75414 L .15006 .75404 L p .707 .577 .707 r
F P
0 g
s
.36129 .63498 m .35776 .69217 L .35472 .68824 L p .707 .577 .707 r
F P
0 g
s
.35472 .68824 m .35825 .63105 L .36129 .63498 L p .707 .577 .707 r
F P
0 g
s
.64906 .28901 m .61703 .80546 L .6268 .80092 L p .707 .577 .707 r
F P
0 g
s
.6268 .80092 m .65883 .28447 L .64906 .28901 L p .707 .577 .707 r
F P
0 g
s
.15418 .67831 m .15771 .62112 L .16463 .61787 L p .707 .577 .707 r
F P
0 g
s
.35747 .71669 m .35367 .75495 L .35039 .75397 L p .707 .577 .707 r
F P
0 g
s
.35039 .75397 m .3542 .7157 L .35747 .71669 L p .707 .577 .707 r
F P
0 g
s
.35825 .63105 m .35472 .68824 L .34201 .68402 L p .707 .577 .707 r
F P
0 g
s
.34201 .68402 m .34554 .62683 L .35825 .63105 L p .707 .577 .707 r
F P
0 g
s
.3542 .7157 m .35039 .75397 L .34819 .75365 L p .707 .577 .707 r
F P
0 g
s
.34819 .75365 m .3375 .75208 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.34923 .72653 m .3542 .7157 L .34819 .75365 L .707 .577 .707 r
F
.37573 .27032 m .37143 .26481 L p .35509 .57235 L F P
0 g
s
.3375 .75208 m .3413 .71381 L .34966 .71504 L p .707 .577 .707 r
F P
0 g
s
.34966 .71504 m .3542 .7157 L p .34923 .72653 L .707 .577 .707 r
F P
0 g
s
.3375 .75208 m .34966 .71504 L .34923 .72653 L .707 .577 .707 r
F
.34954 .77627 m .34742 .79539 L .34588 .79525 L p F P
0 g
s
.34588 .79525 m .33446 .7942 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.34635 .78007 m .34954 .77627 L .34588 .79525 L .707 .577 .707 r
F
.33446 .7942 m .33657 .77508 L .34647 .77599 L p F P
0 g
s
.34647 .77599 m .34954 .77627 L p .34635 .78007 L .707 .577 .707 r
F P
0 g
s
.33446 .7942 m .34647 .77599 L .34635 .78007 L .707 .577 .707 r
F
.35943 .45836 m .35317 .55933 L p .35509 .57235 L F P
0 g
s
.35317 .55933 m .3394 .78126 L p .35114 .625 L .707 .577 .707 r
F P
0 g
s
.35509 .57235 m .35317 .55933 L .35114 .625 L .707 .577 .707 r
F
.3394 .78126 m .3437 .78677 L p .34953 .67702 L F P
0 g
s
.34953 .67702 m .35509 .57235 L .35114 .625 L .707 .577 .707 r
F
.34953 .67702 m .35114 .625 L .3394 .78126 L F
.37143 .26481 m .35943 .45836 L p .35509 .57235 L F P
0 g
s
.3437 .78677 m .35207 .65182 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35207 .65182 m .37573 .27032 L p .35509 .57235 L .707 .577 .707 r
F P
0 g
s
.35291 .77638 m .35079 .79549 L .34742 .79539 L p .707 .577 .707 r
F P
0 g
s
.34742 .79539 m .34954 .77627 L .35291 .77638 L p .707 .577 .707 r
F P
0 g
s
.37573 .27032 m .3437 .78677 L .36164 .7927 L p .707 .577 .707 r
F P
0 g
s
.16463 .61787 m .1611 .67506 L .15418 .67831 L p .707 .577 .707 r
F P
0 g
s
.15062 .73456 m .15442 .69629 L .16108 .69631 L p .707 .577 .707 r
F P
0 g
s
.16108 .69631 m .15728 .73458 L .15062 .73456 L p .707 .577 .707 r
F P
0 g
s
.15662 .75503 m .1545 .77414 L .14795 .77315 L p .707 .577 .707 r
F P
0 g
s
.14795 .77315 m .15006 .75404 L .15662 .75503 L p .707 .577 .707 r
F P
0 g
s
.1611 .67506 m .16463 .61787 L .18084 .61561 L p .707 .577 .707 r
F P
0 g
s
.65883 .28447 m .6268 .80092 L .62251 .79541 L p .707 .577 .707 r
F P
0 g
s
.62251 .79541 m .65454 .27896 L .65883 .28447 L p .707 .577 .707 r
F P
0 g
s
.18084 .61561 m .17731 .6728 L .1611 .67506 L p .707 .577 .707 r
F P
0 g
s
.15728 .73458 m .16108 .69631 L .17703 .69732 L p .707 .577 .707 r
F P
0 g
s
.17703 .69732 m .17323 .73559 L .15728 .73458 L p .707 .577 .707 r
F P
0 g
s
.17246 .75701 m .17035 .77613 L .1545 .77414 L p .707 .577 .707 r
F P
0 g
s
.1545 .77414 m .15662 .75503 L .17246 .75701 L p .707 .577 .707 r
F P
0 g
s
.34554 .62683 m .34201 .68402 L .32088 .67992 L p .707 .577 .707 r
F P
0 g
s
.32088 .67992 m .32441 .62273 L .34554 .62683 L p .707 .577 .707 r
F P
0 g
s
.3394 .78126 m .37143 .26481 L .3812 .26026 L p .707 .577 .707 r
F P
0 g
s
.17731 .6728 m .18084 .61561 L .20475 .61458 L p .707 .577 .707 r
F P
0 g
s
.3413 .71381 m .3375 .75208 L .31625 .74948 L p .707 .577 .707 r
F P
0 g
s
.31625 .74948 m .32005 .71121 L .3413 .71381 L p .707 .577 .707 r
F P
0 g
s
.20475 .61458 m .20122 .67177 L .17731 .6728 L p .707 .577 .707 r
F P
0 g
s
.33657 .77508 m .33446 .7942 L .31316 .79205 L p .707 .577 .707 r
F P
0 g
s
.31316 .79205 m .31527 .77293 L .33657 .77508 L p .707 .577 .707 r
F P
0 g
s
.17323 .73559 m .17703 .69732 L .2007 .69923 L p .707 .577 .707 r
F P
0 g
s
.2007 .69923 m .1969 .7375 L .17323 .73559 L p .707 .577 .707 r
F P
0 g
s
.32441 .62273 m .32088 .67992 L .2934 .67634 L p .707 .577 .707 r
F P
0 g
s
.2934 .67634 m .29693 .61915 L .32441 .62273 L p .707 .577 .707 r
F P
0 g
s
.19604 .7598 m .19393 .77891 L .17035 .77613 L p .707 .577 .707 r
F P
0 g
s
.17035 .77613 m .17246 .75701 L .19604 .7598 L p .707 .577 .707 r
F P
0 g
s
.20122 .67177 m .20475 .61458 L .23402 .61486 L p .707 .577 .707 r
F P
0 g
s
.65454 .27896 m .62251 .79541 L .60457 .78948 L p .707 .577 .707 r
F P
0 g
s
.60457 .78948 m .6366 .27302 L .65454 .27896 L p .707 .577 .707 r
F P
0 g
s
.23402 .61486 m .23049 .67205 L .20122 .67177 L p .707 .577 .707 r
F P
0 g
s
.32005 .71121 m .31625 .74948 L .28872 .74642 L p .707 .577 .707 r
F P
0 g
s
.28872 .74642 m .29253 .70815 L .32005 .71121 L p .707 .577 .707 r
F P
0 g
s
.29693 .61915 m .2934 .67634 L .26225 .67362 L p .707 .577 .707 r
F P
0 g
s
.26225 .67362 m .26578 .61643 L .29693 .61915 L p .707 .577 .707 r
F P
0 g
s
.31527 .77293 m .31316 .79205 L .28562 .78913 L p .707 .577 .707 r
F P
0 g
s
.28562 .78913 m .28773 .77002 L .31527 .77293 L p .707 .577 .707 r
F P
0 g
s
.23049 .67205 m .23402 .61486 L .26578 .61643 L p .707 .577 .707 r
F P
0 g
s
.7299 .64631 m .73343 .58912 L .70228 .58641 L p .707 .577 .707 r
F P
0 g
s
.73343 .58912 m .7299 .64631 L .76166 .64788 L p .707 .577 .707 r
F P
0 g
s
.76166 .64788 m .76519 .59069 L .73343 .58912 L p .707 .577 .707 r
F P
0 g
s
.1969 .7375 m .2007 .69923 L .22978 .70185 L p .707 .577 .707 r
F P
0 g
s
.22978 .70185 m .22598 .74011 L .1969 .7375 L p .707 .577 .707 r
F P
0 g
s
.34918 .77672 m .3812 .26026 L .40408 .25712 L p .707 .577 .707 r
F P
0 g
s
.3812 .26026 m .34918 .77672 L .3394 .78126 L p .707 .577 .707 r
F P
0 g
s
.26578 .61643 m .26225 .67362 L .23049 .67205 L p .707 .577 .707 r
F P
0 g
s
.76519 .59069 m .76166 .64788 L .79093 .64816 L p .707 .577 .707 r
F P
0 g
s
.79093 .64816 m .79446 .59097 L .76519 .59069 L p .707 .577 .707 r
F P
0 g
s
.22505 .76311 m .22293 .78223 L .19393 .77891 L p .707 .577 .707 r
F P
0 g
s
.19393 .77891 m .19604 .7598 L .22505 .76311 L p .707 .577 .707 r
F P
0 g
s
.69875 .6436 m .70228 .58641 L .6748 .58282 L p .707 .577 .707 r
F P
0 g
s
.70228 .58641 m .69875 .6436 L .7299 .64631 L p .707 .577 .707 r
F P
0 g
s
.29253 .70815 m .28872 .74642 L .25762 .74319 L p .707 .577 .707 r
F P
0 g
s
.25762 .74319 m .26142 .70492 L .29253 .70815 L p .707 .577 .707 r
F P
0 g
s
.22598 .74011 m .22978 .70185 L .26142 .70492 L p .707 .577 .707 r
F P
0 g
s
.6748 .58282 m .67127 .64001 L .69875 .6436 L p .707 .577 .707 r
F P
0 g
s
.72689 .70202 m .73069 .66375 L .69958 .66052 L p .707 .577 .707 r
F P
0 g
s
.73069 .66375 m .72689 .70202 L .75853 .70509 L p .707 .577 .707 r
F P
0 g
s
.75853 .70509 m .76233 .66682 L .73069 .66375 L p .707 .577 .707 r
F P
0 g
s
.26142 .70492 m .25762 .74319 L .22598 .74011 L p .707 .577 .707 r
F P
0 g
s
.28773 .77002 m .28562 .78913 L .25453 .78575 L p .707 .577 .707 r
F P
0 g
s
.69958 .66052 m .69578 .69879 L .72689 .70202 L p .707 .577 .707 r
F P
0 g
s
.25453 .78575 m .25664 .76664 L .28773 .77002 L p .707 .577 .707 r
F P
0 g
s
.79446 .59097 m .79093 .64816 L .81484 .64713 L p .707 .577 .707 r
F P
0 g
s
.81484 .64713 m .81837 .58994 L .79446 .59097 L p .707 .577 .707 r
F P
0 g
s
.76233 .66682 m .75853 .70509 L .78761 .70771 L p .707 .577 .707 r
F P
0 g
s
.78761 .70771 m .79141 .66944 L .76233 .66682 L p .707 .577 .707 r
F P
0 g
s
.25664 .76664 m .25453 .78575 L .22293 .78223 L p .707 .577 .707 r
F P
0 g
s
.22293 .78223 m .22505 .76311 L .25664 .76664 L p .707 .577 .707 r
F P
0 g
s
.69578 .69879 m .69958 .66052 L .67206 .65746 L p .707 .577 .707 r
F P
0 g
s
.69545 .72486 m .69334 .74397 L .72443 .74736 L p .707 .577 .707 r
F P
0 g
s
.72443 .74736 m .72654 .72824 L .69545 .72486 L p .707 .577 .707 r
F P
0 g
s
.72654 .72824 m .72443 .74736 L .75602 .75088 L p .707 .577 .707 r
F P
0 g
s
.75602 .75088 m .75813 .73176 L .72654 .72824 L p .707 .577 .707 r
F P
0 g
s
.67206 .65746 m .66826 .69573 L .69578 .69879 L p .707 .577 .707 r
F P
0 g
s
.67127 .64001 m .6748 .58282 L .65367 .57872 L p .707 .577 .707 r
F P
0 g
s
.75813 .73176 m .75602 .75088 L .78503 .75419 L p .707 .577 .707 r
F P
0 g
s
.78503 .75419 m .78714 .73508 L .75813 .73176 L p .707 .577 .707 r
F P
0 g
s
.66791 .72195 m .6658 .74106 L .69334 .74397 L p .707 .577 .707 r
F P
0 g
s
.69334 .74397 m .69545 .72486 L .66791 .72195 L p .707 .577 .707 r
F P
0 g
s
.6366 .27302 m .60457 .78948 L .57474 .7837 L p .707 .577 .707 r
F P
0 g
s
.57474 .7837 m .60676 .26725 L .6366 .27302 L p .707 .577 .707 r
F P
0 g
s
.65367 .57872 m .65014 .63591 L .67127 .64001 L p .707 .577 .707 r
F P
0 g
s
.79141 .66944 m .78761 .70771 L .81128 .70962 L p .707 .577 .707 r
F P
0 g
s
.81128 .70962 m .81508 .67135 L .79141 .66944 L p .707 .577 .707 r
F P
0 g
s
.66826 .69573 m .67206 .65746 L .65081 .65485 L p .707 .577 .707 r
F P
0 g
s
.65081 .65485 m .64701 .69312 L .66826 .69573 L p .707 .577 .707 r
F P
0 g
s
.78714 .73508 m .78503 .75419 L .80861 .75698 L p .707 .577 .707 r
F P
0 g
s
.80861 .75698 m .81072 .73787 L .78714 .73508 L p .707 .577 .707 r
F P
0 g
s
.81837 .58994 m .81484 .64713 L .83105 .64487 L p .707 .577 .707 r
F P
0 g
s
.83105 .64487 m .83458 .58768 L .81837 .58994 L p .707 .577 .707 r
F P
0 g
s
.40408 .25712 m .37206 .77357 L .34918 .77672 L p .707 .577 .707 r
F P
0 g
s
.37206 .77357 m .40408 .25712 L .43784 .2557 L p .707 .577 .707 r
F P
0 g
s
.64661 .71979 m .6445 .73891 L .6658 .74106 L p .707 .577 .707 r
F P
0 g
s
.6658 .74106 m .66791 .72195 L .64661 .71979 L p .707 .577 .707 r
F P
0 g
s
.65014 .63591 m .65367 .57872 L .64096 .5745 L p .707 .577 .707 r
F P
0 g
s
.81508 .67135 m .81128 .70962 L .82723 .71063 L p .707 .577 .707 r
F P
0 g
s
.82723 .71063 m .83103 .67236 L .81508 .67135 L p .707 .577 .707 r
F P
0 g
s
.64096 .5745 m .63744 .63169 L .65014 .63591 L p .707 .577 .707 r
F P
0 g
s
.81072 .73787 m .80861 .75698 L .82445 .75897 L p .707 .577 .707 r
F P
0 g
s
.82445 .75897 m .82656 .73985 L .81072 .73787 L p .707 .577 .707 r
F P
0 g
s
.64701 .69312 m .65081 .65485 L .63791 .65297 L p .707 .577 .707 r
F P
0 g
s
.63791 .65297 m .63411 .69124 L .64701 .69312 L p .707 .577 .707 r
F P
0 g
s
.60676 .26725 m .57474 .7837 L .53594 .77865 L p .707 .577 .707 r
F P
0 g
s
.53594 .77865 m .56796 .2622 L .60676 .26725 L p .707 .577 .707 r
F P
0 g
s
.83458 .58768 m .83105 .64487 L .83797 .64162 L p .707 .577 .707 r
F P
0 g
s
.83797 .64162 m .8415 .58443 L .83458 .58768 L p .707 .577 .707 r
F P
0 g
s
.63364 .7186 m .63153 .73772 L .6445 .73891 L p .707 .577 .707 r
F P
0 g
s
.6445 .73891 m .64661 .71979 L .63364 .7186 L p .707 .577 .707 r
F P
0 g
s
.40581 .77215 m .43784 .2557 L .47915 .25613 L p .707 .577 .707 r
F P
0 g
s
.43784 .2557 m .40581 .77215 L .37206 .77357 L p .707 .577 .707 r
F P
0 g
s
.63744 .63169 m .64096 .5745 L .63792 .57057 L p .707 .577 .707 r
F P
0 g
s
.83103 .67236 m .82723 .71063 L .83389 .71064 L p .707 .577 .707 r
F P
0 g
s
.83389 .71064 m .83769 .67237 L .83103 .67236 L p .707 .577 .707 r
F P
0 g
s
.63792 .57057 m .63439 .62776 L .63744 .63169 L p .707 .577 .707 r
F P
0 g
s
.56796 .2622 m .53594 .77865 L .49196 .77482 L p .707 .577 .707 r
F P
0 g
s
.49196 .77482 m .52399 .25837 L .56796 .2622 L p .707 .577 .707 r
F P
0 g
s
.82656 .73985 m .82445 .75897 L .83101 .75996 L p .707 .577 .707 r
F P
0 g
s
.83101 .75996 m .83312 .74084 L .82656 .73985 L p .707 .577 .707 r
F P
0 g
s
.44712 .77258 m .47915 .25613 L .52399 .25837 L p .707 .577 .707 r
F P
0 g
s
.47915 .25613 m .44712 .77258 L .40581 .77215 L p .707 .577 .707 r
F P
0 g
s
.63411 .69124 m .63791 .65297 L .63464 .65198 L p .707 .577 .707 r
F P
0 g
s
.63464 .65198 m .63083 .69025 L .63411 .69124 L p .707 .577 .707 r
F P
0 g
s
.52399 .25837 m .49196 .77482 L .44712 .77258 L p .707 .577 .707 r
F P
0 g
s
.8415 .58443 m .83797 .64162 L .83493 .63769 L p .707 .577 .707 r
F P
0 g
s
.83493 .63769 m .83846 .5805 L .8415 .58443 L p .707 .577 .707 r
F P
0 g
s
.63027 .7185 m .62816 .73762 L .63153 .73772 L p .707 .577 .707 r
F P
0 g
s
.63153 .73772 m .63364 .7186 L .63027 .7185 L p .707 .577 .707 r
F P
0 g
s
.63439 .62776 m .63792 .57057 L .64485 .56732 L p .707 .577 .707 r
F P
0 g
s
.83769 .67237 m .83389 .71064 L .83061 .70966 L p .707 .577 .707 r
F P
0 g
s
.83061 .70966 m .83441 .67139 L .83769 .67237 L p .707 .577 .707 r
F P
0 g
s
.64485 .56732 m .64132 .62451 L .63439 .62776 L p .707 .577 .707 r
F P
0 g
s
.83312 .74084 m .83101 .75996 L .82764 .75985 L p .707 .577 .707 r
F P
0 g
s
.82764 .75985 m .82975 .74074 L .83312 .74084 L p .707 .577 .707 r
F P
0 g
s
.63083 .69025 m .63464 .65198 L .6413 .652 L p .707 .577 .707 r
F P
0 g
s
.6413 .652 m .63749 .69027 L .63083 .69025 L p .707 .577 .707 r
F P
0 g
s
.83846 .5805 m .83493 .63769 L .82223 .63347 L p .707 .577 .707 r
F P
0 g
s
.82223 .63347 m .82575 .57628 L .83846 .5805 L p .707 .577 .707 r
F P
0 g
s
.63683 .71949 m .63472 .7386 L .62816 .73762 L p .707 .577 .707 r
F P
0 g
s
.62816 .73762 m .63027 .7185 L .63683 .71949 L p .707 .577 .707 r
F P
0 g
s
.38689 .60949 m .39042 .5523 L .35927 .54959 L p .707 .577 .707 r
F P
0 g
s
.39042 .5523 m .38689 .60949 L .41865 .61106 L p .707 .577 .707 r
F P
0 g
s
.41865 .61106 m .42218 .55387 L .39042 .5523 L p .707 .577 .707 r
F P
0 g
s
.42218 .55387 m .41865 .61106 L .44792 .61135 L p .707 .577 .707 r
F P
0 g
s
.44792 .61135 m .45145 .55416 L .42218 .55387 L p .707 .577 .707 r
F P
0 g
s
.64132 .62451 m .64485 .56732 L .66105 .56506 L p .707 .577 .707 r
F P
0 g
s
.35574 .60678 m .35927 .54959 L .33179 .54601 L p .707 .577 .707 r
F P
0 g
s
.35927 .54959 m .35574 .60678 L .38689 .60949 L p .707 .577 .707 r
F P
0 g
s
.83441 .67139 m .83061 .70966 L .81771 .70777 L p .707 .577 .707 r
F P
0 g
s
.81771 .70777 m .82152 .6695 L .83441 .67139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66105 .56506 m .65753 .62225 L .64132 .62451 L p .707 .577 .707 r
F P
0 g
s
.33179 .54601 m .32826 .6032 L .35574 .60678 L p .707 .577 .707 r
F P
0 g
s
.38388 .6652 m .38768 .62694 L .35657 .62371 L p .707 .577 .707 r
F P
0 g
s
.38768 .62694 m .38388 .6652 L .41552 .66828 L p .707 .577 .707 r
F P
0 g
s
.41552 .66828 m .41932 .63001 L .38768 .62694 L p .707 .577 .707 r
F P
0 g
s
.35657 .62371 m .35277 .66198 L .38388 .6652 L p .707 .577 .707 r
F P
0 g
s
.45145 .55416 m .44792 .61135 L .47183 .61031 L p .707 .577 .707 r
F P
0 g
s
.47183 .61031 m .47536 .55312 L .45145 .55416 L p .707 .577 .707 r
F P
0 g
s
.41932 .63001 m .41552 .66828 L .4446 .6709 L p .707 .577 .707 r
F P
0 g
s
.4446 .6709 m .4484 .63263 L .41932 .63001 L p .707 .577 .707 r
F P
0 g
s
.82975 .74074 m .82764 .75985 L .81467 .75866 L p .707 .577 .707 r
F P
0 g
s
.81467 .75866 m .81678 .73955 L .82975 .74074 L p .707 .577 .707 r
F P
0 g
s
.63749 .69027 m .6413 .652 L .65724 .65301 L p .707 .577 .707 r
F P
0 g
s
.35277 .66198 m .35657 .62371 L .32905 .62064 L p .707 .577 .707 r
F P
0 g
s
.35244 .68804 m .35033 .70716 L .38142 .71054 L p .707 .577 .707 r
F P
0 g
s
.38142 .71054 m .38353 .69142 L .35244 .68804 L p .707 .577 .707 r
F P
0 g
s
.38353 .69142 m .38142 .71054 L .41301 .71406 L p .707 .577 .707 r
F P
0 g
s
.65724 .65301 m .65344 .69128 L .63749 .69027 L p .707 .577 .707 r
F P
0 g
s
.41301 .71406 m .41512 .69495 L .38353 .69142 L p .707 .577 .707 r
F P
0 g
s
.32905 .62064 m .32525 .65891 L .35277 .66198 L p .707 .577 .707 r
F P
0 g
s
.32826 .6032 m .33179 .54601 L .31066 .5419 L p .707 .577 .707 r
F P
0 g
s
.41512 .69495 m .41301 .71406 L .44202 .71738 L p .707 .577 .707 r
F P
0 g
s
.44202 .71738 m .44413 .69826 L .41512 .69495 L p .707 .577 .707 r
F P
0 g
s
.82575 .57628 m .82223 .63347 L .8011 .62937 L p .707 .577 .707 r
F P
0 g
s
.8011 .62937 m .80462 .57218 L .82575 .57628 L p .707 .577 .707 r
F P
0 g
s
.65268 .72147 m .65056 .74059 L .63472 .7386 L p .707 .577 .707 r
F P
0 g
s
.63472 .7386 m .63683 .71949 L .65268 .72147 L p .707 .577 .707 r
F P
0 g
s
.3249 .68513 m .32279 .70425 L .35033 .70716 L p .707 .577 .707 r
F P
0 g
s
.35033 .70716 m .35244 .68804 L .3249 .68513 L p .707 .577 .707 r
F P
0 g
s
.31066 .5419 m .30713 .59909 L .32826 .6032 L p .707 .577 .707 r
F P
0 g
s
.4484 .63263 m .4446 .6709 L .46827 .6728 L p .707 .577 .707 r
F P
0 g
s
.46827 .6728 m .47207 .63454 L .4484 .63263 L p .707 .577 .707 r
F P
0 g
s
.65753 .62225 m .66105 .56506 L .68496 .56403 L p .707 .577 .707 r
F P
0 g
s
.32525 .65891 m .32905 .62064 L .3078 .61804 L p .707 .577 .707 r
F P
0 g
s
.3078 .61804 m .304 .65631 L .32525 .65891 L p .707 .577 .707 r
F P
0 g
s
.44413 .69826 m .44202 .71738 L .4656 .72017 L p .707 .577 .707 r
F P
0 g
s
.4656 .72017 m .46771 .70105 L .44413 .69826 L p .707 .577 .707 r
F P
0 g
s
.47536 .55312 m .47183 .61031 L .48804 .60806 L p .707 .577 .707 r
F P
0 g
s
.48804 .60806 m .49157 .55087 L .47536 .55312 L p .707 .577 .707 r
F P
0 g
s
.82152 .6695 m .81771 .70777 L .79646 .70517 L p .707 .577 .707 r
F P
0 g
s
.79646 .70517 m .80027 .6669 L .82152 .6695 L p .707 .577 .707 r
F P
0 g
s
.68496 .56403 m .68144 .62122 L .65753 .62225 L p .707 .577 .707 r
F P
0 g
s
.3036 .68298 m .30149 .70209 L .32279 .70425 L p .707 .577 .707 r
F P
0 g
s
.32279 .70425 m .3249 .68513 L .3036 .68298 L p .707 .577 .707 r
F P
0 g
s
.30713 .59909 m .31066 .5419 L .29795 .53768 L p .707 .577 .707 r
F P
0 g
s
.81678 .73955 m .81467 .75866 L .79337 .75651 L p .707 .577 .707 r
F P
0 g
s
.79337 .75651 m .79549 .73739 L .81678 .73955 L p .707 .577 .707 r
F P
0 g
s
.65344 .69128 m .65724 .65301 L .68091 .65492 L p .707 .577 .707 r
F P
0 g
s
.80462 .57218 m .8011 .62937 L .77361 .62579 L p .707 .577 .707 r
F P
0 g
s
.77361 .62579 m .77714 .5686 L .80462 .57218 L p .707 .577 .707 r
F P
0 g
s
.68091 .65492 m .67711 .69318 L .65344 .69128 L p .707 .577 .707 r
F P
0 g
s
.47207 .63454 m .46827 .6728 L .48422 .67381 L p .707 .577 .707 r
F P
0 g
s
.48422 .67381 m .48802 .63555 L .47207 .63454 L p .707 .577 .707 r
F P
0 g
s
.29795 .53768 m .29442 .59487 L .30713 .59909 L p .707 .577 .707 r
F P
0 g
s
.68144 .62122 m .68496 .56403 L .71423 .56431 L p .707 .577 .707 r
F P
0 g
s
.67625 .72426 m .67414 .74338 L .65056 .74059 L p .707 .577 .707 r
F P
0 g
s
.65056 .74059 m .65268 .72147 L .67625 .72426 L p .707 .577 .707 r
F P
0 g
s
.46771 .70105 m .4656 .72017 L .48144 .72215 L p .707 .577 .707 r
F P
0 g
s
.48144 .72215 m .48355 .70304 L .46771 .70105 L p .707 .577 .707 r
F P
0 g
s
.304 .65631 m .3078 .61804 L .2949 .61615 L p .707 .577 .707 r
F P
0 g
s
.2949 .61615 m .2911 .65442 L .304 .65631 L p .707 .577 .707 r
F P
0 g
s
.71423 .56431 m .7107 .6215 L .68144 .62122 L p .707 .577 .707 r
F P
0 g
s
.80027 .6669 m .79646 .70517 L .76894 .7021 L p .707 .577 .707 r
F P
0 g
s
.76894 .7021 m .77274 .66384 L .80027 .6669 L p .707 .577 .707 r
F P
0 g
s
.77714 .5686 m .77361 .62579 L .74247 .62307 L p .707 .577 .707 r
F P
0 g
s
.74247 .62307 m .74599 .56588 L .77714 .5686 L p .707 .577 .707 r
F P
0 g
s
.49157 .55087 m .48804 .60806 L .49496 .60481 L p .707 .577 .707 r
F P
0 g
s
.49496 .60481 m .49849 .54762 L .49157 .55087 L p .707 .577 .707 r
F P
0 g
s
.29063 .68179 m .28852 .7009 L .30149 .70209 L p .707 .577 .707 r
F P
0 g
s
.30149 .70209 m .3036 .68298 L .29063 .68179 L p .707 .577 .707 r
F P
0 g
s
.7107 .6215 m .71423 .56431 L .74599 .56588 L p .707 .577 .707 r
F P
0 g
s
.67711 .69318 m .68091 .65492 L .70999 .65753 L p .707 .577 .707 r
F P
0 g
s
.70999 .65753 m .70619 .6958 L .67711 .69318 L p .707 .577 .707 r
F P
0 g
s
.79549 .73739 m .79337 .75651 L .76583 .7536 L p .707 .577 .707 r
F P
0 g
s
.76583 .7536 m .76794 .73448 L .79549 .73739 L p .707 .577 .707 r
F P
0 g
s
.74599 .56588 m .74247 .62307 L .7107 .6215 L p .707 .577 .707 r
F P
0 g
s
.29442 .59487 m .29795 .53768 L .29491 .53375 L p .707 .577 .707 r
F P
0 g
s
.70526 .72758 m .70315 .74669 L .67414 .74338 L p .707 .577 .707 r
F P
0 g
s
.67414 .74338 m .67625 .72426 L .70526 .72758 L p .707 .577 .707 r
F P
0 g
s
.77274 .66384 m .76894 .7021 L .73783 .69888 L p .707 .577 .707 r
F P
0 g
s
.73783 .69888 m .74163 .66061 L .77274 .66384 L p .707 .577 .707 r
F P
0 g
s
.48802 .63555 m .48422 .67381 L .49088 .67383 L p .707 .577 .707 r
F P
0 g
s
.49088 .67383 m .49468 .63556 L .48802 .63555 L p .707 .577 .707 r
F P
0 g
s
.29491 .53375 m .29138 .59094 L .29442 .59487 L p .707 .577 .707 r
F P
0 g
s
.70619 .6958 m .70999 .65753 L .74163 .66061 L p .707 .577 .707 r
F P
0 g
s
.74163 .66061 m .73783 .69888 L .70619 .6958 L p .707 .577 .707 r
F P
0 g
s
.76794 .73448 m .76583 .7536 L .73474 .75022 L p .707 .577 .707 r
F P
0 g
s
.73474 .75022 m .73686 .7311 L .76794 .73448 L p .707 .577 .707 r
F P
0 g
s
.48355 .70304 m .48144 .72215 L .488 .72314 L p .707 .577 .707 r
F P
0 g
s
.488 .72314 m .49011 .70403 L .48355 .70304 L p .707 .577 .707 r
F P
0 g
s
.2911 .65442 m .2949 .61615 L .29163 .61517 L p .707 .577 .707 r
F P
0 g
s
.73686 .7311 m .73474 .75022 L .70315 .74669 L p .707 .577 .707 r
F P
0 g
s
.70315 .74669 m .70526 .72758 L .73686 .7311 L p .707 .577 .707 r
F P
0 g
s
.29163 .61517 m .28782 .65344 L .2911 .65442 L p .707 .577 .707 r
F P
0 g
s
.49849 .54762 m .49496 .60481 L .49192 .60088 L p .707 .577 .707 r
F P
0 g
s
.49192 .60088 m .49545 .54369 L .49849 .54762 L p .707 .577 .707 r
F P
0 g
s
.28726 .68168 m .28515 .7008 L .28852 .7009 L p .707 .577 .707 r
F P
0 g
s
.28852 .7009 m .29063 .68179 L .28726 .68168 L p .707 .577 .707 r
F P
0 g
s
.29138 .59094 m .29491 .53375 L .30183 .5305 L p .707 .577 .707 r
F P
0 g
s
.49468 .63556 m .49088 .67383 L .4876 .67284 L p .707 .577 .707 r
F P
0 g
s
.4876 .67284 m .4914 .63457 L .49468 .63556 L p .707 .577 .707 r
F P
0 g
s
.30183 .5305 m .29831 .58769 L .29138 .59094 L p .707 .577 .707 r
F P
0 g
s
.49011 .70403 m .488 .72314 L .48463 .72304 L p .707 .577 .707 r
F P
0 g
s
.48463 .72304 m .48674 .70392 L .49011 .70403 L p .707 .577 .707 r
F P
0 g
s
.28782 .65344 m .29163 .61517 L .29829 .61518 L p .707 .577 .707 r
F P
0 g
s
.29829 .61518 m .29448 .65345 L .28782 .65344 L p .707 .577 .707 r
F P
0 g
s
.49545 .54369 m .49192 .60088 L .47921 .59666 L p .707 .577 .707 r
F P
0 g
s
.47921 .59666 m .48274 .53947 L .49545 .54369 L p .707 .577 .707 r
F P
0 g
s
.29382 .68267 m .29171 .70179 L .28515 .7008 L p .707 .577 .707 r
F P
0 g
s
.28515 .7008 m .28726 .68168 L .29382 .68267 L p .707 .577 .707 r
F P
0 g
s
.29831 .58769 m .30183 .5305 L .31804 .52825 L p .707 .577 .707 r
F P
0 g
s
.4914 .63457 m .4876 .67284 L .4747 .67096 L p .707 .577 .707 r
F P
0 g
s
.4747 .67096 m .4785 .63269 L .4914 .63457 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31804 .52825 m .31452 .58544 L .29831 .58769 L p .707 .577 .707 r
F P
0 g
s
.48674 .70392 m .48463 .72304 L .47166 .72185 L p .707 .577 .707 r
F P
0 g
s
.47166 .72185 m .47377 .70273 L .48674 .70392 L p .707 .577 .707 r
F P
0 g
s
.29448 .65345 m .29829 .61518 L .31423 .61619 L p .707 .577 .707 r
F P
0 g
s
.31423 .61619 m .31043 .65446 L .29448 .65345 L p .707 .577 .707 r
F P
0 g
s
.48274 .53947 m .47921 .59666 L .45809 .59255 L p .707 .577 .707 r
F P
0 g
s
.45809 .59255 m .46161 .53536 L .48274 .53947 L p .707 .577 .707 r
F P
0 g
s
.30966 .68466 m .30755 .70377 L .29171 .70179 L p .707 .577 .707 r
F P
0 g
s
.29171 .70179 m .29382 .68267 L .30966 .68466 L p .707 .577 .707 r
F P
0 g
s
.31452 .58544 m .31804 .52825 L .34195 .52721 L p .707 .577 .707 r
F P
0 g
s
.4785 .63269 m .4747 .67096 L .45345 .66835 L p .707 .577 .707 r
F P
0 g
s
.45345 .66835 m .45725 .63009 L .4785 .63269 L p .707 .577 .707 r
F P
0 g
s
.34195 .52721 m .33842 .5844 L .31452 .58544 L p .707 .577 .707 r
F P
0 g
s
.47377 .70273 m .47166 .72185 L .45036 .71969 L p .707 .577 .707 r
F P
0 g
s
.45036 .71969 m .45248 .70058 L .47377 .70273 L p .707 .577 .707 r
F P
0 g
s
.31043 .65446 m .31423 .61619 L .3379 .6181 L p .707 .577 .707 r
F P
0 g
s
.46161 .53536 m .45809 .59255 L .4306 .58897 L p .707 .577 .707 r
F P
0 g
s
.4306 .58897 m .43413 .53178 L .46161 .53536 L p .707 .577 .707 r
F P
0 g
s
.3379 .6181 m .3341 .65637 L .31043 .65446 L p .707 .577 .707 r
F P
0 g
s
.33842 .5844 m .34195 .52721 L .37122 .5275 L p .707 .577 .707 r
F P
0 g
s
.33324 .68745 m .33113 .70656 L .30755 .70377 L p .707 .577 .707 r
F P
0 g
s
.30755 .70377 m .30966 .68466 L .33324 .68745 L p .707 .577 .707 r
F P
0 g
s
.37122 .5275 m .36769 .58469 L .33842 .5844 L p .707 .577 .707 r
F P
0 g
s
.45725 .63009 m .45345 .66835 L .42593 .66529 L p .707 .577 .707 r
F P
0 g
s
.42593 .66529 m .42973 .62702 L .45725 .63009 L p .707 .577 .707 r
F P
0 g
s
.43413 .53178 m .4306 .58897 L .39945 .58626 L p .707 .577 .707 r
F P
0 g
s
.39945 .58626 m .40298 .52907 L .43413 .53178 L p .707 .577 .707 r
F P
0 g
s
.36769 .58469 m .37122 .5275 L .40298 .52907 L p .707 .577 .707 r
F P
0 g
s
.3341 .65637 m .3379 .6181 L .36698 .62072 L p .707 .577 .707 r
F P
0 g
s
.36698 .62072 m .36318 .65899 L .3341 .65637 L p .707 .577 .707 r
F P
0 g
s
.45248 .70058 m .45036 .71969 L .42282 .71678 L p .707 .577 .707 r
F P
0 g
s
.42282 .71678 m .42493 .69767 L .45248 .70058 L p .707 .577 .707 r
F P
0 g
s
.40298 .52907 m .39945 .58626 L .36769 .58469 L p .707 .577 .707 r
F P
0 g
s
.36225 .69076 m .36014 .70988 L .33113 .70656 L p .707 .577 .707 r
F P
0 g
s
.33113 .70656 m .33324 .68745 L .36225 .69076 L p .707 .577 .707 r
F P
0 g
s
.42973 .62702 m .42593 .66529 L .39482 .66206 L p .707 .577 .707 r
F P
0 g
s
.39482 .66206 m .39862 .62379 L .42973 .62702 L p .707 .577 .707 r
F P
0 g
s
.36318 .65899 m .36698 .62072 L .39862 .62379 L p .707 .577 .707 r
F P
0 g
s
.39862 .62379 m .39482 .66206 L .36318 .65899 L p .707 .577 .707 r
F P
0 g
s
.42493 .69767 m .42282 .71678 L .39173 .7134 L p .707 .577 .707 r
F P
0 g
s
.39173 .7134 m .39384 .69428 L .42493 .69767 L p .707 .577 .707 r
F P
0 g
s
.39384 .69428 m .39173 .7134 L .36014 .70988 L p .707 .577 .707 r
F P
0 g
s
.36014 .70988 m .36225 .69076 L .39384 .69428 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00N7oo5P00Sgoo001`Ool80004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH=0022Ool006]oo`D0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00AJEPT007Uoo`00JGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Lgoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF
1P00KGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEPH006Moo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEP00008006Aoo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80069oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065o
o`00JGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80065oo`00JGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HGoo
001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00HGoo001XOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0Ggoo001XOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
Ool0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HWoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIo
o`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1ROol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Moo`04001JEUYF0004FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001NOol70002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Eoo`T000=JEP04001JEUYFFUHC000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`<000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo7P00AGoo
001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP003eoo`00DWoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00P005YFFUH005YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPL003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF008000eJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0
039oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP800005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5
00001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo1@000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool005Yoo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
001QOol80004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP040000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool006=oo`04001JEUYF0002FUHP0005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0002eoo`00=goo40002goo1@0037oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02ioo`T000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`03001JEP00009JEPd0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000^Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP04001JEUYFFUH90009FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF001JEUYF5P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EQ0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000AJEP04
001JEUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH<0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000`003EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000017oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000Moo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000aooa80
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0001iooaH003=oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP/005moo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF4@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@0
05YFFUIJEQ0004moo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@00AWoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH90004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0002FUH01000FUIJEUYF2@000eYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000gOol0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEQH0
009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP08000_Ool002]oo`03001JEP00024000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP/00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP@000=JEPL000=JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH30003FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUHC0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo000^Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH200000eYF001JEP03FUH00`00FUIJEP0>00000eYF001JEP02FUH500000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000cOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF4@0000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF2`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool003Yoo`P000AJEP03001JEUYF00MJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUHG0004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[OolB0005
OolA0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP02FUH90003FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@002goo10000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPh0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000MJ
EP03001JEUYF00=JEP04001JEUYFFUH20002Ool90003FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH90006Ool=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P002goo20000eYF1`000eYF00@005YFFUIJEP8002mo
o`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200027oo300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000COolC000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH01000FUIJ
EUYF300015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000QOol5000_Ool002Yoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00
FUIJEP04FUH;0004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH70003FUH01000FUIJEUYF0P002Goo0`00BGoo
000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH00UYF2P000eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001P001EYF10000eYF0P0027oo1@00B7oo000ZOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0800000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00
FUH005YF001JEPh00003FUH0000000Qoo`D004Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00AJEP04001JEUYFFUH90003Ool50018Ool002Yoo`03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004Moo`00:Woo1@000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?goo000[OolA
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF2P00=Goo000bOol7
0003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000020000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH02000<7oo000iOol90003FUH90004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040004Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02000`Ool0049oo`T000=JEPP000=JEP03001JEUYF00=JEP05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF1`0017oo2@0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo001;OolF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH0
20001Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80031oo`00:Woo2000
:Goo1P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000=Ool80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo
000ZOol00`00FUH00002FUH:000WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000MJEP03001JEUYF00=JEP04001JEUYFFUH2000EOol<0002FUH2000`Ool002Yoo`03
001JEP0000AJEP03001JEUYF010001aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP80025oo`@0031oo`00:Woo0P001EYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@004goo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00EGoo000ZOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30000UYF00@005YFFUIJEQh000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0005Eoo`00:goo2@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@000UYF100025YF00<005YFFUH025YF00<0
05YFFUH025YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol003Aoo`L000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00EWoo000kOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH70006FUH00`00FUIJEP02FUH00`00FUH000040004FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00EWoo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000035YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF
00<005YFFUH00UYF00@005YF000000=JEPL000=JEP04001JEUYFFUH2001FOol004eoo`P000AJEP03
001JEUYF00=JEP03001JEUYF00<000YJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEPD000=JEP04001JEP00OolC001FOol005Eoo``00004FUH0
0000Ool40006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP003goo1@00EWoo001QOol30005Ool40002
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH200000eYF001oo`1YOol006eoo`P000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00001ZOol007Eoo`/0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD006Uoo`00
P7oo3@001UYF00<005YFFUH02EYF00<005YFFUH00UYF6000HGoo002;OolI0006FUH00`00FUIJEP06
FUH01000FUIJEUYF3@00FGoo002?Ool90008FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00002001GOol009Uoo`P000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF008005Moo`00XGoo3@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Moo`00Zgoo2`0015YF00<005YFFUH00eYF00@005YFFUIJEP80
05Moo`00]7oo2@000eYF00@005YFFUIJEP8005Moo`00_Goo2@00Egoo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59389 .73986 m .59607 .6831 L .56491 .6807 L p .707 .577 .707 r
F P
0 g
s
.59607 .6831 m .59389 .73986 L .6257 .74053 L p .707 .577 .707 r
F P
0 g
s
.6257 .74053 m .62788 .68377 L .59607 .6831 L p .707 .577 .707 r
F P
0 g
s
.62788 .68377 m .6257 .74053 L .65503 .7394 L p .707 .577 .707 r
F P
0 g
s
.65503 .7394 m .65722 .68264 L .62788 .68377 L p .707 .577 .707 r
F P
0 g
s
.56273 .73746 m .56491 .6807 L .53744 .67681 L p .707 .577 .707 r
F P
0 g
s
.56491 .6807 m .56273 .73746 L .59389 .73986 L p .707 .577 .707 r
F P
0 g
s
.59183 .7936 m .5942 .75547 L .56305 .75275 L p .707 .577 .707 r
F P
0 g
s
.5942 .75547 m .59183 .7936 L .62359 .79519 L p .707 .577 .707 r
F P
0 g
s
.62359 .79519 m .62596 .75706 L .5942 .75547 L p .707 .577 .707 r
F P
0 g
s
.65722 .68264 m .65503 .7394 L .67903 .73658 L p .707 .577 .707 r
F P
0 g
s
.67903 .73658 m .68122 .67983 L .65722 .68264 L p .707 .577 .707 r
F P
0 g
s
.53744 .67681 m .53526 .73356 L .56273 .73746 L p .707 .577 .707 r
F P
0 g
s
.62596 .75706 m .62359 .79519 L .65286 .7955 L p .707 .577 .707 r
F P
0 g
s
.65286 .7955 m .65522 .75737 L .62596 .75706 L p .707 .577 .707 r
F P
0 g
s
.56305 .75275 m .56068 .79088 L .59183 .7936 L p .707 .577 .707 r
F P
0 g
s
.56068 .79088 m .56305 .75275 L .53557 .74918 L p .707 .577 .707 r
F P
0 g
s
.53526 .73356 m .53744 .67681 L .51636 .6718 L p .707 .577 .707 r
F P
0 g
s
.59024 .83212 m .59156 .81303 L .56042 .81022 L p .707 .577 .707 r
F P
0 g
s
.59156 .81303 m .59024 .83212 L .62198 .83399 L p .707 .577 .707 r
F P
0 g
s
.62198 .83399 m .6233 .81489 L .59156 .81303 L p .707 .577 .707 r
F P
0 g
s
.56042 .81022 m .5591 .82931 L .59024 .83212 L p .707 .577 .707 r
F P
0 g
s
.53557 .74918 m .5332 .78731 L .56068 .79088 L p .707 .577 .707 r
F P
0 g
s
.6233 .81489 m .62198 .83399 L .65122 .83472 L p .707 .577 .707 r
F P
0 g
s
.65122 .83472 m .65254 .81563 L .6233 .81489 L p .707 .577 .707 r
F P
0 g
s
.5591 .82931 m .56042 .81022 L .53293 .80673 L p .707 .577 .707 r
F P
0 g
s
.65522 .75737 m .65286 .7955 L .67676 .79449 L p .707 .577 .707 r
F P
0 g
s
.67676 .79449 m .67913 .75636 L .65522 .75737 L p .707 .577 .707 r
F P
0 g
s
.51636 .6718 m .51417 .72856 L .53526 .73356 L p .707 .577 .707 r
F P
0 g
s
.53293 .80673 m .53161 .82583 L .5591 .82931 L p .707 .577 .707 r
F P
0 g
s
.68122 .67983 m .67903 .73658 L .69534 .73236 L p .707 .577 .707 r
F P
0 g
s
.69534 .73236 m .69753 .6756 L .68122 .67983 L p .707 .577 .707 r
F P
0 g
s
.5332 .78731 m .53557 .74918 L .51444 .74509 L p .707 .577 .707 r
F P
0 g
s
.65254 .81563 m .65122 .83472 L .67509 .83426 L p .707 .577 .707 r
F P
0 g
s
.67509 .83426 m .67641 .81517 L .65254 .81563 L p .707 .577 .707 r
F P
0 g
s
.51444 .74509 m .51207 .78322 L .5332 .78731 L p .707 .577 .707 r
F P
0 g
s
.51417 .72856 m .51636 .6718 L .50372 .66616 L p .707 .577 .707 r
F P
0 g
s
.53161 .82583 m .53293 .80673 L .51178 .80292 L p .707 .577 .707 r
F P
0 g
s
.51178 .80292 m .51046 .82202 L .53161 .82583 L p .707 .577 .707 r
F P
0 g
s
.67913 .75636 m .67676 .79449 L .69297 .79227 L p .707 .577 .707 r
F P
0 g
s
.69297 .79227 m .69534 .75414 L .67913 .75636 L p .707 .577 .707 r
F P
0 g
s
.50372 .66616 m .50154 .72292 L .51417 .72856 L p .707 .577 .707 r
F P
0 g
s
.51207 .78322 m .51444 .74509 L .50173 .74089 L p .707 .577 .707 r
F P
0 g
s
.67641 .81517 m .67509 .83426 L .69126 .83264 L p .707 .577 .707 r
F P
0 g
s
.69126 .83264 m .69258 .81355 L .67641 .81517 L p .707 .577 .707 r
F P
0 g
s
.69753 .6756 m .69534 .73236 L .70236 .72714 L p .707 .577 .707 r
F P
0 g
s
.70236 .72714 m .70455 .67038 L .69753 .6756 L p .707 .577 .707 r
F P
0 g
s
.50173 .74089 m .49936 .77902 L .51207 .78322 L p .707 .577 .707 r
F P
0 g
s
.51046 .82202 m .51178 .80292 L .49904 .79916 L p .707 .577 .707 r
F P
0 g
s
.49904 .79916 m .49772 .81825 L .51046 .82202 L p .707 .577 .707 r
F P
0 g
s
.50154 .72292 m .50372 .66616 L .50077 .66046 L p .707 .577 .707 r
F P
0 g
s
.69534 .75414 m .69297 .79227 L .69989 .78906 L p .707 .577 .707 r
F P
0 g
s
.69989 .78906 m .70226 .75093 L .69534 .75414 L p .707 .577 .707 r
F P
0 g
s
.50077 .66046 m .49859 .71722 L .50154 .72292 L p .707 .577 .707 r
F P
0 g
s
.69258 .81355 m .69126 .83264 L .69814 .83003 L p .707 .577 .707 r
F P
0 g
s
.69814 .83003 m .69946 .81094 L .69258 .81355 L p .707 .577 .707 r
F P
0 g
s
.49936 .77902 m .50173 .74089 L .49869 .73699 L p .707 .577 .707 r
F P
0 g
s
.70455 .67038 m .70236 .72714 L .69941 .72144 L p .707 .577 .707 r
F P
0 g
s
.69941 .72144 m .7016 .66468 L .70455 .67038 L p .707 .577 .707 r
F P
0 g
s
.49869 .73699 m .49632 .77512 L .49936 .77902 L p .707 .577 .707 r
F P
0 g
s
.49772 .81825 m .49904 .79916 L .49596 .7958 L p .707 .577 .707 r
F P
0 g
s
.49596 .7958 m .49465 .81489 L .49772 .81825 L p .707 .577 .707 r
F P
0 g
s
.49859 .71722 m .50077 .66046 L .50779 .65524 L p .707 .577 .707 r
F P
0 g
s
.70226 .75093 m .69989 .78906 L .69685 .78516 L p .707 .577 .707 r
F P
0 g
s
.69685 .78516 m .69922 .74703 L .70226 .75093 L p .707 .577 .707 r
F P
0 g
s
.50779 .65524 m .50561 .712 L .49859 .71722 L p .707 .577 .707 r
F P
0 g
s
.69946 .81094 m .69814 .83003 L .69506 .82667 L p .707 .577 .707 r
F P
0 g
s
.69506 .82667 m .69638 .80758 L .69946 .81094 L p .707 .577 .707 r
F P
0 g
s
.49632 .77512 m .49869 .73699 L .50561 .73378 L p .707 .577 .707 r
F P
0 g
s
.48023 .8138 m .50009 .30124 L .45609 .29785 L p .707 .577 .707 r
F P
0 g
s
.50561 .73378 m .50324 .77191 L .49632 .77512 L p .707 .577 .707 r
F P
0 g
s
.49465 .81489 m .49596 .7958 L .50285 .79319 L p .707 .577 .707 r
F P
0 g
s
.50285 .79319 m .50153 .81228 L .49465 .81489 L p .707 .577 .707 r
F P
0 g
s
.50561 .712 m .50779 .65524 L .5241 .65102 L p .707 .577 .707 r
F P
0 g
s
.5241 .65102 m .52192 .70777 L .50561 .712 L p .707 .577 .707 r
F P
0 g
s
.50324 .77191 m .50561 .73378 L .52181 .73156 L p .707 .577 .707 r
F P
0 g
s
.52181 .73156 m .51945 .76969 L .50324 .77191 L p .707 .577 .707 r
F P
0 g
s
.50153 .81228 m .50285 .79319 L .51901 .79157 L p .707 .577 .707 r
F P
0 g
s
.51901 .79157 m .51769 .81066 L .50153 .81228 L p .707 .577 .707 r
F P
0 g
s
.51945 .76969 m .52181 .73156 L .54572 .73056 L p .707 .577 .707 r
F P
0 g
s
.54572 .73056 m .54335 .76869 L .51945 .76969 L p .707 .577 .707 r
F P
0 g
s
.51769 .81066 m .51901 .79157 L .54288 .79111 L p .707 .577 .707 r
F P
0 g
s
.54288 .79111 m .54157 .8102 L .51769 .81066 L p .707 .577 .707 r
F P
0 g
s
.50009 .30124 m .48023 .8138 L .52514 .81475 L p .707 .577 .707 r
F P
0 g
s
.52192 .70777 m .5241 .65102 L .5481 .6482 L p .707 .577 .707 r
F P
0 g
s
.5481 .6482 m .54591 .70496 L .52192 .70777 L p .707 .577 .707 r
F P
0 g
s
.52514 .81475 m .54499 .3022 L .50009 .30124 L p .707 .577 .707 r
F P
0 g
s
.7016 .66468 m .69941 .72144 L .68677 .7158 L p .707 .577 .707 r
F P
0 g
s
.68677 .7158 m .68896 .65904 L .7016 .66468 L p .707 .577 .707 r
F P
0 g
s
.54591 .70496 m .5481 .6482 L .57744 .64707 L p .707 .577 .707 r
F P
0 g
s
.57744 .64707 m .57525 .70383 L .54591 .70496 L p .707 .577 .707 r
F P
0 g
s
.54335 .76869 m .54555 .73329 L p .57499 .73086 L .707 .577 .707 r
F P
0 g
s
.54555 .73329 m .54572 .73056 L .54596 .73056 L p .707 .577 .707 r
F P
0 g
s
.54596 .73056 m .57499 .73086 L p .54555 .73329 L .707 .577 .707 r
F P
0 g
s
.57525 .70383 m .57744 .64707 L .60925 .64774 L p .707 .577 .707 r
F P
0 g
s
.60925 .64774 m .60706 .7045 L .57525 .70383 L p .707 .577 .707 r
F P
0 g
s
.57499 .73086 m .57262 .76899 L .54335 .76869 L p .707 .577 .707 r
F P
0 g
s
.54157 .8102 m .54288 .79111 L .57212 .79184 L p .707 .577 .707 r
F P
0 g
s
.57212 .79184 m .5708 .81094 L .54157 .8102 L p .707 .577 .707 r
F P
0 g
s
.57262 .76899 m .57499 .73086 L .60675 .73245 L p .707 .577 .707 r
F P
0 g
s
.60675 .73245 m .60438 .77058 L .57262 .76899 L p .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57212 .79184 L .57817 .7922 L p .707 .577 .707 r
F P
0 g
s
.57817 .7922 m .60386 .79371 L p .57684 .80779 L .707 .577 .707 r
F P
0 g
s
.5708 .81094 m .57817 .7922 L .57684 .80779 L .707 .577 .707 r
F
.64041 .65014 m .63822 .7069 L .60706 .7045 L p F P
0 g
s
.60706 .7045 m .60925 .64774 L .64041 .65014 L p .707 .577 .707 r
F P
0 g
s
.63789 .73517 m .63553 .7733 L .60438 .77058 L p .707 .577 .707 r
F P
0 g
s
.60438 .77058 m .60675 .73245 L .63789 .73517 L p .707 .577 .707 r
F P
0 g
s
.63501 .79652 m .63369 .81561 L .60255 .8128 L p .707 .577 .707 r
F P
0 g
s
.60255 .8128 m .60386 .79371 L .63501 .79652 L p .707 .577 .707 r
F P
0 g
s
.60386 .79371 m .60255 .8128 L .5708 .81094 L p .707 .577 .707 r
F P
0 g
s
.60044 .80923 m .62346 .80329 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62029 .29667 m .62022 .29825 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.62022 .29825 m .60044 .80923 L p .62029 .29748 L .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .60044 .80923 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.58641 .30062 m .57816 .51356 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.57816 .51356 m .56656 .81318 L p .59007 .43333 L .707 .577 .707 r
F P
0 g
s
.54499 .3022 m .52514 .81475 L .56656 .81318 L p .707 .577 .707 r
F P
0 g
s
.56656 .81318 m .58641 .30062 L .54499 .3022 L p .707 .577 .707 r
F P
0 g
s
.25088 .70304 m .25307 .64628 L .2219 .64389 L p .707 .577 .707 r
F P
0 g
s
.25307 .64628 m .25088 .70304 L .28269 .70371 L p .707 .577 .707 r
F P
0 g
s
.28269 .70371 m .28487 .64695 L .25307 .64628 L p .707 .577 .707 r
F P
0 g
s
.43624 .81041 m .45609 .29785 L .41731 .29236 L p .707 .577 .707 r
F P
0 g
s
.45609 .29785 m .43624 .81041 L .48023 .8138 L p .707 .577 .707 r
F P
0 g
s
.28487 .64695 m .28269 .70371 L .31203 .70258 L p .707 .577 .707 r
F P
0 g
s
.31203 .70258 m .31421 .64582 L .28487 .64695 L p .707 .577 .707 r
F P
0 g
s
.21972 .70064 m .2219 .64389 L .19444 .63999 L p .707 .577 .707 r
F P
0 g
s
.2219 .64389 m .21972 .70064 L .25088 .70304 L p .707 .577 .707 r
F P
0 g
s
.69922 .74703 m .69685 .78516 L .68414 .78096 L p .707 .577 .707 r
F P
0 g
s
.68414 .78096 m .68651 .74283 L .69922 .74703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60044 .80923 m .62029 .29667 L .58641 .30062 L p .707 .577 .707 r
F P
0 g
s
.24882 .75679 m .25119 .71865 L .22004 .71594 L p .707 .577 .707 r
F P
0 g
s
.25119 .71865 m .24882 .75679 L .28058 .75837 L p .707 .577 .707 r
F P
0 g
s
.28058 .75837 m .28295 .72024 L .25119 .71865 L p .707 .577 .707 r
F P
0 g
s
.31421 .64582 m .31203 .70258 L .33602 .69977 L p .707 .577 .707 r
F P
0 g
s
.33602 .69977 m .33821 .64301 L .31421 .64582 L p .707 .577 .707 r
F P
0 g
s
.19444 .63999 m .19225 .69675 L .21972 .70064 L p .707 .577 .707 r
F P
0 g
s
.28295 .72024 m .28058 .75837 L .30985 .75868 L p .707 .577 .707 r
F P
0 g
s
.30985 .75868 m .31222 .72055 L .28295 .72024 L p .707 .577 .707 r
F P
0 g
s
.22004 .71594 m .21767 .75407 L .24882 .75679 L p .707 .577 .707 r
F P
0 g
s
.69638 .80758 m .69506 .82667 L .68232 .82291 L p .707 .577 .707 r
F P
0 g
s
.68232 .82291 m .68364 .80381 L .69638 .80758 L p .707 .577 .707 r
F P
0 g
s
.21767 .75407 m .22004 .71594 L .19256 .71236 L p .707 .577 .707 r
F P
0 g
s
.68896 .65904 m .68677 .7158 L .66569 .71079 L p .707 .577 .707 r
F P
0 g
s
.66569 .71079 m .66788 .65403 L .68896 .65904 L p .707 .577 .707 r
F P
0 g
s
.19225 .69675 m .19444 .63999 L .17335 .63498 L p .707 .577 .707 r
F P
0 g
s
.39746 .80491 m .41731 .29236 L .38755 .2853 L p .707 .577 .707 r
F P
0 g
s
.41731 .29236 m .39746 .80491 L .43624 .81041 L p .707 .577 .707 r
F P
0 g
s
.24723 .7953 m .24855 .77621 L .21741 .7734 L p .707 .577 .707 r
F P
0 g
s
.24855 .77621 m .24723 .7953 L .27897 .79717 L p .707 .577 .707 r
F P
0 g
s
.27897 .79717 m .28029 .77808 L .24855 .77621 L p .707 .577 .707 r
F P
0 g
s
.21741 .7734 m .21609 .79249 L .24723 .7953 L p .707 .577 .707 r
F P
0 g
s
.19256 .71236 m .19019 .75049 L .21767 .75407 L p .707 .577 .707 r
F P
0 g
s
.28029 .77808 m .27897 .79717 L .30821 .79791 L p .707 .577 .707 r
F P
0 g
s
.30821 .79791 m .30953 .77881 L .28029 .77808 L p .707 .577 .707 r
F P
0 g
s
.21609 .79249 m .21741 .7734 L .18992 .76992 L p .707 .577 .707 r
F P
0 g
s
.31222 .72055 m .30985 .75868 L .33376 .75768 L p .707 .577 .707 r
F P
0 g
s
.33376 .75768 m .33612 .71955 L .31222 .72055 L p .707 .577 .707 r
F P
0 g
s
.17335 .63498 m .17117 .69174 L .19225 .69675 L p .707 .577 .707 r
F P
0 g
s
.18992 .76992 m .1886 .78901 L .21609 .79249 L p .707 .577 .707 r
F P
0 g
s
.33821 .64301 m .33602 .69977 L .35233 .69555 L p .707 .577 .707 r
F P
0 g
s
.35233 .69555 m .35452 .63879 L .33821 .64301 L p .707 .577 .707 r
F P
0 g
s
.19019 .75049 m .19256 .71236 L .17143 .70827 L p .707 .577 .707 r
F P
0 g
s
.68651 .74283 m .68414 .78096 L .66301 .77688 L p .707 .577 .707 r
F P
0 g
s
.66301 .77688 m .66538 .73874 L .68651 .74283 L p .707 .577 .707 r
F P
0 g
s
.30953 .77881 m .30821 .79791 L .33208 .79745 L p .707 .577 .707 r
F P
0 g
s
.33208 .79745 m .3334 .77835 L .30953 .77881 L p .707 .577 .707 r
F P
0 g
s
.17143 .70827 m .16906 .7464 L .19019 .75049 L p .707 .577 .707 r
F P
0 g
s
.62346 .80329 m .64331 .29074 L .62029 .29667 L p .707 .577 .707 r
F P
0 g
s
.66788 .65403 m .66569 .71079 L .63822 .7069 L p .707 .577 .707 r
F P
0 g
s
.63822 .7069 m .64041 .65014 L .66788 .65403 L p .707 .577 .707 r
F P
0 g
s
.17117 .69174 m .17335 .63498 L .16072 .62935 L p .707 .577 .707 r
F P
0 g
s
.1886 .78901 m .18992 .76992 L .16877 .76611 L p .707 .577 .707 r
F P
0 g
s
.16877 .76611 m .16745 .7852 L .1886 .78901 L p .707 .577 .707 r
F P
0 g
s
.68364 .80381 m .68232 .82291 L .66118 .8191 L p .707 .577 .707 r
F P
0 g
s
.66118 .8191 m .6625 .8 L .68364 .80381 L p .707 .577 .707 r
F P
0 g
s
.33612 .71955 m .33376 .75768 L .34996 .75546 L p .707 .577 .707 r
F P
0 g
s
.34996 .75546 m .35233 .71733 L .33612 .71955 L p .707 .577 .707 r
F P
0 g
s
.16072 .62935 m .15853 .68611 L .17117 .69174 L p .707 .577 .707 r
F P
0 g
s
.3677 .79785 m .38755 .2853 L .36971 .27736 L p .707 .577 .707 r
F P
0 g
s
.38755 .2853 m .3677 .79785 L .39746 .80491 L p .707 .577 .707 r
F P
0 g
s
.16906 .7464 m .17143 .70827 L .15872 .70408 L p .707 .577 .707 r
F P
0 g
s
.3334 .77835 m .33208 .79745 L .34825 .79583 L p .707 .577 .707 r
F P
0 g
s
.34825 .79583 m .34957 .77673 L .3334 .77835 L p .707 .577 .707 r
F P
0 g
s
.66538 .73874 m .66301 .77688 L .63553 .7733 L p .707 .577 .707 r
F P
0 g
s
.63553 .7733 m .63789 .73517 L .66538 .73874 L p .707 .577 .707 r
F P
0 g
s
.35452 .63879 m .35233 .69555 L .35935 .69033 L p .707 .577 .707 r
F P
0 g
s
.35935 .69033 m .36154 .63357 L .35452 .63879 L p .707 .577 .707 r
F P
0 g
s
.15872 .70408 m .15635 .74221 L .16906 .7464 L p .707 .577 .707 r
F P
0 g
s
.16745 .7852 m .16877 .76611 L .15603 .76234 L p .707 .577 .707 r
F P
0 g
s
.15603 .76234 m .15471 .78143 L .16745 .7852 L p .707 .577 .707 r
F P
0 g
s
.6625 .8 m .66118 .8191 L .63369 .81561 L p .707 .577 .707 r
F P
0 g
s
.63369 .81561 m .63501 .79652 L .6625 .8 L p .707 .577 .707 r
F P
0 g
s
.15853 .68611 m .16072 .62935 L .15776 .62364 L p .707 .577 .707 r
F P
0 g
s
.35233 .71733 m .34996 .75546 L .35688 .75224 L p .707 .577 .707 r
F P
0 g
s
.35688 .75224 m .35925 .71411 L .35233 .71733 L p .707 .577 .707 r
F P
0 g
s
.64331 .29074 m .62346 .80329 L .63337 .79595 L p .707 .577 .707 r
F P
0 g
s
.63337 .79595 m .65322 .28339 L .64331 .29074 L p .707 .577 .707 r
F P
0 g
s
.15776 .62364 m .15558 .6804 L .15853 .68611 L p .707 .577 .707 r
F P
0 g
s
.34957 .77673 m .34825 .79583 L .35513 .79321 L p .707 .577 .707 r
F P
0 g
s
.35513 .79321 m .35645 .77412 L .34957 .77673 L p .707 .577 .707 r
F P
0 g
s
.15635 .74221 m .15872 .70408 L .15568 .70018 L p .707 .577 .707 r
F P
0 g
s
.36154 .63357 m .35935 .69033 L .3564 .68462 L p .707 .577 .707 r
F P
0 g
s
.3564 .68462 m .35859 .62786 L .36154 .63357 L p .707 .577 .707 r
F P
0 g
s
.15568 .70018 m .15331 .73831 L .15635 .74221 L p .707 .577 .707 r
F P
0 g
s
.35859 .62786 m .3564 .68462 L .34376 .67899 L p .707 .577 .707 r
F P
0 g
s
.34376 .67899 m .34595 .62223 L .35859 .62786 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .34113 .74415 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35621 .71021 m .35604 .71295 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.35604 .71295 m .35384 .74835 L p .3561 .71046 L .707 .577 .707 r
F P
0 g
s
.34113 .74415 m .3435 .70602 L .35621 .71021 L p .707 .577 .707 r
F P
0 g
s
.35337 .77077 m .35205 .78986 L .33932 .78609 L p .707 .577 .707 r
F P
0 g
s
.33932 .78609 m .34063 .767 L .35337 .77077 L p .707 .577 .707 r
F P
0 g
s
.34986 .78992 m .36146 .4903 L p .36554 .26933 L .707 .577 .707 r
F P
0 g
s
.36146 .4903 m .36971 .27736 L .36678 .27173 L p .707 .577 .707 r
F P
0 g
s
.36678 .27173 m .36554 .26933 L p .36146 .4903 L .707 .577 .707 r
F P
0 g
s
.35925 .71411 m .35688 .75224 L .35384 .74835 L p .707 .577 .707 r
F P
0 g
s
.35384 .74835 m .35621 .71021 L .35925 .71411 L p .707 .577 .707 r
F P
0 g
s
.35645 .77412 m .35513 .79321 L .35205 .78986 L p .707 .577 .707 r
F P
0 g
s
.35205 .78986 m .35337 .77077 L .35645 .77412 L p .707 .577 .707 r
F P
0 g
s
.36971 .27736 m .34986 .78992 L .3677 .79785 L p .707 .577 .707 r
F P
0 g
s
.15471 .78143 m .15603 .76234 L .15295 .75898 L p .707 .577 .707 r
F P
0 g
s
.15295 .75898 m .15164 .77808 L .15471 .78143 L p .707 .577 .707 r
F P
0 g
s
.15558 .6804 m .15776 .62364 L .16479 .61842 L p .707 .577 .707 r
F P
0 g
s
.16479 .61842 m .1626 .67518 L .15558 .6804 L p .707 .577 .707 r
F P
0 g
s
.15331 .73831 m .15568 .70018 L .1626 .69696 L p .707 .577 .707 r
F P
0 g
s
.65322 .28339 m .63337 .79595 L .6292 .78791 L p .707 .577 .707 r
F P
0 g
s
.6292 .78791 m .64905 .27536 L .65322 .28339 L p .707 .577 .707 r
F P
0 g
s
.1626 .69696 m .16023 .73509 L .15331 .73831 L p .707 .577 .707 r
F P
0 g
s
.15164 .77808 m .15295 .75898 L .15984 .75637 L p .707 .577 .707 r
F P
0 g
s
.15984 .75637 m .15852 .77546 L .15164 .77808 L p .707 .577 .707 r
F P
0 g
s
.1626 .67518 m .16479 .61842 L .18109 .6142 L p .707 .577 .707 r
F P
0 g
s
.36554 .26933 m .34569 .78189 L .34986 .78992 L p .707 .577 .707 r
F P
0 g
s
.34569 .78189 m .36554 .26933 L .37545 .26199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18109 .6142 m .17891 .67096 L .1626 .67518 L p .707 .577 .707 r
F P
0 g
s
.16023 .73509 m .1626 .69696 L .1788 .69474 L p .707 .577 .707 r
F P
0 g
s
.34595 .62223 m .34376 .67899 L .32268 .67398 L p .707 .577 .707 r
F P
0 g
s
.32268 .67398 m .32487 .61722 L .34595 .62223 L p .707 .577 .707 r
F P
0 g
s
.1788 .69474 m .17644 .73288 L .16023 .73509 L p .707 .577 .707 r
F P
0 g
s
.15852 .77546 m .15984 .75637 L .176 .75475 L p .707 .577 .707 r
F P
0 g
s
.17891 .67096 m .18109 .6142 L .20509 .61139 L p .707 .577 .707 r
F P
0 g
s
.176 .75475 m .17468 .77385 L .15852 .77546 L p .707 .577 .707 r
F P
0 g
s
.64905 .27536 m .6292 .78791 L .61136 .77998 L p .707 .577 .707 r
F P
0 g
s
.61136 .77998 m .63121 .26742 L .64905 .27536 L p .707 .577 .707 r
F P
0 g
s
.3435 .70602 m .34113 .74415 L .32 .74006 L p .707 .577 .707 r
F P
0 g
s
.32 .74006 m .32237 .70193 L .3435 .70602 L p .707 .577 .707 r
F P
0 g
s
.20509 .61139 m .2029 .66815 L .17891 .67096 L p .707 .577 .707 r
F P
0 g
s
.32487 .61722 m .32268 .67398 L .29521 .67008 L p .707 .577 .707 r
F P
0 g
s
.29521 .67008 m .2974 .61333 L .32487 .61722 L p .707 .577 .707 r
F P
0 g
s
.17644 .73288 m .1788 .69474 L .20271 .69374 L p .707 .577 .707 r
F P
0 g
s
.34063 .767 m .33932 .78609 L .31817 .78228 L p .707 .577 .707 r
F P
0 g
s
.31817 .78228 m .31949 .76319 L .34063 .767 L p .707 .577 .707 r
F P
0 g
s
.2029 .66815 m .20509 .61139 L .23443 .61026 L p .707 .577 .707 r
F P
0 g
s
.20271 .69374 m .20034 .73187 L .17644 .73288 L p .707 .577 .707 r
F P
0 g
s
.3556 .77454 m .37545 .26199 L .39847 .25605 L p .707 .577 .707 r
F P
0 g
s
.37545 .26199 m .3556 .77454 L .34569 .78189 L p .707 .577 .707 r
F P
0 g
s
.17468 .77385 m .176 .75475 L .19987 .75429 L p .707 .577 .707 r
F P
0 g
s
.19987 .75429 m .19856 .77338 L .17468 .77385 L p .707 .577 .707 r
F P
0 g
s
.2974 .61333 m .29521 .67008 L .26405 .66769 L p .707 .577 .707 r
F P
0 g
s
.26405 .66769 m .26624 .61093 L .2974 .61333 L p .707 .577 .707 r
F P
0 g
s
.23443 .61026 m .23224 .66702 L .2029 .66815 L p .707 .577 .707 r
F P
0 g
s
.32237 .70193 m .32 .74006 L .29252 .73648 L p .707 .577 .707 r
F P
0 g
s
.29252 .73648 m .29489 .69835 L .32237 .70193 L p .707 .577 .707 r
F P
0 g
s
.23224 .66702 m .23443 .61026 L .26624 .61093 L p .707 .577 .707 r
F P
0 g
s
.73109 .65071 m .73328 .59395 L .70212 .59155 L p .707 .577 .707 r
F P
0 g
s
.73328 .59395 m .73109 .65071 L .7629 .65138 L p .707 .577 .707 r
F P
0 g
s
.7629 .65138 m .76509 .59462 L .73328 .59395 L p .707 .577 .707 r
F P
0 g
s
.26624 .61093 m .26405 .66769 L .23224 .66702 L p .707 .577 .707 r
F P
0 g
s
.20034 .73187 m .20271 .69374 L .23198 .69405 L p .707 .577 .707 r
F P
0 g
s
.76509 .59462 m .7629 .65138 L .79224 .65025 L p .707 .577 .707 r
F P
0 g
s
.79224 .65025 m .79442 .59349 L .76509 .59462 L p .707 .577 .707 r
F P
0 g
s
.31949 .76319 m .31817 .78228 L .29068 .7788 L p .707 .577 .707 r
F P
0 g
s
.29068 .7788 m .292 .75971 L .31949 .76319 L p .707 .577 .707 r
F P
0 g
s
.69993 .64831 m .70212 .59155 L .67465 .58766 L p .707 .577 .707 r
F P
0 g
s
.70212 .59155 m .69993 .64831 L .73109 .65071 L p .707 .577 .707 r
F P
0 g
s
.23198 .69405 m .22961 .73218 L .20034 .73187 L p .707 .577 .707 r
F P
0 g
s
.63121 .26742 m .61136 .77998 L .5816 .77292 L p .707 .577 .707 r
F P
0 g
s
.5816 .77292 m .60145 .26036 L .63121 .26742 L p .707 .577 .707 r
F P
0 g
s
.29489 .69835 m .29252 .73648 L .26137 .73377 L p .707 .577 .707 r
F P
0 g
s
.26137 .73377 m .26374 .69564 L .29489 .69835 L p .707 .577 .707 r
F P
0 g
s
.19856 .77338 m .19987 .75429 L .22911 .75503 L p .707 .577 .707 r
F P
0 g
s
.22911 .75503 m .22779 .77412 L .19856 .77338 L p .707 .577 .707 r
F P
0 g
s
.22961 .73218 m .23198 .69405 L .26374 .69564 L p .707 .577 .707 r
F P
0 g
s
.79442 .59349 m .79224 .65025 L .81624 .64743 L p .707 .577 .707 r
F P
0 g
s
.81624 .64743 m .81842 .59068 L .79442 .59349 L p .707 .577 .707 r
F P
0 g
s
.72903 .70831 m .7314 .67018 L .70026 .66746 L p .707 .577 .707 r
F P
0 g
s
.7314 .67018 m .72903 .70831 L .7608 .7099 L p .707 .577 .707 r
F P
0 g
s
.7608 .7099 m .76316 .67177 L .7314 .67018 L p .707 .577 .707 r
F P
0 g
s
.67465 .58766 m .67246 .64441 L .69993 .64831 L p .707 .577 .707 r
F P
0 g
s
.26374 .69564 m .26137 .73377 L .22961 .73218 L p .707 .577 .707 r
F P
0 g
s
.76316 .67177 m .7608 .7099 L .79006 .7102 L p .707 .577 .707 r
F P
0 g
s
.79006 .7102 m .79243 .67207 L .76316 .67177 L p .707 .577 .707 r
F P
0 g
s
.70026 .66746 m .69789 .70559 L .72903 .70831 L p .707 .577 .707 r
F P
0 g
s
.292 .75971 m .29068 .7788 L .25954 .77599 L p .707 .577 .707 r
F P
0 g
s
.25954 .77599 m .26086 .75689 L .292 .75971 L p .707 .577 .707 r
F P
0 g
s
.67246 .64441 m .67465 .58766 L .65356 .58265 L p .707 .577 .707 r
F P
0 g
s
.69789 .70559 m .70026 .66746 L .67277 .66388 L p .707 .577 .707 r
F P
0 g
s
.39847 .25605 m .37862 .76861 L .3556 .77454 L p .707 .577 .707 r
F P
0 g
s
.37862 .76861 m .39847 .25605 L .43235 .2521 L p .707 .577 .707 r
F P
0 g
s
.22779 .77412 m .22911 .75503 L .26086 .75689 L p .707 .577 .707 r
F P
0 g
s
.72744 .75225 m .72876 .73315 L .69762 .73034 L p .707 .577 .707 r
F P
0 g
s
.72876 .73315 m .72744 .75225 L .75919 .75411 L p .707 .577 .707 r
F P
0 g
s
.75919 .75411 m .7605 .73502 L .72876 .73315 L p .707 .577 .707 r
F P
0 g
s
.26086 .75689 m .25954 .77599 L .22779 .77412 L p .707 .577 .707 r
F P
0 g
s
.67277 .66388 m .6704 .70201 L .69789 .70559 L p .707 .577 .707 r
F P
0 g
s
.69762 .73034 m .6963 .74944 L .72744 .75225 L p .707 .577 .707 r
F P
0 g
s
.7605 .73502 m .75919 .75411 L .78842 .75485 L p .707 .577 .707 r
F P
0 g
s
.78842 .75485 m .78974 .73576 L .7605 .73502 L p .707 .577 .707 r
F P
0 g
s
.79243 .67207 m .79006 .7102 L .81397 .7092 L p .707 .577 .707 r
F P
0 g
s
.81397 .7092 m .81634 .67107 L .79243 .67207 L p .707 .577 .707 r
F P
0 g
s
.65356 .58265 m .65138 .63941 L .67246 .64441 L p .707 .577 .707 r
F P
0 g
s
.6963 .74944 m .69762 .73034 L .67013 .72686 L p .707 .577 .707 r
F P
0 g
s
.67013 .72686 m .66881 .74596 L .6963 .74944 L p .707 .577 .707 r
F P
0 g
s
.81842 .59068 m .81624 .64743 L .83254 .64321 L p .707 .577 .707 r
F P
0 g
s
.83254 .64321 m .83473 .58645 L .81842 .59068 L p .707 .577 .707 r
F P
0 g
s
.6704 .70201 m .67277 .66388 L .65164 .6598 L p .707 .577 .707 r
F P
0 g
s
.78974 .73576 m .78842 .75485 L .8123 .75439 L p .707 .577 .707 r
F P
0 g
s
.8123 .75439 m .81361 .7353 L .78974 .73576 L p .707 .577 .707 r
F P
0 g
s
.65164 .6598 m .64927 .69793 L .6704 .70201 L p .707 .577 .707 r
F P
0 g
s
.60145 .26036 m .5816 .77292 L .54282 .76743 L p .707 .577 .707 r
F P
0 g
s
.54282 .76743 m .56267 .25487 L .60145 .26036 L p .707 .577 .707 r
F P
0 g
s
.65138 .63941 m .65356 .58265 L .64093 .57701 L p .707 .577 .707 r
F P
0 g
s
.66881 .74596 m .67013 .72686 L .64898 .72305 L p .707 .577 .707 r
F P
0 g
s
.64898 .72305 m .64766 .74214 L .66881 .74596 L p .707 .577 .707 r
F P
0 g
s
.81634 .67107 m .81397 .7092 L .83018 .70698 L p .707 .577 .707 r
F P
0 g
s
.83018 .70698 m .83254 .66885 L .81634 .67107 L p .707 .577 .707 r
F P
0 g
s
.4125 .76466 m .43235 .2521 L .47377 .25052 L p .707 .577 .707 r
F P
0 g
s
.43235 .2521 m .4125 .76466 L .37862 .76861 L p .707 .577 .707 r
F P
0 g
s
.64093 .57701 m .63874 .63377 L .65138 .63941 L p .707 .577 .707 r
F P
0 g
s
.64927 .69793 m .65164 .6598 L .63893 .6556 L p .707 .577 .707 r
F P
0 g
s
.83473 .58645 m .83254 .64321 L .83957 .63799 L p .707 .577 .707 r
F P
0 g
s
.83957 .63799 m .84175 .58123 L .83473 .58645 L p .707 .577 .707 r
F P
0 g
s
.81361 .7353 m .8123 .75439 L .82846 .75277 L p .707 .577 .707 r
F P
0 g
s
.82846 .75277 m .82978 .73368 L .81361 .7353 L p .707 .577 .707 r
F P
0 g
s
.63893 .6556 m .63657 .69373 L .64927 .69793 L p .707 .577 .707 r
F P
0 g
s
.56267 .25487 m .54282 .76743 L .49882 .76404 L p .707 .577 .707 r
F P
0 g
s
.49882 .76404 m .51867 .25148 L .56267 .25487 L p .707 .577 .707 r
F P
0 g
s
.45392 .76308 m .47377 .25052 L .51867 .25148 L p .707 .577 .707 r
F P
0 g
s
.47377 .25052 m .45392 .76308 L .4125 .76466 L p .707 .577 .707 r
F P
0 g
s
.64766 .74214 m .64898 .72305 L .63625 .71928 L p .707 .577 .707 r
F P
0 g
s
.63874 .63377 m .64093 .57701 L .63798 .57131 L p .707 .577 .707 r
F P
0 g
s
.63625 .71928 m .63493 .73838 L .64766 .74214 L p .707 .577 .707 r
F P
0 g
s
.51867 .25148 m .49882 .76404 L .45392 .76308 L p .707 .577 .707 r
F P
0 g
s
.83254 .66885 m .83018 .70698 L .8371 .70376 L p .707 .577 .707 r
F P
0 g
s
.8371 .70376 m .83946 .66563 L .83254 .66885 L p .707 .577 .707 r
F P
0 g
s
.63798 .57131 m .63579 .62807 L .63874 .63377 L p .707 .577 .707 r
F P
0 g
s
.63657 .69373 m .63893 .6556 L .63589 .6517 L p .707 .577 .707 r
F P
0 g
s
.82978 .73368 m .82846 .75277 L .83534 .75016 L p .707 .577 .707 r
F P
0 g
s
.83534 .75016 m .83666 .73106 L .82978 .73368 L p .707 .577 .707 r
F P
0 g
s
.84175 .58123 m .83957 .63799 L .83662 .63229 L p .707 .577 .707 r
F P
0 g
s
.83662 .63229 m .8388 .57553 L .84175 .58123 L p .707 .577 .707 r
F P
0 g
s
.63589 .6517 m .63352 .68983 L .63657 .69373 L p .707 .577 .707 r
F P
0 g
s
.63493 .73838 m .63625 .71928 L .63317 .71593 L p .707 .577 .707 r
F P
0 g
s
.63317 .71593 m .63185 .73502 L .63493 .73838 L p .707 .577 .707 r
F P
0 g
s
.63579 .62807 m .63798 .57131 L .645 .56609 L p .707 .577 .707 r
F P
0 g
s
.83946 .66563 m .8371 .70376 L .83405 .69987 L p .707 .577 .707 r
F P
0 g
s
.83405 .69987 m .83642 .66174 L .83946 .66563 L p .707 .577 .707 r
F P
0 g
s
.645 .56609 m .64281 .62285 L .63579 .62807 L p .707 .577 .707 r
F P
0 g
s
.83666 .73106 m .83534 .75016 L .83227 .7468 L p .707 .577 .707 r
F P
0 g
s
.83227 .7468 m .83358 .72771 L .83666 .73106 L p .707 .577 .707 r
F P
0 g
s
.63352 .68983 m .63589 .6517 L .64281 .64848 L p .707 .577 .707 r
F P
0 g
s
.8388 .57553 m .83662 .63229 L .82398 .62665 L p .707 .577 .707 r
F P
0 g
s
.82398 .62665 m .82617 .56989 L .8388 .57553 L p .707 .577 .707 r
F P
0 g
s
.64281 .64848 m .64044 .68662 L .63352 .68983 L p .707 .577 .707 r
F P
0 g
s
.38808 .61389 m .39027 .55713 L .35911 .55473 L p .707 .577 .707 r
F P
0 g
s
.39027 .55713 m .38808 .61389 L .41989 .61456 L p .707 .577 .707 r
F P
0 g
s
.41989 .61456 m .42208 .5578 L .39027 .55713 L p .707 .577 .707 r
F P
0 g
s
.63185 .73502 m .63317 .71593 L .64005 .71331 L p .707 .577 .707 r
F P
0 g
s
.42208 .5578 m .41989 .61456 L .44923 .61343 L p .707 .577 .707 r
F P
0 g
s
.44923 .61343 m .45142 .55667 L .42208 .5578 L p .707 .577 .707 r
F P
0 g
s
.64005 .71331 m .63873 .73241 L .63185 .73502 L p .707 .577 .707 r
F P
0 g
s
.64281 .62285 m .645 .56609 L .66131 .56186 L p .707 .577 .707 r
F P
0 g
s
.35692 .61149 m .35911 .55473 L .33164 .55084 L p .707 .577 .707 r
F P
0 g
s
.35911 .55473 m .35692 .61149 L .38808 .61389 L p .707 .577 .707 r
F P
0 g
s
.83642 .66174 m .83405 .69987 L .82135 .69567 L p .707 .577 .707 r
F P
0 g
s
.82135 .69567 m .82371 .65754 L .83642 .66174 L p .707 .577 .707 r
F P
0 g
s
.66131 .56186 m .65912 .61862 L .64281 .62285 L p .707 .577 .707 r
F P
0 g
s
.45142 .55667 m .44923 .61343 L .47323 .61062 L p .707 .577 .707 r
F P
0 g
s
.47323 .61062 m .47541 .55386 L .45142 .55667 L p .707 .577 .707 r
F P
0 g
s
.38602 .67149 m .38839 .63336 L .35725 .63064 L p .707 .577 .707 r
F P
0 g
s
.38839 .63336 m .38602 .67149 L .41779 .67308 L p .707 .577 .707 r
F P
0 g
s
.41779 .67308 m .42015 .63495 L .38839 .63336 L p .707 .577 .707 r
F P
0 g
s
.33164 .55084 m .32945 .6076 L .35692 .61149 L p .707 .577 .707 r
F P
0 g
s
.42015 .63495 m .41779 .67308 L .44705 .67339 L p .707 .577 .707 r
F P
0 g
s
.44705 .67339 m .44942 .63526 L .42015 .63495 L p .707 .577 .707 r
F P
0 g
s
.35725 .63064 m .35488 .66877 L .38602 .67149 L p .707 .577 .707 r
F P
0 g
s
.64044 .68662 m .64281 .64848 L .65902 .64627 L p .707 .577 .707 r
F P
0 g
s
.82617 .56989 m .82398 .62665 L .8029 .62164 L p .707 .577 .707 r
F P
0 g
s
.8029 .62164 m .80508 .56488 L .82617 .56989 L p .707 .577 .707 r
F P
0 g
s
.32945 .6076 m .33164 .55084 L .31055 .54583 L p .707 .577 .707 r
F P
0 g
s
.83358 .72771 m .83227 .7468 L .81953 .74303 L p .707 .577 .707 r
F P
0 g
s
.81953 .74303 m .82085 .72394 L .83358 .72771 L p .707 .577 .707 r
F P
0 g
s
.35488 .66877 m .35725 .63064 L .32976 .62707 L p .707 .577 .707 r
F P
0 g
s
.65902 .64627 m .65665 .6844 L .64044 .68662 L p .707 .577 .707 r
F P
0 g
s
.38443 .71543 m .38575 .69634 L .35461 .69353 L p .707 .577 .707 r
F P
0 g
s
.38575 .69634 m .38443 .71543 L .41618 .7173 L p .707 .577 .707 r
F P
0 g
s
.41618 .7173 m .41749 .69821 L .38575 .69634 L p .707 .577 .707 r
F P
0 g
s
.32976 .62707 m .32739 .6652 L .35488 .66877 L p .707 .577 .707 r
F P
0 g
s
.35461 .69353 m .35329 .71262 L .38443 .71543 L p .707 .577 .707 r
F P
0 g
s
.41749 .69821 m .41618 .7173 L .44541 .71804 L p .707 .577 .707 r
F P
0 g
s
.44541 .71804 m .44673 .69894 L .41749 .69821 L p .707 .577 .707 r
F P
0 g
s
.65912 .61862 m .66131 .56186 L .6853 .55905 L p .707 .577 .707 r
F P
0 g
s
.44942 .63526 m .44705 .67339 L .47096 .67238 L p .707 .577 .707 r
F P
0 g
s
.47096 .67238 m .47333 .63425 L .44942 .63526 L p .707 .577 .707 r
F P
0 g
s
.31055 .54583 m .30837 .60259 L .32945 .6076 L p .707 .577 .707 r
F P
0 g
s
.63873 .73241 m .64005 .71331 L .65622 .7117 L p .707 .577 .707 r
F P
0 g
s
.35329 .71262 m .35461 .69353 L .32712 .69005 L p .707 .577 .707 r
F P
0 g
s
.65622 .7117 m .6549 .73079 L .63873 .73241 L p .707 .577 .707 r
F P
0 g
s
.32712 .69005 m .3258 .70914 L .35329 .71262 L p .707 .577 .707 r
F P
0 g
s
.47541 .55386 m .47323 .61062 L .48953 .6064 L p .707 .577 .707 r
F P
0 g
s
.48953 .6064 m .49172 .54964 L .47541 .55386 L p .707 .577 .707 r
F P
0 g
s
.32739 .6652 m .32976 .62707 L .30863 .62298 L p .707 .577 .707 r
F P
0 g
s
.82371 .65754 m .82135 .69567 L .80022 .69158 L p .707 .577 .707 r
F P
0 g
s
.80022 .69158 m .80258 .65345 L .82371 .65754 L p .707 .577 .707 r
F P
0 g
s
.6853 .55905 m .68312 .61581 L .65912 .61862 L p .707 .577 .707 r
F P
0 g
s
.44673 .69894 m .44541 .71804 L .46929 .71757 L p .707 .577 .707 r
F P
0 g
s
.46929 .71757 m .4706 .69848 L .44673 .69894 L p .707 .577 .707 r
F P
0 g
s
.30863 .62298 m .30626 .66111 L .32739 .6652 L p .707 .577 .707 r
F P
0 g
s
.80508 .56488 m .8029 .62164 L .77543 .61775 L p .707 .577 .707 r
F P
0 g
s
.77543 .61775 m .77761 .56099 L .80508 .56488 L p .707 .577 .707 r
F P
0 g
s
.30837 .60259 m .31055 .54583 L .29792 .5402 L p .707 .577 .707 r
F P
0 g
s
.65665 .6844 m .65902 .64627 L .68292 .64526 L p .707 .577 .707 r
F P
0 g
s
.3258 .70914 m .32712 .69005 L .30597 .68624 L p .707 .577 .707 r
F P
0 g
s
.30597 .68624 m .30465 .70533 L .3258 .70914 L p .707 .577 .707 r
F P
0 g
s
.82085 .72394 m .81953 .74303 L .79838 .73922 L p .707 .577 .707 r
F P
0 g
s
.79838 .73922 m .7997 .72013 L .82085 .72394 L p .707 .577 .707 r
F P
0 g
s
.68312 .61581 m .6853 .55905 L .71464 .55792 L p .707 .577 .707 r
F P
0 g
s
.47333 .63425 m .47096 .67238 L .48717 .67016 L p .707 .577 .707 r
F P
0 g
s
.48717 .67016 m .48953 .63203 L .47333 .63425 L p .707 .577 .707 r
F P
0 g
s
.68292 .64526 m .68056 .68339 L .65665 .6844 L p .707 .577 .707 r
F P
0 g
s
.29792 .5402 m .29573 .59696 L .30837 .60259 L p .707 .577 .707 r
F P
0 g
s
.6549 .73079 m .65622 .7117 L .68009 .71123 L p .707 .577 .707 r
F P
0 g
s
.77761 .56099 m .77543 .61775 L .74426 .61535 L p .707 .577 .707 r
F P
0 g
s
.74426 .61535 m .74645 .55859 L .77761 .56099 L p .707 .577 .707 r
F P
0 g
s
.68009 .71123 m .67877 .73033 L .6549 .73079 L p .707 .577 .707 r
F P
0 g
s
.30626 .66111 m .30863 .62298 L .29592 .61878 L p .707 .577 .707 r
F P
0 g
s
.71464 .55792 m .71246 .61468 L .68312 .61581 L p .707 .577 .707 r
F P
0 g
s
.49172 .54964 m .48953 .6064 L .49656 .60118 L p .707 .577 .707 r
F P
0 g
s
.49656 .60118 m .49874 .54442 L .49172 .54964 L p .707 .577 .707 r
F P
0 g
s
.80258 .65345 m .80022 .69158 L .77273 .688 L p .707 .577 .707 r
F P
0 g
s
.77273 .688 m .7751 .64987 L .80258 .65345 L p .707 .577 .707 r
F P
0 g
s
.4706 .69848 m .46929 .71757 L .48545 .71596 L p .707 .577 .707 r
F P
0 g
s
.48545 .71596 m .48677 .69686 L .4706 .69848 L p .707 .577 .707 r
F P
0 g
s
.71246 .61468 m .71464 .55792 L .74645 .55859 L p .707 .577 .707 r
F P
0 g
s
.29592 .61878 m .29356 .65691 L .30626 .66111 L p .707 .577 .707 r
F P
0 g
s
.74645 .55859 m .74426 .61535 L .71246 .61468 L p .707 .577 .707 r
F P
0 g
s
.68056 .68339 m .68292 .64526 L .71219 .64557 L p .707 .577 .707 r
F P
0 g
s
.30465 .70533 m .30597 .68624 L .29324 .68247 L p .707 .577 .707 r
F P
0 g
s
.29573 .59696 m .29792 .5402 L .29497 .53449 L p .707 .577 .707 r
F P
0 g
s
.29324 .68247 m .29192 .70156 L .30465 .70533 L p .707 .577 .707 r
F P
0 g
s
.71219 .64557 m .70982 .6837 L .68056 .68339 L p .707 .577 .707 r
F P
0 g
s
.7997 .72013 m .79838 .73922 L .77089 .73574 L p .707 .577 .707 r
F P
0 g
s
.77089 .73574 m .77221 .71665 L .7997 .72013 L p .707 .577 .707 r
F P
0 g
s
.7751 .64987 m .77273 .688 L .74159 .68529 L p .707 .577 .707 r
F P
0 g
s
.74159 .68529 m .74395 .64716 L .7751 .64987 L p .707 .577 .707 r
F P
0 g
s
.48953 .63203 m .48717 .67016 L .49409 .66695 L p .707 .577 .707 r
F P
0 g
s
.49409 .66695 m .49645 .62882 L .48953 .63203 L p .707 .577 .707 r
F P
0 g
s
.67877 .73033 m .68009 .71123 L .70933 .71197 L p .707 .577 .707 r
F P
0 g
s
.70982 .6837 m .71219 .64557 L .74395 .64716 L p .707 .577 .707 r
F P
0 g
s
.70933 .71197 m .70801 .73107 L .67877 .73033 L p .707 .577 .707 r
F P
0 g
s
.29497 .53449 m .29278 .59125 L .29573 .59696 L p .707 .577 .707 r
F P
0 g
s
.74395 .64716 m .74159 .68529 L .70982 .6837 L p .707 .577 .707 r
F P
0 g
s
.77221 .71665 m .77089 .73574 L .73975 .73293 L p .707 .577 .707 r
F P
0 g
s
.73975 .73293 m .74107 .71384 L .77221 .71665 L p .707 .577 .707 r
F P
0 g
s
.29356 .65691 m .29592 .61878 L .29288 .61488 L p .707 .577 .707 r
F P
0 g
s
.48677 .69686 m .48545 .71596 L .49233 .71334 L p .707 .577 .707 r
F P
0 g
s
.49233 .71334 m .49365 .69425 L .48677 .69686 L p .707 .577 .707 r
F P
0 g
s
.49874 .54442 m .49656 .60118 L .4936 .59547 L p .707 .577 .707 r
F P
0 g
s
.4936 .59547 m .49579 .53871 L .49874 .54442 L p .707 .577 .707 r
F P
0 g
s
.70801 .73107 m .70933 .71197 L .74107 .71384 L p .707 .577 .707 r
F P
0 g
s
.29288 .61488 m .29051 .65302 L .29356 .65691 L p .707 .577 .707 r
F P
0 g
s
.74107 .71384 m .73975 .73293 L .70801 .73107 L p .707 .577 .707 r
F P
0 g
s
.29192 .70156 m .29324 .68247 L .29016 .67911 L p .707 .577 .707 r
F P
0 g
s
.29016 .67911 m .28884 .69821 L .29192 .70156 L p .707 .577 .707 r
F P
0 g
s
.29278 .59125 m .29497 .53449 L .30199 .52927 L p .707 .577 .707 r
F P
0 g
s
.49645 .62882 m .49409 .66695 L .49104 .66305 L p .707 .577 .707 r
F P
0 g
s
.49104 .66305 m .49341 .62492 L .49645 .62882 L p .707 .577 .707 r
F P
0 g
s
.30199 .52927 m .2998 .58603 L .29278 .59125 L p .707 .577 .707 r
F P
0 g
s
.49365 .69425 m .49233 .71334 L .48926 .70999 L p .707 .577 .707 r
F P
0 g
s
.48926 .70999 m .49057 .69089 L .49365 .69425 L p .707 .577 .707 r
F P
0 g
s
.29051 .65302 m .29288 .61488 L .2998 .61167 L p .707 .577 .707 r
F P
0 g
s
.49579 .53871 m .4936 .59547 L .48097 .58984 L p .707 .577 .707 r
F P
0 g
s
.48097 .58984 m .48315 .53308 L .49579 .53871 L p .707 .577 .707 r
F P
0 g
s
.2998 .61167 m .29743 .6498 L .29051 .65302 L p .707 .577 .707 r
F P
0 g
s
.28884 .69821 m .29016 .67911 L .29704 .6765 L p .707 .577 .707 r
F P
0 g
s
.29704 .6765 m .29572 .69559 L .28884 .69821 L p .707 .577 .707 r
F P
0 g
s
.2998 .58603 m .30199 .52927 L .3183 .52505 L p .707 .577 .707 r
F P
0 g
s
.49341 .62492 m .49104 .66305 L .47834 .65885 L p .707 .577 .707 r
F P
0 g
s
.47834 .65885 m .4807 .62072 L .49341 .62492 L p .707 .577 .707 r
F P
0 g
s
.3183 .52505 m .31611 .58181 L .2998 .58603 L p .707 .577 .707 r
F P
0 g
s
.29743 .6498 m .2998 .61167 L .31601 .60945 L p .707 .577 .707 r
F P
0 g
s
.48315 .53308 m .48097 .58984 L .45988 .58483 L p .707 .577 .707 r
F P
0 g
s
.45988 .58483 m .46207 .52807 L .48315 .53308 L p .707 .577 .707 r
F P
0 g
s
.49057 .69089 m .48926 .70999 L .47652 .70622 L p .707 .577 .707 r
F P
0 g
s
.47652 .70622 m .47784 .68713 L .49057 .69089 L p .707 .577 .707 r
F P
0 g
s
.31601 .60945 m .31364 .64758 L .29743 .6498 L p .707 .577 .707 r
F P
0 g
s
.31611 .58181 m .3183 .52505 L .34229 .52224 L p .707 .577 .707 r
F P
0 g
s
.29572 .69559 m .29704 .6765 L .31321 .67488 L p .707 .577 .707 r
F P
0 g
s
.31321 .67488 m .31189 .69397 L .29572 .69559 L p .707 .577 .707 r
F P
0 g
s
.4807 .62072 m .47834 .65885 L .45721 .65477 L p .707 .577 .707 r
F P
0 g
s
.45721 .65477 m .45957 .61664 L .4807 .62072 L p .707 .577 .707 r
F P
0 g
s
.34229 .52224 m .34011 .57899 L .31611 .58181 L p .707 .577 .707 r
F P
0 g
s
.46207 .52807 m .45988 .58483 L .43242 .58093 L p .707 .577 .707 r
F P
0 g
s
.43242 .58093 m .4346 .52417 L .46207 .52807 L p .707 .577 .707 r
F P
0 g
s
.31364 .64758 m .31601 .60945 L .33991 .60845 L p .707 .577 .707 r
F P
0 g
s
.47784 .68713 m .47652 .70622 L .45537 .70241 L p .707 .577 .707 r
F P
0 g
s
.45537 .70241 m .45669 .68331 L .47784 .68713 L p .707 .577 .707 r
F P
0 g
s
.34011 .57899 m .34229 .52224 L .37163 .52111 L p .707 .577 .707 r
F P
0 g
s
.33991 .60845 m .33755 .64658 L .31364 .64758 L p .707 .577 .707 r
F P
0 g
s
.31189 .69397 m .31321 .67488 L .33708 .67442 L p .707 .577 .707 r
F P
0 g
s
.4346 .52417 m .43242 .58093 L .40125 .57853 L p .707 .577 .707 r
F P
0 g
s
.40125 .57853 m .40344 .52178 L .4346 .52417 L p .707 .577 .707 r
F P
0 g
s
.33708 .67442 m .33576 .69351 L .31189 .69397 L p .707 .577 .707 r
F P
0 g
s
.37163 .52111 m .36945 .57787 L .34011 .57899 L p .707 .577 .707 r
F P
0 g
s
.45957 .61664 m .45721 .65477 L .42972 .65119 L p .707 .577 .707 r
F P
0 g
s
.42972 .65119 m .43209 .61306 L .45957 .61664 L p .707 .577 .707 r
F P
0 g
s
.36945 .57787 m .37163 .52111 L .40344 .52178 L p .707 .577 .707 r
F P
0 g
s
.40344 .52178 m .40125 .57853 L .36945 .57787 L p .707 .577 .707 r
F P
0 g
s
.33755 .64658 m .33991 .60845 L .36918 .60875 L p .707 .577 .707 r
F P
0 g
s
.36918 .60875 m .36681 .64688 L .33755 .64658 L p .707 .577 .707 r
F P
0 g
s
.45669 .68331 m .45537 .70241 L .42788 .69893 L p .707 .577 .707 r
F P
0 g
s
.42788 .69893 m .4292 .67983 L .45669 .68331 L p .707 .577 .707 r
F P
0 g
s
.43209 .61306 m .42972 .65119 L .39857 .64847 L p .707 .577 .707 r
F P
0 g
s
.39857 .64847 m .40094 .61034 L .43209 .61306 L p .707 .577 .707 r
F P
0 g
s
.33576 .69351 m .33708 .67442 L .36632 .67516 L p .707 .577 .707 r
F P
0 g
s
.36681 .64688 m .36918 .60875 L .40094 .61034 L p .707 .577 .707 r
F P
0 g
s
.36632 .67516 m .365 .69425 L .33576 .69351 L p .707 .577 .707 r
F P
0 g
s
.40094 .61034 m .39857 .64847 L .36681 .64688 L p .707 .577 .707 r
F P
0 g
s
.4292 .67983 m .42788 .69893 L .39674 .69612 L p .707 .577 .707 r
F P
0 g
s
.39674 .69612 m .39806 .67702 L .4292 .67983 L p .707 .577 .707 r
F P
0 g
s
.365 .69425 m .36632 .67516 L .39806 .67702 L p .707 .577 .707 r
F P
0 g
s
.39806 .67702 m .39674 .69612 L .365 .69425 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Ioob<008Aoo`00L7oo1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF2@00Ngoo001/Ool400000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol006Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00J7oo0`001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01000K7oo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000J7oo001WOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YF000006Ioo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001TOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001NOolJ000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Qoo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0047oo4P00A7oo001COol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo300015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP<0035oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00008002ioo`00Dgoo00<005YF00000eYF00@005YFFUIJEQT000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1`000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH00000FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00EGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo001J
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00=goo6@001Goo8@0000=JEP00
FUH01UYF00@005YFFUIJEPH000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00<Goo1P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3@0035YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1`002UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF3P001eYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP050005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1P0015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH000020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF0000000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000@000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003OolG0008FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000090007FUH00`00FUIJEP05FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF6`00<goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00;7oo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=J
EP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@00003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ40
00AJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ao
o`03001JEP0000=JEP`00003FUH005YF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEQ40
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00;7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEPd0009JEP03001JEUYF00=JEP03001JEUYF00=JEQH000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF008002ioo`00;7oo00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEUYF
009JEQ<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
FUIJEQh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`800003
FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP050005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF2000
15YF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00;goo0`0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=J
EP05001JEUYFFUH0000_Ool0035ooah00005FUH005YF001JEP0Q0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<007ooOol0;Goo000^Ool300000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHD0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP00Ool0;Woo000/Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002moo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1@000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<0
05YFFUH00eYF00<005YFFUH00P000goo8P00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000240
04Ioo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH04@0015YF
00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2000?Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=goo000[Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000bOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEP00000`Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEQH000AJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002moo`00:goo00<005YF0000
0UYF7`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF
300015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00:goo1P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF20000eYF00<005YFFUH00eYF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2`000eYF00<005YFFUH00eYF00@005YFFUIJ
EP8002moo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;goo000/Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF10000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF0P00;goo000^Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000EJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4000_Ool003=oo`L000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH00UYF4@0015YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;goo000`OolG0008FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP03FUH00`00FUIJEP02000;OolJ000`Ool0
02]oo`D0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ/00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00FUIJ
EP02001EOol002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007
FUH00`00FUIJEP04FUH00`00FUIJEP02001EOol002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60005Ool01000FUIJEP00
1EYF00<005YFFUH00eYF30002UYF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00:goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH01P000UYF00<005YFFUH00UYF1`002eYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Eoo`00:goo00<005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEP00008000IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol002]oo`03001JEP0000L0
0003FUH005YF00AJEQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP8000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP@0009JEP03001JEUYF009JEP03001JEP0000=JEPH000AJEP05001JEUYFFUH0001FOol002]oo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP03
001JEP00008000]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP03001JEP0000AJEP03001JEUYF009JEP<00003FUH005YF009JEP03
001oogoo05Aoo`00:goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1P00
0eYF00<005YFFUH015YF1`000eYF00<005YF00003EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP0000AJ
EP03001JEUYF00AJEP@0009JEP03001oogoo05Aoo`00;Goo1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1P003EYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000=JEP00FUH00eYF00<005YFFUH015YF00@005YFFUIJEP<005Ioo`00<Woo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EWoo
000iOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
0009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YFFUIJEPT005Moo`00@Woo8P000goo0`00
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH02@00H7oo001ZOol40002FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH7
001NOol006ioo`D000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03001JEUYF00D005Uoo`00Lgoo1P000eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Moo`00NGoo2@001UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00UYF1`001eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH00P00EWoo0022Oolf0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EWoo002=Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH60003
FUH01000FUIJEUYF0P00EWoo002?Ool50003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH2001FOol009Aoo`L000=JEP03001JEUYF00IJEP03
001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003FUH0000005Io
o`00Vgoo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0`00EWoo002SOol90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05001FOol00:ao
oaH005]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59874 .75859 m .59656 .70477 L .56539 .70335 L p .707 .577 .707 r
F P
0 g
s
.59656 .70477 m .59874 .75859 L .63055 .75641 L p .707 .577 .707 r
F P
0 g
s
.63055 .75641 m .62836 .70258 L .59656 .70477 L p .707 .577 .707 r
F P
0 g
s
.62836 .70258 m .63055 .75641 L .65989 .75084 L p .707 .577 .707 r
F P
0 g
s
.65989 .75084 m .6577 .69701 L .62836 .70258 L p .707 .577 .707 r
F P
0 g
s
.56758 .75718 m .56539 .70335 L .53793 .69847 L p .707 .577 .707 r
F P
0 g
s
.56539 .70335 m .56758 .75718 L .59874 .75859 L p .707 .577 .707 r
F P
0 g
s
.6577 .69701 m .65989 .75084 L .68389 .74242 L p .707 .577 .707 r
F P
0 g
s
.68389 .74242 m .6817 .6886 L .6577 .69701 L p .707 .577 .707 r
F P
0 g
s
.54011 .7523 m .53793 .69847 L .51684 .69061 L p .707 .577 .707 r
F P
0 g
s
.53793 .69847 m .54011 .7523 L .56758 .75718 L p .707 .577 .707 r
F P
0 g
s
.60142 .82493 m .59906 .78998 L .56791 .78886 L p .707 .577 .707 r
F P
0 g
s
.59906 .78998 m .60142 .82493 L .63318 .82189 L p .707 .577 .707 r
F P
0 g
s
.63318 .82189 m .63082 .78694 L .59906 .78998 L p .707 .577 .707 r
F P
0 g
s
.63082 .78694 m .63318 .82189 L .66245 .81498 L p .707 .577 .707 r
F P
0 g
s
.66245 .81498 m .66008 .78003 L .63082 .78694 L p .707 .577 .707 r
F P
0 g
s
.6817 .6886 m .68389 .74242 L .70019 .73199 L p .707 .577 .707 r
F P
0 g
s
.70019 .73199 m .69801 .67817 L .6817 .6886 L p .707 .577 .707 r
F P
0 g
s
.57028 .82381 m .56791 .78886 L .54042 .78369 L p .707 .577 .707 r
F P
0 g
s
.56791 .78886 m .57028 .82381 L .60142 .82493 L p .707 .577 .707 r
F P
0 g
s
.66008 .78003 m .66245 .81498 L .68636 .80488 L p .707 .577 .707 r
F P
0 g
s
.68636 .80488 m .68399 .76993 L .66008 .78003 L p .707 .577 .707 r
F P
0 g
s
.51684 .69061 m .51903 .74444 L .54011 .7523 L p .707 .577 .707 r
F P
0 g
s
.51903 .74444 m .51684 .69061 L .50421 .68053 L p .707 .577 .707 r
F P
0 g
s
.54279 .81864 m .54042 .78369 L .51929 .77497 L p .707 .577 .707 r
F P
0 g
s
.54042 .78369 m .54279 .81864 L .57028 .82381 L p .707 .577 .707 r
F P
0 g
s
.60326 .87011 m .60194 .85279 L .5708 .85176 L p .707 .577 .707 r
F P
0 g
s
.60194 .85279 m .60326 .87011 L .635 .86682 L p .707 .577 .707 r
F P
0 g
s
.635 .86682 m .63368 .84949 L .60194 .85279 L p .707 .577 .707 r
F P
0 g
s
.63368 .84949 m .635 .86682 L .66424 .85952 L p .707 .577 .707 r
F P
0 g
s
.66424 .85952 m .66292 .84219 L .63368 .84949 L p .707 .577 .707 r
F P
0 g
s
.69801 .67817 m .70019 .73199 L .70722 .72057 L p .707 .577 .707 r
F P
0 g
s
.70722 .72057 m .70503 .66674 L .69801 .67817 L p .707 .577 .707 r
F P
0 g
s
.68399 .76993 m .68636 .80488 L .70256 .79258 L p .707 .577 .707 r
F P
0 g
s
.70256 .79258 m .7002 .75763 L .68399 .76993 L p .707 .577 .707 r
F P
0 g
s
.57212 .86908 m .5708 .85176 L .54331 .8465 L p .707 .577 .707 r
F P
0 g
s
.5708 .85176 m .57212 .86908 L .60326 .87011 L p .707 .577 .707 r
F P
0 g
s
.50421 .68053 m .50639 .73436 L .51903 .74444 L p .707 .577 .707 r
F P
0 g
s
.66292 .84219 m .66424 .85952 L .68811 .84892 L p .707 .577 .707 r
F P
0 g
s
.68811 .84892 m .68679 .8316 L .66292 .84219 L p .707 .577 .707 r
F P
0 g
s
.51929 .77497 m .52166 .80992 L .54279 .81864 L p .707 .577 .707 r
F P
0 g
s
.54331 .8465 m .54463 .86382 L .57212 .86908 L p .707 .577 .707 r
F P
0 g
s
.50639 .73436 m .50421 .68053 L .50125 .66923 L p .707 .577 .707 r
F P
0 g
s
.52166 .80992 m .51929 .77497 L .50659 .76355 L p .707 .577 .707 r
F P
0 g
s
.54463 .86382 m .54331 .8465 L .52216 .83752 L p .707 .577 .707 r
F P
0 g
s
.50117 .82687 m .48132 .34094 L .43733 .33895 L p .707 .577 .707 r
F P
0 g
s
.50659 .76355 m .50895 .79851 L .52166 .80992 L p .707 .577 .707 r
F P
0 g
s
.50125 .66923 m .50344 .72306 L .50639 .73436 L p .707 .577 .707 r
F P
0 g
s
.52348 .85485 m .52216 .83752 L .50942 .82572 L p .707 .577 .707 r
F P
0 g
s
.50895 .79851 m .50659 .76355 L .50354 .75056 L p .707 .577 .707 r
F P
0 g
s
.50344 .72306 m .50125 .66923 L .50828 .6578 L p .707 .577 .707 r
F P
0 g
s
.50942 .82572 m .51074 .84304 L .52348 .85485 L p .707 .577 .707 r
F P
0 g
s
.50354 .75056 m .50591 .78551 L .50895 .79851 L p .707 .577 .707 r
F P
0 g
s
.50828 .6578 m .51046 .71163 L .50344 .72306 L p .707 .577 .707 r
F P
0 g
s
.51074 .84304 m .50942 .82572 L .50634 .81223 L p .707 .577 .707 r
F P
0 g
s
.50591 .78551 m .50354 .75056 L .51046 .73726 L p .707 .577 .707 r
F P
0 g
s
.51046 .71163 m .50828 .6578 L .52458 .64737 L p .707 .577 .707 r
F P
0 g
s
.50634 .81223 m .50766 .82956 L .51074 .84304 L p .707 .577 .707 r
F P
0 g
s
.51046 .73726 m .51283 .77222 L .50591 .78551 L p .707 .577 .707 r
F P
0 g
s
.52458 .64737 m .52677 .7012 L .51046 .71163 L p .707 .577 .707 r
F P
0 g
s
.50766 .82956 m .50634 .81223 L .51323 .79839 L p .707 .577 .707 r
F P
0 g
s
.52677 .7012 m .52458 .64737 L .54858 .63896 L p .707 .577 .707 r
F P
0 g
s
.51283 .77222 m .51046 .73726 L .52667 .72497 L p .707 .577 .707 r
F P
0 g
s
.51323 .79839 m .51454 .81571 L .50766 .82956 L p .707 .577 .707 r
F P
0 g
s
.52667 .72497 m .52904 .75992 L .51283 .77222 L p .707 .577 .707 r
F P
0 g
s
.54858 .63896 m .55077 .69279 L .52677 .7012 L p .707 .577 .707 r
F P
0 g
s
.51454 .81571 m .51323 .79839 L .52939 .78554 L p .707 .577 .707 r
F P
0 g
s
.52904 .75992 m .52667 .72497 L .55058 .71487 L p .707 .577 .707 r
F P
0 g
s
.52939 .78554 m .53071 .80287 L .51454 .81571 L p .707 .577 .707 r
F P
0 g
s
.55058 .71487 m .55295 .74982 L .52904 .75992 L p .707 .577 .707 r
F P
0 g
s
.53071 .80287 m .52939 .78554 L .55326 .77495 L p .707 .577 .707 r
F P
0 g
s
.55326 .77495 m .55458 .79227 L .53071 .80287 L p .707 .577 .707 r
F P
0 g
s
.48132 .34094 m .50117 .82687 L .54608 .82377 L p .707 .577 .707 r
F P
0 g
s
.54608 .82377 m .52623 .33785 L .48132 .34094 L p .707 .577 .707 r
F P
0 g
s
.55077 .69279 m .54858 .63896 L .57792 .63339 L p .707 .577 .707 r
F P
0 g
s
.57792 .63339 m .58011 .68722 L .55077 .69279 L p .707 .577 .707 r
F P
0 g
s
.55295 .74982 m .55058 .71487 L .57984 .70796 L p .707 .577 .707 r
F P
0 g
s
.57984 .70796 m .58221 .74291 L .55295 .74982 L p .707 .577 .707 r
F P
0 g
s
.55458 .79227 m .55326 .77495 L .5825 .76765 L p .707 .577 .707 r
F P
0 g
s
.5825 .76765 m .58382 .78497 L .55458 .79227 L p .707 .577 .707 r
F P
0 g
s
.52623 .33785 m .54608 .82377 L .5875 .81589 L p .707 .577 .707 r
F P
0 g
s
.58011 .68722 m .57792 .63339 L .60973 .63121 L p .707 .577 .707 r
F P
0 g
s
.60973 .63121 m .61191 .68503 L .58011 .68722 L p .707 .577 .707 r
F P
0 g
s
.58221 .74291 m .57984 .70796 L .61161 .70491 L p .707 .577 .707 r
F P
0 g
s
.61161 .70491 m .61397 .73987 L .58221 .74291 L p .707 .577 .707 r
F P
0 g
s
.58382 .78497 m .5825 .76765 L .61425 .76435 L p .707 .577 .707 r
F P
0 g
s
.61425 .76435 m .61556 .78167 L .58382 .78497 L p .707 .577 .707 r
F P
0 g
s
.5875 .81589 m .56765 .32997 L .52623 .33785 L p .707 .577 .707 r
F P
0 g
s
.52216 .83752 m .52348 .85485 L .54463 .86382 L p .707 .577 .707 r
F P
0 g
s
.68679 .8316 m .68811 .84892 L .70428 .83608 L p .707 .577 .707 r
F P
0 g
s
.70428 .83608 m .70296 .81875 L .68679 .8316 L p .707 .577 .707 r
F P
0 g
s
.7002 .75763 m .70256 .79258 L .70948 .77929 L p .707 .577 .707 r
F P
0 g
s
.70948 .77929 m .70712 .74433 L .7002 .75763 L p .707 .577 .707 r
F P
0 g
s
.70503 .66674 m .70722 .72057 L .70426 .70926 L p .707 .577 .707 r
F P
0 g
s
.70426 .70926 m .70208 .65544 L .70503 .66674 L p .707 .577 .707 r
F P
0 g
s
.45718 .82487 m .43733 .33895 L .39855 .33206 L p .707 .577 .707 r
F P
0 g
s
.43733 .33895 m .45718 .82487 L .50117 .82687 L p .707 .577 .707 r
F P
0 g
s
.64275 .70603 m .64512 .74099 L .61397 .73987 L p .707 .577 .707 r
F P
0 g
s
.61397 .73987 m .61161 .70491 L .64275 .70603 L p .707 .577 .707 r
F P
0 g
s
.64539 .76538 m .6467 .78271 L .61556 .78167 L p .707 .577 .707 r
F P
0 g
s
.61556 .78167 m .61425 .76435 L .64539 .76538 L p .707 .577 .707 r
F P
0 g
s
.56765 .32997 m .5875 .81589 L .62138 .80399 L p .707 .577 .707 r
F P
0 g
s
.64089 .63262 m .64308 .68645 L .61191 .68503 L p .707 .577 .707 r
F P
0 g
s
.61191 .68503 m .60973 .63121 L .64089 .63262 L p .707 .577 .707 r
F P
0 g
s
.62138 .80399 m .60152 .31807 L .56765 .32997 L p .707 .577 .707 r
F P
0 g
s
.70296 .81875 m .70428 .83608 L .71116 .82223 L p .707 .577 .707 r
F P
0 g
s
.71116 .82223 m .70984 .80491 L .70296 .81875 L p .707 .577 .707 r
F P
0 g
s
.4184 .81798 m .39855 .33206 L .36879 .32095 L p .707 .577 .707 r
F P
0 g
s
.39855 .33206 m .4184 .81798 L .45718 .82487 L p .707 .577 .707 r
F P
0 g
s
.70712 .74433 m .70948 .77929 L .70644 .7663 L p .707 .577 .707 r
F P
0 g
s
.70644 .7663 m .70407 .73134 L .70712 .74433 L p .707 .577 .707 r
F P
0 g
s
.70208 .65544 m .70426 .70926 L .69163 .69919 L p .707 .577 .707 r
F P
0 g
s
.69163 .69919 m .68944 .64536 L .70208 .65544 L p .707 .577 .707 r
F P
0 g
s
.60152 .31807 m .62138 .80399 L .6444 .78925 L p .707 .577 .707 r
F P
0 g
s
.6444 .78925 m .62455 .30332 L .60152 .31807 L p .707 .577 .707 r
F P
0 g
s
.25573 .72178 m .25355 .66795 L .22239 .66653 L p .707 .577 .707 r
F P
0 g
s
.25355 .66795 m .25573 .72178 L .28754 .71959 L p .707 .577 .707 r
F P
0 g
s
.28754 .71959 m .28536 .66577 L .25355 .66795 L p .707 .577 .707 r
F P
0 g
s
.28536 .66577 m .28754 .71959 L .31688 .71402 L p .707 .577 .707 r
F P
0 g
s
.31688 .71402 m .31469 .66019 L .28536 .66577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70984 .80491 m .71116 .82223 L .70808 .80875 L p .707 .577 .707 r
F P
0 g
s
.70808 .80875 m .70676 .79142 L .70984 .80491 L p .707 .577 .707 r
F P
0 g
s
.22457 .72036 m .22239 .66653 L .19492 .66166 L p .707 .577 .707 r
F P
0 g
s
.22239 .66653 m .22457 .72036 L .25573 .72178 L p .707 .577 .707 r
F P
0 g
s
.38864 .80687 m .36879 .32095 L .35095 .30671 L p .707 .577 .707 r
F P
0 g
s
.36879 .32095 m .38864 .80687 L .4184 .81798 L p .707 .577 .707 r
F P
0 g
s
.70407 .73134 m .70644 .7663 L .69373 .75488 L p .707 .577 .707 r
F P
0 g
s
.69373 .75488 m .69137 .71993 L .70407 .73134 L p .707 .577 .707 r
F P
0 g
s
.68944 .64536 m .69163 .69919 L .67054 .69132 L p .707 .577 .707 r
F P
0 g
s
.67054 .69132 m .66836 .6375 L .68944 .64536 L p .707 .577 .707 r
F P
0 g
s
.31469 .66019 m .31688 .71402 L .34088 .70561 L p .707 .577 .707 r
F P
0 g
s
.34088 .70561 m .33869 .65178 L .31469 .66019 L p .707 .577 .707 r
F P
0 g
s
.1971 .71548 m .19492 .66166 L .17383 .6538 L p .707 .577 .707 r
F P
0 g
s
.19492 .66166 m .1971 .71548 L .22457 .72036 L p .707 .577 .707 r
F P
0 g
s
.66836 .6375 m .67054 .69132 L .64308 .68645 L p .707 .577 .707 r
F P
0 g
s
.64308 .68645 m .64089 .63262 L .66836 .6375 L p .707 .577 .707 r
F P
0 g
s
.67024 .71121 m .6726 .74616 L .64512 .74099 L p .707 .577 .707 r
F P
0 g
s
.64512 .74099 m .64275 .70603 L .67024 .71121 L p .707 .577 .707 r
F P
0 g
s
.67288 .77064 m .67419 .78797 L .6467 .78271 L p .707 .577 .707 r
F P
0 g
s
.6467 .78271 m .64539 .76538 L .67288 .77064 L p .707 .577 .707 r
F P
0 g
s
.62455 .30332 m .6444 .78925 L .65431 .77309 L p .707 .577 .707 r
F P
0 g
s
.65431 .77309 m .63446 .28717 L .62455 .30332 L p .707 .577 .707 r
F P
0 g
s
.25841 .78812 m .25605 .75316 L .2249 .75204 L p .707 .577 .707 r
F P
0 g
s
.25605 .75316 m .25841 .78812 L .29017 .78507 L p .707 .577 .707 r
F P
0 g
s
.29017 .78507 m .28781 .75012 L .25605 .75316 L p .707 .577 .707 r
F P
0 g
s
.28781 .75012 m .29017 .78507 L .31944 .77817 L p .707 .577 .707 r
F P
0 g
s
.31944 .77817 m .31707 .74321 L .28781 .75012 L p .707 .577 .707 r
F P
0 g
s
.33869 .65178 m .34088 .70561 L .35719 .69518 L p .707 .577 .707 r
F P
0 g
s
.35719 .69518 m .355 .64135 L .33869 .65178 L p .707 .577 .707 r
F P
0 g
s
.70676 .79142 m .70808 .80875 L .69534 .79694 L p .707 .577 .707 r
F P
0 g
s
.69534 .79694 m .69402 .77962 L .70676 .79142 L p .707 .577 .707 r
F P
0 g
s
.22727 .787 m .2249 .75204 L .19742 .74687 L p .707 .577 .707 r
F P
0 g
s
.2249 .75204 m .22727 .787 L .25841 .78812 L p .707 .577 .707 r
F P
0 g
s
.69137 .71993 m .69373 .75488 L .6726 .74616 L p .707 .577 .707 r
F P
0 g
s
.6726 .74616 m .67024 .71121 L .69137 .71993 L p .707 .577 .707 r
F P
0 g
s
.31707 .74321 m .31944 .77817 L .34335 .76807 L p .707 .577 .707 r
F P
0 g
s
.34335 .76807 m .34098 .73311 L .31707 .74321 L p .707 .577 .707 r
F P
0 g
s
.17383 .6538 m .17602 .70762 L .1971 .71548 L p .707 .577 .707 r
F P
0 g
s
.17602 .70762 m .17383 .6538 L .1612 .64372 L p .707 .577 .707 r
F P
0 g
s
.3708 .79263 m .35095 .30671 L .34678 .29073 L p .707 .577 .707 r
F P
0 g
s
.35095 .30671 m .3708 .79263 L .38864 .80687 L p .707 .577 .707 r
F P
0 g
s
.19978 .78183 m .19742 .74687 L .17629 .73815 L p .707 .577 .707 r
F P
0 g
s
.19742 .74687 m .19978 .78183 L .22727 .787 L p .707 .577 .707 r
F P
0 g
s
.26025 .8333 m .25893 .81598 L .22779 .81494 L p .707 .577 .707 r
F P
0 g
s
.25893 .81598 m .26025 .8333 L .29199 .83 L p .707 .577 .707 r
F P
0 g
s
.29199 .83 m .29067 .81268 L .25893 .81598 L p .707 .577 .707 r
F P
0 g
s
.29067 .81268 m .29199 .83 L .32123 .8227 L p .707 .577 .707 r
F P
0 g
s
.32123 .8227 m .31991 .80538 L .29067 .81268 L p .707 .577 .707 r
F P
0 g
s
.355 .64135 m .35719 .69518 L .36421 .68375 L p .707 .577 .707 r
F P
0 g
s
.36421 .68375 m .36202 .62993 L .355 .64135 L p .707 .577 .707 r
F P
0 g
s
.34098 .73311 m .34335 .76807 L .35955 .75577 L p .707 .577 .707 r
F P
0 g
s
.35955 .75577 m .35719 .72081 L .34098 .73311 L p .707 .577 .707 r
F P
0 g
s
.69402 .77962 m .69534 .79694 L .67419 .78797 L p .707 .577 .707 r
F P
0 g
s
.67419 .78797 m .67288 .77064 L .69402 .77962 L p .707 .577 .707 r
F P
0 g
s
.22911 .83227 m .22779 .81494 L .2003 .80968 L p .707 .577 .707 r
F P
0 g
s
.22779 .81494 m .22911 .83227 L .26025 .8333 L p .707 .577 .707 r
F P
0 g
s
.1612 .64372 m .16338 .69755 L .17602 .70762 L p .707 .577 .707 r
F P
0 g
s
.31991 .80538 m .32123 .8227 L .3451 .81211 L p .707 .577 .707 r
F P
0 g
s
.3451 .81211 m .34378 .79478 L .31991 .80538 L p .707 .577 .707 r
F P
0 g
s
.17629 .73815 m .17865 .77311 L .19978 .78183 L p .707 .577 .707 r
F P
0 g
s
.2003 .80968 m .20162 .82701 L .22911 .83227 L p .707 .577 .707 r
F P
0 g
s
.63446 .28717 m .65431 .77309 L .65014 .75711 L p .707 .577 .707 r
F P
0 g
s
.65014 .75711 m .63854 .47306 L p .63446 .28717 L .707 .577 .707 r
F P
0 g
s
.63029 .27118 m .65014 .75711 L .6323 .74287 L p .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .6565 .67618 L .64389 .66486 L p .707 .577 .707 r
F P
0 g
s
.64389 .66486 m .64379 .66477 L p .6439 .6651 L .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .64389 .66486 L .6439 .6651 L .707 .577 .707 r
F
.63854 .47306 m .63029 .27118 L .63321 .2824 L p F P
0 g
s
.63321 .2824 m .63446 .28717 L p .63854 .47306 L .707 .577 .707 r
F P
0 g
s
.16338 .69755 m .1612 .64372 L .15825 .63241 L p .707 .577 .707 r
F P
0 g
s
.17865 .77311 m .17629 .73815 L .16358 .72674 L p .707 .577 .707 r
F P
0 g
s
.20162 .82701 m .2003 .80968 L .17915 .80071 L p .707 .577 .707 r
F P
0 g
s
.17915 .80071 m .18047 .81803 L .20162 .82701 L p .707 .577 .707 r
F P
0 g
s
.34378 .79478 m .3451 .81211 L .36127 .79926 L p .707 .577 .707 r
F P
0 g
s
.36127 .79926 m .35995 .78194 L .34378 .79478 L p .707 .577 .707 r
F P
0 g
s
.35719 .72081 m .35955 .75577 L .36648 .74247 L p .707 .577 .707 r
F P
0 g
s
.36648 .74247 m .36411 .70752 L .35719 .72081 L p .707 .577 .707 r
F P
0 g
s
.36202 .62993 m .36421 .68375 L .36126 .67245 L p .707 .577 .707 r
F P
0 g
s
.36126 .67245 m .35907 .61862 L .36202 .62993 L p .707 .577 .707 r
F P
0 g
s
.16358 .72674 m .16594 .76169 L .17865 .77311 L p .707 .577 .707 r
F P
0 g
s
.36815 .78542 m .36683 .76809 L .35995 .78194 L p .707 .577 .707 r
F P
0 g
s
.36411 .70752 m .36648 .74247 L .36343 .72948 L p .707 .577 .707 r
F P
0 g
s
.36343 .72948 m .36107 .69453 L .36411 .70752 L p .707 .577 .707 r
F P
0 g
s
.36683 .76809 m .36815 .78542 L .36507 .77193 L p .707 .577 .707 r
F P
0 g
s
.36507 .77193 m .36375 .75461 L .36683 .76809 L p .707 .577 .707 r
F P
0 g
s
.34678 .29073 m .36663 .77665 L .3708 .79263 L p .707 .577 .707 r
F P
0 g
s
.36663 .77665 m .34678 .29073 L .35669 .27457 L p .707 .577 .707 r
F P
0 g
s
.15825 .63241 m .16043 .68624 L .16338 .69755 L p .707 .577 .707 r
F P
0 g
s
.18047 .81803 m .17915 .80071 L .16641 .7889 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16594 .76169 m .16358 .72674 L .16053 .71375 L p .707 .577 .707 r
F P
0 g
s
.16043 .68624 m .15825 .63241 L .16527 .62099 L p .707 .577 .707 r
F P
0 g
s
.16641 .7889 m .16773 .80623 L .18047 .81803 L p .707 .577 .707 r
F P
0 g
s
.35995 .78194 m .36127 .79926 L .36815 .78542 L p .707 .577 .707 r
F P
0 g
s
.6323 .74287 m .61245 .25694 L .63029 .27118 L p .707 .577 .707 r
F P
0 g
s
.35907 .61862 m .36126 .67245 L .34862 .66237 L p .707 .577 .707 r
F P
0 g
s
.34862 .66237 m .34643 .60854 L .35907 .61862 L p .707 .577 .707 r
F P
0 g
s
.16053 .71375 m .1629 .7487 L .16594 .76169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16527 .62099 m .16745 .67481 L .16043 .68624 L p .707 .577 .707 r
F P
0 g
s
.16773 .80623 m .16641 .7889 L .16334 .77542 L p .707 .577 .707 r
F P
0 g
s
.1629 .7487 m .16053 .71375 L .16745 .70045 L p .707 .577 .707 r
F P
0 g
s
.16745 .67481 m .16527 .62099 L .18158 .61056 L p .707 .577 .707 r
F P
0 g
s
.37654 .7605 m .35669 .27457 L .37971 .25982 L p .707 .577 .707 r
F P
0 g
s
.35669 .27457 m .37654 .7605 L .36663 .77665 L p .707 .577 .707 r
F P
0 g
s
.16334 .77542 m .16465 .79274 L .16773 .80623 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36107 .69453 m .36343 .72948 L .35072 .71807 L p .707 .577 .707 r
F P
0 g
s
.35072 .71807 m .34836 .68311 L .36107 .69453 L p .707 .577 .707 r
F P
0 g
s
.34643 .60854 m .34862 .66237 L .32754 .65451 L p .707 .577 .707 r
F P
0 g
s
.32754 .65451 m .32535 .60068 L .34643 .60854 L p .707 .577 .707 r
F P
0 g
s
.16745 .70045 m .16982 .7354 L .1629 .7487 L p .707 .577 .707 r
F P
0 g
s
.61245 .25694 m .6323 .74287 L .60254 .73176 L p .707 .577 .707 r
F P
0 g
s
.60254 .73176 m .58268 .24583 L .61245 .25694 L p .707 .577 .707 r
F P
0 g
s
.18158 .61056 m .18376 .66438 L .16745 .67481 L p .707 .577 .707 r
F P
0 g
s
.16465 .79274 m .16334 .77542 L .17022 .76157 L p .707 .577 .707 r
F P
0 g
s
.18376 .66438 m .18158 .61056 L .20557 .60215 L p .707 .577 .707 r
F P
0 g
s
.16982 .7354 m .16745 .70045 L .18366 .68815 L p .707 .577 .707 r
F P
0 g
s
.17022 .76157 m .17154 .7789 L .16465 .79274 L p .707 .577 .707 r
F P
0 g
s
.36375 .75461 m .36507 .77193 L .35233 .76013 L p .707 .577 .707 r
F P
0 g
s
.35233 .76013 m .35102 .7428 L .36375 .75461 L p .707 .577 .707 r
F P
0 g
s
.32535 .60068 m .32754 .65451 L .30007 .64963 L p .707 .577 .707 r
F P
0 g
s
.30007 .64963 m .29788 .59581 L .32535 .60068 L p .707 .577 .707 r
F P
0 g
s
.37971 .25982 m .39956 .74575 L .37654 .7605 L p .707 .577 .707 r
F P
0 g
s
.39956 .74575 m .37971 .25982 L .41359 .24793 L p .707 .577 .707 r
F P
0 g
s
.34836 .68311 m .35072 .71807 L .32959 .70935 L p .707 .577 .707 r
F P
0 g
s
.32959 .70935 m .32723 .67439 L .34836 .68311 L p .707 .577 .707 r
F P
0 g
s
.18366 .68815 m .18603 .7231 L .16982 .7354 L p .707 .577 .707 r
F P
0 g
s
.20776 .65597 m .20557 .60215 L .23491 .59658 L p .707 .577 .707 r
F P
0 g
s
.20557 .60215 m .20776 .65597 L .18376 .66438 L p .707 .577 .707 r
F P
0 g
s
.29788 .59581 m .30007 .64963 L .2689 .64822 L p .707 .577 .707 r
F P
0 g
s
.2689 .64822 m .26672 .59439 L .29788 .59581 L p .707 .577 .707 r
F P
0 g
s
.17154 .7789 m .17022 .76157 L .18638 .74873 L p .707 .577 .707 r
F P
0 g
s
.58268 .24583 m .60254 .73176 L .56376 .72487 L p .707 .577 .707 r
F P
0 g
s
.56376 .72487 m .54391 .23894 L .58268 .24583 L p .707 .577 .707 r
F P
0 g
s
.18603 .7231 m .18366 .68815 L .20757 .67805 L p .707 .577 .707 r
F P
0 g
s
.2371 .6504 m .23491 .59658 L .26672 .59439 L p .707 .577 .707 r
F P
0 g
s
.23491 .59658 m .2371 .6504 L .20776 .65597 L p .707 .577 .707 r
F P
0 g
s
.26672 .59439 m .2689 .64822 L .2371 .6504 L p .707 .577 .707 r
F P
0 g
s
.18638 .74873 m .1877 .76605 L .17154 .7789 L p .707 .577 .707 r
F P
0 g
s
.32723 .67439 m .32959 .70935 L .30211 .70417 L p .707 .577 .707 r
F P
0 g
s
.30211 .70417 m .29974 .66922 L .32723 .67439 L p .707 .577 .707 r
F P
0 g
s
.35102 .7428 m .35233 .76013 L .33119 .75115 L p .707 .577 .707 r
F P
0 g
s
.33119 .75115 m .32987 .73383 L .35102 .7428 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .41359 .24793 L .45501 .24004 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .39956 .74575 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.42184 .4498 m .43344 .73385 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.45501 .24004 m .47486 .72597 L .43344 .73385 L p .707 .577 .707 r
F P
0 g
s
.45664 .67938 m .45445 .64693 L p .42501 .65134 L .707 .577 .707 r
F P
0 g
s
.45445 .64693 m .45428 .64443 L .45404 .64448 L p .707 .577 .707 r
F P
0 g
s
.45404 .64448 m .42501 .65134 L p .45445 .64693 L .707 .577 .707 r
F P
0 g
s
.41359 .24793 m .42184 .4498 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.73595 .66366 m .73376 .60984 L .7026 .60842 L p .707 .577 .707 r
F P
0 g
s
.73376 .60984 m .73595 .66366 L .76775 .66148 L p .707 .577 .707 r
F P
0 g
s
.76775 .66148 m .76557 .60765 L .73376 .60984 L p .707 .577 .707 r
F P
0 g
s
.76557 .60765 m .76775 .66148 L .79709 .65591 L p .707 .577 .707 r
F P
0 g
s
.79709 .65591 m .79491 .60208 L .76557 .60765 L p .707 .577 .707 r
F P
0 g
s
.20757 .67805 m .20994 .71301 L .18603 .7231 L p .707 .577 .707 r
F P
0 g
s
.20994 .71301 m .20757 .67805 L .23683 .67114 L p .707 .577 .707 r
F P
0 g
s
.70478 .66225 m .7026 .60842 L .67513 .60355 L p .707 .577 .707 r
F P
0 g
s
.7026 .60842 m .70478 .66225 L .73595 .66366 L p .707 .577 .707 r
F P
0 g
s
.54391 .23894 m .56376 .72487 L .51976 .72287 L p .707 .577 .707 r
F P
0 g
s
.51976 .72287 m .49991 .23695 L .54391 .23894 L p .707 .577 .707 r
F P
0 g
s
.1877 .76605 m .18638 .74873 L .21026 .73813 L p .707 .577 .707 r
F P
0 g
s
.29974 .66922 m .30211 .70417 L .27096 .70305 L p .707 .577 .707 r
F P
0 g
s
.27096 .70305 m .2686 .6681 L .29974 .66922 L p .707 .577 .707 r
F P
0 g
s
.79491 .60208 m .79709 .65591 L .82109 .6475 L p .707 .577 .707 r
F P
0 g
s
.82109 .6475 m .8189 .59367 L .79491 .60208 L p .707 .577 .707 r
F P
0 g
s
.47486 .72597 m .45501 .24004 L .49991 .23695 L p .707 .577 .707 r
F P
0 g
s
.2392 .7061 m .23683 .67114 L .2686 .6681 L p .707 .577 .707 r
F P
0 g
s
.23683 .67114 m .2392 .7061 L .20994 .71301 L p .707 .577 .707 r
F P
0 g
s
.2686 .6681 m .27096 .70305 L .2392 .7061 L p .707 .577 .707 r
F P
0 g
s
.49991 .23695 m .51976 .72287 L .47486 .72597 L p .707 .577 .707 r
F P
0 g
s
.21026 .73813 m .21157 .75546 L .1877 .76605 L p .707 .577 .707 r
F P
0 g
s
.32987 .73383 m .33119 .75115 L .3037 .74589 L p .707 .577 .707 r
F P
0 g
s
.3037 .74589 m .30238 .72857 L .32987 .73383 L p .707 .577 .707 r
F P
0 g
s
.67732 .65737 m .67513 .60355 L .65405 .59568 L p .707 .577 .707 r
F P
0 g
s
.67513 .60355 m .67732 .65737 L .70478 .66225 L p .707 .577 .707 r
F P
0 g
s
.21157 .75546 m .21026 .73813 L .23949 .73083 L p .707 .577 .707 r
F P
0 g
s
.73863 .72615 m .73626 .6912 L .70511 .69008 L p .707 .577 .707 r
F P
0 g
s
.73626 .6912 m .73863 .72615 L .77039 .72311 L p .707 .577 .707 r
F P
0 g
s
.77039 .72311 m .76802 .68815 L .73626 .6912 L p .707 .577 .707 r
F P
0 g
s
.76802 .68815 m .77039 .72311 L .79965 .7162 L p .707 .577 .707 r
F P
0 g
s
.79965 .7162 m .79729 .68124 L .76802 .68815 L p .707 .577 .707 r
F P
0 g
s
.8189 .59367 m .82109 .6475 L .8374 .63707 L p .707 .577 .707 r
F P
0 g
s
.8374 .63707 m .83521 .58324 L .8189 .59367 L p .707 .577 .707 r
F P
0 g
s
.30238 .72857 m .3037 .74589 L .27255 .74486 L p .707 .577 .707 r
F P
0 g
s
.27255 .74486 m .27124 .72754 L .30238 .72857 L p .707 .577 .707 r
F P
0 g
s
.70748 .72503 m .70511 .69008 L .67763 .6849 L p .707 .577 .707 r
F P
0 g
s
.70511 .69008 m .70748 .72503 L .73863 .72615 L p .707 .577 .707 r
F P
0 g
s
.23949 .73083 m .24081 .74816 L .21157 .75546 L p .707 .577 .707 r
F P
0 g
s
.24081 .74816 m .23949 .73083 L .27124 .72754 L p .707 .577 .707 r
F P
0 g
s
.27124 .72754 m .27255 .74486 L .24081 .74816 L p .707 .577 .707 r
F P
0 g
s
.79729 .68124 m .79965 .7162 L .82356 .7061 L p .707 .577 .707 r
F P
0 g
s
.82356 .7061 m .82119 .67115 L .79729 .68124 L p .707 .577 .707 r
F P
0 g
s
.65405 .59568 m .65623 .64951 L .67732 .65737 L p .707 .577 .707 r
F P
0 g
s
.65623 .64951 m .65405 .59568 L .64141 .58561 L p .707 .577 .707 r
F P
0 g
s
.68 .71986 m .67763 .6849 L .6565 .67618 L p .707 .577 .707 r
F P
0 g
s
.67763 .6849 m .68 .71986 L .70748 .72503 L p .707 .577 .707 r
F P
0 g
s
.74046 .76591 m .73914 .74859 L .708 .74755 L p .707 .577 .707 r
F P
0 g
s
.73914 .74859 m .74046 .76591 L .7722 .76261 L p .707 .577 .707 r
F P
0 g
s
.7722 .76261 m .77089 .74529 L .73914 .74859 L p .707 .577 .707 r
F P
0 g
s
.77089 .74529 m .7722 .76261 L .80144 .75531 L p .707 .577 .707 r
F P
0 g
s
.80144 .75531 m .80012 .73799 L .77089 .74529 L p .707 .577 .707 r
F P
0 g
s
.83521 .58324 m .8374 .63707 L .84442 .62564 L p .707 .577 .707 r
F P
0 g
s
.84442 .62564 m .84223 .57181 L .83521 .58324 L p .707 .577 .707 r
F P
0 g
s
.70932 .76488 m .708 .74755 L .68051 .74229 L p .707 .577 .707 r
F P
0 g
s
.708 .74755 m .70932 .76488 L .74046 .76591 L p .707 .577 .707 r
F P
0 g
s
.82119 .67115 m .82356 .7061 L .83977 .6938 L p .707 .577 .707 r
F P
0 g
s
.83977 .6938 m .8374 .65885 L .82119 .67115 L p .707 .577 .707 r
F P
0 g
s
.80012 .73799 m .80144 .75531 L .82531 .74472 L p .707 .577 .707 r
F P
0 g
s
.82531 .74472 m .82399 .7274 L .80012 .73799 L p .707 .577 .707 r
F P
0 g
s
.64141 .58561 m .6436 .63943 L .65623 .64951 L p .707 .577 .707 r
F P
0 g
s
.6565 .67618 m .65887 .71114 L .68 .71986 L p .707 .577 .707 r
F P
0 g
s
.68051 .74229 m .68183 .75962 L .70932 .76488 L p .707 .577 .707 r
F P
0 g
s
.6436 .63943 m .64141 .58561 L .63846 .5743 L p .707 .577 .707 r
F P
0 g
s
.68183 .75962 m .68051 .74229 L .65936 .73332 L p .707 .577 .707 r
F P
0 g
s
.65936 .73332 m .66068 .75064 L .68183 .75962 L p .707 .577 .707 r
F P
0 g
s
.82399 .7274 m .82531 .74472 L .84148 .73187 L p .707 .577 .707 r
F P
0 g
s
.84148 .73187 m .84016 .71455 L .82399 .7274 L p .707 .577 .707 r
F P
0 g
s
.8374 .65885 m .83977 .6938 L .84669 .6805 L p .707 .577 .707 r
F P
0 g
s
.84669 .6805 m .84432 .64555 L .8374 .65885 L p .707 .577 .707 r
F P
0 g
s
.84223 .57181 m .84442 .62564 L .84147 .61434 L p .707 .577 .707 r
F P
0 g
s
.84147 .61434 m .83928 .56051 L .84223 .57181 L p .707 .577 .707 r
F P
0 g
s
.64379 .66477 m .64616 .69972 L .65887 .71114 L p .707 .577 .707 r
F P
0 g
s
.63846 .5743 m .64065 .62813 L .6436 .63943 L p .707 .577 .707 r
F P
0 g
s
.66068 .75064 m .65936 .73332 L .64663 .72151 L p .707 .577 .707 r
F P
0 g
s
.64616 .69972 m .64379 .66477 L .64075 .65178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64065 .62813 m .63846 .5743 L .64548 .56288 L p .707 .577 .707 r
F P
0 g
s
.64663 .72151 m .64795 .73884 L .66068 .75064 L p .707 .577 .707 r
F P
0 g
s
.84016 .71455 m .84148 .73187 L .84836 .71803 L p .707 .577 .707 r
F P
0 g
s
.84836 .71803 m .84704 .7007 L .84016 .71455 L p .707 .577 .707 r
F P
0 g
s
.84432 .64555 m .84669 .6805 L .84365 .66751 L p .707 .577 .707 r
F P
0 g
s
.84365 .66751 m .84128 .63256 L .84432 .64555 L p .707 .577 .707 r
F P
0 g
s
.64075 .65178 m .64311 .68673 L .64616 .69972 L p .707 .577 .707 r
F P
0 g
s
.83928 .56051 m .84147 .61434 L .82883 .60426 L p .707 .577 .707 r
F P
0 g
s
.82883 .60426 m .82665 .55043 L .83928 .56051 L p .707 .577 .707 r
F P
0 g
s
.64548 .56288 m .64767 .6167 L .64065 .62813 L p .707 .577 .707 r
F P
0 g
s
.64795 .73884 m .64663 .72151 L .64355 .70803 L p .707 .577 .707 r
F P
0 g
s
.64311 .68673 m .64075 .65178 L .64767 .63848 L p .707 .577 .707 r
F P
0 g
s
.64767 .6167 m .64548 .56288 L .66179 .55245 L p .707 .577 .707 r
F P
0 g
s
.39294 .62685 m .39075 .57302 L .35959 .57161 L p .707 .577 .707 r
F P
0 g
s
.39075 .57302 m .39294 .62685 L .42474 .62466 L p .707 .577 .707 r
F P
0 g
s
.42474 .62466 m .42256 .57084 L .39075 .57302 L p .707 .577 .707 r
F P
0 g
s
.64355 .70803 m .64487 .72535 L .64795 .73884 L p .707 .577 .707 r
F P
0 g
s
.42256 .57084 m .42474 .62466 L .45408 .61909 L p .707 .577 .707 r
F P
0 g
s
.45408 .61909 m .4519 .56527 L .42256 .57084 L p .707 .577 .707 r
F P
0 g
s
.84704 .7007 m .84836 .71803 L .84528 .70454 L p .707 .577 .707 r
F P
0 g
s
.84528 .70454 m .84397 .68722 L .84704 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36177 .62543 m .35959 .57161 L .33212 .56673 L p .707 .577 .707 r
F P
0 g
s
.35959 .57161 m .36177 .62543 L .39294 .62685 L p .707 .577 .707 r
F P
0 g
s
.84128 .63256 m .84365 .66751 L .83094 .6561 L p .707 .577 .707 r
F P
0 g
s
.83094 .6561 m .82857 .62114 L .84128 .63256 L p .707 .577 .707 r
F P
0 g
s
.82665 .55043 m .82883 .60426 L .80775 .5964 L p .707 .577 .707 r
F P
0 g
s
.80775 .5964 m .80556 .54257 L .82665 .55043 L p .707 .577 .707 r
F P
0 g
s
.4519 .56527 m .45408 .61909 L .47808 .61068 L p .707 .577 .707 r
F P
0 g
s
.47808 .61068 m .47589 .55686 L .4519 .56527 L p .707 .577 .707 r
F P
0 g
s
.64767 .63848 m .65004 .67344 L .64311 .68673 L p .707 .577 .707 r
F P
0 g
s
.66179 .55245 m .66398 .60627 L .64767 .6167 L p .707 .577 .707 r
F P
0 g
s
.64487 .72535 m .64355 .70803 L .65043 .69418 L p .707 .577 .707 r
F P
0 g
s
.33431 .62056 m .33212 .56673 L .31104 .55887 L p .707 .577 .707 r
F P
0 g
s
.33212 .56673 m .33431 .62056 L .36177 .62543 L p .707 .577 .707 r
F P
0 g
s
.66398 .60627 m .66179 .55245 L .68579 .54403 L p .707 .577 .707 r
F P
0 g
s
.65004 .67344 m .64767 .63848 L .66388 .62618 L p .707 .577 .707 r
F P
0 g
s
.39562 .68934 m .39325 .65438 L .3621 .65326 L p .707 .577 .707 r
F P
0 g
s
.39325 .65438 m .39562 .68934 L .42738 .68629 L p .707 .577 .707 r
F P
0 g
s
.42738 .68629 m .42501 .65134 L .39325 .65438 L p .707 .577 .707 r
F P
0 g
s
.65043 .69418 m .65175 .71151 L .64487 .72535 L p .707 .577 .707 r
F P
0 g
s
.42501 .65134 m .42738 .68629 L .45664 .67938 L p .707 .577 .707 r
F P
0 g
s
.84397 .68722 m .84528 .70454 L .83255 .69274 L p .707 .577 .707 r
F P
0 g
s
.83255 .69274 m .83123 .67541 L .84397 .68722 L p .707 .577 .707 r
F P
0 g
s
.47589 .55686 m .47808 .61068 L .49439 .60025 L p .707 .577 .707 r
F P
0 g
s
.49439 .60025 m .4922 .54643 L .47589 .55686 L p .707 .577 .707 r
F P
0 g
s
.80556 .54257 m .80775 .5964 L .78028 .59152 L p .707 .577 .707 r
F P
0 g
s
.78028 .59152 m .7781 .53769 L .80556 .54257 L p .707 .577 .707 r
F P
0 g
s
.36447 .68822 m .3621 .65326 L .33462 .64809 L p .707 .577 .707 r
F P
0 g
s
.3621 .65326 m .36447 .68822 L .39562 .68934 L p .707 .577 .707 r
F P
0 g
s
.82857 .62114 m .83094 .6561 L .80981 .64738 L p .707 .577 .707 r
F P
0 g
s
.80981 .64738 m .80744 .61242 L .82857 .62114 L p .707 .577 .707 r
F P
0 g
s
.45428 .64443 m .45664 .67938 L .48055 .66928 L p .707 .577 .707 r
F P
0 g
s
.48055 .66928 m .47818 .63433 L .45428 .64443 L p .707 .577 .707 r
F P
0 g
s
.66388 .62618 m .66624 .66114 L .65004 .67344 L p .707 .577 .707 r
F P
0 g
s
.31104 .55887 m .31322 .61269 L .33431 .62056 L p .707 .577 .707 r
F P
0 g
s
.68797 .59786 m .68579 .54403 L .71513 .53846 L p .707 .577 .707 r
F P
0 g
s
.68579 .54403 m .68797 .59786 L .66398 .60627 L p .707 .577 .707 r
F P
0 g
s
.31322 .61269 m .31104 .55887 L .2984 .54879 L p .707 .577 .707 r
F P
0 g
s
.65175 .71151 m .65043 .69418 L .6666 .68134 L p .707 .577 .707 r
F P
0 g
s
.66624 .66114 m .66388 .62618 L .68778 .61608 L p .707 .577 .707 r
F P
0 g
s
.7781 .53769 m .78028 .59152 L .74912 .5901 L p .707 .577 .707 r
F P
0 g
s
.74912 .5901 m .74693 .53628 L .7781 .53769 L p .707 .577 .707 r
F P
0 g
s
.33699 .68304 m .33462 .64809 L .31349 .63937 L p .707 .577 .707 r
F P
0 g
s
.33462 .64809 m .33699 .68304 L .36447 .68822 L p .707 .577 .707 r
F P
0 g
s
.39745 .7291 m .39613 .71177 L .36499 .71074 L p .707 .577 .707 r
F P
0 g
s
.39613 .71177 m .39745 .7291 L .42919 .7258 L p .707 .577 .707 r
F P
0 g
s
.42919 .7258 m .42788 .70847 L .39613 .71177 L p .707 .577 .707 r
F P
0 g
s
.42788 .70847 m .42919 .7258 L .45843 .7185 L p .707 .577 .707 r
F P
0 g
s
.45843 .7185 m .45711 .70117 L .42788 .70847 L p .707 .577 .707 r
F P
0 g
s
.71731 .59229 m .71513 .53846 L .74693 .53628 L p .707 .577 .707 r
F P
0 g
s
.71513 .53846 m .71731 .59229 L .68797 .59786 L p .707 .577 .707 r
F P
0 g
s
.6666 .68134 m .66792 .69866 L .65175 .71151 L p .707 .577 .707 r
F P
0 g
s
.74693 .53628 m .74912 .5901 L .71731 .59229 L p .707 .577 .707 r
F P
0 g
s
.4922 .54643 m .49439 .60025 L .50141 .58882 L p .707 .577 .707 r
F P
0 g
s
.50141 .58882 m .49922 .535 L .4922 .54643 L p .707 .577 .707 r
F P
0 g
s
.83123 .67541 m .83255 .69274 L .8114 .68376 L p .707 .577 .707 r
F P
0 g
s
.8114 .68376 m .81008 .66644 L .83123 .67541 L p .707 .577 .707 r
F P
0 g
s
.80744 .61242 m .80981 .64738 L .78232 .64221 L p .707 .577 .707 r
F P
0 g
s
.78232 .64221 m .77996 .60725 L .80744 .61242 L p .707 .577 .707 r
F P
0 g
s
.36631 .72806 m .36499 .71074 L .3375 .70548 L p .707 .577 .707 r
F P
0 g
s
.36499 .71074 m .36631 .72806 L .39745 .7291 L p .707 .577 .707 r
F P
0 g
s
.47818 .63433 m .48055 .66928 L .49676 .65699 L p .707 .577 .707 r
F P
0 g
s
.49676 .65699 m .49439 .62203 L .47818 .63433 L p .707 .577 .707 r
F P
0 g
s
.45711 .70117 m .45843 .7185 L .4823 .7079 L p .707 .577 .707 r
F P
0 g
s
.4823 .7079 m .48098 .69058 L .45711 .70117 L p .707 .577 .707 r
F P
0 g
s
.2984 .54879 m .30059 .60262 L .31322 .61269 L p .707 .577 .707 r
F P
0 g
s
.68778 .61608 m .69015 .65104 L .66624 .66114 L p .707 .577 .707 r
F P
0 g
s
.31349 .63937 m .31586 .67432 L .33699 .68304 L p .707 .577 .707 r
F P
0 g
s
.3375 .70548 m .33882 .7228 L .36631 .72806 L p .707 .577 .707 r
F P
0 g
s
.69015 .65104 m .68778 .61608 L .71705 .60918 L p .707 .577 .707 r
F P
0 g
s
.30059 .60262 m .2984 .54879 L .29545 .53749 L p .707 .577 .707 r
F P
0 g
s
.66792 .69866 m .6666 .68134 L .69047 .67074 L p .707 .577 .707 r
F P
0 g
s
.31586 .67432 m .31349 .63937 L .30078 .62795 L p .707 .577 .707 r
F P
0 g
s
.33882 .7228 m .3375 .70548 L .31635 .69651 L p .707 .577 .707 r
F P
0 g
s
.77996 .60725 m .78232 .64221 L .75118 .64109 L p .707 .577 .707 r
F P
0 g
s
.75118 .64109 m .74881 .60613 L .77996 .60725 L p .707 .577 .707 r
F P
0 g
s
.71942 .64413 m .71705 .60918 L .74881 .60613 L p .707 .577 .707 r
F P
0 g
s
.71705 .60918 m .71942 .64413 L .69015 .65104 L p .707 .577 .707 r
F P
0 g
s
.69047 .67074 m .69179 .68807 L .66792 .69866 L p .707 .577 .707 r
F P
0 g
s
.81008 .66644 m .8114 .68376 L .78391 .6785 L p .707 .577 .707 r
F P
0 g
s
.78391 .6785 m .78259 .66118 L .81008 .66644 L p .707 .577 .707 r
F P
0 g
s
.74881 .60613 m .75118 .64109 L .71942 .64413 L p .707 .577 .707 r
F P
0 g
s
.31635 .69651 m .31767 .71383 L .33882 .7228 L p .707 .577 .707 r
F P
0 g
s
.48098 .69058 m .4823 .7079 L .49847 .69506 L p .707 .577 .707 r
F P
0 g
s
.49847 .69506 m .49715 .67773 L .48098 .69058 L p .707 .577 .707 r
F P
0 g
s
.49439 .62203 m .49676 .65699 L .50368 .64369 L p .707 .577 .707 r
F P
0 g
s
.50368 .64369 m .50131 .60873 L .49439 .62203 L p .707 .577 .707 r
F P
0 g
s
.49922 .535 m .50141 .58882 L .49846 .57752 L p .707 .577 .707 r
F P
0 g
s
.49846 .57752 m .49627 .52369 L .49922 .535 L p .707 .577 .707 r
F P
0 g
s
.30078 .62795 m .30315 .66291 L .31586 .67432 L p .707 .577 .707 r
F P
0 g
s
.69179 .68807 m .69047 .67074 L .71971 .66344 L p .707 .577 .707 r
F P
0 g
s
.29545 .53749 m .29763 .59131 L .30059 .60262 L p .707 .577 .707 r
F P
0 g
s
.78259 .66118 m .78391 .6785 L .75277 .67747 L p .707 .577 .707 r
F P
0 g
s
.75277 .67747 m .75145 .66015 L .78259 .66118 L p .707 .577 .707 r
F P
0 g
s
.31767 .71383 m .31635 .69651 L .30362 .6847 L p .707 .577 .707 r
F P
0 g
s
.71971 .66344 m .72103 .68077 L .69179 .68807 L p .707 .577 .707 r
F P
0 g
s
.30315 .66291 m .30078 .62795 L .29774 .61496 L p .707 .577 .707 r
F P
0 g
s
.72103 .68077 m .71971 .66344 L .75145 .66015 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29763 .59131 m .29545 .53749 L .30247 .52606 L p .707 .577 .707 r
F P
0 g
s
.75145 .66015 m .75277 .67747 L .72103 .68077 L p .707 .577 .707 r
F P
0 g
s
.30362 .6847 m .30494 .70202 L .31767 .71383 L p .707 .577 .707 r
F P
0 g
s
.49715 .67773 m .49847 .69506 L .50535 .68121 L p .707 .577 .707 r
F P
0 g
s
.50535 .68121 m .50403 .66389 L .49715 .67773 L p .707 .577 .707 r
F P
0 g
s
.50131 .60873 m .50368 .64369 L .50064 .6307 L p .707 .577 .707 r
F P
0 g
s
.50064 .6307 m .49827 .59574 L .50131 .60873 L p .707 .577 .707 r
F P
0 g
s
.29774 .61496 m .3001 .64992 L .30315 .66291 L p .707 .577 .707 r
F P
0 g
s
.49627 .52369 m .49846 .57752 L .48582 .56744 L p .707 .577 .707 r
F P
0 g
s
.48582 .56744 m .48364 .51362 L .49627 .52369 L p .707 .577 .707 r
F P
0 g
s
.30247 .52606 m .30466 .57989 L .29763 .59131 L p .707 .577 .707 r
F P
0 g
s
.30494 .70202 m .30362 .6847 L .30054 .67121 L p .707 .577 .707 r
F P
0 g
s
.3001 .64992 m .29774 .61496 L .30466 .60167 L p .707 .577 .707 r
F P
0 g
s
.30466 .57989 m .30247 .52606 L .31878 .51563 L p .707 .577 .707 r
F P
0 g
s
.30054 .67121 m .30186 .68854 L .30494 .70202 L p .707 .577 .707 r
F P
0 g
s
.50403 .66389 m .50535 .68121 L .50227 .66773 L p .707 .577 .707 r
F P
0 g
s
.50227 .66773 m .50096 .6504 L .50403 .66389 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49827 .59574 m .50064 .6307 L .48793 .61928 L p .707 .577 .707 r
F P
0 g
s
.48793 .61928 m .48556 .58433 L .49827 .59574 L p .707 .577 .707 r
F P
0 g
s
.48364 .51362 m .48582 .56744 L .46474 .55958 L p .707 .577 .707 r
F P
0 g
s
.46474 .55958 m .46255 .50576 L .48364 .51362 L p .707 .577 .707 r
F P
0 g
s
.30466 .60167 m .30703 .63662 L .3001 .64992 L p .707 .577 .707 r
F P
0 g
s
.31878 .51563 m .32096 .56946 L .30466 .57989 L p .707 .577 .707 r
F P
0 g
s
.30186 .68854 m .30054 .67121 L .30742 .65737 L p .707 .577 .707 r
F P
0 g
s
.32096 .56946 m .31878 .51563 L .34278 .50722 L p .707 .577 .707 r
F P
0 g
s
.30703 .63662 m .30466 .60167 L .32087 .58937 L p .707 .577 .707 r
F P
0 g
s
.30742 .65737 m .30874 .67469 L .30186 .68854 L p .707 .577 .707 r
F P
0 g
s
.50096 .6504 m .50227 .66773 L .48954 .65592 L p .707 .577 .707 r
F P
0 g
s
.48954 .65592 m .48822 .6386 L .50096 .6504 L p .707 .577 .707 r
F P
0 g
s
.46255 .50576 m .46474 .55958 L .43727 .5547 L p .707 .577 .707 r
F P
0 g
s
.43727 .5547 m .43508 .50088 L .46255 .50576 L p .707 .577 .707 r
F P
0 g
s
.48556 .58433 m .48793 .61928 L .4668 .61056 L p .707 .577 .707 r
F P
0 g
s
.4668 .61056 m .46443 .57561 L .48556 .58433 L p .707 .577 .707 r
F P
0 g
s
.32087 .58937 m .32323 .62432 L .30703 .63662 L p .707 .577 .707 r
F P
0 g
s
.34496 .56104 m .34278 .50722 L .37211 .50165 L p .707 .577 .707 r
F P
0 g
s
.34278 .50722 m .34496 .56104 L .32096 .56946 L p .707 .577 .707 r
F P
0 g
s
.30874 .67469 m .30742 .65737 L .32359 .64452 L p .707 .577 .707 r
F P
0 g
s
.32323 .62432 m .32087 .58937 L .34477 .57927 L p .707 .577 .707 r
F P
0 g
s
.43508 .50088 m .43727 .5547 L .40611 .55329 L p .707 .577 .707 r
F P
0 g
s
.40611 .55329 m .40392 .49946 L .43508 .50088 L p .707 .577 .707 r
F P
0 g
s
.3743 .55547 m .37211 .50165 L .40392 .49946 L p .707 .577 .707 r
F P
0 g
s
.37211 .50165 m .3743 .55547 L .34496 .56104 L p .707 .577 .707 r
F P
0 g
s
.32359 .64452 m .32491 .66185 L .30874 .67469 L p .707 .577 .707 r
F P
0 g
s
.40392 .49946 m .40611 .55329 L .3743 .55547 L p .707 .577 .707 r
F P
0 g
s
.48822 .6386 m .48954 .65592 L .46839 .64695 L p .707 .577 .707 r
F P
0 g
s
.46839 .64695 m .46707 .62962 L .48822 .6386 L p .707 .577 .707 r
F P
0 g
s
.46443 .57561 m .4668 .61056 L .43931 .60539 L p .707 .577 .707 r
F P
0 g
s
.43931 .60539 m .43695 .57044 L .46443 .57561 L p .707 .577 .707 r
F P
0 g
s
.34477 .57927 m .34714 .61422 L .32323 .62432 L p .707 .577 .707 r
F P
0 g
s
.34714 .61422 m .34477 .57927 L .37404 .57236 L p .707 .577 .707 r
F P
0 g
s
.32491 .66185 m .32359 .64452 L .34746 .63393 L p .707 .577 .707 r
F P
0 g
s
.43695 .57044 m .43931 .60539 L .40817 .60427 L p .707 .577 .707 r
F P
0 g
s
.40817 .60427 m .4058 .56932 L .43695 .57044 L p .707 .577 .707 r
F P
0 g
s
.37641 .60731 m .37404 .57236 L .4058 .56932 L p .707 .577 .707 r
F P
0 g
s
.37404 .57236 m .37641 .60731 L .34714 .61422 L p .707 .577 .707 r
F P
0 g
s
.34746 .63393 m .34878 .65125 L .32491 .66185 L p .707 .577 .707 r
F P
0 g
s
.46707 .62962 m .46839 .64695 L .4409 .64169 L p .707 .577 .707 r
F P
0 g
s
.4409 .64169 m .43958 .62436 L .46707 .62962 L p .707 .577 .707 r
F P
0 g
s
.4058 .56932 m .40817 .60427 L .37641 .60731 L p .707 .577 .707 r
F P
0 g
s
.34878 .65125 m .34746 .63393 L .3767 .62663 L p .707 .577 .707 r
F P
0 g
s
.43958 .62436 m .4409 .64169 L .40976 .64065 L p .707 .577 .707 r
F P
0 g
s
.40976 .64065 m .40844 .62333 L .43958 .62436 L p .707 .577 .707 r
F P
0 g
s
.3767 .62663 m .37802 .64395 L .34878 .65125 L p .707 .577 .707 r
F P
0 g
s
.37802 .64395 m .3767 .62663 L .40844 .62333 L p .707 .577 .707 r
F P
0 g
s
.40844 .62333 m .40976 .64065 L .37802 .64395 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0028Ool<0029Ool007moo`T0
00IJEP03001JEUYF00=JEP`007eoo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MWoo001dOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000M7oo001aOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LWoo001]Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001`Ool006]oo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006io
o`00JWoo0P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0P00KGoo001YOol00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH00000Jgoo001WOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01@00FUIJEUYF0000JWoo001VOol00`00FUIJEP02FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1WOol006Eoo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo
001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000EJEP03
001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP80
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJ7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVQoo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF
J7oo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol0069oo`05001JEUYFFUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00Hgoo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIWOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVMoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEUYF01L000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001VOol0061oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
05aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001V
Ool005Yoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0067oo3`00?Woo001COol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P003goo2@0015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0027oo
0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001C
Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Woo0P000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
035oo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00MJ
EP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001C
Ool01000FUIJEP0015YF00<005YFFUH00eYF1@000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
1UYF100015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF0004
FUH00`00FUH000030004Ool01@00FUIJEUYF000015YF1@001UYF00<005YFFUH00eYF0`0015YF0`00
00AJEP00FUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEPL000=o
o`05001JEUYFFUH00004FUH:00000eYF001JEP0400000eYF001JEP05FUH01000FUH000000UYF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF0P000eYF00@005YFFUIJEPd0
00AJEP03001JEUYF009JEPT000IJEP06001JEUYFFUH005YF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
02eoo`00E7oo00<005YF00000P001EYF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00E7oo00D005YF001JEP0000EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH0
0`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol2
0003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol20003
FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP04FUH60009Ool80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Goo0011OolE0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP05001JEUYF
FUH00006FUH00`00FUIJEP040007Ool3000=Ool60004FUH01@00FUIJEUYF0000;Goo000mOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP05001JEUYF
FUH00005FUH4000:Ool5000>Ool20002FUH300000eYF001JEP02FUH2000/Ool003Uoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEP0000<000ioo`D0
00Uoo`D000EJEP04001JEP000003FUH2000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJEPP000AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF0P0000=JEP00FUH010002goo3`000UYF00<005YFFUH015YF00D005YF
FUIJEP00009JEP8002aoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00002FUH01@00FUIJEUYF00001EYF2`0015YF00<005YFFUH01UYF00<005YF0000
0`001EYF00<005YFFUH00UYF1000;7oo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH00`00FUIJEP04FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP04FUH3000/Ool002moo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH0000200001EYF000005YF00000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P001EYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0015YF0`00;7oo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH0
00050003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUIJEUYF
0P000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20000
0eYF001JEP04FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH20005FUH90004
FUH?0007FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00;7oo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00<005YF00001EYF00D005YFFUIJEP00009JEPL000AJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002eo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00UYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000AJEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020003FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`8000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP800003FUH005YF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Goo0P00
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`00
00=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000AJ
EP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04
001JEUYF000]Ool002eoo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP04001JEP000006FUH00`00FUIJEP04FUH70009FUH00`00FUIJEP02FUH7
0004FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00AJEQD0009JEP<000MJEP03001JEUYF00D000EJEP03001JEUYF00MJEPD0009JEP03001J
EUYF009JEP8000=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00@000Ioo`<000Yoo`800005FUH00000FUH00006FUH90005FUH01000
FUIJEUYF1`001UYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001P0000EJEP00FUIJEP0002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF10002Goo1@002Goo0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01@00
FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH01000
FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001goo0P000UYF
00<007ooOol0:goo000]Ool00`00FUH00004FUH00`00FUH00003000=Ool5000:Ool20004FUH01000
FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H0
05YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000AJEP05001JEP00001JEP040002FUH00`00FUIJEP06FUH:0002FUH4000<Ool00`00
FUH0000]Ool002eoo`03001JEP0000AJEPL000aoo`D000Qoo`@000AJEP800003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP03
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP8000AJEP03001JEUYF00/000AJEP03001JEUYF009JEPP000Yoo`@002eoo`00;Goo00<005YF0000
0UYF0P000eYF00@005YFFUIJEQT00004FUH005YF0002FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00009JEP800003FUH005YF
00=JEP04001JEUYFFUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000goo0P00
0UYF0`00;7oo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP02FUH5000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUIJEP00FUH30003FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH3000/Ool002eoo`05001JEP00FUH00005FUH0
0`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUH005YF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00P000eYF0`00;7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF0P000UYF0`000eYF00<005YF
FUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJEP00FUH002aoo`00;Goo0P00
0UYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF00<000EJEP03001JEUYF00AJEPH000moo`@0009JEP03001JEUYF00=JEP<0
0003FUH007oo02]oo`00;Goo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000IJ
EP04001JEUYFFUH200000eYF00000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`0000=JEP00FUH00P001UYF00<005YFFUH010004Woo100000=JEP00FUH01000
15YF00@005YF000002eoo`00;Goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000EJEP03001JEUYF00=JEPT0009JEPD0009JEPL000YJEP04001JEUYF
0003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P0000=JEP00FUH015YF100000=JEP00Ool037oo1`001EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0002eoo`00;Goo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00eYF00<005YF00000P000UYF00<005YF000020001EYF00<005YFFUH0
2EYF0`0015YF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF009JEP04001JEUYFFUH20003FUH@0004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH30002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF00800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF009JEP<000QJEP8000UJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEP04
001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH200000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001oo`0[Ool002moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF009JEPP000AJEP80009JEP03001JEP00008000EJEP03001JEUYF0080009JEP03001JEUYF
00=JEP03001JEUYF00QJEP03001JEUYF009JEP<000IJEP03001JEP0000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH01@00FUIJEUYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo0P00;7oo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008FUH700000eYF001JEP03FUH30002FUH00`00
FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP08FUH500000eYF001JEP06FUH20008FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
17oo0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH00`00FUH0000300000eYF00000002FUH00`00FUIJEP04FUH01000FUIJ
EUYF1`001EYF00<005YFFUH015YF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH20006Ool2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool01000FUH00000:goo000]Ool0
0`00FUH00004FUH01000FUIJEUYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH300000eYF001JEP06FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP04FUH40009Ool01000
FUIJEP00:goo000]Ool00`00FUH00004FUH01000FUH0000017oo200015YF00<005YFFUH00UYF2@00
1goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00EJEP03001JEP00008000IJEP03001JEUYF00AJEPD000EJEP03001JEUYF00@000aoo`80009JEP03
001oogoo02Uoo`00;Goo00@005YFFUH000=JEP8000ioo`T0019oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH500000eYF
00000005000>Ool2000015YF001JEP00;7oo000]Ool01000FUIJEP000UYF00<007ooOol04Goo2P00
4Goo10000UYF00<005YFFUH01EYF00<005YFFUH00eYF1`001eYF2P0035YF2@0025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEP0000l001=oo`8000AJEP8002aoo`00
;Goo00H005YFFUH005YF000?Ool70004FUH01000FUIJEUYF200027oo00@005YFFUIJEQ4000EJEP03
001JEUYF00H000UJEP03001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP06001J
EUYFFUH005YF0P000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`<001=oo`800003FUH005YF
00=JEP03001oogoo02]oo`00;Woo00@005YF000000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH50002Ool00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF
FUIJEP80009JEP05001JEUYFFUH00004FUH01@00FUIJEUYF000077oo0P000eYF00<005YFFUH00UYF
00<007ooOol0:goo000^Ool01@00FUH005YF00001goo10001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF100015YF00<005YF00002EYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00<0
05YFFUH00`0000=JEP00FUH00eYF00D005YFFUIJEP0001Uoo`<000EJEP03001JEUYF008002ioo`00
;Woo0P000UYF0`000goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P0015YF00<005YFFUH025YF00@005YFFUIJEP<000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<00003FUH005YF00=JEP04001JEUYF
0002FUH20005FUH01000FUIJEP005Goo100000=JEP00FUH01EYF0`00<7oo000^Ool20002FUH00`00
FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH025YF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00P0015YF0P0000=JEP00FUH00eYF1P000UYF
00<007ooOol037oo1`001EYF00<005YFFUH00eYF0P00<Woo000^Ool20002FUH01000FUH000001UYF
00<005YFFUH015YF1P002Goo200015YF00<005YFFUH00UYF0P0000=JEP0000002EYF0P000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF00@005YFFUIJEP@000EJEP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00=7oo000^Ool20002FUH30007FUH00`00FUIJEP050009Ool70006FUH50004FUH00`00FUH0
00020007FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=Woo000^Ool20002FUH00`00
FUH00006FUH50004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEP00
1UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH01EYF0`000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo000_Ool00`00FUH00003FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP0000AJEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Aoo`800003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@003]oo`00;goo0P0015YF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01`00
FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPL003moo`00;goo0P0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0P000Woo00<005YF00000UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH015YF0`002Goo5000AWoo000_Ool20003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000`0017oo0P0015YF0`00Dgoo000^Ool01000FUH005YF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00@005YFFUIJEP80
00Moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP@00003FUH0
05YF00=JEP<005=oo`00;Woo00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000IJEP03001JEUYF00EJEP04001JEP000009Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUH000020003FUH00`00FUH0001COol002ioo`03001JEP0000Aoo`80
0003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<000Yoo`@000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEP800004FUH005YF001COol002ioo`80
00Moo`D000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000eoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH4001DOol002ioo`8000aoo`T000=J
EP<000=JEPL000moo`<00003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00<0009JEP03001JEUYF00=JEP@005Aoo`00;Woo0P005Goo2@0057oo0P000UYF0P0000=oo`00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00FUH40004FUH00`00FUH0001EOol0
02ioo`<0031oo`03001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP8000AJEP03001JEUYF00=JEP<00005FUH005YFFUH0001DOol002ioo`800003FUH007oo02aoo`<0
00AJEP05001oogooOol00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP020006FUH00`00FUIJEP05FUH3
0002FUH00`00Oomoo`1BOol002ioo`80009JEP03001oogoo02Qoo`80009JEP03001JEUYF009JEP03
001oogoo009oo`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000QJEP03001JEUYF00AJEP@00003FUH0000005=oo`00
;goo00<005YFFUH00`009Woo0P001EYF00@005YFFUH000Moo`8000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=oo`<005=oo`00;goo00@005YFFUH0009JEP80029oo`8000MJEP<000Uo
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20006Ool2001COol0031oo`04001JEUYF
0003FUH5000IOol400000eYF001JEP05FUH2000=Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040006FUH00`00FUIJEP06FUH01000FUH0
000027oo0P00Dgoo000aOol30004FUH01000FUIJEUYF2@002Goo1`001EYF00<005YFFUH00UYF0P00
4Goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF0`0000=J
EP0000000`001EYF00<005YFFUH015YF10002Goo00@005YF0000059oo`00<goo00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000001Ioo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP@000AJEPD000EJEP03001JEUYF00@0
00eoo`04001JEUYF001BOol003Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<001aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP00
00<00003FUH005YF00EJEPD00003FUH0000000D0011oo`80009JEP03001oogoo051oo`00=Woo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P009Goo2@001UYF
00<005YFFUH015YF20000goo3`005Woo00D005YF001JEP0005=oo`00>7oo1@0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YF00000P00<7oo3@00;goo00@005YFFUIJEP8005=oo`00?Goo6000
>goo00<005YF0000;goo0P0015YF00<007ooOol0DWoo002@Ool200000eYF001oo`0[Ool200000eYF
001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF008002Qoo`8000=JEP05001JEUYFFUH0001E
Ool0095oo`05001JEUYF001JEP03000ROol30005FUH01000FUH00000EWoo002BOol00`00FUH00004
FUH3000KOol400000eYF001JEP05FUH2001HOol0099oo`03001JEP0000EJEP03001JEP0000<0011o
o`L000EJEP03001JEUYF00=JEP8005Uoo`00Tgoo0P001EYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00@005YFFUIJEP8005]oo`00U7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF000005eoo`00UWoo0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00Ggoo002IOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04001ROol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF009J
EPL006Ioo`00X7oo4000KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60054 .7639 m .59701 .71144 L .56587 .71032 L p .707 .577 .707 r
F P
0 g
s
.59701 .71144 m .60054 .7639 L .6323 .76087 L p .707 .577 .707 r
F P
0 g
s
.6323 .76087 m .62878 .70841 L .59701 .71144 L p .707 .577 .707 r
F P
0 g
s
.62878 .70841 m .6323 .76087 L .66157 .75399 L p .707 .577 .707 r
F P
0 g
s
.66157 .75399 m .65804 .70153 L .62878 .70841 L p .707 .577 .707 r
F P
0 g
s
.56939 .76278 m .56587 .71032 L .53838 .70515 L p .707 .577 .707 r
F P
0 g
s
.56587 .71032 m .56939 .76278 L .60054 .7639 L p .707 .577 .707 r
F P
0 g
s
.65804 .70153 m .66157 .75399 L .68548 .74392 L p .707 .577 .707 r
F P
0 g
s
.68548 .74392 m .68195 .69146 L .65804 .70153 L p .707 .577 .707 r
F P
0 g
s
.54191 .75761 m .53838 .70515 L .51726 .69645 L p .707 .577 .707 r
F P
0 g
s
.53838 .70515 m .54191 .75761 L .56939 .76278 L p .707 .577 .707 r
F P
0 g
s
.68195 .69146 m .68548 .74392 L .70169 .73165 L p .707 .577 .707 r
F P
0 g
s
.70169 .73165 m .69816 .67919 L .68195 .69146 L p .707 .577 .707 r
F P
0 g
s
.60517 .83349 m .60137 .80032 L .57027 .79966 L p .707 .577 .707 r
F P
0 g
s
.60137 .80032 m .60517 .83349 L .63682 .82912 L p .707 .577 .707 r
F P
0 g
s
.63682 .82912 m .63301 .79595 L .60137 .80032 L p .707 .577 .707 r
F P
0 g
s
.63301 .79595 m .63682 .82912 L .6659 .82015 L p .707 .577 .707 r
F P
0 g
s
.6659 .82015 m .66209 .78698 L .63301 .79595 L p .707 .577 .707 r
F P
0 g
s
.57407 .83282 m .57027 .79966 L .54274 .79403 L p .707 .577 .707 r
F P
0 g
s
.57027 .79966 m .57407 .83282 L .60517 .83349 L p .707 .577 .707 r
F P
0 g
s
.52078 .7489 m .51726 .69645 L .50455 .68505 L p .707 .577 .707 r
F P
0 g
s
.51726 .69645 m .52078 .7489 L .54191 .75761 L p .707 .577 .707 r
F P
0 g
s
.66209 .78698 m .6659 .82015 L .68957 .80745 L p .707 .577 .707 r
F P
0 g
s
.68957 .80745 m .68576 .77429 L .66209 .78698 L p .707 .577 .707 r
F P
0 g
s
.69816 .67919 m .70169 .73165 L .70861 .71838 L p .707 .577 .707 r
F P
0 g
s
.70861 .71838 m .70508 .66593 L .69816 .67919 L p .707 .577 .707 r
F P
0 g
s
.54654 .8272 m .54274 .79403 L .52149 .78398 L p .707 .577 .707 r
F P
0 g
s
.54274 .79403 m .54654 .8272 L .57407 .83282 L p .707 .577 .707 r
F P
0 g
s
.68576 .77429 m .68957 .80745 L .70551 .79228 L p .707 .577 .707 r
F P
0 g
s
.70551 .79228 m .70171 .75911 L .68576 .77429 L p .707 .577 .707 r
F P
0 g
s
.60827 .88068 m .60615 .8644 L .57506 .86387 L p .707 .577 .707 r
F P
0 g
s
.60615 .8644 m .60827 .88068 L .63986 .87593 L p .707 .577 .707 r
F P
0 g
s
.63986 .87593 m .63775 .85965 L .60615 .8644 L p .707 .577 .707 r
F P
0 g
s
.50803 .82845 m .47601 .35497 L .43203 .35338 L p .707 .577 .707 r
F P
0 g
s
.50455 .68505 m .50808 .73751 L .52078 .7489 L p .707 .577 .707 r
F P
0 g
s
.50808 .73751 m .50455 .68505 L .50151 .67209 L p .707 .577 .707 r
F P
0 g
s
.52149 .78398 m .52529 .81715 L .54654 .8272 L p .707 .577 .707 r
F P
0 g
s
.52529 .81715 m .52149 .78398 L .5086 .77051 L p .707 .577 .707 r
F P
0 g
s
.50151 .67209 m .50503 .72455 L .50808 .73751 L p .707 .577 .707 r
F P
0 g
s
.5086 .77051 m .5124 .80368 L .52529 .81715 L p .707 .577 .707 r
F P
0 g
s
.50503 .72455 m .50151 .67209 L .50843 .65883 L p .707 .577 .707 r
F P
0 g
s
.5124 .80368 m .5086 .77051 L .50532 .75492 L p .707 .577 .707 r
F P
0 g
s
.50843 .65883 m .51196 .71128 L .50503 .72455 L p .707 .577 .707 r
F P
0 g
s
.50532 .75492 m .50912 .78809 L .5124 .80368 L p .707 .577 .707 r
F P
0 g
s
.51196 .71128 m .50843 .65883 L .52464 .64656 L p .707 .577 .707 r
F P
0 g
s
.50912 .78809 m .50532 .75492 L .51198 .73874 L p .707 .577 .707 r
F P
0 g
s
.51537 .84988 m .51326 .8336 L .50989 .81726 L p .707 .577 .707 r
F P
0 g
s
.50989 .81726 m .512 .83354 L .51537 .84988 L p .707 .577 .707 r
F P
0 g
s
.52464 .64656 m .52817 .69902 L .51196 .71128 L p .707 .577 .707 r
F P
0 g
s
.51198 .73874 m .51578 .77191 L .50912 .78809 L p .707 .577 .707 r
F P
0 g
s
.52817 .69902 m .52464 .64656 L .54855 .63649 L p .707 .577 .707 r
F P
0 g
s
.51578 .77191 m .51198 .73874 L .52793 .72357 L p .707 .577 .707 r
F P
0 g
s
.512 .83354 m .50989 .81726 L .51644 .80025 L p .707 .577 .707 r
F P
0 g
s
.54855 .63649 m .55208 .68895 L .52817 .69902 L p .707 .577 .707 r
F P
0 g
s
.51644 .80025 m .51856 .81653 L .512 .83354 L p .707 .577 .707 r
F P
0 g
s
.52793 .72357 m .53173 .75673 L .51578 .77191 L p .707 .577 .707 r
F P
0 g
s
.53173 .75673 m .52793 .72357 L .5516 .71087 L p .707 .577 .707 r
F P
0 g
s
.51856 .81653 m .51644 .80025 L .53229 .78423 L p .707 .577 .707 r
F P
0 g
s
.53229 .78423 m .5344 .80051 L .51856 .81653 L p .707 .577 .707 r
F P
0 g
s
.5516 .71087 m .5554 .74404 L .53173 .75673 L p .707 .577 .707 r
F P
0 g
s
.5344 .80051 m .53229 .78423 L .55587 .77078 L p .707 .577 .707 r
F P
0 g
s
.55587 .77078 m .55798 .78706 L .5344 .80051 L p .707 .577 .707 r
F P
0 g
s
.47601 .35497 m .50803 .82845 L .55287 .82415 L p .707 .577 .707 r
F P
0 g
s
.55287 .82415 m .52084 .35067 L .47601 .35497 L p .707 .577 .707 r
F P
0 g
s
.63775 .85965 m .63986 .87593 L .66887 .86636 L p .707 .577 .707 r
F P
0 g
s
.66887 .86636 m .66675 .85008 L .63775 .85965 L p .707 .577 .707 r
F P
0 g
s
.55208 .68895 m .54855 .63649 L .57782 .6296 L p .707 .577 .707 r
F P
0 g
s
.57782 .6296 m .58134 .68206 L .55208 .68895 L p .707 .577 .707 r
F P
0 g
s
.5554 .74404 m .5516 .71087 L .58068 .7019 L p .707 .577 .707 r
F P
0 g
s
.58068 .7019 m .58448 .73507 L .5554 .74404 L p .707 .577 .707 r
F P
0 g
s
.55798 .78706 m .55587 .77078 L .58487 .76121 L p .707 .577 .707 r
F P
0 g
s
.58699 .77749 m .58487 .76121 L .61647 .75646 L p .707 .577 .707 r
F P
0 g
s
.58487 .76121 m .58699 .77749 L .55798 .78706 L p .707 .577 .707 r
F P
0 g
s
.61647 .75646 m .61858 .77274 L .58699 .77749 L p .707 .577 .707 r
F P
0 g
s
.52084 .35067 m .55287 .82415 L .59419 .8144 L p .707 .577 .707 r
F P
0 g
s
.58134 .68206 m .57782 .6296 L .60958 .62657 L p .707 .577 .707 r
F P
0 g
s
.60958 .62657 m .61311 .67903 L .58134 .68206 L p .707 .577 .707 r
F P
0 g
s
.58448 .73507 m .58068 .7019 L .61232 .69753 L p .707 .577 .707 r
F P
0 g
s
.61232 .69753 m .61612 .7307 L .58448 .73507 L p .707 .577 .707 r
F P
0 g
s
.59419 .8144 m .56216 .34092 L .52084 .35067 L p .707 .577 .707 r
F P
0 g
s
.57718 .88015 m .57506 .86387 L .54752 .85811 L p .707 .577 .707 r
F P
0 g
s
.57506 .86387 m .57718 .88015 L .60827 .88068 L p .707 .577 .707 r
F P
0 g
s
.46406 .82686 m .43203 .35338 L .39323 .34608 L p .707 .577 .707 r
F P
0 g
s
.43203 .35338 m .46406 .82686 L .50803 .82845 L p .707 .577 .707 r
F P
0 g
s
.66675 .85008 m .66887 .86636 L .69245 .8529 L p .707 .577 .707 r
F P
0 g
s
.69245 .8529 m .69033 .83663 L .66675 .85008 L p .707 .577 .707 r
F P
0 g
s
.54752 .85811 m .54964 .87439 L .57718 .88015 L p .707 .577 .707 r
F P
0 g
s
.70508 .66593 m .70861 .71838 L .70557 .70542 L p .707 .577 .707 r
F P
0 g
s
.70557 .70542 m .70204 .65296 L .70508 .66593 L p .707 .577 .707 r
F P
0 g
s
.64342 .6982 m .64723 .73136 L .61612 .7307 L p .707 .577 .707 r
F P
0 g
s
.61612 .7307 m .61232 .69753 L .64342 .6982 L p .707 .577 .707 r
F P
0 g
s
.64756 .75699 m .64967 .77327 L .61858 .77274 L p .707 .577 .707 r
F P
0 g
s
.61858 .77274 m .61647 .75646 L .64756 .75699 L p .707 .577 .707 r
F P
0 g
s
.56216 .34092 m .59419 .8144 L .62794 .80015 L p .707 .577 .707 r
F P
0 g
s
.64072 .6277 m .64425 .68016 L .61311 .67903 L p .707 .577 .707 r
F P
0 g
s
.61311 .67903 m .60958 .62657 L .64072 .6277 L p .707 .577 .707 r
F P
0 g
s
.62794 .80015 m .59591 .32667 L .56216 .34092 L p .707 .577 .707 r
F P
0 g
s
.70171 .75911 m .70551 .79228 L .71217 .7761 L p .707 .577 .707 r
F P
0 g
s
.71217 .7761 m .70837 .74293 L .70171 .75911 L p .707 .577 .707 r
F P
0 g
s
.54964 .87439 m .54752 .85811 L .52622 .84768 L p .707 .577 .707 r
F P
0 g
s
.69033 .83663 m .69245 .8529 L .70829 .83689 L p .707 .577 .707 r
F P
0 g
s
.70829 .83689 m .70618 .82061 L .69033 .83663 L p .707 .577 .707 r
F P
0 g
s
.42526 .81956 m .39323 .34608 L .3634 .33377 L p .707 .577 .707 r
F P
0 g
s
.39323 .34608 m .42526 .81956 L .46406 .82686 L p .707 .577 .707 r
F P
0 g
s
.52622 .84768 m .52834 .86396 L .54964 .87439 L p .707 .577 .707 r
F P
0 g
s
.52834 .86396 m .52622 .84768 L .51326 .8336 L p .707 .577 .707 r
F P
0 g
s
.6751 .76275 m .67721 .77903 L .64967 .77327 L p .707 .577 .707 r
F P
0 g
s
.64967 .77327 m .64756 .75699 L .6751 .76275 L p .707 .577 .707 r
F P
0 g
s
.59591 .32667 m .62794 .80015 L .65082 .7828 L p .707 .577 .707 r
F P
0 g
s
.67095 .70383 m .67475 .73699 L .64723 .73136 L p .707 .577 .707 r
F P
0 g
s
.64723 .73136 m .64342 .6982 L .67095 .70383 L p .707 .577 .707 r
F P
0 g
s
.65082 .7828 m .61879 .30932 L .59591 .32667 L p .707 .577 .707 r
F P
0 g
s
.70204 .65296 m .70557 .70542 L .69286 .69403 L p .707 .577 .707 r
F P
0 g
s
.69286 .69403 m .68934 .64157 L .70204 .65296 L p .707 .577 .707 r
F P
0 g
s
.70837 .74293 m .71217 .7761 L .7089 .76051 L p .707 .577 .707 r
F P
0 g
s
.7089 .76051 m .70509 .72735 L .70837 .74293 L p .707 .577 .707 r
F P
0 g
s
.70618 .82061 m .70829 .83689 L .71485 .81988 L p .707 .577 .707 r
F P
0 g
s
.71485 .81988 m .71273 .8036 L .70618 .82061 L p .707 .577 .707 r
F P
0 g
s
.51326 .8336 m .51537 .84988 L .52834 .86396 L p .707 .577 .707 r
F P
0 g
s
.39543 .80725 m .3634 .33377 L .34546 .31766 L p .707 .577 .707 r
F P
0 g
s
.3634 .33377 m .39543 .80725 L .42526 .81956 L p .707 .577 .707 r
F P
0 g
s
.25753 .72709 m .25401 .67463 L .22286 .6735 L p .707 .577 .707 r
F P
0 g
s
.25401 .67463 m .25753 .72709 L .2893 .72406 L p .707 .577 .707 r
F P
0 g
s
.2893 .72406 m .28577 .6716 L .25401 .67463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28577 .6716 m .2893 .72406 L .31856 .71717 L p .707 .577 .707 r
F P
0 g
s
.31856 .71717 m .31504 .66471 L .28577 .6716 L p .707 .577 .707 r
F P
0 g
s
.22639 .72596 m .22286 .6735 L .19538 .66834 L p .707 .577 .707 r
F P
0 g
s
.22286 .6735 m .22639 .72596 L .25753 .72709 L p .707 .577 .707 r
F P
0 g
s
.68934 .64157 m .69286 .69403 L .67174 .68532 L p .707 .577 .707 r
F P
0 g
s
.67174 .68532 m .66821 .63287 L .68934 .64157 L p .707 .577 .707 r
F P
0 g
s
.70509 .72735 m .7089 .76051 L .696 .74704 L p .707 .577 .707 r
F P
0 g
s
.696 .74704 m .6922 .71387 L .70509 .72735 L p .707 .577 .707 r
F P
0 g
s
.71273 .8036 m .71485 .81988 L .71148 .80353 L p .707 .577 .707 r
F P
0 g
s
.71148 .80353 m .70936 .78725 L .71273 .8036 L p .707 .577 .707 r
F P
0 g
s
.31504 .66471 m .31856 .71717 L .34247 .7071 L p .707 .577 .707 r
F P
0 g
s
.34247 .7071 m .33894 .65464 L .31504 .66471 L p .707 .577 .707 r
F P
0 g
s
.66821 .63287 m .67174 .68532 L .64425 .68016 L p .707 .577 .707 r
F P
0 g
s
.64425 .68016 m .64072 .6277 L .66821 .63287 L p .707 .577 .707 r
F P
0 g
s
.61879 .30932 m .65082 .7828 L .66059 .76403 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .62857 .29055 L .61879 .30932 L p .707 .577 .707 r
F P
0 g
s
.1989 .72079 m .19538 .66834 L .17425 .65963 L p .707 .577 .707 r
F P
0 g
s
.19538 .66834 m .1989 .72079 L .22639 .72596 L p .707 .577 .707 r
F P
0 g
s
.33894 .65464 m .34247 .7071 L .35868 .69483 L p .707 .577 .707 r
F P
0 g
s
.35868 .69483 m .35515 .64238 L .33894 .65464 L p .707 .577 .707 r
F P
0 g
s
.6922 .71387 m .696 .74704 L .67475 .73699 L p .707 .577 .707 r
F P
0 g
s
.67475 .73699 m .67095 .70383 L .6922 .71387 L p .707 .577 .707 r
F P
0 g
s
.37749 .79114 m .34546 .31766 L .34117 .29933 L p .707 .577 .707 r
F P
0 g
s
.34546 .31766 m .37749 .79114 L .39543 .80725 L p .707 .577 .707 r
F P
0 g
s
.26217 .79667 m .25836 .7635 L .22726 .76284 L p .707 .577 .707 r
F P
0 g
s
.25836 .7635 m .26217 .79667 L .29381 .79231 L p .707 .577 .707 r
F P
0 g
s
.29381 .79231 m .29001 .75914 L .25836 .7635 L p .707 .577 .707 r
F P
0 g
s
.29001 .75914 m .29381 .79231 L .32289 .78334 L p .707 .577 .707 r
F P
0 g
s
.32289 .78334 m .31908 .75017 L .29001 .75914 L p .707 .577 .707 r
F P
0 g
s
.70936 .78725 m .71148 .80353 L .69851 .78946 L p .707 .577 .707 r
F P
0 g
s
.69851 .78946 m .69639 .77318 L .70936 .78725 L p .707 .577 .707 r
F P
0 g
s
.23106 .79601 m .22726 .76284 L .19973 .75721 L p .707 .577 .707 r
F P
0 g
s
.22726 .76284 m .23106 .79601 L .26217 .79667 L p .707 .577 .707 r
F P
0 g
s
.17777 .71209 m .17425 .65963 L .16154 .64824 L p .707 .577 .707 r
F P
0 g
s
.17425 .65963 m .17777 .71209 L .1989 .72079 L p .707 .577 .707 r
F P
0 g
s
.31908 .75017 m .32289 .78334 L .34656 .77064 L p .707 .577 .707 r
F P
0 g
s
.34656 .77064 m .34276 .73747 L .31908 .75017 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .6563 .7457 L p .65047 .65 L .707 .577 .707 r
F P
0 g
s
.65047 .65 m .64491 .55872 L .64886 .61047 L .707 .577 .707 r
F
.65047 .65 m .64886 .61047 L .66059 .76403 L F
.64057 .468 m .66059 .76403 L p .64491 .55872 L F P
0 g
s
.62427 .27222 m .62857 .29055 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.6563 .7457 m .64793 .62198 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.64793 .62198 m .62427 .27222 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.62427 .27222 m .6563 .7457 L .63836 .72959 L p .707 .577 .707 r
F P
0 g
s
.6458 .66756 m .6496 .70073 L .6518 .70302 L p .707 .577 .707 r
F P
0 g
s
.6518 .70302 m .6625 .7142 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.65077 .68144 m .6458 .66756 L .6518 .70302 L .707 .577 .707 r
F
.66554 .75223 m .66343 .73595 L .65353 .72521 L p F P
0 g
s
.65353 .72521 m .65046 .72188 L p .65365 .7283 L .707 .577 .707 r
F P
0 g
s
.66554 .75223 m .65353 .72521 L .65365 .7283 L .707 .577 .707 r
F
.6625 .7142 m .6587 .68103 L .65033 .67229 L p F P
0 g
s
.65033 .67229 m .6458 .66756 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.6625 .7142 m .65033 .67229 L .65077 .68144 L .707 .577 .707 r
F
.62857 .29055 m .64057 .468 L p .64491 .55872 L F P
0 g
s
.35515 .64238 m .35868 .69483 L .3656 .68157 L p .707 .577 .707 r
F P
0 g
s
.3656 .68157 m .36208 .62911 L .35515 .64238 L p .707 .577 .707 r
F P
0 g
s
.20354 .79038 m .19973 .75721 L .17848 .74717 L p .707 .577 .707 r
F P
0 g
s
.19973 .75721 m .20354 .79038 L .23106 .79601 L p .707 .577 .707 r
F P
0 g
s
.69639 .77318 m .69851 .78946 L .67721 .77903 L p .707 .577 .707 r
F P
0 g
s
.67721 .77903 m .6751 .76275 L .69639 .77318 L p .707 .577 .707 r
F P
0 g
s
.34276 .73747 m .34656 .77064 L .3625 .75546 L p .707 .577 .707 r
F P
0 g
s
.3625 .75546 m .3587 .72229 L .34276 .73747 L p .707 .577 .707 r
F P
0 g
s
.26526 .84386 m .26314 .82758 L .23205 .82705 L p .707 .577 .707 r
F P
0 g
s
.26314 .82758 m .26526 .84386 L .29685 .83911 L p .707 .577 .707 r
F P
0 g
s
.29685 .83911 m .29474 .82283 L .26314 .82758 L p .707 .577 .707 r
F P
0 g
s
.29474 .82283 m .29685 .83911 L .32586 .82954 L p .707 .577 .707 r
F P
0 g
s
.32586 .82954 m .32374 .81326 L .29474 .82283 L p .707 .577 .707 r
F P
0 g
s
.16154 .64824 m .16507 .7007 L .17777 .71209 L p .707 .577 .707 r
F P
0 g
s
.16507 .7007 m .16154 .64824 L .1585 .63528 L p .707 .577 .707 r
F P
0 g
s
.23417 .84333 m .23205 .82705 L .20451 .82129 L p .707 .577 .707 r
F P
0 g
s
.23205 .82705 m .23417 .84333 L .26526 .84386 L p .707 .577 .707 r
F P
0 g
s
.32374 .81326 m .32586 .82954 L .34944 .81609 L p .707 .577 .707 r
F P
0 g
s
.34944 .81609 m .34732 .79981 L .32374 .81326 L p .707 .577 .707 r
F P
0 g
s
.34117 .29933 m .37319 .77281 L .37749 .79114 L p .707 .577 .707 r
F P
0 g
s
.37319 .77281 m .34117 .29933 L .35094 .28057 L p .707 .577 .707 r
F P
0 g
s
.17848 .74717 m .18229 .78034 L .20354 .79038 L p .707 .577 .707 r
F P
0 g
s
.18229 .78034 m .17848 .74717 L .16559 .73369 L p .707 .577 .707 r
F P
0 g
s
.20451 .82129 m .20663 .83757 L .23417 .84333 L p .707 .577 .707 r
F P
0 g
s
.36208 .62911 m .3656 .68157 L .36256 .66861 L p .707 .577 .707 r
F P
0 g
s
.36256 .66861 m .35904 .61615 L .36208 .62911 L p .707 .577 .707 r
F P
0 g
s
.3587 .72229 m .3625 .75546 L .36916 .73929 L p .707 .577 .707 r
F P
0 g
s
.36916 .73929 m .36536 .70612 L .3587 .72229 L p .707 .577 .707 r
F P
0 g
s
.20663 .83757 m .20451 .82129 L .18322 .81086 L p .707 .577 .707 r
F P
0 g
s
.34732 .79981 m .34944 .81609 L .36528 .80007 L p .707 .577 .707 r
F P
0 g
s
.36528 .80007 m .36317 .78379 L .34732 .79981 L p .707 .577 .707 r
F P
0 g
s
.63836 .72959 m .60633 .25611 L .62427 .27222 L p .707 .577 .707 r
F P
0 g
s
.1585 .63528 m .16203 .68773 L .16507 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18322 .81086 m .18533 .82714 L .20663 .83757 L p .707 .577 .707 r
F P
0 g
s
.16559 .73369 m .16939 .76686 L .18229 .78034 L p .707 .577 .707 r
F P
0 g
s
.16203 .68773 m .1585 .63528 L .16542 .62201 L p .707 .577 .707 r
F P
0 g
s
.16939 .76686 m .16559 .73369 L .16231 .7181 L p .707 .577 .707 r
F P
0 g
s
.18533 .82714 m .18322 .81086 L .17025 .79679 L p .707 .577 .707 r
F P
0 g
s
.35904 .61615 m .36256 .66861 L .34986 .65722 L p .707 .577 .707 r
F P
0 g
s
.34986 .65722 m .34633 .60476 L .35904 .61615 L p .707 .577 .707 r
F P
0 g
s
.36536 .70612 m .36916 .73929 L .36589 .7237 L p .707 .577 .707 r
F P
0 g
s
.36589 .7237 m .36208 .69053 L .36536 .70612 L p .707 .577 .707 r
F P
0 g
s
.36317 .78379 m .36528 .80007 L .37184 .78306 L p .707 .577 .707 r
F P
0 g
s
.37184 .78306 m .36972 .76678 L .36317 .78379 L p .707 .577 .707 r
F P
0 g
s
.38297 .75405 m .35094 .28057 L .37382 .26321 L p .707 .577 .707 r
F P
0 g
s
.35094 .28057 m .38297 .75405 L .37319 .77281 L p .707 .577 .707 r
F P
0 g
s
.17025 .79679 m .17236 .81307 L .18533 .82714 L p .707 .577 .707 r
F P
0 g
s
.16542 .62201 m .16895 .67447 L .16203 .68773 L p .707 .577 .707 r
F P
0 g
s
.16231 .7181 m .16611 .75127 L .16939 .76686 L p .707 .577 .707 r
F P
0 g
s
.16895 .67447 m .16542 .62201 L .18163 .60974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.60633 .25611 m .63836 .72959 L .60853 .71728 L p .707 .577 .707 r
F P
0 g
s
.60853 .71728 m .5765 .2438 L .60633 .25611 L p .707 .577 .707 r
F P
0 g
s
.16611 .75127 m .16231 .7181 L .16897 .70193 L p .707 .577 .707 r
F P
0 g
s
.17236 .81307 m .17025 .79679 L .16688 .78044 L p .707 .577 .707 r
F P
0 g
s
.34633 .60476 m .34986 .65722 L .32873 .64851 L p .707 .577 .707 r
F P
0 g
s
.32873 .64851 m .3252 .59605 L .34633 .60476 L p .707 .577 .707 r
F P
0 g
s
.36208 .69053 m .36589 .7237 L .35299 .71022 L p .707 .577 .707 r
F P
0 g
s
.35299 .71022 m .34919 .67705 L .36208 .69053 L p .707 .577 .707 r
F P
0 g
s
.36972 .76678 m .37184 .78306 L .36847 .76672 L p .707 .577 .707 r
F P
0 g
s
.36847 .76672 m .36635 .75044 L .36972 .76678 L p .707 .577 .707 r
F P
0 g
s
.16688 .78044 m .16899 .79672 L .17236 .81307 L p .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .38297 .75405 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.38215 .38639 m .40585 .73669 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .37382 .26321 L .40757 .24896 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40585 .73669 L p .40643 .57268 L .707 .577 .707 r
F P
0 g
s
.40643 .57268 m .42334 .61922 L .4396 .72244 L .707 .577 .707 r
F
.43123 .59872 m .43473 .65055 L p .40664 .51311 L F P
0 g
s
.43473 .65055 m .4396 .72244 L p .42334 .61922 L .707 .577 .707 r
F P
0 g
s
.40664 .51311 m .43473 .65055 L .42334 .61922 L .707 .577 .707 r
F
.44889 .23921 m .48092 .71269 L .4396 .72244 L p F P
0 g
s
.46306 .71782 m .46095 .70154 L .45409 .7038 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40757 .24896 L .44889 .23921 L p .707 .577 .707 r
F P
0 g
s
.45409 .7038 m .43194 .71111 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.46306 .71782 m .45409 .7038 L .45886 .71691 L .707 .577 .707 r
F
.43194 .71111 m .43405 .72739 L .4596 .71896 L p F P
0 g
s
.4596 .71896 m .46306 .71782 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.45886 .71691 m .43194 .71111 L .4596 .71896 L .707 .577 .707 r
F
.40643 .57268 m .40664 .51311 L .42334 .61922 L F
.40757 .24896 m .43123 .59872 L p .40664 .51311 L F P
0 g
s
.42721 .65619 m .43101 .68936 L .45513 .68192 L p .707 .577 .707 r
F P
0 g
s
.45513 .68192 m .46009 .68038 L p .45324 .67534 L .707 .577 .707 r
F P
0 g
s
.45324 .67534 m .42721 .65619 L .45513 .68192 L .707 .577 .707 r
F
.39557 .66055 m .39937 .69372 L .42406 .69032 L p F P
0 g
s
.42406 .69032 m .43101 .68936 L p .42303 .68287 L .707 .577 .707 r
F P
0 g
s
.42303 .68287 m .39557 .66055 L .42406 .69032 L .707 .577 .707 r
F
.37382 .26321 m .38215 .38639 L p .37517 .33577 L F P
0 g
s
.18163 .60974 m .18516 .6622 L .16895 .67447 L p .707 .577 .707 r
F P
0 g
s
.16897 .70193 m .17277 .7351 L .16611 .75127 L p .707 .577 .707 r
F P
0 g
s
.18516 .6622 m .18163 .60974 L .20554 .59967 L p .707 .577 .707 r
F P
0 g
s
.17277 .7351 m .16897 .70193 L .18492 .68675 L p .707 .577 .707 r
F P
0 g
s
.3252 .59605 m .32873 .64851 L .30124 .64334 L p .707 .577 .707 r
F P
0 g
s
.30124 .64334 m .29772 .59088 L .3252 .59605 L p .707 .577 .707 r
F P
0 g
s
.16899 .79672 m .16688 .78044 L .17343 .76343 L p .707 .577 .707 r
F P
0 g
s
.5765 .2438 m .60853 .71728 L .56973 .70998 L p .707 .577 .707 r
F P
0 g
s
.56973 .70998 m .5377 .2365 L .5765 .2438 L p .707 .577 .707 r
F P
0 g
s
.34919 .67705 m .35299 .71022 L .33174 .70018 L p .707 .577 .707 r
F P
0 g
s
.33174 .70018 m .32794 .66701 L .34919 .67705 L p .707 .577 .707 r
F P
0 g
s
.36635 .75044 m .36847 .76672 L .3555 .75264 L p .707 .577 .707 r
F P
0 g
s
.3555 .75264 m .35339 .73636 L .36635 .75044 L p .707 .577 .707 r
F P
0 g
s
.20907 .65213 m .20554 .59967 L .23481 .59279 L p .707 .577 .707 r
F P
0 g
s
.20554 .59967 m .20907 .65213 L .18516 .6622 L p .707 .577 .707 r
F P
0 g
s
.17343 .76343 m .17555 .77971 L .16899 .79672 L p .707 .577 .707 r
F P
0 g
s
.29772 .59088 m .30124 .64334 L .2701 .64222 L p .707 .577 .707 r
F P
0 g
s
.2701 .64222 m .26657 .58976 L .29772 .59088 L p .707 .577 .707 r
F P
0 g
s
.18492 .68675 m .18872 .71992 L .17277 .7351 L p .707 .577 .707 r
F P
0 g
s
.23833 .64525 m .23481 .59279 L .26657 .58976 L p .707 .577 .707 r
F P
0 g
s
.23481 .59279 m .23833 .64525 L .20907 .65213 L p .707 .577 .707 r
F P
0 g
s
.18872 .71992 m .18492 .68675 L .20859 .67405 L p .707 .577 .707 r
F P
0 g
s
.26657 .58976 m .2701 .64222 L .23833 .64525 L p .707 .577 .707 r
F P
0 g
s
.5377 .2365 m .56973 .70998 L .52575 .7084 L p .707 .577 .707 r
F P
0 g
s
.52575 .7084 m .49373 .23492 L .5377 .2365 L p .707 .577 .707 r
F P
0 g
s
.17555 .77971 m .17343 .76343 L .18928 .74741 L p .707 .577 .707 r
F P
0 g
s
.32794 .66701 m .33174 .70018 L .30422 .69455 L p .707 .577 .707 r
F P
0 g
s
.30422 .69455 m .30041 .66138 L .32794 .66701 L p .707 .577 .707 r
F P
0 g
s
.48092 .71269 m .46251 .44063 L p .49373 .23492 L .707 .577 .707 r
F P
0 g
s
.49373 .23492 m .52575 .7084 L .48092 .71269 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .48376 .66769 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45629 .64722 m .45828 .66455 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45828 .66455 m .46009 .68038 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.46251 .44063 m .44889 .23921 L .46635 .23754 L p .707 .577 .707 r
F P
0 g
s
.46635 .23754 m .49373 .23492 L p .46251 .44063 L .707 .577 .707 r
F P
0 g
s
.35339 .73636 m .3555 .75264 L .3342 .74221 L p .707 .577 .707 r
F P
0 g
s
.3342 .74221 m .33209 .72593 L .35339 .73636 L p .707 .577 .707 r
F P
0 g
s
.73775 .66719 m .73422 .61473 L .70307 .61361 L p .707 .577 .707 r
F P
0 g
s
.73422 .61473 m .73775 .66719 L .76951 .66416 L p .707 .577 .707 r
F P
0 g
s
.76951 .66416 m .76598 .6117 L .73422 .61473 L p .707 .577 .707 r
F P
0 g
s
.76598 .6117 m .76951 .66416 L .79878 .65727 L p .707 .577 .707 r
F P
0 g
s
.79878 .65727 m .79525 .60482 L .76598 .6117 L p .707 .577 .707 r
F P
0 g
s
.18928 .74741 m .19139 .76369 L .17555 .77971 L p .707 .577 .707 r
F P
0 g
s
.21239 .70722 m .20859 .67405 L .23767 .66508 L p .707 .577 .707 r
F P
0 g
s
.20859 .67405 m .21239 .70722 L .18872 .71992 L p .707 .577 .707 r
F P
0 g
s
.7066 .66607 m .70307 .61361 L .67559 .60844 L p .707 .577 .707 r
F P
0 g
s
.70307 .61361 m .7066 .66607 L .73775 .66719 L p .707 .577 .707 r
F P
0 g
s
.30041 .66138 m .30422 .69455 L .27311 .69389 L p .707 .577 .707 r
F P
0 g
s
.27311 .69389 m .26931 .66072 L .30041 .66138 L p .707 .577 .707 r
F P
0 g
s
.79525 .60482 m .79878 .65727 L .82268 .6472 L p .707 .577 .707 r
F P
0 g
s
.82268 .6472 m .81916 .59475 L .79525 .60482 L p .707 .577 .707 r
F P
0 g
s
.24147 .69825 m .23767 .66508 L .26931 .66072 L p .707 .577 .707 r
F P
0 g
s
.23767 .66508 m .24147 .69825 L .21239 .70722 L p .707 .577 .707 r
F P
0 g
s
.19139 .76369 m .18928 .74741 L .21286 .73396 L p .707 .577 .707 r
F P
0 g
s
.26931 .66072 m .27311 .69389 L .24147 .69825 L p .707 .577 .707 r
F P
0 g
s
.33209 .72593 m .3342 .74221 L .30666 .73645 L p .707 .577 .707 r
F P
0 g
s
.30666 .73645 m .30455 .72017 L .33209 .72593 L p .707 .577 .707 r
F P
0 g
s
.67912 .6609 m .67559 .60844 L .65446 .59973 L p .707 .577 .707 r
F P
0 g
s
.67559 .60844 m .67912 .6609 L .7066 .66607 L p .707 .577 .707 r
F P
0 g
s
.21286 .73396 m .21497 .75024 L .19139 .76369 L p .707 .577 .707 r
F P
0 g
s
.81916 .59475 m .82268 .6472 L .83889 .63494 L p .707 .577 .707 r
F P
0 g
s
.83889 .63494 m .83537 .58248 L .81916 .59475 L p .707 .577 .707 r
F P
0 g
s
.21497 .75024 m .21286 .73396 L .24186 .72439 L p .707 .577 .707 r
F P
0 g
s
.74238 .73054 m .73858 .69737 L .70747 .69671 L p .707 .577 .707 r
F P
0 g
s
.73858 .69737 m .74238 .73054 L .77402 .72617 L p .707 .577 .707 r
F P
0 g
s
.77402 .72617 m .77022 .693 L .73858 .69737 L p .707 .577 .707 r
F P
0 g
s
.30455 .72017 m .30666 .73645 L .27557 .73592 L p .707 .577 .707 r
F P
0 g
s
.27557 .73592 m .27346 .71964 L .30455 .72017 L p .707 .577 .707 r
F P
0 g
s
.77022 .693 m .77402 .72617 L .8031 .7172 L p .707 .577 .707 r
F P
0 g
s
.8031 .7172 m .7993 .68403 L .77022 .693 L p .707 .577 .707 r
F P
0 g
s
.24398 .74067 m .24186 .72439 L .27346 .71964 L p .707 .577 .707 r
F P
0 g
s
.24186 .72439 m .24398 .74067 L .21497 .75024 L p .707 .577 .707 r
F P
0 g
s
.71127 .72987 m .70747 .69671 L .67995 .69108 L p .707 .577 .707 r
F P
0 g
s
.70747 .69671 m .71127 .72987 L .74238 .73054 L p .707 .577 .707 r
F P
0 g
s
.27346 .71964 m .27557 .73592 L .24398 .74067 L p .707 .577 .707 r
F P
0 g
s
.65799 .65219 m .65446 .59973 L .64175 .58834 L p .707 .577 .707 r
F P
0 g
s
.65446 .59973 m .65799 .65219 L .67912 .6609 L p .707 .577 .707 r
F P
0 g
s
.7993 .68403 m .8031 .7172 L .82677 .7045 L p .707 .577 .707 r
F P
0 g
s
.82677 .7045 m .82297 .67134 L .7993 .68403 L p .707 .577 .707 r
F P
0 g
s
.83537 .58248 m .83889 .63494 L .84582 .62167 L p .707 .577 .707 r
F P
0 g
s
.84582 .62167 m .84229 .56922 L .83537 .58248 L p .707 .577 .707 r
F P
0 g
s
.68375 .72425 m .67995 .69108 L .6587 .68103 L p .707 .577 .707 r
F P
0 g
s
.67995 .69108 m .68375 .72425 L .71127 .72987 L p .707 .577 .707 r
F P
0 g
s
.74547 .76896 m .74336 .75268 L .71227 .75214 L p .707 .577 .707 r
F P
0 g
s
.74336 .75268 m .74547 .76896 L .77706 .7642 L p .707 .577 .707 r
F P
0 g
s
.77706 .7642 m .77495 .74792 L .74336 .75268 L p .707 .577 .707 r
F P
0 g
s
.82297 .67134 m .82677 .7045 L .84272 .68933 L p .707 .577 .707 r
F P
0 g
s
.84272 .68933 m .83892 .65616 L .82297 .67134 L p .707 .577 .707 r
F P
0 g
s
.77495 .74792 m .77706 .7642 L .80607 .75463 L p .707 .577 .707 r
F P
0 g
s
.80607 .75463 m .80396 .73835 L .77495 .74792 L p .707 .577 .707 r
F P
0 g
s
.64175 .58834 m .64528 .6408 L .65799 .65219 L p .707 .577 .707 r
F P
0 g
s
.71438 .76842 m .71227 .75214 L .68473 .74638 L p .707 .577 .707 r
F P
0 g
s
.71227 .75214 m .71438 .76842 L .74547 .76896 L p .707 .577 .707 r
F P
0 g
s
.64528 .6408 m .64175 .58834 L .63871 .57538 L p .707 .577 .707 r
F P
0 g
s
.80396 .73835 m .80607 .75463 L .82965 .74118 L p .707 .577 .707 r
F P
0 g
s
.82965 .74118 m .82754 .7249 L .80396 .73835 L p .707 .577 .707 r
F P
0 g
s
.6587 .68103 m .6625 .7142 L .68375 .72425 L p .707 .577 .707 r
F P
0 g
s
.68473 .74638 m .68684 .76266 L .71438 .76842 L p .707 .577 .707 r
F P
0 g
s
.84229 .56922 m .84582 .62167 L .84278 .60871 L p .707 .577 .707 r
F P
0 g
s
.84278 .60871 m .83925 .55625 L .84229 .56922 L p .707 .577 .707 r
F P
0 g
s
.68684 .76266 m .68473 .74638 L .66343 .73595 L p .707 .577 .707 r
F P
0 g
s
.83892 .65616 m .84272 .68933 L .84938 .67315 L p .707 .577 .707 r
F P
0 g
s
.84938 .67315 m .84558 .63998 L .83892 .65616 L p .707 .577 .707 r
F P
0 g
s
.82754 .7249 m .82965 .74118 L .84549 .72517 L p .707 .577 .707 r
F P
0 g
s
.84549 .72517 m .84338 .70889 L .82754 .7249 L p .707 .577 .707 r
F P
0 g
s
.66343 .73595 m .66554 .75223 L .68684 .76266 L p .707 .577 .707 r
F P
0 g
s
.63871 .57538 m .64224 .62784 L .64528 .6408 L p .707 .577 .707 r
F P
0 g
s
.64224 .62784 m .63871 .57538 L .64563 .56212 L p .707 .577 .707 r
F P
0 g
s
.6496 .70073 m .6458 .66756 L .64252 .65197 L p .707 .577 .707 r
F P
0 g
s
.84338 .70889 m .84549 .72517 L .85205 .70815 L p .707 .577 .707 r
F P
0 g
s
.85205 .70815 m .84994 .69187 L .84338 .70889 L p .707 .577 .707 r
F P
0 g
s
.84558 .63998 m .84938 .67315 L .8461 .65756 L p .707 .577 .707 r
F P
0 g
s
.8461 .65756 m .8423 .62439 L .84558 .63998 L p .707 .577 .707 r
F P
0 g
s
.83925 .55625 m .84278 .60871 L .83007 .59732 L p .707 .577 .707 r
F P
0 g
s
.83007 .59732 m .82654 .54486 L .83925 .55625 L p .707 .577 .707 r
F P
0 g
s
.65046 .72188 m .65257 .73816 L .66554 .75223 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64252 .65197 m .64633 .68514 L .6496 .70073 L p .707 .577 .707 r
F P
0 g
s
.64563 .56212 m .64916 .61457 L .64224 .62784 L p .707 .577 .707 r
F P
0 g
s
.64916 .61457 m .64563 .56212 L .66184 .54985 L p .707 .577 .707 r
F P
0 g
s
.65257 .73816 m .65046 .72188 L .64709 .70553 L p .707 .577 .707 r
F P
0 g
s
.39474 .63037 m .39121 .57792 L .36006 .57679 L p .707 .577 .707 r
F P
0 g
s
.39121 .57792 m .39474 .63037 L .4265 .62735 L p .707 .577 .707 r
F P
0 g
s
.4265 .62735 m .42297 .57489 L .39121 .57792 L p .707 .577 .707 r
F P
0 g
s
.64633 .68514 m .64252 .65197 L .64918 .63579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42297 .57489 m .4265 .62735 L .45577 .62046 L p .707 .577 .707 r
F P
0 g
s
.45577 .62046 m .45224 .568 L .42297 .57489 L p .707 .577 .707 r
F P
0 g
s
.84994 .69187 m .85205 .70815 L .84868 .69181 L p .707 .577 .707 r
F P
0 g
s
.84868 .69181 m .84657 .67553 L .84994 .69187 L p .707 .577 .707 r
F P
0 g
s
.36359 .62925 m .36006 .57679 L .33258 .57162 L p .707 .577 .707 r
F P
0 g
s
.36006 .57679 m .36359 .62925 L .39474 .63037 L p .707 .577 .707 r
F P
0 g
s
.8423 .62439 m .8461 .65756 L .83321 .64409 L p .707 .577 .707 r
F P
0 g
s
.83321 .64409 m .8294 .61092 L .8423 .62439 L p .707 .577 .707 r
F P
0 g
s
.82654 .54486 m .83007 .59732 L .80894 .58861 L p .707 .577 .707 r
F P
0 g
s
.80894 .58861 m .80541 .53615 L .82654 .54486 L p .707 .577 .707 r
F P
0 g
s
.64709 .70553 m .6492 .72181 L .65257 .73816 L p .707 .577 .707 r
F P
0 g
s
.45224 .568 m .45577 .62046 L .47967 .61039 L p .707 .577 .707 r
F P
0 g
s
.47967 .61039 m .47615 .55793 L .45224 .568 L p .707 .577 .707 r
F P
0 g
s
.64918 .63579 m .65299 .66896 L .64633 .68514 L p .707 .577 .707 r
F P
0 g
s
.66184 .54985 m .66537 .60231 L .64916 .61457 L p .707 .577 .707 r
F P
0 g
s
.66537 .60231 m .66184 .54985 L .68575 .53978 L p .707 .577 .707 r
F P
0 g
s
.33611 .62408 m .33258 .57162 L .31145 .56292 L p .707 .577 .707 r
F P
0 g
s
.33258 .57162 m .33611 .62408 L .36359 .62925 L p .707 .577 .707 r
F P
0 g
s
.65299 .66896 m .64918 .63579 L .66513 .62062 L p .707 .577 .707 r
F P
0 g
s
.6492 .72181 m .64709 .70553 L .65365 .68852 L p .707 .577 .707 r
F P
0 g
s
.80541 .53615 m .80894 .58861 L .78146 .58344 L p .707 .577 .707 r
F P
0 g
s
.78146 .58344 m .77793 .53099 L .80541 .53615 L p .707 .577 .707 r
F P
0 g
s
.47615 .55793 m .47967 .61039 L .49588 .59812 L p .707 .577 .707 r
F P
0 g
s
.49588 .59812 m .49236 .54566 L .47615 .55793 L p .707 .577 .707 r
F P
0 g
s
.84657 .67553 m .84868 .69181 L .83571 .67773 L p .707 .577 .707 r
F P
0 g
s
.83571 .67773 m .8336 .66145 L .84657 .67553 L p .707 .577 .707 r
F P
0 g
s
.8294 .61092 m .83321 .64409 L .81196 .63404 L p .707 .577 .707 r
F P
0 g
s
.81196 .63404 m .80815 .60087 L .8294 .61092 L p .707 .577 .707 r
F P
0 g
s
.39937 .69372 m .39557 .66055 L .36446 .65989 L p .707 .577 .707 r
F P
0 g
s
.43101 .68936 m .42721 .65619 L .39557 .66055 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .45629 .64722 L .42721 .65619 L p .707 .577 .707 r
F P
0 g
s
.65365 .68852 m .65576 .7048 L .6492 .72181 L p .707 .577 .707 r
F P
0 g
s
.68928 .59224 m .68575 .53978 L .71502 .53289 L p .707 .577 .707 r
F P
0 g
s
.68575 .53978 m .68928 .59224 L .66537 .60231 L p .707 .577 .707 r
F P
0 g
s
.36826 .69306 m .36446 .65989 L .33694 .65426 L p .707 .577 .707 r
F P
0 g
s
.36446 .65989 m .36826 .69306 L .39937 .69372 L p .707 .577 .707 r
F P
0 g
s
.31498 .61538 m .31145 .56292 L .29874 .55153 L p .707 .577 .707 r
F P
0 g
s
.31145 .56292 m .31498 .61538 L .33611 .62408 L p .707 .577 .707 r
F P
0 g
s
.48376 .66769 m .47996 .63452 L .45629 .64722 L p .707 .577 .707 r
F P
0 g
s
.66513 .62062 m .66893 .65378 L .65299 .66896 L p .707 .577 .707 r
F P
0 g
s
.77793 .53099 m .78146 .58344 L .75031 .58232 L p .707 .577 .707 r
F P
0 g
s
.75031 .58232 m .74678 .52986 L .77793 .53099 L p .707 .577 .707 r
F P
0 g
s
.66893 .65378 m .66513 .62062 L .6888 .60792 L p .707 .577 .707 r
F P
0 g
s
.71855 .58535 m .71502 .53289 L .74678 .52986 L p .707 .577 .707 r
F P
0 g
s
.71502 .53289 m .71855 .58535 L .68928 .59224 L p .707 .577 .707 r
F P
0 g
s
.65576 .7048 m .65365 .68852 L .66949 .67251 L p .707 .577 .707 r
F P
0 g
s
.74678 .52986 m .75031 .58232 L .71855 .58535 L p .707 .577 .707 r
F P
0 g
s
.80815 .60087 m .81196 .63404 L .78443 .62841 L p .707 .577 .707 r
F P
0 g
s
.78443 .62841 m .78063 .59524 L .80815 .60087 L p .707 .577 .707 r
F P
0 g
s
.49236 .54566 m .49588 .59812 L .50281 .58486 L p .707 .577 .707 r
F P
0 g
s
.50281 .58486 m .49928 .5324 L .49236 .54566 L p .707 .577 .707 r
F P
0 g
s
.34074 .68743 m .33694 .65426 L .31569 .64422 L p .707 .577 .707 r
F P
0 g
s
.33694 .65426 m .34074 .68743 L .36826 .69306 L p .707 .577 .707 r
F P
0 g
s
.8336 .66145 m .83571 .67773 L .81442 .6673 L p .707 .577 .707 r
F P
0 g
s
.81442 .6673 m .8123 .65102 L .8336 .66145 L p .707 .577 .707 r
F P
0 g
s
.40246 .73214 m .40035 .71586 L .36926 .71533 L p .707 .577 .707 r
F P
0 g
s
.40035 .71586 m .40246 .73214 L .43405 .72739 L p .707 .577 .707 r
F P
0 g
s
.43405 .72739 m .43194 .71111 L .40035 .71586 L p .707 .577 .707 r
F P
0 g
s
.47996 .63452 m .48376 .66769 L .49971 .65251 L p .707 .577 .707 r
F P
0 g
s
.49971 .65251 m .49591 .61934 L .47996 .63452 L p .707 .577 .707 r
F P
0 g
s
.66949 .67251 m .67161 .68879 L .65576 .7048 L p .707 .577 .707 r
F P
0 g
s
.6926 .64109 m .6888 .60792 L .71788 .59895 L p .707 .577 .707 r
F P
0 g
s
.6888 .60792 m .6926 .64109 L .66893 .65378 L p .707 .577 .707 r
F P
0 g
s
.29874 .55153 m .30227 .60398 L .31498 .61538 L p .707 .577 .707 r
F P
0 g
s
.37137 .73161 m .36926 .71533 L .34172 .70957 L p .707 .577 .707 r
F P
0 g
s
.36926 .71533 m .37137 .73161 L .40246 .73214 L p .707 .577 .707 r
F P
0 g
s
.78063 .59524 m .78443 .62841 L .75332 .62775 L p .707 .577 .707 r
F P
0 g
s
.75332 .62775 m .74952 .59458 L .78063 .59524 L p .707 .577 .707 r
F P
0 g
s
.30227 .60398 m .29874 .55153 L .2957 .53856 L p .707 .577 .707 r
F P
0 g
s
.46095 .70154 m .46306 .71782 L .48664 .70437 L p .707 .577 .707 r
F P
0 g
s
.48664 .70437 m .48453 .68809 L .46095 .70154 L p .707 .577 .707 r
F P
0 g
s
.67161 .68879 m .66949 .67251 L .69307 .65905 L p .707 .577 .707 r
F P
0 g
s
.31569 .64422 m .31949 .67739 L .34074 .68743 L p .707 .577 .707 r
F P
0 g
s
.72168 .63212 m .71788 .59895 L .74952 .59458 L p .707 .577 .707 r
F P
0 g
s
.71788 .59895 m .72168 .63212 L .6926 .64109 L p .707 .577 .707 r
F P
0 g
s
.74952 .59458 m .75332 .62775 L .72168 .63212 L p .707 .577 .707 r
F P
0 g
s
.31949 .67739 m .31569 .64422 L .30279 .63074 L p .707 .577 .707 r
F P
0 g
s
.34172 .70957 m .34383 .72585 L .37137 .73161 L p .707 .577 .707 r
F P
0 g
s
.8123 .65102 m .81442 .6673 L .78688 .66154 L p .707 .577 .707 r
F P
0 g
s
.78688 .66154 m .78476 .64526 L .8123 .65102 L p .707 .577 .707 r
F P
0 g
s
.49928 .5324 m .50281 .58486 L .49977 .57189 L p .707 .577 .707 r
F P
0 g
s
.49977 .57189 m .49624 .51944 L .49928 .5324 L p .707 .577 .707 r
F P
0 g
s
.34383 .72585 m .34172 .70957 L .32042 .69914 L p .707 .577 .707 r
F P
0 g
s
.69307 .65905 m .69519 .67533 L .67161 .68879 L p .707 .577 .707 r
F P
0 g
s
.49591 .61934 m .49971 .65251 L .50637 .63634 L p .707 .577 .707 r
F P
0 g
s
.50637 .63634 m .50257 .60317 L .49591 .61934 L p .707 .577 .707 r
F P
0 g
s
.48453 .68809 m .48664 .70437 L .50248 .68835 L p .707 .577 .707 r
F P
0 g
s
.50248 .68835 m .50037 .67207 L .48453 .68809 L p .707 .577 .707 r
F P
0 g
s
.69519 .67533 m .69307 .65905 L .72208 .64948 L p .707 .577 .707 r
F P
0 g
s
.32042 .69914 m .32253 .71542 L .34383 .72585 L p .707 .577 .707 r
F P
0 g
s
.2957 .53856 m .29923 .59102 L .30227 .60398 L p .707 .577 .707 r
F P
0 g
s
.78476 .64526 m .78688 .66154 L .75579 .66101 L p .707 .577 .707 r
F P
0 g
s
.75579 .66101 m .75367 .64473 L .78476 .64526 L p .707 .577 .707 r
F P
0 g
s
.30279 .63074 m .30659 .66391 L .31949 .67739 L p .707 .577 .707 r
F P
0 g
s
.29923 .59102 m .2957 .53856 L .30262 .5253 L p .707 .577 .707 r
F P
0 g
s
.72419 .66576 m .72208 .64948 L .75367 .64473 L p .707 .577 .707 r
F P
0 g
s
.72208 .64948 m .72419 .66576 L .69519 .67533 L p .707 .577 .707 r
F P
0 g
s
.75367 .64473 m .75579 .66101 L .72419 .66576 L p .707 .577 .707 r
F P
0 g
s
.30659 .66391 m .30279 .63074 L .29951 .61515 L p .707 .577 .707 r
F P
0 g
s
.32253 .71542 m .32042 .69914 L .30745 .68506 L p .707 .577 .707 r
F P
0 g
s
.50037 .67207 m .50248 .68835 L .50904 .67134 L p .707 .577 .707 r
F P
0 g
s
.50904 .67134 m .50693 .65506 L .50037 .67207 L p .707 .577 .707 r
F P
0 g
s
.50257 .60317 m .50637 .63634 L .50309 .62075 L p .707 .577 .707 r
F P
0 g
s
.50309 .62075 m .49929 .58758 L .50257 .60317 L p .707 .577 .707 r
F P
0 g
s
.49624 .51944 m .49977 .57189 L .48706 .5605 L p .707 .577 .707 r
F P
0 g
s
.48706 .5605 m .48353 .50805 L .49624 .51944 L p .707 .577 .707 r
F P
0 g
s
.30745 .68506 m .30956 .70134 L .32253 .71542 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29951 .61515 m .30331 .64832 L .30659 .66391 L p .707 .577 .707 r
F P
0 g
s
.30262 .5253 m .30615 .57776 L .29923 .59102 L p .707 .577 .707 r
F P
0 g
s
.30615 .57776 m .30262 .5253 L .31883 .51303 L p .707 .577 .707 r
F P
0 g
s
.30956 .70134 m .30745 .68506 L .30408 .66872 L p .707 .577 .707 r
F P
0 g
s
.30331 .64832 m .29951 .61515 L .30617 .59898 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50693 .65506 m .50904 .67134 L .50567 .65499 L p .707 .577 .707 r
F P
0 g
s
.50567 .65499 m .50356 .63871 L .50693 .65506 L p .707 .577 .707 r
F P
0 g
s
.49929 .58758 m .50309 .62075 L .49019 .60727 L p .707 .577 .707 r
F P
0 g
s
.49019 .60727 m .48639 .5741 L .49929 .58758 L p .707 .577 .707 r
F P
0 g
s
.48353 .50805 m .48706 .5605 L .46593 .5518 L p .707 .577 .707 r
F P
0 g
s
.46593 .5518 m .4624 .49934 L .48353 .50805 L p .707 .577 .707 r
F P
0 g
s
.30408 .66872 m .30619 .685 L .30956 .70134 L p .707 .577 .707 r
F P
0 g
s
.30617 .59898 m .30998 .63215 L .30331 .64832 L p .707 .577 .707 r
F P
0 g
s
.31883 .51303 m .32236 .56549 L .30615 .57776 L p .707 .577 .707 r
F P
0 g
s
.32236 .56549 m .31883 .51303 L .34274 .50296 L p .707 .577 .707 r
F P
0 g
s
.30998 .63215 m .30617 .59898 L .32212 .5838 L p .707 .577 .707 r
F P
0 g
s
.30619 .685 m .30408 .66872 L .31064 .65171 L p .707 .577 .707 r
F P
0 g
s
.4624 .49934 m .46593 .5518 L .43845 .54663 L p .707 .577 .707 r
F P
0 g
s
.43845 .54663 m .43492 .49417 L .4624 .49934 L p .707 .577 .707 r
F P
0 g
s
.50356 .63871 m .50567 .65499 L .4927 .64092 L p .707 .577 .707 r
F P
0 g
s
.4927 .64092 m .49059 .62464 L .50356 .63871 L p .707 .577 .707 r
F P
0 g
s
.48639 .5741 m .49019 .60727 L .46894 .59723 L p .707 .577 .707 r
F P
0 g
s
.46894 .59723 m .46514 .56406 L .48639 .5741 L p .707 .577 .707 r
F P
0 g
s
.31064 .65171 m .31275 .66799 L .30619 .685 L p .707 .577 .707 r
F P
0 g
s
.34627 .55542 m .34274 .50296 L .37201 .49608 L p .707 .577 .707 r
F P
0 g
s
.34274 .50296 m .34627 .55542 L .32236 .56549 L p .707 .577 .707 r
F P
0 g
s
.32212 .5838 m .32592 .61697 L .30998 .63215 L p .707 .577 .707 r
F P
0 g
s
.43492 .49417 m .43845 .54663 L .4073 .5455 L p .707 .577 .707 r
F P
0 g
s
.4073 .5455 m .40377 .49305 L .43492 .49417 L p .707 .577 .707 r
F P
0 g
s
.32592 .61697 m .32212 .5838 L .34579 .5711 L p .707 .577 .707 r
F P
0 g
s
.37554 .54853 m .37201 .49608 L .40377 .49305 L p .707 .577 .707 r
F P
0 g
s
.37201 .49608 m .37554 .54853 L .34627 .55542 L p .707 .577 .707 r
F P
0 g
s
.31275 .66799 m .31064 .65171 L .32648 .63569 L p .707 .577 .707 r
F P
0 g
s
.40377 .49305 m .4073 .5455 L .37554 .54853 L p .707 .577 .707 r
F P
0 g
s
.46514 .56406 m .46894 .59723 L .44142 .5916 L p .707 .577 .707 r
F P
0 g
s
.44142 .5916 m .43762 .55843 L .46514 .56406 L p .707 .577 .707 r
F P
0 g
s
.49059 .62464 m .4927 .64092 L .47141 .63049 L p .707 .577 .707 r
F P
0 g
s
.47141 .63049 m .46929 .61421 L .49059 .62464 L p .707 .577 .707 r
F P
0 g
s
.32648 .63569 m .3286 .65197 L .31275 .66799 L p .707 .577 .707 r
F P
0 g
s
.34959 .60427 m .34579 .5711 L .37487 .56213 L p .707 .577 .707 r
F P
0 g
s
.34579 .5711 m .34959 .60427 L .32592 .61697 L p .707 .577 .707 r
F P
0 g
s
.43762 .55843 m .44142 .5916 L .41031 .59093 L p .707 .577 .707 r
F P
0 g
s
.41031 .59093 m .40651 .55777 L .43762 .55843 L p .707 .577 .707 r
F P
0 g
s
.3286 .65197 m .32648 .63569 L .35006 .62224 L p .707 .577 .707 r
F P
0 g
s
.37867 .5953 m .37487 .56213 L .40651 .55777 L p .707 .577 .707 r
F P
0 g
s
.37487 .56213 m .37867 .5953 L .34959 .60427 L p .707 .577 .707 r
F P
0 g
s
.40651 .55777 m .41031 .59093 L .37867 .5953 L p .707 .577 .707 r
F P
0 g
s
.46929 .61421 m .47141 .63049 L .44386 .62473 L p .707 .577 .707 r
F P
0 g
s
.44386 .62473 m .44175 .60845 L .46929 .61421 L p .707 .577 .707 r
F P
0 g
s
.35006 .62224 m .35217 .63852 L .3286 .65197 L p .707 .577 .707 r
F P
0 g
s
.35217 .63852 m .35006 .62224 L .37907 .61267 L p .707 .577 .707 r
F P
0 g
s
.44175 .60845 m .44386 .62473 L .41278 .6242 L p .707 .577 .707 r
F P
0 g
s
.41278 .6242 m .41066 .60792 L .44175 .60845 L p .707 .577 .707 r
F P
0 g
s
.38118 .62895 m .37907 .61267 L .41066 .60792 L p .707 .577 .707 r
F P
0 g
s
.37907 .61267 m .38118 .62895 L .35217 .63852 L p .707 .577 .707 r
F P
0 g
s
.41066 .60792 m .41278 .6242 L .38118 .62895 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00RGoo2@00Rgoo0022Ool70003FUH00`00
FUIJEP03FUH90022Ool007eoo`D000YJEP03001JEUYF00UJEP03001JEUYF00H007aoo`00Mgoo1P00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000N7oo001bOol50008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001eOol0071oo`800003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0079o
o`00KWoo0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00L7oo001/Ool20005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001_Ool006Yoo`8000MJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0006ioo`00
J7oo0`0025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUH006eoo`00Igoo00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH0001/Ool006Io
o`05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1YOol006Aoo`8000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEV]oo`00Hgoo00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
Jgoo001ROol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0069oo`8000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00HGoo00<005YF00001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0J7oo001QOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0
061oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061o
o`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061oo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065o
o`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Moo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP8000aJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00Igoo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001W
Ool006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00Hgoo00@005YFFUH0
00IJEP8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH3001VOol006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`00IWoo001SOol01000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF3`001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIVOol006Aoo`03001JEUYF
00L000AJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0006Eoo`00H7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP<006Eoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001IOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001HOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001GOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOol90014Ool0
05Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000AOol70004FUH00`00FUIJEP02FUH8000lOol005Ao
o`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1@00=goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0027oo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Ioo`80009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@002EYF00<005YFFUH015YF1@00
1EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUH0000`Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP03FUH6
00000eYF001JEP05FUH20008FUH00`00FUIJEP09FUH20003FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000_Ool005Aoo`04001JEUYF0003FUH01000FUIJEUYF0P0017oo00@005YFFUH000IJEPl000MJEP@0
0003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00@005YFFUH000=JEP04001J
EP000007Ool00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUH000030002FUH200000eYF001J
EP020003FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003FUH20009Ool30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH01@00FUIJEUYF00000UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo001DOol2000015YF001JEUYF0`001goo0`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool0
05Aoo`800004FUH005YF0003FUH30002Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020002FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ao
o`800003FUH0000000EJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo
00@005YF000000EJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol2
00000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPl000EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP05001J
EUYFFUH0000]Ool004Moo`T000Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001J
EUYF00=JEP03001JEUYF00@001Yoo`<000AJEP05001JEUYFFUH0000]Ool0045oo`H000AJEP03001J
EUYF009JEPH000=JEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH3000QOol300000eYF001JEP02FUH00`00Oomo
o`0[Ool003eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP80009JEP04001JEUYF0007FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP06FUH50005FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP8000io
oa0000Moo`04001JEP000003FUH2000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH01000FUH000002Goo1`0015YF00<0
05YFFUH01EYF00@005YFFUIJEPP000=JEP03001JEUYF008002aoo`00=goo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<005YFFUH015YF100025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0P001goo10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF100015YF00@005YF000002aoo`00=Goo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00IJEP03001JEP0000L000MJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF100017oo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P000eYF1000;7oo
000cOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03
FUH00`00FUIJEP020006FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH90005FUH20003FUH0
0`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0
0`0015YF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0`00;7oo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP03FUH40007FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
1UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00P005YFFUH0
05YF001JEP001EYF00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP800004FUH00000000/Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH4
00000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH01000FUH000000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YFFUIJEP80
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEP00001JEP00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP<00003FUH005YF009JEP<000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00H005YFFUH005YF000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`0025YF00<005YFFUH00UYF3`001UYF00@0
05YFFUIJEP<0009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP020002FUH01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YF0000
009JEP03001JEUYF00EJEPL000=JEPL000AJEP@0009JEP03001JEUYF009JEP80009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF0P001EYF00<005YFFUH00UYF0P0000=JEP0000001`001EYF00<005YF
FUH01eYF0`0015YF00D005YF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEPH000MJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF009J
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEPD000MJEP03001JEUYF00YJEP8000=J
EP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH4
0005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP8000MJEP@0009JEP04001JEUYFFUH50007FUH0
0`00FUIJEP09FUH500001EYF001JEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00=JEP03001JEP00008000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ400004FUH005YF0005FUH20002FUH2
0002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP020002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH6000>Ool00`00FUIJEP020002FUH00`00FUIJEP0200000eYF001JEP02FUH0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP04
001JEUYFFUH20004FUH00`00FUIJEP06FUH@0002FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0Z
Ool002eoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000DOol200000eYF001JEP02
FUH30003FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYF001JEP001EYF00@005YF000000IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030003FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<0
05YFFUH00eYF10002Woo0`002goo0`0015YF00<007oo00000P0000=JEP00FUH00UYF00@005YFFUH0
00IJEP03001JEUYF00MJEPD00003FUH005YF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00005FUH200000eYF001JEP05FUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006Ool3000/Ool002eoo`04001JEUYF
0003FUH01000FUIJEUYF0P003Goo1@002Woo0`000eYF00<005YF00001@000eYF0P0000=JEP00FUH0
1EYF00@005YFFUIJEPL000EJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP<00003FUH005YF
00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Eoo`03001JEP00
02aoo`00;Goo00@005YFFUH000=JEP04001JEP00000?Ool:0006Ool200000eYF00000003FUH01000
FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF0000009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP07001JEUYF001JEP00FUH0
0`0000=JEP0000001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF00<005YFFUH00P000Woo
0P0000=JEP000000:goo000]Ool200000eYF001JEP02FUH2000@Ool40002FUH00`00FUIJEP02FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH2
0004FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00002FUH01000FUIJEUYF0`0025YF00<005YFFUH010000UYF3@0015YF00@005YFFUIJEP80
0003FUH005YF008002]oo`00;Goo0P0000AJEP00FUIJEP<000aoo`@000IJEP03001JEUYF00IJEP80
0004FUH005YF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUH00002FUH20003FUH01000FUIJEP000UYF00<005YFFUH01EYF2P003Goo1@00
15YF0`000UYF00<007ooOol0:Goo000]Ool2000015YF000000000eYF1@000goo100000=JEP00FUH0
1eYF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEP0000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0`0015YF00<005YFFUH00UYF
0P0017oo1@004goo0P000UYF00<005YF00000UYF00<007ooOol0:Goo000]Ool200000eYF00000005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00000000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000IJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00AJEP03001JEUYF00AJEP03001JEP00008000Ioo`D0019oo`D00006FUH005YF001JEP00:goo000^
Ool200000eYF001JEP04FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH20005FUH50007Ool5000AOol01000FUIJEP000UYF0P000UYF0P00:goo
000^Ool200000eYF001JEP04FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP03FUH30004
FUH01000FUIJEUYF0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUH000=JEP800003FUH005YF009JEP<000=JEP03001oogoo00Ioo`<0011oo`8000=J
EP03001JEUYF009JEP03001JEP0002aoo`00;Woo00@005YFFUH000=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP800003FUH005YF00IJEP03001JEUYF00=JEPD0
00MJEP04001JEUYFFUH20007FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00@005YFFUH0009JEP06001JEUYFFUH005YF0P000UYF00D005YF
FUIJEP0001Uoo`8000EJEP03001JEUYF00=JEP8002aoo`00;Woo00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30005FUH40006FUH00`00FUIJEP03FUH5
0007FUH01000FUH000002UYF0P0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00`0015YF0`000eYF00D005YFFUIJEP0001Ioo`<00003FUH005YF
00AJEP03001JEUYF00=JEP<002]oo`00;Woo00@005YFFUIJEP<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH50002FUH7000;FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`0AOol3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Ool0000[Ool002ioo`07001JEUYFFUH005YF
00001eYF00<005YFFUH01EYF00<005YFFUH00UYF400000=JEP00FUH00UYF00<005YFFUH00eYF00<0
05YF00003P001UYF00<005YFFUH025YF00@005YFFUH0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02FUH00`00FUH0
000300000eYF0000000<Ool60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000Woo00<007ooOol0
:Goo000^Ool01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH015YF1P002EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEP00Ool00002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH20004FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP03FUH?0004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000Woo0P00:goo000^Ool00`00FUH00003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05
0004FUH01@00FUIJEP00Ool00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH015YF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000Aoo`03001JEP0002Yoo`00;goo0P0015YF00<005YFFUH015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF1@0000UJEP00FUIJEP00Ool0
05YF00001UYF00<005YFFUH01eYF00@005YFFUIJEP@000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo009o
o`04001JEUYF000ZOol002moo`8000AJEP03001JEUYF00=JEP<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEPD0009JEP05001oo`00FUH00006FUH00`00FUIJ
EP07FUH40003FUH00`00FUIJEP02FUH20005FUHE0008FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001Goo00@005YFFUH002Yoo`00;goo0P0015YF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEP0000@00004Ool005YF000:
FUH60007FUH00`00FUIJEP09000<FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP06FUH01000FUH0
05YF10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000000Ioo`80009JEP03001oogoo02Qoo`00;Woo00<005YF000015YF00@005YF000000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP03001JEUYF00=JEPl000AJEP03
001JEUYF00IJEP@000MJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH40007FUH00`00
FUIJEP0300000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP05
FUH30007Ool01@00FUH005YF0000:goo000^Ool00`00FUH00004FUH50006FUH00`00FUIJEP06FUH@
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP030003
FUH300000eYF001JEP06FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP02FUH2000:Ool00`00FUIJ
EP02000[Ool002ioo`04001JEUYF0002FUH00`00Oomoo`03Ool40002FUH00`00FUIJEP060004FUH0
0`00FUIJEP06FUH00`00FUH000030002Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH01P00FUIJEP00FUH000AJEP03001JEP00008000IJEP03001JEUYF00=JEPD000MJEP03001JEP00
008000]oo`05001JEUYFFUH0000/Ool002ioo`06001JEUYF001JEP002Woo1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0000Aoo`00000000IJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP<0
0004FUH005YFFUH30004FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH50003FUH6000<Ool2
0004FUH00`00Oomoo`0ZOol002ioo`06001JEUYF001JEP002Woo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF0`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH0100025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH00P00
0UYF00<005YF000015YF00<005YFFUH00UYF00@005YFFUIJEQ00011oo`800003FUH005YF009JEP03
001oogoo02]oo`00;Woo00<005YFFUH00P002Goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00P000eYF4@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH00UYF00D005YFFUH005YF0080009JEP03001JEUYF
00=JEP04001JEUYF000MOol20003FUH01000FUH00000;Woo000_Ool00`00FUH00008Ool30008FUH0
0`00FUIJEP02FUH?0006FUH01000FUIJEUYF0P0000=JEP00FUH00P002EYF0P0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF10001EYF00<005YFFUH00P006Goo0`001EYF0P00<7oo000_Ool20007Ool20002
FUH00`00FUIJEP05FUH6000?Ool40002FUH00`00FUIJEP02FUH300000eYF00000007FUH20003FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH200000eYF001JEP0300000eYF00000003FUH00`00FUIJEP02000GOol200000eYF
001JEP05FUH00`00Oomoo`0_Ool002moo`<000Aoo`8000EJEP03001JEUYF009JEP8001Uoo`<000AJ
EP04001JEP00FUH20006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030002FUH20000
1EYF000005YF00000UYF0P0057oo0`000eYF00<005YFFUH00UYF0P00<Woo000_Ool01000FUIJEP00
0Woo00<005YFFUH01EYF00<005YF00000P006Goo0P000eYF0P000eYF00D005YF001oo`0000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00@000=JEPD000=JEP03001oogoo00ioo`@000MJ
EP04001JEUYF000dOol002moo`03001JEUYF00@000MJEP8001Yoo`8000IJEP<00006FUH005YFFUH0
07oo0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0100015YF00@005YFFUIJEPT000Moo`@0009J
EP03001JEUYF00IJEP<003Eoo`00;goo0P0000EJEP00001JEP0000EJEP8001Qoo`@00003FUH005YF
00EJEP03001JEUYF0080009JEP05001ooeYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP060002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH2000g
Ool002moo`800003FUH00000009JEP03001JEUYF00<001Aoo`D000EJEP03001JEUYF00EJEP08001J
EUYFFUH005YF001oo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0017oo0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00>Goo000`Ool00`00
FUH00003FUH30003FUH90007Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
00001EYF000005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH01@000Woo0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00?7oo000`Ool20004FUH00`00FUH0
0007FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002Ool3
00000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000eYF0`000goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?goo000`Ool20003FUH01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0017oo10000eYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00`000UYF00<005YF00003P00
AGoo000`Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0005FUH01000FUIJEUYF0P0000EJEP00FUIJEP00059oo`00;goo00<005YF00000P001EYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@000]JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00=JEPH0009JEP03001JEUYF009JEP<0009JEP03001oogoo051oo`00;goo00D005YF001o
o`0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000MJEP03001JEUYF00EJEP04001JEP000008
Ool00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004Ool30004FUH01P00FUH00000FUH0059oo`00
;goo00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF1@001eYF00<005YFFUH0
15YF0`002Woo00D005YF001oo`0000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00=JEP03001oogoo00=o
o`800003FUH0000000=JEP04001JEP00001COol002moo`03001JEP0000Aoo`800003FUH005YF00IJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF009JEP8000aoo`800004FUH007oo0004FUH00`00FUIJ
EP04FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP02FUH01000Oomoogoo0`001EYF0P0000EJEP00FUIJEP0005=oo`00<7oo00<0
07ooOol01Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003Goo00@005YF
0000009oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP06001JEUYFFUH007oo0`0000=JEP00FUH01EYF
00@005YF0000009JEP03001oogoo055oo`00<7oo00<007ooOol027oo10000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P003goo00<005YFFUH00P000goo00D005YFFUIJEP00015JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000Dgoo000`Ool00`00Oomoo`0<Ool@000DOol01@00FUIJEUYF0000
1Goo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP<000MJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`1AOol0
031oo`80031oo`03001JEUYF009JEP03001oogoo00Aoo`03001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP<000QJEP03001JEUYF
00EJEP03001JEP00009oo`80059oo`00<7oo00<005YF0000;Goo0`000eYF00<007ooOol01Woo0P00
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P000UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0017oo00<007ooOol0D7oo000aOol00`00
FUH0000[Ool01000FUIJEP000UYF00<007ooOol027oo00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001oogoo00=oo`03001oogoo051oo`00<Goo00@005YFFUH002Qoo`8000AJ
EP03001JEP0000]oo`8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`80059oo`00
<Goo00<005YFFUH00`008goo0`001UYF0P003Woo0P000eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF1`001UYF00<005YFFUH01UYF00<005YFFUH00P001goo00<0
05YF0000DGoo000bOol00`00FUH00002FUH2000MOol40002FUH00`00FUIJEP03FUH2000AOol20000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH40002FUH50006FUH0
0`00FUIJEP06FUH30008Ool01000FUIJEP00DGoo000bOol00`00FUH00004FUH3000EOol50006FUH0
1000FUIJEUYF0P005Goo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF000010001EYF
1@001eYF00<005YFFUH015YF0P002Woo00@005YFFUH0055oo`00<goo0P001EYF00<005YF00000`00
3Goo10000UYF00<005YFFUH01UYF00@005YF000001]oo`H0009JEP03001JEUYF00YJEP03001JEUYF
00AJEPP000AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00@000]oo`800003FUH007oo055oo`00
=7oo00<005YFFUH00eYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0`008goo5P000goo1@00
15YF00<005YFFUH01UYF00<005YFFUH00UYF1`003Woo00D005YF001JEP00059oo`00=Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00=Woo00<007oo
Ool02goo4P0057oo00D005YFFUIJEP0005=oo`00=goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000P00>7oo00<007ooOol0<7oo00<005YFFUH00UYF00<007ooOol0
DGoo000iOol50004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000kOol2000_Ool30003FUH00`00
Oomoo`1BOol003iooa80045oo`03001JEP0002aoo`80009JEP04001JEUYF001EOol0099oo`03001J
EP0002Uoo`8000AJEP03001JEP0005Ioo`00TWoo00<005YFFUH00P009Goo0P001UYF0P00Egoo002C
Ool01000FUH005YF0`0087oo0P0000=JEP00FUH01EYF00<007ooOol0EWoo002DOol20004FUH3000J
Ool30003FUH00`00FUIJEP02FUH2001IOol009Eoo`8000AJEP03001JEP0000<0011oo`H000MJEP04
001JEUYF001KOol009Ioo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP<0
05aoo`00Ugoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P00GWoo002IOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH3001POol009]oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006=o
o`00WWoo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00IWoo002ROol?001/Ool00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60054 .7639 m .59701 .71144 L .56587 .71032 L p .707 .577 .707 r
F P
0 g
s
.59701 .71144 m .60054 .7639 L .6323 .76087 L p .707 .577 .707 r
F P
0 g
s
.6323 .76087 m .62878 .70841 L .59701 .71144 L p .707 .577 .707 r
F P
0 g
s
.62878 .70841 m .6323 .76087 L .66157 .75399 L p .707 .577 .707 r
F P
0 g
s
.66157 .75399 m .65804 .70153 L .62878 .70841 L p .707 .577 .707 r
F P
0 g
s
.56939 .76278 m .56587 .71032 L .53838 .70515 L p .707 .577 .707 r
F P
0 g
s
.56587 .71032 m .56939 .76278 L .60054 .7639 L p .707 .577 .707 r
F P
0 g
s
.65804 .70153 m .66157 .75399 L .68548 .74392 L p .707 .577 .707 r
F P
0 g
s
.68548 .74392 m .68195 .69146 L .65804 .70153 L p .707 .577 .707 r
F P
0 g
s
.54191 .75761 m .53838 .70515 L .51726 .69645 L p .707 .577 .707 r
F P
0 g
s
.53838 .70515 m .54191 .75761 L .56939 .76278 L p .707 .577 .707 r
F P
0 g
s
.68195 .69146 m .68548 .74392 L .70169 .73165 L p .707 .577 .707 r
F P
0 g
s
.70169 .73165 m .69816 .67919 L .68195 .69146 L p .707 .577 .707 r
F P
0 g
s
.60517 .83349 m .60137 .80032 L .57027 .79966 L p .707 .577 .707 r
F P
0 g
s
.60137 .80032 m .60517 .83349 L .63682 .82912 L p .707 .577 .707 r
F P
0 g
s
.63682 .82912 m .63301 .79595 L .60137 .80032 L p .707 .577 .707 r
F P
0 g
s
.63301 .79595 m .63682 .82912 L .6659 .82015 L p .707 .577 .707 r
F P
0 g
s
.6659 .82015 m .66209 .78698 L .63301 .79595 L p .707 .577 .707 r
F P
0 g
s
.57407 .83282 m .57027 .79966 L .54274 .79403 L p .707 .577 .707 r
F P
0 g
s
.57027 .79966 m .57407 .83282 L .60517 .83349 L p .707 .577 .707 r
F P
0 g
s
.52078 .7489 m .51726 .69645 L .50455 .68505 L p .707 .577 .707 r
F P
0 g
s
.51726 .69645 m .52078 .7489 L .54191 .75761 L p .707 .577 .707 r
F P
0 g
s
.66209 .78698 m .6659 .82015 L .68957 .80745 L p .707 .577 .707 r
F P
0 g
s
.68957 .80745 m .68576 .77429 L .66209 .78698 L p .707 .577 .707 r
F P
0 g
s
.69816 .67919 m .70169 .73165 L .70861 .71838 L p .707 .577 .707 r
F P
0 g
s
.70861 .71838 m .70508 .66593 L .69816 .67919 L p .707 .577 .707 r
F P
0 g
s
.54654 .8272 m .54274 .79403 L .52149 .78398 L p .707 .577 .707 r
F P
0 g
s
.54274 .79403 m .54654 .8272 L .57407 .83282 L p .707 .577 .707 r
F P
0 g
s
.68576 .77429 m .68957 .80745 L .70551 .79228 L p .707 .577 .707 r
F P
0 g
s
.70551 .79228 m .70171 .75911 L .68576 .77429 L p .707 .577 .707 r
F P
0 g
s
.60827 .88068 m .60615 .8644 L .57506 .86387 L p .707 .577 .707 r
F P
0 g
s
.60615 .8644 m .60827 .88068 L .63986 .87593 L p .707 .577 .707 r
F P
0 g
s
.63986 .87593 m .63775 .85965 L .60615 .8644 L p .707 .577 .707 r
F P
0 g
s
.50803 .82845 m .47601 .35497 L .43203 .35338 L p .707 .577 .707 r
F P
0 g
s
.50455 .68505 m .50808 .73751 L .52078 .7489 L p .707 .577 .707 r
F P
0 g
s
.50808 .73751 m .50455 .68505 L .50151 .67209 L p .707 .577 .707 r
F P
0 g
s
.52149 .78398 m .52529 .81715 L .54654 .8272 L p .707 .577 .707 r
F P
0 g
s
.52529 .81715 m .52149 .78398 L .5086 .77051 L p .707 .577 .707 r
F P
0 g
s
.50151 .67209 m .50503 .72455 L .50808 .73751 L p .707 .577 .707 r
F P
0 g
s
.5086 .77051 m .5124 .80368 L .52529 .81715 L p .707 .577 .707 r
F P
0 g
s
.50503 .72455 m .50151 .67209 L .50843 .65883 L p .707 .577 .707 r
F P
0 g
s
.5124 .80368 m .5086 .77051 L .50532 .75492 L p .707 .577 .707 r
F P
0 g
s
.50843 .65883 m .51196 .71128 L .50503 .72455 L p .707 .577 .707 r
F P
0 g
s
.50532 .75492 m .50912 .78809 L .5124 .80368 L p .707 .577 .707 r
F P
0 g
s
.51196 .71128 m .50843 .65883 L .52464 .64656 L p .707 .577 .707 r
F P
0 g
s
.50912 .78809 m .50532 .75492 L .51198 .73874 L p .707 .577 .707 r
F P
0 g
s
.51537 .84988 m .51326 .8336 L .50989 .81726 L p .707 .577 .707 r
F P
0 g
s
.50989 .81726 m .512 .83354 L .51537 .84988 L p .707 .577 .707 r
F P
0 g
s
.52464 .64656 m .52817 .69902 L .51196 .71128 L p .707 .577 .707 r
F P
0 g
s
.51198 .73874 m .51578 .77191 L .50912 .78809 L p .707 .577 .707 r
F P
0 g
s
.52817 .69902 m .52464 .64656 L .54855 .63649 L p .707 .577 .707 r
F P
0 g
s
.51578 .77191 m .51198 .73874 L .52793 .72357 L p .707 .577 .707 r
F P
0 g
s
.512 .83354 m .50989 .81726 L .51644 .80025 L p .707 .577 .707 r
F P
0 g
s
.54855 .63649 m .55208 .68895 L .52817 .69902 L p .707 .577 .707 r
F P
0 g
s
.51644 .80025 m .51856 .81653 L .512 .83354 L p .707 .577 .707 r
F P
0 g
s
.52793 .72357 m .53173 .75673 L .51578 .77191 L p .707 .577 .707 r
F P
0 g
s
.53173 .75673 m .52793 .72357 L .5516 .71087 L p .707 .577 .707 r
F P
0 g
s
.51856 .81653 m .51644 .80025 L .53229 .78423 L p .707 .577 .707 r
F P
0 g
s
.53229 .78423 m .5344 .80051 L .51856 .81653 L p .707 .577 .707 r
F P
0 g
s
.5516 .71087 m .5554 .74404 L .53173 .75673 L p .707 .577 .707 r
F P
0 g
s
.5344 .80051 m .53229 .78423 L .55587 .77078 L p .707 .577 .707 r
F P
0 g
s
.55587 .77078 m .55798 .78706 L .5344 .80051 L p .707 .577 .707 r
F P
0 g
s
.47601 .35497 m .50803 .82845 L .55287 .82415 L p .707 .577 .707 r
F P
0 g
s
.55287 .82415 m .52084 .35067 L .47601 .35497 L p .707 .577 .707 r
F P
0 g
s
.63775 .85965 m .63986 .87593 L .66887 .86636 L p .707 .577 .707 r
F P
0 g
s
.66887 .86636 m .66675 .85008 L .63775 .85965 L p .707 .577 .707 r
F P
0 g
s
.55208 .68895 m .54855 .63649 L .57782 .6296 L p .707 .577 .707 r
F P
0 g
s
.57782 .6296 m .58134 .68206 L .55208 .68895 L p .707 .577 .707 r
F P
0 g
s
.5554 .74404 m .5516 .71087 L .58068 .7019 L p .707 .577 .707 r
F P
0 g
s
.58068 .7019 m .58448 .73507 L .5554 .74404 L p .707 .577 .707 r
F P
0 g
s
.55798 .78706 m .55587 .77078 L .58487 .76121 L p .707 .577 .707 r
F P
0 g
s
.58699 .77749 m .58487 .76121 L .61647 .75646 L p .707 .577 .707 r
F P
0 g
s
.58487 .76121 m .58699 .77749 L .55798 .78706 L p .707 .577 .707 r
F P
0 g
s
.61647 .75646 m .61858 .77274 L .58699 .77749 L p .707 .577 .707 r
F P
0 g
s
.52084 .35067 m .55287 .82415 L .59419 .8144 L p .707 .577 .707 r
F P
0 g
s
.58134 .68206 m .57782 .6296 L .60958 .62657 L p .707 .577 .707 r
F P
0 g
s
.60958 .62657 m .61311 .67903 L .58134 .68206 L p .707 .577 .707 r
F P
0 g
s
.58448 .73507 m .58068 .7019 L .61232 .69753 L p .707 .577 .707 r
F P
0 g
s
.61232 .69753 m .61612 .7307 L .58448 .73507 L p .707 .577 .707 r
F P
0 g
s
.59419 .8144 m .56216 .34092 L .52084 .35067 L p .707 .577 .707 r
F P
0 g
s
.57718 .88015 m .57506 .86387 L .54752 .85811 L p .707 .577 .707 r
F P
0 g
s
.57506 .86387 m .57718 .88015 L .60827 .88068 L p .707 .577 .707 r
F P
0 g
s
.46406 .82686 m .43203 .35338 L .39323 .34608 L p .707 .577 .707 r
F P
0 g
s
.43203 .35338 m .46406 .82686 L .50803 .82845 L p .707 .577 .707 r
F P
0 g
s
.66675 .85008 m .66887 .86636 L .69245 .8529 L p .707 .577 .707 r
F P
0 g
s
.69245 .8529 m .69033 .83663 L .66675 .85008 L p .707 .577 .707 r
F P
0 g
s
.54752 .85811 m .54964 .87439 L .57718 .88015 L p .707 .577 .707 r
F P
0 g
s
.70508 .66593 m .70861 .71838 L .70557 .70542 L p .707 .577 .707 r
F P
0 g
s
.70557 .70542 m .70204 .65296 L .70508 .66593 L p .707 .577 .707 r
F P
0 g
s
.64342 .6982 m .64723 .73136 L .61612 .7307 L p .707 .577 .707 r
F P
0 g
s
.61612 .7307 m .61232 .69753 L .64342 .6982 L p .707 .577 .707 r
F P
0 g
s
.64756 .75699 m .64967 .77327 L .61858 .77274 L p .707 .577 .707 r
F P
0 g
s
.61858 .77274 m .61647 .75646 L .64756 .75699 L p .707 .577 .707 r
F P
0 g
s
.56216 .34092 m .59419 .8144 L .62794 .80015 L p .707 .577 .707 r
F P
0 g
s
.64072 .6277 m .64425 .68016 L .61311 .67903 L p .707 .577 .707 r
F P
0 g
s
.61311 .67903 m .60958 .62657 L .64072 .6277 L p .707 .577 .707 r
F P
0 g
s
.62794 .80015 m .59591 .32667 L .56216 .34092 L p .707 .577 .707 r
F P
0 g
s
.70171 .75911 m .70551 .79228 L .71217 .7761 L p .707 .577 .707 r
F P
0 g
s
.71217 .7761 m .70837 .74293 L .70171 .75911 L p .707 .577 .707 r
F P
0 g
s
.54964 .87439 m .54752 .85811 L .52622 .84768 L p .707 .577 .707 r
F P
0 g
s
.69033 .83663 m .69245 .8529 L .70829 .83689 L p .707 .577 .707 r
F P
0 g
s
.70829 .83689 m .70618 .82061 L .69033 .83663 L p .707 .577 .707 r
F P
0 g
s
.42526 .81956 m .39323 .34608 L .3634 .33377 L p .707 .577 .707 r
F P
0 g
s
.39323 .34608 m .42526 .81956 L .46406 .82686 L p .707 .577 .707 r
F P
0 g
s
.52622 .84768 m .52834 .86396 L .54964 .87439 L p .707 .577 .707 r
F P
0 g
s
.52834 .86396 m .52622 .84768 L .51326 .8336 L p .707 .577 .707 r
F P
0 g
s
.6751 .76275 m .67721 .77903 L .64967 .77327 L p .707 .577 .707 r
F P
0 g
s
.64967 .77327 m .64756 .75699 L .6751 .76275 L p .707 .577 .707 r
F P
0 g
s
.59591 .32667 m .62794 .80015 L .65082 .7828 L p .707 .577 .707 r
F P
0 g
s
.67095 .70383 m .67475 .73699 L .64723 .73136 L p .707 .577 .707 r
F P
0 g
s
.64723 .73136 m .64342 .6982 L .67095 .70383 L p .707 .577 .707 r
F P
0 g
s
.65082 .7828 m .61879 .30932 L .59591 .32667 L p .707 .577 .707 r
F P
0 g
s
.70204 .65296 m .70557 .70542 L .69286 .69403 L p .707 .577 .707 r
F P
0 g
s
.69286 .69403 m .68934 .64157 L .70204 .65296 L p .707 .577 .707 r
F P
0 g
s
.70837 .74293 m .71217 .7761 L .7089 .76051 L p .707 .577 .707 r
F P
0 g
s
.7089 .76051 m .70509 .72735 L .70837 .74293 L p .707 .577 .707 r
F P
0 g
s
.70618 .82061 m .70829 .83689 L .71485 .81988 L p .707 .577 .707 r
F P
0 g
s
.71485 .81988 m .71273 .8036 L .70618 .82061 L p .707 .577 .707 r
F P
0 g
s
.51326 .8336 m .51537 .84988 L .52834 .86396 L p .707 .577 .707 r
F P
0 g
s
.39543 .80725 m .3634 .33377 L .34546 .31766 L p .707 .577 .707 r
F P
0 g
s
.3634 .33377 m .39543 .80725 L .42526 .81956 L p .707 .577 .707 r
F P
0 g
s
.25753 .72709 m .25401 .67463 L .22286 .6735 L p .707 .577 .707 r
F P
0 g
s
.25401 .67463 m .25753 .72709 L .2893 .72406 L p .707 .577 .707 r
F P
0 g
s
.2893 .72406 m .28577 .6716 L .25401 .67463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28577 .6716 m .2893 .72406 L .31856 .71717 L p .707 .577 .707 r
F P
0 g
s
.31856 .71717 m .31504 .66471 L .28577 .6716 L p .707 .577 .707 r
F P
0 g
s
.22639 .72596 m .22286 .6735 L .19538 .66834 L p .707 .577 .707 r
F P
0 g
s
.22286 .6735 m .22639 .72596 L .25753 .72709 L p .707 .577 .707 r
F P
0 g
s
.68934 .64157 m .69286 .69403 L .67174 .68532 L p .707 .577 .707 r
F P
0 g
s
.67174 .68532 m .66821 .63287 L .68934 .64157 L p .707 .577 .707 r
F P
0 g
s
.70509 .72735 m .7089 .76051 L .696 .74704 L p .707 .577 .707 r
F P
0 g
s
.696 .74704 m .6922 .71387 L .70509 .72735 L p .707 .577 .707 r
F P
0 g
s
.71273 .8036 m .71485 .81988 L .71148 .80353 L p .707 .577 .707 r
F P
0 g
s
.71148 .80353 m .70936 .78725 L .71273 .8036 L p .707 .577 .707 r
F P
0 g
s
.31504 .66471 m .31856 .71717 L .34247 .7071 L p .707 .577 .707 r
F P
0 g
s
.34247 .7071 m .33894 .65464 L .31504 .66471 L p .707 .577 .707 r
F P
0 g
s
.66821 .63287 m .67174 .68532 L .64425 .68016 L p .707 .577 .707 r
F P
0 g
s
.64425 .68016 m .64072 .6277 L .66821 .63287 L p .707 .577 .707 r
F P
0 g
s
.61879 .30932 m .65082 .7828 L .66059 .76403 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .62857 .29055 L .61879 .30932 L p .707 .577 .707 r
F P
0 g
s
.1989 .72079 m .19538 .66834 L .17425 .65963 L p .707 .577 .707 r
F P
0 g
s
.19538 .66834 m .1989 .72079 L .22639 .72596 L p .707 .577 .707 r
F P
0 g
s
.33894 .65464 m .34247 .7071 L .35868 .69483 L p .707 .577 .707 r
F P
0 g
s
.35868 .69483 m .35515 .64238 L .33894 .65464 L p .707 .577 .707 r
F P
0 g
s
.6922 .71387 m .696 .74704 L .67475 .73699 L p .707 .577 .707 r
F P
0 g
s
.67475 .73699 m .67095 .70383 L .6922 .71387 L p .707 .577 .707 r
F P
0 g
s
.37749 .79114 m .34546 .31766 L .34117 .29933 L p .707 .577 .707 r
F P
0 g
s
.34546 .31766 m .37749 .79114 L .39543 .80725 L p .707 .577 .707 r
F P
0 g
s
.26217 .79667 m .25836 .7635 L .22726 .76284 L p .707 .577 .707 r
F P
0 g
s
.25836 .7635 m .26217 .79667 L .29381 .79231 L p .707 .577 .707 r
F P
0 g
s
.29381 .79231 m .29001 .75914 L .25836 .7635 L p .707 .577 .707 r
F P
0 g
s
.29001 .75914 m .29381 .79231 L .32289 .78334 L p .707 .577 .707 r
F P
0 g
s
.32289 .78334 m .31908 .75017 L .29001 .75914 L p .707 .577 .707 r
F P
0 g
s
.70936 .78725 m .71148 .80353 L .69851 .78946 L p .707 .577 .707 r
F P
0 g
s
.69851 .78946 m .69639 .77318 L .70936 .78725 L p .707 .577 .707 r
F P
0 g
s
.23106 .79601 m .22726 .76284 L .19973 .75721 L p .707 .577 .707 r
F P
0 g
s
.22726 .76284 m .23106 .79601 L .26217 .79667 L p .707 .577 .707 r
F P
0 g
s
.17777 .71209 m .17425 .65963 L .16154 .64824 L p .707 .577 .707 r
F P
0 g
s
.17425 .65963 m .17777 .71209 L .1989 .72079 L p .707 .577 .707 r
F P
0 g
s
.31908 .75017 m .32289 .78334 L .34656 .77064 L p .707 .577 .707 r
F P
0 g
s
.34656 .77064 m .34276 .73747 L .31908 .75017 L p .707 .577 .707 r
F P
0 g
s
.66059 .76403 m .6563 .7457 L p .65047 .65 L .707 .577 .707 r
F P
0 g
s
.65047 .65 m .64491 .55872 L .64886 .61047 L .707 .577 .707 r
F
.65047 .65 m .64886 .61047 L .66059 .76403 L F
.64057 .468 m .66059 .76403 L p .64491 .55872 L F P
0 g
s
.62427 .27222 m .62857 .29055 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.6563 .7457 m .64793 .62198 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.64793 .62198 m .62427 .27222 L p .64491 .55872 L .707 .577 .707 r
F P
0 g
s
.62427 .27222 m .6563 .7457 L .63836 .72959 L p .707 .577 .707 r
F P
0 g
s
.6458 .66756 m .6496 .70073 L .6518 .70302 L p .707 .577 .707 r
F P
0 g
s
.6518 .70302 m .6625 .7142 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.65077 .68144 m .6458 .66756 L .6518 .70302 L .707 .577 .707 r
F
.66554 .75223 m .66343 .73595 L .65353 .72521 L p F P
0 g
s
.65353 .72521 m .65046 .72188 L p .65365 .7283 L .707 .577 .707 r
F P
0 g
s
.66554 .75223 m .65353 .72521 L .65365 .7283 L .707 .577 .707 r
F
.6625 .7142 m .6587 .68103 L .65033 .67229 L p F P
0 g
s
.65033 .67229 m .6458 .66756 L p .65077 .68144 L .707 .577 .707 r
F P
0 g
s
.6625 .7142 m .65033 .67229 L .65077 .68144 L .707 .577 .707 r
F
.62857 .29055 m .64057 .468 L p .64491 .55872 L F P
0 g
s
.35515 .64238 m .35868 .69483 L .3656 .68157 L p .707 .577 .707 r
F P
0 g
s
.3656 .68157 m .36208 .62911 L .35515 .64238 L p .707 .577 .707 r
F P
0 g
s
.20354 .79038 m .19973 .75721 L .17848 .74717 L p .707 .577 .707 r
F P
0 g
s
.19973 .75721 m .20354 .79038 L .23106 .79601 L p .707 .577 .707 r
F P
0 g
s
.69639 .77318 m .69851 .78946 L .67721 .77903 L p .707 .577 .707 r
F P
0 g
s
.67721 .77903 m .6751 .76275 L .69639 .77318 L p .707 .577 .707 r
F P
0 g
s
.34276 .73747 m .34656 .77064 L .3625 .75546 L p .707 .577 .707 r
F P
0 g
s
.3625 .75546 m .3587 .72229 L .34276 .73747 L p .707 .577 .707 r
F P
0 g
s
.26526 .84386 m .26314 .82758 L .23205 .82705 L p .707 .577 .707 r
F P
0 g
s
.26314 .82758 m .26526 .84386 L .29685 .83911 L p .707 .577 .707 r
F P
0 g
s
.29685 .83911 m .29474 .82283 L .26314 .82758 L p .707 .577 .707 r
F P
0 g
s
.29474 .82283 m .29685 .83911 L .32586 .82954 L p .707 .577 .707 r
F P
0 g
s
.32586 .82954 m .32374 .81326 L .29474 .82283 L p .707 .577 .707 r
F P
0 g
s
.16154 .64824 m .16507 .7007 L .17777 .71209 L p .707 .577 .707 r
F P
0 g
s
.16507 .7007 m .16154 .64824 L .1585 .63528 L p .707 .577 .707 r
F P
0 g
s
.23417 .84333 m .23205 .82705 L .20451 .82129 L p .707 .577 .707 r
F P
0 g
s
.23205 .82705 m .23417 .84333 L .26526 .84386 L p .707 .577 .707 r
F P
0 g
s
.32374 .81326 m .32586 .82954 L .34944 .81609 L p .707 .577 .707 r
F P
0 g
s
.34944 .81609 m .34732 .79981 L .32374 .81326 L p .707 .577 .707 r
F P
0 g
s
.34117 .29933 m .37319 .77281 L .37749 .79114 L p .707 .577 .707 r
F P
0 g
s
.37319 .77281 m .34117 .29933 L .35094 .28057 L p .707 .577 .707 r
F P
0 g
s
.17848 .74717 m .18229 .78034 L .20354 .79038 L p .707 .577 .707 r
F P
0 g
s
.18229 .78034 m .17848 .74717 L .16559 .73369 L p .707 .577 .707 r
F P
0 g
s
.20451 .82129 m .20663 .83757 L .23417 .84333 L p .707 .577 .707 r
F P
0 g
s
.36208 .62911 m .3656 .68157 L .36256 .66861 L p .707 .577 .707 r
F P
0 g
s
.36256 .66861 m .35904 .61615 L .36208 .62911 L p .707 .577 .707 r
F P
0 g
s
.3587 .72229 m .3625 .75546 L .36916 .73929 L p .707 .577 .707 r
F P
0 g
s
.36916 .73929 m .36536 .70612 L .3587 .72229 L p .707 .577 .707 r
F P
0 g
s
.20663 .83757 m .20451 .82129 L .18322 .81086 L p .707 .577 .707 r
F P
0 g
s
.34732 .79981 m .34944 .81609 L .36528 .80007 L p .707 .577 .707 r
F P
0 g
s
.36528 .80007 m .36317 .78379 L .34732 .79981 L p .707 .577 .707 r
F P
0 g
s
.63836 .72959 m .60633 .25611 L .62427 .27222 L p .707 .577 .707 r
F P
0 g
s
.1585 .63528 m .16203 .68773 L .16507 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18322 .81086 m .18533 .82714 L .20663 .83757 L p .707 .577 .707 r
F P
0 g
s
.16559 .73369 m .16939 .76686 L .18229 .78034 L p .707 .577 .707 r
F P
0 g
s
.16203 .68773 m .1585 .63528 L .16542 .62201 L p .707 .577 .707 r
F P
0 g
s
.16939 .76686 m .16559 .73369 L .16231 .7181 L p .707 .577 .707 r
F P
0 g
s
.18533 .82714 m .18322 .81086 L .17025 .79679 L p .707 .577 .707 r
F P
0 g
s
.35904 .61615 m .36256 .66861 L .34986 .65722 L p .707 .577 .707 r
F P
0 g
s
.34986 .65722 m .34633 .60476 L .35904 .61615 L p .707 .577 .707 r
F P
0 g
s
.36536 .70612 m .36916 .73929 L .36589 .7237 L p .707 .577 .707 r
F P
0 g
s
.36589 .7237 m .36208 .69053 L .36536 .70612 L p .707 .577 .707 r
F P
0 g
s
.36317 .78379 m .36528 .80007 L .37184 .78306 L p .707 .577 .707 r
F P
0 g
s
.37184 .78306 m .36972 .76678 L .36317 .78379 L p .707 .577 .707 r
F P
0 g
s
.38297 .75405 m .35094 .28057 L .37382 .26321 L p .707 .577 .707 r
F P
0 g
s
.35094 .28057 m .38297 .75405 L .37319 .77281 L p .707 .577 .707 r
F P
0 g
s
.17025 .79679 m .17236 .81307 L .18533 .82714 L p .707 .577 .707 r
F P
0 g
s
.16542 .62201 m .16895 .67447 L .16203 .68773 L p .707 .577 .707 r
F P
0 g
s
.16231 .7181 m .16611 .75127 L .16939 .76686 L p .707 .577 .707 r
F P
0 g
s
.16895 .67447 m .16542 .62201 L .18163 .60974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.60633 .25611 m .63836 .72959 L .60853 .71728 L p .707 .577 .707 r
F P
0 g
s
.60853 .71728 m .5765 .2438 L .60633 .25611 L p .707 .577 .707 r
F P
0 g
s
.16611 .75127 m .16231 .7181 L .16897 .70193 L p .707 .577 .707 r
F P
0 g
s
.17236 .81307 m .17025 .79679 L .16688 .78044 L p .707 .577 .707 r
F P
0 g
s
.34633 .60476 m .34986 .65722 L .32873 .64851 L p .707 .577 .707 r
F P
0 g
s
.32873 .64851 m .3252 .59605 L .34633 .60476 L p .707 .577 .707 r
F P
0 g
s
.36208 .69053 m .36589 .7237 L .35299 .71022 L p .707 .577 .707 r
F P
0 g
s
.35299 .71022 m .34919 .67705 L .36208 .69053 L p .707 .577 .707 r
F P
0 g
s
.36972 .76678 m .37184 .78306 L .36847 .76672 L p .707 .577 .707 r
F P
0 g
s
.36847 .76672 m .36635 .75044 L .36972 .76678 L p .707 .577 .707 r
F P
0 g
s
.16688 .78044 m .16899 .79672 L .17236 .81307 L p .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .38297 .75405 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.38215 .38639 m .40585 .73669 L p .37517 .33577 L .707 .577 .707 r
F P
0 g
s
.40585 .73669 m .37382 .26321 L .40757 .24896 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40585 .73669 L p .40643 .57268 L .707 .577 .707 r
F P
0 g
s
.40643 .57268 m .42334 .61922 L .4396 .72244 L .707 .577 .707 r
F
.43123 .59872 m .43473 .65055 L p .40664 .51311 L F P
0 g
s
.43473 .65055 m .4396 .72244 L p .42334 .61922 L .707 .577 .707 r
F P
0 g
s
.40664 .51311 m .43473 .65055 L .42334 .61922 L .707 .577 .707 r
F
.44889 .23921 m .48092 .71269 L .4396 .72244 L p F P
0 g
s
.46306 .71782 m .46095 .70154 L .45409 .7038 L p .707 .577 .707 r
F P
0 g
s
.4396 .72244 m .40757 .24896 L .44889 .23921 L p .707 .577 .707 r
F P
0 g
s
.45409 .7038 m .43194 .71111 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.46306 .71782 m .45409 .7038 L .45886 .71691 L .707 .577 .707 r
F
.43194 .71111 m .43405 .72739 L .4596 .71896 L p F P
0 g
s
.4596 .71896 m .46306 .71782 L p .45886 .71691 L .707 .577 .707 r
F P
0 g
s
.45886 .71691 m .43194 .71111 L .4596 .71896 L .707 .577 .707 r
F
.40643 .57268 m .40664 .51311 L .42334 .61922 L F
.40757 .24896 m .43123 .59872 L p .40664 .51311 L F P
0 g
s
.42721 .65619 m .43101 .68936 L .45513 .68192 L p .707 .577 .707 r
F P
0 g
s
.45513 .68192 m .46009 .68038 L p .45324 .67534 L .707 .577 .707 r
F P
0 g
s
.45324 .67534 m .42721 .65619 L .45513 .68192 L .707 .577 .707 r
F
.39557 .66055 m .39937 .69372 L .42406 .69032 L p F P
0 g
s
.42406 .69032 m .43101 .68936 L p .42303 .68287 L .707 .577 .707 r
F P
0 g
s
.42303 .68287 m .39557 .66055 L .42406 .69032 L .707 .577 .707 r
F
.37382 .26321 m .38215 .38639 L p .37517 .33577 L F P
0 g
s
.18163 .60974 m .18516 .6622 L .16895 .67447 L p .707 .577 .707 r
F P
0 g
s
.16897 .70193 m .17277 .7351 L .16611 .75127 L p .707 .577 .707 r
F P
0 g
s
.18516 .6622 m .18163 .60974 L .20554 .59967 L p .707 .577 .707 r
F P
0 g
s
.17277 .7351 m .16897 .70193 L .18492 .68675 L p .707 .577 .707 r
F P
0 g
s
.3252 .59605 m .32873 .64851 L .30124 .64334 L p .707 .577 .707 r
F P
0 g
s
.30124 .64334 m .29772 .59088 L .3252 .59605 L p .707 .577 .707 r
F P
0 g
s
.16899 .79672 m .16688 .78044 L .17343 .76343 L p .707 .577 .707 r
F P
0 g
s
.5765 .2438 m .60853 .71728 L .56973 .70998 L p .707 .577 .707 r
F P
0 g
s
.56973 .70998 m .5377 .2365 L .5765 .2438 L p .707 .577 .707 r
F P
0 g
s
.34919 .67705 m .35299 .71022 L .33174 .70018 L p .707 .577 .707 r
F P
0 g
s
.33174 .70018 m .32794 .66701 L .34919 .67705 L p .707 .577 .707 r
F P
0 g
s
.36635 .75044 m .36847 .76672 L .3555 .75264 L p .707 .577 .707 r
F P
0 g
s
.3555 .75264 m .35339 .73636 L .36635 .75044 L p .707 .577 .707 r
F P
0 g
s
.20907 .65213 m .20554 .59967 L .23481 .59279 L p .707 .577 .707 r
F P
0 g
s
.20554 .59967 m .20907 .65213 L .18516 .6622 L p .707 .577 .707 r
F P
0 g
s
.17343 .76343 m .17555 .77971 L .16899 .79672 L p .707 .577 .707 r
F P
0 g
s
.29772 .59088 m .30124 .64334 L .2701 .64222 L p .707 .577 .707 r
F P
0 g
s
.2701 .64222 m .26657 .58976 L .29772 .59088 L p .707 .577 .707 r
F P
0 g
s
.18492 .68675 m .18872 .71992 L .17277 .7351 L p .707 .577 .707 r
F P
0 g
s
.23833 .64525 m .23481 .59279 L .26657 .58976 L p .707 .577 .707 r
F P
0 g
s
.23481 .59279 m .23833 .64525 L .20907 .65213 L p .707 .577 .707 r
F P
0 g
s
.18872 .71992 m .18492 .68675 L .20859 .67405 L p .707 .577 .707 r
F P
0 g
s
.26657 .58976 m .2701 .64222 L .23833 .64525 L p .707 .577 .707 r
F P
0 g
s
.5377 .2365 m .56973 .70998 L .52575 .7084 L p .707 .577 .707 r
F P
0 g
s
.52575 .7084 m .49373 .23492 L .5377 .2365 L p .707 .577 .707 r
F P
0 g
s
.17555 .77971 m .17343 .76343 L .18928 .74741 L p .707 .577 .707 r
F P
0 g
s
.32794 .66701 m .33174 .70018 L .30422 .69455 L p .707 .577 .707 r
F P
0 g
s
.30422 .69455 m .30041 .66138 L .32794 .66701 L p .707 .577 .707 r
F P
0 g
s
.48092 .71269 m .46251 .44063 L p .49373 .23492 L .707 .577 .707 r
F P
0 g
s
.49373 .23492 m .52575 .7084 L .48092 .71269 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .48376 .66769 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45629 .64722 m .45828 .66455 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.45828 .66455 m .46009 .68038 L p .45857 .64892 L .707 .577 .707 r
F P
0 g
s
.46251 .44063 m .44889 .23921 L .46635 .23754 L p .707 .577 .707 r
F P
0 g
s
.46635 .23754 m .49373 .23492 L p .46251 .44063 L .707 .577 .707 r
F P
0 g
s
.35339 .73636 m .3555 .75264 L .3342 .74221 L p .707 .577 .707 r
F P
0 g
s
.3342 .74221 m .33209 .72593 L .35339 .73636 L p .707 .577 .707 r
F P
0 g
s
.73775 .66719 m .73422 .61473 L .70307 .61361 L p .707 .577 .707 r
F P
0 g
s
.73422 .61473 m .73775 .66719 L .76951 .66416 L p .707 .577 .707 r
F P
0 g
s
.76951 .66416 m .76598 .6117 L .73422 .61473 L p .707 .577 .707 r
F P
0 g
s
.76598 .6117 m .76951 .66416 L .79878 .65727 L p .707 .577 .707 r
F P
0 g
s
.79878 .65727 m .79525 .60482 L .76598 .6117 L p .707 .577 .707 r
F P
0 g
s
.18928 .74741 m .19139 .76369 L .17555 .77971 L p .707 .577 .707 r
F P
0 g
s
.21239 .70722 m .20859 .67405 L .23767 .66508 L p .707 .577 .707 r
F P
0 g
s
.20859 .67405 m .21239 .70722 L .18872 .71992 L p .707 .577 .707 r
F P
0 g
s
.7066 .66607 m .70307 .61361 L .67559 .60844 L p .707 .577 .707 r
F P
0 g
s
.70307 .61361 m .7066 .66607 L .73775 .66719 L p .707 .577 .707 r
F P
0 g
s
.30041 .66138 m .30422 .69455 L .27311 .69389 L p .707 .577 .707 r
F P
0 g
s
.27311 .69389 m .26931 .66072 L .30041 .66138 L p .707 .577 .707 r
F P
0 g
s
.79525 .60482 m .79878 .65727 L .82268 .6472 L p .707 .577 .707 r
F P
0 g
s
.82268 .6472 m .81916 .59475 L .79525 .60482 L p .707 .577 .707 r
F P
0 g
s
.24147 .69825 m .23767 .66508 L .26931 .66072 L p .707 .577 .707 r
F P
0 g
s
.23767 .66508 m .24147 .69825 L .21239 .70722 L p .707 .577 .707 r
F P
0 g
s
.19139 .76369 m .18928 .74741 L .21286 .73396 L p .707 .577 .707 r
F P
0 g
s
.26931 .66072 m .27311 .69389 L .24147 .69825 L p .707 .577 .707 r
F P
0 g
s
.33209 .72593 m .3342 .74221 L .30666 .73645 L p .707 .577 .707 r
F P
0 g
s
.30666 .73645 m .30455 .72017 L .33209 .72593 L p .707 .577 .707 r
F P
0 g
s
.67912 .6609 m .67559 .60844 L .65446 .59973 L p .707 .577 .707 r
F P
0 g
s
.67559 .60844 m .67912 .6609 L .7066 .66607 L p .707 .577 .707 r
F P
0 g
s
.21286 .73396 m .21497 .75024 L .19139 .76369 L p .707 .577 .707 r
F P
0 g
s
.81916 .59475 m .82268 .6472 L .83889 .63494 L p .707 .577 .707 r
F P
0 g
s
.83889 .63494 m .83537 .58248 L .81916 .59475 L p .707 .577 .707 r
F P
0 g
s
.21497 .75024 m .21286 .73396 L .24186 .72439 L p .707 .577 .707 r
F P
0 g
s
.74238 .73054 m .73858 .69737 L .70747 .69671 L p .707 .577 .707 r
F P
0 g
s
.73858 .69737 m .74238 .73054 L .77402 .72617 L p .707 .577 .707 r
F P
0 g
s
.77402 .72617 m .77022 .693 L .73858 .69737 L p .707 .577 .707 r
F P
0 g
s
.30455 .72017 m .30666 .73645 L .27557 .73592 L p .707 .577 .707 r
F P
0 g
s
.27557 .73592 m .27346 .71964 L .30455 .72017 L p .707 .577 .707 r
F P
0 g
s
.77022 .693 m .77402 .72617 L .8031 .7172 L p .707 .577 .707 r
F P
0 g
s
.8031 .7172 m .7993 .68403 L .77022 .693 L p .707 .577 .707 r
F P
0 g
s
.24398 .74067 m .24186 .72439 L .27346 .71964 L p .707 .577 .707 r
F P
0 g
s
.24186 .72439 m .24398 .74067 L .21497 .75024 L p .707 .577 .707 r
F P
0 g
s
.71127 .72987 m .70747 .69671 L .67995 .69108 L p .707 .577 .707 r
F P
0 g
s
.70747 .69671 m .71127 .72987 L .74238 .73054 L p .707 .577 .707 r
F P
0 g
s
.27346 .71964 m .27557 .73592 L .24398 .74067 L p .707 .577 .707 r
F P
0 g
s
.65799 .65219 m .65446 .59973 L .64175 .58834 L p .707 .577 .707 r
F P
0 g
s
.65446 .59973 m .65799 .65219 L .67912 .6609 L p .707 .577 .707 r
F P
0 g
s
.7993 .68403 m .8031 .7172 L .82677 .7045 L p .707 .577 .707 r
F P
0 g
s
.82677 .7045 m .82297 .67134 L .7993 .68403 L p .707 .577 .707 r
F P
0 g
s
.83537 .58248 m .83889 .63494 L .84582 .62167 L p .707 .577 .707 r
F P
0 g
s
.84582 .62167 m .84229 .56922 L .83537 .58248 L p .707 .577 .707 r
F P
0 g
s
.68375 .72425 m .67995 .69108 L .6587 .68103 L p .707 .577 .707 r
F P
0 g
s
.67995 .69108 m .68375 .72425 L .71127 .72987 L p .707 .577 .707 r
F P
0 g
s
.74547 .76896 m .74336 .75268 L .71227 .75214 L p .707 .577 .707 r
F P
0 g
s
.74336 .75268 m .74547 .76896 L .77706 .7642 L p .707 .577 .707 r
F P
0 g
s
.77706 .7642 m .77495 .74792 L .74336 .75268 L p .707 .577 .707 r
F P
0 g
s
.82297 .67134 m .82677 .7045 L .84272 .68933 L p .707 .577 .707 r
F P
0 g
s
.84272 .68933 m .83892 .65616 L .82297 .67134 L p .707 .577 .707 r
F P
0 g
s
.77495 .74792 m .77706 .7642 L .80607 .75463 L p .707 .577 .707 r
F P
0 g
s
.80607 .75463 m .80396 .73835 L .77495 .74792 L p .707 .577 .707 r
F P
0 g
s
.64175 .58834 m .64528 .6408 L .65799 .65219 L p .707 .577 .707 r
F P
0 g
s
.71438 .76842 m .71227 .75214 L .68473 .74638 L p .707 .577 .707 r
F P
0 g
s
.71227 .75214 m .71438 .76842 L .74547 .76896 L p .707 .577 .707 r
F P
0 g
s
.64528 .6408 m .64175 .58834 L .63871 .57538 L p .707 .577 .707 r
F P
0 g
s
.80396 .73835 m .80607 .75463 L .82965 .74118 L p .707 .577 .707 r
F P
0 g
s
.82965 .74118 m .82754 .7249 L .80396 .73835 L p .707 .577 .707 r
F P
0 g
s
.6587 .68103 m .6625 .7142 L .68375 .72425 L p .707 .577 .707 r
F P
0 g
s
.68473 .74638 m .68684 .76266 L .71438 .76842 L p .707 .577 .707 r
F P
0 g
s
.84229 .56922 m .84582 .62167 L .84278 .60871 L p .707 .577 .707 r
F P
0 g
s
.84278 .60871 m .83925 .55625 L .84229 .56922 L p .707 .577 .707 r
F P
0 g
s
.68684 .76266 m .68473 .74638 L .66343 .73595 L p .707 .577 .707 r
F P
0 g
s
.83892 .65616 m .84272 .68933 L .84938 .67315 L p .707 .577 .707 r
F P
0 g
s
.84938 .67315 m .84558 .63998 L .83892 .65616 L p .707 .577 .707 r
F P
0 g
s
.82754 .7249 m .82965 .74118 L .84549 .72517 L p .707 .577 .707 r
F P
0 g
s
.84549 .72517 m .84338 .70889 L .82754 .7249 L p .707 .577 .707 r
F P
0 g
s
.66343 .73595 m .66554 .75223 L .68684 .76266 L p .707 .577 .707 r
F P
0 g
s
.63871 .57538 m .64224 .62784 L .64528 .6408 L p .707 .577 .707 r
F P
0 g
s
.64224 .62784 m .63871 .57538 L .64563 .56212 L p .707 .577 .707 r
F P
0 g
s
.6496 .70073 m .6458 .66756 L .64252 .65197 L p .707 .577 .707 r
F P
0 g
s
.84338 .70889 m .84549 .72517 L .85205 .70815 L p .707 .577 .707 r
F P
0 g
s
.85205 .70815 m .84994 .69187 L .84338 .70889 L p .707 .577 .707 r
F P
0 g
s
.84558 .63998 m .84938 .67315 L .8461 .65756 L p .707 .577 .707 r
F P
0 g
s
.8461 .65756 m .8423 .62439 L .84558 .63998 L p .707 .577 .707 r
F P
0 g
s
.83925 .55625 m .84278 .60871 L .83007 .59732 L p .707 .577 .707 r
F P
0 g
s
.83007 .59732 m .82654 .54486 L .83925 .55625 L p .707 .577 .707 r
F P
0 g
s
.65046 .72188 m .65257 .73816 L .66554 .75223 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64252 .65197 m .64633 .68514 L .6496 .70073 L p .707 .577 .707 r
F P
0 g
s
.64563 .56212 m .64916 .61457 L .64224 .62784 L p .707 .577 .707 r
F P
0 g
s
.64916 .61457 m .64563 .56212 L .66184 .54985 L p .707 .577 .707 r
F P
0 g
s
.65257 .73816 m .65046 .72188 L .64709 .70553 L p .707 .577 .707 r
F P
0 g
s
.39474 .63037 m .39121 .57792 L .36006 .57679 L p .707 .577 .707 r
F P
0 g
s
.39121 .57792 m .39474 .63037 L .4265 .62735 L p .707 .577 .707 r
F P
0 g
s
.4265 .62735 m .42297 .57489 L .39121 .57792 L p .707 .577 .707 r
F P
0 g
s
.64633 .68514 m .64252 .65197 L .64918 .63579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42297 .57489 m .4265 .62735 L .45577 .62046 L p .707 .577 .707 r
F P
0 g
s
.45577 .62046 m .45224 .568 L .42297 .57489 L p .707 .577 .707 r
F P
0 g
s
.84994 .69187 m .85205 .70815 L .84868 .69181 L p .707 .577 .707 r
F P
0 g
s
.84868 .69181 m .84657 .67553 L .84994 .69187 L p .707 .577 .707 r
F P
0 g
s
.36359 .62925 m .36006 .57679 L .33258 .57162 L p .707 .577 .707 r
F P
0 g
s
.36006 .57679 m .36359 .62925 L .39474 .63037 L p .707 .577 .707 r
F P
0 g
s
.8423 .62439 m .8461 .65756 L .83321 .64409 L p .707 .577 .707 r
F P
0 g
s
.83321 .64409 m .8294 .61092 L .8423 .62439 L p .707 .577 .707 r
F P
0 g
s
.82654 .54486 m .83007 .59732 L .80894 .58861 L p .707 .577 .707 r
F P
0 g
s
.80894 .58861 m .80541 .53615 L .82654 .54486 L p .707 .577 .707 r
F P
0 g
s
.64709 .70553 m .6492 .72181 L .65257 .73816 L p .707 .577 .707 r
F P
0 g
s
.45224 .568 m .45577 .62046 L .47967 .61039 L p .707 .577 .707 r
F P
0 g
s
.47967 .61039 m .47615 .55793 L .45224 .568 L p .707 .577 .707 r
F P
0 g
s
.64918 .63579 m .65299 .66896 L .64633 .68514 L p .707 .577 .707 r
F P
0 g
s
.66184 .54985 m .66537 .60231 L .64916 .61457 L p .707 .577 .707 r
F P
0 g
s
.66537 .60231 m .66184 .54985 L .68575 .53978 L p .707 .577 .707 r
F P
0 g
s
.33611 .62408 m .33258 .57162 L .31145 .56292 L p .707 .577 .707 r
F P
0 g
s
.33258 .57162 m .33611 .62408 L .36359 .62925 L p .707 .577 .707 r
F P
0 g
s
.65299 .66896 m .64918 .63579 L .66513 .62062 L p .707 .577 .707 r
F P
0 g
s
.6492 .72181 m .64709 .70553 L .65365 .68852 L p .707 .577 .707 r
F P
0 g
s
.80541 .53615 m .80894 .58861 L .78146 .58344 L p .707 .577 .707 r
F P
0 g
s
.78146 .58344 m .77793 .53099 L .80541 .53615 L p .707 .577 .707 r
F P
0 g
s
.47615 .55793 m .47967 .61039 L .49588 .59812 L p .707 .577 .707 r
F P
0 g
s
.49588 .59812 m .49236 .54566 L .47615 .55793 L p .707 .577 .707 r
F P
0 g
s
.84657 .67553 m .84868 .69181 L .83571 .67773 L p .707 .577 .707 r
F P
0 g
s
.83571 .67773 m .8336 .66145 L .84657 .67553 L p .707 .577 .707 r
F P
0 g
s
.8294 .61092 m .83321 .64409 L .81196 .63404 L p .707 .577 .707 r
F P
0 g
s
.81196 .63404 m .80815 .60087 L .8294 .61092 L p .707 .577 .707 r
F P
0 g
s
.39937 .69372 m .39557 .66055 L .36446 .65989 L p .707 .577 .707 r
F P
0 g
s
.43101 .68936 m .42721 .65619 L .39557 .66055 L p .707 .577 .707 r
F P
0 g
s
.46009 .68038 m .45629 .64722 L .42721 .65619 L p .707 .577 .707 r
F P
0 g
s
.65365 .68852 m .65576 .7048 L .6492 .72181 L p .707 .577 .707 r
F P
0 g
s
.68928 .59224 m .68575 .53978 L .71502 .53289 L p .707 .577 .707 r
F P
0 g
s
.68575 .53978 m .68928 .59224 L .66537 .60231 L p .707 .577 .707 r
F P
0 g
s
.36826 .69306 m .36446 .65989 L .33694 .65426 L p .707 .577 .707 r
F P
0 g
s
.36446 .65989 m .36826 .69306 L .39937 .69372 L p .707 .577 .707 r
F P
0 g
s
.31498 .61538 m .31145 .56292 L .29874 .55153 L p .707 .577 .707 r
F P
0 g
s
.31145 .56292 m .31498 .61538 L .33611 .62408 L p .707 .577 .707 r
F P
0 g
s
.48376 .66769 m .47996 .63452 L .45629 .64722 L p .707 .577 .707 r
F P
0 g
s
.66513 .62062 m .66893 .65378 L .65299 .66896 L p .707 .577 .707 r
F P
0 g
s
.77793 .53099 m .78146 .58344 L .75031 .58232 L p .707 .577 .707 r
F P
0 g
s
.75031 .58232 m .74678 .52986 L .77793 .53099 L p .707 .577 .707 r
F P
0 g
s
.66893 .65378 m .66513 .62062 L .6888 .60792 L p .707 .577 .707 r
F P
0 g
s
.71855 .58535 m .71502 .53289 L .74678 .52986 L p .707 .577 .707 r
F P
0 g
s
.71502 .53289 m .71855 .58535 L .68928 .59224 L p .707 .577 .707 r
F P
0 g
s
.65576 .7048 m .65365 .68852 L .66949 .67251 L p .707 .577 .707 r
F P
0 g
s
.74678 .52986 m .75031 .58232 L .71855 .58535 L p .707 .577 .707 r
F P
0 g
s
.80815 .60087 m .81196 .63404 L .78443 .62841 L p .707 .577 .707 r
F P
0 g
s
.78443 .62841 m .78063 .59524 L .80815 .60087 L p .707 .577 .707 r
F P
0 g
s
.49236 .54566 m .49588 .59812 L .50281 .58486 L p .707 .577 .707 r
F P
0 g
s
.50281 .58486 m .49928 .5324 L .49236 .54566 L p .707 .577 .707 r
F P
0 g
s
.34074 .68743 m .33694 .65426 L .31569 .64422 L p .707 .577 .707 r
F P
0 g
s
.33694 .65426 m .34074 .68743 L .36826 .69306 L p .707 .577 .707 r
F P
0 g
s
.8336 .66145 m .83571 .67773 L .81442 .6673 L p .707 .577 .707 r
F P
0 g
s
.81442 .6673 m .8123 .65102 L .8336 .66145 L p .707 .577 .707 r
F P
0 g
s
.40246 .73214 m .40035 .71586 L .36926 .71533 L p .707 .577 .707 r
F P
0 g
s
.40035 .71586 m .40246 .73214 L .43405 .72739 L p .707 .577 .707 r
F P
0 g
s
.43405 .72739 m .43194 .71111 L .40035 .71586 L p .707 .577 .707 r
F P
0 g
s
.47996 .63452 m .48376 .66769 L .49971 .65251 L p .707 .577 .707 r
F P
0 g
s
.49971 .65251 m .49591 .61934 L .47996 .63452 L p .707 .577 .707 r
F P
0 g
s
.66949 .67251 m .67161 .68879 L .65576 .7048 L p .707 .577 .707 r
F P
0 g
s
.6926 .64109 m .6888 .60792 L .71788 .59895 L p .707 .577 .707 r
F P
0 g
s
.6888 .60792 m .6926 .64109 L .66893 .65378 L p .707 .577 .707 r
F P
0 g
s
.29874 .55153 m .30227 .60398 L .31498 .61538 L p .707 .577 .707 r
F P
0 g
s
.37137 .73161 m .36926 .71533 L .34172 .70957 L p .707 .577 .707 r
F P
0 g
s
.36926 .71533 m .37137 .73161 L .40246 .73214 L p .707 .577 .707 r
F P
0 g
s
.78063 .59524 m .78443 .62841 L .75332 .62775 L p .707 .577 .707 r
F P
0 g
s
.75332 .62775 m .74952 .59458 L .78063 .59524 L p .707 .577 .707 r
F P
0 g
s
.30227 .60398 m .29874 .55153 L .2957 .53856 L p .707 .577 .707 r
F P
0 g
s
.46095 .70154 m .46306 .71782 L .48664 .70437 L p .707 .577 .707 r
F P
0 g
s
.48664 .70437 m .48453 .68809 L .46095 .70154 L p .707 .577 .707 r
F P
0 g
s
.67161 .68879 m .66949 .67251 L .69307 .65905 L p .707 .577 .707 r
F P
0 g
s
.31569 .64422 m .31949 .67739 L .34074 .68743 L p .707 .577 .707 r
F P
0 g
s
.72168 .63212 m .71788 .59895 L .74952 .59458 L p .707 .577 .707 r
F P
0 g
s
.71788 .59895 m .72168 .63212 L .6926 .64109 L p .707 .577 .707 r
F P
0 g
s
.74952 .59458 m .75332 .62775 L .72168 .63212 L p .707 .577 .707 r
F P
0 g
s
.31949 .67739 m .31569 .64422 L .30279 .63074 L p .707 .577 .707 r
F P
0 g
s
.34172 .70957 m .34383 .72585 L .37137 .73161 L p .707 .577 .707 r
F P
0 g
s
.8123 .65102 m .81442 .6673 L .78688 .66154 L p .707 .577 .707 r
F P
0 g
s
.78688 .66154 m .78476 .64526 L .8123 .65102 L p .707 .577 .707 r
F P
0 g
s
.49928 .5324 m .50281 .58486 L .49977 .57189 L p .707 .577 .707 r
F P
0 g
s
.49977 .57189 m .49624 .51944 L .49928 .5324 L p .707 .577 .707 r
F P
0 g
s
.34383 .72585 m .34172 .70957 L .32042 .69914 L p .707 .577 .707 r
F P
0 g
s
.69307 .65905 m .69519 .67533 L .67161 .68879 L p .707 .577 .707 r
F P
0 g
s
.49591 .61934 m .49971 .65251 L .50637 .63634 L p .707 .577 .707 r
F P
0 g
s
.50637 .63634 m .50257 .60317 L .49591 .61934 L p .707 .577 .707 r
F P
0 g
s
.48453 .68809 m .48664 .70437 L .50248 .68835 L p .707 .577 .707 r
F P
0 g
s
.50248 .68835 m .50037 .67207 L .48453 .68809 L p .707 .577 .707 r
F P
0 g
s
.69519 .67533 m .69307 .65905 L .72208 .64948 L p .707 .577 .707 r
F P
0 g
s
.32042 .69914 m .32253 .71542 L .34383 .72585 L p .707 .577 .707 r
F P
0 g
s
.2957 .53856 m .29923 .59102 L .30227 .60398 L p .707 .577 .707 r
F P
0 g
s
.78476 .64526 m .78688 .66154 L .75579 .66101 L p .707 .577 .707 r
F P
0 g
s
.75579 .66101 m .75367 .64473 L .78476 .64526 L p .707 .577 .707 r
F P
0 g
s
.30279 .63074 m .30659 .66391 L .31949 .67739 L p .707 .577 .707 r
F P
0 g
s
.29923 .59102 m .2957 .53856 L .30262 .5253 L p .707 .577 .707 r
F P
0 g
s
.72419 .66576 m .72208 .64948 L .75367 .64473 L p .707 .577 .707 r
F P
0 g
s
.72208 .64948 m .72419 .66576 L .69519 .67533 L p .707 .577 .707 r
F P
0 g
s
.75367 .64473 m .75579 .66101 L .72419 .66576 L p .707 .577 .707 r
F P
0 g
s
.30659 .66391 m .30279 .63074 L .29951 .61515 L p .707 .577 .707 r
F P
0 g
s
.32253 .71542 m .32042 .69914 L .30745 .68506 L p .707 .577 .707 r
F P
0 g
s
.50037 .67207 m .50248 .68835 L .50904 .67134 L p .707 .577 .707 r
F P
0 g
s
.50904 .67134 m .50693 .65506 L .50037 .67207 L p .707 .577 .707 r
F P
0 g
s
.50257 .60317 m .50637 .63634 L .50309 .62075 L p .707 .577 .707 r
F P
0 g
s
.50309 .62075 m .49929 .58758 L .50257 .60317 L p .707 .577 .707 r
F P
0 g
s
.49624 .51944 m .49977 .57189 L .48706 .5605 L p .707 .577 .707 r
F P
0 g
s
.48706 .5605 m .48353 .50805 L .49624 .51944 L p .707 .577 .707 r
F P
0 g
s
.30745 .68506 m .30956 .70134 L .32253 .71542 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29951 .61515 m .30331 .64832 L .30659 .66391 L p .707 .577 .707 r
F P
0 g
s
.30262 .5253 m .30615 .57776 L .29923 .59102 L p .707 .577 .707 r
F P
0 g
s
.30615 .57776 m .30262 .5253 L .31883 .51303 L p .707 .577 .707 r
F P
0 g
s
.30956 .70134 m .30745 .68506 L .30408 .66872 L p .707 .577 .707 r
F P
0 g
s
.30331 .64832 m .29951 .61515 L .30617 .59898 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50693 .65506 m .50904 .67134 L .50567 .65499 L p .707 .577 .707 r
F P
0 g
s
.50567 .65499 m .50356 .63871 L .50693 .65506 L p .707 .577 .707 r
F P
0 g
s
.49929 .58758 m .50309 .62075 L .49019 .60727 L p .707 .577 .707 r
F P
0 g
s
.49019 .60727 m .48639 .5741 L .49929 .58758 L p .707 .577 .707 r
F P
0 g
s
.48353 .50805 m .48706 .5605 L .46593 .5518 L p .707 .577 .707 r
F P
0 g
s
.46593 .5518 m .4624 .49934 L .48353 .50805 L p .707 .577 .707 r
F P
0 g
s
.30408 .66872 m .30619 .685 L .30956 .70134 L p .707 .577 .707 r
F P
0 g
s
.30617 .59898 m .30998 .63215 L .30331 .64832 L p .707 .577 .707 r
F P
0 g
s
.31883 .51303 m .32236 .56549 L .30615 .57776 L p .707 .577 .707 r
F P
0 g
s
.32236 .56549 m .31883 .51303 L .34274 .50296 L p .707 .577 .707 r
F P
0 g
s
.30998 .63215 m .30617 .59898 L .32212 .5838 L p .707 .577 .707 r
F P
0 g
s
.30619 .685 m .30408 .66872 L .31064 .65171 L p .707 .577 .707 r
F P
0 g
s
.4624 .49934 m .46593 .5518 L .43845 .54663 L p .707 .577 .707 r
F P
0 g
s
.43845 .54663 m .43492 .49417 L .4624 .49934 L p .707 .577 .707 r
F P
0 g
s
.50356 .63871 m .50567 .65499 L .4927 .64092 L p .707 .577 .707 r
F P
0 g
s
.4927 .64092 m .49059 .62464 L .50356 .63871 L p .707 .577 .707 r
F P
0 g
s
.48639 .5741 m .49019 .60727 L .46894 .59723 L p .707 .577 .707 r
F P
0 g
s
.46894 .59723 m .46514 .56406 L .48639 .5741 L p .707 .577 .707 r
F P
0 g
s
.31064 .65171 m .31275 .66799 L .30619 .685 L p .707 .577 .707 r
F P
0 g
s
.34627 .55542 m .34274 .50296 L .37201 .49608 L p .707 .577 .707 r
F P
0 g
s
.34274 .50296 m .34627 .55542 L .32236 .56549 L p .707 .577 .707 r
F P
0 g
s
.32212 .5838 m .32592 .61697 L .30998 .63215 L p .707 .577 .707 r
F P
0 g
s
.43492 .49417 m .43845 .54663 L .4073 .5455 L p .707 .577 .707 r
F P
0 g
s
.4073 .5455 m .40377 .49305 L .43492 .49417 L p .707 .577 .707 r
F P
0 g
s
.32592 .61697 m .32212 .5838 L .34579 .5711 L p .707 .577 .707 r
F P
0 g
s
.37554 .54853 m .37201 .49608 L .40377 .49305 L p .707 .577 .707 r
F P
0 g
s
.37201 .49608 m .37554 .54853 L .34627 .55542 L p .707 .577 .707 r
F P
0 g
s
.31275 .66799 m .31064 .65171 L .32648 .63569 L p .707 .577 .707 r
F P
0 g
s
.40377 .49305 m .4073 .5455 L .37554 .54853 L p .707 .577 .707 r
F P
0 g
s
.46514 .56406 m .46894 .59723 L .44142 .5916 L p .707 .577 .707 r
F P
0 g
s
.44142 .5916 m .43762 .55843 L .46514 .56406 L p .707 .577 .707 r
F P
0 g
s
.49059 .62464 m .4927 .64092 L .47141 .63049 L p .707 .577 .707 r
F P
0 g
s
.47141 .63049 m .46929 .61421 L .49059 .62464 L p .707 .577 .707 r
F P
0 g
s
.32648 .63569 m .3286 .65197 L .31275 .66799 L p .707 .577 .707 r
F P
0 g
s
.34959 .60427 m .34579 .5711 L .37487 .56213 L p .707 .577 .707 r
F P
0 g
s
.34579 .5711 m .34959 .60427 L .32592 .61697 L p .707 .577 .707 r
F P
0 g
s
.43762 .55843 m .44142 .5916 L .41031 .59093 L p .707 .577 .707 r
F P
0 g
s
.41031 .59093 m .40651 .55777 L .43762 .55843 L p .707 .577 .707 r
F P
0 g
s
.3286 .65197 m .32648 .63569 L .35006 .62224 L p .707 .577 .707 r
F P
0 g
s
.37867 .5953 m .37487 .56213 L .40651 .55777 L p .707 .577 .707 r
F P
0 g
s
.37487 .56213 m .37867 .5953 L .34959 .60427 L p .707 .577 .707 r
F P
0 g
s
.40651 .55777 m .41031 .59093 L .37867 .5953 L p .707 .577 .707 r
F P
0 g
s
.46929 .61421 m .47141 .63049 L .44386 .62473 L p .707 .577 .707 r
F P
0 g
s
.44386 .62473 m .44175 .60845 L .46929 .61421 L p .707 .577 .707 r
F P
0 g
s
.35006 .62224 m .35217 .63852 L .3286 .65197 L p .707 .577 .707 r
F P
0 g
s
.35217 .63852 m .35006 .62224 L .37907 .61267 L p .707 .577 .707 r
F P
0 g
s
.44175 .60845 m .44386 .62473 L .41278 .6242 L p .707 .577 .707 r
F P
0 g
s
.41278 .6242 m .41066 .60792 L .44175 .60845 L p .707 .577 .707 r
F P
0 g
s
.38118 .62895 m .37907 .61267 L .41066 .60792 L p .707 .577 .707 r
F P
0 g
s
.37907 .61267 m .38118 .62895 L .35217 .63852 L p .707 .577 .707 r
F P
0 g
s
.41066 .60792 m .41278 .6242 L .38118 .62895 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00RGoo2@00Rgoo0022Ool70003FUH00`00
FUIJEP03FUH90022Ool007eoo`D000YJEP03001JEUYF00UJEP03001JEUYF00H007aoo`00Mgoo1P00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000N7oo001bOol50008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001eOol0071oo`800003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0079o
o`00KWoo0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00L7oo001/Ool20005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001_Ool006Yoo`8000MJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0006ioo`00
J7oo0`0025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUH006eoo`00Igoo00@005YFFUH000QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH0001/Ool006Io
o`05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1YOol006Aoo`8000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEV]oo`00Hgoo00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
Jgoo001ROol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0069oo`8000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00HGoo00<005YF00001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0J7oo001QOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1XOol0061oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0
061oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061o
o`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0061oo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001YOol0061oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065o
o`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Moo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP8000aJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00Igoo001ROol0
1000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01000FUIJEP001UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001W
Ool006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00Hgoo00@005YFFUH0
00IJEP8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH3001VOol006=oo`04001JEUYF0006FUH20008FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`00IWoo001SOol01000FUIJEP001UYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF3`001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIVOol006Aoo`03001JEUYF
00L000AJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0006Eoo`00H7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP<006Eoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001IOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001HOol0
0`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001GOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOol90014Ool0
05Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000AOol70004FUH00`00FUIJEP02FUH8000lOol005Ao
o`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1@00=goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0027oo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Ioo`80009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@002EYF00<005YFFUH015YF1@00
1EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUH0000`Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP03FUH6
00000eYF001JEP05FUH20008FUH00`00FUIJEP09FUH20003FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000_Ool005Aoo`04001JEUYF0003FUH01000FUIJEUYF0P0017oo00@005YFFUH000IJEPl000MJEP@0
0003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00@005YFFUH000=JEP04001J
EP000007Ool00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUH000030002FUH200000eYF001J
EP020003FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003FUH20009Ool30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH01@00FUIJEUYF00000UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo001DOol2000015YF001JEUYF0`001goo0`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool0
05Aoo`800004FUH005YF0003FUH30002Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020002FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ao
o`800003FUH0000000EJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo
00@005YF000000EJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol2
00000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPl000EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP05001J
EUYFFUH0000]Ool004Moo`T000Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001J
EUYF00=JEP03001JEUYF00@001Yoo`<000AJEP05001JEUYFFUH0000]Ool0045oo`H000AJEP03001J
EUYF009JEPH000=JEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001J
EUYF00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH3000QOol300000eYF001JEP02FUH00`00Oomo
o`0[Ool003eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP80009JEP04001JEUYF0007FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP06FUH50005FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEP8000io
oa0000Moo`04001JEP000003FUH2000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH01000FUH000002Goo1`0015YF00<0
05YFFUH01EYF00@005YFFUIJEPP000=JEP03001JEUYF008002aoo`00=goo0P0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<005YFFUH015YF100025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0P001goo10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF100015YF00@005YF000002aoo`00=Goo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00IJEP03001JEP0000L000MJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF100017oo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P000eYF1000;7oo
000cOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03
FUH00`00FUIJEP020006FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH90005FUH20003FUH0
0`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0
0`0015YF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0`00;7oo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
00000eYF001JEP03FUH40007FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
1UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00P005YFFUH0
05YF001JEP001EYF00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP800004FUH00000000/Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH4
00000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH01000FUH000000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YFFUIJEP80
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEP00001JEP00;7oo000_Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP<00003FUH005YF009JEP<000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00H005YFFUH005YF000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`0025YF00<005YFFUH00UYF3`001UYF00@0
05YFFUIJEP<0009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP020002FUH01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YF0000
009JEP03001JEUYF00EJEPL000=JEPL000AJEP@0009JEP03001JEUYF009JEP80009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF0P001EYF00<005YFFUH00UYF0P0000=JEP0000001`001EYF00<005YF
FUH01eYF0`0015YF00D005YF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEPH000MJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF009J
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEPD000MJEP03001JEUYF00YJEP8000=J
EP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH4
0005FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP8000MJEP@0009JEP04001JEUYFFUH50007FUH0
0`00FUIJEP09FUH500001EYF001JEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00=JEP03001JEP00008000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ400004FUH005YF0005FUH20002FUH2
0002FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP020002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH6000>Ool00`00FUIJEP020002FUH00`00FUIJEP0200000eYF001JEP02FUH0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP04
001JEUYFFUH20004FUH00`00FUIJEP06FUH@0002FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0Z
Ool002eoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000DOol200000eYF001JEP02
FUH30003FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYF001JEP001EYF00@005YF000000IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030003FUH20003Ool01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF00<0
05YFFUH00eYF10002Woo0`002goo0`0015YF00<007oo00000P0000=JEP00FUH00UYF00@005YFFUH0
00IJEP03001JEUYF00MJEPD00003FUH005YF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00005FUH200000eYF001JEP05FUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006Ool3000/Ool002eoo`04001JEUYF
0003FUH01000FUIJEUYF0P003Goo1@002Woo0`000eYF00<005YF00001@000eYF0P0000=JEP00FUH0
1EYF00@005YFFUIJEPL000EJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP<00003FUH005YF
00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Eoo`03001JEP00
02aoo`00;Goo00@005YFFUH000=JEP04001JEP00000?Ool:0006Ool200000eYF00000003FUH01000
FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF0000009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP07001JEUYF001JEP00FUH0
0`0000=JEP0000001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF00<005YFFUH00P000Woo
0P0000=JEP000000:goo000]Ool200000eYF001JEP02FUH2000@Ool40002FUH00`00FUIJEP02FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH2
0004FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00002FUH01000FUIJEUYF0`0025YF00<005YFFUH010000UYF3@0015YF00@005YFFUIJEP80
0003FUH005YF008002]oo`00;Goo0P0000AJEP00FUIJEP<000aoo`@000IJEP03001JEUYF00IJEP80
0004FUH005YF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUH00002FUH20003FUH01000FUIJEP000UYF00<005YFFUH01EYF2P003Goo1@00
15YF0`000UYF00<007ooOol0:Goo000]Ool2000015YF000000000eYF1@000goo100000=JEP00FUH0
1eYF00<005YFFUH01UYF0P0000AJEP00FUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEP0000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF0`0015YF00<005YFFUH00UYF
0P0017oo1@004goo0P000UYF00<005YF00000UYF00<007ooOol0:Goo000]Ool200000eYF00000005
FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00000000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000IJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00AJEP03001JEUYF00AJEP03001JEP00008000Ioo`D0019oo`D00006FUH005YF001JEP00:goo000^
Ool200000eYF001JEP04FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH20005FUH50007Ool5000AOol01000FUIJEP000UYF0P000UYF0P00:goo
000^Ool200000eYF001JEP04FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP03FUH30004
FUH01000FUIJEUYF0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUH000=JEP800003FUH005YF009JEP<000=JEP03001oogoo00Ioo`<0011oo`8000=J
EP03001JEUYF009JEP03001JEP0002aoo`00;Woo00@005YFFUH000=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP800003FUH005YF00IJEP03001JEUYF00=JEPD0
00MJEP04001JEUYFFUH20007FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00@005YFFUH0009JEP06001JEUYFFUH005YF0P000UYF00D005YF
FUIJEP0001Uoo`8000EJEP03001JEUYF00=JEP8002aoo`00;Woo00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30005FUH40006FUH00`00FUIJEP03FUH5
0007FUH01000FUH000002UYF0P0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00`0015YF0`000eYF00D005YFFUIJEP0001Ioo`<00003FUH005YF
00AJEP03001JEUYF00=JEP<002]oo`00;Woo00@005YFFUIJEP<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH50002FUH7000;FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`0AOol3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Ool0000[Ool002ioo`07001JEUYFFUH005YF
00001eYF00<005YFFUH01EYF00<005YFFUH00UYF400000=JEP00FUH00UYF00<005YFFUH00eYF00<0
05YF00003P001UYF00<005YFFUH025YF00@005YFFUH0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02FUH00`00FUH0
000300000eYF0000000<Ool60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000Woo00<007ooOol0
:Goo000^Ool01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH015YF1P002EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP05001JEP00Ool00002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH20004FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP03FUH?0004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000Woo0P00:goo000^Ool00`00FUH00003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP05
0004FUH01@00FUIJEP00Ool00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH015YF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000Aoo`03001JEP0002Yoo`00;goo0P0015YF00<005YFFUH015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF1@0000UJEP00FUIJEP00Ool0
05YF00001UYF00<005YFFUH01eYF00@005YFFUIJEP@000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo009o
o`04001JEUYF000ZOol002moo`8000AJEP03001JEUYF00=JEP<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEPD0009JEP05001oo`00FUH00006FUH00`00FUIJ
EP07FUH40003FUH00`00FUIJEP02FUH20005FUHE0008FUH00`00FUIJEP06FUH00`00FUH00002FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001Goo00@005YFFUH002Yoo`00;goo0P0015YF00@005YFFUIJEP8000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEP0000@00004Ool005YF000:
FUH60007FUH00`00FUIJEP09000<FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP06FUH01000FUH0
05YF10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000000Ioo`80009JEP03001oogoo02Qoo`00;Woo00<005YF000015YF00@005YF000000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP03001JEUYF00=JEPl000AJEP03
001JEUYF00IJEP@000MJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH40007FUH00`00
FUIJEP0300000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP05
FUH30007Ool01@00FUH005YF0000:goo000^Ool00`00FUH00004FUH50006FUH00`00FUIJEP06FUH@
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP030003
FUH300000eYF001JEP06FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP02FUH2000:Ool00`00FUIJ
EP02000[Ool002ioo`04001JEUYF0002FUH00`00Oomoo`03Ool40002FUH00`00FUIJEP060004FUH0
0`00FUIJEP06FUH00`00FUH000030002Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH01P00FUIJEP00FUH000AJEP03001JEP00008000IJEP03001JEUYF00=JEPD000MJEP03001JEP00
008000]oo`05001JEUYFFUH0000/Ool002ioo`06001JEUYF001JEP002Woo1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0000Aoo`00000000IJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP<0
0004FUH005YFFUH30004FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH50003FUH6000<Ool2
0004FUH00`00Oomoo`0ZOol002ioo`06001JEUYF001JEP002Woo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF0`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH0100025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH00P00
0UYF00<005YF000015YF00<005YFFUH00UYF00@005YFFUIJEQ00011oo`800003FUH005YF009JEP03
001oogoo02]oo`00;Woo00<005YFFUH00P002Goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00P000eYF4@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YFFUH00UYF00D005YFFUH005YF0080009JEP03001JEUYF
00=JEP04001JEUYF000MOol20003FUH01000FUH00000;Woo000_Ool00`00FUH00008Ool30008FUH0
0`00FUIJEP02FUH?0006FUH01000FUIJEUYF0P0000=JEP00FUH00P002EYF0P0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF10001EYF00<005YFFUH00P006Goo0`001EYF0P00<7oo000_Ool20007Ool20002
FUH00`00FUIJEP05FUH6000?Ool40002FUH00`00FUIJEP02FUH300000eYF00000007FUH20003FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH200000eYF001JEP0300000eYF00000003FUH00`00FUIJEP02000GOol200000eYF
001JEP05FUH00`00Oomoo`0_Ool002moo`<000Aoo`8000EJEP03001JEUYF009JEP8001Uoo`<000AJ
EP04001JEP00FUH20006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030002FUH20000
1EYF000005YF00000UYF0P0057oo0`000eYF00<005YFFUH00UYF0P00<Woo000_Ool01000FUIJEP00
0Woo00<005YFFUH01EYF00<005YF00000P006Goo0P000eYF0P000eYF00D005YF001oo`0000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00@000=JEPD000=JEP03001oogoo00ioo`@000MJ
EP04001JEUYF000dOol002moo`03001JEUYF00@000MJEP8001Yoo`8000IJEP<00006FUH005YFFUH0
07oo0eYF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0100015YF00@005YFFUIJEPT000Moo`@0009J
EP03001JEUYF00IJEP<003Eoo`00;goo0P0000EJEP00001JEP0000EJEP8001Qoo`@00003FUH005YF
00EJEP03001JEUYF0080009JEP05001ooeYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP060002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH2000g
Ool002moo`800003FUH00000009JEP03001JEUYF00<001Aoo`D000EJEP03001JEUYF00EJEP08001J
EUYFFUH005YF001oo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0017oo0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00>Goo000`Ool00`00
FUH00003FUH30003FUH90007Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
00001EYF000005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH01@000Woo0`00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00?7oo000`Ool20004FUH00`00FUH0
0007FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002Ool3
00000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000eYF0`000goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00?goo000`Ool20003FUH01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0017oo10000eYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00`000UYF00<005YF00003P00
AGoo000`Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0
0005FUH01000FUIJEUYF0P0000EJEP00FUIJEP00059oo`00;goo00<005YF00000P001EYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@000]JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00=JEPH0009JEP03001JEUYF009JEP<0009JEP03001oogoo051oo`00;goo00D005YF001o
o`0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000MJEP03001JEUYF00EJEP04001JEP000008
Ool00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004Ool30004FUH01P00FUH00000FUH0059oo`00
;goo00<005YF00000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF1@001eYF00<005YFFUH0
15YF0`002Woo00D005YF001oo`0000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00=JEP03001oogoo00=o
o`800003FUH0000000=JEP04001JEP00001COol002moo`03001JEP0000Aoo`800003FUH005YF00IJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF009JEP8000aoo`800004FUH007oo0004FUH00`00FUIJ
EP04FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP02FUH01000Oomoogoo0`001EYF0P0000EJEP00FUIJEP0005=oo`00<7oo00<0
07ooOol01Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003Goo00@005YF
0000009oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP06001JEUYFFUH007oo0`0000=JEP00FUH01EYF
00@005YF0000009JEP03001oogoo055oo`00<7oo00<007ooOol027oo10000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P003goo00<005YFFUH00P000goo00D005YFFUIJEP00015JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000Dgoo000`Ool00`00Oomoo`0<Ool@000DOol01@00FUIJEUYF0000
1Goo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP<000MJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`1AOol0
031oo`80031oo`03001JEUYF009JEP03001oogoo00Aoo`03001JEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP<000QJEP03001JEUYF
00EJEP03001JEP00009oo`80059oo`00<7oo00<005YF0000;Goo0`000eYF00<007ooOol01Woo0P00
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P000UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0017oo00<007ooOol0D7oo000aOol00`00
FUH0000[Ool01000FUIJEP000UYF00<007ooOol027oo00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001oogoo00=oo`03001oogoo051oo`00<Goo00@005YFFUH002Qoo`8000AJ
EP03001JEP0000]oo`8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`80059oo`00
<Goo00<005YFFUH00`008goo0`001UYF0P003Woo0P000eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF1`001UYF00<005YFFUH01UYF00<005YFFUH00P001goo00<0
05YF0000DGoo000bOol00`00FUH00002FUH2000MOol40002FUH00`00FUIJEP03FUH2000AOol20000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH40002FUH50006FUH0
0`00FUIJEP06FUH30008Ool01000FUIJEP00DGoo000bOol00`00FUH00004FUH3000EOol50006FUH0
1000FUIJEUYF0P005Goo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF000010001EYF
1@001eYF00<005YFFUH015YF0P002Woo00@005YFFUH0055oo`00<goo0P001EYF00<005YF00000`00
3Goo10000UYF00<005YFFUH01UYF00@005YF000001]oo`H0009JEP03001JEUYF00YJEP03001JEUYF
00AJEPP000AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00@000]oo`800003FUH007oo055oo`00
=7oo00<005YFFUH00eYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0`008goo5P000goo1@00
15YF00<005YFFUH01UYF00<005YFFUH00UYF1`003Woo00D005YF001JEP00059oo`00=Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00=Woo00<007oo
Ool02goo4P0057oo00D005YFFUIJEP0005=oo`00=goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000P00>7oo00<007ooOol0<7oo00<005YFFUH00UYF00<007ooOol0
DGoo000iOol50004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000kOol2000_Ool30003FUH00`00
Oomoo`1BOol003iooa80045oo`03001JEP0002aoo`80009JEP04001JEUYF001EOol0099oo`03001J
EP0002Uoo`8000AJEP03001JEP0005Ioo`00TWoo00<005YFFUH00P009Goo0P001UYF0P00Egoo002C
Ool01000FUH005YF0`0087oo0P0000=JEP00FUH01EYF00<007ooOol0EWoo002DOol20004FUH3000J
Ool30003FUH00`00FUIJEP02FUH2001IOol009Eoo`8000AJEP03001JEP0000<0011oo`H000MJEP04
001JEUYF001KOol009Ioo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP<0
05aoo`00Ugoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P00GWoo002IOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH3001POol009]oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006=o
o`00WWoo10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00IWoo002ROol?001/Ool00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59874 .75859 m .59656 .70477 L .56539 .70335 L p .707 .577 .707 r
F P
0 g
s
.59656 .70477 m .59874 .75859 L .63055 .75641 L p .707 .577 .707 r
F P
0 g
s
.63055 .75641 m .62836 .70258 L .59656 .70477 L p .707 .577 .707 r
F P
0 g
s
.62836 .70258 m .63055 .75641 L .65989 .75084 L p .707 .577 .707 r
F P
0 g
s
.65989 .75084 m .6577 .69701 L .62836 .70258 L p .707 .577 .707 r
F P
0 g
s
.56758 .75718 m .56539 .70335 L .53793 .69847 L p .707 .577 .707 r
F P
0 g
s
.56539 .70335 m .56758 .75718 L .59874 .75859 L p .707 .577 .707 r
F P
0 g
s
.6577 .69701 m .65989 .75084 L .68389 .74242 L p .707 .577 .707 r
F P
0 g
s
.68389 .74242 m .6817 .6886 L .6577 .69701 L p .707 .577 .707 r
F P
0 g
s
.54011 .7523 m .53793 .69847 L .51684 .69061 L p .707 .577 .707 r
F P
0 g
s
.53793 .69847 m .54011 .7523 L .56758 .75718 L p .707 .577 .707 r
F P
0 g
s
.60142 .82493 m .59906 .78998 L .56791 .78886 L p .707 .577 .707 r
F P
0 g
s
.59906 .78998 m .60142 .82493 L .63318 .82189 L p .707 .577 .707 r
F P
0 g
s
.63318 .82189 m .63082 .78694 L .59906 .78998 L p .707 .577 .707 r
F P
0 g
s
.63082 .78694 m .63318 .82189 L .66245 .81498 L p .707 .577 .707 r
F P
0 g
s
.66245 .81498 m .66008 .78003 L .63082 .78694 L p .707 .577 .707 r
F P
0 g
s
.6817 .6886 m .68389 .74242 L .70019 .73199 L p .707 .577 .707 r
F P
0 g
s
.70019 .73199 m .69801 .67817 L .6817 .6886 L p .707 .577 .707 r
F P
0 g
s
.57028 .82381 m .56791 .78886 L .54042 .78369 L p .707 .577 .707 r
F P
0 g
s
.56791 .78886 m .57028 .82381 L .60142 .82493 L p .707 .577 .707 r
F P
0 g
s
.66008 .78003 m .66245 .81498 L .68636 .80488 L p .707 .577 .707 r
F P
0 g
s
.68636 .80488 m .68399 .76993 L .66008 .78003 L p .707 .577 .707 r
F P
0 g
s
.51684 .69061 m .51903 .74444 L .54011 .7523 L p .707 .577 .707 r
F P
0 g
s
.51903 .74444 m .51684 .69061 L .50421 .68053 L p .707 .577 .707 r
F P
0 g
s
.54279 .81864 m .54042 .78369 L .51929 .77497 L p .707 .577 .707 r
F P
0 g
s
.54042 .78369 m .54279 .81864 L .57028 .82381 L p .707 .577 .707 r
F P
0 g
s
.60326 .87011 m .60194 .85279 L .5708 .85176 L p .707 .577 .707 r
F P
0 g
s
.60194 .85279 m .60326 .87011 L .635 .86682 L p .707 .577 .707 r
F P
0 g
s
.635 .86682 m .63368 .84949 L .60194 .85279 L p .707 .577 .707 r
F P
0 g
s
.63368 .84949 m .635 .86682 L .66424 .85952 L p .707 .577 .707 r
F P
0 g
s
.66424 .85952 m .66292 .84219 L .63368 .84949 L p .707 .577 .707 r
F P
0 g
s
.69801 .67817 m .70019 .73199 L .70722 .72057 L p .707 .577 .707 r
F P
0 g
s
.70722 .72057 m .70503 .66674 L .69801 .67817 L p .707 .577 .707 r
F P
0 g
s
.68399 .76993 m .68636 .80488 L .70256 .79258 L p .707 .577 .707 r
F P
0 g
s
.70256 .79258 m .7002 .75763 L .68399 .76993 L p .707 .577 .707 r
F P
0 g
s
.57212 .86908 m .5708 .85176 L .54331 .8465 L p .707 .577 .707 r
F P
0 g
s
.5708 .85176 m .57212 .86908 L .60326 .87011 L p .707 .577 .707 r
F P
0 g
s
.50421 .68053 m .50639 .73436 L .51903 .74444 L p .707 .577 .707 r
F P
0 g
s
.66292 .84219 m .66424 .85952 L .68811 .84892 L p .707 .577 .707 r
F P
0 g
s
.68811 .84892 m .68679 .8316 L .66292 .84219 L p .707 .577 .707 r
F P
0 g
s
.51929 .77497 m .52166 .80992 L .54279 .81864 L p .707 .577 .707 r
F P
0 g
s
.54331 .8465 m .54463 .86382 L .57212 .86908 L p .707 .577 .707 r
F P
0 g
s
.50639 .73436 m .50421 .68053 L .50125 .66923 L p .707 .577 .707 r
F P
0 g
s
.52166 .80992 m .51929 .77497 L .50659 .76355 L p .707 .577 .707 r
F P
0 g
s
.54463 .86382 m .54331 .8465 L .52216 .83752 L p .707 .577 .707 r
F P
0 g
s
.50117 .82687 m .48132 .34094 L .43733 .33895 L p .707 .577 .707 r
F P
0 g
s
.50659 .76355 m .50895 .79851 L .52166 .80992 L p .707 .577 .707 r
F P
0 g
s
.50125 .66923 m .50344 .72306 L .50639 .73436 L p .707 .577 .707 r
F P
0 g
s
.52348 .85485 m .52216 .83752 L .50942 .82572 L p .707 .577 .707 r
F P
0 g
s
.50895 .79851 m .50659 .76355 L .50354 .75056 L p .707 .577 .707 r
F P
0 g
s
.50344 .72306 m .50125 .66923 L .50828 .6578 L p .707 .577 .707 r
F P
0 g
s
.50942 .82572 m .51074 .84304 L .52348 .85485 L p .707 .577 .707 r
F P
0 g
s
.50354 .75056 m .50591 .78551 L .50895 .79851 L p .707 .577 .707 r
F P
0 g
s
.50828 .6578 m .51046 .71163 L .50344 .72306 L p .707 .577 .707 r
F P
0 g
s
.51074 .84304 m .50942 .82572 L .50634 .81223 L p .707 .577 .707 r
F P
0 g
s
.50591 .78551 m .50354 .75056 L .51046 .73726 L p .707 .577 .707 r
F P
0 g
s
.51046 .71163 m .50828 .6578 L .52458 .64737 L p .707 .577 .707 r
F P
0 g
s
.50634 .81223 m .50766 .82956 L .51074 .84304 L p .707 .577 .707 r
F P
0 g
s
.51046 .73726 m .51283 .77222 L .50591 .78551 L p .707 .577 .707 r
F P
0 g
s
.52458 .64737 m .52677 .7012 L .51046 .71163 L p .707 .577 .707 r
F P
0 g
s
.50766 .82956 m .50634 .81223 L .51323 .79839 L p .707 .577 .707 r
F P
0 g
s
.52677 .7012 m .52458 .64737 L .54858 .63896 L p .707 .577 .707 r
F P
0 g
s
.51283 .77222 m .51046 .73726 L .52667 .72497 L p .707 .577 .707 r
F P
0 g
s
.51323 .79839 m .51454 .81571 L .50766 .82956 L p .707 .577 .707 r
F P
0 g
s
.52667 .72497 m .52904 .75992 L .51283 .77222 L p .707 .577 .707 r
F P
0 g
s
.54858 .63896 m .55077 .69279 L .52677 .7012 L p .707 .577 .707 r
F P
0 g
s
.51454 .81571 m .51323 .79839 L .52939 .78554 L p .707 .577 .707 r
F P
0 g
s
.52904 .75992 m .52667 .72497 L .55058 .71487 L p .707 .577 .707 r
F P
0 g
s
.52939 .78554 m .53071 .80287 L .51454 .81571 L p .707 .577 .707 r
F P
0 g
s
.55058 .71487 m .55295 .74982 L .52904 .75992 L p .707 .577 .707 r
F P
0 g
s
.53071 .80287 m .52939 .78554 L .55326 .77495 L p .707 .577 .707 r
F P
0 g
s
.55326 .77495 m .55458 .79227 L .53071 .80287 L p .707 .577 .707 r
F P
0 g
s
.48132 .34094 m .50117 .82687 L .54608 .82377 L p .707 .577 .707 r
F P
0 g
s
.54608 .82377 m .52623 .33785 L .48132 .34094 L p .707 .577 .707 r
F P
0 g
s
.55077 .69279 m .54858 .63896 L .57792 .63339 L p .707 .577 .707 r
F P
0 g
s
.57792 .63339 m .58011 .68722 L .55077 .69279 L p .707 .577 .707 r
F P
0 g
s
.55295 .74982 m .55058 .71487 L .57984 .70796 L p .707 .577 .707 r
F P
0 g
s
.57984 .70796 m .58221 .74291 L .55295 .74982 L p .707 .577 .707 r
F P
0 g
s
.55458 .79227 m .55326 .77495 L .5825 .76765 L p .707 .577 .707 r
F P
0 g
s
.5825 .76765 m .58382 .78497 L .55458 .79227 L p .707 .577 .707 r
F P
0 g
s
.52623 .33785 m .54608 .82377 L .5875 .81589 L p .707 .577 .707 r
F P
0 g
s
.58011 .68722 m .57792 .63339 L .60973 .63121 L p .707 .577 .707 r
F P
0 g
s
.60973 .63121 m .61191 .68503 L .58011 .68722 L p .707 .577 .707 r
F P
0 g
s
.58221 .74291 m .57984 .70796 L .61161 .70491 L p .707 .577 .707 r
F P
0 g
s
.61161 .70491 m .61397 .73987 L .58221 .74291 L p .707 .577 .707 r
F P
0 g
s
.58382 .78497 m .5825 .76765 L .61425 .76435 L p .707 .577 .707 r
F P
0 g
s
.61425 .76435 m .61556 .78167 L .58382 .78497 L p .707 .577 .707 r
F P
0 g
s
.5875 .81589 m .56765 .32997 L .52623 .33785 L p .707 .577 .707 r
F P
0 g
s
.52216 .83752 m .52348 .85485 L .54463 .86382 L p .707 .577 .707 r
F P
0 g
s
.68679 .8316 m .68811 .84892 L .70428 .83608 L p .707 .577 .707 r
F P
0 g
s
.70428 .83608 m .70296 .81875 L .68679 .8316 L p .707 .577 .707 r
F P
0 g
s
.7002 .75763 m .70256 .79258 L .70948 .77929 L p .707 .577 .707 r
F P
0 g
s
.70948 .77929 m .70712 .74433 L .7002 .75763 L p .707 .577 .707 r
F P
0 g
s
.70503 .66674 m .70722 .72057 L .70426 .70926 L p .707 .577 .707 r
F P
0 g
s
.70426 .70926 m .70208 .65544 L .70503 .66674 L p .707 .577 .707 r
F P
0 g
s
.45718 .82487 m .43733 .33895 L .39855 .33206 L p .707 .577 .707 r
F P
0 g
s
.43733 .33895 m .45718 .82487 L .50117 .82687 L p .707 .577 .707 r
F P
0 g
s
.64275 .70603 m .64512 .74099 L .61397 .73987 L p .707 .577 .707 r
F P
0 g
s
.61397 .73987 m .61161 .70491 L .64275 .70603 L p .707 .577 .707 r
F P
0 g
s
.64539 .76538 m .6467 .78271 L .61556 .78167 L p .707 .577 .707 r
F P
0 g
s
.61556 .78167 m .61425 .76435 L .64539 .76538 L p .707 .577 .707 r
F P
0 g
s
.56765 .32997 m .5875 .81589 L .62138 .80399 L p .707 .577 .707 r
F P
0 g
s
.64089 .63262 m .64308 .68645 L .61191 .68503 L p .707 .577 .707 r
F P
0 g
s
.61191 .68503 m .60973 .63121 L .64089 .63262 L p .707 .577 .707 r
F P
0 g
s
.62138 .80399 m .60152 .31807 L .56765 .32997 L p .707 .577 .707 r
F P
0 g
s
.70296 .81875 m .70428 .83608 L .71116 .82223 L p .707 .577 .707 r
F P
0 g
s
.71116 .82223 m .70984 .80491 L .70296 .81875 L p .707 .577 .707 r
F P
0 g
s
.4184 .81798 m .39855 .33206 L .36879 .32095 L p .707 .577 .707 r
F P
0 g
s
.39855 .33206 m .4184 .81798 L .45718 .82487 L p .707 .577 .707 r
F P
0 g
s
.70712 .74433 m .70948 .77929 L .70644 .7663 L p .707 .577 .707 r
F P
0 g
s
.70644 .7663 m .70407 .73134 L .70712 .74433 L p .707 .577 .707 r
F P
0 g
s
.70208 .65544 m .70426 .70926 L .69163 .69919 L p .707 .577 .707 r
F P
0 g
s
.69163 .69919 m .68944 .64536 L .70208 .65544 L p .707 .577 .707 r
F P
0 g
s
.60152 .31807 m .62138 .80399 L .6444 .78925 L p .707 .577 .707 r
F P
0 g
s
.6444 .78925 m .62455 .30332 L .60152 .31807 L p .707 .577 .707 r
F P
0 g
s
.25573 .72178 m .25355 .66795 L .22239 .66653 L p .707 .577 .707 r
F P
0 g
s
.25355 .66795 m .25573 .72178 L .28754 .71959 L p .707 .577 .707 r
F P
0 g
s
.28754 .71959 m .28536 .66577 L .25355 .66795 L p .707 .577 .707 r
F P
0 g
s
.28536 .66577 m .28754 .71959 L .31688 .71402 L p .707 .577 .707 r
F P
0 g
s
.31688 .71402 m .31469 .66019 L .28536 .66577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70984 .80491 m .71116 .82223 L .70808 .80875 L p .707 .577 .707 r
F P
0 g
s
.70808 .80875 m .70676 .79142 L .70984 .80491 L p .707 .577 .707 r
F P
0 g
s
.22457 .72036 m .22239 .66653 L .19492 .66166 L p .707 .577 .707 r
F P
0 g
s
.22239 .66653 m .22457 .72036 L .25573 .72178 L p .707 .577 .707 r
F P
0 g
s
.38864 .80687 m .36879 .32095 L .35095 .30671 L p .707 .577 .707 r
F P
0 g
s
.36879 .32095 m .38864 .80687 L .4184 .81798 L p .707 .577 .707 r
F P
0 g
s
.70407 .73134 m .70644 .7663 L .69373 .75488 L p .707 .577 .707 r
F P
0 g
s
.69373 .75488 m .69137 .71993 L .70407 .73134 L p .707 .577 .707 r
F P
0 g
s
.68944 .64536 m .69163 .69919 L .67054 .69132 L p .707 .577 .707 r
F P
0 g
s
.67054 .69132 m .66836 .6375 L .68944 .64536 L p .707 .577 .707 r
F P
0 g
s
.31469 .66019 m .31688 .71402 L .34088 .70561 L p .707 .577 .707 r
F P
0 g
s
.34088 .70561 m .33869 .65178 L .31469 .66019 L p .707 .577 .707 r
F P
0 g
s
.1971 .71548 m .19492 .66166 L .17383 .6538 L p .707 .577 .707 r
F P
0 g
s
.19492 .66166 m .1971 .71548 L .22457 .72036 L p .707 .577 .707 r
F P
0 g
s
.66836 .6375 m .67054 .69132 L .64308 .68645 L p .707 .577 .707 r
F P
0 g
s
.64308 .68645 m .64089 .63262 L .66836 .6375 L p .707 .577 .707 r
F P
0 g
s
.67024 .71121 m .6726 .74616 L .64512 .74099 L p .707 .577 .707 r
F P
0 g
s
.64512 .74099 m .64275 .70603 L .67024 .71121 L p .707 .577 .707 r
F P
0 g
s
.67288 .77064 m .67419 .78797 L .6467 .78271 L p .707 .577 .707 r
F P
0 g
s
.6467 .78271 m .64539 .76538 L .67288 .77064 L p .707 .577 .707 r
F P
0 g
s
.62455 .30332 m .6444 .78925 L .65431 .77309 L p .707 .577 .707 r
F P
0 g
s
.65431 .77309 m .63446 .28717 L .62455 .30332 L p .707 .577 .707 r
F P
0 g
s
.25841 .78812 m .25605 .75316 L .2249 .75204 L p .707 .577 .707 r
F P
0 g
s
.25605 .75316 m .25841 .78812 L .29017 .78507 L p .707 .577 .707 r
F P
0 g
s
.29017 .78507 m .28781 .75012 L .25605 .75316 L p .707 .577 .707 r
F P
0 g
s
.28781 .75012 m .29017 .78507 L .31944 .77817 L p .707 .577 .707 r
F P
0 g
s
.31944 .77817 m .31707 .74321 L .28781 .75012 L p .707 .577 .707 r
F P
0 g
s
.33869 .65178 m .34088 .70561 L .35719 .69518 L p .707 .577 .707 r
F P
0 g
s
.35719 .69518 m .355 .64135 L .33869 .65178 L p .707 .577 .707 r
F P
0 g
s
.70676 .79142 m .70808 .80875 L .69534 .79694 L p .707 .577 .707 r
F P
0 g
s
.69534 .79694 m .69402 .77962 L .70676 .79142 L p .707 .577 .707 r
F P
0 g
s
.22727 .787 m .2249 .75204 L .19742 .74687 L p .707 .577 .707 r
F P
0 g
s
.2249 .75204 m .22727 .787 L .25841 .78812 L p .707 .577 .707 r
F P
0 g
s
.69137 .71993 m .69373 .75488 L .6726 .74616 L p .707 .577 .707 r
F P
0 g
s
.6726 .74616 m .67024 .71121 L .69137 .71993 L p .707 .577 .707 r
F P
0 g
s
.31707 .74321 m .31944 .77817 L .34335 .76807 L p .707 .577 .707 r
F P
0 g
s
.34335 .76807 m .34098 .73311 L .31707 .74321 L p .707 .577 .707 r
F P
0 g
s
.17383 .6538 m .17602 .70762 L .1971 .71548 L p .707 .577 .707 r
F P
0 g
s
.17602 .70762 m .17383 .6538 L .1612 .64372 L p .707 .577 .707 r
F P
0 g
s
.3708 .79263 m .35095 .30671 L .34678 .29073 L p .707 .577 .707 r
F P
0 g
s
.35095 .30671 m .3708 .79263 L .38864 .80687 L p .707 .577 .707 r
F P
0 g
s
.19978 .78183 m .19742 .74687 L .17629 .73815 L p .707 .577 .707 r
F P
0 g
s
.19742 .74687 m .19978 .78183 L .22727 .787 L p .707 .577 .707 r
F P
0 g
s
.26025 .8333 m .25893 .81598 L .22779 .81494 L p .707 .577 .707 r
F P
0 g
s
.25893 .81598 m .26025 .8333 L .29199 .83 L p .707 .577 .707 r
F P
0 g
s
.29199 .83 m .29067 .81268 L .25893 .81598 L p .707 .577 .707 r
F P
0 g
s
.29067 .81268 m .29199 .83 L .32123 .8227 L p .707 .577 .707 r
F P
0 g
s
.32123 .8227 m .31991 .80538 L .29067 .81268 L p .707 .577 .707 r
F P
0 g
s
.355 .64135 m .35719 .69518 L .36421 .68375 L p .707 .577 .707 r
F P
0 g
s
.36421 .68375 m .36202 .62993 L .355 .64135 L p .707 .577 .707 r
F P
0 g
s
.34098 .73311 m .34335 .76807 L .35955 .75577 L p .707 .577 .707 r
F P
0 g
s
.35955 .75577 m .35719 .72081 L .34098 .73311 L p .707 .577 .707 r
F P
0 g
s
.69402 .77962 m .69534 .79694 L .67419 .78797 L p .707 .577 .707 r
F P
0 g
s
.67419 .78797 m .67288 .77064 L .69402 .77962 L p .707 .577 .707 r
F P
0 g
s
.22911 .83227 m .22779 .81494 L .2003 .80968 L p .707 .577 .707 r
F P
0 g
s
.22779 .81494 m .22911 .83227 L .26025 .8333 L p .707 .577 .707 r
F P
0 g
s
.1612 .64372 m .16338 .69755 L .17602 .70762 L p .707 .577 .707 r
F P
0 g
s
.31991 .80538 m .32123 .8227 L .3451 .81211 L p .707 .577 .707 r
F P
0 g
s
.3451 .81211 m .34378 .79478 L .31991 .80538 L p .707 .577 .707 r
F P
0 g
s
.17629 .73815 m .17865 .77311 L .19978 .78183 L p .707 .577 .707 r
F P
0 g
s
.2003 .80968 m .20162 .82701 L .22911 .83227 L p .707 .577 .707 r
F P
0 g
s
.63446 .28717 m .65431 .77309 L .65014 .75711 L p .707 .577 .707 r
F P
0 g
s
.65014 .75711 m .63854 .47306 L p .63446 .28717 L .707 .577 .707 r
F P
0 g
s
.63029 .27118 m .65014 .75711 L .6323 .74287 L p .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .6565 .67618 L .64389 .66486 L p .707 .577 .707 r
F P
0 g
s
.64389 .66486 m .64379 .66477 L p .6439 .6651 L .707 .577 .707 r
F P
0 g
s
.65887 .71114 m .64389 .66486 L .6439 .6651 L .707 .577 .707 r
F
.63854 .47306 m .63029 .27118 L .63321 .2824 L p F P
0 g
s
.63321 .2824 m .63446 .28717 L p .63854 .47306 L .707 .577 .707 r
F P
0 g
s
.16338 .69755 m .1612 .64372 L .15825 .63241 L p .707 .577 .707 r
F P
0 g
s
.17865 .77311 m .17629 .73815 L .16358 .72674 L p .707 .577 .707 r
F P
0 g
s
.20162 .82701 m .2003 .80968 L .17915 .80071 L p .707 .577 .707 r
F P
0 g
s
.17915 .80071 m .18047 .81803 L .20162 .82701 L p .707 .577 .707 r
F P
0 g
s
.34378 .79478 m .3451 .81211 L .36127 .79926 L p .707 .577 .707 r
F P
0 g
s
.36127 .79926 m .35995 .78194 L .34378 .79478 L p .707 .577 .707 r
F P
0 g
s
.35719 .72081 m .35955 .75577 L .36648 .74247 L p .707 .577 .707 r
F P
0 g
s
.36648 .74247 m .36411 .70752 L .35719 .72081 L p .707 .577 .707 r
F P
0 g
s
.36202 .62993 m .36421 .68375 L .36126 .67245 L p .707 .577 .707 r
F P
0 g
s
.36126 .67245 m .35907 .61862 L .36202 .62993 L p .707 .577 .707 r
F P
0 g
s
.16358 .72674 m .16594 .76169 L .17865 .77311 L p .707 .577 .707 r
F P
0 g
s
.36815 .78542 m .36683 .76809 L .35995 .78194 L p .707 .577 .707 r
F P
0 g
s
.36411 .70752 m .36648 .74247 L .36343 .72948 L p .707 .577 .707 r
F P
0 g
s
.36343 .72948 m .36107 .69453 L .36411 .70752 L p .707 .577 .707 r
F P
0 g
s
.36683 .76809 m .36815 .78542 L .36507 .77193 L p .707 .577 .707 r
F P
0 g
s
.36507 .77193 m .36375 .75461 L .36683 .76809 L p .707 .577 .707 r
F P
0 g
s
.34678 .29073 m .36663 .77665 L .3708 .79263 L p .707 .577 .707 r
F P
0 g
s
.36663 .77665 m .34678 .29073 L .35669 .27457 L p .707 .577 .707 r
F P
0 g
s
.15825 .63241 m .16043 .68624 L .16338 .69755 L p .707 .577 .707 r
F P
0 g
s
.18047 .81803 m .17915 .80071 L .16641 .7889 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16594 .76169 m .16358 .72674 L .16053 .71375 L p .707 .577 .707 r
F P
0 g
s
.16043 .68624 m .15825 .63241 L .16527 .62099 L p .707 .577 .707 r
F P
0 g
s
.16641 .7889 m .16773 .80623 L .18047 .81803 L p .707 .577 .707 r
F P
0 g
s
.35995 .78194 m .36127 .79926 L .36815 .78542 L p .707 .577 .707 r
F P
0 g
s
.6323 .74287 m .61245 .25694 L .63029 .27118 L p .707 .577 .707 r
F P
0 g
s
.35907 .61862 m .36126 .67245 L .34862 .66237 L p .707 .577 .707 r
F P
0 g
s
.34862 .66237 m .34643 .60854 L .35907 .61862 L p .707 .577 .707 r
F P
0 g
s
.16053 .71375 m .1629 .7487 L .16594 .76169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16527 .62099 m .16745 .67481 L .16043 .68624 L p .707 .577 .707 r
F P
0 g
s
.16773 .80623 m .16641 .7889 L .16334 .77542 L p .707 .577 .707 r
F P
0 g
s
.1629 .7487 m .16053 .71375 L .16745 .70045 L p .707 .577 .707 r
F P
0 g
s
.16745 .67481 m .16527 .62099 L .18158 .61056 L p .707 .577 .707 r
F P
0 g
s
.37654 .7605 m .35669 .27457 L .37971 .25982 L p .707 .577 .707 r
F P
0 g
s
.35669 .27457 m .37654 .7605 L .36663 .77665 L p .707 .577 .707 r
F P
0 g
s
.16334 .77542 m .16465 .79274 L .16773 .80623 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36107 .69453 m .36343 .72948 L .35072 .71807 L p .707 .577 .707 r
F P
0 g
s
.35072 .71807 m .34836 .68311 L .36107 .69453 L p .707 .577 .707 r
F P
0 g
s
.34643 .60854 m .34862 .66237 L .32754 .65451 L p .707 .577 .707 r
F P
0 g
s
.32754 .65451 m .32535 .60068 L .34643 .60854 L p .707 .577 .707 r
F P
0 g
s
.16745 .70045 m .16982 .7354 L .1629 .7487 L p .707 .577 .707 r
F P
0 g
s
.61245 .25694 m .6323 .74287 L .60254 .73176 L p .707 .577 .707 r
F P
0 g
s
.60254 .73176 m .58268 .24583 L .61245 .25694 L p .707 .577 .707 r
F P
0 g
s
.18158 .61056 m .18376 .66438 L .16745 .67481 L p .707 .577 .707 r
F P
0 g
s
.16465 .79274 m .16334 .77542 L .17022 .76157 L p .707 .577 .707 r
F P
0 g
s
.18376 .66438 m .18158 .61056 L .20557 .60215 L p .707 .577 .707 r
F P
0 g
s
.16982 .7354 m .16745 .70045 L .18366 .68815 L p .707 .577 .707 r
F P
0 g
s
.17022 .76157 m .17154 .7789 L .16465 .79274 L p .707 .577 .707 r
F P
0 g
s
.36375 .75461 m .36507 .77193 L .35233 .76013 L p .707 .577 .707 r
F P
0 g
s
.35233 .76013 m .35102 .7428 L .36375 .75461 L p .707 .577 .707 r
F P
0 g
s
.32535 .60068 m .32754 .65451 L .30007 .64963 L p .707 .577 .707 r
F P
0 g
s
.30007 .64963 m .29788 .59581 L .32535 .60068 L p .707 .577 .707 r
F P
0 g
s
.37971 .25982 m .39956 .74575 L .37654 .7605 L p .707 .577 .707 r
F P
0 g
s
.39956 .74575 m .37971 .25982 L .41359 .24793 L p .707 .577 .707 r
F P
0 g
s
.34836 .68311 m .35072 .71807 L .32959 .70935 L p .707 .577 .707 r
F P
0 g
s
.32959 .70935 m .32723 .67439 L .34836 .68311 L p .707 .577 .707 r
F P
0 g
s
.18366 .68815 m .18603 .7231 L .16982 .7354 L p .707 .577 .707 r
F P
0 g
s
.20776 .65597 m .20557 .60215 L .23491 .59658 L p .707 .577 .707 r
F P
0 g
s
.20557 .60215 m .20776 .65597 L .18376 .66438 L p .707 .577 .707 r
F P
0 g
s
.29788 .59581 m .30007 .64963 L .2689 .64822 L p .707 .577 .707 r
F P
0 g
s
.2689 .64822 m .26672 .59439 L .29788 .59581 L p .707 .577 .707 r
F P
0 g
s
.17154 .7789 m .17022 .76157 L .18638 .74873 L p .707 .577 .707 r
F P
0 g
s
.58268 .24583 m .60254 .73176 L .56376 .72487 L p .707 .577 .707 r
F P
0 g
s
.56376 .72487 m .54391 .23894 L .58268 .24583 L p .707 .577 .707 r
F P
0 g
s
.18603 .7231 m .18366 .68815 L .20757 .67805 L p .707 .577 .707 r
F P
0 g
s
.2371 .6504 m .23491 .59658 L .26672 .59439 L p .707 .577 .707 r
F P
0 g
s
.23491 .59658 m .2371 .6504 L .20776 .65597 L p .707 .577 .707 r
F P
0 g
s
.26672 .59439 m .2689 .64822 L .2371 .6504 L p .707 .577 .707 r
F P
0 g
s
.18638 .74873 m .1877 .76605 L .17154 .7789 L p .707 .577 .707 r
F P
0 g
s
.32723 .67439 m .32959 .70935 L .30211 .70417 L p .707 .577 .707 r
F P
0 g
s
.30211 .70417 m .29974 .66922 L .32723 .67439 L p .707 .577 .707 r
F P
0 g
s
.35102 .7428 m .35233 .76013 L .33119 .75115 L p .707 .577 .707 r
F P
0 g
s
.33119 .75115 m .32987 .73383 L .35102 .7428 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .41359 .24793 L .45501 .24004 L p .707 .577 .707 r
F P
0 g
s
.43344 .73385 m .39956 .74575 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.42184 .4498 m .43344 .73385 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.45501 .24004 m .47486 .72597 L .43344 .73385 L p .707 .577 .707 r
F P
0 g
s
.45664 .67938 m .45445 .64693 L p .42501 .65134 L .707 .577 .707 r
F P
0 g
s
.45445 .64693 m .45428 .64443 L .45404 .64448 L p .707 .577 .707 r
F P
0 g
s
.45404 .64448 m .42501 .65134 L p .45445 .64693 L .707 .577 .707 r
F P
0 g
s
.41359 .24793 m .42184 .4498 L p .40993 .37782 L .707 .577 .707 r
F P
0 g
s
.73595 .66366 m .73376 .60984 L .7026 .60842 L p .707 .577 .707 r
F P
0 g
s
.73376 .60984 m .73595 .66366 L .76775 .66148 L p .707 .577 .707 r
F P
0 g
s
.76775 .66148 m .76557 .60765 L .73376 .60984 L p .707 .577 .707 r
F P
0 g
s
.76557 .60765 m .76775 .66148 L .79709 .65591 L p .707 .577 .707 r
F P
0 g
s
.79709 .65591 m .79491 .60208 L .76557 .60765 L p .707 .577 .707 r
F P
0 g
s
.20757 .67805 m .20994 .71301 L .18603 .7231 L p .707 .577 .707 r
F P
0 g
s
.20994 .71301 m .20757 .67805 L .23683 .67114 L p .707 .577 .707 r
F P
0 g
s
.70478 .66225 m .7026 .60842 L .67513 .60355 L p .707 .577 .707 r
F P
0 g
s
.7026 .60842 m .70478 .66225 L .73595 .66366 L p .707 .577 .707 r
F P
0 g
s
.54391 .23894 m .56376 .72487 L .51976 .72287 L p .707 .577 .707 r
F P
0 g
s
.51976 .72287 m .49991 .23695 L .54391 .23894 L p .707 .577 .707 r
F P
0 g
s
.1877 .76605 m .18638 .74873 L .21026 .73813 L p .707 .577 .707 r
F P
0 g
s
.29974 .66922 m .30211 .70417 L .27096 .70305 L p .707 .577 .707 r
F P
0 g
s
.27096 .70305 m .2686 .6681 L .29974 .66922 L p .707 .577 .707 r
F P
0 g
s
.79491 .60208 m .79709 .65591 L .82109 .6475 L p .707 .577 .707 r
F P
0 g
s
.82109 .6475 m .8189 .59367 L .79491 .60208 L p .707 .577 .707 r
F P
0 g
s
.47486 .72597 m .45501 .24004 L .49991 .23695 L p .707 .577 .707 r
F P
0 g
s
.2392 .7061 m .23683 .67114 L .2686 .6681 L p .707 .577 .707 r
F P
0 g
s
.23683 .67114 m .2392 .7061 L .20994 .71301 L p .707 .577 .707 r
F P
0 g
s
.2686 .6681 m .27096 .70305 L .2392 .7061 L p .707 .577 .707 r
F P
0 g
s
.49991 .23695 m .51976 .72287 L .47486 .72597 L p .707 .577 .707 r
F P
0 g
s
.21026 .73813 m .21157 .75546 L .1877 .76605 L p .707 .577 .707 r
F P
0 g
s
.32987 .73383 m .33119 .75115 L .3037 .74589 L p .707 .577 .707 r
F P
0 g
s
.3037 .74589 m .30238 .72857 L .32987 .73383 L p .707 .577 .707 r
F P
0 g
s
.67732 .65737 m .67513 .60355 L .65405 .59568 L p .707 .577 .707 r
F P
0 g
s
.67513 .60355 m .67732 .65737 L .70478 .66225 L p .707 .577 .707 r
F P
0 g
s
.21157 .75546 m .21026 .73813 L .23949 .73083 L p .707 .577 .707 r
F P
0 g
s
.73863 .72615 m .73626 .6912 L .70511 .69008 L p .707 .577 .707 r
F P
0 g
s
.73626 .6912 m .73863 .72615 L .77039 .72311 L p .707 .577 .707 r
F P
0 g
s
.77039 .72311 m .76802 .68815 L .73626 .6912 L p .707 .577 .707 r
F P
0 g
s
.76802 .68815 m .77039 .72311 L .79965 .7162 L p .707 .577 .707 r
F P
0 g
s
.79965 .7162 m .79729 .68124 L .76802 .68815 L p .707 .577 .707 r
F P
0 g
s
.8189 .59367 m .82109 .6475 L .8374 .63707 L p .707 .577 .707 r
F P
0 g
s
.8374 .63707 m .83521 .58324 L .8189 .59367 L p .707 .577 .707 r
F P
0 g
s
.30238 .72857 m .3037 .74589 L .27255 .74486 L p .707 .577 .707 r
F P
0 g
s
.27255 .74486 m .27124 .72754 L .30238 .72857 L p .707 .577 .707 r
F P
0 g
s
.70748 .72503 m .70511 .69008 L .67763 .6849 L p .707 .577 .707 r
F P
0 g
s
.70511 .69008 m .70748 .72503 L .73863 .72615 L p .707 .577 .707 r
F P
0 g
s
.23949 .73083 m .24081 .74816 L .21157 .75546 L p .707 .577 .707 r
F P
0 g
s
.24081 .74816 m .23949 .73083 L .27124 .72754 L p .707 .577 .707 r
F P
0 g
s
.27124 .72754 m .27255 .74486 L .24081 .74816 L p .707 .577 .707 r
F P
0 g
s
.79729 .68124 m .79965 .7162 L .82356 .7061 L p .707 .577 .707 r
F P
0 g
s
.82356 .7061 m .82119 .67115 L .79729 .68124 L p .707 .577 .707 r
F P
0 g
s
.65405 .59568 m .65623 .64951 L .67732 .65737 L p .707 .577 .707 r
F P
0 g
s
.65623 .64951 m .65405 .59568 L .64141 .58561 L p .707 .577 .707 r
F P
0 g
s
.68 .71986 m .67763 .6849 L .6565 .67618 L p .707 .577 .707 r
F P
0 g
s
.67763 .6849 m .68 .71986 L .70748 .72503 L p .707 .577 .707 r
F P
0 g
s
.74046 .76591 m .73914 .74859 L .708 .74755 L p .707 .577 .707 r
F P
0 g
s
.73914 .74859 m .74046 .76591 L .7722 .76261 L p .707 .577 .707 r
F P
0 g
s
.7722 .76261 m .77089 .74529 L .73914 .74859 L p .707 .577 .707 r
F P
0 g
s
.77089 .74529 m .7722 .76261 L .80144 .75531 L p .707 .577 .707 r
F P
0 g
s
.80144 .75531 m .80012 .73799 L .77089 .74529 L p .707 .577 .707 r
F P
0 g
s
.83521 .58324 m .8374 .63707 L .84442 .62564 L p .707 .577 .707 r
F P
0 g
s
.84442 .62564 m .84223 .57181 L .83521 .58324 L p .707 .577 .707 r
F P
0 g
s
.70932 .76488 m .708 .74755 L .68051 .74229 L p .707 .577 .707 r
F P
0 g
s
.708 .74755 m .70932 .76488 L .74046 .76591 L p .707 .577 .707 r
F P
0 g
s
.82119 .67115 m .82356 .7061 L .83977 .6938 L p .707 .577 .707 r
F P
0 g
s
.83977 .6938 m .8374 .65885 L .82119 .67115 L p .707 .577 .707 r
F P
0 g
s
.80012 .73799 m .80144 .75531 L .82531 .74472 L p .707 .577 .707 r
F P
0 g
s
.82531 .74472 m .82399 .7274 L .80012 .73799 L p .707 .577 .707 r
F P
0 g
s
.64141 .58561 m .6436 .63943 L .65623 .64951 L p .707 .577 .707 r
F P
0 g
s
.6565 .67618 m .65887 .71114 L .68 .71986 L p .707 .577 .707 r
F P
0 g
s
.68051 .74229 m .68183 .75962 L .70932 .76488 L p .707 .577 .707 r
F P
0 g
s
.6436 .63943 m .64141 .58561 L .63846 .5743 L p .707 .577 .707 r
F P
0 g
s
.68183 .75962 m .68051 .74229 L .65936 .73332 L p .707 .577 .707 r
F P
0 g
s
.65936 .73332 m .66068 .75064 L .68183 .75962 L p .707 .577 .707 r
F P
0 g
s
.82399 .7274 m .82531 .74472 L .84148 .73187 L p .707 .577 .707 r
F P
0 g
s
.84148 .73187 m .84016 .71455 L .82399 .7274 L p .707 .577 .707 r
F P
0 g
s
.8374 .65885 m .83977 .6938 L .84669 .6805 L p .707 .577 .707 r
F P
0 g
s
.84669 .6805 m .84432 .64555 L .8374 .65885 L p .707 .577 .707 r
F P
0 g
s
.84223 .57181 m .84442 .62564 L .84147 .61434 L p .707 .577 .707 r
F P
0 g
s
.84147 .61434 m .83928 .56051 L .84223 .57181 L p .707 .577 .707 r
F P
0 g
s
.64379 .66477 m .64616 .69972 L .65887 .71114 L p .707 .577 .707 r
F P
0 g
s
.63846 .5743 m .64065 .62813 L .6436 .63943 L p .707 .577 .707 r
F P
0 g
s
.66068 .75064 m .65936 .73332 L .64663 .72151 L p .707 .577 .707 r
F P
0 g
s
.64616 .69972 m .64379 .66477 L .64075 .65178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64065 .62813 m .63846 .5743 L .64548 .56288 L p .707 .577 .707 r
F P
0 g
s
.64663 .72151 m .64795 .73884 L .66068 .75064 L p .707 .577 .707 r
F P
0 g
s
.84016 .71455 m .84148 .73187 L .84836 .71803 L p .707 .577 .707 r
F P
0 g
s
.84836 .71803 m .84704 .7007 L .84016 .71455 L p .707 .577 .707 r
F P
0 g
s
.84432 .64555 m .84669 .6805 L .84365 .66751 L p .707 .577 .707 r
F P
0 g
s
.84365 .66751 m .84128 .63256 L .84432 .64555 L p .707 .577 .707 r
F P
0 g
s
.64075 .65178 m .64311 .68673 L .64616 .69972 L p .707 .577 .707 r
F P
0 g
s
.83928 .56051 m .84147 .61434 L .82883 .60426 L p .707 .577 .707 r
F P
0 g
s
.82883 .60426 m .82665 .55043 L .83928 .56051 L p .707 .577 .707 r
F P
0 g
s
.64548 .56288 m .64767 .6167 L .64065 .62813 L p .707 .577 .707 r
F P
0 g
s
.64795 .73884 m .64663 .72151 L .64355 .70803 L p .707 .577 .707 r
F P
0 g
s
.64311 .68673 m .64075 .65178 L .64767 .63848 L p .707 .577 .707 r
F P
0 g
s
.64767 .6167 m .64548 .56288 L .66179 .55245 L p .707 .577 .707 r
F P
0 g
s
.39294 .62685 m .39075 .57302 L .35959 .57161 L p .707 .577 .707 r
F P
0 g
s
.39075 .57302 m .39294 .62685 L .42474 .62466 L p .707 .577 .707 r
F P
0 g
s
.42474 .62466 m .42256 .57084 L .39075 .57302 L p .707 .577 .707 r
F P
0 g
s
.64355 .70803 m .64487 .72535 L .64795 .73884 L p .707 .577 .707 r
F P
0 g
s
.42256 .57084 m .42474 .62466 L .45408 .61909 L p .707 .577 .707 r
F P
0 g
s
.45408 .61909 m .4519 .56527 L .42256 .57084 L p .707 .577 .707 r
F P
0 g
s
.84704 .7007 m .84836 .71803 L .84528 .70454 L p .707 .577 .707 r
F P
0 g
s
.84528 .70454 m .84397 .68722 L .84704 .7007 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36177 .62543 m .35959 .57161 L .33212 .56673 L p .707 .577 .707 r
F P
0 g
s
.35959 .57161 m .36177 .62543 L .39294 .62685 L p .707 .577 .707 r
F P
0 g
s
.84128 .63256 m .84365 .66751 L .83094 .6561 L p .707 .577 .707 r
F P
0 g
s
.83094 .6561 m .82857 .62114 L .84128 .63256 L p .707 .577 .707 r
F P
0 g
s
.82665 .55043 m .82883 .60426 L .80775 .5964 L p .707 .577 .707 r
F P
0 g
s
.80775 .5964 m .80556 .54257 L .82665 .55043 L p .707 .577 .707 r
F P
0 g
s
.4519 .56527 m .45408 .61909 L .47808 .61068 L p .707 .577 .707 r
F P
0 g
s
.47808 .61068 m .47589 .55686 L .4519 .56527 L p .707 .577 .707 r
F P
0 g
s
.64767 .63848 m .65004 .67344 L .64311 .68673 L p .707 .577 .707 r
F P
0 g
s
.66179 .55245 m .66398 .60627 L .64767 .6167 L p .707 .577 .707 r
F P
0 g
s
.64487 .72535 m .64355 .70803 L .65043 .69418 L p .707 .577 .707 r
F P
0 g
s
.33431 .62056 m .33212 .56673 L .31104 .55887 L p .707 .577 .707 r
F P
0 g
s
.33212 .56673 m .33431 .62056 L .36177 .62543 L p .707 .577 .707 r
F P
0 g
s
.66398 .60627 m .66179 .55245 L .68579 .54403 L p .707 .577 .707 r
F P
0 g
s
.65004 .67344 m .64767 .63848 L .66388 .62618 L p .707 .577 .707 r
F P
0 g
s
.39562 .68934 m .39325 .65438 L .3621 .65326 L p .707 .577 .707 r
F P
0 g
s
.39325 .65438 m .39562 .68934 L .42738 .68629 L p .707 .577 .707 r
F P
0 g
s
.42738 .68629 m .42501 .65134 L .39325 .65438 L p .707 .577 .707 r
F P
0 g
s
.65043 .69418 m .65175 .71151 L .64487 .72535 L p .707 .577 .707 r
F P
0 g
s
.42501 .65134 m .42738 .68629 L .45664 .67938 L p .707 .577 .707 r
F P
0 g
s
.84397 .68722 m .84528 .70454 L .83255 .69274 L p .707 .577 .707 r
F P
0 g
s
.83255 .69274 m .83123 .67541 L .84397 .68722 L p .707 .577 .707 r
F P
0 g
s
.47589 .55686 m .47808 .61068 L .49439 .60025 L p .707 .577 .707 r
F P
0 g
s
.49439 .60025 m .4922 .54643 L .47589 .55686 L p .707 .577 .707 r
F P
0 g
s
.80556 .54257 m .80775 .5964 L .78028 .59152 L p .707 .577 .707 r
F P
0 g
s
.78028 .59152 m .7781 .53769 L .80556 .54257 L p .707 .577 .707 r
F P
0 g
s
.36447 .68822 m .3621 .65326 L .33462 .64809 L p .707 .577 .707 r
F P
0 g
s
.3621 .65326 m .36447 .68822 L .39562 .68934 L p .707 .577 .707 r
F P
0 g
s
.82857 .62114 m .83094 .6561 L .80981 .64738 L p .707 .577 .707 r
F P
0 g
s
.80981 .64738 m .80744 .61242 L .82857 .62114 L p .707 .577 .707 r
F P
0 g
s
.45428 .64443 m .45664 .67938 L .48055 .66928 L p .707 .577 .707 r
F P
0 g
s
.48055 .66928 m .47818 .63433 L .45428 .64443 L p .707 .577 .707 r
F P
0 g
s
.66388 .62618 m .66624 .66114 L .65004 .67344 L p .707 .577 .707 r
F P
0 g
s
.31104 .55887 m .31322 .61269 L .33431 .62056 L p .707 .577 .707 r
F P
0 g
s
.68797 .59786 m .68579 .54403 L .71513 .53846 L p .707 .577 .707 r
F P
0 g
s
.68579 .54403 m .68797 .59786 L .66398 .60627 L p .707 .577 .707 r
F P
0 g
s
.31322 .61269 m .31104 .55887 L .2984 .54879 L p .707 .577 .707 r
F P
0 g
s
.65175 .71151 m .65043 .69418 L .6666 .68134 L p .707 .577 .707 r
F P
0 g
s
.66624 .66114 m .66388 .62618 L .68778 .61608 L p .707 .577 .707 r
F P
0 g
s
.7781 .53769 m .78028 .59152 L .74912 .5901 L p .707 .577 .707 r
F P
0 g
s
.74912 .5901 m .74693 .53628 L .7781 .53769 L p .707 .577 .707 r
F P
0 g
s
.33699 .68304 m .33462 .64809 L .31349 .63937 L p .707 .577 .707 r
F P
0 g
s
.33462 .64809 m .33699 .68304 L .36447 .68822 L p .707 .577 .707 r
F P
0 g
s
.39745 .7291 m .39613 .71177 L .36499 .71074 L p .707 .577 .707 r
F P
0 g
s
.39613 .71177 m .39745 .7291 L .42919 .7258 L p .707 .577 .707 r
F P
0 g
s
.42919 .7258 m .42788 .70847 L .39613 .71177 L p .707 .577 .707 r
F P
0 g
s
.42788 .70847 m .42919 .7258 L .45843 .7185 L p .707 .577 .707 r
F P
0 g
s
.45843 .7185 m .45711 .70117 L .42788 .70847 L p .707 .577 .707 r
F P
0 g
s
.71731 .59229 m .71513 .53846 L .74693 .53628 L p .707 .577 .707 r
F P
0 g
s
.71513 .53846 m .71731 .59229 L .68797 .59786 L p .707 .577 .707 r
F P
0 g
s
.6666 .68134 m .66792 .69866 L .65175 .71151 L p .707 .577 .707 r
F P
0 g
s
.74693 .53628 m .74912 .5901 L .71731 .59229 L p .707 .577 .707 r
F P
0 g
s
.4922 .54643 m .49439 .60025 L .50141 .58882 L p .707 .577 .707 r
F P
0 g
s
.50141 .58882 m .49922 .535 L .4922 .54643 L p .707 .577 .707 r
F P
0 g
s
.83123 .67541 m .83255 .69274 L .8114 .68376 L p .707 .577 .707 r
F P
0 g
s
.8114 .68376 m .81008 .66644 L .83123 .67541 L p .707 .577 .707 r
F P
0 g
s
.80744 .61242 m .80981 .64738 L .78232 .64221 L p .707 .577 .707 r
F P
0 g
s
.78232 .64221 m .77996 .60725 L .80744 .61242 L p .707 .577 .707 r
F P
0 g
s
.36631 .72806 m .36499 .71074 L .3375 .70548 L p .707 .577 .707 r
F P
0 g
s
.36499 .71074 m .36631 .72806 L .39745 .7291 L p .707 .577 .707 r
F P
0 g
s
.47818 .63433 m .48055 .66928 L .49676 .65699 L p .707 .577 .707 r
F P
0 g
s
.49676 .65699 m .49439 .62203 L .47818 .63433 L p .707 .577 .707 r
F P
0 g
s
.45711 .70117 m .45843 .7185 L .4823 .7079 L p .707 .577 .707 r
F P
0 g
s
.4823 .7079 m .48098 .69058 L .45711 .70117 L p .707 .577 .707 r
F P
0 g
s
.2984 .54879 m .30059 .60262 L .31322 .61269 L p .707 .577 .707 r
F P
0 g
s
.68778 .61608 m .69015 .65104 L .66624 .66114 L p .707 .577 .707 r
F P
0 g
s
.31349 .63937 m .31586 .67432 L .33699 .68304 L p .707 .577 .707 r
F P
0 g
s
.3375 .70548 m .33882 .7228 L .36631 .72806 L p .707 .577 .707 r
F P
0 g
s
.69015 .65104 m .68778 .61608 L .71705 .60918 L p .707 .577 .707 r
F P
0 g
s
.30059 .60262 m .2984 .54879 L .29545 .53749 L p .707 .577 .707 r
F P
0 g
s
.66792 .69866 m .6666 .68134 L .69047 .67074 L p .707 .577 .707 r
F P
0 g
s
.31586 .67432 m .31349 .63937 L .30078 .62795 L p .707 .577 .707 r
F P
0 g
s
.33882 .7228 m .3375 .70548 L .31635 .69651 L p .707 .577 .707 r
F P
0 g
s
.77996 .60725 m .78232 .64221 L .75118 .64109 L p .707 .577 .707 r
F P
0 g
s
.75118 .64109 m .74881 .60613 L .77996 .60725 L p .707 .577 .707 r
F P
0 g
s
.71942 .64413 m .71705 .60918 L .74881 .60613 L p .707 .577 .707 r
F P
0 g
s
.71705 .60918 m .71942 .64413 L .69015 .65104 L p .707 .577 .707 r
F P
0 g
s
.69047 .67074 m .69179 .68807 L .66792 .69866 L p .707 .577 .707 r
F P
0 g
s
.81008 .66644 m .8114 .68376 L .78391 .6785 L p .707 .577 .707 r
F P
0 g
s
.78391 .6785 m .78259 .66118 L .81008 .66644 L p .707 .577 .707 r
F P
0 g
s
.74881 .60613 m .75118 .64109 L .71942 .64413 L p .707 .577 .707 r
F P
0 g
s
.31635 .69651 m .31767 .71383 L .33882 .7228 L p .707 .577 .707 r
F P
0 g
s
.48098 .69058 m .4823 .7079 L .49847 .69506 L p .707 .577 .707 r
F P
0 g
s
.49847 .69506 m .49715 .67773 L .48098 .69058 L p .707 .577 .707 r
F P
0 g
s
.49439 .62203 m .49676 .65699 L .50368 .64369 L p .707 .577 .707 r
F P
0 g
s
.50368 .64369 m .50131 .60873 L .49439 .62203 L p .707 .577 .707 r
F P
0 g
s
.49922 .535 m .50141 .58882 L .49846 .57752 L p .707 .577 .707 r
F P
0 g
s
.49846 .57752 m .49627 .52369 L .49922 .535 L p .707 .577 .707 r
F P
0 g
s
.30078 .62795 m .30315 .66291 L .31586 .67432 L p .707 .577 .707 r
F P
0 g
s
.69179 .68807 m .69047 .67074 L .71971 .66344 L p .707 .577 .707 r
F P
0 g
s
.29545 .53749 m .29763 .59131 L .30059 .60262 L p .707 .577 .707 r
F P
0 g
s
.78259 .66118 m .78391 .6785 L .75277 .67747 L p .707 .577 .707 r
F P
0 g
s
.75277 .67747 m .75145 .66015 L .78259 .66118 L p .707 .577 .707 r
F P
0 g
s
.31767 .71383 m .31635 .69651 L .30362 .6847 L p .707 .577 .707 r
F P
0 g
s
.71971 .66344 m .72103 .68077 L .69179 .68807 L p .707 .577 .707 r
F P
0 g
s
.30315 .66291 m .30078 .62795 L .29774 .61496 L p .707 .577 .707 r
F P
0 g
s
.72103 .68077 m .71971 .66344 L .75145 .66015 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29763 .59131 m .29545 .53749 L .30247 .52606 L p .707 .577 .707 r
F P
0 g
s
.75145 .66015 m .75277 .67747 L .72103 .68077 L p .707 .577 .707 r
F P
0 g
s
.30362 .6847 m .30494 .70202 L .31767 .71383 L p .707 .577 .707 r
F P
0 g
s
.49715 .67773 m .49847 .69506 L .50535 .68121 L p .707 .577 .707 r
F P
0 g
s
.50535 .68121 m .50403 .66389 L .49715 .67773 L p .707 .577 .707 r
F P
0 g
s
.50131 .60873 m .50368 .64369 L .50064 .6307 L p .707 .577 .707 r
F P
0 g
s
.50064 .6307 m .49827 .59574 L .50131 .60873 L p .707 .577 .707 r
F P
0 g
s
.29774 .61496 m .3001 .64992 L .30315 .66291 L p .707 .577 .707 r
F P
0 g
s
.49627 .52369 m .49846 .57752 L .48582 .56744 L p .707 .577 .707 r
F P
0 g
s
.48582 .56744 m .48364 .51362 L .49627 .52369 L p .707 .577 .707 r
F P
0 g
s
.30247 .52606 m .30466 .57989 L .29763 .59131 L p .707 .577 .707 r
F P
0 g
s
.30494 .70202 m .30362 .6847 L .30054 .67121 L p .707 .577 .707 r
F P
0 g
s
.3001 .64992 m .29774 .61496 L .30466 .60167 L p .707 .577 .707 r
F P
0 g
s
.30466 .57989 m .30247 .52606 L .31878 .51563 L p .707 .577 .707 r
F P
0 g
s
.30054 .67121 m .30186 .68854 L .30494 .70202 L p .707 .577 .707 r
F P
0 g
s
.50403 .66389 m .50535 .68121 L .50227 .66773 L p .707 .577 .707 r
F P
0 g
s
.50227 .66773 m .50096 .6504 L .50403 .66389 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49827 .59574 m .50064 .6307 L .48793 .61928 L p .707 .577 .707 r
F P
0 g
s
.48793 .61928 m .48556 .58433 L .49827 .59574 L p .707 .577 .707 r
F P
0 g
s
.48364 .51362 m .48582 .56744 L .46474 .55958 L p .707 .577 .707 r
F P
0 g
s
.46474 .55958 m .46255 .50576 L .48364 .51362 L p .707 .577 .707 r
F P
0 g
s
.30466 .60167 m .30703 .63662 L .3001 .64992 L p .707 .577 .707 r
F P
0 g
s
.31878 .51563 m .32096 .56946 L .30466 .57989 L p .707 .577 .707 r
F P
0 g
s
.30186 .68854 m .30054 .67121 L .30742 .65737 L p .707 .577 .707 r
F P
0 g
s
.32096 .56946 m .31878 .51563 L .34278 .50722 L p .707 .577 .707 r
F P
0 g
s
.30703 .63662 m .30466 .60167 L .32087 .58937 L p .707 .577 .707 r
F P
0 g
s
.30742 .65737 m .30874 .67469 L .30186 .68854 L p .707 .577 .707 r
F P
0 g
s
.50096 .6504 m .50227 .66773 L .48954 .65592 L p .707 .577 .707 r
F P
0 g
s
.48954 .65592 m .48822 .6386 L .50096 .6504 L p .707 .577 .707 r
F P
0 g
s
.46255 .50576 m .46474 .55958 L .43727 .5547 L p .707 .577 .707 r
F P
0 g
s
.43727 .5547 m .43508 .50088 L .46255 .50576 L p .707 .577 .707 r
F P
0 g
s
.48556 .58433 m .48793 .61928 L .4668 .61056 L p .707 .577 .707 r
F P
0 g
s
.4668 .61056 m .46443 .57561 L .48556 .58433 L p .707 .577 .707 r
F P
0 g
s
.32087 .58937 m .32323 .62432 L .30703 .63662 L p .707 .577 .707 r
F P
0 g
s
.34496 .56104 m .34278 .50722 L .37211 .50165 L p .707 .577 .707 r
F P
0 g
s
.34278 .50722 m .34496 .56104 L .32096 .56946 L p .707 .577 .707 r
F P
0 g
s
.30874 .67469 m .30742 .65737 L .32359 .64452 L p .707 .577 .707 r
F P
0 g
s
.32323 .62432 m .32087 .58937 L .34477 .57927 L p .707 .577 .707 r
F P
0 g
s
.43508 .50088 m .43727 .5547 L .40611 .55329 L p .707 .577 .707 r
F P
0 g
s
.40611 .55329 m .40392 .49946 L .43508 .50088 L p .707 .577 .707 r
F P
0 g
s
.3743 .55547 m .37211 .50165 L .40392 .49946 L p .707 .577 .707 r
F P
0 g
s
.37211 .50165 m .3743 .55547 L .34496 .56104 L p .707 .577 .707 r
F P
0 g
s
.32359 .64452 m .32491 .66185 L .30874 .67469 L p .707 .577 .707 r
F P
0 g
s
.40392 .49946 m .40611 .55329 L .3743 .55547 L p .707 .577 .707 r
F P
0 g
s
.48822 .6386 m .48954 .65592 L .46839 .64695 L p .707 .577 .707 r
F P
0 g
s
.46839 .64695 m .46707 .62962 L .48822 .6386 L p .707 .577 .707 r
F P
0 g
s
.46443 .57561 m .4668 .61056 L .43931 .60539 L p .707 .577 .707 r
F P
0 g
s
.43931 .60539 m .43695 .57044 L .46443 .57561 L p .707 .577 .707 r
F P
0 g
s
.34477 .57927 m .34714 .61422 L .32323 .62432 L p .707 .577 .707 r
F P
0 g
s
.34714 .61422 m .34477 .57927 L .37404 .57236 L p .707 .577 .707 r
F P
0 g
s
.32491 .66185 m .32359 .64452 L .34746 .63393 L p .707 .577 .707 r
F P
0 g
s
.43695 .57044 m .43931 .60539 L .40817 .60427 L p .707 .577 .707 r
F P
0 g
s
.40817 .60427 m .4058 .56932 L .43695 .57044 L p .707 .577 .707 r
F P
0 g
s
.37641 .60731 m .37404 .57236 L .4058 .56932 L p .707 .577 .707 r
F P
0 g
s
.37404 .57236 m .37641 .60731 L .34714 .61422 L p .707 .577 .707 r
F P
0 g
s
.34746 .63393 m .34878 .65125 L .32491 .66185 L p .707 .577 .707 r
F P
0 g
s
.46707 .62962 m .46839 .64695 L .4409 .64169 L p .707 .577 .707 r
F P
0 g
s
.4409 .64169 m .43958 .62436 L .46707 .62962 L p .707 .577 .707 r
F P
0 g
s
.4058 .56932 m .40817 .60427 L .37641 .60731 L p .707 .577 .707 r
F P
0 g
s
.34878 .65125 m .34746 .63393 L .3767 .62663 L p .707 .577 .707 r
F P
0 g
s
.43958 .62436 m .4409 .64169 L .40976 .64065 L p .707 .577 .707 r
F P
0 g
s
.40976 .64065 m .40844 .62333 L .43958 .62436 L p .707 .577 .707 r
F P
0 g
s
.3767 .62663 m .37802 .64395 L .34878 .65125 L p .707 .577 .707 r
F P
0 g
s
.37802 .64395 m .3767 .62663 L .40844 .62333 L p .707 .577 .707 r
F P
0 g
s
.40844 .62333 m .40976 .64065 L .37802 .64395 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0028Ool<0029Ool007moo`T0
00IJEP03001JEUYF00=JEP`007eoo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MWoo001dOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000M7oo001aOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LWoo001]Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001`Ool006]oo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006io
o`00JWoo0P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0P00KGoo001YOol00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH00000Jgoo001WOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01@00FUIJEUYF0000JWoo001VOol00`00FUIJEP02FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1WOol006Eoo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo
001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000EJEP03
001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP80
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Moo`00HWoo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Moo`00HWoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJ7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVQoo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF
J7oo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIXOol0069oo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol0069oo`05001JEUYFFUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUIXOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1UOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001J
EUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00Hgoo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIWOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVMoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEUYF01L000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH2001VOol0061oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
05aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001V
Ool005Yoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0067oo3`00?Woo001COol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P003goo2@0015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0027oo
0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo001C
Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Woo0P000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
035oo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00MJ
EP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001C
Ool01000FUIJEP0015YF00<005YFFUH00eYF1@000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
1UYF100015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF0004
FUH00`00FUH000030004Ool01@00FUIJEUYF000015YF1@001UYF00<005YFFUH00eYF0`0015YF0`00
00AJEP00FUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEPL000=o
o`05001JEUYFFUH00004FUH:00000eYF001JEP0400000eYF001JEP05FUH01000FUH000000UYF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF0P000eYF00@005YFFUIJEPd0
00AJEP03001JEUYF009JEPT000IJEP06001JEUYFFUH005YF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
02eoo`00E7oo00<005YF00000P001EYF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00E7oo00D005YF001JEP0000EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH0
0`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol2
0003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol20003
FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP04FUH60009Ool80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Goo0011OolE0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP05001JEUYF
FUH00006FUH00`00FUIJEP040007Ool3000=Ool60004FUH01@00FUIJEUYF0000;Goo000mOol40000
0eYF001JEP07FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP05001JEUYF
FUH00005FUH4000:Ool5000>Ool20002FUH300000eYF001JEP02FUH2000/Ool003Uoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEP0000<000ioo`D0
00Uoo`D000EJEP04001JEP000003FUH2000/Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPL000QJEPP000AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF0P0000=JEP00FUH010002goo3`000UYF00<005YFFUH015YF00D005YF
FUIJEP00009JEP8002aoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00002FUH01@00FUIJEUYF00001EYF2`0015YF00<005YFFUH01UYF00<005YF0000
0`001EYF00<005YFFUH00UYF1000;7oo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH00`00FUIJEP04FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP04FUH3000/Ool002moo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH0000200001EYF000005YF00000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P001EYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0015YF0`00;7oo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH0
00050003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002FUH01000FUIJEUYF
0P000eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20000
0eYF001JEP04FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH20005FUH90004
FUH?0007FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00;7oo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00<005YF00001EYF00D005YFFUIJEP00009JEPL000AJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002eo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00UYF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000AJEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020003FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool002eoo`8000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP800003FUH005YF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Goo0P00
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`00
00=JEP0000000eYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0P0000AJ
EP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04
001JEUYF000]Ool002eoo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP04001JEP000006FUH00`00FUIJEP04FUH70009FUH00`00FUIJEP02FUH7
0004FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00AJEQD0009JEP<000MJEP03001JEUYF00D000EJEP03001JEUYF00MJEPD0009JEP03001J
EUYF009JEP8000=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<000AJEP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00@000Ioo`<000Yoo`800005FUH00000FUH00006FUH90005FUH01000
FUIJEUYF1`001UYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001P0000EJEP00FUIJEP0002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF10002Goo1@002Goo0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01@00
FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH01000
FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001goo0P000UYF
00<007ooOol0:goo000]Ool00`00FUH00004FUH00`00FUH00003000=Ool5000:Ool20004FUH01000
FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H0
05YFFUIJEP00FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000AJEP05001JEP00001JEP040002FUH00`00FUIJEP06FUH:0002FUH4000<Ool00`00
FUH0000]Ool002eoo`03001JEP0000AJEPL000aoo`D000Qoo`@000AJEP800003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP03
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP8000AJEP03001JEUYF00/000AJEP03001JEUYF009JEPP000Yoo`@002eoo`00;Goo00<005YF0000
0UYF0P000eYF00@005YFFUIJEQT00004FUH005YF0002FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00009JEP800003FUH005YF
00=JEP04001JEUYFFUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000goo0P00
0UYF0`00;7oo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP02FUH5000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUIJEP00FUH30003FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH3000/Ool002eoo`05001JEP00FUH00005FUH0
0`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUH005YF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0015YF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00P000eYF0`00;7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP040005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF0P000UYF0`000eYF00<005YF
FUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJEP00FUH002aoo`00;Goo0P00
0UYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP<00003FUH005YF00<000EJEP03001JEUYF00AJEPH000moo`@0009JEP03001JEUYF00=JEP<0
0003FUH007oo02]oo`00;Goo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEPH000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000IJ
EP04001JEUYFFUH200000eYF00000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`0000=JEP00FUH00P001UYF00<005YFFUH010004Woo100000=JEP00FUH01000
15YF00@005YF000002eoo`00;Goo0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000EJEP03001JEUYF00=JEPT0009JEPD0009JEPL000YJEP04001JEUYF
0003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P0000=JEP00FUH015YF100000=JEP00Ool037oo1`001EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0002eoo`00;Goo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00eYF00<005YF00000P000UYF00<005YF000020001EYF00<005YFFUH0
2EYF0`0015YF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF009JEP04001JEUYFFUH20003FUH@0004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH30002FUH00`00Oomoo`0[Ool002ioo`03001JEUYF00800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF009JEP<000QJEP8000UJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEP04
001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH00eYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH200000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001oo`0[Ool002moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF009JEPP000AJEP80009JEP03001JEP00008000EJEP03001JEUYF0080009JEP03001JEUYF
00=JEP03001JEUYF00QJEP03001JEUYF009JEP<000IJEP03001JEP0000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH01@00FUIJEUYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo0P00;7oo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008FUH700000eYF001JEP03FUH30002FUH00`00
FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP08FUH500000eYF001JEP06FUH20008FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
17oo0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH00`00FUH0000300000eYF00000002FUH00`00FUIJEP04FUH01000FUIJ
EUYF1`001EYF00<005YFFUH015YF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH20006Ool2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000007Ool01000FUH00000:goo000]Ool0
0`00FUH00004FUH01000FUIJEUYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH300000eYF001JEP06FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP04FUH40009Ool01000
FUIJEP00:goo000]Ool00`00FUH00004FUH01000FUH0000017oo200015YF00<005YFFUH00UYF2@00
1goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00EJEP03001JEP00008000IJEP03001JEUYF00AJEPD000EJEP03001JEUYF00@000aoo`80009JEP03
001oogoo02Uoo`00;Goo00@005YFFUH000=JEP8000ioo`T0019oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH500000eYF
00000005000>Ool2000015YF001JEP00;7oo000]Ool01000FUIJEP000UYF00<007ooOol04Goo2P00
4Goo10000UYF00<005YFFUH01EYF00<005YFFUH00eYF1`001eYF2P0035YF2@0025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEP0000l001=oo`8000AJEP8002aoo`00
;Goo00H005YFFUH005YF000?Ool70004FUH01000FUIJEUYF200027oo00@005YFFUIJEQ4000EJEP03
001JEUYF00H000UJEP03001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP06001J
EUYFFUH005YF0P000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`<001=oo`800003FUH005YF
00=JEP03001oogoo02]oo`00;Woo00@005YF000000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH50002Ool00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF
FUIJEP80009JEP05001JEUYFFUH00004FUH01@00FUIJEUYF000077oo0P000eYF00<005YFFUH00UYF
00<007ooOol0:goo000^Ool01@00FUH005YF00001goo10001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF100015YF00<005YF00002EYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00<0
05YFFUH00`0000=JEP00FUH00eYF00D005YFFUIJEP0001Uoo`<000EJEP03001JEUYF008002ioo`00
;Woo0P000UYF0`000goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00P0015YF00<005YFFUH025YF00@005YFFUIJEP<000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<00003FUH005YF00=JEP04001JEUYF
0002FUH20005FUH01000FUIJEP005Goo100000=JEP00FUH01EYF0`00<7oo000^Ool20002FUH00`00
FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH025YF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00P0015YF0P0000=JEP00FUH00eYF1P000UYF
00<007ooOol037oo1`001EYF00<005YFFUH00eYF0P00<Woo000^Ool20002FUH01000FUH000001UYF
00<005YFFUH015YF1P002Goo200015YF00<005YFFUH00UYF0P0000=JEP0000002EYF0P000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF00@005YFFUIJEP@000EJEP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00=7oo000^Ool20002FUH30007FUH00`00FUIJEP050009Ool70006FUH50004FUH00`00FUH0
00020007FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=Woo000^Ool20002FUH00`00
FUH00006FUH50004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEP00
1UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH01EYF0`000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo000_Ool00`00FUH00003FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP0000AJEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Aoo`800003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@003]oo`00;goo0P0015YF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01`00
FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00EJEP<000Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPL003moo`00;goo0P0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0P000Woo00<005YF00000UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH015YF0`002Goo5000AWoo000_Ool20003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000`0017oo0P0015YF0`00Dgoo000^Ool01000FUH005YF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00@005YFFUIJEP80
00Moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP@00003FUH0
05YF00=JEP<005=oo`00;Woo00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000IJEP03001JEUYF00EJEP04001JEP000009Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUH000020003FUH00`00FUH0001COol002ioo`03001JEP0000Aoo`80
0003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<000Yoo`@000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEP800004FUH005YF001COol002ioo`80
00Moo`D000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00@000eoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH4001DOol002ioo`8000aoo`T000=J
EP<000=JEPL000moo`<00003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00<0009JEP03001JEUYF00=JEP@005Aoo`00;Woo0P005Goo2@0057oo0P000UYF0P0000=oo`00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00FUH40004FUH00`00FUH0001EOol0
02ioo`<0031oo`03001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP8000AJEP03001JEUYF00=JEP<00005FUH005YFFUH0001DOol002ioo`800003FUH007oo02aoo`<0
00AJEP05001oogooOol00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP020006FUH00`00FUIJEP05FUH3
0002FUH00`00Oomoo`1BOol002ioo`80009JEP03001oogoo02Qoo`80009JEP03001JEUYF009JEP03
001oogoo009oo`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000QJEP03001JEUYF00AJEP@00003FUH0000005=oo`00
;goo00<005YFFUH00`009Woo0P001EYF00@005YFFUH000Moo`8000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=oo`<005=oo`00;goo00@005YFFUH0009JEP80029oo`8000MJEP<000Uo
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20006Ool2001COol0031oo`04001JEUYF
0003FUH5000IOol400000eYF001JEP05FUH2000=Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040006FUH00`00FUIJEP06FUH01000FUH0
000027oo0P00Dgoo000aOol30004FUH01000FUIJEUYF2@002Goo1`001EYF00<005YFFUH00UYF0P00
4Goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF0`0000=J
EP0000000`001EYF00<005YFFUH015YF10002Goo00@005YF0000059oo`00<goo00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000001Ioo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP@000AJEPD000EJEP03001JEUYF00@0
00eoo`04001JEUYF001BOol003Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<001aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEP00
00<00003FUH005YF00EJEPD00003FUH0000000D0011oo`80009JEP03001oogoo051oo`00=Woo0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P009Goo2@001UYF
00<005YFFUH015YF20000goo3`005Woo00D005YF001JEP0005=oo`00>7oo1@0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YF00000P00<7oo3@00;goo00@005YFFUIJEP8005=oo`00?Goo6000
>goo00<005YF0000;goo0P0015YF00<007ooOol0DWoo002@Ool200000eYF001oo`0[Ool200000eYF
001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF008002Qoo`8000=JEP05001JEUYFFUH0001E
Ool0095oo`05001JEUYF001JEP03000ROol30005FUH01000FUH00000EWoo002BOol00`00FUH00004
FUH3000KOol400000eYF001JEP05FUH2001HOol0099oo`03001JEP0000EJEP03001JEP0000<0011o
o`L000EJEP03001JEUYF00=JEP8005Uoo`00Tgoo0P001EYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00@005YFFUIJEP8005]oo`00U7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF000005eoo`00UWoo0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00Ggoo002IOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04001ROol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF009J
EPL006Ioo`00X7oo4000KGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]4\[InvisibleSpace]"     "\
\[InvisibleSpace]2.3517602945677583`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 4, "     ", 2.3517602945677583, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59004 .75323 m .59551 .69853 L .56449 .69354 L p .707 .577 .707 r
F P
0 g
s
.59551 .69853 m .59004 .75323 L .62173 .75524 L p .707 .577 .707 r
F P
0 g
s
.62173 .75524 m .6272 .70054 L .59551 .69853 L p .707 .577 .707 r
F P
0 g
s
.6272 .70054 m .62173 .75524 L .65101 .75407 L p .707 .577 .707 r
F P
0 g
s
.65101 .75407 m .65647 .69937 L .6272 .70054 L p .707 .577 .707 r
F P
0 g
s
.55902 .74825 m .56449 .69354 L .53718 .68606 L p .707 .577 .707 r
F P
0 g
s
.56449 .69354 m .55902 .74825 L .59004 .75323 L p .707 .577 .707 r
F P
0 g
s
.65647 .69937 m .65101 .75407 L .67499 .74984 L p .707 .577 .707 r
F P
0 g
s
.67499 .74984 m .68046 .69514 L .65647 .69937 L p .707 .577 .707 r
F P
0 g
s
.53171 .74077 m .53718 .68606 L .51626 .67682 L p .707 .577 .707 r
F P
0 g
s
.53718 .68606 m .53171 .74077 L .55902 .74825 L p .707 .577 .707 r
F P
0 g
s
.58385 .81668 m .58978 .78077 L .55902 .77386 L p .707 .577 .707 r
F P
0 g
s
.58978 .78077 m .58385 .81668 L .61532 .82041 L p .707 .577 .707 r
F P
0 g
s
.61532 .82041 m .62125 .78451 L .58978 .78077 L p .707 .577 .707 r
F P
0 g
s
.62125 .78451 m .61532 .82041 L .64441 .82062 L p .707 .577 .707 r
F P
0 g
s
.64441 .82062 m .65034 .78472 L .62125 .78451 L p .707 .577 .707 r
F P
0 g
s
.55309 .80977 m .55902 .77386 L .53196 .76447 L p .707 .577 .707 r
F P
0 g
s
.55902 .77386 m .55309 .80977 L .58385 .81668 L p .707 .577 .707 r
F P
0 g
s
.68046 .69514 m .67499 .74984 L .69134 .74296 L p .707 .577 .707 r
F P
0 g
s
.69134 .74296 m .6968 .68826 L .68046 .69514 L p .707 .577 .707 r
F P
0 g
s
.51626 .67682 m .5108 .73153 L .53171 .74077 L p .707 .577 .707 r
F P
0 g
s
.65034 .78472 m .64441 .82062 L .66828 .81727 L p .707 .577 .707 r
F P
0 g
s
.66828 .81727 m .67421 .78137 L .65034 .78472 L p .707 .577 .707 r
F P
0 g
s
.53196 .76447 m .52603 .80037 L .55309 .80977 L p .707 .577 .707 r
F P
0 g
s
.5108 .73153 m .51626 .67682 L .50378 .66673 L p .707 .577 .707 r
F P
0 g
s
.52603 .80037 m .53196 .76447 L .51128 .7535 L p .707 .577 .707 r
F P
0 g
s
.57945 .8614 m .58276 .84354 L .55209 .83607 L p .707 .577 .707 r
F P
0 g
s
.58276 .84354 m .57945 .8614 L .61083 .86565 L p .707 .577 .707 r
F P
0 g
s
.61083 .86565 m .61414 .84779 L .58276 .84354 L p .707 .577 .707 r
F P
0 g
s
.61414 .84779 m .61083 .86565 L .63985 .86626 L p .707 .577 .707 r
F P
0 g
s
.63985 .86626 m .64316 .84841 L .61414 .84779 L p .707 .577 .707 r
F P
0 g
s
.54879 .85392 m .55209 .83607 L .52514 .8261 L p .707 .577 .707 r
F P
0 g
s
.55209 .83607 m .54879 .85392 L .57945 .8614 L p .707 .577 .707 r
F P
0 g
s
.52514 .8261 m .52184 .84396 L .54879 .85392 L p .707 .577 .707 r
F P
0 g
s
.51128 .7535 m .50535 .7894 L .52603 .80037 L p .707 .577 .707 r
F P
0 g
s
.50378 .66673 m .49831 .72143 L .5108 .73153 L p .707 .577 .707 r
F P
0 g
s
.64316 .84841 m .63985 .86626 L .66367 .86317 L p .707 .577 .707 r
F P
0 g
s
.66367 .86317 m .66698 .84532 L .64316 .84841 L p .707 .577 .707 r
F P
0 g
s
.6968 .68826 m .69134 .74296 L .69844 .73411 L p .707 .577 .707 r
F P
0 g
s
.69844 .73411 m .70391 .67941 L .6968 .68826 L p .707 .577 .707 r
F P
0 g
s
.67421 .78137 m .66828 .81727 L .68458 .8107 L p .707 .577 .707 r
F P
0 g
s
.68458 .8107 m .69051 .77479 L .67421 .78137 L p .707 .577 .707 r
F P
0 g
s
.52184 .84396 m .52514 .8261 L .50454 .81462 L p .707 .577 .707 r
F P
0 g
s
.50535 .7894 m .51128 .7535 L .49897 .74203 L p .707 .577 .707 r
F P
0 g
s
.49831 .72143 m .50378 .66673 L .50095 .65676 L p .707 .577 .707 r
F P
0 g
s
.50454 .81462 m .50124 .83247 L .52184 .84396 L p .707 .577 .707 r
F P
0 g
s
.49897 .74203 m .49304 .77793 L .50535 .7894 L p .707 .577 .707 r
F P
0 g
s
.66698 .84532 m .66367 .86317 L .67996 .85669 L p .707 .577 .707 r
F P
0 g
s
.67996 .85669 m .68326 .83883 L .66698 .84532 L p .707 .577 .707 r
F P
0 g
s
.50124 .83247 m .50454 .81462 L .49231 .80275 L p .707 .577 .707 r
F P
0 g
s
.50095 .65676 m .49549 .71147 L .49831 .72143 L p .707 .577 .707 r
F P
0 g
s
.69051 .77479 m .68458 .8107 L .69173 .80154 L p .707 .577 .707 r
F P
0 g
s
.69173 .80154 m .69766 .76563 L .69051 .77479 L p .707 .577 .707 r
F P
0 g
s
.49231 .80275 m .48901 .8206 L .50124 .83247 L p .707 .577 .707 r
F P
0 g
s
.46423 .82209 m .51334 .32806 L .46954 .32104 L p .707 .577 .707 r
F P
0 g
s
.49304 .77793 m .49897 .74203 L .49626 .73119 L p .707 .577 .707 r
F P
0 g
s
.49549 .71147 m .50095 .65676 L .50806 .64791 L p .707 .577 .707 r
F P
0 g
s
.49626 .73119 m .49034 .76709 L .49304 .77793 L p .707 .577 .707 r
F P
0 g
s
.48901 .8206 m .49231 .80275 L .48965 .79164 L p .707 .577 .707 r
F P
0 g
s
.50806 .64791 m .50259 .70262 L .49549 .71147 L p .707 .577 .707 r
F P
0 g
s
.48965 .79164 m .48634 .80949 L .48901 .8206 L p .707 .577 .707 r
F P
0 g
s
.49034 .76709 m .49626 .73119 L .50341 .72203 L p .707 .577 .707 r
F P
0 g
s
.50259 .70262 m .50806 .64791 L .52441 .64103 L p .707 .577 .707 r
F P
0 g
s
.50341 .72203 m .49748 .75793 L .49034 .76709 L p .707 .577 .707 r
F P
0 g
s
.48634 .80949 m .48965 .79164 L .49681 .7824 L p .707 .577 .707 r
F P
0 g
s
.52441 .64103 m .51894 .69574 L .50259 .70262 L p .707 .577 .707 r
F P
0 g
s
.49681 .7824 m .49351 .80025 L .48634 .80949 L p .707 .577 .707 r
F P
0 g
s
.49748 .75793 m .50341 .72203 L .51972 .71545 L p .707 .577 .707 r
F P
0 g
s
.51972 .71545 m .51379 .75136 L .49748 .75793 L p .707 .577 .707 r
F P
0 g
s
.49351 .80025 m .49681 .7824 L .5131 .77591 L p .707 .577 .707 r
F P
0 g
s
.5131 .77591 m .50979 .79376 L .49351 .80025 L p .707 .577 .707 r
F P
0 g
s
.51334 .32806 m .46423 .82209 L .50899 .8249 L p .707 .577 .707 r
F P
0 g
s
.51894 .69574 m .52441 .64103 L .54839 .6368 L p .707 .577 .707 r
F P
0 g
s
.54839 .6368 m .54292 .69151 L .51894 .69574 L p .707 .577 .707 r
F P
0 g
s
.51379 .75136 m .51972 .71545 L .54358 .7121 L p .707 .577 .707 r
F P
0 g
s
.54358 .7121 m .53765 .74801 L .51379 .75136 L p .707 .577 .707 r
F P
0 g
s
.50979 .79376 m .5131 .77591 L .53692 .77282 L p .707 .577 .707 r
F P
0 g
s
.53692 .77282 m .53361 .79068 L .50979 .79376 L p .707 .577 .707 r
F P
0 g
s
.50899 .8249 m .55809 .33088 L .51334 .32806 L p .707 .577 .707 r
F P
0 g
s
.70391 .67941 m .69844 .73411 L .69562 .72415 L p .707 .577 .707 r
F P
0 g
s
.69562 .72415 m .70108 .66944 L .70391 .67941 L p .707 .577 .707 r
F P
0 g
s
.54292 .69151 m .54839 .6368 L .57766 .63563 L p .707 .577 .707 r
F P
0 g
s
.57766 .63563 m .57219 .69034 L .54292 .69151 L p .707 .577 .707 r
F P
0 g
s
.53765 .74801 m .54358 .7121 L .57267 .71231 L p .707 .577 .707 r
F P
0 g
s
.57267 .71231 m .56674 .74821 L .53765 .74801 L p .707 .577 .707 r
F P
0 g
s
.53361 .79068 m .53692 .77282 L .56594 .77343 L p .707 .577 .707 r
F P
0 g
s
.56594 .77343 m .56263 .79129 L .53361 .79068 L p .707 .577 .707 r
F P
0 g
s
.55809 .33088 m .50899 .8249 L .55031 .82324 L p .707 .577 .707 r
F P
0 g
s
.55031 .82324 m .59942 .32921 L .55809 .33088 L p .707 .577 .707 r
F P
0 g
s
.42044 .81507 m .46954 .32104 L .43099 .31051 L p .707 .577 .707 r
F P
0 g
s
.46954 .32104 m .42044 .81507 L .46423 .82209 L p .707 .577 .707 r
F P
0 g
s
.68326 .83883 m .67996 .85669 L .68712 .84744 L p .707 .577 .707 r
F P
0 g
s
.68712 .84744 m .69043 .82959 L .68326 .83883 L p .707 .577 .707 r
F P
0 g
s
.57219 .69034 m .57766 .63563 L .60936 .63764 L p .707 .577 .707 r
F P
0 g
s
.60936 .63764 m .60389 .69235 L .57219 .69034 L p .707 .577 .707 r
F P
0 g
s
.56674 .74821 m .57267 .71231 L .60414 .71605 L p .707 .577 .707 r
F P
0 g
s
.60414 .71605 m .59821 .75195 L .56674 .74821 L p .707 .577 .707 r
F P
0 g
s
.56263 .79129 m .56594 .77343 L .59732 .77769 L p .707 .577 .707 r
F P
0 g
s
.59732 .77769 m .59401 .79554 L .56263 .79129 L p .707 .577 .707 r
F P
0 g
s
.59942 .32921 m .55031 .82324 L .58417 .81725 L p .707 .577 .707 r
F P
0 g
s
.58417 .81725 m .63327 .32323 L .59942 .32921 L p .707 .577 .707 r
F P
0 g
s
.69766 .76563 m .69173 .80154 L .68902 .7907 L p .707 .577 .707 r
F P
0 g
s
.68902 .7907 m .69495 .75479 L .69766 .76563 L p .707 .577 .707 r
F P
0 g
s
.38189 .80453 m .43099 .31051 L .40146 .29748 L p .707 .577 .707 r
F P
0 g
s
.43099 .31051 m .38189 .80453 L .42044 .81507 L p .707 .577 .707 r
F P
0 g
s
.70108 .66944 m .69562 .72415 L .68313 .71406 L p .707 .577 .707 r
F P
0 g
s
.68313 .71406 m .6886 .65935 L .70108 .66944 L p .707 .577 .707 r
F P
0 g
s
.24703 .71355 m .2525 .65885 L .22148 .65386 L p .707 .577 .707 r
F P
0 g
s
.2525 .65885 m .24703 .71355 L .27873 .71556 L p .707 .577 .707 r
F P
0 g
s
.27873 .71556 m .28419 .66086 L .2525 .65885 L p .707 .577 .707 r
F P
0 g
s
.28419 .66086 m .27873 .71556 L .308 .71439 L p .707 .577 .707 r
F P
0 g
s
.308 .71439 m .31347 .65969 L .28419 .66086 L p .707 .577 .707 r
F P
0 g
s
.21601 .70857 m .22148 .65386 L .19417 .64638 L p .707 .577 .707 r
F P
0 g
s
.22148 .65386 m .21601 .70857 L .24703 .71355 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69043 .82959 m .68712 .84744 L .68446 .83634 L p .707 .577 .707 r
F P
0 g
s
.68446 .83634 m .68776 .81848 L .69043 .82959 L p .707 .577 .707 r
F P
0 g
s
.64038 .64263 m .63491 .69734 L .60389 .69235 L p .707 .577 .707 r
F P
0 g
s
.60389 .69235 m .60936 .63764 L .64038 .64263 L p .707 .577 .707 r
F P
0 g
s
.63491 .72296 m .62898 .75886 L .59821 .75195 L p .707 .577 .707 r
F P
0 g
s
.59821 .75195 m .60414 .71605 L .63491 .72296 L p .707 .577 .707 r
F P
0 g
s
.62798 .78516 m .62468 .80301 L .59401 .79554 L p .707 .577 .707 r
F P
0 g
s
.59401 .79554 m .59732 .77769 L .62798 .78516 L p .707 .577 .707 r
F P
0 g
s
.63327 .32323 m .58417 .81725 L .60725 .80754 L p .707 .577 .707 r
F P
0 g
s
.60725 .80754 m .65635 .31351 L .63327 .32323 L p .707 .577 .707 r
F P
0 g
s
.31347 .65969 m .308 .71439 L .33198 .71016 L p .707 .577 .707 r
F P
0 g
s
.33198 .71016 m .33745 .65546 L .31347 .65969 L p .707 .577 .707 r
F P
0 g
s
.69495 .75479 m .68902 .7907 L .67672 .77923 L p .707 .577 .707 r
F P
0 g
s
.67672 .77923 m .68265 .74332 L .69495 .75479 L p .707 .577 .707 r
F P
0 g
s
.6886 .65935 m .68313 .71406 L .66222 .70482 L p .707 .577 .707 r
F P
0 g
s
.66222 .70482 m .66768 .65011 L .6886 .65935 L p .707 .577 .707 r
F P
0 g
s
.1887 .70109 m .19417 .64638 L .17325 .63714 L p .707 .577 .707 r
F P
0 g
s
.19417 .64638 m .1887 .70109 L .21601 .70857 L p .707 .577 .707 r
F P
0 g
s
.35236 .79151 m .40146 .29748 L .38383 .28325 L p .707 .577 .707 r
F P
0 g
s
.40146 .29748 m .35236 .79151 L .38189 .80453 L p .707 .577 .707 r
F P
0 g
s
.24084 .77317 m .24677 .73727 L .21601 .73036 L p .707 .577 .707 r
F P
0 g
s
.24677 .73727 m .24084 .77317 L .27231 .77691 L p .707 .577 .707 r
F P
0 g
s
.27231 .77691 m .27824 .74101 L .24677 .73727 L p .707 .577 .707 r
F P
0 g
s
.27824 .74101 m .27231 .77691 L .3014 .77712 L p .707 .577 .707 r
F P
0 g
s
.3014 .77712 m .30733 .74121 L .27824 .74101 L p .707 .577 .707 r
F P
0 g
s
.21008 .76627 m .21601 .73036 L .18896 .72097 L p .707 .577 .707 r
F P
0 g
s
.21601 .73036 m .21008 .76627 L .24084 .77317 L p .707 .577 .707 r
F P
0 g
s
.33745 .65546 m .33198 .71016 L .34833 .70328 L p .707 .577 .707 r
F P
0 g
s
.34833 .70328 m .35379 .64858 L .33745 .65546 L p .707 .577 .707 r
F P
0 g
s
.17325 .63714 m .16779 .69185 L .1887 .70109 L p .707 .577 .707 r
F P
0 g
s
.68776 .81848 m .68446 .83634 L .67223 .82446 L p .707 .577 .707 r
F P
0 g
s
.67223 .82446 m .67553 .80661 L .68776 .81848 L p .707 .577 .707 r
F P
0 g
s
.30733 .74121 m .3014 .77712 L .32527 .77377 L p .707 .577 .707 r
F P
0 g
s
.32527 .77377 m .3312 .73787 L .30733 .74121 L p .707 .577 .707 r
F P
0 g
s
.18896 .72097 m .18303 .75687 L .21008 .76627 L p .707 .577 .707 r
F P
0 g
s
.66768 .65011 m .66222 .70482 L .63491 .69734 L p .707 .577 .707 r
F P
0 g
s
.63491 .69734 m .64038 .64263 L .66768 .65011 L p .707 .577 .707 r
F P
0 g
s
.16779 .69185 m .17325 .63714 L .16077 .62705 L p .707 .577 .707 r
F P
0 g
s
.23644 .81253 m .23975 .79468 L .20908 .7872 L p .707 .577 .707 r
F P
0 g
s
.23975 .79468 m .23644 .81253 L .26782 .81678 L p .707 .577 .707 r
F P
0 g
s
.26782 .81678 m .27113 .79893 L .23975 .79468 L p .707 .577 .707 r
F P
0 g
s
.18303 .75687 m .18896 .72097 L .16827 .71 L p .707 .577 .707 r
F P
0 g
s
.68265 .74332 m .67672 .77923 L .65603 .76826 L p .707 .577 .707 r
F P
0 g
s
.65603 .76826 m .66196 .73235 L .68265 .74332 L p .707 .577 .707 r
F P
0 g
s
.27113 .79893 m .26782 .81678 L .29684 .81739 L p .707 .577 .707 r
F P
0 g
s
.29684 .81739 m .30015 .79954 L .27113 .79893 L p .707 .577 .707 r
F P
0 g
s
.20578 .80506 m .20908 .7872 L .18213 .77724 L p .707 .577 .707 r
F P
0 g
s
.20908 .7872 m .20578 .80506 L .23644 .81253 L p .707 .577 .707 r
F P
0 g
s
.65635 .31351 m .60725 .80754 L .61728 .79504 L p .707 .577 .707 r
F P
0 g
s
.61728 .79504 m .66638 .30102 L .65635 .31351 L p .707 .577 .707 r
F P
0 g
s
.18213 .77724 m .17883 .79509 L .20578 .80506 L p .707 .577 .707 r
F P
0 g
s
.16827 .71 m .16234 .7459 L .18303 .75687 L p .707 .577 .707 r
F P
0 g
s
.16077 .62705 m .1553 .68175 L .16779 .69185 L p .707 .577 .707 r
F P
0 g
s
.30015 .79954 m .29684 .81739 L .32066 .81431 L p .707 .577 .707 r
F P
0 g
s
.32066 .81431 m .32397 .79645 L .30015 .79954 L p .707 .577 .707 r
F P
0 g
s
.3312 .73787 m .32527 .77377 L .34157 .7672 L p .707 .577 .707 r
F P
0 g
s
.34157 .7672 m .3475 .73129 L .3312 .73787 L p .707 .577 .707 r
F P
0 g
s
.35379 .64858 m .34833 .70328 L .35543 .69443 L p .707 .577 .707 r
F P
0 g
s
.35543 .69443 m .3609 .63973 L .35379 .64858 L p .707 .577 .707 r
F P
0 g
s
.35807 .62976 m .35261 .68447 L .34012 .67437 L p .707 .577 .707 r
F P
0 g
s
.34012 .67437 m .34559 .61967 L .35807 .62976 L p .707 .577 .707 r
F P
0 g
s
.3475 .73129 m .34157 .7672 L .34872 .75804 L p .707 .577 .707 r
F P
0 g
s
.34872 .75804 m .35465 .72213 L .3475 .73129 L p .707 .577 .707 r
F P
0 g
s
.35194 .71129 m .34601 .74719 L .34253 .74395 L p .707 .577 .707 r
F P
0 g
s
.34253 .74395 m .33371 .73573 L p .34437 .72144 L .707 .577 .707 r
F P
0 g
s
.34437 .72144 m .35194 .71129 L .34253 .74395 L .707 .577 .707 r
F
.33371 .73573 m .33964 .69982 L .35194 .71129 L p F P
0 g
s
.34476 .76962 m .34145 .78747 L .33864 .78474 L p .707 .577 .707 r
F P
0 g
s
.33864 .78474 m .32922 .77559 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.33964 .77158 m .34476 .76962 L .33864 .78474 L .707 .577 .707 r
F
.3674 .40935 m .36304 .49242 L .37984 .2692 L F
.32922 .77559 m .33253 .75774 L .34014 .76513 L p F P
0 g
s
.34014 .76513 m .34476 .76962 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.32922 .77559 m .34014 .76513 L .33964 .77158 L .707 .577 .707 r
F
.34559 .61967 m .34012 .67437 L .31921 .66514 L p F P
0 g
s
.33964 .69982 m .33371 .73573 L .31302 .72476 L p .707 .577 .707 r
F P
0 g
s
.31302 .72476 m .31895 .68885 L .33964 .69982 L p .707 .577 .707 r
F P
0 g
s
.33253 .75774 m .32922 .77559 L .30862 .76411 L p .707 .577 .707 r
F P
0 g
s
.30862 .76411 m .31193 .74626 L .33253 .75774 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .33473 .77728 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.37984 .2692 m .3724 .34407 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.31921 .66514 m .32467 .61043 L .34559 .61967 L p .707 .577 .707 r
F P
0 g
s
.3724 .34407 m .33074 .76322 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.33473 .77728 m .35427 .5807 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.35427 .5807 m .36304 .49242 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.36304 .49242 m .38383 .28325 L .38094 .27305 L p .707 .577 .707 r
F P
0 g
s
.38094 .27305 m .37984 .2692 L p .36304 .49242 L .707 .577 .707 r
F P
0 g
s
.3609 .63973 m .35543 .69443 L .35261 .68447 L p .707 .577 .707 r
F P
0 g
s
.35261 .68447 m .35807 .62976 L .3609 .63973 L p .707 .577 .707 r
F P
0 g
s
.34411 .79857 m .34742 .78072 L .34026 .78997 L p .707 .577 .707 r
F P
0 g
s
.35465 .72213 m .34872 .75804 L .34601 .74719 L p .707 .577 .707 r
F P
0 g
s
.34601 .74719 m .35194 .71129 L .35465 .72213 L p .707 .577 .707 r
F P
0 g
s
.34742 .78072 m .34411 .79857 L .34145 .78747 L p .707 .577 .707 r
F P
0 g
s
.34145 .78747 m .34476 .76962 L .34742 .78072 L p .707 .577 .707 r
F P
0 g
s
.38383 .28325 m .33473 .77728 L .35236 .79151 L p .707 .577 .707 r
F P
0 g
s
.17883 .79509 m .18213 .77724 L .16153 .76576 L p .707 .577 .707 r
F P
0 g
s
.16234 .7459 m .16827 .71 L .15597 .69853 L p .707 .577 .707 r
F P
0 g
s
.67553 .80661 m .67223 .82446 L .65163 .81298 L p .707 .577 .707 r
F P
0 g
s
.65163 .81298 m .65494 .79513 L .67553 .80661 L p .707 .577 .707 r
F P
0 g
s
.66196 .73235 m .65603 .76826 L .62898 .75886 L p .707 .577 .707 r
F P
0 g
s
.62898 .75886 m .63491 .72296 L .66196 .73235 L p .707 .577 .707 r
F P
0 g
s
.16153 .76576 m .15823 .78361 L .17883 .79509 L p .707 .577 .707 r
F P
0 g
s
.1553 .68175 m .16077 .62705 L .15795 .61708 L p .707 .577 .707 r
F P
0 g
s
.15597 .69853 m .15004 .73443 L .16234 .7459 L p .707 .577 .707 r
F P
0 g
s
.32397 .79645 m .32066 .81431 L .33695 .80782 L p .707 .577 .707 r
F P
0 g
s
.33695 .80782 m .34026 .78997 L .32397 .79645 L p .707 .577 .707 r
F P
0 g
s
.15823 .78361 m .16153 .76576 L .1493 .75388 L p .707 .577 .707 r
F P
0 g
s
.65494 .79513 m .65163 .81298 L .62468 .80301 L p .707 .577 .707 r
F P
0 g
s
.62468 .80301 m .62798 .78516 L .65494 .79513 L p .707 .577 .707 r
F P
0 g
s
.15795 .61708 m .15248 .67179 L .1553 .68175 L p .707 .577 .707 r
F P
0 g
s
.1493 .75388 m .146 .77173 L .15823 .78361 L p .707 .577 .707 r
F P
0 g
s
.15004 .73443 m .15597 .69853 L .15326 .68768 L p .707 .577 .707 r
F P
0 g
s
.66638 .30102 m .61728 .79504 L .61329 .78099 L p .707 .577 .707 r
F P
0 g
s
.61329 .78099 m .66239 .28696 L .66638 .30102 L p .707 .577 .707 r
F P
0 g
s
.15248 .67179 m .15795 .61708 L .16505 .60823 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .37984 .2692 L .38988 .2567 L p .707 .577 .707 r
F P
0 g
s
.15326 .68768 m .14733 .72359 L .15004 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34026 .78997 m .33695 .80782 L .34411 .79857 L p .707 .577 .707 r
F P
0 g
s
.146 .77173 m .1493 .75388 L .14664 .74278 L p .707 .577 .707 r
F P
0 g
s
.14664 .74278 m .14333 .76063 L .146 .77173 L p .707 .577 .707 r
F P
0 g
s
.16505 .60823 m .15958 .66294 L .15248 .67179 L p .707 .577 .707 r
F P
0 g
s
.14733 .72359 m .15326 .68768 L .1604 .67853 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15958 .66294 m .16505 .60823 L .1814 .60135 L p .707 .577 .707 r
F P
0 g
s
.1604 .67853 m .15447 .71443 L .14733 .72359 L p .707 .577 .707 r
F P
0 g
s
.66239 .28696 m .61329 .78099 L .59567 .76676 L p .707 .577 .707 r
F P
0 g
s
.59567 .76676 m .64477 .27273 L .66239 .28696 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14333 .76063 m .14664 .74278 L .1538 .73353 L p .707 .577 .707 r
F P
0 g
s
.34077 .75073 m .38988 .2567 L .41295 .24699 L p .707 .577 .707 r
F P
0 g
s
.38988 .2567 m .34077 .75073 L .33074 .76322 L p .707 .577 .707 r
F P
0 g
s
.1538 .73353 m .1505 .75138 L .14333 .76063 L p .707 .577 .707 r
F P
0 g
s
.1814 .60135 m .17593 .65606 L .15958 .66294 L p .707 .577 .707 r
F P
0 g
s
.15447 .71443 m .1604 .67853 L .17671 .67195 L p .707 .577 .707 r
F P
0 g
s
.17593 .65606 m .1814 .60135 L .20538 .59712 L p .707 .577 .707 r
F P
0 g
s
.17671 .67195 m .17078 .70786 L .15447 .71443 L p .707 .577 .707 r
F P
0 g
s
.1505 .75138 m .1538 .73353 L .17009 .72704 L p .707 .577 .707 r
F P
0 g
s
.32467 .61043 m .31921 .66514 L .2919 .65766 L p .707 .577 .707 r
F P
0 g
s
.2919 .65766 m .29737 .60295 L .32467 .61043 L p .707 .577 .707 r
F P
0 g
s
.20538 .59712 m .19991 .65183 L .17593 .65606 L p .707 .577 .707 r
F P
0 g
s
.64477 .27273 m .59567 .76676 L .56613 .75373 L p .707 .577 .707 r
F P
0 g
s
.56613 .75373 m .61524 .25971 L .64477 .27273 L p .707 .577 .707 r
F P
0 g
s
.17009 .72704 m .16678 .7449 L .1505 .75138 L p .707 .577 .707 r
F P
0 g
s
.19991 .65183 m .20538 .59712 L .23465 .59595 L p .707 .577 .707 r
F P
0 g
s
.17078 .70786 m .17671 .67195 L .20057 .6686 L p .707 .577 .707 r
F P
0 g
s
.41295 .24699 m .36385 .74101 L .34077 .75073 L p .707 .577 .707 r
F P
0 g
s
.36385 .74101 m .41295 .24699 L .44681 .241 L p .707 .577 .707 r
F P
0 g
s
.29737 .60295 m .2919 .65766 L .26088 .65267 L p .707 .577 .707 r
F P
0 g
s
.26088 .65267 m .26635 .59796 L .29737 .60295 L p .707 .577 .707 r
F P
0 g
s
.22918 .65066 m .23465 .59595 L .26635 .59796 L p .707 .577 .707 r
F P
0 g
s
.23465 .59595 m .22918 .65066 L .19991 .65183 L p .707 .577 .707 r
F P
0 g
s
.20057 .6686 m .19464 .70451 L .17078 .70786 L p .707 .577 .707 r
F P
0 g
s
.26635 .59796 m .26088 .65267 L .22918 .65066 L p .707 .577 .707 r
F P
0 g
s
.16678 .7449 m .17009 .72704 L .19391 .72396 L p .707 .577 .707 r
F P
0 g
s
.31895 .68885 m .31302 .72476 L .28597 .71536 L p .707 .577 .707 r
F P
0 g
s
.28597 .71536 m .2919 .67945 L .31895 .68885 L p .707 .577 .707 r
F P
0 g
s
.72724 .6612 m .73271 .60649 L .70169 .6015 L p .707 .577 .707 r
F P
0 g
s
.73271 .60649 m .72724 .6612 L .75894 .6632 L p .707 .577 .707 r
F P
0 g
s
.75894 .6632 m .76441 .6085 L .73271 .60649 L p .707 .577 .707 r
F P
0 g
s
.19464 .70451 m .20057 .6686 L .22966 .66881 L p .707 .577 .707 r
F P
0 g
s
.76441 .6085 m .75894 .6632 L .78821 .66204 L p .707 .577 .707 r
F P
0 g
s
.78821 .66204 m .79368 .60733 L .76441 .6085 L p .707 .577 .707 r
F P
0 g
s
.19391 .72396 m .19061 .74181 L .16678 .7449 L p .707 .577 .707 r
F P
0 g
s
.69622 .65621 m .70169 .6015 L .67439 .59402 L p .707 .577 .707 r
F P
0 g
s
.70169 .6015 m .69622 .65621 L .72724 .6612 L p .707 .577 .707 r
F P
0 g
s
.61524 .25971 m .56613 .75373 L .52758 .7432 L p .707 .577 .707 r
F P
0 g
s
.52758 .7432 m .57668 .24917 L .61524 .25971 L p .707 .577 .707 r
F P
0 g
s
.2919 .67945 m .28597 .71536 L .2552 .70845 L p .707 .577 .707 r
F P
0 g
s
.2552 .70845 m .26113 .67255 L .2919 .67945 L p .707 .577 .707 r
F P
0 g
s
.22966 .66881 m .22373 .70471 L .19464 .70451 L p .707 .577 .707 r
F P
0 g
s
.39771 .73503 m .44681 .241 L .48814 .23934 L p .707 .577 .707 r
F P
0 g
s
.44681 .241 m .39771 .73503 L .36385 .74101 L p .707 .577 .707 r
F P
0 g
s
.22373 .70471 m .22966 .66881 L .26113 .67255 L p .707 .577 .707 r
F P
0 g
s
.79368 .60733 m .78821 .66204 L .81219 .6578 L p .707 .577 .707 r
F P
0 g
s
.81219 .6578 m .81766 .6031 L .79368 .60733 L p .707 .577 .707 r
F P
0 g
s
.31193 .74626 m .30862 .76411 L .28167 .75415 L p .707 .577 .707 r
F P
0 g
s
.28167 .75415 m .28497 .73629 L .31193 .74626 L p .707 .577 .707 r
F P
0 g
s
.26113 .67255 m .2552 .70845 L .22373 .70471 L p .707 .577 .707 r
F P
0 g
s
.19061 .74181 m .19391 .72396 L .22293 .72457 L p .707 .577 .707 r
F P
0 g
s
.66892 .64873 m .67439 .59402 L .65347 .58478 L p .707 .577 .707 r
F P
0 g
s
.67439 .59402 m .66892 .64873 L .69622 .65621 L p .707 .577 .707 r
F P
0 g
s
.72106 .72464 m .72698 .68873 L .69622 .68183 L p .707 .577 .707 r
F P
0 g
s
.72698 .68873 m .72106 .72464 L .75252 .72838 L p .707 .577 .707 r
F P
0 g
s
.75252 .72838 m .75845 .69247 L .72698 .68873 L p .707 .577 .707 r
F P
0 g
s
.22293 .72457 m .21962 .74242 L .19061 .74181 L p .707 .577 .707 r
F P
0 g
s
.57668 .24917 m .52758 .7432 L .48379 .73618 L p .707 .577 .707 r
F P
0 g
s
.48379 .73618 m .53289 .24215 L .57668 .24917 L p .707 .577 .707 r
F P
0 g
s
.75845 .69247 m .75252 .72838 L .78162 .72858 L p .707 .577 .707 r
F P
0 g
s
.78162 .72858 m .78754 .69268 L .75845 .69247 L p .707 .577 .707 r
F P
0 g
s
.69029 .71773 m .69622 .68183 L .66917 .67243 L p .707 .577 .707 r
F P
0 g
s
.69622 .68183 m .69029 .71773 L .72106 .72464 L p .707 .577 .707 r
F P
0 g
s
.43904 .73336 m .48814 .23934 L .53289 .24215 L p .707 .577 .707 r
F P
0 g
s
.48814 .23934 m .43904 .73336 L .39771 .73503 L p .707 .577 .707 r
F P
0 g
s
.28497 .73629 m .28167 .75415 L .251 .74667 L p .707 .577 .707 r
F P
0 g
s
.251 .74667 m .25431 .72882 L .28497 .73629 L p .707 .577 .707 r
F P
0 g
s
.21962 .74242 m .22293 .72457 L .25431 .72882 L p .707 .577 .707 r
F P
0 g
s
.25431 .72882 m .251 .74667 L .21962 .74242 L p .707 .577 .707 r
F P
0 g
s
.53289 .24215 m .48379 .73618 L .43904 .73336 L p .707 .577 .707 r
F P
0 g
s
.81766 .6031 m .81219 .6578 L .82854 .65093 L p .707 .577 .707 r
F P
0 g
s
.82854 .65093 m .83401 .59622 L .81766 .6031 L p .707 .577 .707 r
F P
0 g
s
.65347 .58478 m .648 .63949 L .66892 .64873 L p .707 .577 .707 r
F P
0 g
s
.78754 .69268 m .78162 .72858 L .80548 .72523 L p .707 .577 .707 r
F P
0 g
s
.80548 .72523 m .81141 .68933 L .78754 .69268 L p .707 .577 .707 r
F P
0 g
s
.66917 .67243 m .66324 .70833 L .69029 .71773 L p .707 .577 .707 r
F P
0 g
s
.648 .63949 m .65347 .58478 L .64098 .57469 L p .707 .577 .707 r
F P
0 g
s
.66324 .70833 m .66917 .67243 L .64848 .66146 L p .707 .577 .707 r
F P
0 g
s
.71666 .76936 m .71996 .75151 L .6893 .74403 L p .707 .577 .707 r
F P
0 g
s
.71996 .75151 m .71666 .76936 L .74804 .77361 L p .707 .577 .707 r
F P
0 g
s
.74804 .77361 m .75134 .75576 L .71996 .75151 L p .707 .577 .707 r
F P
0 g
s
.75134 .75576 m .74804 .77361 L .77706 .77422 L p .707 .577 .707 r
F P
0 g
s
.77706 .77422 m .78036 .75637 L .75134 .75576 L p .707 .577 .707 r
F P
0 g
s
.68599 .76188 m .6893 .74403 L .66234 .73407 L p .707 .577 .707 r
F P
0 g
s
.6893 .74403 m .68599 .76188 L .71666 .76936 L p .707 .577 .707 r
F P
0 g
s
.66234 .73407 m .65904 .75192 L .68599 .76188 L p .707 .577 .707 r
F P
0 g
s
.64848 .66146 m .64255 .69736 L .66324 .70833 L p .707 .577 .707 r
F P
0 g
s
.64098 .57469 m .63552 .62939 L .648 .63949 L p .707 .577 .707 r
F P
0 g
s
.78036 .75637 m .77706 .77422 L .80088 .77113 L p .707 .577 .707 r
F P
0 g
s
.80088 .77113 m .80418 .75328 L .78036 .75637 L p .707 .577 .707 r
F P
0 g
s
.83401 .59622 m .82854 .65093 L .83565 .64207 L p .707 .577 .707 r
F P
0 g
s
.83565 .64207 m .84111 .58737 L .83401 .59622 L p .707 .577 .707 r
F P
0 g
s
.81141 .68933 m .80548 .72523 L .82179 .71866 L p .707 .577 .707 r
F P
0 g
s
.82179 .71866 m .82772 .68275 L .81141 .68933 L p .707 .577 .707 r
F P
0 g
s
.65904 .75192 m .66234 .73407 L .64174 .72258 L p .707 .577 .707 r
F P
0 g
s
.64255 .69736 m .64848 .66146 L .63618 .64999 L p .707 .577 .707 r
F P
0 g
s
.63552 .62939 m .64098 .57469 L .63816 .56473 L p .707 .577 .707 r
F P
0 g
s
.64174 .72258 m .63844 .74044 L .65904 .75192 L p .707 .577 .707 r
F P
0 g
s
.63618 .64999 m .63025 .68589 L .64255 .69736 L p .707 .577 .707 r
F P
0 g
s
.80418 .75328 m .80088 .77113 L .81717 .76465 L p .707 .577 .707 r
F P
0 g
s
.81717 .76465 m .82047 .7468 L .80418 .75328 L p .707 .577 .707 r
F P
0 g
s
.63844 .74044 m .64174 .72258 L .62951 .71071 L p .707 .577 .707 r
F P
0 g
s
.63816 .56473 m .63269 .61943 L .63552 .62939 L p .707 .577 .707 r
F P
0 g
s
.82772 .68275 m .82179 .71866 L .82893 .7095 L p .707 .577 .707 r
F P
0 g
s
.82893 .7095 m .83486 .6736 L .82772 .68275 L p .707 .577 .707 r
F P
0 g
s
.62951 .71071 m .62621 .72856 L .63844 .74044 L p .707 .577 .707 r
F P
0 g
s
.84111 .58737 m .83565 .64207 L .83282 .63211 L p .707 .577 .707 r
F P
0 g
s
.83282 .63211 m .83829 .57741 L .84111 .58737 L p .707 .577 .707 r
F P
0 g
s
.63025 .68589 m .63618 .64999 L .63347 .63915 L p .707 .577 .707 r
F P
0 g
s
.63269 .61943 m .63816 .56473 L .64527 .55587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63347 .63915 m .62754 .67505 L .63025 .68589 L p .707 .577 .707 r
F P
0 g
s
.82047 .7468 m .81717 .76465 L .82433 .7554 L p .707 .577 .707 r
F P
0 g
s
.82433 .7554 m .82763 .73755 L .82047 .7468 L p .707 .577 .707 r
F P
0 g
s
.62621 .72856 m .62951 .71071 L .62685 .6996 L p .707 .577 .707 r
F P
0 g
s
.64527 .55587 m .6398 .61058 L .63269 .61943 L p .707 .577 .707 r
F P
0 g
s
.62685 .6996 m .62355 .71746 L .62621 .72856 L p .707 .577 .707 r
F P
0 g
s
.83486 .6736 m .82893 .7095 L .82622 .69866 L p .707 .577 .707 r
F P
0 g
s
.82622 .69866 m .83215 .66275 L .83486 .6736 L p .707 .577 .707 r
F P
0 g
s
.62754 .67505 m .63347 .63915 L .64062 .62999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83829 .57741 m .83282 .63211 L .82034 .62202 L p .707 .577 .707 r
F P
0 g
s
.82034 .62202 m .82581 .56731 L .83829 .57741 L p .707 .577 .707 r
F P
0 g
s
.6398 .61058 m .64527 .55587 L .66161 .54899 L p .707 .577 .707 r
F P
0 g
s
.38423 .62151 m .3897 .56681 L .35868 .56182 L p .707 .577 .707 r
F P
0 g
s
.3897 .56681 m .38423 .62151 L .41593 .62352 L p .707 .577 .707 r
F P
0 g
s
.41593 .62352 m .4214 .56882 L .3897 .56681 L p .707 .577 .707 r
F P
0 g
s
.4214 .56882 m .41593 .62352 L .4452 .62235 L p .707 .577 .707 r
F P
0 g
s
.4452 .62235 m .45067 .56765 L .4214 .56882 L p .707 .577 .707 r
F P
0 g
s
.64062 .62999 m .63469 .66589 L .62754 .67505 L p .707 .577 .707 r
F P
0 g
s
.35321 .61653 m .35868 .56182 L .33138 .55434 L p .707 .577 .707 r
F P
0 g
s
.35868 .56182 m .35321 .61653 L .38423 .62151 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82763 .73755 m .82433 .7554 L .82166 .7443 L p .707 .577 .707 r
F P
0 g
s
.82166 .7443 m .82497 .72644 L .82763 .73755 L p .707 .577 .707 r
F P
0 g
s
.62355 .71746 m .62685 .6996 L .63401 .69036 L p .707 .577 .707 r
F P
0 g
s
.45067 .56765 m .4452 .62235 L .46918 .61812 L p .707 .577 .707 r
F P
0 g
s
.46918 .61812 m .47465 .56342 L .45067 .56765 L p .707 .577 .707 r
F P
0 g
s
.66161 .54899 m .65614 .6037 L .6398 .61058 L p .707 .577 .707 r
F P
0 g
s
.63401 .69036 m .63071 .70821 L .62355 .71746 L p .707 .577 .707 r
F P
0 g
s
.83215 .66275 m .82622 .69866 L .81392 .68719 L p .707 .577 .707 r
F P
0 g
s
.81392 .68719 m .81985 .65128 L .83215 .66275 L p .707 .577 .707 r
F P
0 g
s
.82581 .56731 m .82034 .62202 L .79942 .61278 L p .707 .577 .707 r
F P
0 g
s
.79942 .61278 m .80489 .55807 L .82581 .56731 L p .707 .577 .707 r
F P
0 g
s
.32591 .60905 m .33138 .55434 L .31046 .5451 L p .707 .577 .707 r
F P
0 g
s
.33138 .55434 m .32591 .60905 L .35321 .61653 L p .707 .577 .707 r
F P
0 g
s
.63469 .66589 m .64062 .62999 L .65692 .62342 L p .707 .577 .707 r
F P
0 g
s
.37805 .68114 m .38397 .64523 L .35321 .63833 L p .707 .577 .707 r
F P
0 g
s
.38397 .64523 m .37805 .68114 L .40951 .68488 L p .707 .577 .707 r
F P
0 g
s
.40951 .68488 m .41544 .64897 L .38397 .64523 L p .707 .577 .707 r
F P
0 g
s
.65614 .6037 m .66161 .54899 L .68559 .54476 L p .707 .577 .707 r
F P
0 g
s
.41544 .64897 m .40951 .68488 L .43861 .68508 L p .707 .577 .707 r
F P
0 g
s
.43861 .68508 m .44453 .64918 L .41544 .64897 L p .707 .577 .707 r
F P
0 g
s
.34728 .67423 m .35321 .63833 L .32616 .62893 L p .707 .577 .707 r
F P
0 g
s
.35321 .63833 m .34728 .67423 L .37805 .68114 L p .707 .577 .707 r
F P
0 g
s
.65692 .62342 m .65099 .65932 L .63469 .66589 L p .707 .577 .707 r
F P
0 g
s
.47465 .56342 m .46918 .61812 L .48553 .61125 L p .707 .577 .707 r
F P
0 g
s
.48553 .61125 m .491 .55654 L .47465 .56342 L p .707 .577 .707 r
F P
0 g
s
.31046 .5451 m .30499 .59981 L .32591 .60905 L p .707 .577 .707 r
F P
0 g
s
.82497 .72644 m .82166 .7443 L .80944 .73242 L p .707 .577 .707 r
F P
0 g
s
.80944 .73242 m .81274 .71457 L .82497 .72644 L p .707 .577 .707 r
F P
0 g
s
.63071 .70821 m .63401 .69036 L .6503 .68387 L p .707 .577 .707 r
F P
0 g
s
.44453 .64918 m .43861 .68508 L .46247 .68173 L p .707 .577 .707 r
F P
0 g
s
.46247 .68173 m .4684 .64583 L .44453 .64918 L p .707 .577 .707 r
F P
0 g
s
.32616 .62893 m .32023 .66483 L .34728 .67423 L p .707 .577 .707 r
F P
0 g
s
.80489 .55807 m .79942 .61278 L .77212 .6053 L p .707 .577 .707 r
F P
0 g
s
.77212 .6053 m .77758 .55059 L .80489 .55807 L p .707 .577 .707 r
F P
0 g
s
.30499 .59981 m .31046 .5451 L .29797 .53501 L p .707 .577 .707 r
F P
0 g
s
.37365 .72049 m .37695 .70264 L .34629 .69517 L p .707 .577 .707 r
F P
0 g
s
.37695 .70264 m .37365 .72049 L .40503 .72474 L p .707 .577 .707 r
F P
0 g
s
.40503 .72474 m .40833 .70689 L .37695 .70264 L p .707 .577 .707 r
F P
0 g
s
.68559 .54476 m .68013 .59947 L .65614 .6037 L p .707 .577 .707 r
F P
0 g
s
.32023 .66483 m .32616 .62893 L .30547 .61796 L p .707 .577 .707 r
F P
0 g
s
.81985 .65128 m .81392 .68719 L .79323 .67622 L p .707 .577 .707 r
F P
0 g
s
.79323 .67622 m .79916 .64031 L .81985 .65128 L p .707 .577 .707 r
F P
0 g
s
.68013 .59947 m .68559 .54476 L .71487 .5436 L p .707 .577 .707 r
F P
0 g
s
.40833 .70689 m .40503 .72474 L .43405 .72536 L p .707 .577 .707 r
F P
0 g
s
.43405 .72536 m .43735 .7075 L .40833 .70689 L p .707 .577 .707 r
F P
0 g
s
.6503 .68387 m .647 .70172 L .63071 .70821 L p .707 .577 .707 r
F P
0 g
s
.34298 .71302 m .34629 .69517 L .31933 .6852 L p .707 .577 .707 r
F P
0 g
s
.34629 .69517 m .34298 .71302 L .37365 .72049 L p .707 .577 .707 r
F P
0 g
s
.65099 .65932 m .65692 .62342 L .68079 .62007 L p .707 .577 .707 r
F P
0 g
s
.31933 .6852 m .31603 .70305 L .34298 .71302 L p .707 .577 .707 r
F P
0 g
s
.30547 .61796 m .29954 .65386 L .32023 .66483 L p .707 .577 .707 r
F P
0 g
s
.77758 .55059 m .77212 .6053 L .7411 .60031 L p .707 .577 .707 r
F P
0 g
s
.7411 .60031 m .74656 .5456 L .77758 .55059 L p .707 .577 .707 r
F P
0 g
s
.7094 .5983 m .71487 .5436 L .74656 .5456 L p .707 .577 .707 r
F P
0 g
s
.71487 .5436 m .7094 .5983 L .68013 .59947 L p .707 .577 .707 r
F P
0 g
s
.29797 .53501 m .29251 .58971 L .30499 .59981 L p .707 .577 .707 r
F P
0 g
s
.43735 .7075 m .43405 .72536 L .45787 .72227 L p .707 .577 .707 r
F P
0 g
s
.45787 .72227 m .46117 .70441 L .43735 .7075 L p .707 .577 .707 r
F P
0 g
s
.68079 .62007 m .67486 .65597 L .65099 .65932 L p .707 .577 .707 r
F P
0 g
s
.31603 .70305 m .31933 .6852 L .29873 .67372 L p .707 .577 .707 r
F P
0 g
s
.4684 .64583 m .46247 .68173 L .47878 .67516 L p .707 .577 .707 r
F P
0 g
s
.47878 .67516 m .48471 .63925 L .4684 .64583 L p .707 .577 .707 r
F P
0 g
s
.74656 .5456 m .7411 .60031 L .7094 .5983 L p .707 .577 .707 r
F P
0 g
s
.491 .55654 m .48553 .61125 L .49264 .60239 L p .707 .577 .707 r
F P
0 g
s
.49264 .60239 m .4981 .54769 L .491 .55654 L p .707 .577 .707 r
F P
0 g
s
.29954 .65386 m .30547 .61796 L .29317 .60649 L p .707 .577 .707 r
F P
0 g
s
.81274 .71457 m .80944 .73242 L .78884 .72094 L p .707 .577 .707 r
F P
0 g
s
.78884 .72094 m .79214 .70309 L .81274 .71457 L p .707 .577 .707 r
F P
0 g
s
.79916 .64031 m .79323 .67622 L .76618 .66682 L p .707 .577 .707 r
F P
0 g
s
.76618 .66682 m .77211 .63092 L .79916 .64031 L p .707 .577 .707 r
F P
0 g
s
.647 .70172 m .6503 .68387 L .67412 .68078 L p .707 .577 .707 r
F P
0 g
s
.29873 .67372 m .29543 .69157 L .31603 .70305 L p .707 .577 .707 r
F P
0 g
s
.67486 .65597 m .68079 .62007 L .70988 .62027 L p .707 .577 .707 r
F P
0 g
s
.29251 .58971 m .29797 .53501 L .29515 .52505 L p .707 .577 .707 r
F P
0 g
s
.67412 .68078 m .67082 .69864 L .647 .70172 L p .707 .577 .707 r
F P
0 g
s
.29317 .60649 m .28724 .64239 L .29954 .65386 L p .707 .577 .707 r
F P
0 g
s
.77211 .63092 m .76618 .66682 L .73542 .65991 L p .707 .577 .707 r
F P
0 g
s
.73542 .65991 m .74135 .62401 L .77211 .63092 L p .707 .577 .707 r
F P
0 g
s
.46117 .70441 m .45787 .72227 L .47416 .71578 L p .707 .577 .707 r
F P
0 g
s
.47416 .71578 m .47746 .69793 L .46117 .70441 L p .707 .577 .707 r
F P
0 g
s
.70988 .62027 m .70395 .65618 L .67486 .65597 L p .707 .577 .707 r
F P
0 g
s
.70395 .65618 m .70988 .62027 L .74135 .62401 L p .707 .577 .707 r
F P
0 g
s
.29543 .69157 m .29873 .67372 L .2865 .66184 L p .707 .577 .707 r
F P
0 g
s
.74135 .62401 m .73542 .65991 L .70395 .65618 L p .707 .577 .707 r
F P
0 g
s
.79214 .70309 m .78884 .72094 L .76188 .71097 L p .707 .577 .707 r
F P
0 g
s
.76188 .71097 m .76519 .69312 L .79214 .70309 L p .707 .577 .707 r
F P
0 g
s
.29515 .52505 m .28968 .57975 L .29251 .58971 L p .707 .577 .707 r
F P
0 g
s
.48471 .63925 m .47878 .67516 L .48592 .666 L p .707 .577 .707 r
F P
0 g
s
.48592 .666 m .49185 .6301 L .48471 .63925 L p .707 .577 .707 r
F P
0 g
s
.67082 .69864 m .67412 .68078 L .70314 .6814 L p .707 .577 .707 r
F P
0 g
s
.2865 .66184 m .2832 .6797 L .29543 .69157 L p .707 .577 .707 r
F P
0 g
s
.28724 .64239 m .29317 .60649 L .29046 .59565 L p .707 .577 .707 r
F P
0 g
s
.4981 .54769 m .49264 .60239 L .48981 .59243 L p .707 .577 .707 r
F P
0 g
s
.48981 .59243 m .49528 .53773 L .4981 .54769 L p .707 .577 .707 r
F P
0 g
s
.70314 .6814 m .69984 .69925 L .67082 .69864 L p .707 .577 .707 r
F P
0 g
s
.28968 .57975 m .29515 .52505 L .30226 .51619 L p .707 .577 .707 r
F P
0 g
s
.76519 .69312 m .76188 .71097 L .73122 .7035 L p .707 .577 .707 r
F P
0 g
s
.73122 .7035 m .73452 .68565 L .76519 .69312 L p .707 .577 .707 r
F P
0 g
s
.69984 .69925 m .70314 .6814 L .73452 .68565 L p .707 .577 .707 r
F P
0 g
s
.29046 .59565 m .28453 .63155 L .28724 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73452 .68565 m .73122 .7035 L .69984 .69925 L p .707 .577 .707 r
F P
0 g
s
.47746 .69793 m .47416 .71578 L .48132 .70654 L p .707 .577 .707 r
F P
0 g
s
.48132 .70654 m .48462 .68868 L .47746 .69793 L p .707 .577 .707 r
F P
0 g
s
.2832 .6797 m .2865 .66184 L .28384 .65074 L p .707 .577 .707 r
F P
0 g
s
.28384 .65074 m .28054 .66859 L .2832 .6797 L p .707 .577 .707 r
F P
0 g
s
.30226 .51619 m .29679 .5709 L .28968 .57975 L p .707 .577 .707 r
F P
0 g
s
.49185 .6301 m .48592 .666 L .48321 .65516 L p .707 .577 .707 r
F P
0 g
s
.48321 .65516 m .48914 .61925 L .49185 .6301 L p .707 .577 .707 r
F P
0 g
s
.28453 .63155 m .29046 .59565 L .29761 .58649 L p .707 .577 .707 r
F P
0 g
s
.49528 .53773 m .48981 .59243 L .47733 .58234 L p .707 .577 .707 r
F P
0 g
s
.47733 .58234 m .4828 .52763 L .49528 .53773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29679 .5709 m .30226 .51619 L .3186 .50931 L p .707 .577 .707 r
F P
0 g
s
.29761 .58649 m .29168 .62239 L .28453 .63155 L p .707 .577 .707 r
F P
0 g
s
.48462 .68868 m .48132 .70654 L .47865 .69543 L p .707 .577 .707 r
F P
0 g
s
.47865 .69543 m .48196 .67758 L .48462 .68868 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28054 .66859 m .28384 .65074 L .291 .64149 L p .707 .577 .707 r
F P
0 g
s
.291 .64149 m .2877 .65934 L .28054 .66859 L p .707 .577 .707 r
F P
0 g
s
.3186 .50931 m .31313 .56402 L .29679 .5709 L p .707 .577 .707 r
F P
0 g
s
.48914 .61925 m .48321 .65516 L .47091 .64369 L p .707 .577 .707 r
F P
0 g
s
.47091 .64369 m .47684 .60778 L .48914 .61925 L p .707 .577 .707 r
F P
0 g
s
.4828 .52763 m .47733 .58234 L .45641 .5731 L p .707 .577 .707 r
F P
0 g
s
.45641 .5731 m .46188 .51839 L .4828 .52763 L p .707 .577 .707 r
F P
0 g
s
.29168 .62239 m .29761 .58649 L .31391 .57991 L p .707 .577 .707 r
F P
0 g
s
.31313 .56402 m .3186 .50931 L .34258 .50508 L p .707 .577 .707 r
F P
0 g
s
.31391 .57991 m .30798 .61582 L .29168 .62239 L p .707 .577 .707 r
F P
0 g
s
.48196 .67758 m .47865 .69543 L .46642 .68356 L p .707 .577 .707 r
F P
0 g
s
.46642 .68356 m .46973 .6657 L .48196 .67758 L p .707 .577 .707 r
F P
0 g
s
.2877 .65934 m .291 .64149 L .30729 .63501 L p .707 .577 .707 r
F P
0 g
s
.46188 .51839 m .45641 .5731 L .42911 .56562 L p .707 .577 .707 r
F P
0 g
s
.42911 .56562 m .43457 .51091 L .46188 .51839 L p .707 .577 .707 r
F P
0 g
s
.34258 .50508 m .33712 .55979 L .31313 .56402 L p .707 .577 .707 r
F P
0 g
s
.47684 .60778 m .47091 .64369 L .45022 .63272 L p .707 .577 .707 r
F P
0 g
s
.45022 .63272 m .45615 .59681 L .47684 .60778 L p .707 .577 .707 r
F P
0 g
s
.30729 .63501 m .30399 .65286 L .2877 .65934 L p .707 .577 .707 r
F P
0 g
s
.33712 .55979 m .34258 .50508 L .37186 .50391 L p .707 .577 .707 r
F P
0 g
s
.30798 .61582 m .31391 .57991 L .33778 .57657 L p .707 .577 .707 r
F P
0 g
s
.43457 .51091 m .42911 .56562 L .39809 .56063 L p .707 .577 .707 r
F P
0 g
s
.39809 .56063 m .40355 .50592 L .43457 .51091 L p .707 .577 .707 r
F P
0 g
s
.36639 .55862 m .37186 .50391 L .40355 .50592 L p .707 .577 .707 r
F P
0 g
s
.37186 .50391 m .36639 .55862 L .33712 .55979 L p .707 .577 .707 r
F P
0 g
s
.33778 .57657 m .33185 .61247 L .30798 .61582 L p .707 .577 .707 r
F P
0 g
s
.40355 .50592 m .39809 .56063 L .36639 .55862 L p .707 .577 .707 r
F P
0 g
s
.46973 .6657 m .46642 .68356 L .44583 .67207 L p .707 .577 .707 r
F P
0 g
s
.44583 .67207 m .44913 .65422 L .46973 .6657 L p .707 .577 .707 r
F P
0 g
s
.30399 .65286 m .30729 .63501 L .33111 .63192 L p .707 .577 .707 r
F P
0 g
s
.45615 .59681 m .45022 .63272 L .42317 .62332 L p .707 .577 .707 r
F P
0 g
s
.42317 .62332 m .4291 .58742 L .45615 .59681 L p .707 .577 .707 r
F P
0 g
s
.33185 .61247 m .33778 .57657 L .36687 .57677 L p .707 .577 .707 r
F P
0 g
s
.33111 .63192 m .32781 .64977 L .30399 .65286 L p .707 .577 .707 r
F P
0 g
s
.4291 .58742 m .42317 .62332 L .39241 .61641 L p .707 .577 .707 r
F P
0 g
s
.39241 .61641 m .39834 .58051 L .4291 .58742 L p .707 .577 .707 r
F P
0 g
s
.36687 .57677 m .36094 .61267 L .33185 .61247 L p .707 .577 .707 r
F P
0 g
s
.36094 .61267 m .36687 .57677 L .39834 .58051 L p .707 .577 .707 r
F P
0 g
s
.44913 .65422 m .44583 .67207 L .41887 .66211 L p .707 .577 .707 r
F P
0 g
s
.41887 .66211 m .42218 .64426 L .44913 .65422 L p .707 .577 .707 r
F P
0 g
s
.39834 .58051 m .39241 .61641 L .36094 .61267 L p .707 .577 .707 r
F P
0 g
s
.32781 .64977 m .33111 .63192 L .36013 .63253 L p .707 .577 .707 r
F P
0 g
s
.36013 .63253 m .35683 .65038 L .32781 .64977 L p .707 .577 .707 r
F P
0 g
s
.42218 .64426 m .41887 .66211 L .38821 .65463 L p .707 .577 .707 r
F P
0 g
s
.38821 .65463 m .39151 .63678 L .42218 .64426 L p .707 .577 .707 r
F P
0 g
s
.35683 .65038 m .36013 .63253 L .39151 .63678 L p .707 .577 .707 r
F P
0 g
s
.39151 .63678 m .38821 .65463 L .35683 .65038 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007eooad008=o
o`00N7oo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH01P00OGoo001dOol40007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001hOol0079oo`800003FUH005YF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Aoo`00L7oo
0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000L7oo001^Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001]Ool006eoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001[Ool006aoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEUYFFUH2001YOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH2001W
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001UOol006]oo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP8006Aoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000069oo`00Jgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00D005YFFUIJEP00065oo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00Ggoo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001Z
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001ZOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<007ooOol0GGoo001ZOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006Yoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF0000Ggoo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUIoo`1OOol006Uoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EWoo05moo`00JGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05mo
o`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05moo`00JGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000H7oo001YOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH0001POol006Uoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0H7oo001Y
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1POol006Qoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo061oo`00J7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
065oo`00J7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00065oo`00J7oo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0HGoo001XOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIoo`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH00`00FUH0001ROol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001SOol006Moo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001V
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001UOol005iooaL000=JEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00FGoo
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol0
05Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001V
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000:Ool?
001=Ool005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP02FUH90014Ool0
05=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20004Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH6000nOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol0059oo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH2000hOol0059oo`03001JEP0000AJEP04001JEUYFFUH;0004FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo00<005YF00000eYF1@0000=J
EP00FUH01EYF00<005YFFUH01@0000=JEP0000000`000UYF1P001UYF00<005YFFUH015YF00D005YF
FUH005YF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008003Aoo`00DWoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF
00AJEQ<0009JEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`06001J
EP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF0`001EYF
00H005YFFUIJEP00FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000aOol0059oo`8000=JEP03001JEUYF00=JEPL00003FUH005YF00MJEP@0
00EJEP03001JEUYF00IJEP04001JEP000003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002mo
o`00DWoo0P000eYF1P000eYF00@005YFFUIJEPT00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001BOol20002FUH200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH20003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH00`00FUH00002FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH4000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002eo
o`00>Goo3P002goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF009JEPT0009oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF
00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH0
1000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool0
035oo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
008000AJEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30003
FUH500000eYF001JEP05FUH60004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0017oo10001UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF10000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@00003
FUH0000000X0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003FUH5000015YF001JEUYF0P0000=oo`0000001@000UYF1`001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH000040003FUH00`00FUIJEP02FUH200000eYF001JEP03FUH=0002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH@00000eYF001JEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP030006
FUH00`00FUH00005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUH000030003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH02000FUIJ
EP00FUH005YF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF009JEP<000AJEP8000IJEP03001JEUYF009J
EP<0009JEP03001JEUYF00=JEP@00003FUH005YF00EJEP03001JEUYF009JEP8000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001oo`0]
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000=JEP03001JEUYF009JEPh00003FUH005YF009JEPD00003FUH005YF00QJ
EP8000IJEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEPH000=JEP03001J
EUYF00EJEP03001JEUYF00@00003FUH0000000<00003FUH005YF00UJEP<000AJEP04001JEUYFFUH3
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJ
EP03001JEUYF009JEP8002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1P0000=JEP00FUH02EYF00@005YFFUH0009JEP03001JEUYF009JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001J
EP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
2EYF00@005YFFUIJEP<000AJEP<000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP8000=JEP07001JEUYFFUH005YF0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH01000FUIJEUYF100015YF0`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF0P00<7oo000[Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0003FUH01000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YF00001`000eYF0P000UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF0P00<7oo000[Ool00`00FUH00004FUH01000FUIJEUYF5P0015YF0P000eYF1@0000=JEP00
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEP00
00@000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP@0035oo`00:goo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH01000
0Woo2`0000AJEP00001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH005YF009JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000bOol002]oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH?0004FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1EYF0`000UYF00@005YFFUIJEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000003FUH60004FUH20004Ool400000eYF000000040006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH0000aOol002]oo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF1@000eYF0`000UYF100000AJEP00000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0
00IJEP03001JEUYF00<000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01@00FUIJEP00FUH00`0015YF00<005YFFUH00eYF0P001goo2`000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF100015YF10001EYF1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEP8000=JEP03001JEUYF00=JEP80009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH30002FUH00`00FUIJEP03FUH01000
FUH000002Woo0`000goo10001eYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF
00<005YFFUH00eYF400000=JEP00FUH01UYF00D005YF001JEP0000EJEP03001JEUYF00D00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00EJEP800005FUH00000FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP030005
FUH01@00FUIJEUYF000027oo1@001Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEP8002moo`00
:goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF0P000eYF00D005YFFUIJ
EP0000IJEPH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP03001JEP0000800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00=J
EP<000=JEP05001JEUYFFUH00008Ool50008Ool300000eYF001JEP05FUH01P00FUIJEP00FUH002mo
o`00:goo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00001000
0eYF0`0000=JEP00FUH01EYF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP8000Moo`D000]o
o`8000IJEP06001JEUYF001JEP00;goo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0P001UYF0P0000=JEP00FUH01EYF
2@000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00=JEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEQ0000Eoo`<000io
o`8000=JEP07001JEUYFFUH005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30002FUH01@00FUH005YF00001UYF
00<005YFFUH00UYF4P000eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0`000eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P004Woo0P0000=JEP00FUH0
0UYF0P00<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000015YF001JEP001EYF00<005YFFUH00eYF1@002UYF00<0
05YFFUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P004Goo0P000eYF0P00
<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH01000FUIJEUYF0`0000=JEP00FUH015YF00<005YFFUH00eYF1@002UYF00<005YFFUH0
1UYF1@002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF500000AJEP00FUH0
031oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YF000000=JEP03001JEUYF00EJEP@000=JEP03001JEUYF00AJEP@000YJEP03001JEUYF
00QJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo02moo`00:Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1eYF00<005YFFUH010002EYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP00009JEP04001JEUYFFUH>
0006FUH00`00FUIJEP07FUH00`00FUH000040006FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`001eYF00<005YFFUH015YF1@0015YF00<005YFFUH025YF00<005YFFUH01EYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF000000=J
EP@00003FUH005YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00=JEP03001JEUYF009JEP80035oo`00:Woo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP07FUH00`00FUIJEP05000:FUH0
0`00FUIJEP050002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF1@001UYF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF0P00<Goo000ZOol20003FUH50007Ool70002FUH70006FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00
00=JEP0000001EYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<Goo000ZOol00eYF001JEP05000@Ool=0002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30007
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00<005YFFUH00UYF
0P000UYF0P00<Woo000YOol01000FUH000000UYF00@005YFFUH001Qoo`P000IJEP03001JEUYF00=J
EP03001JEP00009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0006FUH00`00FUIJEP03FUH300000eYF001JEP07FUH01000FUIJEUYF0`000UYF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP04001JEP00000bOol002Uoo`<000=JEP04001JEUYFFUH2000NOol20003
FUH00`00FUIJEP04FUH00`00FUH00006FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00000015YF00<005YFFUH00eYF00<005YFFUH00`001UYF00@005YFFUIJEPD00003FUH005YF
00AJEP<00003FUH005YF00EJEP<003=oo`00:Goo00<005YF00000eYF00<005YFFUH00UYF1`003Goo
0`002Woo0P0000=JEP00FUH01EYF00<005YF00001EYF00<005YFFUH00eYF10000UYF00<005YFFUH0
1EYF00@005YFFUIJEPD000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF1P00
25YF0`001UYF00<005YF0000<goo000YOol00`00FUIJEP03FUH50003FUH01000FUIJEUYF2@000goo
1@002goo0P001UYF00<005YF00001EYF00<005YFFUH01eYF3P002UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF10001UYF00<005YFFUH00UYF0P000goo
300025YF00<005YFFUH00P000eYF00D005YFFUIJEP00039oo`00:Woo00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF20003Goo0P000eYF0P001eYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00P001EYF00L005YFFUIJEP00FUH0000:OolA
00001Goo000005YF00000eYF00<007ooOol0<7oo000ZOol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH00eYF30001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF0000009JEP03001JEUYF00=JEP<0009JEP07001JEUYFFUH005YF00007Woo0P00
0eYF0P00<Goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH40008Ool400000eYF001JEP05FUH00`00FUIJEP03FUH:0002FUH00`00FUIJEP07FUH9
0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001UYF00@0
05YF000000AJEP80025oo`05001JEP00FUH0000aOol002Yoo`8000=JEP04001JEUYFFUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000070003FUH00`00FUH00005FUH700000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01`00FUH005YF001JEP0000IJEP04001JEUYFFUH20002FUH2000ROol200000eYF
001oo`0`Ool002Uoo`8000=JEPD00003FUH005YF00AJEPT000AJEP03001JEUYF00MJEP04001JEUYF
FUH30006FUH00`00FUH00003FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH50009FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH00`00FUIJ
EP04FUH4000SOol00`00FUH0000aOol002Uoo`800004FUH000000005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH70006FUH00`00FUIJEP04FUH20004FUH200000eYF001JEP0200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH40005FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP04
000NOol3000bOol002Uoo`<000=oo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP@0009JEP03001JEUYF00EJEP<0009JEP800003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@00003FUH005YF00MJEP03
001JEUYF00=JEP800003FUH005YF00IJEP<000IJEP03001JEUYF00AJEPL001Eoo`800003FUH00000
039oo`00:7oo0`001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF
00<005YFFUH01P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF10001eYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00@005YF000000=J
EP03001JEUYF00MJEP03001JEUYF009JEPP000Qoo`D000=JEP80039oo`00:7oo10001goo0`001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP@000AJEP03
001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04
001JEUYFFUH20005FUH00`00FUIJEP03FUH50007FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<0
05YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000cOol002Qoo`05001JEP00FUH00009
Ool400000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH20003Ool20004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<goo000XOol2
0003FUH00`00Oomoo`0:Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20006FUH20005FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUH00005Ool300000eYF001JEP05FUH00`00FUIJ
EP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00=7oo
000YOol01000FUIJEUYF0`003Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0P000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YF000027oo0P001UYF00H005YFFUH005YF
0002Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000=Woo000YOol01@00FUIJ
EUYF00000UYF00<007ooOol03goo2@000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
000000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH0000:Ool20003FUH01`00FUIJEUYF
001JEP0000Uoo`P000AJEP04001JEUYFFUH5000hOol002Yoo`03001JEP0000AJEP8001AooaL00003
FUH005YF00aJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH2000015YF001JEP0037oo0P0000=JEP00FUH00UYF0P004Woo2000
?Goo000[Ool20006FUH2000BOol5000BOol2000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000?Ool20003FUH2001G
Ool002aoo`03001JEUYF00AJEP03001JEP0000<000ioo`D001=oo`8000aJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00aoo`H00004FUH005YF001GOol002eoo`8000AJEP03001JEUYF00=JEPD000Yoo`<001Eoo`<001EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF00=JEPl000=J
EP03001JEUYF00800003FUH007oo05Ioo`00;goo00@005YFFUH000QJEP03001JEUYF00@001ioo`@0
01AJEP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEP000002FUH01000FUH000000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001GOol0031o
o`<000QJEP03001JEUYF00AJEPD001Moo`@0009oo`80019JEP03001JEUYF00UJEP03001JEUYF00UJ
EP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF
00<005YFFUH00UYF0P00F7oo000bOol20006FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002
FUH20004Ool2000LFUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01P00FUIJEP00FUH000MJEP8000=JEP03001JEUYF009JEP8005Qoo`00=7oo10000UYF00<005YF
FUH01eYF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0006Ool3000IFUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP06FUH3
00000eYF001JEP03FUH2001HOol003Qoo`@000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF008000Yoo`<002=JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH00000008000MJEP03001JEUYF008000=JEP8005Uoo`00?7oo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000ioo`@001iJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH20004FUH00`00FUIJEP03FUH2
00000eYF0000001IOol003moo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000COol4000JFUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`000UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0`00FWoo0012Ool60004FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@006Goo10005UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001P0025YF0`001UYF
00<005YF0000FWoo0018Ool@000ROol6000@FUH00`00FUIJEP09FUH00`00FUIJEP05FUH;0008FUH0
0`00FUIJEP020003FUH01@00FUIJEUYF0000FGoo0020Ool:0006FUH00`00FUIJEP09FUH00`00FUIJ
EP050005OolB00001Goo000005YF00000eYF00<007ooOol0Egoo002:OolE000;Ool3000AOol20003
FUH2001HOol008eoo`8000IJEP04001JEP00000WOol01@00FUH005YF0000F7oo002>Ool00`00FUIJ
EP04FUH01000FUIJEUYF0P009Woo0P0000=JEP00Ool0Egoo002?Ool20003FUH00`00FUIJEP04FUH4
000SOol00`00FUH0001HOol0095oo`800003FUH005YF00IJEP03001JEUYF00@001ioo`<005Uoo`00
Tgoo0`001UYF00<005YFFUH015YF1@005goo0P0000=JEP000000FGoo002FOol20003FUH00`00FUIJ
EP07FUH00`00FUIJEP04000>Ool50003FUH2001IOol009Qoo`800003FUH005YF00QJEP03001JEUYF
00AJEPh000=JEP04001JEUYFFUH2001JOol009Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2001JOol009ioo`@0009JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2001KOol00:9oo`D000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001MOol00:Moo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001OOol0
0:]oo`h006Aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58613 .75537 m .59496 .70149 L .56418 .69463 L p .707 .577 .707 r
F P
0 g
s
.59496 .70149 m .58613 .75537 L .61761 .75907 L p .707 .577 .707 r
F P
0 g
s
.61761 .75907 m .62643 .7052 L .59496 .70149 L p .707 .577 .707 r
F P
0 g
s
.62643 .7052 m .61761 .75907 L .6467 .75925 L p .707 .577 .707 r
F P
0 g
s
.6467 .75925 m .65553 .70537 L .62643 .7052 L p .707 .577 .707 r
F P
0 g
s
.55536 .7485 m .56418 .69463 L .53713 .68527 L p .707 .577 .707 r
F P
0 g
s
.56418 .69463 m .55536 .7485 L .58613 .75537 L p .707 .577 .707 r
F P
0 g
s
.65553 .70537 m .6467 .75925 L .67057 .75588 L p .707 .577 .707 r
F P
0 g
s
.67057 .75588 m .67939 .702 L .65553 .70537 L p .707 .577 .707 r
F P
0 g
s
.5283 .73915 m .53713 .68527 L .51643 .67434 L p .707 .577 .707 r
F P
0 g
s
.53713 .68527 m .5283 .73915 L .55536 .7485 L p .707 .577 .707 r
F P
0 g
s
.5759 .82053 m .58542 .78584 L .55531 .77595 L p .707 .577 .707 r
F P
0 g
s
.58542 .78584 m .5759 .82053 L .60678 .82697 L p .707 .577 .707 r
F P
0 g
s
.60678 .82697 m .6163 .79228 L .58542 .78584 L p .707 .577 .707 r
F P
0 g
s
.54579 .81064 m .55531 .77595 L .52891 .76356 L p .707 .577 .707 r
F P
0 g
s
.55531 .77595 m .54579 .81064 L .5759 .82053 L p .707 .577 .707 r
F P
0 g
s
.6163 .79228 m .60678 .82697 L .6354 .82931 L p .707 .577 .707 r
F P
0 g
s
.6354 .82931 m .64492 .79462 L .6163 .79228 L p .707 .577 .707 r
F P
0 g
s
.51643 .67434 m .50761 .72821 L .5283 .73915 L p .707 .577 .707 r
F P
0 g
s
.67939 .702 m .67057 .75588 L .68688 .7493 L p .707 .577 .707 r
F P
0 g
s
.68688 .7493 m .6957 .69542 L .67939 .702 L p .707 .577 .707 r
F P
0 g
s
.50761 .72821 m .51643 .67434 L .50413 .6629 L p .707 .577 .707 r
F P
0 g
s
.51939 .79825 m .52891 .76356 L .50881 .74989 L p .707 .577 .707 r
F P
0 g
s
.52891 .76356 m .51939 .79825 L .54579 .81064 L p .707 .577 .707 r
F P
0 g
s
.64492 .79462 m .6354 .82931 L .65896 .82734 L p .707 .577 .707 r
F P
0 g
s
.65896 .82734 m .66849 .79265 L .64492 .79462 L p .707 .577 .707 r
F P
0 g
s
.56867 .8671 m .57397 .84997 L .54412 .83919 L p .707 .577 .707 r
F P
0 g
s
.57397 .84997 m .56867 .8671 L .59932 .87433 L p .707 .577 .707 r
F P
0 g
s
.59932 .87433 m .60461 .85721 L .57397 .84997 L p .707 .577 .707 r
F P
0 g
s
.53882 .85632 m .54412 .83919 L .51798 .82592 L p .707 .577 .707 r
F P
0 g
s
.54412 .83919 m .53882 .85632 L .56867 .8671 L p .707 .577 .707 r
F P
0 g
s
.60461 .85721 m .59932 .87433 L .62776 .87731 L p .707 .577 .707 r
F P
0 g
s
.62776 .87731 m .63305 .86019 L .60461 .85721 L p .707 .577 .707 r
F P
0 g
s
.50881 .74989 m .49929 .78458 L .51939 .79825 L p .707 .577 .707 r
F P
0 g
s
.50413 .6629 m .4953 .71677 L .50761 .72821 L p .707 .577 .707 r
F P
0 g
s
.51798 .82592 m .51268 .84305 L .53882 .85632 L p .707 .577 .707 r
F P
0 g
s
.6957 .69542 m .68688 .7493 L .69403 .74015 L p .707 .577 .707 r
F P
0 g
s
.69403 .74015 m .70285 .68627 L .6957 .69542 L p .707 .577 .707 r
F P
0 g
s
.49929 .78458 m .50881 .74989 L .49698 .73628 L p .707 .577 .707 r
F P
0 g
s
.51268 .84305 m .51798 .82592 L .49811 .81146 L p .707 .577 .707 r
F P
0 g
s
.66849 .79265 m .65896 .82734 L .67516 .82124 L p .707 .577 .707 r
F P
0 g
s
.67516 .82124 m .68469 .78655 L .66849 .79265 L p .707 .577 .707 r
F P
0 g
s
.4953 .71677 m .50413 .6629 L .50141 .65207 L p .707 .577 .707 r
F P
0 g
s
.63305 .86019 m .62776 .87731 L .6512 .87574 L p .707 .577 .707 r
F P
0 g
s
.6512 .87574 m .6565 .85862 L .63305 .86019 L p .707 .577 .707 r
F P
0 g
s
.49811 .81146 m .49281 .82858 L .51268 .84305 L p .707 .577 .707 r
F P
0 g
s
.49698 .73628 m .48746 .77098 L .49929 .78458 L p .707 .577 .707 r
F P
0 g
s
.49281 .82858 m .49811 .81146 L .48646 .79722 L p .707 .577 .707 r
F P
0 g
s
.50141 .65207 m .49259 .70595 L .4953 .71677 L p .707 .577 .707 r
F P
0 g
s
.44794 .82092 m .52717 .33431 L .48372 .32466 L p .707 .577 .707 r
F P
0 g
s
.48746 .77098 m .49698 .73628 L .49457 .72407 L p .707 .577 .707 r
F P
0 g
s
.48646 .79722 m .48117 .81434 L .49281 .82858 L p .707 .577 .707 r
F P
0 g
s
.49259 .70595 m .50141 .65207 L .50856 .64292 L p .707 .577 .707 r
F P
0 g
s
.49457 .72407 m .48505 .75876 L .48746 .77098 L p .707 .577 .707 r
F P
0 g
s
.48117 .81434 m .48646 .79722 L .48417 .78459 L p .707 .577 .707 r
F P
0 g
s
.50856 .64292 m .49974 .6968 L .49259 .70595 L p .707 .577 .707 r
F P
0 g
s
.48417 .78459 m .47888 .80172 L .48117 .81434 L p .707 .577 .707 r
F P
0 g
s
.48505 .75876 m .49457 .72407 L .50182 .71444 L p .707 .577 .707 r
F P
0 g
s
.49974 .6968 m .50856 .64292 L .52486 .63634 L p .707 .577 .707 r
F P
0 g
s
.50182 .71444 m .4923 .74913 L .48505 .75876 L p .707 .577 .707 r
F P
0 g
s
.47888 .80172 m .48417 .78459 L .49147 .77482 L p .707 .577 .707 r
F P
0 g
s
.52486 .63634 m .51604 .69022 L .49974 .6968 L p .707 .577 .707 r
F P
0 g
s
.49147 .77482 m .48617 .79195 L .47888 .80172 L p .707 .577 .707 r
F P
0 g
s
.4923 .74913 m .50182 .71444 L .51802 .70833 L p .707 .577 .707 r
F P
0 g
s
.51802 .70833 m .5085 .74303 L .4923 .74913 L p .707 .577 .707 r
F P
0 g
s
.48617 .79195 m .49147 .77482 L .50763 .76886 L p .707 .577 .707 r
F P
0 g
s
.50763 .76886 m .50233 .78598 L .48617 .79195 L p .707 .577 .707 r
F P
0 g
s
.52717 .33431 m .44794 .82092 L .49238 .82611 L p .707 .577 .707 r
F P
0 g
s
.49238 .82611 m .57161 .33951 L .52717 .33431 L p .707 .577 .707 r
F P
0 g
s
.6565 .85862 m .6512 .87574 L .66736 .86978 L p .707 .577 .707 r
F P
0 g
s
.66736 .86978 m .67266 .85266 L .6565 .85862 L p .707 .577 .707 r
F P
0 g
s
.51604 .69022 m .52486 .63634 L .54873 .63297 L p .707 .577 .707 r
F P
0 g
s
.54873 .63297 m .53991 .68685 L .51604 .69022 L p .707 .577 .707 r
F P
0 g
s
.53991 .68685 m .54873 .63297 L .57783 .63315 L p .707 .577 .707 r
F P
0 g
s
.5085 .74303 m .51802 .70833 L .54159 .70636 L p .707 .577 .707 r
F P
0 g
s
.57783 .63315 m .56901 .68703 L .53991 .68685 L p .707 .577 .707 r
F P
0 g
s
.54159 .70636 m .53207 .74105 L .5085 .74303 L p .707 .577 .707 r
F P
0 g
s
.50233 .78598 m .50763 .76886 L .53107 .76729 L p .707 .577 .707 r
F P
0 g
s
.53207 .74105 m .54159 .70636 L .57021 .70871 L p .707 .577 .707 r
F P
0 g
s
.53107 .76729 m .52578 .78442 L .50233 .78598 L p .707 .577 .707 r
F P
0 g
s
.57021 .70871 m .56069 .7434 L .53207 .74105 L p .707 .577 .707 r
F P
0 g
s
.52578 .78442 m .53107 .76729 L .55951 .77027 L p .707 .577 .707 r
F P
0 g
s
.55951 .77027 m .55421 .7874 L .52578 .78442 L p .707 .577 .707 r
F P
0 g
s
.57161 .33951 m .49238 .82611 L .53346 .82634 L p .707 .577 .707 r
F P
0 g
s
.53346 .82634 m .61269 .33973 L .57161 .33951 L p .707 .577 .707 r
F P
0 g
s
.70285 .68627 m .69403 .74015 L .69131 .72932 L p .707 .577 .707 r
F P
0 g
s
.69131 .72932 m .70013 .67545 L .70285 .68627 L p .707 .577 .707 r
F P
0 g
s
.68469 .78655 m .67516 .82124 L .68242 .81161 L p .707 .577 .707 r
F P
0 g
s
.68242 .81161 m .69194 .77692 L .68469 .78655 L p .707 .577 .707 r
F P
0 g
s
.40449 .81126 m .48372 .32466 L .44551 .31148 L p .707 .577 .707 r
F P
0 g
s
.48372 .32466 m .40449 .81126 L .44794 .82092 L p .707 .577 .707 r
F P
0 g
s
.56901 .68703 m .57783 .63315 L .6093 .63685 L p .707 .577 .707 r
F P
0 g
s
.6093 .63685 m .60048 .69073 L .56901 .68703 L p .707 .577 .707 r
F P
0 g
s
.56069 .7434 m .57021 .70871 L .60109 .71514 L p .707 .577 .707 r
F P
0 g
s
.60109 .71514 m .59157 .74983 L .56069 .7434 L p .707 .577 .707 r
F P
0 g
s
.55421 .7874 m .55951 .77027 L .59016 .7775 L p .707 .577 .707 r
F P
0 g
s
.59016 .7775 m .58486 .79463 L .55421 .7874 L p .707 .577 .707 r
F P
0 g
s
.61269 .33973 m .53346 .82634 L .56716 .82156 L p .707 .577 .707 r
F P
0 g
s
.56716 .82156 m .64639 .33496 L .61269 .33973 L p .707 .577 .707 r
F P
0 g
s
.36628 .79809 m .44551 .31148 L .41629 .29608 L p .707 .577 .707 r
F P
0 g
s
.44551 .31148 m .36628 .79809 L .40449 .81126 L p .707 .577 .707 r
F P
0 g
s
.67266 .85266 m .66736 .86978 L .67465 .86001 L p .707 .577 .707 r
F P
0 g
s
.67465 .86001 m .67995 .84289 L .67266 .85266 L p .707 .577 .707 r
F P
0 g
s
.69194 .77692 m .68242 .81161 L .68001 .79939 L p .707 .577 .707 r
F P
0 g
s
.68001 .79939 m .68953 .7647 L .69194 .77692 L p .707 .577 .707 r
F P
0 g
s
.70013 .67545 m .69131 .72932 L .67901 .71789 L p .707 .577 .707 r
F P
0 g
s
.67901 .71789 m .68783 .66401 L .70013 .67545 L p .707 .577 .707 r
F P
0 g
s
.24313 .71392 m .25195 .66004 L .22117 .65318 L p .707 .577 .707 r
F P
0 g
s
.25195 .66004 m .24313 .71392 L .2746 .71762 L p .707 .577 .707 r
F P
0 g
s
.2746 .71762 m .28342 .66374 L .25195 .66004 L p .707 .577 .707 r
F P
0 g
s
.28342 .66374 m .2746 .71762 L .3037 .7178 L p .707 .577 .707 r
F P
0 g
s
.3037 .7178 m .31252 .66392 L .28342 .66374 L p .707 .577 .707 r
F P
0 g
s
.21235 .70705 m .22117 .65318 L .19412 .64382 L p .707 .577 .707 r
F P
0 g
s
.22117 .65318 m .21235 .70705 L .24313 .71392 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64008 .64372 m .63125 .69759 L .60048 .69073 L p .707 .577 .707 r
F P
0 g
s
.60048 .69073 m .6093 .63685 L .64008 .64372 L p .707 .577 .707 r
F P
0 g
s
.6312 .72504 m .62168 .75973 L .59157 .74983 L p .707 .577 .707 r
F P
0 g
s
.59157 .74983 m .60109 .71514 L .6312 .72504 L p .707 .577 .707 r
F P
0 g
s
.62001 .78828 m .61471 .80541 L .58486 .79463 L p .707 .577 .707 r
F P
0 g
s
.58486 .79463 m .59016 .7775 L .62001 .78828 L p .707 .577 .707 r
F P
0 g
s
.64639 .33496 m .56716 .82156 L .59018 .81227 L p .707 .577 .707 r
F P
0 g
s
.59018 .81227 m .66941 .32566 L .64639 .33496 L p .707 .577 .707 r
F P
0 g
s
.35269 .65397 m .34387 .70785 L .35102 .6987 L p .707 .577 .707 r
F P
0 g
s
.35102 .6987 m .35984 .64482 L .35269 .65397 L p .707 .577 .707 r
F P
0 g
s
.34168 .73891 m .33216 .77361 L .33941 .76398 L p .707 .577 .707 r
F P
0 g
s
.33941 .76398 m .34893 .72928 L .34168 .73891 L p .707 .577 .707 r
F P
0 g
s
.35984 .64482 m .35102 .6987 L .3483 .68787 L p .707 .577 .707 r
F P
0 g
s
.3483 .68787 m .35713 .634 L .35984 .64482 L p .707 .577 .707 r
F P
0 g
s
.33216 .77361 m .34168 .73891 L .32548 .74502 L p .707 .577 .707 r
F P
0 g
s
.34893 .72928 m .33941 .76398 L .337 .75176 L p .707 .577 .707 r
F P
0 g
s
.337 .75176 m .34652 .71707 L .34893 .72928 L p .707 .577 .707 r
F P
0 g
s
.33639 .66055 m .32756 .71443 L .34387 .70785 L p .707 .577 .707 r
F P
0 g
s
.34387 .70785 m .35269 .65397 L .33639 .66055 L p .707 .577 .707 r
F P
0 g
s
.35713 .634 m .3483 .68787 L .336 .67643 L p .707 .577 .707 r
F P
0 g
s
.336 .67643 m .34482 .62256 L .35713 .634 L p .707 .577 .707 r
F P
0 g
s
.34652 .71707 m .337 .75176 L .32516 .73815 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .33469 .70346 L .34652 .71707 L p .707 .577 .707 r
F P
0 g
s
.33706 .78269 m .41629 .29608 L .39891 .27996 L p .707 .577 .707 r
F P
0 g
s
.41629 .29608 m .33706 .78269 L .36628 .79809 L p .707 .577 .707 r
F P
0 g
s
.67995 .84289 m .67465 .86001 L .67236 .84739 L p .707 .577 .707 r
F P
0 g
s
.67236 .84739 m .67766 .83026 L .67995 .84289 L p .707 .577 .707 r
F P
0 g
s
.31252 .66392 m .3037 .7178 L .32756 .71443 L p .707 .577 .707 r
F P
0 g
s
.32756 .71443 m .33639 .66055 L .31252 .66392 L p .707 .577 .707 r
F P
0 g
s
.1853 .6977 m .19412 .64382 L .17342 .63289 L p .707 .577 .707 r
F P
0 g
s
.19412 .64382 m .1853 .6977 L .21235 .70705 L p .707 .577 .707 r
F P
0 g
s
.68783 .66401 m .67901 .71789 L .65831 .70695 L p .707 .577 .707 r
F P
0 g
s
.65831 .70695 m .66713 .65308 L .68783 .66401 L p .707 .577 .707 r
F P
0 g
s
.68953 .7647 m .68001 .79939 L .66817 .78578 L p .707 .577 .707 r
F P
0 g
s
.66817 .78578 m .6777 .75109 L .68953 .7647 L p .707 .577 .707 r
F P
0 g
s
.23289 .7729 m .24241 .73821 L .2123 .72831 L p .707 .577 .707 r
F P
0 g
s
.24241 .73821 m .23289 .7729 L .26377 .77934 L p .707 .577 .707 r
F P
0 g
s
.26377 .77934 m .27329 .74465 L .24241 .73821 L p .707 .577 .707 r
F P
0 g
s
.20278 .76301 m .2123 .72831 L .1859 .71593 L p .707 .577 .707 r
F P
0 g
s
.2123 .72831 m .20278 .76301 L .23289 .7729 L p .707 .577 .707 r
F P
0 g
s
.27329 .74465 m .26377 .77934 L .29239 .78168 L p .707 .577 .707 r
F P
0 g
s
.29239 .78168 m .30191 .74699 L .27329 .74465 L p .707 .577 .707 r
F P
0 g
s
.17342 .63289 m .1646 .68676 L .1853 .6977 L p .707 .577 .707 r
F P
0 g
s
.1646 .68676 m .17342 .63289 L .16112 .62145 L p .707 .577 .707 r
F P
0 g
s
.66713 .65308 m .65831 .70695 L .63125 .69759 L p .707 .577 .707 r
F P
0 g
s
.63125 .69759 m .64008 .64372 L .66713 .65308 L p .707 .577 .707 r
F P
0 g
s
.17638 .75062 m .1859 .71593 L .1658 .70226 L p .707 .577 .707 r
F P
0 g
s
.1859 .71593 m .17638 .75062 L .20278 .76301 L p .707 .577 .707 r
F P
0 g
s
.30191 .74699 m .29239 .78168 L .31595 .77971 L p .707 .577 .707 r
F P
0 g
s
.31595 .77971 m .32548 .74502 L .30191 .74699 L p .707 .577 .707 r
F P
0 g
s
.22566 .81079 m .23096 .79366 L .20111 .78288 L p .707 .577 .707 r
F P
0 g
s
.23096 .79366 m .22566 .81079 L .25631 .81802 L p .707 .577 .707 r
F P
0 g
s
.25631 .81802 m .26161 .80089 L .23096 .79366 L p .707 .577 .707 r
F P
0 g
s
.67766 .83026 m .67236 .84739 L .66072 .83315 L p .707 .577 .707 r
F P
0 g
s
.66072 .83315 m .66601 .81602 L .67766 .83026 L p .707 .577 .707 r
F P
0 g
s
.66941 .32566 m .59018 .81227 L .60027 .79935 L p .707 .577 .707 r
F P
0 g
s
.60027 .79935 m .6795 .31275 L .66941 .32566 L p .707 .577 .707 r
F P
0 g
s
.6777 .75109 m .66817 .78578 L .64808 .77212 L p .707 .577 .707 r
F P
0 g
s
.64808 .77212 m .6576 .73742 L .6777 .75109 L p .707 .577 .707 r
F P
0 g
s
.19581 .80001 m .20111 .78288 L .17497 .76961 L p .707 .577 .707 r
F P
0 g
s
.20111 .78288 m .19581 .80001 L .22566 .81079 L p .707 .577 .707 r
F P
0 g
s
.26161 .80089 m .25631 .81802 L .28475 .821 L p .707 .577 .707 r
F P
0 g
s
.28475 .821 m .29004 .80387 L .26161 .80089 L p .707 .577 .707 r
F P
0 g
s
.32548 .74502 m .31595 .77971 L .33216 .77361 L p .707 .577 .707 r
F P
0 g
s
.34482 .62256 m .336 .67643 L .3153 .6655 L p .707 .577 .707 r
F P
0 g
s
.3153 .6655 m .32412 .61162 L .34482 .62256 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .30507 .72448 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.33469 .70346 m .32974 .72149 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.32974 .72149 m .32516 .73815 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.30507 .72448 m .31459 .68979 L .33469 .70346 L p .707 .577 .707 r
F P
0 g
s
.323 .75971 m .31771 .77683 L .29784 .76237 L p .707 .577 .707 r
F P
0 g
s
.29784 .76237 m .30314 .74524 L .323 .75971 L p .707 .577 .707 r
F P
0 g
s
.31968 .76657 m .36445 .49161 L p .39508 .26469 L .707 .577 .707 r
F P
0 g
s
.36445 .49161 m .39891 .27996 L .39735 .27375 L p .707 .577 .707 r
F P
0 g
s
.39735 .27375 m .39508 .26469 L p .36445 .49161 L .707 .577 .707 r
F P
0 g
s
.32935 .79107 m .33465 .77395 L .33694 .78657 L p .707 .577 .707 r
F P
0 g
s
.33465 .77395 m .32935 .79107 L .31771 .77683 L p .707 .577 .707 r
F P
0 g
s
.31771 .77683 m .323 .75971 L .33465 .77395 L p .707 .577 .707 r
F P
0 g
s
.39891 .27996 m .31968 .76657 L .33706 .78269 L p .707 .577 .707 r
F P
0 g
s
.1658 .70226 m .15628 .73695 L .17638 .75062 L p .707 .577 .707 r
F P
0 g
s
.17497 .76961 m .16967 .78673 L .19581 .80001 L p .707 .577 .707 r
F P
0 g
s
.16112 .62145 m .15229 .67532 L .1646 .68676 L p .707 .577 .707 r
F P
0 g
s
.16967 .78673 m .17497 .76961 L .1551 .75514 L p .707 .577 .707 r
F P
0 g
s
.15628 .73695 m .1658 .70226 L .15397 .68865 L p .707 .577 .707 r
F P
0 g
s
.29004 .80387 m .28475 .821 L .30819 .81943 L p .707 .577 .707 r
F P
0 g
s
.30819 .81943 m .31349 .80231 L .29004 .80387 L p .707 .577 .707 r
F P
0 g
s
.15229 .67532 m .16112 .62145 L .1584 .61062 L p .707 .577 .707 r
F P
0 g
s
.1551 .75514 m .14981 .77227 L .16967 .78673 L p .707 .577 .707 r
F P
0 g
s
.6576 .73742 m .64808 .77212 L .62168 .75973 L p .707 .577 .707 r
F P
0 g
s
.62168 .75973 m .6312 .72504 L .6576 .73742 L p .707 .577 .707 r
F P
0 g
s
.66601 .81602 m .66072 .83315 L .64085 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .81868 m .64615 .80156 L .66601 .81602 L p .707 .577 .707 r
F P
0 g
s
.15397 .68865 m .14445 .72334 L .15628 .73695 L p .707 .577 .707 r
F P
0 g
s
.14981 .77227 m .1551 .75514 L .14345 .7409 L p .707 .577 .707 r
F P
0 g
s
.1584 .61062 m .14958 .6645 L .15229 .67532 L p .707 .577 .707 r
F P
0 g
s
.31349 .80231 m .30819 .81943 L .32435 .81347 L p .707 .577 .707 r
F P
0 g
s
.32435 .81347 m .32965 .79634 L .31349 .80231 L p .707 .577 .707 r
F P
0 g
s
.14345 .7409 m .13816 .75803 L .14981 .77227 L p .707 .577 .707 r
F P
0 g
s
.14445 .72334 m .15397 .68865 L .15156 .67643 L p .707 .577 .707 r
F P
0 g
s
.6795 .31275 m .60027 .79935 L .59644 .78409 L p .707 .577 .707 r
F P
0 g
s
.59644 .78409 m .67566 .29748 L .6795 .31275 L p .707 .577 .707 r
F P
0 g
s
.64615 .80156 m .64085 .81868 L .61471 .80541 L p .707 .577 .707 r
F P
0 g
s
.61471 .80541 m .62001 .78828 L .64615 .80156 L p .707 .577 .707 r
F P
0 g
s
.39508 .26469 m .31585 .7513 L .31968 .76657 L p .707 .577 .707 r
F P
0 g
s
.31585 .7513 m .39508 .26469 L .40517 .25178 L p .707 .577 .707 r
F P
0 g
s
.14958 .6645 m .1584 .61062 L .16555 .60147 L p .707 .577 .707 r
F P
0 g
s
.15156 .67643 m .14204 .71113 L .14445 .72334 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.13816 .75803 m .14345 .7409 L .14116 .72828 L p .707 .577 .707 r
F P
0 g
s
.32965 .79634 m .32435 .81347 L .33164 .8037 L p .707 .577 .707 r
F P
0 g
s
.33164 .8037 m .33694 .78657 L .32965 .79634 L p .707 .577 .707 r
F P
0 g
s
.14116 .72828 m .13587 .7454 L .13816 .75803 L p .707 .577 .707 r
F P
0 g
s
.16555 .60147 m .15673 .65535 L .14958 .6645 L p .707 .577 .707 r
F P
0 g
s
.14204 .71113 m .15156 .67643 L .15881 .6668 L p .707 .577 .707 r
F P
0 g
s
.15673 .65535 m .16555 .60147 L .18186 .59489 L p .707 .577 .707 r
F P
0 g
s
.67566 .29748 m .59644 .78409 L .57906 .76797 L p .707 .577 .707 r
F P
0 g
s
.57906 .76797 m .65829 .28136 L .67566 .29748 L p .707 .577 .707 r
F P
0 g
s
.15881 .6668 m .14929 .70149 L .14204 .71113 L p .707 .577 .707 r
F P
0 g
s
.32594 .73839 m .40517 .25178 L .42819 .24248 L p .707 .577 .707 r
F P
0 g
s
.40517 .25178 m .32594 .73839 L .31585 .7513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13587 .7454 m .14116 .72828 L .14846 .71851 L p .707 .577 .707 r
F P
0 g
s
.33694 .78657 m .33164 .8037 L .32935 .79107 L p .707 .577 .707 r
F P
0 g
s
.14846 .71851 m .14316 .73563 L .13587 .7454 L p .707 .577 .707 r
F P
0 g
s
.18186 .59489 m .17303 .64877 L .15673 .65535 L p .707 .577 .707 r
F P
0 g
s
.14929 .70149 m .15881 .6668 L .17501 .6607 L p .707 .577 .707 r
F P
0 g
s
.17303 .64877 m .18186 .59489 L .20572 .59152 L p .707 .577 .707 r
F P
0 g
s
.17501 .6607 m .16549 .69539 L .14929 .70149 L p .707 .577 .707 r
F P
0 g
s
.14316 .73563 m .14846 .71851 L .16462 .71255 L p .707 .577 .707 r
F P
0 g
s
.65829 .28136 m .57906 .76797 L .54984 .75257 L p .707 .577 .707 r
F P
0 g
s
.54984 .75257 m .62906 .26596 L .65829 .28136 L p .707 .577 .707 r
F P
0 g
s
.20572 .59152 m .1969 .6454 L .17303 .64877 L p .707 .577 .707 r
F P
0 g
s
.32412 .61162 m .3153 .6655 L .28825 .65614 L p .707 .577 .707 r
F P
0 g
s
.28825 .65614 m .29707 .60227 L .32412 .61162 L p .707 .577 .707 r
F P
0 g
s
.16462 .71255 m .15932 .72967 L .14316 .73563 L p .707 .577 .707 r
F P
0 g
s
.42819 .24248 m .34896 .72909 L .32594 .73839 L p .707 .577 .707 r
F P
0 g
s
.34896 .72909 m .42819 .24248 L .46189 .23771 L p .707 .577 .707 r
F P
0 g
s
.1969 .6454 m .20572 .59152 L .23482 .5917 L p .707 .577 .707 r
F P
0 g
s
.16549 .69539 m .17501 .6607 L .19858 .65873 L p .707 .577 .707 r
F P
0 g
s
.29707 .60227 m .28825 .65614 L .25747 .64928 L p .707 .577 .707 r
F P
0 g
s
.25747 .64928 m .26629 .5954 L .29707 .60227 L p .707 .577 .707 r
F P
0 g
s
.226 .64557 m .23482 .5917 L .26629 .5954 L p .707 .577 .707 r
F P
0 g
s
.23482 .5917 m .226 .64557 L .1969 .6454 L p .707 .577 .707 r
F P
0 g
s
.19858 .65873 m .18906 .69342 L .16549 .69539 L p .707 .577 .707 r
F P
0 g
s
.26629 .5954 m .25747 .64928 L .226 .64557 L p .707 .577 .707 r
F P
0 g
s
.15932 .72967 m .16462 .71255 L .18806 .71098 L p .707 .577 .707 r
F P
0 g
s
.18906 .69342 m .19858 .65873 L .2272 .66107 L p .707 .577 .707 r
F P
0 g
s
.72334 .66333 m .73216 .60946 L .70139 .60259 L p .707 .577 .707 r
F P
0 g
s
.73216 .60946 m .72334 .66333 L .75481 .66703 L p .707 .577 .707 r
F P
0 g
s
.75481 .66703 m .76363 .61316 L .73216 .60946 L p .707 .577 .707 r
F P
0 g
s
.31459 .68979 m .30507 .72448 L .27867 .7121 L p .707 .577 .707 r
F P
0 g
s
.27867 .7121 m .28819 .6774 L .31459 .68979 L p .707 .577 .707 r
F P
0 g
s
.18806 .71098 m .18277 .7281 L .15932 .72967 L p .707 .577 .707 r
F P
0 g
s
.62906 .26596 m .54984 .75257 L .51163 .73939 L p .707 .577 .707 r
F P
0 g
s
.51163 .73939 m .59086 .25278 L .62906 .26596 L p .707 .577 .707 r
F P
0 g
s
.76363 .61316 m .75481 .66703 L .78391 .66721 L p .707 .577 .707 r
F P
0 g
s
.78391 .66721 m .79273 .61333 L .76363 .61316 L p .707 .577 .707 r
F P
0 g
s
.69257 .65647 m .70139 .60259 L .67433 .59323 L p .707 .577 .707 r
F P
0 g
s
.70139 .60259 m .69257 .65647 L .72334 .66333 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .46189 .23771 L .50297 .23793 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .34896 .72909 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.42743 .44936 m .38266 .72432 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.50297 .23793 m .42374 .72454 L .38266 .72432 L p .707 .577 .707 r
F P
0 g
s
.40097 .6873 m .40554 .67064 L p .37961 .64617 L .707 .577 .707 r
F P
0 g
s
.40554 .67064 m .41049 .65261 L .40739 .65196 L p .707 .577 .707 r
F P
0 g
s
.40739 .65196 m .37961 .64617 L p .40554 .67064 L .707 .577 .707 r
F P
0 g
s
.46189 .23771 m .42743 .44936 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.2272 .66107 m .21768 .69576 L .18906 .69342 L p .707 .577 .707 r
F P
0 g
s
.21768 .69576 m .2272 .66107 L .25808 .66751 L p .707 .577 .707 r
F P
0 g
s
.28819 .6774 m .27867 .7121 L .24856 .7022 L p .707 .577 .707 r
F P
0 g
s
.24856 .7022 m .25808 .66751 L .28819 .6774 L p .707 .577 .707 r
F P
0 g
s
.18277 .7281 m .18806 .71098 L .2165 .71396 L p .707 .577 .707 r
F P
0 g
s
.25808 .66751 m .24856 .7022 L .21768 .69576 L p .707 .577 .707 r
F P
0 g
s
.79273 .61333 m .78391 .66721 L .80778 .66384 L p .707 .577 .707 r
F P
0 g
s
.80778 .66384 m .8166 .60997 L .79273 .61333 L p .707 .577 .707 r
F P
0 g
s
.66551 .64711 m .67433 .59323 L .65363 .5823 L p .707 .577 .707 r
F P
0 g
s
.67433 .59323 m .66551 .64711 L .69257 .65647 L p .707 .577 .707 r
F P
0 g
s
.30314 .74524 m .29784 .76237 L .2717 .7491 L p .707 .577 .707 r
F P
0 g
s
.2717 .7491 m .277 .73197 L .30314 .74524 L p .707 .577 .707 r
F P
0 g
s
.59086 .25278 m .51163 .73939 L .46818 .72974 L p .707 .577 .707 r
F P
0 g
s
.46818 .72974 m .54741 .24313 L .59086 .25278 L p .707 .577 .707 r
F P
0 g
s
.2165 .71396 m .2112 .73108 L .18277 .7281 L p .707 .577 .707 r
F P
0 g
s
.41049 .65261 m .40097 .6873 L .40578 .68769 L p .707 .577 .707 r
F P
0 g
s
.44943 .62454 m .44421 .59881 L .47335 .53142 L .707 .577 .707 r
F
.42374 .72454 m .43571 .65102 L p .44943 .62454 L F P
0 g
s
.43571 .65102 m .44421 .59881 L p .44943 .62454 L .707 .577 .707 r
F P
0 g
s
.54741 .24313 m .46818 .72974 L .42374 .72454 L p .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .42725 .71184 L .4054 .70955 L p .707 .577 .707 r
F P
0 g
s
.4054 .70955 m .39881 .70886 L p .4036 .71302 L .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .4054 .70955 L .4036 .71302 L .707 .577 .707 r
F
.40578 .68769 m .42959 .68964 L p .41618 .66364 L F P
0 g
s
.41618 .66364 m .41049 .65261 L .40578 .68769 L .707 .577 .707 r
F
.50297 .23793 m .54741 .24313 L p .47335 .53142 L F P
0 g
s
.44421 .59881 m .50297 .23793 L p .47335 .53142 L .707 .577 .707 r
F P
0 g
s
.7131 .7285 m .72262 .6938 L .69251 .68391 L p .707 .577 .707 r
F P
0 g
s
.72262 .6938 m .7131 .7285 L .74398 .73493 L p .707 .577 .707 r
F P
0 g
s
.74398 .73493 m .7535 .70024 L .72262 .6938 L p .707 .577 .707 r
F P
0 g
s
.2112 .73108 m .2165 .71396 L .24715 .72119 L p .707 .577 .707 r
F P
0 g
s
.68299 .7186 m .69251 .68391 L .66612 .67152 L p .707 .577 .707 r
F P
0 g
s
.69251 .68391 m .68299 .7186 L .7131 .7285 L p .707 .577 .707 r
F P
0 g
s
.7535 .70024 m .74398 .73493 L .7726 .73728 L p .707 .577 .707 r
F P
0 g
s
.7726 .73728 m .78212 .70258 L .7535 .70024 L p .707 .577 .707 r
F P
0 g
s
.277 .73197 m .2717 .7491 L .24185 .73832 L p .707 .577 .707 r
F P
0 g
s
.24185 .73832 m .24715 .72119 L .277 .73197 L p .707 .577 .707 r
F P
0 g
s
.24715 .72119 m .24185 .73832 L .2112 .73108 L p .707 .577 .707 r
F P
0 g
s
.65363 .5823 m .64481 .63617 L .66551 .64711 L p .707 .577 .707 r
F P
0 g
s
.8166 .60997 m .80778 .66384 L .82408 .65726 L p .707 .577 .707 r
F P
0 g
s
.82408 .65726 m .83291 .60338 L .8166 .60997 L p .707 .577 .707 r
F P
0 g
s
.64481 .63617 m .65363 .5823 L .64133 .57086 L p .707 .577 .707 r
F P
0 g
s
.65659 .70621 m .66612 .67152 L .64602 .65785 L p .707 .577 .707 r
F P
0 g
s
.66612 .67152 m .65659 .70621 L .68299 .7186 L p .707 .577 .707 r
F P
0 g
s
.78212 .70258 m .7726 .73728 L .79617 .7353 L p .707 .577 .707 r
F P
0 g
s
.79617 .7353 m .80569 .70061 L .78212 .70258 L p .707 .577 .707 r
F P
0 g
s
.70588 .77506 m .71117 .75794 L .68132 .74716 L p .707 .577 .707 r
F P
0 g
s
.71117 .75794 m .70588 .77506 L .73652 .7823 L p .707 .577 .707 r
F P
0 g
s
.73652 .7823 m .74182 .76517 L .71117 .75794 L p .707 .577 .707 r
F P
0 g
s
.67602 .76428 m .68132 .74716 L .65518 .73388 L p .707 .577 .707 r
F P
0 g
s
.68132 .74716 m .67602 .76428 L .70588 .77506 L p .707 .577 .707 r
F P
0 g
s
.74182 .76517 m .73652 .7823 L .76496 .78527 L p .707 .577 .707 r
F P
0 g
s
.76496 .78527 m .77026 .76815 L .74182 .76517 L p .707 .577 .707 r
F P
0 g
s
.64602 .65785 m .63649 .69255 L .65659 .70621 L p .707 .577 .707 r
F P
0 g
s
.64133 .57086 m .63251 .62474 L .64481 .63617 L p .707 .577 .707 r
F P
0 g
s
.65518 .73388 m .64988 .75101 L .67602 .76428 L p .707 .577 .707 r
F P
0 g
s
.83291 .60338 m .82408 .65726 L .83123 .64811 L p .707 .577 .707 r
F P
0 g
s
.83123 .64811 m .84005 .59423 L .83291 .60338 L p .707 .577 .707 r
F P
0 g
s
.63649 .69255 m .64602 .65785 L .63418 .64425 L p .707 .577 .707 r
F P
0 g
s
.64988 .75101 m .65518 .73388 L .63532 .71942 L p .707 .577 .707 r
F P
0 g
s
.80569 .70061 m .79617 .7353 L .81237 .7292 L p .707 .577 .707 r
F P
0 g
s
.81237 .7292 m .82189 .69451 L .80569 .70061 L p .707 .577 .707 r
F P
0 g
s
.63251 .62474 m .64133 .57086 L .63862 .56003 L p .707 .577 .707 r
F P
0 g
s
.77026 .76815 m .76496 .78527 L .78841 .78371 L p .707 .577 .707 r
F P
0 g
s
.78841 .78371 m .7937 .76658 L .77026 .76815 L p .707 .577 .707 r
F P
0 g
s
.63532 .71942 m .63002 .73654 L .64988 .75101 L p .707 .577 .707 r
F P
0 g
s
.63418 .64425 m .62466 .67894 L .63649 .69255 L p .707 .577 .707 r
F P
0 g
s
.63002 .73654 m .63532 .71942 L .62367 .70518 L p .707 .577 .707 r
F P
0 g
s
.63862 .56003 m .6298 .61391 L .63251 .62474 L p .707 .577 .707 r
F P
0 g
s
.7937 .76658 m .78841 .78371 L .80457 .77774 L p .707 .577 .707 r
F P
0 g
s
.80457 .77774 m .80986 .76062 L .7937 .76658 L p .707 .577 .707 r
F P
0 g
s
.62466 .67894 m .63418 .64425 L .63178 .63203 L p .707 .577 .707 r
F P
0 g
s
.62367 .70518 m .61837 .7223 L .63002 .73654 L p .707 .577 .707 r
F P
0 g
s
.84005 .59423 m .83123 .64811 L .82852 .63729 L p .707 .577 .707 r
F P
0 g
s
.82852 .63729 m .83734 .58341 L .84005 .59423 L p .707 .577 .707 r
F P
0 g
s
.82189 .69451 m .81237 .7292 L .81962 .71957 L p .707 .577 .707 r
F P
0 g
s
.81962 .71957 m .82914 .68488 L .82189 .69451 L p .707 .577 .707 r
F P
0 g
s
.6298 .61391 m .63862 .56003 L .64576 .55088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63178 .63203 m .62225 .66672 L .62466 .67894 L p .707 .577 .707 r
F P
0 g
s
.61837 .7223 m .62367 .70518 L .62138 .69255 L p .707 .577 .707 r
F P
0 g
s
.64576 .55088 m .63694 .60476 L .6298 .61391 L p .707 .577 .707 r
F P
0 g
s
.80986 .76062 m .80457 .77774 L .81186 .76797 L p .707 .577 .707 r
F P
0 g
s
.81186 .76797 m .81716 .75085 L .80986 .76062 L p .707 .577 .707 r
F P
0 g
s
.62138 .69255 m .61608 .70968 L .61837 .7223 L p .707 .577 .707 r
F P
0 g
s
.62225 .66672 m .63178 .63203 L .63903 .6224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.82914 .68488 m .81962 .71957 L .81721 .70735 L p .707 .577 .707 r
F P
0 g
s
.81721 .70735 m .82673 .67266 L .82914 .68488 L p .707 .577 .707 r
F P
0 g
s
.83734 .58341 m .82852 .63729 L .81621 .62585 L p .707 .577 .707 r
F P
0 g
s
.81621 .62585 m .82503 .57197 L .83734 .58341 L p .707 .577 .707 r
F P
0 g
s
.63694 .60476 m .64576 .55088 L .66207 .5443 L p .707 .577 .707 r
F P
0 g
s
.38033 .62188 m .38915 .568 L .35838 .56114 L p .707 .577 .707 r
F P
0 g
s
.38915 .568 m .38033 .62188 L .4118 .62558 L p .707 .577 .707 r
F P
0 g
s
.4118 .62558 m .42062 .57171 L .38915 .568 L p .707 .577 .707 r
F P
0 g
s
.63903 .6224 m .6295 .65709 L .62225 .66672 L p .707 .577 .707 r
F P
0 g
s
.42062 .57171 m .4118 .62558 L .4409 .62576 L p .707 .577 .707 r
F P
0 g
s
.4409 .62576 m .44972 .57188 L .42062 .57171 L p .707 .577 .707 r
F P
0 g
s
.34956 .61501 m .35838 .56114 L .33132 .55178 L p .707 .577 .707 r
F P
0 g
s
.35838 .56114 m .34956 .61501 L .38033 .62188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.61608 .70968 m .62138 .69255 L .62867 .68278 L p .707 .577 .707 r
F P
0 g
s
.66207 .5443 m .65325 .59818 L .63694 .60476 L p .707 .577 .707 r
F P
0 g
s
.81716 .75085 m .81186 .76797 L .80957 .75535 L p .707 .577 .707 r
F P
0 g
s
.80957 .75535 m .81487 .73822 L .81716 .75085 L p .707 .577 .707 r
F P
0 g
s
.44972 .57188 m .4409 .62576 L .46477 .62239 L p .707 .577 .707 r
F P
0 g
s
.46477 .62239 m .47359 .56851 L .44972 .57188 L p .707 .577 .707 r
F P
0 g
s
.62867 .68278 m .62337 .69991 L .61608 .70968 L p .707 .577 .707 r
F P
0 g
s
.3225 .60566 m .33132 .55178 L .31062 .54085 L p .707 .577 .707 r
F P
0 g
s
.33132 .55178 m .3225 .60566 L .34956 .61501 L p .707 .577 .707 r
F P
0 g
s
.6295 .65709 m .63903 .6224 L .65523 .6163 L p .707 .577 .707 r
F P
0 g
s
.82503 .57197 m .81621 .62585 L .79552 .61491 L p .707 .577 .707 r
F P
0 g
s
.79552 .61491 m .80434 .56104 L .82503 .57197 L p .707 .577 .707 r
F P
0 g
s
.82673 .67266 m .81721 .70735 L .80538 .69374 L p .707 .577 .707 r
F P
0 g
s
.80538 .69374 m .8149 .65905 L .82673 .67266 L p .707 .577 .707 r
F P
0 g
s
.65325 .59818 m .66207 .5443 L .68594 .54093 L p .707 .577 .707 r
F P
0 g
s
.37009 .68086 m .37961 .64617 L .3495 .63628 L p .707 .577 .707 r
F P
0 g
s
.37961 .64617 m .37009 .68086 L .40097 .6873 L p .707 .577 .707 r
F P
0 g
s
.33998 .67097 m .3495 .63628 L .32311 .62389 L p .707 .577 .707 r
F P
0 g
s
.3495 .63628 m .33998 .67097 L .37009 .68086 L p .707 .577 .707 r
F P
0 g
s
.42959 .68964 m .43911 .65495 L .41049 .65261 L p .707 .577 .707 r
F P
0 g
s
.65523 .6163 m .64571 .65099 L .6295 .65709 L p .707 .577 .707 r
F P
0 g
s
.31062 .54085 m .3018 .59472 L .3225 .60566 L p .707 .577 .707 r
F P
0 g
s
.47359 .56851 m .46477 .62239 L .48107 .61581 L p .707 .577 .707 r
F P
0 g
s
.48107 .61581 m .4899 .56193 L .47359 .56851 L p .707 .577 .707 r
F P
0 g
s
.62337 .69991 m .62867 .68278 L .64483 .67682 L p .707 .577 .707 r
F P
0 g
s
.3018 .59472 m .31062 .54085 L .29832 .52941 L p .707 .577 .707 r
F P
0 g
s
.68594 .54093 m .67712 .59481 L .65325 .59818 L p .707 .577 .707 r
F P
0 g
s
.80434 .56104 m .79552 .61491 L .76846 .60556 L p .707 .577 .707 r
F P
0 g
s
.76846 .60556 m .77728 .55168 L .80434 .56104 L p .707 .577 .707 r
F P
0 g
s
.31358 .65858 m .32311 .62389 L .30301 .61022 L p .707 .577 .707 r
F P
0 g
s
.32311 .62389 m .31358 .65858 L .33998 .67097 L p .707 .577 .707 r
F P
0 g
s
.43911 .65495 m .42959 .68964 L .45316 .68767 L p .707 .577 .707 r
F P
0 g
s
.45316 .68767 m .46268 .65298 L .43911 .65495 L p .707 .577 .707 r
F P
0 g
s
.67712 .59481 m .68594 .54093 L .71503 .54111 L p .707 .577 .707 r
F P
0 g
s
.36287 .71875 m .36816 .70162 L .33831 .69084 L p .707 .577 .707 r
F P
0 g
s
.36816 .70162 m .36287 .71875 L .39351 .72598 L p .707 .577 .707 r
F P
0 g
s
.39351 .72598 m .39881 .70886 L .36816 .70162 L p .707 .577 .707 r
F P
0 g
s
.81487 .73822 m .80957 .75535 L .79792 .74111 L p .707 .577 .707 r
F P
0 g
s
.79792 .74111 m .80322 .72398 L .81487 .73822 L p .707 .577 .707 r
F P
0 g
s
.64571 .65099 m .65523 .6163 L .67879 .61432 L p .707 .577 .707 r
F P
0 g
s
.64483 .67682 m .63953 .69395 L .62337 .69991 L p .707 .577 .707 r
F P
0 g
s
.8149 .65905 m .80538 .69374 L .78528 .68008 L p .707 .577 .707 r
F P
0 g
s
.78528 .68008 m .7948 .64539 L .8149 .65905 L p .707 .577 .707 r
F P
0 g
s
.33301 .70797 m .33831 .69084 L .31217 .67757 L p .707 .577 .707 r
F P
0 g
s
.33831 .69084 m .33301 .70797 L .36287 .71875 L p .707 .577 .707 r
F P
0 g
s
.39881 .70886 m .39351 .72598 L .42195 .72896 L p .707 .577 .707 r
F P
0 g
s
.30301 .61022 m .29348 .64491 L .31358 .65858 L p .707 .577 .707 r
F P
0 g
s
.31217 .67757 m .30687 .6947 L .33301 .70797 L p .707 .577 .707 r
F P
0 g
s
.77728 .55168 m .76846 .60556 L .73769 .59869 L p .707 .577 .707 r
F P
0 g
s
.73769 .59869 m .74651 .54481 L .77728 .55168 L p .707 .577 .707 r
F P
0 g
s
.70621 .59499 m .71503 .54111 L .74651 .54481 L p .707 .577 .707 r
F P
0 g
s
.71503 .54111 m .70621 .59499 L .67712 .59481 L p .707 .577 .707 r
F P
0 g
s
.29832 .52941 m .2895 .58328 L .3018 .59472 L p .707 .577 .707 r
F P
0 g
s
.67879 .61432 m .66927 .64901 L .64571 .65099 L p .707 .577 .707 r
F P
0 g
s
.74651 .54481 m .73769 .59869 L .70621 .59499 L p .707 .577 .707 r
F P
0 g
s
.30687 .6947 m .31217 .67757 L .29231 .66311 L p .707 .577 .707 r
F P
0 g
s
.29348 .64491 m .30301 .61022 L .29117 .59661 L p .707 .577 .707 r
F P
0 g
s
.4899 .56193 m .48107 .61581 L .48822 .60666 L p .707 .577 .707 r
F P
0 g
s
.48822 .60666 m .49704 .55278 L .4899 .56193 L p .707 .577 .707 r
F P
0 g
s
.42725 .71184 m .42195 .72896 L .4454 .72739 L p .707 .577 .707 r
F P
0 g
s
.4454 .72739 m .45069 .71027 L .42725 .71184 L p .707 .577 .707 r
F P
0 g
s
.46268 .65298 m .45316 .68767 L .46936 .68157 L p .707 .577 .707 r
F P
0 g
s
.46936 .68157 m .47888 .64688 L .46268 .65298 L p .707 .577 .707 r
F P
0 g
s
.63953 .69395 m .64483 .67682 L .66828 .67525 L p .707 .577 .707 r
F P
0 g
s
.66927 .64901 m .67879 .61432 L .70742 .61667 L p .707 .577 .707 r
F P
0 g
s
.2895 .58328 m .29832 .52941 L .29561 .51858 L p .707 .577 .707 r
F P
0 g
s
.29231 .66311 m .28701 .68023 L .30687 .6947 L p .707 .577 .707 r
F P
0 g
s
.7948 .64539 m .78528 .68008 L .75888 .66769 L p .707 .577 .707 r
F P
0 g
s
.75888 .66769 m .76841 .633 L .7948 .64539 L p .707 .577 .707 r
F P
0 g
s
.80322 .72398 m .79792 .74111 L .77806 .72664 L p .707 .577 .707 r
F P
0 g
s
.77806 .72664 m .78335 .70952 L .80322 .72398 L p .707 .577 .707 r
F P
0 g
s
.66828 .67525 m .66298 .69238 L .63953 .69395 L p .707 .577 .707 r
F P
0 g
s
.29117 .59661 m .28165 .6313 L .29348 .64491 L p .707 .577 .707 r
F P
0 g
s
.70742 .61667 m .69789 .65136 L .66927 .64901 L p .707 .577 .707 r
F P
0 g
s
.69789 .65136 m .70742 .61667 L .73829 .6231 L p .707 .577 .707 r
F P
0 g
s
.28701 .68023 m .29231 .66311 L .28066 .64886 L p .707 .577 .707 r
F P
0 g
s
.76841 .633 m .75888 .66769 L .72877 .65779 L p .707 .577 .707 r
F P
0 g
s
.72877 .65779 m .73829 .6231 L .76841 .633 L p .707 .577 .707 r
F P
0 g
s
.29561 .51858 m .28678 .57246 L .2895 .58328 L p .707 .577 .707 r
F P
0 g
s
.45069 .71027 m .4454 .72739 L .46156 .72143 L p .707 .577 .707 r
F P
0 g
s
.46156 .72143 m .46685 .70431 L .45069 .71027 L p .707 .577 .707 r
F P
0 g
s
.73829 .6231 m .72877 .65779 L .69789 .65136 L p .707 .577 .707 r
F P
0 g
s
.66298 .69238 m .66828 .67525 L .69671 .67823 L p .707 .577 .707 r
F P
0 g
s
.28066 .64886 m .27536 .66599 L .28701 .68023 L p .707 .577 .707 r
F P
0 g
s
.28165 .6313 m .29117 .59661 L .28877 .5844 L p .707 .577 .707 r
F P
0 g
s
.78335 .70952 m .77806 .72664 L .75192 .71337 L p .707 .577 .707 r
F P
0 g
s
.75192 .71337 m .75721 .69625 L .78335 .70952 L p .707 .577 .707 r
F P
0 g
s
.47888 .64688 m .46936 .68157 L .47661 .67194 L p .707 .577 .707 r
F P
0 g
s
.47661 .67194 m .48613 .63725 L .47888 .64688 L p .707 .577 .707 r
F P
0 g
s
.49704 .55278 m .48822 .60666 L .48551 .59583 L p .707 .577 .707 r
F P
0 g
s
.48551 .59583 m .49433 .54196 L .49704 .55278 L p .707 .577 .707 r
F P
0 g
s
.69671 .67823 m .69142 .69536 L .66298 .69238 L p .707 .577 .707 r
F P
0 g
s
.28678 .57246 m .29561 .51858 L .30275 .50943 L p .707 .577 .707 r
F P
0 g
s
.28877 .5844 m .27924 .61909 L .28165 .6313 L p .707 .577 .707 r
F P
0 g
s
.69142 .69536 m .69671 .67823 L .72736 .68547 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.75721 .69625 m .75192 .71337 L .72206 .70259 L p .707 .577 .707 r
F P
0 g
s
.72206 .70259 m .72736 .68547 L .75721 .69625 L p .707 .577 .707 r
F P
0 g
s
.27536 .66599 m .28066 .64886 L .27837 .63624 L p .707 .577 .707 r
F P
0 g
s
.72736 .68547 m .72206 .70259 L .69142 .69536 L p .707 .577 .707 r
F P
0 g
s
.46685 .70431 m .46156 .72143 L .46885 .71166 L p .707 .577 .707 r
F P
0 g
s
.46885 .71166 m .47415 .69453 L .46685 .70431 L p .707 .577 .707 r
F P
0 g
s
.27837 .63624 m .27307 .65336 L .27536 .66599 L p .707 .577 .707 r
F P
0 g
s
.30275 .50943 m .29393 .56331 L .28678 .57246 L p .707 .577 .707 r
F P
0 g
s
.27924 .61909 m .28877 .5844 L .29602 .57476 L p .707 .577 .707 r
F P
0 g
s
.48613 .63725 m .47661 .67194 L .4742 .65972 L p .707 .577 .707 r
F P
0 g
s
.4742 .65972 m .48372 .62503 L .48613 .63725 L p .707 .577 .707 r
F P
0 g
s
.49433 .54196 m .48551 .59583 L .4732 .5844 L p .707 .577 .707 r
F P
0 g
s
.4732 .5844 m .48202 .53052 L .49433 .54196 L p .707 .577 .707 r
F P
0 g
s
.29393 .56331 m .30275 .50943 L .31906 .50285 L p .707 .577 .707 r
F P
0 g
s
.29602 .57476 m .28649 .60946 L .27924 .61909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27307 .65336 m .27837 .63624 L .28566 .62647 L p .707 .577 .707 r
F P
0 g
s
.47415 .69453 m .46885 .71166 L .46656 .69904 L p .707 .577 .707 r
F P
0 g
s
.46656 .69904 m .47186 .68191 L .47415 .69453 L p .707 .577 .707 r
F P
0 g
s
.28566 .62647 m .28036 .64359 L .27307 .65336 L p .707 .577 .707 r
F P
0 g
s
.31906 .50285 m .31024 .55673 L .29393 .56331 L p .707 .577 .707 r
F P
0 g
s
.28649 .60946 m .29602 .57476 L .31222 .56866 L p .707 .577 .707 r
F P
0 g
s
.48202 .53052 m .4732 .5844 L .45251 .57346 L p .707 .577 .707 r
F P
0 g
s
.45251 .57346 m .46133 .51959 L .48202 .53052 L p .707 .577 .707 r
F P
0 g
s
.48372 .62503 m .4742 .65972 L .46237 .64611 L p .707 .577 .707 r
F P
0 g
s
.46237 .64611 m .47189 .61142 L .48372 .62503 L p .707 .577 .707 r
F P
0 g
s
.31024 .55673 m .31906 .50285 L .34293 .49948 L p .707 .577 .707 r
F P
0 g
s
.31222 .56866 m .3027 .60335 L .28649 .60946 L p .707 .577 .707 r
F P
0 g
s
.28036 .64359 m .28566 .62647 L .30182 .62051 L p .707 .577 .707 r
F P
0 g
s
.47186 .68191 m .46656 .69904 L .45491 .68479 L p .707 .577 .707 r
F P
0 g
s
.45491 .68479 m .46021 .66767 L .47186 .68191 L p .707 .577 .707 r
F P
0 g
s
.34293 .49948 m .33411 .55336 L .31024 .55673 L p .707 .577 .707 r
F P
0 g
s
.46133 .51959 m .45251 .57346 L .42545 .5641 L p .707 .577 .707 r
F P
0 g
s
.42545 .5641 m .43427 .51023 L .46133 .51959 L p .707 .577 .707 r
F P
0 g
s
.30182 .62051 m .29652 .63763 L .28036 .64359 L p .707 .577 .707 r
F P
0 g
s
.33411 .55336 m .34293 .49948 L .37202 .49966 L p .707 .577 .707 r
F P
0 g
s
.3027 .60335 m .31222 .56866 L .33578 .56669 L p .707 .577 .707 r
F P
0 g
s
.47189 .61142 m .46237 .64611 L .44227 .63244 L p .707 .577 .707 r
F P
0 g
s
.44227 .63244 m .45179 .59775 L .47189 .61142 L p .707 .577 .707 r
F P
0 g
s
.43427 .51023 m .42545 .5641 L .39468 .55724 L p .707 .577 .707 r
F P
0 g
s
.39468 .55724 m .4035 .50336 L .43427 .51023 L p .707 .577 .707 r
F P
0 g
s
.3632 .55354 m .37202 .49966 L .4035 .50336 L p .707 .577 .707 r
F P
0 g
s
.37202 .49966 m .3632 .55354 L .33411 .55336 L p .707 .577 .707 r
F P
0 g
s
.33578 .56669 m .32626 .60138 L .3027 .60335 L p .707 .577 .707 r
F P
0 g
s
.4035 .50336 m .39468 .55724 L .3632 .55354 L p .707 .577 .707 r
F P
0 g
s
.29652 .63763 m .30182 .62051 L .32527 .61894 L p .707 .577 .707 r
F P
0 g
s
.32626 .60138 m .33578 .56669 L .36441 .56903 L p .707 .577 .707 r
F P
0 g
s
.46021 .66767 m .45491 .68479 L .43504 .67033 L p .707 .577 .707 r
F P
0 g
s
.43504 .67033 m .44034 .6532 L .46021 .66767 L p .707 .577 .707 r
F P
0 g
s
.45179 .59775 m .44227 .63244 L .41587 .62006 L p .707 .577 .707 r
F P
0 g
s
.41587 .62006 m .4254 .58537 L .45179 .59775 L p .707 .577 .707 r
F P
0 g
s
.32527 .61894 m .31997 .63606 L .29652 .63763 L p .707 .577 .707 r
F P
0 g
s
.36441 .56903 m .35488 .60373 L .32626 .60138 L p .707 .577 .707 r
F P
0 g
s
.35488 .60373 m .36441 .56903 L .39528 .57547 L p .707 .577 .707 r
F P
0 g
s
.4254 .58537 m .41587 .62006 L .38576 .61016 L p .707 .577 .707 r
F P
0 g
s
.38576 .61016 m .39528 .57547 L .4254 .58537 L p .707 .577 .707 r
F P
0 g
s
.31997 .63606 m .32527 .61894 L .3537 .62192 L p .707 .577 .707 r
F P
0 g
s
.39528 .57547 m .38576 .61016 L .35488 .60373 L p .707 .577 .707 r
F P
0 g
s
.44034 .6532 m .43504 .67033 L .40891 .65706 L p .707 .577 .707 r
F P
0 g
s
.40891 .65706 m .4142 .63993 L .44034 .6532 L p .707 .577 .707 r
F P
0 g
s
.3537 .62192 m .34841 .63904 L .31997 .63606 L p .707 .577 .707 r
F P
0 g
s
.34841 .63904 m .3537 .62192 L .38435 .62915 L p .707 .577 .707 r
F P
0 g
s
.4142 .63993 m .40891 .65706 L .37905 .64628 L p .707 .577 .707 r
F P
0 g
s
.37905 .64628 m .38435 .62915 L .4142 .63993 L p .707 .577 .707 r
F P
0 g
s
.38435 .62915 m .37905 .64628 L .34841 .63904 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolA002;Ool007aoo`D0
009JEP03001JEUYF00QJEP04001JEUYFFUH60025Ool007Qoo`@000MJEP03001JEUYF00QJEP03001J
EUYF00MJEPH007moo`00MGoo0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00NGoo001cOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP06FUH5001dOol0079oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEP000080075oo`00LGoo00<005YF000015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF0P00Kgoo001aOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH3001/Ool0071oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP8006Yoo`00L7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00J7oo001`
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP02001VOol006moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH2
001TOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0@FUH2001ROol006moo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001oogoo05moo`00Kgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF0P00H7oo001_Ool00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH01000FUH00000GWoo001_Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00Oomoo`1K
Ool006ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0<FUH00`00Oomoo`1JOol006ioo`04001JEUYF0004
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1JOol006ioo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001oogoo05Yoo`00KWoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00<007ooOol0FGoo001^Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00Oomoo`1IOol006ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0005]oo`00KGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
05]oo`00KGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005]oo`00
KGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0Fgoo001]Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUILOol006eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP03001JEUYF05aoo`00KGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000G7oo001/Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1L
Ool006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF05eoo`00K7oo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH0GGoo001/Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001MOol006]oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEWoo05eoo`00Jgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YFFUH0GWoo001[Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001N
Ool006]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo
00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0GWoo001ZOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIJEP1OOol006Yoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF0P0035YF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001Y
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIoo`1OOol006Uoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000H7oo001YOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo
061oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P00HWoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0
001ROol006Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00069oo`00
Igoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001SOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006=oo`00IWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
0000Hgoo001VOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001NOol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol005Uoo`D000=J
EP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Aoo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
I7oo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001TOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000D000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
15YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Io
o`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Uooa0004eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEP0000Aoo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00DWoo00<005YF0000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<004=oo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@003moo`00DWoo00<005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00
DWoo0P000eYF1@000UYF00@005YFFUIJEP<000IJEPL000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP<003Yoo`00DWoo00=JEP00FUH00`001EYF00<005YFFUH015YF10000eYF00@005YFFUIJEPL0009J
EP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Qoo`00DGoo00@005YF0000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@0009JEPH0009JEP@000MJEP03001JEUYF
00=JEP05001JEUYFFUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF0`00=Woo001AOol30002FUH00`00FUH0000A0002FUH80006FUH20004FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF008003Aoo`00DGoo00<005YFFUH00UYF0`001UYF00<005YFFUH01EYF
00<005YFFUH05@0000=JEP00FUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000bOol0055oo`03001JEUYF
0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJ
EP8000IJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000aOol0059oo`<0009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YF0000<7oo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUH00002FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00=goo40002Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH0100035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000=oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
00IJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUH000000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP06001JEUYF001JEP00;Woo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP050003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20004FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000AJEP00FUIJEPD0009JEP04001JEUYFFUH30007Ool70006FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01`00FUIJEUYF001JEP0002ioo`00;goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF4P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF0`000UYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP00FUH40006FUH00`00FUIJEP04FUH40006Ool80002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00000020001UYF00@005YFFUIJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH010000Woo1@000goo10001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Mo
o`@0009JEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP8000AJEP@00003FUH0000000<0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP03FUH700000eYF001J
EP08FUH00`00FUIJEP02FUH>0005FUH01000FUIJEUYF0P00;goo000]Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP020002FUH0
1000FUIJEP000UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001J
EUYF00AJEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF000015YF1P000UYF00<005YFFUH00UYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YF0000009JEP03001JEUYF009JEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF4P0000=JEP00FUH0
1`0015YF0`001UYF00<005YFFUH015YF00H005YFFUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH00004
0009FUH00`00FUIJEP05FUH01000FUIJEUYF0`0015YF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0`001EYF
00<005YFFUH01UYF00<005YFFUH010001UYF2@0015YF00<005YFFUH015YF00@005YFFUIJEP8000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF100000=JEP00FUH025YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00EJEP03001JEUYF
00AJEP80009JEP03001JEP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000]JEP8000IJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0002moo`00;7oo
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJEP04001JEP000004FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00800003FUH007oo02ioo`00:goo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1@000UYF00<0
05YFFUH00UYF1P001eYF00<005YFFUH01EYF0P001UYF00D005YFFUIJEP0000=JEP07001JEUYFFUH0
05YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000006FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP02FUH30003FUH01000
FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<0
05YFFUH00UYF0P00<7oo000[Ool00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH00UYF
0`0000=JEP0000001UYF00<005YFFUH01EYF00<005YFFUH015YF100025YF00<005YFFUH00P0000=J
EP00FUH01UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20004FUH01`00FUIJEUYF001JEP00031oo`00:goo0P000eYF1@00
0UYF00<005YF00000`0027oo1P000UYF0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00=JEP8000QJEP06001JEUYF001JEP002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH7
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01`00FUIJEUYF001J
EP00031oo`00:goo00=JEP00FUH00`001UYF00<005YFFUH00eYF10001goo1P0000AJEP00000000AJ
EP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP06FUH20002FUH5
0002FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000UYF2@0000=oo`00000020001UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH2000aOol002Yoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP040002Ool500001Goo001JEP00FUH00P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0025YF0`000eYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0000300000eYF001JEP05FUH30003Ool40002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000bOol002Yoo`<0009JEP03001JEP000140009J
EPL00003Ool005YF00=JEP<000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0005FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P001Goo
10000UYF10001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP02FUH3
0006FUH00`00FUIJEP05FUH00`00FUIJEP0<0004FUH500000eYF001JEP020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YF00002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF0`000eYF00<005YFFUH00UYF
0P001goo2P000UYF00<005YFFUH01UYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP020002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP02FUH20003
FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH0
0003FUH01000FUIJEUYF0`001UYF0P0037oo1`0025YF00<005YFFUH00eYF00<005YF0000=7oo000Z
Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP04001JEUYF0002FUH200000eYF001JEP0200000eYF001JEP030008FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH00eYF0P001EYF00<005YF00002Woo1@00
0goo0P001UYF00<005YFFUH00eYF00@005YFFUH003=oo`00:goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF0P000eYF0P00
00AJEP00FUIJEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP00FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YF
FUH015YF0`000eYF00@005YFFUH000Uoo`D000Eoo`8000=JEP03001JEUYF00AJEP05001JEUYFFUH0
000bOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP000003FUHC0008Ool50007Ool200000eYF001JEP04FUH00`00FUIJEP02
FUH00`00Oomoo`0`Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<00005FUH005YFFUH00005FUH00`00FUIJEP030004FUH4
0008FUH01000FUIJEUYF0`0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF0000009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEP0000<000Eoo`<0
00Yoo`8000EJEP03001JEUYF009JEP80035oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF0`0015YF00<005YFFUH00P0000=JEP00FUH01EYF00<0
05YFFUH00eYF20001eYF00<005YFFUH00eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
15YF100047oo00<005YFFUH00UYF00L005YFFUIJEP00FUH0000aOol002Yoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP03FUH20006FUH00`00FUIJEP06FUH90003FUH01000FUIJEUYF1@000UYF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000ioo`80009JEP07001JEUYFFUH005YF0000
<Goo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30007FUH30003FUH00`00FUIJEP05FUH60004FUH70004FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04
001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000=Ool20004FUH00`00FUIoo`0a
Ool002Uoo`03001JEP00009JEQ8000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP06001JEP00001JEP001eYF00<005YF00000P001eYF00<005YFFUH01eYF0P0000=JEP0000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000eYF10000UYF00<0
05YFFUH00UYF1`001UYF00<005YFFUH01UYF0P0037oo00<005YFFUH00UYF0P00<Woo000YOol20000
15YF0000000017oo0`001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP80
00EJEP03001JEUYF009JEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000aJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000800003FUH00000009JEP05
001JEUYFFUH00007FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF0`002goo00@005YFFUIJEP80
039oo`00:Goo0`000eYF00<007ooOol017oo0P0015YF00<005YFFUH01EYF100025YF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00EJEP@0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH20002
Ool2000015YF0000000025YF00<005YFFUH01EYF10001eYF00@005YFFUIJEPd00003FUH0000003=o
o`00:Goo0P0015YF0P001goo0`0000=JEP00FUH01eYF00<005YFFUH00`0015YF00<005YFFUH01UYF
00<005YFFUH010002EYF00<005YFFUH010002UYF00<005YFFUH01eYF100035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF3P0025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<0
05YFFUH00eYF0`001UYF00<005YF00000P00<goo000XOol30003FUH00`00FUIJEP020008Ool40006
FUH00`00FUIJEP03FUH300000eYF001JEP06FUH01P00FUIJEUYF001JEP<000QJEP03001JEUYF00AJ
EPL000=JEP04001JEUYFFUH6000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF00D005YF000005YF008000MJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYFFUH2000cOol002Qoo`03001JEP0000=JEP/0
00Ioo`@0009JEP03001JEUYF00IJEP8000MJEP07001JEUYFFUH005YF00000UYF0`0015YF00<005YF
FUH01eYF00<005YFFUH00UYF1`000eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00IJEP03001JEP00008000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP8000QJEP<000=JEP03001JEUYF00<003=oo`00:7oo00@005YFFUIJ
EP<000IJEP04001JEUYFFUH70003Ool70004FUH01000FUH000001EYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00=JEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00=JEP<00004FUH0
00000006FUH01000FUIJEP000UYF00<005YFFUH00P00=7oo000YOol30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040006Ool:0003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH40007FUH00`00FUIJEP02FUH50003FUH20003FUH00`00FUIJEP02FUH20003FUH2000dOol0
02Uoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000aoo`<000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00
0004FUH30002FUH00`00FUIJEP04FUH01000FUH005YF0P001EYF00<005YFFUH00UYF1@001EYF0P00
00=JEP00FUH01EYF00@005YFFUH003Eoo`00:Goo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH0100000=J
EP00FUH01P0015YF00@005YFFUIJEPH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUH00006FUH00`00FUIJEP02
00001UYF00000000FUH000EJEPD000MJEP8000IJEP@003Eoo`00:7oo0P000UYF4P001eYF00<005YF
FUH00UYF0`002Woo0P0000AJEP00FUH000EJEP@000EJEP03001JEUYF00EJEPP000AJEPP000YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEP0000AJEP80
00EJEP03001JEUYF009JEP8000=oo`H0009JEP<000QJEP03001JEP0000AJEP04001JEP00000fOol0
02Moo`800004FUH000000006FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP06FUH3
0009Ool01@00FUIJEP00FUH010002EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YFFUIJEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP8000IJEP03
001JEUYF009JEP03001JEUYF009JEP8000Uoo`P000AJEP04001JEUYFFUH20002FUH01000FUIJEP00
=Woo000WOol30002Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40008FUH01000
FUH0000027oo0UYF0P000eYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YF
FUH01EYF10000UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF
0P001UYF0`000UYF00L005YFFUIJEP00FUH0000AOol<0004FUH00`00Oomoo`0cOol002Ioo`<000Ao
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01000FUIJEUYF0`0017oo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF
10002UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF00<005YF000015YF00@005YF
FUIJEP<000=JEP03001JEP0001aoo`03001JEUYF009JEP03001oogoo03=oo`009Woo00@005YF0000
00Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF0P00
0Woo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00@0
05YFFUIJEP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH20002FUH2000NOol01@00FUIJEUYF0000=Goo000VOol01@00FUH005YF
00001Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH01eYF1P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF0P0025YF10007goo00D0
05YF001JEP0003Aoo`009Woo00<005YFFUH00UYF00<007ooOol017oo0P001UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001UYF00<005YFFUH00P0000=JEP00FUH03EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH01eYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0
<goo000WOol00`00FUIJEP02FUH00`00Oomoo`05Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP020004FUH01@00FUIJEUYF000045YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF0`0025YF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000=7oo000WOol00`00FUIJEP02FUH20008
Ool200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP07FUH0
1000FUH000000eYF00<005YFFUH01UYF0`006Woo0P00=Goo000XOol01000FUIJEP000UYF0P0027oo
0`0025YF00<005YFFUH01EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000Woo0`001eYF00@005YFFUIJEP800003FUH005YF00QJ
EP03001JEP0000<001Aoo`@003Eoo`00:7oo00@005YFFUH000AJEP03001oogoo00Qoo`<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP03001JEP0000Eoo`8000AJEP03001JEUYF00AJEP<000MJEP03001JEUYF00AJEPH000Qo
o`H0009JEP03001oogoo03Aoo`00:Goo0P001UYF00<007ooOol02Woo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00@005YFFUH0009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP8000EJEP8000Qoo`<00003FUH0
05YF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJ
EP8003Ioo`00:Woo00<005YFFUH015YF0`003Goo0`0015YF100025YF00@005YFFUIJEP<00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEP0000=JEP03001JEP0000]oo`8000EJEP03001JEUYF009JEP@00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000gOol002]oo`8000AJEP03001J
EUYF008000ioo`P000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00800004
FUH005YF000=Ool00`00FUIJEP02FUH01`00FUIJEUYF001JEP00009oo`@000IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYFFUH2000gOol002eoo`04001JEUYF0005FUH2000?Ool80004FUH0
1000FUIJEUYF1@000UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00Ool03Goo0P000UYF
00L005YFFUIJEP00FUH00006Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000hOol002ioo`<000MJEP<000aoo`D000=oo`P000Aoo`03001JEUYF00<000QJEP03001JEUYF00MJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP800003FUH007oo00moo`8000AJEP03001JEWoo00Yoo`H000AJEP04001JEUYFFUH6000jOol0031o
o`03001JEUYF00IJEP04001JEP00000;Ool3000AOol200000eYF001oo`02000@FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000
0002000>Ool00`00FUIJEP02FUH2000AOol80010Ool0035oo`8000EJEP03001JEUYF009JEP<001eo
o`03001JEP0000=oo`8000iJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000AJEP<000aoo`04001JEUYFFUH2001IOol003=oo`8000=JEP03
001JEUYF00EJEP@001Uoo`03001JEP0000Eoo`8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEP0000d00003
FUH0000005Yoo`00=Goo0`002EYF00<005YFFUH010005Goo0P0027oo0`002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YF00000P00FWoo000gOol20008FUH00`00FUIJ
EP04FUH6000=Ool4000;Ool2000DFUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF0P001EYF00@005YFFUIJEP8005Yoo`00
>Goo0`0015YF00<005YFFUH01eYF00@005YFFUIJEPd0009JEP8000eoo`<0015JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP07
FUH20004FUH00`00FUIJEP03001JOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF0080015oo`8000mJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP<000MJEP03001JEP0000=JEP03001JEUYF008005]oo`00?goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8001=oo`@001MJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP8000AJEP04001JEUYFFUH3
0003FUH2001KOol0049oo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008001Qo
o`@0019JEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH50004FUH300000eYF
001JEP04FUH01@00FUIJEUYF0000G7oo0016Ool60004FUH00`00FUIJEP04FUH01000FUH000007Woo
10003UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000AJEPD000MJEP8000IJEP04001J
EP00001LOol004aoo`d002Aoo`P000IJEP03001JEUYF00UJEP03001JEUYF00=JEPT000=JEPD000MJ
EP03001JEP0000AJEP04001JEP00001MOol008EooaP000Uoo`L000MJEP04001JEUYFFUH20002FUH0
0`00FUH0001NOol008aoo`03001JEUYF00AJEP<001Aooa8000=JEP03001oogoo05]oo`00SGoo00<0
05YFFUH00UYF00@005YFFUIJEP8002=oo`03001JEUYF009JEP03001oogoo05Yoo`00SWoo0P000UYF
00<005YFFUH00eYF0P008Woo00D005YFFUIJEP0005aoo`00T7oo0P0025YF0P008Goo00D005YF001J
EP0005]oo`00TGoo00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0FWoo002BOol2
0006FUH00`00FUIJEP02FUH3000MOol00`00FUH0001KOol009Aoo`8000=JEP03001JEUYF00IJEP<0
01Yoo`8005aoo`00UWoo0P0000=JEP00FUH025YF00<005YF00000`005Goo0`00G7oo002HOol30007
FUH00`00FUIJEP04FUH6000=Ool200000eYF001oo`1LOol009]oo`8000EJEP03001JEUYF00IJEP04
001JEUYFFUH=0002FUH2001MOol009eoo`<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol00:1oo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008005ioo`00Y7oo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005mo
o`00Z7oo1P0015YF00<005YFFUH015YF00@005YF0000061oo`00[Woo3@00HWoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58613 .75537 m .59496 .70149 L .56418 .69463 L p .707 .577 .707 r
F P
0 g
s
.59496 .70149 m .58613 .75537 L .61761 .75907 L p .707 .577 .707 r
F P
0 g
s
.61761 .75907 m .62643 .7052 L .59496 .70149 L p .707 .577 .707 r
F P
0 g
s
.62643 .7052 m .61761 .75907 L .6467 .75925 L p .707 .577 .707 r
F P
0 g
s
.6467 .75925 m .65553 .70537 L .62643 .7052 L p .707 .577 .707 r
F P
0 g
s
.55536 .7485 m .56418 .69463 L .53713 .68527 L p .707 .577 .707 r
F P
0 g
s
.56418 .69463 m .55536 .7485 L .58613 .75537 L p .707 .577 .707 r
F P
0 g
s
.65553 .70537 m .6467 .75925 L .67057 .75588 L p .707 .577 .707 r
F P
0 g
s
.67057 .75588 m .67939 .702 L .65553 .70537 L p .707 .577 .707 r
F P
0 g
s
.5283 .73915 m .53713 .68527 L .51643 .67434 L p .707 .577 .707 r
F P
0 g
s
.53713 .68527 m .5283 .73915 L .55536 .7485 L p .707 .577 .707 r
F P
0 g
s
.5759 .82053 m .58542 .78584 L .55531 .77595 L p .707 .577 .707 r
F P
0 g
s
.58542 .78584 m .5759 .82053 L .60678 .82697 L p .707 .577 .707 r
F P
0 g
s
.60678 .82697 m .6163 .79228 L .58542 .78584 L p .707 .577 .707 r
F P
0 g
s
.54579 .81064 m .55531 .77595 L .52891 .76356 L p .707 .577 .707 r
F P
0 g
s
.55531 .77595 m .54579 .81064 L .5759 .82053 L p .707 .577 .707 r
F P
0 g
s
.6163 .79228 m .60678 .82697 L .6354 .82931 L p .707 .577 .707 r
F P
0 g
s
.6354 .82931 m .64492 .79462 L .6163 .79228 L p .707 .577 .707 r
F P
0 g
s
.51643 .67434 m .50761 .72821 L .5283 .73915 L p .707 .577 .707 r
F P
0 g
s
.67939 .702 m .67057 .75588 L .68688 .7493 L p .707 .577 .707 r
F P
0 g
s
.68688 .7493 m .6957 .69542 L .67939 .702 L p .707 .577 .707 r
F P
0 g
s
.50761 .72821 m .51643 .67434 L .50413 .6629 L p .707 .577 .707 r
F P
0 g
s
.51939 .79825 m .52891 .76356 L .50881 .74989 L p .707 .577 .707 r
F P
0 g
s
.52891 .76356 m .51939 .79825 L .54579 .81064 L p .707 .577 .707 r
F P
0 g
s
.64492 .79462 m .6354 .82931 L .65896 .82734 L p .707 .577 .707 r
F P
0 g
s
.65896 .82734 m .66849 .79265 L .64492 .79462 L p .707 .577 .707 r
F P
0 g
s
.56867 .8671 m .57397 .84997 L .54412 .83919 L p .707 .577 .707 r
F P
0 g
s
.57397 .84997 m .56867 .8671 L .59932 .87433 L p .707 .577 .707 r
F P
0 g
s
.59932 .87433 m .60461 .85721 L .57397 .84997 L p .707 .577 .707 r
F P
0 g
s
.53882 .85632 m .54412 .83919 L .51798 .82592 L p .707 .577 .707 r
F P
0 g
s
.54412 .83919 m .53882 .85632 L .56867 .8671 L p .707 .577 .707 r
F P
0 g
s
.60461 .85721 m .59932 .87433 L .62776 .87731 L p .707 .577 .707 r
F P
0 g
s
.62776 .87731 m .63305 .86019 L .60461 .85721 L p .707 .577 .707 r
F P
0 g
s
.50881 .74989 m .49929 .78458 L .51939 .79825 L p .707 .577 .707 r
F P
0 g
s
.50413 .6629 m .4953 .71677 L .50761 .72821 L p .707 .577 .707 r
F P
0 g
s
.51798 .82592 m .51268 .84305 L .53882 .85632 L p .707 .577 .707 r
F P
0 g
s
.6957 .69542 m .68688 .7493 L .69403 .74015 L p .707 .577 .707 r
F P
0 g
s
.69403 .74015 m .70285 .68627 L .6957 .69542 L p .707 .577 .707 r
F P
0 g
s
.49929 .78458 m .50881 .74989 L .49698 .73628 L p .707 .577 .707 r
F P
0 g
s
.51268 .84305 m .51798 .82592 L .49811 .81146 L p .707 .577 .707 r
F P
0 g
s
.66849 .79265 m .65896 .82734 L .67516 .82124 L p .707 .577 .707 r
F P
0 g
s
.67516 .82124 m .68469 .78655 L .66849 .79265 L p .707 .577 .707 r
F P
0 g
s
.4953 .71677 m .50413 .6629 L .50141 .65207 L p .707 .577 .707 r
F P
0 g
s
.63305 .86019 m .62776 .87731 L .6512 .87574 L p .707 .577 .707 r
F P
0 g
s
.6512 .87574 m .6565 .85862 L .63305 .86019 L p .707 .577 .707 r
F P
0 g
s
.49811 .81146 m .49281 .82858 L .51268 .84305 L p .707 .577 .707 r
F P
0 g
s
.49698 .73628 m .48746 .77098 L .49929 .78458 L p .707 .577 .707 r
F P
0 g
s
.49281 .82858 m .49811 .81146 L .48646 .79722 L p .707 .577 .707 r
F P
0 g
s
.50141 .65207 m .49259 .70595 L .4953 .71677 L p .707 .577 .707 r
F P
0 g
s
.44794 .82092 m .52717 .33431 L .48372 .32466 L p .707 .577 .707 r
F P
0 g
s
.48746 .77098 m .49698 .73628 L .49457 .72407 L p .707 .577 .707 r
F P
0 g
s
.48646 .79722 m .48117 .81434 L .49281 .82858 L p .707 .577 .707 r
F P
0 g
s
.49259 .70595 m .50141 .65207 L .50856 .64292 L p .707 .577 .707 r
F P
0 g
s
.49457 .72407 m .48505 .75876 L .48746 .77098 L p .707 .577 .707 r
F P
0 g
s
.48117 .81434 m .48646 .79722 L .48417 .78459 L p .707 .577 .707 r
F P
0 g
s
.50856 .64292 m .49974 .6968 L .49259 .70595 L p .707 .577 .707 r
F P
0 g
s
.48417 .78459 m .47888 .80172 L .48117 .81434 L p .707 .577 .707 r
F P
0 g
s
.48505 .75876 m .49457 .72407 L .50182 .71444 L p .707 .577 .707 r
F P
0 g
s
.49974 .6968 m .50856 .64292 L .52486 .63634 L p .707 .577 .707 r
F P
0 g
s
.50182 .71444 m .4923 .74913 L .48505 .75876 L p .707 .577 .707 r
F P
0 g
s
.47888 .80172 m .48417 .78459 L .49147 .77482 L p .707 .577 .707 r
F P
0 g
s
.52486 .63634 m .51604 .69022 L .49974 .6968 L p .707 .577 .707 r
F P
0 g
s
.49147 .77482 m .48617 .79195 L .47888 .80172 L p .707 .577 .707 r
F P
0 g
s
.4923 .74913 m .50182 .71444 L .51802 .70833 L p .707 .577 .707 r
F P
0 g
s
.51802 .70833 m .5085 .74303 L .4923 .74913 L p .707 .577 .707 r
F P
0 g
s
.48617 .79195 m .49147 .77482 L .50763 .76886 L p .707 .577 .707 r
F P
0 g
s
.50763 .76886 m .50233 .78598 L .48617 .79195 L p .707 .577 .707 r
F P
0 g
s
.52717 .33431 m .44794 .82092 L .49238 .82611 L p .707 .577 .707 r
F P
0 g
s
.49238 .82611 m .57161 .33951 L .52717 .33431 L p .707 .577 .707 r
F P
0 g
s
.6565 .85862 m .6512 .87574 L .66736 .86978 L p .707 .577 .707 r
F P
0 g
s
.66736 .86978 m .67266 .85266 L .6565 .85862 L p .707 .577 .707 r
F P
0 g
s
.51604 .69022 m .52486 .63634 L .54873 .63297 L p .707 .577 .707 r
F P
0 g
s
.54873 .63297 m .53991 .68685 L .51604 .69022 L p .707 .577 .707 r
F P
0 g
s
.53991 .68685 m .54873 .63297 L .57783 .63315 L p .707 .577 .707 r
F P
0 g
s
.5085 .74303 m .51802 .70833 L .54159 .70636 L p .707 .577 .707 r
F P
0 g
s
.57783 .63315 m .56901 .68703 L .53991 .68685 L p .707 .577 .707 r
F P
0 g
s
.54159 .70636 m .53207 .74105 L .5085 .74303 L p .707 .577 .707 r
F P
0 g
s
.50233 .78598 m .50763 .76886 L .53107 .76729 L p .707 .577 .707 r
F P
0 g
s
.53207 .74105 m .54159 .70636 L .57021 .70871 L p .707 .577 .707 r
F P
0 g
s
.53107 .76729 m .52578 .78442 L .50233 .78598 L p .707 .577 .707 r
F P
0 g
s
.57021 .70871 m .56069 .7434 L .53207 .74105 L p .707 .577 .707 r
F P
0 g
s
.52578 .78442 m .53107 .76729 L .55951 .77027 L p .707 .577 .707 r
F P
0 g
s
.55951 .77027 m .55421 .7874 L .52578 .78442 L p .707 .577 .707 r
F P
0 g
s
.57161 .33951 m .49238 .82611 L .53346 .82634 L p .707 .577 .707 r
F P
0 g
s
.53346 .82634 m .61269 .33973 L .57161 .33951 L p .707 .577 .707 r
F P
0 g
s
.70285 .68627 m .69403 .74015 L .69131 .72932 L p .707 .577 .707 r
F P
0 g
s
.69131 .72932 m .70013 .67545 L .70285 .68627 L p .707 .577 .707 r
F P
0 g
s
.68469 .78655 m .67516 .82124 L .68242 .81161 L p .707 .577 .707 r
F P
0 g
s
.68242 .81161 m .69194 .77692 L .68469 .78655 L p .707 .577 .707 r
F P
0 g
s
.40449 .81126 m .48372 .32466 L .44551 .31148 L p .707 .577 .707 r
F P
0 g
s
.48372 .32466 m .40449 .81126 L .44794 .82092 L p .707 .577 .707 r
F P
0 g
s
.56901 .68703 m .57783 .63315 L .6093 .63685 L p .707 .577 .707 r
F P
0 g
s
.6093 .63685 m .60048 .69073 L .56901 .68703 L p .707 .577 .707 r
F P
0 g
s
.56069 .7434 m .57021 .70871 L .60109 .71514 L p .707 .577 .707 r
F P
0 g
s
.60109 .71514 m .59157 .74983 L .56069 .7434 L p .707 .577 .707 r
F P
0 g
s
.55421 .7874 m .55951 .77027 L .59016 .7775 L p .707 .577 .707 r
F P
0 g
s
.59016 .7775 m .58486 .79463 L .55421 .7874 L p .707 .577 .707 r
F P
0 g
s
.61269 .33973 m .53346 .82634 L .56716 .82156 L p .707 .577 .707 r
F P
0 g
s
.56716 .82156 m .64639 .33496 L .61269 .33973 L p .707 .577 .707 r
F P
0 g
s
.36628 .79809 m .44551 .31148 L .41629 .29608 L p .707 .577 .707 r
F P
0 g
s
.44551 .31148 m .36628 .79809 L .40449 .81126 L p .707 .577 .707 r
F P
0 g
s
.67266 .85266 m .66736 .86978 L .67465 .86001 L p .707 .577 .707 r
F P
0 g
s
.67465 .86001 m .67995 .84289 L .67266 .85266 L p .707 .577 .707 r
F P
0 g
s
.69194 .77692 m .68242 .81161 L .68001 .79939 L p .707 .577 .707 r
F P
0 g
s
.68001 .79939 m .68953 .7647 L .69194 .77692 L p .707 .577 .707 r
F P
0 g
s
.70013 .67545 m .69131 .72932 L .67901 .71789 L p .707 .577 .707 r
F P
0 g
s
.67901 .71789 m .68783 .66401 L .70013 .67545 L p .707 .577 .707 r
F P
0 g
s
.24313 .71392 m .25195 .66004 L .22117 .65318 L p .707 .577 .707 r
F P
0 g
s
.25195 .66004 m .24313 .71392 L .2746 .71762 L p .707 .577 .707 r
F P
0 g
s
.2746 .71762 m .28342 .66374 L .25195 .66004 L p .707 .577 .707 r
F P
0 g
s
.28342 .66374 m .2746 .71762 L .3037 .7178 L p .707 .577 .707 r
F P
0 g
s
.3037 .7178 m .31252 .66392 L .28342 .66374 L p .707 .577 .707 r
F P
0 g
s
.21235 .70705 m .22117 .65318 L .19412 .64382 L p .707 .577 .707 r
F P
0 g
s
.22117 .65318 m .21235 .70705 L .24313 .71392 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64008 .64372 m .63125 .69759 L .60048 .69073 L p .707 .577 .707 r
F P
0 g
s
.60048 .69073 m .6093 .63685 L .64008 .64372 L p .707 .577 .707 r
F P
0 g
s
.6312 .72504 m .62168 .75973 L .59157 .74983 L p .707 .577 .707 r
F P
0 g
s
.59157 .74983 m .60109 .71514 L .6312 .72504 L p .707 .577 .707 r
F P
0 g
s
.62001 .78828 m .61471 .80541 L .58486 .79463 L p .707 .577 .707 r
F P
0 g
s
.58486 .79463 m .59016 .7775 L .62001 .78828 L p .707 .577 .707 r
F P
0 g
s
.64639 .33496 m .56716 .82156 L .59018 .81227 L p .707 .577 .707 r
F P
0 g
s
.59018 .81227 m .66941 .32566 L .64639 .33496 L p .707 .577 .707 r
F P
0 g
s
.35269 .65397 m .34387 .70785 L .35102 .6987 L p .707 .577 .707 r
F P
0 g
s
.35102 .6987 m .35984 .64482 L .35269 .65397 L p .707 .577 .707 r
F P
0 g
s
.34168 .73891 m .33216 .77361 L .33941 .76398 L p .707 .577 .707 r
F P
0 g
s
.33941 .76398 m .34893 .72928 L .34168 .73891 L p .707 .577 .707 r
F P
0 g
s
.35984 .64482 m .35102 .6987 L .3483 .68787 L p .707 .577 .707 r
F P
0 g
s
.3483 .68787 m .35713 .634 L .35984 .64482 L p .707 .577 .707 r
F P
0 g
s
.33216 .77361 m .34168 .73891 L .32548 .74502 L p .707 .577 .707 r
F P
0 g
s
.34893 .72928 m .33941 .76398 L .337 .75176 L p .707 .577 .707 r
F P
0 g
s
.337 .75176 m .34652 .71707 L .34893 .72928 L p .707 .577 .707 r
F P
0 g
s
.33639 .66055 m .32756 .71443 L .34387 .70785 L p .707 .577 .707 r
F P
0 g
s
.34387 .70785 m .35269 .65397 L .33639 .66055 L p .707 .577 .707 r
F P
0 g
s
.35713 .634 m .3483 .68787 L .336 .67643 L p .707 .577 .707 r
F P
0 g
s
.336 .67643 m .34482 .62256 L .35713 .634 L p .707 .577 .707 r
F P
0 g
s
.34652 .71707 m .337 .75176 L .32516 .73815 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .33469 .70346 L .34652 .71707 L p .707 .577 .707 r
F P
0 g
s
.33706 .78269 m .41629 .29608 L .39891 .27996 L p .707 .577 .707 r
F P
0 g
s
.41629 .29608 m .33706 .78269 L .36628 .79809 L p .707 .577 .707 r
F P
0 g
s
.67995 .84289 m .67465 .86001 L .67236 .84739 L p .707 .577 .707 r
F P
0 g
s
.67236 .84739 m .67766 .83026 L .67995 .84289 L p .707 .577 .707 r
F P
0 g
s
.31252 .66392 m .3037 .7178 L .32756 .71443 L p .707 .577 .707 r
F P
0 g
s
.32756 .71443 m .33639 .66055 L .31252 .66392 L p .707 .577 .707 r
F P
0 g
s
.1853 .6977 m .19412 .64382 L .17342 .63289 L p .707 .577 .707 r
F P
0 g
s
.19412 .64382 m .1853 .6977 L .21235 .70705 L p .707 .577 .707 r
F P
0 g
s
.68783 .66401 m .67901 .71789 L .65831 .70695 L p .707 .577 .707 r
F P
0 g
s
.65831 .70695 m .66713 .65308 L .68783 .66401 L p .707 .577 .707 r
F P
0 g
s
.68953 .7647 m .68001 .79939 L .66817 .78578 L p .707 .577 .707 r
F P
0 g
s
.66817 .78578 m .6777 .75109 L .68953 .7647 L p .707 .577 .707 r
F P
0 g
s
.23289 .7729 m .24241 .73821 L .2123 .72831 L p .707 .577 .707 r
F P
0 g
s
.24241 .73821 m .23289 .7729 L .26377 .77934 L p .707 .577 .707 r
F P
0 g
s
.26377 .77934 m .27329 .74465 L .24241 .73821 L p .707 .577 .707 r
F P
0 g
s
.20278 .76301 m .2123 .72831 L .1859 .71593 L p .707 .577 .707 r
F P
0 g
s
.2123 .72831 m .20278 .76301 L .23289 .7729 L p .707 .577 .707 r
F P
0 g
s
.27329 .74465 m .26377 .77934 L .29239 .78168 L p .707 .577 .707 r
F P
0 g
s
.29239 .78168 m .30191 .74699 L .27329 .74465 L p .707 .577 .707 r
F P
0 g
s
.17342 .63289 m .1646 .68676 L .1853 .6977 L p .707 .577 .707 r
F P
0 g
s
.1646 .68676 m .17342 .63289 L .16112 .62145 L p .707 .577 .707 r
F P
0 g
s
.66713 .65308 m .65831 .70695 L .63125 .69759 L p .707 .577 .707 r
F P
0 g
s
.63125 .69759 m .64008 .64372 L .66713 .65308 L p .707 .577 .707 r
F P
0 g
s
.17638 .75062 m .1859 .71593 L .1658 .70226 L p .707 .577 .707 r
F P
0 g
s
.1859 .71593 m .17638 .75062 L .20278 .76301 L p .707 .577 .707 r
F P
0 g
s
.30191 .74699 m .29239 .78168 L .31595 .77971 L p .707 .577 .707 r
F P
0 g
s
.31595 .77971 m .32548 .74502 L .30191 .74699 L p .707 .577 .707 r
F P
0 g
s
.22566 .81079 m .23096 .79366 L .20111 .78288 L p .707 .577 .707 r
F P
0 g
s
.23096 .79366 m .22566 .81079 L .25631 .81802 L p .707 .577 .707 r
F P
0 g
s
.25631 .81802 m .26161 .80089 L .23096 .79366 L p .707 .577 .707 r
F P
0 g
s
.67766 .83026 m .67236 .84739 L .66072 .83315 L p .707 .577 .707 r
F P
0 g
s
.66072 .83315 m .66601 .81602 L .67766 .83026 L p .707 .577 .707 r
F P
0 g
s
.66941 .32566 m .59018 .81227 L .60027 .79935 L p .707 .577 .707 r
F P
0 g
s
.60027 .79935 m .6795 .31275 L .66941 .32566 L p .707 .577 .707 r
F P
0 g
s
.6777 .75109 m .66817 .78578 L .64808 .77212 L p .707 .577 .707 r
F P
0 g
s
.64808 .77212 m .6576 .73742 L .6777 .75109 L p .707 .577 .707 r
F P
0 g
s
.19581 .80001 m .20111 .78288 L .17497 .76961 L p .707 .577 .707 r
F P
0 g
s
.20111 .78288 m .19581 .80001 L .22566 .81079 L p .707 .577 .707 r
F P
0 g
s
.26161 .80089 m .25631 .81802 L .28475 .821 L p .707 .577 .707 r
F P
0 g
s
.28475 .821 m .29004 .80387 L .26161 .80089 L p .707 .577 .707 r
F P
0 g
s
.32548 .74502 m .31595 .77971 L .33216 .77361 L p .707 .577 .707 r
F P
0 g
s
.34482 .62256 m .336 .67643 L .3153 .6655 L p .707 .577 .707 r
F P
0 g
s
.3153 .6655 m .32412 .61162 L .34482 .62256 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .30507 .72448 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.33469 .70346 m .32974 .72149 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.32974 .72149 m .32516 .73815 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.30507 .72448 m .31459 .68979 L .33469 .70346 L p .707 .577 .707 r
F P
0 g
s
.323 .75971 m .31771 .77683 L .29784 .76237 L p .707 .577 .707 r
F P
0 g
s
.29784 .76237 m .30314 .74524 L .323 .75971 L p .707 .577 .707 r
F P
0 g
s
.31968 .76657 m .36445 .49161 L p .39508 .26469 L .707 .577 .707 r
F P
0 g
s
.36445 .49161 m .39891 .27996 L .39735 .27375 L p .707 .577 .707 r
F P
0 g
s
.39735 .27375 m .39508 .26469 L p .36445 .49161 L .707 .577 .707 r
F P
0 g
s
.32935 .79107 m .33465 .77395 L .33694 .78657 L p .707 .577 .707 r
F P
0 g
s
.33465 .77395 m .32935 .79107 L .31771 .77683 L p .707 .577 .707 r
F P
0 g
s
.31771 .77683 m .323 .75971 L .33465 .77395 L p .707 .577 .707 r
F P
0 g
s
.39891 .27996 m .31968 .76657 L .33706 .78269 L p .707 .577 .707 r
F P
0 g
s
.1658 .70226 m .15628 .73695 L .17638 .75062 L p .707 .577 .707 r
F P
0 g
s
.17497 .76961 m .16967 .78673 L .19581 .80001 L p .707 .577 .707 r
F P
0 g
s
.16112 .62145 m .15229 .67532 L .1646 .68676 L p .707 .577 .707 r
F P
0 g
s
.16967 .78673 m .17497 .76961 L .1551 .75514 L p .707 .577 .707 r
F P
0 g
s
.15628 .73695 m .1658 .70226 L .15397 .68865 L p .707 .577 .707 r
F P
0 g
s
.29004 .80387 m .28475 .821 L .30819 .81943 L p .707 .577 .707 r
F P
0 g
s
.30819 .81943 m .31349 .80231 L .29004 .80387 L p .707 .577 .707 r
F P
0 g
s
.15229 .67532 m .16112 .62145 L .1584 .61062 L p .707 .577 .707 r
F P
0 g
s
.1551 .75514 m .14981 .77227 L .16967 .78673 L p .707 .577 .707 r
F P
0 g
s
.6576 .73742 m .64808 .77212 L .62168 .75973 L p .707 .577 .707 r
F P
0 g
s
.62168 .75973 m .6312 .72504 L .6576 .73742 L p .707 .577 .707 r
F P
0 g
s
.66601 .81602 m .66072 .83315 L .64085 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .81868 m .64615 .80156 L .66601 .81602 L p .707 .577 .707 r
F P
0 g
s
.15397 .68865 m .14445 .72334 L .15628 .73695 L p .707 .577 .707 r
F P
0 g
s
.14981 .77227 m .1551 .75514 L .14345 .7409 L p .707 .577 .707 r
F P
0 g
s
.1584 .61062 m .14958 .6645 L .15229 .67532 L p .707 .577 .707 r
F P
0 g
s
.31349 .80231 m .30819 .81943 L .32435 .81347 L p .707 .577 .707 r
F P
0 g
s
.32435 .81347 m .32965 .79634 L .31349 .80231 L p .707 .577 .707 r
F P
0 g
s
.14345 .7409 m .13816 .75803 L .14981 .77227 L p .707 .577 .707 r
F P
0 g
s
.14445 .72334 m .15397 .68865 L .15156 .67643 L p .707 .577 .707 r
F P
0 g
s
.6795 .31275 m .60027 .79935 L .59644 .78409 L p .707 .577 .707 r
F P
0 g
s
.59644 .78409 m .67566 .29748 L .6795 .31275 L p .707 .577 .707 r
F P
0 g
s
.64615 .80156 m .64085 .81868 L .61471 .80541 L p .707 .577 .707 r
F P
0 g
s
.61471 .80541 m .62001 .78828 L .64615 .80156 L p .707 .577 .707 r
F P
0 g
s
.39508 .26469 m .31585 .7513 L .31968 .76657 L p .707 .577 .707 r
F P
0 g
s
.31585 .7513 m .39508 .26469 L .40517 .25178 L p .707 .577 .707 r
F P
0 g
s
.14958 .6645 m .1584 .61062 L .16555 .60147 L p .707 .577 .707 r
F P
0 g
s
.15156 .67643 m .14204 .71113 L .14445 .72334 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.13816 .75803 m .14345 .7409 L .14116 .72828 L p .707 .577 .707 r
F P
0 g
s
.32965 .79634 m .32435 .81347 L .33164 .8037 L p .707 .577 .707 r
F P
0 g
s
.33164 .8037 m .33694 .78657 L .32965 .79634 L p .707 .577 .707 r
F P
0 g
s
.14116 .72828 m .13587 .7454 L .13816 .75803 L p .707 .577 .707 r
F P
0 g
s
.16555 .60147 m .15673 .65535 L .14958 .6645 L p .707 .577 .707 r
F P
0 g
s
.14204 .71113 m .15156 .67643 L .15881 .6668 L p .707 .577 .707 r
F P
0 g
s
.15673 .65535 m .16555 .60147 L .18186 .59489 L p .707 .577 .707 r
F P
0 g
s
.67566 .29748 m .59644 .78409 L .57906 .76797 L p .707 .577 .707 r
F P
0 g
s
.57906 .76797 m .65829 .28136 L .67566 .29748 L p .707 .577 .707 r
F P
0 g
s
.15881 .6668 m .14929 .70149 L .14204 .71113 L p .707 .577 .707 r
F P
0 g
s
.32594 .73839 m .40517 .25178 L .42819 .24248 L p .707 .577 .707 r
F P
0 g
s
.40517 .25178 m .32594 .73839 L .31585 .7513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13587 .7454 m .14116 .72828 L .14846 .71851 L p .707 .577 .707 r
F P
0 g
s
.33694 .78657 m .33164 .8037 L .32935 .79107 L p .707 .577 .707 r
F P
0 g
s
.14846 .71851 m .14316 .73563 L .13587 .7454 L p .707 .577 .707 r
F P
0 g
s
.18186 .59489 m .17303 .64877 L .15673 .65535 L p .707 .577 .707 r
F P
0 g
s
.14929 .70149 m .15881 .6668 L .17501 .6607 L p .707 .577 .707 r
F P
0 g
s
.17303 .64877 m .18186 .59489 L .20572 .59152 L p .707 .577 .707 r
F P
0 g
s
.17501 .6607 m .16549 .69539 L .14929 .70149 L p .707 .577 .707 r
F P
0 g
s
.14316 .73563 m .14846 .71851 L .16462 .71255 L p .707 .577 .707 r
F P
0 g
s
.65829 .28136 m .57906 .76797 L .54984 .75257 L p .707 .577 .707 r
F P
0 g
s
.54984 .75257 m .62906 .26596 L .65829 .28136 L p .707 .577 .707 r
F P
0 g
s
.20572 .59152 m .1969 .6454 L .17303 .64877 L p .707 .577 .707 r
F P
0 g
s
.32412 .61162 m .3153 .6655 L .28825 .65614 L p .707 .577 .707 r
F P
0 g
s
.28825 .65614 m .29707 .60227 L .32412 .61162 L p .707 .577 .707 r
F P
0 g
s
.16462 .71255 m .15932 .72967 L .14316 .73563 L p .707 .577 .707 r
F P
0 g
s
.42819 .24248 m .34896 .72909 L .32594 .73839 L p .707 .577 .707 r
F P
0 g
s
.34896 .72909 m .42819 .24248 L .46189 .23771 L p .707 .577 .707 r
F P
0 g
s
.1969 .6454 m .20572 .59152 L .23482 .5917 L p .707 .577 .707 r
F P
0 g
s
.16549 .69539 m .17501 .6607 L .19858 .65873 L p .707 .577 .707 r
F P
0 g
s
.29707 .60227 m .28825 .65614 L .25747 .64928 L p .707 .577 .707 r
F P
0 g
s
.25747 .64928 m .26629 .5954 L .29707 .60227 L p .707 .577 .707 r
F P
0 g
s
.226 .64557 m .23482 .5917 L .26629 .5954 L p .707 .577 .707 r
F P
0 g
s
.23482 .5917 m .226 .64557 L .1969 .6454 L p .707 .577 .707 r
F P
0 g
s
.19858 .65873 m .18906 .69342 L .16549 .69539 L p .707 .577 .707 r
F P
0 g
s
.26629 .5954 m .25747 .64928 L .226 .64557 L p .707 .577 .707 r
F P
0 g
s
.15932 .72967 m .16462 .71255 L .18806 .71098 L p .707 .577 .707 r
F P
0 g
s
.18906 .69342 m .19858 .65873 L .2272 .66107 L p .707 .577 .707 r
F P
0 g
s
.72334 .66333 m .73216 .60946 L .70139 .60259 L p .707 .577 .707 r
F P
0 g
s
.73216 .60946 m .72334 .66333 L .75481 .66703 L p .707 .577 .707 r
F P
0 g
s
.75481 .66703 m .76363 .61316 L .73216 .60946 L p .707 .577 .707 r
F P
0 g
s
.31459 .68979 m .30507 .72448 L .27867 .7121 L p .707 .577 .707 r
F P
0 g
s
.27867 .7121 m .28819 .6774 L .31459 .68979 L p .707 .577 .707 r
F P
0 g
s
.18806 .71098 m .18277 .7281 L .15932 .72967 L p .707 .577 .707 r
F P
0 g
s
.62906 .26596 m .54984 .75257 L .51163 .73939 L p .707 .577 .707 r
F P
0 g
s
.51163 .73939 m .59086 .25278 L .62906 .26596 L p .707 .577 .707 r
F P
0 g
s
.76363 .61316 m .75481 .66703 L .78391 .66721 L p .707 .577 .707 r
F P
0 g
s
.78391 .66721 m .79273 .61333 L .76363 .61316 L p .707 .577 .707 r
F P
0 g
s
.69257 .65647 m .70139 .60259 L .67433 .59323 L p .707 .577 .707 r
F P
0 g
s
.70139 .60259 m .69257 .65647 L .72334 .66333 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .46189 .23771 L .50297 .23793 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .34896 .72909 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.42743 .44936 m .38266 .72432 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.50297 .23793 m .42374 .72454 L .38266 .72432 L p .707 .577 .707 r
F P
0 g
s
.40097 .6873 m .40554 .67064 L p .37961 .64617 L .707 .577 .707 r
F P
0 g
s
.40554 .67064 m .41049 .65261 L .40739 .65196 L p .707 .577 .707 r
F P
0 g
s
.40739 .65196 m .37961 .64617 L p .40554 .67064 L .707 .577 .707 r
F P
0 g
s
.46189 .23771 m .42743 .44936 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.2272 .66107 m .21768 .69576 L .18906 .69342 L p .707 .577 .707 r
F P
0 g
s
.21768 .69576 m .2272 .66107 L .25808 .66751 L p .707 .577 .707 r
F P
0 g
s
.28819 .6774 m .27867 .7121 L .24856 .7022 L p .707 .577 .707 r
F P
0 g
s
.24856 .7022 m .25808 .66751 L .28819 .6774 L p .707 .577 .707 r
F P
0 g
s
.18277 .7281 m .18806 .71098 L .2165 .71396 L p .707 .577 .707 r
F P
0 g
s
.25808 .66751 m .24856 .7022 L .21768 .69576 L p .707 .577 .707 r
F P
0 g
s
.79273 .61333 m .78391 .66721 L .80778 .66384 L p .707 .577 .707 r
F P
0 g
s
.80778 .66384 m .8166 .60997 L .79273 .61333 L p .707 .577 .707 r
F P
0 g
s
.66551 .64711 m .67433 .59323 L .65363 .5823 L p .707 .577 .707 r
F P
0 g
s
.67433 .59323 m .66551 .64711 L .69257 .65647 L p .707 .577 .707 r
F P
0 g
s
.30314 .74524 m .29784 .76237 L .2717 .7491 L p .707 .577 .707 r
F P
0 g
s
.2717 .7491 m .277 .73197 L .30314 .74524 L p .707 .577 .707 r
F P
0 g
s
.59086 .25278 m .51163 .73939 L .46818 .72974 L p .707 .577 .707 r
F P
0 g
s
.46818 .72974 m .54741 .24313 L .59086 .25278 L p .707 .577 .707 r
F P
0 g
s
.2165 .71396 m .2112 .73108 L .18277 .7281 L p .707 .577 .707 r
F P
0 g
s
.41049 .65261 m .40097 .6873 L .40578 .68769 L p .707 .577 .707 r
F P
0 g
s
.44943 .62454 m .44421 .59881 L .47335 .53142 L .707 .577 .707 r
F
.42374 .72454 m .43571 .65102 L p .44943 .62454 L F P
0 g
s
.43571 .65102 m .44421 .59881 L p .44943 .62454 L .707 .577 .707 r
F P
0 g
s
.54741 .24313 m .46818 .72974 L .42374 .72454 L p .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .42725 .71184 L .4054 .70955 L p .707 .577 .707 r
F P
0 g
s
.4054 .70955 m .39881 .70886 L p .4036 .71302 L .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .4054 .70955 L .4036 .71302 L .707 .577 .707 r
F
.40578 .68769 m .42959 .68964 L p .41618 .66364 L F P
0 g
s
.41618 .66364 m .41049 .65261 L .40578 .68769 L .707 .577 .707 r
F
.50297 .23793 m .54741 .24313 L p .47335 .53142 L F P
0 g
s
.44421 .59881 m .50297 .23793 L p .47335 .53142 L .707 .577 .707 r
F P
0 g
s
.7131 .7285 m .72262 .6938 L .69251 .68391 L p .707 .577 .707 r
F P
0 g
s
.72262 .6938 m .7131 .7285 L .74398 .73493 L p .707 .577 .707 r
F P
0 g
s
.74398 .73493 m .7535 .70024 L .72262 .6938 L p .707 .577 .707 r
F P
0 g
s
.2112 .73108 m .2165 .71396 L .24715 .72119 L p .707 .577 .707 r
F P
0 g
s
.68299 .7186 m .69251 .68391 L .66612 .67152 L p .707 .577 .707 r
F P
0 g
s
.69251 .68391 m .68299 .7186 L .7131 .7285 L p .707 .577 .707 r
F P
0 g
s
.7535 .70024 m .74398 .73493 L .7726 .73728 L p .707 .577 .707 r
F P
0 g
s
.7726 .73728 m .78212 .70258 L .7535 .70024 L p .707 .577 .707 r
F P
0 g
s
.277 .73197 m .2717 .7491 L .24185 .73832 L p .707 .577 .707 r
F P
0 g
s
.24185 .73832 m .24715 .72119 L .277 .73197 L p .707 .577 .707 r
F P
0 g
s
.24715 .72119 m .24185 .73832 L .2112 .73108 L p .707 .577 .707 r
F P
0 g
s
.65363 .5823 m .64481 .63617 L .66551 .64711 L p .707 .577 .707 r
F P
0 g
s
.8166 .60997 m .80778 .66384 L .82408 .65726 L p .707 .577 .707 r
F P
0 g
s
.82408 .65726 m .83291 .60338 L .8166 .60997 L p .707 .577 .707 r
F P
0 g
s
.64481 .63617 m .65363 .5823 L .64133 .57086 L p .707 .577 .707 r
F P
0 g
s
.65659 .70621 m .66612 .67152 L .64602 .65785 L p .707 .577 .707 r
F P
0 g
s
.66612 .67152 m .65659 .70621 L .68299 .7186 L p .707 .577 .707 r
F P
0 g
s
.78212 .70258 m .7726 .73728 L .79617 .7353 L p .707 .577 .707 r
F P
0 g
s
.79617 .7353 m .80569 .70061 L .78212 .70258 L p .707 .577 .707 r
F P
0 g
s
.70588 .77506 m .71117 .75794 L .68132 .74716 L p .707 .577 .707 r
F P
0 g
s
.71117 .75794 m .70588 .77506 L .73652 .7823 L p .707 .577 .707 r
F P
0 g
s
.73652 .7823 m .74182 .76517 L .71117 .75794 L p .707 .577 .707 r
F P
0 g
s
.67602 .76428 m .68132 .74716 L .65518 .73388 L p .707 .577 .707 r
F P
0 g
s
.68132 .74716 m .67602 .76428 L .70588 .77506 L p .707 .577 .707 r
F P
0 g
s
.74182 .76517 m .73652 .7823 L .76496 .78527 L p .707 .577 .707 r
F P
0 g
s
.76496 .78527 m .77026 .76815 L .74182 .76517 L p .707 .577 .707 r
F P
0 g
s
.64602 .65785 m .63649 .69255 L .65659 .70621 L p .707 .577 .707 r
F P
0 g
s
.64133 .57086 m .63251 .62474 L .64481 .63617 L p .707 .577 .707 r
F P
0 g
s
.65518 .73388 m .64988 .75101 L .67602 .76428 L p .707 .577 .707 r
F P
0 g
s
.83291 .60338 m .82408 .65726 L .83123 .64811 L p .707 .577 .707 r
F P
0 g
s
.83123 .64811 m .84005 .59423 L .83291 .60338 L p .707 .577 .707 r
F P
0 g
s
.63649 .69255 m .64602 .65785 L .63418 .64425 L p .707 .577 .707 r
F P
0 g
s
.64988 .75101 m .65518 .73388 L .63532 .71942 L p .707 .577 .707 r
F P
0 g
s
.80569 .70061 m .79617 .7353 L .81237 .7292 L p .707 .577 .707 r
F P
0 g
s
.81237 .7292 m .82189 .69451 L .80569 .70061 L p .707 .577 .707 r
F P
0 g
s
.63251 .62474 m .64133 .57086 L .63862 .56003 L p .707 .577 .707 r
F P
0 g
s
.77026 .76815 m .76496 .78527 L .78841 .78371 L p .707 .577 .707 r
F P
0 g
s
.78841 .78371 m .7937 .76658 L .77026 .76815 L p .707 .577 .707 r
F P
0 g
s
.63532 .71942 m .63002 .73654 L .64988 .75101 L p .707 .577 .707 r
F P
0 g
s
.63418 .64425 m .62466 .67894 L .63649 .69255 L p .707 .577 .707 r
F P
0 g
s
.63002 .73654 m .63532 .71942 L .62367 .70518 L p .707 .577 .707 r
F P
0 g
s
.63862 .56003 m .6298 .61391 L .63251 .62474 L p .707 .577 .707 r
F P
0 g
s
.7937 .76658 m .78841 .78371 L .80457 .77774 L p .707 .577 .707 r
F P
0 g
s
.80457 .77774 m .80986 .76062 L .7937 .76658 L p .707 .577 .707 r
F P
0 g
s
.62466 .67894 m .63418 .64425 L .63178 .63203 L p .707 .577 .707 r
F P
0 g
s
.62367 .70518 m .61837 .7223 L .63002 .73654 L p .707 .577 .707 r
F P
0 g
s
.84005 .59423 m .83123 .64811 L .82852 .63729 L p .707 .577 .707 r
F P
0 g
s
.82852 .63729 m .83734 .58341 L .84005 .59423 L p .707 .577 .707 r
F P
0 g
s
.82189 .69451 m .81237 .7292 L .81962 .71957 L p .707 .577 .707 r
F P
0 g
s
.81962 .71957 m .82914 .68488 L .82189 .69451 L p .707 .577 .707 r
F P
0 g
s
.6298 .61391 m .63862 .56003 L .64576 .55088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63178 .63203 m .62225 .66672 L .62466 .67894 L p .707 .577 .707 r
F P
0 g
s
.61837 .7223 m .62367 .70518 L .62138 .69255 L p .707 .577 .707 r
F P
0 g
s
.64576 .55088 m .63694 .60476 L .6298 .61391 L p .707 .577 .707 r
F P
0 g
s
.80986 .76062 m .80457 .77774 L .81186 .76797 L p .707 .577 .707 r
F P
0 g
s
.81186 .76797 m .81716 .75085 L .80986 .76062 L p .707 .577 .707 r
F P
0 g
s
.62138 .69255 m .61608 .70968 L .61837 .7223 L p .707 .577 .707 r
F P
0 g
s
.62225 .66672 m .63178 .63203 L .63903 .6224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.82914 .68488 m .81962 .71957 L .81721 .70735 L p .707 .577 .707 r
F P
0 g
s
.81721 .70735 m .82673 .67266 L .82914 .68488 L p .707 .577 .707 r
F P
0 g
s
.83734 .58341 m .82852 .63729 L .81621 .62585 L p .707 .577 .707 r
F P
0 g
s
.81621 .62585 m .82503 .57197 L .83734 .58341 L p .707 .577 .707 r
F P
0 g
s
.63694 .60476 m .64576 .55088 L .66207 .5443 L p .707 .577 .707 r
F P
0 g
s
.38033 .62188 m .38915 .568 L .35838 .56114 L p .707 .577 .707 r
F P
0 g
s
.38915 .568 m .38033 .62188 L .4118 .62558 L p .707 .577 .707 r
F P
0 g
s
.4118 .62558 m .42062 .57171 L .38915 .568 L p .707 .577 .707 r
F P
0 g
s
.63903 .6224 m .6295 .65709 L .62225 .66672 L p .707 .577 .707 r
F P
0 g
s
.42062 .57171 m .4118 .62558 L .4409 .62576 L p .707 .577 .707 r
F P
0 g
s
.4409 .62576 m .44972 .57188 L .42062 .57171 L p .707 .577 .707 r
F P
0 g
s
.34956 .61501 m .35838 .56114 L .33132 .55178 L p .707 .577 .707 r
F P
0 g
s
.35838 .56114 m .34956 .61501 L .38033 .62188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.61608 .70968 m .62138 .69255 L .62867 .68278 L p .707 .577 .707 r
F P
0 g
s
.66207 .5443 m .65325 .59818 L .63694 .60476 L p .707 .577 .707 r
F P
0 g
s
.81716 .75085 m .81186 .76797 L .80957 .75535 L p .707 .577 .707 r
F P
0 g
s
.80957 .75535 m .81487 .73822 L .81716 .75085 L p .707 .577 .707 r
F P
0 g
s
.44972 .57188 m .4409 .62576 L .46477 .62239 L p .707 .577 .707 r
F P
0 g
s
.46477 .62239 m .47359 .56851 L .44972 .57188 L p .707 .577 .707 r
F P
0 g
s
.62867 .68278 m .62337 .69991 L .61608 .70968 L p .707 .577 .707 r
F P
0 g
s
.3225 .60566 m .33132 .55178 L .31062 .54085 L p .707 .577 .707 r
F P
0 g
s
.33132 .55178 m .3225 .60566 L .34956 .61501 L p .707 .577 .707 r
F P
0 g
s
.6295 .65709 m .63903 .6224 L .65523 .6163 L p .707 .577 .707 r
F P
0 g
s
.82503 .57197 m .81621 .62585 L .79552 .61491 L p .707 .577 .707 r
F P
0 g
s
.79552 .61491 m .80434 .56104 L .82503 .57197 L p .707 .577 .707 r
F P
0 g
s
.82673 .67266 m .81721 .70735 L .80538 .69374 L p .707 .577 .707 r
F P
0 g
s
.80538 .69374 m .8149 .65905 L .82673 .67266 L p .707 .577 .707 r
F P
0 g
s
.65325 .59818 m .66207 .5443 L .68594 .54093 L p .707 .577 .707 r
F P
0 g
s
.37009 .68086 m .37961 .64617 L .3495 .63628 L p .707 .577 .707 r
F P
0 g
s
.37961 .64617 m .37009 .68086 L .40097 .6873 L p .707 .577 .707 r
F P
0 g
s
.33998 .67097 m .3495 .63628 L .32311 .62389 L p .707 .577 .707 r
F P
0 g
s
.3495 .63628 m .33998 .67097 L .37009 .68086 L p .707 .577 .707 r
F P
0 g
s
.42959 .68964 m .43911 .65495 L .41049 .65261 L p .707 .577 .707 r
F P
0 g
s
.65523 .6163 m .64571 .65099 L .6295 .65709 L p .707 .577 .707 r
F P
0 g
s
.31062 .54085 m .3018 .59472 L .3225 .60566 L p .707 .577 .707 r
F P
0 g
s
.47359 .56851 m .46477 .62239 L .48107 .61581 L p .707 .577 .707 r
F P
0 g
s
.48107 .61581 m .4899 .56193 L .47359 .56851 L p .707 .577 .707 r
F P
0 g
s
.62337 .69991 m .62867 .68278 L .64483 .67682 L p .707 .577 .707 r
F P
0 g
s
.3018 .59472 m .31062 .54085 L .29832 .52941 L p .707 .577 .707 r
F P
0 g
s
.68594 .54093 m .67712 .59481 L .65325 .59818 L p .707 .577 .707 r
F P
0 g
s
.80434 .56104 m .79552 .61491 L .76846 .60556 L p .707 .577 .707 r
F P
0 g
s
.76846 .60556 m .77728 .55168 L .80434 .56104 L p .707 .577 .707 r
F P
0 g
s
.31358 .65858 m .32311 .62389 L .30301 .61022 L p .707 .577 .707 r
F P
0 g
s
.32311 .62389 m .31358 .65858 L .33998 .67097 L p .707 .577 .707 r
F P
0 g
s
.43911 .65495 m .42959 .68964 L .45316 .68767 L p .707 .577 .707 r
F P
0 g
s
.45316 .68767 m .46268 .65298 L .43911 .65495 L p .707 .577 .707 r
F P
0 g
s
.67712 .59481 m .68594 .54093 L .71503 .54111 L p .707 .577 .707 r
F P
0 g
s
.36287 .71875 m .36816 .70162 L .33831 .69084 L p .707 .577 .707 r
F P
0 g
s
.36816 .70162 m .36287 .71875 L .39351 .72598 L p .707 .577 .707 r
F P
0 g
s
.39351 .72598 m .39881 .70886 L .36816 .70162 L p .707 .577 .707 r
F P
0 g
s
.81487 .73822 m .80957 .75535 L .79792 .74111 L p .707 .577 .707 r
F P
0 g
s
.79792 .74111 m .80322 .72398 L .81487 .73822 L p .707 .577 .707 r
F P
0 g
s
.64571 .65099 m .65523 .6163 L .67879 .61432 L p .707 .577 .707 r
F P
0 g
s
.64483 .67682 m .63953 .69395 L .62337 .69991 L p .707 .577 .707 r
F P
0 g
s
.8149 .65905 m .80538 .69374 L .78528 .68008 L p .707 .577 .707 r
F P
0 g
s
.78528 .68008 m .7948 .64539 L .8149 .65905 L p .707 .577 .707 r
F P
0 g
s
.33301 .70797 m .33831 .69084 L .31217 .67757 L p .707 .577 .707 r
F P
0 g
s
.33831 .69084 m .33301 .70797 L .36287 .71875 L p .707 .577 .707 r
F P
0 g
s
.39881 .70886 m .39351 .72598 L .42195 .72896 L p .707 .577 .707 r
F P
0 g
s
.30301 .61022 m .29348 .64491 L .31358 .65858 L p .707 .577 .707 r
F P
0 g
s
.31217 .67757 m .30687 .6947 L .33301 .70797 L p .707 .577 .707 r
F P
0 g
s
.77728 .55168 m .76846 .60556 L .73769 .59869 L p .707 .577 .707 r
F P
0 g
s
.73769 .59869 m .74651 .54481 L .77728 .55168 L p .707 .577 .707 r
F P
0 g
s
.70621 .59499 m .71503 .54111 L .74651 .54481 L p .707 .577 .707 r
F P
0 g
s
.71503 .54111 m .70621 .59499 L .67712 .59481 L p .707 .577 .707 r
F P
0 g
s
.29832 .52941 m .2895 .58328 L .3018 .59472 L p .707 .577 .707 r
F P
0 g
s
.67879 .61432 m .66927 .64901 L .64571 .65099 L p .707 .577 .707 r
F P
0 g
s
.74651 .54481 m .73769 .59869 L .70621 .59499 L p .707 .577 .707 r
F P
0 g
s
.30687 .6947 m .31217 .67757 L .29231 .66311 L p .707 .577 .707 r
F P
0 g
s
.29348 .64491 m .30301 .61022 L .29117 .59661 L p .707 .577 .707 r
F P
0 g
s
.4899 .56193 m .48107 .61581 L .48822 .60666 L p .707 .577 .707 r
F P
0 g
s
.48822 .60666 m .49704 .55278 L .4899 .56193 L p .707 .577 .707 r
F P
0 g
s
.42725 .71184 m .42195 .72896 L .4454 .72739 L p .707 .577 .707 r
F P
0 g
s
.4454 .72739 m .45069 .71027 L .42725 .71184 L p .707 .577 .707 r
F P
0 g
s
.46268 .65298 m .45316 .68767 L .46936 .68157 L p .707 .577 .707 r
F P
0 g
s
.46936 .68157 m .47888 .64688 L .46268 .65298 L p .707 .577 .707 r
F P
0 g
s
.63953 .69395 m .64483 .67682 L .66828 .67525 L p .707 .577 .707 r
F P
0 g
s
.66927 .64901 m .67879 .61432 L .70742 .61667 L p .707 .577 .707 r
F P
0 g
s
.2895 .58328 m .29832 .52941 L .29561 .51858 L p .707 .577 .707 r
F P
0 g
s
.29231 .66311 m .28701 .68023 L .30687 .6947 L p .707 .577 .707 r
F P
0 g
s
.7948 .64539 m .78528 .68008 L .75888 .66769 L p .707 .577 .707 r
F P
0 g
s
.75888 .66769 m .76841 .633 L .7948 .64539 L p .707 .577 .707 r
F P
0 g
s
.80322 .72398 m .79792 .74111 L .77806 .72664 L p .707 .577 .707 r
F P
0 g
s
.77806 .72664 m .78335 .70952 L .80322 .72398 L p .707 .577 .707 r
F P
0 g
s
.66828 .67525 m .66298 .69238 L .63953 .69395 L p .707 .577 .707 r
F P
0 g
s
.29117 .59661 m .28165 .6313 L .29348 .64491 L p .707 .577 .707 r
F P
0 g
s
.70742 .61667 m .69789 .65136 L .66927 .64901 L p .707 .577 .707 r
F P
0 g
s
.69789 .65136 m .70742 .61667 L .73829 .6231 L p .707 .577 .707 r
F P
0 g
s
.28701 .68023 m .29231 .66311 L .28066 .64886 L p .707 .577 .707 r
F P
0 g
s
.76841 .633 m .75888 .66769 L .72877 .65779 L p .707 .577 .707 r
F P
0 g
s
.72877 .65779 m .73829 .6231 L .76841 .633 L p .707 .577 .707 r
F P
0 g
s
.29561 .51858 m .28678 .57246 L .2895 .58328 L p .707 .577 .707 r
F P
0 g
s
.45069 .71027 m .4454 .72739 L .46156 .72143 L p .707 .577 .707 r
F P
0 g
s
.46156 .72143 m .46685 .70431 L .45069 .71027 L p .707 .577 .707 r
F P
0 g
s
.73829 .6231 m .72877 .65779 L .69789 .65136 L p .707 .577 .707 r
F P
0 g
s
.66298 .69238 m .66828 .67525 L .69671 .67823 L p .707 .577 .707 r
F P
0 g
s
.28066 .64886 m .27536 .66599 L .28701 .68023 L p .707 .577 .707 r
F P
0 g
s
.28165 .6313 m .29117 .59661 L .28877 .5844 L p .707 .577 .707 r
F P
0 g
s
.78335 .70952 m .77806 .72664 L .75192 .71337 L p .707 .577 .707 r
F P
0 g
s
.75192 .71337 m .75721 .69625 L .78335 .70952 L p .707 .577 .707 r
F P
0 g
s
.47888 .64688 m .46936 .68157 L .47661 .67194 L p .707 .577 .707 r
F P
0 g
s
.47661 .67194 m .48613 .63725 L .47888 .64688 L p .707 .577 .707 r
F P
0 g
s
.49704 .55278 m .48822 .60666 L .48551 .59583 L p .707 .577 .707 r
F P
0 g
s
.48551 .59583 m .49433 .54196 L .49704 .55278 L p .707 .577 .707 r
F P
0 g
s
.69671 .67823 m .69142 .69536 L .66298 .69238 L p .707 .577 .707 r
F P
0 g
s
.28678 .57246 m .29561 .51858 L .30275 .50943 L p .707 .577 .707 r
F P
0 g
s
.28877 .5844 m .27924 .61909 L .28165 .6313 L p .707 .577 .707 r
F P
0 g
s
.69142 .69536 m .69671 .67823 L .72736 .68547 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.75721 .69625 m .75192 .71337 L .72206 .70259 L p .707 .577 .707 r
F P
0 g
s
.72206 .70259 m .72736 .68547 L .75721 .69625 L p .707 .577 .707 r
F P
0 g
s
.27536 .66599 m .28066 .64886 L .27837 .63624 L p .707 .577 .707 r
F P
0 g
s
.72736 .68547 m .72206 .70259 L .69142 .69536 L p .707 .577 .707 r
F P
0 g
s
.46685 .70431 m .46156 .72143 L .46885 .71166 L p .707 .577 .707 r
F P
0 g
s
.46885 .71166 m .47415 .69453 L .46685 .70431 L p .707 .577 .707 r
F P
0 g
s
.27837 .63624 m .27307 .65336 L .27536 .66599 L p .707 .577 .707 r
F P
0 g
s
.30275 .50943 m .29393 .56331 L .28678 .57246 L p .707 .577 .707 r
F P
0 g
s
.27924 .61909 m .28877 .5844 L .29602 .57476 L p .707 .577 .707 r
F P
0 g
s
.48613 .63725 m .47661 .67194 L .4742 .65972 L p .707 .577 .707 r
F P
0 g
s
.4742 .65972 m .48372 .62503 L .48613 .63725 L p .707 .577 .707 r
F P
0 g
s
.49433 .54196 m .48551 .59583 L .4732 .5844 L p .707 .577 .707 r
F P
0 g
s
.4732 .5844 m .48202 .53052 L .49433 .54196 L p .707 .577 .707 r
F P
0 g
s
.29393 .56331 m .30275 .50943 L .31906 .50285 L p .707 .577 .707 r
F P
0 g
s
.29602 .57476 m .28649 .60946 L .27924 .61909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27307 .65336 m .27837 .63624 L .28566 .62647 L p .707 .577 .707 r
F P
0 g
s
.47415 .69453 m .46885 .71166 L .46656 .69904 L p .707 .577 .707 r
F P
0 g
s
.46656 .69904 m .47186 .68191 L .47415 .69453 L p .707 .577 .707 r
F P
0 g
s
.28566 .62647 m .28036 .64359 L .27307 .65336 L p .707 .577 .707 r
F P
0 g
s
.31906 .50285 m .31024 .55673 L .29393 .56331 L p .707 .577 .707 r
F P
0 g
s
.28649 .60946 m .29602 .57476 L .31222 .56866 L p .707 .577 .707 r
F P
0 g
s
.48202 .53052 m .4732 .5844 L .45251 .57346 L p .707 .577 .707 r
F P
0 g
s
.45251 .57346 m .46133 .51959 L .48202 .53052 L p .707 .577 .707 r
F P
0 g
s
.48372 .62503 m .4742 .65972 L .46237 .64611 L p .707 .577 .707 r
F P
0 g
s
.46237 .64611 m .47189 .61142 L .48372 .62503 L p .707 .577 .707 r
F P
0 g
s
.31024 .55673 m .31906 .50285 L .34293 .49948 L p .707 .577 .707 r
F P
0 g
s
.31222 .56866 m .3027 .60335 L .28649 .60946 L p .707 .577 .707 r
F P
0 g
s
.28036 .64359 m .28566 .62647 L .30182 .62051 L p .707 .577 .707 r
F P
0 g
s
.47186 .68191 m .46656 .69904 L .45491 .68479 L p .707 .577 .707 r
F P
0 g
s
.45491 .68479 m .46021 .66767 L .47186 .68191 L p .707 .577 .707 r
F P
0 g
s
.34293 .49948 m .33411 .55336 L .31024 .55673 L p .707 .577 .707 r
F P
0 g
s
.46133 .51959 m .45251 .57346 L .42545 .5641 L p .707 .577 .707 r
F P
0 g
s
.42545 .5641 m .43427 .51023 L .46133 .51959 L p .707 .577 .707 r
F P
0 g
s
.30182 .62051 m .29652 .63763 L .28036 .64359 L p .707 .577 .707 r
F P
0 g
s
.33411 .55336 m .34293 .49948 L .37202 .49966 L p .707 .577 .707 r
F P
0 g
s
.3027 .60335 m .31222 .56866 L .33578 .56669 L p .707 .577 .707 r
F P
0 g
s
.47189 .61142 m .46237 .64611 L .44227 .63244 L p .707 .577 .707 r
F P
0 g
s
.44227 .63244 m .45179 .59775 L .47189 .61142 L p .707 .577 .707 r
F P
0 g
s
.43427 .51023 m .42545 .5641 L .39468 .55724 L p .707 .577 .707 r
F P
0 g
s
.39468 .55724 m .4035 .50336 L .43427 .51023 L p .707 .577 .707 r
F P
0 g
s
.3632 .55354 m .37202 .49966 L .4035 .50336 L p .707 .577 .707 r
F P
0 g
s
.37202 .49966 m .3632 .55354 L .33411 .55336 L p .707 .577 .707 r
F P
0 g
s
.33578 .56669 m .32626 .60138 L .3027 .60335 L p .707 .577 .707 r
F P
0 g
s
.4035 .50336 m .39468 .55724 L .3632 .55354 L p .707 .577 .707 r
F P
0 g
s
.29652 .63763 m .30182 .62051 L .32527 .61894 L p .707 .577 .707 r
F P
0 g
s
.32626 .60138 m .33578 .56669 L .36441 .56903 L p .707 .577 .707 r
F P
0 g
s
.46021 .66767 m .45491 .68479 L .43504 .67033 L p .707 .577 .707 r
F P
0 g
s
.43504 .67033 m .44034 .6532 L .46021 .66767 L p .707 .577 .707 r
F P
0 g
s
.45179 .59775 m .44227 .63244 L .41587 .62006 L p .707 .577 .707 r
F P
0 g
s
.41587 .62006 m .4254 .58537 L .45179 .59775 L p .707 .577 .707 r
F P
0 g
s
.32527 .61894 m .31997 .63606 L .29652 .63763 L p .707 .577 .707 r
F P
0 g
s
.36441 .56903 m .35488 .60373 L .32626 .60138 L p .707 .577 .707 r
F P
0 g
s
.35488 .60373 m .36441 .56903 L .39528 .57547 L p .707 .577 .707 r
F P
0 g
s
.4254 .58537 m .41587 .62006 L .38576 .61016 L p .707 .577 .707 r
F P
0 g
s
.38576 .61016 m .39528 .57547 L .4254 .58537 L p .707 .577 .707 r
F P
0 g
s
.31997 .63606 m .32527 .61894 L .3537 .62192 L p .707 .577 .707 r
F P
0 g
s
.39528 .57547 m .38576 .61016 L .35488 .60373 L p .707 .577 .707 r
F P
0 g
s
.44034 .6532 m .43504 .67033 L .40891 .65706 L p .707 .577 .707 r
F P
0 g
s
.40891 .65706 m .4142 .63993 L .44034 .6532 L p .707 .577 .707 r
F P
0 g
s
.3537 .62192 m .34841 .63904 L .31997 .63606 L p .707 .577 .707 r
F P
0 g
s
.34841 .63904 m .3537 .62192 L .38435 .62915 L p .707 .577 .707 r
F P
0 g
s
.4142 .63993 m .40891 .65706 L .37905 .64628 L p .707 .577 .707 r
F P
0 g
s
.37905 .64628 m .38435 .62915 L .4142 .63993 L p .707 .577 .707 r
F P
0 g
s
.38435 .62915 m .37905 .64628 L .34841 .63904 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolA002;Ool007aoo`D0
009JEP03001JEUYF00QJEP04001JEUYFFUH60025Ool007Qoo`@000MJEP03001JEUYF00QJEP03001J
EUYF00MJEPH007moo`00MGoo0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00NGoo001cOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP06FUH5001dOol0079oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEP000080075oo`00LGoo00<005YF000015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF0P00Kgoo001aOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH3001/Ool0071oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP8006Yoo`00L7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00J7oo001`
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP02001VOol006moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH2
001TOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0@FUH2001ROol006moo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001oogoo05moo`00Kgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF0P00H7oo001_Ool00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH01000FUH00000GWoo001_Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00Oomoo`1K
Ool006ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0<FUH00`00Oomoo`1JOol006ioo`04001JEUYF0004
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1JOol006ioo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001oogoo05Yoo`00KWoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00<007ooOol0FGoo001^Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00Oomoo`1IOol006ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0005]oo`00KGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
05]oo`00KGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005]oo`00
KGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0Fgoo001]Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUILOol006eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP03001JEUYF05aoo`00KGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000G7oo001/Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1L
Ool006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF05eoo`00K7oo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH0GGoo001/Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001MOol006]oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEWoo05eoo`00Jgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YFFUH0GWoo001[Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001N
Ool006]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo
00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0GWoo001ZOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIJEP1OOol006Yoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF0P0035YF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001Y
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIoo`1OOol006Uoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000H7oo001YOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo
061oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P00HWoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0
001ROol006Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00069oo`00
Igoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001SOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006=oo`00IWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
0000Hgoo001VOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001NOol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol005Uoo`D000=J
EP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Aoo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
I7oo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001TOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000D000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
15YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Io
o`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Uooa0004eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEP0000Aoo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00DWoo00<005YF0000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<004=oo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@003moo`00DWoo00<005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00
DWoo0P000eYF1@000UYF00@005YFFUIJEP<000IJEPL000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP<003Yoo`00DWoo00=JEP00FUH00`001EYF00<005YFFUH015YF10000eYF00@005YFFUIJEPL0009J
EP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Qoo`00DGoo00@005YF0000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@0009JEPH0009JEP@000MJEP03001JEUYF
00=JEP05001JEUYFFUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF0`00=Woo001AOol30002FUH00`00FUH0000A0002FUH80006FUH20004FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF008003Aoo`00DGoo00<005YFFUH00UYF0`001UYF00<005YFFUH01EYF
00<005YFFUH05@0000=JEP00FUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000bOol0055oo`03001JEUYF
0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJ
EP8000IJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000aOol0059oo`<0009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YF0000<7oo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUH00002FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00=goo40002Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH0100035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000=oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
00IJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUH000000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP06001JEUYF001JEP00;Woo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP050003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20004FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000AJEP00FUIJEPD0009JEP04001JEUYFFUH30007Ool70006FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01`00FUIJEUYF001JEP0002ioo`00;goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF4P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF0`000UYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP00FUH40006FUH00`00FUIJEP04FUH40006Ool80002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00000020001UYF00@005YFFUIJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH010000Woo1@000goo10001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Mo
o`@0009JEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP8000AJEP@00003FUH0000000<0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP03FUH700000eYF001J
EP08FUH00`00FUIJEP02FUH>0005FUH01000FUIJEUYF0P00;goo000]Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP020002FUH0
1000FUIJEP000UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001J
EUYF00AJEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF000015YF1P000UYF00<005YFFUH00UYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YF0000009JEP03001JEUYF009JEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF4P0000=JEP00FUH0
1`0015YF0`001UYF00<005YFFUH015YF00H005YFFUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH00004
0009FUH00`00FUIJEP05FUH01000FUIJEUYF0`0015YF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0`001EYF
00<005YFFUH01UYF00<005YFFUH010001UYF2@0015YF00<005YFFUH015YF00@005YFFUIJEP8000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF100000=JEP00FUH025YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00EJEP03001JEUYF
00AJEP80009JEP03001JEP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000]JEP8000IJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0002moo`00;7oo
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJEP04001JEP000004FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00800003FUH007oo02ioo`00:goo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1@000UYF00<0
05YFFUH00UYF1P001eYF00<005YFFUH01EYF0P001UYF00D005YFFUIJEP0000=JEP07001JEUYFFUH0
05YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000006FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP02FUH30003FUH01000
FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<0
05YFFUH00UYF0P00<7oo000[Ool00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH00UYF
0`0000=JEP0000001UYF00<005YFFUH01EYF00<005YFFUH015YF100025YF00<005YFFUH00P0000=J
EP00FUH01UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20004FUH01`00FUIJEUYF001JEP00031oo`00:goo0P000eYF1@00
0UYF00<005YF00000`0027oo1P000UYF0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00=JEP8000QJEP06001JEUYF001JEP002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH7
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01`00FUIJEUYF001J
EP00031oo`00:goo00=JEP00FUH00`001UYF00<005YFFUH00eYF10001goo1P0000AJEP00000000AJ
EP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP06FUH20002FUH5
0002FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000UYF2@0000=oo`00000020001UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH2000aOol002Yoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP040002Ool500001Goo001JEP00FUH00P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0025YF0`000eYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0000300000eYF001JEP05FUH30003Ool40002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000bOol002Yoo`<0009JEP03001JEP000140009J
EPL00003Ool005YF00=JEP<000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0005FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P001Goo
10000UYF10001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP02FUH3
0006FUH00`00FUIJEP05FUH00`00FUIJEP0<0004FUH500000eYF001JEP020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YF00002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF0`000eYF00<005YFFUH00UYF
0P001goo2P000UYF00<005YFFUH01UYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP020002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP02FUH20003
FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH0
0003FUH01000FUIJEUYF0`001UYF0P0037oo1`0025YF00<005YFFUH00eYF00<005YF0000=7oo000Z
Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP04001JEUYF0002FUH200000eYF001JEP0200000eYF001JEP030008FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH00eYF0P001EYF00<005YF00002Woo1@00
0goo0P001UYF00<005YFFUH00eYF00@005YFFUH003=oo`00:goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF0P000eYF0P00
00AJEP00FUIJEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP00FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YF
FUH015YF0`000eYF00@005YFFUH000Uoo`D000Eoo`8000=JEP03001JEUYF00AJEP05001JEUYFFUH0
000bOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP000003FUHC0008Ool50007Ool200000eYF001JEP04FUH00`00FUIJEP02
FUH00`00Oomoo`0`Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<00005FUH005YFFUH00005FUH00`00FUIJEP030004FUH4
0008FUH01000FUIJEUYF0`0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF0000009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEP0000<000Eoo`<0
00Yoo`8000EJEP03001JEUYF009JEP80035oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF0`0015YF00<005YFFUH00P0000=JEP00FUH01EYF00<0
05YFFUH00eYF20001eYF00<005YFFUH00eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
15YF100047oo00<005YFFUH00UYF00L005YFFUIJEP00FUH0000aOol002Yoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP03FUH20006FUH00`00FUIJEP06FUH90003FUH01000FUIJEUYF1@000UYF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000ioo`80009JEP07001JEUYFFUH005YF0000
<Goo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30007FUH30003FUH00`00FUIJEP05FUH60004FUH70004FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04
001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000=Ool20004FUH00`00FUIoo`0a
Ool002Uoo`03001JEP00009JEQ8000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP06001JEP00001JEP001eYF00<005YF00000P001eYF00<005YFFUH01eYF0P0000=JEP0000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000eYF10000UYF00<0
05YFFUH00UYF1`001UYF00<005YFFUH01UYF0P0037oo00<005YFFUH00UYF0P00<Woo000YOol20000
15YF0000000017oo0`001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP80
00EJEP03001JEUYF009JEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000aJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000800003FUH00000009JEP05
001JEUYFFUH00007FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF0`002goo00@005YFFUIJEP80
039oo`00:Goo0`000eYF00<007ooOol017oo0P0015YF00<005YFFUH01EYF100025YF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00EJEP@0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH20002
Ool2000015YF0000000025YF00<005YFFUH01EYF10001eYF00@005YFFUIJEPd00003FUH0000003=o
o`00:Goo0P0015YF0P001goo0`0000=JEP00FUH01eYF00<005YFFUH00`0015YF00<005YFFUH01UYF
00<005YFFUH010002EYF00<005YFFUH010002UYF00<005YFFUH01eYF100035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF3P0025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<0
05YFFUH00eYF0`001UYF00<005YF00000P00<goo000XOol30003FUH00`00FUIJEP020008Ool40006
FUH00`00FUIJEP03FUH300000eYF001JEP06FUH01P00FUIJEUYF001JEP<000QJEP03001JEUYF00AJ
EPL000=JEP04001JEUYFFUH6000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF00D005YF000005YF008000MJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYFFUH2000cOol002Qoo`03001JEP0000=JEP/0
00Ioo`@0009JEP03001JEUYF00IJEP8000MJEP07001JEUYFFUH005YF00000UYF0`0015YF00<005YF
FUH01eYF00<005YFFUH00UYF1`000eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00IJEP03001JEP00008000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP8000QJEP<000=JEP03001JEUYF00<003=oo`00:7oo00@005YFFUIJ
EP<000IJEP04001JEUYFFUH70003Ool70004FUH01000FUH000001EYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00=JEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00=JEP<00004FUH0
00000006FUH01000FUIJEP000UYF00<005YFFUH00P00=7oo000YOol30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040006Ool:0003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH40007FUH00`00FUIJEP02FUH50003FUH20003FUH00`00FUIJEP02FUH20003FUH2000dOol0
02Uoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000aoo`<000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00
0004FUH30002FUH00`00FUIJEP04FUH01000FUH005YF0P001EYF00<005YFFUH00UYF1@001EYF0P00
00=JEP00FUH01EYF00@005YFFUH003Eoo`00:Goo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH0100000=J
EP00FUH01P0015YF00@005YFFUIJEPH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUH00006FUH00`00FUIJEP02
00001UYF00000000FUH000EJEPD000MJEP8000IJEP@003Eoo`00:7oo0P000UYF4P001eYF00<005YF
FUH00UYF0`002Woo0P0000AJEP00FUH000EJEP@000EJEP03001JEUYF00EJEPP000AJEPP000YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEP0000AJEP80
00EJEP03001JEUYF009JEP8000=oo`H0009JEP<000QJEP03001JEP0000AJEP04001JEP00000fOol0
02Moo`800004FUH000000006FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP06FUH3
0009Ool01@00FUIJEP00FUH010002EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YFFUIJEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP8000IJEP03
001JEUYF009JEP03001JEUYF009JEP8000Uoo`P000AJEP04001JEUYFFUH20002FUH01000FUIJEP00
=Woo000WOol30002Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40008FUH01000
FUH0000027oo0UYF0P000eYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YF
FUH01EYF10000UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF
0P001UYF0`000UYF00L005YFFUIJEP00FUH0000AOol<0004FUH00`00Oomoo`0cOol002Ioo`<000Ao
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01000FUIJEUYF0`0017oo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF
10002UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF00<005YF000015YF00@005YF
FUIJEP<000=JEP03001JEP0001aoo`03001JEUYF009JEP03001oogoo03=oo`009Woo00@005YF0000
00Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF0P00
0Woo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00@0
05YFFUIJEP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH20002FUH2000NOol01@00FUIJEUYF0000=Goo000VOol01@00FUH005YF
00001Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH01eYF1P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF0P0025YF10007goo00D0
05YF001JEP0003Aoo`009Woo00<005YFFUH00UYF00<007ooOol017oo0P001UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001UYF00<005YFFUH00P0000=JEP00FUH03EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH01eYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0
<goo000WOol00`00FUIJEP02FUH00`00Oomoo`05Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP020004FUH01@00FUIJEUYF000045YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF0`0025YF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000=7oo000WOol00`00FUIJEP02FUH20008
Ool200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP07FUH0
1000FUH000000eYF00<005YFFUH01UYF0`006Woo0P00=Goo000XOol01000FUIJEP000UYF0P0027oo
0`0025YF00<005YFFUH01EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000Woo0`001eYF00@005YFFUIJEP800003FUH005YF00QJ
EP03001JEP0000<001Aoo`@003Eoo`00:7oo00@005YFFUH000AJEP03001oogoo00Qoo`<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP03001JEP0000Eoo`8000AJEP03001JEUYF00AJEP<000MJEP03001JEUYF00AJEPH000Qo
o`H0009JEP03001oogoo03Aoo`00:Goo0P001UYF00<007ooOol02Woo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00@005YFFUH0009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP8000EJEP8000Qoo`<00003FUH0
05YF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJ
EP8003Ioo`00:Woo00<005YFFUH015YF0`003Goo0`0015YF100025YF00@005YFFUIJEP<00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEP0000=JEP03001JEP0000]oo`8000EJEP03001JEUYF009JEP@00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000gOol002]oo`8000AJEP03001J
EUYF008000ioo`P000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00800004
FUH005YF000=Ool00`00FUIJEP02FUH01`00FUIJEUYF001JEP00009oo`@000IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYFFUH2000gOol002eoo`04001JEUYF0005FUH2000?Ool80004FUH0
1000FUIJEUYF1@000UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00Ool03Goo0P000UYF
00L005YFFUIJEP00FUH00006Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000hOol002ioo`<000MJEP<000aoo`D000=oo`P000Aoo`03001JEUYF00<000QJEP03001JEUYF00MJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP800003FUH007oo00moo`8000AJEP03001JEWoo00Yoo`H000AJEP04001JEUYFFUH6000jOol0031o
o`03001JEUYF00IJEP04001JEP00000;Ool3000AOol200000eYF001oo`02000@FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000
0002000>Ool00`00FUIJEP02FUH2000AOol80010Ool0035oo`8000EJEP03001JEUYF009JEP<001eo
o`03001JEP0000=oo`8000iJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000AJEP<000aoo`04001JEUYFFUH2001IOol003=oo`8000=JEP03
001JEUYF00EJEP@001Uoo`03001JEP0000Eoo`8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEP0000d00003
FUH0000005Yoo`00=Goo0`002EYF00<005YFFUH010005Goo0P0027oo0`002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YF00000P00FWoo000gOol20008FUH00`00FUIJ
EP04FUH6000=Ool4000;Ool2000DFUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF0P001EYF00@005YFFUIJEP8005Yoo`00
>Goo0`0015YF00<005YFFUH01eYF00@005YFFUIJEPd0009JEP8000eoo`<0015JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP07
FUH20004FUH00`00FUIJEP03001JOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF0080015oo`8000mJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP<000MJEP03001JEP0000=JEP03001JEUYF008005]oo`00?goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8001=oo`@001MJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP8000AJEP04001JEUYFFUH3
0003FUH2001KOol0049oo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008001Qo
o`@0019JEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH50004FUH300000eYF
001JEP04FUH01@00FUIJEUYF0000G7oo0016Ool60004FUH00`00FUIJEP04FUH01000FUH000007Woo
10003UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000AJEPD000MJEP8000IJEP04001J
EP00001LOol004aoo`d002Aoo`P000IJEP03001JEUYF00UJEP03001JEUYF00=JEPT000=JEPD000MJ
EP03001JEP0000AJEP04001JEP00001MOol008EooaP000Uoo`L000MJEP04001JEUYFFUH20002FUH0
0`00FUH0001NOol008aoo`03001JEUYF00AJEP<001Aooa8000=JEP03001oogoo05]oo`00SGoo00<0
05YFFUH00UYF00@005YFFUIJEP8002=oo`03001JEUYF009JEP03001oogoo05Yoo`00SWoo0P000UYF
00<005YFFUH00eYF0P008Woo00D005YFFUIJEP0005aoo`00T7oo0P0025YF0P008Goo00D005YF001J
EP0005]oo`00TGoo00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0FWoo002BOol2
0006FUH00`00FUIJEP02FUH3000MOol00`00FUH0001KOol009Aoo`8000=JEP03001JEUYF00IJEP<0
01Yoo`8005aoo`00UWoo0P0000=JEP00FUH025YF00<005YF00000`005Goo0`00G7oo002HOol30007
FUH00`00FUIJEP04FUH6000=Ool200000eYF001oo`1LOol009]oo`8000EJEP03001JEUYF00IJEP04
001JEUYFFUH=0002FUH2001MOol009eoo`<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol00:1oo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008005ioo`00Y7oo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005mo
o`00Z7oo1P0015YF00<005YFFUH015YF00@005YF0000061oo`00[Woo3@00HWoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59004 .75323 m .59551 .69853 L .56449 .69354 L p .707 .577 .707 r
F P
0 g
s
.59551 .69853 m .59004 .75323 L .62173 .75524 L p .707 .577 .707 r
F P
0 g
s
.62173 .75524 m .6272 .70054 L .59551 .69853 L p .707 .577 .707 r
F P
0 g
s
.6272 .70054 m .62173 .75524 L .65101 .75407 L p .707 .577 .707 r
F P
0 g
s
.65101 .75407 m .65647 .69937 L .6272 .70054 L p .707 .577 .707 r
F P
0 g
s
.55902 .74825 m .56449 .69354 L .53718 .68606 L p .707 .577 .707 r
F P
0 g
s
.56449 .69354 m .55902 .74825 L .59004 .75323 L p .707 .577 .707 r
F P
0 g
s
.65647 .69937 m .65101 .75407 L .67499 .74984 L p .707 .577 .707 r
F P
0 g
s
.67499 .74984 m .68046 .69514 L .65647 .69937 L p .707 .577 .707 r
F P
0 g
s
.53171 .74077 m .53718 .68606 L .51626 .67682 L p .707 .577 .707 r
F P
0 g
s
.53718 .68606 m .53171 .74077 L .55902 .74825 L p .707 .577 .707 r
F P
0 g
s
.58385 .81668 m .58978 .78077 L .55902 .77386 L p .707 .577 .707 r
F P
0 g
s
.58978 .78077 m .58385 .81668 L .61532 .82041 L p .707 .577 .707 r
F P
0 g
s
.61532 .82041 m .62125 .78451 L .58978 .78077 L p .707 .577 .707 r
F P
0 g
s
.62125 .78451 m .61532 .82041 L .64441 .82062 L p .707 .577 .707 r
F P
0 g
s
.64441 .82062 m .65034 .78472 L .62125 .78451 L p .707 .577 .707 r
F P
0 g
s
.55309 .80977 m .55902 .77386 L .53196 .76447 L p .707 .577 .707 r
F P
0 g
s
.55902 .77386 m .55309 .80977 L .58385 .81668 L p .707 .577 .707 r
F P
0 g
s
.68046 .69514 m .67499 .74984 L .69134 .74296 L p .707 .577 .707 r
F P
0 g
s
.69134 .74296 m .6968 .68826 L .68046 .69514 L p .707 .577 .707 r
F P
0 g
s
.51626 .67682 m .5108 .73153 L .53171 .74077 L p .707 .577 .707 r
F P
0 g
s
.65034 .78472 m .64441 .82062 L .66828 .81727 L p .707 .577 .707 r
F P
0 g
s
.66828 .81727 m .67421 .78137 L .65034 .78472 L p .707 .577 .707 r
F P
0 g
s
.53196 .76447 m .52603 .80037 L .55309 .80977 L p .707 .577 .707 r
F P
0 g
s
.5108 .73153 m .51626 .67682 L .50378 .66673 L p .707 .577 .707 r
F P
0 g
s
.52603 .80037 m .53196 .76447 L .51128 .7535 L p .707 .577 .707 r
F P
0 g
s
.57945 .8614 m .58276 .84354 L .55209 .83607 L p .707 .577 .707 r
F P
0 g
s
.58276 .84354 m .57945 .8614 L .61083 .86565 L p .707 .577 .707 r
F P
0 g
s
.61083 .86565 m .61414 .84779 L .58276 .84354 L p .707 .577 .707 r
F P
0 g
s
.61414 .84779 m .61083 .86565 L .63985 .86626 L p .707 .577 .707 r
F P
0 g
s
.63985 .86626 m .64316 .84841 L .61414 .84779 L p .707 .577 .707 r
F P
0 g
s
.54879 .85392 m .55209 .83607 L .52514 .8261 L p .707 .577 .707 r
F P
0 g
s
.55209 .83607 m .54879 .85392 L .57945 .8614 L p .707 .577 .707 r
F P
0 g
s
.52514 .8261 m .52184 .84396 L .54879 .85392 L p .707 .577 .707 r
F P
0 g
s
.51128 .7535 m .50535 .7894 L .52603 .80037 L p .707 .577 .707 r
F P
0 g
s
.50378 .66673 m .49831 .72143 L .5108 .73153 L p .707 .577 .707 r
F P
0 g
s
.64316 .84841 m .63985 .86626 L .66367 .86317 L p .707 .577 .707 r
F P
0 g
s
.66367 .86317 m .66698 .84532 L .64316 .84841 L p .707 .577 .707 r
F P
0 g
s
.6968 .68826 m .69134 .74296 L .69844 .73411 L p .707 .577 .707 r
F P
0 g
s
.69844 .73411 m .70391 .67941 L .6968 .68826 L p .707 .577 .707 r
F P
0 g
s
.67421 .78137 m .66828 .81727 L .68458 .8107 L p .707 .577 .707 r
F P
0 g
s
.68458 .8107 m .69051 .77479 L .67421 .78137 L p .707 .577 .707 r
F P
0 g
s
.52184 .84396 m .52514 .8261 L .50454 .81462 L p .707 .577 .707 r
F P
0 g
s
.50535 .7894 m .51128 .7535 L .49897 .74203 L p .707 .577 .707 r
F P
0 g
s
.49831 .72143 m .50378 .66673 L .50095 .65676 L p .707 .577 .707 r
F P
0 g
s
.50454 .81462 m .50124 .83247 L .52184 .84396 L p .707 .577 .707 r
F P
0 g
s
.49897 .74203 m .49304 .77793 L .50535 .7894 L p .707 .577 .707 r
F P
0 g
s
.66698 .84532 m .66367 .86317 L .67996 .85669 L p .707 .577 .707 r
F P
0 g
s
.67996 .85669 m .68326 .83883 L .66698 .84532 L p .707 .577 .707 r
F P
0 g
s
.50124 .83247 m .50454 .81462 L .49231 .80275 L p .707 .577 .707 r
F P
0 g
s
.50095 .65676 m .49549 .71147 L .49831 .72143 L p .707 .577 .707 r
F P
0 g
s
.69051 .77479 m .68458 .8107 L .69173 .80154 L p .707 .577 .707 r
F P
0 g
s
.69173 .80154 m .69766 .76563 L .69051 .77479 L p .707 .577 .707 r
F P
0 g
s
.49231 .80275 m .48901 .8206 L .50124 .83247 L p .707 .577 .707 r
F P
0 g
s
.46423 .82209 m .51334 .32806 L .46954 .32104 L p .707 .577 .707 r
F P
0 g
s
.49304 .77793 m .49897 .74203 L .49626 .73119 L p .707 .577 .707 r
F P
0 g
s
.49549 .71147 m .50095 .65676 L .50806 .64791 L p .707 .577 .707 r
F P
0 g
s
.49626 .73119 m .49034 .76709 L .49304 .77793 L p .707 .577 .707 r
F P
0 g
s
.48901 .8206 m .49231 .80275 L .48965 .79164 L p .707 .577 .707 r
F P
0 g
s
.50806 .64791 m .50259 .70262 L .49549 .71147 L p .707 .577 .707 r
F P
0 g
s
.48965 .79164 m .48634 .80949 L .48901 .8206 L p .707 .577 .707 r
F P
0 g
s
.49034 .76709 m .49626 .73119 L .50341 .72203 L p .707 .577 .707 r
F P
0 g
s
.50259 .70262 m .50806 .64791 L .52441 .64103 L p .707 .577 .707 r
F P
0 g
s
.50341 .72203 m .49748 .75793 L .49034 .76709 L p .707 .577 .707 r
F P
0 g
s
.48634 .80949 m .48965 .79164 L .49681 .7824 L p .707 .577 .707 r
F P
0 g
s
.52441 .64103 m .51894 .69574 L .50259 .70262 L p .707 .577 .707 r
F P
0 g
s
.49681 .7824 m .49351 .80025 L .48634 .80949 L p .707 .577 .707 r
F P
0 g
s
.49748 .75793 m .50341 .72203 L .51972 .71545 L p .707 .577 .707 r
F P
0 g
s
.51972 .71545 m .51379 .75136 L .49748 .75793 L p .707 .577 .707 r
F P
0 g
s
.49351 .80025 m .49681 .7824 L .5131 .77591 L p .707 .577 .707 r
F P
0 g
s
.5131 .77591 m .50979 .79376 L .49351 .80025 L p .707 .577 .707 r
F P
0 g
s
.51334 .32806 m .46423 .82209 L .50899 .8249 L p .707 .577 .707 r
F P
0 g
s
.51894 .69574 m .52441 .64103 L .54839 .6368 L p .707 .577 .707 r
F P
0 g
s
.54839 .6368 m .54292 .69151 L .51894 .69574 L p .707 .577 .707 r
F P
0 g
s
.51379 .75136 m .51972 .71545 L .54358 .7121 L p .707 .577 .707 r
F P
0 g
s
.54358 .7121 m .53765 .74801 L .51379 .75136 L p .707 .577 .707 r
F P
0 g
s
.50979 .79376 m .5131 .77591 L .53692 .77282 L p .707 .577 .707 r
F P
0 g
s
.53692 .77282 m .53361 .79068 L .50979 .79376 L p .707 .577 .707 r
F P
0 g
s
.50899 .8249 m .55809 .33088 L .51334 .32806 L p .707 .577 .707 r
F P
0 g
s
.70391 .67941 m .69844 .73411 L .69562 .72415 L p .707 .577 .707 r
F P
0 g
s
.69562 .72415 m .70108 .66944 L .70391 .67941 L p .707 .577 .707 r
F P
0 g
s
.54292 .69151 m .54839 .6368 L .57766 .63563 L p .707 .577 .707 r
F P
0 g
s
.57766 .63563 m .57219 .69034 L .54292 .69151 L p .707 .577 .707 r
F P
0 g
s
.53765 .74801 m .54358 .7121 L .57267 .71231 L p .707 .577 .707 r
F P
0 g
s
.57267 .71231 m .56674 .74821 L .53765 .74801 L p .707 .577 .707 r
F P
0 g
s
.53361 .79068 m .53692 .77282 L .56594 .77343 L p .707 .577 .707 r
F P
0 g
s
.56594 .77343 m .56263 .79129 L .53361 .79068 L p .707 .577 .707 r
F P
0 g
s
.55809 .33088 m .50899 .8249 L .55031 .82324 L p .707 .577 .707 r
F P
0 g
s
.55031 .82324 m .59942 .32921 L .55809 .33088 L p .707 .577 .707 r
F P
0 g
s
.42044 .81507 m .46954 .32104 L .43099 .31051 L p .707 .577 .707 r
F P
0 g
s
.46954 .32104 m .42044 .81507 L .46423 .82209 L p .707 .577 .707 r
F P
0 g
s
.68326 .83883 m .67996 .85669 L .68712 .84744 L p .707 .577 .707 r
F P
0 g
s
.68712 .84744 m .69043 .82959 L .68326 .83883 L p .707 .577 .707 r
F P
0 g
s
.57219 .69034 m .57766 .63563 L .60936 .63764 L p .707 .577 .707 r
F P
0 g
s
.60936 .63764 m .60389 .69235 L .57219 .69034 L p .707 .577 .707 r
F P
0 g
s
.56674 .74821 m .57267 .71231 L .60414 .71605 L p .707 .577 .707 r
F P
0 g
s
.60414 .71605 m .59821 .75195 L .56674 .74821 L p .707 .577 .707 r
F P
0 g
s
.56263 .79129 m .56594 .77343 L .59732 .77769 L p .707 .577 .707 r
F P
0 g
s
.59732 .77769 m .59401 .79554 L .56263 .79129 L p .707 .577 .707 r
F P
0 g
s
.59942 .32921 m .55031 .82324 L .58417 .81725 L p .707 .577 .707 r
F P
0 g
s
.58417 .81725 m .63327 .32323 L .59942 .32921 L p .707 .577 .707 r
F P
0 g
s
.69766 .76563 m .69173 .80154 L .68902 .7907 L p .707 .577 .707 r
F P
0 g
s
.68902 .7907 m .69495 .75479 L .69766 .76563 L p .707 .577 .707 r
F P
0 g
s
.38189 .80453 m .43099 .31051 L .40146 .29748 L p .707 .577 .707 r
F P
0 g
s
.43099 .31051 m .38189 .80453 L .42044 .81507 L p .707 .577 .707 r
F P
0 g
s
.70108 .66944 m .69562 .72415 L .68313 .71406 L p .707 .577 .707 r
F P
0 g
s
.68313 .71406 m .6886 .65935 L .70108 .66944 L p .707 .577 .707 r
F P
0 g
s
.24703 .71355 m .2525 .65885 L .22148 .65386 L p .707 .577 .707 r
F P
0 g
s
.2525 .65885 m .24703 .71355 L .27873 .71556 L p .707 .577 .707 r
F P
0 g
s
.27873 .71556 m .28419 .66086 L .2525 .65885 L p .707 .577 .707 r
F P
0 g
s
.28419 .66086 m .27873 .71556 L .308 .71439 L p .707 .577 .707 r
F P
0 g
s
.308 .71439 m .31347 .65969 L .28419 .66086 L p .707 .577 .707 r
F P
0 g
s
.21601 .70857 m .22148 .65386 L .19417 .64638 L p .707 .577 .707 r
F P
0 g
s
.22148 .65386 m .21601 .70857 L .24703 .71355 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69043 .82959 m .68712 .84744 L .68446 .83634 L p .707 .577 .707 r
F P
0 g
s
.68446 .83634 m .68776 .81848 L .69043 .82959 L p .707 .577 .707 r
F P
0 g
s
.64038 .64263 m .63491 .69734 L .60389 .69235 L p .707 .577 .707 r
F P
0 g
s
.60389 .69235 m .60936 .63764 L .64038 .64263 L p .707 .577 .707 r
F P
0 g
s
.63491 .72296 m .62898 .75886 L .59821 .75195 L p .707 .577 .707 r
F P
0 g
s
.59821 .75195 m .60414 .71605 L .63491 .72296 L p .707 .577 .707 r
F P
0 g
s
.62798 .78516 m .62468 .80301 L .59401 .79554 L p .707 .577 .707 r
F P
0 g
s
.59401 .79554 m .59732 .77769 L .62798 .78516 L p .707 .577 .707 r
F P
0 g
s
.63327 .32323 m .58417 .81725 L .60725 .80754 L p .707 .577 .707 r
F P
0 g
s
.60725 .80754 m .65635 .31351 L .63327 .32323 L p .707 .577 .707 r
F P
0 g
s
.31347 .65969 m .308 .71439 L .33198 .71016 L p .707 .577 .707 r
F P
0 g
s
.33198 .71016 m .33745 .65546 L .31347 .65969 L p .707 .577 .707 r
F P
0 g
s
.69495 .75479 m .68902 .7907 L .67672 .77923 L p .707 .577 .707 r
F P
0 g
s
.67672 .77923 m .68265 .74332 L .69495 .75479 L p .707 .577 .707 r
F P
0 g
s
.6886 .65935 m .68313 .71406 L .66222 .70482 L p .707 .577 .707 r
F P
0 g
s
.66222 .70482 m .66768 .65011 L .6886 .65935 L p .707 .577 .707 r
F P
0 g
s
.1887 .70109 m .19417 .64638 L .17325 .63714 L p .707 .577 .707 r
F P
0 g
s
.19417 .64638 m .1887 .70109 L .21601 .70857 L p .707 .577 .707 r
F P
0 g
s
.35236 .79151 m .40146 .29748 L .38383 .28325 L p .707 .577 .707 r
F P
0 g
s
.40146 .29748 m .35236 .79151 L .38189 .80453 L p .707 .577 .707 r
F P
0 g
s
.24084 .77317 m .24677 .73727 L .21601 .73036 L p .707 .577 .707 r
F P
0 g
s
.24677 .73727 m .24084 .77317 L .27231 .77691 L p .707 .577 .707 r
F P
0 g
s
.27231 .77691 m .27824 .74101 L .24677 .73727 L p .707 .577 .707 r
F P
0 g
s
.27824 .74101 m .27231 .77691 L .3014 .77712 L p .707 .577 .707 r
F P
0 g
s
.3014 .77712 m .30733 .74121 L .27824 .74101 L p .707 .577 .707 r
F P
0 g
s
.21008 .76627 m .21601 .73036 L .18896 .72097 L p .707 .577 .707 r
F P
0 g
s
.21601 .73036 m .21008 .76627 L .24084 .77317 L p .707 .577 .707 r
F P
0 g
s
.33745 .65546 m .33198 .71016 L .34833 .70328 L p .707 .577 .707 r
F P
0 g
s
.34833 .70328 m .35379 .64858 L .33745 .65546 L p .707 .577 .707 r
F P
0 g
s
.17325 .63714 m .16779 .69185 L .1887 .70109 L p .707 .577 .707 r
F P
0 g
s
.68776 .81848 m .68446 .83634 L .67223 .82446 L p .707 .577 .707 r
F P
0 g
s
.67223 .82446 m .67553 .80661 L .68776 .81848 L p .707 .577 .707 r
F P
0 g
s
.30733 .74121 m .3014 .77712 L .32527 .77377 L p .707 .577 .707 r
F P
0 g
s
.32527 .77377 m .3312 .73787 L .30733 .74121 L p .707 .577 .707 r
F P
0 g
s
.18896 .72097 m .18303 .75687 L .21008 .76627 L p .707 .577 .707 r
F P
0 g
s
.66768 .65011 m .66222 .70482 L .63491 .69734 L p .707 .577 .707 r
F P
0 g
s
.63491 .69734 m .64038 .64263 L .66768 .65011 L p .707 .577 .707 r
F P
0 g
s
.16779 .69185 m .17325 .63714 L .16077 .62705 L p .707 .577 .707 r
F P
0 g
s
.23644 .81253 m .23975 .79468 L .20908 .7872 L p .707 .577 .707 r
F P
0 g
s
.23975 .79468 m .23644 .81253 L .26782 .81678 L p .707 .577 .707 r
F P
0 g
s
.26782 .81678 m .27113 .79893 L .23975 .79468 L p .707 .577 .707 r
F P
0 g
s
.18303 .75687 m .18896 .72097 L .16827 .71 L p .707 .577 .707 r
F P
0 g
s
.68265 .74332 m .67672 .77923 L .65603 .76826 L p .707 .577 .707 r
F P
0 g
s
.65603 .76826 m .66196 .73235 L .68265 .74332 L p .707 .577 .707 r
F P
0 g
s
.27113 .79893 m .26782 .81678 L .29684 .81739 L p .707 .577 .707 r
F P
0 g
s
.29684 .81739 m .30015 .79954 L .27113 .79893 L p .707 .577 .707 r
F P
0 g
s
.20578 .80506 m .20908 .7872 L .18213 .77724 L p .707 .577 .707 r
F P
0 g
s
.20908 .7872 m .20578 .80506 L .23644 .81253 L p .707 .577 .707 r
F P
0 g
s
.65635 .31351 m .60725 .80754 L .61728 .79504 L p .707 .577 .707 r
F P
0 g
s
.61728 .79504 m .66638 .30102 L .65635 .31351 L p .707 .577 .707 r
F P
0 g
s
.18213 .77724 m .17883 .79509 L .20578 .80506 L p .707 .577 .707 r
F P
0 g
s
.16827 .71 m .16234 .7459 L .18303 .75687 L p .707 .577 .707 r
F P
0 g
s
.16077 .62705 m .1553 .68175 L .16779 .69185 L p .707 .577 .707 r
F P
0 g
s
.30015 .79954 m .29684 .81739 L .32066 .81431 L p .707 .577 .707 r
F P
0 g
s
.32066 .81431 m .32397 .79645 L .30015 .79954 L p .707 .577 .707 r
F P
0 g
s
.3312 .73787 m .32527 .77377 L .34157 .7672 L p .707 .577 .707 r
F P
0 g
s
.34157 .7672 m .3475 .73129 L .3312 .73787 L p .707 .577 .707 r
F P
0 g
s
.35379 .64858 m .34833 .70328 L .35543 .69443 L p .707 .577 .707 r
F P
0 g
s
.35543 .69443 m .3609 .63973 L .35379 .64858 L p .707 .577 .707 r
F P
0 g
s
.35807 .62976 m .35261 .68447 L .34012 .67437 L p .707 .577 .707 r
F P
0 g
s
.34012 .67437 m .34559 .61967 L .35807 .62976 L p .707 .577 .707 r
F P
0 g
s
.3475 .73129 m .34157 .7672 L .34872 .75804 L p .707 .577 .707 r
F P
0 g
s
.34872 .75804 m .35465 .72213 L .3475 .73129 L p .707 .577 .707 r
F P
0 g
s
.35194 .71129 m .34601 .74719 L .34253 .74395 L p .707 .577 .707 r
F P
0 g
s
.34253 .74395 m .33371 .73573 L p .34437 .72144 L .707 .577 .707 r
F P
0 g
s
.34437 .72144 m .35194 .71129 L .34253 .74395 L .707 .577 .707 r
F
.33371 .73573 m .33964 .69982 L .35194 .71129 L p F P
0 g
s
.34476 .76962 m .34145 .78747 L .33864 .78474 L p .707 .577 .707 r
F P
0 g
s
.33864 .78474 m .32922 .77559 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.33964 .77158 m .34476 .76962 L .33864 .78474 L .707 .577 .707 r
F
.3674 .40935 m .36304 .49242 L .37984 .2692 L F
.32922 .77559 m .33253 .75774 L .34014 .76513 L p F P
0 g
s
.34014 .76513 m .34476 .76962 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.32922 .77559 m .34014 .76513 L .33964 .77158 L .707 .577 .707 r
F
.34559 .61967 m .34012 .67437 L .31921 .66514 L p F P
0 g
s
.33964 .69982 m .33371 .73573 L .31302 .72476 L p .707 .577 .707 r
F P
0 g
s
.31302 .72476 m .31895 .68885 L .33964 .69982 L p .707 .577 .707 r
F P
0 g
s
.33253 .75774 m .32922 .77559 L .30862 .76411 L p .707 .577 .707 r
F P
0 g
s
.30862 .76411 m .31193 .74626 L .33253 .75774 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .33473 .77728 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.37984 .2692 m .3724 .34407 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.31921 .66514 m .32467 .61043 L .34559 .61967 L p .707 .577 .707 r
F P
0 g
s
.3724 .34407 m .33074 .76322 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.33473 .77728 m .35427 .5807 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.35427 .5807 m .36304 .49242 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.36304 .49242 m .38383 .28325 L .38094 .27305 L p .707 .577 .707 r
F P
0 g
s
.38094 .27305 m .37984 .2692 L p .36304 .49242 L .707 .577 .707 r
F P
0 g
s
.3609 .63973 m .35543 .69443 L .35261 .68447 L p .707 .577 .707 r
F P
0 g
s
.35261 .68447 m .35807 .62976 L .3609 .63973 L p .707 .577 .707 r
F P
0 g
s
.34411 .79857 m .34742 .78072 L .34026 .78997 L p .707 .577 .707 r
F P
0 g
s
.35465 .72213 m .34872 .75804 L .34601 .74719 L p .707 .577 .707 r
F P
0 g
s
.34601 .74719 m .35194 .71129 L .35465 .72213 L p .707 .577 .707 r
F P
0 g
s
.34742 .78072 m .34411 .79857 L .34145 .78747 L p .707 .577 .707 r
F P
0 g
s
.34145 .78747 m .34476 .76962 L .34742 .78072 L p .707 .577 .707 r
F P
0 g
s
.38383 .28325 m .33473 .77728 L .35236 .79151 L p .707 .577 .707 r
F P
0 g
s
.17883 .79509 m .18213 .77724 L .16153 .76576 L p .707 .577 .707 r
F P
0 g
s
.16234 .7459 m .16827 .71 L .15597 .69853 L p .707 .577 .707 r
F P
0 g
s
.67553 .80661 m .67223 .82446 L .65163 .81298 L p .707 .577 .707 r
F P
0 g
s
.65163 .81298 m .65494 .79513 L .67553 .80661 L p .707 .577 .707 r
F P
0 g
s
.66196 .73235 m .65603 .76826 L .62898 .75886 L p .707 .577 .707 r
F P
0 g
s
.62898 .75886 m .63491 .72296 L .66196 .73235 L p .707 .577 .707 r
F P
0 g
s
.16153 .76576 m .15823 .78361 L .17883 .79509 L p .707 .577 .707 r
F P
0 g
s
.1553 .68175 m .16077 .62705 L .15795 .61708 L p .707 .577 .707 r
F P
0 g
s
.15597 .69853 m .15004 .73443 L .16234 .7459 L p .707 .577 .707 r
F P
0 g
s
.32397 .79645 m .32066 .81431 L .33695 .80782 L p .707 .577 .707 r
F P
0 g
s
.33695 .80782 m .34026 .78997 L .32397 .79645 L p .707 .577 .707 r
F P
0 g
s
.15823 .78361 m .16153 .76576 L .1493 .75388 L p .707 .577 .707 r
F P
0 g
s
.65494 .79513 m .65163 .81298 L .62468 .80301 L p .707 .577 .707 r
F P
0 g
s
.62468 .80301 m .62798 .78516 L .65494 .79513 L p .707 .577 .707 r
F P
0 g
s
.15795 .61708 m .15248 .67179 L .1553 .68175 L p .707 .577 .707 r
F P
0 g
s
.1493 .75388 m .146 .77173 L .15823 .78361 L p .707 .577 .707 r
F P
0 g
s
.15004 .73443 m .15597 .69853 L .15326 .68768 L p .707 .577 .707 r
F P
0 g
s
.66638 .30102 m .61728 .79504 L .61329 .78099 L p .707 .577 .707 r
F P
0 g
s
.61329 .78099 m .66239 .28696 L .66638 .30102 L p .707 .577 .707 r
F P
0 g
s
.15248 .67179 m .15795 .61708 L .16505 .60823 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .37984 .2692 L .38988 .2567 L p .707 .577 .707 r
F P
0 g
s
.15326 .68768 m .14733 .72359 L .15004 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34026 .78997 m .33695 .80782 L .34411 .79857 L p .707 .577 .707 r
F P
0 g
s
.146 .77173 m .1493 .75388 L .14664 .74278 L p .707 .577 .707 r
F P
0 g
s
.14664 .74278 m .14333 .76063 L .146 .77173 L p .707 .577 .707 r
F P
0 g
s
.16505 .60823 m .15958 .66294 L .15248 .67179 L p .707 .577 .707 r
F P
0 g
s
.14733 .72359 m .15326 .68768 L .1604 .67853 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15958 .66294 m .16505 .60823 L .1814 .60135 L p .707 .577 .707 r
F P
0 g
s
.1604 .67853 m .15447 .71443 L .14733 .72359 L p .707 .577 .707 r
F P
0 g
s
.66239 .28696 m .61329 .78099 L .59567 .76676 L p .707 .577 .707 r
F P
0 g
s
.59567 .76676 m .64477 .27273 L .66239 .28696 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14333 .76063 m .14664 .74278 L .1538 .73353 L p .707 .577 .707 r
F P
0 g
s
.34077 .75073 m .38988 .2567 L .41295 .24699 L p .707 .577 .707 r
F P
0 g
s
.38988 .2567 m .34077 .75073 L .33074 .76322 L p .707 .577 .707 r
F P
0 g
s
.1538 .73353 m .1505 .75138 L .14333 .76063 L p .707 .577 .707 r
F P
0 g
s
.1814 .60135 m .17593 .65606 L .15958 .66294 L p .707 .577 .707 r
F P
0 g
s
.15447 .71443 m .1604 .67853 L .17671 .67195 L p .707 .577 .707 r
F P
0 g
s
.17593 .65606 m .1814 .60135 L .20538 .59712 L p .707 .577 .707 r
F P
0 g
s
.17671 .67195 m .17078 .70786 L .15447 .71443 L p .707 .577 .707 r
F P
0 g
s
.1505 .75138 m .1538 .73353 L .17009 .72704 L p .707 .577 .707 r
F P
0 g
s
.32467 .61043 m .31921 .66514 L .2919 .65766 L p .707 .577 .707 r
F P
0 g
s
.2919 .65766 m .29737 .60295 L .32467 .61043 L p .707 .577 .707 r
F P
0 g
s
.20538 .59712 m .19991 .65183 L .17593 .65606 L p .707 .577 .707 r
F P
0 g
s
.64477 .27273 m .59567 .76676 L .56613 .75373 L p .707 .577 .707 r
F P
0 g
s
.56613 .75373 m .61524 .25971 L .64477 .27273 L p .707 .577 .707 r
F P
0 g
s
.17009 .72704 m .16678 .7449 L .1505 .75138 L p .707 .577 .707 r
F P
0 g
s
.19991 .65183 m .20538 .59712 L .23465 .59595 L p .707 .577 .707 r
F P
0 g
s
.17078 .70786 m .17671 .67195 L .20057 .6686 L p .707 .577 .707 r
F P
0 g
s
.41295 .24699 m .36385 .74101 L .34077 .75073 L p .707 .577 .707 r
F P
0 g
s
.36385 .74101 m .41295 .24699 L .44681 .241 L p .707 .577 .707 r
F P
0 g
s
.29737 .60295 m .2919 .65766 L .26088 .65267 L p .707 .577 .707 r
F P
0 g
s
.26088 .65267 m .26635 .59796 L .29737 .60295 L p .707 .577 .707 r
F P
0 g
s
.22918 .65066 m .23465 .59595 L .26635 .59796 L p .707 .577 .707 r
F P
0 g
s
.23465 .59595 m .22918 .65066 L .19991 .65183 L p .707 .577 .707 r
F P
0 g
s
.20057 .6686 m .19464 .70451 L .17078 .70786 L p .707 .577 .707 r
F P
0 g
s
.26635 .59796 m .26088 .65267 L .22918 .65066 L p .707 .577 .707 r
F P
0 g
s
.16678 .7449 m .17009 .72704 L .19391 .72396 L p .707 .577 .707 r
F P
0 g
s
.31895 .68885 m .31302 .72476 L .28597 .71536 L p .707 .577 .707 r
F P
0 g
s
.28597 .71536 m .2919 .67945 L .31895 .68885 L p .707 .577 .707 r
F P
0 g
s
.72724 .6612 m .73271 .60649 L .70169 .6015 L p .707 .577 .707 r
F P
0 g
s
.73271 .60649 m .72724 .6612 L .75894 .6632 L p .707 .577 .707 r
F P
0 g
s
.75894 .6632 m .76441 .6085 L .73271 .60649 L p .707 .577 .707 r
F P
0 g
s
.19464 .70451 m .20057 .6686 L .22966 .66881 L p .707 .577 .707 r
F P
0 g
s
.76441 .6085 m .75894 .6632 L .78821 .66204 L p .707 .577 .707 r
F P
0 g
s
.78821 .66204 m .79368 .60733 L .76441 .6085 L p .707 .577 .707 r
F P
0 g
s
.19391 .72396 m .19061 .74181 L .16678 .7449 L p .707 .577 .707 r
F P
0 g
s
.69622 .65621 m .70169 .6015 L .67439 .59402 L p .707 .577 .707 r
F P
0 g
s
.70169 .6015 m .69622 .65621 L .72724 .6612 L p .707 .577 .707 r
F P
0 g
s
.61524 .25971 m .56613 .75373 L .52758 .7432 L p .707 .577 .707 r
F P
0 g
s
.52758 .7432 m .57668 .24917 L .61524 .25971 L p .707 .577 .707 r
F P
0 g
s
.2919 .67945 m .28597 .71536 L .2552 .70845 L p .707 .577 .707 r
F P
0 g
s
.2552 .70845 m .26113 .67255 L .2919 .67945 L p .707 .577 .707 r
F P
0 g
s
.22966 .66881 m .22373 .70471 L .19464 .70451 L p .707 .577 .707 r
F P
0 g
s
.39771 .73503 m .44681 .241 L .48814 .23934 L p .707 .577 .707 r
F P
0 g
s
.44681 .241 m .39771 .73503 L .36385 .74101 L p .707 .577 .707 r
F P
0 g
s
.22373 .70471 m .22966 .66881 L .26113 .67255 L p .707 .577 .707 r
F P
0 g
s
.79368 .60733 m .78821 .66204 L .81219 .6578 L p .707 .577 .707 r
F P
0 g
s
.81219 .6578 m .81766 .6031 L .79368 .60733 L p .707 .577 .707 r
F P
0 g
s
.31193 .74626 m .30862 .76411 L .28167 .75415 L p .707 .577 .707 r
F P
0 g
s
.28167 .75415 m .28497 .73629 L .31193 .74626 L p .707 .577 .707 r
F P
0 g
s
.26113 .67255 m .2552 .70845 L .22373 .70471 L p .707 .577 .707 r
F P
0 g
s
.19061 .74181 m .19391 .72396 L .22293 .72457 L p .707 .577 .707 r
F P
0 g
s
.66892 .64873 m .67439 .59402 L .65347 .58478 L p .707 .577 .707 r
F P
0 g
s
.67439 .59402 m .66892 .64873 L .69622 .65621 L p .707 .577 .707 r
F P
0 g
s
.72106 .72464 m .72698 .68873 L .69622 .68183 L p .707 .577 .707 r
F P
0 g
s
.72698 .68873 m .72106 .72464 L .75252 .72838 L p .707 .577 .707 r
F P
0 g
s
.75252 .72838 m .75845 .69247 L .72698 .68873 L p .707 .577 .707 r
F P
0 g
s
.22293 .72457 m .21962 .74242 L .19061 .74181 L p .707 .577 .707 r
F P
0 g
s
.57668 .24917 m .52758 .7432 L .48379 .73618 L p .707 .577 .707 r
F P
0 g
s
.48379 .73618 m .53289 .24215 L .57668 .24917 L p .707 .577 .707 r
F P
0 g
s
.75845 .69247 m .75252 .72838 L .78162 .72858 L p .707 .577 .707 r
F P
0 g
s
.78162 .72858 m .78754 .69268 L .75845 .69247 L p .707 .577 .707 r
F P
0 g
s
.69029 .71773 m .69622 .68183 L .66917 .67243 L p .707 .577 .707 r
F P
0 g
s
.69622 .68183 m .69029 .71773 L .72106 .72464 L p .707 .577 .707 r
F P
0 g
s
.43904 .73336 m .48814 .23934 L .53289 .24215 L p .707 .577 .707 r
F P
0 g
s
.48814 .23934 m .43904 .73336 L .39771 .73503 L p .707 .577 .707 r
F P
0 g
s
.28497 .73629 m .28167 .75415 L .251 .74667 L p .707 .577 .707 r
F P
0 g
s
.251 .74667 m .25431 .72882 L .28497 .73629 L p .707 .577 .707 r
F P
0 g
s
.21962 .74242 m .22293 .72457 L .25431 .72882 L p .707 .577 .707 r
F P
0 g
s
.25431 .72882 m .251 .74667 L .21962 .74242 L p .707 .577 .707 r
F P
0 g
s
.53289 .24215 m .48379 .73618 L .43904 .73336 L p .707 .577 .707 r
F P
0 g
s
.81766 .6031 m .81219 .6578 L .82854 .65093 L p .707 .577 .707 r
F P
0 g
s
.82854 .65093 m .83401 .59622 L .81766 .6031 L p .707 .577 .707 r
F P
0 g
s
.65347 .58478 m .648 .63949 L .66892 .64873 L p .707 .577 .707 r
F P
0 g
s
.78754 .69268 m .78162 .72858 L .80548 .72523 L p .707 .577 .707 r
F P
0 g
s
.80548 .72523 m .81141 .68933 L .78754 .69268 L p .707 .577 .707 r
F P
0 g
s
.66917 .67243 m .66324 .70833 L .69029 .71773 L p .707 .577 .707 r
F P
0 g
s
.648 .63949 m .65347 .58478 L .64098 .57469 L p .707 .577 .707 r
F P
0 g
s
.66324 .70833 m .66917 .67243 L .64848 .66146 L p .707 .577 .707 r
F P
0 g
s
.71666 .76936 m .71996 .75151 L .6893 .74403 L p .707 .577 .707 r
F P
0 g
s
.71996 .75151 m .71666 .76936 L .74804 .77361 L p .707 .577 .707 r
F P
0 g
s
.74804 .77361 m .75134 .75576 L .71996 .75151 L p .707 .577 .707 r
F P
0 g
s
.75134 .75576 m .74804 .77361 L .77706 .77422 L p .707 .577 .707 r
F P
0 g
s
.77706 .77422 m .78036 .75637 L .75134 .75576 L p .707 .577 .707 r
F P
0 g
s
.68599 .76188 m .6893 .74403 L .66234 .73407 L p .707 .577 .707 r
F P
0 g
s
.6893 .74403 m .68599 .76188 L .71666 .76936 L p .707 .577 .707 r
F P
0 g
s
.66234 .73407 m .65904 .75192 L .68599 .76188 L p .707 .577 .707 r
F P
0 g
s
.64848 .66146 m .64255 .69736 L .66324 .70833 L p .707 .577 .707 r
F P
0 g
s
.64098 .57469 m .63552 .62939 L .648 .63949 L p .707 .577 .707 r
F P
0 g
s
.78036 .75637 m .77706 .77422 L .80088 .77113 L p .707 .577 .707 r
F P
0 g
s
.80088 .77113 m .80418 .75328 L .78036 .75637 L p .707 .577 .707 r
F P
0 g
s
.83401 .59622 m .82854 .65093 L .83565 .64207 L p .707 .577 .707 r
F P
0 g
s
.83565 .64207 m .84111 .58737 L .83401 .59622 L p .707 .577 .707 r
F P
0 g
s
.81141 .68933 m .80548 .72523 L .82179 .71866 L p .707 .577 .707 r
F P
0 g
s
.82179 .71866 m .82772 .68275 L .81141 .68933 L p .707 .577 .707 r
F P
0 g
s
.65904 .75192 m .66234 .73407 L .64174 .72258 L p .707 .577 .707 r
F P
0 g
s
.64255 .69736 m .64848 .66146 L .63618 .64999 L p .707 .577 .707 r
F P
0 g
s
.63552 .62939 m .64098 .57469 L .63816 .56473 L p .707 .577 .707 r
F P
0 g
s
.64174 .72258 m .63844 .74044 L .65904 .75192 L p .707 .577 .707 r
F P
0 g
s
.63618 .64999 m .63025 .68589 L .64255 .69736 L p .707 .577 .707 r
F P
0 g
s
.80418 .75328 m .80088 .77113 L .81717 .76465 L p .707 .577 .707 r
F P
0 g
s
.81717 .76465 m .82047 .7468 L .80418 .75328 L p .707 .577 .707 r
F P
0 g
s
.63844 .74044 m .64174 .72258 L .62951 .71071 L p .707 .577 .707 r
F P
0 g
s
.63816 .56473 m .63269 .61943 L .63552 .62939 L p .707 .577 .707 r
F P
0 g
s
.82772 .68275 m .82179 .71866 L .82893 .7095 L p .707 .577 .707 r
F P
0 g
s
.82893 .7095 m .83486 .6736 L .82772 .68275 L p .707 .577 .707 r
F P
0 g
s
.62951 .71071 m .62621 .72856 L .63844 .74044 L p .707 .577 .707 r
F P
0 g
s
.84111 .58737 m .83565 .64207 L .83282 .63211 L p .707 .577 .707 r
F P
0 g
s
.83282 .63211 m .83829 .57741 L .84111 .58737 L p .707 .577 .707 r
F P
0 g
s
.63025 .68589 m .63618 .64999 L .63347 .63915 L p .707 .577 .707 r
F P
0 g
s
.63269 .61943 m .63816 .56473 L .64527 .55587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63347 .63915 m .62754 .67505 L .63025 .68589 L p .707 .577 .707 r
F P
0 g
s
.82047 .7468 m .81717 .76465 L .82433 .7554 L p .707 .577 .707 r
F P
0 g
s
.82433 .7554 m .82763 .73755 L .82047 .7468 L p .707 .577 .707 r
F P
0 g
s
.62621 .72856 m .62951 .71071 L .62685 .6996 L p .707 .577 .707 r
F P
0 g
s
.64527 .55587 m .6398 .61058 L .63269 .61943 L p .707 .577 .707 r
F P
0 g
s
.62685 .6996 m .62355 .71746 L .62621 .72856 L p .707 .577 .707 r
F P
0 g
s
.83486 .6736 m .82893 .7095 L .82622 .69866 L p .707 .577 .707 r
F P
0 g
s
.82622 .69866 m .83215 .66275 L .83486 .6736 L p .707 .577 .707 r
F P
0 g
s
.62754 .67505 m .63347 .63915 L .64062 .62999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83829 .57741 m .83282 .63211 L .82034 .62202 L p .707 .577 .707 r
F P
0 g
s
.82034 .62202 m .82581 .56731 L .83829 .57741 L p .707 .577 .707 r
F P
0 g
s
.6398 .61058 m .64527 .55587 L .66161 .54899 L p .707 .577 .707 r
F P
0 g
s
.38423 .62151 m .3897 .56681 L .35868 .56182 L p .707 .577 .707 r
F P
0 g
s
.3897 .56681 m .38423 .62151 L .41593 .62352 L p .707 .577 .707 r
F P
0 g
s
.41593 .62352 m .4214 .56882 L .3897 .56681 L p .707 .577 .707 r
F P
0 g
s
.4214 .56882 m .41593 .62352 L .4452 .62235 L p .707 .577 .707 r
F P
0 g
s
.4452 .62235 m .45067 .56765 L .4214 .56882 L p .707 .577 .707 r
F P
0 g
s
.64062 .62999 m .63469 .66589 L .62754 .67505 L p .707 .577 .707 r
F P
0 g
s
.35321 .61653 m .35868 .56182 L .33138 .55434 L p .707 .577 .707 r
F P
0 g
s
.35868 .56182 m .35321 .61653 L .38423 .62151 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82763 .73755 m .82433 .7554 L .82166 .7443 L p .707 .577 .707 r
F P
0 g
s
.82166 .7443 m .82497 .72644 L .82763 .73755 L p .707 .577 .707 r
F P
0 g
s
.62355 .71746 m .62685 .6996 L .63401 .69036 L p .707 .577 .707 r
F P
0 g
s
.45067 .56765 m .4452 .62235 L .46918 .61812 L p .707 .577 .707 r
F P
0 g
s
.46918 .61812 m .47465 .56342 L .45067 .56765 L p .707 .577 .707 r
F P
0 g
s
.66161 .54899 m .65614 .6037 L .6398 .61058 L p .707 .577 .707 r
F P
0 g
s
.63401 .69036 m .63071 .70821 L .62355 .71746 L p .707 .577 .707 r
F P
0 g
s
.83215 .66275 m .82622 .69866 L .81392 .68719 L p .707 .577 .707 r
F P
0 g
s
.81392 .68719 m .81985 .65128 L .83215 .66275 L p .707 .577 .707 r
F P
0 g
s
.82581 .56731 m .82034 .62202 L .79942 .61278 L p .707 .577 .707 r
F P
0 g
s
.79942 .61278 m .80489 .55807 L .82581 .56731 L p .707 .577 .707 r
F P
0 g
s
.32591 .60905 m .33138 .55434 L .31046 .5451 L p .707 .577 .707 r
F P
0 g
s
.33138 .55434 m .32591 .60905 L .35321 .61653 L p .707 .577 .707 r
F P
0 g
s
.63469 .66589 m .64062 .62999 L .65692 .62342 L p .707 .577 .707 r
F P
0 g
s
.37805 .68114 m .38397 .64523 L .35321 .63833 L p .707 .577 .707 r
F P
0 g
s
.38397 .64523 m .37805 .68114 L .40951 .68488 L p .707 .577 .707 r
F P
0 g
s
.40951 .68488 m .41544 .64897 L .38397 .64523 L p .707 .577 .707 r
F P
0 g
s
.65614 .6037 m .66161 .54899 L .68559 .54476 L p .707 .577 .707 r
F P
0 g
s
.41544 .64897 m .40951 .68488 L .43861 .68508 L p .707 .577 .707 r
F P
0 g
s
.43861 .68508 m .44453 .64918 L .41544 .64897 L p .707 .577 .707 r
F P
0 g
s
.34728 .67423 m .35321 .63833 L .32616 .62893 L p .707 .577 .707 r
F P
0 g
s
.35321 .63833 m .34728 .67423 L .37805 .68114 L p .707 .577 .707 r
F P
0 g
s
.65692 .62342 m .65099 .65932 L .63469 .66589 L p .707 .577 .707 r
F P
0 g
s
.47465 .56342 m .46918 .61812 L .48553 .61125 L p .707 .577 .707 r
F P
0 g
s
.48553 .61125 m .491 .55654 L .47465 .56342 L p .707 .577 .707 r
F P
0 g
s
.31046 .5451 m .30499 .59981 L .32591 .60905 L p .707 .577 .707 r
F P
0 g
s
.82497 .72644 m .82166 .7443 L .80944 .73242 L p .707 .577 .707 r
F P
0 g
s
.80944 .73242 m .81274 .71457 L .82497 .72644 L p .707 .577 .707 r
F P
0 g
s
.63071 .70821 m .63401 .69036 L .6503 .68387 L p .707 .577 .707 r
F P
0 g
s
.44453 .64918 m .43861 .68508 L .46247 .68173 L p .707 .577 .707 r
F P
0 g
s
.46247 .68173 m .4684 .64583 L .44453 .64918 L p .707 .577 .707 r
F P
0 g
s
.32616 .62893 m .32023 .66483 L .34728 .67423 L p .707 .577 .707 r
F P
0 g
s
.80489 .55807 m .79942 .61278 L .77212 .6053 L p .707 .577 .707 r
F P
0 g
s
.77212 .6053 m .77758 .55059 L .80489 .55807 L p .707 .577 .707 r
F P
0 g
s
.30499 .59981 m .31046 .5451 L .29797 .53501 L p .707 .577 .707 r
F P
0 g
s
.37365 .72049 m .37695 .70264 L .34629 .69517 L p .707 .577 .707 r
F P
0 g
s
.37695 .70264 m .37365 .72049 L .40503 .72474 L p .707 .577 .707 r
F P
0 g
s
.40503 .72474 m .40833 .70689 L .37695 .70264 L p .707 .577 .707 r
F P
0 g
s
.68559 .54476 m .68013 .59947 L .65614 .6037 L p .707 .577 .707 r
F P
0 g
s
.32023 .66483 m .32616 .62893 L .30547 .61796 L p .707 .577 .707 r
F P
0 g
s
.81985 .65128 m .81392 .68719 L .79323 .67622 L p .707 .577 .707 r
F P
0 g
s
.79323 .67622 m .79916 .64031 L .81985 .65128 L p .707 .577 .707 r
F P
0 g
s
.68013 .59947 m .68559 .54476 L .71487 .5436 L p .707 .577 .707 r
F P
0 g
s
.40833 .70689 m .40503 .72474 L .43405 .72536 L p .707 .577 .707 r
F P
0 g
s
.43405 .72536 m .43735 .7075 L .40833 .70689 L p .707 .577 .707 r
F P
0 g
s
.6503 .68387 m .647 .70172 L .63071 .70821 L p .707 .577 .707 r
F P
0 g
s
.34298 .71302 m .34629 .69517 L .31933 .6852 L p .707 .577 .707 r
F P
0 g
s
.34629 .69517 m .34298 .71302 L .37365 .72049 L p .707 .577 .707 r
F P
0 g
s
.65099 .65932 m .65692 .62342 L .68079 .62007 L p .707 .577 .707 r
F P
0 g
s
.31933 .6852 m .31603 .70305 L .34298 .71302 L p .707 .577 .707 r
F P
0 g
s
.30547 .61796 m .29954 .65386 L .32023 .66483 L p .707 .577 .707 r
F P
0 g
s
.77758 .55059 m .77212 .6053 L .7411 .60031 L p .707 .577 .707 r
F P
0 g
s
.7411 .60031 m .74656 .5456 L .77758 .55059 L p .707 .577 .707 r
F P
0 g
s
.7094 .5983 m .71487 .5436 L .74656 .5456 L p .707 .577 .707 r
F P
0 g
s
.71487 .5436 m .7094 .5983 L .68013 .59947 L p .707 .577 .707 r
F P
0 g
s
.29797 .53501 m .29251 .58971 L .30499 .59981 L p .707 .577 .707 r
F P
0 g
s
.43735 .7075 m .43405 .72536 L .45787 .72227 L p .707 .577 .707 r
F P
0 g
s
.45787 .72227 m .46117 .70441 L .43735 .7075 L p .707 .577 .707 r
F P
0 g
s
.68079 .62007 m .67486 .65597 L .65099 .65932 L p .707 .577 .707 r
F P
0 g
s
.31603 .70305 m .31933 .6852 L .29873 .67372 L p .707 .577 .707 r
F P
0 g
s
.4684 .64583 m .46247 .68173 L .47878 .67516 L p .707 .577 .707 r
F P
0 g
s
.47878 .67516 m .48471 .63925 L .4684 .64583 L p .707 .577 .707 r
F P
0 g
s
.74656 .5456 m .7411 .60031 L .7094 .5983 L p .707 .577 .707 r
F P
0 g
s
.491 .55654 m .48553 .61125 L .49264 .60239 L p .707 .577 .707 r
F P
0 g
s
.49264 .60239 m .4981 .54769 L .491 .55654 L p .707 .577 .707 r
F P
0 g
s
.29954 .65386 m .30547 .61796 L .29317 .60649 L p .707 .577 .707 r
F P
0 g
s
.81274 .71457 m .80944 .73242 L .78884 .72094 L p .707 .577 .707 r
F P
0 g
s
.78884 .72094 m .79214 .70309 L .81274 .71457 L p .707 .577 .707 r
F P
0 g
s
.79916 .64031 m .79323 .67622 L .76618 .66682 L p .707 .577 .707 r
F P
0 g
s
.76618 .66682 m .77211 .63092 L .79916 .64031 L p .707 .577 .707 r
F P
0 g
s
.647 .70172 m .6503 .68387 L .67412 .68078 L p .707 .577 .707 r
F P
0 g
s
.29873 .67372 m .29543 .69157 L .31603 .70305 L p .707 .577 .707 r
F P
0 g
s
.67486 .65597 m .68079 .62007 L .70988 .62027 L p .707 .577 .707 r
F P
0 g
s
.29251 .58971 m .29797 .53501 L .29515 .52505 L p .707 .577 .707 r
F P
0 g
s
.67412 .68078 m .67082 .69864 L .647 .70172 L p .707 .577 .707 r
F P
0 g
s
.29317 .60649 m .28724 .64239 L .29954 .65386 L p .707 .577 .707 r
F P
0 g
s
.77211 .63092 m .76618 .66682 L .73542 .65991 L p .707 .577 .707 r
F P
0 g
s
.73542 .65991 m .74135 .62401 L .77211 .63092 L p .707 .577 .707 r
F P
0 g
s
.46117 .70441 m .45787 .72227 L .47416 .71578 L p .707 .577 .707 r
F P
0 g
s
.47416 .71578 m .47746 .69793 L .46117 .70441 L p .707 .577 .707 r
F P
0 g
s
.70988 .62027 m .70395 .65618 L .67486 .65597 L p .707 .577 .707 r
F P
0 g
s
.70395 .65618 m .70988 .62027 L .74135 .62401 L p .707 .577 .707 r
F P
0 g
s
.29543 .69157 m .29873 .67372 L .2865 .66184 L p .707 .577 .707 r
F P
0 g
s
.74135 .62401 m .73542 .65991 L .70395 .65618 L p .707 .577 .707 r
F P
0 g
s
.79214 .70309 m .78884 .72094 L .76188 .71097 L p .707 .577 .707 r
F P
0 g
s
.76188 .71097 m .76519 .69312 L .79214 .70309 L p .707 .577 .707 r
F P
0 g
s
.29515 .52505 m .28968 .57975 L .29251 .58971 L p .707 .577 .707 r
F P
0 g
s
.48471 .63925 m .47878 .67516 L .48592 .666 L p .707 .577 .707 r
F P
0 g
s
.48592 .666 m .49185 .6301 L .48471 .63925 L p .707 .577 .707 r
F P
0 g
s
.67082 .69864 m .67412 .68078 L .70314 .6814 L p .707 .577 .707 r
F P
0 g
s
.2865 .66184 m .2832 .6797 L .29543 .69157 L p .707 .577 .707 r
F P
0 g
s
.28724 .64239 m .29317 .60649 L .29046 .59565 L p .707 .577 .707 r
F P
0 g
s
.4981 .54769 m .49264 .60239 L .48981 .59243 L p .707 .577 .707 r
F P
0 g
s
.48981 .59243 m .49528 .53773 L .4981 .54769 L p .707 .577 .707 r
F P
0 g
s
.70314 .6814 m .69984 .69925 L .67082 .69864 L p .707 .577 .707 r
F P
0 g
s
.28968 .57975 m .29515 .52505 L .30226 .51619 L p .707 .577 .707 r
F P
0 g
s
.76519 .69312 m .76188 .71097 L .73122 .7035 L p .707 .577 .707 r
F P
0 g
s
.73122 .7035 m .73452 .68565 L .76519 .69312 L p .707 .577 .707 r
F P
0 g
s
.69984 .69925 m .70314 .6814 L .73452 .68565 L p .707 .577 .707 r
F P
0 g
s
.29046 .59565 m .28453 .63155 L .28724 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73452 .68565 m .73122 .7035 L .69984 .69925 L p .707 .577 .707 r
F P
0 g
s
.47746 .69793 m .47416 .71578 L .48132 .70654 L p .707 .577 .707 r
F P
0 g
s
.48132 .70654 m .48462 .68868 L .47746 .69793 L p .707 .577 .707 r
F P
0 g
s
.2832 .6797 m .2865 .66184 L .28384 .65074 L p .707 .577 .707 r
F P
0 g
s
.28384 .65074 m .28054 .66859 L .2832 .6797 L p .707 .577 .707 r
F P
0 g
s
.30226 .51619 m .29679 .5709 L .28968 .57975 L p .707 .577 .707 r
F P
0 g
s
.49185 .6301 m .48592 .666 L .48321 .65516 L p .707 .577 .707 r
F P
0 g
s
.48321 .65516 m .48914 .61925 L .49185 .6301 L p .707 .577 .707 r
F P
0 g
s
.28453 .63155 m .29046 .59565 L .29761 .58649 L p .707 .577 .707 r
F P
0 g
s
.49528 .53773 m .48981 .59243 L .47733 .58234 L p .707 .577 .707 r
F P
0 g
s
.47733 .58234 m .4828 .52763 L .49528 .53773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29679 .5709 m .30226 .51619 L .3186 .50931 L p .707 .577 .707 r
F P
0 g
s
.29761 .58649 m .29168 .62239 L .28453 .63155 L p .707 .577 .707 r
F P
0 g
s
.48462 .68868 m .48132 .70654 L .47865 .69543 L p .707 .577 .707 r
F P
0 g
s
.47865 .69543 m .48196 .67758 L .48462 .68868 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28054 .66859 m .28384 .65074 L .291 .64149 L p .707 .577 .707 r
F P
0 g
s
.291 .64149 m .2877 .65934 L .28054 .66859 L p .707 .577 .707 r
F P
0 g
s
.3186 .50931 m .31313 .56402 L .29679 .5709 L p .707 .577 .707 r
F P
0 g
s
.48914 .61925 m .48321 .65516 L .47091 .64369 L p .707 .577 .707 r
F P
0 g
s
.47091 .64369 m .47684 .60778 L .48914 .61925 L p .707 .577 .707 r
F P
0 g
s
.4828 .52763 m .47733 .58234 L .45641 .5731 L p .707 .577 .707 r
F P
0 g
s
.45641 .5731 m .46188 .51839 L .4828 .52763 L p .707 .577 .707 r
F P
0 g
s
.29168 .62239 m .29761 .58649 L .31391 .57991 L p .707 .577 .707 r
F P
0 g
s
.31313 .56402 m .3186 .50931 L .34258 .50508 L p .707 .577 .707 r
F P
0 g
s
.31391 .57991 m .30798 .61582 L .29168 .62239 L p .707 .577 .707 r
F P
0 g
s
.48196 .67758 m .47865 .69543 L .46642 .68356 L p .707 .577 .707 r
F P
0 g
s
.46642 .68356 m .46973 .6657 L .48196 .67758 L p .707 .577 .707 r
F P
0 g
s
.2877 .65934 m .291 .64149 L .30729 .63501 L p .707 .577 .707 r
F P
0 g
s
.46188 .51839 m .45641 .5731 L .42911 .56562 L p .707 .577 .707 r
F P
0 g
s
.42911 .56562 m .43457 .51091 L .46188 .51839 L p .707 .577 .707 r
F P
0 g
s
.34258 .50508 m .33712 .55979 L .31313 .56402 L p .707 .577 .707 r
F P
0 g
s
.47684 .60778 m .47091 .64369 L .45022 .63272 L p .707 .577 .707 r
F P
0 g
s
.45022 .63272 m .45615 .59681 L .47684 .60778 L p .707 .577 .707 r
F P
0 g
s
.30729 .63501 m .30399 .65286 L .2877 .65934 L p .707 .577 .707 r
F P
0 g
s
.33712 .55979 m .34258 .50508 L .37186 .50391 L p .707 .577 .707 r
F P
0 g
s
.30798 .61582 m .31391 .57991 L .33778 .57657 L p .707 .577 .707 r
F P
0 g
s
.43457 .51091 m .42911 .56562 L .39809 .56063 L p .707 .577 .707 r
F P
0 g
s
.39809 .56063 m .40355 .50592 L .43457 .51091 L p .707 .577 .707 r
F P
0 g
s
.36639 .55862 m .37186 .50391 L .40355 .50592 L p .707 .577 .707 r
F P
0 g
s
.37186 .50391 m .36639 .55862 L .33712 .55979 L p .707 .577 .707 r
F P
0 g
s
.33778 .57657 m .33185 .61247 L .30798 .61582 L p .707 .577 .707 r
F P
0 g
s
.40355 .50592 m .39809 .56063 L .36639 .55862 L p .707 .577 .707 r
F P
0 g
s
.46973 .6657 m .46642 .68356 L .44583 .67207 L p .707 .577 .707 r
F P
0 g
s
.44583 .67207 m .44913 .65422 L .46973 .6657 L p .707 .577 .707 r
F P
0 g
s
.30399 .65286 m .30729 .63501 L .33111 .63192 L p .707 .577 .707 r
F P
0 g
s
.45615 .59681 m .45022 .63272 L .42317 .62332 L p .707 .577 .707 r
F P
0 g
s
.42317 .62332 m .4291 .58742 L .45615 .59681 L p .707 .577 .707 r
F P
0 g
s
.33185 .61247 m .33778 .57657 L .36687 .57677 L p .707 .577 .707 r
F P
0 g
s
.33111 .63192 m .32781 .64977 L .30399 .65286 L p .707 .577 .707 r
F P
0 g
s
.4291 .58742 m .42317 .62332 L .39241 .61641 L p .707 .577 .707 r
F P
0 g
s
.39241 .61641 m .39834 .58051 L .4291 .58742 L p .707 .577 .707 r
F P
0 g
s
.36687 .57677 m .36094 .61267 L .33185 .61247 L p .707 .577 .707 r
F P
0 g
s
.36094 .61267 m .36687 .57677 L .39834 .58051 L p .707 .577 .707 r
F P
0 g
s
.44913 .65422 m .44583 .67207 L .41887 .66211 L p .707 .577 .707 r
F P
0 g
s
.41887 .66211 m .42218 .64426 L .44913 .65422 L p .707 .577 .707 r
F P
0 g
s
.39834 .58051 m .39241 .61641 L .36094 .61267 L p .707 .577 .707 r
F P
0 g
s
.32781 .64977 m .33111 .63192 L .36013 .63253 L p .707 .577 .707 r
F P
0 g
s
.36013 .63253 m .35683 .65038 L .32781 .64977 L p .707 .577 .707 r
F P
0 g
s
.42218 .64426 m .41887 .66211 L .38821 .65463 L p .707 .577 .707 r
F P
0 g
s
.38821 .65463 m .39151 .63678 L .42218 .64426 L p .707 .577 .707 r
F P
0 g
s
.35683 .65038 m .36013 .63253 L .39151 .63678 L p .707 .577 .707 r
F P
0 g
s
.39151 .63678 m .38821 .65463 L .35683 .65038 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007eooad008=o
o`00N7oo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH01P00OGoo001dOol40007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001hOol0079oo`800003FUH005YF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Aoo`00L7oo
0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000L7oo001^Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001]Ool006eoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001[Ool006aoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEUYFFUH2001YOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH2001W
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001UOol006]oo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP8006Aoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000069oo`00Jgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00D005YFFUIJEP00065oo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00Ggoo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001Z
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001ZOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<007ooOol0GGoo001ZOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006Yoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF0000Ggoo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUIoo`1OOol006Uoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EWoo05moo`00JGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05mo
o`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05moo`00JGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000H7oo001YOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH0001POol006Uoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0H7oo001Y
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1POol006Qoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo061oo`00J7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
065oo`00J7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00065oo`00J7oo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0HGoo001XOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIoo`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH00`00FUH0001ROol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001SOol006Moo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001V
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001UOol005iooaL000=JEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00FGoo
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol0
05Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001V
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000:Ool?
001=Ool005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP02FUH90014Ool0
05=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20004Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH6000nOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol0059oo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH2000hOol0059oo`03001JEP0000AJEP04001JEUYFFUH;0004FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo00<005YF00000eYF1@0000=J
EP00FUH01EYF00<005YFFUH01@0000=JEP0000000`000UYF1P001UYF00<005YFFUH015YF00D005YF
FUH005YF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008003Aoo`00DWoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF
00AJEQ<0009JEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`06001J
EP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF0`001EYF
00H005YFFUIJEP00FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000aOol0059oo`8000=JEP03001JEUYF00=JEPL00003FUH005YF00MJEP@0
00EJEP03001JEUYF00IJEP04001JEP000003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002mo
o`00DWoo0P000eYF1P000eYF00@005YFFUIJEPT00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001BOol20002FUH200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH20003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH00`00FUH00002FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH4000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002eo
o`00>Goo3P002goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF009JEPT0009oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF
00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH0
1000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool0
035oo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
008000AJEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30003
FUH500000eYF001JEP05FUH60004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0017oo10001UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF10000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@00003
FUH0000000X0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003FUH5000015YF001JEUYF0P0000=oo`0000001@000UYF1`001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH000040003FUH00`00FUIJEP02FUH200000eYF001JEP03FUH=0002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH@00000eYF001JEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP030006
FUH00`00FUH00005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUH000030003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH02000FUIJ
EP00FUH005YF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF009JEP<000AJEP8000IJEP03001JEUYF009J
EP<0009JEP03001JEUYF00=JEP@00003FUH005YF00EJEP03001JEUYF009JEP8000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001oo`0]
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000=JEP03001JEUYF009JEPh00003FUH005YF009JEPD00003FUH005YF00QJ
EP8000IJEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEPH000=JEP03001J
EUYF00EJEP03001JEUYF00@00003FUH0000000<00003FUH005YF00UJEP<000AJEP04001JEUYFFUH3
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJ
EP03001JEUYF009JEP8002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1P0000=JEP00FUH02EYF00@005YFFUH0009JEP03001JEUYF009JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001J
EP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
2EYF00@005YFFUIJEP<000AJEP<000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP8000=JEP07001JEUYFFUH005YF0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH01000FUIJEUYF100015YF0`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF0P00<7oo000[Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0003FUH01000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YF00001`000eYF0P000UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF0P00<7oo000[Ool00`00FUH00004FUH01000FUIJEUYF5P0015YF0P000eYF1@0000=JEP00
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEP00
00@000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP@0035oo`00:goo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH01000
0Woo2`0000AJEP00001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH005YF009JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000bOol002]oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH?0004FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1EYF0`000UYF00@005YFFUIJEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000003FUH60004FUH20004Ool400000eYF000000040006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH0000aOol002]oo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF1@000eYF0`000UYF100000AJEP00000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0
00IJEP03001JEUYF00<000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01@00FUIJEP00FUH00`0015YF00<005YFFUH00eYF0P001goo2`000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF100015YF10001EYF1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEP8000=JEP03001JEUYF00=JEP80009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH30002FUH00`00FUIJEP03FUH01000
FUH000002Woo0`000goo10001eYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF
00<005YFFUH00eYF400000=JEP00FUH01UYF00D005YF001JEP0000EJEP03001JEUYF00D00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00EJEP800005FUH00000FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP030005
FUH01@00FUIJEUYF000027oo1@001Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEP8002moo`00
:goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF0P000eYF00D005YFFUIJ
EP0000IJEPH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP03001JEP0000800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00=J
EP<000=JEP05001JEUYFFUH00008Ool50008Ool300000eYF001JEP05FUH01P00FUIJEP00FUH002mo
o`00:goo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00001000
0eYF0`0000=JEP00FUH01EYF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP8000Moo`D000]o
o`8000IJEP06001JEUYF001JEP00;goo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0P001UYF0P0000=JEP00FUH01EYF
2@000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00=JEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEQ0000Eoo`<000io
o`8000=JEP07001JEUYFFUH005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30002FUH01@00FUH005YF00001UYF
00<005YFFUH00UYF4P000eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0`000eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P004Woo0P0000=JEP00FUH0
0UYF0P00<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000015YF001JEP001EYF00<005YFFUH00eYF1@002UYF00<0
05YFFUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P004Goo0P000eYF0P00
<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH01000FUIJEUYF0`0000=JEP00FUH015YF00<005YFFUH00eYF1@002UYF00<005YFFUH0
1UYF1@002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF500000AJEP00FUH0
031oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YF000000=JEP03001JEUYF00EJEP@000=JEP03001JEUYF00AJEP@000YJEP03001JEUYF
00QJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo02moo`00:Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1eYF00<005YFFUH010002EYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP00009JEP04001JEUYFFUH>
0006FUH00`00FUIJEP07FUH00`00FUH000040006FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`001eYF00<005YFFUH015YF1@0015YF00<005YFFUH025YF00<005YFFUH01EYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF000000=J
EP@00003FUH005YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00=JEP03001JEUYF009JEP80035oo`00:Woo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP07FUH00`00FUIJEP05000:FUH0
0`00FUIJEP050002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF1@001UYF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF0P00<Goo000ZOol20003FUH50007Ool70002FUH70006FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00
00=JEP0000001EYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<Goo000ZOol00eYF001JEP05000@Ool=0002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30007
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00<005YFFUH00UYF
0P000UYF0P00<Woo000YOol01000FUH000000UYF00@005YFFUH001Qoo`P000IJEP03001JEUYF00=J
EP03001JEP00009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0006FUH00`00FUIJEP03FUH300000eYF001JEP07FUH01000FUIJEUYF0`000UYF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP04001JEP00000bOol002Uoo`<000=JEP04001JEUYFFUH2000NOol20003
FUH00`00FUIJEP04FUH00`00FUH00006FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00000015YF00<005YFFUH00eYF00<005YFFUH00`001UYF00@005YFFUIJEPD00003FUH005YF
00AJEP<00003FUH005YF00EJEP<003=oo`00:Goo00<005YF00000eYF00<005YFFUH00UYF1`003Goo
0`002Woo0P0000=JEP00FUH01EYF00<005YF00001EYF00<005YFFUH00eYF10000UYF00<005YFFUH0
1EYF00@005YFFUIJEPD000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF1P00
25YF0`001UYF00<005YF0000<goo000YOol00`00FUIJEP03FUH50003FUH01000FUIJEUYF2@000goo
1@002goo0P001UYF00<005YF00001EYF00<005YFFUH01eYF3P002UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF10001UYF00<005YFFUH00UYF0P000goo
300025YF00<005YFFUH00P000eYF00D005YFFUIJEP00039oo`00:Woo00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF20003Goo0P000eYF0P001eYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00P001EYF00L005YFFUIJEP00FUH0000:OolA
00001Goo000005YF00000eYF00<007ooOol0<7oo000ZOol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH00eYF30001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF0000009JEP03001JEUYF00=JEP<0009JEP07001JEUYFFUH005YF00007Woo0P00
0eYF0P00<Goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH40008Ool400000eYF001JEP05FUH00`00FUIJEP03FUH:0002FUH00`00FUIJEP07FUH9
0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001UYF00@0
05YF000000AJEP80025oo`05001JEP00FUH0000aOol002Yoo`8000=JEP04001JEUYFFUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000070003FUH00`00FUH00005FUH700000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01`00FUH005YF001JEP0000IJEP04001JEUYFFUH20002FUH2000ROol200000eYF
001oo`0`Ool002Uoo`8000=JEPD00003FUH005YF00AJEPT000AJEP03001JEUYF00MJEP04001JEUYF
FUH30006FUH00`00FUH00003FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH50009FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH00`00FUIJ
EP04FUH4000SOol00`00FUH0000aOol002Uoo`800004FUH000000005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH70006FUH00`00FUIJEP04FUH20004FUH200000eYF001JEP0200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH40005FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP04
000NOol3000bOol002Uoo`<000=oo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP@0009JEP03001JEUYF00EJEP<0009JEP800003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@00003FUH005YF00MJEP03
001JEUYF00=JEP800003FUH005YF00IJEP<000IJEP03001JEUYF00AJEPL001Eoo`800003FUH00000
039oo`00:7oo0`001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF
00<005YFFUH01P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF10001eYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00@005YF000000=J
EP03001JEUYF00MJEP03001JEUYF009JEPP000Qoo`D000=JEP80039oo`00:7oo10001goo0`001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP@000AJEP03
001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04
001JEUYFFUH20005FUH00`00FUIJEP03FUH50007FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<0
05YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000cOol002Qoo`05001JEP00FUH00009
Ool400000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH20003Ool20004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<goo000XOol2
0003FUH00`00Oomoo`0:Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20006FUH20005FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUH00005Ool300000eYF001JEP05FUH00`00FUIJ
EP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00=7oo
000YOol01000FUIJEUYF0`003Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0P000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YF000027oo0P001UYF00H005YFFUH005YF
0002Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000=Woo000YOol01@00FUIJ
EUYF00000UYF00<007ooOol03goo2@000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
000000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH0000:Ool20003FUH01`00FUIJEUYF
001JEP0000Uoo`P000AJEP04001JEUYFFUH5000hOol002Yoo`03001JEP0000AJEP8001AooaL00003
FUH005YF00aJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH2000015YF001JEP0037oo0P0000=JEP00FUH00UYF0P004Woo2000
?Goo000[Ool20006FUH2000BOol5000BOol2000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000?Ool20003FUH2001G
Ool002aoo`03001JEUYF00AJEP03001JEP0000<000ioo`D001=oo`8000aJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00aoo`H00004FUH005YF001GOol002eoo`8000AJEP03001JEUYF00=JEPD000Yoo`<001Eoo`<001EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF00=JEPl000=J
EP03001JEUYF00800003FUH007oo05Ioo`00;goo00@005YFFUH000QJEP03001JEUYF00@001ioo`@0
01AJEP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEP000002FUH01000FUH000000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001GOol0031o
o`<000QJEP03001JEUYF00AJEPD001Moo`@0009oo`80019JEP03001JEUYF00UJEP03001JEUYF00UJ
EP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF
00<005YFFUH00UYF0P00F7oo000bOol20006FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002
FUH20004Ool2000LFUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01P00FUIJEP00FUH000MJEP8000=JEP03001JEUYF009JEP8005Qoo`00=7oo10000UYF00<005YF
FUH01eYF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0006Ool3000IFUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP06FUH3
00000eYF001JEP03FUH2001HOol003Qoo`@000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF008000Yoo`<002=JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH00000008000MJEP03001JEUYF008000=JEP8005Uoo`00?7oo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000ioo`@001iJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH20004FUH00`00FUIJEP03FUH2
00000eYF0000001IOol003moo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000COol4000JFUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`000UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0`00FWoo0012Ool60004FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@006Goo10005UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001P0025YF0`001UYF
00<005YF0000FWoo0018Ool@000ROol6000@FUH00`00FUIJEP09FUH00`00FUIJEP05FUH;0008FUH0
0`00FUIJEP020003FUH01@00FUIJEUYF0000FGoo0020Ool:0006FUH00`00FUIJEP09FUH00`00FUIJ
EP050005OolB00001Goo000005YF00000eYF00<007ooOol0Egoo002:OolE000;Ool3000AOol20003
FUH2001HOol008eoo`8000IJEP04001JEP00000WOol01@00FUH005YF0000F7oo002>Ool00`00FUIJ
EP04FUH01000FUIJEUYF0P009Woo0P0000=JEP00Ool0Egoo002?Ool20003FUH00`00FUIJEP04FUH4
000SOol00`00FUH0001HOol0095oo`800003FUH005YF00IJEP03001JEUYF00@001ioo`<005Uoo`00
Tgoo0`001UYF00<005YFFUH015YF1@005goo0P0000=JEP000000FGoo002FOol20003FUH00`00FUIJ
EP07FUH00`00FUIJEP04000>Ool50003FUH2001IOol009Qoo`800003FUH005YF00QJEP03001JEUYF
00AJEPh000=JEP04001JEUYFFUH2001JOol009Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2001JOol009ioo`@0009JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2001KOol00:9oo`D000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001MOol00:Moo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001OOol0
0:]oo`h006Aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60191 .74543 m .59644 .68956 L .56542 .69078 L p .707 .577 .707 r
F P
0 g
s
.59644 .68956 m .60191 .74543 L .63361 .74184 L p .707 .577 .707 r
F P
0 g
s
.63361 .74184 m .62814 .68596 L .59644 .68956 L p .707 .577 .707 r
F P
0 g
s
.62814 .68596 m .63361 .74184 L .66288 .73623 L p .707 .577 .707 r
F P
0 g
s
.66288 .73623 m .65741 .68035 L .62814 .68596 L p .707 .577 .707 r
F P
0 g
s
.57089 .74665 m .56542 .69078 L .53812 .6895 L p .707 .577 .707 r
F P
0 g
s
.56542 .69078 m .57089 .74665 L .60191 .74543 L p .707 .577 .707 r
F P
0 g
s
.65741 .68035 m .66288 .73623 L .68686 .72915 L p .707 .577 .707 r
F P
0 g
s
.68686 .72915 m .6814 .67327 L .65741 .68035 L p .707 .577 .707 r
F P
0 g
s
.60759 .80244 m .60166 .76526 L .57089 .76845 L p .707 .577 .707 r
F P
0 g
s
.60166 .76526 m .60759 .80244 L .63906 .79707 L p .707 .577 .707 r
F P
0 g
s
.63906 .79707 m .63313 .75989 L .60166 .76526 L p .707 .577 .707 r
F P
0 g
s
.63313 .75989 m .63906 .79707 L .66815 .79004 L p .707 .577 .707 r
F P
0 g
s
.66815 .79004 m .66222 .75286 L .63313 .75989 L p .707 .577 .707 r
F P
0 g
s
.53812 .6895 m .54359 .74538 L .57089 .74665 L p .707 .577 .707 r
F P
0 g
s
.54359 .74538 m .53812 .6895 L .5172 .68587 L p .707 .577 .707 r
F P
0 g
s
.57089 .76845 m .57682 .80563 L .60759 .80244 L p .707 .577 .707 r
F P
0 g
s
.57682 .80563 m .57089 .76845 L .54384 .76916 L p .707 .577 .707 r
F P
0 g
s
.66222 .75286 m .66815 .79004 L .69202 .78205 L p .707 .577 .707 r
F P
0 g
s
.69202 .78205 m .68609 .74487 L .66222 .75286 L p .707 .577 .707 r
F P
0 g
s
.61179 .84156 m .60849 .823 L .57782 .82678 L p .707 .577 .707 r
F P
0 g
s
.60849 .823 m .61179 .84156 L .64317 .83566 L p .707 .577 .707 r
F P
0 g
s
.64317 .83566 m .63986 .81709 L .60849 .823 L p .707 .577 .707 r
F P
0 g
s
.6814 .67327 m .68686 .72915 L .70321 .72128 L p .707 .577 .707 r
F P
0 g
s
.70321 .72128 m .69774 .6654 L .6814 .67327 L p .707 .577 .707 r
F P
0 g
s
.63986 .81709 m .64317 .83566 L .67219 .82821 L p .707 .577 .707 r
F P
0 g
s
.67219 .82821 m .66888 .80965 L .63986 .81709 L p .707 .577 .707 r
F P
0 g
s
.54384 .76916 m .54977 .80633 L .57682 .80563 L p .707 .577 .707 r
F P
0 g
s
.57782 .82678 m .58112 .84534 L .61179 .84156 L p .707 .577 .707 r
F P
0 g
s
.5172 .68587 m .52267 .74174 L .54359 .74538 L p .707 .577 .707 r
F P
0 g
s
.58112 .84534 m .57782 .82678 L .55087 .82807 L p .707 .577 .707 r
F P
0 g
s
.54977 .80633 m .54384 .76916 L .52316 .7673 L p .707 .577 .707 r
F P
0 g
s
.55087 .82807 m .55417 .84663 L .58112 .84534 L p .707 .577 .707 r
F P
0 g
s
.66888 .80965 m .67219 .82821 L .69601 .81995 L p .707 .577 .707 r
F P
0 g
s
.69601 .81995 m .6927 .80139 L .66888 .80965 L p .707 .577 .707 r
F P
0 g
s
.52267 .74174 m .5172 .68587 L .50472 .68022 L p .707 .577 .707 r
F P
0 g
s
.68609 .74487 m .69202 .78205 L .70832 .77388 L p .707 .577 .707 r
F P
0 g
s
.70832 .77388 m .70239 .7367 L .68609 .74487 L p .707 .577 .707 r
F P
0 g
s
.52316 .7673 m .52908 .80447 L .54977 .80633 L p .707 .577 .707 r
F P
0 g
s
.55417 .84663 m .55087 .82807 L .53027 .82674 L p .707 .577 .707 r
F P
0 g
s
.69774 .6654 m .70321 .72128 L .71032 .71341 L p .707 .577 .707 r
F P
0 g
s
.71032 .71341 m .70485 .65753 L .69774 .6654 L p .707 .577 .707 r
F P
0 g
s
.53027 .82674 m .53357 .8453 L .55417 .84663 L p .707 .577 .707 r
F P
0 g
s
.50472 .68022 m .51019 .73609 L .52267 .74174 L p .707 .577 .707 r
F P
0 g
s
.6927 .80139 m .69601 .81995 L .7123 .81168 L p .707 .577 .707 r
F P
0 g
s
.7123 .81168 m .70899 .79312 L .6927 .80139 L p .707 .577 .707 r
F P
0 g
s
.52908 .80447 m .52316 .7673 L .51085 .76306 L p .707 .577 .707 r
F P
0 g
s
.51085 .76306 m .51678 .80024 L .52908 .80447 L p .707 .577 .707 r
F P
0 g
s
.51019 .73609 m .50472 .68022 L .50189 .67311 L p .707 .577 .707 r
F P
0 g
s
.70239 .7367 m .70832 .77388 L .71547 .76632 L p .707 .577 .707 r
F P
0 g
s
.71547 .76632 m .70954 .72914 L .70239 .7367 L p .707 .577 .707 r
F P
0 g
s
.53357 .8453 m .53027 .82674 L .51804 .82293 L p .707 .577 .707 r
F P
0 g
s
.51804 .82293 m .52134 .84149 L .53357 .8453 L p .707 .577 .707 r
F P
0 g
s
.70485 .65753 m .71032 .71341 L .70749 .70631 L p .707 .577 .707 r
F P
0 g
s
.70749 .70631 m .70202 .65043 L .70485 .65753 L p .707 .577 .707 r
F P
0 g
s
.50189 .67311 m .50736 .72899 L .51019 .73609 L p .707 .577 .707 r
F P
0 g
s
.70899 .79312 m .7123 .81168 L .71946 .80422 L p .707 .577 .707 r
F P
0 g
s
.71946 .80422 m .71616 .78565 L .70899 .79312 L p .707 .577 .707 r
F P
0 g
s
.51678 .80024 m .51085 .76306 L .50814 .75686 L p .707 .577 .707 r
F P
0 g
s
.50814 .75686 m .51407 .79403 L .51678 .80024 L p .707 .577 .707 r
F P
0 g
s
.70954 .72914 m .71547 .76632 L .71276 .76012 L p .707 .577 .707 r
F P
0 g
s
.71276 .76012 m .70683 .72294 L .70954 .72914 L p .707 .577 .707 r
F P
0 g
s
.50736 .72899 m .50189 .67311 L .509 .66524 L p .707 .577 .707 r
F P
0 g
s
.52134 .84149 m .51804 .82293 L .51537 .817 L p .707 .577 .707 r
F P
0 g
s
.509 .66524 m .51447 .72112 L .50736 .72899 L p .707 .577 .707 r
F P
0 g
s
.51407 .79403 m .50814 .75686 L .51529 .7493 L p .707 .577 .707 r
F P
0 g
s
.51537 .817 m .51868 .83556 L .52134 .84149 L p .707 .577 .707 r
F P
0 g
s
.51868 .83556 m .51537 .817 L .52254 .80953 L p .707 .577 .707 r
F P
0 g
s
.51621 .81895 m .46711 .31438 L .42331 .31608 L p .707 .577 .707 r
F P
0 g
s
.51529 .7493 m .52122 .78648 L .51407 .79403 L p .707 .577 .707 r
F P
0 g
s
.51447 .72112 m .509 .66524 L .52535 .65738 L p .707 .577 .707 r
F P
0 g
s
.52254 .80953 m .52584 .82809 L .51868 .83556 L p .707 .577 .707 r
F P
0 g
s
.52535 .65738 m .53081 .71325 L .51447 .72112 L p .707 .577 .707 r
F P
0 g
s
.52122 .78648 m .51529 .7493 L .5316 .74113 L p .707 .577 .707 r
F P
0 g
s
.53081 .71325 m .52535 .65738 L .54933 .65029 L p .707 .577 .707 r
F P
0 g
s
.5316 .74113 m .53753 .7783 L .52122 .78648 L p .707 .577 .707 r
F P
0 g
s
.52584 .82809 m .52254 .80953 L .53883 .80126 L p .707 .577 .707 r
F P
0 g
s
.53883 .80126 m .54213 .81983 L .52584 .82809 L p .707 .577 .707 r
F P
0 g
s
.54933 .65029 m .5548 .70617 L .53081 .71325 L p .707 .577 .707 r
F P
0 g
s
.53753 .7783 m .5316 .74113 L .55546 .73313 L p .707 .577 .707 r
F P
0 g
s
.55546 .73313 m .56139 .77031 L .53753 .7783 L p .707 .577 .707 r
F P
0 g
s
.54213 .81983 m .53883 .80126 L .56265 .793 L p .707 .577 .707 r
F P
0 g
s
.56265 .793 m .56595 .81157 L .54213 .81983 L p .707 .577 .707 r
F P
0 g
s
.46711 .31438 m .51621 .81895 L .56096 .8139 L p .707 .577 .707 r
F P
0 g
s
.56096 .8139 m .51186 .30933 L .46711 .31438 L p .707 .577 .707 r
F P
0 g
s
.5548 .70617 m .54933 .65029 L .5786 .64468 L p .707 .577 .707 r
F P
0 g
s
.5786 .64468 m .58407 .70056 L .5548 .70617 L p .707 .577 .707 r
F P
0 g
s
.56139 .77031 m .55546 .73313 L .58455 .72611 L p .707 .577 .707 r
F P
0 g
s
.58455 .72611 m .59048 .76329 L .56139 .77031 L p .707 .577 .707 r
F P
0 g
s
.59048 .76329 m .58455 .72611 L .61602 .72074 L p .707 .577 .707 r
F P
0 g
s
.61602 .72074 m .62195 .75791 L .59048 .76329 L p .707 .577 .707 r
F P
0 g
s
.56595 .81157 m .56265 .793 L .59167 .78556 L p .707 .577 .707 r
F P
0 g
s
.59167 .78556 m .59497 .80412 L .56595 .81157 L p .707 .577 .707 r
F P
0 g
s
.59497 .80412 m .59167 .78556 L .62305 .77965 L p .707 .577 .707 r
F P
0 g
s
.62305 .77965 m .62635 .79821 L .59497 .80412 L p .707 .577 .707 r
F P
0 g
s
.51186 .30933 m .56096 .8139 L .60229 .80599 L p .707 .577 .707 r
F P
0 g
s
.58407 .70056 m .5786 .64468 L .6103 .64109 L p .707 .577 .707 r
F P
0 g
s
.6103 .64109 m .61577 .69696 L .58407 .70056 L p .707 .577 .707 r
F P
0 g
s
.60229 .80599 m .55319 .30143 L .51186 .30933 L p .707 .577 .707 r
F P
0 g
s
.71616 .78565 m .71946 .80422 L .7168 .79829 L p .707 .577 .707 r
F P
0 g
s
.7168 .79829 m .71349 .77972 L .71616 .78565 L p .707 .577 .707 r
F P
0 g
s
.70202 .65043 m .70749 .70631 L .69501 .70066 L p .707 .577 .707 r
F P
0 g
s
.69501 .70066 m .68954 .64478 L .70202 .65043 L p .707 .577 .707 r
F P
0 g
s
.47242 .82065 m .42331 .31608 L .38476 .31426 L p .707 .577 .707 r
F P
0 g
s
.42331 .31608 m .47242 .82065 L .51621 .81895 L p .707 .577 .707 r
F P
0 g
s
.64132 .63987 m .64678 .69574 L .61577 .69696 L p .707 .577 .707 r
F P
0 g
s
.61577 .69696 m .6103 .64109 L .64132 .63987 L p .707 .577 .707 r
F P
0 g
s
.64679 .71754 m .65272 .75472 L .62195 .75791 L p .707 .577 .707 r
F P
0 g
s
.62195 .75791 m .61602 .72074 L .64679 .71754 L p .707 .577 .707 r
F P
0 g
s
.65371 .77587 m .65702 .79443 L .62635 .79821 L p .707 .577 .707 r
F P
0 g
s
.62635 .79821 m .62305 .77965 L .65371 .77587 L p .707 .577 .707 r
F P
0 g
s
.55319 .30143 m .60229 .80599 L .63615 .796 L p .707 .577 .707 r
F P
0 g
s
.63615 .796 m .58705 .29144 L .55319 .30143 L p .707 .577 .707 r
F P
0 g
s
.2589 .71148 m .25343 .65561 L .22242 .65683 L p .707 .577 .707 r
F P
0 g
s
.25343 .65561 m .2589 .71148 L .2906 .70789 L p .707 .577 .707 r
F P
0 g
s
.2906 .70789 m .28513 .65201 L .25343 .65561 L p .707 .577 .707 r
F P
0 g
s
.28513 .65201 m .2906 .70789 L .31987 .70228 L p .707 .577 .707 r
F P
0 g
s
.31987 .70228 m .3144 .6464 L .28513 .65201 L p .707 .577 .707 r
F P
0 g
s
.70683 .72294 m .71276 .76012 L .70046 .75588 L p .707 .577 .707 r
F P
0 g
s
.70046 .75588 m .69453 .7187 L .70683 .72294 L p .707 .577 .707 r
F P
0 g
s
.22788 .7127 m .22242 .65683 L .19511 .65555 L p .707 .577 .707 r
F P
0 g
s
.22242 .65683 m .22788 .7127 L .2589 .71148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.43386 .81883 m .38476 .31426 L .35523 .3091 L p .707 .577 .707 r
F P
0 g
s
.38476 .31426 m .43386 .81883 L .47242 .82065 L p .707 .577 .707 r
F P
0 g
s
.3144 .6464 m .31987 .70228 L .34385 .6952 L p .707 .577 .707 r
F P
0 g
s
.34385 .6952 m .33839 .63932 L .3144 .6464 L p .707 .577 .707 r
F P
0 g
s
.68954 .64478 m .69501 .70066 L .67409 .69702 L p .707 .577 .707 r
F P
0 g
s
.67409 .69702 m .66862 .64114 L .68954 .64478 L p .707 .577 .707 r
F P
0 g
s
.71349 .77972 m .7168 .79829 L .70457 .79447 L p .707 .577 .707 r
F P
0 g
s
.70457 .79447 m .70126 .77591 L .71349 .77972 L p .707 .577 .707 r
F P
0 g
s
.26458 .77231 m .25865 .73513 L .22789 .73832 L p .707 .577 .707 r
F P
0 g
s
.25865 .73513 m .26458 .77231 L .29605 .76694 L p .707 .577 .707 r
F P
0 g
s
.29605 .76694 m .29012 .72976 L .25865 .73513 L p .707 .577 .707 r
F P
0 g
s
.19511 .65555 m .20058 .71143 L .22788 .7127 L p .707 .577 .707 r
F P
0 g
s
.29012 .72976 m .29605 .76694 L .32514 .75991 L p .707 .577 .707 r
F P
0 g
s
.32514 .75991 m .31921 .72273 L .29012 .72976 L p .707 .577 .707 r
F P
0 g
s
.20058 .71143 m .19511 .65555 L .17419 .65192 L p .707 .577 .707 r
F P
0 g
s
.67384 .71684 m .67977 .75402 L .65272 .75472 L p .707 .577 .707 r
F P
0 g
s
.65272 .75472 m .64679 .71754 L .67384 .71684 L p .707 .577 .707 r
F P
0 g
s
.65702 .79443 m .65371 .77587 L .68066 .77458 L p .707 .577 .707 r
F P
0 g
s
.58705 .29144 m .63615 .796 L .65922 .78491 L p .707 .577 .707 r
F P
0 g
s
.66862 .64114 m .67409 .69702 L .64678 .69574 L p .707 .577 .707 r
F P
0 g
s
.64678 .69574 m .64132 .63987 L .66862 .64114 L p .707 .577 .707 r
F P
0 g
s
.65922 .78491 m .61012 .28034 L .58705 .29144 L p .707 .577 .707 r
F P
0 g
s
.22789 .73832 m .23382 .7755 L .26458 .77231 L p .707 .577 .707 r
F P
0 g
s
.23382 .7755 m .22789 .73832 L .20083 .73903 L p .707 .577 .707 r
F P
0 g
s
.31921 .72273 m .32514 .75991 L .34901 .75192 L p .707 .577 .707 r
F P
0 g
s
.34901 .75192 m .34308 .71474 L .31921 .72273 L p .707 .577 .707 r
F P
0 g
s
.33839 .63932 m .34385 .6952 L .3602 .68733 L p .707 .577 .707 r
F P
0 g
s
.3602 .68733 m .35473 .63145 L .33839 .63932 L p .707 .577 .707 r
F P
0 g
s
.26878 .8168 m .26548 .79823 L .23481 .80202 L p .707 .577 .707 r
F P
0 g
s
.26548 .79823 m .26878 .8168 L .30016 .81089 L p .707 .577 .707 r
F P
0 g
s
.30016 .81089 m .29686 .79233 L .26548 .79823 L p .707 .577 .707 r
F P
0 g
s
.69453 .7187 m .70046 .75588 L .67977 .75402 L p .707 .577 .707 r
F P
0 g
s
.67977 .75402 m .67384 .71684 L .69453 .7187 L p .707 .577 .707 r
F P
0 g
s
.20083 .73903 m .20676 .7762 L .23382 .7755 L p .707 .577 .707 r
F P
0 g
s
.29686 .79233 m .30016 .81089 L .32918 .80345 L p .707 .577 .707 r
F P
0 g
s
.32918 .80345 m .32587 .78488 L .29686 .79233 L p .707 .577 .707 r
F P
0 g
s
.17419 .65192 m .17966 .70779 L .20058 .71143 L p .707 .577 .707 r
F P
0 g
s
.23481 .80202 m .23811 .82058 L .26878 .8168 L p .707 .577 .707 r
F P
0 g
s
.23811 .82058 m .23481 .80202 L .20786 .80331 L p .707 .577 .707 r
F P
0 g
s
.20676 .7762 m .20083 .73903 L .18015 .73717 L p .707 .577 .707 r
F P
0 g
s
.40433 .81367 m .35523 .3091 L .33761 .30111 L p .707 .577 .707 r
F P
0 g
s
.35523 .3091 m .40433 .81367 L .43386 .81883 L p .707 .577 .707 r
F P
0 g
s
.20786 .80331 m .21116 .82187 L .23811 .82058 L p .707 .577 .707 r
F P
0 g
s
.32587 .78488 m .32918 .80345 L .353 .79518 L p .707 .577 .707 r
F P
0 g
s
.353 .79518 m .3497 .77662 L .32587 .78488 L p .707 .577 .707 r
F P
0 g
s
.17966 .70779 m .17419 .65192 L .16171 .64627 L p .707 .577 .707 r
F P
0 g
s
.70126 .77591 m .70457 .79447 L .68397 .79314 L p .707 .577 .707 r
F P
0 g
s
.68397 .79314 m .68066 .77458 L .70126 .77591 L p .707 .577 .707 r
F P
0 g
s
.34308 .71474 m .34901 .75192 L .36531 .74375 L p .707 .577 .707 r
F P
0 g
s
.36531 .74375 m .35938 .70657 L .34308 .71474 L p .707 .577 .707 r
F P
0 g
s
.18015 .73717 m .18608 .77434 L .20676 .7762 L p .707 .577 .707 r
F P
0 g
s
.35473 .63145 m .3602 .68733 L .36731 .67946 L p .707 .577 .707 r
F P
0 g
s
.36731 .67946 m .36184 .62358 L .35473 .63145 L p .707 .577 .707 r
F P
0 g
s
.21116 .82187 m .20786 .80331 L .18726 .80198 L p .707 .577 .707 r
F P
0 g
s
.16171 .64627 m .16718 .70214 L .17966 .70779 L p .707 .577 .707 r
F P
0 g
s
.61012 .28034 m .65922 .78491 L .66926 .77379 L p .707 .577 .707 r
F P
0 g
s
.66926 .77379 m .62015 .26923 L .61012 .28034 L p .707 .577 .707 r
F P
0 g
s
.18726 .80198 m .19056 .82054 L .21116 .82187 L p .707 .577 .707 r
F P
0 g
s
.3497 .77662 m .353 .79518 L .36929 .78692 L p .707 .577 .707 r
F P
0 g
s
.36929 .78692 m .36598 .76835 L .3497 .77662 L p .707 .577 .707 r
F P
0 g
s
.18608 .77434 m .18015 .73717 L .16784 .73293 L p .707 .577 .707 r
F P
0 g
s
.68066 .77458 m .68397 .79314 L .65702 .79443 L p .707 .577 .707 r
F P
0 g
s
.16718 .70214 m .16171 .64627 L .15888 .63916 L p .707 .577 .707 r
F P
0 g
s
.16784 .73293 m .17377 .77011 L .18608 .77434 L p .707 .577 .707 r
F P
0 g
s
.35938 .70657 m .36531 .74375 L .37246 .73619 L p .707 .577 .707 r
F P
0 g
s
.37246 .73619 m .36653 .69901 L .35938 .70657 L p .707 .577 .707 r
F P
0 g
s
.19056 .82054 m .18726 .80198 L .17503 .79816 L p .707 .577 .707 r
F P
0 g
s
.38671 .80568 m .33761 .30111 L .33361 .29106 L p .707 .577 .707 r
F P
0 g
s
.33761 .30111 m .38671 .80568 L .40433 .81367 L p .707 .577 .707 r
F P
0 g
s
.17503 .79816 m .17833 .81672 L .19056 .82054 L p .707 .577 .707 r
F P
0 g
s
.36184 .62358 m .36731 .67946 L .36448 .67236 L p .707 .577 .707 r
F P
0 g
s
.36448 .67236 m .35901 .61648 L .36184 .62358 L p .707 .577 .707 r
F P
0 g
s
.15888 .63916 m .16435 .69504 L .16718 .70214 L p .707 .577 .707 r
F P
0 g
s
.36598 .76835 m .36929 .78692 L .37645 .77945 L p .707 .577 .707 r
F P
0 g
s
.37645 .77945 m .37315 .76089 L .36598 .76835 L p .707 .577 .707 r
F P
0 g
s
.17377 .77011 m .16784 .73293 L .16514 .72673 L p .707 .577 .707 r
F P
0 g
s
.62015 .26923 m .66926 .77379 L .66527 .76375 L p .707 .577 .707 r
F P
0 g
s
.66527 .76375 m .63695 .47281 L p .62015 .26923 L .707 .577 .707 r
F P
0 g
s
.61616 .25918 m .66527 .76375 L .64764 .75575 L p .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .66036 .67526 L .65433 .67318 L p .707 .577 .707 r
F P
0 g
s
.65433 .67318 m .64806 .67102 L p .65563 .68823 L .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .65433 .67318 L .65563 .68823 L .707 .577 .707 r
F
.63695 .47281 m .61616 .25918 L .61906 .26647 L p F P
0 g
s
.61906 .26647 m .62015 .26923 L p .63695 .47281 L .707 .577 .707 r
F P
0 g
s
.16514 .72673 m .17106 .7639 L .17377 .77011 L p .707 .577 .707 r
F P
0 g
s
.16435 .69504 m .15888 .63916 L .16599 .63129 L p .707 .577 .707 r
F P
0 g
s
.36653 .69901 m .37246 .73619 L .36975 .72999 L p .707 .577 .707 r
F P
0 g
s
.36975 .72999 m .36382 .69281 L .36653 .69901 L p .707 .577 .707 r
F P
0 g
s
.17833 .81672 m .17503 .79816 L .17237 .79223 L p .707 .577 .707 r
F P
0 g
s
.17237 .79223 m .17567 .81079 L .17833 .81672 L p .707 .577 .707 r
F P
0 g
s
.35901 .61648 m .36448 .67236 L .352 .66671 L p .707 .577 .707 r
F P
0 g
s
.352 .66671 m .34653 .61083 L .35901 .61648 L p .707 .577 .707 r
F P
0 g
s
.16599 .63129 m .17146 .68717 L .16435 .69504 L p .707 .577 .707 r
F P
0 g
s
.37315 .76089 m .37645 .77945 L .37379 .77352 L p .707 .577 .707 r
F P
0 g
s
.37379 .77352 m .37048 .75496 L .37315 .76089 L p .707 .577 .707 r
F P
0 g
s
.17106 .7639 m .16514 .72673 L .17228 .71917 L p .707 .577 .707 r
F P
0 g
s
.33361 .29106 m .38272 .79563 L .38671 .80568 L p .707 .577 .707 r
F P
0 g
s
.38272 .79563 m .33361 .29106 L .34365 .27995 L p .707 .577 .707 r
F P
0 g
s
.17228 .71917 m .17821 .75635 L .17106 .7639 L p .707 .577 .707 r
F P
0 g
s
.17146 .68717 m .16599 .63129 L .18234 .62343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36382 .69281 m .36975 .72999 L .35745 .72575 L p .707 .577 .707 r
F P
0 g
s
.35745 .72575 m .35152 .68857 L .36382 .69281 L p .707 .577 .707 r
F P
0 g
s
.17567 .81079 m .17237 .79223 L .17953 .78477 L p .707 .577 .707 r
F P
0 g
s
.17953 .78477 m .18283 .80333 L .17567 .81079 L p .707 .577 .707 r
F P
0 g
s
.64764 .75575 m .59854 .25119 L .61616 .25918 L p .707 .577 .707 r
F P
0 g
s
.34653 .61083 m .352 .66671 L .33108 .66307 L p .707 .577 .707 r
F P
0 g
s
.33108 .66307 m .32561 .60719 L .34653 .61083 L p .707 .577 .707 r
F P
0 g
s
.18234 .62343 m .1878 .6793 L .17146 .68717 L p .707 .577 .707 r
F P
0 g
s
.37048 .75496 m .37379 .77352 L .36156 .76971 L p .707 .577 .707 r
F P
0 g
s
.36156 .76971 m .35825 .75114 L .37048 .75496 L p .707 .577 .707 r
F P
0 g
s
.17821 .75635 m .17228 .71917 L .18859 .711 L p .707 .577 .707 r
F P
0 g
s
.1878 .6793 m .18234 .62343 L .20632 .61634 L p .707 .577 .707 r
F P
0 g
s
.18859 .711 m .19452 .74817 L .17821 .75635 L p .707 .577 .707 r
F P
0 g
s
.35152 .68857 m .35745 .72575 L .33676 .72389 L p .707 .577 .707 r
F P
0 g
s
.33676 .72389 m .33083 .68671 L .35152 .68857 L p .707 .577 .707 r
F P
0 g
s
.39275 .78452 m .34365 .27995 L .36672 .26885 L p .707 .577 .707 r
F P
0 g
s
.34365 .27995 m .39275 .78452 L .38272 .79563 L p .707 .577 .707 r
F P
0 g
s
.32561 .60719 m .33108 .66307 L .30378 .66179 L p .707 .577 .707 r
F P
0 g
s
.30378 .66179 m .29831 .60592 L .32561 .60719 L p .707 .577 .707 r
F P
0 g
s
.18283 .80333 m .17953 .78477 L .19582 .7765 L p .707 .577 .707 r
F P
0 g
s
.20632 .61634 m .21179 .67222 L .1878 .6793 L p .707 .577 .707 r
F P
0 g
s
.19582 .7765 m .19912 .79506 L .18283 .80333 L p .707 .577 .707 r
F P
0 g
s
.35825 .75114 m .36156 .76971 L .34096 .76838 L p .707 .577 .707 r
F P
0 g
s
.34096 .76838 m .33765 .74982 L .35825 .75114 L p .707 .577 .707 r
F P
0 g
s
.21179 .67222 m .20632 .61634 L .23559 .61073 L p .707 .577 .707 r
F P
0 g
s
.19452 .74817 m .18859 .711 L .21245 .703 L p .707 .577 .707 r
F P
0 g
s
.59854 .25119 m .64764 .75575 L .61811 .75059 L p .707 .577 .707 r
F P
0 g
s
.61811 .75059 m .56901 .24603 L .59854 .25119 L p .707 .577 .707 r
F P
0 g
s
.29831 .60592 m .30378 .66179 L .27276 .66301 L p .707 .577 .707 r
F P
0 g
s
.27276 .66301 m .26729 .60714 L .29831 .60592 L p .707 .577 .707 r
F P
0 g
s
.33083 .68671 m .33676 .72389 L .30971 .72459 L p .707 .577 .707 r
F P
0 g
s
.30971 .72459 m .30378 .68741 L .33083 .68671 L p .707 .577 .707 r
F P
0 g
s
.21245 .703 m .21838 .74018 L .19452 .74817 L p .707 .577 .707 r
F P
0 g
s
.24106 .66661 m .23559 .61073 L .26729 .60714 L p .707 .577 .707 r
F P
0 g
s
.23559 .61073 m .24106 .66661 L .21179 .67222 L p .707 .577 .707 r
F P
0 g
s
.73912 .6534 m .73365 .59752 L .70263 .59874 L p .707 .577 .707 r
F P
0 g
s
.73365 .59752 m .73912 .6534 L .77081 .6498 L p .707 .577 .707 r
F P
0 g
s
.77081 .6498 m .76535 .59393 L .73365 .59752 L p .707 .577 .707 r
F P
0 g
s
.26729 .60714 m .27276 .66301 L .24106 .66661 L p .707 .577 .707 r
F P
0 g
s
.76535 .59393 m .77081 .6498 L .80009 .64419 L p .707 .577 .707 r
F P
0 g
s
.80009 .64419 m .79462 .58831 L .76535 .59393 L p .707 .577 .707 r
F P
0 g
s
.19912 .79506 m .19582 .7765 L .21964 .76824 L p .707 .577 .707 r
F P
0 g
s
.7081 .65462 m .70263 .59874 L .67532 .59747 L p .707 .577 .707 r
F P
0 g
s
.70263 .59874 m .7081 .65462 L .73912 .6534 L p .707 .577 .707 r
F P
0 g
s
.21964 .76824 m .22294 .7868 L .19912 .79506 L p .707 .577 .707 r
F P
0 g
s
.21838 .74018 m .21245 .703 L .24154 .69598 L p .707 .577 .707 r
F P
0 g
s
.33765 .74982 m .34096 .76838 L .31401 .76967 L p .707 .577 .707 r
F P
0 g
s
.31401 .76967 m .3107 .75111 L .33765 .74982 L p .707 .577 .707 r
F P
0 g
s
.36672 .26885 m .41583 .77342 L .39275 .78452 L p .707 .577 .707 r
F P
0 g
s
.41583 .77342 m .36672 .26885 L .40058 .25886 L p .707 .577 .707 r
F P
0 g
s
.30378 .68741 m .30971 .72459 L .27894 .72778 L p .707 .577 .707 r
F P
0 g
s
.27894 .72778 m .27301 .69061 L .30378 .68741 L p .707 .577 .707 r
F P
0 g
s
.79462 .58831 m .80009 .64419 L .82407 .63711 L p .707 .577 .707 r
F P
0 g
s
.82407 .63711 m .8186 .58123 L .79462 .58831 L p .707 .577 .707 r
F P
0 g
s
.24154 .69598 m .24747 .73316 L .21838 .74018 L p .707 .577 .707 r
F P
0 g
s
.74479 .7104 m .73886 .67322 L .7081 .67642 L p .707 .577 .707 r
F P
0 g
s
.73886 .67322 m .74479 .7104 L .77626 .70503 L p .707 .577 .707 r
F P
0 g
s
.77626 .70503 m .77033 .66785 L .73886 .67322 L p .707 .577 .707 r
F P
0 g
s
.24747 .73316 m .24154 .69598 L .27301 .69061 L p .707 .577 .707 r
F P
0 g
s
.77033 .66785 m .77626 .70503 L .80535 .698 L p .707 .577 .707 r
F P
0 g
s
.80535 .698 m .79942 .66083 L .77033 .66785 L p .707 .577 .707 r
F P
0 g
s
.67532 .59747 m .68079 .65334 L .7081 .65462 L p .707 .577 .707 r
F P
0 g
s
.27301 .69061 m .27894 .72778 L .24747 .73316 L p .707 .577 .707 r
F P
0 g
s
.22294 .7868 m .21964 .76824 L .24866 .76079 L p .707 .577 .707 r
F P
0 g
s
.68079 .65334 m .67532 .59747 L .65441 .59383 L p .707 .577 .707 r
F P
0 g
s
.56901 .24603 m .61811 .75059 L .57956 .74877 L p .707 .577 .707 r
F P
0 g
s
.57956 .74877 m .53046 .24421 L .56901 .24603 L p .707 .577 .707 r
F P
0 g
s
.7081 .67642 m .71403 .71359 L .74479 .7104 L p .707 .577 .707 r
F P
0 g
s
.71403 .71359 m .7081 .67642 L .68105 .67712 L p .707 .577 .707 r
F P
0 g
s
.24866 .76079 m .25196 .77935 L .22294 .7868 L p .707 .577 .707 r
F P
0 g
s
.3107 .75111 m .31401 .76967 L .28334 .77345 L p .707 .577 .707 r
F P
0 g
s
.28334 .77345 m .28004 .75489 L .3107 .75111 L p .707 .577 .707 r
F P
0 g
s
.79942 .66083 m .80535 .698 L .82922 .69001 L p .707 .577 .707 r
F P
0 g
s
.82922 .69001 m .82329 .65284 L .79942 .66083 L p .707 .577 .707 r
F P
0 g
s
.74899 .74952 m .74569 .73096 L .71502 .73474 L p .707 .577 .707 r
F P
0 g
s
.74569 .73096 m .74899 .74952 L .78037 .74362 L p .707 .577 .707 r
F P
0 g
s
.78037 .74362 m .77707 .72506 L .74569 .73096 L p .707 .577 .707 r
F P
0 g
s
.8186 .58123 m .82407 .63711 L .84041 .62924 L p .707 .577 .707 r
F P
0 g
s
.84041 .62924 m .83495 .57337 L .8186 .58123 L p .707 .577 .707 r
F P
0 g
s
.77707 .72506 m .78037 .74362 L .80939 .73617 L p .707 .577 .707 r
F P
0 g
s
.80939 .73617 m .80609 .71761 L .77707 .72506 L p .707 .577 .707 r
F P
0 g
s
.25196 .77935 m .24866 .76079 L .28004 .75489 L p .707 .577 .707 r
F P
0 g
s
.68105 .67712 m .68698 .71429 L .71403 .71359 L p .707 .577 .707 r
F P
0 g
s
.71502 .73474 m .71833 .7533 L .74899 .74952 L p .707 .577 .707 r
F P
0 g
s
.28004 .75489 m .28334 .77345 L .25196 .77935 L p .707 .577 .707 r
F P
0 g
s
.65441 .59383 m .65987 .64971 L .68079 .65334 L p .707 .577 .707 r
F P
0 g
s
.71833 .7533 m .71502 .73474 L .68807 .73603 L p .707 .577 .707 r
F P
0 g
s
.44968 .76343 m .40058 .25886 L .44191 .25096 L p .707 .577 .707 r
F P
0 g
s
.40058 .25886 m .44968 .76343 L .41583 .77342 L p .707 .577 .707 r
F P
0 g
s
.68698 .71429 m .68105 .67712 L .66036 .67526 L p .707 .577 .707 r
F P
0 g
s
.68807 .73603 m .69138 .75459 L .71833 .7533 L p .707 .577 .707 r
F P
0 g
s
.80609 .71761 m .80939 .73617 L .83321 .72791 L p .707 .577 .707 r
F P
0 g
s
.83321 .72791 m .82991 .70935 L .80609 .71761 L p .707 .577 .707 r
F P
0 g
s
.65987 .64971 m .65441 .59383 L .64192 .58818 L p .707 .577 .707 r
F P
0 g
s
.53046 .24421 m .57956 .74877 L .53576 .75047 L p .707 .577 .707 r
F P
0 g
s
.53576 .75047 m .48666 .24591 L .53046 .24421 L p .707 .577 .707 r
F P
0 g
s
.82329 .65284 m .82922 .69001 L .84552 .68184 L p .707 .577 .707 r
F P
0 g
s
.84552 .68184 m .8396 .64466 L .82329 .65284 L p .707 .577 .707 r
F P
0 g
s
.66036 .67526 m .66629 .71244 L .68698 .71429 L p .707 .577 .707 r
F P
0 g
s
.49101 .75552 m .44191 .25096 L .48666 .24591 L p .707 .577 .707 r
F P
0 g
s
.44191 .25096 m .49101 .75552 L .44968 .76343 L p .707 .577 .707 r
F P
0 g
s
.69138 .75459 m .68807 .73603 L .66747 .7347 L p .707 .577 .707 r
F P
0 g
s
.83495 .57337 m .84041 .62924 L .84752 .62137 L p .707 .577 .707 r
F P
0 g
s
.84752 .62137 m .84205 .5655 L .83495 .57337 L p .707 .577 .707 r
F P
0 g
s
.48666 .24591 m .53576 .75047 L .49101 .75552 L p .707 .577 .707 r
F P
0 g
s
.66747 .7347 m .67078 .75327 L .69138 .75459 L p .707 .577 .707 r
F P
0 g
s
.64192 .58818 m .64739 .64406 L .65987 .64971 L p .707 .577 .707 r
F P
0 g
s
.82991 .70935 m .83321 .72791 L .8495 .71964 L p .707 .577 .707 r
F P
0 g
s
.8495 .71964 m .8462 .70108 L .82991 .70935 L p .707 .577 .707 r
F P
0 g
s
.64806 .67102 m .65399 .7082 L .66629 .71244 L p .707 .577 .707 r
F P
0 g
s
.64739 .64406 m .64192 .58818 L .6391 .58107 L p .707 .577 .707 r
F P
0 g
s
.8396 .64466 m .84552 .68184 L .85267 .67428 L p .707 .577 .707 r
F P
0 g
s
.85267 .67428 m .84674 .6371 L .8396 .64466 L p .707 .577 .707 r
F P
0 g
s
.67078 .75327 m .66747 .7347 L .65524 .73089 L p .707 .577 .707 r
F P
0 g
s
.65524 .73089 m .65855 .74945 L .67078 .75327 L p .707 .577 .707 r
F P
0 g
s
.84205 .5655 m .84752 .62137 L .84469 .61427 L p .707 .577 .707 r
F P
0 g
s
.84469 .61427 m .83923 .55839 L .84205 .5655 L p .707 .577 .707 r
F P
0 g
s
.6391 .58107 m .64456 .63695 L .64739 .64406 L p .707 .577 .707 r
F P
0 g
s
.8462 .70108 m .8495 .71964 L .85667 .71218 L p .707 .577 .707 r
F P
0 g
s
.85667 .71218 m .85336 .69362 L .8462 .70108 L p .707 .577 .707 r
F P
0 g
s
.65399 .7082 m .64806 .67102 L .64535 .66482 L p .707 .577 .707 r
F P
0 g
s
.64535 .66482 m .65128 .702 L .65399 .7082 L p .707 .577 .707 r
F P
0 g
s
.84674 .6371 m .85267 .67428 L .84996 .66808 L p .707 .577 .707 r
F P
0 g
s
.84996 .66808 m .84403 .6309 L .84674 .6371 L p .707 .577 .707 r
F P
0 g
s
.64456 .63695 m .6391 .58107 L .6462 .5732 L p .707 .577 .707 r
F P
0 g
s
.65855 .74945 m .65524 .73089 L .65258 .72496 L p .707 .577 .707 r
F P
0 g
s
.65258 .72496 m .65588 .74352 L .65855 .74945 L p .707 .577 .707 r
F P
0 g
s
.85336 .69362 m .85667 .71218 L .854 .70625 L p .707 .577 .707 r
F P
0 g
s
.854 .70625 m .8507 .68769 L .85336 .69362 L p .707 .577 .707 r
F P
0 g
s
.83923 .55839 m .84469 .61427 L .83221 .60862 L p .707 .577 .707 r
F P
0 g
s
.83221 .60862 m .82674 .55274 L .83923 .55839 L p .707 .577 .707 r
F P
0 g
s
.6462 .5732 m .65167 .62908 L .64456 .63695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65128 .702 m .64535 .66482 L .6525 .65726 L p .707 .577 .707 r
F P
0 g
s
.39611 .61945 m .39064 .56357 L .35962 .56479 L p .707 .577 .707 r
F P
0 g
s
.39064 .56357 m .39611 .61945 L .4278 .61585 L p .707 .577 .707 r
F P
0 g
s
.4278 .61585 m .42234 .55997 L .39064 .56357 L p .707 .577 .707 r
F P
0 g
s
.42234 .55997 m .4278 .61585 L .45708 .61024 L p .707 .577 .707 r
F P
0 g
s
.45708 .61024 m .45161 .55436 L .42234 .55997 L p .707 .577 .707 r
F P
0 g
s
.6525 .65726 m .65843 .69444 L .65128 .702 L p .707 .577 .707 r
F P
0 g
s
.65167 .62908 m .6462 .5732 L .66255 .56534 L p .707 .577 .707 r
F P
0 g
s
.84403 .6309 m .84996 .66808 L .83766 .66384 L p .707 .577 .707 r
F P
0 g
s
.83766 .66384 m .83173 .62666 L .84403 .6309 L p .707 .577 .707 r
F P
0 g
s
.36509 .62067 m .35962 .56479 L .33231 .56352 L p .707 .577 .707 r
F P
0 g
s
.35962 .56479 m .36509 .62067 L .39611 .61945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65588 .74352 m .65258 .72496 L .65974 .71749 L p .707 .577 .707 r
F P
0 g
s
.65974 .71749 m .66305 .73606 L .65588 .74352 L p .707 .577 .707 r
F P
0 g
s
.45161 .55436 m .45708 .61024 L .48106 .60316 L p .707 .577 .707 r
F P
0 g
s
.48106 .60316 m .47559 .54728 L .45161 .55436 L p .707 .577 .707 r
F P
0 g
s
.82674 .55274 m .83221 .60862 L .81129 .60498 L p .707 .577 .707 r
F P
0 g
s
.81129 .60498 m .80583 .5491 L .82674 .55274 L p .707 .577 .707 r
F P
0 g
s
.66255 .56534 m .66802 .62122 L .65167 .62908 L p .707 .577 .707 r
F P
0 g
s
.8507 .68769 m .854 .70625 L .84177 .70243 L p .707 .577 .707 r
F P
0 g
s
.84177 .70243 m .83847 .68387 L .8507 .68769 L p .707 .577 .707 r
F P
0 g
s
.40178 .68027 m .39585 .64309 L .36509 .64629 L p .707 .577 .707 r
F P
0 g
s
.39585 .64309 m .40178 .68027 L .43325 .6749 L p .707 .577 .707 r
F P
0 g
s
.43325 .6749 m .42732 .63772 L .39585 .64309 L p .707 .577 .707 r
F P
0 g
s
.33231 .56352 m .33778 .61939 L .36509 .62067 L p .707 .577 .707 r
F P
0 g
s
.42732 .63772 m .43325 .6749 L .46234 .66787 L p .707 .577 .707 r
F P
0 g
s
.46234 .66787 m .45641 .6307 L .42732 .63772 L p .707 .577 .707 r
F P
0 g
s
.33778 .61939 m .33231 .56352 L .3114 .55988 L p .707 .577 .707 r
F P
0 g
s
.65843 .69444 m .6525 .65726 L .6688 .64909 L p .707 .577 .707 r
F P
0 g
s
.36509 .64629 m .37102 .68346 L .40178 .68027 L p .707 .577 .707 r
F P
0 g
s
.37102 .68346 m .36509 .64629 L .33804 .64699 L p .707 .577 .707 r
F P
0 g
s
.66802 .62122 m .66255 .56534 L .68653 .55825 L p .707 .577 .707 r
F P
0 g
s
.45641 .6307 m .46234 .66787 L .48621 .65988 L p .707 .577 .707 r
F P
0 g
s
.48621 .65988 m .48028 .62271 L .45641 .6307 L p .707 .577 .707 r
F P
0 g
s
.47559 .54728 m .48106 .60316 L .4974 .59529 L p .707 .577 .707 r
F P
0 g
s
.4974 .59529 m .49194 .53942 L .47559 .54728 L p .707 .577 .707 r
F P
0 g
s
.6688 .64909 m .67473 .68626 L .65843 .69444 L p .707 .577 .707 r
F P
0 g
s
.40598 .72476 m .40268 .7062 L .37201 .70998 L p .707 .577 .707 r
F P
0 g
s
.40268 .7062 m .40598 .72476 L .43736 .71885 L p .707 .577 .707 r
F P
0 g
s
.43736 .71885 m .43406 .70029 L .40268 .7062 L p .707 .577 .707 r
F P
0 g
s
.83173 .62666 m .83766 .66384 L .81697 .66198 L p .707 .577 .707 r
F P
0 g
s
.81697 .66198 m .81104 .62481 L .83173 .62666 L p .707 .577 .707 r
F P
0 g
s
.33804 .64699 m .34397 .68416 L .37102 .68346 L p .707 .577 .707 r
F P
0 g
s
.43406 .70029 m .43736 .71885 L .46638 .71141 L p .707 .577 .707 r
F P
0 g
s
.46638 .71141 m .46308 .69284 L .43406 .70029 L p .707 .577 .707 r
F P
0 g
s
.3114 .55988 m .31686 .61576 L .33778 .61939 L p .707 .577 .707 r
F P
0 g
s
.37201 .70998 m .37532 .72854 L .40598 .72476 L p .707 .577 .707 r
F P
0 g
s
.66305 .73606 m .65974 .71749 L .67603 .70923 L p .707 .577 .707 r
F P
0 g
s
.80583 .5491 m .81129 .60498 L .78399 .60371 L p .707 .577 .707 r
F P
0 g
s
.78399 .60371 m .77852 .54783 L .80583 .5491 L p .707 .577 .707 r
F P
0 g
s
.37532 .72854 m .37201 .70998 L .34506 .71127 L p .707 .577 .707 r
F P
0 g
s
.67603 .70923 m .67934 .72779 L .66305 .73606 L p .707 .577 .707 r
F P
0 g
s
.68653 .55825 m .692 .61413 L .66802 .62122 L p .707 .577 .707 r
F P
0 g
s
.34397 .68416 m .33804 .64699 L .31735 .64513 L p .707 .577 .707 r
F P
0 g
s
.34506 .71127 m .34837 .72983 L .37532 .72854 L p .707 .577 .707 r
F P
0 g
s
.46308 .69284 m .46638 .71141 L .4902 .70315 L p .707 .577 .707 r
F P
0 g
s
.4902 .70315 m .4869 .68458 L .46308 .69284 L p .707 .577 .707 r
F P
0 g
s
.31686 .61576 m .3114 .55988 L .29891 .55423 L p .707 .577 .707 r
F P
0 g
s
.83847 .68387 m .84177 .70243 L .82117 .7011 L p .707 .577 .707 r
F P
0 g
s
.82117 .7011 m .81787 .68254 L .83847 .68387 L p .707 .577 .707 r
F P
0 g
s
.692 .61413 m .68653 .55825 L .7158 .55264 L p .707 .577 .707 r
F P
0 g
s
.67473 .68626 m .6688 .64909 L .69267 .6411 L p .707 .577 .707 r
F P
0 g
s
.48028 .62271 m .48621 .65988 L .50251 .65171 L p .707 .577 .707 r
F P
0 g
s
.50251 .65171 m .49659 .61453 L .48028 .62271 L p .707 .577 .707 r
F P
0 g
s
.31735 .64513 m .32328 .68231 L .34397 .68416 L p .707 .577 .707 r
F P
0 g
s
.77852 .54783 m .78399 .60371 L .75297 .60493 L p .707 .577 .707 r
F P
0 g
s
.75297 .60493 m .7475 .54905 L .77852 .54783 L p .707 .577 .707 r
F P
0 g
s
.81104 .62481 m .81697 .66198 L .78992 .66268 L p .707 .577 .707 r
F P
0 g
s
.78992 .66268 m .78399 .62551 L .81104 .62481 L p .707 .577 .707 r
F P
0 g
s
.49194 .53942 m .4974 .59529 L .50451 .58742 L p .707 .577 .707 r
F P
0 g
s
.50451 .58742 m .49904 .53155 L .49194 .53942 L p .707 .577 .707 r
F P
0 g
s
.34837 .72983 m .34506 .71127 L .32446 .70994 L p .707 .577 .707 r
F P
0 g
s
.69267 .6411 m .6986 .67827 L .67473 .68626 L p .707 .577 .707 r
F P
0 g
s
.29891 .55423 m .30438 .61011 L .31686 .61576 L p .707 .577 .707 r
F P
0 g
s
.72127 .60852 m .7158 .55264 L .7475 .54905 L p .707 .577 .707 r
F P
0 g
s
.7158 .55264 m .72127 .60852 L .692 .61413 L p .707 .577 .707 r
F P
0 g
s
.32446 .70994 m .32777 .7285 L .34837 .72983 L p .707 .577 .707 r
F P
0 g
s
.7475 .54905 m .75297 .60493 L .72127 .60852 L p .707 .577 .707 r
F P
0 g
s
.67934 .72779 m .67603 .70923 L .69985 .70096 L p .707 .577 .707 r
F P
0 g
s
.4869 .68458 m .4902 .70315 L .50649 .69488 L p .707 .577 .707 r
F P
0 g
s
.50649 .69488 m .50319 .67632 L .4869 .68458 L p .707 .577 .707 r
F P
0 g
s
.32328 .68231 m .31735 .64513 L .30505 .64089 L p .707 .577 .707 r
F P
0 g
s
.69985 .70096 m .70316 .71953 L .67934 .72779 L p .707 .577 .707 r
F P
0 g
s
.6986 .67827 m .69267 .6411 L .72176 .63407 L p .707 .577 .707 r
F P
0 g
s
.81787 .68254 m .82117 .7011 L .79422 .70239 L p .707 .577 .707 r
F P
0 g
s
.79422 .70239 m .79092 .68383 L .81787 .68254 L p .707 .577 .707 r
F P
0 g
s
.78399 .62551 m .78992 .66268 L .75916 .66588 L p .707 .577 .707 r
F P
0 g
s
.75916 .66588 m .75323 .6287 L .78399 .62551 L p .707 .577 .707 r
F P
0 g
s
.30438 .61011 m .29891 .55423 L .29609 .54712 L p .707 .577 .707 r
F P
0 g
s
.30505 .64089 m .31098 .67807 L .32328 .68231 L p .707 .577 .707 r
F P
0 g
s
.49659 .61453 m .50251 .65171 L .50966 .64415 L p .707 .577 .707 r
F P
0 g
s
.50966 .64415 m .50373 .60697 L .49659 .61453 L p .707 .577 .707 r
F P
0 g
s
.72176 .63407 m .72769 .67125 L .6986 .67827 L p .707 .577 .707 r
F P
0 g
s
.72769 .67125 m .72176 .63407 L .75323 .6287 L p .707 .577 .707 r
F P
0 g
s
.32777 .7285 m .32446 .70994 L .31223 .70612 L p .707 .577 .707 r
F P
0 g
s
.75323 .6287 m .75916 .66588 L .72769 .67125 L p .707 .577 .707 r
F P
0 g
s
.70316 .71953 m .69985 .70096 L .72887 .69352 L p .707 .577 .707 r
F P
0 g
s
.31223 .70612 m .31554 .72469 L .32777 .7285 L p .707 .577 .707 r
F P
0 g
s
.72887 .69352 m .73218 .71208 L .70316 .71953 L p .707 .577 .707 r
F P
0 g
s
.49904 .53155 m .50451 .58742 L .50168 .58032 L p .707 .577 .707 r
F P
0 g
s
.50168 .58032 m .49622 .52444 L .49904 .53155 L p .707 .577 .707 r
F P
0 g
s
.79092 .68383 m .79422 .70239 L .76355 .70618 L p .707 .577 .707 r
F P
0 g
s
.76355 .70618 m .76025 .68761 L .79092 .68383 L p .707 .577 .707 r
F P
0 g
s
.29609 .54712 m .30155 .603 L .30438 .61011 L p .707 .577 .707 r
F P
0 g
s
.50319 .67632 m .50649 .69488 L .51366 .68741 L p .707 .577 .707 r
F P
0 g
s
.51366 .68741 m .51035 .66885 L .50319 .67632 L p .707 .577 .707 r
F P
0 g
s
.73218 .71208 m .72887 .69352 L .76025 .68761 L p .707 .577 .707 r
F P
0 g
s
.76025 .68761 m .76355 .70618 L .73218 .71208 L p .707 .577 .707 r
F P
0 g
s
.31098 .67807 m .30505 .64089 L .30234 .63469 L p .707 .577 .707 r
F P
0 g
s
.30234 .63469 m .30827 .67187 L .31098 .67807 L p .707 .577 .707 r
F P
0 g
s
.30155 .603 m .29609 .54712 L .30319 .53925 L p .707 .577 .707 r
F P
0 g
s
.50373 .60697 m .50966 .64415 L .50695 .63795 L p .707 .577 .707 r
F P
0 g
s
.50695 .63795 m .50102 .60077 L .50373 .60697 L p .707 .577 .707 r
F P
0 g
s
.31554 .72469 m .31223 .70612 L .30957 .70019 L p .707 .577 .707 r
F P
0 g
s
.30957 .70019 m .31287 .71876 L .31554 .72469 L p .707 .577 .707 r
F P
0 g
s
.49622 .52444 m .50168 .58032 L .4892 .57467 L p .707 .577 .707 r
F P
0 g
s
.4892 .57467 m .48373 .51879 L .49622 .52444 L p .707 .577 .707 r
F P
0 g
s
.30319 .53925 m .30866 .59513 L .30155 .603 L p .707 .577 .707 r
F P
0 g
s
.51035 .66885 m .51366 .68741 L .51099 .68148 L p .707 .577 .707 r
F P
0 g
s
.51099 .68148 m .50769 .66292 L .51035 .66885 L p .707 .577 .707 r
F P
0 g
s
.30827 .67187 m .30234 .63469 L .30949 .62713 L p .707 .577 .707 r
F P
0 g
s
.30949 .62713 m .31542 .66431 L .30827 .67187 L p .707 .577 .707 r
F P
0 g
s
.30866 .59513 m .30319 .53925 L .31954 .53139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50102 .60077 m .50695 .63795 L .49465 .63371 L p .707 .577 .707 r
F P
0 g
s
.49465 .63371 m .48872 .59653 L .50102 .60077 L p .707 .577 .707 r
F P
0 g
s
.31287 .71876 m .30957 .70019 L .31673 .69273 L p .707 .577 .707 r
F P
0 g
s
.31673 .69273 m .32004 .71129 L .31287 .71876 L p .707 .577 .707 r
F P
0 g
s
.48373 .51879 m .4892 .57467 L .46828 .57103 L p .707 .577 .707 r
F P
0 g
s
.46828 .57103 m .46282 .51515 L .48373 .51879 L p .707 .577 .707 r
F P
0 g
s
.31954 .53139 m .32501 .58727 L .30866 .59513 L p .707 .577 .707 r
F P
0 g
s
.50769 .66292 m .51099 .68148 L .49876 .67767 L p .707 .577 .707 r
F P
0 g
s
.49876 .67767 m .49546 .6591 L .50769 .66292 L p .707 .577 .707 r
F P
0 g
s
.31542 .66431 m .30949 .62713 L .32579 .61896 L p .707 .577 .707 r
F P
0 g
s
.32501 .58727 m .31954 .53139 L .34352 .5243 L p .707 .577 .707 r
F P
0 g
s
.32579 .61896 m .33172 .65613 L .31542 .66431 L p .707 .577 .707 r
F P
0 g
s
.48872 .59653 m .49465 .63371 L .47396 .63185 L p .707 .577 .707 r
F P
0 g
s
.47396 .63185 m .46803 .59468 L .48872 .59653 L p .707 .577 .707 r
F P
0 g
s
.46282 .51515 m .46828 .57103 L .44098 .56976 L p .707 .577 .707 r
F P
0 g
s
.44098 .56976 m .43551 .51388 L .46282 .51515 L p .707 .577 .707 r
F P
0 g
s
.32004 .71129 m .31673 .69273 L .33302 .68446 L p .707 .577 .707 r
F P
0 g
s
.34352 .5243 m .34899 .58018 L .32501 .58727 L p .707 .577 .707 r
F P
0 g
s
.33302 .68446 m .33632 .70302 L .32004 .71129 L p .707 .577 .707 r
F P
0 g
s
.49546 .6591 m .49876 .67767 L .47816 .67634 L p .707 .577 .707 r
F P
0 g
s
.47816 .67634 m .47486 .65778 L .49546 .6591 L p .707 .577 .707 r
F P
0 g
s
.34899 .58018 m .34352 .5243 L .37279 .51869 L p .707 .577 .707 r
F P
0 g
s
.33172 .65613 m .32579 .61896 L .34966 .61097 L p .707 .577 .707 r
F P
0 g
s
.43551 .51388 m .44098 .56976 L .40996 .57098 L p .707 .577 .707 r
F P
0 g
s
.40996 .57098 m .40449 .5151 L .43551 .51388 L p .707 .577 .707 r
F P
0 g
s
.46803 .59468 m .47396 .63185 L .44691 .63255 L p .707 .577 .707 r
F P
0 g
s
.44691 .63255 m .44098 .59538 L .46803 .59468 L p .707 .577 .707 r
F P
0 g
s
.34966 .61097 m .35559 .64814 L .33172 .65613 L p .707 .577 .707 r
F P
0 g
s
.37826 .57457 m .37279 .51869 L .40449 .5151 L p .707 .577 .707 r
F P
0 g
s
.37279 .51869 m .37826 .57457 L .34899 .58018 L p .707 .577 .707 r
F P
0 g
s
.40449 .5151 m .40996 .57098 L .37826 .57457 L p .707 .577 .707 r
F P
0 g
s
.33632 .70302 m .33302 .68446 L .35684 .6762 L p .707 .577 .707 r
F P
0 g
s
.35684 .6762 m .36015 .69476 L .33632 .70302 L p .707 .577 .707 r
F P
0 g
s
.35559 .64814 m .34966 .61097 L .37875 .60394 L p .707 .577 .707 r
F P
0 g
s
.47486 .65778 m .47816 .67634 L .45121 .67763 L p .707 .577 .707 r
F P
0 g
s
.45121 .67763 m .44791 .65907 L .47486 .65778 L p .707 .577 .707 r
F P
0 g
s
.44098 .59538 m .44691 .63255 L .41615 .63575 L p .707 .577 .707 r
F P
0 g
s
.41615 .63575 m .41022 .59857 L .44098 .59538 L p .707 .577 .707 r
F P
0 g
s
.37875 .60394 m .38468 .64112 L .35559 .64814 L p .707 .577 .707 r
F P
0 g
s
.38468 .64112 m .37875 .60394 L .41022 .59857 L p .707 .577 .707 r
F P
0 g
s
.41022 .59857 m .41615 .63575 L .38468 .64112 L p .707 .577 .707 r
F P
0 g
s
.36015 .69476 m .35684 .6762 L .38586 .66875 L p .707 .577 .707 r
F P
0 g
s
.38586 .66875 m .38917 .68731 L .36015 .69476 L p .707 .577 .707 r
F P
0 g
s
.44791 .65907 m .45121 .67763 L .42054 .68141 L p .707 .577 .707 r
F P
0 g
s
.42054 .68141 m .41724 .66285 L .44791 .65907 L p .707 .577 .707 r
F P
0 g
s
.38917 .68731 m .38586 .66875 L .41724 .66285 L p .707 .577 .707 r
F P
0 g
s
.41724 .66285 m .42054 .68141 L .38917 .68731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
TGoo2`00PGoo0024Ool=000;FUH:001gOol007]oo`T000IJEP03001JEUYF01UJEPH0075oo`00MGoo
1P000UYF00<005YFFUH02UYF00<005YFFUH07eYF0P00Kgoo001`Ool50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0QFUH2001]Ool006eoo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF02=J
EVeoo`00JWoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
5UYFKGoo001WOol30007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00Oomoo`1ZOol006Eoo`800003FUH005YF00MJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EVaoo`00Hgoo0P000eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001QOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUI/Ool0061oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVaoo`00
Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001NOol01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<007ooOol0JGoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005mo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00
Ggoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol0061oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVYoo`00
H7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00H7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
06Moo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00H7oo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Mo
o`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Ioo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00
HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00HWoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001SOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001J
EUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF0007FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00005FUHH000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF
FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol0061oo`@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005aoo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001J
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001HOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0087oo2000?7oo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000GOol90004FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000?Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol0
05Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00;Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP06001JEUYFFUH005YF;Goo001DOol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUH000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYF001JEP0]Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05Eoo`03001JEP0000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00FUH0
0003FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE0006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000AJEP03001JEUYF00=JEP05001JEUYFFUH0000/
Ool004Mooa0000=JEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90007FUH70003FUH01@00FUIJEUYF0000;7oo0011Ool60004FUH00`00FUIJEP06
FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EPT000QJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001oogoo02Yoo`00?Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00
FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@00003
FUH0000000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUH00002FUH01P00FUIJEUYF001JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF
FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000UYF00@005YF000000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ0000AJEP8002eoo`00<Goo0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03
001JEUYF00H002ioo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF3P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000^Ool20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<00000eYF001JEP06FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00@00003FUH0000000D000EJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH00000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=J
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00=JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00AJEP03001JEUYF00=JEP@000QJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YF00001EYF00<005YF00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP04001JEP000007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002]oo`00;Goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ@000MJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0
02eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHD00000eYF001oo`0ZOol002eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6
0008FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH:0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000ZOol002ioo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP04FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF300000=JEP00FUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002Yoo`00;Woo00<005YF000015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@00003Ool0000000D000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0002Yoo`00;Woo00<005YF000015YF00<005YF
00000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001JEUYF009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH9
0002FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000[Ool002ioo`03
001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000AJEP@00003FUH005YF00MJEP03001JEUYF00AJEPL00003FUH005YF00YJEP03001JEUYF0080
0003FUH00000008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH0100025YF00<005YFFUH02EYF0`000eYF00@005YF000000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00004P00;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH=0007FUH00`00FUIJEP04FUH600000eYF001JEP07FUH00`00
FUIJEP07FUH200000eYF001JEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJ
EP04001JEUYFFUH70003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:goo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90004FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`0000=JEP00FUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YF00000UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00H000AJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00<0009JEP03001JEUYF00IJEP03001JEUYF009J
EP<000IJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH01000FUIJEUYF1@001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000002Yoo`00;Woo0P000eYF00<005YFFUH00UYF00<0
05YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000<0
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEPD00003FUH005YF00IJEP04001JEP000008
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000ZOol002moo`05001JEUYFFUH00005FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH20003FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00L000EJEP03001JEUYF00AJEP<000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00@000IJEP03001J
EUYF00MJEP03001JEUYF009JEQ<00003FUH007oo02Uoo`00<7oo0P0000=JEP00FUH015YF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00FUIJEP8000EJEP04001JEUYF
FUH20003FUH:0004FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00UYF0`0000=JEP00FUH025YF00<0
05YFFUH015YF20003Woo0P0000=JEP0000000P00:Goo000bOol400000eYF00000003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF000000040004FUH00`00FUH000070004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF008000AJEP03001J
EUYF00MJEP03001JEUYF00L0015oo`8000=JEP04001JEP00000YOol003Aoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800004FUH005YF0002FUH70003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH015YF20004goo0`001EYF
00<005YF0000:Goo000bOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP040003Ool3000COol20002
FUH00`00FUIJEP03FUH2000ZOol0031oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH40006Ool5000>Ool40005FUH01000FUIJ
EUYF0P00:goo000_Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF00000007Ool5000:Ool40002FUH00`00
FUIJEP04FUH01000FUH00000;Goo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH70008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUH005YF00001EYF0P000UYF00@005YFFUH000Moo`D000=oo`L000IJEP03001JEUYF00AJ
EP8002moo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
00=oo`D000EJEQD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF008000EJEP04001J
EP000006Ool80004FUH00`00FUIJEP07FUH01000FUIJEUYF0P00<Goo000^Ool01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH015YF10000goo10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009J
EPD000EJEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000cOol0
02moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00/000IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP0GFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000=Goo000_Ool00`00FUH0
0005FUH00`00FUIJEP03FUH40008FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0G
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Uoo`00;goo00<005YF0000
1EYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00D005YFFUIJEP0000=oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF01MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000_Ool00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH0000017oo
0eYF00<005YFFUH015YF00<005YFFUH085YF00<005YFFUH015YF2`001EYF00<005YFFUH01UYF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0049o
o`00;goo00@005YFFUH0009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EQ@000Aoo`04001JEUYF0006FUH00`00FUIJEP0JFUH=000:FUH;0004FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60016Ool002moo`03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0000800005Ool005YFFUH0000KFUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6
0004FUHD001<Ool0031oo`9JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH007oo00000UYF00<0
05YFFUH05EYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF0P0015YF00<005YFFUH00UYF1000DGoo000`Ool01EYF001JEUYF00001EYF00<005YF
FUH015YF00@005YFFUIJEP@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF00<0009JEP03001JEUYF015JEP@000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000AJEP03001JEUYF009JEP04001JEP00001AOol0031oo`80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0<FUH50002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
0005FUH01@00FUIJEUYF00000UYF00<007ooOol0Cgoo000aOol01000FUIJEP001EYF00<005YFFUH0
10001EYF00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P003EYF100025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP03001JEUYF009JEP80059oo`00<Woo0`0015YF100000=JEP00FUH01eYF00<005YFFUH015YF1`00
47oo0P0000=JEP0000000P002UYF0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF009J
EP80059oo`00=7oo1@001EYF00<005YFFUH01UYF00<005YFFUH0100057oo0`000eYF00@005YF0000
00QJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00`005=oo`00=Woo0P001eYF00<005YFFUH015YF
1P0057oo0P0000=JEP00FUH00eYF00@005YFFUH000IJEP8000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00=JEP03001JEUYF00=JEP04001JEP00001BOol003Aoo`800003FUH005YF00IJEP03001JEUYF00@0
0003Ool0000000<0019oo`8000=JEP03001JEUYF009JEP<00003OomJEUYF009JEP8000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYF001BOol003=oo`05001JEUYFFUH00006FUH4
0006Ool3000@Ool30005FUH00`00FUIJEP02FUH01000Oomoogoo0eYF00<005YF000025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001UYF00<005YFFUH00eYF00@005YF0000055oo`00<Woo0P0015YF00@005YFFUIJEP80
01Uoo`@00003FUH005YF00IJEP04001JEUYF0004Ool2FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
1eYF00<005YFFUH00eYF00@005YFFUH0055oo`00<Goo00<005YF000015YF00@005YF000001Aoo`L0
00EJEP03001JEUYF00EJEP<000Eoo`03FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEP0001<00003FUH007oo051oo`00
<Goo00<005YF00000eYF0`003goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P001goo0P00
15YF00<005YFFUH045YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
1EYF1@003Woo0P0000=JEP0000000P00D7oo000aOol01000FUH005YF0P003Woo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`004Goo0P00
0eYF00@005YF0000051oo`00<Goo00<005YF00004@001UYF00<005YFFUH01eYF00<005YFFUH015YF
0`003Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P004Woo0`001EYF00<005YF0000D7oo000aOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
000AOol20003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH4000COol20002FUH00`00FUIJEP03FUH2001AOol0035oo`80009JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD001Moo`800003FUH005YF00MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH6000017oo00000000
3goo100015YF00<005YFFUH00eYF00<007ooOol0D7oo000aOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000NOol60004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH:0006Ool5000:Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02001C
Ool0039oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Qoo`X000EJ
EP03001JEUYF00AJEP`00003FUH005YF008000]oo`D000Eoo`D000IJEP03001JEUYF00AJEP<005Eo
o`00=7oo5000>Goo30001Goo00@005YFFUH000=JEP<000eoo`D00003Ool000000080009JEP03001J
EUYF00MJEP03001JEUYF009JEP8005Moo`00TWoo00D005YFFUH005YF0080011oo`H000IJEP03001J
EUYF00MJEP03001JEP00008005Uoo`00Tgoo00<005YF00004`000eYF00<005YFFUH01eYF00<005YF
FUH015YF1000G7oo002COol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04001POol009=oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD006Aoo`00Tgoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01000JGoo002DOol200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH6001]Ool009Iooa@007=oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60532 .74278 m .5965 .68701 L .56573 .69016 L p .707 .577 .707 r
F P
0 g
s
.5965 .68701 m .60532 .74278 L .63679 .73744 L p .707 .577 .707 r
F P
0 g
s
.63679 .73744 m .62797 .68167 L .5965 .68701 L p .707 .577 .707 r
F P
0 g
s
.62797 .68167 m .63679 .73744 L .66589 .73045 L p .707 .577 .707 r
F P
0 g
s
.66589 .73045 m .65707 .67468 L .62797 .68167 L p .707 .577 .707 r
F P
0 g
s
.57455 .74593 m .56573 .69016 L .53867 .69082 L p .707 .577 .707 r
F P
0 g
s
.56573 .69016 m .57455 .74593 L .60532 .74278 L p .707 .577 .707 r
F P
0 g
s
.65707 .67468 m .66589 .73045 L .68976 .72248 L p .707 .577 .707 r
F P
0 g
s
.68976 .72248 m .68094 .66671 L .65707 .67468 L p .707 .577 .707 r
F P
0 g
s
.61424 .79761 m .60471 .76088 L .5746 .7672 L p .707 .577 .707 r
F P
0 g
s
.60471 .76088 m .61424 .79761 L .64511 .78942 L p .707 .577 .707 r
F P
0 g
s
.64511 .78942 m .63559 .75268 L .60471 .76088 L p .707 .577 .707 r
F P
0 g
s
.63559 .75268 m .64511 .78942 L .67374 .78015 L p .707 .577 .707 r
F P
0 g
s
.67374 .78015 m .66421 .74342 L .63559 .75268 L p .707 .577 .707 r
F P
0 g
s
.53867 .69082 m .54749 .74659 L .57455 .74593 L p .707 .577 .707 r
F P
0 g
s
.5746 .7672 m .58412 .80394 L .61424 .79761 L p .707 .577 .707 r
F P
0 g
s
.54749 .74659 m .53867 .69082 L .51797 .68892 L p .707 .577 .707 r
F P
0 g
s
.58412 .80394 m .5746 .7672 L .54821 .77103 L p .707 .577 .707 r
F P
0 g
s
.62094 .83517 m .61565 .81691 L .58579 .82417 L p .707 .577 .707 r
F P
0 g
s
.61565 .81691 m .62094 .83517 L .65159 .82613 L p .707 .577 .707 r
F P
0 g
s
.65159 .82613 m .64629 .80786 L .61565 .81691 L p .707 .577 .707 r
F P
0 g
s
.66421 .74342 m .67374 .78015 L .6973 .77072 L p .707 .577 .707 r
F P
0 g
s
.6973 .77072 m .68778 .73399 L .66421 .74342 L p .707 .577 .707 r
F P
0 g
s
.64629 .80786 m .65159 .82613 L .68003 .81619 L p .707 .577 .707 r
F P
0 g
s
.68003 .81619 m .67473 .79792 L .64629 .80786 L p .707 .577 .707 r
F P
0 g
s
.58579 .82417 m .59109 .84243 L .62094 .83517 L p .707 .577 .707 r
F P
0 g
s
.54821 .77103 m .55773 .80777 L .58412 .80394 L p .707 .577 .707 r
F P
0 g
s
.68094 .66671 m .68976 .72248 L .70607 .71431 L p .707 .577 .707 r
F P
0 g
s
.70607 .71431 m .69724 .65854 L .68094 .66671 L p .707 .577 .707 r
F P
0 g
s
.51797 .68892 m .5268 .74469 L .54749 .74659 L p .707 .577 .707 r
F P
0 g
s
.59109 .84243 m .58579 .82417 L .55966 .82894 L p .707 .577 .707 r
F P
0 g
s
.67473 .79792 m .68003 .81619 L .70347 .80632 L p .707 .577 .707 r
F P
0 g
s
.70347 .80632 m .69818 .78806 L .67473 .79792 L p .707 .577 .707 r
F P
0 g
s
.55966 .82894 m .56495 .8472 L .59109 .84243 L p .707 .577 .707 r
F P
0 g
s
.55773 .80777 m .54821 .77103 L .52811 .77199 L p .707 .577 .707 r
F P
0 g
s
.68778 .73399 m .6973 .77072 L .7135 .76205 L p .707 .577 .707 r
F P
0 g
s
.7135 .76205 m .70398 .72532 L .68778 .73399 L p .707 .577 .707 r
F P
0 g
s
.5268 .74469 m .51797 .68892 L .50567 .68465 L p .707 .577 .707 r
F P
0 g
s
.52811 .77199 m .53763 .80873 L .55773 .80777 L p .707 .577 .707 r
F P
0 g
s
.56495 .8472 m .55966 .82894 L .53979 .83075 L p .707 .577 .707 r
F P
0 g
s
.53979 .83075 m .54509 .84901 L .56495 .8472 L p .707 .577 .707 r
F P
0 g
s
.69724 .65854 m .70607 .71431 L .71321 .70674 L p .707 .577 .707 r
F P
0 g
s
.71321 .70674 m .70439 .65097 L .69724 .65854 L p .707 .577 .707 r
F P
0 g
s
.69818 .78806 m .70347 .80632 L .71963 .79751 L p .707 .577 .707 r
F P
0 g
s
.71963 .79751 m .71434 .77924 L .69818 .78806 L p .707 .577 .707 r
F P
0 g
s
.50567 .68465 m .51449 .74042 L .5268 .74469 L p .707 .577 .707 r
F P
0 g
s
.53763 .80873 m .52811 .77199 L .51627 .77 L p .707 .577 .707 r
F P
0 g
s
.51627 .77 m .5258 .80673 L .53763 .80873 L p .707 .577 .707 r
F P
0 g
s
.70398 .72532 m .7135 .76205 L .72075 .75499 L p .707 .577 .707 r
F P
0 g
s
.72075 .75499 m .71123 .71825 L .70398 .72532 L p .707 .577 .707 r
F P
0 g
s
.51449 .74042 m .50567 .68465 L .50296 .67843 L p .707 .577 .707 r
F P
0 g
s
.54509 .84901 m .53979 .83075 L .52814 .82943 L p .707 .577 .707 r
F P
0 g
s
.52814 .82943 m .53344 .84769 L .54509 .84901 L p .707 .577 .707 r
F P
0 g
s
.71434 .77924 m .71963 .79751 L .72693 .79059 L p .707 .577 .707 r
F P
0 g
s
.72693 .79059 m .72163 .77233 L .71434 .77924 L p .707 .577 .707 r
F P
0 g
s
.70439 .65097 m .71321 .70674 L .7105 .70052 L p .707 .577 .707 r
F P
0 g
s
.7105 .70052 m .70168 .64475 L .70439 .65097 L p .707 .577 .707 r
F P
0 g
s
.50296 .67843 m .51178 .7342 L .51449 .74042 L p .707 .577 .707 r
F P
0 g
s
.5258 .80673 m .51627 .77 L .51387 .76524 L p .707 .577 .707 r
F P
0 g
s
.51387 .76524 m .52339 .80197 L .5258 .80673 L p .707 .577 .707 r
F P
0 g
s
.71123 .71825 m .72075 .75499 L .71834 .75023 L p .707 .577 .707 r
F P
0 g
s
.71834 .75023 m .70882 .71349 L .71123 .71825 L p .707 .577 .707 r
F P
0 g
s
.53344 .84769 m .52814 .82943 L .52585 .8251 L p .707 .577 .707 r
F P
0 g
s
.51178 .7342 m .50296 .67843 L .5101 .67087 L p .707 .577 .707 r
F P
0 g
s
.52585 .8251 m .53115 .84336 L .53344 .84769 L p .707 .577 .707 r
F P
0 g
s
.72163 .77233 m .72693 .79059 L .72464 .78626 L p .707 .577 .707 r
F P
0 g
s
.72464 .78626 m .71934 .768 L .72163 .77233 L p .707 .577 .707 r
F P
0 g
s
.5101 .67087 m .51892 .72664 L .51178 .7342 L p .707 .577 .707 r
F P
0 g
s
.52339 .80197 m .51387 .76524 L .52112 .75817 L p .707 .577 .707 r
F P
0 g
s
.52112 .75817 m .53064 .79491 L .52339 .80197 L p .707 .577 .707 r
F P
0 g
s
.53064 .79491 m .52112 .75817 L .53732 .7495 L p .707 .577 .707 r
F P
0 g
s
.53182 .81586 m .45259 .31224 L .40914 .31665 L p .707 .577 .707 r
F P
0 g
s
.51892 .72664 m .5101 .67087 L .52641 .6627 L p .707 .577 .707 r
F P
0 g
s
.52641 .6627 m .53523 .71847 L .51892 .72664 L p .707 .577 .707 r
F P
0 g
s
.53732 .7495 m .54684 .78624 L .53064 .79491 L p .707 .577 .707 r
F P
0 g
s
.53523 .71847 m .52641 .6627 L .55028 .65473 L p .707 .577 .707 r
F P
0 g
s
.53844 .83645 m .53314 .81819 L .5493 .80937 L p .707 .577 .707 r
F P
0 g
s
.5493 .80937 m .5546 .82763 L .53844 .83645 L p .707 .577 .707 r
F P
0 g
s
.55028 .65473 m .5591 .7105 L .53523 .71847 L p .707 .577 .707 r
F P
0 g
s
.54684 .78624 m .53732 .7495 L .56088 .74007 L p .707 .577 .707 r
F P
0 g
s
.56088 .74007 m .5704 .77681 L .54684 .78624 L p .707 .577 .707 r
F P
0 g
s
.5546 .82763 m .5493 .80937 L .57275 .7995 L p .707 .577 .707 r
F P
0 g
s
.57275 .7995 m .57805 .81777 L .5546 .82763 L p .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .57275 .7995 L .5946 .79187 L p .707 .577 .707 r
F P
0 g
s
.5946 .79187 m .60119 .78957 L p .5964 .7954 L .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .5946 .79187 L .5964 .7954 L .707 .577 .707 r
F
.53182 .81586 m .57626 .80836 L p .55057 .7053 L F P
0 g
s
.45259 .31224 m .49824 .60244 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.49824 .60244 m .53182 .81586 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.5591 .7105 m .55028 .65473 L .57937 .64773 L p .707 .577 .707 r
F P
0 g
s
.57937 .64773 m .58819 .7035 L .5591 .7105 L p .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .56088 .74007 L .5794 .73408 L p .707 .577 .707 r
F P
0 g
s
.5794 .73408 m .58951 .73081 L p .58381 .74451 L .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .5794 .73408 L .58381 .74451 L .707 .577 .707 r
F
.49703 .30475 m .45259 .31224 L p .52665 .60934 L F P
0 g
s
.58951 .73081 m .59903 .76754 L .5704 .77681 L p .707 .577 .707 r
F P
0 g
s
.57626 .80836 m .55578 .67824 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.55578 .67824 m .49703 .30475 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.58819 .7035 m .57937 .64773 L .61085 .6424 L p .707 .577 .707 r
F P
0 g
s
.61085 .6424 m .61967 .69817 L .58819 .7035 L p .707 .577 .707 r
F P
0 g
s
.59903 .76754 m .59446 .74991 L p .62038 .72261 L .707 .577 .707 r
F P
0 g
s
.59446 .74991 m .58951 .73081 L .59261 .72998 L p .707 .577 .707 r
F P
0 g
s
.59261 .72998 m .62038 .72261 L p .59446 .74991 L .707 .577 .707 r
F P
0 g
s
.64162 .63925 m .65044 .69502 L .61967 .69817 L p .707 .577 .707 r
F P
0 g
s
.61967 .69817 m .61085 .6424 L .64162 .63925 L p .707 .577 .707 r
F P
0 g
s
.65049 .71629 m .66002 .75303 L .62991 .75935 L p .707 .577 .707 r
F P
0 g
s
.62991 .75935 m .62038 .72261 L .65049 .71629 L p .707 .577 .707 r
F P
0 g
s
.62038 .72261 m .62991 .75935 L .59903 .76754 L p .707 .577 .707 r
F P
0 g
s
.66169 .77326 m .66698 .79152 L .63713 .79878 L p .707 .577 .707 r
F P
0 g
s
.63713 .79878 m .63183 .78052 L .66169 .77326 L p .707 .577 .707 r
F P
0 g
s
.60649 .80783 m .60119 .78957 L .63183 .78052 L p .707 .577 .707 r
F P
0 g
s
.63183 .78052 m .63713 .79878 L .60649 .80783 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .65104 .78728 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.53811 .2949 m .57257 .51394 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.57257 .51394 m .61734 .79851 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.60119 .78957 m .60649 .80783 L .57805 .81777 L p .707 .577 .707 r
F P
0 g
s
.49703 .30475 m .57626 .80836 L .61734 .79851 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .53811 .2949 L .49703 .30475 L p .707 .577 .707 r
F P
0 g
s
.70168 .64475 m .7105 .70052 L .69819 .69626 L p .707 .577 .707 r
F P
0 g
s
.69819 .69626 m .68937 .64049 L .70168 .64475 L p .707 .577 .707 r
F P
0 g
s
.48837 .82027 m .40914 .31665 L .37093 .31754 L p .707 .577 .707 r
F P
0 g
s
.40914 .31665 m .48837 .82027 L .53182 .81586 L p .707 .577 .707 r
F P
0 g
s
.26231 .7106 m .25349 .65483 L .22272 .65798 L p .707 .577 .707 r
F P
0 g
s
.25349 .65483 m .26231 .7106 L .29379 .70526 L p .707 .577 .707 r
F P
0 g
s
.29379 .70526 m .28496 .64949 L .25349 .65483 L p .707 .577 .707 r
F P
0 g
s
.28496 .64949 m .29379 .70526 L .32288 .69827 L p .707 .577 .707 r
F P
0 g
s
.32288 .69827 m .31406 .6425 L .28496 .64949 L p .707 .577 .707 r
F P
0 g
s
.65104 .78728 m .57181 .28366 L .53811 .2949 L p .707 .577 .707 r
F P
0 g
s
.70882 .71349 m .71834 .75023 L .70651 .74823 L p .707 .577 .707 r
F P
0 g
s
.70651 .74823 m .69699 .7115 L .70882 .71349 L p .707 .577 .707 r
F P
0 g
s
.53115 .84336 m .52585 .8251 L .53314 .81819 L p .707 .577 .707 r
F P
0 g
s
.23154 .71375 m .22272 .65798 L .19566 .65864 L p .707 .577 .707 r
F P
0 g
s
.22272 .65798 m .23154 .71375 L .26231 .7106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.53314 .81819 m .53844 .83645 L .53115 .84336 L p .707 .577 .707 r
F P
0 g
s
.31406 .6425 m .32288 .69827 L .34675 .6903 L p .707 .577 .707 r
F P
0 g
s
.34675 .6903 m .33793 .63453 L .31406 .6425 L p .707 .577 .707 r
F P
0 g
s
.71934 .768 m .72464 .78626 L .71299 .78494 L p .707 .577 .707 r
F P
0 g
s
.71299 .78494 m .70769 .76668 L .71934 .768 L p .707 .577 .707 r
F P
0 g
s
.68937 .64049 m .69819 .69626 L .6775 .69436 L p .707 .577 .707 r
F P
0 g
s
.6775 .69436 m .66868 .63859 L .68937 .64049 L p .707 .577 .707 r
F P
0 g
s
.27123 .77162 m .2617 .73488 L .23159 .7412 L p .707 .577 .707 r
F P
0 g
s
.2617 .73488 m .27123 .77162 L .3021 .76342 L p .707 .577 .707 r
F P
0 g
s
.3021 .76342 m .29258 .72668 L .2617 .73488 L p .707 .577 .707 r
F P
0 g
s
.45016 .82116 m .37093 .31754 L .34171 .31483 L p .707 .577 .707 r
F P
0 g
s
.37093 .31754 m .45016 .82116 L .48837 .82027 L p .707 .577 .707 r
F P
0 g
s
.19566 .65864 m .20448 .71441 L .23154 .71375 L p .707 .577 .707 r
F P
0 g
s
.29258 .72668 m .3021 .76342 L .33073 .75415 L p .707 .577 .707 r
F P
0 g
s
.33073 .75415 m .32121 .71742 L .29258 .72668 L p .707 .577 .707 r
F P
0 g
s
.20448 .71441 m .19566 .65864 L .17497 .65674 L p .707 .577 .707 r
F P
0 g
s
.23159 .7412 m .24112 .77794 L .27123 .77162 L p .707 .577 .707 r
F P
0 g
s
.24112 .77794 m .23159 .7412 L .2052 .74503 L p .707 .577 .707 r
F P
0 g
s
.66868 .63859 m .6775 .69436 L .65044 .69502 L p .707 .577 .707 r
F P
0 g
s
.65044 .69502 m .64162 .63925 L .66868 .63859 L p .707 .577 .707 r
F P
0 g
s
.67689 .71246 m .68641 .74919 L .66002 .75303 L p .707 .577 .707 r
F P
0 g
s
.66002 .75303 m .65049 .71629 L .67689 .71246 L p .707 .577 .707 r
F P
0 g
s
.66698 .79152 m .66169 .77326 L .68783 .76849 L p .707 .577 .707 r
F P
0 g
s
.57181 .28366 m .65104 .78728 L .67406 .77575 L p .707 .577 .707 r
F P
0 g
s
.67406 .77575 m .59483 .27214 L .57181 .28366 L p .707 .577 .707 r
F P
0 g
s
.32121 .71742 m .33073 .75415 L .35429 .74472 L p .707 .577 .707 r
F P
0 g
s
.35429 .74472 m .34477 .70799 L .32121 .71742 L p .707 .577 .707 r
F P
0 g
s
.27794 .81785 m .27264 .79959 L .24279 .80685 L p .707 .577 .707 r
F P
0 g
s
.27264 .79959 m .27794 .81785 L .30858 .80881 L p .707 .577 .707 r
F P
0 g
s
.30858 .80881 m .30328 .79055 L .27264 .79959 L p .707 .577 .707 r
F P
0 g
s
.33793 .63453 m .34675 .6903 L .36306 .68213 L p .707 .577 .707 r
F P
0 g
s
.36306 .68213 m .35424 .62636 L .33793 .63453 L p .707 .577 .707 r
F P
0 g
s
.69699 .7115 m .70651 .74823 L .68641 .74919 L p .707 .577 .707 r
F P
0 g
s
.68641 .74919 m .67689 .71246 L .69699 .7115 L p .707 .577 .707 r
F P
0 g
s
.30328 .79055 m .30858 .80881 L .33702 .79887 L p .707 .577 .707 r
F P
0 g
s
.33702 .79887 m .33172 .78061 L .30328 .79055 L p .707 .577 .707 r
F P
0 g
s
.2052 .74503 m .21472 .78177 L .24112 .77794 L p .707 .577 .707 r
F P
0 g
s
.24279 .80685 m .24808 .82511 L .27794 .81785 L p .707 .577 .707 r
F P
0 g
s
.17497 .65674 m .18379 .71251 L .20448 .71441 L p .707 .577 .707 r
F P
0 g
s
.24808 .82511 m .24279 .80685 L .21665 .81162 L p .707 .577 .707 r
F P
0 g
s
.70769 .76668 m .71299 .78494 L .69312 .78675 L p .707 .577 .707 r
F P
0 g
s
.69312 .78675 m .68783 .76849 L .70769 .76668 L p .707 .577 .707 r
F P
0 g
s
.33172 .78061 m .33702 .79887 L .36046 .78901 L p .707 .577 .707 r
F P
0 g
s
.36046 .78901 m .35517 .77075 L .33172 .78061 L p .707 .577 .707 r
F P
0 g
s
.21665 .81162 m .22194 .82989 L .24808 .82511 L p .707 .577 .707 r
F P
0 g
s
.21472 .78177 m .2052 .74503 L .1851 .746 L p .707 .577 .707 r
F P
0 g
s
.18379 .71251 m .17497 .65674 L .16266 .65247 L p .707 .577 .707 r
F P
0 g
s
.34477 .70799 m .35429 .74472 L .37049 .73605 L p .707 .577 .707 r
F P
0 g
s
.37049 .73605 m .36097 .69932 L .34477 .70799 L p .707 .577 .707 r
F P
0 g
s
.1851 .746 m .19462 .78273 L .21472 .78177 L p .707 .577 .707 r
F P
0 g
s
.42094 .81845 m .34171 .31483 L .32433 .30878 L p .707 .577 .707 r
F P
0 g
s
.34171 .31483 m .42094 .81845 L .45016 .82116 L p .707 .577 .707 r
F P
0 g
s
.35424 .62636 m .36306 .68213 L .3702 .67456 L p .707 .577 .707 r
F P
0 g
s
.3702 .67456 m .36138 .61879 L .35424 .62636 L p .707 .577 .707 r
F P
0 g
s
.22194 .82989 m .21665 .81162 L .19678 .81344 L p .707 .577 .707 r
F P
0 g
s
.16266 .65247 m .17148 .70824 L .18379 .71251 L p .707 .577 .707 r
F P
0 g
s
.19678 .81344 m .20208 .8317 L .22194 .82989 L p .707 .577 .707 r
F P
0 g
s
.35517 .77075 m .36046 .78901 L .37663 .78019 L p .707 .577 .707 r
F P
0 g
s
.37663 .78019 m .37133 .76193 L .35517 .77075 L p .707 .577 .707 r
F P
0 g
s
.59483 .27214 m .67406 .77575 L .68415 .76507 L p .707 .577 .707 r
F P
0 g
s
.68415 .76507 m .60492 .26145 L .59483 .27214 L p .707 .577 .707 r
F P
0 g
s
.68783 .76849 m .69312 .78675 L .66698 .79152 L p .707 .577 .707 r
F P
0 g
s
.19462 .78273 m .1851 .746 L .17326 .744 L p .707 .577 .707 r
F P
0 g
s
.17326 .744 m .18279 .78074 L .19462 .78273 L p .707 .577 .707 r
F P
0 g
s
.36097 .69932 m .37049 .73605 L .37774 .72899 L p .707 .577 .707 r
F P
0 g
s
.37774 .72899 m .36822 .69226 L .36097 .69932 L p .707 .577 .707 r
F P
0 g
s
.17148 .70824 m .16266 .65247 L .15995 .64625 L p .707 .577 .707 r
F P
0 g
s
.20208 .8317 m .19678 .81344 L .18513 .81211 L p .707 .577 .707 r
F P
0 g
s
.18513 .81211 m .19043 .83037 L .20208 .8317 L p .707 .577 .707 r
F P
0 g
s
.36138 .61879 m .3702 .67456 L .36749 .66834 L p .707 .577 .707 r
F P
0 g
s
.36749 .66834 m .35867 .61257 L .36138 .61879 L p .707 .577 .707 r
F P
0 g
s
.37133 .76193 m .37663 .78019 L .38392 .77328 L p .707 .577 .707 r
F P
0 g
s
.38392 .77328 m .37862 .75501 L .37133 .76193 L p .707 .577 .707 r
F P
0 g
s
.15995 .64625 m .16877 .70202 L .17148 .70824 L p .707 .577 .707 r
F P
0 g
s
.40356 .81239 m .32433 .30878 L .3205 .29998 L p .707 .577 .707 r
F P
0 g
s
.32433 .30878 m .40356 .81239 L .42094 .81845 L p .707 .577 .707 r
F P
0 g
s
.18279 .78074 m .17326 .744 L .17086 .73924 L p .707 .577 .707 r
F P
0 g
s
.17086 .73924 m .18038 .77597 L .18279 .78074 L p .707 .577 .707 r
F P
0 g
s
.36822 .69226 m .37774 .72899 L .37534 .72423 L p .707 .577 .707 r
F P
0 g
s
.37534 .72423 m .36581 .68749 L .36822 .69226 L p .707 .577 .707 r
F P
0 g
s
.60492 .26145 m .68415 .76507 L .68031 .75627 L p .707 .577 .707 r
F P
0 g
s
.68031 .75627 m .63555 .4717 L p .60492 .26145 L .707 .577 .707 r
F P
0 g
s
.60109 .25265 m .68031 .75627 L .66294 .75022 L p .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .68541 .67899 L .66733 .67986 L p .707 .577 .707 r
F P
0 g
s
.66733 .67986 m .66531 .67996 L p .6678 .68297 L .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .66733 .67986 L .6678 .68297 L .707 .577 .707 r
F
.63555 .4717 m .60109 .25265 L .60265 .25623 L p F P
0 g
s
.60265 .25623 m .60492 .26145 L p .63555 .4717 L .707 .577 .707 r
F P
0 g
s
.16877 .70202 m .15995 .64625 L .16709 .63869 L p .707 .577 .707 r
F P
0 g
s
.19043 .83037 m .18513 .81211 L .18284 .80778 L p .707 .577 .707 r
F P
0 g
s
.18284 .80778 m .18814 .82604 L .19043 .83037 L p .707 .577 .707 r
F P
0 g
s
.37862 .75501 m .38392 .77328 L .38163 .76895 L p .707 .577 .707 r
F P
0 g
s
.38163 .76895 m .37633 .75068 L .37862 .75501 L p .707 .577 .707 r
F P
0 g
s
.35867 .61257 m .36749 .66834 L .35518 .66408 L p .707 .577 .707 r
F P
0 g
s
.35518 .66408 m .34636 .60831 L .35867 .61257 L p .707 .577 .707 r
F P
0 g
s
.16709 .63869 m .17591 .69446 L .16877 .70202 L p .707 .577 .707 r
F P
0 g
s
.18038 .77597 m .17086 .73924 L .17811 .73218 L p .707 .577 .707 r
F P
0 g
s
.17811 .73218 m .18763 .76891 L .18038 .77597 L p .707 .577 .707 r
F P
0 g
s
.36581 .68749 m .37534 .72423 L .3635 .72223 L p .707 .577 .707 r
F P
0 g
s
.3635 .72223 m .35398 .6855 L .36581 .68749 L p .707 .577 .707 r
F P
0 g
s
.3205 .29998 m .39973 .80359 L .40356 .81239 L p .707 .577 .707 r
F P
0 g
s
.39973 .80359 m .3205 .29998 L .33059 .28929 L p .707 .577 .707 r
F P
0 g
s
.17591 .69446 m .16709 .63869 L .1834 .63052 L p .707 .577 .707 r
F P
0 g
s
.18814 .82604 m .18284 .80778 L .19013 .80087 L p .707 .577 .707 r
F P
0 g
s
.19013 .80087 m .19543 .81913 L .18814 .82604 L p .707 .577 .707 r
F P
0 g
s
.34636 .60831 m .35518 .66408 L .33449 .66218 L p .707 .577 .707 r
F P
0 g
s
.33449 .66218 m .32567 .60641 L .34636 .60831 L p .707 .577 .707 r
F P
0 g
s
.37633 .75068 m .38163 .76895 L .36998 .76762 L p .707 .577 .707 r
F P
0 g
s
.36998 .76762 m .36468 .74936 L .37633 .75068 L p .707 .577 .707 r
F P
0 g
s
.1834 .63052 m .19222 .68629 L .17591 .69446 L p .707 .577 .707 r
F P
0 g
s
.66294 .75022 m .58371 .2466 L .60109 .25265 L p .707 .577 .707 r
F P
0 g
s
.18763 .76891 m .17811 .73218 L .19431 .72351 L p .707 .577 .707 r
F P
0 g
s
.19222 .68629 m .1834 .63052 L .20727 .62255 L p .707 .577 .707 r
F P
0 g
s
.19431 .72351 m .20383 .76024 L .18763 .76891 L p .707 .577 .707 r
F P
0 g
s
.35398 .6855 m .3635 .72223 L .3434 .7232 L p .707 .577 .707 r
F P
0 g
s
.3434 .7232 m .33388 .68646 L .35398 .6855 L p .707 .577 .707 r
F P
0 g
s
.32567 .60641 m .33449 .66218 L .30743 .66284 L p .707 .577 .707 r
F P
0 g
s
.30743 .66284 m .29861 .60707 L .32567 .60641 L p .707 .577 .707 r
F P
0 g
s
.19543 .81913 m .19013 .80087 L .20629 .79205 L p .707 .577 .707 r
F P
0 g
s
.20727 .62255 m .21609 .67832 L .19222 .68629 L p .707 .577 .707 r
F P
0 g
s
.20629 .79205 m .21159 .81031 L .19543 .81913 L p .707 .577 .707 r
F P
0 g
s
.36468 .74936 m .36998 .76762 L .35011 .76943 L p .707 .577 .707 r
F P
0 g
s
.35011 .76943 m .34482 .75117 L .36468 .74936 L p .707 .577 .707 r
F P
0 g
s
.40982 .79291 m .33059 .28929 L .35361 .27777 L p .707 .577 .707 r
F P
0 g
s
.33059 .28929 m .40982 .79291 L .39973 .80359 L p .707 .577 .707 r
F P
0 g
s
.21609 .67832 m .20727 .62255 L .23636 .61555 L p .707 .577 .707 r
F P
0 g
s
.20383 .76024 m .19431 .72351 L .21787 .71408 L p .707 .577 .707 r
F P
0 g
s
.29861 .60707 m .30743 .66284 L .27666 .66599 L p .707 .577 .707 r
F P
0 g
s
.27666 .66599 m .26784 .61022 L .29861 .60707 L p .707 .577 .707 r
F P
0 g
s
.33388 .68646 m .3434 .7232 L .31701 .72703 L p .707 .577 .707 r
F P
0 g
s
.31701 .72703 m .30749 .69029 L .33388 .68646 L p .707 .577 .707 r
F P
0 g
s
.21787 .71408 m .2274 .75081 L .20383 .76024 L p .707 .577 .707 r
F P
0 g
s
.58371 .2466 m .66294 .75022 L .63371 .7475 L p .707 .577 .707 r
F P
0 g
s
.63371 .7475 m .55449 .24389 L .58371 .2466 L p .707 .577 .707 r
F P
0 g
s
.74252 .65074 m .7337 .59497 L .70293 .59812 L p .707 .577 .707 r
F P
0 g
s
.7337 .59497 m .74252 .65074 L .774 .6454 L p .707 .577 .707 r
F P
0 g
s
.774 .6454 m .76518 .58963 L .7337 .59497 L p .707 .577 .707 r
F P
0 g
s
.24518 .67132 m .23636 .61555 L .26784 .61022 L p .707 .577 .707 r
F P
0 g
s
.23636 .61555 m .24518 .67132 L .21609 .67832 L p .707 .577 .707 r
F P
0 g
s
.76518 .58963 m .774 .6454 L .8031 .63841 L p .707 .577 .707 r
F P
0 g
s
.8031 .63841 m .79427 .58264 L .76518 .58963 L p .707 .577 .707 r
F P
0 g
s
.26784 .61022 m .27666 .66599 L .24518 .67132 L p .707 .577 .707 r
F P
0 g
s
.21159 .81031 m .20629 .79205 L .22974 .78219 L p .707 .577 .707 r
F P
0 g
s
.22974 .78219 m .23504 .80045 L .21159 .81031 L p .707 .577 .707 r
F P
0 g
s
.71175 .65389 m .70293 .59812 L .67587 .59878 L p .707 .577 .707 r
F P
0 g
s
.70293 .59812 m .71175 .65389 L .74252 .65074 L p .707 .577 .707 r
F P
0 g
s
.34482 .75117 m .35011 .76943 L .32397 .7742 L p .707 .577 .707 r
F P
0 g
s
.32397 .7742 m .31868 .75594 L .34482 .75117 L p .707 .577 .707 r
F P
0 g
s
.2274 .75081 m .21787 .71408 L .2465 .70481 L p .707 .577 .707 r
F P
0 g
s
.79427 .58264 m .8031 .63841 L .82696 .63044 L p .707 .577 .707 r
F P
0 g
s
.82696 .63044 m .81814 .57467 L .79427 .58264 L p .707 .577 .707 r
F P
0 g
s
.30749 .69029 m .31701 .72703 L .2869 .73335 L p .707 .577 .707 r
F P
0 g
s
.2869 .73335 m .27737 .69661 L .30749 .69029 L p .707 .577 .707 r
F P
0 g
s
.2465 .70481 m .25602 .74155 L .2274 .75081 L p .707 .577 .707 r
F P
0 g
s
.75144 .70557 m .74192 .66884 L .71181 .67516 L p .707 .577 .707 r
F P
0 g
s
.74192 .66884 m .75144 .70557 L .78232 .69738 L p .707 .577 .707 r
F P
0 g
s
.78232 .69738 m .7728 .66064 L .74192 .66884 L p .707 .577 .707 r
F P
0 g
s
.7728 .66064 m .78232 .69738 L .81094 .68811 L p .707 .577 .707 r
F P
0 g
s
.81094 .68811 m .80142 .65138 L .7728 .66064 L p .707 .577 .707 r
F P
0 g
s
.67587 .59878 m .68469 .65455 L .71175 .65389 L p .707 .577 .707 r
F P
0 g
s
.25602 .74155 m .2465 .70481 L .27737 .69661 L p .707 .577 .707 r
F P
0 g
s
.35361 .27777 m .43284 .78138 L .40982 .79291 L p .707 .577 .707 r
F P
0 g
s
.43284 .78138 m .35361 .27777 L .38731 .26653 L p .707 .577 .707 r
F P
0 g
s
.27737 .69661 m .2869 .73335 L .25602 .74155 L p .707 .577 .707 r
F P
0 g
s
.71181 .67516 m .72133 .7119 L .75144 .70557 L p .707 .577 .707 r
F P
0 g
s
.23504 .80045 m .22974 .78219 L .25818 .77225 L p .707 .577 .707 r
F P
0 g
s
.68469 .65455 m .67587 .59878 L .65518 .59688 L p .707 .577 .707 r
F P
0 g
s
.72133 .7119 m .71181 .67516 L .68541 .67899 L p .707 .577 .707 r
F P
0 g
s
.31868 .75594 m .32397 .7742 L .29412 .78147 L p .707 .577 .707 r
F P
0 g
s
.29412 .78147 m .28882 .76321 L .31868 .75594 L p .707 .577 .707 r
F P
0 g
s
.25818 .77225 m .26348 .79051 L .23504 .80045 L p .707 .577 .707 r
F P
0 g
s
.75815 .74313 m .75285 .72487 L .723 .73213 L p .707 .577 .707 r
F P
0 g
s
.75285 .72487 m .75815 .74313 L .78879 .73409 L p .707 .577 .707 r
F P
0 g
s
.78879 .73409 m .7835 .71583 L .75285 .72487 L p .707 .577 .707 r
F P
0 g
s
.80142 .65138 m .81094 .68811 L .83451 .67868 L p .707 .577 .707 r
F P
0 g
s
.83451 .67868 m .82498 .64195 L .80142 .65138 L p .707 .577 .707 r
F P
0 g
s
.7835 .71583 m .78879 .73409 L .81723 .72415 L p .707 .577 .707 r
F P
0 g
s
.81723 .72415 m .81194 .70589 L .7835 .71583 L p .707 .577 .707 r
F P
0 g
s
.723 .73213 m .7283 .75039 L .75815 .74313 L p .707 .577 .707 r
F P
0 g
s
.68541 .67899 m .69493 .71573 L .72133 .7119 L p .707 .577 .707 r
F P
0 g
s
.55449 .24389 m .63371 .7475 L .59551 .74839 L p .707 .577 .707 r
F P
0 g
s
.59551 .74839 m .51628 .24478 L .55449 .24389 L p .707 .577 .707 r
F P
0 g
s
.81814 .57467 m .82696 .63044 L .84327 .62227 L p .707 .577 .707 r
F P
0 g
s
.84327 .62227 m .83445 .5665 L .81814 .57467 L p .707 .577 .707 r
F P
0 g
s
.26348 .79051 m .25818 .77225 L .28882 .76321 L p .707 .577 .707 r
F P
0 g
s
.28882 .76321 m .29412 .78147 L .26348 .79051 L p .707 .577 .707 r
F P
0 g
s
.65518 .59688 m .664 .65265 L .68469 .65455 L p .707 .577 .707 r
F P
0 g
s
.7283 .75039 m .723 .73213 L .69686 .7369 L p .707 .577 .707 r
F P
0 g
s
.81194 .70589 m .81723 .72415 L .84068 .71429 L p .707 .577 .707 r
F P
0 g
s
.84068 .71429 m .83538 .69602 L .81194 .70589 L p .707 .577 .707 r
F P
0 g
s
.69686 .7369 m .70216 .75516 L .7283 .75039 L p .707 .577 .707 r
F P
0 g
s
.82498 .64195 m .83451 .67868 L .85071 .67001 L p .707 .577 .707 r
F P
0 g
s
.85071 .67001 m .84118 .63328 L .82498 .64195 L p .707 .577 .707 r
F P
0 g
s
.46654 .77015 m .38731 .26653 L .42839 .25668 L p .707 .577 .707 r
F P
0 g
s
.38731 .26653 m .46654 .77015 L .43284 .78138 L p .707 .577 .707 r
F P
0 g
s
.664 .65265 m .65518 .59688 L .64287 .59261 L p .707 .577 .707 r
F P
0 g
s
.66531 .67996 m .67483 .71669 L .69493 .71573 L p .707 .577 .707 r
F P
0 g
s
.70216 .75516 m .69686 .7369 L .67699 .73871 L p .707 .577 .707 r
F P
0 g
s
.51628 .24478 m .59551 .74839 L .55206 .7528 L p .707 .577 .707 r
F P
0 g
s
.55206 .7528 m .47283 .24919 L .51628 .24478 L p .707 .577 .707 r
F P
0 g
s
.67699 .73871 m .68229 .75698 L .70216 .75516 L p .707 .577 .707 r
F P
0 g
s
.83445 .5665 m .84327 .62227 L .85042 .61471 L p .707 .577 .707 r
F P
0 g
s
.85042 .61471 m .8416 .55893 L .83445 .5665 L p .707 .577 .707 r
F P
0 g
s
.83538 .69602 m .84068 .71429 L .85684 .70547 L p .707 .577 .707 r
F P
0 g
s
.85684 .70547 m .85154 .68721 L .83538 .69602 L p .707 .577 .707 r
F P
0 g
s
.64287 .59261 m .65169 .64838 L .664 .65265 L p .707 .577 .707 r
F P
0 g
s
.50762 .7603 m .42839 .25668 L .47283 .24919 L p .707 .577 .707 r
F P
0 g
s
.42839 .25668 m .50762 .7603 L .46654 .77015 L p .707 .577 .707 r
F P
0 g
s
.47283 .24919 m .55206 .7528 L .50762 .7603 L p .707 .577 .707 r
F P
0 g
s
.67483 .71669 m .66531 .67996 L .65348 .67796 L p .707 .577 .707 r
F P
0 g
s
.65348 .67796 m .663 .7147 L .67483 .71669 L p .707 .577 .707 r
F P
0 g
s
.84118 .63328 m .85071 .67001 L .85796 .66295 L p .707 .577 .707 r
F P
0 g
s
.85796 .66295 m .84844 .62622 L .84118 .63328 L p .707 .577 .707 r
F P
0 g
s
.65169 .64838 m .64287 .59261 L .64016 .58639 L p .707 .577 .707 r
F P
0 g
s
.68229 .75698 m .67699 .73871 L .66535 .73739 L p .707 .577 .707 r
F P
0 g
s
.66535 .73739 m .67064 .75565 L .68229 .75698 L p .707 .577 .707 r
F P
0 g
s
.85154 .68721 m .85684 .70547 L .86413 .69855 L p .707 .577 .707 r
F P
0 g
s
.86413 .69855 m .85883 .68029 L .85154 .68721 L p .707 .577 .707 r
F P
0 g
s
.8416 .55893 m .85042 .61471 L .8477 .60848 L p .707 .577 .707 r
F P
0 g
s
.8477 .60848 m .83888 .55271 L .8416 .55893 L p .707 .577 .707 r
F P
0 g
s
.64016 .58639 m .64898 .64216 L .65169 .64838 L p .707 .577 .707 r
F P
0 g
s
.663 .7147 m .65348 .67796 L .65107 .6732 L p .707 .577 .707 r
F P
0 g
s
.65107 .6732 m .66059 .70993 L .663 .7147 L p .707 .577 .707 r
F P
0 g
s
.84844 .62622 m .85796 .66295 L .85555 .65819 L p .707 .577 .707 r
F P
0 g
s
.85555 .65819 m .84603 .62145 L .84844 .62622 L p .707 .577 .707 r
F P
0 g
s
.67064 .75565 m .66535 .73739 L .66306 .73306 L p .707 .577 .707 r
F P
0 g
s
.64898 .64216 m .64016 .58639 L .64731 .57883 L p .707 .577 .707 r
F P
0 g
s
.66306 .73306 m .66835 .75132 L .67064 .75565 L p .707 .577 .707 r
F P
0 g
s
.85883 .68029 m .86413 .69855 L .86184 .69422 L p .707 .577 .707 r
F P
0 g
s
.86184 .69422 m .85654 .67596 L .85883 .68029 L p .707 .577 .707 r
F P
0 g
s
.83888 .55271 m .8477 .60848 L .8354 .60422 L p .707 .577 .707 r
F P
0 g
s
.8354 .60422 m .82658 .54845 L .83888 .55271 L p .707 .577 .707 r
F P
0 g
s
.64731 .57883 m .65613 .6346 L .64898 .64216 L p .707 .577 .707 r
F P
0 g
s
.66059 .70993 m .65107 .6732 L .65832 .66614 L p .707 .577 .707 r
F P
0 g
s
.39951 .61856 m .39069 .56279 L .35992 .56594 L p .707 .577 .707 r
F P
0 g
s
.39069 .56279 m .39951 .61856 L .43099 .61322 L p .707 .577 .707 r
F P
0 g
s
.43099 .61322 m .42217 .55745 L .39069 .56279 L p .707 .577 .707 r
F P
0 g
s
.42217 .55745 m .43099 .61322 L .46009 .60623 L p .707 .577 .707 r
F P
0 g
s
.46009 .60623 m .45126 .55046 L .42217 .55745 L p .707 .577 .707 r
F P
0 g
s
.65832 .66614 m .66784 .70287 L .66059 .70993 L p .707 .577 .707 r
F P
0 g
s
.84603 .62145 m .85555 .65819 L .84372 .65619 L p .707 .577 .707 r
F P
0 g
s
.84372 .65619 m .83419 .61946 L .84603 .62145 L p .707 .577 .707 r
F P
0 g
s
.65613 .6346 m .64731 .57883 L .66361 .57066 L p .707 .577 .707 r
F P
0 g
s
.66835 .75132 m .66306 .73306 L .67035 .72615 L p .707 .577 .707 r
F P
0 g
s
.36874 .62171 m .35992 .56594 L .33286 .5666 L p .707 .577 .707 r
F P
0 g
s
.35992 .56594 m .36874 .62171 L .39951 .61856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67035 .72615 m .67565 .74441 L .66835 .75132 L p .707 .577 .707 r
F P
0 g
s
.45126 .55046 m .46009 .60623 L .48395 .59826 L p .707 .577 .707 r
F P
0 g
s
.48395 .59826 m .47513 .54249 L .45126 .55046 L p .707 .577 .707 r
F P
0 g
s
.85654 .67596 m .86184 .69422 L .85019 .6929 L p .707 .577 .707 r
F P
0 g
s
.85019 .6929 m .8449 .67464 L .85654 .67596 L p .707 .577 .707 r
F P
0 g
s
.82658 .54845 m .8354 .60422 L .8147 .60232 L p .707 .577 .707 r
F P
0 g
s
.8147 .60232 m .80588 .54655 L .82658 .54845 L p .707 .577 .707 r
F P
0 g
s
.66361 .57066 m .67243 .62643 L .65613 .6346 L p .707 .577 .707 r
F P
0 g
s
.40843 .67958 m .39891 .64284 L .3688 .64916 L p .707 .577 .707 r
F P
0 g
s
.39891 .64284 m .40843 .67958 L .43931 .67138 L p .707 .577 .707 r
F P
0 g
s
.43931 .67138 m .42979 .63465 L .39891 .64284 L p .707 .577 .707 r
F P
0 g
s
.33286 .5666 m .34168 .62237 L .36874 .62171 L p .707 .577 .707 r
F P
0 g
s
.42979 .63465 m .43931 .67138 L .46793 .66212 L p .707 .577 .707 r
F P
0 g
s
.46793 .66212 m .45841 .62538 L .42979 .63465 L p .707 .577 .707 r
F P
0 g
s
.34168 .62237 m .33286 .5666 L .31217 .5647 L p .707 .577 .707 r
F P
0 g
s
.3688 .64916 m .37832 .6859 L .40843 .67958 L p .707 .577 .707 r
F P
0 g
s
.66784 .70287 m .65832 .66614 L .67452 .65747 L p .707 .577 .707 r
F P
0 g
s
.37832 .6859 m .3688 .64916 L .3424 .65299 L p .707 .577 .707 r
F P
0 g
s
.45841 .62538 m .46793 .66212 L .4915 .65269 L p .707 .577 .707 r
F P
0 g
s
.4915 .65269 m .48197 .61595 L .45841 .62538 L p .707 .577 .707 r
F P
0 g
s
.41514 .72581 m .40984 .70755 L .37999 .71481 L p .707 .577 .707 r
F P
0 g
s
.40984 .70755 m .41514 .72581 L .44578 .71677 L p .707 .577 .707 r
F P
0 g
s
.44578 .71677 m .44049 .69851 L .40984 .70755 L p .707 .577 .707 r
F P
0 g
s
.67452 .65747 m .68404 .6942 L .66784 .70287 L p .707 .577 .707 r
F P
0 g
s
.47513 .54249 m .48395 .59826 L .50026 .59009 L p .707 .577 .707 r
F P
0 g
s
.50026 .59009 m .49144 .53432 L .47513 .54249 L p .707 .577 .707 r
F P
0 g
s
.83419 .61946 m .84372 .65619 L .82362 .65716 L p .707 .577 .707 r
F P
0 g
s
.82362 .65716 m .8141 .62042 L .83419 .61946 L p .707 .577 .707 r
F P
0 g
s
.67243 .62643 m .66361 .57066 L .68748 .56269 L p .707 .577 .707 r
F P
0 g
s
.44049 .69851 m .44578 .71677 L .47422 .70683 L p .707 .577 .707 r
F P
0 g
s
.47422 .70683 m .46893 .68857 L .44049 .69851 L p .707 .577 .707 r
F P
0 g
s
.3424 .65299 m .35192 .68973 L .37832 .6859 L p .707 .577 .707 r
F P
0 g
s
.37999 .71481 m .38529 .73308 L .41514 .72581 L p .707 .577 .707 r
F P
0 g
s
.31217 .5647 m .32099 .62047 L .34168 .62237 L p .707 .577 .707 r
F P
0 g
s
.67565 .74441 m .67035 .72615 L .68651 .71733 L p .707 .577 .707 r
F P
0 g
s
.80588 .54655 m .8147 .60232 L .78765 .60298 L p .707 .577 .707 r
F P
0 g
s
.78765 .60298 m .77882 .54721 L .80588 .54655 L p .707 .577 .707 r
F P
0 g
s
.68651 .71733 m .69181 .73559 L .67565 .74441 L p .707 .577 .707 r
F P
0 g
s
.38529 .73308 m .37999 .71481 L .35385 .71959 L p .707 .577 .707 r
F P
0 g
s
.8449 .67464 m .85019 .6929 L .83033 .69471 L p .707 .577 .707 r
F P
0 g
s
.83033 .69471 m .82503 .67645 L .8449 .67464 L p .707 .577 .707 r
F P
0 g
s
.46893 .68857 m .47422 .70683 L .49767 .69697 L p .707 .577 .707 r
F P
0 g
s
.49767 .69697 m .49237 .67871 L .46893 .68857 L p .707 .577 .707 r
F P
0 g
s
.35385 .71959 m .35915 .73785 L .38529 .73308 L p .707 .577 .707 r
F P
0 g
s
.68748 .56269 m .6963 .61846 L .67243 .62643 L p .707 .577 .707 r
F P
0 g
s
.35192 .68973 m .3424 .65299 L .3223 .65396 L p .707 .577 .707 r
F P
0 g
s
.32099 .62047 m .31217 .5647 L .29986 .56043 L p .707 .577 .707 r
F P
0 g
s
.48197 .61595 m .4915 .65269 L .5077 .64402 L p .707 .577 .707 r
F P
0 g
s
.5077 .64402 m .49818 .60728 L .48197 .61595 L p .707 .577 .707 r
F P
0 g
s
.3223 .65396 m .33182 .69069 L .35192 .68973 L p .707 .577 .707 r
F P
0 g
s
.68404 .6942 m .67452 .65747 L .69809 .64804 L p .707 .577 .707 r
F P
0 g
s
.6963 .61846 m .68748 .56269 L .71658 .55569 L p .707 .577 .707 r
F P
0 g
s
.77882 .54721 m .78765 .60298 L .75687 .60613 L p .707 .577 .707 r
F P
0 g
s
.75687 .60613 m .74805 .55036 L .77882 .54721 L p .707 .577 .707 r
F P
0 g
s
.8141 .62042 m .82362 .65716 L .79722 .66099 L p .707 .577 .707 r
F P
0 g
s
.79722 .66099 m .7877 .62425 L .8141 .62042 L p .707 .577 .707 r
F P
0 g
s
.69809 .64804 m .70761 .68477 L .68404 .6942 L p .707 .577 .707 r
F P
0 g
s
.49144 .53432 m .50026 .59009 L .50741 .58253 L p .707 .577 .707 r
F P
0 g
s
.50741 .58253 m .49859 .52676 L .49144 .53432 L p .707 .577 .707 r
F P
0 g
s
.35915 .73785 m .35385 .71959 L .33398 .7214 L p .707 .577 .707 r
F P
0 g
s
.29986 .56043 m .30868 .6162 L .32099 .62047 L p .707 .577 .707 r
F P
0 g
s
.33398 .7214 m .33928 .73966 L .35915 .73785 L p .707 .577 .707 r
F P
0 g
s
.49237 .67871 m .49767 .69697 L .51383 .68815 L p .707 .577 .707 r
F P
0 g
s
.51383 .68815 m .50853 .66989 L .49237 .67871 L p .707 .577 .707 r
F P
0 g
s
.7254 .61146 m .71658 .55569 L .74805 .55036 L p .707 .577 .707 r
F P
0 g
s
.71658 .55569 m .7254 .61146 L .6963 .61846 L p .707 .577 .707 r
F P
0 g
s
.69181 .73559 m .68651 .71733 L .70996 .70747 L p .707 .577 .707 r
F P
0 g
s
.74805 .55036 m .75687 .60613 L .7254 .61146 L p .707 .577 .707 r
F P
0 g
s
.70996 .70747 m .71525 .72573 L .69181 .73559 L p .707 .577 .707 r
F P
0 g
s
.82503 .67645 m .83033 .69471 L .80419 .69948 L p .707 .577 .707 r
F P
0 g
s
.80419 .69948 m .79889 .68122 L .82503 .67645 L p .707 .577 .707 r
F P
0 g
s
.33182 .69069 m .3223 .65396 L .31047 .65196 L p .707 .577 .707 r
F P
0 g
s
.70761 .68477 m .69809 .64804 L .72671 .63877 L p .707 .577 .707 r
F P
0 g
s
.7877 .62425 m .79722 .66099 L .76711 .66731 L p .707 .577 .707 r
F P
0 g
s
.76711 .66731 m .75759 .63057 L .7877 .62425 L p .707 .577 .707 r
F P
0 g
s
.31047 .65196 m .31999 .6887 L .33182 .69069 L p .707 .577 .707 r
F P
0 g
s
.49818 .60728 m .5077 .64402 L .51495 .63695 L p .707 .577 .707 r
F P
0 g
s
.51495 .63695 m .50543 .60022 L .49818 .60728 L p .707 .577 .707 r
F P
0 g
s
.72671 .63877 m .73623 .67551 L .70761 .68477 L p .707 .577 .707 r
F P
0 g
s
.30868 .6162 m .29986 .56043 L .29715 .55421 L p .707 .577 .707 r
F P
0 g
s
.73623 .67551 m .72671 .63877 L .75759 .63057 L p .707 .577 .707 r
F P
0 g
s
.71525 .72573 m .70996 .70747 L .73839 .69753 L p .707 .577 .707 r
F P
0 g
s
.75759 .63057 m .76711 .66731 L .73623 .67551 L p .707 .577 .707 r
F P
0 g
s
.33928 .73966 m .33398 .7214 L .32234 .72007 L p .707 .577 .707 r
F P
0 g
s
.79889 .68122 m .80419 .69948 L .77434 .70675 L p .707 .577 .707 r
F P
0 g
s
.77434 .70675 m .76904 .68848 L .79889 .68122 L p .707 .577 .707 r
F P
0 g
s
.73839 .69753 m .74369 .71579 L .71525 .72573 L p .707 .577 .707 r
F P
0 g
s
.32234 .72007 m .32763 .73834 L .33928 .73966 L p .707 .577 .707 r
F P
0 g
s
.49859 .52676 m .50741 .58253 L .50469 .5763 L p .707 .577 .707 r
F P
0 g
s
.50469 .5763 m .49587 .52053 L .49859 .52676 L p .707 .577 .707 r
F P
0 g
s
.50853 .66989 m .51383 .68815 L .52112 .68124 L p .707 .577 .707 r
F P
0 g
s
.52112 .68124 m .51582 .66298 L .50853 .66989 L p .707 .577 .707 r
F P
0 g
s
.29715 .55421 m .30597 .60998 L .30868 .6162 L p .707 .577 .707 r
F P
0 g
s
.74369 .71579 m .73839 .69753 L .76904 .68848 L p .707 .577 .707 r
F P
0 g
s
.76904 .68848 m .77434 .70675 L .74369 .71579 L p .707 .577 .707 r
F P
0 g
s
.31999 .6887 m .31047 .65196 L .30806 .6472 L p .707 .577 .707 r
F P
0 g
s
.30806 .6472 m .31758 .68393 L .31999 .6887 L p .707 .577 .707 r
F P
0 g
s
.50543 .60022 m .51495 .63695 L .51254 .63219 L p .707 .577 .707 r
F P
0 g
s
.51254 .63219 m .50302 .59546 L .50543 .60022 L p .707 .577 .707 r
F P
0 g
s
.30597 .60998 m .29715 .55421 L .3043 .54665 L p .707 .577 .707 r
F P
0 g
s
.32763 .73834 m .32234 .72007 L .32005 .71574 L p .707 .577 .707 r
F P
0 g
s
.32005 .71574 m .32534 .73401 L .32763 .73834 L p .707 .577 .707 r
F P
0 g
s
.51582 .66298 m .52112 .68124 L .51883 .67691 L p .707 .577 .707 r
F P
0 g
s
.51883 .67691 m .51353 .65864 L .51582 .66298 L p .707 .577 .707 r
F P
0 g
s
.49587 .52053 m .50469 .5763 L .49239 .57204 L p .707 .577 .707 r
F P
0 g
s
.49239 .57204 m .48357 .51627 L .49587 .52053 L p .707 .577 .707 r
F P
0 g
s
.3043 .54665 m .31312 .60242 L .30597 .60998 L p .707 .577 .707 r
F P
0 g
s
.31758 .68393 m .30806 .6472 L .31531 .64014 L p .707 .577 .707 r
F P
0 g
s
.31531 .64014 m .32483 .67687 L .31758 .68393 L p .707 .577 .707 r
F P
0 g
s
.50302 .59546 m .51254 .63219 L .50071 .63019 L p .707 .577 .707 r
F P
0 g
s
.50071 .63019 m .49118 .59346 L .50302 .59546 L p .707 .577 .707 r
F P
0 g
s
.31312 .60242 m .3043 .54665 L .3206 .53848 L p .707 .577 .707 r
F P
0 g
s
.32534 .73401 m .32005 .71574 L .32734 .70883 L p .707 .577 .707 r
F P
0 g
s
.32734 .70883 m .33263 .72709 L .32534 .73401 L p .707 .577 .707 r
F P
0 g
s
.48357 .51627 m .49239 .57204 L .47169 .57014 L p .707 .577 .707 r
F P
0 g
s
.47169 .57014 m .46287 .51437 L .48357 .51627 L p .707 .577 .707 r
F P
0 g
s
.51353 .65864 m .51883 .67691 L .50718 .67558 L p .707 .577 .707 r
F P
0 g
s
.50718 .67558 m .50189 .65732 L .51353 .65864 L p .707 .577 .707 r
F P
0 g
s
.3206 .53848 m .32942 .59425 L .31312 .60242 L p .707 .577 .707 r
F P
0 g
s
.32483 .67687 m .31531 .64014 L .33151 .63147 L p .707 .577 .707 r
F P
0 g
s
.32942 .59425 m .3206 .53848 L .34447 .53051 L p .707 .577 .707 r
F P
0 g
s
.33151 .63147 m .34103 .6682 L .32483 .67687 L p .707 .577 .707 r
F P
0 g
s
.49118 .59346 m .50071 .63019 L .48061 .63116 L p .707 .577 .707 r
F P
0 g
s
.48061 .63116 m .47109 .59442 L .49118 .59346 L p .707 .577 .707 r
F P
0 g
s
.46287 .51437 m .47169 .57014 L .44464 .5708 L p .707 .577 .707 r
F P
0 g
s
.44464 .5708 m .43581 .51503 L .46287 .51437 L p .707 .577 .707 r
F P
0 g
s
.33263 .72709 m .32734 .70883 L .3435 .70001 L p .707 .577 .707 r
F P
0 g
s
.34447 .53051 m .35329 .58628 L .32942 .59425 L p .707 .577 .707 r
F P
0 g
s
.3435 .70001 m .34879 .71827 L .33263 .72709 L p .707 .577 .707 r
F P
0 g
s
.50189 .65732 m .50718 .67558 L .48732 .6774 L p .707 .577 .707 r
F P
0 g
s
.48732 .6774 m .48202 .65913 L .50189 .65732 L p .707 .577 .707 r
F P
0 g
s
.35329 .58628 m .34447 .53051 L .37357 .52351 L p .707 .577 .707 r
F P
0 g
s
.34103 .6682 m .33151 .63147 L .35508 .62204 L p .707 .577 .707 r
F P
0 g
s
.43581 .51503 m .44464 .5708 L .41386 .57395 L p .707 .577 .707 r
F P
0 g
s
.41386 .57395 m .40504 .51818 L .43581 .51503 L p .707 .577 .707 r
F P
0 g
s
.47109 .59442 m .48061 .63116 L .45421 .63499 L p .707 .577 .707 r
F P
0 g
s
.45421 .63499 m .44469 .59825 L .47109 .59442 L p .707 .577 .707 r
F P
0 g
s
.35508 .62204 m .3646 .65877 L .34103 .6682 L p .707 .577 .707 r
F P
0 g
s
.38239 .57928 m .37357 .52351 L .40504 .51818 L p .707 .577 .707 r
F P
0 g
s
.37357 .52351 m .38239 .57928 L .35329 .58628 L p .707 .577 .707 r
F P
0 g
s
.40504 .51818 m .41386 .57395 L .38239 .57928 L p .707 .577 .707 r
F P
0 g
s
.34879 .71827 m .3435 .70001 L .36694 .69015 L p .707 .577 .707 r
F P
0 g
s
.36694 .69015 m .37224 .70841 L .34879 .71827 L p .707 .577 .707 r
F P
0 g
s
.48202 .65913 m .48732 .6774 L .46118 .68217 L p .707 .577 .707 r
F P
0 g
s
.46118 .68217 m .45588 .6639 L .48202 .65913 L p .707 .577 .707 r
F P
0 g
s
.3646 .65877 m .35508 .62204 L .3837 .61277 L p .707 .577 .707 r
F P
0 g
s
.44469 .59825 m .45421 .63499 L .4241 .64131 L p .707 .577 .707 r
F P
0 g
s
.4241 .64131 m .41458 .60458 L .44469 .59825 L p .707 .577 .707 r
F P
0 g
s
.3837 .61277 m .39322 .64951 L .3646 .65877 L p .707 .577 .707 r
F P
0 g
s
.39322 .64951 m .3837 .61277 L .41458 .60458 L p .707 .577 .707 r
F P
0 g
s
.41458 .60458 m .4241 .64131 L .39322 .64951 L p .707 .577 .707 r
F P
0 g
s
.37224 .70841 m .36694 .69015 L .39538 .68021 L p .707 .577 .707 r
F P
0 g
s
.45588 .6639 m .46118 .68217 L .43132 .68943 L p .707 .577 .707 r
F P
0 g
s
.43132 .68943 m .42603 .67117 L .45588 .6639 L p .707 .577 .707 r
F P
0 g
s
.39538 .68021 m .40068 .69847 L .37224 .70841 L p .707 .577 .707 r
F P
0 g
s
.40068 .69847 m .39538 .68021 L .42603 .67117 L p .707 .577 .707 r
F P
0 g
s
.42603 .67117 m .43132 .68943 L .40068 .69847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
SGoo5000O7oo0024Ool9000DFUH7001eOol0081oo`@0009JEP03001JEUYF01mJEP<0079oo`00O7oo
10001UYF00<005YFFUH08UYF00<007ooOol0Kgoo001gOol5000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool0075oo`H0009JEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06moo`00KGoo1000
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Kgoo001[Ool200000eYF001JEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1_Ool006Qoo`<000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06moo`00IWoo0P001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00L7oo001SOol30009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP04FUI`Ool0065oo`800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEW1oo`00Ggoo0P00
0eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KWoo001MOol20005FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005aoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Kgoo001KOol0
0`00FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06eoo`00G7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo
001LOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001^Ool005aoo`03001JEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006ioo`00G7oo00@005YFFUH000IJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH2001^Ool005aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVioo`00G7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVioo`00GGoo00<0
05YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`03001JEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP03001JEUYF009JEP8006eoo`00GGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001]Ool005eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00KGoo001MOol01000
FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFKGoo001MOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001/Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006aoo`00GWoo00@0
05YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001/Ool005ioo`04001JEUYF0006FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUI/Ool005moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00Ggoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001O
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EV]oo`00H7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JWoo001POol00`00
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001ZOol0061oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00JWoo001POol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Yoo`00H7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Qoo`00H7oo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Qoo`00
HGoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00<005YF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Qo
o`00HWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo
00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0007FUH0
0`00FUIJEP06FUHB0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`03001JEP0000MJEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Eoo`00
IGoo00<005YFFUH01`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001UOol0
06Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001UOol0065oo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol005moo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1SOol005eoo`80009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00FWoo0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF0P00I7oo001HOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0087oo4P00<Woo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol05goo1`0015YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol04goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001DOol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80011oo`@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8000aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYF001JEP0]Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20008Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUIJEP00FUH0;Goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUIJEP00FUH0;Goo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001EOol01000FUIJ
EP000eYF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004
FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001J
EP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000AJEP04001JEP00
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00000eYF0P0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF1`000UYF00@005YF000000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000/
Ool005Ioo`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH9
0003FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002aoo`00EWoo0eYF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF
001JEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUHB0002
FUH2000[Ool0055oo`D00005FUH00000FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH30000
0eYF001JEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP05FUH01000FUIJEUYF1000:goo001:Ool70003
FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF0`0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002]oo`00AWoo10000UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00@0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo0011Ool50006FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH0
05YF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002aoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH>000/
Ool003Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<000UJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YF
FUH00eYF00@005YFFUH002aoo`00=Woo0`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00AJEP80009JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP07FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:goo000cOol30004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF3@001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00D000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0035o
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEP03001JEUYF
009JEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005
FUH00`00FUIJEP05FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00:Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YFFUH00UYF00<005YFFUH01EYF00H005YF0000
05YF0009FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<0009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000ZOol002eoo`04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YF000005YF0005FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP@0009J
EP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF000ZOol002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol09goo000]Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF1`00
0UYF00@005YF000000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
009JEP@002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF2@001EYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP@000MJEP03001JEUYF00EJEP03001JEUYF009JEP8002Yoo`00;Woo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00AJEP03001JEP0000AJEP<000MJ
EP03001JEUYF00IJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`0YOol002ioo`04001JEUYF0003FUH00`00FUIJEP05FUH0
0`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00AJEP80
0003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002]oo`00;Woo00@005YFFUH000AJEP03001JEUYF00=J
EPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00AJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00MJEP04001JEUYFFUH>0004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF1000
25YF00<005YFFUH01UYF00<005YF00001P000UYF00@005YF000002Uoo`00;Woo00@005YFFUH000AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH50003FUH20005FUH0
1000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP04001JEUYFFUH60003FUH00`00
FUIJEP03FUH00`00FUIJEP02000XOol002ioo`04001JEUYF0004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF00EJEP06001J
EP00001JEP002EYF00<005YFFUH00UYF0`001EYF0`0000=JEP00FUH01EYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF10001eYF
00<005YFFUH01eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00:7oo000^
Ool01@00FUIJEUYF00000eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEP0000800003
FUH005YF009JEP<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000XOol002mo
o`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP0600000eYF0000000<0007FUH00`00FUIJEP04FUH40005FUH300000eYF001JEP05FUH01000FUIJ
EUYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002Moo`00;goo0eYF0P001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
1eYF00<005YFFUH010001eYF0`000eYF00<005YFFUH01EYF0`002EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH015YF0P000UYF00@005YFFUIJEP<000MJEP03001JEUYF00EJEP<000EJEP03
001JEUYF00IJEP03001JEUYF009JEPd002Moo`00;goo00EJEP00001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH01EYF10000eYF00<005YFFUH00UYF0`001UYF00<005YFFUH015YF0P0035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF0080009JEP03001JEUYF00IJEP04
001JEUYFFUH30008FUH00`00FUIJEP05FUH600001Goo000005YF00001EYF00<005YF00009goo000_
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH400000eYF001JEP08FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00UYF0`001UYF00<005YF00000P0000=JEP00
FUH01eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000EJEP03001JEUYF00EJEP06001JEP00001JEP002UYF00<005YFFUH0
10001Goo0P000eYF00<005YFFUH00eYF0P00:7oo000_Ool20003FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF0000
0P000UYF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP06FUH40006Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0
031oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP80009oo`04001JEUYF0002FUH30008FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP02FUH01000FUIJEUYF0`001eYF00<005YFFUH00eYF0`0027oo0P0000=J
EP00FUH01UYF00<005YFFUH00P00:Woo000bOol50003FUH01000FUIJEUYF100015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000P0015YF00<005YFFUH00UYF10000Woo00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF0`0000=JEP00FUH025YF00<005YF00000P00
27oo0`0015YF00<005YFFUH015YF0`00;7oo000gOol80008FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH20002FUH00`00FUIJEP03FUH01000FUH000000UYF1P001UYF00<005YFFUH01EYF100000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
000020001EYF00<005YFFUH01EYF0`0027oo0`001eYF00<005YFFUH00eYF0P00;Woo000iOol30000
0eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUIJEUYF1`000eYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEPD000IJEP03001JEUYF00=JEPD000Eo
o`<00003FUH005YF00QJEP03001JEP000080031oo`00=goo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01eYF0P000UYF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP05FUH00`00FUH000070002Ool3
0005FUH00`00FUIJEP05FUH3000cOol003Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP@0009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0004FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP03FUH2000fOol003=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000005FUH01000
FUIJEUYF100017oo100000=JEP00FUH02EYF00<005YF00000P00>7oo000bOol00`00FUIJEP03FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50008FUH200000eYF001JEP05FUH01000
FUIJEUYF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00UYF00@005YF0000
009JEPH000IJEP03001JEUYF00IJEP<003]oo`00<Goo0P001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH010001EYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF1P0017oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00AJEP80009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00=JEP<003ioo`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000QJEP03
001JEUYF00IJEP03001JEP0000D00003FUH0000000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEUYF001JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP000080045o
o`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8000Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2
0002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30014Ool0035oo`03001JEP0000AJEP03
001JEUYF00EJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000]oo`=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEQ8000AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00@004Moo`00<Goo00<005YF
000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo0eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH05UYF00@005YFFUIJEPH000MJEP03001JEUYF00MJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF009JEPH004]oo`00<Goo00@005YFFUH000AJEP04001J
EUYFFUH20003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP02FUH00`00FUIJEP020003Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH055YF1P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0000=JEP00FUH00UYF2000D7oo000a
Ool01000FUIJEP0015YF00@005YF000000EJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00
001JEP001eYF00<005YFFUH00eYF00@005YFFUH000=oo`04001JEUYF0007FUH00`00FUIJEP0GFUH6
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000050004FUH2001A
Ool0039oo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF0080009oo`05001JEUYFFUH00006FUH00`00FUIJEP0A
FUH7000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00Oomoo`1@Ool0039oo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009oo`05001JEUYFFUH00006FUH00`00FUIJEP0;FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0005=oo`00<Woo
00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01UYF10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF300000=oo`00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P0035YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00002`00D7oo000b
Ool01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH00UYF10001UYF00<005YFFUH01eYF
00<005YF00000`0000=oo`0000001EYF00@005YFFUH0009oo`=JEP03001JEUYF00]JEP8000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80
009JEP03001JEUYF00=JEP03001JEUYF008004moo`00<goo00@005YFFUH000EJEP03001JEUYF00EJ
EP06001JEP00001JEP002EYF00<005YFFUH015YF10000Woo0`0000=JEP00FUH01EYF0P000goo0eYF
00<005YFFUH02EYF0P001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00P00Cgoo000c
Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEUYF00@000=o
o`<000EJEP03001JEUYF00=JEP03001oogoo009oo`04001JEUYF0009FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P001EYF00<005YF
FUH00eYF00@005YFFUH004moo`00<goo40001eYF00<005YFFUH015YF1@001Goo0P0000=JEP00FUH0
1EYF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000008FUH00`00FUIJEP02FUH00`00FUIJEP02
001>Ool003ioo`800003FUH005YF00MJEP03001JEUYF00@000Moo`<000=JEP03001JEUYF00EJEP<0
00Moo`03001JEUYF00EJEP8000=JEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP<0009JEP03001JEUYF00AJEP/004ioo`00?7oo0P000eYF00<0
05YFFUH01EYF100027oo0`001UYF00<005YFFUH015YF0P002Goo00<005YFFUH00eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF0P00
1EYF00<005YFFUH0100000=oo`0000001EYF00<005YF0000CWoo000jOol20006FUH00`00FUIJEP02
FUH20009Ool300000eYF001JEP07FUH01000FUIJEUYF0P0037oo0eYF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEP<000IJEP@00003Ool0
000000800003FUH005YF00AJEP8004moo`00>7oo0`001eYF00<005YF00000P0027oo0`0015YF00<0
05YFFUH01UYF00@005YF000000ioo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH000000UYF00<005YFFUH010000Woo0`001EYF
00<005YFFUH00eYF00<007ooOol0CWoo000fOol20003FUH00`00FUIJEP04FUH20008Ool30008FUH0
0`00FUIJEP04FUH3000@Ool00eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0GFUH00`00FUIJ
EP07FUH40002FUH50004Ool200000eYF001JEP06FUH00`00FUIJEP02001AOol003Aoo`<000AJEP03
001JEUYF009JEP8000Ioo`@00003FUH005YF00QJEP03001JEUYF00@001=oo`8000]JEP03001JEUYF
00QJEP03001JEUYF01MJEP04001JEUYFFUH60002FUH40006Ool30004FUH00`00FUIJEP04FUH3001C
Ool003=oo`04001JEUYF0005FUH01000FUH000000Woo1P001UYF00<005YFFUH01EYF10005goo0P00
15YF00<005YFFUH07EYF00<005YFFUH01eYF1P0015YF10001goo0`001eYF00<005YFFUH015YF00<0
07ooOol0Dgoo000cOol01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0077oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YF
FUIJEPH0009JEP03001JEUYF00=JEP@000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEP8005Io
o`00=7oo00D005YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
01ioo`<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEPL00003FUH005YF00IJ
EP03001JEP0000L0009oo`<000EJEP03001JEUYF00IJEP04001JEP00001HOol003Aoo`03001JEUYF
008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@002Aoo`H000AJEP03001JEUYF00QJEP04001J
EUYFFUH60003Ool20003FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP05FUH3001JOol0
03Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@002iooa<000Qoo`8000EJEP04
001JEUYFFUH20006Ool6000:FUH00`00FUIJEP04001MOol003Eoo`04001JEUYF0006FUH01000FUIJ
EUYF1P00C7oo00@005YFFUH000AJEP04001JEP000002Ool6000015YF000000000UYF00<005YFFUH0
1UYF1000HGoo000eOol20002FUH01000FUIJEUYF1P00DWoo00@005YFFUH000AJEPH000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP<006Eoo`00=Woo1`00F7oo00H005YFFUIJEP00FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00002001XOol009Ioo`03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP<006]oo`00UWoo10001UYF00<005YFFUH01EYF00<005YFFUH01000
KWoo002FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6001bOol009Ioo`80009JEP04001J
EUYFFUH7001hOol009Moo`L007moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60532 .74278 m .5965 .68701 L .56573 .69016 L p .707 .577 .707 r
F P
0 g
s
.5965 .68701 m .60532 .74278 L .63679 .73744 L p .707 .577 .707 r
F P
0 g
s
.63679 .73744 m .62797 .68167 L .5965 .68701 L p .707 .577 .707 r
F P
0 g
s
.62797 .68167 m .63679 .73744 L .66589 .73045 L p .707 .577 .707 r
F P
0 g
s
.66589 .73045 m .65707 .67468 L .62797 .68167 L p .707 .577 .707 r
F P
0 g
s
.57455 .74593 m .56573 .69016 L .53867 .69082 L p .707 .577 .707 r
F P
0 g
s
.56573 .69016 m .57455 .74593 L .60532 .74278 L p .707 .577 .707 r
F P
0 g
s
.65707 .67468 m .66589 .73045 L .68976 .72248 L p .707 .577 .707 r
F P
0 g
s
.68976 .72248 m .68094 .66671 L .65707 .67468 L p .707 .577 .707 r
F P
0 g
s
.61424 .79761 m .60471 .76088 L .5746 .7672 L p .707 .577 .707 r
F P
0 g
s
.60471 .76088 m .61424 .79761 L .64511 .78942 L p .707 .577 .707 r
F P
0 g
s
.64511 .78942 m .63559 .75268 L .60471 .76088 L p .707 .577 .707 r
F P
0 g
s
.63559 .75268 m .64511 .78942 L .67374 .78015 L p .707 .577 .707 r
F P
0 g
s
.67374 .78015 m .66421 .74342 L .63559 .75268 L p .707 .577 .707 r
F P
0 g
s
.53867 .69082 m .54749 .74659 L .57455 .74593 L p .707 .577 .707 r
F P
0 g
s
.5746 .7672 m .58412 .80394 L .61424 .79761 L p .707 .577 .707 r
F P
0 g
s
.54749 .74659 m .53867 .69082 L .51797 .68892 L p .707 .577 .707 r
F P
0 g
s
.58412 .80394 m .5746 .7672 L .54821 .77103 L p .707 .577 .707 r
F P
0 g
s
.62094 .83517 m .61565 .81691 L .58579 .82417 L p .707 .577 .707 r
F P
0 g
s
.61565 .81691 m .62094 .83517 L .65159 .82613 L p .707 .577 .707 r
F P
0 g
s
.65159 .82613 m .64629 .80786 L .61565 .81691 L p .707 .577 .707 r
F P
0 g
s
.66421 .74342 m .67374 .78015 L .6973 .77072 L p .707 .577 .707 r
F P
0 g
s
.6973 .77072 m .68778 .73399 L .66421 .74342 L p .707 .577 .707 r
F P
0 g
s
.64629 .80786 m .65159 .82613 L .68003 .81619 L p .707 .577 .707 r
F P
0 g
s
.68003 .81619 m .67473 .79792 L .64629 .80786 L p .707 .577 .707 r
F P
0 g
s
.58579 .82417 m .59109 .84243 L .62094 .83517 L p .707 .577 .707 r
F P
0 g
s
.54821 .77103 m .55773 .80777 L .58412 .80394 L p .707 .577 .707 r
F P
0 g
s
.68094 .66671 m .68976 .72248 L .70607 .71431 L p .707 .577 .707 r
F P
0 g
s
.70607 .71431 m .69724 .65854 L .68094 .66671 L p .707 .577 .707 r
F P
0 g
s
.51797 .68892 m .5268 .74469 L .54749 .74659 L p .707 .577 .707 r
F P
0 g
s
.59109 .84243 m .58579 .82417 L .55966 .82894 L p .707 .577 .707 r
F P
0 g
s
.67473 .79792 m .68003 .81619 L .70347 .80632 L p .707 .577 .707 r
F P
0 g
s
.70347 .80632 m .69818 .78806 L .67473 .79792 L p .707 .577 .707 r
F P
0 g
s
.55966 .82894 m .56495 .8472 L .59109 .84243 L p .707 .577 .707 r
F P
0 g
s
.55773 .80777 m .54821 .77103 L .52811 .77199 L p .707 .577 .707 r
F P
0 g
s
.68778 .73399 m .6973 .77072 L .7135 .76205 L p .707 .577 .707 r
F P
0 g
s
.7135 .76205 m .70398 .72532 L .68778 .73399 L p .707 .577 .707 r
F P
0 g
s
.5268 .74469 m .51797 .68892 L .50567 .68465 L p .707 .577 .707 r
F P
0 g
s
.52811 .77199 m .53763 .80873 L .55773 .80777 L p .707 .577 .707 r
F P
0 g
s
.56495 .8472 m .55966 .82894 L .53979 .83075 L p .707 .577 .707 r
F P
0 g
s
.53979 .83075 m .54509 .84901 L .56495 .8472 L p .707 .577 .707 r
F P
0 g
s
.69724 .65854 m .70607 .71431 L .71321 .70674 L p .707 .577 .707 r
F P
0 g
s
.71321 .70674 m .70439 .65097 L .69724 .65854 L p .707 .577 .707 r
F P
0 g
s
.69818 .78806 m .70347 .80632 L .71963 .79751 L p .707 .577 .707 r
F P
0 g
s
.71963 .79751 m .71434 .77924 L .69818 .78806 L p .707 .577 .707 r
F P
0 g
s
.50567 .68465 m .51449 .74042 L .5268 .74469 L p .707 .577 .707 r
F P
0 g
s
.53763 .80873 m .52811 .77199 L .51627 .77 L p .707 .577 .707 r
F P
0 g
s
.51627 .77 m .5258 .80673 L .53763 .80873 L p .707 .577 .707 r
F P
0 g
s
.70398 .72532 m .7135 .76205 L .72075 .75499 L p .707 .577 .707 r
F P
0 g
s
.72075 .75499 m .71123 .71825 L .70398 .72532 L p .707 .577 .707 r
F P
0 g
s
.51449 .74042 m .50567 .68465 L .50296 .67843 L p .707 .577 .707 r
F P
0 g
s
.54509 .84901 m .53979 .83075 L .52814 .82943 L p .707 .577 .707 r
F P
0 g
s
.52814 .82943 m .53344 .84769 L .54509 .84901 L p .707 .577 .707 r
F P
0 g
s
.71434 .77924 m .71963 .79751 L .72693 .79059 L p .707 .577 .707 r
F P
0 g
s
.72693 .79059 m .72163 .77233 L .71434 .77924 L p .707 .577 .707 r
F P
0 g
s
.70439 .65097 m .71321 .70674 L .7105 .70052 L p .707 .577 .707 r
F P
0 g
s
.7105 .70052 m .70168 .64475 L .70439 .65097 L p .707 .577 .707 r
F P
0 g
s
.50296 .67843 m .51178 .7342 L .51449 .74042 L p .707 .577 .707 r
F P
0 g
s
.5258 .80673 m .51627 .77 L .51387 .76524 L p .707 .577 .707 r
F P
0 g
s
.51387 .76524 m .52339 .80197 L .5258 .80673 L p .707 .577 .707 r
F P
0 g
s
.71123 .71825 m .72075 .75499 L .71834 .75023 L p .707 .577 .707 r
F P
0 g
s
.71834 .75023 m .70882 .71349 L .71123 .71825 L p .707 .577 .707 r
F P
0 g
s
.53344 .84769 m .52814 .82943 L .52585 .8251 L p .707 .577 .707 r
F P
0 g
s
.51178 .7342 m .50296 .67843 L .5101 .67087 L p .707 .577 .707 r
F P
0 g
s
.52585 .8251 m .53115 .84336 L .53344 .84769 L p .707 .577 .707 r
F P
0 g
s
.72163 .77233 m .72693 .79059 L .72464 .78626 L p .707 .577 .707 r
F P
0 g
s
.72464 .78626 m .71934 .768 L .72163 .77233 L p .707 .577 .707 r
F P
0 g
s
.5101 .67087 m .51892 .72664 L .51178 .7342 L p .707 .577 .707 r
F P
0 g
s
.52339 .80197 m .51387 .76524 L .52112 .75817 L p .707 .577 .707 r
F P
0 g
s
.52112 .75817 m .53064 .79491 L .52339 .80197 L p .707 .577 .707 r
F P
0 g
s
.53064 .79491 m .52112 .75817 L .53732 .7495 L p .707 .577 .707 r
F P
0 g
s
.53182 .81586 m .45259 .31224 L .40914 .31665 L p .707 .577 .707 r
F P
0 g
s
.51892 .72664 m .5101 .67087 L .52641 .6627 L p .707 .577 .707 r
F P
0 g
s
.52641 .6627 m .53523 .71847 L .51892 .72664 L p .707 .577 .707 r
F P
0 g
s
.53732 .7495 m .54684 .78624 L .53064 .79491 L p .707 .577 .707 r
F P
0 g
s
.53523 .71847 m .52641 .6627 L .55028 .65473 L p .707 .577 .707 r
F P
0 g
s
.53844 .83645 m .53314 .81819 L .5493 .80937 L p .707 .577 .707 r
F P
0 g
s
.5493 .80937 m .5546 .82763 L .53844 .83645 L p .707 .577 .707 r
F P
0 g
s
.55028 .65473 m .5591 .7105 L .53523 .71847 L p .707 .577 .707 r
F P
0 g
s
.54684 .78624 m .53732 .7495 L .56088 .74007 L p .707 .577 .707 r
F P
0 g
s
.56088 .74007 m .5704 .77681 L .54684 .78624 L p .707 .577 .707 r
F P
0 g
s
.5546 .82763 m .5493 .80937 L .57275 .7995 L p .707 .577 .707 r
F P
0 g
s
.57275 .7995 m .57805 .81777 L .5546 .82763 L p .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .57275 .7995 L .5946 .79187 L p .707 .577 .707 r
F P
0 g
s
.5946 .79187 m .60119 .78957 L p .5964 .7954 L .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .5946 .79187 L .5964 .7954 L .707 .577 .707 r
F
.53182 .81586 m .57626 .80836 L p .55057 .7053 L F P
0 g
s
.45259 .31224 m .49824 .60244 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.49824 .60244 m .53182 .81586 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.5591 .7105 m .55028 .65473 L .57937 .64773 L p .707 .577 .707 r
F P
0 g
s
.57937 .64773 m .58819 .7035 L .5591 .7105 L p .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .56088 .74007 L .5794 .73408 L p .707 .577 .707 r
F P
0 g
s
.5794 .73408 m .58951 .73081 L p .58381 .74451 L .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .5794 .73408 L .58381 .74451 L .707 .577 .707 r
F
.49703 .30475 m .45259 .31224 L p .52665 .60934 L F P
0 g
s
.58951 .73081 m .59903 .76754 L .5704 .77681 L p .707 .577 .707 r
F P
0 g
s
.57626 .80836 m .55578 .67824 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.55578 .67824 m .49703 .30475 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.58819 .7035 m .57937 .64773 L .61085 .6424 L p .707 .577 .707 r
F P
0 g
s
.61085 .6424 m .61967 .69817 L .58819 .7035 L p .707 .577 .707 r
F P
0 g
s
.59903 .76754 m .59446 .74991 L p .62038 .72261 L .707 .577 .707 r
F P
0 g
s
.59446 .74991 m .58951 .73081 L .59261 .72998 L p .707 .577 .707 r
F P
0 g
s
.59261 .72998 m .62038 .72261 L p .59446 .74991 L .707 .577 .707 r
F P
0 g
s
.64162 .63925 m .65044 .69502 L .61967 .69817 L p .707 .577 .707 r
F P
0 g
s
.61967 .69817 m .61085 .6424 L .64162 .63925 L p .707 .577 .707 r
F P
0 g
s
.65049 .71629 m .66002 .75303 L .62991 .75935 L p .707 .577 .707 r
F P
0 g
s
.62991 .75935 m .62038 .72261 L .65049 .71629 L p .707 .577 .707 r
F P
0 g
s
.62038 .72261 m .62991 .75935 L .59903 .76754 L p .707 .577 .707 r
F P
0 g
s
.66169 .77326 m .66698 .79152 L .63713 .79878 L p .707 .577 .707 r
F P
0 g
s
.63713 .79878 m .63183 .78052 L .66169 .77326 L p .707 .577 .707 r
F P
0 g
s
.60649 .80783 m .60119 .78957 L .63183 .78052 L p .707 .577 .707 r
F P
0 g
s
.63183 .78052 m .63713 .79878 L .60649 .80783 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .65104 .78728 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.53811 .2949 m .57257 .51394 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.57257 .51394 m .61734 .79851 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.60119 .78957 m .60649 .80783 L .57805 .81777 L p .707 .577 .707 r
F P
0 g
s
.49703 .30475 m .57626 .80836 L .61734 .79851 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .53811 .2949 L .49703 .30475 L p .707 .577 .707 r
F P
0 g
s
.70168 .64475 m .7105 .70052 L .69819 .69626 L p .707 .577 .707 r
F P
0 g
s
.69819 .69626 m .68937 .64049 L .70168 .64475 L p .707 .577 .707 r
F P
0 g
s
.48837 .82027 m .40914 .31665 L .37093 .31754 L p .707 .577 .707 r
F P
0 g
s
.40914 .31665 m .48837 .82027 L .53182 .81586 L p .707 .577 .707 r
F P
0 g
s
.26231 .7106 m .25349 .65483 L .22272 .65798 L p .707 .577 .707 r
F P
0 g
s
.25349 .65483 m .26231 .7106 L .29379 .70526 L p .707 .577 .707 r
F P
0 g
s
.29379 .70526 m .28496 .64949 L .25349 .65483 L p .707 .577 .707 r
F P
0 g
s
.28496 .64949 m .29379 .70526 L .32288 .69827 L p .707 .577 .707 r
F P
0 g
s
.32288 .69827 m .31406 .6425 L .28496 .64949 L p .707 .577 .707 r
F P
0 g
s
.65104 .78728 m .57181 .28366 L .53811 .2949 L p .707 .577 .707 r
F P
0 g
s
.70882 .71349 m .71834 .75023 L .70651 .74823 L p .707 .577 .707 r
F P
0 g
s
.70651 .74823 m .69699 .7115 L .70882 .71349 L p .707 .577 .707 r
F P
0 g
s
.53115 .84336 m .52585 .8251 L .53314 .81819 L p .707 .577 .707 r
F P
0 g
s
.23154 .71375 m .22272 .65798 L .19566 .65864 L p .707 .577 .707 r
F P
0 g
s
.22272 .65798 m .23154 .71375 L .26231 .7106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.53314 .81819 m .53844 .83645 L .53115 .84336 L p .707 .577 .707 r
F P
0 g
s
.31406 .6425 m .32288 .69827 L .34675 .6903 L p .707 .577 .707 r
F P
0 g
s
.34675 .6903 m .33793 .63453 L .31406 .6425 L p .707 .577 .707 r
F P
0 g
s
.71934 .768 m .72464 .78626 L .71299 .78494 L p .707 .577 .707 r
F P
0 g
s
.71299 .78494 m .70769 .76668 L .71934 .768 L p .707 .577 .707 r
F P
0 g
s
.68937 .64049 m .69819 .69626 L .6775 .69436 L p .707 .577 .707 r
F P
0 g
s
.6775 .69436 m .66868 .63859 L .68937 .64049 L p .707 .577 .707 r
F P
0 g
s
.27123 .77162 m .2617 .73488 L .23159 .7412 L p .707 .577 .707 r
F P
0 g
s
.2617 .73488 m .27123 .77162 L .3021 .76342 L p .707 .577 .707 r
F P
0 g
s
.3021 .76342 m .29258 .72668 L .2617 .73488 L p .707 .577 .707 r
F P
0 g
s
.45016 .82116 m .37093 .31754 L .34171 .31483 L p .707 .577 .707 r
F P
0 g
s
.37093 .31754 m .45016 .82116 L .48837 .82027 L p .707 .577 .707 r
F P
0 g
s
.19566 .65864 m .20448 .71441 L .23154 .71375 L p .707 .577 .707 r
F P
0 g
s
.29258 .72668 m .3021 .76342 L .33073 .75415 L p .707 .577 .707 r
F P
0 g
s
.33073 .75415 m .32121 .71742 L .29258 .72668 L p .707 .577 .707 r
F P
0 g
s
.20448 .71441 m .19566 .65864 L .17497 .65674 L p .707 .577 .707 r
F P
0 g
s
.23159 .7412 m .24112 .77794 L .27123 .77162 L p .707 .577 .707 r
F P
0 g
s
.24112 .77794 m .23159 .7412 L .2052 .74503 L p .707 .577 .707 r
F P
0 g
s
.66868 .63859 m .6775 .69436 L .65044 .69502 L p .707 .577 .707 r
F P
0 g
s
.65044 .69502 m .64162 .63925 L .66868 .63859 L p .707 .577 .707 r
F P
0 g
s
.67689 .71246 m .68641 .74919 L .66002 .75303 L p .707 .577 .707 r
F P
0 g
s
.66002 .75303 m .65049 .71629 L .67689 .71246 L p .707 .577 .707 r
F P
0 g
s
.66698 .79152 m .66169 .77326 L .68783 .76849 L p .707 .577 .707 r
F P
0 g
s
.57181 .28366 m .65104 .78728 L .67406 .77575 L p .707 .577 .707 r
F P
0 g
s
.67406 .77575 m .59483 .27214 L .57181 .28366 L p .707 .577 .707 r
F P
0 g
s
.32121 .71742 m .33073 .75415 L .35429 .74472 L p .707 .577 .707 r
F P
0 g
s
.35429 .74472 m .34477 .70799 L .32121 .71742 L p .707 .577 .707 r
F P
0 g
s
.27794 .81785 m .27264 .79959 L .24279 .80685 L p .707 .577 .707 r
F P
0 g
s
.27264 .79959 m .27794 .81785 L .30858 .80881 L p .707 .577 .707 r
F P
0 g
s
.30858 .80881 m .30328 .79055 L .27264 .79959 L p .707 .577 .707 r
F P
0 g
s
.33793 .63453 m .34675 .6903 L .36306 .68213 L p .707 .577 .707 r
F P
0 g
s
.36306 .68213 m .35424 .62636 L .33793 .63453 L p .707 .577 .707 r
F P
0 g
s
.69699 .7115 m .70651 .74823 L .68641 .74919 L p .707 .577 .707 r
F P
0 g
s
.68641 .74919 m .67689 .71246 L .69699 .7115 L p .707 .577 .707 r
F P
0 g
s
.30328 .79055 m .30858 .80881 L .33702 .79887 L p .707 .577 .707 r
F P
0 g
s
.33702 .79887 m .33172 .78061 L .30328 .79055 L p .707 .577 .707 r
F P
0 g
s
.2052 .74503 m .21472 .78177 L .24112 .77794 L p .707 .577 .707 r
F P
0 g
s
.24279 .80685 m .24808 .82511 L .27794 .81785 L p .707 .577 .707 r
F P
0 g
s
.17497 .65674 m .18379 .71251 L .20448 .71441 L p .707 .577 .707 r
F P
0 g
s
.24808 .82511 m .24279 .80685 L .21665 .81162 L p .707 .577 .707 r
F P
0 g
s
.70769 .76668 m .71299 .78494 L .69312 .78675 L p .707 .577 .707 r
F P
0 g
s
.69312 .78675 m .68783 .76849 L .70769 .76668 L p .707 .577 .707 r
F P
0 g
s
.33172 .78061 m .33702 .79887 L .36046 .78901 L p .707 .577 .707 r
F P
0 g
s
.36046 .78901 m .35517 .77075 L .33172 .78061 L p .707 .577 .707 r
F P
0 g
s
.21665 .81162 m .22194 .82989 L .24808 .82511 L p .707 .577 .707 r
F P
0 g
s
.21472 .78177 m .2052 .74503 L .1851 .746 L p .707 .577 .707 r
F P
0 g
s
.18379 .71251 m .17497 .65674 L .16266 .65247 L p .707 .577 .707 r
F P
0 g
s
.34477 .70799 m .35429 .74472 L .37049 .73605 L p .707 .577 .707 r
F P
0 g
s
.37049 .73605 m .36097 .69932 L .34477 .70799 L p .707 .577 .707 r
F P
0 g
s
.1851 .746 m .19462 .78273 L .21472 .78177 L p .707 .577 .707 r
F P
0 g
s
.42094 .81845 m .34171 .31483 L .32433 .30878 L p .707 .577 .707 r
F P
0 g
s
.34171 .31483 m .42094 .81845 L .45016 .82116 L p .707 .577 .707 r
F P
0 g
s
.35424 .62636 m .36306 .68213 L .3702 .67456 L p .707 .577 .707 r
F P
0 g
s
.3702 .67456 m .36138 .61879 L .35424 .62636 L p .707 .577 .707 r
F P
0 g
s
.22194 .82989 m .21665 .81162 L .19678 .81344 L p .707 .577 .707 r
F P
0 g
s
.16266 .65247 m .17148 .70824 L .18379 .71251 L p .707 .577 .707 r
F P
0 g
s
.19678 .81344 m .20208 .8317 L .22194 .82989 L p .707 .577 .707 r
F P
0 g
s
.35517 .77075 m .36046 .78901 L .37663 .78019 L p .707 .577 .707 r
F P
0 g
s
.37663 .78019 m .37133 .76193 L .35517 .77075 L p .707 .577 .707 r
F P
0 g
s
.59483 .27214 m .67406 .77575 L .68415 .76507 L p .707 .577 .707 r
F P
0 g
s
.68415 .76507 m .60492 .26145 L .59483 .27214 L p .707 .577 .707 r
F P
0 g
s
.68783 .76849 m .69312 .78675 L .66698 .79152 L p .707 .577 .707 r
F P
0 g
s
.19462 .78273 m .1851 .746 L .17326 .744 L p .707 .577 .707 r
F P
0 g
s
.17326 .744 m .18279 .78074 L .19462 .78273 L p .707 .577 .707 r
F P
0 g
s
.36097 .69932 m .37049 .73605 L .37774 .72899 L p .707 .577 .707 r
F P
0 g
s
.37774 .72899 m .36822 .69226 L .36097 .69932 L p .707 .577 .707 r
F P
0 g
s
.17148 .70824 m .16266 .65247 L .15995 .64625 L p .707 .577 .707 r
F P
0 g
s
.20208 .8317 m .19678 .81344 L .18513 .81211 L p .707 .577 .707 r
F P
0 g
s
.18513 .81211 m .19043 .83037 L .20208 .8317 L p .707 .577 .707 r
F P
0 g
s
.36138 .61879 m .3702 .67456 L .36749 .66834 L p .707 .577 .707 r
F P
0 g
s
.36749 .66834 m .35867 .61257 L .36138 .61879 L p .707 .577 .707 r
F P
0 g
s
.37133 .76193 m .37663 .78019 L .38392 .77328 L p .707 .577 .707 r
F P
0 g
s
.38392 .77328 m .37862 .75501 L .37133 .76193 L p .707 .577 .707 r
F P
0 g
s
.15995 .64625 m .16877 .70202 L .17148 .70824 L p .707 .577 .707 r
F P
0 g
s
.40356 .81239 m .32433 .30878 L .3205 .29998 L p .707 .577 .707 r
F P
0 g
s
.32433 .30878 m .40356 .81239 L .42094 .81845 L p .707 .577 .707 r
F P
0 g
s
.18279 .78074 m .17326 .744 L .17086 .73924 L p .707 .577 .707 r
F P
0 g
s
.17086 .73924 m .18038 .77597 L .18279 .78074 L p .707 .577 .707 r
F P
0 g
s
.36822 .69226 m .37774 .72899 L .37534 .72423 L p .707 .577 .707 r
F P
0 g
s
.37534 .72423 m .36581 .68749 L .36822 .69226 L p .707 .577 .707 r
F P
0 g
s
.60492 .26145 m .68415 .76507 L .68031 .75627 L p .707 .577 .707 r
F P
0 g
s
.68031 .75627 m .63555 .4717 L p .60492 .26145 L .707 .577 .707 r
F P
0 g
s
.60109 .25265 m .68031 .75627 L .66294 .75022 L p .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .68541 .67899 L .66733 .67986 L p .707 .577 .707 r
F P
0 g
s
.66733 .67986 m .66531 .67996 L p .6678 .68297 L .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .66733 .67986 L .6678 .68297 L .707 .577 .707 r
F
.63555 .4717 m .60109 .25265 L .60265 .25623 L p F P
0 g
s
.60265 .25623 m .60492 .26145 L p .63555 .4717 L .707 .577 .707 r
F P
0 g
s
.16877 .70202 m .15995 .64625 L .16709 .63869 L p .707 .577 .707 r
F P
0 g
s
.19043 .83037 m .18513 .81211 L .18284 .80778 L p .707 .577 .707 r
F P
0 g
s
.18284 .80778 m .18814 .82604 L .19043 .83037 L p .707 .577 .707 r
F P
0 g
s
.37862 .75501 m .38392 .77328 L .38163 .76895 L p .707 .577 .707 r
F P
0 g
s
.38163 .76895 m .37633 .75068 L .37862 .75501 L p .707 .577 .707 r
F P
0 g
s
.35867 .61257 m .36749 .66834 L .35518 .66408 L p .707 .577 .707 r
F P
0 g
s
.35518 .66408 m .34636 .60831 L .35867 .61257 L p .707 .577 .707 r
F P
0 g
s
.16709 .63869 m .17591 .69446 L .16877 .70202 L p .707 .577 .707 r
F P
0 g
s
.18038 .77597 m .17086 .73924 L .17811 .73218 L p .707 .577 .707 r
F P
0 g
s
.17811 .73218 m .18763 .76891 L .18038 .77597 L p .707 .577 .707 r
F P
0 g
s
.36581 .68749 m .37534 .72423 L .3635 .72223 L p .707 .577 .707 r
F P
0 g
s
.3635 .72223 m .35398 .6855 L .36581 .68749 L p .707 .577 .707 r
F P
0 g
s
.3205 .29998 m .39973 .80359 L .40356 .81239 L p .707 .577 .707 r
F P
0 g
s
.39973 .80359 m .3205 .29998 L .33059 .28929 L p .707 .577 .707 r
F P
0 g
s
.17591 .69446 m .16709 .63869 L .1834 .63052 L p .707 .577 .707 r
F P
0 g
s
.18814 .82604 m .18284 .80778 L .19013 .80087 L p .707 .577 .707 r
F P
0 g
s
.19013 .80087 m .19543 .81913 L .18814 .82604 L p .707 .577 .707 r
F P
0 g
s
.34636 .60831 m .35518 .66408 L .33449 .66218 L p .707 .577 .707 r
F P
0 g
s
.33449 .66218 m .32567 .60641 L .34636 .60831 L p .707 .577 .707 r
F P
0 g
s
.37633 .75068 m .38163 .76895 L .36998 .76762 L p .707 .577 .707 r
F P
0 g
s
.36998 .76762 m .36468 .74936 L .37633 .75068 L p .707 .577 .707 r
F P
0 g
s
.1834 .63052 m .19222 .68629 L .17591 .69446 L p .707 .577 .707 r
F P
0 g
s
.66294 .75022 m .58371 .2466 L .60109 .25265 L p .707 .577 .707 r
F P
0 g
s
.18763 .76891 m .17811 .73218 L .19431 .72351 L p .707 .577 .707 r
F P
0 g
s
.19222 .68629 m .1834 .63052 L .20727 .62255 L p .707 .577 .707 r
F P
0 g
s
.19431 .72351 m .20383 .76024 L .18763 .76891 L p .707 .577 .707 r
F P
0 g
s
.35398 .6855 m .3635 .72223 L .3434 .7232 L p .707 .577 .707 r
F P
0 g
s
.3434 .7232 m .33388 .68646 L .35398 .6855 L p .707 .577 .707 r
F P
0 g
s
.32567 .60641 m .33449 .66218 L .30743 .66284 L p .707 .577 .707 r
F P
0 g
s
.30743 .66284 m .29861 .60707 L .32567 .60641 L p .707 .577 .707 r
F P
0 g
s
.19543 .81913 m .19013 .80087 L .20629 .79205 L p .707 .577 .707 r
F P
0 g
s
.20727 .62255 m .21609 .67832 L .19222 .68629 L p .707 .577 .707 r
F P
0 g
s
.20629 .79205 m .21159 .81031 L .19543 .81913 L p .707 .577 .707 r
F P
0 g
s
.36468 .74936 m .36998 .76762 L .35011 .76943 L p .707 .577 .707 r
F P
0 g
s
.35011 .76943 m .34482 .75117 L .36468 .74936 L p .707 .577 .707 r
F P
0 g
s
.40982 .79291 m .33059 .28929 L .35361 .27777 L p .707 .577 .707 r
F P
0 g
s
.33059 .28929 m .40982 .79291 L .39973 .80359 L p .707 .577 .707 r
F P
0 g
s
.21609 .67832 m .20727 .62255 L .23636 .61555 L p .707 .577 .707 r
F P
0 g
s
.20383 .76024 m .19431 .72351 L .21787 .71408 L p .707 .577 .707 r
F P
0 g
s
.29861 .60707 m .30743 .66284 L .27666 .66599 L p .707 .577 .707 r
F P
0 g
s
.27666 .66599 m .26784 .61022 L .29861 .60707 L p .707 .577 .707 r
F P
0 g
s
.33388 .68646 m .3434 .7232 L .31701 .72703 L p .707 .577 .707 r
F P
0 g
s
.31701 .72703 m .30749 .69029 L .33388 .68646 L p .707 .577 .707 r
F P
0 g
s
.21787 .71408 m .2274 .75081 L .20383 .76024 L p .707 .577 .707 r
F P
0 g
s
.58371 .2466 m .66294 .75022 L .63371 .7475 L p .707 .577 .707 r
F P
0 g
s
.63371 .7475 m .55449 .24389 L .58371 .2466 L p .707 .577 .707 r
F P
0 g
s
.74252 .65074 m .7337 .59497 L .70293 .59812 L p .707 .577 .707 r
F P
0 g
s
.7337 .59497 m .74252 .65074 L .774 .6454 L p .707 .577 .707 r
F P
0 g
s
.774 .6454 m .76518 .58963 L .7337 .59497 L p .707 .577 .707 r
F P
0 g
s
.24518 .67132 m .23636 .61555 L .26784 .61022 L p .707 .577 .707 r
F P
0 g
s
.23636 .61555 m .24518 .67132 L .21609 .67832 L p .707 .577 .707 r
F P
0 g
s
.76518 .58963 m .774 .6454 L .8031 .63841 L p .707 .577 .707 r
F P
0 g
s
.8031 .63841 m .79427 .58264 L .76518 .58963 L p .707 .577 .707 r
F P
0 g
s
.26784 .61022 m .27666 .66599 L .24518 .67132 L p .707 .577 .707 r
F P
0 g
s
.21159 .81031 m .20629 .79205 L .22974 .78219 L p .707 .577 .707 r
F P
0 g
s
.22974 .78219 m .23504 .80045 L .21159 .81031 L p .707 .577 .707 r
F P
0 g
s
.71175 .65389 m .70293 .59812 L .67587 .59878 L p .707 .577 .707 r
F P
0 g
s
.70293 .59812 m .71175 .65389 L .74252 .65074 L p .707 .577 .707 r
F P
0 g
s
.34482 .75117 m .35011 .76943 L .32397 .7742 L p .707 .577 .707 r
F P
0 g
s
.32397 .7742 m .31868 .75594 L .34482 .75117 L p .707 .577 .707 r
F P
0 g
s
.2274 .75081 m .21787 .71408 L .2465 .70481 L p .707 .577 .707 r
F P
0 g
s
.79427 .58264 m .8031 .63841 L .82696 .63044 L p .707 .577 .707 r
F P
0 g
s
.82696 .63044 m .81814 .57467 L .79427 .58264 L p .707 .577 .707 r
F P
0 g
s
.30749 .69029 m .31701 .72703 L .2869 .73335 L p .707 .577 .707 r
F P
0 g
s
.2869 .73335 m .27737 .69661 L .30749 .69029 L p .707 .577 .707 r
F P
0 g
s
.2465 .70481 m .25602 .74155 L .2274 .75081 L p .707 .577 .707 r
F P
0 g
s
.75144 .70557 m .74192 .66884 L .71181 .67516 L p .707 .577 .707 r
F P
0 g
s
.74192 .66884 m .75144 .70557 L .78232 .69738 L p .707 .577 .707 r
F P
0 g
s
.78232 .69738 m .7728 .66064 L .74192 .66884 L p .707 .577 .707 r
F P
0 g
s
.7728 .66064 m .78232 .69738 L .81094 .68811 L p .707 .577 .707 r
F P
0 g
s
.81094 .68811 m .80142 .65138 L .7728 .66064 L p .707 .577 .707 r
F P
0 g
s
.67587 .59878 m .68469 .65455 L .71175 .65389 L p .707 .577 .707 r
F P
0 g
s
.25602 .74155 m .2465 .70481 L .27737 .69661 L p .707 .577 .707 r
F P
0 g
s
.35361 .27777 m .43284 .78138 L .40982 .79291 L p .707 .577 .707 r
F P
0 g
s
.43284 .78138 m .35361 .27777 L .38731 .26653 L p .707 .577 .707 r
F P
0 g
s
.27737 .69661 m .2869 .73335 L .25602 .74155 L p .707 .577 .707 r
F P
0 g
s
.71181 .67516 m .72133 .7119 L .75144 .70557 L p .707 .577 .707 r
F P
0 g
s
.23504 .80045 m .22974 .78219 L .25818 .77225 L p .707 .577 .707 r
F P
0 g
s
.68469 .65455 m .67587 .59878 L .65518 .59688 L p .707 .577 .707 r
F P
0 g
s
.72133 .7119 m .71181 .67516 L .68541 .67899 L p .707 .577 .707 r
F P
0 g
s
.31868 .75594 m .32397 .7742 L .29412 .78147 L p .707 .577 .707 r
F P
0 g
s
.29412 .78147 m .28882 .76321 L .31868 .75594 L p .707 .577 .707 r
F P
0 g
s
.25818 .77225 m .26348 .79051 L .23504 .80045 L p .707 .577 .707 r
F P
0 g
s
.75815 .74313 m .75285 .72487 L .723 .73213 L p .707 .577 .707 r
F P
0 g
s
.75285 .72487 m .75815 .74313 L .78879 .73409 L p .707 .577 .707 r
F P
0 g
s
.78879 .73409 m .7835 .71583 L .75285 .72487 L p .707 .577 .707 r
F P
0 g
s
.80142 .65138 m .81094 .68811 L .83451 .67868 L p .707 .577 .707 r
F P
0 g
s
.83451 .67868 m .82498 .64195 L .80142 .65138 L p .707 .577 .707 r
F P
0 g
s
.7835 .71583 m .78879 .73409 L .81723 .72415 L p .707 .577 .707 r
F P
0 g
s
.81723 .72415 m .81194 .70589 L .7835 .71583 L p .707 .577 .707 r
F P
0 g
s
.723 .73213 m .7283 .75039 L .75815 .74313 L p .707 .577 .707 r
F P
0 g
s
.68541 .67899 m .69493 .71573 L .72133 .7119 L p .707 .577 .707 r
F P
0 g
s
.55449 .24389 m .63371 .7475 L .59551 .74839 L p .707 .577 .707 r
F P
0 g
s
.59551 .74839 m .51628 .24478 L .55449 .24389 L p .707 .577 .707 r
F P
0 g
s
.81814 .57467 m .82696 .63044 L .84327 .62227 L p .707 .577 .707 r
F P
0 g
s
.84327 .62227 m .83445 .5665 L .81814 .57467 L p .707 .577 .707 r
F P
0 g
s
.26348 .79051 m .25818 .77225 L .28882 .76321 L p .707 .577 .707 r
F P
0 g
s
.28882 .76321 m .29412 .78147 L .26348 .79051 L p .707 .577 .707 r
F P
0 g
s
.65518 .59688 m .664 .65265 L .68469 .65455 L p .707 .577 .707 r
F P
0 g
s
.7283 .75039 m .723 .73213 L .69686 .7369 L p .707 .577 .707 r
F P
0 g
s
.81194 .70589 m .81723 .72415 L .84068 .71429 L p .707 .577 .707 r
F P
0 g
s
.84068 .71429 m .83538 .69602 L .81194 .70589 L p .707 .577 .707 r
F P
0 g
s
.69686 .7369 m .70216 .75516 L .7283 .75039 L p .707 .577 .707 r
F P
0 g
s
.82498 .64195 m .83451 .67868 L .85071 .67001 L p .707 .577 .707 r
F P
0 g
s
.85071 .67001 m .84118 .63328 L .82498 .64195 L p .707 .577 .707 r
F P
0 g
s
.46654 .77015 m .38731 .26653 L .42839 .25668 L p .707 .577 .707 r
F P
0 g
s
.38731 .26653 m .46654 .77015 L .43284 .78138 L p .707 .577 .707 r
F P
0 g
s
.664 .65265 m .65518 .59688 L .64287 .59261 L p .707 .577 .707 r
F P
0 g
s
.66531 .67996 m .67483 .71669 L .69493 .71573 L p .707 .577 .707 r
F P
0 g
s
.70216 .75516 m .69686 .7369 L .67699 .73871 L p .707 .577 .707 r
F P
0 g
s
.51628 .24478 m .59551 .74839 L .55206 .7528 L p .707 .577 .707 r
F P
0 g
s
.55206 .7528 m .47283 .24919 L .51628 .24478 L p .707 .577 .707 r
F P
0 g
s
.67699 .73871 m .68229 .75698 L .70216 .75516 L p .707 .577 .707 r
F P
0 g
s
.83445 .5665 m .84327 .62227 L .85042 .61471 L p .707 .577 .707 r
F P
0 g
s
.85042 .61471 m .8416 .55893 L .83445 .5665 L p .707 .577 .707 r
F P
0 g
s
.83538 .69602 m .84068 .71429 L .85684 .70547 L p .707 .577 .707 r
F P
0 g
s
.85684 .70547 m .85154 .68721 L .83538 .69602 L p .707 .577 .707 r
F P
0 g
s
.64287 .59261 m .65169 .64838 L .664 .65265 L p .707 .577 .707 r
F P
0 g
s
.50762 .7603 m .42839 .25668 L .47283 .24919 L p .707 .577 .707 r
F P
0 g
s
.42839 .25668 m .50762 .7603 L .46654 .77015 L p .707 .577 .707 r
F P
0 g
s
.47283 .24919 m .55206 .7528 L .50762 .7603 L p .707 .577 .707 r
F P
0 g
s
.67483 .71669 m .66531 .67996 L .65348 .67796 L p .707 .577 .707 r
F P
0 g
s
.65348 .67796 m .663 .7147 L .67483 .71669 L p .707 .577 .707 r
F P
0 g
s
.84118 .63328 m .85071 .67001 L .85796 .66295 L p .707 .577 .707 r
F P
0 g
s
.85796 .66295 m .84844 .62622 L .84118 .63328 L p .707 .577 .707 r
F P
0 g
s
.65169 .64838 m .64287 .59261 L .64016 .58639 L p .707 .577 .707 r
F P
0 g
s
.68229 .75698 m .67699 .73871 L .66535 .73739 L p .707 .577 .707 r
F P
0 g
s
.66535 .73739 m .67064 .75565 L .68229 .75698 L p .707 .577 .707 r
F P
0 g
s
.85154 .68721 m .85684 .70547 L .86413 .69855 L p .707 .577 .707 r
F P
0 g
s
.86413 .69855 m .85883 .68029 L .85154 .68721 L p .707 .577 .707 r
F P
0 g
s
.8416 .55893 m .85042 .61471 L .8477 .60848 L p .707 .577 .707 r
F P
0 g
s
.8477 .60848 m .83888 .55271 L .8416 .55893 L p .707 .577 .707 r
F P
0 g
s
.64016 .58639 m .64898 .64216 L .65169 .64838 L p .707 .577 .707 r
F P
0 g
s
.663 .7147 m .65348 .67796 L .65107 .6732 L p .707 .577 .707 r
F P
0 g
s
.65107 .6732 m .66059 .70993 L .663 .7147 L p .707 .577 .707 r
F P
0 g
s
.84844 .62622 m .85796 .66295 L .85555 .65819 L p .707 .577 .707 r
F P
0 g
s
.85555 .65819 m .84603 .62145 L .84844 .62622 L p .707 .577 .707 r
F P
0 g
s
.67064 .75565 m .66535 .73739 L .66306 .73306 L p .707 .577 .707 r
F P
0 g
s
.64898 .64216 m .64016 .58639 L .64731 .57883 L p .707 .577 .707 r
F P
0 g
s
.66306 .73306 m .66835 .75132 L .67064 .75565 L p .707 .577 .707 r
F P
0 g
s
.85883 .68029 m .86413 .69855 L .86184 .69422 L p .707 .577 .707 r
F P
0 g
s
.86184 .69422 m .85654 .67596 L .85883 .68029 L p .707 .577 .707 r
F P
0 g
s
.83888 .55271 m .8477 .60848 L .8354 .60422 L p .707 .577 .707 r
F P
0 g
s
.8354 .60422 m .82658 .54845 L .83888 .55271 L p .707 .577 .707 r
F P
0 g
s
.64731 .57883 m .65613 .6346 L .64898 .64216 L p .707 .577 .707 r
F P
0 g
s
.66059 .70993 m .65107 .6732 L .65832 .66614 L p .707 .577 .707 r
F P
0 g
s
.39951 .61856 m .39069 .56279 L .35992 .56594 L p .707 .577 .707 r
F P
0 g
s
.39069 .56279 m .39951 .61856 L .43099 .61322 L p .707 .577 .707 r
F P
0 g
s
.43099 .61322 m .42217 .55745 L .39069 .56279 L p .707 .577 .707 r
F P
0 g
s
.42217 .55745 m .43099 .61322 L .46009 .60623 L p .707 .577 .707 r
F P
0 g
s
.46009 .60623 m .45126 .55046 L .42217 .55745 L p .707 .577 .707 r
F P
0 g
s
.65832 .66614 m .66784 .70287 L .66059 .70993 L p .707 .577 .707 r
F P
0 g
s
.84603 .62145 m .85555 .65819 L .84372 .65619 L p .707 .577 .707 r
F P
0 g
s
.84372 .65619 m .83419 .61946 L .84603 .62145 L p .707 .577 .707 r
F P
0 g
s
.65613 .6346 m .64731 .57883 L .66361 .57066 L p .707 .577 .707 r
F P
0 g
s
.66835 .75132 m .66306 .73306 L .67035 .72615 L p .707 .577 .707 r
F P
0 g
s
.36874 .62171 m .35992 .56594 L .33286 .5666 L p .707 .577 .707 r
F P
0 g
s
.35992 .56594 m .36874 .62171 L .39951 .61856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67035 .72615 m .67565 .74441 L .66835 .75132 L p .707 .577 .707 r
F P
0 g
s
.45126 .55046 m .46009 .60623 L .48395 .59826 L p .707 .577 .707 r
F P
0 g
s
.48395 .59826 m .47513 .54249 L .45126 .55046 L p .707 .577 .707 r
F P
0 g
s
.85654 .67596 m .86184 .69422 L .85019 .6929 L p .707 .577 .707 r
F P
0 g
s
.85019 .6929 m .8449 .67464 L .85654 .67596 L p .707 .577 .707 r
F P
0 g
s
.82658 .54845 m .8354 .60422 L .8147 .60232 L p .707 .577 .707 r
F P
0 g
s
.8147 .60232 m .80588 .54655 L .82658 .54845 L p .707 .577 .707 r
F P
0 g
s
.66361 .57066 m .67243 .62643 L .65613 .6346 L p .707 .577 .707 r
F P
0 g
s
.40843 .67958 m .39891 .64284 L .3688 .64916 L p .707 .577 .707 r
F P
0 g
s
.39891 .64284 m .40843 .67958 L .43931 .67138 L p .707 .577 .707 r
F P
0 g
s
.43931 .67138 m .42979 .63465 L .39891 .64284 L p .707 .577 .707 r
F P
0 g
s
.33286 .5666 m .34168 .62237 L .36874 .62171 L p .707 .577 .707 r
F P
0 g
s
.42979 .63465 m .43931 .67138 L .46793 .66212 L p .707 .577 .707 r
F P
0 g
s
.46793 .66212 m .45841 .62538 L .42979 .63465 L p .707 .577 .707 r
F P
0 g
s
.34168 .62237 m .33286 .5666 L .31217 .5647 L p .707 .577 .707 r
F P
0 g
s
.3688 .64916 m .37832 .6859 L .40843 .67958 L p .707 .577 .707 r
F P
0 g
s
.66784 .70287 m .65832 .66614 L .67452 .65747 L p .707 .577 .707 r
F P
0 g
s
.37832 .6859 m .3688 .64916 L .3424 .65299 L p .707 .577 .707 r
F P
0 g
s
.45841 .62538 m .46793 .66212 L .4915 .65269 L p .707 .577 .707 r
F P
0 g
s
.4915 .65269 m .48197 .61595 L .45841 .62538 L p .707 .577 .707 r
F P
0 g
s
.41514 .72581 m .40984 .70755 L .37999 .71481 L p .707 .577 .707 r
F P
0 g
s
.40984 .70755 m .41514 .72581 L .44578 .71677 L p .707 .577 .707 r
F P
0 g
s
.44578 .71677 m .44049 .69851 L .40984 .70755 L p .707 .577 .707 r
F P
0 g
s
.67452 .65747 m .68404 .6942 L .66784 .70287 L p .707 .577 .707 r
F P
0 g
s
.47513 .54249 m .48395 .59826 L .50026 .59009 L p .707 .577 .707 r
F P
0 g
s
.50026 .59009 m .49144 .53432 L .47513 .54249 L p .707 .577 .707 r
F P
0 g
s
.83419 .61946 m .84372 .65619 L .82362 .65716 L p .707 .577 .707 r
F P
0 g
s
.82362 .65716 m .8141 .62042 L .83419 .61946 L p .707 .577 .707 r
F P
0 g
s
.67243 .62643 m .66361 .57066 L .68748 .56269 L p .707 .577 .707 r
F P
0 g
s
.44049 .69851 m .44578 .71677 L .47422 .70683 L p .707 .577 .707 r
F P
0 g
s
.47422 .70683 m .46893 .68857 L .44049 .69851 L p .707 .577 .707 r
F P
0 g
s
.3424 .65299 m .35192 .68973 L .37832 .6859 L p .707 .577 .707 r
F P
0 g
s
.37999 .71481 m .38529 .73308 L .41514 .72581 L p .707 .577 .707 r
F P
0 g
s
.31217 .5647 m .32099 .62047 L .34168 .62237 L p .707 .577 .707 r
F P
0 g
s
.67565 .74441 m .67035 .72615 L .68651 .71733 L p .707 .577 .707 r
F P
0 g
s
.80588 .54655 m .8147 .60232 L .78765 .60298 L p .707 .577 .707 r
F P
0 g
s
.78765 .60298 m .77882 .54721 L .80588 .54655 L p .707 .577 .707 r
F P
0 g
s
.68651 .71733 m .69181 .73559 L .67565 .74441 L p .707 .577 .707 r
F P
0 g
s
.38529 .73308 m .37999 .71481 L .35385 .71959 L p .707 .577 .707 r
F P
0 g
s
.8449 .67464 m .85019 .6929 L .83033 .69471 L p .707 .577 .707 r
F P
0 g
s
.83033 .69471 m .82503 .67645 L .8449 .67464 L p .707 .577 .707 r
F P
0 g
s
.46893 .68857 m .47422 .70683 L .49767 .69697 L p .707 .577 .707 r
F P
0 g
s
.49767 .69697 m .49237 .67871 L .46893 .68857 L p .707 .577 .707 r
F P
0 g
s
.35385 .71959 m .35915 .73785 L .38529 .73308 L p .707 .577 .707 r
F P
0 g
s
.68748 .56269 m .6963 .61846 L .67243 .62643 L p .707 .577 .707 r
F P
0 g
s
.35192 .68973 m .3424 .65299 L .3223 .65396 L p .707 .577 .707 r
F P
0 g
s
.32099 .62047 m .31217 .5647 L .29986 .56043 L p .707 .577 .707 r
F P
0 g
s
.48197 .61595 m .4915 .65269 L .5077 .64402 L p .707 .577 .707 r
F P
0 g
s
.5077 .64402 m .49818 .60728 L .48197 .61595 L p .707 .577 .707 r
F P
0 g
s
.3223 .65396 m .33182 .69069 L .35192 .68973 L p .707 .577 .707 r
F P
0 g
s
.68404 .6942 m .67452 .65747 L .69809 .64804 L p .707 .577 .707 r
F P
0 g
s
.6963 .61846 m .68748 .56269 L .71658 .55569 L p .707 .577 .707 r
F P
0 g
s
.77882 .54721 m .78765 .60298 L .75687 .60613 L p .707 .577 .707 r
F P
0 g
s
.75687 .60613 m .74805 .55036 L .77882 .54721 L p .707 .577 .707 r
F P
0 g
s
.8141 .62042 m .82362 .65716 L .79722 .66099 L p .707 .577 .707 r
F P
0 g
s
.79722 .66099 m .7877 .62425 L .8141 .62042 L p .707 .577 .707 r
F P
0 g
s
.69809 .64804 m .70761 .68477 L .68404 .6942 L p .707 .577 .707 r
F P
0 g
s
.49144 .53432 m .50026 .59009 L .50741 .58253 L p .707 .577 .707 r
F P
0 g
s
.50741 .58253 m .49859 .52676 L .49144 .53432 L p .707 .577 .707 r
F P
0 g
s
.35915 .73785 m .35385 .71959 L .33398 .7214 L p .707 .577 .707 r
F P
0 g
s
.29986 .56043 m .30868 .6162 L .32099 .62047 L p .707 .577 .707 r
F P
0 g
s
.33398 .7214 m .33928 .73966 L .35915 .73785 L p .707 .577 .707 r
F P
0 g
s
.49237 .67871 m .49767 .69697 L .51383 .68815 L p .707 .577 .707 r
F P
0 g
s
.51383 .68815 m .50853 .66989 L .49237 .67871 L p .707 .577 .707 r
F P
0 g
s
.7254 .61146 m .71658 .55569 L .74805 .55036 L p .707 .577 .707 r
F P
0 g
s
.71658 .55569 m .7254 .61146 L .6963 .61846 L p .707 .577 .707 r
F P
0 g
s
.69181 .73559 m .68651 .71733 L .70996 .70747 L p .707 .577 .707 r
F P
0 g
s
.74805 .55036 m .75687 .60613 L .7254 .61146 L p .707 .577 .707 r
F P
0 g
s
.70996 .70747 m .71525 .72573 L .69181 .73559 L p .707 .577 .707 r
F P
0 g
s
.82503 .67645 m .83033 .69471 L .80419 .69948 L p .707 .577 .707 r
F P
0 g
s
.80419 .69948 m .79889 .68122 L .82503 .67645 L p .707 .577 .707 r
F P
0 g
s
.33182 .69069 m .3223 .65396 L .31047 .65196 L p .707 .577 .707 r
F P
0 g
s
.70761 .68477 m .69809 .64804 L .72671 .63877 L p .707 .577 .707 r
F P
0 g
s
.7877 .62425 m .79722 .66099 L .76711 .66731 L p .707 .577 .707 r
F P
0 g
s
.76711 .66731 m .75759 .63057 L .7877 .62425 L p .707 .577 .707 r
F P
0 g
s
.31047 .65196 m .31999 .6887 L .33182 .69069 L p .707 .577 .707 r
F P
0 g
s
.49818 .60728 m .5077 .64402 L .51495 .63695 L p .707 .577 .707 r
F P
0 g
s
.51495 .63695 m .50543 .60022 L .49818 .60728 L p .707 .577 .707 r
F P
0 g
s
.72671 .63877 m .73623 .67551 L .70761 .68477 L p .707 .577 .707 r
F P
0 g
s
.30868 .6162 m .29986 .56043 L .29715 .55421 L p .707 .577 .707 r
F P
0 g
s
.73623 .67551 m .72671 .63877 L .75759 .63057 L p .707 .577 .707 r
F P
0 g
s
.71525 .72573 m .70996 .70747 L .73839 .69753 L p .707 .577 .707 r
F P
0 g
s
.75759 .63057 m .76711 .66731 L .73623 .67551 L p .707 .577 .707 r
F P
0 g
s
.33928 .73966 m .33398 .7214 L .32234 .72007 L p .707 .577 .707 r
F P
0 g
s
.79889 .68122 m .80419 .69948 L .77434 .70675 L p .707 .577 .707 r
F P
0 g
s
.77434 .70675 m .76904 .68848 L .79889 .68122 L p .707 .577 .707 r
F P
0 g
s
.73839 .69753 m .74369 .71579 L .71525 .72573 L p .707 .577 .707 r
F P
0 g
s
.32234 .72007 m .32763 .73834 L .33928 .73966 L p .707 .577 .707 r
F P
0 g
s
.49859 .52676 m .50741 .58253 L .50469 .5763 L p .707 .577 .707 r
F P
0 g
s
.50469 .5763 m .49587 .52053 L .49859 .52676 L p .707 .577 .707 r
F P
0 g
s
.50853 .66989 m .51383 .68815 L .52112 .68124 L p .707 .577 .707 r
F P
0 g
s
.52112 .68124 m .51582 .66298 L .50853 .66989 L p .707 .577 .707 r
F P
0 g
s
.29715 .55421 m .30597 .60998 L .30868 .6162 L p .707 .577 .707 r
F P
0 g
s
.74369 .71579 m .73839 .69753 L .76904 .68848 L p .707 .577 .707 r
F P
0 g
s
.76904 .68848 m .77434 .70675 L .74369 .71579 L p .707 .577 .707 r
F P
0 g
s
.31999 .6887 m .31047 .65196 L .30806 .6472 L p .707 .577 .707 r
F P
0 g
s
.30806 .6472 m .31758 .68393 L .31999 .6887 L p .707 .577 .707 r
F P
0 g
s
.50543 .60022 m .51495 .63695 L .51254 .63219 L p .707 .577 .707 r
F P
0 g
s
.51254 .63219 m .50302 .59546 L .50543 .60022 L p .707 .577 .707 r
F P
0 g
s
.30597 .60998 m .29715 .55421 L .3043 .54665 L p .707 .577 .707 r
F P
0 g
s
.32763 .73834 m .32234 .72007 L .32005 .71574 L p .707 .577 .707 r
F P
0 g
s
.32005 .71574 m .32534 .73401 L .32763 .73834 L p .707 .577 .707 r
F P
0 g
s
.51582 .66298 m .52112 .68124 L .51883 .67691 L p .707 .577 .707 r
F P
0 g
s
.51883 .67691 m .51353 .65864 L .51582 .66298 L p .707 .577 .707 r
F P
0 g
s
.49587 .52053 m .50469 .5763 L .49239 .57204 L p .707 .577 .707 r
F P
0 g
s
.49239 .57204 m .48357 .51627 L .49587 .52053 L p .707 .577 .707 r
F P
0 g
s
.3043 .54665 m .31312 .60242 L .30597 .60998 L p .707 .577 .707 r
F P
0 g
s
.31758 .68393 m .30806 .6472 L .31531 .64014 L p .707 .577 .707 r
F P
0 g
s
.31531 .64014 m .32483 .67687 L .31758 .68393 L p .707 .577 .707 r
F P
0 g
s
.50302 .59546 m .51254 .63219 L .50071 .63019 L p .707 .577 .707 r
F P
0 g
s
.50071 .63019 m .49118 .59346 L .50302 .59546 L p .707 .577 .707 r
F P
0 g
s
.31312 .60242 m .3043 .54665 L .3206 .53848 L p .707 .577 .707 r
F P
0 g
s
.32534 .73401 m .32005 .71574 L .32734 .70883 L p .707 .577 .707 r
F P
0 g
s
.32734 .70883 m .33263 .72709 L .32534 .73401 L p .707 .577 .707 r
F P
0 g
s
.48357 .51627 m .49239 .57204 L .47169 .57014 L p .707 .577 .707 r
F P
0 g
s
.47169 .57014 m .46287 .51437 L .48357 .51627 L p .707 .577 .707 r
F P
0 g
s
.51353 .65864 m .51883 .67691 L .50718 .67558 L p .707 .577 .707 r
F P
0 g
s
.50718 .67558 m .50189 .65732 L .51353 .65864 L p .707 .577 .707 r
F P
0 g
s
.3206 .53848 m .32942 .59425 L .31312 .60242 L p .707 .577 .707 r
F P
0 g
s
.32483 .67687 m .31531 .64014 L .33151 .63147 L p .707 .577 .707 r
F P
0 g
s
.32942 .59425 m .3206 .53848 L .34447 .53051 L p .707 .577 .707 r
F P
0 g
s
.33151 .63147 m .34103 .6682 L .32483 .67687 L p .707 .577 .707 r
F P
0 g
s
.49118 .59346 m .50071 .63019 L .48061 .63116 L p .707 .577 .707 r
F P
0 g
s
.48061 .63116 m .47109 .59442 L .49118 .59346 L p .707 .577 .707 r
F P
0 g
s
.46287 .51437 m .47169 .57014 L .44464 .5708 L p .707 .577 .707 r
F P
0 g
s
.44464 .5708 m .43581 .51503 L .46287 .51437 L p .707 .577 .707 r
F P
0 g
s
.33263 .72709 m .32734 .70883 L .3435 .70001 L p .707 .577 .707 r
F P
0 g
s
.34447 .53051 m .35329 .58628 L .32942 .59425 L p .707 .577 .707 r
F P
0 g
s
.3435 .70001 m .34879 .71827 L .33263 .72709 L p .707 .577 .707 r
F P
0 g
s
.50189 .65732 m .50718 .67558 L .48732 .6774 L p .707 .577 .707 r
F P
0 g
s
.48732 .6774 m .48202 .65913 L .50189 .65732 L p .707 .577 .707 r
F P
0 g
s
.35329 .58628 m .34447 .53051 L .37357 .52351 L p .707 .577 .707 r
F P
0 g
s
.34103 .6682 m .33151 .63147 L .35508 .62204 L p .707 .577 .707 r
F P
0 g
s
.43581 .51503 m .44464 .5708 L .41386 .57395 L p .707 .577 .707 r
F P
0 g
s
.41386 .57395 m .40504 .51818 L .43581 .51503 L p .707 .577 .707 r
F P
0 g
s
.47109 .59442 m .48061 .63116 L .45421 .63499 L p .707 .577 .707 r
F P
0 g
s
.45421 .63499 m .44469 .59825 L .47109 .59442 L p .707 .577 .707 r
F P
0 g
s
.35508 .62204 m .3646 .65877 L .34103 .6682 L p .707 .577 .707 r
F P
0 g
s
.38239 .57928 m .37357 .52351 L .40504 .51818 L p .707 .577 .707 r
F P
0 g
s
.37357 .52351 m .38239 .57928 L .35329 .58628 L p .707 .577 .707 r
F P
0 g
s
.40504 .51818 m .41386 .57395 L .38239 .57928 L p .707 .577 .707 r
F P
0 g
s
.34879 .71827 m .3435 .70001 L .36694 .69015 L p .707 .577 .707 r
F P
0 g
s
.36694 .69015 m .37224 .70841 L .34879 .71827 L p .707 .577 .707 r
F P
0 g
s
.48202 .65913 m .48732 .6774 L .46118 .68217 L p .707 .577 .707 r
F P
0 g
s
.46118 .68217 m .45588 .6639 L .48202 .65913 L p .707 .577 .707 r
F P
0 g
s
.3646 .65877 m .35508 .62204 L .3837 .61277 L p .707 .577 .707 r
F P
0 g
s
.44469 .59825 m .45421 .63499 L .4241 .64131 L p .707 .577 .707 r
F P
0 g
s
.4241 .64131 m .41458 .60458 L .44469 .59825 L p .707 .577 .707 r
F P
0 g
s
.3837 .61277 m .39322 .64951 L .3646 .65877 L p .707 .577 .707 r
F P
0 g
s
.39322 .64951 m .3837 .61277 L .41458 .60458 L p .707 .577 .707 r
F P
0 g
s
.41458 .60458 m .4241 .64131 L .39322 .64951 L p .707 .577 .707 r
F P
0 g
s
.37224 .70841 m .36694 .69015 L .39538 .68021 L p .707 .577 .707 r
F P
0 g
s
.45588 .6639 m .46118 .68217 L .43132 .68943 L p .707 .577 .707 r
F P
0 g
s
.43132 .68943 m .42603 .67117 L .45588 .6639 L p .707 .577 .707 r
F P
0 g
s
.39538 .68021 m .40068 .69847 L .37224 .70841 L p .707 .577 .707 r
F P
0 g
s
.40068 .69847 m .39538 .68021 L .42603 .67117 L p .707 .577 .707 r
F P
0 g
s
.42603 .67117 m .43132 .68943 L .40068 .69847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
SGoo5000O7oo0024Ool9000DFUH7001eOol0081oo`@0009JEP03001JEUYF01mJEP<0079oo`00O7oo
10001UYF00<005YFFUH08UYF00<007ooOol0Kgoo001gOol5000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool0075oo`H0009JEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06moo`00KGoo1000
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Kgoo001[Ool200000eYF001JEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1_Ool006Qoo`<000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06moo`00IWoo0P001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00L7oo001SOol30009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP04FUI`Ool0065oo`800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEW1oo`00Ggoo0P00
0eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KWoo001MOol20005FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005aoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Kgoo001KOol0
0`00FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06eoo`00G7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo
001LOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001^Ool005aoo`03001JEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006ioo`00G7oo00@005YFFUH000IJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH2001^Ool005aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVioo`00G7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVioo`00GGoo00<0
05YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`03001JEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP03001JEUYF009JEP8006eoo`00GGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001]Ool005eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00KGoo001MOol01000
FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFKGoo001MOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001/Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006aoo`00GWoo00@0
05YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001/Ool005ioo`04001JEUYF0006FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUI/Ool005moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00Ggoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001O
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EV]oo`00H7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JWoo001POol00`00
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001ZOol0061oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00JWoo001POol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Yoo`00H7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Qoo`00H7oo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Qoo`00
HGoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00<005YF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Qo
o`00HWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo
00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0007FUH0
0`00FUIJEP06FUHB0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`03001JEP0000MJEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Eoo`00
IGoo00<005YFFUH01`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001UOol0
06Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001UOol0065oo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol005moo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1SOol005eoo`80009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00FWoo0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF0P00I7oo001HOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0087oo4P00<Woo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol05goo1`0015YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol04goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001DOol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80011oo`@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8000aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYF001JEP0]Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20008Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUIJEP00FUH0;Goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUIJEP00FUH0;Goo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001EOol01000FUIJ
EP000eYF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004
FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001J
EP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000AJEP04001JEP00
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00000eYF0P0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF1`000UYF00@005YF000000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000/
Ool005Ioo`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH9
0003FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002aoo`00EWoo0eYF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF
001JEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUHB0002
FUH2000[Ool0055oo`D00005FUH00000FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH30000
0eYF001JEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP05FUH01000FUIJEUYF1000:goo001:Ool70003
FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF0`0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002]oo`00AWoo10000UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00@0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo0011Ool50006FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH0
05YF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002aoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH>000/
Ool003Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<000UJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YF
FUH00eYF00@005YFFUH002aoo`00=Woo0`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00AJEP80009JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP07FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:goo000cOol30004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF3@001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00D000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0035o
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEP03001JEUYF
009JEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005
FUH00`00FUIJEP05FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00:Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YFFUH00UYF00<005YFFUH01EYF00H005YF0000
05YF0009FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<0009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000ZOol002eoo`04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YF000005YF0005FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP@0009J
EP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF000ZOol002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol09goo000]Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF1`00
0UYF00@005YF000000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
009JEP@002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF2@001EYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP@000MJEP03001JEUYF00EJEP03001JEUYF009JEP8002Yoo`00;Woo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00AJEP03001JEP0000AJEP<000MJ
EP03001JEUYF00IJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`0YOol002ioo`04001JEUYF0003FUH00`00FUIJEP05FUH0
0`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00AJEP80
0003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002]oo`00;Woo00@005YFFUH000AJEP03001JEUYF00=J
EPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00AJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00MJEP04001JEUYFFUH>0004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF1000
25YF00<005YFFUH01UYF00<005YF00001P000UYF00@005YF000002Uoo`00;Woo00@005YFFUH000AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH50003FUH20005FUH0
1000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP04001JEUYFFUH60003FUH00`00
FUIJEP03FUH00`00FUIJEP02000XOol002ioo`04001JEUYF0004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF00EJEP06001J
EP00001JEP002EYF00<005YFFUH00UYF0`001EYF0`0000=JEP00FUH01EYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF10001eYF
00<005YFFUH01eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00:7oo000^
Ool01@00FUIJEUYF00000eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEP0000800003
FUH005YF009JEP<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000XOol002mo
o`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP0600000eYF0000000<0007FUH00`00FUIJEP04FUH40005FUH300000eYF001JEP05FUH01000FUIJ
EUYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002Moo`00;goo0eYF0P001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
1eYF00<005YFFUH010001eYF0`000eYF00<005YFFUH01EYF0`002EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH015YF0P000UYF00@005YFFUIJEP<000MJEP03001JEUYF00EJEP<000EJEP03
001JEUYF00IJEP03001JEUYF009JEPd002Moo`00;goo00EJEP00001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH01EYF10000eYF00<005YFFUH00UYF0`001UYF00<005YFFUH015YF0P0035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF0080009JEP03001JEUYF00IJEP04
001JEUYFFUH30008FUH00`00FUIJEP05FUH600001Goo000005YF00001EYF00<005YF00009goo000_
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH400000eYF001JEP08FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00UYF0`001UYF00<005YF00000P0000=JEP00
FUH01eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000EJEP03001JEUYF00EJEP06001JEP00001JEP002UYF00<005YFFUH0
10001Goo0P000eYF00<005YFFUH00eYF0P00:7oo000_Ool20003FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF0000
0P000UYF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP06FUH40006Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0
031oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP80009oo`04001JEUYF0002FUH30008FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP02FUH01000FUIJEUYF0`001eYF00<005YFFUH00eYF0`0027oo0P0000=J
EP00FUH01UYF00<005YFFUH00P00:Woo000bOol50003FUH01000FUIJEUYF100015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000P0015YF00<005YFFUH00UYF10000Woo00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF0`0000=JEP00FUH025YF00<005YF00000P00
27oo0`0015YF00<005YFFUH015YF0`00;7oo000gOol80008FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH20002FUH00`00FUIJEP03FUH01000FUH000000UYF1P001UYF00<005YFFUH01EYF100000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
000020001EYF00<005YFFUH01EYF0`0027oo0`001eYF00<005YFFUH00eYF0P00;Woo000iOol30000
0eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUIJEUYF1`000eYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEPD000IJEP03001JEUYF00=JEPD000Eo
o`<00003FUH005YF00QJEP03001JEP000080031oo`00=goo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01eYF0P000UYF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP05FUH00`00FUH000070002Ool3
0005FUH00`00FUIJEP05FUH3000cOol003Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP@0009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0004FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP03FUH2000fOol003=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000005FUH01000
FUIJEUYF100017oo100000=JEP00FUH02EYF00<005YF00000P00>7oo000bOol00`00FUIJEP03FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50008FUH200000eYF001JEP05FUH01000
FUIJEUYF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00UYF00@005YF0000
009JEPH000IJEP03001JEUYF00IJEP<003]oo`00<Goo0P001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH010001EYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF1P0017oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00AJEP80009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00=JEP<003ioo`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000QJEP03
001JEUYF00IJEP03001JEP0000D00003FUH0000000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEUYF001JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP000080045o
o`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8000Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2
0002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30014Ool0035oo`03001JEP0000AJEP03
001JEUYF00EJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000]oo`=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEQ8000AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00@004Moo`00<Goo00<005YF
000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo0eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH05UYF00@005YFFUIJEPH000MJEP03001JEUYF00MJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF009JEPH004]oo`00<Goo00@005YFFUH000AJEP04001J
EUYFFUH20003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP02FUH00`00FUIJEP020003Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH055YF1P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0000=JEP00FUH00UYF2000D7oo000a
Ool01000FUIJEP0015YF00@005YF000000EJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00
001JEP001eYF00<005YFFUH00eYF00@005YFFUH000=oo`04001JEUYF0007FUH00`00FUIJEP0GFUH6
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000050004FUH2001A
Ool0039oo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF0080009oo`05001JEUYFFUH00006FUH00`00FUIJEP0A
FUH7000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00Oomoo`1@Ool0039oo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009oo`05001JEUYFFUH00006FUH00`00FUIJEP0;FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0005=oo`00<Woo
00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01UYF10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF300000=oo`00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P0035YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00002`00D7oo000b
Ool01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH00UYF10001UYF00<005YFFUH01eYF
00<005YF00000`0000=oo`0000001EYF00@005YFFUH0009oo`=JEP03001JEUYF00]JEP8000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80
009JEP03001JEUYF00=JEP03001JEUYF008004moo`00<goo00@005YFFUH000EJEP03001JEUYF00EJ
EP06001JEP00001JEP002EYF00<005YFFUH015YF10000Woo0`0000=JEP00FUH01EYF0P000goo0eYF
00<005YFFUH02EYF0P001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00P00Cgoo000c
Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEUYF00@000=o
o`<000EJEP03001JEUYF00=JEP03001oogoo009oo`04001JEUYF0009FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P001EYF00<005YF
FUH00eYF00@005YFFUH004moo`00<goo40001eYF00<005YFFUH015YF1@001Goo0P0000=JEP00FUH0
1EYF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000008FUH00`00FUIJEP02FUH00`00FUIJEP02
001>Ool003ioo`800003FUH005YF00MJEP03001JEUYF00@000Moo`<000=JEP03001JEUYF00EJEP<0
00Moo`03001JEUYF00EJEP8000=JEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP<0009JEP03001JEUYF00AJEP/004ioo`00?7oo0P000eYF00<0
05YFFUH01EYF100027oo0`001UYF00<005YFFUH015YF0P002Goo00<005YFFUH00eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF0P00
1EYF00<005YFFUH0100000=oo`0000001EYF00<005YF0000CWoo000jOol20006FUH00`00FUIJEP02
FUH20009Ool300000eYF001JEP07FUH01000FUIJEUYF0P0037oo0eYF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEP<000IJEP@00003Ool0
000000800003FUH005YF00AJEP8004moo`00>7oo0`001eYF00<005YF00000P0027oo0`0015YF00<0
05YFFUH01UYF00@005YF000000ioo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH000000UYF00<005YFFUH010000Woo0`001EYF
00<005YFFUH00eYF00<007ooOol0CWoo000fOol20003FUH00`00FUIJEP04FUH20008Ool30008FUH0
0`00FUIJEP04FUH3000@Ool00eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0GFUH00`00FUIJ
EP07FUH40002FUH50004Ool200000eYF001JEP06FUH00`00FUIJEP02001AOol003Aoo`<000AJEP03
001JEUYF009JEP8000Ioo`@00003FUH005YF00QJEP03001JEUYF00@001=oo`8000]JEP03001JEUYF
00QJEP03001JEUYF01MJEP04001JEUYFFUH60002FUH40006Ool30004FUH00`00FUIJEP04FUH3001C
Ool003=oo`04001JEUYF0005FUH01000FUH000000Woo1P001UYF00<005YFFUH01EYF10005goo0P00
15YF00<005YFFUH07EYF00<005YFFUH01eYF1P0015YF10001goo0`001eYF00<005YFFUH015YF00<0
07ooOol0Dgoo000cOol01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0077oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YF
FUIJEPH0009JEP03001JEUYF00=JEP@000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEP8005Io
o`00=7oo00D005YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
01ioo`<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEPL00003FUH005YF00IJ
EP03001JEP0000L0009oo`<000EJEP03001JEUYF00IJEP04001JEP00001HOol003Aoo`03001JEUYF
008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@002Aoo`H000AJEP03001JEUYF00QJEP04001J
EUYFFUH60003Ool20003FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP05FUH3001JOol0
03Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@002iooa<000Qoo`8000EJEP04
001JEUYFFUH20006Ool6000:FUH00`00FUIJEP04001MOol003Eoo`04001JEUYF0006FUH01000FUIJ
EUYF1P00C7oo00@005YFFUH000AJEP04001JEP000002Ool6000015YF000000000UYF00<005YFFUH0
1UYF1000HGoo000eOol20002FUH01000FUIJEUYF1P00DWoo00@005YFFUH000AJEPH000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP<006Eoo`00=Woo1`00F7oo00H005YFFUIJEP00FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00002001XOol009Ioo`03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP<006]oo`00UWoo10001UYF00<005YFFUH01EYF00<005YFFUH01000
KWoo002FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6001bOol009Ioo`80009JEP04001J
EUYFFUH7001hOol009Moo`L007moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60191 .74543 m .59644 .68956 L .56542 .69078 L p .707 .577 .707 r
F P
0 g
s
.59644 .68956 m .60191 .74543 L .63361 .74184 L p .707 .577 .707 r
F P
0 g
s
.63361 .74184 m .62814 .68596 L .59644 .68956 L p .707 .577 .707 r
F P
0 g
s
.62814 .68596 m .63361 .74184 L .66288 .73623 L p .707 .577 .707 r
F P
0 g
s
.66288 .73623 m .65741 .68035 L .62814 .68596 L p .707 .577 .707 r
F P
0 g
s
.57089 .74665 m .56542 .69078 L .53812 .6895 L p .707 .577 .707 r
F P
0 g
s
.56542 .69078 m .57089 .74665 L .60191 .74543 L p .707 .577 .707 r
F P
0 g
s
.65741 .68035 m .66288 .73623 L .68686 .72915 L p .707 .577 .707 r
F P
0 g
s
.68686 .72915 m .6814 .67327 L .65741 .68035 L p .707 .577 .707 r
F P
0 g
s
.60759 .80244 m .60166 .76526 L .57089 .76845 L p .707 .577 .707 r
F P
0 g
s
.60166 .76526 m .60759 .80244 L .63906 .79707 L p .707 .577 .707 r
F P
0 g
s
.63906 .79707 m .63313 .75989 L .60166 .76526 L p .707 .577 .707 r
F P
0 g
s
.63313 .75989 m .63906 .79707 L .66815 .79004 L p .707 .577 .707 r
F P
0 g
s
.66815 .79004 m .66222 .75286 L .63313 .75989 L p .707 .577 .707 r
F P
0 g
s
.53812 .6895 m .54359 .74538 L .57089 .74665 L p .707 .577 .707 r
F P
0 g
s
.54359 .74538 m .53812 .6895 L .5172 .68587 L p .707 .577 .707 r
F P
0 g
s
.57089 .76845 m .57682 .80563 L .60759 .80244 L p .707 .577 .707 r
F P
0 g
s
.57682 .80563 m .57089 .76845 L .54384 .76916 L p .707 .577 .707 r
F P
0 g
s
.66222 .75286 m .66815 .79004 L .69202 .78205 L p .707 .577 .707 r
F P
0 g
s
.69202 .78205 m .68609 .74487 L .66222 .75286 L p .707 .577 .707 r
F P
0 g
s
.61179 .84156 m .60849 .823 L .57782 .82678 L p .707 .577 .707 r
F P
0 g
s
.60849 .823 m .61179 .84156 L .64317 .83566 L p .707 .577 .707 r
F P
0 g
s
.64317 .83566 m .63986 .81709 L .60849 .823 L p .707 .577 .707 r
F P
0 g
s
.6814 .67327 m .68686 .72915 L .70321 .72128 L p .707 .577 .707 r
F P
0 g
s
.70321 .72128 m .69774 .6654 L .6814 .67327 L p .707 .577 .707 r
F P
0 g
s
.63986 .81709 m .64317 .83566 L .67219 .82821 L p .707 .577 .707 r
F P
0 g
s
.67219 .82821 m .66888 .80965 L .63986 .81709 L p .707 .577 .707 r
F P
0 g
s
.54384 .76916 m .54977 .80633 L .57682 .80563 L p .707 .577 .707 r
F P
0 g
s
.57782 .82678 m .58112 .84534 L .61179 .84156 L p .707 .577 .707 r
F P
0 g
s
.5172 .68587 m .52267 .74174 L .54359 .74538 L p .707 .577 .707 r
F P
0 g
s
.58112 .84534 m .57782 .82678 L .55087 .82807 L p .707 .577 .707 r
F P
0 g
s
.54977 .80633 m .54384 .76916 L .52316 .7673 L p .707 .577 .707 r
F P
0 g
s
.55087 .82807 m .55417 .84663 L .58112 .84534 L p .707 .577 .707 r
F P
0 g
s
.66888 .80965 m .67219 .82821 L .69601 .81995 L p .707 .577 .707 r
F P
0 g
s
.69601 .81995 m .6927 .80139 L .66888 .80965 L p .707 .577 .707 r
F P
0 g
s
.52267 .74174 m .5172 .68587 L .50472 .68022 L p .707 .577 .707 r
F P
0 g
s
.68609 .74487 m .69202 .78205 L .70832 .77388 L p .707 .577 .707 r
F P
0 g
s
.70832 .77388 m .70239 .7367 L .68609 .74487 L p .707 .577 .707 r
F P
0 g
s
.52316 .7673 m .52908 .80447 L .54977 .80633 L p .707 .577 .707 r
F P
0 g
s
.55417 .84663 m .55087 .82807 L .53027 .82674 L p .707 .577 .707 r
F P
0 g
s
.69774 .6654 m .70321 .72128 L .71032 .71341 L p .707 .577 .707 r
F P
0 g
s
.71032 .71341 m .70485 .65753 L .69774 .6654 L p .707 .577 .707 r
F P
0 g
s
.53027 .82674 m .53357 .8453 L .55417 .84663 L p .707 .577 .707 r
F P
0 g
s
.50472 .68022 m .51019 .73609 L .52267 .74174 L p .707 .577 .707 r
F P
0 g
s
.6927 .80139 m .69601 .81995 L .7123 .81168 L p .707 .577 .707 r
F P
0 g
s
.7123 .81168 m .70899 .79312 L .6927 .80139 L p .707 .577 .707 r
F P
0 g
s
.52908 .80447 m .52316 .7673 L .51085 .76306 L p .707 .577 .707 r
F P
0 g
s
.51085 .76306 m .51678 .80024 L .52908 .80447 L p .707 .577 .707 r
F P
0 g
s
.51019 .73609 m .50472 .68022 L .50189 .67311 L p .707 .577 .707 r
F P
0 g
s
.70239 .7367 m .70832 .77388 L .71547 .76632 L p .707 .577 .707 r
F P
0 g
s
.71547 .76632 m .70954 .72914 L .70239 .7367 L p .707 .577 .707 r
F P
0 g
s
.53357 .8453 m .53027 .82674 L .51804 .82293 L p .707 .577 .707 r
F P
0 g
s
.51804 .82293 m .52134 .84149 L .53357 .8453 L p .707 .577 .707 r
F P
0 g
s
.70485 .65753 m .71032 .71341 L .70749 .70631 L p .707 .577 .707 r
F P
0 g
s
.70749 .70631 m .70202 .65043 L .70485 .65753 L p .707 .577 .707 r
F P
0 g
s
.50189 .67311 m .50736 .72899 L .51019 .73609 L p .707 .577 .707 r
F P
0 g
s
.70899 .79312 m .7123 .81168 L .71946 .80422 L p .707 .577 .707 r
F P
0 g
s
.71946 .80422 m .71616 .78565 L .70899 .79312 L p .707 .577 .707 r
F P
0 g
s
.51678 .80024 m .51085 .76306 L .50814 .75686 L p .707 .577 .707 r
F P
0 g
s
.50814 .75686 m .51407 .79403 L .51678 .80024 L p .707 .577 .707 r
F P
0 g
s
.70954 .72914 m .71547 .76632 L .71276 .76012 L p .707 .577 .707 r
F P
0 g
s
.71276 .76012 m .70683 .72294 L .70954 .72914 L p .707 .577 .707 r
F P
0 g
s
.50736 .72899 m .50189 .67311 L .509 .66524 L p .707 .577 .707 r
F P
0 g
s
.52134 .84149 m .51804 .82293 L .51537 .817 L p .707 .577 .707 r
F P
0 g
s
.509 .66524 m .51447 .72112 L .50736 .72899 L p .707 .577 .707 r
F P
0 g
s
.51407 .79403 m .50814 .75686 L .51529 .7493 L p .707 .577 .707 r
F P
0 g
s
.51537 .817 m .51868 .83556 L .52134 .84149 L p .707 .577 .707 r
F P
0 g
s
.51868 .83556 m .51537 .817 L .52254 .80953 L p .707 .577 .707 r
F P
0 g
s
.51621 .81895 m .46711 .31438 L .42331 .31608 L p .707 .577 .707 r
F P
0 g
s
.51529 .7493 m .52122 .78648 L .51407 .79403 L p .707 .577 .707 r
F P
0 g
s
.51447 .72112 m .509 .66524 L .52535 .65738 L p .707 .577 .707 r
F P
0 g
s
.52254 .80953 m .52584 .82809 L .51868 .83556 L p .707 .577 .707 r
F P
0 g
s
.52535 .65738 m .53081 .71325 L .51447 .72112 L p .707 .577 .707 r
F P
0 g
s
.52122 .78648 m .51529 .7493 L .5316 .74113 L p .707 .577 .707 r
F P
0 g
s
.53081 .71325 m .52535 .65738 L .54933 .65029 L p .707 .577 .707 r
F P
0 g
s
.5316 .74113 m .53753 .7783 L .52122 .78648 L p .707 .577 .707 r
F P
0 g
s
.52584 .82809 m .52254 .80953 L .53883 .80126 L p .707 .577 .707 r
F P
0 g
s
.53883 .80126 m .54213 .81983 L .52584 .82809 L p .707 .577 .707 r
F P
0 g
s
.54933 .65029 m .5548 .70617 L .53081 .71325 L p .707 .577 .707 r
F P
0 g
s
.53753 .7783 m .5316 .74113 L .55546 .73313 L p .707 .577 .707 r
F P
0 g
s
.55546 .73313 m .56139 .77031 L .53753 .7783 L p .707 .577 .707 r
F P
0 g
s
.54213 .81983 m .53883 .80126 L .56265 .793 L p .707 .577 .707 r
F P
0 g
s
.56265 .793 m .56595 .81157 L .54213 .81983 L p .707 .577 .707 r
F P
0 g
s
.46711 .31438 m .51621 .81895 L .56096 .8139 L p .707 .577 .707 r
F P
0 g
s
.56096 .8139 m .51186 .30933 L .46711 .31438 L p .707 .577 .707 r
F P
0 g
s
.5548 .70617 m .54933 .65029 L .5786 .64468 L p .707 .577 .707 r
F P
0 g
s
.5786 .64468 m .58407 .70056 L .5548 .70617 L p .707 .577 .707 r
F P
0 g
s
.56139 .77031 m .55546 .73313 L .58455 .72611 L p .707 .577 .707 r
F P
0 g
s
.58455 .72611 m .59048 .76329 L .56139 .77031 L p .707 .577 .707 r
F P
0 g
s
.59048 .76329 m .58455 .72611 L .61602 .72074 L p .707 .577 .707 r
F P
0 g
s
.61602 .72074 m .62195 .75791 L .59048 .76329 L p .707 .577 .707 r
F P
0 g
s
.56595 .81157 m .56265 .793 L .59167 .78556 L p .707 .577 .707 r
F P
0 g
s
.59167 .78556 m .59497 .80412 L .56595 .81157 L p .707 .577 .707 r
F P
0 g
s
.59497 .80412 m .59167 .78556 L .62305 .77965 L p .707 .577 .707 r
F P
0 g
s
.62305 .77965 m .62635 .79821 L .59497 .80412 L p .707 .577 .707 r
F P
0 g
s
.51186 .30933 m .56096 .8139 L .60229 .80599 L p .707 .577 .707 r
F P
0 g
s
.58407 .70056 m .5786 .64468 L .6103 .64109 L p .707 .577 .707 r
F P
0 g
s
.6103 .64109 m .61577 .69696 L .58407 .70056 L p .707 .577 .707 r
F P
0 g
s
.60229 .80599 m .55319 .30143 L .51186 .30933 L p .707 .577 .707 r
F P
0 g
s
.71616 .78565 m .71946 .80422 L .7168 .79829 L p .707 .577 .707 r
F P
0 g
s
.7168 .79829 m .71349 .77972 L .71616 .78565 L p .707 .577 .707 r
F P
0 g
s
.70202 .65043 m .70749 .70631 L .69501 .70066 L p .707 .577 .707 r
F P
0 g
s
.69501 .70066 m .68954 .64478 L .70202 .65043 L p .707 .577 .707 r
F P
0 g
s
.47242 .82065 m .42331 .31608 L .38476 .31426 L p .707 .577 .707 r
F P
0 g
s
.42331 .31608 m .47242 .82065 L .51621 .81895 L p .707 .577 .707 r
F P
0 g
s
.64132 .63987 m .64678 .69574 L .61577 .69696 L p .707 .577 .707 r
F P
0 g
s
.61577 .69696 m .6103 .64109 L .64132 .63987 L p .707 .577 .707 r
F P
0 g
s
.64679 .71754 m .65272 .75472 L .62195 .75791 L p .707 .577 .707 r
F P
0 g
s
.62195 .75791 m .61602 .72074 L .64679 .71754 L p .707 .577 .707 r
F P
0 g
s
.65371 .77587 m .65702 .79443 L .62635 .79821 L p .707 .577 .707 r
F P
0 g
s
.62635 .79821 m .62305 .77965 L .65371 .77587 L p .707 .577 .707 r
F P
0 g
s
.55319 .30143 m .60229 .80599 L .63615 .796 L p .707 .577 .707 r
F P
0 g
s
.63615 .796 m .58705 .29144 L .55319 .30143 L p .707 .577 .707 r
F P
0 g
s
.2589 .71148 m .25343 .65561 L .22242 .65683 L p .707 .577 .707 r
F P
0 g
s
.25343 .65561 m .2589 .71148 L .2906 .70789 L p .707 .577 .707 r
F P
0 g
s
.2906 .70789 m .28513 .65201 L .25343 .65561 L p .707 .577 .707 r
F P
0 g
s
.28513 .65201 m .2906 .70789 L .31987 .70228 L p .707 .577 .707 r
F P
0 g
s
.31987 .70228 m .3144 .6464 L .28513 .65201 L p .707 .577 .707 r
F P
0 g
s
.70683 .72294 m .71276 .76012 L .70046 .75588 L p .707 .577 .707 r
F P
0 g
s
.70046 .75588 m .69453 .7187 L .70683 .72294 L p .707 .577 .707 r
F P
0 g
s
.22788 .7127 m .22242 .65683 L .19511 .65555 L p .707 .577 .707 r
F P
0 g
s
.22242 .65683 m .22788 .7127 L .2589 .71148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.43386 .81883 m .38476 .31426 L .35523 .3091 L p .707 .577 .707 r
F P
0 g
s
.38476 .31426 m .43386 .81883 L .47242 .82065 L p .707 .577 .707 r
F P
0 g
s
.3144 .6464 m .31987 .70228 L .34385 .6952 L p .707 .577 .707 r
F P
0 g
s
.34385 .6952 m .33839 .63932 L .3144 .6464 L p .707 .577 .707 r
F P
0 g
s
.68954 .64478 m .69501 .70066 L .67409 .69702 L p .707 .577 .707 r
F P
0 g
s
.67409 .69702 m .66862 .64114 L .68954 .64478 L p .707 .577 .707 r
F P
0 g
s
.71349 .77972 m .7168 .79829 L .70457 .79447 L p .707 .577 .707 r
F P
0 g
s
.70457 .79447 m .70126 .77591 L .71349 .77972 L p .707 .577 .707 r
F P
0 g
s
.26458 .77231 m .25865 .73513 L .22789 .73832 L p .707 .577 .707 r
F P
0 g
s
.25865 .73513 m .26458 .77231 L .29605 .76694 L p .707 .577 .707 r
F P
0 g
s
.29605 .76694 m .29012 .72976 L .25865 .73513 L p .707 .577 .707 r
F P
0 g
s
.19511 .65555 m .20058 .71143 L .22788 .7127 L p .707 .577 .707 r
F P
0 g
s
.29012 .72976 m .29605 .76694 L .32514 .75991 L p .707 .577 .707 r
F P
0 g
s
.32514 .75991 m .31921 .72273 L .29012 .72976 L p .707 .577 .707 r
F P
0 g
s
.20058 .71143 m .19511 .65555 L .17419 .65192 L p .707 .577 .707 r
F P
0 g
s
.67384 .71684 m .67977 .75402 L .65272 .75472 L p .707 .577 .707 r
F P
0 g
s
.65272 .75472 m .64679 .71754 L .67384 .71684 L p .707 .577 .707 r
F P
0 g
s
.65702 .79443 m .65371 .77587 L .68066 .77458 L p .707 .577 .707 r
F P
0 g
s
.58705 .29144 m .63615 .796 L .65922 .78491 L p .707 .577 .707 r
F P
0 g
s
.66862 .64114 m .67409 .69702 L .64678 .69574 L p .707 .577 .707 r
F P
0 g
s
.64678 .69574 m .64132 .63987 L .66862 .64114 L p .707 .577 .707 r
F P
0 g
s
.65922 .78491 m .61012 .28034 L .58705 .29144 L p .707 .577 .707 r
F P
0 g
s
.22789 .73832 m .23382 .7755 L .26458 .77231 L p .707 .577 .707 r
F P
0 g
s
.23382 .7755 m .22789 .73832 L .20083 .73903 L p .707 .577 .707 r
F P
0 g
s
.31921 .72273 m .32514 .75991 L .34901 .75192 L p .707 .577 .707 r
F P
0 g
s
.34901 .75192 m .34308 .71474 L .31921 .72273 L p .707 .577 .707 r
F P
0 g
s
.33839 .63932 m .34385 .6952 L .3602 .68733 L p .707 .577 .707 r
F P
0 g
s
.3602 .68733 m .35473 .63145 L .33839 .63932 L p .707 .577 .707 r
F P
0 g
s
.26878 .8168 m .26548 .79823 L .23481 .80202 L p .707 .577 .707 r
F P
0 g
s
.26548 .79823 m .26878 .8168 L .30016 .81089 L p .707 .577 .707 r
F P
0 g
s
.30016 .81089 m .29686 .79233 L .26548 .79823 L p .707 .577 .707 r
F P
0 g
s
.69453 .7187 m .70046 .75588 L .67977 .75402 L p .707 .577 .707 r
F P
0 g
s
.67977 .75402 m .67384 .71684 L .69453 .7187 L p .707 .577 .707 r
F P
0 g
s
.20083 .73903 m .20676 .7762 L .23382 .7755 L p .707 .577 .707 r
F P
0 g
s
.29686 .79233 m .30016 .81089 L .32918 .80345 L p .707 .577 .707 r
F P
0 g
s
.32918 .80345 m .32587 .78488 L .29686 .79233 L p .707 .577 .707 r
F P
0 g
s
.17419 .65192 m .17966 .70779 L .20058 .71143 L p .707 .577 .707 r
F P
0 g
s
.23481 .80202 m .23811 .82058 L .26878 .8168 L p .707 .577 .707 r
F P
0 g
s
.23811 .82058 m .23481 .80202 L .20786 .80331 L p .707 .577 .707 r
F P
0 g
s
.20676 .7762 m .20083 .73903 L .18015 .73717 L p .707 .577 .707 r
F P
0 g
s
.40433 .81367 m .35523 .3091 L .33761 .30111 L p .707 .577 .707 r
F P
0 g
s
.35523 .3091 m .40433 .81367 L .43386 .81883 L p .707 .577 .707 r
F P
0 g
s
.20786 .80331 m .21116 .82187 L .23811 .82058 L p .707 .577 .707 r
F P
0 g
s
.32587 .78488 m .32918 .80345 L .353 .79518 L p .707 .577 .707 r
F P
0 g
s
.353 .79518 m .3497 .77662 L .32587 .78488 L p .707 .577 .707 r
F P
0 g
s
.17966 .70779 m .17419 .65192 L .16171 .64627 L p .707 .577 .707 r
F P
0 g
s
.70126 .77591 m .70457 .79447 L .68397 .79314 L p .707 .577 .707 r
F P
0 g
s
.68397 .79314 m .68066 .77458 L .70126 .77591 L p .707 .577 .707 r
F P
0 g
s
.34308 .71474 m .34901 .75192 L .36531 .74375 L p .707 .577 .707 r
F P
0 g
s
.36531 .74375 m .35938 .70657 L .34308 .71474 L p .707 .577 .707 r
F P
0 g
s
.18015 .73717 m .18608 .77434 L .20676 .7762 L p .707 .577 .707 r
F P
0 g
s
.35473 .63145 m .3602 .68733 L .36731 .67946 L p .707 .577 .707 r
F P
0 g
s
.36731 .67946 m .36184 .62358 L .35473 .63145 L p .707 .577 .707 r
F P
0 g
s
.21116 .82187 m .20786 .80331 L .18726 .80198 L p .707 .577 .707 r
F P
0 g
s
.16171 .64627 m .16718 .70214 L .17966 .70779 L p .707 .577 .707 r
F P
0 g
s
.61012 .28034 m .65922 .78491 L .66926 .77379 L p .707 .577 .707 r
F P
0 g
s
.66926 .77379 m .62015 .26923 L .61012 .28034 L p .707 .577 .707 r
F P
0 g
s
.18726 .80198 m .19056 .82054 L .21116 .82187 L p .707 .577 .707 r
F P
0 g
s
.3497 .77662 m .353 .79518 L .36929 .78692 L p .707 .577 .707 r
F P
0 g
s
.36929 .78692 m .36598 .76835 L .3497 .77662 L p .707 .577 .707 r
F P
0 g
s
.18608 .77434 m .18015 .73717 L .16784 .73293 L p .707 .577 .707 r
F P
0 g
s
.68066 .77458 m .68397 .79314 L .65702 .79443 L p .707 .577 .707 r
F P
0 g
s
.16718 .70214 m .16171 .64627 L .15888 .63916 L p .707 .577 .707 r
F P
0 g
s
.16784 .73293 m .17377 .77011 L .18608 .77434 L p .707 .577 .707 r
F P
0 g
s
.35938 .70657 m .36531 .74375 L .37246 .73619 L p .707 .577 .707 r
F P
0 g
s
.37246 .73619 m .36653 .69901 L .35938 .70657 L p .707 .577 .707 r
F P
0 g
s
.19056 .82054 m .18726 .80198 L .17503 .79816 L p .707 .577 .707 r
F P
0 g
s
.38671 .80568 m .33761 .30111 L .33361 .29106 L p .707 .577 .707 r
F P
0 g
s
.33761 .30111 m .38671 .80568 L .40433 .81367 L p .707 .577 .707 r
F P
0 g
s
.17503 .79816 m .17833 .81672 L .19056 .82054 L p .707 .577 .707 r
F P
0 g
s
.36184 .62358 m .36731 .67946 L .36448 .67236 L p .707 .577 .707 r
F P
0 g
s
.36448 .67236 m .35901 .61648 L .36184 .62358 L p .707 .577 .707 r
F P
0 g
s
.15888 .63916 m .16435 .69504 L .16718 .70214 L p .707 .577 .707 r
F P
0 g
s
.36598 .76835 m .36929 .78692 L .37645 .77945 L p .707 .577 .707 r
F P
0 g
s
.37645 .77945 m .37315 .76089 L .36598 .76835 L p .707 .577 .707 r
F P
0 g
s
.17377 .77011 m .16784 .73293 L .16514 .72673 L p .707 .577 .707 r
F P
0 g
s
.62015 .26923 m .66926 .77379 L .66527 .76375 L p .707 .577 .707 r
F P
0 g
s
.66527 .76375 m .63695 .47281 L p .62015 .26923 L .707 .577 .707 r
F P
0 g
s
.61616 .25918 m .66527 .76375 L .64764 .75575 L p .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .66036 .67526 L .65433 .67318 L p .707 .577 .707 r
F P
0 g
s
.65433 .67318 m .64806 .67102 L p .65563 .68823 L .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .65433 .67318 L .65563 .68823 L .707 .577 .707 r
F
.63695 .47281 m .61616 .25918 L .61906 .26647 L p F P
0 g
s
.61906 .26647 m .62015 .26923 L p .63695 .47281 L .707 .577 .707 r
F P
0 g
s
.16514 .72673 m .17106 .7639 L .17377 .77011 L p .707 .577 .707 r
F P
0 g
s
.16435 .69504 m .15888 .63916 L .16599 .63129 L p .707 .577 .707 r
F P
0 g
s
.36653 .69901 m .37246 .73619 L .36975 .72999 L p .707 .577 .707 r
F P
0 g
s
.36975 .72999 m .36382 .69281 L .36653 .69901 L p .707 .577 .707 r
F P
0 g
s
.17833 .81672 m .17503 .79816 L .17237 .79223 L p .707 .577 .707 r
F P
0 g
s
.17237 .79223 m .17567 .81079 L .17833 .81672 L p .707 .577 .707 r
F P
0 g
s
.35901 .61648 m .36448 .67236 L .352 .66671 L p .707 .577 .707 r
F P
0 g
s
.352 .66671 m .34653 .61083 L .35901 .61648 L p .707 .577 .707 r
F P
0 g
s
.16599 .63129 m .17146 .68717 L .16435 .69504 L p .707 .577 .707 r
F P
0 g
s
.37315 .76089 m .37645 .77945 L .37379 .77352 L p .707 .577 .707 r
F P
0 g
s
.37379 .77352 m .37048 .75496 L .37315 .76089 L p .707 .577 .707 r
F P
0 g
s
.17106 .7639 m .16514 .72673 L .17228 .71917 L p .707 .577 .707 r
F P
0 g
s
.33361 .29106 m .38272 .79563 L .38671 .80568 L p .707 .577 .707 r
F P
0 g
s
.38272 .79563 m .33361 .29106 L .34365 .27995 L p .707 .577 .707 r
F P
0 g
s
.17228 .71917 m .17821 .75635 L .17106 .7639 L p .707 .577 .707 r
F P
0 g
s
.17146 .68717 m .16599 .63129 L .18234 .62343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36382 .69281 m .36975 .72999 L .35745 .72575 L p .707 .577 .707 r
F P
0 g
s
.35745 .72575 m .35152 .68857 L .36382 .69281 L p .707 .577 .707 r
F P
0 g
s
.17567 .81079 m .17237 .79223 L .17953 .78477 L p .707 .577 .707 r
F P
0 g
s
.17953 .78477 m .18283 .80333 L .17567 .81079 L p .707 .577 .707 r
F P
0 g
s
.64764 .75575 m .59854 .25119 L .61616 .25918 L p .707 .577 .707 r
F P
0 g
s
.34653 .61083 m .352 .66671 L .33108 .66307 L p .707 .577 .707 r
F P
0 g
s
.33108 .66307 m .32561 .60719 L .34653 .61083 L p .707 .577 .707 r
F P
0 g
s
.18234 .62343 m .1878 .6793 L .17146 .68717 L p .707 .577 .707 r
F P
0 g
s
.37048 .75496 m .37379 .77352 L .36156 .76971 L p .707 .577 .707 r
F P
0 g
s
.36156 .76971 m .35825 .75114 L .37048 .75496 L p .707 .577 .707 r
F P
0 g
s
.17821 .75635 m .17228 .71917 L .18859 .711 L p .707 .577 .707 r
F P
0 g
s
.1878 .6793 m .18234 .62343 L .20632 .61634 L p .707 .577 .707 r
F P
0 g
s
.18859 .711 m .19452 .74817 L .17821 .75635 L p .707 .577 .707 r
F P
0 g
s
.35152 .68857 m .35745 .72575 L .33676 .72389 L p .707 .577 .707 r
F P
0 g
s
.33676 .72389 m .33083 .68671 L .35152 .68857 L p .707 .577 .707 r
F P
0 g
s
.39275 .78452 m .34365 .27995 L .36672 .26885 L p .707 .577 .707 r
F P
0 g
s
.34365 .27995 m .39275 .78452 L .38272 .79563 L p .707 .577 .707 r
F P
0 g
s
.32561 .60719 m .33108 .66307 L .30378 .66179 L p .707 .577 .707 r
F P
0 g
s
.30378 .66179 m .29831 .60592 L .32561 .60719 L p .707 .577 .707 r
F P
0 g
s
.18283 .80333 m .17953 .78477 L .19582 .7765 L p .707 .577 .707 r
F P
0 g
s
.20632 .61634 m .21179 .67222 L .1878 .6793 L p .707 .577 .707 r
F P
0 g
s
.19582 .7765 m .19912 .79506 L .18283 .80333 L p .707 .577 .707 r
F P
0 g
s
.35825 .75114 m .36156 .76971 L .34096 .76838 L p .707 .577 .707 r
F P
0 g
s
.34096 .76838 m .33765 .74982 L .35825 .75114 L p .707 .577 .707 r
F P
0 g
s
.21179 .67222 m .20632 .61634 L .23559 .61073 L p .707 .577 .707 r
F P
0 g
s
.19452 .74817 m .18859 .711 L .21245 .703 L p .707 .577 .707 r
F P
0 g
s
.59854 .25119 m .64764 .75575 L .61811 .75059 L p .707 .577 .707 r
F P
0 g
s
.61811 .75059 m .56901 .24603 L .59854 .25119 L p .707 .577 .707 r
F P
0 g
s
.29831 .60592 m .30378 .66179 L .27276 .66301 L p .707 .577 .707 r
F P
0 g
s
.27276 .66301 m .26729 .60714 L .29831 .60592 L p .707 .577 .707 r
F P
0 g
s
.33083 .68671 m .33676 .72389 L .30971 .72459 L p .707 .577 .707 r
F P
0 g
s
.30971 .72459 m .30378 .68741 L .33083 .68671 L p .707 .577 .707 r
F P
0 g
s
.21245 .703 m .21838 .74018 L .19452 .74817 L p .707 .577 .707 r
F P
0 g
s
.24106 .66661 m .23559 .61073 L .26729 .60714 L p .707 .577 .707 r
F P
0 g
s
.23559 .61073 m .24106 .66661 L .21179 .67222 L p .707 .577 .707 r
F P
0 g
s
.73912 .6534 m .73365 .59752 L .70263 .59874 L p .707 .577 .707 r
F P
0 g
s
.73365 .59752 m .73912 .6534 L .77081 .6498 L p .707 .577 .707 r
F P
0 g
s
.77081 .6498 m .76535 .59393 L .73365 .59752 L p .707 .577 .707 r
F P
0 g
s
.26729 .60714 m .27276 .66301 L .24106 .66661 L p .707 .577 .707 r
F P
0 g
s
.76535 .59393 m .77081 .6498 L .80009 .64419 L p .707 .577 .707 r
F P
0 g
s
.80009 .64419 m .79462 .58831 L .76535 .59393 L p .707 .577 .707 r
F P
0 g
s
.19912 .79506 m .19582 .7765 L .21964 .76824 L p .707 .577 .707 r
F P
0 g
s
.7081 .65462 m .70263 .59874 L .67532 .59747 L p .707 .577 .707 r
F P
0 g
s
.70263 .59874 m .7081 .65462 L .73912 .6534 L p .707 .577 .707 r
F P
0 g
s
.21964 .76824 m .22294 .7868 L .19912 .79506 L p .707 .577 .707 r
F P
0 g
s
.21838 .74018 m .21245 .703 L .24154 .69598 L p .707 .577 .707 r
F P
0 g
s
.33765 .74982 m .34096 .76838 L .31401 .76967 L p .707 .577 .707 r
F P
0 g
s
.31401 .76967 m .3107 .75111 L .33765 .74982 L p .707 .577 .707 r
F P
0 g
s
.36672 .26885 m .41583 .77342 L .39275 .78452 L p .707 .577 .707 r
F P
0 g
s
.41583 .77342 m .36672 .26885 L .40058 .25886 L p .707 .577 .707 r
F P
0 g
s
.30378 .68741 m .30971 .72459 L .27894 .72778 L p .707 .577 .707 r
F P
0 g
s
.27894 .72778 m .27301 .69061 L .30378 .68741 L p .707 .577 .707 r
F P
0 g
s
.79462 .58831 m .80009 .64419 L .82407 .63711 L p .707 .577 .707 r
F P
0 g
s
.82407 .63711 m .8186 .58123 L .79462 .58831 L p .707 .577 .707 r
F P
0 g
s
.24154 .69598 m .24747 .73316 L .21838 .74018 L p .707 .577 .707 r
F P
0 g
s
.74479 .7104 m .73886 .67322 L .7081 .67642 L p .707 .577 .707 r
F P
0 g
s
.73886 .67322 m .74479 .7104 L .77626 .70503 L p .707 .577 .707 r
F P
0 g
s
.77626 .70503 m .77033 .66785 L .73886 .67322 L p .707 .577 .707 r
F P
0 g
s
.24747 .73316 m .24154 .69598 L .27301 .69061 L p .707 .577 .707 r
F P
0 g
s
.77033 .66785 m .77626 .70503 L .80535 .698 L p .707 .577 .707 r
F P
0 g
s
.80535 .698 m .79942 .66083 L .77033 .66785 L p .707 .577 .707 r
F P
0 g
s
.67532 .59747 m .68079 .65334 L .7081 .65462 L p .707 .577 .707 r
F P
0 g
s
.27301 .69061 m .27894 .72778 L .24747 .73316 L p .707 .577 .707 r
F P
0 g
s
.22294 .7868 m .21964 .76824 L .24866 .76079 L p .707 .577 .707 r
F P
0 g
s
.68079 .65334 m .67532 .59747 L .65441 .59383 L p .707 .577 .707 r
F P
0 g
s
.56901 .24603 m .61811 .75059 L .57956 .74877 L p .707 .577 .707 r
F P
0 g
s
.57956 .74877 m .53046 .24421 L .56901 .24603 L p .707 .577 .707 r
F P
0 g
s
.7081 .67642 m .71403 .71359 L .74479 .7104 L p .707 .577 .707 r
F P
0 g
s
.71403 .71359 m .7081 .67642 L .68105 .67712 L p .707 .577 .707 r
F P
0 g
s
.24866 .76079 m .25196 .77935 L .22294 .7868 L p .707 .577 .707 r
F P
0 g
s
.3107 .75111 m .31401 .76967 L .28334 .77345 L p .707 .577 .707 r
F P
0 g
s
.28334 .77345 m .28004 .75489 L .3107 .75111 L p .707 .577 .707 r
F P
0 g
s
.79942 .66083 m .80535 .698 L .82922 .69001 L p .707 .577 .707 r
F P
0 g
s
.82922 .69001 m .82329 .65284 L .79942 .66083 L p .707 .577 .707 r
F P
0 g
s
.74899 .74952 m .74569 .73096 L .71502 .73474 L p .707 .577 .707 r
F P
0 g
s
.74569 .73096 m .74899 .74952 L .78037 .74362 L p .707 .577 .707 r
F P
0 g
s
.78037 .74362 m .77707 .72506 L .74569 .73096 L p .707 .577 .707 r
F P
0 g
s
.8186 .58123 m .82407 .63711 L .84041 .62924 L p .707 .577 .707 r
F P
0 g
s
.84041 .62924 m .83495 .57337 L .8186 .58123 L p .707 .577 .707 r
F P
0 g
s
.77707 .72506 m .78037 .74362 L .80939 .73617 L p .707 .577 .707 r
F P
0 g
s
.80939 .73617 m .80609 .71761 L .77707 .72506 L p .707 .577 .707 r
F P
0 g
s
.25196 .77935 m .24866 .76079 L .28004 .75489 L p .707 .577 .707 r
F P
0 g
s
.68105 .67712 m .68698 .71429 L .71403 .71359 L p .707 .577 .707 r
F P
0 g
s
.71502 .73474 m .71833 .7533 L .74899 .74952 L p .707 .577 .707 r
F P
0 g
s
.28004 .75489 m .28334 .77345 L .25196 .77935 L p .707 .577 .707 r
F P
0 g
s
.65441 .59383 m .65987 .64971 L .68079 .65334 L p .707 .577 .707 r
F P
0 g
s
.71833 .7533 m .71502 .73474 L .68807 .73603 L p .707 .577 .707 r
F P
0 g
s
.44968 .76343 m .40058 .25886 L .44191 .25096 L p .707 .577 .707 r
F P
0 g
s
.40058 .25886 m .44968 .76343 L .41583 .77342 L p .707 .577 .707 r
F P
0 g
s
.68698 .71429 m .68105 .67712 L .66036 .67526 L p .707 .577 .707 r
F P
0 g
s
.68807 .73603 m .69138 .75459 L .71833 .7533 L p .707 .577 .707 r
F P
0 g
s
.80609 .71761 m .80939 .73617 L .83321 .72791 L p .707 .577 .707 r
F P
0 g
s
.83321 .72791 m .82991 .70935 L .80609 .71761 L p .707 .577 .707 r
F P
0 g
s
.65987 .64971 m .65441 .59383 L .64192 .58818 L p .707 .577 .707 r
F P
0 g
s
.53046 .24421 m .57956 .74877 L .53576 .75047 L p .707 .577 .707 r
F P
0 g
s
.53576 .75047 m .48666 .24591 L .53046 .24421 L p .707 .577 .707 r
F P
0 g
s
.82329 .65284 m .82922 .69001 L .84552 .68184 L p .707 .577 .707 r
F P
0 g
s
.84552 .68184 m .8396 .64466 L .82329 .65284 L p .707 .577 .707 r
F P
0 g
s
.66036 .67526 m .66629 .71244 L .68698 .71429 L p .707 .577 .707 r
F P
0 g
s
.49101 .75552 m .44191 .25096 L .48666 .24591 L p .707 .577 .707 r
F P
0 g
s
.44191 .25096 m .49101 .75552 L .44968 .76343 L p .707 .577 .707 r
F P
0 g
s
.69138 .75459 m .68807 .73603 L .66747 .7347 L p .707 .577 .707 r
F P
0 g
s
.83495 .57337 m .84041 .62924 L .84752 .62137 L p .707 .577 .707 r
F P
0 g
s
.84752 .62137 m .84205 .5655 L .83495 .57337 L p .707 .577 .707 r
F P
0 g
s
.48666 .24591 m .53576 .75047 L .49101 .75552 L p .707 .577 .707 r
F P
0 g
s
.66747 .7347 m .67078 .75327 L .69138 .75459 L p .707 .577 .707 r
F P
0 g
s
.64192 .58818 m .64739 .64406 L .65987 .64971 L p .707 .577 .707 r
F P
0 g
s
.82991 .70935 m .83321 .72791 L .8495 .71964 L p .707 .577 .707 r
F P
0 g
s
.8495 .71964 m .8462 .70108 L .82991 .70935 L p .707 .577 .707 r
F P
0 g
s
.64806 .67102 m .65399 .7082 L .66629 .71244 L p .707 .577 .707 r
F P
0 g
s
.64739 .64406 m .64192 .58818 L .6391 .58107 L p .707 .577 .707 r
F P
0 g
s
.8396 .64466 m .84552 .68184 L .85267 .67428 L p .707 .577 .707 r
F P
0 g
s
.85267 .67428 m .84674 .6371 L .8396 .64466 L p .707 .577 .707 r
F P
0 g
s
.67078 .75327 m .66747 .7347 L .65524 .73089 L p .707 .577 .707 r
F P
0 g
s
.65524 .73089 m .65855 .74945 L .67078 .75327 L p .707 .577 .707 r
F P
0 g
s
.84205 .5655 m .84752 .62137 L .84469 .61427 L p .707 .577 .707 r
F P
0 g
s
.84469 .61427 m .83923 .55839 L .84205 .5655 L p .707 .577 .707 r
F P
0 g
s
.6391 .58107 m .64456 .63695 L .64739 .64406 L p .707 .577 .707 r
F P
0 g
s
.8462 .70108 m .8495 .71964 L .85667 .71218 L p .707 .577 .707 r
F P
0 g
s
.85667 .71218 m .85336 .69362 L .8462 .70108 L p .707 .577 .707 r
F P
0 g
s
.65399 .7082 m .64806 .67102 L .64535 .66482 L p .707 .577 .707 r
F P
0 g
s
.64535 .66482 m .65128 .702 L .65399 .7082 L p .707 .577 .707 r
F P
0 g
s
.84674 .6371 m .85267 .67428 L .84996 .66808 L p .707 .577 .707 r
F P
0 g
s
.84996 .66808 m .84403 .6309 L .84674 .6371 L p .707 .577 .707 r
F P
0 g
s
.64456 .63695 m .6391 .58107 L .6462 .5732 L p .707 .577 .707 r
F P
0 g
s
.65855 .74945 m .65524 .73089 L .65258 .72496 L p .707 .577 .707 r
F P
0 g
s
.65258 .72496 m .65588 .74352 L .65855 .74945 L p .707 .577 .707 r
F P
0 g
s
.85336 .69362 m .85667 .71218 L .854 .70625 L p .707 .577 .707 r
F P
0 g
s
.854 .70625 m .8507 .68769 L .85336 .69362 L p .707 .577 .707 r
F P
0 g
s
.83923 .55839 m .84469 .61427 L .83221 .60862 L p .707 .577 .707 r
F P
0 g
s
.83221 .60862 m .82674 .55274 L .83923 .55839 L p .707 .577 .707 r
F P
0 g
s
.6462 .5732 m .65167 .62908 L .64456 .63695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65128 .702 m .64535 .66482 L .6525 .65726 L p .707 .577 .707 r
F P
0 g
s
.39611 .61945 m .39064 .56357 L .35962 .56479 L p .707 .577 .707 r
F P
0 g
s
.39064 .56357 m .39611 .61945 L .4278 .61585 L p .707 .577 .707 r
F P
0 g
s
.4278 .61585 m .42234 .55997 L .39064 .56357 L p .707 .577 .707 r
F P
0 g
s
.42234 .55997 m .4278 .61585 L .45708 .61024 L p .707 .577 .707 r
F P
0 g
s
.45708 .61024 m .45161 .55436 L .42234 .55997 L p .707 .577 .707 r
F P
0 g
s
.6525 .65726 m .65843 .69444 L .65128 .702 L p .707 .577 .707 r
F P
0 g
s
.65167 .62908 m .6462 .5732 L .66255 .56534 L p .707 .577 .707 r
F P
0 g
s
.84403 .6309 m .84996 .66808 L .83766 .66384 L p .707 .577 .707 r
F P
0 g
s
.83766 .66384 m .83173 .62666 L .84403 .6309 L p .707 .577 .707 r
F P
0 g
s
.36509 .62067 m .35962 .56479 L .33231 .56352 L p .707 .577 .707 r
F P
0 g
s
.35962 .56479 m .36509 .62067 L .39611 .61945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65588 .74352 m .65258 .72496 L .65974 .71749 L p .707 .577 .707 r
F P
0 g
s
.65974 .71749 m .66305 .73606 L .65588 .74352 L p .707 .577 .707 r
F P
0 g
s
.45161 .55436 m .45708 .61024 L .48106 .60316 L p .707 .577 .707 r
F P
0 g
s
.48106 .60316 m .47559 .54728 L .45161 .55436 L p .707 .577 .707 r
F P
0 g
s
.82674 .55274 m .83221 .60862 L .81129 .60498 L p .707 .577 .707 r
F P
0 g
s
.81129 .60498 m .80583 .5491 L .82674 .55274 L p .707 .577 .707 r
F P
0 g
s
.66255 .56534 m .66802 .62122 L .65167 .62908 L p .707 .577 .707 r
F P
0 g
s
.8507 .68769 m .854 .70625 L .84177 .70243 L p .707 .577 .707 r
F P
0 g
s
.84177 .70243 m .83847 .68387 L .8507 .68769 L p .707 .577 .707 r
F P
0 g
s
.40178 .68027 m .39585 .64309 L .36509 .64629 L p .707 .577 .707 r
F P
0 g
s
.39585 .64309 m .40178 .68027 L .43325 .6749 L p .707 .577 .707 r
F P
0 g
s
.43325 .6749 m .42732 .63772 L .39585 .64309 L p .707 .577 .707 r
F P
0 g
s
.33231 .56352 m .33778 .61939 L .36509 .62067 L p .707 .577 .707 r
F P
0 g
s
.42732 .63772 m .43325 .6749 L .46234 .66787 L p .707 .577 .707 r
F P
0 g
s
.46234 .66787 m .45641 .6307 L .42732 .63772 L p .707 .577 .707 r
F P
0 g
s
.33778 .61939 m .33231 .56352 L .3114 .55988 L p .707 .577 .707 r
F P
0 g
s
.65843 .69444 m .6525 .65726 L .6688 .64909 L p .707 .577 .707 r
F P
0 g
s
.36509 .64629 m .37102 .68346 L .40178 .68027 L p .707 .577 .707 r
F P
0 g
s
.37102 .68346 m .36509 .64629 L .33804 .64699 L p .707 .577 .707 r
F P
0 g
s
.66802 .62122 m .66255 .56534 L .68653 .55825 L p .707 .577 .707 r
F P
0 g
s
.45641 .6307 m .46234 .66787 L .48621 .65988 L p .707 .577 .707 r
F P
0 g
s
.48621 .65988 m .48028 .62271 L .45641 .6307 L p .707 .577 .707 r
F P
0 g
s
.47559 .54728 m .48106 .60316 L .4974 .59529 L p .707 .577 .707 r
F P
0 g
s
.4974 .59529 m .49194 .53942 L .47559 .54728 L p .707 .577 .707 r
F P
0 g
s
.6688 .64909 m .67473 .68626 L .65843 .69444 L p .707 .577 .707 r
F P
0 g
s
.40598 .72476 m .40268 .7062 L .37201 .70998 L p .707 .577 .707 r
F P
0 g
s
.40268 .7062 m .40598 .72476 L .43736 .71885 L p .707 .577 .707 r
F P
0 g
s
.43736 .71885 m .43406 .70029 L .40268 .7062 L p .707 .577 .707 r
F P
0 g
s
.83173 .62666 m .83766 .66384 L .81697 .66198 L p .707 .577 .707 r
F P
0 g
s
.81697 .66198 m .81104 .62481 L .83173 .62666 L p .707 .577 .707 r
F P
0 g
s
.33804 .64699 m .34397 .68416 L .37102 .68346 L p .707 .577 .707 r
F P
0 g
s
.43406 .70029 m .43736 .71885 L .46638 .71141 L p .707 .577 .707 r
F P
0 g
s
.46638 .71141 m .46308 .69284 L .43406 .70029 L p .707 .577 .707 r
F P
0 g
s
.3114 .55988 m .31686 .61576 L .33778 .61939 L p .707 .577 .707 r
F P
0 g
s
.37201 .70998 m .37532 .72854 L .40598 .72476 L p .707 .577 .707 r
F P
0 g
s
.66305 .73606 m .65974 .71749 L .67603 .70923 L p .707 .577 .707 r
F P
0 g
s
.80583 .5491 m .81129 .60498 L .78399 .60371 L p .707 .577 .707 r
F P
0 g
s
.78399 .60371 m .77852 .54783 L .80583 .5491 L p .707 .577 .707 r
F P
0 g
s
.37532 .72854 m .37201 .70998 L .34506 .71127 L p .707 .577 .707 r
F P
0 g
s
.67603 .70923 m .67934 .72779 L .66305 .73606 L p .707 .577 .707 r
F P
0 g
s
.68653 .55825 m .692 .61413 L .66802 .62122 L p .707 .577 .707 r
F P
0 g
s
.34397 .68416 m .33804 .64699 L .31735 .64513 L p .707 .577 .707 r
F P
0 g
s
.34506 .71127 m .34837 .72983 L .37532 .72854 L p .707 .577 .707 r
F P
0 g
s
.46308 .69284 m .46638 .71141 L .4902 .70315 L p .707 .577 .707 r
F P
0 g
s
.4902 .70315 m .4869 .68458 L .46308 .69284 L p .707 .577 .707 r
F P
0 g
s
.31686 .61576 m .3114 .55988 L .29891 .55423 L p .707 .577 .707 r
F P
0 g
s
.83847 .68387 m .84177 .70243 L .82117 .7011 L p .707 .577 .707 r
F P
0 g
s
.82117 .7011 m .81787 .68254 L .83847 .68387 L p .707 .577 .707 r
F P
0 g
s
.692 .61413 m .68653 .55825 L .7158 .55264 L p .707 .577 .707 r
F P
0 g
s
.67473 .68626 m .6688 .64909 L .69267 .6411 L p .707 .577 .707 r
F P
0 g
s
.48028 .62271 m .48621 .65988 L .50251 .65171 L p .707 .577 .707 r
F P
0 g
s
.50251 .65171 m .49659 .61453 L .48028 .62271 L p .707 .577 .707 r
F P
0 g
s
.31735 .64513 m .32328 .68231 L .34397 .68416 L p .707 .577 .707 r
F P
0 g
s
.77852 .54783 m .78399 .60371 L .75297 .60493 L p .707 .577 .707 r
F P
0 g
s
.75297 .60493 m .7475 .54905 L .77852 .54783 L p .707 .577 .707 r
F P
0 g
s
.81104 .62481 m .81697 .66198 L .78992 .66268 L p .707 .577 .707 r
F P
0 g
s
.78992 .66268 m .78399 .62551 L .81104 .62481 L p .707 .577 .707 r
F P
0 g
s
.49194 .53942 m .4974 .59529 L .50451 .58742 L p .707 .577 .707 r
F P
0 g
s
.50451 .58742 m .49904 .53155 L .49194 .53942 L p .707 .577 .707 r
F P
0 g
s
.34837 .72983 m .34506 .71127 L .32446 .70994 L p .707 .577 .707 r
F P
0 g
s
.69267 .6411 m .6986 .67827 L .67473 .68626 L p .707 .577 .707 r
F P
0 g
s
.29891 .55423 m .30438 .61011 L .31686 .61576 L p .707 .577 .707 r
F P
0 g
s
.72127 .60852 m .7158 .55264 L .7475 .54905 L p .707 .577 .707 r
F P
0 g
s
.7158 .55264 m .72127 .60852 L .692 .61413 L p .707 .577 .707 r
F P
0 g
s
.32446 .70994 m .32777 .7285 L .34837 .72983 L p .707 .577 .707 r
F P
0 g
s
.7475 .54905 m .75297 .60493 L .72127 .60852 L p .707 .577 .707 r
F P
0 g
s
.67934 .72779 m .67603 .70923 L .69985 .70096 L p .707 .577 .707 r
F P
0 g
s
.4869 .68458 m .4902 .70315 L .50649 .69488 L p .707 .577 .707 r
F P
0 g
s
.50649 .69488 m .50319 .67632 L .4869 .68458 L p .707 .577 .707 r
F P
0 g
s
.32328 .68231 m .31735 .64513 L .30505 .64089 L p .707 .577 .707 r
F P
0 g
s
.69985 .70096 m .70316 .71953 L .67934 .72779 L p .707 .577 .707 r
F P
0 g
s
.6986 .67827 m .69267 .6411 L .72176 .63407 L p .707 .577 .707 r
F P
0 g
s
.81787 .68254 m .82117 .7011 L .79422 .70239 L p .707 .577 .707 r
F P
0 g
s
.79422 .70239 m .79092 .68383 L .81787 .68254 L p .707 .577 .707 r
F P
0 g
s
.78399 .62551 m .78992 .66268 L .75916 .66588 L p .707 .577 .707 r
F P
0 g
s
.75916 .66588 m .75323 .6287 L .78399 .62551 L p .707 .577 .707 r
F P
0 g
s
.30438 .61011 m .29891 .55423 L .29609 .54712 L p .707 .577 .707 r
F P
0 g
s
.30505 .64089 m .31098 .67807 L .32328 .68231 L p .707 .577 .707 r
F P
0 g
s
.49659 .61453 m .50251 .65171 L .50966 .64415 L p .707 .577 .707 r
F P
0 g
s
.50966 .64415 m .50373 .60697 L .49659 .61453 L p .707 .577 .707 r
F P
0 g
s
.72176 .63407 m .72769 .67125 L .6986 .67827 L p .707 .577 .707 r
F P
0 g
s
.72769 .67125 m .72176 .63407 L .75323 .6287 L p .707 .577 .707 r
F P
0 g
s
.32777 .7285 m .32446 .70994 L .31223 .70612 L p .707 .577 .707 r
F P
0 g
s
.75323 .6287 m .75916 .66588 L .72769 .67125 L p .707 .577 .707 r
F P
0 g
s
.70316 .71953 m .69985 .70096 L .72887 .69352 L p .707 .577 .707 r
F P
0 g
s
.31223 .70612 m .31554 .72469 L .32777 .7285 L p .707 .577 .707 r
F P
0 g
s
.72887 .69352 m .73218 .71208 L .70316 .71953 L p .707 .577 .707 r
F P
0 g
s
.49904 .53155 m .50451 .58742 L .50168 .58032 L p .707 .577 .707 r
F P
0 g
s
.50168 .58032 m .49622 .52444 L .49904 .53155 L p .707 .577 .707 r
F P
0 g
s
.79092 .68383 m .79422 .70239 L .76355 .70618 L p .707 .577 .707 r
F P
0 g
s
.76355 .70618 m .76025 .68761 L .79092 .68383 L p .707 .577 .707 r
F P
0 g
s
.29609 .54712 m .30155 .603 L .30438 .61011 L p .707 .577 .707 r
F P
0 g
s
.50319 .67632 m .50649 .69488 L .51366 .68741 L p .707 .577 .707 r
F P
0 g
s
.51366 .68741 m .51035 .66885 L .50319 .67632 L p .707 .577 .707 r
F P
0 g
s
.73218 .71208 m .72887 .69352 L .76025 .68761 L p .707 .577 .707 r
F P
0 g
s
.76025 .68761 m .76355 .70618 L .73218 .71208 L p .707 .577 .707 r
F P
0 g
s
.31098 .67807 m .30505 .64089 L .30234 .63469 L p .707 .577 .707 r
F P
0 g
s
.30234 .63469 m .30827 .67187 L .31098 .67807 L p .707 .577 .707 r
F P
0 g
s
.30155 .603 m .29609 .54712 L .30319 .53925 L p .707 .577 .707 r
F P
0 g
s
.50373 .60697 m .50966 .64415 L .50695 .63795 L p .707 .577 .707 r
F P
0 g
s
.50695 .63795 m .50102 .60077 L .50373 .60697 L p .707 .577 .707 r
F P
0 g
s
.31554 .72469 m .31223 .70612 L .30957 .70019 L p .707 .577 .707 r
F P
0 g
s
.30957 .70019 m .31287 .71876 L .31554 .72469 L p .707 .577 .707 r
F P
0 g
s
.49622 .52444 m .50168 .58032 L .4892 .57467 L p .707 .577 .707 r
F P
0 g
s
.4892 .57467 m .48373 .51879 L .49622 .52444 L p .707 .577 .707 r
F P
0 g
s
.30319 .53925 m .30866 .59513 L .30155 .603 L p .707 .577 .707 r
F P
0 g
s
.51035 .66885 m .51366 .68741 L .51099 .68148 L p .707 .577 .707 r
F P
0 g
s
.51099 .68148 m .50769 .66292 L .51035 .66885 L p .707 .577 .707 r
F P
0 g
s
.30827 .67187 m .30234 .63469 L .30949 .62713 L p .707 .577 .707 r
F P
0 g
s
.30949 .62713 m .31542 .66431 L .30827 .67187 L p .707 .577 .707 r
F P
0 g
s
.30866 .59513 m .30319 .53925 L .31954 .53139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50102 .60077 m .50695 .63795 L .49465 .63371 L p .707 .577 .707 r
F P
0 g
s
.49465 .63371 m .48872 .59653 L .50102 .60077 L p .707 .577 .707 r
F P
0 g
s
.31287 .71876 m .30957 .70019 L .31673 .69273 L p .707 .577 .707 r
F P
0 g
s
.31673 .69273 m .32004 .71129 L .31287 .71876 L p .707 .577 .707 r
F P
0 g
s
.48373 .51879 m .4892 .57467 L .46828 .57103 L p .707 .577 .707 r
F P
0 g
s
.46828 .57103 m .46282 .51515 L .48373 .51879 L p .707 .577 .707 r
F P
0 g
s
.31954 .53139 m .32501 .58727 L .30866 .59513 L p .707 .577 .707 r
F P
0 g
s
.50769 .66292 m .51099 .68148 L .49876 .67767 L p .707 .577 .707 r
F P
0 g
s
.49876 .67767 m .49546 .6591 L .50769 .66292 L p .707 .577 .707 r
F P
0 g
s
.31542 .66431 m .30949 .62713 L .32579 .61896 L p .707 .577 .707 r
F P
0 g
s
.32501 .58727 m .31954 .53139 L .34352 .5243 L p .707 .577 .707 r
F P
0 g
s
.32579 .61896 m .33172 .65613 L .31542 .66431 L p .707 .577 .707 r
F P
0 g
s
.48872 .59653 m .49465 .63371 L .47396 .63185 L p .707 .577 .707 r
F P
0 g
s
.47396 .63185 m .46803 .59468 L .48872 .59653 L p .707 .577 .707 r
F P
0 g
s
.46282 .51515 m .46828 .57103 L .44098 .56976 L p .707 .577 .707 r
F P
0 g
s
.44098 .56976 m .43551 .51388 L .46282 .51515 L p .707 .577 .707 r
F P
0 g
s
.32004 .71129 m .31673 .69273 L .33302 .68446 L p .707 .577 .707 r
F P
0 g
s
.34352 .5243 m .34899 .58018 L .32501 .58727 L p .707 .577 .707 r
F P
0 g
s
.33302 .68446 m .33632 .70302 L .32004 .71129 L p .707 .577 .707 r
F P
0 g
s
.49546 .6591 m .49876 .67767 L .47816 .67634 L p .707 .577 .707 r
F P
0 g
s
.47816 .67634 m .47486 .65778 L .49546 .6591 L p .707 .577 .707 r
F P
0 g
s
.34899 .58018 m .34352 .5243 L .37279 .51869 L p .707 .577 .707 r
F P
0 g
s
.33172 .65613 m .32579 .61896 L .34966 .61097 L p .707 .577 .707 r
F P
0 g
s
.43551 .51388 m .44098 .56976 L .40996 .57098 L p .707 .577 .707 r
F P
0 g
s
.40996 .57098 m .40449 .5151 L .43551 .51388 L p .707 .577 .707 r
F P
0 g
s
.46803 .59468 m .47396 .63185 L .44691 .63255 L p .707 .577 .707 r
F P
0 g
s
.44691 .63255 m .44098 .59538 L .46803 .59468 L p .707 .577 .707 r
F P
0 g
s
.34966 .61097 m .35559 .64814 L .33172 .65613 L p .707 .577 .707 r
F P
0 g
s
.37826 .57457 m .37279 .51869 L .40449 .5151 L p .707 .577 .707 r
F P
0 g
s
.37279 .51869 m .37826 .57457 L .34899 .58018 L p .707 .577 .707 r
F P
0 g
s
.40449 .5151 m .40996 .57098 L .37826 .57457 L p .707 .577 .707 r
F P
0 g
s
.33632 .70302 m .33302 .68446 L .35684 .6762 L p .707 .577 .707 r
F P
0 g
s
.35684 .6762 m .36015 .69476 L .33632 .70302 L p .707 .577 .707 r
F P
0 g
s
.35559 .64814 m .34966 .61097 L .37875 .60394 L p .707 .577 .707 r
F P
0 g
s
.47486 .65778 m .47816 .67634 L .45121 .67763 L p .707 .577 .707 r
F P
0 g
s
.45121 .67763 m .44791 .65907 L .47486 .65778 L p .707 .577 .707 r
F P
0 g
s
.44098 .59538 m .44691 .63255 L .41615 .63575 L p .707 .577 .707 r
F P
0 g
s
.41615 .63575 m .41022 .59857 L .44098 .59538 L p .707 .577 .707 r
F P
0 g
s
.37875 .60394 m .38468 .64112 L .35559 .64814 L p .707 .577 .707 r
F P
0 g
s
.38468 .64112 m .37875 .60394 L .41022 .59857 L p .707 .577 .707 r
F P
0 g
s
.41022 .59857 m .41615 .63575 L .38468 .64112 L p .707 .577 .707 r
F P
0 g
s
.36015 .69476 m .35684 .6762 L .38586 .66875 L p .707 .577 .707 r
F P
0 g
s
.38586 .66875 m .38917 .68731 L .36015 .69476 L p .707 .577 .707 r
F P
0 g
s
.44791 .65907 m .45121 .67763 L .42054 .68141 L p .707 .577 .707 r
F P
0 g
s
.42054 .68141 m .41724 .66285 L .44791 .65907 L p .707 .577 .707 r
F P
0 g
s
.38917 .68731 m .38586 .66875 L .41724 .66285 L p .707 .577 .707 r
F P
0 g
s
.41724 .66285 m .42054 .68141 L .38917 .68731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
TGoo2`00PGoo0024Ool=000;FUH:001gOol007]oo`T000IJEP03001JEUYF01UJEPH0075oo`00MGoo
1P000UYF00<005YFFUH02UYF00<005YFFUH07eYF0P00Kgoo001`Ool50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0QFUH2001]Ool006eoo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF02=J
EVeoo`00JWoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
5UYFKGoo001WOol30007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00Oomoo`1ZOol006Eoo`800003FUH005YF00MJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EVaoo`00Hgoo0P000eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001QOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUI/Ool0061oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVaoo`00
Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001NOol01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<007ooOol0JGoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005mo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00
Ggoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol0061oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVYoo`00
H7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00H7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
06Moo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00H7oo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Mo
o`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Ioo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00
HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00HWoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001SOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001J
EUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF0007FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00005FUHH000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF
FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol0061oo`@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005aoo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001J
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001HOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0087oo2000?7oo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000GOol90004FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000?Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol0
05Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00;Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP06001JEUYFFUH005YF;Goo001DOol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUH000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYF001JEP0]Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05Eoo`03001JEP0000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00FUH0
0003FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE0006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000AJEP03001JEUYF00=JEP05001JEUYFFUH0000/
Ool004Mooa0000=JEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90007FUH70003FUH01@00FUIJEUYF0000;7oo0011Ool60004FUH00`00FUIJEP06
FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EPT000QJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001oogoo02Yoo`00?Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00
FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@00003
FUH0000000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUH00002FUH01P00FUIJEUYF001JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF
FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000UYF00@005YF000000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ0000AJEP8002eoo`00<Goo0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03
001JEUYF00H002ioo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF3P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000^Ool20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<00000eYF001JEP06FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00@00003FUH0000000D000EJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH00000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=J
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00=JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00AJEP03001JEUYF00=JEP@000QJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YF00001EYF00<005YF00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP04001JEP000007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002]oo`00;Goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ@000MJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0
02eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHD00000eYF001oo`0ZOol002eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6
0008FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH:0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000ZOol002ioo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP04FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF300000=JEP00FUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002Yoo`00;Woo00<005YF000015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@00003Ool0000000D000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0002Yoo`00;Woo00<005YF000015YF00<005YF
00000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001JEUYF009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH9
0002FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000[Ool002ioo`03
001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000AJEP@00003FUH005YF00MJEP03001JEUYF00AJEPL00003FUH005YF00YJEP03001JEUYF0080
0003FUH00000008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH0100025YF00<005YFFUH02EYF0`000eYF00@005YF000000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00004P00;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH=0007FUH00`00FUIJEP04FUH600000eYF001JEP07FUH00`00
FUIJEP07FUH200000eYF001JEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJ
EP04001JEUYFFUH70003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:goo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90004FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`0000=JEP00FUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YF00000UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00H000AJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00<0009JEP03001JEUYF00IJEP03001JEUYF009J
EP<000IJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH01000FUIJEUYF1@001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000002Yoo`00;Woo0P000eYF00<005YFFUH00UYF00<0
05YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000<0
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEPD00003FUH005YF00IJEP04001JEP000008
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000ZOol002moo`05001JEUYFFUH00005FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH20003FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00L000EJEP03001JEUYF00AJEP<000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00@000IJEP03001J
EUYF00MJEP03001JEUYF009JEQ<00003FUH007oo02Uoo`00<7oo0P0000=JEP00FUH015YF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00FUIJEP8000EJEP04001JEUYF
FUH20003FUH:0004FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00UYF0`0000=JEP00FUH025YF00<0
05YFFUH015YF20003Woo0P0000=JEP0000000P00:Goo000bOol400000eYF00000003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF000000040004FUH00`00FUH000070004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF008000AJEP03001J
EUYF00MJEP03001JEUYF00L0015oo`8000=JEP04001JEP00000YOol003Aoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800004FUH005YF0002FUH70003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH015YF20004goo0`001EYF
00<005YF0000:Goo000bOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP040003Ool3000COol20002
FUH00`00FUIJEP03FUH2000ZOol0031oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH40006Ool5000>Ool40005FUH01000FUIJ
EUYF0P00:goo000_Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF00000007Ool5000:Ool40002FUH00`00
FUIJEP04FUH01000FUH00000;Goo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH70008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUH005YF00001EYF0P000UYF00@005YFFUH000Moo`D000=oo`L000IJEP03001JEUYF00AJ
EP8002moo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
00=oo`D000EJEQD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF008000EJEP04001J
EP000006Ool80004FUH00`00FUIJEP07FUH01000FUIJEUYF0P00<Goo000^Ool01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH015YF10000goo10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009J
EPD000EJEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000cOol0
02moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00/000IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP0GFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000=Goo000_Ool00`00FUH0
0005FUH00`00FUIJEP03FUH40008FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0G
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Uoo`00;goo00<005YF0000
1EYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00D005YFFUIJEP0000=oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF01MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000_Ool00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH0000017oo
0eYF00<005YFFUH015YF00<005YFFUH085YF00<005YFFUH015YF2`001EYF00<005YFFUH01UYF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0049o
o`00;goo00@005YFFUH0009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EQ@000Aoo`04001JEUYF0006FUH00`00FUIJEP0JFUH=000:FUH;0004FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60016Ool002moo`03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0000800005Ool005YFFUH0000KFUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6
0004FUHD001<Ool0031oo`9JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH007oo00000UYF00<0
05YFFUH05EYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF0P0015YF00<005YFFUH00UYF1000DGoo000`Ool01EYF001JEUYF00001EYF00<005YF
FUH015YF00@005YFFUIJEP@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF00<0009JEP03001JEUYF015JEP@000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000AJEP03001JEUYF009JEP04001JEP00001AOol0031oo`80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0<FUH50002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
0005FUH01@00FUIJEUYF00000UYF00<007ooOol0Cgoo000aOol01000FUIJEP001EYF00<005YFFUH0
10001EYF00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P003EYF100025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP03001JEUYF009JEP80059oo`00<Woo0`0015YF100000=JEP00FUH01eYF00<005YFFUH015YF1`00
47oo0P0000=JEP0000000P002UYF0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF009J
EP80059oo`00=7oo1@001EYF00<005YFFUH01UYF00<005YFFUH0100057oo0`000eYF00@005YF0000
00QJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00`005=oo`00=Woo0P001eYF00<005YFFUH015YF
1P0057oo0P0000=JEP00FUH00eYF00@005YFFUH000IJEP8000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00=JEP03001JEUYF00=JEP04001JEP00001BOol003Aoo`800003FUH005YF00IJEP03001JEUYF00@0
0003Ool0000000<0019oo`8000=JEP03001JEUYF009JEP<00003OomJEUYF009JEP8000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYF001BOol003=oo`05001JEUYFFUH00006FUH4
0006Ool3000@Ool30005FUH00`00FUIJEP02FUH01000Oomoogoo0eYF00<005YF000025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001UYF00<005YFFUH00eYF00@005YF0000055oo`00<Woo0P0015YF00@005YFFUIJEP80
01Uoo`@00003FUH005YF00IJEP04001JEUYF0004Ool2FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
1eYF00<005YFFUH00eYF00@005YFFUH0055oo`00<Goo00<005YF000015YF00@005YF000001Aoo`L0
00EJEP03001JEUYF00EJEP<000Eoo`03FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEP0001<00003FUH007oo051oo`00
<Goo00<005YF00000eYF0`003goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P001goo0P00
15YF00<005YFFUH045YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
1EYF1@003Woo0P0000=JEP0000000P00D7oo000aOol01000FUH005YF0P003Woo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`004Goo0P00
0eYF00@005YF0000051oo`00<Goo00<005YF00004@001UYF00<005YFFUH01eYF00<005YFFUH015YF
0`003Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P004Woo0`001EYF00<005YF0000D7oo000aOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
000AOol20003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH4000COol20002FUH00`00FUIJEP03FUH2001AOol0035oo`80009JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD001Moo`800003FUH005YF00MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH6000017oo00000000
3goo100015YF00<005YFFUH00eYF00<007ooOol0D7oo000aOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000NOol60004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH:0006Ool5000:Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02001C
Ool0039oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Qoo`X000EJ
EP03001JEUYF00AJEP`00003FUH005YF008000]oo`D000Eoo`D000IJEP03001JEUYF00AJEP<005Eo
o`00=7oo5000>Goo30001Goo00@005YFFUH000=JEP<000eoo`D00003Ool000000080009JEP03001J
EUYF00MJEP03001JEUYF009JEP8005Moo`00TWoo00D005YFFUH005YF0080011oo`H000IJEP03001J
EUYF00MJEP03001JEP00008005Uoo`00Tgoo00<005YF00004`000eYF00<005YFFUH01eYF00<005YF
FUH015YF1000G7oo002COol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04001POol009=oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD006Aoo`00Tgoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01000JGoo002DOol200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH6001]Ool009Iooa@007=oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59004 .75323 m .59551 .69853 L .56449 .69354 L p .707 .577 .707 r
F P
0 g
s
.59551 .69853 m .59004 .75323 L .62173 .75524 L p .707 .577 .707 r
F P
0 g
s
.62173 .75524 m .6272 .70054 L .59551 .69853 L p .707 .577 .707 r
F P
0 g
s
.6272 .70054 m .62173 .75524 L .65101 .75407 L p .707 .577 .707 r
F P
0 g
s
.65101 .75407 m .65647 .69937 L .6272 .70054 L p .707 .577 .707 r
F P
0 g
s
.55902 .74825 m .56449 .69354 L .53718 .68606 L p .707 .577 .707 r
F P
0 g
s
.56449 .69354 m .55902 .74825 L .59004 .75323 L p .707 .577 .707 r
F P
0 g
s
.65647 .69937 m .65101 .75407 L .67499 .74984 L p .707 .577 .707 r
F P
0 g
s
.67499 .74984 m .68046 .69514 L .65647 .69937 L p .707 .577 .707 r
F P
0 g
s
.53171 .74077 m .53718 .68606 L .51626 .67682 L p .707 .577 .707 r
F P
0 g
s
.53718 .68606 m .53171 .74077 L .55902 .74825 L p .707 .577 .707 r
F P
0 g
s
.58385 .81668 m .58978 .78077 L .55902 .77386 L p .707 .577 .707 r
F P
0 g
s
.58978 .78077 m .58385 .81668 L .61532 .82041 L p .707 .577 .707 r
F P
0 g
s
.61532 .82041 m .62125 .78451 L .58978 .78077 L p .707 .577 .707 r
F P
0 g
s
.62125 .78451 m .61532 .82041 L .64441 .82062 L p .707 .577 .707 r
F P
0 g
s
.64441 .82062 m .65034 .78472 L .62125 .78451 L p .707 .577 .707 r
F P
0 g
s
.55309 .80977 m .55902 .77386 L .53196 .76447 L p .707 .577 .707 r
F P
0 g
s
.55902 .77386 m .55309 .80977 L .58385 .81668 L p .707 .577 .707 r
F P
0 g
s
.68046 .69514 m .67499 .74984 L .69134 .74296 L p .707 .577 .707 r
F P
0 g
s
.69134 .74296 m .6968 .68826 L .68046 .69514 L p .707 .577 .707 r
F P
0 g
s
.51626 .67682 m .5108 .73153 L .53171 .74077 L p .707 .577 .707 r
F P
0 g
s
.65034 .78472 m .64441 .82062 L .66828 .81727 L p .707 .577 .707 r
F P
0 g
s
.66828 .81727 m .67421 .78137 L .65034 .78472 L p .707 .577 .707 r
F P
0 g
s
.53196 .76447 m .52603 .80037 L .55309 .80977 L p .707 .577 .707 r
F P
0 g
s
.5108 .73153 m .51626 .67682 L .50378 .66673 L p .707 .577 .707 r
F P
0 g
s
.52603 .80037 m .53196 .76447 L .51128 .7535 L p .707 .577 .707 r
F P
0 g
s
.57945 .8614 m .58276 .84354 L .55209 .83607 L p .707 .577 .707 r
F P
0 g
s
.58276 .84354 m .57945 .8614 L .61083 .86565 L p .707 .577 .707 r
F P
0 g
s
.61083 .86565 m .61414 .84779 L .58276 .84354 L p .707 .577 .707 r
F P
0 g
s
.61414 .84779 m .61083 .86565 L .63985 .86626 L p .707 .577 .707 r
F P
0 g
s
.63985 .86626 m .64316 .84841 L .61414 .84779 L p .707 .577 .707 r
F P
0 g
s
.54879 .85392 m .55209 .83607 L .52514 .8261 L p .707 .577 .707 r
F P
0 g
s
.55209 .83607 m .54879 .85392 L .57945 .8614 L p .707 .577 .707 r
F P
0 g
s
.52514 .8261 m .52184 .84396 L .54879 .85392 L p .707 .577 .707 r
F P
0 g
s
.51128 .7535 m .50535 .7894 L .52603 .80037 L p .707 .577 .707 r
F P
0 g
s
.50378 .66673 m .49831 .72143 L .5108 .73153 L p .707 .577 .707 r
F P
0 g
s
.64316 .84841 m .63985 .86626 L .66367 .86317 L p .707 .577 .707 r
F P
0 g
s
.66367 .86317 m .66698 .84532 L .64316 .84841 L p .707 .577 .707 r
F P
0 g
s
.6968 .68826 m .69134 .74296 L .69844 .73411 L p .707 .577 .707 r
F P
0 g
s
.69844 .73411 m .70391 .67941 L .6968 .68826 L p .707 .577 .707 r
F P
0 g
s
.67421 .78137 m .66828 .81727 L .68458 .8107 L p .707 .577 .707 r
F P
0 g
s
.68458 .8107 m .69051 .77479 L .67421 .78137 L p .707 .577 .707 r
F P
0 g
s
.52184 .84396 m .52514 .8261 L .50454 .81462 L p .707 .577 .707 r
F P
0 g
s
.50535 .7894 m .51128 .7535 L .49897 .74203 L p .707 .577 .707 r
F P
0 g
s
.49831 .72143 m .50378 .66673 L .50095 .65676 L p .707 .577 .707 r
F P
0 g
s
.50454 .81462 m .50124 .83247 L .52184 .84396 L p .707 .577 .707 r
F P
0 g
s
.49897 .74203 m .49304 .77793 L .50535 .7894 L p .707 .577 .707 r
F P
0 g
s
.66698 .84532 m .66367 .86317 L .67996 .85669 L p .707 .577 .707 r
F P
0 g
s
.67996 .85669 m .68326 .83883 L .66698 .84532 L p .707 .577 .707 r
F P
0 g
s
.50124 .83247 m .50454 .81462 L .49231 .80275 L p .707 .577 .707 r
F P
0 g
s
.50095 .65676 m .49549 .71147 L .49831 .72143 L p .707 .577 .707 r
F P
0 g
s
.69051 .77479 m .68458 .8107 L .69173 .80154 L p .707 .577 .707 r
F P
0 g
s
.69173 .80154 m .69766 .76563 L .69051 .77479 L p .707 .577 .707 r
F P
0 g
s
.49231 .80275 m .48901 .8206 L .50124 .83247 L p .707 .577 .707 r
F P
0 g
s
.46423 .82209 m .51334 .32806 L .46954 .32104 L p .707 .577 .707 r
F P
0 g
s
.49304 .77793 m .49897 .74203 L .49626 .73119 L p .707 .577 .707 r
F P
0 g
s
.49549 .71147 m .50095 .65676 L .50806 .64791 L p .707 .577 .707 r
F P
0 g
s
.49626 .73119 m .49034 .76709 L .49304 .77793 L p .707 .577 .707 r
F P
0 g
s
.48901 .8206 m .49231 .80275 L .48965 .79164 L p .707 .577 .707 r
F P
0 g
s
.50806 .64791 m .50259 .70262 L .49549 .71147 L p .707 .577 .707 r
F P
0 g
s
.48965 .79164 m .48634 .80949 L .48901 .8206 L p .707 .577 .707 r
F P
0 g
s
.49034 .76709 m .49626 .73119 L .50341 .72203 L p .707 .577 .707 r
F P
0 g
s
.50259 .70262 m .50806 .64791 L .52441 .64103 L p .707 .577 .707 r
F P
0 g
s
.50341 .72203 m .49748 .75793 L .49034 .76709 L p .707 .577 .707 r
F P
0 g
s
.48634 .80949 m .48965 .79164 L .49681 .7824 L p .707 .577 .707 r
F P
0 g
s
.52441 .64103 m .51894 .69574 L .50259 .70262 L p .707 .577 .707 r
F P
0 g
s
.49681 .7824 m .49351 .80025 L .48634 .80949 L p .707 .577 .707 r
F P
0 g
s
.49748 .75793 m .50341 .72203 L .51972 .71545 L p .707 .577 .707 r
F P
0 g
s
.51972 .71545 m .51379 .75136 L .49748 .75793 L p .707 .577 .707 r
F P
0 g
s
.49351 .80025 m .49681 .7824 L .5131 .77591 L p .707 .577 .707 r
F P
0 g
s
.5131 .77591 m .50979 .79376 L .49351 .80025 L p .707 .577 .707 r
F P
0 g
s
.51334 .32806 m .46423 .82209 L .50899 .8249 L p .707 .577 .707 r
F P
0 g
s
.51894 .69574 m .52441 .64103 L .54839 .6368 L p .707 .577 .707 r
F P
0 g
s
.54839 .6368 m .54292 .69151 L .51894 .69574 L p .707 .577 .707 r
F P
0 g
s
.51379 .75136 m .51972 .71545 L .54358 .7121 L p .707 .577 .707 r
F P
0 g
s
.54358 .7121 m .53765 .74801 L .51379 .75136 L p .707 .577 .707 r
F P
0 g
s
.50979 .79376 m .5131 .77591 L .53692 .77282 L p .707 .577 .707 r
F P
0 g
s
.53692 .77282 m .53361 .79068 L .50979 .79376 L p .707 .577 .707 r
F P
0 g
s
.50899 .8249 m .55809 .33088 L .51334 .32806 L p .707 .577 .707 r
F P
0 g
s
.70391 .67941 m .69844 .73411 L .69562 .72415 L p .707 .577 .707 r
F P
0 g
s
.69562 .72415 m .70108 .66944 L .70391 .67941 L p .707 .577 .707 r
F P
0 g
s
.54292 .69151 m .54839 .6368 L .57766 .63563 L p .707 .577 .707 r
F P
0 g
s
.57766 .63563 m .57219 .69034 L .54292 .69151 L p .707 .577 .707 r
F P
0 g
s
.53765 .74801 m .54358 .7121 L .57267 .71231 L p .707 .577 .707 r
F P
0 g
s
.57267 .71231 m .56674 .74821 L .53765 .74801 L p .707 .577 .707 r
F P
0 g
s
.53361 .79068 m .53692 .77282 L .56594 .77343 L p .707 .577 .707 r
F P
0 g
s
.56594 .77343 m .56263 .79129 L .53361 .79068 L p .707 .577 .707 r
F P
0 g
s
.55809 .33088 m .50899 .8249 L .55031 .82324 L p .707 .577 .707 r
F P
0 g
s
.55031 .82324 m .59942 .32921 L .55809 .33088 L p .707 .577 .707 r
F P
0 g
s
.42044 .81507 m .46954 .32104 L .43099 .31051 L p .707 .577 .707 r
F P
0 g
s
.46954 .32104 m .42044 .81507 L .46423 .82209 L p .707 .577 .707 r
F P
0 g
s
.68326 .83883 m .67996 .85669 L .68712 .84744 L p .707 .577 .707 r
F P
0 g
s
.68712 .84744 m .69043 .82959 L .68326 .83883 L p .707 .577 .707 r
F P
0 g
s
.57219 .69034 m .57766 .63563 L .60936 .63764 L p .707 .577 .707 r
F P
0 g
s
.60936 .63764 m .60389 .69235 L .57219 .69034 L p .707 .577 .707 r
F P
0 g
s
.56674 .74821 m .57267 .71231 L .60414 .71605 L p .707 .577 .707 r
F P
0 g
s
.60414 .71605 m .59821 .75195 L .56674 .74821 L p .707 .577 .707 r
F P
0 g
s
.56263 .79129 m .56594 .77343 L .59732 .77769 L p .707 .577 .707 r
F P
0 g
s
.59732 .77769 m .59401 .79554 L .56263 .79129 L p .707 .577 .707 r
F P
0 g
s
.59942 .32921 m .55031 .82324 L .58417 .81725 L p .707 .577 .707 r
F P
0 g
s
.58417 .81725 m .63327 .32323 L .59942 .32921 L p .707 .577 .707 r
F P
0 g
s
.69766 .76563 m .69173 .80154 L .68902 .7907 L p .707 .577 .707 r
F P
0 g
s
.68902 .7907 m .69495 .75479 L .69766 .76563 L p .707 .577 .707 r
F P
0 g
s
.38189 .80453 m .43099 .31051 L .40146 .29748 L p .707 .577 .707 r
F P
0 g
s
.43099 .31051 m .38189 .80453 L .42044 .81507 L p .707 .577 .707 r
F P
0 g
s
.70108 .66944 m .69562 .72415 L .68313 .71406 L p .707 .577 .707 r
F P
0 g
s
.68313 .71406 m .6886 .65935 L .70108 .66944 L p .707 .577 .707 r
F P
0 g
s
.24703 .71355 m .2525 .65885 L .22148 .65386 L p .707 .577 .707 r
F P
0 g
s
.2525 .65885 m .24703 .71355 L .27873 .71556 L p .707 .577 .707 r
F P
0 g
s
.27873 .71556 m .28419 .66086 L .2525 .65885 L p .707 .577 .707 r
F P
0 g
s
.28419 .66086 m .27873 .71556 L .308 .71439 L p .707 .577 .707 r
F P
0 g
s
.308 .71439 m .31347 .65969 L .28419 .66086 L p .707 .577 .707 r
F P
0 g
s
.21601 .70857 m .22148 .65386 L .19417 .64638 L p .707 .577 .707 r
F P
0 g
s
.22148 .65386 m .21601 .70857 L .24703 .71355 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69043 .82959 m .68712 .84744 L .68446 .83634 L p .707 .577 .707 r
F P
0 g
s
.68446 .83634 m .68776 .81848 L .69043 .82959 L p .707 .577 .707 r
F P
0 g
s
.64038 .64263 m .63491 .69734 L .60389 .69235 L p .707 .577 .707 r
F P
0 g
s
.60389 .69235 m .60936 .63764 L .64038 .64263 L p .707 .577 .707 r
F P
0 g
s
.63491 .72296 m .62898 .75886 L .59821 .75195 L p .707 .577 .707 r
F P
0 g
s
.59821 .75195 m .60414 .71605 L .63491 .72296 L p .707 .577 .707 r
F P
0 g
s
.62798 .78516 m .62468 .80301 L .59401 .79554 L p .707 .577 .707 r
F P
0 g
s
.59401 .79554 m .59732 .77769 L .62798 .78516 L p .707 .577 .707 r
F P
0 g
s
.63327 .32323 m .58417 .81725 L .60725 .80754 L p .707 .577 .707 r
F P
0 g
s
.60725 .80754 m .65635 .31351 L .63327 .32323 L p .707 .577 .707 r
F P
0 g
s
.31347 .65969 m .308 .71439 L .33198 .71016 L p .707 .577 .707 r
F P
0 g
s
.33198 .71016 m .33745 .65546 L .31347 .65969 L p .707 .577 .707 r
F P
0 g
s
.69495 .75479 m .68902 .7907 L .67672 .77923 L p .707 .577 .707 r
F P
0 g
s
.67672 .77923 m .68265 .74332 L .69495 .75479 L p .707 .577 .707 r
F P
0 g
s
.6886 .65935 m .68313 .71406 L .66222 .70482 L p .707 .577 .707 r
F P
0 g
s
.66222 .70482 m .66768 .65011 L .6886 .65935 L p .707 .577 .707 r
F P
0 g
s
.1887 .70109 m .19417 .64638 L .17325 .63714 L p .707 .577 .707 r
F P
0 g
s
.19417 .64638 m .1887 .70109 L .21601 .70857 L p .707 .577 .707 r
F P
0 g
s
.35236 .79151 m .40146 .29748 L .38383 .28325 L p .707 .577 .707 r
F P
0 g
s
.40146 .29748 m .35236 .79151 L .38189 .80453 L p .707 .577 .707 r
F P
0 g
s
.24084 .77317 m .24677 .73727 L .21601 .73036 L p .707 .577 .707 r
F P
0 g
s
.24677 .73727 m .24084 .77317 L .27231 .77691 L p .707 .577 .707 r
F P
0 g
s
.27231 .77691 m .27824 .74101 L .24677 .73727 L p .707 .577 .707 r
F P
0 g
s
.27824 .74101 m .27231 .77691 L .3014 .77712 L p .707 .577 .707 r
F P
0 g
s
.3014 .77712 m .30733 .74121 L .27824 .74101 L p .707 .577 .707 r
F P
0 g
s
.21008 .76627 m .21601 .73036 L .18896 .72097 L p .707 .577 .707 r
F P
0 g
s
.21601 .73036 m .21008 .76627 L .24084 .77317 L p .707 .577 .707 r
F P
0 g
s
.33745 .65546 m .33198 .71016 L .34833 .70328 L p .707 .577 .707 r
F P
0 g
s
.34833 .70328 m .35379 .64858 L .33745 .65546 L p .707 .577 .707 r
F P
0 g
s
.17325 .63714 m .16779 .69185 L .1887 .70109 L p .707 .577 .707 r
F P
0 g
s
.68776 .81848 m .68446 .83634 L .67223 .82446 L p .707 .577 .707 r
F P
0 g
s
.67223 .82446 m .67553 .80661 L .68776 .81848 L p .707 .577 .707 r
F P
0 g
s
.30733 .74121 m .3014 .77712 L .32527 .77377 L p .707 .577 .707 r
F P
0 g
s
.32527 .77377 m .3312 .73787 L .30733 .74121 L p .707 .577 .707 r
F P
0 g
s
.18896 .72097 m .18303 .75687 L .21008 .76627 L p .707 .577 .707 r
F P
0 g
s
.66768 .65011 m .66222 .70482 L .63491 .69734 L p .707 .577 .707 r
F P
0 g
s
.63491 .69734 m .64038 .64263 L .66768 .65011 L p .707 .577 .707 r
F P
0 g
s
.16779 .69185 m .17325 .63714 L .16077 .62705 L p .707 .577 .707 r
F P
0 g
s
.23644 .81253 m .23975 .79468 L .20908 .7872 L p .707 .577 .707 r
F P
0 g
s
.23975 .79468 m .23644 .81253 L .26782 .81678 L p .707 .577 .707 r
F P
0 g
s
.26782 .81678 m .27113 .79893 L .23975 .79468 L p .707 .577 .707 r
F P
0 g
s
.18303 .75687 m .18896 .72097 L .16827 .71 L p .707 .577 .707 r
F P
0 g
s
.68265 .74332 m .67672 .77923 L .65603 .76826 L p .707 .577 .707 r
F P
0 g
s
.65603 .76826 m .66196 .73235 L .68265 .74332 L p .707 .577 .707 r
F P
0 g
s
.27113 .79893 m .26782 .81678 L .29684 .81739 L p .707 .577 .707 r
F P
0 g
s
.29684 .81739 m .30015 .79954 L .27113 .79893 L p .707 .577 .707 r
F P
0 g
s
.20578 .80506 m .20908 .7872 L .18213 .77724 L p .707 .577 .707 r
F P
0 g
s
.20908 .7872 m .20578 .80506 L .23644 .81253 L p .707 .577 .707 r
F P
0 g
s
.65635 .31351 m .60725 .80754 L .61728 .79504 L p .707 .577 .707 r
F P
0 g
s
.61728 .79504 m .66638 .30102 L .65635 .31351 L p .707 .577 .707 r
F P
0 g
s
.18213 .77724 m .17883 .79509 L .20578 .80506 L p .707 .577 .707 r
F P
0 g
s
.16827 .71 m .16234 .7459 L .18303 .75687 L p .707 .577 .707 r
F P
0 g
s
.16077 .62705 m .1553 .68175 L .16779 .69185 L p .707 .577 .707 r
F P
0 g
s
.30015 .79954 m .29684 .81739 L .32066 .81431 L p .707 .577 .707 r
F P
0 g
s
.32066 .81431 m .32397 .79645 L .30015 .79954 L p .707 .577 .707 r
F P
0 g
s
.3312 .73787 m .32527 .77377 L .34157 .7672 L p .707 .577 .707 r
F P
0 g
s
.34157 .7672 m .3475 .73129 L .3312 .73787 L p .707 .577 .707 r
F P
0 g
s
.35379 .64858 m .34833 .70328 L .35543 .69443 L p .707 .577 .707 r
F P
0 g
s
.35543 .69443 m .3609 .63973 L .35379 .64858 L p .707 .577 .707 r
F P
0 g
s
.35807 .62976 m .35261 .68447 L .34012 .67437 L p .707 .577 .707 r
F P
0 g
s
.34012 .67437 m .34559 .61967 L .35807 .62976 L p .707 .577 .707 r
F P
0 g
s
.3475 .73129 m .34157 .7672 L .34872 .75804 L p .707 .577 .707 r
F P
0 g
s
.34872 .75804 m .35465 .72213 L .3475 .73129 L p .707 .577 .707 r
F P
0 g
s
.35194 .71129 m .34601 .74719 L .34253 .74395 L p .707 .577 .707 r
F P
0 g
s
.34253 .74395 m .33371 .73573 L p .34437 .72144 L .707 .577 .707 r
F P
0 g
s
.34437 .72144 m .35194 .71129 L .34253 .74395 L .707 .577 .707 r
F
.33371 .73573 m .33964 .69982 L .35194 .71129 L p F P
0 g
s
.34476 .76962 m .34145 .78747 L .33864 .78474 L p .707 .577 .707 r
F P
0 g
s
.33864 .78474 m .32922 .77559 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.33964 .77158 m .34476 .76962 L .33864 .78474 L .707 .577 .707 r
F
.3674 .40935 m .36304 .49242 L .37984 .2692 L F
.32922 .77559 m .33253 .75774 L .34014 .76513 L p F P
0 g
s
.34014 .76513 m .34476 .76962 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.32922 .77559 m .34014 .76513 L .33964 .77158 L .707 .577 .707 r
F
.34559 .61967 m .34012 .67437 L .31921 .66514 L p F P
0 g
s
.33964 .69982 m .33371 .73573 L .31302 .72476 L p .707 .577 .707 r
F P
0 g
s
.31302 .72476 m .31895 .68885 L .33964 .69982 L p .707 .577 .707 r
F P
0 g
s
.33253 .75774 m .32922 .77559 L .30862 .76411 L p .707 .577 .707 r
F P
0 g
s
.30862 .76411 m .31193 .74626 L .33253 .75774 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .33473 .77728 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.37984 .2692 m .3724 .34407 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.31921 .66514 m .32467 .61043 L .34559 .61967 L p .707 .577 .707 r
F P
0 g
s
.3724 .34407 m .33074 .76322 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.33473 .77728 m .35427 .5807 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.35427 .5807 m .36304 .49242 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.36304 .49242 m .38383 .28325 L .38094 .27305 L p .707 .577 .707 r
F P
0 g
s
.38094 .27305 m .37984 .2692 L p .36304 .49242 L .707 .577 .707 r
F P
0 g
s
.3609 .63973 m .35543 .69443 L .35261 .68447 L p .707 .577 .707 r
F P
0 g
s
.35261 .68447 m .35807 .62976 L .3609 .63973 L p .707 .577 .707 r
F P
0 g
s
.34411 .79857 m .34742 .78072 L .34026 .78997 L p .707 .577 .707 r
F P
0 g
s
.35465 .72213 m .34872 .75804 L .34601 .74719 L p .707 .577 .707 r
F P
0 g
s
.34601 .74719 m .35194 .71129 L .35465 .72213 L p .707 .577 .707 r
F P
0 g
s
.34742 .78072 m .34411 .79857 L .34145 .78747 L p .707 .577 .707 r
F P
0 g
s
.34145 .78747 m .34476 .76962 L .34742 .78072 L p .707 .577 .707 r
F P
0 g
s
.38383 .28325 m .33473 .77728 L .35236 .79151 L p .707 .577 .707 r
F P
0 g
s
.17883 .79509 m .18213 .77724 L .16153 .76576 L p .707 .577 .707 r
F P
0 g
s
.16234 .7459 m .16827 .71 L .15597 .69853 L p .707 .577 .707 r
F P
0 g
s
.67553 .80661 m .67223 .82446 L .65163 .81298 L p .707 .577 .707 r
F P
0 g
s
.65163 .81298 m .65494 .79513 L .67553 .80661 L p .707 .577 .707 r
F P
0 g
s
.66196 .73235 m .65603 .76826 L .62898 .75886 L p .707 .577 .707 r
F P
0 g
s
.62898 .75886 m .63491 .72296 L .66196 .73235 L p .707 .577 .707 r
F P
0 g
s
.16153 .76576 m .15823 .78361 L .17883 .79509 L p .707 .577 .707 r
F P
0 g
s
.1553 .68175 m .16077 .62705 L .15795 .61708 L p .707 .577 .707 r
F P
0 g
s
.15597 .69853 m .15004 .73443 L .16234 .7459 L p .707 .577 .707 r
F P
0 g
s
.32397 .79645 m .32066 .81431 L .33695 .80782 L p .707 .577 .707 r
F P
0 g
s
.33695 .80782 m .34026 .78997 L .32397 .79645 L p .707 .577 .707 r
F P
0 g
s
.15823 .78361 m .16153 .76576 L .1493 .75388 L p .707 .577 .707 r
F P
0 g
s
.65494 .79513 m .65163 .81298 L .62468 .80301 L p .707 .577 .707 r
F P
0 g
s
.62468 .80301 m .62798 .78516 L .65494 .79513 L p .707 .577 .707 r
F P
0 g
s
.15795 .61708 m .15248 .67179 L .1553 .68175 L p .707 .577 .707 r
F P
0 g
s
.1493 .75388 m .146 .77173 L .15823 .78361 L p .707 .577 .707 r
F P
0 g
s
.15004 .73443 m .15597 .69853 L .15326 .68768 L p .707 .577 .707 r
F P
0 g
s
.66638 .30102 m .61728 .79504 L .61329 .78099 L p .707 .577 .707 r
F P
0 g
s
.61329 .78099 m .66239 .28696 L .66638 .30102 L p .707 .577 .707 r
F P
0 g
s
.15248 .67179 m .15795 .61708 L .16505 .60823 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .37984 .2692 L .38988 .2567 L p .707 .577 .707 r
F P
0 g
s
.15326 .68768 m .14733 .72359 L .15004 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34026 .78997 m .33695 .80782 L .34411 .79857 L p .707 .577 .707 r
F P
0 g
s
.146 .77173 m .1493 .75388 L .14664 .74278 L p .707 .577 .707 r
F P
0 g
s
.14664 .74278 m .14333 .76063 L .146 .77173 L p .707 .577 .707 r
F P
0 g
s
.16505 .60823 m .15958 .66294 L .15248 .67179 L p .707 .577 .707 r
F P
0 g
s
.14733 .72359 m .15326 .68768 L .1604 .67853 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15958 .66294 m .16505 .60823 L .1814 .60135 L p .707 .577 .707 r
F P
0 g
s
.1604 .67853 m .15447 .71443 L .14733 .72359 L p .707 .577 .707 r
F P
0 g
s
.66239 .28696 m .61329 .78099 L .59567 .76676 L p .707 .577 .707 r
F P
0 g
s
.59567 .76676 m .64477 .27273 L .66239 .28696 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14333 .76063 m .14664 .74278 L .1538 .73353 L p .707 .577 .707 r
F P
0 g
s
.34077 .75073 m .38988 .2567 L .41295 .24699 L p .707 .577 .707 r
F P
0 g
s
.38988 .2567 m .34077 .75073 L .33074 .76322 L p .707 .577 .707 r
F P
0 g
s
.1538 .73353 m .1505 .75138 L .14333 .76063 L p .707 .577 .707 r
F P
0 g
s
.1814 .60135 m .17593 .65606 L .15958 .66294 L p .707 .577 .707 r
F P
0 g
s
.15447 .71443 m .1604 .67853 L .17671 .67195 L p .707 .577 .707 r
F P
0 g
s
.17593 .65606 m .1814 .60135 L .20538 .59712 L p .707 .577 .707 r
F P
0 g
s
.17671 .67195 m .17078 .70786 L .15447 .71443 L p .707 .577 .707 r
F P
0 g
s
.1505 .75138 m .1538 .73353 L .17009 .72704 L p .707 .577 .707 r
F P
0 g
s
.32467 .61043 m .31921 .66514 L .2919 .65766 L p .707 .577 .707 r
F P
0 g
s
.2919 .65766 m .29737 .60295 L .32467 .61043 L p .707 .577 .707 r
F P
0 g
s
.20538 .59712 m .19991 .65183 L .17593 .65606 L p .707 .577 .707 r
F P
0 g
s
.64477 .27273 m .59567 .76676 L .56613 .75373 L p .707 .577 .707 r
F P
0 g
s
.56613 .75373 m .61524 .25971 L .64477 .27273 L p .707 .577 .707 r
F P
0 g
s
.17009 .72704 m .16678 .7449 L .1505 .75138 L p .707 .577 .707 r
F P
0 g
s
.19991 .65183 m .20538 .59712 L .23465 .59595 L p .707 .577 .707 r
F P
0 g
s
.17078 .70786 m .17671 .67195 L .20057 .6686 L p .707 .577 .707 r
F P
0 g
s
.41295 .24699 m .36385 .74101 L .34077 .75073 L p .707 .577 .707 r
F P
0 g
s
.36385 .74101 m .41295 .24699 L .44681 .241 L p .707 .577 .707 r
F P
0 g
s
.29737 .60295 m .2919 .65766 L .26088 .65267 L p .707 .577 .707 r
F P
0 g
s
.26088 .65267 m .26635 .59796 L .29737 .60295 L p .707 .577 .707 r
F P
0 g
s
.22918 .65066 m .23465 .59595 L .26635 .59796 L p .707 .577 .707 r
F P
0 g
s
.23465 .59595 m .22918 .65066 L .19991 .65183 L p .707 .577 .707 r
F P
0 g
s
.20057 .6686 m .19464 .70451 L .17078 .70786 L p .707 .577 .707 r
F P
0 g
s
.26635 .59796 m .26088 .65267 L .22918 .65066 L p .707 .577 .707 r
F P
0 g
s
.16678 .7449 m .17009 .72704 L .19391 .72396 L p .707 .577 .707 r
F P
0 g
s
.31895 .68885 m .31302 .72476 L .28597 .71536 L p .707 .577 .707 r
F P
0 g
s
.28597 .71536 m .2919 .67945 L .31895 .68885 L p .707 .577 .707 r
F P
0 g
s
.72724 .6612 m .73271 .60649 L .70169 .6015 L p .707 .577 .707 r
F P
0 g
s
.73271 .60649 m .72724 .6612 L .75894 .6632 L p .707 .577 .707 r
F P
0 g
s
.75894 .6632 m .76441 .6085 L .73271 .60649 L p .707 .577 .707 r
F P
0 g
s
.19464 .70451 m .20057 .6686 L .22966 .66881 L p .707 .577 .707 r
F P
0 g
s
.76441 .6085 m .75894 .6632 L .78821 .66204 L p .707 .577 .707 r
F P
0 g
s
.78821 .66204 m .79368 .60733 L .76441 .6085 L p .707 .577 .707 r
F P
0 g
s
.19391 .72396 m .19061 .74181 L .16678 .7449 L p .707 .577 .707 r
F P
0 g
s
.69622 .65621 m .70169 .6015 L .67439 .59402 L p .707 .577 .707 r
F P
0 g
s
.70169 .6015 m .69622 .65621 L .72724 .6612 L p .707 .577 .707 r
F P
0 g
s
.61524 .25971 m .56613 .75373 L .52758 .7432 L p .707 .577 .707 r
F P
0 g
s
.52758 .7432 m .57668 .24917 L .61524 .25971 L p .707 .577 .707 r
F P
0 g
s
.2919 .67945 m .28597 .71536 L .2552 .70845 L p .707 .577 .707 r
F P
0 g
s
.2552 .70845 m .26113 .67255 L .2919 .67945 L p .707 .577 .707 r
F P
0 g
s
.22966 .66881 m .22373 .70471 L .19464 .70451 L p .707 .577 .707 r
F P
0 g
s
.39771 .73503 m .44681 .241 L .48814 .23934 L p .707 .577 .707 r
F P
0 g
s
.44681 .241 m .39771 .73503 L .36385 .74101 L p .707 .577 .707 r
F P
0 g
s
.22373 .70471 m .22966 .66881 L .26113 .67255 L p .707 .577 .707 r
F P
0 g
s
.79368 .60733 m .78821 .66204 L .81219 .6578 L p .707 .577 .707 r
F P
0 g
s
.81219 .6578 m .81766 .6031 L .79368 .60733 L p .707 .577 .707 r
F P
0 g
s
.31193 .74626 m .30862 .76411 L .28167 .75415 L p .707 .577 .707 r
F P
0 g
s
.28167 .75415 m .28497 .73629 L .31193 .74626 L p .707 .577 .707 r
F P
0 g
s
.26113 .67255 m .2552 .70845 L .22373 .70471 L p .707 .577 .707 r
F P
0 g
s
.19061 .74181 m .19391 .72396 L .22293 .72457 L p .707 .577 .707 r
F P
0 g
s
.66892 .64873 m .67439 .59402 L .65347 .58478 L p .707 .577 .707 r
F P
0 g
s
.67439 .59402 m .66892 .64873 L .69622 .65621 L p .707 .577 .707 r
F P
0 g
s
.72106 .72464 m .72698 .68873 L .69622 .68183 L p .707 .577 .707 r
F P
0 g
s
.72698 .68873 m .72106 .72464 L .75252 .72838 L p .707 .577 .707 r
F P
0 g
s
.75252 .72838 m .75845 .69247 L .72698 .68873 L p .707 .577 .707 r
F P
0 g
s
.22293 .72457 m .21962 .74242 L .19061 .74181 L p .707 .577 .707 r
F P
0 g
s
.57668 .24917 m .52758 .7432 L .48379 .73618 L p .707 .577 .707 r
F P
0 g
s
.48379 .73618 m .53289 .24215 L .57668 .24917 L p .707 .577 .707 r
F P
0 g
s
.75845 .69247 m .75252 .72838 L .78162 .72858 L p .707 .577 .707 r
F P
0 g
s
.78162 .72858 m .78754 .69268 L .75845 .69247 L p .707 .577 .707 r
F P
0 g
s
.69029 .71773 m .69622 .68183 L .66917 .67243 L p .707 .577 .707 r
F P
0 g
s
.69622 .68183 m .69029 .71773 L .72106 .72464 L p .707 .577 .707 r
F P
0 g
s
.43904 .73336 m .48814 .23934 L .53289 .24215 L p .707 .577 .707 r
F P
0 g
s
.48814 .23934 m .43904 .73336 L .39771 .73503 L p .707 .577 .707 r
F P
0 g
s
.28497 .73629 m .28167 .75415 L .251 .74667 L p .707 .577 .707 r
F P
0 g
s
.251 .74667 m .25431 .72882 L .28497 .73629 L p .707 .577 .707 r
F P
0 g
s
.21962 .74242 m .22293 .72457 L .25431 .72882 L p .707 .577 .707 r
F P
0 g
s
.25431 .72882 m .251 .74667 L .21962 .74242 L p .707 .577 .707 r
F P
0 g
s
.53289 .24215 m .48379 .73618 L .43904 .73336 L p .707 .577 .707 r
F P
0 g
s
.81766 .6031 m .81219 .6578 L .82854 .65093 L p .707 .577 .707 r
F P
0 g
s
.82854 .65093 m .83401 .59622 L .81766 .6031 L p .707 .577 .707 r
F P
0 g
s
.65347 .58478 m .648 .63949 L .66892 .64873 L p .707 .577 .707 r
F P
0 g
s
.78754 .69268 m .78162 .72858 L .80548 .72523 L p .707 .577 .707 r
F P
0 g
s
.80548 .72523 m .81141 .68933 L .78754 .69268 L p .707 .577 .707 r
F P
0 g
s
.66917 .67243 m .66324 .70833 L .69029 .71773 L p .707 .577 .707 r
F P
0 g
s
.648 .63949 m .65347 .58478 L .64098 .57469 L p .707 .577 .707 r
F P
0 g
s
.66324 .70833 m .66917 .67243 L .64848 .66146 L p .707 .577 .707 r
F P
0 g
s
.71666 .76936 m .71996 .75151 L .6893 .74403 L p .707 .577 .707 r
F P
0 g
s
.71996 .75151 m .71666 .76936 L .74804 .77361 L p .707 .577 .707 r
F P
0 g
s
.74804 .77361 m .75134 .75576 L .71996 .75151 L p .707 .577 .707 r
F P
0 g
s
.75134 .75576 m .74804 .77361 L .77706 .77422 L p .707 .577 .707 r
F P
0 g
s
.77706 .77422 m .78036 .75637 L .75134 .75576 L p .707 .577 .707 r
F P
0 g
s
.68599 .76188 m .6893 .74403 L .66234 .73407 L p .707 .577 .707 r
F P
0 g
s
.6893 .74403 m .68599 .76188 L .71666 .76936 L p .707 .577 .707 r
F P
0 g
s
.66234 .73407 m .65904 .75192 L .68599 .76188 L p .707 .577 .707 r
F P
0 g
s
.64848 .66146 m .64255 .69736 L .66324 .70833 L p .707 .577 .707 r
F P
0 g
s
.64098 .57469 m .63552 .62939 L .648 .63949 L p .707 .577 .707 r
F P
0 g
s
.78036 .75637 m .77706 .77422 L .80088 .77113 L p .707 .577 .707 r
F P
0 g
s
.80088 .77113 m .80418 .75328 L .78036 .75637 L p .707 .577 .707 r
F P
0 g
s
.83401 .59622 m .82854 .65093 L .83565 .64207 L p .707 .577 .707 r
F P
0 g
s
.83565 .64207 m .84111 .58737 L .83401 .59622 L p .707 .577 .707 r
F P
0 g
s
.81141 .68933 m .80548 .72523 L .82179 .71866 L p .707 .577 .707 r
F P
0 g
s
.82179 .71866 m .82772 .68275 L .81141 .68933 L p .707 .577 .707 r
F P
0 g
s
.65904 .75192 m .66234 .73407 L .64174 .72258 L p .707 .577 .707 r
F P
0 g
s
.64255 .69736 m .64848 .66146 L .63618 .64999 L p .707 .577 .707 r
F P
0 g
s
.63552 .62939 m .64098 .57469 L .63816 .56473 L p .707 .577 .707 r
F P
0 g
s
.64174 .72258 m .63844 .74044 L .65904 .75192 L p .707 .577 .707 r
F P
0 g
s
.63618 .64999 m .63025 .68589 L .64255 .69736 L p .707 .577 .707 r
F P
0 g
s
.80418 .75328 m .80088 .77113 L .81717 .76465 L p .707 .577 .707 r
F P
0 g
s
.81717 .76465 m .82047 .7468 L .80418 .75328 L p .707 .577 .707 r
F P
0 g
s
.63844 .74044 m .64174 .72258 L .62951 .71071 L p .707 .577 .707 r
F P
0 g
s
.63816 .56473 m .63269 .61943 L .63552 .62939 L p .707 .577 .707 r
F P
0 g
s
.82772 .68275 m .82179 .71866 L .82893 .7095 L p .707 .577 .707 r
F P
0 g
s
.82893 .7095 m .83486 .6736 L .82772 .68275 L p .707 .577 .707 r
F P
0 g
s
.62951 .71071 m .62621 .72856 L .63844 .74044 L p .707 .577 .707 r
F P
0 g
s
.84111 .58737 m .83565 .64207 L .83282 .63211 L p .707 .577 .707 r
F P
0 g
s
.83282 .63211 m .83829 .57741 L .84111 .58737 L p .707 .577 .707 r
F P
0 g
s
.63025 .68589 m .63618 .64999 L .63347 .63915 L p .707 .577 .707 r
F P
0 g
s
.63269 .61943 m .63816 .56473 L .64527 .55587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63347 .63915 m .62754 .67505 L .63025 .68589 L p .707 .577 .707 r
F P
0 g
s
.82047 .7468 m .81717 .76465 L .82433 .7554 L p .707 .577 .707 r
F P
0 g
s
.82433 .7554 m .82763 .73755 L .82047 .7468 L p .707 .577 .707 r
F P
0 g
s
.62621 .72856 m .62951 .71071 L .62685 .6996 L p .707 .577 .707 r
F P
0 g
s
.64527 .55587 m .6398 .61058 L .63269 .61943 L p .707 .577 .707 r
F P
0 g
s
.62685 .6996 m .62355 .71746 L .62621 .72856 L p .707 .577 .707 r
F P
0 g
s
.83486 .6736 m .82893 .7095 L .82622 .69866 L p .707 .577 .707 r
F P
0 g
s
.82622 .69866 m .83215 .66275 L .83486 .6736 L p .707 .577 .707 r
F P
0 g
s
.62754 .67505 m .63347 .63915 L .64062 .62999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83829 .57741 m .83282 .63211 L .82034 .62202 L p .707 .577 .707 r
F P
0 g
s
.82034 .62202 m .82581 .56731 L .83829 .57741 L p .707 .577 .707 r
F P
0 g
s
.6398 .61058 m .64527 .55587 L .66161 .54899 L p .707 .577 .707 r
F P
0 g
s
.38423 .62151 m .3897 .56681 L .35868 .56182 L p .707 .577 .707 r
F P
0 g
s
.3897 .56681 m .38423 .62151 L .41593 .62352 L p .707 .577 .707 r
F P
0 g
s
.41593 .62352 m .4214 .56882 L .3897 .56681 L p .707 .577 .707 r
F P
0 g
s
.4214 .56882 m .41593 .62352 L .4452 .62235 L p .707 .577 .707 r
F P
0 g
s
.4452 .62235 m .45067 .56765 L .4214 .56882 L p .707 .577 .707 r
F P
0 g
s
.64062 .62999 m .63469 .66589 L .62754 .67505 L p .707 .577 .707 r
F P
0 g
s
.35321 .61653 m .35868 .56182 L .33138 .55434 L p .707 .577 .707 r
F P
0 g
s
.35868 .56182 m .35321 .61653 L .38423 .62151 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82763 .73755 m .82433 .7554 L .82166 .7443 L p .707 .577 .707 r
F P
0 g
s
.82166 .7443 m .82497 .72644 L .82763 .73755 L p .707 .577 .707 r
F P
0 g
s
.62355 .71746 m .62685 .6996 L .63401 .69036 L p .707 .577 .707 r
F P
0 g
s
.45067 .56765 m .4452 .62235 L .46918 .61812 L p .707 .577 .707 r
F P
0 g
s
.46918 .61812 m .47465 .56342 L .45067 .56765 L p .707 .577 .707 r
F P
0 g
s
.66161 .54899 m .65614 .6037 L .6398 .61058 L p .707 .577 .707 r
F P
0 g
s
.63401 .69036 m .63071 .70821 L .62355 .71746 L p .707 .577 .707 r
F P
0 g
s
.83215 .66275 m .82622 .69866 L .81392 .68719 L p .707 .577 .707 r
F P
0 g
s
.81392 .68719 m .81985 .65128 L .83215 .66275 L p .707 .577 .707 r
F P
0 g
s
.82581 .56731 m .82034 .62202 L .79942 .61278 L p .707 .577 .707 r
F P
0 g
s
.79942 .61278 m .80489 .55807 L .82581 .56731 L p .707 .577 .707 r
F P
0 g
s
.32591 .60905 m .33138 .55434 L .31046 .5451 L p .707 .577 .707 r
F P
0 g
s
.33138 .55434 m .32591 .60905 L .35321 .61653 L p .707 .577 .707 r
F P
0 g
s
.63469 .66589 m .64062 .62999 L .65692 .62342 L p .707 .577 .707 r
F P
0 g
s
.37805 .68114 m .38397 .64523 L .35321 .63833 L p .707 .577 .707 r
F P
0 g
s
.38397 .64523 m .37805 .68114 L .40951 .68488 L p .707 .577 .707 r
F P
0 g
s
.40951 .68488 m .41544 .64897 L .38397 .64523 L p .707 .577 .707 r
F P
0 g
s
.65614 .6037 m .66161 .54899 L .68559 .54476 L p .707 .577 .707 r
F P
0 g
s
.41544 .64897 m .40951 .68488 L .43861 .68508 L p .707 .577 .707 r
F P
0 g
s
.43861 .68508 m .44453 .64918 L .41544 .64897 L p .707 .577 .707 r
F P
0 g
s
.34728 .67423 m .35321 .63833 L .32616 .62893 L p .707 .577 .707 r
F P
0 g
s
.35321 .63833 m .34728 .67423 L .37805 .68114 L p .707 .577 .707 r
F P
0 g
s
.65692 .62342 m .65099 .65932 L .63469 .66589 L p .707 .577 .707 r
F P
0 g
s
.47465 .56342 m .46918 .61812 L .48553 .61125 L p .707 .577 .707 r
F P
0 g
s
.48553 .61125 m .491 .55654 L .47465 .56342 L p .707 .577 .707 r
F P
0 g
s
.31046 .5451 m .30499 .59981 L .32591 .60905 L p .707 .577 .707 r
F P
0 g
s
.82497 .72644 m .82166 .7443 L .80944 .73242 L p .707 .577 .707 r
F P
0 g
s
.80944 .73242 m .81274 .71457 L .82497 .72644 L p .707 .577 .707 r
F P
0 g
s
.63071 .70821 m .63401 .69036 L .6503 .68387 L p .707 .577 .707 r
F P
0 g
s
.44453 .64918 m .43861 .68508 L .46247 .68173 L p .707 .577 .707 r
F P
0 g
s
.46247 .68173 m .4684 .64583 L .44453 .64918 L p .707 .577 .707 r
F P
0 g
s
.32616 .62893 m .32023 .66483 L .34728 .67423 L p .707 .577 .707 r
F P
0 g
s
.80489 .55807 m .79942 .61278 L .77212 .6053 L p .707 .577 .707 r
F P
0 g
s
.77212 .6053 m .77758 .55059 L .80489 .55807 L p .707 .577 .707 r
F P
0 g
s
.30499 .59981 m .31046 .5451 L .29797 .53501 L p .707 .577 .707 r
F P
0 g
s
.37365 .72049 m .37695 .70264 L .34629 .69517 L p .707 .577 .707 r
F P
0 g
s
.37695 .70264 m .37365 .72049 L .40503 .72474 L p .707 .577 .707 r
F P
0 g
s
.40503 .72474 m .40833 .70689 L .37695 .70264 L p .707 .577 .707 r
F P
0 g
s
.68559 .54476 m .68013 .59947 L .65614 .6037 L p .707 .577 .707 r
F P
0 g
s
.32023 .66483 m .32616 .62893 L .30547 .61796 L p .707 .577 .707 r
F P
0 g
s
.81985 .65128 m .81392 .68719 L .79323 .67622 L p .707 .577 .707 r
F P
0 g
s
.79323 .67622 m .79916 .64031 L .81985 .65128 L p .707 .577 .707 r
F P
0 g
s
.68013 .59947 m .68559 .54476 L .71487 .5436 L p .707 .577 .707 r
F P
0 g
s
.40833 .70689 m .40503 .72474 L .43405 .72536 L p .707 .577 .707 r
F P
0 g
s
.43405 .72536 m .43735 .7075 L .40833 .70689 L p .707 .577 .707 r
F P
0 g
s
.6503 .68387 m .647 .70172 L .63071 .70821 L p .707 .577 .707 r
F P
0 g
s
.34298 .71302 m .34629 .69517 L .31933 .6852 L p .707 .577 .707 r
F P
0 g
s
.34629 .69517 m .34298 .71302 L .37365 .72049 L p .707 .577 .707 r
F P
0 g
s
.65099 .65932 m .65692 .62342 L .68079 .62007 L p .707 .577 .707 r
F P
0 g
s
.31933 .6852 m .31603 .70305 L .34298 .71302 L p .707 .577 .707 r
F P
0 g
s
.30547 .61796 m .29954 .65386 L .32023 .66483 L p .707 .577 .707 r
F P
0 g
s
.77758 .55059 m .77212 .6053 L .7411 .60031 L p .707 .577 .707 r
F P
0 g
s
.7411 .60031 m .74656 .5456 L .77758 .55059 L p .707 .577 .707 r
F P
0 g
s
.7094 .5983 m .71487 .5436 L .74656 .5456 L p .707 .577 .707 r
F P
0 g
s
.71487 .5436 m .7094 .5983 L .68013 .59947 L p .707 .577 .707 r
F P
0 g
s
.29797 .53501 m .29251 .58971 L .30499 .59981 L p .707 .577 .707 r
F P
0 g
s
.43735 .7075 m .43405 .72536 L .45787 .72227 L p .707 .577 .707 r
F P
0 g
s
.45787 .72227 m .46117 .70441 L .43735 .7075 L p .707 .577 .707 r
F P
0 g
s
.68079 .62007 m .67486 .65597 L .65099 .65932 L p .707 .577 .707 r
F P
0 g
s
.31603 .70305 m .31933 .6852 L .29873 .67372 L p .707 .577 .707 r
F P
0 g
s
.4684 .64583 m .46247 .68173 L .47878 .67516 L p .707 .577 .707 r
F P
0 g
s
.47878 .67516 m .48471 .63925 L .4684 .64583 L p .707 .577 .707 r
F P
0 g
s
.74656 .5456 m .7411 .60031 L .7094 .5983 L p .707 .577 .707 r
F P
0 g
s
.491 .55654 m .48553 .61125 L .49264 .60239 L p .707 .577 .707 r
F P
0 g
s
.49264 .60239 m .4981 .54769 L .491 .55654 L p .707 .577 .707 r
F P
0 g
s
.29954 .65386 m .30547 .61796 L .29317 .60649 L p .707 .577 .707 r
F P
0 g
s
.81274 .71457 m .80944 .73242 L .78884 .72094 L p .707 .577 .707 r
F P
0 g
s
.78884 .72094 m .79214 .70309 L .81274 .71457 L p .707 .577 .707 r
F P
0 g
s
.79916 .64031 m .79323 .67622 L .76618 .66682 L p .707 .577 .707 r
F P
0 g
s
.76618 .66682 m .77211 .63092 L .79916 .64031 L p .707 .577 .707 r
F P
0 g
s
.647 .70172 m .6503 .68387 L .67412 .68078 L p .707 .577 .707 r
F P
0 g
s
.29873 .67372 m .29543 .69157 L .31603 .70305 L p .707 .577 .707 r
F P
0 g
s
.67486 .65597 m .68079 .62007 L .70988 .62027 L p .707 .577 .707 r
F P
0 g
s
.29251 .58971 m .29797 .53501 L .29515 .52505 L p .707 .577 .707 r
F P
0 g
s
.67412 .68078 m .67082 .69864 L .647 .70172 L p .707 .577 .707 r
F P
0 g
s
.29317 .60649 m .28724 .64239 L .29954 .65386 L p .707 .577 .707 r
F P
0 g
s
.77211 .63092 m .76618 .66682 L .73542 .65991 L p .707 .577 .707 r
F P
0 g
s
.73542 .65991 m .74135 .62401 L .77211 .63092 L p .707 .577 .707 r
F P
0 g
s
.46117 .70441 m .45787 .72227 L .47416 .71578 L p .707 .577 .707 r
F P
0 g
s
.47416 .71578 m .47746 .69793 L .46117 .70441 L p .707 .577 .707 r
F P
0 g
s
.70988 .62027 m .70395 .65618 L .67486 .65597 L p .707 .577 .707 r
F P
0 g
s
.70395 .65618 m .70988 .62027 L .74135 .62401 L p .707 .577 .707 r
F P
0 g
s
.29543 .69157 m .29873 .67372 L .2865 .66184 L p .707 .577 .707 r
F P
0 g
s
.74135 .62401 m .73542 .65991 L .70395 .65618 L p .707 .577 .707 r
F P
0 g
s
.79214 .70309 m .78884 .72094 L .76188 .71097 L p .707 .577 .707 r
F P
0 g
s
.76188 .71097 m .76519 .69312 L .79214 .70309 L p .707 .577 .707 r
F P
0 g
s
.29515 .52505 m .28968 .57975 L .29251 .58971 L p .707 .577 .707 r
F P
0 g
s
.48471 .63925 m .47878 .67516 L .48592 .666 L p .707 .577 .707 r
F P
0 g
s
.48592 .666 m .49185 .6301 L .48471 .63925 L p .707 .577 .707 r
F P
0 g
s
.67082 .69864 m .67412 .68078 L .70314 .6814 L p .707 .577 .707 r
F P
0 g
s
.2865 .66184 m .2832 .6797 L .29543 .69157 L p .707 .577 .707 r
F P
0 g
s
.28724 .64239 m .29317 .60649 L .29046 .59565 L p .707 .577 .707 r
F P
0 g
s
.4981 .54769 m .49264 .60239 L .48981 .59243 L p .707 .577 .707 r
F P
0 g
s
.48981 .59243 m .49528 .53773 L .4981 .54769 L p .707 .577 .707 r
F P
0 g
s
.70314 .6814 m .69984 .69925 L .67082 .69864 L p .707 .577 .707 r
F P
0 g
s
.28968 .57975 m .29515 .52505 L .30226 .51619 L p .707 .577 .707 r
F P
0 g
s
.76519 .69312 m .76188 .71097 L .73122 .7035 L p .707 .577 .707 r
F P
0 g
s
.73122 .7035 m .73452 .68565 L .76519 .69312 L p .707 .577 .707 r
F P
0 g
s
.69984 .69925 m .70314 .6814 L .73452 .68565 L p .707 .577 .707 r
F P
0 g
s
.29046 .59565 m .28453 .63155 L .28724 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73452 .68565 m .73122 .7035 L .69984 .69925 L p .707 .577 .707 r
F P
0 g
s
.47746 .69793 m .47416 .71578 L .48132 .70654 L p .707 .577 .707 r
F P
0 g
s
.48132 .70654 m .48462 .68868 L .47746 .69793 L p .707 .577 .707 r
F P
0 g
s
.2832 .6797 m .2865 .66184 L .28384 .65074 L p .707 .577 .707 r
F P
0 g
s
.28384 .65074 m .28054 .66859 L .2832 .6797 L p .707 .577 .707 r
F P
0 g
s
.30226 .51619 m .29679 .5709 L .28968 .57975 L p .707 .577 .707 r
F P
0 g
s
.49185 .6301 m .48592 .666 L .48321 .65516 L p .707 .577 .707 r
F P
0 g
s
.48321 .65516 m .48914 .61925 L .49185 .6301 L p .707 .577 .707 r
F P
0 g
s
.28453 .63155 m .29046 .59565 L .29761 .58649 L p .707 .577 .707 r
F P
0 g
s
.49528 .53773 m .48981 .59243 L .47733 .58234 L p .707 .577 .707 r
F P
0 g
s
.47733 .58234 m .4828 .52763 L .49528 .53773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29679 .5709 m .30226 .51619 L .3186 .50931 L p .707 .577 .707 r
F P
0 g
s
.29761 .58649 m .29168 .62239 L .28453 .63155 L p .707 .577 .707 r
F P
0 g
s
.48462 .68868 m .48132 .70654 L .47865 .69543 L p .707 .577 .707 r
F P
0 g
s
.47865 .69543 m .48196 .67758 L .48462 .68868 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28054 .66859 m .28384 .65074 L .291 .64149 L p .707 .577 .707 r
F P
0 g
s
.291 .64149 m .2877 .65934 L .28054 .66859 L p .707 .577 .707 r
F P
0 g
s
.3186 .50931 m .31313 .56402 L .29679 .5709 L p .707 .577 .707 r
F P
0 g
s
.48914 .61925 m .48321 .65516 L .47091 .64369 L p .707 .577 .707 r
F P
0 g
s
.47091 .64369 m .47684 .60778 L .48914 .61925 L p .707 .577 .707 r
F P
0 g
s
.4828 .52763 m .47733 .58234 L .45641 .5731 L p .707 .577 .707 r
F P
0 g
s
.45641 .5731 m .46188 .51839 L .4828 .52763 L p .707 .577 .707 r
F P
0 g
s
.29168 .62239 m .29761 .58649 L .31391 .57991 L p .707 .577 .707 r
F P
0 g
s
.31313 .56402 m .3186 .50931 L .34258 .50508 L p .707 .577 .707 r
F P
0 g
s
.31391 .57991 m .30798 .61582 L .29168 .62239 L p .707 .577 .707 r
F P
0 g
s
.48196 .67758 m .47865 .69543 L .46642 .68356 L p .707 .577 .707 r
F P
0 g
s
.46642 .68356 m .46973 .6657 L .48196 .67758 L p .707 .577 .707 r
F P
0 g
s
.2877 .65934 m .291 .64149 L .30729 .63501 L p .707 .577 .707 r
F P
0 g
s
.46188 .51839 m .45641 .5731 L .42911 .56562 L p .707 .577 .707 r
F P
0 g
s
.42911 .56562 m .43457 .51091 L .46188 .51839 L p .707 .577 .707 r
F P
0 g
s
.34258 .50508 m .33712 .55979 L .31313 .56402 L p .707 .577 .707 r
F P
0 g
s
.47684 .60778 m .47091 .64369 L .45022 .63272 L p .707 .577 .707 r
F P
0 g
s
.45022 .63272 m .45615 .59681 L .47684 .60778 L p .707 .577 .707 r
F P
0 g
s
.30729 .63501 m .30399 .65286 L .2877 .65934 L p .707 .577 .707 r
F P
0 g
s
.33712 .55979 m .34258 .50508 L .37186 .50391 L p .707 .577 .707 r
F P
0 g
s
.30798 .61582 m .31391 .57991 L .33778 .57657 L p .707 .577 .707 r
F P
0 g
s
.43457 .51091 m .42911 .56562 L .39809 .56063 L p .707 .577 .707 r
F P
0 g
s
.39809 .56063 m .40355 .50592 L .43457 .51091 L p .707 .577 .707 r
F P
0 g
s
.36639 .55862 m .37186 .50391 L .40355 .50592 L p .707 .577 .707 r
F P
0 g
s
.37186 .50391 m .36639 .55862 L .33712 .55979 L p .707 .577 .707 r
F P
0 g
s
.33778 .57657 m .33185 .61247 L .30798 .61582 L p .707 .577 .707 r
F P
0 g
s
.40355 .50592 m .39809 .56063 L .36639 .55862 L p .707 .577 .707 r
F P
0 g
s
.46973 .6657 m .46642 .68356 L .44583 .67207 L p .707 .577 .707 r
F P
0 g
s
.44583 .67207 m .44913 .65422 L .46973 .6657 L p .707 .577 .707 r
F P
0 g
s
.30399 .65286 m .30729 .63501 L .33111 .63192 L p .707 .577 .707 r
F P
0 g
s
.45615 .59681 m .45022 .63272 L .42317 .62332 L p .707 .577 .707 r
F P
0 g
s
.42317 .62332 m .4291 .58742 L .45615 .59681 L p .707 .577 .707 r
F P
0 g
s
.33185 .61247 m .33778 .57657 L .36687 .57677 L p .707 .577 .707 r
F P
0 g
s
.33111 .63192 m .32781 .64977 L .30399 .65286 L p .707 .577 .707 r
F P
0 g
s
.4291 .58742 m .42317 .62332 L .39241 .61641 L p .707 .577 .707 r
F P
0 g
s
.39241 .61641 m .39834 .58051 L .4291 .58742 L p .707 .577 .707 r
F P
0 g
s
.36687 .57677 m .36094 .61267 L .33185 .61247 L p .707 .577 .707 r
F P
0 g
s
.36094 .61267 m .36687 .57677 L .39834 .58051 L p .707 .577 .707 r
F P
0 g
s
.44913 .65422 m .44583 .67207 L .41887 .66211 L p .707 .577 .707 r
F P
0 g
s
.41887 .66211 m .42218 .64426 L .44913 .65422 L p .707 .577 .707 r
F P
0 g
s
.39834 .58051 m .39241 .61641 L .36094 .61267 L p .707 .577 .707 r
F P
0 g
s
.32781 .64977 m .33111 .63192 L .36013 .63253 L p .707 .577 .707 r
F P
0 g
s
.36013 .63253 m .35683 .65038 L .32781 .64977 L p .707 .577 .707 r
F P
0 g
s
.42218 .64426 m .41887 .66211 L .38821 .65463 L p .707 .577 .707 r
F P
0 g
s
.38821 .65463 m .39151 .63678 L .42218 .64426 L p .707 .577 .707 r
F P
0 g
s
.35683 .65038 m .36013 .63253 L .39151 .63678 L p .707 .577 .707 r
F P
0 g
s
.39151 .63678 m .38821 .65463 L .35683 .65038 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007eooad008=o
o`00N7oo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH01P00OGoo001dOol40007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001hOol0079oo`800003FUH005YF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Aoo`00L7oo
0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000L7oo001^Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001]Ool006eoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001[Ool006aoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEUYFFUH2001YOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH2001W
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001UOol006]oo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP8006Aoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000069oo`00Jgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00D005YFFUIJEP00065oo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00Ggoo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001Z
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001ZOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<007ooOol0GGoo001ZOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006Yoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF0000Ggoo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUIoo`1OOol006Uoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EWoo05moo`00JGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05mo
o`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05moo`00JGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000H7oo001YOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH0001POol006Uoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0H7oo001Y
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1POol006Qoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo061oo`00J7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
065oo`00J7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00065oo`00J7oo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0HGoo001XOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIoo`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH00`00FUH0001ROol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001SOol006Moo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001V
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001UOol005iooaL000=JEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00FGoo
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol0
05Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001V
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000:Ool?
001=Ool005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP02FUH90014Ool0
05=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20004Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH6000nOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol0059oo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH2000hOol0059oo`03001JEP0000AJEP04001JEUYFFUH;0004FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo00<005YF00000eYF1@0000=J
EP00FUH01EYF00<005YFFUH01@0000=JEP0000000`000UYF1P001UYF00<005YFFUH015YF00D005YF
FUH005YF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008003Aoo`00DWoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF
00AJEQ<0009JEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`06001J
EP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF0`001EYF
00H005YFFUIJEP00FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000aOol0059oo`8000=JEP03001JEUYF00=JEPL00003FUH005YF00MJEP@0
00EJEP03001JEUYF00IJEP04001JEP000003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002mo
o`00DWoo0P000eYF1P000eYF00@005YFFUIJEPT00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001BOol20002FUH200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH20003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH00`00FUH00002FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH4000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002eo
o`00>Goo3P002goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF009JEPT0009oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF
00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH0
1000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool0
035oo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
008000AJEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30003
FUH500000eYF001JEP05FUH60004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0017oo10001UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF10000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@00003
FUH0000000X0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003FUH5000015YF001JEUYF0P0000=oo`0000001@000UYF1`001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH000040003FUH00`00FUIJEP02FUH200000eYF001JEP03FUH=0002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH@00000eYF001JEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP030006
FUH00`00FUH00005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUH000030003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH02000FUIJ
EP00FUH005YF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF009JEP<000AJEP8000IJEP03001JEUYF009J
EP<0009JEP03001JEUYF00=JEP@00003FUH005YF00EJEP03001JEUYF009JEP8000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001oo`0]
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000=JEP03001JEUYF009JEPh00003FUH005YF009JEPD00003FUH005YF00QJ
EP8000IJEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEPH000=JEP03001J
EUYF00EJEP03001JEUYF00@00003FUH0000000<00003FUH005YF00UJEP<000AJEP04001JEUYFFUH3
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJ
EP03001JEUYF009JEP8002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1P0000=JEP00FUH02EYF00@005YFFUH0009JEP03001JEUYF009JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001J
EP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
2EYF00@005YFFUIJEP<000AJEP<000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP8000=JEP07001JEUYFFUH005YF0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH01000FUIJEUYF100015YF0`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF0P00<7oo000[Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0003FUH01000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YF00001`000eYF0P000UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF0P00<7oo000[Ool00`00FUH00004FUH01000FUIJEUYF5P0015YF0P000eYF1@0000=JEP00
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEP00
00@000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP@0035oo`00:goo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH01000
0Woo2`0000AJEP00001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH005YF009JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000bOol002]oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH?0004FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1EYF0`000UYF00@005YFFUIJEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000003FUH60004FUH20004Ool400000eYF000000040006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH0000aOol002]oo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF1@000eYF0`000UYF100000AJEP00000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0
00IJEP03001JEUYF00<000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01@00FUIJEP00FUH00`0015YF00<005YFFUH00eYF0P001goo2`000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF100015YF10001EYF1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEP8000=JEP03001JEUYF00=JEP80009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH30002FUH00`00FUIJEP03FUH01000
FUH000002Woo0`000goo10001eYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF
00<005YFFUH00eYF400000=JEP00FUH01UYF00D005YF001JEP0000EJEP03001JEUYF00D00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00EJEP800005FUH00000FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP030005
FUH01@00FUIJEUYF000027oo1@001Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEP8002moo`00
:goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF0P000eYF00D005YFFUIJ
EP0000IJEPH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP03001JEP0000800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00=J
EP<000=JEP05001JEUYFFUH00008Ool50008Ool300000eYF001JEP05FUH01P00FUIJEP00FUH002mo
o`00:goo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00001000
0eYF0`0000=JEP00FUH01EYF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP8000Moo`D000]o
o`8000IJEP06001JEUYF001JEP00;goo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0P001UYF0P0000=JEP00FUH01EYF
2@000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00=JEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEQ0000Eoo`<000io
o`8000=JEP07001JEUYFFUH005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30002FUH01@00FUH005YF00001UYF
00<005YFFUH00UYF4P000eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0`000eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P004Woo0P0000=JEP00FUH0
0UYF0P00<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000015YF001JEP001EYF00<005YFFUH00eYF1@002UYF00<0
05YFFUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P004Goo0P000eYF0P00
<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH01000FUIJEUYF0`0000=JEP00FUH015YF00<005YFFUH00eYF1@002UYF00<005YFFUH0
1UYF1@002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF500000AJEP00FUH0
031oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YF000000=JEP03001JEUYF00EJEP@000=JEP03001JEUYF00AJEP@000YJEP03001JEUYF
00QJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo02moo`00:Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1eYF00<005YFFUH010002EYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP00009JEP04001JEUYFFUH>
0006FUH00`00FUIJEP07FUH00`00FUH000040006FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`001eYF00<005YFFUH015YF1@0015YF00<005YFFUH025YF00<005YFFUH01EYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF000000=J
EP@00003FUH005YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00=JEP03001JEUYF009JEP80035oo`00:Woo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP07FUH00`00FUIJEP05000:FUH0
0`00FUIJEP050002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF1@001UYF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF0P00<Goo000ZOol20003FUH50007Ool70002FUH70006FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00
00=JEP0000001EYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<Goo000ZOol00eYF001JEP05000@Ool=0002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30007
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00<005YFFUH00UYF
0P000UYF0P00<Woo000YOol01000FUH000000UYF00@005YFFUH001Qoo`P000IJEP03001JEUYF00=J
EP03001JEP00009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0006FUH00`00FUIJEP03FUH300000eYF001JEP07FUH01000FUIJEUYF0`000UYF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP04001JEP00000bOol002Uoo`<000=JEP04001JEUYFFUH2000NOol20003
FUH00`00FUIJEP04FUH00`00FUH00006FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00000015YF00<005YFFUH00eYF00<005YFFUH00`001UYF00@005YFFUIJEPD00003FUH005YF
00AJEP<00003FUH005YF00EJEP<003=oo`00:Goo00<005YF00000eYF00<005YFFUH00UYF1`003Goo
0`002Woo0P0000=JEP00FUH01EYF00<005YF00001EYF00<005YFFUH00eYF10000UYF00<005YFFUH0
1EYF00@005YFFUIJEPD000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF1P00
25YF0`001UYF00<005YF0000<goo000YOol00`00FUIJEP03FUH50003FUH01000FUIJEUYF2@000goo
1@002goo0P001UYF00<005YF00001EYF00<005YFFUH01eYF3P002UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF10001UYF00<005YFFUH00UYF0P000goo
300025YF00<005YFFUH00P000eYF00D005YFFUIJEP00039oo`00:Woo00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF20003Goo0P000eYF0P001eYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00P001EYF00L005YFFUIJEP00FUH0000:OolA
00001Goo000005YF00000eYF00<007ooOol0<7oo000ZOol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH00eYF30001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF0000009JEP03001JEUYF00=JEP<0009JEP07001JEUYFFUH005YF00007Woo0P00
0eYF0P00<Goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH40008Ool400000eYF001JEP05FUH00`00FUIJEP03FUH:0002FUH00`00FUIJEP07FUH9
0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001UYF00@0
05YF000000AJEP80025oo`05001JEP00FUH0000aOol002Yoo`8000=JEP04001JEUYFFUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000070003FUH00`00FUH00005FUH700000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01`00FUH005YF001JEP0000IJEP04001JEUYFFUH20002FUH2000ROol200000eYF
001oo`0`Ool002Uoo`8000=JEPD00003FUH005YF00AJEPT000AJEP03001JEUYF00MJEP04001JEUYF
FUH30006FUH00`00FUH00003FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH50009FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH00`00FUIJ
EP04FUH4000SOol00`00FUH0000aOol002Uoo`800004FUH000000005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH70006FUH00`00FUIJEP04FUH20004FUH200000eYF001JEP0200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH40005FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP04
000NOol3000bOol002Uoo`<000=oo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP@0009JEP03001JEUYF00EJEP<0009JEP800003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@00003FUH005YF00MJEP03
001JEUYF00=JEP800003FUH005YF00IJEP<000IJEP03001JEUYF00AJEPL001Eoo`800003FUH00000
039oo`00:7oo0`001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF
00<005YFFUH01P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF10001eYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00@005YF000000=J
EP03001JEUYF00MJEP03001JEUYF009JEPP000Qoo`D000=JEP80039oo`00:7oo10001goo0`001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP@000AJEP03
001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04
001JEUYFFUH20005FUH00`00FUIJEP03FUH50007FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<0
05YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000cOol002Qoo`05001JEP00FUH00009
Ool400000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH20003Ool20004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<goo000XOol2
0003FUH00`00Oomoo`0:Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20006FUH20005FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUH00005Ool300000eYF001JEP05FUH00`00FUIJ
EP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00=7oo
000YOol01000FUIJEUYF0`003Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0P000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YF000027oo0P001UYF00H005YFFUH005YF
0002Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000=Woo000YOol01@00FUIJ
EUYF00000UYF00<007ooOol03goo2@000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
000000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH0000:Ool20003FUH01`00FUIJEUYF
001JEP0000Uoo`P000AJEP04001JEUYFFUH5000hOol002Yoo`03001JEP0000AJEP8001AooaL00003
FUH005YF00aJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH2000015YF001JEP0037oo0P0000=JEP00FUH00UYF0P004Woo2000
?Goo000[Ool20006FUH2000BOol5000BOol2000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000?Ool20003FUH2001G
Ool002aoo`03001JEUYF00AJEP03001JEP0000<000ioo`D001=oo`8000aJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00aoo`H00004FUH005YF001GOol002eoo`8000AJEP03001JEUYF00=JEPD000Yoo`<001Eoo`<001EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF00=JEPl000=J
EP03001JEUYF00800003FUH007oo05Ioo`00;goo00@005YFFUH000QJEP03001JEUYF00@001ioo`@0
01AJEP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEP000002FUH01000FUH000000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001GOol0031o
o`<000QJEP03001JEUYF00AJEPD001Moo`@0009oo`80019JEP03001JEUYF00UJEP03001JEUYF00UJ
EP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF
00<005YFFUH00UYF0P00F7oo000bOol20006FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002
FUH20004Ool2000LFUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01P00FUIJEP00FUH000MJEP8000=JEP03001JEUYF009JEP8005Qoo`00=7oo10000UYF00<005YF
FUH01eYF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0006Ool3000IFUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP06FUH3
00000eYF001JEP03FUH2001HOol003Qoo`@000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF008000Yoo`<002=JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH00000008000MJEP03001JEUYF008000=JEP8005Uoo`00?7oo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000ioo`@001iJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH20004FUH00`00FUIJEP03FUH2
00000eYF0000001IOol003moo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000COol4000JFUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`000UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0`00FWoo0012Ool60004FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@006Goo10005UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001P0025YF0`001UYF
00<005YF0000FWoo0018Ool@000ROol6000@FUH00`00FUIJEP09FUH00`00FUIJEP05FUH;0008FUH0
0`00FUIJEP020003FUH01@00FUIJEUYF0000FGoo0020Ool:0006FUH00`00FUIJEP09FUH00`00FUIJ
EP050005OolB00001Goo000005YF00000eYF00<007ooOol0Egoo002:OolE000;Ool3000AOol20003
FUH2001HOol008eoo`8000IJEP04001JEP00000WOol01@00FUH005YF0000F7oo002>Ool00`00FUIJ
EP04FUH01000FUIJEUYF0P009Woo0P0000=JEP00Ool0Egoo002?Ool20003FUH00`00FUIJEP04FUH4
000SOol00`00FUH0001HOol0095oo`800003FUH005YF00IJEP03001JEUYF00@001ioo`<005Uoo`00
Tgoo0`001UYF00<005YFFUH015YF1@005goo0P0000=JEP000000FGoo002FOol20003FUH00`00FUIJ
EP07FUH00`00FUIJEP04000>Ool50003FUH2001IOol009Qoo`800003FUH005YF00QJEP03001JEUYF
00AJEPh000=JEP04001JEUYFFUH2001JOol009Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2001JOol009ioo`@0009JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2001KOol00:9oo`D000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001MOol00:Moo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001OOol0
0:]oo`h006Aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58613 .75537 m .59496 .70149 L .56418 .69463 L p .707 .577 .707 r
F P
0 g
s
.59496 .70149 m .58613 .75537 L .61761 .75907 L p .707 .577 .707 r
F P
0 g
s
.61761 .75907 m .62643 .7052 L .59496 .70149 L p .707 .577 .707 r
F P
0 g
s
.62643 .7052 m .61761 .75907 L .6467 .75925 L p .707 .577 .707 r
F P
0 g
s
.6467 .75925 m .65553 .70537 L .62643 .7052 L p .707 .577 .707 r
F P
0 g
s
.55536 .7485 m .56418 .69463 L .53713 .68527 L p .707 .577 .707 r
F P
0 g
s
.56418 .69463 m .55536 .7485 L .58613 .75537 L p .707 .577 .707 r
F P
0 g
s
.65553 .70537 m .6467 .75925 L .67057 .75588 L p .707 .577 .707 r
F P
0 g
s
.67057 .75588 m .67939 .702 L .65553 .70537 L p .707 .577 .707 r
F P
0 g
s
.5283 .73915 m .53713 .68527 L .51643 .67434 L p .707 .577 .707 r
F P
0 g
s
.53713 .68527 m .5283 .73915 L .55536 .7485 L p .707 .577 .707 r
F P
0 g
s
.5759 .82053 m .58542 .78584 L .55531 .77595 L p .707 .577 .707 r
F P
0 g
s
.58542 .78584 m .5759 .82053 L .60678 .82697 L p .707 .577 .707 r
F P
0 g
s
.60678 .82697 m .6163 .79228 L .58542 .78584 L p .707 .577 .707 r
F P
0 g
s
.54579 .81064 m .55531 .77595 L .52891 .76356 L p .707 .577 .707 r
F P
0 g
s
.55531 .77595 m .54579 .81064 L .5759 .82053 L p .707 .577 .707 r
F P
0 g
s
.6163 .79228 m .60678 .82697 L .6354 .82931 L p .707 .577 .707 r
F P
0 g
s
.6354 .82931 m .64492 .79462 L .6163 .79228 L p .707 .577 .707 r
F P
0 g
s
.51643 .67434 m .50761 .72821 L .5283 .73915 L p .707 .577 .707 r
F P
0 g
s
.67939 .702 m .67057 .75588 L .68688 .7493 L p .707 .577 .707 r
F P
0 g
s
.68688 .7493 m .6957 .69542 L .67939 .702 L p .707 .577 .707 r
F P
0 g
s
.50761 .72821 m .51643 .67434 L .50413 .6629 L p .707 .577 .707 r
F P
0 g
s
.51939 .79825 m .52891 .76356 L .50881 .74989 L p .707 .577 .707 r
F P
0 g
s
.52891 .76356 m .51939 .79825 L .54579 .81064 L p .707 .577 .707 r
F P
0 g
s
.64492 .79462 m .6354 .82931 L .65896 .82734 L p .707 .577 .707 r
F P
0 g
s
.65896 .82734 m .66849 .79265 L .64492 .79462 L p .707 .577 .707 r
F P
0 g
s
.56867 .8671 m .57397 .84997 L .54412 .83919 L p .707 .577 .707 r
F P
0 g
s
.57397 .84997 m .56867 .8671 L .59932 .87433 L p .707 .577 .707 r
F P
0 g
s
.59932 .87433 m .60461 .85721 L .57397 .84997 L p .707 .577 .707 r
F P
0 g
s
.53882 .85632 m .54412 .83919 L .51798 .82592 L p .707 .577 .707 r
F P
0 g
s
.54412 .83919 m .53882 .85632 L .56867 .8671 L p .707 .577 .707 r
F P
0 g
s
.60461 .85721 m .59932 .87433 L .62776 .87731 L p .707 .577 .707 r
F P
0 g
s
.62776 .87731 m .63305 .86019 L .60461 .85721 L p .707 .577 .707 r
F P
0 g
s
.50881 .74989 m .49929 .78458 L .51939 .79825 L p .707 .577 .707 r
F P
0 g
s
.50413 .6629 m .4953 .71677 L .50761 .72821 L p .707 .577 .707 r
F P
0 g
s
.51798 .82592 m .51268 .84305 L .53882 .85632 L p .707 .577 .707 r
F P
0 g
s
.6957 .69542 m .68688 .7493 L .69403 .74015 L p .707 .577 .707 r
F P
0 g
s
.69403 .74015 m .70285 .68627 L .6957 .69542 L p .707 .577 .707 r
F P
0 g
s
.49929 .78458 m .50881 .74989 L .49698 .73628 L p .707 .577 .707 r
F P
0 g
s
.51268 .84305 m .51798 .82592 L .49811 .81146 L p .707 .577 .707 r
F P
0 g
s
.66849 .79265 m .65896 .82734 L .67516 .82124 L p .707 .577 .707 r
F P
0 g
s
.67516 .82124 m .68469 .78655 L .66849 .79265 L p .707 .577 .707 r
F P
0 g
s
.4953 .71677 m .50413 .6629 L .50141 .65207 L p .707 .577 .707 r
F P
0 g
s
.63305 .86019 m .62776 .87731 L .6512 .87574 L p .707 .577 .707 r
F P
0 g
s
.6512 .87574 m .6565 .85862 L .63305 .86019 L p .707 .577 .707 r
F P
0 g
s
.49811 .81146 m .49281 .82858 L .51268 .84305 L p .707 .577 .707 r
F P
0 g
s
.49698 .73628 m .48746 .77098 L .49929 .78458 L p .707 .577 .707 r
F P
0 g
s
.49281 .82858 m .49811 .81146 L .48646 .79722 L p .707 .577 .707 r
F P
0 g
s
.50141 .65207 m .49259 .70595 L .4953 .71677 L p .707 .577 .707 r
F P
0 g
s
.44794 .82092 m .52717 .33431 L .48372 .32466 L p .707 .577 .707 r
F P
0 g
s
.48746 .77098 m .49698 .73628 L .49457 .72407 L p .707 .577 .707 r
F P
0 g
s
.48646 .79722 m .48117 .81434 L .49281 .82858 L p .707 .577 .707 r
F P
0 g
s
.49259 .70595 m .50141 .65207 L .50856 .64292 L p .707 .577 .707 r
F P
0 g
s
.49457 .72407 m .48505 .75876 L .48746 .77098 L p .707 .577 .707 r
F P
0 g
s
.48117 .81434 m .48646 .79722 L .48417 .78459 L p .707 .577 .707 r
F P
0 g
s
.50856 .64292 m .49974 .6968 L .49259 .70595 L p .707 .577 .707 r
F P
0 g
s
.48417 .78459 m .47888 .80172 L .48117 .81434 L p .707 .577 .707 r
F P
0 g
s
.48505 .75876 m .49457 .72407 L .50182 .71444 L p .707 .577 .707 r
F P
0 g
s
.49974 .6968 m .50856 .64292 L .52486 .63634 L p .707 .577 .707 r
F P
0 g
s
.50182 .71444 m .4923 .74913 L .48505 .75876 L p .707 .577 .707 r
F P
0 g
s
.47888 .80172 m .48417 .78459 L .49147 .77482 L p .707 .577 .707 r
F P
0 g
s
.52486 .63634 m .51604 .69022 L .49974 .6968 L p .707 .577 .707 r
F P
0 g
s
.49147 .77482 m .48617 .79195 L .47888 .80172 L p .707 .577 .707 r
F P
0 g
s
.4923 .74913 m .50182 .71444 L .51802 .70833 L p .707 .577 .707 r
F P
0 g
s
.51802 .70833 m .5085 .74303 L .4923 .74913 L p .707 .577 .707 r
F P
0 g
s
.48617 .79195 m .49147 .77482 L .50763 .76886 L p .707 .577 .707 r
F P
0 g
s
.50763 .76886 m .50233 .78598 L .48617 .79195 L p .707 .577 .707 r
F P
0 g
s
.52717 .33431 m .44794 .82092 L .49238 .82611 L p .707 .577 .707 r
F P
0 g
s
.49238 .82611 m .57161 .33951 L .52717 .33431 L p .707 .577 .707 r
F P
0 g
s
.6565 .85862 m .6512 .87574 L .66736 .86978 L p .707 .577 .707 r
F P
0 g
s
.66736 .86978 m .67266 .85266 L .6565 .85862 L p .707 .577 .707 r
F P
0 g
s
.51604 .69022 m .52486 .63634 L .54873 .63297 L p .707 .577 .707 r
F P
0 g
s
.54873 .63297 m .53991 .68685 L .51604 .69022 L p .707 .577 .707 r
F P
0 g
s
.53991 .68685 m .54873 .63297 L .57783 .63315 L p .707 .577 .707 r
F P
0 g
s
.5085 .74303 m .51802 .70833 L .54159 .70636 L p .707 .577 .707 r
F P
0 g
s
.57783 .63315 m .56901 .68703 L .53991 .68685 L p .707 .577 .707 r
F P
0 g
s
.54159 .70636 m .53207 .74105 L .5085 .74303 L p .707 .577 .707 r
F P
0 g
s
.50233 .78598 m .50763 .76886 L .53107 .76729 L p .707 .577 .707 r
F P
0 g
s
.53207 .74105 m .54159 .70636 L .57021 .70871 L p .707 .577 .707 r
F P
0 g
s
.53107 .76729 m .52578 .78442 L .50233 .78598 L p .707 .577 .707 r
F P
0 g
s
.57021 .70871 m .56069 .7434 L .53207 .74105 L p .707 .577 .707 r
F P
0 g
s
.52578 .78442 m .53107 .76729 L .55951 .77027 L p .707 .577 .707 r
F P
0 g
s
.55951 .77027 m .55421 .7874 L .52578 .78442 L p .707 .577 .707 r
F P
0 g
s
.57161 .33951 m .49238 .82611 L .53346 .82634 L p .707 .577 .707 r
F P
0 g
s
.53346 .82634 m .61269 .33973 L .57161 .33951 L p .707 .577 .707 r
F P
0 g
s
.70285 .68627 m .69403 .74015 L .69131 .72932 L p .707 .577 .707 r
F P
0 g
s
.69131 .72932 m .70013 .67545 L .70285 .68627 L p .707 .577 .707 r
F P
0 g
s
.68469 .78655 m .67516 .82124 L .68242 .81161 L p .707 .577 .707 r
F P
0 g
s
.68242 .81161 m .69194 .77692 L .68469 .78655 L p .707 .577 .707 r
F P
0 g
s
.40449 .81126 m .48372 .32466 L .44551 .31148 L p .707 .577 .707 r
F P
0 g
s
.48372 .32466 m .40449 .81126 L .44794 .82092 L p .707 .577 .707 r
F P
0 g
s
.56901 .68703 m .57783 .63315 L .6093 .63685 L p .707 .577 .707 r
F P
0 g
s
.6093 .63685 m .60048 .69073 L .56901 .68703 L p .707 .577 .707 r
F P
0 g
s
.56069 .7434 m .57021 .70871 L .60109 .71514 L p .707 .577 .707 r
F P
0 g
s
.60109 .71514 m .59157 .74983 L .56069 .7434 L p .707 .577 .707 r
F P
0 g
s
.55421 .7874 m .55951 .77027 L .59016 .7775 L p .707 .577 .707 r
F P
0 g
s
.59016 .7775 m .58486 .79463 L .55421 .7874 L p .707 .577 .707 r
F P
0 g
s
.61269 .33973 m .53346 .82634 L .56716 .82156 L p .707 .577 .707 r
F P
0 g
s
.56716 .82156 m .64639 .33496 L .61269 .33973 L p .707 .577 .707 r
F P
0 g
s
.36628 .79809 m .44551 .31148 L .41629 .29608 L p .707 .577 .707 r
F P
0 g
s
.44551 .31148 m .36628 .79809 L .40449 .81126 L p .707 .577 .707 r
F P
0 g
s
.67266 .85266 m .66736 .86978 L .67465 .86001 L p .707 .577 .707 r
F P
0 g
s
.67465 .86001 m .67995 .84289 L .67266 .85266 L p .707 .577 .707 r
F P
0 g
s
.69194 .77692 m .68242 .81161 L .68001 .79939 L p .707 .577 .707 r
F P
0 g
s
.68001 .79939 m .68953 .7647 L .69194 .77692 L p .707 .577 .707 r
F P
0 g
s
.70013 .67545 m .69131 .72932 L .67901 .71789 L p .707 .577 .707 r
F P
0 g
s
.67901 .71789 m .68783 .66401 L .70013 .67545 L p .707 .577 .707 r
F P
0 g
s
.24313 .71392 m .25195 .66004 L .22117 .65318 L p .707 .577 .707 r
F P
0 g
s
.25195 .66004 m .24313 .71392 L .2746 .71762 L p .707 .577 .707 r
F P
0 g
s
.2746 .71762 m .28342 .66374 L .25195 .66004 L p .707 .577 .707 r
F P
0 g
s
.28342 .66374 m .2746 .71762 L .3037 .7178 L p .707 .577 .707 r
F P
0 g
s
.3037 .7178 m .31252 .66392 L .28342 .66374 L p .707 .577 .707 r
F P
0 g
s
.21235 .70705 m .22117 .65318 L .19412 .64382 L p .707 .577 .707 r
F P
0 g
s
.22117 .65318 m .21235 .70705 L .24313 .71392 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64008 .64372 m .63125 .69759 L .60048 .69073 L p .707 .577 .707 r
F P
0 g
s
.60048 .69073 m .6093 .63685 L .64008 .64372 L p .707 .577 .707 r
F P
0 g
s
.6312 .72504 m .62168 .75973 L .59157 .74983 L p .707 .577 .707 r
F P
0 g
s
.59157 .74983 m .60109 .71514 L .6312 .72504 L p .707 .577 .707 r
F P
0 g
s
.62001 .78828 m .61471 .80541 L .58486 .79463 L p .707 .577 .707 r
F P
0 g
s
.58486 .79463 m .59016 .7775 L .62001 .78828 L p .707 .577 .707 r
F P
0 g
s
.64639 .33496 m .56716 .82156 L .59018 .81227 L p .707 .577 .707 r
F P
0 g
s
.59018 .81227 m .66941 .32566 L .64639 .33496 L p .707 .577 .707 r
F P
0 g
s
.35269 .65397 m .34387 .70785 L .35102 .6987 L p .707 .577 .707 r
F P
0 g
s
.35102 .6987 m .35984 .64482 L .35269 .65397 L p .707 .577 .707 r
F P
0 g
s
.34168 .73891 m .33216 .77361 L .33941 .76398 L p .707 .577 .707 r
F P
0 g
s
.33941 .76398 m .34893 .72928 L .34168 .73891 L p .707 .577 .707 r
F P
0 g
s
.35984 .64482 m .35102 .6987 L .3483 .68787 L p .707 .577 .707 r
F P
0 g
s
.3483 .68787 m .35713 .634 L .35984 .64482 L p .707 .577 .707 r
F P
0 g
s
.33216 .77361 m .34168 .73891 L .32548 .74502 L p .707 .577 .707 r
F P
0 g
s
.34893 .72928 m .33941 .76398 L .337 .75176 L p .707 .577 .707 r
F P
0 g
s
.337 .75176 m .34652 .71707 L .34893 .72928 L p .707 .577 .707 r
F P
0 g
s
.33639 .66055 m .32756 .71443 L .34387 .70785 L p .707 .577 .707 r
F P
0 g
s
.34387 .70785 m .35269 .65397 L .33639 .66055 L p .707 .577 .707 r
F P
0 g
s
.35713 .634 m .3483 .68787 L .336 .67643 L p .707 .577 .707 r
F P
0 g
s
.336 .67643 m .34482 .62256 L .35713 .634 L p .707 .577 .707 r
F P
0 g
s
.34652 .71707 m .337 .75176 L .32516 .73815 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .33469 .70346 L .34652 .71707 L p .707 .577 .707 r
F P
0 g
s
.33706 .78269 m .41629 .29608 L .39891 .27996 L p .707 .577 .707 r
F P
0 g
s
.41629 .29608 m .33706 .78269 L .36628 .79809 L p .707 .577 .707 r
F P
0 g
s
.67995 .84289 m .67465 .86001 L .67236 .84739 L p .707 .577 .707 r
F P
0 g
s
.67236 .84739 m .67766 .83026 L .67995 .84289 L p .707 .577 .707 r
F P
0 g
s
.31252 .66392 m .3037 .7178 L .32756 .71443 L p .707 .577 .707 r
F P
0 g
s
.32756 .71443 m .33639 .66055 L .31252 .66392 L p .707 .577 .707 r
F P
0 g
s
.1853 .6977 m .19412 .64382 L .17342 .63289 L p .707 .577 .707 r
F P
0 g
s
.19412 .64382 m .1853 .6977 L .21235 .70705 L p .707 .577 .707 r
F P
0 g
s
.68783 .66401 m .67901 .71789 L .65831 .70695 L p .707 .577 .707 r
F P
0 g
s
.65831 .70695 m .66713 .65308 L .68783 .66401 L p .707 .577 .707 r
F P
0 g
s
.68953 .7647 m .68001 .79939 L .66817 .78578 L p .707 .577 .707 r
F P
0 g
s
.66817 .78578 m .6777 .75109 L .68953 .7647 L p .707 .577 .707 r
F P
0 g
s
.23289 .7729 m .24241 .73821 L .2123 .72831 L p .707 .577 .707 r
F P
0 g
s
.24241 .73821 m .23289 .7729 L .26377 .77934 L p .707 .577 .707 r
F P
0 g
s
.26377 .77934 m .27329 .74465 L .24241 .73821 L p .707 .577 .707 r
F P
0 g
s
.20278 .76301 m .2123 .72831 L .1859 .71593 L p .707 .577 .707 r
F P
0 g
s
.2123 .72831 m .20278 .76301 L .23289 .7729 L p .707 .577 .707 r
F P
0 g
s
.27329 .74465 m .26377 .77934 L .29239 .78168 L p .707 .577 .707 r
F P
0 g
s
.29239 .78168 m .30191 .74699 L .27329 .74465 L p .707 .577 .707 r
F P
0 g
s
.17342 .63289 m .1646 .68676 L .1853 .6977 L p .707 .577 .707 r
F P
0 g
s
.1646 .68676 m .17342 .63289 L .16112 .62145 L p .707 .577 .707 r
F P
0 g
s
.66713 .65308 m .65831 .70695 L .63125 .69759 L p .707 .577 .707 r
F P
0 g
s
.63125 .69759 m .64008 .64372 L .66713 .65308 L p .707 .577 .707 r
F P
0 g
s
.17638 .75062 m .1859 .71593 L .1658 .70226 L p .707 .577 .707 r
F P
0 g
s
.1859 .71593 m .17638 .75062 L .20278 .76301 L p .707 .577 .707 r
F P
0 g
s
.30191 .74699 m .29239 .78168 L .31595 .77971 L p .707 .577 .707 r
F P
0 g
s
.31595 .77971 m .32548 .74502 L .30191 .74699 L p .707 .577 .707 r
F P
0 g
s
.22566 .81079 m .23096 .79366 L .20111 .78288 L p .707 .577 .707 r
F P
0 g
s
.23096 .79366 m .22566 .81079 L .25631 .81802 L p .707 .577 .707 r
F P
0 g
s
.25631 .81802 m .26161 .80089 L .23096 .79366 L p .707 .577 .707 r
F P
0 g
s
.67766 .83026 m .67236 .84739 L .66072 .83315 L p .707 .577 .707 r
F P
0 g
s
.66072 .83315 m .66601 .81602 L .67766 .83026 L p .707 .577 .707 r
F P
0 g
s
.66941 .32566 m .59018 .81227 L .60027 .79935 L p .707 .577 .707 r
F P
0 g
s
.60027 .79935 m .6795 .31275 L .66941 .32566 L p .707 .577 .707 r
F P
0 g
s
.6777 .75109 m .66817 .78578 L .64808 .77212 L p .707 .577 .707 r
F P
0 g
s
.64808 .77212 m .6576 .73742 L .6777 .75109 L p .707 .577 .707 r
F P
0 g
s
.19581 .80001 m .20111 .78288 L .17497 .76961 L p .707 .577 .707 r
F P
0 g
s
.20111 .78288 m .19581 .80001 L .22566 .81079 L p .707 .577 .707 r
F P
0 g
s
.26161 .80089 m .25631 .81802 L .28475 .821 L p .707 .577 .707 r
F P
0 g
s
.28475 .821 m .29004 .80387 L .26161 .80089 L p .707 .577 .707 r
F P
0 g
s
.32548 .74502 m .31595 .77971 L .33216 .77361 L p .707 .577 .707 r
F P
0 g
s
.34482 .62256 m .336 .67643 L .3153 .6655 L p .707 .577 .707 r
F P
0 g
s
.3153 .6655 m .32412 .61162 L .34482 .62256 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .30507 .72448 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.33469 .70346 m .32974 .72149 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.32974 .72149 m .32516 .73815 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.30507 .72448 m .31459 .68979 L .33469 .70346 L p .707 .577 .707 r
F P
0 g
s
.323 .75971 m .31771 .77683 L .29784 .76237 L p .707 .577 .707 r
F P
0 g
s
.29784 .76237 m .30314 .74524 L .323 .75971 L p .707 .577 .707 r
F P
0 g
s
.31968 .76657 m .36445 .49161 L p .39508 .26469 L .707 .577 .707 r
F P
0 g
s
.36445 .49161 m .39891 .27996 L .39735 .27375 L p .707 .577 .707 r
F P
0 g
s
.39735 .27375 m .39508 .26469 L p .36445 .49161 L .707 .577 .707 r
F P
0 g
s
.32935 .79107 m .33465 .77395 L .33694 .78657 L p .707 .577 .707 r
F P
0 g
s
.33465 .77395 m .32935 .79107 L .31771 .77683 L p .707 .577 .707 r
F P
0 g
s
.31771 .77683 m .323 .75971 L .33465 .77395 L p .707 .577 .707 r
F P
0 g
s
.39891 .27996 m .31968 .76657 L .33706 .78269 L p .707 .577 .707 r
F P
0 g
s
.1658 .70226 m .15628 .73695 L .17638 .75062 L p .707 .577 .707 r
F P
0 g
s
.17497 .76961 m .16967 .78673 L .19581 .80001 L p .707 .577 .707 r
F P
0 g
s
.16112 .62145 m .15229 .67532 L .1646 .68676 L p .707 .577 .707 r
F P
0 g
s
.16967 .78673 m .17497 .76961 L .1551 .75514 L p .707 .577 .707 r
F P
0 g
s
.15628 .73695 m .1658 .70226 L .15397 .68865 L p .707 .577 .707 r
F P
0 g
s
.29004 .80387 m .28475 .821 L .30819 .81943 L p .707 .577 .707 r
F P
0 g
s
.30819 .81943 m .31349 .80231 L .29004 .80387 L p .707 .577 .707 r
F P
0 g
s
.15229 .67532 m .16112 .62145 L .1584 .61062 L p .707 .577 .707 r
F P
0 g
s
.1551 .75514 m .14981 .77227 L .16967 .78673 L p .707 .577 .707 r
F P
0 g
s
.6576 .73742 m .64808 .77212 L .62168 .75973 L p .707 .577 .707 r
F P
0 g
s
.62168 .75973 m .6312 .72504 L .6576 .73742 L p .707 .577 .707 r
F P
0 g
s
.66601 .81602 m .66072 .83315 L .64085 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .81868 m .64615 .80156 L .66601 .81602 L p .707 .577 .707 r
F P
0 g
s
.15397 .68865 m .14445 .72334 L .15628 .73695 L p .707 .577 .707 r
F P
0 g
s
.14981 .77227 m .1551 .75514 L .14345 .7409 L p .707 .577 .707 r
F P
0 g
s
.1584 .61062 m .14958 .6645 L .15229 .67532 L p .707 .577 .707 r
F P
0 g
s
.31349 .80231 m .30819 .81943 L .32435 .81347 L p .707 .577 .707 r
F P
0 g
s
.32435 .81347 m .32965 .79634 L .31349 .80231 L p .707 .577 .707 r
F P
0 g
s
.14345 .7409 m .13816 .75803 L .14981 .77227 L p .707 .577 .707 r
F P
0 g
s
.14445 .72334 m .15397 .68865 L .15156 .67643 L p .707 .577 .707 r
F P
0 g
s
.6795 .31275 m .60027 .79935 L .59644 .78409 L p .707 .577 .707 r
F P
0 g
s
.59644 .78409 m .67566 .29748 L .6795 .31275 L p .707 .577 .707 r
F P
0 g
s
.64615 .80156 m .64085 .81868 L .61471 .80541 L p .707 .577 .707 r
F P
0 g
s
.61471 .80541 m .62001 .78828 L .64615 .80156 L p .707 .577 .707 r
F P
0 g
s
.39508 .26469 m .31585 .7513 L .31968 .76657 L p .707 .577 .707 r
F P
0 g
s
.31585 .7513 m .39508 .26469 L .40517 .25178 L p .707 .577 .707 r
F P
0 g
s
.14958 .6645 m .1584 .61062 L .16555 .60147 L p .707 .577 .707 r
F P
0 g
s
.15156 .67643 m .14204 .71113 L .14445 .72334 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.13816 .75803 m .14345 .7409 L .14116 .72828 L p .707 .577 .707 r
F P
0 g
s
.32965 .79634 m .32435 .81347 L .33164 .8037 L p .707 .577 .707 r
F P
0 g
s
.33164 .8037 m .33694 .78657 L .32965 .79634 L p .707 .577 .707 r
F P
0 g
s
.14116 .72828 m .13587 .7454 L .13816 .75803 L p .707 .577 .707 r
F P
0 g
s
.16555 .60147 m .15673 .65535 L .14958 .6645 L p .707 .577 .707 r
F P
0 g
s
.14204 .71113 m .15156 .67643 L .15881 .6668 L p .707 .577 .707 r
F P
0 g
s
.15673 .65535 m .16555 .60147 L .18186 .59489 L p .707 .577 .707 r
F P
0 g
s
.67566 .29748 m .59644 .78409 L .57906 .76797 L p .707 .577 .707 r
F P
0 g
s
.57906 .76797 m .65829 .28136 L .67566 .29748 L p .707 .577 .707 r
F P
0 g
s
.15881 .6668 m .14929 .70149 L .14204 .71113 L p .707 .577 .707 r
F P
0 g
s
.32594 .73839 m .40517 .25178 L .42819 .24248 L p .707 .577 .707 r
F P
0 g
s
.40517 .25178 m .32594 .73839 L .31585 .7513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13587 .7454 m .14116 .72828 L .14846 .71851 L p .707 .577 .707 r
F P
0 g
s
.33694 .78657 m .33164 .8037 L .32935 .79107 L p .707 .577 .707 r
F P
0 g
s
.14846 .71851 m .14316 .73563 L .13587 .7454 L p .707 .577 .707 r
F P
0 g
s
.18186 .59489 m .17303 .64877 L .15673 .65535 L p .707 .577 .707 r
F P
0 g
s
.14929 .70149 m .15881 .6668 L .17501 .6607 L p .707 .577 .707 r
F P
0 g
s
.17303 .64877 m .18186 .59489 L .20572 .59152 L p .707 .577 .707 r
F P
0 g
s
.17501 .6607 m .16549 .69539 L .14929 .70149 L p .707 .577 .707 r
F P
0 g
s
.14316 .73563 m .14846 .71851 L .16462 .71255 L p .707 .577 .707 r
F P
0 g
s
.65829 .28136 m .57906 .76797 L .54984 .75257 L p .707 .577 .707 r
F P
0 g
s
.54984 .75257 m .62906 .26596 L .65829 .28136 L p .707 .577 .707 r
F P
0 g
s
.20572 .59152 m .1969 .6454 L .17303 .64877 L p .707 .577 .707 r
F P
0 g
s
.32412 .61162 m .3153 .6655 L .28825 .65614 L p .707 .577 .707 r
F P
0 g
s
.28825 .65614 m .29707 .60227 L .32412 .61162 L p .707 .577 .707 r
F P
0 g
s
.16462 .71255 m .15932 .72967 L .14316 .73563 L p .707 .577 .707 r
F P
0 g
s
.42819 .24248 m .34896 .72909 L .32594 .73839 L p .707 .577 .707 r
F P
0 g
s
.34896 .72909 m .42819 .24248 L .46189 .23771 L p .707 .577 .707 r
F P
0 g
s
.1969 .6454 m .20572 .59152 L .23482 .5917 L p .707 .577 .707 r
F P
0 g
s
.16549 .69539 m .17501 .6607 L .19858 .65873 L p .707 .577 .707 r
F P
0 g
s
.29707 .60227 m .28825 .65614 L .25747 .64928 L p .707 .577 .707 r
F P
0 g
s
.25747 .64928 m .26629 .5954 L .29707 .60227 L p .707 .577 .707 r
F P
0 g
s
.226 .64557 m .23482 .5917 L .26629 .5954 L p .707 .577 .707 r
F P
0 g
s
.23482 .5917 m .226 .64557 L .1969 .6454 L p .707 .577 .707 r
F P
0 g
s
.19858 .65873 m .18906 .69342 L .16549 .69539 L p .707 .577 .707 r
F P
0 g
s
.26629 .5954 m .25747 .64928 L .226 .64557 L p .707 .577 .707 r
F P
0 g
s
.15932 .72967 m .16462 .71255 L .18806 .71098 L p .707 .577 .707 r
F P
0 g
s
.18906 .69342 m .19858 .65873 L .2272 .66107 L p .707 .577 .707 r
F P
0 g
s
.72334 .66333 m .73216 .60946 L .70139 .60259 L p .707 .577 .707 r
F P
0 g
s
.73216 .60946 m .72334 .66333 L .75481 .66703 L p .707 .577 .707 r
F P
0 g
s
.75481 .66703 m .76363 .61316 L .73216 .60946 L p .707 .577 .707 r
F P
0 g
s
.31459 .68979 m .30507 .72448 L .27867 .7121 L p .707 .577 .707 r
F P
0 g
s
.27867 .7121 m .28819 .6774 L .31459 .68979 L p .707 .577 .707 r
F P
0 g
s
.18806 .71098 m .18277 .7281 L .15932 .72967 L p .707 .577 .707 r
F P
0 g
s
.62906 .26596 m .54984 .75257 L .51163 .73939 L p .707 .577 .707 r
F P
0 g
s
.51163 .73939 m .59086 .25278 L .62906 .26596 L p .707 .577 .707 r
F P
0 g
s
.76363 .61316 m .75481 .66703 L .78391 .66721 L p .707 .577 .707 r
F P
0 g
s
.78391 .66721 m .79273 .61333 L .76363 .61316 L p .707 .577 .707 r
F P
0 g
s
.69257 .65647 m .70139 .60259 L .67433 .59323 L p .707 .577 .707 r
F P
0 g
s
.70139 .60259 m .69257 .65647 L .72334 .66333 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .46189 .23771 L .50297 .23793 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .34896 .72909 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.42743 .44936 m .38266 .72432 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.50297 .23793 m .42374 .72454 L .38266 .72432 L p .707 .577 .707 r
F P
0 g
s
.40097 .6873 m .40554 .67064 L p .37961 .64617 L .707 .577 .707 r
F P
0 g
s
.40554 .67064 m .41049 .65261 L .40739 .65196 L p .707 .577 .707 r
F P
0 g
s
.40739 .65196 m .37961 .64617 L p .40554 .67064 L .707 .577 .707 r
F P
0 g
s
.46189 .23771 m .42743 .44936 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.2272 .66107 m .21768 .69576 L .18906 .69342 L p .707 .577 .707 r
F P
0 g
s
.21768 .69576 m .2272 .66107 L .25808 .66751 L p .707 .577 .707 r
F P
0 g
s
.28819 .6774 m .27867 .7121 L .24856 .7022 L p .707 .577 .707 r
F P
0 g
s
.24856 .7022 m .25808 .66751 L .28819 .6774 L p .707 .577 .707 r
F P
0 g
s
.18277 .7281 m .18806 .71098 L .2165 .71396 L p .707 .577 .707 r
F P
0 g
s
.25808 .66751 m .24856 .7022 L .21768 .69576 L p .707 .577 .707 r
F P
0 g
s
.79273 .61333 m .78391 .66721 L .80778 .66384 L p .707 .577 .707 r
F P
0 g
s
.80778 .66384 m .8166 .60997 L .79273 .61333 L p .707 .577 .707 r
F P
0 g
s
.66551 .64711 m .67433 .59323 L .65363 .5823 L p .707 .577 .707 r
F P
0 g
s
.67433 .59323 m .66551 .64711 L .69257 .65647 L p .707 .577 .707 r
F P
0 g
s
.30314 .74524 m .29784 .76237 L .2717 .7491 L p .707 .577 .707 r
F P
0 g
s
.2717 .7491 m .277 .73197 L .30314 .74524 L p .707 .577 .707 r
F P
0 g
s
.59086 .25278 m .51163 .73939 L .46818 .72974 L p .707 .577 .707 r
F P
0 g
s
.46818 .72974 m .54741 .24313 L .59086 .25278 L p .707 .577 .707 r
F P
0 g
s
.2165 .71396 m .2112 .73108 L .18277 .7281 L p .707 .577 .707 r
F P
0 g
s
.41049 .65261 m .40097 .6873 L .40578 .68769 L p .707 .577 .707 r
F P
0 g
s
.44943 .62454 m .44421 .59881 L .47335 .53142 L .707 .577 .707 r
F
.42374 .72454 m .43571 .65102 L p .44943 .62454 L F P
0 g
s
.43571 .65102 m .44421 .59881 L p .44943 .62454 L .707 .577 .707 r
F P
0 g
s
.54741 .24313 m .46818 .72974 L .42374 .72454 L p .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .42725 .71184 L .4054 .70955 L p .707 .577 .707 r
F P
0 g
s
.4054 .70955 m .39881 .70886 L p .4036 .71302 L .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .4054 .70955 L .4036 .71302 L .707 .577 .707 r
F
.40578 .68769 m .42959 .68964 L p .41618 .66364 L F P
0 g
s
.41618 .66364 m .41049 .65261 L .40578 .68769 L .707 .577 .707 r
F
.50297 .23793 m .54741 .24313 L p .47335 .53142 L F P
0 g
s
.44421 .59881 m .50297 .23793 L p .47335 .53142 L .707 .577 .707 r
F P
0 g
s
.7131 .7285 m .72262 .6938 L .69251 .68391 L p .707 .577 .707 r
F P
0 g
s
.72262 .6938 m .7131 .7285 L .74398 .73493 L p .707 .577 .707 r
F P
0 g
s
.74398 .73493 m .7535 .70024 L .72262 .6938 L p .707 .577 .707 r
F P
0 g
s
.2112 .73108 m .2165 .71396 L .24715 .72119 L p .707 .577 .707 r
F P
0 g
s
.68299 .7186 m .69251 .68391 L .66612 .67152 L p .707 .577 .707 r
F P
0 g
s
.69251 .68391 m .68299 .7186 L .7131 .7285 L p .707 .577 .707 r
F P
0 g
s
.7535 .70024 m .74398 .73493 L .7726 .73728 L p .707 .577 .707 r
F P
0 g
s
.7726 .73728 m .78212 .70258 L .7535 .70024 L p .707 .577 .707 r
F P
0 g
s
.277 .73197 m .2717 .7491 L .24185 .73832 L p .707 .577 .707 r
F P
0 g
s
.24185 .73832 m .24715 .72119 L .277 .73197 L p .707 .577 .707 r
F P
0 g
s
.24715 .72119 m .24185 .73832 L .2112 .73108 L p .707 .577 .707 r
F P
0 g
s
.65363 .5823 m .64481 .63617 L .66551 .64711 L p .707 .577 .707 r
F P
0 g
s
.8166 .60997 m .80778 .66384 L .82408 .65726 L p .707 .577 .707 r
F P
0 g
s
.82408 .65726 m .83291 .60338 L .8166 .60997 L p .707 .577 .707 r
F P
0 g
s
.64481 .63617 m .65363 .5823 L .64133 .57086 L p .707 .577 .707 r
F P
0 g
s
.65659 .70621 m .66612 .67152 L .64602 .65785 L p .707 .577 .707 r
F P
0 g
s
.66612 .67152 m .65659 .70621 L .68299 .7186 L p .707 .577 .707 r
F P
0 g
s
.78212 .70258 m .7726 .73728 L .79617 .7353 L p .707 .577 .707 r
F P
0 g
s
.79617 .7353 m .80569 .70061 L .78212 .70258 L p .707 .577 .707 r
F P
0 g
s
.70588 .77506 m .71117 .75794 L .68132 .74716 L p .707 .577 .707 r
F P
0 g
s
.71117 .75794 m .70588 .77506 L .73652 .7823 L p .707 .577 .707 r
F P
0 g
s
.73652 .7823 m .74182 .76517 L .71117 .75794 L p .707 .577 .707 r
F P
0 g
s
.67602 .76428 m .68132 .74716 L .65518 .73388 L p .707 .577 .707 r
F P
0 g
s
.68132 .74716 m .67602 .76428 L .70588 .77506 L p .707 .577 .707 r
F P
0 g
s
.74182 .76517 m .73652 .7823 L .76496 .78527 L p .707 .577 .707 r
F P
0 g
s
.76496 .78527 m .77026 .76815 L .74182 .76517 L p .707 .577 .707 r
F P
0 g
s
.64602 .65785 m .63649 .69255 L .65659 .70621 L p .707 .577 .707 r
F P
0 g
s
.64133 .57086 m .63251 .62474 L .64481 .63617 L p .707 .577 .707 r
F P
0 g
s
.65518 .73388 m .64988 .75101 L .67602 .76428 L p .707 .577 .707 r
F P
0 g
s
.83291 .60338 m .82408 .65726 L .83123 .64811 L p .707 .577 .707 r
F P
0 g
s
.83123 .64811 m .84005 .59423 L .83291 .60338 L p .707 .577 .707 r
F P
0 g
s
.63649 .69255 m .64602 .65785 L .63418 .64425 L p .707 .577 .707 r
F P
0 g
s
.64988 .75101 m .65518 .73388 L .63532 .71942 L p .707 .577 .707 r
F P
0 g
s
.80569 .70061 m .79617 .7353 L .81237 .7292 L p .707 .577 .707 r
F P
0 g
s
.81237 .7292 m .82189 .69451 L .80569 .70061 L p .707 .577 .707 r
F P
0 g
s
.63251 .62474 m .64133 .57086 L .63862 .56003 L p .707 .577 .707 r
F P
0 g
s
.77026 .76815 m .76496 .78527 L .78841 .78371 L p .707 .577 .707 r
F P
0 g
s
.78841 .78371 m .7937 .76658 L .77026 .76815 L p .707 .577 .707 r
F P
0 g
s
.63532 .71942 m .63002 .73654 L .64988 .75101 L p .707 .577 .707 r
F P
0 g
s
.63418 .64425 m .62466 .67894 L .63649 .69255 L p .707 .577 .707 r
F P
0 g
s
.63002 .73654 m .63532 .71942 L .62367 .70518 L p .707 .577 .707 r
F P
0 g
s
.63862 .56003 m .6298 .61391 L .63251 .62474 L p .707 .577 .707 r
F P
0 g
s
.7937 .76658 m .78841 .78371 L .80457 .77774 L p .707 .577 .707 r
F P
0 g
s
.80457 .77774 m .80986 .76062 L .7937 .76658 L p .707 .577 .707 r
F P
0 g
s
.62466 .67894 m .63418 .64425 L .63178 .63203 L p .707 .577 .707 r
F P
0 g
s
.62367 .70518 m .61837 .7223 L .63002 .73654 L p .707 .577 .707 r
F P
0 g
s
.84005 .59423 m .83123 .64811 L .82852 .63729 L p .707 .577 .707 r
F P
0 g
s
.82852 .63729 m .83734 .58341 L .84005 .59423 L p .707 .577 .707 r
F P
0 g
s
.82189 .69451 m .81237 .7292 L .81962 .71957 L p .707 .577 .707 r
F P
0 g
s
.81962 .71957 m .82914 .68488 L .82189 .69451 L p .707 .577 .707 r
F P
0 g
s
.6298 .61391 m .63862 .56003 L .64576 .55088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63178 .63203 m .62225 .66672 L .62466 .67894 L p .707 .577 .707 r
F P
0 g
s
.61837 .7223 m .62367 .70518 L .62138 .69255 L p .707 .577 .707 r
F P
0 g
s
.64576 .55088 m .63694 .60476 L .6298 .61391 L p .707 .577 .707 r
F P
0 g
s
.80986 .76062 m .80457 .77774 L .81186 .76797 L p .707 .577 .707 r
F P
0 g
s
.81186 .76797 m .81716 .75085 L .80986 .76062 L p .707 .577 .707 r
F P
0 g
s
.62138 .69255 m .61608 .70968 L .61837 .7223 L p .707 .577 .707 r
F P
0 g
s
.62225 .66672 m .63178 .63203 L .63903 .6224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.82914 .68488 m .81962 .71957 L .81721 .70735 L p .707 .577 .707 r
F P
0 g
s
.81721 .70735 m .82673 .67266 L .82914 .68488 L p .707 .577 .707 r
F P
0 g
s
.83734 .58341 m .82852 .63729 L .81621 .62585 L p .707 .577 .707 r
F P
0 g
s
.81621 .62585 m .82503 .57197 L .83734 .58341 L p .707 .577 .707 r
F P
0 g
s
.63694 .60476 m .64576 .55088 L .66207 .5443 L p .707 .577 .707 r
F P
0 g
s
.38033 .62188 m .38915 .568 L .35838 .56114 L p .707 .577 .707 r
F P
0 g
s
.38915 .568 m .38033 .62188 L .4118 .62558 L p .707 .577 .707 r
F P
0 g
s
.4118 .62558 m .42062 .57171 L .38915 .568 L p .707 .577 .707 r
F P
0 g
s
.63903 .6224 m .6295 .65709 L .62225 .66672 L p .707 .577 .707 r
F P
0 g
s
.42062 .57171 m .4118 .62558 L .4409 .62576 L p .707 .577 .707 r
F P
0 g
s
.4409 .62576 m .44972 .57188 L .42062 .57171 L p .707 .577 .707 r
F P
0 g
s
.34956 .61501 m .35838 .56114 L .33132 .55178 L p .707 .577 .707 r
F P
0 g
s
.35838 .56114 m .34956 .61501 L .38033 .62188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.61608 .70968 m .62138 .69255 L .62867 .68278 L p .707 .577 .707 r
F P
0 g
s
.66207 .5443 m .65325 .59818 L .63694 .60476 L p .707 .577 .707 r
F P
0 g
s
.81716 .75085 m .81186 .76797 L .80957 .75535 L p .707 .577 .707 r
F P
0 g
s
.80957 .75535 m .81487 .73822 L .81716 .75085 L p .707 .577 .707 r
F P
0 g
s
.44972 .57188 m .4409 .62576 L .46477 .62239 L p .707 .577 .707 r
F P
0 g
s
.46477 .62239 m .47359 .56851 L .44972 .57188 L p .707 .577 .707 r
F P
0 g
s
.62867 .68278 m .62337 .69991 L .61608 .70968 L p .707 .577 .707 r
F P
0 g
s
.3225 .60566 m .33132 .55178 L .31062 .54085 L p .707 .577 .707 r
F P
0 g
s
.33132 .55178 m .3225 .60566 L .34956 .61501 L p .707 .577 .707 r
F P
0 g
s
.6295 .65709 m .63903 .6224 L .65523 .6163 L p .707 .577 .707 r
F P
0 g
s
.82503 .57197 m .81621 .62585 L .79552 .61491 L p .707 .577 .707 r
F P
0 g
s
.79552 .61491 m .80434 .56104 L .82503 .57197 L p .707 .577 .707 r
F P
0 g
s
.82673 .67266 m .81721 .70735 L .80538 .69374 L p .707 .577 .707 r
F P
0 g
s
.80538 .69374 m .8149 .65905 L .82673 .67266 L p .707 .577 .707 r
F P
0 g
s
.65325 .59818 m .66207 .5443 L .68594 .54093 L p .707 .577 .707 r
F P
0 g
s
.37009 .68086 m .37961 .64617 L .3495 .63628 L p .707 .577 .707 r
F P
0 g
s
.37961 .64617 m .37009 .68086 L .40097 .6873 L p .707 .577 .707 r
F P
0 g
s
.33998 .67097 m .3495 .63628 L .32311 .62389 L p .707 .577 .707 r
F P
0 g
s
.3495 .63628 m .33998 .67097 L .37009 .68086 L p .707 .577 .707 r
F P
0 g
s
.42959 .68964 m .43911 .65495 L .41049 .65261 L p .707 .577 .707 r
F P
0 g
s
.65523 .6163 m .64571 .65099 L .6295 .65709 L p .707 .577 .707 r
F P
0 g
s
.31062 .54085 m .3018 .59472 L .3225 .60566 L p .707 .577 .707 r
F P
0 g
s
.47359 .56851 m .46477 .62239 L .48107 .61581 L p .707 .577 .707 r
F P
0 g
s
.48107 .61581 m .4899 .56193 L .47359 .56851 L p .707 .577 .707 r
F P
0 g
s
.62337 .69991 m .62867 .68278 L .64483 .67682 L p .707 .577 .707 r
F P
0 g
s
.3018 .59472 m .31062 .54085 L .29832 .52941 L p .707 .577 .707 r
F P
0 g
s
.68594 .54093 m .67712 .59481 L .65325 .59818 L p .707 .577 .707 r
F P
0 g
s
.80434 .56104 m .79552 .61491 L .76846 .60556 L p .707 .577 .707 r
F P
0 g
s
.76846 .60556 m .77728 .55168 L .80434 .56104 L p .707 .577 .707 r
F P
0 g
s
.31358 .65858 m .32311 .62389 L .30301 .61022 L p .707 .577 .707 r
F P
0 g
s
.32311 .62389 m .31358 .65858 L .33998 .67097 L p .707 .577 .707 r
F P
0 g
s
.43911 .65495 m .42959 .68964 L .45316 .68767 L p .707 .577 .707 r
F P
0 g
s
.45316 .68767 m .46268 .65298 L .43911 .65495 L p .707 .577 .707 r
F P
0 g
s
.67712 .59481 m .68594 .54093 L .71503 .54111 L p .707 .577 .707 r
F P
0 g
s
.36287 .71875 m .36816 .70162 L .33831 .69084 L p .707 .577 .707 r
F P
0 g
s
.36816 .70162 m .36287 .71875 L .39351 .72598 L p .707 .577 .707 r
F P
0 g
s
.39351 .72598 m .39881 .70886 L .36816 .70162 L p .707 .577 .707 r
F P
0 g
s
.81487 .73822 m .80957 .75535 L .79792 .74111 L p .707 .577 .707 r
F P
0 g
s
.79792 .74111 m .80322 .72398 L .81487 .73822 L p .707 .577 .707 r
F P
0 g
s
.64571 .65099 m .65523 .6163 L .67879 .61432 L p .707 .577 .707 r
F P
0 g
s
.64483 .67682 m .63953 .69395 L .62337 .69991 L p .707 .577 .707 r
F P
0 g
s
.8149 .65905 m .80538 .69374 L .78528 .68008 L p .707 .577 .707 r
F P
0 g
s
.78528 .68008 m .7948 .64539 L .8149 .65905 L p .707 .577 .707 r
F P
0 g
s
.33301 .70797 m .33831 .69084 L .31217 .67757 L p .707 .577 .707 r
F P
0 g
s
.33831 .69084 m .33301 .70797 L .36287 .71875 L p .707 .577 .707 r
F P
0 g
s
.39881 .70886 m .39351 .72598 L .42195 .72896 L p .707 .577 .707 r
F P
0 g
s
.30301 .61022 m .29348 .64491 L .31358 .65858 L p .707 .577 .707 r
F P
0 g
s
.31217 .67757 m .30687 .6947 L .33301 .70797 L p .707 .577 .707 r
F P
0 g
s
.77728 .55168 m .76846 .60556 L .73769 .59869 L p .707 .577 .707 r
F P
0 g
s
.73769 .59869 m .74651 .54481 L .77728 .55168 L p .707 .577 .707 r
F P
0 g
s
.70621 .59499 m .71503 .54111 L .74651 .54481 L p .707 .577 .707 r
F P
0 g
s
.71503 .54111 m .70621 .59499 L .67712 .59481 L p .707 .577 .707 r
F P
0 g
s
.29832 .52941 m .2895 .58328 L .3018 .59472 L p .707 .577 .707 r
F P
0 g
s
.67879 .61432 m .66927 .64901 L .64571 .65099 L p .707 .577 .707 r
F P
0 g
s
.74651 .54481 m .73769 .59869 L .70621 .59499 L p .707 .577 .707 r
F P
0 g
s
.30687 .6947 m .31217 .67757 L .29231 .66311 L p .707 .577 .707 r
F P
0 g
s
.29348 .64491 m .30301 .61022 L .29117 .59661 L p .707 .577 .707 r
F P
0 g
s
.4899 .56193 m .48107 .61581 L .48822 .60666 L p .707 .577 .707 r
F P
0 g
s
.48822 .60666 m .49704 .55278 L .4899 .56193 L p .707 .577 .707 r
F P
0 g
s
.42725 .71184 m .42195 .72896 L .4454 .72739 L p .707 .577 .707 r
F P
0 g
s
.4454 .72739 m .45069 .71027 L .42725 .71184 L p .707 .577 .707 r
F P
0 g
s
.46268 .65298 m .45316 .68767 L .46936 .68157 L p .707 .577 .707 r
F P
0 g
s
.46936 .68157 m .47888 .64688 L .46268 .65298 L p .707 .577 .707 r
F P
0 g
s
.63953 .69395 m .64483 .67682 L .66828 .67525 L p .707 .577 .707 r
F P
0 g
s
.66927 .64901 m .67879 .61432 L .70742 .61667 L p .707 .577 .707 r
F P
0 g
s
.2895 .58328 m .29832 .52941 L .29561 .51858 L p .707 .577 .707 r
F P
0 g
s
.29231 .66311 m .28701 .68023 L .30687 .6947 L p .707 .577 .707 r
F P
0 g
s
.7948 .64539 m .78528 .68008 L .75888 .66769 L p .707 .577 .707 r
F P
0 g
s
.75888 .66769 m .76841 .633 L .7948 .64539 L p .707 .577 .707 r
F P
0 g
s
.80322 .72398 m .79792 .74111 L .77806 .72664 L p .707 .577 .707 r
F P
0 g
s
.77806 .72664 m .78335 .70952 L .80322 .72398 L p .707 .577 .707 r
F P
0 g
s
.66828 .67525 m .66298 .69238 L .63953 .69395 L p .707 .577 .707 r
F P
0 g
s
.29117 .59661 m .28165 .6313 L .29348 .64491 L p .707 .577 .707 r
F P
0 g
s
.70742 .61667 m .69789 .65136 L .66927 .64901 L p .707 .577 .707 r
F P
0 g
s
.69789 .65136 m .70742 .61667 L .73829 .6231 L p .707 .577 .707 r
F P
0 g
s
.28701 .68023 m .29231 .66311 L .28066 .64886 L p .707 .577 .707 r
F P
0 g
s
.76841 .633 m .75888 .66769 L .72877 .65779 L p .707 .577 .707 r
F P
0 g
s
.72877 .65779 m .73829 .6231 L .76841 .633 L p .707 .577 .707 r
F P
0 g
s
.29561 .51858 m .28678 .57246 L .2895 .58328 L p .707 .577 .707 r
F P
0 g
s
.45069 .71027 m .4454 .72739 L .46156 .72143 L p .707 .577 .707 r
F P
0 g
s
.46156 .72143 m .46685 .70431 L .45069 .71027 L p .707 .577 .707 r
F P
0 g
s
.73829 .6231 m .72877 .65779 L .69789 .65136 L p .707 .577 .707 r
F P
0 g
s
.66298 .69238 m .66828 .67525 L .69671 .67823 L p .707 .577 .707 r
F P
0 g
s
.28066 .64886 m .27536 .66599 L .28701 .68023 L p .707 .577 .707 r
F P
0 g
s
.28165 .6313 m .29117 .59661 L .28877 .5844 L p .707 .577 .707 r
F P
0 g
s
.78335 .70952 m .77806 .72664 L .75192 .71337 L p .707 .577 .707 r
F P
0 g
s
.75192 .71337 m .75721 .69625 L .78335 .70952 L p .707 .577 .707 r
F P
0 g
s
.47888 .64688 m .46936 .68157 L .47661 .67194 L p .707 .577 .707 r
F P
0 g
s
.47661 .67194 m .48613 .63725 L .47888 .64688 L p .707 .577 .707 r
F P
0 g
s
.49704 .55278 m .48822 .60666 L .48551 .59583 L p .707 .577 .707 r
F P
0 g
s
.48551 .59583 m .49433 .54196 L .49704 .55278 L p .707 .577 .707 r
F P
0 g
s
.69671 .67823 m .69142 .69536 L .66298 .69238 L p .707 .577 .707 r
F P
0 g
s
.28678 .57246 m .29561 .51858 L .30275 .50943 L p .707 .577 .707 r
F P
0 g
s
.28877 .5844 m .27924 .61909 L .28165 .6313 L p .707 .577 .707 r
F P
0 g
s
.69142 .69536 m .69671 .67823 L .72736 .68547 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.75721 .69625 m .75192 .71337 L .72206 .70259 L p .707 .577 .707 r
F P
0 g
s
.72206 .70259 m .72736 .68547 L .75721 .69625 L p .707 .577 .707 r
F P
0 g
s
.27536 .66599 m .28066 .64886 L .27837 .63624 L p .707 .577 .707 r
F P
0 g
s
.72736 .68547 m .72206 .70259 L .69142 .69536 L p .707 .577 .707 r
F P
0 g
s
.46685 .70431 m .46156 .72143 L .46885 .71166 L p .707 .577 .707 r
F P
0 g
s
.46885 .71166 m .47415 .69453 L .46685 .70431 L p .707 .577 .707 r
F P
0 g
s
.27837 .63624 m .27307 .65336 L .27536 .66599 L p .707 .577 .707 r
F P
0 g
s
.30275 .50943 m .29393 .56331 L .28678 .57246 L p .707 .577 .707 r
F P
0 g
s
.27924 .61909 m .28877 .5844 L .29602 .57476 L p .707 .577 .707 r
F P
0 g
s
.48613 .63725 m .47661 .67194 L .4742 .65972 L p .707 .577 .707 r
F P
0 g
s
.4742 .65972 m .48372 .62503 L .48613 .63725 L p .707 .577 .707 r
F P
0 g
s
.49433 .54196 m .48551 .59583 L .4732 .5844 L p .707 .577 .707 r
F P
0 g
s
.4732 .5844 m .48202 .53052 L .49433 .54196 L p .707 .577 .707 r
F P
0 g
s
.29393 .56331 m .30275 .50943 L .31906 .50285 L p .707 .577 .707 r
F P
0 g
s
.29602 .57476 m .28649 .60946 L .27924 .61909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27307 .65336 m .27837 .63624 L .28566 .62647 L p .707 .577 .707 r
F P
0 g
s
.47415 .69453 m .46885 .71166 L .46656 .69904 L p .707 .577 .707 r
F P
0 g
s
.46656 .69904 m .47186 .68191 L .47415 .69453 L p .707 .577 .707 r
F P
0 g
s
.28566 .62647 m .28036 .64359 L .27307 .65336 L p .707 .577 .707 r
F P
0 g
s
.31906 .50285 m .31024 .55673 L .29393 .56331 L p .707 .577 .707 r
F P
0 g
s
.28649 .60946 m .29602 .57476 L .31222 .56866 L p .707 .577 .707 r
F P
0 g
s
.48202 .53052 m .4732 .5844 L .45251 .57346 L p .707 .577 .707 r
F P
0 g
s
.45251 .57346 m .46133 .51959 L .48202 .53052 L p .707 .577 .707 r
F P
0 g
s
.48372 .62503 m .4742 .65972 L .46237 .64611 L p .707 .577 .707 r
F P
0 g
s
.46237 .64611 m .47189 .61142 L .48372 .62503 L p .707 .577 .707 r
F P
0 g
s
.31024 .55673 m .31906 .50285 L .34293 .49948 L p .707 .577 .707 r
F P
0 g
s
.31222 .56866 m .3027 .60335 L .28649 .60946 L p .707 .577 .707 r
F P
0 g
s
.28036 .64359 m .28566 .62647 L .30182 .62051 L p .707 .577 .707 r
F P
0 g
s
.47186 .68191 m .46656 .69904 L .45491 .68479 L p .707 .577 .707 r
F P
0 g
s
.45491 .68479 m .46021 .66767 L .47186 .68191 L p .707 .577 .707 r
F P
0 g
s
.34293 .49948 m .33411 .55336 L .31024 .55673 L p .707 .577 .707 r
F P
0 g
s
.46133 .51959 m .45251 .57346 L .42545 .5641 L p .707 .577 .707 r
F P
0 g
s
.42545 .5641 m .43427 .51023 L .46133 .51959 L p .707 .577 .707 r
F P
0 g
s
.30182 .62051 m .29652 .63763 L .28036 .64359 L p .707 .577 .707 r
F P
0 g
s
.33411 .55336 m .34293 .49948 L .37202 .49966 L p .707 .577 .707 r
F P
0 g
s
.3027 .60335 m .31222 .56866 L .33578 .56669 L p .707 .577 .707 r
F P
0 g
s
.47189 .61142 m .46237 .64611 L .44227 .63244 L p .707 .577 .707 r
F P
0 g
s
.44227 .63244 m .45179 .59775 L .47189 .61142 L p .707 .577 .707 r
F P
0 g
s
.43427 .51023 m .42545 .5641 L .39468 .55724 L p .707 .577 .707 r
F P
0 g
s
.39468 .55724 m .4035 .50336 L .43427 .51023 L p .707 .577 .707 r
F P
0 g
s
.3632 .55354 m .37202 .49966 L .4035 .50336 L p .707 .577 .707 r
F P
0 g
s
.37202 .49966 m .3632 .55354 L .33411 .55336 L p .707 .577 .707 r
F P
0 g
s
.33578 .56669 m .32626 .60138 L .3027 .60335 L p .707 .577 .707 r
F P
0 g
s
.4035 .50336 m .39468 .55724 L .3632 .55354 L p .707 .577 .707 r
F P
0 g
s
.29652 .63763 m .30182 .62051 L .32527 .61894 L p .707 .577 .707 r
F P
0 g
s
.32626 .60138 m .33578 .56669 L .36441 .56903 L p .707 .577 .707 r
F P
0 g
s
.46021 .66767 m .45491 .68479 L .43504 .67033 L p .707 .577 .707 r
F P
0 g
s
.43504 .67033 m .44034 .6532 L .46021 .66767 L p .707 .577 .707 r
F P
0 g
s
.45179 .59775 m .44227 .63244 L .41587 .62006 L p .707 .577 .707 r
F P
0 g
s
.41587 .62006 m .4254 .58537 L .45179 .59775 L p .707 .577 .707 r
F P
0 g
s
.32527 .61894 m .31997 .63606 L .29652 .63763 L p .707 .577 .707 r
F P
0 g
s
.36441 .56903 m .35488 .60373 L .32626 .60138 L p .707 .577 .707 r
F P
0 g
s
.35488 .60373 m .36441 .56903 L .39528 .57547 L p .707 .577 .707 r
F P
0 g
s
.4254 .58537 m .41587 .62006 L .38576 .61016 L p .707 .577 .707 r
F P
0 g
s
.38576 .61016 m .39528 .57547 L .4254 .58537 L p .707 .577 .707 r
F P
0 g
s
.31997 .63606 m .32527 .61894 L .3537 .62192 L p .707 .577 .707 r
F P
0 g
s
.39528 .57547 m .38576 .61016 L .35488 .60373 L p .707 .577 .707 r
F P
0 g
s
.44034 .6532 m .43504 .67033 L .40891 .65706 L p .707 .577 .707 r
F P
0 g
s
.40891 .65706 m .4142 .63993 L .44034 .6532 L p .707 .577 .707 r
F P
0 g
s
.3537 .62192 m .34841 .63904 L .31997 .63606 L p .707 .577 .707 r
F P
0 g
s
.34841 .63904 m .3537 .62192 L .38435 .62915 L p .707 .577 .707 r
F P
0 g
s
.4142 .63993 m .40891 .65706 L .37905 .64628 L p .707 .577 .707 r
F P
0 g
s
.37905 .64628 m .38435 .62915 L .4142 .63993 L p .707 .577 .707 r
F P
0 g
s
.38435 .62915 m .37905 .64628 L .34841 .63904 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolA002;Ool007aoo`D0
009JEP03001JEUYF00QJEP04001JEUYFFUH60025Ool007Qoo`@000MJEP03001JEUYF00QJEP03001J
EUYF00MJEPH007moo`00MGoo0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00NGoo001cOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP06FUH5001dOol0079oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEP000080075oo`00LGoo00<005YF000015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF0P00Kgoo001aOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH3001/Ool0071oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP8006Yoo`00L7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00J7oo001`
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP02001VOol006moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH2
001TOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0@FUH2001ROol006moo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001oogoo05moo`00Kgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF0P00H7oo001_Ool00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH01000FUH00000GWoo001_Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00Oomoo`1K
Ool006ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0<FUH00`00Oomoo`1JOol006ioo`04001JEUYF0004
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1JOol006ioo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001oogoo05Yoo`00KWoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00<007ooOol0FGoo001^Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00Oomoo`1IOol006ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0005]oo`00KGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
05]oo`00KGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005]oo`00
KGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0Fgoo001]Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUILOol006eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP03001JEUYF05aoo`00KGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000G7oo001/Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1L
Ool006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF05eoo`00K7oo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH0GGoo001/Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001MOol006]oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEWoo05eoo`00Jgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YFFUH0GWoo001[Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001N
Ool006]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo
00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0GWoo001ZOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIJEP1OOol006Yoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF0P0035YF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001Y
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIoo`1OOol006Uoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000H7oo001YOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo
061oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P00HWoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0
001ROol006Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00069oo`00
Igoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001SOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006=oo`00IWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
0000Hgoo001VOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001NOol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol005Uoo`D000=J
EP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Aoo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
I7oo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001TOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000D000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
15YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Io
o`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Uooa0004eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEP0000Aoo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00DWoo00<005YF0000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<004=oo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@003moo`00DWoo00<005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00
DWoo0P000eYF1@000UYF00@005YFFUIJEP<000IJEPL000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP<003Yoo`00DWoo00=JEP00FUH00`001EYF00<005YFFUH015YF10000eYF00@005YFFUIJEPL0009J
EP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Qoo`00DGoo00@005YF0000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@0009JEPH0009JEP@000MJEP03001JEUYF
00=JEP05001JEUYFFUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF0`00=Woo001AOol30002FUH00`00FUH0000A0002FUH80006FUH20004FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF008003Aoo`00DGoo00<005YFFUH00UYF0`001UYF00<005YFFUH01EYF
00<005YFFUH05@0000=JEP00FUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000bOol0055oo`03001JEUYF
0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJ
EP8000IJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000aOol0059oo`<0009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YF0000<7oo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUH00002FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00=goo40002Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH0100035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000=oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
00IJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUH000000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP06001JEUYF001JEP00;Woo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP050003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20004FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000AJEP00FUIJEPD0009JEP04001JEUYFFUH30007Ool70006FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01`00FUIJEUYF001JEP0002ioo`00;goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF4P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF0`000UYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP00FUH40006FUH00`00FUIJEP04FUH40006Ool80002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00000020001UYF00@005YFFUIJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH010000Woo1@000goo10001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Mo
o`@0009JEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP8000AJEP@00003FUH0000000<0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP03FUH700000eYF001J
EP08FUH00`00FUIJEP02FUH>0005FUH01000FUIJEUYF0P00;goo000]Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP020002FUH0
1000FUIJEP000UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001J
EUYF00AJEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF000015YF1P000UYF00<005YFFUH00UYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YF0000009JEP03001JEUYF009JEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF4P0000=JEP00FUH0
1`0015YF0`001UYF00<005YFFUH015YF00H005YFFUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH00004
0009FUH00`00FUIJEP05FUH01000FUIJEUYF0`0015YF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0`001EYF
00<005YFFUH01UYF00<005YFFUH010001UYF2@0015YF00<005YFFUH015YF00@005YFFUIJEP8000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF100000=JEP00FUH025YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00EJEP03001JEUYF
00AJEP80009JEP03001JEP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000]JEP8000IJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0002moo`00;7oo
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJEP04001JEP000004FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00800003FUH007oo02ioo`00:goo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1@000UYF00<0
05YFFUH00UYF1P001eYF00<005YFFUH01EYF0P001UYF00D005YFFUIJEP0000=JEP07001JEUYFFUH0
05YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000006FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP02FUH30003FUH01000
FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<0
05YFFUH00UYF0P00<7oo000[Ool00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH00UYF
0`0000=JEP0000001UYF00<005YFFUH01EYF00<005YFFUH015YF100025YF00<005YFFUH00P0000=J
EP00FUH01UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20004FUH01`00FUIJEUYF001JEP00031oo`00:goo0P000eYF1@00
0UYF00<005YF00000`0027oo1P000UYF0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00=JEP8000QJEP06001JEUYF001JEP002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH7
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01`00FUIJEUYF001J
EP00031oo`00:goo00=JEP00FUH00`001UYF00<005YFFUH00eYF10001goo1P0000AJEP00000000AJ
EP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP06FUH20002FUH5
0002FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000UYF2@0000=oo`00000020001UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH2000aOol002Yoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP040002Ool500001Goo001JEP00FUH00P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0025YF0`000eYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0000300000eYF001JEP05FUH30003Ool40002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000bOol002Yoo`<0009JEP03001JEP000140009J
EPL00003Ool005YF00=JEP<000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0005FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P001Goo
10000UYF10001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP02FUH3
0006FUH00`00FUIJEP05FUH00`00FUIJEP0<0004FUH500000eYF001JEP020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YF00002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF0`000eYF00<005YFFUH00UYF
0P001goo2P000UYF00<005YFFUH01UYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP020002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP02FUH20003
FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH0
0003FUH01000FUIJEUYF0`001UYF0P0037oo1`0025YF00<005YFFUH00eYF00<005YF0000=7oo000Z
Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP04001JEUYF0002FUH200000eYF001JEP0200000eYF001JEP030008FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH00eYF0P001EYF00<005YF00002Woo1@00
0goo0P001UYF00<005YFFUH00eYF00@005YFFUH003=oo`00:goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF0P000eYF0P00
00AJEP00FUIJEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP00FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YF
FUH015YF0`000eYF00@005YFFUH000Uoo`D000Eoo`8000=JEP03001JEUYF00AJEP05001JEUYFFUH0
000bOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP000003FUHC0008Ool50007Ool200000eYF001JEP04FUH00`00FUIJEP02
FUH00`00Oomoo`0`Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<00005FUH005YFFUH00005FUH00`00FUIJEP030004FUH4
0008FUH01000FUIJEUYF0`0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF0000009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEP0000<000Eoo`<0
00Yoo`8000EJEP03001JEUYF009JEP80035oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF0`0015YF00<005YFFUH00P0000=JEP00FUH01EYF00<0
05YFFUH00eYF20001eYF00<005YFFUH00eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
15YF100047oo00<005YFFUH00UYF00L005YFFUIJEP00FUH0000aOol002Yoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP03FUH20006FUH00`00FUIJEP06FUH90003FUH01000FUIJEUYF1@000UYF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000ioo`80009JEP07001JEUYFFUH005YF0000
<Goo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30007FUH30003FUH00`00FUIJEP05FUH60004FUH70004FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04
001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000=Ool20004FUH00`00FUIoo`0a
Ool002Uoo`03001JEP00009JEQ8000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP06001JEP00001JEP001eYF00<005YF00000P001eYF00<005YFFUH01eYF0P0000=JEP0000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000eYF10000UYF00<0
05YFFUH00UYF1`001UYF00<005YFFUH01UYF0P0037oo00<005YFFUH00UYF0P00<Woo000YOol20000
15YF0000000017oo0`001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP80
00EJEP03001JEUYF009JEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000aJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000800003FUH00000009JEP05
001JEUYFFUH00007FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF0`002goo00@005YFFUIJEP80
039oo`00:Goo0`000eYF00<007ooOol017oo0P0015YF00<005YFFUH01EYF100025YF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00EJEP@0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH20002
Ool2000015YF0000000025YF00<005YFFUH01EYF10001eYF00@005YFFUIJEPd00003FUH0000003=o
o`00:Goo0P0015YF0P001goo0`0000=JEP00FUH01eYF00<005YFFUH00`0015YF00<005YFFUH01UYF
00<005YFFUH010002EYF00<005YFFUH010002UYF00<005YFFUH01eYF100035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF3P0025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<0
05YFFUH00eYF0`001UYF00<005YF00000P00<goo000XOol30003FUH00`00FUIJEP020008Ool40006
FUH00`00FUIJEP03FUH300000eYF001JEP06FUH01P00FUIJEUYF001JEP<000QJEP03001JEUYF00AJ
EPL000=JEP04001JEUYFFUH6000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF00D005YF000005YF008000MJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYFFUH2000cOol002Qoo`03001JEP0000=JEP/0
00Ioo`@0009JEP03001JEUYF00IJEP8000MJEP07001JEUYFFUH005YF00000UYF0`0015YF00<005YF
FUH01eYF00<005YFFUH00UYF1`000eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00IJEP03001JEP00008000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP8000QJEP<000=JEP03001JEUYF00<003=oo`00:7oo00@005YFFUIJ
EP<000IJEP04001JEUYFFUH70003Ool70004FUH01000FUH000001EYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00=JEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00=JEP<00004FUH0
00000006FUH01000FUIJEP000UYF00<005YFFUH00P00=7oo000YOol30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040006Ool:0003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH40007FUH00`00FUIJEP02FUH50003FUH20003FUH00`00FUIJEP02FUH20003FUH2000dOol0
02Uoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000aoo`<000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00
0004FUH30002FUH00`00FUIJEP04FUH01000FUH005YF0P001EYF00<005YFFUH00UYF1@001EYF0P00
00=JEP00FUH01EYF00@005YFFUH003Eoo`00:Goo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH0100000=J
EP00FUH01P0015YF00@005YFFUIJEPH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUH00006FUH00`00FUIJEP02
00001UYF00000000FUH000EJEPD000MJEP8000IJEP@003Eoo`00:7oo0P000UYF4P001eYF00<005YF
FUH00UYF0`002Woo0P0000AJEP00FUH000EJEP@000EJEP03001JEUYF00EJEPP000AJEPP000YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEP0000AJEP80
00EJEP03001JEUYF009JEP8000=oo`H0009JEP<000QJEP03001JEP0000AJEP04001JEP00000fOol0
02Moo`800004FUH000000006FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP06FUH3
0009Ool01@00FUIJEP00FUH010002EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YFFUIJEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP8000IJEP03
001JEUYF009JEP03001JEUYF009JEP8000Uoo`P000AJEP04001JEUYFFUH20002FUH01000FUIJEP00
=Woo000WOol30002Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40008FUH01000
FUH0000027oo0UYF0P000eYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YF
FUH01EYF10000UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF
0P001UYF0`000UYF00L005YFFUIJEP00FUH0000AOol<0004FUH00`00Oomoo`0cOol002Ioo`<000Ao
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01000FUIJEUYF0`0017oo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF
10002UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF00<005YF000015YF00@005YF
FUIJEP<000=JEP03001JEP0001aoo`03001JEUYF009JEP03001oogoo03=oo`009Woo00@005YF0000
00Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF0P00
0Woo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00@0
05YFFUIJEP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH20002FUH2000NOol01@00FUIJEUYF0000=Goo000VOol01@00FUH005YF
00001Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH01eYF1P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF0P0025YF10007goo00D0
05YF001JEP0003Aoo`009Woo00<005YFFUH00UYF00<007ooOol017oo0P001UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001UYF00<005YFFUH00P0000=JEP00FUH03EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH01eYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0
<goo000WOol00`00FUIJEP02FUH00`00Oomoo`05Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP020004FUH01@00FUIJEUYF000045YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF0`0025YF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000=7oo000WOol00`00FUIJEP02FUH20008
Ool200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP07FUH0
1000FUH000000eYF00<005YFFUH01UYF0`006Woo0P00=Goo000XOol01000FUIJEP000UYF0P0027oo
0`0025YF00<005YFFUH01EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000Woo0`001eYF00@005YFFUIJEP800003FUH005YF00QJ
EP03001JEP0000<001Aoo`@003Eoo`00:7oo00@005YFFUH000AJEP03001oogoo00Qoo`<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP03001JEP0000Eoo`8000AJEP03001JEUYF00AJEP<000MJEP03001JEUYF00AJEPH000Qo
o`H0009JEP03001oogoo03Aoo`00:Goo0P001UYF00<007ooOol02Woo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00@005YFFUH0009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP8000EJEP8000Qoo`<00003FUH0
05YF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJ
EP8003Ioo`00:Woo00<005YFFUH015YF0`003Goo0`0015YF100025YF00@005YFFUIJEP<00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEP0000=JEP03001JEP0000]oo`8000EJEP03001JEUYF009JEP@00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000gOol002]oo`8000AJEP03001J
EUYF008000ioo`P000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00800004
FUH005YF000=Ool00`00FUIJEP02FUH01`00FUIJEUYF001JEP00009oo`@000IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYFFUH2000gOol002eoo`04001JEUYF0005FUH2000?Ool80004FUH0
1000FUIJEUYF1@000UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00Ool03Goo0P000UYF
00L005YFFUIJEP00FUH00006Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000hOol002ioo`<000MJEP<000aoo`D000=oo`P000Aoo`03001JEUYF00<000QJEP03001JEUYF00MJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP800003FUH007oo00moo`8000AJEP03001JEWoo00Yoo`H000AJEP04001JEUYFFUH6000jOol0031o
o`03001JEUYF00IJEP04001JEP00000;Ool3000AOol200000eYF001oo`02000@FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000
0002000>Ool00`00FUIJEP02FUH2000AOol80010Ool0035oo`8000EJEP03001JEUYF009JEP<001eo
o`03001JEP0000=oo`8000iJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000AJEP<000aoo`04001JEUYFFUH2001IOol003=oo`8000=JEP03
001JEUYF00EJEP@001Uoo`03001JEP0000Eoo`8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEP0000d00003
FUH0000005Yoo`00=Goo0`002EYF00<005YFFUH010005Goo0P0027oo0`002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YF00000P00FWoo000gOol20008FUH00`00FUIJ
EP04FUH6000=Ool4000;Ool2000DFUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF0P001EYF00@005YFFUIJEP8005Yoo`00
>Goo0`0015YF00<005YFFUH01eYF00@005YFFUIJEPd0009JEP8000eoo`<0015JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP07
FUH20004FUH00`00FUIJEP03001JOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF0080015oo`8000mJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP<000MJEP03001JEP0000=JEP03001JEUYF008005]oo`00?goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8001=oo`@001MJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP8000AJEP04001JEUYFFUH3
0003FUH2001KOol0049oo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008001Qo
o`@0019JEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH50004FUH300000eYF
001JEP04FUH01@00FUIJEUYF0000G7oo0016Ool60004FUH00`00FUIJEP04FUH01000FUH000007Woo
10003UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000AJEPD000MJEP8000IJEP04001J
EP00001LOol004aoo`d002Aoo`P000IJEP03001JEUYF00UJEP03001JEUYF00=JEPT000=JEPD000MJ
EP03001JEP0000AJEP04001JEP00001MOol008EooaP000Uoo`L000MJEP04001JEUYFFUH20002FUH0
0`00FUH0001NOol008aoo`03001JEUYF00AJEP<001Aooa8000=JEP03001oogoo05]oo`00SGoo00<0
05YFFUH00UYF00@005YFFUIJEP8002=oo`03001JEUYF009JEP03001oogoo05Yoo`00SWoo0P000UYF
00<005YFFUH00eYF0P008Woo00D005YFFUIJEP0005aoo`00T7oo0P0025YF0P008Goo00D005YF001J
EP0005]oo`00TGoo00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0FWoo002BOol2
0006FUH00`00FUIJEP02FUH3000MOol00`00FUH0001KOol009Aoo`8000=JEP03001JEUYF00IJEP<0
01Yoo`8005aoo`00UWoo0P0000=JEP00FUH025YF00<005YF00000`005Goo0`00G7oo002HOol30007
FUH00`00FUIJEP04FUH6000=Ool200000eYF001oo`1LOol009]oo`8000EJEP03001JEUYF00IJEP04
001JEUYFFUH=0002FUH2001MOol009eoo`<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol00:1oo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008005ioo`00Y7oo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005mo
o`00Z7oo1P0015YF00<005YFFUH015YF00@005YF0000061oo`00[Woo3@00HWoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58613 .75537 m .59496 .70149 L .56418 .69463 L p .707 .577 .707 r
F P
0 g
s
.59496 .70149 m .58613 .75537 L .61761 .75907 L p .707 .577 .707 r
F P
0 g
s
.61761 .75907 m .62643 .7052 L .59496 .70149 L p .707 .577 .707 r
F P
0 g
s
.62643 .7052 m .61761 .75907 L .6467 .75925 L p .707 .577 .707 r
F P
0 g
s
.6467 .75925 m .65553 .70537 L .62643 .7052 L p .707 .577 .707 r
F P
0 g
s
.55536 .7485 m .56418 .69463 L .53713 .68527 L p .707 .577 .707 r
F P
0 g
s
.56418 .69463 m .55536 .7485 L .58613 .75537 L p .707 .577 .707 r
F P
0 g
s
.65553 .70537 m .6467 .75925 L .67057 .75588 L p .707 .577 .707 r
F P
0 g
s
.67057 .75588 m .67939 .702 L .65553 .70537 L p .707 .577 .707 r
F P
0 g
s
.5283 .73915 m .53713 .68527 L .51643 .67434 L p .707 .577 .707 r
F P
0 g
s
.53713 .68527 m .5283 .73915 L .55536 .7485 L p .707 .577 .707 r
F P
0 g
s
.5759 .82053 m .58542 .78584 L .55531 .77595 L p .707 .577 .707 r
F P
0 g
s
.58542 .78584 m .5759 .82053 L .60678 .82697 L p .707 .577 .707 r
F P
0 g
s
.60678 .82697 m .6163 .79228 L .58542 .78584 L p .707 .577 .707 r
F P
0 g
s
.54579 .81064 m .55531 .77595 L .52891 .76356 L p .707 .577 .707 r
F P
0 g
s
.55531 .77595 m .54579 .81064 L .5759 .82053 L p .707 .577 .707 r
F P
0 g
s
.6163 .79228 m .60678 .82697 L .6354 .82931 L p .707 .577 .707 r
F P
0 g
s
.6354 .82931 m .64492 .79462 L .6163 .79228 L p .707 .577 .707 r
F P
0 g
s
.51643 .67434 m .50761 .72821 L .5283 .73915 L p .707 .577 .707 r
F P
0 g
s
.67939 .702 m .67057 .75588 L .68688 .7493 L p .707 .577 .707 r
F P
0 g
s
.68688 .7493 m .6957 .69542 L .67939 .702 L p .707 .577 .707 r
F P
0 g
s
.50761 .72821 m .51643 .67434 L .50413 .6629 L p .707 .577 .707 r
F P
0 g
s
.51939 .79825 m .52891 .76356 L .50881 .74989 L p .707 .577 .707 r
F P
0 g
s
.52891 .76356 m .51939 .79825 L .54579 .81064 L p .707 .577 .707 r
F P
0 g
s
.64492 .79462 m .6354 .82931 L .65896 .82734 L p .707 .577 .707 r
F P
0 g
s
.65896 .82734 m .66849 .79265 L .64492 .79462 L p .707 .577 .707 r
F P
0 g
s
.56867 .8671 m .57397 .84997 L .54412 .83919 L p .707 .577 .707 r
F P
0 g
s
.57397 .84997 m .56867 .8671 L .59932 .87433 L p .707 .577 .707 r
F P
0 g
s
.59932 .87433 m .60461 .85721 L .57397 .84997 L p .707 .577 .707 r
F P
0 g
s
.53882 .85632 m .54412 .83919 L .51798 .82592 L p .707 .577 .707 r
F P
0 g
s
.54412 .83919 m .53882 .85632 L .56867 .8671 L p .707 .577 .707 r
F P
0 g
s
.60461 .85721 m .59932 .87433 L .62776 .87731 L p .707 .577 .707 r
F P
0 g
s
.62776 .87731 m .63305 .86019 L .60461 .85721 L p .707 .577 .707 r
F P
0 g
s
.50881 .74989 m .49929 .78458 L .51939 .79825 L p .707 .577 .707 r
F P
0 g
s
.50413 .6629 m .4953 .71677 L .50761 .72821 L p .707 .577 .707 r
F P
0 g
s
.51798 .82592 m .51268 .84305 L .53882 .85632 L p .707 .577 .707 r
F P
0 g
s
.6957 .69542 m .68688 .7493 L .69403 .74015 L p .707 .577 .707 r
F P
0 g
s
.69403 .74015 m .70285 .68627 L .6957 .69542 L p .707 .577 .707 r
F P
0 g
s
.49929 .78458 m .50881 .74989 L .49698 .73628 L p .707 .577 .707 r
F P
0 g
s
.51268 .84305 m .51798 .82592 L .49811 .81146 L p .707 .577 .707 r
F P
0 g
s
.66849 .79265 m .65896 .82734 L .67516 .82124 L p .707 .577 .707 r
F P
0 g
s
.67516 .82124 m .68469 .78655 L .66849 .79265 L p .707 .577 .707 r
F P
0 g
s
.4953 .71677 m .50413 .6629 L .50141 .65207 L p .707 .577 .707 r
F P
0 g
s
.63305 .86019 m .62776 .87731 L .6512 .87574 L p .707 .577 .707 r
F P
0 g
s
.6512 .87574 m .6565 .85862 L .63305 .86019 L p .707 .577 .707 r
F P
0 g
s
.49811 .81146 m .49281 .82858 L .51268 .84305 L p .707 .577 .707 r
F P
0 g
s
.49698 .73628 m .48746 .77098 L .49929 .78458 L p .707 .577 .707 r
F P
0 g
s
.49281 .82858 m .49811 .81146 L .48646 .79722 L p .707 .577 .707 r
F P
0 g
s
.50141 .65207 m .49259 .70595 L .4953 .71677 L p .707 .577 .707 r
F P
0 g
s
.44794 .82092 m .52717 .33431 L .48372 .32466 L p .707 .577 .707 r
F P
0 g
s
.48746 .77098 m .49698 .73628 L .49457 .72407 L p .707 .577 .707 r
F P
0 g
s
.48646 .79722 m .48117 .81434 L .49281 .82858 L p .707 .577 .707 r
F P
0 g
s
.49259 .70595 m .50141 .65207 L .50856 .64292 L p .707 .577 .707 r
F P
0 g
s
.49457 .72407 m .48505 .75876 L .48746 .77098 L p .707 .577 .707 r
F P
0 g
s
.48117 .81434 m .48646 .79722 L .48417 .78459 L p .707 .577 .707 r
F P
0 g
s
.50856 .64292 m .49974 .6968 L .49259 .70595 L p .707 .577 .707 r
F P
0 g
s
.48417 .78459 m .47888 .80172 L .48117 .81434 L p .707 .577 .707 r
F P
0 g
s
.48505 .75876 m .49457 .72407 L .50182 .71444 L p .707 .577 .707 r
F P
0 g
s
.49974 .6968 m .50856 .64292 L .52486 .63634 L p .707 .577 .707 r
F P
0 g
s
.50182 .71444 m .4923 .74913 L .48505 .75876 L p .707 .577 .707 r
F P
0 g
s
.47888 .80172 m .48417 .78459 L .49147 .77482 L p .707 .577 .707 r
F P
0 g
s
.52486 .63634 m .51604 .69022 L .49974 .6968 L p .707 .577 .707 r
F P
0 g
s
.49147 .77482 m .48617 .79195 L .47888 .80172 L p .707 .577 .707 r
F P
0 g
s
.4923 .74913 m .50182 .71444 L .51802 .70833 L p .707 .577 .707 r
F P
0 g
s
.51802 .70833 m .5085 .74303 L .4923 .74913 L p .707 .577 .707 r
F P
0 g
s
.48617 .79195 m .49147 .77482 L .50763 .76886 L p .707 .577 .707 r
F P
0 g
s
.50763 .76886 m .50233 .78598 L .48617 .79195 L p .707 .577 .707 r
F P
0 g
s
.52717 .33431 m .44794 .82092 L .49238 .82611 L p .707 .577 .707 r
F P
0 g
s
.49238 .82611 m .57161 .33951 L .52717 .33431 L p .707 .577 .707 r
F P
0 g
s
.6565 .85862 m .6512 .87574 L .66736 .86978 L p .707 .577 .707 r
F P
0 g
s
.66736 .86978 m .67266 .85266 L .6565 .85862 L p .707 .577 .707 r
F P
0 g
s
.51604 .69022 m .52486 .63634 L .54873 .63297 L p .707 .577 .707 r
F P
0 g
s
.54873 .63297 m .53991 .68685 L .51604 .69022 L p .707 .577 .707 r
F P
0 g
s
.53991 .68685 m .54873 .63297 L .57783 .63315 L p .707 .577 .707 r
F P
0 g
s
.5085 .74303 m .51802 .70833 L .54159 .70636 L p .707 .577 .707 r
F P
0 g
s
.57783 .63315 m .56901 .68703 L .53991 .68685 L p .707 .577 .707 r
F P
0 g
s
.54159 .70636 m .53207 .74105 L .5085 .74303 L p .707 .577 .707 r
F P
0 g
s
.50233 .78598 m .50763 .76886 L .53107 .76729 L p .707 .577 .707 r
F P
0 g
s
.53207 .74105 m .54159 .70636 L .57021 .70871 L p .707 .577 .707 r
F P
0 g
s
.53107 .76729 m .52578 .78442 L .50233 .78598 L p .707 .577 .707 r
F P
0 g
s
.57021 .70871 m .56069 .7434 L .53207 .74105 L p .707 .577 .707 r
F P
0 g
s
.52578 .78442 m .53107 .76729 L .55951 .77027 L p .707 .577 .707 r
F P
0 g
s
.55951 .77027 m .55421 .7874 L .52578 .78442 L p .707 .577 .707 r
F P
0 g
s
.57161 .33951 m .49238 .82611 L .53346 .82634 L p .707 .577 .707 r
F P
0 g
s
.53346 .82634 m .61269 .33973 L .57161 .33951 L p .707 .577 .707 r
F P
0 g
s
.70285 .68627 m .69403 .74015 L .69131 .72932 L p .707 .577 .707 r
F P
0 g
s
.69131 .72932 m .70013 .67545 L .70285 .68627 L p .707 .577 .707 r
F P
0 g
s
.68469 .78655 m .67516 .82124 L .68242 .81161 L p .707 .577 .707 r
F P
0 g
s
.68242 .81161 m .69194 .77692 L .68469 .78655 L p .707 .577 .707 r
F P
0 g
s
.40449 .81126 m .48372 .32466 L .44551 .31148 L p .707 .577 .707 r
F P
0 g
s
.48372 .32466 m .40449 .81126 L .44794 .82092 L p .707 .577 .707 r
F P
0 g
s
.56901 .68703 m .57783 .63315 L .6093 .63685 L p .707 .577 .707 r
F P
0 g
s
.6093 .63685 m .60048 .69073 L .56901 .68703 L p .707 .577 .707 r
F P
0 g
s
.56069 .7434 m .57021 .70871 L .60109 .71514 L p .707 .577 .707 r
F P
0 g
s
.60109 .71514 m .59157 .74983 L .56069 .7434 L p .707 .577 .707 r
F P
0 g
s
.55421 .7874 m .55951 .77027 L .59016 .7775 L p .707 .577 .707 r
F P
0 g
s
.59016 .7775 m .58486 .79463 L .55421 .7874 L p .707 .577 .707 r
F P
0 g
s
.61269 .33973 m .53346 .82634 L .56716 .82156 L p .707 .577 .707 r
F P
0 g
s
.56716 .82156 m .64639 .33496 L .61269 .33973 L p .707 .577 .707 r
F P
0 g
s
.36628 .79809 m .44551 .31148 L .41629 .29608 L p .707 .577 .707 r
F P
0 g
s
.44551 .31148 m .36628 .79809 L .40449 .81126 L p .707 .577 .707 r
F P
0 g
s
.67266 .85266 m .66736 .86978 L .67465 .86001 L p .707 .577 .707 r
F P
0 g
s
.67465 .86001 m .67995 .84289 L .67266 .85266 L p .707 .577 .707 r
F P
0 g
s
.69194 .77692 m .68242 .81161 L .68001 .79939 L p .707 .577 .707 r
F P
0 g
s
.68001 .79939 m .68953 .7647 L .69194 .77692 L p .707 .577 .707 r
F P
0 g
s
.70013 .67545 m .69131 .72932 L .67901 .71789 L p .707 .577 .707 r
F P
0 g
s
.67901 .71789 m .68783 .66401 L .70013 .67545 L p .707 .577 .707 r
F P
0 g
s
.24313 .71392 m .25195 .66004 L .22117 .65318 L p .707 .577 .707 r
F P
0 g
s
.25195 .66004 m .24313 .71392 L .2746 .71762 L p .707 .577 .707 r
F P
0 g
s
.2746 .71762 m .28342 .66374 L .25195 .66004 L p .707 .577 .707 r
F P
0 g
s
.28342 .66374 m .2746 .71762 L .3037 .7178 L p .707 .577 .707 r
F P
0 g
s
.3037 .7178 m .31252 .66392 L .28342 .66374 L p .707 .577 .707 r
F P
0 g
s
.21235 .70705 m .22117 .65318 L .19412 .64382 L p .707 .577 .707 r
F P
0 g
s
.22117 .65318 m .21235 .70705 L .24313 .71392 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64008 .64372 m .63125 .69759 L .60048 .69073 L p .707 .577 .707 r
F P
0 g
s
.60048 .69073 m .6093 .63685 L .64008 .64372 L p .707 .577 .707 r
F P
0 g
s
.6312 .72504 m .62168 .75973 L .59157 .74983 L p .707 .577 .707 r
F P
0 g
s
.59157 .74983 m .60109 .71514 L .6312 .72504 L p .707 .577 .707 r
F P
0 g
s
.62001 .78828 m .61471 .80541 L .58486 .79463 L p .707 .577 .707 r
F P
0 g
s
.58486 .79463 m .59016 .7775 L .62001 .78828 L p .707 .577 .707 r
F P
0 g
s
.64639 .33496 m .56716 .82156 L .59018 .81227 L p .707 .577 .707 r
F P
0 g
s
.59018 .81227 m .66941 .32566 L .64639 .33496 L p .707 .577 .707 r
F P
0 g
s
.35269 .65397 m .34387 .70785 L .35102 .6987 L p .707 .577 .707 r
F P
0 g
s
.35102 .6987 m .35984 .64482 L .35269 .65397 L p .707 .577 .707 r
F P
0 g
s
.34168 .73891 m .33216 .77361 L .33941 .76398 L p .707 .577 .707 r
F P
0 g
s
.33941 .76398 m .34893 .72928 L .34168 .73891 L p .707 .577 .707 r
F P
0 g
s
.35984 .64482 m .35102 .6987 L .3483 .68787 L p .707 .577 .707 r
F P
0 g
s
.3483 .68787 m .35713 .634 L .35984 .64482 L p .707 .577 .707 r
F P
0 g
s
.33216 .77361 m .34168 .73891 L .32548 .74502 L p .707 .577 .707 r
F P
0 g
s
.34893 .72928 m .33941 .76398 L .337 .75176 L p .707 .577 .707 r
F P
0 g
s
.337 .75176 m .34652 .71707 L .34893 .72928 L p .707 .577 .707 r
F P
0 g
s
.33639 .66055 m .32756 .71443 L .34387 .70785 L p .707 .577 .707 r
F P
0 g
s
.34387 .70785 m .35269 .65397 L .33639 .66055 L p .707 .577 .707 r
F P
0 g
s
.35713 .634 m .3483 .68787 L .336 .67643 L p .707 .577 .707 r
F P
0 g
s
.336 .67643 m .34482 .62256 L .35713 .634 L p .707 .577 .707 r
F P
0 g
s
.34652 .71707 m .337 .75176 L .32516 .73815 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .33469 .70346 L .34652 .71707 L p .707 .577 .707 r
F P
0 g
s
.33706 .78269 m .41629 .29608 L .39891 .27996 L p .707 .577 .707 r
F P
0 g
s
.41629 .29608 m .33706 .78269 L .36628 .79809 L p .707 .577 .707 r
F P
0 g
s
.67995 .84289 m .67465 .86001 L .67236 .84739 L p .707 .577 .707 r
F P
0 g
s
.67236 .84739 m .67766 .83026 L .67995 .84289 L p .707 .577 .707 r
F P
0 g
s
.31252 .66392 m .3037 .7178 L .32756 .71443 L p .707 .577 .707 r
F P
0 g
s
.32756 .71443 m .33639 .66055 L .31252 .66392 L p .707 .577 .707 r
F P
0 g
s
.1853 .6977 m .19412 .64382 L .17342 .63289 L p .707 .577 .707 r
F P
0 g
s
.19412 .64382 m .1853 .6977 L .21235 .70705 L p .707 .577 .707 r
F P
0 g
s
.68783 .66401 m .67901 .71789 L .65831 .70695 L p .707 .577 .707 r
F P
0 g
s
.65831 .70695 m .66713 .65308 L .68783 .66401 L p .707 .577 .707 r
F P
0 g
s
.68953 .7647 m .68001 .79939 L .66817 .78578 L p .707 .577 .707 r
F P
0 g
s
.66817 .78578 m .6777 .75109 L .68953 .7647 L p .707 .577 .707 r
F P
0 g
s
.23289 .7729 m .24241 .73821 L .2123 .72831 L p .707 .577 .707 r
F P
0 g
s
.24241 .73821 m .23289 .7729 L .26377 .77934 L p .707 .577 .707 r
F P
0 g
s
.26377 .77934 m .27329 .74465 L .24241 .73821 L p .707 .577 .707 r
F P
0 g
s
.20278 .76301 m .2123 .72831 L .1859 .71593 L p .707 .577 .707 r
F P
0 g
s
.2123 .72831 m .20278 .76301 L .23289 .7729 L p .707 .577 .707 r
F P
0 g
s
.27329 .74465 m .26377 .77934 L .29239 .78168 L p .707 .577 .707 r
F P
0 g
s
.29239 .78168 m .30191 .74699 L .27329 .74465 L p .707 .577 .707 r
F P
0 g
s
.17342 .63289 m .1646 .68676 L .1853 .6977 L p .707 .577 .707 r
F P
0 g
s
.1646 .68676 m .17342 .63289 L .16112 .62145 L p .707 .577 .707 r
F P
0 g
s
.66713 .65308 m .65831 .70695 L .63125 .69759 L p .707 .577 .707 r
F P
0 g
s
.63125 .69759 m .64008 .64372 L .66713 .65308 L p .707 .577 .707 r
F P
0 g
s
.17638 .75062 m .1859 .71593 L .1658 .70226 L p .707 .577 .707 r
F P
0 g
s
.1859 .71593 m .17638 .75062 L .20278 .76301 L p .707 .577 .707 r
F P
0 g
s
.30191 .74699 m .29239 .78168 L .31595 .77971 L p .707 .577 .707 r
F P
0 g
s
.31595 .77971 m .32548 .74502 L .30191 .74699 L p .707 .577 .707 r
F P
0 g
s
.22566 .81079 m .23096 .79366 L .20111 .78288 L p .707 .577 .707 r
F P
0 g
s
.23096 .79366 m .22566 .81079 L .25631 .81802 L p .707 .577 .707 r
F P
0 g
s
.25631 .81802 m .26161 .80089 L .23096 .79366 L p .707 .577 .707 r
F P
0 g
s
.67766 .83026 m .67236 .84739 L .66072 .83315 L p .707 .577 .707 r
F P
0 g
s
.66072 .83315 m .66601 .81602 L .67766 .83026 L p .707 .577 .707 r
F P
0 g
s
.66941 .32566 m .59018 .81227 L .60027 .79935 L p .707 .577 .707 r
F P
0 g
s
.60027 .79935 m .6795 .31275 L .66941 .32566 L p .707 .577 .707 r
F P
0 g
s
.6777 .75109 m .66817 .78578 L .64808 .77212 L p .707 .577 .707 r
F P
0 g
s
.64808 .77212 m .6576 .73742 L .6777 .75109 L p .707 .577 .707 r
F P
0 g
s
.19581 .80001 m .20111 .78288 L .17497 .76961 L p .707 .577 .707 r
F P
0 g
s
.20111 .78288 m .19581 .80001 L .22566 .81079 L p .707 .577 .707 r
F P
0 g
s
.26161 .80089 m .25631 .81802 L .28475 .821 L p .707 .577 .707 r
F P
0 g
s
.28475 .821 m .29004 .80387 L .26161 .80089 L p .707 .577 .707 r
F P
0 g
s
.32548 .74502 m .31595 .77971 L .33216 .77361 L p .707 .577 .707 r
F P
0 g
s
.34482 .62256 m .336 .67643 L .3153 .6655 L p .707 .577 .707 r
F P
0 g
s
.3153 .6655 m .32412 .61162 L .34482 .62256 L p .707 .577 .707 r
F P
0 g
s
.32516 .73815 m .30507 .72448 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.33469 .70346 m .32974 .72149 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.32974 .72149 m .32516 .73815 L p .33219 .70523 L .707 .577 .707 r
F P
0 g
s
.30507 .72448 m .31459 .68979 L .33469 .70346 L p .707 .577 .707 r
F P
0 g
s
.323 .75971 m .31771 .77683 L .29784 .76237 L p .707 .577 .707 r
F P
0 g
s
.29784 .76237 m .30314 .74524 L .323 .75971 L p .707 .577 .707 r
F P
0 g
s
.31968 .76657 m .36445 .49161 L p .39508 .26469 L .707 .577 .707 r
F P
0 g
s
.36445 .49161 m .39891 .27996 L .39735 .27375 L p .707 .577 .707 r
F P
0 g
s
.39735 .27375 m .39508 .26469 L p .36445 .49161 L .707 .577 .707 r
F P
0 g
s
.32935 .79107 m .33465 .77395 L .33694 .78657 L p .707 .577 .707 r
F P
0 g
s
.33465 .77395 m .32935 .79107 L .31771 .77683 L p .707 .577 .707 r
F P
0 g
s
.31771 .77683 m .323 .75971 L .33465 .77395 L p .707 .577 .707 r
F P
0 g
s
.39891 .27996 m .31968 .76657 L .33706 .78269 L p .707 .577 .707 r
F P
0 g
s
.1658 .70226 m .15628 .73695 L .17638 .75062 L p .707 .577 .707 r
F P
0 g
s
.17497 .76961 m .16967 .78673 L .19581 .80001 L p .707 .577 .707 r
F P
0 g
s
.16112 .62145 m .15229 .67532 L .1646 .68676 L p .707 .577 .707 r
F P
0 g
s
.16967 .78673 m .17497 .76961 L .1551 .75514 L p .707 .577 .707 r
F P
0 g
s
.15628 .73695 m .1658 .70226 L .15397 .68865 L p .707 .577 .707 r
F P
0 g
s
.29004 .80387 m .28475 .821 L .30819 .81943 L p .707 .577 .707 r
F P
0 g
s
.30819 .81943 m .31349 .80231 L .29004 .80387 L p .707 .577 .707 r
F P
0 g
s
.15229 .67532 m .16112 .62145 L .1584 .61062 L p .707 .577 .707 r
F P
0 g
s
.1551 .75514 m .14981 .77227 L .16967 .78673 L p .707 .577 .707 r
F P
0 g
s
.6576 .73742 m .64808 .77212 L .62168 .75973 L p .707 .577 .707 r
F P
0 g
s
.62168 .75973 m .6312 .72504 L .6576 .73742 L p .707 .577 .707 r
F P
0 g
s
.66601 .81602 m .66072 .83315 L .64085 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .81868 m .64615 .80156 L .66601 .81602 L p .707 .577 .707 r
F P
0 g
s
.15397 .68865 m .14445 .72334 L .15628 .73695 L p .707 .577 .707 r
F P
0 g
s
.14981 .77227 m .1551 .75514 L .14345 .7409 L p .707 .577 .707 r
F P
0 g
s
.1584 .61062 m .14958 .6645 L .15229 .67532 L p .707 .577 .707 r
F P
0 g
s
.31349 .80231 m .30819 .81943 L .32435 .81347 L p .707 .577 .707 r
F P
0 g
s
.32435 .81347 m .32965 .79634 L .31349 .80231 L p .707 .577 .707 r
F P
0 g
s
.14345 .7409 m .13816 .75803 L .14981 .77227 L p .707 .577 .707 r
F P
0 g
s
.14445 .72334 m .15397 .68865 L .15156 .67643 L p .707 .577 .707 r
F P
0 g
s
.6795 .31275 m .60027 .79935 L .59644 .78409 L p .707 .577 .707 r
F P
0 g
s
.59644 .78409 m .67566 .29748 L .6795 .31275 L p .707 .577 .707 r
F P
0 g
s
.64615 .80156 m .64085 .81868 L .61471 .80541 L p .707 .577 .707 r
F P
0 g
s
.61471 .80541 m .62001 .78828 L .64615 .80156 L p .707 .577 .707 r
F P
0 g
s
.39508 .26469 m .31585 .7513 L .31968 .76657 L p .707 .577 .707 r
F P
0 g
s
.31585 .7513 m .39508 .26469 L .40517 .25178 L p .707 .577 .707 r
F P
0 g
s
.14958 .6645 m .1584 .61062 L .16555 .60147 L p .707 .577 .707 r
F P
0 g
s
.15156 .67643 m .14204 .71113 L .14445 .72334 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.13816 .75803 m .14345 .7409 L .14116 .72828 L p .707 .577 .707 r
F P
0 g
s
.32965 .79634 m .32435 .81347 L .33164 .8037 L p .707 .577 .707 r
F P
0 g
s
.33164 .8037 m .33694 .78657 L .32965 .79634 L p .707 .577 .707 r
F P
0 g
s
.14116 .72828 m .13587 .7454 L .13816 .75803 L p .707 .577 .707 r
F P
0 g
s
.16555 .60147 m .15673 .65535 L .14958 .6645 L p .707 .577 .707 r
F P
0 g
s
.14204 .71113 m .15156 .67643 L .15881 .6668 L p .707 .577 .707 r
F P
0 g
s
.15673 .65535 m .16555 .60147 L .18186 .59489 L p .707 .577 .707 r
F P
0 g
s
.67566 .29748 m .59644 .78409 L .57906 .76797 L p .707 .577 .707 r
F P
0 g
s
.57906 .76797 m .65829 .28136 L .67566 .29748 L p .707 .577 .707 r
F P
0 g
s
.15881 .6668 m .14929 .70149 L .14204 .71113 L p .707 .577 .707 r
F P
0 g
s
.32594 .73839 m .40517 .25178 L .42819 .24248 L p .707 .577 .707 r
F P
0 g
s
.40517 .25178 m .32594 .73839 L .31585 .7513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13587 .7454 m .14116 .72828 L .14846 .71851 L p .707 .577 .707 r
F P
0 g
s
.33694 .78657 m .33164 .8037 L .32935 .79107 L p .707 .577 .707 r
F P
0 g
s
.14846 .71851 m .14316 .73563 L .13587 .7454 L p .707 .577 .707 r
F P
0 g
s
.18186 .59489 m .17303 .64877 L .15673 .65535 L p .707 .577 .707 r
F P
0 g
s
.14929 .70149 m .15881 .6668 L .17501 .6607 L p .707 .577 .707 r
F P
0 g
s
.17303 .64877 m .18186 .59489 L .20572 .59152 L p .707 .577 .707 r
F P
0 g
s
.17501 .6607 m .16549 .69539 L .14929 .70149 L p .707 .577 .707 r
F P
0 g
s
.14316 .73563 m .14846 .71851 L .16462 .71255 L p .707 .577 .707 r
F P
0 g
s
.65829 .28136 m .57906 .76797 L .54984 .75257 L p .707 .577 .707 r
F P
0 g
s
.54984 .75257 m .62906 .26596 L .65829 .28136 L p .707 .577 .707 r
F P
0 g
s
.20572 .59152 m .1969 .6454 L .17303 .64877 L p .707 .577 .707 r
F P
0 g
s
.32412 .61162 m .3153 .6655 L .28825 .65614 L p .707 .577 .707 r
F P
0 g
s
.28825 .65614 m .29707 .60227 L .32412 .61162 L p .707 .577 .707 r
F P
0 g
s
.16462 .71255 m .15932 .72967 L .14316 .73563 L p .707 .577 .707 r
F P
0 g
s
.42819 .24248 m .34896 .72909 L .32594 .73839 L p .707 .577 .707 r
F P
0 g
s
.34896 .72909 m .42819 .24248 L .46189 .23771 L p .707 .577 .707 r
F P
0 g
s
.1969 .6454 m .20572 .59152 L .23482 .5917 L p .707 .577 .707 r
F P
0 g
s
.16549 .69539 m .17501 .6607 L .19858 .65873 L p .707 .577 .707 r
F P
0 g
s
.29707 .60227 m .28825 .65614 L .25747 .64928 L p .707 .577 .707 r
F P
0 g
s
.25747 .64928 m .26629 .5954 L .29707 .60227 L p .707 .577 .707 r
F P
0 g
s
.226 .64557 m .23482 .5917 L .26629 .5954 L p .707 .577 .707 r
F P
0 g
s
.23482 .5917 m .226 .64557 L .1969 .6454 L p .707 .577 .707 r
F P
0 g
s
.19858 .65873 m .18906 .69342 L .16549 .69539 L p .707 .577 .707 r
F P
0 g
s
.26629 .5954 m .25747 .64928 L .226 .64557 L p .707 .577 .707 r
F P
0 g
s
.15932 .72967 m .16462 .71255 L .18806 .71098 L p .707 .577 .707 r
F P
0 g
s
.18906 .69342 m .19858 .65873 L .2272 .66107 L p .707 .577 .707 r
F P
0 g
s
.72334 .66333 m .73216 .60946 L .70139 .60259 L p .707 .577 .707 r
F P
0 g
s
.73216 .60946 m .72334 .66333 L .75481 .66703 L p .707 .577 .707 r
F P
0 g
s
.75481 .66703 m .76363 .61316 L .73216 .60946 L p .707 .577 .707 r
F P
0 g
s
.31459 .68979 m .30507 .72448 L .27867 .7121 L p .707 .577 .707 r
F P
0 g
s
.27867 .7121 m .28819 .6774 L .31459 .68979 L p .707 .577 .707 r
F P
0 g
s
.18806 .71098 m .18277 .7281 L .15932 .72967 L p .707 .577 .707 r
F P
0 g
s
.62906 .26596 m .54984 .75257 L .51163 .73939 L p .707 .577 .707 r
F P
0 g
s
.51163 .73939 m .59086 .25278 L .62906 .26596 L p .707 .577 .707 r
F P
0 g
s
.76363 .61316 m .75481 .66703 L .78391 .66721 L p .707 .577 .707 r
F P
0 g
s
.78391 .66721 m .79273 .61333 L .76363 .61316 L p .707 .577 .707 r
F P
0 g
s
.69257 .65647 m .70139 .60259 L .67433 .59323 L p .707 .577 .707 r
F P
0 g
s
.70139 .60259 m .69257 .65647 L .72334 .66333 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .46189 .23771 L .50297 .23793 L p .707 .577 .707 r
F P
0 g
s
.38266 .72432 m .34896 .72909 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.42743 .44936 m .38266 .72432 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.50297 .23793 m .42374 .72454 L .38266 .72432 L p .707 .577 .707 r
F P
0 g
s
.40097 .6873 m .40554 .67064 L p .37961 .64617 L .707 .577 .707 r
F P
0 g
s
.40554 .67064 m .41049 .65261 L .40739 .65196 L p .707 .577 .707 r
F P
0 g
s
.40739 .65196 m .37961 .64617 L p .40554 .67064 L .707 .577 .707 r
F P
0 g
s
.46189 .23771 m .42743 .44936 L p .43814 .34103 L .707 .577 .707 r
F P
0 g
s
.2272 .66107 m .21768 .69576 L .18906 .69342 L p .707 .577 .707 r
F P
0 g
s
.21768 .69576 m .2272 .66107 L .25808 .66751 L p .707 .577 .707 r
F P
0 g
s
.28819 .6774 m .27867 .7121 L .24856 .7022 L p .707 .577 .707 r
F P
0 g
s
.24856 .7022 m .25808 .66751 L .28819 .6774 L p .707 .577 .707 r
F P
0 g
s
.18277 .7281 m .18806 .71098 L .2165 .71396 L p .707 .577 .707 r
F P
0 g
s
.25808 .66751 m .24856 .7022 L .21768 .69576 L p .707 .577 .707 r
F P
0 g
s
.79273 .61333 m .78391 .66721 L .80778 .66384 L p .707 .577 .707 r
F P
0 g
s
.80778 .66384 m .8166 .60997 L .79273 .61333 L p .707 .577 .707 r
F P
0 g
s
.66551 .64711 m .67433 .59323 L .65363 .5823 L p .707 .577 .707 r
F P
0 g
s
.67433 .59323 m .66551 .64711 L .69257 .65647 L p .707 .577 .707 r
F P
0 g
s
.30314 .74524 m .29784 .76237 L .2717 .7491 L p .707 .577 .707 r
F P
0 g
s
.2717 .7491 m .277 .73197 L .30314 .74524 L p .707 .577 .707 r
F P
0 g
s
.59086 .25278 m .51163 .73939 L .46818 .72974 L p .707 .577 .707 r
F P
0 g
s
.46818 .72974 m .54741 .24313 L .59086 .25278 L p .707 .577 .707 r
F P
0 g
s
.2165 .71396 m .2112 .73108 L .18277 .7281 L p .707 .577 .707 r
F P
0 g
s
.41049 .65261 m .40097 .6873 L .40578 .68769 L p .707 .577 .707 r
F P
0 g
s
.44943 .62454 m .44421 .59881 L .47335 .53142 L .707 .577 .707 r
F
.42374 .72454 m .43571 .65102 L p .44943 .62454 L F P
0 g
s
.43571 .65102 m .44421 .59881 L p .44943 .62454 L .707 .577 .707 r
F P
0 g
s
.54741 .24313 m .46818 .72974 L .42374 .72454 L p .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .42725 .71184 L .4054 .70955 L p .707 .577 .707 r
F P
0 g
s
.4054 .70955 m .39881 .70886 L p .4036 .71302 L .707 .577 .707 r
F P
0 g
s
.42195 .72896 m .4054 .70955 L .4036 .71302 L .707 .577 .707 r
F
.40578 .68769 m .42959 .68964 L p .41618 .66364 L F P
0 g
s
.41618 .66364 m .41049 .65261 L .40578 .68769 L .707 .577 .707 r
F
.50297 .23793 m .54741 .24313 L p .47335 .53142 L F P
0 g
s
.44421 .59881 m .50297 .23793 L p .47335 .53142 L .707 .577 .707 r
F P
0 g
s
.7131 .7285 m .72262 .6938 L .69251 .68391 L p .707 .577 .707 r
F P
0 g
s
.72262 .6938 m .7131 .7285 L .74398 .73493 L p .707 .577 .707 r
F P
0 g
s
.74398 .73493 m .7535 .70024 L .72262 .6938 L p .707 .577 .707 r
F P
0 g
s
.2112 .73108 m .2165 .71396 L .24715 .72119 L p .707 .577 .707 r
F P
0 g
s
.68299 .7186 m .69251 .68391 L .66612 .67152 L p .707 .577 .707 r
F P
0 g
s
.69251 .68391 m .68299 .7186 L .7131 .7285 L p .707 .577 .707 r
F P
0 g
s
.7535 .70024 m .74398 .73493 L .7726 .73728 L p .707 .577 .707 r
F P
0 g
s
.7726 .73728 m .78212 .70258 L .7535 .70024 L p .707 .577 .707 r
F P
0 g
s
.277 .73197 m .2717 .7491 L .24185 .73832 L p .707 .577 .707 r
F P
0 g
s
.24185 .73832 m .24715 .72119 L .277 .73197 L p .707 .577 .707 r
F P
0 g
s
.24715 .72119 m .24185 .73832 L .2112 .73108 L p .707 .577 .707 r
F P
0 g
s
.65363 .5823 m .64481 .63617 L .66551 .64711 L p .707 .577 .707 r
F P
0 g
s
.8166 .60997 m .80778 .66384 L .82408 .65726 L p .707 .577 .707 r
F P
0 g
s
.82408 .65726 m .83291 .60338 L .8166 .60997 L p .707 .577 .707 r
F P
0 g
s
.64481 .63617 m .65363 .5823 L .64133 .57086 L p .707 .577 .707 r
F P
0 g
s
.65659 .70621 m .66612 .67152 L .64602 .65785 L p .707 .577 .707 r
F P
0 g
s
.66612 .67152 m .65659 .70621 L .68299 .7186 L p .707 .577 .707 r
F P
0 g
s
.78212 .70258 m .7726 .73728 L .79617 .7353 L p .707 .577 .707 r
F P
0 g
s
.79617 .7353 m .80569 .70061 L .78212 .70258 L p .707 .577 .707 r
F P
0 g
s
.70588 .77506 m .71117 .75794 L .68132 .74716 L p .707 .577 .707 r
F P
0 g
s
.71117 .75794 m .70588 .77506 L .73652 .7823 L p .707 .577 .707 r
F P
0 g
s
.73652 .7823 m .74182 .76517 L .71117 .75794 L p .707 .577 .707 r
F P
0 g
s
.67602 .76428 m .68132 .74716 L .65518 .73388 L p .707 .577 .707 r
F P
0 g
s
.68132 .74716 m .67602 .76428 L .70588 .77506 L p .707 .577 .707 r
F P
0 g
s
.74182 .76517 m .73652 .7823 L .76496 .78527 L p .707 .577 .707 r
F P
0 g
s
.76496 .78527 m .77026 .76815 L .74182 .76517 L p .707 .577 .707 r
F P
0 g
s
.64602 .65785 m .63649 .69255 L .65659 .70621 L p .707 .577 .707 r
F P
0 g
s
.64133 .57086 m .63251 .62474 L .64481 .63617 L p .707 .577 .707 r
F P
0 g
s
.65518 .73388 m .64988 .75101 L .67602 .76428 L p .707 .577 .707 r
F P
0 g
s
.83291 .60338 m .82408 .65726 L .83123 .64811 L p .707 .577 .707 r
F P
0 g
s
.83123 .64811 m .84005 .59423 L .83291 .60338 L p .707 .577 .707 r
F P
0 g
s
.63649 .69255 m .64602 .65785 L .63418 .64425 L p .707 .577 .707 r
F P
0 g
s
.64988 .75101 m .65518 .73388 L .63532 .71942 L p .707 .577 .707 r
F P
0 g
s
.80569 .70061 m .79617 .7353 L .81237 .7292 L p .707 .577 .707 r
F P
0 g
s
.81237 .7292 m .82189 .69451 L .80569 .70061 L p .707 .577 .707 r
F P
0 g
s
.63251 .62474 m .64133 .57086 L .63862 .56003 L p .707 .577 .707 r
F P
0 g
s
.77026 .76815 m .76496 .78527 L .78841 .78371 L p .707 .577 .707 r
F P
0 g
s
.78841 .78371 m .7937 .76658 L .77026 .76815 L p .707 .577 .707 r
F P
0 g
s
.63532 .71942 m .63002 .73654 L .64988 .75101 L p .707 .577 .707 r
F P
0 g
s
.63418 .64425 m .62466 .67894 L .63649 .69255 L p .707 .577 .707 r
F P
0 g
s
.63002 .73654 m .63532 .71942 L .62367 .70518 L p .707 .577 .707 r
F P
0 g
s
.63862 .56003 m .6298 .61391 L .63251 .62474 L p .707 .577 .707 r
F P
0 g
s
.7937 .76658 m .78841 .78371 L .80457 .77774 L p .707 .577 .707 r
F P
0 g
s
.80457 .77774 m .80986 .76062 L .7937 .76658 L p .707 .577 .707 r
F P
0 g
s
.62466 .67894 m .63418 .64425 L .63178 .63203 L p .707 .577 .707 r
F P
0 g
s
.62367 .70518 m .61837 .7223 L .63002 .73654 L p .707 .577 .707 r
F P
0 g
s
.84005 .59423 m .83123 .64811 L .82852 .63729 L p .707 .577 .707 r
F P
0 g
s
.82852 .63729 m .83734 .58341 L .84005 .59423 L p .707 .577 .707 r
F P
0 g
s
.82189 .69451 m .81237 .7292 L .81962 .71957 L p .707 .577 .707 r
F P
0 g
s
.81962 .71957 m .82914 .68488 L .82189 .69451 L p .707 .577 .707 r
F P
0 g
s
.6298 .61391 m .63862 .56003 L .64576 .55088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63178 .63203 m .62225 .66672 L .62466 .67894 L p .707 .577 .707 r
F P
0 g
s
.61837 .7223 m .62367 .70518 L .62138 .69255 L p .707 .577 .707 r
F P
0 g
s
.64576 .55088 m .63694 .60476 L .6298 .61391 L p .707 .577 .707 r
F P
0 g
s
.80986 .76062 m .80457 .77774 L .81186 .76797 L p .707 .577 .707 r
F P
0 g
s
.81186 .76797 m .81716 .75085 L .80986 .76062 L p .707 .577 .707 r
F P
0 g
s
.62138 .69255 m .61608 .70968 L .61837 .7223 L p .707 .577 .707 r
F P
0 g
s
.62225 .66672 m .63178 .63203 L .63903 .6224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.82914 .68488 m .81962 .71957 L .81721 .70735 L p .707 .577 .707 r
F P
0 g
s
.81721 .70735 m .82673 .67266 L .82914 .68488 L p .707 .577 .707 r
F P
0 g
s
.83734 .58341 m .82852 .63729 L .81621 .62585 L p .707 .577 .707 r
F P
0 g
s
.81621 .62585 m .82503 .57197 L .83734 .58341 L p .707 .577 .707 r
F P
0 g
s
.63694 .60476 m .64576 .55088 L .66207 .5443 L p .707 .577 .707 r
F P
0 g
s
.38033 .62188 m .38915 .568 L .35838 .56114 L p .707 .577 .707 r
F P
0 g
s
.38915 .568 m .38033 .62188 L .4118 .62558 L p .707 .577 .707 r
F P
0 g
s
.4118 .62558 m .42062 .57171 L .38915 .568 L p .707 .577 .707 r
F P
0 g
s
.63903 .6224 m .6295 .65709 L .62225 .66672 L p .707 .577 .707 r
F P
0 g
s
.42062 .57171 m .4118 .62558 L .4409 .62576 L p .707 .577 .707 r
F P
0 g
s
.4409 .62576 m .44972 .57188 L .42062 .57171 L p .707 .577 .707 r
F P
0 g
s
.34956 .61501 m .35838 .56114 L .33132 .55178 L p .707 .577 .707 r
F P
0 g
s
.35838 .56114 m .34956 .61501 L .38033 .62188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.61608 .70968 m .62138 .69255 L .62867 .68278 L p .707 .577 .707 r
F P
0 g
s
.66207 .5443 m .65325 .59818 L .63694 .60476 L p .707 .577 .707 r
F P
0 g
s
.81716 .75085 m .81186 .76797 L .80957 .75535 L p .707 .577 .707 r
F P
0 g
s
.80957 .75535 m .81487 .73822 L .81716 .75085 L p .707 .577 .707 r
F P
0 g
s
.44972 .57188 m .4409 .62576 L .46477 .62239 L p .707 .577 .707 r
F P
0 g
s
.46477 .62239 m .47359 .56851 L .44972 .57188 L p .707 .577 .707 r
F P
0 g
s
.62867 .68278 m .62337 .69991 L .61608 .70968 L p .707 .577 .707 r
F P
0 g
s
.3225 .60566 m .33132 .55178 L .31062 .54085 L p .707 .577 .707 r
F P
0 g
s
.33132 .55178 m .3225 .60566 L .34956 .61501 L p .707 .577 .707 r
F P
0 g
s
.6295 .65709 m .63903 .6224 L .65523 .6163 L p .707 .577 .707 r
F P
0 g
s
.82503 .57197 m .81621 .62585 L .79552 .61491 L p .707 .577 .707 r
F P
0 g
s
.79552 .61491 m .80434 .56104 L .82503 .57197 L p .707 .577 .707 r
F P
0 g
s
.82673 .67266 m .81721 .70735 L .80538 .69374 L p .707 .577 .707 r
F P
0 g
s
.80538 .69374 m .8149 .65905 L .82673 .67266 L p .707 .577 .707 r
F P
0 g
s
.65325 .59818 m .66207 .5443 L .68594 .54093 L p .707 .577 .707 r
F P
0 g
s
.37009 .68086 m .37961 .64617 L .3495 .63628 L p .707 .577 .707 r
F P
0 g
s
.37961 .64617 m .37009 .68086 L .40097 .6873 L p .707 .577 .707 r
F P
0 g
s
.33998 .67097 m .3495 .63628 L .32311 .62389 L p .707 .577 .707 r
F P
0 g
s
.3495 .63628 m .33998 .67097 L .37009 .68086 L p .707 .577 .707 r
F P
0 g
s
.42959 .68964 m .43911 .65495 L .41049 .65261 L p .707 .577 .707 r
F P
0 g
s
.65523 .6163 m .64571 .65099 L .6295 .65709 L p .707 .577 .707 r
F P
0 g
s
.31062 .54085 m .3018 .59472 L .3225 .60566 L p .707 .577 .707 r
F P
0 g
s
.47359 .56851 m .46477 .62239 L .48107 .61581 L p .707 .577 .707 r
F P
0 g
s
.48107 .61581 m .4899 .56193 L .47359 .56851 L p .707 .577 .707 r
F P
0 g
s
.62337 .69991 m .62867 .68278 L .64483 .67682 L p .707 .577 .707 r
F P
0 g
s
.3018 .59472 m .31062 .54085 L .29832 .52941 L p .707 .577 .707 r
F P
0 g
s
.68594 .54093 m .67712 .59481 L .65325 .59818 L p .707 .577 .707 r
F P
0 g
s
.80434 .56104 m .79552 .61491 L .76846 .60556 L p .707 .577 .707 r
F P
0 g
s
.76846 .60556 m .77728 .55168 L .80434 .56104 L p .707 .577 .707 r
F P
0 g
s
.31358 .65858 m .32311 .62389 L .30301 .61022 L p .707 .577 .707 r
F P
0 g
s
.32311 .62389 m .31358 .65858 L .33998 .67097 L p .707 .577 .707 r
F P
0 g
s
.43911 .65495 m .42959 .68964 L .45316 .68767 L p .707 .577 .707 r
F P
0 g
s
.45316 .68767 m .46268 .65298 L .43911 .65495 L p .707 .577 .707 r
F P
0 g
s
.67712 .59481 m .68594 .54093 L .71503 .54111 L p .707 .577 .707 r
F P
0 g
s
.36287 .71875 m .36816 .70162 L .33831 .69084 L p .707 .577 .707 r
F P
0 g
s
.36816 .70162 m .36287 .71875 L .39351 .72598 L p .707 .577 .707 r
F P
0 g
s
.39351 .72598 m .39881 .70886 L .36816 .70162 L p .707 .577 .707 r
F P
0 g
s
.81487 .73822 m .80957 .75535 L .79792 .74111 L p .707 .577 .707 r
F P
0 g
s
.79792 .74111 m .80322 .72398 L .81487 .73822 L p .707 .577 .707 r
F P
0 g
s
.64571 .65099 m .65523 .6163 L .67879 .61432 L p .707 .577 .707 r
F P
0 g
s
.64483 .67682 m .63953 .69395 L .62337 .69991 L p .707 .577 .707 r
F P
0 g
s
.8149 .65905 m .80538 .69374 L .78528 .68008 L p .707 .577 .707 r
F P
0 g
s
.78528 .68008 m .7948 .64539 L .8149 .65905 L p .707 .577 .707 r
F P
0 g
s
.33301 .70797 m .33831 .69084 L .31217 .67757 L p .707 .577 .707 r
F P
0 g
s
.33831 .69084 m .33301 .70797 L .36287 .71875 L p .707 .577 .707 r
F P
0 g
s
.39881 .70886 m .39351 .72598 L .42195 .72896 L p .707 .577 .707 r
F P
0 g
s
.30301 .61022 m .29348 .64491 L .31358 .65858 L p .707 .577 .707 r
F P
0 g
s
.31217 .67757 m .30687 .6947 L .33301 .70797 L p .707 .577 .707 r
F P
0 g
s
.77728 .55168 m .76846 .60556 L .73769 .59869 L p .707 .577 .707 r
F P
0 g
s
.73769 .59869 m .74651 .54481 L .77728 .55168 L p .707 .577 .707 r
F P
0 g
s
.70621 .59499 m .71503 .54111 L .74651 .54481 L p .707 .577 .707 r
F P
0 g
s
.71503 .54111 m .70621 .59499 L .67712 .59481 L p .707 .577 .707 r
F P
0 g
s
.29832 .52941 m .2895 .58328 L .3018 .59472 L p .707 .577 .707 r
F P
0 g
s
.67879 .61432 m .66927 .64901 L .64571 .65099 L p .707 .577 .707 r
F P
0 g
s
.74651 .54481 m .73769 .59869 L .70621 .59499 L p .707 .577 .707 r
F P
0 g
s
.30687 .6947 m .31217 .67757 L .29231 .66311 L p .707 .577 .707 r
F P
0 g
s
.29348 .64491 m .30301 .61022 L .29117 .59661 L p .707 .577 .707 r
F P
0 g
s
.4899 .56193 m .48107 .61581 L .48822 .60666 L p .707 .577 .707 r
F P
0 g
s
.48822 .60666 m .49704 .55278 L .4899 .56193 L p .707 .577 .707 r
F P
0 g
s
.42725 .71184 m .42195 .72896 L .4454 .72739 L p .707 .577 .707 r
F P
0 g
s
.4454 .72739 m .45069 .71027 L .42725 .71184 L p .707 .577 .707 r
F P
0 g
s
.46268 .65298 m .45316 .68767 L .46936 .68157 L p .707 .577 .707 r
F P
0 g
s
.46936 .68157 m .47888 .64688 L .46268 .65298 L p .707 .577 .707 r
F P
0 g
s
.63953 .69395 m .64483 .67682 L .66828 .67525 L p .707 .577 .707 r
F P
0 g
s
.66927 .64901 m .67879 .61432 L .70742 .61667 L p .707 .577 .707 r
F P
0 g
s
.2895 .58328 m .29832 .52941 L .29561 .51858 L p .707 .577 .707 r
F P
0 g
s
.29231 .66311 m .28701 .68023 L .30687 .6947 L p .707 .577 .707 r
F P
0 g
s
.7948 .64539 m .78528 .68008 L .75888 .66769 L p .707 .577 .707 r
F P
0 g
s
.75888 .66769 m .76841 .633 L .7948 .64539 L p .707 .577 .707 r
F P
0 g
s
.80322 .72398 m .79792 .74111 L .77806 .72664 L p .707 .577 .707 r
F P
0 g
s
.77806 .72664 m .78335 .70952 L .80322 .72398 L p .707 .577 .707 r
F P
0 g
s
.66828 .67525 m .66298 .69238 L .63953 .69395 L p .707 .577 .707 r
F P
0 g
s
.29117 .59661 m .28165 .6313 L .29348 .64491 L p .707 .577 .707 r
F P
0 g
s
.70742 .61667 m .69789 .65136 L .66927 .64901 L p .707 .577 .707 r
F P
0 g
s
.69789 .65136 m .70742 .61667 L .73829 .6231 L p .707 .577 .707 r
F P
0 g
s
.28701 .68023 m .29231 .66311 L .28066 .64886 L p .707 .577 .707 r
F P
0 g
s
.76841 .633 m .75888 .66769 L .72877 .65779 L p .707 .577 .707 r
F P
0 g
s
.72877 .65779 m .73829 .6231 L .76841 .633 L p .707 .577 .707 r
F P
0 g
s
.29561 .51858 m .28678 .57246 L .2895 .58328 L p .707 .577 .707 r
F P
0 g
s
.45069 .71027 m .4454 .72739 L .46156 .72143 L p .707 .577 .707 r
F P
0 g
s
.46156 .72143 m .46685 .70431 L .45069 .71027 L p .707 .577 .707 r
F P
0 g
s
.73829 .6231 m .72877 .65779 L .69789 .65136 L p .707 .577 .707 r
F P
0 g
s
.66298 .69238 m .66828 .67525 L .69671 .67823 L p .707 .577 .707 r
F P
0 g
s
.28066 .64886 m .27536 .66599 L .28701 .68023 L p .707 .577 .707 r
F P
0 g
s
.28165 .6313 m .29117 .59661 L .28877 .5844 L p .707 .577 .707 r
F P
0 g
s
.78335 .70952 m .77806 .72664 L .75192 .71337 L p .707 .577 .707 r
F P
0 g
s
.75192 .71337 m .75721 .69625 L .78335 .70952 L p .707 .577 .707 r
F P
0 g
s
.47888 .64688 m .46936 .68157 L .47661 .67194 L p .707 .577 .707 r
F P
0 g
s
.47661 .67194 m .48613 .63725 L .47888 .64688 L p .707 .577 .707 r
F P
0 g
s
.49704 .55278 m .48822 .60666 L .48551 .59583 L p .707 .577 .707 r
F P
0 g
s
.48551 .59583 m .49433 .54196 L .49704 .55278 L p .707 .577 .707 r
F P
0 g
s
.69671 .67823 m .69142 .69536 L .66298 .69238 L p .707 .577 .707 r
F P
0 g
s
.28678 .57246 m .29561 .51858 L .30275 .50943 L p .707 .577 .707 r
F P
0 g
s
.28877 .5844 m .27924 .61909 L .28165 .6313 L p .707 .577 .707 r
F P
0 g
s
.69142 .69536 m .69671 .67823 L .72736 .68547 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.75721 .69625 m .75192 .71337 L .72206 .70259 L p .707 .577 .707 r
F P
0 g
s
.72206 .70259 m .72736 .68547 L .75721 .69625 L p .707 .577 .707 r
F P
0 g
s
.27536 .66599 m .28066 .64886 L .27837 .63624 L p .707 .577 .707 r
F P
0 g
s
.72736 .68547 m .72206 .70259 L .69142 .69536 L p .707 .577 .707 r
F P
0 g
s
.46685 .70431 m .46156 .72143 L .46885 .71166 L p .707 .577 .707 r
F P
0 g
s
.46885 .71166 m .47415 .69453 L .46685 .70431 L p .707 .577 .707 r
F P
0 g
s
.27837 .63624 m .27307 .65336 L .27536 .66599 L p .707 .577 .707 r
F P
0 g
s
.30275 .50943 m .29393 .56331 L .28678 .57246 L p .707 .577 .707 r
F P
0 g
s
.27924 .61909 m .28877 .5844 L .29602 .57476 L p .707 .577 .707 r
F P
0 g
s
.48613 .63725 m .47661 .67194 L .4742 .65972 L p .707 .577 .707 r
F P
0 g
s
.4742 .65972 m .48372 .62503 L .48613 .63725 L p .707 .577 .707 r
F P
0 g
s
.49433 .54196 m .48551 .59583 L .4732 .5844 L p .707 .577 .707 r
F P
0 g
s
.4732 .5844 m .48202 .53052 L .49433 .54196 L p .707 .577 .707 r
F P
0 g
s
.29393 .56331 m .30275 .50943 L .31906 .50285 L p .707 .577 .707 r
F P
0 g
s
.29602 .57476 m .28649 .60946 L .27924 .61909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27307 .65336 m .27837 .63624 L .28566 .62647 L p .707 .577 .707 r
F P
0 g
s
.47415 .69453 m .46885 .71166 L .46656 .69904 L p .707 .577 .707 r
F P
0 g
s
.46656 .69904 m .47186 .68191 L .47415 .69453 L p .707 .577 .707 r
F P
0 g
s
.28566 .62647 m .28036 .64359 L .27307 .65336 L p .707 .577 .707 r
F P
0 g
s
.31906 .50285 m .31024 .55673 L .29393 .56331 L p .707 .577 .707 r
F P
0 g
s
.28649 .60946 m .29602 .57476 L .31222 .56866 L p .707 .577 .707 r
F P
0 g
s
.48202 .53052 m .4732 .5844 L .45251 .57346 L p .707 .577 .707 r
F P
0 g
s
.45251 .57346 m .46133 .51959 L .48202 .53052 L p .707 .577 .707 r
F P
0 g
s
.48372 .62503 m .4742 .65972 L .46237 .64611 L p .707 .577 .707 r
F P
0 g
s
.46237 .64611 m .47189 .61142 L .48372 .62503 L p .707 .577 .707 r
F P
0 g
s
.31024 .55673 m .31906 .50285 L .34293 .49948 L p .707 .577 .707 r
F P
0 g
s
.31222 .56866 m .3027 .60335 L .28649 .60946 L p .707 .577 .707 r
F P
0 g
s
.28036 .64359 m .28566 .62647 L .30182 .62051 L p .707 .577 .707 r
F P
0 g
s
.47186 .68191 m .46656 .69904 L .45491 .68479 L p .707 .577 .707 r
F P
0 g
s
.45491 .68479 m .46021 .66767 L .47186 .68191 L p .707 .577 .707 r
F P
0 g
s
.34293 .49948 m .33411 .55336 L .31024 .55673 L p .707 .577 .707 r
F P
0 g
s
.46133 .51959 m .45251 .57346 L .42545 .5641 L p .707 .577 .707 r
F P
0 g
s
.42545 .5641 m .43427 .51023 L .46133 .51959 L p .707 .577 .707 r
F P
0 g
s
.30182 .62051 m .29652 .63763 L .28036 .64359 L p .707 .577 .707 r
F P
0 g
s
.33411 .55336 m .34293 .49948 L .37202 .49966 L p .707 .577 .707 r
F P
0 g
s
.3027 .60335 m .31222 .56866 L .33578 .56669 L p .707 .577 .707 r
F P
0 g
s
.47189 .61142 m .46237 .64611 L .44227 .63244 L p .707 .577 .707 r
F P
0 g
s
.44227 .63244 m .45179 .59775 L .47189 .61142 L p .707 .577 .707 r
F P
0 g
s
.43427 .51023 m .42545 .5641 L .39468 .55724 L p .707 .577 .707 r
F P
0 g
s
.39468 .55724 m .4035 .50336 L .43427 .51023 L p .707 .577 .707 r
F P
0 g
s
.3632 .55354 m .37202 .49966 L .4035 .50336 L p .707 .577 .707 r
F P
0 g
s
.37202 .49966 m .3632 .55354 L .33411 .55336 L p .707 .577 .707 r
F P
0 g
s
.33578 .56669 m .32626 .60138 L .3027 .60335 L p .707 .577 .707 r
F P
0 g
s
.4035 .50336 m .39468 .55724 L .3632 .55354 L p .707 .577 .707 r
F P
0 g
s
.29652 .63763 m .30182 .62051 L .32527 .61894 L p .707 .577 .707 r
F P
0 g
s
.32626 .60138 m .33578 .56669 L .36441 .56903 L p .707 .577 .707 r
F P
0 g
s
.46021 .66767 m .45491 .68479 L .43504 .67033 L p .707 .577 .707 r
F P
0 g
s
.43504 .67033 m .44034 .6532 L .46021 .66767 L p .707 .577 .707 r
F P
0 g
s
.45179 .59775 m .44227 .63244 L .41587 .62006 L p .707 .577 .707 r
F P
0 g
s
.41587 .62006 m .4254 .58537 L .45179 .59775 L p .707 .577 .707 r
F P
0 g
s
.32527 .61894 m .31997 .63606 L .29652 .63763 L p .707 .577 .707 r
F P
0 g
s
.36441 .56903 m .35488 .60373 L .32626 .60138 L p .707 .577 .707 r
F P
0 g
s
.35488 .60373 m .36441 .56903 L .39528 .57547 L p .707 .577 .707 r
F P
0 g
s
.4254 .58537 m .41587 .62006 L .38576 .61016 L p .707 .577 .707 r
F P
0 g
s
.38576 .61016 m .39528 .57547 L .4254 .58537 L p .707 .577 .707 r
F P
0 g
s
.31997 .63606 m .32527 .61894 L .3537 .62192 L p .707 .577 .707 r
F P
0 g
s
.39528 .57547 m .38576 .61016 L .35488 .60373 L p .707 .577 .707 r
F P
0 g
s
.44034 .6532 m .43504 .67033 L .40891 .65706 L p .707 .577 .707 r
F P
0 g
s
.40891 .65706 m .4142 .63993 L .44034 .6532 L p .707 .577 .707 r
F P
0 g
s
.3537 .62192 m .34841 .63904 L .31997 .63606 L p .707 .577 .707 r
F P
0 g
s
.34841 .63904 m .3537 .62192 L .38435 .62915 L p .707 .577 .707 r
F P
0 g
s
.4142 .63993 m .40891 .65706 L .37905 .64628 L p .707 .577 .707 r
F P
0 g
s
.37905 .64628 m .38435 .62915 L .4142 .63993 L p .707 .577 .707 r
F P
0 g
s
.38435 .62915 m .37905 .64628 L .34841 .63904 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolA002;Ool007aoo`D0
009JEP03001JEUYF00QJEP04001JEUYFFUH60025Ool007Qoo`@000MJEP03001JEUYF00QJEP03001J
EUYF00MJEPH007moo`00MGoo0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00NGoo001cOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP06FUH5001dOol0079oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEP000080075oo`00LGoo00<005YF000015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF0P00Kgoo001aOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH3001/Ool0071oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP8006Yoo`00L7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0`00J7oo001`
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP02001VOol006moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH2
001TOol006moo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0@FUH2001ROol006moo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001oogoo05moo`00Kgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF0P00H7oo001_Ool00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH01000FUH00000GWoo001_Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00Oomoo`1K
Ool006ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0<FUH00`00Oomoo`1JOol006ioo`04001JEUYF0004
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1JOol006ioo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001oogoo05Yoo`00KWoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00<007ooOol0FGoo001^Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00Oomoo`1IOol006ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0005]oo`00KGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
05]oo`00KGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0005]oo`00
KGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0Fgoo001]Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP05FUILOol006eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP03001JEUYF05aoo`00KGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000G7oo001/Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000G7oo001/Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIoo`1L
Ool006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF05eoo`00K7oo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH0GGoo001/Ool00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001MOol006]oo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEWoo05eoo`00Jgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<0
05YFFUH0GWoo001[Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001N
Ool006]oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo
00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005ioo`00JWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YFOol0GWoo001ZOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIJEP1OOol006Yoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH025YF0P0035YF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001Y
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIoo`1OOol006Uoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000H7oo001YOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo
061oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P00HWoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0
001ROol006Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00069oo`00
Igoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001SOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006=oo`00IWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
0000Hgoo001VOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001NOol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol005Uoo`D000=J
EP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Aoo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
I7oo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001TOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000D000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
15YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Io
o`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Uooa0004eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEP0000Aoo`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPH004Moo`00DWoo00<005YF0000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<004=oo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@003moo`00DWoo00<005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00
DWoo0P000eYF1@000UYF00@005YFFUIJEP<000IJEPL000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP<003Yoo`00DWoo00=JEP00FUH00`001EYF00<005YFFUH015YF10000eYF00@005YFFUIJEPL0009J
EP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Qoo`00DGoo00@005YF0000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@0009JEPH0009JEP@000MJEP03001JEUYF
00=JEP05001JEUYFFUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF0`00=Woo001AOol30002FUH00`00FUH0000A0002FUH80006FUH20004FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF008003Aoo`00DGoo00<005YFFUH00UYF0`001UYF00<005YFFUH01EYF
00<005YFFUH05@0000=JEP00FUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000bOol0055oo`03001JEUYF
0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJ
EP8000IJEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000aOol0059oo`<0009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YF0000<7oo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUH00002FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00=goo40002Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH0100035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000=oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
00IJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUH000000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP06001JEUYF001JEP00;Woo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP050003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20004FUH01000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000AJEP00FUIJEPD0009JEP04001JEUYFFUH30007Ool70006FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01`00FUIJEUYF001JEP0002ioo`00;goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF4P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF0`000UYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP00FUH40006FUH00`00FUIJEP04FUH40006Ool80002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00000020001UYF00@005YFFUIJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH010000Woo1@000goo10001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP<000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Mo
o`@0009JEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP8000AJEP@00003FUH0000000<0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP03FUH700000eYF001J
EP08FUH00`00FUIJEP02FUH>0005FUH01000FUIJEUYF0P00;goo000]Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP020002FUH0
1000FUIJEP000UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001J
EUYF00AJEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF000015YF1P000UYF00<005YFFUH00UYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YF0000009JEP03001JEUYF009JEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF4P0000=JEP00FUH0
1`0015YF0`001UYF00<005YFFUH015YF00H005YFFUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH00004
0009FUH00`00FUIJEP05FUH01000FUIJEUYF0`0015YF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0`001EYF
00<005YFFUH01UYF00<005YFFUH010001UYF2@0015YF00<005YFFUH015YF00@005YFFUIJEP8000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0002moo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF100000=JEP00FUH025YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00EJEP03001JEUYF
00AJEP80009JEP03001JEP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000]JEP8000IJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0002moo`00;7oo
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJEP04001JEP000004FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00800003FUH007oo02ioo`00:goo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1@000UYF00<0
05YFFUH00UYF1P001eYF00<005YFFUH01EYF0P001UYF00D005YFFUIJEP0000=JEP07001JEUYFFUH0
05YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000006FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP02FUH30003FUH01000
FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<0
05YFFUH00UYF0P00<7oo000[Ool00`00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH00UYF
0`0000=JEP0000001UYF00<005YFFUH01EYF00<005YFFUH015YF100025YF00<005YFFUH00P0000=J
EP00FUH01UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20004FUH01`00FUIJEUYF001JEP00031oo`00:goo0P000eYF1@00
0UYF00<005YF00000`0027oo1P000UYF0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00=JEP8000QJEP06001JEUYF001JEP002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH7
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01`00FUIJEUYF001J
EP00031oo`00:goo00=JEP00FUH00`001UYF00<005YFFUH00eYF10001goo1P0000AJEP00000000AJ
EP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP06FUH20002FUH5
0002FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000UYF2@0000=oo`00000020001UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH2000aOol002Yoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP040002Ool500001Goo001JEP00FUH00P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0025YF0`000eYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0000300000eYF001JEP05FUH30003Ool40002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000bOol002Yoo`<0009JEP03001JEP000140009J
EPL00003Ool005YF00=JEP<000AJEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0005FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P001Goo
10000UYF10001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP02FUH3
0006FUH00`00FUIJEP05FUH00`00FUIJEP0<0004FUH500000eYF001JEP020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P000eYF00<005YF00002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF100015YF0`000eYF00<005YFFUH00UYF
0P001goo2P000UYF00<005YFFUH01UYF00<005YFFUH015YF0P00=7oo000ZOol00`00FUIJEP020002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP02FUH20003
FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH0
0003FUH01000FUIJEUYF0`001UYF0P0037oo1`0025YF00<005YFFUH00eYF00<005YF0000=7oo000Z
Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP04001JEUYF0002FUH200000eYF001JEP0200000eYF001JEP030008FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH00eYF0P001EYF00<005YF00002Woo1@00
0goo0P001UYF00<005YFFUH00eYF00@005YFFUH003=oo`00:goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF0P000eYF0P00
00AJEP00FUIJEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP04001JEP00FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YF
FUH015YF0`000eYF00@005YFFUH000Uoo`D000Eoo`8000=JEP03001JEUYF00AJEP05001JEUYFFUH0
000bOol002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP000003FUHC0008Ool50007Ool200000eYF001JEP04FUH00`00FUIJEP02
FUH00`00Oomoo`0`Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<00005FUH005YFFUH00005FUH00`00FUIJEP030004FUH4
0008FUH01000FUIJEUYF0`0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF0000009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEP0000<000Eoo`<0
00Yoo`8000EJEP03001JEUYF009JEP80035oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF0`0015YF00<005YFFUH00P0000=JEP00FUH01EYF00<0
05YFFUH00eYF20001eYF00<005YFFUH00eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
15YF100047oo00<005YFFUH00UYF00L005YFFUIJEP00FUH0000aOol002Yoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP03FUH20006FUH00`00FUIJEP06FUH90003FUH01000FUIJEUYF1@000UYF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000ioo`80009JEP07001JEUYFFUH005YF0000
<Goo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30007FUH30003FUH00`00FUIJEP05FUH60004FUH70004FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04
001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000=Ool20004FUH00`00FUIoo`0a
Ool002Uoo`03001JEP00009JEQ8000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP06001JEP00001JEP001eYF00<005YF00000P001eYF00<005YFFUH01eYF0P0000=JEP0000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000eYF10000UYF00<0
05YFFUH00UYF1`001UYF00<005YFFUH01UYF0P0037oo00<005YFFUH00UYF0P00<Woo000YOol20000
15YF0000000017oo0`001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP80
00EJEP03001JEUYF009JEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000aJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000800003FUH00000009JEP05
001JEUYFFUH00007FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF0`002goo00@005YFFUIJEP80
039oo`00:Goo0`000eYF00<007ooOol017oo0P0015YF00<005YFFUH01EYF100025YF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00EJEP@0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH20002
Ool2000015YF0000000025YF00<005YFFUH01EYF10001eYF00@005YFFUIJEPd00003FUH0000003=o
o`00:Goo0P0015YF0P001goo0`0000=JEP00FUH01eYF00<005YFFUH00`0015YF00<005YFFUH01UYF
00<005YFFUH010002EYF00<005YFFUH010002UYF00<005YFFUH01eYF100035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF3P0025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<0
05YFFUH00eYF0`001UYF00<005YF00000P00<goo000XOol30003FUH00`00FUIJEP020008Ool40006
FUH00`00FUIJEP03FUH300000eYF001JEP06FUH01P00FUIJEUYF001JEP<000QJEP03001JEUYF00AJ
EPL000=JEP04001JEUYFFUH6000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF00D005YF000005YF008000MJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF00MJEP03001JEUYF00=JEP04001JEUYFFUH2000cOol002Qoo`03001JEP0000=JEP/0
00Ioo`@0009JEP03001JEUYF00IJEP8000MJEP07001JEUYFFUH005YF00000UYF0`0015YF00<005YF
FUH01eYF00<005YFFUH00UYF1`000eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00IJEP03001JEP00008000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP8000QJEP<000=JEP03001JEUYF00<003=oo`00:7oo00@005YFFUIJ
EP<000IJEP04001JEUYFFUH70003Ool70004FUH01000FUH000001EYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080009J
EP03001JEUYF00=JEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00=JEP<00004FUH0
00000006FUH01000FUIJEP000UYF00<005YFFUH00P00=7oo000YOol30002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040006Ool:0003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH40007FUH00`00FUIJEP02FUH50003FUH20003FUH00`00FUIJEP02FUH20003FUH2000dOol0
02Uoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000aoo`<000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00
0004FUH30002FUH00`00FUIJEP04FUH01000FUH005YF0P001EYF00<005YFFUH00UYF1@001EYF0P00
00=JEP00FUH01EYF00@005YFFUH003Eoo`00:Goo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH0100000=J
EP00FUH01P0015YF00@005YFFUIJEPH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUH00006FUH00`00FUIJEP02
00001UYF00000000FUH000EJEPD000MJEP8000IJEP@003Eoo`00:7oo0P000UYF4P001eYF00<005YF
FUH00UYF0`002Woo0P0000AJEP00FUH000EJEP@000EJEP03001JEUYF00EJEPP000AJEPP000YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEP0000AJEP80
00EJEP03001JEUYF009JEP8000=oo`H0009JEP<000QJEP03001JEP0000AJEP04001JEP00000fOol0
02Moo`800004FUH000000006FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP06FUH3
0009Ool01@00FUIJEP00FUH010002EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YFFUIJEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP8000IJEP03
001JEUYF009JEP03001JEUYF009JEP8000Uoo`P000AJEP04001JEUYFFUH20002FUH01000FUIJEP00
=Woo000WOol30002Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40008FUH01000
FUH0000027oo0UYF0P000eYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YF
FUH01EYF10000UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF
0P001UYF0`000UYF00L005YFFUIJEP00FUH0000AOol<0004FUH00`00Oomoo`0cOol002Ioo`<000Ao
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01000FUIJEUYF0`0017oo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF
10002UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF000015YF00<005YF000015YF00@005YF
FUIJEP<000=JEP03001JEP0001aoo`03001JEUYF009JEP03001oogoo03=oo`009Woo00@005YF0000
00Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF0P00
0Woo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00@0
05YFFUIJEP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH20002FUH2000NOol01@00FUIJEUYF0000=Goo000VOol01@00FUH005YF
00001Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH01eYF1P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF0P0025YF10007goo00D0
05YF001JEP0003Aoo`009Woo00<005YFFUH00UYF00<007ooOol017oo0P001UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001UYF00<005YFFUH00P0000=JEP00FUH03EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH01eYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0
<goo000WOol00`00FUIJEP02FUH00`00Oomoo`05Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP020004FUH01@00FUIJEUYF000045YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF0`0025YF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000=7oo000WOol00`00FUIJEP02FUH20008
Ool200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP07FUH0
1000FUH000000eYF00<005YFFUH01UYF0`006Woo0P00=Goo000XOol01000FUIJEP000UYF0P0027oo
0`0025YF00<005YFFUH01EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000Woo0`001eYF00@005YFFUIJEP800003FUH005YF00QJ
EP03001JEP0000<001Aoo`@003Eoo`00:7oo00@005YFFUH000AJEP03001oogoo00Qoo`<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP03001JEP0000Eoo`8000AJEP03001JEUYF00AJEP<000MJEP03001JEUYF00AJEPH000Qo
o`H0009JEP03001oogoo03Aoo`00:Goo0P001UYF00<007ooOol02Woo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00@005YFFUH0009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP8000EJEP8000Qoo`<00003FUH0
05YF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJ
EP8003Ioo`00:Woo00<005YFFUH015YF0`003Goo0`0015YF100025YF00@005YFFUIJEP<00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEP0000=JEP03001JEP0000]oo`8000EJEP03001JEUYF009JEP@00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000gOol002]oo`8000AJEP03001J
EUYF008000ioo`P000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00800004
FUH005YF000=Ool00`00FUIJEP02FUH01`00FUIJEUYF001JEP00009oo`@000IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYFFUH2000gOol002eoo`04001JEUYF0005FUH2000?Ool80004FUH0
1000FUIJEUYF1@000UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00Ool03Goo0P000UYF
00L005YFFUIJEP00FUH00006Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000hOol002ioo`<000MJEP<000aoo`D000=oo`P000Aoo`03001JEUYF00<000QJEP03001JEUYF00MJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP800003FUH007oo00moo`8000AJEP03001JEWoo00Yoo`H000AJEP04001JEUYFFUH6000jOol0031o
o`03001JEUYF00IJEP04001JEP00000;Ool3000AOol200000eYF001oo`02000@FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF0000
0002000>Ool00`00FUIJEP02FUH2000AOol80010Ool0035oo`8000EJEP03001JEUYF009JEP<001eo
o`03001JEP0000=oo`8000iJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000AJEP<000aoo`04001JEUYFFUH2001IOol003=oo`8000=JEP03
001JEUYF00EJEP@001Uoo`03001JEP0000Eoo`8000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEP0000d00003
FUH0000005Yoo`00=Goo0`002EYF00<005YFFUH010005Goo0P0027oo0`002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YF00000P00FWoo000gOol20008FUH00`00FUIJ
EP04FUH6000=Ool4000;Ool2000DFUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF0P001EYF00@005YFFUIJEP8005Yoo`00
>Goo0`0015YF00<005YFFUH01eYF00@005YFFUIJEPd0009JEP8000eoo`<0015JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP07
FUH20004FUH00`00FUIJEP03001JOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF0080015oo`8000mJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP<000MJEP03001JEP0000=JEP03001JEUYF008005]oo`00?goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8001=oo`@001MJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@0009JEP8000AJEP04001JEUYFFUH3
0003FUH2001KOol0049oo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008001Qo
o`@0019JEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH50004FUH300000eYF
001JEP04FUH01@00FUIJEUYF0000G7oo0016Ool60004FUH00`00FUIJEP04FUH01000FUH000007Woo
10003UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000AJEPD000MJEP8000IJEP04001J
EP00001LOol004aoo`d002Aoo`P000IJEP03001JEUYF00UJEP03001JEUYF00=JEPT000=JEPD000MJ
EP03001JEP0000AJEP04001JEP00001MOol008EooaP000Uoo`L000MJEP04001JEUYFFUH20002FUH0
0`00FUH0001NOol008aoo`03001JEUYF00AJEP<001Aooa8000=JEP03001oogoo05]oo`00SGoo00<0
05YFFUH00UYF00@005YFFUIJEP8002=oo`03001JEUYF009JEP03001oogoo05Yoo`00SWoo0P000UYF
00<005YFFUH00eYF0P008Woo00D005YFFUIJEP0005aoo`00T7oo0P0025YF0P008Goo00D005YF001J
EP0005]oo`00TGoo00<005YFFUH01UYF00<005YF00000P007goo0P0000=JEP00Ool0FWoo002BOol2
0006FUH00`00FUIJEP02FUH3000MOol00`00FUH0001KOol009Aoo`8000=JEP03001JEUYF00IJEP<0
01Yoo`8005aoo`00UWoo0P0000=JEP00FUH025YF00<005YF00000`005Goo0`00G7oo002HOol30007
FUH00`00FUIJEP04FUH6000=Ool200000eYF001oo`1LOol009]oo`8000EJEP03001JEUYF00IJEP04
001JEUYFFUH=0002FUH2001MOol009eoo`<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH0001NOol00:1oo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008005ioo`00Y7oo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005mo
o`00Z7oo1P0015YF00<005YFFUH015YF00@005YF0000061oo`00[Woo3@00HWoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59004 .75323 m .59551 .69853 L .56449 .69354 L p .707 .577 .707 r
F P
0 g
s
.59551 .69853 m .59004 .75323 L .62173 .75524 L p .707 .577 .707 r
F P
0 g
s
.62173 .75524 m .6272 .70054 L .59551 .69853 L p .707 .577 .707 r
F P
0 g
s
.6272 .70054 m .62173 .75524 L .65101 .75407 L p .707 .577 .707 r
F P
0 g
s
.65101 .75407 m .65647 .69937 L .6272 .70054 L p .707 .577 .707 r
F P
0 g
s
.55902 .74825 m .56449 .69354 L .53718 .68606 L p .707 .577 .707 r
F P
0 g
s
.56449 .69354 m .55902 .74825 L .59004 .75323 L p .707 .577 .707 r
F P
0 g
s
.65647 .69937 m .65101 .75407 L .67499 .74984 L p .707 .577 .707 r
F P
0 g
s
.67499 .74984 m .68046 .69514 L .65647 .69937 L p .707 .577 .707 r
F P
0 g
s
.53171 .74077 m .53718 .68606 L .51626 .67682 L p .707 .577 .707 r
F P
0 g
s
.53718 .68606 m .53171 .74077 L .55902 .74825 L p .707 .577 .707 r
F P
0 g
s
.58385 .81668 m .58978 .78077 L .55902 .77386 L p .707 .577 .707 r
F P
0 g
s
.58978 .78077 m .58385 .81668 L .61532 .82041 L p .707 .577 .707 r
F P
0 g
s
.61532 .82041 m .62125 .78451 L .58978 .78077 L p .707 .577 .707 r
F P
0 g
s
.62125 .78451 m .61532 .82041 L .64441 .82062 L p .707 .577 .707 r
F P
0 g
s
.64441 .82062 m .65034 .78472 L .62125 .78451 L p .707 .577 .707 r
F P
0 g
s
.55309 .80977 m .55902 .77386 L .53196 .76447 L p .707 .577 .707 r
F P
0 g
s
.55902 .77386 m .55309 .80977 L .58385 .81668 L p .707 .577 .707 r
F P
0 g
s
.68046 .69514 m .67499 .74984 L .69134 .74296 L p .707 .577 .707 r
F P
0 g
s
.69134 .74296 m .6968 .68826 L .68046 .69514 L p .707 .577 .707 r
F P
0 g
s
.51626 .67682 m .5108 .73153 L .53171 .74077 L p .707 .577 .707 r
F P
0 g
s
.65034 .78472 m .64441 .82062 L .66828 .81727 L p .707 .577 .707 r
F P
0 g
s
.66828 .81727 m .67421 .78137 L .65034 .78472 L p .707 .577 .707 r
F P
0 g
s
.53196 .76447 m .52603 .80037 L .55309 .80977 L p .707 .577 .707 r
F P
0 g
s
.5108 .73153 m .51626 .67682 L .50378 .66673 L p .707 .577 .707 r
F P
0 g
s
.52603 .80037 m .53196 .76447 L .51128 .7535 L p .707 .577 .707 r
F P
0 g
s
.57945 .8614 m .58276 .84354 L .55209 .83607 L p .707 .577 .707 r
F P
0 g
s
.58276 .84354 m .57945 .8614 L .61083 .86565 L p .707 .577 .707 r
F P
0 g
s
.61083 .86565 m .61414 .84779 L .58276 .84354 L p .707 .577 .707 r
F P
0 g
s
.61414 .84779 m .61083 .86565 L .63985 .86626 L p .707 .577 .707 r
F P
0 g
s
.63985 .86626 m .64316 .84841 L .61414 .84779 L p .707 .577 .707 r
F P
0 g
s
.54879 .85392 m .55209 .83607 L .52514 .8261 L p .707 .577 .707 r
F P
0 g
s
.55209 .83607 m .54879 .85392 L .57945 .8614 L p .707 .577 .707 r
F P
0 g
s
.52514 .8261 m .52184 .84396 L .54879 .85392 L p .707 .577 .707 r
F P
0 g
s
.51128 .7535 m .50535 .7894 L .52603 .80037 L p .707 .577 .707 r
F P
0 g
s
.50378 .66673 m .49831 .72143 L .5108 .73153 L p .707 .577 .707 r
F P
0 g
s
.64316 .84841 m .63985 .86626 L .66367 .86317 L p .707 .577 .707 r
F P
0 g
s
.66367 .86317 m .66698 .84532 L .64316 .84841 L p .707 .577 .707 r
F P
0 g
s
.6968 .68826 m .69134 .74296 L .69844 .73411 L p .707 .577 .707 r
F P
0 g
s
.69844 .73411 m .70391 .67941 L .6968 .68826 L p .707 .577 .707 r
F P
0 g
s
.67421 .78137 m .66828 .81727 L .68458 .8107 L p .707 .577 .707 r
F P
0 g
s
.68458 .8107 m .69051 .77479 L .67421 .78137 L p .707 .577 .707 r
F P
0 g
s
.52184 .84396 m .52514 .8261 L .50454 .81462 L p .707 .577 .707 r
F P
0 g
s
.50535 .7894 m .51128 .7535 L .49897 .74203 L p .707 .577 .707 r
F P
0 g
s
.49831 .72143 m .50378 .66673 L .50095 .65676 L p .707 .577 .707 r
F P
0 g
s
.50454 .81462 m .50124 .83247 L .52184 .84396 L p .707 .577 .707 r
F P
0 g
s
.49897 .74203 m .49304 .77793 L .50535 .7894 L p .707 .577 .707 r
F P
0 g
s
.66698 .84532 m .66367 .86317 L .67996 .85669 L p .707 .577 .707 r
F P
0 g
s
.67996 .85669 m .68326 .83883 L .66698 .84532 L p .707 .577 .707 r
F P
0 g
s
.50124 .83247 m .50454 .81462 L .49231 .80275 L p .707 .577 .707 r
F P
0 g
s
.50095 .65676 m .49549 .71147 L .49831 .72143 L p .707 .577 .707 r
F P
0 g
s
.69051 .77479 m .68458 .8107 L .69173 .80154 L p .707 .577 .707 r
F P
0 g
s
.69173 .80154 m .69766 .76563 L .69051 .77479 L p .707 .577 .707 r
F P
0 g
s
.49231 .80275 m .48901 .8206 L .50124 .83247 L p .707 .577 .707 r
F P
0 g
s
.46423 .82209 m .51334 .32806 L .46954 .32104 L p .707 .577 .707 r
F P
0 g
s
.49304 .77793 m .49897 .74203 L .49626 .73119 L p .707 .577 .707 r
F P
0 g
s
.49549 .71147 m .50095 .65676 L .50806 .64791 L p .707 .577 .707 r
F P
0 g
s
.49626 .73119 m .49034 .76709 L .49304 .77793 L p .707 .577 .707 r
F P
0 g
s
.48901 .8206 m .49231 .80275 L .48965 .79164 L p .707 .577 .707 r
F P
0 g
s
.50806 .64791 m .50259 .70262 L .49549 .71147 L p .707 .577 .707 r
F P
0 g
s
.48965 .79164 m .48634 .80949 L .48901 .8206 L p .707 .577 .707 r
F P
0 g
s
.49034 .76709 m .49626 .73119 L .50341 .72203 L p .707 .577 .707 r
F P
0 g
s
.50259 .70262 m .50806 .64791 L .52441 .64103 L p .707 .577 .707 r
F P
0 g
s
.50341 .72203 m .49748 .75793 L .49034 .76709 L p .707 .577 .707 r
F P
0 g
s
.48634 .80949 m .48965 .79164 L .49681 .7824 L p .707 .577 .707 r
F P
0 g
s
.52441 .64103 m .51894 .69574 L .50259 .70262 L p .707 .577 .707 r
F P
0 g
s
.49681 .7824 m .49351 .80025 L .48634 .80949 L p .707 .577 .707 r
F P
0 g
s
.49748 .75793 m .50341 .72203 L .51972 .71545 L p .707 .577 .707 r
F P
0 g
s
.51972 .71545 m .51379 .75136 L .49748 .75793 L p .707 .577 .707 r
F P
0 g
s
.49351 .80025 m .49681 .7824 L .5131 .77591 L p .707 .577 .707 r
F P
0 g
s
.5131 .77591 m .50979 .79376 L .49351 .80025 L p .707 .577 .707 r
F P
0 g
s
.51334 .32806 m .46423 .82209 L .50899 .8249 L p .707 .577 .707 r
F P
0 g
s
.51894 .69574 m .52441 .64103 L .54839 .6368 L p .707 .577 .707 r
F P
0 g
s
.54839 .6368 m .54292 .69151 L .51894 .69574 L p .707 .577 .707 r
F P
0 g
s
.51379 .75136 m .51972 .71545 L .54358 .7121 L p .707 .577 .707 r
F P
0 g
s
.54358 .7121 m .53765 .74801 L .51379 .75136 L p .707 .577 .707 r
F P
0 g
s
.50979 .79376 m .5131 .77591 L .53692 .77282 L p .707 .577 .707 r
F P
0 g
s
.53692 .77282 m .53361 .79068 L .50979 .79376 L p .707 .577 .707 r
F P
0 g
s
.50899 .8249 m .55809 .33088 L .51334 .32806 L p .707 .577 .707 r
F P
0 g
s
.70391 .67941 m .69844 .73411 L .69562 .72415 L p .707 .577 .707 r
F P
0 g
s
.69562 .72415 m .70108 .66944 L .70391 .67941 L p .707 .577 .707 r
F P
0 g
s
.54292 .69151 m .54839 .6368 L .57766 .63563 L p .707 .577 .707 r
F P
0 g
s
.57766 .63563 m .57219 .69034 L .54292 .69151 L p .707 .577 .707 r
F P
0 g
s
.53765 .74801 m .54358 .7121 L .57267 .71231 L p .707 .577 .707 r
F P
0 g
s
.57267 .71231 m .56674 .74821 L .53765 .74801 L p .707 .577 .707 r
F P
0 g
s
.53361 .79068 m .53692 .77282 L .56594 .77343 L p .707 .577 .707 r
F P
0 g
s
.56594 .77343 m .56263 .79129 L .53361 .79068 L p .707 .577 .707 r
F P
0 g
s
.55809 .33088 m .50899 .8249 L .55031 .82324 L p .707 .577 .707 r
F P
0 g
s
.55031 .82324 m .59942 .32921 L .55809 .33088 L p .707 .577 .707 r
F P
0 g
s
.42044 .81507 m .46954 .32104 L .43099 .31051 L p .707 .577 .707 r
F P
0 g
s
.46954 .32104 m .42044 .81507 L .46423 .82209 L p .707 .577 .707 r
F P
0 g
s
.68326 .83883 m .67996 .85669 L .68712 .84744 L p .707 .577 .707 r
F P
0 g
s
.68712 .84744 m .69043 .82959 L .68326 .83883 L p .707 .577 .707 r
F P
0 g
s
.57219 .69034 m .57766 .63563 L .60936 .63764 L p .707 .577 .707 r
F P
0 g
s
.60936 .63764 m .60389 .69235 L .57219 .69034 L p .707 .577 .707 r
F P
0 g
s
.56674 .74821 m .57267 .71231 L .60414 .71605 L p .707 .577 .707 r
F P
0 g
s
.60414 .71605 m .59821 .75195 L .56674 .74821 L p .707 .577 .707 r
F P
0 g
s
.56263 .79129 m .56594 .77343 L .59732 .77769 L p .707 .577 .707 r
F P
0 g
s
.59732 .77769 m .59401 .79554 L .56263 .79129 L p .707 .577 .707 r
F P
0 g
s
.59942 .32921 m .55031 .82324 L .58417 .81725 L p .707 .577 .707 r
F P
0 g
s
.58417 .81725 m .63327 .32323 L .59942 .32921 L p .707 .577 .707 r
F P
0 g
s
.69766 .76563 m .69173 .80154 L .68902 .7907 L p .707 .577 .707 r
F P
0 g
s
.68902 .7907 m .69495 .75479 L .69766 .76563 L p .707 .577 .707 r
F P
0 g
s
.38189 .80453 m .43099 .31051 L .40146 .29748 L p .707 .577 .707 r
F P
0 g
s
.43099 .31051 m .38189 .80453 L .42044 .81507 L p .707 .577 .707 r
F P
0 g
s
.70108 .66944 m .69562 .72415 L .68313 .71406 L p .707 .577 .707 r
F P
0 g
s
.68313 .71406 m .6886 .65935 L .70108 .66944 L p .707 .577 .707 r
F P
0 g
s
.24703 .71355 m .2525 .65885 L .22148 .65386 L p .707 .577 .707 r
F P
0 g
s
.2525 .65885 m .24703 .71355 L .27873 .71556 L p .707 .577 .707 r
F P
0 g
s
.27873 .71556 m .28419 .66086 L .2525 .65885 L p .707 .577 .707 r
F P
0 g
s
.28419 .66086 m .27873 .71556 L .308 .71439 L p .707 .577 .707 r
F P
0 g
s
.308 .71439 m .31347 .65969 L .28419 .66086 L p .707 .577 .707 r
F P
0 g
s
.21601 .70857 m .22148 .65386 L .19417 .64638 L p .707 .577 .707 r
F P
0 g
s
.22148 .65386 m .21601 .70857 L .24703 .71355 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69043 .82959 m .68712 .84744 L .68446 .83634 L p .707 .577 .707 r
F P
0 g
s
.68446 .83634 m .68776 .81848 L .69043 .82959 L p .707 .577 .707 r
F P
0 g
s
.64038 .64263 m .63491 .69734 L .60389 .69235 L p .707 .577 .707 r
F P
0 g
s
.60389 .69235 m .60936 .63764 L .64038 .64263 L p .707 .577 .707 r
F P
0 g
s
.63491 .72296 m .62898 .75886 L .59821 .75195 L p .707 .577 .707 r
F P
0 g
s
.59821 .75195 m .60414 .71605 L .63491 .72296 L p .707 .577 .707 r
F P
0 g
s
.62798 .78516 m .62468 .80301 L .59401 .79554 L p .707 .577 .707 r
F P
0 g
s
.59401 .79554 m .59732 .77769 L .62798 .78516 L p .707 .577 .707 r
F P
0 g
s
.63327 .32323 m .58417 .81725 L .60725 .80754 L p .707 .577 .707 r
F P
0 g
s
.60725 .80754 m .65635 .31351 L .63327 .32323 L p .707 .577 .707 r
F P
0 g
s
.31347 .65969 m .308 .71439 L .33198 .71016 L p .707 .577 .707 r
F P
0 g
s
.33198 .71016 m .33745 .65546 L .31347 .65969 L p .707 .577 .707 r
F P
0 g
s
.69495 .75479 m .68902 .7907 L .67672 .77923 L p .707 .577 .707 r
F P
0 g
s
.67672 .77923 m .68265 .74332 L .69495 .75479 L p .707 .577 .707 r
F P
0 g
s
.6886 .65935 m .68313 .71406 L .66222 .70482 L p .707 .577 .707 r
F P
0 g
s
.66222 .70482 m .66768 .65011 L .6886 .65935 L p .707 .577 .707 r
F P
0 g
s
.1887 .70109 m .19417 .64638 L .17325 .63714 L p .707 .577 .707 r
F P
0 g
s
.19417 .64638 m .1887 .70109 L .21601 .70857 L p .707 .577 .707 r
F P
0 g
s
.35236 .79151 m .40146 .29748 L .38383 .28325 L p .707 .577 .707 r
F P
0 g
s
.40146 .29748 m .35236 .79151 L .38189 .80453 L p .707 .577 .707 r
F P
0 g
s
.24084 .77317 m .24677 .73727 L .21601 .73036 L p .707 .577 .707 r
F P
0 g
s
.24677 .73727 m .24084 .77317 L .27231 .77691 L p .707 .577 .707 r
F P
0 g
s
.27231 .77691 m .27824 .74101 L .24677 .73727 L p .707 .577 .707 r
F P
0 g
s
.27824 .74101 m .27231 .77691 L .3014 .77712 L p .707 .577 .707 r
F P
0 g
s
.3014 .77712 m .30733 .74121 L .27824 .74101 L p .707 .577 .707 r
F P
0 g
s
.21008 .76627 m .21601 .73036 L .18896 .72097 L p .707 .577 .707 r
F P
0 g
s
.21601 .73036 m .21008 .76627 L .24084 .77317 L p .707 .577 .707 r
F P
0 g
s
.33745 .65546 m .33198 .71016 L .34833 .70328 L p .707 .577 .707 r
F P
0 g
s
.34833 .70328 m .35379 .64858 L .33745 .65546 L p .707 .577 .707 r
F P
0 g
s
.17325 .63714 m .16779 .69185 L .1887 .70109 L p .707 .577 .707 r
F P
0 g
s
.68776 .81848 m .68446 .83634 L .67223 .82446 L p .707 .577 .707 r
F P
0 g
s
.67223 .82446 m .67553 .80661 L .68776 .81848 L p .707 .577 .707 r
F P
0 g
s
.30733 .74121 m .3014 .77712 L .32527 .77377 L p .707 .577 .707 r
F P
0 g
s
.32527 .77377 m .3312 .73787 L .30733 .74121 L p .707 .577 .707 r
F P
0 g
s
.18896 .72097 m .18303 .75687 L .21008 .76627 L p .707 .577 .707 r
F P
0 g
s
.66768 .65011 m .66222 .70482 L .63491 .69734 L p .707 .577 .707 r
F P
0 g
s
.63491 .69734 m .64038 .64263 L .66768 .65011 L p .707 .577 .707 r
F P
0 g
s
.16779 .69185 m .17325 .63714 L .16077 .62705 L p .707 .577 .707 r
F P
0 g
s
.23644 .81253 m .23975 .79468 L .20908 .7872 L p .707 .577 .707 r
F P
0 g
s
.23975 .79468 m .23644 .81253 L .26782 .81678 L p .707 .577 .707 r
F P
0 g
s
.26782 .81678 m .27113 .79893 L .23975 .79468 L p .707 .577 .707 r
F P
0 g
s
.18303 .75687 m .18896 .72097 L .16827 .71 L p .707 .577 .707 r
F P
0 g
s
.68265 .74332 m .67672 .77923 L .65603 .76826 L p .707 .577 .707 r
F P
0 g
s
.65603 .76826 m .66196 .73235 L .68265 .74332 L p .707 .577 .707 r
F P
0 g
s
.27113 .79893 m .26782 .81678 L .29684 .81739 L p .707 .577 .707 r
F P
0 g
s
.29684 .81739 m .30015 .79954 L .27113 .79893 L p .707 .577 .707 r
F P
0 g
s
.20578 .80506 m .20908 .7872 L .18213 .77724 L p .707 .577 .707 r
F P
0 g
s
.20908 .7872 m .20578 .80506 L .23644 .81253 L p .707 .577 .707 r
F P
0 g
s
.65635 .31351 m .60725 .80754 L .61728 .79504 L p .707 .577 .707 r
F P
0 g
s
.61728 .79504 m .66638 .30102 L .65635 .31351 L p .707 .577 .707 r
F P
0 g
s
.18213 .77724 m .17883 .79509 L .20578 .80506 L p .707 .577 .707 r
F P
0 g
s
.16827 .71 m .16234 .7459 L .18303 .75687 L p .707 .577 .707 r
F P
0 g
s
.16077 .62705 m .1553 .68175 L .16779 .69185 L p .707 .577 .707 r
F P
0 g
s
.30015 .79954 m .29684 .81739 L .32066 .81431 L p .707 .577 .707 r
F P
0 g
s
.32066 .81431 m .32397 .79645 L .30015 .79954 L p .707 .577 .707 r
F P
0 g
s
.3312 .73787 m .32527 .77377 L .34157 .7672 L p .707 .577 .707 r
F P
0 g
s
.34157 .7672 m .3475 .73129 L .3312 .73787 L p .707 .577 .707 r
F P
0 g
s
.35379 .64858 m .34833 .70328 L .35543 .69443 L p .707 .577 .707 r
F P
0 g
s
.35543 .69443 m .3609 .63973 L .35379 .64858 L p .707 .577 .707 r
F P
0 g
s
.35807 .62976 m .35261 .68447 L .34012 .67437 L p .707 .577 .707 r
F P
0 g
s
.34012 .67437 m .34559 .61967 L .35807 .62976 L p .707 .577 .707 r
F P
0 g
s
.3475 .73129 m .34157 .7672 L .34872 .75804 L p .707 .577 .707 r
F P
0 g
s
.34872 .75804 m .35465 .72213 L .3475 .73129 L p .707 .577 .707 r
F P
0 g
s
.35194 .71129 m .34601 .74719 L .34253 .74395 L p .707 .577 .707 r
F P
0 g
s
.34253 .74395 m .33371 .73573 L p .34437 .72144 L .707 .577 .707 r
F P
0 g
s
.34437 .72144 m .35194 .71129 L .34253 .74395 L .707 .577 .707 r
F
.33371 .73573 m .33964 .69982 L .35194 .71129 L p F P
0 g
s
.34476 .76962 m .34145 .78747 L .33864 .78474 L p .707 .577 .707 r
F P
0 g
s
.33864 .78474 m .32922 .77559 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.33964 .77158 m .34476 .76962 L .33864 .78474 L .707 .577 .707 r
F
.3674 .40935 m .36304 .49242 L .37984 .2692 L F
.32922 .77559 m .33253 .75774 L .34014 .76513 L p F P
0 g
s
.34014 .76513 m .34476 .76962 L p .33964 .77158 L .707 .577 .707 r
F P
0 g
s
.32922 .77559 m .34014 .76513 L .33964 .77158 L .707 .577 .707 r
F
.34559 .61967 m .34012 .67437 L .31921 .66514 L p F P
0 g
s
.33964 .69982 m .33371 .73573 L .31302 .72476 L p .707 .577 .707 r
F P
0 g
s
.31302 .72476 m .31895 .68885 L .33964 .69982 L p .707 .577 .707 r
F P
0 g
s
.33253 .75774 m .32922 .77559 L .30862 .76411 L p .707 .577 .707 r
F P
0 g
s
.30862 .76411 m .31193 .74626 L .33253 .75774 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .33473 .77728 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.37984 .2692 m .3724 .34407 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.31921 .66514 m .32467 .61043 L .34559 .61967 L p .707 .577 .707 r
F P
0 g
s
.3724 .34407 m .33074 .76322 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.33473 .77728 m .35427 .5807 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.35427 .5807 m .36304 .49242 L p .3674 .40935 L .707 .577 .707 r
F P
0 g
s
.36304 .49242 m .38383 .28325 L .38094 .27305 L p .707 .577 .707 r
F P
0 g
s
.38094 .27305 m .37984 .2692 L p .36304 .49242 L .707 .577 .707 r
F P
0 g
s
.3609 .63973 m .35543 .69443 L .35261 .68447 L p .707 .577 .707 r
F P
0 g
s
.35261 .68447 m .35807 .62976 L .3609 .63973 L p .707 .577 .707 r
F P
0 g
s
.34411 .79857 m .34742 .78072 L .34026 .78997 L p .707 .577 .707 r
F P
0 g
s
.35465 .72213 m .34872 .75804 L .34601 .74719 L p .707 .577 .707 r
F P
0 g
s
.34601 .74719 m .35194 .71129 L .35465 .72213 L p .707 .577 .707 r
F P
0 g
s
.34742 .78072 m .34411 .79857 L .34145 .78747 L p .707 .577 .707 r
F P
0 g
s
.34145 .78747 m .34476 .76962 L .34742 .78072 L p .707 .577 .707 r
F P
0 g
s
.38383 .28325 m .33473 .77728 L .35236 .79151 L p .707 .577 .707 r
F P
0 g
s
.17883 .79509 m .18213 .77724 L .16153 .76576 L p .707 .577 .707 r
F P
0 g
s
.16234 .7459 m .16827 .71 L .15597 .69853 L p .707 .577 .707 r
F P
0 g
s
.67553 .80661 m .67223 .82446 L .65163 .81298 L p .707 .577 .707 r
F P
0 g
s
.65163 .81298 m .65494 .79513 L .67553 .80661 L p .707 .577 .707 r
F P
0 g
s
.66196 .73235 m .65603 .76826 L .62898 .75886 L p .707 .577 .707 r
F P
0 g
s
.62898 .75886 m .63491 .72296 L .66196 .73235 L p .707 .577 .707 r
F P
0 g
s
.16153 .76576 m .15823 .78361 L .17883 .79509 L p .707 .577 .707 r
F P
0 g
s
.1553 .68175 m .16077 .62705 L .15795 .61708 L p .707 .577 .707 r
F P
0 g
s
.15597 .69853 m .15004 .73443 L .16234 .7459 L p .707 .577 .707 r
F P
0 g
s
.32397 .79645 m .32066 .81431 L .33695 .80782 L p .707 .577 .707 r
F P
0 g
s
.33695 .80782 m .34026 .78997 L .32397 .79645 L p .707 .577 .707 r
F P
0 g
s
.15823 .78361 m .16153 .76576 L .1493 .75388 L p .707 .577 .707 r
F P
0 g
s
.65494 .79513 m .65163 .81298 L .62468 .80301 L p .707 .577 .707 r
F P
0 g
s
.62468 .80301 m .62798 .78516 L .65494 .79513 L p .707 .577 .707 r
F P
0 g
s
.15795 .61708 m .15248 .67179 L .1553 .68175 L p .707 .577 .707 r
F P
0 g
s
.1493 .75388 m .146 .77173 L .15823 .78361 L p .707 .577 .707 r
F P
0 g
s
.15004 .73443 m .15597 .69853 L .15326 .68768 L p .707 .577 .707 r
F P
0 g
s
.66638 .30102 m .61728 .79504 L .61329 .78099 L p .707 .577 .707 r
F P
0 g
s
.61329 .78099 m .66239 .28696 L .66638 .30102 L p .707 .577 .707 r
F P
0 g
s
.15248 .67179 m .15795 .61708 L .16505 .60823 L p .707 .577 .707 r
F P
0 g
s
.33074 .76322 m .37984 .2692 L .38988 .2567 L p .707 .577 .707 r
F P
0 g
s
.15326 .68768 m .14733 .72359 L .15004 .73443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34026 .78997 m .33695 .80782 L .34411 .79857 L p .707 .577 .707 r
F P
0 g
s
.146 .77173 m .1493 .75388 L .14664 .74278 L p .707 .577 .707 r
F P
0 g
s
.14664 .74278 m .14333 .76063 L .146 .77173 L p .707 .577 .707 r
F P
0 g
s
.16505 .60823 m .15958 .66294 L .15248 .67179 L p .707 .577 .707 r
F P
0 g
s
.14733 .72359 m .15326 .68768 L .1604 .67853 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15958 .66294 m .16505 .60823 L .1814 .60135 L p .707 .577 .707 r
F P
0 g
s
.1604 .67853 m .15447 .71443 L .14733 .72359 L p .707 .577 .707 r
F P
0 g
s
.66239 .28696 m .61329 .78099 L .59567 .76676 L p .707 .577 .707 r
F P
0 g
s
.59567 .76676 m .64477 .27273 L .66239 .28696 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14333 .76063 m .14664 .74278 L .1538 .73353 L p .707 .577 .707 r
F P
0 g
s
.34077 .75073 m .38988 .2567 L .41295 .24699 L p .707 .577 .707 r
F P
0 g
s
.38988 .2567 m .34077 .75073 L .33074 .76322 L p .707 .577 .707 r
F P
0 g
s
.1538 .73353 m .1505 .75138 L .14333 .76063 L p .707 .577 .707 r
F P
0 g
s
.1814 .60135 m .17593 .65606 L .15958 .66294 L p .707 .577 .707 r
F P
0 g
s
.15447 .71443 m .1604 .67853 L .17671 .67195 L p .707 .577 .707 r
F P
0 g
s
.17593 .65606 m .1814 .60135 L .20538 .59712 L p .707 .577 .707 r
F P
0 g
s
.17671 .67195 m .17078 .70786 L .15447 .71443 L p .707 .577 .707 r
F P
0 g
s
.1505 .75138 m .1538 .73353 L .17009 .72704 L p .707 .577 .707 r
F P
0 g
s
.32467 .61043 m .31921 .66514 L .2919 .65766 L p .707 .577 .707 r
F P
0 g
s
.2919 .65766 m .29737 .60295 L .32467 .61043 L p .707 .577 .707 r
F P
0 g
s
.20538 .59712 m .19991 .65183 L .17593 .65606 L p .707 .577 .707 r
F P
0 g
s
.64477 .27273 m .59567 .76676 L .56613 .75373 L p .707 .577 .707 r
F P
0 g
s
.56613 .75373 m .61524 .25971 L .64477 .27273 L p .707 .577 .707 r
F P
0 g
s
.17009 .72704 m .16678 .7449 L .1505 .75138 L p .707 .577 .707 r
F P
0 g
s
.19991 .65183 m .20538 .59712 L .23465 .59595 L p .707 .577 .707 r
F P
0 g
s
.17078 .70786 m .17671 .67195 L .20057 .6686 L p .707 .577 .707 r
F P
0 g
s
.41295 .24699 m .36385 .74101 L .34077 .75073 L p .707 .577 .707 r
F P
0 g
s
.36385 .74101 m .41295 .24699 L .44681 .241 L p .707 .577 .707 r
F P
0 g
s
.29737 .60295 m .2919 .65766 L .26088 .65267 L p .707 .577 .707 r
F P
0 g
s
.26088 .65267 m .26635 .59796 L .29737 .60295 L p .707 .577 .707 r
F P
0 g
s
.22918 .65066 m .23465 .59595 L .26635 .59796 L p .707 .577 .707 r
F P
0 g
s
.23465 .59595 m .22918 .65066 L .19991 .65183 L p .707 .577 .707 r
F P
0 g
s
.20057 .6686 m .19464 .70451 L .17078 .70786 L p .707 .577 .707 r
F P
0 g
s
.26635 .59796 m .26088 .65267 L .22918 .65066 L p .707 .577 .707 r
F P
0 g
s
.16678 .7449 m .17009 .72704 L .19391 .72396 L p .707 .577 .707 r
F P
0 g
s
.31895 .68885 m .31302 .72476 L .28597 .71536 L p .707 .577 .707 r
F P
0 g
s
.28597 .71536 m .2919 .67945 L .31895 .68885 L p .707 .577 .707 r
F P
0 g
s
.72724 .6612 m .73271 .60649 L .70169 .6015 L p .707 .577 .707 r
F P
0 g
s
.73271 .60649 m .72724 .6612 L .75894 .6632 L p .707 .577 .707 r
F P
0 g
s
.75894 .6632 m .76441 .6085 L .73271 .60649 L p .707 .577 .707 r
F P
0 g
s
.19464 .70451 m .20057 .6686 L .22966 .66881 L p .707 .577 .707 r
F P
0 g
s
.76441 .6085 m .75894 .6632 L .78821 .66204 L p .707 .577 .707 r
F P
0 g
s
.78821 .66204 m .79368 .60733 L .76441 .6085 L p .707 .577 .707 r
F P
0 g
s
.19391 .72396 m .19061 .74181 L .16678 .7449 L p .707 .577 .707 r
F P
0 g
s
.69622 .65621 m .70169 .6015 L .67439 .59402 L p .707 .577 .707 r
F P
0 g
s
.70169 .6015 m .69622 .65621 L .72724 .6612 L p .707 .577 .707 r
F P
0 g
s
.61524 .25971 m .56613 .75373 L .52758 .7432 L p .707 .577 .707 r
F P
0 g
s
.52758 .7432 m .57668 .24917 L .61524 .25971 L p .707 .577 .707 r
F P
0 g
s
.2919 .67945 m .28597 .71536 L .2552 .70845 L p .707 .577 .707 r
F P
0 g
s
.2552 .70845 m .26113 .67255 L .2919 .67945 L p .707 .577 .707 r
F P
0 g
s
.22966 .66881 m .22373 .70471 L .19464 .70451 L p .707 .577 .707 r
F P
0 g
s
.39771 .73503 m .44681 .241 L .48814 .23934 L p .707 .577 .707 r
F P
0 g
s
.44681 .241 m .39771 .73503 L .36385 .74101 L p .707 .577 .707 r
F P
0 g
s
.22373 .70471 m .22966 .66881 L .26113 .67255 L p .707 .577 .707 r
F P
0 g
s
.79368 .60733 m .78821 .66204 L .81219 .6578 L p .707 .577 .707 r
F P
0 g
s
.81219 .6578 m .81766 .6031 L .79368 .60733 L p .707 .577 .707 r
F P
0 g
s
.31193 .74626 m .30862 .76411 L .28167 .75415 L p .707 .577 .707 r
F P
0 g
s
.28167 .75415 m .28497 .73629 L .31193 .74626 L p .707 .577 .707 r
F P
0 g
s
.26113 .67255 m .2552 .70845 L .22373 .70471 L p .707 .577 .707 r
F P
0 g
s
.19061 .74181 m .19391 .72396 L .22293 .72457 L p .707 .577 .707 r
F P
0 g
s
.66892 .64873 m .67439 .59402 L .65347 .58478 L p .707 .577 .707 r
F P
0 g
s
.67439 .59402 m .66892 .64873 L .69622 .65621 L p .707 .577 .707 r
F P
0 g
s
.72106 .72464 m .72698 .68873 L .69622 .68183 L p .707 .577 .707 r
F P
0 g
s
.72698 .68873 m .72106 .72464 L .75252 .72838 L p .707 .577 .707 r
F P
0 g
s
.75252 .72838 m .75845 .69247 L .72698 .68873 L p .707 .577 .707 r
F P
0 g
s
.22293 .72457 m .21962 .74242 L .19061 .74181 L p .707 .577 .707 r
F P
0 g
s
.57668 .24917 m .52758 .7432 L .48379 .73618 L p .707 .577 .707 r
F P
0 g
s
.48379 .73618 m .53289 .24215 L .57668 .24917 L p .707 .577 .707 r
F P
0 g
s
.75845 .69247 m .75252 .72838 L .78162 .72858 L p .707 .577 .707 r
F P
0 g
s
.78162 .72858 m .78754 .69268 L .75845 .69247 L p .707 .577 .707 r
F P
0 g
s
.69029 .71773 m .69622 .68183 L .66917 .67243 L p .707 .577 .707 r
F P
0 g
s
.69622 .68183 m .69029 .71773 L .72106 .72464 L p .707 .577 .707 r
F P
0 g
s
.43904 .73336 m .48814 .23934 L .53289 .24215 L p .707 .577 .707 r
F P
0 g
s
.48814 .23934 m .43904 .73336 L .39771 .73503 L p .707 .577 .707 r
F P
0 g
s
.28497 .73629 m .28167 .75415 L .251 .74667 L p .707 .577 .707 r
F P
0 g
s
.251 .74667 m .25431 .72882 L .28497 .73629 L p .707 .577 .707 r
F P
0 g
s
.21962 .74242 m .22293 .72457 L .25431 .72882 L p .707 .577 .707 r
F P
0 g
s
.25431 .72882 m .251 .74667 L .21962 .74242 L p .707 .577 .707 r
F P
0 g
s
.53289 .24215 m .48379 .73618 L .43904 .73336 L p .707 .577 .707 r
F P
0 g
s
.81766 .6031 m .81219 .6578 L .82854 .65093 L p .707 .577 .707 r
F P
0 g
s
.82854 .65093 m .83401 .59622 L .81766 .6031 L p .707 .577 .707 r
F P
0 g
s
.65347 .58478 m .648 .63949 L .66892 .64873 L p .707 .577 .707 r
F P
0 g
s
.78754 .69268 m .78162 .72858 L .80548 .72523 L p .707 .577 .707 r
F P
0 g
s
.80548 .72523 m .81141 .68933 L .78754 .69268 L p .707 .577 .707 r
F P
0 g
s
.66917 .67243 m .66324 .70833 L .69029 .71773 L p .707 .577 .707 r
F P
0 g
s
.648 .63949 m .65347 .58478 L .64098 .57469 L p .707 .577 .707 r
F P
0 g
s
.66324 .70833 m .66917 .67243 L .64848 .66146 L p .707 .577 .707 r
F P
0 g
s
.71666 .76936 m .71996 .75151 L .6893 .74403 L p .707 .577 .707 r
F P
0 g
s
.71996 .75151 m .71666 .76936 L .74804 .77361 L p .707 .577 .707 r
F P
0 g
s
.74804 .77361 m .75134 .75576 L .71996 .75151 L p .707 .577 .707 r
F P
0 g
s
.75134 .75576 m .74804 .77361 L .77706 .77422 L p .707 .577 .707 r
F P
0 g
s
.77706 .77422 m .78036 .75637 L .75134 .75576 L p .707 .577 .707 r
F P
0 g
s
.68599 .76188 m .6893 .74403 L .66234 .73407 L p .707 .577 .707 r
F P
0 g
s
.6893 .74403 m .68599 .76188 L .71666 .76936 L p .707 .577 .707 r
F P
0 g
s
.66234 .73407 m .65904 .75192 L .68599 .76188 L p .707 .577 .707 r
F P
0 g
s
.64848 .66146 m .64255 .69736 L .66324 .70833 L p .707 .577 .707 r
F P
0 g
s
.64098 .57469 m .63552 .62939 L .648 .63949 L p .707 .577 .707 r
F P
0 g
s
.78036 .75637 m .77706 .77422 L .80088 .77113 L p .707 .577 .707 r
F P
0 g
s
.80088 .77113 m .80418 .75328 L .78036 .75637 L p .707 .577 .707 r
F P
0 g
s
.83401 .59622 m .82854 .65093 L .83565 .64207 L p .707 .577 .707 r
F P
0 g
s
.83565 .64207 m .84111 .58737 L .83401 .59622 L p .707 .577 .707 r
F P
0 g
s
.81141 .68933 m .80548 .72523 L .82179 .71866 L p .707 .577 .707 r
F P
0 g
s
.82179 .71866 m .82772 .68275 L .81141 .68933 L p .707 .577 .707 r
F P
0 g
s
.65904 .75192 m .66234 .73407 L .64174 .72258 L p .707 .577 .707 r
F P
0 g
s
.64255 .69736 m .64848 .66146 L .63618 .64999 L p .707 .577 .707 r
F P
0 g
s
.63552 .62939 m .64098 .57469 L .63816 .56473 L p .707 .577 .707 r
F P
0 g
s
.64174 .72258 m .63844 .74044 L .65904 .75192 L p .707 .577 .707 r
F P
0 g
s
.63618 .64999 m .63025 .68589 L .64255 .69736 L p .707 .577 .707 r
F P
0 g
s
.80418 .75328 m .80088 .77113 L .81717 .76465 L p .707 .577 .707 r
F P
0 g
s
.81717 .76465 m .82047 .7468 L .80418 .75328 L p .707 .577 .707 r
F P
0 g
s
.63844 .74044 m .64174 .72258 L .62951 .71071 L p .707 .577 .707 r
F P
0 g
s
.63816 .56473 m .63269 .61943 L .63552 .62939 L p .707 .577 .707 r
F P
0 g
s
.82772 .68275 m .82179 .71866 L .82893 .7095 L p .707 .577 .707 r
F P
0 g
s
.82893 .7095 m .83486 .6736 L .82772 .68275 L p .707 .577 .707 r
F P
0 g
s
.62951 .71071 m .62621 .72856 L .63844 .74044 L p .707 .577 .707 r
F P
0 g
s
.84111 .58737 m .83565 .64207 L .83282 .63211 L p .707 .577 .707 r
F P
0 g
s
.83282 .63211 m .83829 .57741 L .84111 .58737 L p .707 .577 .707 r
F P
0 g
s
.63025 .68589 m .63618 .64999 L .63347 .63915 L p .707 .577 .707 r
F P
0 g
s
.63269 .61943 m .63816 .56473 L .64527 .55587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63347 .63915 m .62754 .67505 L .63025 .68589 L p .707 .577 .707 r
F P
0 g
s
.82047 .7468 m .81717 .76465 L .82433 .7554 L p .707 .577 .707 r
F P
0 g
s
.82433 .7554 m .82763 .73755 L .82047 .7468 L p .707 .577 .707 r
F P
0 g
s
.62621 .72856 m .62951 .71071 L .62685 .6996 L p .707 .577 .707 r
F P
0 g
s
.64527 .55587 m .6398 .61058 L .63269 .61943 L p .707 .577 .707 r
F P
0 g
s
.62685 .6996 m .62355 .71746 L .62621 .72856 L p .707 .577 .707 r
F P
0 g
s
.83486 .6736 m .82893 .7095 L .82622 .69866 L p .707 .577 .707 r
F P
0 g
s
.82622 .69866 m .83215 .66275 L .83486 .6736 L p .707 .577 .707 r
F P
0 g
s
.62754 .67505 m .63347 .63915 L .64062 .62999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83829 .57741 m .83282 .63211 L .82034 .62202 L p .707 .577 .707 r
F P
0 g
s
.82034 .62202 m .82581 .56731 L .83829 .57741 L p .707 .577 .707 r
F P
0 g
s
.6398 .61058 m .64527 .55587 L .66161 .54899 L p .707 .577 .707 r
F P
0 g
s
.38423 .62151 m .3897 .56681 L .35868 .56182 L p .707 .577 .707 r
F P
0 g
s
.3897 .56681 m .38423 .62151 L .41593 .62352 L p .707 .577 .707 r
F P
0 g
s
.41593 .62352 m .4214 .56882 L .3897 .56681 L p .707 .577 .707 r
F P
0 g
s
.4214 .56882 m .41593 .62352 L .4452 .62235 L p .707 .577 .707 r
F P
0 g
s
.4452 .62235 m .45067 .56765 L .4214 .56882 L p .707 .577 .707 r
F P
0 g
s
.64062 .62999 m .63469 .66589 L .62754 .67505 L p .707 .577 .707 r
F P
0 g
s
.35321 .61653 m .35868 .56182 L .33138 .55434 L p .707 .577 .707 r
F P
0 g
s
.35868 .56182 m .35321 .61653 L .38423 .62151 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82763 .73755 m .82433 .7554 L .82166 .7443 L p .707 .577 .707 r
F P
0 g
s
.82166 .7443 m .82497 .72644 L .82763 .73755 L p .707 .577 .707 r
F P
0 g
s
.62355 .71746 m .62685 .6996 L .63401 .69036 L p .707 .577 .707 r
F P
0 g
s
.45067 .56765 m .4452 .62235 L .46918 .61812 L p .707 .577 .707 r
F P
0 g
s
.46918 .61812 m .47465 .56342 L .45067 .56765 L p .707 .577 .707 r
F P
0 g
s
.66161 .54899 m .65614 .6037 L .6398 .61058 L p .707 .577 .707 r
F P
0 g
s
.63401 .69036 m .63071 .70821 L .62355 .71746 L p .707 .577 .707 r
F P
0 g
s
.83215 .66275 m .82622 .69866 L .81392 .68719 L p .707 .577 .707 r
F P
0 g
s
.81392 .68719 m .81985 .65128 L .83215 .66275 L p .707 .577 .707 r
F P
0 g
s
.82581 .56731 m .82034 .62202 L .79942 .61278 L p .707 .577 .707 r
F P
0 g
s
.79942 .61278 m .80489 .55807 L .82581 .56731 L p .707 .577 .707 r
F P
0 g
s
.32591 .60905 m .33138 .55434 L .31046 .5451 L p .707 .577 .707 r
F P
0 g
s
.33138 .55434 m .32591 .60905 L .35321 .61653 L p .707 .577 .707 r
F P
0 g
s
.63469 .66589 m .64062 .62999 L .65692 .62342 L p .707 .577 .707 r
F P
0 g
s
.37805 .68114 m .38397 .64523 L .35321 .63833 L p .707 .577 .707 r
F P
0 g
s
.38397 .64523 m .37805 .68114 L .40951 .68488 L p .707 .577 .707 r
F P
0 g
s
.40951 .68488 m .41544 .64897 L .38397 .64523 L p .707 .577 .707 r
F P
0 g
s
.65614 .6037 m .66161 .54899 L .68559 .54476 L p .707 .577 .707 r
F P
0 g
s
.41544 .64897 m .40951 .68488 L .43861 .68508 L p .707 .577 .707 r
F P
0 g
s
.43861 .68508 m .44453 .64918 L .41544 .64897 L p .707 .577 .707 r
F P
0 g
s
.34728 .67423 m .35321 .63833 L .32616 .62893 L p .707 .577 .707 r
F P
0 g
s
.35321 .63833 m .34728 .67423 L .37805 .68114 L p .707 .577 .707 r
F P
0 g
s
.65692 .62342 m .65099 .65932 L .63469 .66589 L p .707 .577 .707 r
F P
0 g
s
.47465 .56342 m .46918 .61812 L .48553 .61125 L p .707 .577 .707 r
F P
0 g
s
.48553 .61125 m .491 .55654 L .47465 .56342 L p .707 .577 .707 r
F P
0 g
s
.31046 .5451 m .30499 .59981 L .32591 .60905 L p .707 .577 .707 r
F P
0 g
s
.82497 .72644 m .82166 .7443 L .80944 .73242 L p .707 .577 .707 r
F P
0 g
s
.80944 .73242 m .81274 .71457 L .82497 .72644 L p .707 .577 .707 r
F P
0 g
s
.63071 .70821 m .63401 .69036 L .6503 .68387 L p .707 .577 .707 r
F P
0 g
s
.44453 .64918 m .43861 .68508 L .46247 .68173 L p .707 .577 .707 r
F P
0 g
s
.46247 .68173 m .4684 .64583 L .44453 .64918 L p .707 .577 .707 r
F P
0 g
s
.32616 .62893 m .32023 .66483 L .34728 .67423 L p .707 .577 .707 r
F P
0 g
s
.80489 .55807 m .79942 .61278 L .77212 .6053 L p .707 .577 .707 r
F P
0 g
s
.77212 .6053 m .77758 .55059 L .80489 .55807 L p .707 .577 .707 r
F P
0 g
s
.30499 .59981 m .31046 .5451 L .29797 .53501 L p .707 .577 .707 r
F P
0 g
s
.37365 .72049 m .37695 .70264 L .34629 .69517 L p .707 .577 .707 r
F P
0 g
s
.37695 .70264 m .37365 .72049 L .40503 .72474 L p .707 .577 .707 r
F P
0 g
s
.40503 .72474 m .40833 .70689 L .37695 .70264 L p .707 .577 .707 r
F P
0 g
s
.68559 .54476 m .68013 .59947 L .65614 .6037 L p .707 .577 .707 r
F P
0 g
s
.32023 .66483 m .32616 .62893 L .30547 .61796 L p .707 .577 .707 r
F P
0 g
s
.81985 .65128 m .81392 .68719 L .79323 .67622 L p .707 .577 .707 r
F P
0 g
s
.79323 .67622 m .79916 .64031 L .81985 .65128 L p .707 .577 .707 r
F P
0 g
s
.68013 .59947 m .68559 .54476 L .71487 .5436 L p .707 .577 .707 r
F P
0 g
s
.40833 .70689 m .40503 .72474 L .43405 .72536 L p .707 .577 .707 r
F P
0 g
s
.43405 .72536 m .43735 .7075 L .40833 .70689 L p .707 .577 .707 r
F P
0 g
s
.6503 .68387 m .647 .70172 L .63071 .70821 L p .707 .577 .707 r
F P
0 g
s
.34298 .71302 m .34629 .69517 L .31933 .6852 L p .707 .577 .707 r
F P
0 g
s
.34629 .69517 m .34298 .71302 L .37365 .72049 L p .707 .577 .707 r
F P
0 g
s
.65099 .65932 m .65692 .62342 L .68079 .62007 L p .707 .577 .707 r
F P
0 g
s
.31933 .6852 m .31603 .70305 L .34298 .71302 L p .707 .577 .707 r
F P
0 g
s
.30547 .61796 m .29954 .65386 L .32023 .66483 L p .707 .577 .707 r
F P
0 g
s
.77758 .55059 m .77212 .6053 L .7411 .60031 L p .707 .577 .707 r
F P
0 g
s
.7411 .60031 m .74656 .5456 L .77758 .55059 L p .707 .577 .707 r
F P
0 g
s
.7094 .5983 m .71487 .5436 L .74656 .5456 L p .707 .577 .707 r
F P
0 g
s
.71487 .5436 m .7094 .5983 L .68013 .59947 L p .707 .577 .707 r
F P
0 g
s
.29797 .53501 m .29251 .58971 L .30499 .59981 L p .707 .577 .707 r
F P
0 g
s
.43735 .7075 m .43405 .72536 L .45787 .72227 L p .707 .577 .707 r
F P
0 g
s
.45787 .72227 m .46117 .70441 L .43735 .7075 L p .707 .577 .707 r
F P
0 g
s
.68079 .62007 m .67486 .65597 L .65099 .65932 L p .707 .577 .707 r
F P
0 g
s
.31603 .70305 m .31933 .6852 L .29873 .67372 L p .707 .577 .707 r
F P
0 g
s
.4684 .64583 m .46247 .68173 L .47878 .67516 L p .707 .577 .707 r
F P
0 g
s
.47878 .67516 m .48471 .63925 L .4684 .64583 L p .707 .577 .707 r
F P
0 g
s
.74656 .5456 m .7411 .60031 L .7094 .5983 L p .707 .577 .707 r
F P
0 g
s
.491 .55654 m .48553 .61125 L .49264 .60239 L p .707 .577 .707 r
F P
0 g
s
.49264 .60239 m .4981 .54769 L .491 .55654 L p .707 .577 .707 r
F P
0 g
s
.29954 .65386 m .30547 .61796 L .29317 .60649 L p .707 .577 .707 r
F P
0 g
s
.81274 .71457 m .80944 .73242 L .78884 .72094 L p .707 .577 .707 r
F P
0 g
s
.78884 .72094 m .79214 .70309 L .81274 .71457 L p .707 .577 .707 r
F P
0 g
s
.79916 .64031 m .79323 .67622 L .76618 .66682 L p .707 .577 .707 r
F P
0 g
s
.76618 .66682 m .77211 .63092 L .79916 .64031 L p .707 .577 .707 r
F P
0 g
s
.647 .70172 m .6503 .68387 L .67412 .68078 L p .707 .577 .707 r
F P
0 g
s
.29873 .67372 m .29543 .69157 L .31603 .70305 L p .707 .577 .707 r
F P
0 g
s
.67486 .65597 m .68079 .62007 L .70988 .62027 L p .707 .577 .707 r
F P
0 g
s
.29251 .58971 m .29797 .53501 L .29515 .52505 L p .707 .577 .707 r
F P
0 g
s
.67412 .68078 m .67082 .69864 L .647 .70172 L p .707 .577 .707 r
F P
0 g
s
.29317 .60649 m .28724 .64239 L .29954 .65386 L p .707 .577 .707 r
F P
0 g
s
.77211 .63092 m .76618 .66682 L .73542 .65991 L p .707 .577 .707 r
F P
0 g
s
.73542 .65991 m .74135 .62401 L .77211 .63092 L p .707 .577 .707 r
F P
0 g
s
.46117 .70441 m .45787 .72227 L .47416 .71578 L p .707 .577 .707 r
F P
0 g
s
.47416 .71578 m .47746 .69793 L .46117 .70441 L p .707 .577 .707 r
F P
0 g
s
.70988 .62027 m .70395 .65618 L .67486 .65597 L p .707 .577 .707 r
F P
0 g
s
.70395 .65618 m .70988 .62027 L .74135 .62401 L p .707 .577 .707 r
F P
0 g
s
.29543 .69157 m .29873 .67372 L .2865 .66184 L p .707 .577 .707 r
F P
0 g
s
.74135 .62401 m .73542 .65991 L .70395 .65618 L p .707 .577 .707 r
F P
0 g
s
.79214 .70309 m .78884 .72094 L .76188 .71097 L p .707 .577 .707 r
F P
0 g
s
.76188 .71097 m .76519 .69312 L .79214 .70309 L p .707 .577 .707 r
F P
0 g
s
.29515 .52505 m .28968 .57975 L .29251 .58971 L p .707 .577 .707 r
F P
0 g
s
.48471 .63925 m .47878 .67516 L .48592 .666 L p .707 .577 .707 r
F P
0 g
s
.48592 .666 m .49185 .6301 L .48471 .63925 L p .707 .577 .707 r
F P
0 g
s
.67082 .69864 m .67412 .68078 L .70314 .6814 L p .707 .577 .707 r
F P
0 g
s
.2865 .66184 m .2832 .6797 L .29543 .69157 L p .707 .577 .707 r
F P
0 g
s
.28724 .64239 m .29317 .60649 L .29046 .59565 L p .707 .577 .707 r
F P
0 g
s
.4981 .54769 m .49264 .60239 L .48981 .59243 L p .707 .577 .707 r
F P
0 g
s
.48981 .59243 m .49528 .53773 L .4981 .54769 L p .707 .577 .707 r
F P
0 g
s
.70314 .6814 m .69984 .69925 L .67082 .69864 L p .707 .577 .707 r
F P
0 g
s
.28968 .57975 m .29515 .52505 L .30226 .51619 L p .707 .577 .707 r
F P
0 g
s
.76519 .69312 m .76188 .71097 L .73122 .7035 L p .707 .577 .707 r
F P
0 g
s
.73122 .7035 m .73452 .68565 L .76519 .69312 L p .707 .577 .707 r
F P
0 g
s
.69984 .69925 m .70314 .6814 L .73452 .68565 L p .707 .577 .707 r
F P
0 g
s
.29046 .59565 m .28453 .63155 L .28724 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73452 .68565 m .73122 .7035 L .69984 .69925 L p .707 .577 .707 r
F P
0 g
s
.47746 .69793 m .47416 .71578 L .48132 .70654 L p .707 .577 .707 r
F P
0 g
s
.48132 .70654 m .48462 .68868 L .47746 .69793 L p .707 .577 .707 r
F P
0 g
s
.2832 .6797 m .2865 .66184 L .28384 .65074 L p .707 .577 .707 r
F P
0 g
s
.28384 .65074 m .28054 .66859 L .2832 .6797 L p .707 .577 .707 r
F P
0 g
s
.30226 .51619 m .29679 .5709 L .28968 .57975 L p .707 .577 .707 r
F P
0 g
s
.49185 .6301 m .48592 .666 L .48321 .65516 L p .707 .577 .707 r
F P
0 g
s
.48321 .65516 m .48914 .61925 L .49185 .6301 L p .707 .577 .707 r
F P
0 g
s
.28453 .63155 m .29046 .59565 L .29761 .58649 L p .707 .577 .707 r
F P
0 g
s
.49528 .53773 m .48981 .59243 L .47733 .58234 L p .707 .577 .707 r
F P
0 g
s
.47733 .58234 m .4828 .52763 L .49528 .53773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29679 .5709 m .30226 .51619 L .3186 .50931 L p .707 .577 .707 r
F P
0 g
s
.29761 .58649 m .29168 .62239 L .28453 .63155 L p .707 .577 .707 r
F P
0 g
s
.48462 .68868 m .48132 .70654 L .47865 .69543 L p .707 .577 .707 r
F P
0 g
s
.47865 .69543 m .48196 .67758 L .48462 .68868 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28054 .66859 m .28384 .65074 L .291 .64149 L p .707 .577 .707 r
F P
0 g
s
.291 .64149 m .2877 .65934 L .28054 .66859 L p .707 .577 .707 r
F P
0 g
s
.3186 .50931 m .31313 .56402 L .29679 .5709 L p .707 .577 .707 r
F P
0 g
s
.48914 .61925 m .48321 .65516 L .47091 .64369 L p .707 .577 .707 r
F P
0 g
s
.47091 .64369 m .47684 .60778 L .48914 .61925 L p .707 .577 .707 r
F P
0 g
s
.4828 .52763 m .47733 .58234 L .45641 .5731 L p .707 .577 .707 r
F P
0 g
s
.45641 .5731 m .46188 .51839 L .4828 .52763 L p .707 .577 .707 r
F P
0 g
s
.29168 .62239 m .29761 .58649 L .31391 .57991 L p .707 .577 .707 r
F P
0 g
s
.31313 .56402 m .3186 .50931 L .34258 .50508 L p .707 .577 .707 r
F P
0 g
s
.31391 .57991 m .30798 .61582 L .29168 .62239 L p .707 .577 .707 r
F P
0 g
s
.48196 .67758 m .47865 .69543 L .46642 .68356 L p .707 .577 .707 r
F P
0 g
s
.46642 .68356 m .46973 .6657 L .48196 .67758 L p .707 .577 .707 r
F P
0 g
s
.2877 .65934 m .291 .64149 L .30729 .63501 L p .707 .577 .707 r
F P
0 g
s
.46188 .51839 m .45641 .5731 L .42911 .56562 L p .707 .577 .707 r
F P
0 g
s
.42911 .56562 m .43457 .51091 L .46188 .51839 L p .707 .577 .707 r
F P
0 g
s
.34258 .50508 m .33712 .55979 L .31313 .56402 L p .707 .577 .707 r
F P
0 g
s
.47684 .60778 m .47091 .64369 L .45022 .63272 L p .707 .577 .707 r
F P
0 g
s
.45022 .63272 m .45615 .59681 L .47684 .60778 L p .707 .577 .707 r
F P
0 g
s
.30729 .63501 m .30399 .65286 L .2877 .65934 L p .707 .577 .707 r
F P
0 g
s
.33712 .55979 m .34258 .50508 L .37186 .50391 L p .707 .577 .707 r
F P
0 g
s
.30798 .61582 m .31391 .57991 L .33778 .57657 L p .707 .577 .707 r
F P
0 g
s
.43457 .51091 m .42911 .56562 L .39809 .56063 L p .707 .577 .707 r
F P
0 g
s
.39809 .56063 m .40355 .50592 L .43457 .51091 L p .707 .577 .707 r
F P
0 g
s
.36639 .55862 m .37186 .50391 L .40355 .50592 L p .707 .577 .707 r
F P
0 g
s
.37186 .50391 m .36639 .55862 L .33712 .55979 L p .707 .577 .707 r
F P
0 g
s
.33778 .57657 m .33185 .61247 L .30798 .61582 L p .707 .577 .707 r
F P
0 g
s
.40355 .50592 m .39809 .56063 L .36639 .55862 L p .707 .577 .707 r
F P
0 g
s
.46973 .6657 m .46642 .68356 L .44583 .67207 L p .707 .577 .707 r
F P
0 g
s
.44583 .67207 m .44913 .65422 L .46973 .6657 L p .707 .577 .707 r
F P
0 g
s
.30399 .65286 m .30729 .63501 L .33111 .63192 L p .707 .577 .707 r
F P
0 g
s
.45615 .59681 m .45022 .63272 L .42317 .62332 L p .707 .577 .707 r
F P
0 g
s
.42317 .62332 m .4291 .58742 L .45615 .59681 L p .707 .577 .707 r
F P
0 g
s
.33185 .61247 m .33778 .57657 L .36687 .57677 L p .707 .577 .707 r
F P
0 g
s
.33111 .63192 m .32781 .64977 L .30399 .65286 L p .707 .577 .707 r
F P
0 g
s
.4291 .58742 m .42317 .62332 L .39241 .61641 L p .707 .577 .707 r
F P
0 g
s
.39241 .61641 m .39834 .58051 L .4291 .58742 L p .707 .577 .707 r
F P
0 g
s
.36687 .57677 m .36094 .61267 L .33185 .61247 L p .707 .577 .707 r
F P
0 g
s
.36094 .61267 m .36687 .57677 L .39834 .58051 L p .707 .577 .707 r
F P
0 g
s
.44913 .65422 m .44583 .67207 L .41887 .66211 L p .707 .577 .707 r
F P
0 g
s
.41887 .66211 m .42218 .64426 L .44913 .65422 L p .707 .577 .707 r
F P
0 g
s
.39834 .58051 m .39241 .61641 L .36094 .61267 L p .707 .577 .707 r
F P
0 g
s
.32781 .64977 m .33111 .63192 L .36013 .63253 L p .707 .577 .707 r
F P
0 g
s
.36013 .63253 m .35683 .65038 L .32781 .64977 L p .707 .577 .707 r
F P
0 g
s
.42218 .64426 m .41887 .66211 L .38821 .65463 L p .707 .577 .707 r
F P
0 g
s
.38821 .65463 m .39151 .63678 L .42218 .64426 L p .707 .577 .707 r
F P
0 g
s
.35683 .65038 m .36013 .63253 L .39151 .63678 L p .707 .577 .707 r
F P
0 g
s
.39151 .63678 m .38821 .65463 L .35683 .65038 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007eooad008=o
o`00N7oo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH01P00OGoo001dOol40007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001hOol0079oo`800003FUH005YF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Aoo`00L7oo
0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000L7oo001^Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001]Ool006eoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001[Ool006aoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEUYFFUH2001YOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH2001W
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001UOol006]oo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP8006Aoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000069oo`00Jgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01eYF00D005YFFUIJEP00065oo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH01eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0GWoo001ZOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00Ggoo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001Z
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Ggoo001ZOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<007ooOol0GGoo001ZOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006Yoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF009JEP03001JEP0005moo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF0000Ggoo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUIoo`1OOol006Uoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001J
EWoo05moo`00JGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05mo
o`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05moo`00JGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80061oo`00JGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000H7oo001YOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH0001POol006Uoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0H7oo001Y
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1POol006Qoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo061oo`00J7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP80065oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
065oo`00J7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001X
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001QOol006Qoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00065oo`00J7oo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0HGoo001XOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUIoo`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH00`00FUH0001ROol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP03001JEP00069oo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001SOol006Moo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000Hgoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001V
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001UOol005iooaL000=JEP03001JEUYF00MJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00FGoo
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol0
05Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001V
Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000:Ool?
001=Ool005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP02FUH90014Ool0
05=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20004Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH6000nOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol0059oo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH2000hOol0059oo`03001JEP0000AJEP04001JEUYFFUH;0004FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo00<005YF00000eYF1@0000=J
EP00FUH01EYF00<005YFFUH01@0000=JEP0000000`000UYF1P001UYF00<005YFFUH015YF00D005YF
FUH005YF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008003Aoo`00DWoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF
00AJEQ<0009JEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`06001J
EP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF0`001EYF
00H005YFFUIJEP00FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000aOol0059oo`8000=JEP03001JEUYF00=JEPL00003FUH005YF00MJEP@0
00EJEP03001JEUYF00IJEP04001JEP000003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002mo
o`00DWoo0P000eYF1P000eYF00@005YFFUIJEPT00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH200000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001BOol20002FUH200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH20003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH00`00FUH00002FUH3000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH4000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002eo
o`00>Goo3P002goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF009JEPT0009oo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF
00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH0
1000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool0
035oo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
008000AJEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30003
FUH500000eYF001JEP05FUH60004Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0017oo10001UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF10000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@00003
FUH0000000X0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYF
FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003FUH5000015YF001JEUYF0P0000=oo`0000001@000UYF1`001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH000040003FUH00`00FUIJEP02FUH200000eYF001JEP03FUH=0002FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH@00000eYF001JEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP030006
FUH00`00FUH00005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUH000030003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH02000FUIJ
EP00FUH005YF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF009JEP<000AJEP8000IJEP03001JEUYF009J
EP<0009JEP03001JEUYF00=JEP@00003FUH005YF00EJEP03001JEUYF009JEP8000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001oo`0]
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000=JEP03001JEUYF009JEPh00003FUH005YF009JEPD00003FUH005YF00QJ
EP8000IJEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000_Ool002aoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEPH000=JEP03001J
EUYF00EJEP03001JEUYF00@00003FUH0000000<00003FUH005YF00UJEP<000AJEP04001JEUYFFUH3
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJ
EP03001JEUYF009JEP8002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1P0000=JEP00FUH02EYF00@005YFFUH0009JEP03001JEUYF009JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001J
EP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
2EYF00@005YFFUIJEP<000AJEP<000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP8000=JEP07001JEUYFFUH005YF0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH01000FUIJEUYF100015YF0`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF0P00<7oo000[Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0003FUH01000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YF00001`000eYF0P000UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF0P00<7oo000[Ool00`00FUH00004FUH01000FUIJEUYF5P0015YF0P000eYF1@0000=JEP00
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEP00
00@000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP@0035oo`00:goo00<005YF00000eYF1@0000=JEP00FUH01EYF00<005YFFUH01000
0Woo2`0000AJEP00001JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF009JEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH005YF009JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000bOol002]oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH?0004FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1EYF0`000UYF00@005YFFUIJEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000003FUH60004FUH20004Ool400000eYF000000040006FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH0000aOol002]oo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF1@000eYF0`000UYF100000AJEP00000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0
00IJEP03001JEUYF00<000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01@00FUIJEP00FUH00`0015YF00<005YFFUH00eYF0P001goo2`000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF100015YF10001EYF1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEP8000=JEP03001JEUYF00=JEP80009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH30002FUH00`00FUIJEP03FUH01000
FUH000002Woo0`000goo10001eYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00:goo0P000eYF
00<005YFFUH00eYF400000=JEP00FUH01UYF00D005YF001JEP0000EJEP03001JEUYF00D00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00EJEP800005FUH00000FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP030005
FUH01@00FUIJEUYF000027oo1@001Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEP8002moo`00
:goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF0P000eYF00D005YFFUIJ
EP0000IJEPH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP03001JEP0000800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00=J
EP<000=JEP05001JEUYFFUH00008Ool50008Ool300000eYF001JEP05FUH01P00FUIJEP00FUH002mo
o`00:goo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00001000
0eYF0`0000=JEP00FUH01EYF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP8000Moo`D000]o
o`8000IJEP06001JEUYF001JEP00;goo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0P001UYF0P0000=JEP00FUH01EYF
2@000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00=JEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEQ0000Eoo`<000io
o`8000=JEP07001JEUYFFUH005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30002FUH01@00FUH005YF00001UYF
00<005YFFUH00UYF4P000eYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0`000eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P004Woo0P0000=JEP00FUH0
0UYF0P00<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH00`00FUH00002000015YF001JEP001EYF00<005YFFUH00eYF1@002UYF00<0
05YFFUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P004Goo0P000eYF0P00
<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH01000FUIJEUYF0`0000=JEP00FUH015YF00<005YFFUH00eYF1@002UYF00<005YFFUH0
1UYF1@002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP0000000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF500000AJEP00FUH0
031oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YF000000=JEP03001JEUYF00EJEP@000=JEP03001JEUYF00AJEP@000YJEP03001JEUYF
00QJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo02moo`00:Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
1eYF00<005YFFUH010002EYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP00009JEP04001JEUYFFUH>
0006FUH00`00FUIJEP07FUH00`00FUH000040006FUH01`00FUIJEUYF001JEP00031oo`00:Woo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`001eYF00<005YFFUH015YF1@0015YF00<005YFFUH025YF00<005YFFUH01EYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF000000=J
EP@00003FUH005YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00=JEP03001JEUYF009JEP80035oo`00:Woo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEP000004FUH00`00FUIJEP07FUH00`00FUIJEP05000:FUH0
0`00FUIJEP050002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF1@001UYF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF0P00<Goo000ZOol20003FUH50007Ool70002FUH70006FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00
00=JEP0000001EYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<Goo000ZOol00eYF001JEP05000@Ool=0002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30007
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00<005YFFUH00UYF
0P000UYF0P00<Woo000YOol01000FUH000000UYF00@005YFFUH001Qoo`P000IJEP03001JEUYF00=J
EP03001JEP00009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0006FUH00`00FUIJEP03FUH300000eYF001JEP07FUH01000FUIJEUYF0`000UYF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP04001JEP00000bOol002Uoo`<000=JEP04001JEUYFFUH2000NOol20003
FUH00`00FUIJEP04FUH00`00FUH00006FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00000015YF00<005YFFUH00eYF00<005YFFUH00`001UYF00@005YFFUIJEPD00003FUH005YF
00AJEP<00003FUH005YF00EJEP<003=oo`00:Goo00<005YF00000eYF00<005YFFUH00UYF1`003Goo
0`002Woo0P0000=JEP00FUH01EYF00<005YF00001EYF00<005YFFUH00eYF10000UYF00<005YFFUH0
1EYF00@005YFFUIJEPD000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF1P00
25YF0`001UYF00<005YF0000<goo000YOol00`00FUIJEP03FUH50003FUH01000FUIJEUYF2@000goo
1@002goo0P001UYF00<005YF00001EYF00<005YFFUH01eYF3P002UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF10001UYF00<005YFFUH00UYF0P000goo
300025YF00<005YFFUH00P000eYF00D005YFFUIJEP00039oo`00:Woo00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF20003Goo0P000eYF0P001eYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00P001EYF00L005YFFUIJEP00FUH0000:OolA
00001Goo000005YF00000eYF00<007ooOol0<7oo000ZOol30003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH00eYF30001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF0000009JEP03001JEUYF00=JEP<0009JEP07001JEUYFFUH005YF00007Woo0P00
0eYF0P00<Goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH40008Ool400000eYF001JEP05FUH00`00FUIJEP03FUH:0002FUH00`00FUIJEP07FUH9
0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001UYF00@0
05YF000000AJEP80025oo`05001JEP00FUH0000aOol002Yoo`8000=JEP04001JEUYFFUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000070003FUH00`00FUH00005FUH700000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH01`00FUH005YF001JEP0000IJEP04001JEUYFFUH20002FUH2000ROol200000eYF
001oo`0`Ool002Uoo`8000=JEPD00003FUH005YF00AJEPT000AJEP03001JEUYF00MJEP04001JEUYF
FUH30006FUH00`00FUH00003FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH50009FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH00`00FUIJ
EP04FUH4000SOol00`00FUH0000aOol002Uoo`800004FUH000000005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH70006FUH00`00FUIJEP04FUH20004FUH200000eYF001JEP0200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH40005FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP04
000NOol3000bOol002Uoo`<000=oo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP@0009JEP03001JEUYF00EJEP<0009JEP800003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@00003FUH005YF00MJEP03
001JEUYF00=JEP800003FUH005YF00IJEP<000IJEP03001JEUYF00AJEPL001Eoo`800003FUH00000
039oo`00:7oo0`001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF
00<005YFFUH01P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF10001eYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00@005YF000000=J
EP03001JEUYF00MJEP03001JEUYF009JEPP000Qoo`D000=JEP80039oo`00:7oo10001goo0`001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP@000AJEP03
001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04
001JEUYFFUH20005FUH00`00FUIJEP03FUH50007FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<0
05YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000cOol002Qoo`05001JEP00FUH00009
Ool400000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH20003Ool20004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<goo000XOol2
0003FUH00`00Oomoo`0:Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20006FUH20005FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUH00005Ool300000eYF001JEP05FUH00`00FUIJ
EP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00=7oo
000YOol01000FUIJEUYF0`003Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0P000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YF000027oo0P001UYF00H005YFFUH005YF
0002Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000=Woo000YOol01@00FUIJ
EUYF00000UYF00<007ooOol03goo2@000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00
000000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH0000:Ool20003FUH01`00FUIJEUYF
001JEP0000Uoo`P000AJEP04001JEUYFFUH5000hOol002Yoo`03001JEP0000AJEP8001AooaL00003
FUH005YF00aJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH2000015YF001JEP0037oo0P0000=JEP00FUH00UYF0P004Woo2000
?Goo000[Ool20006FUH2000BOol5000BOol2000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000?Ool20003FUH2001G
Ool002aoo`03001JEUYF00AJEP03001JEP0000<000ioo`D001=oo`8000aJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
00aoo`H00004FUH005YF001GOol002eoo`8000AJEP03001JEUYF00=JEPD000Yoo`<001Eoo`<001EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF00=JEPl000=J
EP03001JEUYF00800003FUH007oo05Ioo`00;goo00@005YFFUH000QJEP03001JEUYF00@001ioo`@0
01AJEP03001JEUYF00UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEP000002FUH01000FUH000000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001GOol0031o
o`<000QJEP03001JEUYF00AJEPD001Moo`@0009oo`80019JEP03001JEUYF00UJEP03001JEUYF00UJ
EP8000]JEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF
00<005YFFUH00UYF0P00F7oo000bOol20006FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002
FUH20004Ool2000LFUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01P00FUIJEP00FUH000MJEP8000=JEP03001JEUYF009JEP8005Qoo`00=7oo10000UYF00<005YF
FUH01eYF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0006Ool3000IFUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP06FUH3
00000eYF001JEP03FUH2001HOol003Qoo`@000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF008000Yoo`<002=JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH00000008000MJEP03001JEUYF008000=JEP8005Uoo`00?7oo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000ioo`@001iJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH20004FUH00`00FUIJEP03FUH2
00000eYF0000001IOol003moo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000COol4000JFUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`000UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01EYF0`00FWoo0012Ool60004FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@006Goo10005UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00001P0025YF0`001UYF
00<005YF0000FWoo0018Ool@000ROol6000@FUH00`00FUIJEP09FUH00`00FUIJEP05FUH;0008FUH0
0`00FUIJEP020003FUH01@00FUIJEUYF0000FGoo0020Ool:0006FUH00`00FUIJEP09FUH00`00FUIJ
EP050005OolB00001Goo000005YF00000eYF00<007ooOol0Egoo002:OolE000;Ool3000AOol20003
FUH2001HOol008eoo`8000IJEP04001JEP00000WOol01@00FUH005YF0000F7oo002>Ool00`00FUIJ
EP04FUH01000FUIJEUYF0P009Woo0P0000=JEP00Ool0Egoo002?Ool20003FUH00`00FUIJEP04FUH4
000SOol00`00FUH0001HOol0095oo`800003FUH005YF00IJEP03001JEUYF00@001ioo`<005Uoo`00
Tgoo0`001UYF00<005YFFUH015YF1@005goo0P0000=JEP000000FGoo002FOol20003FUH00`00FUIJ
EP07FUH00`00FUIJEP04000>Ool50003FUH2001IOol009Qoo`800003FUH005YF00QJEP03001JEUYF
00AJEPh000=JEP04001JEUYFFUH2001JOol009Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2001JOol009ioo`@0009JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2001KOol00:9oo`D000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001MOol00:Moo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001OOol0
0:]oo`h006Aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60191 .74543 m .59644 .68956 L .56542 .69078 L p .707 .577 .707 r
F P
0 g
s
.59644 .68956 m .60191 .74543 L .63361 .74184 L p .707 .577 .707 r
F P
0 g
s
.63361 .74184 m .62814 .68596 L .59644 .68956 L p .707 .577 .707 r
F P
0 g
s
.62814 .68596 m .63361 .74184 L .66288 .73623 L p .707 .577 .707 r
F P
0 g
s
.66288 .73623 m .65741 .68035 L .62814 .68596 L p .707 .577 .707 r
F P
0 g
s
.57089 .74665 m .56542 .69078 L .53812 .6895 L p .707 .577 .707 r
F P
0 g
s
.56542 .69078 m .57089 .74665 L .60191 .74543 L p .707 .577 .707 r
F P
0 g
s
.65741 .68035 m .66288 .73623 L .68686 .72915 L p .707 .577 .707 r
F P
0 g
s
.68686 .72915 m .6814 .67327 L .65741 .68035 L p .707 .577 .707 r
F P
0 g
s
.60759 .80244 m .60166 .76526 L .57089 .76845 L p .707 .577 .707 r
F P
0 g
s
.60166 .76526 m .60759 .80244 L .63906 .79707 L p .707 .577 .707 r
F P
0 g
s
.63906 .79707 m .63313 .75989 L .60166 .76526 L p .707 .577 .707 r
F P
0 g
s
.63313 .75989 m .63906 .79707 L .66815 .79004 L p .707 .577 .707 r
F P
0 g
s
.66815 .79004 m .66222 .75286 L .63313 .75989 L p .707 .577 .707 r
F P
0 g
s
.53812 .6895 m .54359 .74538 L .57089 .74665 L p .707 .577 .707 r
F P
0 g
s
.54359 .74538 m .53812 .6895 L .5172 .68587 L p .707 .577 .707 r
F P
0 g
s
.57089 .76845 m .57682 .80563 L .60759 .80244 L p .707 .577 .707 r
F P
0 g
s
.57682 .80563 m .57089 .76845 L .54384 .76916 L p .707 .577 .707 r
F P
0 g
s
.66222 .75286 m .66815 .79004 L .69202 .78205 L p .707 .577 .707 r
F P
0 g
s
.69202 .78205 m .68609 .74487 L .66222 .75286 L p .707 .577 .707 r
F P
0 g
s
.61179 .84156 m .60849 .823 L .57782 .82678 L p .707 .577 .707 r
F P
0 g
s
.60849 .823 m .61179 .84156 L .64317 .83566 L p .707 .577 .707 r
F P
0 g
s
.64317 .83566 m .63986 .81709 L .60849 .823 L p .707 .577 .707 r
F P
0 g
s
.6814 .67327 m .68686 .72915 L .70321 .72128 L p .707 .577 .707 r
F P
0 g
s
.70321 .72128 m .69774 .6654 L .6814 .67327 L p .707 .577 .707 r
F P
0 g
s
.63986 .81709 m .64317 .83566 L .67219 .82821 L p .707 .577 .707 r
F P
0 g
s
.67219 .82821 m .66888 .80965 L .63986 .81709 L p .707 .577 .707 r
F P
0 g
s
.54384 .76916 m .54977 .80633 L .57682 .80563 L p .707 .577 .707 r
F P
0 g
s
.57782 .82678 m .58112 .84534 L .61179 .84156 L p .707 .577 .707 r
F P
0 g
s
.5172 .68587 m .52267 .74174 L .54359 .74538 L p .707 .577 .707 r
F P
0 g
s
.58112 .84534 m .57782 .82678 L .55087 .82807 L p .707 .577 .707 r
F P
0 g
s
.54977 .80633 m .54384 .76916 L .52316 .7673 L p .707 .577 .707 r
F P
0 g
s
.55087 .82807 m .55417 .84663 L .58112 .84534 L p .707 .577 .707 r
F P
0 g
s
.66888 .80965 m .67219 .82821 L .69601 .81995 L p .707 .577 .707 r
F P
0 g
s
.69601 .81995 m .6927 .80139 L .66888 .80965 L p .707 .577 .707 r
F P
0 g
s
.52267 .74174 m .5172 .68587 L .50472 .68022 L p .707 .577 .707 r
F P
0 g
s
.68609 .74487 m .69202 .78205 L .70832 .77388 L p .707 .577 .707 r
F P
0 g
s
.70832 .77388 m .70239 .7367 L .68609 .74487 L p .707 .577 .707 r
F P
0 g
s
.52316 .7673 m .52908 .80447 L .54977 .80633 L p .707 .577 .707 r
F P
0 g
s
.55417 .84663 m .55087 .82807 L .53027 .82674 L p .707 .577 .707 r
F P
0 g
s
.69774 .6654 m .70321 .72128 L .71032 .71341 L p .707 .577 .707 r
F P
0 g
s
.71032 .71341 m .70485 .65753 L .69774 .6654 L p .707 .577 .707 r
F P
0 g
s
.53027 .82674 m .53357 .8453 L .55417 .84663 L p .707 .577 .707 r
F P
0 g
s
.50472 .68022 m .51019 .73609 L .52267 .74174 L p .707 .577 .707 r
F P
0 g
s
.6927 .80139 m .69601 .81995 L .7123 .81168 L p .707 .577 .707 r
F P
0 g
s
.7123 .81168 m .70899 .79312 L .6927 .80139 L p .707 .577 .707 r
F P
0 g
s
.52908 .80447 m .52316 .7673 L .51085 .76306 L p .707 .577 .707 r
F P
0 g
s
.51085 .76306 m .51678 .80024 L .52908 .80447 L p .707 .577 .707 r
F P
0 g
s
.51019 .73609 m .50472 .68022 L .50189 .67311 L p .707 .577 .707 r
F P
0 g
s
.70239 .7367 m .70832 .77388 L .71547 .76632 L p .707 .577 .707 r
F P
0 g
s
.71547 .76632 m .70954 .72914 L .70239 .7367 L p .707 .577 .707 r
F P
0 g
s
.53357 .8453 m .53027 .82674 L .51804 .82293 L p .707 .577 .707 r
F P
0 g
s
.51804 .82293 m .52134 .84149 L .53357 .8453 L p .707 .577 .707 r
F P
0 g
s
.70485 .65753 m .71032 .71341 L .70749 .70631 L p .707 .577 .707 r
F P
0 g
s
.70749 .70631 m .70202 .65043 L .70485 .65753 L p .707 .577 .707 r
F P
0 g
s
.50189 .67311 m .50736 .72899 L .51019 .73609 L p .707 .577 .707 r
F P
0 g
s
.70899 .79312 m .7123 .81168 L .71946 .80422 L p .707 .577 .707 r
F P
0 g
s
.71946 .80422 m .71616 .78565 L .70899 .79312 L p .707 .577 .707 r
F P
0 g
s
.51678 .80024 m .51085 .76306 L .50814 .75686 L p .707 .577 .707 r
F P
0 g
s
.50814 .75686 m .51407 .79403 L .51678 .80024 L p .707 .577 .707 r
F P
0 g
s
.70954 .72914 m .71547 .76632 L .71276 .76012 L p .707 .577 .707 r
F P
0 g
s
.71276 .76012 m .70683 .72294 L .70954 .72914 L p .707 .577 .707 r
F P
0 g
s
.50736 .72899 m .50189 .67311 L .509 .66524 L p .707 .577 .707 r
F P
0 g
s
.52134 .84149 m .51804 .82293 L .51537 .817 L p .707 .577 .707 r
F P
0 g
s
.509 .66524 m .51447 .72112 L .50736 .72899 L p .707 .577 .707 r
F P
0 g
s
.51407 .79403 m .50814 .75686 L .51529 .7493 L p .707 .577 .707 r
F P
0 g
s
.51537 .817 m .51868 .83556 L .52134 .84149 L p .707 .577 .707 r
F P
0 g
s
.51868 .83556 m .51537 .817 L .52254 .80953 L p .707 .577 .707 r
F P
0 g
s
.51621 .81895 m .46711 .31438 L .42331 .31608 L p .707 .577 .707 r
F P
0 g
s
.51529 .7493 m .52122 .78648 L .51407 .79403 L p .707 .577 .707 r
F P
0 g
s
.51447 .72112 m .509 .66524 L .52535 .65738 L p .707 .577 .707 r
F P
0 g
s
.52254 .80953 m .52584 .82809 L .51868 .83556 L p .707 .577 .707 r
F P
0 g
s
.52535 .65738 m .53081 .71325 L .51447 .72112 L p .707 .577 .707 r
F P
0 g
s
.52122 .78648 m .51529 .7493 L .5316 .74113 L p .707 .577 .707 r
F P
0 g
s
.53081 .71325 m .52535 .65738 L .54933 .65029 L p .707 .577 .707 r
F P
0 g
s
.5316 .74113 m .53753 .7783 L .52122 .78648 L p .707 .577 .707 r
F P
0 g
s
.52584 .82809 m .52254 .80953 L .53883 .80126 L p .707 .577 .707 r
F P
0 g
s
.53883 .80126 m .54213 .81983 L .52584 .82809 L p .707 .577 .707 r
F P
0 g
s
.54933 .65029 m .5548 .70617 L .53081 .71325 L p .707 .577 .707 r
F P
0 g
s
.53753 .7783 m .5316 .74113 L .55546 .73313 L p .707 .577 .707 r
F P
0 g
s
.55546 .73313 m .56139 .77031 L .53753 .7783 L p .707 .577 .707 r
F P
0 g
s
.54213 .81983 m .53883 .80126 L .56265 .793 L p .707 .577 .707 r
F P
0 g
s
.56265 .793 m .56595 .81157 L .54213 .81983 L p .707 .577 .707 r
F P
0 g
s
.46711 .31438 m .51621 .81895 L .56096 .8139 L p .707 .577 .707 r
F P
0 g
s
.56096 .8139 m .51186 .30933 L .46711 .31438 L p .707 .577 .707 r
F P
0 g
s
.5548 .70617 m .54933 .65029 L .5786 .64468 L p .707 .577 .707 r
F P
0 g
s
.5786 .64468 m .58407 .70056 L .5548 .70617 L p .707 .577 .707 r
F P
0 g
s
.56139 .77031 m .55546 .73313 L .58455 .72611 L p .707 .577 .707 r
F P
0 g
s
.58455 .72611 m .59048 .76329 L .56139 .77031 L p .707 .577 .707 r
F P
0 g
s
.59048 .76329 m .58455 .72611 L .61602 .72074 L p .707 .577 .707 r
F P
0 g
s
.61602 .72074 m .62195 .75791 L .59048 .76329 L p .707 .577 .707 r
F P
0 g
s
.56595 .81157 m .56265 .793 L .59167 .78556 L p .707 .577 .707 r
F P
0 g
s
.59167 .78556 m .59497 .80412 L .56595 .81157 L p .707 .577 .707 r
F P
0 g
s
.59497 .80412 m .59167 .78556 L .62305 .77965 L p .707 .577 .707 r
F P
0 g
s
.62305 .77965 m .62635 .79821 L .59497 .80412 L p .707 .577 .707 r
F P
0 g
s
.51186 .30933 m .56096 .8139 L .60229 .80599 L p .707 .577 .707 r
F P
0 g
s
.58407 .70056 m .5786 .64468 L .6103 .64109 L p .707 .577 .707 r
F P
0 g
s
.6103 .64109 m .61577 .69696 L .58407 .70056 L p .707 .577 .707 r
F P
0 g
s
.60229 .80599 m .55319 .30143 L .51186 .30933 L p .707 .577 .707 r
F P
0 g
s
.71616 .78565 m .71946 .80422 L .7168 .79829 L p .707 .577 .707 r
F P
0 g
s
.7168 .79829 m .71349 .77972 L .71616 .78565 L p .707 .577 .707 r
F P
0 g
s
.70202 .65043 m .70749 .70631 L .69501 .70066 L p .707 .577 .707 r
F P
0 g
s
.69501 .70066 m .68954 .64478 L .70202 .65043 L p .707 .577 .707 r
F P
0 g
s
.47242 .82065 m .42331 .31608 L .38476 .31426 L p .707 .577 .707 r
F P
0 g
s
.42331 .31608 m .47242 .82065 L .51621 .81895 L p .707 .577 .707 r
F P
0 g
s
.64132 .63987 m .64678 .69574 L .61577 .69696 L p .707 .577 .707 r
F P
0 g
s
.61577 .69696 m .6103 .64109 L .64132 .63987 L p .707 .577 .707 r
F P
0 g
s
.64679 .71754 m .65272 .75472 L .62195 .75791 L p .707 .577 .707 r
F P
0 g
s
.62195 .75791 m .61602 .72074 L .64679 .71754 L p .707 .577 .707 r
F P
0 g
s
.65371 .77587 m .65702 .79443 L .62635 .79821 L p .707 .577 .707 r
F P
0 g
s
.62635 .79821 m .62305 .77965 L .65371 .77587 L p .707 .577 .707 r
F P
0 g
s
.55319 .30143 m .60229 .80599 L .63615 .796 L p .707 .577 .707 r
F P
0 g
s
.63615 .796 m .58705 .29144 L .55319 .30143 L p .707 .577 .707 r
F P
0 g
s
.2589 .71148 m .25343 .65561 L .22242 .65683 L p .707 .577 .707 r
F P
0 g
s
.25343 .65561 m .2589 .71148 L .2906 .70789 L p .707 .577 .707 r
F P
0 g
s
.2906 .70789 m .28513 .65201 L .25343 .65561 L p .707 .577 .707 r
F P
0 g
s
.28513 .65201 m .2906 .70789 L .31987 .70228 L p .707 .577 .707 r
F P
0 g
s
.31987 .70228 m .3144 .6464 L .28513 .65201 L p .707 .577 .707 r
F P
0 g
s
.70683 .72294 m .71276 .76012 L .70046 .75588 L p .707 .577 .707 r
F P
0 g
s
.70046 .75588 m .69453 .7187 L .70683 .72294 L p .707 .577 .707 r
F P
0 g
s
.22788 .7127 m .22242 .65683 L .19511 .65555 L p .707 .577 .707 r
F P
0 g
s
.22242 .65683 m .22788 .7127 L .2589 .71148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.43386 .81883 m .38476 .31426 L .35523 .3091 L p .707 .577 .707 r
F P
0 g
s
.38476 .31426 m .43386 .81883 L .47242 .82065 L p .707 .577 .707 r
F P
0 g
s
.3144 .6464 m .31987 .70228 L .34385 .6952 L p .707 .577 .707 r
F P
0 g
s
.34385 .6952 m .33839 .63932 L .3144 .6464 L p .707 .577 .707 r
F P
0 g
s
.68954 .64478 m .69501 .70066 L .67409 .69702 L p .707 .577 .707 r
F P
0 g
s
.67409 .69702 m .66862 .64114 L .68954 .64478 L p .707 .577 .707 r
F P
0 g
s
.71349 .77972 m .7168 .79829 L .70457 .79447 L p .707 .577 .707 r
F P
0 g
s
.70457 .79447 m .70126 .77591 L .71349 .77972 L p .707 .577 .707 r
F P
0 g
s
.26458 .77231 m .25865 .73513 L .22789 .73832 L p .707 .577 .707 r
F P
0 g
s
.25865 .73513 m .26458 .77231 L .29605 .76694 L p .707 .577 .707 r
F P
0 g
s
.29605 .76694 m .29012 .72976 L .25865 .73513 L p .707 .577 .707 r
F P
0 g
s
.19511 .65555 m .20058 .71143 L .22788 .7127 L p .707 .577 .707 r
F P
0 g
s
.29012 .72976 m .29605 .76694 L .32514 .75991 L p .707 .577 .707 r
F P
0 g
s
.32514 .75991 m .31921 .72273 L .29012 .72976 L p .707 .577 .707 r
F P
0 g
s
.20058 .71143 m .19511 .65555 L .17419 .65192 L p .707 .577 .707 r
F P
0 g
s
.67384 .71684 m .67977 .75402 L .65272 .75472 L p .707 .577 .707 r
F P
0 g
s
.65272 .75472 m .64679 .71754 L .67384 .71684 L p .707 .577 .707 r
F P
0 g
s
.65702 .79443 m .65371 .77587 L .68066 .77458 L p .707 .577 .707 r
F P
0 g
s
.58705 .29144 m .63615 .796 L .65922 .78491 L p .707 .577 .707 r
F P
0 g
s
.66862 .64114 m .67409 .69702 L .64678 .69574 L p .707 .577 .707 r
F P
0 g
s
.64678 .69574 m .64132 .63987 L .66862 .64114 L p .707 .577 .707 r
F P
0 g
s
.65922 .78491 m .61012 .28034 L .58705 .29144 L p .707 .577 .707 r
F P
0 g
s
.22789 .73832 m .23382 .7755 L .26458 .77231 L p .707 .577 .707 r
F P
0 g
s
.23382 .7755 m .22789 .73832 L .20083 .73903 L p .707 .577 .707 r
F P
0 g
s
.31921 .72273 m .32514 .75991 L .34901 .75192 L p .707 .577 .707 r
F P
0 g
s
.34901 .75192 m .34308 .71474 L .31921 .72273 L p .707 .577 .707 r
F P
0 g
s
.33839 .63932 m .34385 .6952 L .3602 .68733 L p .707 .577 .707 r
F P
0 g
s
.3602 .68733 m .35473 .63145 L .33839 .63932 L p .707 .577 .707 r
F P
0 g
s
.26878 .8168 m .26548 .79823 L .23481 .80202 L p .707 .577 .707 r
F P
0 g
s
.26548 .79823 m .26878 .8168 L .30016 .81089 L p .707 .577 .707 r
F P
0 g
s
.30016 .81089 m .29686 .79233 L .26548 .79823 L p .707 .577 .707 r
F P
0 g
s
.69453 .7187 m .70046 .75588 L .67977 .75402 L p .707 .577 .707 r
F P
0 g
s
.67977 .75402 m .67384 .71684 L .69453 .7187 L p .707 .577 .707 r
F P
0 g
s
.20083 .73903 m .20676 .7762 L .23382 .7755 L p .707 .577 .707 r
F P
0 g
s
.29686 .79233 m .30016 .81089 L .32918 .80345 L p .707 .577 .707 r
F P
0 g
s
.32918 .80345 m .32587 .78488 L .29686 .79233 L p .707 .577 .707 r
F P
0 g
s
.17419 .65192 m .17966 .70779 L .20058 .71143 L p .707 .577 .707 r
F P
0 g
s
.23481 .80202 m .23811 .82058 L .26878 .8168 L p .707 .577 .707 r
F P
0 g
s
.23811 .82058 m .23481 .80202 L .20786 .80331 L p .707 .577 .707 r
F P
0 g
s
.20676 .7762 m .20083 .73903 L .18015 .73717 L p .707 .577 .707 r
F P
0 g
s
.40433 .81367 m .35523 .3091 L .33761 .30111 L p .707 .577 .707 r
F P
0 g
s
.35523 .3091 m .40433 .81367 L .43386 .81883 L p .707 .577 .707 r
F P
0 g
s
.20786 .80331 m .21116 .82187 L .23811 .82058 L p .707 .577 .707 r
F P
0 g
s
.32587 .78488 m .32918 .80345 L .353 .79518 L p .707 .577 .707 r
F P
0 g
s
.353 .79518 m .3497 .77662 L .32587 .78488 L p .707 .577 .707 r
F P
0 g
s
.17966 .70779 m .17419 .65192 L .16171 .64627 L p .707 .577 .707 r
F P
0 g
s
.70126 .77591 m .70457 .79447 L .68397 .79314 L p .707 .577 .707 r
F P
0 g
s
.68397 .79314 m .68066 .77458 L .70126 .77591 L p .707 .577 .707 r
F P
0 g
s
.34308 .71474 m .34901 .75192 L .36531 .74375 L p .707 .577 .707 r
F P
0 g
s
.36531 .74375 m .35938 .70657 L .34308 .71474 L p .707 .577 .707 r
F P
0 g
s
.18015 .73717 m .18608 .77434 L .20676 .7762 L p .707 .577 .707 r
F P
0 g
s
.35473 .63145 m .3602 .68733 L .36731 .67946 L p .707 .577 .707 r
F P
0 g
s
.36731 .67946 m .36184 .62358 L .35473 .63145 L p .707 .577 .707 r
F P
0 g
s
.21116 .82187 m .20786 .80331 L .18726 .80198 L p .707 .577 .707 r
F P
0 g
s
.16171 .64627 m .16718 .70214 L .17966 .70779 L p .707 .577 .707 r
F P
0 g
s
.61012 .28034 m .65922 .78491 L .66926 .77379 L p .707 .577 .707 r
F P
0 g
s
.66926 .77379 m .62015 .26923 L .61012 .28034 L p .707 .577 .707 r
F P
0 g
s
.18726 .80198 m .19056 .82054 L .21116 .82187 L p .707 .577 .707 r
F P
0 g
s
.3497 .77662 m .353 .79518 L .36929 .78692 L p .707 .577 .707 r
F P
0 g
s
.36929 .78692 m .36598 .76835 L .3497 .77662 L p .707 .577 .707 r
F P
0 g
s
.18608 .77434 m .18015 .73717 L .16784 .73293 L p .707 .577 .707 r
F P
0 g
s
.68066 .77458 m .68397 .79314 L .65702 .79443 L p .707 .577 .707 r
F P
0 g
s
.16718 .70214 m .16171 .64627 L .15888 .63916 L p .707 .577 .707 r
F P
0 g
s
.16784 .73293 m .17377 .77011 L .18608 .77434 L p .707 .577 .707 r
F P
0 g
s
.35938 .70657 m .36531 .74375 L .37246 .73619 L p .707 .577 .707 r
F P
0 g
s
.37246 .73619 m .36653 .69901 L .35938 .70657 L p .707 .577 .707 r
F P
0 g
s
.19056 .82054 m .18726 .80198 L .17503 .79816 L p .707 .577 .707 r
F P
0 g
s
.38671 .80568 m .33761 .30111 L .33361 .29106 L p .707 .577 .707 r
F P
0 g
s
.33761 .30111 m .38671 .80568 L .40433 .81367 L p .707 .577 .707 r
F P
0 g
s
.17503 .79816 m .17833 .81672 L .19056 .82054 L p .707 .577 .707 r
F P
0 g
s
.36184 .62358 m .36731 .67946 L .36448 .67236 L p .707 .577 .707 r
F P
0 g
s
.36448 .67236 m .35901 .61648 L .36184 .62358 L p .707 .577 .707 r
F P
0 g
s
.15888 .63916 m .16435 .69504 L .16718 .70214 L p .707 .577 .707 r
F P
0 g
s
.36598 .76835 m .36929 .78692 L .37645 .77945 L p .707 .577 .707 r
F P
0 g
s
.37645 .77945 m .37315 .76089 L .36598 .76835 L p .707 .577 .707 r
F P
0 g
s
.17377 .77011 m .16784 .73293 L .16514 .72673 L p .707 .577 .707 r
F P
0 g
s
.62015 .26923 m .66926 .77379 L .66527 .76375 L p .707 .577 .707 r
F P
0 g
s
.66527 .76375 m .63695 .47281 L p .62015 .26923 L .707 .577 .707 r
F P
0 g
s
.61616 .25918 m .66527 .76375 L .64764 .75575 L p .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .66036 .67526 L .65433 .67318 L p .707 .577 .707 r
F P
0 g
s
.65433 .67318 m .64806 .67102 L p .65563 .68823 L .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .65433 .67318 L .65563 .68823 L .707 .577 .707 r
F
.63695 .47281 m .61616 .25918 L .61906 .26647 L p F P
0 g
s
.61906 .26647 m .62015 .26923 L p .63695 .47281 L .707 .577 .707 r
F P
0 g
s
.16514 .72673 m .17106 .7639 L .17377 .77011 L p .707 .577 .707 r
F P
0 g
s
.16435 .69504 m .15888 .63916 L .16599 .63129 L p .707 .577 .707 r
F P
0 g
s
.36653 .69901 m .37246 .73619 L .36975 .72999 L p .707 .577 .707 r
F P
0 g
s
.36975 .72999 m .36382 .69281 L .36653 .69901 L p .707 .577 .707 r
F P
0 g
s
.17833 .81672 m .17503 .79816 L .17237 .79223 L p .707 .577 .707 r
F P
0 g
s
.17237 .79223 m .17567 .81079 L .17833 .81672 L p .707 .577 .707 r
F P
0 g
s
.35901 .61648 m .36448 .67236 L .352 .66671 L p .707 .577 .707 r
F P
0 g
s
.352 .66671 m .34653 .61083 L .35901 .61648 L p .707 .577 .707 r
F P
0 g
s
.16599 .63129 m .17146 .68717 L .16435 .69504 L p .707 .577 .707 r
F P
0 g
s
.37315 .76089 m .37645 .77945 L .37379 .77352 L p .707 .577 .707 r
F P
0 g
s
.37379 .77352 m .37048 .75496 L .37315 .76089 L p .707 .577 .707 r
F P
0 g
s
.17106 .7639 m .16514 .72673 L .17228 .71917 L p .707 .577 .707 r
F P
0 g
s
.33361 .29106 m .38272 .79563 L .38671 .80568 L p .707 .577 .707 r
F P
0 g
s
.38272 .79563 m .33361 .29106 L .34365 .27995 L p .707 .577 .707 r
F P
0 g
s
.17228 .71917 m .17821 .75635 L .17106 .7639 L p .707 .577 .707 r
F P
0 g
s
.17146 .68717 m .16599 .63129 L .18234 .62343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36382 .69281 m .36975 .72999 L .35745 .72575 L p .707 .577 .707 r
F P
0 g
s
.35745 .72575 m .35152 .68857 L .36382 .69281 L p .707 .577 .707 r
F P
0 g
s
.17567 .81079 m .17237 .79223 L .17953 .78477 L p .707 .577 .707 r
F P
0 g
s
.17953 .78477 m .18283 .80333 L .17567 .81079 L p .707 .577 .707 r
F P
0 g
s
.64764 .75575 m .59854 .25119 L .61616 .25918 L p .707 .577 .707 r
F P
0 g
s
.34653 .61083 m .352 .66671 L .33108 .66307 L p .707 .577 .707 r
F P
0 g
s
.33108 .66307 m .32561 .60719 L .34653 .61083 L p .707 .577 .707 r
F P
0 g
s
.18234 .62343 m .1878 .6793 L .17146 .68717 L p .707 .577 .707 r
F P
0 g
s
.37048 .75496 m .37379 .77352 L .36156 .76971 L p .707 .577 .707 r
F P
0 g
s
.36156 .76971 m .35825 .75114 L .37048 .75496 L p .707 .577 .707 r
F P
0 g
s
.17821 .75635 m .17228 .71917 L .18859 .711 L p .707 .577 .707 r
F P
0 g
s
.1878 .6793 m .18234 .62343 L .20632 .61634 L p .707 .577 .707 r
F P
0 g
s
.18859 .711 m .19452 .74817 L .17821 .75635 L p .707 .577 .707 r
F P
0 g
s
.35152 .68857 m .35745 .72575 L .33676 .72389 L p .707 .577 .707 r
F P
0 g
s
.33676 .72389 m .33083 .68671 L .35152 .68857 L p .707 .577 .707 r
F P
0 g
s
.39275 .78452 m .34365 .27995 L .36672 .26885 L p .707 .577 .707 r
F P
0 g
s
.34365 .27995 m .39275 .78452 L .38272 .79563 L p .707 .577 .707 r
F P
0 g
s
.32561 .60719 m .33108 .66307 L .30378 .66179 L p .707 .577 .707 r
F P
0 g
s
.30378 .66179 m .29831 .60592 L .32561 .60719 L p .707 .577 .707 r
F P
0 g
s
.18283 .80333 m .17953 .78477 L .19582 .7765 L p .707 .577 .707 r
F P
0 g
s
.20632 .61634 m .21179 .67222 L .1878 .6793 L p .707 .577 .707 r
F P
0 g
s
.19582 .7765 m .19912 .79506 L .18283 .80333 L p .707 .577 .707 r
F P
0 g
s
.35825 .75114 m .36156 .76971 L .34096 .76838 L p .707 .577 .707 r
F P
0 g
s
.34096 .76838 m .33765 .74982 L .35825 .75114 L p .707 .577 .707 r
F P
0 g
s
.21179 .67222 m .20632 .61634 L .23559 .61073 L p .707 .577 .707 r
F P
0 g
s
.19452 .74817 m .18859 .711 L .21245 .703 L p .707 .577 .707 r
F P
0 g
s
.59854 .25119 m .64764 .75575 L .61811 .75059 L p .707 .577 .707 r
F P
0 g
s
.61811 .75059 m .56901 .24603 L .59854 .25119 L p .707 .577 .707 r
F P
0 g
s
.29831 .60592 m .30378 .66179 L .27276 .66301 L p .707 .577 .707 r
F P
0 g
s
.27276 .66301 m .26729 .60714 L .29831 .60592 L p .707 .577 .707 r
F P
0 g
s
.33083 .68671 m .33676 .72389 L .30971 .72459 L p .707 .577 .707 r
F P
0 g
s
.30971 .72459 m .30378 .68741 L .33083 .68671 L p .707 .577 .707 r
F P
0 g
s
.21245 .703 m .21838 .74018 L .19452 .74817 L p .707 .577 .707 r
F P
0 g
s
.24106 .66661 m .23559 .61073 L .26729 .60714 L p .707 .577 .707 r
F P
0 g
s
.23559 .61073 m .24106 .66661 L .21179 .67222 L p .707 .577 .707 r
F P
0 g
s
.73912 .6534 m .73365 .59752 L .70263 .59874 L p .707 .577 .707 r
F P
0 g
s
.73365 .59752 m .73912 .6534 L .77081 .6498 L p .707 .577 .707 r
F P
0 g
s
.77081 .6498 m .76535 .59393 L .73365 .59752 L p .707 .577 .707 r
F P
0 g
s
.26729 .60714 m .27276 .66301 L .24106 .66661 L p .707 .577 .707 r
F P
0 g
s
.76535 .59393 m .77081 .6498 L .80009 .64419 L p .707 .577 .707 r
F P
0 g
s
.80009 .64419 m .79462 .58831 L .76535 .59393 L p .707 .577 .707 r
F P
0 g
s
.19912 .79506 m .19582 .7765 L .21964 .76824 L p .707 .577 .707 r
F P
0 g
s
.7081 .65462 m .70263 .59874 L .67532 .59747 L p .707 .577 .707 r
F P
0 g
s
.70263 .59874 m .7081 .65462 L .73912 .6534 L p .707 .577 .707 r
F P
0 g
s
.21964 .76824 m .22294 .7868 L .19912 .79506 L p .707 .577 .707 r
F P
0 g
s
.21838 .74018 m .21245 .703 L .24154 .69598 L p .707 .577 .707 r
F P
0 g
s
.33765 .74982 m .34096 .76838 L .31401 .76967 L p .707 .577 .707 r
F P
0 g
s
.31401 .76967 m .3107 .75111 L .33765 .74982 L p .707 .577 .707 r
F P
0 g
s
.36672 .26885 m .41583 .77342 L .39275 .78452 L p .707 .577 .707 r
F P
0 g
s
.41583 .77342 m .36672 .26885 L .40058 .25886 L p .707 .577 .707 r
F P
0 g
s
.30378 .68741 m .30971 .72459 L .27894 .72778 L p .707 .577 .707 r
F P
0 g
s
.27894 .72778 m .27301 .69061 L .30378 .68741 L p .707 .577 .707 r
F P
0 g
s
.79462 .58831 m .80009 .64419 L .82407 .63711 L p .707 .577 .707 r
F P
0 g
s
.82407 .63711 m .8186 .58123 L .79462 .58831 L p .707 .577 .707 r
F P
0 g
s
.24154 .69598 m .24747 .73316 L .21838 .74018 L p .707 .577 .707 r
F P
0 g
s
.74479 .7104 m .73886 .67322 L .7081 .67642 L p .707 .577 .707 r
F P
0 g
s
.73886 .67322 m .74479 .7104 L .77626 .70503 L p .707 .577 .707 r
F P
0 g
s
.77626 .70503 m .77033 .66785 L .73886 .67322 L p .707 .577 .707 r
F P
0 g
s
.24747 .73316 m .24154 .69598 L .27301 .69061 L p .707 .577 .707 r
F P
0 g
s
.77033 .66785 m .77626 .70503 L .80535 .698 L p .707 .577 .707 r
F P
0 g
s
.80535 .698 m .79942 .66083 L .77033 .66785 L p .707 .577 .707 r
F P
0 g
s
.67532 .59747 m .68079 .65334 L .7081 .65462 L p .707 .577 .707 r
F P
0 g
s
.27301 .69061 m .27894 .72778 L .24747 .73316 L p .707 .577 .707 r
F P
0 g
s
.22294 .7868 m .21964 .76824 L .24866 .76079 L p .707 .577 .707 r
F P
0 g
s
.68079 .65334 m .67532 .59747 L .65441 .59383 L p .707 .577 .707 r
F P
0 g
s
.56901 .24603 m .61811 .75059 L .57956 .74877 L p .707 .577 .707 r
F P
0 g
s
.57956 .74877 m .53046 .24421 L .56901 .24603 L p .707 .577 .707 r
F P
0 g
s
.7081 .67642 m .71403 .71359 L .74479 .7104 L p .707 .577 .707 r
F P
0 g
s
.71403 .71359 m .7081 .67642 L .68105 .67712 L p .707 .577 .707 r
F P
0 g
s
.24866 .76079 m .25196 .77935 L .22294 .7868 L p .707 .577 .707 r
F P
0 g
s
.3107 .75111 m .31401 .76967 L .28334 .77345 L p .707 .577 .707 r
F P
0 g
s
.28334 .77345 m .28004 .75489 L .3107 .75111 L p .707 .577 .707 r
F P
0 g
s
.79942 .66083 m .80535 .698 L .82922 .69001 L p .707 .577 .707 r
F P
0 g
s
.82922 .69001 m .82329 .65284 L .79942 .66083 L p .707 .577 .707 r
F P
0 g
s
.74899 .74952 m .74569 .73096 L .71502 .73474 L p .707 .577 .707 r
F P
0 g
s
.74569 .73096 m .74899 .74952 L .78037 .74362 L p .707 .577 .707 r
F P
0 g
s
.78037 .74362 m .77707 .72506 L .74569 .73096 L p .707 .577 .707 r
F P
0 g
s
.8186 .58123 m .82407 .63711 L .84041 .62924 L p .707 .577 .707 r
F P
0 g
s
.84041 .62924 m .83495 .57337 L .8186 .58123 L p .707 .577 .707 r
F P
0 g
s
.77707 .72506 m .78037 .74362 L .80939 .73617 L p .707 .577 .707 r
F P
0 g
s
.80939 .73617 m .80609 .71761 L .77707 .72506 L p .707 .577 .707 r
F P
0 g
s
.25196 .77935 m .24866 .76079 L .28004 .75489 L p .707 .577 .707 r
F P
0 g
s
.68105 .67712 m .68698 .71429 L .71403 .71359 L p .707 .577 .707 r
F P
0 g
s
.71502 .73474 m .71833 .7533 L .74899 .74952 L p .707 .577 .707 r
F P
0 g
s
.28004 .75489 m .28334 .77345 L .25196 .77935 L p .707 .577 .707 r
F P
0 g
s
.65441 .59383 m .65987 .64971 L .68079 .65334 L p .707 .577 .707 r
F P
0 g
s
.71833 .7533 m .71502 .73474 L .68807 .73603 L p .707 .577 .707 r
F P
0 g
s
.44968 .76343 m .40058 .25886 L .44191 .25096 L p .707 .577 .707 r
F P
0 g
s
.40058 .25886 m .44968 .76343 L .41583 .77342 L p .707 .577 .707 r
F P
0 g
s
.68698 .71429 m .68105 .67712 L .66036 .67526 L p .707 .577 .707 r
F P
0 g
s
.68807 .73603 m .69138 .75459 L .71833 .7533 L p .707 .577 .707 r
F P
0 g
s
.80609 .71761 m .80939 .73617 L .83321 .72791 L p .707 .577 .707 r
F P
0 g
s
.83321 .72791 m .82991 .70935 L .80609 .71761 L p .707 .577 .707 r
F P
0 g
s
.65987 .64971 m .65441 .59383 L .64192 .58818 L p .707 .577 .707 r
F P
0 g
s
.53046 .24421 m .57956 .74877 L .53576 .75047 L p .707 .577 .707 r
F P
0 g
s
.53576 .75047 m .48666 .24591 L .53046 .24421 L p .707 .577 .707 r
F P
0 g
s
.82329 .65284 m .82922 .69001 L .84552 .68184 L p .707 .577 .707 r
F P
0 g
s
.84552 .68184 m .8396 .64466 L .82329 .65284 L p .707 .577 .707 r
F P
0 g
s
.66036 .67526 m .66629 .71244 L .68698 .71429 L p .707 .577 .707 r
F P
0 g
s
.49101 .75552 m .44191 .25096 L .48666 .24591 L p .707 .577 .707 r
F P
0 g
s
.44191 .25096 m .49101 .75552 L .44968 .76343 L p .707 .577 .707 r
F P
0 g
s
.69138 .75459 m .68807 .73603 L .66747 .7347 L p .707 .577 .707 r
F P
0 g
s
.83495 .57337 m .84041 .62924 L .84752 .62137 L p .707 .577 .707 r
F P
0 g
s
.84752 .62137 m .84205 .5655 L .83495 .57337 L p .707 .577 .707 r
F P
0 g
s
.48666 .24591 m .53576 .75047 L .49101 .75552 L p .707 .577 .707 r
F P
0 g
s
.66747 .7347 m .67078 .75327 L .69138 .75459 L p .707 .577 .707 r
F P
0 g
s
.64192 .58818 m .64739 .64406 L .65987 .64971 L p .707 .577 .707 r
F P
0 g
s
.82991 .70935 m .83321 .72791 L .8495 .71964 L p .707 .577 .707 r
F P
0 g
s
.8495 .71964 m .8462 .70108 L .82991 .70935 L p .707 .577 .707 r
F P
0 g
s
.64806 .67102 m .65399 .7082 L .66629 .71244 L p .707 .577 .707 r
F P
0 g
s
.64739 .64406 m .64192 .58818 L .6391 .58107 L p .707 .577 .707 r
F P
0 g
s
.8396 .64466 m .84552 .68184 L .85267 .67428 L p .707 .577 .707 r
F P
0 g
s
.85267 .67428 m .84674 .6371 L .8396 .64466 L p .707 .577 .707 r
F P
0 g
s
.67078 .75327 m .66747 .7347 L .65524 .73089 L p .707 .577 .707 r
F P
0 g
s
.65524 .73089 m .65855 .74945 L .67078 .75327 L p .707 .577 .707 r
F P
0 g
s
.84205 .5655 m .84752 .62137 L .84469 .61427 L p .707 .577 .707 r
F P
0 g
s
.84469 .61427 m .83923 .55839 L .84205 .5655 L p .707 .577 .707 r
F P
0 g
s
.6391 .58107 m .64456 .63695 L .64739 .64406 L p .707 .577 .707 r
F P
0 g
s
.8462 .70108 m .8495 .71964 L .85667 .71218 L p .707 .577 .707 r
F P
0 g
s
.85667 .71218 m .85336 .69362 L .8462 .70108 L p .707 .577 .707 r
F P
0 g
s
.65399 .7082 m .64806 .67102 L .64535 .66482 L p .707 .577 .707 r
F P
0 g
s
.64535 .66482 m .65128 .702 L .65399 .7082 L p .707 .577 .707 r
F P
0 g
s
.84674 .6371 m .85267 .67428 L .84996 .66808 L p .707 .577 .707 r
F P
0 g
s
.84996 .66808 m .84403 .6309 L .84674 .6371 L p .707 .577 .707 r
F P
0 g
s
.64456 .63695 m .6391 .58107 L .6462 .5732 L p .707 .577 .707 r
F P
0 g
s
.65855 .74945 m .65524 .73089 L .65258 .72496 L p .707 .577 .707 r
F P
0 g
s
.65258 .72496 m .65588 .74352 L .65855 .74945 L p .707 .577 .707 r
F P
0 g
s
.85336 .69362 m .85667 .71218 L .854 .70625 L p .707 .577 .707 r
F P
0 g
s
.854 .70625 m .8507 .68769 L .85336 .69362 L p .707 .577 .707 r
F P
0 g
s
.83923 .55839 m .84469 .61427 L .83221 .60862 L p .707 .577 .707 r
F P
0 g
s
.83221 .60862 m .82674 .55274 L .83923 .55839 L p .707 .577 .707 r
F P
0 g
s
.6462 .5732 m .65167 .62908 L .64456 .63695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65128 .702 m .64535 .66482 L .6525 .65726 L p .707 .577 .707 r
F P
0 g
s
.39611 .61945 m .39064 .56357 L .35962 .56479 L p .707 .577 .707 r
F P
0 g
s
.39064 .56357 m .39611 .61945 L .4278 .61585 L p .707 .577 .707 r
F P
0 g
s
.4278 .61585 m .42234 .55997 L .39064 .56357 L p .707 .577 .707 r
F P
0 g
s
.42234 .55997 m .4278 .61585 L .45708 .61024 L p .707 .577 .707 r
F P
0 g
s
.45708 .61024 m .45161 .55436 L .42234 .55997 L p .707 .577 .707 r
F P
0 g
s
.6525 .65726 m .65843 .69444 L .65128 .702 L p .707 .577 .707 r
F P
0 g
s
.65167 .62908 m .6462 .5732 L .66255 .56534 L p .707 .577 .707 r
F P
0 g
s
.84403 .6309 m .84996 .66808 L .83766 .66384 L p .707 .577 .707 r
F P
0 g
s
.83766 .66384 m .83173 .62666 L .84403 .6309 L p .707 .577 .707 r
F P
0 g
s
.36509 .62067 m .35962 .56479 L .33231 .56352 L p .707 .577 .707 r
F P
0 g
s
.35962 .56479 m .36509 .62067 L .39611 .61945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65588 .74352 m .65258 .72496 L .65974 .71749 L p .707 .577 .707 r
F P
0 g
s
.65974 .71749 m .66305 .73606 L .65588 .74352 L p .707 .577 .707 r
F P
0 g
s
.45161 .55436 m .45708 .61024 L .48106 .60316 L p .707 .577 .707 r
F P
0 g
s
.48106 .60316 m .47559 .54728 L .45161 .55436 L p .707 .577 .707 r
F P
0 g
s
.82674 .55274 m .83221 .60862 L .81129 .60498 L p .707 .577 .707 r
F P
0 g
s
.81129 .60498 m .80583 .5491 L .82674 .55274 L p .707 .577 .707 r
F P
0 g
s
.66255 .56534 m .66802 .62122 L .65167 .62908 L p .707 .577 .707 r
F P
0 g
s
.8507 .68769 m .854 .70625 L .84177 .70243 L p .707 .577 .707 r
F P
0 g
s
.84177 .70243 m .83847 .68387 L .8507 .68769 L p .707 .577 .707 r
F P
0 g
s
.40178 .68027 m .39585 .64309 L .36509 .64629 L p .707 .577 .707 r
F P
0 g
s
.39585 .64309 m .40178 .68027 L .43325 .6749 L p .707 .577 .707 r
F P
0 g
s
.43325 .6749 m .42732 .63772 L .39585 .64309 L p .707 .577 .707 r
F P
0 g
s
.33231 .56352 m .33778 .61939 L .36509 .62067 L p .707 .577 .707 r
F P
0 g
s
.42732 .63772 m .43325 .6749 L .46234 .66787 L p .707 .577 .707 r
F P
0 g
s
.46234 .66787 m .45641 .6307 L .42732 .63772 L p .707 .577 .707 r
F P
0 g
s
.33778 .61939 m .33231 .56352 L .3114 .55988 L p .707 .577 .707 r
F P
0 g
s
.65843 .69444 m .6525 .65726 L .6688 .64909 L p .707 .577 .707 r
F P
0 g
s
.36509 .64629 m .37102 .68346 L .40178 .68027 L p .707 .577 .707 r
F P
0 g
s
.37102 .68346 m .36509 .64629 L .33804 .64699 L p .707 .577 .707 r
F P
0 g
s
.66802 .62122 m .66255 .56534 L .68653 .55825 L p .707 .577 .707 r
F P
0 g
s
.45641 .6307 m .46234 .66787 L .48621 .65988 L p .707 .577 .707 r
F P
0 g
s
.48621 .65988 m .48028 .62271 L .45641 .6307 L p .707 .577 .707 r
F P
0 g
s
.47559 .54728 m .48106 .60316 L .4974 .59529 L p .707 .577 .707 r
F P
0 g
s
.4974 .59529 m .49194 .53942 L .47559 .54728 L p .707 .577 .707 r
F P
0 g
s
.6688 .64909 m .67473 .68626 L .65843 .69444 L p .707 .577 .707 r
F P
0 g
s
.40598 .72476 m .40268 .7062 L .37201 .70998 L p .707 .577 .707 r
F P
0 g
s
.40268 .7062 m .40598 .72476 L .43736 .71885 L p .707 .577 .707 r
F P
0 g
s
.43736 .71885 m .43406 .70029 L .40268 .7062 L p .707 .577 .707 r
F P
0 g
s
.83173 .62666 m .83766 .66384 L .81697 .66198 L p .707 .577 .707 r
F P
0 g
s
.81697 .66198 m .81104 .62481 L .83173 .62666 L p .707 .577 .707 r
F P
0 g
s
.33804 .64699 m .34397 .68416 L .37102 .68346 L p .707 .577 .707 r
F P
0 g
s
.43406 .70029 m .43736 .71885 L .46638 .71141 L p .707 .577 .707 r
F P
0 g
s
.46638 .71141 m .46308 .69284 L .43406 .70029 L p .707 .577 .707 r
F P
0 g
s
.3114 .55988 m .31686 .61576 L .33778 .61939 L p .707 .577 .707 r
F P
0 g
s
.37201 .70998 m .37532 .72854 L .40598 .72476 L p .707 .577 .707 r
F P
0 g
s
.66305 .73606 m .65974 .71749 L .67603 .70923 L p .707 .577 .707 r
F P
0 g
s
.80583 .5491 m .81129 .60498 L .78399 .60371 L p .707 .577 .707 r
F P
0 g
s
.78399 .60371 m .77852 .54783 L .80583 .5491 L p .707 .577 .707 r
F P
0 g
s
.37532 .72854 m .37201 .70998 L .34506 .71127 L p .707 .577 .707 r
F P
0 g
s
.67603 .70923 m .67934 .72779 L .66305 .73606 L p .707 .577 .707 r
F P
0 g
s
.68653 .55825 m .692 .61413 L .66802 .62122 L p .707 .577 .707 r
F P
0 g
s
.34397 .68416 m .33804 .64699 L .31735 .64513 L p .707 .577 .707 r
F P
0 g
s
.34506 .71127 m .34837 .72983 L .37532 .72854 L p .707 .577 .707 r
F P
0 g
s
.46308 .69284 m .46638 .71141 L .4902 .70315 L p .707 .577 .707 r
F P
0 g
s
.4902 .70315 m .4869 .68458 L .46308 .69284 L p .707 .577 .707 r
F P
0 g
s
.31686 .61576 m .3114 .55988 L .29891 .55423 L p .707 .577 .707 r
F P
0 g
s
.83847 .68387 m .84177 .70243 L .82117 .7011 L p .707 .577 .707 r
F P
0 g
s
.82117 .7011 m .81787 .68254 L .83847 .68387 L p .707 .577 .707 r
F P
0 g
s
.692 .61413 m .68653 .55825 L .7158 .55264 L p .707 .577 .707 r
F P
0 g
s
.67473 .68626 m .6688 .64909 L .69267 .6411 L p .707 .577 .707 r
F P
0 g
s
.48028 .62271 m .48621 .65988 L .50251 .65171 L p .707 .577 .707 r
F P
0 g
s
.50251 .65171 m .49659 .61453 L .48028 .62271 L p .707 .577 .707 r
F P
0 g
s
.31735 .64513 m .32328 .68231 L .34397 .68416 L p .707 .577 .707 r
F P
0 g
s
.77852 .54783 m .78399 .60371 L .75297 .60493 L p .707 .577 .707 r
F P
0 g
s
.75297 .60493 m .7475 .54905 L .77852 .54783 L p .707 .577 .707 r
F P
0 g
s
.81104 .62481 m .81697 .66198 L .78992 .66268 L p .707 .577 .707 r
F P
0 g
s
.78992 .66268 m .78399 .62551 L .81104 .62481 L p .707 .577 .707 r
F P
0 g
s
.49194 .53942 m .4974 .59529 L .50451 .58742 L p .707 .577 .707 r
F P
0 g
s
.50451 .58742 m .49904 .53155 L .49194 .53942 L p .707 .577 .707 r
F P
0 g
s
.34837 .72983 m .34506 .71127 L .32446 .70994 L p .707 .577 .707 r
F P
0 g
s
.69267 .6411 m .6986 .67827 L .67473 .68626 L p .707 .577 .707 r
F P
0 g
s
.29891 .55423 m .30438 .61011 L .31686 .61576 L p .707 .577 .707 r
F P
0 g
s
.72127 .60852 m .7158 .55264 L .7475 .54905 L p .707 .577 .707 r
F P
0 g
s
.7158 .55264 m .72127 .60852 L .692 .61413 L p .707 .577 .707 r
F P
0 g
s
.32446 .70994 m .32777 .7285 L .34837 .72983 L p .707 .577 .707 r
F P
0 g
s
.7475 .54905 m .75297 .60493 L .72127 .60852 L p .707 .577 .707 r
F P
0 g
s
.67934 .72779 m .67603 .70923 L .69985 .70096 L p .707 .577 .707 r
F P
0 g
s
.4869 .68458 m .4902 .70315 L .50649 .69488 L p .707 .577 .707 r
F P
0 g
s
.50649 .69488 m .50319 .67632 L .4869 .68458 L p .707 .577 .707 r
F P
0 g
s
.32328 .68231 m .31735 .64513 L .30505 .64089 L p .707 .577 .707 r
F P
0 g
s
.69985 .70096 m .70316 .71953 L .67934 .72779 L p .707 .577 .707 r
F P
0 g
s
.6986 .67827 m .69267 .6411 L .72176 .63407 L p .707 .577 .707 r
F P
0 g
s
.81787 .68254 m .82117 .7011 L .79422 .70239 L p .707 .577 .707 r
F P
0 g
s
.79422 .70239 m .79092 .68383 L .81787 .68254 L p .707 .577 .707 r
F P
0 g
s
.78399 .62551 m .78992 .66268 L .75916 .66588 L p .707 .577 .707 r
F P
0 g
s
.75916 .66588 m .75323 .6287 L .78399 .62551 L p .707 .577 .707 r
F P
0 g
s
.30438 .61011 m .29891 .55423 L .29609 .54712 L p .707 .577 .707 r
F P
0 g
s
.30505 .64089 m .31098 .67807 L .32328 .68231 L p .707 .577 .707 r
F P
0 g
s
.49659 .61453 m .50251 .65171 L .50966 .64415 L p .707 .577 .707 r
F P
0 g
s
.50966 .64415 m .50373 .60697 L .49659 .61453 L p .707 .577 .707 r
F P
0 g
s
.72176 .63407 m .72769 .67125 L .6986 .67827 L p .707 .577 .707 r
F P
0 g
s
.72769 .67125 m .72176 .63407 L .75323 .6287 L p .707 .577 .707 r
F P
0 g
s
.32777 .7285 m .32446 .70994 L .31223 .70612 L p .707 .577 .707 r
F P
0 g
s
.75323 .6287 m .75916 .66588 L .72769 .67125 L p .707 .577 .707 r
F P
0 g
s
.70316 .71953 m .69985 .70096 L .72887 .69352 L p .707 .577 .707 r
F P
0 g
s
.31223 .70612 m .31554 .72469 L .32777 .7285 L p .707 .577 .707 r
F P
0 g
s
.72887 .69352 m .73218 .71208 L .70316 .71953 L p .707 .577 .707 r
F P
0 g
s
.49904 .53155 m .50451 .58742 L .50168 .58032 L p .707 .577 .707 r
F P
0 g
s
.50168 .58032 m .49622 .52444 L .49904 .53155 L p .707 .577 .707 r
F P
0 g
s
.79092 .68383 m .79422 .70239 L .76355 .70618 L p .707 .577 .707 r
F P
0 g
s
.76355 .70618 m .76025 .68761 L .79092 .68383 L p .707 .577 .707 r
F P
0 g
s
.29609 .54712 m .30155 .603 L .30438 .61011 L p .707 .577 .707 r
F P
0 g
s
.50319 .67632 m .50649 .69488 L .51366 .68741 L p .707 .577 .707 r
F P
0 g
s
.51366 .68741 m .51035 .66885 L .50319 .67632 L p .707 .577 .707 r
F P
0 g
s
.73218 .71208 m .72887 .69352 L .76025 .68761 L p .707 .577 .707 r
F P
0 g
s
.76025 .68761 m .76355 .70618 L .73218 .71208 L p .707 .577 .707 r
F P
0 g
s
.31098 .67807 m .30505 .64089 L .30234 .63469 L p .707 .577 .707 r
F P
0 g
s
.30234 .63469 m .30827 .67187 L .31098 .67807 L p .707 .577 .707 r
F P
0 g
s
.30155 .603 m .29609 .54712 L .30319 .53925 L p .707 .577 .707 r
F P
0 g
s
.50373 .60697 m .50966 .64415 L .50695 .63795 L p .707 .577 .707 r
F P
0 g
s
.50695 .63795 m .50102 .60077 L .50373 .60697 L p .707 .577 .707 r
F P
0 g
s
.31554 .72469 m .31223 .70612 L .30957 .70019 L p .707 .577 .707 r
F P
0 g
s
.30957 .70019 m .31287 .71876 L .31554 .72469 L p .707 .577 .707 r
F P
0 g
s
.49622 .52444 m .50168 .58032 L .4892 .57467 L p .707 .577 .707 r
F P
0 g
s
.4892 .57467 m .48373 .51879 L .49622 .52444 L p .707 .577 .707 r
F P
0 g
s
.30319 .53925 m .30866 .59513 L .30155 .603 L p .707 .577 .707 r
F P
0 g
s
.51035 .66885 m .51366 .68741 L .51099 .68148 L p .707 .577 .707 r
F P
0 g
s
.51099 .68148 m .50769 .66292 L .51035 .66885 L p .707 .577 .707 r
F P
0 g
s
.30827 .67187 m .30234 .63469 L .30949 .62713 L p .707 .577 .707 r
F P
0 g
s
.30949 .62713 m .31542 .66431 L .30827 .67187 L p .707 .577 .707 r
F P
0 g
s
.30866 .59513 m .30319 .53925 L .31954 .53139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50102 .60077 m .50695 .63795 L .49465 .63371 L p .707 .577 .707 r
F P
0 g
s
.49465 .63371 m .48872 .59653 L .50102 .60077 L p .707 .577 .707 r
F P
0 g
s
.31287 .71876 m .30957 .70019 L .31673 .69273 L p .707 .577 .707 r
F P
0 g
s
.31673 .69273 m .32004 .71129 L .31287 .71876 L p .707 .577 .707 r
F P
0 g
s
.48373 .51879 m .4892 .57467 L .46828 .57103 L p .707 .577 .707 r
F P
0 g
s
.46828 .57103 m .46282 .51515 L .48373 .51879 L p .707 .577 .707 r
F P
0 g
s
.31954 .53139 m .32501 .58727 L .30866 .59513 L p .707 .577 .707 r
F P
0 g
s
.50769 .66292 m .51099 .68148 L .49876 .67767 L p .707 .577 .707 r
F P
0 g
s
.49876 .67767 m .49546 .6591 L .50769 .66292 L p .707 .577 .707 r
F P
0 g
s
.31542 .66431 m .30949 .62713 L .32579 .61896 L p .707 .577 .707 r
F P
0 g
s
.32501 .58727 m .31954 .53139 L .34352 .5243 L p .707 .577 .707 r
F P
0 g
s
.32579 .61896 m .33172 .65613 L .31542 .66431 L p .707 .577 .707 r
F P
0 g
s
.48872 .59653 m .49465 .63371 L .47396 .63185 L p .707 .577 .707 r
F P
0 g
s
.47396 .63185 m .46803 .59468 L .48872 .59653 L p .707 .577 .707 r
F P
0 g
s
.46282 .51515 m .46828 .57103 L .44098 .56976 L p .707 .577 .707 r
F P
0 g
s
.44098 .56976 m .43551 .51388 L .46282 .51515 L p .707 .577 .707 r
F P
0 g
s
.32004 .71129 m .31673 .69273 L .33302 .68446 L p .707 .577 .707 r
F P
0 g
s
.34352 .5243 m .34899 .58018 L .32501 .58727 L p .707 .577 .707 r
F P
0 g
s
.33302 .68446 m .33632 .70302 L .32004 .71129 L p .707 .577 .707 r
F P
0 g
s
.49546 .6591 m .49876 .67767 L .47816 .67634 L p .707 .577 .707 r
F P
0 g
s
.47816 .67634 m .47486 .65778 L .49546 .6591 L p .707 .577 .707 r
F P
0 g
s
.34899 .58018 m .34352 .5243 L .37279 .51869 L p .707 .577 .707 r
F P
0 g
s
.33172 .65613 m .32579 .61896 L .34966 .61097 L p .707 .577 .707 r
F P
0 g
s
.43551 .51388 m .44098 .56976 L .40996 .57098 L p .707 .577 .707 r
F P
0 g
s
.40996 .57098 m .40449 .5151 L .43551 .51388 L p .707 .577 .707 r
F P
0 g
s
.46803 .59468 m .47396 .63185 L .44691 .63255 L p .707 .577 .707 r
F P
0 g
s
.44691 .63255 m .44098 .59538 L .46803 .59468 L p .707 .577 .707 r
F P
0 g
s
.34966 .61097 m .35559 .64814 L .33172 .65613 L p .707 .577 .707 r
F P
0 g
s
.37826 .57457 m .37279 .51869 L .40449 .5151 L p .707 .577 .707 r
F P
0 g
s
.37279 .51869 m .37826 .57457 L .34899 .58018 L p .707 .577 .707 r
F P
0 g
s
.40449 .5151 m .40996 .57098 L .37826 .57457 L p .707 .577 .707 r
F P
0 g
s
.33632 .70302 m .33302 .68446 L .35684 .6762 L p .707 .577 .707 r
F P
0 g
s
.35684 .6762 m .36015 .69476 L .33632 .70302 L p .707 .577 .707 r
F P
0 g
s
.35559 .64814 m .34966 .61097 L .37875 .60394 L p .707 .577 .707 r
F P
0 g
s
.47486 .65778 m .47816 .67634 L .45121 .67763 L p .707 .577 .707 r
F P
0 g
s
.45121 .67763 m .44791 .65907 L .47486 .65778 L p .707 .577 .707 r
F P
0 g
s
.44098 .59538 m .44691 .63255 L .41615 .63575 L p .707 .577 .707 r
F P
0 g
s
.41615 .63575 m .41022 .59857 L .44098 .59538 L p .707 .577 .707 r
F P
0 g
s
.37875 .60394 m .38468 .64112 L .35559 .64814 L p .707 .577 .707 r
F P
0 g
s
.38468 .64112 m .37875 .60394 L .41022 .59857 L p .707 .577 .707 r
F P
0 g
s
.41022 .59857 m .41615 .63575 L .38468 .64112 L p .707 .577 .707 r
F P
0 g
s
.36015 .69476 m .35684 .6762 L .38586 .66875 L p .707 .577 .707 r
F P
0 g
s
.38586 .66875 m .38917 .68731 L .36015 .69476 L p .707 .577 .707 r
F P
0 g
s
.44791 .65907 m .45121 .67763 L .42054 .68141 L p .707 .577 .707 r
F P
0 g
s
.42054 .68141 m .41724 .66285 L .44791 .65907 L p .707 .577 .707 r
F P
0 g
s
.38917 .68731 m .38586 .66875 L .41724 .66285 L p .707 .577 .707 r
F P
0 g
s
.41724 .66285 m .42054 .68141 L .38917 .68731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
TGoo2`00PGoo0024Ool=000;FUH:001gOol007]oo`T000IJEP03001JEUYF01UJEPH0075oo`00MGoo
1P000UYF00<005YFFUH02UYF00<005YFFUH07eYF0P00Kgoo001`Ool50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0QFUH2001]Ool006eoo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF02=J
EVeoo`00JWoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
5UYFKGoo001WOol30007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00Oomoo`1ZOol006Eoo`800003FUH005YF00MJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EVaoo`00Hgoo0P000eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001QOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUI/Ool0061oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVaoo`00
Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001NOol01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<007ooOol0JGoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005mo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00
Ggoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol0061oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVYoo`00
H7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00H7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
06Moo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00H7oo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Mo
o`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Ioo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00
HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00HWoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001SOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001J
EUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF0007FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00005FUHH000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF
FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol0061oo`@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005aoo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001J
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001HOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0087oo2000?7oo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000GOol90004FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000?Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol0
05Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00;Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP06001JEUYFFUH005YF;Goo001DOol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUH000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYF001JEP0]Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05Eoo`03001JEP0000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00FUH0
0003FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE0006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000AJEP03001JEUYF00=JEP05001JEUYFFUH0000/
Ool004Mooa0000=JEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90007FUH70003FUH01@00FUIJEUYF0000;7oo0011Ool60004FUH00`00FUIJEP06
FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EPT000QJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001oogoo02Yoo`00?Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00
FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@00003
FUH0000000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUH00002FUH01P00FUIJEUYF001JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF
FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000UYF00@005YF000000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ0000AJEP8002eoo`00<Goo0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03
001JEUYF00H002ioo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF3P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000^Ool20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<00000eYF001JEP06FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00@00003FUH0000000D000EJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH00000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=J
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00=JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00AJEP03001JEUYF00=JEP@000QJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YF00001EYF00<005YF00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP04001JEP000007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002]oo`00;Goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ@000MJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0
02eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHD00000eYF001oo`0ZOol002eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6
0008FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH:0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000ZOol002ioo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP04FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF300000=JEP00FUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002Yoo`00;Woo00<005YF000015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@00003Ool0000000D000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0002Yoo`00;Woo00<005YF000015YF00<005YF
00000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001JEUYF009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH9
0002FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000[Ool002ioo`03
001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000AJEP@00003FUH005YF00MJEP03001JEUYF00AJEPL00003FUH005YF00YJEP03001JEUYF0080
0003FUH00000008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH0100025YF00<005YFFUH02EYF0`000eYF00@005YF000000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00004P00;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH=0007FUH00`00FUIJEP04FUH600000eYF001JEP07FUH00`00
FUIJEP07FUH200000eYF001JEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJ
EP04001JEUYFFUH70003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:goo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90004FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`0000=JEP00FUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YF00000UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00H000AJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00<0009JEP03001JEUYF00IJEP03001JEUYF009J
EP<000IJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH01000FUIJEUYF1@001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000002Yoo`00;Woo0P000eYF00<005YFFUH00UYF00<0
05YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000<0
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEPD00003FUH005YF00IJEP04001JEP000008
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000ZOol002moo`05001JEUYFFUH00005FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH20003FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00L000EJEP03001JEUYF00AJEP<000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00@000IJEP03001J
EUYF00MJEP03001JEUYF009JEQ<00003FUH007oo02Uoo`00<7oo0P0000=JEP00FUH015YF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00FUIJEP8000EJEP04001JEUYF
FUH20003FUH:0004FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00UYF0`0000=JEP00FUH025YF00<0
05YFFUH015YF20003Woo0P0000=JEP0000000P00:Goo000bOol400000eYF00000003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF000000040004FUH00`00FUH000070004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF008000AJEP03001J
EUYF00MJEP03001JEUYF00L0015oo`8000=JEP04001JEP00000YOol003Aoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800004FUH005YF0002FUH70003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH015YF20004goo0`001EYF
00<005YF0000:Goo000bOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP040003Ool3000COol20002
FUH00`00FUIJEP03FUH2000ZOol0031oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH40006Ool5000>Ool40005FUH01000FUIJ
EUYF0P00:goo000_Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF00000007Ool5000:Ool40002FUH00`00
FUIJEP04FUH01000FUH00000;Goo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH70008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUH005YF00001EYF0P000UYF00@005YFFUH000Moo`D000=oo`L000IJEP03001JEUYF00AJ
EP8002moo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
00=oo`D000EJEQD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF008000EJEP04001J
EP000006Ool80004FUH00`00FUIJEP07FUH01000FUIJEUYF0P00<Goo000^Ool01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH015YF10000goo10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009J
EPD000EJEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000cOol0
02moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00/000IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP0GFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000=Goo000_Ool00`00FUH0
0005FUH00`00FUIJEP03FUH40008FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0G
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Uoo`00;goo00<005YF0000
1EYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00D005YFFUIJEP0000=oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF01MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000_Ool00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH0000017oo
0eYF00<005YFFUH015YF00<005YFFUH085YF00<005YFFUH015YF2`001EYF00<005YFFUH01UYF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0049o
o`00;goo00@005YFFUH0009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EQ@000Aoo`04001JEUYF0006FUH00`00FUIJEP0JFUH=000:FUH;0004FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60016Ool002moo`03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0000800005Ool005YFFUH0000KFUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6
0004FUHD001<Ool0031oo`9JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH007oo00000UYF00<0
05YFFUH05EYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF0P0015YF00<005YFFUH00UYF1000DGoo000`Ool01EYF001JEUYF00001EYF00<005YF
FUH015YF00@005YFFUIJEP@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF00<0009JEP03001JEUYF015JEP@000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000AJEP03001JEUYF009JEP04001JEP00001AOol0031oo`80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0<FUH50002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
0005FUH01@00FUIJEUYF00000UYF00<007ooOol0Cgoo000aOol01000FUIJEP001EYF00<005YFFUH0
10001EYF00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P003EYF100025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP03001JEUYF009JEP80059oo`00<Woo0`0015YF100000=JEP00FUH01eYF00<005YFFUH015YF1`00
47oo0P0000=JEP0000000P002UYF0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF009J
EP80059oo`00=7oo1@001EYF00<005YFFUH01UYF00<005YFFUH0100057oo0`000eYF00@005YF0000
00QJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00`005=oo`00=Woo0P001eYF00<005YFFUH015YF
1P0057oo0P0000=JEP00FUH00eYF00@005YFFUH000IJEP8000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00=JEP03001JEUYF00=JEP04001JEP00001BOol003Aoo`800003FUH005YF00IJEP03001JEUYF00@0
0003Ool0000000<0019oo`8000=JEP03001JEUYF009JEP<00003OomJEUYF009JEP8000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYF001BOol003=oo`05001JEUYFFUH00006FUH4
0006Ool3000@Ool30005FUH00`00FUIJEP02FUH01000Oomoogoo0eYF00<005YF000025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001UYF00<005YFFUH00eYF00@005YF0000055oo`00<Woo0P0015YF00@005YFFUIJEP80
01Uoo`@00003FUH005YF00IJEP04001JEUYF0004Ool2FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
1eYF00<005YFFUH00eYF00@005YFFUH0055oo`00<Goo00<005YF000015YF00@005YF000001Aoo`L0
00EJEP03001JEUYF00EJEP<000Eoo`03FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEP0001<00003FUH007oo051oo`00
<Goo00<005YF00000eYF0`003goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P001goo0P00
15YF00<005YFFUH045YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
1EYF1@003Woo0P0000=JEP0000000P00D7oo000aOol01000FUH005YF0P003Woo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`004Goo0P00
0eYF00@005YF0000051oo`00<Goo00<005YF00004@001UYF00<005YFFUH01eYF00<005YFFUH015YF
0`003Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P004Woo0`001EYF00<005YF0000D7oo000aOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
000AOol20003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH4000COol20002FUH00`00FUIJEP03FUH2001AOol0035oo`80009JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD001Moo`800003FUH005YF00MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH6000017oo00000000
3goo100015YF00<005YFFUH00eYF00<007ooOol0D7oo000aOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000NOol60004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH:0006Ool5000:Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02001C
Ool0039oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Qoo`X000EJ
EP03001JEUYF00AJEP`00003FUH005YF008000]oo`D000Eoo`D000IJEP03001JEUYF00AJEP<005Eo
o`00=7oo5000>Goo30001Goo00@005YFFUH000=JEP<000eoo`D00003Ool000000080009JEP03001J
EUYF00MJEP03001JEUYF009JEP8005Moo`00TWoo00D005YFFUH005YF0080011oo`H000IJEP03001J
EUYF00MJEP03001JEP00008005Uoo`00Tgoo00<005YF00004`000eYF00<005YFFUH01eYF00<005YF
FUH015YF1000G7oo002COol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04001POol009=oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD006Aoo`00Tgoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01000JGoo002DOol200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH6001]Ool009Iooa@007=oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60532 .74278 m .5965 .68701 L .56573 .69016 L p .707 .577 .707 r
F P
0 g
s
.5965 .68701 m .60532 .74278 L .63679 .73744 L p .707 .577 .707 r
F P
0 g
s
.63679 .73744 m .62797 .68167 L .5965 .68701 L p .707 .577 .707 r
F P
0 g
s
.62797 .68167 m .63679 .73744 L .66589 .73045 L p .707 .577 .707 r
F P
0 g
s
.66589 .73045 m .65707 .67468 L .62797 .68167 L p .707 .577 .707 r
F P
0 g
s
.57455 .74593 m .56573 .69016 L .53867 .69082 L p .707 .577 .707 r
F P
0 g
s
.56573 .69016 m .57455 .74593 L .60532 .74278 L p .707 .577 .707 r
F P
0 g
s
.65707 .67468 m .66589 .73045 L .68976 .72248 L p .707 .577 .707 r
F P
0 g
s
.68976 .72248 m .68094 .66671 L .65707 .67468 L p .707 .577 .707 r
F P
0 g
s
.61424 .79761 m .60471 .76088 L .5746 .7672 L p .707 .577 .707 r
F P
0 g
s
.60471 .76088 m .61424 .79761 L .64511 .78942 L p .707 .577 .707 r
F P
0 g
s
.64511 .78942 m .63559 .75268 L .60471 .76088 L p .707 .577 .707 r
F P
0 g
s
.63559 .75268 m .64511 .78942 L .67374 .78015 L p .707 .577 .707 r
F P
0 g
s
.67374 .78015 m .66421 .74342 L .63559 .75268 L p .707 .577 .707 r
F P
0 g
s
.53867 .69082 m .54749 .74659 L .57455 .74593 L p .707 .577 .707 r
F P
0 g
s
.5746 .7672 m .58412 .80394 L .61424 .79761 L p .707 .577 .707 r
F P
0 g
s
.54749 .74659 m .53867 .69082 L .51797 .68892 L p .707 .577 .707 r
F P
0 g
s
.58412 .80394 m .5746 .7672 L .54821 .77103 L p .707 .577 .707 r
F P
0 g
s
.62094 .83517 m .61565 .81691 L .58579 .82417 L p .707 .577 .707 r
F P
0 g
s
.61565 .81691 m .62094 .83517 L .65159 .82613 L p .707 .577 .707 r
F P
0 g
s
.65159 .82613 m .64629 .80786 L .61565 .81691 L p .707 .577 .707 r
F P
0 g
s
.66421 .74342 m .67374 .78015 L .6973 .77072 L p .707 .577 .707 r
F P
0 g
s
.6973 .77072 m .68778 .73399 L .66421 .74342 L p .707 .577 .707 r
F P
0 g
s
.64629 .80786 m .65159 .82613 L .68003 .81619 L p .707 .577 .707 r
F P
0 g
s
.68003 .81619 m .67473 .79792 L .64629 .80786 L p .707 .577 .707 r
F P
0 g
s
.58579 .82417 m .59109 .84243 L .62094 .83517 L p .707 .577 .707 r
F P
0 g
s
.54821 .77103 m .55773 .80777 L .58412 .80394 L p .707 .577 .707 r
F P
0 g
s
.68094 .66671 m .68976 .72248 L .70607 .71431 L p .707 .577 .707 r
F P
0 g
s
.70607 .71431 m .69724 .65854 L .68094 .66671 L p .707 .577 .707 r
F P
0 g
s
.51797 .68892 m .5268 .74469 L .54749 .74659 L p .707 .577 .707 r
F P
0 g
s
.59109 .84243 m .58579 .82417 L .55966 .82894 L p .707 .577 .707 r
F P
0 g
s
.67473 .79792 m .68003 .81619 L .70347 .80632 L p .707 .577 .707 r
F P
0 g
s
.70347 .80632 m .69818 .78806 L .67473 .79792 L p .707 .577 .707 r
F P
0 g
s
.55966 .82894 m .56495 .8472 L .59109 .84243 L p .707 .577 .707 r
F P
0 g
s
.55773 .80777 m .54821 .77103 L .52811 .77199 L p .707 .577 .707 r
F P
0 g
s
.68778 .73399 m .6973 .77072 L .7135 .76205 L p .707 .577 .707 r
F P
0 g
s
.7135 .76205 m .70398 .72532 L .68778 .73399 L p .707 .577 .707 r
F P
0 g
s
.5268 .74469 m .51797 .68892 L .50567 .68465 L p .707 .577 .707 r
F P
0 g
s
.52811 .77199 m .53763 .80873 L .55773 .80777 L p .707 .577 .707 r
F P
0 g
s
.56495 .8472 m .55966 .82894 L .53979 .83075 L p .707 .577 .707 r
F P
0 g
s
.53979 .83075 m .54509 .84901 L .56495 .8472 L p .707 .577 .707 r
F P
0 g
s
.69724 .65854 m .70607 .71431 L .71321 .70674 L p .707 .577 .707 r
F P
0 g
s
.71321 .70674 m .70439 .65097 L .69724 .65854 L p .707 .577 .707 r
F P
0 g
s
.69818 .78806 m .70347 .80632 L .71963 .79751 L p .707 .577 .707 r
F P
0 g
s
.71963 .79751 m .71434 .77924 L .69818 .78806 L p .707 .577 .707 r
F P
0 g
s
.50567 .68465 m .51449 .74042 L .5268 .74469 L p .707 .577 .707 r
F P
0 g
s
.53763 .80873 m .52811 .77199 L .51627 .77 L p .707 .577 .707 r
F P
0 g
s
.51627 .77 m .5258 .80673 L .53763 .80873 L p .707 .577 .707 r
F P
0 g
s
.70398 .72532 m .7135 .76205 L .72075 .75499 L p .707 .577 .707 r
F P
0 g
s
.72075 .75499 m .71123 .71825 L .70398 .72532 L p .707 .577 .707 r
F P
0 g
s
.51449 .74042 m .50567 .68465 L .50296 .67843 L p .707 .577 .707 r
F P
0 g
s
.54509 .84901 m .53979 .83075 L .52814 .82943 L p .707 .577 .707 r
F P
0 g
s
.52814 .82943 m .53344 .84769 L .54509 .84901 L p .707 .577 .707 r
F P
0 g
s
.71434 .77924 m .71963 .79751 L .72693 .79059 L p .707 .577 .707 r
F P
0 g
s
.72693 .79059 m .72163 .77233 L .71434 .77924 L p .707 .577 .707 r
F P
0 g
s
.70439 .65097 m .71321 .70674 L .7105 .70052 L p .707 .577 .707 r
F P
0 g
s
.7105 .70052 m .70168 .64475 L .70439 .65097 L p .707 .577 .707 r
F P
0 g
s
.50296 .67843 m .51178 .7342 L .51449 .74042 L p .707 .577 .707 r
F P
0 g
s
.5258 .80673 m .51627 .77 L .51387 .76524 L p .707 .577 .707 r
F P
0 g
s
.51387 .76524 m .52339 .80197 L .5258 .80673 L p .707 .577 .707 r
F P
0 g
s
.71123 .71825 m .72075 .75499 L .71834 .75023 L p .707 .577 .707 r
F P
0 g
s
.71834 .75023 m .70882 .71349 L .71123 .71825 L p .707 .577 .707 r
F P
0 g
s
.53344 .84769 m .52814 .82943 L .52585 .8251 L p .707 .577 .707 r
F P
0 g
s
.51178 .7342 m .50296 .67843 L .5101 .67087 L p .707 .577 .707 r
F P
0 g
s
.52585 .8251 m .53115 .84336 L .53344 .84769 L p .707 .577 .707 r
F P
0 g
s
.72163 .77233 m .72693 .79059 L .72464 .78626 L p .707 .577 .707 r
F P
0 g
s
.72464 .78626 m .71934 .768 L .72163 .77233 L p .707 .577 .707 r
F P
0 g
s
.5101 .67087 m .51892 .72664 L .51178 .7342 L p .707 .577 .707 r
F P
0 g
s
.52339 .80197 m .51387 .76524 L .52112 .75817 L p .707 .577 .707 r
F P
0 g
s
.52112 .75817 m .53064 .79491 L .52339 .80197 L p .707 .577 .707 r
F P
0 g
s
.53064 .79491 m .52112 .75817 L .53732 .7495 L p .707 .577 .707 r
F P
0 g
s
.53182 .81586 m .45259 .31224 L .40914 .31665 L p .707 .577 .707 r
F P
0 g
s
.51892 .72664 m .5101 .67087 L .52641 .6627 L p .707 .577 .707 r
F P
0 g
s
.52641 .6627 m .53523 .71847 L .51892 .72664 L p .707 .577 .707 r
F P
0 g
s
.53732 .7495 m .54684 .78624 L .53064 .79491 L p .707 .577 .707 r
F P
0 g
s
.53523 .71847 m .52641 .6627 L .55028 .65473 L p .707 .577 .707 r
F P
0 g
s
.53844 .83645 m .53314 .81819 L .5493 .80937 L p .707 .577 .707 r
F P
0 g
s
.5493 .80937 m .5546 .82763 L .53844 .83645 L p .707 .577 .707 r
F P
0 g
s
.55028 .65473 m .5591 .7105 L .53523 .71847 L p .707 .577 .707 r
F P
0 g
s
.54684 .78624 m .53732 .7495 L .56088 .74007 L p .707 .577 .707 r
F P
0 g
s
.56088 .74007 m .5704 .77681 L .54684 .78624 L p .707 .577 .707 r
F P
0 g
s
.5546 .82763 m .5493 .80937 L .57275 .7995 L p .707 .577 .707 r
F P
0 g
s
.57275 .7995 m .57805 .81777 L .5546 .82763 L p .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .57275 .7995 L .5946 .79187 L p .707 .577 .707 r
F P
0 g
s
.5946 .79187 m .60119 .78957 L p .5964 .7954 L .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .5946 .79187 L .5964 .7954 L .707 .577 .707 r
F
.53182 .81586 m .57626 .80836 L p .55057 .7053 L F P
0 g
s
.45259 .31224 m .49824 .60244 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.49824 .60244 m .53182 .81586 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.5591 .7105 m .55028 .65473 L .57937 .64773 L p .707 .577 .707 r
F P
0 g
s
.57937 .64773 m .58819 .7035 L .5591 .7105 L p .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .56088 .74007 L .5794 .73408 L p .707 .577 .707 r
F P
0 g
s
.5794 .73408 m .58951 .73081 L p .58381 .74451 L .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .5794 .73408 L .58381 .74451 L .707 .577 .707 r
F
.49703 .30475 m .45259 .31224 L p .52665 .60934 L F P
0 g
s
.58951 .73081 m .59903 .76754 L .5704 .77681 L p .707 .577 .707 r
F P
0 g
s
.57626 .80836 m .55578 .67824 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.55578 .67824 m .49703 .30475 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.58819 .7035 m .57937 .64773 L .61085 .6424 L p .707 .577 .707 r
F P
0 g
s
.61085 .6424 m .61967 .69817 L .58819 .7035 L p .707 .577 .707 r
F P
0 g
s
.59903 .76754 m .59446 .74991 L p .62038 .72261 L .707 .577 .707 r
F P
0 g
s
.59446 .74991 m .58951 .73081 L .59261 .72998 L p .707 .577 .707 r
F P
0 g
s
.59261 .72998 m .62038 .72261 L p .59446 .74991 L .707 .577 .707 r
F P
0 g
s
.64162 .63925 m .65044 .69502 L .61967 .69817 L p .707 .577 .707 r
F P
0 g
s
.61967 .69817 m .61085 .6424 L .64162 .63925 L p .707 .577 .707 r
F P
0 g
s
.65049 .71629 m .66002 .75303 L .62991 .75935 L p .707 .577 .707 r
F P
0 g
s
.62991 .75935 m .62038 .72261 L .65049 .71629 L p .707 .577 .707 r
F P
0 g
s
.62038 .72261 m .62991 .75935 L .59903 .76754 L p .707 .577 .707 r
F P
0 g
s
.66169 .77326 m .66698 .79152 L .63713 .79878 L p .707 .577 .707 r
F P
0 g
s
.63713 .79878 m .63183 .78052 L .66169 .77326 L p .707 .577 .707 r
F P
0 g
s
.60649 .80783 m .60119 .78957 L .63183 .78052 L p .707 .577 .707 r
F P
0 g
s
.63183 .78052 m .63713 .79878 L .60649 .80783 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .65104 .78728 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.53811 .2949 m .57257 .51394 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.57257 .51394 m .61734 .79851 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.60119 .78957 m .60649 .80783 L .57805 .81777 L p .707 .577 .707 r
F P
0 g
s
.49703 .30475 m .57626 .80836 L .61734 .79851 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .53811 .2949 L .49703 .30475 L p .707 .577 .707 r
F P
0 g
s
.70168 .64475 m .7105 .70052 L .69819 .69626 L p .707 .577 .707 r
F P
0 g
s
.69819 .69626 m .68937 .64049 L .70168 .64475 L p .707 .577 .707 r
F P
0 g
s
.48837 .82027 m .40914 .31665 L .37093 .31754 L p .707 .577 .707 r
F P
0 g
s
.40914 .31665 m .48837 .82027 L .53182 .81586 L p .707 .577 .707 r
F P
0 g
s
.26231 .7106 m .25349 .65483 L .22272 .65798 L p .707 .577 .707 r
F P
0 g
s
.25349 .65483 m .26231 .7106 L .29379 .70526 L p .707 .577 .707 r
F P
0 g
s
.29379 .70526 m .28496 .64949 L .25349 .65483 L p .707 .577 .707 r
F P
0 g
s
.28496 .64949 m .29379 .70526 L .32288 .69827 L p .707 .577 .707 r
F P
0 g
s
.32288 .69827 m .31406 .6425 L .28496 .64949 L p .707 .577 .707 r
F P
0 g
s
.65104 .78728 m .57181 .28366 L .53811 .2949 L p .707 .577 .707 r
F P
0 g
s
.70882 .71349 m .71834 .75023 L .70651 .74823 L p .707 .577 .707 r
F P
0 g
s
.70651 .74823 m .69699 .7115 L .70882 .71349 L p .707 .577 .707 r
F P
0 g
s
.53115 .84336 m .52585 .8251 L .53314 .81819 L p .707 .577 .707 r
F P
0 g
s
.23154 .71375 m .22272 .65798 L .19566 .65864 L p .707 .577 .707 r
F P
0 g
s
.22272 .65798 m .23154 .71375 L .26231 .7106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.53314 .81819 m .53844 .83645 L .53115 .84336 L p .707 .577 .707 r
F P
0 g
s
.31406 .6425 m .32288 .69827 L .34675 .6903 L p .707 .577 .707 r
F P
0 g
s
.34675 .6903 m .33793 .63453 L .31406 .6425 L p .707 .577 .707 r
F P
0 g
s
.71934 .768 m .72464 .78626 L .71299 .78494 L p .707 .577 .707 r
F P
0 g
s
.71299 .78494 m .70769 .76668 L .71934 .768 L p .707 .577 .707 r
F P
0 g
s
.68937 .64049 m .69819 .69626 L .6775 .69436 L p .707 .577 .707 r
F P
0 g
s
.6775 .69436 m .66868 .63859 L .68937 .64049 L p .707 .577 .707 r
F P
0 g
s
.27123 .77162 m .2617 .73488 L .23159 .7412 L p .707 .577 .707 r
F P
0 g
s
.2617 .73488 m .27123 .77162 L .3021 .76342 L p .707 .577 .707 r
F P
0 g
s
.3021 .76342 m .29258 .72668 L .2617 .73488 L p .707 .577 .707 r
F P
0 g
s
.45016 .82116 m .37093 .31754 L .34171 .31483 L p .707 .577 .707 r
F P
0 g
s
.37093 .31754 m .45016 .82116 L .48837 .82027 L p .707 .577 .707 r
F P
0 g
s
.19566 .65864 m .20448 .71441 L .23154 .71375 L p .707 .577 .707 r
F P
0 g
s
.29258 .72668 m .3021 .76342 L .33073 .75415 L p .707 .577 .707 r
F P
0 g
s
.33073 .75415 m .32121 .71742 L .29258 .72668 L p .707 .577 .707 r
F P
0 g
s
.20448 .71441 m .19566 .65864 L .17497 .65674 L p .707 .577 .707 r
F P
0 g
s
.23159 .7412 m .24112 .77794 L .27123 .77162 L p .707 .577 .707 r
F P
0 g
s
.24112 .77794 m .23159 .7412 L .2052 .74503 L p .707 .577 .707 r
F P
0 g
s
.66868 .63859 m .6775 .69436 L .65044 .69502 L p .707 .577 .707 r
F P
0 g
s
.65044 .69502 m .64162 .63925 L .66868 .63859 L p .707 .577 .707 r
F P
0 g
s
.67689 .71246 m .68641 .74919 L .66002 .75303 L p .707 .577 .707 r
F P
0 g
s
.66002 .75303 m .65049 .71629 L .67689 .71246 L p .707 .577 .707 r
F P
0 g
s
.66698 .79152 m .66169 .77326 L .68783 .76849 L p .707 .577 .707 r
F P
0 g
s
.57181 .28366 m .65104 .78728 L .67406 .77575 L p .707 .577 .707 r
F P
0 g
s
.67406 .77575 m .59483 .27214 L .57181 .28366 L p .707 .577 .707 r
F P
0 g
s
.32121 .71742 m .33073 .75415 L .35429 .74472 L p .707 .577 .707 r
F P
0 g
s
.35429 .74472 m .34477 .70799 L .32121 .71742 L p .707 .577 .707 r
F P
0 g
s
.27794 .81785 m .27264 .79959 L .24279 .80685 L p .707 .577 .707 r
F P
0 g
s
.27264 .79959 m .27794 .81785 L .30858 .80881 L p .707 .577 .707 r
F P
0 g
s
.30858 .80881 m .30328 .79055 L .27264 .79959 L p .707 .577 .707 r
F P
0 g
s
.33793 .63453 m .34675 .6903 L .36306 .68213 L p .707 .577 .707 r
F P
0 g
s
.36306 .68213 m .35424 .62636 L .33793 .63453 L p .707 .577 .707 r
F P
0 g
s
.69699 .7115 m .70651 .74823 L .68641 .74919 L p .707 .577 .707 r
F P
0 g
s
.68641 .74919 m .67689 .71246 L .69699 .7115 L p .707 .577 .707 r
F P
0 g
s
.30328 .79055 m .30858 .80881 L .33702 .79887 L p .707 .577 .707 r
F P
0 g
s
.33702 .79887 m .33172 .78061 L .30328 .79055 L p .707 .577 .707 r
F P
0 g
s
.2052 .74503 m .21472 .78177 L .24112 .77794 L p .707 .577 .707 r
F P
0 g
s
.24279 .80685 m .24808 .82511 L .27794 .81785 L p .707 .577 .707 r
F P
0 g
s
.17497 .65674 m .18379 .71251 L .20448 .71441 L p .707 .577 .707 r
F P
0 g
s
.24808 .82511 m .24279 .80685 L .21665 .81162 L p .707 .577 .707 r
F P
0 g
s
.70769 .76668 m .71299 .78494 L .69312 .78675 L p .707 .577 .707 r
F P
0 g
s
.69312 .78675 m .68783 .76849 L .70769 .76668 L p .707 .577 .707 r
F P
0 g
s
.33172 .78061 m .33702 .79887 L .36046 .78901 L p .707 .577 .707 r
F P
0 g
s
.36046 .78901 m .35517 .77075 L .33172 .78061 L p .707 .577 .707 r
F P
0 g
s
.21665 .81162 m .22194 .82989 L .24808 .82511 L p .707 .577 .707 r
F P
0 g
s
.21472 .78177 m .2052 .74503 L .1851 .746 L p .707 .577 .707 r
F P
0 g
s
.18379 .71251 m .17497 .65674 L .16266 .65247 L p .707 .577 .707 r
F P
0 g
s
.34477 .70799 m .35429 .74472 L .37049 .73605 L p .707 .577 .707 r
F P
0 g
s
.37049 .73605 m .36097 .69932 L .34477 .70799 L p .707 .577 .707 r
F P
0 g
s
.1851 .746 m .19462 .78273 L .21472 .78177 L p .707 .577 .707 r
F P
0 g
s
.42094 .81845 m .34171 .31483 L .32433 .30878 L p .707 .577 .707 r
F P
0 g
s
.34171 .31483 m .42094 .81845 L .45016 .82116 L p .707 .577 .707 r
F P
0 g
s
.35424 .62636 m .36306 .68213 L .3702 .67456 L p .707 .577 .707 r
F P
0 g
s
.3702 .67456 m .36138 .61879 L .35424 .62636 L p .707 .577 .707 r
F P
0 g
s
.22194 .82989 m .21665 .81162 L .19678 .81344 L p .707 .577 .707 r
F P
0 g
s
.16266 .65247 m .17148 .70824 L .18379 .71251 L p .707 .577 .707 r
F P
0 g
s
.19678 .81344 m .20208 .8317 L .22194 .82989 L p .707 .577 .707 r
F P
0 g
s
.35517 .77075 m .36046 .78901 L .37663 .78019 L p .707 .577 .707 r
F P
0 g
s
.37663 .78019 m .37133 .76193 L .35517 .77075 L p .707 .577 .707 r
F P
0 g
s
.59483 .27214 m .67406 .77575 L .68415 .76507 L p .707 .577 .707 r
F P
0 g
s
.68415 .76507 m .60492 .26145 L .59483 .27214 L p .707 .577 .707 r
F P
0 g
s
.68783 .76849 m .69312 .78675 L .66698 .79152 L p .707 .577 .707 r
F P
0 g
s
.19462 .78273 m .1851 .746 L .17326 .744 L p .707 .577 .707 r
F P
0 g
s
.17326 .744 m .18279 .78074 L .19462 .78273 L p .707 .577 .707 r
F P
0 g
s
.36097 .69932 m .37049 .73605 L .37774 .72899 L p .707 .577 .707 r
F P
0 g
s
.37774 .72899 m .36822 .69226 L .36097 .69932 L p .707 .577 .707 r
F P
0 g
s
.17148 .70824 m .16266 .65247 L .15995 .64625 L p .707 .577 .707 r
F P
0 g
s
.20208 .8317 m .19678 .81344 L .18513 .81211 L p .707 .577 .707 r
F P
0 g
s
.18513 .81211 m .19043 .83037 L .20208 .8317 L p .707 .577 .707 r
F P
0 g
s
.36138 .61879 m .3702 .67456 L .36749 .66834 L p .707 .577 .707 r
F P
0 g
s
.36749 .66834 m .35867 .61257 L .36138 .61879 L p .707 .577 .707 r
F P
0 g
s
.37133 .76193 m .37663 .78019 L .38392 .77328 L p .707 .577 .707 r
F P
0 g
s
.38392 .77328 m .37862 .75501 L .37133 .76193 L p .707 .577 .707 r
F P
0 g
s
.15995 .64625 m .16877 .70202 L .17148 .70824 L p .707 .577 .707 r
F P
0 g
s
.40356 .81239 m .32433 .30878 L .3205 .29998 L p .707 .577 .707 r
F P
0 g
s
.32433 .30878 m .40356 .81239 L .42094 .81845 L p .707 .577 .707 r
F P
0 g
s
.18279 .78074 m .17326 .744 L .17086 .73924 L p .707 .577 .707 r
F P
0 g
s
.17086 .73924 m .18038 .77597 L .18279 .78074 L p .707 .577 .707 r
F P
0 g
s
.36822 .69226 m .37774 .72899 L .37534 .72423 L p .707 .577 .707 r
F P
0 g
s
.37534 .72423 m .36581 .68749 L .36822 .69226 L p .707 .577 .707 r
F P
0 g
s
.60492 .26145 m .68415 .76507 L .68031 .75627 L p .707 .577 .707 r
F P
0 g
s
.68031 .75627 m .63555 .4717 L p .60492 .26145 L .707 .577 .707 r
F P
0 g
s
.60109 .25265 m .68031 .75627 L .66294 .75022 L p .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .68541 .67899 L .66733 .67986 L p .707 .577 .707 r
F P
0 g
s
.66733 .67986 m .66531 .67996 L p .6678 .68297 L .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .66733 .67986 L .6678 .68297 L .707 .577 .707 r
F
.63555 .4717 m .60109 .25265 L .60265 .25623 L p F P
0 g
s
.60265 .25623 m .60492 .26145 L p .63555 .4717 L .707 .577 .707 r
F P
0 g
s
.16877 .70202 m .15995 .64625 L .16709 .63869 L p .707 .577 .707 r
F P
0 g
s
.19043 .83037 m .18513 .81211 L .18284 .80778 L p .707 .577 .707 r
F P
0 g
s
.18284 .80778 m .18814 .82604 L .19043 .83037 L p .707 .577 .707 r
F P
0 g
s
.37862 .75501 m .38392 .77328 L .38163 .76895 L p .707 .577 .707 r
F P
0 g
s
.38163 .76895 m .37633 .75068 L .37862 .75501 L p .707 .577 .707 r
F P
0 g
s
.35867 .61257 m .36749 .66834 L .35518 .66408 L p .707 .577 .707 r
F P
0 g
s
.35518 .66408 m .34636 .60831 L .35867 .61257 L p .707 .577 .707 r
F P
0 g
s
.16709 .63869 m .17591 .69446 L .16877 .70202 L p .707 .577 .707 r
F P
0 g
s
.18038 .77597 m .17086 .73924 L .17811 .73218 L p .707 .577 .707 r
F P
0 g
s
.17811 .73218 m .18763 .76891 L .18038 .77597 L p .707 .577 .707 r
F P
0 g
s
.36581 .68749 m .37534 .72423 L .3635 .72223 L p .707 .577 .707 r
F P
0 g
s
.3635 .72223 m .35398 .6855 L .36581 .68749 L p .707 .577 .707 r
F P
0 g
s
.3205 .29998 m .39973 .80359 L .40356 .81239 L p .707 .577 .707 r
F P
0 g
s
.39973 .80359 m .3205 .29998 L .33059 .28929 L p .707 .577 .707 r
F P
0 g
s
.17591 .69446 m .16709 .63869 L .1834 .63052 L p .707 .577 .707 r
F P
0 g
s
.18814 .82604 m .18284 .80778 L .19013 .80087 L p .707 .577 .707 r
F P
0 g
s
.19013 .80087 m .19543 .81913 L .18814 .82604 L p .707 .577 .707 r
F P
0 g
s
.34636 .60831 m .35518 .66408 L .33449 .66218 L p .707 .577 .707 r
F P
0 g
s
.33449 .66218 m .32567 .60641 L .34636 .60831 L p .707 .577 .707 r
F P
0 g
s
.37633 .75068 m .38163 .76895 L .36998 .76762 L p .707 .577 .707 r
F P
0 g
s
.36998 .76762 m .36468 .74936 L .37633 .75068 L p .707 .577 .707 r
F P
0 g
s
.1834 .63052 m .19222 .68629 L .17591 .69446 L p .707 .577 .707 r
F P
0 g
s
.66294 .75022 m .58371 .2466 L .60109 .25265 L p .707 .577 .707 r
F P
0 g
s
.18763 .76891 m .17811 .73218 L .19431 .72351 L p .707 .577 .707 r
F P
0 g
s
.19222 .68629 m .1834 .63052 L .20727 .62255 L p .707 .577 .707 r
F P
0 g
s
.19431 .72351 m .20383 .76024 L .18763 .76891 L p .707 .577 .707 r
F P
0 g
s
.35398 .6855 m .3635 .72223 L .3434 .7232 L p .707 .577 .707 r
F P
0 g
s
.3434 .7232 m .33388 .68646 L .35398 .6855 L p .707 .577 .707 r
F P
0 g
s
.32567 .60641 m .33449 .66218 L .30743 .66284 L p .707 .577 .707 r
F P
0 g
s
.30743 .66284 m .29861 .60707 L .32567 .60641 L p .707 .577 .707 r
F P
0 g
s
.19543 .81913 m .19013 .80087 L .20629 .79205 L p .707 .577 .707 r
F P
0 g
s
.20727 .62255 m .21609 .67832 L .19222 .68629 L p .707 .577 .707 r
F P
0 g
s
.20629 .79205 m .21159 .81031 L .19543 .81913 L p .707 .577 .707 r
F P
0 g
s
.36468 .74936 m .36998 .76762 L .35011 .76943 L p .707 .577 .707 r
F P
0 g
s
.35011 .76943 m .34482 .75117 L .36468 .74936 L p .707 .577 .707 r
F P
0 g
s
.40982 .79291 m .33059 .28929 L .35361 .27777 L p .707 .577 .707 r
F P
0 g
s
.33059 .28929 m .40982 .79291 L .39973 .80359 L p .707 .577 .707 r
F P
0 g
s
.21609 .67832 m .20727 .62255 L .23636 .61555 L p .707 .577 .707 r
F P
0 g
s
.20383 .76024 m .19431 .72351 L .21787 .71408 L p .707 .577 .707 r
F P
0 g
s
.29861 .60707 m .30743 .66284 L .27666 .66599 L p .707 .577 .707 r
F P
0 g
s
.27666 .66599 m .26784 .61022 L .29861 .60707 L p .707 .577 .707 r
F P
0 g
s
.33388 .68646 m .3434 .7232 L .31701 .72703 L p .707 .577 .707 r
F P
0 g
s
.31701 .72703 m .30749 .69029 L .33388 .68646 L p .707 .577 .707 r
F P
0 g
s
.21787 .71408 m .2274 .75081 L .20383 .76024 L p .707 .577 .707 r
F P
0 g
s
.58371 .2466 m .66294 .75022 L .63371 .7475 L p .707 .577 .707 r
F P
0 g
s
.63371 .7475 m .55449 .24389 L .58371 .2466 L p .707 .577 .707 r
F P
0 g
s
.74252 .65074 m .7337 .59497 L .70293 .59812 L p .707 .577 .707 r
F P
0 g
s
.7337 .59497 m .74252 .65074 L .774 .6454 L p .707 .577 .707 r
F P
0 g
s
.774 .6454 m .76518 .58963 L .7337 .59497 L p .707 .577 .707 r
F P
0 g
s
.24518 .67132 m .23636 .61555 L .26784 .61022 L p .707 .577 .707 r
F P
0 g
s
.23636 .61555 m .24518 .67132 L .21609 .67832 L p .707 .577 .707 r
F P
0 g
s
.76518 .58963 m .774 .6454 L .8031 .63841 L p .707 .577 .707 r
F P
0 g
s
.8031 .63841 m .79427 .58264 L .76518 .58963 L p .707 .577 .707 r
F P
0 g
s
.26784 .61022 m .27666 .66599 L .24518 .67132 L p .707 .577 .707 r
F P
0 g
s
.21159 .81031 m .20629 .79205 L .22974 .78219 L p .707 .577 .707 r
F P
0 g
s
.22974 .78219 m .23504 .80045 L .21159 .81031 L p .707 .577 .707 r
F P
0 g
s
.71175 .65389 m .70293 .59812 L .67587 .59878 L p .707 .577 .707 r
F P
0 g
s
.70293 .59812 m .71175 .65389 L .74252 .65074 L p .707 .577 .707 r
F P
0 g
s
.34482 .75117 m .35011 .76943 L .32397 .7742 L p .707 .577 .707 r
F P
0 g
s
.32397 .7742 m .31868 .75594 L .34482 .75117 L p .707 .577 .707 r
F P
0 g
s
.2274 .75081 m .21787 .71408 L .2465 .70481 L p .707 .577 .707 r
F P
0 g
s
.79427 .58264 m .8031 .63841 L .82696 .63044 L p .707 .577 .707 r
F P
0 g
s
.82696 .63044 m .81814 .57467 L .79427 .58264 L p .707 .577 .707 r
F P
0 g
s
.30749 .69029 m .31701 .72703 L .2869 .73335 L p .707 .577 .707 r
F P
0 g
s
.2869 .73335 m .27737 .69661 L .30749 .69029 L p .707 .577 .707 r
F P
0 g
s
.2465 .70481 m .25602 .74155 L .2274 .75081 L p .707 .577 .707 r
F P
0 g
s
.75144 .70557 m .74192 .66884 L .71181 .67516 L p .707 .577 .707 r
F P
0 g
s
.74192 .66884 m .75144 .70557 L .78232 .69738 L p .707 .577 .707 r
F P
0 g
s
.78232 .69738 m .7728 .66064 L .74192 .66884 L p .707 .577 .707 r
F P
0 g
s
.7728 .66064 m .78232 .69738 L .81094 .68811 L p .707 .577 .707 r
F P
0 g
s
.81094 .68811 m .80142 .65138 L .7728 .66064 L p .707 .577 .707 r
F P
0 g
s
.67587 .59878 m .68469 .65455 L .71175 .65389 L p .707 .577 .707 r
F P
0 g
s
.25602 .74155 m .2465 .70481 L .27737 .69661 L p .707 .577 .707 r
F P
0 g
s
.35361 .27777 m .43284 .78138 L .40982 .79291 L p .707 .577 .707 r
F P
0 g
s
.43284 .78138 m .35361 .27777 L .38731 .26653 L p .707 .577 .707 r
F P
0 g
s
.27737 .69661 m .2869 .73335 L .25602 .74155 L p .707 .577 .707 r
F P
0 g
s
.71181 .67516 m .72133 .7119 L .75144 .70557 L p .707 .577 .707 r
F P
0 g
s
.23504 .80045 m .22974 .78219 L .25818 .77225 L p .707 .577 .707 r
F P
0 g
s
.68469 .65455 m .67587 .59878 L .65518 .59688 L p .707 .577 .707 r
F P
0 g
s
.72133 .7119 m .71181 .67516 L .68541 .67899 L p .707 .577 .707 r
F P
0 g
s
.31868 .75594 m .32397 .7742 L .29412 .78147 L p .707 .577 .707 r
F P
0 g
s
.29412 .78147 m .28882 .76321 L .31868 .75594 L p .707 .577 .707 r
F P
0 g
s
.25818 .77225 m .26348 .79051 L .23504 .80045 L p .707 .577 .707 r
F P
0 g
s
.75815 .74313 m .75285 .72487 L .723 .73213 L p .707 .577 .707 r
F P
0 g
s
.75285 .72487 m .75815 .74313 L .78879 .73409 L p .707 .577 .707 r
F P
0 g
s
.78879 .73409 m .7835 .71583 L .75285 .72487 L p .707 .577 .707 r
F P
0 g
s
.80142 .65138 m .81094 .68811 L .83451 .67868 L p .707 .577 .707 r
F P
0 g
s
.83451 .67868 m .82498 .64195 L .80142 .65138 L p .707 .577 .707 r
F P
0 g
s
.7835 .71583 m .78879 .73409 L .81723 .72415 L p .707 .577 .707 r
F P
0 g
s
.81723 .72415 m .81194 .70589 L .7835 .71583 L p .707 .577 .707 r
F P
0 g
s
.723 .73213 m .7283 .75039 L .75815 .74313 L p .707 .577 .707 r
F P
0 g
s
.68541 .67899 m .69493 .71573 L .72133 .7119 L p .707 .577 .707 r
F P
0 g
s
.55449 .24389 m .63371 .7475 L .59551 .74839 L p .707 .577 .707 r
F P
0 g
s
.59551 .74839 m .51628 .24478 L .55449 .24389 L p .707 .577 .707 r
F P
0 g
s
.81814 .57467 m .82696 .63044 L .84327 .62227 L p .707 .577 .707 r
F P
0 g
s
.84327 .62227 m .83445 .5665 L .81814 .57467 L p .707 .577 .707 r
F P
0 g
s
.26348 .79051 m .25818 .77225 L .28882 .76321 L p .707 .577 .707 r
F P
0 g
s
.28882 .76321 m .29412 .78147 L .26348 .79051 L p .707 .577 .707 r
F P
0 g
s
.65518 .59688 m .664 .65265 L .68469 .65455 L p .707 .577 .707 r
F P
0 g
s
.7283 .75039 m .723 .73213 L .69686 .7369 L p .707 .577 .707 r
F P
0 g
s
.81194 .70589 m .81723 .72415 L .84068 .71429 L p .707 .577 .707 r
F P
0 g
s
.84068 .71429 m .83538 .69602 L .81194 .70589 L p .707 .577 .707 r
F P
0 g
s
.69686 .7369 m .70216 .75516 L .7283 .75039 L p .707 .577 .707 r
F P
0 g
s
.82498 .64195 m .83451 .67868 L .85071 .67001 L p .707 .577 .707 r
F P
0 g
s
.85071 .67001 m .84118 .63328 L .82498 .64195 L p .707 .577 .707 r
F P
0 g
s
.46654 .77015 m .38731 .26653 L .42839 .25668 L p .707 .577 .707 r
F P
0 g
s
.38731 .26653 m .46654 .77015 L .43284 .78138 L p .707 .577 .707 r
F P
0 g
s
.664 .65265 m .65518 .59688 L .64287 .59261 L p .707 .577 .707 r
F P
0 g
s
.66531 .67996 m .67483 .71669 L .69493 .71573 L p .707 .577 .707 r
F P
0 g
s
.70216 .75516 m .69686 .7369 L .67699 .73871 L p .707 .577 .707 r
F P
0 g
s
.51628 .24478 m .59551 .74839 L .55206 .7528 L p .707 .577 .707 r
F P
0 g
s
.55206 .7528 m .47283 .24919 L .51628 .24478 L p .707 .577 .707 r
F P
0 g
s
.67699 .73871 m .68229 .75698 L .70216 .75516 L p .707 .577 .707 r
F P
0 g
s
.83445 .5665 m .84327 .62227 L .85042 .61471 L p .707 .577 .707 r
F P
0 g
s
.85042 .61471 m .8416 .55893 L .83445 .5665 L p .707 .577 .707 r
F P
0 g
s
.83538 .69602 m .84068 .71429 L .85684 .70547 L p .707 .577 .707 r
F P
0 g
s
.85684 .70547 m .85154 .68721 L .83538 .69602 L p .707 .577 .707 r
F P
0 g
s
.64287 .59261 m .65169 .64838 L .664 .65265 L p .707 .577 .707 r
F P
0 g
s
.50762 .7603 m .42839 .25668 L .47283 .24919 L p .707 .577 .707 r
F P
0 g
s
.42839 .25668 m .50762 .7603 L .46654 .77015 L p .707 .577 .707 r
F P
0 g
s
.47283 .24919 m .55206 .7528 L .50762 .7603 L p .707 .577 .707 r
F P
0 g
s
.67483 .71669 m .66531 .67996 L .65348 .67796 L p .707 .577 .707 r
F P
0 g
s
.65348 .67796 m .663 .7147 L .67483 .71669 L p .707 .577 .707 r
F P
0 g
s
.84118 .63328 m .85071 .67001 L .85796 .66295 L p .707 .577 .707 r
F P
0 g
s
.85796 .66295 m .84844 .62622 L .84118 .63328 L p .707 .577 .707 r
F P
0 g
s
.65169 .64838 m .64287 .59261 L .64016 .58639 L p .707 .577 .707 r
F P
0 g
s
.68229 .75698 m .67699 .73871 L .66535 .73739 L p .707 .577 .707 r
F P
0 g
s
.66535 .73739 m .67064 .75565 L .68229 .75698 L p .707 .577 .707 r
F P
0 g
s
.85154 .68721 m .85684 .70547 L .86413 .69855 L p .707 .577 .707 r
F P
0 g
s
.86413 .69855 m .85883 .68029 L .85154 .68721 L p .707 .577 .707 r
F P
0 g
s
.8416 .55893 m .85042 .61471 L .8477 .60848 L p .707 .577 .707 r
F P
0 g
s
.8477 .60848 m .83888 .55271 L .8416 .55893 L p .707 .577 .707 r
F P
0 g
s
.64016 .58639 m .64898 .64216 L .65169 .64838 L p .707 .577 .707 r
F P
0 g
s
.663 .7147 m .65348 .67796 L .65107 .6732 L p .707 .577 .707 r
F P
0 g
s
.65107 .6732 m .66059 .70993 L .663 .7147 L p .707 .577 .707 r
F P
0 g
s
.84844 .62622 m .85796 .66295 L .85555 .65819 L p .707 .577 .707 r
F P
0 g
s
.85555 .65819 m .84603 .62145 L .84844 .62622 L p .707 .577 .707 r
F P
0 g
s
.67064 .75565 m .66535 .73739 L .66306 .73306 L p .707 .577 .707 r
F P
0 g
s
.64898 .64216 m .64016 .58639 L .64731 .57883 L p .707 .577 .707 r
F P
0 g
s
.66306 .73306 m .66835 .75132 L .67064 .75565 L p .707 .577 .707 r
F P
0 g
s
.85883 .68029 m .86413 .69855 L .86184 .69422 L p .707 .577 .707 r
F P
0 g
s
.86184 .69422 m .85654 .67596 L .85883 .68029 L p .707 .577 .707 r
F P
0 g
s
.83888 .55271 m .8477 .60848 L .8354 .60422 L p .707 .577 .707 r
F P
0 g
s
.8354 .60422 m .82658 .54845 L .83888 .55271 L p .707 .577 .707 r
F P
0 g
s
.64731 .57883 m .65613 .6346 L .64898 .64216 L p .707 .577 .707 r
F P
0 g
s
.66059 .70993 m .65107 .6732 L .65832 .66614 L p .707 .577 .707 r
F P
0 g
s
.39951 .61856 m .39069 .56279 L .35992 .56594 L p .707 .577 .707 r
F P
0 g
s
.39069 .56279 m .39951 .61856 L .43099 .61322 L p .707 .577 .707 r
F P
0 g
s
.43099 .61322 m .42217 .55745 L .39069 .56279 L p .707 .577 .707 r
F P
0 g
s
.42217 .55745 m .43099 .61322 L .46009 .60623 L p .707 .577 .707 r
F P
0 g
s
.46009 .60623 m .45126 .55046 L .42217 .55745 L p .707 .577 .707 r
F P
0 g
s
.65832 .66614 m .66784 .70287 L .66059 .70993 L p .707 .577 .707 r
F P
0 g
s
.84603 .62145 m .85555 .65819 L .84372 .65619 L p .707 .577 .707 r
F P
0 g
s
.84372 .65619 m .83419 .61946 L .84603 .62145 L p .707 .577 .707 r
F P
0 g
s
.65613 .6346 m .64731 .57883 L .66361 .57066 L p .707 .577 .707 r
F P
0 g
s
.66835 .75132 m .66306 .73306 L .67035 .72615 L p .707 .577 .707 r
F P
0 g
s
.36874 .62171 m .35992 .56594 L .33286 .5666 L p .707 .577 .707 r
F P
0 g
s
.35992 .56594 m .36874 .62171 L .39951 .61856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67035 .72615 m .67565 .74441 L .66835 .75132 L p .707 .577 .707 r
F P
0 g
s
.45126 .55046 m .46009 .60623 L .48395 .59826 L p .707 .577 .707 r
F P
0 g
s
.48395 .59826 m .47513 .54249 L .45126 .55046 L p .707 .577 .707 r
F P
0 g
s
.85654 .67596 m .86184 .69422 L .85019 .6929 L p .707 .577 .707 r
F P
0 g
s
.85019 .6929 m .8449 .67464 L .85654 .67596 L p .707 .577 .707 r
F P
0 g
s
.82658 .54845 m .8354 .60422 L .8147 .60232 L p .707 .577 .707 r
F P
0 g
s
.8147 .60232 m .80588 .54655 L .82658 .54845 L p .707 .577 .707 r
F P
0 g
s
.66361 .57066 m .67243 .62643 L .65613 .6346 L p .707 .577 .707 r
F P
0 g
s
.40843 .67958 m .39891 .64284 L .3688 .64916 L p .707 .577 .707 r
F P
0 g
s
.39891 .64284 m .40843 .67958 L .43931 .67138 L p .707 .577 .707 r
F P
0 g
s
.43931 .67138 m .42979 .63465 L .39891 .64284 L p .707 .577 .707 r
F P
0 g
s
.33286 .5666 m .34168 .62237 L .36874 .62171 L p .707 .577 .707 r
F P
0 g
s
.42979 .63465 m .43931 .67138 L .46793 .66212 L p .707 .577 .707 r
F P
0 g
s
.46793 .66212 m .45841 .62538 L .42979 .63465 L p .707 .577 .707 r
F P
0 g
s
.34168 .62237 m .33286 .5666 L .31217 .5647 L p .707 .577 .707 r
F P
0 g
s
.3688 .64916 m .37832 .6859 L .40843 .67958 L p .707 .577 .707 r
F P
0 g
s
.66784 .70287 m .65832 .66614 L .67452 .65747 L p .707 .577 .707 r
F P
0 g
s
.37832 .6859 m .3688 .64916 L .3424 .65299 L p .707 .577 .707 r
F P
0 g
s
.45841 .62538 m .46793 .66212 L .4915 .65269 L p .707 .577 .707 r
F P
0 g
s
.4915 .65269 m .48197 .61595 L .45841 .62538 L p .707 .577 .707 r
F P
0 g
s
.41514 .72581 m .40984 .70755 L .37999 .71481 L p .707 .577 .707 r
F P
0 g
s
.40984 .70755 m .41514 .72581 L .44578 .71677 L p .707 .577 .707 r
F P
0 g
s
.44578 .71677 m .44049 .69851 L .40984 .70755 L p .707 .577 .707 r
F P
0 g
s
.67452 .65747 m .68404 .6942 L .66784 .70287 L p .707 .577 .707 r
F P
0 g
s
.47513 .54249 m .48395 .59826 L .50026 .59009 L p .707 .577 .707 r
F P
0 g
s
.50026 .59009 m .49144 .53432 L .47513 .54249 L p .707 .577 .707 r
F P
0 g
s
.83419 .61946 m .84372 .65619 L .82362 .65716 L p .707 .577 .707 r
F P
0 g
s
.82362 .65716 m .8141 .62042 L .83419 .61946 L p .707 .577 .707 r
F P
0 g
s
.67243 .62643 m .66361 .57066 L .68748 .56269 L p .707 .577 .707 r
F P
0 g
s
.44049 .69851 m .44578 .71677 L .47422 .70683 L p .707 .577 .707 r
F P
0 g
s
.47422 .70683 m .46893 .68857 L .44049 .69851 L p .707 .577 .707 r
F P
0 g
s
.3424 .65299 m .35192 .68973 L .37832 .6859 L p .707 .577 .707 r
F P
0 g
s
.37999 .71481 m .38529 .73308 L .41514 .72581 L p .707 .577 .707 r
F P
0 g
s
.31217 .5647 m .32099 .62047 L .34168 .62237 L p .707 .577 .707 r
F P
0 g
s
.67565 .74441 m .67035 .72615 L .68651 .71733 L p .707 .577 .707 r
F P
0 g
s
.80588 .54655 m .8147 .60232 L .78765 .60298 L p .707 .577 .707 r
F P
0 g
s
.78765 .60298 m .77882 .54721 L .80588 .54655 L p .707 .577 .707 r
F P
0 g
s
.68651 .71733 m .69181 .73559 L .67565 .74441 L p .707 .577 .707 r
F P
0 g
s
.38529 .73308 m .37999 .71481 L .35385 .71959 L p .707 .577 .707 r
F P
0 g
s
.8449 .67464 m .85019 .6929 L .83033 .69471 L p .707 .577 .707 r
F P
0 g
s
.83033 .69471 m .82503 .67645 L .8449 .67464 L p .707 .577 .707 r
F P
0 g
s
.46893 .68857 m .47422 .70683 L .49767 .69697 L p .707 .577 .707 r
F P
0 g
s
.49767 .69697 m .49237 .67871 L .46893 .68857 L p .707 .577 .707 r
F P
0 g
s
.35385 .71959 m .35915 .73785 L .38529 .73308 L p .707 .577 .707 r
F P
0 g
s
.68748 .56269 m .6963 .61846 L .67243 .62643 L p .707 .577 .707 r
F P
0 g
s
.35192 .68973 m .3424 .65299 L .3223 .65396 L p .707 .577 .707 r
F P
0 g
s
.32099 .62047 m .31217 .5647 L .29986 .56043 L p .707 .577 .707 r
F P
0 g
s
.48197 .61595 m .4915 .65269 L .5077 .64402 L p .707 .577 .707 r
F P
0 g
s
.5077 .64402 m .49818 .60728 L .48197 .61595 L p .707 .577 .707 r
F P
0 g
s
.3223 .65396 m .33182 .69069 L .35192 .68973 L p .707 .577 .707 r
F P
0 g
s
.68404 .6942 m .67452 .65747 L .69809 .64804 L p .707 .577 .707 r
F P
0 g
s
.6963 .61846 m .68748 .56269 L .71658 .55569 L p .707 .577 .707 r
F P
0 g
s
.77882 .54721 m .78765 .60298 L .75687 .60613 L p .707 .577 .707 r
F P
0 g
s
.75687 .60613 m .74805 .55036 L .77882 .54721 L p .707 .577 .707 r
F P
0 g
s
.8141 .62042 m .82362 .65716 L .79722 .66099 L p .707 .577 .707 r
F P
0 g
s
.79722 .66099 m .7877 .62425 L .8141 .62042 L p .707 .577 .707 r
F P
0 g
s
.69809 .64804 m .70761 .68477 L .68404 .6942 L p .707 .577 .707 r
F P
0 g
s
.49144 .53432 m .50026 .59009 L .50741 .58253 L p .707 .577 .707 r
F P
0 g
s
.50741 .58253 m .49859 .52676 L .49144 .53432 L p .707 .577 .707 r
F P
0 g
s
.35915 .73785 m .35385 .71959 L .33398 .7214 L p .707 .577 .707 r
F P
0 g
s
.29986 .56043 m .30868 .6162 L .32099 .62047 L p .707 .577 .707 r
F P
0 g
s
.33398 .7214 m .33928 .73966 L .35915 .73785 L p .707 .577 .707 r
F P
0 g
s
.49237 .67871 m .49767 .69697 L .51383 .68815 L p .707 .577 .707 r
F P
0 g
s
.51383 .68815 m .50853 .66989 L .49237 .67871 L p .707 .577 .707 r
F P
0 g
s
.7254 .61146 m .71658 .55569 L .74805 .55036 L p .707 .577 .707 r
F P
0 g
s
.71658 .55569 m .7254 .61146 L .6963 .61846 L p .707 .577 .707 r
F P
0 g
s
.69181 .73559 m .68651 .71733 L .70996 .70747 L p .707 .577 .707 r
F P
0 g
s
.74805 .55036 m .75687 .60613 L .7254 .61146 L p .707 .577 .707 r
F P
0 g
s
.70996 .70747 m .71525 .72573 L .69181 .73559 L p .707 .577 .707 r
F P
0 g
s
.82503 .67645 m .83033 .69471 L .80419 .69948 L p .707 .577 .707 r
F P
0 g
s
.80419 .69948 m .79889 .68122 L .82503 .67645 L p .707 .577 .707 r
F P
0 g
s
.33182 .69069 m .3223 .65396 L .31047 .65196 L p .707 .577 .707 r
F P
0 g
s
.70761 .68477 m .69809 .64804 L .72671 .63877 L p .707 .577 .707 r
F P
0 g
s
.7877 .62425 m .79722 .66099 L .76711 .66731 L p .707 .577 .707 r
F P
0 g
s
.76711 .66731 m .75759 .63057 L .7877 .62425 L p .707 .577 .707 r
F P
0 g
s
.31047 .65196 m .31999 .6887 L .33182 .69069 L p .707 .577 .707 r
F P
0 g
s
.49818 .60728 m .5077 .64402 L .51495 .63695 L p .707 .577 .707 r
F P
0 g
s
.51495 .63695 m .50543 .60022 L .49818 .60728 L p .707 .577 .707 r
F P
0 g
s
.72671 .63877 m .73623 .67551 L .70761 .68477 L p .707 .577 .707 r
F P
0 g
s
.30868 .6162 m .29986 .56043 L .29715 .55421 L p .707 .577 .707 r
F P
0 g
s
.73623 .67551 m .72671 .63877 L .75759 .63057 L p .707 .577 .707 r
F P
0 g
s
.71525 .72573 m .70996 .70747 L .73839 .69753 L p .707 .577 .707 r
F P
0 g
s
.75759 .63057 m .76711 .66731 L .73623 .67551 L p .707 .577 .707 r
F P
0 g
s
.33928 .73966 m .33398 .7214 L .32234 .72007 L p .707 .577 .707 r
F P
0 g
s
.79889 .68122 m .80419 .69948 L .77434 .70675 L p .707 .577 .707 r
F P
0 g
s
.77434 .70675 m .76904 .68848 L .79889 .68122 L p .707 .577 .707 r
F P
0 g
s
.73839 .69753 m .74369 .71579 L .71525 .72573 L p .707 .577 .707 r
F P
0 g
s
.32234 .72007 m .32763 .73834 L .33928 .73966 L p .707 .577 .707 r
F P
0 g
s
.49859 .52676 m .50741 .58253 L .50469 .5763 L p .707 .577 .707 r
F P
0 g
s
.50469 .5763 m .49587 .52053 L .49859 .52676 L p .707 .577 .707 r
F P
0 g
s
.50853 .66989 m .51383 .68815 L .52112 .68124 L p .707 .577 .707 r
F P
0 g
s
.52112 .68124 m .51582 .66298 L .50853 .66989 L p .707 .577 .707 r
F P
0 g
s
.29715 .55421 m .30597 .60998 L .30868 .6162 L p .707 .577 .707 r
F P
0 g
s
.74369 .71579 m .73839 .69753 L .76904 .68848 L p .707 .577 .707 r
F P
0 g
s
.76904 .68848 m .77434 .70675 L .74369 .71579 L p .707 .577 .707 r
F P
0 g
s
.31999 .6887 m .31047 .65196 L .30806 .6472 L p .707 .577 .707 r
F P
0 g
s
.30806 .6472 m .31758 .68393 L .31999 .6887 L p .707 .577 .707 r
F P
0 g
s
.50543 .60022 m .51495 .63695 L .51254 .63219 L p .707 .577 .707 r
F P
0 g
s
.51254 .63219 m .50302 .59546 L .50543 .60022 L p .707 .577 .707 r
F P
0 g
s
.30597 .60998 m .29715 .55421 L .3043 .54665 L p .707 .577 .707 r
F P
0 g
s
.32763 .73834 m .32234 .72007 L .32005 .71574 L p .707 .577 .707 r
F P
0 g
s
.32005 .71574 m .32534 .73401 L .32763 .73834 L p .707 .577 .707 r
F P
0 g
s
.51582 .66298 m .52112 .68124 L .51883 .67691 L p .707 .577 .707 r
F P
0 g
s
.51883 .67691 m .51353 .65864 L .51582 .66298 L p .707 .577 .707 r
F P
0 g
s
.49587 .52053 m .50469 .5763 L .49239 .57204 L p .707 .577 .707 r
F P
0 g
s
.49239 .57204 m .48357 .51627 L .49587 .52053 L p .707 .577 .707 r
F P
0 g
s
.3043 .54665 m .31312 .60242 L .30597 .60998 L p .707 .577 .707 r
F P
0 g
s
.31758 .68393 m .30806 .6472 L .31531 .64014 L p .707 .577 .707 r
F P
0 g
s
.31531 .64014 m .32483 .67687 L .31758 .68393 L p .707 .577 .707 r
F P
0 g
s
.50302 .59546 m .51254 .63219 L .50071 .63019 L p .707 .577 .707 r
F P
0 g
s
.50071 .63019 m .49118 .59346 L .50302 .59546 L p .707 .577 .707 r
F P
0 g
s
.31312 .60242 m .3043 .54665 L .3206 .53848 L p .707 .577 .707 r
F P
0 g
s
.32534 .73401 m .32005 .71574 L .32734 .70883 L p .707 .577 .707 r
F P
0 g
s
.32734 .70883 m .33263 .72709 L .32534 .73401 L p .707 .577 .707 r
F P
0 g
s
.48357 .51627 m .49239 .57204 L .47169 .57014 L p .707 .577 .707 r
F P
0 g
s
.47169 .57014 m .46287 .51437 L .48357 .51627 L p .707 .577 .707 r
F P
0 g
s
.51353 .65864 m .51883 .67691 L .50718 .67558 L p .707 .577 .707 r
F P
0 g
s
.50718 .67558 m .50189 .65732 L .51353 .65864 L p .707 .577 .707 r
F P
0 g
s
.3206 .53848 m .32942 .59425 L .31312 .60242 L p .707 .577 .707 r
F P
0 g
s
.32483 .67687 m .31531 .64014 L .33151 .63147 L p .707 .577 .707 r
F P
0 g
s
.32942 .59425 m .3206 .53848 L .34447 .53051 L p .707 .577 .707 r
F P
0 g
s
.33151 .63147 m .34103 .6682 L .32483 .67687 L p .707 .577 .707 r
F P
0 g
s
.49118 .59346 m .50071 .63019 L .48061 .63116 L p .707 .577 .707 r
F P
0 g
s
.48061 .63116 m .47109 .59442 L .49118 .59346 L p .707 .577 .707 r
F P
0 g
s
.46287 .51437 m .47169 .57014 L .44464 .5708 L p .707 .577 .707 r
F P
0 g
s
.44464 .5708 m .43581 .51503 L .46287 .51437 L p .707 .577 .707 r
F P
0 g
s
.33263 .72709 m .32734 .70883 L .3435 .70001 L p .707 .577 .707 r
F P
0 g
s
.34447 .53051 m .35329 .58628 L .32942 .59425 L p .707 .577 .707 r
F P
0 g
s
.3435 .70001 m .34879 .71827 L .33263 .72709 L p .707 .577 .707 r
F P
0 g
s
.50189 .65732 m .50718 .67558 L .48732 .6774 L p .707 .577 .707 r
F P
0 g
s
.48732 .6774 m .48202 .65913 L .50189 .65732 L p .707 .577 .707 r
F P
0 g
s
.35329 .58628 m .34447 .53051 L .37357 .52351 L p .707 .577 .707 r
F P
0 g
s
.34103 .6682 m .33151 .63147 L .35508 .62204 L p .707 .577 .707 r
F P
0 g
s
.43581 .51503 m .44464 .5708 L .41386 .57395 L p .707 .577 .707 r
F P
0 g
s
.41386 .57395 m .40504 .51818 L .43581 .51503 L p .707 .577 .707 r
F P
0 g
s
.47109 .59442 m .48061 .63116 L .45421 .63499 L p .707 .577 .707 r
F P
0 g
s
.45421 .63499 m .44469 .59825 L .47109 .59442 L p .707 .577 .707 r
F P
0 g
s
.35508 .62204 m .3646 .65877 L .34103 .6682 L p .707 .577 .707 r
F P
0 g
s
.38239 .57928 m .37357 .52351 L .40504 .51818 L p .707 .577 .707 r
F P
0 g
s
.37357 .52351 m .38239 .57928 L .35329 .58628 L p .707 .577 .707 r
F P
0 g
s
.40504 .51818 m .41386 .57395 L .38239 .57928 L p .707 .577 .707 r
F P
0 g
s
.34879 .71827 m .3435 .70001 L .36694 .69015 L p .707 .577 .707 r
F P
0 g
s
.36694 .69015 m .37224 .70841 L .34879 .71827 L p .707 .577 .707 r
F P
0 g
s
.48202 .65913 m .48732 .6774 L .46118 .68217 L p .707 .577 .707 r
F P
0 g
s
.46118 .68217 m .45588 .6639 L .48202 .65913 L p .707 .577 .707 r
F P
0 g
s
.3646 .65877 m .35508 .62204 L .3837 .61277 L p .707 .577 .707 r
F P
0 g
s
.44469 .59825 m .45421 .63499 L .4241 .64131 L p .707 .577 .707 r
F P
0 g
s
.4241 .64131 m .41458 .60458 L .44469 .59825 L p .707 .577 .707 r
F P
0 g
s
.3837 .61277 m .39322 .64951 L .3646 .65877 L p .707 .577 .707 r
F P
0 g
s
.39322 .64951 m .3837 .61277 L .41458 .60458 L p .707 .577 .707 r
F P
0 g
s
.41458 .60458 m .4241 .64131 L .39322 .64951 L p .707 .577 .707 r
F P
0 g
s
.37224 .70841 m .36694 .69015 L .39538 .68021 L p .707 .577 .707 r
F P
0 g
s
.45588 .6639 m .46118 .68217 L .43132 .68943 L p .707 .577 .707 r
F P
0 g
s
.43132 .68943 m .42603 .67117 L .45588 .6639 L p .707 .577 .707 r
F P
0 g
s
.39538 .68021 m .40068 .69847 L .37224 .70841 L p .707 .577 .707 r
F P
0 g
s
.40068 .69847 m .39538 .68021 L .42603 .67117 L p .707 .577 .707 r
F P
0 g
s
.42603 .67117 m .43132 .68943 L .40068 .69847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
SGoo5000O7oo0024Ool9000DFUH7001eOol0081oo`@0009JEP03001JEUYF01mJEP<0079oo`00O7oo
10001UYF00<005YFFUH08UYF00<007ooOol0Kgoo001gOol5000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool0075oo`H0009JEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06moo`00KGoo1000
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Kgoo001[Ool200000eYF001JEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1_Ool006Qoo`<000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06moo`00IWoo0P001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00L7oo001SOol30009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP04FUI`Ool0065oo`800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEW1oo`00Ggoo0P00
0eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KWoo001MOol20005FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005aoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Kgoo001KOol0
0`00FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06eoo`00G7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo
001LOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001^Ool005aoo`03001JEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006ioo`00G7oo00@005YFFUH000IJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH2001^Ool005aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVioo`00G7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVioo`00GGoo00<0
05YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`03001JEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP03001JEUYF009JEP8006eoo`00GGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001]Ool005eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00KGoo001MOol01000
FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFKGoo001MOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001/Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006aoo`00GWoo00@0
05YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001/Ool005ioo`04001JEUYF0006FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUI/Ool005moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00Ggoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001O
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EV]oo`00H7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JWoo001POol00`00
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001ZOol0061oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00JWoo001POol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Yoo`00H7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Qoo`00H7oo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Qoo`00
HGoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00<005YF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Qo
o`00HWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo
00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0007FUH0
0`00FUIJEP06FUHB0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`03001JEP0000MJEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Eoo`00
IGoo00<005YFFUH01`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001UOol0
06Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001UOol0065oo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol005moo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1SOol005eoo`80009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00FWoo0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF0P00I7oo001HOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0087oo4P00<Woo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol05goo1`0015YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol04goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001DOol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80011oo`@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8000aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYF001JEP0]Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20008Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUIJEP00FUH0;Goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUIJEP00FUH0;Goo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001EOol01000FUIJ
EP000eYF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004
FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001J
EP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000AJEP04001JEP00
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00000eYF0P0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF1`000UYF00@005YF000000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000/
Ool005Ioo`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH9
0003FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002aoo`00EWoo0eYF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF
001JEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUHB0002
FUH2000[Ool0055oo`D00005FUH00000FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH30000
0eYF001JEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP05FUH01000FUIJEUYF1000:goo001:Ool70003
FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF0`0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002]oo`00AWoo10000UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00@0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo0011Ool50006FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH0
05YF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002aoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH>000/
Ool003Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<000UJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YF
FUH00eYF00@005YFFUH002aoo`00=Woo0`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00AJEP80009JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP07FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:goo000cOol30004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF3@001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00D000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0035o
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEP03001JEUYF
009JEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005
FUH00`00FUIJEP05FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00:Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YFFUH00UYF00<005YFFUH01EYF00H005YF0000
05YF0009FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<0009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000ZOol002eoo`04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YF000005YF0005FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP@0009J
EP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF000ZOol002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol09goo000]Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF1`00
0UYF00@005YF000000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
009JEP@002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF2@001EYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP@000MJEP03001JEUYF00EJEP03001JEUYF009JEP8002Yoo`00;Woo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00AJEP03001JEP0000AJEP<000MJ
EP03001JEUYF00IJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`0YOol002ioo`04001JEUYF0003FUH00`00FUIJEP05FUH0
0`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00AJEP80
0003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002]oo`00;Woo00@005YFFUH000AJEP03001JEUYF00=J
EPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00AJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00MJEP04001JEUYFFUH>0004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF1000
25YF00<005YFFUH01UYF00<005YF00001P000UYF00@005YF000002Uoo`00;Woo00@005YFFUH000AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH50003FUH20005FUH0
1000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP04001JEUYFFUH60003FUH00`00
FUIJEP03FUH00`00FUIJEP02000XOol002ioo`04001JEUYF0004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF00EJEP06001J
EP00001JEP002EYF00<005YFFUH00UYF0`001EYF0`0000=JEP00FUH01EYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF10001eYF
00<005YFFUH01eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00:7oo000^
Ool01@00FUIJEUYF00000eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEP0000800003
FUH005YF009JEP<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000XOol002mo
o`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP0600000eYF0000000<0007FUH00`00FUIJEP04FUH40005FUH300000eYF001JEP05FUH01000FUIJ
EUYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002Moo`00;goo0eYF0P001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
1eYF00<005YFFUH010001eYF0`000eYF00<005YFFUH01EYF0`002EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH015YF0P000UYF00@005YFFUIJEP<000MJEP03001JEUYF00EJEP<000EJEP03
001JEUYF00IJEP03001JEUYF009JEPd002Moo`00;goo00EJEP00001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH01EYF10000eYF00<005YFFUH00UYF0`001UYF00<005YFFUH015YF0P0035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF0080009JEP03001JEUYF00IJEP04
001JEUYFFUH30008FUH00`00FUIJEP05FUH600001Goo000005YF00001EYF00<005YF00009goo000_
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH400000eYF001JEP08FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00UYF0`001UYF00<005YF00000P0000=JEP00
FUH01eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000EJEP03001JEUYF00EJEP06001JEP00001JEP002UYF00<005YFFUH0
10001Goo0P000eYF00<005YFFUH00eYF0P00:7oo000_Ool20003FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF0000
0P000UYF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP06FUH40006Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0
031oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP80009oo`04001JEUYF0002FUH30008FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP02FUH01000FUIJEUYF0`001eYF00<005YFFUH00eYF0`0027oo0P0000=J
EP00FUH01UYF00<005YFFUH00P00:Woo000bOol50003FUH01000FUIJEUYF100015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000P0015YF00<005YFFUH00UYF10000Woo00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF0`0000=JEP00FUH025YF00<005YF00000P00
27oo0`0015YF00<005YFFUH015YF0`00;7oo000gOol80008FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH20002FUH00`00FUIJEP03FUH01000FUH000000UYF1P001UYF00<005YFFUH01EYF100000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
000020001EYF00<005YFFUH01EYF0`0027oo0`001eYF00<005YFFUH00eYF0P00;Woo000iOol30000
0eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUIJEUYF1`000eYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEPD000IJEP03001JEUYF00=JEPD000Eo
o`<00003FUH005YF00QJEP03001JEP000080031oo`00=goo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01eYF0P000UYF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP05FUH00`00FUH000070002Ool3
0005FUH00`00FUIJEP05FUH3000cOol003Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP@0009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0004FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP03FUH2000fOol003=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000005FUH01000
FUIJEUYF100017oo100000=JEP00FUH02EYF00<005YF00000P00>7oo000bOol00`00FUIJEP03FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50008FUH200000eYF001JEP05FUH01000
FUIJEUYF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00UYF00@005YF0000
009JEPH000IJEP03001JEUYF00IJEP<003]oo`00<Goo0P001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH010001EYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF1P0017oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00AJEP80009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00=JEP<003ioo`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000QJEP03
001JEUYF00IJEP03001JEP0000D00003FUH0000000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEUYF001JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP000080045o
o`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8000Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2
0002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30014Ool0035oo`03001JEP0000AJEP03
001JEUYF00EJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000]oo`=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEQ8000AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00@004Moo`00<Goo00<005YF
000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo0eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH05UYF00@005YFFUIJEPH000MJEP03001JEUYF00MJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF009JEPH004]oo`00<Goo00@005YFFUH000AJEP04001J
EUYFFUH20003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP02FUH00`00FUIJEP020003Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH055YF1P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0000=JEP00FUH00UYF2000D7oo000a
Ool01000FUIJEP0015YF00@005YF000000EJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00
001JEP001eYF00<005YFFUH00eYF00@005YFFUH000=oo`04001JEUYF0007FUH00`00FUIJEP0GFUH6
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000050004FUH2001A
Ool0039oo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF0080009oo`05001JEUYFFUH00006FUH00`00FUIJEP0A
FUH7000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00Oomoo`1@Ool0039oo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009oo`05001JEUYFFUH00006FUH00`00FUIJEP0;FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0005=oo`00<Woo
00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01UYF10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF300000=oo`00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P0035YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00002`00D7oo000b
Ool01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH00UYF10001UYF00<005YFFUH01eYF
00<005YF00000`0000=oo`0000001EYF00@005YFFUH0009oo`=JEP03001JEUYF00]JEP8000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80
009JEP03001JEUYF00=JEP03001JEUYF008004moo`00<goo00@005YFFUH000EJEP03001JEUYF00EJ
EP06001JEP00001JEP002EYF00<005YFFUH015YF10000Woo0`0000=JEP00FUH01EYF0P000goo0eYF
00<005YFFUH02EYF0P001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00P00Cgoo000c
Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEUYF00@000=o
o`<000EJEP03001JEUYF00=JEP03001oogoo009oo`04001JEUYF0009FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P001EYF00<005YF
FUH00eYF00@005YFFUH004moo`00<goo40001eYF00<005YFFUH015YF1@001Goo0P0000=JEP00FUH0
1EYF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000008FUH00`00FUIJEP02FUH00`00FUIJEP02
001>Ool003ioo`800003FUH005YF00MJEP03001JEUYF00@000Moo`<000=JEP03001JEUYF00EJEP<0
00Moo`03001JEUYF00EJEP8000=JEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP<0009JEP03001JEUYF00AJEP/004ioo`00?7oo0P000eYF00<0
05YFFUH01EYF100027oo0`001UYF00<005YFFUH015YF0P002Goo00<005YFFUH00eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF0P00
1EYF00<005YFFUH0100000=oo`0000001EYF00<005YF0000CWoo000jOol20006FUH00`00FUIJEP02
FUH20009Ool300000eYF001JEP07FUH01000FUIJEUYF0P0037oo0eYF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEP<000IJEP@00003Ool0
000000800003FUH005YF00AJEP8004moo`00>7oo0`001eYF00<005YF00000P0027oo0`0015YF00<0
05YFFUH01UYF00@005YF000000ioo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH000000UYF00<005YFFUH010000Woo0`001EYF
00<005YFFUH00eYF00<007ooOol0CWoo000fOol20003FUH00`00FUIJEP04FUH20008Ool30008FUH0
0`00FUIJEP04FUH3000@Ool00eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0GFUH00`00FUIJ
EP07FUH40002FUH50004Ool200000eYF001JEP06FUH00`00FUIJEP02001AOol003Aoo`<000AJEP03
001JEUYF009JEP8000Ioo`@00003FUH005YF00QJEP03001JEUYF00@001=oo`8000]JEP03001JEUYF
00QJEP03001JEUYF01MJEP04001JEUYFFUH60002FUH40006Ool30004FUH00`00FUIJEP04FUH3001C
Ool003=oo`04001JEUYF0005FUH01000FUH000000Woo1P001UYF00<005YFFUH01EYF10005goo0P00
15YF00<005YFFUH07EYF00<005YFFUH01eYF1P0015YF10001goo0`001eYF00<005YFFUH015YF00<0
07ooOol0Dgoo000cOol01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0077oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YF
FUIJEPH0009JEP03001JEUYF00=JEP@000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEP8005Io
o`00=7oo00D005YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
01ioo`<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEPL00003FUH005YF00IJ
EP03001JEP0000L0009oo`<000EJEP03001JEUYF00IJEP04001JEP00001HOol003Aoo`03001JEUYF
008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@002Aoo`H000AJEP03001JEUYF00QJEP04001J
EUYFFUH60003Ool20003FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP05FUH3001JOol0
03Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@002iooa<000Qoo`8000EJEP04
001JEUYFFUH20006Ool6000:FUH00`00FUIJEP04001MOol003Eoo`04001JEUYF0006FUH01000FUIJ
EUYF1P00C7oo00@005YFFUH000AJEP04001JEP000002Ool6000015YF000000000UYF00<005YFFUH0
1UYF1000HGoo000eOol20002FUH01000FUIJEUYF1P00DWoo00@005YFFUH000AJEPH000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP<006Eoo`00=Woo1`00F7oo00H005YFFUIJEP00FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00002001XOol009Ioo`03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP<006]oo`00UWoo10001UYF00<005YFFUH01EYF00<005YFFUH01000
KWoo002FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6001bOol009Ioo`80009JEP04001J
EUYFFUH7001hOol009Moo`L007moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60532 .74278 m .5965 .68701 L .56573 .69016 L p .707 .577 .707 r
F P
0 g
s
.5965 .68701 m .60532 .74278 L .63679 .73744 L p .707 .577 .707 r
F P
0 g
s
.63679 .73744 m .62797 .68167 L .5965 .68701 L p .707 .577 .707 r
F P
0 g
s
.62797 .68167 m .63679 .73744 L .66589 .73045 L p .707 .577 .707 r
F P
0 g
s
.66589 .73045 m .65707 .67468 L .62797 .68167 L p .707 .577 .707 r
F P
0 g
s
.57455 .74593 m .56573 .69016 L .53867 .69082 L p .707 .577 .707 r
F P
0 g
s
.56573 .69016 m .57455 .74593 L .60532 .74278 L p .707 .577 .707 r
F P
0 g
s
.65707 .67468 m .66589 .73045 L .68976 .72248 L p .707 .577 .707 r
F P
0 g
s
.68976 .72248 m .68094 .66671 L .65707 .67468 L p .707 .577 .707 r
F P
0 g
s
.61424 .79761 m .60471 .76088 L .5746 .7672 L p .707 .577 .707 r
F P
0 g
s
.60471 .76088 m .61424 .79761 L .64511 .78942 L p .707 .577 .707 r
F P
0 g
s
.64511 .78942 m .63559 .75268 L .60471 .76088 L p .707 .577 .707 r
F P
0 g
s
.63559 .75268 m .64511 .78942 L .67374 .78015 L p .707 .577 .707 r
F P
0 g
s
.67374 .78015 m .66421 .74342 L .63559 .75268 L p .707 .577 .707 r
F P
0 g
s
.53867 .69082 m .54749 .74659 L .57455 .74593 L p .707 .577 .707 r
F P
0 g
s
.5746 .7672 m .58412 .80394 L .61424 .79761 L p .707 .577 .707 r
F P
0 g
s
.54749 .74659 m .53867 .69082 L .51797 .68892 L p .707 .577 .707 r
F P
0 g
s
.58412 .80394 m .5746 .7672 L .54821 .77103 L p .707 .577 .707 r
F P
0 g
s
.62094 .83517 m .61565 .81691 L .58579 .82417 L p .707 .577 .707 r
F P
0 g
s
.61565 .81691 m .62094 .83517 L .65159 .82613 L p .707 .577 .707 r
F P
0 g
s
.65159 .82613 m .64629 .80786 L .61565 .81691 L p .707 .577 .707 r
F P
0 g
s
.66421 .74342 m .67374 .78015 L .6973 .77072 L p .707 .577 .707 r
F P
0 g
s
.6973 .77072 m .68778 .73399 L .66421 .74342 L p .707 .577 .707 r
F P
0 g
s
.64629 .80786 m .65159 .82613 L .68003 .81619 L p .707 .577 .707 r
F P
0 g
s
.68003 .81619 m .67473 .79792 L .64629 .80786 L p .707 .577 .707 r
F P
0 g
s
.58579 .82417 m .59109 .84243 L .62094 .83517 L p .707 .577 .707 r
F P
0 g
s
.54821 .77103 m .55773 .80777 L .58412 .80394 L p .707 .577 .707 r
F P
0 g
s
.68094 .66671 m .68976 .72248 L .70607 .71431 L p .707 .577 .707 r
F P
0 g
s
.70607 .71431 m .69724 .65854 L .68094 .66671 L p .707 .577 .707 r
F P
0 g
s
.51797 .68892 m .5268 .74469 L .54749 .74659 L p .707 .577 .707 r
F P
0 g
s
.59109 .84243 m .58579 .82417 L .55966 .82894 L p .707 .577 .707 r
F P
0 g
s
.67473 .79792 m .68003 .81619 L .70347 .80632 L p .707 .577 .707 r
F P
0 g
s
.70347 .80632 m .69818 .78806 L .67473 .79792 L p .707 .577 .707 r
F P
0 g
s
.55966 .82894 m .56495 .8472 L .59109 .84243 L p .707 .577 .707 r
F P
0 g
s
.55773 .80777 m .54821 .77103 L .52811 .77199 L p .707 .577 .707 r
F P
0 g
s
.68778 .73399 m .6973 .77072 L .7135 .76205 L p .707 .577 .707 r
F P
0 g
s
.7135 .76205 m .70398 .72532 L .68778 .73399 L p .707 .577 .707 r
F P
0 g
s
.5268 .74469 m .51797 .68892 L .50567 .68465 L p .707 .577 .707 r
F P
0 g
s
.52811 .77199 m .53763 .80873 L .55773 .80777 L p .707 .577 .707 r
F P
0 g
s
.56495 .8472 m .55966 .82894 L .53979 .83075 L p .707 .577 .707 r
F P
0 g
s
.53979 .83075 m .54509 .84901 L .56495 .8472 L p .707 .577 .707 r
F P
0 g
s
.69724 .65854 m .70607 .71431 L .71321 .70674 L p .707 .577 .707 r
F P
0 g
s
.71321 .70674 m .70439 .65097 L .69724 .65854 L p .707 .577 .707 r
F P
0 g
s
.69818 .78806 m .70347 .80632 L .71963 .79751 L p .707 .577 .707 r
F P
0 g
s
.71963 .79751 m .71434 .77924 L .69818 .78806 L p .707 .577 .707 r
F P
0 g
s
.50567 .68465 m .51449 .74042 L .5268 .74469 L p .707 .577 .707 r
F P
0 g
s
.53763 .80873 m .52811 .77199 L .51627 .77 L p .707 .577 .707 r
F P
0 g
s
.51627 .77 m .5258 .80673 L .53763 .80873 L p .707 .577 .707 r
F P
0 g
s
.70398 .72532 m .7135 .76205 L .72075 .75499 L p .707 .577 .707 r
F P
0 g
s
.72075 .75499 m .71123 .71825 L .70398 .72532 L p .707 .577 .707 r
F P
0 g
s
.51449 .74042 m .50567 .68465 L .50296 .67843 L p .707 .577 .707 r
F P
0 g
s
.54509 .84901 m .53979 .83075 L .52814 .82943 L p .707 .577 .707 r
F P
0 g
s
.52814 .82943 m .53344 .84769 L .54509 .84901 L p .707 .577 .707 r
F P
0 g
s
.71434 .77924 m .71963 .79751 L .72693 .79059 L p .707 .577 .707 r
F P
0 g
s
.72693 .79059 m .72163 .77233 L .71434 .77924 L p .707 .577 .707 r
F P
0 g
s
.70439 .65097 m .71321 .70674 L .7105 .70052 L p .707 .577 .707 r
F P
0 g
s
.7105 .70052 m .70168 .64475 L .70439 .65097 L p .707 .577 .707 r
F P
0 g
s
.50296 .67843 m .51178 .7342 L .51449 .74042 L p .707 .577 .707 r
F P
0 g
s
.5258 .80673 m .51627 .77 L .51387 .76524 L p .707 .577 .707 r
F P
0 g
s
.51387 .76524 m .52339 .80197 L .5258 .80673 L p .707 .577 .707 r
F P
0 g
s
.71123 .71825 m .72075 .75499 L .71834 .75023 L p .707 .577 .707 r
F P
0 g
s
.71834 .75023 m .70882 .71349 L .71123 .71825 L p .707 .577 .707 r
F P
0 g
s
.53344 .84769 m .52814 .82943 L .52585 .8251 L p .707 .577 .707 r
F P
0 g
s
.51178 .7342 m .50296 .67843 L .5101 .67087 L p .707 .577 .707 r
F P
0 g
s
.52585 .8251 m .53115 .84336 L .53344 .84769 L p .707 .577 .707 r
F P
0 g
s
.72163 .77233 m .72693 .79059 L .72464 .78626 L p .707 .577 .707 r
F P
0 g
s
.72464 .78626 m .71934 .768 L .72163 .77233 L p .707 .577 .707 r
F P
0 g
s
.5101 .67087 m .51892 .72664 L .51178 .7342 L p .707 .577 .707 r
F P
0 g
s
.52339 .80197 m .51387 .76524 L .52112 .75817 L p .707 .577 .707 r
F P
0 g
s
.52112 .75817 m .53064 .79491 L .52339 .80197 L p .707 .577 .707 r
F P
0 g
s
.53064 .79491 m .52112 .75817 L .53732 .7495 L p .707 .577 .707 r
F P
0 g
s
.53182 .81586 m .45259 .31224 L .40914 .31665 L p .707 .577 .707 r
F P
0 g
s
.51892 .72664 m .5101 .67087 L .52641 .6627 L p .707 .577 .707 r
F P
0 g
s
.52641 .6627 m .53523 .71847 L .51892 .72664 L p .707 .577 .707 r
F P
0 g
s
.53732 .7495 m .54684 .78624 L .53064 .79491 L p .707 .577 .707 r
F P
0 g
s
.53523 .71847 m .52641 .6627 L .55028 .65473 L p .707 .577 .707 r
F P
0 g
s
.53844 .83645 m .53314 .81819 L .5493 .80937 L p .707 .577 .707 r
F P
0 g
s
.5493 .80937 m .5546 .82763 L .53844 .83645 L p .707 .577 .707 r
F P
0 g
s
.55028 .65473 m .5591 .7105 L .53523 .71847 L p .707 .577 .707 r
F P
0 g
s
.54684 .78624 m .53732 .7495 L .56088 .74007 L p .707 .577 .707 r
F P
0 g
s
.56088 .74007 m .5704 .77681 L .54684 .78624 L p .707 .577 .707 r
F P
0 g
s
.5546 .82763 m .5493 .80937 L .57275 .7995 L p .707 .577 .707 r
F P
0 g
s
.57275 .7995 m .57805 .81777 L .5546 .82763 L p .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .57275 .7995 L .5946 .79187 L p .707 .577 .707 r
F P
0 g
s
.5946 .79187 m .60119 .78957 L p .5964 .7954 L .707 .577 .707 r
F P
0 g
s
.57805 .81777 m .5946 .79187 L .5964 .7954 L .707 .577 .707 r
F
.53182 .81586 m .57626 .80836 L p .55057 .7053 L F P
0 g
s
.45259 .31224 m .49824 .60244 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.49824 .60244 m .53182 .81586 L p .55057 .7053 L .707 .577 .707 r
F P
0 g
s
.5591 .7105 m .55028 .65473 L .57937 .64773 L p .707 .577 .707 r
F P
0 g
s
.57937 .64773 m .58819 .7035 L .5591 .7105 L p .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .56088 .74007 L .5794 .73408 L p .707 .577 .707 r
F P
0 g
s
.5794 .73408 m .58951 .73081 L p .58381 .74451 L .707 .577 .707 r
F P
0 g
s
.5704 .77681 m .5794 .73408 L .58381 .74451 L .707 .577 .707 r
F
.49703 .30475 m .45259 .31224 L p .52665 .60934 L F P
0 g
s
.58951 .73081 m .59903 .76754 L .5704 .77681 L p .707 .577 .707 r
F P
0 g
s
.57626 .80836 m .55578 .67824 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.55578 .67824 m .49703 .30475 L p .52665 .60934 L .707 .577 .707 r
F P
0 g
s
.58819 .7035 m .57937 .64773 L .61085 .6424 L p .707 .577 .707 r
F P
0 g
s
.61085 .6424 m .61967 .69817 L .58819 .7035 L p .707 .577 .707 r
F P
0 g
s
.59903 .76754 m .59446 .74991 L p .62038 .72261 L .707 .577 .707 r
F P
0 g
s
.59446 .74991 m .58951 .73081 L .59261 .72998 L p .707 .577 .707 r
F P
0 g
s
.59261 .72998 m .62038 .72261 L p .59446 .74991 L .707 .577 .707 r
F P
0 g
s
.64162 .63925 m .65044 .69502 L .61967 .69817 L p .707 .577 .707 r
F P
0 g
s
.61967 .69817 m .61085 .6424 L .64162 .63925 L p .707 .577 .707 r
F P
0 g
s
.65049 .71629 m .66002 .75303 L .62991 .75935 L p .707 .577 .707 r
F P
0 g
s
.62991 .75935 m .62038 .72261 L .65049 .71629 L p .707 .577 .707 r
F P
0 g
s
.62038 .72261 m .62991 .75935 L .59903 .76754 L p .707 .577 .707 r
F P
0 g
s
.66169 .77326 m .66698 .79152 L .63713 .79878 L p .707 .577 .707 r
F P
0 g
s
.63713 .79878 m .63183 .78052 L .66169 .77326 L p .707 .577 .707 r
F P
0 g
s
.60649 .80783 m .60119 .78957 L .63183 .78052 L p .707 .577 .707 r
F P
0 g
s
.63183 .78052 m .63713 .79878 L .60649 .80783 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .65104 .78728 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.53811 .2949 m .57257 .51394 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.57257 .51394 m .61734 .79851 L p .56185 .39843 L .707 .577 .707 r
F P
0 g
s
.60119 .78957 m .60649 .80783 L .57805 .81777 L p .707 .577 .707 r
F P
0 g
s
.49703 .30475 m .57626 .80836 L .61734 .79851 L p .707 .577 .707 r
F P
0 g
s
.61734 .79851 m .53811 .2949 L .49703 .30475 L p .707 .577 .707 r
F P
0 g
s
.70168 .64475 m .7105 .70052 L .69819 .69626 L p .707 .577 .707 r
F P
0 g
s
.69819 .69626 m .68937 .64049 L .70168 .64475 L p .707 .577 .707 r
F P
0 g
s
.48837 .82027 m .40914 .31665 L .37093 .31754 L p .707 .577 .707 r
F P
0 g
s
.40914 .31665 m .48837 .82027 L .53182 .81586 L p .707 .577 .707 r
F P
0 g
s
.26231 .7106 m .25349 .65483 L .22272 .65798 L p .707 .577 .707 r
F P
0 g
s
.25349 .65483 m .26231 .7106 L .29379 .70526 L p .707 .577 .707 r
F P
0 g
s
.29379 .70526 m .28496 .64949 L .25349 .65483 L p .707 .577 .707 r
F P
0 g
s
.28496 .64949 m .29379 .70526 L .32288 .69827 L p .707 .577 .707 r
F P
0 g
s
.32288 .69827 m .31406 .6425 L .28496 .64949 L p .707 .577 .707 r
F P
0 g
s
.65104 .78728 m .57181 .28366 L .53811 .2949 L p .707 .577 .707 r
F P
0 g
s
.70882 .71349 m .71834 .75023 L .70651 .74823 L p .707 .577 .707 r
F P
0 g
s
.70651 .74823 m .69699 .7115 L .70882 .71349 L p .707 .577 .707 r
F P
0 g
s
.53115 .84336 m .52585 .8251 L .53314 .81819 L p .707 .577 .707 r
F P
0 g
s
.23154 .71375 m .22272 .65798 L .19566 .65864 L p .707 .577 .707 r
F P
0 g
s
.22272 .65798 m .23154 .71375 L .26231 .7106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.53314 .81819 m .53844 .83645 L .53115 .84336 L p .707 .577 .707 r
F P
0 g
s
.31406 .6425 m .32288 .69827 L .34675 .6903 L p .707 .577 .707 r
F P
0 g
s
.34675 .6903 m .33793 .63453 L .31406 .6425 L p .707 .577 .707 r
F P
0 g
s
.71934 .768 m .72464 .78626 L .71299 .78494 L p .707 .577 .707 r
F P
0 g
s
.71299 .78494 m .70769 .76668 L .71934 .768 L p .707 .577 .707 r
F P
0 g
s
.68937 .64049 m .69819 .69626 L .6775 .69436 L p .707 .577 .707 r
F P
0 g
s
.6775 .69436 m .66868 .63859 L .68937 .64049 L p .707 .577 .707 r
F P
0 g
s
.27123 .77162 m .2617 .73488 L .23159 .7412 L p .707 .577 .707 r
F P
0 g
s
.2617 .73488 m .27123 .77162 L .3021 .76342 L p .707 .577 .707 r
F P
0 g
s
.3021 .76342 m .29258 .72668 L .2617 .73488 L p .707 .577 .707 r
F P
0 g
s
.45016 .82116 m .37093 .31754 L .34171 .31483 L p .707 .577 .707 r
F P
0 g
s
.37093 .31754 m .45016 .82116 L .48837 .82027 L p .707 .577 .707 r
F P
0 g
s
.19566 .65864 m .20448 .71441 L .23154 .71375 L p .707 .577 .707 r
F P
0 g
s
.29258 .72668 m .3021 .76342 L .33073 .75415 L p .707 .577 .707 r
F P
0 g
s
.33073 .75415 m .32121 .71742 L .29258 .72668 L p .707 .577 .707 r
F P
0 g
s
.20448 .71441 m .19566 .65864 L .17497 .65674 L p .707 .577 .707 r
F P
0 g
s
.23159 .7412 m .24112 .77794 L .27123 .77162 L p .707 .577 .707 r
F P
0 g
s
.24112 .77794 m .23159 .7412 L .2052 .74503 L p .707 .577 .707 r
F P
0 g
s
.66868 .63859 m .6775 .69436 L .65044 .69502 L p .707 .577 .707 r
F P
0 g
s
.65044 .69502 m .64162 .63925 L .66868 .63859 L p .707 .577 .707 r
F P
0 g
s
.67689 .71246 m .68641 .74919 L .66002 .75303 L p .707 .577 .707 r
F P
0 g
s
.66002 .75303 m .65049 .71629 L .67689 .71246 L p .707 .577 .707 r
F P
0 g
s
.66698 .79152 m .66169 .77326 L .68783 .76849 L p .707 .577 .707 r
F P
0 g
s
.57181 .28366 m .65104 .78728 L .67406 .77575 L p .707 .577 .707 r
F P
0 g
s
.67406 .77575 m .59483 .27214 L .57181 .28366 L p .707 .577 .707 r
F P
0 g
s
.32121 .71742 m .33073 .75415 L .35429 .74472 L p .707 .577 .707 r
F P
0 g
s
.35429 .74472 m .34477 .70799 L .32121 .71742 L p .707 .577 .707 r
F P
0 g
s
.27794 .81785 m .27264 .79959 L .24279 .80685 L p .707 .577 .707 r
F P
0 g
s
.27264 .79959 m .27794 .81785 L .30858 .80881 L p .707 .577 .707 r
F P
0 g
s
.30858 .80881 m .30328 .79055 L .27264 .79959 L p .707 .577 .707 r
F P
0 g
s
.33793 .63453 m .34675 .6903 L .36306 .68213 L p .707 .577 .707 r
F P
0 g
s
.36306 .68213 m .35424 .62636 L .33793 .63453 L p .707 .577 .707 r
F P
0 g
s
.69699 .7115 m .70651 .74823 L .68641 .74919 L p .707 .577 .707 r
F P
0 g
s
.68641 .74919 m .67689 .71246 L .69699 .7115 L p .707 .577 .707 r
F P
0 g
s
.30328 .79055 m .30858 .80881 L .33702 .79887 L p .707 .577 .707 r
F P
0 g
s
.33702 .79887 m .33172 .78061 L .30328 .79055 L p .707 .577 .707 r
F P
0 g
s
.2052 .74503 m .21472 .78177 L .24112 .77794 L p .707 .577 .707 r
F P
0 g
s
.24279 .80685 m .24808 .82511 L .27794 .81785 L p .707 .577 .707 r
F P
0 g
s
.17497 .65674 m .18379 .71251 L .20448 .71441 L p .707 .577 .707 r
F P
0 g
s
.24808 .82511 m .24279 .80685 L .21665 .81162 L p .707 .577 .707 r
F P
0 g
s
.70769 .76668 m .71299 .78494 L .69312 .78675 L p .707 .577 .707 r
F P
0 g
s
.69312 .78675 m .68783 .76849 L .70769 .76668 L p .707 .577 .707 r
F P
0 g
s
.33172 .78061 m .33702 .79887 L .36046 .78901 L p .707 .577 .707 r
F P
0 g
s
.36046 .78901 m .35517 .77075 L .33172 .78061 L p .707 .577 .707 r
F P
0 g
s
.21665 .81162 m .22194 .82989 L .24808 .82511 L p .707 .577 .707 r
F P
0 g
s
.21472 .78177 m .2052 .74503 L .1851 .746 L p .707 .577 .707 r
F P
0 g
s
.18379 .71251 m .17497 .65674 L .16266 .65247 L p .707 .577 .707 r
F P
0 g
s
.34477 .70799 m .35429 .74472 L .37049 .73605 L p .707 .577 .707 r
F P
0 g
s
.37049 .73605 m .36097 .69932 L .34477 .70799 L p .707 .577 .707 r
F P
0 g
s
.1851 .746 m .19462 .78273 L .21472 .78177 L p .707 .577 .707 r
F P
0 g
s
.42094 .81845 m .34171 .31483 L .32433 .30878 L p .707 .577 .707 r
F P
0 g
s
.34171 .31483 m .42094 .81845 L .45016 .82116 L p .707 .577 .707 r
F P
0 g
s
.35424 .62636 m .36306 .68213 L .3702 .67456 L p .707 .577 .707 r
F P
0 g
s
.3702 .67456 m .36138 .61879 L .35424 .62636 L p .707 .577 .707 r
F P
0 g
s
.22194 .82989 m .21665 .81162 L .19678 .81344 L p .707 .577 .707 r
F P
0 g
s
.16266 .65247 m .17148 .70824 L .18379 .71251 L p .707 .577 .707 r
F P
0 g
s
.19678 .81344 m .20208 .8317 L .22194 .82989 L p .707 .577 .707 r
F P
0 g
s
.35517 .77075 m .36046 .78901 L .37663 .78019 L p .707 .577 .707 r
F P
0 g
s
.37663 .78019 m .37133 .76193 L .35517 .77075 L p .707 .577 .707 r
F P
0 g
s
.59483 .27214 m .67406 .77575 L .68415 .76507 L p .707 .577 .707 r
F P
0 g
s
.68415 .76507 m .60492 .26145 L .59483 .27214 L p .707 .577 .707 r
F P
0 g
s
.68783 .76849 m .69312 .78675 L .66698 .79152 L p .707 .577 .707 r
F P
0 g
s
.19462 .78273 m .1851 .746 L .17326 .744 L p .707 .577 .707 r
F P
0 g
s
.17326 .744 m .18279 .78074 L .19462 .78273 L p .707 .577 .707 r
F P
0 g
s
.36097 .69932 m .37049 .73605 L .37774 .72899 L p .707 .577 .707 r
F P
0 g
s
.37774 .72899 m .36822 .69226 L .36097 .69932 L p .707 .577 .707 r
F P
0 g
s
.17148 .70824 m .16266 .65247 L .15995 .64625 L p .707 .577 .707 r
F P
0 g
s
.20208 .8317 m .19678 .81344 L .18513 .81211 L p .707 .577 .707 r
F P
0 g
s
.18513 .81211 m .19043 .83037 L .20208 .8317 L p .707 .577 .707 r
F P
0 g
s
.36138 .61879 m .3702 .67456 L .36749 .66834 L p .707 .577 .707 r
F P
0 g
s
.36749 .66834 m .35867 .61257 L .36138 .61879 L p .707 .577 .707 r
F P
0 g
s
.37133 .76193 m .37663 .78019 L .38392 .77328 L p .707 .577 .707 r
F P
0 g
s
.38392 .77328 m .37862 .75501 L .37133 .76193 L p .707 .577 .707 r
F P
0 g
s
.15995 .64625 m .16877 .70202 L .17148 .70824 L p .707 .577 .707 r
F P
0 g
s
.40356 .81239 m .32433 .30878 L .3205 .29998 L p .707 .577 .707 r
F P
0 g
s
.32433 .30878 m .40356 .81239 L .42094 .81845 L p .707 .577 .707 r
F P
0 g
s
.18279 .78074 m .17326 .744 L .17086 .73924 L p .707 .577 .707 r
F P
0 g
s
.17086 .73924 m .18038 .77597 L .18279 .78074 L p .707 .577 .707 r
F P
0 g
s
.36822 .69226 m .37774 .72899 L .37534 .72423 L p .707 .577 .707 r
F P
0 g
s
.37534 .72423 m .36581 .68749 L .36822 .69226 L p .707 .577 .707 r
F P
0 g
s
.60492 .26145 m .68415 .76507 L .68031 .75627 L p .707 .577 .707 r
F P
0 g
s
.68031 .75627 m .63555 .4717 L p .60492 .26145 L .707 .577 .707 r
F P
0 g
s
.60109 .25265 m .68031 .75627 L .66294 .75022 L p .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .68541 .67899 L .66733 .67986 L p .707 .577 .707 r
F P
0 g
s
.66733 .67986 m .66531 .67996 L p .6678 .68297 L .707 .577 .707 r
F P
0 g
s
.69493 .71573 m .66733 .67986 L .6678 .68297 L .707 .577 .707 r
F
.63555 .4717 m .60109 .25265 L .60265 .25623 L p F P
0 g
s
.60265 .25623 m .60492 .26145 L p .63555 .4717 L .707 .577 .707 r
F P
0 g
s
.16877 .70202 m .15995 .64625 L .16709 .63869 L p .707 .577 .707 r
F P
0 g
s
.19043 .83037 m .18513 .81211 L .18284 .80778 L p .707 .577 .707 r
F P
0 g
s
.18284 .80778 m .18814 .82604 L .19043 .83037 L p .707 .577 .707 r
F P
0 g
s
.37862 .75501 m .38392 .77328 L .38163 .76895 L p .707 .577 .707 r
F P
0 g
s
.38163 .76895 m .37633 .75068 L .37862 .75501 L p .707 .577 .707 r
F P
0 g
s
.35867 .61257 m .36749 .66834 L .35518 .66408 L p .707 .577 .707 r
F P
0 g
s
.35518 .66408 m .34636 .60831 L .35867 .61257 L p .707 .577 .707 r
F P
0 g
s
.16709 .63869 m .17591 .69446 L .16877 .70202 L p .707 .577 .707 r
F P
0 g
s
.18038 .77597 m .17086 .73924 L .17811 .73218 L p .707 .577 .707 r
F P
0 g
s
.17811 .73218 m .18763 .76891 L .18038 .77597 L p .707 .577 .707 r
F P
0 g
s
.36581 .68749 m .37534 .72423 L .3635 .72223 L p .707 .577 .707 r
F P
0 g
s
.3635 .72223 m .35398 .6855 L .36581 .68749 L p .707 .577 .707 r
F P
0 g
s
.3205 .29998 m .39973 .80359 L .40356 .81239 L p .707 .577 .707 r
F P
0 g
s
.39973 .80359 m .3205 .29998 L .33059 .28929 L p .707 .577 .707 r
F P
0 g
s
.17591 .69446 m .16709 .63869 L .1834 .63052 L p .707 .577 .707 r
F P
0 g
s
.18814 .82604 m .18284 .80778 L .19013 .80087 L p .707 .577 .707 r
F P
0 g
s
.19013 .80087 m .19543 .81913 L .18814 .82604 L p .707 .577 .707 r
F P
0 g
s
.34636 .60831 m .35518 .66408 L .33449 .66218 L p .707 .577 .707 r
F P
0 g
s
.33449 .66218 m .32567 .60641 L .34636 .60831 L p .707 .577 .707 r
F P
0 g
s
.37633 .75068 m .38163 .76895 L .36998 .76762 L p .707 .577 .707 r
F P
0 g
s
.36998 .76762 m .36468 .74936 L .37633 .75068 L p .707 .577 .707 r
F P
0 g
s
.1834 .63052 m .19222 .68629 L .17591 .69446 L p .707 .577 .707 r
F P
0 g
s
.66294 .75022 m .58371 .2466 L .60109 .25265 L p .707 .577 .707 r
F P
0 g
s
.18763 .76891 m .17811 .73218 L .19431 .72351 L p .707 .577 .707 r
F P
0 g
s
.19222 .68629 m .1834 .63052 L .20727 .62255 L p .707 .577 .707 r
F P
0 g
s
.19431 .72351 m .20383 .76024 L .18763 .76891 L p .707 .577 .707 r
F P
0 g
s
.35398 .6855 m .3635 .72223 L .3434 .7232 L p .707 .577 .707 r
F P
0 g
s
.3434 .7232 m .33388 .68646 L .35398 .6855 L p .707 .577 .707 r
F P
0 g
s
.32567 .60641 m .33449 .66218 L .30743 .66284 L p .707 .577 .707 r
F P
0 g
s
.30743 .66284 m .29861 .60707 L .32567 .60641 L p .707 .577 .707 r
F P
0 g
s
.19543 .81913 m .19013 .80087 L .20629 .79205 L p .707 .577 .707 r
F P
0 g
s
.20727 .62255 m .21609 .67832 L .19222 .68629 L p .707 .577 .707 r
F P
0 g
s
.20629 .79205 m .21159 .81031 L .19543 .81913 L p .707 .577 .707 r
F P
0 g
s
.36468 .74936 m .36998 .76762 L .35011 .76943 L p .707 .577 .707 r
F P
0 g
s
.35011 .76943 m .34482 .75117 L .36468 .74936 L p .707 .577 .707 r
F P
0 g
s
.40982 .79291 m .33059 .28929 L .35361 .27777 L p .707 .577 .707 r
F P
0 g
s
.33059 .28929 m .40982 .79291 L .39973 .80359 L p .707 .577 .707 r
F P
0 g
s
.21609 .67832 m .20727 .62255 L .23636 .61555 L p .707 .577 .707 r
F P
0 g
s
.20383 .76024 m .19431 .72351 L .21787 .71408 L p .707 .577 .707 r
F P
0 g
s
.29861 .60707 m .30743 .66284 L .27666 .66599 L p .707 .577 .707 r
F P
0 g
s
.27666 .66599 m .26784 .61022 L .29861 .60707 L p .707 .577 .707 r
F P
0 g
s
.33388 .68646 m .3434 .7232 L .31701 .72703 L p .707 .577 .707 r
F P
0 g
s
.31701 .72703 m .30749 .69029 L .33388 .68646 L p .707 .577 .707 r
F P
0 g
s
.21787 .71408 m .2274 .75081 L .20383 .76024 L p .707 .577 .707 r
F P
0 g
s
.58371 .2466 m .66294 .75022 L .63371 .7475 L p .707 .577 .707 r
F P
0 g
s
.63371 .7475 m .55449 .24389 L .58371 .2466 L p .707 .577 .707 r
F P
0 g
s
.74252 .65074 m .7337 .59497 L .70293 .59812 L p .707 .577 .707 r
F P
0 g
s
.7337 .59497 m .74252 .65074 L .774 .6454 L p .707 .577 .707 r
F P
0 g
s
.774 .6454 m .76518 .58963 L .7337 .59497 L p .707 .577 .707 r
F P
0 g
s
.24518 .67132 m .23636 .61555 L .26784 .61022 L p .707 .577 .707 r
F P
0 g
s
.23636 .61555 m .24518 .67132 L .21609 .67832 L p .707 .577 .707 r
F P
0 g
s
.76518 .58963 m .774 .6454 L .8031 .63841 L p .707 .577 .707 r
F P
0 g
s
.8031 .63841 m .79427 .58264 L .76518 .58963 L p .707 .577 .707 r
F P
0 g
s
.26784 .61022 m .27666 .66599 L .24518 .67132 L p .707 .577 .707 r
F P
0 g
s
.21159 .81031 m .20629 .79205 L .22974 .78219 L p .707 .577 .707 r
F P
0 g
s
.22974 .78219 m .23504 .80045 L .21159 .81031 L p .707 .577 .707 r
F P
0 g
s
.71175 .65389 m .70293 .59812 L .67587 .59878 L p .707 .577 .707 r
F P
0 g
s
.70293 .59812 m .71175 .65389 L .74252 .65074 L p .707 .577 .707 r
F P
0 g
s
.34482 .75117 m .35011 .76943 L .32397 .7742 L p .707 .577 .707 r
F P
0 g
s
.32397 .7742 m .31868 .75594 L .34482 .75117 L p .707 .577 .707 r
F P
0 g
s
.2274 .75081 m .21787 .71408 L .2465 .70481 L p .707 .577 .707 r
F P
0 g
s
.79427 .58264 m .8031 .63841 L .82696 .63044 L p .707 .577 .707 r
F P
0 g
s
.82696 .63044 m .81814 .57467 L .79427 .58264 L p .707 .577 .707 r
F P
0 g
s
.30749 .69029 m .31701 .72703 L .2869 .73335 L p .707 .577 .707 r
F P
0 g
s
.2869 .73335 m .27737 .69661 L .30749 .69029 L p .707 .577 .707 r
F P
0 g
s
.2465 .70481 m .25602 .74155 L .2274 .75081 L p .707 .577 .707 r
F P
0 g
s
.75144 .70557 m .74192 .66884 L .71181 .67516 L p .707 .577 .707 r
F P
0 g
s
.74192 .66884 m .75144 .70557 L .78232 .69738 L p .707 .577 .707 r
F P
0 g
s
.78232 .69738 m .7728 .66064 L .74192 .66884 L p .707 .577 .707 r
F P
0 g
s
.7728 .66064 m .78232 .69738 L .81094 .68811 L p .707 .577 .707 r
F P
0 g
s
.81094 .68811 m .80142 .65138 L .7728 .66064 L p .707 .577 .707 r
F P
0 g
s
.67587 .59878 m .68469 .65455 L .71175 .65389 L p .707 .577 .707 r
F P
0 g
s
.25602 .74155 m .2465 .70481 L .27737 .69661 L p .707 .577 .707 r
F P
0 g
s
.35361 .27777 m .43284 .78138 L .40982 .79291 L p .707 .577 .707 r
F P
0 g
s
.43284 .78138 m .35361 .27777 L .38731 .26653 L p .707 .577 .707 r
F P
0 g
s
.27737 .69661 m .2869 .73335 L .25602 .74155 L p .707 .577 .707 r
F P
0 g
s
.71181 .67516 m .72133 .7119 L .75144 .70557 L p .707 .577 .707 r
F P
0 g
s
.23504 .80045 m .22974 .78219 L .25818 .77225 L p .707 .577 .707 r
F P
0 g
s
.68469 .65455 m .67587 .59878 L .65518 .59688 L p .707 .577 .707 r
F P
0 g
s
.72133 .7119 m .71181 .67516 L .68541 .67899 L p .707 .577 .707 r
F P
0 g
s
.31868 .75594 m .32397 .7742 L .29412 .78147 L p .707 .577 .707 r
F P
0 g
s
.29412 .78147 m .28882 .76321 L .31868 .75594 L p .707 .577 .707 r
F P
0 g
s
.25818 .77225 m .26348 .79051 L .23504 .80045 L p .707 .577 .707 r
F P
0 g
s
.75815 .74313 m .75285 .72487 L .723 .73213 L p .707 .577 .707 r
F P
0 g
s
.75285 .72487 m .75815 .74313 L .78879 .73409 L p .707 .577 .707 r
F P
0 g
s
.78879 .73409 m .7835 .71583 L .75285 .72487 L p .707 .577 .707 r
F P
0 g
s
.80142 .65138 m .81094 .68811 L .83451 .67868 L p .707 .577 .707 r
F P
0 g
s
.83451 .67868 m .82498 .64195 L .80142 .65138 L p .707 .577 .707 r
F P
0 g
s
.7835 .71583 m .78879 .73409 L .81723 .72415 L p .707 .577 .707 r
F P
0 g
s
.81723 .72415 m .81194 .70589 L .7835 .71583 L p .707 .577 .707 r
F P
0 g
s
.723 .73213 m .7283 .75039 L .75815 .74313 L p .707 .577 .707 r
F P
0 g
s
.68541 .67899 m .69493 .71573 L .72133 .7119 L p .707 .577 .707 r
F P
0 g
s
.55449 .24389 m .63371 .7475 L .59551 .74839 L p .707 .577 .707 r
F P
0 g
s
.59551 .74839 m .51628 .24478 L .55449 .24389 L p .707 .577 .707 r
F P
0 g
s
.81814 .57467 m .82696 .63044 L .84327 .62227 L p .707 .577 .707 r
F P
0 g
s
.84327 .62227 m .83445 .5665 L .81814 .57467 L p .707 .577 .707 r
F P
0 g
s
.26348 .79051 m .25818 .77225 L .28882 .76321 L p .707 .577 .707 r
F P
0 g
s
.28882 .76321 m .29412 .78147 L .26348 .79051 L p .707 .577 .707 r
F P
0 g
s
.65518 .59688 m .664 .65265 L .68469 .65455 L p .707 .577 .707 r
F P
0 g
s
.7283 .75039 m .723 .73213 L .69686 .7369 L p .707 .577 .707 r
F P
0 g
s
.81194 .70589 m .81723 .72415 L .84068 .71429 L p .707 .577 .707 r
F P
0 g
s
.84068 .71429 m .83538 .69602 L .81194 .70589 L p .707 .577 .707 r
F P
0 g
s
.69686 .7369 m .70216 .75516 L .7283 .75039 L p .707 .577 .707 r
F P
0 g
s
.82498 .64195 m .83451 .67868 L .85071 .67001 L p .707 .577 .707 r
F P
0 g
s
.85071 .67001 m .84118 .63328 L .82498 .64195 L p .707 .577 .707 r
F P
0 g
s
.46654 .77015 m .38731 .26653 L .42839 .25668 L p .707 .577 .707 r
F P
0 g
s
.38731 .26653 m .46654 .77015 L .43284 .78138 L p .707 .577 .707 r
F P
0 g
s
.664 .65265 m .65518 .59688 L .64287 .59261 L p .707 .577 .707 r
F P
0 g
s
.66531 .67996 m .67483 .71669 L .69493 .71573 L p .707 .577 .707 r
F P
0 g
s
.70216 .75516 m .69686 .7369 L .67699 .73871 L p .707 .577 .707 r
F P
0 g
s
.51628 .24478 m .59551 .74839 L .55206 .7528 L p .707 .577 .707 r
F P
0 g
s
.55206 .7528 m .47283 .24919 L .51628 .24478 L p .707 .577 .707 r
F P
0 g
s
.67699 .73871 m .68229 .75698 L .70216 .75516 L p .707 .577 .707 r
F P
0 g
s
.83445 .5665 m .84327 .62227 L .85042 .61471 L p .707 .577 .707 r
F P
0 g
s
.85042 .61471 m .8416 .55893 L .83445 .5665 L p .707 .577 .707 r
F P
0 g
s
.83538 .69602 m .84068 .71429 L .85684 .70547 L p .707 .577 .707 r
F P
0 g
s
.85684 .70547 m .85154 .68721 L .83538 .69602 L p .707 .577 .707 r
F P
0 g
s
.64287 .59261 m .65169 .64838 L .664 .65265 L p .707 .577 .707 r
F P
0 g
s
.50762 .7603 m .42839 .25668 L .47283 .24919 L p .707 .577 .707 r
F P
0 g
s
.42839 .25668 m .50762 .7603 L .46654 .77015 L p .707 .577 .707 r
F P
0 g
s
.47283 .24919 m .55206 .7528 L .50762 .7603 L p .707 .577 .707 r
F P
0 g
s
.67483 .71669 m .66531 .67996 L .65348 .67796 L p .707 .577 .707 r
F P
0 g
s
.65348 .67796 m .663 .7147 L .67483 .71669 L p .707 .577 .707 r
F P
0 g
s
.84118 .63328 m .85071 .67001 L .85796 .66295 L p .707 .577 .707 r
F P
0 g
s
.85796 .66295 m .84844 .62622 L .84118 .63328 L p .707 .577 .707 r
F P
0 g
s
.65169 .64838 m .64287 .59261 L .64016 .58639 L p .707 .577 .707 r
F P
0 g
s
.68229 .75698 m .67699 .73871 L .66535 .73739 L p .707 .577 .707 r
F P
0 g
s
.66535 .73739 m .67064 .75565 L .68229 .75698 L p .707 .577 .707 r
F P
0 g
s
.85154 .68721 m .85684 .70547 L .86413 .69855 L p .707 .577 .707 r
F P
0 g
s
.86413 .69855 m .85883 .68029 L .85154 .68721 L p .707 .577 .707 r
F P
0 g
s
.8416 .55893 m .85042 .61471 L .8477 .60848 L p .707 .577 .707 r
F P
0 g
s
.8477 .60848 m .83888 .55271 L .8416 .55893 L p .707 .577 .707 r
F P
0 g
s
.64016 .58639 m .64898 .64216 L .65169 .64838 L p .707 .577 .707 r
F P
0 g
s
.663 .7147 m .65348 .67796 L .65107 .6732 L p .707 .577 .707 r
F P
0 g
s
.65107 .6732 m .66059 .70993 L .663 .7147 L p .707 .577 .707 r
F P
0 g
s
.84844 .62622 m .85796 .66295 L .85555 .65819 L p .707 .577 .707 r
F P
0 g
s
.85555 .65819 m .84603 .62145 L .84844 .62622 L p .707 .577 .707 r
F P
0 g
s
.67064 .75565 m .66535 .73739 L .66306 .73306 L p .707 .577 .707 r
F P
0 g
s
.64898 .64216 m .64016 .58639 L .64731 .57883 L p .707 .577 .707 r
F P
0 g
s
.66306 .73306 m .66835 .75132 L .67064 .75565 L p .707 .577 .707 r
F P
0 g
s
.85883 .68029 m .86413 .69855 L .86184 .69422 L p .707 .577 .707 r
F P
0 g
s
.86184 .69422 m .85654 .67596 L .85883 .68029 L p .707 .577 .707 r
F P
0 g
s
.83888 .55271 m .8477 .60848 L .8354 .60422 L p .707 .577 .707 r
F P
0 g
s
.8354 .60422 m .82658 .54845 L .83888 .55271 L p .707 .577 .707 r
F P
0 g
s
.64731 .57883 m .65613 .6346 L .64898 .64216 L p .707 .577 .707 r
F P
0 g
s
.66059 .70993 m .65107 .6732 L .65832 .66614 L p .707 .577 .707 r
F P
0 g
s
.39951 .61856 m .39069 .56279 L .35992 .56594 L p .707 .577 .707 r
F P
0 g
s
.39069 .56279 m .39951 .61856 L .43099 .61322 L p .707 .577 .707 r
F P
0 g
s
.43099 .61322 m .42217 .55745 L .39069 .56279 L p .707 .577 .707 r
F P
0 g
s
.42217 .55745 m .43099 .61322 L .46009 .60623 L p .707 .577 .707 r
F P
0 g
s
.46009 .60623 m .45126 .55046 L .42217 .55745 L p .707 .577 .707 r
F P
0 g
s
.65832 .66614 m .66784 .70287 L .66059 .70993 L p .707 .577 .707 r
F P
0 g
s
.84603 .62145 m .85555 .65819 L .84372 .65619 L p .707 .577 .707 r
F P
0 g
s
.84372 .65619 m .83419 .61946 L .84603 .62145 L p .707 .577 .707 r
F P
0 g
s
.65613 .6346 m .64731 .57883 L .66361 .57066 L p .707 .577 .707 r
F P
0 g
s
.66835 .75132 m .66306 .73306 L .67035 .72615 L p .707 .577 .707 r
F P
0 g
s
.36874 .62171 m .35992 .56594 L .33286 .5666 L p .707 .577 .707 r
F P
0 g
s
.35992 .56594 m .36874 .62171 L .39951 .61856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67035 .72615 m .67565 .74441 L .66835 .75132 L p .707 .577 .707 r
F P
0 g
s
.45126 .55046 m .46009 .60623 L .48395 .59826 L p .707 .577 .707 r
F P
0 g
s
.48395 .59826 m .47513 .54249 L .45126 .55046 L p .707 .577 .707 r
F P
0 g
s
.85654 .67596 m .86184 .69422 L .85019 .6929 L p .707 .577 .707 r
F P
0 g
s
.85019 .6929 m .8449 .67464 L .85654 .67596 L p .707 .577 .707 r
F P
0 g
s
.82658 .54845 m .8354 .60422 L .8147 .60232 L p .707 .577 .707 r
F P
0 g
s
.8147 .60232 m .80588 .54655 L .82658 .54845 L p .707 .577 .707 r
F P
0 g
s
.66361 .57066 m .67243 .62643 L .65613 .6346 L p .707 .577 .707 r
F P
0 g
s
.40843 .67958 m .39891 .64284 L .3688 .64916 L p .707 .577 .707 r
F P
0 g
s
.39891 .64284 m .40843 .67958 L .43931 .67138 L p .707 .577 .707 r
F P
0 g
s
.43931 .67138 m .42979 .63465 L .39891 .64284 L p .707 .577 .707 r
F P
0 g
s
.33286 .5666 m .34168 .62237 L .36874 .62171 L p .707 .577 .707 r
F P
0 g
s
.42979 .63465 m .43931 .67138 L .46793 .66212 L p .707 .577 .707 r
F P
0 g
s
.46793 .66212 m .45841 .62538 L .42979 .63465 L p .707 .577 .707 r
F P
0 g
s
.34168 .62237 m .33286 .5666 L .31217 .5647 L p .707 .577 .707 r
F P
0 g
s
.3688 .64916 m .37832 .6859 L .40843 .67958 L p .707 .577 .707 r
F P
0 g
s
.66784 .70287 m .65832 .66614 L .67452 .65747 L p .707 .577 .707 r
F P
0 g
s
.37832 .6859 m .3688 .64916 L .3424 .65299 L p .707 .577 .707 r
F P
0 g
s
.45841 .62538 m .46793 .66212 L .4915 .65269 L p .707 .577 .707 r
F P
0 g
s
.4915 .65269 m .48197 .61595 L .45841 .62538 L p .707 .577 .707 r
F P
0 g
s
.41514 .72581 m .40984 .70755 L .37999 .71481 L p .707 .577 .707 r
F P
0 g
s
.40984 .70755 m .41514 .72581 L .44578 .71677 L p .707 .577 .707 r
F P
0 g
s
.44578 .71677 m .44049 .69851 L .40984 .70755 L p .707 .577 .707 r
F P
0 g
s
.67452 .65747 m .68404 .6942 L .66784 .70287 L p .707 .577 .707 r
F P
0 g
s
.47513 .54249 m .48395 .59826 L .50026 .59009 L p .707 .577 .707 r
F P
0 g
s
.50026 .59009 m .49144 .53432 L .47513 .54249 L p .707 .577 .707 r
F P
0 g
s
.83419 .61946 m .84372 .65619 L .82362 .65716 L p .707 .577 .707 r
F P
0 g
s
.82362 .65716 m .8141 .62042 L .83419 .61946 L p .707 .577 .707 r
F P
0 g
s
.67243 .62643 m .66361 .57066 L .68748 .56269 L p .707 .577 .707 r
F P
0 g
s
.44049 .69851 m .44578 .71677 L .47422 .70683 L p .707 .577 .707 r
F P
0 g
s
.47422 .70683 m .46893 .68857 L .44049 .69851 L p .707 .577 .707 r
F P
0 g
s
.3424 .65299 m .35192 .68973 L .37832 .6859 L p .707 .577 .707 r
F P
0 g
s
.37999 .71481 m .38529 .73308 L .41514 .72581 L p .707 .577 .707 r
F P
0 g
s
.31217 .5647 m .32099 .62047 L .34168 .62237 L p .707 .577 .707 r
F P
0 g
s
.67565 .74441 m .67035 .72615 L .68651 .71733 L p .707 .577 .707 r
F P
0 g
s
.80588 .54655 m .8147 .60232 L .78765 .60298 L p .707 .577 .707 r
F P
0 g
s
.78765 .60298 m .77882 .54721 L .80588 .54655 L p .707 .577 .707 r
F P
0 g
s
.68651 .71733 m .69181 .73559 L .67565 .74441 L p .707 .577 .707 r
F P
0 g
s
.38529 .73308 m .37999 .71481 L .35385 .71959 L p .707 .577 .707 r
F P
0 g
s
.8449 .67464 m .85019 .6929 L .83033 .69471 L p .707 .577 .707 r
F P
0 g
s
.83033 .69471 m .82503 .67645 L .8449 .67464 L p .707 .577 .707 r
F P
0 g
s
.46893 .68857 m .47422 .70683 L .49767 .69697 L p .707 .577 .707 r
F P
0 g
s
.49767 .69697 m .49237 .67871 L .46893 .68857 L p .707 .577 .707 r
F P
0 g
s
.35385 .71959 m .35915 .73785 L .38529 .73308 L p .707 .577 .707 r
F P
0 g
s
.68748 .56269 m .6963 .61846 L .67243 .62643 L p .707 .577 .707 r
F P
0 g
s
.35192 .68973 m .3424 .65299 L .3223 .65396 L p .707 .577 .707 r
F P
0 g
s
.32099 .62047 m .31217 .5647 L .29986 .56043 L p .707 .577 .707 r
F P
0 g
s
.48197 .61595 m .4915 .65269 L .5077 .64402 L p .707 .577 .707 r
F P
0 g
s
.5077 .64402 m .49818 .60728 L .48197 .61595 L p .707 .577 .707 r
F P
0 g
s
.3223 .65396 m .33182 .69069 L .35192 .68973 L p .707 .577 .707 r
F P
0 g
s
.68404 .6942 m .67452 .65747 L .69809 .64804 L p .707 .577 .707 r
F P
0 g
s
.6963 .61846 m .68748 .56269 L .71658 .55569 L p .707 .577 .707 r
F P
0 g
s
.77882 .54721 m .78765 .60298 L .75687 .60613 L p .707 .577 .707 r
F P
0 g
s
.75687 .60613 m .74805 .55036 L .77882 .54721 L p .707 .577 .707 r
F P
0 g
s
.8141 .62042 m .82362 .65716 L .79722 .66099 L p .707 .577 .707 r
F P
0 g
s
.79722 .66099 m .7877 .62425 L .8141 .62042 L p .707 .577 .707 r
F P
0 g
s
.69809 .64804 m .70761 .68477 L .68404 .6942 L p .707 .577 .707 r
F P
0 g
s
.49144 .53432 m .50026 .59009 L .50741 .58253 L p .707 .577 .707 r
F P
0 g
s
.50741 .58253 m .49859 .52676 L .49144 .53432 L p .707 .577 .707 r
F P
0 g
s
.35915 .73785 m .35385 .71959 L .33398 .7214 L p .707 .577 .707 r
F P
0 g
s
.29986 .56043 m .30868 .6162 L .32099 .62047 L p .707 .577 .707 r
F P
0 g
s
.33398 .7214 m .33928 .73966 L .35915 .73785 L p .707 .577 .707 r
F P
0 g
s
.49237 .67871 m .49767 .69697 L .51383 .68815 L p .707 .577 .707 r
F P
0 g
s
.51383 .68815 m .50853 .66989 L .49237 .67871 L p .707 .577 .707 r
F P
0 g
s
.7254 .61146 m .71658 .55569 L .74805 .55036 L p .707 .577 .707 r
F P
0 g
s
.71658 .55569 m .7254 .61146 L .6963 .61846 L p .707 .577 .707 r
F P
0 g
s
.69181 .73559 m .68651 .71733 L .70996 .70747 L p .707 .577 .707 r
F P
0 g
s
.74805 .55036 m .75687 .60613 L .7254 .61146 L p .707 .577 .707 r
F P
0 g
s
.70996 .70747 m .71525 .72573 L .69181 .73559 L p .707 .577 .707 r
F P
0 g
s
.82503 .67645 m .83033 .69471 L .80419 .69948 L p .707 .577 .707 r
F P
0 g
s
.80419 .69948 m .79889 .68122 L .82503 .67645 L p .707 .577 .707 r
F P
0 g
s
.33182 .69069 m .3223 .65396 L .31047 .65196 L p .707 .577 .707 r
F P
0 g
s
.70761 .68477 m .69809 .64804 L .72671 .63877 L p .707 .577 .707 r
F P
0 g
s
.7877 .62425 m .79722 .66099 L .76711 .66731 L p .707 .577 .707 r
F P
0 g
s
.76711 .66731 m .75759 .63057 L .7877 .62425 L p .707 .577 .707 r
F P
0 g
s
.31047 .65196 m .31999 .6887 L .33182 .69069 L p .707 .577 .707 r
F P
0 g
s
.49818 .60728 m .5077 .64402 L .51495 .63695 L p .707 .577 .707 r
F P
0 g
s
.51495 .63695 m .50543 .60022 L .49818 .60728 L p .707 .577 .707 r
F P
0 g
s
.72671 .63877 m .73623 .67551 L .70761 .68477 L p .707 .577 .707 r
F P
0 g
s
.30868 .6162 m .29986 .56043 L .29715 .55421 L p .707 .577 .707 r
F P
0 g
s
.73623 .67551 m .72671 .63877 L .75759 .63057 L p .707 .577 .707 r
F P
0 g
s
.71525 .72573 m .70996 .70747 L .73839 .69753 L p .707 .577 .707 r
F P
0 g
s
.75759 .63057 m .76711 .66731 L .73623 .67551 L p .707 .577 .707 r
F P
0 g
s
.33928 .73966 m .33398 .7214 L .32234 .72007 L p .707 .577 .707 r
F P
0 g
s
.79889 .68122 m .80419 .69948 L .77434 .70675 L p .707 .577 .707 r
F P
0 g
s
.77434 .70675 m .76904 .68848 L .79889 .68122 L p .707 .577 .707 r
F P
0 g
s
.73839 .69753 m .74369 .71579 L .71525 .72573 L p .707 .577 .707 r
F P
0 g
s
.32234 .72007 m .32763 .73834 L .33928 .73966 L p .707 .577 .707 r
F P
0 g
s
.49859 .52676 m .50741 .58253 L .50469 .5763 L p .707 .577 .707 r
F P
0 g
s
.50469 .5763 m .49587 .52053 L .49859 .52676 L p .707 .577 .707 r
F P
0 g
s
.50853 .66989 m .51383 .68815 L .52112 .68124 L p .707 .577 .707 r
F P
0 g
s
.52112 .68124 m .51582 .66298 L .50853 .66989 L p .707 .577 .707 r
F P
0 g
s
.29715 .55421 m .30597 .60998 L .30868 .6162 L p .707 .577 .707 r
F P
0 g
s
.74369 .71579 m .73839 .69753 L .76904 .68848 L p .707 .577 .707 r
F P
0 g
s
.76904 .68848 m .77434 .70675 L .74369 .71579 L p .707 .577 .707 r
F P
0 g
s
.31999 .6887 m .31047 .65196 L .30806 .6472 L p .707 .577 .707 r
F P
0 g
s
.30806 .6472 m .31758 .68393 L .31999 .6887 L p .707 .577 .707 r
F P
0 g
s
.50543 .60022 m .51495 .63695 L .51254 .63219 L p .707 .577 .707 r
F P
0 g
s
.51254 .63219 m .50302 .59546 L .50543 .60022 L p .707 .577 .707 r
F P
0 g
s
.30597 .60998 m .29715 .55421 L .3043 .54665 L p .707 .577 .707 r
F P
0 g
s
.32763 .73834 m .32234 .72007 L .32005 .71574 L p .707 .577 .707 r
F P
0 g
s
.32005 .71574 m .32534 .73401 L .32763 .73834 L p .707 .577 .707 r
F P
0 g
s
.51582 .66298 m .52112 .68124 L .51883 .67691 L p .707 .577 .707 r
F P
0 g
s
.51883 .67691 m .51353 .65864 L .51582 .66298 L p .707 .577 .707 r
F P
0 g
s
.49587 .52053 m .50469 .5763 L .49239 .57204 L p .707 .577 .707 r
F P
0 g
s
.49239 .57204 m .48357 .51627 L .49587 .52053 L p .707 .577 .707 r
F P
0 g
s
.3043 .54665 m .31312 .60242 L .30597 .60998 L p .707 .577 .707 r
F P
0 g
s
.31758 .68393 m .30806 .6472 L .31531 .64014 L p .707 .577 .707 r
F P
0 g
s
.31531 .64014 m .32483 .67687 L .31758 .68393 L p .707 .577 .707 r
F P
0 g
s
.50302 .59546 m .51254 .63219 L .50071 .63019 L p .707 .577 .707 r
F P
0 g
s
.50071 .63019 m .49118 .59346 L .50302 .59546 L p .707 .577 .707 r
F P
0 g
s
.31312 .60242 m .3043 .54665 L .3206 .53848 L p .707 .577 .707 r
F P
0 g
s
.32534 .73401 m .32005 .71574 L .32734 .70883 L p .707 .577 .707 r
F P
0 g
s
.32734 .70883 m .33263 .72709 L .32534 .73401 L p .707 .577 .707 r
F P
0 g
s
.48357 .51627 m .49239 .57204 L .47169 .57014 L p .707 .577 .707 r
F P
0 g
s
.47169 .57014 m .46287 .51437 L .48357 .51627 L p .707 .577 .707 r
F P
0 g
s
.51353 .65864 m .51883 .67691 L .50718 .67558 L p .707 .577 .707 r
F P
0 g
s
.50718 .67558 m .50189 .65732 L .51353 .65864 L p .707 .577 .707 r
F P
0 g
s
.3206 .53848 m .32942 .59425 L .31312 .60242 L p .707 .577 .707 r
F P
0 g
s
.32483 .67687 m .31531 .64014 L .33151 .63147 L p .707 .577 .707 r
F P
0 g
s
.32942 .59425 m .3206 .53848 L .34447 .53051 L p .707 .577 .707 r
F P
0 g
s
.33151 .63147 m .34103 .6682 L .32483 .67687 L p .707 .577 .707 r
F P
0 g
s
.49118 .59346 m .50071 .63019 L .48061 .63116 L p .707 .577 .707 r
F P
0 g
s
.48061 .63116 m .47109 .59442 L .49118 .59346 L p .707 .577 .707 r
F P
0 g
s
.46287 .51437 m .47169 .57014 L .44464 .5708 L p .707 .577 .707 r
F P
0 g
s
.44464 .5708 m .43581 .51503 L .46287 .51437 L p .707 .577 .707 r
F P
0 g
s
.33263 .72709 m .32734 .70883 L .3435 .70001 L p .707 .577 .707 r
F P
0 g
s
.34447 .53051 m .35329 .58628 L .32942 .59425 L p .707 .577 .707 r
F P
0 g
s
.3435 .70001 m .34879 .71827 L .33263 .72709 L p .707 .577 .707 r
F P
0 g
s
.50189 .65732 m .50718 .67558 L .48732 .6774 L p .707 .577 .707 r
F P
0 g
s
.48732 .6774 m .48202 .65913 L .50189 .65732 L p .707 .577 .707 r
F P
0 g
s
.35329 .58628 m .34447 .53051 L .37357 .52351 L p .707 .577 .707 r
F P
0 g
s
.34103 .6682 m .33151 .63147 L .35508 .62204 L p .707 .577 .707 r
F P
0 g
s
.43581 .51503 m .44464 .5708 L .41386 .57395 L p .707 .577 .707 r
F P
0 g
s
.41386 .57395 m .40504 .51818 L .43581 .51503 L p .707 .577 .707 r
F P
0 g
s
.47109 .59442 m .48061 .63116 L .45421 .63499 L p .707 .577 .707 r
F P
0 g
s
.45421 .63499 m .44469 .59825 L .47109 .59442 L p .707 .577 .707 r
F P
0 g
s
.35508 .62204 m .3646 .65877 L .34103 .6682 L p .707 .577 .707 r
F P
0 g
s
.38239 .57928 m .37357 .52351 L .40504 .51818 L p .707 .577 .707 r
F P
0 g
s
.37357 .52351 m .38239 .57928 L .35329 .58628 L p .707 .577 .707 r
F P
0 g
s
.40504 .51818 m .41386 .57395 L .38239 .57928 L p .707 .577 .707 r
F P
0 g
s
.34879 .71827 m .3435 .70001 L .36694 .69015 L p .707 .577 .707 r
F P
0 g
s
.36694 .69015 m .37224 .70841 L .34879 .71827 L p .707 .577 .707 r
F P
0 g
s
.48202 .65913 m .48732 .6774 L .46118 .68217 L p .707 .577 .707 r
F P
0 g
s
.46118 .68217 m .45588 .6639 L .48202 .65913 L p .707 .577 .707 r
F P
0 g
s
.3646 .65877 m .35508 .62204 L .3837 .61277 L p .707 .577 .707 r
F P
0 g
s
.44469 .59825 m .45421 .63499 L .4241 .64131 L p .707 .577 .707 r
F P
0 g
s
.4241 .64131 m .41458 .60458 L .44469 .59825 L p .707 .577 .707 r
F P
0 g
s
.3837 .61277 m .39322 .64951 L .3646 .65877 L p .707 .577 .707 r
F P
0 g
s
.39322 .64951 m .3837 .61277 L .41458 .60458 L p .707 .577 .707 r
F P
0 g
s
.41458 .60458 m .4241 .64131 L .39322 .64951 L p .707 .577 .707 r
F P
0 g
s
.37224 .70841 m .36694 .69015 L .39538 .68021 L p .707 .577 .707 r
F P
0 g
s
.45588 .6639 m .46118 .68217 L .43132 .68943 L p .707 .577 .707 r
F P
0 g
s
.43132 .68943 m .42603 .67117 L .45588 .6639 L p .707 .577 .707 r
F P
0 g
s
.39538 .68021 m .40068 .69847 L .37224 .70841 L p .707 .577 .707 r
F P
0 g
s
.40068 .69847 m .39538 .68021 L .42603 .67117 L p .707 .577 .707 r
F P
0 g
s
.42603 .67117 m .43132 .68943 L .40068 .69847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
SGoo5000O7oo0024Ool9000DFUH7001eOol0081oo`@0009JEP03001JEUYF01mJEP<0079oo`00O7oo
10001UYF00<005YFFUH08UYF00<007ooOol0Kgoo001gOol5000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00Oomoo`1_Ool0075oo`H0009JEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06moo`00KGoo1000
25YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Kgoo001[Ool200000eYF001JEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1_Ool006Qoo`<000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06moo`00IWoo0P001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00L7oo001SOol30009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUIJEP04FUI`Ool0065oo`800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEW1oo`00Ggoo0P00
0eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KWoo001MOol20005FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005aoo`8000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06ioo`00G7oo0P001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Kgoo001KOol0
0`00FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001_Ool005]oo`04001JEUYF0006FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEVmoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06eoo`00G7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0KGoo
001LOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001^Ool005aoo`03001JEP00
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006ioo`00G7oo00@005YFFUH000IJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH2001^Ool005aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVioo`00G7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVioo`00GGoo00<0
05YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0K7oo001MOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001]Ool005eoo`03001JEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP03001JEUYF009JEP8006eoo`00GGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001]Ool005eoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00KGoo001MOol01000
FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFKGoo001MOol01000FUIJEP001eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0Jgoo001NOol00`00FUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001/Ool005ioo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06aoo`00GWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006aoo`00GWoo00@0
05YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001/Ool005ioo`04001JEUYF0006FUH00`00
FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ZOol005ioo`04001JEUYF0007FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUI/Ool005moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Yoo`00Ggoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001O
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8006]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000IJEP03001JEUYF00QJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EV]oo`00H7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JWoo001POol00`00
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001ZOol0061oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00JWoo001POol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Yoo`00H7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Qoo`00H7oo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Qoo`00
HGoo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol00`00FUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00
HGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00<005YF00001eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Qo
o`00HWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo
00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@0
05YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF
0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0007FUH0
0`00FUIJEP06FUHB0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`03001JEP0000MJEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Eoo`00
IGoo00<005YFFUH01`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001UOol0
06Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
001UOol0065oo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol005moo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1SOol005eoo`80009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00FWoo0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF0P00I7oo001HOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0087oo4P00<Woo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol05goo1`0015YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol04goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001DOol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80011oo`@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00E7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8000aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYF001JEP0]Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20008Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUIJEP00FUH0;Goo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUIJEP00FUH0;Goo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo
001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001EOol01000FUIJ
EP000eYF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004
FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001J
EP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001JEUYF0004FUH01000FUIJEUYF
0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo00@005YFFUH000AJEP04001JEP00
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00000eYF0P0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF1`000UYF00@005YF000000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000/
Ool005Ioo`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH9
0003FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002aoo`00EWoo0eYF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF
001JEP04FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUHB0002
FUH2000[Ool0055oo`D00005FUH00000FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH30000
0eYF001JEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP05FUH01000FUIJEUYF1000:goo001:Ool70003
FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF0`0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002]oo`00AWoo10000UYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00@0
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo0011Ool50006FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH0
05YF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002aoo`00?Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH>000/
Ool003Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<000UJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YF
FUH00eYF00@005YFFUH002aoo`00=Woo0`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00AJEP80009JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP07FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:goo000cOol30004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF3@001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00D000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0035o
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEP03001JEUYF
009JEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005
FUH00`00FUIJEP05FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00:Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YFFUH00UYF00<005YFFUH01EYF00H005YF0000
05YF0009FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<0009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000ZOol002eoo`04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YF000005YF0005FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP@0009J
EP@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF000ZOol002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol09goo000]Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF1`00
0UYF00@005YF000000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
009JEP@002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF00MJ
EP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0002Uoo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF2@001EYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP@000MJEP03001JEUYF00EJEP03001JEUYF009JEP8002Yoo`00;Woo00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00AJEP03001JEP0000AJEP<000MJ
EP03001JEUYF00IJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`0YOol002ioo`04001JEUYF0003FUH00`00FUIJEP05FUH0
0`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00AJEP80
0003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002]oo`00;Woo00@005YFFUH000AJEP03001JEUYF00=J
EPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00AJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00MJEP04001JEUYFFUH>0004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF1000
25YF00<005YFFUH01UYF00<005YF00001P000UYF00@005YF000002Uoo`00;Woo00@005YFFUH000AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH50003FUH20005FUH0
1000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP04001JEUYFFUH60003FUH00`00
FUIJEP03FUH00`00FUIJEP02000XOol002ioo`04001JEUYF0004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF00EJEP06001J
EP00001JEP002EYF00<005YFFUH00UYF0`001EYF0`0000=JEP00FUH01EYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF10001eYF
00<005YFFUH01eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00:7oo000^
Ool01@00FUIJEUYF00000eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEP0000800003
FUH005YF009JEP<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000XOol002mo
o`=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP0600000eYF0000000<0007FUH00`00FUIJEP04FUH40005FUH300000eYF001JEP05FUH01000FUIJ
EUYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002Moo`00;goo0eYF0P001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
1eYF00<005YFFUH010001eYF0`000eYF00<005YFFUH01EYF0`002EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH015YF0P000UYF00@005YFFUIJEP<000MJEP03001JEUYF00EJEP<000EJEP03
001JEUYF00IJEP03001JEUYF009JEPd002Moo`00;goo00EJEP00001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH01EYF10000eYF00<005YFFUH00UYF0`001UYF00<005YFFUH015YF0P0035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF0080009JEP03001JEUYF00IJEP04
001JEUYFFUH30008FUH00`00FUIJEP05FUH600001Goo000005YF00001EYF00<005YF00009goo000_
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH400000eYF001JEP08FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00UYF0`001UYF00<005YF00000P0000=JEP00
FUH01eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000EJEP03001JEUYF00EJEP06001JEP00001JEP002UYF00<005YFFUH0
10001Goo0P000eYF00<005YFFUH00eYF0P00:7oo000_Ool20003FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF0000
0P000UYF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP06FUH40006Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`0WOol0
031oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP80009oo`04001JEUYF0002FUH30008FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP02FUH01000FUIJEUYF0`001eYF00<005YFFUH00eYF0`0027oo0P0000=J
EP00FUH01UYF00<005YFFUH00P00:Woo000bOol50003FUH01000FUIJEUYF100015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000P0015YF00<005YFFUH00UYF10000Woo00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF0`0000=JEP00FUH025YF00<005YF00000P00
27oo0`0015YF00<005YFFUH015YF0`00;7oo000gOol80008FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH20002FUH00`00FUIJEP03FUH01000FUH000000UYF1P001UYF00<005YFFUH01EYF100000=JEP00
FUH02UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
000020001EYF00<005YFFUH01EYF0`0027oo0`001eYF00<005YFFUH00eYF0P00;Woo000iOol30000
0eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUIJEUYF1`000eYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEPD000IJEP03001JEUYF00=JEPD000Eo
o`<00003FUH005YF00QJEP03001JEP000080031oo`00=goo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01eYF0P000UYF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP05FUH00`00FUH000070002Ool3
0005FUH00`00FUIJEP05FUH3000cOol003Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP@0009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0004FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP03FUH2000fOol003=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000005FUH01000
FUIJEUYF100017oo100000=JEP00FUH02EYF00<005YF00000P00>7oo000bOol00`00FUIJEP03FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50008FUH200000eYF001JEP05FUH01000
FUIJEUYF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00<005YFFUH00UYF00@005YF0000
009JEPH000IJEP03001JEUYF00IJEP<003]oo`00<Goo0P001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH010001EYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF1P0017oo00@005YFFUH0
00MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00AJEP80009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00=JEP<003ioo`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000QJEP03
001JEUYF00IJEP03001JEP0000D00003FUH0000000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEUYF001JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP000080045o
o`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8000Qoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2
0002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30014Ool0035oo`03001JEP0000AJEP03
001JEUYF00EJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000]oo`=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEQ8000AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00@004Moo`00<Goo00<005YF
000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo0eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH05UYF00@005YFFUIJEPH000MJEP03001JEUYF00MJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF009JEPH004]oo`00<Goo00@005YFFUH000AJEP04001J
EUYFFUH20003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP02FUH00`00FUIJEP020003Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH055YF1P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0000=JEP00FUH00UYF2000D7oo000a
Ool01000FUIJEP0015YF00@005YF000000EJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00
001JEP001eYF00<005YFFUH00eYF00@005YFFUH000=oo`04001JEUYF0007FUH00`00FUIJEP0GFUH6
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH000050004FUH2001A
Ool0039oo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF0080009oo`05001JEUYFFUH00006FUH00`00FUIJEP0A
FUH7000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00Oomoo`1@Ool0039oo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH01000FUIJEUYF10001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009oo`05001JEUYFFUH00006FUH00`00FUIJEP0;FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YFFUIJEP0005=oo`00<Woo
00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01UYF10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF300000=oo`00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P0035YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00002`00D7oo000b
Ool01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH00UYF10001UYF00<005YFFUH01eYF
00<005YF00000`0000=oo`0000001EYF00@005YFFUH0009oo`=JEP03001JEUYF00]JEP8000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP80
009JEP03001JEUYF00=JEP03001JEUYF008004moo`00<goo00@005YFFUH000EJEP03001JEUYF00EJ
EP06001JEP00001JEP002EYF00<005YFFUH015YF10000Woo0`0000=JEP00FUH01EYF0P000goo0eYF
00<005YFFUH02EYF0P001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00P00Cgoo000c
Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03001JEUYF00@000=o
o`<000EJEP03001JEUYF00=JEP03001oogoo009oo`04001JEUYF0009FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0P001EYF00<005YF
FUH00eYF00@005YFFUH004moo`00<goo40001eYF00<005YFFUH015YF1@001Goo0P0000=JEP00FUH0
1EYF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP04001JEP000008FUH00`00FUIJEP02FUH00`00FUIJEP02
001>Ool003ioo`800003FUH005YF00MJEP03001JEUYF00@000Moo`<000=JEP03001JEUYF00EJEP<0
00Moo`03001JEUYF00EJEP8000=JEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP<0009JEP03001JEUYF00AJEP/004ioo`00?7oo0P000eYF00<0
05YFFUH01EYF100027oo0`001UYF00<005YFFUH015YF0P002Goo00<005YFFUH00eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF0P00
1EYF00<005YFFUH0100000=oo`0000001EYF00<005YF0000CWoo000jOol20006FUH00`00FUIJEP02
FUH20009Ool300000eYF001JEP07FUH01000FUIJEUYF0P0037oo0eYF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEP<000IJEP@00003Ool0
000000800003FUH005YF00AJEP8004moo`00>7oo0`001eYF00<005YF00000P0027oo0`0015YF00<0
05YFFUH01UYF00@005YF000000ioo`9JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH000000UYF00<005YFFUH010000Woo0`001EYF
00<005YFFUH00eYF00<007ooOol0CWoo000fOol20003FUH00`00FUIJEP04FUH20008Ool30008FUH0
0`00FUIJEP04FUH3000@Ool00eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0GFUH00`00FUIJ
EP07FUH40002FUH50004Ool200000eYF001JEP06FUH00`00FUIJEP02001AOol003Aoo`<000AJEP03
001JEUYF009JEP8000Ioo`@00003FUH005YF00QJEP03001JEUYF00@001=oo`8000]JEP03001JEUYF
00QJEP03001JEUYF01MJEP04001JEUYFFUH60002FUH40006Ool30004FUH00`00FUIJEP04FUH3001C
Ool003=oo`04001JEUYF0005FUH01000FUH000000Woo1P001UYF00<005YFFUH01EYF10005goo0P00
15YF00<005YFFUH07EYF00<005YFFUH01eYF1P0015YF10001goo0`001eYF00<005YFFUH015YF00<0
07ooOol0Dgoo000cOol01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH01UYF00<005YFFUH00eYF
0P0077oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00@005YF
FUIJEPH0009JEP03001JEUYF00=JEP@000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEP8005Io
o`00=7oo00D005YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
01ioo`<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEPL00003FUH005YF00IJ
EP03001JEP0000L0009oo`<000EJEP03001JEUYF00IJEP04001JEP00001HOol003Aoo`03001JEUYF
008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@002Aoo`H000AJEP03001JEUYF00QJEP04001J
EUYFFUH60003Ool20003FUH00`00FUIJEP04FUH30003Ool70008FUH00`00FUIJEP05FUH3001JOol0
03Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@002iooa<000Qoo`8000EJEP04
001JEUYFFUH20006Ool6000:FUH00`00FUIJEP04001MOol003Eoo`04001JEUYF0006FUH01000FUIJ
EUYF1P00C7oo00@005YFFUH000AJEP04001JEP000002Ool6000015YF000000000UYF00<005YFFUH0
1UYF1000HGoo000eOol20002FUH01000FUIJEUYF1P00DWoo00@005YFFUH000AJEPH000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP<006Eoo`00=Woo1`00F7oo00H005YFFUIJEP00FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00002001XOol009Ioo`03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP<006]oo`00UWoo10001UYF00<005YFFUH01EYF00<005YFFUH01000
KWoo002FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6001bOol009Ioo`80009JEP04001J
EUYFFUH7001hOol009Moo`L007moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60191 .74543 m .59644 .68956 L .56542 .69078 L p .707 .577 .707 r
F P
0 g
s
.59644 .68956 m .60191 .74543 L .63361 .74184 L p .707 .577 .707 r
F P
0 g
s
.63361 .74184 m .62814 .68596 L .59644 .68956 L p .707 .577 .707 r
F P
0 g
s
.62814 .68596 m .63361 .74184 L .66288 .73623 L p .707 .577 .707 r
F P
0 g
s
.66288 .73623 m .65741 .68035 L .62814 .68596 L p .707 .577 .707 r
F P
0 g
s
.57089 .74665 m .56542 .69078 L .53812 .6895 L p .707 .577 .707 r
F P
0 g
s
.56542 .69078 m .57089 .74665 L .60191 .74543 L p .707 .577 .707 r
F P
0 g
s
.65741 .68035 m .66288 .73623 L .68686 .72915 L p .707 .577 .707 r
F P
0 g
s
.68686 .72915 m .6814 .67327 L .65741 .68035 L p .707 .577 .707 r
F P
0 g
s
.60759 .80244 m .60166 .76526 L .57089 .76845 L p .707 .577 .707 r
F P
0 g
s
.60166 .76526 m .60759 .80244 L .63906 .79707 L p .707 .577 .707 r
F P
0 g
s
.63906 .79707 m .63313 .75989 L .60166 .76526 L p .707 .577 .707 r
F P
0 g
s
.63313 .75989 m .63906 .79707 L .66815 .79004 L p .707 .577 .707 r
F P
0 g
s
.66815 .79004 m .66222 .75286 L .63313 .75989 L p .707 .577 .707 r
F P
0 g
s
.53812 .6895 m .54359 .74538 L .57089 .74665 L p .707 .577 .707 r
F P
0 g
s
.54359 .74538 m .53812 .6895 L .5172 .68587 L p .707 .577 .707 r
F P
0 g
s
.57089 .76845 m .57682 .80563 L .60759 .80244 L p .707 .577 .707 r
F P
0 g
s
.57682 .80563 m .57089 .76845 L .54384 .76916 L p .707 .577 .707 r
F P
0 g
s
.66222 .75286 m .66815 .79004 L .69202 .78205 L p .707 .577 .707 r
F P
0 g
s
.69202 .78205 m .68609 .74487 L .66222 .75286 L p .707 .577 .707 r
F P
0 g
s
.61179 .84156 m .60849 .823 L .57782 .82678 L p .707 .577 .707 r
F P
0 g
s
.60849 .823 m .61179 .84156 L .64317 .83566 L p .707 .577 .707 r
F P
0 g
s
.64317 .83566 m .63986 .81709 L .60849 .823 L p .707 .577 .707 r
F P
0 g
s
.6814 .67327 m .68686 .72915 L .70321 .72128 L p .707 .577 .707 r
F P
0 g
s
.70321 .72128 m .69774 .6654 L .6814 .67327 L p .707 .577 .707 r
F P
0 g
s
.63986 .81709 m .64317 .83566 L .67219 .82821 L p .707 .577 .707 r
F P
0 g
s
.67219 .82821 m .66888 .80965 L .63986 .81709 L p .707 .577 .707 r
F P
0 g
s
.54384 .76916 m .54977 .80633 L .57682 .80563 L p .707 .577 .707 r
F P
0 g
s
.57782 .82678 m .58112 .84534 L .61179 .84156 L p .707 .577 .707 r
F P
0 g
s
.5172 .68587 m .52267 .74174 L .54359 .74538 L p .707 .577 .707 r
F P
0 g
s
.58112 .84534 m .57782 .82678 L .55087 .82807 L p .707 .577 .707 r
F P
0 g
s
.54977 .80633 m .54384 .76916 L .52316 .7673 L p .707 .577 .707 r
F P
0 g
s
.55087 .82807 m .55417 .84663 L .58112 .84534 L p .707 .577 .707 r
F P
0 g
s
.66888 .80965 m .67219 .82821 L .69601 .81995 L p .707 .577 .707 r
F P
0 g
s
.69601 .81995 m .6927 .80139 L .66888 .80965 L p .707 .577 .707 r
F P
0 g
s
.52267 .74174 m .5172 .68587 L .50472 .68022 L p .707 .577 .707 r
F P
0 g
s
.68609 .74487 m .69202 .78205 L .70832 .77388 L p .707 .577 .707 r
F P
0 g
s
.70832 .77388 m .70239 .7367 L .68609 .74487 L p .707 .577 .707 r
F P
0 g
s
.52316 .7673 m .52908 .80447 L .54977 .80633 L p .707 .577 .707 r
F P
0 g
s
.55417 .84663 m .55087 .82807 L .53027 .82674 L p .707 .577 .707 r
F P
0 g
s
.69774 .6654 m .70321 .72128 L .71032 .71341 L p .707 .577 .707 r
F P
0 g
s
.71032 .71341 m .70485 .65753 L .69774 .6654 L p .707 .577 .707 r
F P
0 g
s
.53027 .82674 m .53357 .8453 L .55417 .84663 L p .707 .577 .707 r
F P
0 g
s
.50472 .68022 m .51019 .73609 L .52267 .74174 L p .707 .577 .707 r
F P
0 g
s
.6927 .80139 m .69601 .81995 L .7123 .81168 L p .707 .577 .707 r
F P
0 g
s
.7123 .81168 m .70899 .79312 L .6927 .80139 L p .707 .577 .707 r
F P
0 g
s
.52908 .80447 m .52316 .7673 L .51085 .76306 L p .707 .577 .707 r
F P
0 g
s
.51085 .76306 m .51678 .80024 L .52908 .80447 L p .707 .577 .707 r
F P
0 g
s
.51019 .73609 m .50472 .68022 L .50189 .67311 L p .707 .577 .707 r
F P
0 g
s
.70239 .7367 m .70832 .77388 L .71547 .76632 L p .707 .577 .707 r
F P
0 g
s
.71547 .76632 m .70954 .72914 L .70239 .7367 L p .707 .577 .707 r
F P
0 g
s
.53357 .8453 m .53027 .82674 L .51804 .82293 L p .707 .577 .707 r
F P
0 g
s
.51804 .82293 m .52134 .84149 L .53357 .8453 L p .707 .577 .707 r
F P
0 g
s
.70485 .65753 m .71032 .71341 L .70749 .70631 L p .707 .577 .707 r
F P
0 g
s
.70749 .70631 m .70202 .65043 L .70485 .65753 L p .707 .577 .707 r
F P
0 g
s
.50189 .67311 m .50736 .72899 L .51019 .73609 L p .707 .577 .707 r
F P
0 g
s
.70899 .79312 m .7123 .81168 L .71946 .80422 L p .707 .577 .707 r
F P
0 g
s
.71946 .80422 m .71616 .78565 L .70899 .79312 L p .707 .577 .707 r
F P
0 g
s
.51678 .80024 m .51085 .76306 L .50814 .75686 L p .707 .577 .707 r
F P
0 g
s
.50814 .75686 m .51407 .79403 L .51678 .80024 L p .707 .577 .707 r
F P
0 g
s
.70954 .72914 m .71547 .76632 L .71276 .76012 L p .707 .577 .707 r
F P
0 g
s
.71276 .76012 m .70683 .72294 L .70954 .72914 L p .707 .577 .707 r
F P
0 g
s
.50736 .72899 m .50189 .67311 L .509 .66524 L p .707 .577 .707 r
F P
0 g
s
.52134 .84149 m .51804 .82293 L .51537 .817 L p .707 .577 .707 r
F P
0 g
s
.509 .66524 m .51447 .72112 L .50736 .72899 L p .707 .577 .707 r
F P
0 g
s
.51407 .79403 m .50814 .75686 L .51529 .7493 L p .707 .577 .707 r
F P
0 g
s
.51537 .817 m .51868 .83556 L .52134 .84149 L p .707 .577 .707 r
F P
0 g
s
.51868 .83556 m .51537 .817 L .52254 .80953 L p .707 .577 .707 r
F P
0 g
s
.51621 .81895 m .46711 .31438 L .42331 .31608 L p .707 .577 .707 r
F P
0 g
s
.51529 .7493 m .52122 .78648 L .51407 .79403 L p .707 .577 .707 r
F P
0 g
s
.51447 .72112 m .509 .66524 L .52535 .65738 L p .707 .577 .707 r
F P
0 g
s
.52254 .80953 m .52584 .82809 L .51868 .83556 L p .707 .577 .707 r
F P
0 g
s
.52535 .65738 m .53081 .71325 L .51447 .72112 L p .707 .577 .707 r
F P
0 g
s
.52122 .78648 m .51529 .7493 L .5316 .74113 L p .707 .577 .707 r
F P
0 g
s
.53081 .71325 m .52535 .65738 L .54933 .65029 L p .707 .577 .707 r
F P
0 g
s
.5316 .74113 m .53753 .7783 L .52122 .78648 L p .707 .577 .707 r
F P
0 g
s
.52584 .82809 m .52254 .80953 L .53883 .80126 L p .707 .577 .707 r
F P
0 g
s
.53883 .80126 m .54213 .81983 L .52584 .82809 L p .707 .577 .707 r
F P
0 g
s
.54933 .65029 m .5548 .70617 L .53081 .71325 L p .707 .577 .707 r
F P
0 g
s
.53753 .7783 m .5316 .74113 L .55546 .73313 L p .707 .577 .707 r
F P
0 g
s
.55546 .73313 m .56139 .77031 L .53753 .7783 L p .707 .577 .707 r
F P
0 g
s
.54213 .81983 m .53883 .80126 L .56265 .793 L p .707 .577 .707 r
F P
0 g
s
.56265 .793 m .56595 .81157 L .54213 .81983 L p .707 .577 .707 r
F P
0 g
s
.46711 .31438 m .51621 .81895 L .56096 .8139 L p .707 .577 .707 r
F P
0 g
s
.56096 .8139 m .51186 .30933 L .46711 .31438 L p .707 .577 .707 r
F P
0 g
s
.5548 .70617 m .54933 .65029 L .5786 .64468 L p .707 .577 .707 r
F P
0 g
s
.5786 .64468 m .58407 .70056 L .5548 .70617 L p .707 .577 .707 r
F P
0 g
s
.56139 .77031 m .55546 .73313 L .58455 .72611 L p .707 .577 .707 r
F P
0 g
s
.58455 .72611 m .59048 .76329 L .56139 .77031 L p .707 .577 .707 r
F P
0 g
s
.59048 .76329 m .58455 .72611 L .61602 .72074 L p .707 .577 .707 r
F P
0 g
s
.61602 .72074 m .62195 .75791 L .59048 .76329 L p .707 .577 .707 r
F P
0 g
s
.56595 .81157 m .56265 .793 L .59167 .78556 L p .707 .577 .707 r
F P
0 g
s
.59167 .78556 m .59497 .80412 L .56595 .81157 L p .707 .577 .707 r
F P
0 g
s
.59497 .80412 m .59167 .78556 L .62305 .77965 L p .707 .577 .707 r
F P
0 g
s
.62305 .77965 m .62635 .79821 L .59497 .80412 L p .707 .577 .707 r
F P
0 g
s
.51186 .30933 m .56096 .8139 L .60229 .80599 L p .707 .577 .707 r
F P
0 g
s
.58407 .70056 m .5786 .64468 L .6103 .64109 L p .707 .577 .707 r
F P
0 g
s
.6103 .64109 m .61577 .69696 L .58407 .70056 L p .707 .577 .707 r
F P
0 g
s
.60229 .80599 m .55319 .30143 L .51186 .30933 L p .707 .577 .707 r
F P
0 g
s
.71616 .78565 m .71946 .80422 L .7168 .79829 L p .707 .577 .707 r
F P
0 g
s
.7168 .79829 m .71349 .77972 L .71616 .78565 L p .707 .577 .707 r
F P
0 g
s
.70202 .65043 m .70749 .70631 L .69501 .70066 L p .707 .577 .707 r
F P
0 g
s
.69501 .70066 m .68954 .64478 L .70202 .65043 L p .707 .577 .707 r
F P
0 g
s
.47242 .82065 m .42331 .31608 L .38476 .31426 L p .707 .577 .707 r
F P
0 g
s
.42331 .31608 m .47242 .82065 L .51621 .81895 L p .707 .577 .707 r
F P
0 g
s
.64132 .63987 m .64678 .69574 L .61577 .69696 L p .707 .577 .707 r
F P
0 g
s
.61577 .69696 m .6103 .64109 L .64132 .63987 L p .707 .577 .707 r
F P
0 g
s
.64679 .71754 m .65272 .75472 L .62195 .75791 L p .707 .577 .707 r
F P
0 g
s
.62195 .75791 m .61602 .72074 L .64679 .71754 L p .707 .577 .707 r
F P
0 g
s
.65371 .77587 m .65702 .79443 L .62635 .79821 L p .707 .577 .707 r
F P
0 g
s
.62635 .79821 m .62305 .77965 L .65371 .77587 L p .707 .577 .707 r
F P
0 g
s
.55319 .30143 m .60229 .80599 L .63615 .796 L p .707 .577 .707 r
F P
0 g
s
.63615 .796 m .58705 .29144 L .55319 .30143 L p .707 .577 .707 r
F P
0 g
s
.2589 .71148 m .25343 .65561 L .22242 .65683 L p .707 .577 .707 r
F P
0 g
s
.25343 .65561 m .2589 .71148 L .2906 .70789 L p .707 .577 .707 r
F P
0 g
s
.2906 .70789 m .28513 .65201 L .25343 .65561 L p .707 .577 .707 r
F P
0 g
s
.28513 .65201 m .2906 .70789 L .31987 .70228 L p .707 .577 .707 r
F P
0 g
s
.31987 .70228 m .3144 .6464 L .28513 .65201 L p .707 .577 .707 r
F P
0 g
s
.70683 .72294 m .71276 .76012 L .70046 .75588 L p .707 .577 .707 r
F P
0 g
s
.70046 .75588 m .69453 .7187 L .70683 .72294 L p .707 .577 .707 r
F P
0 g
s
.22788 .7127 m .22242 .65683 L .19511 .65555 L p .707 .577 .707 r
F P
0 g
s
.22242 .65683 m .22788 .7127 L .2589 .71148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.43386 .81883 m .38476 .31426 L .35523 .3091 L p .707 .577 .707 r
F P
0 g
s
.38476 .31426 m .43386 .81883 L .47242 .82065 L p .707 .577 .707 r
F P
0 g
s
.3144 .6464 m .31987 .70228 L .34385 .6952 L p .707 .577 .707 r
F P
0 g
s
.34385 .6952 m .33839 .63932 L .3144 .6464 L p .707 .577 .707 r
F P
0 g
s
.68954 .64478 m .69501 .70066 L .67409 .69702 L p .707 .577 .707 r
F P
0 g
s
.67409 .69702 m .66862 .64114 L .68954 .64478 L p .707 .577 .707 r
F P
0 g
s
.71349 .77972 m .7168 .79829 L .70457 .79447 L p .707 .577 .707 r
F P
0 g
s
.70457 .79447 m .70126 .77591 L .71349 .77972 L p .707 .577 .707 r
F P
0 g
s
.26458 .77231 m .25865 .73513 L .22789 .73832 L p .707 .577 .707 r
F P
0 g
s
.25865 .73513 m .26458 .77231 L .29605 .76694 L p .707 .577 .707 r
F P
0 g
s
.29605 .76694 m .29012 .72976 L .25865 .73513 L p .707 .577 .707 r
F P
0 g
s
.19511 .65555 m .20058 .71143 L .22788 .7127 L p .707 .577 .707 r
F P
0 g
s
.29012 .72976 m .29605 .76694 L .32514 .75991 L p .707 .577 .707 r
F P
0 g
s
.32514 .75991 m .31921 .72273 L .29012 .72976 L p .707 .577 .707 r
F P
0 g
s
.20058 .71143 m .19511 .65555 L .17419 .65192 L p .707 .577 .707 r
F P
0 g
s
.67384 .71684 m .67977 .75402 L .65272 .75472 L p .707 .577 .707 r
F P
0 g
s
.65272 .75472 m .64679 .71754 L .67384 .71684 L p .707 .577 .707 r
F P
0 g
s
.65702 .79443 m .65371 .77587 L .68066 .77458 L p .707 .577 .707 r
F P
0 g
s
.58705 .29144 m .63615 .796 L .65922 .78491 L p .707 .577 .707 r
F P
0 g
s
.66862 .64114 m .67409 .69702 L .64678 .69574 L p .707 .577 .707 r
F P
0 g
s
.64678 .69574 m .64132 .63987 L .66862 .64114 L p .707 .577 .707 r
F P
0 g
s
.65922 .78491 m .61012 .28034 L .58705 .29144 L p .707 .577 .707 r
F P
0 g
s
.22789 .73832 m .23382 .7755 L .26458 .77231 L p .707 .577 .707 r
F P
0 g
s
.23382 .7755 m .22789 .73832 L .20083 .73903 L p .707 .577 .707 r
F P
0 g
s
.31921 .72273 m .32514 .75991 L .34901 .75192 L p .707 .577 .707 r
F P
0 g
s
.34901 .75192 m .34308 .71474 L .31921 .72273 L p .707 .577 .707 r
F P
0 g
s
.33839 .63932 m .34385 .6952 L .3602 .68733 L p .707 .577 .707 r
F P
0 g
s
.3602 .68733 m .35473 .63145 L .33839 .63932 L p .707 .577 .707 r
F P
0 g
s
.26878 .8168 m .26548 .79823 L .23481 .80202 L p .707 .577 .707 r
F P
0 g
s
.26548 .79823 m .26878 .8168 L .30016 .81089 L p .707 .577 .707 r
F P
0 g
s
.30016 .81089 m .29686 .79233 L .26548 .79823 L p .707 .577 .707 r
F P
0 g
s
.69453 .7187 m .70046 .75588 L .67977 .75402 L p .707 .577 .707 r
F P
0 g
s
.67977 .75402 m .67384 .71684 L .69453 .7187 L p .707 .577 .707 r
F P
0 g
s
.20083 .73903 m .20676 .7762 L .23382 .7755 L p .707 .577 .707 r
F P
0 g
s
.29686 .79233 m .30016 .81089 L .32918 .80345 L p .707 .577 .707 r
F P
0 g
s
.32918 .80345 m .32587 .78488 L .29686 .79233 L p .707 .577 .707 r
F P
0 g
s
.17419 .65192 m .17966 .70779 L .20058 .71143 L p .707 .577 .707 r
F P
0 g
s
.23481 .80202 m .23811 .82058 L .26878 .8168 L p .707 .577 .707 r
F P
0 g
s
.23811 .82058 m .23481 .80202 L .20786 .80331 L p .707 .577 .707 r
F P
0 g
s
.20676 .7762 m .20083 .73903 L .18015 .73717 L p .707 .577 .707 r
F P
0 g
s
.40433 .81367 m .35523 .3091 L .33761 .30111 L p .707 .577 .707 r
F P
0 g
s
.35523 .3091 m .40433 .81367 L .43386 .81883 L p .707 .577 .707 r
F P
0 g
s
.20786 .80331 m .21116 .82187 L .23811 .82058 L p .707 .577 .707 r
F P
0 g
s
.32587 .78488 m .32918 .80345 L .353 .79518 L p .707 .577 .707 r
F P
0 g
s
.353 .79518 m .3497 .77662 L .32587 .78488 L p .707 .577 .707 r
F P
0 g
s
.17966 .70779 m .17419 .65192 L .16171 .64627 L p .707 .577 .707 r
F P
0 g
s
.70126 .77591 m .70457 .79447 L .68397 .79314 L p .707 .577 .707 r
F P
0 g
s
.68397 .79314 m .68066 .77458 L .70126 .77591 L p .707 .577 .707 r
F P
0 g
s
.34308 .71474 m .34901 .75192 L .36531 .74375 L p .707 .577 .707 r
F P
0 g
s
.36531 .74375 m .35938 .70657 L .34308 .71474 L p .707 .577 .707 r
F P
0 g
s
.18015 .73717 m .18608 .77434 L .20676 .7762 L p .707 .577 .707 r
F P
0 g
s
.35473 .63145 m .3602 .68733 L .36731 .67946 L p .707 .577 .707 r
F P
0 g
s
.36731 .67946 m .36184 .62358 L .35473 .63145 L p .707 .577 .707 r
F P
0 g
s
.21116 .82187 m .20786 .80331 L .18726 .80198 L p .707 .577 .707 r
F P
0 g
s
.16171 .64627 m .16718 .70214 L .17966 .70779 L p .707 .577 .707 r
F P
0 g
s
.61012 .28034 m .65922 .78491 L .66926 .77379 L p .707 .577 .707 r
F P
0 g
s
.66926 .77379 m .62015 .26923 L .61012 .28034 L p .707 .577 .707 r
F P
0 g
s
.18726 .80198 m .19056 .82054 L .21116 .82187 L p .707 .577 .707 r
F P
0 g
s
.3497 .77662 m .353 .79518 L .36929 .78692 L p .707 .577 .707 r
F P
0 g
s
.36929 .78692 m .36598 .76835 L .3497 .77662 L p .707 .577 .707 r
F P
0 g
s
.18608 .77434 m .18015 .73717 L .16784 .73293 L p .707 .577 .707 r
F P
0 g
s
.68066 .77458 m .68397 .79314 L .65702 .79443 L p .707 .577 .707 r
F P
0 g
s
.16718 .70214 m .16171 .64627 L .15888 .63916 L p .707 .577 .707 r
F P
0 g
s
.16784 .73293 m .17377 .77011 L .18608 .77434 L p .707 .577 .707 r
F P
0 g
s
.35938 .70657 m .36531 .74375 L .37246 .73619 L p .707 .577 .707 r
F P
0 g
s
.37246 .73619 m .36653 .69901 L .35938 .70657 L p .707 .577 .707 r
F P
0 g
s
.19056 .82054 m .18726 .80198 L .17503 .79816 L p .707 .577 .707 r
F P
0 g
s
.38671 .80568 m .33761 .30111 L .33361 .29106 L p .707 .577 .707 r
F P
0 g
s
.33761 .30111 m .38671 .80568 L .40433 .81367 L p .707 .577 .707 r
F P
0 g
s
.17503 .79816 m .17833 .81672 L .19056 .82054 L p .707 .577 .707 r
F P
0 g
s
.36184 .62358 m .36731 .67946 L .36448 .67236 L p .707 .577 .707 r
F P
0 g
s
.36448 .67236 m .35901 .61648 L .36184 .62358 L p .707 .577 .707 r
F P
0 g
s
.15888 .63916 m .16435 .69504 L .16718 .70214 L p .707 .577 .707 r
F P
0 g
s
.36598 .76835 m .36929 .78692 L .37645 .77945 L p .707 .577 .707 r
F P
0 g
s
.37645 .77945 m .37315 .76089 L .36598 .76835 L p .707 .577 .707 r
F P
0 g
s
.17377 .77011 m .16784 .73293 L .16514 .72673 L p .707 .577 .707 r
F P
0 g
s
.62015 .26923 m .66926 .77379 L .66527 .76375 L p .707 .577 .707 r
F P
0 g
s
.66527 .76375 m .63695 .47281 L p .62015 .26923 L .707 .577 .707 r
F P
0 g
s
.61616 .25918 m .66527 .76375 L .64764 .75575 L p .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .66036 .67526 L .65433 .67318 L p .707 .577 .707 r
F P
0 g
s
.65433 .67318 m .64806 .67102 L p .65563 .68823 L .707 .577 .707 r
F P
0 g
s
.66629 .71244 m .65433 .67318 L .65563 .68823 L .707 .577 .707 r
F
.63695 .47281 m .61616 .25918 L .61906 .26647 L p F P
0 g
s
.61906 .26647 m .62015 .26923 L p .63695 .47281 L .707 .577 .707 r
F P
0 g
s
.16514 .72673 m .17106 .7639 L .17377 .77011 L p .707 .577 .707 r
F P
0 g
s
.16435 .69504 m .15888 .63916 L .16599 .63129 L p .707 .577 .707 r
F P
0 g
s
.36653 .69901 m .37246 .73619 L .36975 .72999 L p .707 .577 .707 r
F P
0 g
s
.36975 .72999 m .36382 .69281 L .36653 .69901 L p .707 .577 .707 r
F P
0 g
s
.17833 .81672 m .17503 .79816 L .17237 .79223 L p .707 .577 .707 r
F P
0 g
s
.17237 .79223 m .17567 .81079 L .17833 .81672 L p .707 .577 .707 r
F P
0 g
s
.35901 .61648 m .36448 .67236 L .352 .66671 L p .707 .577 .707 r
F P
0 g
s
.352 .66671 m .34653 .61083 L .35901 .61648 L p .707 .577 .707 r
F P
0 g
s
.16599 .63129 m .17146 .68717 L .16435 .69504 L p .707 .577 .707 r
F P
0 g
s
.37315 .76089 m .37645 .77945 L .37379 .77352 L p .707 .577 .707 r
F P
0 g
s
.37379 .77352 m .37048 .75496 L .37315 .76089 L p .707 .577 .707 r
F P
0 g
s
.17106 .7639 m .16514 .72673 L .17228 .71917 L p .707 .577 .707 r
F P
0 g
s
.33361 .29106 m .38272 .79563 L .38671 .80568 L p .707 .577 .707 r
F P
0 g
s
.38272 .79563 m .33361 .29106 L .34365 .27995 L p .707 .577 .707 r
F P
0 g
s
.17228 .71917 m .17821 .75635 L .17106 .7639 L p .707 .577 .707 r
F P
0 g
s
.17146 .68717 m .16599 .63129 L .18234 .62343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36382 .69281 m .36975 .72999 L .35745 .72575 L p .707 .577 .707 r
F P
0 g
s
.35745 .72575 m .35152 .68857 L .36382 .69281 L p .707 .577 .707 r
F P
0 g
s
.17567 .81079 m .17237 .79223 L .17953 .78477 L p .707 .577 .707 r
F P
0 g
s
.17953 .78477 m .18283 .80333 L .17567 .81079 L p .707 .577 .707 r
F P
0 g
s
.64764 .75575 m .59854 .25119 L .61616 .25918 L p .707 .577 .707 r
F P
0 g
s
.34653 .61083 m .352 .66671 L .33108 .66307 L p .707 .577 .707 r
F P
0 g
s
.33108 .66307 m .32561 .60719 L .34653 .61083 L p .707 .577 .707 r
F P
0 g
s
.18234 .62343 m .1878 .6793 L .17146 .68717 L p .707 .577 .707 r
F P
0 g
s
.37048 .75496 m .37379 .77352 L .36156 .76971 L p .707 .577 .707 r
F P
0 g
s
.36156 .76971 m .35825 .75114 L .37048 .75496 L p .707 .577 .707 r
F P
0 g
s
.17821 .75635 m .17228 .71917 L .18859 .711 L p .707 .577 .707 r
F P
0 g
s
.1878 .6793 m .18234 .62343 L .20632 .61634 L p .707 .577 .707 r
F P
0 g
s
.18859 .711 m .19452 .74817 L .17821 .75635 L p .707 .577 .707 r
F P
0 g
s
.35152 .68857 m .35745 .72575 L .33676 .72389 L p .707 .577 .707 r
F P
0 g
s
.33676 .72389 m .33083 .68671 L .35152 .68857 L p .707 .577 .707 r
F P
0 g
s
.39275 .78452 m .34365 .27995 L .36672 .26885 L p .707 .577 .707 r
F P
0 g
s
.34365 .27995 m .39275 .78452 L .38272 .79563 L p .707 .577 .707 r
F P
0 g
s
.32561 .60719 m .33108 .66307 L .30378 .66179 L p .707 .577 .707 r
F P
0 g
s
.30378 .66179 m .29831 .60592 L .32561 .60719 L p .707 .577 .707 r
F P
0 g
s
.18283 .80333 m .17953 .78477 L .19582 .7765 L p .707 .577 .707 r
F P
0 g
s
.20632 .61634 m .21179 .67222 L .1878 .6793 L p .707 .577 .707 r
F P
0 g
s
.19582 .7765 m .19912 .79506 L .18283 .80333 L p .707 .577 .707 r
F P
0 g
s
.35825 .75114 m .36156 .76971 L .34096 .76838 L p .707 .577 .707 r
F P
0 g
s
.34096 .76838 m .33765 .74982 L .35825 .75114 L p .707 .577 .707 r
F P
0 g
s
.21179 .67222 m .20632 .61634 L .23559 .61073 L p .707 .577 .707 r
F P
0 g
s
.19452 .74817 m .18859 .711 L .21245 .703 L p .707 .577 .707 r
F P
0 g
s
.59854 .25119 m .64764 .75575 L .61811 .75059 L p .707 .577 .707 r
F P
0 g
s
.61811 .75059 m .56901 .24603 L .59854 .25119 L p .707 .577 .707 r
F P
0 g
s
.29831 .60592 m .30378 .66179 L .27276 .66301 L p .707 .577 .707 r
F P
0 g
s
.27276 .66301 m .26729 .60714 L .29831 .60592 L p .707 .577 .707 r
F P
0 g
s
.33083 .68671 m .33676 .72389 L .30971 .72459 L p .707 .577 .707 r
F P
0 g
s
.30971 .72459 m .30378 .68741 L .33083 .68671 L p .707 .577 .707 r
F P
0 g
s
.21245 .703 m .21838 .74018 L .19452 .74817 L p .707 .577 .707 r
F P
0 g
s
.24106 .66661 m .23559 .61073 L .26729 .60714 L p .707 .577 .707 r
F P
0 g
s
.23559 .61073 m .24106 .66661 L .21179 .67222 L p .707 .577 .707 r
F P
0 g
s
.73912 .6534 m .73365 .59752 L .70263 .59874 L p .707 .577 .707 r
F P
0 g
s
.73365 .59752 m .73912 .6534 L .77081 .6498 L p .707 .577 .707 r
F P
0 g
s
.77081 .6498 m .76535 .59393 L .73365 .59752 L p .707 .577 .707 r
F P
0 g
s
.26729 .60714 m .27276 .66301 L .24106 .66661 L p .707 .577 .707 r
F P
0 g
s
.76535 .59393 m .77081 .6498 L .80009 .64419 L p .707 .577 .707 r
F P
0 g
s
.80009 .64419 m .79462 .58831 L .76535 .59393 L p .707 .577 .707 r
F P
0 g
s
.19912 .79506 m .19582 .7765 L .21964 .76824 L p .707 .577 .707 r
F P
0 g
s
.7081 .65462 m .70263 .59874 L .67532 .59747 L p .707 .577 .707 r
F P
0 g
s
.70263 .59874 m .7081 .65462 L .73912 .6534 L p .707 .577 .707 r
F P
0 g
s
.21964 .76824 m .22294 .7868 L .19912 .79506 L p .707 .577 .707 r
F P
0 g
s
.21838 .74018 m .21245 .703 L .24154 .69598 L p .707 .577 .707 r
F P
0 g
s
.33765 .74982 m .34096 .76838 L .31401 .76967 L p .707 .577 .707 r
F P
0 g
s
.31401 .76967 m .3107 .75111 L .33765 .74982 L p .707 .577 .707 r
F P
0 g
s
.36672 .26885 m .41583 .77342 L .39275 .78452 L p .707 .577 .707 r
F P
0 g
s
.41583 .77342 m .36672 .26885 L .40058 .25886 L p .707 .577 .707 r
F P
0 g
s
.30378 .68741 m .30971 .72459 L .27894 .72778 L p .707 .577 .707 r
F P
0 g
s
.27894 .72778 m .27301 .69061 L .30378 .68741 L p .707 .577 .707 r
F P
0 g
s
.79462 .58831 m .80009 .64419 L .82407 .63711 L p .707 .577 .707 r
F P
0 g
s
.82407 .63711 m .8186 .58123 L .79462 .58831 L p .707 .577 .707 r
F P
0 g
s
.24154 .69598 m .24747 .73316 L .21838 .74018 L p .707 .577 .707 r
F P
0 g
s
.74479 .7104 m .73886 .67322 L .7081 .67642 L p .707 .577 .707 r
F P
0 g
s
.73886 .67322 m .74479 .7104 L .77626 .70503 L p .707 .577 .707 r
F P
0 g
s
.77626 .70503 m .77033 .66785 L .73886 .67322 L p .707 .577 .707 r
F P
0 g
s
.24747 .73316 m .24154 .69598 L .27301 .69061 L p .707 .577 .707 r
F P
0 g
s
.77033 .66785 m .77626 .70503 L .80535 .698 L p .707 .577 .707 r
F P
0 g
s
.80535 .698 m .79942 .66083 L .77033 .66785 L p .707 .577 .707 r
F P
0 g
s
.67532 .59747 m .68079 .65334 L .7081 .65462 L p .707 .577 .707 r
F P
0 g
s
.27301 .69061 m .27894 .72778 L .24747 .73316 L p .707 .577 .707 r
F P
0 g
s
.22294 .7868 m .21964 .76824 L .24866 .76079 L p .707 .577 .707 r
F P
0 g
s
.68079 .65334 m .67532 .59747 L .65441 .59383 L p .707 .577 .707 r
F P
0 g
s
.56901 .24603 m .61811 .75059 L .57956 .74877 L p .707 .577 .707 r
F P
0 g
s
.57956 .74877 m .53046 .24421 L .56901 .24603 L p .707 .577 .707 r
F P
0 g
s
.7081 .67642 m .71403 .71359 L .74479 .7104 L p .707 .577 .707 r
F P
0 g
s
.71403 .71359 m .7081 .67642 L .68105 .67712 L p .707 .577 .707 r
F P
0 g
s
.24866 .76079 m .25196 .77935 L .22294 .7868 L p .707 .577 .707 r
F P
0 g
s
.3107 .75111 m .31401 .76967 L .28334 .77345 L p .707 .577 .707 r
F P
0 g
s
.28334 .77345 m .28004 .75489 L .3107 .75111 L p .707 .577 .707 r
F P
0 g
s
.79942 .66083 m .80535 .698 L .82922 .69001 L p .707 .577 .707 r
F P
0 g
s
.82922 .69001 m .82329 .65284 L .79942 .66083 L p .707 .577 .707 r
F P
0 g
s
.74899 .74952 m .74569 .73096 L .71502 .73474 L p .707 .577 .707 r
F P
0 g
s
.74569 .73096 m .74899 .74952 L .78037 .74362 L p .707 .577 .707 r
F P
0 g
s
.78037 .74362 m .77707 .72506 L .74569 .73096 L p .707 .577 .707 r
F P
0 g
s
.8186 .58123 m .82407 .63711 L .84041 .62924 L p .707 .577 .707 r
F P
0 g
s
.84041 .62924 m .83495 .57337 L .8186 .58123 L p .707 .577 .707 r
F P
0 g
s
.77707 .72506 m .78037 .74362 L .80939 .73617 L p .707 .577 .707 r
F P
0 g
s
.80939 .73617 m .80609 .71761 L .77707 .72506 L p .707 .577 .707 r
F P
0 g
s
.25196 .77935 m .24866 .76079 L .28004 .75489 L p .707 .577 .707 r
F P
0 g
s
.68105 .67712 m .68698 .71429 L .71403 .71359 L p .707 .577 .707 r
F P
0 g
s
.71502 .73474 m .71833 .7533 L .74899 .74952 L p .707 .577 .707 r
F P
0 g
s
.28004 .75489 m .28334 .77345 L .25196 .77935 L p .707 .577 .707 r
F P
0 g
s
.65441 .59383 m .65987 .64971 L .68079 .65334 L p .707 .577 .707 r
F P
0 g
s
.71833 .7533 m .71502 .73474 L .68807 .73603 L p .707 .577 .707 r
F P
0 g
s
.44968 .76343 m .40058 .25886 L .44191 .25096 L p .707 .577 .707 r
F P
0 g
s
.40058 .25886 m .44968 .76343 L .41583 .77342 L p .707 .577 .707 r
F P
0 g
s
.68698 .71429 m .68105 .67712 L .66036 .67526 L p .707 .577 .707 r
F P
0 g
s
.68807 .73603 m .69138 .75459 L .71833 .7533 L p .707 .577 .707 r
F P
0 g
s
.80609 .71761 m .80939 .73617 L .83321 .72791 L p .707 .577 .707 r
F P
0 g
s
.83321 .72791 m .82991 .70935 L .80609 .71761 L p .707 .577 .707 r
F P
0 g
s
.65987 .64971 m .65441 .59383 L .64192 .58818 L p .707 .577 .707 r
F P
0 g
s
.53046 .24421 m .57956 .74877 L .53576 .75047 L p .707 .577 .707 r
F P
0 g
s
.53576 .75047 m .48666 .24591 L .53046 .24421 L p .707 .577 .707 r
F P
0 g
s
.82329 .65284 m .82922 .69001 L .84552 .68184 L p .707 .577 .707 r
F P
0 g
s
.84552 .68184 m .8396 .64466 L .82329 .65284 L p .707 .577 .707 r
F P
0 g
s
.66036 .67526 m .66629 .71244 L .68698 .71429 L p .707 .577 .707 r
F P
0 g
s
.49101 .75552 m .44191 .25096 L .48666 .24591 L p .707 .577 .707 r
F P
0 g
s
.44191 .25096 m .49101 .75552 L .44968 .76343 L p .707 .577 .707 r
F P
0 g
s
.69138 .75459 m .68807 .73603 L .66747 .7347 L p .707 .577 .707 r
F P
0 g
s
.83495 .57337 m .84041 .62924 L .84752 .62137 L p .707 .577 .707 r
F P
0 g
s
.84752 .62137 m .84205 .5655 L .83495 .57337 L p .707 .577 .707 r
F P
0 g
s
.48666 .24591 m .53576 .75047 L .49101 .75552 L p .707 .577 .707 r
F P
0 g
s
.66747 .7347 m .67078 .75327 L .69138 .75459 L p .707 .577 .707 r
F P
0 g
s
.64192 .58818 m .64739 .64406 L .65987 .64971 L p .707 .577 .707 r
F P
0 g
s
.82991 .70935 m .83321 .72791 L .8495 .71964 L p .707 .577 .707 r
F P
0 g
s
.8495 .71964 m .8462 .70108 L .82991 .70935 L p .707 .577 .707 r
F P
0 g
s
.64806 .67102 m .65399 .7082 L .66629 .71244 L p .707 .577 .707 r
F P
0 g
s
.64739 .64406 m .64192 .58818 L .6391 .58107 L p .707 .577 .707 r
F P
0 g
s
.8396 .64466 m .84552 .68184 L .85267 .67428 L p .707 .577 .707 r
F P
0 g
s
.85267 .67428 m .84674 .6371 L .8396 .64466 L p .707 .577 .707 r
F P
0 g
s
.67078 .75327 m .66747 .7347 L .65524 .73089 L p .707 .577 .707 r
F P
0 g
s
.65524 .73089 m .65855 .74945 L .67078 .75327 L p .707 .577 .707 r
F P
0 g
s
.84205 .5655 m .84752 .62137 L .84469 .61427 L p .707 .577 .707 r
F P
0 g
s
.84469 .61427 m .83923 .55839 L .84205 .5655 L p .707 .577 .707 r
F P
0 g
s
.6391 .58107 m .64456 .63695 L .64739 .64406 L p .707 .577 .707 r
F P
0 g
s
.8462 .70108 m .8495 .71964 L .85667 .71218 L p .707 .577 .707 r
F P
0 g
s
.85667 .71218 m .85336 .69362 L .8462 .70108 L p .707 .577 .707 r
F P
0 g
s
.65399 .7082 m .64806 .67102 L .64535 .66482 L p .707 .577 .707 r
F P
0 g
s
.64535 .66482 m .65128 .702 L .65399 .7082 L p .707 .577 .707 r
F P
0 g
s
.84674 .6371 m .85267 .67428 L .84996 .66808 L p .707 .577 .707 r
F P
0 g
s
.84996 .66808 m .84403 .6309 L .84674 .6371 L p .707 .577 .707 r
F P
0 g
s
.64456 .63695 m .6391 .58107 L .6462 .5732 L p .707 .577 .707 r
F P
0 g
s
.65855 .74945 m .65524 .73089 L .65258 .72496 L p .707 .577 .707 r
F P
0 g
s
.65258 .72496 m .65588 .74352 L .65855 .74945 L p .707 .577 .707 r
F P
0 g
s
.85336 .69362 m .85667 .71218 L .854 .70625 L p .707 .577 .707 r
F P
0 g
s
.854 .70625 m .8507 .68769 L .85336 .69362 L p .707 .577 .707 r
F P
0 g
s
.83923 .55839 m .84469 .61427 L .83221 .60862 L p .707 .577 .707 r
F P
0 g
s
.83221 .60862 m .82674 .55274 L .83923 .55839 L p .707 .577 .707 r
F P
0 g
s
.6462 .5732 m .65167 .62908 L .64456 .63695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65128 .702 m .64535 .66482 L .6525 .65726 L p .707 .577 .707 r
F P
0 g
s
.39611 .61945 m .39064 .56357 L .35962 .56479 L p .707 .577 .707 r
F P
0 g
s
.39064 .56357 m .39611 .61945 L .4278 .61585 L p .707 .577 .707 r
F P
0 g
s
.4278 .61585 m .42234 .55997 L .39064 .56357 L p .707 .577 .707 r
F P
0 g
s
.42234 .55997 m .4278 .61585 L .45708 .61024 L p .707 .577 .707 r
F P
0 g
s
.45708 .61024 m .45161 .55436 L .42234 .55997 L p .707 .577 .707 r
F P
0 g
s
.6525 .65726 m .65843 .69444 L .65128 .702 L p .707 .577 .707 r
F P
0 g
s
.65167 .62908 m .6462 .5732 L .66255 .56534 L p .707 .577 .707 r
F P
0 g
s
.84403 .6309 m .84996 .66808 L .83766 .66384 L p .707 .577 .707 r
F P
0 g
s
.83766 .66384 m .83173 .62666 L .84403 .6309 L p .707 .577 .707 r
F P
0 g
s
.36509 .62067 m .35962 .56479 L .33231 .56352 L p .707 .577 .707 r
F P
0 g
s
.35962 .56479 m .36509 .62067 L .39611 .61945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65588 .74352 m .65258 .72496 L .65974 .71749 L p .707 .577 .707 r
F P
0 g
s
.65974 .71749 m .66305 .73606 L .65588 .74352 L p .707 .577 .707 r
F P
0 g
s
.45161 .55436 m .45708 .61024 L .48106 .60316 L p .707 .577 .707 r
F P
0 g
s
.48106 .60316 m .47559 .54728 L .45161 .55436 L p .707 .577 .707 r
F P
0 g
s
.82674 .55274 m .83221 .60862 L .81129 .60498 L p .707 .577 .707 r
F P
0 g
s
.81129 .60498 m .80583 .5491 L .82674 .55274 L p .707 .577 .707 r
F P
0 g
s
.66255 .56534 m .66802 .62122 L .65167 .62908 L p .707 .577 .707 r
F P
0 g
s
.8507 .68769 m .854 .70625 L .84177 .70243 L p .707 .577 .707 r
F P
0 g
s
.84177 .70243 m .83847 .68387 L .8507 .68769 L p .707 .577 .707 r
F P
0 g
s
.40178 .68027 m .39585 .64309 L .36509 .64629 L p .707 .577 .707 r
F P
0 g
s
.39585 .64309 m .40178 .68027 L .43325 .6749 L p .707 .577 .707 r
F P
0 g
s
.43325 .6749 m .42732 .63772 L .39585 .64309 L p .707 .577 .707 r
F P
0 g
s
.33231 .56352 m .33778 .61939 L .36509 .62067 L p .707 .577 .707 r
F P
0 g
s
.42732 .63772 m .43325 .6749 L .46234 .66787 L p .707 .577 .707 r
F P
0 g
s
.46234 .66787 m .45641 .6307 L .42732 .63772 L p .707 .577 .707 r
F P
0 g
s
.33778 .61939 m .33231 .56352 L .3114 .55988 L p .707 .577 .707 r
F P
0 g
s
.65843 .69444 m .6525 .65726 L .6688 .64909 L p .707 .577 .707 r
F P
0 g
s
.36509 .64629 m .37102 .68346 L .40178 .68027 L p .707 .577 .707 r
F P
0 g
s
.37102 .68346 m .36509 .64629 L .33804 .64699 L p .707 .577 .707 r
F P
0 g
s
.66802 .62122 m .66255 .56534 L .68653 .55825 L p .707 .577 .707 r
F P
0 g
s
.45641 .6307 m .46234 .66787 L .48621 .65988 L p .707 .577 .707 r
F P
0 g
s
.48621 .65988 m .48028 .62271 L .45641 .6307 L p .707 .577 .707 r
F P
0 g
s
.47559 .54728 m .48106 .60316 L .4974 .59529 L p .707 .577 .707 r
F P
0 g
s
.4974 .59529 m .49194 .53942 L .47559 .54728 L p .707 .577 .707 r
F P
0 g
s
.6688 .64909 m .67473 .68626 L .65843 .69444 L p .707 .577 .707 r
F P
0 g
s
.40598 .72476 m .40268 .7062 L .37201 .70998 L p .707 .577 .707 r
F P
0 g
s
.40268 .7062 m .40598 .72476 L .43736 .71885 L p .707 .577 .707 r
F P
0 g
s
.43736 .71885 m .43406 .70029 L .40268 .7062 L p .707 .577 .707 r
F P
0 g
s
.83173 .62666 m .83766 .66384 L .81697 .66198 L p .707 .577 .707 r
F P
0 g
s
.81697 .66198 m .81104 .62481 L .83173 .62666 L p .707 .577 .707 r
F P
0 g
s
.33804 .64699 m .34397 .68416 L .37102 .68346 L p .707 .577 .707 r
F P
0 g
s
.43406 .70029 m .43736 .71885 L .46638 .71141 L p .707 .577 .707 r
F P
0 g
s
.46638 .71141 m .46308 .69284 L .43406 .70029 L p .707 .577 .707 r
F P
0 g
s
.3114 .55988 m .31686 .61576 L .33778 .61939 L p .707 .577 .707 r
F P
0 g
s
.37201 .70998 m .37532 .72854 L .40598 .72476 L p .707 .577 .707 r
F P
0 g
s
.66305 .73606 m .65974 .71749 L .67603 .70923 L p .707 .577 .707 r
F P
0 g
s
.80583 .5491 m .81129 .60498 L .78399 .60371 L p .707 .577 .707 r
F P
0 g
s
.78399 .60371 m .77852 .54783 L .80583 .5491 L p .707 .577 .707 r
F P
0 g
s
.37532 .72854 m .37201 .70998 L .34506 .71127 L p .707 .577 .707 r
F P
0 g
s
.67603 .70923 m .67934 .72779 L .66305 .73606 L p .707 .577 .707 r
F P
0 g
s
.68653 .55825 m .692 .61413 L .66802 .62122 L p .707 .577 .707 r
F P
0 g
s
.34397 .68416 m .33804 .64699 L .31735 .64513 L p .707 .577 .707 r
F P
0 g
s
.34506 .71127 m .34837 .72983 L .37532 .72854 L p .707 .577 .707 r
F P
0 g
s
.46308 .69284 m .46638 .71141 L .4902 .70315 L p .707 .577 .707 r
F P
0 g
s
.4902 .70315 m .4869 .68458 L .46308 .69284 L p .707 .577 .707 r
F P
0 g
s
.31686 .61576 m .3114 .55988 L .29891 .55423 L p .707 .577 .707 r
F P
0 g
s
.83847 .68387 m .84177 .70243 L .82117 .7011 L p .707 .577 .707 r
F P
0 g
s
.82117 .7011 m .81787 .68254 L .83847 .68387 L p .707 .577 .707 r
F P
0 g
s
.692 .61413 m .68653 .55825 L .7158 .55264 L p .707 .577 .707 r
F P
0 g
s
.67473 .68626 m .6688 .64909 L .69267 .6411 L p .707 .577 .707 r
F P
0 g
s
.48028 .62271 m .48621 .65988 L .50251 .65171 L p .707 .577 .707 r
F P
0 g
s
.50251 .65171 m .49659 .61453 L .48028 .62271 L p .707 .577 .707 r
F P
0 g
s
.31735 .64513 m .32328 .68231 L .34397 .68416 L p .707 .577 .707 r
F P
0 g
s
.77852 .54783 m .78399 .60371 L .75297 .60493 L p .707 .577 .707 r
F P
0 g
s
.75297 .60493 m .7475 .54905 L .77852 .54783 L p .707 .577 .707 r
F P
0 g
s
.81104 .62481 m .81697 .66198 L .78992 .66268 L p .707 .577 .707 r
F P
0 g
s
.78992 .66268 m .78399 .62551 L .81104 .62481 L p .707 .577 .707 r
F P
0 g
s
.49194 .53942 m .4974 .59529 L .50451 .58742 L p .707 .577 .707 r
F P
0 g
s
.50451 .58742 m .49904 .53155 L .49194 .53942 L p .707 .577 .707 r
F P
0 g
s
.34837 .72983 m .34506 .71127 L .32446 .70994 L p .707 .577 .707 r
F P
0 g
s
.69267 .6411 m .6986 .67827 L .67473 .68626 L p .707 .577 .707 r
F P
0 g
s
.29891 .55423 m .30438 .61011 L .31686 .61576 L p .707 .577 .707 r
F P
0 g
s
.72127 .60852 m .7158 .55264 L .7475 .54905 L p .707 .577 .707 r
F P
0 g
s
.7158 .55264 m .72127 .60852 L .692 .61413 L p .707 .577 .707 r
F P
0 g
s
.32446 .70994 m .32777 .7285 L .34837 .72983 L p .707 .577 .707 r
F P
0 g
s
.7475 .54905 m .75297 .60493 L .72127 .60852 L p .707 .577 .707 r
F P
0 g
s
.67934 .72779 m .67603 .70923 L .69985 .70096 L p .707 .577 .707 r
F P
0 g
s
.4869 .68458 m .4902 .70315 L .50649 .69488 L p .707 .577 .707 r
F P
0 g
s
.50649 .69488 m .50319 .67632 L .4869 .68458 L p .707 .577 .707 r
F P
0 g
s
.32328 .68231 m .31735 .64513 L .30505 .64089 L p .707 .577 .707 r
F P
0 g
s
.69985 .70096 m .70316 .71953 L .67934 .72779 L p .707 .577 .707 r
F P
0 g
s
.6986 .67827 m .69267 .6411 L .72176 .63407 L p .707 .577 .707 r
F P
0 g
s
.81787 .68254 m .82117 .7011 L .79422 .70239 L p .707 .577 .707 r
F P
0 g
s
.79422 .70239 m .79092 .68383 L .81787 .68254 L p .707 .577 .707 r
F P
0 g
s
.78399 .62551 m .78992 .66268 L .75916 .66588 L p .707 .577 .707 r
F P
0 g
s
.75916 .66588 m .75323 .6287 L .78399 .62551 L p .707 .577 .707 r
F P
0 g
s
.30438 .61011 m .29891 .55423 L .29609 .54712 L p .707 .577 .707 r
F P
0 g
s
.30505 .64089 m .31098 .67807 L .32328 .68231 L p .707 .577 .707 r
F P
0 g
s
.49659 .61453 m .50251 .65171 L .50966 .64415 L p .707 .577 .707 r
F P
0 g
s
.50966 .64415 m .50373 .60697 L .49659 .61453 L p .707 .577 .707 r
F P
0 g
s
.72176 .63407 m .72769 .67125 L .6986 .67827 L p .707 .577 .707 r
F P
0 g
s
.72769 .67125 m .72176 .63407 L .75323 .6287 L p .707 .577 .707 r
F P
0 g
s
.32777 .7285 m .32446 .70994 L .31223 .70612 L p .707 .577 .707 r
F P
0 g
s
.75323 .6287 m .75916 .66588 L .72769 .67125 L p .707 .577 .707 r
F P
0 g
s
.70316 .71953 m .69985 .70096 L .72887 .69352 L p .707 .577 .707 r
F P
0 g
s
.31223 .70612 m .31554 .72469 L .32777 .7285 L p .707 .577 .707 r
F P
0 g
s
.72887 .69352 m .73218 .71208 L .70316 .71953 L p .707 .577 .707 r
F P
0 g
s
.49904 .53155 m .50451 .58742 L .50168 .58032 L p .707 .577 .707 r
F P
0 g
s
.50168 .58032 m .49622 .52444 L .49904 .53155 L p .707 .577 .707 r
F P
0 g
s
.79092 .68383 m .79422 .70239 L .76355 .70618 L p .707 .577 .707 r
F P
0 g
s
.76355 .70618 m .76025 .68761 L .79092 .68383 L p .707 .577 .707 r
F P
0 g
s
.29609 .54712 m .30155 .603 L .30438 .61011 L p .707 .577 .707 r
F P
0 g
s
.50319 .67632 m .50649 .69488 L .51366 .68741 L p .707 .577 .707 r
F P
0 g
s
.51366 .68741 m .51035 .66885 L .50319 .67632 L p .707 .577 .707 r
F P
0 g
s
.73218 .71208 m .72887 .69352 L .76025 .68761 L p .707 .577 .707 r
F P
0 g
s
.76025 .68761 m .76355 .70618 L .73218 .71208 L p .707 .577 .707 r
F P
0 g
s
.31098 .67807 m .30505 .64089 L .30234 .63469 L p .707 .577 .707 r
F P
0 g
s
.30234 .63469 m .30827 .67187 L .31098 .67807 L p .707 .577 .707 r
F P
0 g
s
.30155 .603 m .29609 .54712 L .30319 .53925 L p .707 .577 .707 r
F P
0 g
s
.50373 .60697 m .50966 .64415 L .50695 .63795 L p .707 .577 .707 r
F P
0 g
s
.50695 .63795 m .50102 .60077 L .50373 .60697 L p .707 .577 .707 r
F P
0 g
s
.31554 .72469 m .31223 .70612 L .30957 .70019 L p .707 .577 .707 r
F P
0 g
s
.30957 .70019 m .31287 .71876 L .31554 .72469 L p .707 .577 .707 r
F P
0 g
s
.49622 .52444 m .50168 .58032 L .4892 .57467 L p .707 .577 .707 r
F P
0 g
s
.4892 .57467 m .48373 .51879 L .49622 .52444 L p .707 .577 .707 r
F P
0 g
s
.30319 .53925 m .30866 .59513 L .30155 .603 L p .707 .577 .707 r
F P
0 g
s
.51035 .66885 m .51366 .68741 L .51099 .68148 L p .707 .577 .707 r
F P
0 g
s
.51099 .68148 m .50769 .66292 L .51035 .66885 L p .707 .577 .707 r
F P
0 g
s
.30827 .67187 m .30234 .63469 L .30949 .62713 L p .707 .577 .707 r
F P
0 g
s
.30949 .62713 m .31542 .66431 L .30827 .67187 L p .707 .577 .707 r
F P
0 g
s
.30866 .59513 m .30319 .53925 L .31954 .53139 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50102 .60077 m .50695 .63795 L .49465 .63371 L p .707 .577 .707 r
F P
0 g
s
.49465 .63371 m .48872 .59653 L .50102 .60077 L p .707 .577 .707 r
F P
0 g
s
.31287 .71876 m .30957 .70019 L .31673 .69273 L p .707 .577 .707 r
F P
0 g
s
.31673 .69273 m .32004 .71129 L .31287 .71876 L p .707 .577 .707 r
F P
0 g
s
.48373 .51879 m .4892 .57467 L .46828 .57103 L p .707 .577 .707 r
F P
0 g
s
.46828 .57103 m .46282 .51515 L .48373 .51879 L p .707 .577 .707 r
F P
0 g
s
.31954 .53139 m .32501 .58727 L .30866 .59513 L p .707 .577 .707 r
F P
0 g
s
.50769 .66292 m .51099 .68148 L .49876 .67767 L p .707 .577 .707 r
F P
0 g
s
.49876 .67767 m .49546 .6591 L .50769 .66292 L p .707 .577 .707 r
F P
0 g
s
.31542 .66431 m .30949 .62713 L .32579 .61896 L p .707 .577 .707 r
F P
0 g
s
.32501 .58727 m .31954 .53139 L .34352 .5243 L p .707 .577 .707 r
F P
0 g
s
.32579 .61896 m .33172 .65613 L .31542 .66431 L p .707 .577 .707 r
F P
0 g
s
.48872 .59653 m .49465 .63371 L .47396 .63185 L p .707 .577 .707 r
F P
0 g
s
.47396 .63185 m .46803 .59468 L .48872 .59653 L p .707 .577 .707 r
F P
0 g
s
.46282 .51515 m .46828 .57103 L .44098 .56976 L p .707 .577 .707 r
F P
0 g
s
.44098 .56976 m .43551 .51388 L .46282 .51515 L p .707 .577 .707 r
F P
0 g
s
.32004 .71129 m .31673 .69273 L .33302 .68446 L p .707 .577 .707 r
F P
0 g
s
.34352 .5243 m .34899 .58018 L .32501 .58727 L p .707 .577 .707 r
F P
0 g
s
.33302 .68446 m .33632 .70302 L .32004 .71129 L p .707 .577 .707 r
F P
0 g
s
.49546 .6591 m .49876 .67767 L .47816 .67634 L p .707 .577 .707 r
F P
0 g
s
.47816 .67634 m .47486 .65778 L .49546 .6591 L p .707 .577 .707 r
F P
0 g
s
.34899 .58018 m .34352 .5243 L .37279 .51869 L p .707 .577 .707 r
F P
0 g
s
.33172 .65613 m .32579 .61896 L .34966 .61097 L p .707 .577 .707 r
F P
0 g
s
.43551 .51388 m .44098 .56976 L .40996 .57098 L p .707 .577 .707 r
F P
0 g
s
.40996 .57098 m .40449 .5151 L .43551 .51388 L p .707 .577 .707 r
F P
0 g
s
.46803 .59468 m .47396 .63185 L .44691 .63255 L p .707 .577 .707 r
F P
0 g
s
.44691 .63255 m .44098 .59538 L .46803 .59468 L p .707 .577 .707 r
F P
0 g
s
.34966 .61097 m .35559 .64814 L .33172 .65613 L p .707 .577 .707 r
F P
0 g
s
.37826 .57457 m .37279 .51869 L .40449 .5151 L p .707 .577 .707 r
F P
0 g
s
.37279 .51869 m .37826 .57457 L .34899 .58018 L p .707 .577 .707 r
F P
0 g
s
.40449 .5151 m .40996 .57098 L .37826 .57457 L p .707 .577 .707 r
F P
0 g
s
.33632 .70302 m .33302 .68446 L .35684 .6762 L p .707 .577 .707 r
F P
0 g
s
.35684 .6762 m .36015 .69476 L .33632 .70302 L p .707 .577 .707 r
F P
0 g
s
.35559 .64814 m .34966 .61097 L .37875 .60394 L p .707 .577 .707 r
F P
0 g
s
.47486 .65778 m .47816 .67634 L .45121 .67763 L p .707 .577 .707 r
F P
0 g
s
.45121 .67763 m .44791 .65907 L .47486 .65778 L p .707 .577 .707 r
F P
0 g
s
.44098 .59538 m .44691 .63255 L .41615 .63575 L p .707 .577 .707 r
F P
0 g
s
.41615 .63575 m .41022 .59857 L .44098 .59538 L p .707 .577 .707 r
F P
0 g
s
.37875 .60394 m .38468 .64112 L .35559 .64814 L p .707 .577 .707 r
F P
0 g
s
.38468 .64112 m .37875 .60394 L .41022 .59857 L p .707 .577 .707 r
F P
0 g
s
.41022 .59857 m .41615 .63575 L .38468 .64112 L p .707 .577 .707 r
F P
0 g
s
.36015 .69476 m .35684 .6762 L .38586 .66875 L p .707 .577 .707 r
F P
0 g
s
.38586 .66875 m .38917 .68731 L .36015 .69476 L p .707 .577 .707 r
F P
0 g
s
.44791 .65907 m .45121 .67763 L .42054 .68141 L p .707 .577 .707 r
F P
0 g
s
.42054 .68141 m .41724 .66285 L .44791 .65907 L p .707 .577 .707 r
F P
0 g
s
.38917 .68731 m .38586 .66875 L .41724 .66285 L p .707 .577 .707 r
F P
0 g
s
.41724 .66285 m .42054 .68141 L .38917 .68731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
TGoo2`00PGoo0024Ool=000;FUH:001gOol007]oo`T000IJEP03001JEUYF01UJEPH0075oo`00MGoo
1P000UYF00<005YFFUH02UYF00<005YFFUH07eYF0P00Kgoo001`Ool50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0QFUH2001]Ool006eoo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF02=J
EVeoo`00JWoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
5UYFKGoo001WOol30007FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00Oomoo`1ZOol006Eoo`800003FUH005YF00MJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EVaoo`00Hgoo0P000eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001QOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUI/Ool0061oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVaoo`00
Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYFK7oo001NOol01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<007ooOol0JGoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005mo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEV]oo`00
Ggoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Qoo`00Ggoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol0061oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVYoo`00
H7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00H7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEVYoo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Moo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
06Moo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00H7oo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo00D005YFFUIJ
EP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Mo
o`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH0
00MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001oogoo06Ioo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00
HGoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Ioo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Ioo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00
HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00HWoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001SOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001SOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001SOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001J
EUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF0007FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00005FUHH000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`04001JEUYF
FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol0061oo`@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005aoo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001J
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001HOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Hgoo001EOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0087oo2000?7oo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000GOol90004FUH01000FUIJEUYF1`00=Goo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000?Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol0
05Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00;Woo001DOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP06001JEUYFFUH005YF;Goo001DOol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUH000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYF001JEP0]Ool005Aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05Eoo`03001JEP0000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00FUH0
0003FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE0006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP060004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000AJEP03001JEUYF00=JEP05001JEUYFFUH0000/
Ool004Mooa0000=JEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90007FUH70003FUH01@00FUIJEUYF0000;7oo0011Ool60004FUH00`00FUIJEP06
FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EPT000QJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001oogoo02Yoo`00?Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00
FUIJEP03FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool003Uoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@00003
FUH0000000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUH00002FUH01P00FUIJEUYF001JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00=Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF
FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000UYF00@005YF000000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ0000AJEP8002eoo`00<Goo0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03
001JEUYF00H002ioo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF3P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000^Ool20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<00000eYF001JEP06FUH50002FUH00`00
FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00@00003FUH0000000D000EJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH00000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=J
EP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00=JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00AJEP03001JEUYF00=JEP@000QJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YF00001EYF00<005YF00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP04001JEP000007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002]oo`00;Goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ@000MJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0
02eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP070004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHD00000eYF001oo`0ZOol002eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6
0008FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF10000UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH:0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000ZOol002ioo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP04FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF300000=JEP00FUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000002Yoo`00;Woo00<005YF000015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@00003Ool0000000D000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0002Yoo`00;Woo00<005YF000015YF00<005YF
00000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001JEUYF009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH9
0002FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000[Ool002ioo`03
001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000AJEP@00003FUH005YF00MJEP03001JEUYF00AJEPL00003FUH005YF00YJEP03001JEUYF0080
0003FUH00000008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH0100025YF00<005YFFUH02EYF0`000eYF00@005YF000000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00004P00;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH=0007FUH00`00FUIJEP04FUH600000eYF001JEP07FUH00`00
FUIJEP07FUH200000eYF001JEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJ
EP04001JEUYFFUH70003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:goo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90004FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000`0000=JEP00FUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YF00000UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool002ioo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00H000AJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00<0009JEP03001JEUYF00IJEP03001JEUYF009J
EP<000IJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH01000FUIJEUYF1@001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000002Yoo`00;Woo0P000eYF00<005YFFUH00UYF00<0
05YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000<0
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEPD00003FUH005YF00IJEP04001JEP000008
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000ZOol002moo`05001JEUYFFUH00005FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH200000eYF001JEP03FUH20003FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEUYF00L000EJEP03001JEUYF00AJEP<000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00@000IJEP03001J
EUYF00MJEP03001JEUYF009JEQ<00003FUH007oo02Uoo`00<7oo0P0000=JEP00FUH015YF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00FUIJEP8000EJEP04001JEUYF
FUH20003FUH:0004FUH00`00FUIJEP06FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00UYF0`0000=JEP00FUH025YF00<0
05YFFUH015YF20003Woo0P0000=JEP0000000P00:Goo000bOol400000eYF00000003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF000000040004FUH00`00FUH000070004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF008000AJEP03001J
EUYF00MJEP03001JEUYF00L0015oo`8000=JEP04001JEP00000YOol003Aoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800004FUH005YF0002FUH70003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH015YF20004goo0`001EYF
00<005YF0000:Goo000bOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP040003Ool3000COol20002
FUH00`00FUIJEP03FUH2000ZOol0031oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJ
EP03001JEUYF00AJEPD000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP02FUH40006Ool5000>Ool40005FUH01000FUIJ
EUYF0P00:goo000_Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF00000007Ool5000:Ool40002FUH00`00
FUIJEP04FUH01000FUH00000;Goo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH70008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUH005YF00001EYF0P000UYF00@005YFFUH000Moo`D000=oo`L000IJEP03001JEUYF00AJ
EP8002moo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@0
00=oo`D000EJEQD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF008000EJEP04001J
EP000006Ool80004FUH00`00FUIJEP07FUH01000FUIJEUYF0P00<Goo000^Ool01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH015YF10000goo10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009J
EPD000EJEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000cOol0
02moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00/000IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP0GFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000=Goo000_Ool00`00FUH0
0005FUH00`00FUIJEP03FUH40008FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0G
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Uoo`00;goo00<005YF0000
1EYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00D005YFFUIJEP0000=oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF01MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000_Ool00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH0000017oo
0eYF00<005YFFUH015YF00<005YFFUH085YF00<005YFFUH015YF2`001EYF00<005YFFUH01UYF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0049o
o`00;goo00@005YFFUH0009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EQ@000Aoo`04001JEUYF0006FUH00`00FUIJEP0JFUH=000:FUH;0004FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60016Ool002moo`03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0000800005Ool005YFFUH0000KFUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6
0004FUHD001<Ool0031oo`9JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH007oo00000UYF00<0
05YFFUH05EYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF0P0015YF00<005YFFUH00UYF1000DGoo000`Ool01EYF001JEUYF00001EYF00<005YF
FUH015YF00@005YFFUIJEP@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF00<0009JEP03001JEUYF015JEP@000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000AJEP03001JEUYF009JEP04001JEP00001AOol0031oo`80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0<FUH50002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
0005FUH01@00FUIJEUYF00000UYF00<007ooOol0Cgoo000aOol01000FUIJEP001EYF00<005YFFUH0
10001EYF00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P003EYF100025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP03001JEUYF009JEP80059oo`00<Woo0`0015YF100000=JEP00FUH01eYF00<005YFFUH015YF1`00
47oo0P0000=JEP0000000P002UYF0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF009J
EP80059oo`00=7oo1@001EYF00<005YFFUH01UYF00<005YFFUH0100057oo0`000eYF00@005YF0000
00QJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00`005=oo`00=Woo0P001eYF00<005YFFUH015YF
1P0057oo0P0000=JEP00FUH00eYF00@005YFFUH000IJEP8000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00=JEP03001JEUYF00=JEP04001JEP00001BOol003Aoo`800003FUH005YF00IJEP03001JEUYF00@0
0003Ool0000000<0019oo`8000=JEP03001JEUYF009JEP<00003OomJEUYF009JEP8000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYF001BOol003=oo`05001JEUYFFUH00006FUH4
0006Ool3000@Ool30005FUH00`00FUIJEP02FUH01000Oomoogoo0eYF00<005YF000025YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001UYF00<005YFFUH00eYF00@005YF0000055oo`00<Woo0P0015YF00@005YFFUIJEP80
01Uoo`@00003FUH005YF00IJEP04001JEUYF0004Ool2FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
1eYF00<005YFFUH00eYF00@005YFFUH0055oo`00<Goo00<005YF000015YF00@005YF000001Aoo`L0
00EJEP03001JEUYF00EJEP<000Eoo`03FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEP0001<00003FUH007oo051oo`00
<Goo00<005YF00000eYF0`003goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P001goo0P00
15YF00<005YFFUH045YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH0
1EYF1@003Woo0P0000=JEP0000000P00D7oo000aOol01000FUH005YF0P003Woo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`004Goo0P00
0eYF00@005YF0000051oo`00<Goo00<005YF00004@001UYF00<005YFFUH01eYF00<005YFFUH015YF
0`003Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P004Woo0`001EYF00<005YF0000D7oo000aOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
000AOol20003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH4000COol20002FUH00`00FUIJEP03FUH2001AOol0035oo`80009JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD001Moo`800003FUH005YF00MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH6000017oo00000000
3goo100015YF00<005YFFUH00eYF00<007ooOol0D7oo000aOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000NOol60004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH:0006Ool5000:Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02001C
Ool0039oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Qoo`X000EJ
EP03001JEUYF00AJEP`00003FUH005YF008000]oo`D000Eoo`D000IJEP03001JEUYF00AJEP<005Eo
o`00=7oo5000>Goo30001Goo00@005YFFUH000=JEP<000eoo`D00003Ool000000080009JEP03001J
EUYF00MJEP03001JEUYF009JEP8005Moo`00TWoo00D005YFFUH005YF0080011oo`H000IJEP03001J
EUYF00MJEP03001JEP00008005Uoo`00Tgoo00<005YF00004`000eYF00<005YFFUH01eYF00<005YF
FUH015YF1000G7oo002COol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04001POol009=oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD006Aoo`00Tgoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01000JGoo002DOol200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH6001]Ool009Iooa@007=oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]5\[InvisibleSpace]"     "\
\[InvisibleSpace]2.3598988957761797`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 5, "     ", 2.3598988957761797, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73974 m .59613 .68416 L .56496 .68226 L p .707 .577 .707 r
F P
0 g
s
.59613 .68416 m .59613 .73974 L .62796 .73897 L p .707 .577 .707 r
F P
0 g
s
.62796 .73897 m .62796 .68339 L .59613 .68416 L p .707 .577 .707 r
F P
0 g
s
.62796 .68339 m .62796 .73897 L .65734 .73559 L p .707 .577 .707 r
F P
0 g
s
.65734 .73559 m .65734 .68001 L .62796 .68339 L p .707 .577 .707 r
F P
0 g
s
.56496 .73784 m .56496 .68226 L .5375 .67787 L p .707 .577 .707 r
F P
0 g
s
.56496 .68226 m .56496 .73784 L .59613 .73974 L p .707 .577 .707 r
F P
0 g
s
.65734 .68001 m .65734 .73559 L .6814 .72994 L p .707 .577 .707 r
F P
0 g
s
.6814 .72994 m .6814 .67436 L .65734 .68001 L p .707 .577 .707 r
F P
0 g
s
.59613 .78711 m .59613 .75006 L .56496 .74816 L p .707 .577 .707 r
F P
0 g
s
.59613 .75006 m .59613 .78711 L .62796 .78634 L p .707 .577 .707 r
F P
0 g
s
.62796 .78634 m .62796 .74928 L .59613 .75006 L p .707 .577 .707 r
F P
0 g
s
.62796 .74928 m .62796 .78634 L .65735 .78296 L p .707 .577 .707 r
F P
0 g
s
.65735 .78296 m .65735 .7459 L .62796 .74928 L p .707 .577 .707 r
F P
0 g
s
.5375 .67787 m .5375 .73345 L .56496 .73784 L p .707 .577 .707 r
F P
0 g
s
.5375 .73345 m .5375 .67787 L .51644 .67142 L p .707 .577 .707 r
F P
0 g
s
.56496 .78521 m .56496 .74816 L .5375 .74377 L p .707 .577 .707 r
F P
0 g
s
.56496 .74816 m .56496 .78521 L .59613 .78711 L p .707 .577 .707 r
F P
0 g
s
.59613 .81223 m .59613 .79371 L .56496 .7918 L p .707 .577 .707 r
F P
0 g
s
.59613 .79371 m .59613 .81223 L .62796 .81146 L p .707 .577 .707 r
F P
0 g
s
.62796 .81146 m .62796 .79293 L .59613 .79371 L p .707 .577 .707 r
F P
0 g
s
.65735 .7459 m .65735 .78296 L .6814 .77731 L p .707 .577 .707 r
F P
0 g
s
.6814 .77731 m .6814 .74025 L .65735 .7459 L p .707 .577 .707 r
F P
0 g
s
.62796 .79293 m .62796 .81146 L .65735 .80808 L p .707 .577 .707 r
F P
0 g
s
.65735 .80808 m .65735 .78955 L .62796 .79293 L p .707 .577 .707 r
F P
0 g
s
.6814 .67436 m .6814 .72994 L .69777 .72257 L p .707 .577 .707 r
F P
0 g
s
.69777 .72257 m .69777 .66699 L .6814 .67436 L p .707 .577 .707 r
F P
0 g
s
.5375 .74377 m .5375 .78082 L .56496 .78521 L p .707 .577 .707 r
F P
0 g
s
.56496 .7918 m .56496 .81033 L .59613 .81223 L p .707 .577 .707 r
F P
0 g
s
.56496 .81033 m .56496 .7918 L .5375 .78741 L p .707 .577 .707 r
F P
0 g
s
.51644 .67142 m .51644 .727 L .5375 .73345 L p .707 .577 .707 r
F P
0 g
s
.5375 .78082 m .5375 .74377 L .51644 .73731 L p .707 .577 .707 r
F P
0 g
s
.5375 .78741 m .5375 .80594 L .56496 .81033 L p .707 .577 .707 r
F P
0 g
s
.65735 .78955 m .65735 .80808 L .6814 .80243 L p .707 .577 .707 r
F P
0 g
s
.6814 .80243 m .6814 .7839 L .65735 .78955 L p .707 .577 .707 r
F P
0 g
s
.51644 .727 m .51644 .67142 L .50385 .66353 L p .707 .577 .707 r
F P
0 g
s
.51644 .73731 m .51644 .77437 L .5375 .78082 L p .707 .577 .707 r
F P
0 g
s
.5375 .80594 m .5375 .78741 L .51644 .78096 L p .707 .577 .707 r
F P
0 g
s
.6814 .74025 m .6814 .77731 L .69777 .76994 L p .707 .577 .707 r
F P
0 g
s
.69777 .76994 m .69777 .73289 L .6814 .74025 L p .707 .577 .707 r
F P
0 g
s
.51644 .78096 m .51644 .79949 L .5375 .80594 L p .707 .577 .707 r
F P
0 g
s
.50385 .66353 m .50385 .71911 L .51644 .727 L p .707 .577 .707 r
F P
0 g
s
.69777 .66699 m .69777 .72257 L .70485 .71421 L p .707 .577 .707 r
F P
0 g
s
.70485 .71421 m .70485 .65862 L .69777 .66699 L p .707 .577 .707 r
F P
0 g
s
.51644 .77437 m .51644 .73731 L .50385 .72943 L p .707 .577 .707 r
F P
0 g
s
.6814 .7839 m .6814 .80243 L .69777 .79506 L p .707 .577 .707 r
F P
0 g
s
.69777 .79506 m .69777 .77653 L .6814 .7839 L p .707 .577 .707 r
F P
0 g
s
.50385 .71911 m .50385 .66353 L .50095 .65499 L p .707 .577 .707 r
F P
0 g
s
.50385 .72943 m .50385 .76648 L .51644 .77437 L p .707 .577 .707 r
F P
0 g
s
.51644 .79949 m .51644 .78096 L .50385 .77307 L p .707 .577 .707 r
F P
0 g
s
.69777 .73289 m .69777 .76994 L .70485 .76158 L p .707 .577 .707 r
F P
0 g
s
.70485 .76158 m .70485 .72452 L .69777 .73289 L p .707 .577 .707 r
F P
0 g
s
.50385 .77307 m .50385 .7916 L .51644 .79949 L p .707 .577 .707 r
F P
0 g
s
.49044 .76543 m .49044 .26354 L .44643 .26086 L p .707 .577 .707 r
F P
0 g
s
.50095 .65499 m .50095 .71057 L .50385 .71911 L p .707 .577 .707 r
F P
0 g
s
.50385 .76648 m .50385 .72943 L .50095 .72089 L p .707 .577 .707 r
F P
0 g
s
.50095 .72089 m .50095 .75794 L .50385 .76648 L p .707 .577 .707 r
F P
0 g
s
.50385 .7916 m .50385 .77307 L .50095 .76453 L p .707 .577 .707 r
F P
0 g
s
.50095 .71057 m .50095 .65499 L .50804 .64663 L p .707 .577 .707 r
F P
0 g
s
.50095 .76453 m .50095 .78306 L .50385 .7916 L p .707 .577 .707 r
F P
0 g
s
.50804 .64663 m .50804 .70221 L .50095 .71057 L p .707 .577 .707 r
F P
0 g
s
.50095 .75794 m .50095 .72089 L .50804 .71252 L p .707 .577 .707 r
F P
0 g
s
.50804 .71252 m .50804 .74958 L .50095 .75794 L p .707 .577 .707 r
F P
0 g
s
.50804 .70221 m .50804 .64663 L .5244 .63926 L p .707 .577 .707 r
F P
0 g
s
.50095 .78306 m .50095 .76453 L .50804 .75617 L p .707 .577 .707 r
F P
0 g
s
.50804 .75617 m .50804 .7747 L .50095 .78306 L p .707 .577 .707 r
F P
0 g
s
.5244 .63926 m .5244 .69484 L .50804 .70221 L p .707 .577 .707 r
F P
0 g
s
.50804 .74958 m .50804 .71252 L .5244 .70516 L p .707 .577 .707 r
F P
0 g
s
.5244 .69484 m .5244 .63926 L .54846 .63361 L p .707 .577 .707 r
F P
0 g
s
.5244 .70516 m .5244 .74221 L .50804 .74958 L p .707 .577 .707 r
F P
0 g
s
.50804 .7747 m .50804 .75617 L .5244 .7488 L p .707 .577 .707 r
F P
0 g
s
.5244 .7488 m .5244 .76733 L .50804 .7747 L p .707 .577 .707 r
F P
0 g
s
.54846 .63361 m .54846 .68919 L .5244 .69484 L p .707 .577 .707 r
F P
0 g
s
.5244 .74221 m .5244 .70516 L .54846 .69951 L p .707 .577 .707 r
F P
0 g
s
.54846 .69951 m .54846 .73656 L .5244 .74221 L p .707 .577 .707 r
F P
0 g
s
.5244 .76733 m .5244 .7488 L .54846 .74315 L p .707 .577 .707 r
F P
0 g
s
.54846 .74315 m .54846 .76168 L .5244 .76733 L p .707 .577 .707 r
F P
0 g
s
.49044 .26354 m .49044 .76543 L .53538 .76433 L p .707 .577 .707 r
F P
0 g
s
.53538 .76433 m .53538 .26245 L .49044 .26354 L p .707 .577 .707 r
F P
0 g
s
.70485 .65862 m .70485 .71421 L .70195 .70566 L p .707 .577 .707 r
F P
0 g
s
.70195 .70566 m .70195 .65008 L .70485 .65862 L p .707 .577 .707 r
F P
0 g
s
.69777 .77653 m .69777 .79506 L .70485 .78669 L p .707 .577 .707 r
F P
0 g
s
.70485 .78669 m .70485 .76817 L .69777 .77653 L p .707 .577 .707 r
F P
0 g
s
.54846 .68919 m .54846 .63361 L .57784 .63023 L p .707 .577 .707 r
F P
0 g
s
.57784 .63023 m .57784 .68581 L .54846 .68919 L p .707 .577 .707 r
F P
0 g
s
.54846 .73656 m .54846 .69951 L .57784 .69613 L p .707 .577 .707 r
F P
0 g
s
.57784 .69613 m .57784 .73318 L .54846 .73656 L p .707 .577 .707 r
F P
0 g
s
.54846 .76168 m .54846 .74315 L .57784 .73977 L p .707 .577 .707 r
F P
0 g
s
.57784 .73977 m .57784 .7583 L .54846 .76168 L p .707 .577 .707 r
F P
0 g
s
.53538 .26245 m .53538 .76433 L .57686 .75956 L p .707 .577 .707 r
F P
0 g
s
.57686 .75956 m .57686 .25768 L .53538 .26245 L p .707 .577 .707 r
F P
0 g
s
.44643 .76275 m .44643 .26086 L .40766 .25466 L p .707 .577 .707 r
F P
0 g
s
.44643 .26086 m .44643 .76275 L .49044 .76543 L p .707 .577 .707 r
F P
0 g
s
.57784 .68581 m .57784 .63023 L .60968 .62945 L p .707 .577 .707 r
F P
0 g
s
.60968 .62945 m .60968 .68503 L .57784 .68581 L p .707 .577 .707 r
F P
0 g
s
.57784 .73318 m .57784 .69613 L .60968 .69535 L p .707 .577 .707 r
F P
0 g
s
.60968 .69535 m .60968 .7324 L .57784 .73318 L p .707 .577 .707 r
F P
0 g
s
.60968 .75752 m .60968 .73899 L .64085 .7409 L p .707 .577 .707 r
F P
0 g
s
.57784 .7583 m .57784 .73977 L .60968 .73899 L p .707 .577 .707 r
F P
0 g
s
.60968 .73899 m .60968 .75752 L .57784 .7583 L p .707 .577 .707 r
F P
0 g
s
.57686 .25768 m .57686 .75956 L .61082 .75159 L p .707 .577 .707 r
F P
0 g
s
.64085 .63135 m .64085 .68693 L .60968 .68503 L p .707 .577 .707 r
F P
0 g
s
.60968 .68503 m .60968 .62945 L .64085 .63135 L p .707 .577 .707 r
F P
0 g
s
.64085 .69725 m .64085 .7343 L .60968 .7324 L p .707 .577 .707 r
F P
0 g
s
.60968 .7324 m .60968 .69535 L .64085 .69725 L p .707 .577 .707 r
F P
0 g
s
.61082 .75159 m .61082 .2497 L .57686 .25768 L p .707 .577 .707 r
F P
0 g
s
.70485 .72452 m .70485 .76158 L .70195 .75303 L p .707 .577 .707 r
F P
0 g
s
.70195 .75303 m .70195 .71598 L .70485 .72452 L p .707 .577 .707 r
F P
0 g
s
.40766 .75655 m .40766 .25466 L .37794 .24555 L p .707 .577 .707 r
F P
0 g
s
.40766 .25466 m .40766 .75655 L .44643 .76275 L p .707 .577 .707 r
F P
0 g
s
.70485 .76817 m .70485 .78669 L .70195 .77815 L p .707 .577 .707 r
F P
0 g
s
.70195 .77815 m .70195 .75963 L .70485 .76817 L p .707 .577 .707 r
F P
0 g
s
.70195 .65008 m .70195 .70566 L .68936 .69778 L p .707 .577 .707 r
F P
0 g
s
.68936 .69778 m .68936 .6422 L .70195 .65008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.25312 .70293 m .25312 .64735 L .22195 .64545 L p .707 .577 .707 r
F P
0 g
s
.25312 .64735 m .25312 .70293 L .28495 .70215 L p .707 .577 .707 r
F P
0 g
s
.28495 .70215 m .28495 .64657 L .25312 .64735 L p .707 .577 .707 r
F P
0 g
s
.28495 .64657 m .28495 .70215 L .31434 .69877 L p .707 .577 .707 r
F P
0 g
s
.31434 .69877 m .31434 .64319 L .28495 .64657 L p .707 .577 .707 r
F P
0 g
s
.61082 .2497 m .61082 .75159 L .63393 .74119 L p .707 .577 .707 r
F P
0 g
s
.63393 .74119 m .63393 .2393 L .61082 .2497 L p .707 .577 .707 r
F P
0 g
s
.22195 .70103 m .22195 .64545 L .19449 .64105 L p .707 .577 .707 r
F P
0 g
s
.22195 .64545 m .22195 .70103 L .25312 .70293 L p .707 .577 .707 r
F P
0 g
s
.70195 .71598 m .70195 .75303 L .68936 .74515 L p .707 .577 .707 r
F P
0 g
s
.68936 .74515 m .68936 .7081 L .70195 .71598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31434 .64319 m .31434 .69877 L .33839 .69312 L p .707 .577 .707 r
F P
0 g
s
.33839 .69312 m .33839 .63754 L .31434 .64319 L p .707 .577 .707 r
F P
0 g
s
.25312 .7503 m .25312 .71324 L .22195 .71134 L p .707 .577 .707 r
F P
0 g
s
.25312 .71324 m .25312 .7503 L .28495 .74952 L p .707 .577 .707 r
F P
0 g
s
.28495 .74952 m .28495 .71247 L .25312 .71324 L p .707 .577 .707 r
F P
0 g
s
.68936 .6422 m .68936 .69778 L .66831 .69133 L p .707 .577 .707 r
F P
0 g
s
.66831 .69133 m .66831 .63574 L .68936 .6422 L p .707 .577 .707 r
F P
0 g
s
.70195 .75963 m .70195 .77815 L .68936 .77027 L p .707 .577 .707 r
F P
0 g
s
.68936 .77027 m .68936 .75174 L .70195 .75963 L p .707 .577 .707 r
F P
0 g
s
.37794 .74744 m .37794 .24555 L .36016 .23442 L p .707 .577 .707 r
F P
0 g
s
.37794 .24555 m .37794 .74744 L .40766 .75655 L p .707 .577 .707 r
F P
0 g
s
.28495 .71247 m .28495 .74952 L .31434 .74614 L p .707 .577 .707 r
F P
0 g
s
.31434 .74614 m .31434 .70909 L .28495 .71247 L p .707 .577 .707 r
F P
0 g
s
.19449 .64105 m .19449 .69664 L .22195 .70103 L p .707 .577 .707 r
F P
0 g
s
.19449 .69664 m .19449 .64105 L .17343 .6346 L p .707 .577 .707 r
F P
0 g
s
.22195 .7484 m .22195 .71134 L .19449 .70695 L p .707 .577 .707 r
F P
0 g
s
.22195 .71134 m .22195 .7484 L .25312 .7503 L p .707 .577 .707 r
F P
0 g
s
.25312 .77542 m .25312 .75689 L .22195 .75499 L p .707 .577 .707 r
F P
0 g
s
.25312 .75689 m .25312 .77542 L .28495 .77464 L p .707 .577 .707 r
F P
0 g
s
.28495 .77464 m .28495 .75611 L .25312 .75689 L p .707 .577 .707 r
F P
0 g
s
.31434 .70909 m .31434 .74614 L .33839 .74049 L p .707 .577 .707 r
F P
0 g
s
.33839 .74049 m .33839 .70344 L .31434 .70909 L p .707 .577 .707 r
F P
0 g
s
.28495 .75611 m .28495 .77464 L .31434 .77126 L p .707 .577 .707 r
F P
0 g
s
.31434 .77126 m .31434 .75273 L .28495 .75611 L p .707 .577 .707 r
F P
0 g
s
.33839 .63754 m .33839 .69312 L .35476 .68576 L p .707 .577 .707 r
F P
0 g
s
.35476 .68576 m .35476 .63017 L .33839 .63754 L p .707 .577 .707 r
F P
0 g
s
.19449 .70695 m .19449 .74401 L .22195 .7484 L p .707 .577 .707 r
F P
0 g
s
.22195 .75499 m .22195 .77352 L .25312 .77542 L p .707 .577 .707 r
F P
0 g
s
.68936 .7081 m .68936 .74515 L .66831 .7387 L p .707 .577 .707 r
F P
0 g
s
.66831 .7387 m .66831 .70164 L .68936 .7081 L p .707 .577 .707 r
F P
0 g
s
.22195 .77352 m .22195 .75499 L .19449 .7506 L p .707 .577 .707 r
F P
0 g
s
.17343 .6346 m .17343 .69018 L .19449 .69664 L p .707 .577 .707 r
F P
0 g
s
.19449 .74401 m .19449 .70695 L .17343 .7005 L p .707 .577 .707 r
F P
0 g
s
.66831 .63574 m .66831 .69133 L .64085 .68693 L p .707 .577 .707 r
F P
0 g
s
.64085 .68693 m .64085 .63135 L .66831 .63574 L p .707 .577 .707 r
F P
0 g
s
.19449 .7506 m .19449 .76912 L .22195 .77352 L p .707 .577 .707 r
F P
0 g
s
.64085 .7343 m .64085 .69725 L .66831 .70164 L p .707 .577 .707 r
F P
0 g
s
.63393 .2393 m .63393 .74119 L .64393 .72938 L p .707 .577 .707 r
F P
0 g
s
.64393 .72938 m .64393 .22749 L .63393 .2393 L p .707 .577 .707 r
F P
0 g
s
.31434 .75273 m .31434 .77126 L .33839 .76561 L p .707 .577 .707 r
F P
0 g
s
.33839 .76561 m .33839 .74708 L .31434 .75273 L p .707 .577 .707 r
F P
0 g
s
.17343 .69018 m .17343 .6346 L .16084 .62672 L p .707 .577 .707 r
F P
0 g
s
.68936 .75174 m .68936 .77027 L .66831 .76381 L p .707 .577 .707 r
F P
0 g
s
.66831 .76381 m .66831 .74529 L .68936 .75174 L p .707 .577 .707 r
F P
0 g
s
.17343 .7005 m .17343 .73755 L .19449 .74401 L p .707 .577 .707 r
F P
0 g
s
.19449 .76912 m .19449 .7506 L .17343 .74414 L p .707 .577 .707 r
F P
0 g
s
.33839 .70344 m .33839 .74049 L .35476 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .73313 m .35476 .69607 L .33839 .70344 L p .707 .577 .707 r
F P
0 g
s
.17343 .74414 m .17343 .76267 L .19449 .76912 L p .707 .577 .707 r
F P
0 g
s
.66831 .70164 m .66831 .7387 L .64085 .7343 L p .707 .577 .707 r
F P
0 g
s
.35476 .63017 m .35476 .68576 L .36184 .67739 L p .707 .577 .707 r
F P
0 g
s
.36184 .67739 m .36184 .62181 L .35476 .63017 L p .707 .577 .707 r
F P
0 g
s
.35476 .69607 m .35476 .73313 L .36184 .72476 L p .707 .577 .707 r
F P
0 g
s
.36184 .72476 m .36184 .68771 L .35476 .69607 L p .707 .577 .707 r
F P
0 g
s
.36184 .62181 m .36184 .67739 L .35894 .66885 L p .707 .577 .707 r
F P
0 g
s
.35894 .66885 m .35894 .61327 L .36184 .62181 L p .707 .577 .707 r
F P
0 g
s
.36184 .74988 m .36184 .73135 L .35476 .73972 L p .707 .577 .707 r
F P
0 g
s
.36184 .68771 m .36184 .72476 L .35894 .71622 L p .707 .577 .707 r
F P
0 g
s
.35894 .71622 m .35894 .67916 L .36184 .68771 L p .707 .577 .707 r
F P
0 g
s
.35894 .74134 m .35894 .72281 L .36184 .73135 L p .707 .577 .707 r
F P
0 g
s
.36016 .73631 m .36016 .23442 L .35607 .22236 L p .707 .577 .707 r
F P
0 g
s
.36184 .73135 m .36184 .74988 L .35894 .74134 L p .707 .577 .707 r
F P
0 g
s
.36016 .23442 m .36016 .73631 L .37794 .74744 L p .707 .577 .707 r
F P
0 g
s
.16084 .62672 m .16084 .6823 L .17343 .69018 L p .707 .577 .707 r
F P
0 g
s
.17343 .73755 m .17343 .7005 L .16084 .69261 L p .707 .577 .707 r
F P
0 g
s
.33839 .74708 m .33839 .76561 L .35476 .75824 L p .707 .577 .707 r
F P
0 g
s
.35476 .75824 m .35476 .73972 L .33839 .74708 L p .707 .577 .707 r
F P
0 g
s
.66831 .74529 m .66831 .76381 L .64085 .75942 L p .707 .577 .707 r
F P
0 g
s
.64085 .75942 m .64085 .7409 L .66831 .74529 L p .707 .577 .707 r
F P
0 g
s
.16084 .6823 m .16084 .62672 L .15794 .61817 L p .707 .577 .707 r
F P
0 g
s
.16084 .69261 m .16084 .72967 L .17343 .73755 L p .707 .577 .707 r
F P
0 g
s
.17343 .76267 m .17343 .74414 L .16084 .73626 L p .707 .577 .707 r
F P
0 g
s
.16084 .73626 m .16084 .75479 L .17343 .76267 L p .707 .577 .707 r
F P
0 g
s
.64393 .22749 m .64393 .72938 L .63984 .71732 L p .707 .577 .707 r
F P
0 g
s
.63984 .71732 m .63984 .21543 L .64393 .22749 L p .707 .577 .707 r
F P
0 g
s
.64085 .7409 m .64085 .75942 L .60968 .75752 L p .707 .577 .707 r
F P
0 g
s
.15794 .61817 m .15794 .67376 L .16084 .6823 L p .707 .577 .707 r
F P
0 g
s
.35476 .73972 m .35476 .75824 L .36184 .74988 L p .707 .577 .707 r
F P
0 g
s
.16084 .72967 m .16084 .69261 L .15794 .68407 L p .707 .577 .707 r
F P
0 g
s
.15794 .68407 m .15794 .72113 L .16084 .72967 L p .707 .577 .707 r
F P
0 g
s
.35894 .61327 m .35894 .66885 L .34635 .66097 L p .707 .577 .707 r
F P
0 g
s
.34635 .66097 m .34635 .60538 L .35894 .61327 L p .707 .577 .707 r
F P
0 g
s
.35894 .67916 m .35894 .71622 L .34635 .70834 L p .707 .577 .707 r
F P
0 g
s
.34635 .70834 m .34635 .67128 L .35894 .67916 L p .707 .577 .707 r
F P
0 g
s
.35894 .72281 m .35894 .74134 L .34635 .73345 L p .707 .577 .707 r
F P
0 g
s
.34635 .73345 m .34635 .71493 L .35894 .72281 L p .707 .577 .707 r
F P
0 g
s
.35607 .22236 m .35607 .72425 L .36016 .73631 L p .707 .577 .707 r
F P
0 g
s
.35607 .72425 m .35607 .22236 L .36607 .21055 L p .707 .577 .707 r
F P
0 g
s
.16084 .75479 m .16084 .73626 L .15794 .72772 L p .707 .577 .707 r
F P
0 g
s
.15794 .67376 m .15794 .61817 L .16503 .60981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15794 .72772 m .15794 .74624 L .16084 .75479 L p .707 .577 .707 r
F P
0 g
s
.16503 .60981 m .16503 .66539 L .15794 .67376 L p .707 .577 .707 r
F P
0 g
s
.15794 .72113 m .15794 .68407 L .16503 .67571 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63984 .21543 m .63984 .71732 L .62206 .70619 L p .707 .577 .707 r
F P
0 g
s
.62206 .70619 m .62206 .2043 L .63984 .21543 L p .707 .577 .707 r
F P
0 g
s
.16503 .67571 m .16503 .71276 L .15794 .72113 L p .707 .577 .707 r
F P
0 g
s
.16503 .66539 m .16503 .60981 L .1814 .60244 L p .707 .577 .707 r
F P
0 g
s
.15794 .74624 m .15794 .72772 L .16503 .71935 L p .707 .577 .707 r
F P
0 g
s
.16503 .71935 m .16503 .73788 L .15794 .74624 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36607 .71244 m .36607 .21055 L .38918 .20015 L p .707 .577 .707 r
F P
0 g
s
.36607 .21055 m .36607 .71244 L .35607 .72425 L p .707 .577 .707 r
F P
0 g
s
.1814 .60244 m .1814 .65802 L .16503 .66539 L p .707 .577 .707 r
F P
0 g
s
.34635 .60538 m .34635 .66097 L .3253 .65451 L p .707 .577 .707 r
F P
0 g
s
.3253 .65451 m .3253 .59893 L .34635 .60538 L p .707 .577 .707 r
F P
0 g
s
.16503 .71276 m .16503 .67571 L .1814 .66834 L p .707 .577 .707 r
F P
0 g
s
.1814 .65802 m .1814 .60244 L .20545 .59679 L p .707 .577 .707 r
F P
0 g
s
.1814 .66834 m .1814 .70539 L .16503 .71276 L p .707 .577 .707 r
F P
0 g
s
.16503 .73788 m .16503 .71935 L .1814 .71199 L p .707 .577 .707 r
F P
0 g
s
.34635 .67128 m .34635 .70834 L .3253 .70188 L p .707 .577 .707 r
F P
0 g
s
.3253 .70188 m .3253 .66483 L .34635 .67128 L p .707 .577 .707 r
F P
0 g
s
.62206 .2043 m .62206 .70619 L .59233 .69708 L p .707 .577 .707 r
F P
0 g
s
.59233 .69708 m .59233 .19519 L .62206 .2043 L p .707 .577 .707 r
F P
0 g
s
.1814 .71199 m .1814 .73051 L .16503 .73788 L p .707 .577 .707 r
F P
0 g
s
.3253 .59893 m .3253 .65451 L .29784 .65012 L p .707 .577 .707 r
F P
0 g
s
.29784 .65012 m .29784 .59454 L .3253 .59893 L p .707 .577 .707 r
F P
0 g
s
.20545 .59679 m .20545 .65237 L .1814 .65802 L p .707 .577 .707 r
F P
0 g
s
.1814 .70539 m .1814 .66834 L .20545 .66269 L p .707 .577 .707 r
F P
0 g
s
.34635 .71493 m .34635 .73345 L .3253 .727 L p .707 .577 .707 r
F P
0 g
s
.3253 .727 m .3253 .70847 L .34635 .71493 L p .707 .577 .707 r
F P
0 g
s
.20545 .65237 m .20545 .59679 L .23483 .59341 L p .707 .577 .707 r
F P
0 g
s
.38918 .20015 m .38918 .70204 L .36607 .71244 L p .707 .577 .707 r
F P
0 g
s
.38918 .70204 m .38918 .20015 L .42314 .19217 L p .707 .577 .707 r
F P
0 g
s
.29784 .59454 m .29784 .65012 L .26667 .64822 L p .707 .577 .707 r
F P
0 g
s
.26667 .64822 m .26667 .59264 L .29784 .59454 L p .707 .577 .707 r
F P
0 g
s
.20545 .66269 m .20545 .69974 L .1814 .70539 L p .707 .577 .707 r
F P
0 g
s
.1814 .73051 m .1814 .71199 L .20545 .70634 L p .707 .577 .707 r
F P
0 g
s
.3253 .66483 m .3253 .70188 L .29784 .69749 L p .707 .577 .707 r
F P
0 g
s
.29784 .69749 m .29784 .66043 L .3253 .66483 L p .707 .577 .707 r
F P
0 g
s
.23483 .649 m .23483 .59341 L .26667 .59264 L p .707 .577 .707 r
F P
0 g
s
.23483 .59341 m .23483 .649 L .20545 .65237 L p .707 .577 .707 r
F P
0 g
s
.26667 .59264 m .26667 .64822 L .23483 .649 L p .707 .577 .707 r
F P
0 g
s
.20545 .70634 m .20545 .72486 L .1814 .73051 L p .707 .577 .707 r
F P
0 g
s
.73333 .64771 m .73333 .59212 L .70216 .59022 L p .707 .577 .707 r
F P
0 g
s
.73333 .59212 m .73333 .64771 L .76517 .64693 L p .707 .577 .707 r
F P
0 g
s
.76517 .64693 m .76517 .59135 L .73333 .59212 L p .707 .577 .707 r
F P
0 g
s
.20545 .69974 m .20545 .66269 L .23483 .65931 L p .707 .577 .707 r
F P
0 g
s
.76517 .59135 m .76517 .64693 L .79455 .64355 L p .707 .577 .707 r
F P
0 g
s
.79455 .64355 m .79455 .58797 L .76517 .59135 L p .707 .577 .707 r
F P
0 g
s
.59233 .19519 m .59233 .69708 L .55357 .69088 L p .707 .577 .707 r
F P
0 g
s
.55357 .69088 m .55357 .18899 L .59233 .19519 L p .707 .577 .707 r
F P
0 g
s
.3253 .70847 m .3253 .727 L .29784 .72261 L p .707 .577 .707 r
F P
0 g
s
.29784 .72261 m .29784 .70408 L .3253 .70847 L p .707 .577 .707 r
F P
0 g
s
.70216 .64581 m .70216 .59022 L .6747 .58583 L p .707 .577 .707 r
F P
0 g
s
.70216 .59022 m .70216 .64581 L .73333 .64771 L p .707 .577 .707 r
F P
0 g
s
.29784 .66043 m .29784 .69749 L .26667 .69559 L p .707 .577 .707 r
F P
0 g
s
.26667 .69559 m .26667 .65853 L .29784 .66043 L p .707 .577 .707 r
F P
0 g
s
.23483 .65931 m .23483 .69637 L .20545 .69974 L p .707 .577 .707 r
F P
0 g
s
.23483 .69637 m .23483 .65931 L .26667 .65853 L p .707 .577 .707 r
F P
0 g
s
.20545 .72486 m .20545 .70634 L .23483 .70296 L p .707 .577 .707 r
F P
0 g
s
.42314 .69406 m .42314 .19217 L .46462 .1874 L p .707 .577 .707 r
F P
0 g
s
.42314 .19217 m .42314 .69406 L .38918 .70204 L p .707 .577 .707 r
F P
0 g
s
.79455 .58797 m .79455 .64355 L .8186 .6379 L p .707 .577 .707 r
F P
0 g
s
.8186 .6379 m .8186 .58232 L .79455 .58797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65853 m .26667 .69559 L .23483 .69637 L p .707 .577 .707 r
F P
0 g
s
.73333 .69508 m .73333 .65802 L .70216 .65612 L p .707 .577 .707 r
F P
0 g
s
.73333 .65802 m .73333 .69508 L .76517 .6943 L p .707 .577 .707 r
F P
0 g
s
.76517 .6943 m .76517 .65724 L .73333 .65802 L p .707 .577 .707 r
F P
0 g
s
.23483 .70296 m .23483 .72148 L .20545 .72486 L p .707 .577 .707 r
F P
0 g
s
.76517 .65724 m .76517 .6943 L .79455 .69092 L p .707 .577 .707 r
F P
0 g
s
.79455 .69092 m .79455 .65387 L .76517 .65724 L p .707 .577 .707 r
F P
0 g
s
.29784 .70408 m .29784 .72261 L .26667 .72071 L p .707 .577 .707 r
F P
0 g
s
.26667 .72071 m .26667 .70218 L .29784 .70408 L p .707 .577 .707 r
F P
0 g
s
.6747 .58583 m .6747 .64141 L .70216 .64581 L p .707 .577 .707 r
F P
0 g
s
.6747 .64141 m .6747 .58583 L .65365 .57938 L p .707 .577 .707 r
F P
0 g
s
.70216 .69318 m .70216 .65612 L .6747 .65173 L p .707 .577 .707 r
F P
0 g
s
.70216 .65612 m .70216 .69318 L .73333 .69508 L p .707 .577 .707 r
F P
0 g
s
.55357 .18899 m .55357 .69088 L .50956 .68819 L p .707 .577 .707 r
F P
0 g
s
.50956 .68819 m .50956 .1863 L .55357 .18899 L p .707 .577 .707 r
F P
0 g
s
.23483 .72148 m .23483 .70296 L .26667 .70218 L p .707 .577 .707 r
F P
0 g
s
.26667 .70218 m .26667 .72071 L .23483 .72148 L p .707 .577 .707 r
F P
0 g
s
.73333 .72019 m .73333 .70167 L .70216 .69977 L p .707 .577 .707 r
F P
0 g
s
.73333 .70167 m .73333 .72019 L .76517 .71942 L p .707 .577 .707 r
F P
0 g
s
.76517 .71942 m .76517 .70089 L .73333 .70167 L p .707 .577 .707 r
F P
0 g
s
.46462 .68929 m .46462 .1874 L .50956 .1863 L p .707 .577 .707 r
F P
0 g
s
.46462 .1874 m .46462 .68929 L .42314 .69406 L p .707 .577 .707 r
F P
0 g
s
.79455 .65387 m .79455 .69092 L .8186 .68527 L p .707 .577 .707 r
F P
0 g
s
.8186 .68527 m .8186 .64822 L .79455 .65387 L p .707 .577 .707 r
F P
0 g
s
.76517 .70089 m .76517 .71942 L .79455 .71604 L p .707 .577 .707 r
F P
0 g
s
.79455 .71604 m .79455 .69751 L .76517 .70089 L p .707 .577 .707 r
F P
0 g
s
.8186 .58232 m .8186 .6379 L .83497 .63053 L p .707 .577 .707 r
F P
0 g
s
.83497 .63053 m .83497 .57495 L .8186 .58232 L p .707 .577 .707 r
F P
0 g
s
.50956 .1863 m .50956 .68819 L .46462 .68929 L p .707 .577 .707 r
F P
0 g
s
.6747 .65173 m .6747 .68878 L .70216 .69318 L p .707 .577 .707 r
F P
0 g
s
.70216 .69977 m .70216 .71829 L .73333 .72019 L p .707 .577 .707 r
F P
0 g
s
.70216 .71829 m .70216 .69977 L .6747 .69537 L p .707 .577 .707 r
F P
0 g
s
.65365 .57938 m .65365 .63496 L .6747 .64141 L p .707 .577 .707 r
F P
0 g
s
.6747 .68878 m .6747 .65173 L .65365 .64528 L p .707 .577 .707 r
F P
0 g
s
.6747 .69537 m .6747 .7139 L .70216 .71829 L p .707 .577 .707 r
F P
0 g
s
.79455 .69751 m .79455 .71604 L .8186 .71039 L p .707 .577 .707 r
F P
0 g
s
.8186 .71039 m .8186 .69186 L .79455 .69751 L p .707 .577 .707 r
F P
0 g
s
.65365 .63496 m .65365 .57938 L .64105 .57149 L p .707 .577 .707 r
F P
0 g
s
.65365 .64528 m .65365 .68233 L .6747 .68878 L p .707 .577 .707 r
F P
0 g
s
.6747 .7139 m .6747 .69537 L .65365 .68892 L p .707 .577 .707 r
F P
0 g
s
.8186 .64822 m .8186 .68527 L .83497 .6779 L p .707 .577 .707 r
F P
0 g
s
.83497 .6779 m .83497 .64085 L .8186 .64822 L p .707 .577 .707 r
F P
0 g
s
.65365 .68892 m .65365 .70745 L .6747 .7139 L p .707 .577 .707 r
F P
0 g
s
.64105 .57149 m .64105 .62708 L .65365 .63496 L p .707 .577 .707 r
F P
0 g
s
.83497 .57495 m .83497 .63053 L .84205 .62217 L p .707 .577 .707 r
F P
0 g
s
.84205 .62217 m .84205 .56659 L .83497 .57495 L p .707 .577 .707 r
F P
0 g
s
.65365 .68233 m .65365 .64528 L .64105 .63739 L p .707 .577 .707 r
F P
0 g
s
.8186 .69186 m .8186 .71039 L .83497 .70302 L p .707 .577 .707 r
F P
0 g
s
.83497 .70302 m .83497 .68449 L .8186 .69186 L p .707 .577 .707 r
F P
0 g
s
.64105 .62708 m .64105 .57149 L .63816 .56295 L p .707 .577 .707 r
F P
0 g
s
.64105 .63739 m .64105 .67445 L .65365 .68233 L p .707 .577 .707 r
F P
0 g
s
.65365 .70745 m .65365 .68892 L .64105 .68104 L p .707 .577 .707 r
F P
0 g
s
.83497 .64085 m .83497 .6779 L .84206 .66954 L p .707 .577 .707 r
F P
0 g
s
.84206 .66954 m .84205 .63248 L .83497 .64085 L p .707 .577 .707 r
F P
0 g
s
.64105 .68104 m .64105 .69956 L .65365 .70745 L p .707 .577 .707 r
F P
0 g
s
.63816 .56295 m .63816 .61853 L .64105 .62708 L p .707 .577 .707 r
F P
0 g
s
.84205 .56659 m .84205 .62217 L .83916 .61363 L p .707 .577 .707 r
F P
0 g
s
.83916 .61363 m .83916 .55804 L .84205 .56659 L p .707 .577 .707 r
F P
0 g
s
.83497 .68449 m .83497 .70302 L .84206 .69466 L p .707 .577 .707 r
F P
0 g
s
.84206 .69466 m .84206 .67613 L .83497 .68449 L p .707 .577 .707 r
F P
0 g
s
.64105 .67445 m .64105 .63739 L .63816 .62885 L p .707 .577 .707 r
F P
0 g
s
.63816 .62885 m .63816 .6659 L .64105 .67445 L p .707 .577 .707 r
F P
0 g
s
.64105 .69956 m .64105 .68104 L .63816 .67249 L p .707 .577 .707 r
F P
0 g
s
.63816 .61853 m .63816 .56295 L .64524 .55459 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .67249 m .63816 .69102 L .64105 .69956 L p .707 .577 .707 r
F P
0 g
s
.84205 .63248 m .84206 .66954 L .83916 .661 L p .707 .577 .707 r
F P
0 g
s
.83916 .661 m .83916 .62394 L .84205 .63248 L p .707 .577 .707 r
F P
0 g
s
.64524 .55459 m .64524 .61017 L .63816 .61853 L p .707 .577 .707 r
F P
0 g
s
.84206 .67613 m .84206 .69466 L .83916 .68611 L p .707 .577 .707 r
F P
0 g
s
.83916 .68611 m .83916 .66759 L .84206 .67613 L p .707 .577 .707 r
F P
0 g
s
.83916 .55804 m .83916 .61363 L .82657 .60574 L p .707 .577 .707 r
F P
0 g
s
.82657 .60574 m .82657 .55016 L .83916 .55804 L p .707 .577 .707 r
F P
0 g
s
.63816 .6659 m .63816 .62885 L .64524 .62048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39032 .61089 m .39032 .55531 L .35915 .55341 L p .707 .577 .707 r
F P
0 g
s
.39032 .55531 m .39032 .61089 L .42216 .61011 L p .707 .577 .707 r
F P
0 g
s
.42216 .61011 m .42216 .55453 L .39032 .55531 L p .707 .577 .707 r
F P
0 g
s
.64524 .62048 m .64524 .65754 L .63816 .6659 L p .707 .577 .707 r
F P
0 g
s
.64524 .61017 m .64524 .55459 L .66161 .54722 L p .707 .577 .707 r
F P
0 g
s
.42216 .55453 m .42216 .61011 L .45154 .60673 L p .707 .577 .707 r
F P
0 g
s
.45154 .60673 m .45154 .55115 L .42216 .55453 L p .707 .577 .707 r
F P
0 g
s
.63816 .69102 m .63816 .67249 L .64524 .66413 L p .707 .577 .707 r
F P
0 g
s
.35915 .60899 m .35915 .55341 L .33169 .54902 L p .707 .577 .707 r
F P
0 g
s
.35915 .55341 m .35915 .60899 L .39032 .61089 L p .707 .577 .707 r
F P
0 g
s
.64524 .66413 m .64524 .68266 L .63816 .69102 L p .707 .577 .707 r
F P
0 g
s
.83916 .62394 m .83916 .661 L .82657 .65311 L p .707 .577 .707 r
F P
0 g
s
.82657 .65311 m .82657 .61606 L .83916 .62394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .55115 m .45154 .60673 L .47559 .60109 L p .707 .577 .707 r
F P
0 g
s
.47559 .60109 m .47559 .5455 L .45154 .55115 L p .707 .577 .707 r
F P
0 g
s
.66161 .54722 m .66161 .6028 L .64524 .61017 L p .707 .577 .707 r
F P
0 g
s
.39032 .65826 m .39032 .62121 L .35915 .61931 L p .707 .577 .707 r
F P
0 g
s
.39032 .62121 m .39032 .65826 L .42216 .65748 L p .707 .577 .707 r
F P
0 g
s
.42216 .65748 m .42216 .62043 L .39032 .62121 L p .707 .577 .707 r
F P
0 g
s
.82657 .55016 m .82657 .60574 L .80551 .59929 L p .707 .577 .707 r
F P
0 g
s
.80551 .59929 m .80551 .54371 L .82657 .55016 L p .707 .577 .707 r
F P
0 g
s
.83916 .66759 m .83916 .68611 L .82657 .67823 L p .707 .577 .707 r
F P
0 g
s
.82657 .67823 m .82657 .6597 L .83916 .66759 L p .707 .577 .707 r
F P
0 g
s
.64524 .65754 m .64524 .62048 L .66161 .61312 L p .707 .577 .707 r
F P
0 g
s
.42216 .62043 m .42216 .65748 L .45154 .65411 L p .707 .577 .707 r
F P
0 g
s
.45154 .65411 m .45154 .61705 L .42216 .62043 L p .707 .577 .707 r
F P
0 g
s
.33169 .54902 m .33169 .6046 L .35915 .60899 L p .707 .577 .707 r
F P
0 g
s
.33169 .6046 m .33169 .54902 L .31064 .54256 L p .707 .577 .707 r
F P
0 g
s
.35915 .65636 m .35915 .61931 L .33169 .61491 L p .707 .577 .707 r
F P
0 g
s
.35915 .61931 m .35915 .65636 L .39032 .65826 L p .707 .577 .707 r
F P
0 g
s
.66161 .6028 m .66161 .54722 L .68566 .54157 L p .707 .577 .707 r
F P
0 g
s
.39032 .68338 m .39032 .66485 L .35915 .66295 L p .707 .577 .707 r
F P
0 g
s
.39032 .66485 m .39032 .68338 L .42216 .6826 L p .707 .577 .707 r
F P
0 g
s
.42216 .6826 m .42216 .66407 L .39032 .66485 L p .707 .577 .707 r
F P
0 g
s
.66161 .61312 m .66161 .65017 L .64524 .65754 L p .707 .577 .707 r
F P
0 g
s
.64524 .68266 m .64524 .66413 L .66161 .65676 L p .707 .577 .707 r
F P
0 g
s
.45154 .61705 m .45154 .65411 L .47559 .64846 L p .707 .577 .707 r
F P
0 g
s
.47559 .64846 m .47559 .6114 L .45154 .61705 L p .707 .577 .707 r
F P
0 g
s
.42216 .66407 m .42216 .6826 L .45154 .67922 L p .707 .577 .707 r
F P
0 g
s
.45154 .67922 m .45154 .6607 L .42216 .66407 L p .707 .577 .707 r
F P
0 g
s
.47559 .5455 m .47559 .60109 L .49196 .59372 L p .707 .577 .707 r
F P
0 g
s
.49196 .59372 m .49196 .53813 L .47559 .5455 L p .707 .577 .707 r
F P
0 g
s
.33169 .61491 m .33169 .65197 L .35915 .65636 L p .707 .577 .707 r
F P
0 g
s
.35915 .66295 m .35915 .68148 L .39032 .68338 L p .707 .577 .707 r
F P
0 g
s
.82657 .61606 m .82657 .65311 L .80551 .64666 L p .707 .577 .707 r
F P
0 g
s
.80551 .64666 m .80551 .6096 L .82657 .61606 L p .707 .577 .707 r
F P
0 g
s
.35915 .68148 m .35915 .66295 L .33169 .65856 L p .707 .577 .707 r
F P
0 g
s
.31064 .54256 m .31064 .59814 L .33169 .6046 L p .707 .577 .707 r
F P
0 g
s
.66161 .65676 m .66161 .67529 L .64524 .68266 L p .707 .577 .707 r
F P
0 g
s
.33169 .65197 m .33169 .61491 L .31064 .60846 L p .707 .577 .707 r
F P
0 g
s
.80551 .54371 m .80551 .59929 L .77805 .5949 L p .707 .577 .707 r
F P
0 g
s
.77805 .5949 m .77805 .53931 L .80551 .54371 L p .707 .577 .707 r
F P
0 g
s
.33169 .65856 m .33169 .67709 L .35915 .68148 L p .707 .577 .707 r
F P
0 g
s
.68566 .54157 m .68566 .59715 L .66161 .6028 L p .707 .577 .707 r
F P
0 g
s
.45154 .6607 m .45154 .67922 L .47559 .67357 L p .707 .577 .707 r
F P
0 g
s
.47559 .67357 m .47559 .65505 L .45154 .6607 L p .707 .577 .707 r
F P
0 g
s
.31064 .59814 m .31064 .54256 L .29804 .53468 L p .707 .577 .707 r
F P
0 g
s
.66161 .65017 m .66161 .61312 L .68566 .60747 L p .707 .577 .707 r
F P
0 g
s
.82657 .6597 m .82657 .67823 L .80551 .67178 L p .707 .577 .707 r
F P
0 g
s
.80551 .67178 m .80551 .65325 L .82657 .6597 L p .707 .577 .707 r
F P
0 g
s
.68566 .59715 m .68566 .54157 L .71504 .53819 L p .707 .577 .707 r
F P
0 g
s
.31064 .60846 m .31064 .64551 L .33169 .65197 L p .707 .577 .707 r
F P
0 g
s
.33169 .67709 m .33169 .65856 L .31064 .6521 L p .707 .577 .707 r
F P
0 g
s
.47559 .6114 m .47559 .64846 L .49196 .64109 L p .707 .577 .707 r
F P
0 g
s
.49196 .64109 m .49196 .60403 L .47559 .6114 L p .707 .577 .707 r
F P
0 g
s
.77805 .53931 m .77805 .5949 L .74688 .593 L p .707 .577 .707 r
F P
0 g
s
.74688 .593 m .74688 .53741 L .77805 .53931 L p .707 .577 .707 r
F P
0 g
s
.68566 .60747 m .68566 .64452 L .66161 .65017 L p .707 .577 .707 r
F P
0 g
s
.31064 .6521 m .31064 .67063 L .33169 .67709 L p .707 .577 .707 r
F P
0 g
s
.66161 .67529 m .66161 .65676 L .68566 .65111 L p .707 .577 .707 r
F P
0 g
s
.80551 .6096 m .80551 .64666 L .77805 .64227 L p .707 .577 .707 r
F P
0 g
s
.77805 .64227 m .77805 .60521 L .80551 .6096 L p .707 .577 .707 r
F P
0 g
s
.29804 .53468 m .29804 .59026 L .31064 .59814 L p .707 .577 .707 r
F P
0 g
s
.71504 .59377 m .71504 .53819 L .74688 .53741 L p .707 .577 .707 r
F P
0 g
s
.71504 .53819 m .71504 .59377 L .68566 .59715 L p .707 .577 .707 r
F P
0 g
s
.49196 .53813 m .49196 .59372 L .49904 .58535 L p .707 .577 .707 r
F P
0 g
s
.49904 .58535 m .49904 .52977 L .49196 .53813 L p .707 .577 .707 r
F P
0 g
s
.31064 .64551 m .31064 .60846 L .29804 .60058 L p .707 .577 .707 r
F P
0 g
s
.74688 .53741 m .74688 .593 L .71504 .59377 L p .707 .577 .707 r
F P
0 g
s
.68566 .65111 m .68566 .66964 L .66161 .67529 L p .707 .577 .707 r
F P
0 g
s
.47559 .65505 m .47559 .67357 L .49196 .66621 L p .707 .577 .707 r
F P
0 g
s
.49196 .66621 m .49196 .64768 L .47559 .65505 L p .707 .577 .707 r
F P
0 g
s
.68566 .64452 m .68566 .60747 L .71504 .60409 L p .707 .577 .707 r
F P
0 g
s
.80551 .65325 m .80551 .67178 L .77805 .66738 L p .707 .577 .707 r
F P
0 g
s
.77805 .66738 m .77805 .64886 L .80551 .65325 L p .707 .577 .707 r
F P
0 g
s
.29804 .59026 m .29804 .53468 L .29515 .52614 L p .707 .577 .707 r
F P
0 g
s
.29804 .60058 m .29804 .63763 L .31064 .64551 L p .707 .577 .707 r
F P
0 g
s
.77805 .60521 m .77805 .64227 L .74688 .64037 L p .707 .577 .707 r
F P
0 g
s
.74688 .64037 m .74688 .60331 L .77805 .60521 L p .707 .577 .707 r
F P
0 g
s
.31064 .67063 m .31064 .6521 L .29804 .64422 L p .707 .577 .707 r
F P
0 g
s
.71504 .60409 m .71504 .64114 L .68566 .64452 L p .707 .577 .707 r
F P
0 g
s
.71504 .64114 m .71504 .60409 L .74688 .60331 L p .707 .577 .707 r
F P
0 g
s
.68566 .66964 m .68566 .65111 L .71504 .64773 L p .707 .577 .707 r
F P
0 g
s
.49196 .60403 m .49196 .64109 L .49904 .63272 L p .707 .577 .707 r
F P
0 g
s
.49904 .63272 m .49904 .59567 L .49196 .60403 L p .707 .577 .707 r
F P
0 g
s
.29804 .64422 m .29804 .66275 L .31064 .67063 L p .707 .577 .707 r
F P
0 g
s
.74688 .60331 m .74688 .64037 L .71504 .64114 L p .707 .577 .707 r
F P
0 g
s
.71504 .64773 m .71504 .66626 L .68566 .66964 L p .707 .577 .707 r
F P
0 g
s
.77805 .64886 m .77805 .66738 L .74688 .66548 L p .707 .577 .707 r
F P
0 g
s
.74688 .66548 m .74688 .64696 L .77805 .64886 L p .707 .577 .707 r
F P
0 g
s
.29515 .52614 m .29515 .58172 L .29804 .59026 L p .707 .577 .707 r
F P
0 g
s
.49904 .52977 m .49904 .58535 L .49615 .57681 L p .707 .577 .707 r
F P
0 g
s
.49615 .57681 m .49615 .52123 L .49904 .52977 L p .707 .577 .707 r
F P
0 g
s
.71504 .66626 m .71504 .64773 L .74688 .64696 L p .707 .577 .707 r
F P
0 g
s
.49196 .64768 m .49196 .66621 L .49904 .65784 L p .707 .577 .707 r
F P
0 g
s
.49904 .65784 m .49904 .63931 L .49196 .64768 L p .707 .577 .707 r
F P
0 g
s
.29804 .63763 m .29804 .60058 L .29515 .59203 L p .707 .577 .707 r
F P
0 g
s
.74688 .64696 m .74688 .66548 L .71504 .66626 L p .707 .577 .707 r
F P
0 g
s
.29515 .59203 m .29515 .62909 L .29804 .63763 L p .707 .577 .707 r
F P
0 g
s
.29804 .66275 m .29804 .64422 L .29515 .63568 L p .707 .577 .707 r
F P
0 g
s
.29515 .58172 m .29515 .52614 L .30223 .51777 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29515 .63568 m .29515 .65421 L .29804 .66275 L p .707 .577 .707 r
F P
0 g
s
.49904 .59567 m .49904 .63272 L .49615 .62418 L p .707 .577 .707 r
F P
0 g
s
.49615 .62418 m .49615 .58713 L .49904 .59567 L p .707 .577 .707 r
F P
0 g
s
.30223 .51777 m .30223 .57335 L .29515 .58172 L p .707 .577 .707 r
F P
0 g
s
.49904 .63931 m .49904 .65784 L .49615 .6493 L p .707 .577 .707 r
F P
0 g
s
.49615 .6493 m .49615 .63077 L .49904 .63931 L p .707 .577 .707 r
F P
0 g
s
.49615 .52123 m .49615 .57681 L .48356 .56893 L p .707 .577 .707 r
F P
0 g
s
.48356 .56893 m .48356 .51334 L .49615 .52123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62909 m .29515 .59203 L .30223 .58367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .58367 m .30223 .62072 L .29515 .62909 L p .707 .577 .707 r
F P
0 g
s
.30223 .57335 m .30223 .51777 L .3186 .5104 L p .707 .577 .707 r
F P
0 g
s
.29515 .65421 m .29515 .63568 L .30223 .62731 L p .707 .577 .707 r
F P
0 g
s
.30223 .62731 m .30223 .64584 L .29515 .65421 L p .707 .577 .707 r
F P
0 g
s
.49615 .58713 m .49615 .62418 L .48356 .6163 L p .707 .577 .707 r
F P
0 g
s
.48356 .6163 m .48356 .57924 L .49615 .58713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .5104 m .3186 .56599 L .30223 .57335 L p .707 .577 .707 r
F P
0 g
s
.48356 .51334 m .48356 .56893 L .4625 .56247 L p .707 .577 .707 r
F P
0 g
s
.4625 .56247 m .4625 .50689 L .48356 .51334 L p .707 .577 .707 r
F P
0 g
s
.49615 .63077 m .49615 .6493 L .48356 .64141 L p .707 .577 .707 r
F P
0 g
s
.48356 .64141 m .48356 .62289 L .49615 .63077 L p .707 .577 .707 r
F P
0 g
s
.30223 .62072 m .30223 .58367 L .3186 .5763 L p .707 .577 .707 r
F P
0 g
s
.3186 .56599 m .3186 .5104 L .34265 .50475 L p .707 .577 .707 r
F P
0 g
s
.3186 .5763 m .3186 .61336 L .30223 .62072 L p .707 .577 .707 r
F P
0 g
s
.30223 .64584 m .30223 .62731 L .3186 .61995 L p .707 .577 .707 r
F P
0 g
s
.48356 .57924 m .48356 .6163 L .4625 .60984 L p .707 .577 .707 r
F P
0 g
s
.4625 .60984 m .4625 .57279 L .48356 .57924 L p .707 .577 .707 r
F P
0 g
s
.3186 .61995 m .3186 .63847 L .30223 .64584 L p .707 .577 .707 r
F P
0 g
s
.4625 .50689 m .4625 .56247 L .43504 .55808 L p .707 .577 .707 r
F P
0 g
s
.43504 .55808 m .43504 .5025 L .4625 .50689 L p .707 .577 .707 r
F P
0 g
s
.34265 .50475 m .34265 .56034 L .3186 .56599 L p .707 .577 .707 r
F P
0 g
s
.3186 .61336 m .3186 .5763 L .34265 .57065 L p .707 .577 .707 r
F P
0 g
s
.48356 .62289 m .48356 .64141 L .4625 .63496 L p .707 .577 .707 r
F P
0 g
s
.4625 .63496 m .4625 .61643 L .48356 .62289 L p .707 .577 .707 r
F P
0 g
s
.34265 .56034 m .34265 .50475 L .37203 .50137 L p .707 .577 .707 r
F P
0 g
s
.43504 .5025 m .43504 .55808 L .40387 .55618 L p .707 .577 .707 r
F P
0 g
s
.40387 .55618 m .40387 .5006 L .43504 .5025 L p .707 .577 .707 r
F P
0 g
s
.34265 .57065 m .34265 .60771 L .3186 .61336 L p .707 .577 .707 r
F P
0 g
s
.3186 .63847 m .3186 .61995 L .34265 .6143 L p .707 .577 .707 r
F P
0 g
s
.4625 .57279 m .4625 .60984 L .43504 .60545 L p .707 .577 .707 r
F P
0 g
s
.43504 .60545 m .43504 .5684 L .4625 .57279 L p .707 .577 .707 r
F P
0 g
s
.37203 .55696 m .37203 .50137 L .40387 .5006 L p .707 .577 .707 r
F P
0 g
s
.37203 .50137 m .37203 .55696 L .34265 .56034 L p .707 .577 .707 r
F P
0 g
s
.40387 .5006 m .40387 .55618 L .37203 .55696 L p .707 .577 .707 r
F P
0 g
s
.34265 .6143 m .34265 .63282 L .3186 .63847 L p .707 .577 .707 r
F P
0 g
s
.34265 .60771 m .34265 .57065 L .37203 .56727 L p .707 .577 .707 r
F P
0 g
s
.4625 .61643 m .4625 .63496 L .43504 .63057 L p .707 .577 .707 r
F P
0 g
s
.43504 .63057 m .43504 .61204 L .4625 .61643 L p .707 .577 .707 r
F P
0 g
s
.43504 .5684 m .43504 .60545 L .40387 .60355 L p .707 .577 .707 r
F P
0 g
s
.40387 .60355 m .40387 .56649 L .43504 .5684 L p .707 .577 .707 r
F P
0 g
s
.37203 .56727 m .37203 .60433 L .34265 .60771 L p .707 .577 .707 r
F P
0 g
s
.37203 .60433 m .37203 .56727 L .40387 .56649 L p .707 .577 .707 r
F P
0 g
s
.34265 .63282 m .34265 .6143 L .37203 .61092 L p .707 .577 .707 r
F P
0 g
s
.40387 .56649 m .40387 .60355 L .37203 .60433 L p .707 .577 .707 r
F P
0 g
s
.37203 .61092 m .37203 .62945 L .34265 .63282 L p .707 .577 .707 r
F P
0 g
s
.43504 .61204 m .43504 .63057 L .40387 .62867 L p .707 .577 .707 r
F P
0 g
s
.40387 .62867 m .40387 .61014 L .43504 .61204 L p .707 .577 .707 r
F P
0 g
s
.37203 .62945 m .37203 .61092 L .40387 .61014 L p .707 .577 .707 r
F P
0 g
s
.40387 .61014 m .40387 .62867 L .37203 .62945 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eo
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001dOol30000
0eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol0071oo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00
001aOol006eoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEUYFFUH3001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061o
o`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000HOol90014Ool005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?Ool90004FUH00`00FUIJEP02FUH8000l
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00008Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000goo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH40006FUH00`00FUIJEP04
FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF0000
15YF1@001eYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00
FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP8000AJEP03
001JEUYF00EJEQT00003FUH005YF00EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH000030005FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000UYF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0002FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000oOolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP@000EJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUH000020006FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPT000IJEP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH50002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPd000=JEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEPH00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH000020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP00FUH20003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P000UYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF000005YF
00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF001oo`0/Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800004FUH000000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP03FUHC0004
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYF
FUH<0004FUHF0004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHH0003FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30002FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50003FUH00`00FUIJEP0:0004FUH00`00FUIJ
EP02FUH80004Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPL000MJEP@000IJEP04001JEP000002FUH30002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH000030003FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPT000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH30003FUH2000]Ool002aoo`03001JEP0000AJEP03001J
EP0000<000IJEP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUH000040003FUH80004
FUH00`00FUIJEP03FUH>0002FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF000000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020002FUH20000
0eYF0000000]Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQH000=JEP03001JEUYF
009JEPH0009JEP05001JEUYF001JEP0:0004FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF200015YF
00<005YFFUH00eYF2@000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00
;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03
001JEUYF00<002eoo`00;7oo0P000eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEP03001JEUYF
00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`80009JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEP00008000IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<000=JEP04
001JEUYFFUH2000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF200015YF
10001UYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH2000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH0000B0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30002Ool4000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003Ool2000015YF00000000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000`00
0UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0017oo0`000eYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF100015YF2@00
35YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF00<005YFFUH00UYF1P0000=JEP0000005`001Goo100000=JEP00FUH00eYF00<005YF0000;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH?0008FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YF
FUIJEPT0019oo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00<005YF0000
0`000Woo6`000Woo1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`03001JEP0000=JEP@000=oo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000Eoo`@00005FUH005YFFUH00002FUH01000FUIJEUYF0P00
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo000/Ool01000FUH005YF0P000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP<0009J
EP05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00
;7oo00D005YF000005YF00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP000080009JEP<0009JEP800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH4000dOol002aoo`80009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04FUH60004FUH00`00FUIJEP06
FUH40005FUH00`00FUIJEP02FUH7000hOol002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEQ/003moo`00;7oo0`0015YF00<0
05YFFUH015YF00<005YFFUH00UYF30001EYF200015YF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2
0007Ool50018Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00;7oo00<005YF00000eYF1P001eYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
27oo0`00BGoo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP00
00@000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<00003FUH005YF00AJEP04001JEUYFFUH2001DOol002aoo`@000=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`D0009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEPL0009oo`@000=JEP04001JEUYFFUH2001DOol002aoo`80009J
EP<000=oo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00=oo`<00004FUH007ooOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEPX000=JEP8005Ao
o`00;7oo0P000eYF00<005YF00000P001Goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@00
17oo0`000UYF00<005YF000017oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEP00
0080009JEP03001JEUYF008005Aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0027oo4`001Goo1000
00=JEP00FUH00UYF00<005YF00001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001eYF00<005YFFUH015YF00<005YFFUH00UYF
0P0000=JEP0000000P00E7oo000]Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPP001=oo`D000EJ
EP04001JEUYFFUH20009Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000015YF00000000E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4`00
0eYF00<005YFFUH015YF00D005YFFUIJEP0000eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEQL000EJEP03001JEUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000001Eoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEPD000AJEP03001JEUYF00=J
EP@00003FUH005YF00AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002=ooaH000EJEP03001JEUYF
00IJEPD000AJEP03001JEUYF00EJEP03001JEP00008000AJEP05001JEUYFFUH0001EOol003Ioo`D0
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03001J
EP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP8005Aoo`00>goo200015YF10001UYF00<005YFFUH00UYF1@00<goo
00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8005Aoo`00@goo4`00>7oo00<005YF00000`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000=JEP000000
E7oo0017Ool50012Ool2000015YF001oogoo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00004Ool00000FUH3001DOol004Moo`D0049oo`80
009JEP<0009oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL0009oo`<0
00=JEP<005Aoo`00B7oo0`00@goo0P000UYF00<005YFFUH01@000Woo6`001Goo100000=JEP00FUH0
0eYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YF00000`006Goo1@001EYF00<005YF
FUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF1@00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH7001OOol009aooa/006Ioo`00ZGoo1@00Kgoo002YOol5001_Ool00:Uoo`D006moo`00
ZWoo0`00L7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73372 m .59613 .67814 L .56496 .67624 L p .707 .577 .707 r
F P
0 g
s
.59613 .67814 m .59613 .73372 L .62796 .73294 L p .707 .577 .707 r
F P
0 g
s
.62796 .73294 m .62796 .67736 L .59613 .67814 L p .707 .577 .707 r
F P
0 g
s
.62796 .67736 m .62796 .73294 L .65734 .72956 L p .707 .577 .707 r
F P
0 g
s
.65734 .72956 m .65734 .67398 L .62796 .67736 L p .707 .577 .707 r
F P
0 g
s
.56496 .73182 m .56496 .67624 L .5375 .67184 L p .707 .577 .707 r
F P
0 g
s
.56496 .67624 m .56496 .73182 L .59613 .73372 L p .707 .577 .707 r
F P
0 g
s
.65734 .67398 m .65734 .72956 L .6814 .72391 L p .707 .577 .707 r
F P
0 g
s
.6814 .72391 m .6814 .66833 L .65734 .67398 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .736 L .56496 .7341 L p .707 .577 .707 r
F P
0 g
s
.59613 .736 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .736 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.5375 .67184 m .5375 .72743 L .56496 .73182 L p .707 .577 .707 r
F P
0 g
s
.5375 .72743 m .5375 .67184 L .51644 .66539 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .7341 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .7341 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.59613 .78785 m .59613 .76932 L .56496 .76742 L p .707 .577 .707 r
F P
0 g
s
.59613 .76932 m .59613 .78785 L .62796 .78707 L p .707 .577 .707 r
F P
0 g
s
.62796 .78707 m .62796 .76854 L .59613 .76932 L p .707 .577 .707 r
F P
0 g
s
.62796 .76854 m .62796 .78707 L .65735 .78369 L p .707 .577 .707 r
F P
0 g
s
.65735 .78369 m .65735 .76516 L .62796 .76854 L p .707 .577 .707 r
F P
0 g
s
.56496 .76742 m .56496 .78594 L .59613 .78785 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76325 L p .707 .577 .707 r
F P
0 g
s
.6814 .76325 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.56496 .78594 m .56496 .76742 L .5375 .76302 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.6814 .66833 m .6814 .72391 L .69777 .71654 L p .707 .577 .707 r
F P
0 g
s
.69777 .71654 m .69777 .66096 L .6814 .66833 L p .707 .577 .707 r
F P
0 g
s
.5375 .76302 m .5375 .78155 L .56496 .78594 L p .707 .577 .707 r
F P
0 g
s
.51644 .66539 m .51644 .72097 L .5375 .72743 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.65735 .76516 m .65735 .78369 L .6814 .77804 L p .707 .577 .707 r
F P
0 g
s
.6814 .77804 m .6814 .75951 L .65735 .76516 L p .707 .577 .707 r
F P
0 g
s
.51644 .72097 m .51644 .66539 L .50385 .65751 L p .707 .577 .707 r
F P
0 g
s
.5375 .78155 m .5375 .76302 L .51644 .75657 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76325 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.51644 .75657 m .51644 .7751 L .5375 .78155 L p .707 .577 .707 r
F P
0 g
s
.6814 .75951 m .6814 .77804 L .69777 .77067 L p .707 .577 .707 r
F P
0 g
s
.69777 .77067 m .69777 .75214 L .6814 .75951 L p .707 .577 .707 r
F P
0 g
s
.50385 .65751 m .50385 .71309 L .51644 .72097 L p .707 .577 .707 r
F P
0 g
s
.69777 .66096 m .69777 .71654 L .70485 .70818 L p .707 .577 .707 r
F P
0 g
s
.70485 .70818 m .70485 .6526 L .69777 .66096 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71537 L p .707 .577 .707 r
F P
0 g
s
.51644 .7751 m .51644 .75657 L .50385 .74869 L p .707 .577 .707 r
F P
0 g
s
.50385 .71537 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.50385 .71309 m .50385 .65751 L .50095 .64896 L p .707 .577 .707 r
F P
0 g
s
.50385 .74869 m .50385 .76721 L .51644 .7751 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.49044 .73057 m .49044 .22868 L .44643 .226 L p .707 .577 .707 r
F P
0 g
s
.50095 .64896 m .50095 .70455 L .50385 .71309 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71537 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70455 m .50095 .64896 L .50804 .6406 L p .707 .577 .707 r
F P
0 g
s
.50804 .6406 m .50804 .69618 L .50095 .70455 L p .707 .577 .707 r
F P
0 g
s
.50385 .76721 m .50385 .74869 L .50095 .74014 L p .707 .577 .707 r
F P
0 g
s
.50095 .74014 m .50095 .75867 L .50385 .76721 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .69618 m .50804 .6406 L .5244 .63323 L p .707 .577 .707 r
F P
0 g
s
.5244 .63323 m .5244 .68881 L .50804 .69618 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.50804 .75031 m .50804 .73178 L .5244 .72441 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72815 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .68881 m .5244 .63323 L .54846 .62758 L p .707 .577 .707 r
F P
0 g
s
.5244 .72441 m .5244 .74294 L .50804 .75031 L p .707 .577 .707 r
F P
0 g
s
.54846 .62758 m .54846 .68316 L .5244 .68881 L p .707 .577 .707 r
F P
0 g
s
.5244 .72815 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.5244 .74294 m .5244 .72441 L .54846 .71876 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .7225 L .5244 .72815 L p .707 .577 .707 r
F P
0 g
s
.49044 .22868 m .49044 .73057 L .53538 .72947 L p .707 .577 .707 r
F P
0 g
s
.53538 .72947 m .53538 .22758 L .49044 .22868 L p .707 .577 .707 r
F P
0 g
s
.54846 .68316 m .54846 .62758 L .57784 .6242 L p .707 .577 .707 r
F P
0 g
s
.54846 .71876 m .54846 .73729 L .5244 .74294 L p .707 .577 .707 r
F P
0 g
s
.57784 .6242 m .57784 .67978 L .54846 .68316 L p .707 .577 .707 r
F P
0 g
s
.54846 .7225 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.54846 .73729 m .54846 .71876 L .57784 .71538 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .7225 L p .707 .577 .707 r
F P
0 g
s
.57784 .71538 m .57784 .73391 L .54846 .73729 L p .707 .577 .707 r
F P
0 g
s
.53538 .22758 m .53538 .72947 L .57686 .7247 L p .707 .577 .707 r
F P
0 g
s
.57686 .7247 m .57686 .22281 L .53538 .22758 L p .707 .577 .707 r
F P
0 g
s
.69777 .75214 m .69777 .77067 L .70485 .76231 L p .707 .577 .707 r
F P
0 g
s
.70485 .76231 m .70485 .74378 L .69777 .75214 L p .707 .577 .707 r
F P
0 g
s
.44643 .72789 m .44643 .226 L .40766 .2198 L p .707 .577 .707 r
F P
0 g
s
.44643 .226 m .44643 .72789 L .49044 .73057 L p .707 .577 .707 r
F P
0 g
s
.70485 .6526 m .70485 .70818 L .70195 .69964 L p .707 .577 .707 r
F P
0 g
s
.70195 .69964 m .70195 .64406 L .70485 .6526 L p .707 .577 .707 r
F P
0 g
s
.57784 .67978 m .57784 .6242 L .60968 .62343 L p .707 .577 .707 r
F P
0 g
s
.60968 .62343 m .60968 .67901 L .57784 .67978 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .68129 L .64085 .68319 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .68129 L p .707 .577 .707 r
F P
0 g
s
.60968 .68129 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.60968 .73313 m .60968 .71461 L .64085 .71651 L p .707 .577 .707 r
F P
0 g
s
.57784 .73391 m .57784 .71538 L .60968 .71461 L p .707 .577 .707 r
F P
0 g
s
.60968 .71461 m .60968 .73313 L .57784 .73391 L p .707 .577 .707 r
F P
0 g
s
.57686 .22281 m .57686 .7247 L .61082 .71673 L p .707 .577 .707 r
F P
0 g
s
.64085 .62533 m .64085 .68091 L .60968 .67901 L p .707 .577 .707 r
F P
0 g
s
.60968 .67901 m .60968 .62343 L .64085 .62533 L p .707 .577 .707 r
F P
0 g
s
.61082 .71673 m .61082 .21484 L .57686 .22281 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70192 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.40766 .72169 m .40766 .2198 L .37794 .21069 L p .707 .577 .707 r
F P
0 g
s
.40766 .2198 m .40766 .72169 L .44643 .72789 L p .707 .577 .707 r
F P
0 g
s
.70485 .74378 m .70485 .76231 L .70195 .75377 L p .707 .577 .707 r
F P
0 g
s
.70195 .75377 m .70195 .73524 L .70485 .74378 L p .707 .577 .707 r
F P
0 g
s
.70195 .64406 m .70195 .69964 L .68936 .69175 L p .707 .577 .707 r
F P
0 g
s
.68936 .69175 m .68936 .63617 L .70195 .64406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .75867 m .50095 .74014 L .50804 .73178 L p .707 .577 .707 r
F P
0 g
s
.64085 .68319 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.61082 .21484 m .61082 .71673 L .63393 .70632 L p .707 .577 .707 r
F P
0 g
s
.63393 .70632 m .63393 .20444 L .61082 .21484 L p .707 .577 .707 r
F P
0 g
s
.25312 .6969 m .25312 .64132 L .22195 .63942 L p .707 .577 .707 r
F P
0 g
s
.25312 .64132 m .25312 .6969 L .28495 .69613 L p .707 .577 .707 r
F P
0 g
s
.28495 .69613 m .28495 .64054 L .25312 .64132 L p .707 .577 .707 r
F P
0 g
s
.28495 .64054 m .28495 .69613 L .31434 .69275 L p .707 .577 .707 r
F P
0 g
s
.31434 .69275 m .31434 .63716 L .28495 .64054 L p .707 .577 .707 r
F P
0 g
s
.50804 .73178 m .50804 .75031 L .50095 .75867 L p .707 .577 .707 r
F P
0 g
s
.70195 .70192 m .70195 .73898 L .68936 .73109 L p .707 .577 .707 r
F P
0 g
s
.68936 .73109 m .68936 .69404 L .70195 .70192 L p .707 .577 .707 r
F P
0 g
s
.22195 .695 m .22195 .63942 L .19449 .63503 L p .707 .577 .707 r
F P
0 g
s
.22195 .63942 m .22195 .695 L .25312 .6969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.37794 .71257 m .37794 .21069 L .36016 .19956 L p .707 .577 .707 r
F P
0 g
s
.37794 .21069 m .37794 .71257 L .40766 .72169 L p .707 .577 .707 r
F P
0 g
s
.31434 .63716 m .31434 .69275 L .33839 .6871 L p .707 .577 .707 r
F P
0 g
s
.33839 .6871 m .33839 .63152 L .31434 .63716 L p .707 .577 .707 r
F P
0 g
s
.70195 .73524 m .70195 .75377 L .68936 .74588 L p .707 .577 .707 r
F P
0 g
s
.68936 .74588 m .68936 .72735 L .70195 .73524 L p .707 .577 .707 r
F P
0 g
s
.25312 .73624 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73624 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.68936 .63617 m .68936 .69175 L .66831 .6853 L p .707 .577 .707 r
F P
0 g
s
.66831 .6853 m .66831 .62972 L .68936 .63617 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69503 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.19449 .63503 m .19449 .69061 L .22195 .695 L p .707 .577 .707 r
F P
0 g
s
.19449 .69061 m .19449 .63503 L .17343 .62857 L p .707 .577 .707 r
F P
0 g
s
.22195 .73434 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73434 L .25312 .73624 L p .707 .577 .707 r
F P
0 g
s
.25312 .75103 m .25312 .7325 L .22195 .7306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7325 m .25312 .75103 L .28495 .75025 L p .707 .577 .707 r
F P
0 g
s
.28495 .75025 m .28495 .73173 L .25312 .7325 L p .707 .577 .707 r
F P
0 g
s
.28495 .73173 m .28495 .75025 L .31434 .74687 L p .707 .577 .707 r
F P
0 g
s
.31434 .74687 m .31434 .72835 L .28495 .73173 L p .707 .577 .707 r
F P
0 g
s
.22195 .7306 m .22195 .74913 L .25312 .75103 L p .707 .577 .707 r
F P
0 g
s
.31434 .69503 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68938 L .31434 .69503 L p .707 .577 .707 r
F P
0 g
s
.22195 .74913 m .22195 .7306 L .19449 .72621 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73434 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .73109 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.33839 .63152 m .33839 .6871 L .35476 .67973 L p .707 .577 .707 r
F P
0 g
s
.35476 .67973 m .35476 .62415 L .33839 .63152 L p .707 .577 .707 r
F P
0 g
s
.66831 .62972 m .66831 .6853 L .64085 .68091 L p .707 .577 .707 r
F P
0 g
s
.64085 .68091 m .64085 .62533 L .66831 .62972 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .68319 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.63393 .20444 m .63393 .70632 L .64393 .69452 L p .707 .577 .707 r
F P
0 g
s
.64393 .69452 m .64393 .19263 L .63393 .20444 L p .707 .577 .707 r
F P
0 g
s
.19449 .72621 m .19449 .74474 L .22195 .74913 L p .707 .577 .707 r
F P
0 g
s
.17343 .62857 m .17343 .68416 L .19449 .69061 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.31434 .72835 m .31434 .74687 L .33839 .74122 L p .707 .577 .707 r
F P
0 g
s
.33839 .74122 m .33839 .7227 L .31434 .72835 L p .707 .577 .707 r
F P
0 g
s
.68936 .72735 m .68936 .74588 L .66831 .73943 L p .707 .577 .707 r
F P
0 g
s
.66831 .73943 m .66831 .7209 L .68936 .72735 L p .707 .577 .707 r
F P
0 g
s
.17343 .68416 m .17343 .62857 L .16084 .62069 L p .707 .577 .707 r
F P
0 g
s
.19449 .74474 m .19449 .72621 L .17343 .71976 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68938 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68938 L p .707 .577 .707 r
F P
0 g
s
.35476 .62415 m .35476 .67973 L .36184 .67137 L p .707 .577 .707 r
F P
0 g
s
.36184 .67137 m .36184 .61578 L .35476 .62415 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .61578 m .36184 .67137 L .35894 .66282 L p .707 .577 .707 r
F P
0 g
s
.35894 .66282 m .35894 .60724 L .36184 .61578 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .72549 m .36184 .70696 L .35476 .71533 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70216 L p .707 .577 .707 r
F P
0 g
s
.35894 .70216 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .70144 m .36016 .19956 L .35607 .1875 L p .707 .577 .707 r
F P
0 g
s
.36016 .19956 m .36016 .70144 L .37794 .71257 L p .707 .577 .707 r
F P
0 g
s
.17343 .71976 m .17343 .73828 L .19449 .74474 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.33839 .7227 m .33839 .74122 L .35476 .73386 L p .707 .577 .707 r
F P
0 g
s
.35476 .73386 m .35476 .71533 L .33839 .7227 L p .707 .577 .707 r
F P
0 g
s
.16084 .62069 m .16084 .67627 L .17343 .68416 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.66831 .7209 m .66831 .73943 L .64085 .73503 L p .707 .577 .707 r
F P
0 g
s
.64085 .73503 m .64085 .71651 L .66831 .7209 L p .707 .577 .707 r
F P
0 g
s
.17343 .73828 m .17343 .71976 L .16084 .71187 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.16084 .67627 m .16084 .62069 L .15794 .61215 L p .707 .577 .707 r
F P
0 g
s
.16084 .71187 m .16084 .7304 L .17343 .73828 L p .707 .577 .707 r
F P
0 g
s
.64393 .19263 m .64393 .69452 L .63984 .68246 L p .707 .577 .707 r
F P
0 g
s
.63984 .68246 m .63984 .18057 L .64393 .19263 L p .707 .577 .707 r
F P
0 g
s
.64085 .71651 m .64085 .73503 L .60968 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .71533 m .35476 .73386 L .36184 .72549 L p .707 .577 .707 r
F P
0 g
s
.15794 .61215 m .15794 .66773 L .16084 .67627 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.35894 .60724 m .35894 .66282 L .34635 .65494 L p .707 .577 .707 r
F P
0 g
s
.34635 .65494 m .34635 .59936 L .35894 .60724 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70216 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65722 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .1875 m .35607 .68938 L .36016 .70144 L p .707 .577 .707 r
F P
0 g
s
.35607 .68938 m .35607 .1875 L .36607 .17569 L p .707 .577 .707 r
F P
0 g
s
.16084 .7304 m .16084 .71187 L .15794 .70333 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.15794 .70333 m .15794 .72186 L .16084 .7304 L p .707 .577 .707 r
F P
0 g
s
.15794 .66773 m .15794 .61215 L .16503 .60378 L p .707 .577 .707 r
F P
0 g
s
.36184 .70696 m .36184 .72549 L .35894 .71695 L p .707 .577 .707 r
F P
0 g
s
.35894 .71695 m .35894 .69842 L .36184 .70696 L p .707 .577 .707 r
F P
0 g
s
.16503 .60378 m .16503 .65937 L .15794 .66773 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.63984 .18057 m .63984 .68246 L .62206 .67133 L p .707 .577 .707 r
F P
0 g
s
.62206 .67133 m .62206 .16944 L .63984 .18057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .72186 m .15794 .70333 L .16503 .69497 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.16503 .65937 m .16503 .60378 L .1814 .59642 L p .707 .577 .707 r
F P
0 g
s
.16503 .69497 m .16503 .71349 L .15794 .72186 L p .707 .577 .707 r
F P
0 g
s
.36607 .67758 m .36607 .17569 L .38918 .16529 L p .707 .577 .707 r
F P
0 g
s
.36607 .17569 m .36607 .67758 L .35607 .68938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .69842 m .35894 .71695 L .34635 .70907 L p .707 .577 .707 r
F P
0 g
s
.34635 .70907 m .34635 .69054 L .35894 .69842 L p .707 .577 .707 r
F P
0 g
s
.1814 .59642 m .1814 .652 L .16503 .65937 L p .707 .577 .707 r
F P
0 g
s
.34635 .59936 m .34635 .65494 L .3253 .64848 L p .707 .577 .707 r
F P
0 g
s
.3253 .64848 m .3253 .5929 L .34635 .59936 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65428 L p .707 .577 .707 r
F P
0 g
s
.16503 .71349 m .16503 .69497 L .1814 .6876 L p .707 .577 .707 r
F P
0 g
s
.62206 .16944 m .62206 .67133 L .59233 .66221 L p .707 .577 .707 r
F P
0 g
s
.59233 .66221 m .59233 .16033 L .62206 .16944 L p .707 .577 .707 r
F P
0 g
s
.1814 .65428 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.1814 .652 m .1814 .59642 L .20545 .59077 L p .707 .577 .707 r
F P
0 g
s
.1814 .6876 m .1814 .70612 L .16503 .71349 L p .707 .577 .707 r
F P
0 g
s
.34635 .65722 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65722 L p .707 .577 .707 r
F P
0 g
s
.3253 .5929 m .3253 .64848 L .29784 .64409 L p .707 .577 .707 r
F P
0 g
s
.29784 .64409 m .29784 .58851 L .3253 .5929 L p .707 .577 .707 r
F P
0 g
s
.38918 .16529 m .38918 .66717 L .36607 .67758 L p .707 .577 .707 r
F P
0 g
s
.38918 .66717 m .38918 .16529 L .42314 .15731 L p .707 .577 .707 r
F P
0 g
s
.34635 .69054 m .34635 .70907 L .3253 .70261 L p .707 .577 .707 r
F P
0 g
s
.3253 .70261 m .3253 .68408 L .34635 .69054 L p .707 .577 .707 r
F P
0 g
s
.20545 .59077 m .20545 .64635 L .1814 .652 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65428 L .20545 .64863 L p .707 .577 .707 r
F P
0 g
s
.20545 .64635 m .20545 .59077 L .23483 .58739 L p .707 .577 .707 r
F P
0 g
s
.1814 .70612 m .1814 .6876 L .20545 .68195 L p .707 .577 .707 r
F P
0 g
s
.20545 .64863 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.29784 .58851 m .29784 .64409 L .26667 .64219 L p .707 .577 .707 r
F P
0 g
s
.26667 .64219 m .26667 .58661 L .29784 .58851 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68343 L p .707 .577 .707 r
F P
0 g
s
.29784 .68343 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68195 m .20545 .70048 L .1814 .70612 L p .707 .577 .707 r
F P
0 g
s
.23483 .64297 m .23483 .58739 L .26667 .58661 L p .707 .577 .707 r
F P
0 g
s
.23483 .58739 m .23483 .64297 L .20545 .64635 L p .707 .577 .707 r
F P
0 g
s
.59233 .16033 m .59233 .66221 L .55357 .65601 L p .707 .577 .707 r
F P
0 g
s
.55357 .65601 m .55357 .15412 L .59233 .16033 L p .707 .577 .707 r
F P
0 g
s
.26667 .58661 m .26667 .64219 L .23483 .64297 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64863 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.73333 .64168 m .73333 .5861 L .70216 .5842 L p .707 .577 .707 r
F P
0 g
s
.73333 .5861 m .73333 .64168 L .76517 .6409 L p .707 .577 .707 r
F P
0 g
s
.76517 .6409 m .76517 .58532 L .73333 .5861 L p .707 .577 .707 r
F P
0 g
s
.3253 .68408 m .3253 .70261 L .29784 .69822 L p .707 .577 .707 r
F P
0 g
s
.29784 .69822 m .29784 .67969 L .3253 .68408 L p .707 .577 .707 r
F P
0 g
s
.76517 .58532 m .76517 .6409 L .79455 .63752 L p .707 .577 .707 r
F P
0 g
s
.79455 .63752 m .79455 .58194 L .76517 .58532 L p .707 .577 .707 r
F P
0 g
s
.42314 .6592 m .42314 .15731 L .46462 .15254 L p .707 .577 .707 r
F P
0 g
s
.42314 .15731 m .42314 .6592 L .38918 .66717 L p .707 .577 .707 r
F P
0 g
s
.70216 .63978 m .70216 .5842 L .6747 .5798 L p .707 .577 .707 r
F P
0 g
s
.70216 .5842 m .70216 .63978 L .73333 .64168 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68343 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.20545 .70048 m .20545 .68195 L .23483 .67857 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.23483 .67857 m .23483 .6971 L .20545 .70048 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.79455 .58194 m .79455 .63752 L .8186 .63187 L p .707 .577 .707 r
F P
0 g
s
.8186 .63187 m .8186 .57629 L .79455 .58194 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68024 L p .707 .577 .707 r
F P
0 g
s
.76517 .68024 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.29784 .67969 m .29784 .69822 L .26667 .69632 L p .707 .577 .707 r
F P
0 g
s
.26667 .69632 m .26667 .67779 L .29784 .67969 L p .707 .577 .707 r
F P
0 g
s
.55357 .15412 m .55357 .65601 L .50956 .65333 L p .707 .577 .707 r
F P
0 g
s
.50956 .65333 m .50956 .15144 L .55357 .15412 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68024 L .79455 .67686 L p .707 .577 .707 r
F P
0 g
s
.79455 .67686 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.23483 .6971 m .23483 .67857 L .26667 .67779 L p .707 .577 .707 r
F P
0 g
s
.6747 .5798 m .6747 .63539 L .70216 .63978 L p .707 .577 .707 r
F P
0 g
s
.6747 .63539 m .6747 .5798 L .65365 .57335 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63767 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.46462 .65443 m .46462 .15254 L .50956 .15144 L p .707 .577 .707 r
F P
0 g
s
.46462 .15254 m .46462 .65443 L .42314 .6592 L p .707 .577 .707 r
F P
0 g
s
.26667 .67779 m .26667 .69632 L .23483 .6971 L p .707 .577 .707 r
F P
0 g
s
.73333 .69581 m .73333 .67728 L .70216 .67538 L p .707 .577 .707 r
F P
0 g
s
.73333 .67728 m .73333 .69581 L .76517 .69503 L p .707 .577 .707 r
F P
0 g
s
.76517 .69503 m .76517 .6765 L .73333 .67728 L p .707 .577 .707 r
F P
0 g
s
.50956 .15144 m .50956 .65333 L .46462 .65443 L p .707 .577 .707 r
F P
0 g
s
.76517 .6765 m .76517 .69503 L .79455 .69165 L p .707 .577 .707 r
F P
0 g
s
.79455 .69165 m .79455 .67312 L .76517 .6765 L p .707 .577 .707 r
F P
0 g
s
.70216 .67538 m .70216 .69391 L .73333 .69581 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67686 L .8186 .67121 L p .707 .577 .707 r
F P
0 g
s
.8186 .67121 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.70216 .69391 m .70216 .67538 L .6747 .67099 L p .707 .577 .707 r
F P
0 g
s
.6747 .63767 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.8186 .57629 m .8186 .63187 L .83497 .62451 L p .707 .577 .707 r
F P
0 g
s
.83497 .62451 m .83497 .56892 L .8186 .57629 L p .707 .577 .707 r
F P
0 g
s
.6747 .67099 m .6747 .68951 L .70216 .69391 L p .707 .577 .707 r
F P
0 g
s
.65365 .57335 m .65365 .62893 L .6747 .63539 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63767 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.79455 .67312 m .79455 .69165 L .8186 .686 L p .707 .577 .707 r
F P
0 g
s
.8186 .686 m .8186 .66747 L .79455 .67312 L p .707 .577 .707 r
F P
0 g
s
.65365 .62893 m .65365 .57335 L .64105 .56547 L p .707 .577 .707 r
F P
0 g
s
.6747 .68951 m .6747 .67099 L .65365 .66453 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66827 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67121 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.65365 .66453 m .65365 .68306 L .6747 .68951 L p .707 .577 .707 r
F P
0 g
s
.8186 .66747 m .8186 .686 L .83497 .67863 L p .707 .577 .707 r
F P
0 g
s
.83497 .67863 m .83497 .66011 L .8186 .66747 L p .707 .577 .707 r
F P
0 g
s
.64105 .56547 m .64105 .62105 L .65365 .62893 L p .707 .577 .707 r
F P
0 g
s
.83497 .56892 m .83497 .62451 L .84205 .61614 L p .707 .577 .707 r
F P
0 g
s
.84205 .61614 m .84205 .56056 L .83497 .56892 L p .707 .577 .707 r
F P
0 g
s
.65365 .66827 m .65365 .63122 L .64105 .62333 L p .707 .577 .707 r
F P
0 g
s
.65365 .68306 m .65365 .66453 L .64105 .65665 L p .707 .577 .707 r
F P
0 g
s
.64105 .62333 m .64105 .66039 L .65365 .66827 L p .707 .577 .707 r
F P
0 g
s
.64105 .62105 m .64105 .56547 L .63816 .55692 L p .707 .577 .707 r
F P
0 g
s
.64105 .65665 m .64105 .67518 L .65365 .68306 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.83497 .66011 m .83497 .67863 L .84206 .67027 L p .707 .577 .707 r
F P
0 g
s
.84206 .67027 m .84205 .65174 L .83497 .66011 L p .707 .577 .707 r
F P
0 g
s
.63816 .55692 m .63816 .61251 L .64105 .62105 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62333 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.84205 .56056 m .84205 .61614 L .83916 .6076 L p .707 .577 .707 r
F P
0 g
s
.83916 .6076 m .83916 .55202 L .84205 .56056 L p .707 .577 .707 r
F P
0 g
s
.64105 .67518 m .64105 .65665 L .63816 .64811 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.63816 .64811 m .63816 .66663 L .64105 .67518 L p .707 .577 .707 r
F P
0 g
s
.63816 .61251 m .63816 .55692 L .64524 .54856 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.84205 .65174 m .84206 .67027 L .83916 .66173 L p .707 .577 .707 r
F P
0 g
s
.83916 .66173 m .83916 .6432 L .84205 .65174 L p .707 .577 .707 r
F P
0 g
s
.64524 .54856 m .64524 .60414 L .63816 .61251 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.83916 .55202 m .83916 .6076 L .82657 .59972 L p .707 .577 .707 r
F P
0 g
s
.82657 .59972 m .82657 .54413 L .83916 .55202 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .66663 m .63816 .64811 L .64524 .63974 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64348 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.39032 .60486 m .39032 .54928 L .35915 .54738 L p .707 .577 .707 r
F P
0 g
s
.39032 .54928 m .39032 .60486 L .42216 .60409 L p .707 .577 .707 r
F P
0 g
s
.42216 .60409 m .42216 .5485 L .39032 .54928 L p .707 .577 .707 r
F P
0 g
s
.64524 .60414 m .64524 .54856 L .66161 .54119 L p .707 .577 .707 r
F P
0 g
s
.42216 .5485 m .42216 .60409 L .45154 .60071 L p .707 .577 .707 r
F P
0 g
s
.45154 .60071 m .45154 .54513 L .42216 .5485 L p .707 .577 .707 r
F P
0 g
s
.64524 .63974 m .64524 .65827 L .63816 .66663 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.35915 .60296 m .35915 .54738 L .33169 .54299 L p .707 .577 .707 r
F P
0 g
s
.35915 .54738 m .35915 .60296 L .39032 .60486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54513 m .45154 .60071 L .47559 .59506 L p .707 .577 .707 r
F P
0 g
s
.47559 .59506 m .47559 .53948 L .45154 .54513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6432 m .83916 .66173 L .82657 .65384 L p .707 .577 .707 r
F P
0 g
s
.82657 .65384 m .82657 .63532 L .83916 .6432 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60637 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.66161 .54119 m .66161 .59677 L .64524 .60414 L p .707 .577 .707 r
F P
0 g
s
.82657 .54413 m .82657 .59972 L .80551 .59326 L p .707 .577 .707 r
F P
0 g
s
.80551 .59326 m .80551 .53768 L .82657 .54413 L p .707 .577 .707 r
F P
0 g
s
.64524 .64348 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60637 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .60299 L .42216 .60637 L p .707 .577 .707 r
F P
0 g
s
.33169 .54299 m .33169 .59857 L .35915 .60296 L p .707 .577 .707 r
F P
0 g
s
.33169 .59857 m .33169 .54299 L .31064 .53654 L p .707 .577 .707 r
F P
0 g
s
.35915 .6423 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .6423 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.39032 .65899 m .39032 .64046 L .35915 .63856 L p .707 .577 .707 r
F P
0 g
s
.39032 .64046 m .39032 .65899 L .42216 .65821 L p .707 .577 .707 r
F P
0 g
s
.42216 .65821 m .42216 .63969 L .39032 .64046 L p .707 .577 .707 r
F P
0 g
s
.64524 .65827 m .64524 .63974 L .66161 .63237 L p .707 .577 .707 r
F P
0 g
s
.42216 .63969 m .42216 .65821 L .45154 .65484 L p .707 .577 .707 r
F P
0 g
s
.45154 .65484 m .45154 .63631 L .42216 .63969 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59677 m .66161 .54119 L .68566 .53554 L p .707 .577 .707 r
F P
0 g
s
.35915 .63856 m .35915 .65709 L .39032 .65899 L p .707 .577 .707 r
F P
0 g
s
.45154 .60299 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59734 L .45154 .60299 L p .707 .577 .707 r
F P
0 g
s
.35915 .65709 m .35915 .63856 L .33169 .63417 L p .707 .577 .707 r
F P
0 g
s
.66161 .63237 m .66161 .6509 L .64524 .65827 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .6423 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.47559 .53948 m .47559 .59506 L .49196 .58769 L p .707 .577 .707 r
F P
0 g
s
.49196 .58769 m .49196 .53211 L .47559 .53948 L p .707 .577 .707 r
F P
0 g
s
.33169 .63417 m .33169 .6527 L .35915 .65709 L p .707 .577 .707 r
F P
0 g
s
.31064 .53654 m .31064 .59212 L .33169 .59857 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .5944 L p .707 .577 .707 r
F P
0 g
s
.45154 .63631 m .45154 .65484 L .47559 .64919 L p .707 .577 .707 r
F P
0 g
s
.47559 .64919 m .47559 .63066 L .45154 .63631 L p .707 .577 .707 r
F P
0 g
s
.80551 .53768 m .80551 .59326 L .77805 .58887 L p .707 .577 .707 r
F P
0 g
s
.77805 .58887 m .77805 .53329 L .80551 .53768 L p .707 .577 .707 r
F P
0 g
s
.82657 .63532 m .82657 .65384 L .80551 .64739 L p .707 .577 .707 r
F P
0 g
s
.80551 .64739 m .80551 .62886 L .82657 .63532 L p .707 .577 .707 r
F P
0 g
s
.68566 .53554 m .68566 .59112 L .66161 .59677 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.31064 .59212 m .31064 .53654 L .29804 .52865 L p .707 .577 .707 r
F P
0 g
s
.33169 .6527 m .33169 .63417 L .31064 .62772 L p .707 .577 .707 r
F P
0 g
s
.31064 .5944 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.68566 .59112 m .68566 .53554 L .71504 .53216 L p .707 .577 .707 r
F P
0 g
s
.47559 .59734 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59734 L p .707 .577 .707 r
F P
0 g
s
.31064 .62772 m .31064 .64624 L .33169 .6527 L p .707 .577 .707 r
F P
0 g
s
.66161 .6509 m .66161 .63237 L .68566 .62672 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.77805 .53329 m .77805 .58887 L .74688 .58697 L p .707 .577 .707 r
F P
0 g
s
.74688 .58697 m .74688 .53139 L .77805 .53329 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.68566 .62672 m .68566 .64525 L .66161 .6509 L p .707 .577 .707 r
F P
0 g
s
.47559 .63066 m .47559 .64919 L .49196 .64182 L p .707 .577 .707 r
F P
0 g
s
.49196 .64182 m .49196 .62329 L .47559 .63066 L p .707 .577 .707 r
F P
0 g
s
.29804 .52865 m .29804 .58423 L .31064 .59212 L p .707 .577 .707 r
F P
0 g
s
.71504 .58775 m .71504 .53216 L .74688 .53139 L p .707 .577 .707 r
F P
0 g
s
.71504 .53216 m .71504 .58775 L .68566 .59112 L p .707 .577 .707 r
F P
0 g
s
.49196 .53211 m .49196 .58769 L .49904 .57933 L p .707 .577 .707 r
F P
0 g
s
.49904 .57933 m .49904 .52374 L .49196 .53211 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .5944 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.74688 .53139 m .74688 .58697 L .71504 .58775 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.80551 .62886 m .80551 .64739 L .77805 .643 L p .707 .577 .707 r
F P
0 g
s
.77805 .643 m .77805 .62447 L .80551 .62886 L p .707 .577 .707 r
F P
0 g
s
.31064 .64624 m .31064 .62772 L .29804 .61983 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62357 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58925 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.29804 .58423 m .29804 .52865 L .29515 .52011 L p .707 .577 .707 r
F P
0 g
s
.68566 .64525 m .68566 .62672 L .71504 .62335 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.29804 .61983 m .29804 .63836 L .31064 .64624 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58925 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.71504 .62335 m .71504 .64187 L .68566 .64525 L p .707 .577 .707 r
F P
0 g
s
.74688 .58925 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.77805 .62447 m .77805 .643 L .74688 .6411 L p .707 .577 .707 r
F P
0 g
s
.74688 .6411 m .74688 .62257 L .77805 .62447 L p .707 .577 .707 r
F P
0 g
s
.71504 .64187 m .71504 .62335 L .74688 .62257 L p .707 .577 .707 r
F P
0 g
s
.49196 .62329 m .49196 .64182 L .49904 .63345 L p .707 .577 .707 r
F P
0 g
s
.49904 .63345 m .49904 .61493 L .49196 .62329 L p .707 .577 .707 r
F P
0 g
s
.29515 .52011 m .29515 .57569 L .29804 .58423 L p .707 .577 .707 r
F P
0 g
s
.74688 .62257 m .74688 .6411 L .71504 .64187 L p .707 .577 .707 r
F P
0 g
s
.29804 .62357 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.49904 .52374 m .49904 .57933 L .49615 .57078 L p .707 .577 .707 r
F P
0 g
s
.49615 .57078 m .49615 .5152 L .49904 .52374 L p .707 .577 .707 r
F P
0 g
s
.29804 .63836 m .29804 .61983 L .29515 .61129 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62357 L p .707 .577 .707 r
F P
0 g
s
.29515 .61129 m .29515 .62982 L .29804 .63836 L p .707 .577 .707 r
F P
0 g
s
.29515 .57569 m .29515 .52011 L .30223 .51174 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61012 L p .707 .577 .707 r
F P
0 g
s
.49615 .61012 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.49904 .61493 m .49904 .63345 L .49615 .62491 L p .707 .577 .707 r
F P
0 g
s
.49615 .62491 m .49615 .60638 L .49904 .61493 L p .707 .577 .707 r
F P
0 g
s
.30223 .51174 m .30223 .56733 L .29515 .57569 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.49615 .5152 m .49615 .57078 L .48356 .5629 L p .707 .577 .707 r
F P
0 g
s
.48356 .5629 m .48356 .50732 L .49615 .5152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .62982 m .29515 .61129 L .30223 .60293 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.30223 .56733 m .30223 .51174 L .3186 .50438 L p .707 .577 .707 r
F P
0 g
s
.30223 .60293 m .30223 .62145 L .29515 .62982 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61012 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .60638 m .49615 .62491 L .48356 .61703 L p .707 .577 .707 r
F P
0 g
s
.48356 .61703 m .48356 .5985 L .49615 .60638 L p .707 .577 .707 r
F P
0 g
s
.3186 .50438 m .3186 .55996 L .30223 .56733 L p .707 .577 .707 r
F P
0 g
s
.48356 .50732 m .48356 .5629 L .4625 .55645 L p .707 .577 .707 r
F P
0 g
s
.4625 .55645 m .4625 .50086 L .48356 .50732 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56224 L p .707 .577 .707 r
F P
0 g
s
.30223 .62145 m .30223 .60293 L .3186 .59556 L p .707 .577 .707 r
F P
0 g
s
.3186 .56224 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55996 m .3186 .50438 L .34265 .49873 L p .707 .577 .707 r
F P
0 g
s
.3186 .59556 m .3186 .61409 L .30223 .62145 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.4625 .50086 m .4625 .55645 L .43504 .55205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55205 m .43504 .49647 L .4625 .50086 L p .707 .577 .707 r
F P
0 g
s
.48356 .5985 m .48356 .61703 L .4625 .61057 L p .707 .577 .707 r
F P
0 g
s
.4625 .61057 m .4625 .59205 L .48356 .5985 L p .707 .577 .707 r
F P
0 g
s
.34265 .49873 m .34265 .55431 L .3186 .55996 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56224 L .34265 .55659 L p .707 .577 .707 r
F P
0 g
s
.34265 .55431 m .34265 .49873 L .37203 .49535 L p .707 .577 .707 r
F P
0 g
s
.3186 .61409 m .3186 .59556 L .34265 .58991 L p .707 .577 .707 r
F P
0 g
s
.34265 .55659 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.43504 .49647 m .43504 .55205 L .40387 .55015 L p .707 .577 .707 r
F P
0 g
s
.40387 .55015 m .40387 .49457 L .43504 .49647 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .59139 L p .707 .577 .707 r
F P
0 g
s
.43504 .59139 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .58991 m .34265 .60844 L .3186 .61409 L p .707 .577 .707 r
F P
0 g
s
.37203 .55093 m .37203 .49535 L .40387 .49457 L p .707 .577 .707 r
F P
0 g
s
.37203 .49535 m .37203 .55093 L .34265 .55431 L p .707 .577 .707 r
F P
0 g
s
.40387 .49457 m .40387 .55015 L .37203 .55093 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .55659 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.4625 .59205 m .4625 .61057 L .43504 .60618 L p .707 .577 .707 r
F P
0 g
s
.43504 .60618 m .43504 .58765 L .4625 .59205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .59139 L .40387 .58949 L p .707 .577 .707 r
F P
0 g
s
.40387 .58949 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.34265 .60844 m .34265 .58991 L .37203 .58653 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.37203 .58653 m .37203 .60506 L .34265 .60844 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .58949 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.43504 .58765 m .43504 .60618 L .40387 .60428 L p .707 .577 .707 r
F P
0 g
s
.40387 .60428 m .40387 .58575 L .43504 .58765 L p .707 .577 .707 r
F P
0 g
s
.37203 .60506 m .37203 .58653 L .40387 .58575 L p .707 .577 .707 r
F P
0 g
s
.40387 .58575 m .40387 .60428 L .37203 .60506 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP03
FUHO0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
Dgoo00<005YF000015YF00<005YF00002@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@000goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003moo`P000AJEP03001JEUYF009JEP@0
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000gOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=0004FUH01000FUIJEUYF0P00;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000020002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP00003
FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP000000;Goo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1P00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1P001eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJ
EP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEQH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP800004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP80009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04
001JEUYFFUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH70003FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEPD0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP80
0003FUH0000000AJEP@000AJEPD00003FUH0000000L000=JEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
05YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH300000eYF001JEP04FUH01000FUIJEUYF1@000eYF2P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JER4000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70004FUH90004FUH00`00FUIJEP03FUH400000eYF
001JEP04FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000600000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00003FUH700000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH<
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH2000]Ool002aoo`04001JEP00FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0;0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH?000;
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009J
EP8002eoo`00;7oo00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YF0000500035YF00<0
05YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP@002eoo`00;7oo10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00@000IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]
Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF0P000UYF00<005YF00000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH0
0eYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YF000000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP05001JEUYFFUH00003FUH20002FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH5
0004FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEPh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP03FUH0
0`00FUIJEP030002FUHG0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000AJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00@005YFFUIJEP<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP800004FUH000000005FUH00`00FUIJEP03FUH30008FUH40005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEPH0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP06
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol002aoo`03001JEP0000AJEP03001JEP000080009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
0004FUH005YFFUH20004FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00;7oo00<0
05YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEPH000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;7oo00@005YF001JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEPD000AJEP04001JEUYFFUH300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<0
05YFFUH00UYF7000?goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
00001UYF00<005YFFUH00eYF1P00E7oo000/Ool30004FUH01000FUIJEUYF2@001eYF00<005YFFUH0
1eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000IJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00;7oo0`000eYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP03001oogoo00<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo00=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF0`001eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`<004Uo
o`00;7oo0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH007oo00Moo`<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<00003FUH00000
00H00003FUH005YF00@00003FUH005YF00AJEP04001JEUYFFUH20007Ool50018Ool002aoo`80009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0000]oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04001JEUYFFUH20007
Ool50018Ool002aoo`8000=JEP03001JEP0000800003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP03001JEP00019oo``000IJEP03001J
EUYF00YJEP03001JEUYF00=JEPL000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
00=JEP8000Moo`D004Qoo`00;Goo00D005YFFUIJEP0000AJEP800003FUH0000000AJEP@000AJEPD0
00EJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2000OOolI0006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH20008Ool30019Ool002ioo`800003
FUH005YF00AJEP04001JEUYFFUH50003FUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:Goo
00@005YF001JEP800003FUH005YF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF1000
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`@000=JEP03001JEUYF009JEPL0
00AJEQD000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002aoo`03001JEP00
00AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJ
EP04001JEUYFFUH2001DOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<002moo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Aoo`00>Goo
10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000=JEP8005Aoo`00?Goo6@00>7oo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000E7oo002>Ool300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00E7oo002>Ool200000eYF0000
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0003FUH3001DOol008ioo`80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEP0000<00003FUH005YF00=JEP03001JEP0005Aoo`00Sgoo00D005YFFUH0
05YF00<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF009JEPD000EJEP03001J
EUYF009JEP8005Eoo`00Sgoo00@005YFFUH000AJEP80009JEP03001JEUYF009JEQL000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8005Eoo`00B7oo0`00AGoo0`001EYF00@005YFFUIJEPD000QJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol004Moo`D004Ioo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001HOol004Moo`D004Qoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol004Moo`D004]oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00B7oo0`00DGoo2@0015YF00<005YFFUH00UYF
2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002Z
Ool3001`Ool00:Uoo`D006moo`00ZGoo1@00Kgoo002YOol5001_Ool00:Yoo`<0071oo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73372 m .59613 .67814 L .56496 .67624 L p .707 .577 .707 r
F P
0 g
s
.59613 .67814 m .59613 .73372 L .62796 .73294 L p .707 .577 .707 r
F P
0 g
s
.62796 .73294 m .62796 .67736 L .59613 .67814 L p .707 .577 .707 r
F P
0 g
s
.62796 .67736 m .62796 .73294 L .65734 .72956 L p .707 .577 .707 r
F P
0 g
s
.65734 .72956 m .65734 .67398 L .62796 .67736 L p .707 .577 .707 r
F P
0 g
s
.56496 .73182 m .56496 .67624 L .5375 .67184 L p .707 .577 .707 r
F P
0 g
s
.56496 .67624 m .56496 .73182 L .59613 .73372 L p .707 .577 .707 r
F P
0 g
s
.65734 .67398 m .65734 .72956 L .6814 .72391 L p .707 .577 .707 r
F P
0 g
s
.6814 .72391 m .6814 .66833 L .65734 .67398 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .736 L .56496 .7341 L p .707 .577 .707 r
F P
0 g
s
.59613 .736 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .736 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.5375 .67184 m .5375 .72743 L .56496 .73182 L p .707 .577 .707 r
F P
0 g
s
.5375 .72743 m .5375 .67184 L .51644 .66539 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .7341 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .7341 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.59613 .78785 m .59613 .76932 L .56496 .76742 L p .707 .577 .707 r
F P
0 g
s
.59613 .76932 m .59613 .78785 L .62796 .78707 L p .707 .577 .707 r
F P
0 g
s
.62796 .78707 m .62796 .76854 L .59613 .76932 L p .707 .577 .707 r
F P
0 g
s
.62796 .76854 m .62796 .78707 L .65735 .78369 L p .707 .577 .707 r
F P
0 g
s
.65735 .78369 m .65735 .76516 L .62796 .76854 L p .707 .577 .707 r
F P
0 g
s
.56496 .76742 m .56496 .78594 L .59613 .78785 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76325 L p .707 .577 .707 r
F P
0 g
s
.6814 .76325 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.56496 .78594 m .56496 .76742 L .5375 .76302 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.6814 .66833 m .6814 .72391 L .69777 .71654 L p .707 .577 .707 r
F P
0 g
s
.69777 .71654 m .69777 .66096 L .6814 .66833 L p .707 .577 .707 r
F P
0 g
s
.5375 .76302 m .5375 .78155 L .56496 .78594 L p .707 .577 .707 r
F P
0 g
s
.51644 .66539 m .51644 .72097 L .5375 .72743 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.65735 .76516 m .65735 .78369 L .6814 .77804 L p .707 .577 .707 r
F P
0 g
s
.6814 .77804 m .6814 .75951 L .65735 .76516 L p .707 .577 .707 r
F P
0 g
s
.51644 .72097 m .51644 .66539 L .50385 .65751 L p .707 .577 .707 r
F P
0 g
s
.5375 .78155 m .5375 .76302 L .51644 .75657 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76325 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.51644 .75657 m .51644 .7751 L .5375 .78155 L p .707 .577 .707 r
F P
0 g
s
.6814 .75951 m .6814 .77804 L .69777 .77067 L p .707 .577 .707 r
F P
0 g
s
.69777 .77067 m .69777 .75214 L .6814 .75951 L p .707 .577 .707 r
F P
0 g
s
.50385 .65751 m .50385 .71309 L .51644 .72097 L p .707 .577 .707 r
F P
0 g
s
.69777 .66096 m .69777 .71654 L .70485 .70818 L p .707 .577 .707 r
F P
0 g
s
.70485 .70818 m .70485 .6526 L .69777 .66096 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71537 L p .707 .577 .707 r
F P
0 g
s
.51644 .7751 m .51644 .75657 L .50385 .74869 L p .707 .577 .707 r
F P
0 g
s
.50385 .71537 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.50385 .71309 m .50385 .65751 L .50095 .64896 L p .707 .577 .707 r
F P
0 g
s
.50385 .74869 m .50385 .76721 L .51644 .7751 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.49044 .73057 m .49044 .22868 L .44643 .226 L p .707 .577 .707 r
F P
0 g
s
.50095 .64896 m .50095 .70455 L .50385 .71309 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71537 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70455 m .50095 .64896 L .50804 .6406 L p .707 .577 .707 r
F P
0 g
s
.50804 .6406 m .50804 .69618 L .50095 .70455 L p .707 .577 .707 r
F P
0 g
s
.50385 .76721 m .50385 .74869 L .50095 .74014 L p .707 .577 .707 r
F P
0 g
s
.50095 .74014 m .50095 .75867 L .50385 .76721 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .69618 m .50804 .6406 L .5244 .63323 L p .707 .577 .707 r
F P
0 g
s
.5244 .63323 m .5244 .68881 L .50804 .69618 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.50804 .75031 m .50804 .73178 L .5244 .72441 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72815 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .68881 m .5244 .63323 L .54846 .62758 L p .707 .577 .707 r
F P
0 g
s
.5244 .72441 m .5244 .74294 L .50804 .75031 L p .707 .577 .707 r
F P
0 g
s
.54846 .62758 m .54846 .68316 L .5244 .68881 L p .707 .577 .707 r
F P
0 g
s
.5244 .72815 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.5244 .74294 m .5244 .72441 L .54846 .71876 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .7225 L .5244 .72815 L p .707 .577 .707 r
F P
0 g
s
.49044 .22868 m .49044 .73057 L .53538 .72947 L p .707 .577 .707 r
F P
0 g
s
.53538 .72947 m .53538 .22758 L .49044 .22868 L p .707 .577 .707 r
F P
0 g
s
.54846 .68316 m .54846 .62758 L .57784 .6242 L p .707 .577 .707 r
F P
0 g
s
.54846 .71876 m .54846 .73729 L .5244 .74294 L p .707 .577 .707 r
F P
0 g
s
.57784 .6242 m .57784 .67978 L .54846 .68316 L p .707 .577 .707 r
F P
0 g
s
.54846 .7225 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.54846 .73729 m .54846 .71876 L .57784 .71538 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .7225 L p .707 .577 .707 r
F P
0 g
s
.57784 .71538 m .57784 .73391 L .54846 .73729 L p .707 .577 .707 r
F P
0 g
s
.53538 .22758 m .53538 .72947 L .57686 .7247 L p .707 .577 .707 r
F P
0 g
s
.57686 .7247 m .57686 .22281 L .53538 .22758 L p .707 .577 .707 r
F P
0 g
s
.69777 .75214 m .69777 .77067 L .70485 .76231 L p .707 .577 .707 r
F P
0 g
s
.70485 .76231 m .70485 .74378 L .69777 .75214 L p .707 .577 .707 r
F P
0 g
s
.44643 .72789 m .44643 .226 L .40766 .2198 L p .707 .577 .707 r
F P
0 g
s
.44643 .226 m .44643 .72789 L .49044 .73057 L p .707 .577 .707 r
F P
0 g
s
.70485 .6526 m .70485 .70818 L .70195 .69964 L p .707 .577 .707 r
F P
0 g
s
.70195 .69964 m .70195 .64406 L .70485 .6526 L p .707 .577 .707 r
F P
0 g
s
.57784 .67978 m .57784 .6242 L .60968 .62343 L p .707 .577 .707 r
F P
0 g
s
.60968 .62343 m .60968 .67901 L .57784 .67978 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .68129 L .64085 .68319 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .68129 L p .707 .577 .707 r
F P
0 g
s
.60968 .68129 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.60968 .73313 m .60968 .71461 L .64085 .71651 L p .707 .577 .707 r
F P
0 g
s
.57784 .73391 m .57784 .71538 L .60968 .71461 L p .707 .577 .707 r
F P
0 g
s
.60968 .71461 m .60968 .73313 L .57784 .73391 L p .707 .577 .707 r
F P
0 g
s
.57686 .22281 m .57686 .7247 L .61082 .71673 L p .707 .577 .707 r
F P
0 g
s
.64085 .62533 m .64085 .68091 L .60968 .67901 L p .707 .577 .707 r
F P
0 g
s
.60968 .67901 m .60968 .62343 L .64085 .62533 L p .707 .577 .707 r
F P
0 g
s
.61082 .71673 m .61082 .21484 L .57686 .22281 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70192 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.40766 .72169 m .40766 .2198 L .37794 .21069 L p .707 .577 .707 r
F P
0 g
s
.40766 .2198 m .40766 .72169 L .44643 .72789 L p .707 .577 .707 r
F P
0 g
s
.70485 .74378 m .70485 .76231 L .70195 .75377 L p .707 .577 .707 r
F P
0 g
s
.70195 .75377 m .70195 .73524 L .70485 .74378 L p .707 .577 .707 r
F P
0 g
s
.70195 .64406 m .70195 .69964 L .68936 .69175 L p .707 .577 .707 r
F P
0 g
s
.68936 .69175 m .68936 .63617 L .70195 .64406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .75867 m .50095 .74014 L .50804 .73178 L p .707 .577 .707 r
F P
0 g
s
.64085 .68319 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.61082 .21484 m .61082 .71673 L .63393 .70632 L p .707 .577 .707 r
F P
0 g
s
.63393 .70632 m .63393 .20444 L .61082 .21484 L p .707 .577 .707 r
F P
0 g
s
.25312 .6969 m .25312 .64132 L .22195 .63942 L p .707 .577 .707 r
F P
0 g
s
.25312 .64132 m .25312 .6969 L .28495 .69613 L p .707 .577 .707 r
F P
0 g
s
.28495 .69613 m .28495 .64054 L .25312 .64132 L p .707 .577 .707 r
F P
0 g
s
.28495 .64054 m .28495 .69613 L .31434 .69275 L p .707 .577 .707 r
F P
0 g
s
.31434 .69275 m .31434 .63716 L .28495 .64054 L p .707 .577 .707 r
F P
0 g
s
.50804 .73178 m .50804 .75031 L .50095 .75867 L p .707 .577 .707 r
F P
0 g
s
.70195 .70192 m .70195 .73898 L .68936 .73109 L p .707 .577 .707 r
F P
0 g
s
.68936 .73109 m .68936 .69404 L .70195 .70192 L p .707 .577 .707 r
F P
0 g
s
.22195 .695 m .22195 .63942 L .19449 .63503 L p .707 .577 .707 r
F P
0 g
s
.22195 .63942 m .22195 .695 L .25312 .6969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.37794 .71257 m .37794 .21069 L .36016 .19956 L p .707 .577 .707 r
F P
0 g
s
.37794 .21069 m .37794 .71257 L .40766 .72169 L p .707 .577 .707 r
F P
0 g
s
.31434 .63716 m .31434 .69275 L .33839 .6871 L p .707 .577 .707 r
F P
0 g
s
.33839 .6871 m .33839 .63152 L .31434 .63716 L p .707 .577 .707 r
F P
0 g
s
.70195 .73524 m .70195 .75377 L .68936 .74588 L p .707 .577 .707 r
F P
0 g
s
.68936 .74588 m .68936 .72735 L .70195 .73524 L p .707 .577 .707 r
F P
0 g
s
.25312 .73624 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73624 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.68936 .63617 m .68936 .69175 L .66831 .6853 L p .707 .577 .707 r
F P
0 g
s
.66831 .6853 m .66831 .62972 L .68936 .63617 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69503 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.19449 .63503 m .19449 .69061 L .22195 .695 L p .707 .577 .707 r
F P
0 g
s
.19449 .69061 m .19449 .63503 L .17343 .62857 L p .707 .577 .707 r
F P
0 g
s
.22195 .73434 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73434 L .25312 .73624 L p .707 .577 .707 r
F P
0 g
s
.25312 .75103 m .25312 .7325 L .22195 .7306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7325 m .25312 .75103 L .28495 .75025 L p .707 .577 .707 r
F P
0 g
s
.28495 .75025 m .28495 .73173 L .25312 .7325 L p .707 .577 .707 r
F P
0 g
s
.28495 .73173 m .28495 .75025 L .31434 .74687 L p .707 .577 .707 r
F P
0 g
s
.31434 .74687 m .31434 .72835 L .28495 .73173 L p .707 .577 .707 r
F P
0 g
s
.22195 .7306 m .22195 .74913 L .25312 .75103 L p .707 .577 .707 r
F P
0 g
s
.31434 .69503 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68938 L .31434 .69503 L p .707 .577 .707 r
F P
0 g
s
.22195 .74913 m .22195 .7306 L .19449 .72621 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73434 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .73109 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.33839 .63152 m .33839 .6871 L .35476 .67973 L p .707 .577 .707 r
F P
0 g
s
.35476 .67973 m .35476 .62415 L .33839 .63152 L p .707 .577 .707 r
F P
0 g
s
.66831 .62972 m .66831 .6853 L .64085 .68091 L p .707 .577 .707 r
F P
0 g
s
.64085 .68091 m .64085 .62533 L .66831 .62972 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .68319 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.63393 .20444 m .63393 .70632 L .64393 .69452 L p .707 .577 .707 r
F P
0 g
s
.64393 .69452 m .64393 .19263 L .63393 .20444 L p .707 .577 .707 r
F P
0 g
s
.19449 .72621 m .19449 .74474 L .22195 .74913 L p .707 .577 .707 r
F P
0 g
s
.17343 .62857 m .17343 .68416 L .19449 .69061 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.31434 .72835 m .31434 .74687 L .33839 .74122 L p .707 .577 .707 r
F P
0 g
s
.33839 .74122 m .33839 .7227 L .31434 .72835 L p .707 .577 .707 r
F P
0 g
s
.68936 .72735 m .68936 .74588 L .66831 .73943 L p .707 .577 .707 r
F P
0 g
s
.66831 .73943 m .66831 .7209 L .68936 .72735 L p .707 .577 .707 r
F P
0 g
s
.17343 .68416 m .17343 .62857 L .16084 .62069 L p .707 .577 .707 r
F P
0 g
s
.19449 .74474 m .19449 .72621 L .17343 .71976 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68938 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68938 L p .707 .577 .707 r
F P
0 g
s
.35476 .62415 m .35476 .67973 L .36184 .67137 L p .707 .577 .707 r
F P
0 g
s
.36184 .67137 m .36184 .61578 L .35476 .62415 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .61578 m .36184 .67137 L .35894 .66282 L p .707 .577 .707 r
F P
0 g
s
.35894 .66282 m .35894 .60724 L .36184 .61578 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .72549 m .36184 .70696 L .35476 .71533 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70216 L p .707 .577 .707 r
F P
0 g
s
.35894 .70216 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .70144 m .36016 .19956 L .35607 .1875 L p .707 .577 .707 r
F P
0 g
s
.36016 .19956 m .36016 .70144 L .37794 .71257 L p .707 .577 .707 r
F P
0 g
s
.17343 .71976 m .17343 .73828 L .19449 .74474 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.33839 .7227 m .33839 .74122 L .35476 .73386 L p .707 .577 .707 r
F P
0 g
s
.35476 .73386 m .35476 .71533 L .33839 .7227 L p .707 .577 .707 r
F P
0 g
s
.16084 .62069 m .16084 .67627 L .17343 .68416 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.66831 .7209 m .66831 .73943 L .64085 .73503 L p .707 .577 .707 r
F P
0 g
s
.64085 .73503 m .64085 .71651 L .66831 .7209 L p .707 .577 .707 r
F P
0 g
s
.17343 .73828 m .17343 .71976 L .16084 .71187 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.16084 .67627 m .16084 .62069 L .15794 .61215 L p .707 .577 .707 r
F P
0 g
s
.16084 .71187 m .16084 .7304 L .17343 .73828 L p .707 .577 .707 r
F P
0 g
s
.64393 .19263 m .64393 .69452 L .63984 .68246 L p .707 .577 .707 r
F P
0 g
s
.63984 .68246 m .63984 .18057 L .64393 .19263 L p .707 .577 .707 r
F P
0 g
s
.64085 .71651 m .64085 .73503 L .60968 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .71533 m .35476 .73386 L .36184 .72549 L p .707 .577 .707 r
F P
0 g
s
.15794 .61215 m .15794 .66773 L .16084 .67627 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.35894 .60724 m .35894 .66282 L .34635 .65494 L p .707 .577 .707 r
F P
0 g
s
.34635 .65494 m .34635 .59936 L .35894 .60724 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70216 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65722 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .1875 m .35607 .68938 L .36016 .70144 L p .707 .577 .707 r
F P
0 g
s
.35607 .68938 m .35607 .1875 L .36607 .17569 L p .707 .577 .707 r
F P
0 g
s
.16084 .7304 m .16084 .71187 L .15794 .70333 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.15794 .70333 m .15794 .72186 L .16084 .7304 L p .707 .577 .707 r
F P
0 g
s
.15794 .66773 m .15794 .61215 L .16503 .60378 L p .707 .577 .707 r
F P
0 g
s
.36184 .70696 m .36184 .72549 L .35894 .71695 L p .707 .577 .707 r
F P
0 g
s
.35894 .71695 m .35894 .69842 L .36184 .70696 L p .707 .577 .707 r
F P
0 g
s
.16503 .60378 m .16503 .65937 L .15794 .66773 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.63984 .18057 m .63984 .68246 L .62206 .67133 L p .707 .577 .707 r
F P
0 g
s
.62206 .67133 m .62206 .16944 L .63984 .18057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .72186 m .15794 .70333 L .16503 .69497 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.16503 .65937 m .16503 .60378 L .1814 .59642 L p .707 .577 .707 r
F P
0 g
s
.16503 .69497 m .16503 .71349 L .15794 .72186 L p .707 .577 .707 r
F P
0 g
s
.36607 .67758 m .36607 .17569 L .38918 .16529 L p .707 .577 .707 r
F P
0 g
s
.36607 .17569 m .36607 .67758 L .35607 .68938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .69842 m .35894 .71695 L .34635 .70907 L p .707 .577 .707 r
F P
0 g
s
.34635 .70907 m .34635 .69054 L .35894 .69842 L p .707 .577 .707 r
F P
0 g
s
.1814 .59642 m .1814 .652 L .16503 .65937 L p .707 .577 .707 r
F P
0 g
s
.34635 .59936 m .34635 .65494 L .3253 .64848 L p .707 .577 .707 r
F P
0 g
s
.3253 .64848 m .3253 .5929 L .34635 .59936 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65428 L p .707 .577 .707 r
F P
0 g
s
.16503 .71349 m .16503 .69497 L .1814 .6876 L p .707 .577 .707 r
F P
0 g
s
.62206 .16944 m .62206 .67133 L .59233 .66221 L p .707 .577 .707 r
F P
0 g
s
.59233 .66221 m .59233 .16033 L .62206 .16944 L p .707 .577 .707 r
F P
0 g
s
.1814 .65428 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.1814 .652 m .1814 .59642 L .20545 .59077 L p .707 .577 .707 r
F P
0 g
s
.1814 .6876 m .1814 .70612 L .16503 .71349 L p .707 .577 .707 r
F P
0 g
s
.34635 .65722 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65722 L p .707 .577 .707 r
F P
0 g
s
.3253 .5929 m .3253 .64848 L .29784 .64409 L p .707 .577 .707 r
F P
0 g
s
.29784 .64409 m .29784 .58851 L .3253 .5929 L p .707 .577 .707 r
F P
0 g
s
.38918 .16529 m .38918 .66717 L .36607 .67758 L p .707 .577 .707 r
F P
0 g
s
.38918 .66717 m .38918 .16529 L .42314 .15731 L p .707 .577 .707 r
F P
0 g
s
.34635 .69054 m .34635 .70907 L .3253 .70261 L p .707 .577 .707 r
F P
0 g
s
.3253 .70261 m .3253 .68408 L .34635 .69054 L p .707 .577 .707 r
F P
0 g
s
.20545 .59077 m .20545 .64635 L .1814 .652 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65428 L .20545 .64863 L p .707 .577 .707 r
F P
0 g
s
.20545 .64635 m .20545 .59077 L .23483 .58739 L p .707 .577 .707 r
F P
0 g
s
.1814 .70612 m .1814 .6876 L .20545 .68195 L p .707 .577 .707 r
F P
0 g
s
.20545 .64863 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.29784 .58851 m .29784 .64409 L .26667 .64219 L p .707 .577 .707 r
F P
0 g
s
.26667 .64219 m .26667 .58661 L .29784 .58851 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68343 L p .707 .577 .707 r
F P
0 g
s
.29784 .68343 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68195 m .20545 .70048 L .1814 .70612 L p .707 .577 .707 r
F P
0 g
s
.23483 .64297 m .23483 .58739 L .26667 .58661 L p .707 .577 .707 r
F P
0 g
s
.23483 .58739 m .23483 .64297 L .20545 .64635 L p .707 .577 .707 r
F P
0 g
s
.59233 .16033 m .59233 .66221 L .55357 .65601 L p .707 .577 .707 r
F P
0 g
s
.55357 .65601 m .55357 .15412 L .59233 .16033 L p .707 .577 .707 r
F P
0 g
s
.26667 .58661 m .26667 .64219 L .23483 .64297 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64863 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.73333 .64168 m .73333 .5861 L .70216 .5842 L p .707 .577 .707 r
F P
0 g
s
.73333 .5861 m .73333 .64168 L .76517 .6409 L p .707 .577 .707 r
F P
0 g
s
.76517 .6409 m .76517 .58532 L .73333 .5861 L p .707 .577 .707 r
F P
0 g
s
.3253 .68408 m .3253 .70261 L .29784 .69822 L p .707 .577 .707 r
F P
0 g
s
.29784 .69822 m .29784 .67969 L .3253 .68408 L p .707 .577 .707 r
F P
0 g
s
.76517 .58532 m .76517 .6409 L .79455 .63752 L p .707 .577 .707 r
F P
0 g
s
.79455 .63752 m .79455 .58194 L .76517 .58532 L p .707 .577 .707 r
F P
0 g
s
.42314 .6592 m .42314 .15731 L .46462 .15254 L p .707 .577 .707 r
F P
0 g
s
.42314 .15731 m .42314 .6592 L .38918 .66717 L p .707 .577 .707 r
F P
0 g
s
.70216 .63978 m .70216 .5842 L .6747 .5798 L p .707 .577 .707 r
F P
0 g
s
.70216 .5842 m .70216 .63978 L .73333 .64168 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68343 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.20545 .70048 m .20545 .68195 L .23483 .67857 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.23483 .67857 m .23483 .6971 L .20545 .70048 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.79455 .58194 m .79455 .63752 L .8186 .63187 L p .707 .577 .707 r
F P
0 g
s
.8186 .63187 m .8186 .57629 L .79455 .58194 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68024 L p .707 .577 .707 r
F P
0 g
s
.76517 .68024 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.29784 .67969 m .29784 .69822 L .26667 .69632 L p .707 .577 .707 r
F P
0 g
s
.26667 .69632 m .26667 .67779 L .29784 .67969 L p .707 .577 .707 r
F P
0 g
s
.55357 .15412 m .55357 .65601 L .50956 .65333 L p .707 .577 .707 r
F P
0 g
s
.50956 .65333 m .50956 .15144 L .55357 .15412 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68024 L .79455 .67686 L p .707 .577 .707 r
F P
0 g
s
.79455 .67686 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.23483 .6971 m .23483 .67857 L .26667 .67779 L p .707 .577 .707 r
F P
0 g
s
.6747 .5798 m .6747 .63539 L .70216 .63978 L p .707 .577 .707 r
F P
0 g
s
.6747 .63539 m .6747 .5798 L .65365 .57335 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63767 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.46462 .65443 m .46462 .15254 L .50956 .15144 L p .707 .577 .707 r
F P
0 g
s
.46462 .15254 m .46462 .65443 L .42314 .6592 L p .707 .577 .707 r
F P
0 g
s
.26667 .67779 m .26667 .69632 L .23483 .6971 L p .707 .577 .707 r
F P
0 g
s
.73333 .69581 m .73333 .67728 L .70216 .67538 L p .707 .577 .707 r
F P
0 g
s
.73333 .67728 m .73333 .69581 L .76517 .69503 L p .707 .577 .707 r
F P
0 g
s
.76517 .69503 m .76517 .6765 L .73333 .67728 L p .707 .577 .707 r
F P
0 g
s
.50956 .15144 m .50956 .65333 L .46462 .65443 L p .707 .577 .707 r
F P
0 g
s
.76517 .6765 m .76517 .69503 L .79455 .69165 L p .707 .577 .707 r
F P
0 g
s
.79455 .69165 m .79455 .67312 L .76517 .6765 L p .707 .577 .707 r
F P
0 g
s
.70216 .67538 m .70216 .69391 L .73333 .69581 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67686 L .8186 .67121 L p .707 .577 .707 r
F P
0 g
s
.8186 .67121 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.70216 .69391 m .70216 .67538 L .6747 .67099 L p .707 .577 .707 r
F P
0 g
s
.6747 .63767 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.8186 .57629 m .8186 .63187 L .83497 .62451 L p .707 .577 .707 r
F P
0 g
s
.83497 .62451 m .83497 .56892 L .8186 .57629 L p .707 .577 .707 r
F P
0 g
s
.6747 .67099 m .6747 .68951 L .70216 .69391 L p .707 .577 .707 r
F P
0 g
s
.65365 .57335 m .65365 .62893 L .6747 .63539 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63767 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.79455 .67312 m .79455 .69165 L .8186 .686 L p .707 .577 .707 r
F P
0 g
s
.8186 .686 m .8186 .66747 L .79455 .67312 L p .707 .577 .707 r
F P
0 g
s
.65365 .62893 m .65365 .57335 L .64105 .56547 L p .707 .577 .707 r
F P
0 g
s
.6747 .68951 m .6747 .67099 L .65365 .66453 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66827 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67121 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.65365 .66453 m .65365 .68306 L .6747 .68951 L p .707 .577 .707 r
F P
0 g
s
.8186 .66747 m .8186 .686 L .83497 .67863 L p .707 .577 .707 r
F P
0 g
s
.83497 .67863 m .83497 .66011 L .8186 .66747 L p .707 .577 .707 r
F P
0 g
s
.64105 .56547 m .64105 .62105 L .65365 .62893 L p .707 .577 .707 r
F P
0 g
s
.83497 .56892 m .83497 .62451 L .84205 .61614 L p .707 .577 .707 r
F P
0 g
s
.84205 .61614 m .84205 .56056 L .83497 .56892 L p .707 .577 .707 r
F P
0 g
s
.65365 .66827 m .65365 .63122 L .64105 .62333 L p .707 .577 .707 r
F P
0 g
s
.65365 .68306 m .65365 .66453 L .64105 .65665 L p .707 .577 .707 r
F P
0 g
s
.64105 .62333 m .64105 .66039 L .65365 .66827 L p .707 .577 .707 r
F P
0 g
s
.64105 .62105 m .64105 .56547 L .63816 .55692 L p .707 .577 .707 r
F P
0 g
s
.64105 .65665 m .64105 .67518 L .65365 .68306 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.83497 .66011 m .83497 .67863 L .84206 .67027 L p .707 .577 .707 r
F P
0 g
s
.84206 .67027 m .84205 .65174 L .83497 .66011 L p .707 .577 .707 r
F P
0 g
s
.63816 .55692 m .63816 .61251 L .64105 .62105 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62333 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.84205 .56056 m .84205 .61614 L .83916 .6076 L p .707 .577 .707 r
F P
0 g
s
.83916 .6076 m .83916 .55202 L .84205 .56056 L p .707 .577 .707 r
F P
0 g
s
.64105 .67518 m .64105 .65665 L .63816 .64811 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.63816 .64811 m .63816 .66663 L .64105 .67518 L p .707 .577 .707 r
F P
0 g
s
.63816 .61251 m .63816 .55692 L .64524 .54856 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.84205 .65174 m .84206 .67027 L .83916 .66173 L p .707 .577 .707 r
F P
0 g
s
.83916 .66173 m .83916 .6432 L .84205 .65174 L p .707 .577 .707 r
F P
0 g
s
.64524 .54856 m .64524 .60414 L .63816 .61251 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.83916 .55202 m .83916 .6076 L .82657 .59972 L p .707 .577 .707 r
F P
0 g
s
.82657 .59972 m .82657 .54413 L .83916 .55202 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .66663 m .63816 .64811 L .64524 .63974 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64348 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.39032 .60486 m .39032 .54928 L .35915 .54738 L p .707 .577 .707 r
F P
0 g
s
.39032 .54928 m .39032 .60486 L .42216 .60409 L p .707 .577 .707 r
F P
0 g
s
.42216 .60409 m .42216 .5485 L .39032 .54928 L p .707 .577 .707 r
F P
0 g
s
.64524 .60414 m .64524 .54856 L .66161 .54119 L p .707 .577 .707 r
F P
0 g
s
.42216 .5485 m .42216 .60409 L .45154 .60071 L p .707 .577 .707 r
F P
0 g
s
.45154 .60071 m .45154 .54513 L .42216 .5485 L p .707 .577 .707 r
F P
0 g
s
.64524 .63974 m .64524 .65827 L .63816 .66663 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.35915 .60296 m .35915 .54738 L .33169 .54299 L p .707 .577 .707 r
F P
0 g
s
.35915 .54738 m .35915 .60296 L .39032 .60486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54513 m .45154 .60071 L .47559 .59506 L p .707 .577 .707 r
F P
0 g
s
.47559 .59506 m .47559 .53948 L .45154 .54513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6432 m .83916 .66173 L .82657 .65384 L p .707 .577 .707 r
F P
0 g
s
.82657 .65384 m .82657 .63532 L .83916 .6432 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60637 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.66161 .54119 m .66161 .59677 L .64524 .60414 L p .707 .577 .707 r
F P
0 g
s
.82657 .54413 m .82657 .59972 L .80551 .59326 L p .707 .577 .707 r
F P
0 g
s
.80551 .59326 m .80551 .53768 L .82657 .54413 L p .707 .577 .707 r
F P
0 g
s
.64524 .64348 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60637 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .60299 L .42216 .60637 L p .707 .577 .707 r
F P
0 g
s
.33169 .54299 m .33169 .59857 L .35915 .60296 L p .707 .577 .707 r
F P
0 g
s
.33169 .59857 m .33169 .54299 L .31064 .53654 L p .707 .577 .707 r
F P
0 g
s
.35915 .6423 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .6423 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.39032 .65899 m .39032 .64046 L .35915 .63856 L p .707 .577 .707 r
F P
0 g
s
.39032 .64046 m .39032 .65899 L .42216 .65821 L p .707 .577 .707 r
F P
0 g
s
.42216 .65821 m .42216 .63969 L .39032 .64046 L p .707 .577 .707 r
F P
0 g
s
.64524 .65827 m .64524 .63974 L .66161 .63237 L p .707 .577 .707 r
F P
0 g
s
.42216 .63969 m .42216 .65821 L .45154 .65484 L p .707 .577 .707 r
F P
0 g
s
.45154 .65484 m .45154 .63631 L .42216 .63969 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59677 m .66161 .54119 L .68566 .53554 L p .707 .577 .707 r
F P
0 g
s
.35915 .63856 m .35915 .65709 L .39032 .65899 L p .707 .577 .707 r
F P
0 g
s
.45154 .60299 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59734 L .45154 .60299 L p .707 .577 .707 r
F P
0 g
s
.35915 .65709 m .35915 .63856 L .33169 .63417 L p .707 .577 .707 r
F P
0 g
s
.66161 .63237 m .66161 .6509 L .64524 .65827 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .6423 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.47559 .53948 m .47559 .59506 L .49196 .58769 L p .707 .577 .707 r
F P
0 g
s
.49196 .58769 m .49196 .53211 L .47559 .53948 L p .707 .577 .707 r
F P
0 g
s
.33169 .63417 m .33169 .6527 L .35915 .65709 L p .707 .577 .707 r
F P
0 g
s
.31064 .53654 m .31064 .59212 L .33169 .59857 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .5944 L p .707 .577 .707 r
F P
0 g
s
.45154 .63631 m .45154 .65484 L .47559 .64919 L p .707 .577 .707 r
F P
0 g
s
.47559 .64919 m .47559 .63066 L .45154 .63631 L p .707 .577 .707 r
F P
0 g
s
.80551 .53768 m .80551 .59326 L .77805 .58887 L p .707 .577 .707 r
F P
0 g
s
.77805 .58887 m .77805 .53329 L .80551 .53768 L p .707 .577 .707 r
F P
0 g
s
.82657 .63532 m .82657 .65384 L .80551 .64739 L p .707 .577 .707 r
F P
0 g
s
.80551 .64739 m .80551 .62886 L .82657 .63532 L p .707 .577 .707 r
F P
0 g
s
.68566 .53554 m .68566 .59112 L .66161 .59677 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.31064 .59212 m .31064 .53654 L .29804 .52865 L p .707 .577 .707 r
F P
0 g
s
.33169 .6527 m .33169 .63417 L .31064 .62772 L p .707 .577 .707 r
F P
0 g
s
.31064 .5944 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.68566 .59112 m .68566 .53554 L .71504 .53216 L p .707 .577 .707 r
F P
0 g
s
.47559 .59734 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59734 L p .707 .577 .707 r
F P
0 g
s
.31064 .62772 m .31064 .64624 L .33169 .6527 L p .707 .577 .707 r
F P
0 g
s
.66161 .6509 m .66161 .63237 L .68566 .62672 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.77805 .53329 m .77805 .58887 L .74688 .58697 L p .707 .577 .707 r
F P
0 g
s
.74688 .58697 m .74688 .53139 L .77805 .53329 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.68566 .62672 m .68566 .64525 L .66161 .6509 L p .707 .577 .707 r
F P
0 g
s
.47559 .63066 m .47559 .64919 L .49196 .64182 L p .707 .577 .707 r
F P
0 g
s
.49196 .64182 m .49196 .62329 L .47559 .63066 L p .707 .577 .707 r
F P
0 g
s
.29804 .52865 m .29804 .58423 L .31064 .59212 L p .707 .577 .707 r
F P
0 g
s
.71504 .58775 m .71504 .53216 L .74688 .53139 L p .707 .577 .707 r
F P
0 g
s
.71504 .53216 m .71504 .58775 L .68566 .59112 L p .707 .577 .707 r
F P
0 g
s
.49196 .53211 m .49196 .58769 L .49904 .57933 L p .707 .577 .707 r
F P
0 g
s
.49904 .57933 m .49904 .52374 L .49196 .53211 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .5944 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.74688 .53139 m .74688 .58697 L .71504 .58775 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.80551 .62886 m .80551 .64739 L .77805 .643 L p .707 .577 .707 r
F P
0 g
s
.77805 .643 m .77805 .62447 L .80551 .62886 L p .707 .577 .707 r
F P
0 g
s
.31064 .64624 m .31064 .62772 L .29804 .61983 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62357 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58925 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.29804 .58423 m .29804 .52865 L .29515 .52011 L p .707 .577 .707 r
F P
0 g
s
.68566 .64525 m .68566 .62672 L .71504 .62335 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.29804 .61983 m .29804 .63836 L .31064 .64624 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58925 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.71504 .62335 m .71504 .64187 L .68566 .64525 L p .707 .577 .707 r
F P
0 g
s
.74688 .58925 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.77805 .62447 m .77805 .643 L .74688 .6411 L p .707 .577 .707 r
F P
0 g
s
.74688 .6411 m .74688 .62257 L .77805 .62447 L p .707 .577 .707 r
F P
0 g
s
.71504 .64187 m .71504 .62335 L .74688 .62257 L p .707 .577 .707 r
F P
0 g
s
.49196 .62329 m .49196 .64182 L .49904 .63345 L p .707 .577 .707 r
F P
0 g
s
.49904 .63345 m .49904 .61493 L .49196 .62329 L p .707 .577 .707 r
F P
0 g
s
.29515 .52011 m .29515 .57569 L .29804 .58423 L p .707 .577 .707 r
F P
0 g
s
.74688 .62257 m .74688 .6411 L .71504 .64187 L p .707 .577 .707 r
F P
0 g
s
.29804 .62357 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.49904 .52374 m .49904 .57933 L .49615 .57078 L p .707 .577 .707 r
F P
0 g
s
.49615 .57078 m .49615 .5152 L .49904 .52374 L p .707 .577 .707 r
F P
0 g
s
.29804 .63836 m .29804 .61983 L .29515 .61129 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62357 L p .707 .577 .707 r
F P
0 g
s
.29515 .61129 m .29515 .62982 L .29804 .63836 L p .707 .577 .707 r
F P
0 g
s
.29515 .57569 m .29515 .52011 L .30223 .51174 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61012 L p .707 .577 .707 r
F P
0 g
s
.49615 .61012 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.49904 .61493 m .49904 .63345 L .49615 .62491 L p .707 .577 .707 r
F P
0 g
s
.49615 .62491 m .49615 .60638 L .49904 .61493 L p .707 .577 .707 r
F P
0 g
s
.30223 .51174 m .30223 .56733 L .29515 .57569 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.49615 .5152 m .49615 .57078 L .48356 .5629 L p .707 .577 .707 r
F P
0 g
s
.48356 .5629 m .48356 .50732 L .49615 .5152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .62982 m .29515 .61129 L .30223 .60293 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.30223 .56733 m .30223 .51174 L .3186 .50438 L p .707 .577 .707 r
F P
0 g
s
.30223 .60293 m .30223 .62145 L .29515 .62982 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61012 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .60638 m .49615 .62491 L .48356 .61703 L p .707 .577 .707 r
F P
0 g
s
.48356 .61703 m .48356 .5985 L .49615 .60638 L p .707 .577 .707 r
F P
0 g
s
.3186 .50438 m .3186 .55996 L .30223 .56733 L p .707 .577 .707 r
F P
0 g
s
.48356 .50732 m .48356 .5629 L .4625 .55645 L p .707 .577 .707 r
F P
0 g
s
.4625 .55645 m .4625 .50086 L .48356 .50732 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56224 L p .707 .577 .707 r
F P
0 g
s
.30223 .62145 m .30223 .60293 L .3186 .59556 L p .707 .577 .707 r
F P
0 g
s
.3186 .56224 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55996 m .3186 .50438 L .34265 .49873 L p .707 .577 .707 r
F P
0 g
s
.3186 .59556 m .3186 .61409 L .30223 .62145 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.4625 .50086 m .4625 .55645 L .43504 .55205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55205 m .43504 .49647 L .4625 .50086 L p .707 .577 .707 r
F P
0 g
s
.48356 .5985 m .48356 .61703 L .4625 .61057 L p .707 .577 .707 r
F P
0 g
s
.4625 .61057 m .4625 .59205 L .48356 .5985 L p .707 .577 .707 r
F P
0 g
s
.34265 .49873 m .34265 .55431 L .3186 .55996 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56224 L .34265 .55659 L p .707 .577 .707 r
F P
0 g
s
.34265 .55431 m .34265 .49873 L .37203 .49535 L p .707 .577 .707 r
F P
0 g
s
.3186 .61409 m .3186 .59556 L .34265 .58991 L p .707 .577 .707 r
F P
0 g
s
.34265 .55659 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.43504 .49647 m .43504 .55205 L .40387 .55015 L p .707 .577 .707 r
F P
0 g
s
.40387 .55015 m .40387 .49457 L .43504 .49647 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .59139 L p .707 .577 .707 r
F P
0 g
s
.43504 .59139 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .58991 m .34265 .60844 L .3186 .61409 L p .707 .577 .707 r
F P
0 g
s
.37203 .55093 m .37203 .49535 L .40387 .49457 L p .707 .577 .707 r
F P
0 g
s
.37203 .49535 m .37203 .55093 L .34265 .55431 L p .707 .577 .707 r
F P
0 g
s
.40387 .49457 m .40387 .55015 L .37203 .55093 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .55659 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.4625 .59205 m .4625 .61057 L .43504 .60618 L p .707 .577 .707 r
F P
0 g
s
.43504 .60618 m .43504 .58765 L .4625 .59205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .59139 L .40387 .58949 L p .707 .577 .707 r
F P
0 g
s
.40387 .58949 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.34265 .60844 m .34265 .58991 L .37203 .58653 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.37203 .58653 m .37203 .60506 L .34265 .60844 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .58949 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.43504 .58765 m .43504 .60618 L .40387 .60428 L p .707 .577 .707 r
F P
0 g
s
.40387 .60428 m .40387 .58575 L .43504 .58765 L p .707 .577 .707 r
F P
0 g
s
.37203 .60506 m .37203 .58653 L .40387 .58575 L p .707 .577 .707 r
F P
0 g
s
.40387 .58575 m .40387 .60428 L .37203 .60506 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP03
FUHO0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
Dgoo00<005YF000015YF00<005YF00002@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@000goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003moo`P000AJEP03001JEUYF009JEP@0
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000gOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=0004FUH01000FUIJEUYF0P00;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000020002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP00003
FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP000000;Goo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1P00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1P001eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJ
EP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEQH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP800004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP80009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04
001JEUYFFUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH70003FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEPD0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP80
0003FUH0000000AJEP@000AJEPD00003FUH0000000L000=JEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
05YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH300000eYF001JEP04FUH01000FUIJEUYF1@000eYF2P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JER4000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70004FUH90004FUH00`00FUIJEP03FUH400000eYF
001JEP04FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000600000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00003FUH700000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH<
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH2000]Ool002aoo`04001JEP00FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0;0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH?000;
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009J
EP8002eoo`00;7oo00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YF0000500035YF00<0
05YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP@002eoo`00;7oo10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00@000IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]
Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF0P000UYF00<005YF00000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH0
0eYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YF000000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP05001JEUYFFUH00003FUH20002FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH5
0004FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEPh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP03FUH0
0`00FUIJEP030002FUHG0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000AJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00@005YFFUIJEP<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP800004FUH000000005FUH00`00FUIJEP03FUH30008FUH40005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEPH0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP06
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol002aoo`03001JEP0000AJEP03001JEP000080009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
0004FUH005YFFUH20004FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00;7oo00<0
05YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEPH000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;7oo00@005YF001JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEPD000AJEP04001JEUYFFUH300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<0
05YFFUH00UYF7000?goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
00001UYF00<005YFFUH00eYF1P00E7oo000/Ool30004FUH01000FUIJEUYF2@001eYF00<005YFFUH0
1eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000IJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00;7oo0`000eYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP03001oogoo00<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo00=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF0`001eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`<004Uo
o`00;7oo0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH007oo00Moo`<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<00003FUH00000
00H00003FUH005YF00@00003FUH005YF00AJEP04001JEUYFFUH20007Ool50018Ool002aoo`80009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0000]oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04001JEUYFFUH20007
Ool50018Ool002aoo`8000=JEP03001JEP0000800003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP03001JEP00019oo``000IJEP03001J
EUYF00YJEP03001JEUYF00=JEPL000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
00=JEP8000Moo`D004Qoo`00;Goo00D005YFFUIJEP0000AJEP800003FUH0000000AJEP@000AJEPD0
00EJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2000OOolI0006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH20008Ool30019Ool002ioo`800003
FUH005YF00AJEP04001JEUYFFUH50003FUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:Goo
00@005YF001JEP800003FUH005YF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF1000
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`@000=JEP03001JEUYF009JEPL0
00AJEQD000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002aoo`03001JEP00
00AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJ
EP04001JEUYFFUH2001DOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<002moo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Aoo`00>Goo
10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000=JEP8005Aoo`00?Goo6@00>7oo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000E7oo002>Ool300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00E7oo002>Ool200000eYF0000
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0003FUH3001DOol008ioo`80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEP0000<00003FUH005YF00=JEP03001JEP0005Aoo`00Sgoo00D005YFFUH0
05YF00<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF009JEPD000EJEP03001J
EUYF009JEP8005Eoo`00Sgoo00@005YFFUH000AJEP80009JEP03001JEUYF009JEQL000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8005Eoo`00B7oo0`00AGoo0`001EYF00@005YFFUIJEPD000QJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol004Moo`D004Ioo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001HOol004Moo`D004Qoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol004Moo`D004]oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00B7oo0`00DGoo2@0015YF00<005YFFUH00UYF
2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002Z
Ool3001`Ool00:Uoo`D006moo`00ZGoo1@00Kgoo002YOol5001_Ool00:Yoo`<0071oo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73974 m .59613 .68416 L .56496 .68226 L p .707 .577 .707 r
F P
0 g
s
.59613 .68416 m .59613 .73974 L .62796 .73897 L p .707 .577 .707 r
F P
0 g
s
.62796 .73897 m .62796 .68339 L .59613 .68416 L p .707 .577 .707 r
F P
0 g
s
.62796 .68339 m .62796 .73897 L .65734 .73559 L p .707 .577 .707 r
F P
0 g
s
.65734 .73559 m .65734 .68001 L .62796 .68339 L p .707 .577 .707 r
F P
0 g
s
.56496 .73784 m .56496 .68226 L .5375 .67787 L p .707 .577 .707 r
F P
0 g
s
.56496 .68226 m .56496 .73784 L .59613 .73974 L p .707 .577 .707 r
F P
0 g
s
.65734 .68001 m .65734 .73559 L .6814 .72994 L p .707 .577 .707 r
F P
0 g
s
.6814 .72994 m .6814 .67436 L .65734 .68001 L p .707 .577 .707 r
F P
0 g
s
.59613 .78711 m .59613 .75006 L .56496 .74816 L p .707 .577 .707 r
F P
0 g
s
.59613 .75006 m .59613 .78711 L .62796 .78634 L p .707 .577 .707 r
F P
0 g
s
.62796 .78634 m .62796 .74928 L .59613 .75006 L p .707 .577 .707 r
F P
0 g
s
.62796 .74928 m .62796 .78634 L .65735 .78296 L p .707 .577 .707 r
F P
0 g
s
.65735 .78296 m .65735 .7459 L .62796 .74928 L p .707 .577 .707 r
F P
0 g
s
.5375 .67787 m .5375 .73345 L .56496 .73784 L p .707 .577 .707 r
F P
0 g
s
.5375 .73345 m .5375 .67787 L .51644 .67142 L p .707 .577 .707 r
F P
0 g
s
.56496 .78521 m .56496 .74816 L .5375 .74377 L p .707 .577 .707 r
F P
0 g
s
.56496 .74816 m .56496 .78521 L .59613 .78711 L p .707 .577 .707 r
F P
0 g
s
.59613 .81223 m .59613 .79371 L .56496 .7918 L p .707 .577 .707 r
F P
0 g
s
.59613 .79371 m .59613 .81223 L .62796 .81146 L p .707 .577 .707 r
F P
0 g
s
.62796 .81146 m .62796 .79293 L .59613 .79371 L p .707 .577 .707 r
F P
0 g
s
.65735 .7459 m .65735 .78296 L .6814 .77731 L p .707 .577 .707 r
F P
0 g
s
.6814 .77731 m .6814 .74025 L .65735 .7459 L p .707 .577 .707 r
F P
0 g
s
.62796 .79293 m .62796 .81146 L .65735 .80808 L p .707 .577 .707 r
F P
0 g
s
.65735 .80808 m .65735 .78955 L .62796 .79293 L p .707 .577 .707 r
F P
0 g
s
.6814 .67436 m .6814 .72994 L .69777 .72257 L p .707 .577 .707 r
F P
0 g
s
.69777 .72257 m .69777 .66699 L .6814 .67436 L p .707 .577 .707 r
F P
0 g
s
.5375 .74377 m .5375 .78082 L .56496 .78521 L p .707 .577 .707 r
F P
0 g
s
.56496 .7918 m .56496 .81033 L .59613 .81223 L p .707 .577 .707 r
F P
0 g
s
.56496 .81033 m .56496 .7918 L .5375 .78741 L p .707 .577 .707 r
F P
0 g
s
.51644 .67142 m .51644 .727 L .5375 .73345 L p .707 .577 .707 r
F P
0 g
s
.5375 .78082 m .5375 .74377 L .51644 .73731 L p .707 .577 .707 r
F P
0 g
s
.5375 .78741 m .5375 .80594 L .56496 .81033 L p .707 .577 .707 r
F P
0 g
s
.65735 .78955 m .65735 .80808 L .6814 .80243 L p .707 .577 .707 r
F P
0 g
s
.6814 .80243 m .6814 .7839 L .65735 .78955 L p .707 .577 .707 r
F P
0 g
s
.51644 .727 m .51644 .67142 L .50385 .66353 L p .707 .577 .707 r
F P
0 g
s
.51644 .73731 m .51644 .77437 L .5375 .78082 L p .707 .577 .707 r
F P
0 g
s
.5375 .80594 m .5375 .78741 L .51644 .78096 L p .707 .577 .707 r
F P
0 g
s
.6814 .74025 m .6814 .77731 L .69777 .76994 L p .707 .577 .707 r
F P
0 g
s
.69777 .76994 m .69777 .73289 L .6814 .74025 L p .707 .577 .707 r
F P
0 g
s
.51644 .78096 m .51644 .79949 L .5375 .80594 L p .707 .577 .707 r
F P
0 g
s
.50385 .66353 m .50385 .71911 L .51644 .727 L p .707 .577 .707 r
F P
0 g
s
.69777 .66699 m .69777 .72257 L .70485 .71421 L p .707 .577 .707 r
F P
0 g
s
.70485 .71421 m .70485 .65862 L .69777 .66699 L p .707 .577 .707 r
F P
0 g
s
.51644 .77437 m .51644 .73731 L .50385 .72943 L p .707 .577 .707 r
F P
0 g
s
.6814 .7839 m .6814 .80243 L .69777 .79506 L p .707 .577 .707 r
F P
0 g
s
.69777 .79506 m .69777 .77653 L .6814 .7839 L p .707 .577 .707 r
F P
0 g
s
.50385 .71911 m .50385 .66353 L .50095 .65499 L p .707 .577 .707 r
F P
0 g
s
.50385 .72943 m .50385 .76648 L .51644 .77437 L p .707 .577 .707 r
F P
0 g
s
.51644 .79949 m .51644 .78096 L .50385 .77307 L p .707 .577 .707 r
F P
0 g
s
.69777 .73289 m .69777 .76994 L .70485 .76158 L p .707 .577 .707 r
F P
0 g
s
.70485 .76158 m .70485 .72452 L .69777 .73289 L p .707 .577 .707 r
F P
0 g
s
.50385 .77307 m .50385 .7916 L .51644 .79949 L p .707 .577 .707 r
F P
0 g
s
.49044 .76543 m .49044 .26354 L .44643 .26086 L p .707 .577 .707 r
F P
0 g
s
.50095 .65499 m .50095 .71057 L .50385 .71911 L p .707 .577 .707 r
F P
0 g
s
.50385 .76648 m .50385 .72943 L .50095 .72089 L p .707 .577 .707 r
F P
0 g
s
.50095 .72089 m .50095 .75794 L .50385 .76648 L p .707 .577 .707 r
F P
0 g
s
.50385 .7916 m .50385 .77307 L .50095 .76453 L p .707 .577 .707 r
F P
0 g
s
.50095 .71057 m .50095 .65499 L .50804 .64663 L p .707 .577 .707 r
F P
0 g
s
.50095 .76453 m .50095 .78306 L .50385 .7916 L p .707 .577 .707 r
F P
0 g
s
.50804 .64663 m .50804 .70221 L .50095 .71057 L p .707 .577 .707 r
F P
0 g
s
.50095 .75794 m .50095 .72089 L .50804 .71252 L p .707 .577 .707 r
F P
0 g
s
.50804 .71252 m .50804 .74958 L .50095 .75794 L p .707 .577 .707 r
F P
0 g
s
.50804 .70221 m .50804 .64663 L .5244 .63926 L p .707 .577 .707 r
F P
0 g
s
.50095 .78306 m .50095 .76453 L .50804 .75617 L p .707 .577 .707 r
F P
0 g
s
.50804 .75617 m .50804 .7747 L .50095 .78306 L p .707 .577 .707 r
F P
0 g
s
.5244 .63926 m .5244 .69484 L .50804 .70221 L p .707 .577 .707 r
F P
0 g
s
.50804 .74958 m .50804 .71252 L .5244 .70516 L p .707 .577 .707 r
F P
0 g
s
.5244 .69484 m .5244 .63926 L .54846 .63361 L p .707 .577 .707 r
F P
0 g
s
.5244 .70516 m .5244 .74221 L .50804 .74958 L p .707 .577 .707 r
F P
0 g
s
.50804 .7747 m .50804 .75617 L .5244 .7488 L p .707 .577 .707 r
F P
0 g
s
.5244 .7488 m .5244 .76733 L .50804 .7747 L p .707 .577 .707 r
F P
0 g
s
.54846 .63361 m .54846 .68919 L .5244 .69484 L p .707 .577 .707 r
F P
0 g
s
.5244 .74221 m .5244 .70516 L .54846 .69951 L p .707 .577 .707 r
F P
0 g
s
.54846 .69951 m .54846 .73656 L .5244 .74221 L p .707 .577 .707 r
F P
0 g
s
.5244 .76733 m .5244 .7488 L .54846 .74315 L p .707 .577 .707 r
F P
0 g
s
.54846 .74315 m .54846 .76168 L .5244 .76733 L p .707 .577 .707 r
F P
0 g
s
.49044 .26354 m .49044 .76543 L .53538 .76433 L p .707 .577 .707 r
F P
0 g
s
.53538 .76433 m .53538 .26245 L .49044 .26354 L p .707 .577 .707 r
F P
0 g
s
.70485 .65862 m .70485 .71421 L .70195 .70566 L p .707 .577 .707 r
F P
0 g
s
.70195 .70566 m .70195 .65008 L .70485 .65862 L p .707 .577 .707 r
F P
0 g
s
.69777 .77653 m .69777 .79506 L .70485 .78669 L p .707 .577 .707 r
F P
0 g
s
.70485 .78669 m .70485 .76817 L .69777 .77653 L p .707 .577 .707 r
F P
0 g
s
.54846 .68919 m .54846 .63361 L .57784 .63023 L p .707 .577 .707 r
F P
0 g
s
.57784 .63023 m .57784 .68581 L .54846 .68919 L p .707 .577 .707 r
F P
0 g
s
.54846 .73656 m .54846 .69951 L .57784 .69613 L p .707 .577 .707 r
F P
0 g
s
.57784 .69613 m .57784 .73318 L .54846 .73656 L p .707 .577 .707 r
F P
0 g
s
.54846 .76168 m .54846 .74315 L .57784 .73977 L p .707 .577 .707 r
F P
0 g
s
.57784 .73977 m .57784 .7583 L .54846 .76168 L p .707 .577 .707 r
F P
0 g
s
.53538 .26245 m .53538 .76433 L .57686 .75956 L p .707 .577 .707 r
F P
0 g
s
.57686 .75956 m .57686 .25768 L .53538 .26245 L p .707 .577 .707 r
F P
0 g
s
.44643 .76275 m .44643 .26086 L .40766 .25466 L p .707 .577 .707 r
F P
0 g
s
.44643 .26086 m .44643 .76275 L .49044 .76543 L p .707 .577 .707 r
F P
0 g
s
.57784 .68581 m .57784 .63023 L .60968 .62945 L p .707 .577 .707 r
F P
0 g
s
.60968 .62945 m .60968 .68503 L .57784 .68581 L p .707 .577 .707 r
F P
0 g
s
.57784 .73318 m .57784 .69613 L .60968 .69535 L p .707 .577 .707 r
F P
0 g
s
.60968 .69535 m .60968 .7324 L .57784 .73318 L p .707 .577 .707 r
F P
0 g
s
.60968 .75752 m .60968 .73899 L .64085 .7409 L p .707 .577 .707 r
F P
0 g
s
.57784 .7583 m .57784 .73977 L .60968 .73899 L p .707 .577 .707 r
F P
0 g
s
.60968 .73899 m .60968 .75752 L .57784 .7583 L p .707 .577 .707 r
F P
0 g
s
.57686 .25768 m .57686 .75956 L .61082 .75159 L p .707 .577 .707 r
F P
0 g
s
.64085 .63135 m .64085 .68693 L .60968 .68503 L p .707 .577 .707 r
F P
0 g
s
.60968 .68503 m .60968 .62945 L .64085 .63135 L p .707 .577 .707 r
F P
0 g
s
.64085 .69725 m .64085 .7343 L .60968 .7324 L p .707 .577 .707 r
F P
0 g
s
.60968 .7324 m .60968 .69535 L .64085 .69725 L p .707 .577 .707 r
F P
0 g
s
.61082 .75159 m .61082 .2497 L .57686 .25768 L p .707 .577 .707 r
F P
0 g
s
.70485 .72452 m .70485 .76158 L .70195 .75303 L p .707 .577 .707 r
F P
0 g
s
.70195 .75303 m .70195 .71598 L .70485 .72452 L p .707 .577 .707 r
F P
0 g
s
.40766 .75655 m .40766 .25466 L .37794 .24555 L p .707 .577 .707 r
F P
0 g
s
.40766 .25466 m .40766 .75655 L .44643 .76275 L p .707 .577 .707 r
F P
0 g
s
.70485 .76817 m .70485 .78669 L .70195 .77815 L p .707 .577 .707 r
F P
0 g
s
.70195 .77815 m .70195 .75963 L .70485 .76817 L p .707 .577 .707 r
F P
0 g
s
.70195 .65008 m .70195 .70566 L .68936 .69778 L p .707 .577 .707 r
F P
0 g
s
.68936 .69778 m .68936 .6422 L .70195 .65008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.25312 .70293 m .25312 .64735 L .22195 .64545 L p .707 .577 .707 r
F P
0 g
s
.25312 .64735 m .25312 .70293 L .28495 .70215 L p .707 .577 .707 r
F P
0 g
s
.28495 .70215 m .28495 .64657 L .25312 .64735 L p .707 .577 .707 r
F P
0 g
s
.28495 .64657 m .28495 .70215 L .31434 .69877 L p .707 .577 .707 r
F P
0 g
s
.31434 .69877 m .31434 .64319 L .28495 .64657 L p .707 .577 .707 r
F P
0 g
s
.61082 .2497 m .61082 .75159 L .63393 .74119 L p .707 .577 .707 r
F P
0 g
s
.63393 .74119 m .63393 .2393 L .61082 .2497 L p .707 .577 .707 r
F P
0 g
s
.22195 .70103 m .22195 .64545 L .19449 .64105 L p .707 .577 .707 r
F P
0 g
s
.22195 .64545 m .22195 .70103 L .25312 .70293 L p .707 .577 .707 r
F P
0 g
s
.70195 .71598 m .70195 .75303 L .68936 .74515 L p .707 .577 .707 r
F P
0 g
s
.68936 .74515 m .68936 .7081 L .70195 .71598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31434 .64319 m .31434 .69877 L .33839 .69312 L p .707 .577 .707 r
F P
0 g
s
.33839 .69312 m .33839 .63754 L .31434 .64319 L p .707 .577 .707 r
F P
0 g
s
.25312 .7503 m .25312 .71324 L .22195 .71134 L p .707 .577 .707 r
F P
0 g
s
.25312 .71324 m .25312 .7503 L .28495 .74952 L p .707 .577 .707 r
F P
0 g
s
.28495 .74952 m .28495 .71247 L .25312 .71324 L p .707 .577 .707 r
F P
0 g
s
.68936 .6422 m .68936 .69778 L .66831 .69133 L p .707 .577 .707 r
F P
0 g
s
.66831 .69133 m .66831 .63574 L .68936 .6422 L p .707 .577 .707 r
F P
0 g
s
.70195 .75963 m .70195 .77815 L .68936 .77027 L p .707 .577 .707 r
F P
0 g
s
.68936 .77027 m .68936 .75174 L .70195 .75963 L p .707 .577 .707 r
F P
0 g
s
.37794 .74744 m .37794 .24555 L .36016 .23442 L p .707 .577 .707 r
F P
0 g
s
.37794 .24555 m .37794 .74744 L .40766 .75655 L p .707 .577 .707 r
F P
0 g
s
.28495 .71247 m .28495 .74952 L .31434 .74614 L p .707 .577 .707 r
F P
0 g
s
.31434 .74614 m .31434 .70909 L .28495 .71247 L p .707 .577 .707 r
F P
0 g
s
.19449 .64105 m .19449 .69664 L .22195 .70103 L p .707 .577 .707 r
F P
0 g
s
.19449 .69664 m .19449 .64105 L .17343 .6346 L p .707 .577 .707 r
F P
0 g
s
.22195 .7484 m .22195 .71134 L .19449 .70695 L p .707 .577 .707 r
F P
0 g
s
.22195 .71134 m .22195 .7484 L .25312 .7503 L p .707 .577 .707 r
F P
0 g
s
.25312 .77542 m .25312 .75689 L .22195 .75499 L p .707 .577 .707 r
F P
0 g
s
.25312 .75689 m .25312 .77542 L .28495 .77464 L p .707 .577 .707 r
F P
0 g
s
.28495 .77464 m .28495 .75611 L .25312 .75689 L p .707 .577 .707 r
F P
0 g
s
.31434 .70909 m .31434 .74614 L .33839 .74049 L p .707 .577 .707 r
F P
0 g
s
.33839 .74049 m .33839 .70344 L .31434 .70909 L p .707 .577 .707 r
F P
0 g
s
.28495 .75611 m .28495 .77464 L .31434 .77126 L p .707 .577 .707 r
F P
0 g
s
.31434 .77126 m .31434 .75273 L .28495 .75611 L p .707 .577 .707 r
F P
0 g
s
.33839 .63754 m .33839 .69312 L .35476 .68576 L p .707 .577 .707 r
F P
0 g
s
.35476 .68576 m .35476 .63017 L .33839 .63754 L p .707 .577 .707 r
F P
0 g
s
.19449 .70695 m .19449 .74401 L .22195 .7484 L p .707 .577 .707 r
F P
0 g
s
.22195 .75499 m .22195 .77352 L .25312 .77542 L p .707 .577 .707 r
F P
0 g
s
.68936 .7081 m .68936 .74515 L .66831 .7387 L p .707 .577 .707 r
F P
0 g
s
.66831 .7387 m .66831 .70164 L .68936 .7081 L p .707 .577 .707 r
F P
0 g
s
.22195 .77352 m .22195 .75499 L .19449 .7506 L p .707 .577 .707 r
F P
0 g
s
.17343 .6346 m .17343 .69018 L .19449 .69664 L p .707 .577 .707 r
F P
0 g
s
.19449 .74401 m .19449 .70695 L .17343 .7005 L p .707 .577 .707 r
F P
0 g
s
.66831 .63574 m .66831 .69133 L .64085 .68693 L p .707 .577 .707 r
F P
0 g
s
.64085 .68693 m .64085 .63135 L .66831 .63574 L p .707 .577 .707 r
F P
0 g
s
.19449 .7506 m .19449 .76912 L .22195 .77352 L p .707 .577 .707 r
F P
0 g
s
.64085 .7343 m .64085 .69725 L .66831 .70164 L p .707 .577 .707 r
F P
0 g
s
.63393 .2393 m .63393 .74119 L .64393 .72938 L p .707 .577 .707 r
F P
0 g
s
.64393 .72938 m .64393 .22749 L .63393 .2393 L p .707 .577 .707 r
F P
0 g
s
.31434 .75273 m .31434 .77126 L .33839 .76561 L p .707 .577 .707 r
F P
0 g
s
.33839 .76561 m .33839 .74708 L .31434 .75273 L p .707 .577 .707 r
F P
0 g
s
.17343 .69018 m .17343 .6346 L .16084 .62672 L p .707 .577 .707 r
F P
0 g
s
.68936 .75174 m .68936 .77027 L .66831 .76381 L p .707 .577 .707 r
F P
0 g
s
.66831 .76381 m .66831 .74529 L .68936 .75174 L p .707 .577 .707 r
F P
0 g
s
.17343 .7005 m .17343 .73755 L .19449 .74401 L p .707 .577 .707 r
F P
0 g
s
.19449 .76912 m .19449 .7506 L .17343 .74414 L p .707 .577 .707 r
F P
0 g
s
.33839 .70344 m .33839 .74049 L .35476 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .73313 m .35476 .69607 L .33839 .70344 L p .707 .577 .707 r
F P
0 g
s
.17343 .74414 m .17343 .76267 L .19449 .76912 L p .707 .577 .707 r
F P
0 g
s
.66831 .70164 m .66831 .7387 L .64085 .7343 L p .707 .577 .707 r
F P
0 g
s
.35476 .63017 m .35476 .68576 L .36184 .67739 L p .707 .577 .707 r
F P
0 g
s
.36184 .67739 m .36184 .62181 L .35476 .63017 L p .707 .577 .707 r
F P
0 g
s
.35476 .69607 m .35476 .73313 L .36184 .72476 L p .707 .577 .707 r
F P
0 g
s
.36184 .72476 m .36184 .68771 L .35476 .69607 L p .707 .577 .707 r
F P
0 g
s
.36184 .62181 m .36184 .67739 L .35894 .66885 L p .707 .577 .707 r
F P
0 g
s
.35894 .66885 m .35894 .61327 L .36184 .62181 L p .707 .577 .707 r
F P
0 g
s
.36184 .74988 m .36184 .73135 L .35476 .73972 L p .707 .577 .707 r
F P
0 g
s
.36184 .68771 m .36184 .72476 L .35894 .71622 L p .707 .577 .707 r
F P
0 g
s
.35894 .71622 m .35894 .67916 L .36184 .68771 L p .707 .577 .707 r
F P
0 g
s
.35894 .74134 m .35894 .72281 L .36184 .73135 L p .707 .577 .707 r
F P
0 g
s
.36016 .73631 m .36016 .23442 L .35607 .22236 L p .707 .577 .707 r
F P
0 g
s
.36184 .73135 m .36184 .74988 L .35894 .74134 L p .707 .577 .707 r
F P
0 g
s
.36016 .23442 m .36016 .73631 L .37794 .74744 L p .707 .577 .707 r
F P
0 g
s
.16084 .62672 m .16084 .6823 L .17343 .69018 L p .707 .577 .707 r
F P
0 g
s
.17343 .73755 m .17343 .7005 L .16084 .69261 L p .707 .577 .707 r
F P
0 g
s
.33839 .74708 m .33839 .76561 L .35476 .75824 L p .707 .577 .707 r
F P
0 g
s
.35476 .75824 m .35476 .73972 L .33839 .74708 L p .707 .577 .707 r
F P
0 g
s
.66831 .74529 m .66831 .76381 L .64085 .75942 L p .707 .577 .707 r
F P
0 g
s
.64085 .75942 m .64085 .7409 L .66831 .74529 L p .707 .577 .707 r
F P
0 g
s
.16084 .6823 m .16084 .62672 L .15794 .61817 L p .707 .577 .707 r
F P
0 g
s
.16084 .69261 m .16084 .72967 L .17343 .73755 L p .707 .577 .707 r
F P
0 g
s
.17343 .76267 m .17343 .74414 L .16084 .73626 L p .707 .577 .707 r
F P
0 g
s
.16084 .73626 m .16084 .75479 L .17343 .76267 L p .707 .577 .707 r
F P
0 g
s
.64393 .22749 m .64393 .72938 L .63984 .71732 L p .707 .577 .707 r
F P
0 g
s
.63984 .71732 m .63984 .21543 L .64393 .22749 L p .707 .577 .707 r
F P
0 g
s
.64085 .7409 m .64085 .75942 L .60968 .75752 L p .707 .577 .707 r
F P
0 g
s
.15794 .61817 m .15794 .67376 L .16084 .6823 L p .707 .577 .707 r
F P
0 g
s
.35476 .73972 m .35476 .75824 L .36184 .74988 L p .707 .577 .707 r
F P
0 g
s
.16084 .72967 m .16084 .69261 L .15794 .68407 L p .707 .577 .707 r
F P
0 g
s
.15794 .68407 m .15794 .72113 L .16084 .72967 L p .707 .577 .707 r
F P
0 g
s
.35894 .61327 m .35894 .66885 L .34635 .66097 L p .707 .577 .707 r
F P
0 g
s
.34635 .66097 m .34635 .60538 L .35894 .61327 L p .707 .577 .707 r
F P
0 g
s
.35894 .67916 m .35894 .71622 L .34635 .70834 L p .707 .577 .707 r
F P
0 g
s
.34635 .70834 m .34635 .67128 L .35894 .67916 L p .707 .577 .707 r
F P
0 g
s
.35894 .72281 m .35894 .74134 L .34635 .73345 L p .707 .577 .707 r
F P
0 g
s
.34635 .73345 m .34635 .71493 L .35894 .72281 L p .707 .577 .707 r
F P
0 g
s
.35607 .22236 m .35607 .72425 L .36016 .73631 L p .707 .577 .707 r
F P
0 g
s
.35607 .72425 m .35607 .22236 L .36607 .21055 L p .707 .577 .707 r
F P
0 g
s
.16084 .75479 m .16084 .73626 L .15794 .72772 L p .707 .577 .707 r
F P
0 g
s
.15794 .67376 m .15794 .61817 L .16503 .60981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15794 .72772 m .15794 .74624 L .16084 .75479 L p .707 .577 .707 r
F P
0 g
s
.16503 .60981 m .16503 .66539 L .15794 .67376 L p .707 .577 .707 r
F P
0 g
s
.15794 .72113 m .15794 .68407 L .16503 .67571 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63984 .21543 m .63984 .71732 L .62206 .70619 L p .707 .577 .707 r
F P
0 g
s
.62206 .70619 m .62206 .2043 L .63984 .21543 L p .707 .577 .707 r
F P
0 g
s
.16503 .67571 m .16503 .71276 L .15794 .72113 L p .707 .577 .707 r
F P
0 g
s
.16503 .66539 m .16503 .60981 L .1814 .60244 L p .707 .577 .707 r
F P
0 g
s
.15794 .74624 m .15794 .72772 L .16503 .71935 L p .707 .577 .707 r
F P
0 g
s
.16503 .71935 m .16503 .73788 L .15794 .74624 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36607 .71244 m .36607 .21055 L .38918 .20015 L p .707 .577 .707 r
F P
0 g
s
.36607 .21055 m .36607 .71244 L .35607 .72425 L p .707 .577 .707 r
F P
0 g
s
.1814 .60244 m .1814 .65802 L .16503 .66539 L p .707 .577 .707 r
F P
0 g
s
.34635 .60538 m .34635 .66097 L .3253 .65451 L p .707 .577 .707 r
F P
0 g
s
.3253 .65451 m .3253 .59893 L .34635 .60538 L p .707 .577 .707 r
F P
0 g
s
.16503 .71276 m .16503 .67571 L .1814 .66834 L p .707 .577 .707 r
F P
0 g
s
.1814 .65802 m .1814 .60244 L .20545 .59679 L p .707 .577 .707 r
F P
0 g
s
.1814 .66834 m .1814 .70539 L .16503 .71276 L p .707 .577 .707 r
F P
0 g
s
.16503 .73788 m .16503 .71935 L .1814 .71199 L p .707 .577 .707 r
F P
0 g
s
.34635 .67128 m .34635 .70834 L .3253 .70188 L p .707 .577 .707 r
F P
0 g
s
.3253 .70188 m .3253 .66483 L .34635 .67128 L p .707 .577 .707 r
F P
0 g
s
.62206 .2043 m .62206 .70619 L .59233 .69708 L p .707 .577 .707 r
F P
0 g
s
.59233 .69708 m .59233 .19519 L .62206 .2043 L p .707 .577 .707 r
F P
0 g
s
.1814 .71199 m .1814 .73051 L .16503 .73788 L p .707 .577 .707 r
F P
0 g
s
.3253 .59893 m .3253 .65451 L .29784 .65012 L p .707 .577 .707 r
F P
0 g
s
.29784 .65012 m .29784 .59454 L .3253 .59893 L p .707 .577 .707 r
F P
0 g
s
.20545 .59679 m .20545 .65237 L .1814 .65802 L p .707 .577 .707 r
F P
0 g
s
.1814 .70539 m .1814 .66834 L .20545 .66269 L p .707 .577 .707 r
F P
0 g
s
.34635 .71493 m .34635 .73345 L .3253 .727 L p .707 .577 .707 r
F P
0 g
s
.3253 .727 m .3253 .70847 L .34635 .71493 L p .707 .577 .707 r
F P
0 g
s
.20545 .65237 m .20545 .59679 L .23483 .59341 L p .707 .577 .707 r
F P
0 g
s
.38918 .20015 m .38918 .70204 L .36607 .71244 L p .707 .577 .707 r
F P
0 g
s
.38918 .70204 m .38918 .20015 L .42314 .19217 L p .707 .577 .707 r
F P
0 g
s
.29784 .59454 m .29784 .65012 L .26667 .64822 L p .707 .577 .707 r
F P
0 g
s
.26667 .64822 m .26667 .59264 L .29784 .59454 L p .707 .577 .707 r
F P
0 g
s
.20545 .66269 m .20545 .69974 L .1814 .70539 L p .707 .577 .707 r
F P
0 g
s
.1814 .73051 m .1814 .71199 L .20545 .70634 L p .707 .577 .707 r
F P
0 g
s
.3253 .66483 m .3253 .70188 L .29784 .69749 L p .707 .577 .707 r
F P
0 g
s
.29784 .69749 m .29784 .66043 L .3253 .66483 L p .707 .577 .707 r
F P
0 g
s
.23483 .649 m .23483 .59341 L .26667 .59264 L p .707 .577 .707 r
F P
0 g
s
.23483 .59341 m .23483 .649 L .20545 .65237 L p .707 .577 .707 r
F P
0 g
s
.26667 .59264 m .26667 .64822 L .23483 .649 L p .707 .577 .707 r
F P
0 g
s
.20545 .70634 m .20545 .72486 L .1814 .73051 L p .707 .577 .707 r
F P
0 g
s
.73333 .64771 m .73333 .59212 L .70216 .59022 L p .707 .577 .707 r
F P
0 g
s
.73333 .59212 m .73333 .64771 L .76517 .64693 L p .707 .577 .707 r
F P
0 g
s
.76517 .64693 m .76517 .59135 L .73333 .59212 L p .707 .577 .707 r
F P
0 g
s
.20545 .69974 m .20545 .66269 L .23483 .65931 L p .707 .577 .707 r
F P
0 g
s
.76517 .59135 m .76517 .64693 L .79455 .64355 L p .707 .577 .707 r
F P
0 g
s
.79455 .64355 m .79455 .58797 L .76517 .59135 L p .707 .577 .707 r
F P
0 g
s
.59233 .19519 m .59233 .69708 L .55357 .69088 L p .707 .577 .707 r
F P
0 g
s
.55357 .69088 m .55357 .18899 L .59233 .19519 L p .707 .577 .707 r
F P
0 g
s
.3253 .70847 m .3253 .727 L .29784 .72261 L p .707 .577 .707 r
F P
0 g
s
.29784 .72261 m .29784 .70408 L .3253 .70847 L p .707 .577 .707 r
F P
0 g
s
.70216 .64581 m .70216 .59022 L .6747 .58583 L p .707 .577 .707 r
F P
0 g
s
.70216 .59022 m .70216 .64581 L .73333 .64771 L p .707 .577 .707 r
F P
0 g
s
.29784 .66043 m .29784 .69749 L .26667 .69559 L p .707 .577 .707 r
F P
0 g
s
.26667 .69559 m .26667 .65853 L .29784 .66043 L p .707 .577 .707 r
F P
0 g
s
.23483 .65931 m .23483 .69637 L .20545 .69974 L p .707 .577 .707 r
F P
0 g
s
.23483 .69637 m .23483 .65931 L .26667 .65853 L p .707 .577 .707 r
F P
0 g
s
.20545 .72486 m .20545 .70634 L .23483 .70296 L p .707 .577 .707 r
F P
0 g
s
.42314 .69406 m .42314 .19217 L .46462 .1874 L p .707 .577 .707 r
F P
0 g
s
.42314 .19217 m .42314 .69406 L .38918 .70204 L p .707 .577 .707 r
F P
0 g
s
.79455 .58797 m .79455 .64355 L .8186 .6379 L p .707 .577 .707 r
F P
0 g
s
.8186 .6379 m .8186 .58232 L .79455 .58797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65853 m .26667 .69559 L .23483 .69637 L p .707 .577 .707 r
F P
0 g
s
.73333 .69508 m .73333 .65802 L .70216 .65612 L p .707 .577 .707 r
F P
0 g
s
.73333 .65802 m .73333 .69508 L .76517 .6943 L p .707 .577 .707 r
F P
0 g
s
.76517 .6943 m .76517 .65724 L .73333 .65802 L p .707 .577 .707 r
F P
0 g
s
.23483 .70296 m .23483 .72148 L .20545 .72486 L p .707 .577 .707 r
F P
0 g
s
.76517 .65724 m .76517 .6943 L .79455 .69092 L p .707 .577 .707 r
F P
0 g
s
.79455 .69092 m .79455 .65387 L .76517 .65724 L p .707 .577 .707 r
F P
0 g
s
.29784 .70408 m .29784 .72261 L .26667 .72071 L p .707 .577 .707 r
F P
0 g
s
.26667 .72071 m .26667 .70218 L .29784 .70408 L p .707 .577 .707 r
F P
0 g
s
.6747 .58583 m .6747 .64141 L .70216 .64581 L p .707 .577 .707 r
F P
0 g
s
.6747 .64141 m .6747 .58583 L .65365 .57938 L p .707 .577 .707 r
F P
0 g
s
.70216 .69318 m .70216 .65612 L .6747 .65173 L p .707 .577 .707 r
F P
0 g
s
.70216 .65612 m .70216 .69318 L .73333 .69508 L p .707 .577 .707 r
F P
0 g
s
.55357 .18899 m .55357 .69088 L .50956 .68819 L p .707 .577 .707 r
F P
0 g
s
.50956 .68819 m .50956 .1863 L .55357 .18899 L p .707 .577 .707 r
F P
0 g
s
.23483 .72148 m .23483 .70296 L .26667 .70218 L p .707 .577 .707 r
F P
0 g
s
.26667 .70218 m .26667 .72071 L .23483 .72148 L p .707 .577 .707 r
F P
0 g
s
.73333 .72019 m .73333 .70167 L .70216 .69977 L p .707 .577 .707 r
F P
0 g
s
.73333 .70167 m .73333 .72019 L .76517 .71942 L p .707 .577 .707 r
F P
0 g
s
.76517 .71942 m .76517 .70089 L .73333 .70167 L p .707 .577 .707 r
F P
0 g
s
.46462 .68929 m .46462 .1874 L .50956 .1863 L p .707 .577 .707 r
F P
0 g
s
.46462 .1874 m .46462 .68929 L .42314 .69406 L p .707 .577 .707 r
F P
0 g
s
.79455 .65387 m .79455 .69092 L .8186 .68527 L p .707 .577 .707 r
F P
0 g
s
.8186 .68527 m .8186 .64822 L .79455 .65387 L p .707 .577 .707 r
F P
0 g
s
.76517 .70089 m .76517 .71942 L .79455 .71604 L p .707 .577 .707 r
F P
0 g
s
.79455 .71604 m .79455 .69751 L .76517 .70089 L p .707 .577 .707 r
F P
0 g
s
.8186 .58232 m .8186 .6379 L .83497 .63053 L p .707 .577 .707 r
F P
0 g
s
.83497 .63053 m .83497 .57495 L .8186 .58232 L p .707 .577 .707 r
F P
0 g
s
.50956 .1863 m .50956 .68819 L .46462 .68929 L p .707 .577 .707 r
F P
0 g
s
.6747 .65173 m .6747 .68878 L .70216 .69318 L p .707 .577 .707 r
F P
0 g
s
.70216 .69977 m .70216 .71829 L .73333 .72019 L p .707 .577 .707 r
F P
0 g
s
.70216 .71829 m .70216 .69977 L .6747 .69537 L p .707 .577 .707 r
F P
0 g
s
.65365 .57938 m .65365 .63496 L .6747 .64141 L p .707 .577 .707 r
F P
0 g
s
.6747 .68878 m .6747 .65173 L .65365 .64528 L p .707 .577 .707 r
F P
0 g
s
.6747 .69537 m .6747 .7139 L .70216 .71829 L p .707 .577 .707 r
F P
0 g
s
.79455 .69751 m .79455 .71604 L .8186 .71039 L p .707 .577 .707 r
F P
0 g
s
.8186 .71039 m .8186 .69186 L .79455 .69751 L p .707 .577 .707 r
F P
0 g
s
.65365 .63496 m .65365 .57938 L .64105 .57149 L p .707 .577 .707 r
F P
0 g
s
.65365 .64528 m .65365 .68233 L .6747 .68878 L p .707 .577 .707 r
F P
0 g
s
.6747 .7139 m .6747 .69537 L .65365 .68892 L p .707 .577 .707 r
F P
0 g
s
.8186 .64822 m .8186 .68527 L .83497 .6779 L p .707 .577 .707 r
F P
0 g
s
.83497 .6779 m .83497 .64085 L .8186 .64822 L p .707 .577 .707 r
F P
0 g
s
.65365 .68892 m .65365 .70745 L .6747 .7139 L p .707 .577 .707 r
F P
0 g
s
.64105 .57149 m .64105 .62708 L .65365 .63496 L p .707 .577 .707 r
F P
0 g
s
.83497 .57495 m .83497 .63053 L .84205 .62217 L p .707 .577 .707 r
F P
0 g
s
.84205 .62217 m .84205 .56659 L .83497 .57495 L p .707 .577 .707 r
F P
0 g
s
.65365 .68233 m .65365 .64528 L .64105 .63739 L p .707 .577 .707 r
F P
0 g
s
.8186 .69186 m .8186 .71039 L .83497 .70302 L p .707 .577 .707 r
F P
0 g
s
.83497 .70302 m .83497 .68449 L .8186 .69186 L p .707 .577 .707 r
F P
0 g
s
.64105 .62708 m .64105 .57149 L .63816 .56295 L p .707 .577 .707 r
F P
0 g
s
.64105 .63739 m .64105 .67445 L .65365 .68233 L p .707 .577 .707 r
F P
0 g
s
.65365 .70745 m .65365 .68892 L .64105 .68104 L p .707 .577 .707 r
F P
0 g
s
.83497 .64085 m .83497 .6779 L .84206 .66954 L p .707 .577 .707 r
F P
0 g
s
.84206 .66954 m .84205 .63248 L .83497 .64085 L p .707 .577 .707 r
F P
0 g
s
.64105 .68104 m .64105 .69956 L .65365 .70745 L p .707 .577 .707 r
F P
0 g
s
.63816 .56295 m .63816 .61853 L .64105 .62708 L p .707 .577 .707 r
F P
0 g
s
.84205 .56659 m .84205 .62217 L .83916 .61363 L p .707 .577 .707 r
F P
0 g
s
.83916 .61363 m .83916 .55804 L .84205 .56659 L p .707 .577 .707 r
F P
0 g
s
.83497 .68449 m .83497 .70302 L .84206 .69466 L p .707 .577 .707 r
F P
0 g
s
.84206 .69466 m .84206 .67613 L .83497 .68449 L p .707 .577 .707 r
F P
0 g
s
.64105 .67445 m .64105 .63739 L .63816 .62885 L p .707 .577 .707 r
F P
0 g
s
.63816 .62885 m .63816 .6659 L .64105 .67445 L p .707 .577 .707 r
F P
0 g
s
.64105 .69956 m .64105 .68104 L .63816 .67249 L p .707 .577 .707 r
F P
0 g
s
.63816 .61853 m .63816 .56295 L .64524 .55459 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .67249 m .63816 .69102 L .64105 .69956 L p .707 .577 .707 r
F P
0 g
s
.84205 .63248 m .84206 .66954 L .83916 .661 L p .707 .577 .707 r
F P
0 g
s
.83916 .661 m .83916 .62394 L .84205 .63248 L p .707 .577 .707 r
F P
0 g
s
.64524 .55459 m .64524 .61017 L .63816 .61853 L p .707 .577 .707 r
F P
0 g
s
.84206 .67613 m .84206 .69466 L .83916 .68611 L p .707 .577 .707 r
F P
0 g
s
.83916 .68611 m .83916 .66759 L .84206 .67613 L p .707 .577 .707 r
F P
0 g
s
.83916 .55804 m .83916 .61363 L .82657 .60574 L p .707 .577 .707 r
F P
0 g
s
.82657 .60574 m .82657 .55016 L .83916 .55804 L p .707 .577 .707 r
F P
0 g
s
.63816 .6659 m .63816 .62885 L .64524 .62048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39032 .61089 m .39032 .55531 L .35915 .55341 L p .707 .577 .707 r
F P
0 g
s
.39032 .55531 m .39032 .61089 L .42216 .61011 L p .707 .577 .707 r
F P
0 g
s
.42216 .61011 m .42216 .55453 L .39032 .55531 L p .707 .577 .707 r
F P
0 g
s
.64524 .62048 m .64524 .65754 L .63816 .6659 L p .707 .577 .707 r
F P
0 g
s
.64524 .61017 m .64524 .55459 L .66161 .54722 L p .707 .577 .707 r
F P
0 g
s
.42216 .55453 m .42216 .61011 L .45154 .60673 L p .707 .577 .707 r
F P
0 g
s
.45154 .60673 m .45154 .55115 L .42216 .55453 L p .707 .577 .707 r
F P
0 g
s
.63816 .69102 m .63816 .67249 L .64524 .66413 L p .707 .577 .707 r
F P
0 g
s
.35915 .60899 m .35915 .55341 L .33169 .54902 L p .707 .577 .707 r
F P
0 g
s
.35915 .55341 m .35915 .60899 L .39032 .61089 L p .707 .577 .707 r
F P
0 g
s
.64524 .66413 m .64524 .68266 L .63816 .69102 L p .707 .577 .707 r
F P
0 g
s
.83916 .62394 m .83916 .661 L .82657 .65311 L p .707 .577 .707 r
F P
0 g
s
.82657 .65311 m .82657 .61606 L .83916 .62394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .55115 m .45154 .60673 L .47559 .60109 L p .707 .577 .707 r
F P
0 g
s
.47559 .60109 m .47559 .5455 L .45154 .55115 L p .707 .577 .707 r
F P
0 g
s
.66161 .54722 m .66161 .6028 L .64524 .61017 L p .707 .577 .707 r
F P
0 g
s
.39032 .65826 m .39032 .62121 L .35915 .61931 L p .707 .577 .707 r
F P
0 g
s
.39032 .62121 m .39032 .65826 L .42216 .65748 L p .707 .577 .707 r
F P
0 g
s
.42216 .65748 m .42216 .62043 L .39032 .62121 L p .707 .577 .707 r
F P
0 g
s
.82657 .55016 m .82657 .60574 L .80551 .59929 L p .707 .577 .707 r
F P
0 g
s
.80551 .59929 m .80551 .54371 L .82657 .55016 L p .707 .577 .707 r
F P
0 g
s
.83916 .66759 m .83916 .68611 L .82657 .67823 L p .707 .577 .707 r
F P
0 g
s
.82657 .67823 m .82657 .6597 L .83916 .66759 L p .707 .577 .707 r
F P
0 g
s
.64524 .65754 m .64524 .62048 L .66161 .61312 L p .707 .577 .707 r
F P
0 g
s
.42216 .62043 m .42216 .65748 L .45154 .65411 L p .707 .577 .707 r
F P
0 g
s
.45154 .65411 m .45154 .61705 L .42216 .62043 L p .707 .577 .707 r
F P
0 g
s
.33169 .54902 m .33169 .6046 L .35915 .60899 L p .707 .577 .707 r
F P
0 g
s
.33169 .6046 m .33169 .54902 L .31064 .54256 L p .707 .577 .707 r
F P
0 g
s
.35915 .65636 m .35915 .61931 L .33169 .61491 L p .707 .577 .707 r
F P
0 g
s
.35915 .61931 m .35915 .65636 L .39032 .65826 L p .707 .577 .707 r
F P
0 g
s
.66161 .6028 m .66161 .54722 L .68566 .54157 L p .707 .577 .707 r
F P
0 g
s
.39032 .68338 m .39032 .66485 L .35915 .66295 L p .707 .577 .707 r
F P
0 g
s
.39032 .66485 m .39032 .68338 L .42216 .6826 L p .707 .577 .707 r
F P
0 g
s
.42216 .6826 m .42216 .66407 L .39032 .66485 L p .707 .577 .707 r
F P
0 g
s
.66161 .61312 m .66161 .65017 L .64524 .65754 L p .707 .577 .707 r
F P
0 g
s
.64524 .68266 m .64524 .66413 L .66161 .65676 L p .707 .577 .707 r
F P
0 g
s
.45154 .61705 m .45154 .65411 L .47559 .64846 L p .707 .577 .707 r
F P
0 g
s
.47559 .64846 m .47559 .6114 L .45154 .61705 L p .707 .577 .707 r
F P
0 g
s
.42216 .66407 m .42216 .6826 L .45154 .67922 L p .707 .577 .707 r
F P
0 g
s
.45154 .67922 m .45154 .6607 L .42216 .66407 L p .707 .577 .707 r
F P
0 g
s
.47559 .5455 m .47559 .60109 L .49196 .59372 L p .707 .577 .707 r
F P
0 g
s
.49196 .59372 m .49196 .53813 L .47559 .5455 L p .707 .577 .707 r
F P
0 g
s
.33169 .61491 m .33169 .65197 L .35915 .65636 L p .707 .577 .707 r
F P
0 g
s
.35915 .66295 m .35915 .68148 L .39032 .68338 L p .707 .577 .707 r
F P
0 g
s
.82657 .61606 m .82657 .65311 L .80551 .64666 L p .707 .577 .707 r
F P
0 g
s
.80551 .64666 m .80551 .6096 L .82657 .61606 L p .707 .577 .707 r
F P
0 g
s
.35915 .68148 m .35915 .66295 L .33169 .65856 L p .707 .577 .707 r
F P
0 g
s
.31064 .54256 m .31064 .59814 L .33169 .6046 L p .707 .577 .707 r
F P
0 g
s
.66161 .65676 m .66161 .67529 L .64524 .68266 L p .707 .577 .707 r
F P
0 g
s
.33169 .65197 m .33169 .61491 L .31064 .60846 L p .707 .577 .707 r
F P
0 g
s
.80551 .54371 m .80551 .59929 L .77805 .5949 L p .707 .577 .707 r
F P
0 g
s
.77805 .5949 m .77805 .53931 L .80551 .54371 L p .707 .577 .707 r
F P
0 g
s
.33169 .65856 m .33169 .67709 L .35915 .68148 L p .707 .577 .707 r
F P
0 g
s
.68566 .54157 m .68566 .59715 L .66161 .6028 L p .707 .577 .707 r
F P
0 g
s
.45154 .6607 m .45154 .67922 L .47559 .67357 L p .707 .577 .707 r
F P
0 g
s
.47559 .67357 m .47559 .65505 L .45154 .6607 L p .707 .577 .707 r
F P
0 g
s
.31064 .59814 m .31064 .54256 L .29804 .53468 L p .707 .577 .707 r
F P
0 g
s
.66161 .65017 m .66161 .61312 L .68566 .60747 L p .707 .577 .707 r
F P
0 g
s
.82657 .6597 m .82657 .67823 L .80551 .67178 L p .707 .577 .707 r
F P
0 g
s
.80551 .67178 m .80551 .65325 L .82657 .6597 L p .707 .577 .707 r
F P
0 g
s
.68566 .59715 m .68566 .54157 L .71504 .53819 L p .707 .577 .707 r
F P
0 g
s
.31064 .60846 m .31064 .64551 L .33169 .65197 L p .707 .577 .707 r
F P
0 g
s
.33169 .67709 m .33169 .65856 L .31064 .6521 L p .707 .577 .707 r
F P
0 g
s
.47559 .6114 m .47559 .64846 L .49196 .64109 L p .707 .577 .707 r
F P
0 g
s
.49196 .64109 m .49196 .60403 L .47559 .6114 L p .707 .577 .707 r
F P
0 g
s
.77805 .53931 m .77805 .5949 L .74688 .593 L p .707 .577 .707 r
F P
0 g
s
.74688 .593 m .74688 .53741 L .77805 .53931 L p .707 .577 .707 r
F P
0 g
s
.68566 .60747 m .68566 .64452 L .66161 .65017 L p .707 .577 .707 r
F P
0 g
s
.31064 .6521 m .31064 .67063 L .33169 .67709 L p .707 .577 .707 r
F P
0 g
s
.66161 .67529 m .66161 .65676 L .68566 .65111 L p .707 .577 .707 r
F P
0 g
s
.80551 .6096 m .80551 .64666 L .77805 .64227 L p .707 .577 .707 r
F P
0 g
s
.77805 .64227 m .77805 .60521 L .80551 .6096 L p .707 .577 .707 r
F P
0 g
s
.29804 .53468 m .29804 .59026 L .31064 .59814 L p .707 .577 .707 r
F P
0 g
s
.71504 .59377 m .71504 .53819 L .74688 .53741 L p .707 .577 .707 r
F P
0 g
s
.71504 .53819 m .71504 .59377 L .68566 .59715 L p .707 .577 .707 r
F P
0 g
s
.49196 .53813 m .49196 .59372 L .49904 .58535 L p .707 .577 .707 r
F P
0 g
s
.49904 .58535 m .49904 .52977 L .49196 .53813 L p .707 .577 .707 r
F P
0 g
s
.31064 .64551 m .31064 .60846 L .29804 .60058 L p .707 .577 .707 r
F P
0 g
s
.74688 .53741 m .74688 .593 L .71504 .59377 L p .707 .577 .707 r
F P
0 g
s
.68566 .65111 m .68566 .66964 L .66161 .67529 L p .707 .577 .707 r
F P
0 g
s
.47559 .65505 m .47559 .67357 L .49196 .66621 L p .707 .577 .707 r
F P
0 g
s
.49196 .66621 m .49196 .64768 L .47559 .65505 L p .707 .577 .707 r
F P
0 g
s
.68566 .64452 m .68566 .60747 L .71504 .60409 L p .707 .577 .707 r
F P
0 g
s
.80551 .65325 m .80551 .67178 L .77805 .66738 L p .707 .577 .707 r
F P
0 g
s
.77805 .66738 m .77805 .64886 L .80551 .65325 L p .707 .577 .707 r
F P
0 g
s
.29804 .59026 m .29804 .53468 L .29515 .52614 L p .707 .577 .707 r
F P
0 g
s
.29804 .60058 m .29804 .63763 L .31064 .64551 L p .707 .577 .707 r
F P
0 g
s
.77805 .60521 m .77805 .64227 L .74688 .64037 L p .707 .577 .707 r
F P
0 g
s
.74688 .64037 m .74688 .60331 L .77805 .60521 L p .707 .577 .707 r
F P
0 g
s
.31064 .67063 m .31064 .6521 L .29804 .64422 L p .707 .577 .707 r
F P
0 g
s
.71504 .60409 m .71504 .64114 L .68566 .64452 L p .707 .577 .707 r
F P
0 g
s
.71504 .64114 m .71504 .60409 L .74688 .60331 L p .707 .577 .707 r
F P
0 g
s
.68566 .66964 m .68566 .65111 L .71504 .64773 L p .707 .577 .707 r
F P
0 g
s
.49196 .60403 m .49196 .64109 L .49904 .63272 L p .707 .577 .707 r
F P
0 g
s
.49904 .63272 m .49904 .59567 L .49196 .60403 L p .707 .577 .707 r
F P
0 g
s
.29804 .64422 m .29804 .66275 L .31064 .67063 L p .707 .577 .707 r
F P
0 g
s
.74688 .60331 m .74688 .64037 L .71504 .64114 L p .707 .577 .707 r
F P
0 g
s
.71504 .64773 m .71504 .66626 L .68566 .66964 L p .707 .577 .707 r
F P
0 g
s
.77805 .64886 m .77805 .66738 L .74688 .66548 L p .707 .577 .707 r
F P
0 g
s
.74688 .66548 m .74688 .64696 L .77805 .64886 L p .707 .577 .707 r
F P
0 g
s
.29515 .52614 m .29515 .58172 L .29804 .59026 L p .707 .577 .707 r
F P
0 g
s
.49904 .52977 m .49904 .58535 L .49615 .57681 L p .707 .577 .707 r
F P
0 g
s
.49615 .57681 m .49615 .52123 L .49904 .52977 L p .707 .577 .707 r
F P
0 g
s
.71504 .66626 m .71504 .64773 L .74688 .64696 L p .707 .577 .707 r
F P
0 g
s
.49196 .64768 m .49196 .66621 L .49904 .65784 L p .707 .577 .707 r
F P
0 g
s
.49904 .65784 m .49904 .63931 L .49196 .64768 L p .707 .577 .707 r
F P
0 g
s
.29804 .63763 m .29804 .60058 L .29515 .59203 L p .707 .577 .707 r
F P
0 g
s
.74688 .64696 m .74688 .66548 L .71504 .66626 L p .707 .577 .707 r
F P
0 g
s
.29515 .59203 m .29515 .62909 L .29804 .63763 L p .707 .577 .707 r
F P
0 g
s
.29804 .66275 m .29804 .64422 L .29515 .63568 L p .707 .577 .707 r
F P
0 g
s
.29515 .58172 m .29515 .52614 L .30223 .51777 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29515 .63568 m .29515 .65421 L .29804 .66275 L p .707 .577 .707 r
F P
0 g
s
.49904 .59567 m .49904 .63272 L .49615 .62418 L p .707 .577 .707 r
F P
0 g
s
.49615 .62418 m .49615 .58713 L .49904 .59567 L p .707 .577 .707 r
F P
0 g
s
.30223 .51777 m .30223 .57335 L .29515 .58172 L p .707 .577 .707 r
F P
0 g
s
.49904 .63931 m .49904 .65784 L .49615 .6493 L p .707 .577 .707 r
F P
0 g
s
.49615 .6493 m .49615 .63077 L .49904 .63931 L p .707 .577 .707 r
F P
0 g
s
.49615 .52123 m .49615 .57681 L .48356 .56893 L p .707 .577 .707 r
F P
0 g
s
.48356 .56893 m .48356 .51334 L .49615 .52123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62909 m .29515 .59203 L .30223 .58367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .58367 m .30223 .62072 L .29515 .62909 L p .707 .577 .707 r
F P
0 g
s
.30223 .57335 m .30223 .51777 L .3186 .5104 L p .707 .577 .707 r
F P
0 g
s
.29515 .65421 m .29515 .63568 L .30223 .62731 L p .707 .577 .707 r
F P
0 g
s
.30223 .62731 m .30223 .64584 L .29515 .65421 L p .707 .577 .707 r
F P
0 g
s
.49615 .58713 m .49615 .62418 L .48356 .6163 L p .707 .577 .707 r
F P
0 g
s
.48356 .6163 m .48356 .57924 L .49615 .58713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .5104 m .3186 .56599 L .30223 .57335 L p .707 .577 .707 r
F P
0 g
s
.48356 .51334 m .48356 .56893 L .4625 .56247 L p .707 .577 .707 r
F P
0 g
s
.4625 .56247 m .4625 .50689 L .48356 .51334 L p .707 .577 .707 r
F P
0 g
s
.49615 .63077 m .49615 .6493 L .48356 .64141 L p .707 .577 .707 r
F P
0 g
s
.48356 .64141 m .48356 .62289 L .49615 .63077 L p .707 .577 .707 r
F P
0 g
s
.30223 .62072 m .30223 .58367 L .3186 .5763 L p .707 .577 .707 r
F P
0 g
s
.3186 .56599 m .3186 .5104 L .34265 .50475 L p .707 .577 .707 r
F P
0 g
s
.3186 .5763 m .3186 .61336 L .30223 .62072 L p .707 .577 .707 r
F P
0 g
s
.30223 .64584 m .30223 .62731 L .3186 .61995 L p .707 .577 .707 r
F P
0 g
s
.48356 .57924 m .48356 .6163 L .4625 .60984 L p .707 .577 .707 r
F P
0 g
s
.4625 .60984 m .4625 .57279 L .48356 .57924 L p .707 .577 .707 r
F P
0 g
s
.3186 .61995 m .3186 .63847 L .30223 .64584 L p .707 .577 .707 r
F P
0 g
s
.4625 .50689 m .4625 .56247 L .43504 .55808 L p .707 .577 .707 r
F P
0 g
s
.43504 .55808 m .43504 .5025 L .4625 .50689 L p .707 .577 .707 r
F P
0 g
s
.34265 .50475 m .34265 .56034 L .3186 .56599 L p .707 .577 .707 r
F P
0 g
s
.3186 .61336 m .3186 .5763 L .34265 .57065 L p .707 .577 .707 r
F P
0 g
s
.48356 .62289 m .48356 .64141 L .4625 .63496 L p .707 .577 .707 r
F P
0 g
s
.4625 .63496 m .4625 .61643 L .48356 .62289 L p .707 .577 .707 r
F P
0 g
s
.34265 .56034 m .34265 .50475 L .37203 .50137 L p .707 .577 .707 r
F P
0 g
s
.43504 .5025 m .43504 .55808 L .40387 .55618 L p .707 .577 .707 r
F P
0 g
s
.40387 .55618 m .40387 .5006 L .43504 .5025 L p .707 .577 .707 r
F P
0 g
s
.34265 .57065 m .34265 .60771 L .3186 .61336 L p .707 .577 .707 r
F P
0 g
s
.3186 .63847 m .3186 .61995 L .34265 .6143 L p .707 .577 .707 r
F P
0 g
s
.4625 .57279 m .4625 .60984 L .43504 .60545 L p .707 .577 .707 r
F P
0 g
s
.43504 .60545 m .43504 .5684 L .4625 .57279 L p .707 .577 .707 r
F P
0 g
s
.37203 .55696 m .37203 .50137 L .40387 .5006 L p .707 .577 .707 r
F P
0 g
s
.37203 .50137 m .37203 .55696 L .34265 .56034 L p .707 .577 .707 r
F P
0 g
s
.40387 .5006 m .40387 .55618 L .37203 .55696 L p .707 .577 .707 r
F P
0 g
s
.34265 .6143 m .34265 .63282 L .3186 .63847 L p .707 .577 .707 r
F P
0 g
s
.34265 .60771 m .34265 .57065 L .37203 .56727 L p .707 .577 .707 r
F P
0 g
s
.4625 .61643 m .4625 .63496 L .43504 .63057 L p .707 .577 .707 r
F P
0 g
s
.43504 .63057 m .43504 .61204 L .4625 .61643 L p .707 .577 .707 r
F P
0 g
s
.43504 .5684 m .43504 .60545 L .40387 .60355 L p .707 .577 .707 r
F P
0 g
s
.40387 .60355 m .40387 .56649 L .43504 .5684 L p .707 .577 .707 r
F P
0 g
s
.37203 .56727 m .37203 .60433 L .34265 .60771 L p .707 .577 .707 r
F P
0 g
s
.37203 .60433 m .37203 .56727 L .40387 .56649 L p .707 .577 .707 r
F P
0 g
s
.34265 .63282 m .34265 .6143 L .37203 .61092 L p .707 .577 .707 r
F P
0 g
s
.40387 .56649 m .40387 .60355 L .37203 .60433 L p .707 .577 .707 r
F P
0 g
s
.37203 .61092 m .37203 .62945 L .34265 .63282 L p .707 .577 .707 r
F P
0 g
s
.43504 .61204 m .43504 .63057 L .40387 .62867 L p .707 .577 .707 r
F P
0 g
s
.40387 .62867 m .40387 .61014 L .43504 .61204 L p .707 .577 .707 r
F P
0 g
s
.37203 .62945 m .37203 .61092 L .40387 .61014 L p .707 .577 .707 r
F P
0 g
s
.40387 .61014 m .40387 .62867 L .37203 .62945 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eo
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001dOol30000
0eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol0071oo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00
001aOol006eoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEUYFFUH3001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061o
o`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000HOol90014Ool005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?Ool90004FUH00`00FUIJEP02FUH8000l
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00008Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000goo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH40006FUH00`00FUIJEP04
FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF0000
15YF1@001eYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00
FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP8000AJEP03
001JEUYF00EJEQT00003FUH005YF00EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH000030005FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000UYF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0002FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000oOolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP@000EJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUH000020006FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPT000IJEP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH50002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPd000=JEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEPH00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH000020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP00FUH20003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P000UYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF000005YF
00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF001oo`0/Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800004FUH000000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP03FUHC0004
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYF
FUH<0004FUHF0004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHH0003FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30002FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50003FUH00`00FUIJEP0:0004FUH00`00FUIJ
EP02FUH80004Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPL000MJEP@000IJEP04001JEP000002FUH30002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH000030003FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPT000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH30003FUH2000]Ool002aoo`03001JEP0000AJEP03001J
EP0000<000IJEP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUH000040003FUH80004
FUH00`00FUIJEP03FUH>0002FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF000000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020002FUH20000
0eYF0000000]Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQH000=JEP03001JEUYF
009JEPH0009JEP05001JEUYF001JEP0:0004FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF200015YF
00<005YFFUH00eYF2@000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00
;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03
001JEUYF00<002eoo`00;7oo0P000eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEP03001JEUYF
00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`80009JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEP00008000IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<000=JEP04
001JEUYFFUH2000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF200015YF
10001UYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH2000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH0000B0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30002Ool4000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003Ool2000015YF00000000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000`00
0UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0017oo0`000eYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF100015YF2@00
35YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF00<005YFFUH00UYF1P0000=JEP0000005`001Goo100000=JEP00FUH00eYF00<005YF0000;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH?0008FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YF
FUIJEPT0019oo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00<005YF0000
0`000Woo6`000Woo1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`03001JEP0000=JEP@000=oo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000Eoo`@00005FUH005YFFUH00002FUH01000FUIJEUYF0P00
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo000/Ool01000FUH005YF0P000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP<0009J
EP05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00
;7oo00D005YF000005YF00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP000080009JEP<0009JEP800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH4000dOol002aoo`80009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04FUH60004FUH00`00FUIJEP06
FUH40005FUH00`00FUIJEP02FUH7000hOol002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEQ/003moo`00;7oo0`0015YF00<0
05YFFUH015YF00<005YFFUH00UYF30001EYF200015YF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2
0007Ool50018Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00;7oo00<005YF00000eYF1P001eYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
27oo0`00BGoo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP00
00@000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<00003FUH005YF00AJEP04001JEUYFFUH2001DOol002aoo`@000=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`D0009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEPL0009oo`@000=JEP04001JEUYFFUH2001DOol002aoo`80009J
EP<000=oo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00=oo`<00004FUH007ooOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEPX000=JEP8005Ao
o`00;7oo0P000eYF00<005YF00000P001Goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@00
17oo0`000UYF00<005YF000017oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEP00
0080009JEP03001JEUYF008005Aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0027oo4`001Goo1000
00=JEP00FUH00UYF00<005YF00001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001eYF00<005YFFUH015YF00<005YFFUH00UYF
0P0000=JEP0000000P00E7oo000]Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPP001=oo`D000EJ
EP04001JEUYFFUH20009Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000015YF00000000E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4`00
0eYF00<005YFFUH015YF00D005YFFUIJEP0000eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEQL000EJEP03001JEUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000001Eoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEPD000AJEP03001JEUYF00=J
EP@00003FUH005YF00AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002=ooaH000EJEP03001JEUYF
00IJEPD000AJEP03001JEUYF00EJEP03001JEP00008000AJEP05001JEUYFFUH0001EOol003Ioo`D0
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03001J
EP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP8005Aoo`00>goo200015YF10001UYF00<005YFFUH00UYF1@00<goo
00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8005Aoo`00@goo4`00>7oo00<005YF00000`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000=JEP000000
E7oo0017Ool50012Ool2000015YF001oogoo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00004Ool00000FUH3001DOol004Moo`D0049oo`80
009JEP<0009oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL0009oo`<0
00=JEP<005Aoo`00B7oo0`00@goo0P000UYF00<005YFFUH01@000Woo6`001Goo100000=JEP00FUH0
0eYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YF00000`006Goo1@001EYF00<005YF
FUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF1@00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH7001OOol009aooa/006Ioo`00ZGoo1@00Kgoo002YOol5001_Ool00:Uoo`D006moo`00
ZWoo0`00L7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75925 m .59613 .70366 L .56496 .70176 L p .707 .577 .707 r
F P
0 g
s
.59613 .70366 m .59613 .75925 L .62796 .75847 L p .707 .577 .707 r
F P
0 g
s
.62796 .75847 m .62796 .70289 L .59613 .70366 L p .707 .577 .707 r
F P
0 g
s
.62796 .70289 m .62796 .75847 L .65735 .75509 L p .707 .577 .707 r
F P
0 g
s
.65735 .75509 m .65734 .69951 L .62796 .70289 L p .707 .577 .707 r
F P
0 g
s
.56496 .75735 m .56496 .70176 L .5375 .69737 L p .707 .577 .707 r
F P
0 g
s
.56496 .70176 m .56496 .75735 L .59613 .75925 L p .707 .577 .707 r
F P
0 g
s
.65734 .69951 m .65735 .75509 L .6814 .74944 L p .707 .577 .707 r
F P
0 g
s
.6814 .74944 m .6814 .69386 L .65734 .69951 L p .707 .577 .707 r
F P
0 g
s
.5375 .69737 m .5375 .75295 L .56496 .75735 L p .707 .577 .707 r
F P
0 g
s
.5375 .75295 m .5375 .69737 L .51644 .69092 L p .707 .577 .707 r
F P
0 g
s
.59613 .8326 m .59613 .79555 L .56496 .79365 L p .707 .577 .707 r
F P
0 g
s
.59613 .79555 m .59613 .8326 L .62796 .83182 L p .707 .577 .707 r
F P
0 g
s
.62796 .83182 m .62796 .79477 L .59613 .79555 L p .707 .577 .707 r
F P
0 g
s
.62796 .79477 m .62796 .83182 L .65735 .82844 L p .707 .577 .707 r
F P
0 g
s
.65735 .82844 m .65735 .79139 L .62796 .79477 L p .707 .577 .707 r
F P
0 g
s
.56496 .8307 m .56496 .79365 L .5375 .78925 L p .707 .577 .707 r
F P
0 g
s
.56496 .79365 m .56496 .8307 L .59613 .8326 L p .707 .577 .707 r
F P
0 g
s
.6814 .69386 m .6814 .74944 L .69777 .74207 L p .707 .577 .707 r
F P
0 g
s
.69777 .74207 m .69777 .68649 L .6814 .69386 L p .707 .577 .707 r
F P
0 g
s
.51644 .69092 m .51644 .7465 L .5375 .75295 L p .707 .577 .707 r
F P
0 g
s
.65735 .79139 m .65735 .82844 L .6814 .8228 L p .707 .577 .707 r
F P
0 g
s
.6814 .8228 m .6814 .78574 L .65735 .79139 L p .707 .577 .707 r
F P
0 g
s
.5375 .78925 m .5375 .82631 L .56496 .8307 L p .707 .577 .707 r
F P
0 g
s
.51644 .7465 m .51644 .69092 L .50385 .68303 L p .707 .577 .707 r
F P
0 g
s
.59613 .89115 m .59613 .87263 L .56496 .87072 L p .707 .577 .707 r
F P
0 g
s
.59613 .87263 m .59613 .89115 L .62796 .89038 L p .707 .577 .707 r
F P
0 g
s
.62796 .89038 m .62796 .87185 L .59613 .87263 L p .707 .577 .707 r
F P
0 g
s
.5375 .82631 m .5375 .78925 L .51644 .7828 L p .707 .577 .707 r
F P
0 g
s
.62796 .87185 m .62796 .89038 L .65735 .887 L p .707 .577 .707 r
F P
0 g
s
.65735 .887 m .65735 .86847 L .62796 .87185 L p .707 .577 .707 r
F P
0 g
s
.56496 .87072 m .56496 .88925 L .59613 .89115 L p .707 .577 .707 r
F P
0 g
s
.56496 .88925 m .56496 .87072 L .5375 .86633 L p .707 .577 .707 r
F P
0 g
s
.51644 .7828 m .51644 .81985 L .5375 .82631 L p .707 .577 .707 r
F P
0 g
s
.5375 .86633 m .5375 .88486 L .56496 .88925 L p .707 .577 .707 r
F P
0 g
s
.6814 .78574 m .6814 .8228 L .69777 .81543 L p .707 .577 .707 r
F P
0 g
s
.69777 .81543 m .69777 .77837 L .6814 .78574 L p .707 .577 .707 r
F P
0 g
s
.50385 .68303 m .50385 .73862 L .51644 .7465 L p .707 .577 .707 r
F P
0 g
s
.69777 .68649 m .69777 .74207 L .70485 .73371 L p .707 .577 .707 r
F P
0 g
s
.70485 .73371 m .70485 .67813 L .69777 .68649 L p .707 .577 .707 r
F P
0 g
s
.65735 .86847 m .65735 .887 L .6814 .88135 L p .707 .577 .707 r
F P
0 g
s
.6814 .88135 m .6814 .86282 L .65735 .86847 L p .707 .577 .707 r
F P
0 g
s
.5375 .88486 m .5375 .86633 L .51644 .85988 L p .707 .577 .707 r
F P
0 g
s
.51644 .81985 m .51644 .7828 L .50385 .77492 L p .707 .577 .707 r
F P
0 g
s
.50385 .73862 m .50385 .68303 L .50095 .67449 L p .707 .577 .707 r
F P
0 g
s
.51644 .85988 m .51644 .87841 L .5375 .88486 L p .707 .577 .707 r
F P
0 g
s
.50385 .77492 m .50385 .81197 L .51644 .81985 L p .707 .577 .707 r
F P
0 g
s
.6814 .86282 m .6814 .88135 L .69777 .87398 L p .707 .577 .707 r
F P
0 g
s
.69777 .87398 m .69777 .85545 L .6814 .86282 L p .707 .577 .707 r
F P
0 g
s
.69777 .77837 m .69777 .81543 L .70485 .80706 L p .707 .577 .707 r
F P
0 g
s
.70485 .80706 m .70485 .77001 L .69777 .77837 L p .707 .577 .707 r
F P
0 g
s
.50095 .67449 m .50095 .73007 L .50385 .73862 L p .707 .577 .707 r
F P
0 g
s
.70485 .67813 m .70485 .73371 L .70195 .72517 L p .707 .577 .707 r
F P
0 g
s
.70195 .72517 m .70195 .66958 L .70485 .67813 L p .707 .577 .707 r
F P
0 g
s
.51644 .87841 m .51644 .85988 L .50385 .85199 L p .707 .577 .707 r
F P
0 g
s
.50385 .85199 m .50385 .87052 L .51644 .87841 L p .707 .577 .707 r
F P
0 g
s
.50385 .81197 m .50385 .77492 L .50095 .76637 L p .707 .577 .707 r
F P
0 g
s
.50095 .73007 m .50095 .67449 L .50804 .66613 L p .707 .577 .707 r
F P
0 g
s
.69777 .85545 m .69777 .87398 L .70485 .86561 L p .707 .577 .707 r
F P
0 g
s
.70485 .86561 m .70485 .84709 L .69777 .85545 L p .707 .577 .707 r
F P
0 g
s
.50095 .76637 m .50095 .80343 L .50385 .81197 L p .707 .577 .707 r
F P
0 g
s
.49044 .87824 m .49044 .37636 L .44643 .37367 L p .707 .577 .707 r
F P
0 g
s
.50804 .66613 m .50804 .72171 L .50095 .73007 L p .707 .577 .707 r
F P
0 g
s
.50385 .87052 m .50385 .85199 L .50095 .84345 L p .707 .577 .707 r
F P
0 g
s
.50095 .84345 m .50095 .86198 L .50385 .87052 L p .707 .577 .707 r
F P
0 g
s
.50095 .80343 m .50095 .76637 L .50804 .75801 L p .707 .577 .707 r
F P
0 g
s
.50804 .72171 m .50804 .66613 L .5244 .65876 L p .707 .577 .707 r
F P
0 g
s
.50804 .75801 m .50804 .79506 L .50095 .80343 L p .707 .577 .707 r
F P
0 g
s
.5244 .65876 m .5244 .71434 L .50804 .72171 L p .707 .577 .707 r
F P
0 g
s
.50095 .86198 m .50095 .84345 L .50804 .83509 L p .707 .577 .707 r
F P
0 g
s
.50804 .83509 m .50804 .85362 L .50095 .86198 L p .707 .577 .707 r
F P
0 g
s
.50804 .79506 m .50804 .75801 L .5244 .75064 L p .707 .577 .707 r
F P
0 g
s
.5244 .75064 m .5244 .7877 L .50804 .79506 L p .707 .577 .707 r
F P
0 g
s
.50804 .85362 m .50804 .83509 L .5244 .82772 L p .707 .577 .707 r
F P
0 g
s
.5244 .7877 m .5244 .75064 L .54846 .74499 L p .707 .577 .707 r
F P
0 g
s
.5244 .82772 m .5244 .84625 L .50804 .85362 L p .707 .577 .707 r
F P
0 g
s
.54846 .74499 m .54846 .78205 L .5244 .7877 L p .707 .577 .707 r
F P
0 g
s
.5244 .84625 m .5244 .82772 L .54846 .82207 L p .707 .577 .707 r
F P
0 g
s
.54846 .82207 m .54846 .8406 L .5244 .84625 L p .707 .577 .707 r
F P
0 g
s
.49044 .37636 m .49044 .87824 L .53538 .87715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71434 m .5244 .65876 L .54846 .65311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65311 m .54846 .70869 L .5244 .71434 L p .707 .577 .707 r
F P
0 g
s
.53538 .87715 m .53538 .37526 L .49044 .37636 L p .707 .577 .707 r
F P
0 g
s
.70485 .77001 m .70485 .80706 L .70195 .79852 L p .707 .577 .707 r
F P
0 g
s
.70195 .79852 m .70195 .76147 L .70485 .77001 L p .707 .577 .707 r
F P
0 g
s
.54846 .70869 m .54846 .65311 L .57784 .64973 L p .707 .577 .707 r
F P
0 g
s
.57784 .64973 m .57784 .70531 L .54846 .70869 L p .707 .577 .707 r
F P
0 g
s
.54846 .78205 m .54846 .74499 L .57784 .74161 L p .707 .577 .707 r
F P
0 g
s
.57784 .74161 m .57784 .77867 L .54846 .78205 L p .707 .577 .707 r
F P
0 g
s
.54846 .8406 m .54846 .82207 L .57784 .81869 L p .707 .577 .707 r
F P
0 g
s
.57784 .81869 m .57784 .83722 L .54846 .8406 L p .707 .577 .707 r
F P
0 g
s
.53538 .37526 m .53538 .87715 L .57686 .87238 L p .707 .577 .707 r
F P
0 g
s
.57686 .87238 m .57686 .37049 L .53538 .37526 L p .707 .577 .707 r
F P
0 g
s
.70195 .66958 m .70195 .72517 L .68936 .71728 L p .707 .577 .707 r
F P
0 g
s
.68936 .71728 m .68936 .6617 L .70195 .66958 L p .707 .577 .707 r
F P
0 g
s
.44643 .87556 m .44643 .37367 L .40766 .36747 L p .707 .577 .707 r
F P
0 g
s
.44643 .37367 m .44643 .87556 L .49044 .87824 L p .707 .577 .707 r
F P
0 g
s
.25312 .72243 m .25312 .66685 L .22195 .66495 L p .707 .577 .707 r
F P
0 g
s
.25312 .66685 m .25312 .72243 L .28495 .72165 L p .707 .577 .707 r
F P
0 g
s
.28495 .72165 m .28495 .66607 L .25312 .66685 L p .707 .577 .707 r
F P
0 g
s
.28495 .66607 m .28495 .72165 L .31434 .71828 L p .707 .577 .707 r
F P
0 g
s
.31434 .71828 m .31434 .66269 L .28495 .66607 L p .707 .577 .707 r
F P
0 g
s
.57784 .70531 m .57784 .64973 L .60968 .64895 L p .707 .577 .707 r
F P
0 g
s
.60968 .64895 m .60968 .70454 L .57784 .70531 L p .707 .577 .707 r
F P
0 g
s
.57784 .77867 m .57784 .74161 L .60968 .74084 L p .707 .577 .707 r
F P
0 g
s
.60968 .74084 m .60968 .77789 L .57784 .77867 L p .707 .577 .707 r
F P
0 g
s
.57784 .83722 m .57784 .81869 L .60968 .81791 L p .707 .577 .707 r
F P
0 g
s
.60968 .81791 m .60968 .83644 L .57784 .83722 L p .707 .577 .707 r
F P
0 g
s
.57686 .37049 m .57686 .87238 L .61082 .8644 L p .707 .577 .707 r
F P
0 g
s
.64085 .65085 m .64085 .70644 L .60968 .70454 L p .707 .577 .707 r
F P
0 g
s
.60968 .70454 m .60968 .64895 L .64085 .65085 L p .707 .577 .707 r
F P
0 g
s
.64085 .74274 m .64085 .77979 L .60968 .77789 L p .707 .577 .707 r
F P
0 g
s
.60968 .77789 m .60968 .74084 L .64085 .74274 L p .707 .577 .707 r
F P
0 g
s
.64085 .81982 m .64085 .83834 L .60968 .83644 L p .707 .577 .707 r
F P
0 g
s
.60968 .83644 m .60968 .81791 L .64085 .81982 L p .707 .577 .707 r
F P
0 g
s
.61082 .8644 m .61082 .36251 L .57686 .37049 L p .707 .577 .707 r
F P
0 g
s
.70485 .84709 m .70485 .86561 L .70195 .85707 L p .707 .577 .707 r
F P
0 g
s
.70195 .85707 m .70195 .83855 L .70485 .84709 L p .707 .577 .707 r
F P
0 g
s
.22195 .72053 m .22195 .66495 L .19449 .66056 L p .707 .577 .707 r
F P
0 g
s
.22195 .66495 m .22195 .72053 L .25312 .72243 L p .707 .577 .707 r
F P
0 g
s
.40766 .86936 m .40766 .36747 L .37794 .35836 L p .707 .577 .707 r
F P
0 g
s
.40766 .36747 m .40766 .86936 L .44643 .87556 L p .707 .577 .707 r
F P
0 g
s
.31434 .66269 m .31434 .71828 L .33839 .71263 L p .707 .577 .707 r
F P
0 g
s
.33839 .71263 m .33839 .65704 L .31434 .66269 L p .707 .577 .707 r
F P
0 g
s
.70195 .76147 m .70195 .79852 L .68936 .79064 L p .707 .577 .707 r
F P
0 g
s
.68936 .79064 m .68936 .75358 L .70195 .76147 L p .707 .577 .707 r
F P
0 g
s
.68936 .6617 m .68936 .71728 L .66831 .71083 L p .707 .577 .707 r
F P
0 g
s
.66831 .71083 m .66831 .65525 L .68936 .6617 L p .707 .577 .707 r
F P
0 g
s
.19449 .66056 m .19449 .71614 L .22195 .72053 L p .707 .577 .707 r
F P
0 g
s
.19449 .71614 m .19449 .66056 L .17343 .6541 L p .707 .577 .707 r
F P
0 g
s
.25312 .79579 m .25312 .75873 L .22195 .75683 L p .707 .577 .707 r
F P
0 g
s
.25312 .75873 m .25312 .79579 L .28495 .79501 L p .707 .577 .707 r
F P
0 g
s
.28495 .79501 m .28495 .75795 L .25312 .75873 L p .707 .577 .707 r
F P
0 g
s
.28495 .75795 m .28495 .79501 L .31434 .79163 L p .707 .577 .707 r
F P
0 g
s
.31434 .79163 m .31434 .75457 L .28495 .75795 L p .707 .577 .707 r
F P
0 g
s
.61082 .36251 m .61082 .8644 L .63393 .854 L p .707 .577 .707 r
F P
0 g
s
.63393 .854 m .63393 .35211 L .61082 .36251 L p .707 .577 .707 r
F P
0 g
s
.22195 .79389 m .22195 .75683 L .19449 .75244 L p .707 .577 .707 r
F P
0 g
s
.22195 .75683 m .22195 .79389 L .25312 .79579 L p .707 .577 .707 r
F P
0 g
s
.33839 .65704 m .33839 .71263 L .35476 .70526 L p .707 .577 .707 r
F P
0 g
s
.35476 .70526 m .35476 .64968 L .33839 .65704 L p .707 .577 .707 r
F P
0 g
s
.70195 .83855 m .70195 .85707 L .68936 .84919 L p .707 .577 .707 r
F P
0 g
s
.68936 .84919 m .68936 .83066 L .70195 .83855 L p .707 .577 .707 r
F P
0 g
s
.17343 .6541 m .17343 .70968 L .19449 .71614 L p .707 .577 .707 r
F P
0 g
s
.31434 .75457 m .31434 .79163 L .33839 .78598 L p .707 .577 .707 r
F P
0 g
s
.33839 .78598 m .33839 .74893 L .31434 .75457 L p .707 .577 .707 r
F P
0 g
s
.66831 .65525 m .66831 .71083 L .64085 .70644 L p .707 .577 .707 r
F P
0 g
s
.64085 .70644 m .64085 .65085 L .66831 .65525 L p .707 .577 .707 r
F P
0 g
s
.19449 .75244 m .19449 .78949 L .22195 .79389 L p .707 .577 .707 r
F P
0 g
s
.68936 .75358 m .68936 .79064 L .66831 .78418 L p .707 .577 .707 r
F P
0 g
s
.66831 .78418 m .66831 .74713 L .68936 .75358 L p .707 .577 .707 r
F P
0 g
s
.17343 .70968 m .17343 .6541 L .16084 .64622 L p .707 .577 .707 r
F P
0 g
s
.37794 .86025 m .37794 .35836 L .36016 .34723 L p .707 .577 .707 r
F P
0 g
s
.37794 .35836 m .37794 .86025 L .40766 .86936 L p .707 .577 .707 r
F P
0 g
s
.25312 .85434 m .25312 .83581 L .22195 .83391 L p .707 .577 .707 r
F P
0 g
s
.25312 .83581 m .25312 .85434 L .28495 .85356 L p .707 .577 .707 r
F P
0 g
s
.28495 .85356 m .28495 .83503 L .25312 .83581 L p .707 .577 .707 r
F P
0 g
s
.19449 .78949 m .19449 .75244 L .17343 .74598 L p .707 .577 .707 r
F P
0 g
s
.28495 .83503 m .28495 .85356 L .31434 .85018 L p .707 .577 .707 r
F P
0 g
s
.31434 .85018 m .31434 .83165 L .28495 .83503 L p .707 .577 .707 r
F P
0 g
s
.22195 .83391 m .22195 .85244 L .25312 .85434 L p .707 .577 .707 r
F P
0 g
s
.22195 .85244 m .22195 .83391 L .19449 .82952 L p .707 .577 .707 r
F P
0 g
s
.17343 .74598 m .17343 .78304 L .19449 .78949 L p .707 .577 .707 r
F P
0 g
s
.19449 .82952 m .19449 .84804 L .22195 .85244 L p .707 .577 .707 r
F P
0 g
s
.33839 .74893 m .33839 .78598 L .35476 .77861 L p .707 .577 .707 r
F P
0 g
s
.35476 .77861 m .35476 .74156 L .33839 .74893 L p .707 .577 .707 r
F P
0 g
s
.16084 .64622 m .16084 .7018 L .17343 .70968 L p .707 .577 .707 r
F P
0 g
s
.35476 .64968 m .35476 .70526 L .36184 .69689 L p .707 .577 .707 r
F P
0 g
s
.36184 .69689 m .36184 .64131 L .35476 .64968 L p .707 .577 .707 r
F P
0 g
s
.31434 .83165 m .31434 .85018 L .33839 .84453 L p .707 .577 .707 r
F P
0 g
s
.33839 .84453 m .33839 .826 L .31434 .83165 L p .707 .577 .707 r
F P
0 g
s
.68936 .83066 m .68936 .84919 L .66831 .84273 L p .707 .577 .707 r
F P
0 g
s
.66831 .84273 m .66831 .82421 L .68936 .83066 L p .707 .577 .707 r
F P
0 g
s
.66831 .74713 m .66831 .78418 L .64085 .77979 L p .707 .577 .707 r
F P
0 g
s
.64085 .77979 m .64085 .74274 L .66831 .74713 L p .707 .577 .707 r
F P
0 g
s
.66831 .82421 m .66831 .84273 L .64085 .83834 L p .707 .577 .707 r
F P
0 g
s
.64085 .83834 m .64085 .81982 L .66831 .82421 L p .707 .577 .707 r
F P
0 g
s
.63393 .35211 m .63393 .854 L .64393 .84219 L p .707 .577 .707 r
F P
0 g
s
.64393 .84219 m .64393 .3403 L .63393 .35211 L p .707 .577 .707 r
F P
0 g
s
.19449 .84804 m .19449 .82952 L .17343 .82306 L p .707 .577 .707 r
F P
0 g
s
.17343 .78304 m .17343 .74598 L .16084 .7381 L p .707 .577 .707 r
F P
0 g
s
.16084 .7018 m .16084 .64622 L .15794 .63768 L p .707 .577 .707 r
F P
0 g
s
.17343 .82306 m .17343 .84159 L .19449 .84804 L p .707 .577 .707 r
F P
0 g
s
.16084 .7381 m .16084 .77515 L .17343 .78304 L p .707 .577 .707 r
F P
0 g
s
.33839 .826 m .33839 .84453 L .35476 .83716 L p .707 .577 .707 r
F P
0 g
s
.35476 .83716 m .35476 .81864 L .33839 .826 L p .707 .577 .707 r
F P
0 g
s
.35476 .74156 m .35476 .77861 L .36184 .77025 L p .707 .577 .707 r
F P
0 g
s
.36184 .77025 m .36184 .73319 L .35476 .74156 L p .707 .577 .707 r
F P
0 g
s
.36184 .64131 m .36184 .69689 L .35894 .68835 L p .707 .577 .707 r
F P
0 g
s
.35894 .68835 m .35894 .63277 L .36184 .64131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81864 m .35476 .83716 L .36184 .8288 L p .707 .577 .707 r
F P
0 g
s
.36184 .8288 m .36184 .81027 L .35476 .81864 L p .707 .577 .707 r
F P
0 g
s
.36184 .73319 m .36184 .77025 L .35894 .76171 L p .707 .577 .707 r
F P
0 g
s
.35894 .76171 m .35894 .72465 L .36184 .73319 L p .707 .577 .707 r
F P
0 g
s
.35894 .63277 m .35894 .68835 L .34635 .68047 L p .707 .577 .707 r
F P
0 g
s
.34635 .68047 m .34635 .62489 L .35894 .63277 L p .707 .577 .707 r
F P
0 g
s
.36184 .81027 m .36184 .8288 L .35894 .82026 L p .707 .577 .707 r
F P
0 g
s
.35894 .82026 m .35894 .80173 L .36184 .81027 L p .707 .577 .707 r
F P
0 g
s
.36016 .84912 m .36016 .34723 L .35607 .33517 L p .707 .577 .707 r
F P
0 g
s
.36016 .34723 m .36016 .84912 L .37794 .86025 L p .707 .577 .707 r
F P
0 g
s
.15794 .63768 m .15794 .69326 L .16084 .7018 L p .707 .577 .707 r
F P
0 g
s
.17343 .84159 m .17343 .82306 L .16084 .81518 L p .707 .577 .707 r
F P
0 g
s
.16084 .81518 m .16084 .83371 L .17343 .84159 L p .707 .577 .707 r
F P
0 g
s
.16084 .77515 m .16084 .7381 L .15794 .72956 L p .707 .577 .707 r
F P
0 g
s
.15794 .69326 m .15794 .63768 L .16503 .62931 L p .707 .577 .707 r
F P
0 g
s
.15794 .72956 m .15794 .76661 L .16084 .77515 L p .707 .577 .707 r
F P
0 g
s
.64393 .3403 m .64393 .84219 L .63984 .83013 L p .707 .577 .707 r
F P
0 g
s
.63984 .83013 m .63984 .32824 L .64393 .3403 L p .707 .577 .707 r
F P
0 g
s
.16503 .62931 m .16503 .68489 L .15794 .69326 L p .707 .577 .707 r
F P
0 g
s
.16084 .83371 m .16084 .81518 L .15794 .80664 L p .707 .577 .707 r
F P
0 g
s
.15794 .80664 m .15794 .82516 L .16084 .83371 L p .707 .577 .707 r
F P
0 g
s
.35894 .72465 m .35894 .76171 L .34635 .75382 L p .707 .577 .707 r
F P
0 g
s
.34635 .75382 m .34635 .71677 L .35894 .72465 L p .707 .577 .707 r
F P
0 g
s
.35894 .80173 m .35894 .82026 L .34635 .81237 L p .707 .577 .707 r
F P
0 g
s
.34635 .81237 m .34635 .79385 L .35894 .80173 L p .707 .577 .707 r
F P
0 g
s
.35607 .33517 m .35607 .83706 L .36016 .84912 L p .707 .577 .707 r
F P
0 g
s
.35607 .83706 m .35607 .33517 L .36607 .32336 L p .707 .577 .707 r
F P
0 g
s
.15794 .76661 m .15794 .72956 L .16503 .72119 L p .707 .577 .707 r
F P
0 g
s
.16503 .68489 m .16503 .62931 L .1814 .62194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72119 m .16503 .75825 L .15794 .76661 L p .707 .577 .707 r
F P
0 g
s
.1814 .62194 m .1814 .67753 L .16503 .68489 L p .707 .577 .707 r
F P
0 g
s
.34635 .62489 m .34635 .68047 L .3253 .67401 L p .707 .577 .707 r
F P
0 g
s
.3253 .67401 m .3253 .61843 L .34635 .62489 L p .707 .577 .707 r
F P
0 g
s
.15794 .82516 m .15794 .80664 L .16503 .79827 L p .707 .577 .707 r
F P
0 g
s
.63984 .32824 m .63984 .83013 L .62206 .819 L p .707 .577 .707 r
F P
0 g
s
.62206 .819 m .62206 .31711 L .63984 .32824 L p .707 .577 .707 r
F P
0 g
s
.16503 .79827 m .16503 .8168 L .15794 .82516 L p .707 .577 .707 r
F P
0 g
s
.16503 .75825 m .16503 .72119 L .1814 .71383 L p .707 .577 .707 r
F P
0 g
s
.1814 .67753 m .1814 .62194 L .20545 .61629 L p .707 .577 .707 r
F P
0 g
s
.1814 .71383 m .1814 .75088 L .16503 .75825 L p .707 .577 .707 r
F P
0 g
s
.36607 .82525 m .36607 .32336 L .38918 .31296 L p .707 .577 .707 r
F P
0 g
s
.36607 .32336 m .36607 .82525 L .35607 .83706 L p .707 .577 .707 r
F P
0 g
s
.3253 .61843 m .3253 .67401 L .29784 .66962 L p .707 .577 .707 r
F P
0 g
s
.29784 .66962 m .29784 .61404 L .3253 .61843 L p .707 .577 .707 r
F P
0 g
s
.34635 .71677 m .34635 .75382 L .3253 .74737 L p .707 .577 .707 r
F P
0 g
s
.3253 .74737 m .3253 .71031 L .34635 .71677 L p .707 .577 .707 r
F P
0 g
s
.20545 .61629 m .20545 .67188 L .1814 .67753 L p .707 .577 .707 r
F P
0 g
s
.20545 .67188 m .20545 .61629 L .23483 .61292 L p .707 .577 .707 r
F P
0 g
s
.16503 .8168 m .16503 .79827 L .1814 .79091 L p .707 .577 .707 r
F P
0 g
s
.1814 .75088 m .1814 .71383 L .20545 .70818 L p .707 .577 .707 r
F P
0 g
s
.1814 .79091 m .1814 .80943 L .16503 .8168 L p .707 .577 .707 r
F P
0 g
s
.29784 .61404 m .29784 .66962 L .26667 .66772 L p .707 .577 .707 r
F P
0 g
s
.26667 .66772 m .26667 .61214 L .29784 .61404 L p .707 .577 .707 r
F P
0 g
s
.23483 .6685 m .23483 .61292 L .26667 .61214 L p .707 .577 .707 r
F P
0 g
s
.23483 .61292 m .23483 .6685 L .20545 .67188 L p .707 .577 .707 r
F P
0 g
s
.62206 .31711 m .62206 .819 L .59233 .80989 L p .707 .577 .707 r
F P
0 g
s
.59233 .80989 m .59233 .308 L .62206 .31711 L p .707 .577 .707 r
F P
0 g
s
.26667 .61214 m .26667 .66772 L .23483 .6685 L p .707 .577 .707 r
F P
0 g
s
.20545 .70818 m .20545 .74523 L .1814 .75088 L p .707 .577 .707 r
F P
0 g
s
.34635 .79385 m .34635 .81237 L .3253 .80592 L p .707 .577 .707 r
F P
0 g
s
.3253 .80592 m .3253 .78739 L .34635 .79385 L p .707 .577 .707 r
F P
0 g
s
.73333 .66721 m .73333 .61163 L .70216 .60973 L p .707 .577 .707 r
F P
0 g
s
.73333 .61163 m .73333 .66721 L .76517 .66643 L p .707 .577 .707 r
F P
0 g
s
.76517 .66643 m .76517 .61085 L .73333 .61163 L p .707 .577 .707 r
F P
0 g
s
.3253 .71031 m .3253 .74737 L .29784 .74298 L p .707 .577 .707 r
F P
0 g
s
.29784 .74298 m .29784 .70592 L .3253 .71031 L p .707 .577 .707 r
F P
0 g
s
.76517 .61085 m .76517 .66643 L .79455 .66305 L p .707 .577 .707 r
F P
0 g
s
.79455 .66305 m .79455 .60747 L .76517 .61085 L p .707 .577 .707 r
F P
0 g
s
.70216 .66531 m .70216 .60973 L .6747 .60533 L p .707 .577 .707 r
F P
0 g
s
.70216 .60973 m .70216 .66531 L .73333 .66721 L p .707 .577 .707 r
F P
0 g
s
.20545 .74523 m .20545 .70818 L .23483 .7048 L p .707 .577 .707 r
F P
0 g
s
.1814 .80943 m .1814 .79091 L .20545 .78526 L p .707 .577 .707 r
F P
0 g
s
.38918 .31296 m .38918 .81485 L .36607 .82525 L p .707 .577 .707 r
F P
0 g
s
.38918 .81485 m .38918 .31296 L .42314 .30498 L p .707 .577 .707 r
F P
0 g
s
.79455 .60747 m .79455 .66305 L .8186 .6574 L p .707 .577 .707 r
F P
0 g
s
.8186 .6574 m .8186 .60182 L .79455 .60747 L p .707 .577 .707 r
F P
0 g
s
.20545 .78526 m .20545 .80378 L .1814 .80943 L p .707 .577 .707 r
F P
0 g
s
.29784 .70592 m .29784 .74298 L .26667 .74107 L p .707 .577 .707 r
F P
0 g
s
.26667 .74107 m .26667 .70402 L .29784 .70592 L p .707 .577 .707 r
F P
0 g
s
.23483 .7048 m .23483 .74185 L .20545 .74523 L p .707 .577 .707 r
F P
0 g
s
.23483 .74185 m .23483 .7048 L .26667 .70402 L p .707 .577 .707 r
F P
0 g
s
.6747 .60533 m .6747 .66092 L .70216 .66531 L p .707 .577 .707 r
F P
0 g
s
.6747 .66092 m .6747 .60533 L .65365 .59888 L p .707 .577 .707 r
F P
0 g
s
.3253 .78739 m .3253 .80592 L .29784 .80153 L p .707 .577 .707 r
F P
0 g
s
.29784 .80153 m .29784 .783 L .3253 .78739 L p .707 .577 .707 r
F P
0 g
s
.26667 .70402 m .26667 .74107 L .23483 .74185 L p .707 .577 .707 r
F P
0 g
s
.73333 .74056 m .73333 .70351 L .70216 .70161 L p .707 .577 .707 r
F P
0 g
s
.73333 .70351 m .73333 .74056 L .76517 .73979 L p .707 .577 .707 r
F P
0 g
s
.76517 .73979 m .76517 .70273 L .73333 .70351 L p .707 .577 .707 r
F P
0 g
s
.76517 .70273 m .76517 .73979 L .79455 .73641 L p .707 .577 .707 r
F P
0 g
s
.79455 .73641 m .79455 .69935 L .76517 .70273 L p .707 .577 .707 r
F P
0 g
s
.59233 .308 m .59233 .80989 L .55357 .80369 L p .707 .577 .707 r
F P
0 g
s
.55357 .80369 m .55357 .3018 L .59233 .308 L p .707 .577 .707 r
F P
0 g
s
.20545 .80378 m .20545 .78526 L .23483 .78188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73866 m .70216 .70161 L .6747 .69722 L p .707 .577 .707 r
F P
0 g
s
.70216 .70161 m .70216 .73866 L .73333 .74056 L p .707 .577 .707 r
F P
0 g
s
.8186 .60182 m .8186 .6574 L .83497 .65003 L p .707 .577 .707 r
F P
0 g
s
.83497 .65003 m .83497 .59445 L .8186 .60182 L p .707 .577 .707 r
F P
0 g
s
.23483 .78188 m .23483 .8004 L .20545 .80378 L p .707 .577 .707 r
F P
0 g
s
.65365 .59888 m .65365 .65446 L .6747 .66092 L p .707 .577 .707 r
F P
0 g
s
.29784 .783 m .29784 .80153 L .26667 .79963 L p .707 .577 .707 r
F P
0 g
s
.26667 .79963 m .26667 .7811 L .29784 .783 L p .707 .577 .707 r
F P
0 g
s
.42314 .80687 m .42314 .30498 L .46462 .30021 L p .707 .577 .707 r
F P
0 g
s
.42314 .30498 m .42314 .80687 L .38918 .81485 L p .707 .577 .707 r
F P
0 g
s
.79455 .69935 m .79455 .73641 L .8186 .73076 L p .707 .577 .707 r
F P
0 g
s
.8186 .73076 m .8186 .6937 L .79455 .69935 L p .707 .577 .707 r
F P
0 g
s
.23483 .8004 m .23483 .78188 L .26667 .7811 L p .707 .577 .707 r
F P
0 g
s
.6747 .69722 m .6747 .73427 L .70216 .73866 L p .707 .577 .707 r
F P
0 g
s
.26667 .7811 m .26667 .79963 L .23483 .8004 L p .707 .577 .707 r
F P
0 g
s
.65365 .65446 m .65365 .59888 L .64105 .591 L p .707 .577 .707 r
F P
0 g
s
.73333 .79911 m .73333 .78059 L .70216 .77869 L p .707 .577 .707 r
F P
0 g
s
.73333 .78059 m .73333 .79911 L .76517 .79834 L p .707 .577 .707 r
F P
0 g
s
.76517 .79834 m .76517 .77981 L .73333 .78059 L p .707 .577 .707 r
F P
0 g
s
.6747 .73427 m .6747 .69722 L .65365 .69076 L p .707 .577 .707 r
F P
0 g
s
.76517 .77981 m .76517 .79834 L .79455 .79496 L p .707 .577 .707 r
F P
0 g
s
.79455 .79496 m .79455 .77643 L .76517 .77981 L p .707 .577 .707 r
F P
0 g
s
.55357 .3018 m .55357 .80369 L .50956 .80101 L p .707 .577 .707 r
F P
0 g
s
.50956 .80101 m .50956 .29912 L .55357 .3018 L p .707 .577 .707 r
F P
0 g
s
.70216 .77869 m .70216 .79721 L .73333 .79911 L p .707 .577 .707 r
F P
0 g
s
.70216 .79721 m .70216 .77869 L .6747 .77429 L p .707 .577 .707 r
F P
0 g
s
.46462 .8021 m .46462 .30021 L .50956 .29912 L p .707 .577 .707 r
F P
0 g
s
.46462 .30021 m .46462 .8021 L .42314 .80687 L p .707 .577 .707 r
F P
0 g
s
.65365 .69076 m .65365 .72782 L .6747 .73427 L p .707 .577 .707 r
F P
0 g
s
.6747 .77429 m .6747 .79282 L .70216 .79721 L p .707 .577 .707 r
F P
0 g
s
.8186 .6937 m .8186 .73076 L .83497 .72339 L p .707 .577 .707 r
F P
0 g
s
.83497 .72339 m .83497 .68633 L .8186 .6937 L p .707 .577 .707 r
F P
0 g
s
.64105 .591 m .64105 .64658 L .65365 .65446 L p .707 .577 .707 r
F P
0 g
s
.50956 .29912 m .50956 .80101 L .46462 .8021 L p .707 .577 .707 r
F P
0 g
s
.83497 .59445 m .83497 .65003 L .84205 .64167 L p .707 .577 .707 r
F P
0 g
s
.84205 .64167 m .84205 .58609 L .83497 .59445 L p .707 .577 .707 r
F P
0 g
s
.79455 .77643 m .79455 .79496 L .8186 .78931 L p .707 .577 .707 r
F P
0 g
s
.8186 .78931 m .8186 .77078 L .79455 .77643 L p .707 .577 .707 r
F P
0 g
s
.6747 .79282 m .6747 .77429 L .65365 .76784 L p .707 .577 .707 r
F P
0 g
s
.65365 .72782 m .65365 .69076 L .64105 .68288 L p .707 .577 .707 r
F P
0 g
s
.64105 .64658 m .64105 .591 L .63816 .58245 L p .707 .577 .707 r
F P
0 g
s
.65365 .76784 m .65365 .78637 L .6747 .79282 L p .707 .577 .707 r
F P
0 g
s
.64105 .68288 m .64105 .71993 L .65365 .72782 L p .707 .577 .707 r
F P
0 g
s
.8186 .77078 m .8186 .78931 L .83497 .78194 L p .707 .577 .707 r
F P
0 g
s
.83497 .78194 m .83497 .76341 L .8186 .77078 L p .707 .577 .707 r
F P
0 g
s
.83497 .68633 m .83497 .72339 L .84206 .71502 L p .707 .577 .707 r
F P
0 g
s
.84206 .71502 m .84206 .67797 L .83497 .68633 L p .707 .577 .707 r
F P
0 g
s
.63816 .58245 m .63816 .63804 L .64105 .64658 L p .707 .577 .707 r
F P
0 g
s
.84205 .58609 m .84205 .64167 L .83916 .63313 L p .707 .577 .707 r
F P
0 g
s
.83916 .63313 m .83916 .57755 L .84205 .58609 L p .707 .577 .707 r
F P
0 g
s
.65365 .78637 m .65365 .76784 L .64105 .75996 L p .707 .577 .707 r
F P
0 g
s
.64105 .75996 m .64105 .77848 L .65365 .78637 L p .707 .577 .707 r
F P
0 g
s
.64105 .71993 m .64105 .68288 L .63816 .67433 L p .707 .577 .707 r
F P
0 g
s
.63816 .63804 m .63816 .58245 L .64524 .57409 L p .707 .577 .707 r
F P
0 g
s
.83497 .76341 m .83497 .78194 L .84206 .77358 L p .707 .577 .707 r
F P
0 g
s
.84206 .77358 m .84206 .75505 L .83497 .76341 L p .707 .577 .707 r
F P
0 g
s
.63816 .67433 m .63816 .71139 L .64105 .71993 L p .707 .577 .707 r
F P
0 g
s
.84206 .67797 m .84206 .71502 L .83916 .70648 L p .707 .577 .707 r
F P
0 g
s
.83916 .70648 m .83916 .66943 L .84206 .67797 L p .707 .577 .707 r
F P
0 g
s
.64524 .57409 m .64524 .62967 L .63816 .63804 L p .707 .577 .707 r
F P
0 g
s
.64105 .77848 m .64105 .75996 L .63816 .75141 L p .707 .577 .707 r
F P
0 g
s
.83916 .57755 m .83916 .63313 L .82657 .62524 L p .707 .577 .707 r
F P
0 g
s
.82657 .62524 m .82657 .56966 L .83916 .57755 L p .707 .577 .707 r
F P
0 g
s
.63816 .75141 m .63816 .76994 L .64105 .77848 L p .707 .577 .707 r
F P
0 g
s
.63816 .71139 m .63816 .67433 L .64524 .66597 L p .707 .577 .707 r
F P
0 g
s
.39032 .63039 m .39032 .57481 L .35915 .57291 L p .707 .577 .707 r
F P
0 g
s
.39032 .57481 m .39032 .63039 L .42216 .62962 L p .707 .577 .707 r
F P
0 g
s
.42216 .62962 m .42216 .57403 L .39032 .57481 L p .707 .577 .707 r
F P
0 g
s
.64524 .62967 m .64524 .57409 L .66161 .56672 L p .707 .577 .707 r
F P
0 g
s
.42216 .57403 m .42216 .62962 L .45154 .62624 L p .707 .577 .707 r
F P
0 g
s
.45154 .62624 m .45154 .57065 L .42216 .57403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84206 .75505 m .84206 .77358 L .83916 .76503 L p .707 .577 .707 r
F P
0 g
s
.83916 .76503 m .83916 .74651 L .84206 .75505 L p .707 .577 .707 r
F P
0 g
s
.35915 .62849 m .35915 .57291 L .33169 .56852 L p .707 .577 .707 r
F P
0 g
s
.35915 .57291 m .35915 .62849 L .39032 .63039 L p .707 .577 .707 r
F P
0 g
s
.64524 .66597 m .64524 .70303 L .63816 .71139 L p .707 .577 .707 r
F P
0 g
s
.45154 .57065 m .45154 .62624 L .47559 .62059 L p .707 .577 .707 r
F P
0 g
s
.47559 .62059 m .47559 .565 L .45154 .57065 L p .707 .577 .707 r
F P
0 g
s
.83916 .66943 m .83916 .70648 L .82657 .6986 L p .707 .577 .707 r
F P
0 g
s
.82657 .6986 m .82657 .66154 L .83916 .66943 L p .707 .577 .707 r
F P
0 g
s
.66161 .56672 m .66161 .6223 L .64524 .62967 L p .707 .577 .707 r
F P
0 g
s
.82657 .56966 m .82657 .62524 L .80551 .61879 L p .707 .577 .707 r
F P
0 g
s
.80551 .61879 m .80551 .56321 L .82657 .56966 L p .707 .577 .707 r
F P
0 g
s
.63816 .76994 m .63816 .75141 L .64524 .74305 L p .707 .577 .707 r
F P
0 g
s
.33169 .56852 m .33169 .6241 L .35915 .62849 L p .707 .577 .707 r
F P
0 g
s
.33169 .6241 m .33169 .56852 L .31064 .56206 L p .707 .577 .707 r
F P
0 g
s
.64524 .74305 m .64524 .76158 L .63816 .76994 L p .707 .577 .707 r
F P
0 g
s
.39032 .70375 m .39032 .66669 L .35915 .66479 L p .707 .577 .707 r
F P
0 g
s
.39032 .66669 m .39032 .70375 L .42216 .70297 L p .707 .577 .707 r
F P
0 g
s
.42216 .70297 m .42216 .66592 L .39032 .66669 L p .707 .577 .707 r
F P
0 g
s
.64524 .70303 m .64524 .66597 L .66161 .6586 L p .707 .577 .707 r
F P
0 g
s
.42216 .66592 m .42216 .70297 L .45154 .69959 L p .707 .577 .707 r
F P
0 g
s
.45154 .69959 m .45154 .66254 L .42216 .66592 L p .707 .577 .707 r
F P
0 g
s
.66161 .6223 m .66161 .56672 L .68566 .56107 L p .707 .577 .707 r
F P
0 g
s
.35915 .70185 m .35915 .66479 L .33169 .6604 L p .707 .577 .707 r
F P
0 g
s
.35915 .66479 m .35915 .70185 L .39032 .70375 L p .707 .577 .707 r
F P
0 g
s
.47559 .565 m .47559 .62059 L .49196 .61322 L p .707 .577 .707 r
F P
0 g
s
.49196 .61322 m .49196 .55764 L .47559 .565 L p .707 .577 .707 r
F P
0 g
s
.83916 .74651 m .83916 .76503 L .82657 .75715 L p .707 .577 .707 r
F P
0 g
s
.82657 .75715 m .82657 .73862 L .83916 .74651 L p .707 .577 .707 r
F P
0 g
s
.31064 .56206 m .31064 .61765 L .33169 .6241 L p .707 .577 .707 r
F P
0 g
s
.66161 .6586 m .66161 .69566 L .64524 .70303 L p .707 .577 .707 r
F P
0 g
s
.45154 .66254 m .45154 .69959 L .47559 .69394 L p .707 .577 .707 r
F P
0 g
s
.47559 .69394 m .47559 .65689 L .45154 .66254 L p .707 .577 .707 r
F P
0 g
s
.80551 .56321 m .80551 .61879 L .77805 .6144 L p .707 .577 .707 r
F P
0 g
s
.77805 .6144 m .77805 .55882 L .80551 .56321 L p .707 .577 .707 r
F P
0 g
s
.33169 .6604 m .33169 .69745 L .35915 .70185 L p .707 .577 .707 r
F P
0 g
s
.82657 .66154 m .82657 .6986 L .80551 .69214 L p .707 .577 .707 r
F P
0 g
s
.80551 .69214 m .80551 .65509 L .82657 .66154 L p .707 .577 .707 r
F P
0 g
s
.68566 .56107 m .68566 .61665 L .66161 .6223 L p .707 .577 .707 r
F P
0 g
s
.31064 .61765 m .31064 .56206 L .29804 .55418 L p .707 .577 .707 r
F P
0 g
s
.39032 .7623 m .39032 .74377 L .35915 .74187 L p .707 .577 .707 r
F P
0 g
s
.39032 .74377 m .39032 .7623 L .42216 .76152 L p .707 .577 .707 r
F P
0 g
s
.42216 .76152 m .42216 .74299 L .39032 .74377 L p .707 .577 .707 r
F P
0 g
s
.33169 .69745 m .33169 .6604 L .31064 .65395 L p .707 .577 .707 r
F P
0 g
s
.68566 .61665 m .68566 .56107 L .71504 .55769 L p .707 .577 .707 r
F P
0 g
s
.64524 .76158 m .64524 .74305 L .66161 .73568 L p .707 .577 .707 r
F P
0 g
s
.42216 .74299 m .42216 .76152 L .45154 .75814 L p .707 .577 .707 r
F P
0 g
s
.45154 .75814 m .45154 .73962 L .42216 .74299 L p .707 .577 .707 r
F P
0 g
s
.35915 .74187 m .35915 .7604 L .39032 .7623 L p .707 .577 .707 r
F P
0 g
s
.35915 .7604 m .35915 .74187 L .33169 .73748 L p .707 .577 .707 r
F P
0 g
s
.66161 .69566 m .66161 .6586 L .68566 .65295 L p .707 .577 .707 r
F P
0 g
s
.66161 .73568 m .66161 .75421 L .64524 .76158 L p .707 .577 .707 r
F P
0 g
s
.77805 .55882 m .77805 .6144 L .74688 .6125 L p .707 .577 .707 r
F P
0 g
s
.74688 .6125 m .74688 .55691 L .77805 .55882 L p .707 .577 .707 r
F P
0 g
s
.31064 .65395 m .31064 .691 L .33169 .69745 L p .707 .577 .707 r
F P
0 g
s
.33169 .73748 m .33169 .75601 L .35915 .7604 L p .707 .577 .707 r
F P
0 g
s
.47559 .65689 m .47559 .69394 L .49196 .68657 L p .707 .577 .707 r
F P
0 g
s
.49196 .68657 m .49196 .64952 L .47559 .65689 L p .707 .577 .707 r
F P
0 g
s
.29804 .55418 m .29804 .60976 L .31064 .61765 L p .707 .577 .707 r
F P
0 g
s
.71504 .61327 m .71504 .55769 L .74688 .55691 L p .707 .577 .707 r
F P
0 g
s
.71504 .55769 m .71504 .61327 L .68566 .61665 L p .707 .577 .707 r
F P
0 g
s
.49196 .55764 m .49196 .61322 L .49904 .60485 L p .707 .577 .707 r
F P
0 g
s
.49904 .60485 m .49904 .54927 L .49196 .55764 L p .707 .577 .707 r
F P
0 g
s
.45154 .73962 m .45154 .75814 L .47559 .75249 L p .707 .577 .707 r
F P
0 g
s
.47559 .75249 m .47559 .73397 L .45154 .73962 L p .707 .577 .707 r
F P
0 g
s
.74688 .55691 m .74688 .6125 L .71504 .61327 L p .707 .577 .707 r
F P
0 g
s
.68566 .65295 m .68566 .69001 L .66161 .69566 L p .707 .577 .707 r
F P
0 g
s
.82657 .73862 m .82657 .75715 L .80551 .7507 L p .707 .577 .707 r
F P
0 g
s
.80551 .7507 m .80551 .73217 L .82657 .73862 L p .707 .577 .707 r
F P
0 g
s
.80551 .65509 m .80551 .69214 L .77805 .68775 L p .707 .577 .707 r
F P
0 g
s
.77805 .68775 m .77805 .6507 L .80551 .65509 L p .707 .577 .707 r
F P
0 g
s
.33169 .75601 m .33169 .73748 L .31064 .73103 L p .707 .577 .707 r
F P
0 g
s
.31064 .691 m .31064 .65395 L .29804 .64606 L p .707 .577 .707 r
F P
0 g
s
.29804 .60976 m .29804 .55418 L .29515 .54564 L p .707 .577 .707 r
F P
0 g
s
.31064 .73103 m .31064 .74955 L .33169 .75601 L p .707 .577 .707 r
F P
0 g
s
.68566 .69001 m .68566 .65295 L .71504 .64957 L p .707 .577 .707 r
F P
0 g
s
.66161 .75421 m .66161 .73568 L .68566 .73003 L p .707 .577 .707 r
F P
0 g
s
.68566 .73003 m .68566 .74856 L .66161 .75421 L p .707 .577 .707 r
F P
0 g
s
.29804 .64606 m .29804 .68312 L .31064 .691 L p .707 .577 .707 r
F P
0 g
s
.47559 .73397 m .47559 .75249 L .49196 .74513 L p .707 .577 .707 r
F P
0 g
s
.49196 .74513 m .49196 .7266 L .47559 .73397 L p .707 .577 .707 r
F P
0 g
s
.77805 .6507 m .77805 .68775 L .74688 .68585 L p .707 .577 .707 r
F P
0 g
s
.74688 .68585 m .74688 .6488 L .77805 .6507 L p .707 .577 .707 r
F P
0 g
s
.71504 .64957 m .71504 .68663 L .68566 .69001 L p .707 .577 .707 r
F P
0 g
s
.71504 .68663 m .71504 .64957 L .74688 .6488 L p .707 .577 .707 r
F P
0 g
s
.49196 .64952 m .49196 .68657 L .49904 .67821 L p .707 .577 .707 r
F P
0 g
s
.49904 .67821 m .49904 .64115 L .49196 .64952 L p .707 .577 .707 r
F P
0 g
s
.80551 .73217 m .80551 .7507 L .77805 .7463 L p .707 .577 .707 r
F P
0 g
s
.77805 .7463 m .77805 .72778 L .80551 .73217 L p .707 .577 .707 r
F P
0 g
s
.29515 .54564 m .29515 .60122 L .29804 .60976 L p .707 .577 .707 r
F P
0 g
s
.74688 .6488 m .74688 .68585 L .71504 .68663 L p .707 .577 .707 r
F P
0 g
s
.49904 .54927 m .49904 .60485 L .49615 .59631 L p .707 .577 .707 r
F P
0 g
s
.49615 .59631 m .49615 .54073 L .49904 .54927 L p .707 .577 .707 r
F P
0 g
s
.31064 .74955 m .31064 .73103 L .29804 .72314 L p .707 .577 .707 r
F P
0 g
s
.68566 .74856 m .68566 .73003 L .71504 .72665 L p .707 .577 .707 r
F P
0 g
s
.29804 .72314 m .29804 .74167 L .31064 .74955 L p .707 .577 .707 r
F P
0 g
s
.29804 .68312 m .29804 .64606 L .29515 .63752 L p .707 .577 .707 r
F P
0 g
s
.71504 .72665 m .71504 .74518 L .68566 .74856 L p .707 .577 .707 r
F P
0 g
s
.77805 .72778 m .77805 .7463 L .74688 .7444 L p .707 .577 .707 r
F P
0 g
s
.74688 .7444 m .74688 .72588 L .77805 .72778 L p .707 .577 .707 r
F P
0 g
s
.29515 .60122 m .29515 .54564 L .30223 .53727 L p .707 .577 .707 r
F P
0 g
s
.71504 .74518 m .71504 .72665 L .74688 .72588 L p .707 .577 .707 r
F P
0 g
s
.49196 .7266 m .49196 .74513 L .49904 .73676 L p .707 .577 .707 r
F P
0 g
s
.49904 .73676 m .49904 .71823 L .49196 .7266 L p .707 .577 .707 r
F P
0 g
s
.29515 .63752 m .29515 .67457 L .29804 .68312 L p .707 .577 .707 r
F P
0 g
s
.74688 .72588 m .74688 .7444 L .71504 .74518 L p .707 .577 .707 r
F P
0 g
s
.49904 .64115 m .49904 .67821 L .49615 .66967 L p .707 .577 .707 r
F P
0 g
s
.49615 .66967 m .49615 .63261 L .49904 .64115 L p .707 .577 .707 r
F P
0 g
s
.30223 .53727 m .30223 .59286 L .29515 .60122 L p .707 .577 .707 r
F P
0 g
s
.29804 .74167 m .29804 .72314 L .29515 .7146 L p .707 .577 .707 r
F P
0 g
s
.49615 .54073 m .49615 .59631 L .48356 .58843 L p .707 .577 .707 r
F P
0 g
s
.48356 .58843 m .48356 .53285 L .49615 .54073 L p .707 .577 .707 r
F P
0 g
s
.29515 .7146 m .29515 .73313 L .29804 .74167 L p .707 .577 .707 r
F P
0 g
s
.29515 .67457 m .29515 .63752 L .30223 .62915 L p .707 .577 .707 r
F P
0 g
s
.30223 .59286 m .30223 .53727 L .3186 .52991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49904 .71823 m .49904 .73676 L .49615 .72822 L p .707 .577 .707 r
F P
0 g
s
.49615 .72822 m .49615 .70969 L .49904 .71823 L p .707 .577 .707 r
F P
0 g
s
.30223 .62915 m .30223 .66621 L .29515 .67457 L p .707 .577 .707 r
F P
0 g
s
.49615 .63261 m .49615 .66967 L .48356 .66178 L p .707 .577 .707 r
F P
0 g
s
.48356 .66178 m .48356 .62473 L .49615 .63261 L p .707 .577 .707 r
F P
0 g
s
.3186 .52991 m .3186 .58549 L .30223 .59286 L p .707 .577 .707 r
F P
0 g
s
.48356 .53285 m .48356 .58843 L .4625 .58197 L p .707 .577 .707 r
F P
0 g
s
.4625 .58197 m .4625 .52639 L .48356 .53285 L p .707 .577 .707 r
F P
0 g
s
.29515 .73313 m .29515 .7146 L .30223 .70623 L p .707 .577 .707 r
F P
0 g
s
.30223 .70623 m .30223 .72476 L .29515 .73313 L p .707 .577 .707 r
F P
0 g
s
.30223 .66621 m .30223 .62915 L .3186 .62179 L p .707 .577 .707 r
F P
0 g
s
.3186 .58549 m .3186 .52991 L .34265 .52426 L p .707 .577 .707 r
F P
0 g
s
.49615 .70969 m .49615 .72822 L .48356 .72034 L p .707 .577 .707 r
F P
0 g
s
.48356 .72034 m .48356 .70181 L .49615 .70969 L p .707 .577 .707 r
F P
0 g
s
.3186 .62179 m .3186 .65884 L .30223 .66621 L p .707 .577 .707 r
F P
0 g
s
.4625 .52639 m .4625 .58197 L .43504 .57758 L p .707 .577 .707 r
F P
0 g
s
.43504 .57758 m .43504 .522 L .4625 .52639 L p .707 .577 .707 r
F P
0 g
s
.48356 .62473 m .48356 .66178 L .4625 .65533 L p .707 .577 .707 r
F P
0 g
s
.4625 .65533 m .4625 .61827 L .48356 .62473 L p .707 .577 .707 r
F P
0 g
s
.34265 .52426 m .34265 .57984 L .3186 .58549 L p .707 .577 .707 r
F P
0 g
s
.34265 .57984 m .34265 .52426 L .37203 .52088 L p .707 .577 .707 r
F P
0 g
s
.30223 .72476 m .30223 .70623 L .3186 .69887 L p .707 .577 .707 r
F P
0 g
s
.3186 .65884 m .3186 .62179 L .34265 .61614 L p .707 .577 .707 r
F P
0 g
s
.3186 .69887 m .3186 .71739 L .30223 .72476 L p .707 .577 .707 r
F P
0 g
s
.43504 .522 m .43504 .57758 L .40387 .57568 L p .707 .577 .707 r
F P
0 g
s
.40387 .57568 m .40387 .5201 L .43504 .522 L p .707 .577 .707 r
F P
0 g
s
.37203 .57646 m .37203 .52088 L .40387 .5201 L p .707 .577 .707 r
F P
0 g
s
.37203 .52088 m .37203 .57646 L .34265 .57984 L p .707 .577 .707 r
F P
0 g
s
.40387 .5201 m .40387 .57568 L .37203 .57646 L p .707 .577 .707 r
F P
0 g
s
.34265 .61614 m .34265 .65319 L .3186 .65884 L p .707 .577 .707 r
F P
0 g
s
.48356 .70181 m .48356 .72034 L .4625 .71388 L p .707 .577 .707 r
F P
0 g
s
.4625 .71388 m .4625 .69535 L .48356 .70181 L p .707 .577 .707 r
F P
0 g
s
.4625 .61827 m .4625 .65533 L .43504 .65094 L p .707 .577 .707 r
F P
0 g
s
.43504 .65094 m .43504 .61388 L .4625 .61827 L p .707 .577 .707 r
F P
0 g
s
.34265 .65319 m .34265 .61614 L .37203 .61276 L p .707 .577 .707 r
F P
0 g
s
.3186 .71739 m .3186 .69887 L .34265 .69322 L p .707 .577 .707 r
F P
0 g
s
.34265 .69322 m .34265 .71174 L .3186 .71739 L p .707 .577 .707 r
F P
0 g
s
.43504 .61388 m .43504 .65094 L .40387 .64904 L p .707 .577 .707 r
F P
0 g
s
.40387 .64904 m .40387 .61198 L .43504 .61388 L p .707 .577 .707 r
F P
0 g
s
.37203 .61276 m .37203 .64981 L .34265 .65319 L p .707 .577 .707 r
F P
0 g
s
.37203 .64981 m .37203 .61276 L .40387 .61198 L p .707 .577 .707 r
F P
0 g
s
.4625 .69535 m .4625 .71388 L .43504 .70949 L p .707 .577 .707 r
F P
0 g
s
.43504 .70949 m .43504 .69096 L .4625 .69535 L p .707 .577 .707 r
F P
0 g
s
.40387 .61198 m .40387 .64904 L .37203 .64981 L p .707 .577 .707 r
F P
0 g
s
.34265 .71174 m .34265 .69322 L .37203 .68984 L p .707 .577 .707 r
F P
0 g
s
.37203 .68984 m .37203 .70837 L .34265 .71174 L p .707 .577 .707 r
F P
0 g
s
.43504 .69096 m .43504 .70949 L .40387 .70759 L p .707 .577 .707 r
F P
0 g
s
.40387 .70759 m .40387 .68906 L .43504 .69096 L p .707 .577 .707 r
F P
0 g
s
.37203 .70837 m .37203 .68984 L .40387 .68906 L p .707 .577 .707 r
F P
0 g
s
.40387 .68906 m .40387 .70759 L .37203 .70837 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo
001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo2@0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?OolH
000nOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH3000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH007oo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000=JEP<0
009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH0
05YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJ
EP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH0
1EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEPH0009JEP03001JEUYF00=JEP03001JEUYF00IJEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`0000AJEP000000009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01P00FUH0
0000FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YF
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0`00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008
FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/
Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo
00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH900000eYF001JEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF200015YF
00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004
FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF000000060003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF2P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1@000eYF00@005YFFUIJEP8001aoo`@00003FUH005YF
009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPH000=JEP8001Eoo`L000=JEP<000=JEP80
02eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUH90009Ool90003FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEQP000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00<7oo0`0015YF
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF
5`001UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000c
Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP03
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000aOol30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF00000002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01UYF1@000eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF0P0000Eoo`00
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEP0000<000=JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00FUH20003FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEQP0009J
EP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<0009JEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30000
1EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0UYF100000=JEP00FUH01P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF
0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20003FUH00`00FUH000020005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP<0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00UYF1P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJ
EP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF4@0015YF00D005YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00;7oo00<005YF000015YF00<005YFFUH00eYF1P004Goo1P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00
FUH00004FUH00`00FUH00003000MOol30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH7000OOol30003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUH00004000NOol50004FUH01@00FUIJEUYF0000;Woo000/Ool01000FUH005YF0P001EYF
00<005YF00000`006Goo2P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF0P008Woo0`0000=JEP00FUH00UYF0P00;Goo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH3000SOol2
0003FUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF00<005YFFUH00eYF00<005YFFUH00P008goo0P0000=JEP000000;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
100015YF00<005YFFUH00eYF00D005YFFUIJEP0002Aoo`@002eoo`00;7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000QOol2000015YF00000000;Goo000]Ool01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEP00008000EJEP04001JEUYFFUH2000LOol50003FUH00`00FUH0000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF1P000eYF0P005Goo1`000eYF00<005YFFUH00UYF0P00;Woo000^Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP80
02ioo`00<7oo0`0015YF00<005YFFUH01EYF6@0000=JEP00FUH01EYF00H005YF000007oo0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00;goo000cOol300000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;Woo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH00UYF
1@00>Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
30001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000goo4P00?goo000]Ool20004FUH00`00FUIJEP03FUH6000GOol4
0002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`00E7oo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000/Ool00`00FUH00003FUH3000ZOol40002FUH01000
FUIJEP001EYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00EGoo000/Ool01000FUH005YF0P00<Goo00<005YF00000UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
10000UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00
;7oo00@005YF000003Aoo`80009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00002FUH00`00
FUIJEP04FUH01000FUH00000F7oo000/Ool200000eYF0000000aOol40002FUH01000FUH000001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YFFUIJEP0000=JEP03001JEP0000<000EJEP<005Yoo`00;7oo0P000eYF0`00:goo0`000UYF
0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEPH005eoo`00;7oo
0P000eYF00<005YFFUH01@008Woo100000=JEP00FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF
00001EYF00<005YF00000`006Goo1@001EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP800003FUH005YF00AJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00eYF0`00Egoo000^Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000Ool00P0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH0009oo`D000AJEP05001JEUYFFUH0001EOol003=oo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00008Ool300000eYF
001JEP02FUH2001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009J
EPL000Uoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000aoo`8000=JEP8005Ao
o`00>goo6`004Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P003goo0P0000=JEP000000
E7oo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P004Woo1000E7oo001[Ool20006FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000004Woo
0P0000AJEP00000005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF0`003goo1@000eYF00<005YF0000E7oo001_Ool30000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3
000;Ool70003FUH00`00FUIJEP02FUH00`00FUH0001DOol0079oo`L000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<000Eoo`T000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00QGoo6@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo
002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001M
Ool009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76527 m .59613 .70969 L .56496 .70779 L p .707 .577 .707 r
F P
0 g
s
.59613 .70969 m .59613 .76527 L .62796 .7645 L p .707 .577 .707 r
F P
0 g
s
.62796 .7645 m .62796 .70891 L .59613 .70969 L p .707 .577 .707 r
F P
0 g
s
.62796 .70891 m .62796 .7645 L .65735 .76112 L p .707 .577 .707 r
F P
0 g
s
.65735 .76112 m .65734 .70554 L .62796 .70891 L p .707 .577 .707 r
F P
0 g
s
.56496 .76337 m .56496 .70779 L .5375 .7034 L p .707 .577 .707 r
F P
0 g
s
.56496 .70779 m .56496 .76337 L .59613 .76527 L p .707 .577 .707 r
F P
0 g
s
.65734 .70554 m .65735 .76112 L .6814 .75547 L p .707 .577 .707 r
F P
0 g
s
.6814 .75547 m .6814 .69989 L .65734 .70554 L p .707 .577 .707 r
F P
0 g
s
.5375 .7034 m .5375 .75898 L .56496 .76337 L p .707 .577 .707 r
F P
0 g
s
.5375 .75898 m .5375 .7034 L .51644 .69694 L p .707 .577 .707 r
F P
0 g
s
.59613 .84666 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84666 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80545 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .84476 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84476 L .59613 .84666 L p .707 .577 .707 r
F P
0 g
s
.6814 .69989 m .6814 .75547 L .69777 .7481 L p .707 .577 .707 r
F P
0 g
s
.69777 .7481 m .69777 .69252 L .6814 .69989 L p .707 .577 .707 r
F P
0 g
s
.51644 .69694 m .51644 .75253 L .5375 .75898 L p .707 .577 .707 r
F P
0 g
s
.65735 .80545 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .7998 L .65735 .80545 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84476 L p .707 .577 .707 r
F P
0 g
s
.51644 .75253 m .51644 .69694 L .50385 .68906 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79686 L p .707 .577 .707 r
F P
0 g
s
.59613 .91554 m .59613 .89701 L .56496 .89511 L p .707 .577 .707 r
F P
0 g
s
.59613 .89701 m .59613 .91554 L .62796 .91476 L p .707 .577 .707 r
F P
0 g
s
.62796 .91476 m .62796 .89624 L .59613 .89701 L p .707 .577 .707 r
F P
0 g
s
.62796 .89624 m .62796 .91476 L .65735 .91138 L p .707 .577 .707 r
F P
0 g
s
.65735 .91138 m .65735 .89286 L .62796 .89624 L p .707 .577 .707 r
F P
0 g
s
.56496 .89511 m .56496 .91364 L .59613 .91554 L p .707 .577 .707 r
F P
0 g
s
.56496 .91364 m .56496 .89511 L .5375 .89072 L p .707 .577 .707 r
F P
0 g
s
.51644 .79686 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.50385 .68906 m .50385 .74464 L .51644 .75253 L p .707 .577 .707 r
F P
0 g
s
.69777 .69252 m .69777 .7481 L .70485 .73974 L p .707 .577 .707 r
F P
0 g
s
.70485 .73974 m .70485 .68415 L .69777 .69252 L p .707 .577 .707 r
F P
0 g
s
.6814 .7998 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .7998 L p .707 .577 .707 r
F P
0 g
s
.5375 .89072 m .5375 .90925 L .56496 .91364 L p .707 .577 .707 r
F P
0 g
s
.65735 .89286 m .65735 .91138 L .6814 .90573 L p .707 .577 .707 r
F P
0 g
s
.6814 .90573 m .6814 .88721 L .65735 .89286 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79686 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .74464 m .50385 .68906 L .50095 .68052 L p .707 .577 .707 r
F P
0 g
s
.5375 .90925 m .5375 .89072 L .51644 .88427 L p .707 .577 .707 r
F P
0 g
s
.51644 .88427 m .51644 .90279 L .5375 .90925 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82603 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.6814 .88721 m .6814 .90573 L .69777 .89837 L p .707 .577 .707 r
F P
0 g
s
.69777 .89837 m .69777 .87984 L .6814 .88721 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .68052 m .50095 .7361 L .50385 .74464 L p .707 .577 .707 r
F P
0 g
s
.70485 .68415 m .70485 .73974 L .70195 .73119 L p .707 .577 .707 r
F P
0 g
s
.70195 .73119 m .70195 .67561 L .70485 .68415 L p .707 .577 .707 r
F P
0 g
s
.51644 .90279 m .51644 .88427 L .50385 .87638 L p .707 .577 .707 r
F P
0 g
s
.50385 .82603 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50385 .87638 m .50385 .89491 L .51644 .90279 L p .707 .577 .707 r
F P
0 g
s
.50095 .7361 m .50095 .68052 L .50804 .67215 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82603 L p .707 .577 .707 r
F P
0 g
s
.69777 .87984 m .69777 .89837 L .70485 .89 L p .707 .577 .707 r
F P
0 g
s
.70485 .89 m .70485 .87148 L .69777 .87984 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81258 L p .707 .577 .707 r
F P
0 g
s
.70195 .81258 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.50804 .67215 m .50804 .72774 L .50095 .7361 L p .707 .577 .707 r
F P
0 g
s
.70195 .67561 m .70195 .73119 L .68936 .72331 L p .707 .577 .707 r
F P
0 g
s
.68936 .72331 m .68936 .66773 L .70195 .67561 L p .707 .577 .707 r
F P
0 g
s
.49044 .91311 m .49044 .41122 L .44643 .40853 L p .707 .577 .707 r
F P
0 g
s
.50385 .89491 m .50385 .87638 L .50095 .86784 L p .707 .577 .707 r
F P
0 g
s
.50095 .86784 m .50095 .88637 L .50385 .89491 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .72774 m .50804 .67215 L .5244 .66479 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.5244 .66479 m .5244 .72037 L .50804 .72774 L p .707 .577 .707 r
F P
0 g
s
.50095 .88637 m .50095 .86784 L .50804 .85948 L p .707 .577 .707 r
F P
0 g
s
.50804 .85948 m .50804 .878 L .50095 .88637 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .7647 L p .707 .577 .707 r
F P
0 g
s
.5244 .7647 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.50804 .878 m .50804 .85948 L .5244 .85211 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .7647 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.5244 .85211 m .5244 .87064 L .50804 .878 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.5244 .87064 m .5244 .85211 L .54846 .84646 L p .707 .577 .707 r
F P
0 g
s
.54846 .84646 m .54846 .86499 L .5244 .87064 L p .707 .577 .707 r
F P
0 g
s
.49044 .41122 m .49044 .91311 L .53538 .91201 L p .707 .577 .707 r
F P
0 g
s
.5244 .72037 m .5244 .66479 L .54846 .65914 L p .707 .577 .707 r
F P
0 g
s
.54846 .65914 m .54846 .71472 L .5244 .72037 L p .707 .577 .707 r
F P
0 g
s
.53538 .91201 m .53538 .41012 L .49044 .41122 L p .707 .577 .707 r
F P
0 g
s
.54846 .71472 m .54846 .65914 L .57784 .65576 L p .707 .577 .707 r
F P
0 g
s
.57784 .65576 m .57784 .71134 L .54846 .71472 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.54846 .86499 m .54846 .84646 L .57784 .84308 L p .707 .577 .707 r
F P
0 g
s
.57784 .84308 m .57784 .86161 L .54846 .86499 L p .707 .577 .707 r
F P
0 g
s
.53538 .41012 m .53538 .91201 L .57686 .90724 L p .707 .577 .707 r
F P
0 g
s
.57686 .90724 m .57686 .40535 L .53538 .41012 L p .707 .577 .707 r
F P
0 g
s
.44643 .91042 m .44643 .40853 L .40766 .40233 L p .707 .577 .707 r
F P
0 g
s
.44643 .40853 m .44643 .91042 L .49044 .91311 L p .707 .577 .707 r
F P
0 g
s
.25312 .72846 m .25312 .67288 L .22195 .67098 L p .707 .577 .707 r
F P
0 g
s
.25312 .67288 m .25312 .72846 L .28495 .72768 L p .707 .577 .707 r
F P
0 g
s
.28495 .72768 m .28495 .6721 L .25312 .67288 L p .707 .577 .707 r
F P
0 g
s
.28495 .6721 m .28495 .72768 L .31434 .7243 L p .707 .577 .707 r
F P
0 g
s
.31434 .7243 m .31434 .66872 L .28495 .6721 L p .707 .577 .707 r
F P
0 g
s
.22195 .72656 m .22195 .67098 L .19449 .66658 L p .707 .577 .707 r
F P
0 g
s
.22195 .67098 m .22195 .72656 L .25312 .72846 L p .707 .577 .707 r
F P
0 g
s
.57784 .71134 m .57784 .65576 L .60968 .65498 L p .707 .577 .707 r
F P
0 g
s
.60968 .65498 m .60968 .71056 L .57784 .71134 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79195 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57784 .86161 m .57784 .84308 L .60968 .8423 L p .707 .577 .707 r
F P
0 g
s
.60968 .8423 m .60968 .86083 L .57784 .86161 L p .707 .577 .707 r
F P
0 g
s
.57686 .40535 m .57686 .90724 L .61082 .89926 L p .707 .577 .707 r
F P
0 g
s
.64085 .65688 m .64085 .71246 L .60968 .71056 L p .707 .577 .707 r
F P
0 g
s
.60968 .71056 m .60968 .65498 L .64085 .65688 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79385 L .60968 .79195 L p .707 .577 .707 r
F P
0 g
s
.60968 .79195 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.64085 .8442 m .64085 .86273 L .60968 .86083 L p .707 .577 .707 r
F P
0 g
s
.60968 .86083 m .60968 .8423 L .64085 .8442 L p .707 .577 .707 r
F P
0 g
s
.61082 .89926 m .61082 .39737 L .57686 .40535 L p .707 .577 .707 r
F P
0 g
s
.70485 .87148 m .70485 .89 L .70195 .88146 L p .707 .577 .707 r
F P
0 g
s
.70195 .88146 m .70195 .86293 L .70485 .87148 L p .707 .577 .707 r
F P
0 g
s
.31434 .66872 m .31434 .7243 L .33839 .71865 L p .707 .577 .707 r
F P
0 g
s
.33839 .71865 m .33839 .66307 L .31434 .66872 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81258 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.68936 .66773 m .68936 .72331 L .66831 .71686 L p .707 .577 .707 r
F P
0 g
s
.66831 .71686 m .66831 .66127 L .68936 .66773 L p .707 .577 .707 r
F P
0 g
s
.40766 .90422 m .40766 .40233 L .37794 .39322 L p .707 .577 .707 r
F P
0 g
s
.40766 .40233 m .40766 .90422 L .44643 .91042 L p .707 .577 .707 r
F P
0 g
s
.19449 .66658 m .19449 .72217 L .22195 .72656 L p .707 .577 .707 r
F P
0 g
s
.19449 .72217 m .19449 .66658 L .17343 .66013 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77279 L .22195 .77089 L p .707 .577 .707 r
F P
0 g
s
.25312 .77279 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77279 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80569 L p .707 .577 .707 r
F P
0 g
s
.31434 .80569 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77089 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77089 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.33839 .66307 m .33839 .71865 L .35476 .71128 L p .707 .577 .707 r
F P
0 g
s
.35476 .71128 m .35476 .6557 L .33839 .66307 L p .707 .577 .707 r
F P
0 g
s
.17343 .66013 m .17343 .71571 L .19449 .72217 L p .707 .577 .707 r
F P
0 g
s
.61082 .39737 m .61082 .89926 L .63393 .88886 L p .707 .577 .707 r
F P
0 g
s
.63393 .88886 m .63393 .38697 L .61082 .39737 L p .707 .577 .707 r
F P
0 g
s
.66831 .66127 m .66831 .71686 L .64085 .71246 L p .707 .577 .707 r
F P
0 g
s
.64085 .71246 m .64085 .65688 L .66831 .66127 L p .707 .577 .707 r
F P
0 g
s
.70195 .86293 m .70195 .88146 L .68936 .87358 L p .707 .577 .707 r
F P
0 g
s
.68936 .87358 m .68936 .85505 L .70195 .86293 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80569 L .33839 .80004 L p .707 .577 .707 r
F P
0 g
s
.33839 .80004 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.17343 .71571 m .17343 .66013 L .16084 .65224 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.25312 .87873 m .25312 .8602 L .22195 .8583 L p .707 .577 .707 r
F P
0 g
s
.25312 .8602 m .25312 .87873 L .28495 .87795 L p .707 .577 .707 r
F P
0 g
s
.28495 .87795 m .28495 .85942 L .25312 .8602 L p .707 .577 .707 r
F P
0 g
s
.37794 .89511 m .37794 .39322 L .36016 .38209 L p .707 .577 .707 r
F P
0 g
s
.37794 .39322 m .37794 .89511 L .40766 .90422 L p .707 .577 .707 r
F P
0 g
s
.28495 .85942 m .28495 .87795 L .31434 .87457 L p .707 .577 .707 r
F P
0 g
s
.31434 .87457 m .31434 .85604 L .28495 .85942 L p .707 .577 .707 r
F P
0 g
s
.22195 .8583 m .22195 .87682 L .25312 .87873 L p .707 .577 .707 r
F P
0 g
s
.22195 .87682 m .22195 .8583 L .19449 .8539 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.16084 .65224 m .16084 .70783 L .17343 .71571 L p .707 .577 .707 r
F P
0 g
s
.35476 .6557 m .35476 .71128 L .36184 .70292 L p .707 .577 .707 r
F P
0 g
s
.36184 .70292 m .36184 .64734 L .35476 .6557 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80004 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.19449 .8539 m .19449 .87243 L .22195 .87682 L p .707 .577 .707 r
F P
0 g
s
.31434 .85604 m .31434 .87457 L .33839 .86892 L p .707 .577 .707 r
F P
0 g
s
.33839 .86892 m .33839 .85039 L .31434 .85604 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79385 L p .707 .577 .707 r
F P
0 g
s
.64085 .79385 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.68936 .85505 m .68936 .87358 L .66831 .86712 L p .707 .577 .707 r
F P
0 g
s
.66831 .86712 m .66831 .84859 L .68936 .85505 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75216 L p .707 .577 .707 r
F P
0 g
s
.16084 .70783 m .16084 .65224 L .15794 .6437 L p .707 .577 .707 r
F P
0 g
s
.19449 .87243 m .19449 .8539 L .17343 .84745 L p .707 .577 .707 r
F P
0 g
s
.66831 .84859 m .66831 .86712 L .64085 .86273 L p .707 .577 .707 r
F P
0 g
s
.64085 .86273 m .64085 .8442 L .66831 .84859 L p .707 .577 .707 r
F P
0 g
s
.63393 .38697 m .63393 .88886 L .64393 .87705 L p .707 .577 .707 r
F P
0 g
s
.64393 .87705 m .64393 .37516 L .63393 .38697 L p .707 .577 .707 r
F P
0 g
s
.17343 .84745 m .17343 .86598 L .19449 .87243 L p .707 .577 .707 r
F P
0 g
s
.16084 .75216 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.33839 .85039 m .33839 .86892 L .35476 .86155 L p .707 .577 .707 r
F P
0 g
s
.35476 .86155 m .35476 .84302 L .33839 .85039 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.15794 .6437 m .15794 .69928 L .16084 .70783 L p .707 .577 .707 r
F P
0 g
s
.36184 .64734 m .36184 .70292 L .35894 .69438 L p .707 .577 .707 r
F P
0 g
s
.35894 .69438 m .35894 .6388 L .36184 .64734 L p .707 .577 .707 r
F P
0 g
s
.35476 .84302 m .35476 .86155 L .36184 .85319 L p .707 .577 .707 r
F P
0 g
s
.36184 .85319 m .36184 .83466 L .35476 .84302 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .73871 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.35894 .6388 m .35894 .69438 L .34635 .68649 L p .707 .577 .707 r
F P
0 g
s
.34635 .68649 m .34635 .63091 L .35894 .6388 L p .707 .577 .707 r
F P
0 g
s
.36184 .83466 m .36184 .85319 L .35894 .84465 L p .707 .577 .707 r
F P
0 g
s
.35894 .84465 m .35894 .82612 L .36184 .83466 L p .707 .577 .707 r
F P
0 g
s
.36016 .88398 m .36016 .38209 L .35607 .37003 L p .707 .577 .707 r
F P
0 g
s
.36016 .38209 m .36016 .88398 L .37794 .89511 L p .707 .577 .707 r
F P
0 g
s
.17343 .86598 m .17343 .84745 L .16084 .83957 L p .707 .577 .707 r
F P
0 g
s
.16084 .78921 m .16084 .75216 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.16084 .83957 m .16084 .85809 L .17343 .86598 L p .707 .577 .707 r
F P
0 g
s
.15794 .69928 m .15794 .6437 L .16503 .63534 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.64393 .37516 m .64393 .87705 L .63984 .86499 L p .707 .577 .707 r
F P
0 g
s
.63984 .86499 m .63984 .3631 L .64393 .37516 L p .707 .577 .707 r
F P
0 g
s
.16503 .63534 m .16503 .69092 L .15794 .69928 L p .707 .577 .707 r
F P
0 g
s
.16084 .85809 m .16084 .83957 L .15794 .83102 L p .707 .577 .707 r
F P
0 g
s
.15794 .83102 m .15794 .84955 L .16084 .85809 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .69092 m .16503 .63534 L .1814 .62797 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .73871 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .73871 L p .707 .577 .707 r
F P
0 g
s
.35894 .82612 m .35894 .84465 L .34635 .83676 L p .707 .577 .707 r
F P
0 g
s
.34635 .83676 m .34635 .81823 L .35894 .82612 L p .707 .577 .707 r
F P
0 g
s
.35607 .37003 m .35607 .87192 L .36016 .88398 L p .707 .577 .707 r
F P
0 g
s
.35607 .87192 m .35607 .37003 L .36607 .35822 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .62797 m .1814 .68355 L .16503 .69092 L p .707 .577 .707 r
F P
0 g
s
.34635 .63091 m .34635 .68649 L .3253 .68004 L p .707 .577 .707 r
F P
0 g
s
.3253 .68004 m .3253 .62446 L .34635 .63091 L p .707 .577 .707 r
F P
0 g
s
.15794 .84955 m .15794 .83102 L .16503 .82266 L p .707 .577 .707 r
F P
0 g
s
.1814 .68355 m .1814 .62797 L .20545 .62232 L p .707 .577 .707 r
F P
0 g
s
.16503 .82266 m .16503 .84119 L .15794 .84955 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.63984 .3631 m .63984 .86499 L .62206 .85386 L p .707 .577 .707 r
F P
0 g
s
.62206 .85386 m .62206 .35197 L .63984 .3631 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76494 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.3253 .62446 m .3253 .68004 L .29784 .67565 L p .707 .577 .707 r
F P
0 g
s
.29784 .67565 m .29784 .62007 L .3253 .62446 L p .707 .577 .707 r
F P
0 g
s
.20545 .62232 m .20545 .6779 L .1814 .68355 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.36607 .86011 m .36607 .35822 L .38918 .34782 L p .707 .577 .707 r
F P
0 g
s
.36607 .35822 m .36607 .86011 L .35607 .87192 L p .707 .577 .707 r
F P
0 g
s
.20545 .6779 m .20545 .62232 L .23483 .61894 L p .707 .577 .707 r
F P
0 g
s
.16503 .84119 m .16503 .82266 L .1814 .81529 L p .707 .577 .707 r
F P
0 g
s
.1814 .76494 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.29784 .62007 m .29784 .67565 L .26667 .67375 L p .707 .577 .707 r
F P
0 g
s
.26667 .67375 m .26667 .61816 L .29784 .62007 L p .707 .577 .707 r
F P
0 g
s
.1814 .81529 m .1814 .83382 L .16503 .84119 L p .707 .577 .707 r
F P
0 g
s
.23483 .67452 m .23483 .61894 L .26667 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61894 m .23483 .67452 L .20545 .6779 L p .707 .577 .707 r
F P
0 g
s
.26667 .61816 m .26667 .67375 L .23483 .67452 L p .707 .577 .707 r
F P
0 g
s
.73333 .67323 m .73333 .61765 L .70216 .61575 L p .707 .577 .707 r
F P
0 g
s
.73333 .61765 m .73333 .67323 L .76517 .67246 L p .707 .577 .707 r
F P
0 g
s
.76517 .67246 m .76517 .61688 L .73333 .61765 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75929 L .1814 .76494 L p .707 .577 .707 r
F P
0 g
s
.76517 .61688 m .76517 .67246 L .79455 .66908 L p .707 .577 .707 r
F P
0 g
s
.79455 .66908 m .79455 .6135 L .76517 .61688 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71998 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.34635 .81823 m .34635 .83676 L .3253 .83031 L p .707 .577 .707 r
F P
0 g
s
.3253 .83031 m .3253 .81178 L .34635 .81823 L p .707 .577 .707 r
F P
0 g
s
.62206 .35197 m .62206 .85386 L .59233 .84475 L p .707 .577 .707 r
F P
0 g
s
.59233 .84475 m .59233 .34286 L .62206 .35197 L p .707 .577 .707 r
F P
0 g
s
.70216 .67133 m .70216 .61575 L .6747 .61136 L p .707 .577 .707 r
F P
0 g
s
.70216 .61575 m .70216 .67133 L .73333 .67323 L p .707 .577 .707 r
F P
0 g
s
.20545 .75929 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.79455 .6135 m .79455 .66908 L .8186 .66343 L p .707 .577 .707 r
F P
0 g
s
.8186 .66343 m .8186 .60785 L .79455 .6135 L p .707 .577 .707 r
F P
0 g
s
.1814 .83382 m .1814 .81529 L .20545 .80964 L p .707 .577 .707 r
F P
0 g
s
.29784 .71998 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71808 L .29784 .71998 L p .707 .577 .707 r
F P
0 g
s
.38918 .34782 m .38918 .84971 L .36607 .86011 L p .707 .577 .707 r
F P
0 g
s
.38918 .84971 m .38918 .34782 L .42314 .33984 L p .707 .577 .707 r
F P
0 g
s
.20545 .80964 m .20545 .82817 L .1814 .83382 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75929 L p .707 .577 .707 r
F P
0 g
s
.6747 .61136 m .6747 .66694 L .70216 .67133 L p .707 .577 .707 r
F P
0 g
s
.6747 .66694 m .6747 .61136 L .65365 .60491 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71808 L p .707 .577 .707 r
F P
0 g
s
.26667 .71808 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.3253 .81178 m .3253 .83031 L .29784 .82591 L p .707 .577 .707 r
F P
0 g
s
.29784 .82591 m .29784 .80739 L .3253 .81178 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71679 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.76517 .71679 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.8186 .60785 m .8186 .66343 L .83497 .65606 L p .707 .577 .707 r
F P
0 g
s
.83497 .65606 m .83497 .60048 L .8186 .60785 L p .707 .577 .707 r
F P
0 g
s
.20545 .82817 m .20545 .80964 L .23483 .80626 L p .707 .577 .707 r
F P
0 g
s
.59233 .34286 m .59233 .84475 L .55357 .83855 L p .707 .577 .707 r
F P
0 g
s
.55357 .83855 m .55357 .33666 L .59233 .34286 L p .707 .577 .707 r
F P
0 g
s
.65365 .60491 m .65365 .66049 L .6747 .66694 L p .707 .577 .707 r
F P
0 g
s
.23483 .80626 m .23483 .82479 L .20545 .82817 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.29784 .80739 m .29784 .82591 L .26667 .82401 L p .707 .577 .707 r
F P
0 g
s
.26667 .82401 m .26667 .80549 L .29784 .80739 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74833 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.65365 .66049 m .65365 .60491 L .64105 .59702 L p .707 .577 .707 r
F P
0 g
s
.23483 .82479 m .23483 .80626 L .26667 .80549 L p .707 .577 .707 r
F P
0 g
s
.42314 .84173 m .42314 .33984 L .46462 .33507 L p .707 .577 .707 r
F P
0 g
s
.42314 .33984 m .42314 .84173 L .38918 .84971 L p .707 .577 .707 r
F P
0 g
s
.26667 .80549 m .26667 .82401 L .23483 .82479 L p .707 .577 .707 r
F P
0 g
s
.6747 .74833 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.73333 .8235 m .73333 .80498 L .70216 .80307 L p .707 .577 .707 r
F P
0 g
s
.73333 .80498 m .73333 .8235 L .76517 .82273 L p .707 .577 .707 r
F P
0 g
s
.76517 .82273 m .76517 .8042 L .73333 .80498 L p .707 .577 .707 r
F P
0 g
s
.76517 .8042 m .76517 .82273 L .79455 .81935 L p .707 .577 .707 r
F P
0 g
s
.79455 .81935 m .79455 .80082 L .76517 .8042 L p .707 .577 .707 r
F P
0 g
s
.70216 .80307 m .70216 .8216 L .73333 .8235 L p .707 .577 .707 r
F P
0 g
s
.70216 .8216 m .70216 .80307 L .6747 .79868 L p .707 .577 .707 r
F P
0 g
s
.55357 .33666 m .55357 .83855 L .50956 .83587 L p .707 .577 .707 r
F P
0 g
s
.50956 .83587 m .50956 .33398 L .55357 .33666 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74833 L p .707 .577 .707 r
F P
0 g
s
.64105 .59702 m .64105 .6526 L .65365 .66049 L p .707 .577 .707 r
F P
0 g
s
.83497 .60048 m .83497 .65606 L .84205 .6477 L p .707 .577 .707 r
F P
0 g
s
.84205 .6477 m .84205 .59211 L .83497 .60048 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73745 L p .707 .577 .707 r
F P
0 g
s
.83497 .73745 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.6747 .79868 m .6747 .81721 L .70216 .8216 L p .707 .577 .707 r
F P
0 g
s
.46462 .83696 m .46462 .33507 L .50956 .33398 L p .707 .577 .707 r
F P
0 g
s
.46462 .33507 m .46462 .83696 L .42314 .84173 L p .707 .577 .707 r
F P
0 g
s
.79455 .80082 m .79455 .81935 L .8186 .8137 L p .707 .577 .707 r
F P
0 g
s
.8186 .8137 m .8186 .79517 L .79455 .80082 L p .707 .577 .707 r
F P
0 g
s
.50956 .33398 m .50956 .83587 L .46462 .83696 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .6526 m .64105 .59702 L .63816 .58848 L p .707 .577 .707 r
F P
0 g
s
.6747 .81721 m .6747 .79868 L .65365 .79223 L p .707 .577 .707 r
F P
0 g
s
.65365 .79223 m .65365 .81076 L .6747 .81721 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.8186 .79517 m .8186 .8137 L .83497 .80633 L p .707 .577 .707 r
F P
0 g
s
.83497 .80633 m .83497 .7878 L .8186 .79517 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73745 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69203 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .58848 m .63816 .64406 L .64105 .6526 L p .707 .577 .707 r
F P
0 g
s
.84205 .59211 m .84205 .6477 L .83916 .63915 L p .707 .577 .707 r
F P
0 g
s
.83916 .63915 m .83916 .58357 L .84205 .59211 L p .707 .577 .707 r
F P
0 g
s
.65365 .81076 m .65365 .79223 L .64105 .78434 L p .707 .577 .707 r
F P
0 g
s
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.64105 .78434 m .64105 .80287 L .65365 .81076 L p .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .63816 .58848 L .64524 .58011 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72545 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83497 .7878 m .83497 .80633 L .84206 .79796 L p .707 .577 .707 r
F P
0 g
s
.84206 .79796 m .84206 .77944 L .83497 .7878 L p .707 .577 .707 r
F P
0 g
s
.84206 .69203 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69203 L p .707 .577 .707 r
F P
0 g
s
.64524 .58011 m .64524 .6357 L .63816 .64406 L p .707 .577 .707 r
F P
0 g
s
.83916 .58357 m .83916 .63915 L .82657 .63127 L p .707 .577 .707 r
F P
0 g
s
.82657 .63127 m .82657 .57569 L .83916 .58357 L p .707 .577 .707 r
F P
0 g
s
.64105 .80287 m .64105 .78434 L .63816 .7758 L p .707 .577 .707 r
F P
0 g
s
.63816 .7758 m .63816 .79433 L .64105 .80287 L p .707 .577 .707 r
F P
0 g
s
.39032 .63642 m .39032 .58084 L .35915 .57894 L p .707 .577 .707 r
F P
0 g
s
.39032 .58084 m .39032 .63642 L .42216 .63564 L p .707 .577 .707 r
F P
0 g
s
.42216 .63564 m .42216 .58006 L .39032 .58084 L p .707 .577 .707 r
F P
0 g
s
.63816 .72545 m .63816 .68839 L .64524 .68003 L p .707 .577 .707 r
F P
0 g
s
.64524 .6357 m .64524 .58011 L .66161 .57275 L p .707 .577 .707 r
F P
0 g
s
.42216 .58006 m .42216 .63564 L .45154 .63226 L p .707 .577 .707 r
F P
0 g
s
.45154 .63226 m .45154 .57668 L .42216 .58006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35915 .63452 m .35915 .57894 L .33169 .57454 L p .707 .577 .707 r
F P
0 g
s
.35915 .57894 m .35915 .63452 L .39032 .63642 L p .707 .577 .707 r
F P
0 g
s
.64524 .68003 m .64524 .71708 L .63816 .72545 L p .707 .577 .707 r
F P
0 g
s
.84206 .77944 m .84206 .79796 L .83916 .78942 L p .707 .577 .707 r
F P
0 g
s
.83916 .78942 m .83916 .77089 L .84206 .77944 L p .707 .577 .707 r
F P
0 g
s
.45154 .57668 m .45154 .63226 L .47559 .62661 L p .707 .577 .707 r
F P
0 g
s
.47559 .62661 m .47559 .57103 L .45154 .57668 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .57275 m .66161 .62833 L .64524 .6357 L p .707 .577 .707 r
F P
0 g
s
.82657 .57569 m .82657 .63127 L .80551 .62482 L p .707 .577 .707 r
F P
0 g
s
.80551 .62482 m .80551 .56923 L .82657 .57569 L p .707 .577 .707 r
F P
0 g
s
.33169 .57454 m .33169 .63013 L .35915 .63452 L p .707 .577 .707 r
F P
0 g
s
.33169 .63013 m .33169 .57454 L .31064 .56809 L p .707 .577 .707 r
F P
0 g
s
.63816 .79433 m .63816 .7758 L .64524 .76744 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71703 L p .707 .577 .707 r
F P
0 g
s
.42216 .71703 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.66161 .62833 m .66161 .57275 L .68566 .5671 L p .707 .577 .707 r
F P
0 g
s
.64524 .76744 m .64524 .78596 L .63816 .79433 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68003 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71703 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67446 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.47559 .57103 m .47559 .62661 L .49196 .61925 L p .707 .577 .707 r
F P
0 g
s
.49196 .61925 m .49196 .56366 L .47559 .57103 L p .707 .577 .707 r
F P
0 g
s
.31064 .56809 m .31064 .62367 L .33169 .63013 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.80551 .56923 m .80551 .62482 L .77805 .62042 L p .707 .577 .707 r
F P
0 g
s
.77805 .62042 m .77805 .56484 L .80551 .56923 L p .707 .577 .707 r
F P
0 g
s
.83916 .77089 m .83916 .78942 L .82657 .78154 L p .707 .577 .707 r
F P
0 g
s
.82657 .78154 m .82657 .76301 L .83916 .77089 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.68566 .5671 m .68566 .62268 L .66161 .62833 L p .707 .577 .707 r
F P
0 g
s
.33169 .67446 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.31064 .62367 m .31064 .56809 L .29804 .56021 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66915 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.68566 .62268 m .68566 .5671 L .71504 .56372 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67446 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.39032 .78669 m .39032 .76816 L .35915 .76626 L p .707 .577 .707 r
F P
0 g
s
.39032 .76816 m .39032 .78669 L .42216 .78591 L p .707 .577 .707 r
F P
0 g
s
.42216 .78591 m .42216 .76738 L .39032 .76816 L p .707 .577 .707 r
F P
0 g
s
.64524 .78596 m .64524 .76744 L .66161 .76007 L p .707 .577 .707 r
F P
0 g
s
.42216 .76738 m .42216 .78591 L .45154 .78253 L p .707 .577 .707 r
F P
0 g
s
.45154 .78253 m .45154 .764 L .42216 .76738 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.35915 .76626 m .35915 .78479 L .39032 .78669 L p .707 .577 .707 r
F P
0 g
s
.77805 .56484 m .77805 .62042 L .74688 .61852 L p .707 .577 .707 r
F P
0 g
s
.74688 .61852 m .74688 .56294 L .77805 .56484 L p .707 .577 .707 r
F P
0 g
s
.35915 .78479 m .35915 .76626 L .33169 .76187 L p .707 .577 .707 r
F P
0 g
s
.66161 .76007 m .66161 .7786 L .64524 .78596 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70506 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.29804 .56021 m .29804 .61579 L .31064 .62367 L p .707 .577 .707 r
F P
0 g
s
.71504 .6193 m .71504 .56372 L .74688 .56294 L p .707 .577 .707 r
F P
0 g
s
.71504 .56372 m .71504 .6193 L .68566 .62268 L p .707 .577 .707 r
F P
0 g
s
.49196 .56366 m .49196 .61925 L .49904 .61088 L p .707 .577 .707 r
F P
0 g
s
.49904 .61088 m .49904 .5553 L .49196 .56366 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66358 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.33169 .76187 m .33169 .78039 L .35915 .78479 L p .707 .577 .707 r
F P
0 g
s
.74688 .56294 m .74688 .61852 L .71504 .6193 L p .707 .577 .707 r
F P
0 g
s
.45154 .764 m .45154 .78253 L .47559 .77688 L p .707 .577 .707 r
F P
0 g
s
.47559 .77688 m .47559 .75835 L .45154 .764 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66915 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66915 L p .707 .577 .707 r
F P
0 g
s
.82657 .76301 m .82657 .78154 L .80551 .77508 L p .707 .577 .707 r
F P
0 g
s
.80551 .77508 m .80551 .75656 L .82657 .76301 L p .707 .577 .707 r
F P
0 g
s
.31064 .70506 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.29804 .61579 m .29804 .56021 L .29515 .55166 L p .707 .577 .707 r
F P
0 g
s
.33169 .78039 m .33169 .76187 L .31064 .75541 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.31064 .75541 m .31064 .77394 L .33169 .78039 L p .707 .577 .707 r
F P
0 g
s
.66161 .7786 m .66161 .76007 L .68566 .75442 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70506 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.68566 .75442 m .68566 .77295 L .66161 .7786 L p .707 .577 .707 r
F P
0 g
s
.47559 .75835 m .47559 .77688 L .49196 .76951 L p .707 .577 .707 r
F P
0 g
s
.49196 .76951 m .49196 .75099 L .47559 .75835 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66358 m .49196 .70063 L .49904 .69227 L p .707 .577 .707 r
F P
0 g
s
.49904 .69227 m .49904 .65521 L .49196 .66358 L p .707 .577 .707 r
F P
0 g
s
.29515 .55166 m .29515 .60725 L .29804 .61579 L p .707 .577 .707 r
F P
0 g
s
.49904 .5553 m .49904 .61088 L .49615 .60234 L p .707 .577 .707 r
F P
0 g
s
.49615 .60234 m .49615 .54676 L .49904 .5553 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.80551 .75656 m .80551 .77508 L .77805 .77069 L p .707 .577 .707 r
F P
0 g
s
.77805 .77069 m .77805 .75216 L .80551 .75656 L p .707 .577 .707 r
F P
0 g
s
.31064 .77394 m .31064 .75541 L .29804 .74753 L p .707 .577 .707 r
F P
0 g
s
.68566 .77295 m .68566 .75442 L .71504 .75104 L p .707 .577 .707 r
F P
0 g
s
.29804 .69717 m .29804 .66012 L .29515 .65158 L p .707 .577 .707 r
F P
0 g
s
.29804 .74753 m .29804 .76606 L .31064 .77394 L p .707 .577 .707 r
F P
0 g
s
.29515 .60725 m .29515 .55166 L .30223 .5433 L p .707 .577 .707 r
F P
0 g
s
.71504 .75104 m .71504 .76957 L .68566 .77295 L p .707 .577 .707 r
F P
0 g
s
.77805 .75216 m .77805 .77069 L .74688 .76879 L p .707 .577 .707 r
F P
0 g
s
.74688 .76879 m .74688 .75026 L .77805 .75216 L p .707 .577 .707 r
F P
0 g
s
.29515 .65158 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.71504 .76957 m .71504 .75104 L .74688 .75026 L p .707 .577 .707 r
F P
0 g
s
.49196 .75099 m .49196 .76951 L .49904 .76115 L p .707 .577 .707 r
F P
0 g
s
.49904 .76115 m .49904 .74262 L .49196 .75099 L p .707 .577 .707 r
F P
0 g
s
.74688 .75026 m .74688 .76879 L .71504 .76957 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69227 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .5433 m .30223 .59888 L .29515 .60725 L p .707 .577 .707 r
F P
0 g
s
.49615 .54676 m .49615 .60234 L .48356 .59445 L p .707 .577 .707 r
F P
0 g
s
.48356 .59445 m .48356 .53887 L .49615 .54676 L p .707 .577 .707 r
F P
0 g
s
.29804 .76606 m .29804 .74753 L .29515 .73899 L p .707 .577 .707 r
F P
0 g
s
.29515 .73899 m .29515 .75751 L .29804 .76606 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65158 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .59888 m .30223 .5433 L .3186 .53593 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .64321 m .30223 .68027 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49904 .74262 m .49904 .76115 L .49615 .75261 L p .707 .577 .707 r
F P
0 g
s
.49615 .75261 m .49615 .73408 L .49904 .74262 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .53593 m .3186 .59151 L .30223 .59888 L p .707 .577 .707 r
F P
0 g
s
.48356 .53887 m .48356 .59445 L .4625 .588 L p .707 .577 .707 r
F P
0 g
s
.4625 .588 m .4625 .53242 L .48356 .53887 L p .707 .577 .707 r
F P
0 g
s
.29515 .75751 m .29515 .73899 L .30223 .73062 L p .707 .577 .707 r
F P
0 g
s
.3186 .59151 m .3186 .53593 L .34265 .53028 L p .707 .577 .707 r
F P
0 g
s
.30223 .73062 m .30223 .74915 L .29515 .75751 L p .707 .577 .707 r
F P
0 g
s
.30223 .68027 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68027 L p .707 .577 .707 r
F P
0 g
s
.4625 .53242 m .4625 .588 L .43504 .58361 L p .707 .577 .707 r
F P
0 g
s
.43504 .58361 m .43504 .52803 L .4625 .53242 L p .707 .577 .707 r
F P
0 g
s
.49615 .73408 m .49615 .75261 L .48356 .74472 L p .707 .577 .707 r
F P
0 g
s
.48356 .74472 m .48356 .7262 L .49615 .73408 L p .707 .577 .707 r
F P
0 g
s
.34265 .53028 m .34265 .58586 L .3186 .59151 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66939 L p .707 .577 .707 r
F P
0 g
s
.4625 .66939 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.34265 .58586 m .34265 .53028 L .37203 .5269 L p .707 .577 .707 r
F P
0 g
s
.30223 .74915 m .30223 .73062 L .3186 .72325 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.43504 .52803 m .43504 .58361 L .40387 .58171 L p .707 .577 .707 r
F P
0 g
s
.40387 .58171 m .40387 .52613 L .43504 .52803 L p .707 .577 .707 r
F P
0 g
s
.3186 .72325 m .3186 .74178 L .30223 .74915 L p .707 .577 .707 r
F P
0 g
s
.37203 .58249 m .37203 .5269 L .40387 .52613 L p .707 .577 .707 r
F P
0 g
s
.37203 .5269 m .37203 .58249 L .34265 .58586 L p .707 .577 .707 r
F P
0 g
s
.40387 .52613 m .40387 .58171 L .37203 .58249 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66939 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.48356 .7262 m .48356 .74472 L .4625 .73827 L p .707 .577 .707 r
F P
0 g
s
.4625 .73827 m .4625 .71974 L .48356 .7262 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.3186 .74178 m .3186 .72325 L .34265 .7176 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.34265 .7176 m .34265 .73613 L .3186 .74178 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
.4625 .71974 m .4625 .73827 L .43504 .73388 L p .707 .577 .707 r
F P
0 g
s
.43504 .73388 m .43504 .71535 L .4625 .71974 L p .707 .577 .707 r
F P
0 g
s
.34265 .73613 m .34265 .7176 L .37203 .71423 L p .707 .577 .707 r
F P
0 g
s
.37203 .71423 m .37203 .73275 L .34265 .73613 L p .707 .577 .707 r
F P
0 g
s
.43504 .71535 m .43504 .73388 L .40387 .73198 L p .707 .577 .707 r
F P
0 g
s
.40387 .73198 m .40387 .71345 L .43504 .71535 L p .707 .577 .707 r
F P
0 g
s
.37203 .73275 m .37203 .71423 L .40387 .71345 L p .707 .577 .707 r
F P
0 g
s
.40387 .71345 m .40387 .73198 L .37203 .73275 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eoo`00MWoo2@001EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<000UJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool0
06Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001W
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<0
05YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001J
EP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06
001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo0017Ool90004Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h000AJEP03001JEUYF009J
EPL00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH:0008
FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP0
00QJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEQT00003FUH005YF009JEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000=JEP03001JEP0000=JEP<00004FUH0
00000002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF1P00
00=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<0
05YFFUH01UYF100000=JEP00FUH00P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool00`00
FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH3000`Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004FUH0
1000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD000=JEP04001JEUYFFUH2000LOol400000eYF
001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH00`00FUIJEP05FUH900000eYF001J
EP03FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P000eYF1P000eYF0P005Goo1`000eYF0`000eYF0P00;Goo000`Ool30004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUH0000;0004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@001Goo
0`0000=oo`0000001`000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUHI00000eYF001JEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000fOol90003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@00
15YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000cOol40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00;Woo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF20000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP@000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEP80009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00AJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP@0009JEQ`003Yoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF4@000eYF0P000UYF0`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol002aoo`03001J
EP0000AJEP03001JEUYF00=JEPH0015oo`D000=JEP03001JEP00008000EJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
00000eYF0000000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH4000fOol002aoo`03001JEP0000AJEP03001JEP0000<001Yoo`8000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEPL001]oo`05001JEUYFFUH00005FUH01000
FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH2000aOol002aoo`04001JEP00FUH20005FUH00`00FUH00003000HOol01000FUIJ
EP001EYF00<005YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP03FUHL0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YF00000P000UYF00<005YFFUH00P006Goo1@0015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YF000010001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`001EYF00D005YFFUIJEP0001ioo`<00003FUH005YF009JEP8002eoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF001JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000POol20003FUH2000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF6@001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2
000ROol200000eYF0000000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002=oo`@002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2
000QOol2000015YF00000000;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000<000AJEP04001JEUYFFUH2000L
Ool50003FUH00`00FUH0000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH60003FUH2000EOol70003FUH00`00FUIJEP02FUH2
000^Ool003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000kOolP000:Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH000080004FUH00`00FUIJEP02FUH9000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004Ool90018Ool0
02eoo`8000AJEP03001JEUYF00=JEPH001Moo`@0009JEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00EWoo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00@005YF000005Qoo`00;7oo00<005YF00000eYF0`00:Woo10000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00=JEP<005Yoo`00;7oo00@005YF001JEP80035oo`03
001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH00003001MOol0
02aoo`04001JEP00000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH60002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004001QOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00008006=oo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P000UYF
00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool2
0003FUH00`00FUIJEP02FUH3000ROol400000eYF001JEP02FUH20002FUH01000FUIJEUYF0P001EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
100015YF00<005YF00001EYF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF00001EYF00<005YF
00000`006Goo1@001EYF00@005YFFUIJEP80009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF
00<005YF00001EYF00<005YFFUH00UYF0P00FGoo000^Ool01000FUIJEP001EYF00<005YFFUH00eYF
6@000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP<00003FUH005YF00AJEP03001JEUYF00=JEP<005Moo`00;goo0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YFFUH007oo001J
EP000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00=JEP03
001JEUYF008005Eoo`00<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0`000Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
0P0000AJEP00Oomoo`D000AJEP05001JEUYFFUH0001EOol003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40004Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001goo0`0000=JEP00FUH00UYF0P00E7oo000fOol50004
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH70008Ool20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000002Woo0P000eYF0P00E7oo000kOolK000?Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0037oo0P0000=JEP000000E7oo001VOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000>Ool4001DOol006Ioo`03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000eoo`800004FUH00000001DOol006Moo`80009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000Uoo`D000=JEP03001JEP0005Aoo`00JGoo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YFFUIJEP8000Aoo`L000=JEP03001JEUYF009JEP03001JEP0005Aoo`00Jgoo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YF00001`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001]Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo001_Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000F7oo001bOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001J
Ool007Uoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<005eoo`00QGoo5P0000=oo`0000001`0015YF00<005YFFUH01UYF00<005YF
FUH00UYF1@00HGoo002UOolB001VOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76527 m .59613 .70969 L .56496 .70779 L p .707 .577 .707 r
F P
0 g
s
.59613 .70969 m .59613 .76527 L .62796 .7645 L p .707 .577 .707 r
F P
0 g
s
.62796 .7645 m .62796 .70891 L .59613 .70969 L p .707 .577 .707 r
F P
0 g
s
.62796 .70891 m .62796 .7645 L .65735 .76112 L p .707 .577 .707 r
F P
0 g
s
.65735 .76112 m .65734 .70554 L .62796 .70891 L p .707 .577 .707 r
F P
0 g
s
.56496 .76337 m .56496 .70779 L .5375 .7034 L p .707 .577 .707 r
F P
0 g
s
.56496 .70779 m .56496 .76337 L .59613 .76527 L p .707 .577 .707 r
F P
0 g
s
.65734 .70554 m .65735 .76112 L .6814 .75547 L p .707 .577 .707 r
F P
0 g
s
.6814 .75547 m .6814 .69989 L .65734 .70554 L p .707 .577 .707 r
F P
0 g
s
.5375 .7034 m .5375 .75898 L .56496 .76337 L p .707 .577 .707 r
F P
0 g
s
.5375 .75898 m .5375 .7034 L .51644 .69694 L p .707 .577 .707 r
F P
0 g
s
.59613 .84666 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84666 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80545 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .84476 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84476 L .59613 .84666 L p .707 .577 .707 r
F P
0 g
s
.6814 .69989 m .6814 .75547 L .69777 .7481 L p .707 .577 .707 r
F P
0 g
s
.69777 .7481 m .69777 .69252 L .6814 .69989 L p .707 .577 .707 r
F P
0 g
s
.51644 .69694 m .51644 .75253 L .5375 .75898 L p .707 .577 .707 r
F P
0 g
s
.65735 .80545 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .7998 L .65735 .80545 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84476 L p .707 .577 .707 r
F P
0 g
s
.51644 .75253 m .51644 .69694 L .50385 .68906 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79686 L p .707 .577 .707 r
F P
0 g
s
.59613 .91554 m .59613 .89701 L .56496 .89511 L p .707 .577 .707 r
F P
0 g
s
.59613 .89701 m .59613 .91554 L .62796 .91476 L p .707 .577 .707 r
F P
0 g
s
.62796 .91476 m .62796 .89624 L .59613 .89701 L p .707 .577 .707 r
F P
0 g
s
.62796 .89624 m .62796 .91476 L .65735 .91138 L p .707 .577 .707 r
F P
0 g
s
.65735 .91138 m .65735 .89286 L .62796 .89624 L p .707 .577 .707 r
F P
0 g
s
.56496 .89511 m .56496 .91364 L .59613 .91554 L p .707 .577 .707 r
F P
0 g
s
.56496 .91364 m .56496 .89511 L .5375 .89072 L p .707 .577 .707 r
F P
0 g
s
.51644 .79686 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.50385 .68906 m .50385 .74464 L .51644 .75253 L p .707 .577 .707 r
F P
0 g
s
.69777 .69252 m .69777 .7481 L .70485 .73974 L p .707 .577 .707 r
F P
0 g
s
.70485 .73974 m .70485 .68415 L .69777 .69252 L p .707 .577 .707 r
F P
0 g
s
.6814 .7998 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .7998 L p .707 .577 .707 r
F P
0 g
s
.5375 .89072 m .5375 .90925 L .56496 .91364 L p .707 .577 .707 r
F P
0 g
s
.65735 .89286 m .65735 .91138 L .6814 .90573 L p .707 .577 .707 r
F P
0 g
s
.6814 .90573 m .6814 .88721 L .65735 .89286 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79686 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .74464 m .50385 .68906 L .50095 .68052 L p .707 .577 .707 r
F P
0 g
s
.5375 .90925 m .5375 .89072 L .51644 .88427 L p .707 .577 .707 r
F P
0 g
s
.51644 .88427 m .51644 .90279 L .5375 .90925 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82603 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.6814 .88721 m .6814 .90573 L .69777 .89837 L p .707 .577 .707 r
F P
0 g
s
.69777 .89837 m .69777 .87984 L .6814 .88721 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .68052 m .50095 .7361 L .50385 .74464 L p .707 .577 .707 r
F P
0 g
s
.70485 .68415 m .70485 .73974 L .70195 .73119 L p .707 .577 .707 r
F P
0 g
s
.70195 .73119 m .70195 .67561 L .70485 .68415 L p .707 .577 .707 r
F P
0 g
s
.51644 .90279 m .51644 .88427 L .50385 .87638 L p .707 .577 .707 r
F P
0 g
s
.50385 .82603 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50385 .87638 m .50385 .89491 L .51644 .90279 L p .707 .577 .707 r
F P
0 g
s
.50095 .7361 m .50095 .68052 L .50804 .67215 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82603 L p .707 .577 .707 r
F P
0 g
s
.69777 .87984 m .69777 .89837 L .70485 .89 L p .707 .577 .707 r
F P
0 g
s
.70485 .89 m .70485 .87148 L .69777 .87984 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81258 L p .707 .577 .707 r
F P
0 g
s
.70195 .81258 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.50804 .67215 m .50804 .72774 L .50095 .7361 L p .707 .577 .707 r
F P
0 g
s
.70195 .67561 m .70195 .73119 L .68936 .72331 L p .707 .577 .707 r
F P
0 g
s
.68936 .72331 m .68936 .66773 L .70195 .67561 L p .707 .577 .707 r
F P
0 g
s
.49044 .91311 m .49044 .41122 L .44643 .40853 L p .707 .577 .707 r
F P
0 g
s
.50385 .89491 m .50385 .87638 L .50095 .86784 L p .707 .577 .707 r
F P
0 g
s
.50095 .86784 m .50095 .88637 L .50385 .89491 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .72774 m .50804 .67215 L .5244 .66479 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.5244 .66479 m .5244 .72037 L .50804 .72774 L p .707 .577 .707 r
F P
0 g
s
.50095 .88637 m .50095 .86784 L .50804 .85948 L p .707 .577 .707 r
F P
0 g
s
.50804 .85948 m .50804 .878 L .50095 .88637 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .7647 L p .707 .577 .707 r
F P
0 g
s
.5244 .7647 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.50804 .878 m .50804 .85948 L .5244 .85211 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .7647 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.5244 .85211 m .5244 .87064 L .50804 .878 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.5244 .87064 m .5244 .85211 L .54846 .84646 L p .707 .577 .707 r
F P
0 g
s
.54846 .84646 m .54846 .86499 L .5244 .87064 L p .707 .577 .707 r
F P
0 g
s
.49044 .41122 m .49044 .91311 L .53538 .91201 L p .707 .577 .707 r
F P
0 g
s
.5244 .72037 m .5244 .66479 L .54846 .65914 L p .707 .577 .707 r
F P
0 g
s
.54846 .65914 m .54846 .71472 L .5244 .72037 L p .707 .577 .707 r
F P
0 g
s
.53538 .91201 m .53538 .41012 L .49044 .41122 L p .707 .577 .707 r
F P
0 g
s
.54846 .71472 m .54846 .65914 L .57784 .65576 L p .707 .577 .707 r
F P
0 g
s
.57784 .65576 m .57784 .71134 L .54846 .71472 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.54846 .86499 m .54846 .84646 L .57784 .84308 L p .707 .577 .707 r
F P
0 g
s
.57784 .84308 m .57784 .86161 L .54846 .86499 L p .707 .577 .707 r
F P
0 g
s
.53538 .41012 m .53538 .91201 L .57686 .90724 L p .707 .577 .707 r
F P
0 g
s
.57686 .90724 m .57686 .40535 L .53538 .41012 L p .707 .577 .707 r
F P
0 g
s
.44643 .91042 m .44643 .40853 L .40766 .40233 L p .707 .577 .707 r
F P
0 g
s
.44643 .40853 m .44643 .91042 L .49044 .91311 L p .707 .577 .707 r
F P
0 g
s
.25312 .72846 m .25312 .67288 L .22195 .67098 L p .707 .577 .707 r
F P
0 g
s
.25312 .67288 m .25312 .72846 L .28495 .72768 L p .707 .577 .707 r
F P
0 g
s
.28495 .72768 m .28495 .6721 L .25312 .67288 L p .707 .577 .707 r
F P
0 g
s
.28495 .6721 m .28495 .72768 L .31434 .7243 L p .707 .577 .707 r
F P
0 g
s
.31434 .7243 m .31434 .66872 L .28495 .6721 L p .707 .577 .707 r
F P
0 g
s
.22195 .72656 m .22195 .67098 L .19449 .66658 L p .707 .577 .707 r
F P
0 g
s
.22195 .67098 m .22195 .72656 L .25312 .72846 L p .707 .577 .707 r
F P
0 g
s
.57784 .71134 m .57784 .65576 L .60968 .65498 L p .707 .577 .707 r
F P
0 g
s
.60968 .65498 m .60968 .71056 L .57784 .71134 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79195 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57784 .86161 m .57784 .84308 L .60968 .8423 L p .707 .577 .707 r
F P
0 g
s
.60968 .8423 m .60968 .86083 L .57784 .86161 L p .707 .577 .707 r
F P
0 g
s
.57686 .40535 m .57686 .90724 L .61082 .89926 L p .707 .577 .707 r
F P
0 g
s
.64085 .65688 m .64085 .71246 L .60968 .71056 L p .707 .577 .707 r
F P
0 g
s
.60968 .71056 m .60968 .65498 L .64085 .65688 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79385 L .60968 .79195 L p .707 .577 .707 r
F P
0 g
s
.60968 .79195 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.64085 .8442 m .64085 .86273 L .60968 .86083 L p .707 .577 .707 r
F P
0 g
s
.60968 .86083 m .60968 .8423 L .64085 .8442 L p .707 .577 .707 r
F P
0 g
s
.61082 .89926 m .61082 .39737 L .57686 .40535 L p .707 .577 .707 r
F P
0 g
s
.70485 .87148 m .70485 .89 L .70195 .88146 L p .707 .577 .707 r
F P
0 g
s
.70195 .88146 m .70195 .86293 L .70485 .87148 L p .707 .577 .707 r
F P
0 g
s
.31434 .66872 m .31434 .7243 L .33839 .71865 L p .707 .577 .707 r
F P
0 g
s
.33839 .71865 m .33839 .66307 L .31434 .66872 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81258 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.68936 .66773 m .68936 .72331 L .66831 .71686 L p .707 .577 .707 r
F P
0 g
s
.66831 .71686 m .66831 .66127 L .68936 .66773 L p .707 .577 .707 r
F P
0 g
s
.40766 .90422 m .40766 .40233 L .37794 .39322 L p .707 .577 .707 r
F P
0 g
s
.40766 .40233 m .40766 .90422 L .44643 .91042 L p .707 .577 .707 r
F P
0 g
s
.19449 .66658 m .19449 .72217 L .22195 .72656 L p .707 .577 .707 r
F P
0 g
s
.19449 .72217 m .19449 .66658 L .17343 .66013 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77279 L .22195 .77089 L p .707 .577 .707 r
F P
0 g
s
.25312 .77279 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77279 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80569 L p .707 .577 .707 r
F P
0 g
s
.31434 .80569 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77089 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77089 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.33839 .66307 m .33839 .71865 L .35476 .71128 L p .707 .577 .707 r
F P
0 g
s
.35476 .71128 m .35476 .6557 L .33839 .66307 L p .707 .577 .707 r
F P
0 g
s
.17343 .66013 m .17343 .71571 L .19449 .72217 L p .707 .577 .707 r
F P
0 g
s
.61082 .39737 m .61082 .89926 L .63393 .88886 L p .707 .577 .707 r
F P
0 g
s
.63393 .88886 m .63393 .38697 L .61082 .39737 L p .707 .577 .707 r
F P
0 g
s
.66831 .66127 m .66831 .71686 L .64085 .71246 L p .707 .577 .707 r
F P
0 g
s
.64085 .71246 m .64085 .65688 L .66831 .66127 L p .707 .577 .707 r
F P
0 g
s
.70195 .86293 m .70195 .88146 L .68936 .87358 L p .707 .577 .707 r
F P
0 g
s
.68936 .87358 m .68936 .85505 L .70195 .86293 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80569 L .33839 .80004 L p .707 .577 .707 r
F P
0 g
s
.33839 .80004 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.17343 .71571 m .17343 .66013 L .16084 .65224 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.25312 .87873 m .25312 .8602 L .22195 .8583 L p .707 .577 .707 r
F P
0 g
s
.25312 .8602 m .25312 .87873 L .28495 .87795 L p .707 .577 .707 r
F P
0 g
s
.28495 .87795 m .28495 .85942 L .25312 .8602 L p .707 .577 .707 r
F P
0 g
s
.37794 .89511 m .37794 .39322 L .36016 .38209 L p .707 .577 .707 r
F P
0 g
s
.37794 .39322 m .37794 .89511 L .40766 .90422 L p .707 .577 .707 r
F P
0 g
s
.28495 .85942 m .28495 .87795 L .31434 .87457 L p .707 .577 .707 r
F P
0 g
s
.31434 .87457 m .31434 .85604 L .28495 .85942 L p .707 .577 .707 r
F P
0 g
s
.22195 .8583 m .22195 .87682 L .25312 .87873 L p .707 .577 .707 r
F P
0 g
s
.22195 .87682 m .22195 .8583 L .19449 .8539 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.16084 .65224 m .16084 .70783 L .17343 .71571 L p .707 .577 .707 r
F P
0 g
s
.35476 .6557 m .35476 .71128 L .36184 .70292 L p .707 .577 .707 r
F P
0 g
s
.36184 .70292 m .36184 .64734 L .35476 .6557 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80004 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.19449 .8539 m .19449 .87243 L .22195 .87682 L p .707 .577 .707 r
F P
0 g
s
.31434 .85604 m .31434 .87457 L .33839 .86892 L p .707 .577 .707 r
F P
0 g
s
.33839 .86892 m .33839 .85039 L .31434 .85604 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79385 L p .707 .577 .707 r
F P
0 g
s
.64085 .79385 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.68936 .85505 m .68936 .87358 L .66831 .86712 L p .707 .577 .707 r
F P
0 g
s
.66831 .86712 m .66831 .84859 L .68936 .85505 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75216 L p .707 .577 .707 r
F P
0 g
s
.16084 .70783 m .16084 .65224 L .15794 .6437 L p .707 .577 .707 r
F P
0 g
s
.19449 .87243 m .19449 .8539 L .17343 .84745 L p .707 .577 .707 r
F P
0 g
s
.66831 .84859 m .66831 .86712 L .64085 .86273 L p .707 .577 .707 r
F P
0 g
s
.64085 .86273 m .64085 .8442 L .66831 .84859 L p .707 .577 .707 r
F P
0 g
s
.63393 .38697 m .63393 .88886 L .64393 .87705 L p .707 .577 .707 r
F P
0 g
s
.64393 .87705 m .64393 .37516 L .63393 .38697 L p .707 .577 .707 r
F P
0 g
s
.17343 .84745 m .17343 .86598 L .19449 .87243 L p .707 .577 .707 r
F P
0 g
s
.16084 .75216 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.33839 .85039 m .33839 .86892 L .35476 .86155 L p .707 .577 .707 r
F P
0 g
s
.35476 .86155 m .35476 .84302 L .33839 .85039 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.15794 .6437 m .15794 .69928 L .16084 .70783 L p .707 .577 .707 r
F P
0 g
s
.36184 .64734 m .36184 .70292 L .35894 .69438 L p .707 .577 .707 r
F P
0 g
s
.35894 .69438 m .35894 .6388 L .36184 .64734 L p .707 .577 .707 r
F P
0 g
s
.35476 .84302 m .35476 .86155 L .36184 .85319 L p .707 .577 .707 r
F P
0 g
s
.36184 .85319 m .36184 .83466 L .35476 .84302 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .73871 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.35894 .6388 m .35894 .69438 L .34635 .68649 L p .707 .577 .707 r
F P
0 g
s
.34635 .68649 m .34635 .63091 L .35894 .6388 L p .707 .577 .707 r
F P
0 g
s
.36184 .83466 m .36184 .85319 L .35894 .84465 L p .707 .577 .707 r
F P
0 g
s
.35894 .84465 m .35894 .82612 L .36184 .83466 L p .707 .577 .707 r
F P
0 g
s
.36016 .88398 m .36016 .38209 L .35607 .37003 L p .707 .577 .707 r
F P
0 g
s
.36016 .38209 m .36016 .88398 L .37794 .89511 L p .707 .577 .707 r
F P
0 g
s
.17343 .86598 m .17343 .84745 L .16084 .83957 L p .707 .577 .707 r
F P
0 g
s
.16084 .78921 m .16084 .75216 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.16084 .83957 m .16084 .85809 L .17343 .86598 L p .707 .577 .707 r
F P
0 g
s
.15794 .69928 m .15794 .6437 L .16503 .63534 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.64393 .37516 m .64393 .87705 L .63984 .86499 L p .707 .577 .707 r
F P
0 g
s
.63984 .86499 m .63984 .3631 L .64393 .37516 L p .707 .577 .707 r
F P
0 g
s
.16503 .63534 m .16503 .69092 L .15794 .69928 L p .707 .577 .707 r
F P
0 g
s
.16084 .85809 m .16084 .83957 L .15794 .83102 L p .707 .577 .707 r
F P
0 g
s
.15794 .83102 m .15794 .84955 L .16084 .85809 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .69092 m .16503 .63534 L .1814 .62797 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .73871 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .73871 L p .707 .577 .707 r
F P
0 g
s
.35894 .82612 m .35894 .84465 L .34635 .83676 L p .707 .577 .707 r
F P
0 g
s
.34635 .83676 m .34635 .81823 L .35894 .82612 L p .707 .577 .707 r
F P
0 g
s
.35607 .37003 m .35607 .87192 L .36016 .88398 L p .707 .577 .707 r
F P
0 g
s
.35607 .87192 m .35607 .37003 L .36607 .35822 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .62797 m .1814 .68355 L .16503 .69092 L p .707 .577 .707 r
F P
0 g
s
.34635 .63091 m .34635 .68649 L .3253 .68004 L p .707 .577 .707 r
F P
0 g
s
.3253 .68004 m .3253 .62446 L .34635 .63091 L p .707 .577 .707 r
F P
0 g
s
.15794 .84955 m .15794 .83102 L .16503 .82266 L p .707 .577 .707 r
F P
0 g
s
.1814 .68355 m .1814 .62797 L .20545 .62232 L p .707 .577 .707 r
F P
0 g
s
.16503 .82266 m .16503 .84119 L .15794 .84955 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.63984 .3631 m .63984 .86499 L .62206 .85386 L p .707 .577 .707 r
F P
0 g
s
.62206 .85386 m .62206 .35197 L .63984 .3631 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76494 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.3253 .62446 m .3253 .68004 L .29784 .67565 L p .707 .577 .707 r
F P
0 g
s
.29784 .67565 m .29784 .62007 L .3253 .62446 L p .707 .577 .707 r
F P
0 g
s
.20545 .62232 m .20545 .6779 L .1814 .68355 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.36607 .86011 m .36607 .35822 L .38918 .34782 L p .707 .577 .707 r
F P
0 g
s
.36607 .35822 m .36607 .86011 L .35607 .87192 L p .707 .577 .707 r
F P
0 g
s
.20545 .6779 m .20545 .62232 L .23483 .61894 L p .707 .577 .707 r
F P
0 g
s
.16503 .84119 m .16503 .82266 L .1814 .81529 L p .707 .577 .707 r
F P
0 g
s
.1814 .76494 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.29784 .62007 m .29784 .67565 L .26667 .67375 L p .707 .577 .707 r
F P
0 g
s
.26667 .67375 m .26667 .61816 L .29784 .62007 L p .707 .577 .707 r
F P
0 g
s
.1814 .81529 m .1814 .83382 L .16503 .84119 L p .707 .577 .707 r
F P
0 g
s
.23483 .67452 m .23483 .61894 L .26667 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61894 m .23483 .67452 L .20545 .6779 L p .707 .577 .707 r
F P
0 g
s
.26667 .61816 m .26667 .67375 L .23483 .67452 L p .707 .577 .707 r
F P
0 g
s
.73333 .67323 m .73333 .61765 L .70216 .61575 L p .707 .577 .707 r
F P
0 g
s
.73333 .61765 m .73333 .67323 L .76517 .67246 L p .707 .577 .707 r
F P
0 g
s
.76517 .67246 m .76517 .61688 L .73333 .61765 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75929 L .1814 .76494 L p .707 .577 .707 r
F P
0 g
s
.76517 .61688 m .76517 .67246 L .79455 .66908 L p .707 .577 .707 r
F P
0 g
s
.79455 .66908 m .79455 .6135 L .76517 .61688 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71998 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.34635 .81823 m .34635 .83676 L .3253 .83031 L p .707 .577 .707 r
F P
0 g
s
.3253 .83031 m .3253 .81178 L .34635 .81823 L p .707 .577 .707 r
F P
0 g
s
.62206 .35197 m .62206 .85386 L .59233 .84475 L p .707 .577 .707 r
F P
0 g
s
.59233 .84475 m .59233 .34286 L .62206 .35197 L p .707 .577 .707 r
F P
0 g
s
.70216 .67133 m .70216 .61575 L .6747 .61136 L p .707 .577 .707 r
F P
0 g
s
.70216 .61575 m .70216 .67133 L .73333 .67323 L p .707 .577 .707 r
F P
0 g
s
.20545 .75929 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.79455 .6135 m .79455 .66908 L .8186 .66343 L p .707 .577 .707 r
F P
0 g
s
.8186 .66343 m .8186 .60785 L .79455 .6135 L p .707 .577 .707 r
F P
0 g
s
.1814 .83382 m .1814 .81529 L .20545 .80964 L p .707 .577 .707 r
F P
0 g
s
.29784 .71998 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71808 L .29784 .71998 L p .707 .577 .707 r
F P
0 g
s
.38918 .34782 m .38918 .84971 L .36607 .86011 L p .707 .577 .707 r
F P
0 g
s
.38918 .84971 m .38918 .34782 L .42314 .33984 L p .707 .577 .707 r
F P
0 g
s
.20545 .80964 m .20545 .82817 L .1814 .83382 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75929 L p .707 .577 .707 r
F P
0 g
s
.6747 .61136 m .6747 .66694 L .70216 .67133 L p .707 .577 .707 r
F P
0 g
s
.6747 .66694 m .6747 .61136 L .65365 .60491 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71808 L p .707 .577 .707 r
F P
0 g
s
.26667 .71808 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.3253 .81178 m .3253 .83031 L .29784 .82591 L p .707 .577 .707 r
F P
0 g
s
.29784 .82591 m .29784 .80739 L .3253 .81178 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71679 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.76517 .71679 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.8186 .60785 m .8186 .66343 L .83497 .65606 L p .707 .577 .707 r
F P
0 g
s
.83497 .65606 m .83497 .60048 L .8186 .60785 L p .707 .577 .707 r
F P
0 g
s
.20545 .82817 m .20545 .80964 L .23483 .80626 L p .707 .577 .707 r
F P
0 g
s
.59233 .34286 m .59233 .84475 L .55357 .83855 L p .707 .577 .707 r
F P
0 g
s
.55357 .83855 m .55357 .33666 L .59233 .34286 L p .707 .577 .707 r
F P
0 g
s
.65365 .60491 m .65365 .66049 L .6747 .66694 L p .707 .577 .707 r
F P
0 g
s
.23483 .80626 m .23483 .82479 L .20545 .82817 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.29784 .80739 m .29784 .82591 L .26667 .82401 L p .707 .577 .707 r
F P
0 g
s
.26667 .82401 m .26667 .80549 L .29784 .80739 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74833 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.65365 .66049 m .65365 .60491 L .64105 .59702 L p .707 .577 .707 r
F P
0 g
s
.23483 .82479 m .23483 .80626 L .26667 .80549 L p .707 .577 .707 r
F P
0 g
s
.42314 .84173 m .42314 .33984 L .46462 .33507 L p .707 .577 .707 r
F P
0 g
s
.42314 .33984 m .42314 .84173 L .38918 .84971 L p .707 .577 .707 r
F P
0 g
s
.26667 .80549 m .26667 .82401 L .23483 .82479 L p .707 .577 .707 r
F P
0 g
s
.6747 .74833 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.73333 .8235 m .73333 .80498 L .70216 .80307 L p .707 .577 .707 r
F P
0 g
s
.73333 .80498 m .73333 .8235 L .76517 .82273 L p .707 .577 .707 r
F P
0 g
s
.76517 .82273 m .76517 .8042 L .73333 .80498 L p .707 .577 .707 r
F P
0 g
s
.76517 .8042 m .76517 .82273 L .79455 .81935 L p .707 .577 .707 r
F P
0 g
s
.79455 .81935 m .79455 .80082 L .76517 .8042 L p .707 .577 .707 r
F P
0 g
s
.70216 .80307 m .70216 .8216 L .73333 .8235 L p .707 .577 .707 r
F P
0 g
s
.70216 .8216 m .70216 .80307 L .6747 .79868 L p .707 .577 .707 r
F P
0 g
s
.55357 .33666 m .55357 .83855 L .50956 .83587 L p .707 .577 .707 r
F P
0 g
s
.50956 .83587 m .50956 .33398 L .55357 .33666 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74833 L p .707 .577 .707 r
F P
0 g
s
.64105 .59702 m .64105 .6526 L .65365 .66049 L p .707 .577 .707 r
F P
0 g
s
.83497 .60048 m .83497 .65606 L .84205 .6477 L p .707 .577 .707 r
F P
0 g
s
.84205 .6477 m .84205 .59211 L .83497 .60048 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73745 L p .707 .577 .707 r
F P
0 g
s
.83497 .73745 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.6747 .79868 m .6747 .81721 L .70216 .8216 L p .707 .577 .707 r
F P
0 g
s
.46462 .83696 m .46462 .33507 L .50956 .33398 L p .707 .577 .707 r
F P
0 g
s
.46462 .33507 m .46462 .83696 L .42314 .84173 L p .707 .577 .707 r
F P
0 g
s
.79455 .80082 m .79455 .81935 L .8186 .8137 L p .707 .577 .707 r
F P
0 g
s
.8186 .8137 m .8186 .79517 L .79455 .80082 L p .707 .577 .707 r
F P
0 g
s
.50956 .33398 m .50956 .83587 L .46462 .83696 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .6526 m .64105 .59702 L .63816 .58848 L p .707 .577 .707 r
F P
0 g
s
.6747 .81721 m .6747 .79868 L .65365 .79223 L p .707 .577 .707 r
F P
0 g
s
.65365 .79223 m .65365 .81076 L .6747 .81721 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.8186 .79517 m .8186 .8137 L .83497 .80633 L p .707 .577 .707 r
F P
0 g
s
.83497 .80633 m .83497 .7878 L .8186 .79517 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73745 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69203 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .58848 m .63816 .64406 L .64105 .6526 L p .707 .577 .707 r
F P
0 g
s
.84205 .59211 m .84205 .6477 L .83916 .63915 L p .707 .577 .707 r
F P
0 g
s
.83916 .63915 m .83916 .58357 L .84205 .59211 L p .707 .577 .707 r
F P
0 g
s
.65365 .81076 m .65365 .79223 L .64105 .78434 L p .707 .577 .707 r
F P
0 g
s
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.64105 .78434 m .64105 .80287 L .65365 .81076 L p .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .63816 .58848 L .64524 .58011 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72545 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83497 .7878 m .83497 .80633 L .84206 .79796 L p .707 .577 .707 r
F P
0 g
s
.84206 .79796 m .84206 .77944 L .83497 .7878 L p .707 .577 .707 r
F P
0 g
s
.84206 .69203 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69203 L p .707 .577 .707 r
F P
0 g
s
.64524 .58011 m .64524 .6357 L .63816 .64406 L p .707 .577 .707 r
F P
0 g
s
.83916 .58357 m .83916 .63915 L .82657 .63127 L p .707 .577 .707 r
F P
0 g
s
.82657 .63127 m .82657 .57569 L .83916 .58357 L p .707 .577 .707 r
F P
0 g
s
.64105 .80287 m .64105 .78434 L .63816 .7758 L p .707 .577 .707 r
F P
0 g
s
.63816 .7758 m .63816 .79433 L .64105 .80287 L p .707 .577 .707 r
F P
0 g
s
.39032 .63642 m .39032 .58084 L .35915 .57894 L p .707 .577 .707 r
F P
0 g
s
.39032 .58084 m .39032 .63642 L .42216 .63564 L p .707 .577 .707 r
F P
0 g
s
.42216 .63564 m .42216 .58006 L .39032 .58084 L p .707 .577 .707 r
F P
0 g
s
.63816 .72545 m .63816 .68839 L .64524 .68003 L p .707 .577 .707 r
F P
0 g
s
.64524 .6357 m .64524 .58011 L .66161 .57275 L p .707 .577 .707 r
F P
0 g
s
.42216 .58006 m .42216 .63564 L .45154 .63226 L p .707 .577 .707 r
F P
0 g
s
.45154 .63226 m .45154 .57668 L .42216 .58006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35915 .63452 m .35915 .57894 L .33169 .57454 L p .707 .577 .707 r
F P
0 g
s
.35915 .57894 m .35915 .63452 L .39032 .63642 L p .707 .577 .707 r
F P
0 g
s
.64524 .68003 m .64524 .71708 L .63816 .72545 L p .707 .577 .707 r
F P
0 g
s
.84206 .77944 m .84206 .79796 L .83916 .78942 L p .707 .577 .707 r
F P
0 g
s
.83916 .78942 m .83916 .77089 L .84206 .77944 L p .707 .577 .707 r
F P
0 g
s
.45154 .57668 m .45154 .63226 L .47559 .62661 L p .707 .577 .707 r
F P
0 g
s
.47559 .62661 m .47559 .57103 L .45154 .57668 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .57275 m .66161 .62833 L .64524 .6357 L p .707 .577 .707 r
F P
0 g
s
.82657 .57569 m .82657 .63127 L .80551 .62482 L p .707 .577 .707 r
F P
0 g
s
.80551 .62482 m .80551 .56923 L .82657 .57569 L p .707 .577 .707 r
F P
0 g
s
.33169 .57454 m .33169 .63013 L .35915 .63452 L p .707 .577 .707 r
F P
0 g
s
.33169 .63013 m .33169 .57454 L .31064 .56809 L p .707 .577 .707 r
F P
0 g
s
.63816 .79433 m .63816 .7758 L .64524 .76744 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71703 L p .707 .577 .707 r
F P
0 g
s
.42216 .71703 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.66161 .62833 m .66161 .57275 L .68566 .5671 L p .707 .577 .707 r
F P
0 g
s
.64524 .76744 m .64524 .78596 L .63816 .79433 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68003 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71703 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67446 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.47559 .57103 m .47559 .62661 L .49196 .61925 L p .707 .577 .707 r
F P
0 g
s
.49196 .61925 m .49196 .56366 L .47559 .57103 L p .707 .577 .707 r
F P
0 g
s
.31064 .56809 m .31064 .62367 L .33169 .63013 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.80551 .56923 m .80551 .62482 L .77805 .62042 L p .707 .577 .707 r
F P
0 g
s
.77805 .62042 m .77805 .56484 L .80551 .56923 L p .707 .577 .707 r
F P
0 g
s
.83916 .77089 m .83916 .78942 L .82657 .78154 L p .707 .577 .707 r
F P
0 g
s
.82657 .78154 m .82657 .76301 L .83916 .77089 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.68566 .5671 m .68566 .62268 L .66161 .62833 L p .707 .577 .707 r
F P
0 g
s
.33169 .67446 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.31064 .62367 m .31064 .56809 L .29804 .56021 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66915 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.68566 .62268 m .68566 .5671 L .71504 .56372 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67446 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.39032 .78669 m .39032 .76816 L .35915 .76626 L p .707 .577 .707 r
F P
0 g
s
.39032 .76816 m .39032 .78669 L .42216 .78591 L p .707 .577 .707 r
F P
0 g
s
.42216 .78591 m .42216 .76738 L .39032 .76816 L p .707 .577 .707 r
F P
0 g
s
.64524 .78596 m .64524 .76744 L .66161 .76007 L p .707 .577 .707 r
F P
0 g
s
.42216 .76738 m .42216 .78591 L .45154 .78253 L p .707 .577 .707 r
F P
0 g
s
.45154 .78253 m .45154 .764 L .42216 .76738 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.35915 .76626 m .35915 .78479 L .39032 .78669 L p .707 .577 .707 r
F P
0 g
s
.77805 .56484 m .77805 .62042 L .74688 .61852 L p .707 .577 .707 r
F P
0 g
s
.74688 .61852 m .74688 .56294 L .77805 .56484 L p .707 .577 .707 r
F P
0 g
s
.35915 .78479 m .35915 .76626 L .33169 .76187 L p .707 .577 .707 r
F P
0 g
s
.66161 .76007 m .66161 .7786 L .64524 .78596 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70506 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.29804 .56021 m .29804 .61579 L .31064 .62367 L p .707 .577 .707 r
F P
0 g
s
.71504 .6193 m .71504 .56372 L .74688 .56294 L p .707 .577 .707 r
F P
0 g
s
.71504 .56372 m .71504 .6193 L .68566 .62268 L p .707 .577 .707 r
F P
0 g
s
.49196 .56366 m .49196 .61925 L .49904 .61088 L p .707 .577 .707 r
F P
0 g
s
.49904 .61088 m .49904 .5553 L .49196 .56366 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66358 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.33169 .76187 m .33169 .78039 L .35915 .78479 L p .707 .577 .707 r
F P
0 g
s
.74688 .56294 m .74688 .61852 L .71504 .6193 L p .707 .577 .707 r
F P
0 g
s
.45154 .764 m .45154 .78253 L .47559 .77688 L p .707 .577 .707 r
F P
0 g
s
.47559 .77688 m .47559 .75835 L .45154 .764 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66915 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66915 L p .707 .577 .707 r
F P
0 g
s
.82657 .76301 m .82657 .78154 L .80551 .77508 L p .707 .577 .707 r
F P
0 g
s
.80551 .77508 m .80551 .75656 L .82657 .76301 L p .707 .577 .707 r
F P
0 g
s
.31064 .70506 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.29804 .61579 m .29804 .56021 L .29515 .55166 L p .707 .577 .707 r
F P
0 g
s
.33169 .78039 m .33169 .76187 L .31064 .75541 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.31064 .75541 m .31064 .77394 L .33169 .78039 L p .707 .577 .707 r
F P
0 g
s
.66161 .7786 m .66161 .76007 L .68566 .75442 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70506 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.68566 .75442 m .68566 .77295 L .66161 .7786 L p .707 .577 .707 r
F P
0 g
s
.47559 .75835 m .47559 .77688 L .49196 .76951 L p .707 .577 .707 r
F P
0 g
s
.49196 .76951 m .49196 .75099 L .47559 .75835 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66358 m .49196 .70063 L .49904 .69227 L p .707 .577 .707 r
F P
0 g
s
.49904 .69227 m .49904 .65521 L .49196 .66358 L p .707 .577 .707 r
F P
0 g
s
.29515 .55166 m .29515 .60725 L .29804 .61579 L p .707 .577 .707 r
F P
0 g
s
.49904 .5553 m .49904 .61088 L .49615 .60234 L p .707 .577 .707 r
F P
0 g
s
.49615 .60234 m .49615 .54676 L .49904 .5553 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.80551 .75656 m .80551 .77508 L .77805 .77069 L p .707 .577 .707 r
F P
0 g
s
.77805 .77069 m .77805 .75216 L .80551 .75656 L p .707 .577 .707 r
F P
0 g
s
.31064 .77394 m .31064 .75541 L .29804 .74753 L p .707 .577 .707 r
F P
0 g
s
.68566 .77295 m .68566 .75442 L .71504 .75104 L p .707 .577 .707 r
F P
0 g
s
.29804 .69717 m .29804 .66012 L .29515 .65158 L p .707 .577 .707 r
F P
0 g
s
.29804 .74753 m .29804 .76606 L .31064 .77394 L p .707 .577 .707 r
F P
0 g
s
.29515 .60725 m .29515 .55166 L .30223 .5433 L p .707 .577 .707 r
F P
0 g
s
.71504 .75104 m .71504 .76957 L .68566 .77295 L p .707 .577 .707 r
F P
0 g
s
.77805 .75216 m .77805 .77069 L .74688 .76879 L p .707 .577 .707 r
F P
0 g
s
.74688 .76879 m .74688 .75026 L .77805 .75216 L p .707 .577 .707 r
F P
0 g
s
.29515 .65158 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.71504 .76957 m .71504 .75104 L .74688 .75026 L p .707 .577 .707 r
F P
0 g
s
.49196 .75099 m .49196 .76951 L .49904 .76115 L p .707 .577 .707 r
F P
0 g
s
.49904 .76115 m .49904 .74262 L .49196 .75099 L p .707 .577 .707 r
F P
0 g
s
.74688 .75026 m .74688 .76879 L .71504 .76957 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69227 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .5433 m .30223 .59888 L .29515 .60725 L p .707 .577 .707 r
F P
0 g
s
.49615 .54676 m .49615 .60234 L .48356 .59445 L p .707 .577 .707 r
F P
0 g
s
.48356 .59445 m .48356 .53887 L .49615 .54676 L p .707 .577 .707 r
F P
0 g
s
.29804 .76606 m .29804 .74753 L .29515 .73899 L p .707 .577 .707 r
F P
0 g
s
.29515 .73899 m .29515 .75751 L .29804 .76606 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65158 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .59888 m .30223 .5433 L .3186 .53593 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .64321 m .30223 .68027 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49904 .74262 m .49904 .76115 L .49615 .75261 L p .707 .577 .707 r
F P
0 g
s
.49615 .75261 m .49615 .73408 L .49904 .74262 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .53593 m .3186 .59151 L .30223 .59888 L p .707 .577 .707 r
F P
0 g
s
.48356 .53887 m .48356 .59445 L .4625 .588 L p .707 .577 .707 r
F P
0 g
s
.4625 .588 m .4625 .53242 L .48356 .53887 L p .707 .577 .707 r
F P
0 g
s
.29515 .75751 m .29515 .73899 L .30223 .73062 L p .707 .577 .707 r
F P
0 g
s
.3186 .59151 m .3186 .53593 L .34265 .53028 L p .707 .577 .707 r
F P
0 g
s
.30223 .73062 m .30223 .74915 L .29515 .75751 L p .707 .577 .707 r
F P
0 g
s
.30223 .68027 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68027 L p .707 .577 .707 r
F P
0 g
s
.4625 .53242 m .4625 .588 L .43504 .58361 L p .707 .577 .707 r
F P
0 g
s
.43504 .58361 m .43504 .52803 L .4625 .53242 L p .707 .577 .707 r
F P
0 g
s
.49615 .73408 m .49615 .75261 L .48356 .74472 L p .707 .577 .707 r
F P
0 g
s
.48356 .74472 m .48356 .7262 L .49615 .73408 L p .707 .577 .707 r
F P
0 g
s
.34265 .53028 m .34265 .58586 L .3186 .59151 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66939 L p .707 .577 .707 r
F P
0 g
s
.4625 .66939 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.34265 .58586 m .34265 .53028 L .37203 .5269 L p .707 .577 .707 r
F P
0 g
s
.30223 .74915 m .30223 .73062 L .3186 .72325 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.43504 .52803 m .43504 .58361 L .40387 .58171 L p .707 .577 .707 r
F P
0 g
s
.40387 .58171 m .40387 .52613 L .43504 .52803 L p .707 .577 .707 r
F P
0 g
s
.3186 .72325 m .3186 .74178 L .30223 .74915 L p .707 .577 .707 r
F P
0 g
s
.37203 .58249 m .37203 .5269 L .40387 .52613 L p .707 .577 .707 r
F P
0 g
s
.37203 .5269 m .37203 .58249 L .34265 .58586 L p .707 .577 .707 r
F P
0 g
s
.40387 .52613 m .40387 .58171 L .37203 .58249 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66939 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.48356 .7262 m .48356 .74472 L .4625 .73827 L p .707 .577 .707 r
F P
0 g
s
.4625 .73827 m .4625 .71974 L .48356 .7262 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.3186 .74178 m .3186 .72325 L .34265 .7176 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.34265 .7176 m .34265 .73613 L .3186 .74178 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
.4625 .71974 m .4625 .73827 L .43504 .73388 L p .707 .577 .707 r
F P
0 g
s
.43504 .73388 m .43504 .71535 L .4625 .71974 L p .707 .577 .707 r
F P
0 g
s
.34265 .73613 m .34265 .7176 L .37203 .71423 L p .707 .577 .707 r
F P
0 g
s
.37203 .71423 m .37203 .73275 L .34265 .73613 L p .707 .577 .707 r
F P
0 g
s
.43504 .71535 m .43504 .73388 L .40387 .73198 L p .707 .577 .707 r
F P
0 g
s
.40387 .73198 m .40387 .71345 L .43504 .71535 L p .707 .577 .707 r
F P
0 g
s
.37203 .73275 m .37203 .71423 L .40387 .71345 L p .707 .577 .707 r
F P
0 g
s
.40387 .71345 m .40387 .73198 L .37203 .73275 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eoo`00MWoo2@001EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<000UJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool0
06Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001W
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<0
05YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001J
EP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06
001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo0017Ool90004Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h000AJEP03001JEUYF009J
EPL00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH:0008
FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP0
00QJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEQT00003FUH005YF009JEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000=JEP03001JEP0000=JEP<00004FUH0
00000002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF1P00
00=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<0
05YFFUH01UYF100000=JEP00FUH00P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool00`00
FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH3000`Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004FUH0
1000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD000=JEP04001JEUYFFUH2000LOol400000eYF
001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH00`00FUIJEP05FUH900000eYF001J
EP03FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P000eYF1P000eYF0P005Goo1`000eYF0`000eYF0P00;Goo000`Ool30004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUH0000;0004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@001Goo
0`0000=oo`0000001`000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUHI00000eYF001JEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000fOol90003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@00
15YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000cOol40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00;Woo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF20000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP@000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEP80009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00AJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP@0009JEQ`003Yoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF4@000eYF0P000UYF0`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol002aoo`03001J
EP0000AJEP03001JEUYF00=JEPH0015oo`D000=JEP03001JEP00008000EJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
00000eYF0000000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH4000fOol002aoo`03001JEP0000AJEP03001JEP0000<001Yoo`8000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEPL001]oo`05001JEUYFFUH00005FUH01000
FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH2000aOol002aoo`04001JEP00FUH20005FUH00`00FUH00003000HOol01000FUIJ
EP001EYF00<005YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP03FUHL0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YF00000P000UYF00<005YFFUH00P006Goo1@0015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YF000010001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`001EYF00D005YFFUIJEP0001ioo`<00003FUH005YF009JEP8002eoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF001JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000POol20003FUH2000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF6@001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2
000ROol200000eYF0000000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002=oo`@002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2
000QOol2000015YF00000000;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000<000AJEP04001JEUYFFUH2000L
Ool50003FUH00`00FUH0000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH60003FUH2000EOol70003FUH00`00FUIJEP02FUH2
000^Ool003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000kOolP000:Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH000080004FUH00`00FUIJEP02FUH9000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004Ool90018Ool0
02eoo`8000AJEP03001JEUYF00=JEPH001Moo`@0009JEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00EWoo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00@005YF000005Qoo`00;7oo00<005YF00000eYF0`00:Woo10000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00=JEP<005Yoo`00;7oo00@005YF001JEP80035oo`03
001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH00003001MOol0
02aoo`04001JEP00000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH60002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004001QOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00008006=oo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P000UYF
00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool2
0003FUH00`00FUIJEP02FUH3000ROol400000eYF001JEP02FUH20002FUH01000FUIJEUYF0P001EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
100015YF00<005YF00001EYF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF00001EYF00<005YF
00000`006Goo1@001EYF00@005YFFUIJEP80009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF
00<005YF00001EYF00<005YFFUH00UYF0P00FGoo000^Ool01000FUIJEP001EYF00<005YFFUH00eYF
6@000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP<00003FUH005YF00AJEP03001JEUYF00=JEP<005Moo`00;goo0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YFFUH007oo001J
EP000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00=JEP03
001JEUYF008005Eoo`00<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0`000Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
0P0000AJEP00Oomoo`D000AJEP05001JEUYFFUH0001EOol003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40004Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001goo0`0000=JEP00FUH00UYF0P00E7oo000fOol50004
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH70008Ool20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000002Woo0P000eYF0P00E7oo000kOolK000?Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0037oo0P0000=JEP000000E7oo001VOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000>Ool4001DOol006Ioo`03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000eoo`800004FUH00000001DOol006Moo`80009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000Uoo`D000=JEP03001JEP0005Aoo`00JGoo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YFFUIJEP8000Aoo`L000=JEP03001JEUYF009JEP03001JEP0005Aoo`00Jgoo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YF00001`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001]Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo001_Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000F7oo001bOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001J
Ool007Uoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<005eoo`00QGoo5P0000=oo`0000001`0015YF00<005YFFUH01UYF00<005YF
FUH00UYF1@00HGoo002UOolB001VOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75925 m .59613 .70366 L .56496 .70176 L p .707 .577 .707 r
F P
0 g
s
.59613 .70366 m .59613 .75925 L .62796 .75847 L p .707 .577 .707 r
F P
0 g
s
.62796 .75847 m .62796 .70289 L .59613 .70366 L p .707 .577 .707 r
F P
0 g
s
.62796 .70289 m .62796 .75847 L .65735 .75509 L p .707 .577 .707 r
F P
0 g
s
.65735 .75509 m .65734 .69951 L .62796 .70289 L p .707 .577 .707 r
F P
0 g
s
.56496 .75735 m .56496 .70176 L .5375 .69737 L p .707 .577 .707 r
F P
0 g
s
.56496 .70176 m .56496 .75735 L .59613 .75925 L p .707 .577 .707 r
F P
0 g
s
.65734 .69951 m .65735 .75509 L .6814 .74944 L p .707 .577 .707 r
F P
0 g
s
.6814 .74944 m .6814 .69386 L .65734 .69951 L p .707 .577 .707 r
F P
0 g
s
.5375 .69737 m .5375 .75295 L .56496 .75735 L p .707 .577 .707 r
F P
0 g
s
.5375 .75295 m .5375 .69737 L .51644 .69092 L p .707 .577 .707 r
F P
0 g
s
.59613 .8326 m .59613 .79555 L .56496 .79365 L p .707 .577 .707 r
F P
0 g
s
.59613 .79555 m .59613 .8326 L .62796 .83182 L p .707 .577 .707 r
F P
0 g
s
.62796 .83182 m .62796 .79477 L .59613 .79555 L p .707 .577 .707 r
F P
0 g
s
.62796 .79477 m .62796 .83182 L .65735 .82844 L p .707 .577 .707 r
F P
0 g
s
.65735 .82844 m .65735 .79139 L .62796 .79477 L p .707 .577 .707 r
F P
0 g
s
.56496 .8307 m .56496 .79365 L .5375 .78925 L p .707 .577 .707 r
F P
0 g
s
.56496 .79365 m .56496 .8307 L .59613 .8326 L p .707 .577 .707 r
F P
0 g
s
.6814 .69386 m .6814 .74944 L .69777 .74207 L p .707 .577 .707 r
F P
0 g
s
.69777 .74207 m .69777 .68649 L .6814 .69386 L p .707 .577 .707 r
F P
0 g
s
.51644 .69092 m .51644 .7465 L .5375 .75295 L p .707 .577 .707 r
F P
0 g
s
.65735 .79139 m .65735 .82844 L .6814 .8228 L p .707 .577 .707 r
F P
0 g
s
.6814 .8228 m .6814 .78574 L .65735 .79139 L p .707 .577 .707 r
F P
0 g
s
.5375 .78925 m .5375 .82631 L .56496 .8307 L p .707 .577 .707 r
F P
0 g
s
.51644 .7465 m .51644 .69092 L .50385 .68303 L p .707 .577 .707 r
F P
0 g
s
.59613 .89115 m .59613 .87263 L .56496 .87072 L p .707 .577 .707 r
F P
0 g
s
.59613 .87263 m .59613 .89115 L .62796 .89038 L p .707 .577 .707 r
F P
0 g
s
.62796 .89038 m .62796 .87185 L .59613 .87263 L p .707 .577 .707 r
F P
0 g
s
.5375 .82631 m .5375 .78925 L .51644 .7828 L p .707 .577 .707 r
F P
0 g
s
.62796 .87185 m .62796 .89038 L .65735 .887 L p .707 .577 .707 r
F P
0 g
s
.65735 .887 m .65735 .86847 L .62796 .87185 L p .707 .577 .707 r
F P
0 g
s
.56496 .87072 m .56496 .88925 L .59613 .89115 L p .707 .577 .707 r
F P
0 g
s
.56496 .88925 m .56496 .87072 L .5375 .86633 L p .707 .577 .707 r
F P
0 g
s
.51644 .7828 m .51644 .81985 L .5375 .82631 L p .707 .577 .707 r
F P
0 g
s
.5375 .86633 m .5375 .88486 L .56496 .88925 L p .707 .577 .707 r
F P
0 g
s
.6814 .78574 m .6814 .8228 L .69777 .81543 L p .707 .577 .707 r
F P
0 g
s
.69777 .81543 m .69777 .77837 L .6814 .78574 L p .707 .577 .707 r
F P
0 g
s
.50385 .68303 m .50385 .73862 L .51644 .7465 L p .707 .577 .707 r
F P
0 g
s
.69777 .68649 m .69777 .74207 L .70485 .73371 L p .707 .577 .707 r
F P
0 g
s
.70485 .73371 m .70485 .67813 L .69777 .68649 L p .707 .577 .707 r
F P
0 g
s
.65735 .86847 m .65735 .887 L .6814 .88135 L p .707 .577 .707 r
F P
0 g
s
.6814 .88135 m .6814 .86282 L .65735 .86847 L p .707 .577 .707 r
F P
0 g
s
.5375 .88486 m .5375 .86633 L .51644 .85988 L p .707 .577 .707 r
F P
0 g
s
.51644 .81985 m .51644 .7828 L .50385 .77492 L p .707 .577 .707 r
F P
0 g
s
.50385 .73862 m .50385 .68303 L .50095 .67449 L p .707 .577 .707 r
F P
0 g
s
.51644 .85988 m .51644 .87841 L .5375 .88486 L p .707 .577 .707 r
F P
0 g
s
.50385 .77492 m .50385 .81197 L .51644 .81985 L p .707 .577 .707 r
F P
0 g
s
.6814 .86282 m .6814 .88135 L .69777 .87398 L p .707 .577 .707 r
F P
0 g
s
.69777 .87398 m .69777 .85545 L .6814 .86282 L p .707 .577 .707 r
F P
0 g
s
.69777 .77837 m .69777 .81543 L .70485 .80706 L p .707 .577 .707 r
F P
0 g
s
.70485 .80706 m .70485 .77001 L .69777 .77837 L p .707 .577 .707 r
F P
0 g
s
.50095 .67449 m .50095 .73007 L .50385 .73862 L p .707 .577 .707 r
F P
0 g
s
.70485 .67813 m .70485 .73371 L .70195 .72517 L p .707 .577 .707 r
F P
0 g
s
.70195 .72517 m .70195 .66958 L .70485 .67813 L p .707 .577 .707 r
F P
0 g
s
.51644 .87841 m .51644 .85988 L .50385 .85199 L p .707 .577 .707 r
F P
0 g
s
.50385 .85199 m .50385 .87052 L .51644 .87841 L p .707 .577 .707 r
F P
0 g
s
.50385 .81197 m .50385 .77492 L .50095 .76637 L p .707 .577 .707 r
F P
0 g
s
.50095 .73007 m .50095 .67449 L .50804 .66613 L p .707 .577 .707 r
F P
0 g
s
.69777 .85545 m .69777 .87398 L .70485 .86561 L p .707 .577 .707 r
F P
0 g
s
.70485 .86561 m .70485 .84709 L .69777 .85545 L p .707 .577 .707 r
F P
0 g
s
.50095 .76637 m .50095 .80343 L .50385 .81197 L p .707 .577 .707 r
F P
0 g
s
.49044 .87824 m .49044 .37636 L .44643 .37367 L p .707 .577 .707 r
F P
0 g
s
.50804 .66613 m .50804 .72171 L .50095 .73007 L p .707 .577 .707 r
F P
0 g
s
.50385 .87052 m .50385 .85199 L .50095 .84345 L p .707 .577 .707 r
F P
0 g
s
.50095 .84345 m .50095 .86198 L .50385 .87052 L p .707 .577 .707 r
F P
0 g
s
.50095 .80343 m .50095 .76637 L .50804 .75801 L p .707 .577 .707 r
F P
0 g
s
.50804 .72171 m .50804 .66613 L .5244 .65876 L p .707 .577 .707 r
F P
0 g
s
.50804 .75801 m .50804 .79506 L .50095 .80343 L p .707 .577 .707 r
F P
0 g
s
.5244 .65876 m .5244 .71434 L .50804 .72171 L p .707 .577 .707 r
F P
0 g
s
.50095 .86198 m .50095 .84345 L .50804 .83509 L p .707 .577 .707 r
F P
0 g
s
.50804 .83509 m .50804 .85362 L .50095 .86198 L p .707 .577 .707 r
F P
0 g
s
.50804 .79506 m .50804 .75801 L .5244 .75064 L p .707 .577 .707 r
F P
0 g
s
.5244 .75064 m .5244 .7877 L .50804 .79506 L p .707 .577 .707 r
F P
0 g
s
.50804 .85362 m .50804 .83509 L .5244 .82772 L p .707 .577 .707 r
F P
0 g
s
.5244 .7877 m .5244 .75064 L .54846 .74499 L p .707 .577 .707 r
F P
0 g
s
.5244 .82772 m .5244 .84625 L .50804 .85362 L p .707 .577 .707 r
F P
0 g
s
.54846 .74499 m .54846 .78205 L .5244 .7877 L p .707 .577 .707 r
F P
0 g
s
.5244 .84625 m .5244 .82772 L .54846 .82207 L p .707 .577 .707 r
F P
0 g
s
.54846 .82207 m .54846 .8406 L .5244 .84625 L p .707 .577 .707 r
F P
0 g
s
.49044 .37636 m .49044 .87824 L .53538 .87715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71434 m .5244 .65876 L .54846 .65311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65311 m .54846 .70869 L .5244 .71434 L p .707 .577 .707 r
F P
0 g
s
.53538 .87715 m .53538 .37526 L .49044 .37636 L p .707 .577 .707 r
F P
0 g
s
.70485 .77001 m .70485 .80706 L .70195 .79852 L p .707 .577 .707 r
F P
0 g
s
.70195 .79852 m .70195 .76147 L .70485 .77001 L p .707 .577 .707 r
F P
0 g
s
.54846 .70869 m .54846 .65311 L .57784 .64973 L p .707 .577 .707 r
F P
0 g
s
.57784 .64973 m .57784 .70531 L .54846 .70869 L p .707 .577 .707 r
F P
0 g
s
.54846 .78205 m .54846 .74499 L .57784 .74161 L p .707 .577 .707 r
F P
0 g
s
.57784 .74161 m .57784 .77867 L .54846 .78205 L p .707 .577 .707 r
F P
0 g
s
.54846 .8406 m .54846 .82207 L .57784 .81869 L p .707 .577 .707 r
F P
0 g
s
.57784 .81869 m .57784 .83722 L .54846 .8406 L p .707 .577 .707 r
F P
0 g
s
.53538 .37526 m .53538 .87715 L .57686 .87238 L p .707 .577 .707 r
F P
0 g
s
.57686 .87238 m .57686 .37049 L .53538 .37526 L p .707 .577 .707 r
F P
0 g
s
.70195 .66958 m .70195 .72517 L .68936 .71728 L p .707 .577 .707 r
F P
0 g
s
.68936 .71728 m .68936 .6617 L .70195 .66958 L p .707 .577 .707 r
F P
0 g
s
.44643 .87556 m .44643 .37367 L .40766 .36747 L p .707 .577 .707 r
F P
0 g
s
.44643 .37367 m .44643 .87556 L .49044 .87824 L p .707 .577 .707 r
F P
0 g
s
.25312 .72243 m .25312 .66685 L .22195 .66495 L p .707 .577 .707 r
F P
0 g
s
.25312 .66685 m .25312 .72243 L .28495 .72165 L p .707 .577 .707 r
F P
0 g
s
.28495 .72165 m .28495 .66607 L .25312 .66685 L p .707 .577 .707 r
F P
0 g
s
.28495 .66607 m .28495 .72165 L .31434 .71828 L p .707 .577 .707 r
F P
0 g
s
.31434 .71828 m .31434 .66269 L .28495 .66607 L p .707 .577 .707 r
F P
0 g
s
.57784 .70531 m .57784 .64973 L .60968 .64895 L p .707 .577 .707 r
F P
0 g
s
.60968 .64895 m .60968 .70454 L .57784 .70531 L p .707 .577 .707 r
F P
0 g
s
.57784 .77867 m .57784 .74161 L .60968 .74084 L p .707 .577 .707 r
F P
0 g
s
.60968 .74084 m .60968 .77789 L .57784 .77867 L p .707 .577 .707 r
F P
0 g
s
.57784 .83722 m .57784 .81869 L .60968 .81791 L p .707 .577 .707 r
F P
0 g
s
.60968 .81791 m .60968 .83644 L .57784 .83722 L p .707 .577 .707 r
F P
0 g
s
.57686 .37049 m .57686 .87238 L .61082 .8644 L p .707 .577 .707 r
F P
0 g
s
.64085 .65085 m .64085 .70644 L .60968 .70454 L p .707 .577 .707 r
F P
0 g
s
.60968 .70454 m .60968 .64895 L .64085 .65085 L p .707 .577 .707 r
F P
0 g
s
.64085 .74274 m .64085 .77979 L .60968 .77789 L p .707 .577 .707 r
F P
0 g
s
.60968 .77789 m .60968 .74084 L .64085 .74274 L p .707 .577 .707 r
F P
0 g
s
.64085 .81982 m .64085 .83834 L .60968 .83644 L p .707 .577 .707 r
F P
0 g
s
.60968 .83644 m .60968 .81791 L .64085 .81982 L p .707 .577 .707 r
F P
0 g
s
.61082 .8644 m .61082 .36251 L .57686 .37049 L p .707 .577 .707 r
F P
0 g
s
.70485 .84709 m .70485 .86561 L .70195 .85707 L p .707 .577 .707 r
F P
0 g
s
.70195 .85707 m .70195 .83855 L .70485 .84709 L p .707 .577 .707 r
F P
0 g
s
.22195 .72053 m .22195 .66495 L .19449 .66056 L p .707 .577 .707 r
F P
0 g
s
.22195 .66495 m .22195 .72053 L .25312 .72243 L p .707 .577 .707 r
F P
0 g
s
.40766 .86936 m .40766 .36747 L .37794 .35836 L p .707 .577 .707 r
F P
0 g
s
.40766 .36747 m .40766 .86936 L .44643 .87556 L p .707 .577 .707 r
F P
0 g
s
.31434 .66269 m .31434 .71828 L .33839 .71263 L p .707 .577 .707 r
F P
0 g
s
.33839 .71263 m .33839 .65704 L .31434 .66269 L p .707 .577 .707 r
F P
0 g
s
.70195 .76147 m .70195 .79852 L .68936 .79064 L p .707 .577 .707 r
F P
0 g
s
.68936 .79064 m .68936 .75358 L .70195 .76147 L p .707 .577 .707 r
F P
0 g
s
.68936 .6617 m .68936 .71728 L .66831 .71083 L p .707 .577 .707 r
F P
0 g
s
.66831 .71083 m .66831 .65525 L .68936 .6617 L p .707 .577 .707 r
F P
0 g
s
.19449 .66056 m .19449 .71614 L .22195 .72053 L p .707 .577 .707 r
F P
0 g
s
.19449 .71614 m .19449 .66056 L .17343 .6541 L p .707 .577 .707 r
F P
0 g
s
.25312 .79579 m .25312 .75873 L .22195 .75683 L p .707 .577 .707 r
F P
0 g
s
.25312 .75873 m .25312 .79579 L .28495 .79501 L p .707 .577 .707 r
F P
0 g
s
.28495 .79501 m .28495 .75795 L .25312 .75873 L p .707 .577 .707 r
F P
0 g
s
.28495 .75795 m .28495 .79501 L .31434 .79163 L p .707 .577 .707 r
F P
0 g
s
.31434 .79163 m .31434 .75457 L .28495 .75795 L p .707 .577 .707 r
F P
0 g
s
.61082 .36251 m .61082 .8644 L .63393 .854 L p .707 .577 .707 r
F P
0 g
s
.63393 .854 m .63393 .35211 L .61082 .36251 L p .707 .577 .707 r
F P
0 g
s
.22195 .79389 m .22195 .75683 L .19449 .75244 L p .707 .577 .707 r
F P
0 g
s
.22195 .75683 m .22195 .79389 L .25312 .79579 L p .707 .577 .707 r
F P
0 g
s
.33839 .65704 m .33839 .71263 L .35476 .70526 L p .707 .577 .707 r
F P
0 g
s
.35476 .70526 m .35476 .64968 L .33839 .65704 L p .707 .577 .707 r
F P
0 g
s
.70195 .83855 m .70195 .85707 L .68936 .84919 L p .707 .577 .707 r
F P
0 g
s
.68936 .84919 m .68936 .83066 L .70195 .83855 L p .707 .577 .707 r
F P
0 g
s
.17343 .6541 m .17343 .70968 L .19449 .71614 L p .707 .577 .707 r
F P
0 g
s
.31434 .75457 m .31434 .79163 L .33839 .78598 L p .707 .577 .707 r
F P
0 g
s
.33839 .78598 m .33839 .74893 L .31434 .75457 L p .707 .577 .707 r
F P
0 g
s
.66831 .65525 m .66831 .71083 L .64085 .70644 L p .707 .577 .707 r
F P
0 g
s
.64085 .70644 m .64085 .65085 L .66831 .65525 L p .707 .577 .707 r
F P
0 g
s
.19449 .75244 m .19449 .78949 L .22195 .79389 L p .707 .577 .707 r
F P
0 g
s
.68936 .75358 m .68936 .79064 L .66831 .78418 L p .707 .577 .707 r
F P
0 g
s
.66831 .78418 m .66831 .74713 L .68936 .75358 L p .707 .577 .707 r
F P
0 g
s
.17343 .70968 m .17343 .6541 L .16084 .64622 L p .707 .577 .707 r
F P
0 g
s
.37794 .86025 m .37794 .35836 L .36016 .34723 L p .707 .577 .707 r
F P
0 g
s
.37794 .35836 m .37794 .86025 L .40766 .86936 L p .707 .577 .707 r
F P
0 g
s
.25312 .85434 m .25312 .83581 L .22195 .83391 L p .707 .577 .707 r
F P
0 g
s
.25312 .83581 m .25312 .85434 L .28495 .85356 L p .707 .577 .707 r
F P
0 g
s
.28495 .85356 m .28495 .83503 L .25312 .83581 L p .707 .577 .707 r
F P
0 g
s
.19449 .78949 m .19449 .75244 L .17343 .74598 L p .707 .577 .707 r
F P
0 g
s
.28495 .83503 m .28495 .85356 L .31434 .85018 L p .707 .577 .707 r
F P
0 g
s
.31434 .85018 m .31434 .83165 L .28495 .83503 L p .707 .577 .707 r
F P
0 g
s
.22195 .83391 m .22195 .85244 L .25312 .85434 L p .707 .577 .707 r
F P
0 g
s
.22195 .85244 m .22195 .83391 L .19449 .82952 L p .707 .577 .707 r
F P
0 g
s
.17343 .74598 m .17343 .78304 L .19449 .78949 L p .707 .577 .707 r
F P
0 g
s
.19449 .82952 m .19449 .84804 L .22195 .85244 L p .707 .577 .707 r
F P
0 g
s
.33839 .74893 m .33839 .78598 L .35476 .77861 L p .707 .577 .707 r
F P
0 g
s
.35476 .77861 m .35476 .74156 L .33839 .74893 L p .707 .577 .707 r
F P
0 g
s
.16084 .64622 m .16084 .7018 L .17343 .70968 L p .707 .577 .707 r
F P
0 g
s
.35476 .64968 m .35476 .70526 L .36184 .69689 L p .707 .577 .707 r
F P
0 g
s
.36184 .69689 m .36184 .64131 L .35476 .64968 L p .707 .577 .707 r
F P
0 g
s
.31434 .83165 m .31434 .85018 L .33839 .84453 L p .707 .577 .707 r
F P
0 g
s
.33839 .84453 m .33839 .826 L .31434 .83165 L p .707 .577 .707 r
F P
0 g
s
.68936 .83066 m .68936 .84919 L .66831 .84273 L p .707 .577 .707 r
F P
0 g
s
.66831 .84273 m .66831 .82421 L .68936 .83066 L p .707 .577 .707 r
F P
0 g
s
.66831 .74713 m .66831 .78418 L .64085 .77979 L p .707 .577 .707 r
F P
0 g
s
.64085 .77979 m .64085 .74274 L .66831 .74713 L p .707 .577 .707 r
F P
0 g
s
.66831 .82421 m .66831 .84273 L .64085 .83834 L p .707 .577 .707 r
F P
0 g
s
.64085 .83834 m .64085 .81982 L .66831 .82421 L p .707 .577 .707 r
F P
0 g
s
.63393 .35211 m .63393 .854 L .64393 .84219 L p .707 .577 .707 r
F P
0 g
s
.64393 .84219 m .64393 .3403 L .63393 .35211 L p .707 .577 .707 r
F P
0 g
s
.19449 .84804 m .19449 .82952 L .17343 .82306 L p .707 .577 .707 r
F P
0 g
s
.17343 .78304 m .17343 .74598 L .16084 .7381 L p .707 .577 .707 r
F P
0 g
s
.16084 .7018 m .16084 .64622 L .15794 .63768 L p .707 .577 .707 r
F P
0 g
s
.17343 .82306 m .17343 .84159 L .19449 .84804 L p .707 .577 .707 r
F P
0 g
s
.16084 .7381 m .16084 .77515 L .17343 .78304 L p .707 .577 .707 r
F P
0 g
s
.33839 .826 m .33839 .84453 L .35476 .83716 L p .707 .577 .707 r
F P
0 g
s
.35476 .83716 m .35476 .81864 L .33839 .826 L p .707 .577 .707 r
F P
0 g
s
.35476 .74156 m .35476 .77861 L .36184 .77025 L p .707 .577 .707 r
F P
0 g
s
.36184 .77025 m .36184 .73319 L .35476 .74156 L p .707 .577 .707 r
F P
0 g
s
.36184 .64131 m .36184 .69689 L .35894 .68835 L p .707 .577 .707 r
F P
0 g
s
.35894 .68835 m .35894 .63277 L .36184 .64131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81864 m .35476 .83716 L .36184 .8288 L p .707 .577 .707 r
F P
0 g
s
.36184 .8288 m .36184 .81027 L .35476 .81864 L p .707 .577 .707 r
F P
0 g
s
.36184 .73319 m .36184 .77025 L .35894 .76171 L p .707 .577 .707 r
F P
0 g
s
.35894 .76171 m .35894 .72465 L .36184 .73319 L p .707 .577 .707 r
F P
0 g
s
.35894 .63277 m .35894 .68835 L .34635 .68047 L p .707 .577 .707 r
F P
0 g
s
.34635 .68047 m .34635 .62489 L .35894 .63277 L p .707 .577 .707 r
F P
0 g
s
.36184 .81027 m .36184 .8288 L .35894 .82026 L p .707 .577 .707 r
F P
0 g
s
.35894 .82026 m .35894 .80173 L .36184 .81027 L p .707 .577 .707 r
F P
0 g
s
.36016 .84912 m .36016 .34723 L .35607 .33517 L p .707 .577 .707 r
F P
0 g
s
.36016 .34723 m .36016 .84912 L .37794 .86025 L p .707 .577 .707 r
F P
0 g
s
.15794 .63768 m .15794 .69326 L .16084 .7018 L p .707 .577 .707 r
F P
0 g
s
.17343 .84159 m .17343 .82306 L .16084 .81518 L p .707 .577 .707 r
F P
0 g
s
.16084 .81518 m .16084 .83371 L .17343 .84159 L p .707 .577 .707 r
F P
0 g
s
.16084 .77515 m .16084 .7381 L .15794 .72956 L p .707 .577 .707 r
F P
0 g
s
.15794 .69326 m .15794 .63768 L .16503 .62931 L p .707 .577 .707 r
F P
0 g
s
.15794 .72956 m .15794 .76661 L .16084 .77515 L p .707 .577 .707 r
F P
0 g
s
.64393 .3403 m .64393 .84219 L .63984 .83013 L p .707 .577 .707 r
F P
0 g
s
.63984 .83013 m .63984 .32824 L .64393 .3403 L p .707 .577 .707 r
F P
0 g
s
.16503 .62931 m .16503 .68489 L .15794 .69326 L p .707 .577 .707 r
F P
0 g
s
.16084 .83371 m .16084 .81518 L .15794 .80664 L p .707 .577 .707 r
F P
0 g
s
.15794 .80664 m .15794 .82516 L .16084 .83371 L p .707 .577 .707 r
F P
0 g
s
.35894 .72465 m .35894 .76171 L .34635 .75382 L p .707 .577 .707 r
F P
0 g
s
.34635 .75382 m .34635 .71677 L .35894 .72465 L p .707 .577 .707 r
F P
0 g
s
.35894 .80173 m .35894 .82026 L .34635 .81237 L p .707 .577 .707 r
F P
0 g
s
.34635 .81237 m .34635 .79385 L .35894 .80173 L p .707 .577 .707 r
F P
0 g
s
.35607 .33517 m .35607 .83706 L .36016 .84912 L p .707 .577 .707 r
F P
0 g
s
.35607 .83706 m .35607 .33517 L .36607 .32336 L p .707 .577 .707 r
F P
0 g
s
.15794 .76661 m .15794 .72956 L .16503 .72119 L p .707 .577 .707 r
F P
0 g
s
.16503 .68489 m .16503 .62931 L .1814 .62194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72119 m .16503 .75825 L .15794 .76661 L p .707 .577 .707 r
F P
0 g
s
.1814 .62194 m .1814 .67753 L .16503 .68489 L p .707 .577 .707 r
F P
0 g
s
.34635 .62489 m .34635 .68047 L .3253 .67401 L p .707 .577 .707 r
F P
0 g
s
.3253 .67401 m .3253 .61843 L .34635 .62489 L p .707 .577 .707 r
F P
0 g
s
.15794 .82516 m .15794 .80664 L .16503 .79827 L p .707 .577 .707 r
F P
0 g
s
.63984 .32824 m .63984 .83013 L .62206 .819 L p .707 .577 .707 r
F P
0 g
s
.62206 .819 m .62206 .31711 L .63984 .32824 L p .707 .577 .707 r
F P
0 g
s
.16503 .79827 m .16503 .8168 L .15794 .82516 L p .707 .577 .707 r
F P
0 g
s
.16503 .75825 m .16503 .72119 L .1814 .71383 L p .707 .577 .707 r
F P
0 g
s
.1814 .67753 m .1814 .62194 L .20545 .61629 L p .707 .577 .707 r
F P
0 g
s
.1814 .71383 m .1814 .75088 L .16503 .75825 L p .707 .577 .707 r
F P
0 g
s
.36607 .82525 m .36607 .32336 L .38918 .31296 L p .707 .577 .707 r
F P
0 g
s
.36607 .32336 m .36607 .82525 L .35607 .83706 L p .707 .577 .707 r
F P
0 g
s
.3253 .61843 m .3253 .67401 L .29784 .66962 L p .707 .577 .707 r
F P
0 g
s
.29784 .66962 m .29784 .61404 L .3253 .61843 L p .707 .577 .707 r
F P
0 g
s
.34635 .71677 m .34635 .75382 L .3253 .74737 L p .707 .577 .707 r
F P
0 g
s
.3253 .74737 m .3253 .71031 L .34635 .71677 L p .707 .577 .707 r
F P
0 g
s
.20545 .61629 m .20545 .67188 L .1814 .67753 L p .707 .577 .707 r
F P
0 g
s
.20545 .67188 m .20545 .61629 L .23483 .61292 L p .707 .577 .707 r
F P
0 g
s
.16503 .8168 m .16503 .79827 L .1814 .79091 L p .707 .577 .707 r
F P
0 g
s
.1814 .75088 m .1814 .71383 L .20545 .70818 L p .707 .577 .707 r
F P
0 g
s
.1814 .79091 m .1814 .80943 L .16503 .8168 L p .707 .577 .707 r
F P
0 g
s
.29784 .61404 m .29784 .66962 L .26667 .66772 L p .707 .577 .707 r
F P
0 g
s
.26667 .66772 m .26667 .61214 L .29784 .61404 L p .707 .577 .707 r
F P
0 g
s
.23483 .6685 m .23483 .61292 L .26667 .61214 L p .707 .577 .707 r
F P
0 g
s
.23483 .61292 m .23483 .6685 L .20545 .67188 L p .707 .577 .707 r
F P
0 g
s
.62206 .31711 m .62206 .819 L .59233 .80989 L p .707 .577 .707 r
F P
0 g
s
.59233 .80989 m .59233 .308 L .62206 .31711 L p .707 .577 .707 r
F P
0 g
s
.26667 .61214 m .26667 .66772 L .23483 .6685 L p .707 .577 .707 r
F P
0 g
s
.20545 .70818 m .20545 .74523 L .1814 .75088 L p .707 .577 .707 r
F P
0 g
s
.34635 .79385 m .34635 .81237 L .3253 .80592 L p .707 .577 .707 r
F P
0 g
s
.3253 .80592 m .3253 .78739 L .34635 .79385 L p .707 .577 .707 r
F P
0 g
s
.73333 .66721 m .73333 .61163 L .70216 .60973 L p .707 .577 .707 r
F P
0 g
s
.73333 .61163 m .73333 .66721 L .76517 .66643 L p .707 .577 .707 r
F P
0 g
s
.76517 .66643 m .76517 .61085 L .73333 .61163 L p .707 .577 .707 r
F P
0 g
s
.3253 .71031 m .3253 .74737 L .29784 .74298 L p .707 .577 .707 r
F P
0 g
s
.29784 .74298 m .29784 .70592 L .3253 .71031 L p .707 .577 .707 r
F P
0 g
s
.76517 .61085 m .76517 .66643 L .79455 .66305 L p .707 .577 .707 r
F P
0 g
s
.79455 .66305 m .79455 .60747 L .76517 .61085 L p .707 .577 .707 r
F P
0 g
s
.70216 .66531 m .70216 .60973 L .6747 .60533 L p .707 .577 .707 r
F P
0 g
s
.70216 .60973 m .70216 .66531 L .73333 .66721 L p .707 .577 .707 r
F P
0 g
s
.20545 .74523 m .20545 .70818 L .23483 .7048 L p .707 .577 .707 r
F P
0 g
s
.1814 .80943 m .1814 .79091 L .20545 .78526 L p .707 .577 .707 r
F P
0 g
s
.38918 .31296 m .38918 .81485 L .36607 .82525 L p .707 .577 .707 r
F P
0 g
s
.38918 .81485 m .38918 .31296 L .42314 .30498 L p .707 .577 .707 r
F P
0 g
s
.79455 .60747 m .79455 .66305 L .8186 .6574 L p .707 .577 .707 r
F P
0 g
s
.8186 .6574 m .8186 .60182 L .79455 .60747 L p .707 .577 .707 r
F P
0 g
s
.20545 .78526 m .20545 .80378 L .1814 .80943 L p .707 .577 .707 r
F P
0 g
s
.29784 .70592 m .29784 .74298 L .26667 .74107 L p .707 .577 .707 r
F P
0 g
s
.26667 .74107 m .26667 .70402 L .29784 .70592 L p .707 .577 .707 r
F P
0 g
s
.23483 .7048 m .23483 .74185 L .20545 .74523 L p .707 .577 .707 r
F P
0 g
s
.23483 .74185 m .23483 .7048 L .26667 .70402 L p .707 .577 .707 r
F P
0 g
s
.6747 .60533 m .6747 .66092 L .70216 .66531 L p .707 .577 .707 r
F P
0 g
s
.6747 .66092 m .6747 .60533 L .65365 .59888 L p .707 .577 .707 r
F P
0 g
s
.3253 .78739 m .3253 .80592 L .29784 .80153 L p .707 .577 .707 r
F P
0 g
s
.29784 .80153 m .29784 .783 L .3253 .78739 L p .707 .577 .707 r
F P
0 g
s
.26667 .70402 m .26667 .74107 L .23483 .74185 L p .707 .577 .707 r
F P
0 g
s
.73333 .74056 m .73333 .70351 L .70216 .70161 L p .707 .577 .707 r
F P
0 g
s
.73333 .70351 m .73333 .74056 L .76517 .73979 L p .707 .577 .707 r
F P
0 g
s
.76517 .73979 m .76517 .70273 L .73333 .70351 L p .707 .577 .707 r
F P
0 g
s
.76517 .70273 m .76517 .73979 L .79455 .73641 L p .707 .577 .707 r
F P
0 g
s
.79455 .73641 m .79455 .69935 L .76517 .70273 L p .707 .577 .707 r
F P
0 g
s
.59233 .308 m .59233 .80989 L .55357 .80369 L p .707 .577 .707 r
F P
0 g
s
.55357 .80369 m .55357 .3018 L .59233 .308 L p .707 .577 .707 r
F P
0 g
s
.20545 .80378 m .20545 .78526 L .23483 .78188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73866 m .70216 .70161 L .6747 .69722 L p .707 .577 .707 r
F P
0 g
s
.70216 .70161 m .70216 .73866 L .73333 .74056 L p .707 .577 .707 r
F P
0 g
s
.8186 .60182 m .8186 .6574 L .83497 .65003 L p .707 .577 .707 r
F P
0 g
s
.83497 .65003 m .83497 .59445 L .8186 .60182 L p .707 .577 .707 r
F P
0 g
s
.23483 .78188 m .23483 .8004 L .20545 .80378 L p .707 .577 .707 r
F P
0 g
s
.65365 .59888 m .65365 .65446 L .6747 .66092 L p .707 .577 .707 r
F P
0 g
s
.29784 .783 m .29784 .80153 L .26667 .79963 L p .707 .577 .707 r
F P
0 g
s
.26667 .79963 m .26667 .7811 L .29784 .783 L p .707 .577 .707 r
F P
0 g
s
.42314 .80687 m .42314 .30498 L .46462 .30021 L p .707 .577 .707 r
F P
0 g
s
.42314 .30498 m .42314 .80687 L .38918 .81485 L p .707 .577 .707 r
F P
0 g
s
.79455 .69935 m .79455 .73641 L .8186 .73076 L p .707 .577 .707 r
F P
0 g
s
.8186 .73076 m .8186 .6937 L .79455 .69935 L p .707 .577 .707 r
F P
0 g
s
.23483 .8004 m .23483 .78188 L .26667 .7811 L p .707 .577 .707 r
F P
0 g
s
.6747 .69722 m .6747 .73427 L .70216 .73866 L p .707 .577 .707 r
F P
0 g
s
.26667 .7811 m .26667 .79963 L .23483 .8004 L p .707 .577 .707 r
F P
0 g
s
.65365 .65446 m .65365 .59888 L .64105 .591 L p .707 .577 .707 r
F P
0 g
s
.73333 .79911 m .73333 .78059 L .70216 .77869 L p .707 .577 .707 r
F P
0 g
s
.73333 .78059 m .73333 .79911 L .76517 .79834 L p .707 .577 .707 r
F P
0 g
s
.76517 .79834 m .76517 .77981 L .73333 .78059 L p .707 .577 .707 r
F P
0 g
s
.6747 .73427 m .6747 .69722 L .65365 .69076 L p .707 .577 .707 r
F P
0 g
s
.76517 .77981 m .76517 .79834 L .79455 .79496 L p .707 .577 .707 r
F P
0 g
s
.79455 .79496 m .79455 .77643 L .76517 .77981 L p .707 .577 .707 r
F P
0 g
s
.55357 .3018 m .55357 .80369 L .50956 .80101 L p .707 .577 .707 r
F P
0 g
s
.50956 .80101 m .50956 .29912 L .55357 .3018 L p .707 .577 .707 r
F P
0 g
s
.70216 .77869 m .70216 .79721 L .73333 .79911 L p .707 .577 .707 r
F P
0 g
s
.70216 .79721 m .70216 .77869 L .6747 .77429 L p .707 .577 .707 r
F P
0 g
s
.46462 .8021 m .46462 .30021 L .50956 .29912 L p .707 .577 .707 r
F P
0 g
s
.46462 .30021 m .46462 .8021 L .42314 .80687 L p .707 .577 .707 r
F P
0 g
s
.65365 .69076 m .65365 .72782 L .6747 .73427 L p .707 .577 .707 r
F P
0 g
s
.6747 .77429 m .6747 .79282 L .70216 .79721 L p .707 .577 .707 r
F P
0 g
s
.8186 .6937 m .8186 .73076 L .83497 .72339 L p .707 .577 .707 r
F P
0 g
s
.83497 .72339 m .83497 .68633 L .8186 .6937 L p .707 .577 .707 r
F P
0 g
s
.64105 .591 m .64105 .64658 L .65365 .65446 L p .707 .577 .707 r
F P
0 g
s
.50956 .29912 m .50956 .80101 L .46462 .8021 L p .707 .577 .707 r
F P
0 g
s
.83497 .59445 m .83497 .65003 L .84205 .64167 L p .707 .577 .707 r
F P
0 g
s
.84205 .64167 m .84205 .58609 L .83497 .59445 L p .707 .577 .707 r
F P
0 g
s
.79455 .77643 m .79455 .79496 L .8186 .78931 L p .707 .577 .707 r
F P
0 g
s
.8186 .78931 m .8186 .77078 L .79455 .77643 L p .707 .577 .707 r
F P
0 g
s
.6747 .79282 m .6747 .77429 L .65365 .76784 L p .707 .577 .707 r
F P
0 g
s
.65365 .72782 m .65365 .69076 L .64105 .68288 L p .707 .577 .707 r
F P
0 g
s
.64105 .64658 m .64105 .591 L .63816 .58245 L p .707 .577 .707 r
F P
0 g
s
.65365 .76784 m .65365 .78637 L .6747 .79282 L p .707 .577 .707 r
F P
0 g
s
.64105 .68288 m .64105 .71993 L .65365 .72782 L p .707 .577 .707 r
F P
0 g
s
.8186 .77078 m .8186 .78931 L .83497 .78194 L p .707 .577 .707 r
F P
0 g
s
.83497 .78194 m .83497 .76341 L .8186 .77078 L p .707 .577 .707 r
F P
0 g
s
.83497 .68633 m .83497 .72339 L .84206 .71502 L p .707 .577 .707 r
F P
0 g
s
.84206 .71502 m .84206 .67797 L .83497 .68633 L p .707 .577 .707 r
F P
0 g
s
.63816 .58245 m .63816 .63804 L .64105 .64658 L p .707 .577 .707 r
F P
0 g
s
.84205 .58609 m .84205 .64167 L .83916 .63313 L p .707 .577 .707 r
F P
0 g
s
.83916 .63313 m .83916 .57755 L .84205 .58609 L p .707 .577 .707 r
F P
0 g
s
.65365 .78637 m .65365 .76784 L .64105 .75996 L p .707 .577 .707 r
F P
0 g
s
.64105 .75996 m .64105 .77848 L .65365 .78637 L p .707 .577 .707 r
F P
0 g
s
.64105 .71993 m .64105 .68288 L .63816 .67433 L p .707 .577 .707 r
F P
0 g
s
.63816 .63804 m .63816 .58245 L .64524 .57409 L p .707 .577 .707 r
F P
0 g
s
.83497 .76341 m .83497 .78194 L .84206 .77358 L p .707 .577 .707 r
F P
0 g
s
.84206 .77358 m .84206 .75505 L .83497 .76341 L p .707 .577 .707 r
F P
0 g
s
.63816 .67433 m .63816 .71139 L .64105 .71993 L p .707 .577 .707 r
F P
0 g
s
.84206 .67797 m .84206 .71502 L .83916 .70648 L p .707 .577 .707 r
F P
0 g
s
.83916 .70648 m .83916 .66943 L .84206 .67797 L p .707 .577 .707 r
F P
0 g
s
.64524 .57409 m .64524 .62967 L .63816 .63804 L p .707 .577 .707 r
F P
0 g
s
.64105 .77848 m .64105 .75996 L .63816 .75141 L p .707 .577 .707 r
F P
0 g
s
.83916 .57755 m .83916 .63313 L .82657 .62524 L p .707 .577 .707 r
F P
0 g
s
.82657 .62524 m .82657 .56966 L .83916 .57755 L p .707 .577 .707 r
F P
0 g
s
.63816 .75141 m .63816 .76994 L .64105 .77848 L p .707 .577 .707 r
F P
0 g
s
.63816 .71139 m .63816 .67433 L .64524 .66597 L p .707 .577 .707 r
F P
0 g
s
.39032 .63039 m .39032 .57481 L .35915 .57291 L p .707 .577 .707 r
F P
0 g
s
.39032 .57481 m .39032 .63039 L .42216 .62962 L p .707 .577 .707 r
F P
0 g
s
.42216 .62962 m .42216 .57403 L .39032 .57481 L p .707 .577 .707 r
F P
0 g
s
.64524 .62967 m .64524 .57409 L .66161 .56672 L p .707 .577 .707 r
F P
0 g
s
.42216 .57403 m .42216 .62962 L .45154 .62624 L p .707 .577 .707 r
F P
0 g
s
.45154 .62624 m .45154 .57065 L .42216 .57403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84206 .75505 m .84206 .77358 L .83916 .76503 L p .707 .577 .707 r
F P
0 g
s
.83916 .76503 m .83916 .74651 L .84206 .75505 L p .707 .577 .707 r
F P
0 g
s
.35915 .62849 m .35915 .57291 L .33169 .56852 L p .707 .577 .707 r
F P
0 g
s
.35915 .57291 m .35915 .62849 L .39032 .63039 L p .707 .577 .707 r
F P
0 g
s
.64524 .66597 m .64524 .70303 L .63816 .71139 L p .707 .577 .707 r
F P
0 g
s
.45154 .57065 m .45154 .62624 L .47559 .62059 L p .707 .577 .707 r
F P
0 g
s
.47559 .62059 m .47559 .565 L .45154 .57065 L p .707 .577 .707 r
F P
0 g
s
.83916 .66943 m .83916 .70648 L .82657 .6986 L p .707 .577 .707 r
F P
0 g
s
.82657 .6986 m .82657 .66154 L .83916 .66943 L p .707 .577 .707 r
F P
0 g
s
.66161 .56672 m .66161 .6223 L .64524 .62967 L p .707 .577 .707 r
F P
0 g
s
.82657 .56966 m .82657 .62524 L .80551 .61879 L p .707 .577 .707 r
F P
0 g
s
.80551 .61879 m .80551 .56321 L .82657 .56966 L p .707 .577 .707 r
F P
0 g
s
.63816 .76994 m .63816 .75141 L .64524 .74305 L p .707 .577 .707 r
F P
0 g
s
.33169 .56852 m .33169 .6241 L .35915 .62849 L p .707 .577 .707 r
F P
0 g
s
.33169 .6241 m .33169 .56852 L .31064 .56206 L p .707 .577 .707 r
F P
0 g
s
.64524 .74305 m .64524 .76158 L .63816 .76994 L p .707 .577 .707 r
F P
0 g
s
.39032 .70375 m .39032 .66669 L .35915 .66479 L p .707 .577 .707 r
F P
0 g
s
.39032 .66669 m .39032 .70375 L .42216 .70297 L p .707 .577 .707 r
F P
0 g
s
.42216 .70297 m .42216 .66592 L .39032 .66669 L p .707 .577 .707 r
F P
0 g
s
.64524 .70303 m .64524 .66597 L .66161 .6586 L p .707 .577 .707 r
F P
0 g
s
.42216 .66592 m .42216 .70297 L .45154 .69959 L p .707 .577 .707 r
F P
0 g
s
.45154 .69959 m .45154 .66254 L .42216 .66592 L p .707 .577 .707 r
F P
0 g
s
.66161 .6223 m .66161 .56672 L .68566 .56107 L p .707 .577 .707 r
F P
0 g
s
.35915 .70185 m .35915 .66479 L .33169 .6604 L p .707 .577 .707 r
F P
0 g
s
.35915 .66479 m .35915 .70185 L .39032 .70375 L p .707 .577 .707 r
F P
0 g
s
.47559 .565 m .47559 .62059 L .49196 .61322 L p .707 .577 .707 r
F P
0 g
s
.49196 .61322 m .49196 .55764 L .47559 .565 L p .707 .577 .707 r
F P
0 g
s
.83916 .74651 m .83916 .76503 L .82657 .75715 L p .707 .577 .707 r
F P
0 g
s
.82657 .75715 m .82657 .73862 L .83916 .74651 L p .707 .577 .707 r
F P
0 g
s
.31064 .56206 m .31064 .61765 L .33169 .6241 L p .707 .577 .707 r
F P
0 g
s
.66161 .6586 m .66161 .69566 L .64524 .70303 L p .707 .577 .707 r
F P
0 g
s
.45154 .66254 m .45154 .69959 L .47559 .69394 L p .707 .577 .707 r
F P
0 g
s
.47559 .69394 m .47559 .65689 L .45154 .66254 L p .707 .577 .707 r
F P
0 g
s
.80551 .56321 m .80551 .61879 L .77805 .6144 L p .707 .577 .707 r
F P
0 g
s
.77805 .6144 m .77805 .55882 L .80551 .56321 L p .707 .577 .707 r
F P
0 g
s
.33169 .6604 m .33169 .69745 L .35915 .70185 L p .707 .577 .707 r
F P
0 g
s
.82657 .66154 m .82657 .6986 L .80551 .69214 L p .707 .577 .707 r
F P
0 g
s
.80551 .69214 m .80551 .65509 L .82657 .66154 L p .707 .577 .707 r
F P
0 g
s
.68566 .56107 m .68566 .61665 L .66161 .6223 L p .707 .577 .707 r
F P
0 g
s
.31064 .61765 m .31064 .56206 L .29804 .55418 L p .707 .577 .707 r
F P
0 g
s
.39032 .7623 m .39032 .74377 L .35915 .74187 L p .707 .577 .707 r
F P
0 g
s
.39032 .74377 m .39032 .7623 L .42216 .76152 L p .707 .577 .707 r
F P
0 g
s
.42216 .76152 m .42216 .74299 L .39032 .74377 L p .707 .577 .707 r
F P
0 g
s
.33169 .69745 m .33169 .6604 L .31064 .65395 L p .707 .577 .707 r
F P
0 g
s
.68566 .61665 m .68566 .56107 L .71504 .55769 L p .707 .577 .707 r
F P
0 g
s
.64524 .76158 m .64524 .74305 L .66161 .73568 L p .707 .577 .707 r
F P
0 g
s
.42216 .74299 m .42216 .76152 L .45154 .75814 L p .707 .577 .707 r
F P
0 g
s
.45154 .75814 m .45154 .73962 L .42216 .74299 L p .707 .577 .707 r
F P
0 g
s
.35915 .74187 m .35915 .7604 L .39032 .7623 L p .707 .577 .707 r
F P
0 g
s
.35915 .7604 m .35915 .74187 L .33169 .73748 L p .707 .577 .707 r
F P
0 g
s
.66161 .69566 m .66161 .6586 L .68566 .65295 L p .707 .577 .707 r
F P
0 g
s
.66161 .73568 m .66161 .75421 L .64524 .76158 L p .707 .577 .707 r
F P
0 g
s
.77805 .55882 m .77805 .6144 L .74688 .6125 L p .707 .577 .707 r
F P
0 g
s
.74688 .6125 m .74688 .55691 L .77805 .55882 L p .707 .577 .707 r
F P
0 g
s
.31064 .65395 m .31064 .691 L .33169 .69745 L p .707 .577 .707 r
F P
0 g
s
.33169 .73748 m .33169 .75601 L .35915 .7604 L p .707 .577 .707 r
F P
0 g
s
.47559 .65689 m .47559 .69394 L .49196 .68657 L p .707 .577 .707 r
F P
0 g
s
.49196 .68657 m .49196 .64952 L .47559 .65689 L p .707 .577 .707 r
F P
0 g
s
.29804 .55418 m .29804 .60976 L .31064 .61765 L p .707 .577 .707 r
F P
0 g
s
.71504 .61327 m .71504 .55769 L .74688 .55691 L p .707 .577 .707 r
F P
0 g
s
.71504 .55769 m .71504 .61327 L .68566 .61665 L p .707 .577 .707 r
F P
0 g
s
.49196 .55764 m .49196 .61322 L .49904 .60485 L p .707 .577 .707 r
F P
0 g
s
.49904 .60485 m .49904 .54927 L .49196 .55764 L p .707 .577 .707 r
F P
0 g
s
.45154 .73962 m .45154 .75814 L .47559 .75249 L p .707 .577 .707 r
F P
0 g
s
.47559 .75249 m .47559 .73397 L .45154 .73962 L p .707 .577 .707 r
F P
0 g
s
.74688 .55691 m .74688 .6125 L .71504 .61327 L p .707 .577 .707 r
F P
0 g
s
.68566 .65295 m .68566 .69001 L .66161 .69566 L p .707 .577 .707 r
F P
0 g
s
.82657 .73862 m .82657 .75715 L .80551 .7507 L p .707 .577 .707 r
F P
0 g
s
.80551 .7507 m .80551 .73217 L .82657 .73862 L p .707 .577 .707 r
F P
0 g
s
.80551 .65509 m .80551 .69214 L .77805 .68775 L p .707 .577 .707 r
F P
0 g
s
.77805 .68775 m .77805 .6507 L .80551 .65509 L p .707 .577 .707 r
F P
0 g
s
.33169 .75601 m .33169 .73748 L .31064 .73103 L p .707 .577 .707 r
F P
0 g
s
.31064 .691 m .31064 .65395 L .29804 .64606 L p .707 .577 .707 r
F P
0 g
s
.29804 .60976 m .29804 .55418 L .29515 .54564 L p .707 .577 .707 r
F P
0 g
s
.31064 .73103 m .31064 .74955 L .33169 .75601 L p .707 .577 .707 r
F P
0 g
s
.68566 .69001 m .68566 .65295 L .71504 .64957 L p .707 .577 .707 r
F P
0 g
s
.66161 .75421 m .66161 .73568 L .68566 .73003 L p .707 .577 .707 r
F P
0 g
s
.68566 .73003 m .68566 .74856 L .66161 .75421 L p .707 .577 .707 r
F P
0 g
s
.29804 .64606 m .29804 .68312 L .31064 .691 L p .707 .577 .707 r
F P
0 g
s
.47559 .73397 m .47559 .75249 L .49196 .74513 L p .707 .577 .707 r
F P
0 g
s
.49196 .74513 m .49196 .7266 L .47559 .73397 L p .707 .577 .707 r
F P
0 g
s
.77805 .6507 m .77805 .68775 L .74688 .68585 L p .707 .577 .707 r
F P
0 g
s
.74688 .68585 m .74688 .6488 L .77805 .6507 L p .707 .577 .707 r
F P
0 g
s
.71504 .64957 m .71504 .68663 L .68566 .69001 L p .707 .577 .707 r
F P
0 g
s
.71504 .68663 m .71504 .64957 L .74688 .6488 L p .707 .577 .707 r
F P
0 g
s
.49196 .64952 m .49196 .68657 L .49904 .67821 L p .707 .577 .707 r
F P
0 g
s
.49904 .67821 m .49904 .64115 L .49196 .64952 L p .707 .577 .707 r
F P
0 g
s
.80551 .73217 m .80551 .7507 L .77805 .7463 L p .707 .577 .707 r
F P
0 g
s
.77805 .7463 m .77805 .72778 L .80551 .73217 L p .707 .577 .707 r
F P
0 g
s
.29515 .54564 m .29515 .60122 L .29804 .60976 L p .707 .577 .707 r
F P
0 g
s
.74688 .6488 m .74688 .68585 L .71504 .68663 L p .707 .577 .707 r
F P
0 g
s
.49904 .54927 m .49904 .60485 L .49615 .59631 L p .707 .577 .707 r
F P
0 g
s
.49615 .59631 m .49615 .54073 L .49904 .54927 L p .707 .577 .707 r
F P
0 g
s
.31064 .74955 m .31064 .73103 L .29804 .72314 L p .707 .577 .707 r
F P
0 g
s
.68566 .74856 m .68566 .73003 L .71504 .72665 L p .707 .577 .707 r
F P
0 g
s
.29804 .72314 m .29804 .74167 L .31064 .74955 L p .707 .577 .707 r
F P
0 g
s
.29804 .68312 m .29804 .64606 L .29515 .63752 L p .707 .577 .707 r
F P
0 g
s
.71504 .72665 m .71504 .74518 L .68566 .74856 L p .707 .577 .707 r
F P
0 g
s
.77805 .72778 m .77805 .7463 L .74688 .7444 L p .707 .577 .707 r
F P
0 g
s
.74688 .7444 m .74688 .72588 L .77805 .72778 L p .707 .577 .707 r
F P
0 g
s
.29515 .60122 m .29515 .54564 L .30223 .53727 L p .707 .577 .707 r
F P
0 g
s
.71504 .74518 m .71504 .72665 L .74688 .72588 L p .707 .577 .707 r
F P
0 g
s
.49196 .7266 m .49196 .74513 L .49904 .73676 L p .707 .577 .707 r
F P
0 g
s
.49904 .73676 m .49904 .71823 L .49196 .7266 L p .707 .577 .707 r
F P
0 g
s
.29515 .63752 m .29515 .67457 L .29804 .68312 L p .707 .577 .707 r
F P
0 g
s
.74688 .72588 m .74688 .7444 L .71504 .74518 L p .707 .577 .707 r
F P
0 g
s
.49904 .64115 m .49904 .67821 L .49615 .66967 L p .707 .577 .707 r
F P
0 g
s
.49615 .66967 m .49615 .63261 L .49904 .64115 L p .707 .577 .707 r
F P
0 g
s
.30223 .53727 m .30223 .59286 L .29515 .60122 L p .707 .577 .707 r
F P
0 g
s
.29804 .74167 m .29804 .72314 L .29515 .7146 L p .707 .577 .707 r
F P
0 g
s
.49615 .54073 m .49615 .59631 L .48356 .58843 L p .707 .577 .707 r
F P
0 g
s
.48356 .58843 m .48356 .53285 L .49615 .54073 L p .707 .577 .707 r
F P
0 g
s
.29515 .7146 m .29515 .73313 L .29804 .74167 L p .707 .577 .707 r
F P
0 g
s
.29515 .67457 m .29515 .63752 L .30223 .62915 L p .707 .577 .707 r
F P
0 g
s
.30223 .59286 m .30223 .53727 L .3186 .52991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49904 .71823 m .49904 .73676 L .49615 .72822 L p .707 .577 .707 r
F P
0 g
s
.49615 .72822 m .49615 .70969 L .49904 .71823 L p .707 .577 .707 r
F P
0 g
s
.30223 .62915 m .30223 .66621 L .29515 .67457 L p .707 .577 .707 r
F P
0 g
s
.49615 .63261 m .49615 .66967 L .48356 .66178 L p .707 .577 .707 r
F P
0 g
s
.48356 .66178 m .48356 .62473 L .49615 .63261 L p .707 .577 .707 r
F P
0 g
s
.3186 .52991 m .3186 .58549 L .30223 .59286 L p .707 .577 .707 r
F P
0 g
s
.48356 .53285 m .48356 .58843 L .4625 .58197 L p .707 .577 .707 r
F P
0 g
s
.4625 .58197 m .4625 .52639 L .48356 .53285 L p .707 .577 .707 r
F P
0 g
s
.29515 .73313 m .29515 .7146 L .30223 .70623 L p .707 .577 .707 r
F P
0 g
s
.30223 .70623 m .30223 .72476 L .29515 .73313 L p .707 .577 .707 r
F P
0 g
s
.30223 .66621 m .30223 .62915 L .3186 .62179 L p .707 .577 .707 r
F P
0 g
s
.3186 .58549 m .3186 .52991 L .34265 .52426 L p .707 .577 .707 r
F P
0 g
s
.49615 .70969 m .49615 .72822 L .48356 .72034 L p .707 .577 .707 r
F P
0 g
s
.48356 .72034 m .48356 .70181 L .49615 .70969 L p .707 .577 .707 r
F P
0 g
s
.3186 .62179 m .3186 .65884 L .30223 .66621 L p .707 .577 .707 r
F P
0 g
s
.4625 .52639 m .4625 .58197 L .43504 .57758 L p .707 .577 .707 r
F P
0 g
s
.43504 .57758 m .43504 .522 L .4625 .52639 L p .707 .577 .707 r
F P
0 g
s
.48356 .62473 m .48356 .66178 L .4625 .65533 L p .707 .577 .707 r
F P
0 g
s
.4625 .65533 m .4625 .61827 L .48356 .62473 L p .707 .577 .707 r
F P
0 g
s
.34265 .52426 m .34265 .57984 L .3186 .58549 L p .707 .577 .707 r
F P
0 g
s
.34265 .57984 m .34265 .52426 L .37203 .52088 L p .707 .577 .707 r
F P
0 g
s
.30223 .72476 m .30223 .70623 L .3186 .69887 L p .707 .577 .707 r
F P
0 g
s
.3186 .65884 m .3186 .62179 L .34265 .61614 L p .707 .577 .707 r
F P
0 g
s
.3186 .69887 m .3186 .71739 L .30223 .72476 L p .707 .577 .707 r
F P
0 g
s
.43504 .522 m .43504 .57758 L .40387 .57568 L p .707 .577 .707 r
F P
0 g
s
.40387 .57568 m .40387 .5201 L .43504 .522 L p .707 .577 .707 r
F P
0 g
s
.37203 .57646 m .37203 .52088 L .40387 .5201 L p .707 .577 .707 r
F P
0 g
s
.37203 .52088 m .37203 .57646 L .34265 .57984 L p .707 .577 .707 r
F P
0 g
s
.40387 .5201 m .40387 .57568 L .37203 .57646 L p .707 .577 .707 r
F P
0 g
s
.34265 .61614 m .34265 .65319 L .3186 .65884 L p .707 .577 .707 r
F P
0 g
s
.48356 .70181 m .48356 .72034 L .4625 .71388 L p .707 .577 .707 r
F P
0 g
s
.4625 .71388 m .4625 .69535 L .48356 .70181 L p .707 .577 .707 r
F P
0 g
s
.4625 .61827 m .4625 .65533 L .43504 .65094 L p .707 .577 .707 r
F P
0 g
s
.43504 .65094 m .43504 .61388 L .4625 .61827 L p .707 .577 .707 r
F P
0 g
s
.34265 .65319 m .34265 .61614 L .37203 .61276 L p .707 .577 .707 r
F P
0 g
s
.3186 .71739 m .3186 .69887 L .34265 .69322 L p .707 .577 .707 r
F P
0 g
s
.34265 .69322 m .34265 .71174 L .3186 .71739 L p .707 .577 .707 r
F P
0 g
s
.43504 .61388 m .43504 .65094 L .40387 .64904 L p .707 .577 .707 r
F P
0 g
s
.40387 .64904 m .40387 .61198 L .43504 .61388 L p .707 .577 .707 r
F P
0 g
s
.37203 .61276 m .37203 .64981 L .34265 .65319 L p .707 .577 .707 r
F P
0 g
s
.37203 .64981 m .37203 .61276 L .40387 .61198 L p .707 .577 .707 r
F P
0 g
s
.4625 .69535 m .4625 .71388 L .43504 .70949 L p .707 .577 .707 r
F P
0 g
s
.43504 .70949 m .43504 .69096 L .4625 .69535 L p .707 .577 .707 r
F P
0 g
s
.40387 .61198 m .40387 .64904 L .37203 .64981 L p .707 .577 .707 r
F P
0 g
s
.34265 .71174 m .34265 .69322 L .37203 .68984 L p .707 .577 .707 r
F P
0 g
s
.37203 .68984 m .37203 .70837 L .34265 .71174 L p .707 .577 .707 r
F P
0 g
s
.43504 .69096 m .43504 .70949 L .40387 .70759 L p .707 .577 .707 r
F P
0 g
s
.40387 .70759 m .40387 .68906 L .43504 .69096 L p .707 .577 .707 r
F P
0 g
s
.37203 .70837 m .37203 .68984 L .40387 .68906 L p .707 .577 .707 r
F P
0 g
s
.40387 .68906 m .40387 .70759 L .37203 .70837 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo
001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo2@0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?OolH
000nOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH3000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH007oo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000=JEP<0
009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH0
05YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJ
EP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH0
1EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEPH0009JEP03001JEUYF00=JEP03001JEUYF00IJEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`0000AJEP000000009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01P00FUH0
0000FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YF
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0`00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008
FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/
Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo
00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH900000eYF001JEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF200015YF
00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004
FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF000000060003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF2P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1@000eYF00@005YFFUIJEP8001aoo`@00003FUH005YF
009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPH000=JEP8001Eoo`L000=JEP<000=JEP80
02eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUH90009Ool90003FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEQP000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00<7oo0`0015YF
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF
5`001UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000c
Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP03
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000aOol30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF00000002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01UYF1@000eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF0P0000Eoo`00
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEP0000<000=JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00FUH20003FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEQP0009J
EP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<0009JEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30000
1EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0UYF100000=JEP00FUH01P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF
0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20003FUH00`00FUH000020005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP<0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00UYF1P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJ
EP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF4@0015YF00D005YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00;7oo00<005YF000015YF00<005YFFUH00eYF1P004Goo1P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00
FUH00004FUH00`00FUH00003000MOol30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH7000OOol30003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUH00004000NOol50004FUH01@00FUIJEUYF0000;Woo000/Ool01000FUH005YF0P001EYF
00<005YF00000`006Goo2P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF0P008Woo0`0000=JEP00FUH00UYF0P00;Goo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH3000SOol2
0003FUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF00<005YFFUH00eYF00<005YFFUH00P008goo0P0000=JEP000000;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
100015YF00<005YFFUH00eYF00D005YFFUIJEP0002Aoo`@002eoo`00;7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000QOol2000015YF00000000;Goo000]Ool01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEP00008000EJEP04001JEUYFFUH2000LOol50003FUH00`00FUH0000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF1P000eYF0P005Goo1`000eYF00<005YFFUH00UYF0P00;Woo000^Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP80
02ioo`00<7oo0`0015YF00<005YFFUH01EYF6@0000=JEP00FUH01EYF00H005YF000007oo0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00;goo000cOol300000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;Woo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH00UYF
1@00>Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
30001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000goo4P00?goo000]Ool20004FUH00`00FUIJEP03FUH6000GOol4
0002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`00E7oo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000/Ool00`00FUH00003FUH3000ZOol40002FUH01000
FUIJEP001EYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00EGoo000/Ool01000FUH005YF0P00<Goo00<005YF00000UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
10000UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00
;7oo00@005YF000003Aoo`80009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00002FUH00`00
FUIJEP04FUH01000FUH00000F7oo000/Ool200000eYF0000000aOol40002FUH01000FUH000001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YFFUIJEP0000=JEP03001JEP0000<000EJEP<005Yoo`00;7oo0P000eYF0`00:goo0`000UYF
0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEPH005eoo`00;7oo
0P000eYF00<005YFFUH01@008Woo100000=JEP00FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF
00001EYF00<005YF00000`006Goo1@001EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP800003FUH005YF00AJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00eYF0`00Egoo000^Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000Ool00P0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH0009oo`D000AJEP05001JEUYFFUH0001EOol003=oo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00008Ool300000eYF
001JEP02FUH2001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009J
EPL000Uoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000aoo`8000=JEP8005Ao
o`00>goo6`004Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P003goo0P0000=JEP000000
E7oo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P004Woo1000E7oo001[Ool20006FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000004Woo
0P0000AJEP00000005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF0`003goo1@000eYF00<005YF0000E7oo001_Ool30000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3
000;Ool70003FUH00`00FUIJEP02FUH00`00FUH0001DOol0079oo`L000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<000Eoo`T000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00QGoo6@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo
002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001M
Ool009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73974 m .59613 .68416 L .56496 .68226 L p .707 .577 .707 r
F P
0 g
s
.59613 .68416 m .59613 .73974 L .62796 .73897 L p .707 .577 .707 r
F P
0 g
s
.62796 .73897 m .62796 .68339 L .59613 .68416 L p .707 .577 .707 r
F P
0 g
s
.62796 .68339 m .62796 .73897 L .65734 .73559 L p .707 .577 .707 r
F P
0 g
s
.65734 .73559 m .65734 .68001 L .62796 .68339 L p .707 .577 .707 r
F P
0 g
s
.56496 .73784 m .56496 .68226 L .5375 .67787 L p .707 .577 .707 r
F P
0 g
s
.56496 .68226 m .56496 .73784 L .59613 .73974 L p .707 .577 .707 r
F P
0 g
s
.65734 .68001 m .65734 .73559 L .6814 .72994 L p .707 .577 .707 r
F P
0 g
s
.6814 .72994 m .6814 .67436 L .65734 .68001 L p .707 .577 .707 r
F P
0 g
s
.59613 .78711 m .59613 .75006 L .56496 .74816 L p .707 .577 .707 r
F P
0 g
s
.59613 .75006 m .59613 .78711 L .62796 .78634 L p .707 .577 .707 r
F P
0 g
s
.62796 .78634 m .62796 .74928 L .59613 .75006 L p .707 .577 .707 r
F P
0 g
s
.62796 .74928 m .62796 .78634 L .65735 .78296 L p .707 .577 .707 r
F P
0 g
s
.65735 .78296 m .65735 .7459 L .62796 .74928 L p .707 .577 .707 r
F P
0 g
s
.5375 .67787 m .5375 .73345 L .56496 .73784 L p .707 .577 .707 r
F P
0 g
s
.5375 .73345 m .5375 .67787 L .51644 .67142 L p .707 .577 .707 r
F P
0 g
s
.56496 .78521 m .56496 .74816 L .5375 .74377 L p .707 .577 .707 r
F P
0 g
s
.56496 .74816 m .56496 .78521 L .59613 .78711 L p .707 .577 .707 r
F P
0 g
s
.59613 .81223 m .59613 .79371 L .56496 .7918 L p .707 .577 .707 r
F P
0 g
s
.59613 .79371 m .59613 .81223 L .62796 .81146 L p .707 .577 .707 r
F P
0 g
s
.62796 .81146 m .62796 .79293 L .59613 .79371 L p .707 .577 .707 r
F P
0 g
s
.65735 .7459 m .65735 .78296 L .6814 .77731 L p .707 .577 .707 r
F P
0 g
s
.6814 .77731 m .6814 .74025 L .65735 .7459 L p .707 .577 .707 r
F P
0 g
s
.62796 .79293 m .62796 .81146 L .65735 .80808 L p .707 .577 .707 r
F P
0 g
s
.65735 .80808 m .65735 .78955 L .62796 .79293 L p .707 .577 .707 r
F P
0 g
s
.6814 .67436 m .6814 .72994 L .69777 .72257 L p .707 .577 .707 r
F P
0 g
s
.69777 .72257 m .69777 .66699 L .6814 .67436 L p .707 .577 .707 r
F P
0 g
s
.5375 .74377 m .5375 .78082 L .56496 .78521 L p .707 .577 .707 r
F P
0 g
s
.56496 .7918 m .56496 .81033 L .59613 .81223 L p .707 .577 .707 r
F P
0 g
s
.56496 .81033 m .56496 .7918 L .5375 .78741 L p .707 .577 .707 r
F P
0 g
s
.51644 .67142 m .51644 .727 L .5375 .73345 L p .707 .577 .707 r
F P
0 g
s
.5375 .78082 m .5375 .74377 L .51644 .73731 L p .707 .577 .707 r
F P
0 g
s
.5375 .78741 m .5375 .80594 L .56496 .81033 L p .707 .577 .707 r
F P
0 g
s
.65735 .78955 m .65735 .80808 L .6814 .80243 L p .707 .577 .707 r
F P
0 g
s
.6814 .80243 m .6814 .7839 L .65735 .78955 L p .707 .577 .707 r
F P
0 g
s
.51644 .727 m .51644 .67142 L .50385 .66353 L p .707 .577 .707 r
F P
0 g
s
.51644 .73731 m .51644 .77437 L .5375 .78082 L p .707 .577 .707 r
F P
0 g
s
.5375 .80594 m .5375 .78741 L .51644 .78096 L p .707 .577 .707 r
F P
0 g
s
.6814 .74025 m .6814 .77731 L .69777 .76994 L p .707 .577 .707 r
F P
0 g
s
.69777 .76994 m .69777 .73289 L .6814 .74025 L p .707 .577 .707 r
F P
0 g
s
.51644 .78096 m .51644 .79949 L .5375 .80594 L p .707 .577 .707 r
F P
0 g
s
.50385 .66353 m .50385 .71911 L .51644 .727 L p .707 .577 .707 r
F P
0 g
s
.69777 .66699 m .69777 .72257 L .70485 .71421 L p .707 .577 .707 r
F P
0 g
s
.70485 .71421 m .70485 .65862 L .69777 .66699 L p .707 .577 .707 r
F P
0 g
s
.51644 .77437 m .51644 .73731 L .50385 .72943 L p .707 .577 .707 r
F P
0 g
s
.6814 .7839 m .6814 .80243 L .69777 .79506 L p .707 .577 .707 r
F P
0 g
s
.69777 .79506 m .69777 .77653 L .6814 .7839 L p .707 .577 .707 r
F P
0 g
s
.50385 .71911 m .50385 .66353 L .50095 .65499 L p .707 .577 .707 r
F P
0 g
s
.50385 .72943 m .50385 .76648 L .51644 .77437 L p .707 .577 .707 r
F P
0 g
s
.51644 .79949 m .51644 .78096 L .50385 .77307 L p .707 .577 .707 r
F P
0 g
s
.69777 .73289 m .69777 .76994 L .70485 .76158 L p .707 .577 .707 r
F P
0 g
s
.70485 .76158 m .70485 .72452 L .69777 .73289 L p .707 .577 .707 r
F P
0 g
s
.50385 .77307 m .50385 .7916 L .51644 .79949 L p .707 .577 .707 r
F P
0 g
s
.49044 .76543 m .49044 .26354 L .44643 .26086 L p .707 .577 .707 r
F P
0 g
s
.50095 .65499 m .50095 .71057 L .50385 .71911 L p .707 .577 .707 r
F P
0 g
s
.50385 .76648 m .50385 .72943 L .50095 .72089 L p .707 .577 .707 r
F P
0 g
s
.50095 .72089 m .50095 .75794 L .50385 .76648 L p .707 .577 .707 r
F P
0 g
s
.50385 .7916 m .50385 .77307 L .50095 .76453 L p .707 .577 .707 r
F P
0 g
s
.50095 .71057 m .50095 .65499 L .50804 .64663 L p .707 .577 .707 r
F P
0 g
s
.50095 .76453 m .50095 .78306 L .50385 .7916 L p .707 .577 .707 r
F P
0 g
s
.50804 .64663 m .50804 .70221 L .50095 .71057 L p .707 .577 .707 r
F P
0 g
s
.50095 .75794 m .50095 .72089 L .50804 .71252 L p .707 .577 .707 r
F P
0 g
s
.50804 .71252 m .50804 .74958 L .50095 .75794 L p .707 .577 .707 r
F P
0 g
s
.50804 .70221 m .50804 .64663 L .5244 .63926 L p .707 .577 .707 r
F P
0 g
s
.50095 .78306 m .50095 .76453 L .50804 .75617 L p .707 .577 .707 r
F P
0 g
s
.50804 .75617 m .50804 .7747 L .50095 .78306 L p .707 .577 .707 r
F P
0 g
s
.5244 .63926 m .5244 .69484 L .50804 .70221 L p .707 .577 .707 r
F P
0 g
s
.50804 .74958 m .50804 .71252 L .5244 .70516 L p .707 .577 .707 r
F P
0 g
s
.5244 .69484 m .5244 .63926 L .54846 .63361 L p .707 .577 .707 r
F P
0 g
s
.5244 .70516 m .5244 .74221 L .50804 .74958 L p .707 .577 .707 r
F P
0 g
s
.50804 .7747 m .50804 .75617 L .5244 .7488 L p .707 .577 .707 r
F P
0 g
s
.5244 .7488 m .5244 .76733 L .50804 .7747 L p .707 .577 .707 r
F P
0 g
s
.54846 .63361 m .54846 .68919 L .5244 .69484 L p .707 .577 .707 r
F P
0 g
s
.5244 .74221 m .5244 .70516 L .54846 .69951 L p .707 .577 .707 r
F P
0 g
s
.54846 .69951 m .54846 .73656 L .5244 .74221 L p .707 .577 .707 r
F P
0 g
s
.5244 .76733 m .5244 .7488 L .54846 .74315 L p .707 .577 .707 r
F P
0 g
s
.54846 .74315 m .54846 .76168 L .5244 .76733 L p .707 .577 .707 r
F P
0 g
s
.49044 .26354 m .49044 .76543 L .53538 .76433 L p .707 .577 .707 r
F P
0 g
s
.53538 .76433 m .53538 .26245 L .49044 .26354 L p .707 .577 .707 r
F P
0 g
s
.70485 .65862 m .70485 .71421 L .70195 .70566 L p .707 .577 .707 r
F P
0 g
s
.70195 .70566 m .70195 .65008 L .70485 .65862 L p .707 .577 .707 r
F P
0 g
s
.69777 .77653 m .69777 .79506 L .70485 .78669 L p .707 .577 .707 r
F P
0 g
s
.70485 .78669 m .70485 .76817 L .69777 .77653 L p .707 .577 .707 r
F P
0 g
s
.54846 .68919 m .54846 .63361 L .57784 .63023 L p .707 .577 .707 r
F P
0 g
s
.57784 .63023 m .57784 .68581 L .54846 .68919 L p .707 .577 .707 r
F P
0 g
s
.54846 .73656 m .54846 .69951 L .57784 .69613 L p .707 .577 .707 r
F P
0 g
s
.57784 .69613 m .57784 .73318 L .54846 .73656 L p .707 .577 .707 r
F P
0 g
s
.54846 .76168 m .54846 .74315 L .57784 .73977 L p .707 .577 .707 r
F P
0 g
s
.57784 .73977 m .57784 .7583 L .54846 .76168 L p .707 .577 .707 r
F P
0 g
s
.53538 .26245 m .53538 .76433 L .57686 .75956 L p .707 .577 .707 r
F P
0 g
s
.57686 .75956 m .57686 .25768 L .53538 .26245 L p .707 .577 .707 r
F P
0 g
s
.44643 .76275 m .44643 .26086 L .40766 .25466 L p .707 .577 .707 r
F P
0 g
s
.44643 .26086 m .44643 .76275 L .49044 .76543 L p .707 .577 .707 r
F P
0 g
s
.57784 .68581 m .57784 .63023 L .60968 .62945 L p .707 .577 .707 r
F P
0 g
s
.60968 .62945 m .60968 .68503 L .57784 .68581 L p .707 .577 .707 r
F P
0 g
s
.57784 .73318 m .57784 .69613 L .60968 .69535 L p .707 .577 .707 r
F P
0 g
s
.60968 .69535 m .60968 .7324 L .57784 .73318 L p .707 .577 .707 r
F P
0 g
s
.60968 .75752 m .60968 .73899 L .64085 .7409 L p .707 .577 .707 r
F P
0 g
s
.57784 .7583 m .57784 .73977 L .60968 .73899 L p .707 .577 .707 r
F P
0 g
s
.60968 .73899 m .60968 .75752 L .57784 .7583 L p .707 .577 .707 r
F P
0 g
s
.57686 .25768 m .57686 .75956 L .61082 .75159 L p .707 .577 .707 r
F P
0 g
s
.64085 .63135 m .64085 .68693 L .60968 .68503 L p .707 .577 .707 r
F P
0 g
s
.60968 .68503 m .60968 .62945 L .64085 .63135 L p .707 .577 .707 r
F P
0 g
s
.64085 .69725 m .64085 .7343 L .60968 .7324 L p .707 .577 .707 r
F P
0 g
s
.60968 .7324 m .60968 .69535 L .64085 .69725 L p .707 .577 .707 r
F P
0 g
s
.61082 .75159 m .61082 .2497 L .57686 .25768 L p .707 .577 .707 r
F P
0 g
s
.70485 .72452 m .70485 .76158 L .70195 .75303 L p .707 .577 .707 r
F P
0 g
s
.70195 .75303 m .70195 .71598 L .70485 .72452 L p .707 .577 .707 r
F P
0 g
s
.40766 .75655 m .40766 .25466 L .37794 .24555 L p .707 .577 .707 r
F P
0 g
s
.40766 .25466 m .40766 .75655 L .44643 .76275 L p .707 .577 .707 r
F P
0 g
s
.70485 .76817 m .70485 .78669 L .70195 .77815 L p .707 .577 .707 r
F P
0 g
s
.70195 .77815 m .70195 .75963 L .70485 .76817 L p .707 .577 .707 r
F P
0 g
s
.70195 .65008 m .70195 .70566 L .68936 .69778 L p .707 .577 .707 r
F P
0 g
s
.68936 .69778 m .68936 .6422 L .70195 .65008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.25312 .70293 m .25312 .64735 L .22195 .64545 L p .707 .577 .707 r
F P
0 g
s
.25312 .64735 m .25312 .70293 L .28495 .70215 L p .707 .577 .707 r
F P
0 g
s
.28495 .70215 m .28495 .64657 L .25312 .64735 L p .707 .577 .707 r
F P
0 g
s
.28495 .64657 m .28495 .70215 L .31434 .69877 L p .707 .577 .707 r
F P
0 g
s
.31434 .69877 m .31434 .64319 L .28495 .64657 L p .707 .577 .707 r
F P
0 g
s
.61082 .2497 m .61082 .75159 L .63393 .74119 L p .707 .577 .707 r
F P
0 g
s
.63393 .74119 m .63393 .2393 L .61082 .2497 L p .707 .577 .707 r
F P
0 g
s
.22195 .70103 m .22195 .64545 L .19449 .64105 L p .707 .577 .707 r
F P
0 g
s
.22195 .64545 m .22195 .70103 L .25312 .70293 L p .707 .577 .707 r
F P
0 g
s
.70195 .71598 m .70195 .75303 L .68936 .74515 L p .707 .577 .707 r
F P
0 g
s
.68936 .74515 m .68936 .7081 L .70195 .71598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31434 .64319 m .31434 .69877 L .33839 .69312 L p .707 .577 .707 r
F P
0 g
s
.33839 .69312 m .33839 .63754 L .31434 .64319 L p .707 .577 .707 r
F P
0 g
s
.25312 .7503 m .25312 .71324 L .22195 .71134 L p .707 .577 .707 r
F P
0 g
s
.25312 .71324 m .25312 .7503 L .28495 .74952 L p .707 .577 .707 r
F P
0 g
s
.28495 .74952 m .28495 .71247 L .25312 .71324 L p .707 .577 .707 r
F P
0 g
s
.68936 .6422 m .68936 .69778 L .66831 .69133 L p .707 .577 .707 r
F P
0 g
s
.66831 .69133 m .66831 .63574 L .68936 .6422 L p .707 .577 .707 r
F P
0 g
s
.70195 .75963 m .70195 .77815 L .68936 .77027 L p .707 .577 .707 r
F P
0 g
s
.68936 .77027 m .68936 .75174 L .70195 .75963 L p .707 .577 .707 r
F P
0 g
s
.37794 .74744 m .37794 .24555 L .36016 .23442 L p .707 .577 .707 r
F P
0 g
s
.37794 .24555 m .37794 .74744 L .40766 .75655 L p .707 .577 .707 r
F P
0 g
s
.28495 .71247 m .28495 .74952 L .31434 .74614 L p .707 .577 .707 r
F P
0 g
s
.31434 .74614 m .31434 .70909 L .28495 .71247 L p .707 .577 .707 r
F P
0 g
s
.19449 .64105 m .19449 .69664 L .22195 .70103 L p .707 .577 .707 r
F P
0 g
s
.19449 .69664 m .19449 .64105 L .17343 .6346 L p .707 .577 .707 r
F P
0 g
s
.22195 .7484 m .22195 .71134 L .19449 .70695 L p .707 .577 .707 r
F P
0 g
s
.22195 .71134 m .22195 .7484 L .25312 .7503 L p .707 .577 .707 r
F P
0 g
s
.25312 .77542 m .25312 .75689 L .22195 .75499 L p .707 .577 .707 r
F P
0 g
s
.25312 .75689 m .25312 .77542 L .28495 .77464 L p .707 .577 .707 r
F P
0 g
s
.28495 .77464 m .28495 .75611 L .25312 .75689 L p .707 .577 .707 r
F P
0 g
s
.31434 .70909 m .31434 .74614 L .33839 .74049 L p .707 .577 .707 r
F P
0 g
s
.33839 .74049 m .33839 .70344 L .31434 .70909 L p .707 .577 .707 r
F P
0 g
s
.28495 .75611 m .28495 .77464 L .31434 .77126 L p .707 .577 .707 r
F P
0 g
s
.31434 .77126 m .31434 .75273 L .28495 .75611 L p .707 .577 .707 r
F P
0 g
s
.33839 .63754 m .33839 .69312 L .35476 .68576 L p .707 .577 .707 r
F P
0 g
s
.35476 .68576 m .35476 .63017 L .33839 .63754 L p .707 .577 .707 r
F P
0 g
s
.19449 .70695 m .19449 .74401 L .22195 .7484 L p .707 .577 .707 r
F P
0 g
s
.22195 .75499 m .22195 .77352 L .25312 .77542 L p .707 .577 .707 r
F P
0 g
s
.68936 .7081 m .68936 .74515 L .66831 .7387 L p .707 .577 .707 r
F P
0 g
s
.66831 .7387 m .66831 .70164 L .68936 .7081 L p .707 .577 .707 r
F P
0 g
s
.22195 .77352 m .22195 .75499 L .19449 .7506 L p .707 .577 .707 r
F P
0 g
s
.17343 .6346 m .17343 .69018 L .19449 .69664 L p .707 .577 .707 r
F P
0 g
s
.19449 .74401 m .19449 .70695 L .17343 .7005 L p .707 .577 .707 r
F P
0 g
s
.66831 .63574 m .66831 .69133 L .64085 .68693 L p .707 .577 .707 r
F P
0 g
s
.64085 .68693 m .64085 .63135 L .66831 .63574 L p .707 .577 .707 r
F P
0 g
s
.19449 .7506 m .19449 .76912 L .22195 .77352 L p .707 .577 .707 r
F P
0 g
s
.64085 .7343 m .64085 .69725 L .66831 .70164 L p .707 .577 .707 r
F P
0 g
s
.63393 .2393 m .63393 .74119 L .64393 .72938 L p .707 .577 .707 r
F P
0 g
s
.64393 .72938 m .64393 .22749 L .63393 .2393 L p .707 .577 .707 r
F P
0 g
s
.31434 .75273 m .31434 .77126 L .33839 .76561 L p .707 .577 .707 r
F P
0 g
s
.33839 .76561 m .33839 .74708 L .31434 .75273 L p .707 .577 .707 r
F P
0 g
s
.17343 .69018 m .17343 .6346 L .16084 .62672 L p .707 .577 .707 r
F P
0 g
s
.68936 .75174 m .68936 .77027 L .66831 .76381 L p .707 .577 .707 r
F P
0 g
s
.66831 .76381 m .66831 .74529 L .68936 .75174 L p .707 .577 .707 r
F P
0 g
s
.17343 .7005 m .17343 .73755 L .19449 .74401 L p .707 .577 .707 r
F P
0 g
s
.19449 .76912 m .19449 .7506 L .17343 .74414 L p .707 .577 .707 r
F P
0 g
s
.33839 .70344 m .33839 .74049 L .35476 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .73313 m .35476 .69607 L .33839 .70344 L p .707 .577 .707 r
F P
0 g
s
.17343 .74414 m .17343 .76267 L .19449 .76912 L p .707 .577 .707 r
F P
0 g
s
.66831 .70164 m .66831 .7387 L .64085 .7343 L p .707 .577 .707 r
F P
0 g
s
.35476 .63017 m .35476 .68576 L .36184 .67739 L p .707 .577 .707 r
F P
0 g
s
.36184 .67739 m .36184 .62181 L .35476 .63017 L p .707 .577 .707 r
F P
0 g
s
.35476 .69607 m .35476 .73313 L .36184 .72476 L p .707 .577 .707 r
F P
0 g
s
.36184 .72476 m .36184 .68771 L .35476 .69607 L p .707 .577 .707 r
F P
0 g
s
.36184 .62181 m .36184 .67739 L .35894 .66885 L p .707 .577 .707 r
F P
0 g
s
.35894 .66885 m .35894 .61327 L .36184 .62181 L p .707 .577 .707 r
F P
0 g
s
.36184 .74988 m .36184 .73135 L .35476 .73972 L p .707 .577 .707 r
F P
0 g
s
.36184 .68771 m .36184 .72476 L .35894 .71622 L p .707 .577 .707 r
F P
0 g
s
.35894 .71622 m .35894 .67916 L .36184 .68771 L p .707 .577 .707 r
F P
0 g
s
.35894 .74134 m .35894 .72281 L .36184 .73135 L p .707 .577 .707 r
F P
0 g
s
.36016 .73631 m .36016 .23442 L .35607 .22236 L p .707 .577 .707 r
F P
0 g
s
.36184 .73135 m .36184 .74988 L .35894 .74134 L p .707 .577 .707 r
F P
0 g
s
.36016 .23442 m .36016 .73631 L .37794 .74744 L p .707 .577 .707 r
F P
0 g
s
.16084 .62672 m .16084 .6823 L .17343 .69018 L p .707 .577 .707 r
F P
0 g
s
.17343 .73755 m .17343 .7005 L .16084 .69261 L p .707 .577 .707 r
F P
0 g
s
.33839 .74708 m .33839 .76561 L .35476 .75824 L p .707 .577 .707 r
F P
0 g
s
.35476 .75824 m .35476 .73972 L .33839 .74708 L p .707 .577 .707 r
F P
0 g
s
.66831 .74529 m .66831 .76381 L .64085 .75942 L p .707 .577 .707 r
F P
0 g
s
.64085 .75942 m .64085 .7409 L .66831 .74529 L p .707 .577 .707 r
F P
0 g
s
.16084 .6823 m .16084 .62672 L .15794 .61817 L p .707 .577 .707 r
F P
0 g
s
.16084 .69261 m .16084 .72967 L .17343 .73755 L p .707 .577 .707 r
F P
0 g
s
.17343 .76267 m .17343 .74414 L .16084 .73626 L p .707 .577 .707 r
F P
0 g
s
.16084 .73626 m .16084 .75479 L .17343 .76267 L p .707 .577 .707 r
F P
0 g
s
.64393 .22749 m .64393 .72938 L .63984 .71732 L p .707 .577 .707 r
F P
0 g
s
.63984 .71732 m .63984 .21543 L .64393 .22749 L p .707 .577 .707 r
F P
0 g
s
.64085 .7409 m .64085 .75942 L .60968 .75752 L p .707 .577 .707 r
F P
0 g
s
.15794 .61817 m .15794 .67376 L .16084 .6823 L p .707 .577 .707 r
F P
0 g
s
.35476 .73972 m .35476 .75824 L .36184 .74988 L p .707 .577 .707 r
F P
0 g
s
.16084 .72967 m .16084 .69261 L .15794 .68407 L p .707 .577 .707 r
F P
0 g
s
.15794 .68407 m .15794 .72113 L .16084 .72967 L p .707 .577 .707 r
F P
0 g
s
.35894 .61327 m .35894 .66885 L .34635 .66097 L p .707 .577 .707 r
F P
0 g
s
.34635 .66097 m .34635 .60538 L .35894 .61327 L p .707 .577 .707 r
F P
0 g
s
.35894 .67916 m .35894 .71622 L .34635 .70834 L p .707 .577 .707 r
F P
0 g
s
.34635 .70834 m .34635 .67128 L .35894 .67916 L p .707 .577 .707 r
F P
0 g
s
.35894 .72281 m .35894 .74134 L .34635 .73345 L p .707 .577 .707 r
F P
0 g
s
.34635 .73345 m .34635 .71493 L .35894 .72281 L p .707 .577 .707 r
F P
0 g
s
.35607 .22236 m .35607 .72425 L .36016 .73631 L p .707 .577 .707 r
F P
0 g
s
.35607 .72425 m .35607 .22236 L .36607 .21055 L p .707 .577 .707 r
F P
0 g
s
.16084 .75479 m .16084 .73626 L .15794 .72772 L p .707 .577 .707 r
F P
0 g
s
.15794 .67376 m .15794 .61817 L .16503 .60981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15794 .72772 m .15794 .74624 L .16084 .75479 L p .707 .577 .707 r
F P
0 g
s
.16503 .60981 m .16503 .66539 L .15794 .67376 L p .707 .577 .707 r
F P
0 g
s
.15794 .72113 m .15794 .68407 L .16503 .67571 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63984 .21543 m .63984 .71732 L .62206 .70619 L p .707 .577 .707 r
F P
0 g
s
.62206 .70619 m .62206 .2043 L .63984 .21543 L p .707 .577 .707 r
F P
0 g
s
.16503 .67571 m .16503 .71276 L .15794 .72113 L p .707 .577 .707 r
F P
0 g
s
.16503 .66539 m .16503 .60981 L .1814 .60244 L p .707 .577 .707 r
F P
0 g
s
.15794 .74624 m .15794 .72772 L .16503 .71935 L p .707 .577 .707 r
F P
0 g
s
.16503 .71935 m .16503 .73788 L .15794 .74624 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36607 .71244 m .36607 .21055 L .38918 .20015 L p .707 .577 .707 r
F P
0 g
s
.36607 .21055 m .36607 .71244 L .35607 .72425 L p .707 .577 .707 r
F P
0 g
s
.1814 .60244 m .1814 .65802 L .16503 .66539 L p .707 .577 .707 r
F P
0 g
s
.34635 .60538 m .34635 .66097 L .3253 .65451 L p .707 .577 .707 r
F P
0 g
s
.3253 .65451 m .3253 .59893 L .34635 .60538 L p .707 .577 .707 r
F P
0 g
s
.16503 .71276 m .16503 .67571 L .1814 .66834 L p .707 .577 .707 r
F P
0 g
s
.1814 .65802 m .1814 .60244 L .20545 .59679 L p .707 .577 .707 r
F P
0 g
s
.1814 .66834 m .1814 .70539 L .16503 .71276 L p .707 .577 .707 r
F P
0 g
s
.16503 .73788 m .16503 .71935 L .1814 .71199 L p .707 .577 .707 r
F P
0 g
s
.34635 .67128 m .34635 .70834 L .3253 .70188 L p .707 .577 .707 r
F P
0 g
s
.3253 .70188 m .3253 .66483 L .34635 .67128 L p .707 .577 .707 r
F P
0 g
s
.62206 .2043 m .62206 .70619 L .59233 .69708 L p .707 .577 .707 r
F P
0 g
s
.59233 .69708 m .59233 .19519 L .62206 .2043 L p .707 .577 .707 r
F P
0 g
s
.1814 .71199 m .1814 .73051 L .16503 .73788 L p .707 .577 .707 r
F P
0 g
s
.3253 .59893 m .3253 .65451 L .29784 .65012 L p .707 .577 .707 r
F P
0 g
s
.29784 .65012 m .29784 .59454 L .3253 .59893 L p .707 .577 .707 r
F P
0 g
s
.20545 .59679 m .20545 .65237 L .1814 .65802 L p .707 .577 .707 r
F P
0 g
s
.1814 .70539 m .1814 .66834 L .20545 .66269 L p .707 .577 .707 r
F P
0 g
s
.34635 .71493 m .34635 .73345 L .3253 .727 L p .707 .577 .707 r
F P
0 g
s
.3253 .727 m .3253 .70847 L .34635 .71493 L p .707 .577 .707 r
F P
0 g
s
.20545 .65237 m .20545 .59679 L .23483 .59341 L p .707 .577 .707 r
F P
0 g
s
.38918 .20015 m .38918 .70204 L .36607 .71244 L p .707 .577 .707 r
F P
0 g
s
.38918 .70204 m .38918 .20015 L .42314 .19217 L p .707 .577 .707 r
F P
0 g
s
.29784 .59454 m .29784 .65012 L .26667 .64822 L p .707 .577 .707 r
F P
0 g
s
.26667 .64822 m .26667 .59264 L .29784 .59454 L p .707 .577 .707 r
F P
0 g
s
.20545 .66269 m .20545 .69974 L .1814 .70539 L p .707 .577 .707 r
F P
0 g
s
.1814 .73051 m .1814 .71199 L .20545 .70634 L p .707 .577 .707 r
F P
0 g
s
.3253 .66483 m .3253 .70188 L .29784 .69749 L p .707 .577 .707 r
F P
0 g
s
.29784 .69749 m .29784 .66043 L .3253 .66483 L p .707 .577 .707 r
F P
0 g
s
.23483 .649 m .23483 .59341 L .26667 .59264 L p .707 .577 .707 r
F P
0 g
s
.23483 .59341 m .23483 .649 L .20545 .65237 L p .707 .577 .707 r
F P
0 g
s
.26667 .59264 m .26667 .64822 L .23483 .649 L p .707 .577 .707 r
F P
0 g
s
.20545 .70634 m .20545 .72486 L .1814 .73051 L p .707 .577 .707 r
F P
0 g
s
.73333 .64771 m .73333 .59212 L .70216 .59022 L p .707 .577 .707 r
F P
0 g
s
.73333 .59212 m .73333 .64771 L .76517 .64693 L p .707 .577 .707 r
F P
0 g
s
.76517 .64693 m .76517 .59135 L .73333 .59212 L p .707 .577 .707 r
F P
0 g
s
.20545 .69974 m .20545 .66269 L .23483 .65931 L p .707 .577 .707 r
F P
0 g
s
.76517 .59135 m .76517 .64693 L .79455 .64355 L p .707 .577 .707 r
F P
0 g
s
.79455 .64355 m .79455 .58797 L .76517 .59135 L p .707 .577 .707 r
F P
0 g
s
.59233 .19519 m .59233 .69708 L .55357 .69088 L p .707 .577 .707 r
F P
0 g
s
.55357 .69088 m .55357 .18899 L .59233 .19519 L p .707 .577 .707 r
F P
0 g
s
.3253 .70847 m .3253 .727 L .29784 .72261 L p .707 .577 .707 r
F P
0 g
s
.29784 .72261 m .29784 .70408 L .3253 .70847 L p .707 .577 .707 r
F P
0 g
s
.70216 .64581 m .70216 .59022 L .6747 .58583 L p .707 .577 .707 r
F P
0 g
s
.70216 .59022 m .70216 .64581 L .73333 .64771 L p .707 .577 .707 r
F P
0 g
s
.29784 .66043 m .29784 .69749 L .26667 .69559 L p .707 .577 .707 r
F P
0 g
s
.26667 .69559 m .26667 .65853 L .29784 .66043 L p .707 .577 .707 r
F P
0 g
s
.23483 .65931 m .23483 .69637 L .20545 .69974 L p .707 .577 .707 r
F P
0 g
s
.23483 .69637 m .23483 .65931 L .26667 .65853 L p .707 .577 .707 r
F P
0 g
s
.20545 .72486 m .20545 .70634 L .23483 .70296 L p .707 .577 .707 r
F P
0 g
s
.42314 .69406 m .42314 .19217 L .46462 .1874 L p .707 .577 .707 r
F P
0 g
s
.42314 .19217 m .42314 .69406 L .38918 .70204 L p .707 .577 .707 r
F P
0 g
s
.79455 .58797 m .79455 .64355 L .8186 .6379 L p .707 .577 .707 r
F P
0 g
s
.8186 .6379 m .8186 .58232 L .79455 .58797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65853 m .26667 .69559 L .23483 .69637 L p .707 .577 .707 r
F P
0 g
s
.73333 .69508 m .73333 .65802 L .70216 .65612 L p .707 .577 .707 r
F P
0 g
s
.73333 .65802 m .73333 .69508 L .76517 .6943 L p .707 .577 .707 r
F P
0 g
s
.76517 .6943 m .76517 .65724 L .73333 .65802 L p .707 .577 .707 r
F P
0 g
s
.23483 .70296 m .23483 .72148 L .20545 .72486 L p .707 .577 .707 r
F P
0 g
s
.76517 .65724 m .76517 .6943 L .79455 .69092 L p .707 .577 .707 r
F P
0 g
s
.79455 .69092 m .79455 .65387 L .76517 .65724 L p .707 .577 .707 r
F P
0 g
s
.29784 .70408 m .29784 .72261 L .26667 .72071 L p .707 .577 .707 r
F P
0 g
s
.26667 .72071 m .26667 .70218 L .29784 .70408 L p .707 .577 .707 r
F P
0 g
s
.6747 .58583 m .6747 .64141 L .70216 .64581 L p .707 .577 .707 r
F P
0 g
s
.6747 .64141 m .6747 .58583 L .65365 .57938 L p .707 .577 .707 r
F P
0 g
s
.70216 .69318 m .70216 .65612 L .6747 .65173 L p .707 .577 .707 r
F P
0 g
s
.70216 .65612 m .70216 .69318 L .73333 .69508 L p .707 .577 .707 r
F P
0 g
s
.55357 .18899 m .55357 .69088 L .50956 .68819 L p .707 .577 .707 r
F P
0 g
s
.50956 .68819 m .50956 .1863 L .55357 .18899 L p .707 .577 .707 r
F P
0 g
s
.23483 .72148 m .23483 .70296 L .26667 .70218 L p .707 .577 .707 r
F P
0 g
s
.26667 .70218 m .26667 .72071 L .23483 .72148 L p .707 .577 .707 r
F P
0 g
s
.73333 .72019 m .73333 .70167 L .70216 .69977 L p .707 .577 .707 r
F P
0 g
s
.73333 .70167 m .73333 .72019 L .76517 .71942 L p .707 .577 .707 r
F P
0 g
s
.76517 .71942 m .76517 .70089 L .73333 .70167 L p .707 .577 .707 r
F P
0 g
s
.46462 .68929 m .46462 .1874 L .50956 .1863 L p .707 .577 .707 r
F P
0 g
s
.46462 .1874 m .46462 .68929 L .42314 .69406 L p .707 .577 .707 r
F P
0 g
s
.79455 .65387 m .79455 .69092 L .8186 .68527 L p .707 .577 .707 r
F P
0 g
s
.8186 .68527 m .8186 .64822 L .79455 .65387 L p .707 .577 .707 r
F P
0 g
s
.76517 .70089 m .76517 .71942 L .79455 .71604 L p .707 .577 .707 r
F P
0 g
s
.79455 .71604 m .79455 .69751 L .76517 .70089 L p .707 .577 .707 r
F P
0 g
s
.8186 .58232 m .8186 .6379 L .83497 .63053 L p .707 .577 .707 r
F P
0 g
s
.83497 .63053 m .83497 .57495 L .8186 .58232 L p .707 .577 .707 r
F P
0 g
s
.50956 .1863 m .50956 .68819 L .46462 .68929 L p .707 .577 .707 r
F P
0 g
s
.6747 .65173 m .6747 .68878 L .70216 .69318 L p .707 .577 .707 r
F P
0 g
s
.70216 .69977 m .70216 .71829 L .73333 .72019 L p .707 .577 .707 r
F P
0 g
s
.70216 .71829 m .70216 .69977 L .6747 .69537 L p .707 .577 .707 r
F P
0 g
s
.65365 .57938 m .65365 .63496 L .6747 .64141 L p .707 .577 .707 r
F P
0 g
s
.6747 .68878 m .6747 .65173 L .65365 .64528 L p .707 .577 .707 r
F P
0 g
s
.6747 .69537 m .6747 .7139 L .70216 .71829 L p .707 .577 .707 r
F P
0 g
s
.79455 .69751 m .79455 .71604 L .8186 .71039 L p .707 .577 .707 r
F P
0 g
s
.8186 .71039 m .8186 .69186 L .79455 .69751 L p .707 .577 .707 r
F P
0 g
s
.65365 .63496 m .65365 .57938 L .64105 .57149 L p .707 .577 .707 r
F P
0 g
s
.65365 .64528 m .65365 .68233 L .6747 .68878 L p .707 .577 .707 r
F P
0 g
s
.6747 .7139 m .6747 .69537 L .65365 .68892 L p .707 .577 .707 r
F P
0 g
s
.8186 .64822 m .8186 .68527 L .83497 .6779 L p .707 .577 .707 r
F P
0 g
s
.83497 .6779 m .83497 .64085 L .8186 .64822 L p .707 .577 .707 r
F P
0 g
s
.65365 .68892 m .65365 .70745 L .6747 .7139 L p .707 .577 .707 r
F P
0 g
s
.64105 .57149 m .64105 .62708 L .65365 .63496 L p .707 .577 .707 r
F P
0 g
s
.83497 .57495 m .83497 .63053 L .84205 .62217 L p .707 .577 .707 r
F P
0 g
s
.84205 .62217 m .84205 .56659 L .83497 .57495 L p .707 .577 .707 r
F P
0 g
s
.65365 .68233 m .65365 .64528 L .64105 .63739 L p .707 .577 .707 r
F P
0 g
s
.8186 .69186 m .8186 .71039 L .83497 .70302 L p .707 .577 .707 r
F P
0 g
s
.83497 .70302 m .83497 .68449 L .8186 .69186 L p .707 .577 .707 r
F P
0 g
s
.64105 .62708 m .64105 .57149 L .63816 .56295 L p .707 .577 .707 r
F P
0 g
s
.64105 .63739 m .64105 .67445 L .65365 .68233 L p .707 .577 .707 r
F P
0 g
s
.65365 .70745 m .65365 .68892 L .64105 .68104 L p .707 .577 .707 r
F P
0 g
s
.83497 .64085 m .83497 .6779 L .84206 .66954 L p .707 .577 .707 r
F P
0 g
s
.84206 .66954 m .84205 .63248 L .83497 .64085 L p .707 .577 .707 r
F P
0 g
s
.64105 .68104 m .64105 .69956 L .65365 .70745 L p .707 .577 .707 r
F P
0 g
s
.63816 .56295 m .63816 .61853 L .64105 .62708 L p .707 .577 .707 r
F P
0 g
s
.84205 .56659 m .84205 .62217 L .83916 .61363 L p .707 .577 .707 r
F P
0 g
s
.83916 .61363 m .83916 .55804 L .84205 .56659 L p .707 .577 .707 r
F P
0 g
s
.83497 .68449 m .83497 .70302 L .84206 .69466 L p .707 .577 .707 r
F P
0 g
s
.84206 .69466 m .84206 .67613 L .83497 .68449 L p .707 .577 .707 r
F P
0 g
s
.64105 .67445 m .64105 .63739 L .63816 .62885 L p .707 .577 .707 r
F P
0 g
s
.63816 .62885 m .63816 .6659 L .64105 .67445 L p .707 .577 .707 r
F P
0 g
s
.64105 .69956 m .64105 .68104 L .63816 .67249 L p .707 .577 .707 r
F P
0 g
s
.63816 .61853 m .63816 .56295 L .64524 .55459 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .67249 m .63816 .69102 L .64105 .69956 L p .707 .577 .707 r
F P
0 g
s
.84205 .63248 m .84206 .66954 L .83916 .661 L p .707 .577 .707 r
F P
0 g
s
.83916 .661 m .83916 .62394 L .84205 .63248 L p .707 .577 .707 r
F P
0 g
s
.64524 .55459 m .64524 .61017 L .63816 .61853 L p .707 .577 .707 r
F P
0 g
s
.84206 .67613 m .84206 .69466 L .83916 .68611 L p .707 .577 .707 r
F P
0 g
s
.83916 .68611 m .83916 .66759 L .84206 .67613 L p .707 .577 .707 r
F P
0 g
s
.83916 .55804 m .83916 .61363 L .82657 .60574 L p .707 .577 .707 r
F P
0 g
s
.82657 .60574 m .82657 .55016 L .83916 .55804 L p .707 .577 .707 r
F P
0 g
s
.63816 .6659 m .63816 .62885 L .64524 .62048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39032 .61089 m .39032 .55531 L .35915 .55341 L p .707 .577 .707 r
F P
0 g
s
.39032 .55531 m .39032 .61089 L .42216 .61011 L p .707 .577 .707 r
F P
0 g
s
.42216 .61011 m .42216 .55453 L .39032 .55531 L p .707 .577 .707 r
F P
0 g
s
.64524 .62048 m .64524 .65754 L .63816 .6659 L p .707 .577 .707 r
F P
0 g
s
.64524 .61017 m .64524 .55459 L .66161 .54722 L p .707 .577 .707 r
F P
0 g
s
.42216 .55453 m .42216 .61011 L .45154 .60673 L p .707 .577 .707 r
F P
0 g
s
.45154 .60673 m .45154 .55115 L .42216 .55453 L p .707 .577 .707 r
F P
0 g
s
.63816 .69102 m .63816 .67249 L .64524 .66413 L p .707 .577 .707 r
F P
0 g
s
.35915 .60899 m .35915 .55341 L .33169 .54902 L p .707 .577 .707 r
F P
0 g
s
.35915 .55341 m .35915 .60899 L .39032 .61089 L p .707 .577 .707 r
F P
0 g
s
.64524 .66413 m .64524 .68266 L .63816 .69102 L p .707 .577 .707 r
F P
0 g
s
.83916 .62394 m .83916 .661 L .82657 .65311 L p .707 .577 .707 r
F P
0 g
s
.82657 .65311 m .82657 .61606 L .83916 .62394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .55115 m .45154 .60673 L .47559 .60109 L p .707 .577 .707 r
F P
0 g
s
.47559 .60109 m .47559 .5455 L .45154 .55115 L p .707 .577 .707 r
F P
0 g
s
.66161 .54722 m .66161 .6028 L .64524 .61017 L p .707 .577 .707 r
F P
0 g
s
.39032 .65826 m .39032 .62121 L .35915 .61931 L p .707 .577 .707 r
F P
0 g
s
.39032 .62121 m .39032 .65826 L .42216 .65748 L p .707 .577 .707 r
F P
0 g
s
.42216 .65748 m .42216 .62043 L .39032 .62121 L p .707 .577 .707 r
F P
0 g
s
.82657 .55016 m .82657 .60574 L .80551 .59929 L p .707 .577 .707 r
F P
0 g
s
.80551 .59929 m .80551 .54371 L .82657 .55016 L p .707 .577 .707 r
F P
0 g
s
.83916 .66759 m .83916 .68611 L .82657 .67823 L p .707 .577 .707 r
F P
0 g
s
.82657 .67823 m .82657 .6597 L .83916 .66759 L p .707 .577 .707 r
F P
0 g
s
.64524 .65754 m .64524 .62048 L .66161 .61312 L p .707 .577 .707 r
F P
0 g
s
.42216 .62043 m .42216 .65748 L .45154 .65411 L p .707 .577 .707 r
F P
0 g
s
.45154 .65411 m .45154 .61705 L .42216 .62043 L p .707 .577 .707 r
F P
0 g
s
.33169 .54902 m .33169 .6046 L .35915 .60899 L p .707 .577 .707 r
F P
0 g
s
.33169 .6046 m .33169 .54902 L .31064 .54256 L p .707 .577 .707 r
F P
0 g
s
.35915 .65636 m .35915 .61931 L .33169 .61491 L p .707 .577 .707 r
F P
0 g
s
.35915 .61931 m .35915 .65636 L .39032 .65826 L p .707 .577 .707 r
F P
0 g
s
.66161 .6028 m .66161 .54722 L .68566 .54157 L p .707 .577 .707 r
F P
0 g
s
.39032 .68338 m .39032 .66485 L .35915 .66295 L p .707 .577 .707 r
F P
0 g
s
.39032 .66485 m .39032 .68338 L .42216 .6826 L p .707 .577 .707 r
F P
0 g
s
.42216 .6826 m .42216 .66407 L .39032 .66485 L p .707 .577 .707 r
F P
0 g
s
.66161 .61312 m .66161 .65017 L .64524 .65754 L p .707 .577 .707 r
F P
0 g
s
.64524 .68266 m .64524 .66413 L .66161 .65676 L p .707 .577 .707 r
F P
0 g
s
.45154 .61705 m .45154 .65411 L .47559 .64846 L p .707 .577 .707 r
F P
0 g
s
.47559 .64846 m .47559 .6114 L .45154 .61705 L p .707 .577 .707 r
F P
0 g
s
.42216 .66407 m .42216 .6826 L .45154 .67922 L p .707 .577 .707 r
F P
0 g
s
.45154 .67922 m .45154 .6607 L .42216 .66407 L p .707 .577 .707 r
F P
0 g
s
.47559 .5455 m .47559 .60109 L .49196 .59372 L p .707 .577 .707 r
F P
0 g
s
.49196 .59372 m .49196 .53813 L .47559 .5455 L p .707 .577 .707 r
F P
0 g
s
.33169 .61491 m .33169 .65197 L .35915 .65636 L p .707 .577 .707 r
F P
0 g
s
.35915 .66295 m .35915 .68148 L .39032 .68338 L p .707 .577 .707 r
F P
0 g
s
.82657 .61606 m .82657 .65311 L .80551 .64666 L p .707 .577 .707 r
F P
0 g
s
.80551 .64666 m .80551 .6096 L .82657 .61606 L p .707 .577 .707 r
F P
0 g
s
.35915 .68148 m .35915 .66295 L .33169 .65856 L p .707 .577 .707 r
F P
0 g
s
.31064 .54256 m .31064 .59814 L .33169 .6046 L p .707 .577 .707 r
F P
0 g
s
.66161 .65676 m .66161 .67529 L .64524 .68266 L p .707 .577 .707 r
F P
0 g
s
.33169 .65197 m .33169 .61491 L .31064 .60846 L p .707 .577 .707 r
F P
0 g
s
.80551 .54371 m .80551 .59929 L .77805 .5949 L p .707 .577 .707 r
F P
0 g
s
.77805 .5949 m .77805 .53931 L .80551 .54371 L p .707 .577 .707 r
F P
0 g
s
.33169 .65856 m .33169 .67709 L .35915 .68148 L p .707 .577 .707 r
F P
0 g
s
.68566 .54157 m .68566 .59715 L .66161 .6028 L p .707 .577 .707 r
F P
0 g
s
.45154 .6607 m .45154 .67922 L .47559 .67357 L p .707 .577 .707 r
F P
0 g
s
.47559 .67357 m .47559 .65505 L .45154 .6607 L p .707 .577 .707 r
F P
0 g
s
.31064 .59814 m .31064 .54256 L .29804 .53468 L p .707 .577 .707 r
F P
0 g
s
.66161 .65017 m .66161 .61312 L .68566 .60747 L p .707 .577 .707 r
F P
0 g
s
.82657 .6597 m .82657 .67823 L .80551 .67178 L p .707 .577 .707 r
F P
0 g
s
.80551 .67178 m .80551 .65325 L .82657 .6597 L p .707 .577 .707 r
F P
0 g
s
.68566 .59715 m .68566 .54157 L .71504 .53819 L p .707 .577 .707 r
F P
0 g
s
.31064 .60846 m .31064 .64551 L .33169 .65197 L p .707 .577 .707 r
F P
0 g
s
.33169 .67709 m .33169 .65856 L .31064 .6521 L p .707 .577 .707 r
F P
0 g
s
.47559 .6114 m .47559 .64846 L .49196 .64109 L p .707 .577 .707 r
F P
0 g
s
.49196 .64109 m .49196 .60403 L .47559 .6114 L p .707 .577 .707 r
F P
0 g
s
.77805 .53931 m .77805 .5949 L .74688 .593 L p .707 .577 .707 r
F P
0 g
s
.74688 .593 m .74688 .53741 L .77805 .53931 L p .707 .577 .707 r
F P
0 g
s
.68566 .60747 m .68566 .64452 L .66161 .65017 L p .707 .577 .707 r
F P
0 g
s
.31064 .6521 m .31064 .67063 L .33169 .67709 L p .707 .577 .707 r
F P
0 g
s
.66161 .67529 m .66161 .65676 L .68566 .65111 L p .707 .577 .707 r
F P
0 g
s
.80551 .6096 m .80551 .64666 L .77805 .64227 L p .707 .577 .707 r
F P
0 g
s
.77805 .64227 m .77805 .60521 L .80551 .6096 L p .707 .577 .707 r
F P
0 g
s
.29804 .53468 m .29804 .59026 L .31064 .59814 L p .707 .577 .707 r
F P
0 g
s
.71504 .59377 m .71504 .53819 L .74688 .53741 L p .707 .577 .707 r
F P
0 g
s
.71504 .53819 m .71504 .59377 L .68566 .59715 L p .707 .577 .707 r
F P
0 g
s
.49196 .53813 m .49196 .59372 L .49904 .58535 L p .707 .577 .707 r
F P
0 g
s
.49904 .58535 m .49904 .52977 L .49196 .53813 L p .707 .577 .707 r
F P
0 g
s
.31064 .64551 m .31064 .60846 L .29804 .60058 L p .707 .577 .707 r
F P
0 g
s
.74688 .53741 m .74688 .593 L .71504 .59377 L p .707 .577 .707 r
F P
0 g
s
.68566 .65111 m .68566 .66964 L .66161 .67529 L p .707 .577 .707 r
F P
0 g
s
.47559 .65505 m .47559 .67357 L .49196 .66621 L p .707 .577 .707 r
F P
0 g
s
.49196 .66621 m .49196 .64768 L .47559 .65505 L p .707 .577 .707 r
F P
0 g
s
.68566 .64452 m .68566 .60747 L .71504 .60409 L p .707 .577 .707 r
F P
0 g
s
.80551 .65325 m .80551 .67178 L .77805 .66738 L p .707 .577 .707 r
F P
0 g
s
.77805 .66738 m .77805 .64886 L .80551 .65325 L p .707 .577 .707 r
F P
0 g
s
.29804 .59026 m .29804 .53468 L .29515 .52614 L p .707 .577 .707 r
F P
0 g
s
.29804 .60058 m .29804 .63763 L .31064 .64551 L p .707 .577 .707 r
F P
0 g
s
.77805 .60521 m .77805 .64227 L .74688 .64037 L p .707 .577 .707 r
F P
0 g
s
.74688 .64037 m .74688 .60331 L .77805 .60521 L p .707 .577 .707 r
F P
0 g
s
.31064 .67063 m .31064 .6521 L .29804 .64422 L p .707 .577 .707 r
F P
0 g
s
.71504 .60409 m .71504 .64114 L .68566 .64452 L p .707 .577 .707 r
F P
0 g
s
.71504 .64114 m .71504 .60409 L .74688 .60331 L p .707 .577 .707 r
F P
0 g
s
.68566 .66964 m .68566 .65111 L .71504 .64773 L p .707 .577 .707 r
F P
0 g
s
.49196 .60403 m .49196 .64109 L .49904 .63272 L p .707 .577 .707 r
F P
0 g
s
.49904 .63272 m .49904 .59567 L .49196 .60403 L p .707 .577 .707 r
F P
0 g
s
.29804 .64422 m .29804 .66275 L .31064 .67063 L p .707 .577 .707 r
F P
0 g
s
.74688 .60331 m .74688 .64037 L .71504 .64114 L p .707 .577 .707 r
F P
0 g
s
.71504 .64773 m .71504 .66626 L .68566 .66964 L p .707 .577 .707 r
F P
0 g
s
.77805 .64886 m .77805 .66738 L .74688 .66548 L p .707 .577 .707 r
F P
0 g
s
.74688 .66548 m .74688 .64696 L .77805 .64886 L p .707 .577 .707 r
F P
0 g
s
.29515 .52614 m .29515 .58172 L .29804 .59026 L p .707 .577 .707 r
F P
0 g
s
.49904 .52977 m .49904 .58535 L .49615 .57681 L p .707 .577 .707 r
F P
0 g
s
.49615 .57681 m .49615 .52123 L .49904 .52977 L p .707 .577 .707 r
F P
0 g
s
.71504 .66626 m .71504 .64773 L .74688 .64696 L p .707 .577 .707 r
F P
0 g
s
.49196 .64768 m .49196 .66621 L .49904 .65784 L p .707 .577 .707 r
F P
0 g
s
.49904 .65784 m .49904 .63931 L .49196 .64768 L p .707 .577 .707 r
F P
0 g
s
.29804 .63763 m .29804 .60058 L .29515 .59203 L p .707 .577 .707 r
F P
0 g
s
.74688 .64696 m .74688 .66548 L .71504 .66626 L p .707 .577 .707 r
F P
0 g
s
.29515 .59203 m .29515 .62909 L .29804 .63763 L p .707 .577 .707 r
F P
0 g
s
.29804 .66275 m .29804 .64422 L .29515 .63568 L p .707 .577 .707 r
F P
0 g
s
.29515 .58172 m .29515 .52614 L .30223 .51777 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29515 .63568 m .29515 .65421 L .29804 .66275 L p .707 .577 .707 r
F P
0 g
s
.49904 .59567 m .49904 .63272 L .49615 .62418 L p .707 .577 .707 r
F P
0 g
s
.49615 .62418 m .49615 .58713 L .49904 .59567 L p .707 .577 .707 r
F P
0 g
s
.30223 .51777 m .30223 .57335 L .29515 .58172 L p .707 .577 .707 r
F P
0 g
s
.49904 .63931 m .49904 .65784 L .49615 .6493 L p .707 .577 .707 r
F P
0 g
s
.49615 .6493 m .49615 .63077 L .49904 .63931 L p .707 .577 .707 r
F P
0 g
s
.49615 .52123 m .49615 .57681 L .48356 .56893 L p .707 .577 .707 r
F P
0 g
s
.48356 .56893 m .48356 .51334 L .49615 .52123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62909 m .29515 .59203 L .30223 .58367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .58367 m .30223 .62072 L .29515 .62909 L p .707 .577 .707 r
F P
0 g
s
.30223 .57335 m .30223 .51777 L .3186 .5104 L p .707 .577 .707 r
F P
0 g
s
.29515 .65421 m .29515 .63568 L .30223 .62731 L p .707 .577 .707 r
F P
0 g
s
.30223 .62731 m .30223 .64584 L .29515 .65421 L p .707 .577 .707 r
F P
0 g
s
.49615 .58713 m .49615 .62418 L .48356 .6163 L p .707 .577 .707 r
F P
0 g
s
.48356 .6163 m .48356 .57924 L .49615 .58713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .5104 m .3186 .56599 L .30223 .57335 L p .707 .577 .707 r
F P
0 g
s
.48356 .51334 m .48356 .56893 L .4625 .56247 L p .707 .577 .707 r
F P
0 g
s
.4625 .56247 m .4625 .50689 L .48356 .51334 L p .707 .577 .707 r
F P
0 g
s
.49615 .63077 m .49615 .6493 L .48356 .64141 L p .707 .577 .707 r
F P
0 g
s
.48356 .64141 m .48356 .62289 L .49615 .63077 L p .707 .577 .707 r
F P
0 g
s
.30223 .62072 m .30223 .58367 L .3186 .5763 L p .707 .577 .707 r
F P
0 g
s
.3186 .56599 m .3186 .5104 L .34265 .50475 L p .707 .577 .707 r
F P
0 g
s
.3186 .5763 m .3186 .61336 L .30223 .62072 L p .707 .577 .707 r
F P
0 g
s
.30223 .64584 m .30223 .62731 L .3186 .61995 L p .707 .577 .707 r
F P
0 g
s
.48356 .57924 m .48356 .6163 L .4625 .60984 L p .707 .577 .707 r
F P
0 g
s
.4625 .60984 m .4625 .57279 L .48356 .57924 L p .707 .577 .707 r
F P
0 g
s
.3186 .61995 m .3186 .63847 L .30223 .64584 L p .707 .577 .707 r
F P
0 g
s
.4625 .50689 m .4625 .56247 L .43504 .55808 L p .707 .577 .707 r
F P
0 g
s
.43504 .55808 m .43504 .5025 L .4625 .50689 L p .707 .577 .707 r
F P
0 g
s
.34265 .50475 m .34265 .56034 L .3186 .56599 L p .707 .577 .707 r
F P
0 g
s
.3186 .61336 m .3186 .5763 L .34265 .57065 L p .707 .577 .707 r
F P
0 g
s
.48356 .62289 m .48356 .64141 L .4625 .63496 L p .707 .577 .707 r
F P
0 g
s
.4625 .63496 m .4625 .61643 L .48356 .62289 L p .707 .577 .707 r
F P
0 g
s
.34265 .56034 m .34265 .50475 L .37203 .50137 L p .707 .577 .707 r
F P
0 g
s
.43504 .5025 m .43504 .55808 L .40387 .55618 L p .707 .577 .707 r
F P
0 g
s
.40387 .55618 m .40387 .5006 L .43504 .5025 L p .707 .577 .707 r
F P
0 g
s
.34265 .57065 m .34265 .60771 L .3186 .61336 L p .707 .577 .707 r
F P
0 g
s
.3186 .63847 m .3186 .61995 L .34265 .6143 L p .707 .577 .707 r
F P
0 g
s
.4625 .57279 m .4625 .60984 L .43504 .60545 L p .707 .577 .707 r
F P
0 g
s
.43504 .60545 m .43504 .5684 L .4625 .57279 L p .707 .577 .707 r
F P
0 g
s
.37203 .55696 m .37203 .50137 L .40387 .5006 L p .707 .577 .707 r
F P
0 g
s
.37203 .50137 m .37203 .55696 L .34265 .56034 L p .707 .577 .707 r
F P
0 g
s
.40387 .5006 m .40387 .55618 L .37203 .55696 L p .707 .577 .707 r
F P
0 g
s
.34265 .6143 m .34265 .63282 L .3186 .63847 L p .707 .577 .707 r
F P
0 g
s
.34265 .60771 m .34265 .57065 L .37203 .56727 L p .707 .577 .707 r
F P
0 g
s
.4625 .61643 m .4625 .63496 L .43504 .63057 L p .707 .577 .707 r
F P
0 g
s
.43504 .63057 m .43504 .61204 L .4625 .61643 L p .707 .577 .707 r
F P
0 g
s
.43504 .5684 m .43504 .60545 L .40387 .60355 L p .707 .577 .707 r
F P
0 g
s
.40387 .60355 m .40387 .56649 L .43504 .5684 L p .707 .577 .707 r
F P
0 g
s
.37203 .56727 m .37203 .60433 L .34265 .60771 L p .707 .577 .707 r
F P
0 g
s
.37203 .60433 m .37203 .56727 L .40387 .56649 L p .707 .577 .707 r
F P
0 g
s
.34265 .63282 m .34265 .6143 L .37203 .61092 L p .707 .577 .707 r
F P
0 g
s
.40387 .56649 m .40387 .60355 L .37203 .60433 L p .707 .577 .707 r
F P
0 g
s
.37203 .61092 m .37203 .62945 L .34265 .63282 L p .707 .577 .707 r
F P
0 g
s
.43504 .61204 m .43504 .63057 L .40387 .62867 L p .707 .577 .707 r
F P
0 g
s
.40387 .62867 m .40387 .61014 L .43504 .61204 L p .707 .577 .707 r
F P
0 g
s
.37203 .62945 m .37203 .61092 L .40387 .61014 L p .707 .577 .707 r
F P
0 g
s
.40387 .61014 m .40387 .62867 L .37203 .62945 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eo
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001dOol30000
0eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol0071oo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00
001aOol006eoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEUYFFUH3001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061o
o`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000HOol90014Ool005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?Ool90004FUH00`00FUIJEP02FUH8000l
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00008Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000goo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH40006FUH00`00FUIJEP04
FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF0000
15YF1@001eYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00
FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP8000AJEP03
001JEUYF00EJEQT00003FUH005YF00EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH000030005FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000UYF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0002FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000oOolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP@000EJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUH000020006FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPT000IJEP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH50002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPd000=JEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEPH00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH000020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP00FUH20003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P000UYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF000005YF
00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF001oo`0/Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800004FUH000000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP03FUHC0004
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYF
FUH<0004FUHF0004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHH0003FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30002FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50003FUH00`00FUIJEP0:0004FUH00`00FUIJ
EP02FUH80004Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPL000MJEP@000IJEP04001JEP000002FUH30002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH000030003FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPT000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH30003FUH2000]Ool002aoo`03001JEP0000AJEP03001J
EP0000<000IJEP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUH000040003FUH80004
FUH00`00FUIJEP03FUH>0002FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF000000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020002FUH20000
0eYF0000000]Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQH000=JEP03001JEUYF
009JEPH0009JEP05001JEUYF001JEP0:0004FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF200015YF
00<005YFFUH00eYF2@000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00
;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03
001JEUYF00<002eoo`00;7oo0P000eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEP03001JEUYF
00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`80009JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEP00008000IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<000=JEP04
001JEUYFFUH2000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF200015YF
10001UYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH2000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH0000B0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30002Ool4000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003Ool2000015YF00000000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000`00
0UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0017oo0`000eYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF100015YF2@00
35YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF00<005YFFUH00UYF1P0000=JEP0000005`001Goo100000=JEP00FUH00eYF00<005YF0000;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH?0008FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YF
FUIJEPT0019oo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00<005YF0000
0`000Woo6`000Woo1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`03001JEP0000=JEP@000=oo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000Eoo`@00005FUH005YFFUH00002FUH01000FUIJEUYF0P00
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo000/Ool01000FUH005YF0P000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP<0009J
EP05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00
;7oo00D005YF000005YF00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP000080009JEP<0009JEP800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH4000dOol002aoo`80009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04FUH60004FUH00`00FUIJEP06
FUH40005FUH00`00FUIJEP02FUH7000hOol002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEQ/003moo`00;7oo0`0015YF00<0
05YFFUH015YF00<005YFFUH00UYF30001EYF200015YF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2
0007Ool50018Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00;7oo00<005YF00000eYF1P001eYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
27oo0`00BGoo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP00
00@000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<00003FUH005YF00AJEP04001JEUYFFUH2001DOol002aoo`@000=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`D0009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEPL0009oo`@000=JEP04001JEUYFFUH2001DOol002aoo`80009J
EP<000=oo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00=oo`<00004FUH007ooOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEPX000=JEP8005Ao
o`00;7oo0P000eYF00<005YF00000P001Goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@00
17oo0`000UYF00<005YF000017oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEP00
0080009JEP03001JEUYF008005Aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0027oo4`001Goo1000
00=JEP00FUH00UYF00<005YF00001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001eYF00<005YFFUH015YF00<005YFFUH00UYF
0P0000=JEP0000000P00E7oo000]Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPP001=oo`D000EJ
EP04001JEUYFFUH20009Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000015YF00000000E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4`00
0eYF00<005YFFUH015YF00D005YFFUIJEP0000eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEQL000EJEP03001JEUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000001Eoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEPD000AJEP03001JEUYF00=J
EP@00003FUH005YF00AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002=ooaH000EJEP03001JEUYF
00IJEPD000AJEP03001JEUYF00EJEP03001JEP00008000AJEP05001JEUYFFUH0001EOol003Ioo`D0
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03001J
EP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP8005Aoo`00>goo200015YF10001UYF00<005YFFUH00UYF1@00<goo
00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8005Aoo`00@goo4`00>7oo00<005YF00000`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000=JEP000000
E7oo0017Ool50012Ool2000015YF001oogoo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00004Ool00000FUH3001DOol004Moo`D0049oo`80
009JEP<0009oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL0009oo`<0
00=JEP<005Aoo`00B7oo0`00@goo0P000UYF00<005YFFUH01@000Woo6`001Goo100000=JEP00FUH0
0eYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YF00000`006Goo1@001EYF00<005YF
FUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF1@00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH7001OOol009aooa/006Ioo`00ZGoo1@00Kgoo002YOol5001_Ool00:Uoo`D006moo`00
ZWoo0`00L7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73372 m .59613 .67814 L .56496 .67624 L p .707 .577 .707 r
F P
0 g
s
.59613 .67814 m .59613 .73372 L .62796 .73294 L p .707 .577 .707 r
F P
0 g
s
.62796 .73294 m .62796 .67736 L .59613 .67814 L p .707 .577 .707 r
F P
0 g
s
.62796 .67736 m .62796 .73294 L .65734 .72956 L p .707 .577 .707 r
F P
0 g
s
.65734 .72956 m .65734 .67398 L .62796 .67736 L p .707 .577 .707 r
F P
0 g
s
.56496 .73182 m .56496 .67624 L .5375 .67184 L p .707 .577 .707 r
F P
0 g
s
.56496 .67624 m .56496 .73182 L .59613 .73372 L p .707 .577 .707 r
F P
0 g
s
.65734 .67398 m .65734 .72956 L .6814 .72391 L p .707 .577 .707 r
F P
0 g
s
.6814 .72391 m .6814 .66833 L .65734 .67398 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .736 L .56496 .7341 L p .707 .577 .707 r
F P
0 g
s
.59613 .736 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .736 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.5375 .67184 m .5375 .72743 L .56496 .73182 L p .707 .577 .707 r
F P
0 g
s
.5375 .72743 m .5375 .67184 L .51644 .66539 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .7341 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .7341 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.59613 .78785 m .59613 .76932 L .56496 .76742 L p .707 .577 .707 r
F P
0 g
s
.59613 .76932 m .59613 .78785 L .62796 .78707 L p .707 .577 .707 r
F P
0 g
s
.62796 .78707 m .62796 .76854 L .59613 .76932 L p .707 .577 .707 r
F P
0 g
s
.62796 .76854 m .62796 .78707 L .65735 .78369 L p .707 .577 .707 r
F P
0 g
s
.65735 .78369 m .65735 .76516 L .62796 .76854 L p .707 .577 .707 r
F P
0 g
s
.56496 .76742 m .56496 .78594 L .59613 .78785 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76325 L p .707 .577 .707 r
F P
0 g
s
.6814 .76325 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.56496 .78594 m .56496 .76742 L .5375 .76302 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.6814 .66833 m .6814 .72391 L .69777 .71654 L p .707 .577 .707 r
F P
0 g
s
.69777 .71654 m .69777 .66096 L .6814 .66833 L p .707 .577 .707 r
F P
0 g
s
.5375 .76302 m .5375 .78155 L .56496 .78594 L p .707 .577 .707 r
F P
0 g
s
.51644 .66539 m .51644 .72097 L .5375 .72743 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.65735 .76516 m .65735 .78369 L .6814 .77804 L p .707 .577 .707 r
F P
0 g
s
.6814 .77804 m .6814 .75951 L .65735 .76516 L p .707 .577 .707 r
F P
0 g
s
.51644 .72097 m .51644 .66539 L .50385 .65751 L p .707 .577 .707 r
F P
0 g
s
.5375 .78155 m .5375 .76302 L .51644 .75657 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76325 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.51644 .75657 m .51644 .7751 L .5375 .78155 L p .707 .577 .707 r
F P
0 g
s
.6814 .75951 m .6814 .77804 L .69777 .77067 L p .707 .577 .707 r
F P
0 g
s
.69777 .77067 m .69777 .75214 L .6814 .75951 L p .707 .577 .707 r
F P
0 g
s
.50385 .65751 m .50385 .71309 L .51644 .72097 L p .707 .577 .707 r
F P
0 g
s
.69777 .66096 m .69777 .71654 L .70485 .70818 L p .707 .577 .707 r
F P
0 g
s
.70485 .70818 m .70485 .6526 L .69777 .66096 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71537 L p .707 .577 .707 r
F P
0 g
s
.51644 .7751 m .51644 .75657 L .50385 .74869 L p .707 .577 .707 r
F P
0 g
s
.50385 .71537 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.50385 .71309 m .50385 .65751 L .50095 .64896 L p .707 .577 .707 r
F P
0 g
s
.50385 .74869 m .50385 .76721 L .51644 .7751 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.49044 .73057 m .49044 .22868 L .44643 .226 L p .707 .577 .707 r
F P
0 g
s
.50095 .64896 m .50095 .70455 L .50385 .71309 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71537 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70455 m .50095 .64896 L .50804 .6406 L p .707 .577 .707 r
F P
0 g
s
.50804 .6406 m .50804 .69618 L .50095 .70455 L p .707 .577 .707 r
F P
0 g
s
.50385 .76721 m .50385 .74869 L .50095 .74014 L p .707 .577 .707 r
F P
0 g
s
.50095 .74014 m .50095 .75867 L .50385 .76721 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .69618 m .50804 .6406 L .5244 .63323 L p .707 .577 .707 r
F P
0 g
s
.5244 .63323 m .5244 .68881 L .50804 .69618 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.50804 .75031 m .50804 .73178 L .5244 .72441 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72815 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .68881 m .5244 .63323 L .54846 .62758 L p .707 .577 .707 r
F P
0 g
s
.5244 .72441 m .5244 .74294 L .50804 .75031 L p .707 .577 .707 r
F P
0 g
s
.54846 .62758 m .54846 .68316 L .5244 .68881 L p .707 .577 .707 r
F P
0 g
s
.5244 .72815 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.5244 .74294 m .5244 .72441 L .54846 .71876 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .7225 L .5244 .72815 L p .707 .577 .707 r
F P
0 g
s
.49044 .22868 m .49044 .73057 L .53538 .72947 L p .707 .577 .707 r
F P
0 g
s
.53538 .72947 m .53538 .22758 L .49044 .22868 L p .707 .577 .707 r
F P
0 g
s
.54846 .68316 m .54846 .62758 L .57784 .6242 L p .707 .577 .707 r
F P
0 g
s
.54846 .71876 m .54846 .73729 L .5244 .74294 L p .707 .577 .707 r
F P
0 g
s
.57784 .6242 m .57784 .67978 L .54846 .68316 L p .707 .577 .707 r
F P
0 g
s
.54846 .7225 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.54846 .73729 m .54846 .71876 L .57784 .71538 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .7225 L p .707 .577 .707 r
F P
0 g
s
.57784 .71538 m .57784 .73391 L .54846 .73729 L p .707 .577 .707 r
F P
0 g
s
.53538 .22758 m .53538 .72947 L .57686 .7247 L p .707 .577 .707 r
F P
0 g
s
.57686 .7247 m .57686 .22281 L .53538 .22758 L p .707 .577 .707 r
F P
0 g
s
.69777 .75214 m .69777 .77067 L .70485 .76231 L p .707 .577 .707 r
F P
0 g
s
.70485 .76231 m .70485 .74378 L .69777 .75214 L p .707 .577 .707 r
F P
0 g
s
.44643 .72789 m .44643 .226 L .40766 .2198 L p .707 .577 .707 r
F P
0 g
s
.44643 .226 m .44643 .72789 L .49044 .73057 L p .707 .577 .707 r
F P
0 g
s
.70485 .6526 m .70485 .70818 L .70195 .69964 L p .707 .577 .707 r
F P
0 g
s
.70195 .69964 m .70195 .64406 L .70485 .6526 L p .707 .577 .707 r
F P
0 g
s
.57784 .67978 m .57784 .6242 L .60968 .62343 L p .707 .577 .707 r
F P
0 g
s
.60968 .62343 m .60968 .67901 L .57784 .67978 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .68129 L .64085 .68319 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .68129 L p .707 .577 .707 r
F P
0 g
s
.60968 .68129 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.60968 .73313 m .60968 .71461 L .64085 .71651 L p .707 .577 .707 r
F P
0 g
s
.57784 .73391 m .57784 .71538 L .60968 .71461 L p .707 .577 .707 r
F P
0 g
s
.60968 .71461 m .60968 .73313 L .57784 .73391 L p .707 .577 .707 r
F P
0 g
s
.57686 .22281 m .57686 .7247 L .61082 .71673 L p .707 .577 .707 r
F P
0 g
s
.64085 .62533 m .64085 .68091 L .60968 .67901 L p .707 .577 .707 r
F P
0 g
s
.60968 .67901 m .60968 .62343 L .64085 .62533 L p .707 .577 .707 r
F P
0 g
s
.61082 .71673 m .61082 .21484 L .57686 .22281 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70192 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.40766 .72169 m .40766 .2198 L .37794 .21069 L p .707 .577 .707 r
F P
0 g
s
.40766 .2198 m .40766 .72169 L .44643 .72789 L p .707 .577 .707 r
F P
0 g
s
.70485 .74378 m .70485 .76231 L .70195 .75377 L p .707 .577 .707 r
F P
0 g
s
.70195 .75377 m .70195 .73524 L .70485 .74378 L p .707 .577 .707 r
F P
0 g
s
.70195 .64406 m .70195 .69964 L .68936 .69175 L p .707 .577 .707 r
F P
0 g
s
.68936 .69175 m .68936 .63617 L .70195 .64406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .75867 m .50095 .74014 L .50804 .73178 L p .707 .577 .707 r
F P
0 g
s
.64085 .68319 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.61082 .21484 m .61082 .71673 L .63393 .70632 L p .707 .577 .707 r
F P
0 g
s
.63393 .70632 m .63393 .20444 L .61082 .21484 L p .707 .577 .707 r
F P
0 g
s
.25312 .6969 m .25312 .64132 L .22195 .63942 L p .707 .577 .707 r
F P
0 g
s
.25312 .64132 m .25312 .6969 L .28495 .69613 L p .707 .577 .707 r
F P
0 g
s
.28495 .69613 m .28495 .64054 L .25312 .64132 L p .707 .577 .707 r
F P
0 g
s
.28495 .64054 m .28495 .69613 L .31434 .69275 L p .707 .577 .707 r
F P
0 g
s
.31434 .69275 m .31434 .63716 L .28495 .64054 L p .707 .577 .707 r
F P
0 g
s
.50804 .73178 m .50804 .75031 L .50095 .75867 L p .707 .577 .707 r
F P
0 g
s
.70195 .70192 m .70195 .73898 L .68936 .73109 L p .707 .577 .707 r
F P
0 g
s
.68936 .73109 m .68936 .69404 L .70195 .70192 L p .707 .577 .707 r
F P
0 g
s
.22195 .695 m .22195 .63942 L .19449 .63503 L p .707 .577 .707 r
F P
0 g
s
.22195 .63942 m .22195 .695 L .25312 .6969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.37794 .71257 m .37794 .21069 L .36016 .19956 L p .707 .577 .707 r
F P
0 g
s
.37794 .21069 m .37794 .71257 L .40766 .72169 L p .707 .577 .707 r
F P
0 g
s
.31434 .63716 m .31434 .69275 L .33839 .6871 L p .707 .577 .707 r
F P
0 g
s
.33839 .6871 m .33839 .63152 L .31434 .63716 L p .707 .577 .707 r
F P
0 g
s
.70195 .73524 m .70195 .75377 L .68936 .74588 L p .707 .577 .707 r
F P
0 g
s
.68936 .74588 m .68936 .72735 L .70195 .73524 L p .707 .577 .707 r
F P
0 g
s
.25312 .73624 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73624 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.68936 .63617 m .68936 .69175 L .66831 .6853 L p .707 .577 .707 r
F P
0 g
s
.66831 .6853 m .66831 .62972 L .68936 .63617 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69503 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.19449 .63503 m .19449 .69061 L .22195 .695 L p .707 .577 .707 r
F P
0 g
s
.19449 .69061 m .19449 .63503 L .17343 .62857 L p .707 .577 .707 r
F P
0 g
s
.22195 .73434 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73434 L .25312 .73624 L p .707 .577 .707 r
F P
0 g
s
.25312 .75103 m .25312 .7325 L .22195 .7306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7325 m .25312 .75103 L .28495 .75025 L p .707 .577 .707 r
F P
0 g
s
.28495 .75025 m .28495 .73173 L .25312 .7325 L p .707 .577 .707 r
F P
0 g
s
.28495 .73173 m .28495 .75025 L .31434 .74687 L p .707 .577 .707 r
F P
0 g
s
.31434 .74687 m .31434 .72835 L .28495 .73173 L p .707 .577 .707 r
F P
0 g
s
.22195 .7306 m .22195 .74913 L .25312 .75103 L p .707 .577 .707 r
F P
0 g
s
.31434 .69503 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68938 L .31434 .69503 L p .707 .577 .707 r
F P
0 g
s
.22195 .74913 m .22195 .7306 L .19449 .72621 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73434 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .73109 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.33839 .63152 m .33839 .6871 L .35476 .67973 L p .707 .577 .707 r
F P
0 g
s
.35476 .67973 m .35476 .62415 L .33839 .63152 L p .707 .577 .707 r
F P
0 g
s
.66831 .62972 m .66831 .6853 L .64085 .68091 L p .707 .577 .707 r
F P
0 g
s
.64085 .68091 m .64085 .62533 L .66831 .62972 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .68319 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.63393 .20444 m .63393 .70632 L .64393 .69452 L p .707 .577 .707 r
F P
0 g
s
.64393 .69452 m .64393 .19263 L .63393 .20444 L p .707 .577 .707 r
F P
0 g
s
.19449 .72621 m .19449 .74474 L .22195 .74913 L p .707 .577 .707 r
F P
0 g
s
.17343 .62857 m .17343 .68416 L .19449 .69061 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.31434 .72835 m .31434 .74687 L .33839 .74122 L p .707 .577 .707 r
F P
0 g
s
.33839 .74122 m .33839 .7227 L .31434 .72835 L p .707 .577 .707 r
F P
0 g
s
.68936 .72735 m .68936 .74588 L .66831 .73943 L p .707 .577 .707 r
F P
0 g
s
.66831 .73943 m .66831 .7209 L .68936 .72735 L p .707 .577 .707 r
F P
0 g
s
.17343 .68416 m .17343 .62857 L .16084 .62069 L p .707 .577 .707 r
F P
0 g
s
.19449 .74474 m .19449 .72621 L .17343 .71976 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68938 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68938 L p .707 .577 .707 r
F P
0 g
s
.35476 .62415 m .35476 .67973 L .36184 .67137 L p .707 .577 .707 r
F P
0 g
s
.36184 .67137 m .36184 .61578 L .35476 .62415 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .61578 m .36184 .67137 L .35894 .66282 L p .707 .577 .707 r
F P
0 g
s
.35894 .66282 m .35894 .60724 L .36184 .61578 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .72549 m .36184 .70696 L .35476 .71533 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70216 L p .707 .577 .707 r
F P
0 g
s
.35894 .70216 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .70144 m .36016 .19956 L .35607 .1875 L p .707 .577 .707 r
F P
0 g
s
.36016 .19956 m .36016 .70144 L .37794 .71257 L p .707 .577 .707 r
F P
0 g
s
.17343 .71976 m .17343 .73828 L .19449 .74474 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.33839 .7227 m .33839 .74122 L .35476 .73386 L p .707 .577 .707 r
F P
0 g
s
.35476 .73386 m .35476 .71533 L .33839 .7227 L p .707 .577 .707 r
F P
0 g
s
.16084 .62069 m .16084 .67627 L .17343 .68416 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.66831 .7209 m .66831 .73943 L .64085 .73503 L p .707 .577 .707 r
F P
0 g
s
.64085 .73503 m .64085 .71651 L .66831 .7209 L p .707 .577 .707 r
F P
0 g
s
.17343 .73828 m .17343 .71976 L .16084 .71187 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.16084 .67627 m .16084 .62069 L .15794 .61215 L p .707 .577 .707 r
F P
0 g
s
.16084 .71187 m .16084 .7304 L .17343 .73828 L p .707 .577 .707 r
F P
0 g
s
.64393 .19263 m .64393 .69452 L .63984 .68246 L p .707 .577 .707 r
F P
0 g
s
.63984 .68246 m .63984 .18057 L .64393 .19263 L p .707 .577 .707 r
F P
0 g
s
.64085 .71651 m .64085 .73503 L .60968 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .71533 m .35476 .73386 L .36184 .72549 L p .707 .577 .707 r
F P
0 g
s
.15794 .61215 m .15794 .66773 L .16084 .67627 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.35894 .60724 m .35894 .66282 L .34635 .65494 L p .707 .577 .707 r
F P
0 g
s
.34635 .65494 m .34635 .59936 L .35894 .60724 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70216 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65722 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .1875 m .35607 .68938 L .36016 .70144 L p .707 .577 .707 r
F P
0 g
s
.35607 .68938 m .35607 .1875 L .36607 .17569 L p .707 .577 .707 r
F P
0 g
s
.16084 .7304 m .16084 .71187 L .15794 .70333 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.15794 .70333 m .15794 .72186 L .16084 .7304 L p .707 .577 .707 r
F P
0 g
s
.15794 .66773 m .15794 .61215 L .16503 .60378 L p .707 .577 .707 r
F P
0 g
s
.36184 .70696 m .36184 .72549 L .35894 .71695 L p .707 .577 .707 r
F P
0 g
s
.35894 .71695 m .35894 .69842 L .36184 .70696 L p .707 .577 .707 r
F P
0 g
s
.16503 .60378 m .16503 .65937 L .15794 .66773 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.63984 .18057 m .63984 .68246 L .62206 .67133 L p .707 .577 .707 r
F P
0 g
s
.62206 .67133 m .62206 .16944 L .63984 .18057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .72186 m .15794 .70333 L .16503 .69497 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.16503 .65937 m .16503 .60378 L .1814 .59642 L p .707 .577 .707 r
F P
0 g
s
.16503 .69497 m .16503 .71349 L .15794 .72186 L p .707 .577 .707 r
F P
0 g
s
.36607 .67758 m .36607 .17569 L .38918 .16529 L p .707 .577 .707 r
F P
0 g
s
.36607 .17569 m .36607 .67758 L .35607 .68938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .69842 m .35894 .71695 L .34635 .70907 L p .707 .577 .707 r
F P
0 g
s
.34635 .70907 m .34635 .69054 L .35894 .69842 L p .707 .577 .707 r
F P
0 g
s
.1814 .59642 m .1814 .652 L .16503 .65937 L p .707 .577 .707 r
F P
0 g
s
.34635 .59936 m .34635 .65494 L .3253 .64848 L p .707 .577 .707 r
F P
0 g
s
.3253 .64848 m .3253 .5929 L .34635 .59936 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65428 L p .707 .577 .707 r
F P
0 g
s
.16503 .71349 m .16503 .69497 L .1814 .6876 L p .707 .577 .707 r
F P
0 g
s
.62206 .16944 m .62206 .67133 L .59233 .66221 L p .707 .577 .707 r
F P
0 g
s
.59233 .66221 m .59233 .16033 L .62206 .16944 L p .707 .577 .707 r
F P
0 g
s
.1814 .65428 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.1814 .652 m .1814 .59642 L .20545 .59077 L p .707 .577 .707 r
F P
0 g
s
.1814 .6876 m .1814 .70612 L .16503 .71349 L p .707 .577 .707 r
F P
0 g
s
.34635 .65722 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65722 L p .707 .577 .707 r
F P
0 g
s
.3253 .5929 m .3253 .64848 L .29784 .64409 L p .707 .577 .707 r
F P
0 g
s
.29784 .64409 m .29784 .58851 L .3253 .5929 L p .707 .577 .707 r
F P
0 g
s
.38918 .16529 m .38918 .66717 L .36607 .67758 L p .707 .577 .707 r
F P
0 g
s
.38918 .66717 m .38918 .16529 L .42314 .15731 L p .707 .577 .707 r
F P
0 g
s
.34635 .69054 m .34635 .70907 L .3253 .70261 L p .707 .577 .707 r
F P
0 g
s
.3253 .70261 m .3253 .68408 L .34635 .69054 L p .707 .577 .707 r
F P
0 g
s
.20545 .59077 m .20545 .64635 L .1814 .652 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65428 L .20545 .64863 L p .707 .577 .707 r
F P
0 g
s
.20545 .64635 m .20545 .59077 L .23483 .58739 L p .707 .577 .707 r
F P
0 g
s
.1814 .70612 m .1814 .6876 L .20545 .68195 L p .707 .577 .707 r
F P
0 g
s
.20545 .64863 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.29784 .58851 m .29784 .64409 L .26667 .64219 L p .707 .577 .707 r
F P
0 g
s
.26667 .64219 m .26667 .58661 L .29784 .58851 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68343 L p .707 .577 .707 r
F P
0 g
s
.29784 .68343 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68195 m .20545 .70048 L .1814 .70612 L p .707 .577 .707 r
F P
0 g
s
.23483 .64297 m .23483 .58739 L .26667 .58661 L p .707 .577 .707 r
F P
0 g
s
.23483 .58739 m .23483 .64297 L .20545 .64635 L p .707 .577 .707 r
F P
0 g
s
.59233 .16033 m .59233 .66221 L .55357 .65601 L p .707 .577 .707 r
F P
0 g
s
.55357 .65601 m .55357 .15412 L .59233 .16033 L p .707 .577 .707 r
F P
0 g
s
.26667 .58661 m .26667 .64219 L .23483 .64297 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64863 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.73333 .64168 m .73333 .5861 L .70216 .5842 L p .707 .577 .707 r
F P
0 g
s
.73333 .5861 m .73333 .64168 L .76517 .6409 L p .707 .577 .707 r
F P
0 g
s
.76517 .6409 m .76517 .58532 L .73333 .5861 L p .707 .577 .707 r
F P
0 g
s
.3253 .68408 m .3253 .70261 L .29784 .69822 L p .707 .577 .707 r
F P
0 g
s
.29784 .69822 m .29784 .67969 L .3253 .68408 L p .707 .577 .707 r
F P
0 g
s
.76517 .58532 m .76517 .6409 L .79455 .63752 L p .707 .577 .707 r
F P
0 g
s
.79455 .63752 m .79455 .58194 L .76517 .58532 L p .707 .577 .707 r
F P
0 g
s
.42314 .6592 m .42314 .15731 L .46462 .15254 L p .707 .577 .707 r
F P
0 g
s
.42314 .15731 m .42314 .6592 L .38918 .66717 L p .707 .577 .707 r
F P
0 g
s
.70216 .63978 m .70216 .5842 L .6747 .5798 L p .707 .577 .707 r
F P
0 g
s
.70216 .5842 m .70216 .63978 L .73333 .64168 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68343 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.20545 .70048 m .20545 .68195 L .23483 .67857 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.23483 .67857 m .23483 .6971 L .20545 .70048 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.79455 .58194 m .79455 .63752 L .8186 .63187 L p .707 .577 .707 r
F P
0 g
s
.8186 .63187 m .8186 .57629 L .79455 .58194 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68024 L p .707 .577 .707 r
F P
0 g
s
.76517 .68024 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.29784 .67969 m .29784 .69822 L .26667 .69632 L p .707 .577 .707 r
F P
0 g
s
.26667 .69632 m .26667 .67779 L .29784 .67969 L p .707 .577 .707 r
F P
0 g
s
.55357 .15412 m .55357 .65601 L .50956 .65333 L p .707 .577 .707 r
F P
0 g
s
.50956 .65333 m .50956 .15144 L .55357 .15412 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68024 L .79455 .67686 L p .707 .577 .707 r
F P
0 g
s
.79455 .67686 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.23483 .6971 m .23483 .67857 L .26667 .67779 L p .707 .577 .707 r
F P
0 g
s
.6747 .5798 m .6747 .63539 L .70216 .63978 L p .707 .577 .707 r
F P
0 g
s
.6747 .63539 m .6747 .5798 L .65365 .57335 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63767 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.46462 .65443 m .46462 .15254 L .50956 .15144 L p .707 .577 .707 r
F P
0 g
s
.46462 .15254 m .46462 .65443 L .42314 .6592 L p .707 .577 .707 r
F P
0 g
s
.26667 .67779 m .26667 .69632 L .23483 .6971 L p .707 .577 .707 r
F P
0 g
s
.73333 .69581 m .73333 .67728 L .70216 .67538 L p .707 .577 .707 r
F P
0 g
s
.73333 .67728 m .73333 .69581 L .76517 .69503 L p .707 .577 .707 r
F P
0 g
s
.76517 .69503 m .76517 .6765 L .73333 .67728 L p .707 .577 .707 r
F P
0 g
s
.50956 .15144 m .50956 .65333 L .46462 .65443 L p .707 .577 .707 r
F P
0 g
s
.76517 .6765 m .76517 .69503 L .79455 .69165 L p .707 .577 .707 r
F P
0 g
s
.79455 .69165 m .79455 .67312 L .76517 .6765 L p .707 .577 .707 r
F P
0 g
s
.70216 .67538 m .70216 .69391 L .73333 .69581 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67686 L .8186 .67121 L p .707 .577 .707 r
F P
0 g
s
.8186 .67121 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.70216 .69391 m .70216 .67538 L .6747 .67099 L p .707 .577 .707 r
F P
0 g
s
.6747 .63767 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.8186 .57629 m .8186 .63187 L .83497 .62451 L p .707 .577 .707 r
F P
0 g
s
.83497 .62451 m .83497 .56892 L .8186 .57629 L p .707 .577 .707 r
F P
0 g
s
.6747 .67099 m .6747 .68951 L .70216 .69391 L p .707 .577 .707 r
F P
0 g
s
.65365 .57335 m .65365 .62893 L .6747 .63539 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63767 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.79455 .67312 m .79455 .69165 L .8186 .686 L p .707 .577 .707 r
F P
0 g
s
.8186 .686 m .8186 .66747 L .79455 .67312 L p .707 .577 .707 r
F P
0 g
s
.65365 .62893 m .65365 .57335 L .64105 .56547 L p .707 .577 .707 r
F P
0 g
s
.6747 .68951 m .6747 .67099 L .65365 .66453 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66827 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67121 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.65365 .66453 m .65365 .68306 L .6747 .68951 L p .707 .577 .707 r
F P
0 g
s
.8186 .66747 m .8186 .686 L .83497 .67863 L p .707 .577 .707 r
F P
0 g
s
.83497 .67863 m .83497 .66011 L .8186 .66747 L p .707 .577 .707 r
F P
0 g
s
.64105 .56547 m .64105 .62105 L .65365 .62893 L p .707 .577 .707 r
F P
0 g
s
.83497 .56892 m .83497 .62451 L .84205 .61614 L p .707 .577 .707 r
F P
0 g
s
.84205 .61614 m .84205 .56056 L .83497 .56892 L p .707 .577 .707 r
F P
0 g
s
.65365 .66827 m .65365 .63122 L .64105 .62333 L p .707 .577 .707 r
F P
0 g
s
.65365 .68306 m .65365 .66453 L .64105 .65665 L p .707 .577 .707 r
F P
0 g
s
.64105 .62333 m .64105 .66039 L .65365 .66827 L p .707 .577 .707 r
F P
0 g
s
.64105 .62105 m .64105 .56547 L .63816 .55692 L p .707 .577 .707 r
F P
0 g
s
.64105 .65665 m .64105 .67518 L .65365 .68306 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.83497 .66011 m .83497 .67863 L .84206 .67027 L p .707 .577 .707 r
F P
0 g
s
.84206 .67027 m .84205 .65174 L .83497 .66011 L p .707 .577 .707 r
F P
0 g
s
.63816 .55692 m .63816 .61251 L .64105 .62105 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62333 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.84205 .56056 m .84205 .61614 L .83916 .6076 L p .707 .577 .707 r
F P
0 g
s
.83916 .6076 m .83916 .55202 L .84205 .56056 L p .707 .577 .707 r
F P
0 g
s
.64105 .67518 m .64105 .65665 L .63816 .64811 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.63816 .64811 m .63816 .66663 L .64105 .67518 L p .707 .577 .707 r
F P
0 g
s
.63816 .61251 m .63816 .55692 L .64524 .54856 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.84205 .65174 m .84206 .67027 L .83916 .66173 L p .707 .577 .707 r
F P
0 g
s
.83916 .66173 m .83916 .6432 L .84205 .65174 L p .707 .577 .707 r
F P
0 g
s
.64524 .54856 m .64524 .60414 L .63816 .61251 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.83916 .55202 m .83916 .6076 L .82657 .59972 L p .707 .577 .707 r
F P
0 g
s
.82657 .59972 m .82657 .54413 L .83916 .55202 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .66663 m .63816 .64811 L .64524 .63974 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64348 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.39032 .60486 m .39032 .54928 L .35915 .54738 L p .707 .577 .707 r
F P
0 g
s
.39032 .54928 m .39032 .60486 L .42216 .60409 L p .707 .577 .707 r
F P
0 g
s
.42216 .60409 m .42216 .5485 L .39032 .54928 L p .707 .577 .707 r
F P
0 g
s
.64524 .60414 m .64524 .54856 L .66161 .54119 L p .707 .577 .707 r
F P
0 g
s
.42216 .5485 m .42216 .60409 L .45154 .60071 L p .707 .577 .707 r
F P
0 g
s
.45154 .60071 m .45154 .54513 L .42216 .5485 L p .707 .577 .707 r
F P
0 g
s
.64524 .63974 m .64524 .65827 L .63816 .66663 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.35915 .60296 m .35915 .54738 L .33169 .54299 L p .707 .577 .707 r
F P
0 g
s
.35915 .54738 m .35915 .60296 L .39032 .60486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54513 m .45154 .60071 L .47559 .59506 L p .707 .577 .707 r
F P
0 g
s
.47559 .59506 m .47559 .53948 L .45154 .54513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6432 m .83916 .66173 L .82657 .65384 L p .707 .577 .707 r
F P
0 g
s
.82657 .65384 m .82657 .63532 L .83916 .6432 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60637 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.66161 .54119 m .66161 .59677 L .64524 .60414 L p .707 .577 .707 r
F P
0 g
s
.82657 .54413 m .82657 .59972 L .80551 .59326 L p .707 .577 .707 r
F P
0 g
s
.80551 .59326 m .80551 .53768 L .82657 .54413 L p .707 .577 .707 r
F P
0 g
s
.64524 .64348 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60637 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .60299 L .42216 .60637 L p .707 .577 .707 r
F P
0 g
s
.33169 .54299 m .33169 .59857 L .35915 .60296 L p .707 .577 .707 r
F P
0 g
s
.33169 .59857 m .33169 .54299 L .31064 .53654 L p .707 .577 .707 r
F P
0 g
s
.35915 .6423 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .6423 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.39032 .65899 m .39032 .64046 L .35915 .63856 L p .707 .577 .707 r
F P
0 g
s
.39032 .64046 m .39032 .65899 L .42216 .65821 L p .707 .577 .707 r
F P
0 g
s
.42216 .65821 m .42216 .63969 L .39032 .64046 L p .707 .577 .707 r
F P
0 g
s
.64524 .65827 m .64524 .63974 L .66161 .63237 L p .707 .577 .707 r
F P
0 g
s
.42216 .63969 m .42216 .65821 L .45154 .65484 L p .707 .577 .707 r
F P
0 g
s
.45154 .65484 m .45154 .63631 L .42216 .63969 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59677 m .66161 .54119 L .68566 .53554 L p .707 .577 .707 r
F P
0 g
s
.35915 .63856 m .35915 .65709 L .39032 .65899 L p .707 .577 .707 r
F P
0 g
s
.45154 .60299 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59734 L .45154 .60299 L p .707 .577 .707 r
F P
0 g
s
.35915 .65709 m .35915 .63856 L .33169 .63417 L p .707 .577 .707 r
F P
0 g
s
.66161 .63237 m .66161 .6509 L .64524 .65827 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .6423 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.47559 .53948 m .47559 .59506 L .49196 .58769 L p .707 .577 .707 r
F P
0 g
s
.49196 .58769 m .49196 .53211 L .47559 .53948 L p .707 .577 .707 r
F P
0 g
s
.33169 .63417 m .33169 .6527 L .35915 .65709 L p .707 .577 .707 r
F P
0 g
s
.31064 .53654 m .31064 .59212 L .33169 .59857 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .5944 L p .707 .577 .707 r
F P
0 g
s
.45154 .63631 m .45154 .65484 L .47559 .64919 L p .707 .577 .707 r
F P
0 g
s
.47559 .64919 m .47559 .63066 L .45154 .63631 L p .707 .577 .707 r
F P
0 g
s
.80551 .53768 m .80551 .59326 L .77805 .58887 L p .707 .577 .707 r
F P
0 g
s
.77805 .58887 m .77805 .53329 L .80551 .53768 L p .707 .577 .707 r
F P
0 g
s
.82657 .63532 m .82657 .65384 L .80551 .64739 L p .707 .577 .707 r
F P
0 g
s
.80551 .64739 m .80551 .62886 L .82657 .63532 L p .707 .577 .707 r
F P
0 g
s
.68566 .53554 m .68566 .59112 L .66161 .59677 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.31064 .59212 m .31064 .53654 L .29804 .52865 L p .707 .577 .707 r
F P
0 g
s
.33169 .6527 m .33169 .63417 L .31064 .62772 L p .707 .577 .707 r
F P
0 g
s
.31064 .5944 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.68566 .59112 m .68566 .53554 L .71504 .53216 L p .707 .577 .707 r
F P
0 g
s
.47559 .59734 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59734 L p .707 .577 .707 r
F P
0 g
s
.31064 .62772 m .31064 .64624 L .33169 .6527 L p .707 .577 .707 r
F P
0 g
s
.66161 .6509 m .66161 .63237 L .68566 .62672 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.77805 .53329 m .77805 .58887 L .74688 .58697 L p .707 .577 .707 r
F P
0 g
s
.74688 .58697 m .74688 .53139 L .77805 .53329 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.68566 .62672 m .68566 .64525 L .66161 .6509 L p .707 .577 .707 r
F P
0 g
s
.47559 .63066 m .47559 .64919 L .49196 .64182 L p .707 .577 .707 r
F P
0 g
s
.49196 .64182 m .49196 .62329 L .47559 .63066 L p .707 .577 .707 r
F P
0 g
s
.29804 .52865 m .29804 .58423 L .31064 .59212 L p .707 .577 .707 r
F P
0 g
s
.71504 .58775 m .71504 .53216 L .74688 .53139 L p .707 .577 .707 r
F P
0 g
s
.71504 .53216 m .71504 .58775 L .68566 .59112 L p .707 .577 .707 r
F P
0 g
s
.49196 .53211 m .49196 .58769 L .49904 .57933 L p .707 .577 .707 r
F P
0 g
s
.49904 .57933 m .49904 .52374 L .49196 .53211 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .5944 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.74688 .53139 m .74688 .58697 L .71504 .58775 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.80551 .62886 m .80551 .64739 L .77805 .643 L p .707 .577 .707 r
F P
0 g
s
.77805 .643 m .77805 .62447 L .80551 .62886 L p .707 .577 .707 r
F P
0 g
s
.31064 .64624 m .31064 .62772 L .29804 .61983 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62357 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58925 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.29804 .58423 m .29804 .52865 L .29515 .52011 L p .707 .577 .707 r
F P
0 g
s
.68566 .64525 m .68566 .62672 L .71504 .62335 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.29804 .61983 m .29804 .63836 L .31064 .64624 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58925 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.71504 .62335 m .71504 .64187 L .68566 .64525 L p .707 .577 .707 r
F P
0 g
s
.74688 .58925 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.77805 .62447 m .77805 .643 L .74688 .6411 L p .707 .577 .707 r
F P
0 g
s
.74688 .6411 m .74688 .62257 L .77805 .62447 L p .707 .577 .707 r
F P
0 g
s
.71504 .64187 m .71504 .62335 L .74688 .62257 L p .707 .577 .707 r
F P
0 g
s
.49196 .62329 m .49196 .64182 L .49904 .63345 L p .707 .577 .707 r
F P
0 g
s
.49904 .63345 m .49904 .61493 L .49196 .62329 L p .707 .577 .707 r
F P
0 g
s
.29515 .52011 m .29515 .57569 L .29804 .58423 L p .707 .577 .707 r
F P
0 g
s
.74688 .62257 m .74688 .6411 L .71504 .64187 L p .707 .577 .707 r
F P
0 g
s
.29804 .62357 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.49904 .52374 m .49904 .57933 L .49615 .57078 L p .707 .577 .707 r
F P
0 g
s
.49615 .57078 m .49615 .5152 L .49904 .52374 L p .707 .577 .707 r
F P
0 g
s
.29804 .63836 m .29804 .61983 L .29515 .61129 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62357 L p .707 .577 .707 r
F P
0 g
s
.29515 .61129 m .29515 .62982 L .29804 .63836 L p .707 .577 .707 r
F P
0 g
s
.29515 .57569 m .29515 .52011 L .30223 .51174 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61012 L p .707 .577 .707 r
F P
0 g
s
.49615 .61012 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.49904 .61493 m .49904 .63345 L .49615 .62491 L p .707 .577 .707 r
F P
0 g
s
.49615 .62491 m .49615 .60638 L .49904 .61493 L p .707 .577 .707 r
F P
0 g
s
.30223 .51174 m .30223 .56733 L .29515 .57569 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.49615 .5152 m .49615 .57078 L .48356 .5629 L p .707 .577 .707 r
F P
0 g
s
.48356 .5629 m .48356 .50732 L .49615 .5152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .62982 m .29515 .61129 L .30223 .60293 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.30223 .56733 m .30223 .51174 L .3186 .50438 L p .707 .577 .707 r
F P
0 g
s
.30223 .60293 m .30223 .62145 L .29515 .62982 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61012 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .60638 m .49615 .62491 L .48356 .61703 L p .707 .577 .707 r
F P
0 g
s
.48356 .61703 m .48356 .5985 L .49615 .60638 L p .707 .577 .707 r
F P
0 g
s
.3186 .50438 m .3186 .55996 L .30223 .56733 L p .707 .577 .707 r
F P
0 g
s
.48356 .50732 m .48356 .5629 L .4625 .55645 L p .707 .577 .707 r
F P
0 g
s
.4625 .55645 m .4625 .50086 L .48356 .50732 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56224 L p .707 .577 .707 r
F P
0 g
s
.30223 .62145 m .30223 .60293 L .3186 .59556 L p .707 .577 .707 r
F P
0 g
s
.3186 .56224 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55996 m .3186 .50438 L .34265 .49873 L p .707 .577 .707 r
F P
0 g
s
.3186 .59556 m .3186 .61409 L .30223 .62145 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.4625 .50086 m .4625 .55645 L .43504 .55205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55205 m .43504 .49647 L .4625 .50086 L p .707 .577 .707 r
F P
0 g
s
.48356 .5985 m .48356 .61703 L .4625 .61057 L p .707 .577 .707 r
F P
0 g
s
.4625 .61057 m .4625 .59205 L .48356 .5985 L p .707 .577 .707 r
F P
0 g
s
.34265 .49873 m .34265 .55431 L .3186 .55996 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56224 L .34265 .55659 L p .707 .577 .707 r
F P
0 g
s
.34265 .55431 m .34265 .49873 L .37203 .49535 L p .707 .577 .707 r
F P
0 g
s
.3186 .61409 m .3186 .59556 L .34265 .58991 L p .707 .577 .707 r
F P
0 g
s
.34265 .55659 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.43504 .49647 m .43504 .55205 L .40387 .55015 L p .707 .577 .707 r
F P
0 g
s
.40387 .55015 m .40387 .49457 L .43504 .49647 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .59139 L p .707 .577 .707 r
F P
0 g
s
.43504 .59139 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .58991 m .34265 .60844 L .3186 .61409 L p .707 .577 .707 r
F P
0 g
s
.37203 .55093 m .37203 .49535 L .40387 .49457 L p .707 .577 .707 r
F P
0 g
s
.37203 .49535 m .37203 .55093 L .34265 .55431 L p .707 .577 .707 r
F P
0 g
s
.40387 .49457 m .40387 .55015 L .37203 .55093 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .55659 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.4625 .59205 m .4625 .61057 L .43504 .60618 L p .707 .577 .707 r
F P
0 g
s
.43504 .60618 m .43504 .58765 L .4625 .59205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .59139 L .40387 .58949 L p .707 .577 .707 r
F P
0 g
s
.40387 .58949 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.34265 .60844 m .34265 .58991 L .37203 .58653 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.37203 .58653 m .37203 .60506 L .34265 .60844 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .58949 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.43504 .58765 m .43504 .60618 L .40387 .60428 L p .707 .577 .707 r
F P
0 g
s
.40387 .60428 m .40387 .58575 L .43504 .58765 L p .707 .577 .707 r
F P
0 g
s
.37203 .60506 m .37203 .58653 L .40387 .58575 L p .707 .577 .707 r
F P
0 g
s
.40387 .58575 m .40387 .60428 L .37203 .60506 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP03
FUHO0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
Dgoo00<005YF000015YF00<005YF00002@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@000goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003moo`P000AJEP03001JEUYF009JEP@0
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000gOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=0004FUH01000FUIJEUYF0P00;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000020002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP00003
FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP000000;Goo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1P00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1P001eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJ
EP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEQH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP800004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP80009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04
001JEUYFFUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH70003FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEPD0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP80
0003FUH0000000AJEP@000AJEPD00003FUH0000000L000=JEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
05YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH300000eYF001JEP04FUH01000FUIJEUYF1@000eYF2P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JER4000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70004FUH90004FUH00`00FUIJEP03FUH400000eYF
001JEP04FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000600000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00003FUH700000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH<
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH2000]Ool002aoo`04001JEP00FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0;0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH?000;
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009J
EP8002eoo`00;7oo00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YF0000500035YF00<0
05YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP@002eoo`00;7oo10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00@000IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]
Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF0P000UYF00<005YF00000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH0
0eYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YF000000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP05001JEUYFFUH00003FUH20002FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH5
0004FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEPh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP03FUH0
0`00FUIJEP030002FUHG0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000AJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00@005YFFUIJEP<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP800004FUH000000005FUH00`00FUIJEP03FUH30008FUH40005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEPH0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP06
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol002aoo`03001JEP0000AJEP03001JEP000080009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
0004FUH005YFFUH20004FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00;7oo00<0
05YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEPH000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;7oo00@005YF001JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEPD000AJEP04001JEUYFFUH300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<0
05YFFUH00UYF7000?goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
00001UYF00<005YFFUH00eYF1P00E7oo000/Ool30004FUH01000FUIJEUYF2@001eYF00<005YFFUH0
1eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000IJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00;7oo0`000eYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP03001oogoo00<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo00=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF0`001eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`<004Uo
o`00;7oo0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH007oo00Moo`<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<00003FUH00000
00H00003FUH005YF00@00003FUH005YF00AJEP04001JEUYFFUH20007Ool50018Ool002aoo`80009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0000]oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04001JEUYFFUH20007
Ool50018Ool002aoo`8000=JEP03001JEP0000800003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP03001JEP00019oo``000IJEP03001J
EUYF00YJEP03001JEUYF00=JEPL000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
00=JEP8000Moo`D004Qoo`00;Goo00D005YFFUIJEP0000AJEP800003FUH0000000AJEP@000AJEPD0
00EJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2000OOolI0006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH20008Ool30019Ool002ioo`800003
FUH005YF00AJEP04001JEUYFFUH50003FUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:Goo
00@005YF001JEP800003FUH005YF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF1000
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`@000=JEP03001JEUYF009JEPL0
00AJEQD000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002aoo`03001JEP00
00AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJ
EP04001JEUYFFUH2001DOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<002moo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Aoo`00>Goo
10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000=JEP8005Aoo`00?Goo6@00>7oo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000E7oo002>Ool300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00E7oo002>Ool200000eYF0000
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0003FUH3001DOol008ioo`80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEP0000<00003FUH005YF00=JEP03001JEP0005Aoo`00Sgoo00D005YFFUH0
05YF00<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF009JEPD000EJEP03001J
EUYF009JEP8005Eoo`00Sgoo00@005YFFUH000AJEP80009JEP03001JEUYF009JEQL000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8005Eoo`00B7oo0`00AGoo0`001EYF00@005YFFUIJEPD000QJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol004Moo`D004Ioo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001HOol004Moo`D004Qoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol004Moo`D004]oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00B7oo0`00DGoo2@0015YF00<005YFFUH00UYF
2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002Z
Ool3001`Ool00:Uoo`D006moo`00ZGoo1@00Kgoo002YOol5001_Ool00:Yoo`<0071oo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73372 m .59613 .67814 L .56496 .67624 L p .707 .577 .707 r
F P
0 g
s
.59613 .67814 m .59613 .73372 L .62796 .73294 L p .707 .577 .707 r
F P
0 g
s
.62796 .73294 m .62796 .67736 L .59613 .67814 L p .707 .577 .707 r
F P
0 g
s
.62796 .67736 m .62796 .73294 L .65734 .72956 L p .707 .577 .707 r
F P
0 g
s
.65734 .72956 m .65734 .67398 L .62796 .67736 L p .707 .577 .707 r
F P
0 g
s
.56496 .73182 m .56496 .67624 L .5375 .67184 L p .707 .577 .707 r
F P
0 g
s
.56496 .67624 m .56496 .73182 L .59613 .73372 L p .707 .577 .707 r
F P
0 g
s
.65734 .67398 m .65734 .72956 L .6814 .72391 L p .707 .577 .707 r
F P
0 g
s
.6814 .72391 m .6814 .66833 L .65734 .67398 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .736 L .56496 .7341 L p .707 .577 .707 r
F P
0 g
s
.59613 .736 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .736 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.5375 .67184 m .5375 .72743 L .56496 .73182 L p .707 .577 .707 r
F P
0 g
s
.5375 .72743 m .5375 .67184 L .51644 .66539 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .7341 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .7341 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.59613 .78785 m .59613 .76932 L .56496 .76742 L p .707 .577 .707 r
F P
0 g
s
.59613 .76932 m .59613 .78785 L .62796 .78707 L p .707 .577 .707 r
F P
0 g
s
.62796 .78707 m .62796 .76854 L .59613 .76932 L p .707 .577 .707 r
F P
0 g
s
.62796 .76854 m .62796 .78707 L .65735 .78369 L p .707 .577 .707 r
F P
0 g
s
.65735 .78369 m .65735 .76516 L .62796 .76854 L p .707 .577 .707 r
F P
0 g
s
.56496 .76742 m .56496 .78594 L .59613 .78785 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76325 L p .707 .577 .707 r
F P
0 g
s
.6814 .76325 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.56496 .78594 m .56496 .76742 L .5375 .76302 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.6814 .66833 m .6814 .72391 L .69777 .71654 L p .707 .577 .707 r
F P
0 g
s
.69777 .71654 m .69777 .66096 L .6814 .66833 L p .707 .577 .707 r
F P
0 g
s
.5375 .76302 m .5375 .78155 L .56496 .78594 L p .707 .577 .707 r
F P
0 g
s
.51644 .66539 m .51644 .72097 L .5375 .72743 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.65735 .76516 m .65735 .78369 L .6814 .77804 L p .707 .577 .707 r
F P
0 g
s
.6814 .77804 m .6814 .75951 L .65735 .76516 L p .707 .577 .707 r
F P
0 g
s
.51644 .72097 m .51644 .66539 L .50385 .65751 L p .707 .577 .707 r
F P
0 g
s
.5375 .78155 m .5375 .76302 L .51644 .75657 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76325 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.51644 .75657 m .51644 .7751 L .5375 .78155 L p .707 .577 .707 r
F P
0 g
s
.6814 .75951 m .6814 .77804 L .69777 .77067 L p .707 .577 .707 r
F P
0 g
s
.69777 .77067 m .69777 .75214 L .6814 .75951 L p .707 .577 .707 r
F P
0 g
s
.50385 .65751 m .50385 .71309 L .51644 .72097 L p .707 .577 .707 r
F P
0 g
s
.69777 .66096 m .69777 .71654 L .70485 .70818 L p .707 .577 .707 r
F P
0 g
s
.70485 .70818 m .70485 .6526 L .69777 .66096 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71537 L p .707 .577 .707 r
F P
0 g
s
.51644 .7751 m .51644 .75657 L .50385 .74869 L p .707 .577 .707 r
F P
0 g
s
.50385 .71537 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.50385 .71309 m .50385 .65751 L .50095 .64896 L p .707 .577 .707 r
F P
0 g
s
.50385 .74869 m .50385 .76721 L .51644 .7751 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.49044 .73057 m .49044 .22868 L .44643 .226 L p .707 .577 .707 r
F P
0 g
s
.50095 .64896 m .50095 .70455 L .50385 .71309 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71537 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70455 m .50095 .64896 L .50804 .6406 L p .707 .577 .707 r
F P
0 g
s
.50804 .6406 m .50804 .69618 L .50095 .70455 L p .707 .577 .707 r
F P
0 g
s
.50385 .76721 m .50385 .74869 L .50095 .74014 L p .707 .577 .707 r
F P
0 g
s
.50095 .74014 m .50095 .75867 L .50385 .76721 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .69618 m .50804 .6406 L .5244 .63323 L p .707 .577 .707 r
F P
0 g
s
.5244 .63323 m .5244 .68881 L .50804 .69618 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.50804 .75031 m .50804 .73178 L .5244 .72441 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72815 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .68881 m .5244 .63323 L .54846 .62758 L p .707 .577 .707 r
F P
0 g
s
.5244 .72441 m .5244 .74294 L .50804 .75031 L p .707 .577 .707 r
F P
0 g
s
.54846 .62758 m .54846 .68316 L .5244 .68881 L p .707 .577 .707 r
F P
0 g
s
.5244 .72815 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.5244 .74294 m .5244 .72441 L .54846 .71876 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .7225 L .5244 .72815 L p .707 .577 .707 r
F P
0 g
s
.49044 .22868 m .49044 .73057 L .53538 .72947 L p .707 .577 .707 r
F P
0 g
s
.53538 .72947 m .53538 .22758 L .49044 .22868 L p .707 .577 .707 r
F P
0 g
s
.54846 .68316 m .54846 .62758 L .57784 .6242 L p .707 .577 .707 r
F P
0 g
s
.54846 .71876 m .54846 .73729 L .5244 .74294 L p .707 .577 .707 r
F P
0 g
s
.57784 .6242 m .57784 .67978 L .54846 .68316 L p .707 .577 .707 r
F P
0 g
s
.54846 .7225 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.54846 .73729 m .54846 .71876 L .57784 .71538 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .7225 L p .707 .577 .707 r
F P
0 g
s
.57784 .71538 m .57784 .73391 L .54846 .73729 L p .707 .577 .707 r
F P
0 g
s
.53538 .22758 m .53538 .72947 L .57686 .7247 L p .707 .577 .707 r
F P
0 g
s
.57686 .7247 m .57686 .22281 L .53538 .22758 L p .707 .577 .707 r
F P
0 g
s
.69777 .75214 m .69777 .77067 L .70485 .76231 L p .707 .577 .707 r
F P
0 g
s
.70485 .76231 m .70485 .74378 L .69777 .75214 L p .707 .577 .707 r
F P
0 g
s
.44643 .72789 m .44643 .226 L .40766 .2198 L p .707 .577 .707 r
F P
0 g
s
.44643 .226 m .44643 .72789 L .49044 .73057 L p .707 .577 .707 r
F P
0 g
s
.70485 .6526 m .70485 .70818 L .70195 .69964 L p .707 .577 .707 r
F P
0 g
s
.70195 .69964 m .70195 .64406 L .70485 .6526 L p .707 .577 .707 r
F P
0 g
s
.57784 .67978 m .57784 .6242 L .60968 .62343 L p .707 .577 .707 r
F P
0 g
s
.60968 .62343 m .60968 .67901 L .57784 .67978 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .68129 L .64085 .68319 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .68129 L p .707 .577 .707 r
F P
0 g
s
.60968 .68129 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.60968 .73313 m .60968 .71461 L .64085 .71651 L p .707 .577 .707 r
F P
0 g
s
.57784 .73391 m .57784 .71538 L .60968 .71461 L p .707 .577 .707 r
F P
0 g
s
.60968 .71461 m .60968 .73313 L .57784 .73391 L p .707 .577 .707 r
F P
0 g
s
.57686 .22281 m .57686 .7247 L .61082 .71673 L p .707 .577 .707 r
F P
0 g
s
.64085 .62533 m .64085 .68091 L .60968 .67901 L p .707 .577 .707 r
F P
0 g
s
.60968 .67901 m .60968 .62343 L .64085 .62533 L p .707 .577 .707 r
F P
0 g
s
.61082 .71673 m .61082 .21484 L .57686 .22281 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70192 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.40766 .72169 m .40766 .2198 L .37794 .21069 L p .707 .577 .707 r
F P
0 g
s
.40766 .2198 m .40766 .72169 L .44643 .72789 L p .707 .577 .707 r
F P
0 g
s
.70485 .74378 m .70485 .76231 L .70195 .75377 L p .707 .577 .707 r
F P
0 g
s
.70195 .75377 m .70195 .73524 L .70485 .74378 L p .707 .577 .707 r
F P
0 g
s
.70195 .64406 m .70195 .69964 L .68936 .69175 L p .707 .577 .707 r
F P
0 g
s
.68936 .69175 m .68936 .63617 L .70195 .64406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .75867 m .50095 .74014 L .50804 .73178 L p .707 .577 .707 r
F P
0 g
s
.64085 .68319 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.61082 .21484 m .61082 .71673 L .63393 .70632 L p .707 .577 .707 r
F P
0 g
s
.63393 .70632 m .63393 .20444 L .61082 .21484 L p .707 .577 .707 r
F P
0 g
s
.25312 .6969 m .25312 .64132 L .22195 .63942 L p .707 .577 .707 r
F P
0 g
s
.25312 .64132 m .25312 .6969 L .28495 .69613 L p .707 .577 .707 r
F P
0 g
s
.28495 .69613 m .28495 .64054 L .25312 .64132 L p .707 .577 .707 r
F P
0 g
s
.28495 .64054 m .28495 .69613 L .31434 .69275 L p .707 .577 .707 r
F P
0 g
s
.31434 .69275 m .31434 .63716 L .28495 .64054 L p .707 .577 .707 r
F P
0 g
s
.50804 .73178 m .50804 .75031 L .50095 .75867 L p .707 .577 .707 r
F P
0 g
s
.70195 .70192 m .70195 .73898 L .68936 .73109 L p .707 .577 .707 r
F P
0 g
s
.68936 .73109 m .68936 .69404 L .70195 .70192 L p .707 .577 .707 r
F P
0 g
s
.22195 .695 m .22195 .63942 L .19449 .63503 L p .707 .577 .707 r
F P
0 g
s
.22195 .63942 m .22195 .695 L .25312 .6969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.37794 .71257 m .37794 .21069 L .36016 .19956 L p .707 .577 .707 r
F P
0 g
s
.37794 .21069 m .37794 .71257 L .40766 .72169 L p .707 .577 .707 r
F P
0 g
s
.31434 .63716 m .31434 .69275 L .33839 .6871 L p .707 .577 .707 r
F P
0 g
s
.33839 .6871 m .33839 .63152 L .31434 .63716 L p .707 .577 .707 r
F P
0 g
s
.70195 .73524 m .70195 .75377 L .68936 .74588 L p .707 .577 .707 r
F P
0 g
s
.68936 .74588 m .68936 .72735 L .70195 .73524 L p .707 .577 .707 r
F P
0 g
s
.25312 .73624 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73624 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.68936 .63617 m .68936 .69175 L .66831 .6853 L p .707 .577 .707 r
F P
0 g
s
.66831 .6853 m .66831 .62972 L .68936 .63617 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69503 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.19449 .63503 m .19449 .69061 L .22195 .695 L p .707 .577 .707 r
F P
0 g
s
.19449 .69061 m .19449 .63503 L .17343 .62857 L p .707 .577 .707 r
F P
0 g
s
.22195 .73434 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73434 L .25312 .73624 L p .707 .577 .707 r
F P
0 g
s
.25312 .75103 m .25312 .7325 L .22195 .7306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7325 m .25312 .75103 L .28495 .75025 L p .707 .577 .707 r
F P
0 g
s
.28495 .75025 m .28495 .73173 L .25312 .7325 L p .707 .577 .707 r
F P
0 g
s
.28495 .73173 m .28495 .75025 L .31434 .74687 L p .707 .577 .707 r
F P
0 g
s
.31434 .74687 m .31434 .72835 L .28495 .73173 L p .707 .577 .707 r
F P
0 g
s
.22195 .7306 m .22195 .74913 L .25312 .75103 L p .707 .577 .707 r
F P
0 g
s
.31434 .69503 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68938 L .31434 .69503 L p .707 .577 .707 r
F P
0 g
s
.22195 .74913 m .22195 .7306 L .19449 .72621 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73434 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .73109 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.33839 .63152 m .33839 .6871 L .35476 .67973 L p .707 .577 .707 r
F P
0 g
s
.35476 .67973 m .35476 .62415 L .33839 .63152 L p .707 .577 .707 r
F P
0 g
s
.66831 .62972 m .66831 .6853 L .64085 .68091 L p .707 .577 .707 r
F P
0 g
s
.64085 .68091 m .64085 .62533 L .66831 .62972 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .68319 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.63393 .20444 m .63393 .70632 L .64393 .69452 L p .707 .577 .707 r
F P
0 g
s
.64393 .69452 m .64393 .19263 L .63393 .20444 L p .707 .577 .707 r
F P
0 g
s
.19449 .72621 m .19449 .74474 L .22195 .74913 L p .707 .577 .707 r
F P
0 g
s
.17343 .62857 m .17343 .68416 L .19449 .69061 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.31434 .72835 m .31434 .74687 L .33839 .74122 L p .707 .577 .707 r
F P
0 g
s
.33839 .74122 m .33839 .7227 L .31434 .72835 L p .707 .577 .707 r
F P
0 g
s
.68936 .72735 m .68936 .74588 L .66831 .73943 L p .707 .577 .707 r
F P
0 g
s
.66831 .73943 m .66831 .7209 L .68936 .72735 L p .707 .577 .707 r
F P
0 g
s
.17343 .68416 m .17343 .62857 L .16084 .62069 L p .707 .577 .707 r
F P
0 g
s
.19449 .74474 m .19449 .72621 L .17343 .71976 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68938 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68938 L p .707 .577 .707 r
F P
0 g
s
.35476 .62415 m .35476 .67973 L .36184 .67137 L p .707 .577 .707 r
F P
0 g
s
.36184 .67137 m .36184 .61578 L .35476 .62415 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .61578 m .36184 .67137 L .35894 .66282 L p .707 .577 .707 r
F P
0 g
s
.35894 .66282 m .35894 .60724 L .36184 .61578 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .72549 m .36184 .70696 L .35476 .71533 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70216 L p .707 .577 .707 r
F P
0 g
s
.35894 .70216 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .70144 m .36016 .19956 L .35607 .1875 L p .707 .577 .707 r
F P
0 g
s
.36016 .19956 m .36016 .70144 L .37794 .71257 L p .707 .577 .707 r
F P
0 g
s
.17343 .71976 m .17343 .73828 L .19449 .74474 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.33839 .7227 m .33839 .74122 L .35476 .73386 L p .707 .577 .707 r
F P
0 g
s
.35476 .73386 m .35476 .71533 L .33839 .7227 L p .707 .577 .707 r
F P
0 g
s
.16084 .62069 m .16084 .67627 L .17343 .68416 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.66831 .7209 m .66831 .73943 L .64085 .73503 L p .707 .577 .707 r
F P
0 g
s
.64085 .73503 m .64085 .71651 L .66831 .7209 L p .707 .577 .707 r
F P
0 g
s
.17343 .73828 m .17343 .71976 L .16084 .71187 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.16084 .67627 m .16084 .62069 L .15794 .61215 L p .707 .577 .707 r
F P
0 g
s
.16084 .71187 m .16084 .7304 L .17343 .73828 L p .707 .577 .707 r
F P
0 g
s
.64393 .19263 m .64393 .69452 L .63984 .68246 L p .707 .577 .707 r
F P
0 g
s
.63984 .68246 m .63984 .18057 L .64393 .19263 L p .707 .577 .707 r
F P
0 g
s
.64085 .71651 m .64085 .73503 L .60968 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .71533 m .35476 .73386 L .36184 .72549 L p .707 .577 .707 r
F P
0 g
s
.15794 .61215 m .15794 .66773 L .16084 .67627 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.35894 .60724 m .35894 .66282 L .34635 .65494 L p .707 .577 .707 r
F P
0 g
s
.34635 .65494 m .34635 .59936 L .35894 .60724 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70216 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65722 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .1875 m .35607 .68938 L .36016 .70144 L p .707 .577 .707 r
F P
0 g
s
.35607 .68938 m .35607 .1875 L .36607 .17569 L p .707 .577 .707 r
F P
0 g
s
.16084 .7304 m .16084 .71187 L .15794 .70333 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.15794 .70333 m .15794 .72186 L .16084 .7304 L p .707 .577 .707 r
F P
0 g
s
.15794 .66773 m .15794 .61215 L .16503 .60378 L p .707 .577 .707 r
F P
0 g
s
.36184 .70696 m .36184 .72549 L .35894 .71695 L p .707 .577 .707 r
F P
0 g
s
.35894 .71695 m .35894 .69842 L .36184 .70696 L p .707 .577 .707 r
F P
0 g
s
.16503 .60378 m .16503 .65937 L .15794 .66773 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.63984 .18057 m .63984 .68246 L .62206 .67133 L p .707 .577 .707 r
F P
0 g
s
.62206 .67133 m .62206 .16944 L .63984 .18057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .72186 m .15794 .70333 L .16503 .69497 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.16503 .65937 m .16503 .60378 L .1814 .59642 L p .707 .577 .707 r
F P
0 g
s
.16503 .69497 m .16503 .71349 L .15794 .72186 L p .707 .577 .707 r
F P
0 g
s
.36607 .67758 m .36607 .17569 L .38918 .16529 L p .707 .577 .707 r
F P
0 g
s
.36607 .17569 m .36607 .67758 L .35607 .68938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .69842 m .35894 .71695 L .34635 .70907 L p .707 .577 .707 r
F P
0 g
s
.34635 .70907 m .34635 .69054 L .35894 .69842 L p .707 .577 .707 r
F P
0 g
s
.1814 .59642 m .1814 .652 L .16503 .65937 L p .707 .577 .707 r
F P
0 g
s
.34635 .59936 m .34635 .65494 L .3253 .64848 L p .707 .577 .707 r
F P
0 g
s
.3253 .64848 m .3253 .5929 L .34635 .59936 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65428 L p .707 .577 .707 r
F P
0 g
s
.16503 .71349 m .16503 .69497 L .1814 .6876 L p .707 .577 .707 r
F P
0 g
s
.62206 .16944 m .62206 .67133 L .59233 .66221 L p .707 .577 .707 r
F P
0 g
s
.59233 .66221 m .59233 .16033 L .62206 .16944 L p .707 .577 .707 r
F P
0 g
s
.1814 .65428 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.1814 .652 m .1814 .59642 L .20545 .59077 L p .707 .577 .707 r
F P
0 g
s
.1814 .6876 m .1814 .70612 L .16503 .71349 L p .707 .577 .707 r
F P
0 g
s
.34635 .65722 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65722 L p .707 .577 .707 r
F P
0 g
s
.3253 .5929 m .3253 .64848 L .29784 .64409 L p .707 .577 .707 r
F P
0 g
s
.29784 .64409 m .29784 .58851 L .3253 .5929 L p .707 .577 .707 r
F P
0 g
s
.38918 .16529 m .38918 .66717 L .36607 .67758 L p .707 .577 .707 r
F P
0 g
s
.38918 .66717 m .38918 .16529 L .42314 .15731 L p .707 .577 .707 r
F P
0 g
s
.34635 .69054 m .34635 .70907 L .3253 .70261 L p .707 .577 .707 r
F P
0 g
s
.3253 .70261 m .3253 .68408 L .34635 .69054 L p .707 .577 .707 r
F P
0 g
s
.20545 .59077 m .20545 .64635 L .1814 .652 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65428 L .20545 .64863 L p .707 .577 .707 r
F P
0 g
s
.20545 .64635 m .20545 .59077 L .23483 .58739 L p .707 .577 .707 r
F P
0 g
s
.1814 .70612 m .1814 .6876 L .20545 .68195 L p .707 .577 .707 r
F P
0 g
s
.20545 .64863 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.29784 .58851 m .29784 .64409 L .26667 .64219 L p .707 .577 .707 r
F P
0 g
s
.26667 .64219 m .26667 .58661 L .29784 .58851 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68343 L p .707 .577 .707 r
F P
0 g
s
.29784 .68343 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68195 m .20545 .70048 L .1814 .70612 L p .707 .577 .707 r
F P
0 g
s
.23483 .64297 m .23483 .58739 L .26667 .58661 L p .707 .577 .707 r
F P
0 g
s
.23483 .58739 m .23483 .64297 L .20545 .64635 L p .707 .577 .707 r
F P
0 g
s
.59233 .16033 m .59233 .66221 L .55357 .65601 L p .707 .577 .707 r
F P
0 g
s
.55357 .65601 m .55357 .15412 L .59233 .16033 L p .707 .577 .707 r
F P
0 g
s
.26667 .58661 m .26667 .64219 L .23483 .64297 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64863 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.73333 .64168 m .73333 .5861 L .70216 .5842 L p .707 .577 .707 r
F P
0 g
s
.73333 .5861 m .73333 .64168 L .76517 .6409 L p .707 .577 .707 r
F P
0 g
s
.76517 .6409 m .76517 .58532 L .73333 .5861 L p .707 .577 .707 r
F P
0 g
s
.3253 .68408 m .3253 .70261 L .29784 .69822 L p .707 .577 .707 r
F P
0 g
s
.29784 .69822 m .29784 .67969 L .3253 .68408 L p .707 .577 .707 r
F P
0 g
s
.76517 .58532 m .76517 .6409 L .79455 .63752 L p .707 .577 .707 r
F P
0 g
s
.79455 .63752 m .79455 .58194 L .76517 .58532 L p .707 .577 .707 r
F P
0 g
s
.42314 .6592 m .42314 .15731 L .46462 .15254 L p .707 .577 .707 r
F P
0 g
s
.42314 .15731 m .42314 .6592 L .38918 .66717 L p .707 .577 .707 r
F P
0 g
s
.70216 .63978 m .70216 .5842 L .6747 .5798 L p .707 .577 .707 r
F P
0 g
s
.70216 .5842 m .70216 .63978 L .73333 .64168 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68343 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.20545 .70048 m .20545 .68195 L .23483 .67857 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.23483 .67857 m .23483 .6971 L .20545 .70048 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.79455 .58194 m .79455 .63752 L .8186 .63187 L p .707 .577 .707 r
F P
0 g
s
.8186 .63187 m .8186 .57629 L .79455 .58194 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68024 L p .707 .577 .707 r
F P
0 g
s
.76517 .68024 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.29784 .67969 m .29784 .69822 L .26667 .69632 L p .707 .577 .707 r
F P
0 g
s
.26667 .69632 m .26667 .67779 L .29784 .67969 L p .707 .577 .707 r
F P
0 g
s
.55357 .15412 m .55357 .65601 L .50956 .65333 L p .707 .577 .707 r
F P
0 g
s
.50956 .65333 m .50956 .15144 L .55357 .15412 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68024 L .79455 .67686 L p .707 .577 .707 r
F P
0 g
s
.79455 .67686 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.23483 .6971 m .23483 .67857 L .26667 .67779 L p .707 .577 .707 r
F P
0 g
s
.6747 .5798 m .6747 .63539 L .70216 .63978 L p .707 .577 .707 r
F P
0 g
s
.6747 .63539 m .6747 .5798 L .65365 .57335 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63767 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.46462 .65443 m .46462 .15254 L .50956 .15144 L p .707 .577 .707 r
F P
0 g
s
.46462 .15254 m .46462 .65443 L .42314 .6592 L p .707 .577 .707 r
F P
0 g
s
.26667 .67779 m .26667 .69632 L .23483 .6971 L p .707 .577 .707 r
F P
0 g
s
.73333 .69581 m .73333 .67728 L .70216 .67538 L p .707 .577 .707 r
F P
0 g
s
.73333 .67728 m .73333 .69581 L .76517 .69503 L p .707 .577 .707 r
F P
0 g
s
.76517 .69503 m .76517 .6765 L .73333 .67728 L p .707 .577 .707 r
F P
0 g
s
.50956 .15144 m .50956 .65333 L .46462 .65443 L p .707 .577 .707 r
F P
0 g
s
.76517 .6765 m .76517 .69503 L .79455 .69165 L p .707 .577 .707 r
F P
0 g
s
.79455 .69165 m .79455 .67312 L .76517 .6765 L p .707 .577 .707 r
F P
0 g
s
.70216 .67538 m .70216 .69391 L .73333 .69581 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67686 L .8186 .67121 L p .707 .577 .707 r
F P
0 g
s
.8186 .67121 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.70216 .69391 m .70216 .67538 L .6747 .67099 L p .707 .577 .707 r
F P
0 g
s
.6747 .63767 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.8186 .57629 m .8186 .63187 L .83497 .62451 L p .707 .577 .707 r
F P
0 g
s
.83497 .62451 m .83497 .56892 L .8186 .57629 L p .707 .577 .707 r
F P
0 g
s
.6747 .67099 m .6747 .68951 L .70216 .69391 L p .707 .577 .707 r
F P
0 g
s
.65365 .57335 m .65365 .62893 L .6747 .63539 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63767 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.79455 .67312 m .79455 .69165 L .8186 .686 L p .707 .577 .707 r
F P
0 g
s
.8186 .686 m .8186 .66747 L .79455 .67312 L p .707 .577 .707 r
F P
0 g
s
.65365 .62893 m .65365 .57335 L .64105 .56547 L p .707 .577 .707 r
F P
0 g
s
.6747 .68951 m .6747 .67099 L .65365 .66453 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66827 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67121 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.65365 .66453 m .65365 .68306 L .6747 .68951 L p .707 .577 .707 r
F P
0 g
s
.8186 .66747 m .8186 .686 L .83497 .67863 L p .707 .577 .707 r
F P
0 g
s
.83497 .67863 m .83497 .66011 L .8186 .66747 L p .707 .577 .707 r
F P
0 g
s
.64105 .56547 m .64105 .62105 L .65365 .62893 L p .707 .577 .707 r
F P
0 g
s
.83497 .56892 m .83497 .62451 L .84205 .61614 L p .707 .577 .707 r
F P
0 g
s
.84205 .61614 m .84205 .56056 L .83497 .56892 L p .707 .577 .707 r
F P
0 g
s
.65365 .66827 m .65365 .63122 L .64105 .62333 L p .707 .577 .707 r
F P
0 g
s
.65365 .68306 m .65365 .66453 L .64105 .65665 L p .707 .577 .707 r
F P
0 g
s
.64105 .62333 m .64105 .66039 L .65365 .66827 L p .707 .577 .707 r
F P
0 g
s
.64105 .62105 m .64105 .56547 L .63816 .55692 L p .707 .577 .707 r
F P
0 g
s
.64105 .65665 m .64105 .67518 L .65365 .68306 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.83497 .66011 m .83497 .67863 L .84206 .67027 L p .707 .577 .707 r
F P
0 g
s
.84206 .67027 m .84205 .65174 L .83497 .66011 L p .707 .577 .707 r
F P
0 g
s
.63816 .55692 m .63816 .61251 L .64105 .62105 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62333 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.84205 .56056 m .84205 .61614 L .83916 .6076 L p .707 .577 .707 r
F P
0 g
s
.83916 .6076 m .83916 .55202 L .84205 .56056 L p .707 .577 .707 r
F P
0 g
s
.64105 .67518 m .64105 .65665 L .63816 .64811 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.63816 .64811 m .63816 .66663 L .64105 .67518 L p .707 .577 .707 r
F P
0 g
s
.63816 .61251 m .63816 .55692 L .64524 .54856 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.84205 .65174 m .84206 .67027 L .83916 .66173 L p .707 .577 .707 r
F P
0 g
s
.83916 .66173 m .83916 .6432 L .84205 .65174 L p .707 .577 .707 r
F P
0 g
s
.64524 .54856 m .64524 .60414 L .63816 .61251 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.83916 .55202 m .83916 .6076 L .82657 .59972 L p .707 .577 .707 r
F P
0 g
s
.82657 .59972 m .82657 .54413 L .83916 .55202 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .66663 m .63816 .64811 L .64524 .63974 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64348 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.39032 .60486 m .39032 .54928 L .35915 .54738 L p .707 .577 .707 r
F P
0 g
s
.39032 .54928 m .39032 .60486 L .42216 .60409 L p .707 .577 .707 r
F P
0 g
s
.42216 .60409 m .42216 .5485 L .39032 .54928 L p .707 .577 .707 r
F P
0 g
s
.64524 .60414 m .64524 .54856 L .66161 .54119 L p .707 .577 .707 r
F P
0 g
s
.42216 .5485 m .42216 .60409 L .45154 .60071 L p .707 .577 .707 r
F P
0 g
s
.45154 .60071 m .45154 .54513 L .42216 .5485 L p .707 .577 .707 r
F P
0 g
s
.64524 .63974 m .64524 .65827 L .63816 .66663 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.35915 .60296 m .35915 .54738 L .33169 .54299 L p .707 .577 .707 r
F P
0 g
s
.35915 .54738 m .35915 .60296 L .39032 .60486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54513 m .45154 .60071 L .47559 .59506 L p .707 .577 .707 r
F P
0 g
s
.47559 .59506 m .47559 .53948 L .45154 .54513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6432 m .83916 .66173 L .82657 .65384 L p .707 .577 .707 r
F P
0 g
s
.82657 .65384 m .82657 .63532 L .83916 .6432 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60637 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.66161 .54119 m .66161 .59677 L .64524 .60414 L p .707 .577 .707 r
F P
0 g
s
.82657 .54413 m .82657 .59972 L .80551 .59326 L p .707 .577 .707 r
F P
0 g
s
.80551 .59326 m .80551 .53768 L .82657 .54413 L p .707 .577 .707 r
F P
0 g
s
.64524 .64348 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60637 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .60299 L .42216 .60637 L p .707 .577 .707 r
F P
0 g
s
.33169 .54299 m .33169 .59857 L .35915 .60296 L p .707 .577 .707 r
F P
0 g
s
.33169 .59857 m .33169 .54299 L .31064 .53654 L p .707 .577 .707 r
F P
0 g
s
.35915 .6423 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .6423 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.39032 .65899 m .39032 .64046 L .35915 .63856 L p .707 .577 .707 r
F P
0 g
s
.39032 .64046 m .39032 .65899 L .42216 .65821 L p .707 .577 .707 r
F P
0 g
s
.42216 .65821 m .42216 .63969 L .39032 .64046 L p .707 .577 .707 r
F P
0 g
s
.64524 .65827 m .64524 .63974 L .66161 .63237 L p .707 .577 .707 r
F P
0 g
s
.42216 .63969 m .42216 .65821 L .45154 .65484 L p .707 .577 .707 r
F P
0 g
s
.45154 .65484 m .45154 .63631 L .42216 .63969 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59677 m .66161 .54119 L .68566 .53554 L p .707 .577 .707 r
F P
0 g
s
.35915 .63856 m .35915 .65709 L .39032 .65899 L p .707 .577 .707 r
F P
0 g
s
.45154 .60299 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59734 L .45154 .60299 L p .707 .577 .707 r
F P
0 g
s
.35915 .65709 m .35915 .63856 L .33169 .63417 L p .707 .577 .707 r
F P
0 g
s
.66161 .63237 m .66161 .6509 L .64524 .65827 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .6423 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.47559 .53948 m .47559 .59506 L .49196 .58769 L p .707 .577 .707 r
F P
0 g
s
.49196 .58769 m .49196 .53211 L .47559 .53948 L p .707 .577 .707 r
F P
0 g
s
.33169 .63417 m .33169 .6527 L .35915 .65709 L p .707 .577 .707 r
F P
0 g
s
.31064 .53654 m .31064 .59212 L .33169 .59857 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .5944 L p .707 .577 .707 r
F P
0 g
s
.45154 .63631 m .45154 .65484 L .47559 .64919 L p .707 .577 .707 r
F P
0 g
s
.47559 .64919 m .47559 .63066 L .45154 .63631 L p .707 .577 .707 r
F P
0 g
s
.80551 .53768 m .80551 .59326 L .77805 .58887 L p .707 .577 .707 r
F P
0 g
s
.77805 .58887 m .77805 .53329 L .80551 .53768 L p .707 .577 .707 r
F P
0 g
s
.82657 .63532 m .82657 .65384 L .80551 .64739 L p .707 .577 .707 r
F P
0 g
s
.80551 .64739 m .80551 .62886 L .82657 .63532 L p .707 .577 .707 r
F P
0 g
s
.68566 .53554 m .68566 .59112 L .66161 .59677 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.31064 .59212 m .31064 .53654 L .29804 .52865 L p .707 .577 .707 r
F P
0 g
s
.33169 .6527 m .33169 .63417 L .31064 .62772 L p .707 .577 .707 r
F P
0 g
s
.31064 .5944 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.68566 .59112 m .68566 .53554 L .71504 .53216 L p .707 .577 .707 r
F P
0 g
s
.47559 .59734 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59734 L p .707 .577 .707 r
F P
0 g
s
.31064 .62772 m .31064 .64624 L .33169 .6527 L p .707 .577 .707 r
F P
0 g
s
.66161 .6509 m .66161 .63237 L .68566 .62672 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.77805 .53329 m .77805 .58887 L .74688 .58697 L p .707 .577 .707 r
F P
0 g
s
.74688 .58697 m .74688 .53139 L .77805 .53329 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.68566 .62672 m .68566 .64525 L .66161 .6509 L p .707 .577 .707 r
F P
0 g
s
.47559 .63066 m .47559 .64919 L .49196 .64182 L p .707 .577 .707 r
F P
0 g
s
.49196 .64182 m .49196 .62329 L .47559 .63066 L p .707 .577 .707 r
F P
0 g
s
.29804 .52865 m .29804 .58423 L .31064 .59212 L p .707 .577 .707 r
F P
0 g
s
.71504 .58775 m .71504 .53216 L .74688 .53139 L p .707 .577 .707 r
F P
0 g
s
.71504 .53216 m .71504 .58775 L .68566 .59112 L p .707 .577 .707 r
F P
0 g
s
.49196 .53211 m .49196 .58769 L .49904 .57933 L p .707 .577 .707 r
F P
0 g
s
.49904 .57933 m .49904 .52374 L .49196 .53211 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .5944 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.74688 .53139 m .74688 .58697 L .71504 .58775 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.80551 .62886 m .80551 .64739 L .77805 .643 L p .707 .577 .707 r
F P
0 g
s
.77805 .643 m .77805 .62447 L .80551 .62886 L p .707 .577 .707 r
F P
0 g
s
.31064 .64624 m .31064 .62772 L .29804 .61983 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62357 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58925 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.29804 .58423 m .29804 .52865 L .29515 .52011 L p .707 .577 .707 r
F P
0 g
s
.68566 .64525 m .68566 .62672 L .71504 .62335 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.29804 .61983 m .29804 .63836 L .31064 .64624 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58925 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.71504 .62335 m .71504 .64187 L .68566 .64525 L p .707 .577 .707 r
F P
0 g
s
.74688 .58925 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.77805 .62447 m .77805 .643 L .74688 .6411 L p .707 .577 .707 r
F P
0 g
s
.74688 .6411 m .74688 .62257 L .77805 .62447 L p .707 .577 .707 r
F P
0 g
s
.71504 .64187 m .71504 .62335 L .74688 .62257 L p .707 .577 .707 r
F P
0 g
s
.49196 .62329 m .49196 .64182 L .49904 .63345 L p .707 .577 .707 r
F P
0 g
s
.49904 .63345 m .49904 .61493 L .49196 .62329 L p .707 .577 .707 r
F P
0 g
s
.29515 .52011 m .29515 .57569 L .29804 .58423 L p .707 .577 .707 r
F P
0 g
s
.74688 .62257 m .74688 .6411 L .71504 .64187 L p .707 .577 .707 r
F P
0 g
s
.29804 .62357 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.49904 .52374 m .49904 .57933 L .49615 .57078 L p .707 .577 .707 r
F P
0 g
s
.49615 .57078 m .49615 .5152 L .49904 .52374 L p .707 .577 .707 r
F P
0 g
s
.29804 .63836 m .29804 .61983 L .29515 .61129 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62357 L p .707 .577 .707 r
F P
0 g
s
.29515 .61129 m .29515 .62982 L .29804 .63836 L p .707 .577 .707 r
F P
0 g
s
.29515 .57569 m .29515 .52011 L .30223 .51174 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61012 L p .707 .577 .707 r
F P
0 g
s
.49615 .61012 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.49904 .61493 m .49904 .63345 L .49615 .62491 L p .707 .577 .707 r
F P
0 g
s
.49615 .62491 m .49615 .60638 L .49904 .61493 L p .707 .577 .707 r
F P
0 g
s
.30223 .51174 m .30223 .56733 L .29515 .57569 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.49615 .5152 m .49615 .57078 L .48356 .5629 L p .707 .577 .707 r
F P
0 g
s
.48356 .5629 m .48356 .50732 L .49615 .5152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .62982 m .29515 .61129 L .30223 .60293 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.30223 .56733 m .30223 .51174 L .3186 .50438 L p .707 .577 .707 r
F P
0 g
s
.30223 .60293 m .30223 .62145 L .29515 .62982 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61012 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .60638 m .49615 .62491 L .48356 .61703 L p .707 .577 .707 r
F P
0 g
s
.48356 .61703 m .48356 .5985 L .49615 .60638 L p .707 .577 .707 r
F P
0 g
s
.3186 .50438 m .3186 .55996 L .30223 .56733 L p .707 .577 .707 r
F P
0 g
s
.48356 .50732 m .48356 .5629 L .4625 .55645 L p .707 .577 .707 r
F P
0 g
s
.4625 .55645 m .4625 .50086 L .48356 .50732 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56224 L p .707 .577 .707 r
F P
0 g
s
.30223 .62145 m .30223 .60293 L .3186 .59556 L p .707 .577 .707 r
F P
0 g
s
.3186 .56224 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55996 m .3186 .50438 L .34265 .49873 L p .707 .577 .707 r
F P
0 g
s
.3186 .59556 m .3186 .61409 L .30223 .62145 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.4625 .50086 m .4625 .55645 L .43504 .55205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55205 m .43504 .49647 L .4625 .50086 L p .707 .577 .707 r
F P
0 g
s
.48356 .5985 m .48356 .61703 L .4625 .61057 L p .707 .577 .707 r
F P
0 g
s
.4625 .61057 m .4625 .59205 L .48356 .5985 L p .707 .577 .707 r
F P
0 g
s
.34265 .49873 m .34265 .55431 L .3186 .55996 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56224 L .34265 .55659 L p .707 .577 .707 r
F P
0 g
s
.34265 .55431 m .34265 .49873 L .37203 .49535 L p .707 .577 .707 r
F P
0 g
s
.3186 .61409 m .3186 .59556 L .34265 .58991 L p .707 .577 .707 r
F P
0 g
s
.34265 .55659 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.43504 .49647 m .43504 .55205 L .40387 .55015 L p .707 .577 .707 r
F P
0 g
s
.40387 .55015 m .40387 .49457 L .43504 .49647 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .59139 L p .707 .577 .707 r
F P
0 g
s
.43504 .59139 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .58991 m .34265 .60844 L .3186 .61409 L p .707 .577 .707 r
F P
0 g
s
.37203 .55093 m .37203 .49535 L .40387 .49457 L p .707 .577 .707 r
F P
0 g
s
.37203 .49535 m .37203 .55093 L .34265 .55431 L p .707 .577 .707 r
F P
0 g
s
.40387 .49457 m .40387 .55015 L .37203 .55093 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .55659 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.4625 .59205 m .4625 .61057 L .43504 .60618 L p .707 .577 .707 r
F P
0 g
s
.43504 .60618 m .43504 .58765 L .4625 .59205 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .59139 L .40387 .58949 L p .707 .577 .707 r
F P
0 g
s
.40387 .58949 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.34265 .60844 m .34265 .58991 L .37203 .58653 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.37203 .58653 m .37203 .60506 L .34265 .60844 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .58949 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.43504 .58765 m .43504 .60618 L .40387 .60428 L p .707 .577 .707 r
F P
0 g
s
.40387 .60428 m .40387 .58575 L .43504 .58765 L p .707 .577 .707 r
F P
0 g
s
.37203 .60506 m .37203 .58653 L .40387 .58575 L p .707 .577 .707 r
F P
0 g
s
.40387 .58575 m .40387 .60428 L .37203 .60506 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP03
FUHO0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
Dgoo00<005YF000015YF00<005YF00002@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@000goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003moo`P000AJEP03001JEUYF009JEP@0
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000gOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=0004FUH01000FUIJEUYF0P00;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000020002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPP00003
FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP000000;Goo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1P00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1P001eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJ
EP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEQH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP800004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP80009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04
001JEUYFFUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH70003FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEPD0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP80
0003FUH0000000AJEP@000AJEPD00003FUH0000000L000=JEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
05YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH300000eYF001JEP04FUH01000FUIJEUYF1@000eYF2P0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JER4000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70004FUH90004FUH00`00FUIJEP03FUH400000eYF
001JEP04FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000600000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00003FUH700000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH<
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH2000]Ool002aoo`04001JEP00FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0;0004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH?000;
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009J
EP8002eoo`00;7oo00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YF0000500035YF00<0
05YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP@002eoo`00;7oo10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00@000IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]
Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF0P000UYF00<005YF00000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH0
0eYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YF000000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP05001JEUYFFUH00003FUH20002FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH5
0004FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEPh000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP03FUH0
0`00FUIJEP030002FUHG0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000AJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00@005YFFUIJEP<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP800004FUH000000005FUH00`00FUIJEP03FUH30008FUH40005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEPH0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP06
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol002aoo`03001JEP0000AJEP03001JEP000080009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
0004FUH005YFFUH20004FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00;7oo00<0
05YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEPH000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;7oo00@005YF001JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEPD000AJEP04001JEUYFFUH300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<0
05YFFUH00UYF7000?goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
00001UYF00<005YFFUH00eYF1P00E7oo000/Ool30004FUH01000FUIJEUYF2@001eYF00<005YFFUH0
1eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000IJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00;7oo0`000eYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP03001oogoo00<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800003FUH007oo00=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF0`001eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`<004Uo
o`00;7oo0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH007oo00Moo`<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<00003FUH00000
00H00003FUH005YF00@00003FUH005YF00AJEP04001JEUYFFUH20007Ool50018Ool002aoo`80009J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0000]oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04001JEUYFFUH20007
Ool50018Ool002aoo`8000=JEP03001JEP0000800003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP03001JEP00019oo``000IJEP03001J
EUYF00YJEP03001JEUYF00=JEPL000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0
00=JEP8000Moo`D004Qoo`00;Goo00D005YFFUIJEP0000AJEP800003FUH0000000AJEP@000AJEPD0
00EJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2000OOolI0006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH20008Ool30019Ool002ioo`800003
FUH005YF00AJEP04001JEUYFFUH50003FUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:Goo
00@005YF001JEP800003FUH005YF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF1000
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`@000=JEP03001JEUYF009JEPL0
00AJEQD000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002aoo`03001JEP00
00AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJ
EP04001JEUYFFUH2001DOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<002moo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Aoo`00>Goo
10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP<000=JEP8005Aoo`00?Goo6@00>7oo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000E7oo002>Ool300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00E7oo002>Ool200000eYF0000
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0003FUH3001DOol008ioo`80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEP0000<00003FUH005YF00=JEP03001JEP0005Aoo`00Sgoo00D005YFFUH0
05YF00<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF009JEPD000EJEP03001J
EUYF009JEP8005Eoo`00Sgoo00@005YFFUH000AJEP80009JEP03001JEUYF009JEQL000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8005Eoo`00B7oo0`00AGoo0`001EYF00@005YFFUIJEPD000QJEP@0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol004Moo`D004Ioo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00001HOol004Moo`D004Qoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol004Moo`D004]oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00B7oo0`00DGoo2@0015YF00<005YFFUH00UYF
2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002Z
Ool3001`Ool00:Uoo`D006moo`00ZGoo1@00Kgoo002YOol5001_Ool00:Yoo`<0071oo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73974 m .59613 .68416 L .56496 .68226 L p .707 .577 .707 r
F P
0 g
s
.59613 .68416 m .59613 .73974 L .62796 .73897 L p .707 .577 .707 r
F P
0 g
s
.62796 .73897 m .62796 .68339 L .59613 .68416 L p .707 .577 .707 r
F P
0 g
s
.62796 .68339 m .62796 .73897 L .65734 .73559 L p .707 .577 .707 r
F P
0 g
s
.65734 .73559 m .65734 .68001 L .62796 .68339 L p .707 .577 .707 r
F P
0 g
s
.56496 .73784 m .56496 .68226 L .5375 .67787 L p .707 .577 .707 r
F P
0 g
s
.56496 .68226 m .56496 .73784 L .59613 .73974 L p .707 .577 .707 r
F P
0 g
s
.65734 .68001 m .65734 .73559 L .6814 .72994 L p .707 .577 .707 r
F P
0 g
s
.6814 .72994 m .6814 .67436 L .65734 .68001 L p .707 .577 .707 r
F P
0 g
s
.59613 .78711 m .59613 .75006 L .56496 .74816 L p .707 .577 .707 r
F P
0 g
s
.59613 .75006 m .59613 .78711 L .62796 .78634 L p .707 .577 .707 r
F P
0 g
s
.62796 .78634 m .62796 .74928 L .59613 .75006 L p .707 .577 .707 r
F P
0 g
s
.62796 .74928 m .62796 .78634 L .65735 .78296 L p .707 .577 .707 r
F P
0 g
s
.65735 .78296 m .65735 .7459 L .62796 .74928 L p .707 .577 .707 r
F P
0 g
s
.5375 .67787 m .5375 .73345 L .56496 .73784 L p .707 .577 .707 r
F P
0 g
s
.5375 .73345 m .5375 .67787 L .51644 .67142 L p .707 .577 .707 r
F P
0 g
s
.56496 .78521 m .56496 .74816 L .5375 .74377 L p .707 .577 .707 r
F P
0 g
s
.56496 .74816 m .56496 .78521 L .59613 .78711 L p .707 .577 .707 r
F P
0 g
s
.59613 .81223 m .59613 .79371 L .56496 .7918 L p .707 .577 .707 r
F P
0 g
s
.59613 .79371 m .59613 .81223 L .62796 .81146 L p .707 .577 .707 r
F P
0 g
s
.62796 .81146 m .62796 .79293 L .59613 .79371 L p .707 .577 .707 r
F P
0 g
s
.65735 .7459 m .65735 .78296 L .6814 .77731 L p .707 .577 .707 r
F P
0 g
s
.6814 .77731 m .6814 .74025 L .65735 .7459 L p .707 .577 .707 r
F P
0 g
s
.62796 .79293 m .62796 .81146 L .65735 .80808 L p .707 .577 .707 r
F P
0 g
s
.65735 .80808 m .65735 .78955 L .62796 .79293 L p .707 .577 .707 r
F P
0 g
s
.6814 .67436 m .6814 .72994 L .69777 .72257 L p .707 .577 .707 r
F P
0 g
s
.69777 .72257 m .69777 .66699 L .6814 .67436 L p .707 .577 .707 r
F P
0 g
s
.5375 .74377 m .5375 .78082 L .56496 .78521 L p .707 .577 .707 r
F P
0 g
s
.56496 .7918 m .56496 .81033 L .59613 .81223 L p .707 .577 .707 r
F P
0 g
s
.56496 .81033 m .56496 .7918 L .5375 .78741 L p .707 .577 .707 r
F P
0 g
s
.51644 .67142 m .51644 .727 L .5375 .73345 L p .707 .577 .707 r
F P
0 g
s
.5375 .78082 m .5375 .74377 L .51644 .73731 L p .707 .577 .707 r
F P
0 g
s
.5375 .78741 m .5375 .80594 L .56496 .81033 L p .707 .577 .707 r
F P
0 g
s
.65735 .78955 m .65735 .80808 L .6814 .80243 L p .707 .577 .707 r
F P
0 g
s
.6814 .80243 m .6814 .7839 L .65735 .78955 L p .707 .577 .707 r
F P
0 g
s
.51644 .727 m .51644 .67142 L .50385 .66353 L p .707 .577 .707 r
F P
0 g
s
.51644 .73731 m .51644 .77437 L .5375 .78082 L p .707 .577 .707 r
F P
0 g
s
.5375 .80594 m .5375 .78741 L .51644 .78096 L p .707 .577 .707 r
F P
0 g
s
.6814 .74025 m .6814 .77731 L .69777 .76994 L p .707 .577 .707 r
F P
0 g
s
.69777 .76994 m .69777 .73289 L .6814 .74025 L p .707 .577 .707 r
F P
0 g
s
.51644 .78096 m .51644 .79949 L .5375 .80594 L p .707 .577 .707 r
F P
0 g
s
.50385 .66353 m .50385 .71911 L .51644 .727 L p .707 .577 .707 r
F P
0 g
s
.69777 .66699 m .69777 .72257 L .70485 .71421 L p .707 .577 .707 r
F P
0 g
s
.70485 .71421 m .70485 .65862 L .69777 .66699 L p .707 .577 .707 r
F P
0 g
s
.51644 .77437 m .51644 .73731 L .50385 .72943 L p .707 .577 .707 r
F P
0 g
s
.6814 .7839 m .6814 .80243 L .69777 .79506 L p .707 .577 .707 r
F P
0 g
s
.69777 .79506 m .69777 .77653 L .6814 .7839 L p .707 .577 .707 r
F P
0 g
s
.50385 .71911 m .50385 .66353 L .50095 .65499 L p .707 .577 .707 r
F P
0 g
s
.50385 .72943 m .50385 .76648 L .51644 .77437 L p .707 .577 .707 r
F P
0 g
s
.51644 .79949 m .51644 .78096 L .50385 .77307 L p .707 .577 .707 r
F P
0 g
s
.69777 .73289 m .69777 .76994 L .70485 .76158 L p .707 .577 .707 r
F P
0 g
s
.70485 .76158 m .70485 .72452 L .69777 .73289 L p .707 .577 .707 r
F P
0 g
s
.50385 .77307 m .50385 .7916 L .51644 .79949 L p .707 .577 .707 r
F P
0 g
s
.49044 .76543 m .49044 .26354 L .44643 .26086 L p .707 .577 .707 r
F P
0 g
s
.50095 .65499 m .50095 .71057 L .50385 .71911 L p .707 .577 .707 r
F P
0 g
s
.50385 .76648 m .50385 .72943 L .50095 .72089 L p .707 .577 .707 r
F P
0 g
s
.50095 .72089 m .50095 .75794 L .50385 .76648 L p .707 .577 .707 r
F P
0 g
s
.50385 .7916 m .50385 .77307 L .50095 .76453 L p .707 .577 .707 r
F P
0 g
s
.50095 .71057 m .50095 .65499 L .50804 .64663 L p .707 .577 .707 r
F P
0 g
s
.50095 .76453 m .50095 .78306 L .50385 .7916 L p .707 .577 .707 r
F P
0 g
s
.50804 .64663 m .50804 .70221 L .50095 .71057 L p .707 .577 .707 r
F P
0 g
s
.50095 .75794 m .50095 .72089 L .50804 .71252 L p .707 .577 .707 r
F P
0 g
s
.50804 .71252 m .50804 .74958 L .50095 .75794 L p .707 .577 .707 r
F P
0 g
s
.50804 .70221 m .50804 .64663 L .5244 .63926 L p .707 .577 .707 r
F P
0 g
s
.50095 .78306 m .50095 .76453 L .50804 .75617 L p .707 .577 .707 r
F P
0 g
s
.50804 .75617 m .50804 .7747 L .50095 .78306 L p .707 .577 .707 r
F P
0 g
s
.5244 .63926 m .5244 .69484 L .50804 .70221 L p .707 .577 .707 r
F P
0 g
s
.50804 .74958 m .50804 .71252 L .5244 .70516 L p .707 .577 .707 r
F P
0 g
s
.5244 .69484 m .5244 .63926 L .54846 .63361 L p .707 .577 .707 r
F P
0 g
s
.5244 .70516 m .5244 .74221 L .50804 .74958 L p .707 .577 .707 r
F P
0 g
s
.50804 .7747 m .50804 .75617 L .5244 .7488 L p .707 .577 .707 r
F P
0 g
s
.5244 .7488 m .5244 .76733 L .50804 .7747 L p .707 .577 .707 r
F P
0 g
s
.54846 .63361 m .54846 .68919 L .5244 .69484 L p .707 .577 .707 r
F P
0 g
s
.5244 .74221 m .5244 .70516 L .54846 .69951 L p .707 .577 .707 r
F P
0 g
s
.54846 .69951 m .54846 .73656 L .5244 .74221 L p .707 .577 .707 r
F P
0 g
s
.5244 .76733 m .5244 .7488 L .54846 .74315 L p .707 .577 .707 r
F P
0 g
s
.54846 .74315 m .54846 .76168 L .5244 .76733 L p .707 .577 .707 r
F P
0 g
s
.49044 .26354 m .49044 .76543 L .53538 .76433 L p .707 .577 .707 r
F P
0 g
s
.53538 .76433 m .53538 .26245 L .49044 .26354 L p .707 .577 .707 r
F P
0 g
s
.70485 .65862 m .70485 .71421 L .70195 .70566 L p .707 .577 .707 r
F P
0 g
s
.70195 .70566 m .70195 .65008 L .70485 .65862 L p .707 .577 .707 r
F P
0 g
s
.69777 .77653 m .69777 .79506 L .70485 .78669 L p .707 .577 .707 r
F P
0 g
s
.70485 .78669 m .70485 .76817 L .69777 .77653 L p .707 .577 .707 r
F P
0 g
s
.54846 .68919 m .54846 .63361 L .57784 .63023 L p .707 .577 .707 r
F P
0 g
s
.57784 .63023 m .57784 .68581 L .54846 .68919 L p .707 .577 .707 r
F P
0 g
s
.54846 .73656 m .54846 .69951 L .57784 .69613 L p .707 .577 .707 r
F P
0 g
s
.57784 .69613 m .57784 .73318 L .54846 .73656 L p .707 .577 .707 r
F P
0 g
s
.54846 .76168 m .54846 .74315 L .57784 .73977 L p .707 .577 .707 r
F P
0 g
s
.57784 .73977 m .57784 .7583 L .54846 .76168 L p .707 .577 .707 r
F P
0 g
s
.53538 .26245 m .53538 .76433 L .57686 .75956 L p .707 .577 .707 r
F P
0 g
s
.57686 .75956 m .57686 .25768 L .53538 .26245 L p .707 .577 .707 r
F P
0 g
s
.44643 .76275 m .44643 .26086 L .40766 .25466 L p .707 .577 .707 r
F P
0 g
s
.44643 .26086 m .44643 .76275 L .49044 .76543 L p .707 .577 .707 r
F P
0 g
s
.57784 .68581 m .57784 .63023 L .60968 .62945 L p .707 .577 .707 r
F P
0 g
s
.60968 .62945 m .60968 .68503 L .57784 .68581 L p .707 .577 .707 r
F P
0 g
s
.57784 .73318 m .57784 .69613 L .60968 .69535 L p .707 .577 .707 r
F P
0 g
s
.60968 .69535 m .60968 .7324 L .57784 .73318 L p .707 .577 .707 r
F P
0 g
s
.60968 .75752 m .60968 .73899 L .64085 .7409 L p .707 .577 .707 r
F P
0 g
s
.57784 .7583 m .57784 .73977 L .60968 .73899 L p .707 .577 .707 r
F P
0 g
s
.60968 .73899 m .60968 .75752 L .57784 .7583 L p .707 .577 .707 r
F P
0 g
s
.57686 .25768 m .57686 .75956 L .61082 .75159 L p .707 .577 .707 r
F P
0 g
s
.64085 .63135 m .64085 .68693 L .60968 .68503 L p .707 .577 .707 r
F P
0 g
s
.60968 .68503 m .60968 .62945 L .64085 .63135 L p .707 .577 .707 r
F P
0 g
s
.64085 .69725 m .64085 .7343 L .60968 .7324 L p .707 .577 .707 r
F P
0 g
s
.60968 .7324 m .60968 .69535 L .64085 .69725 L p .707 .577 .707 r
F P
0 g
s
.61082 .75159 m .61082 .2497 L .57686 .25768 L p .707 .577 .707 r
F P
0 g
s
.70485 .72452 m .70485 .76158 L .70195 .75303 L p .707 .577 .707 r
F P
0 g
s
.70195 .75303 m .70195 .71598 L .70485 .72452 L p .707 .577 .707 r
F P
0 g
s
.40766 .75655 m .40766 .25466 L .37794 .24555 L p .707 .577 .707 r
F P
0 g
s
.40766 .25466 m .40766 .75655 L .44643 .76275 L p .707 .577 .707 r
F P
0 g
s
.70485 .76817 m .70485 .78669 L .70195 .77815 L p .707 .577 .707 r
F P
0 g
s
.70195 .77815 m .70195 .75963 L .70485 .76817 L p .707 .577 .707 r
F P
0 g
s
.70195 .65008 m .70195 .70566 L .68936 .69778 L p .707 .577 .707 r
F P
0 g
s
.68936 .69778 m .68936 .6422 L .70195 .65008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.25312 .70293 m .25312 .64735 L .22195 .64545 L p .707 .577 .707 r
F P
0 g
s
.25312 .64735 m .25312 .70293 L .28495 .70215 L p .707 .577 .707 r
F P
0 g
s
.28495 .70215 m .28495 .64657 L .25312 .64735 L p .707 .577 .707 r
F P
0 g
s
.28495 .64657 m .28495 .70215 L .31434 .69877 L p .707 .577 .707 r
F P
0 g
s
.31434 .69877 m .31434 .64319 L .28495 .64657 L p .707 .577 .707 r
F P
0 g
s
.61082 .2497 m .61082 .75159 L .63393 .74119 L p .707 .577 .707 r
F P
0 g
s
.63393 .74119 m .63393 .2393 L .61082 .2497 L p .707 .577 .707 r
F P
0 g
s
.22195 .70103 m .22195 .64545 L .19449 .64105 L p .707 .577 .707 r
F P
0 g
s
.22195 .64545 m .22195 .70103 L .25312 .70293 L p .707 .577 .707 r
F P
0 g
s
.70195 .71598 m .70195 .75303 L .68936 .74515 L p .707 .577 .707 r
F P
0 g
s
.68936 .74515 m .68936 .7081 L .70195 .71598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31434 .64319 m .31434 .69877 L .33839 .69312 L p .707 .577 .707 r
F P
0 g
s
.33839 .69312 m .33839 .63754 L .31434 .64319 L p .707 .577 .707 r
F P
0 g
s
.25312 .7503 m .25312 .71324 L .22195 .71134 L p .707 .577 .707 r
F P
0 g
s
.25312 .71324 m .25312 .7503 L .28495 .74952 L p .707 .577 .707 r
F P
0 g
s
.28495 .74952 m .28495 .71247 L .25312 .71324 L p .707 .577 .707 r
F P
0 g
s
.68936 .6422 m .68936 .69778 L .66831 .69133 L p .707 .577 .707 r
F P
0 g
s
.66831 .69133 m .66831 .63574 L .68936 .6422 L p .707 .577 .707 r
F P
0 g
s
.70195 .75963 m .70195 .77815 L .68936 .77027 L p .707 .577 .707 r
F P
0 g
s
.68936 .77027 m .68936 .75174 L .70195 .75963 L p .707 .577 .707 r
F P
0 g
s
.37794 .74744 m .37794 .24555 L .36016 .23442 L p .707 .577 .707 r
F P
0 g
s
.37794 .24555 m .37794 .74744 L .40766 .75655 L p .707 .577 .707 r
F P
0 g
s
.28495 .71247 m .28495 .74952 L .31434 .74614 L p .707 .577 .707 r
F P
0 g
s
.31434 .74614 m .31434 .70909 L .28495 .71247 L p .707 .577 .707 r
F P
0 g
s
.19449 .64105 m .19449 .69664 L .22195 .70103 L p .707 .577 .707 r
F P
0 g
s
.19449 .69664 m .19449 .64105 L .17343 .6346 L p .707 .577 .707 r
F P
0 g
s
.22195 .7484 m .22195 .71134 L .19449 .70695 L p .707 .577 .707 r
F P
0 g
s
.22195 .71134 m .22195 .7484 L .25312 .7503 L p .707 .577 .707 r
F P
0 g
s
.25312 .77542 m .25312 .75689 L .22195 .75499 L p .707 .577 .707 r
F P
0 g
s
.25312 .75689 m .25312 .77542 L .28495 .77464 L p .707 .577 .707 r
F P
0 g
s
.28495 .77464 m .28495 .75611 L .25312 .75689 L p .707 .577 .707 r
F P
0 g
s
.31434 .70909 m .31434 .74614 L .33839 .74049 L p .707 .577 .707 r
F P
0 g
s
.33839 .74049 m .33839 .70344 L .31434 .70909 L p .707 .577 .707 r
F P
0 g
s
.28495 .75611 m .28495 .77464 L .31434 .77126 L p .707 .577 .707 r
F P
0 g
s
.31434 .77126 m .31434 .75273 L .28495 .75611 L p .707 .577 .707 r
F P
0 g
s
.33839 .63754 m .33839 .69312 L .35476 .68576 L p .707 .577 .707 r
F P
0 g
s
.35476 .68576 m .35476 .63017 L .33839 .63754 L p .707 .577 .707 r
F P
0 g
s
.19449 .70695 m .19449 .74401 L .22195 .7484 L p .707 .577 .707 r
F P
0 g
s
.22195 .75499 m .22195 .77352 L .25312 .77542 L p .707 .577 .707 r
F P
0 g
s
.68936 .7081 m .68936 .74515 L .66831 .7387 L p .707 .577 .707 r
F P
0 g
s
.66831 .7387 m .66831 .70164 L .68936 .7081 L p .707 .577 .707 r
F P
0 g
s
.22195 .77352 m .22195 .75499 L .19449 .7506 L p .707 .577 .707 r
F P
0 g
s
.17343 .6346 m .17343 .69018 L .19449 .69664 L p .707 .577 .707 r
F P
0 g
s
.19449 .74401 m .19449 .70695 L .17343 .7005 L p .707 .577 .707 r
F P
0 g
s
.66831 .63574 m .66831 .69133 L .64085 .68693 L p .707 .577 .707 r
F P
0 g
s
.64085 .68693 m .64085 .63135 L .66831 .63574 L p .707 .577 .707 r
F P
0 g
s
.19449 .7506 m .19449 .76912 L .22195 .77352 L p .707 .577 .707 r
F P
0 g
s
.64085 .7343 m .64085 .69725 L .66831 .70164 L p .707 .577 .707 r
F P
0 g
s
.63393 .2393 m .63393 .74119 L .64393 .72938 L p .707 .577 .707 r
F P
0 g
s
.64393 .72938 m .64393 .22749 L .63393 .2393 L p .707 .577 .707 r
F P
0 g
s
.31434 .75273 m .31434 .77126 L .33839 .76561 L p .707 .577 .707 r
F P
0 g
s
.33839 .76561 m .33839 .74708 L .31434 .75273 L p .707 .577 .707 r
F P
0 g
s
.17343 .69018 m .17343 .6346 L .16084 .62672 L p .707 .577 .707 r
F P
0 g
s
.68936 .75174 m .68936 .77027 L .66831 .76381 L p .707 .577 .707 r
F P
0 g
s
.66831 .76381 m .66831 .74529 L .68936 .75174 L p .707 .577 .707 r
F P
0 g
s
.17343 .7005 m .17343 .73755 L .19449 .74401 L p .707 .577 .707 r
F P
0 g
s
.19449 .76912 m .19449 .7506 L .17343 .74414 L p .707 .577 .707 r
F P
0 g
s
.33839 .70344 m .33839 .74049 L .35476 .73313 L p .707 .577 .707 r
F P
0 g
s
.35476 .73313 m .35476 .69607 L .33839 .70344 L p .707 .577 .707 r
F P
0 g
s
.17343 .74414 m .17343 .76267 L .19449 .76912 L p .707 .577 .707 r
F P
0 g
s
.66831 .70164 m .66831 .7387 L .64085 .7343 L p .707 .577 .707 r
F P
0 g
s
.35476 .63017 m .35476 .68576 L .36184 .67739 L p .707 .577 .707 r
F P
0 g
s
.36184 .67739 m .36184 .62181 L .35476 .63017 L p .707 .577 .707 r
F P
0 g
s
.35476 .69607 m .35476 .73313 L .36184 .72476 L p .707 .577 .707 r
F P
0 g
s
.36184 .72476 m .36184 .68771 L .35476 .69607 L p .707 .577 .707 r
F P
0 g
s
.36184 .62181 m .36184 .67739 L .35894 .66885 L p .707 .577 .707 r
F P
0 g
s
.35894 .66885 m .35894 .61327 L .36184 .62181 L p .707 .577 .707 r
F P
0 g
s
.36184 .74988 m .36184 .73135 L .35476 .73972 L p .707 .577 .707 r
F P
0 g
s
.36184 .68771 m .36184 .72476 L .35894 .71622 L p .707 .577 .707 r
F P
0 g
s
.35894 .71622 m .35894 .67916 L .36184 .68771 L p .707 .577 .707 r
F P
0 g
s
.35894 .74134 m .35894 .72281 L .36184 .73135 L p .707 .577 .707 r
F P
0 g
s
.36016 .73631 m .36016 .23442 L .35607 .22236 L p .707 .577 .707 r
F P
0 g
s
.36184 .73135 m .36184 .74988 L .35894 .74134 L p .707 .577 .707 r
F P
0 g
s
.36016 .23442 m .36016 .73631 L .37794 .74744 L p .707 .577 .707 r
F P
0 g
s
.16084 .62672 m .16084 .6823 L .17343 .69018 L p .707 .577 .707 r
F P
0 g
s
.17343 .73755 m .17343 .7005 L .16084 .69261 L p .707 .577 .707 r
F P
0 g
s
.33839 .74708 m .33839 .76561 L .35476 .75824 L p .707 .577 .707 r
F P
0 g
s
.35476 .75824 m .35476 .73972 L .33839 .74708 L p .707 .577 .707 r
F P
0 g
s
.66831 .74529 m .66831 .76381 L .64085 .75942 L p .707 .577 .707 r
F P
0 g
s
.64085 .75942 m .64085 .7409 L .66831 .74529 L p .707 .577 .707 r
F P
0 g
s
.16084 .6823 m .16084 .62672 L .15794 .61817 L p .707 .577 .707 r
F P
0 g
s
.16084 .69261 m .16084 .72967 L .17343 .73755 L p .707 .577 .707 r
F P
0 g
s
.17343 .76267 m .17343 .74414 L .16084 .73626 L p .707 .577 .707 r
F P
0 g
s
.16084 .73626 m .16084 .75479 L .17343 .76267 L p .707 .577 .707 r
F P
0 g
s
.64393 .22749 m .64393 .72938 L .63984 .71732 L p .707 .577 .707 r
F P
0 g
s
.63984 .71732 m .63984 .21543 L .64393 .22749 L p .707 .577 .707 r
F P
0 g
s
.64085 .7409 m .64085 .75942 L .60968 .75752 L p .707 .577 .707 r
F P
0 g
s
.15794 .61817 m .15794 .67376 L .16084 .6823 L p .707 .577 .707 r
F P
0 g
s
.35476 .73972 m .35476 .75824 L .36184 .74988 L p .707 .577 .707 r
F P
0 g
s
.16084 .72967 m .16084 .69261 L .15794 .68407 L p .707 .577 .707 r
F P
0 g
s
.15794 .68407 m .15794 .72113 L .16084 .72967 L p .707 .577 .707 r
F P
0 g
s
.35894 .61327 m .35894 .66885 L .34635 .66097 L p .707 .577 .707 r
F P
0 g
s
.34635 .66097 m .34635 .60538 L .35894 .61327 L p .707 .577 .707 r
F P
0 g
s
.35894 .67916 m .35894 .71622 L .34635 .70834 L p .707 .577 .707 r
F P
0 g
s
.34635 .70834 m .34635 .67128 L .35894 .67916 L p .707 .577 .707 r
F P
0 g
s
.35894 .72281 m .35894 .74134 L .34635 .73345 L p .707 .577 .707 r
F P
0 g
s
.34635 .73345 m .34635 .71493 L .35894 .72281 L p .707 .577 .707 r
F P
0 g
s
.35607 .22236 m .35607 .72425 L .36016 .73631 L p .707 .577 .707 r
F P
0 g
s
.35607 .72425 m .35607 .22236 L .36607 .21055 L p .707 .577 .707 r
F P
0 g
s
.16084 .75479 m .16084 .73626 L .15794 .72772 L p .707 .577 .707 r
F P
0 g
s
.15794 .67376 m .15794 .61817 L .16503 .60981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15794 .72772 m .15794 .74624 L .16084 .75479 L p .707 .577 .707 r
F P
0 g
s
.16503 .60981 m .16503 .66539 L .15794 .67376 L p .707 .577 .707 r
F P
0 g
s
.15794 .72113 m .15794 .68407 L .16503 .67571 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63984 .21543 m .63984 .71732 L .62206 .70619 L p .707 .577 .707 r
F P
0 g
s
.62206 .70619 m .62206 .2043 L .63984 .21543 L p .707 .577 .707 r
F P
0 g
s
.16503 .67571 m .16503 .71276 L .15794 .72113 L p .707 .577 .707 r
F P
0 g
s
.16503 .66539 m .16503 .60981 L .1814 .60244 L p .707 .577 .707 r
F P
0 g
s
.15794 .74624 m .15794 .72772 L .16503 .71935 L p .707 .577 .707 r
F P
0 g
s
.16503 .71935 m .16503 .73788 L .15794 .74624 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36607 .71244 m .36607 .21055 L .38918 .20015 L p .707 .577 .707 r
F P
0 g
s
.36607 .21055 m .36607 .71244 L .35607 .72425 L p .707 .577 .707 r
F P
0 g
s
.1814 .60244 m .1814 .65802 L .16503 .66539 L p .707 .577 .707 r
F P
0 g
s
.34635 .60538 m .34635 .66097 L .3253 .65451 L p .707 .577 .707 r
F P
0 g
s
.3253 .65451 m .3253 .59893 L .34635 .60538 L p .707 .577 .707 r
F P
0 g
s
.16503 .71276 m .16503 .67571 L .1814 .66834 L p .707 .577 .707 r
F P
0 g
s
.1814 .65802 m .1814 .60244 L .20545 .59679 L p .707 .577 .707 r
F P
0 g
s
.1814 .66834 m .1814 .70539 L .16503 .71276 L p .707 .577 .707 r
F P
0 g
s
.16503 .73788 m .16503 .71935 L .1814 .71199 L p .707 .577 .707 r
F P
0 g
s
.34635 .67128 m .34635 .70834 L .3253 .70188 L p .707 .577 .707 r
F P
0 g
s
.3253 .70188 m .3253 .66483 L .34635 .67128 L p .707 .577 .707 r
F P
0 g
s
.62206 .2043 m .62206 .70619 L .59233 .69708 L p .707 .577 .707 r
F P
0 g
s
.59233 .69708 m .59233 .19519 L .62206 .2043 L p .707 .577 .707 r
F P
0 g
s
.1814 .71199 m .1814 .73051 L .16503 .73788 L p .707 .577 .707 r
F P
0 g
s
.3253 .59893 m .3253 .65451 L .29784 .65012 L p .707 .577 .707 r
F P
0 g
s
.29784 .65012 m .29784 .59454 L .3253 .59893 L p .707 .577 .707 r
F P
0 g
s
.20545 .59679 m .20545 .65237 L .1814 .65802 L p .707 .577 .707 r
F P
0 g
s
.1814 .70539 m .1814 .66834 L .20545 .66269 L p .707 .577 .707 r
F P
0 g
s
.34635 .71493 m .34635 .73345 L .3253 .727 L p .707 .577 .707 r
F P
0 g
s
.3253 .727 m .3253 .70847 L .34635 .71493 L p .707 .577 .707 r
F P
0 g
s
.20545 .65237 m .20545 .59679 L .23483 .59341 L p .707 .577 .707 r
F P
0 g
s
.38918 .20015 m .38918 .70204 L .36607 .71244 L p .707 .577 .707 r
F P
0 g
s
.38918 .70204 m .38918 .20015 L .42314 .19217 L p .707 .577 .707 r
F P
0 g
s
.29784 .59454 m .29784 .65012 L .26667 .64822 L p .707 .577 .707 r
F P
0 g
s
.26667 .64822 m .26667 .59264 L .29784 .59454 L p .707 .577 .707 r
F P
0 g
s
.20545 .66269 m .20545 .69974 L .1814 .70539 L p .707 .577 .707 r
F P
0 g
s
.1814 .73051 m .1814 .71199 L .20545 .70634 L p .707 .577 .707 r
F P
0 g
s
.3253 .66483 m .3253 .70188 L .29784 .69749 L p .707 .577 .707 r
F P
0 g
s
.29784 .69749 m .29784 .66043 L .3253 .66483 L p .707 .577 .707 r
F P
0 g
s
.23483 .649 m .23483 .59341 L .26667 .59264 L p .707 .577 .707 r
F P
0 g
s
.23483 .59341 m .23483 .649 L .20545 .65237 L p .707 .577 .707 r
F P
0 g
s
.26667 .59264 m .26667 .64822 L .23483 .649 L p .707 .577 .707 r
F P
0 g
s
.20545 .70634 m .20545 .72486 L .1814 .73051 L p .707 .577 .707 r
F P
0 g
s
.73333 .64771 m .73333 .59212 L .70216 .59022 L p .707 .577 .707 r
F P
0 g
s
.73333 .59212 m .73333 .64771 L .76517 .64693 L p .707 .577 .707 r
F P
0 g
s
.76517 .64693 m .76517 .59135 L .73333 .59212 L p .707 .577 .707 r
F P
0 g
s
.20545 .69974 m .20545 .66269 L .23483 .65931 L p .707 .577 .707 r
F P
0 g
s
.76517 .59135 m .76517 .64693 L .79455 .64355 L p .707 .577 .707 r
F P
0 g
s
.79455 .64355 m .79455 .58797 L .76517 .59135 L p .707 .577 .707 r
F P
0 g
s
.59233 .19519 m .59233 .69708 L .55357 .69088 L p .707 .577 .707 r
F P
0 g
s
.55357 .69088 m .55357 .18899 L .59233 .19519 L p .707 .577 .707 r
F P
0 g
s
.3253 .70847 m .3253 .727 L .29784 .72261 L p .707 .577 .707 r
F P
0 g
s
.29784 .72261 m .29784 .70408 L .3253 .70847 L p .707 .577 .707 r
F P
0 g
s
.70216 .64581 m .70216 .59022 L .6747 .58583 L p .707 .577 .707 r
F P
0 g
s
.70216 .59022 m .70216 .64581 L .73333 .64771 L p .707 .577 .707 r
F P
0 g
s
.29784 .66043 m .29784 .69749 L .26667 .69559 L p .707 .577 .707 r
F P
0 g
s
.26667 .69559 m .26667 .65853 L .29784 .66043 L p .707 .577 .707 r
F P
0 g
s
.23483 .65931 m .23483 .69637 L .20545 .69974 L p .707 .577 .707 r
F P
0 g
s
.23483 .69637 m .23483 .65931 L .26667 .65853 L p .707 .577 .707 r
F P
0 g
s
.20545 .72486 m .20545 .70634 L .23483 .70296 L p .707 .577 .707 r
F P
0 g
s
.42314 .69406 m .42314 .19217 L .46462 .1874 L p .707 .577 .707 r
F P
0 g
s
.42314 .19217 m .42314 .69406 L .38918 .70204 L p .707 .577 .707 r
F P
0 g
s
.79455 .58797 m .79455 .64355 L .8186 .6379 L p .707 .577 .707 r
F P
0 g
s
.8186 .6379 m .8186 .58232 L .79455 .58797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65853 m .26667 .69559 L .23483 .69637 L p .707 .577 .707 r
F P
0 g
s
.73333 .69508 m .73333 .65802 L .70216 .65612 L p .707 .577 .707 r
F P
0 g
s
.73333 .65802 m .73333 .69508 L .76517 .6943 L p .707 .577 .707 r
F P
0 g
s
.76517 .6943 m .76517 .65724 L .73333 .65802 L p .707 .577 .707 r
F P
0 g
s
.23483 .70296 m .23483 .72148 L .20545 .72486 L p .707 .577 .707 r
F P
0 g
s
.76517 .65724 m .76517 .6943 L .79455 .69092 L p .707 .577 .707 r
F P
0 g
s
.79455 .69092 m .79455 .65387 L .76517 .65724 L p .707 .577 .707 r
F P
0 g
s
.29784 .70408 m .29784 .72261 L .26667 .72071 L p .707 .577 .707 r
F P
0 g
s
.26667 .72071 m .26667 .70218 L .29784 .70408 L p .707 .577 .707 r
F P
0 g
s
.6747 .58583 m .6747 .64141 L .70216 .64581 L p .707 .577 .707 r
F P
0 g
s
.6747 .64141 m .6747 .58583 L .65365 .57938 L p .707 .577 .707 r
F P
0 g
s
.70216 .69318 m .70216 .65612 L .6747 .65173 L p .707 .577 .707 r
F P
0 g
s
.70216 .65612 m .70216 .69318 L .73333 .69508 L p .707 .577 .707 r
F P
0 g
s
.55357 .18899 m .55357 .69088 L .50956 .68819 L p .707 .577 .707 r
F P
0 g
s
.50956 .68819 m .50956 .1863 L .55357 .18899 L p .707 .577 .707 r
F P
0 g
s
.23483 .72148 m .23483 .70296 L .26667 .70218 L p .707 .577 .707 r
F P
0 g
s
.26667 .70218 m .26667 .72071 L .23483 .72148 L p .707 .577 .707 r
F P
0 g
s
.73333 .72019 m .73333 .70167 L .70216 .69977 L p .707 .577 .707 r
F P
0 g
s
.73333 .70167 m .73333 .72019 L .76517 .71942 L p .707 .577 .707 r
F P
0 g
s
.76517 .71942 m .76517 .70089 L .73333 .70167 L p .707 .577 .707 r
F P
0 g
s
.46462 .68929 m .46462 .1874 L .50956 .1863 L p .707 .577 .707 r
F P
0 g
s
.46462 .1874 m .46462 .68929 L .42314 .69406 L p .707 .577 .707 r
F P
0 g
s
.79455 .65387 m .79455 .69092 L .8186 .68527 L p .707 .577 .707 r
F P
0 g
s
.8186 .68527 m .8186 .64822 L .79455 .65387 L p .707 .577 .707 r
F P
0 g
s
.76517 .70089 m .76517 .71942 L .79455 .71604 L p .707 .577 .707 r
F P
0 g
s
.79455 .71604 m .79455 .69751 L .76517 .70089 L p .707 .577 .707 r
F P
0 g
s
.8186 .58232 m .8186 .6379 L .83497 .63053 L p .707 .577 .707 r
F P
0 g
s
.83497 .63053 m .83497 .57495 L .8186 .58232 L p .707 .577 .707 r
F P
0 g
s
.50956 .1863 m .50956 .68819 L .46462 .68929 L p .707 .577 .707 r
F P
0 g
s
.6747 .65173 m .6747 .68878 L .70216 .69318 L p .707 .577 .707 r
F P
0 g
s
.70216 .69977 m .70216 .71829 L .73333 .72019 L p .707 .577 .707 r
F P
0 g
s
.70216 .71829 m .70216 .69977 L .6747 .69537 L p .707 .577 .707 r
F P
0 g
s
.65365 .57938 m .65365 .63496 L .6747 .64141 L p .707 .577 .707 r
F P
0 g
s
.6747 .68878 m .6747 .65173 L .65365 .64528 L p .707 .577 .707 r
F P
0 g
s
.6747 .69537 m .6747 .7139 L .70216 .71829 L p .707 .577 .707 r
F P
0 g
s
.79455 .69751 m .79455 .71604 L .8186 .71039 L p .707 .577 .707 r
F P
0 g
s
.8186 .71039 m .8186 .69186 L .79455 .69751 L p .707 .577 .707 r
F P
0 g
s
.65365 .63496 m .65365 .57938 L .64105 .57149 L p .707 .577 .707 r
F P
0 g
s
.65365 .64528 m .65365 .68233 L .6747 .68878 L p .707 .577 .707 r
F P
0 g
s
.6747 .7139 m .6747 .69537 L .65365 .68892 L p .707 .577 .707 r
F P
0 g
s
.8186 .64822 m .8186 .68527 L .83497 .6779 L p .707 .577 .707 r
F P
0 g
s
.83497 .6779 m .83497 .64085 L .8186 .64822 L p .707 .577 .707 r
F P
0 g
s
.65365 .68892 m .65365 .70745 L .6747 .7139 L p .707 .577 .707 r
F P
0 g
s
.64105 .57149 m .64105 .62708 L .65365 .63496 L p .707 .577 .707 r
F P
0 g
s
.83497 .57495 m .83497 .63053 L .84205 .62217 L p .707 .577 .707 r
F P
0 g
s
.84205 .62217 m .84205 .56659 L .83497 .57495 L p .707 .577 .707 r
F P
0 g
s
.65365 .68233 m .65365 .64528 L .64105 .63739 L p .707 .577 .707 r
F P
0 g
s
.8186 .69186 m .8186 .71039 L .83497 .70302 L p .707 .577 .707 r
F P
0 g
s
.83497 .70302 m .83497 .68449 L .8186 .69186 L p .707 .577 .707 r
F P
0 g
s
.64105 .62708 m .64105 .57149 L .63816 .56295 L p .707 .577 .707 r
F P
0 g
s
.64105 .63739 m .64105 .67445 L .65365 .68233 L p .707 .577 .707 r
F P
0 g
s
.65365 .70745 m .65365 .68892 L .64105 .68104 L p .707 .577 .707 r
F P
0 g
s
.83497 .64085 m .83497 .6779 L .84206 .66954 L p .707 .577 .707 r
F P
0 g
s
.84206 .66954 m .84205 .63248 L .83497 .64085 L p .707 .577 .707 r
F P
0 g
s
.64105 .68104 m .64105 .69956 L .65365 .70745 L p .707 .577 .707 r
F P
0 g
s
.63816 .56295 m .63816 .61853 L .64105 .62708 L p .707 .577 .707 r
F P
0 g
s
.84205 .56659 m .84205 .62217 L .83916 .61363 L p .707 .577 .707 r
F P
0 g
s
.83916 .61363 m .83916 .55804 L .84205 .56659 L p .707 .577 .707 r
F P
0 g
s
.83497 .68449 m .83497 .70302 L .84206 .69466 L p .707 .577 .707 r
F P
0 g
s
.84206 .69466 m .84206 .67613 L .83497 .68449 L p .707 .577 .707 r
F P
0 g
s
.64105 .67445 m .64105 .63739 L .63816 .62885 L p .707 .577 .707 r
F P
0 g
s
.63816 .62885 m .63816 .6659 L .64105 .67445 L p .707 .577 .707 r
F P
0 g
s
.64105 .69956 m .64105 .68104 L .63816 .67249 L p .707 .577 .707 r
F P
0 g
s
.63816 .61853 m .63816 .56295 L .64524 .55459 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .67249 m .63816 .69102 L .64105 .69956 L p .707 .577 .707 r
F P
0 g
s
.84205 .63248 m .84206 .66954 L .83916 .661 L p .707 .577 .707 r
F P
0 g
s
.83916 .661 m .83916 .62394 L .84205 .63248 L p .707 .577 .707 r
F P
0 g
s
.64524 .55459 m .64524 .61017 L .63816 .61853 L p .707 .577 .707 r
F P
0 g
s
.84206 .67613 m .84206 .69466 L .83916 .68611 L p .707 .577 .707 r
F P
0 g
s
.83916 .68611 m .83916 .66759 L .84206 .67613 L p .707 .577 .707 r
F P
0 g
s
.83916 .55804 m .83916 .61363 L .82657 .60574 L p .707 .577 .707 r
F P
0 g
s
.82657 .60574 m .82657 .55016 L .83916 .55804 L p .707 .577 .707 r
F P
0 g
s
.63816 .6659 m .63816 .62885 L .64524 .62048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39032 .61089 m .39032 .55531 L .35915 .55341 L p .707 .577 .707 r
F P
0 g
s
.39032 .55531 m .39032 .61089 L .42216 .61011 L p .707 .577 .707 r
F P
0 g
s
.42216 .61011 m .42216 .55453 L .39032 .55531 L p .707 .577 .707 r
F P
0 g
s
.64524 .62048 m .64524 .65754 L .63816 .6659 L p .707 .577 .707 r
F P
0 g
s
.64524 .61017 m .64524 .55459 L .66161 .54722 L p .707 .577 .707 r
F P
0 g
s
.42216 .55453 m .42216 .61011 L .45154 .60673 L p .707 .577 .707 r
F P
0 g
s
.45154 .60673 m .45154 .55115 L .42216 .55453 L p .707 .577 .707 r
F P
0 g
s
.63816 .69102 m .63816 .67249 L .64524 .66413 L p .707 .577 .707 r
F P
0 g
s
.35915 .60899 m .35915 .55341 L .33169 .54902 L p .707 .577 .707 r
F P
0 g
s
.35915 .55341 m .35915 .60899 L .39032 .61089 L p .707 .577 .707 r
F P
0 g
s
.64524 .66413 m .64524 .68266 L .63816 .69102 L p .707 .577 .707 r
F P
0 g
s
.83916 .62394 m .83916 .661 L .82657 .65311 L p .707 .577 .707 r
F P
0 g
s
.82657 .65311 m .82657 .61606 L .83916 .62394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .55115 m .45154 .60673 L .47559 .60109 L p .707 .577 .707 r
F P
0 g
s
.47559 .60109 m .47559 .5455 L .45154 .55115 L p .707 .577 .707 r
F P
0 g
s
.66161 .54722 m .66161 .6028 L .64524 .61017 L p .707 .577 .707 r
F P
0 g
s
.39032 .65826 m .39032 .62121 L .35915 .61931 L p .707 .577 .707 r
F P
0 g
s
.39032 .62121 m .39032 .65826 L .42216 .65748 L p .707 .577 .707 r
F P
0 g
s
.42216 .65748 m .42216 .62043 L .39032 .62121 L p .707 .577 .707 r
F P
0 g
s
.82657 .55016 m .82657 .60574 L .80551 .59929 L p .707 .577 .707 r
F P
0 g
s
.80551 .59929 m .80551 .54371 L .82657 .55016 L p .707 .577 .707 r
F P
0 g
s
.83916 .66759 m .83916 .68611 L .82657 .67823 L p .707 .577 .707 r
F P
0 g
s
.82657 .67823 m .82657 .6597 L .83916 .66759 L p .707 .577 .707 r
F P
0 g
s
.64524 .65754 m .64524 .62048 L .66161 .61312 L p .707 .577 .707 r
F P
0 g
s
.42216 .62043 m .42216 .65748 L .45154 .65411 L p .707 .577 .707 r
F P
0 g
s
.45154 .65411 m .45154 .61705 L .42216 .62043 L p .707 .577 .707 r
F P
0 g
s
.33169 .54902 m .33169 .6046 L .35915 .60899 L p .707 .577 .707 r
F P
0 g
s
.33169 .6046 m .33169 .54902 L .31064 .54256 L p .707 .577 .707 r
F P
0 g
s
.35915 .65636 m .35915 .61931 L .33169 .61491 L p .707 .577 .707 r
F P
0 g
s
.35915 .61931 m .35915 .65636 L .39032 .65826 L p .707 .577 .707 r
F P
0 g
s
.66161 .6028 m .66161 .54722 L .68566 .54157 L p .707 .577 .707 r
F P
0 g
s
.39032 .68338 m .39032 .66485 L .35915 .66295 L p .707 .577 .707 r
F P
0 g
s
.39032 .66485 m .39032 .68338 L .42216 .6826 L p .707 .577 .707 r
F P
0 g
s
.42216 .6826 m .42216 .66407 L .39032 .66485 L p .707 .577 .707 r
F P
0 g
s
.66161 .61312 m .66161 .65017 L .64524 .65754 L p .707 .577 .707 r
F P
0 g
s
.64524 .68266 m .64524 .66413 L .66161 .65676 L p .707 .577 .707 r
F P
0 g
s
.45154 .61705 m .45154 .65411 L .47559 .64846 L p .707 .577 .707 r
F P
0 g
s
.47559 .64846 m .47559 .6114 L .45154 .61705 L p .707 .577 .707 r
F P
0 g
s
.42216 .66407 m .42216 .6826 L .45154 .67922 L p .707 .577 .707 r
F P
0 g
s
.45154 .67922 m .45154 .6607 L .42216 .66407 L p .707 .577 .707 r
F P
0 g
s
.47559 .5455 m .47559 .60109 L .49196 .59372 L p .707 .577 .707 r
F P
0 g
s
.49196 .59372 m .49196 .53813 L .47559 .5455 L p .707 .577 .707 r
F P
0 g
s
.33169 .61491 m .33169 .65197 L .35915 .65636 L p .707 .577 .707 r
F P
0 g
s
.35915 .66295 m .35915 .68148 L .39032 .68338 L p .707 .577 .707 r
F P
0 g
s
.82657 .61606 m .82657 .65311 L .80551 .64666 L p .707 .577 .707 r
F P
0 g
s
.80551 .64666 m .80551 .6096 L .82657 .61606 L p .707 .577 .707 r
F P
0 g
s
.35915 .68148 m .35915 .66295 L .33169 .65856 L p .707 .577 .707 r
F P
0 g
s
.31064 .54256 m .31064 .59814 L .33169 .6046 L p .707 .577 .707 r
F P
0 g
s
.66161 .65676 m .66161 .67529 L .64524 .68266 L p .707 .577 .707 r
F P
0 g
s
.33169 .65197 m .33169 .61491 L .31064 .60846 L p .707 .577 .707 r
F P
0 g
s
.80551 .54371 m .80551 .59929 L .77805 .5949 L p .707 .577 .707 r
F P
0 g
s
.77805 .5949 m .77805 .53931 L .80551 .54371 L p .707 .577 .707 r
F P
0 g
s
.33169 .65856 m .33169 .67709 L .35915 .68148 L p .707 .577 .707 r
F P
0 g
s
.68566 .54157 m .68566 .59715 L .66161 .6028 L p .707 .577 .707 r
F P
0 g
s
.45154 .6607 m .45154 .67922 L .47559 .67357 L p .707 .577 .707 r
F P
0 g
s
.47559 .67357 m .47559 .65505 L .45154 .6607 L p .707 .577 .707 r
F P
0 g
s
.31064 .59814 m .31064 .54256 L .29804 .53468 L p .707 .577 .707 r
F P
0 g
s
.66161 .65017 m .66161 .61312 L .68566 .60747 L p .707 .577 .707 r
F P
0 g
s
.82657 .6597 m .82657 .67823 L .80551 .67178 L p .707 .577 .707 r
F P
0 g
s
.80551 .67178 m .80551 .65325 L .82657 .6597 L p .707 .577 .707 r
F P
0 g
s
.68566 .59715 m .68566 .54157 L .71504 .53819 L p .707 .577 .707 r
F P
0 g
s
.31064 .60846 m .31064 .64551 L .33169 .65197 L p .707 .577 .707 r
F P
0 g
s
.33169 .67709 m .33169 .65856 L .31064 .6521 L p .707 .577 .707 r
F P
0 g
s
.47559 .6114 m .47559 .64846 L .49196 .64109 L p .707 .577 .707 r
F P
0 g
s
.49196 .64109 m .49196 .60403 L .47559 .6114 L p .707 .577 .707 r
F P
0 g
s
.77805 .53931 m .77805 .5949 L .74688 .593 L p .707 .577 .707 r
F P
0 g
s
.74688 .593 m .74688 .53741 L .77805 .53931 L p .707 .577 .707 r
F P
0 g
s
.68566 .60747 m .68566 .64452 L .66161 .65017 L p .707 .577 .707 r
F P
0 g
s
.31064 .6521 m .31064 .67063 L .33169 .67709 L p .707 .577 .707 r
F P
0 g
s
.66161 .67529 m .66161 .65676 L .68566 .65111 L p .707 .577 .707 r
F P
0 g
s
.80551 .6096 m .80551 .64666 L .77805 .64227 L p .707 .577 .707 r
F P
0 g
s
.77805 .64227 m .77805 .60521 L .80551 .6096 L p .707 .577 .707 r
F P
0 g
s
.29804 .53468 m .29804 .59026 L .31064 .59814 L p .707 .577 .707 r
F P
0 g
s
.71504 .59377 m .71504 .53819 L .74688 .53741 L p .707 .577 .707 r
F P
0 g
s
.71504 .53819 m .71504 .59377 L .68566 .59715 L p .707 .577 .707 r
F P
0 g
s
.49196 .53813 m .49196 .59372 L .49904 .58535 L p .707 .577 .707 r
F P
0 g
s
.49904 .58535 m .49904 .52977 L .49196 .53813 L p .707 .577 .707 r
F P
0 g
s
.31064 .64551 m .31064 .60846 L .29804 .60058 L p .707 .577 .707 r
F P
0 g
s
.74688 .53741 m .74688 .593 L .71504 .59377 L p .707 .577 .707 r
F P
0 g
s
.68566 .65111 m .68566 .66964 L .66161 .67529 L p .707 .577 .707 r
F P
0 g
s
.47559 .65505 m .47559 .67357 L .49196 .66621 L p .707 .577 .707 r
F P
0 g
s
.49196 .66621 m .49196 .64768 L .47559 .65505 L p .707 .577 .707 r
F P
0 g
s
.68566 .64452 m .68566 .60747 L .71504 .60409 L p .707 .577 .707 r
F P
0 g
s
.80551 .65325 m .80551 .67178 L .77805 .66738 L p .707 .577 .707 r
F P
0 g
s
.77805 .66738 m .77805 .64886 L .80551 .65325 L p .707 .577 .707 r
F P
0 g
s
.29804 .59026 m .29804 .53468 L .29515 .52614 L p .707 .577 .707 r
F P
0 g
s
.29804 .60058 m .29804 .63763 L .31064 .64551 L p .707 .577 .707 r
F P
0 g
s
.77805 .60521 m .77805 .64227 L .74688 .64037 L p .707 .577 .707 r
F P
0 g
s
.74688 .64037 m .74688 .60331 L .77805 .60521 L p .707 .577 .707 r
F P
0 g
s
.31064 .67063 m .31064 .6521 L .29804 .64422 L p .707 .577 .707 r
F P
0 g
s
.71504 .60409 m .71504 .64114 L .68566 .64452 L p .707 .577 .707 r
F P
0 g
s
.71504 .64114 m .71504 .60409 L .74688 .60331 L p .707 .577 .707 r
F P
0 g
s
.68566 .66964 m .68566 .65111 L .71504 .64773 L p .707 .577 .707 r
F P
0 g
s
.49196 .60403 m .49196 .64109 L .49904 .63272 L p .707 .577 .707 r
F P
0 g
s
.49904 .63272 m .49904 .59567 L .49196 .60403 L p .707 .577 .707 r
F P
0 g
s
.29804 .64422 m .29804 .66275 L .31064 .67063 L p .707 .577 .707 r
F P
0 g
s
.74688 .60331 m .74688 .64037 L .71504 .64114 L p .707 .577 .707 r
F P
0 g
s
.71504 .64773 m .71504 .66626 L .68566 .66964 L p .707 .577 .707 r
F P
0 g
s
.77805 .64886 m .77805 .66738 L .74688 .66548 L p .707 .577 .707 r
F P
0 g
s
.74688 .66548 m .74688 .64696 L .77805 .64886 L p .707 .577 .707 r
F P
0 g
s
.29515 .52614 m .29515 .58172 L .29804 .59026 L p .707 .577 .707 r
F P
0 g
s
.49904 .52977 m .49904 .58535 L .49615 .57681 L p .707 .577 .707 r
F P
0 g
s
.49615 .57681 m .49615 .52123 L .49904 .52977 L p .707 .577 .707 r
F P
0 g
s
.71504 .66626 m .71504 .64773 L .74688 .64696 L p .707 .577 .707 r
F P
0 g
s
.49196 .64768 m .49196 .66621 L .49904 .65784 L p .707 .577 .707 r
F P
0 g
s
.49904 .65784 m .49904 .63931 L .49196 .64768 L p .707 .577 .707 r
F P
0 g
s
.29804 .63763 m .29804 .60058 L .29515 .59203 L p .707 .577 .707 r
F P
0 g
s
.74688 .64696 m .74688 .66548 L .71504 .66626 L p .707 .577 .707 r
F P
0 g
s
.29515 .59203 m .29515 .62909 L .29804 .63763 L p .707 .577 .707 r
F P
0 g
s
.29804 .66275 m .29804 .64422 L .29515 .63568 L p .707 .577 .707 r
F P
0 g
s
.29515 .58172 m .29515 .52614 L .30223 .51777 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29515 .63568 m .29515 .65421 L .29804 .66275 L p .707 .577 .707 r
F P
0 g
s
.49904 .59567 m .49904 .63272 L .49615 .62418 L p .707 .577 .707 r
F P
0 g
s
.49615 .62418 m .49615 .58713 L .49904 .59567 L p .707 .577 .707 r
F P
0 g
s
.30223 .51777 m .30223 .57335 L .29515 .58172 L p .707 .577 .707 r
F P
0 g
s
.49904 .63931 m .49904 .65784 L .49615 .6493 L p .707 .577 .707 r
F P
0 g
s
.49615 .6493 m .49615 .63077 L .49904 .63931 L p .707 .577 .707 r
F P
0 g
s
.49615 .52123 m .49615 .57681 L .48356 .56893 L p .707 .577 .707 r
F P
0 g
s
.48356 .56893 m .48356 .51334 L .49615 .52123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62909 m .29515 .59203 L .30223 .58367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .58367 m .30223 .62072 L .29515 .62909 L p .707 .577 .707 r
F P
0 g
s
.30223 .57335 m .30223 .51777 L .3186 .5104 L p .707 .577 .707 r
F P
0 g
s
.29515 .65421 m .29515 .63568 L .30223 .62731 L p .707 .577 .707 r
F P
0 g
s
.30223 .62731 m .30223 .64584 L .29515 .65421 L p .707 .577 .707 r
F P
0 g
s
.49615 .58713 m .49615 .62418 L .48356 .6163 L p .707 .577 .707 r
F P
0 g
s
.48356 .6163 m .48356 .57924 L .49615 .58713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .5104 m .3186 .56599 L .30223 .57335 L p .707 .577 .707 r
F P
0 g
s
.48356 .51334 m .48356 .56893 L .4625 .56247 L p .707 .577 .707 r
F P
0 g
s
.4625 .56247 m .4625 .50689 L .48356 .51334 L p .707 .577 .707 r
F P
0 g
s
.49615 .63077 m .49615 .6493 L .48356 .64141 L p .707 .577 .707 r
F P
0 g
s
.48356 .64141 m .48356 .62289 L .49615 .63077 L p .707 .577 .707 r
F P
0 g
s
.30223 .62072 m .30223 .58367 L .3186 .5763 L p .707 .577 .707 r
F P
0 g
s
.3186 .56599 m .3186 .5104 L .34265 .50475 L p .707 .577 .707 r
F P
0 g
s
.3186 .5763 m .3186 .61336 L .30223 .62072 L p .707 .577 .707 r
F P
0 g
s
.30223 .64584 m .30223 .62731 L .3186 .61995 L p .707 .577 .707 r
F P
0 g
s
.48356 .57924 m .48356 .6163 L .4625 .60984 L p .707 .577 .707 r
F P
0 g
s
.4625 .60984 m .4625 .57279 L .48356 .57924 L p .707 .577 .707 r
F P
0 g
s
.3186 .61995 m .3186 .63847 L .30223 .64584 L p .707 .577 .707 r
F P
0 g
s
.4625 .50689 m .4625 .56247 L .43504 .55808 L p .707 .577 .707 r
F P
0 g
s
.43504 .55808 m .43504 .5025 L .4625 .50689 L p .707 .577 .707 r
F P
0 g
s
.34265 .50475 m .34265 .56034 L .3186 .56599 L p .707 .577 .707 r
F P
0 g
s
.3186 .61336 m .3186 .5763 L .34265 .57065 L p .707 .577 .707 r
F P
0 g
s
.48356 .62289 m .48356 .64141 L .4625 .63496 L p .707 .577 .707 r
F P
0 g
s
.4625 .63496 m .4625 .61643 L .48356 .62289 L p .707 .577 .707 r
F P
0 g
s
.34265 .56034 m .34265 .50475 L .37203 .50137 L p .707 .577 .707 r
F P
0 g
s
.43504 .5025 m .43504 .55808 L .40387 .55618 L p .707 .577 .707 r
F P
0 g
s
.40387 .55618 m .40387 .5006 L .43504 .5025 L p .707 .577 .707 r
F P
0 g
s
.34265 .57065 m .34265 .60771 L .3186 .61336 L p .707 .577 .707 r
F P
0 g
s
.3186 .63847 m .3186 .61995 L .34265 .6143 L p .707 .577 .707 r
F P
0 g
s
.4625 .57279 m .4625 .60984 L .43504 .60545 L p .707 .577 .707 r
F P
0 g
s
.43504 .60545 m .43504 .5684 L .4625 .57279 L p .707 .577 .707 r
F P
0 g
s
.37203 .55696 m .37203 .50137 L .40387 .5006 L p .707 .577 .707 r
F P
0 g
s
.37203 .50137 m .37203 .55696 L .34265 .56034 L p .707 .577 .707 r
F P
0 g
s
.40387 .5006 m .40387 .55618 L .37203 .55696 L p .707 .577 .707 r
F P
0 g
s
.34265 .6143 m .34265 .63282 L .3186 .63847 L p .707 .577 .707 r
F P
0 g
s
.34265 .60771 m .34265 .57065 L .37203 .56727 L p .707 .577 .707 r
F P
0 g
s
.4625 .61643 m .4625 .63496 L .43504 .63057 L p .707 .577 .707 r
F P
0 g
s
.43504 .63057 m .43504 .61204 L .4625 .61643 L p .707 .577 .707 r
F P
0 g
s
.43504 .5684 m .43504 .60545 L .40387 .60355 L p .707 .577 .707 r
F P
0 g
s
.40387 .60355 m .40387 .56649 L .43504 .5684 L p .707 .577 .707 r
F P
0 g
s
.37203 .56727 m .37203 .60433 L .34265 .60771 L p .707 .577 .707 r
F P
0 g
s
.37203 .60433 m .37203 .56727 L .40387 .56649 L p .707 .577 .707 r
F P
0 g
s
.34265 .63282 m .34265 .6143 L .37203 .61092 L p .707 .577 .707 r
F P
0 g
s
.40387 .56649 m .40387 .60355 L .37203 .60433 L p .707 .577 .707 r
F P
0 g
s
.37203 .61092 m .37203 .62945 L .34265 .63282 L p .707 .577 .707 r
F P
0 g
s
.43504 .61204 m .43504 .63057 L .40387 .62867 L p .707 .577 .707 r
F P
0 g
s
.40387 .62867 m .40387 .61014 L .43504 .61204 L p .707 .577 .707 r
F P
0 g
s
.37203 .62945 m .37203 .61092 L .40387 .61014 L p .707 .577 .707 r
F P
0 g
s
.40387 .61014 m .40387 .62867 L .37203 .62945 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eo
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001dOol30000
0eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol0071oo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00
001aOol006eoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEUYFFUH3001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061o
o`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000HOol90014Ool005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?Ool90004FUH00`00FUIJEP02FUH8000l
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00008Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000goo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH40006FUH00`00FUIJEP04
FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF0000
15YF1@001eYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00
FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP8000AJEP03
001JEUYF00EJEQT00003FUH005YF00EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH000030005FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000UYF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0002FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000oOolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP@000EJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUH000020006FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF
009JEPT000IJEP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH50002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPd000=JEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEPH00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH000020004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP00FUH20003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P000UYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF000005YF
00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF001oo`0/Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800004FUH000000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP03FUHC0004
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYF
FUH<0004FUHF0004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHH0003FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30002FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50003FUH00`00FUIJEP0:0004FUH00`00FUIJ
EP02FUH80004Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPL000MJEP@000IJEP04001JEP000002FUH30002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH000030003FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPT000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH30003FUH2000]Ool002aoo`03001JEP0000AJEP03001J
EP0000<000IJEP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUH000040003FUH80004
FUH00`00FUIJEP03FUH>0002FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF000000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020002FUH20000
0eYF0000000]Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQH000=JEP03001JEUYF
009JEPH0009JEP05001JEUYF001JEP0:0004FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP<002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF200015YF
00<005YFFUH00eYF2@000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00
;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03
001JEUYF00<002eoo`00;7oo0P000eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEP03001JEUYF
00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`80009JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEP00008000IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<000=JEP04
001JEUYFFUH2000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF200015YF
10001UYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000002FUH2000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH0000B0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30002Ool4000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030003Ool2000015YF00000000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000`00
0UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0017oo0`000eYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF100015YF2@00
35YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF00<005YFFUH00UYF1P0000=JEP0000005`001Goo100000=JEP00FUH00eYF00<005YF0000;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH?0008FUH80004FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YF
FUIJEPT0019oo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00<005YF0000
0`000Woo6`000Woo1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`03001JEP0000=JEP@000=oo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000Eoo`@00005FUH005YFFUH00002FUH01000FUIJEUYF0P00
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo000/Ool01000FUH005YF0P000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP<0009J
EP05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00
;7oo00D005YF000005YF00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP000080009JEP<0009JEP800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH4000dOol002aoo`80009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04FUH60004FUH00`00FUIJEP06
FUH40005FUH00`00FUIJEP02FUH7000hOol002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEQ/003moo`00;7oo0`0015YF00<0
05YFFUH015YF00<005YFFUH00UYF30001EYF200015YF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2
0007Ool50018Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00;7oo00<005YF00000eYF1P001eYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
27oo0`00BGoo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP00
00@000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<00003FUH005YF00AJEP04001JEUYFFUH2001DOol002aoo`@000=oo`<00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`D0009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEPL0009oo`@000=JEP04001JEUYFFUH2001DOol002aoo`80009J
EP<000=oo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00=oo`<00004FUH007ooOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEPX000=JEP8005Ao
o`00;7oo0P000eYF00<005YF00000P001Goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@00
17oo0`000UYF00<005YF000017oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEP00
0080009JEP03001JEUYF008005Aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0027oo4`001Goo1000
00=JEP00FUH00UYF00<005YF00001Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001eYF00<005YFFUH015YF00<005YFFUH00UYF
0P0000=JEP0000000P00E7oo000]Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPP001=oo`D000EJ
EP04001JEUYFFUH20009Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000015YF00000000E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4`00
0eYF00<005YFFUH015YF00D005YFFUIJEP0000eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEQL000EJEP03001JEUYF00=JEP03001JEP0000<005Aoo`00<7oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000001Eoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEPD000AJEP03001JEUYF00=J
EP@00003FUH005YF00AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<002=ooaH000EJEP03001JEUYF
00IJEPD000AJEP03001JEUYF00EJEP03001JEP00008000AJEP05001JEUYFFUH0001EOol003Ioo`D0
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03001J
EP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP8005Aoo`00>goo200015YF10001UYF00<005YFFUH00UYF1@00<goo
00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8005Aoo`00@goo4`00>7oo00<005YF00000`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000=JEP000000
E7oo0017Ool50012Ool2000015YF001oogoo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00004Ool00000FUH3001DOol004Moo`D0049oo`80
009JEP<0009oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL0009oo`<0
00=JEP<005Aoo`00B7oo0`00@goo0P000UYF00<005YFFUH01@000Woo6`001Goo100000=JEP00FUH0
0eYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YF00000`006Goo1@001EYF00<005YF
FUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF1@00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH7001OOol009aooa/006Ioo`00ZGoo1@00Kgoo002YOol5001_Ool00:Uoo`D006moo`00
ZWoo0`00L7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75925 m .59613 .70366 L .56496 .70176 L p .707 .577 .707 r
F P
0 g
s
.59613 .70366 m .59613 .75925 L .62796 .75847 L p .707 .577 .707 r
F P
0 g
s
.62796 .75847 m .62796 .70289 L .59613 .70366 L p .707 .577 .707 r
F P
0 g
s
.62796 .70289 m .62796 .75847 L .65735 .75509 L p .707 .577 .707 r
F P
0 g
s
.65735 .75509 m .65734 .69951 L .62796 .70289 L p .707 .577 .707 r
F P
0 g
s
.56496 .75735 m .56496 .70176 L .5375 .69737 L p .707 .577 .707 r
F P
0 g
s
.56496 .70176 m .56496 .75735 L .59613 .75925 L p .707 .577 .707 r
F P
0 g
s
.65734 .69951 m .65735 .75509 L .6814 .74944 L p .707 .577 .707 r
F P
0 g
s
.6814 .74944 m .6814 .69386 L .65734 .69951 L p .707 .577 .707 r
F P
0 g
s
.5375 .69737 m .5375 .75295 L .56496 .75735 L p .707 .577 .707 r
F P
0 g
s
.5375 .75295 m .5375 .69737 L .51644 .69092 L p .707 .577 .707 r
F P
0 g
s
.59613 .8326 m .59613 .79555 L .56496 .79365 L p .707 .577 .707 r
F P
0 g
s
.59613 .79555 m .59613 .8326 L .62796 .83182 L p .707 .577 .707 r
F P
0 g
s
.62796 .83182 m .62796 .79477 L .59613 .79555 L p .707 .577 .707 r
F P
0 g
s
.62796 .79477 m .62796 .83182 L .65735 .82844 L p .707 .577 .707 r
F P
0 g
s
.65735 .82844 m .65735 .79139 L .62796 .79477 L p .707 .577 .707 r
F P
0 g
s
.56496 .8307 m .56496 .79365 L .5375 .78925 L p .707 .577 .707 r
F P
0 g
s
.56496 .79365 m .56496 .8307 L .59613 .8326 L p .707 .577 .707 r
F P
0 g
s
.6814 .69386 m .6814 .74944 L .69777 .74207 L p .707 .577 .707 r
F P
0 g
s
.69777 .74207 m .69777 .68649 L .6814 .69386 L p .707 .577 .707 r
F P
0 g
s
.51644 .69092 m .51644 .7465 L .5375 .75295 L p .707 .577 .707 r
F P
0 g
s
.65735 .79139 m .65735 .82844 L .6814 .8228 L p .707 .577 .707 r
F P
0 g
s
.6814 .8228 m .6814 .78574 L .65735 .79139 L p .707 .577 .707 r
F P
0 g
s
.5375 .78925 m .5375 .82631 L .56496 .8307 L p .707 .577 .707 r
F P
0 g
s
.51644 .7465 m .51644 .69092 L .50385 .68303 L p .707 .577 .707 r
F P
0 g
s
.59613 .89115 m .59613 .87263 L .56496 .87072 L p .707 .577 .707 r
F P
0 g
s
.59613 .87263 m .59613 .89115 L .62796 .89038 L p .707 .577 .707 r
F P
0 g
s
.62796 .89038 m .62796 .87185 L .59613 .87263 L p .707 .577 .707 r
F P
0 g
s
.5375 .82631 m .5375 .78925 L .51644 .7828 L p .707 .577 .707 r
F P
0 g
s
.62796 .87185 m .62796 .89038 L .65735 .887 L p .707 .577 .707 r
F P
0 g
s
.65735 .887 m .65735 .86847 L .62796 .87185 L p .707 .577 .707 r
F P
0 g
s
.56496 .87072 m .56496 .88925 L .59613 .89115 L p .707 .577 .707 r
F P
0 g
s
.56496 .88925 m .56496 .87072 L .5375 .86633 L p .707 .577 .707 r
F P
0 g
s
.51644 .7828 m .51644 .81985 L .5375 .82631 L p .707 .577 .707 r
F P
0 g
s
.5375 .86633 m .5375 .88486 L .56496 .88925 L p .707 .577 .707 r
F P
0 g
s
.6814 .78574 m .6814 .8228 L .69777 .81543 L p .707 .577 .707 r
F P
0 g
s
.69777 .81543 m .69777 .77837 L .6814 .78574 L p .707 .577 .707 r
F P
0 g
s
.50385 .68303 m .50385 .73862 L .51644 .7465 L p .707 .577 .707 r
F P
0 g
s
.69777 .68649 m .69777 .74207 L .70485 .73371 L p .707 .577 .707 r
F P
0 g
s
.70485 .73371 m .70485 .67813 L .69777 .68649 L p .707 .577 .707 r
F P
0 g
s
.65735 .86847 m .65735 .887 L .6814 .88135 L p .707 .577 .707 r
F P
0 g
s
.6814 .88135 m .6814 .86282 L .65735 .86847 L p .707 .577 .707 r
F P
0 g
s
.5375 .88486 m .5375 .86633 L .51644 .85988 L p .707 .577 .707 r
F P
0 g
s
.51644 .81985 m .51644 .7828 L .50385 .77492 L p .707 .577 .707 r
F P
0 g
s
.50385 .73862 m .50385 .68303 L .50095 .67449 L p .707 .577 .707 r
F P
0 g
s
.51644 .85988 m .51644 .87841 L .5375 .88486 L p .707 .577 .707 r
F P
0 g
s
.50385 .77492 m .50385 .81197 L .51644 .81985 L p .707 .577 .707 r
F P
0 g
s
.6814 .86282 m .6814 .88135 L .69777 .87398 L p .707 .577 .707 r
F P
0 g
s
.69777 .87398 m .69777 .85545 L .6814 .86282 L p .707 .577 .707 r
F P
0 g
s
.69777 .77837 m .69777 .81543 L .70485 .80706 L p .707 .577 .707 r
F P
0 g
s
.70485 .80706 m .70485 .77001 L .69777 .77837 L p .707 .577 .707 r
F P
0 g
s
.50095 .67449 m .50095 .73007 L .50385 .73862 L p .707 .577 .707 r
F P
0 g
s
.70485 .67813 m .70485 .73371 L .70195 .72517 L p .707 .577 .707 r
F P
0 g
s
.70195 .72517 m .70195 .66958 L .70485 .67813 L p .707 .577 .707 r
F P
0 g
s
.51644 .87841 m .51644 .85988 L .50385 .85199 L p .707 .577 .707 r
F P
0 g
s
.50385 .85199 m .50385 .87052 L .51644 .87841 L p .707 .577 .707 r
F P
0 g
s
.50385 .81197 m .50385 .77492 L .50095 .76637 L p .707 .577 .707 r
F P
0 g
s
.50095 .73007 m .50095 .67449 L .50804 .66613 L p .707 .577 .707 r
F P
0 g
s
.69777 .85545 m .69777 .87398 L .70485 .86561 L p .707 .577 .707 r
F P
0 g
s
.70485 .86561 m .70485 .84709 L .69777 .85545 L p .707 .577 .707 r
F P
0 g
s
.50095 .76637 m .50095 .80343 L .50385 .81197 L p .707 .577 .707 r
F P
0 g
s
.49044 .87824 m .49044 .37636 L .44643 .37367 L p .707 .577 .707 r
F P
0 g
s
.50804 .66613 m .50804 .72171 L .50095 .73007 L p .707 .577 .707 r
F P
0 g
s
.50385 .87052 m .50385 .85199 L .50095 .84345 L p .707 .577 .707 r
F P
0 g
s
.50095 .84345 m .50095 .86198 L .50385 .87052 L p .707 .577 .707 r
F P
0 g
s
.50095 .80343 m .50095 .76637 L .50804 .75801 L p .707 .577 .707 r
F P
0 g
s
.50804 .72171 m .50804 .66613 L .5244 .65876 L p .707 .577 .707 r
F P
0 g
s
.50804 .75801 m .50804 .79506 L .50095 .80343 L p .707 .577 .707 r
F P
0 g
s
.5244 .65876 m .5244 .71434 L .50804 .72171 L p .707 .577 .707 r
F P
0 g
s
.50095 .86198 m .50095 .84345 L .50804 .83509 L p .707 .577 .707 r
F P
0 g
s
.50804 .83509 m .50804 .85362 L .50095 .86198 L p .707 .577 .707 r
F P
0 g
s
.50804 .79506 m .50804 .75801 L .5244 .75064 L p .707 .577 .707 r
F P
0 g
s
.5244 .75064 m .5244 .7877 L .50804 .79506 L p .707 .577 .707 r
F P
0 g
s
.50804 .85362 m .50804 .83509 L .5244 .82772 L p .707 .577 .707 r
F P
0 g
s
.5244 .7877 m .5244 .75064 L .54846 .74499 L p .707 .577 .707 r
F P
0 g
s
.5244 .82772 m .5244 .84625 L .50804 .85362 L p .707 .577 .707 r
F P
0 g
s
.54846 .74499 m .54846 .78205 L .5244 .7877 L p .707 .577 .707 r
F P
0 g
s
.5244 .84625 m .5244 .82772 L .54846 .82207 L p .707 .577 .707 r
F P
0 g
s
.54846 .82207 m .54846 .8406 L .5244 .84625 L p .707 .577 .707 r
F P
0 g
s
.49044 .37636 m .49044 .87824 L .53538 .87715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71434 m .5244 .65876 L .54846 .65311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65311 m .54846 .70869 L .5244 .71434 L p .707 .577 .707 r
F P
0 g
s
.53538 .87715 m .53538 .37526 L .49044 .37636 L p .707 .577 .707 r
F P
0 g
s
.70485 .77001 m .70485 .80706 L .70195 .79852 L p .707 .577 .707 r
F P
0 g
s
.70195 .79852 m .70195 .76147 L .70485 .77001 L p .707 .577 .707 r
F P
0 g
s
.54846 .70869 m .54846 .65311 L .57784 .64973 L p .707 .577 .707 r
F P
0 g
s
.57784 .64973 m .57784 .70531 L .54846 .70869 L p .707 .577 .707 r
F P
0 g
s
.54846 .78205 m .54846 .74499 L .57784 .74161 L p .707 .577 .707 r
F P
0 g
s
.57784 .74161 m .57784 .77867 L .54846 .78205 L p .707 .577 .707 r
F P
0 g
s
.54846 .8406 m .54846 .82207 L .57784 .81869 L p .707 .577 .707 r
F P
0 g
s
.57784 .81869 m .57784 .83722 L .54846 .8406 L p .707 .577 .707 r
F P
0 g
s
.53538 .37526 m .53538 .87715 L .57686 .87238 L p .707 .577 .707 r
F P
0 g
s
.57686 .87238 m .57686 .37049 L .53538 .37526 L p .707 .577 .707 r
F P
0 g
s
.70195 .66958 m .70195 .72517 L .68936 .71728 L p .707 .577 .707 r
F P
0 g
s
.68936 .71728 m .68936 .6617 L .70195 .66958 L p .707 .577 .707 r
F P
0 g
s
.44643 .87556 m .44643 .37367 L .40766 .36747 L p .707 .577 .707 r
F P
0 g
s
.44643 .37367 m .44643 .87556 L .49044 .87824 L p .707 .577 .707 r
F P
0 g
s
.25312 .72243 m .25312 .66685 L .22195 .66495 L p .707 .577 .707 r
F P
0 g
s
.25312 .66685 m .25312 .72243 L .28495 .72165 L p .707 .577 .707 r
F P
0 g
s
.28495 .72165 m .28495 .66607 L .25312 .66685 L p .707 .577 .707 r
F P
0 g
s
.28495 .66607 m .28495 .72165 L .31434 .71828 L p .707 .577 .707 r
F P
0 g
s
.31434 .71828 m .31434 .66269 L .28495 .66607 L p .707 .577 .707 r
F P
0 g
s
.57784 .70531 m .57784 .64973 L .60968 .64895 L p .707 .577 .707 r
F P
0 g
s
.60968 .64895 m .60968 .70454 L .57784 .70531 L p .707 .577 .707 r
F P
0 g
s
.57784 .77867 m .57784 .74161 L .60968 .74084 L p .707 .577 .707 r
F P
0 g
s
.60968 .74084 m .60968 .77789 L .57784 .77867 L p .707 .577 .707 r
F P
0 g
s
.57784 .83722 m .57784 .81869 L .60968 .81791 L p .707 .577 .707 r
F P
0 g
s
.60968 .81791 m .60968 .83644 L .57784 .83722 L p .707 .577 .707 r
F P
0 g
s
.57686 .37049 m .57686 .87238 L .61082 .8644 L p .707 .577 .707 r
F P
0 g
s
.64085 .65085 m .64085 .70644 L .60968 .70454 L p .707 .577 .707 r
F P
0 g
s
.60968 .70454 m .60968 .64895 L .64085 .65085 L p .707 .577 .707 r
F P
0 g
s
.64085 .74274 m .64085 .77979 L .60968 .77789 L p .707 .577 .707 r
F P
0 g
s
.60968 .77789 m .60968 .74084 L .64085 .74274 L p .707 .577 .707 r
F P
0 g
s
.64085 .81982 m .64085 .83834 L .60968 .83644 L p .707 .577 .707 r
F P
0 g
s
.60968 .83644 m .60968 .81791 L .64085 .81982 L p .707 .577 .707 r
F P
0 g
s
.61082 .8644 m .61082 .36251 L .57686 .37049 L p .707 .577 .707 r
F P
0 g
s
.70485 .84709 m .70485 .86561 L .70195 .85707 L p .707 .577 .707 r
F P
0 g
s
.70195 .85707 m .70195 .83855 L .70485 .84709 L p .707 .577 .707 r
F P
0 g
s
.22195 .72053 m .22195 .66495 L .19449 .66056 L p .707 .577 .707 r
F P
0 g
s
.22195 .66495 m .22195 .72053 L .25312 .72243 L p .707 .577 .707 r
F P
0 g
s
.40766 .86936 m .40766 .36747 L .37794 .35836 L p .707 .577 .707 r
F P
0 g
s
.40766 .36747 m .40766 .86936 L .44643 .87556 L p .707 .577 .707 r
F P
0 g
s
.31434 .66269 m .31434 .71828 L .33839 .71263 L p .707 .577 .707 r
F P
0 g
s
.33839 .71263 m .33839 .65704 L .31434 .66269 L p .707 .577 .707 r
F P
0 g
s
.70195 .76147 m .70195 .79852 L .68936 .79064 L p .707 .577 .707 r
F P
0 g
s
.68936 .79064 m .68936 .75358 L .70195 .76147 L p .707 .577 .707 r
F P
0 g
s
.68936 .6617 m .68936 .71728 L .66831 .71083 L p .707 .577 .707 r
F P
0 g
s
.66831 .71083 m .66831 .65525 L .68936 .6617 L p .707 .577 .707 r
F P
0 g
s
.19449 .66056 m .19449 .71614 L .22195 .72053 L p .707 .577 .707 r
F P
0 g
s
.19449 .71614 m .19449 .66056 L .17343 .6541 L p .707 .577 .707 r
F P
0 g
s
.25312 .79579 m .25312 .75873 L .22195 .75683 L p .707 .577 .707 r
F P
0 g
s
.25312 .75873 m .25312 .79579 L .28495 .79501 L p .707 .577 .707 r
F P
0 g
s
.28495 .79501 m .28495 .75795 L .25312 .75873 L p .707 .577 .707 r
F P
0 g
s
.28495 .75795 m .28495 .79501 L .31434 .79163 L p .707 .577 .707 r
F P
0 g
s
.31434 .79163 m .31434 .75457 L .28495 .75795 L p .707 .577 .707 r
F P
0 g
s
.61082 .36251 m .61082 .8644 L .63393 .854 L p .707 .577 .707 r
F P
0 g
s
.63393 .854 m .63393 .35211 L .61082 .36251 L p .707 .577 .707 r
F P
0 g
s
.22195 .79389 m .22195 .75683 L .19449 .75244 L p .707 .577 .707 r
F P
0 g
s
.22195 .75683 m .22195 .79389 L .25312 .79579 L p .707 .577 .707 r
F P
0 g
s
.33839 .65704 m .33839 .71263 L .35476 .70526 L p .707 .577 .707 r
F P
0 g
s
.35476 .70526 m .35476 .64968 L .33839 .65704 L p .707 .577 .707 r
F P
0 g
s
.70195 .83855 m .70195 .85707 L .68936 .84919 L p .707 .577 .707 r
F P
0 g
s
.68936 .84919 m .68936 .83066 L .70195 .83855 L p .707 .577 .707 r
F P
0 g
s
.17343 .6541 m .17343 .70968 L .19449 .71614 L p .707 .577 .707 r
F P
0 g
s
.31434 .75457 m .31434 .79163 L .33839 .78598 L p .707 .577 .707 r
F P
0 g
s
.33839 .78598 m .33839 .74893 L .31434 .75457 L p .707 .577 .707 r
F P
0 g
s
.66831 .65525 m .66831 .71083 L .64085 .70644 L p .707 .577 .707 r
F P
0 g
s
.64085 .70644 m .64085 .65085 L .66831 .65525 L p .707 .577 .707 r
F P
0 g
s
.19449 .75244 m .19449 .78949 L .22195 .79389 L p .707 .577 .707 r
F P
0 g
s
.68936 .75358 m .68936 .79064 L .66831 .78418 L p .707 .577 .707 r
F P
0 g
s
.66831 .78418 m .66831 .74713 L .68936 .75358 L p .707 .577 .707 r
F P
0 g
s
.17343 .70968 m .17343 .6541 L .16084 .64622 L p .707 .577 .707 r
F P
0 g
s
.37794 .86025 m .37794 .35836 L .36016 .34723 L p .707 .577 .707 r
F P
0 g
s
.37794 .35836 m .37794 .86025 L .40766 .86936 L p .707 .577 .707 r
F P
0 g
s
.25312 .85434 m .25312 .83581 L .22195 .83391 L p .707 .577 .707 r
F P
0 g
s
.25312 .83581 m .25312 .85434 L .28495 .85356 L p .707 .577 .707 r
F P
0 g
s
.28495 .85356 m .28495 .83503 L .25312 .83581 L p .707 .577 .707 r
F P
0 g
s
.19449 .78949 m .19449 .75244 L .17343 .74598 L p .707 .577 .707 r
F P
0 g
s
.28495 .83503 m .28495 .85356 L .31434 .85018 L p .707 .577 .707 r
F P
0 g
s
.31434 .85018 m .31434 .83165 L .28495 .83503 L p .707 .577 .707 r
F P
0 g
s
.22195 .83391 m .22195 .85244 L .25312 .85434 L p .707 .577 .707 r
F P
0 g
s
.22195 .85244 m .22195 .83391 L .19449 .82952 L p .707 .577 .707 r
F P
0 g
s
.17343 .74598 m .17343 .78304 L .19449 .78949 L p .707 .577 .707 r
F P
0 g
s
.19449 .82952 m .19449 .84804 L .22195 .85244 L p .707 .577 .707 r
F P
0 g
s
.33839 .74893 m .33839 .78598 L .35476 .77861 L p .707 .577 .707 r
F P
0 g
s
.35476 .77861 m .35476 .74156 L .33839 .74893 L p .707 .577 .707 r
F P
0 g
s
.16084 .64622 m .16084 .7018 L .17343 .70968 L p .707 .577 .707 r
F P
0 g
s
.35476 .64968 m .35476 .70526 L .36184 .69689 L p .707 .577 .707 r
F P
0 g
s
.36184 .69689 m .36184 .64131 L .35476 .64968 L p .707 .577 .707 r
F P
0 g
s
.31434 .83165 m .31434 .85018 L .33839 .84453 L p .707 .577 .707 r
F P
0 g
s
.33839 .84453 m .33839 .826 L .31434 .83165 L p .707 .577 .707 r
F P
0 g
s
.68936 .83066 m .68936 .84919 L .66831 .84273 L p .707 .577 .707 r
F P
0 g
s
.66831 .84273 m .66831 .82421 L .68936 .83066 L p .707 .577 .707 r
F P
0 g
s
.66831 .74713 m .66831 .78418 L .64085 .77979 L p .707 .577 .707 r
F P
0 g
s
.64085 .77979 m .64085 .74274 L .66831 .74713 L p .707 .577 .707 r
F P
0 g
s
.66831 .82421 m .66831 .84273 L .64085 .83834 L p .707 .577 .707 r
F P
0 g
s
.64085 .83834 m .64085 .81982 L .66831 .82421 L p .707 .577 .707 r
F P
0 g
s
.63393 .35211 m .63393 .854 L .64393 .84219 L p .707 .577 .707 r
F P
0 g
s
.64393 .84219 m .64393 .3403 L .63393 .35211 L p .707 .577 .707 r
F P
0 g
s
.19449 .84804 m .19449 .82952 L .17343 .82306 L p .707 .577 .707 r
F P
0 g
s
.17343 .78304 m .17343 .74598 L .16084 .7381 L p .707 .577 .707 r
F P
0 g
s
.16084 .7018 m .16084 .64622 L .15794 .63768 L p .707 .577 .707 r
F P
0 g
s
.17343 .82306 m .17343 .84159 L .19449 .84804 L p .707 .577 .707 r
F P
0 g
s
.16084 .7381 m .16084 .77515 L .17343 .78304 L p .707 .577 .707 r
F P
0 g
s
.33839 .826 m .33839 .84453 L .35476 .83716 L p .707 .577 .707 r
F P
0 g
s
.35476 .83716 m .35476 .81864 L .33839 .826 L p .707 .577 .707 r
F P
0 g
s
.35476 .74156 m .35476 .77861 L .36184 .77025 L p .707 .577 .707 r
F P
0 g
s
.36184 .77025 m .36184 .73319 L .35476 .74156 L p .707 .577 .707 r
F P
0 g
s
.36184 .64131 m .36184 .69689 L .35894 .68835 L p .707 .577 .707 r
F P
0 g
s
.35894 .68835 m .35894 .63277 L .36184 .64131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81864 m .35476 .83716 L .36184 .8288 L p .707 .577 .707 r
F P
0 g
s
.36184 .8288 m .36184 .81027 L .35476 .81864 L p .707 .577 .707 r
F P
0 g
s
.36184 .73319 m .36184 .77025 L .35894 .76171 L p .707 .577 .707 r
F P
0 g
s
.35894 .76171 m .35894 .72465 L .36184 .73319 L p .707 .577 .707 r
F P
0 g
s
.35894 .63277 m .35894 .68835 L .34635 .68047 L p .707 .577 .707 r
F P
0 g
s
.34635 .68047 m .34635 .62489 L .35894 .63277 L p .707 .577 .707 r
F P
0 g
s
.36184 .81027 m .36184 .8288 L .35894 .82026 L p .707 .577 .707 r
F P
0 g
s
.35894 .82026 m .35894 .80173 L .36184 .81027 L p .707 .577 .707 r
F P
0 g
s
.36016 .84912 m .36016 .34723 L .35607 .33517 L p .707 .577 .707 r
F P
0 g
s
.36016 .34723 m .36016 .84912 L .37794 .86025 L p .707 .577 .707 r
F P
0 g
s
.15794 .63768 m .15794 .69326 L .16084 .7018 L p .707 .577 .707 r
F P
0 g
s
.17343 .84159 m .17343 .82306 L .16084 .81518 L p .707 .577 .707 r
F P
0 g
s
.16084 .81518 m .16084 .83371 L .17343 .84159 L p .707 .577 .707 r
F P
0 g
s
.16084 .77515 m .16084 .7381 L .15794 .72956 L p .707 .577 .707 r
F P
0 g
s
.15794 .69326 m .15794 .63768 L .16503 .62931 L p .707 .577 .707 r
F P
0 g
s
.15794 .72956 m .15794 .76661 L .16084 .77515 L p .707 .577 .707 r
F P
0 g
s
.64393 .3403 m .64393 .84219 L .63984 .83013 L p .707 .577 .707 r
F P
0 g
s
.63984 .83013 m .63984 .32824 L .64393 .3403 L p .707 .577 .707 r
F P
0 g
s
.16503 .62931 m .16503 .68489 L .15794 .69326 L p .707 .577 .707 r
F P
0 g
s
.16084 .83371 m .16084 .81518 L .15794 .80664 L p .707 .577 .707 r
F P
0 g
s
.15794 .80664 m .15794 .82516 L .16084 .83371 L p .707 .577 .707 r
F P
0 g
s
.35894 .72465 m .35894 .76171 L .34635 .75382 L p .707 .577 .707 r
F P
0 g
s
.34635 .75382 m .34635 .71677 L .35894 .72465 L p .707 .577 .707 r
F P
0 g
s
.35894 .80173 m .35894 .82026 L .34635 .81237 L p .707 .577 .707 r
F P
0 g
s
.34635 .81237 m .34635 .79385 L .35894 .80173 L p .707 .577 .707 r
F P
0 g
s
.35607 .33517 m .35607 .83706 L .36016 .84912 L p .707 .577 .707 r
F P
0 g
s
.35607 .83706 m .35607 .33517 L .36607 .32336 L p .707 .577 .707 r
F P
0 g
s
.15794 .76661 m .15794 .72956 L .16503 .72119 L p .707 .577 .707 r
F P
0 g
s
.16503 .68489 m .16503 .62931 L .1814 .62194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72119 m .16503 .75825 L .15794 .76661 L p .707 .577 .707 r
F P
0 g
s
.1814 .62194 m .1814 .67753 L .16503 .68489 L p .707 .577 .707 r
F P
0 g
s
.34635 .62489 m .34635 .68047 L .3253 .67401 L p .707 .577 .707 r
F P
0 g
s
.3253 .67401 m .3253 .61843 L .34635 .62489 L p .707 .577 .707 r
F P
0 g
s
.15794 .82516 m .15794 .80664 L .16503 .79827 L p .707 .577 .707 r
F P
0 g
s
.63984 .32824 m .63984 .83013 L .62206 .819 L p .707 .577 .707 r
F P
0 g
s
.62206 .819 m .62206 .31711 L .63984 .32824 L p .707 .577 .707 r
F P
0 g
s
.16503 .79827 m .16503 .8168 L .15794 .82516 L p .707 .577 .707 r
F P
0 g
s
.16503 .75825 m .16503 .72119 L .1814 .71383 L p .707 .577 .707 r
F P
0 g
s
.1814 .67753 m .1814 .62194 L .20545 .61629 L p .707 .577 .707 r
F P
0 g
s
.1814 .71383 m .1814 .75088 L .16503 .75825 L p .707 .577 .707 r
F P
0 g
s
.36607 .82525 m .36607 .32336 L .38918 .31296 L p .707 .577 .707 r
F P
0 g
s
.36607 .32336 m .36607 .82525 L .35607 .83706 L p .707 .577 .707 r
F P
0 g
s
.3253 .61843 m .3253 .67401 L .29784 .66962 L p .707 .577 .707 r
F P
0 g
s
.29784 .66962 m .29784 .61404 L .3253 .61843 L p .707 .577 .707 r
F P
0 g
s
.34635 .71677 m .34635 .75382 L .3253 .74737 L p .707 .577 .707 r
F P
0 g
s
.3253 .74737 m .3253 .71031 L .34635 .71677 L p .707 .577 .707 r
F P
0 g
s
.20545 .61629 m .20545 .67188 L .1814 .67753 L p .707 .577 .707 r
F P
0 g
s
.20545 .67188 m .20545 .61629 L .23483 .61292 L p .707 .577 .707 r
F P
0 g
s
.16503 .8168 m .16503 .79827 L .1814 .79091 L p .707 .577 .707 r
F P
0 g
s
.1814 .75088 m .1814 .71383 L .20545 .70818 L p .707 .577 .707 r
F P
0 g
s
.1814 .79091 m .1814 .80943 L .16503 .8168 L p .707 .577 .707 r
F P
0 g
s
.29784 .61404 m .29784 .66962 L .26667 .66772 L p .707 .577 .707 r
F P
0 g
s
.26667 .66772 m .26667 .61214 L .29784 .61404 L p .707 .577 .707 r
F P
0 g
s
.23483 .6685 m .23483 .61292 L .26667 .61214 L p .707 .577 .707 r
F P
0 g
s
.23483 .61292 m .23483 .6685 L .20545 .67188 L p .707 .577 .707 r
F P
0 g
s
.62206 .31711 m .62206 .819 L .59233 .80989 L p .707 .577 .707 r
F P
0 g
s
.59233 .80989 m .59233 .308 L .62206 .31711 L p .707 .577 .707 r
F P
0 g
s
.26667 .61214 m .26667 .66772 L .23483 .6685 L p .707 .577 .707 r
F P
0 g
s
.20545 .70818 m .20545 .74523 L .1814 .75088 L p .707 .577 .707 r
F P
0 g
s
.34635 .79385 m .34635 .81237 L .3253 .80592 L p .707 .577 .707 r
F P
0 g
s
.3253 .80592 m .3253 .78739 L .34635 .79385 L p .707 .577 .707 r
F P
0 g
s
.73333 .66721 m .73333 .61163 L .70216 .60973 L p .707 .577 .707 r
F P
0 g
s
.73333 .61163 m .73333 .66721 L .76517 .66643 L p .707 .577 .707 r
F P
0 g
s
.76517 .66643 m .76517 .61085 L .73333 .61163 L p .707 .577 .707 r
F P
0 g
s
.3253 .71031 m .3253 .74737 L .29784 .74298 L p .707 .577 .707 r
F P
0 g
s
.29784 .74298 m .29784 .70592 L .3253 .71031 L p .707 .577 .707 r
F P
0 g
s
.76517 .61085 m .76517 .66643 L .79455 .66305 L p .707 .577 .707 r
F P
0 g
s
.79455 .66305 m .79455 .60747 L .76517 .61085 L p .707 .577 .707 r
F P
0 g
s
.70216 .66531 m .70216 .60973 L .6747 .60533 L p .707 .577 .707 r
F P
0 g
s
.70216 .60973 m .70216 .66531 L .73333 .66721 L p .707 .577 .707 r
F P
0 g
s
.20545 .74523 m .20545 .70818 L .23483 .7048 L p .707 .577 .707 r
F P
0 g
s
.1814 .80943 m .1814 .79091 L .20545 .78526 L p .707 .577 .707 r
F P
0 g
s
.38918 .31296 m .38918 .81485 L .36607 .82525 L p .707 .577 .707 r
F P
0 g
s
.38918 .81485 m .38918 .31296 L .42314 .30498 L p .707 .577 .707 r
F P
0 g
s
.79455 .60747 m .79455 .66305 L .8186 .6574 L p .707 .577 .707 r
F P
0 g
s
.8186 .6574 m .8186 .60182 L .79455 .60747 L p .707 .577 .707 r
F P
0 g
s
.20545 .78526 m .20545 .80378 L .1814 .80943 L p .707 .577 .707 r
F P
0 g
s
.29784 .70592 m .29784 .74298 L .26667 .74107 L p .707 .577 .707 r
F P
0 g
s
.26667 .74107 m .26667 .70402 L .29784 .70592 L p .707 .577 .707 r
F P
0 g
s
.23483 .7048 m .23483 .74185 L .20545 .74523 L p .707 .577 .707 r
F P
0 g
s
.23483 .74185 m .23483 .7048 L .26667 .70402 L p .707 .577 .707 r
F P
0 g
s
.6747 .60533 m .6747 .66092 L .70216 .66531 L p .707 .577 .707 r
F P
0 g
s
.6747 .66092 m .6747 .60533 L .65365 .59888 L p .707 .577 .707 r
F P
0 g
s
.3253 .78739 m .3253 .80592 L .29784 .80153 L p .707 .577 .707 r
F P
0 g
s
.29784 .80153 m .29784 .783 L .3253 .78739 L p .707 .577 .707 r
F P
0 g
s
.26667 .70402 m .26667 .74107 L .23483 .74185 L p .707 .577 .707 r
F P
0 g
s
.73333 .74056 m .73333 .70351 L .70216 .70161 L p .707 .577 .707 r
F P
0 g
s
.73333 .70351 m .73333 .74056 L .76517 .73979 L p .707 .577 .707 r
F P
0 g
s
.76517 .73979 m .76517 .70273 L .73333 .70351 L p .707 .577 .707 r
F P
0 g
s
.76517 .70273 m .76517 .73979 L .79455 .73641 L p .707 .577 .707 r
F P
0 g
s
.79455 .73641 m .79455 .69935 L .76517 .70273 L p .707 .577 .707 r
F P
0 g
s
.59233 .308 m .59233 .80989 L .55357 .80369 L p .707 .577 .707 r
F P
0 g
s
.55357 .80369 m .55357 .3018 L .59233 .308 L p .707 .577 .707 r
F P
0 g
s
.20545 .80378 m .20545 .78526 L .23483 .78188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73866 m .70216 .70161 L .6747 .69722 L p .707 .577 .707 r
F P
0 g
s
.70216 .70161 m .70216 .73866 L .73333 .74056 L p .707 .577 .707 r
F P
0 g
s
.8186 .60182 m .8186 .6574 L .83497 .65003 L p .707 .577 .707 r
F P
0 g
s
.83497 .65003 m .83497 .59445 L .8186 .60182 L p .707 .577 .707 r
F P
0 g
s
.23483 .78188 m .23483 .8004 L .20545 .80378 L p .707 .577 .707 r
F P
0 g
s
.65365 .59888 m .65365 .65446 L .6747 .66092 L p .707 .577 .707 r
F P
0 g
s
.29784 .783 m .29784 .80153 L .26667 .79963 L p .707 .577 .707 r
F P
0 g
s
.26667 .79963 m .26667 .7811 L .29784 .783 L p .707 .577 .707 r
F P
0 g
s
.42314 .80687 m .42314 .30498 L .46462 .30021 L p .707 .577 .707 r
F P
0 g
s
.42314 .30498 m .42314 .80687 L .38918 .81485 L p .707 .577 .707 r
F P
0 g
s
.79455 .69935 m .79455 .73641 L .8186 .73076 L p .707 .577 .707 r
F P
0 g
s
.8186 .73076 m .8186 .6937 L .79455 .69935 L p .707 .577 .707 r
F P
0 g
s
.23483 .8004 m .23483 .78188 L .26667 .7811 L p .707 .577 .707 r
F P
0 g
s
.6747 .69722 m .6747 .73427 L .70216 .73866 L p .707 .577 .707 r
F P
0 g
s
.26667 .7811 m .26667 .79963 L .23483 .8004 L p .707 .577 .707 r
F P
0 g
s
.65365 .65446 m .65365 .59888 L .64105 .591 L p .707 .577 .707 r
F P
0 g
s
.73333 .79911 m .73333 .78059 L .70216 .77869 L p .707 .577 .707 r
F P
0 g
s
.73333 .78059 m .73333 .79911 L .76517 .79834 L p .707 .577 .707 r
F P
0 g
s
.76517 .79834 m .76517 .77981 L .73333 .78059 L p .707 .577 .707 r
F P
0 g
s
.6747 .73427 m .6747 .69722 L .65365 .69076 L p .707 .577 .707 r
F P
0 g
s
.76517 .77981 m .76517 .79834 L .79455 .79496 L p .707 .577 .707 r
F P
0 g
s
.79455 .79496 m .79455 .77643 L .76517 .77981 L p .707 .577 .707 r
F P
0 g
s
.55357 .3018 m .55357 .80369 L .50956 .80101 L p .707 .577 .707 r
F P
0 g
s
.50956 .80101 m .50956 .29912 L .55357 .3018 L p .707 .577 .707 r
F P
0 g
s
.70216 .77869 m .70216 .79721 L .73333 .79911 L p .707 .577 .707 r
F P
0 g
s
.70216 .79721 m .70216 .77869 L .6747 .77429 L p .707 .577 .707 r
F P
0 g
s
.46462 .8021 m .46462 .30021 L .50956 .29912 L p .707 .577 .707 r
F P
0 g
s
.46462 .30021 m .46462 .8021 L .42314 .80687 L p .707 .577 .707 r
F P
0 g
s
.65365 .69076 m .65365 .72782 L .6747 .73427 L p .707 .577 .707 r
F P
0 g
s
.6747 .77429 m .6747 .79282 L .70216 .79721 L p .707 .577 .707 r
F P
0 g
s
.8186 .6937 m .8186 .73076 L .83497 .72339 L p .707 .577 .707 r
F P
0 g
s
.83497 .72339 m .83497 .68633 L .8186 .6937 L p .707 .577 .707 r
F P
0 g
s
.64105 .591 m .64105 .64658 L .65365 .65446 L p .707 .577 .707 r
F P
0 g
s
.50956 .29912 m .50956 .80101 L .46462 .8021 L p .707 .577 .707 r
F P
0 g
s
.83497 .59445 m .83497 .65003 L .84205 .64167 L p .707 .577 .707 r
F P
0 g
s
.84205 .64167 m .84205 .58609 L .83497 .59445 L p .707 .577 .707 r
F P
0 g
s
.79455 .77643 m .79455 .79496 L .8186 .78931 L p .707 .577 .707 r
F P
0 g
s
.8186 .78931 m .8186 .77078 L .79455 .77643 L p .707 .577 .707 r
F P
0 g
s
.6747 .79282 m .6747 .77429 L .65365 .76784 L p .707 .577 .707 r
F P
0 g
s
.65365 .72782 m .65365 .69076 L .64105 .68288 L p .707 .577 .707 r
F P
0 g
s
.64105 .64658 m .64105 .591 L .63816 .58245 L p .707 .577 .707 r
F P
0 g
s
.65365 .76784 m .65365 .78637 L .6747 .79282 L p .707 .577 .707 r
F P
0 g
s
.64105 .68288 m .64105 .71993 L .65365 .72782 L p .707 .577 .707 r
F P
0 g
s
.8186 .77078 m .8186 .78931 L .83497 .78194 L p .707 .577 .707 r
F P
0 g
s
.83497 .78194 m .83497 .76341 L .8186 .77078 L p .707 .577 .707 r
F P
0 g
s
.83497 .68633 m .83497 .72339 L .84206 .71502 L p .707 .577 .707 r
F P
0 g
s
.84206 .71502 m .84206 .67797 L .83497 .68633 L p .707 .577 .707 r
F P
0 g
s
.63816 .58245 m .63816 .63804 L .64105 .64658 L p .707 .577 .707 r
F P
0 g
s
.84205 .58609 m .84205 .64167 L .83916 .63313 L p .707 .577 .707 r
F P
0 g
s
.83916 .63313 m .83916 .57755 L .84205 .58609 L p .707 .577 .707 r
F P
0 g
s
.65365 .78637 m .65365 .76784 L .64105 .75996 L p .707 .577 .707 r
F P
0 g
s
.64105 .75996 m .64105 .77848 L .65365 .78637 L p .707 .577 .707 r
F P
0 g
s
.64105 .71993 m .64105 .68288 L .63816 .67433 L p .707 .577 .707 r
F P
0 g
s
.63816 .63804 m .63816 .58245 L .64524 .57409 L p .707 .577 .707 r
F P
0 g
s
.83497 .76341 m .83497 .78194 L .84206 .77358 L p .707 .577 .707 r
F P
0 g
s
.84206 .77358 m .84206 .75505 L .83497 .76341 L p .707 .577 .707 r
F P
0 g
s
.63816 .67433 m .63816 .71139 L .64105 .71993 L p .707 .577 .707 r
F P
0 g
s
.84206 .67797 m .84206 .71502 L .83916 .70648 L p .707 .577 .707 r
F P
0 g
s
.83916 .70648 m .83916 .66943 L .84206 .67797 L p .707 .577 .707 r
F P
0 g
s
.64524 .57409 m .64524 .62967 L .63816 .63804 L p .707 .577 .707 r
F P
0 g
s
.64105 .77848 m .64105 .75996 L .63816 .75141 L p .707 .577 .707 r
F P
0 g
s
.83916 .57755 m .83916 .63313 L .82657 .62524 L p .707 .577 .707 r
F P
0 g
s
.82657 .62524 m .82657 .56966 L .83916 .57755 L p .707 .577 .707 r
F P
0 g
s
.63816 .75141 m .63816 .76994 L .64105 .77848 L p .707 .577 .707 r
F P
0 g
s
.63816 .71139 m .63816 .67433 L .64524 .66597 L p .707 .577 .707 r
F P
0 g
s
.39032 .63039 m .39032 .57481 L .35915 .57291 L p .707 .577 .707 r
F P
0 g
s
.39032 .57481 m .39032 .63039 L .42216 .62962 L p .707 .577 .707 r
F P
0 g
s
.42216 .62962 m .42216 .57403 L .39032 .57481 L p .707 .577 .707 r
F P
0 g
s
.64524 .62967 m .64524 .57409 L .66161 .56672 L p .707 .577 .707 r
F P
0 g
s
.42216 .57403 m .42216 .62962 L .45154 .62624 L p .707 .577 .707 r
F P
0 g
s
.45154 .62624 m .45154 .57065 L .42216 .57403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84206 .75505 m .84206 .77358 L .83916 .76503 L p .707 .577 .707 r
F P
0 g
s
.83916 .76503 m .83916 .74651 L .84206 .75505 L p .707 .577 .707 r
F P
0 g
s
.35915 .62849 m .35915 .57291 L .33169 .56852 L p .707 .577 .707 r
F P
0 g
s
.35915 .57291 m .35915 .62849 L .39032 .63039 L p .707 .577 .707 r
F P
0 g
s
.64524 .66597 m .64524 .70303 L .63816 .71139 L p .707 .577 .707 r
F P
0 g
s
.45154 .57065 m .45154 .62624 L .47559 .62059 L p .707 .577 .707 r
F P
0 g
s
.47559 .62059 m .47559 .565 L .45154 .57065 L p .707 .577 .707 r
F P
0 g
s
.83916 .66943 m .83916 .70648 L .82657 .6986 L p .707 .577 .707 r
F P
0 g
s
.82657 .6986 m .82657 .66154 L .83916 .66943 L p .707 .577 .707 r
F P
0 g
s
.66161 .56672 m .66161 .6223 L .64524 .62967 L p .707 .577 .707 r
F P
0 g
s
.82657 .56966 m .82657 .62524 L .80551 .61879 L p .707 .577 .707 r
F P
0 g
s
.80551 .61879 m .80551 .56321 L .82657 .56966 L p .707 .577 .707 r
F P
0 g
s
.63816 .76994 m .63816 .75141 L .64524 .74305 L p .707 .577 .707 r
F P
0 g
s
.33169 .56852 m .33169 .6241 L .35915 .62849 L p .707 .577 .707 r
F P
0 g
s
.33169 .6241 m .33169 .56852 L .31064 .56206 L p .707 .577 .707 r
F P
0 g
s
.64524 .74305 m .64524 .76158 L .63816 .76994 L p .707 .577 .707 r
F P
0 g
s
.39032 .70375 m .39032 .66669 L .35915 .66479 L p .707 .577 .707 r
F P
0 g
s
.39032 .66669 m .39032 .70375 L .42216 .70297 L p .707 .577 .707 r
F P
0 g
s
.42216 .70297 m .42216 .66592 L .39032 .66669 L p .707 .577 .707 r
F P
0 g
s
.64524 .70303 m .64524 .66597 L .66161 .6586 L p .707 .577 .707 r
F P
0 g
s
.42216 .66592 m .42216 .70297 L .45154 .69959 L p .707 .577 .707 r
F P
0 g
s
.45154 .69959 m .45154 .66254 L .42216 .66592 L p .707 .577 .707 r
F P
0 g
s
.66161 .6223 m .66161 .56672 L .68566 .56107 L p .707 .577 .707 r
F P
0 g
s
.35915 .70185 m .35915 .66479 L .33169 .6604 L p .707 .577 .707 r
F P
0 g
s
.35915 .66479 m .35915 .70185 L .39032 .70375 L p .707 .577 .707 r
F P
0 g
s
.47559 .565 m .47559 .62059 L .49196 .61322 L p .707 .577 .707 r
F P
0 g
s
.49196 .61322 m .49196 .55764 L .47559 .565 L p .707 .577 .707 r
F P
0 g
s
.83916 .74651 m .83916 .76503 L .82657 .75715 L p .707 .577 .707 r
F P
0 g
s
.82657 .75715 m .82657 .73862 L .83916 .74651 L p .707 .577 .707 r
F P
0 g
s
.31064 .56206 m .31064 .61765 L .33169 .6241 L p .707 .577 .707 r
F P
0 g
s
.66161 .6586 m .66161 .69566 L .64524 .70303 L p .707 .577 .707 r
F P
0 g
s
.45154 .66254 m .45154 .69959 L .47559 .69394 L p .707 .577 .707 r
F P
0 g
s
.47559 .69394 m .47559 .65689 L .45154 .66254 L p .707 .577 .707 r
F P
0 g
s
.80551 .56321 m .80551 .61879 L .77805 .6144 L p .707 .577 .707 r
F P
0 g
s
.77805 .6144 m .77805 .55882 L .80551 .56321 L p .707 .577 .707 r
F P
0 g
s
.33169 .6604 m .33169 .69745 L .35915 .70185 L p .707 .577 .707 r
F P
0 g
s
.82657 .66154 m .82657 .6986 L .80551 .69214 L p .707 .577 .707 r
F P
0 g
s
.80551 .69214 m .80551 .65509 L .82657 .66154 L p .707 .577 .707 r
F P
0 g
s
.68566 .56107 m .68566 .61665 L .66161 .6223 L p .707 .577 .707 r
F P
0 g
s
.31064 .61765 m .31064 .56206 L .29804 .55418 L p .707 .577 .707 r
F P
0 g
s
.39032 .7623 m .39032 .74377 L .35915 .74187 L p .707 .577 .707 r
F P
0 g
s
.39032 .74377 m .39032 .7623 L .42216 .76152 L p .707 .577 .707 r
F P
0 g
s
.42216 .76152 m .42216 .74299 L .39032 .74377 L p .707 .577 .707 r
F P
0 g
s
.33169 .69745 m .33169 .6604 L .31064 .65395 L p .707 .577 .707 r
F P
0 g
s
.68566 .61665 m .68566 .56107 L .71504 .55769 L p .707 .577 .707 r
F P
0 g
s
.64524 .76158 m .64524 .74305 L .66161 .73568 L p .707 .577 .707 r
F P
0 g
s
.42216 .74299 m .42216 .76152 L .45154 .75814 L p .707 .577 .707 r
F P
0 g
s
.45154 .75814 m .45154 .73962 L .42216 .74299 L p .707 .577 .707 r
F P
0 g
s
.35915 .74187 m .35915 .7604 L .39032 .7623 L p .707 .577 .707 r
F P
0 g
s
.35915 .7604 m .35915 .74187 L .33169 .73748 L p .707 .577 .707 r
F P
0 g
s
.66161 .69566 m .66161 .6586 L .68566 .65295 L p .707 .577 .707 r
F P
0 g
s
.66161 .73568 m .66161 .75421 L .64524 .76158 L p .707 .577 .707 r
F P
0 g
s
.77805 .55882 m .77805 .6144 L .74688 .6125 L p .707 .577 .707 r
F P
0 g
s
.74688 .6125 m .74688 .55691 L .77805 .55882 L p .707 .577 .707 r
F P
0 g
s
.31064 .65395 m .31064 .691 L .33169 .69745 L p .707 .577 .707 r
F P
0 g
s
.33169 .73748 m .33169 .75601 L .35915 .7604 L p .707 .577 .707 r
F P
0 g
s
.47559 .65689 m .47559 .69394 L .49196 .68657 L p .707 .577 .707 r
F P
0 g
s
.49196 .68657 m .49196 .64952 L .47559 .65689 L p .707 .577 .707 r
F P
0 g
s
.29804 .55418 m .29804 .60976 L .31064 .61765 L p .707 .577 .707 r
F P
0 g
s
.71504 .61327 m .71504 .55769 L .74688 .55691 L p .707 .577 .707 r
F P
0 g
s
.71504 .55769 m .71504 .61327 L .68566 .61665 L p .707 .577 .707 r
F P
0 g
s
.49196 .55764 m .49196 .61322 L .49904 .60485 L p .707 .577 .707 r
F P
0 g
s
.49904 .60485 m .49904 .54927 L .49196 .55764 L p .707 .577 .707 r
F P
0 g
s
.45154 .73962 m .45154 .75814 L .47559 .75249 L p .707 .577 .707 r
F P
0 g
s
.47559 .75249 m .47559 .73397 L .45154 .73962 L p .707 .577 .707 r
F P
0 g
s
.74688 .55691 m .74688 .6125 L .71504 .61327 L p .707 .577 .707 r
F P
0 g
s
.68566 .65295 m .68566 .69001 L .66161 .69566 L p .707 .577 .707 r
F P
0 g
s
.82657 .73862 m .82657 .75715 L .80551 .7507 L p .707 .577 .707 r
F P
0 g
s
.80551 .7507 m .80551 .73217 L .82657 .73862 L p .707 .577 .707 r
F P
0 g
s
.80551 .65509 m .80551 .69214 L .77805 .68775 L p .707 .577 .707 r
F P
0 g
s
.77805 .68775 m .77805 .6507 L .80551 .65509 L p .707 .577 .707 r
F P
0 g
s
.33169 .75601 m .33169 .73748 L .31064 .73103 L p .707 .577 .707 r
F P
0 g
s
.31064 .691 m .31064 .65395 L .29804 .64606 L p .707 .577 .707 r
F P
0 g
s
.29804 .60976 m .29804 .55418 L .29515 .54564 L p .707 .577 .707 r
F P
0 g
s
.31064 .73103 m .31064 .74955 L .33169 .75601 L p .707 .577 .707 r
F P
0 g
s
.68566 .69001 m .68566 .65295 L .71504 .64957 L p .707 .577 .707 r
F P
0 g
s
.66161 .75421 m .66161 .73568 L .68566 .73003 L p .707 .577 .707 r
F P
0 g
s
.68566 .73003 m .68566 .74856 L .66161 .75421 L p .707 .577 .707 r
F P
0 g
s
.29804 .64606 m .29804 .68312 L .31064 .691 L p .707 .577 .707 r
F P
0 g
s
.47559 .73397 m .47559 .75249 L .49196 .74513 L p .707 .577 .707 r
F P
0 g
s
.49196 .74513 m .49196 .7266 L .47559 .73397 L p .707 .577 .707 r
F P
0 g
s
.77805 .6507 m .77805 .68775 L .74688 .68585 L p .707 .577 .707 r
F P
0 g
s
.74688 .68585 m .74688 .6488 L .77805 .6507 L p .707 .577 .707 r
F P
0 g
s
.71504 .64957 m .71504 .68663 L .68566 .69001 L p .707 .577 .707 r
F P
0 g
s
.71504 .68663 m .71504 .64957 L .74688 .6488 L p .707 .577 .707 r
F P
0 g
s
.49196 .64952 m .49196 .68657 L .49904 .67821 L p .707 .577 .707 r
F P
0 g
s
.49904 .67821 m .49904 .64115 L .49196 .64952 L p .707 .577 .707 r
F P
0 g
s
.80551 .73217 m .80551 .7507 L .77805 .7463 L p .707 .577 .707 r
F P
0 g
s
.77805 .7463 m .77805 .72778 L .80551 .73217 L p .707 .577 .707 r
F P
0 g
s
.29515 .54564 m .29515 .60122 L .29804 .60976 L p .707 .577 .707 r
F P
0 g
s
.74688 .6488 m .74688 .68585 L .71504 .68663 L p .707 .577 .707 r
F P
0 g
s
.49904 .54927 m .49904 .60485 L .49615 .59631 L p .707 .577 .707 r
F P
0 g
s
.49615 .59631 m .49615 .54073 L .49904 .54927 L p .707 .577 .707 r
F P
0 g
s
.31064 .74955 m .31064 .73103 L .29804 .72314 L p .707 .577 .707 r
F P
0 g
s
.68566 .74856 m .68566 .73003 L .71504 .72665 L p .707 .577 .707 r
F P
0 g
s
.29804 .72314 m .29804 .74167 L .31064 .74955 L p .707 .577 .707 r
F P
0 g
s
.29804 .68312 m .29804 .64606 L .29515 .63752 L p .707 .577 .707 r
F P
0 g
s
.71504 .72665 m .71504 .74518 L .68566 .74856 L p .707 .577 .707 r
F P
0 g
s
.77805 .72778 m .77805 .7463 L .74688 .7444 L p .707 .577 .707 r
F P
0 g
s
.74688 .7444 m .74688 .72588 L .77805 .72778 L p .707 .577 .707 r
F P
0 g
s
.29515 .60122 m .29515 .54564 L .30223 .53727 L p .707 .577 .707 r
F P
0 g
s
.71504 .74518 m .71504 .72665 L .74688 .72588 L p .707 .577 .707 r
F P
0 g
s
.49196 .7266 m .49196 .74513 L .49904 .73676 L p .707 .577 .707 r
F P
0 g
s
.49904 .73676 m .49904 .71823 L .49196 .7266 L p .707 .577 .707 r
F P
0 g
s
.29515 .63752 m .29515 .67457 L .29804 .68312 L p .707 .577 .707 r
F P
0 g
s
.74688 .72588 m .74688 .7444 L .71504 .74518 L p .707 .577 .707 r
F P
0 g
s
.49904 .64115 m .49904 .67821 L .49615 .66967 L p .707 .577 .707 r
F P
0 g
s
.49615 .66967 m .49615 .63261 L .49904 .64115 L p .707 .577 .707 r
F P
0 g
s
.30223 .53727 m .30223 .59286 L .29515 .60122 L p .707 .577 .707 r
F P
0 g
s
.29804 .74167 m .29804 .72314 L .29515 .7146 L p .707 .577 .707 r
F P
0 g
s
.49615 .54073 m .49615 .59631 L .48356 .58843 L p .707 .577 .707 r
F P
0 g
s
.48356 .58843 m .48356 .53285 L .49615 .54073 L p .707 .577 .707 r
F P
0 g
s
.29515 .7146 m .29515 .73313 L .29804 .74167 L p .707 .577 .707 r
F P
0 g
s
.29515 .67457 m .29515 .63752 L .30223 .62915 L p .707 .577 .707 r
F P
0 g
s
.30223 .59286 m .30223 .53727 L .3186 .52991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49904 .71823 m .49904 .73676 L .49615 .72822 L p .707 .577 .707 r
F P
0 g
s
.49615 .72822 m .49615 .70969 L .49904 .71823 L p .707 .577 .707 r
F P
0 g
s
.30223 .62915 m .30223 .66621 L .29515 .67457 L p .707 .577 .707 r
F P
0 g
s
.49615 .63261 m .49615 .66967 L .48356 .66178 L p .707 .577 .707 r
F P
0 g
s
.48356 .66178 m .48356 .62473 L .49615 .63261 L p .707 .577 .707 r
F P
0 g
s
.3186 .52991 m .3186 .58549 L .30223 .59286 L p .707 .577 .707 r
F P
0 g
s
.48356 .53285 m .48356 .58843 L .4625 .58197 L p .707 .577 .707 r
F P
0 g
s
.4625 .58197 m .4625 .52639 L .48356 .53285 L p .707 .577 .707 r
F P
0 g
s
.29515 .73313 m .29515 .7146 L .30223 .70623 L p .707 .577 .707 r
F P
0 g
s
.30223 .70623 m .30223 .72476 L .29515 .73313 L p .707 .577 .707 r
F P
0 g
s
.30223 .66621 m .30223 .62915 L .3186 .62179 L p .707 .577 .707 r
F P
0 g
s
.3186 .58549 m .3186 .52991 L .34265 .52426 L p .707 .577 .707 r
F P
0 g
s
.49615 .70969 m .49615 .72822 L .48356 .72034 L p .707 .577 .707 r
F P
0 g
s
.48356 .72034 m .48356 .70181 L .49615 .70969 L p .707 .577 .707 r
F P
0 g
s
.3186 .62179 m .3186 .65884 L .30223 .66621 L p .707 .577 .707 r
F P
0 g
s
.4625 .52639 m .4625 .58197 L .43504 .57758 L p .707 .577 .707 r
F P
0 g
s
.43504 .57758 m .43504 .522 L .4625 .52639 L p .707 .577 .707 r
F P
0 g
s
.48356 .62473 m .48356 .66178 L .4625 .65533 L p .707 .577 .707 r
F P
0 g
s
.4625 .65533 m .4625 .61827 L .48356 .62473 L p .707 .577 .707 r
F P
0 g
s
.34265 .52426 m .34265 .57984 L .3186 .58549 L p .707 .577 .707 r
F P
0 g
s
.34265 .57984 m .34265 .52426 L .37203 .52088 L p .707 .577 .707 r
F P
0 g
s
.30223 .72476 m .30223 .70623 L .3186 .69887 L p .707 .577 .707 r
F P
0 g
s
.3186 .65884 m .3186 .62179 L .34265 .61614 L p .707 .577 .707 r
F P
0 g
s
.3186 .69887 m .3186 .71739 L .30223 .72476 L p .707 .577 .707 r
F P
0 g
s
.43504 .522 m .43504 .57758 L .40387 .57568 L p .707 .577 .707 r
F P
0 g
s
.40387 .57568 m .40387 .5201 L .43504 .522 L p .707 .577 .707 r
F P
0 g
s
.37203 .57646 m .37203 .52088 L .40387 .5201 L p .707 .577 .707 r
F P
0 g
s
.37203 .52088 m .37203 .57646 L .34265 .57984 L p .707 .577 .707 r
F P
0 g
s
.40387 .5201 m .40387 .57568 L .37203 .57646 L p .707 .577 .707 r
F P
0 g
s
.34265 .61614 m .34265 .65319 L .3186 .65884 L p .707 .577 .707 r
F P
0 g
s
.48356 .70181 m .48356 .72034 L .4625 .71388 L p .707 .577 .707 r
F P
0 g
s
.4625 .71388 m .4625 .69535 L .48356 .70181 L p .707 .577 .707 r
F P
0 g
s
.4625 .61827 m .4625 .65533 L .43504 .65094 L p .707 .577 .707 r
F P
0 g
s
.43504 .65094 m .43504 .61388 L .4625 .61827 L p .707 .577 .707 r
F P
0 g
s
.34265 .65319 m .34265 .61614 L .37203 .61276 L p .707 .577 .707 r
F P
0 g
s
.3186 .71739 m .3186 .69887 L .34265 .69322 L p .707 .577 .707 r
F P
0 g
s
.34265 .69322 m .34265 .71174 L .3186 .71739 L p .707 .577 .707 r
F P
0 g
s
.43504 .61388 m .43504 .65094 L .40387 .64904 L p .707 .577 .707 r
F P
0 g
s
.40387 .64904 m .40387 .61198 L .43504 .61388 L p .707 .577 .707 r
F P
0 g
s
.37203 .61276 m .37203 .64981 L .34265 .65319 L p .707 .577 .707 r
F P
0 g
s
.37203 .64981 m .37203 .61276 L .40387 .61198 L p .707 .577 .707 r
F P
0 g
s
.4625 .69535 m .4625 .71388 L .43504 .70949 L p .707 .577 .707 r
F P
0 g
s
.43504 .70949 m .43504 .69096 L .4625 .69535 L p .707 .577 .707 r
F P
0 g
s
.40387 .61198 m .40387 .64904 L .37203 .64981 L p .707 .577 .707 r
F P
0 g
s
.34265 .71174 m .34265 .69322 L .37203 .68984 L p .707 .577 .707 r
F P
0 g
s
.37203 .68984 m .37203 .70837 L .34265 .71174 L p .707 .577 .707 r
F P
0 g
s
.43504 .69096 m .43504 .70949 L .40387 .70759 L p .707 .577 .707 r
F P
0 g
s
.40387 .70759 m .40387 .68906 L .43504 .69096 L p .707 .577 .707 r
F P
0 g
s
.37203 .70837 m .37203 .68984 L .40387 .68906 L p .707 .577 .707 r
F P
0 g
s
.40387 .68906 m .40387 .70759 L .37203 .70837 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo
001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo2@0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?OolH
000nOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH3000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH007oo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000=JEP<0
009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH0
05YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJ
EP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH0
1EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEPH0009JEP03001JEUYF00=JEP03001JEUYF00IJEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`0000AJEP000000009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01P00FUH0
0000FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YF
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0`00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008
FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/
Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo
00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH900000eYF001JEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF200015YF
00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004
FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF000000060003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF2P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1@000eYF00@005YFFUIJEP8001aoo`@00003FUH005YF
009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPH000=JEP8001Eoo`L000=JEP<000=JEP80
02eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUH90009Ool90003FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEQP000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00<7oo0`0015YF
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF
5`001UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000c
Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP03
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000aOol30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF00000002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01UYF1@000eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF0P0000Eoo`00
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEP0000<000=JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00FUH20003FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEQP0009J
EP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<0009JEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30000
1EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0UYF100000=JEP00FUH01P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF
0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20003FUH00`00FUH000020005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP<0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00UYF1P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJ
EP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF4@0015YF00D005YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00;7oo00<005YF000015YF00<005YFFUH00eYF1P004Goo1P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00
FUH00004FUH00`00FUH00003000MOol30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH7000OOol30003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUH00004000NOol50004FUH01@00FUIJEUYF0000;Woo000/Ool01000FUH005YF0P001EYF
00<005YF00000`006Goo2P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF0P008Woo0`0000=JEP00FUH00UYF0P00;Goo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH3000SOol2
0003FUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF00<005YFFUH00eYF00<005YFFUH00P008goo0P0000=JEP000000;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
100015YF00<005YFFUH00eYF00D005YFFUIJEP0002Aoo`@002eoo`00;7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000QOol2000015YF00000000;Goo000]Ool01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEP00008000EJEP04001JEUYFFUH2000LOol50003FUH00`00FUH0000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF1P000eYF0P005Goo1`000eYF00<005YFFUH00UYF0P00;Woo000^Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP80
02ioo`00<7oo0`0015YF00<005YFFUH01EYF6@0000=JEP00FUH01EYF00H005YF000007oo0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00;goo000cOol300000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;Woo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH00UYF
1@00>Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
30001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000goo4P00?goo000]Ool20004FUH00`00FUIJEP03FUH6000GOol4
0002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`00E7oo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000/Ool00`00FUH00003FUH3000ZOol40002FUH01000
FUIJEP001EYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00EGoo000/Ool01000FUH005YF0P00<Goo00<005YF00000UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
10000UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00
;7oo00@005YF000003Aoo`80009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00002FUH00`00
FUIJEP04FUH01000FUH00000F7oo000/Ool200000eYF0000000aOol40002FUH01000FUH000001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YFFUIJEP0000=JEP03001JEP0000<000EJEP<005Yoo`00;7oo0P000eYF0`00:goo0`000UYF
0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEPH005eoo`00;7oo
0P000eYF00<005YFFUH01@008Woo100000=JEP00FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF
00001EYF00<005YF00000`006Goo1@001EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP800003FUH005YF00AJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00eYF0`00Egoo000^Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000Ool00P0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH0009oo`D000AJEP05001JEUYFFUH0001EOol003=oo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00008Ool300000eYF
001JEP02FUH2001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009J
EPL000Uoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000aoo`8000=JEP8005Ao
o`00>goo6`004Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P003goo0P0000=JEP000000
E7oo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P004Woo1000E7oo001[Ool20006FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000004Woo
0P0000AJEP00000005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF0`003goo1@000eYF00<005YF0000E7oo001_Ool30000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3
000;Ool70003FUH00`00FUIJEP02FUH00`00FUH0001DOol0079oo`L000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<000Eoo`T000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00QGoo6@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo
002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001M
Ool009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76527 m .59613 .70969 L .56496 .70779 L p .707 .577 .707 r
F P
0 g
s
.59613 .70969 m .59613 .76527 L .62796 .7645 L p .707 .577 .707 r
F P
0 g
s
.62796 .7645 m .62796 .70891 L .59613 .70969 L p .707 .577 .707 r
F P
0 g
s
.62796 .70891 m .62796 .7645 L .65735 .76112 L p .707 .577 .707 r
F P
0 g
s
.65735 .76112 m .65734 .70554 L .62796 .70891 L p .707 .577 .707 r
F P
0 g
s
.56496 .76337 m .56496 .70779 L .5375 .7034 L p .707 .577 .707 r
F P
0 g
s
.56496 .70779 m .56496 .76337 L .59613 .76527 L p .707 .577 .707 r
F P
0 g
s
.65734 .70554 m .65735 .76112 L .6814 .75547 L p .707 .577 .707 r
F P
0 g
s
.6814 .75547 m .6814 .69989 L .65734 .70554 L p .707 .577 .707 r
F P
0 g
s
.5375 .7034 m .5375 .75898 L .56496 .76337 L p .707 .577 .707 r
F P
0 g
s
.5375 .75898 m .5375 .7034 L .51644 .69694 L p .707 .577 .707 r
F P
0 g
s
.59613 .84666 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84666 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80545 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .84476 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84476 L .59613 .84666 L p .707 .577 .707 r
F P
0 g
s
.6814 .69989 m .6814 .75547 L .69777 .7481 L p .707 .577 .707 r
F P
0 g
s
.69777 .7481 m .69777 .69252 L .6814 .69989 L p .707 .577 .707 r
F P
0 g
s
.51644 .69694 m .51644 .75253 L .5375 .75898 L p .707 .577 .707 r
F P
0 g
s
.65735 .80545 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .7998 L .65735 .80545 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84476 L p .707 .577 .707 r
F P
0 g
s
.51644 .75253 m .51644 .69694 L .50385 .68906 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79686 L p .707 .577 .707 r
F P
0 g
s
.59613 .91554 m .59613 .89701 L .56496 .89511 L p .707 .577 .707 r
F P
0 g
s
.59613 .89701 m .59613 .91554 L .62796 .91476 L p .707 .577 .707 r
F P
0 g
s
.62796 .91476 m .62796 .89624 L .59613 .89701 L p .707 .577 .707 r
F P
0 g
s
.62796 .89624 m .62796 .91476 L .65735 .91138 L p .707 .577 .707 r
F P
0 g
s
.65735 .91138 m .65735 .89286 L .62796 .89624 L p .707 .577 .707 r
F P
0 g
s
.56496 .89511 m .56496 .91364 L .59613 .91554 L p .707 .577 .707 r
F P
0 g
s
.56496 .91364 m .56496 .89511 L .5375 .89072 L p .707 .577 .707 r
F P
0 g
s
.51644 .79686 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.50385 .68906 m .50385 .74464 L .51644 .75253 L p .707 .577 .707 r
F P
0 g
s
.69777 .69252 m .69777 .7481 L .70485 .73974 L p .707 .577 .707 r
F P
0 g
s
.70485 .73974 m .70485 .68415 L .69777 .69252 L p .707 .577 .707 r
F P
0 g
s
.6814 .7998 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .7998 L p .707 .577 .707 r
F P
0 g
s
.5375 .89072 m .5375 .90925 L .56496 .91364 L p .707 .577 .707 r
F P
0 g
s
.65735 .89286 m .65735 .91138 L .6814 .90573 L p .707 .577 .707 r
F P
0 g
s
.6814 .90573 m .6814 .88721 L .65735 .89286 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79686 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .74464 m .50385 .68906 L .50095 .68052 L p .707 .577 .707 r
F P
0 g
s
.5375 .90925 m .5375 .89072 L .51644 .88427 L p .707 .577 .707 r
F P
0 g
s
.51644 .88427 m .51644 .90279 L .5375 .90925 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82603 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.6814 .88721 m .6814 .90573 L .69777 .89837 L p .707 .577 .707 r
F P
0 g
s
.69777 .89837 m .69777 .87984 L .6814 .88721 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .68052 m .50095 .7361 L .50385 .74464 L p .707 .577 .707 r
F P
0 g
s
.70485 .68415 m .70485 .73974 L .70195 .73119 L p .707 .577 .707 r
F P
0 g
s
.70195 .73119 m .70195 .67561 L .70485 .68415 L p .707 .577 .707 r
F P
0 g
s
.51644 .90279 m .51644 .88427 L .50385 .87638 L p .707 .577 .707 r
F P
0 g
s
.50385 .82603 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50385 .87638 m .50385 .89491 L .51644 .90279 L p .707 .577 .707 r
F P
0 g
s
.50095 .7361 m .50095 .68052 L .50804 .67215 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82603 L p .707 .577 .707 r
F P
0 g
s
.69777 .87984 m .69777 .89837 L .70485 .89 L p .707 .577 .707 r
F P
0 g
s
.70485 .89 m .70485 .87148 L .69777 .87984 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81258 L p .707 .577 .707 r
F P
0 g
s
.70195 .81258 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.50804 .67215 m .50804 .72774 L .50095 .7361 L p .707 .577 .707 r
F P
0 g
s
.70195 .67561 m .70195 .73119 L .68936 .72331 L p .707 .577 .707 r
F P
0 g
s
.68936 .72331 m .68936 .66773 L .70195 .67561 L p .707 .577 .707 r
F P
0 g
s
.49044 .91311 m .49044 .41122 L .44643 .40853 L p .707 .577 .707 r
F P
0 g
s
.50385 .89491 m .50385 .87638 L .50095 .86784 L p .707 .577 .707 r
F P
0 g
s
.50095 .86784 m .50095 .88637 L .50385 .89491 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .72774 m .50804 .67215 L .5244 .66479 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.5244 .66479 m .5244 .72037 L .50804 .72774 L p .707 .577 .707 r
F P
0 g
s
.50095 .88637 m .50095 .86784 L .50804 .85948 L p .707 .577 .707 r
F P
0 g
s
.50804 .85948 m .50804 .878 L .50095 .88637 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .7647 L p .707 .577 .707 r
F P
0 g
s
.5244 .7647 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.50804 .878 m .50804 .85948 L .5244 .85211 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .7647 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.5244 .85211 m .5244 .87064 L .50804 .878 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.5244 .87064 m .5244 .85211 L .54846 .84646 L p .707 .577 .707 r
F P
0 g
s
.54846 .84646 m .54846 .86499 L .5244 .87064 L p .707 .577 .707 r
F P
0 g
s
.49044 .41122 m .49044 .91311 L .53538 .91201 L p .707 .577 .707 r
F P
0 g
s
.5244 .72037 m .5244 .66479 L .54846 .65914 L p .707 .577 .707 r
F P
0 g
s
.54846 .65914 m .54846 .71472 L .5244 .72037 L p .707 .577 .707 r
F P
0 g
s
.53538 .91201 m .53538 .41012 L .49044 .41122 L p .707 .577 .707 r
F P
0 g
s
.54846 .71472 m .54846 .65914 L .57784 .65576 L p .707 .577 .707 r
F P
0 g
s
.57784 .65576 m .57784 .71134 L .54846 .71472 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.54846 .86499 m .54846 .84646 L .57784 .84308 L p .707 .577 .707 r
F P
0 g
s
.57784 .84308 m .57784 .86161 L .54846 .86499 L p .707 .577 .707 r
F P
0 g
s
.53538 .41012 m .53538 .91201 L .57686 .90724 L p .707 .577 .707 r
F P
0 g
s
.57686 .90724 m .57686 .40535 L .53538 .41012 L p .707 .577 .707 r
F P
0 g
s
.44643 .91042 m .44643 .40853 L .40766 .40233 L p .707 .577 .707 r
F P
0 g
s
.44643 .40853 m .44643 .91042 L .49044 .91311 L p .707 .577 .707 r
F P
0 g
s
.25312 .72846 m .25312 .67288 L .22195 .67098 L p .707 .577 .707 r
F P
0 g
s
.25312 .67288 m .25312 .72846 L .28495 .72768 L p .707 .577 .707 r
F P
0 g
s
.28495 .72768 m .28495 .6721 L .25312 .67288 L p .707 .577 .707 r
F P
0 g
s
.28495 .6721 m .28495 .72768 L .31434 .7243 L p .707 .577 .707 r
F P
0 g
s
.31434 .7243 m .31434 .66872 L .28495 .6721 L p .707 .577 .707 r
F P
0 g
s
.22195 .72656 m .22195 .67098 L .19449 .66658 L p .707 .577 .707 r
F P
0 g
s
.22195 .67098 m .22195 .72656 L .25312 .72846 L p .707 .577 .707 r
F P
0 g
s
.57784 .71134 m .57784 .65576 L .60968 .65498 L p .707 .577 .707 r
F P
0 g
s
.60968 .65498 m .60968 .71056 L .57784 .71134 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79195 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57784 .86161 m .57784 .84308 L .60968 .8423 L p .707 .577 .707 r
F P
0 g
s
.60968 .8423 m .60968 .86083 L .57784 .86161 L p .707 .577 .707 r
F P
0 g
s
.57686 .40535 m .57686 .90724 L .61082 .89926 L p .707 .577 .707 r
F P
0 g
s
.64085 .65688 m .64085 .71246 L .60968 .71056 L p .707 .577 .707 r
F P
0 g
s
.60968 .71056 m .60968 .65498 L .64085 .65688 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79385 L .60968 .79195 L p .707 .577 .707 r
F P
0 g
s
.60968 .79195 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.64085 .8442 m .64085 .86273 L .60968 .86083 L p .707 .577 .707 r
F P
0 g
s
.60968 .86083 m .60968 .8423 L .64085 .8442 L p .707 .577 .707 r
F P
0 g
s
.61082 .89926 m .61082 .39737 L .57686 .40535 L p .707 .577 .707 r
F P
0 g
s
.70485 .87148 m .70485 .89 L .70195 .88146 L p .707 .577 .707 r
F P
0 g
s
.70195 .88146 m .70195 .86293 L .70485 .87148 L p .707 .577 .707 r
F P
0 g
s
.31434 .66872 m .31434 .7243 L .33839 .71865 L p .707 .577 .707 r
F P
0 g
s
.33839 .71865 m .33839 .66307 L .31434 .66872 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81258 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.68936 .66773 m .68936 .72331 L .66831 .71686 L p .707 .577 .707 r
F P
0 g
s
.66831 .71686 m .66831 .66127 L .68936 .66773 L p .707 .577 .707 r
F P
0 g
s
.40766 .90422 m .40766 .40233 L .37794 .39322 L p .707 .577 .707 r
F P
0 g
s
.40766 .40233 m .40766 .90422 L .44643 .91042 L p .707 .577 .707 r
F P
0 g
s
.19449 .66658 m .19449 .72217 L .22195 .72656 L p .707 .577 .707 r
F P
0 g
s
.19449 .72217 m .19449 .66658 L .17343 .66013 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77279 L .22195 .77089 L p .707 .577 .707 r
F P
0 g
s
.25312 .77279 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77279 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80569 L p .707 .577 .707 r
F P
0 g
s
.31434 .80569 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77089 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77089 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.33839 .66307 m .33839 .71865 L .35476 .71128 L p .707 .577 .707 r
F P
0 g
s
.35476 .71128 m .35476 .6557 L .33839 .66307 L p .707 .577 .707 r
F P
0 g
s
.17343 .66013 m .17343 .71571 L .19449 .72217 L p .707 .577 .707 r
F P
0 g
s
.61082 .39737 m .61082 .89926 L .63393 .88886 L p .707 .577 .707 r
F P
0 g
s
.63393 .88886 m .63393 .38697 L .61082 .39737 L p .707 .577 .707 r
F P
0 g
s
.66831 .66127 m .66831 .71686 L .64085 .71246 L p .707 .577 .707 r
F P
0 g
s
.64085 .71246 m .64085 .65688 L .66831 .66127 L p .707 .577 .707 r
F P
0 g
s
.70195 .86293 m .70195 .88146 L .68936 .87358 L p .707 .577 .707 r
F P
0 g
s
.68936 .87358 m .68936 .85505 L .70195 .86293 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80569 L .33839 .80004 L p .707 .577 .707 r
F P
0 g
s
.33839 .80004 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.17343 .71571 m .17343 .66013 L .16084 .65224 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.25312 .87873 m .25312 .8602 L .22195 .8583 L p .707 .577 .707 r
F P
0 g
s
.25312 .8602 m .25312 .87873 L .28495 .87795 L p .707 .577 .707 r
F P
0 g
s
.28495 .87795 m .28495 .85942 L .25312 .8602 L p .707 .577 .707 r
F P
0 g
s
.37794 .89511 m .37794 .39322 L .36016 .38209 L p .707 .577 .707 r
F P
0 g
s
.37794 .39322 m .37794 .89511 L .40766 .90422 L p .707 .577 .707 r
F P
0 g
s
.28495 .85942 m .28495 .87795 L .31434 .87457 L p .707 .577 .707 r
F P
0 g
s
.31434 .87457 m .31434 .85604 L .28495 .85942 L p .707 .577 .707 r
F P
0 g
s
.22195 .8583 m .22195 .87682 L .25312 .87873 L p .707 .577 .707 r
F P
0 g
s
.22195 .87682 m .22195 .8583 L .19449 .8539 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.16084 .65224 m .16084 .70783 L .17343 .71571 L p .707 .577 .707 r
F P
0 g
s
.35476 .6557 m .35476 .71128 L .36184 .70292 L p .707 .577 .707 r
F P
0 g
s
.36184 .70292 m .36184 .64734 L .35476 .6557 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80004 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.19449 .8539 m .19449 .87243 L .22195 .87682 L p .707 .577 .707 r
F P
0 g
s
.31434 .85604 m .31434 .87457 L .33839 .86892 L p .707 .577 .707 r
F P
0 g
s
.33839 .86892 m .33839 .85039 L .31434 .85604 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79385 L p .707 .577 .707 r
F P
0 g
s
.64085 .79385 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.68936 .85505 m .68936 .87358 L .66831 .86712 L p .707 .577 .707 r
F P
0 g
s
.66831 .86712 m .66831 .84859 L .68936 .85505 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75216 L p .707 .577 .707 r
F P
0 g
s
.16084 .70783 m .16084 .65224 L .15794 .6437 L p .707 .577 .707 r
F P
0 g
s
.19449 .87243 m .19449 .8539 L .17343 .84745 L p .707 .577 .707 r
F P
0 g
s
.66831 .84859 m .66831 .86712 L .64085 .86273 L p .707 .577 .707 r
F P
0 g
s
.64085 .86273 m .64085 .8442 L .66831 .84859 L p .707 .577 .707 r
F P
0 g
s
.63393 .38697 m .63393 .88886 L .64393 .87705 L p .707 .577 .707 r
F P
0 g
s
.64393 .87705 m .64393 .37516 L .63393 .38697 L p .707 .577 .707 r
F P
0 g
s
.17343 .84745 m .17343 .86598 L .19449 .87243 L p .707 .577 .707 r
F P
0 g
s
.16084 .75216 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.33839 .85039 m .33839 .86892 L .35476 .86155 L p .707 .577 .707 r
F P
0 g
s
.35476 .86155 m .35476 .84302 L .33839 .85039 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.15794 .6437 m .15794 .69928 L .16084 .70783 L p .707 .577 .707 r
F P
0 g
s
.36184 .64734 m .36184 .70292 L .35894 .69438 L p .707 .577 .707 r
F P
0 g
s
.35894 .69438 m .35894 .6388 L .36184 .64734 L p .707 .577 .707 r
F P
0 g
s
.35476 .84302 m .35476 .86155 L .36184 .85319 L p .707 .577 .707 r
F P
0 g
s
.36184 .85319 m .36184 .83466 L .35476 .84302 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .73871 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.35894 .6388 m .35894 .69438 L .34635 .68649 L p .707 .577 .707 r
F P
0 g
s
.34635 .68649 m .34635 .63091 L .35894 .6388 L p .707 .577 .707 r
F P
0 g
s
.36184 .83466 m .36184 .85319 L .35894 .84465 L p .707 .577 .707 r
F P
0 g
s
.35894 .84465 m .35894 .82612 L .36184 .83466 L p .707 .577 .707 r
F P
0 g
s
.36016 .88398 m .36016 .38209 L .35607 .37003 L p .707 .577 .707 r
F P
0 g
s
.36016 .38209 m .36016 .88398 L .37794 .89511 L p .707 .577 .707 r
F P
0 g
s
.17343 .86598 m .17343 .84745 L .16084 .83957 L p .707 .577 .707 r
F P
0 g
s
.16084 .78921 m .16084 .75216 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.16084 .83957 m .16084 .85809 L .17343 .86598 L p .707 .577 .707 r
F P
0 g
s
.15794 .69928 m .15794 .6437 L .16503 .63534 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.64393 .37516 m .64393 .87705 L .63984 .86499 L p .707 .577 .707 r
F P
0 g
s
.63984 .86499 m .63984 .3631 L .64393 .37516 L p .707 .577 .707 r
F P
0 g
s
.16503 .63534 m .16503 .69092 L .15794 .69928 L p .707 .577 .707 r
F P
0 g
s
.16084 .85809 m .16084 .83957 L .15794 .83102 L p .707 .577 .707 r
F P
0 g
s
.15794 .83102 m .15794 .84955 L .16084 .85809 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .69092 m .16503 .63534 L .1814 .62797 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .73871 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .73871 L p .707 .577 .707 r
F P
0 g
s
.35894 .82612 m .35894 .84465 L .34635 .83676 L p .707 .577 .707 r
F P
0 g
s
.34635 .83676 m .34635 .81823 L .35894 .82612 L p .707 .577 .707 r
F P
0 g
s
.35607 .37003 m .35607 .87192 L .36016 .88398 L p .707 .577 .707 r
F P
0 g
s
.35607 .87192 m .35607 .37003 L .36607 .35822 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .62797 m .1814 .68355 L .16503 .69092 L p .707 .577 .707 r
F P
0 g
s
.34635 .63091 m .34635 .68649 L .3253 .68004 L p .707 .577 .707 r
F P
0 g
s
.3253 .68004 m .3253 .62446 L .34635 .63091 L p .707 .577 .707 r
F P
0 g
s
.15794 .84955 m .15794 .83102 L .16503 .82266 L p .707 .577 .707 r
F P
0 g
s
.1814 .68355 m .1814 .62797 L .20545 .62232 L p .707 .577 .707 r
F P
0 g
s
.16503 .82266 m .16503 .84119 L .15794 .84955 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.63984 .3631 m .63984 .86499 L .62206 .85386 L p .707 .577 .707 r
F P
0 g
s
.62206 .85386 m .62206 .35197 L .63984 .3631 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76494 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.3253 .62446 m .3253 .68004 L .29784 .67565 L p .707 .577 .707 r
F P
0 g
s
.29784 .67565 m .29784 .62007 L .3253 .62446 L p .707 .577 .707 r
F P
0 g
s
.20545 .62232 m .20545 .6779 L .1814 .68355 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.36607 .86011 m .36607 .35822 L .38918 .34782 L p .707 .577 .707 r
F P
0 g
s
.36607 .35822 m .36607 .86011 L .35607 .87192 L p .707 .577 .707 r
F P
0 g
s
.20545 .6779 m .20545 .62232 L .23483 .61894 L p .707 .577 .707 r
F P
0 g
s
.16503 .84119 m .16503 .82266 L .1814 .81529 L p .707 .577 .707 r
F P
0 g
s
.1814 .76494 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.29784 .62007 m .29784 .67565 L .26667 .67375 L p .707 .577 .707 r
F P
0 g
s
.26667 .67375 m .26667 .61816 L .29784 .62007 L p .707 .577 .707 r
F P
0 g
s
.1814 .81529 m .1814 .83382 L .16503 .84119 L p .707 .577 .707 r
F P
0 g
s
.23483 .67452 m .23483 .61894 L .26667 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61894 m .23483 .67452 L .20545 .6779 L p .707 .577 .707 r
F P
0 g
s
.26667 .61816 m .26667 .67375 L .23483 .67452 L p .707 .577 .707 r
F P
0 g
s
.73333 .67323 m .73333 .61765 L .70216 .61575 L p .707 .577 .707 r
F P
0 g
s
.73333 .61765 m .73333 .67323 L .76517 .67246 L p .707 .577 .707 r
F P
0 g
s
.76517 .67246 m .76517 .61688 L .73333 .61765 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75929 L .1814 .76494 L p .707 .577 .707 r
F P
0 g
s
.76517 .61688 m .76517 .67246 L .79455 .66908 L p .707 .577 .707 r
F P
0 g
s
.79455 .66908 m .79455 .6135 L .76517 .61688 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71998 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.34635 .81823 m .34635 .83676 L .3253 .83031 L p .707 .577 .707 r
F P
0 g
s
.3253 .83031 m .3253 .81178 L .34635 .81823 L p .707 .577 .707 r
F P
0 g
s
.62206 .35197 m .62206 .85386 L .59233 .84475 L p .707 .577 .707 r
F P
0 g
s
.59233 .84475 m .59233 .34286 L .62206 .35197 L p .707 .577 .707 r
F P
0 g
s
.70216 .67133 m .70216 .61575 L .6747 .61136 L p .707 .577 .707 r
F P
0 g
s
.70216 .61575 m .70216 .67133 L .73333 .67323 L p .707 .577 .707 r
F P
0 g
s
.20545 .75929 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.79455 .6135 m .79455 .66908 L .8186 .66343 L p .707 .577 .707 r
F P
0 g
s
.8186 .66343 m .8186 .60785 L .79455 .6135 L p .707 .577 .707 r
F P
0 g
s
.1814 .83382 m .1814 .81529 L .20545 .80964 L p .707 .577 .707 r
F P
0 g
s
.29784 .71998 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71808 L .29784 .71998 L p .707 .577 .707 r
F P
0 g
s
.38918 .34782 m .38918 .84971 L .36607 .86011 L p .707 .577 .707 r
F P
0 g
s
.38918 .84971 m .38918 .34782 L .42314 .33984 L p .707 .577 .707 r
F P
0 g
s
.20545 .80964 m .20545 .82817 L .1814 .83382 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75929 L p .707 .577 .707 r
F P
0 g
s
.6747 .61136 m .6747 .66694 L .70216 .67133 L p .707 .577 .707 r
F P
0 g
s
.6747 .66694 m .6747 .61136 L .65365 .60491 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71808 L p .707 .577 .707 r
F P
0 g
s
.26667 .71808 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.3253 .81178 m .3253 .83031 L .29784 .82591 L p .707 .577 .707 r
F P
0 g
s
.29784 .82591 m .29784 .80739 L .3253 .81178 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71679 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.76517 .71679 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.8186 .60785 m .8186 .66343 L .83497 .65606 L p .707 .577 .707 r
F P
0 g
s
.83497 .65606 m .83497 .60048 L .8186 .60785 L p .707 .577 .707 r
F P
0 g
s
.20545 .82817 m .20545 .80964 L .23483 .80626 L p .707 .577 .707 r
F P
0 g
s
.59233 .34286 m .59233 .84475 L .55357 .83855 L p .707 .577 .707 r
F P
0 g
s
.55357 .83855 m .55357 .33666 L .59233 .34286 L p .707 .577 .707 r
F P
0 g
s
.65365 .60491 m .65365 .66049 L .6747 .66694 L p .707 .577 .707 r
F P
0 g
s
.23483 .80626 m .23483 .82479 L .20545 .82817 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.29784 .80739 m .29784 .82591 L .26667 .82401 L p .707 .577 .707 r
F P
0 g
s
.26667 .82401 m .26667 .80549 L .29784 .80739 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74833 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.65365 .66049 m .65365 .60491 L .64105 .59702 L p .707 .577 .707 r
F P
0 g
s
.23483 .82479 m .23483 .80626 L .26667 .80549 L p .707 .577 .707 r
F P
0 g
s
.42314 .84173 m .42314 .33984 L .46462 .33507 L p .707 .577 .707 r
F P
0 g
s
.42314 .33984 m .42314 .84173 L .38918 .84971 L p .707 .577 .707 r
F P
0 g
s
.26667 .80549 m .26667 .82401 L .23483 .82479 L p .707 .577 .707 r
F P
0 g
s
.6747 .74833 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.73333 .8235 m .73333 .80498 L .70216 .80307 L p .707 .577 .707 r
F P
0 g
s
.73333 .80498 m .73333 .8235 L .76517 .82273 L p .707 .577 .707 r
F P
0 g
s
.76517 .82273 m .76517 .8042 L .73333 .80498 L p .707 .577 .707 r
F P
0 g
s
.76517 .8042 m .76517 .82273 L .79455 .81935 L p .707 .577 .707 r
F P
0 g
s
.79455 .81935 m .79455 .80082 L .76517 .8042 L p .707 .577 .707 r
F P
0 g
s
.70216 .80307 m .70216 .8216 L .73333 .8235 L p .707 .577 .707 r
F P
0 g
s
.70216 .8216 m .70216 .80307 L .6747 .79868 L p .707 .577 .707 r
F P
0 g
s
.55357 .33666 m .55357 .83855 L .50956 .83587 L p .707 .577 .707 r
F P
0 g
s
.50956 .83587 m .50956 .33398 L .55357 .33666 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74833 L p .707 .577 .707 r
F P
0 g
s
.64105 .59702 m .64105 .6526 L .65365 .66049 L p .707 .577 .707 r
F P
0 g
s
.83497 .60048 m .83497 .65606 L .84205 .6477 L p .707 .577 .707 r
F P
0 g
s
.84205 .6477 m .84205 .59211 L .83497 .60048 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73745 L p .707 .577 .707 r
F P
0 g
s
.83497 .73745 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.6747 .79868 m .6747 .81721 L .70216 .8216 L p .707 .577 .707 r
F P
0 g
s
.46462 .83696 m .46462 .33507 L .50956 .33398 L p .707 .577 .707 r
F P
0 g
s
.46462 .33507 m .46462 .83696 L .42314 .84173 L p .707 .577 .707 r
F P
0 g
s
.79455 .80082 m .79455 .81935 L .8186 .8137 L p .707 .577 .707 r
F P
0 g
s
.8186 .8137 m .8186 .79517 L .79455 .80082 L p .707 .577 .707 r
F P
0 g
s
.50956 .33398 m .50956 .83587 L .46462 .83696 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .6526 m .64105 .59702 L .63816 .58848 L p .707 .577 .707 r
F P
0 g
s
.6747 .81721 m .6747 .79868 L .65365 .79223 L p .707 .577 .707 r
F P
0 g
s
.65365 .79223 m .65365 .81076 L .6747 .81721 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.8186 .79517 m .8186 .8137 L .83497 .80633 L p .707 .577 .707 r
F P
0 g
s
.83497 .80633 m .83497 .7878 L .8186 .79517 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73745 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69203 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .58848 m .63816 .64406 L .64105 .6526 L p .707 .577 .707 r
F P
0 g
s
.84205 .59211 m .84205 .6477 L .83916 .63915 L p .707 .577 .707 r
F P
0 g
s
.83916 .63915 m .83916 .58357 L .84205 .59211 L p .707 .577 .707 r
F P
0 g
s
.65365 .81076 m .65365 .79223 L .64105 .78434 L p .707 .577 .707 r
F P
0 g
s
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.64105 .78434 m .64105 .80287 L .65365 .81076 L p .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .63816 .58848 L .64524 .58011 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72545 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83497 .7878 m .83497 .80633 L .84206 .79796 L p .707 .577 .707 r
F P
0 g
s
.84206 .79796 m .84206 .77944 L .83497 .7878 L p .707 .577 .707 r
F P
0 g
s
.84206 .69203 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69203 L p .707 .577 .707 r
F P
0 g
s
.64524 .58011 m .64524 .6357 L .63816 .64406 L p .707 .577 .707 r
F P
0 g
s
.83916 .58357 m .83916 .63915 L .82657 .63127 L p .707 .577 .707 r
F P
0 g
s
.82657 .63127 m .82657 .57569 L .83916 .58357 L p .707 .577 .707 r
F P
0 g
s
.64105 .80287 m .64105 .78434 L .63816 .7758 L p .707 .577 .707 r
F P
0 g
s
.63816 .7758 m .63816 .79433 L .64105 .80287 L p .707 .577 .707 r
F P
0 g
s
.39032 .63642 m .39032 .58084 L .35915 .57894 L p .707 .577 .707 r
F P
0 g
s
.39032 .58084 m .39032 .63642 L .42216 .63564 L p .707 .577 .707 r
F P
0 g
s
.42216 .63564 m .42216 .58006 L .39032 .58084 L p .707 .577 .707 r
F P
0 g
s
.63816 .72545 m .63816 .68839 L .64524 .68003 L p .707 .577 .707 r
F P
0 g
s
.64524 .6357 m .64524 .58011 L .66161 .57275 L p .707 .577 .707 r
F P
0 g
s
.42216 .58006 m .42216 .63564 L .45154 .63226 L p .707 .577 .707 r
F P
0 g
s
.45154 .63226 m .45154 .57668 L .42216 .58006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35915 .63452 m .35915 .57894 L .33169 .57454 L p .707 .577 .707 r
F P
0 g
s
.35915 .57894 m .35915 .63452 L .39032 .63642 L p .707 .577 .707 r
F P
0 g
s
.64524 .68003 m .64524 .71708 L .63816 .72545 L p .707 .577 .707 r
F P
0 g
s
.84206 .77944 m .84206 .79796 L .83916 .78942 L p .707 .577 .707 r
F P
0 g
s
.83916 .78942 m .83916 .77089 L .84206 .77944 L p .707 .577 .707 r
F P
0 g
s
.45154 .57668 m .45154 .63226 L .47559 .62661 L p .707 .577 .707 r
F P
0 g
s
.47559 .62661 m .47559 .57103 L .45154 .57668 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .57275 m .66161 .62833 L .64524 .6357 L p .707 .577 .707 r
F P
0 g
s
.82657 .57569 m .82657 .63127 L .80551 .62482 L p .707 .577 .707 r
F P
0 g
s
.80551 .62482 m .80551 .56923 L .82657 .57569 L p .707 .577 .707 r
F P
0 g
s
.33169 .57454 m .33169 .63013 L .35915 .63452 L p .707 .577 .707 r
F P
0 g
s
.33169 .63013 m .33169 .57454 L .31064 .56809 L p .707 .577 .707 r
F P
0 g
s
.63816 .79433 m .63816 .7758 L .64524 .76744 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71703 L p .707 .577 .707 r
F P
0 g
s
.42216 .71703 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.66161 .62833 m .66161 .57275 L .68566 .5671 L p .707 .577 .707 r
F P
0 g
s
.64524 .76744 m .64524 .78596 L .63816 .79433 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68003 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71703 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67446 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.47559 .57103 m .47559 .62661 L .49196 .61925 L p .707 .577 .707 r
F P
0 g
s
.49196 .61925 m .49196 .56366 L .47559 .57103 L p .707 .577 .707 r
F P
0 g
s
.31064 .56809 m .31064 .62367 L .33169 .63013 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.80551 .56923 m .80551 .62482 L .77805 .62042 L p .707 .577 .707 r
F P
0 g
s
.77805 .62042 m .77805 .56484 L .80551 .56923 L p .707 .577 .707 r
F P
0 g
s
.83916 .77089 m .83916 .78942 L .82657 .78154 L p .707 .577 .707 r
F P
0 g
s
.82657 .78154 m .82657 .76301 L .83916 .77089 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.68566 .5671 m .68566 .62268 L .66161 .62833 L p .707 .577 .707 r
F P
0 g
s
.33169 .67446 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.31064 .62367 m .31064 .56809 L .29804 .56021 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66915 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.68566 .62268 m .68566 .5671 L .71504 .56372 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67446 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.39032 .78669 m .39032 .76816 L .35915 .76626 L p .707 .577 .707 r
F P
0 g
s
.39032 .76816 m .39032 .78669 L .42216 .78591 L p .707 .577 .707 r
F P
0 g
s
.42216 .78591 m .42216 .76738 L .39032 .76816 L p .707 .577 .707 r
F P
0 g
s
.64524 .78596 m .64524 .76744 L .66161 .76007 L p .707 .577 .707 r
F P
0 g
s
.42216 .76738 m .42216 .78591 L .45154 .78253 L p .707 .577 .707 r
F P
0 g
s
.45154 .78253 m .45154 .764 L .42216 .76738 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.35915 .76626 m .35915 .78479 L .39032 .78669 L p .707 .577 .707 r
F P
0 g
s
.77805 .56484 m .77805 .62042 L .74688 .61852 L p .707 .577 .707 r
F P
0 g
s
.74688 .61852 m .74688 .56294 L .77805 .56484 L p .707 .577 .707 r
F P
0 g
s
.35915 .78479 m .35915 .76626 L .33169 .76187 L p .707 .577 .707 r
F P
0 g
s
.66161 .76007 m .66161 .7786 L .64524 .78596 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70506 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.29804 .56021 m .29804 .61579 L .31064 .62367 L p .707 .577 .707 r
F P
0 g
s
.71504 .6193 m .71504 .56372 L .74688 .56294 L p .707 .577 .707 r
F P
0 g
s
.71504 .56372 m .71504 .6193 L .68566 .62268 L p .707 .577 .707 r
F P
0 g
s
.49196 .56366 m .49196 .61925 L .49904 .61088 L p .707 .577 .707 r
F P
0 g
s
.49904 .61088 m .49904 .5553 L .49196 .56366 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66358 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.33169 .76187 m .33169 .78039 L .35915 .78479 L p .707 .577 .707 r
F P
0 g
s
.74688 .56294 m .74688 .61852 L .71504 .6193 L p .707 .577 .707 r
F P
0 g
s
.45154 .764 m .45154 .78253 L .47559 .77688 L p .707 .577 .707 r
F P
0 g
s
.47559 .77688 m .47559 .75835 L .45154 .764 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66915 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66915 L p .707 .577 .707 r
F P
0 g
s
.82657 .76301 m .82657 .78154 L .80551 .77508 L p .707 .577 .707 r
F P
0 g
s
.80551 .77508 m .80551 .75656 L .82657 .76301 L p .707 .577 .707 r
F P
0 g
s
.31064 .70506 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.29804 .61579 m .29804 .56021 L .29515 .55166 L p .707 .577 .707 r
F P
0 g
s
.33169 .78039 m .33169 .76187 L .31064 .75541 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.31064 .75541 m .31064 .77394 L .33169 .78039 L p .707 .577 .707 r
F P
0 g
s
.66161 .7786 m .66161 .76007 L .68566 .75442 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70506 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.68566 .75442 m .68566 .77295 L .66161 .7786 L p .707 .577 .707 r
F P
0 g
s
.47559 .75835 m .47559 .77688 L .49196 .76951 L p .707 .577 .707 r
F P
0 g
s
.49196 .76951 m .49196 .75099 L .47559 .75835 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66358 m .49196 .70063 L .49904 .69227 L p .707 .577 .707 r
F P
0 g
s
.49904 .69227 m .49904 .65521 L .49196 .66358 L p .707 .577 .707 r
F P
0 g
s
.29515 .55166 m .29515 .60725 L .29804 .61579 L p .707 .577 .707 r
F P
0 g
s
.49904 .5553 m .49904 .61088 L .49615 .60234 L p .707 .577 .707 r
F P
0 g
s
.49615 .60234 m .49615 .54676 L .49904 .5553 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.80551 .75656 m .80551 .77508 L .77805 .77069 L p .707 .577 .707 r
F P
0 g
s
.77805 .77069 m .77805 .75216 L .80551 .75656 L p .707 .577 .707 r
F P
0 g
s
.31064 .77394 m .31064 .75541 L .29804 .74753 L p .707 .577 .707 r
F P
0 g
s
.68566 .77295 m .68566 .75442 L .71504 .75104 L p .707 .577 .707 r
F P
0 g
s
.29804 .69717 m .29804 .66012 L .29515 .65158 L p .707 .577 .707 r
F P
0 g
s
.29804 .74753 m .29804 .76606 L .31064 .77394 L p .707 .577 .707 r
F P
0 g
s
.29515 .60725 m .29515 .55166 L .30223 .5433 L p .707 .577 .707 r
F P
0 g
s
.71504 .75104 m .71504 .76957 L .68566 .77295 L p .707 .577 .707 r
F P
0 g
s
.77805 .75216 m .77805 .77069 L .74688 .76879 L p .707 .577 .707 r
F P
0 g
s
.74688 .76879 m .74688 .75026 L .77805 .75216 L p .707 .577 .707 r
F P
0 g
s
.29515 .65158 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.71504 .76957 m .71504 .75104 L .74688 .75026 L p .707 .577 .707 r
F P
0 g
s
.49196 .75099 m .49196 .76951 L .49904 .76115 L p .707 .577 .707 r
F P
0 g
s
.49904 .76115 m .49904 .74262 L .49196 .75099 L p .707 .577 .707 r
F P
0 g
s
.74688 .75026 m .74688 .76879 L .71504 .76957 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69227 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .5433 m .30223 .59888 L .29515 .60725 L p .707 .577 .707 r
F P
0 g
s
.49615 .54676 m .49615 .60234 L .48356 .59445 L p .707 .577 .707 r
F P
0 g
s
.48356 .59445 m .48356 .53887 L .49615 .54676 L p .707 .577 .707 r
F P
0 g
s
.29804 .76606 m .29804 .74753 L .29515 .73899 L p .707 .577 .707 r
F P
0 g
s
.29515 .73899 m .29515 .75751 L .29804 .76606 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65158 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .59888 m .30223 .5433 L .3186 .53593 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .64321 m .30223 .68027 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49904 .74262 m .49904 .76115 L .49615 .75261 L p .707 .577 .707 r
F P
0 g
s
.49615 .75261 m .49615 .73408 L .49904 .74262 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .53593 m .3186 .59151 L .30223 .59888 L p .707 .577 .707 r
F P
0 g
s
.48356 .53887 m .48356 .59445 L .4625 .588 L p .707 .577 .707 r
F P
0 g
s
.4625 .588 m .4625 .53242 L .48356 .53887 L p .707 .577 .707 r
F P
0 g
s
.29515 .75751 m .29515 .73899 L .30223 .73062 L p .707 .577 .707 r
F P
0 g
s
.3186 .59151 m .3186 .53593 L .34265 .53028 L p .707 .577 .707 r
F P
0 g
s
.30223 .73062 m .30223 .74915 L .29515 .75751 L p .707 .577 .707 r
F P
0 g
s
.30223 .68027 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68027 L p .707 .577 .707 r
F P
0 g
s
.4625 .53242 m .4625 .588 L .43504 .58361 L p .707 .577 .707 r
F P
0 g
s
.43504 .58361 m .43504 .52803 L .4625 .53242 L p .707 .577 .707 r
F P
0 g
s
.49615 .73408 m .49615 .75261 L .48356 .74472 L p .707 .577 .707 r
F P
0 g
s
.48356 .74472 m .48356 .7262 L .49615 .73408 L p .707 .577 .707 r
F P
0 g
s
.34265 .53028 m .34265 .58586 L .3186 .59151 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66939 L p .707 .577 .707 r
F P
0 g
s
.4625 .66939 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.34265 .58586 m .34265 .53028 L .37203 .5269 L p .707 .577 .707 r
F P
0 g
s
.30223 .74915 m .30223 .73062 L .3186 .72325 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.43504 .52803 m .43504 .58361 L .40387 .58171 L p .707 .577 .707 r
F P
0 g
s
.40387 .58171 m .40387 .52613 L .43504 .52803 L p .707 .577 .707 r
F P
0 g
s
.3186 .72325 m .3186 .74178 L .30223 .74915 L p .707 .577 .707 r
F P
0 g
s
.37203 .58249 m .37203 .5269 L .40387 .52613 L p .707 .577 .707 r
F P
0 g
s
.37203 .5269 m .37203 .58249 L .34265 .58586 L p .707 .577 .707 r
F P
0 g
s
.40387 .52613 m .40387 .58171 L .37203 .58249 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66939 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.48356 .7262 m .48356 .74472 L .4625 .73827 L p .707 .577 .707 r
F P
0 g
s
.4625 .73827 m .4625 .71974 L .48356 .7262 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.3186 .74178 m .3186 .72325 L .34265 .7176 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.34265 .7176 m .34265 .73613 L .3186 .74178 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
.4625 .71974 m .4625 .73827 L .43504 .73388 L p .707 .577 .707 r
F P
0 g
s
.43504 .73388 m .43504 .71535 L .4625 .71974 L p .707 .577 .707 r
F P
0 g
s
.34265 .73613 m .34265 .7176 L .37203 .71423 L p .707 .577 .707 r
F P
0 g
s
.37203 .71423 m .37203 .73275 L .34265 .73613 L p .707 .577 .707 r
F P
0 g
s
.43504 .71535 m .43504 .73388 L .40387 .73198 L p .707 .577 .707 r
F P
0 g
s
.40387 .73198 m .40387 .71345 L .43504 .71535 L p .707 .577 .707 r
F P
0 g
s
.37203 .73275 m .37203 .71423 L .40387 .71345 L p .707 .577 .707 r
F P
0 g
s
.40387 .71345 m .40387 .73198 L .37203 .73275 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eoo`00MWoo2@001EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<000UJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool0
06Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001W
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<0
05YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001J
EP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06
001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo0017Ool90004Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h000AJEP03001JEUYF009J
EPL00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH:0008
FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP0
00QJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEQT00003FUH005YF009JEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000=JEP03001JEP0000=JEP<00004FUH0
00000002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF1P00
00=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<0
05YFFUH01UYF100000=JEP00FUH00P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool00`00
FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH3000`Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004FUH0
1000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD000=JEP04001JEUYFFUH2000LOol400000eYF
001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH00`00FUIJEP05FUH900000eYF001J
EP03FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P000eYF1P000eYF0P005Goo1`000eYF0`000eYF0P00;Goo000`Ool30004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUH0000;0004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@001Goo
0`0000=oo`0000001`000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUHI00000eYF001JEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000fOol90003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@00
15YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000cOol40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00;Woo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF20000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP@000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEP80009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00AJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP@0009JEQ`003Yoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF4@000eYF0P000UYF0`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol002aoo`03001J
EP0000AJEP03001JEUYF00=JEPH0015oo`D000=JEP03001JEP00008000EJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
00000eYF0000000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH4000fOol002aoo`03001JEP0000AJEP03001JEP0000<001Yoo`8000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEPL001]oo`05001JEUYFFUH00005FUH01000
FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH2000aOol002aoo`04001JEP00FUH20005FUH00`00FUH00003000HOol01000FUIJ
EP001EYF00<005YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP03FUHL0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YF00000P000UYF00<005YFFUH00P006Goo1@0015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YF000010001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`001EYF00D005YFFUIJEP0001ioo`<00003FUH005YF009JEP8002eoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF001JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000POol20003FUH2000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF6@001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2
000ROol200000eYF0000000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002=oo`@002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2
000QOol2000015YF00000000;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000<000AJEP04001JEUYFFUH2000L
Ool50003FUH00`00FUH0000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH60003FUH2000EOol70003FUH00`00FUIJEP02FUH2
000^Ool003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000kOolP000:Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH000080004FUH00`00FUIJEP02FUH9000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004Ool90018Ool0
02eoo`8000AJEP03001JEUYF00=JEPH001Moo`@0009JEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00EWoo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00@005YF000005Qoo`00;7oo00<005YF00000eYF0`00:Woo10000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00=JEP<005Yoo`00;7oo00@005YF001JEP80035oo`03
001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH00003001MOol0
02aoo`04001JEP00000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH60002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004001QOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00008006=oo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P000UYF
00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool2
0003FUH00`00FUIJEP02FUH3000ROol400000eYF001JEP02FUH20002FUH01000FUIJEUYF0P001EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
100015YF00<005YF00001EYF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF00001EYF00<005YF
00000`006Goo1@001EYF00@005YFFUIJEP80009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF
00<005YF00001EYF00<005YFFUH00UYF0P00FGoo000^Ool01000FUIJEP001EYF00<005YFFUH00eYF
6@000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP<00003FUH005YF00AJEP03001JEUYF00=JEP<005Moo`00;goo0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YFFUH007oo001J
EP000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00=JEP03
001JEUYF008005Eoo`00<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0`000Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
0P0000AJEP00Oomoo`D000AJEP05001JEUYFFUH0001EOol003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40004Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001goo0`0000=JEP00FUH00UYF0P00E7oo000fOol50004
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH70008Ool20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000002Woo0P000eYF0P00E7oo000kOolK000?Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0037oo0P0000=JEP000000E7oo001VOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000>Ool4001DOol006Ioo`03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000eoo`800004FUH00000001DOol006Moo`80009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000Uoo`D000=JEP03001JEP0005Aoo`00JGoo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YFFUIJEP8000Aoo`L000=JEP03001JEUYF009JEP03001JEP0005Aoo`00Jgoo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YF00001`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001]Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo001_Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000F7oo001bOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001J
Ool007Uoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<005eoo`00QGoo5P0000=oo`0000001`0015YF00<005YFFUH01UYF00<005YF
FUH00UYF1@00HGoo002UOolB001VOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76527 m .59613 .70969 L .56496 .70779 L p .707 .577 .707 r
F P
0 g
s
.59613 .70969 m .59613 .76527 L .62796 .7645 L p .707 .577 .707 r
F P
0 g
s
.62796 .7645 m .62796 .70891 L .59613 .70969 L p .707 .577 .707 r
F P
0 g
s
.62796 .70891 m .62796 .7645 L .65735 .76112 L p .707 .577 .707 r
F P
0 g
s
.65735 .76112 m .65734 .70554 L .62796 .70891 L p .707 .577 .707 r
F P
0 g
s
.56496 .76337 m .56496 .70779 L .5375 .7034 L p .707 .577 .707 r
F P
0 g
s
.56496 .70779 m .56496 .76337 L .59613 .76527 L p .707 .577 .707 r
F P
0 g
s
.65734 .70554 m .65735 .76112 L .6814 .75547 L p .707 .577 .707 r
F P
0 g
s
.6814 .75547 m .6814 .69989 L .65734 .70554 L p .707 .577 .707 r
F P
0 g
s
.5375 .7034 m .5375 .75898 L .56496 .76337 L p .707 .577 .707 r
F P
0 g
s
.5375 .75898 m .5375 .7034 L .51644 .69694 L p .707 .577 .707 r
F P
0 g
s
.59613 .84666 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84666 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80545 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .84476 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84476 L .59613 .84666 L p .707 .577 .707 r
F P
0 g
s
.6814 .69989 m .6814 .75547 L .69777 .7481 L p .707 .577 .707 r
F P
0 g
s
.69777 .7481 m .69777 .69252 L .6814 .69989 L p .707 .577 .707 r
F P
0 g
s
.51644 .69694 m .51644 .75253 L .5375 .75898 L p .707 .577 .707 r
F P
0 g
s
.65735 .80545 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .7998 L .65735 .80545 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84476 L p .707 .577 .707 r
F P
0 g
s
.51644 .75253 m .51644 .69694 L .50385 .68906 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79686 L p .707 .577 .707 r
F P
0 g
s
.59613 .91554 m .59613 .89701 L .56496 .89511 L p .707 .577 .707 r
F P
0 g
s
.59613 .89701 m .59613 .91554 L .62796 .91476 L p .707 .577 .707 r
F P
0 g
s
.62796 .91476 m .62796 .89624 L .59613 .89701 L p .707 .577 .707 r
F P
0 g
s
.62796 .89624 m .62796 .91476 L .65735 .91138 L p .707 .577 .707 r
F P
0 g
s
.65735 .91138 m .65735 .89286 L .62796 .89624 L p .707 .577 .707 r
F P
0 g
s
.56496 .89511 m .56496 .91364 L .59613 .91554 L p .707 .577 .707 r
F P
0 g
s
.56496 .91364 m .56496 .89511 L .5375 .89072 L p .707 .577 .707 r
F P
0 g
s
.51644 .79686 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.50385 .68906 m .50385 .74464 L .51644 .75253 L p .707 .577 .707 r
F P
0 g
s
.69777 .69252 m .69777 .7481 L .70485 .73974 L p .707 .577 .707 r
F P
0 g
s
.70485 .73974 m .70485 .68415 L .69777 .69252 L p .707 .577 .707 r
F P
0 g
s
.6814 .7998 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .7998 L p .707 .577 .707 r
F P
0 g
s
.5375 .89072 m .5375 .90925 L .56496 .91364 L p .707 .577 .707 r
F P
0 g
s
.65735 .89286 m .65735 .91138 L .6814 .90573 L p .707 .577 .707 r
F P
0 g
s
.6814 .90573 m .6814 .88721 L .65735 .89286 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79686 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .74464 m .50385 .68906 L .50095 .68052 L p .707 .577 .707 r
F P
0 g
s
.5375 .90925 m .5375 .89072 L .51644 .88427 L p .707 .577 .707 r
F P
0 g
s
.51644 .88427 m .51644 .90279 L .5375 .90925 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82603 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.6814 .88721 m .6814 .90573 L .69777 .89837 L p .707 .577 .707 r
F P
0 g
s
.69777 .89837 m .69777 .87984 L .6814 .88721 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .68052 m .50095 .7361 L .50385 .74464 L p .707 .577 .707 r
F P
0 g
s
.70485 .68415 m .70485 .73974 L .70195 .73119 L p .707 .577 .707 r
F P
0 g
s
.70195 .73119 m .70195 .67561 L .70485 .68415 L p .707 .577 .707 r
F P
0 g
s
.51644 .90279 m .51644 .88427 L .50385 .87638 L p .707 .577 .707 r
F P
0 g
s
.50385 .82603 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50385 .87638 m .50385 .89491 L .51644 .90279 L p .707 .577 .707 r
F P
0 g
s
.50095 .7361 m .50095 .68052 L .50804 .67215 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82603 L p .707 .577 .707 r
F P
0 g
s
.69777 .87984 m .69777 .89837 L .70485 .89 L p .707 .577 .707 r
F P
0 g
s
.70485 .89 m .70485 .87148 L .69777 .87984 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81258 L p .707 .577 .707 r
F P
0 g
s
.70195 .81258 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.50804 .67215 m .50804 .72774 L .50095 .7361 L p .707 .577 .707 r
F P
0 g
s
.70195 .67561 m .70195 .73119 L .68936 .72331 L p .707 .577 .707 r
F P
0 g
s
.68936 .72331 m .68936 .66773 L .70195 .67561 L p .707 .577 .707 r
F P
0 g
s
.49044 .91311 m .49044 .41122 L .44643 .40853 L p .707 .577 .707 r
F P
0 g
s
.50385 .89491 m .50385 .87638 L .50095 .86784 L p .707 .577 .707 r
F P
0 g
s
.50095 .86784 m .50095 .88637 L .50385 .89491 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .72774 m .50804 .67215 L .5244 .66479 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.5244 .66479 m .5244 .72037 L .50804 .72774 L p .707 .577 .707 r
F P
0 g
s
.50095 .88637 m .50095 .86784 L .50804 .85948 L p .707 .577 .707 r
F P
0 g
s
.50804 .85948 m .50804 .878 L .50095 .88637 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .7647 L p .707 .577 .707 r
F P
0 g
s
.5244 .7647 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.50804 .878 m .50804 .85948 L .5244 .85211 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .7647 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.5244 .85211 m .5244 .87064 L .50804 .878 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.5244 .87064 m .5244 .85211 L .54846 .84646 L p .707 .577 .707 r
F P
0 g
s
.54846 .84646 m .54846 .86499 L .5244 .87064 L p .707 .577 .707 r
F P
0 g
s
.49044 .41122 m .49044 .91311 L .53538 .91201 L p .707 .577 .707 r
F P
0 g
s
.5244 .72037 m .5244 .66479 L .54846 .65914 L p .707 .577 .707 r
F P
0 g
s
.54846 .65914 m .54846 .71472 L .5244 .72037 L p .707 .577 .707 r
F P
0 g
s
.53538 .91201 m .53538 .41012 L .49044 .41122 L p .707 .577 .707 r
F P
0 g
s
.54846 .71472 m .54846 .65914 L .57784 .65576 L p .707 .577 .707 r
F P
0 g
s
.57784 .65576 m .57784 .71134 L .54846 .71472 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.54846 .86499 m .54846 .84646 L .57784 .84308 L p .707 .577 .707 r
F P
0 g
s
.57784 .84308 m .57784 .86161 L .54846 .86499 L p .707 .577 .707 r
F P
0 g
s
.53538 .41012 m .53538 .91201 L .57686 .90724 L p .707 .577 .707 r
F P
0 g
s
.57686 .90724 m .57686 .40535 L .53538 .41012 L p .707 .577 .707 r
F P
0 g
s
.44643 .91042 m .44643 .40853 L .40766 .40233 L p .707 .577 .707 r
F P
0 g
s
.44643 .40853 m .44643 .91042 L .49044 .91311 L p .707 .577 .707 r
F P
0 g
s
.25312 .72846 m .25312 .67288 L .22195 .67098 L p .707 .577 .707 r
F P
0 g
s
.25312 .67288 m .25312 .72846 L .28495 .72768 L p .707 .577 .707 r
F P
0 g
s
.28495 .72768 m .28495 .6721 L .25312 .67288 L p .707 .577 .707 r
F P
0 g
s
.28495 .6721 m .28495 .72768 L .31434 .7243 L p .707 .577 .707 r
F P
0 g
s
.31434 .7243 m .31434 .66872 L .28495 .6721 L p .707 .577 .707 r
F P
0 g
s
.22195 .72656 m .22195 .67098 L .19449 .66658 L p .707 .577 .707 r
F P
0 g
s
.22195 .67098 m .22195 .72656 L .25312 .72846 L p .707 .577 .707 r
F P
0 g
s
.57784 .71134 m .57784 .65576 L .60968 .65498 L p .707 .577 .707 r
F P
0 g
s
.60968 .65498 m .60968 .71056 L .57784 .71134 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79195 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57784 .86161 m .57784 .84308 L .60968 .8423 L p .707 .577 .707 r
F P
0 g
s
.60968 .8423 m .60968 .86083 L .57784 .86161 L p .707 .577 .707 r
F P
0 g
s
.57686 .40535 m .57686 .90724 L .61082 .89926 L p .707 .577 .707 r
F P
0 g
s
.64085 .65688 m .64085 .71246 L .60968 .71056 L p .707 .577 .707 r
F P
0 g
s
.60968 .71056 m .60968 .65498 L .64085 .65688 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79385 L .60968 .79195 L p .707 .577 .707 r
F P
0 g
s
.60968 .79195 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.64085 .8442 m .64085 .86273 L .60968 .86083 L p .707 .577 .707 r
F P
0 g
s
.60968 .86083 m .60968 .8423 L .64085 .8442 L p .707 .577 .707 r
F P
0 g
s
.61082 .89926 m .61082 .39737 L .57686 .40535 L p .707 .577 .707 r
F P
0 g
s
.70485 .87148 m .70485 .89 L .70195 .88146 L p .707 .577 .707 r
F P
0 g
s
.70195 .88146 m .70195 .86293 L .70485 .87148 L p .707 .577 .707 r
F P
0 g
s
.31434 .66872 m .31434 .7243 L .33839 .71865 L p .707 .577 .707 r
F P
0 g
s
.33839 .71865 m .33839 .66307 L .31434 .66872 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81258 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.68936 .66773 m .68936 .72331 L .66831 .71686 L p .707 .577 .707 r
F P
0 g
s
.66831 .71686 m .66831 .66127 L .68936 .66773 L p .707 .577 .707 r
F P
0 g
s
.40766 .90422 m .40766 .40233 L .37794 .39322 L p .707 .577 .707 r
F P
0 g
s
.40766 .40233 m .40766 .90422 L .44643 .91042 L p .707 .577 .707 r
F P
0 g
s
.19449 .66658 m .19449 .72217 L .22195 .72656 L p .707 .577 .707 r
F P
0 g
s
.19449 .72217 m .19449 .66658 L .17343 .66013 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77279 L .22195 .77089 L p .707 .577 .707 r
F P
0 g
s
.25312 .77279 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77279 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80569 L p .707 .577 .707 r
F P
0 g
s
.31434 .80569 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77089 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77089 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.33839 .66307 m .33839 .71865 L .35476 .71128 L p .707 .577 .707 r
F P
0 g
s
.35476 .71128 m .35476 .6557 L .33839 .66307 L p .707 .577 .707 r
F P
0 g
s
.17343 .66013 m .17343 .71571 L .19449 .72217 L p .707 .577 .707 r
F P
0 g
s
.61082 .39737 m .61082 .89926 L .63393 .88886 L p .707 .577 .707 r
F P
0 g
s
.63393 .88886 m .63393 .38697 L .61082 .39737 L p .707 .577 .707 r
F P
0 g
s
.66831 .66127 m .66831 .71686 L .64085 .71246 L p .707 .577 .707 r
F P
0 g
s
.64085 .71246 m .64085 .65688 L .66831 .66127 L p .707 .577 .707 r
F P
0 g
s
.70195 .86293 m .70195 .88146 L .68936 .87358 L p .707 .577 .707 r
F P
0 g
s
.68936 .87358 m .68936 .85505 L .70195 .86293 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80569 L .33839 .80004 L p .707 .577 .707 r
F P
0 g
s
.33839 .80004 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.17343 .71571 m .17343 .66013 L .16084 .65224 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.25312 .87873 m .25312 .8602 L .22195 .8583 L p .707 .577 .707 r
F P
0 g
s
.25312 .8602 m .25312 .87873 L .28495 .87795 L p .707 .577 .707 r
F P
0 g
s
.28495 .87795 m .28495 .85942 L .25312 .8602 L p .707 .577 .707 r
F P
0 g
s
.37794 .89511 m .37794 .39322 L .36016 .38209 L p .707 .577 .707 r
F P
0 g
s
.37794 .39322 m .37794 .89511 L .40766 .90422 L p .707 .577 .707 r
F P
0 g
s
.28495 .85942 m .28495 .87795 L .31434 .87457 L p .707 .577 .707 r
F P
0 g
s
.31434 .87457 m .31434 .85604 L .28495 .85942 L p .707 .577 .707 r
F P
0 g
s
.22195 .8583 m .22195 .87682 L .25312 .87873 L p .707 .577 .707 r
F P
0 g
s
.22195 .87682 m .22195 .8583 L .19449 .8539 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.16084 .65224 m .16084 .70783 L .17343 .71571 L p .707 .577 .707 r
F P
0 g
s
.35476 .6557 m .35476 .71128 L .36184 .70292 L p .707 .577 .707 r
F P
0 g
s
.36184 .70292 m .36184 .64734 L .35476 .6557 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80004 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.19449 .8539 m .19449 .87243 L .22195 .87682 L p .707 .577 .707 r
F P
0 g
s
.31434 .85604 m .31434 .87457 L .33839 .86892 L p .707 .577 .707 r
F P
0 g
s
.33839 .86892 m .33839 .85039 L .31434 .85604 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79385 L p .707 .577 .707 r
F P
0 g
s
.64085 .79385 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.68936 .85505 m .68936 .87358 L .66831 .86712 L p .707 .577 .707 r
F P
0 g
s
.66831 .86712 m .66831 .84859 L .68936 .85505 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75216 L p .707 .577 .707 r
F P
0 g
s
.16084 .70783 m .16084 .65224 L .15794 .6437 L p .707 .577 .707 r
F P
0 g
s
.19449 .87243 m .19449 .8539 L .17343 .84745 L p .707 .577 .707 r
F P
0 g
s
.66831 .84859 m .66831 .86712 L .64085 .86273 L p .707 .577 .707 r
F P
0 g
s
.64085 .86273 m .64085 .8442 L .66831 .84859 L p .707 .577 .707 r
F P
0 g
s
.63393 .38697 m .63393 .88886 L .64393 .87705 L p .707 .577 .707 r
F P
0 g
s
.64393 .87705 m .64393 .37516 L .63393 .38697 L p .707 .577 .707 r
F P
0 g
s
.17343 .84745 m .17343 .86598 L .19449 .87243 L p .707 .577 .707 r
F P
0 g
s
.16084 .75216 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.33839 .85039 m .33839 .86892 L .35476 .86155 L p .707 .577 .707 r
F P
0 g
s
.35476 .86155 m .35476 .84302 L .33839 .85039 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.15794 .6437 m .15794 .69928 L .16084 .70783 L p .707 .577 .707 r
F P
0 g
s
.36184 .64734 m .36184 .70292 L .35894 .69438 L p .707 .577 .707 r
F P
0 g
s
.35894 .69438 m .35894 .6388 L .36184 .64734 L p .707 .577 .707 r
F P
0 g
s
.35476 .84302 m .35476 .86155 L .36184 .85319 L p .707 .577 .707 r
F P
0 g
s
.36184 .85319 m .36184 .83466 L .35476 .84302 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .73871 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.35894 .6388 m .35894 .69438 L .34635 .68649 L p .707 .577 .707 r
F P
0 g
s
.34635 .68649 m .34635 .63091 L .35894 .6388 L p .707 .577 .707 r
F P
0 g
s
.36184 .83466 m .36184 .85319 L .35894 .84465 L p .707 .577 .707 r
F P
0 g
s
.35894 .84465 m .35894 .82612 L .36184 .83466 L p .707 .577 .707 r
F P
0 g
s
.36016 .88398 m .36016 .38209 L .35607 .37003 L p .707 .577 .707 r
F P
0 g
s
.36016 .38209 m .36016 .88398 L .37794 .89511 L p .707 .577 .707 r
F P
0 g
s
.17343 .86598 m .17343 .84745 L .16084 .83957 L p .707 .577 .707 r
F P
0 g
s
.16084 .78921 m .16084 .75216 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.16084 .83957 m .16084 .85809 L .17343 .86598 L p .707 .577 .707 r
F P
0 g
s
.15794 .69928 m .15794 .6437 L .16503 .63534 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.64393 .37516 m .64393 .87705 L .63984 .86499 L p .707 .577 .707 r
F P
0 g
s
.63984 .86499 m .63984 .3631 L .64393 .37516 L p .707 .577 .707 r
F P
0 g
s
.16503 .63534 m .16503 .69092 L .15794 .69928 L p .707 .577 .707 r
F P
0 g
s
.16084 .85809 m .16084 .83957 L .15794 .83102 L p .707 .577 .707 r
F P
0 g
s
.15794 .83102 m .15794 .84955 L .16084 .85809 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .69092 m .16503 .63534 L .1814 .62797 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .73871 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .73871 L p .707 .577 .707 r
F P
0 g
s
.35894 .82612 m .35894 .84465 L .34635 .83676 L p .707 .577 .707 r
F P
0 g
s
.34635 .83676 m .34635 .81823 L .35894 .82612 L p .707 .577 .707 r
F P
0 g
s
.35607 .37003 m .35607 .87192 L .36016 .88398 L p .707 .577 .707 r
F P
0 g
s
.35607 .87192 m .35607 .37003 L .36607 .35822 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .62797 m .1814 .68355 L .16503 .69092 L p .707 .577 .707 r
F P
0 g
s
.34635 .63091 m .34635 .68649 L .3253 .68004 L p .707 .577 .707 r
F P
0 g
s
.3253 .68004 m .3253 .62446 L .34635 .63091 L p .707 .577 .707 r
F P
0 g
s
.15794 .84955 m .15794 .83102 L .16503 .82266 L p .707 .577 .707 r
F P
0 g
s
.1814 .68355 m .1814 .62797 L .20545 .62232 L p .707 .577 .707 r
F P
0 g
s
.16503 .82266 m .16503 .84119 L .15794 .84955 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.63984 .3631 m .63984 .86499 L .62206 .85386 L p .707 .577 .707 r
F P
0 g
s
.62206 .85386 m .62206 .35197 L .63984 .3631 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76494 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.3253 .62446 m .3253 .68004 L .29784 .67565 L p .707 .577 .707 r
F P
0 g
s
.29784 .67565 m .29784 .62007 L .3253 .62446 L p .707 .577 .707 r
F P
0 g
s
.20545 .62232 m .20545 .6779 L .1814 .68355 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.36607 .86011 m .36607 .35822 L .38918 .34782 L p .707 .577 .707 r
F P
0 g
s
.36607 .35822 m .36607 .86011 L .35607 .87192 L p .707 .577 .707 r
F P
0 g
s
.20545 .6779 m .20545 .62232 L .23483 .61894 L p .707 .577 .707 r
F P
0 g
s
.16503 .84119 m .16503 .82266 L .1814 .81529 L p .707 .577 .707 r
F P
0 g
s
.1814 .76494 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.29784 .62007 m .29784 .67565 L .26667 .67375 L p .707 .577 .707 r
F P
0 g
s
.26667 .67375 m .26667 .61816 L .29784 .62007 L p .707 .577 .707 r
F P
0 g
s
.1814 .81529 m .1814 .83382 L .16503 .84119 L p .707 .577 .707 r
F P
0 g
s
.23483 .67452 m .23483 .61894 L .26667 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61894 m .23483 .67452 L .20545 .6779 L p .707 .577 .707 r
F P
0 g
s
.26667 .61816 m .26667 .67375 L .23483 .67452 L p .707 .577 .707 r
F P
0 g
s
.73333 .67323 m .73333 .61765 L .70216 .61575 L p .707 .577 .707 r
F P
0 g
s
.73333 .61765 m .73333 .67323 L .76517 .67246 L p .707 .577 .707 r
F P
0 g
s
.76517 .67246 m .76517 .61688 L .73333 .61765 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75929 L .1814 .76494 L p .707 .577 .707 r
F P
0 g
s
.76517 .61688 m .76517 .67246 L .79455 .66908 L p .707 .577 .707 r
F P
0 g
s
.79455 .66908 m .79455 .6135 L .76517 .61688 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71998 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.34635 .81823 m .34635 .83676 L .3253 .83031 L p .707 .577 .707 r
F P
0 g
s
.3253 .83031 m .3253 .81178 L .34635 .81823 L p .707 .577 .707 r
F P
0 g
s
.62206 .35197 m .62206 .85386 L .59233 .84475 L p .707 .577 .707 r
F P
0 g
s
.59233 .84475 m .59233 .34286 L .62206 .35197 L p .707 .577 .707 r
F P
0 g
s
.70216 .67133 m .70216 .61575 L .6747 .61136 L p .707 .577 .707 r
F P
0 g
s
.70216 .61575 m .70216 .67133 L .73333 .67323 L p .707 .577 .707 r
F P
0 g
s
.20545 .75929 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.79455 .6135 m .79455 .66908 L .8186 .66343 L p .707 .577 .707 r
F P
0 g
s
.8186 .66343 m .8186 .60785 L .79455 .6135 L p .707 .577 .707 r
F P
0 g
s
.1814 .83382 m .1814 .81529 L .20545 .80964 L p .707 .577 .707 r
F P
0 g
s
.29784 .71998 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71808 L .29784 .71998 L p .707 .577 .707 r
F P
0 g
s
.38918 .34782 m .38918 .84971 L .36607 .86011 L p .707 .577 .707 r
F P
0 g
s
.38918 .84971 m .38918 .34782 L .42314 .33984 L p .707 .577 .707 r
F P
0 g
s
.20545 .80964 m .20545 .82817 L .1814 .83382 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75929 L p .707 .577 .707 r
F P
0 g
s
.6747 .61136 m .6747 .66694 L .70216 .67133 L p .707 .577 .707 r
F P
0 g
s
.6747 .66694 m .6747 .61136 L .65365 .60491 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71808 L p .707 .577 .707 r
F P
0 g
s
.26667 .71808 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.3253 .81178 m .3253 .83031 L .29784 .82591 L p .707 .577 .707 r
F P
0 g
s
.29784 .82591 m .29784 .80739 L .3253 .81178 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71679 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.76517 .71679 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.8186 .60785 m .8186 .66343 L .83497 .65606 L p .707 .577 .707 r
F P
0 g
s
.83497 .65606 m .83497 .60048 L .8186 .60785 L p .707 .577 .707 r
F P
0 g
s
.20545 .82817 m .20545 .80964 L .23483 .80626 L p .707 .577 .707 r
F P
0 g
s
.59233 .34286 m .59233 .84475 L .55357 .83855 L p .707 .577 .707 r
F P
0 g
s
.55357 .83855 m .55357 .33666 L .59233 .34286 L p .707 .577 .707 r
F P
0 g
s
.65365 .60491 m .65365 .66049 L .6747 .66694 L p .707 .577 .707 r
F P
0 g
s
.23483 .80626 m .23483 .82479 L .20545 .82817 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.29784 .80739 m .29784 .82591 L .26667 .82401 L p .707 .577 .707 r
F P
0 g
s
.26667 .82401 m .26667 .80549 L .29784 .80739 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74833 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.65365 .66049 m .65365 .60491 L .64105 .59702 L p .707 .577 .707 r
F P
0 g
s
.23483 .82479 m .23483 .80626 L .26667 .80549 L p .707 .577 .707 r
F P
0 g
s
.42314 .84173 m .42314 .33984 L .46462 .33507 L p .707 .577 .707 r
F P
0 g
s
.42314 .33984 m .42314 .84173 L .38918 .84971 L p .707 .577 .707 r
F P
0 g
s
.26667 .80549 m .26667 .82401 L .23483 .82479 L p .707 .577 .707 r
F P
0 g
s
.6747 .74833 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.73333 .8235 m .73333 .80498 L .70216 .80307 L p .707 .577 .707 r
F P
0 g
s
.73333 .80498 m .73333 .8235 L .76517 .82273 L p .707 .577 .707 r
F P
0 g
s
.76517 .82273 m .76517 .8042 L .73333 .80498 L p .707 .577 .707 r
F P
0 g
s
.76517 .8042 m .76517 .82273 L .79455 .81935 L p .707 .577 .707 r
F P
0 g
s
.79455 .81935 m .79455 .80082 L .76517 .8042 L p .707 .577 .707 r
F P
0 g
s
.70216 .80307 m .70216 .8216 L .73333 .8235 L p .707 .577 .707 r
F P
0 g
s
.70216 .8216 m .70216 .80307 L .6747 .79868 L p .707 .577 .707 r
F P
0 g
s
.55357 .33666 m .55357 .83855 L .50956 .83587 L p .707 .577 .707 r
F P
0 g
s
.50956 .83587 m .50956 .33398 L .55357 .33666 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74833 L p .707 .577 .707 r
F P
0 g
s
.64105 .59702 m .64105 .6526 L .65365 .66049 L p .707 .577 .707 r
F P
0 g
s
.83497 .60048 m .83497 .65606 L .84205 .6477 L p .707 .577 .707 r
F P
0 g
s
.84205 .6477 m .84205 .59211 L .83497 .60048 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73745 L p .707 .577 .707 r
F P
0 g
s
.83497 .73745 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.6747 .79868 m .6747 .81721 L .70216 .8216 L p .707 .577 .707 r
F P
0 g
s
.46462 .83696 m .46462 .33507 L .50956 .33398 L p .707 .577 .707 r
F P
0 g
s
.46462 .33507 m .46462 .83696 L .42314 .84173 L p .707 .577 .707 r
F P
0 g
s
.79455 .80082 m .79455 .81935 L .8186 .8137 L p .707 .577 .707 r
F P
0 g
s
.8186 .8137 m .8186 .79517 L .79455 .80082 L p .707 .577 .707 r
F P
0 g
s
.50956 .33398 m .50956 .83587 L .46462 .83696 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .6526 m .64105 .59702 L .63816 .58848 L p .707 .577 .707 r
F P
0 g
s
.6747 .81721 m .6747 .79868 L .65365 .79223 L p .707 .577 .707 r
F P
0 g
s
.65365 .79223 m .65365 .81076 L .6747 .81721 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.8186 .79517 m .8186 .8137 L .83497 .80633 L p .707 .577 .707 r
F P
0 g
s
.83497 .80633 m .83497 .7878 L .8186 .79517 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73745 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69203 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .58848 m .63816 .64406 L .64105 .6526 L p .707 .577 .707 r
F P
0 g
s
.84205 .59211 m .84205 .6477 L .83916 .63915 L p .707 .577 .707 r
F P
0 g
s
.83916 .63915 m .83916 .58357 L .84205 .59211 L p .707 .577 .707 r
F P
0 g
s
.65365 .81076 m .65365 .79223 L .64105 .78434 L p .707 .577 .707 r
F P
0 g
s
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.64105 .78434 m .64105 .80287 L .65365 .81076 L p .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .63816 .58848 L .64524 .58011 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72545 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83497 .7878 m .83497 .80633 L .84206 .79796 L p .707 .577 .707 r
F P
0 g
s
.84206 .79796 m .84206 .77944 L .83497 .7878 L p .707 .577 .707 r
F P
0 g
s
.84206 .69203 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69203 L p .707 .577 .707 r
F P
0 g
s
.64524 .58011 m .64524 .6357 L .63816 .64406 L p .707 .577 .707 r
F P
0 g
s
.83916 .58357 m .83916 .63915 L .82657 .63127 L p .707 .577 .707 r
F P
0 g
s
.82657 .63127 m .82657 .57569 L .83916 .58357 L p .707 .577 .707 r
F P
0 g
s
.64105 .80287 m .64105 .78434 L .63816 .7758 L p .707 .577 .707 r
F P
0 g
s
.63816 .7758 m .63816 .79433 L .64105 .80287 L p .707 .577 .707 r
F P
0 g
s
.39032 .63642 m .39032 .58084 L .35915 .57894 L p .707 .577 .707 r
F P
0 g
s
.39032 .58084 m .39032 .63642 L .42216 .63564 L p .707 .577 .707 r
F P
0 g
s
.42216 .63564 m .42216 .58006 L .39032 .58084 L p .707 .577 .707 r
F P
0 g
s
.63816 .72545 m .63816 .68839 L .64524 .68003 L p .707 .577 .707 r
F P
0 g
s
.64524 .6357 m .64524 .58011 L .66161 .57275 L p .707 .577 .707 r
F P
0 g
s
.42216 .58006 m .42216 .63564 L .45154 .63226 L p .707 .577 .707 r
F P
0 g
s
.45154 .63226 m .45154 .57668 L .42216 .58006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35915 .63452 m .35915 .57894 L .33169 .57454 L p .707 .577 .707 r
F P
0 g
s
.35915 .57894 m .35915 .63452 L .39032 .63642 L p .707 .577 .707 r
F P
0 g
s
.64524 .68003 m .64524 .71708 L .63816 .72545 L p .707 .577 .707 r
F P
0 g
s
.84206 .77944 m .84206 .79796 L .83916 .78942 L p .707 .577 .707 r
F P
0 g
s
.83916 .78942 m .83916 .77089 L .84206 .77944 L p .707 .577 .707 r
F P
0 g
s
.45154 .57668 m .45154 .63226 L .47559 .62661 L p .707 .577 .707 r
F P
0 g
s
.47559 .62661 m .47559 .57103 L .45154 .57668 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .57275 m .66161 .62833 L .64524 .6357 L p .707 .577 .707 r
F P
0 g
s
.82657 .57569 m .82657 .63127 L .80551 .62482 L p .707 .577 .707 r
F P
0 g
s
.80551 .62482 m .80551 .56923 L .82657 .57569 L p .707 .577 .707 r
F P
0 g
s
.33169 .57454 m .33169 .63013 L .35915 .63452 L p .707 .577 .707 r
F P
0 g
s
.33169 .63013 m .33169 .57454 L .31064 .56809 L p .707 .577 .707 r
F P
0 g
s
.63816 .79433 m .63816 .7758 L .64524 .76744 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71703 L p .707 .577 .707 r
F P
0 g
s
.42216 .71703 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.66161 .62833 m .66161 .57275 L .68566 .5671 L p .707 .577 .707 r
F P
0 g
s
.64524 .76744 m .64524 .78596 L .63816 .79433 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68003 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71703 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67446 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.47559 .57103 m .47559 .62661 L .49196 .61925 L p .707 .577 .707 r
F P
0 g
s
.49196 .61925 m .49196 .56366 L .47559 .57103 L p .707 .577 .707 r
F P
0 g
s
.31064 .56809 m .31064 .62367 L .33169 .63013 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.80551 .56923 m .80551 .62482 L .77805 .62042 L p .707 .577 .707 r
F P
0 g
s
.77805 .62042 m .77805 .56484 L .80551 .56923 L p .707 .577 .707 r
F P
0 g
s
.83916 .77089 m .83916 .78942 L .82657 .78154 L p .707 .577 .707 r
F P
0 g
s
.82657 .78154 m .82657 .76301 L .83916 .77089 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.68566 .5671 m .68566 .62268 L .66161 .62833 L p .707 .577 .707 r
F P
0 g
s
.33169 .67446 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.31064 .62367 m .31064 .56809 L .29804 .56021 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66915 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.68566 .62268 m .68566 .5671 L .71504 .56372 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67446 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.39032 .78669 m .39032 .76816 L .35915 .76626 L p .707 .577 .707 r
F P
0 g
s
.39032 .76816 m .39032 .78669 L .42216 .78591 L p .707 .577 .707 r
F P
0 g
s
.42216 .78591 m .42216 .76738 L .39032 .76816 L p .707 .577 .707 r
F P
0 g
s
.64524 .78596 m .64524 .76744 L .66161 .76007 L p .707 .577 .707 r
F P
0 g
s
.42216 .76738 m .42216 .78591 L .45154 .78253 L p .707 .577 .707 r
F P
0 g
s
.45154 .78253 m .45154 .764 L .42216 .76738 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.35915 .76626 m .35915 .78479 L .39032 .78669 L p .707 .577 .707 r
F P
0 g
s
.77805 .56484 m .77805 .62042 L .74688 .61852 L p .707 .577 .707 r
F P
0 g
s
.74688 .61852 m .74688 .56294 L .77805 .56484 L p .707 .577 .707 r
F P
0 g
s
.35915 .78479 m .35915 .76626 L .33169 .76187 L p .707 .577 .707 r
F P
0 g
s
.66161 .76007 m .66161 .7786 L .64524 .78596 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70506 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.29804 .56021 m .29804 .61579 L .31064 .62367 L p .707 .577 .707 r
F P
0 g
s
.71504 .6193 m .71504 .56372 L .74688 .56294 L p .707 .577 .707 r
F P
0 g
s
.71504 .56372 m .71504 .6193 L .68566 .62268 L p .707 .577 .707 r
F P
0 g
s
.49196 .56366 m .49196 .61925 L .49904 .61088 L p .707 .577 .707 r
F P
0 g
s
.49904 .61088 m .49904 .5553 L .49196 .56366 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66358 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.33169 .76187 m .33169 .78039 L .35915 .78479 L p .707 .577 .707 r
F P
0 g
s
.74688 .56294 m .74688 .61852 L .71504 .6193 L p .707 .577 .707 r
F P
0 g
s
.45154 .764 m .45154 .78253 L .47559 .77688 L p .707 .577 .707 r
F P
0 g
s
.47559 .77688 m .47559 .75835 L .45154 .764 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66915 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66915 L p .707 .577 .707 r
F P
0 g
s
.82657 .76301 m .82657 .78154 L .80551 .77508 L p .707 .577 .707 r
F P
0 g
s
.80551 .77508 m .80551 .75656 L .82657 .76301 L p .707 .577 .707 r
F P
0 g
s
.31064 .70506 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.29804 .61579 m .29804 .56021 L .29515 .55166 L p .707 .577 .707 r
F P
0 g
s
.33169 .78039 m .33169 .76187 L .31064 .75541 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.31064 .75541 m .31064 .77394 L .33169 .78039 L p .707 .577 .707 r
F P
0 g
s
.66161 .7786 m .66161 .76007 L .68566 .75442 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70506 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.68566 .75442 m .68566 .77295 L .66161 .7786 L p .707 .577 .707 r
F P
0 g
s
.47559 .75835 m .47559 .77688 L .49196 .76951 L p .707 .577 .707 r
F P
0 g
s
.49196 .76951 m .49196 .75099 L .47559 .75835 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66358 m .49196 .70063 L .49904 .69227 L p .707 .577 .707 r
F P
0 g
s
.49904 .69227 m .49904 .65521 L .49196 .66358 L p .707 .577 .707 r
F P
0 g
s
.29515 .55166 m .29515 .60725 L .29804 .61579 L p .707 .577 .707 r
F P
0 g
s
.49904 .5553 m .49904 .61088 L .49615 .60234 L p .707 .577 .707 r
F P
0 g
s
.49615 .60234 m .49615 .54676 L .49904 .5553 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.80551 .75656 m .80551 .77508 L .77805 .77069 L p .707 .577 .707 r
F P
0 g
s
.77805 .77069 m .77805 .75216 L .80551 .75656 L p .707 .577 .707 r
F P
0 g
s
.31064 .77394 m .31064 .75541 L .29804 .74753 L p .707 .577 .707 r
F P
0 g
s
.68566 .77295 m .68566 .75442 L .71504 .75104 L p .707 .577 .707 r
F P
0 g
s
.29804 .69717 m .29804 .66012 L .29515 .65158 L p .707 .577 .707 r
F P
0 g
s
.29804 .74753 m .29804 .76606 L .31064 .77394 L p .707 .577 .707 r
F P
0 g
s
.29515 .60725 m .29515 .55166 L .30223 .5433 L p .707 .577 .707 r
F P
0 g
s
.71504 .75104 m .71504 .76957 L .68566 .77295 L p .707 .577 .707 r
F P
0 g
s
.77805 .75216 m .77805 .77069 L .74688 .76879 L p .707 .577 .707 r
F P
0 g
s
.74688 .76879 m .74688 .75026 L .77805 .75216 L p .707 .577 .707 r
F P
0 g
s
.29515 .65158 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.71504 .76957 m .71504 .75104 L .74688 .75026 L p .707 .577 .707 r
F P
0 g
s
.49196 .75099 m .49196 .76951 L .49904 .76115 L p .707 .577 .707 r
F P
0 g
s
.49904 .76115 m .49904 .74262 L .49196 .75099 L p .707 .577 .707 r
F P
0 g
s
.74688 .75026 m .74688 .76879 L .71504 .76957 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69227 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .5433 m .30223 .59888 L .29515 .60725 L p .707 .577 .707 r
F P
0 g
s
.49615 .54676 m .49615 .60234 L .48356 .59445 L p .707 .577 .707 r
F P
0 g
s
.48356 .59445 m .48356 .53887 L .49615 .54676 L p .707 .577 .707 r
F P
0 g
s
.29804 .76606 m .29804 .74753 L .29515 .73899 L p .707 .577 .707 r
F P
0 g
s
.29515 .73899 m .29515 .75751 L .29804 .76606 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65158 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .59888 m .30223 .5433 L .3186 .53593 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .64321 m .30223 .68027 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49904 .74262 m .49904 .76115 L .49615 .75261 L p .707 .577 .707 r
F P
0 g
s
.49615 .75261 m .49615 .73408 L .49904 .74262 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .53593 m .3186 .59151 L .30223 .59888 L p .707 .577 .707 r
F P
0 g
s
.48356 .53887 m .48356 .59445 L .4625 .588 L p .707 .577 .707 r
F P
0 g
s
.4625 .588 m .4625 .53242 L .48356 .53887 L p .707 .577 .707 r
F P
0 g
s
.29515 .75751 m .29515 .73899 L .30223 .73062 L p .707 .577 .707 r
F P
0 g
s
.3186 .59151 m .3186 .53593 L .34265 .53028 L p .707 .577 .707 r
F P
0 g
s
.30223 .73062 m .30223 .74915 L .29515 .75751 L p .707 .577 .707 r
F P
0 g
s
.30223 .68027 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68027 L p .707 .577 .707 r
F P
0 g
s
.4625 .53242 m .4625 .588 L .43504 .58361 L p .707 .577 .707 r
F P
0 g
s
.43504 .58361 m .43504 .52803 L .4625 .53242 L p .707 .577 .707 r
F P
0 g
s
.49615 .73408 m .49615 .75261 L .48356 .74472 L p .707 .577 .707 r
F P
0 g
s
.48356 .74472 m .48356 .7262 L .49615 .73408 L p .707 .577 .707 r
F P
0 g
s
.34265 .53028 m .34265 .58586 L .3186 .59151 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66939 L p .707 .577 .707 r
F P
0 g
s
.4625 .66939 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.34265 .58586 m .34265 .53028 L .37203 .5269 L p .707 .577 .707 r
F P
0 g
s
.30223 .74915 m .30223 .73062 L .3186 .72325 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.43504 .52803 m .43504 .58361 L .40387 .58171 L p .707 .577 .707 r
F P
0 g
s
.40387 .58171 m .40387 .52613 L .43504 .52803 L p .707 .577 .707 r
F P
0 g
s
.3186 .72325 m .3186 .74178 L .30223 .74915 L p .707 .577 .707 r
F P
0 g
s
.37203 .58249 m .37203 .5269 L .40387 .52613 L p .707 .577 .707 r
F P
0 g
s
.37203 .5269 m .37203 .58249 L .34265 .58586 L p .707 .577 .707 r
F P
0 g
s
.40387 .52613 m .40387 .58171 L .37203 .58249 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66939 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.48356 .7262 m .48356 .74472 L .4625 .73827 L p .707 .577 .707 r
F P
0 g
s
.4625 .73827 m .4625 .71974 L .48356 .7262 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.3186 .74178 m .3186 .72325 L .34265 .7176 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.34265 .7176 m .34265 .73613 L .3186 .74178 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
.4625 .71974 m .4625 .73827 L .43504 .73388 L p .707 .577 .707 r
F P
0 g
s
.43504 .73388 m .43504 .71535 L .4625 .71974 L p .707 .577 .707 r
F P
0 g
s
.34265 .73613 m .34265 .7176 L .37203 .71423 L p .707 .577 .707 r
F P
0 g
s
.37203 .71423 m .37203 .73275 L .34265 .73613 L p .707 .577 .707 r
F P
0 g
s
.43504 .71535 m .43504 .73388 L .40387 .73198 L p .707 .577 .707 r
F P
0 g
s
.40387 .73198 m .40387 .71345 L .43504 .71535 L p .707 .577 .707 r
F P
0 g
s
.37203 .73275 m .37203 .71423 L .40387 .71345 L p .707 .577 .707 r
F P
0 g
s
.40387 .71345 m .40387 .73198 L .37203 .73275 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol007moob4007eoo`00MWoo2@001EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<000UJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool0
06Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001W
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001J
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001C
Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<0
05YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001J
EP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06
001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo0017Ool90004Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h000AJEP03001JEUYF009J
EPL00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH:0008
FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP0
00QJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF
00IJEQT00003FUH005YF009JEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000=JEP03001JEP0000=JEP<00004FUH0
00000002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF1P00
00=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<0
05YFFUH01UYF100000=JEP00FUH00P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool00`00
FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH3000`Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004FUH0
1000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD000=JEP04001JEUYFFUH2000LOol400000eYF
001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH00`00FUIJEP05FUH900000eYF001J
EP03FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P000eYF1P000eYF0P005Goo1`000eYF0`000eYF0P00;Goo000`Ool30004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUH0000;0004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@001Goo
0`0000=oo`0000001`000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUHI00000eYF001JEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000fOol90003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@00
15YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000cOol40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00;Woo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF20000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP@000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEP80009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00AJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP@0009JEQ`003Yoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF4@000eYF0P000UYF0`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol002aoo`03001J
EP0000AJEP03001JEUYF00=JEPH0015oo`D000=JEP03001JEP00008000EJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
00000eYF0000000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH4000fOol002aoo`03001JEP0000AJEP03001JEP0000<001Yoo`8000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04000bOol002aoo`03001JEP0000=JEPL001]oo`05001JEUYFFUH00005FUH01000
FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20000
0eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH2000aOol002aoo`04001JEP00FUH20005FUH00`00FUH00003000HOol01000FUIJ
EP001EYF00<005YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002moo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP03FUHL0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YF00000P000UYF00<005YFFUH00P006Goo1@0015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YF000010001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`001EYF00D005YFFUIJEP0001ioo`<00003FUH005YF009JEP8002eoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF001JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000POol20003FUH2000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF6@001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2
000ROol200000eYF0000000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002=oo`@002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH2
000QOol2000015YF00000000;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000<000AJEP04001JEUYFFUH2000L
Ool50003FUH00`00FUH0000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH60003FUH2000EOol70003FUH00`00FUIJEP02FUH2
000^Ool003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000kOolP000:Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH000080004FUH00`00FUIJEP02FUH9000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004Ool90018Ool0
02eoo`8000AJEP03001JEUYF00=JEPH001Moo`@0009JEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00EWoo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00@005YF000005Qoo`00;7oo00<005YF00000eYF0`00:Woo10000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00=JEP<005Yoo`00;7oo00@005YF001JEP80035oo`03
001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09
FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH00003001MOol0
02aoo`04001JEP00000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH60002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004001QOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00008006=oo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P000UYF
00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool2
0003FUH00`00FUIJEP02FUH3000ROol400000eYF001JEP02FUH20002FUH01000FUIJEUYF0P001EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
100015YF00<005YF00001EYF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF00001EYF00<005YF
00000`006Goo1@001EYF00@005YFFUIJEP80009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF
00<005YF00001EYF00<005YFFUH00UYF0P00FGoo000^Ool01000FUIJEP001EYF00<005YFFUH00eYF
6@000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP<00003FUH005YF00AJEP03001JEUYF00=JEP<005Moo`00;goo0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YFFUH007oo001J
EP000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00=JEP03
001JEUYF008005Eoo`00<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0`000Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
0P0000AJEP00Oomoo`D000AJEP05001JEUYFFUH0001EOol003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40004Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001goo0`0000=JEP00FUH00UYF0P00E7oo000fOol50004
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH70008Ool20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000002Woo0P000eYF0P00E7oo000kOolK000?Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0037oo0P0000=JEP000000E7oo001VOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000>Ool4001DOol006Ioo`03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000eoo`800004FUH00000001DOol006Moo`80009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000Uoo`D000=JEP03001JEP0005Aoo`00JGoo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YFFUIJEP8000Aoo`L000=JEP03001JEUYF009JEP03001JEP0005Aoo`00Jgoo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YF00001`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001]Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo001_Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000F7oo001bOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001J
Ool007Uoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<005eoo`00QGoo5P0000=oo`0000001`0015YF00<005YFFUH01UYF00<005YF
FUH00UYF1@00HGoo002UOolB001VOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75925 m .59613 .70366 L .56496 .70176 L p .707 .577 .707 r
F P
0 g
s
.59613 .70366 m .59613 .75925 L .62796 .75847 L p .707 .577 .707 r
F P
0 g
s
.62796 .75847 m .62796 .70289 L .59613 .70366 L p .707 .577 .707 r
F P
0 g
s
.62796 .70289 m .62796 .75847 L .65735 .75509 L p .707 .577 .707 r
F P
0 g
s
.65735 .75509 m .65734 .69951 L .62796 .70289 L p .707 .577 .707 r
F P
0 g
s
.56496 .75735 m .56496 .70176 L .5375 .69737 L p .707 .577 .707 r
F P
0 g
s
.56496 .70176 m .56496 .75735 L .59613 .75925 L p .707 .577 .707 r
F P
0 g
s
.65734 .69951 m .65735 .75509 L .6814 .74944 L p .707 .577 .707 r
F P
0 g
s
.6814 .74944 m .6814 .69386 L .65734 .69951 L p .707 .577 .707 r
F P
0 g
s
.5375 .69737 m .5375 .75295 L .56496 .75735 L p .707 .577 .707 r
F P
0 g
s
.5375 .75295 m .5375 .69737 L .51644 .69092 L p .707 .577 .707 r
F P
0 g
s
.59613 .8326 m .59613 .79555 L .56496 .79365 L p .707 .577 .707 r
F P
0 g
s
.59613 .79555 m .59613 .8326 L .62796 .83182 L p .707 .577 .707 r
F P
0 g
s
.62796 .83182 m .62796 .79477 L .59613 .79555 L p .707 .577 .707 r
F P
0 g
s
.62796 .79477 m .62796 .83182 L .65735 .82844 L p .707 .577 .707 r
F P
0 g
s
.65735 .82844 m .65735 .79139 L .62796 .79477 L p .707 .577 .707 r
F P
0 g
s
.56496 .8307 m .56496 .79365 L .5375 .78925 L p .707 .577 .707 r
F P
0 g
s
.56496 .79365 m .56496 .8307 L .59613 .8326 L p .707 .577 .707 r
F P
0 g
s
.6814 .69386 m .6814 .74944 L .69777 .74207 L p .707 .577 .707 r
F P
0 g
s
.69777 .74207 m .69777 .68649 L .6814 .69386 L p .707 .577 .707 r
F P
0 g
s
.51644 .69092 m .51644 .7465 L .5375 .75295 L p .707 .577 .707 r
F P
0 g
s
.65735 .79139 m .65735 .82844 L .6814 .8228 L p .707 .577 .707 r
F P
0 g
s
.6814 .8228 m .6814 .78574 L .65735 .79139 L p .707 .577 .707 r
F P
0 g
s
.5375 .78925 m .5375 .82631 L .56496 .8307 L p .707 .577 .707 r
F P
0 g
s
.51644 .7465 m .51644 .69092 L .50385 .68303 L p .707 .577 .707 r
F P
0 g
s
.59613 .89115 m .59613 .87263 L .56496 .87072 L p .707 .577 .707 r
F P
0 g
s
.59613 .87263 m .59613 .89115 L .62796 .89038 L p .707 .577 .707 r
F P
0 g
s
.62796 .89038 m .62796 .87185 L .59613 .87263 L p .707 .577 .707 r
F P
0 g
s
.5375 .82631 m .5375 .78925 L .51644 .7828 L p .707 .577 .707 r
F P
0 g
s
.62796 .87185 m .62796 .89038 L .65735 .887 L p .707 .577 .707 r
F P
0 g
s
.65735 .887 m .65735 .86847 L .62796 .87185 L p .707 .577 .707 r
F P
0 g
s
.56496 .87072 m .56496 .88925 L .59613 .89115 L p .707 .577 .707 r
F P
0 g
s
.56496 .88925 m .56496 .87072 L .5375 .86633 L p .707 .577 .707 r
F P
0 g
s
.51644 .7828 m .51644 .81985 L .5375 .82631 L p .707 .577 .707 r
F P
0 g
s
.5375 .86633 m .5375 .88486 L .56496 .88925 L p .707 .577 .707 r
F P
0 g
s
.6814 .78574 m .6814 .8228 L .69777 .81543 L p .707 .577 .707 r
F P
0 g
s
.69777 .81543 m .69777 .77837 L .6814 .78574 L p .707 .577 .707 r
F P
0 g
s
.50385 .68303 m .50385 .73862 L .51644 .7465 L p .707 .577 .707 r
F P
0 g
s
.69777 .68649 m .69777 .74207 L .70485 .73371 L p .707 .577 .707 r
F P
0 g
s
.70485 .73371 m .70485 .67813 L .69777 .68649 L p .707 .577 .707 r
F P
0 g
s
.65735 .86847 m .65735 .887 L .6814 .88135 L p .707 .577 .707 r
F P
0 g
s
.6814 .88135 m .6814 .86282 L .65735 .86847 L p .707 .577 .707 r
F P
0 g
s
.5375 .88486 m .5375 .86633 L .51644 .85988 L p .707 .577 .707 r
F P
0 g
s
.51644 .81985 m .51644 .7828 L .50385 .77492 L p .707 .577 .707 r
F P
0 g
s
.50385 .73862 m .50385 .68303 L .50095 .67449 L p .707 .577 .707 r
F P
0 g
s
.51644 .85988 m .51644 .87841 L .5375 .88486 L p .707 .577 .707 r
F P
0 g
s
.50385 .77492 m .50385 .81197 L .51644 .81985 L p .707 .577 .707 r
F P
0 g
s
.6814 .86282 m .6814 .88135 L .69777 .87398 L p .707 .577 .707 r
F P
0 g
s
.69777 .87398 m .69777 .85545 L .6814 .86282 L p .707 .577 .707 r
F P
0 g
s
.69777 .77837 m .69777 .81543 L .70485 .80706 L p .707 .577 .707 r
F P
0 g
s
.70485 .80706 m .70485 .77001 L .69777 .77837 L p .707 .577 .707 r
F P
0 g
s
.50095 .67449 m .50095 .73007 L .50385 .73862 L p .707 .577 .707 r
F P
0 g
s
.70485 .67813 m .70485 .73371 L .70195 .72517 L p .707 .577 .707 r
F P
0 g
s
.70195 .72517 m .70195 .66958 L .70485 .67813 L p .707 .577 .707 r
F P
0 g
s
.51644 .87841 m .51644 .85988 L .50385 .85199 L p .707 .577 .707 r
F P
0 g
s
.50385 .85199 m .50385 .87052 L .51644 .87841 L p .707 .577 .707 r
F P
0 g
s
.50385 .81197 m .50385 .77492 L .50095 .76637 L p .707 .577 .707 r
F P
0 g
s
.50095 .73007 m .50095 .67449 L .50804 .66613 L p .707 .577 .707 r
F P
0 g
s
.69777 .85545 m .69777 .87398 L .70485 .86561 L p .707 .577 .707 r
F P
0 g
s
.70485 .86561 m .70485 .84709 L .69777 .85545 L p .707 .577 .707 r
F P
0 g
s
.50095 .76637 m .50095 .80343 L .50385 .81197 L p .707 .577 .707 r
F P
0 g
s
.49044 .87824 m .49044 .37636 L .44643 .37367 L p .707 .577 .707 r
F P
0 g
s
.50804 .66613 m .50804 .72171 L .50095 .73007 L p .707 .577 .707 r
F P
0 g
s
.50385 .87052 m .50385 .85199 L .50095 .84345 L p .707 .577 .707 r
F P
0 g
s
.50095 .84345 m .50095 .86198 L .50385 .87052 L p .707 .577 .707 r
F P
0 g
s
.50095 .80343 m .50095 .76637 L .50804 .75801 L p .707 .577 .707 r
F P
0 g
s
.50804 .72171 m .50804 .66613 L .5244 .65876 L p .707 .577 .707 r
F P
0 g
s
.50804 .75801 m .50804 .79506 L .50095 .80343 L p .707 .577 .707 r
F P
0 g
s
.5244 .65876 m .5244 .71434 L .50804 .72171 L p .707 .577 .707 r
F P
0 g
s
.50095 .86198 m .50095 .84345 L .50804 .83509 L p .707 .577 .707 r
F P
0 g
s
.50804 .83509 m .50804 .85362 L .50095 .86198 L p .707 .577 .707 r
F P
0 g
s
.50804 .79506 m .50804 .75801 L .5244 .75064 L p .707 .577 .707 r
F P
0 g
s
.5244 .75064 m .5244 .7877 L .50804 .79506 L p .707 .577 .707 r
F P
0 g
s
.50804 .85362 m .50804 .83509 L .5244 .82772 L p .707 .577 .707 r
F P
0 g
s
.5244 .7877 m .5244 .75064 L .54846 .74499 L p .707 .577 .707 r
F P
0 g
s
.5244 .82772 m .5244 .84625 L .50804 .85362 L p .707 .577 .707 r
F P
0 g
s
.54846 .74499 m .54846 .78205 L .5244 .7877 L p .707 .577 .707 r
F P
0 g
s
.5244 .84625 m .5244 .82772 L .54846 .82207 L p .707 .577 .707 r
F P
0 g
s
.54846 .82207 m .54846 .8406 L .5244 .84625 L p .707 .577 .707 r
F P
0 g
s
.49044 .37636 m .49044 .87824 L .53538 .87715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71434 m .5244 .65876 L .54846 .65311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65311 m .54846 .70869 L .5244 .71434 L p .707 .577 .707 r
F P
0 g
s
.53538 .87715 m .53538 .37526 L .49044 .37636 L p .707 .577 .707 r
F P
0 g
s
.70485 .77001 m .70485 .80706 L .70195 .79852 L p .707 .577 .707 r
F P
0 g
s
.70195 .79852 m .70195 .76147 L .70485 .77001 L p .707 .577 .707 r
F P
0 g
s
.54846 .70869 m .54846 .65311 L .57784 .64973 L p .707 .577 .707 r
F P
0 g
s
.57784 .64973 m .57784 .70531 L .54846 .70869 L p .707 .577 .707 r
F P
0 g
s
.54846 .78205 m .54846 .74499 L .57784 .74161 L p .707 .577 .707 r
F P
0 g
s
.57784 .74161 m .57784 .77867 L .54846 .78205 L p .707 .577 .707 r
F P
0 g
s
.54846 .8406 m .54846 .82207 L .57784 .81869 L p .707 .577 .707 r
F P
0 g
s
.57784 .81869 m .57784 .83722 L .54846 .8406 L p .707 .577 .707 r
F P
0 g
s
.53538 .37526 m .53538 .87715 L .57686 .87238 L p .707 .577 .707 r
F P
0 g
s
.57686 .87238 m .57686 .37049 L .53538 .37526 L p .707 .577 .707 r
F P
0 g
s
.70195 .66958 m .70195 .72517 L .68936 .71728 L p .707 .577 .707 r
F P
0 g
s
.68936 .71728 m .68936 .6617 L .70195 .66958 L p .707 .577 .707 r
F P
0 g
s
.44643 .87556 m .44643 .37367 L .40766 .36747 L p .707 .577 .707 r
F P
0 g
s
.44643 .37367 m .44643 .87556 L .49044 .87824 L p .707 .577 .707 r
F P
0 g
s
.25312 .72243 m .25312 .66685 L .22195 .66495 L p .707 .577 .707 r
F P
0 g
s
.25312 .66685 m .25312 .72243 L .28495 .72165 L p .707 .577 .707 r
F P
0 g
s
.28495 .72165 m .28495 .66607 L .25312 .66685 L p .707 .577 .707 r
F P
0 g
s
.28495 .66607 m .28495 .72165 L .31434 .71828 L p .707 .577 .707 r
F P
0 g
s
.31434 .71828 m .31434 .66269 L .28495 .66607 L p .707 .577 .707 r
F P
0 g
s
.57784 .70531 m .57784 .64973 L .60968 .64895 L p .707 .577 .707 r
F P
0 g
s
.60968 .64895 m .60968 .70454 L .57784 .70531 L p .707 .577 .707 r
F P
0 g
s
.57784 .77867 m .57784 .74161 L .60968 .74084 L p .707 .577 .707 r
F P
0 g
s
.60968 .74084 m .60968 .77789 L .57784 .77867 L p .707 .577 .707 r
F P
0 g
s
.57784 .83722 m .57784 .81869 L .60968 .81791 L p .707 .577 .707 r
F P
0 g
s
.60968 .81791 m .60968 .83644 L .57784 .83722 L p .707 .577 .707 r
F P
0 g
s
.57686 .37049 m .57686 .87238 L .61082 .8644 L p .707 .577 .707 r
F P
0 g
s
.64085 .65085 m .64085 .70644 L .60968 .70454 L p .707 .577 .707 r
F P
0 g
s
.60968 .70454 m .60968 .64895 L .64085 .65085 L p .707 .577 .707 r
F P
0 g
s
.64085 .74274 m .64085 .77979 L .60968 .77789 L p .707 .577 .707 r
F P
0 g
s
.60968 .77789 m .60968 .74084 L .64085 .74274 L p .707 .577 .707 r
F P
0 g
s
.64085 .81982 m .64085 .83834 L .60968 .83644 L p .707 .577 .707 r
F P
0 g
s
.60968 .83644 m .60968 .81791 L .64085 .81982 L p .707 .577 .707 r
F P
0 g
s
.61082 .8644 m .61082 .36251 L .57686 .37049 L p .707 .577 .707 r
F P
0 g
s
.70485 .84709 m .70485 .86561 L .70195 .85707 L p .707 .577 .707 r
F P
0 g
s
.70195 .85707 m .70195 .83855 L .70485 .84709 L p .707 .577 .707 r
F P
0 g
s
.22195 .72053 m .22195 .66495 L .19449 .66056 L p .707 .577 .707 r
F P
0 g
s
.22195 .66495 m .22195 .72053 L .25312 .72243 L p .707 .577 .707 r
F P
0 g
s
.40766 .86936 m .40766 .36747 L .37794 .35836 L p .707 .577 .707 r
F P
0 g
s
.40766 .36747 m .40766 .86936 L .44643 .87556 L p .707 .577 .707 r
F P
0 g
s
.31434 .66269 m .31434 .71828 L .33839 .71263 L p .707 .577 .707 r
F P
0 g
s
.33839 .71263 m .33839 .65704 L .31434 .66269 L p .707 .577 .707 r
F P
0 g
s
.70195 .76147 m .70195 .79852 L .68936 .79064 L p .707 .577 .707 r
F P
0 g
s
.68936 .79064 m .68936 .75358 L .70195 .76147 L p .707 .577 .707 r
F P
0 g
s
.68936 .6617 m .68936 .71728 L .66831 .71083 L p .707 .577 .707 r
F P
0 g
s
.66831 .71083 m .66831 .65525 L .68936 .6617 L p .707 .577 .707 r
F P
0 g
s
.19449 .66056 m .19449 .71614 L .22195 .72053 L p .707 .577 .707 r
F P
0 g
s
.19449 .71614 m .19449 .66056 L .17343 .6541 L p .707 .577 .707 r
F P
0 g
s
.25312 .79579 m .25312 .75873 L .22195 .75683 L p .707 .577 .707 r
F P
0 g
s
.25312 .75873 m .25312 .79579 L .28495 .79501 L p .707 .577 .707 r
F P
0 g
s
.28495 .79501 m .28495 .75795 L .25312 .75873 L p .707 .577 .707 r
F P
0 g
s
.28495 .75795 m .28495 .79501 L .31434 .79163 L p .707 .577 .707 r
F P
0 g
s
.31434 .79163 m .31434 .75457 L .28495 .75795 L p .707 .577 .707 r
F P
0 g
s
.61082 .36251 m .61082 .8644 L .63393 .854 L p .707 .577 .707 r
F P
0 g
s
.63393 .854 m .63393 .35211 L .61082 .36251 L p .707 .577 .707 r
F P
0 g
s
.22195 .79389 m .22195 .75683 L .19449 .75244 L p .707 .577 .707 r
F P
0 g
s
.22195 .75683 m .22195 .79389 L .25312 .79579 L p .707 .577 .707 r
F P
0 g
s
.33839 .65704 m .33839 .71263 L .35476 .70526 L p .707 .577 .707 r
F P
0 g
s
.35476 .70526 m .35476 .64968 L .33839 .65704 L p .707 .577 .707 r
F P
0 g
s
.70195 .83855 m .70195 .85707 L .68936 .84919 L p .707 .577 .707 r
F P
0 g
s
.68936 .84919 m .68936 .83066 L .70195 .83855 L p .707 .577 .707 r
F P
0 g
s
.17343 .6541 m .17343 .70968 L .19449 .71614 L p .707 .577 .707 r
F P
0 g
s
.31434 .75457 m .31434 .79163 L .33839 .78598 L p .707 .577 .707 r
F P
0 g
s
.33839 .78598 m .33839 .74893 L .31434 .75457 L p .707 .577 .707 r
F P
0 g
s
.66831 .65525 m .66831 .71083 L .64085 .70644 L p .707 .577 .707 r
F P
0 g
s
.64085 .70644 m .64085 .65085 L .66831 .65525 L p .707 .577 .707 r
F P
0 g
s
.19449 .75244 m .19449 .78949 L .22195 .79389 L p .707 .577 .707 r
F P
0 g
s
.68936 .75358 m .68936 .79064 L .66831 .78418 L p .707 .577 .707 r
F P
0 g
s
.66831 .78418 m .66831 .74713 L .68936 .75358 L p .707 .577 .707 r
F P
0 g
s
.17343 .70968 m .17343 .6541 L .16084 .64622 L p .707 .577 .707 r
F P
0 g
s
.37794 .86025 m .37794 .35836 L .36016 .34723 L p .707 .577 .707 r
F P
0 g
s
.37794 .35836 m .37794 .86025 L .40766 .86936 L p .707 .577 .707 r
F P
0 g
s
.25312 .85434 m .25312 .83581 L .22195 .83391 L p .707 .577 .707 r
F P
0 g
s
.25312 .83581 m .25312 .85434 L .28495 .85356 L p .707 .577 .707 r
F P
0 g
s
.28495 .85356 m .28495 .83503 L .25312 .83581 L p .707 .577 .707 r
F P
0 g
s
.19449 .78949 m .19449 .75244 L .17343 .74598 L p .707 .577 .707 r
F P
0 g
s
.28495 .83503 m .28495 .85356 L .31434 .85018 L p .707 .577 .707 r
F P
0 g
s
.31434 .85018 m .31434 .83165 L .28495 .83503 L p .707 .577 .707 r
F P
0 g
s
.22195 .83391 m .22195 .85244 L .25312 .85434 L p .707 .577 .707 r
F P
0 g
s
.22195 .85244 m .22195 .83391 L .19449 .82952 L p .707 .577 .707 r
F P
0 g
s
.17343 .74598 m .17343 .78304 L .19449 .78949 L p .707 .577 .707 r
F P
0 g
s
.19449 .82952 m .19449 .84804 L .22195 .85244 L p .707 .577 .707 r
F P
0 g
s
.33839 .74893 m .33839 .78598 L .35476 .77861 L p .707 .577 .707 r
F P
0 g
s
.35476 .77861 m .35476 .74156 L .33839 .74893 L p .707 .577 .707 r
F P
0 g
s
.16084 .64622 m .16084 .7018 L .17343 .70968 L p .707 .577 .707 r
F P
0 g
s
.35476 .64968 m .35476 .70526 L .36184 .69689 L p .707 .577 .707 r
F P
0 g
s
.36184 .69689 m .36184 .64131 L .35476 .64968 L p .707 .577 .707 r
F P
0 g
s
.31434 .83165 m .31434 .85018 L .33839 .84453 L p .707 .577 .707 r
F P
0 g
s
.33839 .84453 m .33839 .826 L .31434 .83165 L p .707 .577 .707 r
F P
0 g
s
.68936 .83066 m .68936 .84919 L .66831 .84273 L p .707 .577 .707 r
F P
0 g
s
.66831 .84273 m .66831 .82421 L .68936 .83066 L p .707 .577 .707 r
F P
0 g
s
.66831 .74713 m .66831 .78418 L .64085 .77979 L p .707 .577 .707 r
F P
0 g
s
.64085 .77979 m .64085 .74274 L .66831 .74713 L p .707 .577 .707 r
F P
0 g
s
.66831 .82421 m .66831 .84273 L .64085 .83834 L p .707 .577 .707 r
F P
0 g
s
.64085 .83834 m .64085 .81982 L .66831 .82421 L p .707 .577 .707 r
F P
0 g
s
.63393 .35211 m .63393 .854 L .64393 .84219 L p .707 .577 .707 r
F P
0 g
s
.64393 .84219 m .64393 .3403 L .63393 .35211 L p .707 .577 .707 r
F P
0 g
s
.19449 .84804 m .19449 .82952 L .17343 .82306 L p .707 .577 .707 r
F P
0 g
s
.17343 .78304 m .17343 .74598 L .16084 .7381 L p .707 .577 .707 r
F P
0 g
s
.16084 .7018 m .16084 .64622 L .15794 .63768 L p .707 .577 .707 r
F P
0 g
s
.17343 .82306 m .17343 .84159 L .19449 .84804 L p .707 .577 .707 r
F P
0 g
s
.16084 .7381 m .16084 .77515 L .17343 .78304 L p .707 .577 .707 r
F P
0 g
s
.33839 .826 m .33839 .84453 L .35476 .83716 L p .707 .577 .707 r
F P
0 g
s
.35476 .83716 m .35476 .81864 L .33839 .826 L p .707 .577 .707 r
F P
0 g
s
.35476 .74156 m .35476 .77861 L .36184 .77025 L p .707 .577 .707 r
F P
0 g
s
.36184 .77025 m .36184 .73319 L .35476 .74156 L p .707 .577 .707 r
F P
0 g
s
.36184 .64131 m .36184 .69689 L .35894 .68835 L p .707 .577 .707 r
F P
0 g
s
.35894 .68835 m .35894 .63277 L .36184 .64131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81864 m .35476 .83716 L .36184 .8288 L p .707 .577 .707 r
F P
0 g
s
.36184 .8288 m .36184 .81027 L .35476 .81864 L p .707 .577 .707 r
F P
0 g
s
.36184 .73319 m .36184 .77025 L .35894 .76171 L p .707 .577 .707 r
F P
0 g
s
.35894 .76171 m .35894 .72465 L .36184 .73319 L p .707 .577 .707 r
F P
0 g
s
.35894 .63277 m .35894 .68835 L .34635 .68047 L p .707 .577 .707 r
F P
0 g
s
.34635 .68047 m .34635 .62489 L .35894 .63277 L p .707 .577 .707 r
F P
0 g
s
.36184 .81027 m .36184 .8288 L .35894 .82026 L p .707 .577 .707 r
F P
0 g
s
.35894 .82026 m .35894 .80173 L .36184 .81027 L p .707 .577 .707 r
F P
0 g
s
.36016 .84912 m .36016 .34723 L .35607 .33517 L p .707 .577 .707 r
F P
0 g
s
.36016 .34723 m .36016 .84912 L .37794 .86025 L p .707 .577 .707 r
F P
0 g
s
.15794 .63768 m .15794 .69326 L .16084 .7018 L p .707 .577 .707 r
F P
0 g
s
.17343 .84159 m .17343 .82306 L .16084 .81518 L p .707 .577 .707 r
F P
0 g
s
.16084 .81518 m .16084 .83371 L .17343 .84159 L p .707 .577 .707 r
F P
0 g
s
.16084 .77515 m .16084 .7381 L .15794 .72956 L p .707 .577 .707 r
F P
0 g
s
.15794 .69326 m .15794 .63768 L .16503 .62931 L p .707 .577 .707 r
F P
0 g
s
.15794 .72956 m .15794 .76661 L .16084 .77515 L p .707 .577 .707 r
F P
0 g
s
.64393 .3403 m .64393 .84219 L .63984 .83013 L p .707 .577 .707 r
F P
0 g
s
.63984 .83013 m .63984 .32824 L .64393 .3403 L p .707 .577 .707 r
F P
0 g
s
.16503 .62931 m .16503 .68489 L .15794 .69326 L p .707 .577 .707 r
F P
0 g
s
.16084 .83371 m .16084 .81518 L .15794 .80664 L p .707 .577 .707 r
F P
0 g
s
.15794 .80664 m .15794 .82516 L .16084 .83371 L p .707 .577 .707 r
F P
0 g
s
.35894 .72465 m .35894 .76171 L .34635 .75382 L p .707 .577 .707 r
F P
0 g
s
.34635 .75382 m .34635 .71677 L .35894 .72465 L p .707 .577 .707 r
F P
0 g
s
.35894 .80173 m .35894 .82026 L .34635 .81237 L p .707 .577 .707 r
F P
0 g
s
.34635 .81237 m .34635 .79385 L .35894 .80173 L p .707 .577 .707 r
F P
0 g
s
.35607 .33517 m .35607 .83706 L .36016 .84912 L p .707 .577 .707 r
F P
0 g
s
.35607 .83706 m .35607 .33517 L .36607 .32336 L p .707 .577 .707 r
F P
0 g
s
.15794 .76661 m .15794 .72956 L .16503 .72119 L p .707 .577 .707 r
F P
0 g
s
.16503 .68489 m .16503 .62931 L .1814 .62194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72119 m .16503 .75825 L .15794 .76661 L p .707 .577 .707 r
F P
0 g
s
.1814 .62194 m .1814 .67753 L .16503 .68489 L p .707 .577 .707 r
F P
0 g
s
.34635 .62489 m .34635 .68047 L .3253 .67401 L p .707 .577 .707 r
F P
0 g
s
.3253 .67401 m .3253 .61843 L .34635 .62489 L p .707 .577 .707 r
F P
0 g
s
.15794 .82516 m .15794 .80664 L .16503 .79827 L p .707 .577 .707 r
F P
0 g
s
.63984 .32824 m .63984 .83013 L .62206 .819 L p .707 .577 .707 r
F P
0 g
s
.62206 .819 m .62206 .31711 L .63984 .32824 L p .707 .577 .707 r
F P
0 g
s
.16503 .79827 m .16503 .8168 L .15794 .82516 L p .707 .577 .707 r
F P
0 g
s
.16503 .75825 m .16503 .72119 L .1814 .71383 L p .707 .577 .707 r
F P
0 g
s
.1814 .67753 m .1814 .62194 L .20545 .61629 L p .707 .577 .707 r
F P
0 g
s
.1814 .71383 m .1814 .75088 L .16503 .75825 L p .707 .577 .707 r
F P
0 g
s
.36607 .82525 m .36607 .32336 L .38918 .31296 L p .707 .577 .707 r
F P
0 g
s
.36607 .32336 m .36607 .82525 L .35607 .83706 L p .707 .577 .707 r
F P
0 g
s
.3253 .61843 m .3253 .67401 L .29784 .66962 L p .707 .577 .707 r
F P
0 g
s
.29784 .66962 m .29784 .61404 L .3253 .61843 L p .707 .577 .707 r
F P
0 g
s
.34635 .71677 m .34635 .75382 L .3253 .74737 L p .707 .577 .707 r
F P
0 g
s
.3253 .74737 m .3253 .71031 L .34635 .71677 L p .707 .577 .707 r
F P
0 g
s
.20545 .61629 m .20545 .67188 L .1814 .67753 L p .707 .577 .707 r
F P
0 g
s
.20545 .67188 m .20545 .61629 L .23483 .61292 L p .707 .577 .707 r
F P
0 g
s
.16503 .8168 m .16503 .79827 L .1814 .79091 L p .707 .577 .707 r
F P
0 g
s
.1814 .75088 m .1814 .71383 L .20545 .70818 L p .707 .577 .707 r
F P
0 g
s
.1814 .79091 m .1814 .80943 L .16503 .8168 L p .707 .577 .707 r
F P
0 g
s
.29784 .61404 m .29784 .66962 L .26667 .66772 L p .707 .577 .707 r
F P
0 g
s
.26667 .66772 m .26667 .61214 L .29784 .61404 L p .707 .577 .707 r
F P
0 g
s
.23483 .6685 m .23483 .61292 L .26667 .61214 L p .707 .577 .707 r
F P
0 g
s
.23483 .61292 m .23483 .6685 L .20545 .67188 L p .707 .577 .707 r
F P
0 g
s
.62206 .31711 m .62206 .819 L .59233 .80989 L p .707 .577 .707 r
F P
0 g
s
.59233 .80989 m .59233 .308 L .62206 .31711 L p .707 .577 .707 r
F P
0 g
s
.26667 .61214 m .26667 .66772 L .23483 .6685 L p .707 .577 .707 r
F P
0 g
s
.20545 .70818 m .20545 .74523 L .1814 .75088 L p .707 .577 .707 r
F P
0 g
s
.34635 .79385 m .34635 .81237 L .3253 .80592 L p .707 .577 .707 r
F P
0 g
s
.3253 .80592 m .3253 .78739 L .34635 .79385 L p .707 .577 .707 r
F P
0 g
s
.73333 .66721 m .73333 .61163 L .70216 .60973 L p .707 .577 .707 r
F P
0 g
s
.73333 .61163 m .73333 .66721 L .76517 .66643 L p .707 .577 .707 r
F P
0 g
s
.76517 .66643 m .76517 .61085 L .73333 .61163 L p .707 .577 .707 r
F P
0 g
s
.3253 .71031 m .3253 .74737 L .29784 .74298 L p .707 .577 .707 r
F P
0 g
s
.29784 .74298 m .29784 .70592 L .3253 .71031 L p .707 .577 .707 r
F P
0 g
s
.76517 .61085 m .76517 .66643 L .79455 .66305 L p .707 .577 .707 r
F P
0 g
s
.79455 .66305 m .79455 .60747 L .76517 .61085 L p .707 .577 .707 r
F P
0 g
s
.70216 .66531 m .70216 .60973 L .6747 .60533 L p .707 .577 .707 r
F P
0 g
s
.70216 .60973 m .70216 .66531 L .73333 .66721 L p .707 .577 .707 r
F P
0 g
s
.20545 .74523 m .20545 .70818 L .23483 .7048 L p .707 .577 .707 r
F P
0 g
s
.1814 .80943 m .1814 .79091 L .20545 .78526 L p .707 .577 .707 r
F P
0 g
s
.38918 .31296 m .38918 .81485 L .36607 .82525 L p .707 .577 .707 r
F P
0 g
s
.38918 .81485 m .38918 .31296 L .42314 .30498 L p .707 .577 .707 r
F P
0 g
s
.79455 .60747 m .79455 .66305 L .8186 .6574 L p .707 .577 .707 r
F P
0 g
s
.8186 .6574 m .8186 .60182 L .79455 .60747 L p .707 .577 .707 r
F P
0 g
s
.20545 .78526 m .20545 .80378 L .1814 .80943 L p .707 .577 .707 r
F P
0 g
s
.29784 .70592 m .29784 .74298 L .26667 .74107 L p .707 .577 .707 r
F P
0 g
s
.26667 .74107 m .26667 .70402 L .29784 .70592 L p .707 .577 .707 r
F P
0 g
s
.23483 .7048 m .23483 .74185 L .20545 .74523 L p .707 .577 .707 r
F P
0 g
s
.23483 .74185 m .23483 .7048 L .26667 .70402 L p .707 .577 .707 r
F P
0 g
s
.6747 .60533 m .6747 .66092 L .70216 .66531 L p .707 .577 .707 r
F P
0 g
s
.6747 .66092 m .6747 .60533 L .65365 .59888 L p .707 .577 .707 r
F P
0 g
s
.3253 .78739 m .3253 .80592 L .29784 .80153 L p .707 .577 .707 r
F P
0 g
s
.29784 .80153 m .29784 .783 L .3253 .78739 L p .707 .577 .707 r
F P
0 g
s
.26667 .70402 m .26667 .74107 L .23483 .74185 L p .707 .577 .707 r
F P
0 g
s
.73333 .74056 m .73333 .70351 L .70216 .70161 L p .707 .577 .707 r
F P
0 g
s
.73333 .70351 m .73333 .74056 L .76517 .73979 L p .707 .577 .707 r
F P
0 g
s
.76517 .73979 m .76517 .70273 L .73333 .70351 L p .707 .577 .707 r
F P
0 g
s
.76517 .70273 m .76517 .73979 L .79455 .73641 L p .707 .577 .707 r
F P
0 g
s
.79455 .73641 m .79455 .69935 L .76517 .70273 L p .707 .577 .707 r
F P
0 g
s
.59233 .308 m .59233 .80989 L .55357 .80369 L p .707 .577 .707 r
F P
0 g
s
.55357 .80369 m .55357 .3018 L .59233 .308 L p .707 .577 .707 r
F P
0 g
s
.20545 .80378 m .20545 .78526 L .23483 .78188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73866 m .70216 .70161 L .6747 .69722 L p .707 .577 .707 r
F P
0 g
s
.70216 .70161 m .70216 .73866 L .73333 .74056 L p .707 .577 .707 r
F P
0 g
s
.8186 .60182 m .8186 .6574 L .83497 .65003 L p .707 .577 .707 r
F P
0 g
s
.83497 .65003 m .83497 .59445 L .8186 .60182 L p .707 .577 .707 r
F P
0 g
s
.23483 .78188 m .23483 .8004 L .20545 .80378 L p .707 .577 .707 r
F P
0 g
s
.65365 .59888 m .65365 .65446 L .6747 .66092 L p .707 .577 .707 r
F P
0 g
s
.29784 .783 m .29784 .80153 L .26667 .79963 L p .707 .577 .707 r
F P
0 g
s
.26667 .79963 m .26667 .7811 L .29784 .783 L p .707 .577 .707 r
F P
0 g
s
.42314 .80687 m .42314 .30498 L .46462 .30021 L p .707 .577 .707 r
F P
0 g
s
.42314 .30498 m .42314 .80687 L .38918 .81485 L p .707 .577 .707 r
F P
0 g
s
.79455 .69935 m .79455 .73641 L .8186 .73076 L p .707 .577 .707 r
F P
0 g
s
.8186 .73076 m .8186 .6937 L .79455 .69935 L p .707 .577 .707 r
F P
0 g
s
.23483 .8004 m .23483 .78188 L .26667 .7811 L p .707 .577 .707 r
F P
0 g
s
.6747 .69722 m .6747 .73427 L .70216 .73866 L p .707 .577 .707 r
F P
0 g
s
.26667 .7811 m .26667 .79963 L .23483 .8004 L p .707 .577 .707 r
F P
0 g
s
.65365 .65446 m .65365 .59888 L .64105 .591 L p .707 .577 .707 r
F P
0 g
s
.73333 .79911 m .73333 .78059 L .70216 .77869 L p .707 .577 .707 r
F P
0 g
s
.73333 .78059 m .73333 .79911 L .76517 .79834 L p .707 .577 .707 r
F P
0 g
s
.76517 .79834 m .76517 .77981 L .73333 .78059 L p .707 .577 .707 r
F P
0 g
s
.6747 .73427 m .6747 .69722 L .65365 .69076 L p .707 .577 .707 r
F P
0 g
s
.76517 .77981 m .76517 .79834 L .79455 .79496 L p .707 .577 .707 r
F P
0 g
s
.79455 .79496 m .79455 .77643 L .76517 .77981 L p .707 .577 .707 r
F P
0 g
s
.55357 .3018 m .55357 .80369 L .50956 .80101 L p .707 .577 .707 r
F P
0 g
s
.50956 .80101 m .50956 .29912 L .55357 .3018 L p .707 .577 .707 r
F P
0 g
s
.70216 .77869 m .70216 .79721 L .73333 .79911 L p .707 .577 .707 r
F P
0 g
s
.70216 .79721 m .70216 .77869 L .6747 .77429 L p .707 .577 .707 r
F P
0 g
s
.46462 .8021 m .46462 .30021 L .50956 .29912 L p .707 .577 .707 r
F P
0 g
s
.46462 .30021 m .46462 .8021 L .42314 .80687 L p .707 .577 .707 r
F P
0 g
s
.65365 .69076 m .65365 .72782 L .6747 .73427 L p .707 .577 .707 r
F P
0 g
s
.6747 .77429 m .6747 .79282 L .70216 .79721 L p .707 .577 .707 r
F P
0 g
s
.8186 .6937 m .8186 .73076 L .83497 .72339 L p .707 .577 .707 r
F P
0 g
s
.83497 .72339 m .83497 .68633 L .8186 .6937 L p .707 .577 .707 r
F P
0 g
s
.64105 .591 m .64105 .64658 L .65365 .65446 L p .707 .577 .707 r
F P
0 g
s
.50956 .29912 m .50956 .80101 L .46462 .8021 L p .707 .577 .707 r
F P
0 g
s
.83497 .59445 m .83497 .65003 L .84205 .64167 L p .707 .577 .707 r
F P
0 g
s
.84205 .64167 m .84205 .58609 L .83497 .59445 L p .707 .577 .707 r
F P
0 g
s
.79455 .77643 m .79455 .79496 L .8186 .78931 L p .707 .577 .707 r
F P
0 g
s
.8186 .78931 m .8186 .77078 L .79455 .77643 L p .707 .577 .707 r
F P
0 g
s
.6747 .79282 m .6747 .77429 L .65365 .76784 L p .707 .577 .707 r
F P
0 g
s
.65365 .72782 m .65365 .69076 L .64105 .68288 L p .707 .577 .707 r
F P
0 g
s
.64105 .64658 m .64105 .591 L .63816 .58245 L p .707 .577 .707 r
F P
0 g
s
.65365 .76784 m .65365 .78637 L .6747 .79282 L p .707 .577 .707 r
F P
0 g
s
.64105 .68288 m .64105 .71993 L .65365 .72782 L p .707 .577 .707 r
F P
0 g
s
.8186 .77078 m .8186 .78931 L .83497 .78194 L p .707 .577 .707 r
F P
0 g
s
.83497 .78194 m .83497 .76341 L .8186 .77078 L p .707 .577 .707 r
F P
0 g
s
.83497 .68633 m .83497 .72339 L .84206 .71502 L p .707 .577 .707 r
F P
0 g
s
.84206 .71502 m .84206 .67797 L .83497 .68633 L p .707 .577 .707 r
F P
0 g
s
.63816 .58245 m .63816 .63804 L .64105 .64658 L p .707 .577 .707 r
F P
0 g
s
.84205 .58609 m .84205 .64167 L .83916 .63313 L p .707 .577 .707 r
F P
0 g
s
.83916 .63313 m .83916 .57755 L .84205 .58609 L p .707 .577 .707 r
F P
0 g
s
.65365 .78637 m .65365 .76784 L .64105 .75996 L p .707 .577 .707 r
F P
0 g
s
.64105 .75996 m .64105 .77848 L .65365 .78637 L p .707 .577 .707 r
F P
0 g
s
.64105 .71993 m .64105 .68288 L .63816 .67433 L p .707 .577 .707 r
F P
0 g
s
.63816 .63804 m .63816 .58245 L .64524 .57409 L p .707 .577 .707 r
F P
0 g
s
.83497 .76341 m .83497 .78194 L .84206 .77358 L p .707 .577 .707 r
F P
0 g
s
.84206 .77358 m .84206 .75505 L .83497 .76341 L p .707 .577 .707 r
F P
0 g
s
.63816 .67433 m .63816 .71139 L .64105 .71993 L p .707 .577 .707 r
F P
0 g
s
.84206 .67797 m .84206 .71502 L .83916 .70648 L p .707 .577 .707 r
F P
0 g
s
.83916 .70648 m .83916 .66943 L .84206 .67797 L p .707 .577 .707 r
F P
0 g
s
.64524 .57409 m .64524 .62967 L .63816 .63804 L p .707 .577 .707 r
F P
0 g
s
.64105 .77848 m .64105 .75996 L .63816 .75141 L p .707 .577 .707 r
F P
0 g
s
.83916 .57755 m .83916 .63313 L .82657 .62524 L p .707 .577 .707 r
F P
0 g
s
.82657 .62524 m .82657 .56966 L .83916 .57755 L p .707 .577 .707 r
F P
0 g
s
.63816 .75141 m .63816 .76994 L .64105 .77848 L p .707 .577 .707 r
F P
0 g
s
.63816 .71139 m .63816 .67433 L .64524 .66597 L p .707 .577 .707 r
F P
0 g
s
.39032 .63039 m .39032 .57481 L .35915 .57291 L p .707 .577 .707 r
F P
0 g
s
.39032 .57481 m .39032 .63039 L .42216 .62962 L p .707 .577 .707 r
F P
0 g
s
.42216 .62962 m .42216 .57403 L .39032 .57481 L p .707 .577 .707 r
F P
0 g
s
.64524 .62967 m .64524 .57409 L .66161 .56672 L p .707 .577 .707 r
F P
0 g
s
.42216 .57403 m .42216 .62962 L .45154 .62624 L p .707 .577 .707 r
F P
0 g
s
.45154 .62624 m .45154 .57065 L .42216 .57403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84206 .75505 m .84206 .77358 L .83916 .76503 L p .707 .577 .707 r
F P
0 g
s
.83916 .76503 m .83916 .74651 L .84206 .75505 L p .707 .577 .707 r
F P
0 g
s
.35915 .62849 m .35915 .57291 L .33169 .56852 L p .707 .577 .707 r
F P
0 g
s
.35915 .57291 m .35915 .62849 L .39032 .63039 L p .707 .577 .707 r
F P
0 g
s
.64524 .66597 m .64524 .70303 L .63816 .71139 L p .707 .577 .707 r
F P
0 g
s
.45154 .57065 m .45154 .62624 L .47559 .62059 L p .707 .577 .707 r
F P
0 g
s
.47559 .62059 m .47559 .565 L .45154 .57065 L p .707 .577 .707 r
F P
0 g
s
.83916 .66943 m .83916 .70648 L .82657 .6986 L p .707 .577 .707 r
F P
0 g
s
.82657 .6986 m .82657 .66154 L .83916 .66943 L p .707 .577 .707 r
F P
0 g
s
.66161 .56672 m .66161 .6223 L .64524 .62967 L p .707 .577 .707 r
F P
0 g
s
.82657 .56966 m .82657 .62524 L .80551 .61879 L p .707 .577 .707 r
F P
0 g
s
.80551 .61879 m .80551 .56321 L .82657 .56966 L p .707 .577 .707 r
F P
0 g
s
.63816 .76994 m .63816 .75141 L .64524 .74305 L p .707 .577 .707 r
F P
0 g
s
.33169 .56852 m .33169 .6241 L .35915 .62849 L p .707 .577 .707 r
F P
0 g
s
.33169 .6241 m .33169 .56852 L .31064 .56206 L p .707 .577 .707 r
F P
0 g
s
.64524 .74305 m .64524 .76158 L .63816 .76994 L p .707 .577 .707 r
F P
0 g
s
.39032 .70375 m .39032 .66669 L .35915 .66479 L p .707 .577 .707 r
F P
0 g
s
.39032 .66669 m .39032 .70375 L .42216 .70297 L p .707 .577 .707 r
F P
0 g
s
.42216 .70297 m .42216 .66592 L .39032 .66669 L p .707 .577 .707 r
F P
0 g
s
.64524 .70303 m .64524 .66597 L .66161 .6586 L p .707 .577 .707 r
F P
0 g
s
.42216 .66592 m .42216 .70297 L .45154 .69959 L p .707 .577 .707 r
F P
0 g
s
.45154 .69959 m .45154 .66254 L .42216 .66592 L p .707 .577 .707 r
F P
0 g
s
.66161 .6223 m .66161 .56672 L .68566 .56107 L p .707 .577 .707 r
F P
0 g
s
.35915 .70185 m .35915 .66479 L .33169 .6604 L p .707 .577 .707 r
F P
0 g
s
.35915 .66479 m .35915 .70185 L .39032 .70375 L p .707 .577 .707 r
F P
0 g
s
.47559 .565 m .47559 .62059 L .49196 .61322 L p .707 .577 .707 r
F P
0 g
s
.49196 .61322 m .49196 .55764 L .47559 .565 L p .707 .577 .707 r
F P
0 g
s
.83916 .74651 m .83916 .76503 L .82657 .75715 L p .707 .577 .707 r
F P
0 g
s
.82657 .75715 m .82657 .73862 L .83916 .74651 L p .707 .577 .707 r
F P
0 g
s
.31064 .56206 m .31064 .61765 L .33169 .6241 L p .707 .577 .707 r
F P
0 g
s
.66161 .6586 m .66161 .69566 L .64524 .70303 L p .707 .577 .707 r
F P
0 g
s
.45154 .66254 m .45154 .69959 L .47559 .69394 L p .707 .577 .707 r
F P
0 g
s
.47559 .69394 m .47559 .65689 L .45154 .66254 L p .707 .577 .707 r
F P
0 g
s
.80551 .56321 m .80551 .61879 L .77805 .6144 L p .707 .577 .707 r
F P
0 g
s
.77805 .6144 m .77805 .55882 L .80551 .56321 L p .707 .577 .707 r
F P
0 g
s
.33169 .6604 m .33169 .69745 L .35915 .70185 L p .707 .577 .707 r
F P
0 g
s
.82657 .66154 m .82657 .6986 L .80551 .69214 L p .707 .577 .707 r
F P
0 g
s
.80551 .69214 m .80551 .65509 L .82657 .66154 L p .707 .577 .707 r
F P
0 g
s
.68566 .56107 m .68566 .61665 L .66161 .6223 L p .707 .577 .707 r
F P
0 g
s
.31064 .61765 m .31064 .56206 L .29804 .55418 L p .707 .577 .707 r
F P
0 g
s
.39032 .7623 m .39032 .74377 L .35915 .74187 L p .707 .577 .707 r
F P
0 g
s
.39032 .74377 m .39032 .7623 L .42216 .76152 L p .707 .577 .707 r
F P
0 g
s
.42216 .76152 m .42216 .74299 L .39032 .74377 L p .707 .577 .707 r
F P
0 g
s
.33169 .69745 m .33169 .6604 L .31064 .65395 L p .707 .577 .707 r
F P
0 g
s
.68566 .61665 m .68566 .56107 L .71504 .55769 L p .707 .577 .707 r
F P
0 g
s
.64524 .76158 m .64524 .74305 L .66161 .73568 L p .707 .577 .707 r
F P
0 g
s
.42216 .74299 m .42216 .76152 L .45154 .75814 L p .707 .577 .707 r
F P
0 g
s
.45154 .75814 m .45154 .73962 L .42216 .74299 L p .707 .577 .707 r
F P
0 g
s
.35915 .74187 m .35915 .7604 L .39032 .7623 L p .707 .577 .707 r
F P
0 g
s
.35915 .7604 m .35915 .74187 L .33169 .73748 L p .707 .577 .707 r
F P
0 g
s
.66161 .69566 m .66161 .6586 L .68566 .65295 L p .707 .577 .707 r
F P
0 g
s
.66161 .73568 m .66161 .75421 L .64524 .76158 L p .707 .577 .707 r
F P
0 g
s
.77805 .55882 m .77805 .6144 L .74688 .6125 L p .707 .577 .707 r
F P
0 g
s
.74688 .6125 m .74688 .55691 L .77805 .55882 L p .707 .577 .707 r
F P
0 g
s
.31064 .65395 m .31064 .691 L .33169 .69745 L p .707 .577 .707 r
F P
0 g
s
.33169 .73748 m .33169 .75601 L .35915 .7604 L p .707 .577 .707 r
F P
0 g
s
.47559 .65689 m .47559 .69394 L .49196 .68657 L p .707 .577 .707 r
F P
0 g
s
.49196 .68657 m .49196 .64952 L .47559 .65689 L p .707 .577 .707 r
F P
0 g
s
.29804 .55418 m .29804 .60976 L .31064 .61765 L p .707 .577 .707 r
F P
0 g
s
.71504 .61327 m .71504 .55769 L .74688 .55691 L p .707 .577 .707 r
F P
0 g
s
.71504 .55769 m .71504 .61327 L .68566 .61665 L p .707 .577 .707 r
F P
0 g
s
.49196 .55764 m .49196 .61322 L .49904 .60485 L p .707 .577 .707 r
F P
0 g
s
.49904 .60485 m .49904 .54927 L .49196 .55764 L p .707 .577 .707 r
F P
0 g
s
.45154 .73962 m .45154 .75814 L .47559 .75249 L p .707 .577 .707 r
F P
0 g
s
.47559 .75249 m .47559 .73397 L .45154 .73962 L p .707 .577 .707 r
F P
0 g
s
.74688 .55691 m .74688 .6125 L .71504 .61327 L p .707 .577 .707 r
F P
0 g
s
.68566 .65295 m .68566 .69001 L .66161 .69566 L p .707 .577 .707 r
F P
0 g
s
.82657 .73862 m .82657 .75715 L .80551 .7507 L p .707 .577 .707 r
F P
0 g
s
.80551 .7507 m .80551 .73217 L .82657 .73862 L p .707 .577 .707 r
F P
0 g
s
.80551 .65509 m .80551 .69214 L .77805 .68775 L p .707 .577 .707 r
F P
0 g
s
.77805 .68775 m .77805 .6507 L .80551 .65509 L p .707 .577 .707 r
F P
0 g
s
.33169 .75601 m .33169 .73748 L .31064 .73103 L p .707 .577 .707 r
F P
0 g
s
.31064 .691 m .31064 .65395 L .29804 .64606 L p .707 .577 .707 r
F P
0 g
s
.29804 .60976 m .29804 .55418 L .29515 .54564 L p .707 .577 .707 r
F P
0 g
s
.31064 .73103 m .31064 .74955 L .33169 .75601 L p .707 .577 .707 r
F P
0 g
s
.68566 .69001 m .68566 .65295 L .71504 .64957 L p .707 .577 .707 r
F P
0 g
s
.66161 .75421 m .66161 .73568 L .68566 .73003 L p .707 .577 .707 r
F P
0 g
s
.68566 .73003 m .68566 .74856 L .66161 .75421 L p .707 .577 .707 r
F P
0 g
s
.29804 .64606 m .29804 .68312 L .31064 .691 L p .707 .577 .707 r
F P
0 g
s
.47559 .73397 m .47559 .75249 L .49196 .74513 L p .707 .577 .707 r
F P
0 g
s
.49196 .74513 m .49196 .7266 L .47559 .73397 L p .707 .577 .707 r
F P
0 g
s
.77805 .6507 m .77805 .68775 L .74688 .68585 L p .707 .577 .707 r
F P
0 g
s
.74688 .68585 m .74688 .6488 L .77805 .6507 L p .707 .577 .707 r
F P
0 g
s
.71504 .64957 m .71504 .68663 L .68566 .69001 L p .707 .577 .707 r
F P
0 g
s
.71504 .68663 m .71504 .64957 L .74688 .6488 L p .707 .577 .707 r
F P
0 g
s
.49196 .64952 m .49196 .68657 L .49904 .67821 L p .707 .577 .707 r
F P
0 g
s
.49904 .67821 m .49904 .64115 L .49196 .64952 L p .707 .577 .707 r
F P
0 g
s
.80551 .73217 m .80551 .7507 L .77805 .7463 L p .707 .577 .707 r
F P
0 g
s
.77805 .7463 m .77805 .72778 L .80551 .73217 L p .707 .577 .707 r
F P
0 g
s
.29515 .54564 m .29515 .60122 L .29804 .60976 L p .707 .577 .707 r
F P
0 g
s
.74688 .6488 m .74688 .68585 L .71504 .68663 L p .707 .577 .707 r
F P
0 g
s
.49904 .54927 m .49904 .60485 L .49615 .59631 L p .707 .577 .707 r
F P
0 g
s
.49615 .59631 m .49615 .54073 L .49904 .54927 L p .707 .577 .707 r
F P
0 g
s
.31064 .74955 m .31064 .73103 L .29804 .72314 L p .707 .577 .707 r
F P
0 g
s
.68566 .74856 m .68566 .73003 L .71504 .72665 L p .707 .577 .707 r
F P
0 g
s
.29804 .72314 m .29804 .74167 L .31064 .74955 L p .707 .577 .707 r
F P
0 g
s
.29804 .68312 m .29804 .64606 L .29515 .63752 L p .707 .577 .707 r
F P
0 g
s
.71504 .72665 m .71504 .74518 L .68566 .74856 L p .707 .577 .707 r
F P
0 g
s
.77805 .72778 m .77805 .7463 L .74688 .7444 L p .707 .577 .707 r
F P
0 g
s
.74688 .7444 m .74688 .72588 L .77805 .72778 L p .707 .577 .707 r
F P
0 g
s
.29515 .60122 m .29515 .54564 L .30223 .53727 L p .707 .577 .707 r
F P
0 g
s
.71504 .74518 m .71504 .72665 L .74688 .72588 L p .707 .577 .707 r
F P
0 g
s
.49196 .7266 m .49196 .74513 L .49904 .73676 L p .707 .577 .707 r
F P
0 g
s
.49904 .73676 m .49904 .71823 L .49196 .7266 L p .707 .577 .707 r
F P
0 g
s
.29515 .63752 m .29515 .67457 L .29804 .68312 L p .707 .577 .707 r
F P
0 g
s
.74688 .72588 m .74688 .7444 L .71504 .74518 L p .707 .577 .707 r
F P
0 g
s
.49904 .64115 m .49904 .67821 L .49615 .66967 L p .707 .577 .707 r
F P
0 g
s
.49615 .66967 m .49615 .63261 L .49904 .64115 L p .707 .577 .707 r
F P
0 g
s
.30223 .53727 m .30223 .59286 L .29515 .60122 L p .707 .577 .707 r
F P
0 g
s
.29804 .74167 m .29804 .72314 L .29515 .7146 L p .707 .577 .707 r
F P
0 g
s
.49615 .54073 m .49615 .59631 L .48356 .58843 L p .707 .577 .707 r
F P
0 g
s
.48356 .58843 m .48356 .53285 L .49615 .54073 L p .707 .577 .707 r
F P
0 g
s
.29515 .7146 m .29515 .73313 L .29804 .74167 L p .707 .577 .707 r
F P
0 g
s
.29515 .67457 m .29515 .63752 L .30223 .62915 L p .707 .577 .707 r
F P
0 g
s
.30223 .59286 m .30223 .53727 L .3186 .52991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49904 .71823 m .49904 .73676 L .49615 .72822 L p .707 .577 .707 r
F P
0 g
s
.49615 .72822 m .49615 .70969 L .49904 .71823 L p .707 .577 .707 r
F P
0 g
s
.30223 .62915 m .30223 .66621 L .29515 .67457 L p .707 .577 .707 r
F P
0 g
s
.49615 .63261 m .49615 .66967 L .48356 .66178 L p .707 .577 .707 r
F P
0 g
s
.48356 .66178 m .48356 .62473 L .49615 .63261 L p .707 .577 .707 r
F P
0 g
s
.3186 .52991 m .3186 .58549 L .30223 .59286 L p .707 .577 .707 r
F P
0 g
s
.48356 .53285 m .48356 .58843 L .4625 .58197 L p .707 .577 .707 r
F P
0 g
s
.4625 .58197 m .4625 .52639 L .48356 .53285 L p .707 .577 .707 r
F P
0 g
s
.29515 .73313 m .29515 .7146 L .30223 .70623 L p .707 .577 .707 r
F P
0 g
s
.30223 .70623 m .30223 .72476 L .29515 .73313 L p .707 .577 .707 r
F P
0 g
s
.30223 .66621 m .30223 .62915 L .3186 .62179 L p .707 .577 .707 r
F P
0 g
s
.3186 .58549 m .3186 .52991 L .34265 .52426 L p .707 .577 .707 r
F P
0 g
s
.49615 .70969 m .49615 .72822 L .48356 .72034 L p .707 .577 .707 r
F P
0 g
s
.48356 .72034 m .48356 .70181 L .49615 .70969 L p .707 .577 .707 r
F P
0 g
s
.3186 .62179 m .3186 .65884 L .30223 .66621 L p .707 .577 .707 r
F P
0 g
s
.4625 .52639 m .4625 .58197 L .43504 .57758 L p .707 .577 .707 r
F P
0 g
s
.43504 .57758 m .43504 .522 L .4625 .52639 L p .707 .577 .707 r
F P
0 g
s
.48356 .62473 m .48356 .66178 L .4625 .65533 L p .707 .577 .707 r
F P
0 g
s
.4625 .65533 m .4625 .61827 L .48356 .62473 L p .707 .577 .707 r
F P
0 g
s
.34265 .52426 m .34265 .57984 L .3186 .58549 L p .707 .577 .707 r
F P
0 g
s
.34265 .57984 m .34265 .52426 L .37203 .52088 L p .707 .577 .707 r
F P
0 g
s
.30223 .72476 m .30223 .70623 L .3186 .69887 L p .707 .577 .707 r
F P
0 g
s
.3186 .65884 m .3186 .62179 L .34265 .61614 L p .707 .577 .707 r
F P
0 g
s
.3186 .69887 m .3186 .71739 L .30223 .72476 L p .707 .577 .707 r
F P
0 g
s
.43504 .522 m .43504 .57758 L .40387 .57568 L p .707 .577 .707 r
F P
0 g
s
.40387 .57568 m .40387 .5201 L .43504 .522 L p .707 .577 .707 r
F P
0 g
s
.37203 .57646 m .37203 .52088 L .40387 .5201 L p .707 .577 .707 r
F P
0 g
s
.37203 .52088 m .37203 .57646 L .34265 .57984 L p .707 .577 .707 r
F P
0 g
s
.40387 .5201 m .40387 .57568 L .37203 .57646 L p .707 .577 .707 r
F P
0 g
s
.34265 .61614 m .34265 .65319 L .3186 .65884 L p .707 .577 .707 r
F P
0 g
s
.48356 .70181 m .48356 .72034 L .4625 .71388 L p .707 .577 .707 r
F P
0 g
s
.4625 .71388 m .4625 .69535 L .48356 .70181 L p .707 .577 .707 r
F P
0 g
s
.4625 .61827 m .4625 .65533 L .43504 .65094 L p .707 .577 .707 r
F P
0 g
s
.43504 .65094 m .43504 .61388 L .4625 .61827 L p .707 .577 .707 r
F P
0 g
s
.34265 .65319 m .34265 .61614 L .37203 .61276 L p .707 .577 .707 r
F P
0 g
s
.3186 .71739 m .3186 .69887 L .34265 .69322 L p .707 .577 .707 r
F P
0 g
s
.34265 .69322 m .34265 .71174 L .3186 .71739 L p .707 .577 .707 r
F P
0 g
s
.43504 .61388 m .43504 .65094 L .40387 .64904 L p .707 .577 .707 r
F P
0 g
s
.40387 .64904 m .40387 .61198 L .43504 .61388 L p .707 .577 .707 r
F P
0 g
s
.37203 .61276 m .37203 .64981 L .34265 .65319 L p .707 .577 .707 r
F P
0 g
s
.37203 .64981 m .37203 .61276 L .40387 .61198 L p .707 .577 .707 r
F P
0 g
s
.4625 .69535 m .4625 .71388 L .43504 .70949 L p .707 .577 .707 r
F P
0 g
s
.43504 .70949 m .43504 .69096 L .4625 .69535 L p .707 .577 .707 r
F P
0 g
s
.40387 .61198 m .40387 .64904 L .37203 .64981 L p .707 .577 .707 r
F P
0 g
s
.34265 .71174 m .34265 .69322 L .37203 .68984 L p .707 .577 .707 r
F P
0 g
s
.37203 .68984 m .37203 .70837 L .34265 .71174 L p .707 .577 .707 r
F P
0 g
s
.43504 .69096 m .43504 .70949 L .40387 .70759 L p .707 .577 .707 r
F P
0 g
s
.40387 .70759 m .40387 .68906 L .43504 .69096 L p .707 .577 .707 r
F P
0 g
s
.37203 .70837 m .37203 .68984 L .40387 .68906 L p .707 .577 .707 r
F P
0 g
s
.40387 .68906 m .40387 .70759 L .37203 .70837 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolQ001mOol007Moo`P000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00H007Moo`00M7oo0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1UYF1000Lgoo001`Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH01000FUH00000LGoo001^Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo
001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo2@0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000?OolH
000nOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH3000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH007oo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000=JEP<0
009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH0
05YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJ
EP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF
6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH0
1EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEPH0009JEP03001JEUYF00=JEP03001JEUYF00IJEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030002
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`0000AJEP000000009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01P00FUH0
0000FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YF
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0`00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008
FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/
Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo
00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH900000eYF001JEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF200015YF
00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH9000HOol50004
FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF000000060003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF2P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1@000eYF00@005YFFUIJEP8001aoo`@00003FUH005YF
009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEPH000=JEP8001Eoo`L000=JEP<000=JEP80
02eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUH90009Ool90003FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEQP000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00<7oo0`0015YF
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF
5`001UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000c
Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP03
FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000aOol30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF00000002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01UYF1@000eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF0P0000Eoo`00
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEP0000<000=JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00FUH20003FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEQP0009J
EP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<0009JEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30000
1EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0UYF100000=JEP00FUH01P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF
0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20003FUH00`00FUH000020005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP<0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00UYF1P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJ
EP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF4@0015YF00D005YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039o
o`00;7oo00<005YF000015YF00<005YFFUH00eYF1P004Goo1P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00
FUH00004FUH00`00FUH00003000MOol30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH7000OOol30003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUH00004000NOol50004FUH01@00FUIJEUYF0000;Woo000/Ool01000FUH005YF0P001EYF
00<005YF00000`006Goo2P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF0P008Woo0`0000=JEP00FUH00UYF0P00;Goo000/Ool01P00FUH00000
FUH000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH3000SOol2
0003FUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF00<005YFFUH00eYF00<005YFFUH00P008goo0P0000=JEP000000;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
100015YF00<005YFFUH00eYF00D005YFFUIJEP0002Aoo`@002eoo`00;7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP80009JEP03001JEUYF00=JEP04001JEUYFFUH2000QOol2000015YF00000000;Goo000]Ool01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEP00008000EJEP04001JEUYFFUH2000LOol50003FUH00`00FUH0000]Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF1P000eYF0P005Goo1`000eYF00<005YFFUH00UYF0P00;Woo000^Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP80
02ioo`00<7oo0`0015YF00<005YFFUH01EYF6@0000=JEP00FUH01EYF00H005YF000007oo0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00;goo000cOol300000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000035oo`00<Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;Woo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH00UYF
1@00>Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
30001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000goo4P00?goo000]Ool20004FUH00`00FUIJEP03FUH6000GOol4
0002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00UYF0`00E7oo000/Ool00`00FUH00004FUH00`00FUH00003000QOol50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000/Ool00`00FUH00003FUH3000ZOol40002FUH01000
FUIJEP001EYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00EGoo000/Ool01000FUH005YF0P00<Goo00<005YF00000UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
10000UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00
;7oo00@005YF000003Aoo`80009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00002FUH00`00
FUIJEP04FUH01000FUH00000F7oo000/Ool200000eYF0000000aOol40002FUH01000FUH000001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YFFUIJEP0000=JEP03001JEP0000<000EJEP<005Yoo`00;7oo0P000eYF0`00:goo0`000UYF
0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEPH005eoo`00;7oo
0P000eYF00<005YFFUH01@008Woo100000=JEP00FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YF00000P00Fgoo000]Ool01@00FUIJEUYF
00001EYF00<005YF00000`006Goo1@001EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP800003FUH005YF00AJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00eYF0`00Egoo000^Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000Ool00P0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH0009oo`D000AJEP05001JEUYFFUH0001EOol003=oo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00008Ool300000eYF
001JEP02FUH2001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009J
EPL000Uoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000aoo`8000=JEP8005Ao
o`00>goo6`004Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P003goo0P0000=JEP000000
E7oo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P004Woo1000E7oo001[Ool20006FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000004Woo
0P0000AJEP00000005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF0`003goo1@000eYF00<005YF0000E7oo001_Ool30000
0eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3
000;Ool70003FUH00`00FUIJEP02FUH00`00FUH0001DOol0079oo`L000EJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<000Eoo`T000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH00eYF400015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00QGoo6@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo
002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001M
Ool009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]6\[InvisibleSpace]"     "\
\[InvisibleSpace]2.839469025058277`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 6, "     ", 2.839469025058277, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60003 .74268 m .59787 .68883 L .56671 .68741 L p .707 .577 .707 r
F P
0 g
s
.59787 .68883 m .60003 .74268 L .63184 .74051 L p .707 .577 .707 r
F P
0 g
s
.63184 .74051 m .62968 .68666 L .59787 .68883 L p .707 .577 .707 r
F P
0 g
s
.62968 .68666 m .63184 .74051 L .66118 .73497 L p .707 .577 .707 r
F P
0 g
s
.66118 .73497 m .65902 .68112 L .62968 .68666 L p .707 .577 .707 r
F P
0 g
s
.56887 .74126 m .56671 .68741 L .53924 .68253 L p .707 .577 .707 r
F P
0 g
s
.56671 .68741 m .56887 .74126 L .60003 .74268 L p .707 .577 .707 r
F P
0 g
s
.65902 .68112 m .66118 .73497 L .68518 .72659 L p .707 .577 .707 r
F P
0 g
s
.68518 .72659 m .68302 .67274 L .65902 .68112 L p .707 .577 .707 r
F P
0 g
s
.60011 .78226 m .60036 .74505 L .56919 .74307 L p .707 .577 .707 r
F P
0 g
s
.60036 .74505 m .60011 .78226 L .63195 .78173 L p .707 .577 .707 r
F P
0 g
s
.63195 .78173 m .63219 .74451 L .60036 .74505 L p .707 .577 .707 r
F P
0 g
s
.5414 .73639 m .53924 .68253 L .51816 .67469 L p .707 .577 .707 r
F P
0 g
s
.53924 .68253 m .5414 .73639 L .56887 .74126 L p .707 .577 .707 r
F P
0 g
s
.63219 .74451 m .63195 .78173 L .66133 .77872 L p .707 .577 .707 r
F P
0 g
s
.66133 .77872 m .66157 .74151 L .63219 .74451 L p .707 .577 .707 r
F P
0 g
s
.56894 .78028 m .56919 .74307 L .54173 .73876 L p .707 .577 .707 r
F P
0 g
s
.56919 .74307 m .56894 .78028 L .60011 .78226 L p .707 .577 .707 r
F P
0 g
s
.59777 .8126 m .59914 .7935 L .568 .79065 L p .707 .577 .707 r
F P
0 g
s
.59914 .7935 m .59777 .8126 L .6295 .81458 L p .707 .577 .707 r
F P
0 g
s
.6295 .81458 m .63088 .79548 L .59914 .7935 L p .707 .577 .707 r
F P
0 g
s
.68302 .67274 m .68518 .72659 L .70149 .7162 L p .707 .577 .707 r
F P
0 g
s
.70149 .7162 m .69933 .66235 L .68302 .67274 L p .707 .577 .707 r
F P
0 g
s
.568 .79065 m .56663 .80975 L .59777 .8126 L p .707 .577 .707 r
F P
0 g
s
.63088 .79548 m .6295 .81458 L .65873 .81549 L p .707 .577 .707 r
F P
0 g
s
.65873 .81549 m .6601 .79639 L .63088 .79548 L p .707 .577 .707 r
F P
0 g
s
.66157 .74151 m .66133 .77872 L .68538 .77354 L p .707 .577 .707 r
F P
0 g
s
.68538 .77354 m .68562 .73633 L .66157 .74151 L p .707 .577 .707 r
F P
0 g
s
.54173 .73876 m .54148 .77597 L .56894 .78028 L p .707 .577 .707 r
F P
0 g
s
.56663 .80975 m .568 .79065 L .54051 .78721 L p .707 .577 .707 r
F P
0 g
s
.54051 .78721 m .53914 .80631 L .56663 .80975 L p .707 .577 .707 r
F P
0 g
s
.51816 .67469 m .52032 .72854 L .5414 .73639 L p .707 .577 .707 r
F P
0 g
s
.54148 .77597 m .54173 .73876 L .52067 .73254 L p .707 .577 .707 r
F P
0 g
s
.52032 .72854 m .51816 .67469 L .50552 .66464 L p .707 .577 .707 r
F P
0 g
s
.6601 .79639 m .65873 .81549 L .68259 .81525 L p .707 .577 .707 r
F P
0 g
s
.68259 .81525 m .68396 .79615 L .6601 .79639 L p .707 .577 .707 r
F P
0 g
s
.52067 .73254 m .52043 .76976 L .54148 .77597 L p .707 .577 .707 r
F P
0 g
s
.53914 .80631 m .54051 .78721 L .51936 .78351 L p .707 .577 .707 r
F P
0 g
s
.51936 .78351 m .51798 .80261 L .53914 .80631 L p .707 .577 .707 r
F P
0 g
s
.68562 .73633 m .68538 .77354 L .70175 .76669 L p .707 .577 .707 r
F P
0 g
s
.70175 .76669 m .70199 .72948 L .68562 .73633 L p .707 .577 .707 r
F P
0 g
s
.69933 .66235 m .70149 .7162 L .70851 .70481 L p .707 .577 .707 r
F P
0 g
s
.70851 .70481 m .70635 .65096 L .69933 .66235 L p .707 .577 .707 r
F P
0 g
s
.50552 .66464 m .50768 .71849 L .52032 .72854 L p .707 .577 .707 r
F P
0 g
s
.52043 .76976 m .52067 .73254 L .50808 .72503 L p .707 .577 .707 r
F P
0 g
s
.68396 .79615 m .68259 .81525 L .69874 .81388 L p .707 .577 .707 r
F P
0 g
s
.69874 .81388 m .70011 .79478 L .68396 .79615 L p .707 .577 .707 r
F P
0 g
s
.50768 .71849 m .50552 .66464 L .50257 .65337 L p .707 .577 .707 r
F P
0 g
s
.50808 .72503 m .50783 .76224 L .52043 .76976 L p .707 .577 .707 r
F P
0 g
s
.51798 .80261 m .51936 .78351 L .50661 .77992 L p .707 .577 .707 r
F P
0 g
s
.50661 .77992 m .50523 .79902 L .51798 .80261 L p .707 .577 .707 r
F P
0 g
s
.70199 .72948 m .70175 .76669 L .70883 .75885 L p .707 .577 .707 r
F P
0 g
s
.70883 .75885 m .70907 .72164 L .70199 .72948 L p .707 .577 .707 r
F P
0 g
s
.4885 .82526 m .48534 .32556 L .44133 .32299 L p .707 .577 .707 r
F P
0 g
s
.50257 .65337 m .50473 .70722 L .50768 .71849 L p .707 .577 .707 r
F P
0 g
s
.50783 .76224 m .50808 .72503 L .50518 .71696 L p .707 .577 .707 r
F P
0 g
s
.50473 .70722 m .50257 .65337 L .5096 .64199 L p .707 .577 .707 r
F P
0 g
s
.50518 .71696 m .50493 .75417 L .50783 .76224 L p .707 .577 .707 r
F P
0 g
s
.50523 .79902 m .50661 .77992 L .50351 .77678 L p .707 .577 .707 r
F P
0 g
s
.50351 .77678 m .50214 .79588 L .50523 .79902 L p .707 .577 .707 r
F P
0 g
s
.5096 .64199 m .51175 .69584 L .50473 .70722 L p .707 .577 .707 r
F P
0 g
s
.50493 .75417 m .50518 .71696 L .51226 .70912 L p .707 .577 .707 r
F P
0 g
s
.51175 .69584 m .5096 .64199 L .52591 .63159 L p .707 .577 .707 r
F P
0 g
s
.51226 .70912 m .51202 .74633 L .50493 .75417 L p .707 .577 .707 r
F P
0 g
s
.50214 .79588 m .50351 .77678 L .51038 .77441 L p .707 .577 .707 r
F P
0 g
s
.51038 .77441 m .509 .79351 L .50214 .79588 L p .707 .577 .707 r
F P
0 g
s
.52591 .63159 m .52806 .68545 L .51175 .69584 L p .707 .577 .707 r
F P
0 g
s
.51202 .74633 m .51226 .70912 L .52863 .70227 L p .707 .577 .707 r
F P
0 g
s
.52863 .70227 m .52838 .73948 L .51202 .74633 L p .707 .577 .707 r
F P
0 g
s
.509 .79351 m .51038 .77441 L .52653 .77304 L p .707 .577 .707 r
F P
0 g
s
.52653 .77304 m .52515 .79214 L .509 .79351 L p .707 .577 .707 r
F P
0 g
s
.52515 .79214 m .52653 .77304 L .55038 .7728 L p .707 .577 .707 r
F P
0 g
s
.55038 .7728 m .54901 .7919 L .52515 .79214 L p .707 .577 .707 r
F P
0 g
s
.48534 .32556 m .4885 .82526 L .53344 .82384 L p .707 .577 .707 r
F P
0 g
s
.52806 .68545 m .52591 .63159 L .5499 .62322 L p .707 .577 .707 r
F P
0 g
s
.5499 .62322 m .55206 .67707 L .52806 .68545 L p .707 .577 .707 r
F P
0 g
s
.52838 .73948 m .52863 .70227 L .55268 .69709 L p .707 .577 .707 r
F P
0 g
s
.55268 .69709 m .55244 .7343 L .52838 .73948 L p .707 .577 .707 r
F P
0 g
s
.53344 .82384 m .53028 .32414 L .48534 .32556 L p .707 .577 .707 r
F P
0 g
s
.70635 .65096 m .70851 .70481 L .70556 .69354 L p .707 .577 .707 r
F P
0 g
s
.70556 .69354 m .7034 .63969 L .70635 .65096 L p .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .5499 .62322 L .55178 .62286 L p .707 .577 .707 r
F P
0 g
s
.55178 .62286 m .57924 .61767 L p .55844 .66314 L .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .55178 .62286 L .55844 .66314 L .707 .577 .707 r
F
.5814 .67153 m .57924 .61767 L .61105 .61551 L p F P
0 g
s
.57924 .61767 m .5814 .67153 L .55206 .67707 L p .707 .577 .707 r
F P
0 g
s
.61105 .61551 m .61321 .66936 L .5814 .67153 L p .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .55268 .69709 L .56291 .69604 L p .707 .577 .707 r
F P
0 g
s
.56291 .69604 m .58206 .69408 L p .56154 .72194 L .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .56291 .69604 L .56154 .72194 L .707 .577 .707 r
F
.58206 .69408 m .58182 .73129 L .55244 .7343 L p F P
0 g
s
.58182 .73129 m .58206 .69408 L .61389 .69354 L p .707 .577 .707 r
F P
0 g
s
.61389 .69354 m .61365 .73076 L .58182 .73129 L p .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .57961 .77371 L .58581 .7741 L p .707 .577 .707 r
F P
0 g
s
.58581 .7741 m .61134 .77569 L p .58405 .78981 L .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .58581 .7741 L .58405 .78981 L .707 .577 .707 r
F
.64221 .61693 m .64437 .67078 L .61321 .66936 L p F P
0 g
s
.61321 .66936 m .61105 .61551 L .64221 .61693 L p .707 .577 .707 r
F P
0 g
s
.64507 .69553 m .64482 .73274 L .61365 .73076 L p .707 .577 .707 r
F P
0 g
s
.61365 .73076 m .61389 .69354 L .64507 .69553 L p .707 .577 .707 r
F P
0 g
s
.64248 .77854 m .64111 .79764 L .61377 .79514 L p .707 .577 .707 r
F P
0 g
s
.61377 .79514 m .60997 .79479 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.61386 .79285 m .64248 .77854 L .61377 .79514 L .707 .577 .707 r
F
.64111 .79764 m .64248 .77854 L .66997 .78198 L p F P
0 g
s
.60997 .79479 m .61134 .77569 L .61453 .77598 L p .707 .577 .707 r
F P
0 g
s
.61453 .77598 m .64248 .77854 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.60997 .79479 m .61453 .77598 L .61386 .79285 L .707 .577 .707 r
F
.64198 .78635 m .63882 .28665 L .63376 .29299 L p F P
0 g
s
.63376 .29299 m .62882 .29916 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.64198 .78635 m .63376 .29299 L .63072 .3693 L .707 .577 .707 r
F
.63199 .79886 m .64198 .78635 L p .63072 .3693 L F P
0 g
s
.62882 .29916 m .62947 .40074 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.62947 .40074 m .63199 .79886 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.61134 .77569 m .60997 .79479 L .57824 .79281 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .63199 .79886 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60572 .31026 m .60743 .58166 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60743 .58166 m .60888 .80996 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .57829 .40525 L .57456 .76058 L .707 .577 .707 r
F
.57176 .31887 m .57295 .50625 L p .57829 .40525 L F P
0 g
s
.57295 .50625 m .57456 .76058 L p .57829 .40525 L .707 .577 .707 r
F P
0 g
s
.54901 .7919 m .55038 .7728 L .57961 .77371 L p .707 .577 .707 r
F P
0 g
s
.57961 .77371 m .57824 .79281 L .54901 .7919 L p .707 .577 .707 r
F P
0 g
s
.57456 .76058 m .57492 .81857 L .58378 .81633 L p .707 .577 .707 r
F P
0 g
s
.58378 .81633 m .60888 .80996 L p .57456 .76058 L .707 .577 .707 r
F P
0 g
s
.53028 .32414 m .53344 .82384 L .57492 .81857 L p .707 .577 .707 r
F P
0 g
s
.57492 .81857 m .57176 .31887 L .53028 .32414 L p .707 .577 .707 r
F P
0 g
s
.44449 .82269 m .44133 .32299 L .40257 .31668 L p .707 .577 .707 r
F P
0 g
s
.44133 .32299 m .44449 .82269 L .4885 .82526 L p .707 .577 .707 r
F P
0 g
s
.70011 .79478 m .69874 .81388 L .7056 .81151 L p .707 .577 .707 r
F P
0 g
s
.7056 .81151 m .70697 .79241 L .70011 .79478 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .60572 .31026 L .57176 .31887 L p .707 .577 .707 r
F P
0 g
s
.70907 .72164 m .70883 .75885 L .70593 .75078 L p .707 .577 .707 r
F P
0 g
s
.70593 .75078 m .70618 .71356 L .70907 .72164 L p .707 .577 .707 r
F P
0 g
s
.7034 .63969 m .70556 .69354 L .69292 .6835 L p .707 .577 .707 r
F P
0 g
s
.69292 .6835 m .69077 .62964 L .7034 .63969 L p .707 .577 .707 r
F P
0 g
s
.40573 .81638 m .40257 .31668 L .37284 .30724 L p .707 .577 .707 r
F P
0 g
s
.40257 .31668 m .40573 .81638 L .44449 .82269 L p .707 .577 .707 r
F P
0 g
s
.70697 .79241 m .7056 .81151 L .70251 .80837 L p .707 .577 .707 r
F P
0 g
s
.70251 .80837 m .70388 .78927 L .70697 .79241 L p .707 .577 .707 r
F P
0 g
s
.25702 .70586 m .25486 .65201 L .2237 .65059 L p .707 .577 .707 r
F P
0 g
s
.25486 .65201 m .25702 .70586 L .28883 .7037 L p .707 .577 .707 r
F P
0 g
s
.28883 .7037 m .28667 .64985 L .25486 .65201 L p .707 .577 .707 r
F P
0 g
s
.28667 .64985 m .28883 .7037 L .31817 .69815 L p .707 .577 .707 r
F P
0 g
s
.31817 .69815 m .31601 .6443 L .28667 .64985 L p .707 .577 .707 r
F P
0 g
s
.63199 .79886 m .62882 .29916 L .60572 .31026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22586 .70444 m .2237 .65059 L .19623 .64572 L p .707 .577 .707 r
F P
0 g
s
.2237 .65059 m .22586 .70444 L .25702 .70586 L p .707 .577 .707 r
F P
0 g
s
.69077 .62964 m .69292 .6835 L .67184 .67565 L p .707 .577 .707 r
F P
0 g
s
.67184 .67565 m .66968 .6218 L .69077 .62964 L p .707 .577 .707 r
F P
0 g
s
.70618 .71356 m .70593 .75078 L .69334 .74326 L p .707 .577 .707 r
F P
0 g
s
.69334 .74326 m .69358 .70605 L .70618 .71356 L p .707 .577 .707 r
F P
0 g
s
.31601 .6443 m .31817 .69815 L .34217 .68978 L p .707 .577 .707 r
F P
0 g
s
.34217 .68978 m .34001 .63593 L .31601 .6443 L p .707 .577 .707 r
F P
0 g
s
.376 .80694 m .37284 .30724 L .35506 .29561 L p .707 .577 .707 r
F P
0 g
s
.37284 .30724 m .376 .80694 L .40573 .81638 L p .707 .577 .707 r
F P
0 g
s
.2571 .74545 m .25735 .70824 L .22618 .70625 L p .707 .577 .707 r
F P
0 g
s
.25735 .70824 m .2571 .74545 L .28894 .74491 L p .707 .577 .707 r
F P
0 g
s
.28894 .74491 m .28918 .7077 L .25735 .70824 L p .707 .577 .707 r
F P
0 g
s
.19839 .69957 m .19623 .64572 L .17515 .63788 L p .707 .577 .707 r
F P
0 g
s
.19623 .64572 m .19839 .69957 L .22586 .70444 L p .707 .577 .707 r
F P
0 g
s
.28918 .7077 m .28894 .74491 L .31832 .7419 L p .707 .577 .707 r
F P
0 g
s
.31832 .7419 m .31856 .70469 L .28918 .7077 L p .707 .577 .707 r
F P
0 g
s
.70388 .78927 m .70251 .80837 L .68976 .80478 L p .707 .577 .707 r
F P
0 g
s
.68976 .80478 m .69113 .78568 L .70388 .78927 L p .707 .577 .707 r
F P
0 g
s
.22593 .74347 m .22618 .70625 L .19872 .70194 L p .707 .577 .707 r
F P
0 g
s
.22618 .70625 m .22593 .74347 L .2571 .74545 L p .707 .577 .707 r
F P
0 g
s
.25476 .77579 m .25613 .75668 L .225 .75383 L p .707 .577 .707 r
F P
0 g
s
.25613 .75668 m .25476 .77579 L .2865 .77777 L p .707 .577 .707 r
F P
0 g
s
.2865 .77777 m .28787 .75866 L .25613 .75668 L p .707 .577 .707 r
F P
0 g
s
.34001 .63593 m .34217 .68978 L .35848 .67939 L p .707 .577 .707 r
F P
0 g
s
.35848 .67939 m .35632 .62553 L .34001 .63593 L p .707 .577 .707 r
F P
0 g
s
.225 .75383 m .22362 .77294 L .25476 .77579 L p .707 .577 .707 r
F P
0 g
s
.66968 .6218 m .67184 .67565 L .64437 .67078 L p .707 .577 .707 r
F P
0 g
s
.64437 .67078 m .64221 .61693 L .66968 .6218 L p .707 .577 .707 r
F P
0 g
s
.28787 .75866 m .2865 .77777 L .31572 .77868 L p .707 .577 .707 r
F P
0 g
s
.31572 .77868 m .31709 .75958 L .28787 .75866 L p .707 .577 .707 r
F P
0 g
s
.31856 .70469 m .31832 .7419 L .34237 .73672 L p .707 .577 .707 r
F P
0 g
s
.34237 .73672 m .34262 .69951 L .31856 .70469 L p .707 .577 .707 r
F P
0 g
s
.19872 .70194 m .19847 .73916 L .22593 .74347 L p .707 .577 .707 r
F P
0 g
s
.22362 .77294 m .225 .75383 L .1975 .75039 L p .707 .577 .707 r
F P
0 g
s
.1975 .75039 m .19613 .76949 L .22362 .77294 L p .707 .577 .707 r
F P
0 g
s
.69358 .70605 m .69334 .74326 L .67228 .73705 L p .707 .577 .707 r
F P
0 g
s
.67228 .73705 m .67253 .69984 L .69358 .70605 L p .707 .577 .707 r
F P
0 g
s
.17515 .63788 m .17731 .69173 L .19839 .69957 L p .707 .577 .707 r
F P
0 g
s
.19847 .73916 m .19872 .70194 L .17766 .69573 L p .707 .577 .707 r
F P
0 g
s
.17731 .69173 m .17515 .63788 L .16251 .62783 L p .707 .577 .707 r
F P
0 g
s
.31709 .75958 m .31572 .77868 L .33958 .77844 L p .707 .577 .707 r
F P
0 g
s
.33958 .77844 m .34095 .75933 L .31709 .75958 L p .707 .577 .707 r
F P
0 g
s
.17766 .69573 m .17742 .73294 L .19847 .73916 L p .707 .577 .707 r
F P
0 g
s
.19613 .76949 m .1975 .75039 L .17635 .74669 L p .707 .577 .707 r
F P
0 g
s
.17635 .74669 m .17497 .7658 L .19613 .76949 L p .707 .577 .707 r
F P
0 g
s
.69113 .78568 m .68976 .80478 L .6686 .80108 L p .707 .577 .707 r
F P
0 g
s
.6686 .80108 m .66997 .78198 L .69113 .78568 L p .707 .577 .707 r
F P
0 g
s
.34262 .69951 m .34237 .73672 L .35874 .72988 L p .707 .577 .707 r
F P
0 g
s
.35874 .72988 m .35898 .69266 L .34262 .69951 L p .707 .577 .707 r
F P
0 g
s
.35632 .62553 m .35848 .67939 L .3655 .668 L p .707 .577 .707 r
F P
0 g
s
.3655 .668 m .36334 .61415 L .35632 .62553 L p .707 .577 .707 r
F P
0 g
s
.3571 .75796 m .35573 .77706 L .36259 .77469 L p .707 .577 .707 r
F P
0 g
s
.36259 .77469 m .36396 .75559 L .3571 .75796 L p .707 .577 .707 r
F P
0 g
s
.36039 .60288 m .36255 .65673 L .35892 .65385 L p .707 .577 .707 r
F P
0 g
s
.35892 .65385 m .34991 .64668 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.35953 .60647 m .36039 .60288 L .35892 .65385 L .707 .577 .707 r
F
.34991 .64668 m .34776 .59283 L .35959 .60224 L p F P
0 g
s
.35959 .60224 m .36039 .60288 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.34991 .64668 m .35959 .60224 L .35953 .60647 L .707 .577 .707 r
F
.34095 .75933 m .33958 .77844 L .35573 .77706 L p F P
0 g
s
.35573 .77706 m .3571 .75796 L .34095 .75933 L p .707 .577 .707 r
F P
0 g
s
.35898 .69266 m .35874 .72988 L .36582 .72203 L p .707 .577 .707 r
F P
0 g
s
.36582 .72203 m .36606 .68482 L .35898 .69266 L p .707 .577 .707 r
F P
0 g
s
.36317 .67675 m .36292 .71396 L .35928 .71179 L p .707 .577 .707 r
F P
0 g
s
.35928 .71179 m .35033 .70645 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35895 .68651 m .36317 .67675 L .35928 .71179 L .707 .577 .707 r
F
.35033 .70645 m .35057 .66924 L .35878 .67413 L p F P
0 g
s
.35878 .67413 m .36317 .67675 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35033 .70645 m .35878 .67413 L .35895 .68651 L .707 .577 .707 r
F
.34675 .76797 m .34812 .74886 L .36079 .75243 L p F P
0 g
s
.36079 .75243 m .36087 .75246 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.34675 .76797 m .36079 .75243 L .36079 .75254 L .707 .577 .707 r
F
.35786 .73732 m .35751 .68206 L p .35764 .75416 L F P
0 g
s
.35751 .68206 m .35625 .48299 L p .35724 .67636 L .707 .577 .707 r
F P
0 g
s
.35751 .68206 m .35724 .67636 L .35764 .75416 L .707 .577 .707 r
F
.35625 .48299 m .35506 .29561 L p .35602 .46576 L F P
0 g
s
.35625 .48299 m .35602 .46576 L .35764 .75416 L .707 .577 .707 r
F
.35764 .75416 m .35602 .46576 L .35097 .28292 L F
.35506 .29561 m .35371 .29141 L p .35602 .46576 L F P
0 g
s
.35371 .29141 m .35097 .28292 L p .35602 .46576 L .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .34675 .76797 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36087 .75246 m .36082 .75313 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36082 .75313 m .3595 .77156 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35716 .792 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35097 .28292 m .35287 .5826 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35287 .5826 m .35413 .78262 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35716 .792 m .35822 .79531 L p .35764 .75416 L .707 .577 .707 r
F P
0 g
s
.35764 .75416 m .35097 .28292 L .35716 .792 L .707 .577 .707 r
F
.35822 .79531 m .35786 .73732 L p .35764 .75416 L F P
0 g
s
.36334 .61415 m .3655 .668 L .36255 .65673 L p .707 .577 .707 r
F P
0 g
s
.36255 .65673 m .36039 .60288 L .36334 .61415 L p .707 .577 .707 r
F P
0 g
s
.36606 .68482 m .36582 .72203 L .36292 .71396 L p .707 .577 .707 r
F P
0 g
s
.36292 .71396 m .36317 .67675 L .36606 .68482 L p .707 .577 .707 r
F P
0 g
s
.36396 .75559 m .36259 .77469 L .3595 .77156 L p .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .36087 .75246 L .36396 .75559 L p .707 .577 .707 r
F P
0 g
s
.35506 .29561 m .35822 .79531 L .376 .80694 L p .707 .577 .707 r
F P
0 g
s
.67253 .69984 m .67228 .73705 L .64482 .73274 L p .707 .577 .707 r
F P
0 g
s
.64482 .73274 m .64507 .69553 L .67253 .69984 L p .707 .577 .707 r
F P
0 g
s
.16251 .62783 m .16467 .68168 L .17731 .69173 L p .707 .577 .707 r
F P
0 g
s
.17742 .73294 m .17766 .69573 L .16507 .68822 L p .707 .577 .707 r
F P
0 g
s
.16467 .68168 m .16251 .62783 L .15956 .61656 L p .707 .577 .707 r
F P
0 g
s
.16507 .68822 m .16482 .72543 L .17742 .73294 L p .707 .577 .707 r
F P
0 g
s
.17497 .7658 m .17635 .74669 L .1636 .7431 L p .707 .577 .707 r
F P
0 g
s
.1636 .7431 m .16222 .7622 L .17497 .7658 L p .707 .577 .707 r
F P
0 g
s
.66997 .78198 m .6686 .80108 L .64111 .79764 L p .707 .577 .707 r
F P
0 g
s
.63882 .28665 m .64198 .78635 L .63789 .77366 L p .707 .577 .707 r
F P
0 g
s
.63789 .77366 m .63473 .27396 L .63882 .28665 L p .707 .577 .707 r
F P
0 g
s
.15956 .61656 m .16172 .67041 L .16467 .68168 L p .707 .577 .707 r
F P
0 g
s
.16482 .72543 m .16507 .68822 L .16217 .68014 L p .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35097 .28292 L .36097 .27041 L p .707 .577 .707 r
F P
0 g
s
.16172 .67041 m .15956 .61656 L .16659 .60517 L p .707 .577 .707 r
F P
0 g
s
.16217 .68014 m .16193 .71736 L .16482 .72543 L p .707 .577 .707 r
F P
0 g
s
.16222 .7622 m .1636 .7431 L .1605 .73997 L p .707 .577 .707 r
F P
0 g
s
.1605 .73997 m .15913 .75907 L .16222 .7622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16659 .60517 m .16874 .65902 L .16172 .67041 L p .707 .577 .707 r
F P
0 g
s
.63473 .27396 m .63789 .77366 L .62011 .76203 L p .707 .577 .707 r
F P
0 g
s
.62011 .76203 m .61695 .26233 L .63473 .27396 L p .707 .577 .707 r
F P
0 g
s
.16193 .71736 m .16217 .68014 L .16925 .6723 L p .707 .577 .707 r
F P
0 g
s
.16874 .65902 m .16659 .60517 L .1829 .59478 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16925 .6723 m .16901 .70951 L .16193 .71736 L p .707 .577 .707 r
F P
0 g
s
.15913 .75907 m .1605 .73997 L .16737 .7376 L p .707 .577 .707 r
F P
0 g
s
.16737 .7376 m .16599 .7567 L .15913 .75907 L p .707 .577 .707 r
F P
0 g
s
.36413 .77011 m .36097 .27041 L .38407 .25931 L p .707 .577 .707 r
F P
0 g
s
.36097 .27041 m .36413 .77011 L .35413 .78262 L p .707 .577 .707 r
F P
0 g
s
.34776 .59283 m .34991 .64668 L .32883 .63884 L p .707 .577 .707 r
F P
0 g
s
.32883 .63884 m .32667 .58498 L .34776 .59283 L p .707 .577 .707 r
F P
0 g
s
.1829 .59478 m .18505 .64863 L .16874 .65902 L p .707 .577 .707 r
F P
0 g
s
.18505 .64863 m .1829 .59478 L .20689 .5864 L p .707 .577 .707 r
F P
0 g
s
.16901 .70951 m .16925 .6723 L .18562 .66545 L p .707 .577 .707 r
F P
0 g
s
.61695 .26233 m .62011 .76203 L .59039 .7526 L p .707 .577 .707 r
F P
0 g
s
.59039 .7526 m .58722 .2529 L .61695 .26233 L p .707 .577 .707 r
F P
0 g
s
.18562 .66545 m .18537 .70267 L .16901 .70951 L p .707 .577 .707 r
F P
0 g
s
.32667 .58498 m .32883 .63884 L .30136 .63397 L p .707 .577 .707 r
F P
0 g
s
.30136 .63397 m .29921 .58011 L .32667 .58498 L p .707 .577 .707 r
F P
0 g
s
.16599 .7567 m .16737 .7376 L .18352 .73622 L p .707 .577 .707 r
F P
0 g
s
.18352 .73622 m .18214 .75533 L .16599 .7567 L p .707 .577 .707 r
F P
0 g
s
.35057 .66924 m .35033 .70645 L .32927 .70023 L p .707 .577 .707 r
F P
0 g
s
.32927 .70023 m .32952 .66302 L .35057 .66924 L p .707 .577 .707 r
F P
0 g
s
.20905 .64025 m .20689 .5864 L .23623 .58086 L p .707 .577 .707 r
F P
0 g
s
.20689 .5864 m .20905 .64025 L .18505 .64863 L p .707 .577 .707 r
F P
0 g
s
.38407 .25931 m .38724 .75901 L .36413 .77011 L p .707 .577 .707 r
F P
0 g
s
.38724 .75901 m .38407 .25931 L .41803 .2507 L p .707 .577 .707 r
F P
0 g
s
.29921 .58011 m .30136 .63397 L .2702 .63254 L p .707 .577 .707 r
F P
0 g
s
.2702 .63254 m .26804 .57869 L .29921 .58011 L p .707 .577 .707 r
F P
0 g
s
.18537 .70267 m .18562 .66545 L .20967 .66027 L p .707 .577 .707 r
F P
0 g
s
.23839 .63471 m .23623 .58086 L .26804 .57869 L p .707 .577 .707 r
F P
0 g
s
.23623 .58086 m .23839 .63471 L .20905 .64025 L p .707 .577 .707 r
F P
0 g
s
.34812 .74886 m .34675 .76797 L .32559 .76427 L p .707 .577 .707 r
F P
0 g
s
.32559 .76427 m .32696 .74517 L .34812 .74886 L p .707 .577 .707 r
F P
0 g
s
.26804 .57869 m .2702 .63254 L .23839 .63471 L p .707 .577 .707 r
F P
0 g
s
.20967 .66027 m .20943 .69749 L .18537 .70267 L p .707 .577 .707 r
F P
0 g
s
.32952 .66302 m .32927 .70023 L .30181 .69592 L p .707 .577 .707 r
F P
0 g
s
.30181 .69592 m .30206 .65871 L .32952 .66302 L p .707 .577 .707 r
F P
0 g
s
.18214 .75533 m .18352 .73622 L .20737 .73598 L p .707 .577 .707 r
F P
0 g
s
.58722 .2529 m .59039 .7526 L .55162 .74628 L p .707 .577 .707 r
F P
0 g
s
.55162 .74628 m .54846 .24658 L .58722 .2529 L p .707 .577 .707 r
F P
0 g
s
.20737 .73598 m .206 .75508 L .18214 .75533 L p .707 .577 .707 r
F P
0 g
s
.20943 .69749 m .20967 .66027 L .23905 .65727 L p .707 .577 .707 r
F P
0 g
s
.73723 .67761 m .73507 .62376 L .70391 .62234 L p .707 .577 .707 r
F P
0 g
s
.73507 .62376 m .73723 .67761 L .76904 .67545 L p .707 .577 .707 r
F P
0 g
s
.76904 .67545 m .76688 .62159 L .73507 .62376 L p .707 .577 .707 r
F P
0 g
s
.76688 .62159 m .76904 .67545 L .79838 .6699 L p .707 .577 .707 r
F P
0 g
s
.79838 .6699 m .79622 .61605 L .76688 .62159 L p .707 .577 .707 r
F P
0 g
s
.42119 .7504 m .41803 .2507 L .45951 .24543 L p .707 .577 .707 r
F P
0 g
s
.41803 .2507 m .42119 .7504 L .38724 .75901 L p .707 .577 .707 r
F P
0 g
s
.30206 .65871 m .30181 .69592 L .27064 .69394 L p .707 .577 .707 r
F P
0 g
s
.27064 .69394 m .27089 .65673 L .30206 .65871 L p .707 .577 .707 r
F P
0 g
s
.70607 .67619 m .70391 .62234 L .67644 .61747 L p .707 .577 .707 r
F P
0 g
s
.70391 .62234 m .70607 .67619 L .73723 .67761 L p .707 .577 .707 r
F P
0 g
s
.32696 .74517 m .32559 .76427 L .2981 .76083 L p .707 .577 .707 r
F P
0 g
s
.2981 .76083 m .29947 .74172 L .32696 .74517 L p .707 .577 .707 r
F P
0 g
s
.23905 .65727 m .23881 .69448 L .20943 .69749 L p .707 .577 .707 r
F P
0 g
s
.23881 .69448 m .23905 .65727 L .27089 .65673 L p .707 .577 .707 r
F P
0 g
s
.27089 .65673 m .27064 .69394 L .23881 .69448 L p .707 .577 .707 r
F P
0 g
s
.206 .75508 m .20737 .73598 L .2366 .73689 L p .707 .577 .707 r
F P
0 g
s
.79622 .61605 m .79838 .6699 L .82238 .66153 L p .707 .577 .707 r
F P
0 g
s
.82238 .66153 m .82022 .60767 L .79622 .61605 L p .707 .577 .707 r
F P
0 g
s
.54846 .24658 m .55162 .74628 L .50761 .74371 L p .707 .577 .707 r
F P
0 g
s
.50761 .74371 m .50445 .24401 L .54846 .24658 L p .707 .577 .707 r
F P
0 g
s
.2366 .73689 m .23523 .756 L .206 .75508 L p .707 .577 .707 r
F P
0 g
s
.46267 .74513 m .45951 .24543 L .50445 .24401 L p .707 .577 .707 r
F P
0 g
s
.45951 .24543 m .46267 .74513 L .42119 .7504 L p .707 .577 .707 r
F P
0 g
s
.6786 .67132 m .67644 .61747 L .65536 .60962 L p .707 .577 .707 r
F P
0 g
s
.67644 .61747 m .6786 .67132 L .70607 .67619 L p .707 .577 .707 r
F P
0 g
s
.29947 .74172 m .2981 .76083 L .26696 .75798 L p .707 .577 .707 r
F P
0 g
s
.26696 .75798 m .26833 .73887 L .29947 .74172 L p .707 .577 .707 r
F P
0 g
s
.50445 .24401 m .50761 .74371 L .46267 .74513 L p .707 .577 .707 r
F P
0 g
s
.23523 .756 m .2366 .73689 L .26833 .73887 L p .707 .577 .707 r
F P
0 g
s
.73732 .73686 m .73756 .69965 L .70639 .69767 L p .707 .577 .707 r
F P
0 g
s
.73756 .69965 m .73732 .73686 L .76915 .73633 L p .707 .577 .707 r
F P
0 g
s
.76915 .73633 m .7694 .69911 L .73756 .69965 L p .707 .577 .707 r
F P
0 g
s
.26833 .73887 m .26696 .75798 L .23523 .756 L p .707 .577 .707 r
F P
0 g
s
.7694 .69911 m .76915 .73633 L .79853 .73332 L p .707 .577 .707 r
F P
0 g
s
.79853 .73332 m .79878 .69611 L .7694 .69911 L p .707 .577 .707 r
F P
0 g
s
.82022 .60767 m .82238 .66153 L .83869 .65113 L p .707 .577 .707 r
F P
0 g
s
.83869 .65113 m .83653 .59728 L .82022 .60767 L p .707 .577 .707 r
F P
0 g
s
.70615 .73488 m .70639 .69767 L .67893 .69336 L p .707 .577 .707 r
F P
0 g
s
.70639 .69767 m .70615 .73488 L .73732 .73686 L p .707 .577 .707 r
F P
0 g
s
.73497 .7602 m .73635 .7411 L .70521 .73825 L p .707 .577 .707 r
F P
0 g
s
.73635 .7411 m .73497 .7602 L .76671 .76218 L p .707 .577 .707 r
F P
0 g
s
.76671 .76218 m .76808 .74308 L .73635 .7411 L p .707 .577 .707 r
F P
0 g
s
.70521 .73825 m .70384 .75735 L .73497 .7602 L p .707 .577 .707 r
F P
0 g
s
.76808 .74308 m .76671 .76218 L .79593 .76309 L p .707 .577 .707 r
F P
0 g
s
.79593 .76309 m .79731 .74399 L .76808 .74308 L p .707 .577 .707 r
F P
0 g
s
.70384 .75735 m .70521 .73825 L .67772 .7348 L p .707 .577 .707 r
F P
0 g
s
.79878 .69611 m .79853 .73332 L .82258 .72814 L p .707 .577 .707 r
F P
0 g
s
.82258 .72814 m .82283 .69093 L .79878 .69611 L p .707 .577 .707 r
F P
0 g
s
.65536 .60962 m .65752 .66348 L .6786 .67132 L p .707 .577 .707 r
F P
0 g
s
.67893 .69336 m .67869 .73057 L .70615 .73488 L p .707 .577 .707 r
F P
0 g
s
.67772 .7348 m .67634 .75391 L .70384 .75735 L p .707 .577 .707 r
F P
0 g
s
.65752 .66348 m .65536 .60962 L .64273 .59958 L p .707 .577 .707 r
F P
0 g
s
.67869 .73057 m .67893 .69336 L .65787 .68714 L p .707 .577 .707 r
F P
0 g
s
.79731 .74399 m .79593 .76309 L .81979 .76285 L p .707 .577 .707 r
F P
0 g
s
.81979 .76285 m .82116 .74375 L .79731 .74399 L p .707 .577 .707 r
F P
0 g
s
.67634 .75391 m .67772 .7348 L .65656 .73111 L p .707 .577 .707 r
F P
0 g
s
.83653 .59728 m .83869 .65113 L .84571 .63975 L p .707 .577 .707 r
F P
0 g
s
.84571 .63975 m .84356 .58589 L .83653 .59728 L p .707 .577 .707 r
F P
0 g
s
.65787 .68714 m .65763 .72436 L .67869 .73057 L p .707 .577 .707 r
F P
0 g
s
.65656 .73111 m .65519 .75021 L .67634 .75391 L p .707 .577 .707 r
F P
0 g
s
.82283 .69093 m .82258 .72814 L .83895 .72129 L p .707 .577 .707 r
F P
0 g
s
.83895 .72129 m .8392 .68408 L .82283 .69093 L p .707 .577 .707 r
F P
0 g
s
.64273 .59958 m .64488 .65343 L .65752 .66348 L p .707 .577 .707 r
F P
0 g
s
.64488 .65343 m .64273 .59958 L .63978 .58831 L p .707 .577 .707 r
F P
0 g
s
.65763 .72436 m .65787 .68714 L .64528 .67963 L p .707 .577 .707 r
F P
0 g
s
.82116 .74375 m .81979 .76285 L .83594 .76148 L p .707 .577 .707 r
F P
0 g
s
.83594 .76148 m .83731 .74237 L .82116 .74375 L p .707 .577 .707 r
F P
0 g
s
.65519 .75021 m .65656 .73111 L .64381 .72751 L p .707 .577 .707 r
F P
0 g
s
.64528 .67963 m .64504 .71685 L .65763 .72436 L p .707 .577 .707 r
F P
0 g
s
.64381 .72751 m .64244 .74662 L .65519 .75021 L p .707 .577 .707 r
F P
0 g
s
.84356 .58589 m .84571 .63975 L .84276 .62848 L p .707 .577 .707 r
F P
0 g
s
.84276 .62848 m .84061 .57462 L .84356 .58589 L p .707 .577 .707 r
F P
0 g
s
.8392 .68408 m .83895 .72129 L .84603 .71345 L p .707 .577 .707 r
F P
0 g
s
.84603 .71345 m .84628 .67624 L .8392 .68408 L p .707 .577 .707 r
F P
0 g
s
.63978 .58831 m .64193 .64216 L .64488 .65343 L p .707 .577 .707 r
F P
0 g
s
.83731 .74237 m .83594 .76148 L .8428 .75911 L p .707 .577 .707 r
F P
0 g
s
.8428 .75911 m .84418 .74 L .83731 .74237 L p .707 .577 .707 r
F P
0 g
s
.64504 .71685 m .64528 .67963 L .64238 .67156 L p .707 .577 .707 r
F P
0 g
s
.64193 .64216 m .63978 .58831 L .6468 .57692 L p .707 .577 .707 r
F P
0 g
s
.64244 .74662 m .64381 .72751 L .64072 .72438 L p .707 .577 .707 r
F P
0 g
s
.64238 .67156 m .64214 .70877 L .64504 .71685 L p .707 .577 .707 r
F P
0 g
s
.64072 .72438 m .63934 .74348 L .64244 .74662 L p .707 .577 .707 r
F P
0 g
s
.84061 .57462 m .84276 .62848 L .83013 .61843 L p .707 .577 .707 r
F P
0 g
s
.83013 .61843 m .82797 .56458 L .84061 .57462 L p .707 .577 .707 r
F P
0 g
s
.84628 .67624 m .84603 .71345 L .84314 .70538 L p .707 .577 .707 r
F P
0 g
s
.84314 .70538 m .84338 .66816 L .84628 .67624 L p .707 .577 .707 r
F P
0 g
s
.6468 .57692 m .64896 .63077 L .64193 .64216 L p .707 .577 .707 r
F P
0 g
s
.64896 .63077 m .6468 .57692 L .66311 .56653 L p .707 .577 .707 r
F P
0 g
s
.84418 .74 m .8428 .75911 L .83971 .75597 L p .707 .577 .707 r
F P
0 g
s
.83971 .75597 m .84108 .73687 L .84418 .74 L p .707 .577 .707 r
F P
0 g
s
.39422 .6408 m .39207 .58695 L .3609 .58552 L p .707 .577 .707 r
F P
0 g
s
.39207 .58695 m .39422 .6408 L .42603 .63863 L p .707 .577 .707 r
F P
0 g
s
.42603 .63863 m .42387 .58478 L .39207 .58695 L p .707 .577 .707 r
F P
0 g
s
.64214 .70877 m .64238 .67156 L .64946 .66372 L p .707 .577 .707 r
F P
0 g
s
.42387 .58478 m .42603 .63863 L .45537 .63309 L p .707 .577 .707 r
F P
0 g
s
.45537 .63309 m .45321 .57923 L .42387 .58478 L p .707 .577 .707 r
F P
0 g
s
.36306 .63938 m .3609 .58552 L .33343 .58065 L p .707 .577 .707 r
F P
0 g
s
.3609 .58552 m .36306 .63938 L .39422 .6408 L p .707 .577 .707 r
F P
0 g
s
.64946 .66372 m .64922 .70093 L .64214 .70877 L p .707 .577 .707 r
F P
0 g
s
.63934 .74348 m .64072 .72438 L .64758 .72201 L p .707 .577 .707 r
F P
0 g
s
.64758 .72201 m .64621 .74111 L .63934 .74348 L p .707 .577 .707 r
F P
0 g
s
.82797 .56458 m .83013 .61843 L .80905 .61058 L p .707 .577 .707 r
F P
0 g
s
.80905 .61058 m .80689 .55673 L .82797 .56458 L p .707 .577 .707 r
F P
0 g
s
.45321 .57923 m .45537 .63309 L .47937 .62471 L p .707 .577 .707 r
F P
0 g
s
.47937 .62471 m .47721 .57086 L .45321 .57923 L p .707 .577 .707 r
F P
0 g
s
.84338 .66816 m .84314 .70538 L .83054 .69786 L p .707 .577 .707 r
F P
0 g
s
.83054 .69786 m .83079 .66065 L .84338 .66816 L p .707 .577 .707 r
F P
0 g
s
.66311 .56653 m .66527 .62038 L .64896 .63077 L p .707 .577 .707 r
F P
0 g
s
.33559 .6345 m .33343 .58065 L .31235 .57281 L p .707 .577 .707 r
F P
0 g
s
.33343 .58065 m .33559 .6345 L .36306 .63938 L p .707 .577 .707 r
F P
0 g
s
.66527 .62038 m .66311 .56653 L .68711 .55815 L p .707 .577 .707 r
F P
0 g
s
.39431 .70005 m .39455 .66284 L .36338 .66085 L p .707 .577 .707 r
F P
0 g
s
.39455 .66284 m .39431 .70005 L .42614 .69951 L p .707 .577 .707 r
F P
0 g
s
.42614 .69951 m .42639 .6623 L .39455 .66284 L p .707 .577 .707 r
F P
0 g
s
.42639 .6623 m .42614 .69951 L .45552 .6965 L p .707 .577 .707 r
F P
0 g
s
.45552 .6965 m .45577 .65929 L .42639 .6623 L p .707 .577 .707 r
F P
0 g
s
.64922 .70093 m .64946 .66372 L .66583 .65687 L p .707 .577 .707 r
F P
0 g
s
.84108 .73687 m .83971 .75597 L .82696 .75238 L p .707 .577 .707 r
F P
0 g
s
.82696 .75238 m .82834 .73328 L .84108 .73687 L p .707 .577 .707 r
F P
0 g
s
.47721 .57086 m .47937 .62471 L .49568 .61432 L p .707 .577 .707 r
F P
0 g
s
.49568 .61432 m .49352 .56047 L .47721 .57086 L p .707 .577 .707 r
F P
0 g
s
.36314 .69807 m .36338 .66085 L .33592 .65654 L p .707 .577 .707 r
F P
0 g
s
.36338 .66085 m .36314 .69807 L .39431 .70005 L p .707 .577 .707 r
F P
0 g
s
.80689 .55673 m .80905 .61058 L .78158 .60571 L p .707 .577 .707 r
F P
0 g
s
.78158 .60571 m .77942 .55186 L .80689 .55673 L p .707 .577 .707 r
F P
0 g
s
.39196 .72339 m .39334 .70428 L .3622 .70143 L p .707 .577 .707 r
F P
0 g
s
.39334 .70428 m .39196 .72339 L .4237 .72536 L p .707 .577 .707 r
F P
0 g
s
.4237 .72536 m .42507 .70626 L .39334 .70428 L p .707 .577 .707 r
F P
0 g
s
.3622 .70143 m .36083 .72054 L .39196 .72339 L p .707 .577 .707 r
F P
0 g
s
.42507 .70626 m .4237 .72536 L .45292 .72628 L p .707 .577 .707 r
F P
0 g
s
.45292 .72628 m .4543 .70717 L .42507 .70626 L p .707 .577 .707 r
F P
0 g
s
.66583 .65687 m .66559 .69408 L .64922 .70093 L p .707 .577 .707 r
F P
0 g
s
.64621 .74111 m .64758 .72201 L .66373 .72064 L p .707 .577 .707 r
F P
0 g
s
.36083 .72054 m .3622 .70143 L .33471 .69799 L p .707 .577 .707 r
F P
0 g
s
.45577 .65929 m .45552 .6965 L .47958 .69132 L p .707 .577 .707 r
F P
0 g
s
.47958 .69132 m .47982 .65411 L .45577 .65929 L p .707 .577 .707 r
F P
0 g
s
.31235 .57281 m .31451 .62666 L .33559 .6345 L p .707 .577 .707 r
F P
0 g
s
.66373 .72064 m .66236 .73974 L .64621 .74111 L p .707 .577 .707 r
F P
0 g
s
.33592 .65654 m .33568 .69376 L .36314 .69807 L p .707 .577 .707 r
F P
0 g
s
.68927 .612 m .68711 .55815 L .71645 .55261 L p .707 .577 .707 r
F P
0 g
s
.68711 .55815 m .68927 .612 L .66527 .62038 L p .707 .577 .707 r
F P
0 g
s
.33471 .69799 m .33333 .71709 L .36083 .72054 L p .707 .577 .707 r
F P
0 g
s
.31451 .62666 m .31235 .57281 L .29972 .56276 L p .707 .577 .707 r
F P
0 g
s
.83079 .66065 m .83054 .69786 L .80949 .69165 L p .707 .577 .707 r
F P
0 g
s
.80949 .69165 m .80973 .65444 L .83079 .66065 L p .707 .577 .707 r
F P
0 g
s
.33568 .69376 m .33592 .65654 L .31486 .65033 L p .707 .577 .707 r
F P
0 g
s
.77942 .55186 m .78158 .60571 L .75041 .60429 L p .707 .577 .707 r
F P
0 g
s
.75041 .60429 m .74826 .55044 L .77942 .55186 L p .707 .577 .707 r
F P
0 g
s
.4543 .70717 m .45292 .72628 L .47678 .72603 L p .707 .577 .707 r
F P
0 g
s
.47678 .72603 m .47815 .70693 L .4543 .70717 L p .707 .577 .707 r
F P
0 g
s
.71861 .60646 m .71645 .55261 L .74826 .55044 L p .707 .577 .707 r
F P
0 g
s
.71645 .55261 m .71861 .60646 L .68927 .612 L p .707 .577 .707 r
F P
0 g
s
.66559 .69408 m .66583 .65687 L .68988 .65169 L p .707 .577 .707 r
F P
0 g
s
.74826 .55044 m .75041 .60429 L .71861 .60646 L p .707 .577 .707 r
F P
0 g
s
.33333 .71709 m .33471 .69799 L .31355 .69429 L p .707 .577 .707 r
F P
0 g
s
.49352 .56047 m .49568 .61432 L .5027 .60293 L p .707 .577 .707 r
F P
0 g
s
.5027 .60293 m .50055 .54908 L .49352 .56047 L p .707 .577 .707 r
F P
0 g
s
.31486 .65033 m .31462 .68754 L .33568 .69376 L p .707 .577 .707 r
F P
0 g
s
.31355 .69429 m .31218 .71339 L .33333 .71709 L p .707 .577 .707 r
F P
0 g
s
.82834 .73328 m .82696 .75238 L .80581 .74868 L p .707 .577 .707 r
F P
0 g
s
.80581 .74868 m .80718 .72958 L .82834 .73328 L p .707 .577 .707 r
F P
0 g
s
.47982 .65411 m .47958 .69132 L .49594 .68448 L p .707 .577 .707 r
F P
0 g
s
.49594 .68448 m .49619 .64726 L .47982 .65411 L p .707 .577 .707 r
F P
0 g
s
.29972 .56276 m .30187 .61661 L .31451 .62666 L p .707 .577 .707 r
F P
0 g
s
.68988 .65169 m .68964 .6889 L .66559 .69408 L p .707 .577 .707 r
F P
0 g
s
.66236 .73974 m .66373 .72064 L .68759 .7204 L p .707 .577 .707 r
F P
0 g
s
.80973 .65444 m .80949 .69165 L .78203 .68734 L p .707 .577 .707 r
F P
0 g
s
.78203 .68734 m .78227 .65013 L .80973 .65444 L p .707 .577 .707 r
F P
0 g
s
.68759 .7204 m .68621 .7395 L .66236 .73974 L p .707 .577 .707 r
F P
0 g
s
.30187 .61661 m .29972 .56276 L .29677 .55149 L p .707 .577 .707 r
F P
0 g
s
.31462 .68754 m .31486 .65033 L .30227 .64282 L p .707 .577 .707 r
F P
0 g
s
.47815 .70693 m .47678 .72603 L .49293 .72466 L p .707 .577 .707 r
F P
0 g
s
.49293 .72466 m .4943 .70556 L .47815 .70693 L p .707 .577 .707 r
F P
0 g
s
.68964 .6889 m .68988 .65169 L .71926 .64868 L p .707 .577 .707 r
F P
0 g
s
.31218 .71339 m .31355 .69429 L .3008 .6907 L p .707 .577 .707 r
F P
0 g
s
.30227 .64282 m .30203 .68003 L .31462 .68754 L p .707 .577 .707 r
F P
0 g
s
.3008 .6907 m .29943 .7098 L .31218 .71339 L p .707 .577 .707 r
F P
0 g
s
.80718 .72958 m .80581 .74868 L .77831 .74524 L p .707 .577 .707 r
F P
0 g
s
.77831 .74524 m .77969 .72614 L .80718 .72958 L p .707 .577 .707 r
F P
0 g
s
.78227 .65013 m .78203 .68734 L .75086 .68536 L p .707 .577 .707 r
F P
0 g
s
.75086 .68536 m .7511 .64814 L .78227 .65013 L p .707 .577 .707 r
F P
0 g
s
.71926 .64868 m .71902 .6859 L .68964 .6889 L p .707 .577 .707 r
F P
0 g
s
.50055 .54908 m .5027 .60293 L .49975 .59166 L p .707 .577 .707 r
F P
0 g
s
.49975 .59166 m .49759 .53781 L .50055 .54908 L p .707 .577 .707 r
F P
0 g
s
.49619 .64726 m .49594 .68448 L .50302 .67663 L p .707 .577 .707 r
F P
0 g
s
.50302 .67663 m .50327 .63942 L .49619 .64726 L p .707 .577 .707 r
F P
0 g
s
.71902 .6859 m .71926 .64868 L .7511 .64814 L p .707 .577 .707 r
F P
0 g
s
.68621 .7395 m .68759 .7204 L .71681 .72131 L p .707 .577 .707 r
F P
0 g
s
.71681 .72131 m .71544 .74041 L .68621 .7395 L p .707 .577 .707 r
F P
0 g
s
.7511 .64814 m .75086 .68536 L .71902 .6859 L p .707 .577 .707 r
F P
0 g
s
.29677 .55149 m .29892 .60534 L .30187 .61661 L p .707 .577 .707 r
F P
0 g
s
.77969 .72614 m .77831 .74524 L .74718 .74239 L p .707 .577 .707 r
F P
0 g
s
.74718 .74239 m .74855 .72329 L .77969 .72614 L p .707 .577 .707 r
F P
0 g
s
.4943 .70556 m .49293 .72466 L .49979 .72229 L p .707 .577 .707 r
F P
0 g
s
.49979 .72229 m .50117 .70319 L .4943 .70556 L p .707 .577 .707 r
F P
0 g
s
.30203 .68003 m .30227 .64282 L .29937 .63474 L p .707 .577 .707 r
F P
0 g
s
.29892 .60534 m .29677 .55149 L .30379 .5401 L p .707 .577 .707 r
F P
0 g
s
.71544 .74041 m .71681 .72131 L .74855 .72329 L p .707 .577 .707 r
F P
0 g
s
.74855 .72329 m .74718 .74239 L .71544 .74041 L p .707 .577 .707 r
F P
0 g
s
.29943 .7098 m .3008 .6907 L .29771 .68756 L p .707 .577 .707 r
F P
0 g
s
.29937 .63474 m .29913 .67196 L .30203 .68003 L p .707 .577 .707 r
F P
0 g
s
.29771 .68756 m .29633 .70667 L .29943 .7098 L p .707 .577 .707 r
F P
0 g
s
.49759 .53781 m .49975 .59166 L .48712 .58161 L p .707 .577 .707 r
F P
0 g
s
.48712 .58161 m .48496 .52776 L .49759 .53781 L p .707 .577 .707 r
F P
0 g
s
.50327 .63942 m .50302 .67663 L .50013 .66856 L p .707 .577 .707 r
F P
0 g
s
.50013 .66856 m .50037 .63135 L .50327 .63942 L p .707 .577 .707 r
F P
0 g
s
.30379 .5401 m .30595 .59395 L .29892 .60534 L p .707 .577 .707 r
F P
0 g
s
.30595 .59395 m .30379 .5401 L .3201 .52971 L p .707 .577 .707 r
F P
0 g
s
.50117 .70319 m .49979 .72229 L .4967 .71916 L p .707 .577 .707 r
F P
0 g
s
.4967 .71916 m .49807 .70005 L .50117 .70319 L p .707 .577 .707 r
F P
0 g
s
.29913 .67196 m .29937 .63474 L .30645 .6269 L p .707 .577 .707 r
F P
0 g
s
.30645 .6269 m .30621 .66411 L .29913 .67196 L p .707 .577 .707 r
F P
0 g
s
.29633 .70667 m .29771 .68756 L .30457 .68519 L p .707 .577 .707 r
F P
0 g
s
.30457 .68519 m .3032 .7043 L .29633 .70667 L p .707 .577 .707 r
F P
0 g
s
.48496 .52776 m .48712 .58161 L .46603 .57377 L p .707 .577 .707 r
F P
0 g
s
.46603 .57377 m .46388 .51992 L .48496 .52776 L p .707 .577 .707 r
F P
0 g
s
.50037 .63135 m .50013 .66856 L .48753 .66105 L p .707 .577 .707 r
F P
0 g
s
.48753 .66105 m .48778 .62384 L .50037 .63135 L p .707 .577 .707 r
F P
0 g
s
.3201 .52971 m .32226 .58356 L .30595 .59395 L p .707 .577 .707 r
F P
0 g
s
.32226 .58356 m .3201 .52971 L .3441 .52133 L p .707 .577 .707 r
F P
0 g
s
.30621 .66411 m .30645 .6269 L .32282 .62005 L p .707 .577 .707 r
F P
0 g
s
.49807 .70005 m .4967 .71916 L .48395 .71557 L p .707 .577 .707 r
F P
0 g
s
.48395 .71557 m .48532 .69646 L .49807 .70005 L p .707 .577 .707 r
F P
0 g
s
.46388 .51992 m .46603 .57377 L .43857 .5689 L p .707 .577 .707 r
F P
0 g
s
.43857 .5689 m .43641 .51505 L .46388 .51992 L p .707 .577 .707 r
F P
0 g
s
.32282 .62005 m .32258 .65727 L .30621 .66411 L p .707 .577 .707 r
F P
0 g
s
.3032 .7043 m .30457 .68519 L .32072 .68382 L p .707 .577 .707 r
F P
0 g
s
.32072 .68382 m .31935 .70292 L .3032 .7043 L p .707 .577 .707 r
F P
0 g
s
.34626 .57519 m .3441 .52133 L .37344 .51579 L p .707 .577 .707 r
F P
0 g
s
.3441 .52133 m .34626 .57519 L .32226 .58356 L p .707 .577 .707 r
F P
0 g
s
.48778 .62384 m .48753 .66105 L .46648 .65483 L p .707 .577 .707 r
F P
0 g
s
.46648 .65483 m .46672 .61762 L .48778 .62384 L p .707 .577 .707 r
F P
0 g
s
.43641 .51505 m .43857 .5689 L .4074 .56748 L p .707 .577 .707 r
F P
0 g
s
.4074 .56748 m .40525 .51362 L .43641 .51505 L p .707 .577 .707 r
F P
0 g
s
.3756 .56964 m .37344 .51579 L .40525 .51362 L p .707 .577 .707 r
F P
0 g
s
.37344 .51579 m .3756 .56964 L .34626 .57519 L p .707 .577 .707 r
F P
0 g
s
.32258 .65727 m .32282 .62005 L .34687 .61487 L p .707 .577 .707 r
F P
0 g
s
.40525 .51362 m .4074 .56748 L .3756 .56964 L p .707 .577 .707 r
F P
0 g
s
.48532 .69646 m .48395 .71557 L .4628 .71187 L p .707 .577 .707 r
F P
0 g
s
.4628 .71187 m .46417 .69276 L .48532 .69646 L p .707 .577 .707 r
F P
0 g
s
.34687 .61487 m .34663 .65209 L .32258 .65727 L p .707 .577 .707 r
F P
0 g
s
.31935 .70292 m .32072 .68382 L .34458 .68358 L p .707 .577 .707 r
F P
0 g
s
.46672 .61762 m .46648 .65483 L .43902 .65052 L p .707 .577 .707 r
F P
0 g
s
.43902 .65052 m .43926 .61331 L .46672 .61762 L p .707 .577 .707 r
F P
0 g
s
.34458 .68358 m .3432 .70268 L .31935 .70292 L p .707 .577 .707 r
F P
0 g
s
.34663 .65209 m .34687 .61487 L .37625 .61187 L p .707 .577 .707 r
F P
0 g
s
.46417 .69276 m .4628 .71187 L .4353 .70842 L p .707 .577 .707 r
F P
0 g
s
.4353 .70842 m .43668 .68932 L .46417 .69276 L p .707 .577 .707 r
F P
0 g
s
.43926 .61331 m .43902 .65052 L .40784 .64854 L p .707 .577 .707 r
F P
0 g
s
.40784 .64854 m .40809 .61133 L .43926 .61331 L p .707 .577 .707 r
F P
0 g
s
.37625 .61187 m .37601 .64908 L .34663 .65209 L p .707 .577 .707 r
F P
0 g
s
.37601 .64908 m .37625 .61187 L .40809 .61133 L p .707 .577 .707 r
F P
0 g
s
.3432 .70268 m .34458 .68358 L .3738 .68449 L p .707 .577 .707 r
F P
0 g
s
.3738 .68449 m .37243 .7036 L .3432 .70268 L p .707 .577 .707 r
F P
0 g
s
.40809 .61133 m .40784 .64854 L .37601 .64908 L p .707 .577 .707 r
F P
0 g
s
.43668 .68932 m .4353 .70842 L .40416 .70557 L p .707 .577 .707 r
F P
0 g
s
.40416 .70557 m .40554 .68647 L .43668 .68932 L p .707 .577 .707 r
F P
0 g
s
.37243 .7036 m .3738 .68449 L .40554 .68647 L p .707 .577 .707 r
F P
0 g
s
.40554 .68647 m .40416 .70557 L .37243 .7036 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo5@00R7oo001jOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001lOol007Aoo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL007Eoo`00L7oo10000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00LWoo001/
Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH3001_Ool006Yoo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eoo`00J7oo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`00Jgoo001VOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001YOol006Eoo`8000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYF001JEP0H0003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Moo`00H7oo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Moo`00GGoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0IGoo001KOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol005Uoo`<000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Egoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IGoo001FOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P006Goo3`00?Woo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH4000fOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
03=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP80031oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@000AJEP07
001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=o
o`0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00B7oo3@0000=JEP00FUH00eYF00<005YF
00000`000goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP<00003FUH0
05YF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool003moo`T000AJEP03001JEUYF00EJEP03001JEP0000AJ
EPL0009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00@0
05YF000000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00>Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000UYF0P000eYF00@005YFFUIJEQT000EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP09001JEUYFFUH005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00<7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00T005YFFUIJEP00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00;goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH70009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00@001Qoo`D000AJEP05001JEUYFFUH0000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05
001JEUYFFUH00005FUH00`00FUH0000>0004FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YF
FUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEUYF0004FUH00`00FUIJEP02FUH4000NOol200001UYF00000000FUH000=JEP8002aoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH60002FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF000010006Woo1P001EYF0`000eYF0P00;7oo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20002FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YF000010001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF20002Goo2@0015YF00<0
05YFFUH015YF00@005YFFUH0009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000=J
EP03001JEUYF00EJEP04001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1@0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@001=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@001Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEP0000<001]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP800003FUH005YF00@0011oo`T0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHH0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02eoo`03001JEP00009JEP8000=JEP03001JEUYF00=JEQ0000AJEP07001JEUYFFUH005YF00000eYF
00@005YFFUIJEPT000IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002eoo`03001JEP00008000EJEP03001JEUYF00EJEQ<000=JEP03001J
EP0000=JEPP00005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH01000
FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH0
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
0P00;goo000]Ool01@00FUH005YF00001EYF00<005YFFUH01P000eYF00<005YFFUH01eYF00@005YF
FUIJEPD00003FUH005YF008000AJEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70002FUH40003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00@0031oo`00;Goo0P000UYF00<005YFFUH00UYF100000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF4P000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo0P000eYF
00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`8000=JEP<000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP09001JEUYFFUH0
05YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`800003FUH00000009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02@00FUIJ
EUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^Ool30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF6P0000=JEP00FUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH0
1UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00=JEPh000Uoo`P000AJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH015YF0`001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000eYF100067oo1P0015YF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHE00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF20000eYF0`005Goo200000IJEP000000
05YF0002FUH2000/Ool002ioo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH0
1@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P0015YF00@005YFFUIJEQ/000AJEP03001JEUYF
00=JEP04001JEP000002FUH2000/Ool002ioo`03001JEP0000=JEPX0009JEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEP00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@002aoo`00;Woo00@0
05YF001JEP8000AJEP04001JEUYFFUHM0006FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;7oo000^Ool00`00FUH0
00020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`00;7oo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000^Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002eo
o`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0002FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUHB00000eYF001JEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJ
EP03001JEUYF00=JEQX0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00000`Ool002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2P00<Woo
000aOol30004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<7oo000_OolL0007FUH00`00FUIJEP05FUH01000FUIJEUYF1@0000Eo
o`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002eoo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0UYF5P001Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0001P000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH60005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01eYF5@001UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF4@0015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJ
EP03001JEUYF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001J
EUYF008002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000=JEP000000;Goo
000]Ool00`00FUH00002FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000040006FUH00`00FUIJEP02FUH20005FUH80004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo000]
Ool50006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YF00000UYF00@005YFFUIJEP8000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP@000AJEP8000AJEP03001JEUYF00AJEP03001JEUYF009JEP8000=oob<002ioo`00<7oo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YF
00000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2001DOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPH0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJ
EP03001JEUYF00<005Eoo`00>goo2@0015YF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF
FUH00eYF1000F7oo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF00000`00G7oo0017Ool5
00000goo0000000D00000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00007
001POol004Moo`D001Qoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH7
001LOol004Qoo`<001Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP05001GOol006Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000007FUH00`00FUIJEP03FUH00`00FUH00002001DOol006Eoo`03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001DOol0
06Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEPL000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001DOol006Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000=JEP03001JEUYF008005Aoo`00J7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP<000MJEP03001JEUYF00=J
EPD00003FUH0000005Aoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0008FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00E7oo001/Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0005Aoo`00Kgoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF8000EGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH700000goo00000003001_Ool007Uoo`/000IJEP03001JEUYF00YJEP04001J
EUYFFUH60008Ool5001_Ool008AooaL000moo`<0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60262 .73816 m .59914 .68566 L .56799 .68452 L p .707 .577 .707 r
F P
0 g
s
.59914 .68566 m .60262 .73816 L .60483 .73796 L p .707 .577 .707 r
F P
0 g
s
.56799 .68452 m .57147 .73703 L .57331 .7371 L p .707 .577 .707 r
F P
0 g
s
.57331 .7371 m .60262 .73816 L p .58714 .71418 L .707 .577 .707 r
F P
0 g
s
.58714 .71418 m .56799 .68452 L .57331 .7371 L .707 .577 .707 r
F
.57147 .73703 m .56799 .68452 L .54051 .67936 L p F P
0 g
s
.54051 .67936 m .54399 .73187 L .54565 .73218 L p .707 .577 .707 r
F P
0 g
s
.54565 .73218 m .57147 .73703 L p .55677 .70966 L .707 .577 .707 r
F P
0 g
s
.55677 .70966 m .54051 .67936 L .54565 .73218 L .707 .577 .707 r
F
.54399 .73187 m .54051 .67936 L .51938 .67069 L p F P
0 g
s
.51938 .67069 m .52286 .72319 L .52426 .72377 L p .707 .577 .707 r
F P
0 g
s
.52426 .72377 m .54399 .73187 L p .531 .69957 L .707 .577 .707 r
F P
0 g
s
.531 .69957 m .51938 .67069 L .52426 .72377 L .707 .577 .707 r
F
.52286 .72319 m .51938 .67069 L .50667 .65934 L p F P
0 g
s
.50667 .65934 m .51016 .71185 L .52286 .72319 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .51069 .70826 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52289 .75284 m .52316 .7277 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52316 .7277 m .52329 .71554 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .52329 .71554 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.54395 .75891 m .5442 .73512 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5442 .73512 m .54435 .72161 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .54435 .72161 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57141 .76317 m .57166 .73984 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57166 .73984 m .5718 .72586 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.60298 .7279 m .5718 .72586 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60258 .7652 m .60283 .74141 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60283 .74141 m .60298 .7279 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60483 .73796 m .63438 .73516 L p .61894 .71348 L .707 .577 .707 r
F P
0 g
s
.61894 .71348 m .59914 .68566 L .60483 .73796 L .707 .577 .707 r
F
.63438 .73516 m .6309 .68266 L .59914 .68566 L p F P
0 g
s
.6309 .68266 m .63438 .73516 L .63696 .73456 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .60298 .7279 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63442 .76481 m .63468 .73967 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63468 .73967 m .63481 .72751 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63696 .73456 m .66365 .72832 L p .6489 .70776 L .707 .577 .707 r
F P
0 g
s
.6489 .70776 m .6309 .68266 L .63696 .73456 L .707 .577 .707 r
F
.66365 .72832 m .66017 .67581 L .6309 .68266 L p F P
0 g
s
.66017 .67581 m .66365 .72832 L .66605 .72732 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .63481 .72751 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66379 .76204 m .66408 .7348 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66408 .7348 m .66419 .72473 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66605 .72732 m .68756 .71831 L p .67398 .69723 L .707 .577 .707 r
F P
0 g
s
.67398 .69723 m .66017 .67581 L .66605 .72732 L .707 .577 .707 r
F
.68756 .71831 m .68408 .6658 L .66017 .67581 L p F P
0 g
s
.60298 .7279 m .60258 .7652 L .63442 .76481 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .63442 .76481 L .66379 .76204 L p .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .57141 .76317 L .60258 .7652 L p .707 .577 .707 r
F P
0 g
s
.57058 .76557 m .56838 .78467 L .59946 .78811 L p .707 .577 .707 r
F P
0 g
s
.59946 .78811 m .60166 .76901 L .57058 .76557 L p .707 .577 .707 r
F P
0 g
s
.60166 .76901 m .59946 .78811 L .63103 .79182 L p .707 .577 .707 r
F P
0 g
s
.63103 .79182 m .63323 .77271 L .60166 .76901 L p .707 .577 .707 r
F P
0 g
s
.68408 .6658 m .68756 .71831 L .70378 .7061 L p .707 .577 .707 r
F P
0 g
s
.70378 .7061 m .7003 .65359 L .68408 .6658 L p .707 .577 .707 r
F P
0 g
s
.63323 .77271 m .63103 .79182 L .66001 .79542 L p .707 .577 .707 r
F P
0 g
s
.66001 .79542 m .66221 .77631 L .63323 .77271 L p .707 .577 .707 r
F P
0 g
s
.54303 .76272 m .54083 .78182 L .56838 .78467 L p .707 .577 .707 r
F P
0 g
s
.56838 .78467 m .57058 .76557 L .54303 .76272 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .66379 .76204 L .68784 .75715 L p .707 .577 .707 r
F P
0 g
s
.68784 .75715 m .68824 .71984 L .66419 .72473 L p .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .54395 .75891 L .57141 .76317 L p .707 .577 .707 r
F P
0 g
s
.66221 .77631 m .66001 .79542 L .68355 .79856 L p .707 .577 .707 r
F P
0 g
s
.68355 .79856 m .68575 .77946 L .66221 .77631 L p .707 .577 .707 r
F P
0 g
s
.52171 .76074 m .51951 .77985 L .54083 .78182 L p .707 .577 .707 r
F P
0 g
s
.54083 .78182 m .54303 .76272 L .52171 .76074 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .52289 .75284 L .54395 .75891 L p .707 .577 .707 r
F P
0 g
s
.7003 .65359 m .70378 .7061 L .71071 .6929 L p .707 .577 .707 r
F P
0 g
s
.71071 .6929 m .70722 .64039 L .7003 .65359 L p .707 .577 .707 r
F P
0 g
s
.68824 .71984 m .68784 .75715 L .70421 .75063 L p .707 .577 .707 r
F P
0 g
s
.70421 .75063 m .7046 .71332 L .68824 .71984 L p .707 .577 .707 r
F P
0 g
s
.68575 .77946 m .68355 .79856 L .69935 .80094 L p .707 .577 .707 r
F P
0 g
s
.69935 .80094 m .70154 .78184 L .68575 .77946 L p .707 .577 .707 r
F P
0 g
s
.51016 .71185 m .50667 .65934 L .50364 .64643 L p .707 .577 .707 r
F P
0 g
s
.50871 .75984 m .50651 .77894 L .51951 .77985 L p .707 .577 .707 r
F P
0 g
s
.51951 .77985 m .52171 .76074 L .50871 .75984 L p .707 .577 .707 r
F P
0 g
s
.51069 .70826 m .5103 .74556 L .52289 .75284 L p .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .4822 .32906 L .43819 .32655 L p .707 .577 .707 r
F P
0 g
s
.50364 .64643 m .50712 .69894 L .51016 .71185 L p .707 .577 .707 r
F P
0 g
s
.5103 .74556 m .51069 .70826 L .50779 .70048 L p .707 .577 .707 r
F P
0 g
s
.50712 .69894 m .50364 .64643 L .51056 .63323 L p .707 .577 .707 r
F P
0 g
s
.5053 .76009 m .5031 .7792 L .50651 .77894 L p .707 .577 .707 r
F P
0 g
s
.50651 .77894 m .50871 .75984 L .5053 .76009 L p .707 .577 .707 r
F P
0 g
s
.50779 .70048 m .5074 .73778 L .5103 .74556 L p .707 .577 .707 r
F P
0 g
s
.51056 .63323 m .51405 .68574 L .50712 .69894 L p .707 .577 .707 r
F P
0 g
s
.5074 .73778 m .50779 .70048 L .51487 .69296 L p .707 .577 .707 r
F P
0 g
s
.51405 .68574 m .51056 .63323 L .52678 .62102 L p .707 .577 .707 r
F P
0 g
s
.51487 .69296 m .51448 .73026 L .5074 .73778 L p .707 .577 .707 r
F P
0 g
s
.51181 .76148 m .50961 .78058 L .5031 .7792 L p .707 .577 .707 r
F P
0 g
s
.5031 .7792 m .5053 .76009 L .51181 .76148 L p .707 .577 .707 r
F P
0 g
s
.52678 .62102 m .53026 .67353 L .51405 .68574 L p .707 .577 .707 r
F P
0 g
s
.51448 .73026 m .51487 .69296 L .53124 .68643 L p .707 .577 .707 r
F P
0 g
s
.53124 .68643 m .53084 .72374 L .51448 .73026 L p .707 .577 .707 r
F P
0 g
s
.52761 .76386 m .52541 .78296 L .50961 .78058 L p .707 .577 .707 r
F P
0 g
s
.50961 .78058 m .51181 .76148 L .52761 .76386 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .52541 .78296 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55115 .767 m .55098 .76853 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55098 .76853 m .54895 .78611 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .52761 .76386 L .55053 .76692 L p .707 .577 .707 r
F P
0 g
s
.55053 .76692 m .55115 .767 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .55053 .76692 L .55064 .76732 L .707 .577 .707 r
F
.52714 .32744 m .4822 .32906 L p .51236 .62831 L F P
0 g
s
.53084 .72374 m .53124 .68643 L .5459 .68345 L p .707 .577 .707 r
F P
0 g
s
.53026 .67353 m .52678 .62102 L .55069 .61101 L p .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .55286 .6438 L p .53026 .67353 L .707 .577 .707 r
F P
0 g
s
.58013 .7706 m .57793 .78971 L .54895 .78611 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .54904 .7853 L p .58013 .7706 L .707 .577 .707 r
F P
0 g
s
.54904 .7853 m .55115 .767 L .55886 .76796 L p .707 .577 .707 r
F P
0 g
s
.55886 .76796 m .58013 .7706 L p .54904 .7853 L .707 .577 .707 r
F P
0 g
s
.58427 .71607 m .58466 .67877 L .6165 .67838 L p .707 .577 .707 r
F P
0 g
s
.6165 .67838 m .6161 .71568 L .58427 .71607 L p .707 .577 .707 r
F P
0 g
s
.6117 .77431 m .6095 .79341 L .58385 .7904 L p .707 .577 .707 r
F P
0 g
s
.58385 .7904 m .57793 .78971 L p .58452 .7867 L .707 .577 .707 r
F P
0 g
s
.58452 .7867 m .6117 .77431 L .58385 .7904 L .707 .577 .707 r
F
.64287 .6023 m .64635 .65481 L .61521 .65367 L p F P
0 g
s
.61521 .65367 m .61172 .60116 L .64287 .6023 L p .707 .577 .707 r
F P
0 g
s
.64767 .68041 m .64727 .71772 L .6161 .71568 L p .707 .577 .707 r
F P
0 g
s
.6161 .71568 m .6165 .67838 L .64767 .68041 L p .707 .577 .707 r
F P
0 g
s
.64278 .77775 m .64058 .79686 L .61294 .79379 L p .707 .577 .707 r
F P
0 g
s
.61294 .79379 m .6095 .79341 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.61308 .79173 m .64278 .77775 L .61294 .79379 L .707 .577 .707 r
F
.6095 .79341 m .6117 .77431 L .61417 .77458 L p F P
0 g
s
.61417 .77458 m .64278 .77775 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.6095 .79341 m .61417 .77458 L .61308 .79173 L .707 .577 .707 r
F
.63566 .28839 m .62567 .30133 L p .63179 .498 L F P
0 g
s
.64078 .78667 m .63698 .4166 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63698 .4166 m .63566 .28839 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .64078 .78667 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62567 .30133 m .62826 .55347 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62826 .55347 m .63079 .79961 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.57793 .78971 m .58013 .7706 L .6117 .77431 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .63079 .79961 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .57996 .60417 L .61172 .60116 L p .707 .577 .707 r
F P
0 g
s
.61172 .60116 m .61521 .65367 L .58344 .65667 L p .707 .577 .707 r
F P
0 g
s
.60257 .31286 m .6062 .66641 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.6062 .66641 m .60768 .81114 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .60768 .81114 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .56292 .60815 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56292 .60815 m .57996 .60417 L p .56891 .62961 L .707 .577 .707 r
F P
0 g
s
.5636 .64181 m .56292 .60815 L .56891 .62961 L .707 .577 .707 r
F
.57188 .64028 m .57294 .7431 L p .57673 .73641 L F P
0 g
s
.58161 .67906 m .58466 .67877 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58187 .67605 m .57188 .64028 L .57673 .73641 L .707 .577 .707 r
F
.58466 .67877 m .58427 .71607 L .57841 .71663 L p F P
0 g
s
.56797 .77749 m .55286 .6438 L .55119 .6533 L .707 .577 .707 r
F
.57373 .82014 m .56867 .77741 L .56797 .77749 L F
.56867 .77741 m .55286 .6438 L .56797 .77749 L F
.57373 .82014 m .55698 .64303 L .55286 .6438 L F
.54902 .66568 m .53026 .67353 L p .55286 .6438 L F P
0 g
s
.55803 .82225 m .57373 .82014 L p .52878 .4874 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .57188 .64028 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .55417 .66352 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.57996 .60417 m .58223 .63836 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.58223 .63836 m .58344 .65667 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55069 .61101 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56862 .32186 m .52714 .32744 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57188 .64028 m .56862 .32186 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57841 .71663 m .55489 .71885 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58124 .68337 m .58466 .67877 L .57841 .71663 L .707 .577 .707 r
F
.59863 .69774 m .5829 .66394 L .59145 .71041 L F
.5829 .66394 m .57188 .64028 L .58187 .67605 L F
.5829 .66394 m .58187 .67605 L .59145 .71041 L F
.59145 .71041 m .58187 .67605 L .57673 .73641 L F
.55489 .71885 m .55528 .68154 L .58161 .67906 L p F P
0 g
s
.55489 .71885 m .58161 .67906 L .58124 .68337 L .707 .577 .707 r
F
.56862 .32186 m .57188 .64028 L p .59863 .69774 L F P
0 g
s
.57294 .7431 m .57373 .82014 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55417 .66352 L .54902 .66568 L p .707 .577 .707 r
F P
0 g
s
.55119 .6533 m .55286 .6438 L .54998 .64433 L .707 .577 .707 r
F
.52714 .32744 m .52878 .4874 L p .54998 .64433 L F P
0 g
s
.55698 .64303 m .52714 .32744 L .54998 .64433 L .707 .577 .707 r
F
.55417 .66352 m .55286 .6438 L p .5636 .64181 L F P
0 g
s
.5459 .68345 m .55528 .68154 L p .54699 .69587 L .707 .577 .707 r
F P
0 g
s
.53084 .72374 m .5459 .68345 L .54699 .69587 L .707 .577 .707 r
F
.55528 .68154 m .55489 .71885 L .53084 .72374 L p F P
0 g
s
.52878 .4874 m .53225 .82572 L .55803 .82225 L p .707 .577 .707 r
F P
0 g
s
.53225 .82572 m .53092 .6957 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.53092 .6957 m .52714 .32744 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .53225 .82572 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.4822 .32906 m .48422 .52615 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48422 .52615 m .48731 .82734 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.7046 .71332 m .70421 .75063 L .71129 .7431 L p .707 .577 .707 r
F P
0 g
s
.71129 .7431 m .71168 .7058 L .7046 .71332 L p .707 .577 .707 r
F P
0 g
s
.70722 .64039 m .71071 .6929 L .70767 .67999 L p .707 .577 .707 r
F P
0 g
s
.70767 .67999 m .70419 .62748 L .70722 .64039 L p .707 .577 .707 r
F P
0 g
s
.4433 .82483 m .43819 .32655 L .39943 .32017 L p .707 .577 .707 r
F P
0 g
s
.43819 .32655 m .4433 .82483 L .48731 .82734 L p .707 .577 .707 r
F P
0 g
s
.70154 .78184 m .69935 .80094 L .70586 .80233 L p .707 .577 .707 r
F P
0 g
s
.70586 .80233 m .70806 .78323 L .70154 .78184 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .60257 .31286 L .56862 .32186 L p .707 .577 .707 r
F P
0 g
s
.40454 .81845 m .39943 .32017 L .3697 .31054 L p .707 .577 .707 r
F P
0 g
s
.39943 .32017 m .40454 .81845 L .4433 .82483 L p .707 .577 .707 r
F P
0 g
s
.70419 .62748 m .70767 .67999 L .69496 .66864 L p .707 .577 .707 r
F P
0 g
s
.69496 .66864 m .69148 .61614 L .70419 .62748 L p .707 .577 .707 r
F P
0 g
s
.71168 .7058 m .71129 .7431 L .70839 .73532 L p .707 .577 .707 r
F P
0 g
s
.70839 .73532 m .70878 .69802 L .71168 .7058 L p .707 .577 .707 r
F P
0 g
s
.70806 .78323 m .70586 .80233 L .70245 .80258 L p .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .62567 .30133 L .60257 .31286 L p .707 .577 .707 r
F P
0 g
s
.70245 .80258 m .70465 .78348 L .70806 .78323 L p .707 .577 .707 r
F P
0 g
s
.25961 .70135 m .25613 .64884 L .22498 .64771 L p .707 .577 .707 r
F P
0 g
s
.25613 .64884 m .25961 .70135 L .26182 .70114 L p .707 .577 .707 r
F P
0 g
s
.22498 .64771 m .22846 .70022 L .2303 .70028 L p .707 .577 .707 r
F P
0 g
s
.2303 .70028 m .25961 .70135 L p .24413 .67737 L .707 .577 .707 r
F P
0 g
s
.24413 .67737 m .22498 .64771 L .2303 .70028 L .707 .577 .707 r
F
.22846 .70022 m .22498 .64771 L .1975 .64255 L p F P
0 g
s
.1975 .64255 m .20098 .69506 L .20264 .69537 L p .707 .577 .707 r
F P
0 g
s
.20264 .69537 m .22846 .70022 L p .21376 .67284 L .707 .577 .707 r
F P
0 g
s
.21376 .67284 m .1975 .64255 L .20264 .69537 L .707 .577 .707 r
F
.20098 .69506 m .1975 .64255 L .17637 .63387 L p F P
0 g
s
.17637 .63387 m .17985 .68638 L .18125 .68695 L p .707 .577 .707 r
F P
0 g
s
.18125 .68695 m .20098 .69506 L p .18799 .66275 L .707 .577 .707 r
F P
0 g
s
.18799 .66275 m .17637 .63387 L .18125 .68695 L .707 .577 .707 r
F
.17985 .68638 m .17637 .63387 L .16367 .62252 L p F P
0 g
s
.16367 .62252 m .16715 .67503 L .17985 .68638 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .16768 .67144 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.17988 .71603 m .18015 .69089 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.18015 .69089 m .18028 .67872 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .18028 .67872 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20094 .7221 m .20119 .6983 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20119 .6983 m .20134 .68479 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .20134 .68479 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.2284 .72635 m .22865 .70303 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.22865 .70303 m .2288 .68905 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .2288 .68905 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25957 .72839 m .25982 .7046 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25982 .7046 m .25997 .69108 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.26182 .70114 m .29137 .69835 L p .27593 .67666 L .707 .577 .707 r
F P
0 g
s
.27593 .67666 m .25613 .64884 L .26182 .70114 L .707 .577 .707 r
F
.29137 .69835 m .28789 .64584 L .25613 .64884 L p F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28789 .64584 m .29137 .69835 L .29395 .69775 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .25997 .69108 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29141 .728 m .29167 .70286 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29167 .70286 m .2918 .69069 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29395 .69775 m .32064 .69151 L p .3059 .67094 L .707 .577 .707 r
F P
0 g
s
.3059 .67094 m .28789 .64584 L .29395 .69775 L .707 .577 .707 r
F
.32064 .69151 m .31716 .639 L .28789 .64584 L p F P
0 g
s
.69148 .61614 m .69496 .66864 L .67384 .65996 L p .707 .577 .707 r
F P
0 g
s
.67384 .65996 m .67035 .60746 L .69148 .61614 L p .707 .577 .707 r
F P
0 g
s
.36828 .70629 m .36867 .66898 L .36159 .6765 L p .707 .577 .707 r
F P
0 g
s
.36159 .6765 m .3612 .71381 L .36828 .70629 L p .707 .577 .707 r
F P
0 g
s
.36867 .66898 m .36828 .70629 L .36608 .70038 L p .707 .577 .707 r
F P
0 g
s
.36631 .69015 m .36867 .66898 L .36608 .70038 L .707 .577 .707 r
F
.34107 .62898 m .34456 .68149 L .36077 .66928 L p F P
0 g
s
.36077 .66928 m .35729 .61678 L .34107 .62898 L p .707 .577 .707 r
F P
0 g
s
.35729 .61678 m .36077 .66928 L .3677 .65608 L p .707 .577 .707 r
F P
0 g
s
.3677 .65608 m .36421 .60357 L .35729 .61678 L p .707 .577 .707 r
F P
0 g
s
.34523 .68303 m .34483 .72033 L .3612 .71381 L p .707 .577 .707 r
F P
0 g
s
.3612 .71381 m .36159 .6765 L .34523 .68303 L p .707 .577 .707 r
F P
0 g
s
.35634 .76413 m .35854 .74503 L .34274 .74264 L p .707 .577 .707 r
F P
0 g
s
.35854 .74503 m .35634 .76413 L .36285 .76551 L p .707 .577 .707 r
F P
0 g
s
.36285 .76551 m .36505 .74641 L .35854 .74503 L p .707 .577 .707 r
F P
0 g
s
.36505 .74641 m .36285 .76551 L .35944 .76577 L p .707 .577 .707 r
F P
0 g
s
.35944 .76577 m .36164 .74666 L .36505 .74641 L p .707 .577 .707 r
F P
0 g
s
.35703 .79688 m .37481 .80882 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.36421 .60357 m .3677 .65608 L .36531 .64596 L p .707 .577 .707 r
F P
0 g
s
.3646 .63775 m .36421 .60357 L .36531 .64596 L .707 .577 .707 r
F
.3669 .66419 m .36335 .62346 L .36534 .73239 L F
.36538 .69851 m .36577 .6612 L .3669 .66424 L p F P
0 g
s
.3669 .66424 m .36867 .66898 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.36538 .69851 m .3669 .66424 L .36631 .69015 L .707 .577 .707 r
F
.34274 .74264 m .34054 .76175 L .35634 .76413 L p F P
0 g
s
.35944 .76577 m .34644 .76486 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.36164 .74666 m .35953 .76496 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35953 .76496 m .35944 .76577 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35529 .69268 m .35278 .69123 L p .35514 .68576 L .707 .577 .707 r
F P
0 g
s
.35532 .69385 m .3548 .63425 L .35442 .65164 L .707 .577 .707 r
F
.35278 .69123 m .35318 .65392 L .35448 .65468 L p F P
0 g
s
.3548 .63437 m .35196 .63183 L p .35517 .61746 L .707 .577 .707 r
F P
0 g
s
.35624 .71984 m .35518 .61702 L p .35532 .69385 L .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .34847 .57932 L .35587 .58593 L p .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .35587 .58593 L .35517 .61746 L .707 .577 .707 r
F
.35518 .61702 m .35192 .2986 L p .3548 .63425 L F P
0 g
s
.35518 .61702 m .3548 .63425 L .35532 .69385 L .707 .577 .707 r
F
.34644 .76486 m .34864 .74576 L .35818 .74642 L p F P
0 g
s
.35818 .74642 m .36164 .74666 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.34644 .76486 m .35818 .74642 L .35847 .75045 L .707 .577 .707 r
F
.35294 .7838 m .35703 .79688 L p .35545 .70899 L F P
0 g
s
.35278 .69123 m .35448 .65468 L .35514 .68576 L .707 .577 .707 r
F
.34847 .57932 m .35196 .63183 L .34562 .62923 L p F P
0 g
s
.34562 .62923 m .33083 .62315 L p .3438 .59092 L .707 .577 .707 r
F P
0 g
s
.3438 .59092 m .34847 .57932 L .34562 .62923 L .707 .577 .707 r
F
.31716 .639 m .32064 .69151 L .32305 .6905 L p F P
0 g
s
.32305 .6905 m .34456 .68149 L p .33097 .66041 L .707 .577 .707 r
F P
0 g
s
.33097 .66041 m .31716 .639 L .32305 .6905 L .707 .577 .707 r
F
.32118 .68792 m .2918 .69069 L p .31554 .71898 L F P
0 g
s
.32079 .72522 m .32107 .69799 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.32107 .69799 m .32118 .68792 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.34456 .68149 m .34107 .62898 L .31716 .639 L p .707 .577 .707 r
F P
0 g
s
.34483 .72033 m .34523 .68303 L .32118 .68792 L p .707 .577 .707 r
F P
0 g
s
.35318 .65392 m .35278 .69123 L .33172 .68516 L p .707 .577 .707 r
F P
0 g
s
.33172 .68516 m .33212 .64785 L .35318 .65392 L p .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35163 .65671 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35163 .65671 m .35294 .7838 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .34782 .28552 L p .35442 .6518 L .707 .577 .707 r
F P
0 g
s
.3548 .63425 m .35192 .2986 L .35442 .6518 L .707 .577 .707 r
F
.35518 .61702 m .35703 .79688 L p .36335 .62346 L F P
0 g
s
.35587 .58593 m .36118 .59067 L p .35526 .61708 L .707 .577 .707 r
F P
0 g
s
.35517 .61746 m .35518 .61702 L .35526 .61708 L .707 .577 .707 r
F
.35518 .61702 m .35587 .58593 L .35526 .61708 L F
.36118 .59067 m .36335 .62346 L p .35526 .61708 L F P
0 g
s
.35417 .51818 m .35518 .61702 L p .36335 .62346 L .707 .577 .707 r
F P
0 g
s
.36118 .59067 m .36421 .60357 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36466 .64318 m .36335 .62346 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36335 .62346 m .36118 .59067 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .35417 .51818 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .35192 .2986 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35781 .27258 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35294 .7838 m .35292 .7827 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35292 .7827 m .34782 .28552 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.36534 .73239 m .36335 .62346 L .35703 .79688 L .707 .577 .707 r
F
.35448 .65468 m .36577 .6612 L p .35514 .68576 L F P
0 g
s
.35572 .71269 m .35532 .69385 L .35545 .70899 L .707 .577 .707 r
F
.35624 .71984 m .35532 .69385 L .35572 .71269 L F
.35545 .70899 m .35532 .69385 L .35442 .6518 L F
.35532 .69385 m .35442 .65164 L .35442 .6518 L F
.36577 .6612 m .36538 .69851 L .35529 .69268 L p F P
0 g
s
.35514 .68576 m .36577 .6612 L .35529 .69268 L .707 .577 .707 r
F
.36466 .64318 m .3548 .63437 L p .35526 .61708 L F P
0 g
s
.35517 .61746 m .35526 .61708 L .3548 .63437 L .707 .577 .707 r
F
.35703 .79688 m .35624 .71984 L p .35545 .70899 L F P
0 g
s
.36982 .69764 m .3669 .66419 L .36534 .73239 L .707 .577 .707 r
F
.36335 .62346 m .36466 .64318 L p .35526 .61708 L F P
0 g
s
.36531 .64596 m .36466 .64318 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36608 .70038 m .36538 .69851 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.37481 .80882 m .37134 .47051 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.37134 .47051 m .3697 .31054 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .37481 .80882 L .40454 .81845 L p .707 .577 .707 r
F P
0 g
s
.70878 .69802 m .70839 .73532 L .69579 .72804 L p .707 .577 .707 r
F P
0 g
s
.69579 .72804 m .69619 .69074 L .70878 .69802 L p .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .25957 .72839 L .29141 .728 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .29141 .728 L .32079 .72522 L p .707 .577 .707 r
F P
0 g
s
.70465 .78348 m .70245 .80258 L .68945 .80168 L p .707 .577 .707 r
F P
0 g
s
.68945 .80168 m .69165 .78257 L .70465 .78348 L p .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .2284 .72635 L .25957 .72839 L p .707 .577 .707 r
F P
0 g
s
.22757 .72875 m .22537 .74785 L .25645 .7513 L p .707 .577 .707 r
F P
0 g
s
.25645 .7513 m .25865 .73219 L .22757 .72875 L p .707 .577 .707 r
F P
0 g
s
.25865 .73219 m .25645 .7513 L .28802 .755 L p .707 .577 .707 r
F P
0 g
s
.28802 .755 m .29022 .7359 L .25865 .73219 L p .707 .577 .707 r
F P
0 g
s
.67035 .60746 m .67384 .65996 L .64635 .65481 L p .707 .577 .707 r
F P
0 g
s
.64635 .65481 m .64287 .6023 L .67035 .60746 L p .707 .577 .707 r
F P
0 g
s
.29022 .7359 m .28802 .755 L .317 .7586 L p .707 .577 .707 r
F P
0 g
s
.317 .7586 m .3192 .7395 L .29022 .7359 L p .707 .577 .707 r
F P
0 g
s
.20002 .7259 m .19782 .745 L .22537 .74785 L p .707 .577 .707 r
F P
0 g
s
.22537 .74785 m .22757 .72875 L .20002 .7259 L p .707 .577 .707 r
F P
0 g
s
.32118 .68792 m .32079 .72522 L .34483 .72033 L p .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .20094 .7221 L .2284 .72635 L p .707 .577 .707 r
F P
0 g
s
.69619 .69074 m .69579 .72804 L .67473 .72198 L p .707 .577 .707 r
F P
0 g
s
.67473 .72198 m .67513 .68467 L .69619 .69074 L p .707 .577 .707 r
F P
0 g
s
.3192 .7395 m .317 .7586 L .34054 .76175 L p .707 .577 .707 r
F P
0 g
s
.34054 .76175 m .34274 .74264 L .3192 .7395 L p .707 .577 .707 r
F P
0 g
s
.1787 .72393 m .1765 .74303 L .19782 .745 L p .707 .577 .707 r
F P
0 g
s
.19782 .745 m .20002 .7259 L .1787 .72393 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .17988 .71603 L .20094 .7221 L p .707 .577 .707 r
F P
0 g
s
.69165 .78257 m .68945 .80168 L .66813 .7997 L p .707 .577 .707 r
F P
0 g
s
.66813 .7997 m .67033 .7806 L .69165 .78257 L p .707 .577 .707 r
F P
0 g
s
.67513 .68467 m .67473 .72198 L .64727 .71772 L p .707 .577 .707 r
F P
0 g
s
.64727 .71772 m .64767 .68041 L .67513 .68467 L p .707 .577 .707 r
F P
0 g
s
.16715 .67503 m .16367 .62252 L .16063 .60962 L p .707 .577 .707 r
F P
0 g
s
.63566 .28839 m .64078 .78667 L .63669 .77359 L p .707 .577 .707 r
F P
0 g
s
.63669 .77359 m .63157 .27531 L .63566 .28839 L p .707 .577 .707 r
F P
0 g
s
.1657 .72302 m .1635 .74213 L .1765 .74303 L p .707 .577 .707 r
F P
0 g
s
.1765 .74303 m .1787 .72393 L .1657 .72302 L p .707 .577 .707 r
F P
0 g
s
.16768 .67144 m .16729 .70875 L .17988 .71603 L p .707 .577 .707 r
F P
0 g
s
.67033 .7806 m .66813 .7997 L .64058 .79686 L p .707 .577 .707 r
F P
0 g
s
.64058 .79686 m .64278 .77775 L .67033 .7806 L p .707 .577 .707 r
F P
0 g
s
.16063 .60962 m .16411 .66212 L .16715 .67503 L p .707 .577 .707 r
F P
0 g
s
.16729 .70875 m .16768 .67144 L .16478 .66366 L p .707 .577 .707 r
F P
0 g
s
.16411 .66212 m .16063 .60962 L .16756 .59641 L p .707 .577 .707 r
F P
0 g
s
.16229 .72328 m .16009 .74238 L .1635 .74213 L p .707 .577 .707 r
F P
0 g
s
.1635 .74213 m .1657 .72302 L .16229 .72328 L p .707 .577 .707 r
F P
0 g
s
.16478 .66366 m .16439 .70097 L .16729 .70875 L p .707 .577 .707 r
F P
0 g
s
.63157 .27531 m .63669 .77359 L .6189 .76165 L p .707 .577 .707 r
F P
0 g
s
.6189 .76165 m .61379 .26337 L .63157 .27531 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16756 .59641 m .17104 .64892 L .16411 .66212 L p .707 .577 .707 r
F P
0 g
s
.16439 .70097 m .16478 .66366 L .17186 .65614 L p .707 .577 .707 r
F P
0 g
s
.17104 .64892 m .16756 .59641 L .18377 .58421 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36293 .77086 m .35781 .27258 L .38092 .26105 L p .707 .577 .707 r
F P
0 g
s
.35781 .27258 m .36293 .77086 L .35294 .7838 L p .707 .577 .707 r
F P
0 g
s
.17186 .65614 m .17147 .69345 L .16439 .70097 L p .707 .577 .707 r
F P
0 g
s
.1688 .72466 m .1666 .74376 L .16009 .74238 L p .707 .577 .707 r
F P
0 g
s
.16009 .74238 m .16229 .72328 L .1688 .72466 L p .707 .577 .707 r
F P
0 g
s
.33083 .62315 m .32735 .57064 L .34847 .57932 L p .707 .577 .707 r
F P
0 g
s
.18377 .58421 m .18725 .63671 L .17104 .64892 L p .707 .577 .707 r
F P
0 g
s
.18725 .63671 m .18377 .58421 L .20768 .57419 L p .707 .577 .707 r
F P
0 g
s
.61379 .26337 m .6189 .76165 L .58918 .75202 L p .707 .577 .707 r
F P
0 g
s
.58918 .75202 m .58406 .25374 L .61379 .26337 L p .707 .577 .707 r
F P
0 g
s
.17147 .69345 m .17186 .65614 L .18823 .64962 L p .707 .577 .707 r
F P
0 g
s
.32735 .57064 m .33083 .62315 L .30335 .61799 L p .707 .577 .707 r
F P
0 g
s
.30335 .61799 m .29986 .56548 L .32735 .57064 L p .707 .577 .707 r
F P
0 g
s
.18823 .64962 m .18783 .68692 L .17147 .69345 L p .707 .577 .707 r
F P
0 g
s
.1846 .72704 m .1824 .74615 L .1666 .74376 L p .707 .577 .707 r
F P
0 g
s
.1666 .74376 m .1688 .72466 L .1846 .72704 L p .707 .577 .707 r
F P
0 g
s
.38092 .26105 m .38603 .75933 L .36293 .77086 L p .707 .577 .707 r
F P
0 g
s
.38603 .75933 m .38092 .26105 L .41487 .25205 L p .707 .577 .707 r
F P
0 g
s
.21116 .6267 m .20768 .57419 L .23695 .56735 L p .707 .577 .707 r
F P
0 g
s
.20768 .57419 m .21116 .6267 L .18725 .63671 L p .707 .577 .707 r
F P
0 g
s
.29986 .56548 m .30335 .61799 L .2722 .61686 L p .707 .577 .707 r
F P
0 g
s
.2722 .61686 m .26871 .56435 L .29986 .56548 L p .707 .577 .707 r
F P
0 g
s
.24043 .61986 m .23695 .56735 L .26871 .56435 L p .707 .577 .707 r
F P
0 g
s
.23695 .56735 m .24043 .61986 L .21116 .6267 L p .707 .577 .707 r
F P
0 g
s
.18783 .68692 m .18823 .64962 L .21228 .64473 L p .707 .577 .707 r
F P
0 g
s
.26871 .56435 m .2722 .61686 L .24043 .61986 L p .707 .577 .707 r
F P
0 g
s
.34864 .74576 m .34644 .76486 L .32512 .76289 L p .707 .577 .707 r
F P
0 g
s
.32512 .76289 m .32732 .74379 L .34864 .74576 L p .707 .577 .707 r
F P
0 g
s
.58406 .25374 m .58918 .75202 L .55041 .74564 L p .707 .577 .707 r
F P
0 g
s
.55041 .74564 m .5453 .24736 L .58406 .25374 L p .707 .577 .707 r
F P
0 g
s
.21228 .64473 m .21188 .68203 L .18783 .68692 L p .707 .577 .707 r
F P
0 g
s
.20814 .73019 m .20594 .74929 L .1824 .74615 L p .707 .577 .707 r
F P
0 g
s
.1824 .74615 m .1846 .72704 L .20814 .73019 L p .707 .577 .707 r
F P
0 g
s
.33212 .64785 m .33172 .68516 L .30426 .6809 L p .707 .577 .707 r
F P
0 g
s
.30426 .6809 m .30466 .6436 L .33212 .64785 L p .707 .577 .707 r
F P
0 g
s
.41998 .75033 m .41487 .25205 L .45635 .24647 L p .707 .577 .707 r
F P
0 g
s
.41487 .25205 m .41998 .75033 L .38603 .75933 L p .707 .577 .707 r
F P
0 g
s
.21188 .68203 m .21228 .64473 L .24165 .64195 L p .707 .577 .707 r
F P
0 g
s
.73982 .68977 m .73634 .63726 L .70519 .63613 L p .707 .577 .707 r
F P
0 g
s
.73634 .63726 m .73982 .68977 L .77159 .68677 L p .707 .577 .707 r
F P
0 g
s
.77159 .68677 m .7681 .63426 L .73634 .63726 L p .707 .577 .707 r
F P
0 g
s
.5453 .24736 m .55041 .74564 L .5064 .74314 L p .707 .577 .707 r
F P
0 g
s
.5064 .74314 m .50129 .24485 L .5453 .24736 L p .707 .577 .707 r
F P
0 g
s
.32732 .74379 m .32512 .76289 L .29757 .76004 L p .707 .577 .707 r
F P
0 g
s
.29757 .76004 m .29977 .74094 L .32732 .74379 L p .707 .577 .707 r
F P
0 g
s
.7681 .63426 m .77159 .68677 L .80086 .67992 L p .707 .577 .707 r
F P
0 g
s
.80086 .67992 m .79737 .62742 L .7681 .63426 L p .707 .577 .707 r
F P
0 g
s
.30466 .6436 m .30426 .6809 L .27309 .67887 L p .707 .577 .707 r
F P
0 g
s
.27309 .67887 m .27349 .64156 L .30466 .6436 L p .707 .577 .707 r
F P
0 g
s
.24165 .64195 m .24126 .67926 L .21188 .68203 L p .707 .577 .707 r
F P
0 g
s
.46146 .74475 m .45635 .24647 L .50129 .24485 L p .707 .577 .707 r
F P
0 g
s
.45635 .24647 m .46146 .74475 L .41998 .75033 L p .707 .577 .707 r
F P
0 g
s
.24126 .67926 m .24165 .64195 L .27349 .64156 L p .707 .577 .707 r
F P
0 g
s
.23712 .73379 m .23492 .75289 L .20594 .74929 L p .707 .577 .707 r
F P
0 g
s
.20594 .74929 m .20814 .73019 L .23712 .73379 L p .707 .577 .707 r
F P
0 g
s
.70867 .68863 m .70519 .63613 L .67771 .63097 L p .707 .577 .707 r
F P
0 g
s
.70519 .63613 m .70867 .68863 L .73982 .68977 L p .707 .577 .707 r
F P
0 g
s
.27349 .64156 m .27309 .67887 L .24126 .67926 L p .707 .577 .707 r
F P
0 g
s
.50129 .24485 m .5064 .74314 L .46146 .74475 L p .707 .577 .707 r
F P
0 g
s
.79737 .62742 m .80086 .67992 L .82477 .66991 L p .707 .577 .707 r
F P
0 g
s
.82477 .66991 m .82129 .6174 L .79737 .62742 L p .707 .577 .707 r
F P
0 g
s
.29977 .74094 m .29757 .76004 L .26649 .7566 L p .707 .577 .707 r
F P
0 g
s
.26649 .7566 m .26869 .73749 L .29977 .74094 L p .707 .577 .707 r
F P
0 g
s
.26869 .73749 m .26649 .7566 L .23492 .75289 L p .707 .577 .707 r
F P
0 g
s
.23492 .75289 m .23712 .73379 L .26869 .73749 L p .707 .577 .707 r
F P
0 g
s
.68119 .68347 m .67771 .63097 L .65658 .62229 L p .707 .577 .707 r
F P
0 g
s
.67771 .63097 m .68119 .68347 L .70867 .68863 L p .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .73886 .74111 L .71576 .73854 L p .707 .577 .707 r
F P
0 g
s
.71576 .73854 m .70778 .73766 L p .72435 .75059 L .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .71576 .73854 L .72435 .75059 L .707 .577 .707 r
F
.70778 .73766 m .70558 .75676 L .73666 .76021 L p F P
0 g
s
.70558 .75676 m .70778 .73766 L .68686 .7355 L p .707 .577 .707 r
F P
0 g
s
.68686 .7355 m .68023 .73481 L p .69196 .74497 L .707 .577 .707 r
F P
0 g
s
.70558 .75676 m .68686 .7355 L .69196 .74497 L .707 .577 .707 r
F
.68023 .73481 m .67803 .75392 L .70558 .75676 L p F P
0 g
s
.67803 .75392 m .68023 .73481 L .66375 .73329 L p .707 .577 .707 r
F P
0 g
s
.66375 .73329 m .65892 .73284 L p .66583 .74046 L .707 .577 .707 r
F P
0 g
s
.67803 .75392 m .66375 .73329 L .66583 .74046 L .707 .577 .707 r
F
.65892 .73284 m .65672 .75194 L .67803 .75392 L p F P
0 g
s
.6601 .73627 m .66026 .72118 L p .6479 .69168 L .707 .577 .707 r
F P
0 g
s
.66026 .72118 m .66049 .69896 L .65251 .69435 L p .707 .577 .707 r
F P
0 g
s
.65251 .69435 m .6479 .69168 L p .66026 .72118 L .707 .577 .707 r
F P
0 g
s
.68116 .74234 m .68134 .72523 L p .66049 .69896 L .707 .577 .707 r
F P
0 g
s
.68134 .72523 m .68155 .70503 L .66844 .70125 L p .707 .577 .707 r
F P
0 g
s
.66844 .70125 m .66049 .69896 L p .68134 .72523 L .707 .577 .707 r
F P
0 g
s
.70861 .74659 m .7088 .72879 L p .68155 .70503 L .707 .577 .707 r
F P
0 g
s
.7088 .72879 m .70901 .70929 L .69315 .70683 L p .707 .577 .707 r
F P
0 g
s
.69315 .70683 m .68155 .70503 L p .7088 .72879 L .707 .577 .707 r
F P
0 g
s
.73886 .74111 m .73666 .76021 L .76394 .76341 L p .707 .577 .707 r
F P
0 g
s
.76394 .76341 m .76824 .76391 L p .75882 .7566 L .707 .577 .707 r
F P
0 g
s
.75882 .7566 m .73886 .74111 L .76394 .76341 L .707 .577 .707 r
F
.76824 .76391 m .77044 .74481 L .73886 .74111 L p F P
0 g
s
.73979 .74863 m .73997 .73152 L p .70901 .70929 L .707 .577 .707 r
F P
0 g
s
.73997 .73152 m .74018 .71132 L .72399 .71027 L p .707 .577 .707 r
F P
0 g
s
.72399 .71027 m .70901 .70929 L p .73997 .73152 L .707 .577 .707 r
F P
0 g
s
.77044 .74481 m .76824 .76391 L .79307 .767 L p .707 .577 .707 r
F P
0 g
s
.79307 .767 m .79721 .76751 L p .78903 .76058 L .707 .577 .707 r
F P
0 g
s
.78903 .76058 m .77044 .74481 L .79307 .767 L .707 .577 .707 r
F
.79721 .76751 m .79941 .74841 L .77044 .74481 L p F P
0 g
s
.77162 .74824 m .77178 .73315 L p .74018 .71132 L .707 .577 .707 r
F P
0 g
s
.77178 .73315 m .77201 .71093 L .75791 .71111 L p .707 .577 .707 r
F P
0 g
s
.75791 .71111 m .74018 .71132 L p .77178 .73315 L .707 .577 .707 r
F P
0 g
s
.74018 .71132 m .73979 .74863 L .77162 .74824 L p .707 .577 .707 r
F P
0 g
s
.82129 .6174 m .82477 .66991 L .84098 .6577 L p .707 .577 .707 r
F P
0 g
s
.84098 .6577 m .8375 .6052 L .82129 .6174 L p .707 .577 .707 r
F P
0 g
s
.77201 .71093 m .77162 .74824 L .801 .74546 L p .707 .577 .707 r
F P
0 g
s
.801 .74546 m .80139 .70816 L .77201 .71093 L p .707 .577 .707 r
F P
0 g
s
.70901 .70929 m .70861 .74659 L .73979 .74863 L p .707 .577 .707 r
F P
0 g
s
.66006 .6748 m .65658 .62229 L .64388 .61094 L p .707 .577 .707 r
F P
0 g
s
.65658 .62229 m .66006 .6748 L .68119 .68347 L p .707 .577 .707 r
F P
0 g
s
.80139 .70816 m .801 .74546 L .82505 .74057 L p .707 .577 .707 r
F P
0 g
s
.82505 .74057 m .82544 .70327 L .80139 .70816 L p .707 .577 .707 r
F P
0 g
s
.68155 .70503 m .68116 .74234 L .70861 .74659 L p .707 .577 .707 r
F P
0 g
s
.79941 .74841 m .79721 .76751 L .82075 .77066 L p .707 .577 .707 r
F P
0 g
s
.82075 .77066 m .82295 .75156 L .79941 .74841 L p .707 .577 .707 r
F P
0 g
s
.8375 .6052 m .84098 .6577 L .84791 .6445 L p .707 .577 .707 r
F P
0 g
s
.84791 .6445 m .84443 .59199 L .8375 .6052 L p .707 .577 .707 r
F P
0 g
s
.66049 .69896 m .6601 .73627 L .68116 .74234 L p .707 .577 .707 r
F P
0 g
s
.82544 .70327 m .82505 .74057 L .84141 .73405 L p .707 .577 .707 r
F P
0 g
s
.84141 .73405 m .84181 .69674 L .82544 .70327 L p .707 .577 .707 r
F P
0 g
s
.64388 .61094 m .64736 .66345 L .66006 .6748 L p .707 .577 .707 r
F P
0 g
s
.64736 .66345 m .64388 .61094 L .64084 .59803 L p .707 .577 .707 r
F P
0 g
s
.82295 .75156 m .82075 .77066 L .83655 .77304 L p .707 .577 .707 r
F P
0 g
s
.83655 .77304 m .83875 .75394 L .82295 .75156 L p .707 .577 .707 r
F P
0 g
s
.64592 .73194 m .64372 .75104 L .65672 .75194 L p .707 .577 .707 r
F P
0 g
s
.65672 .75194 m .65892 .73284 L .64592 .73194 L p .707 .577 .707 r
F P
0 g
s
.84443 .59199 m .84791 .6445 L .84487 .63159 L p .707 .577 .707 r
F P
0 g
s
.84487 .63159 m .84139 .57909 L .84443 .59199 L p .707 .577 .707 r
F P
0 g
s
.6479 .69168 m .6475 .72899 L .6601 .73627 L p .707 .577 .707 r
F P
0 g
s
.84181 .69674 m .84141 .73405 L .84849 .72653 L p .707 .577 .707 r
F P
0 g
s
.84849 .72653 m .84889 .68922 L .84181 .69674 L p .707 .577 .707 r
F P
0 g
s
.64084 .59803 m .64432 .65054 L .64736 .66345 L p .707 .577 .707 r
F P
0 g
s
.83875 .75394 m .83655 .77304 L .84306 .77442 L p .707 .577 .707 r
F P
0 g
s
.84306 .77442 m .84526 .75532 L .83875 .75394 L p .707 .577 .707 r
F P
0 g
s
.64432 .65054 m .64084 .59803 L .64777 .58483 L p .707 .577 .707 r
F P
0 g
s
.6475 .72899 m .6479 .69168 L .645 .6839 L p .707 .577 .707 r
F P
0 g
s
.6425 .73219 m .6403 .75129 L .64372 .75104 L p .707 .577 .707 r
F P
0 g
s
.64372 .75104 m .64592 .73194 L .6425 .73219 L p .707 .577 .707 r
F P
0 g
s
.84139 .57909 m .84487 .63159 L .83217 .62024 L p .707 .577 .707 r
F P
0 g
s
.83217 .62024 m .82869 .56774 L .84139 .57909 L p .707 .577 .707 r
F P
0 g
s
.645 .6839 m .6446 .72121 L .6475 .72899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84889 .68922 m .84849 .72653 L .84559 .71875 L p .707 .577 .707 r
F P
0 g
s
.84559 .71875 m .84599 .68144 L .84889 .68922 L p .707 .577 .707 r
F P
0 g
s
.64777 .58483 m .65125 .63734 L .64432 .65054 L p .707 .577 .707 r
F P
0 g
s
.65125 .63734 m .64777 .58483 L .66398 .57262 L p .707 .577 .707 r
F P
0 g
s
.84526 .75532 m .84306 .77442 L .83965 .77468 L p .707 .577 .707 r
F P
0 g
s
.39681 .65295 m .39333 .60044 L .36218 .59931 L p .707 .577 .707 r
F P
0 g
s
.39333 .60044 m .39681 .65295 L .42858 .64995 L p .707 .577 .707 r
F P
0 g
s
.42858 .64995 m .42509 .59744 L .39333 .60044 L p .707 .577 .707 r
F P
0 g
s
.83965 .77468 m .84185 .75557 L .84526 .75532 L p .707 .577 .707 r
F P
0 g
s
.42509 .59744 m .42858 .64995 L .45785 .64311 L p .707 .577 .707 r
F P
0 g
s
.45785 .64311 m .45436 .5906 L .42509 .59744 L p .707 .577 .707 r
F P
0 g
s
.6446 .72121 m .645 .6839 L .65208 .67638 L p .707 .577 .707 r
F P
0 g
s
.36566 .65182 m .36218 .59931 L .3347 .59415 L p .707 .577 .707 r
F P
0 g
s
.36218 .59931 m .36566 .65182 L .39681 .65295 L p .707 .577 .707 r
F P
0 g
s
.82869 .56774 m .83217 .62024 L .81104 .61157 L p .707 .577 .707 r
F P
0 g
s
.81104 .61157 m .80756 .55906 L .82869 .56774 L p .707 .577 .707 r
F P
0 g
s
.64902 .73357 m .64682 .75268 L .6403 .75129 L p .707 .577 .707 r
F P
0 g
s
.6403 .75129 m .6425 .73219 L .64902 .73357 L p .707 .577 .707 r
F P
0 g
s
.45436 .5906 m .45785 .64311 L .48176 .63309 L p .707 .577 .707 r
F P
0 g
s
.48176 .63309 m .47828 .58059 L .45436 .5906 L p .707 .577 .707 r
F P
0 g
s
.65208 .67638 m .65168 .71369 L .6446 .72121 L p .707 .577 .707 r
F P
0 g
s
.66398 .57262 m .66746 .62513 L .65125 .63734 L p .707 .577 .707 r
F P
0 g
s
.84599 .68144 m .84559 .71875 L .833 .71147 L p .707 .577 .707 r
F P
0 g
s
.833 .71147 m .83339 .67416 L .84599 .68144 L p .707 .577 .707 r
F P
0 g
s
.66746 .62513 m .66398 .57262 L .68789 .56261 L p .707 .577 .707 r
F P
0 g
s
.33818 .64666 m .3347 .59415 L .31357 .58547 L p .707 .577 .707 r
F P
0 g
s
.3347 .59415 m .33818 .64666 L .36566 .65182 L p .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .39585 .70429 L .37275 .70173 L p .707 .577 .707 r
F P
0 g
s
.37275 .70173 m .36477 .70085 L p .38134 .71378 L .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .37275 .70173 L .38134 .71378 L .707 .577 .707 r
F
.36477 .70085 m .36257 .71995 L .39365 .72339 L p F P
0 g
s
.36257 .71995 m .36477 .70085 L .34385 .69868 L p .707 .577 .707 r
F P
0 g
s
.34385 .69868 m .33722 .698 L p .34895 .70815 L .707 .577 .707 r
F P
0 g
s
.36257 .71995 m .34385 .69868 L .34895 .70815 L .707 .577 .707 r
F
.33722 .698 m .33502 .7171 L .36257 .71995 L p F P
0 g
s
.33502 .7171 m .33722 .698 L .32074 .69647 L p .707 .577 .707 r
F P
0 g
s
.32074 .69647 m .31591 .69602 L p .32282 .70364 L .707 .577 .707 r
F P
0 g
s
.33502 .7171 m .32074 .69647 L .32282 .70364 L .707 .577 .707 r
F
.31591 .69602 m .31371 .71513 L .33502 .7171 L p F P
0 g
s
.31709 .69945 m .31725 .68437 L p .30489 .65487 L .707 .577 .707 r
F P
0 g
s
.31725 .68437 m .31748 .66215 L .30949 .65753 L p .707 .577 .707 r
F P
0 g
s
.30949 .65753 m .30489 .65487 L p .31725 .68437 L .707 .577 .707 r
F P
0 g
s
.33815 .70552 m .33833 .68841 L p .31748 .66215 L .707 .577 .707 r
F P
0 g
s
.33833 .68841 m .33854 .66821 L .32542 .66444 L p .707 .577 .707 r
F P
0 g
s
.32542 .66444 m .31748 .66215 L p .33833 .68841 L .707 .577 .707 r
F P
0 g
s
.3656 .70978 m .36579 .69197 L p .33854 .66821 L .707 .577 .707 r
F P
0 g
s
.36579 .69197 m .366 .67247 L .35014 .67001 L p .707 .577 .707 r
F P
0 g
s
.35014 .67001 m .33854 .66821 L p .36579 .69197 L .707 .577 .707 r
F P
0 g
s
.39585 .70429 m .39365 .72339 L .42093 .72659 L p .707 .577 .707 r
F P
0 g
s
.42093 .72659 m .42523 .7271 L p .41581 .71979 L .707 .577 .707 r
F P
0 g
s
.41581 .71979 m .39585 .70429 L .42093 .72659 L .707 .577 .707 r
F
.42523 .7271 m .42743 .70799 L .39585 .70429 L p F P
0 g
s
.39678 .71181 m .39696 .69471 L p .366 .67247 L .707 .577 .707 r
F P
0 g
s
.39696 .69471 m .39717 .67451 L .38098 .67345 L p .707 .577 .707 r
F P
0 g
s
.38098 .67345 m .366 .67247 L p .39696 .69471 L .707 .577 .707 r
F P
0 g
s
.42743 .70799 m .42523 .7271 L .45006 .73018 L p .707 .577 .707 r
F P
0 g
s
.45006 .73018 m .4542 .7307 L p .44602 .72376 L .707 .577 .707 r
F P
0 g
s
.44602 .72376 m .42743 .70799 L .45006 .73018 L .707 .577 .707 r
F
.4542 .7307 m .4564 .71159 L .42743 .70799 L p F P
0 g
s
.42861 .71142 m .42877 .69634 L p .39717 .67451 L .707 .577 .707 r
F P
0 g
s
.42877 .69634 m .429 .67412 L .4149 .67429 L p .707 .577 .707 r
F P
0 g
s
.4149 .67429 m .39717 .67451 L p .42877 .69634 L .707 .577 .707 r
F P
0 g
s
.39717 .67451 m .39678 .71181 L .42861 .71142 L p .707 .577 .707 r
F P
0 g
s
.80756 .55906 m .81104 .61157 L .78356 .60641 L p .707 .577 .707 r
F P
0 g
s
.78356 .60641 m .78008 .5539 L .80756 .55906 L p .707 .577 .707 r
F P
0 g
s
.84185 .75557 m .83965 .77468 L .82665 .77377 L p .707 .577 .707 r
F P
0 g
s
.47828 .58059 m .48176 .63309 L .49797 .62089 L p .707 .577 .707 r
F P
0 g
s
.49797 .62089 m .49449 .56838 L .47828 .58059 L p .707 .577 .707 r
F P
0 g
s
.82665 .77377 m .82885 .75467 L .84185 .75557 L p .707 .577 .707 r
F P
0 g
s
.429 .67412 m .42861 .71142 L .45799 .70865 L p .707 .577 .707 r
F P
0 g
s
.45799 .70865 m .45838 .67134 L .429 .67412 L p .707 .577 .707 r
F P
0 g
s
.65168 .71369 m .65208 .67638 L .66844 .66986 L p .707 .577 .707 r
F P
0 g
s
.366 .67247 m .3656 .70978 L .39678 .71181 L p .707 .577 .707 r
F P
0 g
s
.69138 .61512 m .68789 .56261 L .71717 .55577 L p .707 .577 .707 r
F P
0 g
s
.68789 .56261 m .69138 .61512 L .66746 .62513 L p .707 .577 .707 r
F P
0 g
s
.66482 .73595 m .66262 .75506 L .64682 .75268 L p .707 .577 .707 r
F P
0 g
s
.64682 .75268 m .64902 .73357 L .66482 .73595 L p .707 .577 .707 r
F P
0 g
s
.66844 .66986 m .66805 .70716 L .65168 .71369 L p .707 .577 .707 r
F P
0 g
s
.31705 .63798 m .31357 .58547 L .30087 .57413 L p .707 .577 .707 r
F P
0 g
s
.31357 .58547 m .31705 .63798 L .33818 .64666 L p .707 .577 .707 r
F P
0 g
s
.45838 .67134 m .45799 .70865 L .48204 .70376 L p .707 .577 .707 r
F P
0 g
s
.48204 .70376 m .48243 .66645 L .45838 .67134 L p .707 .577 .707 r
F P
0 g
s
.78008 .5539 m .78356 .60641 L .75241 .60527 L p .707 .577 .707 r
F P
0 g
s
.75241 .60527 m .74893 .55277 L .78008 .5539 L p .707 .577 .707 r
F P
0 g
s
.33854 .66821 m .33815 .70552 L .3656 .70978 L p .707 .577 .707 r
F P
0 g
s
.83339 .67416 m .833 .71147 L .81194 .7054 L p .707 .577 .707 r
F P
0 g
s
.81194 .7054 m .81233 .6681 L .83339 .67416 L p .707 .577 .707 r
F P
0 g
s
.4564 .71159 m .4542 .7307 L .47774 .73384 L p .707 .577 .707 r
F P
0 g
s
.72065 .60827 m .71717 .55577 L .74893 .55277 L p .707 .577 .707 r
F P
0 g
s
.71717 .55577 m .72065 .60827 L .69138 .61512 L p .707 .577 .707 r
F P
0 g
s
.47774 .73384 m .47994 .71474 L .4564 .71159 L p .707 .577 .707 r
F P
0 g
s
.74893 .55277 m .75241 .60527 L .72065 .60827 L p .707 .577 .707 r
F P
0 g
s
.49449 .56838 m .49797 .62089 L .5049 .60768 L p .707 .577 .707 r
F P
0 g
s
.5049 .60768 m .50142 .55518 L .49449 .56838 L p .707 .577 .707 r
F P
0 g
s
.66805 .70716 m .66844 .66986 L .69249 .66497 L p .707 .577 .707 r
F P
0 g
s
.82885 .75467 m .82665 .77377 L .80533 .7718 L p .707 .577 .707 r
F P
0 g
s
.80533 .7718 m .80753 .7527 L .82885 .75467 L p .707 .577 .707 r
F P
0 g
s
.31748 .66215 m .31709 .69945 L .33815 .70552 L p .707 .577 .707 r
F P
0 g
s
.48243 .66645 m .48204 .70376 L .4984 .69723 L p .707 .577 .707 r
F P
0 g
s
.4984 .69723 m .4988 .65993 L .48243 .66645 L p .707 .577 .707 r
F P
0 g
s
.30087 .57413 m .30435 .62663 L .31705 .63798 L p .707 .577 .707 r
F P
0 g
s
.68836 .7391 m .68616 .7582 L .66262 .75506 L p .707 .577 .707 r
F P
0 g
s
.66262 .75506 m .66482 .73595 L .68836 .7391 L p .707 .577 .707 r
F P
0 g
s
.69249 .66497 m .69209 .70227 L .66805 .70716 L p .707 .577 .707 r
F P
0 g
s
.30435 .62663 m .30087 .57413 L .29783 .56122 L p .707 .577 .707 r
F P
0 g
s
.47994 .71474 m .47774 .73384 L .49354 .73622 L p .707 .577 .707 r
F P
0 g
s
.49354 .73622 m .49574 .71712 L .47994 .71474 L p .707 .577 .707 r
F P
0 g
s
.81233 .6681 m .81194 .7054 L .78448 .70114 L p .707 .577 .707 r
F P
0 g
s
.78448 .70114 m .78487 .66384 L .81233 .6681 L p .707 .577 .707 r
F P
0 g
s
.69209 .70227 m .69249 .66497 L .72187 .66219 L p .707 .577 .707 r
F P
0 g
s
.3029 .69512 m .3007 .71422 L .31371 .71513 L p .707 .577 .707 r
F P
0 g
s
.31371 .71513 m .31591 .69602 L .3029 .69512 L p .707 .577 .707 r
F P
0 g
s
.80753 .7527 m .80533 .7718 L .77779 .76895 L p .707 .577 .707 r
F P
0 g
s
.50142 .55518 m .5049 .60768 L .50186 .59478 L p .707 .577 .707 r
F P
0 g
s
.50186 .59478 m .49838 .54227 L .50142 .55518 L p .707 .577 .707 r
F P
0 g
s
.77779 .76895 m .77999 .74985 L .80753 .7527 L p .707 .577 .707 r
F P
0 g
s
.30489 .65487 m .30449 .69217 L .31709 .69945 L p .707 .577 .707 r
F P
0 g
s
.78487 .66384 m .78448 .70114 L .75331 .69911 L p .707 .577 .707 r
F P
0 g
s
.75331 .69911 m .7537 .6618 L .78487 .66384 L p .707 .577 .707 r
F P
0 g
s
.72187 .66219 m .72147 .6995 L .69209 .70227 L p .707 .577 .707 r
F P
0 g
s
.71733 .7427 m .71513 .7618 L .68616 .7582 L p .707 .577 .707 r
F P
0 g
s
.68616 .7582 m .68836 .7391 L .71733 .7427 L p .707 .577 .707 r
F P
0 g
s
.4988 .65993 m .4984 .69723 L .50548 .68971 L p .707 .577 .707 r
F P
0 g
s
.50548 .68971 m .50588 .65241 L .4988 .65993 L p .707 .577 .707 r
F P
0 g
s
.72147 .6995 m .72187 .66219 L .7537 .6618 L p .707 .577 .707 r
F P
0 g
s
.29783 .56122 m .30131 .61373 L .30435 .62663 L p .707 .577 .707 r
F P
0 g
s
.7537 .6618 m .75331 .69911 L .72147 .6995 L p .707 .577 .707 r
F P
0 g
s
.77999 .74985 m .77779 .76895 L .7467 .76551 L p .707 .577 .707 r
F P
0 g
s
.49574 .71712 m .49354 .73622 L .50005 .73761 L p .707 .577 .707 r
F P
0 g
s
.7467 .76551 m .7489 .7464 L .77999 .74985 L p .707 .577 .707 r
F P
0 g
s
.50005 .73761 m .50225 .71851 L .49574 .71712 L p .707 .577 .707 r
F P
0 g
s
.30131 .61373 m .29783 .56122 L .30476 .54802 L p .707 .577 .707 r
F P
0 g
s
.7489 .7464 m .7467 .76551 L .71513 .7618 L p .707 .577 .707 r
F P
0 g
s
.71513 .7618 m .71733 .7427 L .7489 .7464 L p .707 .577 .707 r
F P
0 g
s
.30449 .69217 m .30489 .65487 L .30199 .64709 L p .707 .577 .707 r
F P
0 g
s
.29949 .69537 m .29729 .71448 L .3007 .71422 L p .707 .577 .707 r
F P
0 g
s
.3007 .71422 m .3029 .69512 L .29949 .69537 L p .707 .577 .707 r
F P
0 g
s
.49838 .54227 m .50186 .59478 L .48916 .58343 L p .707 .577 .707 r
F P
0 g
s
.48916 .58343 m .48568 .53092 L .49838 .54227 L p .707 .577 .707 r
F P
0 g
s
.30199 .64709 m .30159 .68439 L .30449 .69217 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50588 .65241 m .50548 .68971 L .50258 .68193 L p .707 .577 .707 r
F P
0 g
s
.50258 .68193 m .50298 .64463 L .50588 .65241 L p .707 .577 .707 r
F P
0 g
s
.30476 .54802 m .30824 .60052 L .30131 .61373 L p .707 .577 .707 r
F P
0 g
s
.30824 .60052 m .30476 .54802 L .32097 .53581 L p .707 .577 .707 r
F P
0 g
s
.50225 .71851 m .50005 .73761 L .49664 .73786 L p .707 .577 .707 r
F P
0 g
s
.49664 .73786 m .49884 .71876 L .50225 .71851 L p .707 .577 .707 r
F P
0 g
s
.30159 .68439 m .30199 .64709 L .30906 .63957 L p .707 .577 .707 r
F P
0 g
s
.48568 .53092 m .48916 .58343 L .46803 .57475 L p .707 .577 .707 r
F P
0 g
s
.46803 .57475 m .46455 .52224 L .48568 .53092 L p .707 .577 .707 r
F P
0 g
s
.30601 .69676 m .30381 .71586 L .29729 .71448 L p .707 .577 .707 r
F P
0 g
s
.29729 .71448 m .29949 .69537 L .30601 .69676 L p .707 .577 .707 r
F P
0 g
s
.30906 .63957 m .30867 .67687 L .30159 .68439 L p .707 .577 .707 r
F P
0 g
s
.32097 .53581 m .32445 .58832 L .30824 .60052 L p .707 .577 .707 r
F P
0 g
s
.50298 .64463 m .50258 .68193 L .48999 .67465 L p .707 .577 .707 r
F P
0 g
s
.48999 .67465 m .49038 .63735 L .50298 .64463 L p .707 .577 .707 r
F P
0 g
s
.32445 .58832 m .32097 .53581 L .34488 .52579 L p .707 .577 .707 r
F P
0 g
s
.46455 .52224 m .46803 .57475 L .44055 .56959 L p .707 .577 .707 r
F P
0 g
s
.44055 .56959 m .43707 .51708 L .46455 .52224 L p .707 .577 .707 r
F P
0 g
s
.49884 .71876 m .49664 .73786 L .48364 .73696 L p .707 .577 .707 r
F P
0 g
s
.48364 .73696 m .48584 .71785 L .49884 .71876 L p .707 .577 .707 r
F P
0 g
s
.30867 .67687 m .30906 .63957 L .32543 .63304 L p .707 .577 .707 r
F P
0 g
s
.34837 .5783 m .34488 .52579 L .37415 .51895 L p .707 .577 .707 r
F P
0 g
s
.34488 .52579 m .34837 .5783 L .32445 .58832 L p .707 .577 .707 r
F P
0 g
s
.32181 .69914 m .31961 .71824 L .30381 .71586 L p .707 .577 .707 r
F P
0 g
s
.30381 .71586 m .30601 .69676 L .32181 .69914 L p .707 .577 .707 r
F P
0 g
s
.32543 .63304 m .32503 .67035 L .30867 .67687 L p .707 .577 .707 r
F P
0 g
s
.43707 .51708 m .44055 .56959 L .4094 .56846 L p .707 .577 .707 r
F P
0 g
s
.4094 .56846 m .40592 .51595 L .43707 .51708 L p .707 .577 .707 r
F P
0 g
s
.49038 .63735 m .48999 .67465 L .46893 .66859 L p .707 .577 .707 r
F P
0 g
s
.46893 .66859 m .46932 .63128 L .49038 .63735 L p .707 .577 .707 r
F P
0 g
s
.37764 .57146 m .37415 .51895 L .40592 .51595 L p .707 .577 .707 r
F P
0 g
s
.37415 .51895 m .37764 .57146 L .34837 .5783 L p .707 .577 .707 r
F P
0 g
s
.40592 .51595 m .4094 .56846 L .37764 .57146 L p .707 .577 .707 r
F P
0 g
s
.32503 .67035 m .32543 .63304 L .34948 .62815 L p .707 .577 .707 r
F P
0 g
s
.48584 .71785 m .48364 .73696 L .46232 .73498 L p .707 .577 .707 r
F P
0 g
s
.46232 .73498 m .46452 .71588 L .48584 .71785 L p .707 .577 .707 r
F P
0 g
s
.34535 .70228 m .34315 .72139 L .31961 .71824 L p .707 .577 .707 r
F P
0 g
s
.31961 .71824 m .32181 .69914 L .34535 .70228 L p .707 .577 .707 r
F P
0 g
s
.34948 .62815 m .34908 .66546 L .32503 .67035 L p .707 .577 .707 r
F P
0 g
s
.46932 .63128 m .46893 .66859 L .44147 .66433 L p .707 .577 .707 r
F P
0 g
s
.44147 .66433 m .44186 .62702 L .46932 .63128 L p .707 .577 .707 r
F P
0 g
s
.34908 .66546 m .34948 .62815 L .37886 .62538 L p .707 .577 .707 r
F P
0 g
s
.46452 .71588 m .46232 .73498 L .43478 .73214 L p .707 .577 .707 r
F P
0 g
s
.43478 .73214 m .43698 .71303 L .46452 .71588 L p .707 .577 .707 r
F P
0 g
s
.44186 .62702 m .44147 .66433 L .4103 .66229 L p .707 .577 .707 r
F P
0 g
s
.4103 .66229 m .41069 .62499 L .44186 .62702 L p .707 .577 .707 r
F P
0 g
s
.37886 .62538 m .37846 .66268 L .34908 .66546 L p .707 .577 .707 r
F P
0 g
s
.37432 .70588 m .37212 .72499 L .34315 .72139 L p .707 .577 .707 r
F P
0 g
s
.34315 .72139 m .34535 .70228 L .37432 .70588 L p .707 .577 .707 r
F P
0 g
s
.37846 .66268 m .37886 .62538 L .41069 .62499 L p .707 .577 .707 r
F P
0 g
s
.41069 .62499 m .4103 .66229 L .37846 .66268 L p .707 .577 .707 r
F P
0 g
s
.43698 .71303 m .43478 .73214 L .40369 .72869 L p .707 .577 .707 r
F P
0 g
s
.40369 .72869 m .40589 .70959 L .43698 .71303 L p .707 .577 .707 r
F P
0 g
s
.40589 .70959 m .40369 .72869 L .37212 .72499 L p .707 .577 .707 r
F P
0 g
s
.37212 .72499 m .37432 .70588 L .40589 .70959 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo3@00R7oo001lOol<0006FUH00`00FUIJEP04FUH9001oOol007Aoo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Uoo`00LGoo0`0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01UYF1000MGoo001^Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001aOol006]oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<006io
o`00JGoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P00KGoo001WOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000
Jgoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000JWoo001TOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Moo`00Hgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001W
Ool0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo
001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0
069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001R
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00HWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001ROol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069oo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000IJEP03
001JEP0000P000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF0000Igoo001SOol01000FUIJEP000UYF1P0015YF00<005YFFUH00UYF2000
0UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH0001WOol006=oo`03001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYF
FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
06Moo`00HGoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001OOol20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005eo
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Moo`00Fgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001IOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06
001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001F
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001EOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000JOol?000nOol005Aoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Aoo`H000AJEP03001JEUYF00IJEP03001J
EP0000<003Yoo`00E7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0047oo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo0018Ool=00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0049oo`H000AJEP03
001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000Qoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP80035oo`00?Woo100000=JEP00FUH01eYF00<005YFFUH01EYF00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF00<005YFFUH01UYF10000UYF00<005YF
FUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
1Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00<7oo000jOol40005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH01UYF00<005YFFUH02EYF1@0015YF
00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Goo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002ioo`00>7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEUYF00=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF009JEP<00004FUH005YFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20004Ool00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000fOol20003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00@005YFFUIJEP800005FUH005YFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000UYF0P000UYF0P0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00@005YFFUH000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH01000FUH000000eYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP@0
0003FUH005YF00=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P001EYF00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;7oo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20002FUH30002FUH01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00UYF100035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002aoo`00;goo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH0
15YF1`001UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00
FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00@0
01Moo`D000EJEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP05001JEUYFFUH0
0005FUH4000POol20003FUH01@00FUIJEUYF0000;7oo000]Ool00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF
00000eYF10008goo0`0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH6000<Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01P00FUIJEUYF
001JEP8000=JEP80021oo`800003FUH005YF008000=JEP8002]oo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00@001=oo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH00`00FUH0
000A0008FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP8000EJEP04001JEP00000LOol2
0003FUH01@00FUIJEUYF00000UYF0P00:goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF1000
5goo00D005YFFUIJEP0000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP0
0003FUH005YF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH4000015YF001JEUYF0`001EYF00D005YFFUIJEP0001Qoo`<000EJEP03001J
EUYF009JEP@002]oo`00;Goo00@005YFFUH000AJEP04001JEUYFFUH2000LOol01000FUIJEP000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH00000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00004FUH0
05YF0003FUH60003FUH00`00Oomoo`0BOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH0
0000:goo000]Ool01000FUIJEP0015YF00@005YF000001moo`H000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH0000000EJEP04001JEUYFFUH9
0009Ool70005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000[Ool002ioo`03001JEP0000AJEP80
021oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00;Woo00<005YF00000UYF
0P000UYF0`001goo4@000Woo100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
0000:goo000^Ool00`00FUH000020005FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH500000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002ioo`06001JEP00FUH0
05YF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;7oo000^Ool20002FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool002ioo`@000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP03001oogoo02]oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF5`001UYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001oo`00009JEP03001JEUYF00=JEP03001JEUYF00EJEQ/000IJEP03
001JEUYF008002ioo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009oo`03001JEP0000EJEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH50002FUH3000`Ool002ioo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP/00003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPX000=JEP03001JEUYF008000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`800003FUH00000008000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080039o
o`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP8000EJEP03001JEUYF00=JEQP000AJEP03001JEUYF00=JEP@0009JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
031oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000^Ool002ioo`03
001JEP0000AJEP03001JEUYF00=JEQ`000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002ioo`03001JEP0000AJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP8000EJEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool002io
o`03001JEP0000=JEP<0009JEP04001JEUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP020003
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20005FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06
001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo00@005YF001JEP80
00EJEP03001JEUYF00EJEP04001JEUYFFUHB0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002]oo`00;Woo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00:goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP0:00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P0015YF
00@005YFFUIJEPL00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01P00FUH00000FUH000=JEP03001JEUYF00=JEPL0011oo`P000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000[Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YF00000`000UYF00@005YFFUIJ
EP8001Moo`H000AJEP04001JEUYFFUH2000[Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF20002EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0002FUH30002FUH00`00FUH0000<
000@Ool50003FUH300000eYF001JEP02FUH2000[Ool0031oo`800003FUH005YF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF009JEP09OomJEUYFFUH005YF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPd000YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP04FUH30003FUH2000[Ool0039oo`<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP05OomJEUYF001JEP040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF3@000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000=JEP000000:goo000eOol300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP09000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002ioo`L000=o
o`D000=JEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo3P0000=oo`0000001P000UYF1@001UYF00<005YFFUH00UYF1P001goo2P00
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000:goo000^Ool00`00FUH00003FUH01000FUIJEUYF7`003Goo00@005YFFUH000EJ
EPX000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00@005YFFUIJEPl001Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3P003Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00EJEQ4000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP06001JEP00FUH005YF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@001Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH01000FUIJEUYF1`00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0035oo`00;Goo
10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEP`0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001J
EUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000fOol0035oo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001J
EUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09FUH<0005FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHF000gOol003Moo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP8000YJEPL000IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00H0035o
o`00?Woo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02EYF0P002UYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF00<005YF00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEQ0002aoo`00Agoo2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF00000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02EYF0P002UYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF00<005YF00001EYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000/Ool0051oo`l000=JEP03001JEP00009JEP04001JEUYFFUH20005FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
000015YF00<005YF00000UYF1`001goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00Ggoo1P000UYF00@005YFFUH000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP8000UJEP04001JEUYFFUH20002FUH00`00
FUH00002000GOol90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001T
Ool00`00FUIJEP040007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0QOol80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo0018Ool3000IOol01000FUIJEP000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P0000=JEP000000:Goo1P000eYF00@005YFFUIJEP8002eoo`00Agoo1@0067oo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01`00:7oo2@00;Goo0017Ool5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000?001HOol004Moo`D001Qo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP09001COol0
04Qoo`<001Uoo`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00Dgoo001TOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH000001UYF00<005YFFUH015YF00@005YFFUIJEP8005=oo`00IGoo00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00=oo`00
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00IGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00IWoo0P000UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001Woo2`00
0UYF0P00E7oo001XOol30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P004goo1000E7oo001ZOol20006FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0
0000KGoo001/Ool20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH4001_Ool006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPH006moo`00LGoo10002EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00000P0000=oo`0000000`00Kgoo001eOol60003
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF2P0017oo1@00Kgoo001kOol90006FUH0
0`00FUIJEP04FUH:000?Ool3001`Ool008Aoo`d008aoo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60262 .73816 m .59914 .68566 L .56799 .68452 L p .707 .577 .707 r
F P
0 g
s
.59914 .68566 m .60262 .73816 L .60483 .73796 L p .707 .577 .707 r
F P
0 g
s
.56799 .68452 m .57147 .73703 L .57331 .7371 L p .707 .577 .707 r
F P
0 g
s
.57331 .7371 m .60262 .73816 L p .58714 .71418 L .707 .577 .707 r
F P
0 g
s
.58714 .71418 m .56799 .68452 L .57331 .7371 L .707 .577 .707 r
F
.57147 .73703 m .56799 .68452 L .54051 .67936 L p F P
0 g
s
.54051 .67936 m .54399 .73187 L .54565 .73218 L p .707 .577 .707 r
F P
0 g
s
.54565 .73218 m .57147 .73703 L p .55677 .70966 L .707 .577 .707 r
F P
0 g
s
.55677 .70966 m .54051 .67936 L .54565 .73218 L .707 .577 .707 r
F
.54399 .73187 m .54051 .67936 L .51938 .67069 L p F P
0 g
s
.51938 .67069 m .52286 .72319 L .52426 .72377 L p .707 .577 .707 r
F P
0 g
s
.52426 .72377 m .54399 .73187 L p .531 .69957 L .707 .577 .707 r
F P
0 g
s
.531 .69957 m .51938 .67069 L .52426 .72377 L .707 .577 .707 r
F
.52286 .72319 m .51938 .67069 L .50667 .65934 L p F P
0 g
s
.50667 .65934 m .51016 .71185 L .52286 .72319 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .51069 .70826 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52289 .75284 m .52316 .7277 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52316 .7277 m .52329 .71554 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .52329 .71554 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.54395 .75891 m .5442 .73512 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5442 .73512 m .54435 .72161 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .54435 .72161 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57141 .76317 m .57166 .73984 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57166 .73984 m .5718 .72586 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.60298 .7279 m .5718 .72586 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60258 .7652 m .60283 .74141 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60283 .74141 m .60298 .7279 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60483 .73796 m .63438 .73516 L p .61894 .71348 L .707 .577 .707 r
F P
0 g
s
.61894 .71348 m .59914 .68566 L .60483 .73796 L .707 .577 .707 r
F
.63438 .73516 m .6309 .68266 L .59914 .68566 L p F P
0 g
s
.6309 .68266 m .63438 .73516 L .63696 .73456 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .60298 .7279 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63442 .76481 m .63468 .73967 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63468 .73967 m .63481 .72751 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63696 .73456 m .66365 .72832 L p .6489 .70776 L .707 .577 .707 r
F P
0 g
s
.6489 .70776 m .6309 .68266 L .63696 .73456 L .707 .577 .707 r
F
.66365 .72832 m .66017 .67581 L .6309 .68266 L p F P
0 g
s
.66017 .67581 m .66365 .72832 L .66605 .72732 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .63481 .72751 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66379 .76204 m .66408 .7348 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66408 .7348 m .66419 .72473 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66605 .72732 m .68756 .71831 L p .67398 .69723 L .707 .577 .707 r
F P
0 g
s
.67398 .69723 m .66017 .67581 L .66605 .72732 L .707 .577 .707 r
F
.68756 .71831 m .68408 .6658 L .66017 .67581 L p F P
0 g
s
.60298 .7279 m .60258 .7652 L .63442 .76481 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .63442 .76481 L .66379 .76204 L p .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .57141 .76317 L .60258 .7652 L p .707 .577 .707 r
F P
0 g
s
.57058 .76557 m .56838 .78467 L .59946 .78811 L p .707 .577 .707 r
F P
0 g
s
.59946 .78811 m .60166 .76901 L .57058 .76557 L p .707 .577 .707 r
F P
0 g
s
.60166 .76901 m .59946 .78811 L .63103 .79182 L p .707 .577 .707 r
F P
0 g
s
.63103 .79182 m .63323 .77271 L .60166 .76901 L p .707 .577 .707 r
F P
0 g
s
.68408 .6658 m .68756 .71831 L .70378 .7061 L p .707 .577 .707 r
F P
0 g
s
.70378 .7061 m .7003 .65359 L .68408 .6658 L p .707 .577 .707 r
F P
0 g
s
.63323 .77271 m .63103 .79182 L .66001 .79542 L p .707 .577 .707 r
F P
0 g
s
.66001 .79542 m .66221 .77631 L .63323 .77271 L p .707 .577 .707 r
F P
0 g
s
.54303 .76272 m .54083 .78182 L .56838 .78467 L p .707 .577 .707 r
F P
0 g
s
.56838 .78467 m .57058 .76557 L .54303 .76272 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .66379 .76204 L .68784 .75715 L p .707 .577 .707 r
F P
0 g
s
.68784 .75715 m .68824 .71984 L .66419 .72473 L p .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .54395 .75891 L .57141 .76317 L p .707 .577 .707 r
F P
0 g
s
.66221 .77631 m .66001 .79542 L .68355 .79856 L p .707 .577 .707 r
F P
0 g
s
.68355 .79856 m .68575 .77946 L .66221 .77631 L p .707 .577 .707 r
F P
0 g
s
.52171 .76074 m .51951 .77985 L .54083 .78182 L p .707 .577 .707 r
F P
0 g
s
.54083 .78182 m .54303 .76272 L .52171 .76074 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .52289 .75284 L .54395 .75891 L p .707 .577 .707 r
F P
0 g
s
.7003 .65359 m .70378 .7061 L .71071 .6929 L p .707 .577 .707 r
F P
0 g
s
.71071 .6929 m .70722 .64039 L .7003 .65359 L p .707 .577 .707 r
F P
0 g
s
.68824 .71984 m .68784 .75715 L .70421 .75063 L p .707 .577 .707 r
F P
0 g
s
.70421 .75063 m .7046 .71332 L .68824 .71984 L p .707 .577 .707 r
F P
0 g
s
.68575 .77946 m .68355 .79856 L .69935 .80094 L p .707 .577 .707 r
F P
0 g
s
.69935 .80094 m .70154 .78184 L .68575 .77946 L p .707 .577 .707 r
F P
0 g
s
.51016 .71185 m .50667 .65934 L .50364 .64643 L p .707 .577 .707 r
F P
0 g
s
.50871 .75984 m .50651 .77894 L .51951 .77985 L p .707 .577 .707 r
F P
0 g
s
.51951 .77985 m .52171 .76074 L .50871 .75984 L p .707 .577 .707 r
F P
0 g
s
.51069 .70826 m .5103 .74556 L .52289 .75284 L p .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .4822 .32906 L .43819 .32655 L p .707 .577 .707 r
F P
0 g
s
.50364 .64643 m .50712 .69894 L .51016 .71185 L p .707 .577 .707 r
F P
0 g
s
.5103 .74556 m .51069 .70826 L .50779 .70048 L p .707 .577 .707 r
F P
0 g
s
.50712 .69894 m .50364 .64643 L .51056 .63323 L p .707 .577 .707 r
F P
0 g
s
.5053 .76009 m .5031 .7792 L .50651 .77894 L p .707 .577 .707 r
F P
0 g
s
.50651 .77894 m .50871 .75984 L .5053 .76009 L p .707 .577 .707 r
F P
0 g
s
.50779 .70048 m .5074 .73778 L .5103 .74556 L p .707 .577 .707 r
F P
0 g
s
.51056 .63323 m .51405 .68574 L .50712 .69894 L p .707 .577 .707 r
F P
0 g
s
.5074 .73778 m .50779 .70048 L .51487 .69296 L p .707 .577 .707 r
F P
0 g
s
.51405 .68574 m .51056 .63323 L .52678 .62102 L p .707 .577 .707 r
F P
0 g
s
.51487 .69296 m .51448 .73026 L .5074 .73778 L p .707 .577 .707 r
F P
0 g
s
.51181 .76148 m .50961 .78058 L .5031 .7792 L p .707 .577 .707 r
F P
0 g
s
.5031 .7792 m .5053 .76009 L .51181 .76148 L p .707 .577 .707 r
F P
0 g
s
.52678 .62102 m .53026 .67353 L .51405 .68574 L p .707 .577 .707 r
F P
0 g
s
.51448 .73026 m .51487 .69296 L .53124 .68643 L p .707 .577 .707 r
F P
0 g
s
.53124 .68643 m .53084 .72374 L .51448 .73026 L p .707 .577 .707 r
F P
0 g
s
.52761 .76386 m .52541 .78296 L .50961 .78058 L p .707 .577 .707 r
F P
0 g
s
.50961 .78058 m .51181 .76148 L .52761 .76386 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .52541 .78296 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55115 .767 m .55098 .76853 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55098 .76853 m .54895 .78611 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .52761 .76386 L .55053 .76692 L p .707 .577 .707 r
F P
0 g
s
.55053 .76692 m .55115 .767 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .55053 .76692 L .55064 .76732 L .707 .577 .707 r
F
.52714 .32744 m .4822 .32906 L p .51236 .62831 L F P
0 g
s
.53084 .72374 m .53124 .68643 L .5459 .68345 L p .707 .577 .707 r
F P
0 g
s
.53026 .67353 m .52678 .62102 L .55069 .61101 L p .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .55286 .6438 L p .53026 .67353 L .707 .577 .707 r
F P
0 g
s
.58013 .7706 m .57793 .78971 L .54895 .78611 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .54904 .7853 L p .58013 .7706 L .707 .577 .707 r
F P
0 g
s
.54904 .7853 m .55115 .767 L .55886 .76796 L p .707 .577 .707 r
F P
0 g
s
.55886 .76796 m .58013 .7706 L p .54904 .7853 L .707 .577 .707 r
F P
0 g
s
.58427 .71607 m .58466 .67877 L .6165 .67838 L p .707 .577 .707 r
F P
0 g
s
.6165 .67838 m .6161 .71568 L .58427 .71607 L p .707 .577 .707 r
F P
0 g
s
.6117 .77431 m .6095 .79341 L .58385 .7904 L p .707 .577 .707 r
F P
0 g
s
.58385 .7904 m .57793 .78971 L p .58452 .7867 L .707 .577 .707 r
F P
0 g
s
.58452 .7867 m .6117 .77431 L .58385 .7904 L .707 .577 .707 r
F
.64287 .6023 m .64635 .65481 L .61521 .65367 L p F P
0 g
s
.61521 .65367 m .61172 .60116 L .64287 .6023 L p .707 .577 .707 r
F P
0 g
s
.64767 .68041 m .64727 .71772 L .6161 .71568 L p .707 .577 .707 r
F P
0 g
s
.6161 .71568 m .6165 .67838 L .64767 .68041 L p .707 .577 .707 r
F P
0 g
s
.64278 .77775 m .64058 .79686 L .61294 .79379 L p .707 .577 .707 r
F P
0 g
s
.61294 .79379 m .6095 .79341 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.61308 .79173 m .64278 .77775 L .61294 .79379 L .707 .577 .707 r
F
.6095 .79341 m .6117 .77431 L .61417 .77458 L p F P
0 g
s
.61417 .77458 m .64278 .77775 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.6095 .79341 m .61417 .77458 L .61308 .79173 L .707 .577 .707 r
F
.63566 .28839 m .62567 .30133 L p .63179 .498 L F P
0 g
s
.64078 .78667 m .63698 .4166 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63698 .4166 m .63566 .28839 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .64078 .78667 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62567 .30133 m .62826 .55347 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62826 .55347 m .63079 .79961 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.57793 .78971 m .58013 .7706 L .6117 .77431 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .63079 .79961 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .57996 .60417 L .61172 .60116 L p .707 .577 .707 r
F P
0 g
s
.61172 .60116 m .61521 .65367 L .58344 .65667 L p .707 .577 .707 r
F P
0 g
s
.60257 .31286 m .6062 .66641 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.6062 .66641 m .60768 .81114 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .60768 .81114 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .56292 .60815 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56292 .60815 m .57996 .60417 L p .56891 .62961 L .707 .577 .707 r
F P
0 g
s
.5636 .64181 m .56292 .60815 L .56891 .62961 L .707 .577 .707 r
F
.57188 .64028 m .57294 .7431 L p .57673 .73641 L F P
0 g
s
.58161 .67906 m .58466 .67877 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58187 .67605 m .57188 .64028 L .57673 .73641 L .707 .577 .707 r
F
.58466 .67877 m .58427 .71607 L .57841 .71663 L p F P
0 g
s
.56797 .77749 m .55286 .6438 L .55119 .6533 L .707 .577 .707 r
F
.57373 .82014 m .56867 .77741 L .56797 .77749 L F
.56867 .77741 m .55286 .6438 L .56797 .77749 L F
.57373 .82014 m .55698 .64303 L .55286 .6438 L F
.54902 .66568 m .53026 .67353 L p .55286 .6438 L F P
0 g
s
.55803 .82225 m .57373 .82014 L p .52878 .4874 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .57188 .64028 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .55417 .66352 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.57996 .60417 m .58223 .63836 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.58223 .63836 m .58344 .65667 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55069 .61101 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56862 .32186 m .52714 .32744 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57188 .64028 m .56862 .32186 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57841 .71663 m .55489 .71885 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58124 .68337 m .58466 .67877 L .57841 .71663 L .707 .577 .707 r
F
.59863 .69774 m .5829 .66394 L .59145 .71041 L F
.5829 .66394 m .57188 .64028 L .58187 .67605 L F
.5829 .66394 m .58187 .67605 L .59145 .71041 L F
.59145 .71041 m .58187 .67605 L .57673 .73641 L F
.55489 .71885 m .55528 .68154 L .58161 .67906 L p F P
0 g
s
.55489 .71885 m .58161 .67906 L .58124 .68337 L .707 .577 .707 r
F
.56862 .32186 m .57188 .64028 L p .59863 .69774 L F P
0 g
s
.57294 .7431 m .57373 .82014 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55417 .66352 L .54902 .66568 L p .707 .577 .707 r
F P
0 g
s
.55119 .6533 m .55286 .6438 L .54998 .64433 L .707 .577 .707 r
F
.52714 .32744 m .52878 .4874 L p .54998 .64433 L F P
0 g
s
.55698 .64303 m .52714 .32744 L .54998 .64433 L .707 .577 .707 r
F
.55417 .66352 m .55286 .6438 L p .5636 .64181 L F P
0 g
s
.5459 .68345 m .55528 .68154 L p .54699 .69587 L .707 .577 .707 r
F P
0 g
s
.53084 .72374 m .5459 .68345 L .54699 .69587 L .707 .577 .707 r
F
.55528 .68154 m .55489 .71885 L .53084 .72374 L p F P
0 g
s
.52878 .4874 m .53225 .82572 L .55803 .82225 L p .707 .577 .707 r
F P
0 g
s
.53225 .82572 m .53092 .6957 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.53092 .6957 m .52714 .32744 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .53225 .82572 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.4822 .32906 m .48422 .52615 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48422 .52615 m .48731 .82734 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.7046 .71332 m .70421 .75063 L .71129 .7431 L p .707 .577 .707 r
F P
0 g
s
.71129 .7431 m .71168 .7058 L .7046 .71332 L p .707 .577 .707 r
F P
0 g
s
.70722 .64039 m .71071 .6929 L .70767 .67999 L p .707 .577 .707 r
F P
0 g
s
.70767 .67999 m .70419 .62748 L .70722 .64039 L p .707 .577 .707 r
F P
0 g
s
.4433 .82483 m .43819 .32655 L .39943 .32017 L p .707 .577 .707 r
F P
0 g
s
.43819 .32655 m .4433 .82483 L .48731 .82734 L p .707 .577 .707 r
F P
0 g
s
.70154 .78184 m .69935 .80094 L .70586 .80233 L p .707 .577 .707 r
F P
0 g
s
.70586 .80233 m .70806 .78323 L .70154 .78184 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .60257 .31286 L .56862 .32186 L p .707 .577 .707 r
F P
0 g
s
.40454 .81845 m .39943 .32017 L .3697 .31054 L p .707 .577 .707 r
F P
0 g
s
.39943 .32017 m .40454 .81845 L .4433 .82483 L p .707 .577 .707 r
F P
0 g
s
.70419 .62748 m .70767 .67999 L .69496 .66864 L p .707 .577 .707 r
F P
0 g
s
.69496 .66864 m .69148 .61614 L .70419 .62748 L p .707 .577 .707 r
F P
0 g
s
.71168 .7058 m .71129 .7431 L .70839 .73532 L p .707 .577 .707 r
F P
0 g
s
.70839 .73532 m .70878 .69802 L .71168 .7058 L p .707 .577 .707 r
F P
0 g
s
.70806 .78323 m .70586 .80233 L .70245 .80258 L p .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .62567 .30133 L .60257 .31286 L p .707 .577 .707 r
F P
0 g
s
.70245 .80258 m .70465 .78348 L .70806 .78323 L p .707 .577 .707 r
F P
0 g
s
.25961 .70135 m .25613 .64884 L .22498 .64771 L p .707 .577 .707 r
F P
0 g
s
.25613 .64884 m .25961 .70135 L .26182 .70114 L p .707 .577 .707 r
F P
0 g
s
.22498 .64771 m .22846 .70022 L .2303 .70028 L p .707 .577 .707 r
F P
0 g
s
.2303 .70028 m .25961 .70135 L p .24413 .67737 L .707 .577 .707 r
F P
0 g
s
.24413 .67737 m .22498 .64771 L .2303 .70028 L .707 .577 .707 r
F
.22846 .70022 m .22498 .64771 L .1975 .64255 L p F P
0 g
s
.1975 .64255 m .20098 .69506 L .20264 .69537 L p .707 .577 .707 r
F P
0 g
s
.20264 .69537 m .22846 .70022 L p .21376 .67284 L .707 .577 .707 r
F P
0 g
s
.21376 .67284 m .1975 .64255 L .20264 .69537 L .707 .577 .707 r
F
.20098 .69506 m .1975 .64255 L .17637 .63387 L p F P
0 g
s
.17637 .63387 m .17985 .68638 L .18125 .68695 L p .707 .577 .707 r
F P
0 g
s
.18125 .68695 m .20098 .69506 L p .18799 .66275 L .707 .577 .707 r
F P
0 g
s
.18799 .66275 m .17637 .63387 L .18125 .68695 L .707 .577 .707 r
F
.17985 .68638 m .17637 .63387 L .16367 .62252 L p F P
0 g
s
.16367 .62252 m .16715 .67503 L .17985 .68638 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .16768 .67144 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.17988 .71603 m .18015 .69089 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.18015 .69089 m .18028 .67872 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .18028 .67872 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20094 .7221 m .20119 .6983 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20119 .6983 m .20134 .68479 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .20134 .68479 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.2284 .72635 m .22865 .70303 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.22865 .70303 m .2288 .68905 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .2288 .68905 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25957 .72839 m .25982 .7046 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25982 .7046 m .25997 .69108 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.26182 .70114 m .29137 .69835 L p .27593 .67666 L .707 .577 .707 r
F P
0 g
s
.27593 .67666 m .25613 .64884 L .26182 .70114 L .707 .577 .707 r
F
.29137 .69835 m .28789 .64584 L .25613 .64884 L p F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28789 .64584 m .29137 .69835 L .29395 .69775 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .25997 .69108 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29141 .728 m .29167 .70286 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29167 .70286 m .2918 .69069 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29395 .69775 m .32064 .69151 L p .3059 .67094 L .707 .577 .707 r
F P
0 g
s
.3059 .67094 m .28789 .64584 L .29395 .69775 L .707 .577 .707 r
F
.32064 .69151 m .31716 .639 L .28789 .64584 L p F P
0 g
s
.69148 .61614 m .69496 .66864 L .67384 .65996 L p .707 .577 .707 r
F P
0 g
s
.67384 .65996 m .67035 .60746 L .69148 .61614 L p .707 .577 .707 r
F P
0 g
s
.36828 .70629 m .36867 .66898 L .36159 .6765 L p .707 .577 .707 r
F P
0 g
s
.36159 .6765 m .3612 .71381 L .36828 .70629 L p .707 .577 .707 r
F P
0 g
s
.36867 .66898 m .36828 .70629 L .36608 .70038 L p .707 .577 .707 r
F P
0 g
s
.36631 .69015 m .36867 .66898 L .36608 .70038 L .707 .577 .707 r
F
.34107 .62898 m .34456 .68149 L .36077 .66928 L p F P
0 g
s
.36077 .66928 m .35729 .61678 L .34107 .62898 L p .707 .577 .707 r
F P
0 g
s
.35729 .61678 m .36077 .66928 L .3677 .65608 L p .707 .577 .707 r
F P
0 g
s
.3677 .65608 m .36421 .60357 L .35729 .61678 L p .707 .577 .707 r
F P
0 g
s
.34523 .68303 m .34483 .72033 L .3612 .71381 L p .707 .577 .707 r
F P
0 g
s
.3612 .71381 m .36159 .6765 L .34523 .68303 L p .707 .577 .707 r
F P
0 g
s
.35634 .76413 m .35854 .74503 L .34274 .74264 L p .707 .577 .707 r
F P
0 g
s
.35854 .74503 m .35634 .76413 L .36285 .76551 L p .707 .577 .707 r
F P
0 g
s
.36285 .76551 m .36505 .74641 L .35854 .74503 L p .707 .577 .707 r
F P
0 g
s
.36505 .74641 m .36285 .76551 L .35944 .76577 L p .707 .577 .707 r
F P
0 g
s
.35944 .76577 m .36164 .74666 L .36505 .74641 L p .707 .577 .707 r
F P
0 g
s
.35703 .79688 m .37481 .80882 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.36421 .60357 m .3677 .65608 L .36531 .64596 L p .707 .577 .707 r
F P
0 g
s
.3646 .63775 m .36421 .60357 L .36531 .64596 L .707 .577 .707 r
F
.3669 .66419 m .36335 .62346 L .36534 .73239 L F
.36538 .69851 m .36577 .6612 L .3669 .66424 L p F P
0 g
s
.3669 .66424 m .36867 .66898 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.36538 .69851 m .3669 .66424 L .36631 .69015 L .707 .577 .707 r
F
.34274 .74264 m .34054 .76175 L .35634 .76413 L p F P
0 g
s
.35944 .76577 m .34644 .76486 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.36164 .74666 m .35953 .76496 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35953 .76496 m .35944 .76577 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35529 .69268 m .35278 .69123 L p .35514 .68576 L .707 .577 .707 r
F P
0 g
s
.35532 .69385 m .3548 .63425 L .35442 .65164 L .707 .577 .707 r
F
.35278 .69123 m .35318 .65392 L .35448 .65468 L p F P
0 g
s
.3548 .63437 m .35196 .63183 L p .35517 .61746 L .707 .577 .707 r
F P
0 g
s
.35624 .71984 m .35518 .61702 L p .35532 .69385 L .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .34847 .57932 L .35587 .58593 L p .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .35587 .58593 L .35517 .61746 L .707 .577 .707 r
F
.35518 .61702 m .35192 .2986 L p .3548 .63425 L F P
0 g
s
.35518 .61702 m .3548 .63425 L .35532 .69385 L .707 .577 .707 r
F
.34644 .76486 m .34864 .74576 L .35818 .74642 L p F P
0 g
s
.35818 .74642 m .36164 .74666 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.34644 .76486 m .35818 .74642 L .35847 .75045 L .707 .577 .707 r
F
.35294 .7838 m .35703 .79688 L p .35545 .70899 L F P
0 g
s
.35278 .69123 m .35448 .65468 L .35514 .68576 L .707 .577 .707 r
F
.34847 .57932 m .35196 .63183 L .34562 .62923 L p F P
0 g
s
.34562 .62923 m .33083 .62315 L p .3438 .59092 L .707 .577 .707 r
F P
0 g
s
.3438 .59092 m .34847 .57932 L .34562 .62923 L .707 .577 .707 r
F
.31716 .639 m .32064 .69151 L .32305 .6905 L p F P
0 g
s
.32305 .6905 m .34456 .68149 L p .33097 .66041 L .707 .577 .707 r
F P
0 g
s
.33097 .66041 m .31716 .639 L .32305 .6905 L .707 .577 .707 r
F
.32118 .68792 m .2918 .69069 L p .31554 .71898 L F P
0 g
s
.32079 .72522 m .32107 .69799 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.32107 .69799 m .32118 .68792 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.34456 .68149 m .34107 .62898 L .31716 .639 L p .707 .577 .707 r
F P
0 g
s
.34483 .72033 m .34523 .68303 L .32118 .68792 L p .707 .577 .707 r
F P
0 g
s
.35318 .65392 m .35278 .69123 L .33172 .68516 L p .707 .577 .707 r
F P
0 g
s
.33172 .68516 m .33212 .64785 L .35318 .65392 L p .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35163 .65671 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35163 .65671 m .35294 .7838 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .34782 .28552 L p .35442 .6518 L .707 .577 .707 r
F P
0 g
s
.3548 .63425 m .35192 .2986 L .35442 .6518 L .707 .577 .707 r
F
.35518 .61702 m .35703 .79688 L p .36335 .62346 L F P
0 g
s
.35587 .58593 m .36118 .59067 L p .35526 .61708 L .707 .577 .707 r
F P
0 g
s
.35517 .61746 m .35518 .61702 L .35526 .61708 L .707 .577 .707 r
F
.35518 .61702 m .35587 .58593 L .35526 .61708 L F
.36118 .59067 m .36335 .62346 L p .35526 .61708 L F P
0 g
s
.35417 .51818 m .35518 .61702 L p .36335 .62346 L .707 .577 .707 r
F P
0 g
s
.36118 .59067 m .36421 .60357 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36466 .64318 m .36335 .62346 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36335 .62346 m .36118 .59067 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .35417 .51818 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .35192 .2986 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35781 .27258 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35294 .7838 m .35292 .7827 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35292 .7827 m .34782 .28552 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.36534 .73239 m .36335 .62346 L .35703 .79688 L .707 .577 .707 r
F
.35448 .65468 m .36577 .6612 L p .35514 .68576 L F P
0 g
s
.35572 .71269 m .35532 .69385 L .35545 .70899 L .707 .577 .707 r
F
.35624 .71984 m .35532 .69385 L .35572 .71269 L F
.35545 .70899 m .35532 .69385 L .35442 .6518 L F
.35532 .69385 m .35442 .65164 L .35442 .6518 L F
.36577 .6612 m .36538 .69851 L .35529 .69268 L p F P
0 g
s
.35514 .68576 m .36577 .6612 L .35529 .69268 L .707 .577 .707 r
F
.36466 .64318 m .3548 .63437 L p .35526 .61708 L F P
0 g
s
.35517 .61746 m .35526 .61708 L .3548 .63437 L .707 .577 .707 r
F
.35703 .79688 m .35624 .71984 L p .35545 .70899 L F P
0 g
s
.36982 .69764 m .3669 .66419 L .36534 .73239 L .707 .577 .707 r
F
.36335 .62346 m .36466 .64318 L p .35526 .61708 L F P
0 g
s
.36531 .64596 m .36466 .64318 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36608 .70038 m .36538 .69851 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.37481 .80882 m .37134 .47051 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.37134 .47051 m .3697 .31054 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .37481 .80882 L .40454 .81845 L p .707 .577 .707 r
F P
0 g
s
.70878 .69802 m .70839 .73532 L .69579 .72804 L p .707 .577 .707 r
F P
0 g
s
.69579 .72804 m .69619 .69074 L .70878 .69802 L p .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .25957 .72839 L .29141 .728 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .29141 .728 L .32079 .72522 L p .707 .577 .707 r
F P
0 g
s
.70465 .78348 m .70245 .80258 L .68945 .80168 L p .707 .577 .707 r
F P
0 g
s
.68945 .80168 m .69165 .78257 L .70465 .78348 L p .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .2284 .72635 L .25957 .72839 L p .707 .577 .707 r
F P
0 g
s
.22757 .72875 m .22537 .74785 L .25645 .7513 L p .707 .577 .707 r
F P
0 g
s
.25645 .7513 m .25865 .73219 L .22757 .72875 L p .707 .577 .707 r
F P
0 g
s
.25865 .73219 m .25645 .7513 L .28802 .755 L p .707 .577 .707 r
F P
0 g
s
.28802 .755 m .29022 .7359 L .25865 .73219 L p .707 .577 .707 r
F P
0 g
s
.67035 .60746 m .67384 .65996 L .64635 .65481 L p .707 .577 .707 r
F P
0 g
s
.64635 .65481 m .64287 .6023 L .67035 .60746 L p .707 .577 .707 r
F P
0 g
s
.29022 .7359 m .28802 .755 L .317 .7586 L p .707 .577 .707 r
F P
0 g
s
.317 .7586 m .3192 .7395 L .29022 .7359 L p .707 .577 .707 r
F P
0 g
s
.20002 .7259 m .19782 .745 L .22537 .74785 L p .707 .577 .707 r
F P
0 g
s
.22537 .74785 m .22757 .72875 L .20002 .7259 L p .707 .577 .707 r
F P
0 g
s
.32118 .68792 m .32079 .72522 L .34483 .72033 L p .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .20094 .7221 L .2284 .72635 L p .707 .577 .707 r
F P
0 g
s
.69619 .69074 m .69579 .72804 L .67473 .72198 L p .707 .577 .707 r
F P
0 g
s
.67473 .72198 m .67513 .68467 L .69619 .69074 L p .707 .577 .707 r
F P
0 g
s
.3192 .7395 m .317 .7586 L .34054 .76175 L p .707 .577 .707 r
F P
0 g
s
.34054 .76175 m .34274 .74264 L .3192 .7395 L p .707 .577 .707 r
F P
0 g
s
.1787 .72393 m .1765 .74303 L .19782 .745 L p .707 .577 .707 r
F P
0 g
s
.19782 .745 m .20002 .7259 L .1787 .72393 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .17988 .71603 L .20094 .7221 L p .707 .577 .707 r
F P
0 g
s
.69165 .78257 m .68945 .80168 L .66813 .7997 L p .707 .577 .707 r
F P
0 g
s
.66813 .7997 m .67033 .7806 L .69165 .78257 L p .707 .577 .707 r
F P
0 g
s
.67513 .68467 m .67473 .72198 L .64727 .71772 L p .707 .577 .707 r
F P
0 g
s
.64727 .71772 m .64767 .68041 L .67513 .68467 L p .707 .577 .707 r
F P
0 g
s
.16715 .67503 m .16367 .62252 L .16063 .60962 L p .707 .577 .707 r
F P
0 g
s
.63566 .28839 m .64078 .78667 L .63669 .77359 L p .707 .577 .707 r
F P
0 g
s
.63669 .77359 m .63157 .27531 L .63566 .28839 L p .707 .577 .707 r
F P
0 g
s
.1657 .72302 m .1635 .74213 L .1765 .74303 L p .707 .577 .707 r
F P
0 g
s
.1765 .74303 m .1787 .72393 L .1657 .72302 L p .707 .577 .707 r
F P
0 g
s
.16768 .67144 m .16729 .70875 L .17988 .71603 L p .707 .577 .707 r
F P
0 g
s
.67033 .7806 m .66813 .7997 L .64058 .79686 L p .707 .577 .707 r
F P
0 g
s
.64058 .79686 m .64278 .77775 L .67033 .7806 L p .707 .577 .707 r
F P
0 g
s
.16063 .60962 m .16411 .66212 L .16715 .67503 L p .707 .577 .707 r
F P
0 g
s
.16729 .70875 m .16768 .67144 L .16478 .66366 L p .707 .577 .707 r
F P
0 g
s
.16411 .66212 m .16063 .60962 L .16756 .59641 L p .707 .577 .707 r
F P
0 g
s
.16229 .72328 m .16009 .74238 L .1635 .74213 L p .707 .577 .707 r
F P
0 g
s
.1635 .74213 m .1657 .72302 L .16229 .72328 L p .707 .577 .707 r
F P
0 g
s
.16478 .66366 m .16439 .70097 L .16729 .70875 L p .707 .577 .707 r
F P
0 g
s
.63157 .27531 m .63669 .77359 L .6189 .76165 L p .707 .577 .707 r
F P
0 g
s
.6189 .76165 m .61379 .26337 L .63157 .27531 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16756 .59641 m .17104 .64892 L .16411 .66212 L p .707 .577 .707 r
F P
0 g
s
.16439 .70097 m .16478 .66366 L .17186 .65614 L p .707 .577 .707 r
F P
0 g
s
.17104 .64892 m .16756 .59641 L .18377 .58421 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36293 .77086 m .35781 .27258 L .38092 .26105 L p .707 .577 .707 r
F P
0 g
s
.35781 .27258 m .36293 .77086 L .35294 .7838 L p .707 .577 .707 r
F P
0 g
s
.17186 .65614 m .17147 .69345 L .16439 .70097 L p .707 .577 .707 r
F P
0 g
s
.1688 .72466 m .1666 .74376 L .16009 .74238 L p .707 .577 .707 r
F P
0 g
s
.16009 .74238 m .16229 .72328 L .1688 .72466 L p .707 .577 .707 r
F P
0 g
s
.33083 .62315 m .32735 .57064 L .34847 .57932 L p .707 .577 .707 r
F P
0 g
s
.18377 .58421 m .18725 .63671 L .17104 .64892 L p .707 .577 .707 r
F P
0 g
s
.18725 .63671 m .18377 .58421 L .20768 .57419 L p .707 .577 .707 r
F P
0 g
s
.61379 .26337 m .6189 .76165 L .58918 .75202 L p .707 .577 .707 r
F P
0 g
s
.58918 .75202 m .58406 .25374 L .61379 .26337 L p .707 .577 .707 r
F P
0 g
s
.17147 .69345 m .17186 .65614 L .18823 .64962 L p .707 .577 .707 r
F P
0 g
s
.32735 .57064 m .33083 .62315 L .30335 .61799 L p .707 .577 .707 r
F P
0 g
s
.30335 .61799 m .29986 .56548 L .32735 .57064 L p .707 .577 .707 r
F P
0 g
s
.18823 .64962 m .18783 .68692 L .17147 .69345 L p .707 .577 .707 r
F P
0 g
s
.1846 .72704 m .1824 .74615 L .1666 .74376 L p .707 .577 .707 r
F P
0 g
s
.1666 .74376 m .1688 .72466 L .1846 .72704 L p .707 .577 .707 r
F P
0 g
s
.38092 .26105 m .38603 .75933 L .36293 .77086 L p .707 .577 .707 r
F P
0 g
s
.38603 .75933 m .38092 .26105 L .41487 .25205 L p .707 .577 .707 r
F P
0 g
s
.21116 .6267 m .20768 .57419 L .23695 .56735 L p .707 .577 .707 r
F P
0 g
s
.20768 .57419 m .21116 .6267 L .18725 .63671 L p .707 .577 .707 r
F P
0 g
s
.29986 .56548 m .30335 .61799 L .2722 .61686 L p .707 .577 .707 r
F P
0 g
s
.2722 .61686 m .26871 .56435 L .29986 .56548 L p .707 .577 .707 r
F P
0 g
s
.24043 .61986 m .23695 .56735 L .26871 .56435 L p .707 .577 .707 r
F P
0 g
s
.23695 .56735 m .24043 .61986 L .21116 .6267 L p .707 .577 .707 r
F P
0 g
s
.18783 .68692 m .18823 .64962 L .21228 .64473 L p .707 .577 .707 r
F P
0 g
s
.26871 .56435 m .2722 .61686 L .24043 .61986 L p .707 .577 .707 r
F P
0 g
s
.34864 .74576 m .34644 .76486 L .32512 .76289 L p .707 .577 .707 r
F P
0 g
s
.32512 .76289 m .32732 .74379 L .34864 .74576 L p .707 .577 .707 r
F P
0 g
s
.58406 .25374 m .58918 .75202 L .55041 .74564 L p .707 .577 .707 r
F P
0 g
s
.55041 .74564 m .5453 .24736 L .58406 .25374 L p .707 .577 .707 r
F P
0 g
s
.21228 .64473 m .21188 .68203 L .18783 .68692 L p .707 .577 .707 r
F P
0 g
s
.20814 .73019 m .20594 .74929 L .1824 .74615 L p .707 .577 .707 r
F P
0 g
s
.1824 .74615 m .1846 .72704 L .20814 .73019 L p .707 .577 .707 r
F P
0 g
s
.33212 .64785 m .33172 .68516 L .30426 .6809 L p .707 .577 .707 r
F P
0 g
s
.30426 .6809 m .30466 .6436 L .33212 .64785 L p .707 .577 .707 r
F P
0 g
s
.41998 .75033 m .41487 .25205 L .45635 .24647 L p .707 .577 .707 r
F P
0 g
s
.41487 .25205 m .41998 .75033 L .38603 .75933 L p .707 .577 .707 r
F P
0 g
s
.21188 .68203 m .21228 .64473 L .24165 .64195 L p .707 .577 .707 r
F P
0 g
s
.73982 .68977 m .73634 .63726 L .70519 .63613 L p .707 .577 .707 r
F P
0 g
s
.73634 .63726 m .73982 .68977 L .77159 .68677 L p .707 .577 .707 r
F P
0 g
s
.77159 .68677 m .7681 .63426 L .73634 .63726 L p .707 .577 .707 r
F P
0 g
s
.5453 .24736 m .55041 .74564 L .5064 .74314 L p .707 .577 .707 r
F P
0 g
s
.5064 .74314 m .50129 .24485 L .5453 .24736 L p .707 .577 .707 r
F P
0 g
s
.32732 .74379 m .32512 .76289 L .29757 .76004 L p .707 .577 .707 r
F P
0 g
s
.29757 .76004 m .29977 .74094 L .32732 .74379 L p .707 .577 .707 r
F P
0 g
s
.7681 .63426 m .77159 .68677 L .80086 .67992 L p .707 .577 .707 r
F P
0 g
s
.80086 .67992 m .79737 .62742 L .7681 .63426 L p .707 .577 .707 r
F P
0 g
s
.30466 .6436 m .30426 .6809 L .27309 .67887 L p .707 .577 .707 r
F P
0 g
s
.27309 .67887 m .27349 .64156 L .30466 .6436 L p .707 .577 .707 r
F P
0 g
s
.24165 .64195 m .24126 .67926 L .21188 .68203 L p .707 .577 .707 r
F P
0 g
s
.46146 .74475 m .45635 .24647 L .50129 .24485 L p .707 .577 .707 r
F P
0 g
s
.45635 .24647 m .46146 .74475 L .41998 .75033 L p .707 .577 .707 r
F P
0 g
s
.24126 .67926 m .24165 .64195 L .27349 .64156 L p .707 .577 .707 r
F P
0 g
s
.23712 .73379 m .23492 .75289 L .20594 .74929 L p .707 .577 .707 r
F P
0 g
s
.20594 .74929 m .20814 .73019 L .23712 .73379 L p .707 .577 .707 r
F P
0 g
s
.70867 .68863 m .70519 .63613 L .67771 .63097 L p .707 .577 .707 r
F P
0 g
s
.70519 .63613 m .70867 .68863 L .73982 .68977 L p .707 .577 .707 r
F P
0 g
s
.27349 .64156 m .27309 .67887 L .24126 .67926 L p .707 .577 .707 r
F P
0 g
s
.50129 .24485 m .5064 .74314 L .46146 .74475 L p .707 .577 .707 r
F P
0 g
s
.79737 .62742 m .80086 .67992 L .82477 .66991 L p .707 .577 .707 r
F P
0 g
s
.82477 .66991 m .82129 .6174 L .79737 .62742 L p .707 .577 .707 r
F P
0 g
s
.29977 .74094 m .29757 .76004 L .26649 .7566 L p .707 .577 .707 r
F P
0 g
s
.26649 .7566 m .26869 .73749 L .29977 .74094 L p .707 .577 .707 r
F P
0 g
s
.26869 .73749 m .26649 .7566 L .23492 .75289 L p .707 .577 .707 r
F P
0 g
s
.23492 .75289 m .23712 .73379 L .26869 .73749 L p .707 .577 .707 r
F P
0 g
s
.68119 .68347 m .67771 .63097 L .65658 .62229 L p .707 .577 .707 r
F P
0 g
s
.67771 .63097 m .68119 .68347 L .70867 .68863 L p .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .73886 .74111 L .71576 .73854 L p .707 .577 .707 r
F P
0 g
s
.71576 .73854 m .70778 .73766 L p .72435 .75059 L .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .71576 .73854 L .72435 .75059 L .707 .577 .707 r
F
.70778 .73766 m .70558 .75676 L .73666 .76021 L p F P
0 g
s
.70558 .75676 m .70778 .73766 L .68686 .7355 L p .707 .577 .707 r
F P
0 g
s
.68686 .7355 m .68023 .73481 L p .69196 .74497 L .707 .577 .707 r
F P
0 g
s
.70558 .75676 m .68686 .7355 L .69196 .74497 L .707 .577 .707 r
F
.68023 .73481 m .67803 .75392 L .70558 .75676 L p F P
0 g
s
.67803 .75392 m .68023 .73481 L .66375 .73329 L p .707 .577 .707 r
F P
0 g
s
.66375 .73329 m .65892 .73284 L p .66583 .74046 L .707 .577 .707 r
F P
0 g
s
.67803 .75392 m .66375 .73329 L .66583 .74046 L .707 .577 .707 r
F
.65892 .73284 m .65672 .75194 L .67803 .75392 L p F P
0 g
s
.6601 .73627 m .66026 .72118 L p .6479 .69168 L .707 .577 .707 r
F P
0 g
s
.66026 .72118 m .66049 .69896 L .65251 .69435 L p .707 .577 .707 r
F P
0 g
s
.65251 .69435 m .6479 .69168 L p .66026 .72118 L .707 .577 .707 r
F P
0 g
s
.68116 .74234 m .68134 .72523 L p .66049 .69896 L .707 .577 .707 r
F P
0 g
s
.68134 .72523 m .68155 .70503 L .66844 .70125 L p .707 .577 .707 r
F P
0 g
s
.66844 .70125 m .66049 .69896 L p .68134 .72523 L .707 .577 .707 r
F P
0 g
s
.70861 .74659 m .7088 .72879 L p .68155 .70503 L .707 .577 .707 r
F P
0 g
s
.7088 .72879 m .70901 .70929 L .69315 .70683 L p .707 .577 .707 r
F P
0 g
s
.69315 .70683 m .68155 .70503 L p .7088 .72879 L .707 .577 .707 r
F P
0 g
s
.73886 .74111 m .73666 .76021 L .76394 .76341 L p .707 .577 .707 r
F P
0 g
s
.76394 .76341 m .76824 .76391 L p .75882 .7566 L .707 .577 .707 r
F P
0 g
s
.75882 .7566 m .73886 .74111 L .76394 .76341 L .707 .577 .707 r
F
.76824 .76391 m .77044 .74481 L .73886 .74111 L p F P
0 g
s
.73979 .74863 m .73997 .73152 L p .70901 .70929 L .707 .577 .707 r
F P
0 g
s
.73997 .73152 m .74018 .71132 L .72399 .71027 L p .707 .577 .707 r
F P
0 g
s
.72399 .71027 m .70901 .70929 L p .73997 .73152 L .707 .577 .707 r
F P
0 g
s
.77044 .74481 m .76824 .76391 L .79307 .767 L p .707 .577 .707 r
F P
0 g
s
.79307 .767 m .79721 .76751 L p .78903 .76058 L .707 .577 .707 r
F P
0 g
s
.78903 .76058 m .77044 .74481 L .79307 .767 L .707 .577 .707 r
F
.79721 .76751 m .79941 .74841 L .77044 .74481 L p F P
0 g
s
.77162 .74824 m .77178 .73315 L p .74018 .71132 L .707 .577 .707 r
F P
0 g
s
.77178 .73315 m .77201 .71093 L .75791 .71111 L p .707 .577 .707 r
F P
0 g
s
.75791 .71111 m .74018 .71132 L p .77178 .73315 L .707 .577 .707 r
F P
0 g
s
.74018 .71132 m .73979 .74863 L .77162 .74824 L p .707 .577 .707 r
F P
0 g
s
.82129 .6174 m .82477 .66991 L .84098 .6577 L p .707 .577 .707 r
F P
0 g
s
.84098 .6577 m .8375 .6052 L .82129 .6174 L p .707 .577 .707 r
F P
0 g
s
.77201 .71093 m .77162 .74824 L .801 .74546 L p .707 .577 .707 r
F P
0 g
s
.801 .74546 m .80139 .70816 L .77201 .71093 L p .707 .577 .707 r
F P
0 g
s
.70901 .70929 m .70861 .74659 L .73979 .74863 L p .707 .577 .707 r
F P
0 g
s
.66006 .6748 m .65658 .62229 L .64388 .61094 L p .707 .577 .707 r
F P
0 g
s
.65658 .62229 m .66006 .6748 L .68119 .68347 L p .707 .577 .707 r
F P
0 g
s
.80139 .70816 m .801 .74546 L .82505 .74057 L p .707 .577 .707 r
F P
0 g
s
.82505 .74057 m .82544 .70327 L .80139 .70816 L p .707 .577 .707 r
F P
0 g
s
.68155 .70503 m .68116 .74234 L .70861 .74659 L p .707 .577 .707 r
F P
0 g
s
.79941 .74841 m .79721 .76751 L .82075 .77066 L p .707 .577 .707 r
F P
0 g
s
.82075 .77066 m .82295 .75156 L .79941 .74841 L p .707 .577 .707 r
F P
0 g
s
.8375 .6052 m .84098 .6577 L .84791 .6445 L p .707 .577 .707 r
F P
0 g
s
.84791 .6445 m .84443 .59199 L .8375 .6052 L p .707 .577 .707 r
F P
0 g
s
.66049 .69896 m .6601 .73627 L .68116 .74234 L p .707 .577 .707 r
F P
0 g
s
.82544 .70327 m .82505 .74057 L .84141 .73405 L p .707 .577 .707 r
F P
0 g
s
.84141 .73405 m .84181 .69674 L .82544 .70327 L p .707 .577 .707 r
F P
0 g
s
.64388 .61094 m .64736 .66345 L .66006 .6748 L p .707 .577 .707 r
F P
0 g
s
.64736 .66345 m .64388 .61094 L .64084 .59803 L p .707 .577 .707 r
F P
0 g
s
.82295 .75156 m .82075 .77066 L .83655 .77304 L p .707 .577 .707 r
F P
0 g
s
.83655 .77304 m .83875 .75394 L .82295 .75156 L p .707 .577 .707 r
F P
0 g
s
.64592 .73194 m .64372 .75104 L .65672 .75194 L p .707 .577 .707 r
F P
0 g
s
.65672 .75194 m .65892 .73284 L .64592 .73194 L p .707 .577 .707 r
F P
0 g
s
.84443 .59199 m .84791 .6445 L .84487 .63159 L p .707 .577 .707 r
F P
0 g
s
.84487 .63159 m .84139 .57909 L .84443 .59199 L p .707 .577 .707 r
F P
0 g
s
.6479 .69168 m .6475 .72899 L .6601 .73627 L p .707 .577 .707 r
F P
0 g
s
.84181 .69674 m .84141 .73405 L .84849 .72653 L p .707 .577 .707 r
F P
0 g
s
.84849 .72653 m .84889 .68922 L .84181 .69674 L p .707 .577 .707 r
F P
0 g
s
.64084 .59803 m .64432 .65054 L .64736 .66345 L p .707 .577 .707 r
F P
0 g
s
.83875 .75394 m .83655 .77304 L .84306 .77442 L p .707 .577 .707 r
F P
0 g
s
.84306 .77442 m .84526 .75532 L .83875 .75394 L p .707 .577 .707 r
F P
0 g
s
.64432 .65054 m .64084 .59803 L .64777 .58483 L p .707 .577 .707 r
F P
0 g
s
.6475 .72899 m .6479 .69168 L .645 .6839 L p .707 .577 .707 r
F P
0 g
s
.6425 .73219 m .6403 .75129 L .64372 .75104 L p .707 .577 .707 r
F P
0 g
s
.64372 .75104 m .64592 .73194 L .6425 .73219 L p .707 .577 .707 r
F P
0 g
s
.84139 .57909 m .84487 .63159 L .83217 .62024 L p .707 .577 .707 r
F P
0 g
s
.83217 .62024 m .82869 .56774 L .84139 .57909 L p .707 .577 .707 r
F P
0 g
s
.645 .6839 m .6446 .72121 L .6475 .72899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84889 .68922 m .84849 .72653 L .84559 .71875 L p .707 .577 .707 r
F P
0 g
s
.84559 .71875 m .84599 .68144 L .84889 .68922 L p .707 .577 .707 r
F P
0 g
s
.64777 .58483 m .65125 .63734 L .64432 .65054 L p .707 .577 .707 r
F P
0 g
s
.65125 .63734 m .64777 .58483 L .66398 .57262 L p .707 .577 .707 r
F P
0 g
s
.84526 .75532 m .84306 .77442 L .83965 .77468 L p .707 .577 .707 r
F P
0 g
s
.39681 .65295 m .39333 .60044 L .36218 .59931 L p .707 .577 .707 r
F P
0 g
s
.39333 .60044 m .39681 .65295 L .42858 .64995 L p .707 .577 .707 r
F P
0 g
s
.42858 .64995 m .42509 .59744 L .39333 .60044 L p .707 .577 .707 r
F P
0 g
s
.83965 .77468 m .84185 .75557 L .84526 .75532 L p .707 .577 .707 r
F P
0 g
s
.42509 .59744 m .42858 .64995 L .45785 .64311 L p .707 .577 .707 r
F P
0 g
s
.45785 .64311 m .45436 .5906 L .42509 .59744 L p .707 .577 .707 r
F P
0 g
s
.6446 .72121 m .645 .6839 L .65208 .67638 L p .707 .577 .707 r
F P
0 g
s
.36566 .65182 m .36218 .59931 L .3347 .59415 L p .707 .577 .707 r
F P
0 g
s
.36218 .59931 m .36566 .65182 L .39681 .65295 L p .707 .577 .707 r
F P
0 g
s
.82869 .56774 m .83217 .62024 L .81104 .61157 L p .707 .577 .707 r
F P
0 g
s
.81104 .61157 m .80756 .55906 L .82869 .56774 L p .707 .577 .707 r
F P
0 g
s
.64902 .73357 m .64682 .75268 L .6403 .75129 L p .707 .577 .707 r
F P
0 g
s
.6403 .75129 m .6425 .73219 L .64902 .73357 L p .707 .577 .707 r
F P
0 g
s
.45436 .5906 m .45785 .64311 L .48176 .63309 L p .707 .577 .707 r
F P
0 g
s
.48176 .63309 m .47828 .58059 L .45436 .5906 L p .707 .577 .707 r
F P
0 g
s
.65208 .67638 m .65168 .71369 L .6446 .72121 L p .707 .577 .707 r
F P
0 g
s
.66398 .57262 m .66746 .62513 L .65125 .63734 L p .707 .577 .707 r
F P
0 g
s
.84599 .68144 m .84559 .71875 L .833 .71147 L p .707 .577 .707 r
F P
0 g
s
.833 .71147 m .83339 .67416 L .84599 .68144 L p .707 .577 .707 r
F P
0 g
s
.66746 .62513 m .66398 .57262 L .68789 .56261 L p .707 .577 .707 r
F P
0 g
s
.33818 .64666 m .3347 .59415 L .31357 .58547 L p .707 .577 .707 r
F P
0 g
s
.3347 .59415 m .33818 .64666 L .36566 .65182 L p .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .39585 .70429 L .37275 .70173 L p .707 .577 .707 r
F P
0 g
s
.37275 .70173 m .36477 .70085 L p .38134 .71378 L .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .37275 .70173 L .38134 .71378 L .707 .577 .707 r
F
.36477 .70085 m .36257 .71995 L .39365 .72339 L p F P
0 g
s
.36257 .71995 m .36477 .70085 L .34385 .69868 L p .707 .577 .707 r
F P
0 g
s
.34385 .69868 m .33722 .698 L p .34895 .70815 L .707 .577 .707 r
F P
0 g
s
.36257 .71995 m .34385 .69868 L .34895 .70815 L .707 .577 .707 r
F
.33722 .698 m .33502 .7171 L .36257 .71995 L p F P
0 g
s
.33502 .7171 m .33722 .698 L .32074 .69647 L p .707 .577 .707 r
F P
0 g
s
.32074 .69647 m .31591 .69602 L p .32282 .70364 L .707 .577 .707 r
F P
0 g
s
.33502 .7171 m .32074 .69647 L .32282 .70364 L .707 .577 .707 r
F
.31591 .69602 m .31371 .71513 L .33502 .7171 L p F P
0 g
s
.31709 .69945 m .31725 .68437 L p .30489 .65487 L .707 .577 .707 r
F P
0 g
s
.31725 .68437 m .31748 .66215 L .30949 .65753 L p .707 .577 .707 r
F P
0 g
s
.30949 .65753 m .30489 .65487 L p .31725 .68437 L .707 .577 .707 r
F P
0 g
s
.33815 .70552 m .33833 .68841 L p .31748 .66215 L .707 .577 .707 r
F P
0 g
s
.33833 .68841 m .33854 .66821 L .32542 .66444 L p .707 .577 .707 r
F P
0 g
s
.32542 .66444 m .31748 .66215 L p .33833 .68841 L .707 .577 .707 r
F P
0 g
s
.3656 .70978 m .36579 .69197 L p .33854 .66821 L .707 .577 .707 r
F P
0 g
s
.36579 .69197 m .366 .67247 L .35014 .67001 L p .707 .577 .707 r
F P
0 g
s
.35014 .67001 m .33854 .66821 L p .36579 .69197 L .707 .577 .707 r
F P
0 g
s
.39585 .70429 m .39365 .72339 L .42093 .72659 L p .707 .577 .707 r
F P
0 g
s
.42093 .72659 m .42523 .7271 L p .41581 .71979 L .707 .577 .707 r
F P
0 g
s
.41581 .71979 m .39585 .70429 L .42093 .72659 L .707 .577 .707 r
F
.42523 .7271 m .42743 .70799 L .39585 .70429 L p F P
0 g
s
.39678 .71181 m .39696 .69471 L p .366 .67247 L .707 .577 .707 r
F P
0 g
s
.39696 .69471 m .39717 .67451 L .38098 .67345 L p .707 .577 .707 r
F P
0 g
s
.38098 .67345 m .366 .67247 L p .39696 .69471 L .707 .577 .707 r
F P
0 g
s
.42743 .70799 m .42523 .7271 L .45006 .73018 L p .707 .577 .707 r
F P
0 g
s
.45006 .73018 m .4542 .7307 L p .44602 .72376 L .707 .577 .707 r
F P
0 g
s
.44602 .72376 m .42743 .70799 L .45006 .73018 L .707 .577 .707 r
F
.4542 .7307 m .4564 .71159 L .42743 .70799 L p F P
0 g
s
.42861 .71142 m .42877 .69634 L p .39717 .67451 L .707 .577 .707 r
F P
0 g
s
.42877 .69634 m .429 .67412 L .4149 .67429 L p .707 .577 .707 r
F P
0 g
s
.4149 .67429 m .39717 .67451 L p .42877 .69634 L .707 .577 .707 r
F P
0 g
s
.39717 .67451 m .39678 .71181 L .42861 .71142 L p .707 .577 .707 r
F P
0 g
s
.80756 .55906 m .81104 .61157 L .78356 .60641 L p .707 .577 .707 r
F P
0 g
s
.78356 .60641 m .78008 .5539 L .80756 .55906 L p .707 .577 .707 r
F P
0 g
s
.84185 .75557 m .83965 .77468 L .82665 .77377 L p .707 .577 .707 r
F P
0 g
s
.47828 .58059 m .48176 .63309 L .49797 .62089 L p .707 .577 .707 r
F P
0 g
s
.49797 .62089 m .49449 .56838 L .47828 .58059 L p .707 .577 .707 r
F P
0 g
s
.82665 .77377 m .82885 .75467 L .84185 .75557 L p .707 .577 .707 r
F P
0 g
s
.429 .67412 m .42861 .71142 L .45799 .70865 L p .707 .577 .707 r
F P
0 g
s
.45799 .70865 m .45838 .67134 L .429 .67412 L p .707 .577 .707 r
F P
0 g
s
.65168 .71369 m .65208 .67638 L .66844 .66986 L p .707 .577 .707 r
F P
0 g
s
.366 .67247 m .3656 .70978 L .39678 .71181 L p .707 .577 .707 r
F P
0 g
s
.69138 .61512 m .68789 .56261 L .71717 .55577 L p .707 .577 .707 r
F P
0 g
s
.68789 .56261 m .69138 .61512 L .66746 .62513 L p .707 .577 .707 r
F P
0 g
s
.66482 .73595 m .66262 .75506 L .64682 .75268 L p .707 .577 .707 r
F P
0 g
s
.64682 .75268 m .64902 .73357 L .66482 .73595 L p .707 .577 .707 r
F P
0 g
s
.66844 .66986 m .66805 .70716 L .65168 .71369 L p .707 .577 .707 r
F P
0 g
s
.31705 .63798 m .31357 .58547 L .30087 .57413 L p .707 .577 .707 r
F P
0 g
s
.31357 .58547 m .31705 .63798 L .33818 .64666 L p .707 .577 .707 r
F P
0 g
s
.45838 .67134 m .45799 .70865 L .48204 .70376 L p .707 .577 .707 r
F P
0 g
s
.48204 .70376 m .48243 .66645 L .45838 .67134 L p .707 .577 .707 r
F P
0 g
s
.78008 .5539 m .78356 .60641 L .75241 .60527 L p .707 .577 .707 r
F P
0 g
s
.75241 .60527 m .74893 .55277 L .78008 .5539 L p .707 .577 .707 r
F P
0 g
s
.33854 .66821 m .33815 .70552 L .3656 .70978 L p .707 .577 .707 r
F P
0 g
s
.83339 .67416 m .833 .71147 L .81194 .7054 L p .707 .577 .707 r
F P
0 g
s
.81194 .7054 m .81233 .6681 L .83339 .67416 L p .707 .577 .707 r
F P
0 g
s
.4564 .71159 m .4542 .7307 L .47774 .73384 L p .707 .577 .707 r
F P
0 g
s
.72065 .60827 m .71717 .55577 L .74893 .55277 L p .707 .577 .707 r
F P
0 g
s
.71717 .55577 m .72065 .60827 L .69138 .61512 L p .707 .577 .707 r
F P
0 g
s
.47774 .73384 m .47994 .71474 L .4564 .71159 L p .707 .577 .707 r
F P
0 g
s
.74893 .55277 m .75241 .60527 L .72065 .60827 L p .707 .577 .707 r
F P
0 g
s
.49449 .56838 m .49797 .62089 L .5049 .60768 L p .707 .577 .707 r
F P
0 g
s
.5049 .60768 m .50142 .55518 L .49449 .56838 L p .707 .577 .707 r
F P
0 g
s
.66805 .70716 m .66844 .66986 L .69249 .66497 L p .707 .577 .707 r
F P
0 g
s
.82885 .75467 m .82665 .77377 L .80533 .7718 L p .707 .577 .707 r
F P
0 g
s
.80533 .7718 m .80753 .7527 L .82885 .75467 L p .707 .577 .707 r
F P
0 g
s
.31748 .66215 m .31709 .69945 L .33815 .70552 L p .707 .577 .707 r
F P
0 g
s
.48243 .66645 m .48204 .70376 L .4984 .69723 L p .707 .577 .707 r
F P
0 g
s
.4984 .69723 m .4988 .65993 L .48243 .66645 L p .707 .577 .707 r
F P
0 g
s
.30087 .57413 m .30435 .62663 L .31705 .63798 L p .707 .577 .707 r
F P
0 g
s
.68836 .7391 m .68616 .7582 L .66262 .75506 L p .707 .577 .707 r
F P
0 g
s
.66262 .75506 m .66482 .73595 L .68836 .7391 L p .707 .577 .707 r
F P
0 g
s
.69249 .66497 m .69209 .70227 L .66805 .70716 L p .707 .577 .707 r
F P
0 g
s
.30435 .62663 m .30087 .57413 L .29783 .56122 L p .707 .577 .707 r
F P
0 g
s
.47994 .71474 m .47774 .73384 L .49354 .73622 L p .707 .577 .707 r
F P
0 g
s
.49354 .73622 m .49574 .71712 L .47994 .71474 L p .707 .577 .707 r
F P
0 g
s
.81233 .6681 m .81194 .7054 L .78448 .70114 L p .707 .577 .707 r
F P
0 g
s
.78448 .70114 m .78487 .66384 L .81233 .6681 L p .707 .577 .707 r
F P
0 g
s
.69209 .70227 m .69249 .66497 L .72187 .66219 L p .707 .577 .707 r
F P
0 g
s
.3029 .69512 m .3007 .71422 L .31371 .71513 L p .707 .577 .707 r
F P
0 g
s
.31371 .71513 m .31591 .69602 L .3029 .69512 L p .707 .577 .707 r
F P
0 g
s
.80753 .7527 m .80533 .7718 L .77779 .76895 L p .707 .577 .707 r
F P
0 g
s
.50142 .55518 m .5049 .60768 L .50186 .59478 L p .707 .577 .707 r
F P
0 g
s
.50186 .59478 m .49838 .54227 L .50142 .55518 L p .707 .577 .707 r
F P
0 g
s
.77779 .76895 m .77999 .74985 L .80753 .7527 L p .707 .577 .707 r
F P
0 g
s
.30489 .65487 m .30449 .69217 L .31709 .69945 L p .707 .577 .707 r
F P
0 g
s
.78487 .66384 m .78448 .70114 L .75331 .69911 L p .707 .577 .707 r
F P
0 g
s
.75331 .69911 m .7537 .6618 L .78487 .66384 L p .707 .577 .707 r
F P
0 g
s
.72187 .66219 m .72147 .6995 L .69209 .70227 L p .707 .577 .707 r
F P
0 g
s
.71733 .7427 m .71513 .7618 L .68616 .7582 L p .707 .577 .707 r
F P
0 g
s
.68616 .7582 m .68836 .7391 L .71733 .7427 L p .707 .577 .707 r
F P
0 g
s
.4988 .65993 m .4984 .69723 L .50548 .68971 L p .707 .577 .707 r
F P
0 g
s
.50548 .68971 m .50588 .65241 L .4988 .65993 L p .707 .577 .707 r
F P
0 g
s
.72147 .6995 m .72187 .66219 L .7537 .6618 L p .707 .577 .707 r
F P
0 g
s
.29783 .56122 m .30131 .61373 L .30435 .62663 L p .707 .577 .707 r
F P
0 g
s
.7537 .6618 m .75331 .69911 L .72147 .6995 L p .707 .577 .707 r
F P
0 g
s
.77999 .74985 m .77779 .76895 L .7467 .76551 L p .707 .577 .707 r
F P
0 g
s
.49574 .71712 m .49354 .73622 L .50005 .73761 L p .707 .577 .707 r
F P
0 g
s
.7467 .76551 m .7489 .7464 L .77999 .74985 L p .707 .577 .707 r
F P
0 g
s
.50005 .73761 m .50225 .71851 L .49574 .71712 L p .707 .577 .707 r
F P
0 g
s
.30131 .61373 m .29783 .56122 L .30476 .54802 L p .707 .577 .707 r
F P
0 g
s
.7489 .7464 m .7467 .76551 L .71513 .7618 L p .707 .577 .707 r
F P
0 g
s
.71513 .7618 m .71733 .7427 L .7489 .7464 L p .707 .577 .707 r
F P
0 g
s
.30449 .69217 m .30489 .65487 L .30199 .64709 L p .707 .577 .707 r
F P
0 g
s
.29949 .69537 m .29729 .71448 L .3007 .71422 L p .707 .577 .707 r
F P
0 g
s
.3007 .71422 m .3029 .69512 L .29949 .69537 L p .707 .577 .707 r
F P
0 g
s
.49838 .54227 m .50186 .59478 L .48916 .58343 L p .707 .577 .707 r
F P
0 g
s
.48916 .58343 m .48568 .53092 L .49838 .54227 L p .707 .577 .707 r
F P
0 g
s
.30199 .64709 m .30159 .68439 L .30449 .69217 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50588 .65241 m .50548 .68971 L .50258 .68193 L p .707 .577 .707 r
F P
0 g
s
.50258 .68193 m .50298 .64463 L .50588 .65241 L p .707 .577 .707 r
F P
0 g
s
.30476 .54802 m .30824 .60052 L .30131 .61373 L p .707 .577 .707 r
F P
0 g
s
.30824 .60052 m .30476 .54802 L .32097 .53581 L p .707 .577 .707 r
F P
0 g
s
.50225 .71851 m .50005 .73761 L .49664 .73786 L p .707 .577 .707 r
F P
0 g
s
.49664 .73786 m .49884 .71876 L .50225 .71851 L p .707 .577 .707 r
F P
0 g
s
.30159 .68439 m .30199 .64709 L .30906 .63957 L p .707 .577 .707 r
F P
0 g
s
.48568 .53092 m .48916 .58343 L .46803 .57475 L p .707 .577 .707 r
F P
0 g
s
.46803 .57475 m .46455 .52224 L .48568 .53092 L p .707 .577 .707 r
F P
0 g
s
.30601 .69676 m .30381 .71586 L .29729 .71448 L p .707 .577 .707 r
F P
0 g
s
.29729 .71448 m .29949 .69537 L .30601 .69676 L p .707 .577 .707 r
F P
0 g
s
.30906 .63957 m .30867 .67687 L .30159 .68439 L p .707 .577 .707 r
F P
0 g
s
.32097 .53581 m .32445 .58832 L .30824 .60052 L p .707 .577 .707 r
F P
0 g
s
.50298 .64463 m .50258 .68193 L .48999 .67465 L p .707 .577 .707 r
F P
0 g
s
.48999 .67465 m .49038 .63735 L .50298 .64463 L p .707 .577 .707 r
F P
0 g
s
.32445 .58832 m .32097 .53581 L .34488 .52579 L p .707 .577 .707 r
F P
0 g
s
.46455 .52224 m .46803 .57475 L .44055 .56959 L p .707 .577 .707 r
F P
0 g
s
.44055 .56959 m .43707 .51708 L .46455 .52224 L p .707 .577 .707 r
F P
0 g
s
.49884 .71876 m .49664 .73786 L .48364 .73696 L p .707 .577 .707 r
F P
0 g
s
.48364 .73696 m .48584 .71785 L .49884 .71876 L p .707 .577 .707 r
F P
0 g
s
.30867 .67687 m .30906 .63957 L .32543 .63304 L p .707 .577 .707 r
F P
0 g
s
.34837 .5783 m .34488 .52579 L .37415 .51895 L p .707 .577 .707 r
F P
0 g
s
.34488 .52579 m .34837 .5783 L .32445 .58832 L p .707 .577 .707 r
F P
0 g
s
.32181 .69914 m .31961 .71824 L .30381 .71586 L p .707 .577 .707 r
F P
0 g
s
.30381 .71586 m .30601 .69676 L .32181 .69914 L p .707 .577 .707 r
F P
0 g
s
.32543 .63304 m .32503 .67035 L .30867 .67687 L p .707 .577 .707 r
F P
0 g
s
.43707 .51708 m .44055 .56959 L .4094 .56846 L p .707 .577 .707 r
F P
0 g
s
.4094 .56846 m .40592 .51595 L .43707 .51708 L p .707 .577 .707 r
F P
0 g
s
.49038 .63735 m .48999 .67465 L .46893 .66859 L p .707 .577 .707 r
F P
0 g
s
.46893 .66859 m .46932 .63128 L .49038 .63735 L p .707 .577 .707 r
F P
0 g
s
.37764 .57146 m .37415 .51895 L .40592 .51595 L p .707 .577 .707 r
F P
0 g
s
.37415 .51895 m .37764 .57146 L .34837 .5783 L p .707 .577 .707 r
F P
0 g
s
.40592 .51595 m .4094 .56846 L .37764 .57146 L p .707 .577 .707 r
F P
0 g
s
.32503 .67035 m .32543 .63304 L .34948 .62815 L p .707 .577 .707 r
F P
0 g
s
.48584 .71785 m .48364 .73696 L .46232 .73498 L p .707 .577 .707 r
F P
0 g
s
.46232 .73498 m .46452 .71588 L .48584 .71785 L p .707 .577 .707 r
F P
0 g
s
.34535 .70228 m .34315 .72139 L .31961 .71824 L p .707 .577 .707 r
F P
0 g
s
.31961 .71824 m .32181 .69914 L .34535 .70228 L p .707 .577 .707 r
F P
0 g
s
.34948 .62815 m .34908 .66546 L .32503 .67035 L p .707 .577 .707 r
F P
0 g
s
.46932 .63128 m .46893 .66859 L .44147 .66433 L p .707 .577 .707 r
F P
0 g
s
.44147 .66433 m .44186 .62702 L .46932 .63128 L p .707 .577 .707 r
F P
0 g
s
.34908 .66546 m .34948 .62815 L .37886 .62538 L p .707 .577 .707 r
F P
0 g
s
.46452 .71588 m .46232 .73498 L .43478 .73214 L p .707 .577 .707 r
F P
0 g
s
.43478 .73214 m .43698 .71303 L .46452 .71588 L p .707 .577 .707 r
F P
0 g
s
.44186 .62702 m .44147 .66433 L .4103 .66229 L p .707 .577 .707 r
F P
0 g
s
.4103 .66229 m .41069 .62499 L .44186 .62702 L p .707 .577 .707 r
F P
0 g
s
.37886 .62538 m .37846 .66268 L .34908 .66546 L p .707 .577 .707 r
F P
0 g
s
.37432 .70588 m .37212 .72499 L .34315 .72139 L p .707 .577 .707 r
F P
0 g
s
.34315 .72139 m .34535 .70228 L .37432 .70588 L p .707 .577 .707 r
F P
0 g
s
.37846 .66268 m .37886 .62538 L .41069 .62499 L p .707 .577 .707 r
F P
0 g
s
.41069 .62499 m .4103 .66229 L .37846 .66268 L p .707 .577 .707 r
F P
0 g
s
.43698 .71303 m .43478 .73214 L .40369 .72869 L p .707 .577 .707 r
F P
0 g
s
.40369 .72869 m .40589 .70959 L .43698 .71303 L p .707 .577 .707 r
F P
0 g
s
.40589 .70959 m .40369 .72869 L .37212 .72499 L p .707 .577 .707 r
F P
0 g
s
.37212 .72499 m .37432 .70588 L .40589 .70959 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo3@00R7oo001lOol<0006FUH00`00FUIJEP04FUH9001oOol007Aoo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Uoo`00LGoo0`0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01UYF1000MGoo001^Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001aOol006]oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<006io
o`00JGoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P00KGoo001WOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000
Jgoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000JWoo001TOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Moo`00Hgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001W
Ool0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo
001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0
069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001R
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00HWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001ROol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069oo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000IJEP03
001JEP0000P000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF0000Igoo001SOol01000FUIJEP000UYF1P0015YF00<005YFFUH00UYF2000
0UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH0001WOol006=oo`03001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYF
FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
06Moo`00HGoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001OOol20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005eo
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Moo`00Fgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001IOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06
001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001F
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001EOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000JOol?000nOol005Aoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Aoo`H000AJEP03001JEUYF00IJEP03001J
EP0000<003Yoo`00E7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0047oo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo0018Ool=00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0049oo`H000AJEP03
001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000Qoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP80035oo`00?Woo100000=JEP00FUH01eYF00<005YFFUH01EYF00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF00<005YFFUH01UYF10000UYF00<005YF
FUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
1Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00<7oo000jOol40005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH01UYF00<005YFFUH02EYF1@0015YF
00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Goo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002ioo`00>7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEUYF00=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF009JEP<00004FUH005YFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20004Ool00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000fOol20003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00@005YFFUIJEP800005FUH005YFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000UYF0P000UYF0P0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00@005YFFUH000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH01000FUH000000eYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP@0
0003FUH005YF00=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P001EYF00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;7oo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20002FUH30002FUH01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00UYF100035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002aoo`00;goo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH0
15YF1`001UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00
FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00@0
01Moo`D000EJEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP05001JEUYFFUH0
0005FUH4000POol20003FUH01@00FUIJEUYF0000;7oo000]Ool00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF
00000eYF10008goo0`0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH6000<Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01P00FUIJEUYF
001JEP8000=JEP80021oo`800003FUH005YF008000=JEP8002]oo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00@001=oo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH00`00FUH0
000A0008FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP8000EJEP04001JEP00000LOol2
0003FUH01@00FUIJEUYF00000UYF0P00:goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF1000
5goo00D005YFFUIJEP0000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP0
0003FUH005YF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH4000015YF001JEUYF0`001EYF00D005YFFUIJEP0001Qoo`<000EJEP03001J
EUYF009JEP@002]oo`00;Goo00@005YFFUH000AJEP04001JEUYFFUH2000LOol01000FUIJEP000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH00000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00004FUH0
05YF0003FUH60003FUH00`00Oomoo`0BOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH0
0000:goo000]Ool01000FUIJEP0015YF00@005YF000001moo`H000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH0000000EJEP04001JEUYFFUH9
0009Ool70005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000[Ool002ioo`03001JEP0000AJEP80
021oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00;Woo00<005YF00000UYF
0P000UYF0`001goo4@000Woo100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
0000:goo000^Ool00`00FUH000020005FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH500000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002ioo`06001JEP00FUH0
05YF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;7oo000^Ool20002FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool002ioo`@000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP03001oogoo02]oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF5`001UYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001oo`00009JEP03001JEUYF00=JEP03001JEUYF00EJEQ/000IJEP03
001JEUYF008002ioo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009oo`03001JEP0000EJEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH50002FUH3000`Ool002ioo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP/00003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPX000=JEP03001JEUYF008000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`800003FUH00000008000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080039o
o`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP8000EJEP03001JEUYF00=JEQP000AJEP03001JEUYF00=JEP@0009JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
031oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000^Ool002ioo`03
001JEP0000AJEP03001JEUYF00=JEQ`000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002ioo`03001JEP0000AJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP8000EJEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool002io
o`03001JEP0000=JEP<0009JEP04001JEUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP020003
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20005FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06
001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo00@005YF001JEP80
00EJEP03001JEUYF00EJEP04001JEUYFFUHB0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002]oo`00;Woo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00:goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP0:00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P0015YF
00@005YFFUIJEPL00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01P00FUH00000FUH000=JEP03001JEUYF00=JEPL0011oo`P000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000[Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YF00000`000UYF00@005YFFUIJ
EP8001Moo`H000AJEP04001JEUYFFUH2000[Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF20002EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0002FUH30002FUH00`00FUH0000<
000@Ool50003FUH300000eYF001JEP02FUH2000[Ool0031oo`800003FUH005YF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF009JEP09OomJEUYFFUH005YF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPd000YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP04FUH30003FUH2000[Ool0039oo`<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP05OomJEUYF001JEP040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF3@000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000=JEP000000:goo000eOol300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP09000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002ioo`L000=o
o`D000=JEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo3P0000=oo`0000001P000UYF1@001UYF00<005YFFUH00UYF1P001goo2P00
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000:goo000^Ool00`00FUH00003FUH01000FUIJEUYF7`003Goo00@005YFFUH000EJ
EPX000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00@005YFFUIJEPl001Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3P003Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00EJEQ4000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP06001JEP00FUH005YF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@001Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH01000FUIJEUYF1`00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0035oo`00;Goo
10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEP`0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001J
EUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000fOol0035oo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001J
EUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09FUH<0005FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHF000gOol003Moo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP8000YJEPL000IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00H0035o
o`00?Woo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02EYF0P002UYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF00<005YF00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEQ0002aoo`00Agoo2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF00000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02EYF0P002UYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF00<005YF00001EYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000/Ool0051oo`l000=JEP03001JEP00009JEP04001JEUYFFUH20005FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
000015YF00<005YF00000UYF1`001goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00Ggoo1P000UYF00@005YFFUH000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP8000UJEP04001JEUYFFUH20002FUH00`00
FUH00002000GOol90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001T
Ool00`00FUIJEP040007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0QOol80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo0018Ool3000IOol01000FUIJEP000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P0000=JEP000000:Goo1P000eYF00@005YFFUIJEP8002eoo`00Agoo1@0067oo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01`00:7oo2@00;Goo0017Ool5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000?001HOol004Moo`D001Qo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP09001COol0
04Qoo`<001Uoo`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00Dgoo001TOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH000001UYF00<005YFFUH015YF00@005YFFUIJEP8005=oo`00IGoo00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00=oo`00
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00IGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00IWoo0P000UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001Woo2`00
0UYF0P00E7oo001XOol30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P004goo1000E7oo001ZOol20006FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0
0000KGoo001/Ool20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH4001_Ool006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPH006moo`00LGoo10002EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00000P0000=oo`0000000`00Kgoo001eOol60003
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF2P0017oo1@00Kgoo001kOol90006FUH0
0`00FUIJEP04FUH:000?Ool3001`Ool008Aoo`d008aoo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60003 .74268 m .59787 .68883 L .56671 .68741 L p .707 .577 .707 r
F P
0 g
s
.59787 .68883 m .60003 .74268 L .63184 .74051 L p .707 .577 .707 r
F P
0 g
s
.63184 .74051 m .62968 .68666 L .59787 .68883 L p .707 .577 .707 r
F P
0 g
s
.62968 .68666 m .63184 .74051 L .66118 .73497 L p .707 .577 .707 r
F P
0 g
s
.66118 .73497 m .65902 .68112 L .62968 .68666 L p .707 .577 .707 r
F P
0 g
s
.56887 .74126 m .56671 .68741 L .53924 .68253 L p .707 .577 .707 r
F P
0 g
s
.56671 .68741 m .56887 .74126 L .60003 .74268 L p .707 .577 .707 r
F P
0 g
s
.65902 .68112 m .66118 .73497 L .68518 .72659 L p .707 .577 .707 r
F P
0 g
s
.68518 .72659 m .68302 .67274 L .65902 .68112 L p .707 .577 .707 r
F P
0 g
s
.60011 .78226 m .60036 .74505 L .56919 .74307 L p .707 .577 .707 r
F P
0 g
s
.60036 .74505 m .60011 .78226 L .63195 .78173 L p .707 .577 .707 r
F P
0 g
s
.63195 .78173 m .63219 .74451 L .60036 .74505 L p .707 .577 .707 r
F P
0 g
s
.5414 .73639 m .53924 .68253 L .51816 .67469 L p .707 .577 .707 r
F P
0 g
s
.53924 .68253 m .5414 .73639 L .56887 .74126 L p .707 .577 .707 r
F P
0 g
s
.63219 .74451 m .63195 .78173 L .66133 .77872 L p .707 .577 .707 r
F P
0 g
s
.66133 .77872 m .66157 .74151 L .63219 .74451 L p .707 .577 .707 r
F P
0 g
s
.56894 .78028 m .56919 .74307 L .54173 .73876 L p .707 .577 .707 r
F P
0 g
s
.56919 .74307 m .56894 .78028 L .60011 .78226 L p .707 .577 .707 r
F P
0 g
s
.59777 .8126 m .59914 .7935 L .568 .79065 L p .707 .577 .707 r
F P
0 g
s
.59914 .7935 m .59777 .8126 L .6295 .81458 L p .707 .577 .707 r
F P
0 g
s
.6295 .81458 m .63088 .79548 L .59914 .7935 L p .707 .577 .707 r
F P
0 g
s
.68302 .67274 m .68518 .72659 L .70149 .7162 L p .707 .577 .707 r
F P
0 g
s
.70149 .7162 m .69933 .66235 L .68302 .67274 L p .707 .577 .707 r
F P
0 g
s
.568 .79065 m .56663 .80975 L .59777 .8126 L p .707 .577 .707 r
F P
0 g
s
.63088 .79548 m .6295 .81458 L .65873 .81549 L p .707 .577 .707 r
F P
0 g
s
.65873 .81549 m .6601 .79639 L .63088 .79548 L p .707 .577 .707 r
F P
0 g
s
.66157 .74151 m .66133 .77872 L .68538 .77354 L p .707 .577 .707 r
F P
0 g
s
.68538 .77354 m .68562 .73633 L .66157 .74151 L p .707 .577 .707 r
F P
0 g
s
.54173 .73876 m .54148 .77597 L .56894 .78028 L p .707 .577 .707 r
F P
0 g
s
.56663 .80975 m .568 .79065 L .54051 .78721 L p .707 .577 .707 r
F P
0 g
s
.54051 .78721 m .53914 .80631 L .56663 .80975 L p .707 .577 .707 r
F P
0 g
s
.51816 .67469 m .52032 .72854 L .5414 .73639 L p .707 .577 .707 r
F P
0 g
s
.54148 .77597 m .54173 .73876 L .52067 .73254 L p .707 .577 .707 r
F P
0 g
s
.52032 .72854 m .51816 .67469 L .50552 .66464 L p .707 .577 .707 r
F P
0 g
s
.6601 .79639 m .65873 .81549 L .68259 .81525 L p .707 .577 .707 r
F P
0 g
s
.68259 .81525 m .68396 .79615 L .6601 .79639 L p .707 .577 .707 r
F P
0 g
s
.52067 .73254 m .52043 .76976 L .54148 .77597 L p .707 .577 .707 r
F P
0 g
s
.53914 .80631 m .54051 .78721 L .51936 .78351 L p .707 .577 .707 r
F P
0 g
s
.51936 .78351 m .51798 .80261 L .53914 .80631 L p .707 .577 .707 r
F P
0 g
s
.68562 .73633 m .68538 .77354 L .70175 .76669 L p .707 .577 .707 r
F P
0 g
s
.70175 .76669 m .70199 .72948 L .68562 .73633 L p .707 .577 .707 r
F P
0 g
s
.69933 .66235 m .70149 .7162 L .70851 .70481 L p .707 .577 .707 r
F P
0 g
s
.70851 .70481 m .70635 .65096 L .69933 .66235 L p .707 .577 .707 r
F P
0 g
s
.50552 .66464 m .50768 .71849 L .52032 .72854 L p .707 .577 .707 r
F P
0 g
s
.52043 .76976 m .52067 .73254 L .50808 .72503 L p .707 .577 .707 r
F P
0 g
s
.68396 .79615 m .68259 .81525 L .69874 .81388 L p .707 .577 .707 r
F P
0 g
s
.69874 .81388 m .70011 .79478 L .68396 .79615 L p .707 .577 .707 r
F P
0 g
s
.50768 .71849 m .50552 .66464 L .50257 .65337 L p .707 .577 .707 r
F P
0 g
s
.50808 .72503 m .50783 .76224 L .52043 .76976 L p .707 .577 .707 r
F P
0 g
s
.51798 .80261 m .51936 .78351 L .50661 .77992 L p .707 .577 .707 r
F P
0 g
s
.50661 .77992 m .50523 .79902 L .51798 .80261 L p .707 .577 .707 r
F P
0 g
s
.70199 .72948 m .70175 .76669 L .70883 .75885 L p .707 .577 .707 r
F P
0 g
s
.70883 .75885 m .70907 .72164 L .70199 .72948 L p .707 .577 .707 r
F P
0 g
s
.4885 .82526 m .48534 .32556 L .44133 .32299 L p .707 .577 .707 r
F P
0 g
s
.50257 .65337 m .50473 .70722 L .50768 .71849 L p .707 .577 .707 r
F P
0 g
s
.50783 .76224 m .50808 .72503 L .50518 .71696 L p .707 .577 .707 r
F P
0 g
s
.50473 .70722 m .50257 .65337 L .5096 .64199 L p .707 .577 .707 r
F P
0 g
s
.50518 .71696 m .50493 .75417 L .50783 .76224 L p .707 .577 .707 r
F P
0 g
s
.50523 .79902 m .50661 .77992 L .50351 .77678 L p .707 .577 .707 r
F P
0 g
s
.50351 .77678 m .50214 .79588 L .50523 .79902 L p .707 .577 .707 r
F P
0 g
s
.5096 .64199 m .51175 .69584 L .50473 .70722 L p .707 .577 .707 r
F P
0 g
s
.50493 .75417 m .50518 .71696 L .51226 .70912 L p .707 .577 .707 r
F P
0 g
s
.51175 .69584 m .5096 .64199 L .52591 .63159 L p .707 .577 .707 r
F P
0 g
s
.51226 .70912 m .51202 .74633 L .50493 .75417 L p .707 .577 .707 r
F P
0 g
s
.50214 .79588 m .50351 .77678 L .51038 .77441 L p .707 .577 .707 r
F P
0 g
s
.51038 .77441 m .509 .79351 L .50214 .79588 L p .707 .577 .707 r
F P
0 g
s
.52591 .63159 m .52806 .68545 L .51175 .69584 L p .707 .577 .707 r
F P
0 g
s
.51202 .74633 m .51226 .70912 L .52863 .70227 L p .707 .577 .707 r
F P
0 g
s
.52863 .70227 m .52838 .73948 L .51202 .74633 L p .707 .577 .707 r
F P
0 g
s
.509 .79351 m .51038 .77441 L .52653 .77304 L p .707 .577 .707 r
F P
0 g
s
.52653 .77304 m .52515 .79214 L .509 .79351 L p .707 .577 .707 r
F P
0 g
s
.52515 .79214 m .52653 .77304 L .55038 .7728 L p .707 .577 .707 r
F P
0 g
s
.55038 .7728 m .54901 .7919 L .52515 .79214 L p .707 .577 .707 r
F P
0 g
s
.48534 .32556 m .4885 .82526 L .53344 .82384 L p .707 .577 .707 r
F P
0 g
s
.52806 .68545 m .52591 .63159 L .5499 .62322 L p .707 .577 .707 r
F P
0 g
s
.5499 .62322 m .55206 .67707 L .52806 .68545 L p .707 .577 .707 r
F P
0 g
s
.52838 .73948 m .52863 .70227 L .55268 .69709 L p .707 .577 .707 r
F P
0 g
s
.55268 .69709 m .55244 .7343 L .52838 .73948 L p .707 .577 .707 r
F P
0 g
s
.53344 .82384 m .53028 .32414 L .48534 .32556 L p .707 .577 .707 r
F P
0 g
s
.70635 .65096 m .70851 .70481 L .70556 .69354 L p .707 .577 .707 r
F P
0 g
s
.70556 .69354 m .7034 .63969 L .70635 .65096 L p .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .5499 .62322 L .55178 .62286 L p .707 .577 .707 r
F P
0 g
s
.55178 .62286 m .57924 .61767 L p .55844 .66314 L .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .55178 .62286 L .55844 .66314 L .707 .577 .707 r
F
.5814 .67153 m .57924 .61767 L .61105 .61551 L p F P
0 g
s
.57924 .61767 m .5814 .67153 L .55206 .67707 L p .707 .577 .707 r
F P
0 g
s
.61105 .61551 m .61321 .66936 L .5814 .67153 L p .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .55268 .69709 L .56291 .69604 L p .707 .577 .707 r
F P
0 g
s
.56291 .69604 m .58206 .69408 L p .56154 .72194 L .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .56291 .69604 L .56154 .72194 L .707 .577 .707 r
F
.58206 .69408 m .58182 .73129 L .55244 .7343 L p F P
0 g
s
.58182 .73129 m .58206 .69408 L .61389 .69354 L p .707 .577 .707 r
F P
0 g
s
.61389 .69354 m .61365 .73076 L .58182 .73129 L p .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .57961 .77371 L .58581 .7741 L p .707 .577 .707 r
F P
0 g
s
.58581 .7741 m .61134 .77569 L p .58405 .78981 L .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .58581 .7741 L .58405 .78981 L .707 .577 .707 r
F
.64221 .61693 m .64437 .67078 L .61321 .66936 L p F P
0 g
s
.61321 .66936 m .61105 .61551 L .64221 .61693 L p .707 .577 .707 r
F P
0 g
s
.64507 .69553 m .64482 .73274 L .61365 .73076 L p .707 .577 .707 r
F P
0 g
s
.61365 .73076 m .61389 .69354 L .64507 .69553 L p .707 .577 .707 r
F P
0 g
s
.64248 .77854 m .64111 .79764 L .61377 .79514 L p .707 .577 .707 r
F P
0 g
s
.61377 .79514 m .60997 .79479 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.61386 .79285 m .64248 .77854 L .61377 .79514 L .707 .577 .707 r
F
.64111 .79764 m .64248 .77854 L .66997 .78198 L p F P
0 g
s
.60997 .79479 m .61134 .77569 L .61453 .77598 L p .707 .577 .707 r
F P
0 g
s
.61453 .77598 m .64248 .77854 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.60997 .79479 m .61453 .77598 L .61386 .79285 L .707 .577 .707 r
F
.64198 .78635 m .63882 .28665 L .63376 .29299 L p F P
0 g
s
.63376 .29299 m .62882 .29916 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.64198 .78635 m .63376 .29299 L .63072 .3693 L .707 .577 .707 r
F
.63199 .79886 m .64198 .78635 L p .63072 .3693 L F P
0 g
s
.62882 .29916 m .62947 .40074 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.62947 .40074 m .63199 .79886 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.61134 .77569 m .60997 .79479 L .57824 .79281 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .63199 .79886 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60572 .31026 m .60743 .58166 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60743 .58166 m .60888 .80996 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .57829 .40525 L .57456 .76058 L .707 .577 .707 r
F
.57176 .31887 m .57295 .50625 L p .57829 .40525 L F P
0 g
s
.57295 .50625 m .57456 .76058 L p .57829 .40525 L .707 .577 .707 r
F P
0 g
s
.54901 .7919 m .55038 .7728 L .57961 .77371 L p .707 .577 .707 r
F P
0 g
s
.57961 .77371 m .57824 .79281 L .54901 .7919 L p .707 .577 .707 r
F P
0 g
s
.57456 .76058 m .57492 .81857 L .58378 .81633 L p .707 .577 .707 r
F P
0 g
s
.58378 .81633 m .60888 .80996 L p .57456 .76058 L .707 .577 .707 r
F P
0 g
s
.53028 .32414 m .53344 .82384 L .57492 .81857 L p .707 .577 .707 r
F P
0 g
s
.57492 .81857 m .57176 .31887 L .53028 .32414 L p .707 .577 .707 r
F P
0 g
s
.44449 .82269 m .44133 .32299 L .40257 .31668 L p .707 .577 .707 r
F P
0 g
s
.44133 .32299 m .44449 .82269 L .4885 .82526 L p .707 .577 .707 r
F P
0 g
s
.70011 .79478 m .69874 .81388 L .7056 .81151 L p .707 .577 .707 r
F P
0 g
s
.7056 .81151 m .70697 .79241 L .70011 .79478 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .60572 .31026 L .57176 .31887 L p .707 .577 .707 r
F P
0 g
s
.70907 .72164 m .70883 .75885 L .70593 .75078 L p .707 .577 .707 r
F P
0 g
s
.70593 .75078 m .70618 .71356 L .70907 .72164 L p .707 .577 .707 r
F P
0 g
s
.7034 .63969 m .70556 .69354 L .69292 .6835 L p .707 .577 .707 r
F P
0 g
s
.69292 .6835 m .69077 .62964 L .7034 .63969 L p .707 .577 .707 r
F P
0 g
s
.40573 .81638 m .40257 .31668 L .37284 .30724 L p .707 .577 .707 r
F P
0 g
s
.40257 .31668 m .40573 .81638 L .44449 .82269 L p .707 .577 .707 r
F P
0 g
s
.70697 .79241 m .7056 .81151 L .70251 .80837 L p .707 .577 .707 r
F P
0 g
s
.70251 .80837 m .70388 .78927 L .70697 .79241 L p .707 .577 .707 r
F P
0 g
s
.25702 .70586 m .25486 .65201 L .2237 .65059 L p .707 .577 .707 r
F P
0 g
s
.25486 .65201 m .25702 .70586 L .28883 .7037 L p .707 .577 .707 r
F P
0 g
s
.28883 .7037 m .28667 .64985 L .25486 .65201 L p .707 .577 .707 r
F P
0 g
s
.28667 .64985 m .28883 .7037 L .31817 .69815 L p .707 .577 .707 r
F P
0 g
s
.31817 .69815 m .31601 .6443 L .28667 .64985 L p .707 .577 .707 r
F P
0 g
s
.63199 .79886 m .62882 .29916 L .60572 .31026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22586 .70444 m .2237 .65059 L .19623 .64572 L p .707 .577 .707 r
F P
0 g
s
.2237 .65059 m .22586 .70444 L .25702 .70586 L p .707 .577 .707 r
F P
0 g
s
.69077 .62964 m .69292 .6835 L .67184 .67565 L p .707 .577 .707 r
F P
0 g
s
.67184 .67565 m .66968 .6218 L .69077 .62964 L p .707 .577 .707 r
F P
0 g
s
.70618 .71356 m .70593 .75078 L .69334 .74326 L p .707 .577 .707 r
F P
0 g
s
.69334 .74326 m .69358 .70605 L .70618 .71356 L p .707 .577 .707 r
F P
0 g
s
.31601 .6443 m .31817 .69815 L .34217 .68978 L p .707 .577 .707 r
F P
0 g
s
.34217 .68978 m .34001 .63593 L .31601 .6443 L p .707 .577 .707 r
F P
0 g
s
.376 .80694 m .37284 .30724 L .35506 .29561 L p .707 .577 .707 r
F P
0 g
s
.37284 .30724 m .376 .80694 L .40573 .81638 L p .707 .577 .707 r
F P
0 g
s
.2571 .74545 m .25735 .70824 L .22618 .70625 L p .707 .577 .707 r
F P
0 g
s
.25735 .70824 m .2571 .74545 L .28894 .74491 L p .707 .577 .707 r
F P
0 g
s
.28894 .74491 m .28918 .7077 L .25735 .70824 L p .707 .577 .707 r
F P
0 g
s
.19839 .69957 m .19623 .64572 L .17515 .63788 L p .707 .577 .707 r
F P
0 g
s
.19623 .64572 m .19839 .69957 L .22586 .70444 L p .707 .577 .707 r
F P
0 g
s
.28918 .7077 m .28894 .74491 L .31832 .7419 L p .707 .577 .707 r
F P
0 g
s
.31832 .7419 m .31856 .70469 L .28918 .7077 L p .707 .577 .707 r
F P
0 g
s
.70388 .78927 m .70251 .80837 L .68976 .80478 L p .707 .577 .707 r
F P
0 g
s
.68976 .80478 m .69113 .78568 L .70388 .78927 L p .707 .577 .707 r
F P
0 g
s
.22593 .74347 m .22618 .70625 L .19872 .70194 L p .707 .577 .707 r
F P
0 g
s
.22618 .70625 m .22593 .74347 L .2571 .74545 L p .707 .577 .707 r
F P
0 g
s
.25476 .77579 m .25613 .75668 L .225 .75383 L p .707 .577 .707 r
F P
0 g
s
.25613 .75668 m .25476 .77579 L .2865 .77777 L p .707 .577 .707 r
F P
0 g
s
.2865 .77777 m .28787 .75866 L .25613 .75668 L p .707 .577 .707 r
F P
0 g
s
.34001 .63593 m .34217 .68978 L .35848 .67939 L p .707 .577 .707 r
F P
0 g
s
.35848 .67939 m .35632 .62553 L .34001 .63593 L p .707 .577 .707 r
F P
0 g
s
.225 .75383 m .22362 .77294 L .25476 .77579 L p .707 .577 .707 r
F P
0 g
s
.66968 .6218 m .67184 .67565 L .64437 .67078 L p .707 .577 .707 r
F P
0 g
s
.64437 .67078 m .64221 .61693 L .66968 .6218 L p .707 .577 .707 r
F P
0 g
s
.28787 .75866 m .2865 .77777 L .31572 .77868 L p .707 .577 .707 r
F P
0 g
s
.31572 .77868 m .31709 .75958 L .28787 .75866 L p .707 .577 .707 r
F P
0 g
s
.31856 .70469 m .31832 .7419 L .34237 .73672 L p .707 .577 .707 r
F P
0 g
s
.34237 .73672 m .34262 .69951 L .31856 .70469 L p .707 .577 .707 r
F P
0 g
s
.19872 .70194 m .19847 .73916 L .22593 .74347 L p .707 .577 .707 r
F P
0 g
s
.22362 .77294 m .225 .75383 L .1975 .75039 L p .707 .577 .707 r
F P
0 g
s
.1975 .75039 m .19613 .76949 L .22362 .77294 L p .707 .577 .707 r
F P
0 g
s
.69358 .70605 m .69334 .74326 L .67228 .73705 L p .707 .577 .707 r
F P
0 g
s
.67228 .73705 m .67253 .69984 L .69358 .70605 L p .707 .577 .707 r
F P
0 g
s
.17515 .63788 m .17731 .69173 L .19839 .69957 L p .707 .577 .707 r
F P
0 g
s
.19847 .73916 m .19872 .70194 L .17766 .69573 L p .707 .577 .707 r
F P
0 g
s
.17731 .69173 m .17515 .63788 L .16251 .62783 L p .707 .577 .707 r
F P
0 g
s
.31709 .75958 m .31572 .77868 L .33958 .77844 L p .707 .577 .707 r
F P
0 g
s
.33958 .77844 m .34095 .75933 L .31709 .75958 L p .707 .577 .707 r
F P
0 g
s
.17766 .69573 m .17742 .73294 L .19847 .73916 L p .707 .577 .707 r
F P
0 g
s
.19613 .76949 m .1975 .75039 L .17635 .74669 L p .707 .577 .707 r
F P
0 g
s
.17635 .74669 m .17497 .7658 L .19613 .76949 L p .707 .577 .707 r
F P
0 g
s
.69113 .78568 m .68976 .80478 L .6686 .80108 L p .707 .577 .707 r
F P
0 g
s
.6686 .80108 m .66997 .78198 L .69113 .78568 L p .707 .577 .707 r
F P
0 g
s
.34262 .69951 m .34237 .73672 L .35874 .72988 L p .707 .577 .707 r
F P
0 g
s
.35874 .72988 m .35898 .69266 L .34262 .69951 L p .707 .577 .707 r
F P
0 g
s
.35632 .62553 m .35848 .67939 L .3655 .668 L p .707 .577 .707 r
F P
0 g
s
.3655 .668 m .36334 .61415 L .35632 .62553 L p .707 .577 .707 r
F P
0 g
s
.3571 .75796 m .35573 .77706 L .36259 .77469 L p .707 .577 .707 r
F P
0 g
s
.36259 .77469 m .36396 .75559 L .3571 .75796 L p .707 .577 .707 r
F P
0 g
s
.36039 .60288 m .36255 .65673 L .35892 .65385 L p .707 .577 .707 r
F P
0 g
s
.35892 .65385 m .34991 .64668 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.35953 .60647 m .36039 .60288 L .35892 .65385 L .707 .577 .707 r
F
.34991 .64668 m .34776 .59283 L .35959 .60224 L p F P
0 g
s
.35959 .60224 m .36039 .60288 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.34991 .64668 m .35959 .60224 L .35953 .60647 L .707 .577 .707 r
F
.34095 .75933 m .33958 .77844 L .35573 .77706 L p F P
0 g
s
.35573 .77706 m .3571 .75796 L .34095 .75933 L p .707 .577 .707 r
F P
0 g
s
.35898 .69266 m .35874 .72988 L .36582 .72203 L p .707 .577 .707 r
F P
0 g
s
.36582 .72203 m .36606 .68482 L .35898 .69266 L p .707 .577 .707 r
F P
0 g
s
.36317 .67675 m .36292 .71396 L .35928 .71179 L p .707 .577 .707 r
F P
0 g
s
.35928 .71179 m .35033 .70645 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35895 .68651 m .36317 .67675 L .35928 .71179 L .707 .577 .707 r
F
.35033 .70645 m .35057 .66924 L .35878 .67413 L p F P
0 g
s
.35878 .67413 m .36317 .67675 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35033 .70645 m .35878 .67413 L .35895 .68651 L .707 .577 .707 r
F
.34675 .76797 m .34812 .74886 L .36079 .75243 L p F P
0 g
s
.36079 .75243 m .36087 .75246 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.34675 .76797 m .36079 .75243 L .36079 .75254 L .707 .577 .707 r
F
.35786 .73732 m .35751 .68206 L p .35764 .75416 L F P
0 g
s
.35751 .68206 m .35625 .48299 L p .35724 .67636 L .707 .577 .707 r
F P
0 g
s
.35751 .68206 m .35724 .67636 L .35764 .75416 L .707 .577 .707 r
F
.35625 .48299 m .35506 .29561 L p .35602 .46576 L F P
0 g
s
.35625 .48299 m .35602 .46576 L .35764 .75416 L .707 .577 .707 r
F
.35764 .75416 m .35602 .46576 L .35097 .28292 L F
.35506 .29561 m .35371 .29141 L p .35602 .46576 L F P
0 g
s
.35371 .29141 m .35097 .28292 L p .35602 .46576 L .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .34675 .76797 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36087 .75246 m .36082 .75313 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36082 .75313 m .3595 .77156 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35716 .792 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35097 .28292 m .35287 .5826 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35287 .5826 m .35413 .78262 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35716 .792 m .35822 .79531 L p .35764 .75416 L .707 .577 .707 r
F P
0 g
s
.35764 .75416 m .35097 .28292 L .35716 .792 L .707 .577 .707 r
F
.35822 .79531 m .35786 .73732 L p .35764 .75416 L F P
0 g
s
.36334 .61415 m .3655 .668 L .36255 .65673 L p .707 .577 .707 r
F P
0 g
s
.36255 .65673 m .36039 .60288 L .36334 .61415 L p .707 .577 .707 r
F P
0 g
s
.36606 .68482 m .36582 .72203 L .36292 .71396 L p .707 .577 .707 r
F P
0 g
s
.36292 .71396 m .36317 .67675 L .36606 .68482 L p .707 .577 .707 r
F P
0 g
s
.36396 .75559 m .36259 .77469 L .3595 .77156 L p .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .36087 .75246 L .36396 .75559 L p .707 .577 .707 r
F P
0 g
s
.35506 .29561 m .35822 .79531 L .376 .80694 L p .707 .577 .707 r
F P
0 g
s
.67253 .69984 m .67228 .73705 L .64482 .73274 L p .707 .577 .707 r
F P
0 g
s
.64482 .73274 m .64507 .69553 L .67253 .69984 L p .707 .577 .707 r
F P
0 g
s
.16251 .62783 m .16467 .68168 L .17731 .69173 L p .707 .577 .707 r
F P
0 g
s
.17742 .73294 m .17766 .69573 L .16507 .68822 L p .707 .577 .707 r
F P
0 g
s
.16467 .68168 m .16251 .62783 L .15956 .61656 L p .707 .577 .707 r
F P
0 g
s
.16507 .68822 m .16482 .72543 L .17742 .73294 L p .707 .577 .707 r
F P
0 g
s
.17497 .7658 m .17635 .74669 L .1636 .7431 L p .707 .577 .707 r
F P
0 g
s
.1636 .7431 m .16222 .7622 L .17497 .7658 L p .707 .577 .707 r
F P
0 g
s
.66997 .78198 m .6686 .80108 L .64111 .79764 L p .707 .577 .707 r
F P
0 g
s
.63882 .28665 m .64198 .78635 L .63789 .77366 L p .707 .577 .707 r
F P
0 g
s
.63789 .77366 m .63473 .27396 L .63882 .28665 L p .707 .577 .707 r
F P
0 g
s
.15956 .61656 m .16172 .67041 L .16467 .68168 L p .707 .577 .707 r
F P
0 g
s
.16482 .72543 m .16507 .68822 L .16217 .68014 L p .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35097 .28292 L .36097 .27041 L p .707 .577 .707 r
F P
0 g
s
.16172 .67041 m .15956 .61656 L .16659 .60517 L p .707 .577 .707 r
F P
0 g
s
.16217 .68014 m .16193 .71736 L .16482 .72543 L p .707 .577 .707 r
F P
0 g
s
.16222 .7622 m .1636 .7431 L .1605 .73997 L p .707 .577 .707 r
F P
0 g
s
.1605 .73997 m .15913 .75907 L .16222 .7622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16659 .60517 m .16874 .65902 L .16172 .67041 L p .707 .577 .707 r
F P
0 g
s
.63473 .27396 m .63789 .77366 L .62011 .76203 L p .707 .577 .707 r
F P
0 g
s
.62011 .76203 m .61695 .26233 L .63473 .27396 L p .707 .577 .707 r
F P
0 g
s
.16193 .71736 m .16217 .68014 L .16925 .6723 L p .707 .577 .707 r
F P
0 g
s
.16874 .65902 m .16659 .60517 L .1829 .59478 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16925 .6723 m .16901 .70951 L .16193 .71736 L p .707 .577 .707 r
F P
0 g
s
.15913 .75907 m .1605 .73997 L .16737 .7376 L p .707 .577 .707 r
F P
0 g
s
.16737 .7376 m .16599 .7567 L .15913 .75907 L p .707 .577 .707 r
F P
0 g
s
.36413 .77011 m .36097 .27041 L .38407 .25931 L p .707 .577 .707 r
F P
0 g
s
.36097 .27041 m .36413 .77011 L .35413 .78262 L p .707 .577 .707 r
F P
0 g
s
.34776 .59283 m .34991 .64668 L .32883 .63884 L p .707 .577 .707 r
F P
0 g
s
.32883 .63884 m .32667 .58498 L .34776 .59283 L p .707 .577 .707 r
F P
0 g
s
.1829 .59478 m .18505 .64863 L .16874 .65902 L p .707 .577 .707 r
F P
0 g
s
.18505 .64863 m .1829 .59478 L .20689 .5864 L p .707 .577 .707 r
F P
0 g
s
.16901 .70951 m .16925 .6723 L .18562 .66545 L p .707 .577 .707 r
F P
0 g
s
.61695 .26233 m .62011 .76203 L .59039 .7526 L p .707 .577 .707 r
F P
0 g
s
.59039 .7526 m .58722 .2529 L .61695 .26233 L p .707 .577 .707 r
F P
0 g
s
.18562 .66545 m .18537 .70267 L .16901 .70951 L p .707 .577 .707 r
F P
0 g
s
.32667 .58498 m .32883 .63884 L .30136 .63397 L p .707 .577 .707 r
F P
0 g
s
.30136 .63397 m .29921 .58011 L .32667 .58498 L p .707 .577 .707 r
F P
0 g
s
.16599 .7567 m .16737 .7376 L .18352 .73622 L p .707 .577 .707 r
F P
0 g
s
.18352 .73622 m .18214 .75533 L .16599 .7567 L p .707 .577 .707 r
F P
0 g
s
.35057 .66924 m .35033 .70645 L .32927 .70023 L p .707 .577 .707 r
F P
0 g
s
.32927 .70023 m .32952 .66302 L .35057 .66924 L p .707 .577 .707 r
F P
0 g
s
.20905 .64025 m .20689 .5864 L .23623 .58086 L p .707 .577 .707 r
F P
0 g
s
.20689 .5864 m .20905 .64025 L .18505 .64863 L p .707 .577 .707 r
F P
0 g
s
.38407 .25931 m .38724 .75901 L .36413 .77011 L p .707 .577 .707 r
F P
0 g
s
.38724 .75901 m .38407 .25931 L .41803 .2507 L p .707 .577 .707 r
F P
0 g
s
.29921 .58011 m .30136 .63397 L .2702 .63254 L p .707 .577 .707 r
F P
0 g
s
.2702 .63254 m .26804 .57869 L .29921 .58011 L p .707 .577 .707 r
F P
0 g
s
.18537 .70267 m .18562 .66545 L .20967 .66027 L p .707 .577 .707 r
F P
0 g
s
.23839 .63471 m .23623 .58086 L .26804 .57869 L p .707 .577 .707 r
F P
0 g
s
.23623 .58086 m .23839 .63471 L .20905 .64025 L p .707 .577 .707 r
F P
0 g
s
.34812 .74886 m .34675 .76797 L .32559 .76427 L p .707 .577 .707 r
F P
0 g
s
.32559 .76427 m .32696 .74517 L .34812 .74886 L p .707 .577 .707 r
F P
0 g
s
.26804 .57869 m .2702 .63254 L .23839 .63471 L p .707 .577 .707 r
F P
0 g
s
.20967 .66027 m .20943 .69749 L .18537 .70267 L p .707 .577 .707 r
F P
0 g
s
.32952 .66302 m .32927 .70023 L .30181 .69592 L p .707 .577 .707 r
F P
0 g
s
.30181 .69592 m .30206 .65871 L .32952 .66302 L p .707 .577 .707 r
F P
0 g
s
.18214 .75533 m .18352 .73622 L .20737 .73598 L p .707 .577 .707 r
F P
0 g
s
.58722 .2529 m .59039 .7526 L .55162 .74628 L p .707 .577 .707 r
F P
0 g
s
.55162 .74628 m .54846 .24658 L .58722 .2529 L p .707 .577 .707 r
F P
0 g
s
.20737 .73598 m .206 .75508 L .18214 .75533 L p .707 .577 .707 r
F P
0 g
s
.20943 .69749 m .20967 .66027 L .23905 .65727 L p .707 .577 .707 r
F P
0 g
s
.73723 .67761 m .73507 .62376 L .70391 .62234 L p .707 .577 .707 r
F P
0 g
s
.73507 .62376 m .73723 .67761 L .76904 .67545 L p .707 .577 .707 r
F P
0 g
s
.76904 .67545 m .76688 .62159 L .73507 .62376 L p .707 .577 .707 r
F P
0 g
s
.76688 .62159 m .76904 .67545 L .79838 .6699 L p .707 .577 .707 r
F P
0 g
s
.79838 .6699 m .79622 .61605 L .76688 .62159 L p .707 .577 .707 r
F P
0 g
s
.42119 .7504 m .41803 .2507 L .45951 .24543 L p .707 .577 .707 r
F P
0 g
s
.41803 .2507 m .42119 .7504 L .38724 .75901 L p .707 .577 .707 r
F P
0 g
s
.30206 .65871 m .30181 .69592 L .27064 .69394 L p .707 .577 .707 r
F P
0 g
s
.27064 .69394 m .27089 .65673 L .30206 .65871 L p .707 .577 .707 r
F P
0 g
s
.70607 .67619 m .70391 .62234 L .67644 .61747 L p .707 .577 .707 r
F P
0 g
s
.70391 .62234 m .70607 .67619 L .73723 .67761 L p .707 .577 .707 r
F P
0 g
s
.32696 .74517 m .32559 .76427 L .2981 .76083 L p .707 .577 .707 r
F P
0 g
s
.2981 .76083 m .29947 .74172 L .32696 .74517 L p .707 .577 .707 r
F P
0 g
s
.23905 .65727 m .23881 .69448 L .20943 .69749 L p .707 .577 .707 r
F P
0 g
s
.23881 .69448 m .23905 .65727 L .27089 .65673 L p .707 .577 .707 r
F P
0 g
s
.27089 .65673 m .27064 .69394 L .23881 .69448 L p .707 .577 .707 r
F P
0 g
s
.206 .75508 m .20737 .73598 L .2366 .73689 L p .707 .577 .707 r
F P
0 g
s
.79622 .61605 m .79838 .6699 L .82238 .66153 L p .707 .577 .707 r
F P
0 g
s
.82238 .66153 m .82022 .60767 L .79622 .61605 L p .707 .577 .707 r
F P
0 g
s
.54846 .24658 m .55162 .74628 L .50761 .74371 L p .707 .577 .707 r
F P
0 g
s
.50761 .74371 m .50445 .24401 L .54846 .24658 L p .707 .577 .707 r
F P
0 g
s
.2366 .73689 m .23523 .756 L .206 .75508 L p .707 .577 .707 r
F P
0 g
s
.46267 .74513 m .45951 .24543 L .50445 .24401 L p .707 .577 .707 r
F P
0 g
s
.45951 .24543 m .46267 .74513 L .42119 .7504 L p .707 .577 .707 r
F P
0 g
s
.6786 .67132 m .67644 .61747 L .65536 .60962 L p .707 .577 .707 r
F P
0 g
s
.67644 .61747 m .6786 .67132 L .70607 .67619 L p .707 .577 .707 r
F P
0 g
s
.29947 .74172 m .2981 .76083 L .26696 .75798 L p .707 .577 .707 r
F P
0 g
s
.26696 .75798 m .26833 .73887 L .29947 .74172 L p .707 .577 .707 r
F P
0 g
s
.50445 .24401 m .50761 .74371 L .46267 .74513 L p .707 .577 .707 r
F P
0 g
s
.23523 .756 m .2366 .73689 L .26833 .73887 L p .707 .577 .707 r
F P
0 g
s
.73732 .73686 m .73756 .69965 L .70639 .69767 L p .707 .577 .707 r
F P
0 g
s
.73756 .69965 m .73732 .73686 L .76915 .73633 L p .707 .577 .707 r
F P
0 g
s
.76915 .73633 m .7694 .69911 L .73756 .69965 L p .707 .577 .707 r
F P
0 g
s
.26833 .73887 m .26696 .75798 L .23523 .756 L p .707 .577 .707 r
F P
0 g
s
.7694 .69911 m .76915 .73633 L .79853 .73332 L p .707 .577 .707 r
F P
0 g
s
.79853 .73332 m .79878 .69611 L .7694 .69911 L p .707 .577 .707 r
F P
0 g
s
.82022 .60767 m .82238 .66153 L .83869 .65113 L p .707 .577 .707 r
F P
0 g
s
.83869 .65113 m .83653 .59728 L .82022 .60767 L p .707 .577 .707 r
F P
0 g
s
.70615 .73488 m .70639 .69767 L .67893 .69336 L p .707 .577 .707 r
F P
0 g
s
.70639 .69767 m .70615 .73488 L .73732 .73686 L p .707 .577 .707 r
F P
0 g
s
.73497 .7602 m .73635 .7411 L .70521 .73825 L p .707 .577 .707 r
F P
0 g
s
.73635 .7411 m .73497 .7602 L .76671 .76218 L p .707 .577 .707 r
F P
0 g
s
.76671 .76218 m .76808 .74308 L .73635 .7411 L p .707 .577 .707 r
F P
0 g
s
.70521 .73825 m .70384 .75735 L .73497 .7602 L p .707 .577 .707 r
F P
0 g
s
.76808 .74308 m .76671 .76218 L .79593 .76309 L p .707 .577 .707 r
F P
0 g
s
.79593 .76309 m .79731 .74399 L .76808 .74308 L p .707 .577 .707 r
F P
0 g
s
.70384 .75735 m .70521 .73825 L .67772 .7348 L p .707 .577 .707 r
F P
0 g
s
.79878 .69611 m .79853 .73332 L .82258 .72814 L p .707 .577 .707 r
F P
0 g
s
.82258 .72814 m .82283 .69093 L .79878 .69611 L p .707 .577 .707 r
F P
0 g
s
.65536 .60962 m .65752 .66348 L .6786 .67132 L p .707 .577 .707 r
F P
0 g
s
.67893 .69336 m .67869 .73057 L .70615 .73488 L p .707 .577 .707 r
F P
0 g
s
.67772 .7348 m .67634 .75391 L .70384 .75735 L p .707 .577 .707 r
F P
0 g
s
.65752 .66348 m .65536 .60962 L .64273 .59958 L p .707 .577 .707 r
F P
0 g
s
.67869 .73057 m .67893 .69336 L .65787 .68714 L p .707 .577 .707 r
F P
0 g
s
.79731 .74399 m .79593 .76309 L .81979 .76285 L p .707 .577 .707 r
F P
0 g
s
.81979 .76285 m .82116 .74375 L .79731 .74399 L p .707 .577 .707 r
F P
0 g
s
.67634 .75391 m .67772 .7348 L .65656 .73111 L p .707 .577 .707 r
F P
0 g
s
.83653 .59728 m .83869 .65113 L .84571 .63975 L p .707 .577 .707 r
F P
0 g
s
.84571 .63975 m .84356 .58589 L .83653 .59728 L p .707 .577 .707 r
F P
0 g
s
.65787 .68714 m .65763 .72436 L .67869 .73057 L p .707 .577 .707 r
F P
0 g
s
.65656 .73111 m .65519 .75021 L .67634 .75391 L p .707 .577 .707 r
F P
0 g
s
.82283 .69093 m .82258 .72814 L .83895 .72129 L p .707 .577 .707 r
F P
0 g
s
.83895 .72129 m .8392 .68408 L .82283 .69093 L p .707 .577 .707 r
F P
0 g
s
.64273 .59958 m .64488 .65343 L .65752 .66348 L p .707 .577 .707 r
F P
0 g
s
.64488 .65343 m .64273 .59958 L .63978 .58831 L p .707 .577 .707 r
F P
0 g
s
.65763 .72436 m .65787 .68714 L .64528 .67963 L p .707 .577 .707 r
F P
0 g
s
.82116 .74375 m .81979 .76285 L .83594 .76148 L p .707 .577 .707 r
F P
0 g
s
.83594 .76148 m .83731 .74237 L .82116 .74375 L p .707 .577 .707 r
F P
0 g
s
.65519 .75021 m .65656 .73111 L .64381 .72751 L p .707 .577 .707 r
F P
0 g
s
.64528 .67963 m .64504 .71685 L .65763 .72436 L p .707 .577 .707 r
F P
0 g
s
.64381 .72751 m .64244 .74662 L .65519 .75021 L p .707 .577 .707 r
F P
0 g
s
.84356 .58589 m .84571 .63975 L .84276 .62848 L p .707 .577 .707 r
F P
0 g
s
.84276 .62848 m .84061 .57462 L .84356 .58589 L p .707 .577 .707 r
F P
0 g
s
.8392 .68408 m .83895 .72129 L .84603 .71345 L p .707 .577 .707 r
F P
0 g
s
.84603 .71345 m .84628 .67624 L .8392 .68408 L p .707 .577 .707 r
F P
0 g
s
.63978 .58831 m .64193 .64216 L .64488 .65343 L p .707 .577 .707 r
F P
0 g
s
.83731 .74237 m .83594 .76148 L .8428 .75911 L p .707 .577 .707 r
F P
0 g
s
.8428 .75911 m .84418 .74 L .83731 .74237 L p .707 .577 .707 r
F P
0 g
s
.64504 .71685 m .64528 .67963 L .64238 .67156 L p .707 .577 .707 r
F P
0 g
s
.64193 .64216 m .63978 .58831 L .6468 .57692 L p .707 .577 .707 r
F P
0 g
s
.64244 .74662 m .64381 .72751 L .64072 .72438 L p .707 .577 .707 r
F P
0 g
s
.64238 .67156 m .64214 .70877 L .64504 .71685 L p .707 .577 .707 r
F P
0 g
s
.64072 .72438 m .63934 .74348 L .64244 .74662 L p .707 .577 .707 r
F P
0 g
s
.84061 .57462 m .84276 .62848 L .83013 .61843 L p .707 .577 .707 r
F P
0 g
s
.83013 .61843 m .82797 .56458 L .84061 .57462 L p .707 .577 .707 r
F P
0 g
s
.84628 .67624 m .84603 .71345 L .84314 .70538 L p .707 .577 .707 r
F P
0 g
s
.84314 .70538 m .84338 .66816 L .84628 .67624 L p .707 .577 .707 r
F P
0 g
s
.6468 .57692 m .64896 .63077 L .64193 .64216 L p .707 .577 .707 r
F P
0 g
s
.64896 .63077 m .6468 .57692 L .66311 .56653 L p .707 .577 .707 r
F P
0 g
s
.84418 .74 m .8428 .75911 L .83971 .75597 L p .707 .577 .707 r
F P
0 g
s
.83971 .75597 m .84108 .73687 L .84418 .74 L p .707 .577 .707 r
F P
0 g
s
.39422 .6408 m .39207 .58695 L .3609 .58552 L p .707 .577 .707 r
F P
0 g
s
.39207 .58695 m .39422 .6408 L .42603 .63863 L p .707 .577 .707 r
F P
0 g
s
.42603 .63863 m .42387 .58478 L .39207 .58695 L p .707 .577 .707 r
F P
0 g
s
.64214 .70877 m .64238 .67156 L .64946 .66372 L p .707 .577 .707 r
F P
0 g
s
.42387 .58478 m .42603 .63863 L .45537 .63309 L p .707 .577 .707 r
F P
0 g
s
.45537 .63309 m .45321 .57923 L .42387 .58478 L p .707 .577 .707 r
F P
0 g
s
.36306 .63938 m .3609 .58552 L .33343 .58065 L p .707 .577 .707 r
F P
0 g
s
.3609 .58552 m .36306 .63938 L .39422 .6408 L p .707 .577 .707 r
F P
0 g
s
.64946 .66372 m .64922 .70093 L .64214 .70877 L p .707 .577 .707 r
F P
0 g
s
.63934 .74348 m .64072 .72438 L .64758 .72201 L p .707 .577 .707 r
F P
0 g
s
.64758 .72201 m .64621 .74111 L .63934 .74348 L p .707 .577 .707 r
F P
0 g
s
.82797 .56458 m .83013 .61843 L .80905 .61058 L p .707 .577 .707 r
F P
0 g
s
.80905 .61058 m .80689 .55673 L .82797 .56458 L p .707 .577 .707 r
F P
0 g
s
.45321 .57923 m .45537 .63309 L .47937 .62471 L p .707 .577 .707 r
F P
0 g
s
.47937 .62471 m .47721 .57086 L .45321 .57923 L p .707 .577 .707 r
F P
0 g
s
.84338 .66816 m .84314 .70538 L .83054 .69786 L p .707 .577 .707 r
F P
0 g
s
.83054 .69786 m .83079 .66065 L .84338 .66816 L p .707 .577 .707 r
F P
0 g
s
.66311 .56653 m .66527 .62038 L .64896 .63077 L p .707 .577 .707 r
F P
0 g
s
.33559 .6345 m .33343 .58065 L .31235 .57281 L p .707 .577 .707 r
F P
0 g
s
.33343 .58065 m .33559 .6345 L .36306 .63938 L p .707 .577 .707 r
F P
0 g
s
.66527 .62038 m .66311 .56653 L .68711 .55815 L p .707 .577 .707 r
F P
0 g
s
.39431 .70005 m .39455 .66284 L .36338 .66085 L p .707 .577 .707 r
F P
0 g
s
.39455 .66284 m .39431 .70005 L .42614 .69951 L p .707 .577 .707 r
F P
0 g
s
.42614 .69951 m .42639 .6623 L .39455 .66284 L p .707 .577 .707 r
F P
0 g
s
.42639 .6623 m .42614 .69951 L .45552 .6965 L p .707 .577 .707 r
F P
0 g
s
.45552 .6965 m .45577 .65929 L .42639 .6623 L p .707 .577 .707 r
F P
0 g
s
.64922 .70093 m .64946 .66372 L .66583 .65687 L p .707 .577 .707 r
F P
0 g
s
.84108 .73687 m .83971 .75597 L .82696 .75238 L p .707 .577 .707 r
F P
0 g
s
.82696 .75238 m .82834 .73328 L .84108 .73687 L p .707 .577 .707 r
F P
0 g
s
.47721 .57086 m .47937 .62471 L .49568 .61432 L p .707 .577 .707 r
F P
0 g
s
.49568 .61432 m .49352 .56047 L .47721 .57086 L p .707 .577 .707 r
F P
0 g
s
.36314 .69807 m .36338 .66085 L .33592 .65654 L p .707 .577 .707 r
F P
0 g
s
.36338 .66085 m .36314 .69807 L .39431 .70005 L p .707 .577 .707 r
F P
0 g
s
.80689 .55673 m .80905 .61058 L .78158 .60571 L p .707 .577 .707 r
F P
0 g
s
.78158 .60571 m .77942 .55186 L .80689 .55673 L p .707 .577 .707 r
F P
0 g
s
.39196 .72339 m .39334 .70428 L .3622 .70143 L p .707 .577 .707 r
F P
0 g
s
.39334 .70428 m .39196 .72339 L .4237 .72536 L p .707 .577 .707 r
F P
0 g
s
.4237 .72536 m .42507 .70626 L .39334 .70428 L p .707 .577 .707 r
F P
0 g
s
.3622 .70143 m .36083 .72054 L .39196 .72339 L p .707 .577 .707 r
F P
0 g
s
.42507 .70626 m .4237 .72536 L .45292 .72628 L p .707 .577 .707 r
F P
0 g
s
.45292 .72628 m .4543 .70717 L .42507 .70626 L p .707 .577 .707 r
F P
0 g
s
.66583 .65687 m .66559 .69408 L .64922 .70093 L p .707 .577 .707 r
F P
0 g
s
.64621 .74111 m .64758 .72201 L .66373 .72064 L p .707 .577 .707 r
F P
0 g
s
.36083 .72054 m .3622 .70143 L .33471 .69799 L p .707 .577 .707 r
F P
0 g
s
.45577 .65929 m .45552 .6965 L .47958 .69132 L p .707 .577 .707 r
F P
0 g
s
.47958 .69132 m .47982 .65411 L .45577 .65929 L p .707 .577 .707 r
F P
0 g
s
.31235 .57281 m .31451 .62666 L .33559 .6345 L p .707 .577 .707 r
F P
0 g
s
.66373 .72064 m .66236 .73974 L .64621 .74111 L p .707 .577 .707 r
F P
0 g
s
.33592 .65654 m .33568 .69376 L .36314 .69807 L p .707 .577 .707 r
F P
0 g
s
.68927 .612 m .68711 .55815 L .71645 .55261 L p .707 .577 .707 r
F P
0 g
s
.68711 .55815 m .68927 .612 L .66527 .62038 L p .707 .577 .707 r
F P
0 g
s
.33471 .69799 m .33333 .71709 L .36083 .72054 L p .707 .577 .707 r
F P
0 g
s
.31451 .62666 m .31235 .57281 L .29972 .56276 L p .707 .577 .707 r
F P
0 g
s
.83079 .66065 m .83054 .69786 L .80949 .69165 L p .707 .577 .707 r
F P
0 g
s
.80949 .69165 m .80973 .65444 L .83079 .66065 L p .707 .577 .707 r
F P
0 g
s
.33568 .69376 m .33592 .65654 L .31486 .65033 L p .707 .577 .707 r
F P
0 g
s
.77942 .55186 m .78158 .60571 L .75041 .60429 L p .707 .577 .707 r
F P
0 g
s
.75041 .60429 m .74826 .55044 L .77942 .55186 L p .707 .577 .707 r
F P
0 g
s
.4543 .70717 m .45292 .72628 L .47678 .72603 L p .707 .577 .707 r
F P
0 g
s
.47678 .72603 m .47815 .70693 L .4543 .70717 L p .707 .577 .707 r
F P
0 g
s
.71861 .60646 m .71645 .55261 L .74826 .55044 L p .707 .577 .707 r
F P
0 g
s
.71645 .55261 m .71861 .60646 L .68927 .612 L p .707 .577 .707 r
F P
0 g
s
.66559 .69408 m .66583 .65687 L .68988 .65169 L p .707 .577 .707 r
F P
0 g
s
.74826 .55044 m .75041 .60429 L .71861 .60646 L p .707 .577 .707 r
F P
0 g
s
.33333 .71709 m .33471 .69799 L .31355 .69429 L p .707 .577 .707 r
F P
0 g
s
.49352 .56047 m .49568 .61432 L .5027 .60293 L p .707 .577 .707 r
F P
0 g
s
.5027 .60293 m .50055 .54908 L .49352 .56047 L p .707 .577 .707 r
F P
0 g
s
.31486 .65033 m .31462 .68754 L .33568 .69376 L p .707 .577 .707 r
F P
0 g
s
.31355 .69429 m .31218 .71339 L .33333 .71709 L p .707 .577 .707 r
F P
0 g
s
.82834 .73328 m .82696 .75238 L .80581 .74868 L p .707 .577 .707 r
F P
0 g
s
.80581 .74868 m .80718 .72958 L .82834 .73328 L p .707 .577 .707 r
F P
0 g
s
.47982 .65411 m .47958 .69132 L .49594 .68448 L p .707 .577 .707 r
F P
0 g
s
.49594 .68448 m .49619 .64726 L .47982 .65411 L p .707 .577 .707 r
F P
0 g
s
.29972 .56276 m .30187 .61661 L .31451 .62666 L p .707 .577 .707 r
F P
0 g
s
.68988 .65169 m .68964 .6889 L .66559 .69408 L p .707 .577 .707 r
F P
0 g
s
.66236 .73974 m .66373 .72064 L .68759 .7204 L p .707 .577 .707 r
F P
0 g
s
.80973 .65444 m .80949 .69165 L .78203 .68734 L p .707 .577 .707 r
F P
0 g
s
.78203 .68734 m .78227 .65013 L .80973 .65444 L p .707 .577 .707 r
F P
0 g
s
.68759 .7204 m .68621 .7395 L .66236 .73974 L p .707 .577 .707 r
F P
0 g
s
.30187 .61661 m .29972 .56276 L .29677 .55149 L p .707 .577 .707 r
F P
0 g
s
.31462 .68754 m .31486 .65033 L .30227 .64282 L p .707 .577 .707 r
F P
0 g
s
.47815 .70693 m .47678 .72603 L .49293 .72466 L p .707 .577 .707 r
F P
0 g
s
.49293 .72466 m .4943 .70556 L .47815 .70693 L p .707 .577 .707 r
F P
0 g
s
.68964 .6889 m .68988 .65169 L .71926 .64868 L p .707 .577 .707 r
F P
0 g
s
.31218 .71339 m .31355 .69429 L .3008 .6907 L p .707 .577 .707 r
F P
0 g
s
.30227 .64282 m .30203 .68003 L .31462 .68754 L p .707 .577 .707 r
F P
0 g
s
.3008 .6907 m .29943 .7098 L .31218 .71339 L p .707 .577 .707 r
F P
0 g
s
.80718 .72958 m .80581 .74868 L .77831 .74524 L p .707 .577 .707 r
F P
0 g
s
.77831 .74524 m .77969 .72614 L .80718 .72958 L p .707 .577 .707 r
F P
0 g
s
.78227 .65013 m .78203 .68734 L .75086 .68536 L p .707 .577 .707 r
F P
0 g
s
.75086 .68536 m .7511 .64814 L .78227 .65013 L p .707 .577 .707 r
F P
0 g
s
.71926 .64868 m .71902 .6859 L .68964 .6889 L p .707 .577 .707 r
F P
0 g
s
.50055 .54908 m .5027 .60293 L .49975 .59166 L p .707 .577 .707 r
F P
0 g
s
.49975 .59166 m .49759 .53781 L .50055 .54908 L p .707 .577 .707 r
F P
0 g
s
.49619 .64726 m .49594 .68448 L .50302 .67663 L p .707 .577 .707 r
F P
0 g
s
.50302 .67663 m .50327 .63942 L .49619 .64726 L p .707 .577 .707 r
F P
0 g
s
.71902 .6859 m .71926 .64868 L .7511 .64814 L p .707 .577 .707 r
F P
0 g
s
.68621 .7395 m .68759 .7204 L .71681 .72131 L p .707 .577 .707 r
F P
0 g
s
.71681 .72131 m .71544 .74041 L .68621 .7395 L p .707 .577 .707 r
F P
0 g
s
.7511 .64814 m .75086 .68536 L .71902 .6859 L p .707 .577 .707 r
F P
0 g
s
.29677 .55149 m .29892 .60534 L .30187 .61661 L p .707 .577 .707 r
F P
0 g
s
.77969 .72614 m .77831 .74524 L .74718 .74239 L p .707 .577 .707 r
F P
0 g
s
.74718 .74239 m .74855 .72329 L .77969 .72614 L p .707 .577 .707 r
F P
0 g
s
.4943 .70556 m .49293 .72466 L .49979 .72229 L p .707 .577 .707 r
F P
0 g
s
.49979 .72229 m .50117 .70319 L .4943 .70556 L p .707 .577 .707 r
F P
0 g
s
.30203 .68003 m .30227 .64282 L .29937 .63474 L p .707 .577 .707 r
F P
0 g
s
.29892 .60534 m .29677 .55149 L .30379 .5401 L p .707 .577 .707 r
F P
0 g
s
.71544 .74041 m .71681 .72131 L .74855 .72329 L p .707 .577 .707 r
F P
0 g
s
.74855 .72329 m .74718 .74239 L .71544 .74041 L p .707 .577 .707 r
F P
0 g
s
.29943 .7098 m .3008 .6907 L .29771 .68756 L p .707 .577 .707 r
F P
0 g
s
.29937 .63474 m .29913 .67196 L .30203 .68003 L p .707 .577 .707 r
F P
0 g
s
.29771 .68756 m .29633 .70667 L .29943 .7098 L p .707 .577 .707 r
F P
0 g
s
.49759 .53781 m .49975 .59166 L .48712 .58161 L p .707 .577 .707 r
F P
0 g
s
.48712 .58161 m .48496 .52776 L .49759 .53781 L p .707 .577 .707 r
F P
0 g
s
.50327 .63942 m .50302 .67663 L .50013 .66856 L p .707 .577 .707 r
F P
0 g
s
.50013 .66856 m .50037 .63135 L .50327 .63942 L p .707 .577 .707 r
F P
0 g
s
.30379 .5401 m .30595 .59395 L .29892 .60534 L p .707 .577 .707 r
F P
0 g
s
.30595 .59395 m .30379 .5401 L .3201 .52971 L p .707 .577 .707 r
F P
0 g
s
.50117 .70319 m .49979 .72229 L .4967 .71916 L p .707 .577 .707 r
F P
0 g
s
.4967 .71916 m .49807 .70005 L .50117 .70319 L p .707 .577 .707 r
F P
0 g
s
.29913 .67196 m .29937 .63474 L .30645 .6269 L p .707 .577 .707 r
F P
0 g
s
.30645 .6269 m .30621 .66411 L .29913 .67196 L p .707 .577 .707 r
F P
0 g
s
.29633 .70667 m .29771 .68756 L .30457 .68519 L p .707 .577 .707 r
F P
0 g
s
.30457 .68519 m .3032 .7043 L .29633 .70667 L p .707 .577 .707 r
F P
0 g
s
.48496 .52776 m .48712 .58161 L .46603 .57377 L p .707 .577 .707 r
F P
0 g
s
.46603 .57377 m .46388 .51992 L .48496 .52776 L p .707 .577 .707 r
F P
0 g
s
.50037 .63135 m .50013 .66856 L .48753 .66105 L p .707 .577 .707 r
F P
0 g
s
.48753 .66105 m .48778 .62384 L .50037 .63135 L p .707 .577 .707 r
F P
0 g
s
.3201 .52971 m .32226 .58356 L .30595 .59395 L p .707 .577 .707 r
F P
0 g
s
.32226 .58356 m .3201 .52971 L .3441 .52133 L p .707 .577 .707 r
F P
0 g
s
.30621 .66411 m .30645 .6269 L .32282 .62005 L p .707 .577 .707 r
F P
0 g
s
.49807 .70005 m .4967 .71916 L .48395 .71557 L p .707 .577 .707 r
F P
0 g
s
.48395 .71557 m .48532 .69646 L .49807 .70005 L p .707 .577 .707 r
F P
0 g
s
.46388 .51992 m .46603 .57377 L .43857 .5689 L p .707 .577 .707 r
F P
0 g
s
.43857 .5689 m .43641 .51505 L .46388 .51992 L p .707 .577 .707 r
F P
0 g
s
.32282 .62005 m .32258 .65727 L .30621 .66411 L p .707 .577 .707 r
F P
0 g
s
.3032 .7043 m .30457 .68519 L .32072 .68382 L p .707 .577 .707 r
F P
0 g
s
.32072 .68382 m .31935 .70292 L .3032 .7043 L p .707 .577 .707 r
F P
0 g
s
.34626 .57519 m .3441 .52133 L .37344 .51579 L p .707 .577 .707 r
F P
0 g
s
.3441 .52133 m .34626 .57519 L .32226 .58356 L p .707 .577 .707 r
F P
0 g
s
.48778 .62384 m .48753 .66105 L .46648 .65483 L p .707 .577 .707 r
F P
0 g
s
.46648 .65483 m .46672 .61762 L .48778 .62384 L p .707 .577 .707 r
F P
0 g
s
.43641 .51505 m .43857 .5689 L .4074 .56748 L p .707 .577 .707 r
F P
0 g
s
.4074 .56748 m .40525 .51362 L .43641 .51505 L p .707 .577 .707 r
F P
0 g
s
.3756 .56964 m .37344 .51579 L .40525 .51362 L p .707 .577 .707 r
F P
0 g
s
.37344 .51579 m .3756 .56964 L .34626 .57519 L p .707 .577 .707 r
F P
0 g
s
.32258 .65727 m .32282 .62005 L .34687 .61487 L p .707 .577 .707 r
F P
0 g
s
.40525 .51362 m .4074 .56748 L .3756 .56964 L p .707 .577 .707 r
F P
0 g
s
.48532 .69646 m .48395 .71557 L .4628 .71187 L p .707 .577 .707 r
F P
0 g
s
.4628 .71187 m .46417 .69276 L .48532 .69646 L p .707 .577 .707 r
F P
0 g
s
.34687 .61487 m .34663 .65209 L .32258 .65727 L p .707 .577 .707 r
F P
0 g
s
.31935 .70292 m .32072 .68382 L .34458 .68358 L p .707 .577 .707 r
F P
0 g
s
.46672 .61762 m .46648 .65483 L .43902 .65052 L p .707 .577 .707 r
F P
0 g
s
.43902 .65052 m .43926 .61331 L .46672 .61762 L p .707 .577 .707 r
F P
0 g
s
.34458 .68358 m .3432 .70268 L .31935 .70292 L p .707 .577 .707 r
F P
0 g
s
.34663 .65209 m .34687 .61487 L .37625 .61187 L p .707 .577 .707 r
F P
0 g
s
.46417 .69276 m .4628 .71187 L .4353 .70842 L p .707 .577 .707 r
F P
0 g
s
.4353 .70842 m .43668 .68932 L .46417 .69276 L p .707 .577 .707 r
F P
0 g
s
.43926 .61331 m .43902 .65052 L .40784 .64854 L p .707 .577 .707 r
F P
0 g
s
.40784 .64854 m .40809 .61133 L .43926 .61331 L p .707 .577 .707 r
F P
0 g
s
.37625 .61187 m .37601 .64908 L .34663 .65209 L p .707 .577 .707 r
F P
0 g
s
.37601 .64908 m .37625 .61187 L .40809 .61133 L p .707 .577 .707 r
F P
0 g
s
.3432 .70268 m .34458 .68358 L .3738 .68449 L p .707 .577 .707 r
F P
0 g
s
.3738 .68449 m .37243 .7036 L .3432 .70268 L p .707 .577 .707 r
F P
0 g
s
.40809 .61133 m .40784 .64854 L .37601 .64908 L p .707 .577 .707 r
F P
0 g
s
.43668 .68932 m .4353 .70842 L .40416 .70557 L p .707 .577 .707 r
F P
0 g
s
.40416 .70557 m .40554 .68647 L .43668 .68932 L p .707 .577 .707 r
F P
0 g
s
.37243 .7036 m .3738 .68449 L .40554 .68647 L p .707 .577 .707 r
F P
0 g
s
.40554 .68647 m .40416 .70557 L .37243 .7036 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo5@00R7oo001jOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001lOol007Aoo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL007Eoo`00L7oo10000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00LWoo001/
Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH3001_Ool006Yoo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eoo`00J7oo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`00Jgoo001VOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001YOol006Eoo`8000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYF001JEP0H0003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Moo`00H7oo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Moo`00GGoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0IGoo001KOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol005Uoo`<000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Egoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IGoo001FOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P006Goo3`00?Woo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH4000fOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
03=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP80031oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@000AJEP07
001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=o
o`0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00B7oo3@0000=JEP00FUH00eYF00<005YF
00000`000goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP<00003FUH0
05YF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool003moo`T000AJEP03001JEUYF00EJEP03001JEP0000AJ
EPL0009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00@0
05YF000000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00>Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000UYF0P000eYF00@005YFFUIJEQT000EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP09001JEUYFFUH005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00<7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00T005YFFUIJEP00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00;goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH70009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00@001Qoo`D000AJEP05001JEUYFFUH0000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05
001JEUYFFUH00005FUH00`00FUH0000>0004FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YF
FUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEUYF0004FUH00`00FUIJEP02FUH4000NOol200001UYF00000000FUH000=JEP8002aoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH60002FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF000010006Woo1P001EYF0`000eYF0P00;7oo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20002FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YF000010001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF20002Goo2@0015YF00<0
05YFFUH015YF00@005YFFUH0009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000=J
EP03001JEUYF00EJEP04001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1@0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@001=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@001Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEP0000<001]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP800003FUH005YF00@0011oo`T0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHH0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02eoo`03001JEP00009JEP8000=JEP03001JEUYF00=JEQ0000AJEP07001JEUYFFUH005YF00000eYF
00@005YFFUIJEPT000IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002eoo`03001JEP00008000EJEP03001JEUYF00EJEQ<000=JEP03001J
EP0000=JEPP00005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH01000
FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH0
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
0P00;goo000]Ool01@00FUH005YF00001EYF00<005YFFUH01P000eYF00<005YFFUH01eYF00@005YF
FUIJEPD00003FUH005YF008000AJEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70002FUH40003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00@0031oo`00;Goo0P000UYF00<005YFFUH00UYF100000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF4P000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo0P000eYF
00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`8000=JEP<000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP09001JEUYFFUH0
05YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`800003FUH00000009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02@00FUIJ
EUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^Ool30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF6P0000=JEP00FUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH0
1UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00=JEPh000Uoo`P000AJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH015YF0`001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000eYF100067oo1P0015YF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHE00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF20000eYF0`005Goo200000IJEP000000
05YF0002FUH2000/Ool002ioo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH0
1@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P0015YF00@005YFFUIJEQ/000AJEP03001JEUYF
00=JEP04001JEP000002FUH2000/Ool002ioo`03001JEP0000=JEPX0009JEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEP00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@002aoo`00;Woo00@0
05YF001JEP8000AJEP04001JEUYFFUHM0006FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;7oo000^Ool00`00FUH0
00020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`00;7oo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000^Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002eo
o`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0002FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUHB00000eYF001JEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJ
EP03001JEUYF00=JEQX0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00000`Ool002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2P00<Woo
000aOol30004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<7oo000_OolL0007FUH00`00FUIJEP05FUH01000FUIJEUYF1@0000Eo
o`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002eoo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0UYF5P001Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0001P000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH60005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01eYF5@001UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF4@0015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJ
EP03001JEUYF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001J
EUYF008002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000=JEP000000;Goo
000]Ool00`00FUH00002FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000040006FUH00`00FUIJEP02FUH20005FUH80004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo000]
Ool50006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YF00000UYF00@005YFFUIJEP8000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP@000AJEP8000AJEP03001JEUYF00AJEP03001JEUYF009JEP8000=oob<002ioo`00<7oo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YF
00000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2001DOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPH0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJ
EP03001JEUYF00<005Eoo`00>goo2@0015YF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF
FUH00eYF1000F7oo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF00000`00G7oo0017Ool5
00000goo0000000D00000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00007
001POol004Moo`D001Qoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH7
001LOol004Qoo`<001Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP05001GOol006Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000007FUH00`00FUIJEP03FUH00`00FUH00002001DOol006Eoo`03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001DOol0
06Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEPL000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001DOol006Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000=JEP03001JEUYF008005Aoo`00J7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP<000MJEP03001JEUYF00=J
EPD00003FUH0000005Aoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0008FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00E7oo001/Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0005Aoo`00Kgoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF8000EGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH700000goo00000003001_Ool007Uoo`/000IJEP03001JEUYF00YJEP04001J
EUYFFUH60008Ool5001_Ool008AooaL000moo`<0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59259 .75578 m .59475 .69904 L .56359 .69664 L p .707 .577 .707 r
F P
0 g
s
.59475 .69904 m .59259 .75578 L .6244 .75643 L p .707 .577 .707 r
F P
0 g
s
.6244 .75643 m .62656 .69969 L .59475 .69904 L p .707 .577 .707 r
F P
0 g
s
.62656 .69969 m .6244 .75643 L .65374 .75528 L p .707 .577 .707 r
F P
0 g
s
.65374 .75528 m .6559 .69853 L .62656 .69969 L p .707 .577 .707 r
F P
0 g
s
.56143 .75339 m .56359 .69664 L .53612 .69274 L p .707 .577 .707 r
F P
0 g
s
.56359 .69664 m .56143 .75339 L .59259 .75578 L p .707 .577 .707 r
F P
0 g
s
.6559 .69853 m .65374 .75528 L .67774 .75243 L p .707 .577 .707 r
F P
0 g
s
.67774 .75243 m .6799 .69568 L .6559 .69853 L p .707 .577 .707 r
F P
0 g
s
.53612 .69274 m .53396 .74949 L .56143 .75339 L p .707 .577 .707 r
F P
0 g
s
.59215 .83744 m .59191 .80055 L .56074 .79874 L p .707 .577 .707 r
F P
0 g
s
.59191 .80055 m .59215 .83744 L .62399 .83642 L p .707 .577 .707 r
F P
0 g
s
.62399 .83642 m .62374 .79954 L .59191 .80055 L p .707 .577 .707 r
F P
0 g
s
.53396 .74949 m .53612 .69274 L .51504 .68772 L p .707 .577 .707 r
F P
0 g
s
.62374 .79954 m .62399 .83642 L .65337 .83267 L p .707 .577 .707 r
F P
0 g
s
.65337 .83267 m .65312 .79579 L .62374 .79954 L p .707 .577 .707 r
F P
0 g
s
.56098 .83562 m .56074 .79874 L .53328 .79426 L p .707 .577 .707 r
F P
0 g
s
.56074 .79874 m .56098 .83562 L .59215 .83744 L p .707 .577 .707 r
F P
0 g
s
.51504 .68772 m .51288 .74446 L .53396 .74949 L p .707 .577 .707 r
F P
0 g
s
.65312 .79579 m .65337 .83267 L .67742 .82656 L p .707 .577 .707 r
F P
0 g
s
.67742 .82656 m .67718 .78967 L .65312 .79579 L p .707 .577 .707 r
F P
0 g
s
.6799 .69568 m .67774 .75243 L .69405 .74816 L p .707 .577 .707 r
F P
0 g
s
.69405 .74816 m .69621 .69141 L .6799 .69568 L p .707 .577 .707 r
F P
0 g
s
.53328 .79426 m .53352 .83115 L .56098 .83562 L p .707 .577 .707 r
F P
0 g
s
.53352 .83115 m .53328 .79426 L .51222 .78757 L p .707 .577 .707 r
F P
0 g
s
.51288 .74446 m .51504 .68772 L .5024 .68205 L p .707 .577 .707 r
F P
0 g
s
.59583 .88953 m .59446 .87227 L .56332 .87128 L p .707 .577 .707 r
F P
0 g
s
.59446 .87227 m .59583 .88953 L .62757 .88614 L p .707 .577 .707 r
F P
0 g
s
.62757 .88614 m .62619 .86888 L .59446 .87227 L p .707 .577 .707 r
F P
0 g
s
.62619 .86888 m .62757 .88614 L .65679 .87868 L p .707 .577 .707 r
F P
0 g
s
.65679 .87868 m .65542 .86142 L .62619 .86888 L p .707 .577 .707 r
F P
0 g
s
.51222 .78757 m .51247 .82445 L .53352 .83115 L p .707 .577 .707 r
F P
0 g
s
.56469 .88854 m .56332 .87128 L .53583 .86598 L p .707 .577 .707 r
F P
0 g
s
.56332 .87128 m .56469 .88854 L .59583 .88953 L p .707 .577 .707 r
F P
0 g
s
.67718 .78967 m .67742 .82656 L .69379 .81867 L p .707 .577 .707 r
F P
0 g
s
.69379 .81867 m .69354 .78179 L .67718 .78967 L p .707 .577 .707 r
F P
0 g
s
.5024 .68205 m .50024 .7388 L .51288 .74446 L p .707 .577 .707 r
F P
0 g
s
.65542 .86142 m .65679 .87868 L .68065 .86788 L p .707 .577 .707 r
F P
0 g
s
.68065 .86788 m .67928 .85062 L .65542 .86142 L p .707 .577 .707 r
F P
0 g
s
.53583 .86598 m .5372 .88324 L .56469 .88854 L p .707 .577 .707 r
F P
0 g
s
.69621 .69141 m .69405 .74816 L .70107 .7429 L p .707 .577 .707 r
F P
0 g
s
.70107 .7429 m .70323 .68615 L .69621 .69141 L p .707 .577 .707 r
F P
0 g
s
.51247 .82445 m .51222 .78757 L .49963 .77931 L p .707 .577 .707 r
F P
0 g
s
.5372 .88324 m .53583 .86598 L .51467 .85691 L p .707 .577 .707 r
F P
0 g
s
.50024 .7388 m .5024 .68205 L .49945 .67631 L p .707 .577 .707 r
F P
0 g
s
.49963 .77931 m .49987 .8162 L .51247 .82445 L p .707 .577 .707 r
F P
0 g
s
.67928 .85062 m .68065 .86788 L .6968 .85481 L p .707 .577 .707 r
F P
0 g
s
.6968 .85481 m .69543 .83755 L .67928 .85062 L p .707 .577 .707 r
F P
0 g
s
.51467 .85691 m .51605 .87417 L .5372 .88324 L p .707 .577 .707 r
F P
0 g
s
.69354 .78179 m .69379 .81867 L .70087 .80979 L p .707 .577 .707 r
F P
0 g
s
.70087 .80979 m .70062 .7729 L .69354 .78179 L p .707 .577 .707 r
F P
0 g
s
.49945 .67631 m .49729 .73306 L .50024 .7388 L p .707 .577 .707 r
F P
0 g
s
.51605 .87417 m .51467 .85691 L .50192 .84494 L p .707 .577 .707 r
F P
0 g
s
.70323 .68615 m .70107 .7429 L .69812 .73716 L p .707 .577 .707 r
F P
0 g
s
.69812 .73716 m .70028 .68041 L .70323 .68615 L p .707 .577 .707 r
F P
0 g
s
.49987 .8162 m .49963 .77931 L .49673 .7703 L p .707 .577 .707 r
F P
0 g
s
.50192 .84494 m .5033 .8622 L .51605 .87417 L p .707 .577 .707 r
F P
0 g
s
.69543 .83755 m .6968 .85481 L .70366 .84075 L p .707 .577 .707 r
F P
0 g
s
.70366 .84075 m .70229 .82349 L .69543 .83755 L p .707 .577 .707 r
F P
0 g
s
.49673 .7703 m .49697 .80719 L .49987 .8162 L p .707 .577 .707 r
F P
0 g
s
.49729 .73306 m .49945 .67631 L .50648 .67105 L p .707 .577 .707 r
F P
0 g
s
.70062 .7729 m .70087 .80979 L .69797 .80078 L p .707 .577 .707 r
F P
0 g
s
.69797 .80078 m .69773 .76389 L .70062 .7729 L p .707 .577 .707 r
F P
0 g
s
.49238 .81834 m .49555 .3144 L .45154 .3116 L p .707 .577 .707 r
F P
0 g
s
.50648 .67105 m .50432 .7278 L .49729 .73306 L p .707 .577 .707 r
F P
0 g
s
.49697 .80719 m .49673 .7703 L .50381 .76142 L p .707 .577 .707 r
F P
0 g
s
.50381 .76142 m .50406 .79831 L .49697 .80719 L p .707 .577 .707 r
F P
0 g
s
.50432 .7278 m .50648 .67105 L .52279 .66679 L p .707 .577 .707 r
F P
0 g
s
.52279 .66679 m .52063 .72353 L .50432 .7278 L p .707 .577 .707 r
F P
0 g
s
.5033 .8622 m .50192 .84494 L .49883 .83126 L p .707 .577 .707 r
F P
0 g
s
.49883 .83126 m .5002 .84852 L .5033 .8622 L p .707 .577 .707 r
F P
0 g
s
.5002 .84852 m .49883 .83126 L .50569 .81719 L p .707 .577 .707 r
F P
0 g
s
.50406 .79831 m .50381 .76142 L .52018 .75354 L p .707 .577 .707 r
F P
0 g
s
.50569 .81719 m .50707 .83445 L .5002 .84852 L p .707 .577 .707 r
F P
0 g
s
.52063 .72353 m .52279 .66679 L .54678 .66393 L p .707 .577 .707 r
F P
0 g
s
.52018 .75354 m .52042 .79042 L .50406 .79831 L p .707 .577 .707 r
F P
0 g
s
.54678 .66393 m .54463 .72068 L .52063 .72353 L p .707 .577 .707 r
F P
0 g
s
.50707 .83445 m .50569 .81719 L .52184 .80412 L p .707 .577 .707 r
F P
0 g
s
.52042 .79042 m .52018 .75354 L .54423 .74742 L p .707 .577 .707 r
F P
0 g
s
.52184 .80412 m .52322 .82138 L .50707 .83445 L p .707 .577 .707 r
F P
0 g
s
.54423 .74742 m .54447 .7843 L .52042 .79042 L p .707 .577 .707 r
F P
0 g
s
.52322 .82138 m .52184 .80412 L .5457 .79333 L p .707 .577 .707 r
F P
0 g
s
.5457 .79333 m .54707 .81059 L .52322 .82138 L p .707 .577 .707 r
F P
0 g
s
.49555 .3144 m .49238 .81834 L .53733 .81756 L p .707 .577 .707 r
F P
0 g
s
.53733 .81756 m .54049 .31362 L .49555 .3144 L p .707 .577 .707 r
F P
0 g
s
.54463 .72068 m .54678 .66393 L .57612 .66278 L p .707 .577 .707 r
F P
0 g
s
.57612 .66278 m .57397 .71953 L .54463 .72068 L p .707 .577 .707 r
F P
0 g
s
.54447 .7843 m .54423 .74742 L .57361 .74367 L p .707 .577 .707 r
F P
0 g
s
.57361 .74367 m .57385 .78055 L .54447 .7843 L p .707 .577 .707 r
F P
0 g
s
.57385 .78055 m .57361 .74367 L .60545 .74265 L p .707 .577 .707 r
F P
0 g
s
.60545 .74265 m .60569 .77954 L .57385 .78055 L p .707 .577 .707 r
F P
0 g
s
.54707 .81059 m .5457 .79333 L .57493 .78587 L p .707 .577 .707 r
F P
0 g
s
.57493 .78587 m .5763 .80313 L .54707 .81059 L p .707 .577 .707 r
F P
0 g
s
.5763 .80313 m .57493 .78587 L .60666 .78247 L p .707 .577 .707 r
F P
0 g
s
.60666 .78247 m .60803 .79973 L .5763 .80313 L p .707 .577 .707 r
F P
0 g
s
.54049 .31362 m .53733 .81756 L .57881 .8133 L p .707 .577 .707 r
F P
0 g
s
.57397 .71953 m .57612 .66278 L .60793 .66343 L p .707 .577 .707 r
F P
0 g
s
.60793 .66343 m .60577 .72017 L .57397 .71953 L p .707 .577 .707 r
F P
0 g
s
.57881 .8133 m .58197 .30936 L .54049 .31362 L p .707 .577 .707 r
F P
0 g
s
.44838 .81554 m .45154 .3116 L .41277 .30551 L p .707 .577 .707 r
F P
0 g
s
.45154 .3116 m .44838 .81554 L .49238 .81834 L p .707 .577 .707 r
F P
0 g
s
.70028 .68041 m .69812 .73716 L .68549 .73149 L p .707 .577 .707 r
F P
0 g
s
.68549 .73149 m .68765 .67475 L .70028 .68041 L p .707 .577 .707 r
F P
0 g
s
.70229 .82349 m .70366 .84075 L .70057 .82706 L p .707 .577 .707 r
F P
0 g
s
.70057 .82706 m .6992 .8098 L .70229 .82349 L p .707 .577 .707 r
F P
0 g
s
.24958 .71897 m .25174 .66222 L .22058 .65983 L p .707 .577 .707 r
F P
0 g
s
.25174 .66222 m .24958 .71897 L .28139 .71962 L p .707 .577 .707 r
F P
0 g
s
.28139 .71962 m .28355 .66287 L .25174 .66222 L p .707 .577 .707 r
F P
0 g
s
.28355 .66287 m .28139 .71962 L .31073 .71846 L p .707 .577 .707 r
F P
0 g
s
.31073 .71846 m .31289 .66171 L .28355 .66287 L p .707 .577 .707 r
F P
0 g
s
.6391 .66582 m .63694 .72257 L .60577 .72017 L p .707 .577 .707 r
F P
0 g
s
.60577 .72017 m .60793 .66343 L .6391 .66582 L p .707 .577 .707 r
F P
0 g
s
.63662 .74447 m .63686 .78136 L .60569 .77954 L p .707 .577 .707 r
F P
0 g
s
.60569 .77954 m .60545 .74265 L .63662 .74447 L p .707 .577 .707 r
F P
0 g
s
.6378 .78347 m .63917 .80073 L .60803 .79973 L p .707 .577 .707 r
F P
0 g
s
.60803 .79973 m .60666 .78247 L .6378 .78347 L p .707 .577 .707 r
F P
0 g
s
.58197 .30936 m .57881 .8133 L .61276 .80596 L p .707 .577 .707 r
F P
0 g
s
.61276 .80596 m .61592 .30201 L .58197 .30936 L p .707 .577 .707 r
F P
0 g
s
.21842 .71658 m .22058 .65983 L .19311 .65593 L p .707 .577 .707 r
F P
0 g
s
.22058 .65983 m .21842 .71658 L .24958 .71897 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69773 .76389 m .69797 .80078 L .68538 .79252 L p .707 .577 .707 r
F P
0 g
s
.68538 .79252 m .68513 .75564 L .69773 .76389 L p .707 .577 .707 r
F P
0 g
s
.40961 .80945 m .41277 .30551 L .38305 .29672 L p .707 .577 .707 r
F P
0 g
s
.41277 .30551 m .40961 .80945 L .44838 .81554 L p .707 .577 .707 r
F P
0 g
s
.31289 .66171 m .31073 .71846 L .33473 .71561 L p .707 .577 .707 r
F P
0 g
s
.33473 .71561 m .33689 .65886 L .31289 .66171 L p .707 .577 .707 r
F P
0 g
s
.19311 .65593 m .19095 .71268 L .21842 .71658 L p .707 .577 .707 r
F P
0 g
s
.24914 .80062 m .2489 .76374 L .21773 .76192 L p .707 .577 .707 r
F P
0 g
s
.2489 .76374 m .24914 .80062 L .28098 .79961 L p .707 .577 .707 r
F P
0 g
s
.28098 .79961 m .28073 .76272 L .2489 .76374 L p .707 .577 .707 r
F P
0 g
s
.68765 .67475 m .68549 .73149 L .6644 .72647 L p .707 .577 .707 r
F P
0 g
s
.6644 .72647 m .66656 .66972 L .68765 .67475 L p .707 .577 .707 r
F P
0 g
s
.19095 .71268 m .19311 .65593 L .17203 .6509 L p .707 .577 .707 r
F P
0 g
s
.28073 .76272 m .28098 .79961 L .31036 .79586 L p .707 .577 .707 r
F P
0 g
s
.31036 .79586 m .31012 .75897 L .28073 .76272 L p .707 .577 .707 r
F P
0 g
s
.6992 .8098 m .70057 .82706 L .68782 .8151 L p .707 .577 .707 r
F P
0 g
s
.68782 .8151 m .68645 .79784 L .6992 .8098 L p .707 .577 .707 r
F P
0 g
s
.21797 .79881 m .21773 .76192 L .19027 .75745 L p .707 .577 .707 r
F P
0 g
s
.21773 .76192 m .21797 .79881 L .24914 .80062 L p .707 .577 .707 r
F P
0 g
s
.17203 .6509 m .16987 .70765 L .19095 .71268 L p .707 .577 .707 r
F P
0 g
s
.61592 .30201 m .61276 .80596 L .63587 .79626 L p .707 .577 .707 r
F P
0 g
s
.63587 .79626 m .63903 .29231 L .61592 .30201 L p .707 .577 .707 r
F P
0 g
s
.31012 .75897 m .31036 .79586 L .33441 .78974 L p .707 .577 .707 r
F P
0 g
s
.33441 .78974 m .33417 .75286 L .31012 .75897 L p .707 .577 .707 r
F P
0 g
s
.33689 .65886 m .33473 .71561 L .35104 .71135 L p .707 .577 .707 r
F P
0 g
s
.35104 .71135 m .3532 .6546 L .33689 .65886 L p .707 .577 .707 r
F P
0 g
s
.68513 .75564 m .68538 .79252 L .66432 .78583 L p .707 .577 .707 r
F P
0 g
s
.66432 .78583 m .66408 .74895 L .68513 .75564 L p .707 .577 .707 r
F P
0 g
s
.19027 .75745 m .19051 .79433 L .21797 .79881 L p .707 .577 .707 r
F P
0 g
s
.19051 .79433 m .19027 .75745 L .16921 .75075 L p .707 .577 .707 r
F P
0 g
s
.66656 .66972 m .6644 .72647 L .63694 .72257 L p .707 .577 .707 r
F P
0 g
s
.63694 .72257 m .6391 .66582 L .66656 .66972 L p .707 .577 .707 r
F P
0 g
s
.16987 .70765 m .17203 .6509 L .15939 .64524 L p .707 .577 .707 r
F P
0 g
s
.25282 .85272 m .25145 .83546 L .22031 .83446 L p .707 .577 .707 r
F P
0 g
s
.25145 .83546 m .25282 .85272 L .28456 .84932 L p .707 .577 .707 r
F P
0 g
s
.28456 .84932 m .28319 .83206 L .25145 .83546 L p .707 .577 .707 r
F P
0 g
s
.37988 .80067 m .38305 .29672 L .36527 .2861 L p .707 .577 .707 r
F P
0 g
s
.38305 .29672 m .37988 .80067 L .40961 .80945 L p .707 .577 .707 r
F P
0 g
s
.28319 .83206 m .28456 .84932 L .31378 .84186 L p .707 .577 .707 r
F P
0 g
s
.31378 .84186 m .31241 .8246 L .28319 .83206 L p .707 .577 .707 r
F P
0 g
s
.68645 .79784 m .68782 .8151 L .66666 .80602 L p .707 .577 .707 r
F P
0 g
s
.66666 .80602 m .66529 .78876 L .68645 .79784 L p .707 .577 .707 r
F P
0 g
s
.16921 .75075 m .16946 .78764 L .19051 .79433 L p .707 .577 .707 r
F P
0 g
s
.22169 .85172 m .22031 .83446 L .19282 .82917 L p .707 .577 .707 r
F P
0 g
s
.22031 .83446 m .22169 .85172 L .25282 .85272 L p .707 .577 .707 r
F P
0 g
s
.33417 .75286 m .33441 .78974 L .35078 .78186 L p .707 .577 .707 r
F P
0 g
s
.35078 .78186 m .35053 .74497 L .33417 .75286 L p .707 .577 .707 r
F P
0 g
s
.15939 .64524 m .15724 .70199 L .16987 .70765 L p .707 .577 .707 r
F P
0 g
s
.31241 .8246 m .31378 .84186 L .33764 .83107 L p .707 .577 .707 r
F P
0 g
s
.33764 .83107 m .33627 .81381 L .31241 .8246 L p .707 .577 .707 r
F P
0 g
s
.66408 .74895 m .66432 .78583 L .63686 .78136 L p .707 .577 .707 r
F P
0 g
s
.63686 .78136 m .63662 .74447 L .66408 .74895 L p .707 .577 .707 r
F P
0 g
s
.19282 .82917 m .19419 .84643 L .22169 .85172 L p .707 .577 .707 r
F P
0 g
s
.3532 .6546 m .35104 .71135 L .35806 .70608 L p .707 .577 .707 r
F P
0 g
s
.35806 .70608 m .36022 .64934 L .3532 .6546 L p .707 .577 .707 r
F P
0 g
s
.16946 .78764 m .16921 .75075 L .15662 .7425 L p .707 .577 .707 r
F P
0 g
s
.19419 .84643 m .19282 .82917 L .17166 .82009 L p .707 .577 .707 r
F P
0 g
s
.63917 .80073 m .6378 .78347 L .66529 .78876 L p .707 .577 .707 r
F P
0 g
s
.63903 .29231 m .63587 .79626 L .64587 .78515 L p .707 .577 .707 r
F P
0 g
s
.64587 .78515 m .64903 .28121 L .63903 .29231 L p .707 .577 .707 r
F P
0 g
s
.15724 .70199 m .15939 .64524 L .15644 .6395 L p .707 .577 .707 r
F P
0 g
s
.66529 .78876 m .66666 .80602 L .63917 .80073 L p .707 .577 .707 r
F P
0 g
s
.15662 .7425 m .15686 .77938 L .16946 .78764 L p .707 .577 .707 r
F P
0 g
s
.33627 .81381 m .33764 .83107 L .35379 .818 L p .707 .577 .707 r
F P
0 g
s
.35379 .818 m .35242 .80074 L .33627 .81381 L p .707 .577 .707 r
F P
0 g
s
.17166 .82009 m .17304 .83735 L .19419 .84643 L p .707 .577 .707 r
F P
0 g
s
.35053 .74497 m .35078 .78186 L .35786 .77297 L p .707 .577 .707 r
F P
0 g
s
.35786 .77297 m .35761 .73609 L .35053 .74497 L p .707 .577 .707 r
F P
0 g
s
.15644 .6395 m .15428 .69624 L .15724 .70199 L p .707 .577 .707 r
F P
0 g
s
.36211 .79004 m .36527 .2861 L .36118 .27467 L p .707 .577 .707 r
F P
0 g
s
.36527 .2861 m .36211 .79004 L .37988 .80067 L p .707 .577 .707 r
F P
0 g
s
.17304 .83735 m .17166 .82009 L .15891 .80813 L p .707 .577 .707 r
F P
0 g
s
.36022 .64934 m .35806 .70608 L .35511 .70034 L p .707 .577 .707 r
F P
0 g
s
.35511 .70034 m .35727 .64359 L .36022 .64934 L p .707 .577 .707 r
F P
0 g
s
.15686 .77938 m .15662 .7425 L .15372 .73349 L p .707 .577 .707 r
F P
0 g
s
.15891 .80813 m .16029 .82539 L .17304 .83735 L p .707 .577 .707 r
F P
0 g
s
.35242 .80074 m .35379 .818 L .36065 .80393 L p .707 .577 .707 r
F P
0 g
s
.36065 .80393 m .35928 .78667 L .35242 .80074 L p .707 .577 .707 r
F P
0 g
s
.15372 .73349 m .15396 .77037 L .15686 .77938 L p .707 .577 .707 r
F P
0 g
s
.15428 .69624 m .15644 .6395 L .16347 .63423 L p .707 .577 .707 r
F P
0 g
s
.35761 .73609 m .35786 .77297 L .35496 .76396 L p .707 .577 .707 r
F P
0 g
s
.35496 .76396 m .35472 .72708 L .35761 .73609 L p .707 .577 .707 r
F P
0 g
s
.64903 .28121 m .64587 .78515 L .64284 .77671 L p .707 .577 .707 r
F P
0 g
s
.64236 .73417 m .64903 .28121 L .64284 .77671 L .707 .577 .707 r
F
.64236 .73417 m .64398 .4421 L .64903 .28121 L F
.64214 .71524 m .64375 .45876 L p .64236 .73417 L F P
0 g
s
.64375 .45876 m .64494 .26978 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64375 .45876 m .64398 .4421 L .64236 .73417 L .707 .577 .707 r
F
.64494 .26978 m .64177 .77373 L .624 .7631 L p F P
0 g
s
.63683 .64064 m .63708 .67752 L .64072 .67991 L p .707 .577 .707 r
F P
0 g
s
.64072 .67991 m .64967 .68578 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64105 .65547 m .63683 .64064 L .64072 .67991 L .707 .577 .707 r
F
.64967 .68578 m .64943 .64889 L .64122 .64351 L p F P
0 g
s
.64122 .64351 m .63683 .64064 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64967 .68578 m .64122 .64351 L .64105 .65547 L .707 .577 .707 r
F
.64494 .26978 m .64629 .27357 L p .64398 .4421 L F P
0 g
s
.64629 .27357 m .64903 .28121 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64177 .77373 m .64214 .71524 L p .64236 .73417 L .707 .577 .707 r
F P
0 g
s
.63961 .56304 m .63745 .61979 L .64107 .62142 L p .707 .577 .707 r
F P
0 g
s
.64107 .62142 m .65008 .62545 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.64047 .56817 m .63961 .56304 L .64107 .62142 L .707 .577 .707 r
F
.65008 .62545 m .65224 .56871 L .64041 .5634 L p F P
0 g
s
.64041 .5634 m .63961 .56304 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.65008 .62545 m .64041 .5634 L .64047 .56817 L .707 .577 .707 r
F
.64284 .77671 m .64177 .77373 L p .64236 .73417 L F P
0 g
s
.16347 .63423 m .16131 .69098 L .15428 .69624 L p .707 .577 .707 r
F P
0 g
s
.16029 .82539 m .15891 .80813 L .15582 .79444 L p .707 .577 .707 r
F P
0 g
s
.15396 .77037 m .15372 .73349 L .1608 .72461 L p .707 .577 .707 r
F P
0 g
s
.35727 .64359 m .35511 .70034 L .34248 .69468 L p .707 .577 .707 r
F P
0 g
s
.34248 .69468 m .34464 .63793 L .35727 .64359 L p .707 .577 .707 r
F P
0 g
s
.15582 .79444 m .15719 .8117 L .16029 .82539 L p .707 .577 .707 r
F P
0 g
s
.35928 .78667 m .36065 .80393 L .35756 .79025 L p .707 .577 .707 r
F P
0 g
s
.35756 .79025 m .35619 .77299 L .35928 .78667 L p .707 .577 .707 r
F P
0 g
s
.36118 .27467 m .35801 .77861 L .36211 .79004 L p .707 .577 .707 r
F P
0 g
s
.35801 .77861 m .36118 .27467 L .37117 .26357 L p .707 .577 .707 r
F P
0 g
s
.1608 .72461 m .16105 .76149 L .15396 .77037 L p .707 .577 .707 r
F P
0 g
s
.16131 .69098 m .16347 .63423 L .17978 .62997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35472 .72708 m .35496 .76396 L .34237 .75571 L p .707 .577 .707 r
F P
0 g
s
.34237 .75571 m .34212 .71882 L .35472 .72708 L p .707 .577 .707 r
F P
0 g
s
.17978 .62997 m .17762 .68672 L .16131 .69098 L p .707 .577 .707 r
F P
0 g
s
.15719 .8117 m .15582 .79444 L .16268 .78037 L p .707 .577 .707 r
F P
0 g
s
.34464 .63793 m .34248 .69468 L .32139 .68965 L p .707 .577 .707 r
F P
0 g
s
.32139 .68965 m .32355 .6329 L .34464 .63793 L p .707 .577 .707 r
F P
0 g
s
.16105 .76149 m .1608 .72461 L .17717 .71672 L p .707 .577 .707 r
F P
0 g
s
.16268 .78037 m .16406 .79764 L .15719 .8117 L p .707 .577 .707 r
F P
0 g
s
.624 .7631 m .62716 .25916 L .64494 .26978 L p .707 .577 .707 r
F P
0 g
s
.35619 .77299 m .35756 .79025 L .34481 .77828 L p .707 .577 .707 r
F P
0 g
s
.34481 .77828 m .34344 .76102 L .35619 .77299 L p .707 .577 .707 r
F P
0 g
s
.17762 .68672 m .17978 .62997 L .20377 .62712 L p .707 .577 .707 r
F P
0 g
s
.17717 .71672 m .17741 .75361 L .16105 .76149 L p .707 .577 .707 r
F P
0 g
s
.34212 .71882 m .34237 .75571 L .32131 .74902 L p .707 .577 .707 r
F P
0 g
s
.32131 .74902 m .32107 .71213 L .34212 .71882 L p .707 .577 .707 r
F P
0 g
s
.36801 .76751 m .37117 .26357 L .39428 .25387 L p .707 .577 .707 r
F P
0 g
s
.37117 .26357 m .36801 .76751 L .35801 .77861 L p .707 .577 .707 r
F P
0 g
s
.20377 .62712 m .20162 .68387 L .17762 .68672 L p .707 .577 .707 r
F P
0 g
s
.16406 .79764 m .16268 .78037 L .17883 .76731 L p .707 .577 .707 r
F P
0 g
s
.32355 .6329 m .32139 .68965 L .29393 .68575 L p .707 .577 .707 r
F P
0 g
s
.29393 .68575 m .29609 .629 L .32355 .6329 L p .707 .577 .707 r
F P
0 g
s
.17741 .75361 m .17717 .71672 L .20122 .7106 L p .707 .577 .707 r
F P
0 g
s
.17883 .76731 m .18021 .78457 L .16406 .79764 L p .707 .577 .707 r
F P
0 g
s
.20162 .68387 m .20377 .62712 L .23311 .62596 L p .707 .577 .707 r
F P
0 g
s
.34344 .76102 m .34481 .77828 L .32365 .76921 L p .707 .577 .707 r
F P
0 g
s
.32365 .76921 m .32228 .75195 L .34344 .76102 L p .707 .577 .707 r
F P
0 g
s
.7298 .63677 m .73196 .58003 L .70079 .57763 L p .707 .577 .707 r
F P
0 g
s
.73196 .58003 m .7298 .63677 L .76161 .63742 L p .707 .577 .707 r
F P
0 g
s
.76161 .63742 m .76376 .58068 L .73196 .58003 L p .707 .577 .707 r
F P
0 g
s
.20122 .7106 m .20146 .74749 L .17741 .75361 L p .707 .577 .707 r
F P
0 g
s
.32107 .71213 m .32131 .74902 L .29385 .74454 L p .707 .577 .707 r
F P
0 g
s
.29385 .74454 m .29361 .70766 L .32107 .71213 L p .707 .577 .707 r
F P
0 g
s
.76376 .58068 m .76161 .63742 L .79094 .63627 L p .707 .577 .707 r
F P
0 g
s
.79094 .63627 m .7931 .57952 L .76376 .58068 L p .707 .577 .707 r
F P
0 g
s
.29609 .629 m .29393 .68575 L .26276 .68336 L p .707 .577 .707 r
F P
0 g
s
.26276 .68336 m .26492 .62661 L .29609 .629 L p .707 .577 .707 r
F P
0 g
s
.23311 .62596 m .23096 .68271 L .20162 .68387 L p .707 .577 .707 r
F P
0 g
s
.62716 .25916 m .624 .7631 L .59427 .75431 L p .707 .577 .707 r
F P
0 g
s
.59427 .75431 m .59743 .25037 L .62716 .25916 L p .707 .577 .707 r
F P
0 g
s
.69863 .63438 m .70079 .57763 L .67332 .57373 L p .707 .577 .707 r
F P
0 g
s
.70079 .57763 m .69863 .63438 L .7298 .63677 L p .707 .577 .707 r
F P
0 g
s
.23096 .68271 m .23311 .62596 L .26492 .62661 L p .707 .577 .707 r
F P
0 g
s
.18021 .78457 m .17883 .76731 L .20269 .75651 L p .707 .577 .707 r
F P
0 g
s
.26492 .62661 m .26276 .68336 L .23096 .68271 L p .707 .577 .707 r
F P
0 g
s
.20146 .74749 m .20122 .7106 L .2306 .70685 L p .707 .577 .707 r
F P
0 g
s
.72936 .69876 m .72911 .66188 L .69794 .66006 L p .707 .577 .707 r
F P
0 g
s
.72911 .66188 m .72936 .69876 L .76119 .69775 L p .707 .577 .707 r
F P
0 g
s
.76119 .69775 m .76095 .66086 L .72911 .66188 L p .707 .577 .707 r
F P
0 g
s
.7931 .57952 m .79094 .63627 L .81494 .63342 L p .707 .577 .707 r
F P
0 g
s
.81494 .63342 m .8171 .57667 L .7931 .57952 L p .707 .577 .707 r
F P
0 g
s
.67332 .57373 m .67117 .63048 L .69863 .63438 L p .707 .577 .707 r
F P
0 g
s
.32228 .75195 m .32365 .76921 L .29616 .76391 L p .707 .577 .707 r
F P
0 g
s
.29616 .76391 m .29479 .74665 L .32228 .75195 L p .707 .577 .707 r
F P
0 g
s
.20269 .75651 m .20406 .77377 L .18021 .78457 L p .707 .577 .707 r
F P
0 g
s
.76095 .66086 m .76119 .69775 L .79057 .694 L p .707 .577 .707 r
F P
0 g
s
.79057 .694 m .79033 .65711 L .76095 .66086 L p .707 .577 .707 r
F P
0 g
s
.29361 .70766 m .29385 .74454 L .26268 .74272 L p .707 .577 .707 r
F P
0 g
s
.26268 .74272 m .26244 .70584 L .29361 .70766 L p .707 .577 .707 r
F P
0 g
s
.39428 .25387 m .39112 .75781 L .36801 .76751 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .39428 .25387 L .42824 .24652 L p .707 .577 .707 r
F P
0 g
s
.2306 .70685 m .23085 .74374 L .20146 .74749 L p .707 .577 .707 r
F P
0 g
s
.69818 .69694 m .69794 .66006 L .67048 .65558 L p .707 .577 .707 r
F P
0 g
s
.69794 .66006 m .69818 .69694 L .72936 .69876 L p .707 .577 .707 r
F P
0 g
s
.67117 .63048 m .67332 .57373 L .65224 .56871 L p .707 .577 .707 r
F P
0 g
s
.23085 .74374 m .2306 .70685 L .26244 .70584 L p .707 .577 .707 r
F P
0 g
s
.26244 .70584 m .26268 .74272 L .23085 .74374 L p .707 .577 .707 r
F P
0 g
s
.20406 .77377 m .20269 .75651 L .23192 .74905 L p .707 .577 .707 r
F P
0 g
s
.79033 .65711 m .79057 .694 L .81462 .68788 L p .707 .577 .707 r
F P
0 g
s
.81462 .68788 m .81438 .65099 L .79033 .65711 L p .707 .577 .707 r
F P
0 g
s
.29479 .74665 m .29616 .76391 L .26502 .76292 L p .707 .577 .707 r
F P
0 g
s
.26502 .76292 m .26365 .74565 L .29479 .74665 L p .707 .577 .707 r
F P
0 g
s
.65224 .56871 m .65008 .62545 L .67117 .63048 L p .707 .577 .707 r
F P
0 g
s
.67048 .65558 m .67073 .69247 L .69818 .69694 L p .707 .577 .707 r
F P
0 g
s
.23192 .74905 m .23329 .76631 L .20406 .77377 L p .707 .577 .707 r
F P
0 g
s
.8171 .57667 m .81494 .63342 L .83125 .62915 L p .707 .577 .707 r
F P
0 g
s
.83125 .62915 m .83341 .5724 L .8171 .57667 L p .707 .577 .707 r
F P
0 g
s
.67073 .69247 m .67048 .65558 L .64943 .64889 L p .707 .577 .707 r
F P
0 g
s
.23329 .76631 m .23192 .74905 L .26365 .74565 L p .707 .577 .707 r
F P
0 g
s
.59743 .25037 m .59427 .75431 L .5555 .74822 L p .707 .577 .707 r
F P
0 g
s
.5555 .74822 m .55867 .24428 L .59743 .25037 L p .707 .577 .707 r
F P
0 g
s
.26365 .74565 m .26502 .76292 L .23329 .76631 L p .707 .577 .707 r
F P
0 g
s
.73304 .75786 m .73166 .7406 L .70053 .7396 L p .707 .577 .707 r
F P
0 g
s
.73166 .7406 m .73304 .75786 L .76477 .75446 L p .707 .577 .707 r
F P
0 g
s
.76477 .75446 m .7634 .7372 L .73166 .7406 L p .707 .577 .707 r
F P
0 g
s
.7634 .7372 m .76477 .75446 L .794 .747 L p .707 .577 .707 r
F P
0 g
s
.794 .747 m .79262 .72974 L .7634 .7372 L p .707 .577 .707 r
F P
0 g
s
.64943 .64889 m .64967 .68578 L .67073 .69247 L p .707 .577 .707 r
F P
0 g
s
.42507 .75047 m .42824 .24652 L .46971 .24226 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .42171 .33646 L .42544 .69198 L .707 .577 .707 r
F
.42824 .24652 m .42705 .4355 L p .42171 .33646 L F P
0 g
s
.42705 .4355 m .42544 .69198 L p .42171 .33646 L .707 .577 .707 r
F P
0 g
s
.46971 .24226 m .46655 .7462 L .42507 .75047 L p .707 .577 .707 r
F P
0 g
s
.41794 .62405 m .41818 .66093 L .43907 .65827 L p .707 .577 .707 r
F P
0 g
s
.43907 .65827 m .44756 .65718 L p .43846 .647 L .707 .577 .707 r
F P
0 g
s
.43846 .647 m .41794 .62405 L .43907 .65827 L .707 .577 .707 r
F
.42075 .54386 m .4186 .60061 L .43952 .59978 L p F P
0 g
s
.43952 .59978 m .44794 .59945 L p .44156 .58641 L .707 .577 .707 r
F P
0 g
s
.44156 .58641 m .42075 .54386 L .43952 .59978 L .707 .577 .707 r
F
.42544 .69198 m .42507 .75047 L .41622 .75238 L p F P
0 g
s
.41622 .75238 m .39112 .75781 L p .42544 .69198 L .707 .577 .707 r
F P
0 g
s
.81438 .65099 m .81462 .68788 L .83099 .67999 L p .707 .577 .707 r
F P
0 g
s
.83099 .67999 m .83075 .64311 L .81438 .65099 L p .707 .577 .707 r
F P
0 g
s
.7019 .75686 m .70053 .7396 L .67303 .73431 L p .707 .577 .707 r
F P
0 g
s
.70053 .7396 m .7019 .75686 L .73304 .75786 L p .707 .577 .707 r
F P
0 g
s
.79262 .72974 m .794 .747 L .81785 .73621 L p .707 .577 .707 r
F P
0 g
s
.81785 .73621 m .81648 .71895 L .79262 .72974 L p .707 .577 .707 r
F P
0 g
s
.67303 .73431 m .67441 .75157 L .7019 .75686 L p .707 .577 .707 r
F P
0 g
s
.55867 .24428 m .5555 .74822 L .5115 .74543 L p .707 .577 .707 r
F P
0 g
s
.5115 .74543 m .51466 .24148 L .55867 .24428 L p .707 .577 .707 r
F P
0 g
s
.83341 .5724 m .83125 .62915 L .83828 .62389 L p .707 .577 .707 r
F P
0 g
s
.83828 .62389 m .84044 .56714 L .83341 .5724 L p .707 .577 .707 r
F P
0 g
s
.67441 .75157 m .67303 .73431 L .65188 .72523 L p .707 .577 .707 r
F P
0 g
s
.46655 .7462 m .46971 .24226 L .51466 .24148 L p .707 .577 .707 r
F P
0 g
s
.51466 .24148 m .5115 .74543 L .46655 .7462 L p .707 .577 .707 r
F P
0 g
s
.81648 .71895 m .81785 .73621 L .834 .72314 L p .707 .577 .707 r
F P
0 g
s
.834 .72314 m .83263 .70588 L .81648 .71895 L p .707 .577 .707 r
F P
0 g
s
.63745 .61979 m .63961 .56304 L .63666 .5573 L p .707 .577 .707 r
F P
0 g
s
.65188 .72523 m .65325 .74249 L .67441 .75157 L p .707 .577 .707 r
F P
0 g
s
.83075 .64311 m .83099 .67999 L .83807 .67111 L p .707 .577 .707 r
F P
0 g
s
.83807 .67111 m .83783 .63423 L .83075 .64311 L p .707 .577 .707 r
F P
0 g
s
.63666 .5573 m .6345 .61405 L .63745 .61979 L p .707 .577 .707 r
F P
0 g
s
.65325 .74249 m .65188 .72523 L .63913 .71327 L p .707 .577 .707 r
F P
0 g
s
.63708 .67752 m .63683 .64064 L .63393 .63163 L p .707 .577 .707 r
F P
0 g
s
.84044 .56714 m .83828 .62389 L .83533 .61815 L p .707 .577 .707 r
F P
0 g
s
.83533 .61815 m .83749 .5614 L .84044 .56714 L p .707 .577 .707 r
F P
0 g
s
.63913 .71327 m .6405 .73053 L .65325 .74249 L p .707 .577 .707 r
F P
0 g
s
.83263 .70588 m .834 .72314 L .84087 .70907 L p .707 .577 .707 r
F P
0 g
s
.84087 .70907 m .83949 .69181 L .83263 .70588 L p .707 .577 .707 r
F P
0 g
s
.63393 .63163 m .63418 .66851 L .63708 .67752 L p .707 .577 .707 r
F P
0 g
s
.6345 .61405 m .63666 .5573 L .64368 .55204 L p .707 .577 .707 r
F P
0 g
s
.83783 .63423 m .83807 .67111 L .83517 .6621 L p .707 .577 .707 r
F P
0 g
s
.83517 .6621 m .83493 .62522 L .83783 .63423 L p .707 .577 .707 r
F P
0 g
s
.6405 .73053 m .63913 .71327 L .63603 .69958 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64368 .55204 m .64152 .60879 L .6345 .61405 L p .707 .577 .707 r
F P
0 g
s
.63418 .66851 m .63393 .63163 L .64102 .62274 L p .707 .577 .707 r
F P
0 g
s
.63603 .69958 m .63741 .71684 L .6405 .73053 L p .707 .577 .707 r
F P
0 g
s
.83749 .5614 m .83533 .61815 L .82269 .61248 L p .707 .577 .707 r
F P
0 g
s
.82269 .61248 m .82485 .55574 L .83749 .5614 L p .707 .577 .707 r
F P
0 g
s
.83949 .69181 m .84087 .70907 L .83777 .69539 L p .707 .577 .707 r
F P
0 g
s
.83777 .69539 m .8364 .67813 L .83949 .69181 L p .707 .577 .707 r
F P
0 g
s
.64102 .62274 m .64126 .65963 L .63418 .66851 L p .707 .577 .707 r
F P
0 g
s
.38679 .59996 m .38895 .54321 L .35778 .54082 L p .707 .577 .707 r
F P
0 g
s
.38895 .54321 m .38679 .59996 L .4186 .60061 L p .707 .577 .707 r
F P
0 g
s
.4186 .60061 m .42075 .54386 L .38895 .54321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.44794 .59945 m .45009 .5427 L .42075 .54386 L p .707 .577 .707 r
F P
0 g
s
.64152 .60879 m .64368 .55204 L .65999 .54777 L p .707 .577 .707 r
F P
0 g
s
.83493 .62522 m .83517 .6621 L .82258 .65385 L p .707 .577 .707 r
F P
0 g
s
.82258 .65385 m .82234 .61696 L .83493 .62522 L p .707 .577 .707 r
F P
0 g
s
.35562 .59757 m .35778 .54082 L .33031 .53692 L p .707 .577 .707 r
F P
0 g
s
.35778 .54082 m .35562 .59757 L .38679 .59996 L p .707 .577 .707 r
F P
0 g
s
.63741 .71684 m .63603 .69958 L .6429 .68552 L p .707 .577 .707 r
F P
0 g
s
.65999 .54777 m .65783 .60452 L .64152 .60879 L p .707 .577 .707 r
F P
0 g
s
.38635 .66195 m .3861 .62506 L .35493 .62324 L p .707 .577 .707 r
F P
0 g
s
.3861 .62506 m .38635 .66195 L .41818 .66093 L p .707 .577 .707 r
F P
0 g
s
.41818 .66093 m .41794 .62405 L .3861 .62506 L p .707 .577 .707 r
F P
0 g
s
.45009 .5427 m .44794 .59945 L .47193 .5966 L p .707 .577 .707 r
F P
0 g
s
.47193 .5966 m .47409 .53985 L .45009 .5427 L p .707 .577 .707 r
F P
0 g
s
.33031 .53692 m .32816 .59367 L .35562 .59757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64126 .65963 m .64102 .62274 L .65738 .61486 L p .707 .577 .707 r
F P
0 g
s
.44756 .65718 m .44732 .6203 L .41794 .62405 L p .707 .577 .707 r
F P
0 g
s
.6429 .68552 m .64427 .70278 L .63741 .71684 L p .707 .577 .707 r
F P
0 g
s
.35517 .66013 m .35493 .62324 L .32747 .61877 L p .707 .577 .707 r
F P
0 g
s
.35493 .62324 m .35517 .66013 L .38635 .66195 L p .707 .577 .707 r
F P
0 g
s
.82485 .55574 m .82269 .61248 L .80161 .60746 L p .707 .577 .707 r
F P
0 g
s
.80161 .60746 m .80377 .55071 L .82485 .55574 L p .707 .577 .707 r
F P
0 g
s
.32816 .59367 m .33031 .53692 L .30923 .53189 L p .707 .577 .707 r
F P
0 g
s
.8364 .67813 m .83777 .69539 L .82503 .68342 L p .707 .577 .707 r
F P
0 g
s
.82503 .68342 m .82365 .66616 L .8364 .67813 L p .707 .577 .707 r
F P
0 g
s
.65738 .61486 m .65763 .65174 L .64126 .65963 L p .707 .577 .707 r
F P
0 g
s
.44732 .6203 m .44756 .65718 L .47161 .65106 L p .707 .577 .707 r
F P
0 g
s
.47161 .65106 m .47137 .61418 L .44732 .6203 L p .707 .577 .707 r
F P
0 g
s
.65783 .60452 m .65999 .54777 L .68399 .54492 L p .707 .577 .707 r
F P
0 g
s
.30923 .53189 m .30707 .58864 L .32816 .59367 L p .707 .577 .707 r
F P
0 g
s
.82234 .61696 m .82258 .65385 L .80152 .64715 L p .707 .577 .707 r
F P
0 g
s
.80152 .64715 m .80128 .61027 L .82234 .61696 L p .707 .577 .707 r
F P
0 g
s
.32747 .61877 m .32772 .65565 L .35517 .66013 L p .707 .577 .707 r
F P
0 g
s
.47409 .53985 m .47193 .5966 L .48824 .59234 L p .707 .577 .707 r
F P
0 g
s
.48824 .59234 m .4904 .53559 L .47409 .53985 L p .707 .577 .707 r
F P
0 g
s
.32772 .65565 m .32747 .61877 L .30642 .61208 L p .707 .577 .707 r
F P
0 g
s
.64427 .70278 m .6429 .68552 L .65905 .67245 L p .707 .577 .707 r
F P
0 g
s
.68399 .54492 m .68183 .60167 L .65783 .60452 L p .707 .577 .707 r
F P
0 g
s
.65763 .65174 m .65738 .61486 L .68143 .60874 L p .707 .577 .707 r
F P
0 g
s
.39003 .72104 m .38865 .70378 L .35752 .70279 L p .707 .577 .707 r
F P
0 g
s
.38865 .70378 m .39003 .72104 L .42176 .71765 L p .707 .577 .707 r
F P
0 g
s
.42176 .71765 m .42039 .70039 L .38865 .70378 L p .707 .577 .707 r
F P
0 g
s
.42039 .70039 m .42176 .71765 L .45099 .71019 L p .707 .577 .707 r
F P
0 g
s
.45099 .71019 m .44961 .69293 L .42039 .70039 L p .707 .577 .707 r
F P
0 g
s
.80377 .55071 m .80161 .60746 L .77414 .60356 L p .707 .577 .707 r
F P
0 g
s
.77414 .60356 m .7763 .54681 L .80377 .55071 L p .707 .577 .707 r
F P
0 g
s
.30707 .58864 m .30923 .53189 L .2966 .52623 L p .707 .577 .707 r
F P
0 g
s
.65905 .67245 m .66042 .68971 L .64427 .70278 L p .707 .577 .707 r
F P
0 g
s
.30642 .61208 m .30666 .64896 L .32772 .65565 L p .707 .577 .707 r
F P
0 g
s
.82365 .66616 m .82503 .68342 L .80387 .67435 L p .707 .577 .707 r
F P
0 g
s
.80387 .67435 m .8025 .65709 L .82365 .66616 L p .707 .577 .707 r
F P
0 g
s
.47137 .61418 m .47161 .65106 L .48798 .64318 L p .707 .577 .707 r
F P
0 g
s
.48798 .64318 m .48774 .60629 L .47137 .61418 L p .707 .577 .707 r
F P
0 g
s
.35889 .72005 m .35752 .70279 L .33002 .69749 L p .707 .577 .707 r
F P
0 g
s
.35752 .70279 m .35889 .72005 L .39003 .72104 L p .707 .577 .707 r
F P
0 g
s
.68183 .60167 m .68399 .54492 L .71333 .54377 L p .707 .577 .707 r
F P
0 g
s
.68143 .60874 m .68168 .64563 L .65763 .65174 L p .707 .577 .707 r
F P
0 g
s
.80128 .61027 m .80152 .64715 L .77407 .64268 L p .707 .577 .707 r
F P
0 g
s
.77407 .64268 m .77382 .60579 L .80128 .61027 L p .707 .577 .707 r
F P
0 g
s
.2966 .52623 m .29444 .58298 L .30707 .58864 L p .707 .577 .707 r
F P
0 g
s
.44961 .69293 m .45099 .71019 L .47484 .69939 L p .707 .577 .707 r
F P
0 g
s
.47484 .69939 m .47347 .68213 L .44961 .69293 L p .707 .577 .707 r
F P
0 g
s
.33002 .69749 m .3314 .71475 L .35889 .72005 L p .707 .577 .707 r
F P
0 g
s
.30666 .64896 m .30642 .61208 L .29382 .60382 L p .707 .577 .707 r
F P
0 g
s
.7763 .54681 m .77414 .60356 L .74298 .60116 L p .707 .577 .707 r
F P
0 g
s
.74298 .60116 m .74514 .54442 L .7763 .54681 L p .707 .577 .707 r
F P
0 g
s
.71333 .54377 m .71117 .60051 L .68183 .60167 L p .707 .577 .707 r
F P
0 g
s
.4904 .53559 m .48824 .59234 L .49527 .58707 L p .707 .577 .707 r
F P
0 g
s
.49527 .58707 m .49743 .53033 L .4904 .53559 L p .707 .577 .707 r
F P
0 g
s
.68168 .64563 m .68143 .60874 L .71082 .60499 L p .707 .577 .707 r
F P
0 g
s
.66042 .68971 m .65905 .67245 L .6829 .66165 L p .707 .577 .707 r
F P
0 g
s
.71117 .60051 m .71333 .54377 L .74514 .54442 L p .707 .577 .707 r
F P
0 g
s
.3314 .71475 m .33002 .69749 L .30887 .68842 L p .707 .577 .707 r
F P
0 g
s
.74514 .54442 m .74298 .60116 L .71117 .60051 L p .707 .577 .707 r
F P
0 g
s
.77382 .60579 m .77407 .64268 L .74289 .64086 L p .707 .577 .707 r
F P
0 g
s
.74289 .64086 m .74265 .60398 L .77382 .60579 L p .707 .577 .707 r
F P
0 g
s
.29382 .60382 m .29407 .64071 L .30666 .64896 L p .707 .577 .707 r
F P
0 g
s
.8025 .65709 m .80387 .67435 L .77638 .66905 L p .707 .577 .707 r
F P
0 g
s
.77638 .66905 m .775 .65179 L .8025 .65709 L p .707 .577 .707 r
F P
0 g
s
.6829 .66165 m .68428 .67891 L .66042 .68971 L p .707 .577 .707 r
F P
0 g
s
.47347 .68213 m .47484 .69939 L .49099 .68632 L p .707 .577 .707 r
F P
0 g
s
.49099 .68632 m .48962 .66906 L .47347 .68213 L p .707 .577 .707 r
F P
0 g
s
.29444 .58298 m .2966 .52623 L .29365 .52048 L p .707 .577 .707 r
F P
0 g
s
.71082 .60499 m .71106 .64188 L .68168 .64563 L p .707 .577 .707 r
F P
0 g
s
.30887 .68842 m .31024 .70568 L .3314 .71475 L p .707 .577 .707 r
F P
0 g
s
.71106 .64188 m .71082 .60499 L .74265 .60398 L p .707 .577 .707 r
F P
0 g
s
.48774 .60629 m .48798 .64318 L .49506 .6343 L p .707 .577 .707 r
F P
0 g
s
.49506 .6343 m .49482 .59741 L .48774 .60629 L p .707 .577 .707 r
F P
0 g
s
.74265 .60398 m .74289 .64086 L .71106 .64188 L p .707 .577 .707 r
F P
0 g
s
.68428 .67891 m .6829 .66165 L .71213 .65419 L p .707 .577 .707 r
F P
0 g
s
.29365 .52048 m .29149 .57723 L .29444 .58298 L p .707 .577 .707 r
F P
0 g
s
.775 .65179 m .77638 .66905 L .74524 .66806 L p .707 .577 .707 r
F P
0 g
s
.74524 .66806 m .74387 .65079 L .775 .65179 L p .707 .577 .707 r
F P
0 g
s
.31024 .70568 m .30887 .68842 L .29612 .67645 L p .707 .577 .707 r
F P
0 g
s
.29407 .64071 m .29382 .60382 L .29092 .59481 L p .707 .577 .707 r
F P
0 g
s
.71213 .65419 m .7135 .67145 L .68428 .67891 L p .707 .577 .707 r
F P
0 g
s
.7135 .67145 m .71213 .65419 L .74387 .65079 L p .707 .577 .707 r
F P
0 g
s
.49743 .53033 m .49527 .58707 L .49232 .58133 L p .707 .577 .707 r
F P
0 g
s
.49232 .58133 m .49448 .52458 L .49743 .53033 L p .707 .577 .707 r
F P
0 g
s
.74387 .65079 m .74524 .66806 L .7135 .67145 L p .707 .577 .707 r
F P
0 g
s
.29612 .67645 m .29749 .69371 L .31024 .70568 L p .707 .577 .707 r
F P
0 g
s
.48962 .66906 m .49099 .68632 L .49786 .67226 L p .707 .577 .707 r
F P
0 g
s
.49786 .67226 m .49648 .655 L .48962 .66906 L p .707 .577 .707 r
F P
0 g
s
.29092 .59481 m .29117 .6317 L .29407 .64071 L p .707 .577 .707 r
F P
0 g
s
.29149 .57723 m .29365 .52048 L .30067 .51522 L p .707 .577 .707 r
F P
0 g
s
.49482 .59741 m .49506 .6343 L .49216 .62529 L p .707 .577 .707 r
F P
0 g
s
.49216 .62529 m .49192 .5884 L .49482 .59741 L p .707 .577 .707 r
F P
0 g
s
.29749 .69371 m .29612 .67645 L .29302 .66277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30067 .51522 m .29851 .57197 L .29149 .57723 L p .707 .577 .707 r
F P
0 g
s
.29117 .6317 m .29092 .59481 L .298 .58593 L p .707 .577 .707 r
F P
0 g
s
.29302 .66277 m .2944 .68003 L .29749 .69371 L p .707 .577 .707 r
F P
0 g
s
.49448 .52458 m .49232 .58133 L .47968 .57567 L p .707 .577 .707 r
F P
0 g
s
.47968 .57567 m .48184 .51892 L .49448 .52458 L p .707 .577 .707 r
F P
0 g
s
.49648 .655 m .49786 .67226 L .49476 .65857 L p .707 .577 .707 r
F P
0 g
s
.49476 .65857 m .49339 .64131 L .49648 .655 L p .707 .577 .707 r
F P
0 g
s
.298 .58593 m .29825 .62281 L .29117 .6317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29851 .57197 m .30067 .51522 L .31698 .51096 L p .707 .577 .707 r
F P
0 g
s
.49192 .5884 m .49216 .62529 L .47957 .61703 L p .707 .577 .707 r
F P
0 g
s
.47957 .61703 m .47933 .58015 L .49192 .5884 L p .707 .577 .707 r
F P
0 g
s
.2944 .68003 m .29302 .66277 L .29989 .6487 L p .707 .577 .707 r
F P
0 g
s
.31698 .51096 m .31482 .56771 L .29851 .57197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29825 .62281 m .298 .58593 L .31437 .57804 L p .707 .577 .707 r
F P
0 g
s
.29989 .6487 m .30126 .66596 L .2944 .68003 L p .707 .577 .707 r
F P
0 g
s
.48184 .51892 m .47968 .57567 L .4586 .57064 L p .707 .577 .707 r
F P
0 g
s
.4586 .57064 m .46076 .51389 L .48184 .51892 L p .707 .577 .707 r
F P
0 g
s
.49339 .64131 m .49476 .65857 L .48201 .64661 L p .707 .577 .707 r
F P
0 g
s
.48201 .64661 m .48064 .62935 L .49339 .64131 L p .707 .577 .707 r
F P
0 g
s
.31437 .57804 m .31462 .61493 L .29825 .62281 L p .707 .577 .707 r
F P
0 g
s
.31482 .56771 m .31698 .51096 L .34098 .50811 L p .707 .577 .707 r
F P
0 g
s
.47933 .58015 m .47957 .61703 L .45851 .61034 L p .707 .577 .707 r
F P
0 g
s
.45851 .61034 m .45827 .57345 L .47933 .58015 L p .707 .577 .707 r
F P
0 g
s
.30126 .66596 m .29989 .6487 L .31604 .63563 L p .707 .577 .707 r
F P
0 g
s
.34098 .50811 m .33882 .56486 L .31482 .56771 L p .707 .577 .707 r
F P
0 g
s
.31462 .61493 m .31437 .57804 L .33842 .57193 L p .707 .577 .707 r
F P
0 g
s
.46076 .51389 m .4586 .57064 L .43113 .56674 L p .707 .577 .707 r
F P
0 g
s
.43113 .56674 m .43329 .50999 L .46076 .51389 L p .707 .577 .707 r
F P
0 g
s
.31604 .63563 m .31741 .65289 L .30126 .66596 L p .707 .577 .707 r
F P
0 g
s
.48064 .62935 m .48201 .64661 L .46086 .63753 L p .707 .577 .707 r
F P
0 g
s
.46086 .63753 m .45949 .62027 L .48064 .62935 L p .707 .577 .707 r
F P
0 g
s
.33882 .56486 m .34098 .50811 L .37032 .50695 L p .707 .577 .707 r
F P
0 g
s
.33842 .57193 m .33867 .60881 L .31462 .61493 L p .707 .577 .707 r
F P
0 g
s
.45827 .57345 m .45851 .61034 L .43106 .60586 L p .707 .577 .707 r
F P
0 g
s
.43106 .60586 m .43081 .56898 L .45827 .57345 L p .707 .577 .707 r
F P
0 g
s
.43329 .50999 m .43113 .56674 L .39997 .56435 L p .707 .577 .707 r
F P
0 g
s
.39997 .56435 m .40213 .5076 L .43329 .50999 L p .707 .577 .707 r
F P
0 g
s
.37032 .50695 m .36816 .5637 L .33882 .56486 L p .707 .577 .707 r
F P
0 g
s
.33867 .60881 m .33842 .57193 L .3678 .56818 L p .707 .577 .707 r
F P
0 g
s
.31741 .65289 m .31604 .63563 L .33989 .62484 L p .707 .577 .707 r
F P
0 g
s
.36816 .5637 m .37032 .50695 L .40213 .5076 L p .707 .577 .707 r
F P
0 g
s
.40213 .5076 m .39997 .56435 L .36816 .5637 L p .707 .577 .707 r
F P
0 g
s
.43081 .56898 m .43106 .60586 L .39988 .60405 L p .707 .577 .707 r
F P
0 g
s
.39988 .60405 m .39964 .56716 L .43081 .56898 L p .707 .577 .707 r
F P
0 g
s
.45949 .62027 m .46086 .63753 L .43337 .63224 L p .707 .577 .707 r
F P
0 g
s
.43337 .63224 m .43199 .61498 L .45949 .62027 L p .707 .577 .707 r
F P
0 g
s
.33989 .62484 m .34127 .6421 L .31741 .65289 L p .707 .577 .707 r
F P
0 g
s
.3678 .56818 m .36805 .60506 L .33867 .60881 L p .707 .577 .707 r
F P
0 g
s
.36805 .60506 m .3678 .56818 L .39964 .56716 L p .707 .577 .707 r
F P
0 g
s
.39964 .56716 m .39988 .60405 L .36805 .60506 L p .707 .577 .707 r
F P
0 g
s
.34127 .6421 m .33989 .62484 L .36912 .61738 L p .707 .577 .707 r
F P
0 g
s
.43199 .61498 m .43337 .63224 L .40223 .63124 L p .707 .577 .707 r
F P
0 g
s
.40223 .63124 m .40085 .61398 L .43199 .61498 L p .707 .577 .707 r
F P
0 g
s
.36912 .61738 m .37049 .63464 L .34127 .6421 L p .707 .577 .707 r
F P
0 g
s
.37049 .63464 m .36912 .61738 L .40085 .61398 L p .707 .577 .707 r
F P
0 g
s
.40085 .61398 m .40223 .63124 L .37049 .63464 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008=ooaD008Eo
o`00OGoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF2@00O7oo001gOol60008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol007=oo`@0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0075oo`00Kgoo10001UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000KGoo001]Ool20000
0eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH3001ZOol006]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Qoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00P00IWoo001XOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06=oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Aoo`00GWoo6@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P00I7oo001HOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol005Eoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH6000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000I7oo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=o
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20007OolI0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008003Aoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`00<Goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002ioo`00DWoo00<005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF
00000UYF1`001eYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001BOol00`00FUH000030005FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000080003FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059o
o`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF000000020002FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP000080009JEP@000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00E7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP`00003FUH005YF00IJEPP00003FUH0000000H000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP0009JEP03
001JEUYF00AJEPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0015YF00<005YFFUH01EYF2@0015YF
00@005YFFUIJEPP00003FUH0000000<000AJEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000AJ
EP04001JEUYFFUH90002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60004FUH0
0`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00
FUH00`001EYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPT00003FUH005YF
009JEP8002ioo`00DWoo00<005YF000015YF100027oo00@005YFFUH000AJEPl000QJEP<00004FUH0
05YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUH000050002FUH2000^Ool0059oo`03001JEP00009JEP800003FUH0000000<000Io
o`03001JEP0000D000AJEP03001JEUYF00IJEP03001JEP0000<00007FUH00000001JEP00FUH00P00
0UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP0000000P00;Woo001BOol00`00FUH000030005FUH00`00FUH0000700000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP02FUH40004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1P00;Woo
001BOol00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00;Woo
000gOolM0003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000_
Ool0035oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001J
EUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH300000eYF
001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEP000006FUH00`00FUIJEP04FUH;
0003FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH010001EYF1P000eYF00<005YFFUH01UYF
00<005YF00000`0015YF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000IJEPD000QJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0
0005FUH005YFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH00UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000HOol4
00000eYF001JEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000AJEP00FUH000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YF0000
0`008Woo10000eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP04001JEP000003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP<0019ooa40
00Aoo`H000=JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1@0000=JEP00FUH01EYF0`000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUH005YF001JEP020003FUH50007Ool60004FUH00`00FUIJEP06
FUH01000FUIJEUYF1@000UYF00@005YFFUH0009JEP8002ioo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80009JEP03
001JEUYF00=JEPP000AJEP03001JEUYF009JEP`000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH01000FUIJEUYF1`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF1000;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF
00<005YFFUH00eYF00D005YFFUIJEP00009JEPX000IJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001J
EUYF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF008000=JEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=J
EP<00003FUH005YF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP80
0004FUH00000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH<0003FUH80004FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF008000EJEP03001JEUYF009JEP8000IJEPH0
00=JEP03001JEUYF00EJEPD000EJEP04001JEP00000_Ool002]oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF0080
009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH40006FUH00`00FUH000020008FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP09FUH00`00FUH00004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200001EYF001JEUYF0000;goo
000[Ool00`00FUH00004FUH01000FUIJEUYF6@0015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000002FUH00`00Oomoo`0]Ool002]oo`03001JEP00009JEPL000MJEP03001J
EUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00005FUH00`00FUIJEP020002FUH00`00
FUIJEP03FUH50005FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YF000000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`04001J
EUYF000^Ool002]oo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00L000=JEP03001JEUYF0080009JEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00EJEP8000AJEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030006Ool3000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH20002
FUH40002FUH20002FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP03FUH20006FUH30008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YFFUH0009JEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000]oo`8002io
o`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEPD00003FUH000000080009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEP0000<00003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH30002FUH00`00FUIJEP04FUHJ000@Ool2000^
Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH01000FUIJEUYF2@001EYF00@005YFFUIJEPL000EJEP03001JEUYF009J
EP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH01@00FUIJEUYF000097oo00@005YF000002eoo`00;Goo0P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF2P0025YF00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF008000AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo029oo`04001JEUYF000]Ool002moo`@000=JEP03001JEUYF00EJEPP000AJ
EP03001JEUYF009JEPP00004FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8002=oo`80009J
EP03001oogoo02]oo`00<goo2`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P008Woo00D005YF001JEP0002ioo`00<Woo10000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP04001JEUYF
FUH20009Ool3000EOol01000FUIJEUYF0P00;Woo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0004FUH00`00FUIJEP02FUH6
000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000BOol20004FUH00`00Oomo
o`0]Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00006Ool005YFFUH005YF2@001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH005YF009JEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000@Ool200000eYF001J
EP03FUH00`00Oomoo`0]Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00D000AJEP04001JEUYF
FUH20008Ool5000>Ool20003FUH01@00FUIJEUYF0000<7oo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH01P0000=JEP00FUH00UYF0P002Goo0`002goo10001EYF00@005YF0000035oo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF000015YF1P000UYF0P004goo10000UYF00<005YFFUH015YF0P00<goo000[
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUH00006000<Ool70006FUH00`00FUIJEP03
FUH2000dOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00=JEPl000AJEP03001JEUYF
00IJEP04001JEUYFFUH2000fOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>7oo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH60008OolG0004FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH=000;FUH90008
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH700000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH3000jOol002]oo`03001JEP0000AJEP03001JEP0000<000Qoo`H000AJ
EP03001JEUYF00IJEP04001JEUYFFUH500001Woo00000000FUH0009JEP80009JEP03001JEUYF00AJ
EP03001JEUYF00=JEP/000]JEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@003eoo`00:goo00<005YF00000eYF10001goo100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF0P000UYF00<005YFFUH015YF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00@Goo000[Ool01000FUH005YF0P0015YF1`001EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEP<000=J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP800003Ool0000000h004Qo
o`00:goo00H005YF000005YF0005FUH200000eYF001JEP07FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000AJEP000000009JEP04001JEUYFFUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40005FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000Egoo000[Ool20003FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF2P0015YF2@0015YF00<005YFFUH00UYF1@000UYF00@005YF000000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EUYFFUH00004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo000[Ool20003
FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
15YF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00:goo0P000eYF0`001eYF00<005YF00000P00
1eYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00H005YFFUH005YF
0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000[Ool20002FUH200000eYF001JEP05FUH300000eYF001JEP07FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH2000015YF001JEUYF0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`03001JEP00
00AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH000000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP04001JEP000006FUH00`00FUIJEP06
FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02eoo`8000AJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEP00001oo`030004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP070004FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUH00002FUH400000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH600000eYF001JEP02FUH2001EOol0
02aoo`03001JEP00008000Aoo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP00
00<000=JEP8005Eoo`00;7oo00<005YF00002Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P002Woo0`000Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH00UYF0`00
00=JEP000000EGoo000/Ool2000>OolH000@Ool00`00FUH00004Ool20007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF1@00
1UYF00<005YFFUH00eYF1@00EGoo000/Ool2000eOol200000eYF001oo`05Ool30004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0
00001EYF10000UYF00<005YFFUH00eYF1@00EGoo000/Ool2000cOol200000eYF0000000:Ool30000
0eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
00000eYF001JEP06FUH00`00FUH000030004FUH01@00FUH005YF0000EGoo000/Ool3000aOol01000
FUIJEUYF0P003Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01P0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP8005Eoo`00;7oo0`00
;goo0P0015YF00<007ooOol04goo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF200000=JEP00
000010000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001oogoo05Aoo`00
;7oo0P0000=JEP00Ool0:goo0P0000=JEP00FUH00eYF00<007ooOol07Woo6`0025YF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001FOol002eoo`03001JEUYF008002Qo
o`8000=JEP05001JEUYFFUH0000ZOol20004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001oo`1DOol002eoo`05001J
EUYF001JEP03000ROol30005FUH01000FUH00000:goo0P000eYF00D005YFFUIJEP0000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=oo`8005Eoo`00
;Woo00<005YF000015YF0`006goo100000=JEP00FUH01EYF0P00;7oo00D005YFFUH005YF00@00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40005
Ool2001EOol002moo`03001JEP0000AJEP03001JEP0000<0011oo`L000EJEP03001JEUYF00AJEP03
001oogoo02]oo`03001JEUYF008000Aoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Uoo`8005Eoo`00<7oo0P0015YF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
00@005YFFUIJEP8002ioo`04001JEUYF000:Ool90004FUH00`00FUIJEP02FUH9000?Ool01000FUH0
0000E7oo000aOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000<7oo00<005YF000057oo2@0067oo00@005YFFUH005Aoo`00<goo0`0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000<goo0P00=7oo0P00
0UYF00<007ooOol0DWoo000fOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
000gOol00`00Oomoo`0aOol2000015YF001JEP00EGoo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH7000kOol2000`Ool20004FUH2001EOol003eoo`l0049oo`04001JEP00000/Ool20000
0eYF001JEP03FUH00`00Oomoo`1DOol008ioo`80009JEP03001oogoo02Moo`8000=JEP03001JEUYF
009JEP03001oogoo05Aoo`00Sgoo00<005YFFUH00`0097oo0`001EYF00<005YFFUH00P00Egoo002?
Ool01000FUIJEP000UYF0P007goo0`0000=JEP00FUH01EYF0`00FGoo002@Ool00`00FUH00004FUH5
000GOol30004FUH00`00FUIJEP03FUH2001KOol0095oo`8000EJEP04001JEUYFFUH80009Ool60007
FUH01000FUIJEUYF0P00GGoo002BOol00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@00
15YF00<005YFFUH01UYF00@005YF000005moo`00Tgoo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`00HGoo002EOol200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP04001TOol009Moo`D000AJEP03001JEUYF00IJEP03001J
EUYF009JEPL006Qoo`00W7oo4P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5906 .75944 m .59408 .70227 L .56293 .69957 L p .707 .577 .707 r
F P
0 g
s
.59408 .70227 m .5906 .75944 L .62236 .76099 L p .707 .577 .707 r
F P
0 g
s
.62236 .76099 m .62584 .70381 L .59408 .70227 L p .707 .577 .707 r
F P
0 g
s
.62584 .70381 m .62236 .76099 L .65163 .76122 L p .707 .577 .707 r
F P
0 g
s
.65163 .76122 m .65511 .70404 L .62584 .70381 L p .707 .577 .707 r
F P
0 g
s
.55945 .75674 m .56293 .69957 L .53545 .69597 L p .707 .577 .707 r
F P
0 g
s
.56293 .69957 m .55945 .75674 L .5906 .75944 L p .707 .577 .707 r
F P
0 g
s
.53545 .69597 m .53197 .75315 L .55945 .75674 L p .707 .577 .707 r
F P
0 g
s
.65511 .70404 m .65163 .76122 L .67554 .76013 L p .707 .577 .707 r
F P
0 g
s
.67554 .76013 m .67903 .70295 L .65511 .70404 L p .707 .577 .707 r
F P
0 g
s
.5897 .85448 m .58931 .8177 L .55813 .81594 L p .707 .577 .707 r
F P
0 g
s
.58931 .8177 m .5897 .85448 L .62153 .85332 L p .707 .577 .707 r
F P
0 g
s
.62153 .85332 m .62114 .81654 L .58931 .8177 L p .707 .577 .707 r
F P
0 g
s
.62114 .81654 m .62153 .85332 L .65091 .84934 L p .707 .577 .707 r
F P
0 g
s
.65091 .84934 m .65052 .81256 L .62114 .81654 L p .707 .577 .707 r
F P
0 g
s
.53197 .75315 m .53545 .69597 L .51432 .69184 L p .707 .577 .707 r
F P
0 g
s
.55853 .85271 m .55813 .81594 L .53068 .81141 L p .707 .577 .707 r
F P
0 g
s
.55813 .81594 m .55853 .85271 L .5897 .85448 L p .707 .577 .707 r
F P
0 g
s
.51432 .69184 m .51084 .74902 L .53197 .75315 L p .707 .577 .707 r
F P
0 g
s
.65052 .81256 m .65091 .84934 L .67496 .84293 L p .707 .577 .707 r
F P
0 g
s
.67496 .84293 m .67457 .80616 L .65052 .81256 L p .707 .577 .707 r
F P
0 g
s
.67903 .70295 m .67554 .76013 L .69176 .75781 L p .707 .577 .707 r
F P
0 g
s
.69176 .75781 m .69524 .70063 L .67903 .70295 L p .707 .577 .707 r
F P
0 g
s
.53068 .81141 m .53107 .84819 L .55853 .85271 L p .707 .577 .707 r
F P
0 g
s
.53107 .84819 m .53068 .81141 L .50962 .80457 L p .707 .577 .707 r
F P
0 g
s
.51084 .74902 m .51432 .69184 L .50162 .68757 L p .707 .577 .707 r
F P
0 g
s
.50162 .68757 m .49813 .74475 L .51084 .74902 L p .707 .577 .707 r
F P
0 g
s
.50962 .80457 m .51001 .84135 L .53107 .84819 L p .707 .577 .707 r
F P
0 g
s
.5963 .91202 m .5941 .89587 L .56302 .89539 L p .707 .577 .707 r
F P
0 g
s
.5941 .89587 m .5963 .91202 L .62788 .90711 L p .707 .577 .707 r
F P
0 g
s
.62788 .90711 m .62568 .89096 L .5941 .89587 L p .707 .577 .707 r
F P
0 g
s
.67457 .80616 m .67496 .84293 L .69133 .83473 L p .707 .577 .707 r
F P
0 g
s
.69133 .83473 m .69093 .79795 L .67457 .80616 L p .707 .577 .707 r
F P
0 g
s
.62568 .89096 m .62788 .90711 L .65685 .8973 L p .707 .577 .707 r
F P
0 g
s
.65685 .8973 m .65465 .88115 L .62568 .89096 L p .707 .577 .707 r
F P
0 g
s
.56522 .91154 m .56302 .89539 L .53547 .88957 L p .707 .577 .707 r
F P
0 g
s
.56302 .89539 m .56522 .91154 L .5963 .91202 L p .707 .577 .707 r
F P
0 g
s
.65465 .88115 m .65685 .8973 L .68039 .88355 L p .707 .577 .707 r
F P
0 g
s
.68039 .88355 m .67819 .86739 L .65465 .88115 L p .707 .577 .707 r
F P
0 g
s
.69524 .70063 m .69176 .75781 L .69868 .75449 L p .707 .577 .707 r
F P
0 g
s
.69868 .75449 m .70217 .69731 L .69524 .70063 L p .707 .577 .707 r
F P
0 g
s
.51001 .84135 m .50962 .80457 L .49702 .79609 L p .707 .577 .707 r
F P
0 g
s
.53547 .88957 m .53767 .90573 L .56522 .91154 L p .707 .577 .707 r
F P
0 g
s
.49813 .74475 m .50162 .68757 L .49858 .68358 L p .707 .577 .707 r
F P
0 g
s
.53767 .90573 m .53547 .88957 L .51416 .87899 L p .707 .577 .707 r
F P
0 g
s
.49702 .79609 m .49742 .83286 L .51001 .84135 L p .707 .577 .707 r
F P
0 g
s
.69093 .79795 m .69133 .83473 L .6984 .82553 L p .707 .577 .707 r
F P
0 g
s
.6984 .82553 m .69801 .78875 L .69093 .79795 L p .707 .577 .707 r
F P
0 g
s
.67819 .86739 m .68039 .88355 L .69619 .86719 L p .707 .577 .707 r
F P
0 g
s
.69619 .86719 m .69399 .85104 L .67819 .86739 L p .707 .577 .707 r
F P
0 g
s
.49858 .68358 m .4951 .74076 L .49813 .74475 L p .707 .577 .707 r
F P
0 g
s
.51416 .87899 m .51636 .89514 L .53767 .90573 L p .707 .577 .707 r
F P
0 g
s
.49742 .83286 m .49702 .79609 L .49412 .78679 L p .707 .577 .707 r
F P
0 g
s
.70217 .69731 m .69868 .75449 L .69565 .7505 L p .707 .577 .707 r
F P
0 g
s
.69565 .7505 m .69913 .69332 L .70217 .69731 L p .707 .577 .707 r
F P
0 g
s
.51636 .89514 m .51416 .87899 L .50116 .86468 L p .707 .577 .707 r
F P
0 g
s
.69399 .85104 m .69619 .86719 L .7027 .84985 L p .707 .577 .707 r
F P
0 g
s
.7027 .84985 m .7005 .83369 L .69399 .85104 L p .707 .577 .707 r
F P
0 g
s
.49412 .78679 m .49452 .82357 L .49742 .83286 L p .707 .577 .707 r
F P
0 g
s
.4951 .74076 m .49858 .68358 L .50551 .68026 L p .707 .577 .707 r
F P
0 g
s
.50116 .86468 m .50336 .88083 L .51636 .89514 L p .707 .577 .707 r
F P
0 g
s
.69801 .78875 m .6984 .82553 L .6955 .81623 L p .707 .577 .707 r
F P
0 g
s
.6955 .81623 m .69511 .77945 L .69801 .78875 L p .707 .577 .707 r
F P
0 g
s
.50551 .68026 m .50202 .73744 L .4951 .74076 L p .707 .577 .707 r
F P
0 g
s
.50336 .88083 m .50116 .86468 L .49774 .84803 L p .707 .577 .707 r
F P
0 g
s
.49359 .81614 m .49871 .31099 L .4547 .30813 L p .707 .577 .707 r
F P
0 g
s
.49452 .82357 m .49412 .78679 L .5012 .77759 L p .707 .577 .707 r
F P
0 g
s
.5012 .77759 m .50159 .81437 L .49452 .82357 L p .707 .577 .707 r
F P
0 g
s
.50202 .73744 m .50551 .68026 L .52172 .67794 L p .707 .577 .707 r
F P
0 g
s
.52172 .67794 m .51824 .73512 L .50202 .73744 L p .707 .577 .707 r
F P
0 g
s
.50159 .81437 m .5012 .77759 L .51756 .76938 L p .707 .577 .707 r
F P
0 g
s
.51756 .76938 m .51796 .80616 L .50159 .81437 L p .707 .577 .707 r
F P
0 g
s
.51824 .73512 m .52172 .67794 L .54563 .67685 L p .707 .577 .707 r
F P
0 g
s
.54563 .67685 m .54215 .73402 L .51824 .73512 L p .707 .577 .707 r
F P
0 g
s
.50646 .84683 m .50426 .83068 L .52006 .81433 L p .707 .577 .707 r
F P
0 g
s
.51796 .80616 m .51756 .76938 L .54161 .76298 L p .707 .577 .707 r
F P
0 g
s
.52006 .81433 m .52226 .83048 L .50646 .84683 L p .707 .577 .707 r
F P
0 g
s
.54161 .76298 m .54201 .79976 L .51796 .80616 L p .707 .577 .707 r
F P
0 g
s
.52226 .83048 m .52006 .81433 L .5436 .80057 L p .707 .577 .707 r
F P
0 g
s
.5436 .80057 m .5458 .81672 L .52226 .83048 L p .707 .577 .707 r
F P
0 g
s
.49871 .31099 m .49359 .81614 L .53854 .81556 L p .707 .577 .707 r
F P
0 g
s
.53854 .81556 m .54365 .31042 L .49871 .31099 L p .707 .577 .707 r
F P
0 g
s
.69913 .69332 m .69565 .7505 L .68294 .74623 L p .707 .577 .707 r
F P
0 g
s
.68294 .74623 m .68642 .68905 L .69913 .69332 L p .707 .577 .707 r
F P
0 g
s
.54215 .73402 m .54563 .67685 L .5749 .67708 L p .707 .577 .707 r
F P
0 g
s
.5749 .67708 m .57142 .73426 L .54215 .73402 L p .707 .577 .707 r
F P
0 g
s
.57142 .73426 m .5749 .67708 L .60667 .67862 L p .707 .577 .707 r
F P
0 g
s
.54201 .79976 m .54161 .76298 L .57099 .759 L p .707 .577 .707 r
F P
0 g
s
.60667 .67862 m .60318 .7358 L .57142 .73426 L p .707 .577 .707 r
F P
0 g
s
.57099 .759 m .57139 .79578 L .54201 .79976 L p .707 .577 .707 r
F P
0 g
s
.57139 .79578 m .57123 .78091 L p .60283 .75784 L .707 .577 .707 r
F P
0 g
s
.57123 .78091 m .57099 .759 L .5851 .75849 L p .707 .577 .707 r
F P
0 g
s
.5851 .75849 m .60283 .75784 L p .57123 .78091 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .5436 .80057 L .56316 .79395 L p .707 .577 .707 r
F P
0 g
s
.56316 .79395 m .57257 .79076 L p .55397 .80879 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .56316 .79395 L .55397 .80879 L .707 .577 .707 r
F
.60283 .75784 m .60322 .79462 L .57139 .79578 L p F P
0 g
s
.57477 .80691 m .57257 .79076 L .59503 .78727 L p .707 .577 .707 r
F P
0 g
s
.60322 .79462 m .60304 .77775 L p .634 .75961 L .707 .577 .707 r
F P
0 g
s
.59503 .78727 m .60414 .78585 L p .58419 .80016 L .707 .577 .707 r
F P
0 g
s
.57477 .80691 m .59503 .78727 L .58419 .80016 L .707 .577 .707 r
F
.60304 .77775 m .60283 .75784 L .61902 .75876 L p F P
0 g
s
.61902 .75876 m .634 .75961 L p .60304 .77775 L .707 .577 .707 r
F P
0 g
s
.57257 .79076 m .57477 .80691 L .5458 .81672 L p .707 .577 .707 r
F P
0 g
s
.634 .75961 m .63439 .79638 L .60322 .79462 L p .707 .577 .707 r
F P
0 g
s
.60414 .78585 m .60634 .80201 L .57477 .80691 L p .707 .577 .707 r
F P
0 g
s
.54365 .31042 m .53854 .81556 L .58001 .81161 L p .707 .577 .707 r
F P
0 g
s
.58001 .81161 m .58513 .30646 L .54365 .31042 L p .707 .577 .707 r
F P
0 g
s
.7005 .83369 m .7027 .84985 L .69929 .8332 L p .707 .577 .707 r
F P
0 g
s
.69929 .8332 m .69709 .81705 L .7005 .83369 L p .707 .577 .707 r
F P
0 g
s
.24759 .72263 m .25107 .66545 L .21992 .66275 L p .707 .577 .707 r
F P
0 g
s
.25107 .66545 m .24759 .72263 L .27935 .72417 L p .707 .577 .707 r
F P
0 g
s
.27935 .72417 m .28283 .66699 L .25107 .66545 L p .707 .577 .707 r
F P
0 g
s
.44959 .81327 m .4547 .30813 L .41594 .30211 L p .707 .577 .707 r
F P
0 g
s
.4547 .30813 m .44959 .81327 L .49359 .81614 L p .707 .577 .707 r
F P
0 g
s
.49774 .84803 m .49994 .86418 L .50336 .88083 L p .707 .577 .707 r
F P
0 g
s
.28283 .66699 m .27935 .72417 L .30862 .72441 L p .707 .577 .707 r
F P
0 g
s
.30862 .72441 m .3121 .66723 L .28283 .66699 L p .707 .577 .707 r
F P
0 g
s
.21644 .71993 m .21992 .66275 L .19244 .65916 L p .707 .577 .707 r
F P
0 g
s
.21992 .66275 m .21644 .71993 L .24759 .72263 L p .707 .577 .707 r
F P
0 g
s
.69511 .77945 m .6955 .81623 L .68291 .80775 L p .707 .577 .707 r
F P
0 g
s
.68291 .80775 m .68251 .77097 L .69511 .77945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63781 .68132 m .63433 .7385 L .60318 .7358 L p .707 .577 .707 r
F P
0 g
s
.60318 .7358 m .60667 .67862 L .63781 .68132 L p .707 .577 .707 r
F P
0 g
s
.66146 .76413 m .66185 .80091 L .63439 .79638 L p .707 .577 .707 r
F P
0 g
s
.63439 .79638 m .6342 .77883 L p .66146 .76413 L .707 .577 .707 r
F P
0 g
s
.63523 .78633 m .63743 .80248 L .61227 .8021 L p .707 .577 .707 r
F P
0 g
s
.61227 .8021 m .60634 .80201 L p .61866 .79532 L .707 .577 .707 r
F P
0 g
s
.61866 .79532 m .63523 .78633 L .61227 .8021 L .707 .577 .707 r
F
.6342 .77883 m .634 .75961 L .64986 .76222 L p F P
0 g
s
.64986 .76222 m .66146 .76413 L p .6342 .77883 L .707 .577 .707 r
F P
0 g
s
.60634 .80201 m .60414 .78585 L .63523 .78633 L p .707 .577 .707 r
F P
0 g
s
.58513 .30646 m .58001 .81161 L .61396 .80466 L p .707 .577 .707 r
F P
0 g
s
.61396 .80466 m .61908 .29952 L .58513 .30646 L p .707 .577 .707 r
F P
0 g
s
.19244 .65916 m .18896 .71634 L .21644 .71993 L p .707 .577 .707 r
F P
0 g
s
.3121 .66723 m .30862 .72441 L .33253 .72331 L p .707 .577 .707 r
F P
0 g
s
.33253 .72331 m .33602 .66613 L .3121 .66723 L p .707 .577 .707 r
F P
0 g
s
.49994 .86418 m .49774 .84803 L .50426 .83068 L p .707 .577 .707 r
F P
0 g
s
.24669 .81766 m .2463 .78089 L .21513 .77912 L p .707 .577 .707 r
F P
0 g
s
.2463 .78089 m .24669 .81766 L .27852 .8165 L p .707 .577 .707 r
F P
0 g
s
.27852 .8165 m .27813 .77973 L .2463 .78089 L p .707 .577 .707 r
F P
0 g
s
.27813 .77973 m .27852 .8165 L .3079 .81252 L p .707 .577 .707 r
F P
0 g
s
.3079 .81252 m .30751 .77575 L .27813 .77973 L p .707 .577 .707 r
F P
0 g
s
.18896 .71634 m .19244 .65916 L .17131 .65502 L p .707 .577 .707 r
F P
0 g
s
.41082 .80725 m .41594 .30211 L .38621 .29352 L p .707 .577 .707 r
F P
0 g
s
.41594 .30211 m .41082 .80725 L .44959 .81327 L p .707 .577 .707 r
F P
0 g
s
.68642 .68905 m .68294 .74623 L .66181 .7421 L p .707 .577 .707 r
F P
0 g
s
.66181 .7421 m .6653 .68492 L .68642 .68905 L p .707 .577 .707 r
F P
0 g
s
.69709 .81705 m .69929 .8332 L .68629 .81888 L p .707 .577 .707 r
F P
0 g
s
.68629 .81888 m .68409 .80273 L .69709 .81705 L p .707 .577 .707 r
F P
0 g
s
.21552 .8159 m .21513 .77912 L .18767 .7746 L p .707 .577 .707 r
F P
0 g
s
.21513 .77912 m .21552 .8159 L .24669 .81766 L p .707 .577 .707 r
F P
0 g
s
.50426 .83068 m .50646 .84683 L .49994 .86418 L p .707 .577 .707 r
F P
0 g
s
.17131 .65502 m .16783 .7122 L .18896 .71634 L p .707 .577 .707 r
F P
0 g
s
.30751 .77575 m .3079 .81252 L .33195 .80612 L p .707 .577 .707 r
F P
0 g
s
.33195 .80612 m .33156 .76934 L .30751 .77575 L p .707 .577 .707 r
F P
0 g
s
.68251 .77097 m .68291 .80775 L .66185 .80091 L p .707 .577 .707 r
F P
0 g
s
.66185 .80091 m .66167 .78404 L p .68251 .77097 L .707 .577 .707 r
F P
0 g
s
.66277 .79215 m .66497 .8083 L .64513 .80411 L p .707 .577 .707 r
F P
0 g
s
.64513 .80411 m .63743 .80248 L p .65105 .79693 L .707 .577 .707 r
F P
0 g
s
.65105 .79693 m .66277 .79215 L .64513 .80411 L .707 .577 .707 r
F
.66167 .78404 m .66146 .76413 L .67457 .76839 L p F P
0 g
s
.67457 .76839 m .68251 .77097 L p .66167 .78404 L .707 .577 .707 r
F P
0 g
s
.33602 .66613 m .33253 .72331 L .34875 .72099 L p .707 .577 .707 r
F P
0 g
s
.34875 .72099 m .35223 .66381 L .33602 .66613 L p .707 .577 .707 r
F P
0 g
s
.18767 .7746 m .18806 .81137 L .21552 .8159 L p .707 .577 .707 r
F P
0 g
s
.6653 .68492 m .66181 .7421 L .63433 .7385 L p .707 .577 .707 r
F P
0 g
s
.63433 .7385 m .63781 .68132 L .6653 .68492 L p .707 .577 .707 r
F P
0 g
s
.63743 .80248 m .63523 .78633 L .66277 .79215 L p .707 .577 .707 r
F P
0 g
s
.61908 .29952 m .61396 .80466 L .63707 .7954 L p .707 .577 .707 r
F P
0 g
s
.63707 .7954 m .64218 .29025 L .61908 .29952 L p .707 .577 .707 r
F P
0 g
s
.18806 .81137 m .18767 .7746 L .16661 .76776 L p .707 .577 .707 r
F P
0 g
s
.16783 .7122 m .17131 .65502 L .15861 .65075 L p .707 .577 .707 r
F P
0 g
s
.68409 .80273 m .68629 .81888 L .66497 .8083 L p .707 .577 .707 r
F P
0 g
s
.66497 .8083 m .66277 .79215 L .68409 .80273 L p .707 .577 .707 r
F P
0 g
s
.15861 .65075 m .15513 .70793 L .16783 .7122 L p .707 .577 .707 r
F P
0 g
s
.16661 .76776 m .167 .80453 L .18806 .81137 L p .707 .577 .707 r
F P
0 g
s
.25329 .8752 m .25109 .85905 L .22001 .85858 L p .707 .577 .707 r
F P
0 g
s
.25109 .85905 m .25329 .8752 L .28487 .8703 L p .707 .577 .707 r
F P
0 g
s
.28487 .8703 m .28267 .85415 L .25109 .85905 L p .707 .577 .707 r
F P
0 g
s
.33156 .76934 m .33195 .80612 L .34832 .79791 L p .707 .577 .707 r
F P
0 g
s
.34832 .79791 m .34792 .76114 L .33156 .76934 L p .707 .577 .707 r
F P
0 g
s
.28267 .85415 m .28487 .8703 L .31384 .86049 L p .707 .577 .707 r
F P
0 g
s
.31384 .86049 m .31164 .84433 L .28267 .85415 L p .707 .577 .707 r
F P
0 g
s
.38109 .79867 m .38621 .29352 L .36843 .28321 L p .707 .577 .707 r
F P
0 g
s
.38621 .29352 m .38109 .79867 L .41082 .80725 L p .707 .577 .707 r
F P
0 g
s
.22221 .87473 m .22001 .85858 L .19246 .85276 L p .707 .577 .707 r
F P
0 g
s
.22001 .85858 m .22221 .87473 L .25329 .8752 L p .707 .577 .707 r
F P
0 g
s
.31164 .84433 m .31384 .86049 L .33738 .84673 L p .707 .577 .707 r
F P
0 g
s
.33738 .84673 m .33518 .83058 L .31164 .84433 L p .707 .577 .707 r
F P
0 g
s
.35223 .66381 m .34875 .72099 L .35567 .71767 L p .707 .577 .707 r
F P
0 g
s
.35567 .71767 m .35916 .66049 L .35223 .66381 L p .707 .577 .707 r
F P
0 g
s
.167 .80453 m .16661 .76776 L .15401 .75927 L p .707 .577 .707 r
F P
0 g
s
.19246 .85276 m .19466 .86891 L .22221 .87473 L p .707 .577 .707 r
F P
0 g
s
.15513 .70793 m .15861 .65075 L .15557 .64676 L p .707 .577 .707 r
F P
0 g
s
.19466 .86891 m .19246 .85276 L .17115 .84218 L p .707 .577 .707 r
F P
0 g
s
.15401 .75927 m .15441 .79605 L .167 .80453 L p .707 .577 .707 r
F P
0 g
s
.64218 .29025 m .63707 .7954 L .64706 .78473 L p .707 .577 .707 r
F P
0 g
s
.65218 .27958 m .64218 .29025 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64707 .78361 m .65218 .27958 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64707 .78361 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64297 .7737 L p .64455 .68877 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .646 .67628 L .64706 .78473 L .707 .577 .707 r
F
.64558 .63351 m .64562 .63144 L .64752 .73994 L F
.65218 .27958 m .65108 .38807 L p .64562 .63144 L F P
0 g
s
.65108 .38807 m .64752 .73994 L p .64562 .63144 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64558 .63351 L .646 .67628 L .707 .577 .707 r
F
.64752 .73994 m .64706 .78473 L p .64558 .63351 L F P
0 g
s
.64551 .63619 m .63423 .62859 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64808 .26855 m .64583 .49115 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.64583 .49115 m .64481 .59135 L p .63665 .58759 L .707 .577 .707 r
F P
0 g
s
.63339 .58609 m .64583 .49115 L .63665 .58759 L .707 .577 .707 r
F
.63534 .60907 m .63665 .58759 L p .6354 .60069 L F P
0 g
s
.64482 .59189 m .64481 .59135 L .64474 .59132 L .707 .577 .707 r
F
.64808 .26855 m .65218 .27958 L p .64558 .63351 L F P
0 g
s
.63882 .55189 m .63534 .60907 L .6452 .61238 L p .707 .577 .707 r
F P
0 g
s
.64482 .59189 m .63882 .55189 L .6452 .61238 L .707 .577 .707 r
F
.63423 .62859 m .63462 .66536 L .64471 .67216 L p F P
0 g
s
.64297 .7737 m .64341 .72984 L p .64429 .69106 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64429 .69106 L .64558 .63351 L .707 .577 .707 r
F
.64297 .7737 m .64429 .69106 L .64455 .68877 L F
.64485 .66561 m .63423 .62859 L .64471 .67216 L F
.64341 .72984 m .64481 .59135 L p .64558 .63332 L F P
0 g
s
.64341 .72984 m .64558 .63332 L .64558 .63351 L .707 .577 .707 r
F
.63339 .58609 m .63665 .58759 L .63508 .60399 L F
.63468 .60821 m .63534 .60907 L p .6354 .60069 L F P
0 g
s
.63339 .58609 m .64376 .69559 L .63876 .69119 L .707 .577 .707 r
F
.63462 .66536 m .63423 .62859 L .63309 .62496 L p F P
0 g
s
.63462 .66536 m .63309 .62496 L .63369 .65232 L .707 .577 .707 r
F
.63624 .76979 m .62519 .76338 L p .63261 .60284 L F P
0 g
s
.62519 .76338 m .62866 .4204 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.63133 .61929 m .63172 .65607 L .63392 .66312 L p .707 .577 .707 r
F P
0 g
s
.63392 .66312 m .63462 .66536 L p .63369 .65232 L .707 .577 .707 r
F P
0 g
s
.63369 .65232 m .63133 .61929 L .63392 .66312 L .707 .577 .707 r
F
.6303 .25824 m .64808 .26855 L p .63261 .60284 L F P
0 g
s
.62866 .4204 m .6303 .25824 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.64297 .7737 m .63624 .76979 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.63261 .60284 m .63339 .58609 L .63624 .76979 L .707 .577 .707 r
F
.63309 .62496 m .63133 .61929 L p .63369 .65232 L F P
0 g
s
.63578 .5479 m .6323 .60508 L .63468 .60821 L p .707 .577 .707 r
F P
0 g
s
.6354 .60069 m .63578 .5479 L .63468 .60821 L .707 .577 .707 r
F
.64481 .59135 m .64376 .69559 L p .63508 .60399 L F P
0 g
s
.63665 .58759 m .64481 .59135 L .63508 .60399 L .707 .577 .707 r
F
.64376 .69559 m .64297 .7737 L p .63876 .69119 L F P
0 g
s
.64056 .72466 m .65356 .73897 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.63836 .7085 m .64047 .72397 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64047 .72397 m .64056 .72466 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64471 .67216 m .64722 .67385 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64808 .26855 L p .64558 .63351 L .707 .577 .707 r
F P
0 g
s
.6452 .61238 m .64804 .61334 L p .64482 .59189 L .707 .577 .707 r
F P
0 g
s
.63882 .55189 m .63578 .5479 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.63665 .58759 m .63882 .55189 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.64413 .55367 m .63882 .55189 L p .64474 .59132 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64413 .55367 L .64474 .59132 L .707 .577 .707 r
F
.64722 .67385 m .64682 .63707 L .64551 .63619 L p F P
0 g
s
.64722 .67385 m .64551 .63619 L .64485 .66561 L .707 .577 .707 r
F
.65356 .73897 m .65136 .72282 L .64182 .71231 L p F P
0 g
s
.64182 .71231 m .63836 .7085 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.65356 .73897 m .64182 .71231 L .64152 .71485 L .707 .577 .707 r
F
.64804 .61334 m .65152 .55616 L .64413 .55367 L p F P
0 g
s
.64804 .61334 m .64413 .55367 L .64482 .59189 L .707 .577 .707 r
F
.65152 .55616 m .64804 .61334 L .65437 .61458 L p F P
0 g
s
.65437 .61458 m .66917 .61747 L p .6562 .57239 L .707 .577 .707 r
F P
0 g
s
.6562 .57239 m .65152 .55616 L .65437 .61458 L .707 .577 .707 r
F
.34792 .76114 m .34832 .79791 L .3554 .78871 L p F P
0 g
s
.3554 .78871 m .355 .75194 L .34792 .76114 L p .707 .577 .707 r
F P
0 g
s
.33518 .83058 m .33738 .84673 L .35318 .83038 L p .707 .577 .707 r
F P
0 g
s
.35318 .83038 m .35098 .81423 L .33518 .83058 L p .707 .577 .707 r
F P
0 g
s
.15557 .64676 m .15209 .70394 L .15513 .70793 L p .707 .577 .707 r
F P
0 g
s
.17115 .84218 m .17335 .85833 L .19466 .86891 L p .707 .577 .707 r
F P
0 g
s
.15441 .79605 m .15401 .75927 L .15111 .74998 L p .707 .577 .707 r
F P
0 g
s
.35916 .66049 m .35567 .71767 L .35264 .71368 L p .707 .577 .707 r
F P
0 g
s
.35264 .71368 m .35612 .65651 L .35916 .66049 L p .707 .577 .707 r
F P
0 g
s
.36331 .78835 m .36843 .28321 L .36433 .27217 L p .707 .577 .707 r
F P
0 g
s
.36843 .28321 m .36331 .78835 L .38109 .79867 L p .707 .577 .707 r
F P
0 g
s
.17335 .85833 m .17115 .84218 L .15815 .82786 L p .707 .577 .707 r
F P
0 g
s
.35098 .81423 m .35318 .83038 L .35969 .81303 L p .707 .577 .707 r
F P
0 g
s
.35969 .81303 m .35749 .79688 L .35098 .81423 L p .707 .577 .707 r
F P
0 g
s
.15111 .74998 m .15151 .78675 L .15441 .79605 L p .707 .577 .707 r
F P
0 g
s
.15209 .70394 m .15557 .64676 L .1625 .64345 L p .707 .577 .707 r
F P
0 g
s
.15815 .82786 m .16035 .84401 L .17335 .85833 L p .707 .577 .707 r
F P
0 g
s
.355 .75194 m .3554 .78871 L .3525 .77942 L p .707 .577 .707 r
F P
0 g
s
.3525 .77942 m .3521 .74264 L .355 .75194 L p .707 .577 .707 r
F P
0 g
s
.1625 .64345 m .15902 .70063 L .15209 .70394 L p .707 .577 .707 r
F P
0 g
s
.16035 .84401 m .15815 .82786 L .15474 .81121 L p .707 .577 .707 r
F P
0 g
s
.15151 .78675 m .15111 .74998 L .15819 .74077 L p .707 .577 .707 r
F P
0 g
s
.35612 .65651 m .35264 .71368 L .33993 .70941 L p .707 .577 .707 r
F P
0 g
s
.33993 .70941 m .34342 .65223 L .35612 .65651 L p .707 .577 .707 r
F P
0 g
s
.35749 .79688 m .35969 .81303 L .35628 .79638 L p .707 .577 .707 r
F P
0 g
s
.35628 .79638 m .35408 .78023 L .35749 .79688 L p .707 .577 .707 r
F P
0 g
s
.15474 .81121 m .15694 .82736 L .16035 .84401 L p .707 .577 .707 r
F P
0 g
s
.15819 .74077 m .15859 .77755 L .15151 .78675 L p .707 .577 .707 r
F P
0 g
s
.15902 .70063 m .1625 .64345 L .17871 .64113 L p .707 .577 .707 r
F P
0 g
s
.36433 .27217 m .35922 .77732 L .36331 .78835 L p .707 .577 .707 r
F P
0 g
s
.35922 .77732 m .36433 .27217 L .37433 .2615 L p .707 .577 .707 r
F P
0 g
s
.3521 .74264 m .3525 .77942 L .3399 .77093 L p .707 .577 .707 r
F P
0 g
s
.3399 .77093 m .33951 .73416 L .3521 .74264 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17871 .64113 m .17523 .69831 L .15902 .70063 L p .707 .577 .707 r
F P
0 g
s
.15694 .82736 m .15474 .81121 L .16125 .79386 L p .707 .577 .707 r
F P
0 g
s
.15859 .77755 m .15819 .74077 L .17456 .73257 L p .707 .577 .707 r
F P
0 g
s
.34342 .65223 m .33993 .70941 L .31881 .70528 L p .707 .577 .707 r
F P
0 g
s
.31881 .70528 m .32229 .6481 L .34342 .65223 L p .707 .577 .707 r
F P
0 g
s
.35408 .78023 m .35628 .79638 L .34328 .78207 L p .707 .577 .707 r
F P
0 g
s
.34328 .78207 m .34108 .76592 L .35408 .78023 L p .707 .577 .707 r
F P
0 g
s
.16125 .79386 m .16345 .81002 L .15694 .82736 L p .707 .577 .707 r
F P
0 g
s
.17456 .73257 m .17495 .76935 L .15859 .77755 L p .707 .577 .707 r
F P
0 g
s
.17523 .69831 m .17871 .64113 L .20262 .64003 L p .707 .577 .707 r
F P
0 g
s
.33951 .73416 m .3399 .77093 L .31884 .76409 L p .707 .577 .707 r
F P
0 g
s
.31884 .76409 m .31866 .74723 L p .33951 .73416 L .707 .577 .707 r
F P
0 g
s
.31845 .72732 m .31884 .76409 L .29138 .75957 L p .707 .577 .707 r
F P
0 g
s
.31976 .75533 m .32196 .77148 L .30212 .76729 L p .707 .577 .707 r
F P
0 g
s
.30212 .76729 m .29442 .76567 L p .30804 .76011 L .707 .577 .707 r
F P
0 g
s
.30804 .76011 m .31976 .75533 L .30212 .76729 L .707 .577 .707 r
F
.31866 .74723 m .31845 .72732 L .33156 .73158 L p F P
0 g
s
.33156 .73158 m .33951 .73416 L p .31866 .74723 L .707 .577 .707 r
F P
0 g
s
.20262 .64003 m .19914 .69721 L .17523 .69831 L p .707 .577 .707 r
F P
0 g
s
.16345 .81002 m .16125 .79386 L .17705 .77751 L p .707 .577 .707 r
F P
0 g
s
.17495 .76935 m .17456 .73257 L .1986 .72616 L p .707 .577 .707 r
F P
0 g
s
.32229 .6481 m .31881 .70528 L .29132 .70169 L p .707 .577 .707 r
F P
0 g
s
.29132 .70169 m .29481 .64451 L .32229 .6481 L p .707 .577 .707 r
F P
0 g
s
.34108 .76592 m .34328 .78207 L .32196 .77148 L p .707 .577 .707 r
F P
0 g
s
.32196 .77148 m .31976 .75533 L .34108 .76592 L p .707 .577 .707 r
F P
0 g
s
.36921 .76665 m .37433 .2615 L .39743 .25224 L p .707 .577 .707 r
F P
0 g
s
.37433 .2615 m .36921 .76665 L .35922 .77732 L p .707 .577 .707 r
F P
0 g
s
.7278 .62377 m .73128 .56659 L .70013 .56389 L p .707 .577 .707 r
F P
0 g
s
.73128 .56659 m .7278 .62377 L .75956 .62531 L p .707 .577 .707 r
F P
0 g
s
.75956 .62531 m .76305 .56813 L .73128 .56659 L p .707 .577 .707 r
F P
0 g
s
.19914 .69721 m .20262 .64003 L .23189 .64027 L p .707 .577 .707 r
F P
0 g
s
.17705 .77751 m .17925 .79366 L .16345 .81002 L p .707 .577 .707 r
F P
0 g
s
.76305 .56813 m .75956 .62531 L .78883 .62554 L p .707 .577 .707 r
F P
0 g
s
.78883 .62554 m .79232 .56836 L .76305 .56813 L p .707 .577 .707 r
F P
0 g
s
.1986 .72616 m .199 .76294 L .17495 .76935 L p .707 .577 .707 r
F P
0 g
s
.29138 .75957 m .29119 .74202 L p .31845 .72732 L .707 .577 .707 r
F P
0 g
s
.29099 .72279 m .29138 .75957 L .26021 .7578 L p .707 .577 .707 r
F P
0 g
s
.29222 .74952 m .29442 .76567 L .26926 .76528 L p .707 .577 .707 r
F P
0 g
s
.26926 .76528 m .26333 .76519 L p .27565 .75851 L .707 .577 .707 r
F P
0 g
s
.27565 .75851 m .29222 .74952 L .26926 .76528 L .707 .577 .707 r
F
.29119 .74202 m .29099 .72279 L .30685 .72541 L p F P
0 g
s
.30685 .72541 m .31845 .72732 L p .29119 .74202 L .707 .577 .707 r
F P
0 g
s
.69665 .62107 m .70013 .56389 L .67265 .56029 L p .707 .577 .707 r
F P
0 g
s
.70013 .56389 m .69665 .62107 L .7278 .62377 L p .707 .577 .707 r
F P
0 g
s
.23189 .64027 m .22841 .69744 L .19914 .69721 L p .707 .577 .707 r
F P
0 g
s
.29481 .64451 m .29132 .70169 L .26018 .69899 L p .707 .577 .707 r
F P
0 g
s
.26018 .69899 m .26366 .64181 L .29481 .64451 L p .707 .577 .707 r
F P
0 g
s
.7269 .68698 m .72651 .6502 L .69534 .64843 L p .707 .577 .707 r
F P
0 g
s
.72651 .6502 m .7269 .68698 L .75874 .68582 L p .707 .577 .707 r
F P
0 g
s
.75874 .68582 m .75834 .64904 L .72651 .6502 L p .707 .577 .707 r
F P
0 g
s
.17925 .79366 m .17705 .77751 L .20059 .76376 L p .707 .577 .707 r
F P
0 g
s
.22841 .69744 m .23189 .64027 L .26366 .64181 L p .707 .577 .707 r
F P
0 g
s
.67265 .56029 m .66917 .61747 L .69665 .62107 L p .707 .577 .707 r
F P
0 g
s
.75834 .64904 m .75874 .68582 L .78812 .68184 L p .707 .577 .707 r
F P
0 g
s
.78812 .68184 m .78772 .64506 L .75834 .64904 L p .707 .577 .707 r
F P
0 g
s
.199 .76294 m .1986 .72616 L .22798 .72219 L p .707 .577 .707 r
F P
0 g
s
.79232 .56836 m .78883 .62554 L .81275 .62445 L p .707 .577 .707 r
F P
0 g
s
.81275 .62445 m .81623 .56727 L .79232 .56836 L p .707 .577 .707 r
F P
0 g
s
.26366 .64181 m .26018 .69899 L .22841 .69744 L p .707 .577 .707 r
F P
0 g
s
.29442 .76567 m .29222 .74952 L .31976 .75533 L p .707 .577 .707 r
F P
0 g
s
.69573 .68521 m .69534 .64843 L .66788 .64391 L p .707 .577 .707 r
F P
0 g
s
.69534 .64843 m .69573 .68521 L .7269 .68698 L p .707 .577 .707 r
F P
0 g
s
.6303 .25824 m .62519 .76338 L .59546 .75479 L p .707 .577 .707 r
F P
0 g
s
.59546 .75479 m .60057 .24965 L .6303 .25824 L p .707 .577 .707 r
F P
0 g
s
.22838 .75896 m .22822 .74409 L p .25982 .72102 L .707 .577 .707 r
F P
0 g
s
.22822 .74409 m .22798 .72219 L .24209 .72167 L p .707 .577 .707 r
F P
0 g
s
.24209 .72167 m .25982 .72102 L p .22822 .74409 L .707 .577 .707 r
F P
0 g
s
.22798 .72219 m .22838 .75896 L .199 .76294 L p .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .20059 .76376 L .22015 .75713 L p .707 .577 .707 r
F P
0 g
s
.22015 .75713 m .22956 .75395 L p .21096 .77198 L .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .22015 .75713 L .21096 .77198 L .707 .577 .707 r
F
.25982 .72102 m .26021 .7578 L .22838 .75896 L p F P
0 g
s
.23176 .7701 m .22956 .75395 L .25202 .75046 L p .707 .577 .707 r
F P
0 g
s
.26021 .7578 m .26003 .74093 L p .29099 .72279 L .707 .577 .707 r
F P
0 g
s
.25202 .75046 m .26113 .74904 L p .24118 .76335 L .707 .577 .707 r
F P
0 g
s
.23176 .7701 m .25202 .75046 L .24118 .76335 L .707 .577 .707 r
F
.26003 .74093 m .25982 .72102 L .27601 .72194 L p F P
0 g
s
.27601 .72194 m .29099 .72279 L p .26003 .74093 L .707 .577 .707 r
F P
0 g
s
.66917 .61747 m .67265 .56029 L .65152 .55616 L p .707 .577 .707 r
F P
0 g
s
.20059 .76376 m .20279 .77991 L .17925 .79366 L p .707 .577 .707 r
F P
0 g
s
.78772 .64506 m .78812 .68184 L .81217 .67543 L p .707 .577 .707 r
F P
0 g
s
.81217 .67543 m .81177 .63866 L .78772 .64506 L p .707 .577 .707 r
F P
0 g
s
.66788 .64391 m .66827 .68069 L .69573 .68521 L p .707 .577 .707 r
F P
0 g
s
.26333 .76519 m .26113 .74904 L .29222 .74952 L p .707 .577 .707 r
F P
0 g
s
.66827 .68069 m .66788 .64391 L .64682 .63707 L p .707 .577 .707 r
F P
0 g
s
.39743 .25224 m .39233 .75627 L p .36921 .76665 L .707 .577 .707 r
F P
0 g
s
.39232 .75739 m .39743 .25224 L .43138 .24529 L p .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .39232 .75739 L p .39708 .69499 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .41038 .52063 L .41813 .6089 L .707 .577 .707 r
F
.42158 .64821 m .44511 .64502 L p .41875 .61599 L F P
0 g
s
.42311 .58855 m .44583 .58873 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.42811 .5681 m .43138 .24529 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.43639 .56773 m .43109 .55592 L .42811 .5681 L .707 .577 .707 r
F
.43639 .56773 m .42811 .5681 L .42311 .58855 L F
.43138 .24529 m .47286 .24134 L p .44301 .56744 L F P
0 g
s
.43138 .24529 m .42811 .5681 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.41038 .52063 m .43138 .24529 L .41813 .6089 L .707 .577 .707 r
F
.47286 .24134 m .46957 .56626 L p .44713 .56725 L F P
0 g
s
.44301 .56744 m .44441 .55222 L .44713 .56725 L .707 .577 .707 r
F
.44441 .55222 m .47286 .24134 L .44713 .56725 L F
.44713 .56725 m .44583 .58873 L .45098 .58849 L p F P
0 g
s
.44583 .58873 m .44713 .56725 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.46957 .56626 m .46774 .74648 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.45301 .61856 m .44471 .60825 L .4509 .64348 L .707 .577 .707 r
F
.45739 .5668 m .46957 .56626 L .4519 .63173 L F
.45409 .60575 m .44471 .60825 L p .45301 .61856 L F P
0 g
s
.44301 .56744 m .45739 .5668 L .4519 .63173 L .707 .577 .707 r
F
.44931 .53155 m .44713 .56725 L p .45785 .57691 L F P
0 g
s
.46837 .68446 m .46908 .61467 L p .47111 .71246 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47122 .40351 L p .47115 .60696 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47115 .60696 L .47111 .71246 L .707 .577 .707 r
F
.48764 .54547 m .47122 .40351 L .5178 .24076 L F
.47111 .71246 m .47115 .60696 L .48764 .54547 L F
.47115 .60696 m .47122 .40351 L .48764 .54547 L F
.46774 .74648 m .46837 .68446 L p .47111 .71246 L F P
0 g
s
.46774 .74648 m .44197 .74894 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.5178 .24076 m .51269 .74591 L .46774 .74648 L p .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .47238 .67441 L .44946 .6878 L p .707 .577 .707 r
F P
0 g
s
.44946 .6878 m .44885 .68816 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .44946 .6878 L .44935 .68821 L .707 .577 .707 r
F
.45105 .70431 m .47458 .69056 L p .44935 .68821 L F P
0 g
s
.44885 .68816 m .44902 .68945 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.44902 .68945 m .45105 .70431 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .45492 .54695 L .45785 .57691 L .707 .577 .707 r
F
.45492 .54695 m .44931 .53155 L .45785 .57691 L F
.47122 .40351 m .47286 .24134 L .47981 .24125 L p F P
0 g
s
.47981 .24125 m .5178 .24076 L p .47122 .40351 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .46876 .60184 L .4606 .60401 L p .707 .577 .707 r
F P
0 g
s
.4606 .60401 m .45409 .60575 L p .45984 .6183 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .4606 .60401 L .45984 .6183 L .707 .577 .707 r
F
.46916 .63862 m .45409 .60575 L .45301 .61856 L F
.44471 .60825 m .44511 .64502 L .4509 .64348 L p F P
0 g
s
.40855 .64809 m .42135 .66486 L .42627 .75044 L .707 .577 .707 r
F
.44511 .64502 m .44471 .60825 L .41839 .61181 L p F P
0 g
s
.44511 .64502 m .41839 .61181 L .41875 .61599 L .707 .577 .707 r
F
.42811 .5681 m .42671 .70658 L p .41813 .6089 L F P
0 g
s
.42671 .70658 m .42627 .75044 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .44301 .56744 L .4519 .63173 L .707 .577 .707 r
F
.44197 .74894 m .42627 .75044 L p .4519 .63173 L F P
0 g
s
.42627 .75044 m .42811 .5681 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.45105 .70431 m .45095 .70363 L p .41987 .69797 L .707 .577 .707 r
F P
0 g
s
.45095 .70363 m .44885 .68816 L .44114 .69077 L p .707 .577 .707 r
F P
0 g
s
.44114 .69077 m .41987 .69797 L p .45095 .70363 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .40855 .64809 L .42627 .75044 L .707 .577 .707 r
F
.40855 .64809 m .41813 .6089 L .42135 .66486 L F
.41839 .61181 m .41533 .61222 L p .41875 .61599 L F P
0 g
s
.4509 .64348 m .46916 .63862 L p .45301 .61856 L .707 .577 .707 r
F P
0 g
s
.45098 .58849 m .46974 .58763 L p .44713 .56725 L .707 .577 .707 r
F P
0 g
s
.44931 .53155 m .42004 .53131 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.44713 .56725 m .44931 .53155 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.41533 .61222 m .41573 .649 L .42158 .64821 L p .707 .577 .707 r
F P
0 g
s
.41875 .61599 m .41533 .61222 L .42158 .64821 L .707 .577 .707 r
F
.42004 .53131 m .41655 .58849 L .42311 .58855 L p F P
0 g
s
.43109 .55592 m .42004 .53131 L .42311 .58855 L .707 .577 .707 r
F
.38827 .52977 m .38479 .58695 L .40704 .58803 L p F P
0 g
s
.40704 .58803 m .41655 .58849 L p .40846 .5717 L .707 .577 .707 r
F P
0 g
s
.40846 .5717 m .38827 .52977 L .40704 .58803 L .707 .577 .707 r
F
.39233 .75627 m .39232 .75739 L .39223 .75742 L p F P
0 g
s
.39223 .75742 m .36921 .76665 L p .39233 .75627 L .707 .577 .707 r
F P
0 g
s
.81623 .56727 m .81275 .62445 L .82896 .62213 L p .707 .577 .707 r
F P
0 g
s
.82896 .62213 m .83244 .56495 L .81623 .56727 L p .707 .577 .707 r
F P
0 g
s
.22956 .75395 m .23176 .7701 L .20279 .77991 L p .707 .577 .707 r
F P
0 g
s
.26113 .74904 m .26333 .76519 L .23176 .7701 L p .707 .577 .707 r
F P
0 g
s
.64682 .63707 m .64722 .67385 L .66827 .68069 L p .707 .577 .707 r
F P
0 g
s
.81177 .63866 m .81217 .67543 L .82853 .66723 L p .707 .577 .707 r
F P
0 g
s
.82853 .66723 m .82814 .63045 L .81177 .63866 L p .707 .577 .707 r
F P
0 g
s
.73351 .75585 m .73131 .7397 L .70023 .73922 L p .707 .577 .707 r
F P
0 g
s
.73131 .7397 m .73351 .75585 L .76508 .75094 L p .707 .577 .707 r
F P
0 g
s
.76508 .75094 m .76288 .73479 L .73131 .7397 L p .707 .577 .707 r
F P
0 g
s
.76288 .73479 m .76508 .75094 L .79406 .74113 L p .707 .577 .707 r
F P
0 g
s
.79406 .74113 m .79186 .72498 L .76288 .73479 L p .707 .577 .707 r
F P
0 g
s
.60057 .24965 m .59546 .75479 L .55669 .74877 L p .707 .577 .707 r
F P
0 g
s
.55669 .74877 m .56181 .24363 L .60057 .24965 L p .707 .577 .707 r
F P
0 g
s
.70243 .75537 m .70023 .73922 L .67268 .7334 L p .707 .577 .707 r
F P
0 g
s
.70023 .73922 m .70243 .75537 L .73351 .75585 L p .707 .577 .707 r
F P
0 g
s
.79186 .72498 m .79406 .74113 L .81759 .72738 L p .707 .577 .707 r
F P
0 g
s
.81759 .72738 m .81539 .71122 L .79186 .72498 L p .707 .577 .707 r
F P
0 g
s
.83244 .56495 m .82896 .62213 L .83589 .61881 L p .707 .577 .707 r
F P
0 g
s
.83589 .61881 m .83937 .56163 L .83244 .56495 L p .707 .577 .707 r
F P
0 g
s
.67268 .7334 m .67488 .74955 L .70243 .75537 L p .707 .577 .707 r
F P
0 g
s
.67488 .74955 m .67268 .7334 L .65136 .72282 L p .707 .577 .707 r
F P
0 g
s
.82814 .63045 m .82853 .66723 L .83561 .65803 L p .707 .577 .707 r
F P
0 g
s
.83561 .65803 m .83521 .62125 L .82814 .63045 L p .707 .577 .707 r
F P
0 g
s
.56181 .24363 m .55669 .74877 L .51269 .74591 L p .707 .577 .707 r
F P
0 g
s
.51269 .74591 m .5178 .24076 L .56181 .24363 L p .707 .577 .707 r
F P
0 g
s
.81539 .71122 m .81759 .72738 L .83339 .71102 L p .707 .577 .707 r
F P
0 g
s
.83339 .71102 m .83119 .69487 L .81539 .71122 L p .707 .577 .707 r
F P
0 g
s
.65136 .72282 m .65356 .73897 L .67488 .74955 L p .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83521 .62125 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83271 .64873 m .83242 .62188 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83242 .62188 m .83231 .61195 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83271 .64873 L .82011 .64025 L p .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .83231 .61195 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.82011 .64025 m .81985 .61546 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81985 .61546 m .81972 .60347 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .82011 .64025 L .79906 .63341 L p .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .81972 .60347 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79906 .63341 m .7988 .60995 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.7988 .60995 m .79866 .59663 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .79906 .63341 L .7716 .62888 L p .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .79866 .59663 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7716 .62888 m .77135 .60588 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.77135 .60588 m .7712 .59211 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .7716 .62888 L .74043 .62711 L p .707 .577 .707 r
F P
0 g
s
.74003 .59034 m .7712 .59211 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74043 .62711 m .74017 .60366 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74017 .60366 m .74003 .59034 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.7082 .5915 m .74003 .59034 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70859 .62828 m .70833 .60349 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70833 .60349 m .7082 .5915 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .7082 .5915 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67921 .63225 m .67892 .6054 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67892 .6054 m .67882 .59548 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.65516 .63866 m .65477 .60188 L .67882 .59548 L p .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .67921 .63225 L .65516 .63866 L p .707 .577 .707 r
F P
0 g
s
.68284 .54117 m .67935 .59835 L .67695 .59846 L p .707 .577 .707 r
F P
0 g
s
.67695 .59846 m .65544 .59944 L p .66903 .57054 L .707 .577 .707 r
F P
0 g
s
.66903 .57054 m .68284 .54117 L .67695 .59846 L .707 .577 .707 r
F
.7082 .5915 m .70859 .62828 L .67921 .63225 L p F P
0 g
s
.71211 .5414 m .70863 .59858 L .70605 .59856 L p .707 .577 .707 r
F P
0 g
s
.70605 .59856 m .67935 .59835 L p .6941 .5727 L .707 .577 .707 r
F P
0 g
s
.6941 .5727 m .71211 .5414 L .70605 .59856 L .707 .577 .707 r
F
.74003 .59034 m .74043 .62711 L .70859 .62828 L p F P
0 g
s
.74387 .54294 m .74039 .60012 L .73818 .60002 L p .707 .577 .707 r
F P
0 g
s
.73818 .60002 m .70863 .59858 L p .72407 .57421 L .707 .577 .707 r
F P
0 g
s
.72407 .57421 m .74387 .54294 L .73818 .60002 L .707 .577 .707 r
F
.77502 .54564 m .77154 .60282 L .7697 .60266 L p F P
0 g
s
.7697 .60266 m .74039 .60012 L p .75587 .57577 L .707 .577 .707 r
F P
0 g
s
.75587 .57577 m .77502 .54564 L .7697 .60266 L .707 .577 .707 r
F
.8025 .54924 m .79902 .60642 L .79736 .6062 L p F P
0 g
s
.79736 .6062 m .77154 .60282 L p .78623 .57739 L .707 .577 .707 r
F P
0 g
s
.78623 .57739 m .8025 .54924 L .79736 .6062 L .707 .577 .707 r
F
.82363 .55337 m .82015 .61055 L .81875 .61028 L p F P
0 g
s
.81875 .61028 m .79902 .60642 L p .81201 .57841 L .707 .577 .707 r
F P
0 g
s
.81201 .57841 m .82363 .55337 L .81875 .61028 L .707 .577 .707 r
F
.83633 .55764 m .83285 .61482 L .83208 .61456 L p F P
0 g
s
.83208 .61456 m .82015 .61055 L p .83032 .57729 L .707 .577 .707 r
F P
0 g
s
.83032 .57729 m .83633 .55764 L .83208 .61456 L .707 .577 .707 r
F
.83937 .56163 m .83589 .61881 L .83285 .61482 L p F P
0 g
s
.83285 .61482 m .83633 .55764 L .83937 .56163 L p .707 .577 .707 r
F P
0 g
s
.83119 .69487 m .83339 .71102 L .83991 .69367 L p .707 .577 .707 r
F P
0 g
s
.83991 .69367 m .83771 .67752 L .83119 .69487 L p .707 .577 .707 r
F P
0 g
s
.83521 .62125 m .83561 .65803 L .83271 .64873 L p .707 .577 .707 r
F P
0 g
s
.6323 .60508 m .63578 .5479 L .64271 .54458 L p .707 .577 .707 r
F P
0 g
s
.64271 .54458 m .63923 .60176 L .6323 .60508 L p .707 .577 .707 r
F P
0 g
s
.63172 .65607 m .63133 .61929 L .6384 .61009 L p .707 .577 .707 r
F P
0 g
s
.64056 .72466 m .63836 .7085 L .63495 .69186 L p .707 .577 .707 r
F P
0 g
s
.83771 .67752 m .83991 .69367 L .8365 .67703 L p .707 .577 .707 r
F P
0 g
s
.8365 .67703 m .8343 .66088 L .83771 .67752 L p .707 .577 .707 r
F P
0 g
s
.6384 .61009 m .6388 .64686 L .63172 .65607 L p .707 .577 .707 r
F P
0 g
s
.82015 .61055 m .82363 .55337 L .83633 .55764 L p .707 .577 .707 r
F P
0 g
s
.63495 .69186 m .63715 .70801 L .64056 .72466 L p .707 .577 .707 r
F P
0 g
s
.38479 .58695 m .38827 .52977 L .35713 .52707 L p .707 .577 .707 r
F P
0 g
s
.41655 .58849 m .42004 .53131 L .38827 .52977 L p .707 .577 .707 r
F P
0 g
s
.63923 .60176 m .64271 .54458 L .65892 .54226 L p .707 .577 .707 r
F P
0 g
s
.35364 .58425 m .35713 .52707 L .32964 .52348 L p .707 .577 .707 r
F P
0 g
s
.35713 .52707 m .35364 .58425 L .38479 .58695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38389 .65016 m .3835 .61339 L .35233 .61162 L p .707 .577 .707 r
F P
0 g
s
.3835 .61339 m .38389 .65016 L .41573 .649 L p .707 .577 .707 r
F P
0 g
s
.41573 .649 m .41533 .61222 L .3835 .61339 L p .707 .577 .707 r
F P
0 g
s
.65892 .54226 m .65544 .59944 L .63923 .60176 L p .707 .577 .707 r
F P
0 g
s
.63715 .70801 m .63495 .69186 L .64146 .67451 L p .707 .577 .707 r
F P
0 g
s
.6388 .64686 m .6384 .61009 L .65477 .60188 L p .707 .577 .707 r
F P
0 g
s
.32964 .52348 m .32616 .58066 L .35364 .58425 L p .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .47322 .53045 L .44931 .53155 L p .707 .577 .707 r
F P
0 g
s
.35272 .64839 m .35233 .61162 L .32487 .60709 L p .707 .577 .707 r
F P
0 g
s
.35233 .61162 m .35272 .64839 L .38389 .65016 L p .707 .577 .707 r
F P
0 g
s
.8343 .66088 m .8365 .67703 L .8235 .66271 L p .707 .577 .707 r
F P
0 g
s
.8235 .66271 m .8213 .64656 L .8343 .66088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32616 .58066 m .32964 .52348 L .30851 .51934 L p .707 .577 .707 r
F P
0 g
s
.64146 .67451 m .64366 .69066 L .63715 .70801 L p .707 .577 .707 r
F P
0 g
s
.65477 .60188 m .65516 .63866 L .6388 .64686 L p .707 .577 .707 r
F P
0 g
s
.79902 .60642 m .8025 .54924 L .82363 .55337 L p .707 .577 .707 r
F P
0 g
s
.32487 .60709 m .32526 .64387 L .35272 .64839 L p .707 .577 .707 r
F P
0 g
s
.30851 .51934 m .30503 .57652 L .32616 .58066 L p .707 .577 .707 r
F P
0 g
s
.65544 .59944 m .65892 .54226 L .68284 .54117 L p .707 .577 .707 r
F P
0 g
s
.32526 .64387 m .32487 .60709 L .30381 .60026 L p .707 .577 .707 r
F P
0 g
s
.47322 .53045 m .46974 .58763 L .48595 .58531 L p .707 .577 .707 r
F P
0 g
s
.48595 .58531 m .48943 .52813 L .47322 .53045 L p .707 .577 .707 r
F P
0 g
s
.64366 .69066 m .64146 .67451 L .65726 .65816 L p .707 .577 .707 r
F P
0 g
s
.8213 .64656 m .8235 .66271 L .80218 .65213 L p .707 .577 .707 r
F P
0 g
s
.80218 .65213 m .79998 .63598 L .8213 .64656 L p .707 .577 .707 r
F P
0 g
s
.30381 .60026 m .30421 .63703 L .32526 .64387 L p .707 .577 .707 r
F P
0 g
s
.46876 .60184 m .46916 .63862 L .48552 .63041 L p .707 .577 .707 r
F P
0 g
s
.48552 .63041 m .48513 .59364 L .46876 .60184 L p .707 .577 .707 r
F P
0 g
s
.30503 .57652 m .30851 .51934 L .29581 .51507 L p .707 .577 .707 r
F P
0 g
s
.77154 .60282 m .77502 .54564 L .8025 .54924 L p .707 .577 .707 r
F P
0 g
s
.3905 .71903 m .3883 .70288 L .35722 .7024 L p .707 .577 .707 r
F P
0 g
s
.3883 .70288 m .3905 .71903 L .42207 .71413 L p .707 .577 .707 r
F P
0 g
s
.42207 .71413 m .41987 .69797 L .3883 .70288 L p .707 .577 .707 r
F P
0 g
s
.65726 .65816 m .65946 .67431 L .64366 .69066 L p .707 .577 .707 r
F P
0 g
s
.41987 .69797 m .42207 .71413 L .45105 .70431 L p .707 .577 .707 r
F P
0 g
s
.29581 .51507 m .29233 .57225 L .30503 .57652 L p .707 .577 .707 r
F P
0 g
s
.67935 .59835 m .68284 .54117 L .71211 .5414 L p .707 .577 .707 r
F P
0 g
s
.35942 .71855 m .35722 .7024 L .32967 .69659 L p .707 .577 .707 r
F P
0 g
s
.35722 .7024 m .35942 .71855 L .3905 .71903 L p .707 .577 .707 r
F P
0 g
s
.30421 .63703 m .30381 .60026 L .29122 .59177 L p .707 .577 .707 r
F P
0 g
s
.65946 .67431 m .65726 .65816 L .6808 .6444 L p .707 .577 .707 r
F P
0 g
s
.74039 .60012 m .74387 .54294 L .77502 .54564 L p .707 .577 .707 r
F P
0 g
s
.48943 .52813 m .48595 .58531 L .49288 .58199 L p .707 .577 .707 r
F P
0 g
s
.49288 .58199 m .49636 .52481 L .48943 .52813 L p .707 .577 .707 r
F P
0 g
s
.79998 .63598 m .80218 .65213 L .77463 .64631 L p .707 .577 .707 r
F P
0 g
s
.77463 .64631 m .77243 .63016 L .79998 .63598 L p .707 .577 .707 r
F P
0 g
s
.32967 .69659 m .33187 .71274 L .35942 .71855 L p .707 .577 .707 r
F P
0 g
s
.70863 .59858 m .71211 .5414 L .74387 .54294 L p .707 .577 .707 r
F P
0 g
s
.29122 .59177 m .29161 .62855 L .30421 .63703 L p .707 .577 .707 r
F P
0 g
s
.33187 .71274 m .32967 .69659 L .30835 .686 L p .707 .577 .707 r
F P
0 g
s
.6808 .6444 m .683 .66055 L .65946 .67431 L p .707 .577 .707 r
F P
0 g
s
.48513 .59364 m .48552 .63041 L .4926 .62121 L p .707 .577 .707 r
F P
0 g
s
.4926 .62121 m .49221 .58443 L .48513 .59364 L p .707 .577 .707 r
F P
0 g
s
.47238 .67441 m .47458 .69056 L .49038 .67421 L p .707 .577 .707 r
F P
0 g
s
.49038 .67421 m .48818 .65806 L .47238 .67441 L p .707 .577 .707 r
F P
0 g
s
.29233 .57225 m .29581 .51507 L .29277 .51108 L p .707 .577 .707 r
F P
0 g
s
.683 .66055 m .6808 .6444 L .70977 .63459 L p .707 .577 .707 r
F P
0 g
s
.77243 .63016 m .77463 .64631 L .74355 .64583 L p .707 .577 .707 r
F P
0 g
s
.74355 .64583 m .74135 .62968 L .77243 .63016 L p .707 .577 .707 r
F P
0 g
s
.30835 .686 m .31055 .70216 L .33187 .71274 L p .707 .577 .707 r
F P
0 g
s
.29277 .51108 m .28929 .56826 L .29233 .57225 L p .707 .577 .707 r
F P
0 g
s
.29161 .62855 m .29122 .59177 L .28832 .58247 L p .707 .577 .707 r
F P
0 g
s
.71197 .65074 m .70977 .63459 L .74135 .62968 L p .707 .577 .707 r
F P
0 g
s
.70977 .63459 m .71197 .65074 L .683 .66055 L p .707 .577 .707 r
F P
0 g
s
.74135 .62968 m .74355 .64583 L .71197 .65074 L p .707 .577 .707 r
F P
0 g
s
.31055 .70216 m .30835 .686 L .29535 .67169 L p .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .49221 .58443 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4897 .61191 m .48941 .58506 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.48941 .58506 m .4893 .57514 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .4897 .61191 L .4771 .60343 L p .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4893 .57514 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.4771 .60343 m .47684 .57865 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47684 .57865 m .47671 .56665 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4771 .60343 L .45605 .59659 L p .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .47671 .56665 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45605 .59659 m .45579 .57314 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45579 .57314 m .45565 .55981 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .45605 .59659 L .42859 .59207 L p .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .45565 .55981 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42859 .59207 m .42834 .56907 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42834 .56907 m .42819 .55529 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .42859 .59207 L .39741 .5903 L p .707 .577 .707 r
F P
0 g
s
.39702 .55352 m .42819 .55529 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39741 .5903 m .39716 .56684 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39716 .56684 m .39702 .55352 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.36519 .55468 m .39702 .55352 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36558 .59146 m .36532 .56668 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36532 .56668 m .36519 .55468 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .36519 .55468 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.3362 .59544 m .33591 .56859 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.33591 .56859 m .33581 .55866 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.31215 .60184 m .31176 .56507 L .33581 .55866 L p .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .3362 .59544 L .31215 .60184 L p .707 .577 .707 r
F P
0 g
s
.33983 .50435 m .33634 .56153 L .33394 .56164 L p .707 .577 .707 r
F P
0 g
s
.33394 .56164 m .31243 .56263 L p .32602 .53372 L .707 .577 .707 r
F P
0 g
s
.32602 .53372 m .33983 .50435 L .33394 .56164 L .707 .577 .707 r
F
.36519 .55468 m .36558 .59146 L .3362 .59544 L p F P
0 g
s
.3691 .50459 m .36561 .56176 L .36304 .56174 L p .707 .577 .707 r
F P
0 g
s
.36304 .56174 m .33634 .56153 L p .35109 .53589 L .707 .577 .707 r
F P
0 g
s
.35109 .53589 m .3691 .50459 L .36304 .56174 L .707 .577 .707 r
F
.39702 .55352 m .39741 .5903 L .36558 .59146 L p F P
0 g
s
.40086 .50613 m .39738 .56331 L .39517 .5632 L p .707 .577 .707 r
F P
0 g
s
.39517 .5632 m .36561 .56176 L p .38106 .53739 L .707 .577 .707 r
F P
0 g
s
.38106 .53739 m .40086 .50613 L .39517 .5632 L .707 .577 .707 r
F
.43201 .50883 m .42853 .56601 L .42668 .56585 L p F P
0 g
s
.42668 .56585 m .39738 .56331 L p .41286 .53895 L .707 .577 .707 r
F P
0 g
s
.41286 .53895 m .43201 .50883 L .42668 .56585 L .707 .577 .707 r
F
.45949 .51242 m .45601 .5696 L .45435 .56938 L p F P
0 g
s
.45435 .56938 m .42853 .56601 L p .44322 .54057 L .707 .577 .707 r
F P
0 g
s
.44322 .54057 m .45949 .51242 L .45435 .56938 L .707 .577 .707 r
F
.48062 .51655 m .47714 .57373 L .47574 .57346 L p F P
0 g
s
.47574 .57346 m .45601 .5696 L p .469 .5416 L .707 .577 .707 r
F P
0 g
s
.469 .5416 m .48062 .51655 L .47574 .57346 L .707 .577 .707 r
F
.49332 .52083 m .48984 .57801 L .48907 .57774 L p F P
0 g
s
.48907 .57774 m .47714 .57373 L p .48731 .54047 L .707 .577 .707 r
F P
0 g
s
.48731 .54047 m .49332 .52083 L .48907 .57774 L .707 .577 .707 r
F
.49636 .52481 m .49288 .58199 L .48984 .57801 L p F P
0 g
s
.48984 .57801 m .49332 .52083 L .49636 .52481 L p .707 .577 .707 r
F P
0 g
s
.28832 .58247 m .28871 .61925 L .29161 .62855 L p .707 .577 .707 r
F P
0 g
s
.48818 .65806 m .49038 .67421 L .4969 .65686 L p .707 .577 .707 r
F P
0 g
s
.4969 .65686 m .4947 .64071 L .48818 .65806 L p .707 .577 .707 r
F P
0 g
s
.49221 .58443 m .4926 .62121 L .4897 .61191 L p .707 .577 .707 r
F P
0 g
s
.29535 .67169 m .29755 .68784 L .31055 .70216 L p .707 .577 .707 r
F P
0 g
s
.28929 .56826 m .29277 .51108 L .2997 .50777 L p .707 .577 .707 r
F P
0 g
s
.2997 .50777 m .29622 .56495 L .28929 .56826 L p .707 .577 .707 r
F P
0 g
s
.28871 .61925 m .28832 .58247 L .29539 .57327 L p .707 .577 .707 r
F P
0 g
s
.29755 .68784 m .29535 .67169 L .29194 .65504 L p .707 .577 .707 r
F P
0 g
s
.4947 .64071 m .4969 .65686 L .49349 .64021 L p .707 .577 .707 r
F P
0 g
s
.49349 .64021 m .49129 .62406 L .4947 .64071 L p .707 .577 .707 r
F P
0 g
s
.29539 .57327 m .29579 .61005 L .28871 .61925 L p .707 .577 .707 r
F P
0 g
s
.47714 .57373 m .48062 .51655 L .49332 .52083 L p .707 .577 .707 r
F P
0 g
s
.29194 .65504 m .29414 .67119 L .29755 .68784 L p .707 .577 .707 r
F P
0 g
s
.29622 .56495 m .2997 .50777 L .31591 .50545 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31591 .50545 m .31243 .56263 L .29622 .56495 L p .707 .577 .707 r
F P
0 g
s
.29414 .67119 m .29194 .65504 L .29845 .63769 L p .707 .577 .707 r
F P
0 g
s
.29579 .61005 m .29539 .57327 L .31176 .56507 L p .707 .577 .707 r
F P
0 g
s
.49129 .62406 m .49349 .64021 L .48049 .62589 L p .707 .577 .707 r
F P
0 g
s
.48049 .62589 m .47829 .60974 L .49129 .62406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29845 .63769 m .30065 .65384 L .29414 .67119 L p .707 .577 .707 r
F P
0 g
s
.31176 .56507 m .31215 .60184 L .29579 .61005 L p .707 .577 .707 r
F P
0 g
s
.45601 .5696 m .45949 .51242 L .48062 .51655 L p .707 .577 .707 r
F P
0 g
s
.31243 .56263 m .31591 .50545 L .33983 .50435 L p .707 .577 .707 r
F P
0 g
s
.30065 .65384 m .29845 .63769 L .31425 .62134 L p .707 .577 .707 r
F P
0 g
s
.47829 .60974 m .48049 .62589 L .45917 .61531 L p .707 .577 .707 r
F P
0 g
s
.45917 .61531 m .45697 .59916 L .47829 .60974 L p .707 .577 .707 r
F P
0 g
s
.42853 .56601 m .43201 .50883 L .45949 .51242 L p .707 .577 .707 r
F P
0 g
s
.31425 .62134 m .31645 .63749 L .30065 .65384 L p .707 .577 .707 r
F P
0 g
s
.33634 .56153 m .33983 .50435 L .3691 .50459 L p .707 .577 .707 r
F P
0 g
s
.31645 .63749 m .31425 .62134 L .33779 .60758 L p .707 .577 .707 r
F P
0 g
s
.39738 .56331 m .40086 .50613 L .43201 .50883 L p .707 .577 .707 r
F P
0 g
s
.45697 .59916 m .45917 .61531 L .43162 .6095 L p .707 .577 .707 r
F P
0 g
s
.43162 .6095 m .42942 .59334 L .45697 .59916 L p .707 .577 .707 r
F P
0 g
s
.36561 .56176 m .3691 .50459 L .40086 .50613 L p .707 .577 .707 r
F P
0 g
s
.33779 .60758 m .33999 .62374 L .31645 .63749 L p .707 .577 .707 r
F P
0 g
s
.33999 .62374 m .33779 .60758 L .36676 .59777 L p .707 .577 .707 r
F P
0 g
s
.42942 .59334 m .43162 .6095 L .40054 .60902 L p .707 .577 .707 r
F P
0 g
s
.40054 .60902 m .39834 .59287 L .42942 .59334 L p .707 .577 .707 r
F P
0 g
s
.36896 .61393 m .36676 .59777 L .39834 .59287 L p .707 .577 .707 r
F P
0 g
s
.36676 .59777 m .36896 .61393 L .33999 .62374 L p .707 .577 .707 r
F P
0 g
s
.39834 .59287 m .40054 .60902 L .36896 .61393 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaP008Ao
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@00Ngoo001cOol50002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol0071oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00KWoo0`002EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000
K7oo001/Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001YOol006Yoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Mo
o`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00IGoo001XOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00goo
001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Hgoo
001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
3UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP0?FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Mo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0F
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00F7oo7P000eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000Hgoo001EOol300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000DFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH7000=FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH00008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001eYF00L005YFFUIJEP00FUH00003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol005=oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool@
001>Ool0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2@000eYF00<005YFFUH01EYF00<005YF
FUH00UYF2@00AGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH7000fOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<Goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00000_Ool0059oo`03001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002ioo`00DWoo00<005YF00001`000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0`000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00@005YFFUIJEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool005=oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00002000^Ool0059oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002moo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
0eYF3P0015YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DGoo
00@005YFFUH000=JEP03001JEUYF00=JEPH0009oo`05001JEUYF001JEP040002FUH00`00FUIJEP06
FUH00`00FUH000060004FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001AOol01000
FUIJEP000eYF00<005YF00000`0027oo1@001UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000IJ
EP00000005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH2000015YF001JEUYF7P001EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo
001BOol00`00FUH00003FUH30008Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20000
0eYF000000050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@0015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo001BOol01000FUH005YF0P000eYF20001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<0009JEP800003FUH005YF00AJEP03001JEUYF
00=JEP04001JEUYF0008FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH0
0P00;goo001BOol00`00FUH000020005FUH00`00FUH000020007FUH00`00FUIJEP02FUHA0004FUH0
1000FUIJEUYF0P0000EJEP00001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D00003FUH0000002moo`00DWoo0P000UYF00<005YF
FUH00eYF0P000UYF00<005YFFUH015YF40000UYF00<005YFFUH00UYF1@0015YF0P0000AJEP000000
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF00000000;goo001BOol20002FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
0P001UYF00<005YFFUH01UYF00@005YFFUH000UJEP80009JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
000_Ool0059oo`05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJ
EP06FUH01000FUIJEP002eYF0P0000IJEP00FUH005YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000_Ool0059oo`06
001JEUYFFUH005YF0P001UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000]J
EP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00OomJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02000_Ool0059oo`04001JEUYFFUH200000eYF
001JEP03FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004FUH01000FUIJEP002eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00OomJEP03FUH00`00FUIJEP02000_
Ool005=oo`04001JEUYF0002FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH60003FUH01000FUIJ
EP002eYF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80
0003FUH005YF00=JEP03001JEUYF00=JEPH000Qooa<0009JEP03001JEUYF00=JEP800003FUH00000
02moo`00E7oo0P000eYF10001eYF00<005YFFUH01UYF1P000eYF00@005YFFUH000]JEP08001JEP00
001JEP00FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF
00=JEP03001JEP0000<000Qoo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP02000_Ool005Aoo`03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH60003FUH01000
FUIJEP002EYF100015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF001JEP0000=JEP<000Yoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEPD0
0004FUH005YFFUH2000_Ool002ioob4000Eoo`04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH000020004FUH01000FUIJEP001UYF0`002EYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00FUH50007Ool30003FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH2000_Ool002aoo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP04001o
ogooOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP004UYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<000AJEPL000MJEP03
001JEUYF00AJEPd000IJEP04001JEUYFFUH6000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000P0009ooaP00003FUH0
05YF011JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001J
EP020005FUH00`00FUH000020008FUH00`00FUIJEP0?0002FUH40002FUH00`00FUIJEP02FUH5000_
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0005FUH00`00FUIJEP050003Ool00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP0?FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUH00000FUH00P001EYF0P000UYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YF00000P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH0
0eYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH03UYF00@005YFFUH0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP8000=JEP80
00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP04001JEP00000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF0P000UYF00<005YFFUH0
1EYF100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000EJEP00FUIJEP00
02moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000EJEP8000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009J
EP03001oogoo02eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP09001JEUYFFUH005YF001JEP0000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEP0002moo`00;7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH30007
FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0300000eYF0000000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH00007FUH0
0`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003Ool3000^
Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YF000010000UYF00<005YFFUH01UYF00@005YFFUIJEP<000Ioo`8002ioo`00:goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<0
05YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF0`001eYF00<005YFFUH01UYF0P000UYF
00@005YFFUH000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
0002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH6
0009Ool2000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH02@00FUIJEUYF001JEP00
FUH00005FUH50006FUH00`00FUIJEP04FUH20004FUH00`00FUH00008FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001P0000=oo`0000001`0015YF
00<005YFFUH01UYF00<005YFFUH010003goo0P00;Woo000[Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP00
1EYF00T005YFFUIJEP00FUH005YF00001EYF1@001UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<000AJEP03
001JEUYF00@000Iooa0001=oo`8002ioo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00@000EJEP04001JEUYFFUH3
00000eYF001JEP04FUH50006FUH00`00FUIJEP040006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP03FUH3000V
Ool00`00FUH0000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH20004FUH01000FUIJEUYF0`0000=JEP00
FUH01EYF0`001eYF0`000eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00P005YFFUH005YF001JEP0015YF00<005YFFUH00eYF00@005YFFUH002Eoo`03
001JEP0002ioo`00:goo00<005YF00000UYF7P0015YF00<005YFFUH00UYF0P000eYF1@000eYF0`00
00=JEP00FUH01EYF00@005YFFUIJEPH000MJEP03001JEUYF00<000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
008002=oo`800003FUH007oo02eoo`00:goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF20000UYF00<005YFFUH00UYF00@005YFFUIJEQ8000AJEP03001JEUYF
00IJEP<00003FUH0000000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000ROol01000FUH00000;goo
000[Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00P008Goo00<005YFFUH00P00;goo
000/Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001EYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF0080021oo`05001JEUYFFUH0
000`Ool002ioo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000OOol00`00FUIJEP02FUH00`00Oomoo`0^Ool0
039oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF009JEPH000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P002Goo0`004Goo0`000eYF00<007ooOol0;goo000iOol90004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo1@003goo00@005YFFUH0009JEP03
001oogoo031oo`00?Goo:00000Aoo`00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000Qoo`D000eoo`8000AJEP8003=oo`00=goo
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P002goo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH010001EYF00<005YFFUH00P002Goo1@002Woo0`00
1UYF00<007ooOol0<Woo000cOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEUYF0P0015YF00<005YFFUH00P002Woo0`001goo10000UYF00<005YFFUH00UYF0P00=Goo000`
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP040005Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH3000015YF001JEUYF0P003goo1@001UYF00<005YFFUH00P00=goo000^Ool200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20004Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF00<0
05YF00001@002goo10000UYF00<005YFFUH01UYF0`00>Goo000/Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000Woo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJ
EP03001JEUYF00=JEPd000IJEP03001JEUYF00EJEP8003]oo`00:goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00T005YFFUIJEP00Ool005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?Goo000[
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0U
0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00?goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP03FUH80003FUH00`00FUIJEP03
FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Woo000ZOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEUYF10001EYF00T005YF
FUIJEP00Ool005YF00001UYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF0180
04Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00T005YFFUIJEP00Ool005YF00001EYF10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
0P0015YF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF00<005Moo`00:Woo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH0
0`00FUIJEP0200000eYF001JEP02FUH01@00Ool005YF00000eYF0P001UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
00<005YF00002P00FWoo000ZOol01000FUIJEP000eYF00<005YF00000`000Woo0P001UYF00<005YF
FUH00UYF3P001eYF00@005YFFUIJEP8000=JEP06001oo`00FUH005YF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00000P00
0eYF0P000UYF1000Ggoo000ZOol01000FUIJEP000eYF0P0017oo0`001UYF1P003Woo10000eYF00<0
05YFFUH00UYF0P000UYF00@007oo001JEP80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003
FUH0000000AJEP04001JEP00001MOol002]oo`03001JEP00009JEP@00003Ool00000009JEP03001J
EWoo009JEP8000Qoo`<000eoo`@000AJEP04001JEP00FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH01000FUIJEUYF0P00Fgoo000[Ool00`00FUH000020003FUH20004FUH00`00Ool0
00020009Ool50008Ool50003FUH20003FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP02FUH3001IOol002]oo`05001JEP00FUH00002FUH00`00FUIJEP04
FUH90005Ool=0003FUH00`00FUIJEP04FUH2000015YF001JEUYF100015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0015YF00<005YFFUH00UYF00<005YFFUH00P00Egoo000[Ool20002FUH01000FUH0
000015YF0P0015YF00<005YFFUH00UYF2P000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
0000009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF009J
EP05001JEUYFFUH0001GOol002]oo`04001JEUYFFUH2000015YF001JEUYF0P001UYF00<005YFFUH0
1UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH20000
0goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00EWoo000[Ool01000FUIJEP000eYF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEPD0009JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002]oo`03
001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2
0003FUH30005FUH00`00FUIJEP02001FOol002]oo`03001JEP0000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Ool00004Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20006FUH30003FUH00`00FUIJEP02001FOol002ao
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009oo`03001oogoo00Aoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00<00003FUH005YF00EJEP03001JEUYF00800004FUH005YFFUH2001FOol002aoo`05001JEP00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003Ool20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH>0003FUH01000FUIJEUYF0P000UYF0P00EWoo000/Ool01@00
FUH00000Ool00`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P001Goo00<005YF00002goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01@003Woo100015YF0P0000=JEP000000EWoo000/Ool00`00FUH0
0005Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030006
Ool01000FUIJEP0047oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
0goo0`003Goo1P000UYF00<005YF00000P00EWoo000/Ool00`00FUH0000:Ool90004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP005Woo2@001UYF00<005YFFUH015YF3@002Goo
1@001goo1@001EYF0`0000=JEP00FUH00P00EWoo000/Ool2000DOolB000>Ool20002FUH00`00Oomo
o`0MOol>0007FUHJ0003FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00Oomoo`1DOol002ao
o`8003=oo`05001JEP00FUH0000VOol20002FUH200000eYF001JEP04FUH20003FUH00`00FUIJEP06
FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
001FOol002aoo`03001oogoo039oo`03001JEUYF008002Ioo`80009JEP80009JEP03001JEUYF0080
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Ioo`00;7oo00<007ooOol0<Goo00D005YFFUIJEP0002Moo`80009JEP04
001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH4001EOol002aoo`80035oo`03001JEUYF009JEP03001oogoo02Ioo`03001J
EP0000AJEP03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP@005Eoo`00;7oo00<005YF0000;Woo0`000eYF00<007ooOol0:7oo
0P000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH200000goo0000001EOol002eoo`03001JEP0002]oo`80009JEP04001J
EP00000[Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000goo0P00EGoo000]Ool01000FUIJEP00:7oo
0P0015YF0P00;Goo100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001Goo0P00EGoo000^Ool00`00FUH00002000TOol20006FUH00`00
Oomoo`0[Ool00`00FUH00002Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH000020007Ool00`00FUH0001EOol002moo`80009JEP8001ioo`@00003
FUH005YF00=JEP8002ioo`03001JEP0000Eoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPH000Yoo`03001JEP0005Eoo`00;goo00<005YF00000eYF0`005Woo1@001EYF00D0
05YFFUIJEP00031oo`03001JEP0000Yooa/000moo`800003FUH007oo05Aoo`00<7oo0P0015YF00<0
05YF00000`003Woo10000UYF00<005YFFUH01UYF0`00<Goo0P00=7oo00@005YF000005Ioo`00<Goo
00<005YFFUH00UYF00<005YFFUH00eYF3P001UYF00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo
00<005YFFUH00P00EWoo000bOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH3000fOol00`00Oomoo`0`Ool01@00FUIJEUYF0000Egoo000dOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002000iOol2000`Ool00`00FUIJ
EP02FUH00`00Oomoo`1EOol003Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF009JEPD003aoo`03
001JEP0002eoo`<000=JEP03001oogoo05Ioo`00>goo4P00@Woo00<005YF0000:goo00@005YFFUH0
009JEP03001oogoo05Moo`00Sgoo00@005YFFUH002Qoo`8000AJEP03001JEP0005Uoo`00Sgoo00<0
05YFFUH00`0097oo0P001UYF0P00FWoo002@Ool00`00FUH00002FUH2000OOol300000eYF001JEP05
FUH00`00Oomoo`1IOol0091oo`03001JEP0000AJEP<001Uoo`<000AJEP03001JEUYF009JEP8005ao
o`00TGoo0P001EYF00<005YF00000`003goo1P001eYF00<005YFFUH00P00GWoo002BOol00`00FUIJ
EP03FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3001POol009=oo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80069oo`00UGoo0P0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002GOol30006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH5001XOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@0
06eoo`00WWoo3P00LGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5906 .75944 m .59408 .70227 L .56293 .69957 L p .707 .577 .707 r
F P
0 g
s
.59408 .70227 m .5906 .75944 L .62236 .76099 L p .707 .577 .707 r
F P
0 g
s
.62236 .76099 m .62584 .70381 L .59408 .70227 L p .707 .577 .707 r
F P
0 g
s
.62584 .70381 m .62236 .76099 L .65163 .76122 L p .707 .577 .707 r
F P
0 g
s
.65163 .76122 m .65511 .70404 L .62584 .70381 L p .707 .577 .707 r
F P
0 g
s
.55945 .75674 m .56293 .69957 L .53545 .69597 L p .707 .577 .707 r
F P
0 g
s
.56293 .69957 m .55945 .75674 L .5906 .75944 L p .707 .577 .707 r
F P
0 g
s
.53545 .69597 m .53197 .75315 L .55945 .75674 L p .707 .577 .707 r
F P
0 g
s
.65511 .70404 m .65163 .76122 L .67554 .76013 L p .707 .577 .707 r
F P
0 g
s
.67554 .76013 m .67903 .70295 L .65511 .70404 L p .707 .577 .707 r
F P
0 g
s
.5897 .85448 m .58931 .8177 L .55813 .81594 L p .707 .577 .707 r
F P
0 g
s
.58931 .8177 m .5897 .85448 L .62153 .85332 L p .707 .577 .707 r
F P
0 g
s
.62153 .85332 m .62114 .81654 L .58931 .8177 L p .707 .577 .707 r
F P
0 g
s
.62114 .81654 m .62153 .85332 L .65091 .84934 L p .707 .577 .707 r
F P
0 g
s
.65091 .84934 m .65052 .81256 L .62114 .81654 L p .707 .577 .707 r
F P
0 g
s
.53197 .75315 m .53545 .69597 L .51432 .69184 L p .707 .577 .707 r
F P
0 g
s
.55853 .85271 m .55813 .81594 L .53068 .81141 L p .707 .577 .707 r
F P
0 g
s
.55813 .81594 m .55853 .85271 L .5897 .85448 L p .707 .577 .707 r
F P
0 g
s
.51432 .69184 m .51084 .74902 L .53197 .75315 L p .707 .577 .707 r
F P
0 g
s
.65052 .81256 m .65091 .84934 L .67496 .84293 L p .707 .577 .707 r
F P
0 g
s
.67496 .84293 m .67457 .80616 L .65052 .81256 L p .707 .577 .707 r
F P
0 g
s
.67903 .70295 m .67554 .76013 L .69176 .75781 L p .707 .577 .707 r
F P
0 g
s
.69176 .75781 m .69524 .70063 L .67903 .70295 L p .707 .577 .707 r
F P
0 g
s
.53068 .81141 m .53107 .84819 L .55853 .85271 L p .707 .577 .707 r
F P
0 g
s
.53107 .84819 m .53068 .81141 L .50962 .80457 L p .707 .577 .707 r
F P
0 g
s
.51084 .74902 m .51432 .69184 L .50162 .68757 L p .707 .577 .707 r
F P
0 g
s
.50162 .68757 m .49813 .74475 L .51084 .74902 L p .707 .577 .707 r
F P
0 g
s
.50962 .80457 m .51001 .84135 L .53107 .84819 L p .707 .577 .707 r
F P
0 g
s
.5963 .91202 m .5941 .89587 L .56302 .89539 L p .707 .577 .707 r
F P
0 g
s
.5941 .89587 m .5963 .91202 L .62788 .90711 L p .707 .577 .707 r
F P
0 g
s
.62788 .90711 m .62568 .89096 L .5941 .89587 L p .707 .577 .707 r
F P
0 g
s
.67457 .80616 m .67496 .84293 L .69133 .83473 L p .707 .577 .707 r
F P
0 g
s
.69133 .83473 m .69093 .79795 L .67457 .80616 L p .707 .577 .707 r
F P
0 g
s
.62568 .89096 m .62788 .90711 L .65685 .8973 L p .707 .577 .707 r
F P
0 g
s
.65685 .8973 m .65465 .88115 L .62568 .89096 L p .707 .577 .707 r
F P
0 g
s
.56522 .91154 m .56302 .89539 L .53547 .88957 L p .707 .577 .707 r
F P
0 g
s
.56302 .89539 m .56522 .91154 L .5963 .91202 L p .707 .577 .707 r
F P
0 g
s
.65465 .88115 m .65685 .8973 L .68039 .88355 L p .707 .577 .707 r
F P
0 g
s
.68039 .88355 m .67819 .86739 L .65465 .88115 L p .707 .577 .707 r
F P
0 g
s
.69524 .70063 m .69176 .75781 L .69868 .75449 L p .707 .577 .707 r
F P
0 g
s
.69868 .75449 m .70217 .69731 L .69524 .70063 L p .707 .577 .707 r
F P
0 g
s
.51001 .84135 m .50962 .80457 L .49702 .79609 L p .707 .577 .707 r
F P
0 g
s
.53547 .88957 m .53767 .90573 L .56522 .91154 L p .707 .577 .707 r
F P
0 g
s
.49813 .74475 m .50162 .68757 L .49858 .68358 L p .707 .577 .707 r
F P
0 g
s
.53767 .90573 m .53547 .88957 L .51416 .87899 L p .707 .577 .707 r
F P
0 g
s
.49702 .79609 m .49742 .83286 L .51001 .84135 L p .707 .577 .707 r
F P
0 g
s
.69093 .79795 m .69133 .83473 L .6984 .82553 L p .707 .577 .707 r
F P
0 g
s
.6984 .82553 m .69801 .78875 L .69093 .79795 L p .707 .577 .707 r
F P
0 g
s
.67819 .86739 m .68039 .88355 L .69619 .86719 L p .707 .577 .707 r
F P
0 g
s
.69619 .86719 m .69399 .85104 L .67819 .86739 L p .707 .577 .707 r
F P
0 g
s
.49858 .68358 m .4951 .74076 L .49813 .74475 L p .707 .577 .707 r
F P
0 g
s
.51416 .87899 m .51636 .89514 L .53767 .90573 L p .707 .577 .707 r
F P
0 g
s
.49742 .83286 m .49702 .79609 L .49412 .78679 L p .707 .577 .707 r
F P
0 g
s
.70217 .69731 m .69868 .75449 L .69565 .7505 L p .707 .577 .707 r
F P
0 g
s
.69565 .7505 m .69913 .69332 L .70217 .69731 L p .707 .577 .707 r
F P
0 g
s
.51636 .89514 m .51416 .87899 L .50116 .86468 L p .707 .577 .707 r
F P
0 g
s
.69399 .85104 m .69619 .86719 L .7027 .84985 L p .707 .577 .707 r
F P
0 g
s
.7027 .84985 m .7005 .83369 L .69399 .85104 L p .707 .577 .707 r
F P
0 g
s
.49412 .78679 m .49452 .82357 L .49742 .83286 L p .707 .577 .707 r
F P
0 g
s
.4951 .74076 m .49858 .68358 L .50551 .68026 L p .707 .577 .707 r
F P
0 g
s
.50116 .86468 m .50336 .88083 L .51636 .89514 L p .707 .577 .707 r
F P
0 g
s
.69801 .78875 m .6984 .82553 L .6955 .81623 L p .707 .577 .707 r
F P
0 g
s
.6955 .81623 m .69511 .77945 L .69801 .78875 L p .707 .577 .707 r
F P
0 g
s
.50551 .68026 m .50202 .73744 L .4951 .74076 L p .707 .577 .707 r
F P
0 g
s
.50336 .88083 m .50116 .86468 L .49774 .84803 L p .707 .577 .707 r
F P
0 g
s
.49359 .81614 m .49871 .31099 L .4547 .30813 L p .707 .577 .707 r
F P
0 g
s
.49452 .82357 m .49412 .78679 L .5012 .77759 L p .707 .577 .707 r
F P
0 g
s
.5012 .77759 m .50159 .81437 L .49452 .82357 L p .707 .577 .707 r
F P
0 g
s
.50202 .73744 m .50551 .68026 L .52172 .67794 L p .707 .577 .707 r
F P
0 g
s
.52172 .67794 m .51824 .73512 L .50202 .73744 L p .707 .577 .707 r
F P
0 g
s
.50159 .81437 m .5012 .77759 L .51756 .76938 L p .707 .577 .707 r
F P
0 g
s
.51756 .76938 m .51796 .80616 L .50159 .81437 L p .707 .577 .707 r
F P
0 g
s
.51824 .73512 m .52172 .67794 L .54563 .67685 L p .707 .577 .707 r
F P
0 g
s
.54563 .67685 m .54215 .73402 L .51824 .73512 L p .707 .577 .707 r
F P
0 g
s
.50646 .84683 m .50426 .83068 L .52006 .81433 L p .707 .577 .707 r
F P
0 g
s
.51796 .80616 m .51756 .76938 L .54161 .76298 L p .707 .577 .707 r
F P
0 g
s
.52006 .81433 m .52226 .83048 L .50646 .84683 L p .707 .577 .707 r
F P
0 g
s
.54161 .76298 m .54201 .79976 L .51796 .80616 L p .707 .577 .707 r
F P
0 g
s
.52226 .83048 m .52006 .81433 L .5436 .80057 L p .707 .577 .707 r
F P
0 g
s
.5436 .80057 m .5458 .81672 L .52226 .83048 L p .707 .577 .707 r
F P
0 g
s
.49871 .31099 m .49359 .81614 L .53854 .81556 L p .707 .577 .707 r
F P
0 g
s
.53854 .81556 m .54365 .31042 L .49871 .31099 L p .707 .577 .707 r
F P
0 g
s
.69913 .69332 m .69565 .7505 L .68294 .74623 L p .707 .577 .707 r
F P
0 g
s
.68294 .74623 m .68642 .68905 L .69913 .69332 L p .707 .577 .707 r
F P
0 g
s
.54215 .73402 m .54563 .67685 L .5749 .67708 L p .707 .577 .707 r
F P
0 g
s
.5749 .67708 m .57142 .73426 L .54215 .73402 L p .707 .577 .707 r
F P
0 g
s
.57142 .73426 m .5749 .67708 L .60667 .67862 L p .707 .577 .707 r
F P
0 g
s
.54201 .79976 m .54161 .76298 L .57099 .759 L p .707 .577 .707 r
F P
0 g
s
.60667 .67862 m .60318 .7358 L .57142 .73426 L p .707 .577 .707 r
F P
0 g
s
.57099 .759 m .57139 .79578 L .54201 .79976 L p .707 .577 .707 r
F P
0 g
s
.57139 .79578 m .57123 .78091 L p .60283 .75784 L .707 .577 .707 r
F P
0 g
s
.57123 .78091 m .57099 .759 L .5851 .75849 L p .707 .577 .707 r
F P
0 g
s
.5851 .75849 m .60283 .75784 L p .57123 .78091 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .5436 .80057 L .56316 .79395 L p .707 .577 .707 r
F P
0 g
s
.56316 .79395 m .57257 .79076 L p .55397 .80879 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .56316 .79395 L .55397 .80879 L .707 .577 .707 r
F
.60283 .75784 m .60322 .79462 L .57139 .79578 L p F P
0 g
s
.57477 .80691 m .57257 .79076 L .59503 .78727 L p .707 .577 .707 r
F P
0 g
s
.60322 .79462 m .60304 .77775 L p .634 .75961 L .707 .577 .707 r
F P
0 g
s
.59503 .78727 m .60414 .78585 L p .58419 .80016 L .707 .577 .707 r
F P
0 g
s
.57477 .80691 m .59503 .78727 L .58419 .80016 L .707 .577 .707 r
F
.60304 .77775 m .60283 .75784 L .61902 .75876 L p F P
0 g
s
.61902 .75876 m .634 .75961 L p .60304 .77775 L .707 .577 .707 r
F P
0 g
s
.57257 .79076 m .57477 .80691 L .5458 .81672 L p .707 .577 .707 r
F P
0 g
s
.634 .75961 m .63439 .79638 L .60322 .79462 L p .707 .577 .707 r
F P
0 g
s
.60414 .78585 m .60634 .80201 L .57477 .80691 L p .707 .577 .707 r
F P
0 g
s
.54365 .31042 m .53854 .81556 L .58001 .81161 L p .707 .577 .707 r
F P
0 g
s
.58001 .81161 m .58513 .30646 L .54365 .31042 L p .707 .577 .707 r
F P
0 g
s
.7005 .83369 m .7027 .84985 L .69929 .8332 L p .707 .577 .707 r
F P
0 g
s
.69929 .8332 m .69709 .81705 L .7005 .83369 L p .707 .577 .707 r
F P
0 g
s
.24759 .72263 m .25107 .66545 L .21992 .66275 L p .707 .577 .707 r
F P
0 g
s
.25107 .66545 m .24759 .72263 L .27935 .72417 L p .707 .577 .707 r
F P
0 g
s
.27935 .72417 m .28283 .66699 L .25107 .66545 L p .707 .577 .707 r
F P
0 g
s
.44959 .81327 m .4547 .30813 L .41594 .30211 L p .707 .577 .707 r
F P
0 g
s
.4547 .30813 m .44959 .81327 L .49359 .81614 L p .707 .577 .707 r
F P
0 g
s
.49774 .84803 m .49994 .86418 L .50336 .88083 L p .707 .577 .707 r
F P
0 g
s
.28283 .66699 m .27935 .72417 L .30862 .72441 L p .707 .577 .707 r
F P
0 g
s
.30862 .72441 m .3121 .66723 L .28283 .66699 L p .707 .577 .707 r
F P
0 g
s
.21644 .71993 m .21992 .66275 L .19244 .65916 L p .707 .577 .707 r
F P
0 g
s
.21992 .66275 m .21644 .71993 L .24759 .72263 L p .707 .577 .707 r
F P
0 g
s
.69511 .77945 m .6955 .81623 L .68291 .80775 L p .707 .577 .707 r
F P
0 g
s
.68291 .80775 m .68251 .77097 L .69511 .77945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63781 .68132 m .63433 .7385 L .60318 .7358 L p .707 .577 .707 r
F P
0 g
s
.60318 .7358 m .60667 .67862 L .63781 .68132 L p .707 .577 .707 r
F P
0 g
s
.66146 .76413 m .66185 .80091 L .63439 .79638 L p .707 .577 .707 r
F P
0 g
s
.63439 .79638 m .6342 .77883 L p .66146 .76413 L .707 .577 .707 r
F P
0 g
s
.63523 .78633 m .63743 .80248 L .61227 .8021 L p .707 .577 .707 r
F P
0 g
s
.61227 .8021 m .60634 .80201 L p .61866 .79532 L .707 .577 .707 r
F P
0 g
s
.61866 .79532 m .63523 .78633 L .61227 .8021 L .707 .577 .707 r
F
.6342 .77883 m .634 .75961 L .64986 .76222 L p F P
0 g
s
.64986 .76222 m .66146 .76413 L p .6342 .77883 L .707 .577 .707 r
F P
0 g
s
.60634 .80201 m .60414 .78585 L .63523 .78633 L p .707 .577 .707 r
F P
0 g
s
.58513 .30646 m .58001 .81161 L .61396 .80466 L p .707 .577 .707 r
F P
0 g
s
.61396 .80466 m .61908 .29952 L .58513 .30646 L p .707 .577 .707 r
F P
0 g
s
.19244 .65916 m .18896 .71634 L .21644 .71993 L p .707 .577 .707 r
F P
0 g
s
.3121 .66723 m .30862 .72441 L .33253 .72331 L p .707 .577 .707 r
F P
0 g
s
.33253 .72331 m .33602 .66613 L .3121 .66723 L p .707 .577 .707 r
F P
0 g
s
.49994 .86418 m .49774 .84803 L .50426 .83068 L p .707 .577 .707 r
F P
0 g
s
.24669 .81766 m .2463 .78089 L .21513 .77912 L p .707 .577 .707 r
F P
0 g
s
.2463 .78089 m .24669 .81766 L .27852 .8165 L p .707 .577 .707 r
F P
0 g
s
.27852 .8165 m .27813 .77973 L .2463 .78089 L p .707 .577 .707 r
F P
0 g
s
.27813 .77973 m .27852 .8165 L .3079 .81252 L p .707 .577 .707 r
F P
0 g
s
.3079 .81252 m .30751 .77575 L .27813 .77973 L p .707 .577 .707 r
F P
0 g
s
.18896 .71634 m .19244 .65916 L .17131 .65502 L p .707 .577 .707 r
F P
0 g
s
.41082 .80725 m .41594 .30211 L .38621 .29352 L p .707 .577 .707 r
F P
0 g
s
.41594 .30211 m .41082 .80725 L .44959 .81327 L p .707 .577 .707 r
F P
0 g
s
.68642 .68905 m .68294 .74623 L .66181 .7421 L p .707 .577 .707 r
F P
0 g
s
.66181 .7421 m .6653 .68492 L .68642 .68905 L p .707 .577 .707 r
F P
0 g
s
.69709 .81705 m .69929 .8332 L .68629 .81888 L p .707 .577 .707 r
F P
0 g
s
.68629 .81888 m .68409 .80273 L .69709 .81705 L p .707 .577 .707 r
F P
0 g
s
.21552 .8159 m .21513 .77912 L .18767 .7746 L p .707 .577 .707 r
F P
0 g
s
.21513 .77912 m .21552 .8159 L .24669 .81766 L p .707 .577 .707 r
F P
0 g
s
.50426 .83068 m .50646 .84683 L .49994 .86418 L p .707 .577 .707 r
F P
0 g
s
.17131 .65502 m .16783 .7122 L .18896 .71634 L p .707 .577 .707 r
F P
0 g
s
.30751 .77575 m .3079 .81252 L .33195 .80612 L p .707 .577 .707 r
F P
0 g
s
.33195 .80612 m .33156 .76934 L .30751 .77575 L p .707 .577 .707 r
F P
0 g
s
.68251 .77097 m .68291 .80775 L .66185 .80091 L p .707 .577 .707 r
F P
0 g
s
.66185 .80091 m .66167 .78404 L p .68251 .77097 L .707 .577 .707 r
F P
0 g
s
.66277 .79215 m .66497 .8083 L .64513 .80411 L p .707 .577 .707 r
F P
0 g
s
.64513 .80411 m .63743 .80248 L p .65105 .79693 L .707 .577 .707 r
F P
0 g
s
.65105 .79693 m .66277 .79215 L .64513 .80411 L .707 .577 .707 r
F
.66167 .78404 m .66146 .76413 L .67457 .76839 L p F P
0 g
s
.67457 .76839 m .68251 .77097 L p .66167 .78404 L .707 .577 .707 r
F P
0 g
s
.33602 .66613 m .33253 .72331 L .34875 .72099 L p .707 .577 .707 r
F P
0 g
s
.34875 .72099 m .35223 .66381 L .33602 .66613 L p .707 .577 .707 r
F P
0 g
s
.18767 .7746 m .18806 .81137 L .21552 .8159 L p .707 .577 .707 r
F P
0 g
s
.6653 .68492 m .66181 .7421 L .63433 .7385 L p .707 .577 .707 r
F P
0 g
s
.63433 .7385 m .63781 .68132 L .6653 .68492 L p .707 .577 .707 r
F P
0 g
s
.63743 .80248 m .63523 .78633 L .66277 .79215 L p .707 .577 .707 r
F P
0 g
s
.61908 .29952 m .61396 .80466 L .63707 .7954 L p .707 .577 .707 r
F P
0 g
s
.63707 .7954 m .64218 .29025 L .61908 .29952 L p .707 .577 .707 r
F P
0 g
s
.18806 .81137 m .18767 .7746 L .16661 .76776 L p .707 .577 .707 r
F P
0 g
s
.16783 .7122 m .17131 .65502 L .15861 .65075 L p .707 .577 .707 r
F P
0 g
s
.68409 .80273 m .68629 .81888 L .66497 .8083 L p .707 .577 .707 r
F P
0 g
s
.66497 .8083 m .66277 .79215 L .68409 .80273 L p .707 .577 .707 r
F P
0 g
s
.15861 .65075 m .15513 .70793 L .16783 .7122 L p .707 .577 .707 r
F P
0 g
s
.16661 .76776 m .167 .80453 L .18806 .81137 L p .707 .577 .707 r
F P
0 g
s
.25329 .8752 m .25109 .85905 L .22001 .85858 L p .707 .577 .707 r
F P
0 g
s
.25109 .85905 m .25329 .8752 L .28487 .8703 L p .707 .577 .707 r
F P
0 g
s
.28487 .8703 m .28267 .85415 L .25109 .85905 L p .707 .577 .707 r
F P
0 g
s
.33156 .76934 m .33195 .80612 L .34832 .79791 L p .707 .577 .707 r
F P
0 g
s
.34832 .79791 m .34792 .76114 L .33156 .76934 L p .707 .577 .707 r
F P
0 g
s
.28267 .85415 m .28487 .8703 L .31384 .86049 L p .707 .577 .707 r
F P
0 g
s
.31384 .86049 m .31164 .84433 L .28267 .85415 L p .707 .577 .707 r
F P
0 g
s
.38109 .79867 m .38621 .29352 L .36843 .28321 L p .707 .577 .707 r
F P
0 g
s
.38621 .29352 m .38109 .79867 L .41082 .80725 L p .707 .577 .707 r
F P
0 g
s
.22221 .87473 m .22001 .85858 L .19246 .85276 L p .707 .577 .707 r
F P
0 g
s
.22001 .85858 m .22221 .87473 L .25329 .8752 L p .707 .577 .707 r
F P
0 g
s
.31164 .84433 m .31384 .86049 L .33738 .84673 L p .707 .577 .707 r
F P
0 g
s
.33738 .84673 m .33518 .83058 L .31164 .84433 L p .707 .577 .707 r
F P
0 g
s
.35223 .66381 m .34875 .72099 L .35567 .71767 L p .707 .577 .707 r
F P
0 g
s
.35567 .71767 m .35916 .66049 L .35223 .66381 L p .707 .577 .707 r
F P
0 g
s
.167 .80453 m .16661 .76776 L .15401 .75927 L p .707 .577 .707 r
F P
0 g
s
.19246 .85276 m .19466 .86891 L .22221 .87473 L p .707 .577 .707 r
F P
0 g
s
.15513 .70793 m .15861 .65075 L .15557 .64676 L p .707 .577 .707 r
F P
0 g
s
.19466 .86891 m .19246 .85276 L .17115 .84218 L p .707 .577 .707 r
F P
0 g
s
.15401 .75927 m .15441 .79605 L .167 .80453 L p .707 .577 .707 r
F P
0 g
s
.64218 .29025 m .63707 .7954 L .64706 .78473 L p .707 .577 .707 r
F P
0 g
s
.65218 .27958 m .64218 .29025 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64707 .78361 m .65218 .27958 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64707 .78361 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64297 .7737 L p .64455 .68877 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .646 .67628 L .64706 .78473 L .707 .577 .707 r
F
.64558 .63351 m .64562 .63144 L .64752 .73994 L F
.65218 .27958 m .65108 .38807 L p .64562 .63144 L F P
0 g
s
.65108 .38807 m .64752 .73994 L p .64562 .63144 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64558 .63351 L .646 .67628 L .707 .577 .707 r
F
.64752 .73994 m .64706 .78473 L p .64558 .63351 L F P
0 g
s
.64551 .63619 m .63423 .62859 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64808 .26855 m .64583 .49115 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.64583 .49115 m .64481 .59135 L p .63665 .58759 L .707 .577 .707 r
F P
0 g
s
.63339 .58609 m .64583 .49115 L .63665 .58759 L .707 .577 .707 r
F
.63534 .60907 m .63665 .58759 L p .6354 .60069 L F P
0 g
s
.64482 .59189 m .64481 .59135 L .64474 .59132 L .707 .577 .707 r
F
.64808 .26855 m .65218 .27958 L p .64558 .63351 L F P
0 g
s
.63882 .55189 m .63534 .60907 L .6452 .61238 L p .707 .577 .707 r
F P
0 g
s
.64482 .59189 m .63882 .55189 L .6452 .61238 L .707 .577 .707 r
F
.63423 .62859 m .63462 .66536 L .64471 .67216 L p F P
0 g
s
.64297 .7737 m .64341 .72984 L p .64429 .69106 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64429 .69106 L .64558 .63351 L .707 .577 .707 r
F
.64297 .7737 m .64429 .69106 L .64455 .68877 L F
.64485 .66561 m .63423 .62859 L .64471 .67216 L F
.64341 .72984 m .64481 .59135 L p .64558 .63332 L F P
0 g
s
.64341 .72984 m .64558 .63332 L .64558 .63351 L .707 .577 .707 r
F
.63339 .58609 m .63665 .58759 L .63508 .60399 L F
.63468 .60821 m .63534 .60907 L p .6354 .60069 L F P
0 g
s
.63339 .58609 m .64376 .69559 L .63876 .69119 L .707 .577 .707 r
F
.63462 .66536 m .63423 .62859 L .63309 .62496 L p F P
0 g
s
.63462 .66536 m .63309 .62496 L .63369 .65232 L .707 .577 .707 r
F
.63624 .76979 m .62519 .76338 L p .63261 .60284 L F P
0 g
s
.62519 .76338 m .62866 .4204 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.63133 .61929 m .63172 .65607 L .63392 .66312 L p .707 .577 .707 r
F P
0 g
s
.63392 .66312 m .63462 .66536 L p .63369 .65232 L .707 .577 .707 r
F P
0 g
s
.63369 .65232 m .63133 .61929 L .63392 .66312 L .707 .577 .707 r
F
.6303 .25824 m .64808 .26855 L p .63261 .60284 L F P
0 g
s
.62866 .4204 m .6303 .25824 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.64297 .7737 m .63624 .76979 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.63261 .60284 m .63339 .58609 L .63624 .76979 L .707 .577 .707 r
F
.63309 .62496 m .63133 .61929 L p .63369 .65232 L F P
0 g
s
.63578 .5479 m .6323 .60508 L .63468 .60821 L p .707 .577 .707 r
F P
0 g
s
.6354 .60069 m .63578 .5479 L .63468 .60821 L .707 .577 .707 r
F
.64481 .59135 m .64376 .69559 L p .63508 .60399 L F P
0 g
s
.63665 .58759 m .64481 .59135 L .63508 .60399 L .707 .577 .707 r
F
.64376 .69559 m .64297 .7737 L p .63876 .69119 L F P
0 g
s
.64056 .72466 m .65356 .73897 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.63836 .7085 m .64047 .72397 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64047 .72397 m .64056 .72466 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64471 .67216 m .64722 .67385 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64808 .26855 L p .64558 .63351 L .707 .577 .707 r
F P
0 g
s
.6452 .61238 m .64804 .61334 L p .64482 .59189 L .707 .577 .707 r
F P
0 g
s
.63882 .55189 m .63578 .5479 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.63665 .58759 m .63882 .55189 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.64413 .55367 m .63882 .55189 L p .64474 .59132 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64413 .55367 L .64474 .59132 L .707 .577 .707 r
F
.64722 .67385 m .64682 .63707 L .64551 .63619 L p F P
0 g
s
.64722 .67385 m .64551 .63619 L .64485 .66561 L .707 .577 .707 r
F
.65356 .73897 m .65136 .72282 L .64182 .71231 L p F P
0 g
s
.64182 .71231 m .63836 .7085 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.65356 .73897 m .64182 .71231 L .64152 .71485 L .707 .577 .707 r
F
.64804 .61334 m .65152 .55616 L .64413 .55367 L p F P
0 g
s
.64804 .61334 m .64413 .55367 L .64482 .59189 L .707 .577 .707 r
F
.65152 .55616 m .64804 .61334 L .65437 .61458 L p F P
0 g
s
.65437 .61458 m .66917 .61747 L p .6562 .57239 L .707 .577 .707 r
F P
0 g
s
.6562 .57239 m .65152 .55616 L .65437 .61458 L .707 .577 .707 r
F
.34792 .76114 m .34832 .79791 L .3554 .78871 L p F P
0 g
s
.3554 .78871 m .355 .75194 L .34792 .76114 L p .707 .577 .707 r
F P
0 g
s
.33518 .83058 m .33738 .84673 L .35318 .83038 L p .707 .577 .707 r
F P
0 g
s
.35318 .83038 m .35098 .81423 L .33518 .83058 L p .707 .577 .707 r
F P
0 g
s
.15557 .64676 m .15209 .70394 L .15513 .70793 L p .707 .577 .707 r
F P
0 g
s
.17115 .84218 m .17335 .85833 L .19466 .86891 L p .707 .577 .707 r
F P
0 g
s
.15441 .79605 m .15401 .75927 L .15111 .74998 L p .707 .577 .707 r
F P
0 g
s
.35916 .66049 m .35567 .71767 L .35264 .71368 L p .707 .577 .707 r
F P
0 g
s
.35264 .71368 m .35612 .65651 L .35916 .66049 L p .707 .577 .707 r
F P
0 g
s
.36331 .78835 m .36843 .28321 L .36433 .27217 L p .707 .577 .707 r
F P
0 g
s
.36843 .28321 m .36331 .78835 L .38109 .79867 L p .707 .577 .707 r
F P
0 g
s
.17335 .85833 m .17115 .84218 L .15815 .82786 L p .707 .577 .707 r
F P
0 g
s
.35098 .81423 m .35318 .83038 L .35969 .81303 L p .707 .577 .707 r
F P
0 g
s
.35969 .81303 m .35749 .79688 L .35098 .81423 L p .707 .577 .707 r
F P
0 g
s
.15111 .74998 m .15151 .78675 L .15441 .79605 L p .707 .577 .707 r
F P
0 g
s
.15209 .70394 m .15557 .64676 L .1625 .64345 L p .707 .577 .707 r
F P
0 g
s
.15815 .82786 m .16035 .84401 L .17335 .85833 L p .707 .577 .707 r
F P
0 g
s
.355 .75194 m .3554 .78871 L .3525 .77942 L p .707 .577 .707 r
F P
0 g
s
.3525 .77942 m .3521 .74264 L .355 .75194 L p .707 .577 .707 r
F P
0 g
s
.1625 .64345 m .15902 .70063 L .15209 .70394 L p .707 .577 .707 r
F P
0 g
s
.16035 .84401 m .15815 .82786 L .15474 .81121 L p .707 .577 .707 r
F P
0 g
s
.15151 .78675 m .15111 .74998 L .15819 .74077 L p .707 .577 .707 r
F P
0 g
s
.35612 .65651 m .35264 .71368 L .33993 .70941 L p .707 .577 .707 r
F P
0 g
s
.33993 .70941 m .34342 .65223 L .35612 .65651 L p .707 .577 .707 r
F P
0 g
s
.35749 .79688 m .35969 .81303 L .35628 .79638 L p .707 .577 .707 r
F P
0 g
s
.35628 .79638 m .35408 .78023 L .35749 .79688 L p .707 .577 .707 r
F P
0 g
s
.15474 .81121 m .15694 .82736 L .16035 .84401 L p .707 .577 .707 r
F P
0 g
s
.15819 .74077 m .15859 .77755 L .15151 .78675 L p .707 .577 .707 r
F P
0 g
s
.15902 .70063 m .1625 .64345 L .17871 .64113 L p .707 .577 .707 r
F P
0 g
s
.36433 .27217 m .35922 .77732 L .36331 .78835 L p .707 .577 .707 r
F P
0 g
s
.35922 .77732 m .36433 .27217 L .37433 .2615 L p .707 .577 .707 r
F P
0 g
s
.3521 .74264 m .3525 .77942 L .3399 .77093 L p .707 .577 .707 r
F P
0 g
s
.3399 .77093 m .33951 .73416 L .3521 .74264 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17871 .64113 m .17523 .69831 L .15902 .70063 L p .707 .577 .707 r
F P
0 g
s
.15694 .82736 m .15474 .81121 L .16125 .79386 L p .707 .577 .707 r
F P
0 g
s
.15859 .77755 m .15819 .74077 L .17456 .73257 L p .707 .577 .707 r
F P
0 g
s
.34342 .65223 m .33993 .70941 L .31881 .70528 L p .707 .577 .707 r
F P
0 g
s
.31881 .70528 m .32229 .6481 L .34342 .65223 L p .707 .577 .707 r
F P
0 g
s
.35408 .78023 m .35628 .79638 L .34328 .78207 L p .707 .577 .707 r
F P
0 g
s
.34328 .78207 m .34108 .76592 L .35408 .78023 L p .707 .577 .707 r
F P
0 g
s
.16125 .79386 m .16345 .81002 L .15694 .82736 L p .707 .577 .707 r
F P
0 g
s
.17456 .73257 m .17495 .76935 L .15859 .77755 L p .707 .577 .707 r
F P
0 g
s
.17523 .69831 m .17871 .64113 L .20262 .64003 L p .707 .577 .707 r
F P
0 g
s
.33951 .73416 m .3399 .77093 L .31884 .76409 L p .707 .577 .707 r
F P
0 g
s
.31884 .76409 m .31866 .74723 L p .33951 .73416 L .707 .577 .707 r
F P
0 g
s
.31845 .72732 m .31884 .76409 L .29138 .75957 L p .707 .577 .707 r
F P
0 g
s
.31976 .75533 m .32196 .77148 L .30212 .76729 L p .707 .577 .707 r
F P
0 g
s
.30212 .76729 m .29442 .76567 L p .30804 .76011 L .707 .577 .707 r
F P
0 g
s
.30804 .76011 m .31976 .75533 L .30212 .76729 L .707 .577 .707 r
F
.31866 .74723 m .31845 .72732 L .33156 .73158 L p F P
0 g
s
.33156 .73158 m .33951 .73416 L p .31866 .74723 L .707 .577 .707 r
F P
0 g
s
.20262 .64003 m .19914 .69721 L .17523 .69831 L p .707 .577 .707 r
F P
0 g
s
.16345 .81002 m .16125 .79386 L .17705 .77751 L p .707 .577 .707 r
F P
0 g
s
.17495 .76935 m .17456 .73257 L .1986 .72616 L p .707 .577 .707 r
F P
0 g
s
.32229 .6481 m .31881 .70528 L .29132 .70169 L p .707 .577 .707 r
F P
0 g
s
.29132 .70169 m .29481 .64451 L .32229 .6481 L p .707 .577 .707 r
F P
0 g
s
.34108 .76592 m .34328 .78207 L .32196 .77148 L p .707 .577 .707 r
F P
0 g
s
.32196 .77148 m .31976 .75533 L .34108 .76592 L p .707 .577 .707 r
F P
0 g
s
.36921 .76665 m .37433 .2615 L .39743 .25224 L p .707 .577 .707 r
F P
0 g
s
.37433 .2615 m .36921 .76665 L .35922 .77732 L p .707 .577 .707 r
F P
0 g
s
.7278 .62377 m .73128 .56659 L .70013 .56389 L p .707 .577 .707 r
F P
0 g
s
.73128 .56659 m .7278 .62377 L .75956 .62531 L p .707 .577 .707 r
F P
0 g
s
.75956 .62531 m .76305 .56813 L .73128 .56659 L p .707 .577 .707 r
F P
0 g
s
.19914 .69721 m .20262 .64003 L .23189 .64027 L p .707 .577 .707 r
F P
0 g
s
.17705 .77751 m .17925 .79366 L .16345 .81002 L p .707 .577 .707 r
F P
0 g
s
.76305 .56813 m .75956 .62531 L .78883 .62554 L p .707 .577 .707 r
F P
0 g
s
.78883 .62554 m .79232 .56836 L .76305 .56813 L p .707 .577 .707 r
F P
0 g
s
.1986 .72616 m .199 .76294 L .17495 .76935 L p .707 .577 .707 r
F P
0 g
s
.29138 .75957 m .29119 .74202 L p .31845 .72732 L .707 .577 .707 r
F P
0 g
s
.29099 .72279 m .29138 .75957 L .26021 .7578 L p .707 .577 .707 r
F P
0 g
s
.29222 .74952 m .29442 .76567 L .26926 .76528 L p .707 .577 .707 r
F P
0 g
s
.26926 .76528 m .26333 .76519 L p .27565 .75851 L .707 .577 .707 r
F P
0 g
s
.27565 .75851 m .29222 .74952 L .26926 .76528 L .707 .577 .707 r
F
.29119 .74202 m .29099 .72279 L .30685 .72541 L p F P
0 g
s
.30685 .72541 m .31845 .72732 L p .29119 .74202 L .707 .577 .707 r
F P
0 g
s
.69665 .62107 m .70013 .56389 L .67265 .56029 L p .707 .577 .707 r
F P
0 g
s
.70013 .56389 m .69665 .62107 L .7278 .62377 L p .707 .577 .707 r
F P
0 g
s
.23189 .64027 m .22841 .69744 L .19914 .69721 L p .707 .577 .707 r
F P
0 g
s
.29481 .64451 m .29132 .70169 L .26018 .69899 L p .707 .577 .707 r
F P
0 g
s
.26018 .69899 m .26366 .64181 L .29481 .64451 L p .707 .577 .707 r
F P
0 g
s
.7269 .68698 m .72651 .6502 L .69534 .64843 L p .707 .577 .707 r
F P
0 g
s
.72651 .6502 m .7269 .68698 L .75874 .68582 L p .707 .577 .707 r
F P
0 g
s
.75874 .68582 m .75834 .64904 L .72651 .6502 L p .707 .577 .707 r
F P
0 g
s
.17925 .79366 m .17705 .77751 L .20059 .76376 L p .707 .577 .707 r
F P
0 g
s
.22841 .69744 m .23189 .64027 L .26366 .64181 L p .707 .577 .707 r
F P
0 g
s
.67265 .56029 m .66917 .61747 L .69665 .62107 L p .707 .577 .707 r
F P
0 g
s
.75834 .64904 m .75874 .68582 L .78812 .68184 L p .707 .577 .707 r
F P
0 g
s
.78812 .68184 m .78772 .64506 L .75834 .64904 L p .707 .577 .707 r
F P
0 g
s
.199 .76294 m .1986 .72616 L .22798 .72219 L p .707 .577 .707 r
F P
0 g
s
.79232 .56836 m .78883 .62554 L .81275 .62445 L p .707 .577 .707 r
F P
0 g
s
.81275 .62445 m .81623 .56727 L .79232 .56836 L p .707 .577 .707 r
F P
0 g
s
.26366 .64181 m .26018 .69899 L .22841 .69744 L p .707 .577 .707 r
F P
0 g
s
.29442 .76567 m .29222 .74952 L .31976 .75533 L p .707 .577 .707 r
F P
0 g
s
.69573 .68521 m .69534 .64843 L .66788 .64391 L p .707 .577 .707 r
F P
0 g
s
.69534 .64843 m .69573 .68521 L .7269 .68698 L p .707 .577 .707 r
F P
0 g
s
.6303 .25824 m .62519 .76338 L .59546 .75479 L p .707 .577 .707 r
F P
0 g
s
.59546 .75479 m .60057 .24965 L .6303 .25824 L p .707 .577 .707 r
F P
0 g
s
.22838 .75896 m .22822 .74409 L p .25982 .72102 L .707 .577 .707 r
F P
0 g
s
.22822 .74409 m .22798 .72219 L .24209 .72167 L p .707 .577 .707 r
F P
0 g
s
.24209 .72167 m .25982 .72102 L p .22822 .74409 L .707 .577 .707 r
F P
0 g
s
.22798 .72219 m .22838 .75896 L .199 .76294 L p .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .20059 .76376 L .22015 .75713 L p .707 .577 .707 r
F P
0 g
s
.22015 .75713 m .22956 .75395 L p .21096 .77198 L .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .22015 .75713 L .21096 .77198 L .707 .577 .707 r
F
.25982 .72102 m .26021 .7578 L .22838 .75896 L p F P
0 g
s
.23176 .7701 m .22956 .75395 L .25202 .75046 L p .707 .577 .707 r
F P
0 g
s
.26021 .7578 m .26003 .74093 L p .29099 .72279 L .707 .577 .707 r
F P
0 g
s
.25202 .75046 m .26113 .74904 L p .24118 .76335 L .707 .577 .707 r
F P
0 g
s
.23176 .7701 m .25202 .75046 L .24118 .76335 L .707 .577 .707 r
F
.26003 .74093 m .25982 .72102 L .27601 .72194 L p F P
0 g
s
.27601 .72194 m .29099 .72279 L p .26003 .74093 L .707 .577 .707 r
F P
0 g
s
.66917 .61747 m .67265 .56029 L .65152 .55616 L p .707 .577 .707 r
F P
0 g
s
.20059 .76376 m .20279 .77991 L .17925 .79366 L p .707 .577 .707 r
F P
0 g
s
.78772 .64506 m .78812 .68184 L .81217 .67543 L p .707 .577 .707 r
F P
0 g
s
.81217 .67543 m .81177 .63866 L .78772 .64506 L p .707 .577 .707 r
F P
0 g
s
.66788 .64391 m .66827 .68069 L .69573 .68521 L p .707 .577 .707 r
F P
0 g
s
.26333 .76519 m .26113 .74904 L .29222 .74952 L p .707 .577 .707 r
F P
0 g
s
.66827 .68069 m .66788 .64391 L .64682 .63707 L p .707 .577 .707 r
F P
0 g
s
.39743 .25224 m .39233 .75627 L p .36921 .76665 L .707 .577 .707 r
F P
0 g
s
.39232 .75739 m .39743 .25224 L .43138 .24529 L p .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .39232 .75739 L p .39708 .69499 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .41038 .52063 L .41813 .6089 L .707 .577 .707 r
F
.42158 .64821 m .44511 .64502 L p .41875 .61599 L F P
0 g
s
.42311 .58855 m .44583 .58873 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.42811 .5681 m .43138 .24529 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.43639 .56773 m .43109 .55592 L .42811 .5681 L .707 .577 .707 r
F
.43639 .56773 m .42811 .5681 L .42311 .58855 L F
.43138 .24529 m .47286 .24134 L p .44301 .56744 L F P
0 g
s
.43138 .24529 m .42811 .5681 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.41038 .52063 m .43138 .24529 L .41813 .6089 L .707 .577 .707 r
F
.47286 .24134 m .46957 .56626 L p .44713 .56725 L F P
0 g
s
.44301 .56744 m .44441 .55222 L .44713 .56725 L .707 .577 .707 r
F
.44441 .55222 m .47286 .24134 L .44713 .56725 L F
.44713 .56725 m .44583 .58873 L .45098 .58849 L p F P
0 g
s
.44583 .58873 m .44713 .56725 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.46957 .56626 m .46774 .74648 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.45301 .61856 m .44471 .60825 L .4509 .64348 L .707 .577 .707 r
F
.45739 .5668 m .46957 .56626 L .4519 .63173 L F
.45409 .60575 m .44471 .60825 L p .45301 .61856 L F P
0 g
s
.44301 .56744 m .45739 .5668 L .4519 .63173 L .707 .577 .707 r
F
.44931 .53155 m .44713 .56725 L p .45785 .57691 L F P
0 g
s
.46837 .68446 m .46908 .61467 L p .47111 .71246 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47122 .40351 L p .47115 .60696 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47115 .60696 L .47111 .71246 L .707 .577 .707 r
F
.48764 .54547 m .47122 .40351 L .5178 .24076 L F
.47111 .71246 m .47115 .60696 L .48764 .54547 L F
.47115 .60696 m .47122 .40351 L .48764 .54547 L F
.46774 .74648 m .46837 .68446 L p .47111 .71246 L F P
0 g
s
.46774 .74648 m .44197 .74894 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.5178 .24076 m .51269 .74591 L .46774 .74648 L p .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .47238 .67441 L .44946 .6878 L p .707 .577 .707 r
F P
0 g
s
.44946 .6878 m .44885 .68816 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .44946 .6878 L .44935 .68821 L .707 .577 .707 r
F
.45105 .70431 m .47458 .69056 L p .44935 .68821 L F P
0 g
s
.44885 .68816 m .44902 .68945 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.44902 .68945 m .45105 .70431 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .45492 .54695 L .45785 .57691 L .707 .577 .707 r
F
.45492 .54695 m .44931 .53155 L .45785 .57691 L F
.47122 .40351 m .47286 .24134 L .47981 .24125 L p F P
0 g
s
.47981 .24125 m .5178 .24076 L p .47122 .40351 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .46876 .60184 L .4606 .60401 L p .707 .577 .707 r
F P
0 g
s
.4606 .60401 m .45409 .60575 L p .45984 .6183 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .4606 .60401 L .45984 .6183 L .707 .577 .707 r
F
.46916 .63862 m .45409 .60575 L .45301 .61856 L F
.44471 .60825 m .44511 .64502 L .4509 .64348 L p F P
0 g
s
.40855 .64809 m .42135 .66486 L .42627 .75044 L .707 .577 .707 r
F
.44511 .64502 m .44471 .60825 L .41839 .61181 L p F P
0 g
s
.44511 .64502 m .41839 .61181 L .41875 .61599 L .707 .577 .707 r
F
.42811 .5681 m .42671 .70658 L p .41813 .6089 L F P
0 g
s
.42671 .70658 m .42627 .75044 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .44301 .56744 L .4519 .63173 L .707 .577 .707 r
F
.44197 .74894 m .42627 .75044 L p .4519 .63173 L F P
0 g
s
.42627 .75044 m .42811 .5681 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.45105 .70431 m .45095 .70363 L p .41987 .69797 L .707 .577 .707 r
F P
0 g
s
.45095 .70363 m .44885 .68816 L .44114 .69077 L p .707 .577 .707 r
F P
0 g
s
.44114 .69077 m .41987 .69797 L p .45095 .70363 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .40855 .64809 L .42627 .75044 L .707 .577 .707 r
F
.40855 .64809 m .41813 .6089 L .42135 .66486 L F
.41839 .61181 m .41533 .61222 L p .41875 .61599 L F P
0 g
s
.4509 .64348 m .46916 .63862 L p .45301 .61856 L .707 .577 .707 r
F P
0 g
s
.45098 .58849 m .46974 .58763 L p .44713 .56725 L .707 .577 .707 r
F P
0 g
s
.44931 .53155 m .42004 .53131 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.44713 .56725 m .44931 .53155 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.41533 .61222 m .41573 .649 L .42158 .64821 L p .707 .577 .707 r
F P
0 g
s
.41875 .61599 m .41533 .61222 L .42158 .64821 L .707 .577 .707 r
F
.42004 .53131 m .41655 .58849 L .42311 .58855 L p F P
0 g
s
.43109 .55592 m .42004 .53131 L .42311 .58855 L .707 .577 .707 r
F
.38827 .52977 m .38479 .58695 L .40704 .58803 L p F P
0 g
s
.40704 .58803 m .41655 .58849 L p .40846 .5717 L .707 .577 .707 r
F P
0 g
s
.40846 .5717 m .38827 .52977 L .40704 .58803 L .707 .577 .707 r
F
.39233 .75627 m .39232 .75739 L .39223 .75742 L p F P
0 g
s
.39223 .75742 m .36921 .76665 L p .39233 .75627 L .707 .577 .707 r
F P
0 g
s
.81623 .56727 m .81275 .62445 L .82896 .62213 L p .707 .577 .707 r
F P
0 g
s
.82896 .62213 m .83244 .56495 L .81623 .56727 L p .707 .577 .707 r
F P
0 g
s
.22956 .75395 m .23176 .7701 L .20279 .77991 L p .707 .577 .707 r
F P
0 g
s
.26113 .74904 m .26333 .76519 L .23176 .7701 L p .707 .577 .707 r
F P
0 g
s
.64682 .63707 m .64722 .67385 L .66827 .68069 L p .707 .577 .707 r
F P
0 g
s
.81177 .63866 m .81217 .67543 L .82853 .66723 L p .707 .577 .707 r
F P
0 g
s
.82853 .66723 m .82814 .63045 L .81177 .63866 L p .707 .577 .707 r
F P
0 g
s
.73351 .75585 m .73131 .7397 L .70023 .73922 L p .707 .577 .707 r
F P
0 g
s
.73131 .7397 m .73351 .75585 L .76508 .75094 L p .707 .577 .707 r
F P
0 g
s
.76508 .75094 m .76288 .73479 L .73131 .7397 L p .707 .577 .707 r
F P
0 g
s
.76288 .73479 m .76508 .75094 L .79406 .74113 L p .707 .577 .707 r
F P
0 g
s
.79406 .74113 m .79186 .72498 L .76288 .73479 L p .707 .577 .707 r
F P
0 g
s
.60057 .24965 m .59546 .75479 L .55669 .74877 L p .707 .577 .707 r
F P
0 g
s
.55669 .74877 m .56181 .24363 L .60057 .24965 L p .707 .577 .707 r
F P
0 g
s
.70243 .75537 m .70023 .73922 L .67268 .7334 L p .707 .577 .707 r
F P
0 g
s
.70023 .73922 m .70243 .75537 L .73351 .75585 L p .707 .577 .707 r
F P
0 g
s
.79186 .72498 m .79406 .74113 L .81759 .72738 L p .707 .577 .707 r
F P
0 g
s
.81759 .72738 m .81539 .71122 L .79186 .72498 L p .707 .577 .707 r
F P
0 g
s
.83244 .56495 m .82896 .62213 L .83589 .61881 L p .707 .577 .707 r
F P
0 g
s
.83589 .61881 m .83937 .56163 L .83244 .56495 L p .707 .577 .707 r
F P
0 g
s
.67268 .7334 m .67488 .74955 L .70243 .75537 L p .707 .577 .707 r
F P
0 g
s
.67488 .74955 m .67268 .7334 L .65136 .72282 L p .707 .577 .707 r
F P
0 g
s
.82814 .63045 m .82853 .66723 L .83561 .65803 L p .707 .577 .707 r
F P
0 g
s
.83561 .65803 m .83521 .62125 L .82814 .63045 L p .707 .577 .707 r
F P
0 g
s
.56181 .24363 m .55669 .74877 L .51269 .74591 L p .707 .577 .707 r
F P
0 g
s
.51269 .74591 m .5178 .24076 L .56181 .24363 L p .707 .577 .707 r
F P
0 g
s
.81539 .71122 m .81759 .72738 L .83339 .71102 L p .707 .577 .707 r
F P
0 g
s
.83339 .71102 m .83119 .69487 L .81539 .71122 L p .707 .577 .707 r
F P
0 g
s
.65136 .72282 m .65356 .73897 L .67488 .74955 L p .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83521 .62125 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83271 .64873 m .83242 .62188 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83242 .62188 m .83231 .61195 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83271 .64873 L .82011 .64025 L p .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .83231 .61195 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.82011 .64025 m .81985 .61546 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81985 .61546 m .81972 .60347 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .82011 .64025 L .79906 .63341 L p .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .81972 .60347 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79906 .63341 m .7988 .60995 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.7988 .60995 m .79866 .59663 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .79906 .63341 L .7716 .62888 L p .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .79866 .59663 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7716 .62888 m .77135 .60588 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.77135 .60588 m .7712 .59211 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .7716 .62888 L .74043 .62711 L p .707 .577 .707 r
F P
0 g
s
.74003 .59034 m .7712 .59211 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74043 .62711 m .74017 .60366 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74017 .60366 m .74003 .59034 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.7082 .5915 m .74003 .59034 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70859 .62828 m .70833 .60349 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70833 .60349 m .7082 .5915 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .7082 .5915 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67921 .63225 m .67892 .6054 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67892 .6054 m .67882 .59548 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.65516 .63866 m .65477 .60188 L .67882 .59548 L p .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .67921 .63225 L .65516 .63866 L p .707 .577 .707 r
F P
0 g
s
.68284 .54117 m .67935 .59835 L .67695 .59846 L p .707 .577 .707 r
F P
0 g
s
.67695 .59846 m .65544 .59944 L p .66903 .57054 L .707 .577 .707 r
F P
0 g
s
.66903 .57054 m .68284 .54117 L .67695 .59846 L .707 .577 .707 r
F
.7082 .5915 m .70859 .62828 L .67921 .63225 L p F P
0 g
s
.71211 .5414 m .70863 .59858 L .70605 .59856 L p .707 .577 .707 r
F P
0 g
s
.70605 .59856 m .67935 .59835 L p .6941 .5727 L .707 .577 .707 r
F P
0 g
s
.6941 .5727 m .71211 .5414 L .70605 .59856 L .707 .577 .707 r
F
.74003 .59034 m .74043 .62711 L .70859 .62828 L p F P
0 g
s
.74387 .54294 m .74039 .60012 L .73818 .60002 L p .707 .577 .707 r
F P
0 g
s
.73818 .60002 m .70863 .59858 L p .72407 .57421 L .707 .577 .707 r
F P
0 g
s
.72407 .57421 m .74387 .54294 L .73818 .60002 L .707 .577 .707 r
F
.77502 .54564 m .77154 .60282 L .7697 .60266 L p F P
0 g
s
.7697 .60266 m .74039 .60012 L p .75587 .57577 L .707 .577 .707 r
F P
0 g
s
.75587 .57577 m .77502 .54564 L .7697 .60266 L .707 .577 .707 r
F
.8025 .54924 m .79902 .60642 L .79736 .6062 L p F P
0 g
s
.79736 .6062 m .77154 .60282 L p .78623 .57739 L .707 .577 .707 r
F P
0 g
s
.78623 .57739 m .8025 .54924 L .79736 .6062 L .707 .577 .707 r
F
.82363 .55337 m .82015 .61055 L .81875 .61028 L p F P
0 g
s
.81875 .61028 m .79902 .60642 L p .81201 .57841 L .707 .577 .707 r
F P
0 g
s
.81201 .57841 m .82363 .55337 L .81875 .61028 L .707 .577 .707 r
F
.83633 .55764 m .83285 .61482 L .83208 .61456 L p F P
0 g
s
.83208 .61456 m .82015 .61055 L p .83032 .57729 L .707 .577 .707 r
F P
0 g
s
.83032 .57729 m .83633 .55764 L .83208 .61456 L .707 .577 .707 r
F
.83937 .56163 m .83589 .61881 L .83285 .61482 L p F P
0 g
s
.83285 .61482 m .83633 .55764 L .83937 .56163 L p .707 .577 .707 r
F P
0 g
s
.83119 .69487 m .83339 .71102 L .83991 .69367 L p .707 .577 .707 r
F P
0 g
s
.83991 .69367 m .83771 .67752 L .83119 .69487 L p .707 .577 .707 r
F P
0 g
s
.83521 .62125 m .83561 .65803 L .83271 .64873 L p .707 .577 .707 r
F P
0 g
s
.6323 .60508 m .63578 .5479 L .64271 .54458 L p .707 .577 .707 r
F P
0 g
s
.64271 .54458 m .63923 .60176 L .6323 .60508 L p .707 .577 .707 r
F P
0 g
s
.63172 .65607 m .63133 .61929 L .6384 .61009 L p .707 .577 .707 r
F P
0 g
s
.64056 .72466 m .63836 .7085 L .63495 .69186 L p .707 .577 .707 r
F P
0 g
s
.83771 .67752 m .83991 .69367 L .8365 .67703 L p .707 .577 .707 r
F P
0 g
s
.8365 .67703 m .8343 .66088 L .83771 .67752 L p .707 .577 .707 r
F P
0 g
s
.6384 .61009 m .6388 .64686 L .63172 .65607 L p .707 .577 .707 r
F P
0 g
s
.82015 .61055 m .82363 .55337 L .83633 .55764 L p .707 .577 .707 r
F P
0 g
s
.63495 .69186 m .63715 .70801 L .64056 .72466 L p .707 .577 .707 r
F P
0 g
s
.38479 .58695 m .38827 .52977 L .35713 .52707 L p .707 .577 .707 r
F P
0 g
s
.41655 .58849 m .42004 .53131 L .38827 .52977 L p .707 .577 .707 r
F P
0 g
s
.63923 .60176 m .64271 .54458 L .65892 .54226 L p .707 .577 .707 r
F P
0 g
s
.35364 .58425 m .35713 .52707 L .32964 .52348 L p .707 .577 .707 r
F P
0 g
s
.35713 .52707 m .35364 .58425 L .38479 .58695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38389 .65016 m .3835 .61339 L .35233 .61162 L p .707 .577 .707 r
F P
0 g
s
.3835 .61339 m .38389 .65016 L .41573 .649 L p .707 .577 .707 r
F P
0 g
s
.41573 .649 m .41533 .61222 L .3835 .61339 L p .707 .577 .707 r
F P
0 g
s
.65892 .54226 m .65544 .59944 L .63923 .60176 L p .707 .577 .707 r
F P
0 g
s
.63715 .70801 m .63495 .69186 L .64146 .67451 L p .707 .577 .707 r
F P
0 g
s
.6388 .64686 m .6384 .61009 L .65477 .60188 L p .707 .577 .707 r
F P
0 g
s
.32964 .52348 m .32616 .58066 L .35364 .58425 L p .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .47322 .53045 L .44931 .53155 L p .707 .577 .707 r
F P
0 g
s
.35272 .64839 m .35233 .61162 L .32487 .60709 L p .707 .577 .707 r
F P
0 g
s
.35233 .61162 m .35272 .64839 L .38389 .65016 L p .707 .577 .707 r
F P
0 g
s
.8343 .66088 m .8365 .67703 L .8235 .66271 L p .707 .577 .707 r
F P
0 g
s
.8235 .66271 m .8213 .64656 L .8343 .66088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32616 .58066 m .32964 .52348 L .30851 .51934 L p .707 .577 .707 r
F P
0 g
s
.64146 .67451 m .64366 .69066 L .63715 .70801 L p .707 .577 .707 r
F P
0 g
s
.65477 .60188 m .65516 .63866 L .6388 .64686 L p .707 .577 .707 r
F P
0 g
s
.79902 .60642 m .8025 .54924 L .82363 .55337 L p .707 .577 .707 r
F P
0 g
s
.32487 .60709 m .32526 .64387 L .35272 .64839 L p .707 .577 .707 r
F P
0 g
s
.30851 .51934 m .30503 .57652 L .32616 .58066 L p .707 .577 .707 r
F P
0 g
s
.65544 .59944 m .65892 .54226 L .68284 .54117 L p .707 .577 .707 r
F P
0 g
s
.32526 .64387 m .32487 .60709 L .30381 .60026 L p .707 .577 .707 r
F P
0 g
s
.47322 .53045 m .46974 .58763 L .48595 .58531 L p .707 .577 .707 r
F P
0 g
s
.48595 .58531 m .48943 .52813 L .47322 .53045 L p .707 .577 .707 r
F P
0 g
s
.64366 .69066 m .64146 .67451 L .65726 .65816 L p .707 .577 .707 r
F P
0 g
s
.8213 .64656 m .8235 .66271 L .80218 .65213 L p .707 .577 .707 r
F P
0 g
s
.80218 .65213 m .79998 .63598 L .8213 .64656 L p .707 .577 .707 r
F P
0 g
s
.30381 .60026 m .30421 .63703 L .32526 .64387 L p .707 .577 .707 r
F P
0 g
s
.46876 .60184 m .46916 .63862 L .48552 .63041 L p .707 .577 .707 r
F P
0 g
s
.48552 .63041 m .48513 .59364 L .46876 .60184 L p .707 .577 .707 r
F P
0 g
s
.30503 .57652 m .30851 .51934 L .29581 .51507 L p .707 .577 .707 r
F P
0 g
s
.77154 .60282 m .77502 .54564 L .8025 .54924 L p .707 .577 .707 r
F P
0 g
s
.3905 .71903 m .3883 .70288 L .35722 .7024 L p .707 .577 .707 r
F P
0 g
s
.3883 .70288 m .3905 .71903 L .42207 .71413 L p .707 .577 .707 r
F P
0 g
s
.42207 .71413 m .41987 .69797 L .3883 .70288 L p .707 .577 .707 r
F P
0 g
s
.65726 .65816 m .65946 .67431 L .64366 .69066 L p .707 .577 .707 r
F P
0 g
s
.41987 .69797 m .42207 .71413 L .45105 .70431 L p .707 .577 .707 r
F P
0 g
s
.29581 .51507 m .29233 .57225 L .30503 .57652 L p .707 .577 .707 r
F P
0 g
s
.67935 .59835 m .68284 .54117 L .71211 .5414 L p .707 .577 .707 r
F P
0 g
s
.35942 .71855 m .35722 .7024 L .32967 .69659 L p .707 .577 .707 r
F P
0 g
s
.35722 .7024 m .35942 .71855 L .3905 .71903 L p .707 .577 .707 r
F P
0 g
s
.30421 .63703 m .30381 .60026 L .29122 .59177 L p .707 .577 .707 r
F P
0 g
s
.65946 .67431 m .65726 .65816 L .6808 .6444 L p .707 .577 .707 r
F P
0 g
s
.74039 .60012 m .74387 .54294 L .77502 .54564 L p .707 .577 .707 r
F P
0 g
s
.48943 .52813 m .48595 .58531 L .49288 .58199 L p .707 .577 .707 r
F P
0 g
s
.49288 .58199 m .49636 .52481 L .48943 .52813 L p .707 .577 .707 r
F P
0 g
s
.79998 .63598 m .80218 .65213 L .77463 .64631 L p .707 .577 .707 r
F P
0 g
s
.77463 .64631 m .77243 .63016 L .79998 .63598 L p .707 .577 .707 r
F P
0 g
s
.32967 .69659 m .33187 .71274 L .35942 .71855 L p .707 .577 .707 r
F P
0 g
s
.70863 .59858 m .71211 .5414 L .74387 .54294 L p .707 .577 .707 r
F P
0 g
s
.29122 .59177 m .29161 .62855 L .30421 .63703 L p .707 .577 .707 r
F P
0 g
s
.33187 .71274 m .32967 .69659 L .30835 .686 L p .707 .577 .707 r
F P
0 g
s
.6808 .6444 m .683 .66055 L .65946 .67431 L p .707 .577 .707 r
F P
0 g
s
.48513 .59364 m .48552 .63041 L .4926 .62121 L p .707 .577 .707 r
F P
0 g
s
.4926 .62121 m .49221 .58443 L .48513 .59364 L p .707 .577 .707 r
F P
0 g
s
.47238 .67441 m .47458 .69056 L .49038 .67421 L p .707 .577 .707 r
F P
0 g
s
.49038 .67421 m .48818 .65806 L .47238 .67441 L p .707 .577 .707 r
F P
0 g
s
.29233 .57225 m .29581 .51507 L .29277 .51108 L p .707 .577 .707 r
F P
0 g
s
.683 .66055 m .6808 .6444 L .70977 .63459 L p .707 .577 .707 r
F P
0 g
s
.77243 .63016 m .77463 .64631 L .74355 .64583 L p .707 .577 .707 r
F P
0 g
s
.74355 .64583 m .74135 .62968 L .77243 .63016 L p .707 .577 .707 r
F P
0 g
s
.30835 .686 m .31055 .70216 L .33187 .71274 L p .707 .577 .707 r
F P
0 g
s
.29277 .51108 m .28929 .56826 L .29233 .57225 L p .707 .577 .707 r
F P
0 g
s
.29161 .62855 m .29122 .59177 L .28832 .58247 L p .707 .577 .707 r
F P
0 g
s
.71197 .65074 m .70977 .63459 L .74135 .62968 L p .707 .577 .707 r
F P
0 g
s
.70977 .63459 m .71197 .65074 L .683 .66055 L p .707 .577 .707 r
F P
0 g
s
.74135 .62968 m .74355 .64583 L .71197 .65074 L p .707 .577 .707 r
F P
0 g
s
.31055 .70216 m .30835 .686 L .29535 .67169 L p .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .49221 .58443 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4897 .61191 m .48941 .58506 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.48941 .58506 m .4893 .57514 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .4897 .61191 L .4771 .60343 L p .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4893 .57514 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.4771 .60343 m .47684 .57865 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47684 .57865 m .47671 .56665 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4771 .60343 L .45605 .59659 L p .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .47671 .56665 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45605 .59659 m .45579 .57314 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45579 .57314 m .45565 .55981 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .45605 .59659 L .42859 .59207 L p .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .45565 .55981 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42859 .59207 m .42834 .56907 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42834 .56907 m .42819 .55529 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .42859 .59207 L .39741 .5903 L p .707 .577 .707 r
F P
0 g
s
.39702 .55352 m .42819 .55529 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39741 .5903 m .39716 .56684 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39716 .56684 m .39702 .55352 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.36519 .55468 m .39702 .55352 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36558 .59146 m .36532 .56668 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36532 .56668 m .36519 .55468 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .36519 .55468 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.3362 .59544 m .33591 .56859 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.33591 .56859 m .33581 .55866 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.31215 .60184 m .31176 .56507 L .33581 .55866 L p .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .3362 .59544 L .31215 .60184 L p .707 .577 .707 r
F P
0 g
s
.33983 .50435 m .33634 .56153 L .33394 .56164 L p .707 .577 .707 r
F P
0 g
s
.33394 .56164 m .31243 .56263 L p .32602 .53372 L .707 .577 .707 r
F P
0 g
s
.32602 .53372 m .33983 .50435 L .33394 .56164 L .707 .577 .707 r
F
.36519 .55468 m .36558 .59146 L .3362 .59544 L p F P
0 g
s
.3691 .50459 m .36561 .56176 L .36304 .56174 L p .707 .577 .707 r
F P
0 g
s
.36304 .56174 m .33634 .56153 L p .35109 .53589 L .707 .577 .707 r
F P
0 g
s
.35109 .53589 m .3691 .50459 L .36304 .56174 L .707 .577 .707 r
F
.39702 .55352 m .39741 .5903 L .36558 .59146 L p F P
0 g
s
.40086 .50613 m .39738 .56331 L .39517 .5632 L p .707 .577 .707 r
F P
0 g
s
.39517 .5632 m .36561 .56176 L p .38106 .53739 L .707 .577 .707 r
F P
0 g
s
.38106 .53739 m .40086 .50613 L .39517 .5632 L .707 .577 .707 r
F
.43201 .50883 m .42853 .56601 L .42668 .56585 L p F P
0 g
s
.42668 .56585 m .39738 .56331 L p .41286 .53895 L .707 .577 .707 r
F P
0 g
s
.41286 .53895 m .43201 .50883 L .42668 .56585 L .707 .577 .707 r
F
.45949 .51242 m .45601 .5696 L .45435 .56938 L p F P
0 g
s
.45435 .56938 m .42853 .56601 L p .44322 .54057 L .707 .577 .707 r
F P
0 g
s
.44322 .54057 m .45949 .51242 L .45435 .56938 L .707 .577 .707 r
F
.48062 .51655 m .47714 .57373 L .47574 .57346 L p F P
0 g
s
.47574 .57346 m .45601 .5696 L p .469 .5416 L .707 .577 .707 r
F P
0 g
s
.469 .5416 m .48062 .51655 L .47574 .57346 L .707 .577 .707 r
F
.49332 .52083 m .48984 .57801 L .48907 .57774 L p F P
0 g
s
.48907 .57774 m .47714 .57373 L p .48731 .54047 L .707 .577 .707 r
F P
0 g
s
.48731 .54047 m .49332 .52083 L .48907 .57774 L .707 .577 .707 r
F
.49636 .52481 m .49288 .58199 L .48984 .57801 L p F P
0 g
s
.48984 .57801 m .49332 .52083 L .49636 .52481 L p .707 .577 .707 r
F P
0 g
s
.28832 .58247 m .28871 .61925 L .29161 .62855 L p .707 .577 .707 r
F P
0 g
s
.48818 .65806 m .49038 .67421 L .4969 .65686 L p .707 .577 .707 r
F P
0 g
s
.4969 .65686 m .4947 .64071 L .48818 .65806 L p .707 .577 .707 r
F P
0 g
s
.49221 .58443 m .4926 .62121 L .4897 .61191 L p .707 .577 .707 r
F P
0 g
s
.29535 .67169 m .29755 .68784 L .31055 .70216 L p .707 .577 .707 r
F P
0 g
s
.28929 .56826 m .29277 .51108 L .2997 .50777 L p .707 .577 .707 r
F P
0 g
s
.2997 .50777 m .29622 .56495 L .28929 .56826 L p .707 .577 .707 r
F P
0 g
s
.28871 .61925 m .28832 .58247 L .29539 .57327 L p .707 .577 .707 r
F P
0 g
s
.29755 .68784 m .29535 .67169 L .29194 .65504 L p .707 .577 .707 r
F P
0 g
s
.4947 .64071 m .4969 .65686 L .49349 .64021 L p .707 .577 .707 r
F P
0 g
s
.49349 .64021 m .49129 .62406 L .4947 .64071 L p .707 .577 .707 r
F P
0 g
s
.29539 .57327 m .29579 .61005 L .28871 .61925 L p .707 .577 .707 r
F P
0 g
s
.47714 .57373 m .48062 .51655 L .49332 .52083 L p .707 .577 .707 r
F P
0 g
s
.29194 .65504 m .29414 .67119 L .29755 .68784 L p .707 .577 .707 r
F P
0 g
s
.29622 .56495 m .2997 .50777 L .31591 .50545 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31591 .50545 m .31243 .56263 L .29622 .56495 L p .707 .577 .707 r
F P
0 g
s
.29414 .67119 m .29194 .65504 L .29845 .63769 L p .707 .577 .707 r
F P
0 g
s
.29579 .61005 m .29539 .57327 L .31176 .56507 L p .707 .577 .707 r
F P
0 g
s
.49129 .62406 m .49349 .64021 L .48049 .62589 L p .707 .577 .707 r
F P
0 g
s
.48049 .62589 m .47829 .60974 L .49129 .62406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29845 .63769 m .30065 .65384 L .29414 .67119 L p .707 .577 .707 r
F P
0 g
s
.31176 .56507 m .31215 .60184 L .29579 .61005 L p .707 .577 .707 r
F P
0 g
s
.45601 .5696 m .45949 .51242 L .48062 .51655 L p .707 .577 .707 r
F P
0 g
s
.31243 .56263 m .31591 .50545 L .33983 .50435 L p .707 .577 .707 r
F P
0 g
s
.30065 .65384 m .29845 .63769 L .31425 .62134 L p .707 .577 .707 r
F P
0 g
s
.47829 .60974 m .48049 .62589 L .45917 .61531 L p .707 .577 .707 r
F P
0 g
s
.45917 .61531 m .45697 .59916 L .47829 .60974 L p .707 .577 .707 r
F P
0 g
s
.42853 .56601 m .43201 .50883 L .45949 .51242 L p .707 .577 .707 r
F P
0 g
s
.31425 .62134 m .31645 .63749 L .30065 .65384 L p .707 .577 .707 r
F P
0 g
s
.33634 .56153 m .33983 .50435 L .3691 .50459 L p .707 .577 .707 r
F P
0 g
s
.31645 .63749 m .31425 .62134 L .33779 .60758 L p .707 .577 .707 r
F P
0 g
s
.39738 .56331 m .40086 .50613 L .43201 .50883 L p .707 .577 .707 r
F P
0 g
s
.45697 .59916 m .45917 .61531 L .43162 .6095 L p .707 .577 .707 r
F P
0 g
s
.43162 .6095 m .42942 .59334 L .45697 .59916 L p .707 .577 .707 r
F P
0 g
s
.36561 .56176 m .3691 .50459 L .40086 .50613 L p .707 .577 .707 r
F P
0 g
s
.33779 .60758 m .33999 .62374 L .31645 .63749 L p .707 .577 .707 r
F P
0 g
s
.33999 .62374 m .33779 .60758 L .36676 .59777 L p .707 .577 .707 r
F P
0 g
s
.42942 .59334 m .43162 .6095 L .40054 .60902 L p .707 .577 .707 r
F P
0 g
s
.40054 .60902 m .39834 .59287 L .42942 .59334 L p .707 .577 .707 r
F P
0 g
s
.36896 .61393 m .36676 .59777 L .39834 .59287 L p .707 .577 .707 r
F P
0 g
s
.36676 .59777 m .36896 .61393 L .33999 .62374 L p .707 .577 .707 r
F P
0 g
s
.39834 .59287 m .40054 .60902 L .36896 .61393 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaP008Ao
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@00Ngoo001cOol50002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol0071oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00KWoo0`002EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000
K7oo001/Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001YOol006Yoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Mo
o`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00IGoo001XOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00goo
001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Hgoo
001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
3UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP0?FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Mo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0F
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00F7oo7P000eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000Hgoo001EOol300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000DFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH7000=FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH00008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001eYF00L005YFFUIJEP00FUH00003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol005=oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool@
001>Ool0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2@000eYF00<005YFFUH01EYF00<005YF
FUH00UYF2@00AGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH7000fOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<Goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00000_Ool0059oo`03001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002ioo`00DWoo00<005YF00001`000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0`000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00@005YFFUIJEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool005=oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00002000^Ool0059oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002moo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
0eYF3P0015YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DGoo
00@005YFFUH000=JEP03001JEUYF00=JEPH0009oo`05001JEUYF001JEP040002FUH00`00FUIJEP06
FUH00`00FUH000060004FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001AOol01000
FUIJEP000eYF00<005YF00000`0027oo1@001UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000IJ
EP00000005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH2000015YF001JEUYF7P001EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo
001BOol00`00FUH00003FUH30008Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20000
0eYF000000050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@0015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo001BOol01000FUH005YF0P000eYF20001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<0009JEP800003FUH005YF00AJEP03001JEUYF
00=JEP04001JEUYF0008FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH0
0P00;goo001BOol00`00FUH000020005FUH00`00FUH000020007FUH00`00FUIJEP02FUHA0004FUH0
1000FUIJEUYF0P0000EJEP00001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D00003FUH0000002moo`00DWoo0P000UYF00<005YF
FUH00eYF0P000UYF00<005YFFUH015YF40000UYF00<005YFFUH00UYF1@0015YF0P0000AJEP000000
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF00000000;goo001BOol20002FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
0P001UYF00<005YFFUH01UYF00@005YFFUH000UJEP80009JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
000_Ool0059oo`05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJ
EP06FUH01000FUIJEP002eYF0P0000IJEP00FUH005YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000_Ool0059oo`06
001JEUYFFUH005YF0P001UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000]J
EP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00OomJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02000_Ool0059oo`04001JEUYFFUH200000eYF
001JEP03FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004FUH01000FUIJEP002eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00OomJEP03FUH00`00FUIJEP02000_
Ool005=oo`04001JEUYF0002FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH60003FUH01000FUIJ
EP002eYF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80
0003FUH005YF00=JEP03001JEUYF00=JEPH000Qooa<0009JEP03001JEUYF00=JEP800003FUH00000
02moo`00E7oo0P000eYF10001eYF00<005YFFUH01UYF1P000eYF00@005YFFUH000]JEP08001JEP00
001JEP00FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF
00=JEP03001JEP0000<000Qoo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP02000_Ool005Aoo`03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH60003FUH01000
FUIJEP002EYF100015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF001JEP0000=JEP<000Yoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEPD0
0004FUH005YFFUH2000_Ool002ioob4000Eoo`04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH000020004FUH01000FUIJEP001UYF0`002EYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00FUH50007Ool30003FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH2000_Ool002aoo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP04001o
ogooOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP004UYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<000AJEPL000MJEP03
001JEUYF00AJEPd000IJEP04001JEUYFFUH6000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000P0009ooaP00003FUH0
05YF011JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001J
EP020005FUH00`00FUH000020008FUH00`00FUIJEP0?0002FUH40002FUH00`00FUIJEP02FUH5000_
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0005FUH00`00FUIJEP050003Ool00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP0?FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUH00000FUH00P001EYF0P000UYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YF00000P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH0
0eYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH03UYF00@005YFFUH0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP8000=JEP80
00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP04001JEP00000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF0P000UYF00<005YFFUH0
1EYF100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000EJEP00FUIJEP00
02moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000EJEP8000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009J
EP03001oogoo02eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP09001JEUYFFUH005YF001JEP0000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEP0002moo`00;7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH30007
FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0300000eYF0000000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH00007FUH0
0`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003Ool3000^
Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YF000010000UYF00<005YFFUH01UYF00@005YFFUIJEP<000Ioo`8002ioo`00:goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<0
05YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF0`001eYF00<005YFFUH01UYF0P000UYF
00@005YFFUH000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
0002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH6
0009Ool2000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH02@00FUIJEUYF001JEP00
FUH00005FUH50006FUH00`00FUIJEP04FUH20004FUH00`00FUH00008FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001P0000=oo`0000001`0015YF
00<005YFFUH01UYF00<005YFFUH010003goo0P00;Woo000[Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP00
1EYF00T005YFFUIJEP00FUH005YF00001EYF1@001UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<000AJEP03
001JEUYF00@000Iooa0001=oo`8002ioo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00@000EJEP04001JEUYFFUH3
00000eYF001JEP04FUH50006FUH00`00FUIJEP040006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP03FUH3000V
Ool00`00FUH0000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH20004FUH01000FUIJEUYF0`0000=JEP00
FUH01EYF0`001eYF0`000eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00P005YFFUH005YF001JEP0015YF00<005YFFUH00eYF00@005YFFUH002Eoo`03
001JEP0002ioo`00:goo00<005YF00000UYF7P0015YF00<005YFFUH00UYF0P000eYF1@000eYF0`00
00=JEP00FUH01EYF00@005YFFUIJEPH000MJEP03001JEUYF00<000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
008002=oo`800003FUH007oo02eoo`00:goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF20000UYF00<005YFFUH00UYF00@005YFFUIJEQ8000AJEP03001JEUYF
00IJEP<00003FUH0000000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000ROol01000FUH00000;goo
000[Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00P008Goo00<005YFFUH00P00;goo
000/Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001EYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF0080021oo`05001JEUYFFUH0
000`Ool002ioo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000OOol00`00FUIJEP02FUH00`00Oomoo`0^Ool0
039oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF009JEPH000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P002Goo0`004Goo0`000eYF00<007ooOol0;goo000iOol90004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo1@003goo00@005YFFUH0009JEP03
001oogoo031oo`00?Goo:00000Aoo`00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000Qoo`D000eoo`8000AJEP8003=oo`00=goo
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P002goo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH010001EYF00<005YFFUH00P002Goo1@002Woo0`00
1UYF00<007ooOol0<Woo000cOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEUYF0P0015YF00<005YFFUH00P002Woo0`001goo10000UYF00<005YFFUH00UYF0P00=Goo000`
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP040005Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH3000015YF001JEUYF0P003goo1@001UYF00<005YFFUH00P00=goo000^Ool200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20004Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF00<0
05YF00001@002goo10000UYF00<005YFFUH01UYF0`00>Goo000/Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000Woo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJ
EP03001JEUYF00=JEPd000IJEP03001JEUYF00EJEP8003]oo`00:goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00T005YFFUIJEP00Ool005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?Goo000[
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0U
0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00?goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP03FUH80003FUH00`00FUIJEP03
FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Woo000ZOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEUYF10001EYF00T005YF
FUIJEP00Ool005YF00001UYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF0180
04Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00T005YFFUIJEP00Ool005YF00001EYF10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
0P0015YF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF00<005Moo`00:Woo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH0
0`00FUIJEP0200000eYF001JEP02FUH01@00Ool005YF00000eYF0P001UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
00<005YF00002P00FWoo000ZOol01000FUIJEP000eYF00<005YF00000`000Woo0P001UYF00<005YF
FUH00UYF3P001eYF00@005YFFUIJEP8000=JEP06001oo`00FUH005YF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00000P00
0eYF0P000UYF1000Ggoo000ZOol01000FUIJEP000eYF0P0017oo0`001UYF1P003Woo10000eYF00<0
05YFFUH00UYF0P000UYF00@007oo001JEP80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003
FUH0000000AJEP04001JEP00001MOol002]oo`03001JEP00009JEP@00003Ool00000009JEP03001J
EWoo009JEP8000Qoo`<000eoo`@000AJEP04001JEP00FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH01000FUIJEUYF0P00Fgoo000[Ool00`00FUH000020003FUH20004FUH00`00Ool0
00020009Ool50008Ool50003FUH20003FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP02FUH3001IOol002]oo`05001JEP00FUH00002FUH00`00FUIJEP04
FUH90005Ool=0003FUH00`00FUIJEP04FUH2000015YF001JEUYF100015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0015YF00<005YFFUH00UYF00<005YFFUH00P00Egoo000[Ool20002FUH01000FUH0
000015YF0P0015YF00<005YFFUH00UYF2P000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
0000009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF009J
EP05001JEUYFFUH0001GOol002]oo`04001JEUYFFUH2000015YF001JEUYF0P001UYF00<005YFFUH0
1UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH20000
0goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00EWoo000[Ool01000FUIJEP000eYF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEPD0009JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002]oo`03
001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2
0003FUH30005FUH00`00FUIJEP02001FOol002]oo`03001JEP0000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Ool00004Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20006FUH30003FUH00`00FUIJEP02001FOol002ao
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009oo`03001oogoo00Aoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00<00003FUH005YF00EJEP03001JEUYF00800004FUH005YFFUH2001FOol002aoo`05001JEP00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003Ool20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH>0003FUH01000FUIJEUYF0P000UYF0P00EWoo000/Ool01@00
FUH00000Ool00`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P001Goo00<005YF00002goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01@003Woo100015YF0P0000=JEP000000EWoo000/Ool00`00FUH0
0005Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030006
Ool01000FUIJEP0047oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
0goo0`003Goo1P000UYF00<005YF00000P00EWoo000/Ool00`00FUH0000:Ool90004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP005Woo2@001UYF00<005YFFUH015YF3@002Goo
1@001goo1@001EYF0`0000=JEP00FUH00P00EWoo000/Ool2000DOolB000>Ool20002FUH00`00Oomo
o`0MOol>0007FUHJ0003FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00Oomoo`1DOol002ao
o`8003=oo`05001JEP00FUH0000VOol20002FUH200000eYF001JEP04FUH20003FUH00`00FUIJEP06
FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
001FOol002aoo`03001oogoo039oo`03001JEUYF008002Ioo`80009JEP80009JEP03001JEUYF0080
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Ioo`00;7oo00<007ooOol0<Goo00D005YFFUIJEP0002Moo`80009JEP04
001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH4001EOol002aoo`80035oo`03001JEUYF009JEP03001oogoo02Ioo`03001J
EP0000AJEP03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP@005Eoo`00;7oo00<005YF0000;Woo0`000eYF00<007ooOol0:7oo
0P000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH200000goo0000001EOol002eoo`03001JEP0002]oo`80009JEP04001J
EP00000[Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000goo0P00EGoo000]Ool01000FUIJEP00:7oo
0P0015YF0P00;Goo100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001Goo0P00EGoo000^Ool00`00FUH00002000TOol20006FUH00`00
Oomoo`0[Ool00`00FUH00002Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH000020007Ool00`00FUH0001EOol002moo`80009JEP8001ioo`@00003
FUH005YF00=JEP8002ioo`03001JEP0000Eoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPH000Yoo`03001JEP0005Eoo`00;goo00<005YF00000eYF0`005Woo1@001EYF00D0
05YFFUIJEP00031oo`03001JEP0000Yooa/000moo`800003FUH007oo05Aoo`00<7oo0P0015YF00<0
05YF00000`003Woo10000UYF00<005YFFUH01UYF0`00<Goo0P00=7oo00@005YF000005Ioo`00<Goo
00<005YFFUH00UYF00<005YFFUH00eYF3P001UYF00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo
00<005YFFUH00P00EWoo000bOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH3000fOol00`00Oomoo`0`Ool01@00FUIJEUYF0000Egoo000dOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002000iOol2000`Ool00`00FUIJ
EP02FUH00`00Oomoo`1EOol003Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF009JEPD003aoo`03
001JEP0002eoo`<000=JEP03001oogoo05Ioo`00>goo4P00@Woo00<005YF0000:goo00@005YFFUH0
009JEP03001oogoo05Moo`00Sgoo00@005YFFUH002Qoo`8000AJEP03001JEP0005Uoo`00Sgoo00<0
05YFFUH00`0097oo0P001UYF0P00FWoo002@Ool00`00FUH00002FUH2000OOol300000eYF001JEP05
FUH00`00Oomoo`1IOol0091oo`03001JEP0000AJEP<001Uoo`<000AJEP03001JEUYF009JEP8005ao
o`00TGoo0P001EYF00<005YF00000`003goo1P001eYF00<005YFFUH00P00GWoo002BOol00`00FUIJ
EP03FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3001POol009=oo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80069oo`00UGoo0P0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002GOol30006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH5001XOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@0
06eoo`00WWoo3P00LGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59259 .75578 m .59475 .69904 L .56359 .69664 L p .707 .577 .707 r
F P
0 g
s
.59475 .69904 m .59259 .75578 L .6244 .75643 L p .707 .577 .707 r
F P
0 g
s
.6244 .75643 m .62656 .69969 L .59475 .69904 L p .707 .577 .707 r
F P
0 g
s
.62656 .69969 m .6244 .75643 L .65374 .75528 L p .707 .577 .707 r
F P
0 g
s
.65374 .75528 m .6559 .69853 L .62656 .69969 L p .707 .577 .707 r
F P
0 g
s
.56143 .75339 m .56359 .69664 L .53612 .69274 L p .707 .577 .707 r
F P
0 g
s
.56359 .69664 m .56143 .75339 L .59259 .75578 L p .707 .577 .707 r
F P
0 g
s
.6559 .69853 m .65374 .75528 L .67774 .75243 L p .707 .577 .707 r
F P
0 g
s
.67774 .75243 m .6799 .69568 L .6559 .69853 L p .707 .577 .707 r
F P
0 g
s
.53612 .69274 m .53396 .74949 L .56143 .75339 L p .707 .577 .707 r
F P
0 g
s
.59215 .83744 m .59191 .80055 L .56074 .79874 L p .707 .577 .707 r
F P
0 g
s
.59191 .80055 m .59215 .83744 L .62399 .83642 L p .707 .577 .707 r
F P
0 g
s
.62399 .83642 m .62374 .79954 L .59191 .80055 L p .707 .577 .707 r
F P
0 g
s
.53396 .74949 m .53612 .69274 L .51504 .68772 L p .707 .577 .707 r
F P
0 g
s
.62374 .79954 m .62399 .83642 L .65337 .83267 L p .707 .577 .707 r
F P
0 g
s
.65337 .83267 m .65312 .79579 L .62374 .79954 L p .707 .577 .707 r
F P
0 g
s
.56098 .83562 m .56074 .79874 L .53328 .79426 L p .707 .577 .707 r
F P
0 g
s
.56074 .79874 m .56098 .83562 L .59215 .83744 L p .707 .577 .707 r
F P
0 g
s
.51504 .68772 m .51288 .74446 L .53396 .74949 L p .707 .577 .707 r
F P
0 g
s
.65312 .79579 m .65337 .83267 L .67742 .82656 L p .707 .577 .707 r
F P
0 g
s
.67742 .82656 m .67718 .78967 L .65312 .79579 L p .707 .577 .707 r
F P
0 g
s
.6799 .69568 m .67774 .75243 L .69405 .74816 L p .707 .577 .707 r
F P
0 g
s
.69405 .74816 m .69621 .69141 L .6799 .69568 L p .707 .577 .707 r
F P
0 g
s
.53328 .79426 m .53352 .83115 L .56098 .83562 L p .707 .577 .707 r
F P
0 g
s
.53352 .83115 m .53328 .79426 L .51222 .78757 L p .707 .577 .707 r
F P
0 g
s
.51288 .74446 m .51504 .68772 L .5024 .68205 L p .707 .577 .707 r
F P
0 g
s
.59583 .88953 m .59446 .87227 L .56332 .87128 L p .707 .577 .707 r
F P
0 g
s
.59446 .87227 m .59583 .88953 L .62757 .88614 L p .707 .577 .707 r
F P
0 g
s
.62757 .88614 m .62619 .86888 L .59446 .87227 L p .707 .577 .707 r
F P
0 g
s
.62619 .86888 m .62757 .88614 L .65679 .87868 L p .707 .577 .707 r
F P
0 g
s
.65679 .87868 m .65542 .86142 L .62619 .86888 L p .707 .577 .707 r
F P
0 g
s
.51222 .78757 m .51247 .82445 L .53352 .83115 L p .707 .577 .707 r
F P
0 g
s
.56469 .88854 m .56332 .87128 L .53583 .86598 L p .707 .577 .707 r
F P
0 g
s
.56332 .87128 m .56469 .88854 L .59583 .88953 L p .707 .577 .707 r
F P
0 g
s
.67718 .78967 m .67742 .82656 L .69379 .81867 L p .707 .577 .707 r
F P
0 g
s
.69379 .81867 m .69354 .78179 L .67718 .78967 L p .707 .577 .707 r
F P
0 g
s
.5024 .68205 m .50024 .7388 L .51288 .74446 L p .707 .577 .707 r
F P
0 g
s
.65542 .86142 m .65679 .87868 L .68065 .86788 L p .707 .577 .707 r
F P
0 g
s
.68065 .86788 m .67928 .85062 L .65542 .86142 L p .707 .577 .707 r
F P
0 g
s
.53583 .86598 m .5372 .88324 L .56469 .88854 L p .707 .577 .707 r
F P
0 g
s
.69621 .69141 m .69405 .74816 L .70107 .7429 L p .707 .577 .707 r
F P
0 g
s
.70107 .7429 m .70323 .68615 L .69621 .69141 L p .707 .577 .707 r
F P
0 g
s
.51247 .82445 m .51222 .78757 L .49963 .77931 L p .707 .577 .707 r
F P
0 g
s
.5372 .88324 m .53583 .86598 L .51467 .85691 L p .707 .577 .707 r
F P
0 g
s
.50024 .7388 m .5024 .68205 L .49945 .67631 L p .707 .577 .707 r
F P
0 g
s
.49963 .77931 m .49987 .8162 L .51247 .82445 L p .707 .577 .707 r
F P
0 g
s
.67928 .85062 m .68065 .86788 L .6968 .85481 L p .707 .577 .707 r
F P
0 g
s
.6968 .85481 m .69543 .83755 L .67928 .85062 L p .707 .577 .707 r
F P
0 g
s
.51467 .85691 m .51605 .87417 L .5372 .88324 L p .707 .577 .707 r
F P
0 g
s
.69354 .78179 m .69379 .81867 L .70087 .80979 L p .707 .577 .707 r
F P
0 g
s
.70087 .80979 m .70062 .7729 L .69354 .78179 L p .707 .577 .707 r
F P
0 g
s
.49945 .67631 m .49729 .73306 L .50024 .7388 L p .707 .577 .707 r
F P
0 g
s
.51605 .87417 m .51467 .85691 L .50192 .84494 L p .707 .577 .707 r
F P
0 g
s
.70323 .68615 m .70107 .7429 L .69812 .73716 L p .707 .577 .707 r
F P
0 g
s
.69812 .73716 m .70028 .68041 L .70323 .68615 L p .707 .577 .707 r
F P
0 g
s
.49987 .8162 m .49963 .77931 L .49673 .7703 L p .707 .577 .707 r
F P
0 g
s
.50192 .84494 m .5033 .8622 L .51605 .87417 L p .707 .577 .707 r
F P
0 g
s
.69543 .83755 m .6968 .85481 L .70366 .84075 L p .707 .577 .707 r
F P
0 g
s
.70366 .84075 m .70229 .82349 L .69543 .83755 L p .707 .577 .707 r
F P
0 g
s
.49673 .7703 m .49697 .80719 L .49987 .8162 L p .707 .577 .707 r
F P
0 g
s
.49729 .73306 m .49945 .67631 L .50648 .67105 L p .707 .577 .707 r
F P
0 g
s
.70062 .7729 m .70087 .80979 L .69797 .80078 L p .707 .577 .707 r
F P
0 g
s
.69797 .80078 m .69773 .76389 L .70062 .7729 L p .707 .577 .707 r
F P
0 g
s
.49238 .81834 m .49555 .3144 L .45154 .3116 L p .707 .577 .707 r
F P
0 g
s
.50648 .67105 m .50432 .7278 L .49729 .73306 L p .707 .577 .707 r
F P
0 g
s
.49697 .80719 m .49673 .7703 L .50381 .76142 L p .707 .577 .707 r
F P
0 g
s
.50381 .76142 m .50406 .79831 L .49697 .80719 L p .707 .577 .707 r
F P
0 g
s
.50432 .7278 m .50648 .67105 L .52279 .66679 L p .707 .577 .707 r
F P
0 g
s
.52279 .66679 m .52063 .72353 L .50432 .7278 L p .707 .577 .707 r
F P
0 g
s
.5033 .8622 m .50192 .84494 L .49883 .83126 L p .707 .577 .707 r
F P
0 g
s
.49883 .83126 m .5002 .84852 L .5033 .8622 L p .707 .577 .707 r
F P
0 g
s
.5002 .84852 m .49883 .83126 L .50569 .81719 L p .707 .577 .707 r
F P
0 g
s
.50406 .79831 m .50381 .76142 L .52018 .75354 L p .707 .577 .707 r
F P
0 g
s
.50569 .81719 m .50707 .83445 L .5002 .84852 L p .707 .577 .707 r
F P
0 g
s
.52063 .72353 m .52279 .66679 L .54678 .66393 L p .707 .577 .707 r
F P
0 g
s
.52018 .75354 m .52042 .79042 L .50406 .79831 L p .707 .577 .707 r
F P
0 g
s
.54678 .66393 m .54463 .72068 L .52063 .72353 L p .707 .577 .707 r
F P
0 g
s
.50707 .83445 m .50569 .81719 L .52184 .80412 L p .707 .577 .707 r
F P
0 g
s
.52042 .79042 m .52018 .75354 L .54423 .74742 L p .707 .577 .707 r
F P
0 g
s
.52184 .80412 m .52322 .82138 L .50707 .83445 L p .707 .577 .707 r
F P
0 g
s
.54423 .74742 m .54447 .7843 L .52042 .79042 L p .707 .577 .707 r
F P
0 g
s
.52322 .82138 m .52184 .80412 L .5457 .79333 L p .707 .577 .707 r
F P
0 g
s
.5457 .79333 m .54707 .81059 L .52322 .82138 L p .707 .577 .707 r
F P
0 g
s
.49555 .3144 m .49238 .81834 L .53733 .81756 L p .707 .577 .707 r
F P
0 g
s
.53733 .81756 m .54049 .31362 L .49555 .3144 L p .707 .577 .707 r
F P
0 g
s
.54463 .72068 m .54678 .66393 L .57612 .66278 L p .707 .577 .707 r
F P
0 g
s
.57612 .66278 m .57397 .71953 L .54463 .72068 L p .707 .577 .707 r
F P
0 g
s
.54447 .7843 m .54423 .74742 L .57361 .74367 L p .707 .577 .707 r
F P
0 g
s
.57361 .74367 m .57385 .78055 L .54447 .7843 L p .707 .577 .707 r
F P
0 g
s
.57385 .78055 m .57361 .74367 L .60545 .74265 L p .707 .577 .707 r
F P
0 g
s
.60545 .74265 m .60569 .77954 L .57385 .78055 L p .707 .577 .707 r
F P
0 g
s
.54707 .81059 m .5457 .79333 L .57493 .78587 L p .707 .577 .707 r
F P
0 g
s
.57493 .78587 m .5763 .80313 L .54707 .81059 L p .707 .577 .707 r
F P
0 g
s
.5763 .80313 m .57493 .78587 L .60666 .78247 L p .707 .577 .707 r
F P
0 g
s
.60666 .78247 m .60803 .79973 L .5763 .80313 L p .707 .577 .707 r
F P
0 g
s
.54049 .31362 m .53733 .81756 L .57881 .8133 L p .707 .577 .707 r
F P
0 g
s
.57397 .71953 m .57612 .66278 L .60793 .66343 L p .707 .577 .707 r
F P
0 g
s
.60793 .66343 m .60577 .72017 L .57397 .71953 L p .707 .577 .707 r
F P
0 g
s
.57881 .8133 m .58197 .30936 L .54049 .31362 L p .707 .577 .707 r
F P
0 g
s
.44838 .81554 m .45154 .3116 L .41277 .30551 L p .707 .577 .707 r
F P
0 g
s
.45154 .3116 m .44838 .81554 L .49238 .81834 L p .707 .577 .707 r
F P
0 g
s
.70028 .68041 m .69812 .73716 L .68549 .73149 L p .707 .577 .707 r
F P
0 g
s
.68549 .73149 m .68765 .67475 L .70028 .68041 L p .707 .577 .707 r
F P
0 g
s
.70229 .82349 m .70366 .84075 L .70057 .82706 L p .707 .577 .707 r
F P
0 g
s
.70057 .82706 m .6992 .8098 L .70229 .82349 L p .707 .577 .707 r
F P
0 g
s
.24958 .71897 m .25174 .66222 L .22058 .65983 L p .707 .577 .707 r
F P
0 g
s
.25174 .66222 m .24958 .71897 L .28139 .71962 L p .707 .577 .707 r
F P
0 g
s
.28139 .71962 m .28355 .66287 L .25174 .66222 L p .707 .577 .707 r
F P
0 g
s
.28355 .66287 m .28139 .71962 L .31073 .71846 L p .707 .577 .707 r
F P
0 g
s
.31073 .71846 m .31289 .66171 L .28355 .66287 L p .707 .577 .707 r
F P
0 g
s
.6391 .66582 m .63694 .72257 L .60577 .72017 L p .707 .577 .707 r
F P
0 g
s
.60577 .72017 m .60793 .66343 L .6391 .66582 L p .707 .577 .707 r
F P
0 g
s
.63662 .74447 m .63686 .78136 L .60569 .77954 L p .707 .577 .707 r
F P
0 g
s
.60569 .77954 m .60545 .74265 L .63662 .74447 L p .707 .577 .707 r
F P
0 g
s
.6378 .78347 m .63917 .80073 L .60803 .79973 L p .707 .577 .707 r
F P
0 g
s
.60803 .79973 m .60666 .78247 L .6378 .78347 L p .707 .577 .707 r
F P
0 g
s
.58197 .30936 m .57881 .8133 L .61276 .80596 L p .707 .577 .707 r
F P
0 g
s
.61276 .80596 m .61592 .30201 L .58197 .30936 L p .707 .577 .707 r
F P
0 g
s
.21842 .71658 m .22058 .65983 L .19311 .65593 L p .707 .577 .707 r
F P
0 g
s
.22058 .65983 m .21842 .71658 L .24958 .71897 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69773 .76389 m .69797 .80078 L .68538 .79252 L p .707 .577 .707 r
F P
0 g
s
.68538 .79252 m .68513 .75564 L .69773 .76389 L p .707 .577 .707 r
F P
0 g
s
.40961 .80945 m .41277 .30551 L .38305 .29672 L p .707 .577 .707 r
F P
0 g
s
.41277 .30551 m .40961 .80945 L .44838 .81554 L p .707 .577 .707 r
F P
0 g
s
.31289 .66171 m .31073 .71846 L .33473 .71561 L p .707 .577 .707 r
F P
0 g
s
.33473 .71561 m .33689 .65886 L .31289 .66171 L p .707 .577 .707 r
F P
0 g
s
.19311 .65593 m .19095 .71268 L .21842 .71658 L p .707 .577 .707 r
F P
0 g
s
.24914 .80062 m .2489 .76374 L .21773 .76192 L p .707 .577 .707 r
F P
0 g
s
.2489 .76374 m .24914 .80062 L .28098 .79961 L p .707 .577 .707 r
F P
0 g
s
.28098 .79961 m .28073 .76272 L .2489 .76374 L p .707 .577 .707 r
F P
0 g
s
.68765 .67475 m .68549 .73149 L .6644 .72647 L p .707 .577 .707 r
F P
0 g
s
.6644 .72647 m .66656 .66972 L .68765 .67475 L p .707 .577 .707 r
F P
0 g
s
.19095 .71268 m .19311 .65593 L .17203 .6509 L p .707 .577 .707 r
F P
0 g
s
.28073 .76272 m .28098 .79961 L .31036 .79586 L p .707 .577 .707 r
F P
0 g
s
.31036 .79586 m .31012 .75897 L .28073 .76272 L p .707 .577 .707 r
F P
0 g
s
.6992 .8098 m .70057 .82706 L .68782 .8151 L p .707 .577 .707 r
F P
0 g
s
.68782 .8151 m .68645 .79784 L .6992 .8098 L p .707 .577 .707 r
F P
0 g
s
.21797 .79881 m .21773 .76192 L .19027 .75745 L p .707 .577 .707 r
F P
0 g
s
.21773 .76192 m .21797 .79881 L .24914 .80062 L p .707 .577 .707 r
F P
0 g
s
.17203 .6509 m .16987 .70765 L .19095 .71268 L p .707 .577 .707 r
F P
0 g
s
.61592 .30201 m .61276 .80596 L .63587 .79626 L p .707 .577 .707 r
F P
0 g
s
.63587 .79626 m .63903 .29231 L .61592 .30201 L p .707 .577 .707 r
F P
0 g
s
.31012 .75897 m .31036 .79586 L .33441 .78974 L p .707 .577 .707 r
F P
0 g
s
.33441 .78974 m .33417 .75286 L .31012 .75897 L p .707 .577 .707 r
F P
0 g
s
.33689 .65886 m .33473 .71561 L .35104 .71135 L p .707 .577 .707 r
F P
0 g
s
.35104 .71135 m .3532 .6546 L .33689 .65886 L p .707 .577 .707 r
F P
0 g
s
.68513 .75564 m .68538 .79252 L .66432 .78583 L p .707 .577 .707 r
F P
0 g
s
.66432 .78583 m .66408 .74895 L .68513 .75564 L p .707 .577 .707 r
F P
0 g
s
.19027 .75745 m .19051 .79433 L .21797 .79881 L p .707 .577 .707 r
F P
0 g
s
.19051 .79433 m .19027 .75745 L .16921 .75075 L p .707 .577 .707 r
F P
0 g
s
.66656 .66972 m .6644 .72647 L .63694 .72257 L p .707 .577 .707 r
F P
0 g
s
.63694 .72257 m .6391 .66582 L .66656 .66972 L p .707 .577 .707 r
F P
0 g
s
.16987 .70765 m .17203 .6509 L .15939 .64524 L p .707 .577 .707 r
F P
0 g
s
.25282 .85272 m .25145 .83546 L .22031 .83446 L p .707 .577 .707 r
F P
0 g
s
.25145 .83546 m .25282 .85272 L .28456 .84932 L p .707 .577 .707 r
F P
0 g
s
.28456 .84932 m .28319 .83206 L .25145 .83546 L p .707 .577 .707 r
F P
0 g
s
.37988 .80067 m .38305 .29672 L .36527 .2861 L p .707 .577 .707 r
F P
0 g
s
.38305 .29672 m .37988 .80067 L .40961 .80945 L p .707 .577 .707 r
F P
0 g
s
.28319 .83206 m .28456 .84932 L .31378 .84186 L p .707 .577 .707 r
F P
0 g
s
.31378 .84186 m .31241 .8246 L .28319 .83206 L p .707 .577 .707 r
F P
0 g
s
.68645 .79784 m .68782 .8151 L .66666 .80602 L p .707 .577 .707 r
F P
0 g
s
.66666 .80602 m .66529 .78876 L .68645 .79784 L p .707 .577 .707 r
F P
0 g
s
.16921 .75075 m .16946 .78764 L .19051 .79433 L p .707 .577 .707 r
F P
0 g
s
.22169 .85172 m .22031 .83446 L .19282 .82917 L p .707 .577 .707 r
F P
0 g
s
.22031 .83446 m .22169 .85172 L .25282 .85272 L p .707 .577 .707 r
F P
0 g
s
.33417 .75286 m .33441 .78974 L .35078 .78186 L p .707 .577 .707 r
F P
0 g
s
.35078 .78186 m .35053 .74497 L .33417 .75286 L p .707 .577 .707 r
F P
0 g
s
.15939 .64524 m .15724 .70199 L .16987 .70765 L p .707 .577 .707 r
F P
0 g
s
.31241 .8246 m .31378 .84186 L .33764 .83107 L p .707 .577 .707 r
F P
0 g
s
.33764 .83107 m .33627 .81381 L .31241 .8246 L p .707 .577 .707 r
F P
0 g
s
.66408 .74895 m .66432 .78583 L .63686 .78136 L p .707 .577 .707 r
F P
0 g
s
.63686 .78136 m .63662 .74447 L .66408 .74895 L p .707 .577 .707 r
F P
0 g
s
.19282 .82917 m .19419 .84643 L .22169 .85172 L p .707 .577 .707 r
F P
0 g
s
.3532 .6546 m .35104 .71135 L .35806 .70608 L p .707 .577 .707 r
F P
0 g
s
.35806 .70608 m .36022 .64934 L .3532 .6546 L p .707 .577 .707 r
F P
0 g
s
.16946 .78764 m .16921 .75075 L .15662 .7425 L p .707 .577 .707 r
F P
0 g
s
.19419 .84643 m .19282 .82917 L .17166 .82009 L p .707 .577 .707 r
F P
0 g
s
.63917 .80073 m .6378 .78347 L .66529 .78876 L p .707 .577 .707 r
F P
0 g
s
.63903 .29231 m .63587 .79626 L .64587 .78515 L p .707 .577 .707 r
F P
0 g
s
.64587 .78515 m .64903 .28121 L .63903 .29231 L p .707 .577 .707 r
F P
0 g
s
.15724 .70199 m .15939 .64524 L .15644 .6395 L p .707 .577 .707 r
F P
0 g
s
.66529 .78876 m .66666 .80602 L .63917 .80073 L p .707 .577 .707 r
F P
0 g
s
.15662 .7425 m .15686 .77938 L .16946 .78764 L p .707 .577 .707 r
F P
0 g
s
.33627 .81381 m .33764 .83107 L .35379 .818 L p .707 .577 .707 r
F P
0 g
s
.35379 .818 m .35242 .80074 L .33627 .81381 L p .707 .577 .707 r
F P
0 g
s
.17166 .82009 m .17304 .83735 L .19419 .84643 L p .707 .577 .707 r
F P
0 g
s
.35053 .74497 m .35078 .78186 L .35786 .77297 L p .707 .577 .707 r
F P
0 g
s
.35786 .77297 m .35761 .73609 L .35053 .74497 L p .707 .577 .707 r
F P
0 g
s
.15644 .6395 m .15428 .69624 L .15724 .70199 L p .707 .577 .707 r
F P
0 g
s
.36211 .79004 m .36527 .2861 L .36118 .27467 L p .707 .577 .707 r
F P
0 g
s
.36527 .2861 m .36211 .79004 L .37988 .80067 L p .707 .577 .707 r
F P
0 g
s
.17304 .83735 m .17166 .82009 L .15891 .80813 L p .707 .577 .707 r
F P
0 g
s
.36022 .64934 m .35806 .70608 L .35511 .70034 L p .707 .577 .707 r
F P
0 g
s
.35511 .70034 m .35727 .64359 L .36022 .64934 L p .707 .577 .707 r
F P
0 g
s
.15686 .77938 m .15662 .7425 L .15372 .73349 L p .707 .577 .707 r
F P
0 g
s
.15891 .80813 m .16029 .82539 L .17304 .83735 L p .707 .577 .707 r
F P
0 g
s
.35242 .80074 m .35379 .818 L .36065 .80393 L p .707 .577 .707 r
F P
0 g
s
.36065 .80393 m .35928 .78667 L .35242 .80074 L p .707 .577 .707 r
F P
0 g
s
.15372 .73349 m .15396 .77037 L .15686 .77938 L p .707 .577 .707 r
F P
0 g
s
.15428 .69624 m .15644 .6395 L .16347 .63423 L p .707 .577 .707 r
F P
0 g
s
.35761 .73609 m .35786 .77297 L .35496 .76396 L p .707 .577 .707 r
F P
0 g
s
.35496 .76396 m .35472 .72708 L .35761 .73609 L p .707 .577 .707 r
F P
0 g
s
.64903 .28121 m .64587 .78515 L .64284 .77671 L p .707 .577 .707 r
F P
0 g
s
.64236 .73417 m .64903 .28121 L .64284 .77671 L .707 .577 .707 r
F
.64236 .73417 m .64398 .4421 L .64903 .28121 L F
.64214 .71524 m .64375 .45876 L p .64236 .73417 L F P
0 g
s
.64375 .45876 m .64494 .26978 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64375 .45876 m .64398 .4421 L .64236 .73417 L .707 .577 .707 r
F
.64494 .26978 m .64177 .77373 L .624 .7631 L p F P
0 g
s
.63683 .64064 m .63708 .67752 L .64072 .67991 L p .707 .577 .707 r
F P
0 g
s
.64072 .67991 m .64967 .68578 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64105 .65547 m .63683 .64064 L .64072 .67991 L .707 .577 .707 r
F
.64967 .68578 m .64943 .64889 L .64122 .64351 L p F P
0 g
s
.64122 .64351 m .63683 .64064 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64967 .68578 m .64122 .64351 L .64105 .65547 L .707 .577 .707 r
F
.64494 .26978 m .64629 .27357 L p .64398 .4421 L F P
0 g
s
.64629 .27357 m .64903 .28121 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64177 .77373 m .64214 .71524 L p .64236 .73417 L .707 .577 .707 r
F P
0 g
s
.63961 .56304 m .63745 .61979 L .64107 .62142 L p .707 .577 .707 r
F P
0 g
s
.64107 .62142 m .65008 .62545 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.64047 .56817 m .63961 .56304 L .64107 .62142 L .707 .577 .707 r
F
.65008 .62545 m .65224 .56871 L .64041 .5634 L p F P
0 g
s
.64041 .5634 m .63961 .56304 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.65008 .62545 m .64041 .5634 L .64047 .56817 L .707 .577 .707 r
F
.64284 .77671 m .64177 .77373 L p .64236 .73417 L F P
0 g
s
.16347 .63423 m .16131 .69098 L .15428 .69624 L p .707 .577 .707 r
F P
0 g
s
.16029 .82539 m .15891 .80813 L .15582 .79444 L p .707 .577 .707 r
F P
0 g
s
.15396 .77037 m .15372 .73349 L .1608 .72461 L p .707 .577 .707 r
F P
0 g
s
.35727 .64359 m .35511 .70034 L .34248 .69468 L p .707 .577 .707 r
F P
0 g
s
.34248 .69468 m .34464 .63793 L .35727 .64359 L p .707 .577 .707 r
F P
0 g
s
.15582 .79444 m .15719 .8117 L .16029 .82539 L p .707 .577 .707 r
F P
0 g
s
.35928 .78667 m .36065 .80393 L .35756 .79025 L p .707 .577 .707 r
F P
0 g
s
.35756 .79025 m .35619 .77299 L .35928 .78667 L p .707 .577 .707 r
F P
0 g
s
.36118 .27467 m .35801 .77861 L .36211 .79004 L p .707 .577 .707 r
F P
0 g
s
.35801 .77861 m .36118 .27467 L .37117 .26357 L p .707 .577 .707 r
F P
0 g
s
.1608 .72461 m .16105 .76149 L .15396 .77037 L p .707 .577 .707 r
F P
0 g
s
.16131 .69098 m .16347 .63423 L .17978 .62997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35472 .72708 m .35496 .76396 L .34237 .75571 L p .707 .577 .707 r
F P
0 g
s
.34237 .75571 m .34212 .71882 L .35472 .72708 L p .707 .577 .707 r
F P
0 g
s
.17978 .62997 m .17762 .68672 L .16131 .69098 L p .707 .577 .707 r
F P
0 g
s
.15719 .8117 m .15582 .79444 L .16268 .78037 L p .707 .577 .707 r
F P
0 g
s
.34464 .63793 m .34248 .69468 L .32139 .68965 L p .707 .577 .707 r
F P
0 g
s
.32139 .68965 m .32355 .6329 L .34464 .63793 L p .707 .577 .707 r
F P
0 g
s
.16105 .76149 m .1608 .72461 L .17717 .71672 L p .707 .577 .707 r
F P
0 g
s
.16268 .78037 m .16406 .79764 L .15719 .8117 L p .707 .577 .707 r
F P
0 g
s
.624 .7631 m .62716 .25916 L .64494 .26978 L p .707 .577 .707 r
F P
0 g
s
.35619 .77299 m .35756 .79025 L .34481 .77828 L p .707 .577 .707 r
F P
0 g
s
.34481 .77828 m .34344 .76102 L .35619 .77299 L p .707 .577 .707 r
F P
0 g
s
.17762 .68672 m .17978 .62997 L .20377 .62712 L p .707 .577 .707 r
F P
0 g
s
.17717 .71672 m .17741 .75361 L .16105 .76149 L p .707 .577 .707 r
F P
0 g
s
.34212 .71882 m .34237 .75571 L .32131 .74902 L p .707 .577 .707 r
F P
0 g
s
.32131 .74902 m .32107 .71213 L .34212 .71882 L p .707 .577 .707 r
F P
0 g
s
.36801 .76751 m .37117 .26357 L .39428 .25387 L p .707 .577 .707 r
F P
0 g
s
.37117 .26357 m .36801 .76751 L .35801 .77861 L p .707 .577 .707 r
F P
0 g
s
.20377 .62712 m .20162 .68387 L .17762 .68672 L p .707 .577 .707 r
F P
0 g
s
.16406 .79764 m .16268 .78037 L .17883 .76731 L p .707 .577 .707 r
F P
0 g
s
.32355 .6329 m .32139 .68965 L .29393 .68575 L p .707 .577 .707 r
F P
0 g
s
.29393 .68575 m .29609 .629 L .32355 .6329 L p .707 .577 .707 r
F P
0 g
s
.17741 .75361 m .17717 .71672 L .20122 .7106 L p .707 .577 .707 r
F P
0 g
s
.17883 .76731 m .18021 .78457 L .16406 .79764 L p .707 .577 .707 r
F P
0 g
s
.20162 .68387 m .20377 .62712 L .23311 .62596 L p .707 .577 .707 r
F P
0 g
s
.34344 .76102 m .34481 .77828 L .32365 .76921 L p .707 .577 .707 r
F P
0 g
s
.32365 .76921 m .32228 .75195 L .34344 .76102 L p .707 .577 .707 r
F P
0 g
s
.7298 .63677 m .73196 .58003 L .70079 .57763 L p .707 .577 .707 r
F P
0 g
s
.73196 .58003 m .7298 .63677 L .76161 .63742 L p .707 .577 .707 r
F P
0 g
s
.76161 .63742 m .76376 .58068 L .73196 .58003 L p .707 .577 .707 r
F P
0 g
s
.20122 .7106 m .20146 .74749 L .17741 .75361 L p .707 .577 .707 r
F P
0 g
s
.32107 .71213 m .32131 .74902 L .29385 .74454 L p .707 .577 .707 r
F P
0 g
s
.29385 .74454 m .29361 .70766 L .32107 .71213 L p .707 .577 .707 r
F P
0 g
s
.76376 .58068 m .76161 .63742 L .79094 .63627 L p .707 .577 .707 r
F P
0 g
s
.79094 .63627 m .7931 .57952 L .76376 .58068 L p .707 .577 .707 r
F P
0 g
s
.29609 .629 m .29393 .68575 L .26276 .68336 L p .707 .577 .707 r
F P
0 g
s
.26276 .68336 m .26492 .62661 L .29609 .629 L p .707 .577 .707 r
F P
0 g
s
.23311 .62596 m .23096 .68271 L .20162 .68387 L p .707 .577 .707 r
F P
0 g
s
.62716 .25916 m .624 .7631 L .59427 .75431 L p .707 .577 .707 r
F P
0 g
s
.59427 .75431 m .59743 .25037 L .62716 .25916 L p .707 .577 .707 r
F P
0 g
s
.69863 .63438 m .70079 .57763 L .67332 .57373 L p .707 .577 .707 r
F P
0 g
s
.70079 .57763 m .69863 .63438 L .7298 .63677 L p .707 .577 .707 r
F P
0 g
s
.23096 .68271 m .23311 .62596 L .26492 .62661 L p .707 .577 .707 r
F P
0 g
s
.18021 .78457 m .17883 .76731 L .20269 .75651 L p .707 .577 .707 r
F P
0 g
s
.26492 .62661 m .26276 .68336 L .23096 .68271 L p .707 .577 .707 r
F P
0 g
s
.20146 .74749 m .20122 .7106 L .2306 .70685 L p .707 .577 .707 r
F P
0 g
s
.72936 .69876 m .72911 .66188 L .69794 .66006 L p .707 .577 .707 r
F P
0 g
s
.72911 .66188 m .72936 .69876 L .76119 .69775 L p .707 .577 .707 r
F P
0 g
s
.76119 .69775 m .76095 .66086 L .72911 .66188 L p .707 .577 .707 r
F P
0 g
s
.7931 .57952 m .79094 .63627 L .81494 .63342 L p .707 .577 .707 r
F P
0 g
s
.81494 .63342 m .8171 .57667 L .7931 .57952 L p .707 .577 .707 r
F P
0 g
s
.67332 .57373 m .67117 .63048 L .69863 .63438 L p .707 .577 .707 r
F P
0 g
s
.32228 .75195 m .32365 .76921 L .29616 .76391 L p .707 .577 .707 r
F P
0 g
s
.29616 .76391 m .29479 .74665 L .32228 .75195 L p .707 .577 .707 r
F P
0 g
s
.20269 .75651 m .20406 .77377 L .18021 .78457 L p .707 .577 .707 r
F P
0 g
s
.76095 .66086 m .76119 .69775 L .79057 .694 L p .707 .577 .707 r
F P
0 g
s
.79057 .694 m .79033 .65711 L .76095 .66086 L p .707 .577 .707 r
F P
0 g
s
.29361 .70766 m .29385 .74454 L .26268 .74272 L p .707 .577 .707 r
F P
0 g
s
.26268 .74272 m .26244 .70584 L .29361 .70766 L p .707 .577 .707 r
F P
0 g
s
.39428 .25387 m .39112 .75781 L .36801 .76751 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .39428 .25387 L .42824 .24652 L p .707 .577 .707 r
F P
0 g
s
.2306 .70685 m .23085 .74374 L .20146 .74749 L p .707 .577 .707 r
F P
0 g
s
.69818 .69694 m .69794 .66006 L .67048 .65558 L p .707 .577 .707 r
F P
0 g
s
.69794 .66006 m .69818 .69694 L .72936 .69876 L p .707 .577 .707 r
F P
0 g
s
.67117 .63048 m .67332 .57373 L .65224 .56871 L p .707 .577 .707 r
F P
0 g
s
.23085 .74374 m .2306 .70685 L .26244 .70584 L p .707 .577 .707 r
F P
0 g
s
.26244 .70584 m .26268 .74272 L .23085 .74374 L p .707 .577 .707 r
F P
0 g
s
.20406 .77377 m .20269 .75651 L .23192 .74905 L p .707 .577 .707 r
F P
0 g
s
.79033 .65711 m .79057 .694 L .81462 .68788 L p .707 .577 .707 r
F P
0 g
s
.81462 .68788 m .81438 .65099 L .79033 .65711 L p .707 .577 .707 r
F P
0 g
s
.29479 .74665 m .29616 .76391 L .26502 .76292 L p .707 .577 .707 r
F P
0 g
s
.26502 .76292 m .26365 .74565 L .29479 .74665 L p .707 .577 .707 r
F P
0 g
s
.65224 .56871 m .65008 .62545 L .67117 .63048 L p .707 .577 .707 r
F P
0 g
s
.67048 .65558 m .67073 .69247 L .69818 .69694 L p .707 .577 .707 r
F P
0 g
s
.23192 .74905 m .23329 .76631 L .20406 .77377 L p .707 .577 .707 r
F P
0 g
s
.8171 .57667 m .81494 .63342 L .83125 .62915 L p .707 .577 .707 r
F P
0 g
s
.83125 .62915 m .83341 .5724 L .8171 .57667 L p .707 .577 .707 r
F P
0 g
s
.67073 .69247 m .67048 .65558 L .64943 .64889 L p .707 .577 .707 r
F P
0 g
s
.23329 .76631 m .23192 .74905 L .26365 .74565 L p .707 .577 .707 r
F P
0 g
s
.59743 .25037 m .59427 .75431 L .5555 .74822 L p .707 .577 .707 r
F P
0 g
s
.5555 .74822 m .55867 .24428 L .59743 .25037 L p .707 .577 .707 r
F P
0 g
s
.26365 .74565 m .26502 .76292 L .23329 .76631 L p .707 .577 .707 r
F P
0 g
s
.73304 .75786 m .73166 .7406 L .70053 .7396 L p .707 .577 .707 r
F P
0 g
s
.73166 .7406 m .73304 .75786 L .76477 .75446 L p .707 .577 .707 r
F P
0 g
s
.76477 .75446 m .7634 .7372 L .73166 .7406 L p .707 .577 .707 r
F P
0 g
s
.7634 .7372 m .76477 .75446 L .794 .747 L p .707 .577 .707 r
F P
0 g
s
.794 .747 m .79262 .72974 L .7634 .7372 L p .707 .577 .707 r
F P
0 g
s
.64943 .64889 m .64967 .68578 L .67073 .69247 L p .707 .577 .707 r
F P
0 g
s
.42507 .75047 m .42824 .24652 L .46971 .24226 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .42171 .33646 L .42544 .69198 L .707 .577 .707 r
F
.42824 .24652 m .42705 .4355 L p .42171 .33646 L F P
0 g
s
.42705 .4355 m .42544 .69198 L p .42171 .33646 L .707 .577 .707 r
F P
0 g
s
.46971 .24226 m .46655 .7462 L .42507 .75047 L p .707 .577 .707 r
F P
0 g
s
.41794 .62405 m .41818 .66093 L .43907 .65827 L p .707 .577 .707 r
F P
0 g
s
.43907 .65827 m .44756 .65718 L p .43846 .647 L .707 .577 .707 r
F P
0 g
s
.43846 .647 m .41794 .62405 L .43907 .65827 L .707 .577 .707 r
F
.42075 .54386 m .4186 .60061 L .43952 .59978 L p F P
0 g
s
.43952 .59978 m .44794 .59945 L p .44156 .58641 L .707 .577 .707 r
F P
0 g
s
.44156 .58641 m .42075 .54386 L .43952 .59978 L .707 .577 .707 r
F
.42544 .69198 m .42507 .75047 L .41622 .75238 L p F P
0 g
s
.41622 .75238 m .39112 .75781 L p .42544 .69198 L .707 .577 .707 r
F P
0 g
s
.81438 .65099 m .81462 .68788 L .83099 .67999 L p .707 .577 .707 r
F P
0 g
s
.83099 .67999 m .83075 .64311 L .81438 .65099 L p .707 .577 .707 r
F P
0 g
s
.7019 .75686 m .70053 .7396 L .67303 .73431 L p .707 .577 .707 r
F P
0 g
s
.70053 .7396 m .7019 .75686 L .73304 .75786 L p .707 .577 .707 r
F P
0 g
s
.79262 .72974 m .794 .747 L .81785 .73621 L p .707 .577 .707 r
F P
0 g
s
.81785 .73621 m .81648 .71895 L .79262 .72974 L p .707 .577 .707 r
F P
0 g
s
.67303 .73431 m .67441 .75157 L .7019 .75686 L p .707 .577 .707 r
F P
0 g
s
.55867 .24428 m .5555 .74822 L .5115 .74543 L p .707 .577 .707 r
F P
0 g
s
.5115 .74543 m .51466 .24148 L .55867 .24428 L p .707 .577 .707 r
F P
0 g
s
.83341 .5724 m .83125 .62915 L .83828 .62389 L p .707 .577 .707 r
F P
0 g
s
.83828 .62389 m .84044 .56714 L .83341 .5724 L p .707 .577 .707 r
F P
0 g
s
.67441 .75157 m .67303 .73431 L .65188 .72523 L p .707 .577 .707 r
F P
0 g
s
.46655 .7462 m .46971 .24226 L .51466 .24148 L p .707 .577 .707 r
F P
0 g
s
.51466 .24148 m .5115 .74543 L .46655 .7462 L p .707 .577 .707 r
F P
0 g
s
.81648 .71895 m .81785 .73621 L .834 .72314 L p .707 .577 .707 r
F P
0 g
s
.834 .72314 m .83263 .70588 L .81648 .71895 L p .707 .577 .707 r
F P
0 g
s
.63745 .61979 m .63961 .56304 L .63666 .5573 L p .707 .577 .707 r
F P
0 g
s
.65188 .72523 m .65325 .74249 L .67441 .75157 L p .707 .577 .707 r
F P
0 g
s
.83075 .64311 m .83099 .67999 L .83807 .67111 L p .707 .577 .707 r
F P
0 g
s
.83807 .67111 m .83783 .63423 L .83075 .64311 L p .707 .577 .707 r
F P
0 g
s
.63666 .5573 m .6345 .61405 L .63745 .61979 L p .707 .577 .707 r
F P
0 g
s
.65325 .74249 m .65188 .72523 L .63913 .71327 L p .707 .577 .707 r
F P
0 g
s
.63708 .67752 m .63683 .64064 L .63393 .63163 L p .707 .577 .707 r
F P
0 g
s
.84044 .56714 m .83828 .62389 L .83533 .61815 L p .707 .577 .707 r
F P
0 g
s
.83533 .61815 m .83749 .5614 L .84044 .56714 L p .707 .577 .707 r
F P
0 g
s
.63913 .71327 m .6405 .73053 L .65325 .74249 L p .707 .577 .707 r
F P
0 g
s
.83263 .70588 m .834 .72314 L .84087 .70907 L p .707 .577 .707 r
F P
0 g
s
.84087 .70907 m .83949 .69181 L .83263 .70588 L p .707 .577 .707 r
F P
0 g
s
.63393 .63163 m .63418 .66851 L .63708 .67752 L p .707 .577 .707 r
F P
0 g
s
.6345 .61405 m .63666 .5573 L .64368 .55204 L p .707 .577 .707 r
F P
0 g
s
.83783 .63423 m .83807 .67111 L .83517 .6621 L p .707 .577 .707 r
F P
0 g
s
.83517 .6621 m .83493 .62522 L .83783 .63423 L p .707 .577 .707 r
F P
0 g
s
.6405 .73053 m .63913 .71327 L .63603 .69958 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64368 .55204 m .64152 .60879 L .6345 .61405 L p .707 .577 .707 r
F P
0 g
s
.63418 .66851 m .63393 .63163 L .64102 .62274 L p .707 .577 .707 r
F P
0 g
s
.63603 .69958 m .63741 .71684 L .6405 .73053 L p .707 .577 .707 r
F P
0 g
s
.83749 .5614 m .83533 .61815 L .82269 .61248 L p .707 .577 .707 r
F P
0 g
s
.82269 .61248 m .82485 .55574 L .83749 .5614 L p .707 .577 .707 r
F P
0 g
s
.83949 .69181 m .84087 .70907 L .83777 .69539 L p .707 .577 .707 r
F P
0 g
s
.83777 .69539 m .8364 .67813 L .83949 .69181 L p .707 .577 .707 r
F P
0 g
s
.64102 .62274 m .64126 .65963 L .63418 .66851 L p .707 .577 .707 r
F P
0 g
s
.38679 .59996 m .38895 .54321 L .35778 .54082 L p .707 .577 .707 r
F P
0 g
s
.38895 .54321 m .38679 .59996 L .4186 .60061 L p .707 .577 .707 r
F P
0 g
s
.4186 .60061 m .42075 .54386 L .38895 .54321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.44794 .59945 m .45009 .5427 L .42075 .54386 L p .707 .577 .707 r
F P
0 g
s
.64152 .60879 m .64368 .55204 L .65999 .54777 L p .707 .577 .707 r
F P
0 g
s
.83493 .62522 m .83517 .6621 L .82258 .65385 L p .707 .577 .707 r
F P
0 g
s
.82258 .65385 m .82234 .61696 L .83493 .62522 L p .707 .577 .707 r
F P
0 g
s
.35562 .59757 m .35778 .54082 L .33031 .53692 L p .707 .577 .707 r
F P
0 g
s
.35778 .54082 m .35562 .59757 L .38679 .59996 L p .707 .577 .707 r
F P
0 g
s
.63741 .71684 m .63603 .69958 L .6429 .68552 L p .707 .577 .707 r
F P
0 g
s
.65999 .54777 m .65783 .60452 L .64152 .60879 L p .707 .577 .707 r
F P
0 g
s
.38635 .66195 m .3861 .62506 L .35493 .62324 L p .707 .577 .707 r
F P
0 g
s
.3861 .62506 m .38635 .66195 L .41818 .66093 L p .707 .577 .707 r
F P
0 g
s
.41818 .66093 m .41794 .62405 L .3861 .62506 L p .707 .577 .707 r
F P
0 g
s
.45009 .5427 m .44794 .59945 L .47193 .5966 L p .707 .577 .707 r
F P
0 g
s
.47193 .5966 m .47409 .53985 L .45009 .5427 L p .707 .577 .707 r
F P
0 g
s
.33031 .53692 m .32816 .59367 L .35562 .59757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64126 .65963 m .64102 .62274 L .65738 .61486 L p .707 .577 .707 r
F P
0 g
s
.44756 .65718 m .44732 .6203 L .41794 .62405 L p .707 .577 .707 r
F P
0 g
s
.6429 .68552 m .64427 .70278 L .63741 .71684 L p .707 .577 .707 r
F P
0 g
s
.35517 .66013 m .35493 .62324 L .32747 .61877 L p .707 .577 .707 r
F P
0 g
s
.35493 .62324 m .35517 .66013 L .38635 .66195 L p .707 .577 .707 r
F P
0 g
s
.82485 .55574 m .82269 .61248 L .80161 .60746 L p .707 .577 .707 r
F P
0 g
s
.80161 .60746 m .80377 .55071 L .82485 .55574 L p .707 .577 .707 r
F P
0 g
s
.32816 .59367 m .33031 .53692 L .30923 .53189 L p .707 .577 .707 r
F P
0 g
s
.8364 .67813 m .83777 .69539 L .82503 .68342 L p .707 .577 .707 r
F P
0 g
s
.82503 .68342 m .82365 .66616 L .8364 .67813 L p .707 .577 .707 r
F P
0 g
s
.65738 .61486 m .65763 .65174 L .64126 .65963 L p .707 .577 .707 r
F P
0 g
s
.44732 .6203 m .44756 .65718 L .47161 .65106 L p .707 .577 .707 r
F P
0 g
s
.47161 .65106 m .47137 .61418 L .44732 .6203 L p .707 .577 .707 r
F P
0 g
s
.65783 .60452 m .65999 .54777 L .68399 .54492 L p .707 .577 .707 r
F P
0 g
s
.30923 .53189 m .30707 .58864 L .32816 .59367 L p .707 .577 .707 r
F P
0 g
s
.82234 .61696 m .82258 .65385 L .80152 .64715 L p .707 .577 .707 r
F P
0 g
s
.80152 .64715 m .80128 .61027 L .82234 .61696 L p .707 .577 .707 r
F P
0 g
s
.32747 .61877 m .32772 .65565 L .35517 .66013 L p .707 .577 .707 r
F P
0 g
s
.47409 .53985 m .47193 .5966 L .48824 .59234 L p .707 .577 .707 r
F P
0 g
s
.48824 .59234 m .4904 .53559 L .47409 .53985 L p .707 .577 .707 r
F P
0 g
s
.32772 .65565 m .32747 .61877 L .30642 .61208 L p .707 .577 .707 r
F P
0 g
s
.64427 .70278 m .6429 .68552 L .65905 .67245 L p .707 .577 .707 r
F P
0 g
s
.68399 .54492 m .68183 .60167 L .65783 .60452 L p .707 .577 .707 r
F P
0 g
s
.65763 .65174 m .65738 .61486 L .68143 .60874 L p .707 .577 .707 r
F P
0 g
s
.39003 .72104 m .38865 .70378 L .35752 .70279 L p .707 .577 .707 r
F P
0 g
s
.38865 .70378 m .39003 .72104 L .42176 .71765 L p .707 .577 .707 r
F P
0 g
s
.42176 .71765 m .42039 .70039 L .38865 .70378 L p .707 .577 .707 r
F P
0 g
s
.42039 .70039 m .42176 .71765 L .45099 .71019 L p .707 .577 .707 r
F P
0 g
s
.45099 .71019 m .44961 .69293 L .42039 .70039 L p .707 .577 .707 r
F P
0 g
s
.80377 .55071 m .80161 .60746 L .77414 .60356 L p .707 .577 .707 r
F P
0 g
s
.77414 .60356 m .7763 .54681 L .80377 .55071 L p .707 .577 .707 r
F P
0 g
s
.30707 .58864 m .30923 .53189 L .2966 .52623 L p .707 .577 .707 r
F P
0 g
s
.65905 .67245 m .66042 .68971 L .64427 .70278 L p .707 .577 .707 r
F P
0 g
s
.30642 .61208 m .30666 .64896 L .32772 .65565 L p .707 .577 .707 r
F P
0 g
s
.82365 .66616 m .82503 .68342 L .80387 .67435 L p .707 .577 .707 r
F P
0 g
s
.80387 .67435 m .8025 .65709 L .82365 .66616 L p .707 .577 .707 r
F P
0 g
s
.47137 .61418 m .47161 .65106 L .48798 .64318 L p .707 .577 .707 r
F P
0 g
s
.48798 .64318 m .48774 .60629 L .47137 .61418 L p .707 .577 .707 r
F P
0 g
s
.35889 .72005 m .35752 .70279 L .33002 .69749 L p .707 .577 .707 r
F P
0 g
s
.35752 .70279 m .35889 .72005 L .39003 .72104 L p .707 .577 .707 r
F P
0 g
s
.68183 .60167 m .68399 .54492 L .71333 .54377 L p .707 .577 .707 r
F P
0 g
s
.68143 .60874 m .68168 .64563 L .65763 .65174 L p .707 .577 .707 r
F P
0 g
s
.80128 .61027 m .80152 .64715 L .77407 .64268 L p .707 .577 .707 r
F P
0 g
s
.77407 .64268 m .77382 .60579 L .80128 .61027 L p .707 .577 .707 r
F P
0 g
s
.2966 .52623 m .29444 .58298 L .30707 .58864 L p .707 .577 .707 r
F P
0 g
s
.44961 .69293 m .45099 .71019 L .47484 .69939 L p .707 .577 .707 r
F P
0 g
s
.47484 .69939 m .47347 .68213 L .44961 .69293 L p .707 .577 .707 r
F P
0 g
s
.33002 .69749 m .3314 .71475 L .35889 .72005 L p .707 .577 .707 r
F P
0 g
s
.30666 .64896 m .30642 .61208 L .29382 .60382 L p .707 .577 .707 r
F P
0 g
s
.7763 .54681 m .77414 .60356 L .74298 .60116 L p .707 .577 .707 r
F P
0 g
s
.74298 .60116 m .74514 .54442 L .7763 .54681 L p .707 .577 .707 r
F P
0 g
s
.71333 .54377 m .71117 .60051 L .68183 .60167 L p .707 .577 .707 r
F P
0 g
s
.4904 .53559 m .48824 .59234 L .49527 .58707 L p .707 .577 .707 r
F P
0 g
s
.49527 .58707 m .49743 .53033 L .4904 .53559 L p .707 .577 .707 r
F P
0 g
s
.68168 .64563 m .68143 .60874 L .71082 .60499 L p .707 .577 .707 r
F P
0 g
s
.66042 .68971 m .65905 .67245 L .6829 .66165 L p .707 .577 .707 r
F P
0 g
s
.71117 .60051 m .71333 .54377 L .74514 .54442 L p .707 .577 .707 r
F P
0 g
s
.3314 .71475 m .33002 .69749 L .30887 .68842 L p .707 .577 .707 r
F P
0 g
s
.74514 .54442 m .74298 .60116 L .71117 .60051 L p .707 .577 .707 r
F P
0 g
s
.77382 .60579 m .77407 .64268 L .74289 .64086 L p .707 .577 .707 r
F P
0 g
s
.74289 .64086 m .74265 .60398 L .77382 .60579 L p .707 .577 .707 r
F P
0 g
s
.29382 .60382 m .29407 .64071 L .30666 .64896 L p .707 .577 .707 r
F P
0 g
s
.8025 .65709 m .80387 .67435 L .77638 .66905 L p .707 .577 .707 r
F P
0 g
s
.77638 .66905 m .775 .65179 L .8025 .65709 L p .707 .577 .707 r
F P
0 g
s
.6829 .66165 m .68428 .67891 L .66042 .68971 L p .707 .577 .707 r
F P
0 g
s
.47347 .68213 m .47484 .69939 L .49099 .68632 L p .707 .577 .707 r
F P
0 g
s
.49099 .68632 m .48962 .66906 L .47347 .68213 L p .707 .577 .707 r
F P
0 g
s
.29444 .58298 m .2966 .52623 L .29365 .52048 L p .707 .577 .707 r
F P
0 g
s
.71082 .60499 m .71106 .64188 L .68168 .64563 L p .707 .577 .707 r
F P
0 g
s
.30887 .68842 m .31024 .70568 L .3314 .71475 L p .707 .577 .707 r
F P
0 g
s
.71106 .64188 m .71082 .60499 L .74265 .60398 L p .707 .577 .707 r
F P
0 g
s
.48774 .60629 m .48798 .64318 L .49506 .6343 L p .707 .577 .707 r
F P
0 g
s
.49506 .6343 m .49482 .59741 L .48774 .60629 L p .707 .577 .707 r
F P
0 g
s
.74265 .60398 m .74289 .64086 L .71106 .64188 L p .707 .577 .707 r
F P
0 g
s
.68428 .67891 m .6829 .66165 L .71213 .65419 L p .707 .577 .707 r
F P
0 g
s
.29365 .52048 m .29149 .57723 L .29444 .58298 L p .707 .577 .707 r
F P
0 g
s
.775 .65179 m .77638 .66905 L .74524 .66806 L p .707 .577 .707 r
F P
0 g
s
.74524 .66806 m .74387 .65079 L .775 .65179 L p .707 .577 .707 r
F P
0 g
s
.31024 .70568 m .30887 .68842 L .29612 .67645 L p .707 .577 .707 r
F P
0 g
s
.29407 .64071 m .29382 .60382 L .29092 .59481 L p .707 .577 .707 r
F P
0 g
s
.71213 .65419 m .7135 .67145 L .68428 .67891 L p .707 .577 .707 r
F P
0 g
s
.7135 .67145 m .71213 .65419 L .74387 .65079 L p .707 .577 .707 r
F P
0 g
s
.49743 .53033 m .49527 .58707 L .49232 .58133 L p .707 .577 .707 r
F P
0 g
s
.49232 .58133 m .49448 .52458 L .49743 .53033 L p .707 .577 .707 r
F P
0 g
s
.74387 .65079 m .74524 .66806 L .7135 .67145 L p .707 .577 .707 r
F P
0 g
s
.29612 .67645 m .29749 .69371 L .31024 .70568 L p .707 .577 .707 r
F P
0 g
s
.48962 .66906 m .49099 .68632 L .49786 .67226 L p .707 .577 .707 r
F P
0 g
s
.49786 .67226 m .49648 .655 L .48962 .66906 L p .707 .577 .707 r
F P
0 g
s
.29092 .59481 m .29117 .6317 L .29407 .64071 L p .707 .577 .707 r
F P
0 g
s
.29149 .57723 m .29365 .52048 L .30067 .51522 L p .707 .577 .707 r
F P
0 g
s
.49482 .59741 m .49506 .6343 L .49216 .62529 L p .707 .577 .707 r
F P
0 g
s
.49216 .62529 m .49192 .5884 L .49482 .59741 L p .707 .577 .707 r
F P
0 g
s
.29749 .69371 m .29612 .67645 L .29302 .66277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30067 .51522 m .29851 .57197 L .29149 .57723 L p .707 .577 .707 r
F P
0 g
s
.29117 .6317 m .29092 .59481 L .298 .58593 L p .707 .577 .707 r
F P
0 g
s
.29302 .66277 m .2944 .68003 L .29749 .69371 L p .707 .577 .707 r
F P
0 g
s
.49448 .52458 m .49232 .58133 L .47968 .57567 L p .707 .577 .707 r
F P
0 g
s
.47968 .57567 m .48184 .51892 L .49448 .52458 L p .707 .577 .707 r
F P
0 g
s
.49648 .655 m .49786 .67226 L .49476 .65857 L p .707 .577 .707 r
F P
0 g
s
.49476 .65857 m .49339 .64131 L .49648 .655 L p .707 .577 .707 r
F P
0 g
s
.298 .58593 m .29825 .62281 L .29117 .6317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29851 .57197 m .30067 .51522 L .31698 .51096 L p .707 .577 .707 r
F P
0 g
s
.49192 .5884 m .49216 .62529 L .47957 .61703 L p .707 .577 .707 r
F P
0 g
s
.47957 .61703 m .47933 .58015 L .49192 .5884 L p .707 .577 .707 r
F P
0 g
s
.2944 .68003 m .29302 .66277 L .29989 .6487 L p .707 .577 .707 r
F P
0 g
s
.31698 .51096 m .31482 .56771 L .29851 .57197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29825 .62281 m .298 .58593 L .31437 .57804 L p .707 .577 .707 r
F P
0 g
s
.29989 .6487 m .30126 .66596 L .2944 .68003 L p .707 .577 .707 r
F P
0 g
s
.48184 .51892 m .47968 .57567 L .4586 .57064 L p .707 .577 .707 r
F P
0 g
s
.4586 .57064 m .46076 .51389 L .48184 .51892 L p .707 .577 .707 r
F P
0 g
s
.49339 .64131 m .49476 .65857 L .48201 .64661 L p .707 .577 .707 r
F P
0 g
s
.48201 .64661 m .48064 .62935 L .49339 .64131 L p .707 .577 .707 r
F P
0 g
s
.31437 .57804 m .31462 .61493 L .29825 .62281 L p .707 .577 .707 r
F P
0 g
s
.31482 .56771 m .31698 .51096 L .34098 .50811 L p .707 .577 .707 r
F P
0 g
s
.47933 .58015 m .47957 .61703 L .45851 .61034 L p .707 .577 .707 r
F P
0 g
s
.45851 .61034 m .45827 .57345 L .47933 .58015 L p .707 .577 .707 r
F P
0 g
s
.30126 .66596 m .29989 .6487 L .31604 .63563 L p .707 .577 .707 r
F P
0 g
s
.34098 .50811 m .33882 .56486 L .31482 .56771 L p .707 .577 .707 r
F P
0 g
s
.31462 .61493 m .31437 .57804 L .33842 .57193 L p .707 .577 .707 r
F P
0 g
s
.46076 .51389 m .4586 .57064 L .43113 .56674 L p .707 .577 .707 r
F P
0 g
s
.43113 .56674 m .43329 .50999 L .46076 .51389 L p .707 .577 .707 r
F P
0 g
s
.31604 .63563 m .31741 .65289 L .30126 .66596 L p .707 .577 .707 r
F P
0 g
s
.48064 .62935 m .48201 .64661 L .46086 .63753 L p .707 .577 .707 r
F P
0 g
s
.46086 .63753 m .45949 .62027 L .48064 .62935 L p .707 .577 .707 r
F P
0 g
s
.33882 .56486 m .34098 .50811 L .37032 .50695 L p .707 .577 .707 r
F P
0 g
s
.33842 .57193 m .33867 .60881 L .31462 .61493 L p .707 .577 .707 r
F P
0 g
s
.45827 .57345 m .45851 .61034 L .43106 .60586 L p .707 .577 .707 r
F P
0 g
s
.43106 .60586 m .43081 .56898 L .45827 .57345 L p .707 .577 .707 r
F P
0 g
s
.43329 .50999 m .43113 .56674 L .39997 .56435 L p .707 .577 .707 r
F P
0 g
s
.39997 .56435 m .40213 .5076 L .43329 .50999 L p .707 .577 .707 r
F P
0 g
s
.37032 .50695 m .36816 .5637 L .33882 .56486 L p .707 .577 .707 r
F P
0 g
s
.33867 .60881 m .33842 .57193 L .3678 .56818 L p .707 .577 .707 r
F P
0 g
s
.31741 .65289 m .31604 .63563 L .33989 .62484 L p .707 .577 .707 r
F P
0 g
s
.36816 .5637 m .37032 .50695 L .40213 .5076 L p .707 .577 .707 r
F P
0 g
s
.40213 .5076 m .39997 .56435 L .36816 .5637 L p .707 .577 .707 r
F P
0 g
s
.43081 .56898 m .43106 .60586 L .39988 .60405 L p .707 .577 .707 r
F P
0 g
s
.39988 .60405 m .39964 .56716 L .43081 .56898 L p .707 .577 .707 r
F P
0 g
s
.45949 .62027 m .46086 .63753 L .43337 .63224 L p .707 .577 .707 r
F P
0 g
s
.43337 .63224 m .43199 .61498 L .45949 .62027 L p .707 .577 .707 r
F P
0 g
s
.33989 .62484 m .34127 .6421 L .31741 .65289 L p .707 .577 .707 r
F P
0 g
s
.3678 .56818 m .36805 .60506 L .33867 .60881 L p .707 .577 .707 r
F P
0 g
s
.36805 .60506 m .3678 .56818 L .39964 .56716 L p .707 .577 .707 r
F P
0 g
s
.39964 .56716 m .39988 .60405 L .36805 .60506 L p .707 .577 .707 r
F P
0 g
s
.34127 .6421 m .33989 .62484 L .36912 .61738 L p .707 .577 .707 r
F P
0 g
s
.43199 .61498 m .43337 .63224 L .40223 .63124 L p .707 .577 .707 r
F P
0 g
s
.40223 .63124 m .40085 .61398 L .43199 .61498 L p .707 .577 .707 r
F P
0 g
s
.36912 .61738 m .37049 .63464 L .34127 .6421 L p .707 .577 .707 r
F P
0 g
s
.37049 .63464 m .36912 .61738 L .40085 .61398 L p .707 .577 .707 r
F P
0 g
s
.40085 .61398 m .40223 .63124 L .37049 .63464 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008=ooaD008Eo
o`00OGoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF2@00O7oo001gOol60008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol007=oo`@0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0075oo`00Kgoo10001UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000KGoo001]Ool20000
0eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH3001ZOol006]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Qoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00P00IWoo001XOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06=oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Aoo`00GWoo6@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P00I7oo001HOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol005Eoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH6000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000I7oo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=o
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20007OolI0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008003Aoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`00<Goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002ioo`00DWoo00<005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF
00000UYF1`001eYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001BOol00`00FUH000030005FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000080003FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059o
o`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF000000020002FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP000080009JEP@000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00E7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP`00003FUH005YF00IJEPP00003FUH0000000H000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP0009JEP03
001JEUYF00AJEPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0015YF00<005YFFUH01EYF2@0015YF
00@005YFFUIJEPP00003FUH0000000<000AJEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000AJ
EP04001JEUYFFUH90002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60004FUH0
0`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00
FUH00`001EYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPT00003FUH005YF
009JEP8002ioo`00DWoo00<005YF000015YF100027oo00@005YFFUH000AJEPl000QJEP<00004FUH0
05YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUH000050002FUH2000^Ool0059oo`03001JEP00009JEP800003FUH0000000<000Io
o`03001JEP0000D000AJEP03001JEUYF00IJEP03001JEP0000<00007FUH00000001JEP00FUH00P00
0UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP0000000P00;Woo001BOol00`00FUH000030005FUH00`00FUH0000700000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP02FUH40004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1P00;Woo
001BOol00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00;Woo
000gOolM0003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000_
Ool0035oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001J
EUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH300000eYF
001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEP000006FUH00`00FUIJEP04FUH;
0003FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH010001EYF1P000eYF00<005YFFUH01UYF
00<005YF00000`0015YF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000IJEPD000QJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0
0005FUH005YFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH00UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000HOol4
00000eYF001JEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000AJEP00FUH000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YF0000
0`008Woo10000eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP04001JEP000003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP<0019ooa40
00Aoo`H000=JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1@0000=JEP00FUH01EYF0`000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUH005YF001JEP020003FUH50007Ool60004FUH00`00FUIJEP06
FUH01000FUIJEUYF1@000UYF00@005YFFUH0009JEP8002ioo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80009JEP03
001JEUYF00=JEPP000AJEP03001JEUYF009JEP`000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH01000FUIJEUYF1`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF1000;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF
00<005YFFUH00eYF00D005YFFUIJEP00009JEPX000IJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001J
EUYF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF008000=JEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=J
EP<00003FUH005YF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP80
0004FUH00000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH<0003FUH80004FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF008000EJEP03001JEUYF009JEP8000IJEPH0
00=JEP03001JEUYF00EJEPD000EJEP04001JEP00000_Ool002]oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF0080
009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH40006FUH00`00FUH000020008FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP09FUH00`00FUH00004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200001EYF001JEUYF0000;goo
000[Ool00`00FUH00004FUH01000FUIJEUYF6@0015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000002FUH00`00Oomoo`0]Ool002]oo`03001JEP00009JEPL000MJEP03001J
EUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00005FUH00`00FUIJEP020002FUH00`00
FUIJEP03FUH50005FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YF000000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`04001J
EUYF000^Ool002]oo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00L000=JEP03001JEUYF0080009JEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00EJEP8000AJEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030006Ool3000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH20002
FUH40002FUH20002FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP03FUH20006FUH30008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YFFUH0009JEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000]oo`8002io
o`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEPD00003FUH000000080009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEP0000<00003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH30002FUH00`00FUIJEP04FUHJ000@Ool2000^
Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH01000FUIJEUYF2@001EYF00@005YFFUIJEPL000EJEP03001JEUYF009J
EP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH01@00FUIJEUYF000097oo00@005YF000002eoo`00;Goo0P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF2P0025YF00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF008000AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo029oo`04001JEUYF000]Ool002moo`@000=JEP03001JEUYF00EJEPP000AJ
EP03001JEUYF009JEPP00004FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8002=oo`80009J
EP03001oogoo02]oo`00<goo2`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P008Woo00D005YF001JEP0002ioo`00<Woo10000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP04001JEUYF
FUH20009Ool3000EOol01000FUIJEUYF0P00;Woo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0004FUH00`00FUIJEP02FUH6
000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000BOol20004FUH00`00Oomo
o`0]Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00006Ool005YFFUH005YF2@001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH005YF009JEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000@Ool200000eYF001J
EP03FUH00`00Oomoo`0]Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00D000AJEP04001JEUYF
FUH20008Ool5000>Ool20003FUH01@00FUIJEUYF0000<7oo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH01P0000=JEP00FUH00UYF0P002Goo0`002goo10001EYF00@005YF0000035oo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF000015YF1P000UYF0P004goo10000UYF00<005YFFUH015YF0P00<goo000[
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUH00006000<Ool70006FUH00`00FUIJEP03
FUH2000dOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00=JEPl000AJEP03001JEUYF
00IJEP04001JEUYFFUH2000fOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>7oo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH60008OolG0004FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH=000;FUH90008
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH700000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH3000jOol002]oo`03001JEP0000AJEP03001JEP0000<000Qoo`H000AJ
EP03001JEUYF00IJEP04001JEUYFFUH500001Woo00000000FUH0009JEP80009JEP03001JEUYF00AJ
EP03001JEUYF00=JEP/000]JEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@003eoo`00:goo00<005YF00000eYF10001goo100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF0P000UYF00<005YFFUH015YF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00@Goo000[Ool01000FUH005YF0P0015YF1`001EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEP<000=J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP800003Ool0000000h004Qo
o`00:goo00H005YF000005YF0005FUH200000eYF001JEP07FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000AJEP000000009JEP04001JEUYFFUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40005FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000Egoo000[Ool20003FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF2P0015YF2@0015YF00<005YFFUH00UYF1@000UYF00@005YF000000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EUYFFUH00004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo000[Ool20003
FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
15YF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00:goo0P000eYF0`001eYF00<005YF00000P00
1eYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00H005YFFUH005YF
0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000[Ool20002FUH200000eYF001JEP05FUH300000eYF001JEP07FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH2000015YF001JEUYF0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`03001JEP00
00AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH000000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP04001JEP000006FUH00`00FUIJEP06
FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02eoo`8000AJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEP00001oo`030004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP070004FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUH00002FUH400000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH600000eYF001JEP02FUH2001EOol0
02aoo`03001JEP00008000Aoo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP00
00<000=JEP8005Eoo`00;7oo00<005YF00002Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P002Woo0`000Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH00UYF0`00
00=JEP000000EGoo000/Ool2000>OolH000@Ool00`00FUH00004Ool20007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF1@00
1UYF00<005YFFUH00eYF1@00EGoo000/Ool2000eOol200000eYF001oo`05Ool30004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0
00001EYF10000UYF00<005YFFUH00eYF1@00EGoo000/Ool2000cOol200000eYF0000000:Ool30000
0eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
00000eYF001JEP06FUH00`00FUH000030004FUH01@00FUH005YF0000EGoo000/Ool3000aOol01000
FUIJEUYF0P003Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01P0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP8005Eoo`00;7oo0`00
;goo0P0015YF00<007ooOol04goo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF200000=JEP00
000010000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001oogoo05Aoo`00
;7oo0P0000=JEP00Ool0:goo0P0000=JEP00FUH00eYF00<007ooOol07Woo6`0025YF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001FOol002eoo`03001JEUYF008002Qo
o`8000=JEP05001JEUYFFUH0000ZOol20004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001oo`1DOol002eoo`05001J
EUYF001JEP03000ROol30005FUH01000FUH00000:goo0P000eYF00D005YFFUIJEP0000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=oo`8005Eoo`00
;Woo00<005YF000015YF0`006goo100000=JEP00FUH01EYF0P00;7oo00D005YFFUH005YF00@00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40005
Ool2001EOol002moo`03001JEP0000AJEP03001JEP0000<0011oo`L000EJEP03001JEUYF00AJEP03
001oogoo02]oo`03001JEUYF008000Aoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Uoo`8005Eoo`00<7oo0P0015YF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
00@005YFFUIJEP8002ioo`04001JEUYF000:Ool90004FUH00`00FUIJEP02FUH9000?Ool01000FUH0
0000E7oo000aOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000<7oo00<005YF000057oo2@0067oo00@005YFFUH005Aoo`00<goo0`0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000<goo0P00=7oo0P00
0UYF00<007ooOol0DWoo000fOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
000gOol00`00Oomoo`0aOol2000015YF001JEP00EGoo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH7000kOol2000`Ool20004FUH2001EOol003eoo`l0049oo`04001JEP00000/Ool20000
0eYF001JEP03FUH00`00Oomoo`1DOol008ioo`80009JEP03001oogoo02Moo`8000=JEP03001JEUYF
009JEP03001oogoo05Aoo`00Sgoo00<005YFFUH00`0097oo0`001EYF00<005YFFUH00P00Egoo002?
Ool01000FUIJEP000UYF0P007goo0`0000=JEP00FUH01EYF0`00FGoo002@Ool00`00FUH00004FUH5
000GOol30004FUH00`00FUIJEP03FUH2001KOol0095oo`8000EJEP04001JEUYFFUH80009Ool60007
FUH01000FUIJEUYF0P00GGoo002BOol00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@00
15YF00<005YFFUH01UYF00@005YF000005moo`00Tgoo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`00HGoo002EOol200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP04001TOol009Moo`D000AJEP03001JEUYF00IJEP03001J
EUYF009JEPL006Qoo`00W7oo4P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60003 .74268 m .59787 .68883 L .56671 .68741 L p .707 .577 .707 r
F P
0 g
s
.59787 .68883 m .60003 .74268 L .63184 .74051 L p .707 .577 .707 r
F P
0 g
s
.63184 .74051 m .62968 .68666 L .59787 .68883 L p .707 .577 .707 r
F P
0 g
s
.62968 .68666 m .63184 .74051 L .66118 .73497 L p .707 .577 .707 r
F P
0 g
s
.66118 .73497 m .65902 .68112 L .62968 .68666 L p .707 .577 .707 r
F P
0 g
s
.56887 .74126 m .56671 .68741 L .53924 .68253 L p .707 .577 .707 r
F P
0 g
s
.56671 .68741 m .56887 .74126 L .60003 .74268 L p .707 .577 .707 r
F P
0 g
s
.65902 .68112 m .66118 .73497 L .68518 .72659 L p .707 .577 .707 r
F P
0 g
s
.68518 .72659 m .68302 .67274 L .65902 .68112 L p .707 .577 .707 r
F P
0 g
s
.60011 .78226 m .60036 .74505 L .56919 .74307 L p .707 .577 .707 r
F P
0 g
s
.60036 .74505 m .60011 .78226 L .63195 .78173 L p .707 .577 .707 r
F P
0 g
s
.63195 .78173 m .63219 .74451 L .60036 .74505 L p .707 .577 .707 r
F P
0 g
s
.5414 .73639 m .53924 .68253 L .51816 .67469 L p .707 .577 .707 r
F P
0 g
s
.53924 .68253 m .5414 .73639 L .56887 .74126 L p .707 .577 .707 r
F P
0 g
s
.63219 .74451 m .63195 .78173 L .66133 .77872 L p .707 .577 .707 r
F P
0 g
s
.66133 .77872 m .66157 .74151 L .63219 .74451 L p .707 .577 .707 r
F P
0 g
s
.56894 .78028 m .56919 .74307 L .54173 .73876 L p .707 .577 .707 r
F P
0 g
s
.56919 .74307 m .56894 .78028 L .60011 .78226 L p .707 .577 .707 r
F P
0 g
s
.59777 .8126 m .59914 .7935 L .568 .79065 L p .707 .577 .707 r
F P
0 g
s
.59914 .7935 m .59777 .8126 L .6295 .81458 L p .707 .577 .707 r
F P
0 g
s
.6295 .81458 m .63088 .79548 L .59914 .7935 L p .707 .577 .707 r
F P
0 g
s
.68302 .67274 m .68518 .72659 L .70149 .7162 L p .707 .577 .707 r
F P
0 g
s
.70149 .7162 m .69933 .66235 L .68302 .67274 L p .707 .577 .707 r
F P
0 g
s
.568 .79065 m .56663 .80975 L .59777 .8126 L p .707 .577 .707 r
F P
0 g
s
.63088 .79548 m .6295 .81458 L .65873 .81549 L p .707 .577 .707 r
F P
0 g
s
.65873 .81549 m .6601 .79639 L .63088 .79548 L p .707 .577 .707 r
F P
0 g
s
.66157 .74151 m .66133 .77872 L .68538 .77354 L p .707 .577 .707 r
F P
0 g
s
.68538 .77354 m .68562 .73633 L .66157 .74151 L p .707 .577 .707 r
F P
0 g
s
.54173 .73876 m .54148 .77597 L .56894 .78028 L p .707 .577 .707 r
F P
0 g
s
.56663 .80975 m .568 .79065 L .54051 .78721 L p .707 .577 .707 r
F P
0 g
s
.54051 .78721 m .53914 .80631 L .56663 .80975 L p .707 .577 .707 r
F P
0 g
s
.51816 .67469 m .52032 .72854 L .5414 .73639 L p .707 .577 .707 r
F P
0 g
s
.54148 .77597 m .54173 .73876 L .52067 .73254 L p .707 .577 .707 r
F P
0 g
s
.52032 .72854 m .51816 .67469 L .50552 .66464 L p .707 .577 .707 r
F P
0 g
s
.6601 .79639 m .65873 .81549 L .68259 .81525 L p .707 .577 .707 r
F P
0 g
s
.68259 .81525 m .68396 .79615 L .6601 .79639 L p .707 .577 .707 r
F P
0 g
s
.52067 .73254 m .52043 .76976 L .54148 .77597 L p .707 .577 .707 r
F P
0 g
s
.53914 .80631 m .54051 .78721 L .51936 .78351 L p .707 .577 .707 r
F P
0 g
s
.51936 .78351 m .51798 .80261 L .53914 .80631 L p .707 .577 .707 r
F P
0 g
s
.68562 .73633 m .68538 .77354 L .70175 .76669 L p .707 .577 .707 r
F P
0 g
s
.70175 .76669 m .70199 .72948 L .68562 .73633 L p .707 .577 .707 r
F P
0 g
s
.69933 .66235 m .70149 .7162 L .70851 .70481 L p .707 .577 .707 r
F P
0 g
s
.70851 .70481 m .70635 .65096 L .69933 .66235 L p .707 .577 .707 r
F P
0 g
s
.50552 .66464 m .50768 .71849 L .52032 .72854 L p .707 .577 .707 r
F P
0 g
s
.52043 .76976 m .52067 .73254 L .50808 .72503 L p .707 .577 .707 r
F P
0 g
s
.68396 .79615 m .68259 .81525 L .69874 .81388 L p .707 .577 .707 r
F P
0 g
s
.69874 .81388 m .70011 .79478 L .68396 .79615 L p .707 .577 .707 r
F P
0 g
s
.50768 .71849 m .50552 .66464 L .50257 .65337 L p .707 .577 .707 r
F P
0 g
s
.50808 .72503 m .50783 .76224 L .52043 .76976 L p .707 .577 .707 r
F P
0 g
s
.51798 .80261 m .51936 .78351 L .50661 .77992 L p .707 .577 .707 r
F P
0 g
s
.50661 .77992 m .50523 .79902 L .51798 .80261 L p .707 .577 .707 r
F P
0 g
s
.70199 .72948 m .70175 .76669 L .70883 .75885 L p .707 .577 .707 r
F P
0 g
s
.70883 .75885 m .70907 .72164 L .70199 .72948 L p .707 .577 .707 r
F P
0 g
s
.4885 .82526 m .48534 .32556 L .44133 .32299 L p .707 .577 .707 r
F P
0 g
s
.50257 .65337 m .50473 .70722 L .50768 .71849 L p .707 .577 .707 r
F P
0 g
s
.50783 .76224 m .50808 .72503 L .50518 .71696 L p .707 .577 .707 r
F P
0 g
s
.50473 .70722 m .50257 .65337 L .5096 .64199 L p .707 .577 .707 r
F P
0 g
s
.50518 .71696 m .50493 .75417 L .50783 .76224 L p .707 .577 .707 r
F P
0 g
s
.50523 .79902 m .50661 .77992 L .50351 .77678 L p .707 .577 .707 r
F P
0 g
s
.50351 .77678 m .50214 .79588 L .50523 .79902 L p .707 .577 .707 r
F P
0 g
s
.5096 .64199 m .51175 .69584 L .50473 .70722 L p .707 .577 .707 r
F P
0 g
s
.50493 .75417 m .50518 .71696 L .51226 .70912 L p .707 .577 .707 r
F P
0 g
s
.51175 .69584 m .5096 .64199 L .52591 .63159 L p .707 .577 .707 r
F P
0 g
s
.51226 .70912 m .51202 .74633 L .50493 .75417 L p .707 .577 .707 r
F P
0 g
s
.50214 .79588 m .50351 .77678 L .51038 .77441 L p .707 .577 .707 r
F P
0 g
s
.51038 .77441 m .509 .79351 L .50214 .79588 L p .707 .577 .707 r
F P
0 g
s
.52591 .63159 m .52806 .68545 L .51175 .69584 L p .707 .577 .707 r
F P
0 g
s
.51202 .74633 m .51226 .70912 L .52863 .70227 L p .707 .577 .707 r
F P
0 g
s
.52863 .70227 m .52838 .73948 L .51202 .74633 L p .707 .577 .707 r
F P
0 g
s
.509 .79351 m .51038 .77441 L .52653 .77304 L p .707 .577 .707 r
F P
0 g
s
.52653 .77304 m .52515 .79214 L .509 .79351 L p .707 .577 .707 r
F P
0 g
s
.52515 .79214 m .52653 .77304 L .55038 .7728 L p .707 .577 .707 r
F P
0 g
s
.55038 .7728 m .54901 .7919 L .52515 .79214 L p .707 .577 .707 r
F P
0 g
s
.48534 .32556 m .4885 .82526 L .53344 .82384 L p .707 .577 .707 r
F P
0 g
s
.52806 .68545 m .52591 .63159 L .5499 .62322 L p .707 .577 .707 r
F P
0 g
s
.5499 .62322 m .55206 .67707 L .52806 .68545 L p .707 .577 .707 r
F P
0 g
s
.52838 .73948 m .52863 .70227 L .55268 .69709 L p .707 .577 .707 r
F P
0 g
s
.55268 .69709 m .55244 .7343 L .52838 .73948 L p .707 .577 .707 r
F P
0 g
s
.53344 .82384 m .53028 .32414 L .48534 .32556 L p .707 .577 .707 r
F P
0 g
s
.70635 .65096 m .70851 .70481 L .70556 .69354 L p .707 .577 .707 r
F P
0 g
s
.70556 .69354 m .7034 .63969 L .70635 .65096 L p .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .5499 .62322 L .55178 .62286 L p .707 .577 .707 r
F P
0 g
s
.55178 .62286 m .57924 .61767 L p .55844 .66314 L .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .55178 .62286 L .55844 .66314 L .707 .577 .707 r
F
.5814 .67153 m .57924 .61767 L .61105 .61551 L p F P
0 g
s
.57924 .61767 m .5814 .67153 L .55206 .67707 L p .707 .577 .707 r
F P
0 g
s
.61105 .61551 m .61321 .66936 L .5814 .67153 L p .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .55268 .69709 L .56291 .69604 L p .707 .577 .707 r
F P
0 g
s
.56291 .69604 m .58206 .69408 L p .56154 .72194 L .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .56291 .69604 L .56154 .72194 L .707 .577 .707 r
F
.58206 .69408 m .58182 .73129 L .55244 .7343 L p F P
0 g
s
.58182 .73129 m .58206 .69408 L .61389 .69354 L p .707 .577 .707 r
F P
0 g
s
.61389 .69354 m .61365 .73076 L .58182 .73129 L p .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .57961 .77371 L .58581 .7741 L p .707 .577 .707 r
F P
0 g
s
.58581 .7741 m .61134 .77569 L p .58405 .78981 L .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .58581 .7741 L .58405 .78981 L .707 .577 .707 r
F
.64221 .61693 m .64437 .67078 L .61321 .66936 L p F P
0 g
s
.61321 .66936 m .61105 .61551 L .64221 .61693 L p .707 .577 .707 r
F P
0 g
s
.64507 .69553 m .64482 .73274 L .61365 .73076 L p .707 .577 .707 r
F P
0 g
s
.61365 .73076 m .61389 .69354 L .64507 .69553 L p .707 .577 .707 r
F P
0 g
s
.64248 .77854 m .64111 .79764 L .61377 .79514 L p .707 .577 .707 r
F P
0 g
s
.61377 .79514 m .60997 .79479 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.61386 .79285 m .64248 .77854 L .61377 .79514 L .707 .577 .707 r
F
.64111 .79764 m .64248 .77854 L .66997 .78198 L p F P
0 g
s
.60997 .79479 m .61134 .77569 L .61453 .77598 L p .707 .577 .707 r
F P
0 g
s
.61453 .77598 m .64248 .77854 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.60997 .79479 m .61453 .77598 L .61386 .79285 L .707 .577 .707 r
F
.64198 .78635 m .63882 .28665 L .63376 .29299 L p F P
0 g
s
.63376 .29299 m .62882 .29916 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.64198 .78635 m .63376 .29299 L .63072 .3693 L .707 .577 .707 r
F
.63199 .79886 m .64198 .78635 L p .63072 .3693 L F P
0 g
s
.62882 .29916 m .62947 .40074 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.62947 .40074 m .63199 .79886 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.61134 .77569 m .60997 .79479 L .57824 .79281 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .63199 .79886 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60572 .31026 m .60743 .58166 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60743 .58166 m .60888 .80996 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .57829 .40525 L .57456 .76058 L .707 .577 .707 r
F
.57176 .31887 m .57295 .50625 L p .57829 .40525 L F P
0 g
s
.57295 .50625 m .57456 .76058 L p .57829 .40525 L .707 .577 .707 r
F P
0 g
s
.54901 .7919 m .55038 .7728 L .57961 .77371 L p .707 .577 .707 r
F P
0 g
s
.57961 .77371 m .57824 .79281 L .54901 .7919 L p .707 .577 .707 r
F P
0 g
s
.57456 .76058 m .57492 .81857 L .58378 .81633 L p .707 .577 .707 r
F P
0 g
s
.58378 .81633 m .60888 .80996 L p .57456 .76058 L .707 .577 .707 r
F P
0 g
s
.53028 .32414 m .53344 .82384 L .57492 .81857 L p .707 .577 .707 r
F P
0 g
s
.57492 .81857 m .57176 .31887 L .53028 .32414 L p .707 .577 .707 r
F P
0 g
s
.44449 .82269 m .44133 .32299 L .40257 .31668 L p .707 .577 .707 r
F P
0 g
s
.44133 .32299 m .44449 .82269 L .4885 .82526 L p .707 .577 .707 r
F P
0 g
s
.70011 .79478 m .69874 .81388 L .7056 .81151 L p .707 .577 .707 r
F P
0 g
s
.7056 .81151 m .70697 .79241 L .70011 .79478 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .60572 .31026 L .57176 .31887 L p .707 .577 .707 r
F P
0 g
s
.70907 .72164 m .70883 .75885 L .70593 .75078 L p .707 .577 .707 r
F P
0 g
s
.70593 .75078 m .70618 .71356 L .70907 .72164 L p .707 .577 .707 r
F P
0 g
s
.7034 .63969 m .70556 .69354 L .69292 .6835 L p .707 .577 .707 r
F P
0 g
s
.69292 .6835 m .69077 .62964 L .7034 .63969 L p .707 .577 .707 r
F P
0 g
s
.40573 .81638 m .40257 .31668 L .37284 .30724 L p .707 .577 .707 r
F P
0 g
s
.40257 .31668 m .40573 .81638 L .44449 .82269 L p .707 .577 .707 r
F P
0 g
s
.70697 .79241 m .7056 .81151 L .70251 .80837 L p .707 .577 .707 r
F P
0 g
s
.70251 .80837 m .70388 .78927 L .70697 .79241 L p .707 .577 .707 r
F P
0 g
s
.25702 .70586 m .25486 .65201 L .2237 .65059 L p .707 .577 .707 r
F P
0 g
s
.25486 .65201 m .25702 .70586 L .28883 .7037 L p .707 .577 .707 r
F P
0 g
s
.28883 .7037 m .28667 .64985 L .25486 .65201 L p .707 .577 .707 r
F P
0 g
s
.28667 .64985 m .28883 .7037 L .31817 .69815 L p .707 .577 .707 r
F P
0 g
s
.31817 .69815 m .31601 .6443 L .28667 .64985 L p .707 .577 .707 r
F P
0 g
s
.63199 .79886 m .62882 .29916 L .60572 .31026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22586 .70444 m .2237 .65059 L .19623 .64572 L p .707 .577 .707 r
F P
0 g
s
.2237 .65059 m .22586 .70444 L .25702 .70586 L p .707 .577 .707 r
F P
0 g
s
.69077 .62964 m .69292 .6835 L .67184 .67565 L p .707 .577 .707 r
F P
0 g
s
.67184 .67565 m .66968 .6218 L .69077 .62964 L p .707 .577 .707 r
F P
0 g
s
.70618 .71356 m .70593 .75078 L .69334 .74326 L p .707 .577 .707 r
F P
0 g
s
.69334 .74326 m .69358 .70605 L .70618 .71356 L p .707 .577 .707 r
F P
0 g
s
.31601 .6443 m .31817 .69815 L .34217 .68978 L p .707 .577 .707 r
F P
0 g
s
.34217 .68978 m .34001 .63593 L .31601 .6443 L p .707 .577 .707 r
F P
0 g
s
.376 .80694 m .37284 .30724 L .35506 .29561 L p .707 .577 .707 r
F P
0 g
s
.37284 .30724 m .376 .80694 L .40573 .81638 L p .707 .577 .707 r
F P
0 g
s
.2571 .74545 m .25735 .70824 L .22618 .70625 L p .707 .577 .707 r
F P
0 g
s
.25735 .70824 m .2571 .74545 L .28894 .74491 L p .707 .577 .707 r
F P
0 g
s
.28894 .74491 m .28918 .7077 L .25735 .70824 L p .707 .577 .707 r
F P
0 g
s
.19839 .69957 m .19623 .64572 L .17515 .63788 L p .707 .577 .707 r
F P
0 g
s
.19623 .64572 m .19839 .69957 L .22586 .70444 L p .707 .577 .707 r
F P
0 g
s
.28918 .7077 m .28894 .74491 L .31832 .7419 L p .707 .577 .707 r
F P
0 g
s
.31832 .7419 m .31856 .70469 L .28918 .7077 L p .707 .577 .707 r
F P
0 g
s
.70388 .78927 m .70251 .80837 L .68976 .80478 L p .707 .577 .707 r
F P
0 g
s
.68976 .80478 m .69113 .78568 L .70388 .78927 L p .707 .577 .707 r
F P
0 g
s
.22593 .74347 m .22618 .70625 L .19872 .70194 L p .707 .577 .707 r
F P
0 g
s
.22618 .70625 m .22593 .74347 L .2571 .74545 L p .707 .577 .707 r
F P
0 g
s
.25476 .77579 m .25613 .75668 L .225 .75383 L p .707 .577 .707 r
F P
0 g
s
.25613 .75668 m .25476 .77579 L .2865 .77777 L p .707 .577 .707 r
F P
0 g
s
.2865 .77777 m .28787 .75866 L .25613 .75668 L p .707 .577 .707 r
F P
0 g
s
.34001 .63593 m .34217 .68978 L .35848 .67939 L p .707 .577 .707 r
F P
0 g
s
.35848 .67939 m .35632 .62553 L .34001 .63593 L p .707 .577 .707 r
F P
0 g
s
.225 .75383 m .22362 .77294 L .25476 .77579 L p .707 .577 .707 r
F P
0 g
s
.66968 .6218 m .67184 .67565 L .64437 .67078 L p .707 .577 .707 r
F P
0 g
s
.64437 .67078 m .64221 .61693 L .66968 .6218 L p .707 .577 .707 r
F P
0 g
s
.28787 .75866 m .2865 .77777 L .31572 .77868 L p .707 .577 .707 r
F P
0 g
s
.31572 .77868 m .31709 .75958 L .28787 .75866 L p .707 .577 .707 r
F P
0 g
s
.31856 .70469 m .31832 .7419 L .34237 .73672 L p .707 .577 .707 r
F P
0 g
s
.34237 .73672 m .34262 .69951 L .31856 .70469 L p .707 .577 .707 r
F P
0 g
s
.19872 .70194 m .19847 .73916 L .22593 .74347 L p .707 .577 .707 r
F P
0 g
s
.22362 .77294 m .225 .75383 L .1975 .75039 L p .707 .577 .707 r
F P
0 g
s
.1975 .75039 m .19613 .76949 L .22362 .77294 L p .707 .577 .707 r
F P
0 g
s
.69358 .70605 m .69334 .74326 L .67228 .73705 L p .707 .577 .707 r
F P
0 g
s
.67228 .73705 m .67253 .69984 L .69358 .70605 L p .707 .577 .707 r
F P
0 g
s
.17515 .63788 m .17731 .69173 L .19839 .69957 L p .707 .577 .707 r
F P
0 g
s
.19847 .73916 m .19872 .70194 L .17766 .69573 L p .707 .577 .707 r
F P
0 g
s
.17731 .69173 m .17515 .63788 L .16251 .62783 L p .707 .577 .707 r
F P
0 g
s
.31709 .75958 m .31572 .77868 L .33958 .77844 L p .707 .577 .707 r
F P
0 g
s
.33958 .77844 m .34095 .75933 L .31709 .75958 L p .707 .577 .707 r
F P
0 g
s
.17766 .69573 m .17742 .73294 L .19847 .73916 L p .707 .577 .707 r
F P
0 g
s
.19613 .76949 m .1975 .75039 L .17635 .74669 L p .707 .577 .707 r
F P
0 g
s
.17635 .74669 m .17497 .7658 L .19613 .76949 L p .707 .577 .707 r
F P
0 g
s
.69113 .78568 m .68976 .80478 L .6686 .80108 L p .707 .577 .707 r
F P
0 g
s
.6686 .80108 m .66997 .78198 L .69113 .78568 L p .707 .577 .707 r
F P
0 g
s
.34262 .69951 m .34237 .73672 L .35874 .72988 L p .707 .577 .707 r
F P
0 g
s
.35874 .72988 m .35898 .69266 L .34262 .69951 L p .707 .577 .707 r
F P
0 g
s
.35632 .62553 m .35848 .67939 L .3655 .668 L p .707 .577 .707 r
F P
0 g
s
.3655 .668 m .36334 .61415 L .35632 .62553 L p .707 .577 .707 r
F P
0 g
s
.3571 .75796 m .35573 .77706 L .36259 .77469 L p .707 .577 .707 r
F P
0 g
s
.36259 .77469 m .36396 .75559 L .3571 .75796 L p .707 .577 .707 r
F P
0 g
s
.36039 .60288 m .36255 .65673 L .35892 .65385 L p .707 .577 .707 r
F P
0 g
s
.35892 .65385 m .34991 .64668 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.35953 .60647 m .36039 .60288 L .35892 .65385 L .707 .577 .707 r
F
.34991 .64668 m .34776 .59283 L .35959 .60224 L p F P
0 g
s
.35959 .60224 m .36039 .60288 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.34991 .64668 m .35959 .60224 L .35953 .60647 L .707 .577 .707 r
F
.34095 .75933 m .33958 .77844 L .35573 .77706 L p F P
0 g
s
.35573 .77706 m .3571 .75796 L .34095 .75933 L p .707 .577 .707 r
F P
0 g
s
.35898 .69266 m .35874 .72988 L .36582 .72203 L p .707 .577 .707 r
F P
0 g
s
.36582 .72203 m .36606 .68482 L .35898 .69266 L p .707 .577 .707 r
F P
0 g
s
.36317 .67675 m .36292 .71396 L .35928 .71179 L p .707 .577 .707 r
F P
0 g
s
.35928 .71179 m .35033 .70645 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35895 .68651 m .36317 .67675 L .35928 .71179 L .707 .577 .707 r
F
.35033 .70645 m .35057 .66924 L .35878 .67413 L p F P
0 g
s
.35878 .67413 m .36317 .67675 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35033 .70645 m .35878 .67413 L .35895 .68651 L .707 .577 .707 r
F
.34675 .76797 m .34812 .74886 L .36079 .75243 L p F P
0 g
s
.36079 .75243 m .36087 .75246 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.34675 .76797 m .36079 .75243 L .36079 .75254 L .707 .577 .707 r
F
.35786 .73732 m .35751 .68206 L p .35764 .75416 L F P
0 g
s
.35751 .68206 m .35625 .48299 L p .35724 .67636 L .707 .577 .707 r
F P
0 g
s
.35751 .68206 m .35724 .67636 L .35764 .75416 L .707 .577 .707 r
F
.35625 .48299 m .35506 .29561 L p .35602 .46576 L F P
0 g
s
.35625 .48299 m .35602 .46576 L .35764 .75416 L .707 .577 .707 r
F
.35764 .75416 m .35602 .46576 L .35097 .28292 L F
.35506 .29561 m .35371 .29141 L p .35602 .46576 L F P
0 g
s
.35371 .29141 m .35097 .28292 L p .35602 .46576 L .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .34675 .76797 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36087 .75246 m .36082 .75313 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36082 .75313 m .3595 .77156 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35716 .792 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35097 .28292 m .35287 .5826 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35287 .5826 m .35413 .78262 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35716 .792 m .35822 .79531 L p .35764 .75416 L .707 .577 .707 r
F P
0 g
s
.35764 .75416 m .35097 .28292 L .35716 .792 L .707 .577 .707 r
F
.35822 .79531 m .35786 .73732 L p .35764 .75416 L F P
0 g
s
.36334 .61415 m .3655 .668 L .36255 .65673 L p .707 .577 .707 r
F P
0 g
s
.36255 .65673 m .36039 .60288 L .36334 .61415 L p .707 .577 .707 r
F P
0 g
s
.36606 .68482 m .36582 .72203 L .36292 .71396 L p .707 .577 .707 r
F P
0 g
s
.36292 .71396 m .36317 .67675 L .36606 .68482 L p .707 .577 .707 r
F P
0 g
s
.36396 .75559 m .36259 .77469 L .3595 .77156 L p .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .36087 .75246 L .36396 .75559 L p .707 .577 .707 r
F P
0 g
s
.35506 .29561 m .35822 .79531 L .376 .80694 L p .707 .577 .707 r
F P
0 g
s
.67253 .69984 m .67228 .73705 L .64482 .73274 L p .707 .577 .707 r
F P
0 g
s
.64482 .73274 m .64507 .69553 L .67253 .69984 L p .707 .577 .707 r
F P
0 g
s
.16251 .62783 m .16467 .68168 L .17731 .69173 L p .707 .577 .707 r
F P
0 g
s
.17742 .73294 m .17766 .69573 L .16507 .68822 L p .707 .577 .707 r
F P
0 g
s
.16467 .68168 m .16251 .62783 L .15956 .61656 L p .707 .577 .707 r
F P
0 g
s
.16507 .68822 m .16482 .72543 L .17742 .73294 L p .707 .577 .707 r
F P
0 g
s
.17497 .7658 m .17635 .74669 L .1636 .7431 L p .707 .577 .707 r
F P
0 g
s
.1636 .7431 m .16222 .7622 L .17497 .7658 L p .707 .577 .707 r
F P
0 g
s
.66997 .78198 m .6686 .80108 L .64111 .79764 L p .707 .577 .707 r
F P
0 g
s
.63882 .28665 m .64198 .78635 L .63789 .77366 L p .707 .577 .707 r
F P
0 g
s
.63789 .77366 m .63473 .27396 L .63882 .28665 L p .707 .577 .707 r
F P
0 g
s
.15956 .61656 m .16172 .67041 L .16467 .68168 L p .707 .577 .707 r
F P
0 g
s
.16482 .72543 m .16507 .68822 L .16217 .68014 L p .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35097 .28292 L .36097 .27041 L p .707 .577 .707 r
F P
0 g
s
.16172 .67041 m .15956 .61656 L .16659 .60517 L p .707 .577 .707 r
F P
0 g
s
.16217 .68014 m .16193 .71736 L .16482 .72543 L p .707 .577 .707 r
F P
0 g
s
.16222 .7622 m .1636 .7431 L .1605 .73997 L p .707 .577 .707 r
F P
0 g
s
.1605 .73997 m .15913 .75907 L .16222 .7622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16659 .60517 m .16874 .65902 L .16172 .67041 L p .707 .577 .707 r
F P
0 g
s
.63473 .27396 m .63789 .77366 L .62011 .76203 L p .707 .577 .707 r
F P
0 g
s
.62011 .76203 m .61695 .26233 L .63473 .27396 L p .707 .577 .707 r
F P
0 g
s
.16193 .71736 m .16217 .68014 L .16925 .6723 L p .707 .577 .707 r
F P
0 g
s
.16874 .65902 m .16659 .60517 L .1829 .59478 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16925 .6723 m .16901 .70951 L .16193 .71736 L p .707 .577 .707 r
F P
0 g
s
.15913 .75907 m .1605 .73997 L .16737 .7376 L p .707 .577 .707 r
F P
0 g
s
.16737 .7376 m .16599 .7567 L .15913 .75907 L p .707 .577 .707 r
F P
0 g
s
.36413 .77011 m .36097 .27041 L .38407 .25931 L p .707 .577 .707 r
F P
0 g
s
.36097 .27041 m .36413 .77011 L .35413 .78262 L p .707 .577 .707 r
F P
0 g
s
.34776 .59283 m .34991 .64668 L .32883 .63884 L p .707 .577 .707 r
F P
0 g
s
.32883 .63884 m .32667 .58498 L .34776 .59283 L p .707 .577 .707 r
F P
0 g
s
.1829 .59478 m .18505 .64863 L .16874 .65902 L p .707 .577 .707 r
F P
0 g
s
.18505 .64863 m .1829 .59478 L .20689 .5864 L p .707 .577 .707 r
F P
0 g
s
.16901 .70951 m .16925 .6723 L .18562 .66545 L p .707 .577 .707 r
F P
0 g
s
.61695 .26233 m .62011 .76203 L .59039 .7526 L p .707 .577 .707 r
F P
0 g
s
.59039 .7526 m .58722 .2529 L .61695 .26233 L p .707 .577 .707 r
F P
0 g
s
.18562 .66545 m .18537 .70267 L .16901 .70951 L p .707 .577 .707 r
F P
0 g
s
.32667 .58498 m .32883 .63884 L .30136 .63397 L p .707 .577 .707 r
F P
0 g
s
.30136 .63397 m .29921 .58011 L .32667 .58498 L p .707 .577 .707 r
F P
0 g
s
.16599 .7567 m .16737 .7376 L .18352 .73622 L p .707 .577 .707 r
F P
0 g
s
.18352 .73622 m .18214 .75533 L .16599 .7567 L p .707 .577 .707 r
F P
0 g
s
.35057 .66924 m .35033 .70645 L .32927 .70023 L p .707 .577 .707 r
F P
0 g
s
.32927 .70023 m .32952 .66302 L .35057 .66924 L p .707 .577 .707 r
F P
0 g
s
.20905 .64025 m .20689 .5864 L .23623 .58086 L p .707 .577 .707 r
F P
0 g
s
.20689 .5864 m .20905 .64025 L .18505 .64863 L p .707 .577 .707 r
F P
0 g
s
.38407 .25931 m .38724 .75901 L .36413 .77011 L p .707 .577 .707 r
F P
0 g
s
.38724 .75901 m .38407 .25931 L .41803 .2507 L p .707 .577 .707 r
F P
0 g
s
.29921 .58011 m .30136 .63397 L .2702 .63254 L p .707 .577 .707 r
F P
0 g
s
.2702 .63254 m .26804 .57869 L .29921 .58011 L p .707 .577 .707 r
F P
0 g
s
.18537 .70267 m .18562 .66545 L .20967 .66027 L p .707 .577 .707 r
F P
0 g
s
.23839 .63471 m .23623 .58086 L .26804 .57869 L p .707 .577 .707 r
F P
0 g
s
.23623 .58086 m .23839 .63471 L .20905 .64025 L p .707 .577 .707 r
F P
0 g
s
.34812 .74886 m .34675 .76797 L .32559 .76427 L p .707 .577 .707 r
F P
0 g
s
.32559 .76427 m .32696 .74517 L .34812 .74886 L p .707 .577 .707 r
F P
0 g
s
.26804 .57869 m .2702 .63254 L .23839 .63471 L p .707 .577 .707 r
F P
0 g
s
.20967 .66027 m .20943 .69749 L .18537 .70267 L p .707 .577 .707 r
F P
0 g
s
.32952 .66302 m .32927 .70023 L .30181 .69592 L p .707 .577 .707 r
F P
0 g
s
.30181 .69592 m .30206 .65871 L .32952 .66302 L p .707 .577 .707 r
F P
0 g
s
.18214 .75533 m .18352 .73622 L .20737 .73598 L p .707 .577 .707 r
F P
0 g
s
.58722 .2529 m .59039 .7526 L .55162 .74628 L p .707 .577 .707 r
F P
0 g
s
.55162 .74628 m .54846 .24658 L .58722 .2529 L p .707 .577 .707 r
F P
0 g
s
.20737 .73598 m .206 .75508 L .18214 .75533 L p .707 .577 .707 r
F P
0 g
s
.20943 .69749 m .20967 .66027 L .23905 .65727 L p .707 .577 .707 r
F P
0 g
s
.73723 .67761 m .73507 .62376 L .70391 .62234 L p .707 .577 .707 r
F P
0 g
s
.73507 .62376 m .73723 .67761 L .76904 .67545 L p .707 .577 .707 r
F P
0 g
s
.76904 .67545 m .76688 .62159 L .73507 .62376 L p .707 .577 .707 r
F P
0 g
s
.76688 .62159 m .76904 .67545 L .79838 .6699 L p .707 .577 .707 r
F P
0 g
s
.79838 .6699 m .79622 .61605 L .76688 .62159 L p .707 .577 .707 r
F P
0 g
s
.42119 .7504 m .41803 .2507 L .45951 .24543 L p .707 .577 .707 r
F P
0 g
s
.41803 .2507 m .42119 .7504 L .38724 .75901 L p .707 .577 .707 r
F P
0 g
s
.30206 .65871 m .30181 .69592 L .27064 .69394 L p .707 .577 .707 r
F P
0 g
s
.27064 .69394 m .27089 .65673 L .30206 .65871 L p .707 .577 .707 r
F P
0 g
s
.70607 .67619 m .70391 .62234 L .67644 .61747 L p .707 .577 .707 r
F P
0 g
s
.70391 .62234 m .70607 .67619 L .73723 .67761 L p .707 .577 .707 r
F P
0 g
s
.32696 .74517 m .32559 .76427 L .2981 .76083 L p .707 .577 .707 r
F P
0 g
s
.2981 .76083 m .29947 .74172 L .32696 .74517 L p .707 .577 .707 r
F P
0 g
s
.23905 .65727 m .23881 .69448 L .20943 .69749 L p .707 .577 .707 r
F P
0 g
s
.23881 .69448 m .23905 .65727 L .27089 .65673 L p .707 .577 .707 r
F P
0 g
s
.27089 .65673 m .27064 .69394 L .23881 .69448 L p .707 .577 .707 r
F P
0 g
s
.206 .75508 m .20737 .73598 L .2366 .73689 L p .707 .577 .707 r
F P
0 g
s
.79622 .61605 m .79838 .6699 L .82238 .66153 L p .707 .577 .707 r
F P
0 g
s
.82238 .66153 m .82022 .60767 L .79622 .61605 L p .707 .577 .707 r
F P
0 g
s
.54846 .24658 m .55162 .74628 L .50761 .74371 L p .707 .577 .707 r
F P
0 g
s
.50761 .74371 m .50445 .24401 L .54846 .24658 L p .707 .577 .707 r
F P
0 g
s
.2366 .73689 m .23523 .756 L .206 .75508 L p .707 .577 .707 r
F P
0 g
s
.46267 .74513 m .45951 .24543 L .50445 .24401 L p .707 .577 .707 r
F P
0 g
s
.45951 .24543 m .46267 .74513 L .42119 .7504 L p .707 .577 .707 r
F P
0 g
s
.6786 .67132 m .67644 .61747 L .65536 .60962 L p .707 .577 .707 r
F P
0 g
s
.67644 .61747 m .6786 .67132 L .70607 .67619 L p .707 .577 .707 r
F P
0 g
s
.29947 .74172 m .2981 .76083 L .26696 .75798 L p .707 .577 .707 r
F P
0 g
s
.26696 .75798 m .26833 .73887 L .29947 .74172 L p .707 .577 .707 r
F P
0 g
s
.50445 .24401 m .50761 .74371 L .46267 .74513 L p .707 .577 .707 r
F P
0 g
s
.23523 .756 m .2366 .73689 L .26833 .73887 L p .707 .577 .707 r
F P
0 g
s
.73732 .73686 m .73756 .69965 L .70639 .69767 L p .707 .577 .707 r
F P
0 g
s
.73756 .69965 m .73732 .73686 L .76915 .73633 L p .707 .577 .707 r
F P
0 g
s
.76915 .73633 m .7694 .69911 L .73756 .69965 L p .707 .577 .707 r
F P
0 g
s
.26833 .73887 m .26696 .75798 L .23523 .756 L p .707 .577 .707 r
F P
0 g
s
.7694 .69911 m .76915 .73633 L .79853 .73332 L p .707 .577 .707 r
F P
0 g
s
.79853 .73332 m .79878 .69611 L .7694 .69911 L p .707 .577 .707 r
F P
0 g
s
.82022 .60767 m .82238 .66153 L .83869 .65113 L p .707 .577 .707 r
F P
0 g
s
.83869 .65113 m .83653 .59728 L .82022 .60767 L p .707 .577 .707 r
F P
0 g
s
.70615 .73488 m .70639 .69767 L .67893 .69336 L p .707 .577 .707 r
F P
0 g
s
.70639 .69767 m .70615 .73488 L .73732 .73686 L p .707 .577 .707 r
F P
0 g
s
.73497 .7602 m .73635 .7411 L .70521 .73825 L p .707 .577 .707 r
F P
0 g
s
.73635 .7411 m .73497 .7602 L .76671 .76218 L p .707 .577 .707 r
F P
0 g
s
.76671 .76218 m .76808 .74308 L .73635 .7411 L p .707 .577 .707 r
F P
0 g
s
.70521 .73825 m .70384 .75735 L .73497 .7602 L p .707 .577 .707 r
F P
0 g
s
.76808 .74308 m .76671 .76218 L .79593 .76309 L p .707 .577 .707 r
F P
0 g
s
.79593 .76309 m .79731 .74399 L .76808 .74308 L p .707 .577 .707 r
F P
0 g
s
.70384 .75735 m .70521 .73825 L .67772 .7348 L p .707 .577 .707 r
F P
0 g
s
.79878 .69611 m .79853 .73332 L .82258 .72814 L p .707 .577 .707 r
F P
0 g
s
.82258 .72814 m .82283 .69093 L .79878 .69611 L p .707 .577 .707 r
F P
0 g
s
.65536 .60962 m .65752 .66348 L .6786 .67132 L p .707 .577 .707 r
F P
0 g
s
.67893 .69336 m .67869 .73057 L .70615 .73488 L p .707 .577 .707 r
F P
0 g
s
.67772 .7348 m .67634 .75391 L .70384 .75735 L p .707 .577 .707 r
F P
0 g
s
.65752 .66348 m .65536 .60962 L .64273 .59958 L p .707 .577 .707 r
F P
0 g
s
.67869 .73057 m .67893 .69336 L .65787 .68714 L p .707 .577 .707 r
F P
0 g
s
.79731 .74399 m .79593 .76309 L .81979 .76285 L p .707 .577 .707 r
F P
0 g
s
.81979 .76285 m .82116 .74375 L .79731 .74399 L p .707 .577 .707 r
F P
0 g
s
.67634 .75391 m .67772 .7348 L .65656 .73111 L p .707 .577 .707 r
F P
0 g
s
.83653 .59728 m .83869 .65113 L .84571 .63975 L p .707 .577 .707 r
F P
0 g
s
.84571 .63975 m .84356 .58589 L .83653 .59728 L p .707 .577 .707 r
F P
0 g
s
.65787 .68714 m .65763 .72436 L .67869 .73057 L p .707 .577 .707 r
F P
0 g
s
.65656 .73111 m .65519 .75021 L .67634 .75391 L p .707 .577 .707 r
F P
0 g
s
.82283 .69093 m .82258 .72814 L .83895 .72129 L p .707 .577 .707 r
F P
0 g
s
.83895 .72129 m .8392 .68408 L .82283 .69093 L p .707 .577 .707 r
F P
0 g
s
.64273 .59958 m .64488 .65343 L .65752 .66348 L p .707 .577 .707 r
F P
0 g
s
.64488 .65343 m .64273 .59958 L .63978 .58831 L p .707 .577 .707 r
F P
0 g
s
.65763 .72436 m .65787 .68714 L .64528 .67963 L p .707 .577 .707 r
F P
0 g
s
.82116 .74375 m .81979 .76285 L .83594 .76148 L p .707 .577 .707 r
F P
0 g
s
.83594 .76148 m .83731 .74237 L .82116 .74375 L p .707 .577 .707 r
F P
0 g
s
.65519 .75021 m .65656 .73111 L .64381 .72751 L p .707 .577 .707 r
F P
0 g
s
.64528 .67963 m .64504 .71685 L .65763 .72436 L p .707 .577 .707 r
F P
0 g
s
.64381 .72751 m .64244 .74662 L .65519 .75021 L p .707 .577 .707 r
F P
0 g
s
.84356 .58589 m .84571 .63975 L .84276 .62848 L p .707 .577 .707 r
F P
0 g
s
.84276 .62848 m .84061 .57462 L .84356 .58589 L p .707 .577 .707 r
F P
0 g
s
.8392 .68408 m .83895 .72129 L .84603 .71345 L p .707 .577 .707 r
F P
0 g
s
.84603 .71345 m .84628 .67624 L .8392 .68408 L p .707 .577 .707 r
F P
0 g
s
.63978 .58831 m .64193 .64216 L .64488 .65343 L p .707 .577 .707 r
F P
0 g
s
.83731 .74237 m .83594 .76148 L .8428 .75911 L p .707 .577 .707 r
F P
0 g
s
.8428 .75911 m .84418 .74 L .83731 .74237 L p .707 .577 .707 r
F P
0 g
s
.64504 .71685 m .64528 .67963 L .64238 .67156 L p .707 .577 .707 r
F P
0 g
s
.64193 .64216 m .63978 .58831 L .6468 .57692 L p .707 .577 .707 r
F P
0 g
s
.64244 .74662 m .64381 .72751 L .64072 .72438 L p .707 .577 .707 r
F P
0 g
s
.64238 .67156 m .64214 .70877 L .64504 .71685 L p .707 .577 .707 r
F P
0 g
s
.64072 .72438 m .63934 .74348 L .64244 .74662 L p .707 .577 .707 r
F P
0 g
s
.84061 .57462 m .84276 .62848 L .83013 .61843 L p .707 .577 .707 r
F P
0 g
s
.83013 .61843 m .82797 .56458 L .84061 .57462 L p .707 .577 .707 r
F P
0 g
s
.84628 .67624 m .84603 .71345 L .84314 .70538 L p .707 .577 .707 r
F P
0 g
s
.84314 .70538 m .84338 .66816 L .84628 .67624 L p .707 .577 .707 r
F P
0 g
s
.6468 .57692 m .64896 .63077 L .64193 .64216 L p .707 .577 .707 r
F P
0 g
s
.64896 .63077 m .6468 .57692 L .66311 .56653 L p .707 .577 .707 r
F P
0 g
s
.84418 .74 m .8428 .75911 L .83971 .75597 L p .707 .577 .707 r
F P
0 g
s
.83971 .75597 m .84108 .73687 L .84418 .74 L p .707 .577 .707 r
F P
0 g
s
.39422 .6408 m .39207 .58695 L .3609 .58552 L p .707 .577 .707 r
F P
0 g
s
.39207 .58695 m .39422 .6408 L .42603 .63863 L p .707 .577 .707 r
F P
0 g
s
.42603 .63863 m .42387 .58478 L .39207 .58695 L p .707 .577 .707 r
F P
0 g
s
.64214 .70877 m .64238 .67156 L .64946 .66372 L p .707 .577 .707 r
F P
0 g
s
.42387 .58478 m .42603 .63863 L .45537 .63309 L p .707 .577 .707 r
F P
0 g
s
.45537 .63309 m .45321 .57923 L .42387 .58478 L p .707 .577 .707 r
F P
0 g
s
.36306 .63938 m .3609 .58552 L .33343 .58065 L p .707 .577 .707 r
F P
0 g
s
.3609 .58552 m .36306 .63938 L .39422 .6408 L p .707 .577 .707 r
F P
0 g
s
.64946 .66372 m .64922 .70093 L .64214 .70877 L p .707 .577 .707 r
F P
0 g
s
.63934 .74348 m .64072 .72438 L .64758 .72201 L p .707 .577 .707 r
F P
0 g
s
.64758 .72201 m .64621 .74111 L .63934 .74348 L p .707 .577 .707 r
F P
0 g
s
.82797 .56458 m .83013 .61843 L .80905 .61058 L p .707 .577 .707 r
F P
0 g
s
.80905 .61058 m .80689 .55673 L .82797 .56458 L p .707 .577 .707 r
F P
0 g
s
.45321 .57923 m .45537 .63309 L .47937 .62471 L p .707 .577 .707 r
F P
0 g
s
.47937 .62471 m .47721 .57086 L .45321 .57923 L p .707 .577 .707 r
F P
0 g
s
.84338 .66816 m .84314 .70538 L .83054 .69786 L p .707 .577 .707 r
F P
0 g
s
.83054 .69786 m .83079 .66065 L .84338 .66816 L p .707 .577 .707 r
F P
0 g
s
.66311 .56653 m .66527 .62038 L .64896 .63077 L p .707 .577 .707 r
F P
0 g
s
.33559 .6345 m .33343 .58065 L .31235 .57281 L p .707 .577 .707 r
F P
0 g
s
.33343 .58065 m .33559 .6345 L .36306 .63938 L p .707 .577 .707 r
F P
0 g
s
.66527 .62038 m .66311 .56653 L .68711 .55815 L p .707 .577 .707 r
F P
0 g
s
.39431 .70005 m .39455 .66284 L .36338 .66085 L p .707 .577 .707 r
F P
0 g
s
.39455 .66284 m .39431 .70005 L .42614 .69951 L p .707 .577 .707 r
F P
0 g
s
.42614 .69951 m .42639 .6623 L .39455 .66284 L p .707 .577 .707 r
F P
0 g
s
.42639 .6623 m .42614 .69951 L .45552 .6965 L p .707 .577 .707 r
F P
0 g
s
.45552 .6965 m .45577 .65929 L .42639 .6623 L p .707 .577 .707 r
F P
0 g
s
.64922 .70093 m .64946 .66372 L .66583 .65687 L p .707 .577 .707 r
F P
0 g
s
.84108 .73687 m .83971 .75597 L .82696 .75238 L p .707 .577 .707 r
F P
0 g
s
.82696 .75238 m .82834 .73328 L .84108 .73687 L p .707 .577 .707 r
F P
0 g
s
.47721 .57086 m .47937 .62471 L .49568 .61432 L p .707 .577 .707 r
F P
0 g
s
.49568 .61432 m .49352 .56047 L .47721 .57086 L p .707 .577 .707 r
F P
0 g
s
.36314 .69807 m .36338 .66085 L .33592 .65654 L p .707 .577 .707 r
F P
0 g
s
.36338 .66085 m .36314 .69807 L .39431 .70005 L p .707 .577 .707 r
F P
0 g
s
.80689 .55673 m .80905 .61058 L .78158 .60571 L p .707 .577 .707 r
F P
0 g
s
.78158 .60571 m .77942 .55186 L .80689 .55673 L p .707 .577 .707 r
F P
0 g
s
.39196 .72339 m .39334 .70428 L .3622 .70143 L p .707 .577 .707 r
F P
0 g
s
.39334 .70428 m .39196 .72339 L .4237 .72536 L p .707 .577 .707 r
F P
0 g
s
.4237 .72536 m .42507 .70626 L .39334 .70428 L p .707 .577 .707 r
F P
0 g
s
.3622 .70143 m .36083 .72054 L .39196 .72339 L p .707 .577 .707 r
F P
0 g
s
.42507 .70626 m .4237 .72536 L .45292 .72628 L p .707 .577 .707 r
F P
0 g
s
.45292 .72628 m .4543 .70717 L .42507 .70626 L p .707 .577 .707 r
F P
0 g
s
.66583 .65687 m .66559 .69408 L .64922 .70093 L p .707 .577 .707 r
F P
0 g
s
.64621 .74111 m .64758 .72201 L .66373 .72064 L p .707 .577 .707 r
F P
0 g
s
.36083 .72054 m .3622 .70143 L .33471 .69799 L p .707 .577 .707 r
F P
0 g
s
.45577 .65929 m .45552 .6965 L .47958 .69132 L p .707 .577 .707 r
F P
0 g
s
.47958 .69132 m .47982 .65411 L .45577 .65929 L p .707 .577 .707 r
F P
0 g
s
.31235 .57281 m .31451 .62666 L .33559 .6345 L p .707 .577 .707 r
F P
0 g
s
.66373 .72064 m .66236 .73974 L .64621 .74111 L p .707 .577 .707 r
F P
0 g
s
.33592 .65654 m .33568 .69376 L .36314 .69807 L p .707 .577 .707 r
F P
0 g
s
.68927 .612 m .68711 .55815 L .71645 .55261 L p .707 .577 .707 r
F P
0 g
s
.68711 .55815 m .68927 .612 L .66527 .62038 L p .707 .577 .707 r
F P
0 g
s
.33471 .69799 m .33333 .71709 L .36083 .72054 L p .707 .577 .707 r
F P
0 g
s
.31451 .62666 m .31235 .57281 L .29972 .56276 L p .707 .577 .707 r
F P
0 g
s
.83079 .66065 m .83054 .69786 L .80949 .69165 L p .707 .577 .707 r
F P
0 g
s
.80949 .69165 m .80973 .65444 L .83079 .66065 L p .707 .577 .707 r
F P
0 g
s
.33568 .69376 m .33592 .65654 L .31486 .65033 L p .707 .577 .707 r
F P
0 g
s
.77942 .55186 m .78158 .60571 L .75041 .60429 L p .707 .577 .707 r
F P
0 g
s
.75041 .60429 m .74826 .55044 L .77942 .55186 L p .707 .577 .707 r
F P
0 g
s
.4543 .70717 m .45292 .72628 L .47678 .72603 L p .707 .577 .707 r
F P
0 g
s
.47678 .72603 m .47815 .70693 L .4543 .70717 L p .707 .577 .707 r
F P
0 g
s
.71861 .60646 m .71645 .55261 L .74826 .55044 L p .707 .577 .707 r
F P
0 g
s
.71645 .55261 m .71861 .60646 L .68927 .612 L p .707 .577 .707 r
F P
0 g
s
.66559 .69408 m .66583 .65687 L .68988 .65169 L p .707 .577 .707 r
F P
0 g
s
.74826 .55044 m .75041 .60429 L .71861 .60646 L p .707 .577 .707 r
F P
0 g
s
.33333 .71709 m .33471 .69799 L .31355 .69429 L p .707 .577 .707 r
F P
0 g
s
.49352 .56047 m .49568 .61432 L .5027 .60293 L p .707 .577 .707 r
F P
0 g
s
.5027 .60293 m .50055 .54908 L .49352 .56047 L p .707 .577 .707 r
F P
0 g
s
.31486 .65033 m .31462 .68754 L .33568 .69376 L p .707 .577 .707 r
F P
0 g
s
.31355 .69429 m .31218 .71339 L .33333 .71709 L p .707 .577 .707 r
F P
0 g
s
.82834 .73328 m .82696 .75238 L .80581 .74868 L p .707 .577 .707 r
F P
0 g
s
.80581 .74868 m .80718 .72958 L .82834 .73328 L p .707 .577 .707 r
F P
0 g
s
.47982 .65411 m .47958 .69132 L .49594 .68448 L p .707 .577 .707 r
F P
0 g
s
.49594 .68448 m .49619 .64726 L .47982 .65411 L p .707 .577 .707 r
F P
0 g
s
.29972 .56276 m .30187 .61661 L .31451 .62666 L p .707 .577 .707 r
F P
0 g
s
.68988 .65169 m .68964 .6889 L .66559 .69408 L p .707 .577 .707 r
F P
0 g
s
.66236 .73974 m .66373 .72064 L .68759 .7204 L p .707 .577 .707 r
F P
0 g
s
.80973 .65444 m .80949 .69165 L .78203 .68734 L p .707 .577 .707 r
F P
0 g
s
.78203 .68734 m .78227 .65013 L .80973 .65444 L p .707 .577 .707 r
F P
0 g
s
.68759 .7204 m .68621 .7395 L .66236 .73974 L p .707 .577 .707 r
F P
0 g
s
.30187 .61661 m .29972 .56276 L .29677 .55149 L p .707 .577 .707 r
F P
0 g
s
.31462 .68754 m .31486 .65033 L .30227 .64282 L p .707 .577 .707 r
F P
0 g
s
.47815 .70693 m .47678 .72603 L .49293 .72466 L p .707 .577 .707 r
F P
0 g
s
.49293 .72466 m .4943 .70556 L .47815 .70693 L p .707 .577 .707 r
F P
0 g
s
.68964 .6889 m .68988 .65169 L .71926 .64868 L p .707 .577 .707 r
F P
0 g
s
.31218 .71339 m .31355 .69429 L .3008 .6907 L p .707 .577 .707 r
F P
0 g
s
.30227 .64282 m .30203 .68003 L .31462 .68754 L p .707 .577 .707 r
F P
0 g
s
.3008 .6907 m .29943 .7098 L .31218 .71339 L p .707 .577 .707 r
F P
0 g
s
.80718 .72958 m .80581 .74868 L .77831 .74524 L p .707 .577 .707 r
F P
0 g
s
.77831 .74524 m .77969 .72614 L .80718 .72958 L p .707 .577 .707 r
F P
0 g
s
.78227 .65013 m .78203 .68734 L .75086 .68536 L p .707 .577 .707 r
F P
0 g
s
.75086 .68536 m .7511 .64814 L .78227 .65013 L p .707 .577 .707 r
F P
0 g
s
.71926 .64868 m .71902 .6859 L .68964 .6889 L p .707 .577 .707 r
F P
0 g
s
.50055 .54908 m .5027 .60293 L .49975 .59166 L p .707 .577 .707 r
F P
0 g
s
.49975 .59166 m .49759 .53781 L .50055 .54908 L p .707 .577 .707 r
F P
0 g
s
.49619 .64726 m .49594 .68448 L .50302 .67663 L p .707 .577 .707 r
F P
0 g
s
.50302 .67663 m .50327 .63942 L .49619 .64726 L p .707 .577 .707 r
F P
0 g
s
.71902 .6859 m .71926 .64868 L .7511 .64814 L p .707 .577 .707 r
F P
0 g
s
.68621 .7395 m .68759 .7204 L .71681 .72131 L p .707 .577 .707 r
F P
0 g
s
.71681 .72131 m .71544 .74041 L .68621 .7395 L p .707 .577 .707 r
F P
0 g
s
.7511 .64814 m .75086 .68536 L .71902 .6859 L p .707 .577 .707 r
F P
0 g
s
.29677 .55149 m .29892 .60534 L .30187 .61661 L p .707 .577 .707 r
F P
0 g
s
.77969 .72614 m .77831 .74524 L .74718 .74239 L p .707 .577 .707 r
F P
0 g
s
.74718 .74239 m .74855 .72329 L .77969 .72614 L p .707 .577 .707 r
F P
0 g
s
.4943 .70556 m .49293 .72466 L .49979 .72229 L p .707 .577 .707 r
F P
0 g
s
.49979 .72229 m .50117 .70319 L .4943 .70556 L p .707 .577 .707 r
F P
0 g
s
.30203 .68003 m .30227 .64282 L .29937 .63474 L p .707 .577 .707 r
F P
0 g
s
.29892 .60534 m .29677 .55149 L .30379 .5401 L p .707 .577 .707 r
F P
0 g
s
.71544 .74041 m .71681 .72131 L .74855 .72329 L p .707 .577 .707 r
F P
0 g
s
.74855 .72329 m .74718 .74239 L .71544 .74041 L p .707 .577 .707 r
F P
0 g
s
.29943 .7098 m .3008 .6907 L .29771 .68756 L p .707 .577 .707 r
F P
0 g
s
.29937 .63474 m .29913 .67196 L .30203 .68003 L p .707 .577 .707 r
F P
0 g
s
.29771 .68756 m .29633 .70667 L .29943 .7098 L p .707 .577 .707 r
F P
0 g
s
.49759 .53781 m .49975 .59166 L .48712 .58161 L p .707 .577 .707 r
F P
0 g
s
.48712 .58161 m .48496 .52776 L .49759 .53781 L p .707 .577 .707 r
F P
0 g
s
.50327 .63942 m .50302 .67663 L .50013 .66856 L p .707 .577 .707 r
F P
0 g
s
.50013 .66856 m .50037 .63135 L .50327 .63942 L p .707 .577 .707 r
F P
0 g
s
.30379 .5401 m .30595 .59395 L .29892 .60534 L p .707 .577 .707 r
F P
0 g
s
.30595 .59395 m .30379 .5401 L .3201 .52971 L p .707 .577 .707 r
F P
0 g
s
.50117 .70319 m .49979 .72229 L .4967 .71916 L p .707 .577 .707 r
F P
0 g
s
.4967 .71916 m .49807 .70005 L .50117 .70319 L p .707 .577 .707 r
F P
0 g
s
.29913 .67196 m .29937 .63474 L .30645 .6269 L p .707 .577 .707 r
F P
0 g
s
.30645 .6269 m .30621 .66411 L .29913 .67196 L p .707 .577 .707 r
F P
0 g
s
.29633 .70667 m .29771 .68756 L .30457 .68519 L p .707 .577 .707 r
F P
0 g
s
.30457 .68519 m .3032 .7043 L .29633 .70667 L p .707 .577 .707 r
F P
0 g
s
.48496 .52776 m .48712 .58161 L .46603 .57377 L p .707 .577 .707 r
F P
0 g
s
.46603 .57377 m .46388 .51992 L .48496 .52776 L p .707 .577 .707 r
F P
0 g
s
.50037 .63135 m .50013 .66856 L .48753 .66105 L p .707 .577 .707 r
F P
0 g
s
.48753 .66105 m .48778 .62384 L .50037 .63135 L p .707 .577 .707 r
F P
0 g
s
.3201 .52971 m .32226 .58356 L .30595 .59395 L p .707 .577 .707 r
F P
0 g
s
.32226 .58356 m .3201 .52971 L .3441 .52133 L p .707 .577 .707 r
F P
0 g
s
.30621 .66411 m .30645 .6269 L .32282 .62005 L p .707 .577 .707 r
F P
0 g
s
.49807 .70005 m .4967 .71916 L .48395 .71557 L p .707 .577 .707 r
F P
0 g
s
.48395 .71557 m .48532 .69646 L .49807 .70005 L p .707 .577 .707 r
F P
0 g
s
.46388 .51992 m .46603 .57377 L .43857 .5689 L p .707 .577 .707 r
F P
0 g
s
.43857 .5689 m .43641 .51505 L .46388 .51992 L p .707 .577 .707 r
F P
0 g
s
.32282 .62005 m .32258 .65727 L .30621 .66411 L p .707 .577 .707 r
F P
0 g
s
.3032 .7043 m .30457 .68519 L .32072 .68382 L p .707 .577 .707 r
F P
0 g
s
.32072 .68382 m .31935 .70292 L .3032 .7043 L p .707 .577 .707 r
F P
0 g
s
.34626 .57519 m .3441 .52133 L .37344 .51579 L p .707 .577 .707 r
F P
0 g
s
.3441 .52133 m .34626 .57519 L .32226 .58356 L p .707 .577 .707 r
F P
0 g
s
.48778 .62384 m .48753 .66105 L .46648 .65483 L p .707 .577 .707 r
F P
0 g
s
.46648 .65483 m .46672 .61762 L .48778 .62384 L p .707 .577 .707 r
F P
0 g
s
.43641 .51505 m .43857 .5689 L .4074 .56748 L p .707 .577 .707 r
F P
0 g
s
.4074 .56748 m .40525 .51362 L .43641 .51505 L p .707 .577 .707 r
F P
0 g
s
.3756 .56964 m .37344 .51579 L .40525 .51362 L p .707 .577 .707 r
F P
0 g
s
.37344 .51579 m .3756 .56964 L .34626 .57519 L p .707 .577 .707 r
F P
0 g
s
.32258 .65727 m .32282 .62005 L .34687 .61487 L p .707 .577 .707 r
F P
0 g
s
.40525 .51362 m .4074 .56748 L .3756 .56964 L p .707 .577 .707 r
F P
0 g
s
.48532 .69646 m .48395 .71557 L .4628 .71187 L p .707 .577 .707 r
F P
0 g
s
.4628 .71187 m .46417 .69276 L .48532 .69646 L p .707 .577 .707 r
F P
0 g
s
.34687 .61487 m .34663 .65209 L .32258 .65727 L p .707 .577 .707 r
F P
0 g
s
.31935 .70292 m .32072 .68382 L .34458 .68358 L p .707 .577 .707 r
F P
0 g
s
.46672 .61762 m .46648 .65483 L .43902 .65052 L p .707 .577 .707 r
F P
0 g
s
.43902 .65052 m .43926 .61331 L .46672 .61762 L p .707 .577 .707 r
F P
0 g
s
.34458 .68358 m .3432 .70268 L .31935 .70292 L p .707 .577 .707 r
F P
0 g
s
.34663 .65209 m .34687 .61487 L .37625 .61187 L p .707 .577 .707 r
F P
0 g
s
.46417 .69276 m .4628 .71187 L .4353 .70842 L p .707 .577 .707 r
F P
0 g
s
.4353 .70842 m .43668 .68932 L .46417 .69276 L p .707 .577 .707 r
F P
0 g
s
.43926 .61331 m .43902 .65052 L .40784 .64854 L p .707 .577 .707 r
F P
0 g
s
.40784 .64854 m .40809 .61133 L .43926 .61331 L p .707 .577 .707 r
F P
0 g
s
.37625 .61187 m .37601 .64908 L .34663 .65209 L p .707 .577 .707 r
F P
0 g
s
.37601 .64908 m .37625 .61187 L .40809 .61133 L p .707 .577 .707 r
F P
0 g
s
.3432 .70268 m .34458 .68358 L .3738 .68449 L p .707 .577 .707 r
F P
0 g
s
.3738 .68449 m .37243 .7036 L .3432 .70268 L p .707 .577 .707 r
F P
0 g
s
.40809 .61133 m .40784 .64854 L .37601 .64908 L p .707 .577 .707 r
F P
0 g
s
.43668 .68932 m .4353 .70842 L .40416 .70557 L p .707 .577 .707 r
F P
0 g
s
.40416 .70557 m .40554 .68647 L .43668 .68932 L p .707 .577 .707 r
F P
0 g
s
.37243 .7036 m .3738 .68449 L .40554 .68647 L p .707 .577 .707 r
F P
0 g
s
.40554 .68647 m .40416 .70557 L .37243 .7036 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo5@00R7oo001jOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001lOol007Aoo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL007Eoo`00L7oo10000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00LWoo001/
Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH3001_Ool006Yoo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eoo`00J7oo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`00Jgoo001VOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001YOol006Eoo`8000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYF001JEP0H0003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Moo`00H7oo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Moo`00GGoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0IGoo001KOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol005Uoo`<000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Egoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IGoo001FOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P006Goo3`00?Woo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH4000fOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
03=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP80031oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@000AJEP07
001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=o
o`0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00B7oo3@0000=JEP00FUH00eYF00<005YF
00000`000goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP<00003FUH0
05YF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool003moo`T000AJEP03001JEUYF00EJEP03001JEP0000AJ
EPL0009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00@0
05YF000000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00>Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000UYF0P000eYF00@005YFFUIJEQT000EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP09001JEUYFFUH005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00<7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00T005YFFUIJEP00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00;goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH70009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00@001Qoo`D000AJEP05001JEUYFFUH0000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05
001JEUYFFUH00005FUH00`00FUH0000>0004FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YF
FUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEUYF0004FUH00`00FUIJEP02FUH4000NOol200001UYF00000000FUH000=JEP8002aoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH60002FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF000010006Woo1P001EYF0`000eYF0P00;7oo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20002FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YF000010001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF20002Goo2@0015YF00<0
05YFFUH015YF00@005YFFUH0009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000=J
EP03001JEUYF00EJEP04001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1@0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@001=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@001Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEP0000<001]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP800003FUH005YF00@0011oo`T0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHH0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02eoo`03001JEP00009JEP8000=JEP03001JEUYF00=JEQ0000AJEP07001JEUYFFUH005YF00000eYF
00@005YFFUIJEPT000IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002eoo`03001JEP00008000EJEP03001JEUYF00EJEQ<000=JEP03001J
EP0000=JEPP00005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH01000
FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH0
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
0P00;goo000]Ool01@00FUH005YF00001EYF00<005YFFUH01P000eYF00<005YFFUH01eYF00@005YF
FUIJEPD00003FUH005YF008000AJEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70002FUH40003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00@0031oo`00;Goo0P000UYF00<005YFFUH00UYF100000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF4P000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo0P000eYF
00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`8000=JEP<000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP09001JEUYFFUH0
05YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`800003FUH00000009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02@00FUIJ
EUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^Ool30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF6P0000=JEP00FUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH0
1UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00=JEPh000Uoo`P000AJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH015YF0`001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000eYF100067oo1P0015YF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHE00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF20000eYF0`005Goo200000IJEP000000
05YF0002FUH2000/Ool002ioo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH0
1@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P0015YF00@005YFFUIJEQ/000AJEP03001JEUYF
00=JEP04001JEP000002FUH2000/Ool002ioo`03001JEP0000=JEPX0009JEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEP00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@002aoo`00;Woo00@0
05YF001JEP8000AJEP04001JEUYFFUHM0006FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;7oo000^Ool00`00FUH0
00020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`00;7oo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000^Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002eo
o`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0002FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUHB00000eYF001JEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJ
EP03001JEUYF00=JEQX0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00000`Ool002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2P00<Woo
000aOol30004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<7oo000_OolL0007FUH00`00FUIJEP05FUH01000FUIJEUYF1@0000Eo
o`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002eoo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0UYF5P001Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0001P000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH60005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01eYF5@001UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF4@0015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJ
EP03001JEUYF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001J
EUYF008002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000=JEP000000;Goo
000]Ool00`00FUH00002FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000040006FUH00`00FUIJEP02FUH20005FUH80004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo000]
Ool50006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YF00000UYF00@005YFFUIJEP8000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP@000AJEP8000AJEP03001JEUYF00AJEP03001JEUYF009JEP8000=oob<002ioo`00<7oo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YF
00000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2001DOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPH0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJ
EP03001JEUYF00<005Eoo`00>goo2@0015YF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF
FUH00eYF1000F7oo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF00000`00G7oo0017Ool5
00000goo0000000D00000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00007
001POol004Moo`D001Qoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH7
001LOol004Qoo`<001Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP05001GOol006Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000007FUH00`00FUIJEP03FUH00`00FUH00002001DOol006Eoo`03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001DOol0
06Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEPL000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001DOol006Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000=JEP03001JEUYF008005Aoo`00J7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP<000MJEP03001JEUYF00=J
EPD00003FUH0000005Aoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0008FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00E7oo001/Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0005Aoo`00Kgoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF8000EGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH700000goo00000003001_Ool007Uoo`/000IJEP03001JEUYF00YJEP04001J
EUYFFUH60008Ool5001_Ool008AooaL000moo`<0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60262 .73816 m .59914 .68566 L .56799 .68452 L p .707 .577 .707 r
F P
0 g
s
.59914 .68566 m .60262 .73816 L .60483 .73796 L p .707 .577 .707 r
F P
0 g
s
.56799 .68452 m .57147 .73703 L .57331 .7371 L p .707 .577 .707 r
F P
0 g
s
.57331 .7371 m .60262 .73816 L p .58714 .71418 L .707 .577 .707 r
F P
0 g
s
.58714 .71418 m .56799 .68452 L .57331 .7371 L .707 .577 .707 r
F
.57147 .73703 m .56799 .68452 L .54051 .67936 L p F P
0 g
s
.54051 .67936 m .54399 .73187 L .54565 .73218 L p .707 .577 .707 r
F P
0 g
s
.54565 .73218 m .57147 .73703 L p .55677 .70966 L .707 .577 .707 r
F P
0 g
s
.55677 .70966 m .54051 .67936 L .54565 .73218 L .707 .577 .707 r
F
.54399 .73187 m .54051 .67936 L .51938 .67069 L p F P
0 g
s
.51938 .67069 m .52286 .72319 L .52426 .72377 L p .707 .577 .707 r
F P
0 g
s
.52426 .72377 m .54399 .73187 L p .531 .69957 L .707 .577 .707 r
F P
0 g
s
.531 .69957 m .51938 .67069 L .52426 .72377 L .707 .577 .707 r
F
.52286 .72319 m .51938 .67069 L .50667 .65934 L p F P
0 g
s
.50667 .65934 m .51016 .71185 L .52286 .72319 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .51069 .70826 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52289 .75284 m .52316 .7277 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52316 .7277 m .52329 .71554 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .52329 .71554 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.54395 .75891 m .5442 .73512 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5442 .73512 m .54435 .72161 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .54435 .72161 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57141 .76317 m .57166 .73984 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57166 .73984 m .5718 .72586 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.60298 .7279 m .5718 .72586 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60258 .7652 m .60283 .74141 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60283 .74141 m .60298 .7279 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60483 .73796 m .63438 .73516 L p .61894 .71348 L .707 .577 .707 r
F P
0 g
s
.61894 .71348 m .59914 .68566 L .60483 .73796 L .707 .577 .707 r
F
.63438 .73516 m .6309 .68266 L .59914 .68566 L p F P
0 g
s
.6309 .68266 m .63438 .73516 L .63696 .73456 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .60298 .7279 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63442 .76481 m .63468 .73967 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63468 .73967 m .63481 .72751 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63696 .73456 m .66365 .72832 L p .6489 .70776 L .707 .577 .707 r
F P
0 g
s
.6489 .70776 m .6309 .68266 L .63696 .73456 L .707 .577 .707 r
F
.66365 .72832 m .66017 .67581 L .6309 .68266 L p F P
0 g
s
.66017 .67581 m .66365 .72832 L .66605 .72732 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .63481 .72751 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66379 .76204 m .66408 .7348 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66408 .7348 m .66419 .72473 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66605 .72732 m .68756 .71831 L p .67398 .69723 L .707 .577 .707 r
F P
0 g
s
.67398 .69723 m .66017 .67581 L .66605 .72732 L .707 .577 .707 r
F
.68756 .71831 m .68408 .6658 L .66017 .67581 L p F P
0 g
s
.60298 .7279 m .60258 .7652 L .63442 .76481 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .63442 .76481 L .66379 .76204 L p .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .57141 .76317 L .60258 .7652 L p .707 .577 .707 r
F P
0 g
s
.57058 .76557 m .56838 .78467 L .59946 .78811 L p .707 .577 .707 r
F P
0 g
s
.59946 .78811 m .60166 .76901 L .57058 .76557 L p .707 .577 .707 r
F P
0 g
s
.60166 .76901 m .59946 .78811 L .63103 .79182 L p .707 .577 .707 r
F P
0 g
s
.63103 .79182 m .63323 .77271 L .60166 .76901 L p .707 .577 .707 r
F P
0 g
s
.68408 .6658 m .68756 .71831 L .70378 .7061 L p .707 .577 .707 r
F P
0 g
s
.70378 .7061 m .7003 .65359 L .68408 .6658 L p .707 .577 .707 r
F P
0 g
s
.63323 .77271 m .63103 .79182 L .66001 .79542 L p .707 .577 .707 r
F P
0 g
s
.66001 .79542 m .66221 .77631 L .63323 .77271 L p .707 .577 .707 r
F P
0 g
s
.54303 .76272 m .54083 .78182 L .56838 .78467 L p .707 .577 .707 r
F P
0 g
s
.56838 .78467 m .57058 .76557 L .54303 .76272 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .66379 .76204 L .68784 .75715 L p .707 .577 .707 r
F P
0 g
s
.68784 .75715 m .68824 .71984 L .66419 .72473 L p .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .54395 .75891 L .57141 .76317 L p .707 .577 .707 r
F P
0 g
s
.66221 .77631 m .66001 .79542 L .68355 .79856 L p .707 .577 .707 r
F P
0 g
s
.68355 .79856 m .68575 .77946 L .66221 .77631 L p .707 .577 .707 r
F P
0 g
s
.52171 .76074 m .51951 .77985 L .54083 .78182 L p .707 .577 .707 r
F P
0 g
s
.54083 .78182 m .54303 .76272 L .52171 .76074 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .52289 .75284 L .54395 .75891 L p .707 .577 .707 r
F P
0 g
s
.7003 .65359 m .70378 .7061 L .71071 .6929 L p .707 .577 .707 r
F P
0 g
s
.71071 .6929 m .70722 .64039 L .7003 .65359 L p .707 .577 .707 r
F P
0 g
s
.68824 .71984 m .68784 .75715 L .70421 .75063 L p .707 .577 .707 r
F P
0 g
s
.70421 .75063 m .7046 .71332 L .68824 .71984 L p .707 .577 .707 r
F P
0 g
s
.68575 .77946 m .68355 .79856 L .69935 .80094 L p .707 .577 .707 r
F P
0 g
s
.69935 .80094 m .70154 .78184 L .68575 .77946 L p .707 .577 .707 r
F P
0 g
s
.51016 .71185 m .50667 .65934 L .50364 .64643 L p .707 .577 .707 r
F P
0 g
s
.50871 .75984 m .50651 .77894 L .51951 .77985 L p .707 .577 .707 r
F P
0 g
s
.51951 .77985 m .52171 .76074 L .50871 .75984 L p .707 .577 .707 r
F P
0 g
s
.51069 .70826 m .5103 .74556 L .52289 .75284 L p .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .4822 .32906 L .43819 .32655 L p .707 .577 .707 r
F P
0 g
s
.50364 .64643 m .50712 .69894 L .51016 .71185 L p .707 .577 .707 r
F P
0 g
s
.5103 .74556 m .51069 .70826 L .50779 .70048 L p .707 .577 .707 r
F P
0 g
s
.50712 .69894 m .50364 .64643 L .51056 .63323 L p .707 .577 .707 r
F P
0 g
s
.5053 .76009 m .5031 .7792 L .50651 .77894 L p .707 .577 .707 r
F P
0 g
s
.50651 .77894 m .50871 .75984 L .5053 .76009 L p .707 .577 .707 r
F P
0 g
s
.50779 .70048 m .5074 .73778 L .5103 .74556 L p .707 .577 .707 r
F P
0 g
s
.51056 .63323 m .51405 .68574 L .50712 .69894 L p .707 .577 .707 r
F P
0 g
s
.5074 .73778 m .50779 .70048 L .51487 .69296 L p .707 .577 .707 r
F P
0 g
s
.51405 .68574 m .51056 .63323 L .52678 .62102 L p .707 .577 .707 r
F P
0 g
s
.51487 .69296 m .51448 .73026 L .5074 .73778 L p .707 .577 .707 r
F P
0 g
s
.51181 .76148 m .50961 .78058 L .5031 .7792 L p .707 .577 .707 r
F P
0 g
s
.5031 .7792 m .5053 .76009 L .51181 .76148 L p .707 .577 .707 r
F P
0 g
s
.52678 .62102 m .53026 .67353 L .51405 .68574 L p .707 .577 .707 r
F P
0 g
s
.51448 .73026 m .51487 .69296 L .53124 .68643 L p .707 .577 .707 r
F P
0 g
s
.53124 .68643 m .53084 .72374 L .51448 .73026 L p .707 .577 .707 r
F P
0 g
s
.52761 .76386 m .52541 .78296 L .50961 .78058 L p .707 .577 .707 r
F P
0 g
s
.50961 .78058 m .51181 .76148 L .52761 .76386 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .52541 .78296 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55115 .767 m .55098 .76853 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55098 .76853 m .54895 .78611 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .52761 .76386 L .55053 .76692 L p .707 .577 .707 r
F P
0 g
s
.55053 .76692 m .55115 .767 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .55053 .76692 L .55064 .76732 L .707 .577 .707 r
F
.52714 .32744 m .4822 .32906 L p .51236 .62831 L F P
0 g
s
.53084 .72374 m .53124 .68643 L .5459 .68345 L p .707 .577 .707 r
F P
0 g
s
.53026 .67353 m .52678 .62102 L .55069 .61101 L p .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .55286 .6438 L p .53026 .67353 L .707 .577 .707 r
F P
0 g
s
.58013 .7706 m .57793 .78971 L .54895 .78611 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .54904 .7853 L p .58013 .7706 L .707 .577 .707 r
F P
0 g
s
.54904 .7853 m .55115 .767 L .55886 .76796 L p .707 .577 .707 r
F P
0 g
s
.55886 .76796 m .58013 .7706 L p .54904 .7853 L .707 .577 .707 r
F P
0 g
s
.58427 .71607 m .58466 .67877 L .6165 .67838 L p .707 .577 .707 r
F P
0 g
s
.6165 .67838 m .6161 .71568 L .58427 .71607 L p .707 .577 .707 r
F P
0 g
s
.6117 .77431 m .6095 .79341 L .58385 .7904 L p .707 .577 .707 r
F P
0 g
s
.58385 .7904 m .57793 .78971 L p .58452 .7867 L .707 .577 .707 r
F P
0 g
s
.58452 .7867 m .6117 .77431 L .58385 .7904 L .707 .577 .707 r
F
.64287 .6023 m .64635 .65481 L .61521 .65367 L p F P
0 g
s
.61521 .65367 m .61172 .60116 L .64287 .6023 L p .707 .577 .707 r
F P
0 g
s
.64767 .68041 m .64727 .71772 L .6161 .71568 L p .707 .577 .707 r
F P
0 g
s
.6161 .71568 m .6165 .67838 L .64767 .68041 L p .707 .577 .707 r
F P
0 g
s
.64278 .77775 m .64058 .79686 L .61294 .79379 L p .707 .577 .707 r
F P
0 g
s
.61294 .79379 m .6095 .79341 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.61308 .79173 m .64278 .77775 L .61294 .79379 L .707 .577 .707 r
F
.6095 .79341 m .6117 .77431 L .61417 .77458 L p F P
0 g
s
.61417 .77458 m .64278 .77775 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.6095 .79341 m .61417 .77458 L .61308 .79173 L .707 .577 .707 r
F
.63566 .28839 m .62567 .30133 L p .63179 .498 L F P
0 g
s
.64078 .78667 m .63698 .4166 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63698 .4166 m .63566 .28839 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .64078 .78667 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62567 .30133 m .62826 .55347 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62826 .55347 m .63079 .79961 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.57793 .78971 m .58013 .7706 L .6117 .77431 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .63079 .79961 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .57996 .60417 L .61172 .60116 L p .707 .577 .707 r
F P
0 g
s
.61172 .60116 m .61521 .65367 L .58344 .65667 L p .707 .577 .707 r
F P
0 g
s
.60257 .31286 m .6062 .66641 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.6062 .66641 m .60768 .81114 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .60768 .81114 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .56292 .60815 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56292 .60815 m .57996 .60417 L p .56891 .62961 L .707 .577 .707 r
F P
0 g
s
.5636 .64181 m .56292 .60815 L .56891 .62961 L .707 .577 .707 r
F
.57188 .64028 m .57294 .7431 L p .57673 .73641 L F P
0 g
s
.58161 .67906 m .58466 .67877 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58187 .67605 m .57188 .64028 L .57673 .73641 L .707 .577 .707 r
F
.58466 .67877 m .58427 .71607 L .57841 .71663 L p F P
0 g
s
.56797 .77749 m .55286 .6438 L .55119 .6533 L .707 .577 .707 r
F
.57373 .82014 m .56867 .77741 L .56797 .77749 L F
.56867 .77741 m .55286 .6438 L .56797 .77749 L F
.57373 .82014 m .55698 .64303 L .55286 .6438 L F
.54902 .66568 m .53026 .67353 L p .55286 .6438 L F P
0 g
s
.55803 .82225 m .57373 .82014 L p .52878 .4874 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .57188 .64028 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .55417 .66352 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.57996 .60417 m .58223 .63836 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.58223 .63836 m .58344 .65667 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55069 .61101 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56862 .32186 m .52714 .32744 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57188 .64028 m .56862 .32186 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57841 .71663 m .55489 .71885 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58124 .68337 m .58466 .67877 L .57841 .71663 L .707 .577 .707 r
F
.59863 .69774 m .5829 .66394 L .59145 .71041 L F
.5829 .66394 m .57188 .64028 L .58187 .67605 L F
.5829 .66394 m .58187 .67605 L .59145 .71041 L F
.59145 .71041 m .58187 .67605 L .57673 .73641 L F
.55489 .71885 m .55528 .68154 L .58161 .67906 L p F P
0 g
s
.55489 .71885 m .58161 .67906 L .58124 .68337 L .707 .577 .707 r
F
.56862 .32186 m .57188 .64028 L p .59863 .69774 L F P
0 g
s
.57294 .7431 m .57373 .82014 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55417 .66352 L .54902 .66568 L p .707 .577 .707 r
F P
0 g
s
.55119 .6533 m .55286 .6438 L .54998 .64433 L .707 .577 .707 r
F
.52714 .32744 m .52878 .4874 L p .54998 .64433 L F P
0 g
s
.55698 .64303 m .52714 .32744 L .54998 .64433 L .707 .577 .707 r
F
.55417 .66352 m .55286 .6438 L p .5636 .64181 L F P
0 g
s
.5459 .68345 m .55528 .68154 L p .54699 .69587 L .707 .577 .707 r
F P
0 g
s
.53084 .72374 m .5459 .68345 L .54699 .69587 L .707 .577 .707 r
F
.55528 .68154 m .55489 .71885 L .53084 .72374 L p F P
0 g
s
.52878 .4874 m .53225 .82572 L .55803 .82225 L p .707 .577 .707 r
F P
0 g
s
.53225 .82572 m .53092 .6957 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.53092 .6957 m .52714 .32744 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .53225 .82572 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.4822 .32906 m .48422 .52615 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48422 .52615 m .48731 .82734 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.7046 .71332 m .70421 .75063 L .71129 .7431 L p .707 .577 .707 r
F P
0 g
s
.71129 .7431 m .71168 .7058 L .7046 .71332 L p .707 .577 .707 r
F P
0 g
s
.70722 .64039 m .71071 .6929 L .70767 .67999 L p .707 .577 .707 r
F P
0 g
s
.70767 .67999 m .70419 .62748 L .70722 .64039 L p .707 .577 .707 r
F P
0 g
s
.4433 .82483 m .43819 .32655 L .39943 .32017 L p .707 .577 .707 r
F P
0 g
s
.43819 .32655 m .4433 .82483 L .48731 .82734 L p .707 .577 .707 r
F P
0 g
s
.70154 .78184 m .69935 .80094 L .70586 .80233 L p .707 .577 .707 r
F P
0 g
s
.70586 .80233 m .70806 .78323 L .70154 .78184 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .60257 .31286 L .56862 .32186 L p .707 .577 .707 r
F P
0 g
s
.40454 .81845 m .39943 .32017 L .3697 .31054 L p .707 .577 .707 r
F P
0 g
s
.39943 .32017 m .40454 .81845 L .4433 .82483 L p .707 .577 .707 r
F P
0 g
s
.70419 .62748 m .70767 .67999 L .69496 .66864 L p .707 .577 .707 r
F P
0 g
s
.69496 .66864 m .69148 .61614 L .70419 .62748 L p .707 .577 .707 r
F P
0 g
s
.71168 .7058 m .71129 .7431 L .70839 .73532 L p .707 .577 .707 r
F P
0 g
s
.70839 .73532 m .70878 .69802 L .71168 .7058 L p .707 .577 .707 r
F P
0 g
s
.70806 .78323 m .70586 .80233 L .70245 .80258 L p .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .62567 .30133 L .60257 .31286 L p .707 .577 .707 r
F P
0 g
s
.70245 .80258 m .70465 .78348 L .70806 .78323 L p .707 .577 .707 r
F P
0 g
s
.25961 .70135 m .25613 .64884 L .22498 .64771 L p .707 .577 .707 r
F P
0 g
s
.25613 .64884 m .25961 .70135 L .26182 .70114 L p .707 .577 .707 r
F P
0 g
s
.22498 .64771 m .22846 .70022 L .2303 .70028 L p .707 .577 .707 r
F P
0 g
s
.2303 .70028 m .25961 .70135 L p .24413 .67737 L .707 .577 .707 r
F P
0 g
s
.24413 .67737 m .22498 .64771 L .2303 .70028 L .707 .577 .707 r
F
.22846 .70022 m .22498 .64771 L .1975 .64255 L p F P
0 g
s
.1975 .64255 m .20098 .69506 L .20264 .69537 L p .707 .577 .707 r
F P
0 g
s
.20264 .69537 m .22846 .70022 L p .21376 .67284 L .707 .577 .707 r
F P
0 g
s
.21376 .67284 m .1975 .64255 L .20264 .69537 L .707 .577 .707 r
F
.20098 .69506 m .1975 .64255 L .17637 .63387 L p F P
0 g
s
.17637 .63387 m .17985 .68638 L .18125 .68695 L p .707 .577 .707 r
F P
0 g
s
.18125 .68695 m .20098 .69506 L p .18799 .66275 L .707 .577 .707 r
F P
0 g
s
.18799 .66275 m .17637 .63387 L .18125 .68695 L .707 .577 .707 r
F
.17985 .68638 m .17637 .63387 L .16367 .62252 L p F P
0 g
s
.16367 .62252 m .16715 .67503 L .17985 .68638 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .16768 .67144 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.17988 .71603 m .18015 .69089 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.18015 .69089 m .18028 .67872 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .18028 .67872 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20094 .7221 m .20119 .6983 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20119 .6983 m .20134 .68479 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .20134 .68479 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.2284 .72635 m .22865 .70303 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.22865 .70303 m .2288 .68905 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .2288 .68905 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25957 .72839 m .25982 .7046 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25982 .7046 m .25997 .69108 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.26182 .70114 m .29137 .69835 L p .27593 .67666 L .707 .577 .707 r
F P
0 g
s
.27593 .67666 m .25613 .64884 L .26182 .70114 L .707 .577 .707 r
F
.29137 .69835 m .28789 .64584 L .25613 .64884 L p F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28789 .64584 m .29137 .69835 L .29395 .69775 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .25997 .69108 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29141 .728 m .29167 .70286 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29167 .70286 m .2918 .69069 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29395 .69775 m .32064 .69151 L p .3059 .67094 L .707 .577 .707 r
F P
0 g
s
.3059 .67094 m .28789 .64584 L .29395 .69775 L .707 .577 .707 r
F
.32064 .69151 m .31716 .639 L .28789 .64584 L p F P
0 g
s
.69148 .61614 m .69496 .66864 L .67384 .65996 L p .707 .577 .707 r
F P
0 g
s
.67384 .65996 m .67035 .60746 L .69148 .61614 L p .707 .577 .707 r
F P
0 g
s
.36828 .70629 m .36867 .66898 L .36159 .6765 L p .707 .577 .707 r
F P
0 g
s
.36159 .6765 m .3612 .71381 L .36828 .70629 L p .707 .577 .707 r
F P
0 g
s
.36867 .66898 m .36828 .70629 L .36608 .70038 L p .707 .577 .707 r
F P
0 g
s
.36631 .69015 m .36867 .66898 L .36608 .70038 L .707 .577 .707 r
F
.34107 .62898 m .34456 .68149 L .36077 .66928 L p F P
0 g
s
.36077 .66928 m .35729 .61678 L .34107 .62898 L p .707 .577 .707 r
F P
0 g
s
.35729 .61678 m .36077 .66928 L .3677 .65608 L p .707 .577 .707 r
F P
0 g
s
.3677 .65608 m .36421 .60357 L .35729 .61678 L p .707 .577 .707 r
F P
0 g
s
.34523 .68303 m .34483 .72033 L .3612 .71381 L p .707 .577 .707 r
F P
0 g
s
.3612 .71381 m .36159 .6765 L .34523 .68303 L p .707 .577 .707 r
F P
0 g
s
.35634 .76413 m .35854 .74503 L .34274 .74264 L p .707 .577 .707 r
F P
0 g
s
.35854 .74503 m .35634 .76413 L .36285 .76551 L p .707 .577 .707 r
F P
0 g
s
.36285 .76551 m .36505 .74641 L .35854 .74503 L p .707 .577 .707 r
F P
0 g
s
.36505 .74641 m .36285 .76551 L .35944 .76577 L p .707 .577 .707 r
F P
0 g
s
.35944 .76577 m .36164 .74666 L .36505 .74641 L p .707 .577 .707 r
F P
0 g
s
.35703 .79688 m .37481 .80882 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.36421 .60357 m .3677 .65608 L .36531 .64596 L p .707 .577 .707 r
F P
0 g
s
.3646 .63775 m .36421 .60357 L .36531 .64596 L .707 .577 .707 r
F
.3669 .66419 m .36335 .62346 L .36534 .73239 L F
.36538 .69851 m .36577 .6612 L .3669 .66424 L p F P
0 g
s
.3669 .66424 m .36867 .66898 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.36538 .69851 m .3669 .66424 L .36631 .69015 L .707 .577 .707 r
F
.34274 .74264 m .34054 .76175 L .35634 .76413 L p F P
0 g
s
.35944 .76577 m .34644 .76486 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.36164 .74666 m .35953 .76496 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35953 .76496 m .35944 .76577 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35529 .69268 m .35278 .69123 L p .35514 .68576 L .707 .577 .707 r
F P
0 g
s
.35532 .69385 m .3548 .63425 L .35442 .65164 L .707 .577 .707 r
F
.35278 .69123 m .35318 .65392 L .35448 .65468 L p F P
0 g
s
.3548 .63437 m .35196 .63183 L p .35517 .61746 L .707 .577 .707 r
F P
0 g
s
.35624 .71984 m .35518 .61702 L p .35532 .69385 L .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .34847 .57932 L .35587 .58593 L p .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .35587 .58593 L .35517 .61746 L .707 .577 .707 r
F
.35518 .61702 m .35192 .2986 L p .3548 .63425 L F P
0 g
s
.35518 .61702 m .3548 .63425 L .35532 .69385 L .707 .577 .707 r
F
.34644 .76486 m .34864 .74576 L .35818 .74642 L p F P
0 g
s
.35818 .74642 m .36164 .74666 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.34644 .76486 m .35818 .74642 L .35847 .75045 L .707 .577 .707 r
F
.35294 .7838 m .35703 .79688 L p .35545 .70899 L F P
0 g
s
.35278 .69123 m .35448 .65468 L .35514 .68576 L .707 .577 .707 r
F
.34847 .57932 m .35196 .63183 L .34562 .62923 L p F P
0 g
s
.34562 .62923 m .33083 .62315 L p .3438 .59092 L .707 .577 .707 r
F P
0 g
s
.3438 .59092 m .34847 .57932 L .34562 .62923 L .707 .577 .707 r
F
.31716 .639 m .32064 .69151 L .32305 .6905 L p F P
0 g
s
.32305 .6905 m .34456 .68149 L p .33097 .66041 L .707 .577 .707 r
F P
0 g
s
.33097 .66041 m .31716 .639 L .32305 .6905 L .707 .577 .707 r
F
.32118 .68792 m .2918 .69069 L p .31554 .71898 L F P
0 g
s
.32079 .72522 m .32107 .69799 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.32107 .69799 m .32118 .68792 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.34456 .68149 m .34107 .62898 L .31716 .639 L p .707 .577 .707 r
F P
0 g
s
.34483 .72033 m .34523 .68303 L .32118 .68792 L p .707 .577 .707 r
F P
0 g
s
.35318 .65392 m .35278 .69123 L .33172 .68516 L p .707 .577 .707 r
F P
0 g
s
.33172 .68516 m .33212 .64785 L .35318 .65392 L p .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35163 .65671 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35163 .65671 m .35294 .7838 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .34782 .28552 L p .35442 .6518 L .707 .577 .707 r
F P
0 g
s
.3548 .63425 m .35192 .2986 L .35442 .6518 L .707 .577 .707 r
F
.35518 .61702 m .35703 .79688 L p .36335 .62346 L F P
0 g
s
.35587 .58593 m .36118 .59067 L p .35526 .61708 L .707 .577 .707 r
F P
0 g
s
.35517 .61746 m .35518 .61702 L .35526 .61708 L .707 .577 .707 r
F
.35518 .61702 m .35587 .58593 L .35526 .61708 L F
.36118 .59067 m .36335 .62346 L p .35526 .61708 L F P
0 g
s
.35417 .51818 m .35518 .61702 L p .36335 .62346 L .707 .577 .707 r
F P
0 g
s
.36118 .59067 m .36421 .60357 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36466 .64318 m .36335 .62346 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36335 .62346 m .36118 .59067 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .35417 .51818 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .35192 .2986 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35781 .27258 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35294 .7838 m .35292 .7827 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35292 .7827 m .34782 .28552 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.36534 .73239 m .36335 .62346 L .35703 .79688 L .707 .577 .707 r
F
.35448 .65468 m .36577 .6612 L p .35514 .68576 L F P
0 g
s
.35572 .71269 m .35532 .69385 L .35545 .70899 L .707 .577 .707 r
F
.35624 .71984 m .35532 .69385 L .35572 .71269 L F
.35545 .70899 m .35532 .69385 L .35442 .6518 L F
.35532 .69385 m .35442 .65164 L .35442 .6518 L F
.36577 .6612 m .36538 .69851 L .35529 .69268 L p F P
0 g
s
.35514 .68576 m .36577 .6612 L .35529 .69268 L .707 .577 .707 r
F
.36466 .64318 m .3548 .63437 L p .35526 .61708 L F P
0 g
s
.35517 .61746 m .35526 .61708 L .3548 .63437 L .707 .577 .707 r
F
.35703 .79688 m .35624 .71984 L p .35545 .70899 L F P
0 g
s
.36982 .69764 m .3669 .66419 L .36534 .73239 L .707 .577 .707 r
F
.36335 .62346 m .36466 .64318 L p .35526 .61708 L F P
0 g
s
.36531 .64596 m .36466 .64318 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36608 .70038 m .36538 .69851 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.37481 .80882 m .37134 .47051 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.37134 .47051 m .3697 .31054 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .37481 .80882 L .40454 .81845 L p .707 .577 .707 r
F P
0 g
s
.70878 .69802 m .70839 .73532 L .69579 .72804 L p .707 .577 .707 r
F P
0 g
s
.69579 .72804 m .69619 .69074 L .70878 .69802 L p .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .25957 .72839 L .29141 .728 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .29141 .728 L .32079 .72522 L p .707 .577 .707 r
F P
0 g
s
.70465 .78348 m .70245 .80258 L .68945 .80168 L p .707 .577 .707 r
F P
0 g
s
.68945 .80168 m .69165 .78257 L .70465 .78348 L p .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .2284 .72635 L .25957 .72839 L p .707 .577 .707 r
F P
0 g
s
.22757 .72875 m .22537 .74785 L .25645 .7513 L p .707 .577 .707 r
F P
0 g
s
.25645 .7513 m .25865 .73219 L .22757 .72875 L p .707 .577 .707 r
F P
0 g
s
.25865 .73219 m .25645 .7513 L .28802 .755 L p .707 .577 .707 r
F P
0 g
s
.28802 .755 m .29022 .7359 L .25865 .73219 L p .707 .577 .707 r
F P
0 g
s
.67035 .60746 m .67384 .65996 L .64635 .65481 L p .707 .577 .707 r
F P
0 g
s
.64635 .65481 m .64287 .6023 L .67035 .60746 L p .707 .577 .707 r
F P
0 g
s
.29022 .7359 m .28802 .755 L .317 .7586 L p .707 .577 .707 r
F P
0 g
s
.317 .7586 m .3192 .7395 L .29022 .7359 L p .707 .577 .707 r
F P
0 g
s
.20002 .7259 m .19782 .745 L .22537 .74785 L p .707 .577 .707 r
F P
0 g
s
.22537 .74785 m .22757 .72875 L .20002 .7259 L p .707 .577 .707 r
F P
0 g
s
.32118 .68792 m .32079 .72522 L .34483 .72033 L p .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .20094 .7221 L .2284 .72635 L p .707 .577 .707 r
F P
0 g
s
.69619 .69074 m .69579 .72804 L .67473 .72198 L p .707 .577 .707 r
F P
0 g
s
.67473 .72198 m .67513 .68467 L .69619 .69074 L p .707 .577 .707 r
F P
0 g
s
.3192 .7395 m .317 .7586 L .34054 .76175 L p .707 .577 .707 r
F P
0 g
s
.34054 .76175 m .34274 .74264 L .3192 .7395 L p .707 .577 .707 r
F P
0 g
s
.1787 .72393 m .1765 .74303 L .19782 .745 L p .707 .577 .707 r
F P
0 g
s
.19782 .745 m .20002 .7259 L .1787 .72393 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .17988 .71603 L .20094 .7221 L p .707 .577 .707 r
F P
0 g
s
.69165 .78257 m .68945 .80168 L .66813 .7997 L p .707 .577 .707 r
F P
0 g
s
.66813 .7997 m .67033 .7806 L .69165 .78257 L p .707 .577 .707 r
F P
0 g
s
.67513 .68467 m .67473 .72198 L .64727 .71772 L p .707 .577 .707 r
F P
0 g
s
.64727 .71772 m .64767 .68041 L .67513 .68467 L p .707 .577 .707 r
F P
0 g
s
.16715 .67503 m .16367 .62252 L .16063 .60962 L p .707 .577 .707 r
F P
0 g
s
.63566 .28839 m .64078 .78667 L .63669 .77359 L p .707 .577 .707 r
F P
0 g
s
.63669 .77359 m .63157 .27531 L .63566 .28839 L p .707 .577 .707 r
F P
0 g
s
.1657 .72302 m .1635 .74213 L .1765 .74303 L p .707 .577 .707 r
F P
0 g
s
.1765 .74303 m .1787 .72393 L .1657 .72302 L p .707 .577 .707 r
F P
0 g
s
.16768 .67144 m .16729 .70875 L .17988 .71603 L p .707 .577 .707 r
F P
0 g
s
.67033 .7806 m .66813 .7997 L .64058 .79686 L p .707 .577 .707 r
F P
0 g
s
.64058 .79686 m .64278 .77775 L .67033 .7806 L p .707 .577 .707 r
F P
0 g
s
.16063 .60962 m .16411 .66212 L .16715 .67503 L p .707 .577 .707 r
F P
0 g
s
.16729 .70875 m .16768 .67144 L .16478 .66366 L p .707 .577 .707 r
F P
0 g
s
.16411 .66212 m .16063 .60962 L .16756 .59641 L p .707 .577 .707 r
F P
0 g
s
.16229 .72328 m .16009 .74238 L .1635 .74213 L p .707 .577 .707 r
F P
0 g
s
.1635 .74213 m .1657 .72302 L .16229 .72328 L p .707 .577 .707 r
F P
0 g
s
.16478 .66366 m .16439 .70097 L .16729 .70875 L p .707 .577 .707 r
F P
0 g
s
.63157 .27531 m .63669 .77359 L .6189 .76165 L p .707 .577 .707 r
F P
0 g
s
.6189 .76165 m .61379 .26337 L .63157 .27531 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16756 .59641 m .17104 .64892 L .16411 .66212 L p .707 .577 .707 r
F P
0 g
s
.16439 .70097 m .16478 .66366 L .17186 .65614 L p .707 .577 .707 r
F P
0 g
s
.17104 .64892 m .16756 .59641 L .18377 .58421 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36293 .77086 m .35781 .27258 L .38092 .26105 L p .707 .577 .707 r
F P
0 g
s
.35781 .27258 m .36293 .77086 L .35294 .7838 L p .707 .577 .707 r
F P
0 g
s
.17186 .65614 m .17147 .69345 L .16439 .70097 L p .707 .577 .707 r
F P
0 g
s
.1688 .72466 m .1666 .74376 L .16009 .74238 L p .707 .577 .707 r
F P
0 g
s
.16009 .74238 m .16229 .72328 L .1688 .72466 L p .707 .577 .707 r
F P
0 g
s
.33083 .62315 m .32735 .57064 L .34847 .57932 L p .707 .577 .707 r
F P
0 g
s
.18377 .58421 m .18725 .63671 L .17104 .64892 L p .707 .577 .707 r
F P
0 g
s
.18725 .63671 m .18377 .58421 L .20768 .57419 L p .707 .577 .707 r
F P
0 g
s
.61379 .26337 m .6189 .76165 L .58918 .75202 L p .707 .577 .707 r
F P
0 g
s
.58918 .75202 m .58406 .25374 L .61379 .26337 L p .707 .577 .707 r
F P
0 g
s
.17147 .69345 m .17186 .65614 L .18823 .64962 L p .707 .577 .707 r
F P
0 g
s
.32735 .57064 m .33083 .62315 L .30335 .61799 L p .707 .577 .707 r
F P
0 g
s
.30335 .61799 m .29986 .56548 L .32735 .57064 L p .707 .577 .707 r
F P
0 g
s
.18823 .64962 m .18783 .68692 L .17147 .69345 L p .707 .577 .707 r
F P
0 g
s
.1846 .72704 m .1824 .74615 L .1666 .74376 L p .707 .577 .707 r
F P
0 g
s
.1666 .74376 m .1688 .72466 L .1846 .72704 L p .707 .577 .707 r
F P
0 g
s
.38092 .26105 m .38603 .75933 L .36293 .77086 L p .707 .577 .707 r
F P
0 g
s
.38603 .75933 m .38092 .26105 L .41487 .25205 L p .707 .577 .707 r
F P
0 g
s
.21116 .6267 m .20768 .57419 L .23695 .56735 L p .707 .577 .707 r
F P
0 g
s
.20768 .57419 m .21116 .6267 L .18725 .63671 L p .707 .577 .707 r
F P
0 g
s
.29986 .56548 m .30335 .61799 L .2722 .61686 L p .707 .577 .707 r
F P
0 g
s
.2722 .61686 m .26871 .56435 L .29986 .56548 L p .707 .577 .707 r
F P
0 g
s
.24043 .61986 m .23695 .56735 L .26871 .56435 L p .707 .577 .707 r
F P
0 g
s
.23695 .56735 m .24043 .61986 L .21116 .6267 L p .707 .577 .707 r
F P
0 g
s
.18783 .68692 m .18823 .64962 L .21228 .64473 L p .707 .577 .707 r
F P
0 g
s
.26871 .56435 m .2722 .61686 L .24043 .61986 L p .707 .577 .707 r
F P
0 g
s
.34864 .74576 m .34644 .76486 L .32512 .76289 L p .707 .577 .707 r
F P
0 g
s
.32512 .76289 m .32732 .74379 L .34864 .74576 L p .707 .577 .707 r
F P
0 g
s
.58406 .25374 m .58918 .75202 L .55041 .74564 L p .707 .577 .707 r
F P
0 g
s
.55041 .74564 m .5453 .24736 L .58406 .25374 L p .707 .577 .707 r
F P
0 g
s
.21228 .64473 m .21188 .68203 L .18783 .68692 L p .707 .577 .707 r
F P
0 g
s
.20814 .73019 m .20594 .74929 L .1824 .74615 L p .707 .577 .707 r
F P
0 g
s
.1824 .74615 m .1846 .72704 L .20814 .73019 L p .707 .577 .707 r
F P
0 g
s
.33212 .64785 m .33172 .68516 L .30426 .6809 L p .707 .577 .707 r
F P
0 g
s
.30426 .6809 m .30466 .6436 L .33212 .64785 L p .707 .577 .707 r
F P
0 g
s
.41998 .75033 m .41487 .25205 L .45635 .24647 L p .707 .577 .707 r
F P
0 g
s
.41487 .25205 m .41998 .75033 L .38603 .75933 L p .707 .577 .707 r
F P
0 g
s
.21188 .68203 m .21228 .64473 L .24165 .64195 L p .707 .577 .707 r
F P
0 g
s
.73982 .68977 m .73634 .63726 L .70519 .63613 L p .707 .577 .707 r
F P
0 g
s
.73634 .63726 m .73982 .68977 L .77159 .68677 L p .707 .577 .707 r
F P
0 g
s
.77159 .68677 m .7681 .63426 L .73634 .63726 L p .707 .577 .707 r
F P
0 g
s
.5453 .24736 m .55041 .74564 L .5064 .74314 L p .707 .577 .707 r
F P
0 g
s
.5064 .74314 m .50129 .24485 L .5453 .24736 L p .707 .577 .707 r
F P
0 g
s
.32732 .74379 m .32512 .76289 L .29757 .76004 L p .707 .577 .707 r
F P
0 g
s
.29757 .76004 m .29977 .74094 L .32732 .74379 L p .707 .577 .707 r
F P
0 g
s
.7681 .63426 m .77159 .68677 L .80086 .67992 L p .707 .577 .707 r
F P
0 g
s
.80086 .67992 m .79737 .62742 L .7681 .63426 L p .707 .577 .707 r
F P
0 g
s
.30466 .6436 m .30426 .6809 L .27309 .67887 L p .707 .577 .707 r
F P
0 g
s
.27309 .67887 m .27349 .64156 L .30466 .6436 L p .707 .577 .707 r
F P
0 g
s
.24165 .64195 m .24126 .67926 L .21188 .68203 L p .707 .577 .707 r
F P
0 g
s
.46146 .74475 m .45635 .24647 L .50129 .24485 L p .707 .577 .707 r
F P
0 g
s
.45635 .24647 m .46146 .74475 L .41998 .75033 L p .707 .577 .707 r
F P
0 g
s
.24126 .67926 m .24165 .64195 L .27349 .64156 L p .707 .577 .707 r
F P
0 g
s
.23712 .73379 m .23492 .75289 L .20594 .74929 L p .707 .577 .707 r
F P
0 g
s
.20594 .74929 m .20814 .73019 L .23712 .73379 L p .707 .577 .707 r
F P
0 g
s
.70867 .68863 m .70519 .63613 L .67771 .63097 L p .707 .577 .707 r
F P
0 g
s
.70519 .63613 m .70867 .68863 L .73982 .68977 L p .707 .577 .707 r
F P
0 g
s
.27349 .64156 m .27309 .67887 L .24126 .67926 L p .707 .577 .707 r
F P
0 g
s
.50129 .24485 m .5064 .74314 L .46146 .74475 L p .707 .577 .707 r
F P
0 g
s
.79737 .62742 m .80086 .67992 L .82477 .66991 L p .707 .577 .707 r
F P
0 g
s
.82477 .66991 m .82129 .6174 L .79737 .62742 L p .707 .577 .707 r
F P
0 g
s
.29977 .74094 m .29757 .76004 L .26649 .7566 L p .707 .577 .707 r
F P
0 g
s
.26649 .7566 m .26869 .73749 L .29977 .74094 L p .707 .577 .707 r
F P
0 g
s
.26869 .73749 m .26649 .7566 L .23492 .75289 L p .707 .577 .707 r
F P
0 g
s
.23492 .75289 m .23712 .73379 L .26869 .73749 L p .707 .577 .707 r
F P
0 g
s
.68119 .68347 m .67771 .63097 L .65658 .62229 L p .707 .577 .707 r
F P
0 g
s
.67771 .63097 m .68119 .68347 L .70867 .68863 L p .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .73886 .74111 L .71576 .73854 L p .707 .577 .707 r
F P
0 g
s
.71576 .73854 m .70778 .73766 L p .72435 .75059 L .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .71576 .73854 L .72435 .75059 L .707 .577 .707 r
F
.70778 .73766 m .70558 .75676 L .73666 .76021 L p F P
0 g
s
.70558 .75676 m .70778 .73766 L .68686 .7355 L p .707 .577 .707 r
F P
0 g
s
.68686 .7355 m .68023 .73481 L p .69196 .74497 L .707 .577 .707 r
F P
0 g
s
.70558 .75676 m .68686 .7355 L .69196 .74497 L .707 .577 .707 r
F
.68023 .73481 m .67803 .75392 L .70558 .75676 L p F P
0 g
s
.67803 .75392 m .68023 .73481 L .66375 .73329 L p .707 .577 .707 r
F P
0 g
s
.66375 .73329 m .65892 .73284 L p .66583 .74046 L .707 .577 .707 r
F P
0 g
s
.67803 .75392 m .66375 .73329 L .66583 .74046 L .707 .577 .707 r
F
.65892 .73284 m .65672 .75194 L .67803 .75392 L p F P
0 g
s
.6601 .73627 m .66026 .72118 L p .6479 .69168 L .707 .577 .707 r
F P
0 g
s
.66026 .72118 m .66049 .69896 L .65251 .69435 L p .707 .577 .707 r
F P
0 g
s
.65251 .69435 m .6479 .69168 L p .66026 .72118 L .707 .577 .707 r
F P
0 g
s
.68116 .74234 m .68134 .72523 L p .66049 .69896 L .707 .577 .707 r
F P
0 g
s
.68134 .72523 m .68155 .70503 L .66844 .70125 L p .707 .577 .707 r
F P
0 g
s
.66844 .70125 m .66049 .69896 L p .68134 .72523 L .707 .577 .707 r
F P
0 g
s
.70861 .74659 m .7088 .72879 L p .68155 .70503 L .707 .577 .707 r
F P
0 g
s
.7088 .72879 m .70901 .70929 L .69315 .70683 L p .707 .577 .707 r
F P
0 g
s
.69315 .70683 m .68155 .70503 L p .7088 .72879 L .707 .577 .707 r
F P
0 g
s
.73886 .74111 m .73666 .76021 L .76394 .76341 L p .707 .577 .707 r
F P
0 g
s
.76394 .76341 m .76824 .76391 L p .75882 .7566 L .707 .577 .707 r
F P
0 g
s
.75882 .7566 m .73886 .74111 L .76394 .76341 L .707 .577 .707 r
F
.76824 .76391 m .77044 .74481 L .73886 .74111 L p F P
0 g
s
.73979 .74863 m .73997 .73152 L p .70901 .70929 L .707 .577 .707 r
F P
0 g
s
.73997 .73152 m .74018 .71132 L .72399 .71027 L p .707 .577 .707 r
F P
0 g
s
.72399 .71027 m .70901 .70929 L p .73997 .73152 L .707 .577 .707 r
F P
0 g
s
.77044 .74481 m .76824 .76391 L .79307 .767 L p .707 .577 .707 r
F P
0 g
s
.79307 .767 m .79721 .76751 L p .78903 .76058 L .707 .577 .707 r
F P
0 g
s
.78903 .76058 m .77044 .74481 L .79307 .767 L .707 .577 .707 r
F
.79721 .76751 m .79941 .74841 L .77044 .74481 L p F P
0 g
s
.77162 .74824 m .77178 .73315 L p .74018 .71132 L .707 .577 .707 r
F P
0 g
s
.77178 .73315 m .77201 .71093 L .75791 .71111 L p .707 .577 .707 r
F P
0 g
s
.75791 .71111 m .74018 .71132 L p .77178 .73315 L .707 .577 .707 r
F P
0 g
s
.74018 .71132 m .73979 .74863 L .77162 .74824 L p .707 .577 .707 r
F P
0 g
s
.82129 .6174 m .82477 .66991 L .84098 .6577 L p .707 .577 .707 r
F P
0 g
s
.84098 .6577 m .8375 .6052 L .82129 .6174 L p .707 .577 .707 r
F P
0 g
s
.77201 .71093 m .77162 .74824 L .801 .74546 L p .707 .577 .707 r
F P
0 g
s
.801 .74546 m .80139 .70816 L .77201 .71093 L p .707 .577 .707 r
F P
0 g
s
.70901 .70929 m .70861 .74659 L .73979 .74863 L p .707 .577 .707 r
F P
0 g
s
.66006 .6748 m .65658 .62229 L .64388 .61094 L p .707 .577 .707 r
F P
0 g
s
.65658 .62229 m .66006 .6748 L .68119 .68347 L p .707 .577 .707 r
F P
0 g
s
.80139 .70816 m .801 .74546 L .82505 .74057 L p .707 .577 .707 r
F P
0 g
s
.82505 .74057 m .82544 .70327 L .80139 .70816 L p .707 .577 .707 r
F P
0 g
s
.68155 .70503 m .68116 .74234 L .70861 .74659 L p .707 .577 .707 r
F P
0 g
s
.79941 .74841 m .79721 .76751 L .82075 .77066 L p .707 .577 .707 r
F P
0 g
s
.82075 .77066 m .82295 .75156 L .79941 .74841 L p .707 .577 .707 r
F P
0 g
s
.8375 .6052 m .84098 .6577 L .84791 .6445 L p .707 .577 .707 r
F P
0 g
s
.84791 .6445 m .84443 .59199 L .8375 .6052 L p .707 .577 .707 r
F P
0 g
s
.66049 .69896 m .6601 .73627 L .68116 .74234 L p .707 .577 .707 r
F P
0 g
s
.82544 .70327 m .82505 .74057 L .84141 .73405 L p .707 .577 .707 r
F P
0 g
s
.84141 .73405 m .84181 .69674 L .82544 .70327 L p .707 .577 .707 r
F P
0 g
s
.64388 .61094 m .64736 .66345 L .66006 .6748 L p .707 .577 .707 r
F P
0 g
s
.64736 .66345 m .64388 .61094 L .64084 .59803 L p .707 .577 .707 r
F P
0 g
s
.82295 .75156 m .82075 .77066 L .83655 .77304 L p .707 .577 .707 r
F P
0 g
s
.83655 .77304 m .83875 .75394 L .82295 .75156 L p .707 .577 .707 r
F P
0 g
s
.64592 .73194 m .64372 .75104 L .65672 .75194 L p .707 .577 .707 r
F P
0 g
s
.65672 .75194 m .65892 .73284 L .64592 .73194 L p .707 .577 .707 r
F P
0 g
s
.84443 .59199 m .84791 .6445 L .84487 .63159 L p .707 .577 .707 r
F P
0 g
s
.84487 .63159 m .84139 .57909 L .84443 .59199 L p .707 .577 .707 r
F P
0 g
s
.6479 .69168 m .6475 .72899 L .6601 .73627 L p .707 .577 .707 r
F P
0 g
s
.84181 .69674 m .84141 .73405 L .84849 .72653 L p .707 .577 .707 r
F P
0 g
s
.84849 .72653 m .84889 .68922 L .84181 .69674 L p .707 .577 .707 r
F P
0 g
s
.64084 .59803 m .64432 .65054 L .64736 .66345 L p .707 .577 .707 r
F P
0 g
s
.83875 .75394 m .83655 .77304 L .84306 .77442 L p .707 .577 .707 r
F P
0 g
s
.84306 .77442 m .84526 .75532 L .83875 .75394 L p .707 .577 .707 r
F P
0 g
s
.64432 .65054 m .64084 .59803 L .64777 .58483 L p .707 .577 .707 r
F P
0 g
s
.6475 .72899 m .6479 .69168 L .645 .6839 L p .707 .577 .707 r
F P
0 g
s
.6425 .73219 m .6403 .75129 L .64372 .75104 L p .707 .577 .707 r
F P
0 g
s
.64372 .75104 m .64592 .73194 L .6425 .73219 L p .707 .577 .707 r
F P
0 g
s
.84139 .57909 m .84487 .63159 L .83217 .62024 L p .707 .577 .707 r
F P
0 g
s
.83217 .62024 m .82869 .56774 L .84139 .57909 L p .707 .577 .707 r
F P
0 g
s
.645 .6839 m .6446 .72121 L .6475 .72899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84889 .68922 m .84849 .72653 L .84559 .71875 L p .707 .577 .707 r
F P
0 g
s
.84559 .71875 m .84599 .68144 L .84889 .68922 L p .707 .577 .707 r
F P
0 g
s
.64777 .58483 m .65125 .63734 L .64432 .65054 L p .707 .577 .707 r
F P
0 g
s
.65125 .63734 m .64777 .58483 L .66398 .57262 L p .707 .577 .707 r
F P
0 g
s
.84526 .75532 m .84306 .77442 L .83965 .77468 L p .707 .577 .707 r
F P
0 g
s
.39681 .65295 m .39333 .60044 L .36218 .59931 L p .707 .577 .707 r
F P
0 g
s
.39333 .60044 m .39681 .65295 L .42858 .64995 L p .707 .577 .707 r
F P
0 g
s
.42858 .64995 m .42509 .59744 L .39333 .60044 L p .707 .577 .707 r
F P
0 g
s
.83965 .77468 m .84185 .75557 L .84526 .75532 L p .707 .577 .707 r
F P
0 g
s
.42509 .59744 m .42858 .64995 L .45785 .64311 L p .707 .577 .707 r
F P
0 g
s
.45785 .64311 m .45436 .5906 L .42509 .59744 L p .707 .577 .707 r
F P
0 g
s
.6446 .72121 m .645 .6839 L .65208 .67638 L p .707 .577 .707 r
F P
0 g
s
.36566 .65182 m .36218 .59931 L .3347 .59415 L p .707 .577 .707 r
F P
0 g
s
.36218 .59931 m .36566 .65182 L .39681 .65295 L p .707 .577 .707 r
F P
0 g
s
.82869 .56774 m .83217 .62024 L .81104 .61157 L p .707 .577 .707 r
F P
0 g
s
.81104 .61157 m .80756 .55906 L .82869 .56774 L p .707 .577 .707 r
F P
0 g
s
.64902 .73357 m .64682 .75268 L .6403 .75129 L p .707 .577 .707 r
F P
0 g
s
.6403 .75129 m .6425 .73219 L .64902 .73357 L p .707 .577 .707 r
F P
0 g
s
.45436 .5906 m .45785 .64311 L .48176 .63309 L p .707 .577 .707 r
F P
0 g
s
.48176 .63309 m .47828 .58059 L .45436 .5906 L p .707 .577 .707 r
F P
0 g
s
.65208 .67638 m .65168 .71369 L .6446 .72121 L p .707 .577 .707 r
F P
0 g
s
.66398 .57262 m .66746 .62513 L .65125 .63734 L p .707 .577 .707 r
F P
0 g
s
.84599 .68144 m .84559 .71875 L .833 .71147 L p .707 .577 .707 r
F P
0 g
s
.833 .71147 m .83339 .67416 L .84599 .68144 L p .707 .577 .707 r
F P
0 g
s
.66746 .62513 m .66398 .57262 L .68789 .56261 L p .707 .577 .707 r
F P
0 g
s
.33818 .64666 m .3347 .59415 L .31357 .58547 L p .707 .577 .707 r
F P
0 g
s
.3347 .59415 m .33818 .64666 L .36566 .65182 L p .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .39585 .70429 L .37275 .70173 L p .707 .577 .707 r
F P
0 g
s
.37275 .70173 m .36477 .70085 L p .38134 .71378 L .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .37275 .70173 L .38134 .71378 L .707 .577 .707 r
F
.36477 .70085 m .36257 .71995 L .39365 .72339 L p F P
0 g
s
.36257 .71995 m .36477 .70085 L .34385 .69868 L p .707 .577 .707 r
F P
0 g
s
.34385 .69868 m .33722 .698 L p .34895 .70815 L .707 .577 .707 r
F P
0 g
s
.36257 .71995 m .34385 .69868 L .34895 .70815 L .707 .577 .707 r
F
.33722 .698 m .33502 .7171 L .36257 .71995 L p F P
0 g
s
.33502 .7171 m .33722 .698 L .32074 .69647 L p .707 .577 .707 r
F P
0 g
s
.32074 .69647 m .31591 .69602 L p .32282 .70364 L .707 .577 .707 r
F P
0 g
s
.33502 .7171 m .32074 .69647 L .32282 .70364 L .707 .577 .707 r
F
.31591 .69602 m .31371 .71513 L .33502 .7171 L p F P
0 g
s
.31709 .69945 m .31725 .68437 L p .30489 .65487 L .707 .577 .707 r
F P
0 g
s
.31725 .68437 m .31748 .66215 L .30949 .65753 L p .707 .577 .707 r
F P
0 g
s
.30949 .65753 m .30489 .65487 L p .31725 .68437 L .707 .577 .707 r
F P
0 g
s
.33815 .70552 m .33833 .68841 L p .31748 .66215 L .707 .577 .707 r
F P
0 g
s
.33833 .68841 m .33854 .66821 L .32542 .66444 L p .707 .577 .707 r
F P
0 g
s
.32542 .66444 m .31748 .66215 L p .33833 .68841 L .707 .577 .707 r
F P
0 g
s
.3656 .70978 m .36579 .69197 L p .33854 .66821 L .707 .577 .707 r
F P
0 g
s
.36579 .69197 m .366 .67247 L .35014 .67001 L p .707 .577 .707 r
F P
0 g
s
.35014 .67001 m .33854 .66821 L p .36579 .69197 L .707 .577 .707 r
F P
0 g
s
.39585 .70429 m .39365 .72339 L .42093 .72659 L p .707 .577 .707 r
F P
0 g
s
.42093 .72659 m .42523 .7271 L p .41581 .71979 L .707 .577 .707 r
F P
0 g
s
.41581 .71979 m .39585 .70429 L .42093 .72659 L .707 .577 .707 r
F
.42523 .7271 m .42743 .70799 L .39585 .70429 L p F P
0 g
s
.39678 .71181 m .39696 .69471 L p .366 .67247 L .707 .577 .707 r
F P
0 g
s
.39696 .69471 m .39717 .67451 L .38098 .67345 L p .707 .577 .707 r
F P
0 g
s
.38098 .67345 m .366 .67247 L p .39696 .69471 L .707 .577 .707 r
F P
0 g
s
.42743 .70799 m .42523 .7271 L .45006 .73018 L p .707 .577 .707 r
F P
0 g
s
.45006 .73018 m .4542 .7307 L p .44602 .72376 L .707 .577 .707 r
F P
0 g
s
.44602 .72376 m .42743 .70799 L .45006 .73018 L .707 .577 .707 r
F
.4542 .7307 m .4564 .71159 L .42743 .70799 L p F P
0 g
s
.42861 .71142 m .42877 .69634 L p .39717 .67451 L .707 .577 .707 r
F P
0 g
s
.42877 .69634 m .429 .67412 L .4149 .67429 L p .707 .577 .707 r
F P
0 g
s
.4149 .67429 m .39717 .67451 L p .42877 .69634 L .707 .577 .707 r
F P
0 g
s
.39717 .67451 m .39678 .71181 L .42861 .71142 L p .707 .577 .707 r
F P
0 g
s
.80756 .55906 m .81104 .61157 L .78356 .60641 L p .707 .577 .707 r
F P
0 g
s
.78356 .60641 m .78008 .5539 L .80756 .55906 L p .707 .577 .707 r
F P
0 g
s
.84185 .75557 m .83965 .77468 L .82665 .77377 L p .707 .577 .707 r
F P
0 g
s
.47828 .58059 m .48176 .63309 L .49797 .62089 L p .707 .577 .707 r
F P
0 g
s
.49797 .62089 m .49449 .56838 L .47828 .58059 L p .707 .577 .707 r
F P
0 g
s
.82665 .77377 m .82885 .75467 L .84185 .75557 L p .707 .577 .707 r
F P
0 g
s
.429 .67412 m .42861 .71142 L .45799 .70865 L p .707 .577 .707 r
F P
0 g
s
.45799 .70865 m .45838 .67134 L .429 .67412 L p .707 .577 .707 r
F P
0 g
s
.65168 .71369 m .65208 .67638 L .66844 .66986 L p .707 .577 .707 r
F P
0 g
s
.366 .67247 m .3656 .70978 L .39678 .71181 L p .707 .577 .707 r
F P
0 g
s
.69138 .61512 m .68789 .56261 L .71717 .55577 L p .707 .577 .707 r
F P
0 g
s
.68789 .56261 m .69138 .61512 L .66746 .62513 L p .707 .577 .707 r
F P
0 g
s
.66482 .73595 m .66262 .75506 L .64682 .75268 L p .707 .577 .707 r
F P
0 g
s
.64682 .75268 m .64902 .73357 L .66482 .73595 L p .707 .577 .707 r
F P
0 g
s
.66844 .66986 m .66805 .70716 L .65168 .71369 L p .707 .577 .707 r
F P
0 g
s
.31705 .63798 m .31357 .58547 L .30087 .57413 L p .707 .577 .707 r
F P
0 g
s
.31357 .58547 m .31705 .63798 L .33818 .64666 L p .707 .577 .707 r
F P
0 g
s
.45838 .67134 m .45799 .70865 L .48204 .70376 L p .707 .577 .707 r
F P
0 g
s
.48204 .70376 m .48243 .66645 L .45838 .67134 L p .707 .577 .707 r
F P
0 g
s
.78008 .5539 m .78356 .60641 L .75241 .60527 L p .707 .577 .707 r
F P
0 g
s
.75241 .60527 m .74893 .55277 L .78008 .5539 L p .707 .577 .707 r
F P
0 g
s
.33854 .66821 m .33815 .70552 L .3656 .70978 L p .707 .577 .707 r
F P
0 g
s
.83339 .67416 m .833 .71147 L .81194 .7054 L p .707 .577 .707 r
F P
0 g
s
.81194 .7054 m .81233 .6681 L .83339 .67416 L p .707 .577 .707 r
F P
0 g
s
.4564 .71159 m .4542 .7307 L .47774 .73384 L p .707 .577 .707 r
F P
0 g
s
.72065 .60827 m .71717 .55577 L .74893 .55277 L p .707 .577 .707 r
F P
0 g
s
.71717 .55577 m .72065 .60827 L .69138 .61512 L p .707 .577 .707 r
F P
0 g
s
.47774 .73384 m .47994 .71474 L .4564 .71159 L p .707 .577 .707 r
F P
0 g
s
.74893 .55277 m .75241 .60527 L .72065 .60827 L p .707 .577 .707 r
F P
0 g
s
.49449 .56838 m .49797 .62089 L .5049 .60768 L p .707 .577 .707 r
F P
0 g
s
.5049 .60768 m .50142 .55518 L .49449 .56838 L p .707 .577 .707 r
F P
0 g
s
.66805 .70716 m .66844 .66986 L .69249 .66497 L p .707 .577 .707 r
F P
0 g
s
.82885 .75467 m .82665 .77377 L .80533 .7718 L p .707 .577 .707 r
F P
0 g
s
.80533 .7718 m .80753 .7527 L .82885 .75467 L p .707 .577 .707 r
F P
0 g
s
.31748 .66215 m .31709 .69945 L .33815 .70552 L p .707 .577 .707 r
F P
0 g
s
.48243 .66645 m .48204 .70376 L .4984 .69723 L p .707 .577 .707 r
F P
0 g
s
.4984 .69723 m .4988 .65993 L .48243 .66645 L p .707 .577 .707 r
F P
0 g
s
.30087 .57413 m .30435 .62663 L .31705 .63798 L p .707 .577 .707 r
F P
0 g
s
.68836 .7391 m .68616 .7582 L .66262 .75506 L p .707 .577 .707 r
F P
0 g
s
.66262 .75506 m .66482 .73595 L .68836 .7391 L p .707 .577 .707 r
F P
0 g
s
.69249 .66497 m .69209 .70227 L .66805 .70716 L p .707 .577 .707 r
F P
0 g
s
.30435 .62663 m .30087 .57413 L .29783 .56122 L p .707 .577 .707 r
F P
0 g
s
.47994 .71474 m .47774 .73384 L .49354 .73622 L p .707 .577 .707 r
F P
0 g
s
.49354 .73622 m .49574 .71712 L .47994 .71474 L p .707 .577 .707 r
F P
0 g
s
.81233 .6681 m .81194 .7054 L .78448 .70114 L p .707 .577 .707 r
F P
0 g
s
.78448 .70114 m .78487 .66384 L .81233 .6681 L p .707 .577 .707 r
F P
0 g
s
.69209 .70227 m .69249 .66497 L .72187 .66219 L p .707 .577 .707 r
F P
0 g
s
.3029 .69512 m .3007 .71422 L .31371 .71513 L p .707 .577 .707 r
F P
0 g
s
.31371 .71513 m .31591 .69602 L .3029 .69512 L p .707 .577 .707 r
F P
0 g
s
.80753 .7527 m .80533 .7718 L .77779 .76895 L p .707 .577 .707 r
F P
0 g
s
.50142 .55518 m .5049 .60768 L .50186 .59478 L p .707 .577 .707 r
F P
0 g
s
.50186 .59478 m .49838 .54227 L .50142 .55518 L p .707 .577 .707 r
F P
0 g
s
.77779 .76895 m .77999 .74985 L .80753 .7527 L p .707 .577 .707 r
F P
0 g
s
.30489 .65487 m .30449 .69217 L .31709 .69945 L p .707 .577 .707 r
F P
0 g
s
.78487 .66384 m .78448 .70114 L .75331 .69911 L p .707 .577 .707 r
F P
0 g
s
.75331 .69911 m .7537 .6618 L .78487 .66384 L p .707 .577 .707 r
F P
0 g
s
.72187 .66219 m .72147 .6995 L .69209 .70227 L p .707 .577 .707 r
F P
0 g
s
.71733 .7427 m .71513 .7618 L .68616 .7582 L p .707 .577 .707 r
F P
0 g
s
.68616 .7582 m .68836 .7391 L .71733 .7427 L p .707 .577 .707 r
F P
0 g
s
.4988 .65993 m .4984 .69723 L .50548 .68971 L p .707 .577 .707 r
F P
0 g
s
.50548 .68971 m .50588 .65241 L .4988 .65993 L p .707 .577 .707 r
F P
0 g
s
.72147 .6995 m .72187 .66219 L .7537 .6618 L p .707 .577 .707 r
F P
0 g
s
.29783 .56122 m .30131 .61373 L .30435 .62663 L p .707 .577 .707 r
F P
0 g
s
.7537 .6618 m .75331 .69911 L .72147 .6995 L p .707 .577 .707 r
F P
0 g
s
.77999 .74985 m .77779 .76895 L .7467 .76551 L p .707 .577 .707 r
F P
0 g
s
.49574 .71712 m .49354 .73622 L .50005 .73761 L p .707 .577 .707 r
F P
0 g
s
.7467 .76551 m .7489 .7464 L .77999 .74985 L p .707 .577 .707 r
F P
0 g
s
.50005 .73761 m .50225 .71851 L .49574 .71712 L p .707 .577 .707 r
F P
0 g
s
.30131 .61373 m .29783 .56122 L .30476 .54802 L p .707 .577 .707 r
F P
0 g
s
.7489 .7464 m .7467 .76551 L .71513 .7618 L p .707 .577 .707 r
F P
0 g
s
.71513 .7618 m .71733 .7427 L .7489 .7464 L p .707 .577 .707 r
F P
0 g
s
.30449 .69217 m .30489 .65487 L .30199 .64709 L p .707 .577 .707 r
F P
0 g
s
.29949 .69537 m .29729 .71448 L .3007 .71422 L p .707 .577 .707 r
F P
0 g
s
.3007 .71422 m .3029 .69512 L .29949 .69537 L p .707 .577 .707 r
F P
0 g
s
.49838 .54227 m .50186 .59478 L .48916 .58343 L p .707 .577 .707 r
F P
0 g
s
.48916 .58343 m .48568 .53092 L .49838 .54227 L p .707 .577 .707 r
F P
0 g
s
.30199 .64709 m .30159 .68439 L .30449 .69217 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50588 .65241 m .50548 .68971 L .50258 .68193 L p .707 .577 .707 r
F P
0 g
s
.50258 .68193 m .50298 .64463 L .50588 .65241 L p .707 .577 .707 r
F P
0 g
s
.30476 .54802 m .30824 .60052 L .30131 .61373 L p .707 .577 .707 r
F P
0 g
s
.30824 .60052 m .30476 .54802 L .32097 .53581 L p .707 .577 .707 r
F P
0 g
s
.50225 .71851 m .50005 .73761 L .49664 .73786 L p .707 .577 .707 r
F P
0 g
s
.49664 .73786 m .49884 .71876 L .50225 .71851 L p .707 .577 .707 r
F P
0 g
s
.30159 .68439 m .30199 .64709 L .30906 .63957 L p .707 .577 .707 r
F P
0 g
s
.48568 .53092 m .48916 .58343 L .46803 .57475 L p .707 .577 .707 r
F P
0 g
s
.46803 .57475 m .46455 .52224 L .48568 .53092 L p .707 .577 .707 r
F P
0 g
s
.30601 .69676 m .30381 .71586 L .29729 .71448 L p .707 .577 .707 r
F P
0 g
s
.29729 .71448 m .29949 .69537 L .30601 .69676 L p .707 .577 .707 r
F P
0 g
s
.30906 .63957 m .30867 .67687 L .30159 .68439 L p .707 .577 .707 r
F P
0 g
s
.32097 .53581 m .32445 .58832 L .30824 .60052 L p .707 .577 .707 r
F P
0 g
s
.50298 .64463 m .50258 .68193 L .48999 .67465 L p .707 .577 .707 r
F P
0 g
s
.48999 .67465 m .49038 .63735 L .50298 .64463 L p .707 .577 .707 r
F P
0 g
s
.32445 .58832 m .32097 .53581 L .34488 .52579 L p .707 .577 .707 r
F P
0 g
s
.46455 .52224 m .46803 .57475 L .44055 .56959 L p .707 .577 .707 r
F P
0 g
s
.44055 .56959 m .43707 .51708 L .46455 .52224 L p .707 .577 .707 r
F P
0 g
s
.49884 .71876 m .49664 .73786 L .48364 .73696 L p .707 .577 .707 r
F P
0 g
s
.48364 .73696 m .48584 .71785 L .49884 .71876 L p .707 .577 .707 r
F P
0 g
s
.30867 .67687 m .30906 .63957 L .32543 .63304 L p .707 .577 .707 r
F P
0 g
s
.34837 .5783 m .34488 .52579 L .37415 .51895 L p .707 .577 .707 r
F P
0 g
s
.34488 .52579 m .34837 .5783 L .32445 .58832 L p .707 .577 .707 r
F P
0 g
s
.32181 .69914 m .31961 .71824 L .30381 .71586 L p .707 .577 .707 r
F P
0 g
s
.30381 .71586 m .30601 .69676 L .32181 .69914 L p .707 .577 .707 r
F P
0 g
s
.32543 .63304 m .32503 .67035 L .30867 .67687 L p .707 .577 .707 r
F P
0 g
s
.43707 .51708 m .44055 .56959 L .4094 .56846 L p .707 .577 .707 r
F P
0 g
s
.4094 .56846 m .40592 .51595 L .43707 .51708 L p .707 .577 .707 r
F P
0 g
s
.49038 .63735 m .48999 .67465 L .46893 .66859 L p .707 .577 .707 r
F P
0 g
s
.46893 .66859 m .46932 .63128 L .49038 .63735 L p .707 .577 .707 r
F P
0 g
s
.37764 .57146 m .37415 .51895 L .40592 .51595 L p .707 .577 .707 r
F P
0 g
s
.37415 .51895 m .37764 .57146 L .34837 .5783 L p .707 .577 .707 r
F P
0 g
s
.40592 .51595 m .4094 .56846 L .37764 .57146 L p .707 .577 .707 r
F P
0 g
s
.32503 .67035 m .32543 .63304 L .34948 .62815 L p .707 .577 .707 r
F P
0 g
s
.48584 .71785 m .48364 .73696 L .46232 .73498 L p .707 .577 .707 r
F P
0 g
s
.46232 .73498 m .46452 .71588 L .48584 .71785 L p .707 .577 .707 r
F P
0 g
s
.34535 .70228 m .34315 .72139 L .31961 .71824 L p .707 .577 .707 r
F P
0 g
s
.31961 .71824 m .32181 .69914 L .34535 .70228 L p .707 .577 .707 r
F P
0 g
s
.34948 .62815 m .34908 .66546 L .32503 .67035 L p .707 .577 .707 r
F P
0 g
s
.46932 .63128 m .46893 .66859 L .44147 .66433 L p .707 .577 .707 r
F P
0 g
s
.44147 .66433 m .44186 .62702 L .46932 .63128 L p .707 .577 .707 r
F P
0 g
s
.34908 .66546 m .34948 .62815 L .37886 .62538 L p .707 .577 .707 r
F P
0 g
s
.46452 .71588 m .46232 .73498 L .43478 .73214 L p .707 .577 .707 r
F P
0 g
s
.43478 .73214 m .43698 .71303 L .46452 .71588 L p .707 .577 .707 r
F P
0 g
s
.44186 .62702 m .44147 .66433 L .4103 .66229 L p .707 .577 .707 r
F P
0 g
s
.4103 .66229 m .41069 .62499 L .44186 .62702 L p .707 .577 .707 r
F P
0 g
s
.37886 .62538 m .37846 .66268 L .34908 .66546 L p .707 .577 .707 r
F P
0 g
s
.37432 .70588 m .37212 .72499 L .34315 .72139 L p .707 .577 .707 r
F P
0 g
s
.34315 .72139 m .34535 .70228 L .37432 .70588 L p .707 .577 .707 r
F P
0 g
s
.37846 .66268 m .37886 .62538 L .41069 .62499 L p .707 .577 .707 r
F P
0 g
s
.41069 .62499 m .4103 .66229 L .37846 .66268 L p .707 .577 .707 r
F P
0 g
s
.43698 .71303 m .43478 .73214 L .40369 .72869 L p .707 .577 .707 r
F P
0 g
s
.40369 .72869 m .40589 .70959 L .43698 .71303 L p .707 .577 .707 r
F P
0 g
s
.40589 .70959 m .40369 .72869 L .37212 .72499 L p .707 .577 .707 r
F P
0 g
s
.37212 .72499 m .37432 .70588 L .40589 .70959 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo3@00R7oo001lOol<0006FUH00`00FUIJEP04FUH9001oOol007Aoo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Uoo`00LGoo0`0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01UYF1000MGoo001^Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001aOol006]oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<006io
o`00JGoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P00KGoo001WOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000
Jgoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000JWoo001TOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Moo`00Hgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001W
Ool0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo
001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0
069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001R
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00HWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001ROol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069oo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000IJEP03
001JEP0000P000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF0000Igoo001SOol01000FUIJEP000UYF1P0015YF00<005YFFUH00UYF2000
0UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH0001WOol006=oo`03001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYF
FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
06Moo`00HGoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001OOol20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005eo
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Moo`00Fgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001IOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06
001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001F
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001EOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000JOol?000nOol005Aoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Aoo`H000AJEP03001JEUYF00IJEP03001J
EP0000<003Yoo`00E7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0047oo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo0018Ool=00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0049oo`H000AJEP03
001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000Qoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP80035oo`00?Woo100000=JEP00FUH01eYF00<005YFFUH01EYF00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF00<005YFFUH01UYF10000UYF00<005YF
FUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
1Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00<7oo000jOol40005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH01UYF00<005YFFUH02EYF1@0015YF
00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Goo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002ioo`00>7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEUYF00=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF009JEP<00004FUH005YFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20004Ool00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000fOol20003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00@005YFFUIJEP800005FUH005YFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000UYF0P000UYF0P0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00@005YFFUH000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH01000FUH000000eYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP@0
0003FUH005YF00=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P001EYF00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;7oo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20002FUH30002FUH01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00UYF100035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002aoo`00;goo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH0
15YF1`001UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00
FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00@0
01Moo`D000EJEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP05001JEUYFFUH0
0005FUH4000POol20003FUH01@00FUIJEUYF0000;7oo000]Ool00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF
00000eYF10008goo0`0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH6000<Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01P00FUIJEUYF
001JEP8000=JEP80021oo`800003FUH005YF008000=JEP8002]oo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00@001=oo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH00`00FUH0
000A0008FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP8000EJEP04001JEP00000LOol2
0003FUH01@00FUIJEUYF00000UYF0P00:goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF1000
5goo00D005YFFUIJEP0000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP0
0003FUH005YF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH4000015YF001JEUYF0`001EYF00D005YFFUIJEP0001Qoo`<000EJEP03001J
EUYF009JEP@002]oo`00;Goo00@005YFFUH000AJEP04001JEUYFFUH2000LOol01000FUIJEP000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH00000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00004FUH0
05YF0003FUH60003FUH00`00Oomoo`0BOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH0
0000:goo000]Ool01000FUIJEP0015YF00@005YF000001moo`H000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH0000000EJEP04001JEUYFFUH9
0009Ool70005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000[Ool002ioo`03001JEP0000AJEP80
021oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00;Woo00<005YF00000UYF
0P000UYF0`001goo4@000Woo100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
0000:goo000^Ool00`00FUH000020005FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH500000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002ioo`06001JEP00FUH0
05YF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;7oo000^Ool20002FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool002ioo`@000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP03001oogoo02]oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF5`001UYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001oo`00009JEP03001JEUYF00=JEP03001JEUYF00EJEQ/000IJEP03
001JEUYF008002ioo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009oo`03001JEP0000EJEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH50002FUH3000`Ool002ioo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP/00003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPX000=JEP03001JEUYF008000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`800003FUH00000008000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080039o
o`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP8000EJEP03001JEUYF00=JEQP000AJEP03001JEUYF00=JEP@0009JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
031oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000^Ool002ioo`03
001JEP0000AJEP03001JEUYF00=JEQ`000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002ioo`03001JEP0000AJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP8000EJEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool002io
o`03001JEP0000=JEP<0009JEP04001JEUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP020003
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20005FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06
001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo00@005YF001JEP80
00EJEP03001JEUYF00EJEP04001JEUYFFUHB0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002]oo`00;Woo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00:goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP0:00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P0015YF
00@005YFFUIJEPL00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01P00FUH00000FUH000=JEP03001JEUYF00=JEPL0011oo`P000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000[Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YF00000`000UYF00@005YFFUIJ
EP8001Moo`H000AJEP04001JEUYFFUH2000[Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF20002EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0002FUH30002FUH00`00FUH0000<
000@Ool50003FUH300000eYF001JEP02FUH2000[Ool0031oo`800003FUH005YF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF009JEP09OomJEUYFFUH005YF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPd000YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP04FUH30003FUH2000[Ool0039oo`<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP05OomJEUYF001JEP040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF3@000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000=JEP000000:goo000eOol300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP09000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002ioo`L000=o
o`D000=JEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo3P0000=oo`0000001P000UYF1@001UYF00<005YFFUH00UYF1P001goo2P00
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000:goo000^Ool00`00FUH00003FUH01000FUIJEUYF7`003Goo00@005YFFUH000EJ
EPX000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00@005YFFUIJEPl001Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3P003Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00EJEQ4000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP06001JEP00FUH005YF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@001Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH01000FUIJEUYF1`00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0035oo`00;Goo
10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEP`0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001J
EUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000fOol0035oo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001J
EUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09FUH<0005FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHF000gOol003Moo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP8000YJEPL000IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00H0035o
o`00?Woo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02EYF0P002UYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF00<005YF00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEQ0002aoo`00Agoo2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF00000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02EYF0P002UYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF00<005YF00001EYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000/Ool0051oo`l000=JEP03001JEP00009JEP04001JEUYFFUH20005FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
000015YF00<005YF00000UYF1`001goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00Ggoo1P000UYF00@005YFFUH000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP8000UJEP04001JEUYFFUH20002FUH00`00
FUH00002000GOol90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001T
Ool00`00FUIJEP040007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0QOol80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo0018Ool3000IOol01000FUIJEP000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P0000=JEP000000:Goo1P000eYF00@005YFFUIJEP8002eoo`00Agoo1@0067oo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01`00:7oo2@00;Goo0017Ool5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000?001HOol004Moo`D001Qo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP09001COol0
04Qoo`<001Uoo`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00Dgoo001TOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH000001UYF00<005YFFUH015YF00@005YFFUIJEP8005=oo`00IGoo00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00=oo`00
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00IGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00IWoo0P000UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001Woo2`00
0UYF0P00E7oo001XOol30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P004goo1000E7oo001ZOol20006FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0
0000KGoo001/Ool20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH4001_Ool006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPH006moo`00LGoo10002EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00000P0000=oo`0000000`00Kgoo001eOol60003
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF2P0017oo1@00Kgoo001kOol90006FUH0
0`00FUIJEP04FUH:000?Ool3001`Ool008Aoo`d008aoo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60262 .73816 m .59914 .68566 L .56799 .68452 L p .707 .577 .707 r
F P
0 g
s
.59914 .68566 m .60262 .73816 L .60483 .73796 L p .707 .577 .707 r
F P
0 g
s
.56799 .68452 m .57147 .73703 L .57331 .7371 L p .707 .577 .707 r
F P
0 g
s
.57331 .7371 m .60262 .73816 L p .58714 .71418 L .707 .577 .707 r
F P
0 g
s
.58714 .71418 m .56799 .68452 L .57331 .7371 L .707 .577 .707 r
F
.57147 .73703 m .56799 .68452 L .54051 .67936 L p F P
0 g
s
.54051 .67936 m .54399 .73187 L .54565 .73218 L p .707 .577 .707 r
F P
0 g
s
.54565 .73218 m .57147 .73703 L p .55677 .70966 L .707 .577 .707 r
F P
0 g
s
.55677 .70966 m .54051 .67936 L .54565 .73218 L .707 .577 .707 r
F
.54399 .73187 m .54051 .67936 L .51938 .67069 L p F P
0 g
s
.51938 .67069 m .52286 .72319 L .52426 .72377 L p .707 .577 .707 r
F P
0 g
s
.52426 .72377 m .54399 .73187 L p .531 .69957 L .707 .577 .707 r
F P
0 g
s
.531 .69957 m .51938 .67069 L .52426 .72377 L .707 .577 .707 r
F
.52286 .72319 m .51938 .67069 L .50667 .65934 L p F P
0 g
s
.50667 .65934 m .51016 .71185 L .52286 .72319 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .51069 .70826 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52289 .75284 m .52316 .7277 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.52316 .7277 m .52329 .71554 L p .51956 .74065 L .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .52329 .71554 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.54395 .75891 m .5442 .73512 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5442 .73512 m .54435 .72161 L p .53831 .74706 L .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .54435 .72161 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57141 .76317 m .57166 .73984 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.57166 .73984 m .5718 .72586 L p .56423 .75215 L .707 .577 .707 r
F P
0 g
s
.60298 .7279 m .5718 .72586 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60258 .7652 m .60283 .74141 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60283 .74141 m .60298 .7279 L p .59483 .75529 L .707 .577 .707 r
F P
0 g
s
.60483 .73796 m .63438 .73516 L p .61894 .71348 L .707 .577 .707 r
F P
0 g
s
.61894 .71348 m .59914 .68566 L .60483 .73796 L .707 .577 .707 r
F
.63438 .73516 m .6309 .68266 L .59914 .68566 L p F P
0 g
s
.6309 .68266 m .63438 .73516 L .63696 .73456 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .60298 .7279 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63442 .76481 m .63468 .73967 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63468 .73967 m .63481 .72751 L p .62723 .75638 L .707 .577 .707 r
F P
0 g
s
.63696 .73456 m .66365 .72832 L p .6489 .70776 L .707 .577 .707 r
F P
0 g
s
.6489 .70776 m .6309 .68266 L .63696 .73456 L .707 .577 .707 r
F
.66365 .72832 m .66017 .67581 L .6309 .68266 L p F P
0 g
s
.66017 .67581 m .66365 .72832 L .66605 .72732 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .63481 .72751 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66379 .76204 m .66408 .7348 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66408 .7348 m .66419 .72473 L p .65855 .7558 L .707 .577 .707 r
F P
0 g
s
.66605 .72732 m .68756 .71831 L p .67398 .69723 L .707 .577 .707 r
F P
0 g
s
.67398 .69723 m .66017 .67581 L .66605 .72732 L .707 .577 .707 r
F
.68756 .71831 m .68408 .6658 L .66017 .67581 L p F P
0 g
s
.60298 .7279 m .60258 .7652 L .63442 .76481 L p .707 .577 .707 r
F P
0 g
s
.63481 .72751 m .63442 .76481 L .66379 .76204 L p .707 .577 .707 r
F P
0 g
s
.5718 .72586 m .57141 .76317 L .60258 .7652 L p .707 .577 .707 r
F P
0 g
s
.57058 .76557 m .56838 .78467 L .59946 .78811 L p .707 .577 .707 r
F P
0 g
s
.59946 .78811 m .60166 .76901 L .57058 .76557 L p .707 .577 .707 r
F P
0 g
s
.60166 .76901 m .59946 .78811 L .63103 .79182 L p .707 .577 .707 r
F P
0 g
s
.63103 .79182 m .63323 .77271 L .60166 .76901 L p .707 .577 .707 r
F P
0 g
s
.68408 .6658 m .68756 .71831 L .70378 .7061 L p .707 .577 .707 r
F P
0 g
s
.70378 .7061 m .7003 .65359 L .68408 .6658 L p .707 .577 .707 r
F P
0 g
s
.63323 .77271 m .63103 .79182 L .66001 .79542 L p .707 .577 .707 r
F P
0 g
s
.66001 .79542 m .66221 .77631 L .63323 .77271 L p .707 .577 .707 r
F P
0 g
s
.54303 .76272 m .54083 .78182 L .56838 .78467 L p .707 .577 .707 r
F P
0 g
s
.56838 .78467 m .57058 .76557 L .54303 .76272 L p .707 .577 .707 r
F P
0 g
s
.66419 .72473 m .66379 .76204 L .68784 .75715 L p .707 .577 .707 r
F P
0 g
s
.68784 .75715 m .68824 .71984 L .66419 .72473 L p .707 .577 .707 r
F P
0 g
s
.54435 .72161 m .54395 .75891 L .57141 .76317 L p .707 .577 .707 r
F P
0 g
s
.66221 .77631 m .66001 .79542 L .68355 .79856 L p .707 .577 .707 r
F P
0 g
s
.68355 .79856 m .68575 .77946 L .66221 .77631 L p .707 .577 .707 r
F P
0 g
s
.52171 .76074 m .51951 .77985 L .54083 .78182 L p .707 .577 .707 r
F P
0 g
s
.54083 .78182 m .54303 .76272 L .52171 .76074 L p .707 .577 .707 r
F P
0 g
s
.52329 .71554 m .52289 .75284 L .54395 .75891 L p .707 .577 .707 r
F P
0 g
s
.7003 .65359 m .70378 .7061 L .71071 .6929 L p .707 .577 .707 r
F P
0 g
s
.71071 .6929 m .70722 .64039 L .7003 .65359 L p .707 .577 .707 r
F P
0 g
s
.68824 .71984 m .68784 .75715 L .70421 .75063 L p .707 .577 .707 r
F P
0 g
s
.70421 .75063 m .7046 .71332 L .68824 .71984 L p .707 .577 .707 r
F P
0 g
s
.68575 .77946 m .68355 .79856 L .69935 .80094 L p .707 .577 .707 r
F P
0 g
s
.69935 .80094 m .70154 .78184 L .68575 .77946 L p .707 .577 .707 r
F P
0 g
s
.51016 .71185 m .50667 .65934 L .50364 .64643 L p .707 .577 .707 r
F P
0 g
s
.50871 .75984 m .50651 .77894 L .51951 .77985 L p .707 .577 .707 r
F P
0 g
s
.51951 .77985 m .52171 .76074 L .50871 .75984 L p .707 .577 .707 r
F P
0 g
s
.51069 .70826 m .5103 .74556 L .52289 .75284 L p .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .4822 .32906 L .43819 .32655 L p .707 .577 .707 r
F P
0 g
s
.50364 .64643 m .50712 .69894 L .51016 .71185 L p .707 .577 .707 r
F P
0 g
s
.5103 .74556 m .51069 .70826 L .50779 .70048 L p .707 .577 .707 r
F P
0 g
s
.50712 .69894 m .50364 .64643 L .51056 .63323 L p .707 .577 .707 r
F P
0 g
s
.5053 .76009 m .5031 .7792 L .50651 .77894 L p .707 .577 .707 r
F P
0 g
s
.50651 .77894 m .50871 .75984 L .5053 .76009 L p .707 .577 .707 r
F P
0 g
s
.50779 .70048 m .5074 .73778 L .5103 .74556 L p .707 .577 .707 r
F P
0 g
s
.51056 .63323 m .51405 .68574 L .50712 .69894 L p .707 .577 .707 r
F P
0 g
s
.5074 .73778 m .50779 .70048 L .51487 .69296 L p .707 .577 .707 r
F P
0 g
s
.51405 .68574 m .51056 .63323 L .52678 .62102 L p .707 .577 .707 r
F P
0 g
s
.51487 .69296 m .51448 .73026 L .5074 .73778 L p .707 .577 .707 r
F P
0 g
s
.51181 .76148 m .50961 .78058 L .5031 .7792 L p .707 .577 .707 r
F P
0 g
s
.5031 .7792 m .5053 .76009 L .51181 .76148 L p .707 .577 .707 r
F P
0 g
s
.52678 .62102 m .53026 .67353 L .51405 .68574 L p .707 .577 .707 r
F P
0 g
s
.51448 .73026 m .51487 .69296 L .53124 .68643 L p .707 .577 .707 r
F P
0 g
s
.53124 .68643 m .53084 .72374 L .51448 .73026 L p .707 .577 .707 r
F P
0 g
s
.52761 .76386 m .52541 .78296 L .50961 .78058 L p .707 .577 .707 r
F P
0 g
s
.50961 .78058 m .51181 .76148 L .52761 .76386 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .52541 .78296 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55115 .767 m .55098 .76853 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.55098 .76853 m .54895 .78611 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .52761 .76386 L .55053 .76692 L p .707 .577 .707 r
F P
0 g
s
.55053 .76692 m .55115 .767 L p .55064 .76732 L .707 .577 .707 r
F P
0 g
s
.52541 .78296 m .55053 .76692 L .55064 .76732 L .707 .577 .707 r
F
.52714 .32744 m .4822 .32906 L p .51236 .62831 L F P
0 g
s
.53084 .72374 m .53124 .68643 L .5459 .68345 L p .707 .577 .707 r
F P
0 g
s
.53026 .67353 m .52678 .62102 L .55069 .61101 L p .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .55286 .6438 L p .53026 .67353 L .707 .577 .707 r
F P
0 g
s
.58013 .7706 m .57793 .78971 L .54895 .78611 L p .707 .577 .707 r
F P
0 g
s
.54895 .78611 m .54904 .7853 L p .58013 .7706 L .707 .577 .707 r
F P
0 g
s
.54904 .7853 m .55115 .767 L .55886 .76796 L p .707 .577 .707 r
F P
0 g
s
.55886 .76796 m .58013 .7706 L p .54904 .7853 L .707 .577 .707 r
F P
0 g
s
.58427 .71607 m .58466 .67877 L .6165 .67838 L p .707 .577 .707 r
F P
0 g
s
.6165 .67838 m .6161 .71568 L .58427 .71607 L p .707 .577 .707 r
F P
0 g
s
.6117 .77431 m .6095 .79341 L .58385 .7904 L p .707 .577 .707 r
F P
0 g
s
.58385 .7904 m .57793 .78971 L p .58452 .7867 L .707 .577 .707 r
F P
0 g
s
.58452 .7867 m .6117 .77431 L .58385 .7904 L .707 .577 .707 r
F
.64287 .6023 m .64635 .65481 L .61521 .65367 L p F P
0 g
s
.61521 .65367 m .61172 .60116 L .64287 .6023 L p .707 .577 .707 r
F P
0 g
s
.64767 .68041 m .64727 .71772 L .6161 .71568 L p .707 .577 .707 r
F P
0 g
s
.6161 .71568 m .6165 .67838 L .64767 .68041 L p .707 .577 .707 r
F P
0 g
s
.64278 .77775 m .64058 .79686 L .61294 .79379 L p .707 .577 .707 r
F P
0 g
s
.61294 .79379 m .6095 .79341 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.61308 .79173 m .64278 .77775 L .61294 .79379 L .707 .577 .707 r
F
.6095 .79341 m .6117 .77431 L .61417 .77458 L p F P
0 g
s
.61417 .77458 m .64278 .77775 L p .61308 .79173 L .707 .577 .707 r
F P
0 g
s
.6095 .79341 m .61417 .77458 L .61308 .79173 L .707 .577 .707 r
F
.63566 .28839 m .62567 .30133 L p .63179 .498 L F P
0 g
s
.64078 .78667 m .63698 .4166 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63698 .4166 m .63566 .28839 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .64078 .78667 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62567 .30133 m .62826 .55347 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.62826 .55347 m .63079 .79961 L p .63179 .498 L .707 .577 .707 r
F P
0 g
s
.57793 .78971 m .58013 .7706 L .6117 .77431 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .63079 .79961 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .57996 .60417 L .61172 .60116 L p .707 .577 .707 r
F P
0 g
s
.61172 .60116 m .61521 .65367 L .58344 .65667 L p .707 .577 .707 r
F P
0 g
s
.60257 .31286 m .6062 .66641 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.6062 .66641 m .60768 .81114 L p .61896 .59559 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .60768 .81114 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55069 .61101 m .56292 .60815 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56292 .60815 m .57996 .60417 L p .56891 .62961 L .707 .577 .707 r
F P
0 g
s
.5636 .64181 m .56292 .60815 L .56891 .62961 L .707 .577 .707 r
F
.57188 .64028 m .57294 .7431 L p .57673 .73641 L F P
0 g
s
.58161 .67906 m .58466 .67877 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58187 .67605 m .57188 .64028 L .57673 .73641 L .707 .577 .707 r
F
.58466 .67877 m .58427 .71607 L .57841 .71663 L p F P
0 g
s
.56797 .77749 m .55286 .6438 L .55119 .6533 L .707 .577 .707 r
F
.57373 .82014 m .56867 .77741 L .56797 .77749 L F
.56867 .77741 m .55286 .6438 L .56797 .77749 L F
.57373 .82014 m .55698 .64303 L .55286 .6438 L F
.54902 .66568 m .53026 .67353 L p .55286 .6438 L F P
0 g
s
.55803 .82225 m .57373 .82014 L p .52878 .4874 L .707 .577 .707 r
F P
0 g
s
.57373 .82014 m .57188 .64028 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.58344 .65667 m .55417 .66352 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.57996 .60417 m .58223 .63836 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.58223 .63836 m .58344 .65667 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55069 .61101 L p .5636 .64181 L .707 .577 .707 r
F P
0 g
s
.56862 .32186 m .52714 .32744 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57188 .64028 m .56862 .32186 L p .55698 .64303 L .707 .577 .707 r
F P
0 g
s
.57841 .71663 m .55489 .71885 L p .58124 .68337 L .707 .577 .707 r
F P
0 g
s
.58124 .68337 m .58466 .67877 L .57841 .71663 L .707 .577 .707 r
F
.59863 .69774 m .5829 .66394 L .59145 .71041 L F
.5829 .66394 m .57188 .64028 L .58187 .67605 L F
.5829 .66394 m .58187 .67605 L .59145 .71041 L F
.59145 .71041 m .58187 .67605 L .57673 .73641 L F
.55489 .71885 m .55528 .68154 L .58161 .67906 L p F P
0 g
s
.55489 .71885 m .58161 .67906 L .58124 .68337 L .707 .577 .707 r
F
.56862 .32186 m .57188 .64028 L p .59863 .69774 L F P
0 g
s
.57294 .7431 m .57373 .82014 L p .59863 .69774 L .707 .577 .707 r
F P
0 g
s
.55286 .6438 m .55417 .66352 L .54902 .66568 L p .707 .577 .707 r
F P
0 g
s
.55119 .6533 m .55286 .6438 L .54998 .64433 L .707 .577 .707 r
F
.52714 .32744 m .52878 .4874 L p .54998 .64433 L F P
0 g
s
.55698 .64303 m .52714 .32744 L .54998 .64433 L .707 .577 .707 r
F
.55417 .66352 m .55286 .6438 L p .5636 .64181 L F P
0 g
s
.5459 .68345 m .55528 .68154 L p .54699 .69587 L .707 .577 .707 r
F P
0 g
s
.53084 .72374 m .5459 .68345 L .54699 .69587 L .707 .577 .707 r
F
.55528 .68154 m .55489 .71885 L .53084 .72374 L p F P
0 g
s
.52878 .4874 m .53225 .82572 L .55803 .82225 L p .707 .577 .707 r
F P
0 g
s
.53225 .82572 m .53092 .6957 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.53092 .6957 m .52714 .32744 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48731 .82734 m .53225 .82572 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.4822 .32906 m .48422 .52615 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.48422 .52615 m .48731 .82734 L p .51236 .62831 L .707 .577 .707 r
F P
0 g
s
.7046 .71332 m .70421 .75063 L .71129 .7431 L p .707 .577 .707 r
F P
0 g
s
.71129 .7431 m .71168 .7058 L .7046 .71332 L p .707 .577 .707 r
F P
0 g
s
.70722 .64039 m .71071 .6929 L .70767 .67999 L p .707 .577 .707 r
F P
0 g
s
.70767 .67999 m .70419 .62748 L .70722 .64039 L p .707 .577 .707 r
F P
0 g
s
.4433 .82483 m .43819 .32655 L .39943 .32017 L p .707 .577 .707 r
F P
0 g
s
.43819 .32655 m .4433 .82483 L .48731 .82734 L p .707 .577 .707 r
F P
0 g
s
.70154 .78184 m .69935 .80094 L .70586 .80233 L p .707 .577 .707 r
F P
0 g
s
.70586 .80233 m .70806 .78323 L .70154 .78184 L p .707 .577 .707 r
F P
0 g
s
.60768 .81114 m .60257 .31286 L .56862 .32186 L p .707 .577 .707 r
F P
0 g
s
.40454 .81845 m .39943 .32017 L .3697 .31054 L p .707 .577 .707 r
F P
0 g
s
.39943 .32017 m .40454 .81845 L .4433 .82483 L p .707 .577 .707 r
F P
0 g
s
.70419 .62748 m .70767 .67999 L .69496 .66864 L p .707 .577 .707 r
F P
0 g
s
.69496 .66864 m .69148 .61614 L .70419 .62748 L p .707 .577 .707 r
F P
0 g
s
.71168 .7058 m .71129 .7431 L .70839 .73532 L p .707 .577 .707 r
F P
0 g
s
.70839 .73532 m .70878 .69802 L .71168 .7058 L p .707 .577 .707 r
F P
0 g
s
.70806 .78323 m .70586 .80233 L .70245 .80258 L p .707 .577 .707 r
F P
0 g
s
.63079 .79961 m .62567 .30133 L .60257 .31286 L p .707 .577 .707 r
F P
0 g
s
.70245 .80258 m .70465 .78348 L .70806 .78323 L p .707 .577 .707 r
F P
0 g
s
.25961 .70135 m .25613 .64884 L .22498 .64771 L p .707 .577 .707 r
F P
0 g
s
.25613 .64884 m .25961 .70135 L .26182 .70114 L p .707 .577 .707 r
F P
0 g
s
.22498 .64771 m .22846 .70022 L .2303 .70028 L p .707 .577 .707 r
F P
0 g
s
.2303 .70028 m .25961 .70135 L p .24413 .67737 L .707 .577 .707 r
F P
0 g
s
.24413 .67737 m .22498 .64771 L .2303 .70028 L .707 .577 .707 r
F
.22846 .70022 m .22498 .64771 L .1975 .64255 L p F P
0 g
s
.1975 .64255 m .20098 .69506 L .20264 .69537 L p .707 .577 .707 r
F P
0 g
s
.20264 .69537 m .22846 .70022 L p .21376 .67284 L .707 .577 .707 r
F P
0 g
s
.21376 .67284 m .1975 .64255 L .20264 .69537 L .707 .577 .707 r
F
.20098 .69506 m .1975 .64255 L .17637 .63387 L p F P
0 g
s
.17637 .63387 m .17985 .68638 L .18125 .68695 L p .707 .577 .707 r
F P
0 g
s
.18125 .68695 m .20098 .69506 L p .18799 .66275 L .707 .577 .707 r
F P
0 g
s
.18799 .66275 m .17637 .63387 L .18125 .68695 L .707 .577 .707 r
F
.17985 .68638 m .17637 .63387 L .16367 .62252 L p F P
0 g
s
.16367 .62252 m .16715 .67503 L .17985 .68638 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .16768 .67144 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.17988 .71603 m .18015 .69089 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.18015 .69089 m .18028 .67872 L p .17655 .70383 L .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .18028 .67872 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20094 .7221 m .20119 .6983 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.20119 .6983 m .20134 .68479 L p .1953 .71025 L .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .20134 .68479 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.2284 .72635 m .22865 .70303 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.22865 .70303 m .2288 .68905 L p .22122 .71533 L .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .2288 .68905 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25957 .72839 m .25982 .7046 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.25982 .7046 m .25997 .69108 L p .25182 .71848 L .707 .577 .707 r
F P
0 g
s
.26182 .70114 m .29137 .69835 L p .27593 .67666 L .707 .577 .707 r
F P
0 g
s
.27593 .67666 m .25613 .64884 L .26182 .70114 L .707 .577 .707 r
F
.29137 .69835 m .28789 .64584 L .25613 .64884 L p F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28789 .64584 m .29137 .69835 L .29395 .69775 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .25997 .69108 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29141 .728 m .29167 .70286 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29167 .70286 m .2918 .69069 L p .28423 .71957 L .707 .577 .707 r
F P
0 g
s
.29395 .69775 m .32064 .69151 L p .3059 .67094 L .707 .577 .707 r
F P
0 g
s
.3059 .67094 m .28789 .64584 L .29395 .69775 L .707 .577 .707 r
F
.32064 .69151 m .31716 .639 L .28789 .64584 L p F P
0 g
s
.69148 .61614 m .69496 .66864 L .67384 .65996 L p .707 .577 .707 r
F P
0 g
s
.67384 .65996 m .67035 .60746 L .69148 .61614 L p .707 .577 .707 r
F P
0 g
s
.36828 .70629 m .36867 .66898 L .36159 .6765 L p .707 .577 .707 r
F P
0 g
s
.36159 .6765 m .3612 .71381 L .36828 .70629 L p .707 .577 .707 r
F P
0 g
s
.36867 .66898 m .36828 .70629 L .36608 .70038 L p .707 .577 .707 r
F P
0 g
s
.36631 .69015 m .36867 .66898 L .36608 .70038 L .707 .577 .707 r
F
.34107 .62898 m .34456 .68149 L .36077 .66928 L p F P
0 g
s
.36077 .66928 m .35729 .61678 L .34107 .62898 L p .707 .577 .707 r
F P
0 g
s
.35729 .61678 m .36077 .66928 L .3677 .65608 L p .707 .577 .707 r
F P
0 g
s
.3677 .65608 m .36421 .60357 L .35729 .61678 L p .707 .577 .707 r
F P
0 g
s
.34523 .68303 m .34483 .72033 L .3612 .71381 L p .707 .577 .707 r
F P
0 g
s
.3612 .71381 m .36159 .6765 L .34523 .68303 L p .707 .577 .707 r
F P
0 g
s
.35634 .76413 m .35854 .74503 L .34274 .74264 L p .707 .577 .707 r
F P
0 g
s
.35854 .74503 m .35634 .76413 L .36285 .76551 L p .707 .577 .707 r
F P
0 g
s
.36285 .76551 m .36505 .74641 L .35854 .74503 L p .707 .577 .707 r
F P
0 g
s
.36505 .74641 m .36285 .76551 L .35944 .76577 L p .707 .577 .707 r
F P
0 g
s
.35944 .76577 m .36164 .74666 L .36505 .74641 L p .707 .577 .707 r
F P
0 g
s
.35703 .79688 m .37481 .80882 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.36421 .60357 m .3677 .65608 L .36531 .64596 L p .707 .577 .707 r
F P
0 g
s
.3646 .63775 m .36421 .60357 L .36531 .64596 L .707 .577 .707 r
F
.3669 .66419 m .36335 .62346 L .36534 .73239 L F
.36538 .69851 m .36577 .6612 L .3669 .66424 L p F P
0 g
s
.3669 .66424 m .36867 .66898 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.36538 .69851 m .3669 .66424 L .36631 .69015 L .707 .577 .707 r
F
.34274 .74264 m .34054 .76175 L .35634 .76413 L p F P
0 g
s
.35944 .76577 m .34644 .76486 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.36164 .74666 m .35953 .76496 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35953 .76496 m .35944 .76577 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.35529 .69268 m .35278 .69123 L p .35514 .68576 L .707 .577 .707 r
F P
0 g
s
.35532 .69385 m .3548 .63425 L .35442 .65164 L .707 .577 .707 r
F
.35278 .69123 m .35318 .65392 L .35448 .65468 L p F P
0 g
s
.3548 .63437 m .35196 .63183 L p .35517 .61746 L .707 .577 .707 r
F P
0 g
s
.35624 .71984 m .35518 .61702 L p .35532 .69385 L .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .34847 .57932 L .35587 .58593 L p .707 .577 .707 r
F P
0 g
s
.35196 .63183 m .35587 .58593 L .35517 .61746 L .707 .577 .707 r
F
.35518 .61702 m .35192 .2986 L p .3548 .63425 L F P
0 g
s
.35518 .61702 m .3548 .63425 L .35532 .69385 L .707 .577 .707 r
F
.34644 .76486 m .34864 .74576 L .35818 .74642 L p F P
0 g
s
.35818 .74642 m .36164 .74666 L p .35847 .75045 L .707 .577 .707 r
F P
0 g
s
.34644 .76486 m .35818 .74642 L .35847 .75045 L .707 .577 .707 r
F
.35294 .7838 m .35703 .79688 L p .35545 .70899 L F P
0 g
s
.35278 .69123 m .35448 .65468 L .35514 .68576 L .707 .577 .707 r
F
.34847 .57932 m .35196 .63183 L .34562 .62923 L p F P
0 g
s
.34562 .62923 m .33083 .62315 L p .3438 .59092 L .707 .577 .707 r
F P
0 g
s
.3438 .59092 m .34847 .57932 L .34562 .62923 L .707 .577 .707 r
F
.31716 .639 m .32064 .69151 L .32305 .6905 L p F P
0 g
s
.32305 .6905 m .34456 .68149 L p .33097 .66041 L .707 .577 .707 r
F P
0 g
s
.33097 .66041 m .31716 .639 L .32305 .6905 L .707 .577 .707 r
F
.32118 .68792 m .2918 .69069 L p .31554 .71898 L F P
0 g
s
.32079 .72522 m .32107 .69799 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.32107 .69799 m .32118 .68792 L p .31554 .71898 L .707 .577 .707 r
F P
0 g
s
.34456 .68149 m .34107 .62898 L .31716 .639 L p .707 .577 .707 r
F P
0 g
s
.34483 .72033 m .34523 .68303 L .32118 .68792 L p .707 .577 .707 r
F P
0 g
s
.35318 .65392 m .35278 .69123 L .33172 .68516 L p .707 .577 .707 r
F P
0 g
s
.33172 .68516 m .33212 .64785 L .35318 .65392 L p .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35163 .65671 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35163 .65671 m .35294 .7838 L p .35545 .70899 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .34782 .28552 L p .35442 .6518 L .707 .577 .707 r
F P
0 g
s
.3548 .63425 m .35192 .2986 L .35442 .6518 L .707 .577 .707 r
F
.35518 .61702 m .35703 .79688 L p .36335 .62346 L F P
0 g
s
.35587 .58593 m .36118 .59067 L p .35526 .61708 L .707 .577 .707 r
F P
0 g
s
.35517 .61746 m .35518 .61702 L .35526 .61708 L .707 .577 .707 r
F
.35518 .61702 m .35587 .58593 L .35526 .61708 L F
.36118 .59067 m .36335 .62346 L p .35526 .61708 L F P
0 g
s
.35417 .51818 m .35518 .61702 L p .36335 .62346 L .707 .577 .707 r
F P
0 g
s
.36118 .59067 m .36421 .60357 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36466 .64318 m .36335 .62346 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36335 .62346 m .36118 .59067 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.35192 .2986 m .35417 .51818 L p .36982 .69764 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .35192 .2986 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.34782 .28552 m .35781 .27258 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35294 .7838 m .35292 .7827 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.35292 .7827 m .34782 .28552 L p .35294 .78309 L .707 .577 .707 r
F P
0 g
s
.36534 .73239 m .36335 .62346 L .35703 .79688 L .707 .577 .707 r
F
.35448 .65468 m .36577 .6612 L p .35514 .68576 L F P
0 g
s
.35572 .71269 m .35532 .69385 L .35545 .70899 L .707 .577 .707 r
F
.35624 .71984 m .35532 .69385 L .35572 .71269 L F
.35545 .70899 m .35532 .69385 L .35442 .6518 L F
.35532 .69385 m .35442 .65164 L .35442 .6518 L F
.36577 .6612 m .36538 .69851 L .35529 .69268 L p F P
0 g
s
.35514 .68576 m .36577 .6612 L .35529 .69268 L .707 .577 .707 r
F
.36466 .64318 m .3548 .63437 L p .35526 .61708 L F P
0 g
s
.35517 .61746 m .35526 .61708 L .3548 .63437 L .707 .577 .707 r
F
.35703 .79688 m .35624 .71984 L p .35545 .70899 L F P
0 g
s
.36982 .69764 m .3669 .66419 L .36534 .73239 L .707 .577 .707 r
F
.36335 .62346 m .36466 .64318 L p .35526 .61708 L F P
0 g
s
.36531 .64596 m .36466 .64318 L p .3646 .63775 L .707 .577 .707 r
F P
0 g
s
.36608 .70038 m .36538 .69851 L p .36631 .69015 L .707 .577 .707 r
F P
0 g
s
.37481 .80882 m .37134 .47051 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.37134 .47051 m .3697 .31054 L p .36738 .64329 L .707 .577 .707 r
F P
0 g
s
.3697 .31054 m .37481 .80882 L .40454 .81845 L p .707 .577 .707 r
F P
0 g
s
.70878 .69802 m .70839 .73532 L .69579 .72804 L p .707 .577 .707 r
F P
0 g
s
.69579 .72804 m .69619 .69074 L .70878 .69802 L p .707 .577 .707 r
F P
0 g
s
.25997 .69108 m .25957 .72839 L .29141 .728 L p .707 .577 .707 r
F P
0 g
s
.2918 .69069 m .29141 .728 L .32079 .72522 L p .707 .577 .707 r
F P
0 g
s
.70465 .78348 m .70245 .80258 L .68945 .80168 L p .707 .577 .707 r
F P
0 g
s
.68945 .80168 m .69165 .78257 L .70465 .78348 L p .707 .577 .707 r
F P
0 g
s
.2288 .68905 m .2284 .72635 L .25957 .72839 L p .707 .577 .707 r
F P
0 g
s
.22757 .72875 m .22537 .74785 L .25645 .7513 L p .707 .577 .707 r
F P
0 g
s
.25645 .7513 m .25865 .73219 L .22757 .72875 L p .707 .577 .707 r
F P
0 g
s
.25865 .73219 m .25645 .7513 L .28802 .755 L p .707 .577 .707 r
F P
0 g
s
.28802 .755 m .29022 .7359 L .25865 .73219 L p .707 .577 .707 r
F P
0 g
s
.67035 .60746 m .67384 .65996 L .64635 .65481 L p .707 .577 .707 r
F P
0 g
s
.64635 .65481 m .64287 .6023 L .67035 .60746 L p .707 .577 .707 r
F P
0 g
s
.29022 .7359 m .28802 .755 L .317 .7586 L p .707 .577 .707 r
F P
0 g
s
.317 .7586 m .3192 .7395 L .29022 .7359 L p .707 .577 .707 r
F P
0 g
s
.20002 .7259 m .19782 .745 L .22537 .74785 L p .707 .577 .707 r
F P
0 g
s
.22537 .74785 m .22757 .72875 L .20002 .7259 L p .707 .577 .707 r
F P
0 g
s
.32118 .68792 m .32079 .72522 L .34483 .72033 L p .707 .577 .707 r
F P
0 g
s
.20134 .68479 m .20094 .7221 L .2284 .72635 L p .707 .577 .707 r
F P
0 g
s
.69619 .69074 m .69579 .72804 L .67473 .72198 L p .707 .577 .707 r
F P
0 g
s
.67473 .72198 m .67513 .68467 L .69619 .69074 L p .707 .577 .707 r
F P
0 g
s
.3192 .7395 m .317 .7586 L .34054 .76175 L p .707 .577 .707 r
F P
0 g
s
.34054 .76175 m .34274 .74264 L .3192 .7395 L p .707 .577 .707 r
F P
0 g
s
.1787 .72393 m .1765 .74303 L .19782 .745 L p .707 .577 .707 r
F P
0 g
s
.19782 .745 m .20002 .7259 L .1787 .72393 L p .707 .577 .707 r
F P
0 g
s
.18028 .67872 m .17988 .71603 L .20094 .7221 L p .707 .577 .707 r
F P
0 g
s
.69165 .78257 m .68945 .80168 L .66813 .7997 L p .707 .577 .707 r
F P
0 g
s
.66813 .7997 m .67033 .7806 L .69165 .78257 L p .707 .577 .707 r
F P
0 g
s
.67513 .68467 m .67473 .72198 L .64727 .71772 L p .707 .577 .707 r
F P
0 g
s
.64727 .71772 m .64767 .68041 L .67513 .68467 L p .707 .577 .707 r
F P
0 g
s
.16715 .67503 m .16367 .62252 L .16063 .60962 L p .707 .577 .707 r
F P
0 g
s
.63566 .28839 m .64078 .78667 L .63669 .77359 L p .707 .577 .707 r
F P
0 g
s
.63669 .77359 m .63157 .27531 L .63566 .28839 L p .707 .577 .707 r
F P
0 g
s
.1657 .72302 m .1635 .74213 L .1765 .74303 L p .707 .577 .707 r
F P
0 g
s
.1765 .74303 m .1787 .72393 L .1657 .72302 L p .707 .577 .707 r
F P
0 g
s
.16768 .67144 m .16729 .70875 L .17988 .71603 L p .707 .577 .707 r
F P
0 g
s
.67033 .7806 m .66813 .7997 L .64058 .79686 L p .707 .577 .707 r
F P
0 g
s
.64058 .79686 m .64278 .77775 L .67033 .7806 L p .707 .577 .707 r
F P
0 g
s
.16063 .60962 m .16411 .66212 L .16715 .67503 L p .707 .577 .707 r
F P
0 g
s
.16729 .70875 m .16768 .67144 L .16478 .66366 L p .707 .577 .707 r
F P
0 g
s
.16411 .66212 m .16063 .60962 L .16756 .59641 L p .707 .577 .707 r
F P
0 g
s
.16229 .72328 m .16009 .74238 L .1635 .74213 L p .707 .577 .707 r
F P
0 g
s
.1635 .74213 m .1657 .72302 L .16229 .72328 L p .707 .577 .707 r
F P
0 g
s
.16478 .66366 m .16439 .70097 L .16729 .70875 L p .707 .577 .707 r
F P
0 g
s
.63157 .27531 m .63669 .77359 L .6189 .76165 L p .707 .577 .707 r
F P
0 g
s
.6189 .76165 m .61379 .26337 L .63157 .27531 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16756 .59641 m .17104 .64892 L .16411 .66212 L p .707 .577 .707 r
F P
0 g
s
.16439 .70097 m .16478 .66366 L .17186 .65614 L p .707 .577 .707 r
F P
0 g
s
.17104 .64892 m .16756 .59641 L .18377 .58421 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36293 .77086 m .35781 .27258 L .38092 .26105 L p .707 .577 .707 r
F P
0 g
s
.35781 .27258 m .36293 .77086 L .35294 .7838 L p .707 .577 .707 r
F P
0 g
s
.17186 .65614 m .17147 .69345 L .16439 .70097 L p .707 .577 .707 r
F P
0 g
s
.1688 .72466 m .1666 .74376 L .16009 .74238 L p .707 .577 .707 r
F P
0 g
s
.16009 .74238 m .16229 .72328 L .1688 .72466 L p .707 .577 .707 r
F P
0 g
s
.33083 .62315 m .32735 .57064 L .34847 .57932 L p .707 .577 .707 r
F P
0 g
s
.18377 .58421 m .18725 .63671 L .17104 .64892 L p .707 .577 .707 r
F P
0 g
s
.18725 .63671 m .18377 .58421 L .20768 .57419 L p .707 .577 .707 r
F P
0 g
s
.61379 .26337 m .6189 .76165 L .58918 .75202 L p .707 .577 .707 r
F P
0 g
s
.58918 .75202 m .58406 .25374 L .61379 .26337 L p .707 .577 .707 r
F P
0 g
s
.17147 .69345 m .17186 .65614 L .18823 .64962 L p .707 .577 .707 r
F P
0 g
s
.32735 .57064 m .33083 .62315 L .30335 .61799 L p .707 .577 .707 r
F P
0 g
s
.30335 .61799 m .29986 .56548 L .32735 .57064 L p .707 .577 .707 r
F P
0 g
s
.18823 .64962 m .18783 .68692 L .17147 .69345 L p .707 .577 .707 r
F P
0 g
s
.1846 .72704 m .1824 .74615 L .1666 .74376 L p .707 .577 .707 r
F P
0 g
s
.1666 .74376 m .1688 .72466 L .1846 .72704 L p .707 .577 .707 r
F P
0 g
s
.38092 .26105 m .38603 .75933 L .36293 .77086 L p .707 .577 .707 r
F P
0 g
s
.38603 .75933 m .38092 .26105 L .41487 .25205 L p .707 .577 .707 r
F P
0 g
s
.21116 .6267 m .20768 .57419 L .23695 .56735 L p .707 .577 .707 r
F P
0 g
s
.20768 .57419 m .21116 .6267 L .18725 .63671 L p .707 .577 .707 r
F P
0 g
s
.29986 .56548 m .30335 .61799 L .2722 .61686 L p .707 .577 .707 r
F P
0 g
s
.2722 .61686 m .26871 .56435 L .29986 .56548 L p .707 .577 .707 r
F P
0 g
s
.24043 .61986 m .23695 .56735 L .26871 .56435 L p .707 .577 .707 r
F P
0 g
s
.23695 .56735 m .24043 .61986 L .21116 .6267 L p .707 .577 .707 r
F P
0 g
s
.18783 .68692 m .18823 .64962 L .21228 .64473 L p .707 .577 .707 r
F P
0 g
s
.26871 .56435 m .2722 .61686 L .24043 .61986 L p .707 .577 .707 r
F P
0 g
s
.34864 .74576 m .34644 .76486 L .32512 .76289 L p .707 .577 .707 r
F P
0 g
s
.32512 .76289 m .32732 .74379 L .34864 .74576 L p .707 .577 .707 r
F P
0 g
s
.58406 .25374 m .58918 .75202 L .55041 .74564 L p .707 .577 .707 r
F P
0 g
s
.55041 .74564 m .5453 .24736 L .58406 .25374 L p .707 .577 .707 r
F P
0 g
s
.21228 .64473 m .21188 .68203 L .18783 .68692 L p .707 .577 .707 r
F P
0 g
s
.20814 .73019 m .20594 .74929 L .1824 .74615 L p .707 .577 .707 r
F P
0 g
s
.1824 .74615 m .1846 .72704 L .20814 .73019 L p .707 .577 .707 r
F P
0 g
s
.33212 .64785 m .33172 .68516 L .30426 .6809 L p .707 .577 .707 r
F P
0 g
s
.30426 .6809 m .30466 .6436 L .33212 .64785 L p .707 .577 .707 r
F P
0 g
s
.41998 .75033 m .41487 .25205 L .45635 .24647 L p .707 .577 .707 r
F P
0 g
s
.41487 .25205 m .41998 .75033 L .38603 .75933 L p .707 .577 .707 r
F P
0 g
s
.21188 .68203 m .21228 .64473 L .24165 .64195 L p .707 .577 .707 r
F P
0 g
s
.73982 .68977 m .73634 .63726 L .70519 .63613 L p .707 .577 .707 r
F P
0 g
s
.73634 .63726 m .73982 .68977 L .77159 .68677 L p .707 .577 .707 r
F P
0 g
s
.77159 .68677 m .7681 .63426 L .73634 .63726 L p .707 .577 .707 r
F P
0 g
s
.5453 .24736 m .55041 .74564 L .5064 .74314 L p .707 .577 .707 r
F P
0 g
s
.5064 .74314 m .50129 .24485 L .5453 .24736 L p .707 .577 .707 r
F P
0 g
s
.32732 .74379 m .32512 .76289 L .29757 .76004 L p .707 .577 .707 r
F P
0 g
s
.29757 .76004 m .29977 .74094 L .32732 .74379 L p .707 .577 .707 r
F P
0 g
s
.7681 .63426 m .77159 .68677 L .80086 .67992 L p .707 .577 .707 r
F P
0 g
s
.80086 .67992 m .79737 .62742 L .7681 .63426 L p .707 .577 .707 r
F P
0 g
s
.30466 .6436 m .30426 .6809 L .27309 .67887 L p .707 .577 .707 r
F P
0 g
s
.27309 .67887 m .27349 .64156 L .30466 .6436 L p .707 .577 .707 r
F P
0 g
s
.24165 .64195 m .24126 .67926 L .21188 .68203 L p .707 .577 .707 r
F P
0 g
s
.46146 .74475 m .45635 .24647 L .50129 .24485 L p .707 .577 .707 r
F P
0 g
s
.45635 .24647 m .46146 .74475 L .41998 .75033 L p .707 .577 .707 r
F P
0 g
s
.24126 .67926 m .24165 .64195 L .27349 .64156 L p .707 .577 .707 r
F P
0 g
s
.23712 .73379 m .23492 .75289 L .20594 .74929 L p .707 .577 .707 r
F P
0 g
s
.20594 .74929 m .20814 .73019 L .23712 .73379 L p .707 .577 .707 r
F P
0 g
s
.70867 .68863 m .70519 .63613 L .67771 .63097 L p .707 .577 .707 r
F P
0 g
s
.70519 .63613 m .70867 .68863 L .73982 .68977 L p .707 .577 .707 r
F P
0 g
s
.27349 .64156 m .27309 .67887 L .24126 .67926 L p .707 .577 .707 r
F P
0 g
s
.50129 .24485 m .5064 .74314 L .46146 .74475 L p .707 .577 .707 r
F P
0 g
s
.79737 .62742 m .80086 .67992 L .82477 .66991 L p .707 .577 .707 r
F P
0 g
s
.82477 .66991 m .82129 .6174 L .79737 .62742 L p .707 .577 .707 r
F P
0 g
s
.29977 .74094 m .29757 .76004 L .26649 .7566 L p .707 .577 .707 r
F P
0 g
s
.26649 .7566 m .26869 .73749 L .29977 .74094 L p .707 .577 .707 r
F P
0 g
s
.26869 .73749 m .26649 .7566 L .23492 .75289 L p .707 .577 .707 r
F P
0 g
s
.23492 .75289 m .23712 .73379 L .26869 .73749 L p .707 .577 .707 r
F P
0 g
s
.68119 .68347 m .67771 .63097 L .65658 .62229 L p .707 .577 .707 r
F P
0 g
s
.67771 .63097 m .68119 .68347 L .70867 .68863 L p .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .73886 .74111 L .71576 .73854 L p .707 .577 .707 r
F P
0 g
s
.71576 .73854 m .70778 .73766 L p .72435 .75059 L .707 .577 .707 r
F P
0 g
s
.73666 .76021 m .71576 .73854 L .72435 .75059 L .707 .577 .707 r
F
.70778 .73766 m .70558 .75676 L .73666 .76021 L p F P
0 g
s
.70558 .75676 m .70778 .73766 L .68686 .7355 L p .707 .577 .707 r
F P
0 g
s
.68686 .7355 m .68023 .73481 L p .69196 .74497 L .707 .577 .707 r
F P
0 g
s
.70558 .75676 m .68686 .7355 L .69196 .74497 L .707 .577 .707 r
F
.68023 .73481 m .67803 .75392 L .70558 .75676 L p F P
0 g
s
.67803 .75392 m .68023 .73481 L .66375 .73329 L p .707 .577 .707 r
F P
0 g
s
.66375 .73329 m .65892 .73284 L p .66583 .74046 L .707 .577 .707 r
F P
0 g
s
.67803 .75392 m .66375 .73329 L .66583 .74046 L .707 .577 .707 r
F
.65892 .73284 m .65672 .75194 L .67803 .75392 L p F P
0 g
s
.6601 .73627 m .66026 .72118 L p .6479 .69168 L .707 .577 .707 r
F P
0 g
s
.66026 .72118 m .66049 .69896 L .65251 .69435 L p .707 .577 .707 r
F P
0 g
s
.65251 .69435 m .6479 .69168 L p .66026 .72118 L .707 .577 .707 r
F P
0 g
s
.68116 .74234 m .68134 .72523 L p .66049 .69896 L .707 .577 .707 r
F P
0 g
s
.68134 .72523 m .68155 .70503 L .66844 .70125 L p .707 .577 .707 r
F P
0 g
s
.66844 .70125 m .66049 .69896 L p .68134 .72523 L .707 .577 .707 r
F P
0 g
s
.70861 .74659 m .7088 .72879 L p .68155 .70503 L .707 .577 .707 r
F P
0 g
s
.7088 .72879 m .70901 .70929 L .69315 .70683 L p .707 .577 .707 r
F P
0 g
s
.69315 .70683 m .68155 .70503 L p .7088 .72879 L .707 .577 .707 r
F P
0 g
s
.73886 .74111 m .73666 .76021 L .76394 .76341 L p .707 .577 .707 r
F P
0 g
s
.76394 .76341 m .76824 .76391 L p .75882 .7566 L .707 .577 .707 r
F P
0 g
s
.75882 .7566 m .73886 .74111 L .76394 .76341 L .707 .577 .707 r
F
.76824 .76391 m .77044 .74481 L .73886 .74111 L p F P
0 g
s
.73979 .74863 m .73997 .73152 L p .70901 .70929 L .707 .577 .707 r
F P
0 g
s
.73997 .73152 m .74018 .71132 L .72399 .71027 L p .707 .577 .707 r
F P
0 g
s
.72399 .71027 m .70901 .70929 L p .73997 .73152 L .707 .577 .707 r
F P
0 g
s
.77044 .74481 m .76824 .76391 L .79307 .767 L p .707 .577 .707 r
F P
0 g
s
.79307 .767 m .79721 .76751 L p .78903 .76058 L .707 .577 .707 r
F P
0 g
s
.78903 .76058 m .77044 .74481 L .79307 .767 L .707 .577 .707 r
F
.79721 .76751 m .79941 .74841 L .77044 .74481 L p F P
0 g
s
.77162 .74824 m .77178 .73315 L p .74018 .71132 L .707 .577 .707 r
F P
0 g
s
.77178 .73315 m .77201 .71093 L .75791 .71111 L p .707 .577 .707 r
F P
0 g
s
.75791 .71111 m .74018 .71132 L p .77178 .73315 L .707 .577 .707 r
F P
0 g
s
.74018 .71132 m .73979 .74863 L .77162 .74824 L p .707 .577 .707 r
F P
0 g
s
.82129 .6174 m .82477 .66991 L .84098 .6577 L p .707 .577 .707 r
F P
0 g
s
.84098 .6577 m .8375 .6052 L .82129 .6174 L p .707 .577 .707 r
F P
0 g
s
.77201 .71093 m .77162 .74824 L .801 .74546 L p .707 .577 .707 r
F P
0 g
s
.801 .74546 m .80139 .70816 L .77201 .71093 L p .707 .577 .707 r
F P
0 g
s
.70901 .70929 m .70861 .74659 L .73979 .74863 L p .707 .577 .707 r
F P
0 g
s
.66006 .6748 m .65658 .62229 L .64388 .61094 L p .707 .577 .707 r
F P
0 g
s
.65658 .62229 m .66006 .6748 L .68119 .68347 L p .707 .577 .707 r
F P
0 g
s
.80139 .70816 m .801 .74546 L .82505 .74057 L p .707 .577 .707 r
F P
0 g
s
.82505 .74057 m .82544 .70327 L .80139 .70816 L p .707 .577 .707 r
F P
0 g
s
.68155 .70503 m .68116 .74234 L .70861 .74659 L p .707 .577 .707 r
F P
0 g
s
.79941 .74841 m .79721 .76751 L .82075 .77066 L p .707 .577 .707 r
F P
0 g
s
.82075 .77066 m .82295 .75156 L .79941 .74841 L p .707 .577 .707 r
F P
0 g
s
.8375 .6052 m .84098 .6577 L .84791 .6445 L p .707 .577 .707 r
F P
0 g
s
.84791 .6445 m .84443 .59199 L .8375 .6052 L p .707 .577 .707 r
F P
0 g
s
.66049 .69896 m .6601 .73627 L .68116 .74234 L p .707 .577 .707 r
F P
0 g
s
.82544 .70327 m .82505 .74057 L .84141 .73405 L p .707 .577 .707 r
F P
0 g
s
.84141 .73405 m .84181 .69674 L .82544 .70327 L p .707 .577 .707 r
F P
0 g
s
.64388 .61094 m .64736 .66345 L .66006 .6748 L p .707 .577 .707 r
F P
0 g
s
.64736 .66345 m .64388 .61094 L .64084 .59803 L p .707 .577 .707 r
F P
0 g
s
.82295 .75156 m .82075 .77066 L .83655 .77304 L p .707 .577 .707 r
F P
0 g
s
.83655 .77304 m .83875 .75394 L .82295 .75156 L p .707 .577 .707 r
F P
0 g
s
.64592 .73194 m .64372 .75104 L .65672 .75194 L p .707 .577 .707 r
F P
0 g
s
.65672 .75194 m .65892 .73284 L .64592 .73194 L p .707 .577 .707 r
F P
0 g
s
.84443 .59199 m .84791 .6445 L .84487 .63159 L p .707 .577 .707 r
F P
0 g
s
.84487 .63159 m .84139 .57909 L .84443 .59199 L p .707 .577 .707 r
F P
0 g
s
.6479 .69168 m .6475 .72899 L .6601 .73627 L p .707 .577 .707 r
F P
0 g
s
.84181 .69674 m .84141 .73405 L .84849 .72653 L p .707 .577 .707 r
F P
0 g
s
.84849 .72653 m .84889 .68922 L .84181 .69674 L p .707 .577 .707 r
F P
0 g
s
.64084 .59803 m .64432 .65054 L .64736 .66345 L p .707 .577 .707 r
F P
0 g
s
.83875 .75394 m .83655 .77304 L .84306 .77442 L p .707 .577 .707 r
F P
0 g
s
.84306 .77442 m .84526 .75532 L .83875 .75394 L p .707 .577 .707 r
F P
0 g
s
.64432 .65054 m .64084 .59803 L .64777 .58483 L p .707 .577 .707 r
F P
0 g
s
.6475 .72899 m .6479 .69168 L .645 .6839 L p .707 .577 .707 r
F P
0 g
s
.6425 .73219 m .6403 .75129 L .64372 .75104 L p .707 .577 .707 r
F P
0 g
s
.64372 .75104 m .64592 .73194 L .6425 .73219 L p .707 .577 .707 r
F P
0 g
s
.84139 .57909 m .84487 .63159 L .83217 .62024 L p .707 .577 .707 r
F P
0 g
s
.83217 .62024 m .82869 .56774 L .84139 .57909 L p .707 .577 .707 r
F P
0 g
s
.645 .6839 m .6446 .72121 L .6475 .72899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84889 .68922 m .84849 .72653 L .84559 .71875 L p .707 .577 .707 r
F P
0 g
s
.84559 .71875 m .84599 .68144 L .84889 .68922 L p .707 .577 .707 r
F P
0 g
s
.64777 .58483 m .65125 .63734 L .64432 .65054 L p .707 .577 .707 r
F P
0 g
s
.65125 .63734 m .64777 .58483 L .66398 .57262 L p .707 .577 .707 r
F P
0 g
s
.84526 .75532 m .84306 .77442 L .83965 .77468 L p .707 .577 .707 r
F P
0 g
s
.39681 .65295 m .39333 .60044 L .36218 .59931 L p .707 .577 .707 r
F P
0 g
s
.39333 .60044 m .39681 .65295 L .42858 .64995 L p .707 .577 .707 r
F P
0 g
s
.42858 .64995 m .42509 .59744 L .39333 .60044 L p .707 .577 .707 r
F P
0 g
s
.83965 .77468 m .84185 .75557 L .84526 .75532 L p .707 .577 .707 r
F P
0 g
s
.42509 .59744 m .42858 .64995 L .45785 .64311 L p .707 .577 .707 r
F P
0 g
s
.45785 .64311 m .45436 .5906 L .42509 .59744 L p .707 .577 .707 r
F P
0 g
s
.6446 .72121 m .645 .6839 L .65208 .67638 L p .707 .577 .707 r
F P
0 g
s
.36566 .65182 m .36218 .59931 L .3347 .59415 L p .707 .577 .707 r
F P
0 g
s
.36218 .59931 m .36566 .65182 L .39681 .65295 L p .707 .577 .707 r
F P
0 g
s
.82869 .56774 m .83217 .62024 L .81104 .61157 L p .707 .577 .707 r
F P
0 g
s
.81104 .61157 m .80756 .55906 L .82869 .56774 L p .707 .577 .707 r
F P
0 g
s
.64902 .73357 m .64682 .75268 L .6403 .75129 L p .707 .577 .707 r
F P
0 g
s
.6403 .75129 m .6425 .73219 L .64902 .73357 L p .707 .577 .707 r
F P
0 g
s
.45436 .5906 m .45785 .64311 L .48176 .63309 L p .707 .577 .707 r
F P
0 g
s
.48176 .63309 m .47828 .58059 L .45436 .5906 L p .707 .577 .707 r
F P
0 g
s
.65208 .67638 m .65168 .71369 L .6446 .72121 L p .707 .577 .707 r
F P
0 g
s
.66398 .57262 m .66746 .62513 L .65125 .63734 L p .707 .577 .707 r
F P
0 g
s
.84599 .68144 m .84559 .71875 L .833 .71147 L p .707 .577 .707 r
F P
0 g
s
.833 .71147 m .83339 .67416 L .84599 .68144 L p .707 .577 .707 r
F P
0 g
s
.66746 .62513 m .66398 .57262 L .68789 .56261 L p .707 .577 .707 r
F P
0 g
s
.33818 .64666 m .3347 .59415 L .31357 .58547 L p .707 .577 .707 r
F P
0 g
s
.3347 .59415 m .33818 .64666 L .36566 .65182 L p .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .39585 .70429 L .37275 .70173 L p .707 .577 .707 r
F P
0 g
s
.37275 .70173 m .36477 .70085 L p .38134 .71378 L .707 .577 .707 r
F P
0 g
s
.39365 .72339 m .37275 .70173 L .38134 .71378 L .707 .577 .707 r
F
.36477 .70085 m .36257 .71995 L .39365 .72339 L p F P
0 g
s
.36257 .71995 m .36477 .70085 L .34385 .69868 L p .707 .577 .707 r
F P
0 g
s
.34385 .69868 m .33722 .698 L p .34895 .70815 L .707 .577 .707 r
F P
0 g
s
.36257 .71995 m .34385 .69868 L .34895 .70815 L .707 .577 .707 r
F
.33722 .698 m .33502 .7171 L .36257 .71995 L p F P
0 g
s
.33502 .7171 m .33722 .698 L .32074 .69647 L p .707 .577 .707 r
F P
0 g
s
.32074 .69647 m .31591 .69602 L p .32282 .70364 L .707 .577 .707 r
F P
0 g
s
.33502 .7171 m .32074 .69647 L .32282 .70364 L .707 .577 .707 r
F
.31591 .69602 m .31371 .71513 L .33502 .7171 L p F P
0 g
s
.31709 .69945 m .31725 .68437 L p .30489 .65487 L .707 .577 .707 r
F P
0 g
s
.31725 .68437 m .31748 .66215 L .30949 .65753 L p .707 .577 .707 r
F P
0 g
s
.30949 .65753 m .30489 .65487 L p .31725 .68437 L .707 .577 .707 r
F P
0 g
s
.33815 .70552 m .33833 .68841 L p .31748 .66215 L .707 .577 .707 r
F P
0 g
s
.33833 .68841 m .33854 .66821 L .32542 .66444 L p .707 .577 .707 r
F P
0 g
s
.32542 .66444 m .31748 .66215 L p .33833 .68841 L .707 .577 .707 r
F P
0 g
s
.3656 .70978 m .36579 .69197 L p .33854 .66821 L .707 .577 .707 r
F P
0 g
s
.36579 .69197 m .366 .67247 L .35014 .67001 L p .707 .577 .707 r
F P
0 g
s
.35014 .67001 m .33854 .66821 L p .36579 .69197 L .707 .577 .707 r
F P
0 g
s
.39585 .70429 m .39365 .72339 L .42093 .72659 L p .707 .577 .707 r
F P
0 g
s
.42093 .72659 m .42523 .7271 L p .41581 .71979 L .707 .577 .707 r
F P
0 g
s
.41581 .71979 m .39585 .70429 L .42093 .72659 L .707 .577 .707 r
F
.42523 .7271 m .42743 .70799 L .39585 .70429 L p F P
0 g
s
.39678 .71181 m .39696 .69471 L p .366 .67247 L .707 .577 .707 r
F P
0 g
s
.39696 .69471 m .39717 .67451 L .38098 .67345 L p .707 .577 .707 r
F P
0 g
s
.38098 .67345 m .366 .67247 L p .39696 .69471 L .707 .577 .707 r
F P
0 g
s
.42743 .70799 m .42523 .7271 L .45006 .73018 L p .707 .577 .707 r
F P
0 g
s
.45006 .73018 m .4542 .7307 L p .44602 .72376 L .707 .577 .707 r
F P
0 g
s
.44602 .72376 m .42743 .70799 L .45006 .73018 L .707 .577 .707 r
F
.4542 .7307 m .4564 .71159 L .42743 .70799 L p F P
0 g
s
.42861 .71142 m .42877 .69634 L p .39717 .67451 L .707 .577 .707 r
F P
0 g
s
.42877 .69634 m .429 .67412 L .4149 .67429 L p .707 .577 .707 r
F P
0 g
s
.4149 .67429 m .39717 .67451 L p .42877 .69634 L .707 .577 .707 r
F P
0 g
s
.39717 .67451 m .39678 .71181 L .42861 .71142 L p .707 .577 .707 r
F P
0 g
s
.80756 .55906 m .81104 .61157 L .78356 .60641 L p .707 .577 .707 r
F P
0 g
s
.78356 .60641 m .78008 .5539 L .80756 .55906 L p .707 .577 .707 r
F P
0 g
s
.84185 .75557 m .83965 .77468 L .82665 .77377 L p .707 .577 .707 r
F P
0 g
s
.47828 .58059 m .48176 .63309 L .49797 .62089 L p .707 .577 .707 r
F P
0 g
s
.49797 .62089 m .49449 .56838 L .47828 .58059 L p .707 .577 .707 r
F P
0 g
s
.82665 .77377 m .82885 .75467 L .84185 .75557 L p .707 .577 .707 r
F P
0 g
s
.429 .67412 m .42861 .71142 L .45799 .70865 L p .707 .577 .707 r
F P
0 g
s
.45799 .70865 m .45838 .67134 L .429 .67412 L p .707 .577 .707 r
F P
0 g
s
.65168 .71369 m .65208 .67638 L .66844 .66986 L p .707 .577 .707 r
F P
0 g
s
.366 .67247 m .3656 .70978 L .39678 .71181 L p .707 .577 .707 r
F P
0 g
s
.69138 .61512 m .68789 .56261 L .71717 .55577 L p .707 .577 .707 r
F P
0 g
s
.68789 .56261 m .69138 .61512 L .66746 .62513 L p .707 .577 .707 r
F P
0 g
s
.66482 .73595 m .66262 .75506 L .64682 .75268 L p .707 .577 .707 r
F P
0 g
s
.64682 .75268 m .64902 .73357 L .66482 .73595 L p .707 .577 .707 r
F P
0 g
s
.66844 .66986 m .66805 .70716 L .65168 .71369 L p .707 .577 .707 r
F P
0 g
s
.31705 .63798 m .31357 .58547 L .30087 .57413 L p .707 .577 .707 r
F P
0 g
s
.31357 .58547 m .31705 .63798 L .33818 .64666 L p .707 .577 .707 r
F P
0 g
s
.45838 .67134 m .45799 .70865 L .48204 .70376 L p .707 .577 .707 r
F P
0 g
s
.48204 .70376 m .48243 .66645 L .45838 .67134 L p .707 .577 .707 r
F P
0 g
s
.78008 .5539 m .78356 .60641 L .75241 .60527 L p .707 .577 .707 r
F P
0 g
s
.75241 .60527 m .74893 .55277 L .78008 .5539 L p .707 .577 .707 r
F P
0 g
s
.33854 .66821 m .33815 .70552 L .3656 .70978 L p .707 .577 .707 r
F P
0 g
s
.83339 .67416 m .833 .71147 L .81194 .7054 L p .707 .577 .707 r
F P
0 g
s
.81194 .7054 m .81233 .6681 L .83339 .67416 L p .707 .577 .707 r
F P
0 g
s
.4564 .71159 m .4542 .7307 L .47774 .73384 L p .707 .577 .707 r
F P
0 g
s
.72065 .60827 m .71717 .55577 L .74893 .55277 L p .707 .577 .707 r
F P
0 g
s
.71717 .55577 m .72065 .60827 L .69138 .61512 L p .707 .577 .707 r
F P
0 g
s
.47774 .73384 m .47994 .71474 L .4564 .71159 L p .707 .577 .707 r
F P
0 g
s
.74893 .55277 m .75241 .60527 L .72065 .60827 L p .707 .577 .707 r
F P
0 g
s
.49449 .56838 m .49797 .62089 L .5049 .60768 L p .707 .577 .707 r
F P
0 g
s
.5049 .60768 m .50142 .55518 L .49449 .56838 L p .707 .577 .707 r
F P
0 g
s
.66805 .70716 m .66844 .66986 L .69249 .66497 L p .707 .577 .707 r
F P
0 g
s
.82885 .75467 m .82665 .77377 L .80533 .7718 L p .707 .577 .707 r
F P
0 g
s
.80533 .7718 m .80753 .7527 L .82885 .75467 L p .707 .577 .707 r
F P
0 g
s
.31748 .66215 m .31709 .69945 L .33815 .70552 L p .707 .577 .707 r
F P
0 g
s
.48243 .66645 m .48204 .70376 L .4984 .69723 L p .707 .577 .707 r
F P
0 g
s
.4984 .69723 m .4988 .65993 L .48243 .66645 L p .707 .577 .707 r
F P
0 g
s
.30087 .57413 m .30435 .62663 L .31705 .63798 L p .707 .577 .707 r
F P
0 g
s
.68836 .7391 m .68616 .7582 L .66262 .75506 L p .707 .577 .707 r
F P
0 g
s
.66262 .75506 m .66482 .73595 L .68836 .7391 L p .707 .577 .707 r
F P
0 g
s
.69249 .66497 m .69209 .70227 L .66805 .70716 L p .707 .577 .707 r
F P
0 g
s
.30435 .62663 m .30087 .57413 L .29783 .56122 L p .707 .577 .707 r
F P
0 g
s
.47994 .71474 m .47774 .73384 L .49354 .73622 L p .707 .577 .707 r
F P
0 g
s
.49354 .73622 m .49574 .71712 L .47994 .71474 L p .707 .577 .707 r
F P
0 g
s
.81233 .6681 m .81194 .7054 L .78448 .70114 L p .707 .577 .707 r
F P
0 g
s
.78448 .70114 m .78487 .66384 L .81233 .6681 L p .707 .577 .707 r
F P
0 g
s
.69209 .70227 m .69249 .66497 L .72187 .66219 L p .707 .577 .707 r
F P
0 g
s
.3029 .69512 m .3007 .71422 L .31371 .71513 L p .707 .577 .707 r
F P
0 g
s
.31371 .71513 m .31591 .69602 L .3029 .69512 L p .707 .577 .707 r
F P
0 g
s
.80753 .7527 m .80533 .7718 L .77779 .76895 L p .707 .577 .707 r
F P
0 g
s
.50142 .55518 m .5049 .60768 L .50186 .59478 L p .707 .577 .707 r
F P
0 g
s
.50186 .59478 m .49838 .54227 L .50142 .55518 L p .707 .577 .707 r
F P
0 g
s
.77779 .76895 m .77999 .74985 L .80753 .7527 L p .707 .577 .707 r
F P
0 g
s
.30489 .65487 m .30449 .69217 L .31709 .69945 L p .707 .577 .707 r
F P
0 g
s
.78487 .66384 m .78448 .70114 L .75331 .69911 L p .707 .577 .707 r
F P
0 g
s
.75331 .69911 m .7537 .6618 L .78487 .66384 L p .707 .577 .707 r
F P
0 g
s
.72187 .66219 m .72147 .6995 L .69209 .70227 L p .707 .577 .707 r
F P
0 g
s
.71733 .7427 m .71513 .7618 L .68616 .7582 L p .707 .577 .707 r
F P
0 g
s
.68616 .7582 m .68836 .7391 L .71733 .7427 L p .707 .577 .707 r
F P
0 g
s
.4988 .65993 m .4984 .69723 L .50548 .68971 L p .707 .577 .707 r
F P
0 g
s
.50548 .68971 m .50588 .65241 L .4988 .65993 L p .707 .577 .707 r
F P
0 g
s
.72147 .6995 m .72187 .66219 L .7537 .6618 L p .707 .577 .707 r
F P
0 g
s
.29783 .56122 m .30131 .61373 L .30435 .62663 L p .707 .577 .707 r
F P
0 g
s
.7537 .6618 m .75331 .69911 L .72147 .6995 L p .707 .577 .707 r
F P
0 g
s
.77999 .74985 m .77779 .76895 L .7467 .76551 L p .707 .577 .707 r
F P
0 g
s
.49574 .71712 m .49354 .73622 L .50005 .73761 L p .707 .577 .707 r
F P
0 g
s
.7467 .76551 m .7489 .7464 L .77999 .74985 L p .707 .577 .707 r
F P
0 g
s
.50005 .73761 m .50225 .71851 L .49574 .71712 L p .707 .577 .707 r
F P
0 g
s
.30131 .61373 m .29783 .56122 L .30476 .54802 L p .707 .577 .707 r
F P
0 g
s
.7489 .7464 m .7467 .76551 L .71513 .7618 L p .707 .577 .707 r
F P
0 g
s
.71513 .7618 m .71733 .7427 L .7489 .7464 L p .707 .577 .707 r
F P
0 g
s
.30449 .69217 m .30489 .65487 L .30199 .64709 L p .707 .577 .707 r
F P
0 g
s
.29949 .69537 m .29729 .71448 L .3007 .71422 L p .707 .577 .707 r
F P
0 g
s
.3007 .71422 m .3029 .69512 L .29949 .69537 L p .707 .577 .707 r
F P
0 g
s
.49838 .54227 m .50186 .59478 L .48916 .58343 L p .707 .577 .707 r
F P
0 g
s
.48916 .58343 m .48568 .53092 L .49838 .54227 L p .707 .577 .707 r
F P
0 g
s
.30199 .64709 m .30159 .68439 L .30449 .69217 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50588 .65241 m .50548 .68971 L .50258 .68193 L p .707 .577 .707 r
F P
0 g
s
.50258 .68193 m .50298 .64463 L .50588 .65241 L p .707 .577 .707 r
F P
0 g
s
.30476 .54802 m .30824 .60052 L .30131 .61373 L p .707 .577 .707 r
F P
0 g
s
.30824 .60052 m .30476 .54802 L .32097 .53581 L p .707 .577 .707 r
F P
0 g
s
.50225 .71851 m .50005 .73761 L .49664 .73786 L p .707 .577 .707 r
F P
0 g
s
.49664 .73786 m .49884 .71876 L .50225 .71851 L p .707 .577 .707 r
F P
0 g
s
.30159 .68439 m .30199 .64709 L .30906 .63957 L p .707 .577 .707 r
F P
0 g
s
.48568 .53092 m .48916 .58343 L .46803 .57475 L p .707 .577 .707 r
F P
0 g
s
.46803 .57475 m .46455 .52224 L .48568 .53092 L p .707 .577 .707 r
F P
0 g
s
.30601 .69676 m .30381 .71586 L .29729 .71448 L p .707 .577 .707 r
F P
0 g
s
.29729 .71448 m .29949 .69537 L .30601 .69676 L p .707 .577 .707 r
F P
0 g
s
.30906 .63957 m .30867 .67687 L .30159 .68439 L p .707 .577 .707 r
F P
0 g
s
.32097 .53581 m .32445 .58832 L .30824 .60052 L p .707 .577 .707 r
F P
0 g
s
.50298 .64463 m .50258 .68193 L .48999 .67465 L p .707 .577 .707 r
F P
0 g
s
.48999 .67465 m .49038 .63735 L .50298 .64463 L p .707 .577 .707 r
F P
0 g
s
.32445 .58832 m .32097 .53581 L .34488 .52579 L p .707 .577 .707 r
F P
0 g
s
.46455 .52224 m .46803 .57475 L .44055 .56959 L p .707 .577 .707 r
F P
0 g
s
.44055 .56959 m .43707 .51708 L .46455 .52224 L p .707 .577 .707 r
F P
0 g
s
.49884 .71876 m .49664 .73786 L .48364 .73696 L p .707 .577 .707 r
F P
0 g
s
.48364 .73696 m .48584 .71785 L .49884 .71876 L p .707 .577 .707 r
F P
0 g
s
.30867 .67687 m .30906 .63957 L .32543 .63304 L p .707 .577 .707 r
F P
0 g
s
.34837 .5783 m .34488 .52579 L .37415 .51895 L p .707 .577 .707 r
F P
0 g
s
.34488 .52579 m .34837 .5783 L .32445 .58832 L p .707 .577 .707 r
F P
0 g
s
.32181 .69914 m .31961 .71824 L .30381 .71586 L p .707 .577 .707 r
F P
0 g
s
.30381 .71586 m .30601 .69676 L .32181 .69914 L p .707 .577 .707 r
F P
0 g
s
.32543 .63304 m .32503 .67035 L .30867 .67687 L p .707 .577 .707 r
F P
0 g
s
.43707 .51708 m .44055 .56959 L .4094 .56846 L p .707 .577 .707 r
F P
0 g
s
.4094 .56846 m .40592 .51595 L .43707 .51708 L p .707 .577 .707 r
F P
0 g
s
.49038 .63735 m .48999 .67465 L .46893 .66859 L p .707 .577 .707 r
F P
0 g
s
.46893 .66859 m .46932 .63128 L .49038 .63735 L p .707 .577 .707 r
F P
0 g
s
.37764 .57146 m .37415 .51895 L .40592 .51595 L p .707 .577 .707 r
F P
0 g
s
.37415 .51895 m .37764 .57146 L .34837 .5783 L p .707 .577 .707 r
F P
0 g
s
.40592 .51595 m .4094 .56846 L .37764 .57146 L p .707 .577 .707 r
F P
0 g
s
.32503 .67035 m .32543 .63304 L .34948 .62815 L p .707 .577 .707 r
F P
0 g
s
.48584 .71785 m .48364 .73696 L .46232 .73498 L p .707 .577 .707 r
F P
0 g
s
.46232 .73498 m .46452 .71588 L .48584 .71785 L p .707 .577 .707 r
F P
0 g
s
.34535 .70228 m .34315 .72139 L .31961 .71824 L p .707 .577 .707 r
F P
0 g
s
.31961 .71824 m .32181 .69914 L .34535 .70228 L p .707 .577 .707 r
F P
0 g
s
.34948 .62815 m .34908 .66546 L .32503 .67035 L p .707 .577 .707 r
F P
0 g
s
.46932 .63128 m .46893 .66859 L .44147 .66433 L p .707 .577 .707 r
F P
0 g
s
.44147 .66433 m .44186 .62702 L .46932 .63128 L p .707 .577 .707 r
F P
0 g
s
.34908 .66546 m .34948 .62815 L .37886 .62538 L p .707 .577 .707 r
F P
0 g
s
.46452 .71588 m .46232 .73498 L .43478 .73214 L p .707 .577 .707 r
F P
0 g
s
.43478 .73214 m .43698 .71303 L .46452 .71588 L p .707 .577 .707 r
F P
0 g
s
.44186 .62702 m .44147 .66433 L .4103 .66229 L p .707 .577 .707 r
F P
0 g
s
.4103 .66229 m .41069 .62499 L .44186 .62702 L p .707 .577 .707 r
F P
0 g
s
.37886 .62538 m .37846 .66268 L .34908 .66546 L p .707 .577 .707 r
F P
0 g
s
.37432 .70588 m .37212 .72499 L .34315 .72139 L p .707 .577 .707 r
F P
0 g
s
.34315 .72139 m .34535 .70228 L .37432 .70588 L p .707 .577 .707 r
F P
0 g
s
.37846 .66268 m .37886 .62538 L .41069 .62499 L p .707 .577 .707 r
F P
0 g
s
.41069 .62499 m .4103 .66229 L .37846 .66268 L p .707 .577 .707 r
F P
0 g
s
.43698 .71303 m .43478 .73214 L .40369 .72869 L p .707 .577 .707 r
F P
0 g
s
.40369 .72869 m .40589 .70959 L .43698 .71303 L p .707 .577 .707 r
F P
0 g
s
.40589 .70959 m .40369 .72869 L .37212 .72499 L p .707 .577 .707 r
F P
0 g
s
.37212 .72499 m .37432 .70588 L .40589 .70959 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo3@00R7oo001lOol<0006FUH00`00FUIJEP04FUH9001oOol007Aoo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Uoo`00LGoo0`0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01UYF1000MGoo001^Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001aOol006]oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<006io
o`00JGoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P00KGoo001WOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000
Jgoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000JWoo001TOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Moo`00Hgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
Igoo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`00Igoo001ROol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001WOol0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Igoo001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001W
Ool0069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo
001ROol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0
069oo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
HWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001R
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00HWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001ROol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol0069oo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00
Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo00@005YFFUH000IJEP03
001JEP0000P000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF0000Igoo001SOol01000FUIJEP000UYF1P0015YF00<005YFFUH00UYF2000
0UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH0001WOol006=oo`03001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYF
FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
06Moo`00HGoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001OOol20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005eo
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Moo`00Fgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001IOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06
001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001F
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001EOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000JOol?000nOol005Aoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Aoo`H000AJEP03001JEUYF00IJEP03001J
EP0000<003Yoo`00E7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0047oo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo0018Ool=00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0049oo`H000AJEP03
001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl0
00IJEP03001JEUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000Qoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP80035oo`00?Woo100000=JEP00FUH01eYF00<005YFFUH01EYF00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF00<005YFFUH01UYF10000UYF00<005YF
FUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
1Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00<7oo000jOol40005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH01UYF00<005YFFUH02EYF1@0015YF
00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001Goo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002ioo`00>7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEUYF00=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF009JEP<00004FUH005YFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20004Ool00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000fOol20003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00@005YFFUIJEP800005FUH005YFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000UYF0P000UYF0P0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00@005YFFUH000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH01000FUH000000eYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP@0
0003FUH005YF00=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P001EYF00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;7oo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20002FUH30002FUH01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00UYF100035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002aoo`00;goo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH0
15YF1`001UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00
FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
00=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool002eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00@0
01Moo`D000EJEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP05001JEUYFFUH0
0005FUH4000POol20003FUH01@00FUIJEUYF0000;7oo000]Ool00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF
00000eYF10008goo0`0000=JEP00FUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH6000<Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH01P00FUIJEUYF
001JEP8000=JEP80021oo`800003FUH005YF008000=JEP8002]oo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00@001=oo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH00`00FUH0
000A0008FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP8000EJEP04001JEP00000LOol2
0003FUH01@00FUIJEUYF00000UYF0P00:goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF1000
5goo00D005YFFUIJEP0000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP0
0003FUH005YF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH4000015YF001JEUYF0`001EYF00D005YFFUIJEP0001Qoo`<000EJEP03001J
EUYF009JEP@002]oo`00;Goo00@005YFFUH000AJEP04001JEUYFFUH2000LOol01000FUIJEP000eYF
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH00000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00004FUH0
05YF0003FUH60003FUH00`00Oomoo`0BOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH0
0000:goo000]Ool01000FUIJEP0015YF00@005YF000001moo`H000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH0000000EJEP04001JEUYFFUH9
0009Ool70005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000[Ool002ioo`03001JEP0000AJEP80
021oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00;Woo00<005YF00000UYF
0P000UYF0`001goo4@000Woo100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
0000:goo000^Ool00`00FUH000020005FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH500000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002ioo`06001JEP00FUH0
05YF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;7oo000^Ool20002FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool002ioo`@000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP03001oogoo02]oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF5`001UYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001oo`00009JEP03001JEUYF00=JEP03001JEUYF00EJEQ/000IJEP03
001JEUYF008002ioo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009oo`03001JEP0000EJEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH50002FUH3000`Ool002ioo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP/00003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPX000=JEP03001JEUYF008000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`800003FUH00000008000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080039o
o`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP8000EJEP03001JEUYF00=JEQP000AJEP03001JEUYF00=JEP@0009JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
031oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000^Ool002ioo`03
001JEP0000AJEP03001JEUYF00=JEQ`000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool002ioo`03001JEP0000AJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00AJEP8000EJEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool002io
o`03001JEP0000=JEP<0009JEP04001JEUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP020003
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20005FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06
001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo00@005YF001JEP80
00EJEP03001JEUYF00EJEP04001JEUYFFUHB0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002]oo`00;Woo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00:goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP0:00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P0015YF
00@005YFFUIJEPL00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01P00FUH00000FUH000=JEP03001JEUYF00=JEPL0011oo`P000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000[Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YF00000`000UYF00@005YFFUIJ
EP8001Moo`H000AJEP04001JEUYFFUH2000[Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF20002EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0002FUH30002FUH00`00FUH0000<
000@Ool50003FUH300000eYF001JEP02FUH2000[Ool0031oo`800003FUH005YF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF009JEP09OomJEUYFFUH005YF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPd000YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP04FUH30003FUH2000[Ool0039oo`<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP05OomJEUYF001JEP040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF3@000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000=JEP000000:goo000eOol300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP09000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002ioo`L000=o
o`D000=JEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002]oo`00;Woo3P0000=oo`0000001P000UYF1@001UYF00<005YFFUH00UYF1P001goo2P00
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000:goo000^Ool00`00FUH00003FUH01000FUIJEUYF7`003Goo00@005YFFUH000EJ
EPX000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00@005YFFUIJEPl001Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001@001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3P003Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00EJEQ4000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP06001JEP00FUH005YF1P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@001Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH01000FUIJEUYF1`00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0035oo`00;Goo
10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEP`0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001J
EUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000fOol0035oo`H000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001J
EUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09FUH<0005FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHF000gOol003Moo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP8000YJEPL000IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00H0035o
o`00?Woo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02EYF0P002UYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF00<005YF00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEQ0002aoo`00Agoo2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF00000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02EYF0P002UYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF00<005YF00001EYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000/Ool0051oo`l000=JEP03001JEP00009JEP04001JEUYFFUH20005FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
000015YF00<005YF00000UYF1`001goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00Ggoo1P000UYF00@005YFFUH000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP8000UJEP04001JEUYFFUH20002FUH00`00
FUH00002000GOol90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001T
Ool00`00FUIJEP040007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0QOol80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo0018Ool3000IOol01000FUIJEP000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P0000=JEP000000:Goo1P000eYF00@005YFFUIJEP8002eoo`00Agoo1@0067oo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01`00:7oo2@00;Goo0017Ool5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000?001HOol004Moo`D001Qo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP09001COol0
04Qoo`<001Uoo`8000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00Dgoo001TOol20004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH000001UYF00<005YFFUH015YF00@005YFFUIJEP8005=oo`00IGoo00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00=oo`00
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00IGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00IWoo0P000UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001Woo2`00
0UYF0P00E7oo001XOol30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P004goo1000E7oo001ZOol20006FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0
0000KGoo001/Ool20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH4001_Ool006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPH006moo`00LGoo10002EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00000P0000=oo`0000000`00Kgoo001eOol60003
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF2P0017oo1@00Kgoo001kOol90006FUH0
0`00FUIJEP04FUH:000?Ool3001`Ool008Aoo`d008aoo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60003 .74268 m .59787 .68883 L .56671 .68741 L p .707 .577 .707 r
F P
0 g
s
.59787 .68883 m .60003 .74268 L .63184 .74051 L p .707 .577 .707 r
F P
0 g
s
.63184 .74051 m .62968 .68666 L .59787 .68883 L p .707 .577 .707 r
F P
0 g
s
.62968 .68666 m .63184 .74051 L .66118 .73497 L p .707 .577 .707 r
F P
0 g
s
.66118 .73497 m .65902 .68112 L .62968 .68666 L p .707 .577 .707 r
F P
0 g
s
.56887 .74126 m .56671 .68741 L .53924 .68253 L p .707 .577 .707 r
F P
0 g
s
.56671 .68741 m .56887 .74126 L .60003 .74268 L p .707 .577 .707 r
F P
0 g
s
.65902 .68112 m .66118 .73497 L .68518 .72659 L p .707 .577 .707 r
F P
0 g
s
.68518 .72659 m .68302 .67274 L .65902 .68112 L p .707 .577 .707 r
F P
0 g
s
.60011 .78226 m .60036 .74505 L .56919 .74307 L p .707 .577 .707 r
F P
0 g
s
.60036 .74505 m .60011 .78226 L .63195 .78173 L p .707 .577 .707 r
F P
0 g
s
.63195 .78173 m .63219 .74451 L .60036 .74505 L p .707 .577 .707 r
F P
0 g
s
.5414 .73639 m .53924 .68253 L .51816 .67469 L p .707 .577 .707 r
F P
0 g
s
.53924 .68253 m .5414 .73639 L .56887 .74126 L p .707 .577 .707 r
F P
0 g
s
.63219 .74451 m .63195 .78173 L .66133 .77872 L p .707 .577 .707 r
F P
0 g
s
.66133 .77872 m .66157 .74151 L .63219 .74451 L p .707 .577 .707 r
F P
0 g
s
.56894 .78028 m .56919 .74307 L .54173 .73876 L p .707 .577 .707 r
F P
0 g
s
.56919 .74307 m .56894 .78028 L .60011 .78226 L p .707 .577 .707 r
F P
0 g
s
.59777 .8126 m .59914 .7935 L .568 .79065 L p .707 .577 .707 r
F P
0 g
s
.59914 .7935 m .59777 .8126 L .6295 .81458 L p .707 .577 .707 r
F P
0 g
s
.6295 .81458 m .63088 .79548 L .59914 .7935 L p .707 .577 .707 r
F P
0 g
s
.68302 .67274 m .68518 .72659 L .70149 .7162 L p .707 .577 .707 r
F P
0 g
s
.70149 .7162 m .69933 .66235 L .68302 .67274 L p .707 .577 .707 r
F P
0 g
s
.568 .79065 m .56663 .80975 L .59777 .8126 L p .707 .577 .707 r
F P
0 g
s
.63088 .79548 m .6295 .81458 L .65873 .81549 L p .707 .577 .707 r
F P
0 g
s
.65873 .81549 m .6601 .79639 L .63088 .79548 L p .707 .577 .707 r
F P
0 g
s
.66157 .74151 m .66133 .77872 L .68538 .77354 L p .707 .577 .707 r
F P
0 g
s
.68538 .77354 m .68562 .73633 L .66157 .74151 L p .707 .577 .707 r
F P
0 g
s
.54173 .73876 m .54148 .77597 L .56894 .78028 L p .707 .577 .707 r
F P
0 g
s
.56663 .80975 m .568 .79065 L .54051 .78721 L p .707 .577 .707 r
F P
0 g
s
.54051 .78721 m .53914 .80631 L .56663 .80975 L p .707 .577 .707 r
F P
0 g
s
.51816 .67469 m .52032 .72854 L .5414 .73639 L p .707 .577 .707 r
F P
0 g
s
.54148 .77597 m .54173 .73876 L .52067 .73254 L p .707 .577 .707 r
F P
0 g
s
.52032 .72854 m .51816 .67469 L .50552 .66464 L p .707 .577 .707 r
F P
0 g
s
.6601 .79639 m .65873 .81549 L .68259 .81525 L p .707 .577 .707 r
F P
0 g
s
.68259 .81525 m .68396 .79615 L .6601 .79639 L p .707 .577 .707 r
F P
0 g
s
.52067 .73254 m .52043 .76976 L .54148 .77597 L p .707 .577 .707 r
F P
0 g
s
.53914 .80631 m .54051 .78721 L .51936 .78351 L p .707 .577 .707 r
F P
0 g
s
.51936 .78351 m .51798 .80261 L .53914 .80631 L p .707 .577 .707 r
F P
0 g
s
.68562 .73633 m .68538 .77354 L .70175 .76669 L p .707 .577 .707 r
F P
0 g
s
.70175 .76669 m .70199 .72948 L .68562 .73633 L p .707 .577 .707 r
F P
0 g
s
.69933 .66235 m .70149 .7162 L .70851 .70481 L p .707 .577 .707 r
F P
0 g
s
.70851 .70481 m .70635 .65096 L .69933 .66235 L p .707 .577 .707 r
F P
0 g
s
.50552 .66464 m .50768 .71849 L .52032 .72854 L p .707 .577 .707 r
F P
0 g
s
.52043 .76976 m .52067 .73254 L .50808 .72503 L p .707 .577 .707 r
F P
0 g
s
.68396 .79615 m .68259 .81525 L .69874 .81388 L p .707 .577 .707 r
F P
0 g
s
.69874 .81388 m .70011 .79478 L .68396 .79615 L p .707 .577 .707 r
F P
0 g
s
.50768 .71849 m .50552 .66464 L .50257 .65337 L p .707 .577 .707 r
F P
0 g
s
.50808 .72503 m .50783 .76224 L .52043 .76976 L p .707 .577 .707 r
F P
0 g
s
.51798 .80261 m .51936 .78351 L .50661 .77992 L p .707 .577 .707 r
F P
0 g
s
.50661 .77992 m .50523 .79902 L .51798 .80261 L p .707 .577 .707 r
F P
0 g
s
.70199 .72948 m .70175 .76669 L .70883 .75885 L p .707 .577 .707 r
F P
0 g
s
.70883 .75885 m .70907 .72164 L .70199 .72948 L p .707 .577 .707 r
F P
0 g
s
.4885 .82526 m .48534 .32556 L .44133 .32299 L p .707 .577 .707 r
F P
0 g
s
.50257 .65337 m .50473 .70722 L .50768 .71849 L p .707 .577 .707 r
F P
0 g
s
.50783 .76224 m .50808 .72503 L .50518 .71696 L p .707 .577 .707 r
F P
0 g
s
.50473 .70722 m .50257 .65337 L .5096 .64199 L p .707 .577 .707 r
F P
0 g
s
.50518 .71696 m .50493 .75417 L .50783 .76224 L p .707 .577 .707 r
F P
0 g
s
.50523 .79902 m .50661 .77992 L .50351 .77678 L p .707 .577 .707 r
F P
0 g
s
.50351 .77678 m .50214 .79588 L .50523 .79902 L p .707 .577 .707 r
F P
0 g
s
.5096 .64199 m .51175 .69584 L .50473 .70722 L p .707 .577 .707 r
F P
0 g
s
.50493 .75417 m .50518 .71696 L .51226 .70912 L p .707 .577 .707 r
F P
0 g
s
.51175 .69584 m .5096 .64199 L .52591 .63159 L p .707 .577 .707 r
F P
0 g
s
.51226 .70912 m .51202 .74633 L .50493 .75417 L p .707 .577 .707 r
F P
0 g
s
.50214 .79588 m .50351 .77678 L .51038 .77441 L p .707 .577 .707 r
F P
0 g
s
.51038 .77441 m .509 .79351 L .50214 .79588 L p .707 .577 .707 r
F P
0 g
s
.52591 .63159 m .52806 .68545 L .51175 .69584 L p .707 .577 .707 r
F P
0 g
s
.51202 .74633 m .51226 .70912 L .52863 .70227 L p .707 .577 .707 r
F P
0 g
s
.52863 .70227 m .52838 .73948 L .51202 .74633 L p .707 .577 .707 r
F P
0 g
s
.509 .79351 m .51038 .77441 L .52653 .77304 L p .707 .577 .707 r
F P
0 g
s
.52653 .77304 m .52515 .79214 L .509 .79351 L p .707 .577 .707 r
F P
0 g
s
.52515 .79214 m .52653 .77304 L .55038 .7728 L p .707 .577 .707 r
F P
0 g
s
.55038 .7728 m .54901 .7919 L .52515 .79214 L p .707 .577 .707 r
F P
0 g
s
.48534 .32556 m .4885 .82526 L .53344 .82384 L p .707 .577 .707 r
F P
0 g
s
.52806 .68545 m .52591 .63159 L .5499 .62322 L p .707 .577 .707 r
F P
0 g
s
.5499 .62322 m .55206 .67707 L .52806 .68545 L p .707 .577 .707 r
F P
0 g
s
.52838 .73948 m .52863 .70227 L .55268 .69709 L p .707 .577 .707 r
F P
0 g
s
.55268 .69709 m .55244 .7343 L .52838 .73948 L p .707 .577 .707 r
F P
0 g
s
.53344 .82384 m .53028 .32414 L .48534 .32556 L p .707 .577 .707 r
F P
0 g
s
.70635 .65096 m .70851 .70481 L .70556 .69354 L p .707 .577 .707 r
F P
0 g
s
.70556 .69354 m .7034 .63969 L .70635 .65096 L p .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .5499 .62322 L .55178 .62286 L p .707 .577 .707 r
F P
0 g
s
.55178 .62286 m .57924 .61767 L p .55844 .66314 L .707 .577 .707 r
F P
0 g
s
.55206 .67707 m .55178 .62286 L .55844 .66314 L .707 .577 .707 r
F
.5814 .67153 m .57924 .61767 L .61105 .61551 L p F P
0 g
s
.57924 .61767 m .5814 .67153 L .55206 .67707 L p .707 .577 .707 r
F P
0 g
s
.61105 .61551 m .61321 .66936 L .5814 .67153 L p .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .55268 .69709 L .56291 .69604 L p .707 .577 .707 r
F P
0 g
s
.56291 .69604 m .58206 .69408 L p .56154 .72194 L .707 .577 .707 r
F P
0 g
s
.55244 .7343 m .56291 .69604 L .56154 .72194 L .707 .577 .707 r
F
.58206 .69408 m .58182 .73129 L .55244 .7343 L p F P
0 g
s
.58182 .73129 m .58206 .69408 L .61389 .69354 L p .707 .577 .707 r
F P
0 g
s
.61389 .69354 m .61365 .73076 L .58182 .73129 L p .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .57961 .77371 L .58581 .7741 L p .707 .577 .707 r
F P
0 g
s
.58581 .7741 m .61134 .77569 L p .58405 .78981 L .707 .577 .707 r
F P
0 g
s
.57824 .79281 m .58581 .7741 L .58405 .78981 L .707 .577 .707 r
F
.64221 .61693 m .64437 .67078 L .61321 .66936 L p F P
0 g
s
.61321 .66936 m .61105 .61551 L .64221 .61693 L p .707 .577 .707 r
F P
0 g
s
.64507 .69553 m .64482 .73274 L .61365 .73076 L p .707 .577 .707 r
F P
0 g
s
.61365 .73076 m .61389 .69354 L .64507 .69553 L p .707 .577 .707 r
F P
0 g
s
.64248 .77854 m .64111 .79764 L .61377 .79514 L p .707 .577 .707 r
F P
0 g
s
.61377 .79514 m .60997 .79479 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.61386 .79285 m .64248 .77854 L .61377 .79514 L .707 .577 .707 r
F
.64111 .79764 m .64248 .77854 L .66997 .78198 L p F P
0 g
s
.60997 .79479 m .61134 .77569 L .61453 .77598 L p .707 .577 .707 r
F P
0 g
s
.61453 .77598 m .64248 .77854 L p .61386 .79285 L .707 .577 .707 r
F P
0 g
s
.60997 .79479 m .61453 .77598 L .61386 .79285 L .707 .577 .707 r
F
.64198 .78635 m .63882 .28665 L .63376 .29299 L p F P
0 g
s
.63376 .29299 m .62882 .29916 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.64198 .78635 m .63376 .29299 L .63072 .3693 L .707 .577 .707 r
F
.63199 .79886 m .64198 .78635 L p .63072 .3693 L F P
0 g
s
.62882 .29916 m .62947 .40074 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.62947 .40074 m .63199 .79886 L p .63072 .3693 L .707 .577 .707 r
F P
0 g
s
.61134 .77569 m .60997 .79479 L .57824 .79281 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .63199 .79886 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60572 .31026 m .60743 .58166 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60743 .58166 m .60888 .80996 L p .61614 .50415 L .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .57829 .40525 L .57456 .76058 L .707 .577 .707 r
F
.57176 .31887 m .57295 .50625 L p .57829 .40525 L F P
0 g
s
.57295 .50625 m .57456 .76058 L p .57829 .40525 L .707 .577 .707 r
F P
0 g
s
.54901 .7919 m .55038 .7728 L .57961 .77371 L p .707 .577 .707 r
F P
0 g
s
.57961 .77371 m .57824 .79281 L .54901 .7919 L p .707 .577 .707 r
F P
0 g
s
.57456 .76058 m .57492 .81857 L .58378 .81633 L p .707 .577 .707 r
F P
0 g
s
.58378 .81633 m .60888 .80996 L p .57456 .76058 L .707 .577 .707 r
F P
0 g
s
.53028 .32414 m .53344 .82384 L .57492 .81857 L p .707 .577 .707 r
F P
0 g
s
.57492 .81857 m .57176 .31887 L .53028 .32414 L p .707 .577 .707 r
F P
0 g
s
.44449 .82269 m .44133 .32299 L .40257 .31668 L p .707 .577 .707 r
F P
0 g
s
.44133 .32299 m .44449 .82269 L .4885 .82526 L p .707 .577 .707 r
F P
0 g
s
.70011 .79478 m .69874 .81388 L .7056 .81151 L p .707 .577 .707 r
F P
0 g
s
.7056 .81151 m .70697 .79241 L .70011 .79478 L p .707 .577 .707 r
F P
0 g
s
.60888 .80996 m .60572 .31026 L .57176 .31887 L p .707 .577 .707 r
F P
0 g
s
.70907 .72164 m .70883 .75885 L .70593 .75078 L p .707 .577 .707 r
F P
0 g
s
.70593 .75078 m .70618 .71356 L .70907 .72164 L p .707 .577 .707 r
F P
0 g
s
.7034 .63969 m .70556 .69354 L .69292 .6835 L p .707 .577 .707 r
F P
0 g
s
.69292 .6835 m .69077 .62964 L .7034 .63969 L p .707 .577 .707 r
F P
0 g
s
.40573 .81638 m .40257 .31668 L .37284 .30724 L p .707 .577 .707 r
F P
0 g
s
.40257 .31668 m .40573 .81638 L .44449 .82269 L p .707 .577 .707 r
F P
0 g
s
.70697 .79241 m .7056 .81151 L .70251 .80837 L p .707 .577 .707 r
F P
0 g
s
.70251 .80837 m .70388 .78927 L .70697 .79241 L p .707 .577 .707 r
F P
0 g
s
.25702 .70586 m .25486 .65201 L .2237 .65059 L p .707 .577 .707 r
F P
0 g
s
.25486 .65201 m .25702 .70586 L .28883 .7037 L p .707 .577 .707 r
F P
0 g
s
.28883 .7037 m .28667 .64985 L .25486 .65201 L p .707 .577 .707 r
F P
0 g
s
.28667 .64985 m .28883 .7037 L .31817 .69815 L p .707 .577 .707 r
F P
0 g
s
.31817 .69815 m .31601 .6443 L .28667 .64985 L p .707 .577 .707 r
F P
0 g
s
.63199 .79886 m .62882 .29916 L .60572 .31026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22586 .70444 m .2237 .65059 L .19623 .64572 L p .707 .577 .707 r
F P
0 g
s
.2237 .65059 m .22586 .70444 L .25702 .70586 L p .707 .577 .707 r
F P
0 g
s
.69077 .62964 m .69292 .6835 L .67184 .67565 L p .707 .577 .707 r
F P
0 g
s
.67184 .67565 m .66968 .6218 L .69077 .62964 L p .707 .577 .707 r
F P
0 g
s
.70618 .71356 m .70593 .75078 L .69334 .74326 L p .707 .577 .707 r
F P
0 g
s
.69334 .74326 m .69358 .70605 L .70618 .71356 L p .707 .577 .707 r
F P
0 g
s
.31601 .6443 m .31817 .69815 L .34217 .68978 L p .707 .577 .707 r
F P
0 g
s
.34217 .68978 m .34001 .63593 L .31601 .6443 L p .707 .577 .707 r
F P
0 g
s
.376 .80694 m .37284 .30724 L .35506 .29561 L p .707 .577 .707 r
F P
0 g
s
.37284 .30724 m .376 .80694 L .40573 .81638 L p .707 .577 .707 r
F P
0 g
s
.2571 .74545 m .25735 .70824 L .22618 .70625 L p .707 .577 .707 r
F P
0 g
s
.25735 .70824 m .2571 .74545 L .28894 .74491 L p .707 .577 .707 r
F P
0 g
s
.28894 .74491 m .28918 .7077 L .25735 .70824 L p .707 .577 .707 r
F P
0 g
s
.19839 .69957 m .19623 .64572 L .17515 .63788 L p .707 .577 .707 r
F P
0 g
s
.19623 .64572 m .19839 .69957 L .22586 .70444 L p .707 .577 .707 r
F P
0 g
s
.28918 .7077 m .28894 .74491 L .31832 .7419 L p .707 .577 .707 r
F P
0 g
s
.31832 .7419 m .31856 .70469 L .28918 .7077 L p .707 .577 .707 r
F P
0 g
s
.70388 .78927 m .70251 .80837 L .68976 .80478 L p .707 .577 .707 r
F P
0 g
s
.68976 .80478 m .69113 .78568 L .70388 .78927 L p .707 .577 .707 r
F P
0 g
s
.22593 .74347 m .22618 .70625 L .19872 .70194 L p .707 .577 .707 r
F P
0 g
s
.22618 .70625 m .22593 .74347 L .2571 .74545 L p .707 .577 .707 r
F P
0 g
s
.25476 .77579 m .25613 .75668 L .225 .75383 L p .707 .577 .707 r
F P
0 g
s
.25613 .75668 m .25476 .77579 L .2865 .77777 L p .707 .577 .707 r
F P
0 g
s
.2865 .77777 m .28787 .75866 L .25613 .75668 L p .707 .577 .707 r
F P
0 g
s
.34001 .63593 m .34217 .68978 L .35848 .67939 L p .707 .577 .707 r
F P
0 g
s
.35848 .67939 m .35632 .62553 L .34001 .63593 L p .707 .577 .707 r
F P
0 g
s
.225 .75383 m .22362 .77294 L .25476 .77579 L p .707 .577 .707 r
F P
0 g
s
.66968 .6218 m .67184 .67565 L .64437 .67078 L p .707 .577 .707 r
F P
0 g
s
.64437 .67078 m .64221 .61693 L .66968 .6218 L p .707 .577 .707 r
F P
0 g
s
.28787 .75866 m .2865 .77777 L .31572 .77868 L p .707 .577 .707 r
F P
0 g
s
.31572 .77868 m .31709 .75958 L .28787 .75866 L p .707 .577 .707 r
F P
0 g
s
.31856 .70469 m .31832 .7419 L .34237 .73672 L p .707 .577 .707 r
F P
0 g
s
.34237 .73672 m .34262 .69951 L .31856 .70469 L p .707 .577 .707 r
F P
0 g
s
.19872 .70194 m .19847 .73916 L .22593 .74347 L p .707 .577 .707 r
F P
0 g
s
.22362 .77294 m .225 .75383 L .1975 .75039 L p .707 .577 .707 r
F P
0 g
s
.1975 .75039 m .19613 .76949 L .22362 .77294 L p .707 .577 .707 r
F P
0 g
s
.69358 .70605 m .69334 .74326 L .67228 .73705 L p .707 .577 .707 r
F P
0 g
s
.67228 .73705 m .67253 .69984 L .69358 .70605 L p .707 .577 .707 r
F P
0 g
s
.17515 .63788 m .17731 .69173 L .19839 .69957 L p .707 .577 .707 r
F P
0 g
s
.19847 .73916 m .19872 .70194 L .17766 .69573 L p .707 .577 .707 r
F P
0 g
s
.17731 .69173 m .17515 .63788 L .16251 .62783 L p .707 .577 .707 r
F P
0 g
s
.31709 .75958 m .31572 .77868 L .33958 .77844 L p .707 .577 .707 r
F P
0 g
s
.33958 .77844 m .34095 .75933 L .31709 .75958 L p .707 .577 .707 r
F P
0 g
s
.17766 .69573 m .17742 .73294 L .19847 .73916 L p .707 .577 .707 r
F P
0 g
s
.19613 .76949 m .1975 .75039 L .17635 .74669 L p .707 .577 .707 r
F P
0 g
s
.17635 .74669 m .17497 .7658 L .19613 .76949 L p .707 .577 .707 r
F P
0 g
s
.69113 .78568 m .68976 .80478 L .6686 .80108 L p .707 .577 .707 r
F P
0 g
s
.6686 .80108 m .66997 .78198 L .69113 .78568 L p .707 .577 .707 r
F P
0 g
s
.34262 .69951 m .34237 .73672 L .35874 .72988 L p .707 .577 .707 r
F P
0 g
s
.35874 .72988 m .35898 .69266 L .34262 .69951 L p .707 .577 .707 r
F P
0 g
s
.35632 .62553 m .35848 .67939 L .3655 .668 L p .707 .577 .707 r
F P
0 g
s
.3655 .668 m .36334 .61415 L .35632 .62553 L p .707 .577 .707 r
F P
0 g
s
.3571 .75796 m .35573 .77706 L .36259 .77469 L p .707 .577 .707 r
F P
0 g
s
.36259 .77469 m .36396 .75559 L .3571 .75796 L p .707 .577 .707 r
F P
0 g
s
.36039 .60288 m .36255 .65673 L .35892 .65385 L p .707 .577 .707 r
F P
0 g
s
.35892 .65385 m .34991 .64668 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.35953 .60647 m .36039 .60288 L .35892 .65385 L .707 .577 .707 r
F
.34991 .64668 m .34776 .59283 L .35959 .60224 L p F P
0 g
s
.35959 .60224 m .36039 .60288 L p .35953 .60647 L .707 .577 .707 r
F P
0 g
s
.34991 .64668 m .35959 .60224 L .35953 .60647 L .707 .577 .707 r
F
.34095 .75933 m .33958 .77844 L .35573 .77706 L p F P
0 g
s
.35573 .77706 m .3571 .75796 L .34095 .75933 L p .707 .577 .707 r
F P
0 g
s
.35898 .69266 m .35874 .72988 L .36582 .72203 L p .707 .577 .707 r
F P
0 g
s
.36582 .72203 m .36606 .68482 L .35898 .69266 L p .707 .577 .707 r
F P
0 g
s
.36317 .67675 m .36292 .71396 L .35928 .71179 L p .707 .577 .707 r
F P
0 g
s
.35928 .71179 m .35033 .70645 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35895 .68651 m .36317 .67675 L .35928 .71179 L .707 .577 .707 r
F
.35033 .70645 m .35057 .66924 L .35878 .67413 L p F P
0 g
s
.35878 .67413 m .36317 .67675 L p .35895 .68651 L .707 .577 .707 r
F P
0 g
s
.35033 .70645 m .35878 .67413 L .35895 .68651 L .707 .577 .707 r
F
.34675 .76797 m .34812 .74886 L .36079 .75243 L p F P
0 g
s
.36079 .75243 m .36087 .75246 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.34675 .76797 m .36079 .75243 L .36079 .75254 L .707 .577 .707 r
F
.35786 .73732 m .35751 .68206 L p .35764 .75416 L F P
0 g
s
.35751 .68206 m .35625 .48299 L p .35724 .67636 L .707 .577 .707 r
F P
0 g
s
.35751 .68206 m .35724 .67636 L .35764 .75416 L .707 .577 .707 r
F
.35625 .48299 m .35506 .29561 L p .35602 .46576 L F P
0 g
s
.35625 .48299 m .35602 .46576 L .35764 .75416 L .707 .577 .707 r
F
.35764 .75416 m .35602 .46576 L .35097 .28292 L F
.35506 .29561 m .35371 .29141 L p .35602 .46576 L F P
0 g
s
.35371 .29141 m .35097 .28292 L p .35602 .46576 L .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .34675 .76797 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36087 .75246 m .36082 .75313 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.36082 .75313 m .3595 .77156 L p .36079 .75254 L .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35716 .792 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35097 .28292 m .35287 .5826 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35287 .5826 m .35413 .78262 L p .35523 .63319 L .707 .577 .707 r
F P
0 g
s
.35716 .792 m .35822 .79531 L p .35764 .75416 L .707 .577 .707 r
F P
0 g
s
.35764 .75416 m .35097 .28292 L .35716 .792 L .707 .577 .707 r
F
.35822 .79531 m .35786 .73732 L p .35764 .75416 L F P
0 g
s
.36334 .61415 m .3655 .668 L .36255 .65673 L p .707 .577 .707 r
F P
0 g
s
.36255 .65673 m .36039 .60288 L .36334 .61415 L p .707 .577 .707 r
F P
0 g
s
.36606 .68482 m .36582 .72203 L .36292 .71396 L p .707 .577 .707 r
F P
0 g
s
.36292 .71396 m .36317 .67675 L .36606 .68482 L p .707 .577 .707 r
F P
0 g
s
.36396 .75559 m .36259 .77469 L .3595 .77156 L p .707 .577 .707 r
F P
0 g
s
.3595 .77156 m .36087 .75246 L .36396 .75559 L p .707 .577 .707 r
F P
0 g
s
.35506 .29561 m .35822 .79531 L .376 .80694 L p .707 .577 .707 r
F P
0 g
s
.67253 .69984 m .67228 .73705 L .64482 .73274 L p .707 .577 .707 r
F P
0 g
s
.64482 .73274 m .64507 .69553 L .67253 .69984 L p .707 .577 .707 r
F P
0 g
s
.16251 .62783 m .16467 .68168 L .17731 .69173 L p .707 .577 .707 r
F P
0 g
s
.17742 .73294 m .17766 .69573 L .16507 .68822 L p .707 .577 .707 r
F P
0 g
s
.16467 .68168 m .16251 .62783 L .15956 .61656 L p .707 .577 .707 r
F P
0 g
s
.16507 .68822 m .16482 .72543 L .17742 .73294 L p .707 .577 .707 r
F P
0 g
s
.17497 .7658 m .17635 .74669 L .1636 .7431 L p .707 .577 .707 r
F P
0 g
s
.1636 .7431 m .16222 .7622 L .17497 .7658 L p .707 .577 .707 r
F P
0 g
s
.66997 .78198 m .6686 .80108 L .64111 .79764 L p .707 .577 .707 r
F P
0 g
s
.63882 .28665 m .64198 .78635 L .63789 .77366 L p .707 .577 .707 r
F P
0 g
s
.63789 .77366 m .63473 .27396 L .63882 .28665 L p .707 .577 .707 r
F P
0 g
s
.15956 .61656 m .16172 .67041 L .16467 .68168 L p .707 .577 .707 r
F P
0 g
s
.16482 .72543 m .16507 .68822 L .16217 .68014 L p .707 .577 .707 r
F P
0 g
s
.35413 .78262 m .35097 .28292 L .36097 .27041 L p .707 .577 .707 r
F P
0 g
s
.16172 .67041 m .15956 .61656 L .16659 .60517 L p .707 .577 .707 r
F P
0 g
s
.16217 .68014 m .16193 .71736 L .16482 .72543 L p .707 .577 .707 r
F P
0 g
s
.16222 .7622 m .1636 .7431 L .1605 .73997 L p .707 .577 .707 r
F P
0 g
s
.1605 .73997 m .15913 .75907 L .16222 .7622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16659 .60517 m .16874 .65902 L .16172 .67041 L p .707 .577 .707 r
F P
0 g
s
.63473 .27396 m .63789 .77366 L .62011 .76203 L p .707 .577 .707 r
F P
0 g
s
.62011 .76203 m .61695 .26233 L .63473 .27396 L p .707 .577 .707 r
F P
0 g
s
.16193 .71736 m .16217 .68014 L .16925 .6723 L p .707 .577 .707 r
F P
0 g
s
.16874 .65902 m .16659 .60517 L .1829 .59478 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16925 .6723 m .16901 .70951 L .16193 .71736 L p .707 .577 .707 r
F P
0 g
s
.15913 .75907 m .1605 .73997 L .16737 .7376 L p .707 .577 .707 r
F P
0 g
s
.16737 .7376 m .16599 .7567 L .15913 .75907 L p .707 .577 .707 r
F P
0 g
s
.36413 .77011 m .36097 .27041 L .38407 .25931 L p .707 .577 .707 r
F P
0 g
s
.36097 .27041 m .36413 .77011 L .35413 .78262 L p .707 .577 .707 r
F P
0 g
s
.34776 .59283 m .34991 .64668 L .32883 .63884 L p .707 .577 .707 r
F P
0 g
s
.32883 .63884 m .32667 .58498 L .34776 .59283 L p .707 .577 .707 r
F P
0 g
s
.1829 .59478 m .18505 .64863 L .16874 .65902 L p .707 .577 .707 r
F P
0 g
s
.18505 .64863 m .1829 .59478 L .20689 .5864 L p .707 .577 .707 r
F P
0 g
s
.16901 .70951 m .16925 .6723 L .18562 .66545 L p .707 .577 .707 r
F P
0 g
s
.61695 .26233 m .62011 .76203 L .59039 .7526 L p .707 .577 .707 r
F P
0 g
s
.59039 .7526 m .58722 .2529 L .61695 .26233 L p .707 .577 .707 r
F P
0 g
s
.18562 .66545 m .18537 .70267 L .16901 .70951 L p .707 .577 .707 r
F P
0 g
s
.32667 .58498 m .32883 .63884 L .30136 .63397 L p .707 .577 .707 r
F P
0 g
s
.30136 .63397 m .29921 .58011 L .32667 .58498 L p .707 .577 .707 r
F P
0 g
s
.16599 .7567 m .16737 .7376 L .18352 .73622 L p .707 .577 .707 r
F P
0 g
s
.18352 .73622 m .18214 .75533 L .16599 .7567 L p .707 .577 .707 r
F P
0 g
s
.35057 .66924 m .35033 .70645 L .32927 .70023 L p .707 .577 .707 r
F P
0 g
s
.32927 .70023 m .32952 .66302 L .35057 .66924 L p .707 .577 .707 r
F P
0 g
s
.20905 .64025 m .20689 .5864 L .23623 .58086 L p .707 .577 .707 r
F P
0 g
s
.20689 .5864 m .20905 .64025 L .18505 .64863 L p .707 .577 .707 r
F P
0 g
s
.38407 .25931 m .38724 .75901 L .36413 .77011 L p .707 .577 .707 r
F P
0 g
s
.38724 .75901 m .38407 .25931 L .41803 .2507 L p .707 .577 .707 r
F P
0 g
s
.29921 .58011 m .30136 .63397 L .2702 .63254 L p .707 .577 .707 r
F P
0 g
s
.2702 .63254 m .26804 .57869 L .29921 .58011 L p .707 .577 .707 r
F P
0 g
s
.18537 .70267 m .18562 .66545 L .20967 .66027 L p .707 .577 .707 r
F P
0 g
s
.23839 .63471 m .23623 .58086 L .26804 .57869 L p .707 .577 .707 r
F P
0 g
s
.23623 .58086 m .23839 .63471 L .20905 .64025 L p .707 .577 .707 r
F P
0 g
s
.34812 .74886 m .34675 .76797 L .32559 .76427 L p .707 .577 .707 r
F P
0 g
s
.32559 .76427 m .32696 .74517 L .34812 .74886 L p .707 .577 .707 r
F P
0 g
s
.26804 .57869 m .2702 .63254 L .23839 .63471 L p .707 .577 .707 r
F P
0 g
s
.20967 .66027 m .20943 .69749 L .18537 .70267 L p .707 .577 .707 r
F P
0 g
s
.32952 .66302 m .32927 .70023 L .30181 .69592 L p .707 .577 .707 r
F P
0 g
s
.30181 .69592 m .30206 .65871 L .32952 .66302 L p .707 .577 .707 r
F P
0 g
s
.18214 .75533 m .18352 .73622 L .20737 .73598 L p .707 .577 .707 r
F P
0 g
s
.58722 .2529 m .59039 .7526 L .55162 .74628 L p .707 .577 .707 r
F P
0 g
s
.55162 .74628 m .54846 .24658 L .58722 .2529 L p .707 .577 .707 r
F P
0 g
s
.20737 .73598 m .206 .75508 L .18214 .75533 L p .707 .577 .707 r
F P
0 g
s
.20943 .69749 m .20967 .66027 L .23905 .65727 L p .707 .577 .707 r
F P
0 g
s
.73723 .67761 m .73507 .62376 L .70391 .62234 L p .707 .577 .707 r
F P
0 g
s
.73507 .62376 m .73723 .67761 L .76904 .67545 L p .707 .577 .707 r
F P
0 g
s
.76904 .67545 m .76688 .62159 L .73507 .62376 L p .707 .577 .707 r
F P
0 g
s
.76688 .62159 m .76904 .67545 L .79838 .6699 L p .707 .577 .707 r
F P
0 g
s
.79838 .6699 m .79622 .61605 L .76688 .62159 L p .707 .577 .707 r
F P
0 g
s
.42119 .7504 m .41803 .2507 L .45951 .24543 L p .707 .577 .707 r
F P
0 g
s
.41803 .2507 m .42119 .7504 L .38724 .75901 L p .707 .577 .707 r
F P
0 g
s
.30206 .65871 m .30181 .69592 L .27064 .69394 L p .707 .577 .707 r
F P
0 g
s
.27064 .69394 m .27089 .65673 L .30206 .65871 L p .707 .577 .707 r
F P
0 g
s
.70607 .67619 m .70391 .62234 L .67644 .61747 L p .707 .577 .707 r
F P
0 g
s
.70391 .62234 m .70607 .67619 L .73723 .67761 L p .707 .577 .707 r
F P
0 g
s
.32696 .74517 m .32559 .76427 L .2981 .76083 L p .707 .577 .707 r
F P
0 g
s
.2981 .76083 m .29947 .74172 L .32696 .74517 L p .707 .577 .707 r
F P
0 g
s
.23905 .65727 m .23881 .69448 L .20943 .69749 L p .707 .577 .707 r
F P
0 g
s
.23881 .69448 m .23905 .65727 L .27089 .65673 L p .707 .577 .707 r
F P
0 g
s
.27089 .65673 m .27064 .69394 L .23881 .69448 L p .707 .577 .707 r
F P
0 g
s
.206 .75508 m .20737 .73598 L .2366 .73689 L p .707 .577 .707 r
F P
0 g
s
.79622 .61605 m .79838 .6699 L .82238 .66153 L p .707 .577 .707 r
F P
0 g
s
.82238 .66153 m .82022 .60767 L .79622 .61605 L p .707 .577 .707 r
F P
0 g
s
.54846 .24658 m .55162 .74628 L .50761 .74371 L p .707 .577 .707 r
F P
0 g
s
.50761 .74371 m .50445 .24401 L .54846 .24658 L p .707 .577 .707 r
F P
0 g
s
.2366 .73689 m .23523 .756 L .206 .75508 L p .707 .577 .707 r
F P
0 g
s
.46267 .74513 m .45951 .24543 L .50445 .24401 L p .707 .577 .707 r
F P
0 g
s
.45951 .24543 m .46267 .74513 L .42119 .7504 L p .707 .577 .707 r
F P
0 g
s
.6786 .67132 m .67644 .61747 L .65536 .60962 L p .707 .577 .707 r
F P
0 g
s
.67644 .61747 m .6786 .67132 L .70607 .67619 L p .707 .577 .707 r
F P
0 g
s
.29947 .74172 m .2981 .76083 L .26696 .75798 L p .707 .577 .707 r
F P
0 g
s
.26696 .75798 m .26833 .73887 L .29947 .74172 L p .707 .577 .707 r
F P
0 g
s
.50445 .24401 m .50761 .74371 L .46267 .74513 L p .707 .577 .707 r
F P
0 g
s
.23523 .756 m .2366 .73689 L .26833 .73887 L p .707 .577 .707 r
F P
0 g
s
.73732 .73686 m .73756 .69965 L .70639 .69767 L p .707 .577 .707 r
F P
0 g
s
.73756 .69965 m .73732 .73686 L .76915 .73633 L p .707 .577 .707 r
F P
0 g
s
.76915 .73633 m .7694 .69911 L .73756 .69965 L p .707 .577 .707 r
F P
0 g
s
.26833 .73887 m .26696 .75798 L .23523 .756 L p .707 .577 .707 r
F P
0 g
s
.7694 .69911 m .76915 .73633 L .79853 .73332 L p .707 .577 .707 r
F P
0 g
s
.79853 .73332 m .79878 .69611 L .7694 .69911 L p .707 .577 .707 r
F P
0 g
s
.82022 .60767 m .82238 .66153 L .83869 .65113 L p .707 .577 .707 r
F P
0 g
s
.83869 .65113 m .83653 .59728 L .82022 .60767 L p .707 .577 .707 r
F P
0 g
s
.70615 .73488 m .70639 .69767 L .67893 .69336 L p .707 .577 .707 r
F P
0 g
s
.70639 .69767 m .70615 .73488 L .73732 .73686 L p .707 .577 .707 r
F P
0 g
s
.73497 .7602 m .73635 .7411 L .70521 .73825 L p .707 .577 .707 r
F P
0 g
s
.73635 .7411 m .73497 .7602 L .76671 .76218 L p .707 .577 .707 r
F P
0 g
s
.76671 .76218 m .76808 .74308 L .73635 .7411 L p .707 .577 .707 r
F P
0 g
s
.70521 .73825 m .70384 .75735 L .73497 .7602 L p .707 .577 .707 r
F P
0 g
s
.76808 .74308 m .76671 .76218 L .79593 .76309 L p .707 .577 .707 r
F P
0 g
s
.79593 .76309 m .79731 .74399 L .76808 .74308 L p .707 .577 .707 r
F P
0 g
s
.70384 .75735 m .70521 .73825 L .67772 .7348 L p .707 .577 .707 r
F P
0 g
s
.79878 .69611 m .79853 .73332 L .82258 .72814 L p .707 .577 .707 r
F P
0 g
s
.82258 .72814 m .82283 .69093 L .79878 .69611 L p .707 .577 .707 r
F P
0 g
s
.65536 .60962 m .65752 .66348 L .6786 .67132 L p .707 .577 .707 r
F P
0 g
s
.67893 .69336 m .67869 .73057 L .70615 .73488 L p .707 .577 .707 r
F P
0 g
s
.67772 .7348 m .67634 .75391 L .70384 .75735 L p .707 .577 .707 r
F P
0 g
s
.65752 .66348 m .65536 .60962 L .64273 .59958 L p .707 .577 .707 r
F P
0 g
s
.67869 .73057 m .67893 .69336 L .65787 .68714 L p .707 .577 .707 r
F P
0 g
s
.79731 .74399 m .79593 .76309 L .81979 .76285 L p .707 .577 .707 r
F P
0 g
s
.81979 .76285 m .82116 .74375 L .79731 .74399 L p .707 .577 .707 r
F P
0 g
s
.67634 .75391 m .67772 .7348 L .65656 .73111 L p .707 .577 .707 r
F P
0 g
s
.83653 .59728 m .83869 .65113 L .84571 .63975 L p .707 .577 .707 r
F P
0 g
s
.84571 .63975 m .84356 .58589 L .83653 .59728 L p .707 .577 .707 r
F P
0 g
s
.65787 .68714 m .65763 .72436 L .67869 .73057 L p .707 .577 .707 r
F P
0 g
s
.65656 .73111 m .65519 .75021 L .67634 .75391 L p .707 .577 .707 r
F P
0 g
s
.82283 .69093 m .82258 .72814 L .83895 .72129 L p .707 .577 .707 r
F P
0 g
s
.83895 .72129 m .8392 .68408 L .82283 .69093 L p .707 .577 .707 r
F P
0 g
s
.64273 .59958 m .64488 .65343 L .65752 .66348 L p .707 .577 .707 r
F P
0 g
s
.64488 .65343 m .64273 .59958 L .63978 .58831 L p .707 .577 .707 r
F P
0 g
s
.65763 .72436 m .65787 .68714 L .64528 .67963 L p .707 .577 .707 r
F P
0 g
s
.82116 .74375 m .81979 .76285 L .83594 .76148 L p .707 .577 .707 r
F P
0 g
s
.83594 .76148 m .83731 .74237 L .82116 .74375 L p .707 .577 .707 r
F P
0 g
s
.65519 .75021 m .65656 .73111 L .64381 .72751 L p .707 .577 .707 r
F P
0 g
s
.64528 .67963 m .64504 .71685 L .65763 .72436 L p .707 .577 .707 r
F P
0 g
s
.64381 .72751 m .64244 .74662 L .65519 .75021 L p .707 .577 .707 r
F P
0 g
s
.84356 .58589 m .84571 .63975 L .84276 .62848 L p .707 .577 .707 r
F P
0 g
s
.84276 .62848 m .84061 .57462 L .84356 .58589 L p .707 .577 .707 r
F P
0 g
s
.8392 .68408 m .83895 .72129 L .84603 .71345 L p .707 .577 .707 r
F P
0 g
s
.84603 .71345 m .84628 .67624 L .8392 .68408 L p .707 .577 .707 r
F P
0 g
s
.63978 .58831 m .64193 .64216 L .64488 .65343 L p .707 .577 .707 r
F P
0 g
s
.83731 .74237 m .83594 .76148 L .8428 .75911 L p .707 .577 .707 r
F P
0 g
s
.8428 .75911 m .84418 .74 L .83731 .74237 L p .707 .577 .707 r
F P
0 g
s
.64504 .71685 m .64528 .67963 L .64238 .67156 L p .707 .577 .707 r
F P
0 g
s
.64193 .64216 m .63978 .58831 L .6468 .57692 L p .707 .577 .707 r
F P
0 g
s
.64244 .74662 m .64381 .72751 L .64072 .72438 L p .707 .577 .707 r
F P
0 g
s
.64238 .67156 m .64214 .70877 L .64504 .71685 L p .707 .577 .707 r
F P
0 g
s
.64072 .72438 m .63934 .74348 L .64244 .74662 L p .707 .577 .707 r
F P
0 g
s
.84061 .57462 m .84276 .62848 L .83013 .61843 L p .707 .577 .707 r
F P
0 g
s
.83013 .61843 m .82797 .56458 L .84061 .57462 L p .707 .577 .707 r
F P
0 g
s
.84628 .67624 m .84603 .71345 L .84314 .70538 L p .707 .577 .707 r
F P
0 g
s
.84314 .70538 m .84338 .66816 L .84628 .67624 L p .707 .577 .707 r
F P
0 g
s
.6468 .57692 m .64896 .63077 L .64193 .64216 L p .707 .577 .707 r
F P
0 g
s
.64896 .63077 m .6468 .57692 L .66311 .56653 L p .707 .577 .707 r
F P
0 g
s
.84418 .74 m .8428 .75911 L .83971 .75597 L p .707 .577 .707 r
F P
0 g
s
.83971 .75597 m .84108 .73687 L .84418 .74 L p .707 .577 .707 r
F P
0 g
s
.39422 .6408 m .39207 .58695 L .3609 .58552 L p .707 .577 .707 r
F P
0 g
s
.39207 .58695 m .39422 .6408 L .42603 .63863 L p .707 .577 .707 r
F P
0 g
s
.42603 .63863 m .42387 .58478 L .39207 .58695 L p .707 .577 .707 r
F P
0 g
s
.64214 .70877 m .64238 .67156 L .64946 .66372 L p .707 .577 .707 r
F P
0 g
s
.42387 .58478 m .42603 .63863 L .45537 .63309 L p .707 .577 .707 r
F P
0 g
s
.45537 .63309 m .45321 .57923 L .42387 .58478 L p .707 .577 .707 r
F P
0 g
s
.36306 .63938 m .3609 .58552 L .33343 .58065 L p .707 .577 .707 r
F P
0 g
s
.3609 .58552 m .36306 .63938 L .39422 .6408 L p .707 .577 .707 r
F P
0 g
s
.64946 .66372 m .64922 .70093 L .64214 .70877 L p .707 .577 .707 r
F P
0 g
s
.63934 .74348 m .64072 .72438 L .64758 .72201 L p .707 .577 .707 r
F P
0 g
s
.64758 .72201 m .64621 .74111 L .63934 .74348 L p .707 .577 .707 r
F P
0 g
s
.82797 .56458 m .83013 .61843 L .80905 .61058 L p .707 .577 .707 r
F P
0 g
s
.80905 .61058 m .80689 .55673 L .82797 .56458 L p .707 .577 .707 r
F P
0 g
s
.45321 .57923 m .45537 .63309 L .47937 .62471 L p .707 .577 .707 r
F P
0 g
s
.47937 .62471 m .47721 .57086 L .45321 .57923 L p .707 .577 .707 r
F P
0 g
s
.84338 .66816 m .84314 .70538 L .83054 .69786 L p .707 .577 .707 r
F P
0 g
s
.83054 .69786 m .83079 .66065 L .84338 .66816 L p .707 .577 .707 r
F P
0 g
s
.66311 .56653 m .66527 .62038 L .64896 .63077 L p .707 .577 .707 r
F P
0 g
s
.33559 .6345 m .33343 .58065 L .31235 .57281 L p .707 .577 .707 r
F P
0 g
s
.33343 .58065 m .33559 .6345 L .36306 .63938 L p .707 .577 .707 r
F P
0 g
s
.66527 .62038 m .66311 .56653 L .68711 .55815 L p .707 .577 .707 r
F P
0 g
s
.39431 .70005 m .39455 .66284 L .36338 .66085 L p .707 .577 .707 r
F P
0 g
s
.39455 .66284 m .39431 .70005 L .42614 .69951 L p .707 .577 .707 r
F P
0 g
s
.42614 .69951 m .42639 .6623 L .39455 .66284 L p .707 .577 .707 r
F P
0 g
s
.42639 .6623 m .42614 .69951 L .45552 .6965 L p .707 .577 .707 r
F P
0 g
s
.45552 .6965 m .45577 .65929 L .42639 .6623 L p .707 .577 .707 r
F P
0 g
s
.64922 .70093 m .64946 .66372 L .66583 .65687 L p .707 .577 .707 r
F P
0 g
s
.84108 .73687 m .83971 .75597 L .82696 .75238 L p .707 .577 .707 r
F P
0 g
s
.82696 .75238 m .82834 .73328 L .84108 .73687 L p .707 .577 .707 r
F P
0 g
s
.47721 .57086 m .47937 .62471 L .49568 .61432 L p .707 .577 .707 r
F P
0 g
s
.49568 .61432 m .49352 .56047 L .47721 .57086 L p .707 .577 .707 r
F P
0 g
s
.36314 .69807 m .36338 .66085 L .33592 .65654 L p .707 .577 .707 r
F P
0 g
s
.36338 .66085 m .36314 .69807 L .39431 .70005 L p .707 .577 .707 r
F P
0 g
s
.80689 .55673 m .80905 .61058 L .78158 .60571 L p .707 .577 .707 r
F P
0 g
s
.78158 .60571 m .77942 .55186 L .80689 .55673 L p .707 .577 .707 r
F P
0 g
s
.39196 .72339 m .39334 .70428 L .3622 .70143 L p .707 .577 .707 r
F P
0 g
s
.39334 .70428 m .39196 .72339 L .4237 .72536 L p .707 .577 .707 r
F P
0 g
s
.4237 .72536 m .42507 .70626 L .39334 .70428 L p .707 .577 .707 r
F P
0 g
s
.3622 .70143 m .36083 .72054 L .39196 .72339 L p .707 .577 .707 r
F P
0 g
s
.42507 .70626 m .4237 .72536 L .45292 .72628 L p .707 .577 .707 r
F P
0 g
s
.45292 .72628 m .4543 .70717 L .42507 .70626 L p .707 .577 .707 r
F P
0 g
s
.66583 .65687 m .66559 .69408 L .64922 .70093 L p .707 .577 .707 r
F P
0 g
s
.64621 .74111 m .64758 .72201 L .66373 .72064 L p .707 .577 .707 r
F P
0 g
s
.36083 .72054 m .3622 .70143 L .33471 .69799 L p .707 .577 .707 r
F P
0 g
s
.45577 .65929 m .45552 .6965 L .47958 .69132 L p .707 .577 .707 r
F P
0 g
s
.47958 .69132 m .47982 .65411 L .45577 .65929 L p .707 .577 .707 r
F P
0 g
s
.31235 .57281 m .31451 .62666 L .33559 .6345 L p .707 .577 .707 r
F P
0 g
s
.66373 .72064 m .66236 .73974 L .64621 .74111 L p .707 .577 .707 r
F P
0 g
s
.33592 .65654 m .33568 .69376 L .36314 .69807 L p .707 .577 .707 r
F P
0 g
s
.68927 .612 m .68711 .55815 L .71645 .55261 L p .707 .577 .707 r
F P
0 g
s
.68711 .55815 m .68927 .612 L .66527 .62038 L p .707 .577 .707 r
F P
0 g
s
.33471 .69799 m .33333 .71709 L .36083 .72054 L p .707 .577 .707 r
F P
0 g
s
.31451 .62666 m .31235 .57281 L .29972 .56276 L p .707 .577 .707 r
F P
0 g
s
.83079 .66065 m .83054 .69786 L .80949 .69165 L p .707 .577 .707 r
F P
0 g
s
.80949 .69165 m .80973 .65444 L .83079 .66065 L p .707 .577 .707 r
F P
0 g
s
.33568 .69376 m .33592 .65654 L .31486 .65033 L p .707 .577 .707 r
F P
0 g
s
.77942 .55186 m .78158 .60571 L .75041 .60429 L p .707 .577 .707 r
F P
0 g
s
.75041 .60429 m .74826 .55044 L .77942 .55186 L p .707 .577 .707 r
F P
0 g
s
.4543 .70717 m .45292 .72628 L .47678 .72603 L p .707 .577 .707 r
F P
0 g
s
.47678 .72603 m .47815 .70693 L .4543 .70717 L p .707 .577 .707 r
F P
0 g
s
.71861 .60646 m .71645 .55261 L .74826 .55044 L p .707 .577 .707 r
F P
0 g
s
.71645 .55261 m .71861 .60646 L .68927 .612 L p .707 .577 .707 r
F P
0 g
s
.66559 .69408 m .66583 .65687 L .68988 .65169 L p .707 .577 .707 r
F P
0 g
s
.74826 .55044 m .75041 .60429 L .71861 .60646 L p .707 .577 .707 r
F P
0 g
s
.33333 .71709 m .33471 .69799 L .31355 .69429 L p .707 .577 .707 r
F P
0 g
s
.49352 .56047 m .49568 .61432 L .5027 .60293 L p .707 .577 .707 r
F P
0 g
s
.5027 .60293 m .50055 .54908 L .49352 .56047 L p .707 .577 .707 r
F P
0 g
s
.31486 .65033 m .31462 .68754 L .33568 .69376 L p .707 .577 .707 r
F P
0 g
s
.31355 .69429 m .31218 .71339 L .33333 .71709 L p .707 .577 .707 r
F P
0 g
s
.82834 .73328 m .82696 .75238 L .80581 .74868 L p .707 .577 .707 r
F P
0 g
s
.80581 .74868 m .80718 .72958 L .82834 .73328 L p .707 .577 .707 r
F P
0 g
s
.47982 .65411 m .47958 .69132 L .49594 .68448 L p .707 .577 .707 r
F P
0 g
s
.49594 .68448 m .49619 .64726 L .47982 .65411 L p .707 .577 .707 r
F P
0 g
s
.29972 .56276 m .30187 .61661 L .31451 .62666 L p .707 .577 .707 r
F P
0 g
s
.68988 .65169 m .68964 .6889 L .66559 .69408 L p .707 .577 .707 r
F P
0 g
s
.66236 .73974 m .66373 .72064 L .68759 .7204 L p .707 .577 .707 r
F P
0 g
s
.80973 .65444 m .80949 .69165 L .78203 .68734 L p .707 .577 .707 r
F P
0 g
s
.78203 .68734 m .78227 .65013 L .80973 .65444 L p .707 .577 .707 r
F P
0 g
s
.68759 .7204 m .68621 .7395 L .66236 .73974 L p .707 .577 .707 r
F P
0 g
s
.30187 .61661 m .29972 .56276 L .29677 .55149 L p .707 .577 .707 r
F P
0 g
s
.31462 .68754 m .31486 .65033 L .30227 .64282 L p .707 .577 .707 r
F P
0 g
s
.47815 .70693 m .47678 .72603 L .49293 .72466 L p .707 .577 .707 r
F P
0 g
s
.49293 .72466 m .4943 .70556 L .47815 .70693 L p .707 .577 .707 r
F P
0 g
s
.68964 .6889 m .68988 .65169 L .71926 .64868 L p .707 .577 .707 r
F P
0 g
s
.31218 .71339 m .31355 .69429 L .3008 .6907 L p .707 .577 .707 r
F P
0 g
s
.30227 .64282 m .30203 .68003 L .31462 .68754 L p .707 .577 .707 r
F P
0 g
s
.3008 .6907 m .29943 .7098 L .31218 .71339 L p .707 .577 .707 r
F P
0 g
s
.80718 .72958 m .80581 .74868 L .77831 .74524 L p .707 .577 .707 r
F P
0 g
s
.77831 .74524 m .77969 .72614 L .80718 .72958 L p .707 .577 .707 r
F P
0 g
s
.78227 .65013 m .78203 .68734 L .75086 .68536 L p .707 .577 .707 r
F P
0 g
s
.75086 .68536 m .7511 .64814 L .78227 .65013 L p .707 .577 .707 r
F P
0 g
s
.71926 .64868 m .71902 .6859 L .68964 .6889 L p .707 .577 .707 r
F P
0 g
s
.50055 .54908 m .5027 .60293 L .49975 .59166 L p .707 .577 .707 r
F P
0 g
s
.49975 .59166 m .49759 .53781 L .50055 .54908 L p .707 .577 .707 r
F P
0 g
s
.49619 .64726 m .49594 .68448 L .50302 .67663 L p .707 .577 .707 r
F P
0 g
s
.50302 .67663 m .50327 .63942 L .49619 .64726 L p .707 .577 .707 r
F P
0 g
s
.71902 .6859 m .71926 .64868 L .7511 .64814 L p .707 .577 .707 r
F P
0 g
s
.68621 .7395 m .68759 .7204 L .71681 .72131 L p .707 .577 .707 r
F P
0 g
s
.71681 .72131 m .71544 .74041 L .68621 .7395 L p .707 .577 .707 r
F P
0 g
s
.7511 .64814 m .75086 .68536 L .71902 .6859 L p .707 .577 .707 r
F P
0 g
s
.29677 .55149 m .29892 .60534 L .30187 .61661 L p .707 .577 .707 r
F P
0 g
s
.77969 .72614 m .77831 .74524 L .74718 .74239 L p .707 .577 .707 r
F P
0 g
s
.74718 .74239 m .74855 .72329 L .77969 .72614 L p .707 .577 .707 r
F P
0 g
s
.4943 .70556 m .49293 .72466 L .49979 .72229 L p .707 .577 .707 r
F P
0 g
s
.49979 .72229 m .50117 .70319 L .4943 .70556 L p .707 .577 .707 r
F P
0 g
s
.30203 .68003 m .30227 .64282 L .29937 .63474 L p .707 .577 .707 r
F P
0 g
s
.29892 .60534 m .29677 .55149 L .30379 .5401 L p .707 .577 .707 r
F P
0 g
s
.71544 .74041 m .71681 .72131 L .74855 .72329 L p .707 .577 .707 r
F P
0 g
s
.74855 .72329 m .74718 .74239 L .71544 .74041 L p .707 .577 .707 r
F P
0 g
s
.29943 .7098 m .3008 .6907 L .29771 .68756 L p .707 .577 .707 r
F P
0 g
s
.29937 .63474 m .29913 .67196 L .30203 .68003 L p .707 .577 .707 r
F P
0 g
s
.29771 .68756 m .29633 .70667 L .29943 .7098 L p .707 .577 .707 r
F P
0 g
s
.49759 .53781 m .49975 .59166 L .48712 .58161 L p .707 .577 .707 r
F P
0 g
s
.48712 .58161 m .48496 .52776 L .49759 .53781 L p .707 .577 .707 r
F P
0 g
s
.50327 .63942 m .50302 .67663 L .50013 .66856 L p .707 .577 .707 r
F P
0 g
s
.50013 .66856 m .50037 .63135 L .50327 .63942 L p .707 .577 .707 r
F P
0 g
s
.30379 .5401 m .30595 .59395 L .29892 .60534 L p .707 .577 .707 r
F P
0 g
s
.30595 .59395 m .30379 .5401 L .3201 .52971 L p .707 .577 .707 r
F P
0 g
s
.50117 .70319 m .49979 .72229 L .4967 .71916 L p .707 .577 .707 r
F P
0 g
s
.4967 .71916 m .49807 .70005 L .50117 .70319 L p .707 .577 .707 r
F P
0 g
s
.29913 .67196 m .29937 .63474 L .30645 .6269 L p .707 .577 .707 r
F P
0 g
s
.30645 .6269 m .30621 .66411 L .29913 .67196 L p .707 .577 .707 r
F P
0 g
s
.29633 .70667 m .29771 .68756 L .30457 .68519 L p .707 .577 .707 r
F P
0 g
s
.30457 .68519 m .3032 .7043 L .29633 .70667 L p .707 .577 .707 r
F P
0 g
s
.48496 .52776 m .48712 .58161 L .46603 .57377 L p .707 .577 .707 r
F P
0 g
s
.46603 .57377 m .46388 .51992 L .48496 .52776 L p .707 .577 .707 r
F P
0 g
s
.50037 .63135 m .50013 .66856 L .48753 .66105 L p .707 .577 .707 r
F P
0 g
s
.48753 .66105 m .48778 .62384 L .50037 .63135 L p .707 .577 .707 r
F P
0 g
s
.3201 .52971 m .32226 .58356 L .30595 .59395 L p .707 .577 .707 r
F P
0 g
s
.32226 .58356 m .3201 .52971 L .3441 .52133 L p .707 .577 .707 r
F P
0 g
s
.30621 .66411 m .30645 .6269 L .32282 .62005 L p .707 .577 .707 r
F P
0 g
s
.49807 .70005 m .4967 .71916 L .48395 .71557 L p .707 .577 .707 r
F P
0 g
s
.48395 .71557 m .48532 .69646 L .49807 .70005 L p .707 .577 .707 r
F P
0 g
s
.46388 .51992 m .46603 .57377 L .43857 .5689 L p .707 .577 .707 r
F P
0 g
s
.43857 .5689 m .43641 .51505 L .46388 .51992 L p .707 .577 .707 r
F P
0 g
s
.32282 .62005 m .32258 .65727 L .30621 .66411 L p .707 .577 .707 r
F P
0 g
s
.3032 .7043 m .30457 .68519 L .32072 .68382 L p .707 .577 .707 r
F P
0 g
s
.32072 .68382 m .31935 .70292 L .3032 .7043 L p .707 .577 .707 r
F P
0 g
s
.34626 .57519 m .3441 .52133 L .37344 .51579 L p .707 .577 .707 r
F P
0 g
s
.3441 .52133 m .34626 .57519 L .32226 .58356 L p .707 .577 .707 r
F P
0 g
s
.48778 .62384 m .48753 .66105 L .46648 .65483 L p .707 .577 .707 r
F P
0 g
s
.46648 .65483 m .46672 .61762 L .48778 .62384 L p .707 .577 .707 r
F P
0 g
s
.43641 .51505 m .43857 .5689 L .4074 .56748 L p .707 .577 .707 r
F P
0 g
s
.4074 .56748 m .40525 .51362 L .43641 .51505 L p .707 .577 .707 r
F P
0 g
s
.3756 .56964 m .37344 .51579 L .40525 .51362 L p .707 .577 .707 r
F P
0 g
s
.37344 .51579 m .3756 .56964 L .34626 .57519 L p .707 .577 .707 r
F P
0 g
s
.32258 .65727 m .32282 .62005 L .34687 .61487 L p .707 .577 .707 r
F P
0 g
s
.40525 .51362 m .4074 .56748 L .3756 .56964 L p .707 .577 .707 r
F P
0 g
s
.48532 .69646 m .48395 .71557 L .4628 .71187 L p .707 .577 .707 r
F P
0 g
s
.4628 .71187 m .46417 .69276 L .48532 .69646 L p .707 .577 .707 r
F P
0 g
s
.34687 .61487 m .34663 .65209 L .32258 .65727 L p .707 .577 .707 r
F P
0 g
s
.31935 .70292 m .32072 .68382 L .34458 .68358 L p .707 .577 .707 r
F P
0 g
s
.46672 .61762 m .46648 .65483 L .43902 .65052 L p .707 .577 .707 r
F P
0 g
s
.43902 .65052 m .43926 .61331 L .46672 .61762 L p .707 .577 .707 r
F P
0 g
s
.34458 .68358 m .3432 .70268 L .31935 .70292 L p .707 .577 .707 r
F P
0 g
s
.34663 .65209 m .34687 .61487 L .37625 .61187 L p .707 .577 .707 r
F P
0 g
s
.46417 .69276 m .4628 .71187 L .4353 .70842 L p .707 .577 .707 r
F P
0 g
s
.4353 .70842 m .43668 .68932 L .46417 .69276 L p .707 .577 .707 r
F P
0 g
s
.43926 .61331 m .43902 .65052 L .40784 .64854 L p .707 .577 .707 r
F P
0 g
s
.40784 .64854 m .40809 .61133 L .43926 .61331 L p .707 .577 .707 r
F P
0 g
s
.37625 .61187 m .37601 .64908 L .34663 .65209 L p .707 .577 .707 r
F P
0 g
s
.37601 .64908 m .37625 .61187 L .40809 .61133 L p .707 .577 .707 r
F P
0 g
s
.3432 .70268 m .34458 .68358 L .3738 .68449 L p .707 .577 .707 r
F P
0 g
s
.3738 .68449 m .37243 .7036 L .3432 .70268 L p .707 .577 .707 r
F P
0 g
s
.40809 .61133 m .40784 .64854 L .37601 .64908 L p .707 .577 .707 r
F P
0 g
s
.43668 .68932 m .4353 .70842 L .40416 .70557 L p .707 .577 .707 r
F P
0 g
s
.40416 .70557 m .40554 .68647 L .43668 .68932 L p .707 .577 .707 r
F P
0 g
s
.37243 .7036 m .3738 .68449 L .40554 .68647 L p .707 .577 .707 r
F P
0 g
s
.40554 .68647 m .40416 .70557 L .37243 .7036 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo5@00R7oo001jOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001lOol007Aoo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL007Eoo`00L7oo10000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00LWoo001/
Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH3001_Ool006Yoo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eoo`00J7oo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`00Jgoo001VOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001YOol006Eoo`8000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00Oomoo`1VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`05001JEUYF001JEP0H0003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Moo`00H7oo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Moo`00GGoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0IGoo001KOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol005Uoo`<000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Egoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0IGoo001FOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P006Goo3`00?Woo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00<005YF00000`00>Woo
001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH4000fOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
03=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP80031oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@000AJEP07
001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=o
o`0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00B7oo3@0000=JEP00FUH00eYF00<005YF
00000`000goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP<00003FUH0
05YF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool003moo`T000AJEP03001JEUYF00EJEP03001JEP0000AJ
EPL0009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00@0
05YF000000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00>Woo1@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000UYF0P000eYF00@005YFFUIJEQT000EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP09001JEUYFFUH005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00<7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00T005YFFUIJEP00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00;goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH70009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00@001Qoo`D000AJEP05001JEUYFFUH0000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05
001JEUYFFUH00005FUH00`00FUH0000>0004FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YF
FUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEUYF0004FUH00`00FUIJEP02FUH4000NOol200001UYF00000000FUH000=JEP8002aoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYFFUH60002FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF000010006Woo1P001EYF0`000eYF0P00;7oo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20002FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YF000010001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF20002Goo2@0015YF00<0
05YFFUH015YF00@005YFFUH0009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000=J
EP03001JEUYF00EJEP04001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF1000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1@0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00@001=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EP@001Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEP0000<001]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP800003FUH005YF00@0011oo`T0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHH0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02eoo`03001JEP00009JEP8000=JEP03001JEUYF00=JEQ0000AJEP07001JEUYFFUH005YF00000eYF
00@005YFFUIJEPT000IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002eoo`03001JEP00008000EJEP03001JEUYF00EJEQ<000=JEP03001J
EP0000=JEPP00005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH50003FUH01000
FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH0
1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
0P00;goo000]Ool01@00FUH005YF00001EYF00<005YFFUH01P000eYF00<005YFFUH01eYF00@005YF
FUIJEPD00003FUH005YF008000AJEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70002FUH40003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00@0031oo`00;Goo0P000UYF00<005YFFUH00UYF100000=JEP00FUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF4P000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo0P000eYF
00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`8000=JEP<000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP09001JEUYFFUH0
05YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`800003FUH00000009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02@00FUIJ
EUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^Ool30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF6P0000=JEP00FUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH0
1UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00=JEPh000Uoo`P000AJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH015YF0`001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000eYF100067oo1P0015YF00<005YFFUH00P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHE00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF20000eYF0`005Goo200000IJEP000000
05YF0002FUH2000/Ool002ioo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH0
1@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P0015YF00@005YFFUIJEQ/000AJEP03001JEUYF
00=JEP04001JEP000002FUH2000/Ool002ioo`03001JEP0000=JEPX0009JEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEP00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@002aoo`00;Woo00@0
05YF001JEP8000AJEP04001JEUYFFUHM0006FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;7oo000^Ool00`00FUH0
00020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`00;7oo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000^Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEQ800003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002eo
o`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0002FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUHB00000eYF001JEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Woo000^Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJ
EP03001JEUYF00=JEQX0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00000`Ool002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2P00<Woo
000aOol30004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<7oo000_OolL0007FUH00`00FUIJEP05FUH01000FUIJEUYF1@0000Eo
o`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002eoo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0UYF5P001Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0001P000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH60005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01eYF5@001UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF4@0015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH01P000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJ
EP03001JEUYF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001J
EUYF008002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@0000=JEP000000;Goo
000]Ool00`00FUH00002FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000040006FUH00`00FUIJEP02FUH20005FUH80004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo000]
Ool50006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0002eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YF00000UYF00@005YFFUIJEP8000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP@000AJEP8000AJEP03001JEUYF00AJEP03001JEUYF009JEP8000=oob<002ioo`00<7oo10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YF
00000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2001DOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEPH0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJ
EP03001JEUYF00<005Eoo`00>goo2@0015YF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF
FUH00eYF1000F7oo0014Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YF00000`00G7oo0017Ool5
00000goo0000000D00000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00007
001POol004Moo`D001Qoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH7
001LOol004Qoo`<001Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0007FUH0
0`00FUIJEP05001GOol006Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000007FUH00`00FUIJEP03FUH00`00FUH00002001DOol006Eoo`03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001DOol0
06Eoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEPL000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001DOol006Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00AJ
EPL000=JEP03001JEUYF008005Aoo`00J7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP<000MJEP03001JEUYF00=J
EPD00003FUH0000005Aoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0008FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00E7oo001/Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0005Aoo`00Kgoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF8000EGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH700000goo00000003001_Ool007Uoo`/000IJEP03001JEUYF00YJEP04001J
EUYFFUH60008Ool5001_Ool008AooaL000moo`<0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59259 .75578 m .59475 .69904 L .56359 .69664 L p .707 .577 .707 r
F P
0 g
s
.59475 .69904 m .59259 .75578 L .6244 .75643 L p .707 .577 .707 r
F P
0 g
s
.6244 .75643 m .62656 .69969 L .59475 .69904 L p .707 .577 .707 r
F P
0 g
s
.62656 .69969 m .6244 .75643 L .65374 .75528 L p .707 .577 .707 r
F P
0 g
s
.65374 .75528 m .6559 .69853 L .62656 .69969 L p .707 .577 .707 r
F P
0 g
s
.56143 .75339 m .56359 .69664 L .53612 .69274 L p .707 .577 .707 r
F P
0 g
s
.56359 .69664 m .56143 .75339 L .59259 .75578 L p .707 .577 .707 r
F P
0 g
s
.6559 .69853 m .65374 .75528 L .67774 .75243 L p .707 .577 .707 r
F P
0 g
s
.67774 .75243 m .6799 .69568 L .6559 .69853 L p .707 .577 .707 r
F P
0 g
s
.53612 .69274 m .53396 .74949 L .56143 .75339 L p .707 .577 .707 r
F P
0 g
s
.59215 .83744 m .59191 .80055 L .56074 .79874 L p .707 .577 .707 r
F P
0 g
s
.59191 .80055 m .59215 .83744 L .62399 .83642 L p .707 .577 .707 r
F P
0 g
s
.62399 .83642 m .62374 .79954 L .59191 .80055 L p .707 .577 .707 r
F P
0 g
s
.53396 .74949 m .53612 .69274 L .51504 .68772 L p .707 .577 .707 r
F P
0 g
s
.62374 .79954 m .62399 .83642 L .65337 .83267 L p .707 .577 .707 r
F P
0 g
s
.65337 .83267 m .65312 .79579 L .62374 .79954 L p .707 .577 .707 r
F P
0 g
s
.56098 .83562 m .56074 .79874 L .53328 .79426 L p .707 .577 .707 r
F P
0 g
s
.56074 .79874 m .56098 .83562 L .59215 .83744 L p .707 .577 .707 r
F P
0 g
s
.51504 .68772 m .51288 .74446 L .53396 .74949 L p .707 .577 .707 r
F P
0 g
s
.65312 .79579 m .65337 .83267 L .67742 .82656 L p .707 .577 .707 r
F P
0 g
s
.67742 .82656 m .67718 .78967 L .65312 .79579 L p .707 .577 .707 r
F P
0 g
s
.6799 .69568 m .67774 .75243 L .69405 .74816 L p .707 .577 .707 r
F P
0 g
s
.69405 .74816 m .69621 .69141 L .6799 .69568 L p .707 .577 .707 r
F P
0 g
s
.53328 .79426 m .53352 .83115 L .56098 .83562 L p .707 .577 .707 r
F P
0 g
s
.53352 .83115 m .53328 .79426 L .51222 .78757 L p .707 .577 .707 r
F P
0 g
s
.51288 .74446 m .51504 .68772 L .5024 .68205 L p .707 .577 .707 r
F P
0 g
s
.59583 .88953 m .59446 .87227 L .56332 .87128 L p .707 .577 .707 r
F P
0 g
s
.59446 .87227 m .59583 .88953 L .62757 .88614 L p .707 .577 .707 r
F P
0 g
s
.62757 .88614 m .62619 .86888 L .59446 .87227 L p .707 .577 .707 r
F P
0 g
s
.62619 .86888 m .62757 .88614 L .65679 .87868 L p .707 .577 .707 r
F P
0 g
s
.65679 .87868 m .65542 .86142 L .62619 .86888 L p .707 .577 .707 r
F P
0 g
s
.51222 .78757 m .51247 .82445 L .53352 .83115 L p .707 .577 .707 r
F P
0 g
s
.56469 .88854 m .56332 .87128 L .53583 .86598 L p .707 .577 .707 r
F P
0 g
s
.56332 .87128 m .56469 .88854 L .59583 .88953 L p .707 .577 .707 r
F P
0 g
s
.67718 .78967 m .67742 .82656 L .69379 .81867 L p .707 .577 .707 r
F P
0 g
s
.69379 .81867 m .69354 .78179 L .67718 .78967 L p .707 .577 .707 r
F P
0 g
s
.5024 .68205 m .50024 .7388 L .51288 .74446 L p .707 .577 .707 r
F P
0 g
s
.65542 .86142 m .65679 .87868 L .68065 .86788 L p .707 .577 .707 r
F P
0 g
s
.68065 .86788 m .67928 .85062 L .65542 .86142 L p .707 .577 .707 r
F P
0 g
s
.53583 .86598 m .5372 .88324 L .56469 .88854 L p .707 .577 .707 r
F P
0 g
s
.69621 .69141 m .69405 .74816 L .70107 .7429 L p .707 .577 .707 r
F P
0 g
s
.70107 .7429 m .70323 .68615 L .69621 .69141 L p .707 .577 .707 r
F P
0 g
s
.51247 .82445 m .51222 .78757 L .49963 .77931 L p .707 .577 .707 r
F P
0 g
s
.5372 .88324 m .53583 .86598 L .51467 .85691 L p .707 .577 .707 r
F P
0 g
s
.50024 .7388 m .5024 .68205 L .49945 .67631 L p .707 .577 .707 r
F P
0 g
s
.49963 .77931 m .49987 .8162 L .51247 .82445 L p .707 .577 .707 r
F P
0 g
s
.67928 .85062 m .68065 .86788 L .6968 .85481 L p .707 .577 .707 r
F P
0 g
s
.6968 .85481 m .69543 .83755 L .67928 .85062 L p .707 .577 .707 r
F P
0 g
s
.51467 .85691 m .51605 .87417 L .5372 .88324 L p .707 .577 .707 r
F P
0 g
s
.69354 .78179 m .69379 .81867 L .70087 .80979 L p .707 .577 .707 r
F P
0 g
s
.70087 .80979 m .70062 .7729 L .69354 .78179 L p .707 .577 .707 r
F P
0 g
s
.49945 .67631 m .49729 .73306 L .50024 .7388 L p .707 .577 .707 r
F P
0 g
s
.51605 .87417 m .51467 .85691 L .50192 .84494 L p .707 .577 .707 r
F P
0 g
s
.70323 .68615 m .70107 .7429 L .69812 .73716 L p .707 .577 .707 r
F P
0 g
s
.69812 .73716 m .70028 .68041 L .70323 .68615 L p .707 .577 .707 r
F P
0 g
s
.49987 .8162 m .49963 .77931 L .49673 .7703 L p .707 .577 .707 r
F P
0 g
s
.50192 .84494 m .5033 .8622 L .51605 .87417 L p .707 .577 .707 r
F P
0 g
s
.69543 .83755 m .6968 .85481 L .70366 .84075 L p .707 .577 .707 r
F P
0 g
s
.70366 .84075 m .70229 .82349 L .69543 .83755 L p .707 .577 .707 r
F P
0 g
s
.49673 .7703 m .49697 .80719 L .49987 .8162 L p .707 .577 .707 r
F P
0 g
s
.49729 .73306 m .49945 .67631 L .50648 .67105 L p .707 .577 .707 r
F P
0 g
s
.70062 .7729 m .70087 .80979 L .69797 .80078 L p .707 .577 .707 r
F P
0 g
s
.69797 .80078 m .69773 .76389 L .70062 .7729 L p .707 .577 .707 r
F P
0 g
s
.49238 .81834 m .49555 .3144 L .45154 .3116 L p .707 .577 .707 r
F P
0 g
s
.50648 .67105 m .50432 .7278 L .49729 .73306 L p .707 .577 .707 r
F P
0 g
s
.49697 .80719 m .49673 .7703 L .50381 .76142 L p .707 .577 .707 r
F P
0 g
s
.50381 .76142 m .50406 .79831 L .49697 .80719 L p .707 .577 .707 r
F P
0 g
s
.50432 .7278 m .50648 .67105 L .52279 .66679 L p .707 .577 .707 r
F P
0 g
s
.52279 .66679 m .52063 .72353 L .50432 .7278 L p .707 .577 .707 r
F P
0 g
s
.5033 .8622 m .50192 .84494 L .49883 .83126 L p .707 .577 .707 r
F P
0 g
s
.49883 .83126 m .5002 .84852 L .5033 .8622 L p .707 .577 .707 r
F P
0 g
s
.5002 .84852 m .49883 .83126 L .50569 .81719 L p .707 .577 .707 r
F P
0 g
s
.50406 .79831 m .50381 .76142 L .52018 .75354 L p .707 .577 .707 r
F P
0 g
s
.50569 .81719 m .50707 .83445 L .5002 .84852 L p .707 .577 .707 r
F P
0 g
s
.52063 .72353 m .52279 .66679 L .54678 .66393 L p .707 .577 .707 r
F P
0 g
s
.52018 .75354 m .52042 .79042 L .50406 .79831 L p .707 .577 .707 r
F P
0 g
s
.54678 .66393 m .54463 .72068 L .52063 .72353 L p .707 .577 .707 r
F P
0 g
s
.50707 .83445 m .50569 .81719 L .52184 .80412 L p .707 .577 .707 r
F P
0 g
s
.52042 .79042 m .52018 .75354 L .54423 .74742 L p .707 .577 .707 r
F P
0 g
s
.52184 .80412 m .52322 .82138 L .50707 .83445 L p .707 .577 .707 r
F P
0 g
s
.54423 .74742 m .54447 .7843 L .52042 .79042 L p .707 .577 .707 r
F P
0 g
s
.52322 .82138 m .52184 .80412 L .5457 .79333 L p .707 .577 .707 r
F P
0 g
s
.5457 .79333 m .54707 .81059 L .52322 .82138 L p .707 .577 .707 r
F P
0 g
s
.49555 .3144 m .49238 .81834 L .53733 .81756 L p .707 .577 .707 r
F P
0 g
s
.53733 .81756 m .54049 .31362 L .49555 .3144 L p .707 .577 .707 r
F P
0 g
s
.54463 .72068 m .54678 .66393 L .57612 .66278 L p .707 .577 .707 r
F P
0 g
s
.57612 .66278 m .57397 .71953 L .54463 .72068 L p .707 .577 .707 r
F P
0 g
s
.54447 .7843 m .54423 .74742 L .57361 .74367 L p .707 .577 .707 r
F P
0 g
s
.57361 .74367 m .57385 .78055 L .54447 .7843 L p .707 .577 .707 r
F P
0 g
s
.57385 .78055 m .57361 .74367 L .60545 .74265 L p .707 .577 .707 r
F P
0 g
s
.60545 .74265 m .60569 .77954 L .57385 .78055 L p .707 .577 .707 r
F P
0 g
s
.54707 .81059 m .5457 .79333 L .57493 .78587 L p .707 .577 .707 r
F P
0 g
s
.57493 .78587 m .5763 .80313 L .54707 .81059 L p .707 .577 .707 r
F P
0 g
s
.5763 .80313 m .57493 .78587 L .60666 .78247 L p .707 .577 .707 r
F P
0 g
s
.60666 .78247 m .60803 .79973 L .5763 .80313 L p .707 .577 .707 r
F P
0 g
s
.54049 .31362 m .53733 .81756 L .57881 .8133 L p .707 .577 .707 r
F P
0 g
s
.57397 .71953 m .57612 .66278 L .60793 .66343 L p .707 .577 .707 r
F P
0 g
s
.60793 .66343 m .60577 .72017 L .57397 .71953 L p .707 .577 .707 r
F P
0 g
s
.57881 .8133 m .58197 .30936 L .54049 .31362 L p .707 .577 .707 r
F P
0 g
s
.44838 .81554 m .45154 .3116 L .41277 .30551 L p .707 .577 .707 r
F P
0 g
s
.45154 .3116 m .44838 .81554 L .49238 .81834 L p .707 .577 .707 r
F P
0 g
s
.70028 .68041 m .69812 .73716 L .68549 .73149 L p .707 .577 .707 r
F P
0 g
s
.68549 .73149 m .68765 .67475 L .70028 .68041 L p .707 .577 .707 r
F P
0 g
s
.70229 .82349 m .70366 .84075 L .70057 .82706 L p .707 .577 .707 r
F P
0 g
s
.70057 .82706 m .6992 .8098 L .70229 .82349 L p .707 .577 .707 r
F P
0 g
s
.24958 .71897 m .25174 .66222 L .22058 .65983 L p .707 .577 .707 r
F P
0 g
s
.25174 .66222 m .24958 .71897 L .28139 .71962 L p .707 .577 .707 r
F P
0 g
s
.28139 .71962 m .28355 .66287 L .25174 .66222 L p .707 .577 .707 r
F P
0 g
s
.28355 .66287 m .28139 .71962 L .31073 .71846 L p .707 .577 .707 r
F P
0 g
s
.31073 .71846 m .31289 .66171 L .28355 .66287 L p .707 .577 .707 r
F P
0 g
s
.6391 .66582 m .63694 .72257 L .60577 .72017 L p .707 .577 .707 r
F P
0 g
s
.60577 .72017 m .60793 .66343 L .6391 .66582 L p .707 .577 .707 r
F P
0 g
s
.63662 .74447 m .63686 .78136 L .60569 .77954 L p .707 .577 .707 r
F P
0 g
s
.60569 .77954 m .60545 .74265 L .63662 .74447 L p .707 .577 .707 r
F P
0 g
s
.6378 .78347 m .63917 .80073 L .60803 .79973 L p .707 .577 .707 r
F P
0 g
s
.60803 .79973 m .60666 .78247 L .6378 .78347 L p .707 .577 .707 r
F P
0 g
s
.58197 .30936 m .57881 .8133 L .61276 .80596 L p .707 .577 .707 r
F P
0 g
s
.61276 .80596 m .61592 .30201 L .58197 .30936 L p .707 .577 .707 r
F P
0 g
s
.21842 .71658 m .22058 .65983 L .19311 .65593 L p .707 .577 .707 r
F P
0 g
s
.22058 .65983 m .21842 .71658 L .24958 .71897 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69773 .76389 m .69797 .80078 L .68538 .79252 L p .707 .577 .707 r
F P
0 g
s
.68538 .79252 m .68513 .75564 L .69773 .76389 L p .707 .577 .707 r
F P
0 g
s
.40961 .80945 m .41277 .30551 L .38305 .29672 L p .707 .577 .707 r
F P
0 g
s
.41277 .30551 m .40961 .80945 L .44838 .81554 L p .707 .577 .707 r
F P
0 g
s
.31289 .66171 m .31073 .71846 L .33473 .71561 L p .707 .577 .707 r
F P
0 g
s
.33473 .71561 m .33689 .65886 L .31289 .66171 L p .707 .577 .707 r
F P
0 g
s
.19311 .65593 m .19095 .71268 L .21842 .71658 L p .707 .577 .707 r
F P
0 g
s
.24914 .80062 m .2489 .76374 L .21773 .76192 L p .707 .577 .707 r
F P
0 g
s
.2489 .76374 m .24914 .80062 L .28098 .79961 L p .707 .577 .707 r
F P
0 g
s
.28098 .79961 m .28073 .76272 L .2489 .76374 L p .707 .577 .707 r
F P
0 g
s
.68765 .67475 m .68549 .73149 L .6644 .72647 L p .707 .577 .707 r
F P
0 g
s
.6644 .72647 m .66656 .66972 L .68765 .67475 L p .707 .577 .707 r
F P
0 g
s
.19095 .71268 m .19311 .65593 L .17203 .6509 L p .707 .577 .707 r
F P
0 g
s
.28073 .76272 m .28098 .79961 L .31036 .79586 L p .707 .577 .707 r
F P
0 g
s
.31036 .79586 m .31012 .75897 L .28073 .76272 L p .707 .577 .707 r
F P
0 g
s
.6992 .8098 m .70057 .82706 L .68782 .8151 L p .707 .577 .707 r
F P
0 g
s
.68782 .8151 m .68645 .79784 L .6992 .8098 L p .707 .577 .707 r
F P
0 g
s
.21797 .79881 m .21773 .76192 L .19027 .75745 L p .707 .577 .707 r
F P
0 g
s
.21773 .76192 m .21797 .79881 L .24914 .80062 L p .707 .577 .707 r
F P
0 g
s
.17203 .6509 m .16987 .70765 L .19095 .71268 L p .707 .577 .707 r
F P
0 g
s
.61592 .30201 m .61276 .80596 L .63587 .79626 L p .707 .577 .707 r
F P
0 g
s
.63587 .79626 m .63903 .29231 L .61592 .30201 L p .707 .577 .707 r
F P
0 g
s
.31012 .75897 m .31036 .79586 L .33441 .78974 L p .707 .577 .707 r
F P
0 g
s
.33441 .78974 m .33417 .75286 L .31012 .75897 L p .707 .577 .707 r
F P
0 g
s
.33689 .65886 m .33473 .71561 L .35104 .71135 L p .707 .577 .707 r
F P
0 g
s
.35104 .71135 m .3532 .6546 L .33689 .65886 L p .707 .577 .707 r
F P
0 g
s
.68513 .75564 m .68538 .79252 L .66432 .78583 L p .707 .577 .707 r
F P
0 g
s
.66432 .78583 m .66408 .74895 L .68513 .75564 L p .707 .577 .707 r
F P
0 g
s
.19027 .75745 m .19051 .79433 L .21797 .79881 L p .707 .577 .707 r
F P
0 g
s
.19051 .79433 m .19027 .75745 L .16921 .75075 L p .707 .577 .707 r
F P
0 g
s
.66656 .66972 m .6644 .72647 L .63694 .72257 L p .707 .577 .707 r
F P
0 g
s
.63694 .72257 m .6391 .66582 L .66656 .66972 L p .707 .577 .707 r
F P
0 g
s
.16987 .70765 m .17203 .6509 L .15939 .64524 L p .707 .577 .707 r
F P
0 g
s
.25282 .85272 m .25145 .83546 L .22031 .83446 L p .707 .577 .707 r
F P
0 g
s
.25145 .83546 m .25282 .85272 L .28456 .84932 L p .707 .577 .707 r
F P
0 g
s
.28456 .84932 m .28319 .83206 L .25145 .83546 L p .707 .577 .707 r
F P
0 g
s
.37988 .80067 m .38305 .29672 L .36527 .2861 L p .707 .577 .707 r
F P
0 g
s
.38305 .29672 m .37988 .80067 L .40961 .80945 L p .707 .577 .707 r
F P
0 g
s
.28319 .83206 m .28456 .84932 L .31378 .84186 L p .707 .577 .707 r
F P
0 g
s
.31378 .84186 m .31241 .8246 L .28319 .83206 L p .707 .577 .707 r
F P
0 g
s
.68645 .79784 m .68782 .8151 L .66666 .80602 L p .707 .577 .707 r
F P
0 g
s
.66666 .80602 m .66529 .78876 L .68645 .79784 L p .707 .577 .707 r
F P
0 g
s
.16921 .75075 m .16946 .78764 L .19051 .79433 L p .707 .577 .707 r
F P
0 g
s
.22169 .85172 m .22031 .83446 L .19282 .82917 L p .707 .577 .707 r
F P
0 g
s
.22031 .83446 m .22169 .85172 L .25282 .85272 L p .707 .577 .707 r
F P
0 g
s
.33417 .75286 m .33441 .78974 L .35078 .78186 L p .707 .577 .707 r
F P
0 g
s
.35078 .78186 m .35053 .74497 L .33417 .75286 L p .707 .577 .707 r
F P
0 g
s
.15939 .64524 m .15724 .70199 L .16987 .70765 L p .707 .577 .707 r
F P
0 g
s
.31241 .8246 m .31378 .84186 L .33764 .83107 L p .707 .577 .707 r
F P
0 g
s
.33764 .83107 m .33627 .81381 L .31241 .8246 L p .707 .577 .707 r
F P
0 g
s
.66408 .74895 m .66432 .78583 L .63686 .78136 L p .707 .577 .707 r
F P
0 g
s
.63686 .78136 m .63662 .74447 L .66408 .74895 L p .707 .577 .707 r
F P
0 g
s
.19282 .82917 m .19419 .84643 L .22169 .85172 L p .707 .577 .707 r
F P
0 g
s
.3532 .6546 m .35104 .71135 L .35806 .70608 L p .707 .577 .707 r
F P
0 g
s
.35806 .70608 m .36022 .64934 L .3532 .6546 L p .707 .577 .707 r
F P
0 g
s
.16946 .78764 m .16921 .75075 L .15662 .7425 L p .707 .577 .707 r
F P
0 g
s
.19419 .84643 m .19282 .82917 L .17166 .82009 L p .707 .577 .707 r
F P
0 g
s
.63917 .80073 m .6378 .78347 L .66529 .78876 L p .707 .577 .707 r
F P
0 g
s
.63903 .29231 m .63587 .79626 L .64587 .78515 L p .707 .577 .707 r
F P
0 g
s
.64587 .78515 m .64903 .28121 L .63903 .29231 L p .707 .577 .707 r
F P
0 g
s
.15724 .70199 m .15939 .64524 L .15644 .6395 L p .707 .577 .707 r
F P
0 g
s
.66529 .78876 m .66666 .80602 L .63917 .80073 L p .707 .577 .707 r
F P
0 g
s
.15662 .7425 m .15686 .77938 L .16946 .78764 L p .707 .577 .707 r
F P
0 g
s
.33627 .81381 m .33764 .83107 L .35379 .818 L p .707 .577 .707 r
F P
0 g
s
.35379 .818 m .35242 .80074 L .33627 .81381 L p .707 .577 .707 r
F P
0 g
s
.17166 .82009 m .17304 .83735 L .19419 .84643 L p .707 .577 .707 r
F P
0 g
s
.35053 .74497 m .35078 .78186 L .35786 .77297 L p .707 .577 .707 r
F P
0 g
s
.35786 .77297 m .35761 .73609 L .35053 .74497 L p .707 .577 .707 r
F P
0 g
s
.15644 .6395 m .15428 .69624 L .15724 .70199 L p .707 .577 .707 r
F P
0 g
s
.36211 .79004 m .36527 .2861 L .36118 .27467 L p .707 .577 .707 r
F P
0 g
s
.36527 .2861 m .36211 .79004 L .37988 .80067 L p .707 .577 .707 r
F P
0 g
s
.17304 .83735 m .17166 .82009 L .15891 .80813 L p .707 .577 .707 r
F P
0 g
s
.36022 .64934 m .35806 .70608 L .35511 .70034 L p .707 .577 .707 r
F P
0 g
s
.35511 .70034 m .35727 .64359 L .36022 .64934 L p .707 .577 .707 r
F P
0 g
s
.15686 .77938 m .15662 .7425 L .15372 .73349 L p .707 .577 .707 r
F P
0 g
s
.15891 .80813 m .16029 .82539 L .17304 .83735 L p .707 .577 .707 r
F P
0 g
s
.35242 .80074 m .35379 .818 L .36065 .80393 L p .707 .577 .707 r
F P
0 g
s
.36065 .80393 m .35928 .78667 L .35242 .80074 L p .707 .577 .707 r
F P
0 g
s
.15372 .73349 m .15396 .77037 L .15686 .77938 L p .707 .577 .707 r
F P
0 g
s
.15428 .69624 m .15644 .6395 L .16347 .63423 L p .707 .577 .707 r
F P
0 g
s
.35761 .73609 m .35786 .77297 L .35496 .76396 L p .707 .577 .707 r
F P
0 g
s
.35496 .76396 m .35472 .72708 L .35761 .73609 L p .707 .577 .707 r
F P
0 g
s
.64903 .28121 m .64587 .78515 L .64284 .77671 L p .707 .577 .707 r
F P
0 g
s
.64236 .73417 m .64903 .28121 L .64284 .77671 L .707 .577 .707 r
F
.64236 .73417 m .64398 .4421 L .64903 .28121 L F
.64214 .71524 m .64375 .45876 L p .64236 .73417 L F P
0 g
s
.64375 .45876 m .64494 .26978 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64375 .45876 m .64398 .4421 L .64236 .73417 L .707 .577 .707 r
F
.64494 .26978 m .64177 .77373 L .624 .7631 L p F P
0 g
s
.63683 .64064 m .63708 .67752 L .64072 .67991 L p .707 .577 .707 r
F P
0 g
s
.64072 .67991 m .64967 .68578 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64105 .65547 m .63683 .64064 L .64072 .67991 L .707 .577 .707 r
F
.64967 .68578 m .64943 .64889 L .64122 .64351 L p F P
0 g
s
.64122 .64351 m .63683 .64064 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64967 .68578 m .64122 .64351 L .64105 .65547 L .707 .577 .707 r
F
.64494 .26978 m .64629 .27357 L p .64398 .4421 L F P
0 g
s
.64629 .27357 m .64903 .28121 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64177 .77373 m .64214 .71524 L p .64236 .73417 L .707 .577 .707 r
F P
0 g
s
.63961 .56304 m .63745 .61979 L .64107 .62142 L p .707 .577 .707 r
F P
0 g
s
.64107 .62142 m .65008 .62545 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.64047 .56817 m .63961 .56304 L .64107 .62142 L .707 .577 .707 r
F
.65008 .62545 m .65224 .56871 L .64041 .5634 L p F P
0 g
s
.64041 .5634 m .63961 .56304 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.65008 .62545 m .64041 .5634 L .64047 .56817 L .707 .577 .707 r
F
.64284 .77671 m .64177 .77373 L p .64236 .73417 L F P
0 g
s
.16347 .63423 m .16131 .69098 L .15428 .69624 L p .707 .577 .707 r
F P
0 g
s
.16029 .82539 m .15891 .80813 L .15582 .79444 L p .707 .577 .707 r
F P
0 g
s
.15396 .77037 m .15372 .73349 L .1608 .72461 L p .707 .577 .707 r
F P
0 g
s
.35727 .64359 m .35511 .70034 L .34248 .69468 L p .707 .577 .707 r
F P
0 g
s
.34248 .69468 m .34464 .63793 L .35727 .64359 L p .707 .577 .707 r
F P
0 g
s
.15582 .79444 m .15719 .8117 L .16029 .82539 L p .707 .577 .707 r
F P
0 g
s
.35928 .78667 m .36065 .80393 L .35756 .79025 L p .707 .577 .707 r
F P
0 g
s
.35756 .79025 m .35619 .77299 L .35928 .78667 L p .707 .577 .707 r
F P
0 g
s
.36118 .27467 m .35801 .77861 L .36211 .79004 L p .707 .577 .707 r
F P
0 g
s
.35801 .77861 m .36118 .27467 L .37117 .26357 L p .707 .577 .707 r
F P
0 g
s
.1608 .72461 m .16105 .76149 L .15396 .77037 L p .707 .577 .707 r
F P
0 g
s
.16131 .69098 m .16347 .63423 L .17978 .62997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35472 .72708 m .35496 .76396 L .34237 .75571 L p .707 .577 .707 r
F P
0 g
s
.34237 .75571 m .34212 .71882 L .35472 .72708 L p .707 .577 .707 r
F P
0 g
s
.17978 .62997 m .17762 .68672 L .16131 .69098 L p .707 .577 .707 r
F P
0 g
s
.15719 .8117 m .15582 .79444 L .16268 .78037 L p .707 .577 .707 r
F P
0 g
s
.34464 .63793 m .34248 .69468 L .32139 .68965 L p .707 .577 .707 r
F P
0 g
s
.32139 .68965 m .32355 .6329 L .34464 .63793 L p .707 .577 .707 r
F P
0 g
s
.16105 .76149 m .1608 .72461 L .17717 .71672 L p .707 .577 .707 r
F P
0 g
s
.16268 .78037 m .16406 .79764 L .15719 .8117 L p .707 .577 .707 r
F P
0 g
s
.624 .7631 m .62716 .25916 L .64494 .26978 L p .707 .577 .707 r
F P
0 g
s
.35619 .77299 m .35756 .79025 L .34481 .77828 L p .707 .577 .707 r
F P
0 g
s
.34481 .77828 m .34344 .76102 L .35619 .77299 L p .707 .577 .707 r
F P
0 g
s
.17762 .68672 m .17978 .62997 L .20377 .62712 L p .707 .577 .707 r
F P
0 g
s
.17717 .71672 m .17741 .75361 L .16105 .76149 L p .707 .577 .707 r
F P
0 g
s
.34212 .71882 m .34237 .75571 L .32131 .74902 L p .707 .577 .707 r
F P
0 g
s
.32131 .74902 m .32107 .71213 L .34212 .71882 L p .707 .577 .707 r
F P
0 g
s
.36801 .76751 m .37117 .26357 L .39428 .25387 L p .707 .577 .707 r
F P
0 g
s
.37117 .26357 m .36801 .76751 L .35801 .77861 L p .707 .577 .707 r
F P
0 g
s
.20377 .62712 m .20162 .68387 L .17762 .68672 L p .707 .577 .707 r
F P
0 g
s
.16406 .79764 m .16268 .78037 L .17883 .76731 L p .707 .577 .707 r
F P
0 g
s
.32355 .6329 m .32139 .68965 L .29393 .68575 L p .707 .577 .707 r
F P
0 g
s
.29393 .68575 m .29609 .629 L .32355 .6329 L p .707 .577 .707 r
F P
0 g
s
.17741 .75361 m .17717 .71672 L .20122 .7106 L p .707 .577 .707 r
F P
0 g
s
.17883 .76731 m .18021 .78457 L .16406 .79764 L p .707 .577 .707 r
F P
0 g
s
.20162 .68387 m .20377 .62712 L .23311 .62596 L p .707 .577 .707 r
F P
0 g
s
.34344 .76102 m .34481 .77828 L .32365 .76921 L p .707 .577 .707 r
F P
0 g
s
.32365 .76921 m .32228 .75195 L .34344 .76102 L p .707 .577 .707 r
F P
0 g
s
.7298 .63677 m .73196 .58003 L .70079 .57763 L p .707 .577 .707 r
F P
0 g
s
.73196 .58003 m .7298 .63677 L .76161 .63742 L p .707 .577 .707 r
F P
0 g
s
.76161 .63742 m .76376 .58068 L .73196 .58003 L p .707 .577 .707 r
F P
0 g
s
.20122 .7106 m .20146 .74749 L .17741 .75361 L p .707 .577 .707 r
F P
0 g
s
.32107 .71213 m .32131 .74902 L .29385 .74454 L p .707 .577 .707 r
F P
0 g
s
.29385 .74454 m .29361 .70766 L .32107 .71213 L p .707 .577 .707 r
F P
0 g
s
.76376 .58068 m .76161 .63742 L .79094 .63627 L p .707 .577 .707 r
F P
0 g
s
.79094 .63627 m .7931 .57952 L .76376 .58068 L p .707 .577 .707 r
F P
0 g
s
.29609 .629 m .29393 .68575 L .26276 .68336 L p .707 .577 .707 r
F P
0 g
s
.26276 .68336 m .26492 .62661 L .29609 .629 L p .707 .577 .707 r
F P
0 g
s
.23311 .62596 m .23096 .68271 L .20162 .68387 L p .707 .577 .707 r
F P
0 g
s
.62716 .25916 m .624 .7631 L .59427 .75431 L p .707 .577 .707 r
F P
0 g
s
.59427 .75431 m .59743 .25037 L .62716 .25916 L p .707 .577 .707 r
F P
0 g
s
.69863 .63438 m .70079 .57763 L .67332 .57373 L p .707 .577 .707 r
F P
0 g
s
.70079 .57763 m .69863 .63438 L .7298 .63677 L p .707 .577 .707 r
F P
0 g
s
.23096 .68271 m .23311 .62596 L .26492 .62661 L p .707 .577 .707 r
F P
0 g
s
.18021 .78457 m .17883 .76731 L .20269 .75651 L p .707 .577 .707 r
F P
0 g
s
.26492 .62661 m .26276 .68336 L .23096 .68271 L p .707 .577 .707 r
F P
0 g
s
.20146 .74749 m .20122 .7106 L .2306 .70685 L p .707 .577 .707 r
F P
0 g
s
.72936 .69876 m .72911 .66188 L .69794 .66006 L p .707 .577 .707 r
F P
0 g
s
.72911 .66188 m .72936 .69876 L .76119 .69775 L p .707 .577 .707 r
F P
0 g
s
.76119 .69775 m .76095 .66086 L .72911 .66188 L p .707 .577 .707 r
F P
0 g
s
.7931 .57952 m .79094 .63627 L .81494 .63342 L p .707 .577 .707 r
F P
0 g
s
.81494 .63342 m .8171 .57667 L .7931 .57952 L p .707 .577 .707 r
F P
0 g
s
.67332 .57373 m .67117 .63048 L .69863 .63438 L p .707 .577 .707 r
F P
0 g
s
.32228 .75195 m .32365 .76921 L .29616 .76391 L p .707 .577 .707 r
F P
0 g
s
.29616 .76391 m .29479 .74665 L .32228 .75195 L p .707 .577 .707 r
F P
0 g
s
.20269 .75651 m .20406 .77377 L .18021 .78457 L p .707 .577 .707 r
F P
0 g
s
.76095 .66086 m .76119 .69775 L .79057 .694 L p .707 .577 .707 r
F P
0 g
s
.79057 .694 m .79033 .65711 L .76095 .66086 L p .707 .577 .707 r
F P
0 g
s
.29361 .70766 m .29385 .74454 L .26268 .74272 L p .707 .577 .707 r
F P
0 g
s
.26268 .74272 m .26244 .70584 L .29361 .70766 L p .707 .577 .707 r
F P
0 g
s
.39428 .25387 m .39112 .75781 L .36801 .76751 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .39428 .25387 L .42824 .24652 L p .707 .577 .707 r
F P
0 g
s
.2306 .70685 m .23085 .74374 L .20146 .74749 L p .707 .577 .707 r
F P
0 g
s
.69818 .69694 m .69794 .66006 L .67048 .65558 L p .707 .577 .707 r
F P
0 g
s
.69794 .66006 m .69818 .69694 L .72936 .69876 L p .707 .577 .707 r
F P
0 g
s
.67117 .63048 m .67332 .57373 L .65224 .56871 L p .707 .577 .707 r
F P
0 g
s
.23085 .74374 m .2306 .70685 L .26244 .70584 L p .707 .577 .707 r
F P
0 g
s
.26244 .70584 m .26268 .74272 L .23085 .74374 L p .707 .577 .707 r
F P
0 g
s
.20406 .77377 m .20269 .75651 L .23192 .74905 L p .707 .577 .707 r
F P
0 g
s
.79033 .65711 m .79057 .694 L .81462 .68788 L p .707 .577 .707 r
F P
0 g
s
.81462 .68788 m .81438 .65099 L .79033 .65711 L p .707 .577 .707 r
F P
0 g
s
.29479 .74665 m .29616 .76391 L .26502 .76292 L p .707 .577 .707 r
F P
0 g
s
.26502 .76292 m .26365 .74565 L .29479 .74665 L p .707 .577 .707 r
F P
0 g
s
.65224 .56871 m .65008 .62545 L .67117 .63048 L p .707 .577 .707 r
F P
0 g
s
.67048 .65558 m .67073 .69247 L .69818 .69694 L p .707 .577 .707 r
F P
0 g
s
.23192 .74905 m .23329 .76631 L .20406 .77377 L p .707 .577 .707 r
F P
0 g
s
.8171 .57667 m .81494 .63342 L .83125 .62915 L p .707 .577 .707 r
F P
0 g
s
.83125 .62915 m .83341 .5724 L .8171 .57667 L p .707 .577 .707 r
F P
0 g
s
.67073 .69247 m .67048 .65558 L .64943 .64889 L p .707 .577 .707 r
F P
0 g
s
.23329 .76631 m .23192 .74905 L .26365 .74565 L p .707 .577 .707 r
F P
0 g
s
.59743 .25037 m .59427 .75431 L .5555 .74822 L p .707 .577 .707 r
F P
0 g
s
.5555 .74822 m .55867 .24428 L .59743 .25037 L p .707 .577 .707 r
F P
0 g
s
.26365 .74565 m .26502 .76292 L .23329 .76631 L p .707 .577 .707 r
F P
0 g
s
.73304 .75786 m .73166 .7406 L .70053 .7396 L p .707 .577 .707 r
F P
0 g
s
.73166 .7406 m .73304 .75786 L .76477 .75446 L p .707 .577 .707 r
F P
0 g
s
.76477 .75446 m .7634 .7372 L .73166 .7406 L p .707 .577 .707 r
F P
0 g
s
.7634 .7372 m .76477 .75446 L .794 .747 L p .707 .577 .707 r
F P
0 g
s
.794 .747 m .79262 .72974 L .7634 .7372 L p .707 .577 .707 r
F P
0 g
s
.64943 .64889 m .64967 .68578 L .67073 .69247 L p .707 .577 .707 r
F P
0 g
s
.42507 .75047 m .42824 .24652 L .46971 .24226 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .42171 .33646 L .42544 .69198 L .707 .577 .707 r
F
.42824 .24652 m .42705 .4355 L p .42171 .33646 L F P
0 g
s
.42705 .4355 m .42544 .69198 L p .42171 .33646 L .707 .577 .707 r
F P
0 g
s
.46971 .24226 m .46655 .7462 L .42507 .75047 L p .707 .577 .707 r
F P
0 g
s
.41794 .62405 m .41818 .66093 L .43907 .65827 L p .707 .577 .707 r
F P
0 g
s
.43907 .65827 m .44756 .65718 L p .43846 .647 L .707 .577 .707 r
F P
0 g
s
.43846 .647 m .41794 .62405 L .43907 .65827 L .707 .577 .707 r
F
.42075 .54386 m .4186 .60061 L .43952 .59978 L p F P
0 g
s
.43952 .59978 m .44794 .59945 L p .44156 .58641 L .707 .577 .707 r
F P
0 g
s
.44156 .58641 m .42075 .54386 L .43952 .59978 L .707 .577 .707 r
F
.42544 .69198 m .42507 .75047 L .41622 .75238 L p F P
0 g
s
.41622 .75238 m .39112 .75781 L p .42544 .69198 L .707 .577 .707 r
F P
0 g
s
.81438 .65099 m .81462 .68788 L .83099 .67999 L p .707 .577 .707 r
F P
0 g
s
.83099 .67999 m .83075 .64311 L .81438 .65099 L p .707 .577 .707 r
F P
0 g
s
.7019 .75686 m .70053 .7396 L .67303 .73431 L p .707 .577 .707 r
F P
0 g
s
.70053 .7396 m .7019 .75686 L .73304 .75786 L p .707 .577 .707 r
F P
0 g
s
.79262 .72974 m .794 .747 L .81785 .73621 L p .707 .577 .707 r
F P
0 g
s
.81785 .73621 m .81648 .71895 L .79262 .72974 L p .707 .577 .707 r
F P
0 g
s
.67303 .73431 m .67441 .75157 L .7019 .75686 L p .707 .577 .707 r
F P
0 g
s
.55867 .24428 m .5555 .74822 L .5115 .74543 L p .707 .577 .707 r
F P
0 g
s
.5115 .74543 m .51466 .24148 L .55867 .24428 L p .707 .577 .707 r
F P
0 g
s
.83341 .5724 m .83125 .62915 L .83828 .62389 L p .707 .577 .707 r
F P
0 g
s
.83828 .62389 m .84044 .56714 L .83341 .5724 L p .707 .577 .707 r
F P
0 g
s
.67441 .75157 m .67303 .73431 L .65188 .72523 L p .707 .577 .707 r
F P
0 g
s
.46655 .7462 m .46971 .24226 L .51466 .24148 L p .707 .577 .707 r
F P
0 g
s
.51466 .24148 m .5115 .74543 L .46655 .7462 L p .707 .577 .707 r
F P
0 g
s
.81648 .71895 m .81785 .73621 L .834 .72314 L p .707 .577 .707 r
F P
0 g
s
.834 .72314 m .83263 .70588 L .81648 .71895 L p .707 .577 .707 r
F P
0 g
s
.63745 .61979 m .63961 .56304 L .63666 .5573 L p .707 .577 .707 r
F P
0 g
s
.65188 .72523 m .65325 .74249 L .67441 .75157 L p .707 .577 .707 r
F P
0 g
s
.83075 .64311 m .83099 .67999 L .83807 .67111 L p .707 .577 .707 r
F P
0 g
s
.83807 .67111 m .83783 .63423 L .83075 .64311 L p .707 .577 .707 r
F P
0 g
s
.63666 .5573 m .6345 .61405 L .63745 .61979 L p .707 .577 .707 r
F P
0 g
s
.65325 .74249 m .65188 .72523 L .63913 .71327 L p .707 .577 .707 r
F P
0 g
s
.63708 .67752 m .63683 .64064 L .63393 .63163 L p .707 .577 .707 r
F P
0 g
s
.84044 .56714 m .83828 .62389 L .83533 .61815 L p .707 .577 .707 r
F P
0 g
s
.83533 .61815 m .83749 .5614 L .84044 .56714 L p .707 .577 .707 r
F P
0 g
s
.63913 .71327 m .6405 .73053 L .65325 .74249 L p .707 .577 .707 r
F P
0 g
s
.83263 .70588 m .834 .72314 L .84087 .70907 L p .707 .577 .707 r
F P
0 g
s
.84087 .70907 m .83949 .69181 L .83263 .70588 L p .707 .577 .707 r
F P
0 g
s
.63393 .63163 m .63418 .66851 L .63708 .67752 L p .707 .577 .707 r
F P
0 g
s
.6345 .61405 m .63666 .5573 L .64368 .55204 L p .707 .577 .707 r
F P
0 g
s
.83783 .63423 m .83807 .67111 L .83517 .6621 L p .707 .577 .707 r
F P
0 g
s
.83517 .6621 m .83493 .62522 L .83783 .63423 L p .707 .577 .707 r
F P
0 g
s
.6405 .73053 m .63913 .71327 L .63603 .69958 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64368 .55204 m .64152 .60879 L .6345 .61405 L p .707 .577 .707 r
F P
0 g
s
.63418 .66851 m .63393 .63163 L .64102 .62274 L p .707 .577 .707 r
F P
0 g
s
.63603 .69958 m .63741 .71684 L .6405 .73053 L p .707 .577 .707 r
F P
0 g
s
.83749 .5614 m .83533 .61815 L .82269 .61248 L p .707 .577 .707 r
F P
0 g
s
.82269 .61248 m .82485 .55574 L .83749 .5614 L p .707 .577 .707 r
F P
0 g
s
.83949 .69181 m .84087 .70907 L .83777 .69539 L p .707 .577 .707 r
F P
0 g
s
.83777 .69539 m .8364 .67813 L .83949 .69181 L p .707 .577 .707 r
F P
0 g
s
.64102 .62274 m .64126 .65963 L .63418 .66851 L p .707 .577 .707 r
F P
0 g
s
.38679 .59996 m .38895 .54321 L .35778 .54082 L p .707 .577 .707 r
F P
0 g
s
.38895 .54321 m .38679 .59996 L .4186 .60061 L p .707 .577 .707 r
F P
0 g
s
.4186 .60061 m .42075 .54386 L .38895 .54321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.44794 .59945 m .45009 .5427 L .42075 .54386 L p .707 .577 .707 r
F P
0 g
s
.64152 .60879 m .64368 .55204 L .65999 .54777 L p .707 .577 .707 r
F P
0 g
s
.83493 .62522 m .83517 .6621 L .82258 .65385 L p .707 .577 .707 r
F P
0 g
s
.82258 .65385 m .82234 .61696 L .83493 .62522 L p .707 .577 .707 r
F P
0 g
s
.35562 .59757 m .35778 .54082 L .33031 .53692 L p .707 .577 .707 r
F P
0 g
s
.35778 .54082 m .35562 .59757 L .38679 .59996 L p .707 .577 .707 r
F P
0 g
s
.63741 .71684 m .63603 .69958 L .6429 .68552 L p .707 .577 .707 r
F P
0 g
s
.65999 .54777 m .65783 .60452 L .64152 .60879 L p .707 .577 .707 r
F P
0 g
s
.38635 .66195 m .3861 .62506 L .35493 .62324 L p .707 .577 .707 r
F P
0 g
s
.3861 .62506 m .38635 .66195 L .41818 .66093 L p .707 .577 .707 r
F P
0 g
s
.41818 .66093 m .41794 .62405 L .3861 .62506 L p .707 .577 .707 r
F P
0 g
s
.45009 .5427 m .44794 .59945 L .47193 .5966 L p .707 .577 .707 r
F P
0 g
s
.47193 .5966 m .47409 .53985 L .45009 .5427 L p .707 .577 .707 r
F P
0 g
s
.33031 .53692 m .32816 .59367 L .35562 .59757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64126 .65963 m .64102 .62274 L .65738 .61486 L p .707 .577 .707 r
F P
0 g
s
.44756 .65718 m .44732 .6203 L .41794 .62405 L p .707 .577 .707 r
F P
0 g
s
.6429 .68552 m .64427 .70278 L .63741 .71684 L p .707 .577 .707 r
F P
0 g
s
.35517 .66013 m .35493 .62324 L .32747 .61877 L p .707 .577 .707 r
F P
0 g
s
.35493 .62324 m .35517 .66013 L .38635 .66195 L p .707 .577 .707 r
F P
0 g
s
.82485 .55574 m .82269 .61248 L .80161 .60746 L p .707 .577 .707 r
F P
0 g
s
.80161 .60746 m .80377 .55071 L .82485 .55574 L p .707 .577 .707 r
F P
0 g
s
.32816 .59367 m .33031 .53692 L .30923 .53189 L p .707 .577 .707 r
F P
0 g
s
.8364 .67813 m .83777 .69539 L .82503 .68342 L p .707 .577 .707 r
F P
0 g
s
.82503 .68342 m .82365 .66616 L .8364 .67813 L p .707 .577 .707 r
F P
0 g
s
.65738 .61486 m .65763 .65174 L .64126 .65963 L p .707 .577 .707 r
F P
0 g
s
.44732 .6203 m .44756 .65718 L .47161 .65106 L p .707 .577 .707 r
F P
0 g
s
.47161 .65106 m .47137 .61418 L .44732 .6203 L p .707 .577 .707 r
F P
0 g
s
.65783 .60452 m .65999 .54777 L .68399 .54492 L p .707 .577 .707 r
F P
0 g
s
.30923 .53189 m .30707 .58864 L .32816 .59367 L p .707 .577 .707 r
F P
0 g
s
.82234 .61696 m .82258 .65385 L .80152 .64715 L p .707 .577 .707 r
F P
0 g
s
.80152 .64715 m .80128 .61027 L .82234 .61696 L p .707 .577 .707 r
F P
0 g
s
.32747 .61877 m .32772 .65565 L .35517 .66013 L p .707 .577 .707 r
F P
0 g
s
.47409 .53985 m .47193 .5966 L .48824 .59234 L p .707 .577 .707 r
F P
0 g
s
.48824 .59234 m .4904 .53559 L .47409 .53985 L p .707 .577 .707 r
F P
0 g
s
.32772 .65565 m .32747 .61877 L .30642 .61208 L p .707 .577 .707 r
F P
0 g
s
.64427 .70278 m .6429 .68552 L .65905 .67245 L p .707 .577 .707 r
F P
0 g
s
.68399 .54492 m .68183 .60167 L .65783 .60452 L p .707 .577 .707 r
F P
0 g
s
.65763 .65174 m .65738 .61486 L .68143 .60874 L p .707 .577 .707 r
F P
0 g
s
.39003 .72104 m .38865 .70378 L .35752 .70279 L p .707 .577 .707 r
F P
0 g
s
.38865 .70378 m .39003 .72104 L .42176 .71765 L p .707 .577 .707 r
F P
0 g
s
.42176 .71765 m .42039 .70039 L .38865 .70378 L p .707 .577 .707 r
F P
0 g
s
.42039 .70039 m .42176 .71765 L .45099 .71019 L p .707 .577 .707 r
F P
0 g
s
.45099 .71019 m .44961 .69293 L .42039 .70039 L p .707 .577 .707 r
F P
0 g
s
.80377 .55071 m .80161 .60746 L .77414 .60356 L p .707 .577 .707 r
F P
0 g
s
.77414 .60356 m .7763 .54681 L .80377 .55071 L p .707 .577 .707 r
F P
0 g
s
.30707 .58864 m .30923 .53189 L .2966 .52623 L p .707 .577 .707 r
F P
0 g
s
.65905 .67245 m .66042 .68971 L .64427 .70278 L p .707 .577 .707 r
F P
0 g
s
.30642 .61208 m .30666 .64896 L .32772 .65565 L p .707 .577 .707 r
F P
0 g
s
.82365 .66616 m .82503 .68342 L .80387 .67435 L p .707 .577 .707 r
F P
0 g
s
.80387 .67435 m .8025 .65709 L .82365 .66616 L p .707 .577 .707 r
F P
0 g
s
.47137 .61418 m .47161 .65106 L .48798 .64318 L p .707 .577 .707 r
F P
0 g
s
.48798 .64318 m .48774 .60629 L .47137 .61418 L p .707 .577 .707 r
F P
0 g
s
.35889 .72005 m .35752 .70279 L .33002 .69749 L p .707 .577 .707 r
F P
0 g
s
.35752 .70279 m .35889 .72005 L .39003 .72104 L p .707 .577 .707 r
F P
0 g
s
.68183 .60167 m .68399 .54492 L .71333 .54377 L p .707 .577 .707 r
F P
0 g
s
.68143 .60874 m .68168 .64563 L .65763 .65174 L p .707 .577 .707 r
F P
0 g
s
.80128 .61027 m .80152 .64715 L .77407 .64268 L p .707 .577 .707 r
F P
0 g
s
.77407 .64268 m .77382 .60579 L .80128 .61027 L p .707 .577 .707 r
F P
0 g
s
.2966 .52623 m .29444 .58298 L .30707 .58864 L p .707 .577 .707 r
F P
0 g
s
.44961 .69293 m .45099 .71019 L .47484 .69939 L p .707 .577 .707 r
F P
0 g
s
.47484 .69939 m .47347 .68213 L .44961 .69293 L p .707 .577 .707 r
F P
0 g
s
.33002 .69749 m .3314 .71475 L .35889 .72005 L p .707 .577 .707 r
F P
0 g
s
.30666 .64896 m .30642 .61208 L .29382 .60382 L p .707 .577 .707 r
F P
0 g
s
.7763 .54681 m .77414 .60356 L .74298 .60116 L p .707 .577 .707 r
F P
0 g
s
.74298 .60116 m .74514 .54442 L .7763 .54681 L p .707 .577 .707 r
F P
0 g
s
.71333 .54377 m .71117 .60051 L .68183 .60167 L p .707 .577 .707 r
F P
0 g
s
.4904 .53559 m .48824 .59234 L .49527 .58707 L p .707 .577 .707 r
F P
0 g
s
.49527 .58707 m .49743 .53033 L .4904 .53559 L p .707 .577 .707 r
F P
0 g
s
.68168 .64563 m .68143 .60874 L .71082 .60499 L p .707 .577 .707 r
F P
0 g
s
.66042 .68971 m .65905 .67245 L .6829 .66165 L p .707 .577 .707 r
F P
0 g
s
.71117 .60051 m .71333 .54377 L .74514 .54442 L p .707 .577 .707 r
F P
0 g
s
.3314 .71475 m .33002 .69749 L .30887 .68842 L p .707 .577 .707 r
F P
0 g
s
.74514 .54442 m .74298 .60116 L .71117 .60051 L p .707 .577 .707 r
F P
0 g
s
.77382 .60579 m .77407 .64268 L .74289 .64086 L p .707 .577 .707 r
F P
0 g
s
.74289 .64086 m .74265 .60398 L .77382 .60579 L p .707 .577 .707 r
F P
0 g
s
.29382 .60382 m .29407 .64071 L .30666 .64896 L p .707 .577 .707 r
F P
0 g
s
.8025 .65709 m .80387 .67435 L .77638 .66905 L p .707 .577 .707 r
F P
0 g
s
.77638 .66905 m .775 .65179 L .8025 .65709 L p .707 .577 .707 r
F P
0 g
s
.6829 .66165 m .68428 .67891 L .66042 .68971 L p .707 .577 .707 r
F P
0 g
s
.47347 .68213 m .47484 .69939 L .49099 .68632 L p .707 .577 .707 r
F P
0 g
s
.49099 .68632 m .48962 .66906 L .47347 .68213 L p .707 .577 .707 r
F P
0 g
s
.29444 .58298 m .2966 .52623 L .29365 .52048 L p .707 .577 .707 r
F P
0 g
s
.71082 .60499 m .71106 .64188 L .68168 .64563 L p .707 .577 .707 r
F P
0 g
s
.30887 .68842 m .31024 .70568 L .3314 .71475 L p .707 .577 .707 r
F P
0 g
s
.71106 .64188 m .71082 .60499 L .74265 .60398 L p .707 .577 .707 r
F P
0 g
s
.48774 .60629 m .48798 .64318 L .49506 .6343 L p .707 .577 .707 r
F P
0 g
s
.49506 .6343 m .49482 .59741 L .48774 .60629 L p .707 .577 .707 r
F P
0 g
s
.74265 .60398 m .74289 .64086 L .71106 .64188 L p .707 .577 .707 r
F P
0 g
s
.68428 .67891 m .6829 .66165 L .71213 .65419 L p .707 .577 .707 r
F P
0 g
s
.29365 .52048 m .29149 .57723 L .29444 .58298 L p .707 .577 .707 r
F P
0 g
s
.775 .65179 m .77638 .66905 L .74524 .66806 L p .707 .577 .707 r
F P
0 g
s
.74524 .66806 m .74387 .65079 L .775 .65179 L p .707 .577 .707 r
F P
0 g
s
.31024 .70568 m .30887 .68842 L .29612 .67645 L p .707 .577 .707 r
F P
0 g
s
.29407 .64071 m .29382 .60382 L .29092 .59481 L p .707 .577 .707 r
F P
0 g
s
.71213 .65419 m .7135 .67145 L .68428 .67891 L p .707 .577 .707 r
F P
0 g
s
.7135 .67145 m .71213 .65419 L .74387 .65079 L p .707 .577 .707 r
F P
0 g
s
.49743 .53033 m .49527 .58707 L .49232 .58133 L p .707 .577 .707 r
F P
0 g
s
.49232 .58133 m .49448 .52458 L .49743 .53033 L p .707 .577 .707 r
F P
0 g
s
.74387 .65079 m .74524 .66806 L .7135 .67145 L p .707 .577 .707 r
F P
0 g
s
.29612 .67645 m .29749 .69371 L .31024 .70568 L p .707 .577 .707 r
F P
0 g
s
.48962 .66906 m .49099 .68632 L .49786 .67226 L p .707 .577 .707 r
F P
0 g
s
.49786 .67226 m .49648 .655 L .48962 .66906 L p .707 .577 .707 r
F P
0 g
s
.29092 .59481 m .29117 .6317 L .29407 .64071 L p .707 .577 .707 r
F P
0 g
s
.29149 .57723 m .29365 .52048 L .30067 .51522 L p .707 .577 .707 r
F P
0 g
s
.49482 .59741 m .49506 .6343 L .49216 .62529 L p .707 .577 .707 r
F P
0 g
s
.49216 .62529 m .49192 .5884 L .49482 .59741 L p .707 .577 .707 r
F P
0 g
s
.29749 .69371 m .29612 .67645 L .29302 .66277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30067 .51522 m .29851 .57197 L .29149 .57723 L p .707 .577 .707 r
F P
0 g
s
.29117 .6317 m .29092 .59481 L .298 .58593 L p .707 .577 .707 r
F P
0 g
s
.29302 .66277 m .2944 .68003 L .29749 .69371 L p .707 .577 .707 r
F P
0 g
s
.49448 .52458 m .49232 .58133 L .47968 .57567 L p .707 .577 .707 r
F P
0 g
s
.47968 .57567 m .48184 .51892 L .49448 .52458 L p .707 .577 .707 r
F P
0 g
s
.49648 .655 m .49786 .67226 L .49476 .65857 L p .707 .577 .707 r
F P
0 g
s
.49476 .65857 m .49339 .64131 L .49648 .655 L p .707 .577 .707 r
F P
0 g
s
.298 .58593 m .29825 .62281 L .29117 .6317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29851 .57197 m .30067 .51522 L .31698 .51096 L p .707 .577 .707 r
F P
0 g
s
.49192 .5884 m .49216 .62529 L .47957 .61703 L p .707 .577 .707 r
F P
0 g
s
.47957 .61703 m .47933 .58015 L .49192 .5884 L p .707 .577 .707 r
F P
0 g
s
.2944 .68003 m .29302 .66277 L .29989 .6487 L p .707 .577 .707 r
F P
0 g
s
.31698 .51096 m .31482 .56771 L .29851 .57197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29825 .62281 m .298 .58593 L .31437 .57804 L p .707 .577 .707 r
F P
0 g
s
.29989 .6487 m .30126 .66596 L .2944 .68003 L p .707 .577 .707 r
F P
0 g
s
.48184 .51892 m .47968 .57567 L .4586 .57064 L p .707 .577 .707 r
F P
0 g
s
.4586 .57064 m .46076 .51389 L .48184 .51892 L p .707 .577 .707 r
F P
0 g
s
.49339 .64131 m .49476 .65857 L .48201 .64661 L p .707 .577 .707 r
F P
0 g
s
.48201 .64661 m .48064 .62935 L .49339 .64131 L p .707 .577 .707 r
F P
0 g
s
.31437 .57804 m .31462 .61493 L .29825 .62281 L p .707 .577 .707 r
F P
0 g
s
.31482 .56771 m .31698 .51096 L .34098 .50811 L p .707 .577 .707 r
F P
0 g
s
.47933 .58015 m .47957 .61703 L .45851 .61034 L p .707 .577 .707 r
F P
0 g
s
.45851 .61034 m .45827 .57345 L .47933 .58015 L p .707 .577 .707 r
F P
0 g
s
.30126 .66596 m .29989 .6487 L .31604 .63563 L p .707 .577 .707 r
F P
0 g
s
.34098 .50811 m .33882 .56486 L .31482 .56771 L p .707 .577 .707 r
F P
0 g
s
.31462 .61493 m .31437 .57804 L .33842 .57193 L p .707 .577 .707 r
F P
0 g
s
.46076 .51389 m .4586 .57064 L .43113 .56674 L p .707 .577 .707 r
F P
0 g
s
.43113 .56674 m .43329 .50999 L .46076 .51389 L p .707 .577 .707 r
F P
0 g
s
.31604 .63563 m .31741 .65289 L .30126 .66596 L p .707 .577 .707 r
F P
0 g
s
.48064 .62935 m .48201 .64661 L .46086 .63753 L p .707 .577 .707 r
F P
0 g
s
.46086 .63753 m .45949 .62027 L .48064 .62935 L p .707 .577 .707 r
F P
0 g
s
.33882 .56486 m .34098 .50811 L .37032 .50695 L p .707 .577 .707 r
F P
0 g
s
.33842 .57193 m .33867 .60881 L .31462 .61493 L p .707 .577 .707 r
F P
0 g
s
.45827 .57345 m .45851 .61034 L .43106 .60586 L p .707 .577 .707 r
F P
0 g
s
.43106 .60586 m .43081 .56898 L .45827 .57345 L p .707 .577 .707 r
F P
0 g
s
.43329 .50999 m .43113 .56674 L .39997 .56435 L p .707 .577 .707 r
F P
0 g
s
.39997 .56435 m .40213 .5076 L .43329 .50999 L p .707 .577 .707 r
F P
0 g
s
.37032 .50695 m .36816 .5637 L .33882 .56486 L p .707 .577 .707 r
F P
0 g
s
.33867 .60881 m .33842 .57193 L .3678 .56818 L p .707 .577 .707 r
F P
0 g
s
.31741 .65289 m .31604 .63563 L .33989 .62484 L p .707 .577 .707 r
F P
0 g
s
.36816 .5637 m .37032 .50695 L .40213 .5076 L p .707 .577 .707 r
F P
0 g
s
.40213 .5076 m .39997 .56435 L .36816 .5637 L p .707 .577 .707 r
F P
0 g
s
.43081 .56898 m .43106 .60586 L .39988 .60405 L p .707 .577 .707 r
F P
0 g
s
.39988 .60405 m .39964 .56716 L .43081 .56898 L p .707 .577 .707 r
F P
0 g
s
.45949 .62027 m .46086 .63753 L .43337 .63224 L p .707 .577 .707 r
F P
0 g
s
.43337 .63224 m .43199 .61498 L .45949 .62027 L p .707 .577 .707 r
F P
0 g
s
.33989 .62484 m .34127 .6421 L .31741 .65289 L p .707 .577 .707 r
F P
0 g
s
.3678 .56818 m .36805 .60506 L .33867 .60881 L p .707 .577 .707 r
F P
0 g
s
.36805 .60506 m .3678 .56818 L .39964 .56716 L p .707 .577 .707 r
F P
0 g
s
.39964 .56716 m .39988 .60405 L .36805 .60506 L p .707 .577 .707 r
F P
0 g
s
.34127 .6421 m .33989 .62484 L .36912 .61738 L p .707 .577 .707 r
F P
0 g
s
.43199 .61498 m .43337 .63224 L .40223 .63124 L p .707 .577 .707 r
F P
0 g
s
.40223 .63124 m .40085 .61398 L .43199 .61498 L p .707 .577 .707 r
F P
0 g
s
.36912 .61738 m .37049 .63464 L .34127 .6421 L p .707 .577 .707 r
F P
0 g
s
.37049 .63464 m .36912 .61738 L .40085 .61398 L p .707 .577 .707 r
F P
0 g
s
.40085 .61398 m .40223 .63124 L .37049 .63464 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008=ooaD008Eo
o`00OGoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF2@00O7oo001gOol60008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol007=oo`@0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0075oo`00Kgoo10001UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000KGoo001]Ool20000
0eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH3001ZOol006]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Qoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00P00IWoo001XOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06=oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Aoo`00GWoo6@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P00I7oo001HOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol005Eoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH6000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000I7oo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=o
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20007OolI0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008003Aoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`00<Goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002ioo`00DWoo00<005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF
00000UYF1`001eYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001BOol00`00FUH000030005FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000080003FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059o
o`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF000000020002FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP000080009JEP@000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00E7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP`00003FUH005YF00IJEPP00003FUH0000000H000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP0009JEP03
001JEUYF00AJEPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0015YF00<005YFFUH01EYF2@0015YF
00@005YFFUIJEPP00003FUH0000000<000AJEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000AJ
EP04001JEUYFFUH90002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60004FUH0
0`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00
FUH00`001EYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPT00003FUH005YF
009JEP8002ioo`00DWoo00<005YF000015YF100027oo00@005YFFUH000AJEPl000QJEP<00004FUH0
05YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUH000050002FUH2000^Ool0059oo`03001JEP00009JEP800003FUH0000000<000Io
o`03001JEP0000D000AJEP03001JEUYF00IJEP03001JEP0000<00007FUH00000001JEP00FUH00P00
0UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP0000000P00;Woo001BOol00`00FUH000030005FUH00`00FUH0000700000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP02FUH40004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1P00;Woo
001BOol00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00;Woo
000gOolM0003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000_
Ool0035oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001J
EUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH300000eYF
001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEP000006FUH00`00FUIJEP04FUH;
0003FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH010001EYF1P000eYF00<005YFFUH01UYF
00<005YF00000`0015YF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000IJEPD000QJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0
0005FUH005YFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH00UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000HOol4
00000eYF001JEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000AJEP00FUH000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YF0000
0`008Woo10000eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP04001JEP000003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP<0019ooa40
00Aoo`H000=JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1@0000=JEP00FUH01EYF0`000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUH005YF001JEP020003FUH50007Ool60004FUH00`00FUIJEP06
FUH01000FUIJEUYF1@000UYF00@005YFFUH0009JEP8002ioo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80009JEP03
001JEUYF00=JEPP000AJEP03001JEUYF009JEP`000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH01000FUIJEUYF1`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF1000;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF
00<005YFFUH00eYF00D005YFFUIJEP00009JEPX000IJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001J
EUYF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF008000=JEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=J
EP<00003FUH005YF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP80
0004FUH00000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH<0003FUH80004FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF008000EJEP03001JEUYF009JEP8000IJEPH0
00=JEP03001JEUYF00EJEPD000EJEP04001JEP00000_Ool002]oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF0080
009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH40006FUH00`00FUH000020008FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP09FUH00`00FUH00004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200001EYF001JEUYF0000;goo
000[Ool00`00FUH00004FUH01000FUIJEUYF6@0015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000002FUH00`00Oomoo`0]Ool002]oo`03001JEP00009JEPL000MJEP03001J
EUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00005FUH00`00FUIJEP020002FUH00`00
FUIJEP03FUH50005FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YF000000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`04001J
EUYF000^Ool002]oo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00L000=JEP03001JEUYF0080009JEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00EJEP8000AJEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030006Ool3000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH20002
FUH40002FUH20002FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP03FUH20006FUH30008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YFFUH0009JEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000]oo`8002io
o`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEPD00003FUH000000080009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEP0000<00003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH30002FUH00`00FUIJEP04FUHJ000@Ool2000^
Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH01000FUIJEUYF2@001EYF00@005YFFUIJEPL000EJEP03001JEUYF009J
EP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH01@00FUIJEUYF000097oo00@005YF000002eoo`00;Goo0P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF2P0025YF00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF008000AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo029oo`04001JEUYF000]Ool002moo`@000=JEP03001JEUYF00EJEPP000AJ
EP03001JEUYF009JEPP00004FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8002=oo`80009J
EP03001oogoo02]oo`00<goo2`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P008Woo00D005YF001JEP0002ioo`00<Woo10000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP04001JEUYF
FUH20009Ool3000EOol01000FUIJEUYF0P00;Woo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0004FUH00`00FUIJEP02FUH6
000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000BOol20004FUH00`00Oomo
o`0]Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00006Ool005YFFUH005YF2@001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH005YF009JEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000@Ool200000eYF001J
EP03FUH00`00Oomoo`0]Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00D000AJEP04001JEUYF
FUH20008Ool5000>Ool20003FUH01@00FUIJEUYF0000<7oo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH01P0000=JEP00FUH00UYF0P002Goo0`002goo10001EYF00@005YF0000035oo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF000015YF1P000UYF0P004goo10000UYF00<005YFFUH015YF0P00<goo000[
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUH00006000<Ool70006FUH00`00FUIJEP03
FUH2000dOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00=JEPl000AJEP03001JEUYF
00IJEP04001JEUYFFUH2000fOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>7oo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH60008OolG0004FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH=000;FUH90008
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH700000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH3000jOol002]oo`03001JEP0000AJEP03001JEP0000<000Qoo`H000AJ
EP03001JEUYF00IJEP04001JEUYFFUH500001Woo00000000FUH0009JEP80009JEP03001JEUYF00AJ
EP03001JEUYF00=JEP/000]JEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@003eoo`00:goo00<005YF00000eYF10001goo100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF0P000UYF00<005YFFUH015YF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00@Goo000[Ool01000FUH005YF0P0015YF1`001EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEP<000=J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP800003Ool0000000h004Qo
o`00:goo00H005YF000005YF0005FUH200000eYF001JEP07FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000AJEP000000009JEP04001JEUYFFUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40005FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000Egoo000[Ool20003FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF2P0015YF2@0015YF00<005YFFUH00UYF1@000UYF00@005YF000000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EUYFFUH00004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo000[Ool20003
FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
15YF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00:goo0P000eYF0`001eYF00<005YF00000P00
1eYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00H005YFFUH005YF
0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000[Ool20002FUH200000eYF001JEP05FUH300000eYF001JEP07FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH2000015YF001JEUYF0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`03001JEP00
00AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH000000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP04001JEP000006FUH00`00FUIJEP06
FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02eoo`8000AJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEP00001oo`030004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP070004FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUH00002FUH400000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH600000eYF001JEP02FUH2001EOol0
02aoo`03001JEP00008000Aoo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP00
00<000=JEP8005Eoo`00;7oo00<005YF00002Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P002Woo0`000Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH00UYF0`00
00=JEP000000EGoo000/Ool2000>OolH000@Ool00`00FUH00004Ool20007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF1@00
1UYF00<005YFFUH00eYF1@00EGoo000/Ool2000eOol200000eYF001oo`05Ool30004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0
00001EYF10000UYF00<005YFFUH00eYF1@00EGoo000/Ool2000cOol200000eYF0000000:Ool30000
0eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
00000eYF001JEP06FUH00`00FUH000030004FUH01@00FUH005YF0000EGoo000/Ool3000aOol01000
FUIJEUYF0P003Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01P0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP8005Eoo`00;7oo0`00
;goo0P0015YF00<007ooOol04goo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF200000=JEP00
000010000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001oogoo05Aoo`00
;7oo0P0000=JEP00Ool0:goo0P0000=JEP00FUH00eYF00<007ooOol07Woo6`0025YF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001FOol002eoo`03001JEUYF008002Qo
o`8000=JEP05001JEUYFFUH0000ZOol20004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001oo`1DOol002eoo`05001J
EUYF001JEP03000ROol30005FUH01000FUH00000:goo0P000eYF00D005YFFUIJEP0000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=oo`8005Eoo`00
;Woo00<005YF000015YF0`006goo100000=JEP00FUH01EYF0P00;7oo00D005YFFUH005YF00@00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40005
Ool2001EOol002moo`03001JEP0000AJEP03001JEP0000<0011oo`L000EJEP03001JEUYF00AJEP03
001oogoo02]oo`03001JEUYF008000Aoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Uoo`8005Eoo`00<7oo0P0015YF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
00@005YFFUIJEP8002ioo`04001JEUYF000:Ool90004FUH00`00FUIJEP02FUH9000?Ool01000FUH0
0000E7oo000aOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000<7oo00<005YF000057oo2@0067oo00@005YFFUH005Aoo`00<goo0`0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000<goo0P00=7oo0P00
0UYF00<007ooOol0DWoo000fOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
000gOol00`00Oomoo`0aOol2000015YF001JEP00EGoo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH7000kOol2000`Ool20004FUH2001EOol003eoo`l0049oo`04001JEP00000/Ool20000
0eYF001JEP03FUH00`00Oomoo`1DOol008ioo`80009JEP03001oogoo02Moo`8000=JEP03001JEUYF
009JEP03001oogoo05Aoo`00Sgoo00<005YFFUH00`0097oo0`001EYF00<005YFFUH00P00Egoo002?
Ool01000FUIJEP000UYF0P007goo0`0000=JEP00FUH01EYF0`00FGoo002@Ool00`00FUH00004FUH5
000GOol30004FUH00`00FUIJEP03FUH2001KOol0095oo`8000EJEP04001JEUYFFUH80009Ool60007
FUH01000FUIJEUYF0P00GGoo002BOol00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@00
15YF00<005YFFUH01UYF00@005YF000005moo`00Tgoo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`00HGoo002EOol200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP04001TOol009Moo`D000AJEP03001JEUYF00IJEP03001J
EUYF009JEPL006Qoo`00W7oo4P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5906 .75944 m .59408 .70227 L .56293 .69957 L p .707 .577 .707 r
F P
0 g
s
.59408 .70227 m .5906 .75944 L .62236 .76099 L p .707 .577 .707 r
F P
0 g
s
.62236 .76099 m .62584 .70381 L .59408 .70227 L p .707 .577 .707 r
F P
0 g
s
.62584 .70381 m .62236 .76099 L .65163 .76122 L p .707 .577 .707 r
F P
0 g
s
.65163 .76122 m .65511 .70404 L .62584 .70381 L p .707 .577 .707 r
F P
0 g
s
.55945 .75674 m .56293 .69957 L .53545 .69597 L p .707 .577 .707 r
F P
0 g
s
.56293 .69957 m .55945 .75674 L .5906 .75944 L p .707 .577 .707 r
F P
0 g
s
.53545 .69597 m .53197 .75315 L .55945 .75674 L p .707 .577 .707 r
F P
0 g
s
.65511 .70404 m .65163 .76122 L .67554 .76013 L p .707 .577 .707 r
F P
0 g
s
.67554 .76013 m .67903 .70295 L .65511 .70404 L p .707 .577 .707 r
F P
0 g
s
.5897 .85448 m .58931 .8177 L .55813 .81594 L p .707 .577 .707 r
F P
0 g
s
.58931 .8177 m .5897 .85448 L .62153 .85332 L p .707 .577 .707 r
F P
0 g
s
.62153 .85332 m .62114 .81654 L .58931 .8177 L p .707 .577 .707 r
F P
0 g
s
.62114 .81654 m .62153 .85332 L .65091 .84934 L p .707 .577 .707 r
F P
0 g
s
.65091 .84934 m .65052 .81256 L .62114 .81654 L p .707 .577 .707 r
F P
0 g
s
.53197 .75315 m .53545 .69597 L .51432 .69184 L p .707 .577 .707 r
F P
0 g
s
.55853 .85271 m .55813 .81594 L .53068 .81141 L p .707 .577 .707 r
F P
0 g
s
.55813 .81594 m .55853 .85271 L .5897 .85448 L p .707 .577 .707 r
F P
0 g
s
.51432 .69184 m .51084 .74902 L .53197 .75315 L p .707 .577 .707 r
F P
0 g
s
.65052 .81256 m .65091 .84934 L .67496 .84293 L p .707 .577 .707 r
F P
0 g
s
.67496 .84293 m .67457 .80616 L .65052 .81256 L p .707 .577 .707 r
F P
0 g
s
.67903 .70295 m .67554 .76013 L .69176 .75781 L p .707 .577 .707 r
F P
0 g
s
.69176 .75781 m .69524 .70063 L .67903 .70295 L p .707 .577 .707 r
F P
0 g
s
.53068 .81141 m .53107 .84819 L .55853 .85271 L p .707 .577 .707 r
F P
0 g
s
.53107 .84819 m .53068 .81141 L .50962 .80457 L p .707 .577 .707 r
F P
0 g
s
.51084 .74902 m .51432 .69184 L .50162 .68757 L p .707 .577 .707 r
F P
0 g
s
.50162 .68757 m .49813 .74475 L .51084 .74902 L p .707 .577 .707 r
F P
0 g
s
.50962 .80457 m .51001 .84135 L .53107 .84819 L p .707 .577 .707 r
F P
0 g
s
.5963 .91202 m .5941 .89587 L .56302 .89539 L p .707 .577 .707 r
F P
0 g
s
.5941 .89587 m .5963 .91202 L .62788 .90711 L p .707 .577 .707 r
F P
0 g
s
.62788 .90711 m .62568 .89096 L .5941 .89587 L p .707 .577 .707 r
F P
0 g
s
.67457 .80616 m .67496 .84293 L .69133 .83473 L p .707 .577 .707 r
F P
0 g
s
.69133 .83473 m .69093 .79795 L .67457 .80616 L p .707 .577 .707 r
F P
0 g
s
.62568 .89096 m .62788 .90711 L .65685 .8973 L p .707 .577 .707 r
F P
0 g
s
.65685 .8973 m .65465 .88115 L .62568 .89096 L p .707 .577 .707 r
F P
0 g
s
.56522 .91154 m .56302 .89539 L .53547 .88957 L p .707 .577 .707 r
F P
0 g
s
.56302 .89539 m .56522 .91154 L .5963 .91202 L p .707 .577 .707 r
F P
0 g
s
.65465 .88115 m .65685 .8973 L .68039 .88355 L p .707 .577 .707 r
F P
0 g
s
.68039 .88355 m .67819 .86739 L .65465 .88115 L p .707 .577 .707 r
F P
0 g
s
.69524 .70063 m .69176 .75781 L .69868 .75449 L p .707 .577 .707 r
F P
0 g
s
.69868 .75449 m .70217 .69731 L .69524 .70063 L p .707 .577 .707 r
F P
0 g
s
.51001 .84135 m .50962 .80457 L .49702 .79609 L p .707 .577 .707 r
F P
0 g
s
.53547 .88957 m .53767 .90573 L .56522 .91154 L p .707 .577 .707 r
F P
0 g
s
.49813 .74475 m .50162 .68757 L .49858 .68358 L p .707 .577 .707 r
F P
0 g
s
.53767 .90573 m .53547 .88957 L .51416 .87899 L p .707 .577 .707 r
F P
0 g
s
.49702 .79609 m .49742 .83286 L .51001 .84135 L p .707 .577 .707 r
F P
0 g
s
.69093 .79795 m .69133 .83473 L .6984 .82553 L p .707 .577 .707 r
F P
0 g
s
.6984 .82553 m .69801 .78875 L .69093 .79795 L p .707 .577 .707 r
F P
0 g
s
.67819 .86739 m .68039 .88355 L .69619 .86719 L p .707 .577 .707 r
F P
0 g
s
.69619 .86719 m .69399 .85104 L .67819 .86739 L p .707 .577 .707 r
F P
0 g
s
.49858 .68358 m .4951 .74076 L .49813 .74475 L p .707 .577 .707 r
F P
0 g
s
.51416 .87899 m .51636 .89514 L .53767 .90573 L p .707 .577 .707 r
F P
0 g
s
.49742 .83286 m .49702 .79609 L .49412 .78679 L p .707 .577 .707 r
F P
0 g
s
.70217 .69731 m .69868 .75449 L .69565 .7505 L p .707 .577 .707 r
F P
0 g
s
.69565 .7505 m .69913 .69332 L .70217 .69731 L p .707 .577 .707 r
F P
0 g
s
.51636 .89514 m .51416 .87899 L .50116 .86468 L p .707 .577 .707 r
F P
0 g
s
.69399 .85104 m .69619 .86719 L .7027 .84985 L p .707 .577 .707 r
F P
0 g
s
.7027 .84985 m .7005 .83369 L .69399 .85104 L p .707 .577 .707 r
F P
0 g
s
.49412 .78679 m .49452 .82357 L .49742 .83286 L p .707 .577 .707 r
F P
0 g
s
.4951 .74076 m .49858 .68358 L .50551 .68026 L p .707 .577 .707 r
F P
0 g
s
.50116 .86468 m .50336 .88083 L .51636 .89514 L p .707 .577 .707 r
F P
0 g
s
.69801 .78875 m .6984 .82553 L .6955 .81623 L p .707 .577 .707 r
F P
0 g
s
.6955 .81623 m .69511 .77945 L .69801 .78875 L p .707 .577 .707 r
F P
0 g
s
.50551 .68026 m .50202 .73744 L .4951 .74076 L p .707 .577 .707 r
F P
0 g
s
.50336 .88083 m .50116 .86468 L .49774 .84803 L p .707 .577 .707 r
F P
0 g
s
.49359 .81614 m .49871 .31099 L .4547 .30813 L p .707 .577 .707 r
F P
0 g
s
.49452 .82357 m .49412 .78679 L .5012 .77759 L p .707 .577 .707 r
F P
0 g
s
.5012 .77759 m .50159 .81437 L .49452 .82357 L p .707 .577 .707 r
F P
0 g
s
.50202 .73744 m .50551 .68026 L .52172 .67794 L p .707 .577 .707 r
F P
0 g
s
.52172 .67794 m .51824 .73512 L .50202 .73744 L p .707 .577 .707 r
F P
0 g
s
.50159 .81437 m .5012 .77759 L .51756 .76938 L p .707 .577 .707 r
F P
0 g
s
.51756 .76938 m .51796 .80616 L .50159 .81437 L p .707 .577 .707 r
F P
0 g
s
.51824 .73512 m .52172 .67794 L .54563 .67685 L p .707 .577 .707 r
F P
0 g
s
.54563 .67685 m .54215 .73402 L .51824 .73512 L p .707 .577 .707 r
F P
0 g
s
.50646 .84683 m .50426 .83068 L .52006 .81433 L p .707 .577 .707 r
F P
0 g
s
.51796 .80616 m .51756 .76938 L .54161 .76298 L p .707 .577 .707 r
F P
0 g
s
.52006 .81433 m .52226 .83048 L .50646 .84683 L p .707 .577 .707 r
F P
0 g
s
.54161 .76298 m .54201 .79976 L .51796 .80616 L p .707 .577 .707 r
F P
0 g
s
.52226 .83048 m .52006 .81433 L .5436 .80057 L p .707 .577 .707 r
F P
0 g
s
.5436 .80057 m .5458 .81672 L .52226 .83048 L p .707 .577 .707 r
F P
0 g
s
.49871 .31099 m .49359 .81614 L .53854 .81556 L p .707 .577 .707 r
F P
0 g
s
.53854 .81556 m .54365 .31042 L .49871 .31099 L p .707 .577 .707 r
F P
0 g
s
.69913 .69332 m .69565 .7505 L .68294 .74623 L p .707 .577 .707 r
F P
0 g
s
.68294 .74623 m .68642 .68905 L .69913 .69332 L p .707 .577 .707 r
F P
0 g
s
.54215 .73402 m .54563 .67685 L .5749 .67708 L p .707 .577 .707 r
F P
0 g
s
.5749 .67708 m .57142 .73426 L .54215 .73402 L p .707 .577 .707 r
F P
0 g
s
.57142 .73426 m .5749 .67708 L .60667 .67862 L p .707 .577 .707 r
F P
0 g
s
.54201 .79976 m .54161 .76298 L .57099 .759 L p .707 .577 .707 r
F P
0 g
s
.60667 .67862 m .60318 .7358 L .57142 .73426 L p .707 .577 .707 r
F P
0 g
s
.57099 .759 m .57139 .79578 L .54201 .79976 L p .707 .577 .707 r
F P
0 g
s
.57139 .79578 m .57123 .78091 L p .60283 .75784 L .707 .577 .707 r
F P
0 g
s
.57123 .78091 m .57099 .759 L .5851 .75849 L p .707 .577 .707 r
F P
0 g
s
.5851 .75849 m .60283 .75784 L p .57123 .78091 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .5436 .80057 L .56316 .79395 L p .707 .577 .707 r
F P
0 g
s
.56316 .79395 m .57257 .79076 L p .55397 .80879 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .56316 .79395 L .55397 .80879 L .707 .577 .707 r
F
.60283 .75784 m .60322 .79462 L .57139 .79578 L p F P
0 g
s
.57477 .80691 m .57257 .79076 L .59503 .78727 L p .707 .577 .707 r
F P
0 g
s
.60322 .79462 m .60304 .77775 L p .634 .75961 L .707 .577 .707 r
F P
0 g
s
.59503 .78727 m .60414 .78585 L p .58419 .80016 L .707 .577 .707 r
F P
0 g
s
.57477 .80691 m .59503 .78727 L .58419 .80016 L .707 .577 .707 r
F
.60304 .77775 m .60283 .75784 L .61902 .75876 L p F P
0 g
s
.61902 .75876 m .634 .75961 L p .60304 .77775 L .707 .577 .707 r
F P
0 g
s
.57257 .79076 m .57477 .80691 L .5458 .81672 L p .707 .577 .707 r
F P
0 g
s
.634 .75961 m .63439 .79638 L .60322 .79462 L p .707 .577 .707 r
F P
0 g
s
.60414 .78585 m .60634 .80201 L .57477 .80691 L p .707 .577 .707 r
F P
0 g
s
.54365 .31042 m .53854 .81556 L .58001 .81161 L p .707 .577 .707 r
F P
0 g
s
.58001 .81161 m .58513 .30646 L .54365 .31042 L p .707 .577 .707 r
F P
0 g
s
.7005 .83369 m .7027 .84985 L .69929 .8332 L p .707 .577 .707 r
F P
0 g
s
.69929 .8332 m .69709 .81705 L .7005 .83369 L p .707 .577 .707 r
F P
0 g
s
.24759 .72263 m .25107 .66545 L .21992 .66275 L p .707 .577 .707 r
F P
0 g
s
.25107 .66545 m .24759 .72263 L .27935 .72417 L p .707 .577 .707 r
F P
0 g
s
.27935 .72417 m .28283 .66699 L .25107 .66545 L p .707 .577 .707 r
F P
0 g
s
.44959 .81327 m .4547 .30813 L .41594 .30211 L p .707 .577 .707 r
F P
0 g
s
.4547 .30813 m .44959 .81327 L .49359 .81614 L p .707 .577 .707 r
F P
0 g
s
.49774 .84803 m .49994 .86418 L .50336 .88083 L p .707 .577 .707 r
F P
0 g
s
.28283 .66699 m .27935 .72417 L .30862 .72441 L p .707 .577 .707 r
F P
0 g
s
.30862 .72441 m .3121 .66723 L .28283 .66699 L p .707 .577 .707 r
F P
0 g
s
.21644 .71993 m .21992 .66275 L .19244 .65916 L p .707 .577 .707 r
F P
0 g
s
.21992 .66275 m .21644 .71993 L .24759 .72263 L p .707 .577 .707 r
F P
0 g
s
.69511 .77945 m .6955 .81623 L .68291 .80775 L p .707 .577 .707 r
F P
0 g
s
.68291 .80775 m .68251 .77097 L .69511 .77945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63781 .68132 m .63433 .7385 L .60318 .7358 L p .707 .577 .707 r
F P
0 g
s
.60318 .7358 m .60667 .67862 L .63781 .68132 L p .707 .577 .707 r
F P
0 g
s
.66146 .76413 m .66185 .80091 L .63439 .79638 L p .707 .577 .707 r
F P
0 g
s
.63439 .79638 m .6342 .77883 L p .66146 .76413 L .707 .577 .707 r
F P
0 g
s
.63523 .78633 m .63743 .80248 L .61227 .8021 L p .707 .577 .707 r
F P
0 g
s
.61227 .8021 m .60634 .80201 L p .61866 .79532 L .707 .577 .707 r
F P
0 g
s
.61866 .79532 m .63523 .78633 L .61227 .8021 L .707 .577 .707 r
F
.6342 .77883 m .634 .75961 L .64986 .76222 L p F P
0 g
s
.64986 .76222 m .66146 .76413 L p .6342 .77883 L .707 .577 .707 r
F P
0 g
s
.60634 .80201 m .60414 .78585 L .63523 .78633 L p .707 .577 .707 r
F P
0 g
s
.58513 .30646 m .58001 .81161 L .61396 .80466 L p .707 .577 .707 r
F P
0 g
s
.61396 .80466 m .61908 .29952 L .58513 .30646 L p .707 .577 .707 r
F P
0 g
s
.19244 .65916 m .18896 .71634 L .21644 .71993 L p .707 .577 .707 r
F P
0 g
s
.3121 .66723 m .30862 .72441 L .33253 .72331 L p .707 .577 .707 r
F P
0 g
s
.33253 .72331 m .33602 .66613 L .3121 .66723 L p .707 .577 .707 r
F P
0 g
s
.49994 .86418 m .49774 .84803 L .50426 .83068 L p .707 .577 .707 r
F P
0 g
s
.24669 .81766 m .2463 .78089 L .21513 .77912 L p .707 .577 .707 r
F P
0 g
s
.2463 .78089 m .24669 .81766 L .27852 .8165 L p .707 .577 .707 r
F P
0 g
s
.27852 .8165 m .27813 .77973 L .2463 .78089 L p .707 .577 .707 r
F P
0 g
s
.27813 .77973 m .27852 .8165 L .3079 .81252 L p .707 .577 .707 r
F P
0 g
s
.3079 .81252 m .30751 .77575 L .27813 .77973 L p .707 .577 .707 r
F P
0 g
s
.18896 .71634 m .19244 .65916 L .17131 .65502 L p .707 .577 .707 r
F P
0 g
s
.41082 .80725 m .41594 .30211 L .38621 .29352 L p .707 .577 .707 r
F P
0 g
s
.41594 .30211 m .41082 .80725 L .44959 .81327 L p .707 .577 .707 r
F P
0 g
s
.68642 .68905 m .68294 .74623 L .66181 .7421 L p .707 .577 .707 r
F P
0 g
s
.66181 .7421 m .6653 .68492 L .68642 .68905 L p .707 .577 .707 r
F P
0 g
s
.69709 .81705 m .69929 .8332 L .68629 .81888 L p .707 .577 .707 r
F P
0 g
s
.68629 .81888 m .68409 .80273 L .69709 .81705 L p .707 .577 .707 r
F P
0 g
s
.21552 .8159 m .21513 .77912 L .18767 .7746 L p .707 .577 .707 r
F P
0 g
s
.21513 .77912 m .21552 .8159 L .24669 .81766 L p .707 .577 .707 r
F P
0 g
s
.50426 .83068 m .50646 .84683 L .49994 .86418 L p .707 .577 .707 r
F P
0 g
s
.17131 .65502 m .16783 .7122 L .18896 .71634 L p .707 .577 .707 r
F P
0 g
s
.30751 .77575 m .3079 .81252 L .33195 .80612 L p .707 .577 .707 r
F P
0 g
s
.33195 .80612 m .33156 .76934 L .30751 .77575 L p .707 .577 .707 r
F P
0 g
s
.68251 .77097 m .68291 .80775 L .66185 .80091 L p .707 .577 .707 r
F P
0 g
s
.66185 .80091 m .66167 .78404 L p .68251 .77097 L .707 .577 .707 r
F P
0 g
s
.66277 .79215 m .66497 .8083 L .64513 .80411 L p .707 .577 .707 r
F P
0 g
s
.64513 .80411 m .63743 .80248 L p .65105 .79693 L .707 .577 .707 r
F P
0 g
s
.65105 .79693 m .66277 .79215 L .64513 .80411 L .707 .577 .707 r
F
.66167 .78404 m .66146 .76413 L .67457 .76839 L p F P
0 g
s
.67457 .76839 m .68251 .77097 L p .66167 .78404 L .707 .577 .707 r
F P
0 g
s
.33602 .66613 m .33253 .72331 L .34875 .72099 L p .707 .577 .707 r
F P
0 g
s
.34875 .72099 m .35223 .66381 L .33602 .66613 L p .707 .577 .707 r
F P
0 g
s
.18767 .7746 m .18806 .81137 L .21552 .8159 L p .707 .577 .707 r
F P
0 g
s
.6653 .68492 m .66181 .7421 L .63433 .7385 L p .707 .577 .707 r
F P
0 g
s
.63433 .7385 m .63781 .68132 L .6653 .68492 L p .707 .577 .707 r
F P
0 g
s
.63743 .80248 m .63523 .78633 L .66277 .79215 L p .707 .577 .707 r
F P
0 g
s
.61908 .29952 m .61396 .80466 L .63707 .7954 L p .707 .577 .707 r
F P
0 g
s
.63707 .7954 m .64218 .29025 L .61908 .29952 L p .707 .577 .707 r
F P
0 g
s
.18806 .81137 m .18767 .7746 L .16661 .76776 L p .707 .577 .707 r
F P
0 g
s
.16783 .7122 m .17131 .65502 L .15861 .65075 L p .707 .577 .707 r
F P
0 g
s
.68409 .80273 m .68629 .81888 L .66497 .8083 L p .707 .577 .707 r
F P
0 g
s
.66497 .8083 m .66277 .79215 L .68409 .80273 L p .707 .577 .707 r
F P
0 g
s
.15861 .65075 m .15513 .70793 L .16783 .7122 L p .707 .577 .707 r
F P
0 g
s
.16661 .76776 m .167 .80453 L .18806 .81137 L p .707 .577 .707 r
F P
0 g
s
.25329 .8752 m .25109 .85905 L .22001 .85858 L p .707 .577 .707 r
F P
0 g
s
.25109 .85905 m .25329 .8752 L .28487 .8703 L p .707 .577 .707 r
F P
0 g
s
.28487 .8703 m .28267 .85415 L .25109 .85905 L p .707 .577 .707 r
F P
0 g
s
.33156 .76934 m .33195 .80612 L .34832 .79791 L p .707 .577 .707 r
F P
0 g
s
.34832 .79791 m .34792 .76114 L .33156 .76934 L p .707 .577 .707 r
F P
0 g
s
.28267 .85415 m .28487 .8703 L .31384 .86049 L p .707 .577 .707 r
F P
0 g
s
.31384 .86049 m .31164 .84433 L .28267 .85415 L p .707 .577 .707 r
F P
0 g
s
.38109 .79867 m .38621 .29352 L .36843 .28321 L p .707 .577 .707 r
F P
0 g
s
.38621 .29352 m .38109 .79867 L .41082 .80725 L p .707 .577 .707 r
F P
0 g
s
.22221 .87473 m .22001 .85858 L .19246 .85276 L p .707 .577 .707 r
F P
0 g
s
.22001 .85858 m .22221 .87473 L .25329 .8752 L p .707 .577 .707 r
F P
0 g
s
.31164 .84433 m .31384 .86049 L .33738 .84673 L p .707 .577 .707 r
F P
0 g
s
.33738 .84673 m .33518 .83058 L .31164 .84433 L p .707 .577 .707 r
F P
0 g
s
.35223 .66381 m .34875 .72099 L .35567 .71767 L p .707 .577 .707 r
F P
0 g
s
.35567 .71767 m .35916 .66049 L .35223 .66381 L p .707 .577 .707 r
F P
0 g
s
.167 .80453 m .16661 .76776 L .15401 .75927 L p .707 .577 .707 r
F P
0 g
s
.19246 .85276 m .19466 .86891 L .22221 .87473 L p .707 .577 .707 r
F P
0 g
s
.15513 .70793 m .15861 .65075 L .15557 .64676 L p .707 .577 .707 r
F P
0 g
s
.19466 .86891 m .19246 .85276 L .17115 .84218 L p .707 .577 .707 r
F P
0 g
s
.15401 .75927 m .15441 .79605 L .167 .80453 L p .707 .577 .707 r
F P
0 g
s
.64218 .29025 m .63707 .7954 L .64706 .78473 L p .707 .577 .707 r
F P
0 g
s
.65218 .27958 m .64218 .29025 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64707 .78361 m .65218 .27958 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64707 .78361 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64297 .7737 L p .64455 .68877 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .646 .67628 L .64706 .78473 L .707 .577 .707 r
F
.64558 .63351 m .64562 .63144 L .64752 .73994 L F
.65218 .27958 m .65108 .38807 L p .64562 .63144 L F P
0 g
s
.65108 .38807 m .64752 .73994 L p .64562 .63144 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64558 .63351 L .646 .67628 L .707 .577 .707 r
F
.64752 .73994 m .64706 .78473 L p .64558 .63351 L F P
0 g
s
.64551 .63619 m .63423 .62859 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64808 .26855 m .64583 .49115 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.64583 .49115 m .64481 .59135 L p .63665 .58759 L .707 .577 .707 r
F P
0 g
s
.63339 .58609 m .64583 .49115 L .63665 .58759 L .707 .577 .707 r
F
.63534 .60907 m .63665 .58759 L p .6354 .60069 L F P
0 g
s
.64482 .59189 m .64481 .59135 L .64474 .59132 L .707 .577 .707 r
F
.64808 .26855 m .65218 .27958 L p .64558 .63351 L F P
0 g
s
.63882 .55189 m .63534 .60907 L .6452 .61238 L p .707 .577 .707 r
F P
0 g
s
.64482 .59189 m .63882 .55189 L .6452 .61238 L .707 .577 .707 r
F
.63423 .62859 m .63462 .66536 L .64471 .67216 L p F P
0 g
s
.64297 .7737 m .64341 .72984 L p .64429 .69106 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64429 .69106 L .64558 .63351 L .707 .577 .707 r
F
.64297 .7737 m .64429 .69106 L .64455 .68877 L F
.64485 .66561 m .63423 .62859 L .64471 .67216 L F
.64341 .72984 m .64481 .59135 L p .64558 .63332 L F P
0 g
s
.64341 .72984 m .64558 .63332 L .64558 .63351 L .707 .577 .707 r
F
.63339 .58609 m .63665 .58759 L .63508 .60399 L F
.63468 .60821 m .63534 .60907 L p .6354 .60069 L F P
0 g
s
.63339 .58609 m .64376 .69559 L .63876 .69119 L .707 .577 .707 r
F
.63462 .66536 m .63423 .62859 L .63309 .62496 L p F P
0 g
s
.63462 .66536 m .63309 .62496 L .63369 .65232 L .707 .577 .707 r
F
.63624 .76979 m .62519 .76338 L p .63261 .60284 L F P
0 g
s
.62519 .76338 m .62866 .4204 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.63133 .61929 m .63172 .65607 L .63392 .66312 L p .707 .577 .707 r
F P
0 g
s
.63392 .66312 m .63462 .66536 L p .63369 .65232 L .707 .577 .707 r
F P
0 g
s
.63369 .65232 m .63133 .61929 L .63392 .66312 L .707 .577 .707 r
F
.6303 .25824 m .64808 .26855 L p .63261 .60284 L F P
0 g
s
.62866 .4204 m .6303 .25824 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.64297 .7737 m .63624 .76979 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.63261 .60284 m .63339 .58609 L .63624 .76979 L .707 .577 .707 r
F
.63309 .62496 m .63133 .61929 L p .63369 .65232 L F P
0 g
s
.63578 .5479 m .6323 .60508 L .63468 .60821 L p .707 .577 .707 r
F P
0 g
s
.6354 .60069 m .63578 .5479 L .63468 .60821 L .707 .577 .707 r
F
.64481 .59135 m .64376 .69559 L p .63508 .60399 L F P
0 g
s
.63665 .58759 m .64481 .59135 L .63508 .60399 L .707 .577 .707 r
F
.64376 .69559 m .64297 .7737 L p .63876 .69119 L F P
0 g
s
.64056 .72466 m .65356 .73897 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.63836 .7085 m .64047 .72397 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64047 .72397 m .64056 .72466 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64471 .67216 m .64722 .67385 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64808 .26855 L p .64558 .63351 L .707 .577 .707 r
F P
0 g
s
.6452 .61238 m .64804 .61334 L p .64482 .59189 L .707 .577 .707 r
F P
0 g
s
.63882 .55189 m .63578 .5479 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.63665 .58759 m .63882 .55189 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.64413 .55367 m .63882 .55189 L p .64474 .59132 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64413 .55367 L .64474 .59132 L .707 .577 .707 r
F
.64722 .67385 m .64682 .63707 L .64551 .63619 L p F P
0 g
s
.64722 .67385 m .64551 .63619 L .64485 .66561 L .707 .577 .707 r
F
.65356 .73897 m .65136 .72282 L .64182 .71231 L p F P
0 g
s
.64182 .71231 m .63836 .7085 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.65356 .73897 m .64182 .71231 L .64152 .71485 L .707 .577 .707 r
F
.64804 .61334 m .65152 .55616 L .64413 .55367 L p F P
0 g
s
.64804 .61334 m .64413 .55367 L .64482 .59189 L .707 .577 .707 r
F
.65152 .55616 m .64804 .61334 L .65437 .61458 L p F P
0 g
s
.65437 .61458 m .66917 .61747 L p .6562 .57239 L .707 .577 .707 r
F P
0 g
s
.6562 .57239 m .65152 .55616 L .65437 .61458 L .707 .577 .707 r
F
.34792 .76114 m .34832 .79791 L .3554 .78871 L p F P
0 g
s
.3554 .78871 m .355 .75194 L .34792 .76114 L p .707 .577 .707 r
F P
0 g
s
.33518 .83058 m .33738 .84673 L .35318 .83038 L p .707 .577 .707 r
F P
0 g
s
.35318 .83038 m .35098 .81423 L .33518 .83058 L p .707 .577 .707 r
F P
0 g
s
.15557 .64676 m .15209 .70394 L .15513 .70793 L p .707 .577 .707 r
F P
0 g
s
.17115 .84218 m .17335 .85833 L .19466 .86891 L p .707 .577 .707 r
F P
0 g
s
.15441 .79605 m .15401 .75927 L .15111 .74998 L p .707 .577 .707 r
F P
0 g
s
.35916 .66049 m .35567 .71767 L .35264 .71368 L p .707 .577 .707 r
F P
0 g
s
.35264 .71368 m .35612 .65651 L .35916 .66049 L p .707 .577 .707 r
F P
0 g
s
.36331 .78835 m .36843 .28321 L .36433 .27217 L p .707 .577 .707 r
F P
0 g
s
.36843 .28321 m .36331 .78835 L .38109 .79867 L p .707 .577 .707 r
F P
0 g
s
.17335 .85833 m .17115 .84218 L .15815 .82786 L p .707 .577 .707 r
F P
0 g
s
.35098 .81423 m .35318 .83038 L .35969 .81303 L p .707 .577 .707 r
F P
0 g
s
.35969 .81303 m .35749 .79688 L .35098 .81423 L p .707 .577 .707 r
F P
0 g
s
.15111 .74998 m .15151 .78675 L .15441 .79605 L p .707 .577 .707 r
F P
0 g
s
.15209 .70394 m .15557 .64676 L .1625 .64345 L p .707 .577 .707 r
F P
0 g
s
.15815 .82786 m .16035 .84401 L .17335 .85833 L p .707 .577 .707 r
F P
0 g
s
.355 .75194 m .3554 .78871 L .3525 .77942 L p .707 .577 .707 r
F P
0 g
s
.3525 .77942 m .3521 .74264 L .355 .75194 L p .707 .577 .707 r
F P
0 g
s
.1625 .64345 m .15902 .70063 L .15209 .70394 L p .707 .577 .707 r
F P
0 g
s
.16035 .84401 m .15815 .82786 L .15474 .81121 L p .707 .577 .707 r
F P
0 g
s
.15151 .78675 m .15111 .74998 L .15819 .74077 L p .707 .577 .707 r
F P
0 g
s
.35612 .65651 m .35264 .71368 L .33993 .70941 L p .707 .577 .707 r
F P
0 g
s
.33993 .70941 m .34342 .65223 L .35612 .65651 L p .707 .577 .707 r
F P
0 g
s
.35749 .79688 m .35969 .81303 L .35628 .79638 L p .707 .577 .707 r
F P
0 g
s
.35628 .79638 m .35408 .78023 L .35749 .79688 L p .707 .577 .707 r
F P
0 g
s
.15474 .81121 m .15694 .82736 L .16035 .84401 L p .707 .577 .707 r
F P
0 g
s
.15819 .74077 m .15859 .77755 L .15151 .78675 L p .707 .577 .707 r
F P
0 g
s
.15902 .70063 m .1625 .64345 L .17871 .64113 L p .707 .577 .707 r
F P
0 g
s
.36433 .27217 m .35922 .77732 L .36331 .78835 L p .707 .577 .707 r
F P
0 g
s
.35922 .77732 m .36433 .27217 L .37433 .2615 L p .707 .577 .707 r
F P
0 g
s
.3521 .74264 m .3525 .77942 L .3399 .77093 L p .707 .577 .707 r
F P
0 g
s
.3399 .77093 m .33951 .73416 L .3521 .74264 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17871 .64113 m .17523 .69831 L .15902 .70063 L p .707 .577 .707 r
F P
0 g
s
.15694 .82736 m .15474 .81121 L .16125 .79386 L p .707 .577 .707 r
F P
0 g
s
.15859 .77755 m .15819 .74077 L .17456 .73257 L p .707 .577 .707 r
F P
0 g
s
.34342 .65223 m .33993 .70941 L .31881 .70528 L p .707 .577 .707 r
F P
0 g
s
.31881 .70528 m .32229 .6481 L .34342 .65223 L p .707 .577 .707 r
F P
0 g
s
.35408 .78023 m .35628 .79638 L .34328 .78207 L p .707 .577 .707 r
F P
0 g
s
.34328 .78207 m .34108 .76592 L .35408 .78023 L p .707 .577 .707 r
F P
0 g
s
.16125 .79386 m .16345 .81002 L .15694 .82736 L p .707 .577 .707 r
F P
0 g
s
.17456 .73257 m .17495 .76935 L .15859 .77755 L p .707 .577 .707 r
F P
0 g
s
.17523 .69831 m .17871 .64113 L .20262 .64003 L p .707 .577 .707 r
F P
0 g
s
.33951 .73416 m .3399 .77093 L .31884 .76409 L p .707 .577 .707 r
F P
0 g
s
.31884 .76409 m .31866 .74723 L p .33951 .73416 L .707 .577 .707 r
F P
0 g
s
.31845 .72732 m .31884 .76409 L .29138 .75957 L p .707 .577 .707 r
F P
0 g
s
.31976 .75533 m .32196 .77148 L .30212 .76729 L p .707 .577 .707 r
F P
0 g
s
.30212 .76729 m .29442 .76567 L p .30804 .76011 L .707 .577 .707 r
F P
0 g
s
.30804 .76011 m .31976 .75533 L .30212 .76729 L .707 .577 .707 r
F
.31866 .74723 m .31845 .72732 L .33156 .73158 L p F P
0 g
s
.33156 .73158 m .33951 .73416 L p .31866 .74723 L .707 .577 .707 r
F P
0 g
s
.20262 .64003 m .19914 .69721 L .17523 .69831 L p .707 .577 .707 r
F P
0 g
s
.16345 .81002 m .16125 .79386 L .17705 .77751 L p .707 .577 .707 r
F P
0 g
s
.17495 .76935 m .17456 .73257 L .1986 .72616 L p .707 .577 .707 r
F P
0 g
s
.32229 .6481 m .31881 .70528 L .29132 .70169 L p .707 .577 .707 r
F P
0 g
s
.29132 .70169 m .29481 .64451 L .32229 .6481 L p .707 .577 .707 r
F P
0 g
s
.34108 .76592 m .34328 .78207 L .32196 .77148 L p .707 .577 .707 r
F P
0 g
s
.32196 .77148 m .31976 .75533 L .34108 .76592 L p .707 .577 .707 r
F P
0 g
s
.36921 .76665 m .37433 .2615 L .39743 .25224 L p .707 .577 .707 r
F P
0 g
s
.37433 .2615 m .36921 .76665 L .35922 .77732 L p .707 .577 .707 r
F P
0 g
s
.7278 .62377 m .73128 .56659 L .70013 .56389 L p .707 .577 .707 r
F P
0 g
s
.73128 .56659 m .7278 .62377 L .75956 .62531 L p .707 .577 .707 r
F P
0 g
s
.75956 .62531 m .76305 .56813 L .73128 .56659 L p .707 .577 .707 r
F P
0 g
s
.19914 .69721 m .20262 .64003 L .23189 .64027 L p .707 .577 .707 r
F P
0 g
s
.17705 .77751 m .17925 .79366 L .16345 .81002 L p .707 .577 .707 r
F P
0 g
s
.76305 .56813 m .75956 .62531 L .78883 .62554 L p .707 .577 .707 r
F P
0 g
s
.78883 .62554 m .79232 .56836 L .76305 .56813 L p .707 .577 .707 r
F P
0 g
s
.1986 .72616 m .199 .76294 L .17495 .76935 L p .707 .577 .707 r
F P
0 g
s
.29138 .75957 m .29119 .74202 L p .31845 .72732 L .707 .577 .707 r
F P
0 g
s
.29099 .72279 m .29138 .75957 L .26021 .7578 L p .707 .577 .707 r
F P
0 g
s
.29222 .74952 m .29442 .76567 L .26926 .76528 L p .707 .577 .707 r
F P
0 g
s
.26926 .76528 m .26333 .76519 L p .27565 .75851 L .707 .577 .707 r
F P
0 g
s
.27565 .75851 m .29222 .74952 L .26926 .76528 L .707 .577 .707 r
F
.29119 .74202 m .29099 .72279 L .30685 .72541 L p F P
0 g
s
.30685 .72541 m .31845 .72732 L p .29119 .74202 L .707 .577 .707 r
F P
0 g
s
.69665 .62107 m .70013 .56389 L .67265 .56029 L p .707 .577 .707 r
F P
0 g
s
.70013 .56389 m .69665 .62107 L .7278 .62377 L p .707 .577 .707 r
F P
0 g
s
.23189 .64027 m .22841 .69744 L .19914 .69721 L p .707 .577 .707 r
F P
0 g
s
.29481 .64451 m .29132 .70169 L .26018 .69899 L p .707 .577 .707 r
F P
0 g
s
.26018 .69899 m .26366 .64181 L .29481 .64451 L p .707 .577 .707 r
F P
0 g
s
.7269 .68698 m .72651 .6502 L .69534 .64843 L p .707 .577 .707 r
F P
0 g
s
.72651 .6502 m .7269 .68698 L .75874 .68582 L p .707 .577 .707 r
F P
0 g
s
.75874 .68582 m .75834 .64904 L .72651 .6502 L p .707 .577 .707 r
F P
0 g
s
.17925 .79366 m .17705 .77751 L .20059 .76376 L p .707 .577 .707 r
F P
0 g
s
.22841 .69744 m .23189 .64027 L .26366 .64181 L p .707 .577 .707 r
F P
0 g
s
.67265 .56029 m .66917 .61747 L .69665 .62107 L p .707 .577 .707 r
F P
0 g
s
.75834 .64904 m .75874 .68582 L .78812 .68184 L p .707 .577 .707 r
F P
0 g
s
.78812 .68184 m .78772 .64506 L .75834 .64904 L p .707 .577 .707 r
F P
0 g
s
.199 .76294 m .1986 .72616 L .22798 .72219 L p .707 .577 .707 r
F P
0 g
s
.79232 .56836 m .78883 .62554 L .81275 .62445 L p .707 .577 .707 r
F P
0 g
s
.81275 .62445 m .81623 .56727 L .79232 .56836 L p .707 .577 .707 r
F P
0 g
s
.26366 .64181 m .26018 .69899 L .22841 .69744 L p .707 .577 .707 r
F P
0 g
s
.29442 .76567 m .29222 .74952 L .31976 .75533 L p .707 .577 .707 r
F P
0 g
s
.69573 .68521 m .69534 .64843 L .66788 .64391 L p .707 .577 .707 r
F P
0 g
s
.69534 .64843 m .69573 .68521 L .7269 .68698 L p .707 .577 .707 r
F P
0 g
s
.6303 .25824 m .62519 .76338 L .59546 .75479 L p .707 .577 .707 r
F P
0 g
s
.59546 .75479 m .60057 .24965 L .6303 .25824 L p .707 .577 .707 r
F P
0 g
s
.22838 .75896 m .22822 .74409 L p .25982 .72102 L .707 .577 .707 r
F P
0 g
s
.22822 .74409 m .22798 .72219 L .24209 .72167 L p .707 .577 .707 r
F P
0 g
s
.24209 .72167 m .25982 .72102 L p .22822 .74409 L .707 .577 .707 r
F P
0 g
s
.22798 .72219 m .22838 .75896 L .199 .76294 L p .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .20059 .76376 L .22015 .75713 L p .707 .577 .707 r
F P
0 g
s
.22015 .75713 m .22956 .75395 L p .21096 .77198 L .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .22015 .75713 L .21096 .77198 L .707 .577 .707 r
F
.25982 .72102 m .26021 .7578 L .22838 .75896 L p F P
0 g
s
.23176 .7701 m .22956 .75395 L .25202 .75046 L p .707 .577 .707 r
F P
0 g
s
.26021 .7578 m .26003 .74093 L p .29099 .72279 L .707 .577 .707 r
F P
0 g
s
.25202 .75046 m .26113 .74904 L p .24118 .76335 L .707 .577 .707 r
F P
0 g
s
.23176 .7701 m .25202 .75046 L .24118 .76335 L .707 .577 .707 r
F
.26003 .74093 m .25982 .72102 L .27601 .72194 L p F P
0 g
s
.27601 .72194 m .29099 .72279 L p .26003 .74093 L .707 .577 .707 r
F P
0 g
s
.66917 .61747 m .67265 .56029 L .65152 .55616 L p .707 .577 .707 r
F P
0 g
s
.20059 .76376 m .20279 .77991 L .17925 .79366 L p .707 .577 .707 r
F P
0 g
s
.78772 .64506 m .78812 .68184 L .81217 .67543 L p .707 .577 .707 r
F P
0 g
s
.81217 .67543 m .81177 .63866 L .78772 .64506 L p .707 .577 .707 r
F P
0 g
s
.66788 .64391 m .66827 .68069 L .69573 .68521 L p .707 .577 .707 r
F P
0 g
s
.26333 .76519 m .26113 .74904 L .29222 .74952 L p .707 .577 .707 r
F P
0 g
s
.66827 .68069 m .66788 .64391 L .64682 .63707 L p .707 .577 .707 r
F P
0 g
s
.39743 .25224 m .39233 .75627 L p .36921 .76665 L .707 .577 .707 r
F P
0 g
s
.39232 .75739 m .39743 .25224 L .43138 .24529 L p .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .39232 .75739 L p .39708 .69499 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .41038 .52063 L .41813 .6089 L .707 .577 .707 r
F
.42158 .64821 m .44511 .64502 L p .41875 .61599 L F P
0 g
s
.42311 .58855 m .44583 .58873 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.42811 .5681 m .43138 .24529 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.43639 .56773 m .43109 .55592 L .42811 .5681 L .707 .577 .707 r
F
.43639 .56773 m .42811 .5681 L .42311 .58855 L F
.43138 .24529 m .47286 .24134 L p .44301 .56744 L F P
0 g
s
.43138 .24529 m .42811 .5681 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.41038 .52063 m .43138 .24529 L .41813 .6089 L .707 .577 .707 r
F
.47286 .24134 m .46957 .56626 L p .44713 .56725 L F P
0 g
s
.44301 .56744 m .44441 .55222 L .44713 .56725 L .707 .577 .707 r
F
.44441 .55222 m .47286 .24134 L .44713 .56725 L F
.44713 .56725 m .44583 .58873 L .45098 .58849 L p F P
0 g
s
.44583 .58873 m .44713 .56725 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.46957 .56626 m .46774 .74648 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.45301 .61856 m .44471 .60825 L .4509 .64348 L .707 .577 .707 r
F
.45739 .5668 m .46957 .56626 L .4519 .63173 L F
.45409 .60575 m .44471 .60825 L p .45301 .61856 L F P
0 g
s
.44301 .56744 m .45739 .5668 L .4519 .63173 L .707 .577 .707 r
F
.44931 .53155 m .44713 .56725 L p .45785 .57691 L F P
0 g
s
.46837 .68446 m .46908 .61467 L p .47111 .71246 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47122 .40351 L p .47115 .60696 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47115 .60696 L .47111 .71246 L .707 .577 .707 r
F
.48764 .54547 m .47122 .40351 L .5178 .24076 L F
.47111 .71246 m .47115 .60696 L .48764 .54547 L F
.47115 .60696 m .47122 .40351 L .48764 .54547 L F
.46774 .74648 m .46837 .68446 L p .47111 .71246 L F P
0 g
s
.46774 .74648 m .44197 .74894 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.5178 .24076 m .51269 .74591 L .46774 .74648 L p .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .47238 .67441 L .44946 .6878 L p .707 .577 .707 r
F P
0 g
s
.44946 .6878 m .44885 .68816 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .44946 .6878 L .44935 .68821 L .707 .577 .707 r
F
.45105 .70431 m .47458 .69056 L p .44935 .68821 L F P
0 g
s
.44885 .68816 m .44902 .68945 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.44902 .68945 m .45105 .70431 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .45492 .54695 L .45785 .57691 L .707 .577 .707 r
F
.45492 .54695 m .44931 .53155 L .45785 .57691 L F
.47122 .40351 m .47286 .24134 L .47981 .24125 L p F P
0 g
s
.47981 .24125 m .5178 .24076 L p .47122 .40351 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .46876 .60184 L .4606 .60401 L p .707 .577 .707 r
F P
0 g
s
.4606 .60401 m .45409 .60575 L p .45984 .6183 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .4606 .60401 L .45984 .6183 L .707 .577 .707 r
F
.46916 .63862 m .45409 .60575 L .45301 .61856 L F
.44471 .60825 m .44511 .64502 L .4509 .64348 L p F P
0 g
s
.40855 .64809 m .42135 .66486 L .42627 .75044 L .707 .577 .707 r
F
.44511 .64502 m .44471 .60825 L .41839 .61181 L p F P
0 g
s
.44511 .64502 m .41839 .61181 L .41875 .61599 L .707 .577 .707 r
F
.42811 .5681 m .42671 .70658 L p .41813 .6089 L F P
0 g
s
.42671 .70658 m .42627 .75044 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .44301 .56744 L .4519 .63173 L .707 .577 .707 r
F
.44197 .74894 m .42627 .75044 L p .4519 .63173 L F P
0 g
s
.42627 .75044 m .42811 .5681 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.45105 .70431 m .45095 .70363 L p .41987 .69797 L .707 .577 .707 r
F P
0 g
s
.45095 .70363 m .44885 .68816 L .44114 .69077 L p .707 .577 .707 r
F P
0 g
s
.44114 .69077 m .41987 .69797 L p .45095 .70363 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .40855 .64809 L .42627 .75044 L .707 .577 .707 r
F
.40855 .64809 m .41813 .6089 L .42135 .66486 L F
.41839 .61181 m .41533 .61222 L p .41875 .61599 L F P
0 g
s
.4509 .64348 m .46916 .63862 L p .45301 .61856 L .707 .577 .707 r
F P
0 g
s
.45098 .58849 m .46974 .58763 L p .44713 .56725 L .707 .577 .707 r
F P
0 g
s
.44931 .53155 m .42004 .53131 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.44713 .56725 m .44931 .53155 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.41533 .61222 m .41573 .649 L .42158 .64821 L p .707 .577 .707 r
F P
0 g
s
.41875 .61599 m .41533 .61222 L .42158 .64821 L .707 .577 .707 r
F
.42004 .53131 m .41655 .58849 L .42311 .58855 L p F P
0 g
s
.43109 .55592 m .42004 .53131 L .42311 .58855 L .707 .577 .707 r
F
.38827 .52977 m .38479 .58695 L .40704 .58803 L p F P
0 g
s
.40704 .58803 m .41655 .58849 L p .40846 .5717 L .707 .577 .707 r
F P
0 g
s
.40846 .5717 m .38827 .52977 L .40704 .58803 L .707 .577 .707 r
F
.39233 .75627 m .39232 .75739 L .39223 .75742 L p F P
0 g
s
.39223 .75742 m .36921 .76665 L p .39233 .75627 L .707 .577 .707 r
F P
0 g
s
.81623 .56727 m .81275 .62445 L .82896 .62213 L p .707 .577 .707 r
F P
0 g
s
.82896 .62213 m .83244 .56495 L .81623 .56727 L p .707 .577 .707 r
F P
0 g
s
.22956 .75395 m .23176 .7701 L .20279 .77991 L p .707 .577 .707 r
F P
0 g
s
.26113 .74904 m .26333 .76519 L .23176 .7701 L p .707 .577 .707 r
F P
0 g
s
.64682 .63707 m .64722 .67385 L .66827 .68069 L p .707 .577 .707 r
F P
0 g
s
.81177 .63866 m .81217 .67543 L .82853 .66723 L p .707 .577 .707 r
F P
0 g
s
.82853 .66723 m .82814 .63045 L .81177 .63866 L p .707 .577 .707 r
F P
0 g
s
.73351 .75585 m .73131 .7397 L .70023 .73922 L p .707 .577 .707 r
F P
0 g
s
.73131 .7397 m .73351 .75585 L .76508 .75094 L p .707 .577 .707 r
F P
0 g
s
.76508 .75094 m .76288 .73479 L .73131 .7397 L p .707 .577 .707 r
F P
0 g
s
.76288 .73479 m .76508 .75094 L .79406 .74113 L p .707 .577 .707 r
F P
0 g
s
.79406 .74113 m .79186 .72498 L .76288 .73479 L p .707 .577 .707 r
F P
0 g
s
.60057 .24965 m .59546 .75479 L .55669 .74877 L p .707 .577 .707 r
F P
0 g
s
.55669 .74877 m .56181 .24363 L .60057 .24965 L p .707 .577 .707 r
F P
0 g
s
.70243 .75537 m .70023 .73922 L .67268 .7334 L p .707 .577 .707 r
F P
0 g
s
.70023 .73922 m .70243 .75537 L .73351 .75585 L p .707 .577 .707 r
F P
0 g
s
.79186 .72498 m .79406 .74113 L .81759 .72738 L p .707 .577 .707 r
F P
0 g
s
.81759 .72738 m .81539 .71122 L .79186 .72498 L p .707 .577 .707 r
F P
0 g
s
.83244 .56495 m .82896 .62213 L .83589 .61881 L p .707 .577 .707 r
F P
0 g
s
.83589 .61881 m .83937 .56163 L .83244 .56495 L p .707 .577 .707 r
F P
0 g
s
.67268 .7334 m .67488 .74955 L .70243 .75537 L p .707 .577 .707 r
F P
0 g
s
.67488 .74955 m .67268 .7334 L .65136 .72282 L p .707 .577 .707 r
F P
0 g
s
.82814 .63045 m .82853 .66723 L .83561 .65803 L p .707 .577 .707 r
F P
0 g
s
.83561 .65803 m .83521 .62125 L .82814 .63045 L p .707 .577 .707 r
F P
0 g
s
.56181 .24363 m .55669 .74877 L .51269 .74591 L p .707 .577 .707 r
F P
0 g
s
.51269 .74591 m .5178 .24076 L .56181 .24363 L p .707 .577 .707 r
F P
0 g
s
.81539 .71122 m .81759 .72738 L .83339 .71102 L p .707 .577 .707 r
F P
0 g
s
.83339 .71102 m .83119 .69487 L .81539 .71122 L p .707 .577 .707 r
F P
0 g
s
.65136 .72282 m .65356 .73897 L .67488 .74955 L p .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83521 .62125 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83271 .64873 m .83242 .62188 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83242 .62188 m .83231 .61195 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83271 .64873 L .82011 .64025 L p .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .83231 .61195 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.82011 .64025 m .81985 .61546 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81985 .61546 m .81972 .60347 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .82011 .64025 L .79906 .63341 L p .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .81972 .60347 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79906 .63341 m .7988 .60995 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.7988 .60995 m .79866 .59663 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .79906 .63341 L .7716 .62888 L p .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .79866 .59663 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7716 .62888 m .77135 .60588 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.77135 .60588 m .7712 .59211 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .7716 .62888 L .74043 .62711 L p .707 .577 .707 r
F P
0 g
s
.74003 .59034 m .7712 .59211 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74043 .62711 m .74017 .60366 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74017 .60366 m .74003 .59034 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.7082 .5915 m .74003 .59034 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70859 .62828 m .70833 .60349 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70833 .60349 m .7082 .5915 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .7082 .5915 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67921 .63225 m .67892 .6054 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67892 .6054 m .67882 .59548 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.65516 .63866 m .65477 .60188 L .67882 .59548 L p .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .67921 .63225 L .65516 .63866 L p .707 .577 .707 r
F P
0 g
s
.68284 .54117 m .67935 .59835 L .67695 .59846 L p .707 .577 .707 r
F P
0 g
s
.67695 .59846 m .65544 .59944 L p .66903 .57054 L .707 .577 .707 r
F P
0 g
s
.66903 .57054 m .68284 .54117 L .67695 .59846 L .707 .577 .707 r
F
.7082 .5915 m .70859 .62828 L .67921 .63225 L p F P
0 g
s
.71211 .5414 m .70863 .59858 L .70605 .59856 L p .707 .577 .707 r
F P
0 g
s
.70605 .59856 m .67935 .59835 L p .6941 .5727 L .707 .577 .707 r
F P
0 g
s
.6941 .5727 m .71211 .5414 L .70605 .59856 L .707 .577 .707 r
F
.74003 .59034 m .74043 .62711 L .70859 .62828 L p F P
0 g
s
.74387 .54294 m .74039 .60012 L .73818 .60002 L p .707 .577 .707 r
F P
0 g
s
.73818 .60002 m .70863 .59858 L p .72407 .57421 L .707 .577 .707 r
F P
0 g
s
.72407 .57421 m .74387 .54294 L .73818 .60002 L .707 .577 .707 r
F
.77502 .54564 m .77154 .60282 L .7697 .60266 L p F P
0 g
s
.7697 .60266 m .74039 .60012 L p .75587 .57577 L .707 .577 .707 r
F P
0 g
s
.75587 .57577 m .77502 .54564 L .7697 .60266 L .707 .577 .707 r
F
.8025 .54924 m .79902 .60642 L .79736 .6062 L p F P
0 g
s
.79736 .6062 m .77154 .60282 L p .78623 .57739 L .707 .577 .707 r
F P
0 g
s
.78623 .57739 m .8025 .54924 L .79736 .6062 L .707 .577 .707 r
F
.82363 .55337 m .82015 .61055 L .81875 .61028 L p F P
0 g
s
.81875 .61028 m .79902 .60642 L p .81201 .57841 L .707 .577 .707 r
F P
0 g
s
.81201 .57841 m .82363 .55337 L .81875 .61028 L .707 .577 .707 r
F
.83633 .55764 m .83285 .61482 L .83208 .61456 L p F P
0 g
s
.83208 .61456 m .82015 .61055 L p .83032 .57729 L .707 .577 .707 r
F P
0 g
s
.83032 .57729 m .83633 .55764 L .83208 .61456 L .707 .577 .707 r
F
.83937 .56163 m .83589 .61881 L .83285 .61482 L p F P
0 g
s
.83285 .61482 m .83633 .55764 L .83937 .56163 L p .707 .577 .707 r
F P
0 g
s
.83119 .69487 m .83339 .71102 L .83991 .69367 L p .707 .577 .707 r
F P
0 g
s
.83991 .69367 m .83771 .67752 L .83119 .69487 L p .707 .577 .707 r
F P
0 g
s
.83521 .62125 m .83561 .65803 L .83271 .64873 L p .707 .577 .707 r
F P
0 g
s
.6323 .60508 m .63578 .5479 L .64271 .54458 L p .707 .577 .707 r
F P
0 g
s
.64271 .54458 m .63923 .60176 L .6323 .60508 L p .707 .577 .707 r
F P
0 g
s
.63172 .65607 m .63133 .61929 L .6384 .61009 L p .707 .577 .707 r
F P
0 g
s
.64056 .72466 m .63836 .7085 L .63495 .69186 L p .707 .577 .707 r
F P
0 g
s
.83771 .67752 m .83991 .69367 L .8365 .67703 L p .707 .577 .707 r
F P
0 g
s
.8365 .67703 m .8343 .66088 L .83771 .67752 L p .707 .577 .707 r
F P
0 g
s
.6384 .61009 m .6388 .64686 L .63172 .65607 L p .707 .577 .707 r
F P
0 g
s
.82015 .61055 m .82363 .55337 L .83633 .55764 L p .707 .577 .707 r
F P
0 g
s
.63495 .69186 m .63715 .70801 L .64056 .72466 L p .707 .577 .707 r
F P
0 g
s
.38479 .58695 m .38827 .52977 L .35713 .52707 L p .707 .577 .707 r
F P
0 g
s
.41655 .58849 m .42004 .53131 L .38827 .52977 L p .707 .577 .707 r
F P
0 g
s
.63923 .60176 m .64271 .54458 L .65892 .54226 L p .707 .577 .707 r
F P
0 g
s
.35364 .58425 m .35713 .52707 L .32964 .52348 L p .707 .577 .707 r
F P
0 g
s
.35713 .52707 m .35364 .58425 L .38479 .58695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38389 .65016 m .3835 .61339 L .35233 .61162 L p .707 .577 .707 r
F P
0 g
s
.3835 .61339 m .38389 .65016 L .41573 .649 L p .707 .577 .707 r
F P
0 g
s
.41573 .649 m .41533 .61222 L .3835 .61339 L p .707 .577 .707 r
F P
0 g
s
.65892 .54226 m .65544 .59944 L .63923 .60176 L p .707 .577 .707 r
F P
0 g
s
.63715 .70801 m .63495 .69186 L .64146 .67451 L p .707 .577 .707 r
F P
0 g
s
.6388 .64686 m .6384 .61009 L .65477 .60188 L p .707 .577 .707 r
F P
0 g
s
.32964 .52348 m .32616 .58066 L .35364 .58425 L p .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .47322 .53045 L .44931 .53155 L p .707 .577 .707 r
F P
0 g
s
.35272 .64839 m .35233 .61162 L .32487 .60709 L p .707 .577 .707 r
F P
0 g
s
.35233 .61162 m .35272 .64839 L .38389 .65016 L p .707 .577 .707 r
F P
0 g
s
.8343 .66088 m .8365 .67703 L .8235 .66271 L p .707 .577 .707 r
F P
0 g
s
.8235 .66271 m .8213 .64656 L .8343 .66088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32616 .58066 m .32964 .52348 L .30851 .51934 L p .707 .577 .707 r
F P
0 g
s
.64146 .67451 m .64366 .69066 L .63715 .70801 L p .707 .577 .707 r
F P
0 g
s
.65477 .60188 m .65516 .63866 L .6388 .64686 L p .707 .577 .707 r
F P
0 g
s
.79902 .60642 m .8025 .54924 L .82363 .55337 L p .707 .577 .707 r
F P
0 g
s
.32487 .60709 m .32526 .64387 L .35272 .64839 L p .707 .577 .707 r
F P
0 g
s
.30851 .51934 m .30503 .57652 L .32616 .58066 L p .707 .577 .707 r
F P
0 g
s
.65544 .59944 m .65892 .54226 L .68284 .54117 L p .707 .577 .707 r
F P
0 g
s
.32526 .64387 m .32487 .60709 L .30381 .60026 L p .707 .577 .707 r
F P
0 g
s
.47322 .53045 m .46974 .58763 L .48595 .58531 L p .707 .577 .707 r
F P
0 g
s
.48595 .58531 m .48943 .52813 L .47322 .53045 L p .707 .577 .707 r
F P
0 g
s
.64366 .69066 m .64146 .67451 L .65726 .65816 L p .707 .577 .707 r
F P
0 g
s
.8213 .64656 m .8235 .66271 L .80218 .65213 L p .707 .577 .707 r
F P
0 g
s
.80218 .65213 m .79998 .63598 L .8213 .64656 L p .707 .577 .707 r
F P
0 g
s
.30381 .60026 m .30421 .63703 L .32526 .64387 L p .707 .577 .707 r
F P
0 g
s
.46876 .60184 m .46916 .63862 L .48552 .63041 L p .707 .577 .707 r
F P
0 g
s
.48552 .63041 m .48513 .59364 L .46876 .60184 L p .707 .577 .707 r
F P
0 g
s
.30503 .57652 m .30851 .51934 L .29581 .51507 L p .707 .577 .707 r
F P
0 g
s
.77154 .60282 m .77502 .54564 L .8025 .54924 L p .707 .577 .707 r
F P
0 g
s
.3905 .71903 m .3883 .70288 L .35722 .7024 L p .707 .577 .707 r
F P
0 g
s
.3883 .70288 m .3905 .71903 L .42207 .71413 L p .707 .577 .707 r
F P
0 g
s
.42207 .71413 m .41987 .69797 L .3883 .70288 L p .707 .577 .707 r
F P
0 g
s
.65726 .65816 m .65946 .67431 L .64366 .69066 L p .707 .577 .707 r
F P
0 g
s
.41987 .69797 m .42207 .71413 L .45105 .70431 L p .707 .577 .707 r
F P
0 g
s
.29581 .51507 m .29233 .57225 L .30503 .57652 L p .707 .577 .707 r
F P
0 g
s
.67935 .59835 m .68284 .54117 L .71211 .5414 L p .707 .577 .707 r
F P
0 g
s
.35942 .71855 m .35722 .7024 L .32967 .69659 L p .707 .577 .707 r
F P
0 g
s
.35722 .7024 m .35942 .71855 L .3905 .71903 L p .707 .577 .707 r
F P
0 g
s
.30421 .63703 m .30381 .60026 L .29122 .59177 L p .707 .577 .707 r
F P
0 g
s
.65946 .67431 m .65726 .65816 L .6808 .6444 L p .707 .577 .707 r
F P
0 g
s
.74039 .60012 m .74387 .54294 L .77502 .54564 L p .707 .577 .707 r
F P
0 g
s
.48943 .52813 m .48595 .58531 L .49288 .58199 L p .707 .577 .707 r
F P
0 g
s
.49288 .58199 m .49636 .52481 L .48943 .52813 L p .707 .577 .707 r
F P
0 g
s
.79998 .63598 m .80218 .65213 L .77463 .64631 L p .707 .577 .707 r
F P
0 g
s
.77463 .64631 m .77243 .63016 L .79998 .63598 L p .707 .577 .707 r
F P
0 g
s
.32967 .69659 m .33187 .71274 L .35942 .71855 L p .707 .577 .707 r
F P
0 g
s
.70863 .59858 m .71211 .5414 L .74387 .54294 L p .707 .577 .707 r
F P
0 g
s
.29122 .59177 m .29161 .62855 L .30421 .63703 L p .707 .577 .707 r
F P
0 g
s
.33187 .71274 m .32967 .69659 L .30835 .686 L p .707 .577 .707 r
F P
0 g
s
.6808 .6444 m .683 .66055 L .65946 .67431 L p .707 .577 .707 r
F P
0 g
s
.48513 .59364 m .48552 .63041 L .4926 .62121 L p .707 .577 .707 r
F P
0 g
s
.4926 .62121 m .49221 .58443 L .48513 .59364 L p .707 .577 .707 r
F P
0 g
s
.47238 .67441 m .47458 .69056 L .49038 .67421 L p .707 .577 .707 r
F P
0 g
s
.49038 .67421 m .48818 .65806 L .47238 .67441 L p .707 .577 .707 r
F P
0 g
s
.29233 .57225 m .29581 .51507 L .29277 .51108 L p .707 .577 .707 r
F P
0 g
s
.683 .66055 m .6808 .6444 L .70977 .63459 L p .707 .577 .707 r
F P
0 g
s
.77243 .63016 m .77463 .64631 L .74355 .64583 L p .707 .577 .707 r
F P
0 g
s
.74355 .64583 m .74135 .62968 L .77243 .63016 L p .707 .577 .707 r
F P
0 g
s
.30835 .686 m .31055 .70216 L .33187 .71274 L p .707 .577 .707 r
F P
0 g
s
.29277 .51108 m .28929 .56826 L .29233 .57225 L p .707 .577 .707 r
F P
0 g
s
.29161 .62855 m .29122 .59177 L .28832 .58247 L p .707 .577 .707 r
F P
0 g
s
.71197 .65074 m .70977 .63459 L .74135 .62968 L p .707 .577 .707 r
F P
0 g
s
.70977 .63459 m .71197 .65074 L .683 .66055 L p .707 .577 .707 r
F P
0 g
s
.74135 .62968 m .74355 .64583 L .71197 .65074 L p .707 .577 .707 r
F P
0 g
s
.31055 .70216 m .30835 .686 L .29535 .67169 L p .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .49221 .58443 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4897 .61191 m .48941 .58506 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.48941 .58506 m .4893 .57514 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .4897 .61191 L .4771 .60343 L p .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4893 .57514 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.4771 .60343 m .47684 .57865 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47684 .57865 m .47671 .56665 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4771 .60343 L .45605 .59659 L p .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .47671 .56665 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45605 .59659 m .45579 .57314 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45579 .57314 m .45565 .55981 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .45605 .59659 L .42859 .59207 L p .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .45565 .55981 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42859 .59207 m .42834 .56907 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42834 .56907 m .42819 .55529 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .42859 .59207 L .39741 .5903 L p .707 .577 .707 r
F P
0 g
s
.39702 .55352 m .42819 .55529 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39741 .5903 m .39716 .56684 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39716 .56684 m .39702 .55352 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.36519 .55468 m .39702 .55352 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36558 .59146 m .36532 .56668 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36532 .56668 m .36519 .55468 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .36519 .55468 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.3362 .59544 m .33591 .56859 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.33591 .56859 m .33581 .55866 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.31215 .60184 m .31176 .56507 L .33581 .55866 L p .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .3362 .59544 L .31215 .60184 L p .707 .577 .707 r
F P
0 g
s
.33983 .50435 m .33634 .56153 L .33394 .56164 L p .707 .577 .707 r
F P
0 g
s
.33394 .56164 m .31243 .56263 L p .32602 .53372 L .707 .577 .707 r
F P
0 g
s
.32602 .53372 m .33983 .50435 L .33394 .56164 L .707 .577 .707 r
F
.36519 .55468 m .36558 .59146 L .3362 .59544 L p F P
0 g
s
.3691 .50459 m .36561 .56176 L .36304 .56174 L p .707 .577 .707 r
F P
0 g
s
.36304 .56174 m .33634 .56153 L p .35109 .53589 L .707 .577 .707 r
F P
0 g
s
.35109 .53589 m .3691 .50459 L .36304 .56174 L .707 .577 .707 r
F
.39702 .55352 m .39741 .5903 L .36558 .59146 L p F P
0 g
s
.40086 .50613 m .39738 .56331 L .39517 .5632 L p .707 .577 .707 r
F P
0 g
s
.39517 .5632 m .36561 .56176 L p .38106 .53739 L .707 .577 .707 r
F P
0 g
s
.38106 .53739 m .40086 .50613 L .39517 .5632 L .707 .577 .707 r
F
.43201 .50883 m .42853 .56601 L .42668 .56585 L p F P
0 g
s
.42668 .56585 m .39738 .56331 L p .41286 .53895 L .707 .577 .707 r
F P
0 g
s
.41286 .53895 m .43201 .50883 L .42668 .56585 L .707 .577 .707 r
F
.45949 .51242 m .45601 .5696 L .45435 .56938 L p F P
0 g
s
.45435 .56938 m .42853 .56601 L p .44322 .54057 L .707 .577 .707 r
F P
0 g
s
.44322 .54057 m .45949 .51242 L .45435 .56938 L .707 .577 .707 r
F
.48062 .51655 m .47714 .57373 L .47574 .57346 L p F P
0 g
s
.47574 .57346 m .45601 .5696 L p .469 .5416 L .707 .577 .707 r
F P
0 g
s
.469 .5416 m .48062 .51655 L .47574 .57346 L .707 .577 .707 r
F
.49332 .52083 m .48984 .57801 L .48907 .57774 L p F P
0 g
s
.48907 .57774 m .47714 .57373 L p .48731 .54047 L .707 .577 .707 r
F P
0 g
s
.48731 .54047 m .49332 .52083 L .48907 .57774 L .707 .577 .707 r
F
.49636 .52481 m .49288 .58199 L .48984 .57801 L p F P
0 g
s
.48984 .57801 m .49332 .52083 L .49636 .52481 L p .707 .577 .707 r
F P
0 g
s
.28832 .58247 m .28871 .61925 L .29161 .62855 L p .707 .577 .707 r
F P
0 g
s
.48818 .65806 m .49038 .67421 L .4969 .65686 L p .707 .577 .707 r
F P
0 g
s
.4969 .65686 m .4947 .64071 L .48818 .65806 L p .707 .577 .707 r
F P
0 g
s
.49221 .58443 m .4926 .62121 L .4897 .61191 L p .707 .577 .707 r
F P
0 g
s
.29535 .67169 m .29755 .68784 L .31055 .70216 L p .707 .577 .707 r
F P
0 g
s
.28929 .56826 m .29277 .51108 L .2997 .50777 L p .707 .577 .707 r
F P
0 g
s
.2997 .50777 m .29622 .56495 L .28929 .56826 L p .707 .577 .707 r
F P
0 g
s
.28871 .61925 m .28832 .58247 L .29539 .57327 L p .707 .577 .707 r
F P
0 g
s
.29755 .68784 m .29535 .67169 L .29194 .65504 L p .707 .577 .707 r
F P
0 g
s
.4947 .64071 m .4969 .65686 L .49349 .64021 L p .707 .577 .707 r
F P
0 g
s
.49349 .64021 m .49129 .62406 L .4947 .64071 L p .707 .577 .707 r
F P
0 g
s
.29539 .57327 m .29579 .61005 L .28871 .61925 L p .707 .577 .707 r
F P
0 g
s
.47714 .57373 m .48062 .51655 L .49332 .52083 L p .707 .577 .707 r
F P
0 g
s
.29194 .65504 m .29414 .67119 L .29755 .68784 L p .707 .577 .707 r
F P
0 g
s
.29622 .56495 m .2997 .50777 L .31591 .50545 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31591 .50545 m .31243 .56263 L .29622 .56495 L p .707 .577 .707 r
F P
0 g
s
.29414 .67119 m .29194 .65504 L .29845 .63769 L p .707 .577 .707 r
F P
0 g
s
.29579 .61005 m .29539 .57327 L .31176 .56507 L p .707 .577 .707 r
F P
0 g
s
.49129 .62406 m .49349 .64021 L .48049 .62589 L p .707 .577 .707 r
F P
0 g
s
.48049 .62589 m .47829 .60974 L .49129 .62406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29845 .63769 m .30065 .65384 L .29414 .67119 L p .707 .577 .707 r
F P
0 g
s
.31176 .56507 m .31215 .60184 L .29579 .61005 L p .707 .577 .707 r
F P
0 g
s
.45601 .5696 m .45949 .51242 L .48062 .51655 L p .707 .577 .707 r
F P
0 g
s
.31243 .56263 m .31591 .50545 L .33983 .50435 L p .707 .577 .707 r
F P
0 g
s
.30065 .65384 m .29845 .63769 L .31425 .62134 L p .707 .577 .707 r
F P
0 g
s
.47829 .60974 m .48049 .62589 L .45917 .61531 L p .707 .577 .707 r
F P
0 g
s
.45917 .61531 m .45697 .59916 L .47829 .60974 L p .707 .577 .707 r
F P
0 g
s
.42853 .56601 m .43201 .50883 L .45949 .51242 L p .707 .577 .707 r
F P
0 g
s
.31425 .62134 m .31645 .63749 L .30065 .65384 L p .707 .577 .707 r
F P
0 g
s
.33634 .56153 m .33983 .50435 L .3691 .50459 L p .707 .577 .707 r
F P
0 g
s
.31645 .63749 m .31425 .62134 L .33779 .60758 L p .707 .577 .707 r
F P
0 g
s
.39738 .56331 m .40086 .50613 L .43201 .50883 L p .707 .577 .707 r
F P
0 g
s
.45697 .59916 m .45917 .61531 L .43162 .6095 L p .707 .577 .707 r
F P
0 g
s
.43162 .6095 m .42942 .59334 L .45697 .59916 L p .707 .577 .707 r
F P
0 g
s
.36561 .56176 m .3691 .50459 L .40086 .50613 L p .707 .577 .707 r
F P
0 g
s
.33779 .60758 m .33999 .62374 L .31645 .63749 L p .707 .577 .707 r
F P
0 g
s
.33999 .62374 m .33779 .60758 L .36676 .59777 L p .707 .577 .707 r
F P
0 g
s
.42942 .59334 m .43162 .6095 L .40054 .60902 L p .707 .577 .707 r
F P
0 g
s
.40054 .60902 m .39834 .59287 L .42942 .59334 L p .707 .577 .707 r
F P
0 g
s
.36896 .61393 m .36676 .59777 L .39834 .59287 L p .707 .577 .707 r
F P
0 g
s
.36676 .59777 m .36896 .61393 L .33999 .62374 L p .707 .577 .707 r
F P
0 g
s
.39834 .59287 m .40054 .60902 L .36896 .61393 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaP008Ao
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@00Ngoo001cOol50002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol0071oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00KWoo0`002EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000
K7oo001/Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001YOol006Yoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Mo
o`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00IGoo001XOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00goo
001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Hgoo
001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
3UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP0?FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Mo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0F
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00F7oo7P000eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000Hgoo001EOol300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000DFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH7000=FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH00008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001eYF00L005YFFUIJEP00FUH00003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol005=oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool@
001>Ool0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2@000eYF00<005YFFUH01EYF00<005YF
FUH00UYF2@00AGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH7000fOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<Goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00000_Ool0059oo`03001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002ioo`00DWoo00<005YF00001`000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0`000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00@005YFFUIJEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool005=oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00002000^Ool0059oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002moo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
0eYF3P0015YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DGoo
00@005YFFUH000=JEP03001JEUYF00=JEPH0009oo`05001JEUYF001JEP040002FUH00`00FUIJEP06
FUH00`00FUH000060004FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001AOol01000
FUIJEP000eYF00<005YF00000`0027oo1@001UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000IJ
EP00000005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH2000015YF001JEUYF7P001EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo
001BOol00`00FUH00003FUH30008Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20000
0eYF000000050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@0015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo001BOol01000FUH005YF0P000eYF20001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<0009JEP800003FUH005YF00AJEP03001JEUYF
00=JEP04001JEUYF0008FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH0
0P00;goo001BOol00`00FUH000020005FUH00`00FUH000020007FUH00`00FUIJEP02FUHA0004FUH0
1000FUIJEUYF0P0000EJEP00001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D00003FUH0000002moo`00DWoo0P000UYF00<005YF
FUH00eYF0P000UYF00<005YFFUH015YF40000UYF00<005YFFUH00UYF1@0015YF0P0000AJEP000000
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF00000000;goo001BOol20002FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
0P001UYF00<005YFFUH01UYF00@005YFFUH000UJEP80009JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
000_Ool0059oo`05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJ
EP06FUH01000FUIJEP002eYF0P0000IJEP00FUH005YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000_Ool0059oo`06
001JEUYFFUH005YF0P001UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000]J
EP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00OomJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02000_Ool0059oo`04001JEUYFFUH200000eYF
001JEP03FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004FUH01000FUIJEP002eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00OomJEP03FUH00`00FUIJEP02000_
Ool005=oo`04001JEUYF0002FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH60003FUH01000FUIJ
EP002eYF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80
0003FUH005YF00=JEP03001JEUYF00=JEPH000Qooa<0009JEP03001JEUYF00=JEP800003FUH00000
02moo`00E7oo0P000eYF10001eYF00<005YFFUH01UYF1P000eYF00@005YFFUH000]JEP08001JEP00
001JEP00FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF
00=JEP03001JEP0000<000Qoo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP02000_Ool005Aoo`03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH60003FUH01000
FUIJEP002EYF100015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF001JEP0000=JEP<000Yoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEPD0
0004FUH005YFFUH2000_Ool002ioob4000Eoo`04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH000020004FUH01000FUIJEP001UYF0`002EYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00FUH50007Ool30003FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH2000_Ool002aoo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP04001o
ogooOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP004UYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<000AJEPL000MJEP03
001JEUYF00AJEPd000IJEP04001JEUYFFUH6000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000P0009ooaP00003FUH0
05YF011JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001J
EP020005FUH00`00FUH000020008FUH00`00FUIJEP0?0002FUH40002FUH00`00FUIJEP02FUH5000_
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0005FUH00`00FUIJEP050003Ool00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP0?FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUH00000FUH00P001EYF0P000UYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YF00000P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH0
0eYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH03UYF00@005YFFUH0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP8000=JEP80
00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP04001JEP00000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF0P000UYF00<005YFFUH0
1EYF100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000EJEP00FUIJEP00
02moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000EJEP8000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009J
EP03001oogoo02eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP09001JEUYFFUH005YF001JEP0000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEP0002moo`00;7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH30007
FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0300000eYF0000000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH00007FUH0
0`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003Ool3000^
Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YF000010000UYF00<005YFFUH01UYF00@005YFFUIJEP<000Ioo`8002ioo`00:goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<0
05YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF0`001eYF00<005YFFUH01UYF0P000UYF
00@005YFFUH000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
0002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH6
0009Ool2000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH02@00FUIJEUYF001JEP00
FUH00005FUH50006FUH00`00FUIJEP04FUH20004FUH00`00FUH00008FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001P0000=oo`0000001`0015YF
00<005YFFUH01UYF00<005YFFUH010003goo0P00;Woo000[Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP00
1EYF00T005YFFUIJEP00FUH005YF00001EYF1@001UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<000AJEP03
001JEUYF00@000Iooa0001=oo`8002ioo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00@000EJEP04001JEUYFFUH3
00000eYF001JEP04FUH50006FUH00`00FUIJEP040006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP03FUH3000V
Ool00`00FUH0000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH20004FUH01000FUIJEUYF0`0000=JEP00
FUH01EYF0`001eYF0`000eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00P005YFFUH005YF001JEP0015YF00<005YFFUH00eYF00@005YFFUH002Eoo`03
001JEP0002ioo`00:goo00<005YF00000UYF7P0015YF00<005YFFUH00UYF0P000eYF1@000eYF0`00
00=JEP00FUH01EYF00@005YFFUIJEPH000MJEP03001JEUYF00<000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
008002=oo`800003FUH007oo02eoo`00:goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF20000UYF00<005YFFUH00UYF00@005YFFUIJEQ8000AJEP03001JEUYF
00IJEP<00003FUH0000000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000ROol01000FUH00000;goo
000[Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00P008Goo00<005YFFUH00P00;goo
000/Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001EYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF0080021oo`05001JEUYFFUH0
000`Ool002ioo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000OOol00`00FUIJEP02FUH00`00Oomoo`0^Ool0
039oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF009JEPH000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P002Goo0`004Goo0`000eYF00<007ooOol0;goo000iOol90004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo1@003goo00@005YFFUH0009JEP03
001oogoo031oo`00?Goo:00000Aoo`00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000Qoo`D000eoo`8000AJEP8003=oo`00=goo
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P002goo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH010001EYF00<005YFFUH00P002Goo1@002Woo0`00
1UYF00<007ooOol0<Woo000cOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEUYF0P0015YF00<005YFFUH00P002Woo0`001goo10000UYF00<005YFFUH00UYF0P00=Goo000`
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP040005Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH3000015YF001JEUYF0P003goo1@001UYF00<005YFFUH00P00=goo000^Ool200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20004Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF00<0
05YF00001@002goo10000UYF00<005YFFUH01UYF0`00>Goo000/Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000Woo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJ
EP03001JEUYF00=JEPd000IJEP03001JEUYF00EJEP8003]oo`00:goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00T005YFFUIJEP00Ool005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?Goo000[
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0U
0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00?goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP03FUH80003FUH00`00FUIJEP03
FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Woo000ZOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEUYF10001EYF00T005YF
FUIJEP00Ool005YF00001UYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF0180
04Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00T005YFFUIJEP00Ool005YF00001EYF10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
0P0015YF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF00<005Moo`00:Woo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH0
0`00FUIJEP0200000eYF001JEP02FUH01@00Ool005YF00000eYF0P001UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
00<005YF00002P00FWoo000ZOol01000FUIJEP000eYF00<005YF00000`000Woo0P001UYF00<005YF
FUH00UYF3P001eYF00@005YFFUIJEP8000=JEP06001oo`00FUH005YF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00000P00
0eYF0P000UYF1000Ggoo000ZOol01000FUIJEP000eYF0P0017oo0`001UYF1P003Woo10000eYF00<0
05YFFUH00UYF0P000UYF00@007oo001JEP80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003
FUH0000000AJEP04001JEP00001MOol002]oo`03001JEP00009JEP@00003Ool00000009JEP03001J
EWoo009JEP8000Qoo`<000eoo`@000AJEP04001JEP00FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH01000FUIJEUYF0P00Fgoo000[Ool00`00FUH000020003FUH20004FUH00`00Ool0
00020009Ool50008Ool50003FUH20003FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP02FUH3001IOol002]oo`05001JEP00FUH00002FUH00`00FUIJEP04
FUH90005Ool=0003FUH00`00FUIJEP04FUH2000015YF001JEUYF100015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0015YF00<005YFFUH00UYF00<005YFFUH00P00Egoo000[Ool20002FUH01000FUH0
000015YF0P0015YF00<005YFFUH00UYF2P000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
0000009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF009J
EP05001JEUYFFUH0001GOol002]oo`04001JEUYFFUH2000015YF001JEUYF0P001UYF00<005YFFUH0
1UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH20000
0goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00EWoo000[Ool01000FUIJEP000eYF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEPD0009JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002]oo`03
001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2
0003FUH30005FUH00`00FUIJEP02001FOol002]oo`03001JEP0000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Ool00004Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20006FUH30003FUH00`00FUIJEP02001FOol002ao
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009oo`03001oogoo00Aoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00<00003FUH005YF00EJEP03001JEUYF00800004FUH005YFFUH2001FOol002aoo`05001JEP00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003Ool20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH>0003FUH01000FUIJEUYF0P000UYF0P00EWoo000/Ool01@00
FUH00000Ool00`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P001Goo00<005YF00002goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01@003Woo100015YF0P0000=JEP000000EWoo000/Ool00`00FUH0
0005Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030006
Ool01000FUIJEP0047oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
0goo0`003Goo1P000UYF00<005YF00000P00EWoo000/Ool00`00FUH0000:Ool90004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP005Woo2@001UYF00<005YFFUH015YF3@002Goo
1@001goo1@001EYF0`0000=JEP00FUH00P00EWoo000/Ool2000DOolB000>Ool20002FUH00`00Oomo
o`0MOol>0007FUHJ0003FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00Oomoo`1DOol002ao
o`8003=oo`05001JEP00FUH0000VOol20002FUH200000eYF001JEP04FUH20003FUH00`00FUIJEP06
FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
001FOol002aoo`03001oogoo039oo`03001JEUYF008002Ioo`80009JEP80009JEP03001JEUYF0080
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Ioo`00;7oo00<007ooOol0<Goo00D005YFFUIJEP0002Moo`80009JEP04
001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH4001EOol002aoo`80035oo`03001JEUYF009JEP03001oogoo02Ioo`03001J
EP0000AJEP03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP@005Eoo`00;7oo00<005YF0000;Woo0`000eYF00<007ooOol0:7oo
0P000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH200000goo0000001EOol002eoo`03001JEP0002]oo`80009JEP04001J
EP00000[Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000goo0P00EGoo000]Ool01000FUIJEP00:7oo
0P0015YF0P00;Goo100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001Goo0P00EGoo000^Ool00`00FUH00002000TOol20006FUH00`00
Oomoo`0[Ool00`00FUH00002Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH000020007Ool00`00FUH0001EOol002moo`80009JEP8001ioo`@00003
FUH005YF00=JEP8002ioo`03001JEP0000Eoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPH000Yoo`03001JEP0005Eoo`00;goo00<005YF00000eYF0`005Woo1@001EYF00D0
05YFFUIJEP00031oo`03001JEP0000Yooa/000moo`800003FUH007oo05Aoo`00<7oo0P0015YF00<0
05YF00000`003Woo10000UYF00<005YFFUH01UYF0`00<Goo0P00=7oo00@005YF000005Ioo`00<Goo
00<005YFFUH00UYF00<005YFFUH00eYF3P001UYF00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo
00<005YFFUH00P00EWoo000bOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH3000fOol00`00Oomoo`0`Ool01@00FUIJEUYF0000Egoo000dOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002000iOol2000`Ool00`00FUIJ
EP02FUH00`00Oomoo`1EOol003Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF009JEPD003aoo`03
001JEP0002eoo`<000=JEP03001oogoo05Ioo`00>goo4P00@Woo00<005YF0000:goo00@005YFFUH0
009JEP03001oogoo05Moo`00Sgoo00@005YFFUH002Qoo`8000AJEP03001JEP0005Uoo`00Sgoo00<0
05YFFUH00`0097oo0P001UYF0P00FWoo002@Ool00`00FUH00002FUH2000OOol300000eYF001JEP05
FUH00`00Oomoo`1IOol0091oo`03001JEP0000AJEP<001Uoo`<000AJEP03001JEUYF009JEP8005ao
o`00TGoo0P001EYF00<005YF00000`003goo1P001eYF00<005YFFUH00P00GWoo002BOol00`00FUIJ
EP03FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3001POol009=oo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80069oo`00UGoo0P0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002GOol30006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH5001XOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@0
06eoo`00WWoo3P00LGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5906 .75944 m .59408 .70227 L .56293 .69957 L p .707 .577 .707 r
F P
0 g
s
.59408 .70227 m .5906 .75944 L .62236 .76099 L p .707 .577 .707 r
F P
0 g
s
.62236 .76099 m .62584 .70381 L .59408 .70227 L p .707 .577 .707 r
F P
0 g
s
.62584 .70381 m .62236 .76099 L .65163 .76122 L p .707 .577 .707 r
F P
0 g
s
.65163 .76122 m .65511 .70404 L .62584 .70381 L p .707 .577 .707 r
F P
0 g
s
.55945 .75674 m .56293 .69957 L .53545 .69597 L p .707 .577 .707 r
F P
0 g
s
.56293 .69957 m .55945 .75674 L .5906 .75944 L p .707 .577 .707 r
F P
0 g
s
.53545 .69597 m .53197 .75315 L .55945 .75674 L p .707 .577 .707 r
F P
0 g
s
.65511 .70404 m .65163 .76122 L .67554 .76013 L p .707 .577 .707 r
F P
0 g
s
.67554 .76013 m .67903 .70295 L .65511 .70404 L p .707 .577 .707 r
F P
0 g
s
.5897 .85448 m .58931 .8177 L .55813 .81594 L p .707 .577 .707 r
F P
0 g
s
.58931 .8177 m .5897 .85448 L .62153 .85332 L p .707 .577 .707 r
F P
0 g
s
.62153 .85332 m .62114 .81654 L .58931 .8177 L p .707 .577 .707 r
F P
0 g
s
.62114 .81654 m .62153 .85332 L .65091 .84934 L p .707 .577 .707 r
F P
0 g
s
.65091 .84934 m .65052 .81256 L .62114 .81654 L p .707 .577 .707 r
F P
0 g
s
.53197 .75315 m .53545 .69597 L .51432 .69184 L p .707 .577 .707 r
F P
0 g
s
.55853 .85271 m .55813 .81594 L .53068 .81141 L p .707 .577 .707 r
F P
0 g
s
.55813 .81594 m .55853 .85271 L .5897 .85448 L p .707 .577 .707 r
F P
0 g
s
.51432 .69184 m .51084 .74902 L .53197 .75315 L p .707 .577 .707 r
F P
0 g
s
.65052 .81256 m .65091 .84934 L .67496 .84293 L p .707 .577 .707 r
F P
0 g
s
.67496 .84293 m .67457 .80616 L .65052 .81256 L p .707 .577 .707 r
F P
0 g
s
.67903 .70295 m .67554 .76013 L .69176 .75781 L p .707 .577 .707 r
F P
0 g
s
.69176 .75781 m .69524 .70063 L .67903 .70295 L p .707 .577 .707 r
F P
0 g
s
.53068 .81141 m .53107 .84819 L .55853 .85271 L p .707 .577 .707 r
F P
0 g
s
.53107 .84819 m .53068 .81141 L .50962 .80457 L p .707 .577 .707 r
F P
0 g
s
.51084 .74902 m .51432 .69184 L .50162 .68757 L p .707 .577 .707 r
F P
0 g
s
.50162 .68757 m .49813 .74475 L .51084 .74902 L p .707 .577 .707 r
F P
0 g
s
.50962 .80457 m .51001 .84135 L .53107 .84819 L p .707 .577 .707 r
F P
0 g
s
.5963 .91202 m .5941 .89587 L .56302 .89539 L p .707 .577 .707 r
F P
0 g
s
.5941 .89587 m .5963 .91202 L .62788 .90711 L p .707 .577 .707 r
F P
0 g
s
.62788 .90711 m .62568 .89096 L .5941 .89587 L p .707 .577 .707 r
F P
0 g
s
.67457 .80616 m .67496 .84293 L .69133 .83473 L p .707 .577 .707 r
F P
0 g
s
.69133 .83473 m .69093 .79795 L .67457 .80616 L p .707 .577 .707 r
F P
0 g
s
.62568 .89096 m .62788 .90711 L .65685 .8973 L p .707 .577 .707 r
F P
0 g
s
.65685 .8973 m .65465 .88115 L .62568 .89096 L p .707 .577 .707 r
F P
0 g
s
.56522 .91154 m .56302 .89539 L .53547 .88957 L p .707 .577 .707 r
F P
0 g
s
.56302 .89539 m .56522 .91154 L .5963 .91202 L p .707 .577 .707 r
F P
0 g
s
.65465 .88115 m .65685 .8973 L .68039 .88355 L p .707 .577 .707 r
F P
0 g
s
.68039 .88355 m .67819 .86739 L .65465 .88115 L p .707 .577 .707 r
F P
0 g
s
.69524 .70063 m .69176 .75781 L .69868 .75449 L p .707 .577 .707 r
F P
0 g
s
.69868 .75449 m .70217 .69731 L .69524 .70063 L p .707 .577 .707 r
F P
0 g
s
.51001 .84135 m .50962 .80457 L .49702 .79609 L p .707 .577 .707 r
F P
0 g
s
.53547 .88957 m .53767 .90573 L .56522 .91154 L p .707 .577 .707 r
F P
0 g
s
.49813 .74475 m .50162 .68757 L .49858 .68358 L p .707 .577 .707 r
F P
0 g
s
.53767 .90573 m .53547 .88957 L .51416 .87899 L p .707 .577 .707 r
F P
0 g
s
.49702 .79609 m .49742 .83286 L .51001 .84135 L p .707 .577 .707 r
F P
0 g
s
.69093 .79795 m .69133 .83473 L .6984 .82553 L p .707 .577 .707 r
F P
0 g
s
.6984 .82553 m .69801 .78875 L .69093 .79795 L p .707 .577 .707 r
F P
0 g
s
.67819 .86739 m .68039 .88355 L .69619 .86719 L p .707 .577 .707 r
F P
0 g
s
.69619 .86719 m .69399 .85104 L .67819 .86739 L p .707 .577 .707 r
F P
0 g
s
.49858 .68358 m .4951 .74076 L .49813 .74475 L p .707 .577 .707 r
F P
0 g
s
.51416 .87899 m .51636 .89514 L .53767 .90573 L p .707 .577 .707 r
F P
0 g
s
.49742 .83286 m .49702 .79609 L .49412 .78679 L p .707 .577 .707 r
F P
0 g
s
.70217 .69731 m .69868 .75449 L .69565 .7505 L p .707 .577 .707 r
F P
0 g
s
.69565 .7505 m .69913 .69332 L .70217 .69731 L p .707 .577 .707 r
F P
0 g
s
.51636 .89514 m .51416 .87899 L .50116 .86468 L p .707 .577 .707 r
F P
0 g
s
.69399 .85104 m .69619 .86719 L .7027 .84985 L p .707 .577 .707 r
F P
0 g
s
.7027 .84985 m .7005 .83369 L .69399 .85104 L p .707 .577 .707 r
F P
0 g
s
.49412 .78679 m .49452 .82357 L .49742 .83286 L p .707 .577 .707 r
F P
0 g
s
.4951 .74076 m .49858 .68358 L .50551 .68026 L p .707 .577 .707 r
F P
0 g
s
.50116 .86468 m .50336 .88083 L .51636 .89514 L p .707 .577 .707 r
F P
0 g
s
.69801 .78875 m .6984 .82553 L .6955 .81623 L p .707 .577 .707 r
F P
0 g
s
.6955 .81623 m .69511 .77945 L .69801 .78875 L p .707 .577 .707 r
F P
0 g
s
.50551 .68026 m .50202 .73744 L .4951 .74076 L p .707 .577 .707 r
F P
0 g
s
.50336 .88083 m .50116 .86468 L .49774 .84803 L p .707 .577 .707 r
F P
0 g
s
.49359 .81614 m .49871 .31099 L .4547 .30813 L p .707 .577 .707 r
F P
0 g
s
.49452 .82357 m .49412 .78679 L .5012 .77759 L p .707 .577 .707 r
F P
0 g
s
.5012 .77759 m .50159 .81437 L .49452 .82357 L p .707 .577 .707 r
F P
0 g
s
.50202 .73744 m .50551 .68026 L .52172 .67794 L p .707 .577 .707 r
F P
0 g
s
.52172 .67794 m .51824 .73512 L .50202 .73744 L p .707 .577 .707 r
F P
0 g
s
.50159 .81437 m .5012 .77759 L .51756 .76938 L p .707 .577 .707 r
F P
0 g
s
.51756 .76938 m .51796 .80616 L .50159 .81437 L p .707 .577 .707 r
F P
0 g
s
.51824 .73512 m .52172 .67794 L .54563 .67685 L p .707 .577 .707 r
F P
0 g
s
.54563 .67685 m .54215 .73402 L .51824 .73512 L p .707 .577 .707 r
F P
0 g
s
.50646 .84683 m .50426 .83068 L .52006 .81433 L p .707 .577 .707 r
F P
0 g
s
.51796 .80616 m .51756 .76938 L .54161 .76298 L p .707 .577 .707 r
F P
0 g
s
.52006 .81433 m .52226 .83048 L .50646 .84683 L p .707 .577 .707 r
F P
0 g
s
.54161 .76298 m .54201 .79976 L .51796 .80616 L p .707 .577 .707 r
F P
0 g
s
.52226 .83048 m .52006 .81433 L .5436 .80057 L p .707 .577 .707 r
F P
0 g
s
.5436 .80057 m .5458 .81672 L .52226 .83048 L p .707 .577 .707 r
F P
0 g
s
.49871 .31099 m .49359 .81614 L .53854 .81556 L p .707 .577 .707 r
F P
0 g
s
.53854 .81556 m .54365 .31042 L .49871 .31099 L p .707 .577 .707 r
F P
0 g
s
.69913 .69332 m .69565 .7505 L .68294 .74623 L p .707 .577 .707 r
F P
0 g
s
.68294 .74623 m .68642 .68905 L .69913 .69332 L p .707 .577 .707 r
F P
0 g
s
.54215 .73402 m .54563 .67685 L .5749 .67708 L p .707 .577 .707 r
F P
0 g
s
.5749 .67708 m .57142 .73426 L .54215 .73402 L p .707 .577 .707 r
F P
0 g
s
.57142 .73426 m .5749 .67708 L .60667 .67862 L p .707 .577 .707 r
F P
0 g
s
.54201 .79976 m .54161 .76298 L .57099 .759 L p .707 .577 .707 r
F P
0 g
s
.60667 .67862 m .60318 .7358 L .57142 .73426 L p .707 .577 .707 r
F P
0 g
s
.57099 .759 m .57139 .79578 L .54201 .79976 L p .707 .577 .707 r
F P
0 g
s
.57139 .79578 m .57123 .78091 L p .60283 .75784 L .707 .577 .707 r
F P
0 g
s
.57123 .78091 m .57099 .759 L .5851 .75849 L p .707 .577 .707 r
F P
0 g
s
.5851 .75849 m .60283 .75784 L p .57123 .78091 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .5436 .80057 L .56316 .79395 L p .707 .577 .707 r
F P
0 g
s
.56316 .79395 m .57257 .79076 L p .55397 .80879 L .707 .577 .707 r
F P
0 g
s
.5458 .81672 m .56316 .79395 L .55397 .80879 L .707 .577 .707 r
F
.60283 .75784 m .60322 .79462 L .57139 .79578 L p F P
0 g
s
.57477 .80691 m .57257 .79076 L .59503 .78727 L p .707 .577 .707 r
F P
0 g
s
.60322 .79462 m .60304 .77775 L p .634 .75961 L .707 .577 .707 r
F P
0 g
s
.59503 .78727 m .60414 .78585 L p .58419 .80016 L .707 .577 .707 r
F P
0 g
s
.57477 .80691 m .59503 .78727 L .58419 .80016 L .707 .577 .707 r
F
.60304 .77775 m .60283 .75784 L .61902 .75876 L p F P
0 g
s
.61902 .75876 m .634 .75961 L p .60304 .77775 L .707 .577 .707 r
F P
0 g
s
.57257 .79076 m .57477 .80691 L .5458 .81672 L p .707 .577 .707 r
F P
0 g
s
.634 .75961 m .63439 .79638 L .60322 .79462 L p .707 .577 .707 r
F P
0 g
s
.60414 .78585 m .60634 .80201 L .57477 .80691 L p .707 .577 .707 r
F P
0 g
s
.54365 .31042 m .53854 .81556 L .58001 .81161 L p .707 .577 .707 r
F P
0 g
s
.58001 .81161 m .58513 .30646 L .54365 .31042 L p .707 .577 .707 r
F P
0 g
s
.7005 .83369 m .7027 .84985 L .69929 .8332 L p .707 .577 .707 r
F P
0 g
s
.69929 .8332 m .69709 .81705 L .7005 .83369 L p .707 .577 .707 r
F P
0 g
s
.24759 .72263 m .25107 .66545 L .21992 .66275 L p .707 .577 .707 r
F P
0 g
s
.25107 .66545 m .24759 .72263 L .27935 .72417 L p .707 .577 .707 r
F P
0 g
s
.27935 .72417 m .28283 .66699 L .25107 .66545 L p .707 .577 .707 r
F P
0 g
s
.44959 .81327 m .4547 .30813 L .41594 .30211 L p .707 .577 .707 r
F P
0 g
s
.4547 .30813 m .44959 .81327 L .49359 .81614 L p .707 .577 .707 r
F P
0 g
s
.49774 .84803 m .49994 .86418 L .50336 .88083 L p .707 .577 .707 r
F P
0 g
s
.28283 .66699 m .27935 .72417 L .30862 .72441 L p .707 .577 .707 r
F P
0 g
s
.30862 .72441 m .3121 .66723 L .28283 .66699 L p .707 .577 .707 r
F P
0 g
s
.21644 .71993 m .21992 .66275 L .19244 .65916 L p .707 .577 .707 r
F P
0 g
s
.21992 .66275 m .21644 .71993 L .24759 .72263 L p .707 .577 .707 r
F P
0 g
s
.69511 .77945 m .6955 .81623 L .68291 .80775 L p .707 .577 .707 r
F P
0 g
s
.68291 .80775 m .68251 .77097 L .69511 .77945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63781 .68132 m .63433 .7385 L .60318 .7358 L p .707 .577 .707 r
F P
0 g
s
.60318 .7358 m .60667 .67862 L .63781 .68132 L p .707 .577 .707 r
F P
0 g
s
.66146 .76413 m .66185 .80091 L .63439 .79638 L p .707 .577 .707 r
F P
0 g
s
.63439 .79638 m .6342 .77883 L p .66146 .76413 L .707 .577 .707 r
F P
0 g
s
.63523 .78633 m .63743 .80248 L .61227 .8021 L p .707 .577 .707 r
F P
0 g
s
.61227 .8021 m .60634 .80201 L p .61866 .79532 L .707 .577 .707 r
F P
0 g
s
.61866 .79532 m .63523 .78633 L .61227 .8021 L .707 .577 .707 r
F
.6342 .77883 m .634 .75961 L .64986 .76222 L p F P
0 g
s
.64986 .76222 m .66146 .76413 L p .6342 .77883 L .707 .577 .707 r
F P
0 g
s
.60634 .80201 m .60414 .78585 L .63523 .78633 L p .707 .577 .707 r
F P
0 g
s
.58513 .30646 m .58001 .81161 L .61396 .80466 L p .707 .577 .707 r
F P
0 g
s
.61396 .80466 m .61908 .29952 L .58513 .30646 L p .707 .577 .707 r
F P
0 g
s
.19244 .65916 m .18896 .71634 L .21644 .71993 L p .707 .577 .707 r
F P
0 g
s
.3121 .66723 m .30862 .72441 L .33253 .72331 L p .707 .577 .707 r
F P
0 g
s
.33253 .72331 m .33602 .66613 L .3121 .66723 L p .707 .577 .707 r
F P
0 g
s
.49994 .86418 m .49774 .84803 L .50426 .83068 L p .707 .577 .707 r
F P
0 g
s
.24669 .81766 m .2463 .78089 L .21513 .77912 L p .707 .577 .707 r
F P
0 g
s
.2463 .78089 m .24669 .81766 L .27852 .8165 L p .707 .577 .707 r
F P
0 g
s
.27852 .8165 m .27813 .77973 L .2463 .78089 L p .707 .577 .707 r
F P
0 g
s
.27813 .77973 m .27852 .8165 L .3079 .81252 L p .707 .577 .707 r
F P
0 g
s
.3079 .81252 m .30751 .77575 L .27813 .77973 L p .707 .577 .707 r
F P
0 g
s
.18896 .71634 m .19244 .65916 L .17131 .65502 L p .707 .577 .707 r
F P
0 g
s
.41082 .80725 m .41594 .30211 L .38621 .29352 L p .707 .577 .707 r
F P
0 g
s
.41594 .30211 m .41082 .80725 L .44959 .81327 L p .707 .577 .707 r
F P
0 g
s
.68642 .68905 m .68294 .74623 L .66181 .7421 L p .707 .577 .707 r
F P
0 g
s
.66181 .7421 m .6653 .68492 L .68642 .68905 L p .707 .577 .707 r
F P
0 g
s
.69709 .81705 m .69929 .8332 L .68629 .81888 L p .707 .577 .707 r
F P
0 g
s
.68629 .81888 m .68409 .80273 L .69709 .81705 L p .707 .577 .707 r
F P
0 g
s
.21552 .8159 m .21513 .77912 L .18767 .7746 L p .707 .577 .707 r
F P
0 g
s
.21513 .77912 m .21552 .8159 L .24669 .81766 L p .707 .577 .707 r
F P
0 g
s
.50426 .83068 m .50646 .84683 L .49994 .86418 L p .707 .577 .707 r
F P
0 g
s
.17131 .65502 m .16783 .7122 L .18896 .71634 L p .707 .577 .707 r
F P
0 g
s
.30751 .77575 m .3079 .81252 L .33195 .80612 L p .707 .577 .707 r
F P
0 g
s
.33195 .80612 m .33156 .76934 L .30751 .77575 L p .707 .577 .707 r
F P
0 g
s
.68251 .77097 m .68291 .80775 L .66185 .80091 L p .707 .577 .707 r
F P
0 g
s
.66185 .80091 m .66167 .78404 L p .68251 .77097 L .707 .577 .707 r
F P
0 g
s
.66277 .79215 m .66497 .8083 L .64513 .80411 L p .707 .577 .707 r
F P
0 g
s
.64513 .80411 m .63743 .80248 L p .65105 .79693 L .707 .577 .707 r
F P
0 g
s
.65105 .79693 m .66277 .79215 L .64513 .80411 L .707 .577 .707 r
F
.66167 .78404 m .66146 .76413 L .67457 .76839 L p F P
0 g
s
.67457 .76839 m .68251 .77097 L p .66167 .78404 L .707 .577 .707 r
F P
0 g
s
.33602 .66613 m .33253 .72331 L .34875 .72099 L p .707 .577 .707 r
F P
0 g
s
.34875 .72099 m .35223 .66381 L .33602 .66613 L p .707 .577 .707 r
F P
0 g
s
.18767 .7746 m .18806 .81137 L .21552 .8159 L p .707 .577 .707 r
F P
0 g
s
.6653 .68492 m .66181 .7421 L .63433 .7385 L p .707 .577 .707 r
F P
0 g
s
.63433 .7385 m .63781 .68132 L .6653 .68492 L p .707 .577 .707 r
F P
0 g
s
.63743 .80248 m .63523 .78633 L .66277 .79215 L p .707 .577 .707 r
F P
0 g
s
.61908 .29952 m .61396 .80466 L .63707 .7954 L p .707 .577 .707 r
F P
0 g
s
.63707 .7954 m .64218 .29025 L .61908 .29952 L p .707 .577 .707 r
F P
0 g
s
.18806 .81137 m .18767 .7746 L .16661 .76776 L p .707 .577 .707 r
F P
0 g
s
.16783 .7122 m .17131 .65502 L .15861 .65075 L p .707 .577 .707 r
F P
0 g
s
.68409 .80273 m .68629 .81888 L .66497 .8083 L p .707 .577 .707 r
F P
0 g
s
.66497 .8083 m .66277 .79215 L .68409 .80273 L p .707 .577 .707 r
F P
0 g
s
.15861 .65075 m .15513 .70793 L .16783 .7122 L p .707 .577 .707 r
F P
0 g
s
.16661 .76776 m .167 .80453 L .18806 .81137 L p .707 .577 .707 r
F P
0 g
s
.25329 .8752 m .25109 .85905 L .22001 .85858 L p .707 .577 .707 r
F P
0 g
s
.25109 .85905 m .25329 .8752 L .28487 .8703 L p .707 .577 .707 r
F P
0 g
s
.28487 .8703 m .28267 .85415 L .25109 .85905 L p .707 .577 .707 r
F P
0 g
s
.33156 .76934 m .33195 .80612 L .34832 .79791 L p .707 .577 .707 r
F P
0 g
s
.34832 .79791 m .34792 .76114 L .33156 .76934 L p .707 .577 .707 r
F P
0 g
s
.28267 .85415 m .28487 .8703 L .31384 .86049 L p .707 .577 .707 r
F P
0 g
s
.31384 .86049 m .31164 .84433 L .28267 .85415 L p .707 .577 .707 r
F P
0 g
s
.38109 .79867 m .38621 .29352 L .36843 .28321 L p .707 .577 .707 r
F P
0 g
s
.38621 .29352 m .38109 .79867 L .41082 .80725 L p .707 .577 .707 r
F P
0 g
s
.22221 .87473 m .22001 .85858 L .19246 .85276 L p .707 .577 .707 r
F P
0 g
s
.22001 .85858 m .22221 .87473 L .25329 .8752 L p .707 .577 .707 r
F P
0 g
s
.31164 .84433 m .31384 .86049 L .33738 .84673 L p .707 .577 .707 r
F P
0 g
s
.33738 .84673 m .33518 .83058 L .31164 .84433 L p .707 .577 .707 r
F P
0 g
s
.35223 .66381 m .34875 .72099 L .35567 .71767 L p .707 .577 .707 r
F P
0 g
s
.35567 .71767 m .35916 .66049 L .35223 .66381 L p .707 .577 .707 r
F P
0 g
s
.167 .80453 m .16661 .76776 L .15401 .75927 L p .707 .577 .707 r
F P
0 g
s
.19246 .85276 m .19466 .86891 L .22221 .87473 L p .707 .577 .707 r
F P
0 g
s
.15513 .70793 m .15861 .65075 L .15557 .64676 L p .707 .577 .707 r
F P
0 g
s
.19466 .86891 m .19246 .85276 L .17115 .84218 L p .707 .577 .707 r
F P
0 g
s
.15401 .75927 m .15441 .79605 L .167 .80453 L p .707 .577 .707 r
F P
0 g
s
.64218 .29025 m .63707 .7954 L .64706 .78473 L p .707 .577 .707 r
F P
0 g
s
.65218 .27958 m .64218 .29025 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64707 .78361 m .65218 .27958 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64707 .78361 L p .64706 .78403 L .707 .577 .707 r
F P
0 g
s
.64706 .78473 m .64297 .7737 L p .64455 .68877 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .646 .67628 L .64706 .78473 L .707 .577 .707 r
F
.64558 .63351 m .64562 .63144 L .64752 .73994 L F
.65218 .27958 m .65108 .38807 L p .64562 .63144 L F P
0 g
s
.65108 .38807 m .64752 .73994 L p .64562 .63144 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64558 .63351 L .646 .67628 L .707 .577 .707 r
F
.64752 .73994 m .64706 .78473 L p .64558 .63351 L F P
0 g
s
.64551 .63619 m .63423 .62859 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64808 .26855 m .64583 .49115 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.64583 .49115 m .64481 .59135 L p .63665 .58759 L .707 .577 .707 r
F P
0 g
s
.63339 .58609 m .64583 .49115 L .63665 .58759 L .707 .577 .707 r
F
.63534 .60907 m .63665 .58759 L p .6354 .60069 L F P
0 g
s
.64482 .59189 m .64481 .59135 L .64474 .59132 L .707 .577 .707 r
F
.64808 .26855 m .65218 .27958 L p .64558 .63351 L F P
0 g
s
.63882 .55189 m .63534 .60907 L .6452 .61238 L p .707 .577 .707 r
F P
0 g
s
.64482 .59189 m .63882 .55189 L .6452 .61238 L .707 .577 .707 r
F
.63423 .62859 m .63462 .66536 L .64471 .67216 L p F P
0 g
s
.64297 .7737 m .64341 .72984 L p .64429 .69106 L .707 .577 .707 r
F P
0 g
s
.64455 .68877 m .64429 .69106 L .64558 .63351 L .707 .577 .707 r
F
.64297 .7737 m .64429 .69106 L .64455 .68877 L F
.64485 .66561 m .63423 .62859 L .64471 .67216 L F
.64341 .72984 m .64481 .59135 L p .64558 .63332 L F P
0 g
s
.64341 .72984 m .64558 .63332 L .64558 .63351 L .707 .577 .707 r
F
.63339 .58609 m .63665 .58759 L .63508 .60399 L F
.63468 .60821 m .63534 .60907 L p .6354 .60069 L F P
0 g
s
.63339 .58609 m .64376 .69559 L .63876 .69119 L .707 .577 .707 r
F
.63462 .66536 m .63423 .62859 L .63309 .62496 L p F P
0 g
s
.63462 .66536 m .63309 .62496 L .63369 .65232 L .707 .577 .707 r
F
.63624 .76979 m .62519 .76338 L p .63261 .60284 L F P
0 g
s
.62519 .76338 m .62866 .4204 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.63133 .61929 m .63172 .65607 L .63392 .66312 L p .707 .577 .707 r
F P
0 g
s
.63392 .66312 m .63462 .66536 L p .63369 .65232 L .707 .577 .707 r
F P
0 g
s
.63369 .65232 m .63133 .61929 L .63392 .66312 L .707 .577 .707 r
F
.6303 .25824 m .64808 .26855 L p .63261 .60284 L F P
0 g
s
.62866 .4204 m .6303 .25824 L p .63261 .60284 L .707 .577 .707 r
F P
0 g
s
.64297 .7737 m .63624 .76979 L p .63339 .58609 L .707 .577 .707 r
F P
0 g
s
.63261 .60284 m .63339 .58609 L .63624 .76979 L .707 .577 .707 r
F
.63309 .62496 m .63133 .61929 L p .63369 .65232 L F P
0 g
s
.63578 .5479 m .6323 .60508 L .63468 .60821 L p .707 .577 .707 r
F P
0 g
s
.6354 .60069 m .63578 .5479 L .63468 .60821 L .707 .577 .707 r
F
.64481 .59135 m .64376 .69559 L p .63508 .60399 L F P
0 g
s
.63665 .58759 m .64481 .59135 L .63508 .60399 L .707 .577 .707 r
F
.64376 .69559 m .64297 .7737 L p .63876 .69119 L F P
0 g
s
.64056 .72466 m .65356 .73897 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.63836 .7085 m .64047 .72397 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64047 .72397 m .64056 .72466 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.64471 .67216 m .64722 .67385 L p .64485 .66561 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64808 .26855 L p .64558 .63351 L .707 .577 .707 r
F P
0 g
s
.6452 .61238 m .64804 .61334 L p .64482 .59189 L .707 .577 .707 r
F P
0 g
s
.63882 .55189 m .63578 .5479 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.63665 .58759 m .63882 .55189 L p .6354 .60069 L .707 .577 .707 r
F P
0 g
s
.64413 .55367 m .63882 .55189 L p .64474 .59132 L .707 .577 .707 r
F P
0 g
s
.64481 .59135 m .64413 .55367 L .64474 .59132 L .707 .577 .707 r
F
.64722 .67385 m .64682 .63707 L .64551 .63619 L p F P
0 g
s
.64722 .67385 m .64551 .63619 L .64485 .66561 L .707 .577 .707 r
F
.65356 .73897 m .65136 .72282 L .64182 .71231 L p F P
0 g
s
.64182 .71231 m .63836 .7085 L p .64152 .71485 L .707 .577 .707 r
F P
0 g
s
.65356 .73897 m .64182 .71231 L .64152 .71485 L .707 .577 .707 r
F
.64804 .61334 m .65152 .55616 L .64413 .55367 L p F P
0 g
s
.64804 .61334 m .64413 .55367 L .64482 .59189 L .707 .577 .707 r
F
.65152 .55616 m .64804 .61334 L .65437 .61458 L p F P
0 g
s
.65437 .61458 m .66917 .61747 L p .6562 .57239 L .707 .577 .707 r
F P
0 g
s
.6562 .57239 m .65152 .55616 L .65437 .61458 L .707 .577 .707 r
F
.34792 .76114 m .34832 .79791 L .3554 .78871 L p F P
0 g
s
.3554 .78871 m .355 .75194 L .34792 .76114 L p .707 .577 .707 r
F P
0 g
s
.33518 .83058 m .33738 .84673 L .35318 .83038 L p .707 .577 .707 r
F P
0 g
s
.35318 .83038 m .35098 .81423 L .33518 .83058 L p .707 .577 .707 r
F P
0 g
s
.15557 .64676 m .15209 .70394 L .15513 .70793 L p .707 .577 .707 r
F P
0 g
s
.17115 .84218 m .17335 .85833 L .19466 .86891 L p .707 .577 .707 r
F P
0 g
s
.15441 .79605 m .15401 .75927 L .15111 .74998 L p .707 .577 .707 r
F P
0 g
s
.35916 .66049 m .35567 .71767 L .35264 .71368 L p .707 .577 .707 r
F P
0 g
s
.35264 .71368 m .35612 .65651 L .35916 .66049 L p .707 .577 .707 r
F P
0 g
s
.36331 .78835 m .36843 .28321 L .36433 .27217 L p .707 .577 .707 r
F P
0 g
s
.36843 .28321 m .36331 .78835 L .38109 .79867 L p .707 .577 .707 r
F P
0 g
s
.17335 .85833 m .17115 .84218 L .15815 .82786 L p .707 .577 .707 r
F P
0 g
s
.35098 .81423 m .35318 .83038 L .35969 .81303 L p .707 .577 .707 r
F P
0 g
s
.35969 .81303 m .35749 .79688 L .35098 .81423 L p .707 .577 .707 r
F P
0 g
s
.15111 .74998 m .15151 .78675 L .15441 .79605 L p .707 .577 .707 r
F P
0 g
s
.15209 .70394 m .15557 .64676 L .1625 .64345 L p .707 .577 .707 r
F P
0 g
s
.15815 .82786 m .16035 .84401 L .17335 .85833 L p .707 .577 .707 r
F P
0 g
s
.355 .75194 m .3554 .78871 L .3525 .77942 L p .707 .577 .707 r
F P
0 g
s
.3525 .77942 m .3521 .74264 L .355 .75194 L p .707 .577 .707 r
F P
0 g
s
.1625 .64345 m .15902 .70063 L .15209 .70394 L p .707 .577 .707 r
F P
0 g
s
.16035 .84401 m .15815 .82786 L .15474 .81121 L p .707 .577 .707 r
F P
0 g
s
.15151 .78675 m .15111 .74998 L .15819 .74077 L p .707 .577 .707 r
F P
0 g
s
.35612 .65651 m .35264 .71368 L .33993 .70941 L p .707 .577 .707 r
F P
0 g
s
.33993 .70941 m .34342 .65223 L .35612 .65651 L p .707 .577 .707 r
F P
0 g
s
.35749 .79688 m .35969 .81303 L .35628 .79638 L p .707 .577 .707 r
F P
0 g
s
.35628 .79638 m .35408 .78023 L .35749 .79688 L p .707 .577 .707 r
F P
0 g
s
.15474 .81121 m .15694 .82736 L .16035 .84401 L p .707 .577 .707 r
F P
0 g
s
.15819 .74077 m .15859 .77755 L .15151 .78675 L p .707 .577 .707 r
F P
0 g
s
.15902 .70063 m .1625 .64345 L .17871 .64113 L p .707 .577 .707 r
F P
0 g
s
.36433 .27217 m .35922 .77732 L .36331 .78835 L p .707 .577 .707 r
F P
0 g
s
.35922 .77732 m .36433 .27217 L .37433 .2615 L p .707 .577 .707 r
F P
0 g
s
.3521 .74264 m .3525 .77942 L .3399 .77093 L p .707 .577 .707 r
F P
0 g
s
.3399 .77093 m .33951 .73416 L .3521 .74264 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17871 .64113 m .17523 .69831 L .15902 .70063 L p .707 .577 .707 r
F P
0 g
s
.15694 .82736 m .15474 .81121 L .16125 .79386 L p .707 .577 .707 r
F P
0 g
s
.15859 .77755 m .15819 .74077 L .17456 .73257 L p .707 .577 .707 r
F P
0 g
s
.34342 .65223 m .33993 .70941 L .31881 .70528 L p .707 .577 .707 r
F P
0 g
s
.31881 .70528 m .32229 .6481 L .34342 .65223 L p .707 .577 .707 r
F P
0 g
s
.35408 .78023 m .35628 .79638 L .34328 .78207 L p .707 .577 .707 r
F P
0 g
s
.34328 .78207 m .34108 .76592 L .35408 .78023 L p .707 .577 .707 r
F P
0 g
s
.16125 .79386 m .16345 .81002 L .15694 .82736 L p .707 .577 .707 r
F P
0 g
s
.17456 .73257 m .17495 .76935 L .15859 .77755 L p .707 .577 .707 r
F P
0 g
s
.17523 .69831 m .17871 .64113 L .20262 .64003 L p .707 .577 .707 r
F P
0 g
s
.33951 .73416 m .3399 .77093 L .31884 .76409 L p .707 .577 .707 r
F P
0 g
s
.31884 .76409 m .31866 .74723 L p .33951 .73416 L .707 .577 .707 r
F P
0 g
s
.31845 .72732 m .31884 .76409 L .29138 .75957 L p .707 .577 .707 r
F P
0 g
s
.31976 .75533 m .32196 .77148 L .30212 .76729 L p .707 .577 .707 r
F P
0 g
s
.30212 .76729 m .29442 .76567 L p .30804 .76011 L .707 .577 .707 r
F P
0 g
s
.30804 .76011 m .31976 .75533 L .30212 .76729 L .707 .577 .707 r
F
.31866 .74723 m .31845 .72732 L .33156 .73158 L p F P
0 g
s
.33156 .73158 m .33951 .73416 L p .31866 .74723 L .707 .577 .707 r
F P
0 g
s
.20262 .64003 m .19914 .69721 L .17523 .69831 L p .707 .577 .707 r
F P
0 g
s
.16345 .81002 m .16125 .79386 L .17705 .77751 L p .707 .577 .707 r
F P
0 g
s
.17495 .76935 m .17456 .73257 L .1986 .72616 L p .707 .577 .707 r
F P
0 g
s
.32229 .6481 m .31881 .70528 L .29132 .70169 L p .707 .577 .707 r
F P
0 g
s
.29132 .70169 m .29481 .64451 L .32229 .6481 L p .707 .577 .707 r
F P
0 g
s
.34108 .76592 m .34328 .78207 L .32196 .77148 L p .707 .577 .707 r
F P
0 g
s
.32196 .77148 m .31976 .75533 L .34108 .76592 L p .707 .577 .707 r
F P
0 g
s
.36921 .76665 m .37433 .2615 L .39743 .25224 L p .707 .577 .707 r
F P
0 g
s
.37433 .2615 m .36921 .76665 L .35922 .77732 L p .707 .577 .707 r
F P
0 g
s
.7278 .62377 m .73128 .56659 L .70013 .56389 L p .707 .577 .707 r
F P
0 g
s
.73128 .56659 m .7278 .62377 L .75956 .62531 L p .707 .577 .707 r
F P
0 g
s
.75956 .62531 m .76305 .56813 L .73128 .56659 L p .707 .577 .707 r
F P
0 g
s
.19914 .69721 m .20262 .64003 L .23189 .64027 L p .707 .577 .707 r
F P
0 g
s
.17705 .77751 m .17925 .79366 L .16345 .81002 L p .707 .577 .707 r
F P
0 g
s
.76305 .56813 m .75956 .62531 L .78883 .62554 L p .707 .577 .707 r
F P
0 g
s
.78883 .62554 m .79232 .56836 L .76305 .56813 L p .707 .577 .707 r
F P
0 g
s
.1986 .72616 m .199 .76294 L .17495 .76935 L p .707 .577 .707 r
F P
0 g
s
.29138 .75957 m .29119 .74202 L p .31845 .72732 L .707 .577 .707 r
F P
0 g
s
.29099 .72279 m .29138 .75957 L .26021 .7578 L p .707 .577 .707 r
F P
0 g
s
.29222 .74952 m .29442 .76567 L .26926 .76528 L p .707 .577 .707 r
F P
0 g
s
.26926 .76528 m .26333 .76519 L p .27565 .75851 L .707 .577 .707 r
F P
0 g
s
.27565 .75851 m .29222 .74952 L .26926 .76528 L .707 .577 .707 r
F
.29119 .74202 m .29099 .72279 L .30685 .72541 L p F P
0 g
s
.30685 .72541 m .31845 .72732 L p .29119 .74202 L .707 .577 .707 r
F P
0 g
s
.69665 .62107 m .70013 .56389 L .67265 .56029 L p .707 .577 .707 r
F P
0 g
s
.70013 .56389 m .69665 .62107 L .7278 .62377 L p .707 .577 .707 r
F P
0 g
s
.23189 .64027 m .22841 .69744 L .19914 .69721 L p .707 .577 .707 r
F P
0 g
s
.29481 .64451 m .29132 .70169 L .26018 .69899 L p .707 .577 .707 r
F P
0 g
s
.26018 .69899 m .26366 .64181 L .29481 .64451 L p .707 .577 .707 r
F P
0 g
s
.7269 .68698 m .72651 .6502 L .69534 .64843 L p .707 .577 .707 r
F P
0 g
s
.72651 .6502 m .7269 .68698 L .75874 .68582 L p .707 .577 .707 r
F P
0 g
s
.75874 .68582 m .75834 .64904 L .72651 .6502 L p .707 .577 .707 r
F P
0 g
s
.17925 .79366 m .17705 .77751 L .20059 .76376 L p .707 .577 .707 r
F P
0 g
s
.22841 .69744 m .23189 .64027 L .26366 .64181 L p .707 .577 .707 r
F P
0 g
s
.67265 .56029 m .66917 .61747 L .69665 .62107 L p .707 .577 .707 r
F P
0 g
s
.75834 .64904 m .75874 .68582 L .78812 .68184 L p .707 .577 .707 r
F P
0 g
s
.78812 .68184 m .78772 .64506 L .75834 .64904 L p .707 .577 .707 r
F P
0 g
s
.199 .76294 m .1986 .72616 L .22798 .72219 L p .707 .577 .707 r
F P
0 g
s
.79232 .56836 m .78883 .62554 L .81275 .62445 L p .707 .577 .707 r
F P
0 g
s
.81275 .62445 m .81623 .56727 L .79232 .56836 L p .707 .577 .707 r
F P
0 g
s
.26366 .64181 m .26018 .69899 L .22841 .69744 L p .707 .577 .707 r
F P
0 g
s
.29442 .76567 m .29222 .74952 L .31976 .75533 L p .707 .577 .707 r
F P
0 g
s
.69573 .68521 m .69534 .64843 L .66788 .64391 L p .707 .577 .707 r
F P
0 g
s
.69534 .64843 m .69573 .68521 L .7269 .68698 L p .707 .577 .707 r
F P
0 g
s
.6303 .25824 m .62519 .76338 L .59546 .75479 L p .707 .577 .707 r
F P
0 g
s
.59546 .75479 m .60057 .24965 L .6303 .25824 L p .707 .577 .707 r
F P
0 g
s
.22838 .75896 m .22822 .74409 L p .25982 .72102 L .707 .577 .707 r
F P
0 g
s
.22822 .74409 m .22798 .72219 L .24209 .72167 L p .707 .577 .707 r
F P
0 g
s
.24209 .72167 m .25982 .72102 L p .22822 .74409 L .707 .577 .707 r
F P
0 g
s
.22798 .72219 m .22838 .75896 L .199 .76294 L p .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .20059 .76376 L .22015 .75713 L p .707 .577 .707 r
F P
0 g
s
.22015 .75713 m .22956 .75395 L p .21096 .77198 L .707 .577 .707 r
F P
0 g
s
.20279 .77991 m .22015 .75713 L .21096 .77198 L .707 .577 .707 r
F
.25982 .72102 m .26021 .7578 L .22838 .75896 L p F P
0 g
s
.23176 .7701 m .22956 .75395 L .25202 .75046 L p .707 .577 .707 r
F P
0 g
s
.26021 .7578 m .26003 .74093 L p .29099 .72279 L .707 .577 .707 r
F P
0 g
s
.25202 .75046 m .26113 .74904 L p .24118 .76335 L .707 .577 .707 r
F P
0 g
s
.23176 .7701 m .25202 .75046 L .24118 .76335 L .707 .577 .707 r
F
.26003 .74093 m .25982 .72102 L .27601 .72194 L p F P
0 g
s
.27601 .72194 m .29099 .72279 L p .26003 .74093 L .707 .577 .707 r
F P
0 g
s
.66917 .61747 m .67265 .56029 L .65152 .55616 L p .707 .577 .707 r
F P
0 g
s
.20059 .76376 m .20279 .77991 L .17925 .79366 L p .707 .577 .707 r
F P
0 g
s
.78772 .64506 m .78812 .68184 L .81217 .67543 L p .707 .577 .707 r
F P
0 g
s
.81217 .67543 m .81177 .63866 L .78772 .64506 L p .707 .577 .707 r
F P
0 g
s
.66788 .64391 m .66827 .68069 L .69573 .68521 L p .707 .577 .707 r
F P
0 g
s
.26333 .76519 m .26113 .74904 L .29222 .74952 L p .707 .577 .707 r
F P
0 g
s
.66827 .68069 m .66788 .64391 L .64682 .63707 L p .707 .577 .707 r
F P
0 g
s
.39743 .25224 m .39233 .75627 L p .36921 .76665 L .707 .577 .707 r
F P
0 g
s
.39232 .75739 m .39743 .25224 L .43138 .24529 L p .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .39232 .75739 L p .39708 .69499 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .41038 .52063 L .41813 .6089 L .707 .577 .707 r
F
.42158 .64821 m .44511 .64502 L p .41875 .61599 L F P
0 g
s
.42311 .58855 m .44583 .58873 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.42811 .5681 m .43138 .24529 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.43639 .56773 m .43109 .55592 L .42811 .5681 L .707 .577 .707 r
F
.43639 .56773 m .42811 .5681 L .42311 .58855 L F
.43138 .24529 m .47286 .24134 L p .44301 .56744 L F P
0 g
s
.43138 .24529 m .42811 .5681 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.41038 .52063 m .43138 .24529 L .41813 .6089 L .707 .577 .707 r
F
.47286 .24134 m .46957 .56626 L p .44713 .56725 L F P
0 g
s
.44301 .56744 m .44441 .55222 L .44713 .56725 L .707 .577 .707 r
F
.44441 .55222 m .47286 .24134 L .44713 .56725 L F
.44713 .56725 m .44583 .58873 L .45098 .58849 L p F P
0 g
s
.44583 .58873 m .44713 .56725 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.46957 .56626 m .46774 .74648 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.45301 .61856 m .44471 .60825 L .4509 .64348 L .707 .577 .707 r
F
.45739 .5668 m .46957 .56626 L .4519 .63173 L F
.45409 .60575 m .44471 .60825 L p .45301 .61856 L F P
0 g
s
.44301 .56744 m .45739 .5668 L .4519 .63173 L .707 .577 .707 r
F
.44931 .53155 m .44713 .56725 L p .45785 .57691 L F P
0 g
s
.46837 .68446 m .46908 .61467 L p .47111 .71246 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47122 .40351 L p .47115 .60696 L .707 .577 .707 r
F P
0 g
s
.46908 .61467 m .47115 .60696 L .47111 .71246 L .707 .577 .707 r
F
.48764 .54547 m .47122 .40351 L .5178 .24076 L F
.47111 .71246 m .47115 .60696 L .48764 .54547 L F
.47115 .60696 m .47122 .40351 L .48764 .54547 L F
.46774 .74648 m .46837 .68446 L p .47111 .71246 L F P
0 g
s
.46774 .74648 m .44197 .74894 L p .4519 .63173 L .707 .577 .707 r
F P
0 g
s
.5178 .24076 m .51269 .74591 L .46774 .74648 L p .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .47238 .67441 L .44946 .6878 L p .707 .577 .707 r
F P
0 g
s
.44946 .6878 m .44885 .68816 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.47458 .69056 m .44946 .6878 L .44935 .68821 L .707 .577 .707 r
F
.45105 .70431 m .47458 .69056 L p .44935 .68821 L F P
0 g
s
.44885 .68816 m .44902 .68945 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.44902 .68945 m .45105 .70431 L p .44935 .68821 L .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .45492 .54695 L .45785 .57691 L .707 .577 .707 r
F
.45492 .54695 m .44931 .53155 L .45785 .57691 L F
.47122 .40351 m .47286 .24134 L .47981 .24125 L p F P
0 g
s
.47981 .24125 m .5178 .24076 L p .47122 .40351 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .46876 .60184 L .4606 .60401 L p .707 .577 .707 r
F P
0 g
s
.4606 .60401 m .45409 .60575 L p .45984 .6183 L .707 .577 .707 r
F P
0 g
s
.46916 .63862 m .4606 .60401 L .45984 .6183 L .707 .577 .707 r
F
.46916 .63862 m .45409 .60575 L .45301 .61856 L F
.44471 .60825 m .44511 .64502 L .4509 .64348 L p F P
0 g
s
.40855 .64809 m .42135 .66486 L .42627 .75044 L .707 .577 .707 r
F
.44511 .64502 m .44471 .60825 L .41839 .61181 L p F P
0 g
s
.44511 .64502 m .41839 .61181 L .41875 .61599 L .707 .577 .707 r
F
.42811 .5681 m .42671 .70658 L p .41813 .6089 L F P
0 g
s
.42671 .70658 m .42627 .75044 L p .41813 .6089 L .707 .577 .707 r
F P
0 g
s
.42627 .75044 m .44301 .56744 L .4519 .63173 L .707 .577 .707 r
F
.44197 .74894 m .42627 .75044 L p .4519 .63173 L F P
0 g
s
.42627 .75044 m .42811 .5681 L p .44301 .56744 L .707 .577 .707 r
F P
0 g
s
.45105 .70431 m .45095 .70363 L p .41987 .69797 L .707 .577 .707 r
F P
0 g
s
.45095 .70363 m .44885 .68816 L .44114 .69077 L p .707 .577 .707 r
F P
0 g
s
.44114 .69077 m .41987 .69797 L p .45095 .70363 L .707 .577 .707 r
F P
0 g
s
.39708 .69499 m .40855 .64809 L .42627 .75044 L .707 .577 .707 r
F
.40855 .64809 m .41813 .6089 L .42135 .66486 L F
.41839 .61181 m .41533 .61222 L p .41875 .61599 L F P
0 g
s
.4509 .64348 m .46916 .63862 L p .45301 .61856 L .707 .577 .707 r
F P
0 g
s
.45098 .58849 m .46974 .58763 L p .44713 .56725 L .707 .577 .707 r
F P
0 g
s
.44931 .53155 m .42004 .53131 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.44713 .56725 m .44931 .53155 L p .43639 .56773 L .707 .577 .707 r
F P
0 g
s
.41533 .61222 m .41573 .649 L .42158 .64821 L p .707 .577 .707 r
F P
0 g
s
.41875 .61599 m .41533 .61222 L .42158 .64821 L .707 .577 .707 r
F
.42004 .53131 m .41655 .58849 L .42311 .58855 L p F P
0 g
s
.43109 .55592 m .42004 .53131 L .42311 .58855 L .707 .577 .707 r
F
.38827 .52977 m .38479 .58695 L .40704 .58803 L p F P
0 g
s
.40704 .58803 m .41655 .58849 L p .40846 .5717 L .707 .577 .707 r
F P
0 g
s
.40846 .5717 m .38827 .52977 L .40704 .58803 L .707 .577 .707 r
F
.39233 .75627 m .39232 .75739 L .39223 .75742 L p F P
0 g
s
.39223 .75742 m .36921 .76665 L p .39233 .75627 L .707 .577 .707 r
F P
0 g
s
.81623 .56727 m .81275 .62445 L .82896 .62213 L p .707 .577 .707 r
F P
0 g
s
.82896 .62213 m .83244 .56495 L .81623 .56727 L p .707 .577 .707 r
F P
0 g
s
.22956 .75395 m .23176 .7701 L .20279 .77991 L p .707 .577 .707 r
F P
0 g
s
.26113 .74904 m .26333 .76519 L .23176 .7701 L p .707 .577 .707 r
F P
0 g
s
.64682 .63707 m .64722 .67385 L .66827 .68069 L p .707 .577 .707 r
F P
0 g
s
.81177 .63866 m .81217 .67543 L .82853 .66723 L p .707 .577 .707 r
F P
0 g
s
.82853 .66723 m .82814 .63045 L .81177 .63866 L p .707 .577 .707 r
F P
0 g
s
.73351 .75585 m .73131 .7397 L .70023 .73922 L p .707 .577 .707 r
F P
0 g
s
.73131 .7397 m .73351 .75585 L .76508 .75094 L p .707 .577 .707 r
F P
0 g
s
.76508 .75094 m .76288 .73479 L .73131 .7397 L p .707 .577 .707 r
F P
0 g
s
.76288 .73479 m .76508 .75094 L .79406 .74113 L p .707 .577 .707 r
F P
0 g
s
.79406 .74113 m .79186 .72498 L .76288 .73479 L p .707 .577 .707 r
F P
0 g
s
.60057 .24965 m .59546 .75479 L .55669 .74877 L p .707 .577 .707 r
F P
0 g
s
.55669 .74877 m .56181 .24363 L .60057 .24965 L p .707 .577 .707 r
F P
0 g
s
.70243 .75537 m .70023 .73922 L .67268 .7334 L p .707 .577 .707 r
F P
0 g
s
.70023 .73922 m .70243 .75537 L .73351 .75585 L p .707 .577 .707 r
F P
0 g
s
.79186 .72498 m .79406 .74113 L .81759 .72738 L p .707 .577 .707 r
F P
0 g
s
.81759 .72738 m .81539 .71122 L .79186 .72498 L p .707 .577 .707 r
F P
0 g
s
.83244 .56495 m .82896 .62213 L .83589 .61881 L p .707 .577 .707 r
F P
0 g
s
.83589 .61881 m .83937 .56163 L .83244 .56495 L p .707 .577 .707 r
F P
0 g
s
.67268 .7334 m .67488 .74955 L .70243 .75537 L p .707 .577 .707 r
F P
0 g
s
.67488 .74955 m .67268 .7334 L .65136 .72282 L p .707 .577 .707 r
F P
0 g
s
.82814 .63045 m .82853 .66723 L .83561 .65803 L p .707 .577 .707 r
F P
0 g
s
.83561 .65803 m .83521 .62125 L .82814 .63045 L p .707 .577 .707 r
F P
0 g
s
.56181 .24363 m .55669 .74877 L .51269 .74591 L p .707 .577 .707 r
F P
0 g
s
.51269 .74591 m .5178 .24076 L .56181 .24363 L p .707 .577 .707 r
F P
0 g
s
.81539 .71122 m .81759 .72738 L .83339 .71102 L p .707 .577 .707 r
F P
0 g
s
.83339 .71102 m .83119 .69487 L .81539 .71122 L p .707 .577 .707 r
F P
0 g
s
.65136 .72282 m .65356 .73897 L .67488 .74955 L p .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83521 .62125 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83271 .64873 m .83242 .62188 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83242 .62188 m .83231 .61195 L p .83335 .64167 L .707 .577 .707 r
F P
0 g
s
.83231 .61195 m .83271 .64873 L .82011 .64025 L p .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .83231 .61195 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.82011 .64025 m .81985 .61546 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81985 .61546 m .81972 .60347 L p .82345 .6325 L .707 .577 .707 r
F P
0 g
s
.81972 .60347 m .82011 .64025 L .79906 .63341 L p .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .81972 .60347 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79906 .63341 m .7988 .60995 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.7988 .60995 m .79866 .59663 L p .8047 .62523 L .707 .577 .707 r
F P
0 g
s
.79866 .59663 m .79906 .63341 L .7716 .62888 L p .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .79866 .59663 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7716 .62888 m .77135 .60588 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.77135 .60588 m .7712 .59211 L p .77877 .62033 L .707 .577 .707 r
F P
0 g
s
.7712 .59211 m .7716 .62888 L .74043 .62711 L p .707 .577 .707 r
F P
0 g
s
.74003 .59034 m .7712 .59211 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74043 .62711 m .74017 .60366 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.74017 .60366 m .74003 .59034 L p .74818 .61829 L .707 .577 .707 r
F P
0 g
s
.7082 .5915 m .74003 .59034 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70859 .62828 m .70833 .60349 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.70833 .60349 m .7082 .5915 L p .71577 .61961 L .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .7082 .5915 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67921 .63225 m .67892 .6054 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.67892 .6054 m .67882 .59548 L p .68445 .62488 L .707 .577 .707 r
F P
0 g
s
.65516 .63866 m .65477 .60188 L .67882 .59548 L p .707 .577 .707 r
F P
0 g
s
.67882 .59548 m .67921 .63225 L .65516 .63866 L p .707 .577 .707 r
F P
0 g
s
.68284 .54117 m .67935 .59835 L .67695 .59846 L p .707 .577 .707 r
F P
0 g
s
.67695 .59846 m .65544 .59944 L p .66903 .57054 L .707 .577 .707 r
F P
0 g
s
.66903 .57054 m .68284 .54117 L .67695 .59846 L .707 .577 .707 r
F
.7082 .5915 m .70859 .62828 L .67921 .63225 L p F P
0 g
s
.71211 .5414 m .70863 .59858 L .70605 .59856 L p .707 .577 .707 r
F P
0 g
s
.70605 .59856 m .67935 .59835 L p .6941 .5727 L .707 .577 .707 r
F P
0 g
s
.6941 .5727 m .71211 .5414 L .70605 .59856 L .707 .577 .707 r
F
.74003 .59034 m .74043 .62711 L .70859 .62828 L p F P
0 g
s
.74387 .54294 m .74039 .60012 L .73818 .60002 L p .707 .577 .707 r
F P
0 g
s
.73818 .60002 m .70863 .59858 L p .72407 .57421 L .707 .577 .707 r
F P
0 g
s
.72407 .57421 m .74387 .54294 L .73818 .60002 L .707 .577 .707 r
F
.77502 .54564 m .77154 .60282 L .7697 .60266 L p F P
0 g
s
.7697 .60266 m .74039 .60012 L p .75587 .57577 L .707 .577 .707 r
F P
0 g
s
.75587 .57577 m .77502 .54564 L .7697 .60266 L .707 .577 .707 r
F
.8025 .54924 m .79902 .60642 L .79736 .6062 L p F P
0 g
s
.79736 .6062 m .77154 .60282 L p .78623 .57739 L .707 .577 .707 r
F P
0 g
s
.78623 .57739 m .8025 .54924 L .79736 .6062 L .707 .577 .707 r
F
.82363 .55337 m .82015 .61055 L .81875 .61028 L p F P
0 g
s
.81875 .61028 m .79902 .60642 L p .81201 .57841 L .707 .577 .707 r
F P
0 g
s
.81201 .57841 m .82363 .55337 L .81875 .61028 L .707 .577 .707 r
F
.83633 .55764 m .83285 .61482 L .83208 .61456 L p F P
0 g
s
.83208 .61456 m .82015 .61055 L p .83032 .57729 L .707 .577 .707 r
F P
0 g
s
.83032 .57729 m .83633 .55764 L .83208 .61456 L .707 .577 .707 r
F
.83937 .56163 m .83589 .61881 L .83285 .61482 L p F P
0 g
s
.83285 .61482 m .83633 .55764 L .83937 .56163 L p .707 .577 .707 r
F P
0 g
s
.83119 .69487 m .83339 .71102 L .83991 .69367 L p .707 .577 .707 r
F P
0 g
s
.83991 .69367 m .83771 .67752 L .83119 .69487 L p .707 .577 .707 r
F P
0 g
s
.83521 .62125 m .83561 .65803 L .83271 .64873 L p .707 .577 .707 r
F P
0 g
s
.6323 .60508 m .63578 .5479 L .64271 .54458 L p .707 .577 .707 r
F P
0 g
s
.64271 .54458 m .63923 .60176 L .6323 .60508 L p .707 .577 .707 r
F P
0 g
s
.63172 .65607 m .63133 .61929 L .6384 .61009 L p .707 .577 .707 r
F P
0 g
s
.64056 .72466 m .63836 .7085 L .63495 .69186 L p .707 .577 .707 r
F P
0 g
s
.83771 .67752 m .83991 .69367 L .8365 .67703 L p .707 .577 .707 r
F P
0 g
s
.8365 .67703 m .8343 .66088 L .83771 .67752 L p .707 .577 .707 r
F P
0 g
s
.6384 .61009 m .6388 .64686 L .63172 .65607 L p .707 .577 .707 r
F P
0 g
s
.82015 .61055 m .82363 .55337 L .83633 .55764 L p .707 .577 .707 r
F P
0 g
s
.63495 .69186 m .63715 .70801 L .64056 .72466 L p .707 .577 .707 r
F P
0 g
s
.38479 .58695 m .38827 .52977 L .35713 .52707 L p .707 .577 .707 r
F P
0 g
s
.41655 .58849 m .42004 .53131 L .38827 .52977 L p .707 .577 .707 r
F P
0 g
s
.63923 .60176 m .64271 .54458 L .65892 .54226 L p .707 .577 .707 r
F P
0 g
s
.35364 .58425 m .35713 .52707 L .32964 .52348 L p .707 .577 .707 r
F P
0 g
s
.35713 .52707 m .35364 .58425 L .38479 .58695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38389 .65016 m .3835 .61339 L .35233 .61162 L p .707 .577 .707 r
F P
0 g
s
.3835 .61339 m .38389 .65016 L .41573 .649 L p .707 .577 .707 r
F P
0 g
s
.41573 .649 m .41533 .61222 L .3835 .61339 L p .707 .577 .707 r
F P
0 g
s
.65892 .54226 m .65544 .59944 L .63923 .60176 L p .707 .577 .707 r
F P
0 g
s
.63715 .70801 m .63495 .69186 L .64146 .67451 L p .707 .577 .707 r
F P
0 g
s
.6388 .64686 m .6384 .61009 L .65477 .60188 L p .707 .577 .707 r
F P
0 g
s
.32964 .52348 m .32616 .58066 L .35364 .58425 L p .707 .577 .707 r
F P
0 g
s
.46974 .58763 m .47322 .53045 L .44931 .53155 L p .707 .577 .707 r
F P
0 g
s
.35272 .64839 m .35233 .61162 L .32487 .60709 L p .707 .577 .707 r
F P
0 g
s
.35233 .61162 m .35272 .64839 L .38389 .65016 L p .707 .577 .707 r
F P
0 g
s
.8343 .66088 m .8365 .67703 L .8235 .66271 L p .707 .577 .707 r
F P
0 g
s
.8235 .66271 m .8213 .64656 L .8343 .66088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32616 .58066 m .32964 .52348 L .30851 .51934 L p .707 .577 .707 r
F P
0 g
s
.64146 .67451 m .64366 .69066 L .63715 .70801 L p .707 .577 .707 r
F P
0 g
s
.65477 .60188 m .65516 .63866 L .6388 .64686 L p .707 .577 .707 r
F P
0 g
s
.79902 .60642 m .8025 .54924 L .82363 .55337 L p .707 .577 .707 r
F P
0 g
s
.32487 .60709 m .32526 .64387 L .35272 .64839 L p .707 .577 .707 r
F P
0 g
s
.30851 .51934 m .30503 .57652 L .32616 .58066 L p .707 .577 .707 r
F P
0 g
s
.65544 .59944 m .65892 .54226 L .68284 .54117 L p .707 .577 .707 r
F P
0 g
s
.32526 .64387 m .32487 .60709 L .30381 .60026 L p .707 .577 .707 r
F P
0 g
s
.47322 .53045 m .46974 .58763 L .48595 .58531 L p .707 .577 .707 r
F P
0 g
s
.48595 .58531 m .48943 .52813 L .47322 .53045 L p .707 .577 .707 r
F P
0 g
s
.64366 .69066 m .64146 .67451 L .65726 .65816 L p .707 .577 .707 r
F P
0 g
s
.8213 .64656 m .8235 .66271 L .80218 .65213 L p .707 .577 .707 r
F P
0 g
s
.80218 .65213 m .79998 .63598 L .8213 .64656 L p .707 .577 .707 r
F P
0 g
s
.30381 .60026 m .30421 .63703 L .32526 .64387 L p .707 .577 .707 r
F P
0 g
s
.46876 .60184 m .46916 .63862 L .48552 .63041 L p .707 .577 .707 r
F P
0 g
s
.48552 .63041 m .48513 .59364 L .46876 .60184 L p .707 .577 .707 r
F P
0 g
s
.30503 .57652 m .30851 .51934 L .29581 .51507 L p .707 .577 .707 r
F P
0 g
s
.77154 .60282 m .77502 .54564 L .8025 .54924 L p .707 .577 .707 r
F P
0 g
s
.3905 .71903 m .3883 .70288 L .35722 .7024 L p .707 .577 .707 r
F P
0 g
s
.3883 .70288 m .3905 .71903 L .42207 .71413 L p .707 .577 .707 r
F P
0 g
s
.42207 .71413 m .41987 .69797 L .3883 .70288 L p .707 .577 .707 r
F P
0 g
s
.65726 .65816 m .65946 .67431 L .64366 .69066 L p .707 .577 .707 r
F P
0 g
s
.41987 .69797 m .42207 .71413 L .45105 .70431 L p .707 .577 .707 r
F P
0 g
s
.29581 .51507 m .29233 .57225 L .30503 .57652 L p .707 .577 .707 r
F P
0 g
s
.67935 .59835 m .68284 .54117 L .71211 .5414 L p .707 .577 .707 r
F P
0 g
s
.35942 .71855 m .35722 .7024 L .32967 .69659 L p .707 .577 .707 r
F P
0 g
s
.35722 .7024 m .35942 .71855 L .3905 .71903 L p .707 .577 .707 r
F P
0 g
s
.30421 .63703 m .30381 .60026 L .29122 .59177 L p .707 .577 .707 r
F P
0 g
s
.65946 .67431 m .65726 .65816 L .6808 .6444 L p .707 .577 .707 r
F P
0 g
s
.74039 .60012 m .74387 .54294 L .77502 .54564 L p .707 .577 .707 r
F P
0 g
s
.48943 .52813 m .48595 .58531 L .49288 .58199 L p .707 .577 .707 r
F P
0 g
s
.49288 .58199 m .49636 .52481 L .48943 .52813 L p .707 .577 .707 r
F P
0 g
s
.79998 .63598 m .80218 .65213 L .77463 .64631 L p .707 .577 .707 r
F P
0 g
s
.77463 .64631 m .77243 .63016 L .79998 .63598 L p .707 .577 .707 r
F P
0 g
s
.32967 .69659 m .33187 .71274 L .35942 .71855 L p .707 .577 .707 r
F P
0 g
s
.70863 .59858 m .71211 .5414 L .74387 .54294 L p .707 .577 .707 r
F P
0 g
s
.29122 .59177 m .29161 .62855 L .30421 .63703 L p .707 .577 .707 r
F P
0 g
s
.33187 .71274 m .32967 .69659 L .30835 .686 L p .707 .577 .707 r
F P
0 g
s
.6808 .6444 m .683 .66055 L .65946 .67431 L p .707 .577 .707 r
F P
0 g
s
.48513 .59364 m .48552 .63041 L .4926 .62121 L p .707 .577 .707 r
F P
0 g
s
.4926 .62121 m .49221 .58443 L .48513 .59364 L p .707 .577 .707 r
F P
0 g
s
.47238 .67441 m .47458 .69056 L .49038 .67421 L p .707 .577 .707 r
F P
0 g
s
.49038 .67421 m .48818 .65806 L .47238 .67441 L p .707 .577 .707 r
F P
0 g
s
.29233 .57225 m .29581 .51507 L .29277 .51108 L p .707 .577 .707 r
F P
0 g
s
.683 .66055 m .6808 .6444 L .70977 .63459 L p .707 .577 .707 r
F P
0 g
s
.77243 .63016 m .77463 .64631 L .74355 .64583 L p .707 .577 .707 r
F P
0 g
s
.74355 .64583 m .74135 .62968 L .77243 .63016 L p .707 .577 .707 r
F P
0 g
s
.30835 .686 m .31055 .70216 L .33187 .71274 L p .707 .577 .707 r
F P
0 g
s
.29277 .51108 m .28929 .56826 L .29233 .57225 L p .707 .577 .707 r
F P
0 g
s
.29161 .62855 m .29122 .59177 L .28832 .58247 L p .707 .577 .707 r
F P
0 g
s
.71197 .65074 m .70977 .63459 L .74135 .62968 L p .707 .577 .707 r
F P
0 g
s
.70977 .63459 m .71197 .65074 L .683 .66055 L p .707 .577 .707 r
F P
0 g
s
.74135 .62968 m .74355 .64583 L .71197 .65074 L p .707 .577 .707 r
F P
0 g
s
.31055 .70216 m .30835 .686 L .29535 .67169 L p .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .49221 .58443 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4897 .61191 m .48941 .58506 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.48941 .58506 m .4893 .57514 L p .49034 .60486 L .707 .577 .707 r
F P
0 g
s
.4893 .57514 m .4897 .61191 L .4771 .60343 L p .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4893 .57514 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.4771 .60343 m .47684 .57865 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47684 .57865 m .47671 .56665 L p .48044 .59569 L .707 .577 .707 r
F P
0 g
s
.47671 .56665 m .4771 .60343 L .45605 .59659 L p .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .47671 .56665 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45605 .59659 m .45579 .57314 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45579 .57314 m .45565 .55981 L p .46169 .58841 L .707 .577 .707 r
F P
0 g
s
.45565 .55981 m .45605 .59659 L .42859 .59207 L p .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .45565 .55981 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42859 .59207 m .42834 .56907 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42834 .56907 m .42819 .55529 L p .43576 .58351 L .707 .577 .707 r
F P
0 g
s
.42819 .55529 m .42859 .59207 L .39741 .5903 L p .707 .577 .707 r
F P
0 g
s
.39702 .55352 m .42819 .55529 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39741 .5903 m .39716 .56684 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.39716 .56684 m .39702 .55352 L p .40517 .58148 L .707 .577 .707 r
F P
0 g
s
.36519 .55468 m .39702 .55352 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36558 .59146 m .36532 .56668 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.36532 .56668 m .36519 .55468 L p .37276 .5828 L .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .36519 .55468 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.3362 .59544 m .33591 .56859 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.33591 .56859 m .33581 .55866 L p .34144 .58807 L .707 .577 .707 r
F P
0 g
s
.31215 .60184 m .31176 .56507 L .33581 .55866 L p .707 .577 .707 r
F P
0 g
s
.33581 .55866 m .3362 .59544 L .31215 .60184 L p .707 .577 .707 r
F P
0 g
s
.33983 .50435 m .33634 .56153 L .33394 .56164 L p .707 .577 .707 r
F P
0 g
s
.33394 .56164 m .31243 .56263 L p .32602 .53372 L .707 .577 .707 r
F P
0 g
s
.32602 .53372 m .33983 .50435 L .33394 .56164 L .707 .577 .707 r
F
.36519 .55468 m .36558 .59146 L .3362 .59544 L p F P
0 g
s
.3691 .50459 m .36561 .56176 L .36304 .56174 L p .707 .577 .707 r
F P
0 g
s
.36304 .56174 m .33634 .56153 L p .35109 .53589 L .707 .577 .707 r
F P
0 g
s
.35109 .53589 m .3691 .50459 L .36304 .56174 L .707 .577 .707 r
F
.39702 .55352 m .39741 .5903 L .36558 .59146 L p F P
0 g
s
.40086 .50613 m .39738 .56331 L .39517 .5632 L p .707 .577 .707 r
F P
0 g
s
.39517 .5632 m .36561 .56176 L p .38106 .53739 L .707 .577 .707 r
F P
0 g
s
.38106 .53739 m .40086 .50613 L .39517 .5632 L .707 .577 .707 r
F
.43201 .50883 m .42853 .56601 L .42668 .56585 L p F P
0 g
s
.42668 .56585 m .39738 .56331 L p .41286 .53895 L .707 .577 .707 r
F P
0 g
s
.41286 .53895 m .43201 .50883 L .42668 .56585 L .707 .577 .707 r
F
.45949 .51242 m .45601 .5696 L .45435 .56938 L p F P
0 g
s
.45435 .56938 m .42853 .56601 L p .44322 .54057 L .707 .577 .707 r
F P
0 g
s
.44322 .54057 m .45949 .51242 L .45435 .56938 L .707 .577 .707 r
F
.48062 .51655 m .47714 .57373 L .47574 .57346 L p F P
0 g
s
.47574 .57346 m .45601 .5696 L p .469 .5416 L .707 .577 .707 r
F P
0 g
s
.469 .5416 m .48062 .51655 L .47574 .57346 L .707 .577 .707 r
F
.49332 .52083 m .48984 .57801 L .48907 .57774 L p F P
0 g
s
.48907 .57774 m .47714 .57373 L p .48731 .54047 L .707 .577 .707 r
F P
0 g
s
.48731 .54047 m .49332 .52083 L .48907 .57774 L .707 .577 .707 r
F
.49636 .52481 m .49288 .58199 L .48984 .57801 L p F P
0 g
s
.48984 .57801 m .49332 .52083 L .49636 .52481 L p .707 .577 .707 r
F P
0 g
s
.28832 .58247 m .28871 .61925 L .29161 .62855 L p .707 .577 .707 r
F P
0 g
s
.48818 .65806 m .49038 .67421 L .4969 .65686 L p .707 .577 .707 r
F P
0 g
s
.4969 .65686 m .4947 .64071 L .48818 .65806 L p .707 .577 .707 r
F P
0 g
s
.49221 .58443 m .4926 .62121 L .4897 .61191 L p .707 .577 .707 r
F P
0 g
s
.29535 .67169 m .29755 .68784 L .31055 .70216 L p .707 .577 .707 r
F P
0 g
s
.28929 .56826 m .29277 .51108 L .2997 .50777 L p .707 .577 .707 r
F P
0 g
s
.2997 .50777 m .29622 .56495 L .28929 .56826 L p .707 .577 .707 r
F P
0 g
s
.28871 .61925 m .28832 .58247 L .29539 .57327 L p .707 .577 .707 r
F P
0 g
s
.29755 .68784 m .29535 .67169 L .29194 .65504 L p .707 .577 .707 r
F P
0 g
s
.4947 .64071 m .4969 .65686 L .49349 .64021 L p .707 .577 .707 r
F P
0 g
s
.49349 .64021 m .49129 .62406 L .4947 .64071 L p .707 .577 .707 r
F P
0 g
s
.29539 .57327 m .29579 .61005 L .28871 .61925 L p .707 .577 .707 r
F P
0 g
s
.47714 .57373 m .48062 .51655 L .49332 .52083 L p .707 .577 .707 r
F P
0 g
s
.29194 .65504 m .29414 .67119 L .29755 .68784 L p .707 .577 .707 r
F P
0 g
s
.29622 .56495 m .2997 .50777 L .31591 .50545 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31591 .50545 m .31243 .56263 L .29622 .56495 L p .707 .577 .707 r
F P
0 g
s
.29414 .67119 m .29194 .65504 L .29845 .63769 L p .707 .577 .707 r
F P
0 g
s
.29579 .61005 m .29539 .57327 L .31176 .56507 L p .707 .577 .707 r
F P
0 g
s
.49129 .62406 m .49349 .64021 L .48049 .62589 L p .707 .577 .707 r
F P
0 g
s
.48049 .62589 m .47829 .60974 L .49129 .62406 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29845 .63769 m .30065 .65384 L .29414 .67119 L p .707 .577 .707 r
F P
0 g
s
.31176 .56507 m .31215 .60184 L .29579 .61005 L p .707 .577 .707 r
F P
0 g
s
.45601 .5696 m .45949 .51242 L .48062 .51655 L p .707 .577 .707 r
F P
0 g
s
.31243 .56263 m .31591 .50545 L .33983 .50435 L p .707 .577 .707 r
F P
0 g
s
.30065 .65384 m .29845 .63769 L .31425 .62134 L p .707 .577 .707 r
F P
0 g
s
.47829 .60974 m .48049 .62589 L .45917 .61531 L p .707 .577 .707 r
F P
0 g
s
.45917 .61531 m .45697 .59916 L .47829 .60974 L p .707 .577 .707 r
F P
0 g
s
.42853 .56601 m .43201 .50883 L .45949 .51242 L p .707 .577 .707 r
F P
0 g
s
.31425 .62134 m .31645 .63749 L .30065 .65384 L p .707 .577 .707 r
F P
0 g
s
.33634 .56153 m .33983 .50435 L .3691 .50459 L p .707 .577 .707 r
F P
0 g
s
.31645 .63749 m .31425 .62134 L .33779 .60758 L p .707 .577 .707 r
F P
0 g
s
.39738 .56331 m .40086 .50613 L .43201 .50883 L p .707 .577 .707 r
F P
0 g
s
.45697 .59916 m .45917 .61531 L .43162 .6095 L p .707 .577 .707 r
F P
0 g
s
.43162 .6095 m .42942 .59334 L .45697 .59916 L p .707 .577 .707 r
F P
0 g
s
.36561 .56176 m .3691 .50459 L .40086 .50613 L p .707 .577 .707 r
F P
0 g
s
.33779 .60758 m .33999 .62374 L .31645 .63749 L p .707 .577 .707 r
F P
0 g
s
.33999 .62374 m .33779 .60758 L .36676 .59777 L p .707 .577 .707 r
F P
0 g
s
.42942 .59334 m .43162 .6095 L .40054 .60902 L p .707 .577 .707 r
F P
0 g
s
.40054 .60902 m .39834 .59287 L .42942 .59334 L p .707 .577 .707 r
F P
0 g
s
.36896 .61393 m .36676 .59777 L .39834 .59287 L p .707 .577 .707 r
F P
0 g
s
.36676 .59777 m .36896 .61393 L .33999 .62374 L p .707 .577 .707 r
F P
0 g
s
.39834 .59287 m .40054 .60902 L .36896 .61393 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaP008Ao
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@00Ngoo001cOol50002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol0071oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00KWoo0`002EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000
K7oo001/Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001YOol006Yoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Mo
o`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00IGoo001XOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00goo
001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00Hgoo
001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH4001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00iJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
3UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP0?FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH03eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol006Mo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0F
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00F7oo7P000eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000Hgoo001EOol300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000DFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH7000=FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH00008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001COol00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001eYF00L005YFFUIJEP00FUH00003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol005=oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool@
001>Ool0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2@000eYF00<005YFFUH01EYF00<005YF
FUH00UYF2@00AGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH7000fOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01@00<Goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00000_Ool0059oo`03001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002ioo`00DWoo00<005YF00001`000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0`000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00@005YFFUIJEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool005=oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00002000^Ool0059oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF008002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH002ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002moo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000
0eYF3P0015YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DGoo
00@005YFFUH000=JEP03001JEUYF00=JEPH0009oo`05001JEUYF001JEP040002FUH00`00FUIJEP06
FUH00`00FUH000060004FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001AOol01000
FUIJEP000eYF00<005YF00000`0027oo1@001UYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000IJ
EP00000005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH2000015YF001JEUYF7P001EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo
001BOol00`00FUH00003FUH30008Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20000
0eYF000000050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@0015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo001BOol01000FUH005YF0P000eYF20001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<0009JEP800003FUH005YF00AJEP03001JEUYF
00=JEP04001JEUYF0008FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF1`000eYF00<005YFFUH0
0P00;goo001BOol00`00FUH000020005FUH00`00FUH000020007FUH00`00FUIJEP02FUHA0004FUH0
1000FUIJEUYF0P0000EJEP00001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D00003FUH0000002moo`00DWoo0P000UYF00<005YF
FUH00eYF0P000UYF00<005YFFUH015YF40000UYF00<005YFFUH00UYF1@0015YF0P0000AJEP000000
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000015YF00000000;goo001BOol20002FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF
0P001UYF00<005YFFUH01UYF00@005YFFUH000UJEP80009JEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
000_Ool0059oo`05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUH000020008FUH00`00FUIJ
EP06FUH01000FUIJEP002eYF0P0000IJEP00FUH005YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000_Ool0059oo`06
001JEUYFFUH005YF0P001UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000]J
EP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00OomJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02000_Ool0059oo`04001JEUYFFUH200000eYF
001JEP03FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004FUH01000FUIJEP002eYF00L005YF
FUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00OomJEP03FUH00`00FUIJEP02000_
Ool005=oo`04001JEUYF0002FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH60003FUH01000FUIJ
EP002eYF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP80
0003FUH005YF00=JEP03001JEUYF00=JEPH000Qooa<0009JEP03001JEUYF00=JEP800003FUH00000
02moo`00E7oo0P000eYF10001eYF00<005YFFUH01UYF1P000eYF00@005YFFUH000]JEP08001JEP00
001JEP00FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF
00=JEP03001JEP0000<000Qoo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJ
EP02000_Ool005Aoo`03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH60003FUH01000
FUIJEP002EYF100015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF001JEP0000=JEP<000Yoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEPD0
0004FUH005YFFUH2000_Ool002ioob4000Eoo`04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH000020004FUH01000FUIJEP001UYF0`002EYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00FUH50007Ool30003FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH2000_Ool002aoo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP04001o
ogooOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP004UYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<000AJEPL000MJEP03
001JEUYF00AJEPd000IJEP04001JEUYFFUH6000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000P0009ooaP00003FUH0
05YF011JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001J
EP020005FUH00`00FUH000020008FUH00`00FUIJEP0?0002FUH40002FUH00`00FUIJEP02FUH5000_
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0005FUH00`00FUIJEP050003Ool00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP0?FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUH00000FUH00P001EYF0P000UYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YF00000P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH0
0eYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH03UYF00@005YFFUH0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP8000=JEP80
00EJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP04001JEP00000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF0P000UYF00<005YFFUH0
1EYF100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`0000EJEP00FUIJEP00
02moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000EJEP8000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009J
EP03001oogoo02eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP09001JEUYFFUH005YF001JEP0000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEP0002moo`00;7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH30007
FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP0300000eYF0000000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH00007FUH0
0`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003Ool3000^
Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YF000010000UYF00<005YFFUH01UYF00@005YFFUIJEP<000Ioo`8002ioo`00:goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<0
05YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF0`001eYF00<005YFFUH01UYF0P000UYF
00@005YFFUH000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
0002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH6
0009Ool2000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH02@00FUIJEUYF001JEP00
FUH00005FUH50006FUH00`00FUIJEP04FUH20004FUH00`00FUH00008FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP0000001P0000=oo`0000001`0015YF
00<005YFFUH01UYF00<005YFFUH010003goo0P00;Woo000[Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP00
1EYF00T005YFFUIJEP00FUH005YF00001EYF1@001UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<000AJEP03
001JEUYF00@000Iooa0001=oo`8002ioo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00@000EJEP04001JEUYFFUH3
00000eYF001JEP04FUH50006FUH00`00FUIJEP040006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP03FUH3000V
Ool00`00FUH0000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH20004FUH01000FUIJEUYF0`0000=JEP00
FUH01EYF0`001eYF0`000eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00P005YFFUH005YF001JEP0015YF00<005YFFUH00eYF00@005YFFUH002Eoo`03
001JEP0002ioo`00:goo00<005YF00000UYF7P0015YF00<005YFFUH00UYF0P000eYF1@000eYF0`00
00=JEP00FUH01EYF00@005YFFUIJEPH000MJEP03001JEUYF00<000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
008002=oo`800003FUH007oo02eoo`00:goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF20000UYF00<005YFFUH00UYF00@005YFFUIJEQ8000AJEP03001JEUYF
00IJEP<00003FUH0000000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000ROol01000FUH00000;goo
000[Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00P008Goo00<005YFFUH00P00;goo
000/Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001EYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF0080021oo`05001JEUYFFUH0
000`Ool002ioo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000OOol00`00FUIJEP02FUH00`00Oomoo`0^Ool0
039oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF009JEPH000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P002Goo0`004Goo0`000eYF00<007ooOol0;goo000iOol90004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo1@003goo00@005YFFUH0009JEP03
001oogoo031oo`00?Goo:00000Aoo`00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000Qoo`D000eoo`8000AJEP8003=oo`00=goo
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P002goo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH010001EYF00<005YFFUH00P002Goo1@002Woo0`00
1UYF00<007ooOol0<Woo000cOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEUYF0P0015YF00<005YFFUH00P002Woo0`001goo10000UYF00<005YFFUH00UYF0P00=Goo000`
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP040005Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH3000015YF001JEUYF0P003goo1@001UYF00<005YFFUH00P00=goo000^Ool200000eYF001JEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20004Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF00<0
05YF00001@002goo10000UYF00<005YFFUH01UYF0`00>Goo000/Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000Woo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJ
EP03001JEUYF00=JEPd000IJEP03001JEUYF00EJEP8003]oo`00:goo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00T005YFFUIJEP00Ool005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?Goo000[
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0U
0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00?goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP03FUH80003FUH00`00FUIJEP03
FUH02@00FUIJEUYF001oo`00FUH00006FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH00000
15YF1@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Woo000ZOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEUYF10001EYF00T005YF
FUIJEP00Ool005YF00001UYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF0180
04Qoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00T005YFFUIJEP00Ool005YF00001EYF10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
0P0015YF00<005YFFUH00UYF00@005YF000000IJEP03001JEUYF00<005Moo`00:Woo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH0
0`00FUIJEP0200000eYF001JEP02FUH01@00Ool005YF00000eYF0P001UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
00<005YF00002P00FWoo000ZOol01000FUIJEP000eYF00<005YF00000`000Woo0P001UYF00<005YF
FUH00UYF3P001eYF00@005YFFUIJEP8000=JEP06001oo`00FUH005YF0`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00000P00
0eYF0P000UYF1000Ggoo000ZOol01000FUIJEP000eYF0P0017oo0`001UYF1P003Woo10000eYF00<0
05YFFUH00UYF0P000UYF00@007oo001JEP80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800003
FUH0000000AJEP04001JEP00001MOol002]oo`03001JEP00009JEP@00003Ool00000009JEP03001J
EWoo009JEP8000Qoo`<000eoo`@000AJEP04001JEP00FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH01000FUIJEUYF0P00Fgoo000[Ool00`00FUH000020003FUH20004FUH00`00Ool0
00020009Ool50008Ool50003FUH20003FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP02FUH3001IOol002]oo`05001JEP00FUH00002FUH00`00FUIJEP04
FUH90005Ool=0003FUH00`00FUIJEP04FUH2000015YF001JEUYF100015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0015YF00<005YFFUH00UYF00<005YFFUH00P00Egoo000[Ool20002FUH01000FUH0
000015YF0P0015YF00<005YFFUH00UYF2P000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
0000009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF009J
EP05001JEUYFFUH0001GOol002]oo`04001JEUYFFUH2000015YF001JEUYF0P001UYF00<005YFFUH0
1UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH20000
0goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00EWoo000[Ool01000FUIJEP000eYF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEPD0009JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002]oo`03
001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2
0003FUH30005FUH00`00FUIJEP02001FOol002]oo`03001JEP0000=JEP05001JEUYFFUH00007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Ool00004Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20006FUH30003FUH00`00FUIJEP02001FOol002ao
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009oo`03001oogoo00Aoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00<00003FUH005YF00EJEP03001JEUYF00800004FUH005YFFUH2001FOol002aoo`05001JEP00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003Ool20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH>0003FUH01000FUIJEUYF0P000UYF0P00EWoo000/Ool01@00
FUH00000Ool00`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P001Goo00<005YF00002goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01@003Woo100015YF0P0000=JEP000000EWoo000/Ool00`00FUH0
0005Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000030006
Ool01000FUIJEP0047oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
0goo0`003Goo1P000UYF00<005YF00000P00EWoo000/Ool00`00FUH0000:Ool90004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP005Woo2@001UYF00<005YFFUH015YF3@002Goo
1@001goo1@001EYF0`0000=JEP00FUH00P00EWoo000/Ool2000DOolB000>Ool20002FUH00`00Oomo
o`0MOol>0007FUHJ0003FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00Oomoo`1DOol002ao
o`8003=oo`05001JEP00FUH0000VOol20002FUH200000eYF001JEP04FUH20003FUH00`00FUIJEP06
FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
001FOol002aoo`03001oogoo039oo`03001JEUYF008002Ioo`80009JEP80009JEP03001JEUYF0080
00EJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Ioo`00;7oo00<007ooOol0<Goo00D005YFFUIJEP0002Moo`80009JEP04
001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH4001EOol002aoo`80035oo`03001JEUYF009JEP03001oogoo02Ioo`03001J
EP0000AJEP03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP@005Eoo`00;7oo00<005YF0000;Woo0`000eYF00<007ooOol0:7oo
0P000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH200000goo0000001EOol002eoo`03001JEP0002]oo`80009JEP04001J
EP00000[Ool200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000goo0P00EGoo000]Ool01000FUIJEP00:7oo
0P0015YF0P00;Goo100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001Goo0P00EGoo000^Ool00`00FUH00002000TOol20006FUH00`00
Oomoo`0[Ool00`00FUH00002Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH000020007Ool00`00FUH0001EOol002moo`80009JEP8001ioo`@00003
FUH005YF00=JEP8002ioo`03001JEP0000Eoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPH000Yoo`03001JEP0005Eoo`00;goo00<005YF00000eYF0`005Woo1@001EYF00D0
05YFFUIJEP00031oo`03001JEP0000Yooa/000moo`800003FUH007oo05Aoo`00<7oo0P0015YF00<0
05YF00000`003Woo10000UYF00<005YFFUH01UYF0`00<Goo0P00=7oo00@005YF000005Ioo`00<Goo
00<005YFFUH00UYF00<005YFFUH00eYF3P001UYF00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo
00<005YFFUH00P00EWoo000bOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH3000fOol00`00Oomoo`0`Ool01@00FUIJEUYF0000Egoo000dOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002000iOol2000`Ool00`00FUIJ
EP02FUH00`00Oomoo`1EOol003Ioo`D000AJEP03001JEUYF00IJEP03001JEUYF009JEPD003aoo`03
001JEP0002eoo`<000=JEP03001oogoo05Ioo`00>goo4P00@Woo00<005YF0000:goo00@005YFFUH0
009JEP03001oogoo05Moo`00Sgoo00@005YFFUH002Qoo`8000AJEP03001JEP0005Uoo`00Sgoo00<0
05YFFUH00`0097oo0P001UYF0P00FWoo002@Ool00`00FUH00002FUH2000OOol300000eYF001JEP05
FUH00`00Oomoo`1IOol0091oo`03001JEP0000AJEP<001Uoo`<000AJEP03001JEUYF009JEP8005ao
o`00TGoo0P001EYF00<005YF00000`003goo1P001eYF00<005YFFUH00P00GWoo002BOol00`00FUIJ
EP03FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3001POol009=oo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80069oo`00UGoo0P0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002GOol30006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH5001XOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@0
06eoo`00WWoo3P00LGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59259 .75578 m .59475 .69904 L .56359 .69664 L p .707 .577 .707 r
F P
0 g
s
.59475 .69904 m .59259 .75578 L .6244 .75643 L p .707 .577 .707 r
F P
0 g
s
.6244 .75643 m .62656 .69969 L .59475 .69904 L p .707 .577 .707 r
F P
0 g
s
.62656 .69969 m .6244 .75643 L .65374 .75528 L p .707 .577 .707 r
F P
0 g
s
.65374 .75528 m .6559 .69853 L .62656 .69969 L p .707 .577 .707 r
F P
0 g
s
.56143 .75339 m .56359 .69664 L .53612 .69274 L p .707 .577 .707 r
F P
0 g
s
.56359 .69664 m .56143 .75339 L .59259 .75578 L p .707 .577 .707 r
F P
0 g
s
.6559 .69853 m .65374 .75528 L .67774 .75243 L p .707 .577 .707 r
F P
0 g
s
.67774 .75243 m .6799 .69568 L .6559 .69853 L p .707 .577 .707 r
F P
0 g
s
.53612 .69274 m .53396 .74949 L .56143 .75339 L p .707 .577 .707 r
F P
0 g
s
.59215 .83744 m .59191 .80055 L .56074 .79874 L p .707 .577 .707 r
F P
0 g
s
.59191 .80055 m .59215 .83744 L .62399 .83642 L p .707 .577 .707 r
F P
0 g
s
.62399 .83642 m .62374 .79954 L .59191 .80055 L p .707 .577 .707 r
F P
0 g
s
.53396 .74949 m .53612 .69274 L .51504 .68772 L p .707 .577 .707 r
F P
0 g
s
.62374 .79954 m .62399 .83642 L .65337 .83267 L p .707 .577 .707 r
F P
0 g
s
.65337 .83267 m .65312 .79579 L .62374 .79954 L p .707 .577 .707 r
F P
0 g
s
.56098 .83562 m .56074 .79874 L .53328 .79426 L p .707 .577 .707 r
F P
0 g
s
.56074 .79874 m .56098 .83562 L .59215 .83744 L p .707 .577 .707 r
F P
0 g
s
.51504 .68772 m .51288 .74446 L .53396 .74949 L p .707 .577 .707 r
F P
0 g
s
.65312 .79579 m .65337 .83267 L .67742 .82656 L p .707 .577 .707 r
F P
0 g
s
.67742 .82656 m .67718 .78967 L .65312 .79579 L p .707 .577 .707 r
F P
0 g
s
.6799 .69568 m .67774 .75243 L .69405 .74816 L p .707 .577 .707 r
F P
0 g
s
.69405 .74816 m .69621 .69141 L .6799 .69568 L p .707 .577 .707 r
F P
0 g
s
.53328 .79426 m .53352 .83115 L .56098 .83562 L p .707 .577 .707 r
F P
0 g
s
.53352 .83115 m .53328 .79426 L .51222 .78757 L p .707 .577 .707 r
F P
0 g
s
.51288 .74446 m .51504 .68772 L .5024 .68205 L p .707 .577 .707 r
F P
0 g
s
.59583 .88953 m .59446 .87227 L .56332 .87128 L p .707 .577 .707 r
F P
0 g
s
.59446 .87227 m .59583 .88953 L .62757 .88614 L p .707 .577 .707 r
F P
0 g
s
.62757 .88614 m .62619 .86888 L .59446 .87227 L p .707 .577 .707 r
F P
0 g
s
.62619 .86888 m .62757 .88614 L .65679 .87868 L p .707 .577 .707 r
F P
0 g
s
.65679 .87868 m .65542 .86142 L .62619 .86888 L p .707 .577 .707 r
F P
0 g
s
.51222 .78757 m .51247 .82445 L .53352 .83115 L p .707 .577 .707 r
F P
0 g
s
.56469 .88854 m .56332 .87128 L .53583 .86598 L p .707 .577 .707 r
F P
0 g
s
.56332 .87128 m .56469 .88854 L .59583 .88953 L p .707 .577 .707 r
F P
0 g
s
.67718 .78967 m .67742 .82656 L .69379 .81867 L p .707 .577 .707 r
F P
0 g
s
.69379 .81867 m .69354 .78179 L .67718 .78967 L p .707 .577 .707 r
F P
0 g
s
.5024 .68205 m .50024 .7388 L .51288 .74446 L p .707 .577 .707 r
F P
0 g
s
.65542 .86142 m .65679 .87868 L .68065 .86788 L p .707 .577 .707 r
F P
0 g
s
.68065 .86788 m .67928 .85062 L .65542 .86142 L p .707 .577 .707 r
F P
0 g
s
.53583 .86598 m .5372 .88324 L .56469 .88854 L p .707 .577 .707 r
F P
0 g
s
.69621 .69141 m .69405 .74816 L .70107 .7429 L p .707 .577 .707 r
F P
0 g
s
.70107 .7429 m .70323 .68615 L .69621 .69141 L p .707 .577 .707 r
F P
0 g
s
.51247 .82445 m .51222 .78757 L .49963 .77931 L p .707 .577 .707 r
F P
0 g
s
.5372 .88324 m .53583 .86598 L .51467 .85691 L p .707 .577 .707 r
F P
0 g
s
.50024 .7388 m .5024 .68205 L .49945 .67631 L p .707 .577 .707 r
F P
0 g
s
.49963 .77931 m .49987 .8162 L .51247 .82445 L p .707 .577 .707 r
F P
0 g
s
.67928 .85062 m .68065 .86788 L .6968 .85481 L p .707 .577 .707 r
F P
0 g
s
.6968 .85481 m .69543 .83755 L .67928 .85062 L p .707 .577 .707 r
F P
0 g
s
.51467 .85691 m .51605 .87417 L .5372 .88324 L p .707 .577 .707 r
F P
0 g
s
.69354 .78179 m .69379 .81867 L .70087 .80979 L p .707 .577 .707 r
F P
0 g
s
.70087 .80979 m .70062 .7729 L .69354 .78179 L p .707 .577 .707 r
F P
0 g
s
.49945 .67631 m .49729 .73306 L .50024 .7388 L p .707 .577 .707 r
F P
0 g
s
.51605 .87417 m .51467 .85691 L .50192 .84494 L p .707 .577 .707 r
F P
0 g
s
.70323 .68615 m .70107 .7429 L .69812 .73716 L p .707 .577 .707 r
F P
0 g
s
.69812 .73716 m .70028 .68041 L .70323 .68615 L p .707 .577 .707 r
F P
0 g
s
.49987 .8162 m .49963 .77931 L .49673 .7703 L p .707 .577 .707 r
F P
0 g
s
.50192 .84494 m .5033 .8622 L .51605 .87417 L p .707 .577 .707 r
F P
0 g
s
.69543 .83755 m .6968 .85481 L .70366 .84075 L p .707 .577 .707 r
F P
0 g
s
.70366 .84075 m .70229 .82349 L .69543 .83755 L p .707 .577 .707 r
F P
0 g
s
.49673 .7703 m .49697 .80719 L .49987 .8162 L p .707 .577 .707 r
F P
0 g
s
.49729 .73306 m .49945 .67631 L .50648 .67105 L p .707 .577 .707 r
F P
0 g
s
.70062 .7729 m .70087 .80979 L .69797 .80078 L p .707 .577 .707 r
F P
0 g
s
.69797 .80078 m .69773 .76389 L .70062 .7729 L p .707 .577 .707 r
F P
0 g
s
.49238 .81834 m .49555 .3144 L .45154 .3116 L p .707 .577 .707 r
F P
0 g
s
.50648 .67105 m .50432 .7278 L .49729 .73306 L p .707 .577 .707 r
F P
0 g
s
.49697 .80719 m .49673 .7703 L .50381 .76142 L p .707 .577 .707 r
F P
0 g
s
.50381 .76142 m .50406 .79831 L .49697 .80719 L p .707 .577 .707 r
F P
0 g
s
.50432 .7278 m .50648 .67105 L .52279 .66679 L p .707 .577 .707 r
F P
0 g
s
.52279 .66679 m .52063 .72353 L .50432 .7278 L p .707 .577 .707 r
F P
0 g
s
.5033 .8622 m .50192 .84494 L .49883 .83126 L p .707 .577 .707 r
F P
0 g
s
.49883 .83126 m .5002 .84852 L .5033 .8622 L p .707 .577 .707 r
F P
0 g
s
.5002 .84852 m .49883 .83126 L .50569 .81719 L p .707 .577 .707 r
F P
0 g
s
.50406 .79831 m .50381 .76142 L .52018 .75354 L p .707 .577 .707 r
F P
0 g
s
.50569 .81719 m .50707 .83445 L .5002 .84852 L p .707 .577 .707 r
F P
0 g
s
.52063 .72353 m .52279 .66679 L .54678 .66393 L p .707 .577 .707 r
F P
0 g
s
.52018 .75354 m .52042 .79042 L .50406 .79831 L p .707 .577 .707 r
F P
0 g
s
.54678 .66393 m .54463 .72068 L .52063 .72353 L p .707 .577 .707 r
F P
0 g
s
.50707 .83445 m .50569 .81719 L .52184 .80412 L p .707 .577 .707 r
F P
0 g
s
.52042 .79042 m .52018 .75354 L .54423 .74742 L p .707 .577 .707 r
F P
0 g
s
.52184 .80412 m .52322 .82138 L .50707 .83445 L p .707 .577 .707 r
F P
0 g
s
.54423 .74742 m .54447 .7843 L .52042 .79042 L p .707 .577 .707 r
F P
0 g
s
.52322 .82138 m .52184 .80412 L .5457 .79333 L p .707 .577 .707 r
F P
0 g
s
.5457 .79333 m .54707 .81059 L .52322 .82138 L p .707 .577 .707 r
F P
0 g
s
.49555 .3144 m .49238 .81834 L .53733 .81756 L p .707 .577 .707 r
F P
0 g
s
.53733 .81756 m .54049 .31362 L .49555 .3144 L p .707 .577 .707 r
F P
0 g
s
.54463 .72068 m .54678 .66393 L .57612 .66278 L p .707 .577 .707 r
F P
0 g
s
.57612 .66278 m .57397 .71953 L .54463 .72068 L p .707 .577 .707 r
F P
0 g
s
.54447 .7843 m .54423 .74742 L .57361 .74367 L p .707 .577 .707 r
F P
0 g
s
.57361 .74367 m .57385 .78055 L .54447 .7843 L p .707 .577 .707 r
F P
0 g
s
.57385 .78055 m .57361 .74367 L .60545 .74265 L p .707 .577 .707 r
F P
0 g
s
.60545 .74265 m .60569 .77954 L .57385 .78055 L p .707 .577 .707 r
F P
0 g
s
.54707 .81059 m .5457 .79333 L .57493 .78587 L p .707 .577 .707 r
F P
0 g
s
.57493 .78587 m .5763 .80313 L .54707 .81059 L p .707 .577 .707 r
F P
0 g
s
.5763 .80313 m .57493 .78587 L .60666 .78247 L p .707 .577 .707 r
F P
0 g
s
.60666 .78247 m .60803 .79973 L .5763 .80313 L p .707 .577 .707 r
F P
0 g
s
.54049 .31362 m .53733 .81756 L .57881 .8133 L p .707 .577 .707 r
F P
0 g
s
.57397 .71953 m .57612 .66278 L .60793 .66343 L p .707 .577 .707 r
F P
0 g
s
.60793 .66343 m .60577 .72017 L .57397 .71953 L p .707 .577 .707 r
F P
0 g
s
.57881 .8133 m .58197 .30936 L .54049 .31362 L p .707 .577 .707 r
F P
0 g
s
.44838 .81554 m .45154 .3116 L .41277 .30551 L p .707 .577 .707 r
F P
0 g
s
.45154 .3116 m .44838 .81554 L .49238 .81834 L p .707 .577 .707 r
F P
0 g
s
.70028 .68041 m .69812 .73716 L .68549 .73149 L p .707 .577 .707 r
F P
0 g
s
.68549 .73149 m .68765 .67475 L .70028 .68041 L p .707 .577 .707 r
F P
0 g
s
.70229 .82349 m .70366 .84075 L .70057 .82706 L p .707 .577 .707 r
F P
0 g
s
.70057 .82706 m .6992 .8098 L .70229 .82349 L p .707 .577 .707 r
F P
0 g
s
.24958 .71897 m .25174 .66222 L .22058 .65983 L p .707 .577 .707 r
F P
0 g
s
.25174 .66222 m .24958 .71897 L .28139 .71962 L p .707 .577 .707 r
F P
0 g
s
.28139 .71962 m .28355 .66287 L .25174 .66222 L p .707 .577 .707 r
F P
0 g
s
.28355 .66287 m .28139 .71962 L .31073 .71846 L p .707 .577 .707 r
F P
0 g
s
.31073 .71846 m .31289 .66171 L .28355 .66287 L p .707 .577 .707 r
F P
0 g
s
.6391 .66582 m .63694 .72257 L .60577 .72017 L p .707 .577 .707 r
F P
0 g
s
.60577 .72017 m .60793 .66343 L .6391 .66582 L p .707 .577 .707 r
F P
0 g
s
.63662 .74447 m .63686 .78136 L .60569 .77954 L p .707 .577 .707 r
F P
0 g
s
.60569 .77954 m .60545 .74265 L .63662 .74447 L p .707 .577 .707 r
F P
0 g
s
.6378 .78347 m .63917 .80073 L .60803 .79973 L p .707 .577 .707 r
F P
0 g
s
.60803 .79973 m .60666 .78247 L .6378 .78347 L p .707 .577 .707 r
F P
0 g
s
.58197 .30936 m .57881 .8133 L .61276 .80596 L p .707 .577 .707 r
F P
0 g
s
.61276 .80596 m .61592 .30201 L .58197 .30936 L p .707 .577 .707 r
F P
0 g
s
.21842 .71658 m .22058 .65983 L .19311 .65593 L p .707 .577 .707 r
F P
0 g
s
.22058 .65983 m .21842 .71658 L .24958 .71897 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69773 .76389 m .69797 .80078 L .68538 .79252 L p .707 .577 .707 r
F P
0 g
s
.68538 .79252 m .68513 .75564 L .69773 .76389 L p .707 .577 .707 r
F P
0 g
s
.40961 .80945 m .41277 .30551 L .38305 .29672 L p .707 .577 .707 r
F P
0 g
s
.41277 .30551 m .40961 .80945 L .44838 .81554 L p .707 .577 .707 r
F P
0 g
s
.31289 .66171 m .31073 .71846 L .33473 .71561 L p .707 .577 .707 r
F P
0 g
s
.33473 .71561 m .33689 .65886 L .31289 .66171 L p .707 .577 .707 r
F P
0 g
s
.19311 .65593 m .19095 .71268 L .21842 .71658 L p .707 .577 .707 r
F P
0 g
s
.24914 .80062 m .2489 .76374 L .21773 .76192 L p .707 .577 .707 r
F P
0 g
s
.2489 .76374 m .24914 .80062 L .28098 .79961 L p .707 .577 .707 r
F P
0 g
s
.28098 .79961 m .28073 .76272 L .2489 .76374 L p .707 .577 .707 r
F P
0 g
s
.68765 .67475 m .68549 .73149 L .6644 .72647 L p .707 .577 .707 r
F P
0 g
s
.6644 .72647 m .66656 .66972 L .68765 .67475 L p .707 .577 .707 r
F P
0 g
s
.19095 .71268 m .19311 .65593 L .17203 .6509 L p .707 .577 .707 r
F P
0 g
s
.28073 .76272 m .28098 .79961 L .31036 .79586 L p .707 .577 .707 r
F P
0 g
s
.31036 .79586 m .31012 .75897 L .28073 .76272 L p .707 .577 .707 r
F P
0 g
s
.6992 .8098 m .70057 .82706 L .68782 .8151 L p .707 .577 .707 r
F P
0 g
s
.68782 .8151 m .68645 .79784 L .6992 .8098 L p .707 .577 .707 r
F P
0 g
s
.21797 .79881 m .21773 .76192 L .19027 .75745 L p .707 .577 .707 r
F P
0 g
s
.21773 .76192 m .21797 .79881 L .24914 .80062 L p .707 .577 .707 r
F P
0 g
s
.17203 .6509 m .16987 .70765 L .19095 .71268 L p .707 .577 .707 r
F P
0 g
s
.61592 .30201 m .61276 .80596 L .63587 .79626 L p .707 .577 .707 r
F P
0 g
s
.63587 .79626 m .63903 .29231 L .61592 .30201 L p .707 .577 .707 r
F P
0 g
s
.31012 .75897 m .31036 .79586 L .33441 .78974 L p .707 .577 .707 r
F P
0 g
s
.33441 .78974 m .33417 .75286 L .31012 .75897 L p .707 .577 .707 r
F P
0 g
s
.33689 .65886 m .33473 .71561 L .35104 .71135 L p .707 .577 .707 r
F P
0 g
s
.35104 .71135 m .3532 .6546 L .33689 .65886 L p .707 .577 .707 r
F P
0 g
s
.68513 .75564 m .68538 .79252 L .66432 .78583 L p .707 .577 .707 r
F P
0 g
s
.66432 .78583 m .66408 .74895 L .68513 .75564 L p .707 .577 .707 r
F P
0 g
s
.19027 .75745 m .19051 .79433 L .21797 .79881 L p .707 .577 .707 r
F P
0 g
s
.19051 .79433 m .19027 .75745 L .16921 .75075 L p .707 .577 .707 r
F P
0 g
s
.66656 .66972 m .6644 .72647 L .63694 .72257 L p .707 .577 .707 r
F P
0 g
s
.63694 .72257 m .6391 .66582 L .66656 .66972 L p .707 .577 .707 r
F P
0 g
s
.16987 .70765 m .17203 .6509 L .15939 .64524 L p .707 .577 .707 r
F P
0 g
s
.25282 .85272 m .25145 .83546 L .22031 .83446 L p .707 .577 .707 r
F P
0 g
s
.25145 .83546 m .25282 .85272 L .28456 .84932 L p .707 .577 .707 r
F P
0 g
s
.28456 .84932 m .28319 .83206 L .25145 .83546 L p .707 .577 .707 r
F P
0 g
s
.37988 .80067 m .38305 .29672 L .36527 .2861 L p .707 .577 .707 r
F P
0 g
s
.38305 .29672 m .37988 .80067 L .40961 .80945 L p .707 .577 .707 r
F P
0 g
s
.28319 .83206 m .28456 .84932 L .31378 .84186 L p .707 .577 .707 r
F P
0 g
s
.31378 .84186 m .31241 .8246 L .28319 .83206 L p .707 .577 .707 r
F P
0 g
s
.68645 .79784 m .68782 .8151 L .66666 .80602 L p .707 .577 .707 r
F P
0 g
s
.66666 .80602 m .66529 .78876 L .68645 .79784 L p .707 .577 .707 r
F P
0 g
s
.16921 .75075 m .16946 .78764 L .19051 .79433 L p .707 .577 .707 r
F P
0 g
s
.22169 .85172 m .22031 .83446 L .19282 .82917 L p .707 .577 .707 r
F P
0 g
s
.22031 .83446 m .22169 .85172 L .25282 .85272 L p .707 .577 .707 r
F P
0 g
s
.33417 .75286 m .33441 .78974 L .35078 .78186 L p .707 .577 .707 r
F P
0 g
s
.35078 .78186 m .35053 .74497 L .33417 .75286 L p .707 .577 .707 r
F P
0 g
s
.15939 .64524 m .15724 .70199 L .16987 .70765 L p .707 .577 .707 r
F P
0 g
s
.31241 .8246 m .31378 .84186 L .33764 .83107 L p .707 .577 .707 r
F P
0 g
s
.33764 .83107 m .33627 .81381 L .31241 .8246 L p .707 .577 .707 r
F P
0 g
s
.66408 .74895 m .66432 .78583 L .63686 .78136 L p .707 .577 .707 r
F P
0 g
s
.63686 .78136 m .63662 .74447 L .66408 .74895 L p .707 .577 .707 r
F P
0 g
s
.19282 .82917 m .19419 .84643 L .22169 .85172 L p .707 .577 .707 r
F P
0 g
s
.3532 .6546 m .35104 .71135 L .35806 .70608 L p .707 .577 .707 r
F P
0 g
s
.35806 .70608 m .36022 .64934 L .3532 .6546 L p .707 .577 .707 r
F P
0 g
s
.16946 .78764 m .16921 .75075 L .15662 .7425 L p .707 .577 .707 r
F P
0 g
s
.19419 .84643 m .19282 .82917 L .17166 .82009 L p .707 .577 .707 r
F P
0 g
s
.63917 .80073 m .6378 .78347 L .66529 .78876 L p .707 .577 .707 r
F P
0 g
s
.63903 .29231 m .63587 .79626 L .64587 .78515 L p .707 .577 .707 r
F P
0 g
s
.64587 .78515 m .64903 .28121 L .63903 .29231 L p .707 .577 .707 r
F P
0 g
s
.15724 .70199 m .15939 .64524 L .15644 .6395 L p .707 .577 .707 r
F P
0 g
s
.66529 .78876 m .66666 .80602 L .63917 .80073 L p .707 .577 .707 r
F P
0 g
s
.15662 .7425 m .15686 .77938 L .16946 .78764 L p .707 .577 .707 r
F P
0 g
s
.33627 .81381 m .33764 .83107 L .35379 .818 L p .707 .577 .707 r
F P
0 g
s
.35379 .818 m .35242 .80074 L .33627 .81381 L p .707 .577 .707 r
F P
0 g
s
.17166 .82009 m .17304 .83735 L .19419 .84643 L p .707 .577 .707 r
F P
0 g
s
.35053 .74497 m .35078 .78186 L .35786 .77297 L p .707 .577 .707 r
F P
0 g
s
.35786 .77297 m .35761 .73609 L .35053 .74497 L p .707 .577 .707 r
F P
0 g
s
.15644 .6395 m .15428 .69624 L .15724 .70199 L p .707 .577 .707 r
F P
0 g
s
.36211 .79004 m .36527 .2861 L .36118 .27467 L p .707 .577 .707 r
F P
0 g
s
.36527 .2861 m .36211 .79004 L .37988 .80067 L p .707 .577 .707 r
F P
0 g
s
.17304 .83735 m .17166 .82009 L .15891 .80813 L p .707 .577 .707 r
F P
0 g
s
.36022 .64934 m .35806 .70608 L .35511 .70034 L p .707 .577 .707 r
F P
0 g
s
.35511 .70034 m .35727 .64359 L .36022 .64934 L p .707 .577 .707 r
F P
0 g
s
.15686 .77938 m .15662 .7425 L .15372 .73349 L p .707 .577 .707 r
F P
0 g
s
.15891 .80813 m .16029 .82539 L .17304 .83735 L p .707 .577 .707 r
F P
0 g
s
.35242 .80074 m .35379 .818 L .36065 .80393 L p .707 .577 .707 r
F P
0 g
s
.36065 .80393 m .35928 .78667 L .35242 .80074 L p .707 .577 .707 r
F P
0 g
s
.15372 .73349 m .15396 .77037 L .15686 .77938 L p .707 .577 .707 r
F P
0 g
s
.15428 .69624 m .15644 .6395 L .16347 .63423 L p .707 .577 .707 r
F P
0 g
s
.35761 .73609 m .35786 .77297 L .35496 .76396 L p .707 .577 .707 r
F P
0 g
s
.35496 .76396 m .35472 .72708 L .35761 .73609 L p .707 .577 .707 r
F P
0 g
s
.64903 .28121 m .64587 .78515 L .64284 .77671 L p .707 .577 .707 r
F P
0 g
s
.64236 .73417 m .64903 .28121 L .64284 .77671 L .707 .577 .707 r
F
.64236 .73417 m .64398 .4421 L .64903 .28121 L F
.64214 .71524 m .64375 .45876 L p .64236 .73417 L F P
0 g
s
.64375 .45876 m .64494 .26978 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64375 .45876 m .64398 .4421 L .64236 .73417 L .707 .577 .707 r
F
.64494 .26978 m .64177 .77373 L .624 .7631 L p F P
0 g
s
.63683 .64064 m .63708 .67752 L .64072 .67991 L p .707 .577 .707 r
F P
0 g
s
.64072 .67991 m .64967 .68578 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64105 .65547 m .63683 .64064 L .64072 .67991 L .707 .577 .707 r
F
.64967 .68578 m .64943 .64889 L .64122 .64351 L p F P
0 g
s
.64122 .64351 m .63683 .64064 L p .64105 .65547 L .707 .577 .707 r
F P
0 g
s
.64967 .68578 m .64122 .64351 L .64105 .65547 L .707 .577 .707 r
F
.64494 .26978 m .64629 .27357 L p .64398 .4421 L F P
0 g
s
.64629 .27357 m .64903 .28121 L p .64398 .4421 L .707 .577 .707 r
F P
0 g
s
.64177 .77373 m .64214 .71524 L p .64236 .73417 L .707 .577 .707 r
F P
0 g
s
.63961 .56304 m .63745 .61979 L .64107 .62142 L p .707 .577 .707 r
F P
0 g
s
.64107 .62142 m .65008 .62545 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.64047 .56817 m .63961 .56304 L .64107 .62142 L .707 .577 .707 r
F
.65008 .62545 m .65224 .56871 L .64041 .5634 L p F P
0 g
s
.64041 .5634 m .63961 .56304 L p .64047 .56817 L .707 .577 .707 r
F P
0 g
s
.65008 .62545 m .64041 .5634 L .64047 .56817 L .707 .577 .707 r
F
.64284 .77671 m .64177 .77373 L p .64236 .73417 L F P
0 g
s
.16347 .63423 m .16131 .69098 L .15428 .69624 L p .707 .577 .707 r
F P
0 g
s
.16029 .82539 m .15891 .80813 L .15582 .79444 L p .707 .577 .707 r
F P
0 g
s
.15396 .77037 m .15372 .73349 L .1608 .72461 L p .707 .577 .707 r
F P
0 g
s
.35727 .64359 m .35511 .70034 L .34248 .69468 L p .707 .577 .707 r
F P
0 g
s
.34248 .69468 m .34464 .63793 L .35727 .64359 L p .707 .577 .707 r
F P
0 g
s
.15582 .79444 m .15719 .8117 L .16029 .82539 L p .707 .577 .707 r
F P
0 g
s
.35928 .78667 m .36065 .80393 L .35756 .79025 L p .707 .577 .707 r
F P
0 g
s
.35756 .79025 m .35619 .77299 L .35928 .78667 L p .707 .577 .707 r
F P
0 g
s
.36118 .27467 m .35801 .77861 L .36211 .79004 L p .707 .577 .707 r
F P
0 g
s
.35801 .77861 m .36118 .27467 L .37117 .26357 L p .707 .577 .707 r
F P
0 g
s
.1608 .72461 m .16105 .76149 L .15396 .77037 L p .707 .577 .707 r
F P
0 g
s
.16131 .69098 m .16347 .63423 L .17978 .62997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35472 .72708 m .35496 .76396 L .34237 .75571 L p .707 .577 .707 r
F P
0 g
s
.34237 .75571 m .34212 .71882 L .35472 .72708 L p .707 .577 .707 r
F P
0 g
s
.17978 .62997 m .17762 .68672 L .16131 .69098 L p .707 .577 .707 r
F P
0 g
s
.15719 .8117 m .15582 .79444 L .16268 .78037 L p .707 .577 .707 r
F P
0 g
s
.34464 .63793 m .34248 .69468 L .32139 .68965 L p .707 .577 .707 r
F P
0 g
s
.32139 .68965 m .32355 .6329 L .34464 .63793 L p .707 .577 .707 r
F P
0 g
s
.16105 .76149 m .1608 .72461 L .17717 .71672 L p .707 .577 .707 r
F P
0 g
s
.16268 .78037 m .16406 .79764 L .15719 .8117 L p .707 .577 .707 r
F P
0 g
s
.624 .7631 m .62716 .25916 L .64494 .26978 L p .707 .577 .707 r
F P
0 g
s
.35619 .77299 m .35756 .79025 L .34481 .77828 L p .707 .577 .707 r
F P
0 g
s
.34481 .77828 m .34344 .76102 L .35619 .77299 L p .707 .577 .707 r
F P
0 g
s
.17762 .68672 m .17978 .62997 L .20377 .62712 L p .707 .577 .707 r
F P
0 g
s
.17717 .71672 m .17741 .75361 L .16105 .76149 L p .707 .577 .707 r
F P
0 g
s
.34212 .71882 m .34237 .75571 L .32131 .74902 L p .707 .577 .707 r
F P
0 g
s
.32131 .74902 m .32107 .71213 L .34212 .71882 L p .707 .577 .707 r
F P
0 g
s
.36801 .76751 m .37117 .26357 L .39428 .25387 L p .707 .577 .707 r
F P
0 g
s
.37117 .26357 m .36801 .76751 L .35801 .77861 L p .707 .577 .707 r
F P
0 g
s
.20377 .62712 m .20162 .68387 L .17762 .68672 L p .707 .577 .707 r
F P
0 g
s
.16406 .79764 m .16268 .78037 L .17883 .76731 L p .707 .577 .707 r
F P
0 g
s
.32355 .6329 m .32139 .68965 L .29393 .68575 L p .707 .577 .707 r
F P
0 g
s
.29393 .68575 m .29609 .629 L .32355 .6329 L p .707 .577 .707 r
F P
0 g
s
.17741 .75361 m .17717 .71672 L .20122 .7106 L p .707 .577 .707 r
F P
0 g
s
.17883 .76731 m .18021 .78457 L .16406 .79764 L p .707 .577 .707 r
F P
0 g
s
.20162 .68387 m .20377 .62712 L .23311 .62596 L p .707 .577 .707 r
F P
0 g
s
.34344 .76102 m .34481 .77828 L .32365 .76921 L p .707 .577 .707 r
F P
0 g
s
.32365 .76921 m .32228 .75195 L .34344 .76102 L p .707 .577 .707 r
F P
0 g
s
.7298 .63677 m .73196 .58003 L .70079 .57763 L p .707 .577 .707 r
F P
0 g
s
.73196 .58003 m .7298 .63677 L .76161 .63742 L p .707 .577 .707 r
F P
0 g
s
.76161 .63742 m .76376 .58068 L .73196 .58003 L p .707 .577 .707 r
F P
0 g
s
.20122 .7106 m .20146 .74749 L .17741 .75361 L p .707 .577 .707 r
F P
0 g
s
.32107 .71213 m .32131 .74902 L .29385 .74454 L p .707 .577 .707 r
F P
0 g
s
.29385 .74454 m .29361 .70766 L .32107 .71213 L p .707 .577 .707 r
F P
0 g
s
.76376 .58068 m .76161 .63742 L .79094 .63627 L p .707 .577 .707 r
F P
0 g
s
.79094 .63627 m .7931 .57952 L .76376 .58068 L p .707 .577 .707 r
F P
0 g
s
.29609 .629 m .29393 .68575 L .26276 .68336 L p .707 .577 .707 r
F P
0 g
s
.26276 .68336 m .26492 .62661 L .29609 .629 L p .707 .577 .707 r
F P
0 g
s
.23311 .62596 m .23096 .68271 L .20162 .68387 L p .707 .577 .707 r
F P
0 g
s
.62716 .25916 m .624 .7631 L .59427 .75431 L p .707 .577 .707 r
F P
0 g
s
.59427 .75431 m .59743 .25037 L .62716 .25916 L p .707 .577 .707 r
F P
0 g
s
.69863 .63438 m .70079 .57763 L .67332 .57373 L p .707 .577 .707 r
F P
0 g
s
.70079 .57763 m .69863 .63438 L .7298 .63677 L p .707 .577 .707 r
F P
0 g
s
.23096 .68271 m .23311 .62596 L .26492 .62661 L p .707 .577 .707 r
F P
0 g
s
.18021 .78457 m .17883 .76731 L .20269 .75651 L p .707 .577 .707 r
F P
0 g
s
.26492 .62661 m .26276 .68336 L .23096 .68271 L p .707 .577 .707 r
F P
0 g
s
.20146 .74749 m .20122 .7106 L .2306 .70685 L p .707 .577 .707 r
F P
0 g
s
.72936 .69876 m .72911 .66188 L .69794 .66006 L p .707 .577 .707 r
F P
0 g
s
.72911 .66188 m .72936 .69876 L .76119 .69775 L p .707 .577 .707 r
F P
0 g
s
.76119 .69775 m .76095 .66086 L .72911 .66188 L p .707 .577 .707 r
F P
0 g
s
.7931 .57952 m .79094 .63627 L .81494 .63342 L p .707 .577 .707 r
F P
0 g
s
.81494 .63342 m .8171 .57667 L .7931 .57952 L p .707 .577 .707 r
F P
0 g
s
.67332 .57373 m .67117 .63048 L .69863 .63438 L p .707 .577 .707 r
F P
0 g
s
.32228 .75195 m .32365 .76921 L .29616 .76391 L p .707 .577 .707 r
F P
0 g
s
.29616 .76391 m .29479 .74665 L .32228 .75195 L p .707 .577 .707 r
F P
0 g
s
.20269 .75651 m .20406 .77377 L .18021 .78457 L p .707 .577 .707 r
F P
0 g
s
.76095 .66086 m .76119 .69775 L .79057 .694 L p .707 .577 .707 r
F P
0 g
s
.79057 .694 m .79033 .65711 L .76095 .66086 L p .707 .577 .707 r
F P
0 g
s
.29361 .70766 m .29385 .74454 L .26268 .74272 L p .707 .577 .707 r
F P
0 g
s
.26268 .74272 m .26244 .70584 L .29361 .70766 L p .707 .577 .707 r
F P
0 g
s
.39428 .25387 m .39112 .75781 L .36801 .76751 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .39428 .25387 L .42824 .24652 L p .707 .577 .707 r
F P
0 g
s
.2306 .70685 m .23085 .74374 L .20146 .74749 L p .707 .577 .707 r
F P
0 g
s
.69818 .69694 m .69794 .66006 L .67048 .65558 L p .707 .577 .707 r
F P
0 g
s
.69794 .66006 m .69818 .69694 L .72936 .69876 L p .707 .577 .707 r
F P
0 g
s
.67117 .63048 m .67332 .57373 L .65224 .56871 L p .707 .577 .707 r
F P
0 g
s
.23085 .74374 m .2306 .70685 L .26244 .70584 L p .707 .577 .707 r
F P
0 g
s
.26244 .70584 m .26268 .74272 L .23085 .74374 L p .707 .577 .707 r
F P
0 g
s
.20406 .77377 m .20269 .75651 L .23192 .74905 L p .707 .577 .707 r
F P
0 g
s
.79033 .65711 m .79057 .694 L .81462 .68788 L p .707 .577 .707 r
F P
0 g
s
.81462 .68788 m .81438 .65099 L .79033 .65711 L p .707 .577 .707 r
F P
0 g
s
.29479 .74665 m .29616 .76391 L .26502 .76292 L p .707 .577 .707 r
F P
0 g
s
.26502 .76292 m .26365 .74565 L .29479 .74665 L p .707 .577 .707 r
F P
0 g
s
.65224 .56871 m .65008 .62545 L .67117 .63048 L p .707 .577 .707 r
F P
0 g
s
.67048 .65558 m .67073 .69247 L .69818 .69694 L p .707 .577 .707 r
F P
0 g
s
.23192 .74905 m .23329 .76631 L .20406 .77377 L p .707 .577 .707 r
F P
0 g
s
.8171 .57667 m .81494 .63342 L .83125 .62915 L p .707 .577 .707 r
F P
0 g
s
.83125 .62915 m .83341 .5724 L .8171 .57667 L p .707 .577 .707 r
F P
0 g
s
.67073 .69247 m .67048 .65558 L .64943 .64889 L p .707 .577 .707 r
F P
0 g
s
.23329 .76631 m .23192 .74905 L .26365 .74565 L p .707 .577 .707 r
F P
0 g
s
.59743 .25037 m .59427 .75431 L .5555 .74822 L p .707 .577 .707 r
F P
0 g
s
.5555 .74822 m .55867 .24428 L .59743 .25037 L p .707 .577 .707 r
F P
0 g
s
.26365 .74565 m .26502 .76292 L .23329 .76631 L p .707 .577 .707 r
F P
0 g
s
.73304 .75786 m .73166 .7406 L .70053 .7396 L p .707 .577 .707 r
F P
0 g
s
.73166 .7406 m .73304 .75786 L .76477 .75446 L p .707 .577 .707 r
F P
0 g
s
.76477 .75446 m .7634 .7372 L .73166 .7406 L p .707 .577 .707 r
F P
0 g
s
.7634 .7372 m .76477 .75446 L .794 .747 L p .707 .577 .707 r
F P
0 g
s
.794 .747 m .79262 .72974 L .7634 .7372 L p .707 .577 .707 r
F P
0 g
s
.64943 .64889 m .64967 .68578 L .67073 .69247 L p .707 .577 .707 r
F P
0 g
s
.42507 .75047 m .42824 .24652 L .46971 .24226 L p .707 .577 .707 r
F P
0 g
s
.39112 .75781 m .42171 .33646 L .42544 .69198 L .707 .577 .707 r
F
.42824 .24652 m .42705 .4355 L p .42171 .33646 L F P
0 g
s
.42705 .4355 m .42544 .69198 L p .42171 .33646 L .707 .577 .707 r
F P
0 g
s
.46971 .24226 m .46655 .7462 L .42507 .75047 L p .707 .577 .707 r
F P
0 g
s
.41794 .62405 m .41818 .66093 L .43907 .65827 L p .707 .577 .707 r
F P
0 g
s
.43907 .65827 m .44756 .65718 L p .43846 .647 L .707 .577 .707 r
F P
0 g
s
.43846 .647 m .41794 .62405 L .43907 .65827 L .707 .577 .707 r
F
.42075 .54386 m .4186 .60061 L .43952 .59978 L p F P
0 g
s
.43952 .59978 m .44794 .59945 L p .44156 .58641 L .707 .577 .707 r
F P
0 g
s
.44156 .58641 m .42075 .54386 L .43952 .59978 L .707 .577 .707 r
F
.42544 .69198 m .42507 .75047 L .41622 .75238 L p F P
0 g
s
.41622 .75238 m .39112 .75781 L p .42544 .69198 L .707 .577 .707 r
F P
0 g
s
.81438 .65099 m .81462 .68788 L .83099 .67999 L p .707 .577 .707 r
F P
0 g
s
.83099 .67999 m .83075 .64311 L .81438 .65099 L p .707 .577 .707 r
F P
0 g
s
.7019 .75686 m .70053 .7396 L .67303 .73431 L p .707 .577 .707 r
F P
0 g
s
.70053 .7396 m .7019 .75686 L .73304 .75786 L p .707 .577 .707 r
F P
0 g
s
.79262 .72974 m .794 .747 L .81785 .73621 L p .707 .577 .707 r
F P
0 g
s
.81785 .73621 m .81648 .71895 L .79262 .72974 L p .707 .577 .707 r
F P
0 g
s
.67303 .73431 m .67441 .75157 L .7019 .75686 L p .707 .577 .707 r
F P
0 g
s
.55867 .24428 m .5555 .74822 L .5115 .74543 L p .707 .577 .707 r
F P
0 g
s
.5115 .74543 m .51466 .24148 L .55867 .24428 L p .707 .577 .707 r
F P
0 g
s
.83341 .5724 m .83125 .62915 L .83828 .62389 L p .707 .577 .707 r
F P
0 g
s
.83828 .62389 m .84044 .56714 L .83341 .5724 L p .707 .577 .707 r
F P
0 g
s
.67441 .75157 m .67303 .73431 L .65188 .72523 L p .707 .577 .707 r
F P
0 g
s
.46655 .7462 m .46971 .24226 L .51466 .24148 L p .707 .577 .707 r
F P
0 g
s
.51466 .24148 m .5115 .74543 L .46655 .7462 L p .707 .577 .707 r
F P
0 g
s
.81648 .71895 m .81785 .73621 L .834 .72314 L p .707 .577 .707 r
F P
0 g
s
.834 .72314 m .83263 .70588 L .81648 .71895 L p .707 .577 .707 r
F P
0 g
s
.63745 .61979 m .63961 .56304 L .63666 .5573 L p .707 .577 .707 r
F P
0 g
s
.65188 .72523 m .65325 .74249 L .67441 .75157 L p .707 .577 .707 r
F P
0 g
s
.83075 .64311 m .83099 .67999 L .83807 .67111 L p .707 .577 .707 r
F P
0 g
s
.83807 .67111 m .83783 .63423 L .83075 .64311 L p .707 .577 .707 r
F P
0 g
s
.63666 .5573 m .6345 .61405 L .63745 .61979 L p .707 .577 .707 r
F P
0 g
s
.65325 .74249 m .65188 .72523 L .63913 .71327 L p .707 .577 .707 r
F P
0 g
s
.63708 .67752 m .63683 .64064 L .63393 .63163 L p .707 .577 .707 r
F P
0 g
s
.84044 .56714 m .83828 .62389 L .83533 .61815 L p .707 .577 .707 r
F P
0 g
s
.83533 .61815 m .83749 .5614 L .84044 .56714 L p .707 .577 .707 r
F P
0 g
s
.63913 .71327 m .6405 .73053 L .65325 .74249 L p .707 .577 .707 r
F P
0 g
s
.83263 .70588 m .834 .72314 L .84087 .70907 L p .707 .577 .707 r
F P
0 g
s
.84087 .70907 m .83949 .69181 L .83263 .70588 L p .707 .577 .707 r
F P
0 g
s
.63393 .63163 m .63418 .66851 L .63708 .67752 L p .707 .577 .707 r
F P
0 g
s
.6345 .61405 m .63666 .5573 L .64368 .55204 L p .707 .577 .707 r
F P
0 g
s
.83783 .63423 m .83807 .67111 L .83517 .6621 L p .707 .577 .707 r
F P
0 g
s
.83517 .6621 m .83493 .62522 L .83783 .63423 L p .707 .577 .707 r
F P
0 g
s
.6405 .73053 m .63913 .71327 L .63603 .69958 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64368 .55204 m .64152 .60879 L .6345 .61405 L p .707 .577 .707 r
F P
0 g
s
.63418 .66851 m .63393 .63163 L .64102 .62274 L p .707 .577 .707 r
F P
0 g
s
.63603 .69958 m .63741 .71684 L .6405 .73053 L p .707 .577 .707 r
F P
0 g
s
.83749 .5614 m .83533 .61815 L .82269 .61248 L p .707 .577 .707 r
F P
0 g
s
.82269 .61248 m .82485 .55574 L .83749 .5614 L p .707 .577 .707 r
F P
0 g
s
.83949 .69181 m .84087 .70907 L .83777 .69539 L p .707 .577 .707 r
F P
0 g
s
.83777 .69539 m .8364 .67813 L .83949 .69181 L p .707 .577 .707 r
F P
0 g
s
.64102 .62274 m .64126 .65963 L .63418 .66851 L p .707 .577 .707 r
F P
0 g
s
.38679 .59996 m .38895 .54321 L .35778 .54082 L p .707 .577 .707 r
F P
0 g
s
.38895 .54321 m .38679 .59996 L .4186 .60061 L p .707 .577 .707 r
F P
0 g
s
.4186 .60061 m .42075 .54386 L .38895 .54321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.44794 .59945 m .45009 .5427 L .42075 .54386 L p .707 .577 .707 r
F P
0 g
s
.64152 .60879 m .64368 .55204 L .65999 .54777 L p .707 .577 .707 r
F P
0 g
s
.83493 .62522 m .83517 .6621 L .82258 .65385 L p .707 .577 .707 r
F P
0 g
s
.82258 .65385 m .82234 .61696 L .83493 .62522 L p .707 .577 .707 r
F P
0 g
s
.35562 .59757 m .35778 .54082 L .33031 .53692 L p .707 .577 .707 r
F P
0 g
s
.35778 .54082 m .35562 .59757 L .38679 .59996 L p .707 .577 .707 r
F P
0 g
s
.63741 .71684 m .63603 .69958 L .6429 .68552 L p .707 .577 .707 r
F P
0 g
s
.65999 .54777 m .65783 .60452 L .64152 .60879 L p .707 .577 .707 r
F P
0 g
s
.38635 .66195 m .3861 .62506 L .35493 .62324 L p .707 .577 .707 r
F P
0 g
s
.3861 .62506 m .38635 .66195 L .41818 .66093 L p .707 .577 .707 r
F P
0 g
s
.41818 .66093 m .41794 .62405 L .3861 .62506 L p .707 .577 .707 r
F P
0 g
s
.45009 .5427 m .44794 .59945 L .47193 .5966 L p .707 .577 .707 r
F P
0 g
s
.47193 .5966 m .47409 .53985 L .45009 .5427 L p .707 .577 .707 r
F P
0 g
s
.33031 .53692 m .32816 .59367 L .35562 .59757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64126 .65963 m .64102 .62274 L .65738 .61486 L p .707 .577 .707 r
F P
0 g
s
.44756 .65718 m .44732 .6203 L .41794 .62405 L p .707 .577 .707 r
F P
0 g
s
.6429 .68552 m .64427 .70278 L .63741 .71684 L p .707 .577 .707 r
F P
0 g
s
.35517 .66013 m .35493 .62324 L .32747 .61877 L p .707 .577 .707 r
F P
0 g
s
.35493 .62324 m .35517 .66013 L .38635 .66195 L p .707 .577 .707 r
F P
0 g
s
.82485 .55574 m .82269 .61248 L .80161 .60746 L p .707 .577 .707 r
F P
0 g
s
.80161 .60746 m .80377 .55071 L .82485 .55574 L p .707 .577 .707 r
F P
0 g
s
.32816 .59367 m .33031 .53692 L .30923 .53189 L p .707 .577 .707 r
F P
0 g
s
.8364 .67813 m .83777 .69539 L .82503 .68342 L p .707 .577 .707 r
F P
0 g
s
.82503 .68342 m .82365 .66616 L .8364 .67813 L p .707 .577 .707 r
F P
0 g
s
.65738 .61486 m .65763 .65174 L .64126 .65963 L p .707 .577 .707 r
F P
0 g
s
.44732 .6203 m .44756 .65718 L .47161 .65106 L p .707 .577 .707 r
F P
0 g
s
.47161 .65106 m .47137 .61418 L .44732 .6203 L p .707 .577 .707 r
F P
0 g
s
.65783 .60452 m .65999 .54777 L .68399 .54492 L p .707 .577 .707 r
F P
0 g
s
.30923 .53189 m .30707 .58864 L .32816 .59367 L p .707 .577 .707 r
F P
0 g
s
.82234 .61696 m .82258 .65385 L .80152 .64715 L p .707 .577 .707 r
F P
0 g
s
.80152 .64715 m .80128 .61027 L .82234 .61696 L p .707 .577 .707 r
F P
0 g
s
.32747 .61877 m .32772 .65565 L .35517 .66013 L p .707 .577 .707 r
F P
0 g
s
.47409 .53985 m .47193 .5966 L .48824 .59234 L p .707 .577 .707 r
F P
0 g
s
.48824 .59234 m .4904 .53559 L .47409 .53985 L p .707 .577 .707 r
F P
0 g
s
.32772 .65565 m .32747 .61877 L .30642 .61208 L p .707 .577 .707 r
F P
0 g
s
.64427 .70278 m .6429 .68552 L .65905 .67245 L p .707 .577 .707 r
F P
0 g
s
.68399 .54492 m .68183 .60167 L .65783 .60452 L p .707 .577 .707 r
F P
0 g
s
.65763 .65174 m .65738 .61486 L .68143 .60874 L p .707 .577 .707 r
F P
0 g
s
.39003 .72104 m .38865 .70378 L .35752 .70279 L p .707 .577 .707 r
F P
0 g
s
.38865 .70378 m .39003 .72104 L .42176 .71765 L p .707 .577 .707 r
F P
0 g
s
.42176 .71765 m .42039 .70039 L .38865 .70378 L p .707 .577 .707 r
F P
0 g
s
.42039 .70039 m .42176 .71765 L .45099 .71019 L p .707 .577 .707 r
F P
0 g
s
.45099 .71019 m .44961 .69293 L .42039 .70039 L p .707 .577 .707 r
F P
0 g
s
.80377 .55071 m .80161 .60746 L .77414 .60356 L p .707 .577 .707 r
F P
0 g
s
.77414 .60356 m .7763 .54681 L .80377 .55071 L p .707 .577 .707 r
F P
0 g
s
.30707 .58864 m .30923 .53189 L .2966 .52623 L p .707 .577 .707 r
F P
0 g
s
.65905 .67245 m .66042 .68971 L .64427 .70278 L p .707 .577 .707 r
F P
0 g
s
.30642 .61208 m .30666 .64896 L .32772 .65565 L p .707 .577 .707 r
F P
0 g
s
.82365 .66616 m .82503 .68342 L .80387 .67435 L p .707 .577 .707 r
F P
0 g
s
.80387 .67435 m .8025 .65709 L .82365 .66616 L p .707 .577 .707 r
F P
0 g
s
.47137 .61418 m .47161 .65106 L .48798 .64318 L p .707 .577 .707 r
F P
0 g
s
.48798 .64318 m .48774 .60629 L .47137 .61418 L p .707 .577 .707 r
F P
0 g
s
.35889 .72005 m .35752 .70279 L .33002 .69749 L p .707 .577 .707 r
F P
0 g
s
.35752 .70279 m .35889 .72005 L .39003 .72104 L p .707 .577 .707 r
F P
0 g
s
.68183 .60167 m .68399 .54492 L .71333 .54377 L p .707 .577 .707 r
F P
0 g
s
.68143 .60874 m .68168 .64563 L .65763 .65174 L p .707 .577 .707 r
F P
0 g
s
.80128 .61027 m .80152 .64715 L .77407 .64268 L p .707 .577 .707 r
F P
0 g
s
.77407 .64268 m .77382 .60579 L .80128 .61027 L p .707 .577 .707 r
F P
0 g
s
.2966 .52623 m .29444 .58298 L .30707 .58864 L p .707 .577 .707 r
F P
0 g
s
.44961 .69293 m .45099 .71019 L .47484 .69939 L p .707 .577 .707 r
F P
0 g
s
.47484 .69939 m .47347 .68213 L .44961 .69293 L p .707 .577 .707 r
F P
0 g
s
.33002 .69749 m .3314 .71475 L .35889 .72005 L p .707 .577 .707 r
F P
0 g
s
.30666 .64896 m .30642 .61208 L .29382 .60382 L p .707 .577 .707 r
F P
0 g
s
.7763 .54681 m .77414 .60356 L .74298 .60116 L p .707 .577 .707 r
F P
0 g
s
.74298 .60116 m .74514 .54442 L .7763 .54681 L p .707 .577 .707 r
F P
0 g
s
.71333 .54377 m .71117 .60051 L .68183 .60167 L p .707 .577 .707 r
F P
0 g
s
.4904 .53559 m .48824 .59234 L .49527 .58707 L p .707 .577 .707 r
F P
0 g
s
.49527 .58707 m .49743 .53033 L .4904 .53559 L p .707 .577 .707 r
F P
0 g
s
.68168 .64563 m .68143 .60874 L .71082 .60499 L p .707 .577 .707 r
F P
0 g
s
.66042 .68971 m .65905 .67245 L .6829 .66165 L p .707 .577 .707 r
F P
0 g
s
.71117 .60051 m .71333 .54377 L .74514 .54442 L p .707 .577 .707 r
F P
0 g
s
.3314 .71475 m .33002 .69749 L .30887 .68842 L p .707 .577 .707 r
F P
0 g
s
.74514 .54442 m .74298 .60116 L .71117 .60051 L p .707 .577 .707 r
F P
0 g
s
.77382 .60579 m .77407 .64268 L .74289 .64086 L p .707 .577 .707 r
F P
0 g
s
.74289 .64086 m .74265 .60398 L .77382 .60579 L p .707 .577 .707 r
F P
0 g
s
.29382 .60382 m .29407 .64071 L .30666 .64896 L p .707 .577 .707 r
F P
0 g
s
.8025 .65709 m .80387 .67435 L .77638 .66905 L p .707 .577 .707 r
F P
0 g
s
.77638 .66905 m .775 .65179 L .8025 .65709 L p .707 .577 .707 r
F P
0 g
s
.6829 .66165 m .68428 .67891 L .66042 .68971 L p .707 .577 .707 r
F P
0 g
s
.47347 .68213 m .47484 .69939 L .49099 .68632 L p .707 .577 .707 r
F P
0 g
s
.49099 .68632 m .48962 .66906 L .47347 .68213 L p .707 .577 .707 r
F P
0 g
s
.29444 .58298 m .2966 .52623 L .29365 .52048 L p .707 .577 .707 r
F P
0 g
s
.71082 .60499 m .71106 .64188 L .68168 .64563 L p .707 .577 .707 r
F P
0 g
s
.30887 .68842 m .31024 .70568 L .3314 .71475 L p .707 .577 .707 r
F P
0 g
s
.71106 .64188 m .71082 .60499 L .74265 .60398 L p .707 .577 .707 r
F P
0 g
s
.48774 .60629 m .48798 .64318 L .49506 .6343 L p .707 .577 .707 r
F P
0 g
s
.49506 .6343 m .49482 .59741 L .48774 .60629 L p .707 .577 .707 r
F P
0 g
s
.74265 .60398 m .74289 .64086 L .71106 .64188 L p .707 .577 .707 r
F P
0 g
s
.68428 .67891 m .6829 .66165 L .71213 .65419 L p .707 .577 .707 r
F P
0 g
s
.29365 .52048 m .29149 .57723 L .29444 .58298 L p .707 .577 .707 r
F P
0 g
s
.775 .65179 m .77638 .66905 L .74524 .66806 L p .707 .577 .707 r
F P
0 g
s
.74524 .66806 m .74387 .65079 L .775 .65179 L p .707 .577 .707 r
F P
0 g
s
.31024 .70568 m .30887 .68842 L .29612 .67645 L p .707 .577 .707 r
F P
0 g
s
.29407 .64071 m .29382 .60382 L .29092 .59481 L p .707 .577 .707 r
F P
0 g
s
.71213 .65419 m .7135 .67145 L .68428 .67891 L p .707 .577 .707 r
F P
0 g
s
.7135 .67145 m .71213 .65419 L .74387 .65079 L p .707 .577 .707 r
F P
0 g
s
.49743 .53033 m .49527 .58707 L .49232 .58133 L p .707 .577 .707 r
F P
0 g
s
.49232 .58133 m .49448 .52458 L .49743 .53033 L p .707 .577 .707 r
F P
0 g
s
.74387 .65079 m .74524 .66806 L .7135 .67145 L p .707 .577 .707 r
F P
0 g
s
.29612 .67645 m .29749 .69371 L .31024 .70568 L p .707 .577 .707 r
F P
0 g
s
.48962 .66906 m .49099 .68632 L .49786 .67226 L p .707 .577 .707 r
F P
0 g
s
.49786 .67226 m .49648 .655 L .48962 .66906 L p .707 .577 .707 r
F P
0 g
s
.29092 .59481 m .29117 .6317 L .29407 .64071 L p .707 .577 .707 r
F P
0 g
s
.29149 .57723 m .29365 .52048 L .30067 .51522 L p .707 .577 .707 r
F P
0 g
s
.49482 .59741 m .49506 .6343 L .49216 .62529 L p .707 .577 .707 r
F P
0 g
s
.49216 .62529 m .49192 .5884 L .49482 .59741 L p .707 .577 .707 r
F P
0 g
s
.29749 .69371 m .29612 .67645 L .29302 .66277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30067 .51522 m .29851 .57197 L .29149 .57723 L p .707 .577 .707 r
F P
0 g
s
.29117 .6317 m .29092 .59481 L .298 .58593 L p .707 .577 .707 r
F P
0 g
s
.29302 .66277 m .2944 .68003 L .29749 .69371 L p .707 .577 .707 r
F P
0 g
s
.49448 .52458 m .49232 .58133 L .47968 .57567 L p .707 .577 .707 r
F P
0 g
s
.47968 .57567 m .48184 .51892 L .49448 .52458 L p .707 .577 .707 r
F P
0 g
s
.49648 .655 m .49786 .67226 L .49476 .65857 L p .707 .577 .707 r
F P
0 g
s
.49476 .65857 m .49339 .64131 L .49648 .655 L p .707 .577 .707 r
F P
0 g
s
.298 .58593 m .29825 .62281 L .29117 .6317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29851 .57197 m .30067 .51522 L .31698 .51096 L p .707 .577 .707 r
F P
0 g
s
.49192 .5884 m .49216 .62529 L .47957 .61703 L p .707 .577 .707 r
F P
0 g
s
.47957 .61703 m .47933 .58015 L .49192 .5884 L p .707 .577 .707 r
F P
0 g
s
.2944 .68003 m .29302 .66277 L .29989 .6487 L p .707 .577 .707 r
F P
0 g
s
.31698 .51096 m .31482 .56771 L .29851 .57197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29825 .62281 m .298 .58593 L .31437 .57804 L p .707 .577 .707 r
F P
0 g
s
.29989 .6487 m .30126 .66596 L .2944 .68003 L p .707 .577 .707 r
F P
0 g
s
.48184 .51892 m .47968 .57567 L .4586 .57064 L p .707 .577 .707 r
F P
0 g
s
.4586 .57064 m .46076 .51389 L .48184 .51892 L p .707 .577 .707 r
F P
0 g
s
.49339 .64131 m .49476 .65857 L .48201 .64661 L p .707 .577 .707 r
F P
0 g
s
.48201 .64661 m .48064 .62935 L .49339 .64131 L p .707 .577 .707 r
F P
0 g
s
.31437 .57804 m .31462 .61493 L .29825 .62281 L p .707 .577 .707 r
F P
0 g
s
.31482 .56771 m .31698 .51096 L .34098 .50811 L p .707 .577 .707 r
F P
0 g
s
.47933 .58015 m .47957 .61703 L .45851 .61034 L p .707 .577 .707 r
F P
0 g
s
.45851 .61034 m .45827 .57345 L .47933 .58015 L p .707 .577 .707 r
F P
0 g
s
.30126 .66596 m .29989 .6487 L .31604 .63563 L p .707 .577 .707 r
F P
0 g
s
.34098 .50811 m .33882 .56486 L .31482 .56771 L p .707 .577 .707 r
F P
0 g
s
.31462 .61493 m .31437 .57804 L .33842 .57193 L p .707 .577 .707 r
F P
0 g
s
.46076 .51389 m .4586 .57064 L .43113 .56674 L p .707 .577 .707 r
F P
0 g
s
.43113 .56674 m .43329 .50999 L .46076 .51389 L p .707 .577 .707 r
F P
0 g
s
.31604 .63563 m .31741 .65289 L .30126 .66596 L p .707 .577 .707 r
F P
0 g
s
.48064 .62935 m .48201 .64661 L .46086 .63753 L p .707 .577 .707 r
F P
0 g
s
.46086 .63753 m .45949 .62027 L .48064 .62935 L p .707 .577 .707 r
F P
0 g
s
.33882 .56486 m .34098 .50811 L .37032 .50695 L p .707 .577 .707 r
F P
0 g
s
.33842 .57193 m .33867 .60881 L .31462 .61493 L p .707 .577 .707 r
F P
0 g
s
.45827 .57345 m .45851 .61034 L .43106 .60586 L p .707 .577 .707 r
F P
0 g
s
.43106 .60586 m .43081 .56898 L .45827 .57345 L p .707 .577 .707 r
F P
0 g
s
.43329 .50999 m .43113 .56674 L .39997 .56435 L p .707 .577 .707 r
F P
0 g
s
.39997 .56435 m .40213 .5076 L .43329 .50999 L p .707 .577 .707 r
F P
0 g
s
.37032 .50695 m .36816 .5637 L .33882 .56486 L p .707 .577 .707 r
F P
0 g
s
.33867 .60881 m .33842 .57193 L .3678 .56818 L p .707 .577 .707 r
F P
0 g
s
.31741 .65289 m .31604 .63563 L .33989 .62484 L p .707 .577 .707 r
F P
0 g
s
.36816 .5637 m .37032 .50695 L .40213 .5076 L p .707 .577 .707 r
F P
0 g
s
.40213 .5076 m .39997 .56435 L .36816 .5637 L p .707 .577 .707 r
F P
0 g
s
.43081 .56898 m .43106 .60586 L .39988 .60405 L p .707 .577 .707 r
F P
0 g
s
.39988 .60405 m .39964 .56716 L .43081 .56898 L p .707 .577 .707 r
F P
0 g
s
.45949 .62027 m .46086 .63753 L .43337 .63224 L p .707 .577 .707 r
F P
0 g
s
.43337 .63224 m .43199 .61498 L .45949 .62027 L p .707 .577 .707 r
F P
0 g
s
.33989 .62484 m .34127 .6421 L .31741 .65289 L p .707 .577 .707 r
F P
0 g
s
.3678 .56818 m .36805 .60506 L .33867 .60881 L p .707 .577 .707 r
F P
0 g
s
.36805 .60506 m .3678 .56818 L .39964 .56716 L p .707 .577 .707 r
F P
0 g
s
.39964 .56716 m .39988 .60405 L .36805 .60506 L p .707 .577 .707 r
F P
0 g
s
.34127 .6421 m .33989 .62484 L .36912 .61738 L p .707 .577 .707 r
F P
0 g
s
.43199 .61498 m .43337 .63224 L .40223 .63124 L p .707 .577 .707 r
F P
0 g
s
.40223 .63124 m .40085 .61398 L .43199 .61498 L p .707 .577 .707 r
F P
0 g
s
.36912 .61738 m .37049 .63464 L .34127 .6421 L p .707 .577 .707 r
F P
0 g
s
.37049 .63464 m .36912 .61738 L .40085 .61398 L p .707 .577 .707 r
F P
0 g
s
.40085 .61398 m .40223 .63124 L .37049 .63464 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008=ooaD008Eo
o`00OGoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF2@00O7oo001gOol60008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol007=oo`@0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0075oo`00Kgoo10001UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000KGoo001]Ool20000
0eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH3001ZOol006]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Qoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00P00IWoo001XOol20006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06=oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo
069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00
IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo069oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Aoo`00GWoo6@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P00I7oo001HOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol005Eoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH6000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000I7oo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=o
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001TOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20007OolI0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008003Aoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`00<Goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002ioo`00DWoo00<005YF000015YF00@005YFFUIJEQT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00DWoo00<005YF
00000UYF1`001eYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001BOol00`00FUH000030005FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000080003FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059o
o`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF000000020002FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0059oo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP000080009JEP@000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00E7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool005=oo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP`00003FUH005YF00IJEPP00003FUH0000000H000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP0009JEP03
001JEUYF00AJEPP000AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0015YF00<005YFFUH01EYF2@0015YF
00@005YFFUIJEPP00003FUH0000000<000AJEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000AJ
EP04001JEUYFFUH90002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60004FUH0
0`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00
FUH00`001EYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPT00003FUH005YF
009JEP8002ioo`00DWoo00<005YF000015YF100027oo00@005YFFUH000AJEPl000QJEP<00004FUH0
05YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUH000050002FUH2000^Ool0059oo`03001JEP00009JEP800003FUH0000000<000Io
o`03001JEP0000D000AJEP03001JEUYF00IJEP03001JEP0000<00007FUH00000001JEP00FUH00P00
0UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP0000000P00;Woo001BOol00`00FUH000030005FUH00`00FUH0000700000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP02FUH40004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1P00;Woo
001BOol00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00;Woo
000gOolM0003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000_
Ool0035oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001J
EUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH300000eYF
001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP04001JEP000006FUH00`00FUIJEP04FUH;
0003FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH010001EYF1P000eYF00<005YFFUH01UYF
00<005YF00000`0015YF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000IJEPD000QJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0
0005FUH005YFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP<000=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH00UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000HOol4
00000eYF001JEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000AJEP00FUH000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YF0000
0`008Woo10000eYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP04001JEP000003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP<0019ooa40
00Aoo`H000=JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF0P000eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF1@0000=JEP00FUH01EYF0`000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUH005YF001JEP020003FUH50007Ool60004FUH00`00FUIJEP06
FUH01000FUIJEUYF1@000UYF00@005YFFUH0009JEP8002ioo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80009JEP03
001JEUYF00=JEPP000AJEP03001JEUYF009JEP`000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH01000FUIJEUYF1`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF10000eYF1000;Woo000/Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF
00<005YFFUH00eYF00D005YFFUIJEP00009JEPX000IJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001J
EUYF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF008000=JEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=J
EP<00003FUH005YF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP80
0004FUH00000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH<0003FUH80004FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80
00IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF008000EJEP03001JEUYF009JEP8000IJEPH0
00=JEP03001JEUYF00EJEPD000EJEP04001JEP00000_Ool002]oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF0080
009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH40006FUH00`00FUH000020008FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP09FUH00`00FUH00004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200001EYF001JEUYF0000;goo
000[Ool00`00FUH00004FUH01000FUIJEUYF6@0015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000002FUH00`00Oomoo`0]Ool002]oo`03001JEP00009JEPL000MJEP03001J
EUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00005FUH00`00FUIJEP020002FUH00`00
FUIJEP03FUH50005FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YF000000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009oo`04001J
EUYF000^Ool002]oo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00L000=JEP03001JEUYF0080009JEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00EJEP8000AJEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030006Ool3000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH20002
FUH40002FUH20002FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP03FUH20006FUH30008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YFFUH0009JEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000]oo`8002io
o`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEPD00003FUH000000080009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEP0000<00003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH30002FUH00`00FUIJEP04FUHJ000@Ool2000^
Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30004FUH01000FUIJEUYF2@001EYF00@005YFFUIJEPL000EJEP03001JEUYF009J
EP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH01@00FUIJEUYF000097oo00@005YF000002eoo`00;Goo0P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF2P0025YF00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF008000AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo029oo`04001JEUYF000]Ool002moo`@000=JEP03001JEUYF00EJEPP000AJ
EP03001JEUYF009JEPP00004FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8002=oo`80009J
EP03001oogoo02]oo`00<goo2`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P008Woo00D005YF001JEP0002ioo`00<Woo10000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP04001JEUYF
FUH20009Ool3000EOol01000FUIJEUYF0P00;Woo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0004FUH00`00FUIJEP02FUH6
000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000BOol20004FUH00`00Oomo
o`0]Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00006Ool005YFFUH005YF2@001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP800003FUH005YF009JEP03001JEUYF00=JEP04001JEUYFFUH20008Ool5000@Ool200000eYF001J
EP03FUH00`00Oomoo`0]Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00D000AJEP04001JEUYF
FUH20008Ool5000>Ool20003FUH01@00FUIJEUYF0000<7oo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH01P0000=JEP00FUH00UYF0P002Goo0`002goo10001EYF00@005YF0000035oo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF000015YF1P000UYF0P004goo10000UYF00<005YFFUH015YF0P00<goo000[
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUH00006000<Ool70006FUH00`00FUIJEP03
FUH2000dOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00=JEPl000AJEP03001JEUYF
00IJEP04001JEUYFFUH2000fOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009J
EQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>7oo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH60008OolG0004FUH0
0`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH=000;FUH90008
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH700000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH3000jOol002]oo`03001JEP0000AJEP03001JEP0000<000Qoo`H000AJ
EP03001JEUYF00IJEP04001JEUYFFUH500001Woo00000000FUH0009JEP80009JEP03001JEUYF00AJ
EP03001JEUYF00=JEP/000]JEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@003eoo`00:goo00<005YF00000eYF10001goo100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF0P000UYF00<005YFFUH015YF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00@Goo000[Ool01000FUH005YF0P0015YF1`001EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEP<000=J
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP800003Ool0000000h004Qo
o`00:goo00H005YF000005YF0005FUH200000eYF001JEP07FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000AJEP000000009JEP04001JEUYFFUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40005FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000Egoo000[Ool20003FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF2P0015YF2@0015YF00<005YFFUH00UYF1@000UYF00@005YF000000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP05001J
EUYFFUH00004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EWoo000[Ool20003
FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
15YF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00:goo0P000eYF0`001eYF00<005YF00000P00
1eYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00H005YFFUH005YF
0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000[Ool20002FUH200000eYF001JEP05FUH300000eYF001JEP07FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH2000015YF001JEUYF0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002aoo`03001JEP00
00AJEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH000000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP04001JEP000006FUH00`00FUIJEP06
FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0
02eoo`8000AJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEP00001oo`030004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP070004FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUH00002FUH400000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH600000eYF001JEP02FUH2001EOol0
02aoo`03001JEP00008000Aoo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<000Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP00
00<000=JEP8005Eoo`00;7oo00<005YF00002Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF1P002Woo0`000Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH00UYF0`00
00=JEP000000EGoo000/Ool2000>OolH000@Ool00`00FUH00004Ool20007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF1@00
1UYF00<005YFFUH00eYF1@00EGoo000/Ool2000eOol200000eYF001oo`05Ool30004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0
00001EYF10000UYF00<005YFFUH00eYF1@00EGoo000/Ool2000cOol200000eYF0000000:Ool30000
0eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
00000eYF001JEP06FUH00`00FUH000030004FUH01@00FUH005YF0000EGoo000/Ool3000aOol01000
FUIJEUYF0P003Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01P0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP8005Eoo`00;7oo0`00
;goo0P0015YF00<007ooOol04goo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF200000=JEP00
000010000eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP03001oogoo05Aoo`00
;7oo0P0000=JEP00Ool0:goo0P0000=JEP00FUH00eYF00<007ooOol07Woo6`0025YF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001FOol002eoo`03001JEUYF008002Qo
o`8000=JEP05001JEUYFFUH0000ZOol20004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001oo`1DOol002eoo`05001J
EUYF001JEP03000ROol30005FUH01000FUH00000:goo0P000eYF00D005YFFUIJEP0000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=oo`8005Eoo`00
;Woo00<005YF000015YF0`006goo100000=JEP00FUH01EYF0P00;7oo00D005YFFUH005YF00@00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40005
Ool2001EOol002moo`03001JEP0000AJEP03001JEP0000<0011oo`L000EJEP03001JEUYF00AJEP03
001oogoo02]oo`03001JEUYF008000Aoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Uoo`8005Eoo`00<7oo0P0015YF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
00@005YFFUIJEP8002ioo`04001JEUYF000:Ool90004FUH00`00FUIJEP02FUH9000?Ool01000FUH0
0000E7oo000aOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000<7oo00<005YF000057oo2@0067oo00@005YFFUH005Aoo`00<goo0`0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000<goo0P00=7oo0P00
0UYF00<007ooOol0DWoo000fOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
000gOol00`00Oomoo`0aOol2000015YF001JEP00EGoo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH7000kOol2000`Ool20004FUH2001EOol003eoo`l0049oo`04001JEP00000/Ool20000
0eYF001JEP03FUH00`00Oomoo`1DOol008ioo`80009JEP03001oogoo02Moo`8000=JEP03001JEUYF
009JEP03001oogoo05Aoo`00Sgoo00<005YFFUH00`0097oo0`001EYF00<005YFFUH00P00Egoo002?
Ool01000FUIJEP000UYF0P007goo0`0000=JEP00FUH01EYF0`00FGoo002@Ool00`00FUH00004FUH5
000GOol30004FUH00`00FUIJEP03FUH2001KOol0095oo`8000EJEP04001JEUYFFUH80009Ool60007
FUH01000FUIJEUYF0P00GGoo002BOol00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@00
15YF00<005YFFUH01UYF00@005YF000005moo`00Tgoo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`00HGoo002EOol200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP04001TOol009Moo`D000AJEP03001JEUYF00IJEP03001J
EUYF009JEPL006Qoo`00W7oo4P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]13\[InvisibleSpace]"     "\
\[InvisibleSpace]5.628853194275645`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 13, "     ", 5.6288531942756448, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58685 .73685 m .59278 .68225 L .56178 .677 L p .707 .577 .707 r
F P
0 g
s
.59278 .68225 m .58685 .73685 L .61852 .73909 L p .707 .577 .707 r
F P
0 g
s
.61852 .73909 m .62445 .68449 L .59278 .68225 L p .707 .577 .707 r
F P
0 g
s
.62445 .68449 m .61852 .73909 L .64778 .73811 L p .707 .577 .707 r
F P
0 g
s
.64778 .73811 m .6537 .6835 L .62445 .68449 L p .707 .577 .707 r
F P
0 g
s
.55586 .73161 m .56178 .677 L .53451 .66926 L p .707 .577 .707 r
F P
0 g
s
.56178 .677 m .55586 .73161 L .58685 .73685 L p .707 .577 .707 r
F P
0 g
s
.6537 .6835 m .64778 .73811 L .67175 .734 L p .707 .577 .707 r
F P
0 g
s
.67175 .734 m .67767 .67939 L .6537 .6835 L p .707 .577 .707 r
F P
0 g
s
.52858 .72387 m .53451 .66926 L .51361 .65979 L p .707 .577 .707 r
F P
0 g
s
.53451 .66926 m .52858 .72387 L .55586 .73161 L p .707 .577 .707 r
F P
0 g
s
.58564 .7833 m .5858 .74626 L .55463 .74422 L p .707 .577 .707 r
F P
0 g
s
.5858 .74626 m .58564 .7833 L .61747 .78264 L p .707 .577 .707 r
F P
0 g
s
.61747 .78264 m .61763 .74561 L .5858 .74626 L p .707 .577 .707 r
F P
0 g
s
.61763 .74561 m .61747 .78264 L .64685 .77936 L p .707 .577 .707 r
F P
0 g
s
.64685 .77936 m .64702 .74233 L .61763 .74561 L p .707 .577 .707 r
F P
0 g
s
.55446 .78126 m .55463 .74422 L .52717 .73969 L p .707 .577 .707 r
F P
0 g
s
.55463 .74422 m .55446 .78126 L .58564 .7833 L p .707 .577 .707 r
F P
0 g
s
.64702 .74233 m .64685 .77936 L .67091 .77378 L p .707 .577 .707 r
F P
0 g
s
.67091 .77378 m .67107 .73674 L .64702 .74233 L p .707 .577 .707 r
F P
0 g
s
.59231 .82447 m .58929 .80589 L .55854 .80918 L p .707 .577 .707 r
F P
0 g
s
.58929 .80589 m .59231 .82447 L .62377 .81901 L p .707 .577 .707 r
F P
0 g
s
.62377 .81901 m .62074 .80042 L .58929 .80589 L p .707 .577 .707 r
F P
0 g
s
.67767 .67939 m .67175 .734 L .68809 .72716 L p .707 .577 .707 r
F P
0 g
s
.68809 .72716 m .69401 .67255 L .67767 .67939 L p .707 .577 .707 r
F P
0 g
s
.62074 .80042 m .62377 .81901 L .65285 .81191 L p .707 .577 .707 r
F P
0 g
s
.65285 .81191 m .64982 .79332 L .62074 .80042 L p .707 .577 .707 r
F P
0 g
s
.52717 .73969 m .52701 .77673 L .55446 .78126 L p .707 .577 .707 r
F P
0 g
s
.51361 .65979 m .50769 .71439 L .52858 .72387 L p .707 .577 .707 r
F P
0 g
s
.55854 .80918 m .56156 .82777 L .59231 .82447 L p .707 .577 .707 r
F P
0 g
s
.50769 .71439 m .51361 .65979 L .50115 .64951 L p .707 .577 .707 r
F P
0 g
s
.52701 .77673 m .52717 .73969 L .50611 .73311 L p .707 .577 .707 r
F P
0 g
s
.56156 .82777 m .55854 .80918 L .53151 .80999 L p .707 .577 .707 r
F P
0 g
s
.53151 .80999 m .53453 .82857 L .56156 .82777 L p .707 .577 .707 r
F P
0 g
s
.64982 .79332 m .65285 .81191 L .6767 .80387 L p .707 .577 .707 r
F P
0 g
s
.6767 .80387 m .67368 .78529 L .64982 .79332 L p .707 .577 .707 r
F P
0 g
s
.50611 .73311 m .50595 .77015 L .52701 .77673 L p .707 .577 .707 r
F P
0 g
s
.67107 .73674 m .67091 .77378 L .68728 .76643 L p .707 .577 .707 r
F P
0 g
s
.68728 .76643 m .68744 .72939 L .67107 .73674 L p .707 .577 .707 r
F P
0 g
s
.50115 .64951 m .49522 .70412 L .50769 .71439 L p .707 .577 .707 r
F P
0 g
s
.53453 .82857 m .53151 .80999 L .51083 .80822 L p .707 .577 .707 r
F P
0 g
s
.69401 .67255 m .68809 .72716 L .6952 .71827 L p .707 .577 .707 r
F P
0 g
s
.6952 .71827 m .70113 .66366 L .69401 .67255 L p .707 .577 .707 r
F P
0 g
s
.51083 .80822 m .51386 .8268 L .53453 .82857 L p .707 .577 .707 r
F P
0 g
s
.50595 .77015 m .50611 .73311 L .49352 .72513 L p .707 .577 .707 r
F P
0 g
s
.67368 .78529 m .6767 .80387 L .69301 .79568 L p .707 .577 .707 r
F P
0 g
s
.69301 .79568 m .68998 .7771 L .67368 .78529 L p .707 .577 .707 r
F P
0 g
s
.49522 .70412 m .50115 .64951 L .49834 .63943 L p .707 .577 .707 r
F P
0 g
s
.49352 .72513 m .49336 .76216 L .50595 .77015 L p .707 .577 .707 r
F P
0 g
s
.68744 .72939 m .68728 .76643 L .69436 .75805 L p .707 .577 .707 r
F P
0 g
s
.69436 .75805 m .69452 .72101 L .68744 .72939 L p .707 .577 .707 r
F P
0 g
s
.51386 .8268 m .51083 .80822 L .49854 .80406 L p .707 .577 .707 r
F P
0 g
s
.49834 .63943 m .49241 .69404 L .49522 .70412 L p .707 .577 .707 r
F P
0 g
s
.49854 .80406 m .50157 .82264 L .51386 .8268 L p .707 .577 .707 r
F P
0 g
s
.70113 .66366 m .6952 .71827 L .69238 .70819 L p .707 .577 .707 r
F P
0 g
s
.69238 .70819 m .69831 .65358 L .70113 .66366 L p .707 .577 .707 r
F P
0 g
s
.49336 .76216 m .49352 .72513 L .49063 .71652 L p .707 .577 .707 r
F P
0 g
s
.68998 .7771 m .69301 .79568 L .70016 .78814 L p .707 .577 .707 r
F P
0 g
s
.70016 .78814 m .69713 .76955 L .68998 .7771 L p .707 .577 .707 r
F P
0 g
s
.49241 .69404 m .49834 .63943 L .50545 .63054 L p .707 .577 .707 r
F P
0 g
s
.49063 .71652 m .49046 .75356 L .49336 .76216 L p .707 .577 .707 r
F P
0 g
s
.50545 .63054 m .49952 .68514 L .49241 .69404 L p .707 .577 .707 r
F P
0 g
s
.49046 .75356 m .49063 .71652 L .49771 .70813 L p .707 .577 .707 r
F P
0 g
s
.49771 .70813 m .49755 .74517 L .49046 .75356 L p .707 .577 .707 r
F P
0 g
s
.4941 .82315 m .50516 .32258 L .46117 .31891 L p .707 .577 .707 r
F P
0 g
s
.50157 .82264 m .49854 .80406 L .49584 .7979 L p .707 .577 .707 r
F P
0 g
s
.49584 .7979 m .49887 .81649 L .50157 .82264 L p .707 .577 .707 r
F P
0 g
s
.49952 .68514 m .50545 .63054 L .52179 .6237 L p .707 .577 .707 r
F P
0 g
s
.49887 .81649 m .49584 .7979 L .50299 .79036 L p .707 .577 .707 r
F P
0 g
s
.52179 .6237 m .51586 .6783 L .49952 .68514 L p .707 .577 .707 r
F P
0 g
s
.50299 .79036 m .50602 .80895 L .49887 .81649 L p .707 .577 .707 r
F P
0 g
s
.49755 .74517 m .49771 .70813 L .51408 .70079 L p .707 .577 .707 r
F P
0 g
s
.51586 .6783 m .52179 .6237 L .54576 .61959 L p .707 .577 .707 r
F P
0 g
s
.51408 .70079 m .51392 .73782 L .49755 .74517 L p .707 .577 .707 r
F P
0 g
s
.54576 .61959 m .53983 .67419 L .51586 .6783 L p .707 .577 .707 r
F P
0 g
s
.50602 .80895 m .50299 .79036 L .51929 .78217 L p .707 .577 .707 r
F P
0 g
s
.51929 .78217 m .52232 .80075 L .50602 .80895 L p .707 .577 .707 r
F P
0 g
s
.51392 .73782 m .51408 .70079 L .53813 .6952 L p .707 .577 .707 r
F P
0 g
s
.53813 .6952 m .53797 .73224 L .51392 .73782 L p .707 .577 .707 r
F P
0 g
s
.52232 .80075 m .51929 .78217 L .54315 .77413 L p .707 .577 .707 r
F P
0 g
s
.54315 .77413 m .54618 .79272 L .52232 .80075 L p .707 .577 .707 r
F P
0 g
s
.50516 .32258 m .4941 .82315 L .53903 .82294 L p .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .54576 .61959 L .57408 .61863 L p .707 .577 .707 r
F P
0 g
s
.57408 .61863 m .57501 .6186 L p .57356 .6209 L .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .57408 .61863 L .57356 .6209 L .707 .577 .707 r
F
.53797 .73224 m .53813 .6952 L .56751 .69192 L p F P
0 g
s
.5501 .32237 m .50516 .32258 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.53903 .82294 m .54033 .76419 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.57501 .6186 m .56908 .67321 L .53983 .67419 L p .707 .577 .707 r
F P
0 g
s
.56751 .69192 m .56735 .72896 L .53797 .73224 L p .707 .577 .707 r
F P
0 g
s
.54033 .76419 m .5501 .32237 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.56908 .67321 m .57501 .6186 L .60668 .62084 L p .707 .577 .707 r
F P
0 g
s
.60668 .62084 m .60076 .67545 L .56908 .67321 L p .707 .577 .707 r
F P
0 g
s
.56735 .72896 m .56751 .69192 L .59935 .69127 L p .707 .577 .707 r
F P
0 g
s
.59935 .69127 m .59919 .72831 L .56735 .72896 L p .707 .577 .707 r
F P
0 g
s
.54618 .79272 m .54315 .77413 L .57223 .76703 L p .707 .577 .707 r
F P
0 g
s
.57223 .76703 m .57526 .78562 L .54618 .79272 L p .707 .577 .707 r
F P
0 g
s
.57526 .78562 m .57223 .76703 L .60368 .76157 L p .707 .577 .707 r
F P
0 g
s
.60368 .76157 m .60671 .78015 L .57526 .78562 L p .707 .577 .707 r
F P
0 g
s
.5501 .32237 m .53903 .82294 L .5805 .81887 L p .707 .577 .707 r
F P
0 g
s
.5805 .81887 m .59157 .3183 L .5501 .32237 L p .707 .577 .707 r
F P
0 g
s
.4501 .81948 m .46117 .31891 L .42241 .31173 L p .707 .577 .707 r
F P
0 g
s
.46117 .31891 m .4501 .81948 L .4941 .82315 L p .707 .577 .707 r
F P
0 g
s
.69452 .72101 m .69436 .75805 L .69146 .74944 L p .707 .577 .707 r
F P
0 g
s
.69146 .74944 m .69163 .7124 L .69452 .72101 L p .707 .577 .707 r
F P
0 g
s
.63768 .62609 m .63175 .6807 L .60076 .67545 L p .707 .577 .707 r
F P
0 g
s
.60076 .67545 m .60668 .62084 L .63768 .62609 L p .707 .577 .707 r
F P
0 g
s
.63052 .69331 m .63036 .73035 L .59919 .72831 L p .707 .577 .707 r
F P
0 g
s
.59919 .72831 m .59935 .69127 L .63052 .69331 L p .707 .577 .707 r
F P
0 g
s
.63443 .75827 m .63746 .77686 L .60671 .78015 L p .707 .577 .707 r
F P
0 g
s
.60671 .78015 m .60368 .76157 L .63443 .75827 L p .707 .577 .707 r
F P
0 g
s
.59157 .3183 m .5805 .81887 L .61446 .81134 L p .707 .577 .707 r
F P
0 g
s
.61446 .81134 m .62552 .31077 L .59157 .3183 L p .707 .577 .707 r
F P
0 g
s
.69831 .65358 m .69238 .70819 L .67992 .69791 L p .707 .577 .707 r
F P
0 g
s
.67992 .69791 m .68585 .6433 L .69831 .65358 L p .707 .577 .707 r
F P
0 g
s
.69713 .76955 m .70016 .78814 L .69746 .78198 L p .707 .577 .707 r
F P
0 g
s
.69746 .78198 m .69443 .7634 L .69713 .76955 L p .707 .577 .707 r
F P
0 g
s
.41135 .8123 m .42241 .31173 L .3927 .30173 L p .707 .577 .707 r
F P
0 g
s
.42241 .31173 m .41135 .8123 L .4501 .81948 L p .707 .577 .707 r
F P
0 g
s
.24384 .72972 m .24977 .67512 L .21878 .66987 L p .707 .577 .707 r
F P
0 g
s
.24977 .67512 m .24384 .72972 L .27551 .73196 L p .707 .577 .707 r
F P
0 g
s
.27551 .73196 m .28144 .67736 L .24977 .67512 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69163 .7124 m .69146 .74944 L .67887 .74146 L p .707 .577 .707 r
F P
0 g
s
.67887 .74146 m .67903 .70442 L .69163 .7124 L p .707 .577 .707 r
F P
0 g
s
.28144 .67736 m .27551 .73196 L .30477 .73098 L p .707 .577 .707 r
F P
0 g
s
.30477 .73098 m .31069 .67637 L .28144 .67736 L p .707 .577 .707 r
F P
0 g
s
.21285 .72448 m .21878 .66987 L .1915 .66213 L p .707 .577 .707 r
F P
0 g
s
.21878 .66987 m .21285 .72448 L .24384 .72972 L p .707 .577 .707 r
F P
0 g
s
.66495 .63383 m .65903 .68843 L .63175 .6807 L p .707 .577 .707 r
F P
0 g
s
.63175 .6807 m .63768 .62609 L .66495 .63383 L p .707 .577 .707 r
F P
0 g
s
.65798 .69784 m .65782 .73488 L .63036 .73035 L p .707 .577 .707 r
F P
0 g
s
.63036 .73035 m .63052 .69331 L .65798 .69784 L p .707 .577 .707 r
F P
0 g
s
.63746 .77686 m .63443 .75827 L .66147 .75747 L p .707 .577 .707 r
F P
0 g
s
.62552 .31077 m .61446 .81134 L .63756 .8011 L p .707 .577 .707 r
F P
0 g
s
.66147 .75747 m .66449 .77605 L .63746 .77686 L p .707 .577 .707 r
F P
0 g
s
.63756 .8011 m .64863 .30053 L .62552 .31077 L p .707 .577 .707 r
F P
0 g
s
.68585 .6433 m .67992 .69791 L .65903 .68843 L p .707 .577 .707 r
F P
0 g
s
.65903 .68843 m .66495 .63383 L .68585 .6433 L p .707 .577 .707 r
F P
0 g
s
.69443 .7634 m .69746 .78198 L .68517 .77782 L p .707 .577 .707 r
F P
0 g
s
.68517 .77782 m .68214 .75924 L .69443 .7634 L p .707 .577 .707 r
F P
0 g
s
.31069 .67637 m .30477 .73098 L .32874 .72687 L p .707 .577 .707 r
F P
0 g
s
.32874 .72687 m .33466 .67226 L .31069 .67637 L p .707 .577 .707 r
F P
0 g
s
.18557 .71674 m .1915 .66213 L .1706 .65266 L p .707 .577 .707 r
F P
0 g
s
.1915 .66213 m .18557 .71674 L .21285 .72448 L p .707 .577 .707 r
F P
0 g
s
.38163 .8023 m .3927 .30173 L .37493 .2899 L p .707 .577 .707 r
F P
0 g
s
.3927 .30173 m .38163 .8023 L .41135 .8123 L p .707 .577 .707 r
F P
0 g
s
.24263 .79763 m .24279 .76059 L .21162 .75855 L p .707 .577 .707 r
F P
0 g
s
.24279 .76059 m .24263 .79763 L .27446 .79698 L p .707 .577 .707 r
F P
0 g
s
.27446 .79698 m .27463 .75994 L .24279 .76059 L p .707 .577 .707 r
F P
0 g
s
.27463 .75994 m .27446 .79698 L .30385 .7937 L p .707 .577 .707 r
F P
0 g
s
.30385 .7937 m .30401 .75666 L .27463 .75994 L p .707 .577 .707 r
F P
0 g
s
.67903 .70442 m .67887 .74146 L .65782 .73488 L p .707 .577 .707 r
F P
0 g
s
.65782 .73488 m .65798 .69784 L .67903 .70442 L p .707 .577 .707 r
F P
0 g
s
.21146 .79559 m .21162 .75855 L .18416 .75402 L p .707 .577 .707 r
F P
0 g
s
.21162 .75855 m .21146 .79559 L .24263 .79763 L p .707 .577 .707 r
F P
0 g
s
.33466 .67226 m .32874 .72687 L .34508 .72003 L p .707 .577 .707 r
F P
0 g
s
.34508 .72003 m .351 .66543 L .33466 .67226 L p .707 .577 .707 r
F P
0 g
s
.1706 .65266 m .16468 .70727 L .18557 .71674 L p .707 .577 .707 r
F P
0 g
s
.2493 .83071 m .24628 .81213 L .21553 .81542 L p .707 .577 .707 r
F P
0 g
s
.24628 .81213 m .2493 .83071 L .28076 .82525 L p .707 .577 .707 r
F P
0 g
s
.28076 .82525 m .27773 .80666 L .24628 .81213 L p .707 .577 .707 r
F P
0 g
s
.27773 .80666 m .28076 .82525 L .30984 .81815 L p .707 .577 .707 r
F P
0 g
s
.30984 .81815 m .30681 .79956 L .27773 .80666 L p .707 .577 .707 r
F P
0 g
s
.30401 .75666 m .30385 .7937 L .3279 .78811 L p .707 .577 .707 r
F P
0 g
s
.3279 .78811 m .32806 .75108 L .30401 .75666 L p .707 .577 .707 r
F P
0 g
s
.16468 .70727 m .1706 .65266 L .15814 .64238 L p .707 .577 .707 r
F P
0 g
s
.21553 .81542 m .21856 .83401 L .2493 .83071 L p .707 .577 .707 r
F P
0 g
s
.18416 .75402 m .184 .79106 L .21146 .79559 L p .707 .577 .707 r
F P
0 g
s
.68214 .75924 m .68517 .77782 L .66449 .77605 L p .707 .577 .707 r
F P
0 g
s
.66449 .77605 m .66147 .75747 L .68214 .75924 L p .707 .577 .707 r
F P
0 g
s
.64863 .30053 m .63756 .8011 L .64757 .78913 L p .707 .577 .707 r
F P
0 g
s
.64757 .78913 m .65863 .28856 L .64863 .30053 L p .707 .577 .707 r
F P
0 g
s
.21856 .83401 m .21553 .81542 L .1885 .81623 L p .707 .577 .707 r
F P
0 g
s
.184 .79106 m .18416 .75402 L .16311 .74744 L p .707 .577 .707 r
F P
0 g
s
.1885 .81623 m .19152 .83481 L .21856 .83401 L p .707 .577 .707 r
F P
0 g
s
.30681 .79956 m .30984 .81815 L .3337 .81011 L p .707 .577 .707 r
F P
0 g
s
.3337 .81011 m .33067 .79153 L .30681 .79956 L p .707 .577 .707 r
F P
0 g
s
.16311 .74744 m .16294 .78448 L .184 .79106 L p .707 .577 .707 r
F P
0 g
s
.15814 .64238 m .15221 .69699 L .16468 .70727 L p .707 .577 .707 r
F P
0 g
s
.36386 .79047 m .37493 .2899 L .37084 .27739 L p .707 .577 .707 r
F P
0 g
s
.37493 .2899 m .36386 .79047 L .38163 .8023 L p .707 .577 .707 r
F P
0 g
s
.32806 .75108 m .3279 .78811 L .34427 .78077 L p .707 .577 .707 r
F P
0 g
s
.34427 .78077 m .34443 .74373 L .32806 .75108 L p .707 .577 .707 r
F P
0 g
s
.351 .66543 m .34508 .72003 L .35219 .71114 L p .707 .577 .707 r
F P
0 g
s
.35219 .71114 m .35812 .65653 L .351 .66543 L p .707 .577 .707 r
F P
0 g
s
.19152 .83481 m .1885 .81623 L .16782 .81446 L p .707 .577 .707 r
F P
0 g
s
.16782 .81446 m .17085 .83304 L .19152 .83481 L p .707 .577 .707 r
F P
0 g
s
.15221 .69699 m .15814 .64238 L .15533 .6323 L p .707 .577 .707 r
F P
0 g
s
.33067 .79153 m .3337 .81011 L .35 .80192 L p .707 .577 .707 r
F P
0 g
s
.35 .80192 m .34697 .78333 L .33067 .79153 L p .707 .577 .707 r
F P
0 g
s
.16294 .78448 m .16311 .74744 L .15051 .73946 L p .707 .577 .707 r
F P
0 g
s
.15051 .73946 m .15035 .7765 L .16294 .78448 L p .707 .577 .707 r
F P
0 g
s
.65455 .27605 m .64348 .77662 L .62571 .76479 L p .707 .577 .707 r
F P
0 g
s
.64489 .62236 m .64505 .62086 L p .63835 .55747 L .707 .577 .707 r
F P
0 g
s
.65863 .28856 m .64757 .78913 L .64456 .77994 L p .707 .577 .707 r
F P
0 g
s
.64469 .73756 m .65863 .28856 L .64456 .77994 L .707 .577 .707 r
F
.64348 .77662 m .65455 .27605 L .65863 .28856 L p F P
0 g
s
.64505 .62086 m .65082 .56775 L .64523 .56314 L p .707 .577 .707 r
F P
0 g
s
.64523 .56314 m .63835 .55747 L p .64505 .62086 L .707 .577 .707 r
F P
0 g
s
.64456 .77994 m .64348 .77662 L p .64469 .73756 L .707 .577 .707 r
F P
0 g
s
.15533 .6323 m .1494 .68691 L .15221 .69699 L p .707 .577 .707 r
F P
0 g
s
.34443 .74373 m .34427 .78077 L .35135 .77238 L p .707 .577 .707 r
F P
0 g
s
.35135 .77238 m .35151 .73534 L .34443 .74373 L p .707 .577 .707 r
F P
0 g
s
.17085 .83304 m .16782 .81446 L .15553 .8103 L p .707 .577 .707 r
F P
0 g
s
.15553 .8103 m .15856 .82888 L .17085 .83304 L p .707 .577 .707 r
F P
0 g
s
.35812 .65653 m .35219 .71114 L .34938 .70106 L p .707 .577 .707 r
F P
0 g
s
.34938 .70106 m .3553 .64645 L .35812 .65653 L p .707 .577 .707 r
F P
0 g
s
.34697 .78333 m .35 .80192 L .35715 .79438 L p .707 .577 .707 r
F P
0 g
s
.35715 .79438 m .35412 .77579 L .34697 .78333 L p .707 .577 .707 r
F P
0 g
s
.1494 .68691 m .15533 .6323 L .16244 .62341 L p .707 .577 .707 r
F P
0 g
s
.15035 .7765 m .15051 .73946 L .14762 .73086 L p .707 .577 .707 r
F P
0 g
s
.37084 .27739 m .35978 .77796 L .36386 .79047 L p .707 .577 .707 r
F P
0 g
s
.35978 .77796 m .37084 .27739 L .38085 .26543 L p .707 .577 .707 r
F P
0 g
s
.14762 .73086 m .14745 .76789 L .15035 .7765 L p .707 .577 .707 r
F P
0 g
s
.15856 .82888 m .15553 .8103 L .15283 .80414 L p .707 .577 .707 r
F P
0 g
s
.16244 .62341 m .15651 .67801 L .1494 .68691 L p .707 .577 .707 r
F P
0 g
s
.35151 .73534 m .35135 .77238 L .34845 .76377 L p .707 .577 .707 r
F P
0 g
s
.34845 .76377 m .34862 .72674 L .35151 .73534 L p .707 .577 .707 r
F P
0 g
s
.15283 .80414 m .15586 .82273 L .15856 .82888 L p .707 .577 .707 r
F P
0 g
s
.3553 .64645 m .34938 .70106 L .33691 .69078 L p .707 .577 .707 r
F P
0 g
s
.33691 .69078 m .34284 .63617 L .3553 .64645 L p .707 .577 .707 r
F P
0 g
s
.35412 .77579 m .35715 .79438 L .35445 .78822 L p .707 .577 .707 r
F P
0 g
s
.35445 .78822 m .35142 .76964 L .35412 .77579 L p .707 .577 .707 r
F P
0 g
s
.15651 .67801 m .16244 .62341 L .17878 .61657 L p .707 .577 .707 r
F P
0 g
s
.62571 .76479 m .63678 .26422 L .65455 .27605 L p .707 .577 .707 r
F P
0 g
s
.14745 .76789 m .14762 .73086 L .1547 .72247 L p .707 .577 .707 r
F P
0 g
s
.1547 .72247 m .15454 .75951 L .14745 .76789 L p .707 .577 .707 r
F P
0 g
s
.36978 .766 m .38085 .26543 L .40395 .25518 L p .707 .577 .707 r
F P
0 g
s
.38085 .26543 m .36978 .766 L .35978 .77796 L p .707 .577 .707 r
F P
0 g
s
.17878 .61657 m .17285 .67117 L .15651 .67801 L p .707 .577 .707 r
F P
0 g
s
.34862 .72674 m .34845 .76377 L .33586 .75579 L p .707 .577 .707 r
F P
0 g
s
.33586 .75579 m .33602 .71875 L .34862 .72674 L p .707 .577 .707 r
F P
0 g
s
.15586 .82273 m .15283 .80414 L .15998 .7966 L p .707 .577 .707 r
F P
0 g
s
.34284 .63617 m .33691 .69078 L .31602 .6813 L p .707 .577 .707 r
F P
0 g
s
.31602 .6813 m .32195 .6267 L .34284 .63617 L p .707 .577 .707 r
F P
0 g
s
.15998 .7966 m .16301 .81518 L .15586 .82273 L p .707 .577 .707 r
F P
0 g
s
.17285 .67117 m .17878 .61657 L .20275 .61246 L p .707 .577 .707 r
F P
0 g
s
.35142 .76964 m .35445 .78822 L .34216 .78406 L p .707 .577 .707 r
F P
0 g
s
.34216 .78406 m .33913 .76548 L .35142 .76964 L p .707 .577 .707 r
F P
0 g
s
.15454 .75951 m .1547 .72247 L .17107 .71512 L p .707 .577 .707 r
F P
0 g
s
.63678 .26422 m .62571 .76479 L .596 .75479 L p .707 .577 .707 r
F P
0 g
s
.596 .75479 m .60706 .25422 L .63678 .26422 L p .707 .577 .707 r
F P
0 g
s
.17107 .71512 m .17091 .75216 L .15454 .75951 L p .707 .577 .707 r
F P
0 g
s
.32195 .6267 m .31602 .6813 L .28874 .67357 L p .707 .577 .707 r
F P
0 g
s
.28874 .67357 m .29467 .61896 L .32195 .6267 L p .707 .577 .707 r
F P
0 g
s
.20275 .61246 m .19682 .66706 L .17285 .67117 L p .707 .577 .707 r
F P
0 g
s
.33602 .71875 m .33586 .75579 L .31481 .74921 L p .707 .577 .707 r
F P
0 g
s
.31481 .74921 m .31497 .71218 L .33602 .71875 L p .707 .577 .707 r
F P
0 g
s
.19682 .66706 m .20275 .61246 L .232 .61147 L p .707 .577 .707 r
F P
0 g
s
.16301 .81518 m .15998 .7966 L .17628 .78841 L p .707 .577 .707 r
F P
0 g
s
.17628 .78841 m .17931 .80699 L .16301 .81518 L p .707 .577 .707 r
F P
0 g
s
.40395 .25518 m .39288 .75575 L .36978 .766 L p .707 .577 .707 r
F P
0 g
s
.39288 .75575 m .40395 .25518 L .43791 .24766 L p .707 .577 .707 r
F P
0 g
s
.17091 .75216 m .17107 .71512 L .19512 .70954 L p .707 .577 .707 r
F P
0 g
s
.29467 .61896 m .28874 .67357 L .25775 .66832 L p .707 .577 .707 r
F P
0 g
s
.25775 .66832 m .26367 .61371 L .29467 .61896 L p .707 .577 .707 r
F P
0 g
s
.33913 .76548 m .34216 .78406 L .32148 .78229 L p .707 .577 .707 r
F P
0 g
s
.32148 .78229 m .31846 .76371 L .33913 .76548 L p .707 .577 .707 r
F P
0 g
s
.72405 .64481 m .72998 .59021 L .69899 .58496 L p .707 .577 .707 r
F P
0 g
s
.72998 .59021 m .72405 .64481 L .75573 .64705 L p .707 .577 .707 r
F P
0 g
s
.75573 .64705 m .76165 .59245 L .72998 .59021 L p .707 .577 .707 r
F P
0 g
s
.22607 .66608 m .232 .61147 L .26367 .61371 L p .707 .577 .707 r
F P
0 g
s
.232 .61147 m .22607 .66608 L .19682 .66706 L p .707 .577 .707 r
F P
0 g
s
.76165 .59245 m .75573 .64705 L .78498 .64607 L p .707 .577 .707 r
F P
0 g
s
.78498 .64607 m .79091 .59147 L .76165 .59245 L p .707 .577 .707 r
F P
0 g
s
.26367 .61371 m .25775 .66832 L .22607 .66608 L p .707 .577 .707 r
F P
0 g
s
.69306 .63957 m .69899 .58496 L .67171 .57722 L p .707 .577 .707 r
F P
0 g
s
.69899 .58496 m .69306 .63957 L .72405 .64481 L p .707 .577 .707 r
F P
0 g
s
.19512 .70954 m .19496 .74657 L .17091 .75216 L p .707 .577 .707 r
F P
0 g
s
.31497 .71218 m .31481 .74921 L .28735 .74468 L p .707 .577 .707 r
F P
0 g
s
.28735 .74468 m .28751 .70764 L .31497 .71218 L p .707 .577 .707 r
F P
0 g
s
.60706 .25422 m .596 .75479 L .55724 .74761 L p .707 .577 .707 r
F P
0 g
s
.55724 .74761 m .56831 .24704 L .60706 .25422 L p .707 .577 .707 r
F P
0 g
s
.17931 .80699 m .17628 .78841 L .20014 .78037 L p .707 .577 .707 r
F P
0 g
s
.79091 .59147 m .78498 .64607 L .80895 .64196 L p .707 .577 .707 r
F P
0 g
s
.80895 .64196 m .81488 .58735 L .79091 .59147 L p .707 .577 .707 r
F P
0 g
s
.19496 .74657 m .19512 .70954 L .2245 .70626 L p .707 .577 .707 r
F P
0 g
s
.20014 .78037 m .20317 .79896 L .17931 .80699 L p .707 .577 .707 r
F P
0 g
s
.66578 .63183 m .67171 .57722 L .65082 .56775 L p .707 .577 .707 r
F P
0 g
s
.67171 .57722 m .66578 .63183 L .69306 .63957 L p .707 .577 .707 r
F P
0 g
s
.72284 .69126 m .723 .65422 L .69183 .65218 L p .707 .577 .707 r
F P
0 g
s
.723 .65422 m .72284 .69126 L .75468 .6906 L p .707 .577 .707 r
F P
0 g
s
.75468 .6906 m .75484 .65357 L .723 .65422 L p .707 .577 .707 r
F P
0 g
s
.42684 .74823 m .43791 .24766 L .47938 .24359 L p .707 .577 .707 r
F P
0 g
s
.43791 .24766 m .42684 .74823 L .39288 .75575 L p .707 .577 .707 r
F P
0 g
s
.31846 .76371 m .32148 .78229 L .29445 .7831 L p .707 .577 .707 r
F P
0 g
s
.29445 .7831 m .29142 .76451 L .31846 .76371 L p .707 .577 .707 r
F P
0 g
s
.75484 .65357 m .75468 .6906 L .78406 .68733 L p .707 .577 .707 r
F P
0 g
s
.78406 .68733 m .78422 .65029 L .75484 .65357 L p .707 .577 .707 r
F P
0 g
s
.28751 .70764 m .28735 .74468 L .25618 .74264 L p .707 .577 .707 r
F P
0 g
s
.25618 .74264 m .25634 .70561 L .28751 .70764 L p .707 .577 .707 r
F P
0 g
s
.69167 .68922 m .69183 .65218 L .66437 .64765 L p .707 .577 .707 r
F P
0 g
s
.69183 .65218 m .69167 .68922 L .72284 .69126 L p .707 .577 .707 r
F P
0 g
s
.2245 .70626 m .22434 .74329 L .19496 .74657 L p .707 .577 .707 r
F P
0 g
s
.22434 .74329 m .2245 .70626 L .25634 .70561 L p .707 .577 .707 r
F P
0 g
s
.25634 .70561 m .25618 .74264 L .22434 .74329 L p .707 .577 .707 r
F P
0 g
s
.56831 .24704 m .55724 .74761 L .51324 .74395 L p .707 .577 .707 r
F P
0 g
s
.51324 .74395 m .52431 .24338 L .56831 .24704 L p .707 .577 .707 r
F P
0 g
s
.78422 .65029 m .78406 .68733 L .80811 .68174 L p .707 .577 .707 r
F P
0 g
s
.80811 .68174 m .80827 .6447 L .78422 .65029 L p .707 .577 .707 r
F P
0 g
s
.20317 .79896 m .20014 .78037 L .22922 .77327 L p .707 .577 .707 r
F P
0 g
s
.72952 .73243 m .72649 .71385 L .69575 .71715 L p .707 .577 .707 r
F P
0 g
s
.72649 .71385 m .72952 .73243 L .76097 .72697 L p .707 .577 .707 r
F P
0 g
s
.76097 .72697 m .75795 .70839 L .72649 .71385 L p .707 .577 .707 r
F P
0 g
s
.81488 .58735 m .80895 .64196 L .82529 .63512 L p .707 .577 .707 r
F P
0 g
s
.82529 .63512 m .83122 .58052 L .81488 .58735 L p .707 .577 .707 r
F P
0 g
s
.75795 .70839 m .76097 .72697 L .79005 .71987 L p .707 .577 .707 r
F P
0 g
s
.79005 .71987 m .78703 .70129 L .75795 .70839 L p .707 .577 .707 r
F P
0 g
s
.66437 .64765 m .66421 .68469 L .69167 .68922 L p .707 .577 .707 r
F P
0 g
s
.65082 .56775 m .64489 .62236 L .66578 .63183 L p .707 .577 .707 r
F P
0 g
s
.22922 .77327 m .23225 .79186 L .20317 .79896 L p .707 .577 .707 r
F P
0 g
s
.69575 .71715 m .69877 .73573 L .72952 .73243 L p .707 .577 .707 r
F P
0 g
s
.46831 .74416 m .47938 .24359 L .52431 .24338 L p .707 .577 .707 r
F P
0 g
s
.47938 .24359 m .46831 .74416 L .42684 .74823 L p .707 .577 .707 r
F P
0 g
s
.29142 .76451 m .29445 .7831 L .2637 .78639 L p .707 .577 .707 r
F P
0 g
s
.2637 .78639 m .26068 .76781 L .29142 .76451 L p .707 .577 .707 r
F P
0 g
s
.66421 .68469 m .66437 .64765 L .64332 .64107 L p .707 .577 .707 r
F P
0 g
s
.69877 .73573 m .69575 .71715 L .66871 .71795 L p .707 .577 .707 r
F P
0 g
s
.52431 .24338 m .51324 .74395 L .46831 .74416 L p .707 .577 .707 r
F P
0 g
s
.23225 .79186 m .22922 .77327 L .26068 .76781 L p .707 .577 .707 r
F P
0 g
s
.66871 .71795 m .67173 .73653 L .69877 .73573 L p .707 .577 .707 r
F P
0 g
s
.26068 .76781 m .2637 .78639 L .23225 .79186 L p .707 .577 .707 r
F P
0 g
s
.78703 .70129 m .79005 .71987 L .81391 .71183 L p .707 .577 .707 r
F P
0 g
s
.81391 .71183 m .81089 .69325 L .78703 .70129 L p .707 .577 .707 r
F P
0 g
s
.64332 .64107 m .64316 .67811 L .66421 .68469 L p .707 .577 .707 r
F P
0 g
s
.80827 .6447 m .80811 .68174 L .82448 .67439 L p .707 .577 .707 r
F P
0 g
s
.82448 .67439 m .82464 .63736 L .80827 .6447 L p .707 .577 .707 r
F P
0 g
s
.63835 .55747 m .63243 .61208 L .64489 .62236 L p .707 .577 .707 r
F P
0 g
s
.67173 .73653 m .66871 .71795 L .64804 .71618 L p .707 .577 .707 r
F P
0 g
s
.83122 .58052 m .82529 .63512 L .8324 .62623 L p .707 .577 .707 r
F P
0 g
s
.8324 .62623 m .83833 .57162 L .83122 .58052 L p .707 .577 .707 r
F P
0 g
s
.64804 .71618 m .65106 .73477 L .67173 .73653 L p .707 .577 .707 r
F P
0 g
s
.64316 .67811 m .64332 .64107 L .63073 .63309 L p .707 .577 .707 r
F P
0 g
s
.81089 .69325 m .81391 .71183 L .83021 .70364 L p .707 .577 .707 r
F P
0 g
s
.83021 .70364 m .82719 .68506 L .81089 .69325 L p .707 .577 .707 r
F P
0 g
s
.63243 .61208 m .63835 .55747 L .63554 .54739 L p .707 .577 .707 r
F P
0 g
s
.63073 .63309 m .63056 .67012 L .64316 .67811 L p .707 .577 .707 r
F P
0 g
s
.82464 .63736 m .82448 .67439 L .83156 .66601 L p .707 .577 .707 r
F P
0 g
s
.83156 .66601 m .83173 .62897 L .82464 .63736 L p .707 .577 .707 r
F P
0 g
s
.65106 .73477 m .64804 .71618 L .63575 .71202 L p .707 .577 .707 r
F P
0 g
s
.63554 .54739 m .62961 .602 L .63243 .61208 L p .707 .577 .707 r
F P
0 g
s
.63575 .71202 m .63877 .7306 L .65106 .73477 L p .707 .577 .707 r
F P
0 g
s
.83833 .57162 m .8324 .62623 L .82959 .61615 L p .707 .577 .707 r
F P
0 g
s
.82959 .61615 m .83552 .56154 L .83833 .57162 L p .707 .577 .707 r
F P
0 g
s
.63056 .67012 m .63073 .63309 L .62783 .62448 L p .707 .577 .707 r
F P
0 g
s
.82719 .68506 m .83021 .70364 L .83736 .6961 L p .707 .577 .707 r
F P
0 g
s
.83736 .6961 m .83434 .67752 L .82719 .68506 L p .707 .577 .707 r
F P
0 g
s
.62961 .602 m .63554 .54739 L .64265 .5385 L p .707 .577 .707 r
F P
0 g
s
.62783 .62448 m .62767 .66152 L .63056 .67012 L p .707 .577 .707 r
F P
0 g
s
.83173 .62897 m .83156 .66601 L .82867 .6574 L p .707 .577 .707 r
F P
0 g
s
.82867 .6574 m .82883 .62036 L .83173 .62897 L p .707 .577 .707 r
F P
0 g
s
.63877 .7306 m .63575 .71202 L .63305 .70586 L p .707 .577 .707 r
F P
0 g
s
.64265 .5385 m .63672 .5931 L .62961 .602 L p .707 .577 .707 r
F P
0 g
s
.63305 .70586 m .63607 .72445 L .63877 .7306 L p .707 .577 .707 r
F P
0 g
s
.83552 .56154 m .82959 .61615 L .81713 .60587 L p .707 .577 .707 r
F P
0 g
s
.81713 .60587 m .82305 .55126 L .83552 .56154 L p .707 .577 .707 r
F P
0 g
s
.83434 .67752 m .83736 .6961 L .83466 .68995 L p .707 .577 .707 r
F P
0 g
s
.83466 .68995 m .83164 .67136 L .83434 .67752 L p .707 .577 .707 r
F P
0 g
s
.62767 .66152 m .62783 .62448 L .63491 .6161 L p .707 .577 .707 r
F P
0 g
s
.63672 .5931 m .64265 .5385 L .65899 .53166 L p .707 .577 .707 r
F P
0 g
s
.63491 .6161 m .63475 .65313 L .62767 .66152 L p .707 .577 .707 r
F P
0 g
s
.38104 .63768 m .38697 .58308 L .35598 .57783 L p .707 .577 .707 r
F P
0 g
s
.38697 .58308 m .38104 .63768 L .41272 .63992 L p .707 .577 .707 r
F P
0 g
s
.41272 .63992 m .41864 .58532 L .38697 .58308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82883 .62036 m .82867 .6574 L .81608 .64942 L p .707 .577 .707 r
F P
0 g
s
.81608 .64942 m .81624 .61238 L .82883 .62036 L p .707 .577 .707 r
F P
0 g
s
.41864 .58532 m .41272 .63992 L .44197 .63894 L p .707 .577 .707 r
F P
0 g
s
.44197 .63894 m .4479 .58434 L .41864 .58532 L p .707 .577 .707 r
F P
0 g
s
.63607 .72445 m .63305 .70586 L .6402 .69832 L p .707 .577 .707 r
F P
0 g
s
.35005 .63244 m .35598 .57783 L .3287 .57009 L p .707 .577 .707 r
F P
0 g
s
.35598 .57783 m .35005 .63244 L .38104 .63768 L p .707 .577 .707 r
F P
0 g
s
.65899 .53166 m .65306 .58626 L .63672 .5931 L p .707 .577 .707 r
F P
0 g
s
.6402 .69832 m .64322 .71691 L .63607 .72445 L p .707 .577 .707 r
F P
0 g
s
.82305 .55126 m .81713 .60587 L .79623 .59639 L p .707 .577 .707 r
F P
0 g
s
.79623 .59639 m .80216 .54179 L .82305 .55126 L p .707 .577 .707 r
F P
0 g
s
.63475 .65313 m .63491 .6161 L .65128 .60875 L p .707 .577 .707 r
F P
0 g
s
.83164 .67136 m .83466 .68995 L .82237 .68578 L p .707 .577 .707 r
F P
0 g
s
.82237 .68578 m .81935 .6672 L .83164 .67136 L p .707 .577 .707 r
F P
0 g
s
.4479 .58434 m .44197 .63894 L .46594 .63483 L p .707 .577 .707 r
F P
0 g
s
.46594 .63483 m .47187 .58022 L .4479 .58434 L p .707 .577 .707 r
F P
0 g
s
.65306 .58626 m .65899 .53166 L .68296 .52755 L p .707 .577 .707 r
F P
0 g
s
.32277 .6247 m .3287 .57009 L .30781 .56062 L p .707 .577 .707 r
F P
0 g
s
.3287 .57009 m .32277 .6247 L .35005 .63244 L p .707 .577 .707 r
F P
0 g
s
.65128 .60875 m .65112 .64579 L .63475 .65313 L p .707 .577 .707 r
F P
0 g
s
.37983 .70559 m .37999 .66856 L .34882 .66652 L p .707 .577 .707 r
F P
0 g
s
.37999 .66856 m .37983 .70559 L .41167 .70494 L p .707 .577 .707 r
F P
0 g
s
.41167 .70494 m .41183 .6679 L .37999 .66856 L p .707 .577 .707 r
F P
0 g
s
.41183 .6679 m .41167 .70494 L .44105 .70166 L p .707 .577 .707 r
F P
0 g
s
.44105 .70166 m .44121 .66462 L .41183 .6679 L p .707 .577 .707 r
F P
0 g
s
.81624 .61238 m .81608 .64942 L .79502 .64284 L p .707 .577 .707 r
F P
0 g
s
.79502 .64284 m .79518 .6058 L .81624 .61238 L p .707 .577 .707 r
F P
0 g
s
.80216 .54179 m .79623 .59639 L .76895 .58866 L p .707 .577 .707 r
F P
0 g
s
.76895 .58866 m .77488 .53405 L .80216 .54179 L p .707 .577 .707 r
F P
0 g
s
.34866 .70355 m .34882 .66652 L .32136 .66199 L p .707 .577 .707 r
F P
0 g
s
.34882 .66652 m .34866 .70355 L .37983 .70559 L p .707 .577 .707 r
F P
0 g
s
.68296 .52755 m .67704 .58215 L .65306 .58626 L p .707 .577 .707 r
F P
0 g
s
.64322 .71691 m .6402 .69832 L .6565 .69013 L p .707 .577 .707 r
F P
0 g
s
.47187 .58022 m .46594 .63483 L .48228 .62799 L p .707 .577 .707 r
F P
0 g
s
.48228 .62799 m .48821 .57339 L .47187 .58022 L p .707 .577 .707 r
F P
0 g
s
.67704 .58215 m .68296 .52755 L .71222 .52656 L p .707 .577 .707 r
F P
0 g
s
.30781 .56062 m .30188 .61523 L .32277 .6247 L p .707 .577 .707 r
F P
0 g
s
.6565 .69013 m .65952 .70872 L .64322 .71691 L p .707 .577 .707 r
F P
0 g
s
.38651 .73867 m .38348 .72009 L .35274 .72338 L p .707 .577 .707 r
F P
0 g
s
.38348 .72009 m .38651 .73867 L .41796 .73321 L p .707 .577 .707 r
F P
0 g
s
.41796 .73321 m .41494 .71462 L .38348 .72009 L p .707 .577 .707 r
F P
0 g
s
.41494 .71462 m .41796 .73321 L .44704 .72611 L p .707 .577 .707 r
F P
0 g
s
.44704 .72611 m .44402 .70752 L .41494 .71462 L p .707 .577 .707 r
F P
0 g
s
.65112 .64579 m .65128 .60875 L .67534 .60316 L p .707 .577 .707 r
F P
0 g
s
.44121 .66462 m .44105 .70166 L .4651 .69607 L p .707 .577 .707 r
F P
0 g
s
.4651 .69607 m .46526 .65904 L .44121 .66462 L p .707 .577 .707 r
F P
0 g
s
.30188 .61523 m .30781 .56062 L .29534 .55034 L p .707 .577 .707 r
F P
0 g
s
.35274 .72338 m .35576 .74197 L .38651 .73867 L p .707 .577 .707 r
F P
0 g
s
.32136 .66199 m .3212 .69902 L .34866 .70355 L p .707 .577 .707 r
F P
0 g
s
.81935 .6672 m .82237 .68578 L .8017 .68402 L p .707 .577 .707 r
F P
0 g
s
.8017 .68402 m .79867 .66543 L .81935 .6672 L p .707 .577 .707 r
F P
0 g
s
.35576 .74197 m .35274 .72338 L .3257 .72419 L p .707 .577 .707 r
F P
0 g
s
.77488 .53405 m .76895 .58866 L .73796 .58341 L p .707 .577 .707 r
F P
0 g
s
.73796 .58341 m .74389 .52881 L .77488 .53405 L p .707 .577 .707 r
F P
0 g
s
.3212 .69902 m .32136 .66199 L .30031 .65541 L p .707 .577 .707 r
F P
0 g
s
.70629 .58117 m .71222 .52656 L .74389 .52881 L p .707 .577 .707 r
F P
0 g
s
.71222 .52656 m .70629 .58117 L .67704 .58215 L p .707 .577 .707 r
F P
0 g
s
.3257 .72419 m .32872 .74277 L .35576 .74197 L p .707 .577 .707 r
F P
0 g
s
.67534 .60316 m .67517 .6402 L .65112 .64579 L p .707 .577 .707 r
F P
0 g
s
.44402 .70752 m .44704 .72611 L .4709 .71807 L p .707 .577 .707 r
F P
0 g
s
.4709 .71807 m .46788 .69949 L .44402 .70752 L p .707 .577 .707 r
F P
0 g
s
.74389 .52881 m .73796 .58341 L .70629 .58117 L p .707 .577 .707 r
F P
0 g
s
.79518 .6058 m .79502 .64284 L .76756 .63831 L p .707 .577 .707 r
F P
0 g
s
.76756 .63831 m .76772 .60127 L .79518 .6058 L p .707 .577 .707 r
F P
0 g
s
.30031 .65541 m .30015 .69244 L .3212 .69902 L p .707 .577 .707 r
F P
0 g
s
.29534 .55034 m .28942 .60495 L .30188 .61523 L p .707 .577 .707 r
F P
0 g
s
.67517 .6402 m .67534 .60316 L .70472 .59988 L p .707 .577 .707 r
F P
0 g
s
.65952 .70872 m .6565 .69013 L .68036 .68209 L p .707 .577 .707 r
F P
0 g
s
.46526 .65904 m .4651 .69607 L .48147 .68873 L p .707 .577 .707 r
F P
0 g
s
.48147 .68873 m .48163 .65169 L .46526 .65904 L p .707 .577 .707 r
F P
0 g
s
.48821 .57339 m .48228 .62799 L .48939 .6191 L p .707 .577 .707 r
F P
0 g
s
.48939 .6191 m .49532 .56449 L .48821 .57339 L p .707 .577 .707 r
F P
0 g
s
.32872 .74277 m .3257 .72419 L .30503 .72242 L p .707 .577 .707 r
F P
0 g
s
.68036 .68209 m .68338 .70068 L .65952 .70872 L p .707 .577 .707 r
F P
0 g
s
.30503 .72242 m .30805 .74101 L .32872 .74277 L p .707 .577 .707 r
F P
0 g
s
.79867 .66543 m .8017 .68402 L .77466 .68482 L p .707 .577 .707 r
F P
0 g
s
.77466 .68482 m .77164 .66623 L .79867 .66543 L p .707 .577 .707 r
F P
0 g
s
.76772 .60127 m .76756 .63831 L .73639 .63627 L p .707 .577 .707 r
F P
0 g
s
.73639 .63627 m .73655 .59923 L .76772 .60127 L p .707 .577 .707 r
F P
0 g
s
.28942 .60495 m .29534 .55034 L .29253 .54026 L p .707 .577 .707 r
F P
0 g
s
.70472 .59988 m .70455 .63692 L .67517 .6402 L p .707 .577 .707 r
F P
0 g
s
.46788 .69949 m .4709 .71807 L .4872 .70988 L p .707 .577 .707 r
F P
0 g
s
.4872 .70988 m .48418 .6913 L .46788 .69949 L p .707 .577 .707 r
F P
0 g
s
.30015 .69244 m .30031 .65541 L .28772 .64742 L p .707 .577 .707 r
F P
0 g
s
.70455 .63692 m .70472 .59988 L .73655 .59923 L p .707 .577 .707 r
F P
0 g
s
.73655 .59923 m .73639 .63627 L .70455 .63692 L p .707 .577 .707 r
F P
0 g
s
.68338 .70068 m .68036 .68209 L .70944 .675 L p .707 .577 .707 r
F P
0 g
s
.28772 .64742 m .28755 .68446 L .30015 .69244 L p .707 .577 .707 r
F P
0 g
s
.70944 .675 m .71246 .69358 L .68338 .70068 L p .707 .577 .707 r
F P
0 g
s
.77164 .66623 m .77466 .68482 L .74391 .68811 L p .707 .577 .707 r
F P
0 g
s
.74391 .68811 m .74089 .66953 L .77164 .66623 L p .707 .577 .707 r
F P
0 g
s
.29253 .54026 m .2866 .59487 L .28942 .60495 L p .707 .577 .707 r
F P
0 g
s
.48163 .65169 m .48147 .68873 L .48855 .68034 L p .707 .577 .707 r
F P
0 g
s
.48855 .68034 m .48872 .64331 L .48163 .65169 L p .707 .577 .707 r
F P
0 g
s
.30805 .74101 m .30503 .72242 L .29274 .71826 L p .707 .577 .707 r
F P
0 g
s
.71246 .69358 m .70944 .675 L .74089 .66953 L p .707 .577 .707 r
F P
0 g
s
.29274 .71826 m .29576 .73684 L .30805 .74101 L p .707 .577 .707 r
F P
0 g
s
.49532 .56449 m .48939 .6191 L .48658 .60902 L p .707 .577 .707 r
F P
0 g
s
.48658 .60902 m .49251 .55441 L .49532 .56449 L p .707 .577 .707 r
F P
0 g
s
.74089 .66953 m .74391 .68811 L .71246 .69358 L p .707 .577 .707 r
F P
0 g
s
.48418 .6913 m .4872 .70988 L .49435 .70234 L p .707 .577 .707 r
F P
0 g
s
.49435 .70234 m .49133 .68375 L .48418 .6913 L p .707 .577 .707 r
F P
0 g
s
.2866 .59487 m .29253 .54026 L .29964 .53137 L p .707 .577 .707 r
F P
0 g
s
.28755 .68446 m .28772 .64742 L .28482 .63882 L p .707 .577 .707 r
F P
0 g
s
.28482 .63882 m .28466 .67585 L .28755 .68446 L p .707 .577 .707 r
F P
0 g
s
.29576 .73684 m .29274 .71826 L .29004 .7121 L p .707 .577 .707 r
F P
0 g
s
.29964 .53137 m .29371 .58597 L .2866 .59487 L p .707 .577 .707 r
F P
0 g
s
.48872 .64331 m .48855 .68034 L .48566 .67174 L p .707 .577 .707 r
F P
0 g
s
.48566 .67174 m .48582 .6347 L .48872 .64331 L p .707 .577 .707 r
F P
0 g
s
.29004 .7121 m .29306 .73069 L .29576 .73684 L p .707 .577 .707 r
F P
0 g
s
.49251 .55441 m .48658 .60902 L .47412 .59874 L p .707 .577 .707 r
F P
0 g
s
.47412 .59874 m .48004 .54413 L .49251 .55441 L p .707 .577 .707 r
F P
0 g
s
.49133 .68375 m .49435 .70234 L .49165 .69619 L p .707 .577 .707 r
F P
0 g
s
.49165 .69619 m .48863 .6776 L .49133 .68375 L p .707 .577 .707 r
F P
0 g
s
.29371 .58597 m .29964 .53137 L .31598 .52453 L p .707 .577 .707 r
F P
0 g
s
.28466 .67585 m .28482 .63882 L .2919 .63043 L p .707 .577 .707 r
F P
0 g
s
.2919 .63043 m .29174 .66747 L .28466 .67585 L p .707 .577 .707 r
F P
0 g
s
.31598 .52453 m .31005 .57913 L .29371 .58597 L p .707 .577 .707 r
F P
0 g
s
.48582 .6347 m .48566 .67174 L .47306 .66375 L p .707 .577 .707 r
F P
0 g
s
.47306 .66375 m .47323 .62672 L .48582 .6347 L p .707 .577 .707 r
F P
0 g
s
.29306 .73069 m .29004 .7121 L .29719 .70456 L p .707 .577 .707 r
F P
0 g
s
.48004 .54413 m .47412 .59874 L .45322 .58926 L p .707 .577 .707 r
F P
0 g
s
.45322 .58926 m .45915 .53466 L .48004 .54413 L p .707 .577 .707 r
F P
0 g
s
.29719 .70456 m .30021 .72315 L .29306 .73069 L p .707 .577 .707 r
F P
0 g
s
.31005 .57913 m .31598 .52453 L .33995 .52042 L p .707 .577 .707 r
F P
0 g
s
.48863 .6776 m .49165 .69619 L .47936 .69202 L p .707 .577 .707 r
F P
0 g
s
.47936 .69202 m .47634 .67344 L .48863 .6776 L p .707 .577 .707 r
F P
0 g
s
.29174 .66747 m .2919 .63043 L .30827 .62308 L p .707 .577 .707 r
F P
0 g
s
.30827 .62308 m .30811 .66012 L .29174 .66747 L p .707 .577 .707 r
F P
0 g
s
.45915 .53466 m .45322 .58926 L .42594 .58153 L p .707 .577 .707 r
F P
0 g
s
.42594 .58153 m .43187 .52692 L .45915 .53466 L p .707 .577 .707 r
F P
0 g
s
.33995 .52042 m .33402 .57502 L .31005 .57913 L p .707 .577 .707 r
F P
0 g
s
.47323 .62672 m .47306 .66375 L .45201 .65717 L p .707 .577 .707 r
F P
0 g
s
.45201 .65717 m .45217 .62014 L .47323 .62672 L p .707 .577 .707 r
F P
0 g
s
.33402 .57502 m .33995 .52042 L .36921 .51943 L p .707 .577 .707 r
F P
0 g
s
.30021 .72315 m .29719 .70456 L .31349 .69637 L p .707 .577 .707 r
F P
0 g
s
.31349 .69637 m .31651 .71496 L .30021 .72315 L p .707 .577 .707 r
F P
0 g
s
.30811 .66012 m .30827 .62308 L .33232 .6175 L p .707 .577 .707 r
F P
0 g
s
.43187 .52692 m .42594 .58153 L .39495 .57628 L p .707 .577 .707 r
F P
0 g
s
.39495 .57628 m .40088 .52168 L .43187 .52692 L p .707 .577 .707 r
F P
0 g
s
.47634 .67344 m .47936 .69202 L .45869 .69025 L p .707 .577 .707 r
F P
0 g
s
.45869 .69025 m .45566 .67167 L .47634 .67344 L p .707 .577 .707 r
F P
0 g
s
.36328 .57404 m .36921 .51943 L .40088 .52168 L p .707 .577 .707 r
F P
0 g
s
.36921 .51943 m .36328 .57404 L .33402 .57502 L p .707 .577 .707 r
F P
0 g
s
.40088 .52168 m .39495 .57628 L .36328 .57404 L p .707 .577 .707 r
F P
0 g
s
.33232 .6175 m .33216 .65454 L .30811 .66012 L p .707 .577 .707 r
F P
0 g
s
.45217 .62014 m .45201 .65717 L .42455 .65264 L p .707 .577 .707 r
F P
0 g
s
.42455 .65264 m .42471 .61561 L .45217 .62014 L p .707 .577 .707 r
F P
0 g
s
.31651 .71496 m .31349 .69637 L .33735 .68833 L p .707 .577 .707 r
F P
0 g
s
.33216 .65454 m .33232 .6175 L .36171 .61422 L p .707 .577 .707 r
F P
0 g
s
.33735 .68833 m .34037 .70692 L .31651 .71496 L p .707 .577 .707 r
F P
0 g
s
.45566 .67167 m .45869 .69025 L .43165 .69106 L p .707 .577 .707 r
F P
0 g
s
.43165 .69106 m .42863 .67247 L .45566 .67167 L p .707 .577 .707 r
F P
0 g
s
.42471 .61561 m .42455 .65264 L .39338 .6506 L p .707 .577 .707 r
F P
0 g
s
.39338 .6506 m .39354 .61357 L .42471 .61561 L p .707 .577 .707 r
F P
0 g
s
.36171 .61422 m .36154 .65126 L .33216 .65454 L p .707 .577 .707 r
F P
0 g
s
.36154 .65126 m .36171 .61422 L .39354 .61357 L p .707 .577 .707 r
F P
0 g
s
.39354 .61357 m .39338 .6506 L .36154 .65126 L p .707 .577 .707 r
F P
0 g
s
.34037 .70692 m .33735 .68833 L .36642 .68123 L p .707 .577 .707 r
F P
0 g
s
.36642 .68123 m .36945 .69982 L .34037 .70692 L p .707 .577 .707 r
F P
0 g
s
.42863 .67247 m .43165 .69106 L .4009 .69435 L p .707 .577 .707 r
F P
0 g
s
.4009 .69435 m .39788 .67577 L .42863 .67247 L p .707 .577 .707 r
F P
0 g
s
.36945 .69982 m .36642 .68123 L .39788 .67577 L p .707 .577 .707 r
F P
0 g
s
.39788 .67577 m .4009 .69435 L .36945 .69982 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Eoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007=oo`00LWoo0`00
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000Kgoo001`
Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000
FUH00000KGoo001^Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0`00JWoo001/Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2
001XOol006]oo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Ioo`00JWoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P00I7oo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HWoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo
001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJ
EP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJEP0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0001QOol006Uoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00065oo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001ROol006Eoo`P000=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00GGoo20000eYF00<005YFFUH00UYF
2@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001IOol40003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH6000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000<Ool8001>Ool005Moo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004Ool80003FUH0
0`00FUIJEP02FUH90015Ool005Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000040003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH6000oOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000mOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00>goo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000hOol005=oo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00002000eOol005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP0000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000cOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Woo
001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0
059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002moo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00;Woo001BOol20004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00;Woo001BOol20003FUH500000eYF
001JEP04FUH80005FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool0055oo`04001JEP00FUH20006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH40005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP04001JEUYFFUHG0006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00DGoo00H005YF000005YF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<00000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000=JEPD00003
FUH005YF00AJEPL000Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF
;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20005FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
Ool40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF
00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
1EYF00@005YFFUIJEP8002moo`00DGoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YF
FUH00eYF4P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002moo`00DWoo
00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJEP03001JEUYF009J
EPP0009JEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;goo001BOol01000FUIJEP001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH60002FUH30002FUH00`00FUH0000_Ool003ioo`P000eoo`<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH40004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01@00FUH005YF
0000;goo000fOol80003FUH00`00FUIJEP02FUH70008Ool00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P000UYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP000000031oo`00
<Woo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010001Goo0P000eYF00<005YF
00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF1@00<7oo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40003Ool500000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP8000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF0080031oo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP80031o
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH70003Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000eYF1P0015YF0P001goo1`0015YF00<005YFFUH00UYF2`0000=JEP00FUH00UYF0P00<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000=JEPD0009JEP04001JEP00000<Ool@0003
FUH30003FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF00<005YFFUH015YF00<005YF
FUH00P0000=JEP000000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF20000UYF00<007oo0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF00001@0015YF00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF1@001EYF00@005YFFUIJEP800005Ool005YFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000`Ool0
02]oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00FUH20004FUH500000eYF001JEP02FUH200001Goo001JEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
031oo`00:goo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00@005YFFUIJEPT0009JEP03001JEUYF00=JEPl000EJEP04001JEUYF0002FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE00000eYF001oo`0_Ool002]oo`8000=JEPD00003
FUH005YF00AJEPL0009oo`T0009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30007FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000`Ool002Yoo`04
001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002Ool40003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHD00000eYF001JEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000
FUIJEUYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
031oo`00:Woo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000_Ool002Yoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
00000eYF001JEP02FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000_Ool002Yoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1@00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF3P000eYF00D005YFFUIJEP0002moo`00
:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00H005YF000005YF0005FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEPD000Ioo`D0009JEP8002ioo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH00UYF500000=JEP00FUH015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01UYF
00<005YFFUH03P0037oo0P000UYF1000;Woo000[Ool01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP0000000UYF00<005YFFUH01eYF
00<005YFFUH015YF1P001eYF00<005YFFUH00eYF1@0000=JEP0000000P0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH0
15YF100067oo0P0015YF00@005YFFUH002ioo`00:goo00@005YFFUH000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00MJEP03001JEUYF
00@000EJEP03001JEUYF00EJEP03001JEP0000<00003FUH0000000=JEP04001JEP000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF
00<005YFFUH0100067oo100000=JEP00FUH00eYF00<005YF0000;goo000/Ool00`00FUH00006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP05
FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP02FUH50003FUH30005FUH00`00FUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH4
00000eYF001oo`0FOol30005FUH00`00FUIJEP02FUH2000`Ool002eoo`8000EJEP03001JEUYF00EJ
EQ40009JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF01L000IJEP80009JEP03
001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00005FUH00`00FUH00004000015YF0000000057oo100000=JEP00FUH01UYF00D005YFFUIJEP00
035oo`00;Woo0P0015YF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF
00<005YFFUH00eYF100000AJEP00Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00@000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP04001JEUYFFUH30004FUH5000=Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000<Woo000`Ool600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP03FUH00`00FUH000030003FUH01@00FUH007oo00000UYF00<005YFFUH00eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00H005YF000005YF0005FUH00`00FUIJEP020004Ool9
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000dOol002moo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP80009JEP04001JEUYFFUH50004FUH20002Ool01000FUIJEP00
1EYF00<005YFFUH01P001UYF00<005YFFUH015YF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000UYF1@001UYF2@0015YF00<005YFFUH00`000eYF00<005YFFUH0
1UYF00<005YF00000`00=goo000]Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUH000020004FUH200000eYF00000003Ool00`00FUIJEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP070003FUH00`00FUIJEP06FUH00`00FUH0
00040003FUH00`00FUIJEP04FUH3000kOol002]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUHD0004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUH000040003FUH00`00FUIJEP04000nOol002Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01eYF1P0000=JEP0000000`00@Woo000YOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000040017Ool002Uoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6000;FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH7001;Ool002Uoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000180
059oo`00:Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00UYF3P002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000100000AJEP00000000=JEP8005Moo`00:Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF2@0000EJEP00Oomoo`00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00EJEP04001JEUYF0002FUH2001GOol002Uoo`03001JEP0000AJEP04001JEUYFFUH8000GOol40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo00@005YFFUH000EJEP03001JEUYF00EJEPX000]J
EP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH4001GOol002Uoo`03001JEP0000=JEPD002=oo`D000=JEP05001JEUYFFUH00002Ool01000
FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF
1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00UYF0`00Egoo
000YOol01000FUH005YF0P0015YF1@0087oo20000eYF00@007ooOol0009JEP03001JEUYF00=JEP<0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
00<000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<005Moo`00:Goo00H005YF
000005YF0005FUH01000FUIJEUYF2@004Woo1@001EYF00@005YFFUH0009JEP04001oogoo0002FUH0
1000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF00002@0000AJEP00FUH005Moo`00
:Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4P000eYF00<005YFFUH0
15YF00@005YFFUIJEP<0009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0
0003FUH00`00FUIJEP02FUH4001HOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEQ@00005FUH007ooOol00002FUH200000eYF001JEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000
FUH0000015YF00<005YF00000eYF00<005YFFUH00UYF00<005YFFUH00P00Egoo000YOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH000000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEP0000=JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002Uoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP02001FOol002Yoo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUH00000Ool00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001@000eYF00D0
05YFFUIJEP0005Ioo`00:goo00@005YFFUH000EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH00000Ool000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<000Aoo`D0009JEP03001oogoo05Aoo`00;7oo0`001EYF
00<005YF00000P0025YF00<005YFFUH01UYF00<005YFFUH00UYF4`000UYF00<007oo00001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000000Moo`80009JEP@005Eoo`00;Woo0`000eYF0P00
0UYF00<005YFFUH01eYF00<005YFFUH015YF1P001eYF00<005YFFUH015YF00<005YF00001P0000=o
o`00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Eoo`8000AJEP04001JEP00
001EOol0035oo`<000AJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00EJEP04001J
EUYFFUH700000eYF001JEP0200000goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00
FUIJEP00Ool0100000=JEP00FUH00eYF00@005YFFUH005Eoo`00;goo0P0000=JEP00FUH01EYF00<0
05YFFUH015YF1@002EYF00<005YFFUH00UYF1`000goo0P000eYF00@005YFFUH0009oo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020005FUH00`00FUIJEP02FUH3001FOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF01L000Ioo`@00003FUH005YF00=JEP8000Aoo`800003FUH0
05YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP05001JEUYFFUH0001HOol002aoo`8000AJ
EP03001JEUYF00=JEP@001Uoo`@000EJEP03001JEUYF009JEP8000Ioo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00EJEP04001JEP00001IOol002]oo`03001JEP0000AJEP03001JEP0000<0
01Uoo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH20008Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0`00Fgoo000[Ool01000FUIJEP000eYF0P005goo1P001UYF00<005YFFUH015YF
00@005YF000000aoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUH00003001NOol002]oo`05001JEUYF
001JEP02000@Ool90003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000BOol40009FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH600000eYF001JEP05FUH3001R
Ool002aoo`03001JEP0000<000Qoo`P000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
008001Uoo`@000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H0
00=JEP03001JEUYF00@006Eoo`00;7oo0P0000AJEP00FUIJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0021oo`@00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00AJEPh00003FUH0000000<006Uoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01000:7oo20001UYF00<005YFFUH015YF3@0025YF1`00
KWoo000/Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH5000dOol=0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001`Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@004Aooa<007Uoo`00;goo10000eYF
00<005YFFUH01EYF00<005YFFUH00UYF1P00e7oo000cOol@003JOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58095 .72883 m .59051 .67517 L .55981 .66789 L p .707 .577 .707 r
F P
0 g
s
.60952 .73254 m .61236 .7329 L p .60508 .71366 L .707 .577 .707 r
F P
0 g
s
.61236 .7329 m .62192 .67924 L .59051 .67517 L p .707 .577 .707 r
F P
0 g
s
.62192 .67924 m .62191 .67931 L p .64141 .73337 L .707 .577 .707 r
F P
0 g
s
.62191 .67931 m .61236 .7329 L .639 .73334 L p .707 .577 .707 r
F P
0 g
s
.639 .73334 m .64141 .73337 L p .62191 .67931 L .707 .577 .707 r
F P
0 g
s
.64141 .73337 m .65097 .67971 L .62192 .67924 L p .707 .577 .707 r
F P
0 g
s
.65097 .67971 m .65023 .68387 L p .66524 .7302 L .707 .577 .707 r
F P
0 g
s
.65023 .68387 m .64141 .73337 L .6636 .73042 L p .707 .577 .707 r
F P
0 g
s
.6636 .73042 m .66524 .7302 L p .65023 .68387 L .707 .577 .707 r
F P
0 g
s
.66524 .7302 m .6748 .67653 L .65097 .67971 L p .707 .577 .707 r
F P
0 g
s
.6748 .67653 m .67427 .67953 L p .68154 .72368 L .707 .577 .707 r
F P
0 g
s
.67427 .67953 m .66524 .7302 L .68055 .72408 L p .707 .577 .707 r
F P
0 g
s
.68055 .72408 m .68154 .72368 L p .67427 .67953 L .707 .577 .707 r
F P
0 g
s
.68154 .72368 m .6911 .67002 L .6748 .67653 L p .707 .577 .707 r
F P
0 g
s
.6911 .67002 m .68154 .72368 L .68826 .71502 L p .707 .577 .707 r
F P
0 g
s
.68826 .71502 m .6887 .71446 L p .68996 .69106 L .707 .577 .707 r
F P
0 g
s
.68996 .69106 m .6911 .67002 L .68826 .71502 L .707 .577 .707 r
F
.68105 .71318 m .68096 .72696 L p .68787 .74181 L F P
0 g
s
.68814 .70478 m .68105 .71318 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68787 .74181 m .68804 .71814 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68804 .71814 m .68814 .70478 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.6887 .71446 m .69826 .6608 L .6911 .67002 L p .707 .577 .707 r
F P
0 g
s
.69826 .6608 m .6887 .71446 L .68851 .7137 L p .707 .577 .707 r
F P
0 g
s
.68814 .70478 m .68804 .71814 L p .68498 .73316 L .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68814 .70478 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68498 .73316 m .68515 .70829 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68515 .70829 m .68524 .69614 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68096 .72696 m .68079 .75021 L .68374 .74671 L p .707 .577 .707 r
F P
0 g
s
.68374 .74671 m .68787 .74181 L p .68096 .72696 L .707 .577 .707 r
F P
0 g
s
.68079 .75021 m .68105 .71318 L .66469 .72051 L p .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68498 .73316 L .67239 .72512 L p .707 .577 .707 r
F P
0 g
s
.69558 .64979 m .68602 .70345 L .685 .70248 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .68524 .69614 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67239 .72512 m .67258 .69837 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67258 .69837 m .67265 .68809 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.66469 .72051 m .66459 .73387 L p .68079 .75021 L .707 .577 .707 r
F P
0 g
s
.66442 .75754 m .66469 .72051 L .64063 .72606 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .67239 .72512 L .65133 .71846 L p .707 .577 .707 r
F P
0 g
s
.65133 .71846 m .65159 .68143 L .67265 .68809 L p .707 .577 .707 r
F P
0 g
s
.68332 .63805 m .67376 .69172 L .6719 .6907 L p .707 .577 .707 r
F P
0 g
s
.6719 .6907 m .65313 .68041 L p .66901 .65813 L .707 .577 .707 r
F P
0 g
s
.66901 .65813 m .68332 .63805 L .6719 .6907 L .707 .577 .707 r
F
.685 .70248 m .67376 .69172 L p .68419 .67167 L F P
0 g
s
.68419 .67167 m .69558 .64979 L .685 .70248 L .707 .577 .707 r
F
.68851 .7137 m .68602 .70345 L p .69169 .68369 L F P
0 g
s
.69169 .68369 m .69826 .6608 L .68851 .7137 L .707 .577 .707 r
F
.68804 .71814 m .68787 .74181 L .68663 .73809 L p F P
0 g
s
.68663 .73809 m .68498 .73316 L p .68804 .71814 L .707 .577 .707 r
F P
0 g
s
.66459 .73387 m .66442 .75754 L .67059 .75477 L p .707 .577 .707 r
F P
0 g
s
.67059 .75477 m .68079 .75021 L p .66459 .73387 L .707 .577 .707 r
F P
0 g
s
.64063 .72606 m .64055 .73822 L p .66442 .75754 L .707 .577 .707 r
F P
0 g
s
.64055 .73822 m .64037 .76309 L .64787 .76136 L p .707 .577 .707 r
F P
0 g
s
.64787 .76136 m .66442 .75754 L p .64055 .73822 L .707 .577 .707 r
F P
0 g
s
.61125 .72928 m .61118 .73956 L p .64037 .76309 L .707 .577 .707 r
F P
0 g
s
.61118 .73956 m .61099 .7663 L .61731 .76561 L p .707 .577 .707 r
F P
0 g
s
.61731 .76561 m .64037 .76309 L p .61118 .73956 L .707 .577 .707 r
F P
0 g
s
.59051 .67517 m .58095 .72883 L .60952 .73254 L p .707 .577 .707 r
F P
0 g
s
.60508 .71366 m .59051 .67517 L .60952 .73254 L .707 .577 .707 r
F
.55025 .72155 m .55981 .66789 L .53282 .65812 L p F P
0 g
s
.55981 .66789 m .55025 .72155 L .58095 .72883 L p .707 .577 .707 r
F P
0 g
s
.52326 .71179 m .53282 .65812 L .51219 .64682 L p .707 .577 .707 r
F P
0 g
s
.53282 .65812 m .52326 .71179 L .55025 .72155 L p .707 .577 .707 r
F P
0 g
s
.57915 .76688 m .57942 .72985 L .54824 .72773 L p .707 .577 .707 r
F P
0 g
s
.57942 .72985 m .57915 .76688 L .61099 .7663 L p .707 .577 .707 r
F P
0 g
s
.61099 .7663 m .61125 .72928 L .57942 .72985 L p .707 .577 .707 r
F P
0 g
s
.64037 .76309 m .64063 .72606 L .61125 .72928 L p .707 .577 .707 r
F P
0 g
s
.54798 .76475 m .54824 .72773 L .52079 .72311 L p .707 .577 .707 r
F P
0 g
s
.54824 .72773 m .54798 .76475 L .57915 .76688 L p .707 .577 .707 r
F P
0 g
s
.58952 .80753 m .58466 .78918 L .5546 .79567 L p .707 .577 .707 r
F P
0 g
s
.58466 .78918 m .58952 .80753 L .62036 .79919 L p .707 .577 .707 r
F P
0 g
s
.62036 .79919 m .6155 .78084 L .58466 .78918 L p .707 .577 .707 r
F P
0 g
s
.6155 .78084 m .62036 .79919 L .64895 .78981 L p .707 .577 .707 r
F P
0 g
s
.64895 .78981 m .6441 .77146 L .6155 .78084 L p .707 .577 .707 r
F P
0 g
s
.52079 .72311 m .52052 .76014 L .54798 .76475 L p .707 .577 .707 r
F P
0 g
s
.5546 .79567 m .55945 .81402 L .58952 .80753 L p .707 .577 .707 r
F P
0 g
s
.51219 .64682 m .50263 .70048 L .52326 .71179 L p .707 .577 .707 r
F P
0 g
s
.50263 .70048 m .51219 .64682 L .49993 .63508 L p .707 .577 .707 r
F P
0 g
s
.52052 .76014 m .52079 .72311 L .49973 .71646 L p .707 .577 .707 r
F P
0 g
s
.55945 .81402 m .5546 .79567 L .52824 .79967 L p .707 .577 .707 r
F P
0 g
s
.52824 .79967 m .5331 .81802 L .55945 .81402 L p .707 .577 .707 r
F P
0 g
s
.6441 .77146 m .64895 .78981 L .6725 .7803 L p .707 .577 .707 r
F P
0 g
s
.6725 .7803 m .66764 .76195 L .6441 .77146 L p .707 .577 .707 r
F P
0 g
s
.49973 .71646 m .49947 .75348 L .52052 .76014 L p .707 .577 .707 r
F P
0 g
s
.49993 .63508 m .49038 .68875 L .50263 .70048 L p .707 .577 .707 r
F P
0 g
s
.5331 .81802 m .52824 .79967 L .50818 .80078 L p .707 .577 .707 r
F P
0 g
s
.50818 .80078 m .51304 .81913 L .5331 .81802 L p .707 .577 .707 r
F P
0 g
s
.49947 .75348 m .49973 .71646 L .48714 .70841 L p .707 .577 .707 r
F P
0 g
s
.66764 .76195 m .6725 .7803 L .68869 .77161 L p .707 .577 .707 r
F P
0 g
s
.68869 .77161 m .68383 .75326 L .66764 .76195 L p .707 .577 .707 r
F P
0 g
s
.49038 .68875 m .49993 .63508 L .49725 .62407 L p .707 .577 .707 r
F P
0 g
s
.48714 .70841 m .48688 .74544 L .49947 .75348 L p .707 .577 .707 r
F P
0 g
s
.51304 .81913 m .50818 .80078 L .49638 .7989 L p .707 .577 .707 r
F P
0 g
s
.49725 .62407 m .4877 .67774 L .49038 .68875 L p .707 .577 .707 r
F P
0 g
s
.49638 .7989 m .50124 .81725 L .51304 .81913 L p .707 .577 .707 r
F P
0 g
s
.68383 .75326 m .68869 .77161 L .69595 .76457 L p .707 .577 .707 r
F P
0 g
s
.69595 .76457 m .69109 .74622 L .68383 .75326 L p .707 .577 .707 r
F P
0 g
s
.48688 .74544 m .48714 .70841 L .48424 .69977 L p .707 .577 .707 r
F P
0 g
s
.68602 .70345 m .69558 .64979 L .69826 .6608 L p .707 .577 .707 r
F P
0 g
s
.4877 .67774 m .49725 .62407 L .50441 .61486 L p .707 .577 .707 r
F P
0 g
s
.50124 .81725 m .49638 .7989 L .49399 .79421 L p .707 .577 .707 r
F P
0 g
s
.50441 .61486 m .49485 .66852 L .4877 .67774 L p .707 .577 .707 r
F P
0 g
s
.49399 .79421 m .49885 .81256 L .50124 .81725 L p .707 .577 .707 r
F P
0 g
s
.48424 .69977 m .48398 .73679 L .48688 .74544 L p .707 .577 .707 r
F P
0 g
s
.48398 .73679 m .48424 .69977 L .49133 .69137 L p .707 .577 .707 r
F P
0 g
s
.49485 .66852 m .50441 .61486 L .52071 .60834 L p .707 .577 .707 r
F P
0 g
s
.49133 .69137 m .49106 .72839 L .48398 .73679 L p .707 .577 .707 r
F P
0 g
s
.52071 .60834 m .51115 .662 L .49485 .66852 L p .707 .577 .707 r
F P
0 g
s
.49885 .81256 m .49399 .79421 L .50125 .78718 L p .707 .577 .707 r
F P
0 g
s
.49106 .72839 m .49133 .69137 L .5077 .68403 L p .707 .577 .707 r
F P
0 g
s
.5077 .68403 m .50743 .72106 L .49106 .72839 L p .707 .577 .707 r
F P
0 g
s
.49635 .82389 m .51426 .32427 L .47028 .32 L p .707 .577 .707 r
F P
0 g
s
.50125 .78718 m .5061 .80553 L .49885 .81256 L p .707 .577 .707 r
F P
0 g
s
.51115 .662 m .52071 .60834 L .54454 .60516 L p .707 .577 .707 r
F P
0 g
s
.54454 .60516 m .53498 .65882 L .51115 .662 L p .707 .577 .707 r
F P
0 g
s
.5061 .80553 m .50125 .78718 L .51744 .77848 L p .707 .577 .707 r
F P
0 g
s
.51744 .77848 m .5223 .79683 L .5061 .80553 L p .707 .577 .707 r
F P
0 g
s
.50743 .72106 m .5077 .68403 L .53175 .67849 L p .707 .577 .707 r
F P
0 g
s
.53175 .67849 m .53149 .71551 L .50743 .72106 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53175 .67849 L .53569 .67806 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53569 .67806 L .53674 .70838 L .707 .577 .707 r
F
.54454 .60516 m .56279 .60546 L p .54202 .64532 L F P
0 g
s
.53498 .65882 m .53736 .64548 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.53736 .64548 m .54454 .60516 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.57744 .60613 m .605 .6097 L p .5792 .64093 L .707 .577 .707 r
F P
0 g
s
.6357 .61698 m .62614 .67064 L .59544 .66337 L p .707 .577 .707 r
F P
0 g
s
.59544 .66337 m .605 .6097 L .6357 .61698 L p .707 .577 .707 r
F P
0 g
s
.605 .6097 m .59544 .66337 L .56923 .65997 L p .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .54769 .64512 L .57028 .66635 L .707 .577 .707 r
F
.56923 .65997 m .56403 .65929 L p .56827 .65416 L F P
0 g
s
.56827 .65416 m .605 .6097 L .56923 .65997 L .707 .577 .707 r
F
.54099 .76897 m .54584 .78732 L .5223 .79683 L p F P
0 g
s
.54584 .78732 m .54099 .76897 L .56138 .76228 L p .707 .577 .707 r
F P
0 g
s
.56138 .76228 m .56958 .75959 L p .56417 .76591 L .707 .577 .707 r
F P
0 g
s
.54584 .78732 m .56138 .76228 L .56417 .76591 L .707 .577 .707 r
F
.5372 .72178 m .54769 .64512 L .53564 .67674 L F
.54428 .74005 m .54769 .64512 L p .53615 .72947 L F P
0 g
s
.56958 .75959 m .57444 .77794 L .54584 .78732 L p .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .54127 .82422 L p .57028 .66635 L .707 .577 .707 r
F P
0 g
s
.56113 .67527 m .56087 .71229 L .53696 .71491 L p .707 .577 .707 r
F P
0 g
s
.53696 .71491 m .53149 .71551 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.53674 .70838 m .56113 .67527 L .53696 .71491 L .707 .577 .707 r
F
.53615 .72947 m .5372 .72178 L .53359 .68213 L F
.5372 .72178 m .53564 .67674 L .53359 .68213 L F
.5223 .79683 m .51744 .77848 L .54099 .76897 L p F P
0 g
s
.54127 .82422 m .54428 .74005 L p .53615 .72947 L .707 .577 .707 r
F P
0 g
s
.57359 .60563 m .57744 .60613 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.56827 .65416 m .57744 .60613 L .5792 .64093 L .707 .577 .707 r
F
.56667 .64445 m .57359 .60563 L p .56827 .65416 L F P
0 g
s
.57435 .64418 m .56667 .64445 L .57028 .66635 L .707 .577 .707 r
F
.62414 .67682 m .62387 .71384 L .5927 .71172 L p F P
0 g
s
.5927 .71172 m .59297 .67469 L .62414 .67682 L p .707 .577 .707 r
F P
0 g
s
.5719 .67619 m .57435 .64418 L .57028 .66635 L .707 .577 .707 r
F
.57436 .64433 m .57435 .64418 L .5719 .67619 L F
.57198 .67507 m .59297 .67469 L p .56993 .70168 L F P
0 g
s
.56663 .7443 m .57028 .66635 L .54127 .82422 L .707 .577 .707 r
F
.59297 .67469 m .5927 .71172 L .56912 .71214 L p F P
0 g
s
.56993 .70168 m .59297 .67469 L .56912 .71214 L .707 .577 .707 r
F
.57748 .71012 m .5719 .67619 L .56663 .7443 L F
.5719 .67619 m .57028 .66635 L .56663 .7443 L F
.56912 .71214 m .56087 .71229 L p .56993 .70168 L F P
0 g
s
.56087 .71229 m .56113 .67527 L .57198 .67507 L p .707 .577 .707 r
F P
0 g
s
.56087 .71229 m .57198 .67507 L .56993 .70168 L .707 .577 .707 r
F
.57748 .71012 m .57436 .64433 L .5719 .67619 L F
.63049 .74476 m .63534 .76311 L .60528 .7696 L p F P
0 g
s
.60528 .7696 m .60042 .75125 L .63049 .74476 L p .707 .577 .707 r
F P
0 g
s
.57444 .77794 m .57034 .76247 L p .60042 .75125 L .707 .577 .707 r
F P
0 g
s
.57034 .76247 m .56958 .75959 L .57103 .7592 L p .707 .577 .707 r
F P
0 g
s
.57103 .7592 m .60042 .75125 L p .57034 .76247 L .707 .577 .707 r
F P
0 g
s
.60042 .75125 m .60528 .7696 L .57444 .77794 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .60903 .57881 L .58504 .75604 L .707 .577 .707 r
F
.60063 .32097 m .58778 .67972 L p .60903 .57881 L F P
0 g
s
.58778 .67972 m .58504 .75604 L p .60903 .57881 L .707 .577 .707 r
F P
0 g
s
.58504 .75604 m .58273 .82059 L .58826 .81941 L p .707 .577 .707 r
F P
0 g
s
.58826 .81941 m .61667 .81334 L p .58504 .75604 L .707 .577 .707 r
F P
0 g
s
.56403 .65929 m .56667 .64445 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.54127 .82422 m .58273 .82059 L p .57748 .71012 L .707 .577 .707 r
F P
0 g
s
.56279 .60546 m .57359 .60563 L p .55073 .63712 L .707 .577 .707 r
F P
0 g
s
.53498 .65882 m .56279 .60546 L .55073 .63712 L .707 .577 .707 r
F
.56403 .65929 m .53498 .65882 L p .54486 .64522 L F P
0 g
s
.57359 .60563 m .56667 .64445 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .56403 .65929 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.60063 .32097 m .55917 .3246 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58273 .82059 m .58907 .64367 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58907 .64367 m .60063 .32097 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .54769 .64512 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .51426 .32427 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .55917 .3246 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.53569 .67806 m .56113 .67527 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.51426 .32427 m .49635 .82389 L .54075 .82422 L p .707 .577 .707 r
F P
0 g
s
.54075 .82422 m .54127 .82422 L p .53982 .7974 L .707 .577 .707 r
F P
0 g
s
.53982 .7974 m .51426 .32427 L .54075 .82422 L .707 .577 .707 r
F
.45237 .81962 m .47028 .32 L .43154 .31221 L p F P
0 g
s
.47028 .32 m .45237 .81962 L .49635 .82389 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .63458 .31372 L .60063 .32097 L p .707 .577 .707 r
F P
0 g
s
.69109 .74622 m .69595 .76457 L .69356 .75988 L p .707 .577 .707 r
F P
0 g
s
.69356 .75988 m .6887 .74153 L .69109 .74622 L p .707 .577 .707 r
F P
0 g
s
.67376 .69172 m .68332 .63805 L .69558 .64979 L p .707 .577 .707 r
F P
0 g
s
.41363 .81183 m .43154 .31221 L .40184 .30167 L p .707 .577 .707 r
F P
0 g
s
.43154 .31221 m .41363 .81183 L .45237 .81962 L p .707 .577 .707 r
F P
0 g
s
.23794 .74005 m .2475 .68638 L .2168 .67911 L p .707 .577 .707 r
F P
0 g
s
.2475 .68638 m .23794 .74005 L .26935 .74412 L p .707 .577 .707 r
F P
0 g
s
.26935 .74412 m .27891 .69046 L .2475 .68638 L p .707 .577 .707 r
F P
0 g
s
.66269 .62675 m .65313 .68041 L .62614 .67064 L p .707 .577 .707 r
F P
0 g
s
.62614 .67064 m .6357 .61698 L .66269 .62675 L p .707 .577 .707 r
F P
0 g
s
.65159 .68143 m .65133 .71846 L .62387 .71384 L p .707 .577 .707 r
F P
0 g
s
.62387 .71384 m .62414 .67682 L .65159 .68143 L p .707 .577 .707 r
F P
0 g
s
.65684 .74077 m .6617 .75912 L .63534 .76311 L p .707 .577 .707 r
F P
0 g
s
.63534 .76311 m .63049 .74476 L .65684 .74077 L p .707 .577 .707 r
F P
0 g
s
.63458 .31372 m .61667 .81334 L .63978 .80319 L p .707 .577 .707 r
F P
0 g
s
.63978 .80319 m .65768 .30357 L .63458 .31372 L p .707 .577 .707 r
F P
0 g
s
.27891 .69046 m .26935 .74412 L .2984 .74459 L p .707 .577 .707 r
F P
0 g
s
.2984 .74459 m .30796 .69093 L .27891 .69046 L p .707 .577 .707 r
F P
0 g
s
.20724 .73277 m .2168 .67911 L .18981 .66934 L p .707 .577 .707 r
F P
0 g
s
.2168 .67911 m .20724 .73277 L .23794 .74005 L p .707 .577 .707 r
F P
0 g
s
.65313 .68041 m .66269 .62675 L .68332 .63805 L p .707 .577 .707 r
F P
0 g
s
.6887 .74153 m .69356 .75988 L .68176 .758 L p .707 .577 .707 r
F P
0 g
s
.68176 .758 m .6769 .73965 L .6887 .74153 L p .707 .577 .707 r
F P
0 g
s
.38393 .80129 m .40184 .30167 L .38408 .2894 L p .707 .577 .707 r
F P
0 g
s
.40184 .30167 m .38393 .80129 L .41363 .81183 L p .707 .577 .707 r
F P
0 g
s
.30796 .69093 m .2984 .74459 L .32224 .74141 L p .707 .577 .707 r
F P
0 g
s
.32224 .74141 m .33179 .68775 L .30796 .69093 L p .707 .577 .707 r
F P
0 g
s
.18025 .723 m .18981 .66934 L .16918 .65803 L p .707 .577 .707 r
F P
0 g
s
.18981 .66934 m .18025 .723 L .20724 .73277 L p .707 .577 .707 r
F P
0 g
s
.23614 .81283 m .23641 .7758 L .20524 .77368 L p .707 .577 .707 r
F P
0 g
s
.23641 .7758 m .23614 .81283 L .26798 .81225 L p .707 .577 .707 r
F P
0 g
s
.26798 .81225 m .26824 .77523 L .23641 .7758 L p .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .30109 .8043 L .28994 .80796 L p .707 .577 .707 r
F P
0 g
s
.28994 .80796 m .27249 .81369 L p .28586 .81727 L .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .28994 .80796 L .28586 .81727 L .707 .577 .707 r
F
.30109 .8043 m .30594 .82266 L .32949 .81315 L p F P
0 g
s
.32949 .81315 m .32463 .7948 L .31614 .79823 L p .707 .577 .707 r
F P
0 g
s
.31614 .79823 m .30109 .8043 L p .31266 .80791 L .707 .577 .707 r
F P
0 g
s
.32949 .81315 m .31614 .79823 L .31266 .80791 L .707 .577 .707 r
F
.32463 .7948 m .32949 .81315 L .34568 .80445 L p F P
0 g
s
.34568 .80445 m .34083 .7861 L .33554 .78894 L p .707 .577 .707 r
F P
0 g
s
.33554 .78894 m .32463 .7948 L p .3338 .799 L .707 .577 .707 r
F P
0 g
s
.34568 .80445 m .33554 .78894 L .3338 .799 L .707 .577 .707 r
F
.34083 .7861 m .34568 .80445 L .35294 .79742 L p F P
0 g
s
.35294 .79742 m .34808 .77907 L .3459 .78119 L p .707 .577 .707 r
F P
0 g
s
.3459 .78119 m .34083 .7861 L p .34656 .79146 L .707 .577 .707 r
F P
0 g
s
.35294 .79742 m .3459 .78119 L .34656 .79146 L .707 .577 .707 r
F
.33778 .79615 m .34486 .78775 L p .33959 .76561 L F P
0 g
s
.34486 .78775 m .34513 .75073 L .33805 .75913 L p .707 .577 .707 r
F P
0 g
s
.34486 .78775 m .34197 .77911 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34513 .75073 m .34501 .76745 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34501 .76745 m .34486 .78775 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.33805 .75913 m .33793 .77516 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.33793 .77516 m .33778 .79615 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .33778 .79615 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32168 .76646 m .32156 .78318 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32156 .78318 m .32141 .80349 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .32141 .80349 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29762 .77201 m .29749 .79071 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29749 .79071 m .29736 .80903 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.26824 .77523 m .26798 .81225 L .29736 .80903 L p .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .29762 .77201 L .26824 .77523 L p .707 .577 .707 r
F P
0 g
s
.20497 .8107 m .20524 .77368 L .17778 .76906 L p .707 .577 .707 r
F P
0 g
s
.20524 .77368 m .20497 .8107 L .23614 .81283 L p .707 .577 .707 r
F P
0 g
s
.6769 .73965 m .68176 .758 L .6617 .75912 L p .707 .577 .707 r
F P
0 g
s
.6617 .75912 m .65684 .74077 L .6769 .73965 L p .707 .577 .707 r
F P
0 g
s
.16918 .65803 m .15962 .7117 L .18025 .723 L p .707 .577 .707 r
F P
0 g
s
.65768 .30357 m .63978 .80319 L .64978 .79113 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .66769 .29151 L .65768 .30357 L p .707 .577 .707 r
F P
0 g
s
.33179 .68775 m .32224 .74141 L .33853 .7349 L p .707 .577 .707 r
F P
0 g
s
.33853 .7349 m .34809 .68123 L .33179 .68775 L p .707 .577 .707 r
F P
0 g
s
.24651 .84038 m .24166 .82203 L .21159 .82852 L p .707 .577 .707 r
F P
0 g
s
.24166 .82203 m .24651 .84038 L .27735 .83204 L p .707 .577 .707 r
F P
0 g
s
.27735 .83204 m .27249 .81369 L .24166 .82203 L p .707 .577 .707 r
F P
0 g
s
.15962 .7117 m .16918 .65803 L .15692 .6463 L p .707 .577 .707 r
F P
0 g
s
.27249 .81369 m .27735 .83204 L .30594 .82266 L p .707 .577 .707 r
F P
0 g
s
.21159 .82852 m .21644 .84687 L .24651 .84038 L p .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .32168 .76646 L .29762 .77201 L p .707 .577 .707 r
F P
0 g
s
.17778 .76906 m .17752 .80608 L .20497 .8107 L p .707 .577 .707 r
F P
0 g
s
.21644 .84687 m .21159 .82852 L .18523 .83251 L p .707 .577 .707 r
F P
0 g
s
.17752 .80608 m .17778 .76906 L .15672 .7624 L p .707 .577 .707 r
F P
0 g
s
.18523 .83251 m .19009 .85086 L .21644 .84687 L p .707 .577 .707 r
F P
0 g
s
.36618 .78902 m .38408 .2894 L .38001 .27661 L p .707 .577 .707 r
F P
0 g
s
.38408 .2894 m .36618 .78902 L .38393 .80129 L p .707 .577 .707 r
F P
0 g
s
.15692 .6463 m .14737 .69997 L .15962 .7117 L p .707 .577 .707 r
F P
0 g
s
.15672 .7624 m .15646 .79943 L .17752 .80608 L p .707 .577 .707 r
F P
0 g
s
.33778 .79615 m .33805 .75913 L .32168 .76646 L p .707 .577 .707 r
F P
0 g
s
.34809 .68123 m .33853 .7349 L .34569 .72568 L p .707 .577 .707 r
F P
0 g
s
.34569 .72568 m .35525 .67202 L .34809 .68123 L p .707 .577 .707 r
F P
0 g
s
.19009 .85086 m .18523 .83251 L .16517 .83363 L p .707 .577 .707 r
F P
0 g
s
.14737 .69997 m .15692 .6463 L .15424 .63529 L p .707 .577 .707 r
F P
0 g
s
.16517 .83363 m .17003 .85198 L .19009 .85086 L p .707 .577 .707 r
F P
0 g
s
.15646 .79943 m .15672 .7624 L .14413 .75436 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .64637 .78043 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66769 .29151 m .66148 .46482 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66148 .46482 m .64978 .79113 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.64729 .74327 m .65556 .56006 L .64637 .78043 L .707 .577 .707 r
F
.65556 .56006 m .66769 .29151 L .65696 .53756 L F
.65556 .56006 m .65696 .53756 L .64637 .78043 L F
.66361 .27872 m .66769 .29151 L p .64729 .74327 L F P
0 g
s
.64571 .77834 m .64802 .71379 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .66361 .27872 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64248 .5936 m .63983 .60844 L .64325 .61031 L p .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64174 .5776 L .64205 .59325 L .707 .577 .707 r
F
.66361 .27872 m .64802 .71379 L p .64405 .62778 L F P
0 g
s
.64411 .62669 m .63694 .62442 L p .64349 .63818 L .707 .577 .707 r
F P
0 g
s
.64174 .5776 m .66136 .30948 L .64405 .62778 L .707 .577 .707 r
F
.66136 .30948 m .66361 .27872 L .64405 .62778 L F
.65773 .6681 m .65799 .63107 L .64411 .62669 L p F P
0 g
s
.63983 .60844 m .64248 .5936 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .64571 .77834 L p .64308 .64562 L .707 .577 .707 r
F P
0 g
s
.64349 .63818 m .63694 .62442 L .64213 .66317 L .707 .577 .707 r
F
.64174 .5776 m .64405 .62778 L .64308 .64562 L F
.64405 .62778 m .64802 .71379 L .64308 .64562 L F
.63694 .62442 m .63667 .66144 L .64213 .66317 L p F P
0 g
s
.62795 .76608 m .59825 .75553 L p .60451 .6912 L .707 .577 .707 r
F P
0 g
s
.63667 .66144 m .63694 .62442 L .62603 .61745 L p .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62463 .48454 L .62602 .61612 L .707 .577 .707 r
F
.63667 .66144 m .62603 .61745 L .62609 .62275 L F
.63983 .60844 m .63911 .59085 L .63226 .59433 L F
.63072 .59971 m .63983 .60844 L p .63226 .59433 L F P
0 g
s
.64585 .26645 m .63437 .58697 L p .62602 .61612 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .62758 .59671 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.62643 .6549 m .63667 .66144 L p .62609 .62275 L .707 .577 .707 r
F P
0 g
s
.63437 .58697 m .62795 .76608 L p .62759 .76494 L .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62602 .61612 L .62759 .76494 L .707 .577 .707 r
F
.62602 .61612 m .63437 .58697 L .62759 .76494 L F
.62434 .61637 m .62408 .6534 L .62643 .6549 L p F P
0 g
s
.62609 .62275 m .62434 .61637 L .62643 .6549 L .707 .577 .707 r
F
.62603 .61745 m .62434 .61637 L p .62609 .62275 L F P
0 g
s
.62463 .48454 m .64585 .26645 L .62602 .61612 L .707 .577 .707 r
F
.62758 .59671 m .63072 .59971 L p .63226 .59433 L F P
0 g
s
.63437 .58697 m .63531 .56057 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .64585 .26645 L p .6416 .53381 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .6416 .53381 L .64068 .59213 L .707 .577 .707 r
F
.63714 .54305 m .63446 .53203 L p .62821 .59081 L F P
0 g
s
.62758 .59671 m .62996 .58337 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .63714 .54305 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.63714 .54305 m .62996 .58337 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64585 .26645 m .66361 .27872 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.62795 .76608 m .63437 .58697 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64571 .77834 m .62795 .76608 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64205 .59325 L .64571 .77834 L .707 .577 .707 r
F
.64213 .66317 m .65773 .6681 L p .64349 .63818 L F P
0 g
s
.65773 .6681 m .64411 .62669 L .64349 .63818 L .707 .577 .707 r
F
.64939 .55478 m .63714 .54305 L p .63911 .59085 L F P
0 g
s
.64248 .5936 m .64939 .55478 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64939 .55478 m .64248 .5936 L p .65048 .61428 L .707 .577 .707 r
F P
0 g
s
.64325 .61031 m .65048 .61428 L p .64248 .5936 L .707 .577 .707 r
F P
0 g
s
.65048 .61428 m .66047 .61975 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.65163 .56791 m .64939 .55478 L .65048 .61428 L .707 .577 .707 r
F
.65024 .72709 m .6703 .72598 L p .64629 .70936 L F P
0 g
s
.64539 .70874 m .64615 .71162 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.64615 .71162 m .65024 .72709 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .66545 .70763 L .64633 .70869 L p .707 .577 .707 r
F P
0 g
s
.64633 .70869 m .64539 .70874 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .64633 .70869 L .64629 .70936 L .707 .577 .707 r
F
.66047 .61975 m .67002 .56608 L .65192 .55616 L p F P
0 g
s
.65192 .55616 m .64939 .55478 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.66047 .61975 m .65192 .55616 L .65163 .56791 L .707 .577 .707 r
F
.64637 .78043 m .64571 .77834 L p .64729 .74327 L F P
0 g
s
.14413 .75436 m .14387 .79138 L .15646 .79943 L p .707 .577 .707 r
F P
0 g
s
.15424 .63529 m .14469 .68895 L .14737 .69997 L p .707 .577 .707 r
F P
0 g
s
.17003 .85198 m .16517 .83363 L .15337 .83175 L p .707 .577 .707 r
F P
0 g
s
.15337 .83175 m .15823 .8501 L .17003 .85198 L p .707 .577 .707 r
F P
0 g
s
.35525 .67202 m .34569 .72568 L .34301 .71467 L p .707 .577 .707 r
F P
0 g
s
.34301 .71467 m .35257 .661 L .35525 .67202 L p .707 .577 .707 r
F P
0 g
s
.38001 .27661 m .3621 .77624 L .36618 .78902 L p .707 .577 .707 r
F P
0 g
s
.3621 .77624 m .38001 .27661 L .39001 .26455 L p .707 .577 .707 r
F P
0 g
s
.14469 .68895 m .15424 .63529 L .1614 .62607 L p .707 .577 .707 r
F P
0 g
s
.14387 .79138 m .14413 .75436 L .14124 .74571 L p .707 .577 .707 r
F P
0 g
s
.14124 .74571 m .14097 .78274 L .14387 .79138 L p .707 .577 .707 r
F P
0 g
s
.1614 .62607 m .15184 .67974 L .14469 .68895 L p .707 .577 .707 r
F P
0 g
s
.15823 .8501 m .15337 .83175 L .15098 .82706 L p .707 .577 .707 r
F P
0 g
s
.34223 .74208 m .34197 .77911 L .32938 .77106 L p .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .33389 .7725 L .34109 .77365 L p .707 .577 .707 r
F P
0 g
s
.34197 .77911 m .3421 .76079 L p .34513 .75073 L .707 .577 .707 r
F P
0 g
s
.34109 .77365 m .34569 .77438 L p .33997 .78795 L .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .34109 .77365 L .33997 .78795 L .707 .577 .707 r
F
.3421 .76079 m .34223 .74208 L .34331 .74531 L p F P
0 g
s
.34331 .74531 m .34513 .75073 L p .3421 .76079 L .707 .577 .707 r
F P
0 g
s
.15098 .82706 m .15584 .84541 L .15823 .8501 L p .707 .577 .707 r
F P
0 g
s
.35257 .661 m .34301 .71467 L .33075 .70293 L p .707 .577 .707 r
F P
0 g
s
.33075 .70293 m .34031 .64927 L .35257 .661 L p .707 .577 .707 r
F P
0 g
s
.15184 .67974 m .1614 .62607 L .1777 .61956 L p .707 .577 .707 r
F P
0 g
s
.34808 .77907 m .35294 .79742 L .35055 .79273 L p .707 .577 .707 r
F P
0 g
s
.35055 .79273 m .34569 .77438 L .34808 .77907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14097 .78274 m .14124 .74571 L .14832 .73731 L p .707 .577 .707 r
F P
0 g
s
.3721 .76418 m .39001 .26455 L .41312 .2544 L p .707 .577 .707 r
F P
0 g
s
.39001 .26455 m .3721 .76418 L .3621 .77624 L p .707 .577 .707 r
F P
0 g
s
.14832 .73731 m .14805 .77434 L .14097 .78274 L p .707 .577 .707 r
F P
0 g
s
.1777 .61956 m .16814 .67322 L .15184 .67974 L p .707 .577 .707 r
F P
0 g
s
.32938 .77106 m .32964 .73404 L .34223 .74208 L p .707 .577 .707 r
F P
0 g
s
.34031 .64927 m .33075 .70293 L .31012 .69163 L p .707 .577 .707 r
F P
0 g
s
.31012 .69163 m .31968 .63797 L .34031 .64927 L p .707 .577 .707 r
F P
0 g
s
.15584 .84541 m .15098 .82706 L .15824 .82002 L p .707 .577 .707 r
F P
0 g
s
.16814 .67322 m .1777 .61956 L .20153 .61638 L p .707 .577 .707 r
F P
0 g
s
.15824 .82002 m .16309 .83837 L .15584 .84541 L p .707 .577 .707 r
F P
0 g
s
.34569 .77438 m .35055 .79273 L .33875 .79085 L p .707 .577 .707 r
F P
0 g
s
.59825 .75553 m .61615 .25591 L .64585 .26645 L p .707 .577 .707 r
F P
0 g
s
.14805 .77434 m .14832 .73731 L .16469 .72998 L p .707 .577 .707 r
F P
0 g
s
.20153 .61638 m .19197 .67004 L .16814 .67322 L p .707 .577 .707 r
F P
0 g
s
.31968 .63797 m .31012 .69163 L .28313 .68186 L p .707 .577 .707 r
F P
0 g
s
.28313 .68186 m .29269 .6282 L .31968 .63797 L p .707 .577 .707 r
F P
0 g
s
.16469 .72998 m .16442 .76701 L .14805 .77434 L p .707 .577 .707 r
F P
0 g
s
.19197 .67004 m .20153 .61638 L .23058 .61685 L p .707 .577 .707 r
F P
0 g
s
.41312 .2544 m .39521 .75403 L .3721 .76418 L p .707 .577 .707 r
F P
0 g
s
.39521 .75403 m .41312 .2544 L .44706 .24715 L p .707 .577 .707 r
F P
0 g
s
.32964 .73404 m .32938 .77106 L .30832 .76441 L p .707 .577 .707 r
F P
0 g
s
.30832 .76441 m .30859 .72738 L .32964 .73404 L p .707 .577 .707 r
F P
0 g
s
.16309 .83837 m .15824 .82002 L .17443 .81133 L p .707 .577 .707 r
F P
0 g
s
.71816 .63679 m .72771 .58313 L .69701 .57585 L p .707 .577 .707 r
F P
0 g
s
.74673 .6405 m .74957 .64087 L p .74228 .62163 L .707 .577 .707 r
F P
0 g
s
.74957 .64087 m .75913 .5872 L .72771 .58313 L p .707 .577 .707 r
F P
0 g
s
.75913 .5872 m .75911 .58727 L p .77861 .64134 L .707 .577 .707 r
F P
0 g
s
.75911 .58727 m .74957 .64087 L .77621 .6413 L p .707 .577 .707 r
F P
0 g
s
.77621 .6413 m .77861 .64134 L p .75911 .58727 L .707 .577 .707 r
F P
0 g
s
.77861 .64134 m .78817 .58767 L .75913 .5872 L p .707 .577 .707 r
F P
0 g
s
.78817 .58767 m .78743 .59183 L p .80245 .63816 L .707 .577 .707 r
F P
0 g
s
.78743 .59183 m .77861 .64134 L .8008 .63838 L p .707 .577 .707 r
F P
0 g
s
.8008 .63838 m .80245 .63816 L p .78743 .59183 L .707 .577 .707 r
F P
0 g
s
.80245 .63816 m .81201 .58449 L .78817 .58767 L p .707 .577 .707 r
F P
0 g
s
.81201 .58449 m .81147 .58749 L p .81874 .63164 L .707 .577 .707 r
F P
0 g
s
.81147 .58749 m .80245 .63816 L .81775 .63204 L p .707 .577 .707 r
F P
0 g
s
.81775 .63204 m .81874 .63164 L p .81147 .58749 L .707 .577 .707 r
F P
0 g
s
.81874 .63164 m .8283 .57798 L .81201 .58449 L p .707 .577 .707 r
F P
0 g
s
.8283 .57798 m .81874 .63164 L .82547 .62298 L p .707 .577 .707 r
F P
0 g
s
.82547 .62298 m .8259 .62243 L p .82717 .59902 L .707 .577 .707 r
F P
0 g
s
.82717 .59902 m .8283 .57798 L .82547 .62298 L .707 .577 .707 r
F
.81826 .62114 m .81816 .63492 L p .82508 .64977 L F P
0 g
s
.82534 .61274 m .81826 .62114 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82508 .64977 m .82525 .6261 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82525 .6261 m .82534 .61274 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.8259 .62243 m .83546 .56876 L .8283 .57798 L p .707 .577 .707 r
F P
0 g
s
.83546 .56876 m .8259 .62243 L .82572 .62166 L p .707 .577 .707 r
F P
0 g
s
.82534 .61274 m .82525 .6261 L p .82218 .64112 L .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82534 .61274 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82218 .64112 m .82236 .61625 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82236 .61625 m .82245 .6041 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.81816 .63492 m .818 .65817 L .82095 .65467 L p .707 .577 .707 r
F P
0 g
s
.82095 .65467 m .82508 .64977 L p .81816 .63492 L .707 .577 .707 r
F P
0 g
s
.818 .65817 m .81826 .62114 L .80189 .62847 L p .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82218 .64112 L .80959 .63308 L p .707 .577 .707 r
F P
0 g
s
.83278 .55775 m .82322 .61141 L .82221 .61044 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .82245 .6041 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80959 .63308 m .80978 .60633 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80978 .60633 m .80985 .59605 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80189 .62847 m .80179 .64183 L p .818 .65817 L .707 .577 .707 r
F P
0 g
s
.80163 .6655 m .80189 .62847 L .77784 .63402 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .80959 .63308 L .78854 .62642 L p .707 .577 .707 r
F P
0 g
s
.78854 .62642 m .7888 .5894 L .80985 .59605 L p .707 .577 .707 r
F P
0 g
s
.82052 .54601 m .81097 .59968 L .8091 .59866 L p .707 .577 .707 r
F P
0 g
s
.8091 .59866 m .79033 .58837 L p .80622 .56609 L .707 .577 .707 r
F P
0 g
s
.80622 .56609 m .82052 .54601 L .8091 .59866 L .707 .577 .707 r
F
.82221 .61044 m .81097 .59968 L p .8214 .57963 L F P
0 g
s
.8214 .57963 m .83278 .55775 L .82221 .61044 L .707 .577 .707 r
F
.82572 .62166 m .82322 .61141 L p .82889 .59165 L F P
0 g
s
.82889 .59165 m .83546 .56876 L .82572 .62166 L .707 .577 .707 r
F
.82525 .6261 m .82508 .64977 L .82383 .64605 L p F P
0 g
s
.82383 .64605 m .82218 .64112 L p .82525 .6261 L .707 .577 .707 r
F P
0 g
s
.80179 .64183 m .80163 .6655 L .8078 .66274 L p .707 .577 .707 r
F P
0 g
s
.8078 .66274 m .818 .65817 L p .80179 .64183 L .707 .577 .707 r
F P
0 g
s
.77784 .63402 m .77775 .64618 L p .80163 .6655 L .707 .577 .707 r
F P
0 g
s
.77775 .64618 m .77757 .67105 L .78507 .66932 L p .707 .577 .707 r
F P
0 g
s
.78507 .66932 m .80163 .6655 L p .77775 .64618 L .707 .577 .707 r
F P
0 g
s
.74846 .63724 m .74838 .64752 L p .77757 .67105 L .707 .577 .707 r
F P
0 g
s
.74838 .64752 m .74819 .67427 L .75452 .67357 L p .707 .577 .707 r
F P
0 g
s
.75452 .67357 m .77757 .67105 L p .74838 .64752 L .707 .577 .707 r
F P
0 g
s
.72771 .58313 m .71816 .63679 L .74673 .6405 L p .707 .577 .707 r
F P
0 g
s
.74228 .62163 m .72771 .58313 L .74673 .6405 L .707 .577 .707 r
F
.17443 .81133 m .17929 .82968 L .16309 .83837 L p F P
0 g
s
.29269 .6282 m .28313 .68186 L .25243 .67458 L p .707 .577 .707 r
F P
0 g
s
.25243 .67458 m .26199 .62092 L .29269 .6282 L p .707 .577 .707 r
F P
0 g
s
.22102 .67051 m .23058 .61685 L .26199 .62092 L p .707 .577 .707 r
F P
0 g
s
.23058 .61685 m .22102 .67051 L .19197 .67004 L p .707 .577 .707 r
F P
0 g
s
.33389 .7725 m .33875 .79085 L .31869 .79196 L p .707 .577 .707 r
F P
0 g
s
.31869 .79196 m .31383 .77361 L .33389 .7725 L p .707 .577 .707 r
F P
0 g
s
.68745 .62952 m .69701 .57585 L .67002 .56608 L p .707 .577 .707 r
F P
0 g
s
.69701 .57585 m .68745 .62952 L .71816 .63679 L p .707 .577 .707 r
F P
0 g
s
.16442 .76701 m .16469 .72998 L .18874 .72443 L p .707 .577 .707 r
F P
0 g
s
.26199 .62092 m .25243 .67458 L .22102 .67051 L p .707 .577 .707 r
F P
0 g
s
.61615 .25591 m .59825 .75553 L .55951 .74775 L p .707 .577 .707 r
F P
0 g
s
.55951 .74775 m .57742 .24812 L .61615 .25591 L p .707 .577 .707 r
F P
0 g
s
.18874 .72443 m .18848 .76146 L .16442 .76701 L p .707 .577 .707 r
F P
0 g
s
.30859 .72738 m .30832 .76441 L .28086 .75979 L p .707 .577 .707 r
F P
0 g
s
.28086 .75979 m .28113 .72277 L .30859 .72738 L p .707 .577 .707 r
F P
0 g
s
.67002 .56608 m .66047 .61975 L .68745 .62952 L p .707 .577 .707 r
F P
0 g
s
.71636 .67484 m .71662 .63781 L .68545 .63569 L p .707 .577 .707 r
F P
0 g
s
.71662 .63781 m .71636 .67484 L .74819 .67427 L p .707 .577 .707 r
F P
0 g
s
.74819 .67427 m .74846 .63724 L .71662 .63781 L p .707 .577 .707 r
F P
0 g
s
.42915 .74678 m .44706 .24715 L .48852 .24352 L p .707 .577 .707 r
F P
0 g
s
.44706 .24715 m .42915 .74678 L .39521 .75403 L p .707 .577 .707 r
F P
0 g
s
.77757 .67105 m .77784 .63402 L .74846 .63724 L p .707 .577 .707 r
F P
0 g
s
.17929 .82968 m .17443 .81133 L .19798 .80182 L p .707 .577 .707 r
F P
0 g
s
.18848 .76146 m .18874 .72443 L .21812 .72122 L p .707 .577 .707 r
F P
0 g
s
.68519 .67272 m .68545 .63569 L .65799 .63107 L p .707 .577 .707 r
F P
0 g
s
.68545 .63569 m .68519 .67272 L .71636 .67484 L p .707 .577 .707 r
F P
0 g
s
.19798 .80182 m .20283 .82017 L .17929 .82968 L p .707 .577 .707 r
F P
0 g
s
.31383 .77361 m .31869 .79196 L .29233 .79596 L p .707 .577 .707 r
F P
0 g
s
.29233 .79596 m .28748 .77761 L .31383 .77361 L p .707 .577 .707 r
F P
0 g
s
.57742 .24812 m .55951 .74775 L .51553 .74348 L p .707 .577 .707 r
F P
0 g
s
.51553 .74348 m .53344 .24385 L .57742 .24812 L p .707 .577 .707 r
F P
0 g
s
.28113 .72277 m .28086 .75979 L .24969 .75767 L p .707 .577 .707 r
F P
0 g
s
.24969 .75767 m .24996 .72064 L .28113 .72277 L p .707 .577 .707 r
F P
0 g
s
.72672 .7155 m .72187 .69715 L .6918 .70363 L p .707 .577 .707 r
F P
0 g
s
.72187 .69715 m .72672 .7155 L .75756 .70715 L p .707 .577 .707 r
F P
0 g
s
.75756 .70715 m .75271 .6888 L .72187 .69715 L p .707 .577 .707 r
F P
0 g
s
.75271 .6888 m .75756 .70715 L .78615 .69777 L p .707 .577 .707 r
F P
0 g
s
.78615 .69777 m .7813 .67942 L .75271 .6888 L p .707 .577 .707 r
F P
0 g
s
.21812 .72122 m .21786 .75824 L .18848 .76146 L p .707 .577 .707 r
F P
0 g
s
.65799 .63107 m .65773 .6681 L .68519 .67272 L p .707 .577 .707 r
F P
0 g
s
.6918 .70363 m .69665 .72198 L .72672 .7155 L p .707 .577 .707 r
F P
0 g
s
.47061 .74314 m .48852 .24352 L .53344 .24385 L p .707 .577 .707 r
F P
0 g
s
.48852 .24352 m .47061 .74314 L .42915 .74678 L p .707 .577 .707 r
F P
0 g
s
.21786 .75824 m .21812 .72122 L .24996 .72064 L p .707 .577 .707 r
F P
0 g
s
.24996 .72064 m .24969 .75767 L .21786 .75824 L p .707 .577 .707 r
F P
0 g
s
.53344 .24385 m .51553 .74348 L .47061 .74314 L p .707 .577 .707 r
F P
0 g
s
.69665 .72198 m .6918 .70363 L .66545 .70763 L p .707 .577 .707 r
F P
0 g
s
.20283 .82017 m .19798 .80182 L .22657 .79244 L p .707 .577 .707 r
F P
0 g
s
.66545 .70763 m .6703 .72598 L .69665 .72198 L p .707 .577 .707 r
F P
0 g
s
.7813 .67942 m .78615 .69777 L .8097 .68826 L p .707 .577 .707 r
F P
0 g
s
.8097 .68826 m .80485 .66991 L .7813 .67942 L p .707 .577 .707 r
F P
0 g
s
.22657 .79244 m .23143 .81079 L .20283 .82017 L p .707 .577 .707 r
F P
0 g
s
.28748 .77761 m .29233 .79596 L .26227 .80245 L p .707 .577 .707 r
F P
0 g
s
.26227 .80245 m .25741 .78409 L .28748 .77761 L p .707 .577 .707 r
F P
0 g
s
.23143 .81079 m .22657 .79244 L .25741 .78409 L p .707 .577 .707 r
F P
0 g
s
.25741 .78409 m .26227 .80245 L .23143 .81079 L p .707 .577 .707 r
F P
0 g
s
.80485 .66991 m .8097 .68826 L .82589 .67957 L p .707 .577 .707 r
F P
0 g
s
.82589 .67957 m .82104 .66122 L .80485 .66991 L p .707 .577 .707 r
F P
0 g
s
.65024 .72709 m .64539 .70874 L .63358 .70686 L p .707 .577 .707 r
F P
0 g
s
.63446 .53203 m .6249 .5857 L .62758 .59671 L p .707 .577 .707 r
F P
0 g
s
.63358 .70686 m .63844 .72521 L .65024 .72709 L p .707 .577 .707 r
F P
0 g
s
.82104 .66122 m .82589 .67957 L .83315 .67253 L p .707 .577 .707 r
F P
0 g
s
.83315 .67253 m .8283 .65418 L .82104 .66122 L p .707 .577 .707 r
F P
0 g
s
.62408 .6534 m .62434 .61637 L .62145 .60773 L p .707 .577 .707 r
F P
0 g
s
.82322 .61141 m .83278 .55775 L .83546 .56876 L p .707 .577 .707 r
F P
0 g
s
.6249 .5857 m .63446 .53203 L .64162 .52282 L p .707 .577 .707 r
F P
0 g
s
.62145 .60773 m .62119 .64475 L .62408 .6534 L p .707 .577 .707 r
F P
0 g
s
.63844 .72521 m .63358 .70686 L .6312 .70217 L p .707 .577 .707 r
F P
0 g
s
.64162 .52282 m .63206 .57648 L .6249 .5857 L p .707 .577 .707 r
F P
0 g
s
.6312 .70217 m .63605 .72052 L .63844 .72521 L p .707 .577 .707 r
F P
0 g
s
.8283 .65418 m .83315 .67253 L .83076 .66785 L p .707 .577 .707 r
F P
0 g
s
.83076 .66785 m .82591 .64949 L .8283 .65418 L p .707 .577 .707 r
F P
0 g
s
.62119 .64475 m .62145 .60773 L .62853 .59933 L p .707 .577 .707 r
F P
0 g
s
.81097 .59968 m .82052 .54601 L .83278 .55775 L p .707 .577 .707 r
F P
0 g
s
.63206 .57648 m .64162 .52282 L .65791 .5163 L p .707 .577 .707 r
F P
0 g
s
.62853 .59933 m .62827 .63635 L .62119 .64475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.37515 .64801 m .3847 .59435 L .354 .58707 L p .707 .577 .707 r
F P
0 g
s
.3847 .59435 m .37515 .64801 L .40656 .65208 L p .707 .577 .707 r
F P
0 g
s
.40656 .65208 m .41612 .59842 L .3847 .59435 L p .707 .577 .707 r
F P
0 g
s
.65791 .5163 m .64835 .56996 L .63206 .57648 L p .707 .577 .707 r
F P
0 g
s
.63605 .72052 m .6312 .70217 L .63845 .69514 L p .707 .577 .707 r
F P
0 g
s
.63845 .69514 m .64331 .71349 L .63605 .72052 L p .707 .577 .707 r
F P
0 g
s
.41612 .59842 m .40656 .65208 L .4356 .65255 L p .707 .577 .707 r
F P
0 g
s
.4356 .65255 m .44516 .59889 L .41612 .59842 L p .707 .577 .707 r
F P
0 g
s
.34444 .64073 m .354 .58707 L .32701 .5773 L p .707 .577 .707 r
F P
0 g
s
.354 .58707 m .34444 .64073 L .37515 .64801 L p .707 .577 .707 r
F P
0 g
s
.79033 .58837 m .79989 .53471 L .82052 .54601 L p .707 .577 .707 r
F P
0 g
s
.82591 .64949 m .83076 .66785 L .81896 .66597 L p .707 .577 .707 r
F P
0 g
s
.81896 .66597 m .81411 .64761 L .82591 .64949 L p .707 .577 .707 r
F P
0 g
s
.64835 .56996 m .65791 .5163 L .68175 .51312 L p .707 .577 .707 r
F P
0 g
s
.62827 .63635 m .62853 .59933 L .6449 .59199 L p .707 .577 .707 r
F P
0 g
s
.44516 .59889 m .4356 .65255 L .45944 .64937 L p .707 .577 .707 r
F P
0 g
s
.45944 .64937 m .469 .59571 L .44516 .59889 L p .707 .577 .707 r
F P
0 g
s
.31746 .63096 m .32701 .5773 L .30638 .566 L p .707 .577 .707 r
F P
0 g
s
.32701 .5773 m .31746 .63096 L .34444 .64073 L p .707 .577 .707 r
F P
0 g
s
.6449 .59199 m .64464 .62902 L .62827 .63635 L p .707 .577 .707 r
F P
0 g
s
.68175 .51312 m .67219 .56679 L .64835 .56996 L p .707 .577 .707 r
F P
0 g
s
.79989 .53471 m .79033 .58837 L .76335 .57861 L p .707 .577 .707 r
F P
0 g
s
.76335 .57861 m .77291 .52494 L .79989 .53471 L p .707 .577 .707 r
F P
0 g
s
.37335 .72079 m .37361 .68376 L .34244 .68164 L p .707 .577 .707 r
F P
0 g
s
.37361 .68376 m .37335 .72079 L .40518 .72021 L p .707 .577 .707 r
F P
0 g
s
.40518 .72021 m .40545 .68319 L .37361 .68376 L p .707 .577 .707 r
F P
0 g
s
.67219 .56679 m .68175 .51312 L .71079 .51359 L p .707 .577 .707 r
F P
0 g
s
.64331 .71349 m .63845 .69514 L .65465 .68644 L p .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .43829 .71227 L .42714 .71593 L p .707 .577 .707 r
F P
0 g
s
.42714 .71593 m .4097 .72165 L p .42306 .72523 L .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .42714 .71593 L .42306 .72523 L .707 .577 .707 r
F
.43829 .71227 m .44314 .73062 L .46669 .72111 L p F P
0 g
s
.46669 .72111 m .46184 .70276 L .45335 .70619 L p .707 .577 .707 r
F P
0 g
s
.45335 .70619 m .43829 .71227 L p .44986 .71587 L .707 .577 .707 r
F P
0 g
s
.46669 .72111 m .45335 .70619 L .44986 .71587 L .707 .577 .707 r
F
.46184 .70276 m .46669 .72111 L .48288 .71242 L p F P
0 g
s
.48288 .71242 m .47803 .69407 L .47274 .6969 L p .707 .577 .707 r
F P
0 g
s
.47274 .6969 m .46184 .70276 L p .471 .70696 L .707 .577 .707 r
F P
0 g
s
.48288 .71242 m .47274 .6969 L .471 .70696 L .707 .577 .707 r
F
.47803 .69407 m .48288 .71242 L .49014 .70538 L p F P
0 g
s
.49014 .70538 m .48529 .68703 L .4831 .68915 L p .707 .577 .707 r
F P
0 g
s
.4831 .68915 m .47803 .69407 L p .48377 .69943 L .707 .577 .707 r
F P
0 g
s
.49014 .70538 m .4831 .68915 L .48377 .69943 L .707 .577 .707 r
F
.47499 .70412 m .48207 .69572 L p .47679 .67357 L F P
0 g
s
.48207 .69572 m .48233 .65869 L .47525 .66709 L p .707 .577 .707 r
F P
0 g
s
.48207 .69572 m .47917 .68707 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48233 .65869 m .48221 .67541 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48221 .67541 m .48207 .69572 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.47525 .66709 m .47513 .68312 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.47513 .68312 m .47499 .70412 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .47499 .70412 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45888 .67442 m .45876 .69114 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45876 .69114 m .45862 .71145 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .45862 .71145 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43483 .67997 m .43469 .69867 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43469 .69867 m .43456 .71699 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.40545 .68319 m .40518 .72021 L .43456 .71699 L p .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .43483 .67997 L .40545 .68319 L p .707 .577 .707 r
F P
0 g
s
.65465 .68644 m .6595 .70479 L .64331 .71349 L p .707 .577 .707 r
F P
0 g
s
.64464 .62902 m .6449 .59199 L .66895 .58645 L p .707 .577 .707 r
F P
0 g
s
.34218 .71866 m .34244 .68164 L .31498 .67702 L p .707 .577 .707 r
F P
0 g
s
.34244 .68164 m .34218 .71866 L .37335 .72079 L p .707 .577 .707 r
F P
0 g
s
.81411 .64761 m .81896 .66597 L .7989 .66708 L p .707 .577 .707 r
F P
0 g
s
.7989 .66708 m .79405 .64873 L .81411 .64761 L p .707 .577 .707 r
F P
0 g
s
.30638 .566 m .29682 .61966 L .31746 .63096 L p .707 .577 .707 r
F P
0 g
s
.469 .59571 m .45944 .64937 L .47573 .64286 L p .707 .577 .707 r
F P
0 g
s
.47573 .64286 m .48529 .58919 L .469 .59571 L p .707 .577 .707 r
F P
0 g
s
.38371 .74834 m .37886 .72999 L .34879 .73648 L p .707 .577 .707 r
F P
0 g
s
.37886 .72999 m .38371 .74834 L .41455 .74 L p .707 .577 .707 r
F P
0 g
s
.41455 .74 m .4097 .72165 L .37886 .72999 L p .707 .577 .707 r
F P
0 g
s
.29682 .61966 m .30638 .566 L .29413 .55426 L p .707 .577 .707 r
F P
0 g
s
.4097 .72165 m .41455 .74 L .44314 .73062 L p .707 .577 .707 r
F P
0 g
s
.77291 .52494 m .76335 .57861 L .73265 .57133 L p .707 .577 .707 r
F P
0 g
s
.73265 .57133 m .7422 .51766 L .77291 .52494 L p .707 .577 .707 r
F P
0 g
s
.70123 .56726 m .71079 .51359 L .7422 .51766 L p .707 .577 .707 r
F P
0 g
s
.71079 .51359 m .70123 .56726 L .67219 .56679 L p .707 .577 .707 r
F P
0 g
s
.34879 .73648 m .35364 .75483 L .38371 .74834 L p .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .45888 .67442 L .43483 .67997 L p .707 .577 .707 r
F P
0 g
s
.66895 .58645 m .66869 .62347 L .64464 .62902 L p .707 .577 .707 r
F P
0 g
s
.31498 .67702 m .31472 .71405 L .34218 .71866 L p .707 .577 .707 r
F P
0 g
s
.7422 .51766 m .73265 .57133 L .70123 .56726 L p .707 .577 .707 r
F P
0 g
s
.7888 .5894 m .78854 .62642 L .76108 .62181 L p .707 .577 .707 r
F P
0 g
s
.76108 .62181 m .76134 .58478 L .7888 .5894 L p .707 .577 .707 r
F P
0 g
s
.35364 .75483 m .34879 .73648 L .32244 .74047 L p .707 .577 .707 r
F P
0 g
s
.31472 .71405 m .31498 .67702 L .29393 .67036 L p .707 .577 .707 r
F P
0 g
s
.32244 .74047 m .32729 .75883 L .35364 .75483 L p .707 .577 .707 r
F P
0 g
s
.66869 .62347 m .66895 .58645 L .69834 .58323 L p .707 .577 .707 r
F P
0 g
s
.6595 .70479 m .65465 .68644 L .67819 .67694 L p .707 .577 .707 r
F P
0 g
s
.29413 .55426 m .28457 .60793 L .29682 .61966 L p .707 .577 .707 r
F P
0 g
s
.67819 .67694 m .68305 .69529 L .6595 .70479 L p .707 .577 .707 r
F P
0 g
s
.29393 .67036 m .29366 .70739 L .31472 .71405 L p .707 .577 .707 r
F P
0 g
s
.79405 .64873 m .7989 .66708 L .77255 .67107 L p .707 .577 .707 r
F P
0 g
s
.77255 .67107 m .76769 .65272 L .79405 .64873 L p .707 .577 .707 r
F P
0 g
s
.76134 .58478 m .76108 .62181 L .72991 .61968 L p .707 .577 .707 r
F P
0 g
s
.72991 .61968 m .73017 .58265 L .76134 .58478 L p .707 .577 .707 r
F P
0 g
s
.47499 .70412 m .47525 .66709 L .45888 .67442 L p .707 .577 .707 r
F P
0 g
s
.48529 .58919 m .47573 .64286 L .48289 .63364 L p .707 .577 .707 r
F P
0 g
s
.48289 .63364 m .49245 .57998 L .48529 .58919 L p .707 .577 .707 r
F P
0 g
s
.69834 .58323 m .69807 .62026 L .66869 .62347 L p .707 .577 .707 r
F P
0 g
s
.32729 .75883 m .32244 .74047 L .30238 .74159 L p .707 .577 .707 r
F P
0 g
s
.69807 .62026 m .69834 .58323 L .73017 .58265 L p .707 .577 .707 r
F P
0 g
s
.28457 .60793 m .29413 .55426 L .29145 .54325 L p .707 .577 .707 r
F P
0 g
s
.30238 .74159 m .30723 .75994 L .32729 .75883 L p .707 .577 .707 r
F P
0 g
s
.73017 .58265 m .72991 .61968 L .69807 .62026 L p .707 .577 .707 r
F P
0 g
s
.29366 .70739 m .29393 .67036 L .28133 .66232 L p .707 .577 .707 r
F P
0 g
s
.68305 .69529 m .67819 .67694 L .70679 .66755 L p .707 .577 .707 r
F P
0 g
s
.70679 .66755 m .71164 .6859 L .68305 .69529 L p .707 .577 .707 r
F P
0 g
s
.76769 .65272 m .77255 .67107 L .74248 .67756 L p .707 .577 .707 r
F P
0 g
s
.74248 .67756 m .73762 .65921 L .76769 .65272 L p .707 .577 .707 r
F P
0 g
s
.28133 .66232 m .28107 .69935 L .29366 .70739 L p .707 .577 .707 r
F P
0 g
s
.29145 .54325 m .28189 .59691 L .28457 .60793 L p .707 .577 .707 r
F P
0 g
s
.71164 .6859 m .70679 .66755 L .73762 .65921 L p .707 .577 .707 r
F P
0 g
s
.73762 .65921 m .74248 .67756 L .71164 .6859 L p .707 .577 .707 r
F P
0 g
s
.30723 .75994 m .30238 .74159 L .29057 .73971 L p .707 .577 .707 r
F P
0 g
s
.29057 .73971 m .29543 .75806 L .30723 .75994 L p .707 .577 .707 r
F P
0 g
s
.49245 .57998 m .48289 .63364 L .48021 .62263 L p .707 .577 .707 r
F P
0 g
s
.48021 .62263 m .48977 .56896 L .49245 .57998 L p .707 .577 .707 r
F P
0 g
s
.28189 .59691 m .29145 .54325 L .2986 .53403 L p .707 .577 .707 r
F P
0 g
s
.28107 .69935 m .28133 .66232 L .27844 .65367 L p .707 .577 .707 r
F P
0 g
s
.27844 .65367 m .27817 .6907 L .28107 .69935 L p .707 .577 .707 r
F P
0 g
s
.2986 .53403 m .28905 .5877 L .28189 .59691 L p .707 .577 .707 r
F P
0 g
s
.29543 .75806 m .29057 .73971 L .28819 .73502 L p .707 .577 .707 r
F P
0 g
s
.47944 .65004 m .47917 .68707 L .46658 .67903 L p .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4711 .68046 L .4783 .68161 L p .707 .577 .707 r
F P
0 g
s
.47917 .68707 m .4793 .66875 L p .48233 .65869 L .707 .577 .707 r
F P
0 g
s
.4783 .68161 m .4829 .68234 L p .47718 .69591 L .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4783 .68161 L .47718 .69591 L .707 .577 .707 r
F
.4793 .66875 m .47944 .65004 L .48052 .65327 L p F P
0 g
s
.48052 .65327 m .48233 .65869 L p .4793 .66875 L .707 .577 .707 r
F P
0 g
s
.28819 .73502 m .29304 .75337 L .29543 .75806 L p .707 .577 .707 r
F P
0 g
s
.48977 .56896 m .48021 .62263 L .46796 .6109 L p .707 .577 .707 r
F P
0 g
s
.46796 .6109 m .47751 .55723 L .48977 .56896 L p .707 .577 .707 r
F P
0 g
s
.28905 .5877 m .2986 .53403 L .3149 .52752 L p .707 .577 .707 r
F P
0 g
s
.48529 .68703 m .49014 .70538 L .48775 .70069 L p .707 .577 .707 r
F P
0 g
s
.48775 .70069 m .4829 .68234 L .48529 .68703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27817 .6907 m .27844 .65367 L .28552 .64527 L p .707 .577 .707 r
F P
0 g
s
.28552 .64527 m .28526 .6823 L .27817 .6907 L p .707 .577 .707 r
F P
0 g
s
.3149 .52752 m .30534 .58118 L .28905 .5877 L p .707 .577 .707 r
F P
0 g
s
.46658 .67903 m .46684 .642 L .47944 .65004 L p .707 .577 .707 r
F P
0 g
s
.47751 .55723 m .46796 .6109 L .44732 .59959 L p .707 .577 .707 r
F P
0 g
s
.44732 .59959 m .45688 .54593 L .47751 .55723 L p .707 .577 .707 r
F P
0 g
s
.29304 .75337 m .28819 .73502 L .29544 .72798 L p .707 .577 .707 r
F P
0 g
s
.30534 .58118 m .3149 .52752 L .33874 .52434 L p .707 .577 .707 r
F P
0 g
s
.29544 .72798 m .3003 .74634 L .29304 .75337 L p .707 .577 .707 r
F P
0 g
s
.4829 .68234 m .48775 .70069 L .47595 .69881 L p .707 .577 .707 r
F P
0 g
s
.28526 .6823 m .28552 .64527 L .30189 .63794 L p .707 .577 .707 r
F P
0 g
s
.33874 .52434 m .32918 .578 L .30534 .58118 L p .707 .577 .707 r
F P
0 g
s
.45688 .54593 m .44732 .59959 L .42034 .58982 L p .707 .577 .707 r
F P
0 g
s
.42034 .58982 m .4299 .53616 L .45688 .54593 L p .707 .577 .707 r
F P
0 g
s
.30189 .63794 m .30163 .67497 L .28526 .6823 L p .707 .577 .707 r
F P
0 g
s
.32918 .578 m .33874 .52434 L .36778 .52481 L p .707 .577 .707 r
F P
0 g
s
.46684 .642 m .46658 .67903 L .44553 .67237 L p .707 .577 .707 r
F P
0 g
s
.44553 .67237 m .44579 .63534 L .46684 .642 L p .707 .577 .707 r
F P
0 g
s
.3003 .74634 m .29544 .72798 L .31164 .71929 L p .707 .577 .707 r
F P
0 g
s
.31164 .71929 m .31649 .73764 L .3003 .74634 L p .707 .577 .707 r
F P
0 g
s
.4299 .53616 m .42034 .58982 L .38963 .58255 L p .707 .577 .707 r
F P
0 g
s
.38963 .58255 m .39919 .52888 L .4299 .53616 L p .707 .577 .707 r
F P
0 g
s
.35822 .57847 m .36778 .52481 L .39919 .52888 L p .707 .577 .707 r
F P
0 g
s
.36778 .52481 m .35822 .57847 L .32918 .578 L p .707 .577 .707 r
F P
0 g
s
.4711 .68046 m .47595 .69881 L .45589 .69993 L p .707 .577 .707 r
F P
0 g
s
.45589 .69993 m .45104 .68157 L .4711 .68046 L p .707 .577 .707 r
F P
0 g
s
.30163 .67497 m .30189 .63794 L .32594 .6324 L p .707 .577 .707 r
F P
0 g
s
.39919 .52888 m .38963 .58255 L .35822 .57847 L p .707 .577 .707 r
F P
0 g
s
.32594 .6324 m .32568 .66942 L .30163 .67497 L p .707 .577 .707 r
F P
0 g
s
.44579 .63534 m .44553 .67237 L .41807 .66775 L p .707 .577 .707 r
F P
0 g
s
.41807 .66775 m .41833 .63073 L .44579 .63534 L p .707 .577 .707 r
F P
0 g
s
.31649 .73764 m .31164 .71929 L .33518 .70978 L p .707 .577 .707 r
F P
0 g
s
.32568 .66942 m .32594 .6324 L .35532 .62918 L p .707 .577 .707 r
F P
0 g
s
.33518 .70978 m .34004 .72813 L .31649 .73764 L p .707 .577 .707 r
F P
0 g
s
.45104 .68157 m .45589 .69993 L .42954 .70392 L p .707 .577 .707 r
F P
0 g
s
.42954 .70392 m .42468 .68557 L .45104 .68157 L p .707 .577 .707 r
F P
0 g
s
.41833 .63073 m .41807 .66775 L .3869 .66563 L p .707 .577 .707 r
F P
0 g
s
.3869 .66563 m .38716 .6286 L .41833 .63073 L p .707 .577 .707 r
F P
0 g
s
.35532 .62918 m .35506 .6662 L .32568 .66942 L p .707 .577 .707 r
F P
0 g
s
.35506 .6662 m .35532 .62918 L .38716 .6286 L p .707 .577 .707 r
F P
0 g
s
.38716 .6286 m .3869 .66563 L .35506 .6662 L p .707 .577 .707 r
F P
0 g
s
.34004 .72813 m .33518 .70978 L .36377 .7004 L p .707 .577 .707 r
F P
0 g
s
.36377 .7004 m .36863 .71875 L .34004 .72813 L p .707 .577 .707 r
F P
0 g
s
.42468 .68557 m .42954 .70392 L .39947 .71041 L p .707 .577 .707 r
F P
0 g
s
.39947 .71041 m .39461 .69206 L .42468 .68557 L p .707 .577 .707 r
F P
0 g
s
.36863 .71875 m .36377 .7004 L .39461 .69206 L p .707 .577 .707 r
F P
0 g
s
.39461 .69206 m .39947 .71041 L .36863 .71875 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
QGoo6@00Ogoo001mOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001fOol007Qoo`D0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H0071oo`00M7oo1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000K7oo001b
Ool200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH01000FUH00000JWoo001`Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00Igoo001^Ool20005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH2001UOol006eoo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001oogoo069oo`00KGoo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF0P00HWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00Oomoo`1OOol0
06aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00YJEP03001oogoo05ioo`00K7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<007ooOol0GWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006ao
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF
0P00Ggoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF0P00Ggoo001/Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH2001OOol006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00]JEP8005mo
o`00K7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]o
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001oogoo05eoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005mo
o`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Ggoo001[Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001OOol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0005moo`00Jgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0Ggoo
001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001POol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001P
Ool006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00H7oo001Z
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001POol006Yoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00
JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80065oo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000=oo`L005Moo`00JGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1@000UYF00<005YFFUH00UYF2000Cgoo001YOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00@005YFFUIJEPL004Qo
o`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@004Aoo`00GGoo40001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000@7oo001G
Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000?Woo001DOol30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF0`00>goo001C
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000i
Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH3000gOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000eOol0059oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8003=oo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Woo001BOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000aOol0055oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP07001JEUYFFUIooeYF0000
0eYF00<007ooOol0;Woo001AOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8002moo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002moo`00DGoo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF0P000UYF1P000UYF00<005YF00000`0027oo1P001UYF00<005YFFUH0
1UYF00@005YFFUIoo`=JEP06001JEUYF001JEP00;goo001AOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH30000
0eYF001JEP05FUH00`00FUIJEP03FUH4000:Ool40002FUH00`00FUIJEP06FUH00`00FUIoo`03FUH0
1`00FUIJEUYF001JEP0002moo`00DGoo0P000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH00003000:Ool4
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo001AOol00eYF001JEP02FUH40002FUH00`00
FUH000030006Ool00`00FUH000060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF
00<005YFFUH00eYF4@001Woo0P0015YF00<005YFFUH015YF00H005YFFUIJEP00FUH`Ool0051oo`04
001JEP00FUH30005FUH00`00FUIJEP03FUH40002Ool01000FUIJEP001EYF10000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF009JEP06001JEP00001JEP001UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2`0000=J
EP00FUH01EYF00H005YFFUH005YF000`Ool0051oo`04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF
FUH005YF0002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@001UYF00H005YFFUH005YF000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF009JEP<000IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH00009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00L005YFFUIJEP00
FUH0000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPL000QJ
EP<00003FUH005YF00EJEP03001JEUYF008000QJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFOol0<7oo001@Ool00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0005FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFOol0<7oo001@Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00@0
05YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF000aOol0051oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUH00000FUH0035oo`00DGoo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP06001JEUYF001JEP00<Goo001BOol00`00FUH00006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH0035oo`00=Woo40003Goo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF001JEP00FUH00008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000b
Ool0035oo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000Moo`03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP800003FUH00000039oo`00;goo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF
000015YF00@005YFFUIJEPT000QJEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH00`00FUIJEP02000bOol002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00EJEQ40009JEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009J
EP03001JEP0000=JEPL0009oo`<00003FUH005YF00MJEP03001JEUYF00AJEP04OomJEUYF0007FUH4
0004FUH00`00FUIJEP02000bOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEP000002Ool80004FUH00`00FUIJEP06FUH01000FUIJEUYF
20000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH01000FUH005YF0P000eYF1P000goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00001@0000AJEP00FUIJEP80039oo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP04001JEP000007FUH01000FUIJ
EUYF2`000UYF00<005YFFUH01EYF00=oo`00FUH00UYF1P0015YF00@005YF0000009JEP80039oo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YF00000`000eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF
00@005YFFUIJEP@0039oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00<Woo000[Ool20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000bOol002Yoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEPh0039oo`00:Woo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH60003FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP00035oo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF000aOol002Yoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
0080009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000`Ool002Yoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP@0
00MJEP03001JEUYF00IJEP03001JEUYF009JEPd0031oo`00:Woo0P000eYF00@005YFFUIJEQ0000AJ
EP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH80002FUH20002Ool01000FUIJEP001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH000000080009JEP03001JEUYF
00800003FUH005YF00QJEP03001JEUYF00EJEPP0009oo`8000=JEP04001JEUYF000`Ool002Yoo`03
FUH005YF009JEP@0009JEP04001JEP00000:Ool70005FUH00`00FUH00003FUH50005FUH01000FUIJ
EUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH5
0004FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool30005FUH00`00FUH0000`Ool002Uoo`04001J
EP00FUH30005FUH01000FUIJEUYF0`003Woo100000AJEP00FUH0009JEP04001JEUYFFUH50002FUH0
1000FUIJEUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00H00003FUH005YF
009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00IJEP8000MJEP03001JEUYF00IJEP@000Yoo`8000=JEP03001JEUYF009JEP80035oo`00:Goo00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP@000ioo`800004FUH000000005FUH01000
FUIJEUYF2@0000Eoo`00FUIJEP0000AJEP<000IJEPl00003FUH0000000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<000QJEP03001JEUYF00=JEP<0
00Yoo`@000EJEP03001JEUYF009JEP03001oogoo031oo`00:Goo0P0015YF00<005YFFUH00UYF00<0
05YFFUH01UYF00<005YFFUH010002goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
009JEQL000=JEP03001JEUYF009JEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEP00008000Uoo`@0
009JEP03001JEUYF00EJEP04001JEP00000cOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH900000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
0`0027oo10001UYF00<005YFFUH015YF0`00=Goo000YOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP06FUH00`00FUIJEP040009Ool200000eYF001JEP08FUH01000FUIJEUYF0P00>7oo000YOol00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH4000:Ool30004FUH00`00FUIJEP06
FUH01000FUH00000>Woo000YOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF00IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001oo`05
Ool40007FUH00`00FUIJEP05FUH3000lOol002Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00MJEP04001JEUYFFUH70002FUH50006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020002
FUH00`00FUH00002Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000oOol002Yoo`04001J
EUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030005FUH0
0`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH01000FUIJEUYF0`000UYF
00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=J
EP<0009JEP03001JEP0000D000IJEP03001JEUYF00MJEP03001JEP000080045oo`00:goo0`001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00UYF10001EYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00@005YF0000
00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40014Ool002eoo`03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP<00004FUH005YFFUH200000eYF
001JEP07FUH00`00FUIJEP04FUH50007FUH01000FUIJEUYF1@001EYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP0000001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01000B7oo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH70019Ool0
031oo`800003FUH005YF00IJEP03001JEUYF00EJEPP0009JEP03001JEUYF00EJEP03001JEUYF0080
00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@000=o
o`D004Qoo`00<Woo0`001EYF2@0015YF00@005YFFUIJEPP0009JEP@000MJEP03001JEUYF009JEP80
009JEP03001JEUYF00AJEP03001JEP0000<000MJEP03001JEUYF00=JEP<000aJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH60007Ool50018Ool0039oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP05FUH00`00FUH000020002Ool2FUH00`00FUIJEP02FUH40002FUH00`00FUIJ
EP06FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0?000<Ool50018Ool002ioo`@000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP03FUH30005Ool2FUH50006FUH0
0`00FUIJEP05FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEUYF10003Goo0`00BGoo000/Ool30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUH000050005
Ool400000eYF001JEP08FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH3001IOol0
02Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP03001JEUYF009JEP80009JEP800003Ool0000000@000IJEP03001JEUYF00IJEP03
001JEP00008000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEP0005Uoo`00:Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YF
FUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP`005Uoo`00
:Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001J
EUYF00AJEQT000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP04001J
EUYF001IOol002Qoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60006
FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUH00004FUH01@00FUIJEUYF0000F7oo000XOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00@0
05YFFUH005Qoo`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP04001JEUYFFUH60002FUH0
0`00FUIJEP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUH000030006FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00@005YFFUH005Qo
o`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00@005YFFUIJEP80
009JEP04001JEUYFFUH600000eYF001oo`02Ool01000FUIJEP000eYF0P001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YF
FUH00eYF2`000UYF00<007ooOol0EGoo000XOol00`00FUH00003FUH00`00FUIJEP03FUH6000AOol8
0002FUH60002FUH01000FUIJEUYF0P000goo00D005YFFUH005YF00<000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00AJ
EP<0009oo`8000=JEP@005Moo`00:7oo00<005YF00000eYF00<005YF00000`007goo1P0015YF00@0
05YFFUIJEP8000=oo`03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000005FUH00`00Oomo
o`030005FUH00`00FUH0001GOol002Qoo`03001JEP0000=JEP800004FUH00000000ROol600000eYF
001JEP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF0`000eYF
00<005YFFUH00UYF0P00F7oo000XOol01000FUH005YF0P0015YF00<005YF00000`0047oo0`001Woo
1@000UYF200000=JEP0000000goo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0Egoo000XOol00`00FUH000020005FUH00`00FUIJ
EP03FUHI0003FUH400000eYF001JEP03FUH00`00FUIJEP020003Ool00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000FUH00000FWoo000XOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00000010001EYF
00<005YFFUH00eYF00@005YFFUH000=oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000QJEP03001JEUYF00=JEP04001J
EP000005FUH3001LOol002Qoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000Aoo`03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP8000QJEP03001JEUYF00=JEP04001JEP000003FUH2001OOol002Qoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP000goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YFFUH00eYF00D0
05YFFUH005YF0080065oo`00:7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001oo`03Ool00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02001SOol002Qoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF
1`000UYF1@0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo000YOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH0
1000FUIJEUYF0`000UYF00<007ooOol017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00IWoo000[Ool30004FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUH000000eYF
0P002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P00IWoo000^Ool3000015YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF1@001eYF00<005YFFUH00eYF0`001EYF00<007ooOol02Woo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0IGoo000a
Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH00`00FUH000030003
FUH00`00FUIJEP02000?Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00
FUIJEP07FUH01000FUIJEUYF0P00J7oo000aOol20005FUH00`00FUIJEP05FUH40004FUH>0007FUH3
000DOol30009FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP07FUH01000FUH00000JWoo
000`Ool20007FUH00`00FUIJEP02FUH:0003Ool40007FUH00`00FUIJEP03FUH2000IOol40005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP04FUH5001/Ool002ioo`800003FUH005YF00IJ
EP03001JEP00008000Uoo`@0009JEP03001JEUYF00IJEP03001JEP0000<001moo`@00003FUH005YF
00]JEP03001JEUYF01EJEP03001JEP0000@0075oo`00;Goo00<005YFFUH00UYF00<005YFFUH00eYF
0`0027oo10001UYF00<005YFFUH01EYF0`009goo20001UYF00<005YFFUH045YF1`00MWoo000[Ool3
0004FUH00`00FUH000030007Ool400000eYF001JEP08FUH00`00FUIJEP02FUH2000bOolI001mOol0
02Yoo`04001JEUYF0004FUH20005Ool60006FUH00`00FUIJEP06FUH00`00FUH00002003:Ool002Yo
o`05001JEUYFFUH00002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3003=Ool002]oo`03
001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@00=1oo`00:goo00@0
05YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD00=Aoo`00;7oo0P0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01000fGoo000/Ool01000FUIJEP001UYF00@005YFFUIJEPH00=eo
o`00;7oo0P000UYF00@005YFFUIJEPH00>=oo`00;Woo1P00jGoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58095 .72883 m .59051 .67517 L .55981 .66789 L p .707 .577 .707 r
F P
0 g
s
.60952 .73254 m .61236 .7329 L p .60508 .71366 L .707 .577 .707 r
F P
0 g
s
.61236 .7329 m .62192 .67924 L .59051 .67517 L p .707 .577 .707 r
F P
0 g
s
.62192 .67924 m .62191 .67931 L p .64141 .73337 L .707 .577 .707 r
F P
0 g
s
.62191 .67931 m .61236 .7329 L .639 .73334 L p .707 .577 .707 r
F P
0 g
s
.639 .73334 m .64141 .73337 L p .62191 .67931 L .707 .577 .707 r
F P
0 g
s
.64141 .73337 m .65097 .67971 L .62192 .67924 L p .707 .577 .707 r
F P
0 g
s
.65097 .67971 m .65023 .68387 L p .66524 .7302 L .707 .577 .707 r
F P
0 g
s
.65023 .68387 m .64141 .73337 L .6636 .73042 L p .707 .577 .707 r
F P
0 g
s
.6636 .73042 m .66524 .7302 L p .65023 .68387 L .707 .577 .707 r
F P
0 g
s
.66524 .7302 m .6748 .67653 L .65097 .67971 L p .707 .577 .707 r
F P
0 g
s
.6748 .67653 m .67427 .67953 L p .68154 .72368 L .707 .577 .707 r
F P
0 g
s
.67427 .67953 m .66524 .7302 L .68055 .72408 L p .707 .577 .707 r
F P
0 g
s
.68055 .72408 m .68154 .72368 L p .67427 .67953 L .707 .577 .707 r
F P
0 g
s
.68154 .72368 m .6911 .67002 L .6748 .67653 L p .707 .577 .707 r
F P
0 g
s
.6911 .67002 m .68154 .72368 L .68826 .71502 L p .707 .577 .707 r
F P
0 g
s
.68826 .71502 m .6887 .71446 L p .68996 .69106 L .707 .577 .707 r
F P
0 g
s
.68996 .69106 m .6911 .67002 L .68826 .71502 L .707 .577 .707 r
F
.68105 .71318 m .68096 .72696 L p .68787 .74181 L F P
0 g
s
.68814 .70478 m .68105 .71318 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68787 .74181 m .68804 .71814 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68804 .71814 m .68814 .70478 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.6887 .71446 m .69826 .6608 L .6911 .67002 L p .707 .577 .707 r
F P
0 g
s
.69826 .6608 m .6887 .71446 L .68851 .7137 L p .707 .577 .707 r
F P
0 g
s
.68814 .70478 m .68804 .71814 L p .68498 .73316 L .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68814 .70478 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68498 .73316 m .68515 .70829 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68515 .70829 m .68524 .69614 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68096 .72696 m .68079 .75021 L .68374 .74671 L p .707 .577 .707 r
F P
0 g
s
.68374 .74671 m .68787 .74181 L p .68096 .72696 L .707 .577 .707 r
F P
0 g
s
.68079 .75021 m .68105 .71318 L .66469 .72051 L p .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68498 .73316 L .67239 .72512 L p .707 .577 .707 r
F P
0 g
s
.69558 .64979 m .68602 .70345 L .685 .70248 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .68524 .69614 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67239 .72512 m .67258 .69837 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67258 .69837 m .67265 .68809 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.66469 .72051 m .66459 .73387 L p .68079 .75021 L .707 .577 .707 r
F P
0 g
s
.66442 .75754 m .66469 .72051 L .64063 .72606 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .67239 .72512 L .65133 .71846 L p .707 .577 .707 r
F P
0 g
s
.65133 .71846 m .65159 .68143 L .67265 .68809 L p .707 .577 .707 r
F P
0 g
s
.68332 .63805 m .67376 .69172 L .6719 .6907 L p .707 .577 .707 r
F P
0 g
s
.6719 .6907 m .65313 .68041 L p .66901 .65813 L .707 .577 .707 r
F P
0 g
s
.66901 .65813 m .68332 .63805 L .6719 .6907 L .707 .577 .707 r
F
.685 .70248 m .67376 .69172 L p .68419 .67167 L F P
0 g
s
.68419 .67167 m .69558 .64979 L .685 .70248 L .707 .577 .707 r
F
.68851 .7137 m .68602 .70345 L p .69169 .68369 L F P
0 g
s
.69169 .68369 m .69826 .6608 L .68851 .7137 L .707 .577 .707 r
F
.68804 .71814 m .68787 .74181 L .68663 .73809 L p F P
0 g
s
.68663 .73809 m .68498 .73316 L p .68804 .71814 L .707 .577 .707 r
F P
0 g
s
.66459 .73387 m .66442 .75754 L .67059 .75477 L p .707 .577 .707 r
F P
0 g
s
.67059 .75477 m .68079 .75021 L p .66459 .73387 L .707 .577 .707 r
F P
0 g
s
.64063 .72606 m .64055 .73822 L p .66442 .75754 L .707 .577 .707 r
F P
0 g
s
.64055 .73822 m .64037 .76309 L .64787 .76136 L p .707 .577 .707 r
F P
0 g
s
.64787 .76136 m .66442 .75754 L p .64055 .73822 L .707 .577 .707 r
F P
0 g
s
.61125 .72928 m .61118 .73956 L p .64037 .76309 L .707 .577 .707 r
F P
0 g
s
.61118 .73956 m .61099 .7663 L .61731 .76561 L p .707 .577 .707 r
F P
0 g
s
.61731 .76561 m .64037 .76309 L p .61118 .73956 L .707 .577 .707 r
F P
0 g
s
.59051 .67517 m .58095 .72883 L .60952 .73254 L p .707 .577 .707 r
F P
0 g
s
.60508 .71366 m .59051 .67517 L .60952 .73254 L .707 .577 .707 r
F
.55025 .72155 m .55981 .66789 L .53282 .65812 L p F P
0 g
s
.55981 .66789 m .55025 .72155 L .58095 .72883 L p .707 .577 .707 r
F P
0 g
s
.52326 .71179 m .53282 .65812 L .51219 .64682 L p .707 .577 .707 r
F P
0 g
s
.53282 .65812 m .52326 .71179 L .55025 .72155 L p .707 .577 .707 r
F P
0 g
s
.57915 .76688 m .57942 .72985 L .54824 .72773 L p .707 .577 .707 r
F P
0 g
s
.57942 .72985 m .57915 .76688 L .61099 .7663 L p .707 .577 .707 r
F P
0 g
s
.61099 .7663 m .61125 .72928 L .57942 .72985 L p .707 .577 .707 r
F P
0 g
s
.64037 .76309 m .64063 .72606 L .61125 .72928 L p .707 .577 .707 r
F P
0 g
s
.54798 .76475 m .54824 .72773 L .52079 .72311 L p .707 .577 .707 r
F P
0 g
s
.54824 .72773 m .54798 .76475 L .57915 .76688 L p .707 .577 .707 r
F P
0 g
s
.58952 .80753 m .58466 .78918 L .5546 .79567 L p .707 .577 .707 r
F P
0 g
s
.58466 .78918 m .58952 .80753 L .62036 .79919 L p .707 .577 .707 r
F P
0 g
s
.62036 .79919 m .6155 .78084 L .58466 .78918 L p .707 .577 .707 r
F P
0 g
s
.6155 .78084 m .62036 .79919 L .64895 .78981 L p .707 .577 .707 r
F P
0 g
s
.64895 .78981 m .6441 .77146 L .6155 .78084 L p .707 .577 .707 r
F P
0 g
s
.52079 .72311 m .52052 .76014 L .54798 .76475 L p .707 .577 .707 r
F P
0 g
s
.5546 .79567 m .55945 .81402 L .58952 .80753 L p .707 .577 .707 r
F P
0 g
s
.51219 .64682 m .50263 .70048 L .52326 .71179 L p .707 .577 .707 r
F P
0 g
s
.50263 .70048 m .51219 .64682 L .49993 .63508 L p .707 .577 .707 r
F P
0 g
s
.52052 .76014 m .52079 .72311 L .49973 .71646 L p .707 .577 .707 r
F P
0 g
s
.55945 .81402 m .5546 .79567 L .52824 .79967 L p .707 .577 .707 r
F P
0 g
s
.52824 .79967 m .5331 .81802 L .55945 .81402 L p .707 .577 .707 r
F P
0 g
s
.6441 .77146 m .64895 .78981 L .6725 .7803 L p .707 .577 .707 r
F P
0 g
s
.6725 .7803 m .66764 .76195 L .6441 .77146 L p .707 .577 .707 r
F P
0 g
s
.49973 .71646 m .49947 .75348 L .52052 .76014 L p .707 .577 .707 r
F P
0 g
s
.49993 .63508 m .49038 .68875 L .50263 .70048 L p .707 .577 .707 r
F P
0 g
s
.5331 .81802 m .52824 .79967 L .50818 .80078 L p .707 .577 .707 r
F P
0 g
s
.50818 .80078 m .51304 .81913 L .5331 .81802 L p .707 .577 .707 r
F P
0 g
s
.49947 .75348 m .49973 .71646 L .48714 .70841 L p .707 .577 .707 r
F P
0 g
s
.66764 .76195 m .6725 .7803 L .68869 .77161 L p .707 .577 .707 r
F P
0 g
s
.68869 .77161 m .68383 .75326 L .66764 .76195 L p .707 .577 .707 r
F P
0 g
s
.49038 .68875 m .49993 .63508 L .49725 .62407 L p .707 .577 .707 r
F P
0 g
s
.48714 .70841 m .48688 .74544 L .49947 .75348 L p .707 .577 .707 r
F P
0 g
s
.51304 .81913 m .50818 .80078 L .49638 .7989 L p .707 .577 .707 r
F P
0 g
s
.49725 .62407 m .4877 .67774 L .49038 .68875 L p .707 .577 .707 r
F P
0 g
s
.49638 .7989 m .50124 .81725 L .51304 .81913 L p .707 .577 .707 r
F P
0 g
s
.68383 .75326 m .68869 .77161 L .69595 .76457 L p .707 .577 .707 r
F P
0 g
s
.69595 .76457 m .69109 .74622 L .68383 .75326 L p .707 .577 .707 r
F P
0 g
s
.48688 .74544 m .48714 .70841 L .48424 .69977 L p .707 .577 .707 r
F P
0 g
s
.68602 .70345 m .69558 .64979 L .69826 .6608 L p .707 .577 .707 r
F P
0 g
s
.4877 .67774 m .49725 .62407 L .50441 .61486 L p .707 .577 .707 r
F P
0 g
s
.50124 .81725 m .49638 .7989 L .49399 .79421 L p .707 .577 .707 r
F P
0 g
s
.50441 .61486 m .49485 .66852 L .4877 .67774 L p .707 .577 .707 r
F P
0 g
s
.49399 .79421 m .49885 .81256 L .50124 .81725 L p .707 .577 .707 r
F P
0 g
s
.48424 .69977 m .48398 .73679 L .48688 .74544 L p .707 .577 .707 r
F P
0 g
s
.48398 .73679 m .48424 .69977 L .49133 .69137 L p .707 .577 .707 r
F P
0 g
s
.49485 .66852 m .50441 .61486 L .52071 .60834 L p .707 .577 .707 r
F P
0 g
s
.49133 .69137 m .49106 .72839 L .48398 .73679 L p .707 .577 .707 r
F P
0 g
s
.52071 .60834 m .51115 .662 L .49485 .66852 L p .707 .577 .707 r
F P
0 g
s
.49885 .81256 m .49399 .79421 L .50125 .78718 L p .707 .577 .707 r
F P
0 g
s
.49106 .72839 m .49133 .69137 L .5077 .68403 L p .707 .577 .707 r
F P
0 g
s
.5077 .68403 m .50743 .72106 L .49106 .72839 L p .707 .577 .707 r
F P
0 g
s
.49635 .82389 m .51426 .32427 L .47028 .32 L p .707 .577 .707 r
F P
0 g
s
.50125 .78718 m .5061 .80553 L .49885 .81256 L p .707 .577 .707 r
F P
0 g
s
.51115 .662 m .52071 .60834 L .54454 .60516 L p .707 .577 .707 r
F P
0 g
s
.54454 .60516 m .53498 .65882 L .51115 .662 L p .707 .577 .707 r
F P
0 g
s
.5061 .80553 m .50125 .78718 L .51744 .77848 L p .707 .577 .707 r
F P
0 g
s
.51744 .77848 m .5223 .79683 L .5061 .80553 L p .707 .577 .707 r
F P
0 g
s
.50743 .72106 m .5077 .68403 L .53175 .67849 L p .707 .577 .707 r
F P
0 g
s
.53175 .67849 m .53149 .71551 L .50743 .72106 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53175 .67849 L .53569 .67806 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53569 .67806 L .53674 .70838 L .707 .577 .707 r
F
.54454 .60516 m .56279 .60546 L p .54202 .64532 L F P
0 g
s
.53498 .65882 m .53736 .64548 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.53736 .64548 m .54454 .60516 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.57744 .60613 m .605 .6097 L p .5792 .64093 L .707 .577 .707 r
F P
0 g
s
.6357 .61698 m .62614 .67064 L .59544 .66337 L p .707 .577 .707 r
F P
0 g
s
.59544 .66337 m .605 .6097 L .6357 .61698 L p .707 .577 .707 r
F P
0 g
s
.605 .6097 m .59544 .66337 L .56923 .65997 L p .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .54769 .64512 L .57028 .66635 L .707 .577 .707 r
F
.56923 .65997 m .56403 .65929 L p .56827 .65416 L F P
0 g
s
.56827 .65416 m .605 .6097 L .56923 .65997 L .707 .577 .707 r
F
.54099 .76897 m .54584 .78732 L .5223 .79683 L p F P
0 g
s
.54584 .78732 m .54099 .76897 L .56138 .76228 L p .707 .577 .707 r
F P
0 g
s
.56138 .76228 m .56958 .75959 L p .56417 .76591 L .707 .577 .707 r
F P
0 g
s
.54584 .78732 m .56138 .76228 L .56417 .76591 L .707 .577 .707 r
F
.5372 .72178 m .54769 .64512 L .53564 .67674 L F
.54428 .74005 m .54769 .64512 L p .53615 .72947 L F P
0 g
s
.56958 .75959 m .57444 .77794 L .54584 .78732 L p .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .54127 .82422 L p .57028 .66635 L .707 .577 .707 r
F P
0 g
s
.56113 .67527 m .56087 .71229 L .53696 .71491 L p .707 .577 .707 r
F P
0 g
s
.53696 .71491 m .53149 .71551 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.53674 .70838 m .56113 .67527 L .53696 .71491 L .707 .577 .707 r
F
.53615 .72947 m .5372 .72178 L .53359 .68213 L F
.5372 .72178 m .53564 .67674 L .53359 .68213 L F
.5223 .79683 m .51744 .77848 L .54099 .76897 L p F P
0 g
s
.54127 .82422 m .54428 .74005 L p .53615 .72947 L .707 .577 .707 r
F P
0 g
s
.57359 .60563 m .57744 .60613 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.56827 .65416 m .57744 .60613 L .5792 .64093 L .707 .577 .707 r
F
.56667 .64445 m .57359 .60563 L p .56827 .65416 L F P
0 g
s
.57435 .64418 m .56667 .64445 L .57028 .66635 L .707 .577 .707 r
F
.62414 .67682 m .62387 .71384 L .5927 .71172 L p F P
0 g
s
.5927 .71172 m .59297 .67469 L .62414 .67682 L p .707 .577 .707 r
F P
0 g
s
.5719 .67619 m .57435 .64418 L .57028 .66635 L .707 .577 .707 r
F
.57436 .64433 m .57435 .64418 L .5719 .67619 L F
.57198 .67507 m .59297 .67469 L p .56993 .70168 L F P
0 g
s
.56663 .7443 m .57028 .66635 L .54127 .82422 L .707 .577 .707 r
F
.59297 .67469 m .5927 .71172 L .56912 .71214 L p F P
0 g
s
.56993 .70168 m .59297 .67469 L .56912 .71214 L .707 .577 .707 r
F
.57748 .71012 m .5719 .67619 L .56663 .7443 L F
.5719 .67619 m .57028 .66635 L .56663 .7443 L F
.56912 .71214 m .56087 .71229 L p .56993 .70168 L F P
0 g
s
.56087 .71229 m .56113 .67527 L .57198 .67507 L p .707 .577 .707 r
F P
0 g
s
.56087 .71229 m .57198 .67507 L .56993 .70168 L .707 .577 .707 r
F
.57748 .71012 m .57436 .64433 L .5719 .67619 L F
.63049 .74476 m .63534 .76311 L .60528 .7696 L p F P
0 g
s
.60528 .7696 m .60042 .75125 L .63049 .74476 L p .707 .577 .707 r
F P
0 g
s
.57444 .77794 m .57034 .76247 L p .60042 .75125 L .707 .577 .707 r
F P
0 g
s
.57034 .76247 m .56958 .75959 L .57103 .7592 L p .707 .577 .707 r
F P
0 g
s
.57103 .7592 m .60042 .75125 L p .57034 .76247 L .707 .577 .707 r
F P
0 g
s
.60042 .75125 m .60528 .7696 L .57444 .77794 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .60903 .57881 L .58504 .75604 L .707 .577 .707 r
F
.60063 .32097 m .58778 .67972 L p .60903 .57881 L F P
0 g
s
.58778 .67972 m .58504 .75604 L p .60903 .57881 L .707 .577 .707 r
F P
0 g
s
.58504 .75604 m .58273 .82059 L .58826 .81941 L p .707 .577 .707 r
F P
0 g
s
.58826 .81941 m .61667 .81334 L p .58504 .75604 L .707 .577 .707 r
F P
0 g
s
.56403 .65929 m .56667 .64445 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.54127 .82422 m .58273 .82059 L p .57748 .71012 L .707 .577 .707 r
F P
0 g
s
.56279 .60546 m .57359 .60563 L p .55073 .63712 L .707 .577 .707 r
F P
0 g
s
.53498 .65882 m .56279 .60546 L .55073 .63712 L .707 .577 .707 r
F
.56403 .65929 m .53498 .65882 L p .54486 .64522 L F P
0 g
s
.57359 .60563 m .56667 .64445 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .56403 .65929 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.60063 .32097 m .55917 .3246 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58273 .82059 m .58907 .64367 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58907 .64367 m .60063 .32097 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .54769 .64512 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .51426 .32427 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .55917 .3246 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.53569 .67806 m .56113 .67527 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.51426 .32427 m .49635 .82389 L .54075 .82422 L p .707 .577 .707 r
F P
0 g
s
.54075 .82422 m .54127 .82422 L p .53982 .7974 L .707 .577 .707 r
F P
0 g
s
.53982 .7974 m .51426 .32427 L .54075 .82422 L .707 .577 .707 r
F
.45237 .81962 m .47028 .32 L .43154 .31221 L p F P
0 g
s
.47028 .32 m .45237 .81962 L .49635 .82389 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .63458 .31372 L .60063 .32097 L p .707 .577 .707 r
F P
0 g
s
.69109 .74622 m .69595 .76457 L .69356 .75988 L p .707 .577 .707 r
F P
0 g
s
.69356 .75988 m .6887 .74153 L .69109 .74622 L p .707 .577 .707 r
F P
0 g
s
.67376 .69172 m .68332 .63805 L .69558 .64979 L p .707 .577 .707 r
F P
0 g
s
.41363 .81183 m .43154 .31221 L .40184 .30167 L p .707 .577 .707 r
F P
0 g
s
.43154 .31221 m .41363 .81183 L .45237 .81962 L p .707 .577 .707 r
F P
0 g
s
.23794 .74005 m .2475 .68638 L .2168 .67911 L p .707 .577 .707 r
F P
0 g
s
.2475 .68638 m .23794 .74005 L .26935 .74412 L p .707 .577 .707 r
F P
0 g
s
.26935 .74412 m .27891 .69046 L .2475 .68638 L p .707 .577 .707 r
F P
0 g
s
.66269 .62675 m .65313 .68041 L .62614 .67064 L p .707 .577 .707 r
F P
0 g
s
.62614 .67064 m .6357 .61698 L .66269 .62675 L p .707 .577 .707 r
F P
0 g
s
.65159 .68143 m .65133 .71846 L .62387 .71384 L p .707 .577 .707 r
F P
0 g
s
.62387 .71384 m .62414 .67682 L .65159 .68143 L p .707 .577 .707 r
F P
0 g
s
.65684 .74077 m .6617 .75912 L .63534 .76311 L p .707 .577 .707 r
F P
0 g
s
.63534 .76311 m .63049 .74476 L .65684 .74077 L p .707 .577 .707 r
F P
0 g
s
.63458 .31372 m .61667 .81334 L .63978 .80319 L p .707 .577 .707 r
F P
0 g
s
.63978 .80319 m .65768 .30357 L .63458 .31372 L p .707 .577 .707 r
F P
0 g
s
.27891 .69046 m .26935 .74412 L .2984 .74459 L p .707 .577 .707 r
F P
0 g
s
.2984 .74459 m .30796 .69093 L .27891 .69046 L p .707 .577 .707 r
F P
0 g
s
.20724 .73277 m .2168 .67911 L .18981 .66934 L p .707 .577 .707 r
F P
0 g
s
.2168 .67911 m .20724 .73277 L .23794 .74005 L p .707 .577 .707 r
F P
0 g
s
.65313 .68041 m .66269 .62675 L .68332 .63805 L p .707 .577 .707 r
F P
0 g
s
.6887 .74153 m .69356 .75988 L .68176 .758 L p .707 .577 .707 r
F P
0 g
s
.68176 .758 m .6769 .73965 L .6887 .74153 L p .707 .577 .707 r
F P
0 g
s
.38393 .80129 m .40184 .30167 L .38408 .2894 L p .707 .577 .707 r
F P
0 g
s
.40184 .30167 m .38393 .80129 L .41363 .81183 L p .707 .577 .707 r
F P
0 g
s
.30796 .69093 m .2984 .74459 L .32224 .74141 L p .707 .577 .707 r
F P
0 g
s
.32224 .74141 m .33179 .68775 L .30796 .69093 L p .707 .577 .707 r
F P
0 g
s
.18025 .723 m .18981 .66934 L .16918 .65803 L p .707 .577 .707 r
F P
0 g
s
.18981 .66934 m .18025 .723 L .20724 .73277 L p .707 .577 .707 r
F P
0 g
s
.23614 .81283 m .23641 .7758 L .20524 .77368 L p .707 .577 .707 r
F P
0 g
s
.23641 .7758 m .23614 .81283 L .26798 .81225 L p .707 .577 .707 r
F P
0 g
s
.26798 .81225 m .26824 .77523 L .23641 .7758 L p .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .30109 .8043 L .28994 .80796 L p .707 .577 .707 r
F P
0 g
s
.28994 .80796 m .27249 .81369 L p .28586 .81727 L .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .28994 .80796 L .28586 .81727 L .707 .577 .707 r
F
.30109 .8043 m .30594 .82266 L .32949 .81315 L p F P
0 g
s
.32949 .81315 m .32463 .7948 L .31614 .79823 L p .707 .577 .707 r
F P
0 g
s
.31614 .79823 m .30109 .8043 L p .31266 .80791 L .707 .577 .707 r
F P
0 g
s
.32949 .81315 m .31614 .79823 L .31266 .80791 L .707 .577 .707 r
F
.32463 .7948 m .32949 .81315 L .34568 .80445 L p F P
0 g
s
.34568 .80445 m .34083 .7861 L .33554 .78894 L p .707 .577 .707 r
F P
0 g
s
.33554 .78894 m .32463 .7948 L p .3338 .799 L .707 .577 .707 r
F P
0 g
s
.34568 .80445 m .33554 .78894 L .3338 .799 L .707 .577 .707 r
F
.34083 .7861 m .34568 .80445 L .35294 .79742 L p F P
0 g
s
.35294 .79742 m .34808 .77907 L .3459 .78119 L p .707 .577 .707 r
F P
0 g
s
.3459 .78119 m .34083 .7861 L p .34656 .79146 L .707 .577 .707 r
F P
0 g
s
.35294 .79742 m .3459 .78119 L .34656 .79146 L .707 .577 .707 r
F
.33778 .79615 m .34486 .78775 L p .33959 .76561 L F P
0 g
s
.34486 .78775 m .34513 .75073 L .33805 .75913 L p .707 .577 .707 r
F P
0 g
s
.34486 .78775 m .34197 .77911 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34513 .75073 m .34501 .76745 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34501 .76745 m .34486 .78775 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.33805 .75913 m .33793 .77516 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.33793 .77516 m .33778 .79615 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .33778 .79615 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32168 .76646 m .32156 .78318 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32156 .78318 m .32141 .80349 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .32141 .80349 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29762 .77201 m .29749 .79071 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29749 .79071 m .29736 .80903 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.26824 .77523 m .26798 .81225 L .29736 .80903 L p .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .29762 .77201 L .26824 .77523 L p .707 .577 .707 r
F P
0 g
s
.20497 .8107 m .20524 .77368 L .17778 .76906 L p .707 .577 .707 r
F P
0 g
s
.20524 .77368 m .20497 .8107 L .23614 .81283 L p .707 .577 .707 r
F P
0 g
s
.6769 .73965 m .68176 .758 L .6617 .75912 L p .707 .577 .707 r
F P
0 g
s
.6617 .75912 m .65684 .74077 L .6769 .73965 L p .707 .577 .707 r
F P
0 g
s
.16918 .65803 m .15962 .7117 L .18025 .723 L p .707 .577 .707 r
F P
0 g
s
.65768 .30357 m .63978 .80319 L .64978 .79113 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .66769 .29151 L .65768 .30357 L p .707 .577 .707 r
F P
0 g
s
.33179 .68775 m .32224 .74141 L .33853 .7349 L p .707 .577 .707 r
F P
0 g
s
.33853 .7349 m .34809 .68123 L .33179 .68775 L p .707 .577 .707 r
F P
0 g
s
.24651 .84038 m .24166 .82203 L .21159 .82852 L p .707 .577 .707 r
F P
0 g
s
.24166 .82203 m .24651 .84038 L .27735 .83204 L p .707 .577 .707 r
F P
0 g
s
.27735 .83204 m .27249 .81369 L .24166 .82203 L p .707 .577 .707 r
F P
0 g
s
.15962 .7117 m .16918 .65803 L .15692 .6463 L p .707 .577 .707 r
F P
0 g
s
.27249 .81369 m .27735 .83204 L .30594 .82266 L p .707 .577 .707 r
F P
0 g
s
.21159 .82852 m .21644 .84687 L .24651 .84038 L p .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .32168 .76646 L .29762 .77201 L p .707 .577 .707 r
F P
0 g
s
.17778 .76906 m .17752 .80608 L .20497 .8107 L p .707 .577 .707 r
F P
0 g
s
.21644 .84687 m .21159 .82852 L .18523 .83251 L p .707 .577 .707 r
F P
0 g
s
.17752 .80608 m .17778 .76906 L .15672 .7624 L p .707 .577 .707 r
F P
0 g
s
.18523 .83251 m .19009 .85086 L .21644 .84687 L p .707 .577 .707 r
F P
0 g
s
.36618 .78902 m .38408 .2894 L .38001 .27661 L p .707 .577 .707 r
F P
0 g
s
.38408 .2894 m .36618 .78902 L .38393 .80129 L p .707 .577 .707 r
F P
0 g
s
.15692 .6463 m .14737 .69997 L .15962 .7117 L p .707 .577 .707 r
F P
0 g
s
.15672 .7624 m .15646 .79943 L .17752 .80608 L p .707 .577 .707 r
F P
0 g
s
.33778 .79615 m .33805 .75913 L .32168 .76646 L p .707 .577 .707 r
F P
0 g
s
.34809 .68123 m .33853 .7349 L .34569 .72568 L p .707 .577 .707 r
F P
0 g
s
.34569 .72568 m .35525 .67202 L .34809 .68123 L p .707 .577 .707 r
F P
0 g
s
.19009 .85086 m .18523 .83251 L .16517 .83363 L p .707 .577 .707 r
F P
0 g
s
.14737 .69997 m .15692 .6463 L .15424 .63529 L p .707 .577 .707 r
F P
0 g
s
.16517 .83363 m .17003 .85198 L .19009 .85086 L p .707 .577 .707 r
F P
0 g
s
.15646 .79943 m .15672 .7624 L .14413 .75436 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .64637 .78043 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66769 .29151 m .66148 .46482 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66148 .46482 m .64978 .79113 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.64729 .74327 m .65556 .56006 L .64637 .78043 L .707 .577 .707 r
F
.65556 .56006 m .66769 .29151 L .65696 .53756 L F
.65556 .56006 m .65696 .53756 L .64637 .78043 L F
.66361 .27872 m .66769 .29151 L p .64729 .74327 L F P
0 g
s
.64571 .77834 m .64802 .71379 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .66361 .27872 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64248 .5936 m .63983 .60844 L .64325 .61031 L p .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64174 .5776 L .64205 .59325 L .707 .577 .707 r
F
.66361 .27872 m .64802 .71379 L p .64405 .62778 L F P
0 g
s
.64411 .62669 m .63694 .62442 L p .64349 .63818 L .707 .577 .707 r
F P
0 g
s
.64174 .5776 m .66136 .30948 L .64405 .62778 L .707 .577 .707 r
F
.66136 .30948 m .66361 .27872 L .64405 .62778 L F
.65773 .6681 m .65799 .63107 L .64411 .62669 L p F P
0 g
s
.63983 .60844 m .64248 .5936 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .64571 .77834 L p .64308 .64562 L .707 .577 .707 r
F P
0 g
s
.64349 .63818 m .63694 .62442 L .64213 .66317 L .707 .577 .707 r
F
.64174 .5776 m .64405 .62778 L .64308 .64562 L F
.64405 .62778 m .64802 .71379 L .64308 .64562 L F
.63694 .62442 m .63667 .66144 L .64213 .66317 L p F P
0 g
s
.62795 .76608 m .59825 .75553 L p .60451 .6912 L .707 .577 .707 r
F P
0 g
s
.63667 .66144 m .63694 .62442 L .62603 .61745 L p .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62463 .48454 L .62602 .61612 L .707 .577 .707 r
F
.63667 .66144 m .62603 .61745 L .62609 .62275 L F
.63983 .60844 m .63911 .59085 L .63226 .59433 L F
.63072 .59971 m .63983 .60844 L p .63226 .59433 L F P
0 g
s
.64585 .26645 m .63437 .58697 L p .62602 .61612 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .62758 .59671 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.62643 .6549 m .63667 .66144 L p .62609 .62275 L .707 .577 .707 r
F P
0 g
s
.63437 .58697 m .62795 .76608 L p .62759 .76494 L .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62602 .61612 L .62759 .76494 L .707 .577 .707 r
F
.62602 .61612 m .63437 .58697 L .62759 .76494 L F
.62434 .61637 m .62408 .6534 L .62643 .6549 L p F P
0 g
s
.62609 .62275 m .62434 .61637 L .62643 .6549 L .707 .577 .707 r
F
.62603 .61745 m .62434 .61637 L p .62609 .62275 L F P
0 g
s
.62463 .48454 m .64585 .26645 L .62602 .61612 L .707 .577 .707 r
F
.62758 .59671 m .63072 .59971 L p .63226 .59433 L F P
0 g
s
.63437 .58697 m .63531 .56057 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .64585 .26645 L p .6416 .53381 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .6416 .53381 L .64068 .59213 L .707 .577 .707 r
F
.63714 .54305 m .63446 .53203 L p .62821 .59081 L F P
0 g
s
.62758 .59671 m .62996 .58337 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .63714 .54305 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.63714 .54305 m .62996 .58337 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64585 .26645 m .66361 .27872 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.62795 .76608 m .63437 .58697 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64571 .77834 m .62795 .76608 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64205 .59325 L .64571 .77834 L .707 .577 .707 r
F
.64213 .66317 m .65773 .6681 L p .64349 .63818 L F P
0 g
s
.65773 .6681 m .64411 .62669 L .64349 .63818 L .707 .577 .707 r
F
.64939 .55478 m .63714 .54305 L p .63911 .59085 L F P
0 g
s
.64248 .5936 m .64939 .55478 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64939 .55478 m .64248 .5936 L p .65048 .61428 L .707 .577 .707 r
F P
0 g
s
.64325 .61031 m .65048 .61428 L p .64248 .5936 L .707 .577 .707 r
F P
0 g
s
.65048 .61428 m .66047 .61975 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.65163 .56791 m .64939 .55478 L .65048 .61428 L .707 .577 .707 r
F
.65024 .72709 m .6703 .72598 L p .64629 .70936 L F P
0 g
s
.64539 .70874 m .64615 .71162 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.64615 .71162 m .65024 .72709 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .66545 .70763 L .64633 .70869 L p .707 .577 .707 r
F P
0 g
s
.64633 .70869 m .64539 .70874 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .64633 .70869 L .64629 .70936 L .707 .577 .707 r
F
.66047 .61975 m .67002 .56608 L .65192 .55616 L p F P
0 g
s
.65192 .55616 m .64939 .55478 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.66047 .61975 m .65192 .55616 L .65163 .56791 L .707 .577 .707 r
F
.64637 .78043 m .64571 .77834 L p .64729 .74327 L F P
0 g
s
.14413 .75436 m .14387 .79138 L .15646 .79943 L p .707 .577 .707 r
F P
0 g
s
.15424 .63529 m .14469 .68895 L .14737 .69997 L p .707 .577 .707 r
F P
0 g
s
.17003 .85198 m .16517 .83363 L .15337 .83175 L p .707 .577 .707 r
F P
0 g
s
.15337 .83175 m .15823 .8501 L .17003 .85198 L p .707 .577 .707 r
F P
0 g
s
.35525 .67202 m .34569 .72568 L .34301 .71467 L p .707 .577 .707 r
F P
0 g
s
.34301 .71467 m .35257 .661 L .35525 .67202 L p .707 .577 .707 r
F P
0 g
s
.38001 .27661 m .3621 .77624 L .36618 .78902 L p .707 .577 .707 r
F P
0 g
s
.3621 .77624 m .38001 .27661 L .39001 .26455 L p .707 .577 .707 r
F P
0 g
s
.14469 .68895 m .15424 .63529 L .1614 .62607 L p .707 .577 .707 r
F P
0 g
s
.14387 .79138 m .14413 .75436 L .14124 .74571 L p .707 .577 .707 r
F P
0 g
s
.14124 .74571 m .14097 .78274 L .14387 .79138 L p .707 .577 .707 r
F P
0 g
s
.1614 .62607 m .15184 .67974 L .14469 .68895 L p .707 .577 .707 r
F P
0 g
s
.15823 .8501 m .15337 .83175 L .15098 .82706 L p .707 .577 .707 r
F P
0 g
s
.34223 .74208 m .34197 .77911 L .32938 .77106 L p .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .33389 .7725 L .34109 .77365 L p .707 .577 .707 r
F P
0 g
s
.34197 .77911 m .3421 .76079 L p .34513 .75073 L .707 .577 .707 r
F P
0 g
s
.34109 .77365 m .34569 .77438 L p .33997 .78795 L .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .34109 .77365 L .33997 .78795 L .707 .577 .707 r
F
.3421 .76079 m .34223 .74208 L .34331 .74531 L p F P
0 g
s
.34331 .74531 m .34513 .75073 L p .3421 .76079 L .707 .577 .707 r
F P
0 g
s
.15098 .82706 m .15584 .84541 L .15823 .8501 L p .707 .577 .707 r
F P
0 g
s
.35257 .661 m .34301 .71467 L .33075 .70293 L p .707 .577 .707 r
F P
0 g
s
.33075 .70293 m .34031 .64927 L .35257 .661 L p .707 .577 .707 r
F P
0 g
s
.15184 .67974 m .1614 .62607 L .1777 .61956 L p .707 .577 .707 r
F P
0 g
s
.34808 .77907 m .35294 .79742 L .35055 .79273 L p .707 .577 .707 r
F P
0 g
s
.35055 .79273 m .34569 .77438 L .34808 .77907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14097 .78274 m .14124 .74571 L .14832 .73731 L p .707 .577 .707 r
F P
0 g
s
.3721 .76418 m .39001 .26455 L .41312 .2544 L p .707 .577 .707 r
F P
0 g
s
.39001 .26455 m .3721 .76418 L .3621 .77624 L p .707 .577 .707 r
F P
0 g
s
.14832 .73731 m .14805 .77434 L .14097 .78274 L p .707 .577 .707 r
F P
0 g
s
.1777 .61956 m .16814 .67322 L .15184 .67974 L p .707 .577 .707 r
F P
0 g
s
.32938 .77106 m .32964 .73404 L .34223 .74208 L p .707 .577 .707 r
F P
0 g
s
.34031 .64927 m .33075 .70293 L .31012 .69163 L p .707 .577 .707 r
F P
0 g
s
.31012 .69163 m .31968 .63797 L .34031 .64927 L p .707 .577 .707 r
F P
0 g
s
.15584 .84541 m .15098 .82706 L .15824 .82002 L p .707 .577 .707 r
F P
0 g
s
.16814 .67322 m .1777 .61956 L .20153 .61638 L p .707 .577 .707 r
F P
0 g
s
.15824 .82002 m .16309 .83837 L .15584 .84541 L p .707 .577 .707 r
F P
0 g
s
.34569 .77438 m .35055 .79273 L .33875 .79085 L p .707 .577 .707 r
F P
0 g
s
.59825 .75553 m .61615 .25591 L .64585 .26645 L p .707 .577 .707 r
F P
0 g
s
.14805 .77434 m .14832 .73731 L .16469 .72998 L p .707 .577 .707 r
F P
0 g
s
.20153 .61638 m .19197 .67004 L .16814 .67322 L p .707 .577 .707 r
F P
0 g
s
.31968 .63797 m .31012 .69163 L .28313 .68186 L p .707 .577 .707 r
F P
0 g
s
.28313 .68186 m .29269 .6282 L .31968 .63797 L p .707 .577 .707 r
F P
0 g
s
.16469 .72998 m .16442 .76701 L .14805 .77434 L p .707 .577 .707 r
F P
0 g
s
.19197 .67004 m .20153 .61638 L .23058 .61685 L p .707 .577 .707 r
F P
0 g
s
.41312 .2544 m .39521 .75403 L .3721 .76418 L p .707 .577 .707 r
F P
0 g
s
.39521 .75403 m .41312 .2544 L .44706 .24715 L p .707 .577 .707 r
F P
0 g
s
.32964 .73404 m .32938 .77106 L .30832 .76441 L p .707 .577 .707 r
F P
0 g
s
.30832 .76441 m .30859 .72738 L .32964 .73404 L p .707 .577 .707 r
F P
0 g
s
.16309 .83837 m .15824 .82002 L .17443 .81133 L p .707 .577 .707 r
F P
0 g
s
.71816 .63679 m .72771 .58313 L .69701 .57585 L p .707 .577 .707 r
F P
0 g
s
.74673 .6405 m .74957 .64087 L p .74228 .62163 L .707 .577 .707 r
F P
0 g
s
.74957 .64087 m .75913 .5872 L .72771 .58313 L p .707 .577 .707 r
F P
0 g
s
.75913 .5872 m .75911 .58727 L p .77861 .64134 L .707 .577 .707 r
F P
0 g
s
.75911 .58727 m .74957 .64087 L .77621 .6413 L p .707 .577 .707 r
F P
0 g
s
.77621 .6413 m .77861 .64134 L p .75911 .58727 L .707 .577 .707 r
F P
0 g
s
.77861 .64134 m .78817 .58767 L .75913 .5872 L p .707 .577 .707 r
F P
0 g
s
.78817 .58767 m .78743 .59183 L p .80245 .63816 L .707 .577 .707 r
F P
0 g
s
.78743 .59183 m .77861 .64134 L .8008 .63838 L p .707 .577 .707 r
F P
0 g
s
.8008 .63838 m .80245 .63816 L p .78743 .59183 L .707 .577 .707 r
F P
0 g
s
.80245 .63816 m .81201 .58449 L .78817 .58767 L p .707 .577 .707 r
F P
0 g
s
.81201 .58449 m .81147 .58749 L p .81874 .63164 L .707 .577 .707 r
F P
0 g
s
.81147 .58749 m .80245 .63816 L .81775 .63204 L p .707 .577 .707 r
F P
0 g
s
.81775 .63204 m .81874 .63164 L p .81147 .58749 L .707 .577 .707 r
F P
0 g
s
.81874 .63164 m .8283 .57798 L .81201 .58449 L p .707 .577 .707 r
F P
0 g
s
.8283 .57798 m .81874 .63164 L .82547 .62298 L p .707 .577 .707 r
F P
0 g
s
.82547 .62298 m .8259 .62243 L p .82717 .59902 L .707 .577 .707 r
F P
0 g
s
.82717 .59902 m .8283 .57798 L .82547 .62298 L .707 .577 .707 r
F
.81826 .62114 m .81816 .63492 L p .82508 .64977 L F P
0 g
s
.82534 .61274 m .81826 .62114 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82508 .64977 m .82525 .6261 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82525 .6261 m .82534 .61274 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.8259 .62243 m .83546 .56876 L .8283 .57798 L p .707 .577 .707 r
F P
0 g
s
.83546 .56876 m .8259 .62243 L .82572 .62166 L p .707 .577 .707 r
F P
0 g
s
.82534 .61274 m .82525 .6261 L p .82218 .64112 L .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82534 .61274 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82218 .64112 m .82236 .61625 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82236 .61625 m .82245 .6041 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.81816 .63492 m .818 .65817 L .82095 .65467 L p .707 .577 .707 r
F P
0 g
s
.82095 .65467 m .82508 .64977 L p .81816 .63492 L .707 .577 .707 r
F P
0 g
s
.818 .65817 m .81826 .62114 L .80189 .62847 L p .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82218 .64112 L .80959 .63308 L p .707 .577 .707 r
F P
0 g
s
.83278 .55775 m .82322 .61141 L .82221 .61044 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .82245 .6041 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80959 .63308 m .80978 .60633 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80978 .60633 m .80985 .59605 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80189 .62847 m .80179 .64183 L p .818 .65817 L .707 .577 .707 r
F P
0 g
s
.80163 .6655 m .80189 .62847 L .77784 .63402 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .80959 .63308 L .78854 .62642 L p .707 .577 .707 r
F P
0 g
s
.78854 .62642 m .7888 .5894 L .80985 .59605 L p .707 .577 .707 r
F P
0 g
s
.82052 .54601 m .81097 .59968 L .8091 .59866 L p .707 .577 .707 r
F P
0 g
s
.8091 .59866 m .79033 .58837 L p .80622 .56609 L .707 .577 .707 r
F P
0 g
s
.80622 .56609 m .82052 .54601 L .8091 .59866 L .707 .577 .707 r
F
.82221 .61044 m .81097 .59968 L p .8214 .57963 L F P
0 g
s
.8214 .57963 m .83278 .55775 L .82221 .61044 L .707 .577 .707 r
F
.82572 .62166 m .82322 .61141 L p .82889 .59165 L F P
0 g
s
.82889 .59165 m .83546 .56876 L .82572 .62166 L .707 .577 .707 r
F
.82525 .6261 m .82508 .64977 L .82383 .64605 L p F P
0 g
s
.82383 .64605 m .82218 .64112 L p .82525 .6261 L .707 .577 .707 r
F P
0 g
s
.80179 .64183 m .80163 .6655 L .8078 .66274 L p .707 .577 .707 r
F P
0 g
s
.8078 .66274 m .818 .65817 L p .80179 .64183 L .707 .577 .707 r
F P
0 g
s
.77784 .63402 m .77775 .64618 L p .80163 .6655 L .707 .577 .707 r
F P
0 g
s
.77775 .64618 m .77757 .67105 L .78507 .66932 L p .707 .577 .707 r
F P
0 g
s
.78507 .66932 m .80163 .6655 L p .77775 .64618 L .707 .577 .707 r
F P
0 g
s
.74846 .63724 m .74838 .64752 L p .77757 .67105 L .707 .577 .707 r
F P
0 g
s
.74838 .64752 m .74819 .67427 L .75452 .67357 L p .707 .577 .707 r
F P
0 g
s
.75452 .67357 m .77757 .67105 L p .74838 .64752 L .707 .577 .707 r
F P
0 g
s
.72771 .58313 m .71816 .63679 L .74673 .6405 L p .707 .577 .707 r
F P
0 g
s
.74228 .62163 m .72771 .58313 L .74673 .6405 L .707 .577 .707 r
F
.17443 .81133 m .17929 .82968 L .16309 .83837 L p F P
0 g
s
.29269 .6282 m .28313 .68186 L .25243 .67458 L p .707 .577 .707 r
F P
0 g
s
.25243 .67458 m .26199 .62092 L .29269 .6282 L p .707 .577 .707 r
F P
0 g
s
.22102 .67051 m .23058 .61685 L .26199 .62092 L p .707 .577 .707 r
F P
0 g
s
.23058 .61685 m .22102 .67051 L .19197 .67004 L p .707 .577 .707 r
F P
0 g
s
.33389 .7725 m .33875 .79085 L .31869 .79196 L p .707 .577 .707 r
F P
0 g
s
.31869 .79196 m .31383 .77361 L .33389 .7725 L p .707 .577 .707 r
F P
0 g
s
.68745 .62952 m .69701 .57585 L .67002 .56608 L p .707 .577 .707 r
F P
0 g
s
.69701 .57585 m .68745 .62952 L .71816 .63679 L p .707 .577 .707 r
F P
0 g
s
.16442 .76701 m .16469 .72998 L .18874 .72443 L p .707 .577 .707 r
F P
0 g
s
.26199 .62092 m .25243 .67458 L .22102 .67051 L p .707 .577 .707 r
F P
0 g
s
.61615 .25591 m .59825 .75553 L .55951 .74775 L p .707 .577 .707 r
F P
0 g
s
.55951 .74775 m .57742 .24812 L .61615 .25591 L p .707 .577 .707 r
F P
0 g
s
.18874 .72443 m .18848 .76146 L .16442 .76701 L p .707 .577 .707 r
F P
0 g
s
.30859 .72738 m .30832 .76441 L .28086 .75979 L p .707 .577 .707 r
F P
0 g
s
.28086 .75979 m .28113 .72277 L .30859 .72738 L p .707 .577 .707 r
F P
0 g
s
.67002 .56608 m .66047 .61975 L .68745 .62952 L p .707 .577 .707 r
F P
0 g
s
.71636 .67484 m .71662 .63781 L .68545 .63569 L p .707 .577 .707 r
F P
0 g
s
.71662 .63781 m .71636 .67484 L .74819 .67427 L p .707 .577 .707 r
F P
0 g
s
.74819 .67427 m .74846 .63724 L .71662 .63781 L p .707 .577 .707 r
F P
0 g
s
.42915 .74678 m .44706 .24715 L .48852 .24352 L p .707 .577 .707 r
F P
0 g
s
.44706 .24715 m .42915 .74678 L .39521 .75403 L p .707 .577 .707 r
F P
0 g
s
.77757 .67105 m .77784 .63402 L .74846 .63724 L p .707 .577 .707 r
F P
0 g
s
.17929 .82968 m .17443 .81133 L .19798 .80182 L p .707 .577 .707 r
F P
0 g
s
.18848 .76146 m .18874 .72443 L .21812 .72122 L p .707 .577 .707 r
F P
0 g
s
.68519 .67272 m .68545 .63569 L .65799 .63107 L p .707 .577 .707 r
F P
0 g
s
.68545 .63569 m .68519 .67272 L .71636 .67484 L p .707 .577 .707 r
F P
0 g
s
.19798 .80182 m .20283 .82017 L .17929 .82968 L p .707 .577 .707 r
F P
0 g
s
.31383 .77361 m .31869 .79196 L .29233 .79596 L p .707 .577 .707 r
F P
0 g
s
.29233 .79596 m .28748 .77761 L .31383 .77361 L p .707 .577 .707 r
F P
0 g
s
.57742 .24812 m .55951 .74775 L .51553 .74348 L p .707 .577 .707 r
F P
0 g
s
.51553 .74348 m .53344 .24385 L .57742 .24812 L p .707 .577 .707 r
F P
0 g
s
.28113 .72277 m .28086 .75979 L .24969 .75767 L p .707 .577 .707 r
F P
0 g
s
.24969 .75767 m .24996 .72064 L .28113 .72277 L p .707 .577 .707 r
F P
0 g
s
.72672 .7155 m .72187 .69715 L .6918 .70363 L p .707 .577 .707 r
F P
0 g
s
.72187 .69715 m .72672 .7155 L .75756 .70715 L p .707 .577 .707 r
F P
0 g
s
.75756 .70715 m .75271 .6888 L .72187 .69715 L p .707 .577 .707 r
F P
0 g
s
.75271 .6888 m .75756 .70715 L .78615 .69777 L p .707 .577 .707 r
F P
0 g
s
.78615 .69777 m .7813 .67942 L .75271 .6888 L p .707 .577 .707 r
F P
0 g
s
.21812 .72122 m .21786 .75824 L .18848 .76146 L p .707 .577 .707 r
F P
0 g
s
.65799 .63107 m .65773 .6681 L .68519 .67272 L p .707 .577 .707 r
F P
0 g
s
.6918 .70363 m .69665 .72198 L .72672 .7155 L p .707 .577 .707 r
F P
0 g
s
.47061 .74314 m .48852 .24352 L .53344 .24385 L p .707 .577 .707 r
F P
0 g
s
.48852 .24352 m .47061 .74314 L .42915 .74678 L p .707 .577 .707 r
F P
0 g
s
.21786 .75824 m .21812 .72122 L .24996 .72064 L p .707 .577 .707 r
F P
0 g
s
.24996 .72064 m .24969 .75767 L .21786 .75824 L p .707 .577 .707 r
F P
0 g
s
.53344 .24385 m .51553 .74348 L .47061 .74314 L p .707 .577 .707 r
F P
0 g
s
.69665 .72198 m .6918 .70363 L .66545 .70763 L p .707 .577 .707 r
F P
0 g
s
.20283 .82017 m .19798 .80182 L .22657 .79244 L p .707 .577 .707 r
F P
0 g
s
.66545 .70763 m .6703 .72598 L .69665 .72198 L p .707 .577 .707 r
F P
0 g
s
.7813 .67942 m .78615 .69777 L .8097 .68826 L p .707 .577 .707 r
F P
0 g
s
.8097 .68826 m .80485 .66991 L .7813 .67942 L p .707 .577 .707 r
F P
0 g
s
.22657 .79244 m .23143 .81079 L .20283 .82017 L p .707 .577 .707 r
F P
0 g
s
.28748 .77761 m .29233 .79596 L .26227 .80245 L p .707 .577 .707 r
F P
0 g
s
.26227 .80245 m .25741 .78409 L .28748 .77761 L p .707 .577 .707 r
F P
0 g
s
.23143 .81079 m .22657 .79244 L .25741 .78409 L p .707 .577 .707 r
F P
0 g
s
.25741 .78409 m .26227 .80245 L .23143 .81079 L p .707 .577 .707 r
F P
0 g
s
.80485 .66991 m .8097 .68826 L .82589 .67957 L p .707 .577 .707 r
F P
0 g
s
.82589 .67957 m .82104 .66122 L .80485 .66991 L p .707 .577 .707 r
F P
0 g
s
.65024 .72709 m .64539 .70874 L .63358 .70686 L p .707 .577 .707 r
F P
0 g
s
.63446 .53203 m .6249 .5857 L .62758 .59671 L p .707 .577 .707 r
F P
0 g
s
.63358 .70686 m .63844 .72521 L .65024 .72709 L p .707 .577 .707 r
F P
0 g
s
.82104 .66122 m .82589 .67957 L .83315 .67253 L p .707 .577 .707 r
F P
0 g
s
.83315 .67253 m .8283 .65418 L .82104 .66122 L p .707 .577 .707 r
F P
0 g
s
.62408 .6534 m .62434 .61637 L .62145 .60773 L p .707 .577 .707 r
F P
0 g
s
.82322 .61141 m .83278 .55775 L .83546 .56876 L p .707 .577 .707 r
F P
0 g
s
.6249 .5857 m .63446 .53203 L .64162 .52282 L p .707 .577 .707 r
F P
0 g
s
.62145 .60773 m .62119 .64475 L .62408 .6534 L p .707 .577 .707 r
F P
0 g
s
.63844 .72521 m .63358 .70686 L .6312 .70217 L p .707 .577 .707 r
F P
0 g
s
.64162 .52282 m .63206 .57648 L .6249 .5857 L p .707 .577 .707 r
F P
0 g
s
.6312 .70217 m .63605 .72052 L .63844 .72521 L p .707 .577 .707 r
F P
0 g
s
.8283 .65418 m .83315 .67253 L .83076 .66785 L p .707 .577 .707 r
F P
0 g
s
.83076 .66785 m .82591 .64949 L .8283 .65418 L p .707 .577 .707 r
F P
0 g
s
.62119 .64475 m .62145 .60773 L .62853 .59933 L p .707 .577 .707 r
F P
0 g
s
.81097 .59968 m .82052 .54601 L .83278 .55775 L p .707 .577 .707 r
F P
0 g
s
.63206 .57648 m .64162 .52282 L .65791 .5163 L p .707 .577 .707 r
F P
0 g
s
.62853 .59933 m .62827 .63635 L .62119 .64475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.37515 .64801 m .3847 .59435 L .354 .58707 L p .707 .577 .707 r
F P
0 g
s
.3847 .59435 m .37515 .64801 L .40656 .65208 L p .707 .577 .707 r
F P
0 g
s
.40656 .65208 m .41612 .59842 L .3847 .59435 L p .707 .577 .707 r
F P
0 g
s
.65791 .5163 m .64835 .56996 L .63206 .57648 L p .707 .577 .707 r
F P
0 g
s
.63605 .72052 m .6312 .70217 L .63845 .69514 L p .707 .577 .707 r
F P
0 g
s
.63845 .69514 m .64331 .71349 L .63605 .72052 L p .707 .577 .707 r
F P
0 g
s
.41612 .59842 m .40656 .65208 L .4356 .65255 L p .707 .577 .707 r
F P
0 g
s
.4356 .65255 m .44516 .59889 L .41612 .59842 L p .707 .577 .707 r
F P
0 g
s
.34444 .64073 m .354 .58707 L .32701 .5773 L p .707 .577 .707 r
F P
0 g
s
.354 .58707 m .34444 .64073 L .37515 .64801 L p .707 .577 .707 r
F P
0 g
s
.79033 .58837 m .79989 .53471 L .82052 .54601 L p .707 .577 .707 r
F P
0 g
s
.82591 .64949 m .83076 .66785 L .81896 .66597 L p .707 .577 .707 r
F P
0 g
s
.81896 .66597 m .81411 .64761 L .82591 .64949 L p .707 .577 .707 r
F P
0 g
s
.64835 .56996 m .65791 .5163 L .68175 .51312 L p .707 .577 .707 r
F P
0 g
s
.62827 .63635 m .62853 .59933 L .6449 .59199 L p .707 .577 .707 r
F P
0 g
s
.44516 .59889 m .4356 .65255 L .45944 .64937 L p .707 .577 .707 r
F P
0 g
s
.45944 .64937 m .469 .59571 L .44516 .59889 L p .707 .577 .707 r
F P
0 g
s
.31746 .63096 m .32701 .5773 L .30638 .566 L p .707 .577 .707 r
F P
0 g
s
.32701 .5773 m .31746 .63096 L .34444 .64073 L p .707 .577 .707 r
F P
0 g
s
.6449 .59199 m .64464 .62902 L .62827 .63635 L p .707 .577 .707 r
F P
0 g
s
.68175 .51312 m .67219 .56679 L .64835 .56996 L p .707 .577 .707 r
F P
0 g
s
.79989 .53471 m .79033 .58837 L .76335 .57861 L p .707 .577 .707 r
F P
0 g
s
.76335 .57861 m .77291 .52494 L .79989 .53471 L p .707 .577 .707 r
F P
0 g
s
.37335 .72079 m .37361 .68376 L .34244 .68164 L p .707 .577 .707 r
F P
0 g
s
.37361 .68376 m .37335 .72079 L .40518 .72021 L p .707 .577 .707 r
F P
0 g
s
.40518 .72021 m .40545 .68319 L .37361 .68376 L p .707 .577 .707 r
F P
0 g
s
.67219 .56679 m .68175 .51312 L .71079 .51359 L p .707 .577 .707 r
F P
0 g
s
.64331 .71349 m .63845 .69514 L .65465 .68644 L p .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .43829 .71227 L .42714 .71593 L p .707 .577 .707 r
F P
0 g
s
.42714 .71593 m .4097 .72165 L p .42306 .72523 L .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .42714 .71593 L .42306 .72523 L .707 .577 .707 r
F
.43829 .71227 m .44314 .73062 L .46669 .72111 L p F P
0 g
s
.46669 .72111 m .46184 .70276 L .45335 .70619 L p .707 .577 .707 r
F P
0 g
s
.45335 .70619 m .43829 .71227 L p .44986 .71587 L .707 .577 .707 r
F P
0 g
s
.46669 .72111 m .45335 .70619 L .44986 .71587 L .707 .577 .707 r
F
.46184 .70276 m .46669 .72111 L .48288 .71242 L p F P
0 g
s
.48288 .71242 m .47803 .69407 L .47274 .6969 L p .707 .577 .707 r
F P
0 g
s
.47274 .6969 m .46184 .70276 L p .471 .70696 L .707 .577 .707 r
F P
0 g
s
.48288 .71242 m .47274 .6969 L .471 .70696 L .707 .577 .707 r
F
.47803 .69407 m .48288 .71242 L .49014 .70538 L p F P
0 g
s
.49014 .70538 m .48529 .68703 L .4831 .68915 L p .707 .577 .707 r
F P
0 g
s
.4831 .68915 m .47803 .69407 L p .48377 .69943 L .707 .577 .707 r
F P
0 g
s
.49014 .70538 m .4831 .68915 L .48377 .69943 L .707 .577 .707 r
F
.47499 .70412 m .48207 .69572 L p .47679 .67357 L F P
0 g
s
.48207 .69572 m .48233 .65869 L .47525 .66709 L p .707 .577 .707 r
F P
0 g
s
.48207 .69572 m .47917 .68707 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48233 .65869 m .48221 .67541 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48221 .67541 m .48207 .69572 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.47525 .66709 m .47513 .68312 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.47513 .68312 m .47499 .70412 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .47499 .70412 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45888 .67442 m .45876 .69114 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45876 .69114 m .45862 .71145 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .45862 .71145 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43483 .67997 m .43469 .69867 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43469 .69867 m .43456 .71699 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.40545 .68319 m .40518 .72021 L .43456 .71699 L p .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .43483 .67997 L .40545 .68319 L p .707 .577 .707 r
F P
0 g
s
.65465 .68644 m .6595 .70479 L .64331 .71349 L p .707 .577 .707 r
F P
0 g
s
.64464 .62902 m .6449 .59199 L .66895 .58645 L p .707 .577 .707 r
F P
0 g
s
.34218 .71866 m .34244 .68164 L .31498 .67702 L p .707 .577 .707 r
F P
0 g
s
.34244 .68164 m .34218 .71866 L .37335 .72079 L p .707 .577 .707 r
F P
0 g
s
.81411 .64761 m .81896 .66597 L .7989 .66708 L p .707 .577 .707 r
F P
0 g
s
.7989 .66708 m .79405 .64873 L .81411 .64761 L p .707 .577 .707 r
F P
0 g
s
.30638 .566 m .29682 .61966 L .31746 .63096 L p .707 .577 .707 r
F P
0 g
s
.469 .59571 m .45944 .64937 L .47573 .64286 L p .707 .577 .707 r
F P
0 g
s
.47573 .64286 m .48529 .58919 L .469 .59571 L p .707 .577 .707 r
F P
0 g
s
.38371 .74834 m .37886 .72999 L .34879 .73648 L p .707 .577 .707 r
F P
0 g
s
.37886 .72999 m .38371 .74834 L .41455 .74 L p .707 .577 .707 r
F P
0 g
s
.41455 .74 m .4097 .72165 L .37886 .72999 L p .707 .577 .707 r
F P
0 g
s
.29682 .61966 m .30638 .566 L .29413 .55426 L p .707 .577 .707 r
F P
0 g
s
.4097 .72165 m .41455 .74 L .44314 .73062 L p .707 .577 .707 r
F P
0 g
s
.77291 .52494 m .76335 .57861 L .73265 .57133 L p .707 .577 .707 r
F P
0 g
s
.73265 .57133 m .7422 .51766 L .77291 .52494 L p .707 .577 .707 r
F P
0 g
s
.70123 .56726 m .71079 .51359 L .7422 .51766 L p .707 .577 .707 r
F P
0 g
s
.71079 .51359 m .70123 .56726 L .67219 .56679 L p .707 .577 .707 r
F P
0 g
s
.34879 .73648 m .35364 .75483 L .38371 .74834 L p .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .45888 .67442 L .43483 .67997 L p .707 .577 .707 r
F P
0 g
s
.66895 .58645 m .66869 .62347 L .64464 .62902 L p .707 .577 .707 r
F P
0 g
s
.31498 .67702 m .31472 .71405 L .34218 .71866 L p .707 .577 .707 r
F P
0 g
s
.7422 .51766 m .73265 .57133 L .70123 .56726 L p .707 .577 .707 r
F P
0 g
s
.7888 .5894 m .78854 .62642 L .76108 .62181 L p .707 .577 .707 r
F P
0 g
s
.76108 .62181 m .76134 .58478 L .7888 .5894 L p .707 .577 .707 r
F P
0 g
s
.35364 .75483 m .34879 .73648 L .32244 .74047 L p .707 .577 .707 r
F P
0 g
s
.31472 .71405 m .31498 .67702 L .29393 .67036 L p .707 .577 .707 r
F P
0 g
s
.32244 .74047 m .32729 .75883 L .35364 .75483 L p .707 .577 .707 r
F P
0 g
s
.66869 .62347 m .66895 .58645 L .69834 .58323 L p .707 .577 .707 r
F P
0 g
s
.6595 .70479 m .65465 .68644 L .67819 .67694 L p .707 .577 .707 r
F P
0 g
s
.29413 .55426 m .28457 .60793 L .29682 .61966 L p .707 .577 .707 r
F P
0 g
s
.67819 .67694 m .68305 .69529 L .6595 .70479 L p .707 .577 .707 r
F P
0 g
s
.29393 .67036 m .29366 .70739 L .31472 .71405 L p .707 .577 .707 r
F P
0 g
s
.79405 .64873 m .7989 .66708 L .77255 .67107 L p .707 .577 .707 r
F P
0 g
s
.77255 .67107 m .76769 .65272 L .79405 .64873 L p .707 .577 .707 r
F P
0 g
s
.76134 .58478 m .76108 .62181 L .72991 .61968 L p .707 .577 .707 r
F P
0 g
s
.72991 .61968 m .73017 .58265 L .76134 .58478 L p .707 .577 .707 r
F P
0 g
s
.47499 .70412 m .47525 .66709 L .45888 .67442 L p .707 .577 .707 r
F P
0 g
s
.48529 .58919 m .47573 .64286 L .48289 .63364 L p .707 .577 .707 r
F P
0 g
s
.48289 .63364 m .49245 .57998 L .48529 .58919 L p .707 .577 .707 r
F P
0 g
s
.69834 .58323 m .69807 .62026 L .66869 .62347 L p .707 .577 .707 r
F P
0 g
s
.32729 .75883 m .32244 .74047 L .30238 .74159 L p .707 .577 .707 r
F P
0 g
s
.69807 .62026 m .69834 .58323 L .73017 .58265 L p .707 .577 .707 r
F P
0 g
s
.28457 .60793 m .29413 .55426 L .29145 .54325 L p .707 .577 .707 r
F P
0 g
s
.30238 .74159 m .30723 .75994 L .32729 .75883 L p .707 .577 .707 r
F P
0 g
s
.73017 .58265 m .72991 .61968 L .69807 .62026 L p .707 .577 .707 r
F P
0 g
s
.29366 .70739 m .29393 .67036 L .28133 .66232 L p .707 .577 .707 r
F P
0 g
s
.68305 .69529 m .67819 .67694 L .70679 .66755 L p .707 .577 .707 r
F P
0 g
s
.70679 .66755 m .71164 .6859 L .68305 .69529 L p .707 .577 .707 r
F P
0 g
s
.76769 .65272 m .77255 .67107 L .74248 .67756 L p .707 .577 .707 r
F P
0 g
s
.74248 .67756 m .73762 .65921 L .76769 .65272 L p .707 .577 .707 r
F P
0 g
s
.28133 .66232 m .28107 .69935 L .29366 .70739 L p .707 .577 .707 r
F P
0 g
s
.29145 .54325 m .28189 .59691 L .28457 .60793 L p .707 .577 .707 r
F P
0 g
s
.71164 .6859 m .70679 .66755 L .73762 .65921 L p .707 .577 .707 r
F P
0 g
s
.73762 .65921 m .74248 .67756 L .71164 .6859 L p .707 .577 .707 r
F P
0 g
s
.30723 .75994 m .30238 .74159 L .29057 .73971 L p .707 .577 .707 r
F P
0 g
s
.29057 .73971 m .29543 .75806 L .30723 .75994 L p .707 .577 .707 r
F P
0 g
s
.49245 .57998 m .48289 .63364 L .48021 .62263 L p .707 .577 .707 r
F P
0 g
s
.48021 .62263 m .48977 .56896 L .49245 .57998 L p .707 .577 .707 r
F P
0 g
s
.28189 .59691 m .29145 .54325 L .2986 .53403 L p .707 .577 .707 r
F P
0 g
s
.28107 .69935 m .28133 .66232 L .27844 .65367 L p .707 .577 .707 r
F P
0 g
s
.27844 .65367 m .27817 .6907 L .28107 .69935 L p .707 .577 .707 r
F P
0 g
s
.2986 .53403 m .28905 .5877 L .28189 .59691 L p .707 .577 .707 r
F P
0 g
s
.29543 .75806 m .29057 .73971 L .28819 .73502 L p .707 .577 .707 r
F P
0 g
s
.47944 .65004 m .47917 .68707 L .46658 .67903 L p .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4711 .68046 L .4783 .68161 L p .707 .577 .707 r
F P
0 g
s
.47917 .68707 m .4793 .66875 L p .48233 .65869 L .707 .577 .707 r
F P
0 g
s
.4783 .68161 m .4829 .68234 L p .47718 .69591 L .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4783 .68161 L .47718 .69591 L .707 .577 .707 r
F
.4793 .66875 m .47944 .65004 L .48052 .65327 L p F P
0 g
s
.48052 .65327 m .48233 .65869 L p .4793 .66875 L .707 .577 .707 r
F P
0 g
s
.28819 .73502 m .29304 .75337 L .29543 .75806 L p .707 .577 .707 r
F P
0 g
s
.48977 .56896 m .48021 .62263 L .46796 .6109 L p .707 .577 .707 r
F P
0 g
s
.46796 .6109 m .47751 .55723 L .48977 .56896 L p .707 .577 .707 r
F P
0 g
s
.28905 .5877 m .2986 .53403 L .3149 .52752 L p .707 .577 .707 r
F P
0 g
s
.48529 .68703 m .49014 .70538 L .48775 .70069 L p .707 .577 .707 r
F P
0 g
s
.48775 .70069 m .4829 .68234 L .48529 .68703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27817 .6907 m .27844 .65367 L .28552 .64527 L p .707 .577 .707 r
F P
0 g
s
.28552 .64527 m .28526 .6823 L .27817 .6907 L p .707 .577 .707 r
F P
0 g
s
.3149 .52752 m .30534 .58118 L .28905 .5877 L p .707 .577 .707 r
F P
0 g
s
.46658 .67903 m .46684 .642 L .47944 .65004 L p .707 .577 .707 r
F P
0 g
s
.47751 .55723 m .46796 .6109 L .44732 .59959 L p .707 .577 .707 r
F P
0 g
s
.44732 .59959 m .45688 .54593 L .47751 .55723 L p .707 .577 .707 r
F P
0 g
s
.29304 .75337 m .28819 .73502 L .29544 .72798 L p .707 .577 .707 r
F P
0 g
s
.30534 .58118 m .3149 .52752 L .33874 .52434 L p .707 .577 .707 r
F P
0 g
s
.29544 .72798 m .3003 .74634 L .29304 .75337 L p .707 .577 .707 r
F P
0 g
s
.4829 .68234 m .48775 .70069 L .47595 .69881 L p .707 .577 .707 r
F P
0 g
s
.28526 .6823 m .28552 .64527 L .30189 .63794 L p .707 .577 .707 r
F P
0 g
s
.33874 .52434 m .32918 .578 L .30534 .58118 L p .707 .577 .707 r
F P
0 g
s
.45688 .54593 m .44732 .59959 L .42034 .58982 L p .707 .577 .707 r
F P
0 g
s
.42034 .58982 m .4299 .53616 L .45688 .54593 L p .707 .577 .707 r
F P
0 g
s
.30189 .63794 m .30163 .67497 L .28526 .6823 L p .707 .577 .707 r
F P
0 g
s
.32918 .578 m .33874 .52434 L .36778 .52481 L p .707 .577 .707 r
F P
0 g
s
.46684 .642 m .46658 .67903 L .44553 .67237 L p .707 .577 .707 r
F P
0 g
s
.44553 .67237 m .44579 .63534 L .46684 .642 L p .707 .577 .707 r
F P
0 g
s
.3003 .74634 m .29544 .72798 L .31164 .71929 L p .707 .577 .707 r
F P
0 g
s
.31164 .71929 m .31649 .73764 L .3003 .74634 L p .707 .577 .707 r
F P
0 g
s
.4299 .53616 m .42034 .58982 L .38963 .58255 L p .707 .577 .707 r
F P
0 g
s
.38963 .58255 m .39919 .52888 L .4299 .53616 L p .707 .577 .707 r
F P
0 g
s
.35822 .57847 m .36778 .52481 L .39919 .52888 L p .707 .577 .707 r
F P
0 g
s
.36778 .52481 m .35822 .57847 L .32918 .578 L p .707 .577 .707 r
F P
0 g
s
.4711 .68046 m .47595 .69881 L .45589 .69993 L p .707 .577 .707 r
F P
0 g
s
.45589 .69993 m .45104 .68157 L .4711 .68046 L p .707 .577 .707 r
F P
0 g
s
.30163 .67497 m .30189 .63794 L .32594 .6324 L p .707 .577 .707 r
F P
0 g
s
.39919 .52888 m .38963 .58255 L .35822 .57847 L p .707 .577 .707 r
F P
0 g
s
.32594 .6324 m .32568 .66942 L .30163 .67497 L p .707 .577 .707 r
F P
0 g
s
.44579 .63534 m .44553 .67237 L .41807 .66775 L p .707 .577 .707 r
F P
0 g
s
.41807 .66775 m .41833 .63073 L .44579 .63534 L p .707 .577 .707 r
F P
0 g
s
.31649 .73764 m .31164 .71929 L .33518 .70978 L p .707 .577 .707 r
F P
0 g
s
.32568 .66942 m .32594 .6324 L .35532 .62918 L p .707 .577 .707 r
F P
0 g
s
.33518 .70978 m .34004 .72813 L .31649 .73764 L p .707 .577 .707 r
F P
0 g
s
.45104 .68157 m .45589 .69993 L .42954 .70392 L p .707 .577 .707 r
F P
0 g
s
.42954 .70392 m .42468 .68557 L .45104 .68157 L p .707 .577 .707 r
F P
0 g
s
.41833 .63073 m .41807 .66775 L .3869 .66563 L p .707 .577 .707 r
F P
0 g
s
.3869 .66563 m .38716 .6286 L .41833 .63073 L p .707 .577 .707 r
F P
0 g
s
.35532 .62918 m .35506 .6662 L .32568 .66942 L p .707 .577 .707 r
F P
0 g
s
.35506 .6662 m .35532 .62918 L .38716 .6286 L p .707 .577 .707 r
F P
0 g
s
.38716 .6286 m .3869 .66563 L .35506 .6662 L p .707 .577 .707 r
F P
0 g
s
.34004 .72813 m .33518 .70978 L .36377 .7004 L p .707 .577 .707 r
F P
0 g
s
.36377 .7004 m .36863 .71875 L .34004 .72813 L p .707 .577 .707 r
F P
0 g
s
.42468 .68557 m .42954 .70392 L .39947 .71041 L p .707 .577 .707 r
F P
0 g
s
.39947 .71041 m .39461 .69206 L .42468 .68557 L p .707 .577 .707 r
F P
0 g
s
.36863 .71875 m .36377 .7004 L .39461 .69206 L p .707 .577 .707 r
F P
0 g
s
.39461 .69206 m .39947 .71041 L .36863 .71875 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
QGoo6@00Ogoo001mOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001fOol007Qoo`D0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H0071oo`00M7oo1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000K7oo001b
Ool200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH01000FUH00000JWoo001`Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00Igoo001^Ool20005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH2001UOol006eoo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001oogoo069oo`00KGoo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF0P00HWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00Oomoo`1OOol0
06aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00YJEP03001oogoo05ioo`00K7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<007ooOol0GWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006ao
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF
0P00Ggoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF0P00Ggoo001/Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH2001OOol006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00]JEP8005mo
o`00K7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]o
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001oogoo05eoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005mo
o`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Ggoo001[Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001OOol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0005moo`00Jgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0Ggoo
001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001POol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001P
Ool006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00H7oo001Z
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001POol006Yoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00
JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80065oo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000=oo`L005Moo`00JGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1@000UYF00<005YFFUH00UYF2000Cgoo001YOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00@005YFFUIJEPL004Qo
o`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@004Aoo`00GGoo40001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000@7oo001G
Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000?Woo001DOol30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF0`00>goo001C
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000i
Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH3000gOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000eOol0059oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8003=oo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Woo001BOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000aOol0055oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP07001JEUYFFUIooeYF0000
0eYF00<007ooOol0;Woo001AOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8002moo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002moo`00DGoo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF0P000UYF1P000UYF00<005YF00000`0027oo1P001UYF00<005YFFUH0
1UYF00@005YFFUIoo`=JEP06001JEUYF001JEP00;goo001AOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH30000
0eYF001JEP05FUH00`00FUIJEP03FUH4000:Ool40002FUH00`00FUIJEP06FUH00`00FUIoo`03FUH0
1`00FUIJEUYF001JEP0002moo`00DGoo0P000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH00003000:Ool4
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo001AOol00eYF001JEP02FUH40002FUH00`00
FUH000030006Ool00`00FUH000060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF
00<005YFFUH00eYF4@001Woo0P0015YF00<005YFFUH015YF00H005YFFUIJEP00FUH`Ool0051oo`04
001JEP00FUH30005FUH00`00FUIJEP03FUH40002Ool01000FUIJEP001EYF10000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF009JEP06001JEP00001JEP001UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2`0000=J
EP00FUH01EYF00H005YFFUH005YF000`Ool0051oo`04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF
FUH005YF0002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@001UYF00H005YFFUH005YF000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF009JEP<000IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH00009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00L005YFFUIJEP00
FUH0000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPL000QJ
EP<00003FUH005YF00EJEP03001JEUYF008000QJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFOol0<7oo001@Ool00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0005FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFOol0<7oo001@Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00@0
05YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF000aOol0051oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUH00000FUH0035oo`00DGoo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP06001JEUYF001JEP00<Goo001BOol00`00FUH00006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH0035oo`00=Woo40003Goo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF001JEP00FUH00008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000b
Ool0035oo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000Moo`03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP800003FUH00000039oo`00;goo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF
000015YF00@005YFFUIJEPT000QJEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH00`00FUIJEP02000bOol002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00EJEQ40009JEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009J
EP03001JEP0000=JEPL0009oo`<00003FUH005YF00MJEP03001JEUYF00AJEP04OomJEUYF0007FUH4
0004FUH00`00FUIJEP02000bOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEP000002Ool80004FUH00`00FUIJEP06FUH01000FUIJEUYF
20000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH01000FUH005YF0P000eYF1P000goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00001@0000AJEP00FUIJEP80039oo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP04001JEP000007FUH01000FUIJ
EUYF2`000UYF00<005YFFUH01EYF00=oo`00FUH00UYF1P0015YF00@005YF0000009JEP80039oo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YF00000`000eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF
00@005YFFUIJEP@0039oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00<Woo000[Ool20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000bOol002Yoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEPh0039oo`00:Woo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH60003FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP00035oo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF000aOol002Yoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
0080009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000`Ool002Yoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP@0
00MJEP03001JEUYF00IJEP03001JEUYF009JEPd0031oo`00:Woo0P000eYF00@005YFFUIJEQ0000AJ
EP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH80002FUH20002Ool01000FUIJEP001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH000000080009JEP03001JEUYF
00800003FUH005YF00QJEP03001JEUYF00EJEPP0009oo`8000=JEP04001JEUYF000`Ool002Yoo`03
FUH005YF009JEP@0009JEP04001JEP00000:Ool70005FUH00`00FUH00003FUH50005FUH01000FUIJ
EUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH5
0004FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool30005FUH00`00FUH0000`Ool002Uoo`04001J
EP00FUH30005FUH01000FUIJEUYF0`003Woo100000AJEP00FUH0009JEP04001JEUYFFUH50002FUH0
1000FUIJEUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00H00003FUH005YF
009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00IJEP8000MJEP03001JEUYF00IJEP@000Yoo`8000=JEP03001JEUYF009JEP80035oo`00:Goo00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP@000ioo`800004FUH000000005FUH01000
FUIJEUYF2@0000Eoo`00FUIJEP0000AJEP<000IJEPl00003FUH0000000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<000QJEP03001JEUYF00=JEP<0
00Yoo`@000EJEP03001JEUYF009JEP03001oogoo031oo`00:Goo0P0015YF00<005YFFUH00UYF00<0
05YFFUH01UYF00<005YFFUH010002goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
009JEQL000=JEP03001JEUYF009JEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEP00008000Uoo`@0
009JEP03001JEUYF00EJEP04001JEP00000cOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH900000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
0`0027oo10001UYF00<005YFFUH015YF0`00=Goo000YOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP06FUH00`00FUIJEP040009Ool200000eYF001JEP08FUH01000FUIJEUYF0P00>7oo000YOol00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH4000:Ool30004FUH00`00FUIJEP06
FUH01000FUH00000>Woo000YOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF00IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001oo`05
Ool40007FUH00`00FUIJEP05FUH3000lOol002Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00MJEP04001JEUYFFUH70002FUH50006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020002
FUH00`00FUH00002Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000oOol002Yoo`04001J
EUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030005FUH0
0`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH01000FUIJEUYF0`000UYF
00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=J
EP<0009JEP03001JEP0000D000IJEP03001JEUYF00MJEP03001JEP000080045oo`00:goo0`001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00UYF10001EYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00@005YF0000
00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40014Ool002eoo`03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP<00004FUH005YFFUH200000eYF
001JEP07FUH00`00FUIJEP04FUH50007FUH01000FUIJEUYF1@001EYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP0000001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01000B7oo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH70019Ool0
031oo`800003FUH005YF00IJEP03001JEUYF00EJEPP0009JEP03001JEUYF00EJEP03001JEUYF0080
00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@000=o
o`D004Qoo`00<Woo0`001EYF2@0015YF00@005YFFUIJEPP0009JEP@000MJEP03001JEUYF009JEP80
009JEP03001JEUYF00AJEP03001JEP0000<000MJEP03001JEUYF00=JEP<000aJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH60007Ool50018Ool0039oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP05FUH00`00FUH000020002Ool2FUH00`00FUIJEP02FUH40002FUH00`00FUIJ
EP06FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0?000<Ool50018Ool002ioo`@000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP03FUH30005Ool2FUH50006FUH0
0`00FUIJEP05FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEUYF10003Goo0`00BGoo000/Ool30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUH000050005
Ool400000eYF001JEP08FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH3001IOol0
02Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP03001JEUYF009JEP80009JEP800003Ool0000000@000IJEP03001JEUYF00IJEP03
001JEP00008000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEP0005Uoo`00:Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YF
FUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP`005Uoo`00
:Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001J
EUYF00AJEQT000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP04001J
EUYF001IOol002Qoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60006
FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUH00004FUH01@00FUIJEUYF0000F7oo000XOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00@0
05YFFUH005Qoo`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP04001JEUYFFUH60002FUH0
0`00FUIJEP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUH000030006FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00@005YFFUH005Qo
o`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00@005YFFUIJEP80
009JEP04001JEUYFFUH600000eYF001oo`02Ool01000FUIJEP000eYF0P001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YF
FUH00eYF2`000UYF00<007ooOol0EGoo000XOol00`00FUH00003FUH00`00FUIJEP03FUH6000AOol8
0002FUH60002FUH01000FUIJEUYF0P000goo00D005YFFUH005YF00<000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00AJ
EP<0009oo`8000=JEP@005Moo`00:7oo00<005YF00000eYF00<005YF00000`007goo1P0015YF00@0
05YFFUIJEP8000=oo`03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000005FUH00`00Oomo
o`030005FUH00`00FUH0001GOol002Qoo`03001JEP0000=JEP800004FUH00000000ROol600000eYF
001JEP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF0`000eYF
00<005YFFUH00UYF0P00F7oo000XOol01000FUH005YF0P0015YF00<005YF00000`0047oo0`001Woo
1@000UYF200000=JEP0000000goo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0Egoo000XOol00`00FUH000020005FUH00`00FUIJ
EP03FUHI0003FUH400000eYF001JEP03FUH00`00FUIJEP020003Ool00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000FUH00000FWoo000XOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00000010001EYF
00<005YFFUH00eYF00@005YFFUH000=oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000QJEP03001JEUYF00=JEP04001J
EP000005FUH3001LOol002Qoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000Aoo`03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP8000QJEP03001JEUYF00=JEP04001JEP000003FUH2001OOol002Qoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP000goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YFFUH00eYF00D0
05YFFUH005YF0080065oo`00:7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001oo`03Ool00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02001SOol002Qoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF
1`000UYF1@0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo000YOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH0
1000FUIJEUYF0`000UYF00<007ooOol017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00IWoo000[Ool30004FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUH000000eYF
0P002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P00IWoo000^Ool3000015YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF1@001eYF00<005YFFUH00eYF0`001EYF00<007ooOol02Woo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0IGoo000a
Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH00`00FUH000030003
FUH00`00FUIJEP02000?Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00
FUIJEP07FUH01000FUIJEUYF0P00J7oo000aOol20005FUH00`00FUIJEP05FUH40004FUH>0007FUH3
000DOol30009FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP07FUH01000FUH00000JWoo
000`Ool20007FUH00`00FUIJEP02FUH:0003Ool40007FUH00`00FUIJEP03FUH2000IOol40005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP04FUH5001/Ool002ioo`800003FUH005YF00IJ
EP03001JEP00008000Uoo`@0009JEP03001JEUYF00IJEP03001JEP0000<001moo`@00003FUH005YF
00]JEP03001JEUYF01EJEP03001JEP0000@0075oo`00;Goo00<005YFFUH00UYF00<005YFFUH00eYF
0`0027oo10001UYF00<005YFFUH01EYF0`009goo20001UYF00<005YFFUH045YF1`00MWoo000[Ool3
0004FUH00`00FUH000030007Ool400000eYF001JEP08FUH00`00FUIJEP02FUH2000bOolI001mOol0
02Yoo`04001JEUYF0004FUH20005Ool60006FUH00`00FUIJEP06FUH00`00FUH00002003:Ool002Yo
o`05001JEUYFFUH00002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3003=Ool002]oo`03
001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@00=1oo`00:goo00@0
05YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD00=Aoo`00;7oo0P0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01000fGoo000/Ool01000FUIJEP001UYF00@005YFFUIJEPH00=eo
o`00;7oo0P000UYF00@005YFFUIJEPH00>=oo`00;Woo1P00jGoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58685 .73685 m .59278 .68225 L .56178 .677 L p .707 .577 .707 r
F P
0 g
s
.59278 .68225 m .58685 .73685 L .61852 .73909 L p .707 .577 .707 r
F P
0 g
s
.61852 .73909 m .62445 .68449 L .59278 .68225 L p .707 .577 .707 r
F P
0 g
s
.62445 .68449 m .61852 .73909 L .64778 .73811 L p .707 .577 .707 r
F P
0 g
s
.64778 .73811 m .6537 .6835 L .62445 .68449 L p .707 .577 .707 r
F P
0 g
s
.55586 .73161 m .56178 .677 L .53451 .66926 L p .707 .577 .707 r
F P
0 g
s
.56178 .677 m .55586 .73161 L .58685 .73685 L p .707 .577 .707 r
F P
0 g
s
.6537 .6835 m .64778 .73811 L .67175 .734 L p .707 .577 .707 r
F P
0 g
s
.67175 .734 m .67767 .67939 L .6537 .6835 L p .707 .577 .707 r
F P
0 g
s
.52858 .72387 m .53451 .66926 L .51361 .65979 L p .707 .577 .707 r
F P
0 g
s
.53451 .66926 m .52858 .72387 L .55586 .73161 L p .707 .577 .707 r
F P
0 g
s
.58564 .7833 m .5858 .74626 L .55463 .74422 L p .707 .577 .707 r
F P
0 g
s
.5858 .74626 m .58564 .7833 L .61747 .78264 L p .707 .577 .707 r
F P
0 g
s
.61747 .78264 m .61763 .74561 L .5858 .74626 L p .707 .577 .707 r
F P
0 g
s
.61763 .74561 m .61747 .78264 L .64685 .77936 L p .707 .577 .707 r
F P
0 g
s
.64685 .77936 m .64702 .74233 L .61763 .74561 L p .707 .577 .707 r
F P
0 g
s
.55446 .78126 m .55463 .74422 L .52717 .73969 L p .707 .577 .707 r
F P
0 g
s
.55463 .74422 m .55446 .78126 L .58564 .7833 L p .707 .577 .707 r
F P
0 g
s
.64702 .74233 m .64685 .77936 L .67091 .77378 L p .707 .577 .707 r
F P
0 g
s
.67091 .77378 m .67107 .73674 L .64702 .74233 L p .707 .577 .707 r
F P
0 g
s
.59231 .82447 m .58929 .80589 L .55854 .80918 L p .707 .577 .707 r
F P
0 g
s
.58929 .80589 m .59231 .82447 L .62377 .81901 L p .707 .577 .707 r
F P
0 g
s
.62377 .81901 m .62074 .80042 L .58929 .80589 L p .707 .577 .707 r
F P
0 g
s
.67767 .67939 m .67175 .734 L .68809 .72716 L p .707 .577 .707 r
F P
0 g
s
.68809 .72716 m .69401 .67255 L .67767 .67939 L p .707 .577 .707 r
F P
0 g
s
.62074 .80042 m .62377 .81901 L .65285 .81191 L p .707 .577 .707 r
F P
0 g
s
.65285 .81191 m .64982 .79332 L .62074 .80042 L p .707 .577 .707 r
F P
0 g
s
.52717 .73969 m .52701 .77673 L .55446 .78126 L p .707 .577 .707 r
F P
0 g
s
.51361 .65979 m .50769 .71439 L .52858 .72387 L p .707 .577 .707 r
F P
0 g
s
.55854 .80918 m .56156 .82777 L .59231 .82447 L p .707 .577 .707 r
F P
0 g
s
.50769 .71439 m .51361 .65979 L .50115 .64951 L p .707 .577 .707 r
F P
0 g
s
.52701 .77673 m .52717 .73969 L .50611 .73311 L p .707 .577 .707 r
F P
0 g
s
.56156 .82777 m .55854 .80918 L .53151 .80999 L p .707 .577 .707 r
F P
0 g
s
.53151 .80999 m .53453 .82857 L .56156 .82777 L p .707 .577 .707 r
F P
0 g
s
.64982 .79332 m .65285 .81191 L .6767 .80387 L p .707 .577 .707 r
F P
0 g
s
.6767 .80387 m .67368 .78529 L .64982 .79332 L p .707 .577 .707 r
F P
0 g
s
.50611 .73311 m .50595 .77015 L .52701 .77673 L p .707 .577 .707 r
F P
0 g
s
.67107 .73674 m .67091 .77378 L .68728 .76643 L p .707 .577 .707 r
F P
0 g
s
.68728 .76643 m .68744 .72939 L .67107 .73674 L p .707 .577 .707 r
F P
0 g
s
.50115 .64951 m .49522 .70412 L .50769 .71439 L p .707 .577 .707 r
F P
0 g
s
.53453 .82857 m .53151 .80999 L .51083 .80822 L p .707 .577 .707 r
F P
0 g
s
.69401 .67255 m .68809 .72716 L .6952 .71827 L p .707 .577 .707 r
F P
0 g
s
.6952 .71827 m .70113 .66366 L .69401 .67255 L p .707 .577 .707 r
F P
0 g
s
.51083 .80822 m .51386 .8268 L .53453 .82857 L p .707 .577 .707 r
F P
0 g
s
.50595 .77015 m .50611 .73311 L .49352 .72513 L p .707 .577 .707 r
F P
0 g
s
.67368 .78529 m .6767 .80387 L .69301 .79568 L p .707 .577 .707 r
F P
0 g
s
.69301 .79568 m .68998 .7771 L .67368 .78529 L p .707 .577 .707 r
F P
0 g
s
.49522 .70412 m .50115 .64951 L .49834 .63943 L p .707 .577 .707 r
F P
0 g
s
.49352 .72513 m .49336 .76216 L .50595 .77015 L p .707 .577 .707 r
F P
0 g
s
.68744 .72939 m .68728 .76643 L .69436 .75805 L p .707 .577 .707 r
F P
0 g
s
.69436 .75805 m .69452 .72101 L .68744 .72939 L p .707 .577 .707 r
F P
0 g
s
.51386 .8268 m .51083 .80822 L .49854 .80406 L p .707 .577 .707 r
F P
0 g
s
.49834 .63943 m .49241 .69404 L .49522 .70412 L p .707 .577 .707 r
F P
0 g
s
.49854 .80406 m .50157 .82264 L .51386 .8268 L p .707 .577 .707 r
F P
0 g
s
.70113 .66366 m .6952 .71827 L .69238 .70819 L p .707 .577 .707 r
F P
0 g
s
.69238 .70819 m .69831 .65358 L .70113 .66366 L p .707 .577 .707 r
F P
0 g
s
.49336 .76216 m .49352 .72513 L .49063 .71652 L p .707 .577 .707 r
F P
0 g
s
.68998 .7771 m .69301 .79568 L .70016 .78814 L p .707 .577 .707 r
F P
0 g
s
.70016 .78814 m .69713 .76955 L .68998 .7771 L p .707 .577 .707 r
F P
0 g
s
.49241 .69404 m .49834 .63943 L .50545 .63054 L p .707 .577 .707 r
F P
0 g
s
.49063 .71652 m .49046 .75356 L .49336 .76216 L p .707 .577 .707 r
F P
0 g
s
.50545 .63054 m .49952 .68514 L .49241 .69404 L p .707 .577 .707 r
F P
0 g
s
.49046 .75356 m .49063 .71652 L .49771 .70813 L p .707 .577 .707 r
F P
0 g
s
.49771 .70813 m .49755 .74517 L .49046 .75356 L p .707 .577 .707 r
F P
0 g
s
.4941 .82315 m .50516 .32258 L .46117 .31891 L p .707 .577 .707 r
F P
0 g
s
.50157 .82264 m .49854 .80406 L .49584 .7979 L p .707 .577 .707 r
F P
0 g
s
.49584 .7979 m .49887 .81649 L .50157 .82264 L p .707 .577 .707 r
F P
0 g
s
.49952 .68514 m .50545 .63054 L .52179 .6237 L p .707 .577 .707 r
F P
0 g
s
.49887 .81649 m .49584 .7979 L .50299 .79036 L p .707 .577 .707 r
F P
0 g
s
.52179 .6237 m .51586 .6783 L .49952 .68514 L p .707 .577 .707 r
F P
0 g
s
.50299 .79036 m .50602 .80895 L .49887 .81649 L p .707 .577 .707 r
F P
0 g
s
.49755 .74517 m .49771 .70813 L .51408 .70079 L p .707 .577 .707 r
F P
0 g
s
.51586 .6783 m .52179 .6237 L .54576 .61959 L p .707 .577 .707 r
F P
0 g
s
.51408 .70079 m .51392 .73782 L .49755 .74517 L p .707 .577 .707 r
F P
0 g
s
.54576 .61959 m .53983 .67419 L .51586 .6783 L p .707 .577 .707 r
F P
0 g
s
.50602 .80895 m .50299 .79036 L .51929 .78217 L p .707 .577 .707 r
F P
0 g
s
.51929 .78217 m .52232 .80075 L .50602 .80895 L p .707 .577 .707 r
F P
0 g
s
.51392 .73782 m .51408 .70079 L .53813 .6952 L p .707 .577 .707 r
F P
0 g
s
.53813 .6952 m .53797 .73224 L .51392 .73782 L p .707 .577 .707 r
F P
0 g
s
.52232 .80075 m .51929 .78217 L .54315 .77413 L p .707 .577 .707 r
F P
0 g
s
.54315 .77413 m .54618 .79272 L .52232 .80075 L p .707 .577 .707 r
F P
0 g
s
.50516 .32258 m .4941 .82315 L .53903 .82294 L p .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .54576 .61959 L .57408 .61863 L p .707 .577 .707 r
F P
0 g
s
.57408 .61863 m .57501 .6186 L p .57356 .6209 L .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .57408 .61863 L .57356 .6209 L .707 .577 .707 r
F
.53797 .73224 m .53813 .6952 L .56751 .69192 L p F P
0 g
s
.5501 .32237 m .50516 .32258 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.53903 .82294 m .54033 .76419 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.57501 .6186 m .56908 .67321 L .53983 .67419 L p .707 .577 .707 r
F P
0 g
s
.56751 .69192 m .56735 .72896 L .53797 .73224 L p .707 .577 .707 r
F P
0 g
s
.54033 .76419 m .5501 .32237 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.56908 .67321 m .57501 .6186 L .60668 .62084 L p .707 .577 .707 r
F P
0 g
s
.60668 .62084 m .60076 .67545 L .56908 .67321 L p .707 .577 .707 r
F P
0 g
s
.56735 .72896 m .56751 .69192 L .59935 .69127 L p .707 .577 .707 r
F P
0 g
s
.59935 .69127 m .59919 .72831 L .56735 .72896 L p .707 .577 .707 r
F P
0 g
s
.54618 .79272 m .54315 .77413 L .57223 .76703 L p .707 .577 .707 r
F P
0 g
s
.57223 .76703 m .57526 .78562 L .54618 .79272 L p .707 .577 .707 r
F P
0 g
s
.57526 .78562 m .57223 .76703 L .60368 .76157 L p .707 .577 .707 r
F P
0 g
s
.60368 .76157 m .60671 .78015 L .57526 .78562 L p .707 .577 .707 r
F P
0 g
s
.5501 .32237 m .53903 .82294 L .5805 .81887 L p .707 .577 .707 r
F P
0 g
s
.5805 .81887 m .59157 .3183 L .5501 .32237 L p .707 .577 .707 r
F P
0 g
s
.4501 .81948 m .46117 .31891 L .42241 .31173 L p .707 .577 .707 r
F P
0 g
s
.46117 .31891 m .4501 .81948 L .4941 .82315 L p .707 .577 .707 r
F P
0 g
s
.69452 .72101 m .69436 .75805 L .69146 .74944 L p .707 .577 .707 r
F P
0 g
s
.69146 .74944 m .69163 .7124 L .69452 .72101 L p .707 .577 .707 r
F P
0 g
s
.63768 .62609 m .63175 .6807 L .60076 .67545 L p .707 .577 .707 r
F P
0 g
s
.60076 .67545 m .60668 .62084 L .63768 .62609 L p .707 .577 .707 r
F P
0 g
s
.63052 .69331 m .63036 .73035 L .59919 .72831 L p .707 .577 .707 r
F P
0 g
s
.59919 .72831 m .59935 .69127 L .63052 .69331 L p .707 .577 .707 r
F P
0 g
s
.63443 .75827 m .63746 .77686 L .60671 .78015 L p .707 .577 .707 r
F P
0 g
s
.60671 .78015 m .60368 .76157 L .63443 .75827 L p .707 .577 .707 r
F P
0 g
s
.59157 .3183 m .5805 .81887 L .61446 .81134 L p .707 .577 .707 r
F P
0 g
s
.61446 .81134 m .62552 .31077 L .59157 .3183 L p .707 .577 .707 r
F P
0 g
s
.69831 .65358 m .69238 .70819 L .67992 .69791 L p .707 .577 .707 r
F P
0 g
s
.67992 .69791 m .68585 .6433 L .69831 .65358 L p .707 .577 .707 r
F P
0 g
s
.69713 .76955 m .70016 .78814 L .69746 .78198 L p .707 .577 .707 r
F P
0 g
s
.69746 .78198 m .69443 .7634 L .69713 .76955 L p .707 .577 .707 r
F P
0 g
s
.41135 .8123 m .42241 .31173 L .3927 .30173 L p .707 .577 .707 r
F P
0 g
s
.42241 .31173 m .41135 .8123 L .4501 .81948 L p .707 .577 .707 r
F P
0 g
s
.24384 .72972 m .24977 .67512 L .21878 .66987 L p .707 .577 .707 r
F P
0 g
s
.24977 .67512 m .24384 .72972 L .27551 .73196 L p .707 .577 .707 r
F P
0 g
s
.27551 .73196 m .28144 .67736 L .24977 .67512 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69163 .7124 m .69146 .74944 L .67887 .74146 L p .707 .577 .707 r
F P
0 g
s
.67887 .74146 m .67903 .70442 L .69163 .7124 L p .707 .577 .707 r
F P
0 g
s
.28144 .67736 m .27551 .73196 L .30477 .73098 L p .707 .577 .707 r
F P
0 g
s
.30477 .73098 m .31069 .67637 L .28144 .67736 L p .707 .577 .707 r
F P
0 g
s
.21285 .72448 m .21878 .66987 L .1915 .66213 L p .707 .577 .707 r
F P
0 g
s
.21878 .66987 m .21285 .72448 L .24384 .72972 L p .707 .577 .707 r
F P
0 g
s
.66495 .63383 m .65903 .68843 L .63175 .6807 L p .707 .577 .707 r
F P
0 g
s
.63175 .6807 m .63768 .62609 L .66495 .63383 L p .707 .577 .707 r
F P
0 g
s
.65798 .69784 m .65782 .73488 L .63036 .73035 L p .707 .577 .707 r
F P
0 g
s
.63036 .73035 m .63052 .69331 L .65798 .69784 L p .707 .577 .707 r
F P
0 g
s
.63746 .77686 m .63443 .75827 L .66147 .75747 L p .707 .577 .707 r
F P
0 g
s
.62552 .31077 m .61446 .81134 L .63756 .8011 L p .707 .577 .707 r
F P
0 g
s
.66147 .75747 m .66449 .77605 L .63746 .77686 L p .707 .577 .707 r
F P
0 g
s
.63756 .8011 m .64863 .30053 L .62552 .31077 L p .707 .577 .707 r
F P
0 g
s
.68585 .6433 m .67992 .69791 L .65903 .68843 L p .707 .577 .707 r
F P
0 g
s
.65903 .68843 m .66495 .63383 L .68585 .6433 L p .707 .577 .707 r
F P
0 g
s
.69443 .7634 m .69746 .78198 L .68517 .77782 L p .707 .577 .707 r
F P
0 g
s
.68517 .77782 m .68214 .75924 L .69443 .7634 L p .707 .577 .707 r
F P
0 g
s
.31069 .67637 m .30477 .73098 L .32874 .72687 L p .707 .577 .707 r
F P
0 g
s
.32874 .72687 m .33466 .67226 L .31069 .67637 L p .707 .577 .707 r
F P
0 g
s
.18557 .71674 m .1915 .66213 L .1706 .65266 L p .707 .577 .707 r
F P
0 g
s
.1915 .66213 m .18557 .71674 L .21285 .72448 L p .707 .577 .707 r
F P
0 g
s
.38163 .8023 m .3927 .30173 L .37493 .2899 L p .707 .577 .707 r
F P
0 g
s
.3927 .30173 m .38163 .8023 L .41135 .8123 L p .707 .577 .707 r
F P
0 g
s
.24263 .79763 m .24279 .76059 L .21162 .75855 L p .707 .577 .707 r
F P
0 g
s
.24279 .76059 m .24263 .79763 L .27446 .79698 L p .707 .577 .707 r
F P
0 g
s
.27446 .79698 m .27463 .75994 L .24279 .76059 L p .707 .577 .707 r
F P
0 g
s
.27463 .75994 m .27446 .79698 L .30385 .7937 L p .707 .577 .707 r
F P
0 g
s
.30385 .7937 m .30401 .75666 L .27463 .75994 L p .707 .577 .707 r
F P
0 g
s
.67903 .70442 m .67887 .74146 L .65782 .73488 L p .707 .577 .707 r
F P
0 g
s
.65782 .73488 m .65798 .69784 L .67903 .70442 L p .707 .577 .707 r
F P
0 g
s
.21146 .79559 m .21162 .75855 L .18416 .75402 L p .707 .577 .707 r
F P
0 g
s
.21162 .75855 m .21146 .79559 L .24263 .79763 L p .707 .577 .707 r
F P
0 g
s
.33466 .67226 m .32874 .72687 L .34508 .72003 L p .707 .577 .707 r
F P
0 g
s
.34508 .72003 m .351 .66543 L .33466 .67226 L p .707 .577 .707 r
F P
0 g
s
.1706 .65266 m .16468 .70727 L .18557 .71674 L p .707 .577 .707 r
F P
0 g
s
.2493 .83071 m .24628 .81213 L .21553 .81542 L p .707 .577 .707 r
F P
0 g
s
.24628 .81213 m .2493 .83071 L .28076 .82525 L p .707 .577 .707 r
F P
0 g
s
.28076 .82525 m .27773 .80666 L .24628 .81213 L p .707 .577 .707 r
F P
0 g
s
.27773 .80666 m .28076 .82525 L .30984 .81815 L p .707 .577 .707 r
F P
0 g
s
.30984 .81815 m .30681 .79956 L .27773 .80666 L p .707 .577 .707 r
F P
0 g
s
.30401 .75666 m .30385 .7937 L .3279 .78811 L p .707 .577 .707 r
F P
0 g
s
.3279 .78811 m .32806 .75108 L .30401 .75666 L p .707 .577 .707 r
F P
0 g
s
.16468 .70727 m .1706 .65266 L .15814 .64238 L p .707 .577 .707 r
F P
0 g
s
.21553 .81542 m .21856 .83401 L .2493 .83071 L p .707 .577 .707 r
F P
0 g
s
.18416 .75402 m .184 .79106 L .21146 .79559 L p .707 .577 .707 r
F P
0 g
s
.68214 .75924 m .68517 .77782 L .66449 .77605 L p .707 .577 .707 r
F P
0 g
s
.66449 .77605 m .66147 .75747 L .68214 .75924 L p .707 .577 .707 r
F P
0 g
s
.64863 .30053 m .63756 .8011 L .64757 .78913 L p .707 .577 .707 r
F P
0 g
s
.64757 .78913 m .65863 .28856 L .64863 .30053 L p .707 .577 .707 r
F P
0 g
s
.21856 .83401 m .21553 .81542 L .1885 .81623 L p .707 .577 .707 r
F P
0 g
s
.184 .79106 m .18416 .75402 L .16311 .74744 L p .707 .577 .707 r
F P
0 g
s
.1885 .81623 m .19152 .83481 L .21856 .83401 L p .707 .577 .707 r
F P
0 g
s
.30681 .79956 m .30984 .81815 L .3337 .81011 L p .707 .577 .707 r
F P
0 g
s
.3337 .81011 m .33067 .79153 L .30681 .79956 L p .707 .577 .707 r
F P
0 g
s
.16311 .74744 m .16294 .78448 L .184 .79106 L p .707 .577 .707 r
F P
0 g
s
.15814 .64238 m .15221 .69699 L .16468 .70727 L p .707 .577 .707 r
F P
0 g
s
.36386 .79047 m .37493 .2899 L .37084 .27739 L p .707 .577 .707 r
F P
0 g
s
.37493 .2899 m .36386 .79047 L .38163 .8023 L p .707 .577 .707 r
F P
0 g
s
.32806 .75108 m .3279 .78811 L .34427 .78077 L p .707 .577 .707 r
F P
0 g
s
.34427 .78077 m .34443 .74373 L .32806 .75108 L p .707 .577 .707 r
F P
0 g
s
.351 .66543 m .34508 .72003 L .35219 .71114 L p .707 .577 .707 r
F P
0 g
s
.35219 .71114 m .35812 .65653 L .351 .66543 L p .707 .577 .707 r
F P
0 g
s
.19152 .83481 m .1885 .81623 L .16782 .81446 L p .707 .577 .707 r
F P
0 g
s
.16782 .81446 m .17085 .83304 L .19152 .83481 L p .707 .577 .707 r
F P
0 g
s
.15221 .69699 m .15814 .64238 L .15533 .6323 L p .707 .577 .707 r
F P
0 g
s
.33067 .79153 m .3337 .81011 L .35 .80192 L p .707 .577 .707 r
F P
0 g
s
.35 .80192 m .34697 .78333 L .33067 .79153 L p .707 .577 .707 r
F P
0 g
s
.16294 .78448 m .16311 .74744 L .15051 .73946 L p .707 .577 .707 r
F P
0 g
s
.15051 .73946 m .15035 .7765 L .16294 .78448 L p .707 .577 .707 r
F P
0 g
s
.65455 .27605 m .64348 .77662 L .62571 .76479 L p .707 .577 .707 r
F P
0 g
s
.64489 .62236 m .64505 .62086 L p .63835 .55747 L .707 .577 .707 r
F P
0 g
s
.65863 .28856 m .64757 .78913 L .64456 .77994 L p .707 .577 .707 r
F P
0 g
s
.64469 .73756 m .65863 .28856 L .64456 .77994 L .707 .577 .707 r
F
.64348 .77662 m .65455 .27605 L .65863 .28856 L p F P
0 g
s
.64505 .62086 m .65082 .56775 L .64523 .56314 L p .707 .577 .707 r
F P
0 g
s
.64523 .56314 m .63835 .55747 L p .64505 .62086 L .707 .577 .707 r
F P
0 g
s
.64456 .77994 m .64348 .77662 L p .64469 .73756 L .707 .577 .707 r
F P
0 g
s
.15533 .6323 m .1494 .68691 L .15221 .69699 L p .707 .577 .707 r
F P
0 g
s
.34443 .74373 m .34427 .78077 L .35135 .77238 L p .707 .577 .707 r
F P
0 g
s
.35135 .77238 m .35151 .73534 L .34443 .74373 L p .707 .577 .707 r
F P
0 g
s
.17085 .83304 m .16782 .81446 L .15553 .8103 L p .707 .577 .707 r
F P
0 g
s
.15553 .8103 m .15856 .82888 L .17085 .83304 L p .707 .577 .707 r
F P
0 g
s
.35812 .65653 m .35219 .71114 L .34938 .70106 L p .707 .577 .707 r
F P
0 g
s
.34938 .70106 m .3553 .64645 L .35812 .65653 L p .707 .577 .707 r
F P
0 g
s
.34697 .78333 m .35 .80192 L .35715 .79438 L p .707 .577 .707 r
F P
0 g
s
.35715 .79438 m .35412 .77579 L .34697 .78333 L p .707 .577 .707 r
F P
0 g
s
.1494 .68691 m .15533 .6323 L .16244 .62341 L p .707 .577 .707 r
F P
0 g
s
.15035 .7765 m .15051 .73946 L .14762 .73086 L p .707 .577 .707 r
F P
0 g
s
.37084 .27739 m .35978 .77796 L .36386 .79047 L p .707 .577 .707 r
F P
0 g
s
.35978 .77796 m .37084 .27739 L .38085 .26543 L p .707 .577 .707 r
F P
0 g
s
.14762 .73086 m .14745 .76789 L .15035 .7765 L p .707 .577 .707 r
F P
0 g
s
.15856 .82888 m .15553 .8103 L .15283 .80414 L p .707 .577 .707 r
F P
0 g
s
.16244 .62341 m .15651 .67801 L .1494 .68691 L p .707 .577 .707 r
F P
0 g
s
.35151 .73534 m .35135 .77238 L .34845 .76377 L p .707 .577 .707 r
F P
0 g
s
.34845 .76377 m .34862 .72674 L .35151 .73534 L p .707 .577 .707 r
F P
0 g
s
.15283 .80414 m .15586 .82273 L .15856 .82888 L p .707 .577 .707 r
F P
0 g
s
.3553 .64645 m .34938 .70106 L .33691 .69078 L p .707 .577 .707 r
F P
0 g
s
.33691 .69078 m .34284 .63617 L .3553 .64645 L p .707 .577 .707 r
F P
0 g
s
.35412 .77579 m .35715 .79438 L .35445 .78822 L p .707 .577 .707 r
F P
0 g
s
.35445 .78822 m .35142 .76964 L .35412 .77579 L p .707 .577 .707 r
F P
0 g
s
.15651 .67801 m .16244 .62341 L .17878 .61657 L p .707 .577 .707 r
F P
0 g
s
.62571 .76479 m .63678 .26422 L .65455 .27605 L p .707 .577 .707 r
F P
0 g
s
.14745 .76789 m .14762 .73086 L .1547 .72247 L p .707 .577 .707 r
F P
0 g
s
.1547 .72247 m .15454 .75951 L .14745 .76789 L p .707 .577 .707 r
F P
0 g
s
.36978 .766 m .38085 .26543 L .40395 .25518 L p .707 .577 .707 r
F P
0 g
s
.38085 .26543 m .36978 .766 L .35978 .77796 L p .707 .577 .707 r
F P
0 g
s
.17878 .61657 m .17285 .67117 L .15651 .67801 L p .707 .577 .707 r
F P
0 g
s
.34862 .72674 m .34845 .76377 L .33586 .75579 L p .707 .577 .707 r
F P
0 g
s
.33586 .75579 m .33602 .71875 L .34862 .72674 L p .707 .577 .707 r
F P
0 g
s
.15586 .82273 m .15283 .80414 L .15998 .7966 L p .707 .577 .707 r
F P
0 g
s
.34284 .63617 m .33691 .69078 L .31602 .6813 L p .707 .577 .707 r
F P
0 g
s
.31602 .6813 m .32195 .6267 L .34284 .63617 L p .707 .577 .707 r
F P
0 g
s
.15998 .7966 m .16301 .81518 L .15586 .82273 L p .707 .577 .707 r
F P
0 g
s
.17285 .67117 m .17878 .61657 L .20275 .61246 L p .707 .577 .707 r
F P
0 g
s
.35142 .76964 m .35445 .78822 L .34216 .78406 L p .707 .577 .707 r
F P
0 g
s
.34216 .78406 m .33913 .76548 L .35142 .76964 L p .707 .577 .707 r
F P
0 g
s
.15454 .75951 m .1547 .72247 L .17107 .71512 L p .707 .577 .707 r
F P
0 g
s
.63678 .26422 m .62571 .76479 L .596 .75479 L p .707 .577 .707 r
F P
0 g
s
.596 .75479 m .60706 .25422 L .63678 .26422 L p .707 .577 .707 r
F P
0 g
s
.17107 .71512 m .17091 .75216 L .15454 .75951 L p .707 .577 .707 r
F P
0 g
s
.32195 .6267 m .31602 .6813 L .28874 .67357 L p .707 .577 .707 r
F P
0 g
s
.28874 .67357 m .29467 .61896 L .32195 .6267 L p .707 .577 .707 r
F P
0 g
s
.20275 .61246 m .19682 .66706 L .17285 .67117 L p .707 .577 .707 r
F P
0 g
s
.33602 .71875 m .33586 .75579 L .31481 .74921 L p .707 .577 .707 r
F P
0 g
s
.31481 .74921 m .31497 .71218 L .33602 .71875 L p .707 .577 .707 r
F P
0 g
s
.19682 .66706 m .20275 .61246 L .232 .61147 L p .707 .577 .707 r
F P
0 g
s
.16301 .81518 m .15998 .7966 L .17628 .78841 L p .707 .577 .707 r
F P
0 g
s
.17628 .78841 m .17931 .80699 L .16301 .81518 L p .707 .577 .707 r
F P
0 g
s
.40395 .25518 m .39288 .75575 L .36978 .766 L p .707 .577 .707 r
F P
0 g
s
.39288 .75575 m .40395 .25518 L .43791 .24766 L p .707 .577 .707 r
F P
0 g
s
.17091 .75216 m .17107 .71512 L .19512 .70954 L p .707 .577 .707 r
F P
0 g
s
.29467 .61896 m .28874 .67357 L .25775 .66832 L p .707 .577 .707 r
F P
0 g
s
.25775 .66832 m .26367 .61371 L .29467 .61896 L p .707 .577 .707 r
F P
0 g
s
.33913 .76548 m .34216 .78406 L .32148 .78229 L p .707 .577 .707 r
F P
0 g
s
.32148 .78229 m .31846 .76371 L .33913 .76548 L p .707 .577 .707 r
F P
0 g
s
.72405 .64481 m .72998 .59021 L .69899 .58496 L p .707 .577 .707 r
F P
0 g
s
.72998 .59021 m .72405 .64481 L .75573 .64705 L p .707 .577 .707 r
F P
0 g
s
.75573 .64705 m .76165 .59245 L .72998 .59021 L p .707 .577 .707 r
F P
0 g
s
.22607 .66608 m .232 .61147 L .26367 .61371 L p .707 .577 .707 r
F P
0 g
s
.232 .61147 m .22607 .66608 L .19682 .66706 L p .707 .577 .707 r
F P
0 g
s
.76165 .59245 m .75573 .64705 L .78498 .64607 L p .707 .577 .707 r
F P
0 g
s
.78498 .64607 m .79091 .59147 L .76165 .59245 L p .707 .577 .707 r
F P
0 g
s
.26367 .61371 m .25775 .66832 L .22607 .66608 L p .707 .577 .707 r
F P
0 g
s
.69306 .63957 m .69899 .58496 L .67171 .57722 L p .707 .577 .707 r
F P
0 g
s
.69899 .58496 m .69306 .63957 L .72405 .64481 L p .707 .577 .707 r
F P
0 g
s
.19512 .70954 m .19496 .74657 L .17091 .75216 L p .707 .577 .707 r
F P
0 g
s
.31497 .71218 m .31481 .74921 L .28735 .74468 L p .707 .577 .707 r
F P
0 g
s
.28735 .74468 m .28751 .70764 L .31497 .71218 L p .707 .577 .707 r
F P
0 g
s
.60706 .25422 m .596 .75479 L .55724 .74761 L p .707 .577 .707 r
F P
0 g
s
.55724 .74761 m .56831 .24704 L .60706 .25422 L p .707 .577 .707 r
F P
0 g
s
.17931 .80699 m .17628 .78841 L .20014 .78037 L p .707 .577 .707 r
F P
0 g
s
.79091 .59147 m .78498 .64607 L .80895 .64196 L p .707 .577 .707 r
F P
0 g
s
.80895 .64196 m .81488 .58735 L .79091 .59147 L p .707 .577 .707 r
F P
0 g
s
.19496 .74657 m .19512 .70954 L .2245 .70626 L p .707 .577 .707 r
F P
0 g
s
.20014 .78037 m .20317 .79896 L .17931 .80699 L p .707 .577 .707 r
F P
0 g
s
.66578 .63183 m .67171 .57722 L .65082 .56775 L p .707 .577 .707 r
F P
0 g
s
.67171 .57722 m .66578 .63183 L .69306 .63957 L p .707 .577 .707 r
F P
0 g
s
.72284 .69126 m .723 .65422 L .69183 .65218 L p .707 .577 .707 r
F P
0 g
s
.723 .65422 m .72284 .69126 L .75468 .6906 L p .707 .577 .707 r
F P
0 g
s
.75468 .6906 m .75484 .65357 L .723 .65422 L p .707 .577 .707 r
F P
0 g
s
.42684 .74823 m .43791 .24766 L .47938 .24359 L p .707 .577 .707 r
F P
0 g
s
.43791 .24766 m .42684 .74823 L .39288 .75575 L p .707 .577 .707 r
F P
0 g
s
.31846 .76371 m .32148 .78229 L .29445 .7831 L p .707 .577 .707 r
F P
0 g
s
.29445 .7831 m .29142 .76451 L .31846 .76371 L p .707 .577 .707 r
F P
0 g
s
.75484 .65357 m .75468 .6906 L .78406 .68733 L p .707 .577 .707 r
F P
0 g
s
.78406 .68733 m .78422 .65029 L .75484 .65357 L p .707 .577 .707 r
F P
0 g
s
.28751 .70764 m .28735 .74468 L .25618 .74264 L p .707 .577 .707 r
F P
0 g
s
.25618 .74264 m .25634 .70561 L .28751 .70764 L p .707 .577 .707 r
F P
0 g
s
.69167 .68922 m .69183 .65218 L .66437 .64765 L p .707 .577 .707 r
F P
0 g
s
.69183 .65218 m .69167 .68922 L .72284 .69126 L p .707 .577 .707 r
F P
0 g
s
.2245 .70626 m .22434 .74329 L .19496 .74657 L p .707 .577 .707 r
F P
0 g
s
.22434 .74329 m .2245 .70626 L .25634 .70561 L p .707 .577 .707 r
F P
0 g
s
.25634 .70561 m .25618 .74264 L .22434 .74329 L p .707 .577 .707 r
F P
0 g
s
.56831 .24704 m .55724 .74761 L .51324 .74395 L p .707 .577 .707 r
F P
0 g
s
.51324 .74395 m .52431 .24338 L .56831 .24704 L p .707 .577 .707 r
F P
0 g
s
.78422 .65029 m .78406 .68733 L .80811 .68174 L p .707 .577 .707 r
F P
0 g
s
.80811 .68174 m .80827 .6447 L .78422 .65029 L p .707 .577 .707 r
F P
0 g
s
.20317 .79896 m .20014 .78037 L .22922 .77327 L p .707 .577 .707 r
F P
0 g
s
.72952 .73243 m .72649 .71385 L .69575 .71715 L p .707 .577 .707 r
F P
0 g
s
.72649 .71385 m .72952 .73243 L .76097 .72697 L p .707 .577 .707 r
F P
0 g
s
.76097 .72697 m .75795 .70839 L .72649 .71385 L p .707 .577 .707 r
F P
0 g
s
.81488 .58735 m .80895 .64196 L .82529 .63512 L p .707 .577 .707 r
F P
0 g
s
.82529 .63512 m .83122 .58052 L .81488 .58735 L p .707 .577 .707 r
F P
0 g
s
.75795 .70839 m .76097 .72697 L .79005 .71987 L p .707 .577 .707 r
F P
0 g
s
.79005 .71987 m .78703 .70129 L .75795 .70839 L p .707 .577 .707 r
F P
0 g
s
.66437 .64765 m .66421 .68469 L .69167 .68922 L p .707 .577 .707 r
F P
0 g
s
.65082 .56775 m .64489 .62236 L .66578 .63183 L p .707 .577 .707 r
F P
0 g
s
.22922 .77327 m .23225 .79186 L .20317 .79896 L p .707 .577 .707 r
F P
0 g
s
.69575 .71715 m .69877 .73573 L .72952 .73243 L p .707 .577 .707 r
F P
0 g
s
.46831 .74416 m .47938 .24359 L .52431 .24338 L p .707 .577 .707 r
F P
0 g
s
.47938 .24359 m .46831 .74416 L .42684 .74823 L p .707 .577 .707 r
F P
0 g
s
.29142 .76451 m .29445 .7831 L .2637 .78639 L p .707 .577 .707 r
F P
0 g
s
.2637 .78639 m .26068 .76781 L .29142 .76451 L p .707 .577 .707 r
F P
0 g
s
.66421 .68469 m .66437 .64765 L .64332 .64107 L p .707 .577 .707 r
F P
0 g
s
.69877 .73573 m .69575 .71715 L .66871 .71795 L p .707 .577 .707 r
F P
0 g
s
.52431 .24338 m .51324 .74395 L .46831 .74416 L p .707 .577 .707 r
F P
0 g
s
.23225 .79186 m .22922 .77327 L .26068 .76781 L p .707 .577 .707 r
F P
0 g
s
.66871 .71795 m .67173 .73653 L .69877 .73573 L p .707 .577 .707 r
F P
0 g
s
.26068 .76781 m .2637 .78639 L .23225 .79186 L p .707 .577 .707 r
F P
0 g
s
.78703 .70129 m .79005 .71987 L .81391 .71183 L p .707 .577 .707 r
F P
0 g
s
.81391 .71183 m .81089 .69325 L .78703 .70129 L p .707 .577 .707 r
F P
0 g
s
.64332 .64107 m .64316 .67811 L .66421 .68469 L p .707 .577 .707 r
F P
0 g
s
.80827 .6447 m .80811 .68174 L .82448 .67439 L p .707 .577 .707 r
F P
0 g
s
.82448 .67439 m .82464 .63736 L .80827 .6447 L p .707 .577 .707 r
F P
0 g
s
.63835 .55747 m .63243 .61208 L .64489 .62236 L p .707 .577 .707 r
F P
0 g
s
.67173 .73653 m .66871 .71795 L .64804 .71618 L p .707 .577 .707 r
F P
0 g
s
.83122 .58052 m .82529 .63512 L .8324 .62623 L p .707 .577 .707 r
F P
0 g
s
.8324 .62623 m .83833 .57162 L .83122 .58052 L p .707 .577 .707 r
F P
0 g
s
.64804 .71618 m .65106 .73477 L .67173 .73653 L p .707 .577 .707 r
F P
0 g
s
.64316 .67811 m .64332 .64107 L .63073 .63309 L p .707 .577 .707 r
F P
0 g
s
.81089 .69325 m .81391 .71183 L .83021 .70364 L p .707 .577 .707 r
F P
0 g
s
.83021 .70364 m .82719 .68506 L .81089 .69325 L p .707 .577 .707 r
F P
0 g
s
.63243 .61208 m .63835 .55747 L .63554 .54739 L p .707 .577 .707 r
F P
0 g
s
.63073 .63309 m .63056 .67012 L .64316 .67811 L p .707 .577 .707 r
F P
0 g
s
.82464 .63736 m .82448 .67439 L .83156 .66601 L p .707 .577 .707 r
F P
0 g
s
.83156 .66601 m .83173 .62897 L .82464 .63736 L p .707 .577 .707 r
F P
0 g
s
.65106 .73477 m .64804 .71618 L .63575 .71202 L p .707 .577 .707 r
F P
0 g
s
.63554 .54739 m .62961 .602 L .63243 .61208 L p .707 .577 .707 r
F P
0 g
s
.63575 .71202 m .63877 .7306 L .65106 .73477 L p .707 .577 .707 r
F P
0 g
s
.83833 .57162 m .8324 .62623 L .82959 .61615 L p .707 .577 .707 r
F P
0 g
s
.82959 .61615 m .83552 .56154 L .83833 .57162 L p .707 .577 .707 r
F P
0 g
s
.63056 .67012 m .63073 .63309 L .62783 .62448 L p .707 .577 .707 r
F P
0 g
s
.82719 .68506 m .83021 .70364 L .83736 .6961 L p .707 .577 .707 r
F P
0 g
s
.83736 .6961 m .83434 .67752 L .82719 .68506 L p .707 .577 .707 r
F P
0 g
s
.62961 .602 m .63554 .54739 L .64265 .5385 L p .707 .577 .707 r
F P
0 g
s
.62783 .62448 m .62767 .66152 L .63056 .67012 L p .707 .577 .707 r
F P
0 g
s
.83173 .62897 m .83156 .66601 L .82867 .6574 L p .707 .577 .707 r
F P
0 g
s
.82867 .6574 m .82883 .62036 L .83173 .62897 L p .707 .577 .707 r
F P
0 g
s
.63877 .7306 m .63575 .71202 L .63305 .70586 L p .707 .577 .707 r
F P
0 g
s
.64265 .5385 m .63672 .5931 L .62961 .602 L p .707 .577 .707 r
F P
0 g
s
.63305 .70586 m .63607 .72445 L .63877 .7306 L p .707 .577 .707 r
F P
0 g
s
.83552 .56154 m .82959 .61615 L .81713 .60587 L p .707 .577 .707 r
F P
0 g
s
.81713 .60587 m .82305 .55126 L .83552 .56154 L p .707 .577 .707 r
F P
0 g
s
.83434 .67752 m .83736 .6961 L .83466 .68995 L p .707 .577 .707 r
F P
0 g
s
.83466 .68995 m .83164 .67136 L .83434 .67752 L p .707 .577 .707 r
F P
0 g
s
.62767 .66152 m .62783 .62448 L .63491 .6161 L p .707 .577 .707 r
F P
0 g
s
.63672 .5931 m .64265 .5385 L .65899 .53166 L p .707 .577 .707 r
F P
0 g
s
.63491 .6161 m .63475 .65313 L .62767 .66152 L p .707 .577 .707 r
F P
0 g
s
.38104 .63768 m .38697 .58308 L .35598 .57783 L p .707 .577 .707 r
F P
0 g
s
.38697 .58308 m .38104 .63768 L .41272 .63992 L p .707 .577 .707 r
F P
0 g
s
.41272 .63992 m .41864 .58532 L .38697 .58308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82883 .62036 m .82867 .6574 L .81608 .64942 L p .707 .577 .707 r
F P
0 g
s
.81608 .64942 m .81624 .61238 L .82883 .62036 L p .707 .577 .707 r
F P
0 g
s
.41864 .58532 m .41272 .63992 L .44197 .63894 L p .707 .577 .707 r
F P
0 g
s
.44197 .63894 m .4479 .58434 L .41864 .58532 L p .707 .577 .707 r
F P
0 g
s
.63607 .72445 m .63305 .70586 L .6402 .69832 L p .707 .577 .707 r
F P
0 g
s
.35005 .63244 m .35598 .57783 L .3287 .57009 L p .707 .577 .707 r
F P
0 g
s
.35598 .57783 m .35005 .63244 L .38104 .63768 L p .707 .577 .707 r
F P
0 g
s
.65899 .53166 m .65306 .58626 L .63672 .5931 L p .707 .577 .707 r
F P
0 g
s
.6402 .69832 m .64322 .71691 L .63607 .72445 L p .707 .577 .707 r
F P
0 g
s
.82305 .55126 m .81713 .60587 L .79623 .59639 L p .707 .577 .707 r
F P
0 g
s
.79623 .59639 m .80216 .54179 L .82305 .55126 L p .707 .577 .707 r
F P
0 g
s
.63475 .65313 m .63491 .6161 L .65128 .60875 L p .707 .577 .707 r
F P
0 g
s
.83164 .67136 m .83466 .68995 L .82237 .68578 L p .707 .577 .707 r
F P
0 g
s
.82237 .68578 m .81935 .6672 L .83164 .67136 L p .707 .577 .707 r
F P
0 g
s
.4479 .58434 m .44197 .63894 L .46594 .63483 L p .707 .577 .707 r
F P
0 g
s
.46594 .63483 m .47187 .58022 L .4479 .58434 L p .707 .577 .707 r
F P
0 g
s
.65306 .58626 m .65899 .53166 L .68296 .52755 L p .707 .577 .707 r
F P
0 g
s
.32277 .6247 m .3287 .57009 L .30781 .56062 L p .707 .577 .707 r
F P
0 g
s
.3287 .57009 m .32277 .6247 L .35005 .63244 L p .707 .577 .707 r
F P
0 g
s
.65128 .60875 m .65112 .64579 L .63475 .65313 L p .707 .577 .707 r
F P
0 g
s
.37983 .70559 m .37999 .66856 L .34882 .66652 L p .707 .577 .707 r
F P
0 g
s
.37999 .66856 m .37983 .70559 L .41167 .70494 L p .707 .577 .707 r
F P
0 g
s
.41167 .70494 m .41183 .6679 L .37999 .66856 L p .707 .577 .707 r
F P
0 g
s
.41183 .6679 m .41167 .70494 L .44105 .70166 L p .707 .577 .707 r
F P
0 g
s
.44105 .70166 m .44121 .66462 L .41183 .6679 L p .707 .577 .707 r
F P
0 g
s
.81624 .61238 m .81608 .64942 L .79502 .64284 L p .707 .577 .707 r
F P
0 g
s
.79502 .64284 m .79518 .6058 L .81624 .61238 L p .707 .577 .707 r
F P
0 g
s
.80216 .54179 m .79623 .59639 L .76895 .58866 L p .707 .577 .707 r
F P
0 g
s
.76895 .58866 m .77488 .53405 L .80216 .54179 L p .707 .577 .707 r
F P
0 g
s
.34866 .70355 m .34882 .66652 L .32136 .66199 L p .707 .577 .707 r
F P
0 g
s
.34882 .66652 m .34866 .70355 L .37983 .70559 L p .707 .577 .707 r
F P
0 g
s
.68296 .52755 m .67704 .58215 L .65306 .58626 L p .707 .577 .707 r
F P
0 g
s
.64322 .71691 m .6402 .69832 L .6565 .69013 L p .707 .577 .707 r
F P
0 g
s
.47187 .58022 m .46594 .63483 L .48228 .62799 L p .707 .577 .707 r
F P
0 g
s
.48228 .62799 m .48821 .57339 L .47187 .58022 L p .707 .577 .707 r
F P
0 g
s
.67704 .58215 m .68296 .52755 L .71222 .52656 L p .707 .577 .707 r
F P
0 g
s
.30781 .56062 m .30188 .61523 L .32277 .6247 L p .707 .577 .707 r
F P
0 g
s
.6565 .69013 m .65952 .70872 L .64322 .71691 L p .707 .577 .707 r
F P
0 g
s
.38651 .73867 m .38348 .72009 L .35274 .72338 L p .707 .577 .707 r
F P
0 g
s
.38348 .72009 m .38651 .73867 L .41796 .73321 L p .707 .577 .707 r
F P
0 g
s
.41796 .73321 m .41494 .71462 L .38348 .72009 L p .707 .577 .707 r
F P
0 g
s
.41494 .71462 m .41796 .73321 L .44704 .72611 L p .707 .577 .707 r
F P
0 g
s
.44704 .72611 m .44402 .70752 L .41494 .71462 L p .707 .577 .707 r
F P
0 g
s
.65112 .64579 m .65128 .60875 L .67534 .60316 L p .707 .577 .707 r
F P
0 g
s
.44121 .66462 m .44105 .70166 L .4651 .69607 L p .707 .577 .707 r
F P
0 g
s
.4651 .69607 m .46526 .65904 L .44121 .66462 L p .707 .577 .707 r
F P
0 g
s
.30188 .61523 m .30781 .56062 L .29534 .55034 L p .707 .577 .707 r
F P
0 g
s
.35274 .72338 m .35576 .74197 L .38651 .73867 L p .707 .577 .707 r
F P
0 g
s
.32136 .66199 m .3212 .69902 L .34866 .70355 L p .707 .577 .707 r
F P
0 g
s
.81935 .6672 m .82237 .68578 L .8017 .68402 L p .707 .577 .707 r
F P
0 g
s
.8017 .68402 m .79867 .66543 L .81935 .6672 L p .707 .577 .707 r
F P
0 g
s
.35576 .74197 m .35274 .72338 L .3257 .72419 L p .707 .577 .707 r
F P
0 g
s
.77488 .53405 m .76895 .58866 L .73796 .58341 L p .707 .577 .707 r
F P
0 g
s
.73796 .58341 m .74389 .52881 L .77488 .53405 L p .707 .577 .707 r
F P
0 g
s
.3212 .69902 m .32136 .66199 L .30031 .65541 L p .707 .577 .707 r
F P
0 g
s
.70629 .58117 m .71222 .52656 L .74389 .52881 L p .707 .577 .707 r
F P
0 g
s
.71222 .52656 m .70629 .58117 L .67704 .58215 L p .707 .577 .707 r
F P
0 g
s
.3257 .72419 m .32872 .74277 L .35576 .74197 L p .707 .577 .707 r
F P
0 g
s
.67534 .60316 m .67517 .6402 L .65112 .64579 L p .707 .577 .707 r
F P
0 g
s
.44402 .70752 m .44704 .72611 L .4709 .71807 L p .707 .577 .707 r
F P
0 g
s
.4709 .71807 m .46788 .69949 L .44402 .70752 L p .707 .577 .707 r
F P
0 g
s
.74389 .52881 m .73796 .58341 L .70629 .58117 L p .707 .577 .707 r
F P
0 g
s
.79518 .6058 m .79502 .64284 L .76756 .63831 L p .707 .577 .707 r
F P
0 g
s
.76756 .63831 m .76772 .60127 L .79518 .6058 L p .707 .577 .707 r
F P
0 g
s
.30031 .65541 m .30015 .69244 L .3212 .69902 L p .707 .577 .707 r
F P
0 g
s
.29534 .55034 m .28942 .60495 L .30188 .61523 L p .707 .577 .707 r
F P
0 g
s
.67517 .6402 m .67534 .60316 L .70472 .59988 L p .707 .577 .707 r
F P
0 g
s
.65952 .70872 m .6565 .69013 L .68036 .68209 L p .707 .577 .707 r
F P
0 g
s
.46526 .65904 m .4651 .69607 L .48147 .68873 L p .707 .577 .707 r
F P
0 g
s
.48147 .68873 m .48163 .65169 L .46526 .65904 L p .707 .577 .707 r
F P
0 g
s
.48821 .57339 m .48228 .62799 L .48939 .6191 L p .707 .577 .707 r
F P
0 g
s
.48939 .6191 m .49532 .56449 L .48821 .57339 L p .707 .577 .707 r
F P
0 g
s
.32872 .74277 m .3257 .72419 L .30503 .72242 L p .707 .577 .707 r
F P
0 g
s
.68036 .68209 m .68338 .70068 L .65952 .70872 L p .707 .577 .707 r
F P
0 g
s
.30503 .72242 m .30805 .74101 L .32872 .74277 L p .707 .577 .707 r
F P
0 g
s
.79867 .66543 m .8017 .68402 L .77466 .68482 L p .707 .577 .707 r
F P
0 g
s
.77466 .68482 m .77164 .66623 L .79867 .66543 L p .707 .577 .707 r
F P
0 g
s
.76772 .60127 m .76756 .63831 L .73639 .63627 L p .707 .577 .707 r
F P
0 g
s
.73639 .63627 m .73655 .59923 L .76772 .60127 L p .707 .577 .707 r
F P
0 g
s
.28942 .60495 m .29534 .55034 L .29253 .54026 L p .707 .577 .707 r
F P
0 g
s
.70472 .59988 m .70455 .63692 L .67517 .6402 L p .707 .577 .707 r
F P
0 g
s
.46788 .69949 m .4709 .71807 L .4872 .70988 L p .707 .577 .707 r
F P
0 g
s
.4872 .70988 m .48418 .6913 L .46788 .69949 L p .707 .577 .707 r
F P
0 g
s
.30015 .69244 m .30031 .65541 L .28772 .64742 L p .707 .577 .707 r
F P
0 g
s
.70455 .63692 m .70472 .59988 L .73655 .59923 L p .707 .577 .707 r
F P
0 g
s
.73655 .59923 m .73639 .63627 L .70455 .63692 L p .707 .577 .707 r
F P
0 g
s
.68338 .70068 m .68036 .68209 L .70944 .675 L p .707 .577 .707 r
F P
0 g
s
.28772 .64742 m .28755 .68446 L .30015 .69244 L p .707 .577 .707 r
F P
0 g
s
.70944 .675 m .71246 .69358 L .68338 .70068 L p .707 .577 .707 r
F P
0 g
s
.77164 .66623 m .77466 .68482 L .74391 .68811 L p .707 .577 .707 r
F P
0 g
s
.74391 .68811 m .74089 .66953 L .77164 .66623 L p .707 .577 .707 r
F P
0 g
s
.29253 .54026 m .2866 .59487 L .28942 .60495 L p .707 .577 .707 r
F P
0 g
s
.48163 .65169 m .48147 .68873 L .48855 .68034 L p .707 .577 .707 r
F P
0 g
s
.48855 .68034 m .48872 .64331 L .48163 .65169 L p .707 .577 .707 r
F P
0 g
s
.30805 .74101 m .30503 .72242 L .29274 .71826 L p .707 .577 .707 r
F P
0 g
s
.71246 .69358 m .70944 .675 L .74089 .66953 L p .707 .577 .707 r
F P
0 g
s
.29274 .71826 m .29576 .73684 L .30805 .74101 L p .707 .577 .707 r
F P
0 g
s
.49532 .56449 m .48939 .6191 L .48658 .60902 L p .707 .577 .707 r
F P
0 g
s
.48658 .60902 m .49251 .55441 L .49532 .56449 L p .707 .577 .707 r
F P
0 g
s
.74089 .66953 m .74391 .68811 L .71246 .69358 L p .707 .577 .707 r
F P
0 g
s
.48418 .6913 m .4872 .70988 L .49435 .70234 L p .707 .577 .707 r
F P
0 g
s
.49435 .70234 m .49133 .68375 L .48418 .6913 L p .707 .577 .707 r
F P
0 g
s
.2866 .59487 m .29253 .54026 L .29964 .53137 L p .707 .577 .707 r
F P
0 g
s
.28755 .68446 m .28772 .64742 L .28482 .63882 L p .707 .577 .707 r
F P
0 g
s
.28482 .63882 m .28466 .67585 L .28755 .68446 L p .707 .577 .707 r
F P
0 g
s
.29576 .73684 m .29274 .71826 L .29004 .7121 L p .707 .577 .707 r
F P
0 g
s
.29964 .53137 m .29371 .58597 L .2866 .59487 L p .707 .577 .707 r
F P
0 g
s
.48872 .64331 m .48855 .68034 L .48566 .67174 L p .707 .577 .707 r
F P
0 g
s
.48566 .67174 m .48582 .6347 L .48872 .64331 L p .707 .577 .707 r
F P
0 g
s
.29004 .7121 m .29306 .73069 L .29576 .73684 L p .707 .577 .707 r
F P
0 g
s
.49251 .55441 m .48658 .60902 L .47412 .59874 L p .707 .577 .707 r
F P
0 g
s
.47412 .59874 m .48004 .54413 L .49251 .55441 L p .707 .577 .707 r
F P
0 g
s
.49133 .68375 m .49435 .70234 L .49165 .69619 L p .707 .577 .707 r
F P
0 g
s
.49165 .69619 m .48863 .6776 L .49133 .68375 L p .707 .577 .707 r
F P
0 g
s
.29371 .58597 m .29964 .53137 L .31598 .52453 L p .707 .577 .707 r
F P
0 g
s
.28466 .67585 m .28482 .63882 L .2919 .63043 L p .707 .577 .707 r
F P
0 g
s
.2919 .63043 m .29174 .66747 L .28466 .67585 L p .707 .577 .707 r
F P
0 g
s
.31598 .52453 m .31005 .57913 L .29371 .58597 L p .707 .577 .707 r
F P
0 g
s
.48582 .6347 m .48566 .67174 L .47306 .66375 L p .707 .577 .707 r
F P
0 g
s
.47306 .66375 m .47323 .62672 L .48582 .6347 L p .707 .577 .707 r
F P
0 g
s
.29306 .73069 m .29004 .7121 L .29719 .70456 L p .707 .577 .707 r
F P
0 g
s
.48004 .54413 m .47412 .59874 L .45322 .58926 L p .707 .577 .707 r
F P
0 g
s
.45322 .58926 m .45915 .53466 L .48004 .54413 L p .707 .577 .707 r
F P
0 g
s
.29719 .70456 m .30021 .72315 L .29306 .73069 L p .707 .577 .707 r
F P
0 g
s
.31005 .57913 m .31598 .52453 L .33995 .52042 L p .707 .577 .707 r
F P
0 g
s
.48863 .6776 m .49165 .69619 L .47936 .69202 L p .707 .577 .707 r
F P
0 g
s
.47936 .69202 m .47634 .67344 L .48863 .6776 L p .707 .577 .707 r
F P
0 g
s
.29174 .66747 m .2919 .63043 L .30827 .62308 L p .707 .577 .707 r
F P
0 g
s
.30827 .62308 m .30811 .66012 L .29174 .66747 L p .707 .577 .707 r
F P
0 g
s
.45915 .53466 m .45322 .58926 L .42594 .58153 L p .707 .577 .707 r
F P
0 g
s
.42594 .58153 m .43187 .52692 L .45915 .53466 L p .707 .577 .707 r
F P
0 g
s
.33995 .52042 m .33402 .57502 L .31005 .57913 L p .707 .577 .707 r
F P
0 g
s
.47323 .62672 m .47306 .66375 L .45201 .65717 L p .707 .577 .707 r
F P
0 g
s
.45201 .65717 m .45217 .62014 L .47323 .62672 L p .707 .577 .707 r
F P
0 g
s
.33402 .57502 m .33995 .52042 L .36921 .51943 L p .707 .577 .707 r
F P
0 g
s
.30021 .72315 m .29719 .70456 L .31349 .69637 L p .707 .577 .707 r
F P
0 g
s
.31349 .69637 m .31651 .71496 L .30021 .72315 L p .707 .577 .707 r
F P
0 g
s
.30811 .66012 m .30827 .62308 L .33232 .6175 L p .707 .577 .707 r
F P
0 g
s
.43187 .52692 m .42594 .58153 L .39495 .57628 L p .707 .577 .707 r
F P
0 g
s
.39495 .57628 m .40088 .52168 L .43187 .52692 L p .707 .577 .707 r
F P
0 g
s
.47634 .67344 m .47936 .69202 L .45869 .69025 L p .707 .577 .707 r
F P
0 g
s
.45869 .69025 m .45566 .67167 L .47634 .67344 L p .707 .577 .707 r
F P
0 g
s
.36328 .57404 m .36921 .51943 L .40088 .52168 L p .707 .577 .707 r
F P
0 g
s
.36921 .51943 m .36328 .57404 L .33402 .57502 L p .707 .577 .707 r
F P
0 g
s
.40088 .52168 m .39495 .57628 L .36328 .57404 L p .707 .577 .707 r
F P
0 g
s
.33232 .6175 m .33216 .65454 L .30811 .66012 L p .707 .577 .707 r
F P
0 g
s
.45217 .62014 m .45201 .65717 L .42455 .65264 L p .707 .577 .707 r
F P
0 g
s
.42455 .65264 m .42471 .61561 L .45217 .62014 L p .707 .577 .707 r
F P
0 g
s
.31651 .71496 m .31349 .69637 L .33735 .68833 L p .707 .577 .707 r
F P
0 g
s
.33216 .65454 m .33232 .6175 L .36171 .61422 L p .707 .577 .707 r
F P
0 g
s
.33735 .68833 m .34037 .70692 L .31651 .71496 L p .707 .577 .707 r
F P
0 g
s
.45566 .67167 m .45869 .69025 L .43165 .69106 L p .707 .577 .707 r
F P
0 g
s
.43165 .69106 m .42863 .67247 L .45566 .67167 L p .707 .577 .707 r
F P
0 g
s
.42471 .61561 m .42455 .65264 L .39338 .6506 L p .707 .577 .707 r
F P
0 g
s
.39338 .6506 m .39354 .61357 L .42471 .61561 L p .707 .577 .707 r
F P
0 g
s
.36171 .61422 m .36154 .65126 L .33216 .65454 L p .707 .577 .707 r
F P
0 g
s
.36154 .65126 m .36171 .61422 L .39354 .61357 L p .707 .577 .707 r
F P
0 g
s
.39354 .61357 m .39338 .6506 L .36154 .65126 L p .707 .577 .707 r
F P
0 g
s
.34037 .70692 m .33735 .68833 L .36642 .68123 L p .707 .577 .707 r
F P
0 g
s
.36642 .68123 m .36945 .69982 L .34037 .70692 L p .707 .577 .707 r
F P
0 g
s
.42863 .67247 m .43165 .69106 L .4009 .69435 L p .707 .577 .707 r
F P
0 g
s
.4009 .69435 m .39788 .67577 L .42863 .67247 L p .707 .577 .707 r
F P
0 g
s
.36945 .69982 m .36642 .68123 L .39788 .67577 L p .707 .577 .707 r
F P
0 g
s
.39788 .67577 m .4009 .69435 L .36945 .69982 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Eoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007=oo`00LWoo0`00
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000Kgoo001`
Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000
FUH00000KGoo001^Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0`00JWoo001/Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2
001XOol006]oo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Ioo`00JWoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P00I7oo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HWoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo
001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJ
EP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJEP0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0001QOol006Uoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00065oo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001ROol006Eoo`P000=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00GGoo20000eYF00<005YFFUH00UYF
2@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001IOol40003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH6000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000<Ool8001>Ool005Moo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004Ool80003FUH0
0`00FUIJEP02FUH90015Ool005Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000040003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH6000oOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000mOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00>goo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000hOol005=oo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00002000eOol005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP0000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000cOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Woo
001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0
059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002moo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00;Woo001BOol20004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00;Woo001BOol20003FUH500000eYF
001JEP04FUH80005FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool0055oo`04001JEP00FUH20006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH40005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP04001JEUYFFUHG0006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00DGoo00H005YF000005YF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<00000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000=JEPD00003
FUH005YF00AJEPL000Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF
;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20005FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
Ool40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF
00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
1EYF00@005YFFUIJEP8002moo`00DGoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YF
FUH00eYF4P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002moo`00DWoo
00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJEP03001JEUYF009J
EPP0009JEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;goo001BOol01000FUIJEP001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH60002FUH30002FUH00`00FUH0000_Ool003ioo`P000eoo`<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH40004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01@00FUH005YF
0000;goo000fOol80003FUH00`00FUIJEP02FUH70008Ool00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P000UYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP000000031oo`00
<Woo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010001Goo0P000eYF00<005YF
00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF1@00<7oo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40003Ool500000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP8000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF0080031oo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP80031o
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH70003Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000eYF1P0015YF0P001goo1`0015YF00<005YFFUH00UYF2`0000=JEP00FUH00UYF0P00<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000=JEPD0009JEP04001JEP00000<Ool@0003
FUH30003FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF00<005YFFUH015YF00<005YF
FUH00P0000=JEP000000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF20000UYF00<007oo0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF00001@0015YF00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF1@001EYF00@005YFFUIJEP800005Ool005YFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000`Ool0
02]oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00FUH20004FUH500000eYF001JEP02FUH200001Goo001JEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
031oo`00:goo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00@005YFFUIJEPT0009JEP03001JEUYF00=JEPl000EJEP04001JEUYF0002FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE00000eYF001oo`0_Ool002]oo`8000=JEPD00003
FUH005YF00AJEPL0009oo`T0009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30007FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000`Ool002Yoo`04
001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002Ool40003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHD00000eYF001JEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000
FUIJEUYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
031oo`00:Woo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000_Ool002Yoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
00000eYF001JEP02FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000_Ool002Yoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1@00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF3P000eYF00D005YFFUIJEP0002moo`00
:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00H005YF000005YF0005FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEPD000Ioo`D0009JEP8002ioo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH00UYF500000=JEP00FUH015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01UYF
00<005YFFUH03P0037oo0P000UYF1000;Woo000[Ool01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP0000000UYF00<005YFFUH01eYF
00<005YFFUH015YF1P001eYF00<005YFFUH00eYF1@0000=JEP0000000P0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH0
15YF100067oo0P0015YF00@005YFFUH002ioo`00:goo00@005YFFUH000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00MJEP03001JEUYF
00@000EJEP03001JEUYF00EJEP03001JEP0000<00003FUH0000000=JEP04001JEP000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF
00<005YFFUH0100067oo100000=JEP00FUH00eYF00<005YF0000;goo000/Ool00`00FUH00006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP05
FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP02FUH50003FUH30005FUH00`00FUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH4
00000eYF001oo`0FOol30005FUH00`00FUIJEP02FUH2000`Ool002eoo`8000EJEP03001JEUYF00EJ
EQ40009JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF01L000IJEP80009JEP03
001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00005FUH00`00FUH00004000015YF0000000057oo100000=JEP00FUH01UYF00D005YFFUIJEP00
035oo`00;Woo0P0015YF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF
00<005YFFUH00eYF100000AJEP00Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00@000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP04001JEUYFFUH30004FUH5000=Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000<Woo000`Ool600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP03FUH00`00FUH000030003FUH01@00FUH007oo00000UYF00<005YFFUH00eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00H005YF000005YF0005FUH00`00FUIJEP020004Ool9
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000dOol002moo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP80009JEP04001JEUYFFUH50004FUH20002Ool01000FUIJEP00
1EYF00<005YFFUH01P001UYF00<005YFFUH015YF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000UYF1@001UYF2@0015YF00<005YFFUH00`000eYF00<005YFFUH0
1UYF00<005YF00000`00=goo000]Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUH000020004FUH200000eYF00000003Ool00`00FUIJEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP070003FUH00`00FUIJEP06FUH00`00FUH0
00040003FUH00`00FUIJEP04FUH3000kOol002]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUHD0004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUH000040003FUH00`00FUIJEP04000nOol002Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01eYF1P0000=JEP0000000`00@Woo000YOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000040017Ool002Uoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6000;FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH7001;Ool002Uoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000180
059oo`00:Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00UYF3P002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000100000AJEP00000000=JEP8005Moo`00:Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF2@0000EJEP00Oomoo`00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00EJEP04001JEUYF0002FUH2001GOol002Uoo`03001JEP0000AJEP04001JEUYFFUH8000GOol40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo00@005YFFUH000EJEP03001JEUYF00EJEPX000]J
EP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH4001GOol002Uoo`03001JEP0000=JEPD002=oo`D000=JEP05001JEUYFFUH00002Ool01000
FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF
1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00UYF0`00Egoo
000YOol01000FUH005YF0P0015YF1@0087oo20000eYF00@007ooOol0009JEP03001JEUYF00=JEP<0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
00<000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<005Moo`00:Goo00H005YF
000005YF0005FUH01000FUIJEUYF2@004Woo1@001EYF00@005YFFUH0009JEP04001oogoo0002FUH0
1000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF00002@0000AJEP00FUH005Moo`00
:Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4P000eYF00<005YFFUH0
15YF00@005YFFUIJEP<0009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0
0003FUH00`00FUIJEP02FUH4001HOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEQ@00005FUH007ooOol00002FUH200000eYF001JEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000
FUH0000015YF00<005YF00000eYF00<005YFFUH00UYF00<005YFFUH00P00Egoo000YOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH000000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEP0000=JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002Uoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP02001FOol002Yoo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUH00000Ool00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001@000eYF00D0
05YFFUIJEP0005Ioo`00:goo00@005YFFUH000EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH00000Ool000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<000Aoo`D0009JEP03001oogoo05Aoo`00;7oo0`001EYF
00<005YF00000P0025YF00<005YFFUH01UYF00<005YFFUH00UYF4`000UYF00<007oo00001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000000Moo`80009JEP@005Eoo`00;Woo0`000eYF0P00
0UYF00<005YFFUH01eYF00<005YFFUH015YF1P001eYF00<005YFFUH015YF00<005YF00001P0000=o
o`00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Eoo`8000AJEP04001JEP00
001EOol0035oo`<000AJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00EJEP04001J
EUYFFUH700000eYF001JEP0200000goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00
FUIJEP00Ool0100000=JEP00FUH00eYF00@005YFFUH005Eoo`00;goo0P0000=JEP00FUH01EYF00<0
05YFFUH015YF1@002EYF00<005YFFUH00UYF1`000goo0P000eYF00@005YFFUH0009oo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020005FUH00`00FUIJEP02FUH3001FOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF01L000Ioo`@00003FUH005YF00=JEP8000Aoo`800003FUH0
05YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP05001JEUYFFUH0001HOol002aoo`8000AJ
EP03001JEUYF00=JEP@001Uoo`@000EJEP03001JEUYF009JEP8000Ioo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00EJEP04001JEP00001IOol002]oo`03001JEP0000AJEP03001JEP0000<0
01Uoo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH20008Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0`00Fgoo000[Ool01000FUIJEP000eYF0P005goo1P001UYF00<005YFFUH015YF
00@005YF000000aoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUH00003001NOol002]oo`05001JEUYF
001JEP02000@Ool90003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000BOol40009FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH600000eYF001JEP05FUH3001R
Ool002aoo`03001JEP0000<000Qoo`P000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
008001Uoo`@000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H0
00=JEP03001JEUYF00@006Eoo`00;7oo0P0000AJEP00FUIJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0021oo`@00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00AJEPh00003FUH0000000<006Uoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01000:7oo20001UYF00<005YFFUH015YF3@0025YF1`00
KWoo000/Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH5000dOol=0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001`Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@004Aooa<007Uoo`00;goo10000eYF
00<005YFFUH01EYF00<005YFFUH00UYF1P00e7oo000cOol@003JOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60505 .76176 m .59912 .70588 L .56813 .70737 L p .707 .577 .707 r
F P
0 g
s
.59912 .70588 m .60505 .76176 L .63672 .75793 L p .707 .577 .707 r
F P
0 g
s
.63672 .75793 m .63079 .70205 L .59912 .70588 L p .707 .577 .707 r
F P
0 g
s
.63079 .70205 m .63672 .75793 L .66597 .75213 L p .707 .577 .707 r
F P
0 g
s
.66597 .75213 m .66004 .69625 L .63079 .70205 L p .707 .577 .707 r
F P
0 g
s
.57405 .76324 m .56813 .70737 L .54085 .70636 L p .707 .577 .707 r
F P
0 g
s
.56813 .70737 m .57405 .76324 L .60505 .76176 L p .707 .577 .707 r
F P
0 g
s
.66004 .69625 m .66597 .75213 L .68994 .74492 L p .707 .577 .707 r
F P
0 g
s
.68994 .74492 m .68402 .68905 L .66004 .69625 L p .707 .577 .707 r
F P
0 g
s
.54085 .70636 m .54678 .76224 L .57405 .76324 L p .707 .577 .707 r
F P
0 g
s
.60662 .83642 m .60645 .79935 L .57528 .79759 L p .707 .577 .707 r
F P
0 g
s
.60645 .79935 m .60662 .83642 L .63845 .83552 L p .707 .577 .707 r
F P
0 g
s
.63845 .83552 m .63829 .79845 L .60645 .79935 L p .707 .577 .707 r
F P
0 g
s
.54678 .76224 m .54085 .70636 L .51996 .70296 L p .707 .577 .707 r
F P
0 g
s
.63829 .79845 m .63845 .83552 L .66783 .83204 L p .707 .577 .707 r
F P
0 g
s
.66783 .83204 m .66767 .79497 L .63829 .79845 L p .707 .577 .707 r
F P
0 g
s
.57545 .83466 m .57528 .79759 L .54783 .79333 L p .707 .577 .707 r
F P
0 g
s
.57528 .79759 m .57545 .83466 L .60662 .83642 L p .707 .577 .707 r
F P
0 g
s
.68402 .68905 m .68994 .74492 L .70628 .73702 L p .707 .577 .707 r
F P
0 g
s
.70628 .73702 m .70036 .68114 L .68402 .68905 L p .707 .577 .707 r
F P
0 g
s
.51996 .70296 m .52588 .75884 L .54678 .76224 L p .707 .577 .707 r
F P
0 g
s
.66767 .79497 m .66783 .83204 L .69189 .82633 L p .707 .577 .707 r
F P
0 g
s
.69189 .82633 m .69172 .78925 L .66767 .79497 L p .707 .577 .707 r
F P
0 g
s
.54783 .79333 m .54799 .8304 L .57545 .83466 L p .707 .577 .707 r
F P
0 g
s
.59909 .87855 m .60212 .86062 L .57137 .85361 L p .707 .577 .707 r
F P
0 g
s
.60212 .86062 m .59909 .87855 L .63055 .88238 L p .707 .577 .707 r
F P
0 g
s
.63055 .88238 m .63357 .86445 L .60212 .86062 L p .707 .577 .707 r
F P
0 g
s
.54799 .8304 m .54783 .79333 L .52677 .787 L p .707 .577 .707 r
F P
0 g
s
.63357 .86445 m .63055 .88238 L .65963 .88266 L p .707 .577 .707 r
F P
0 g
s
.65963 .88266 m .66265 .86472 L .63357 .86445 L p .707 .577 .707 r
F P
0 g
s
.56835 .87155 m .57137 .85361 L .54433 .84412 L p .707 .577 .707 r
F P
0 g
s
.57137 .85361 m .56835 .87155 L .59909 .87855 L p .707 .577 .707 r
F P
0 g
s
.52588 .75884 m .51996 .70296 L .50749 .6975 L p .707 .577 .707 r
F P
0 g
s
.54433 .84412 m .54131 .86205 L .56835 .87155 L p .707 .577 .707 r
F P
0 g
s
.52677 .787 m .52693 .82408 L .54799 .8304 L p .707 .577 .707 r
F P
0 g
s
.69172 .78925 m .69189 .82633 L .70826 .81894 L p .707 .577 .707 r
F P
0 g
s
.70826 .81894 m .70809 .78186 L .69172 .78925 L p .707 .577 .707 r
F P
0 g
s
.66265 .86472 m .65963 .88266 L .68349 .87936 L p .707 .577 .707 r
F P
0 g
s
.68349 .87936 m .68651 .86142 L .66265 .86472 L p .707 .577 .707 r
F P
0 g
s
.70036 .68114 m .70628 .73702 L .71339 .72919 L p .707 .577 .707 r
F P
0 g
s
.71339 .72919 m .70747 .67331 L .70036 .68114 L p .707 .577 .707 r
F P
0 g
s
.54131 .86205 m .54433 .84412 L .52366 .83306 L p .707 .577 .707 r
F P
0 g
s
.50749 .6975 m .51342 .75337 L .52588 .75884 L p .707 .577 .707 r
F P
0 g
s
.52366 .83306 m .52064 .85099 L .54131 .86205 L p .707 .577 .707 r
F P
0 g
s
.52693 .82408 m .52677 .787 L .51418 .77922 L p .707 .577 .707 r
F P
0 g
s
.51342 .75337 m .50749 .6975 L .50468 .69051 L p .707 .577 .707 r
F P
0 g
s
.51418 .77922 m .51434 .81629 L .52693 .82408 L p .707 .577 .707 r
F P
0 g
s
.68651 .86142 m .68349 .87936 L .69979 .8728 L p .707 .577 .707 r
F P
0 g
s
.69979 .8728 m .70281 .85486 L .68651 .86142 L p .707 .577 .707 r
F P
0 g
s
.52064 .85099 m .52366 .83306 L .51137 .82152 L p .707 .577 .707 r
F P
0 g
s
.70809 .78186 m .70826 .81894 L .71534 .81059 L p .707 .577 .707 r
F P
0 g
s
.71534 .81059 m .71518 .77352 L .70809 .78186 L p .707 .577 .707 r
F P
0 g
s
.51137 .82152 m .50835 .83945 L .52064 .85099 L p .707 .577 .707 r
F P
0 g
s
.70747 .67331 m .71339 .72919 L .71058 .7222 L p .707 .577 .707 r
F P
0 g
s
.71058 .7222 m .70465 .66633 L .70747 .67331 L p .707 .577 .707 r
F P
0 g
s
.50468 .69051 m .5106 .74639 L .51342 .75337 L p .707 .577 .707 r
F P
0 g
s
.51434 .81629 m .51418 .77922 L .51128 .77074 L p .707 .577 .707 r
F P
0 g
s
.48675 .82039 m .47568 .31745 L .43169 .31575 L p .707 .577 .707 r
F P
0 g
s
.51128 .77074 m .51144 .80781 L .51434 .81629 L p .707 .577 .707 r
F P
0 g
s
.5106 .74639 m .50468 .69051 L .51179 .68268 L p .707 .577 .707 r
F P
0 g
s
.50835 .83945 m .51137 .82152 L .50867 .81063 L p .707 .577 .707 r
F P
0 g
s
.50867 .81063 m .50565 .82856 L .50835 .83945 L p .707 .577 .707 r
F P
0 g
s
.51179 .68268 m .51772 .73856 L .5106 .74639 L p .707 .577 .707 r
F P
0 g
s
.51144 .80781 m .51128 .77074 L .51836 .7624 L p .707 .577 .707 r
F P
0 g
s
.51836 .7624 m .51853 .79947 L .51144 .80781 L p .707 .577 .707 r
F P
0 g
s
.51772 .73856 m .51179 .68268 L .52813 .67478 L p .707 .577 .707 r
F P
0 g
s
.50565 .82856 m .50867 .81063 L .51582 .80146 L p .707 .577 .707 r
F P
0 g
s
.51582 .80146 m .5128 .81939 L .50565 .82856 L p .707 .577 .707 r
F P
0 g
s
.52813 .67478 m .53406 .73066 L .51772 .73856 L p .707 .577 .707 r
F P
0 g
s
.51853 .79947 m .51836 .7624 L .53473 .75501 L p .707 .577 .707 r
F P
0 g
s
.53473 .75501 m .5349 .79208 L .51853 .79947 L p .707 .577 .707 r
F P
0 g
s
.5128 .81939 m .51582 .80146 L .53212 .7949 L p .707 .577 .707 r
F P
0 g
s
.53212 .7949 m .5291 .81283 L .5128 .81939 L p .707 .577 .707 r
F P
0 g
s
.5291 .81283 m .53212 .7949 L .55598 .79159 L p .707 .577 .707 r
F P
0 g
s
.55598 .79159 m .55296 .80953 L .5291 .81283 L p .707 .577 .707 r
F P
0 g
s
.47568 .31745 m .48675 .82039 L .53169 .81841 L p .707 .577 .707 r
F P
0 g
s
.53406 .73066 m .52813 .67478 L .5521 .66757 L p .707 .577 .707 r
F P
0 g
s
.53169 .81841 m .52062 .31546 L .47568 .31745 L p .707 .577 .707 r
F P
0 g
s
.70281 .85486 m .69979 .8728 L .70694 .86362 L p .707 .577 .707 r
F P
0 g
s
.70694 .86362 m .70996 .84569 L .70281 .85486 L p .707 .577 .707 r
F P
0 g
s
.5521 .66757 m .55803 .72345 L .53406 .73066 L p .707 .577 .707 r
F P
0 g
s
.5349 .79208 m .53473 .75501 L .55879 .7493 L p .707 .577 .707 r
F P
0 g
s
.55803 .72345 m .5521 .66757 L .58135 .66177 L p .707 .577 .707 r
F P
0 g
s
.55879 .7493 m .55895 .78637 L .5349 .79208 L p .707 .577 .707 r
F P
0 g
s
.58135 .66177 m .58728 .71765 L .55803 .72345 L p .707 .577 .707 r
F P
0 g
s
.55895 .78637 m .55879 .7493 L .58817 .74582 L p .707 .577 .707 r
F P
0 g
s
.58817 .74582 m .58833 .78289 L .55895 .78637 L p .707 .577 .707 r
F P
0 g
s
.55296 .80953 m .55598 .79159 L .58506 .79187 L p .707 .577 .707 r
F P
0 g
s
.58506 .79187 m .58204 .80981 L .55296 .80953 L p .707 .577 .707 r
F P
0 g
s
.52062 .31546 m .53169 .81841 L .57316 .81294 L p .707 .577 .707 r
F P
0 g
s
.57316 .81294 m .56209 .30999 L .52062 .31546 L p .707 .577 .707 r
F P
0 g
s
.71518 .77352 m .71534 .81059 L .71244 .80212 L p .707 .577 .707 r
F P
0 g
s
.71244 .80212 m .71228 .76504 L .71518 .77352 L p .707 .577 .707 r
F P
0 g
s
.44276 .81869 m .43169 .31575 L .39293 .31053 L p .707 .577 .707 r
F P
0 g
s
.43169 .31575 m .44276 .81869 L .48675 .82039 L p .707 .577 .707 r
F P
0 g
s
.70465 .66633 m .71058 .7222 L .69812 .71674 L p .707 .577 .707 r
F P
0 g
s
.69812 .71674 m .69219 .66087 L .70465 .66633 L p .707 .577 .707 r
F P
0 g
s
.26204 .69526 m .25611 .63938 L .22512 .64087 L p .707 .577 .707 r
F P
0 g
s
.25611 .63938 m .26204 .69526 L .29371 .69143 L p .707 .577 .707 r
F P
0 g
s
.29371 .69143 m .28778 .63555 L .25611 .63938 L p .707 .577 .707 r
F P
0 g
s
.58728 .71765 m .58135 .66177 L .61303 .65794 L p .707 .577 .707 r
F P
0 g
s
.61303 .65794 m .61895 .71382 L .58728 .71765 L p .707 .577 .707 r
F P
0 g
s
.58833 .78289 m .58817 .74582 L .62 .74491 L p .707 .577 .707 r
F P
0 g
s
.62 .74491 m .62017 .78199 L .58833 .78289 L p .707 .577 .707 r
F P
0 g
s
.58204 .80981 m .58506 .79187 L .61651 .7957 L p .707 .577 .707 r
F P
0 g
s
.61651 .7957 m .61349 .81363 L .58204 .80981 L p .707 .577 .707 r
F P
0 g
s
.56209 .30999 m .57316 .81294 L .60711 .80451 L p .707 .577 .707 r
F P
0 g
s
.60711 .80451 m .59604 .30156 L .56209 .30999 L p .707 .577 .707 r
F P
0 g
s
.28778 .63555 m .29371 .69143 L .32296 .68563 L p .707 .577 .707 r
F P
0 g
s
.32296 .68563 m .31704 .62975 L .28778 .63555 L p .707 .577 .707 r
F P
0 g
s
.23104 .69674 m .22512 .64087 L .19784 .63986 L p .707 .577 .707 r
F P
0 g
s
.22512 .64087 m .23104 .69674 L .26204 .69526 L p .707 .577 .707 r
F P
0 g
s
.70996 .84569 m .70694 .86362 L .70424 .85274 L p .707 .577 .707 r
F P
0 g
s
.70424 .85274 m .70726 .8348 L .70996 .84569 L p .707 .577 .707 r
F P
0 g
s
.404 .81348 m .39293 .31053 L .36322 .30231 L p .707 .577 .707 r
F P
0 g
s
.39293 .31053 m .404 .81348 L .44276 .81869 L p .707 .577 .707 r
F P
0 g
s
.31704 .62975 m .32296 .68563 L .34693 .67842 L p .707 .577 .707 r
F P
0 g
s
.34693 .67842 m .34101 .62254 L .31704 .62975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26361 .74845 m .26345 .71138 L .23227 .70962 L p .707 .577 .707 r
F P
0 g
s
.26345 .71138 m .26361 .74845 L .29544 .74755 L p .707 .577 .707 r
F P
0 g
s
.29544 .74755 m .29528 .71048 L .26345 .71138 L p .707 .577 .707 r
F P
0 g
s
.29528 .71048 m .29544 .74755 L .32483 .74407 L p .707 .577 .707 r
F P
0 g
s
.32483 .74407 m .32466 .707 L .29528 .71048 L p .707 .577 .707 r
F P
0 g
s
.19784 .63986 m .20377 .69574 L .23104 .69674 L p .707 .577 .707 r
F P
0 g
s
.71228 .76504 m .71244 .80212 L .69985 .79433 L p .707 .577 .707 r
F P
0 g
s
.69985 .79433 m .69969 .75726 L .71228 .76504 L p .707 .577 .707 r
F P
0 g
s
.23244 .74669 m .23227 .70962 L .20482 .70537 L p .707 .577 .707 r
F P
0 g
s
.23227 .70962 m .23244 .74669 L .26361 .74845 L p .707 .577 .707 r
F P
0 g
s
.20377 .69574 m .19784 .63986 L .17695 .63646 L p .707 .577 .707 r
F P
0 g
s
.69219 .66087 m .69812 .71674 L .67722 .71334 L p .707 .577 .707 r
F P
0 g
s
.67722 .71334 m .6713 .65746 L .69219 .66087 L p .707 .577 .707 r
F P
0 g
s
.64402 .65646 m .64995 .71233 L .61895 .71382 L p .707 .577 .707 r
F P
0 g
s
.61895 .71382 m .61303 .65794 L .64402 .65646 L p .707 .577 .707 r
F P
0 g
s
.65118 .74668 m .65134 .78375 L .62017 .78199 L p .707 .577 .707 r
F P
0 g
s
.62017 .78199 m .62 .74491 L .65118 .74668 L p .707 .577 .707 r
F P
0 g
s
.61349 .81363 m .61651 .7957 L .64726 .8027 L p .707 .577 .707 r
F P
0 g
s
.59604 .30156 m .60711 .80451 L .63022 .79395 L p .707 .577 .707 r
F P
0 g
s
.63022 .79395 m .61915 .291 L .59604 .30156 L p .707 .577 .707 r
F P
0 g
s
.32466 .707 m .32483 .74407 L .34888 .73836 L p .707 .577 .707 r
F P
0 g
s
.34888 .73836 m .34872 .70129 L .32466 .707 L p .707 .577 .707 r
F P
0 g
s
.34101 .62254 m .34693 .67842 L .36327 .67052 L p .707 .577 .707 r
F P
0 g
s
.36327 .67052 m .35735 .61464 L .34101 .62254 L p .707 .577 .707 r
F P
0 g
s
.20482 .70537 m .20498 .74244 L .23244 .74669 L p .707 .577 .707 r
F P
0 g
s
.17695 .63646 m .18287 .69233 L .20377 .69574 L p .707 .577 .707 r
F P
0 g
s
.25609 .79869 m .25911 .78075 L .22836 .77374 L p .707 .577 .707 r
F P
0 g
s
.25911 .78075 m .25609 .79869 L .28754 .80251 L p .707 .577 .707 r
F P
0 g
s
.28754 .80251 m .29056 .78458 L .25911 .78075 L p .707 .577 .707 r
F P
0 g
s
.20498 .74244 m .20482 .70537 L .18376 .69904 L p .707 .577 .707 r
F P
0 g
s
.29056 .78458 m .28754 .80251 L .31662 .80279 L p .707 .577 .707 r
F P
0 g
s
.31662 .80279 m .31964 .78485 L .29056 .78458 L p .707 .577 .707 r
F P
0 g
s
.70726 .8348 m .70424 .85274 L .69195 .8412 L p .707 .577 .707 r
F P
0 g
s
.69195 .8412 m .69497 .82326 L .70726 .8348 L p .707 .577 .707 r
F P
0 g
s
.22534 .79168 m .22836 .77374 L .20133 .76425 L p .707 .577 .707 r
F P
0 g
s
.22836 .77374 m .22534 .79168 L .25609 .79869 L p .707 .577 .707 r
F P
0 g
s
.35735 .61464 m .36327 .67052 L .37039 .66269 L p .707 .577 .707 r
F P
0 g
s
.37039 .66269 m .36446 .60681 L .35735 .61464 L p .707 .577 .707 r
F P
0 g
s
.36508 .6939 m .36525 .73097 L .37233 .72263 L p .707 .577 .707 r
F P
0 g
s
.37233 .72263 m .37217 .68556 L .36508 .6939 L p .707 .577 .707 r
F P
0 g
s
.36446 .60681 m .37039 .66269 L .36757 .6557 L p .707 .577 .707 r
F P
0 g
s
.36757 .6557 m .36164 .59983 L .36446 .60681 L p .707 .577 .707 r
F P
0 g
s
.37217 .68556 m .37233 .72263 L .36943 .71415 L p .707 .577 .707 r
F P
0 g
s
.36943 .71415 m .36927 .67708 L .37217 .68556 L p .707 .577 .707 r
F P
0 g
s
.36164 .59983 m .36757 .6557 L .35511 .65024 L p .707 .577 .707 r
F P
0 g
s
.36525 .73097 m .36508 .6939 L .34872 .70129 L p .707 .577 .707 r
F P
0 g
s
.36927 .67708 m .36943 .71415 L .35684 .70637 L p .707 .577 .707 r
F P
0 g
s
.35684 .70637 m .35668 .66929 L .36927 .67708 L p .707 .577 .707 r
F P
0 g
s
.37429 .80525 m .36322 .30231 L .34545 .29188 L p .707 .577 .707 r
F P
0 g
s
.36322 .30231 m .37429 .80525 L .404 .81348 L p .707 .577 .707 r
F P
0 g
s
.18287 .69233 m .17695 .63646 L .16448 .631 L p .707 .577 .707 r
F P
0 g
s
.20133 .76425 m .1983 .78218 L .22534 .79168 L p .707 .577 .707 r
F P
0 g
s
.69969 .75726 m .69985 .79433 L .6788 .788 L p .707 .577 .707 r
F P
0 g
s
.6788 .788 m .67863 .75093 L .69969 .75726 L p .707 .577 .707 r
F P
0 g
s
.6713 .65746 m .67722 .71334 L .64995 .71233 L p .707 .577 .707 r
F P
0 g
s
.64995 .71233 m .64402 .65646 L .6713 .65746 L p .707 .577 .707 r
F P
0 g
s
.18376 .69904 m .18392 .73611 L .20498 .74244 L p .707 .577 .707 r
F P
0 g
s
.34872 .70129 m .34888 .73836 L .36525 .73097 L p .707 .577 .707 r
F P
0 g
s
.31964 .78485 m .31662 .80279 L .34048 .79949 L p .707 .577 .707 r
F P
0 g
s
.34048 .79949 m .3435 .78155 L .31964 .78485 L p .707 .577 .707 r
F P
0 g
s
.1983 .78218 m .20133 .76425 L .18065 .75319 L p .707 .577 .707 r
F P
0 g
s
.16448 .631 m .17041 .68687 L .18287 .69233 L p .707 .577 .707 r
F P
0 g
s
.18392 .73611 m .18376 .69904 L .17117 .69125 L p .707 .577 .707 r
F P
0 g
s
.18065 .75319 m .17763 .77112 L .1983 .78218 L p .707 .577 .707 r
F P
0 g
s
.61915 .291 m .63022 .79395 L .64022 .7823 L p .707 .577 .707 r
F P
0 g
s
.64022 .7823 m .62915 .27935 L .61915 .291 L p .707 .577 .707 r
F P
0 g
s
.69497 .82326 m .69195 .8412 L .67127 .83014 L p .707 .577 .707 r
F P
0 g
s
.67127 .83014 m .6743 .8122 L .69497 .82326 L p .707 .577 .707 r
F P
0 g
s
.67863 .75093 m .6788 .788 L .65134 .78375 L p .707 .577 .707 r
F P
0 g
s
.65134 .78375 m .65118 .74668 L .67863 .75093 L p .707 .577 .707 r
F P
0 g
s
.17117 .69125 m .17133 .72833 L .18392 .73611 L p .707 .577 .707 r
F P
0 g
s
.3435 .78155 m .34048 .79949 L .35678 .79293 L p .707 .577 .707 r
F P
0 g
s
.35678 .79293 m .3598 .77499 L .3435 .78155 L p .707 .577 .707 r
F P
0 g
s
.17041 .68687 m .16448 .631 L .16167 .62401 L p .707 .577 .707 r
F P
0 g
s
.17763 .77112 m .18065 .75319 L .16836 .74165 L p .707 .577 .707 r
F P
0 g
s
.16836 .74165 m .16534 .75958 L .17763 .77112 L p .707 .577 .707 r
F P
0 g
s
.35511 .65024 m .35495 .64871 L p .36164 .59983 L .707 .577 .707 r
F P
0 g
s
.35495 .64871 m .34918 .59436 L .35477 .59681 L p .707 .577 .707 r
F P
0 g
s
.35477 .59681 m .36164 .59983 L p .35495 .64871 L .707 .577 .707 r
F P
0 g
s
.34918 .59436 m .35511 .65024 L .33421 .64684 L p .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35196 .74339 L .35826 .74931 L p .707 .577 .707 r
F P
0 g
s
.35826 .74931 m .36425 .75493 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35826 .74931 L .35871 .75725 L .707 .577 .707 r
F
.34545 .29188 m .34136 .28027 L p .35175 .63288 L F P
0 g
s
.35668 .66929 m .35684 .70637 L .33579 .70004 L p .707 .577 .707 r
F P
0 g
s
.33579 .70004 m .33562 .66296 L .35668 .66929 L p .707 .577 .707 r
F P
0 g
s
.3553 .75364 m .35333 .66115 L .35175 .63288 L .707 .577 .707 r
F
.35333 .66115 m .34545 .29188 L .35175 .63288 L F
.36425 .75493 m .36123 .77287 L .35949 .77124 L p F P
0 g
s
.35949 .77124 m .34894 .76133 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.35871 .75725 m .36425 .75493 L .35949 .77124 L .707 .577 .707 r
F
.35243 .78322 m .35652 .79483 L p .35175 .63288 L F P
0 g
s
.34136 .28027 m .34742 .5556 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.33421 .64684 m .32829 .59096 L .34918 .59436 L p .707 .577 .707 r
F P
0 g
s
.35196 .74339 m .34894 .76133 L .32826 .75027 L p .707 .577 .707 r
F P
0 g
s
.32826 .75027 m .33129 .73233 L .35196 .74339 L p .707 .577 .707 r
F P
0 g
s
.34742 .5556 m .35243 .78322 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.35652 .79483 m .35525 .73716 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.35525 .73716 m .34545 .29188 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.3598 .77499 m .35678 .79293 L .36393 .78375 L p .707 .577 .707 r
F P
0 g
s
.36393 .78375 m .36695 .76582 L .3598 .77499 L p .707 .577 .707 r
F P
0 g
s
.36695 .76582 m .36393 .78375 L .36123 .77287 L p .707 .577 .707 r
F P
0 g
s
.36123 .77287 m .36425 .75493 L .36695 .76582 L p .707 .577 .707 r
F P
0 g
s
.34545 .29188 m .35652 .79483 L .37429 .80525 L p .707 .577 .707 r
F P
0 g
s
.16167 .62401 m .1676 .67989 L .17041 .68687 L p .707 .577 .707 r
F P
0 g
s
.17133 .72833 m .17117 .69125 L .16827 .68278 L p .707 .577 .707 r
F P
0 g
s
.6743 .8122 m .67127 .83014 L .64424 .82064 L p .707 .577 .707 r
F P
0 g
s
.64424 .82064 m .64726 .8027 L .6743 .8122 L p .707 .577 .707 r
F P
0 g
s
.16827 .68278 m .16843 .71985 L .17133 .72833 L p .707 .577 .707 r
F P
0 g
s
.64726 .8027 m .64424 .82064 L .61349 .81363 L p .707 .577 .707 r
F P
0 g
s
.16534 .75958 m .16836 .74165 L .16566 .73076 L p .707 .577 .707 r
F P
0 g
s
.1676 .67989 m .16167 .62401 L .16878 .61618 L p .707 .577 .707 r
F P
0 g
s
.62915 .27935 m .64022 .7823 L .63614 .77069 L p .707 .577 .707 r
F P
0 g
s
.63614 .77069 m .62507 .26774 L .62915 .27935 L p .707 .577 .707 r
F P
0 g
s
.16566 .73076 m .16264 .7487 L .16534 .75958 L p .707 .577 .707 r
F P
0 g
s
.16878 .61618 m .17471 .67206 L .1676 .67989 L p .707 .577 .707 r
F P
0 g
s
.16843 .71985 m .16827 .68278 L .17535 .67443 L p .707 .577 .707 r
F P
0 g
s
.35243 .78322 m .34136 .28027 L .35137 .26862 L p .707 .577 .707 r
F P
0 g
s
.17535 .67443 m .17552 .7115 L .16843 .71985 L p .707 .577 .707 r
F P
0 g
s
.16264 .7487 m .16566 .73076 L .17281 .72159 L p .707 .577 .707 r
F P
0 g
s
.17471 .67206 m .16878 .61618 L .18512 .60828 L p .707 .577 .707 r
F P
0 g
s
.17281 .72159 m .16979 .73952 L .16264 .7487 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18512 .60828 m .19105 .66415 L .17471 .67206 L p .707 .577 .707 r
F P
0 g
s
.17552 .7115 m .17535 .67443 L .19172 .66704 L p .707 .577 .707 r
F P
0 g
s
.62507 .26774 m .63614 .77069 L .61837 .76026 L p .707 .577 .707 r
F P
0 g
s
.61837 .76026 m .6073 .25732 L .62507 .26774 L p .707 .577 .707 r
F P
0 g
s
.19172 .66704 m .19189 .70411 L .17552 .7115 L p .707 .577 .707 r
F P
0 g
s
.19105 .66415 m .18512 .60828 L .20909 .60107 L p .707 .577 .707 r
F P
0 g
s
.16979 .73952 m .17281 .72159 L .18911 .71503 L p .707 .577 .707 r
F P
0 g
s
.36243 .77157 m .35137 .26862 L .37447 .25806 L p .707 .577 .707 r
F P
0 g
s
.35137 .26862 m .36243 .77157 L .35243 .78322 L p .707 .577 .707 r
F P
0 g
s
.18911 .71503 m .18609 .73296 L .16979 .73952 L p .707 .577 .707 r
F P
0 g
s
.32829 .59096 m .33421 .64684 L .30694 .64583 L p .707 .577 .707 r
F P
0 g
s
.30694 .64583 m .30101 .58996 L .32829 .59096 L p .707 .577 .707 r
F P
0 g
s
.20909 .60107 m .21502 .65695 L .19105 .66415 L p .707 .577 .707 r
F P
0 g
s
.19189 .70411 m .19172 .66704 L .21578 .66133 L p .707 .577 .707 r
F P
0 g
s
.21502 .65695 m .20909 .60107 L .23834 .59527 L p .707 .577 .707 r
F P
0 g
s
.21578 .66133 m .21594 .6984 L .19189 .70411 L p .707 .577 .707 r
F P
0 g
s
.30101 .58996 m .30694 .64583 L .27594 .64732 L p .707 .577 .707 r
F P
0 g
s
.27594 .64732 m .27002 .59144 L .30101 .58996 L p .707 .577 .707 r
F P
0 g
s
.33562 .66296 m .33579 .70004 L .30833 .69578 L p .707 .577 .707 r
F P
0 g
s
.30833 .69578 m .30817 .65871 L .33562 .66296 L p .707 .577 .707 r
F P
0 g
s
.18609 .73296 m .18911 .71503 L .21297 .71173 L p .707 .577 .707 r
F P
0 g
s
.6073 .25732 m .61837 .76026 L .58865 .75204 L p .707 .577 .707 r
F P
0 g
s
.58865 .75204 m .57758 .24909 L .6073 .25732 L p .707 .577 .707 r
F P
0 g
s
.24427 .65115 m .23834 .59527 L .27002 .59144 L p .707 .577 .707 r
F P
0 g
s
.23834 .59527 m .24427 .65115 L .21502 .65695 L p .707 .577 .707 r
F P
0 g
s
.27002 .59144 m .27594 .64732 L .24427 .65115 L p .707 .577 .707 r
F P
0 g
s
.21594 .6984 m .21578 .66133 L .24516 .65785 L p .707 .577 .707 r
F P
0 g
s
.21297 .71173 m .20995 .72966 L .18609 .73296 L p .707 .577 .707 r
F P
0 g
s
.74225 .66972 m .73632 .61384 L .70533 .61533 L p .707 .577 .707 r
F P
0 g
s
.73632 .61384 m .74225 .66972 L .77392 .66589 L p .707 .577 .707 r
F P
0 g
s
.77392 .66589 m .768 .61001 L .73632 .61384 L p .707 .577 .707 r
F P
0 g
s
.30817 .65871 m .30833 .69578 L .27716 .69402 L p .707 .577 .707 r
F P
0 g
s
.27716 .69402 m .27699 .65695 L .30817 .65871 L p .707 .577 .707 r
F P
0 g
s
.768 .61001 m .77392 .66589 L .80318 .66009 L p .707 .577 .707 r
F P
0 g
s
.80318 .66009 m .79725 .60421 L .768 .61001 L p .707 .577 .707 r
F P
0 g
s
.24516 .65785 m .24532 .69492 L .21594 .6984 L p .707 .577 .707 r
F P
0 g
s
.37447 .25806 m .38554 .76101 L .36243 .77157 L p .707 .577 .707 r
F P
0 g
s
.38554 .76101 m .37447 .25806 L .40843 .24964 L p .707 .577 .707 r
F P
0 g
s
.24532 .69492 m .24516 .65785 L .27699 .65695 L p .707 .577 .707 r
F P
0 g
s
.33129 .73233 m .32826 .75027 L .30123 .74077 L p .707 .577 .707 r
F P
0 g
s
.30123 .74077 m .30425 .72283 L .33129 .73233 L p .707 .577 .707 r
F P
0 g
s
.27699 .65695 m .27716 .69402 L .24532 .69492 L p .707 .577 .707 r
F P
0 g
s
.20995 .72966 m .21297 .71173 L .24205 .712 L p .707 .577 .707 r
F P
0 g
s
.71126 .67121 m .70533 .61533 L .67805 .61432 L p .707 .577 .707 r
F P
0 g
s
.70533 .61533 m .71126 .67121 L .74225 .66972 L p .707 .577 .707 r
F P
0 g
s
.79725 .60421 m .80318 .66009 L .82715 .65288 L p .707 .577 .707 r
F P
0 g
s
.82715 .65288 m .82122 .59701 L .79725 .60421 L p .707 .577 .707 r
F P
0 g
s
.24205 .712 m .23903 .72994 L .20995 .72966 L p .707 .577 .707 r
F P
0 g
s
.30425 .72283 m .30123 .74077 L .27048 .73376 L p .707 .577 .707 r
F P
0 g
s
.27048 .73376 m .2735 .71583 L .30425 .72283 L p .707 .577 .707 r
F P
0 g
s
.57758 .24909 m .58865 .75204 L .5499 .74682 L p .707 .577 .707 r
F P
0 g
s
.5499 .74682 m .53883 .24388 L .57758 .24909 L p .707 .577 .707 r
F P
0 g
s
.23903 .72994 m .24205 .712 L .2735 .71583 L p .707 .577 .707 r
F P
0 g
s
.67805 .61432 m .68398 .6702 L .71126 .67121 L p .707 .577 .707 r
F P
0 g
s
.74382 .74438 m .74366 .70731 L .71249 .70555 L p .707 .577 .707 r
F P
0 g
s
.74366 .70731 m .74382 .74438 L .77566 .74348 L p .707 .577 .707 r
F P
0 g
s
.77566 .74348 m .77549 .70641 L .74366 .70731 L p .707 .577 .707 r
F P
0 g
s
.68398 .6702 m .67805 .61432 L .65716 .61092 L p .707 .577 .707 r
F P
0 g
s
.2735 .71583 m .27048 .73376 L .23903 .72994 L p .707 .577 .707 r
F P
0 g
s
.77549 .70641 m .77566 .74348 L .80504 .74 L p .707 .577 .707 r
F P
0 g
s
.80504 .74 m .80488 .70293 L .77549 .70641 L p .707 .577 .707 r
F P
0 g
s
.71265 .74262 m .71249 .70555 L .68503 .70129 L p .707 .577 .707 r
F P
0 g
s
.71249 .70555 m .71265 .74262 L .74382 .74438 L p .707 .577 .707 r
F P
0 g
s
.41949 .75258 m .40843 .24964 L .4499 .24416 L p .707 .577 .707 r
F P
0 g
s
.40843 .24964 m .41949 .75258 L .38554 .76101 L p .707 .577 .707 r
F P
0 g
s
.82122 .59701 m .82715 .65288 L .84349 .64498 L p .707 .577 .707 r
F P
0 g
s
.84349 .64498 m .83756 .5891 L .82122 .59701 L p .707 .577 .707 r
F P
0 g
s
.65716 .61092 m .66309 .6668 L .68398 .6702 L p .707 .577 .707 r
F P
0 g
s
.80488 .70293 m .80504 .74 L .82909 .73429 L p .707 .577 .707 r
F P
0 g
s
.82909 .73429 m .82893 .69722 L .80488 .70293 L p .707 .577 .707 r
F P
0 g
s
.68503 .70129 m .68519 .73837 L .71265 .74262 L p .707 .577 .707 r
F P
0 g
s
.7363 .78652 m .73932 .76858 L .70857 .76158 L p .707 .577 .707 r
F P
0 g
s
.73932 .76858 m .7363 .78652 L .76775 .79035 L p .707 .577 .707 r
F P
0 g
s
.76775 .79035 m .77078 .77241 L .73932 .76858 L p .707 .577 .707 r
F P
0 g
s
.53883 .24388 m .5499 .74682 L .5059 .74512 L p .707 .577 .707 r
F P
0 g
s
.5059 .74512 m .49483 .24218 L .53883 .24388 L p .707 .577 .707 r
F P
0 g
s
.68519 .73837 m .68503 .70129 L .66397 .69497 L p .707 .577 .707 r
F P
0 g
s
.77078 .77241 m .76775 .79035 L .79683 .79062 L p .707 .577 .707 r
F P
0 g
s
.79683 .79062 m .79986 .77269 L .77078 .77241 L p .707 .577 .707 r
F P
0 g
s
.70555 .77951 m .70857 .76158 L .68154 .75208 L p .707 .577 .707 r
F P
0 g
s
.70857 .76158 m .70555 .77951 L .7363 .78652 L p .707 .577 .707 r
F P
0 g
s
.66309 .6668 m .65716 .61092 L .6447 .60546 L p .707 .577 .707 r
F P
0 g
s
.4499 .24416 m .46097 .74711 L .41949 .75258 L p .707 .577 .707 r
F P
0 g
s
.42499 .54351 m .43091 .59939 L .43863 .59786 L p .707 .577 .707 r
F P
0 g
s
.45967 .68809 m .4499 .24416 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.43863 .59786 m .46017 .59359 L p .42644 .54558 L .707 .577 .707 r
F P
0 g
s
.42644 .54558 m .42499 .54351 L .43863 .59786 L .707 .577 .707 r
F
.4499 .24416 m .49483 .24218 L p .46375 .7056 L F P
0 g
s
.46097 .74711 m .45967 .68809 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.49483 .24218 m .5059 .74512 L .46097 .74711 L p .707 .577 .707 r
F P
0 g
s
.68154 .75208 m .67851 .77001 L .70555 .77951 L p .707 .577 .707 r
F P
0 g
s
.66397 .69497 m .66414 .73204 L .68519 .73837 L p .707 .577 .707 r
F P
0 g
s
.82893 .69722 m .82909 .73429 L .84546 .7269 L p .707 .577 .707 r
F P
0 g
s
.84546 .7269 m .8453 .68983 L .82893 .69722 L p .707 .577 .707 r
F P
0 g
s
.79986 .77269 m .79683 .79062 L .82069 .78732 L p .707 .577 .707 r
F P
0 g
s
.82069 .78732 m .82371 .76938 L .79986 .77269 L p .707 .577 .707 r
F P
0 g
s
.83756 .5891 m .84349 .64498 L .8506 .63715 L p .707 .577 .707 r
F P
0 g
s
.8506 .63715 m .84467 .58127 L .83756 .5891 L p .707 .577 .707 r
F P
0 g
s
.67851 .77001 m .68154 .75208 L .66087 .74102 L p .707 .577 .707 r
F P
0 g
s
.6447 .60546 m .65062 .66134 L .66309 .6668 L p .707 .577 .707 r
F P
0 g
s
.66087 .74102 m .65784 .75895 L .67851 .77001 L p .707 .577 .707 r
F P
0 g
s
.66414 .73204 m .66397 .69497 L .65138 .68718 L p .707 .577 .707 r
F P
0 g
s
.65062 .66134 m .6447 .60546 L .64188 .59847 L p .707 .577 .707 r
F P
0 g
s
.65138 .68718 m .65154 .72425 L .66414 .73204 L p .707 .577 .707 r
F P
0 g
s
.82371 .76938 m .82069 .78732 L .83699 .78076 L p .707 .577 .707 r
F P
0 g
s
.83699 .78076 m .84002 .76282 L .82371 .76938 L p .707 .577 .707 r
F P
0 g
s
.65784 .75895 m .66087 .74102 L .64858 .72948 L p .707 .577 .707 r
F P
0 g
s
.8453 .68983 m .84546 .7269 L .85254 .71856 L p .707 .577 .707 r
F P
0 g
s
.85254 .71856 m .85238 .68148 L .8453 .68983 L p .707 .577 .707 r
F P
0 g
s
.64858 .72948 m .64555 .74742 L .65784 .75895 L p .707 .577 .707 r
F P
0 g
s
.84467 .58127 m .8506 .63715 L .84779 .63017 L p .707 .577 .707 r
F P
0 g
s
.84779 .63017 m .84186 .57429 L .84467 .58127 L p .707 .577 .707 r
F P
0 g
s
.64188 .59847 m .64781 .65435 L .65062 .66134 L p .707 .577 .707 r
F P
0 g
s
.65154 .72425 m .65138 .68718 L .64849 .6787 L p .707 .577 .707 r
F P
0 g
s
.84002 .76282 m .83699 .78076 L .84414 .77159 L p .707 .577 .707 r
F P
0 g
s
.84414 .77159 m .84717 .75365 L .84002 .76282 L p .707 .577 .707 r
F P
0 g
s
.64849 .6787 m .64865 .71577 L .65154 .72425 L p .707 .577 .707 r
F P
0 g
s
.64781 .65435 m .64188 .59847 L .64899 .59064 L p .707 .577 .707 r
F P
0 g
s
.64555 .74742 m .64858 .72948 L .64587 .71859 L p .707 .577 .707 r
F P
0 g
s
.85238 .68148 m .85254 .71856 L .84965 .71008 L p .707 .577 .707 r
F P
0 g
s
.84965 .71008 m .84949 .67301 L .85238 .68148 L p .707 .577 .707 r
F P
0 g
s
.64587 .71859 m .64285 .73653 L .64555 .74742 L p .707 .577 .707 r
F P
0 g
s
.84186 .57429 m .84779 .63017 L .83532 .6247 L p .707 .577 .707 r
F P
0 g
s
.83532 .6247 m .8294 .56883 L .84186 .57429 L p .707 .577 .707 r
F P
0 g
s
.64899 .59064 m .65492 .64652 L .64781 .65435 L p .707 .577 .707 r
F P
0 g
s
.39924 .60322 m .39331 .54734 L .36232 .54883 L p .707 .577 .707 r
F P
0 g
s
.39331 .54734 m .39924 .60322 L .43091 .59939 L p .707 .577 .707 r
F P
0 g
s
.43091 .59939 m .42499 .54351 L .39331 .54734 L p .707 .577 .707 r
F P
0 g
s
.46017 .59359 m .45424 .53771 L .42499 .54351 L p .707 .577 .707 r
F P
0 g
s
.64865 .71577 m .64849 .6787 L .65557 .67036 L p .707 .577 .707 r
F P
0 g
s
.36825 .6047 m .36232 .54883 L .33504 .54782 L p .707 .577 .707 r
F P
0 g
s
.36232 .54883 m .36825 .6047 L .39924 .60322 L p .707 .577 .707 r
F P
0 g
s
.84717 .75365 m .84414 .77159 L .84144 .7607 L p .707 .577 .707 r
F P
0 g
s
.84144 .7607 m .84446 .74276 L .84717 .75365 L p .707 .577 .707 r
F P
0 g
s
.45424 .53771 m .46017 .59359 L .48414 .58638 L p .707 .577 .707 r
F P
0 g
s
.48414 .58638 m .47821 .53051 L .45424 .53771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65557 .67036 m .65573 .70743 L .64865 .71577 L p .707 .577 .707 r
F P
0 g
s
.65492 .64652 m .64899 .59064 L .66533 .58274 L p .707 .577 .707 r
F P
0 g
s
.64285 .73653 m .64587 .71859 L .65302 .70942 L p .707 .577 .707 r
F P
0 g
s
.40081 .65642 m .40065 .61934 L .36948 .61758 L p .707 .577 .707 r
F P
0 g
s
.40065 .61934 m .40081 .65642 L .43265 .65551 L p .707 .577 .707 r
F P
0 g
s
.43265 .65551 m .43248 .61844 L .40065 .61934 L p .707 .577 .707 r
F P
0 g
s
.43248 .61844 m .43265 .65551 L .46203 .65204 L p .707 .577 .707 r
F P
0 g
s
.46203 .65204 m .46187 .61496 L .43248 .61844 L p .707 .577 .707 r
F P
0 g
s
.33504 .54782 m .34097 .6037 L .36825 .6047 L p .707 .577 .707 r
F P
0 g
s
.84949 .67301 m .84965 .71008 L .83706 .70229 L p .707 .577 .707 r
F P
0 g
s
.83706 .70229 m .83689 .66522 L .84949 .67301 L p .707 .577 .707 r
F P
0 g
s
.65302 .70942 m .65 .72735 L .64285 .73653 L p .707 .577 .707 r
F P
0 g
s
.36964 .65465 m .36948 .61758 L .34202 .61333 L p .707 .577 .707 r
F P
0 g
s
.36948 .61758 m .36964 .65465 L .40081 .65642 L p .707 .577 .707 r
F P
0 g
s
.34097 .6037 m .33504 .54782 L .31415 .54442 L p .707 .577 .707 r
F P
0 g
s
.8294 .56883 m .83532 .6247 L .81443 .6213 L p .707 .577 .707 r
F P
0 g
s
.81443 .6213 m .8085 .56543 L .8294 .56883 L p .707 .577 .707 r
F P
0 g
s
.66533 .58274 m .67126 .63862 L .65492 .64652 L p .707 .577 .707 r
F P
0 g
s
.46187 .61496 m .46203 .65204 L .48608 .64632 L p .707 .577 .707 r
F P
0 g
s
.48608 .64632 m .48592 .60925 L .46187 .61496 L p .707 .577 .707 r
F P
0 g
s
.47821 .53051 m .48414 .58638 L .50048 .57848 L p .707 .577 .707 r
F P
0 g
s
.50048 .57848 m .49455 .5226 L .47821 .53051 L p .707 .577 .707 r
F P
0 g
s
.65573 .70743 m .65557 .67036 L .67194 .66297 L p .707 .577 .707 r
F P
0 g
s
.34202 .61333 m .34218 .6504 L .36964 .65465 L p .707 .577 .707 r
F P
0 g
s
.31415 .54442 m .32008 .6003 L .34097 .6037 L p .707 .577 .707 r
F P
0 g
s
.39329 .70665 m .39631 .68871 L .36556 .68171 L p .707 .577 .707 r
F P
0 g
s
.39631 .68871 m .39329 .70665 L .42474 .71048 L p .707 .577 .707 r
F P
0 g
s
.42474 .71048 m .42777 .69254 L .39631 .68871 L p .707 .577 .707 r
F P
0 g
s
.34218 .6504 m .34202 .61333 L .32096 .607 L p .707 .577 .707 r
F P
0 g
s
.67126 .63862 m .66533 .58274 L .6893 .57553 L p .707 .577 .707 r
F P
0 g
s
.42777 .69254 m .42474 .71048 L .45382 .71075 L p .707 .577 .707 r
F P
0 g
s
.45382 .71075 m .45685 .69282 L .42777 .69254 L p .707 .577 .707 r
F P
0 g
s
.84446 .74276 m .84144 .7607 L .82915 .74916 L p .707 .577 .707 r
F P
0 g
s
.82915 .74916 m .83218 .73122 L .84446 .74276 L p .707 .577 .707 r
F P
0 g
s
.36254 .69964 m .36556 .68171 L .33853 .67221 L p .707 .577 .707 r
F P
0 g
s
.36556 .68171 m .36254 .69964 L .39329 .70665 L p .707 .577 .707 r
F P
0 g
s
.67194 .66297 m .6721 .70004 L .65573 .70743 L p .707 .577 .707 r
F P
0 g
s
.65 .72735 m .65302 .70942 L .66933 .70286 L p .707 .577 .707 r
F P
0 g
s
.32008 .6003 m .31415 .54442 L .30169 .53896 L p .707 .577 .707 r
F P
0 g
s
.33853 .67221 m .3355 .69014 L .36254 .69964 L p .707 .577 .707 r
F P
0 g
s
.83689 .66522 m .83706 .70229 L .816 .69596 L p .707 .577 .707 r
F P
0 g
s
.816 .69596 m .81584 .65889 L .83689 .66522 L p .707 .577 .707 r
F P
0 g
s
.8085 .56543 m .81443 .6213 L .78715 .6203 L p .707 .577 .707 r
F P
0 g
s
.78715 .6203 m .78122 .56442 L .8085 .56543 L p .707 .577 .707 r
F P
0 g
s
.32096 .607 m .32113 .64407 L .34218 .6504 L p .707 .577 .707 r
F P
0 g
s
.48592 .60925 m .48608 .64632 L .50245 .63893 L p .707 .577 .707 r
F P
0 g
s
.50245 .63893 m .50229 .60186 L .48592 .60925 L p .707 .577 .707 r
F P
0 g
s
.66933 .70286 m .6663 .72079 L .65 .72735 L p .707 .577 .707 r
F P
0 g
s
.6893 .57553 m .69523 .63141 L .67126 .63862 L p .707 .577 .707 r
F P
0 g
s
.45685 .69282 m .45382 .71075 L .47768 .70745 L p .707 .577 .707 r
F P
0 g
s
.47768 .70745 m .4807 .68951 L .45685 .69282 L p .707 .577 .707 r
F P
0 g
s
.3355 .69014 m .33853 .67221 L .31785 .66115 L p .707 .577 .707 r
F P
0 g
s
.49455 .5226 m .50048 .57848 L .50759 .57065 L p .707 .577 .707 r
F P
0 g
s
.50759 .57065 m .50166 .51477 L .49455 .5226 L p .707 .577 .707 r
F P
0 g
s
.6721 .70004 m .67194 .66297 L .69599 .65726 L p .707 .577 .707 r
F P
0 g
s
.69523 .63141 m .6893 .57553 L .71856 .56973 L p .707 .577 .707 r
F P
0 g
s
.30169 .53896 m .30761 .59483 L .32008 .6003 L p .707 .577 .707 r
F P
0 g
s
.32113 .64407 m .32096 .607 L .30837 .59921 L p .707 .577 .707 r
F P
0 g
s
.31785 .66115 m .31483 .67908 L .3355 .69014 L p .707 .577 .707 r
F P
0 g
s
.78122 .56442 m .78715 .6203 L .75616 .62178 L p .707 .577 .707 r
F P
0 g
s
.75616 .62178 m .75023 .5659 L .78122 .56442 L p .707 .577 .707 r
F P
0 g
s
.83218 .73122 m .82915 .74916 L .80848 .7381 L p .707 .577 .707 r
F P
0 g
s
.80848 .7381 m .8115 .72016 L .83218 .73122 L p .707 .577 .707 r
F P
0 g
s
.69599 .65726 m .69615 .69433 L .6721 .70004 L p .707 .577 .707 r
F P
0 g
s
.72449 .62561 m .71856 .56973 L .75023 .5659 L p .707 .577 .707 r
F P
0 g
s
.71856 .56973 m .72449 .62561 L .69523 .63141 L p .707 .577 .707 r
F P
0 g
s
.6663 .72079 m .66933 .70286 L .69318 .69956 L p .707 .577 .707 r
F P
0 g
s
.81584 .65889 m .816 .69596 L .78854 .69171 L p .707 .577 .707 r
F P
0 g
s
.78854 .69171 m .78838 .65464 L .81584 .65889 L p .707 .577 .707 r
F P
0 g
s
.30837 .59921 m .30853 .63629 L .32113 .64407 L p .707 .577 .707 r
F P
0 g
s
.75023 .5659 m .75616 .62178 L .72449 .62561 L p .707 .577 .707 r
F P
0 g
s
.4807 .68951 m .47768 .70745 L .49398 .70089 L p .707 .577 .707 r
F P
0 g
s
.49398 .70089 m .49701 .68295 L .4807 .68951 L p .707 .577 .707 r
F P
0 g
s
.30761 .59483 m .30169 .53896 L .29887 .53197 L p .707 .577 .707 r
F P
0 g
s
.50229 .60186 m .50245 .63893 L .50953 .63059 L p .707 .577 .707 r
F P
0 g
s
.50953 .63059 m .50937 .59352 L .50229 .60186 L p .707 .577 .707 r
F P
0 g
s
.69318 .69956 m .69016 .71749 L .6663 .72079 L p .707 .577 .707 r
F P
0 g
s
.31483 .67908 m .31785 .66115 L .30557 .64961 L p .707 .577 .707 r
F P
0 g
s
.69615 .69433 m .69599 .65726 L .72537 .65378 L p .707 .577 .707 r
F P
0 g
s
.30557 .64961 m .30254 .66755 L .31483 .67908 L p .707 .577 .707 r
F P
0 g
s
.78838 .65464 m .78854 .69171 L .75737 .68995 L p .707 .577 .707 r
F P
0 g
s
.75737 .68995 m .75721 .65288 L .78838 .65464 L p .707 .577 .707 r
F P
0 g
s
.50166 .51477 m .50759 .57065 L .50478 .56366 L p .707 .577 .707 r
F P
0 g
s
.50478 .56366 m .49885 .50779 L .50166 .51477 L p .707 .577 .707 r
F P
0 g
s
.29887 .53197 m .3048 .58785 L .30761 .59483 L p .707 .577 .707 r
F P
0 g
s
.72537 .65378 m .72554 .69085 L .69615 .69433 L p .707 .577 .707 r
F P
0 g
s
.30853 .63629 m .30837 .59921 L .30547 .59074 L p .707 .577 .707 r
F P
0 g
s
.8115 .72016 m .80848 .7381 L .78144 .7286 L p .707 .577 .707 r
F P
0 g
s
.78144 .7286 m .78447 .71067 L .8115 .72016 L p .707 .577 .707 r
F P
0 g
s
.72554 .69085 m .72537 .65378 L .75721 .65288 L p .707 .577 .707 r
F P
0 g
s
.69016 .71749 m .69318 .69956 L .72226 .69983 L p .707 .577 .707 r
F P
0 g
s
.75721 .65288 m .75737 .68995 L .72554 .69085 L p .707 .577 .707 r
F P
0 g
s
.72226 .69983 m .71924 .71777 L .69016 .71749 L p .707 .577 .707 r
F P
0 g
s
.30547 .59074 m .30564 .62781 L .30853 .63629 L p .707 .577 .707 r
F P
0 g
s
.49701 .68295 m .49398 .70089 L .50113 .69172 L p .707 .577 .707 r
F P
0 g
s
.50113 .69172 m .50416 .67378 L .49701 .68295 L p .707 .577 .707 r
F P
0 g
s
.78447 .71067 m .78144 .7286 L .75069 .7216 L p .707 .577 .707 r
F P
0 g
s
.75069 .7216 m .75372 .70366 L .78447 .71067 L p .707 .577 .707 r
F P
0 g
s
.30254 .66755 m .30557 .64961 L .30286 .63872 L p .707 .577 .707 r
F P
0 g
s
.71924 .71777 m .72226 .69983 L .75372 .70366 L p .707 .577 .707 r
F P
0 g
s
.3048 .58785 m .29887 .53197 L .30598 .52414 L p .707 .577 .707 r
F P
0 g
s
.50937 .59352 m .50953 .63059 L .50664 .62211 L p .707 .577 .707 r
F P
0 g
s
.50664 .62211 m .50648 .58504 L .50937 .59352 L p .707 .577 .707 r
F P
0 g
s
.75372 .70366 m .75069 .7216 L .71924 .71777 L p .707 .577 .707 r
F P
0 g
s
.30286 .63872 m .29984 .65666 L .30254 .66755 L p .707 .577 .707 r
F P
0 g
s
.49885 .50779 m .50478 .56366 L .49231 .5582 L p .707 .577 .707 r
F P
0 g
s
.49231 .5582 m .48638 .50233 L .49885 .50779 L p .707 .577 .707 r
F P
0 g
s
.30598 .52414 m .31191 .58002 L .3048 .58785 L p .707 .577 .707 r
F P
0 g
s
.30564 .62781 m .30547 .59074 L .31256 .58239 L p .707 .577 .707 r
F P
0 g
s
.31256 .58239 m .31272 .61947 L .30564 .62781 L p .707 .577 .707 r
F P
0 g
s
.50416 .67378 m .50113 .69172 L .49843 .68083 L p .707 .577 .707 r
F P
0 g
s
.49843 .68083 m .50145 .66289 L .50416 .67378 L p .707 .577 .707 r
F P
0 g
s
.29984 .65666 m .30286 .63872 L .31001 .62955 L p .707 .577 .707 r
F P
0 g
s
.31191 .58002 m .30598 .52414 L .32232 .51624 L p .707 .577 .707 r
F P
0 g
s
.50648 .58504 m .50664 .62211 L .49405 .61433 L p .707 .577 .707 r
F P
0 g
s
.49405 .61433 m .49388 .57725 L .50648 .58504 L p .707 .577 .707 r
F P
0 g
s
.31001 .62955 m .30699 .64748 L .29984 .65666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48638 .50233 m .49231 .5582 L .47142 .5548 L p .707 .577 .707 r
F P
0 g
s
.47142 .5548 m .46549 .49892 L .48638 .50233 L p .707 .577 .707 r
F P
0 g
s
.32232 .51624 m .32825 .57212 L .31191 .58002 L p .707 .577 .707 r
F P
0 g
s
.31272 .61947 m .31256 .58239 L .32893 .575 L p .707 .577 .707 r
F P
0 g
s
.32893 .575 m .32909 .61208 L .31272 .61947 L p .707 .577 .707 r
F P
0 g
s
.50145 .66289 m .49843 .68083 L .48614 .66929 L p .707 .577 .707 r
F P
0 g
s
.48614 .66929 m .48916 .65135 L .50145 .66289 L p .707 .577 .707 r
F P
0 g
s
.32825 .57212 m .32232 .51624 L .34629 .50903 L p .707 .577 .707 r
F P
0 g
s
.30699 .64748 m .31001 .62955 L .32632 .62299 L p .707 .577 .707 r
F P
0 g
s
.49388 .57725 m .49405 .61433 L .47299 .608 L p .707 .577 .707 r
F P
0 g
s
.47299 .608 m .47283 .57093 L .49388 .57725 L p .707 .577 .707 r
F P
0 g
s
.32632 .62299 m .32329 .64092 L .30699 .64748 L p .707 .577 .707 r
F P
0 g
s
.46549 .49892 m .47142 .5548 L .44414 .55379 L p .707 .577 .707 r
F P
0 g
s
.44414 .55379 m .43821 .49792 L .46549 .49892 L p .707 .577 .707 r
F P
0 g
s
.34629 .50903 m .35222 .56491 L .32825 .57212 L p .707 .577 .707 r
F P
0 g
s
.32909 .61208 m .32893 .575 L .35298 .56929 L p .707 .577 .707 r
F P
0 g
s
.35222 .56491 m .34629 .50903 L .37555 .50323 L p .707 .577 .707 r
F P
0 g
s
.35298 .56929 m .35314 .60636 L .32909 .61208 L p .707 .577 .707 r
F P
0 g
s
.48916 .65135 m .48614 .66929 L .46547 .65823 L p .707 .577 .707 r
F P
0 g
s
.46547 .65823 m .46849 .64029 L .48916 .65135 L p .707 .577 .707 r
F P
0 g
s
.43821 .49792 m .44414 .55379 L .41315 .55528 L p .707 .577 .707 r
F P
0 g
s
.41315 .55528 m .40722 .4994 L .43821 .49792 L p .707 .577 .707 r
F P
0 g
s
.47283 .57093 m .47299 .608 L .44553 .60374 L p .707 .577 .707 r
F P
0 g
s
.44553 .60374 m .44537 .56667 L .47283 .57093 L p .707 .577 .707 r
F P
0 g
s
.32329 .64092 m .32632 .62299 L .35017 .61969 L p .707 .577 .707 r
F P
0 g
s
.38147 .55911 m .37555 .50323 L .40722 .4994 L p .707 .577 .707 r
F P
0 g
s
.37555 .50323 m .38147 .55911 L .35222 .56491 L p .707 .577 .707 r
F P
0 g
s
.40722 .4994 m .41315 .55528 L .38147 .55911 L p .707 .577 .707 r
F P
0 g
s
.35314 .60636 m .35298 .56929 L .38236 .56581 L p .707 .577 .707 r
F P
0 g
s
.35017 .61969 m .34715 .63762 L .32329 .64092 L p .707 .577 .707 r
F P
0 g
s
.44537 .56667 m .44553 .60374 L .41436 .60198 L p .707 .577 .707 r
F P
0 g
s
.41436 .60198 m .4142 .56491 L .44537 .56667 L p .707 .577 .707 r
F P
0 g
s
.38236 .56581 m .38252 .60288 L .35314 .60636 L p .707 .577 .707 r
F P
0 g
s
.38252 .60288 m .38236 .56581 L .4142 .56491 L p .707 .577 .707 r
F P
0 g
s
.46849 .64029 m .46547 .65823 L .43843 .64873 L p .707 .577 .707 r
F P
0 g
s
.43843 .64873 m .44146 .6308 L .46849 .64029 L p .707 .577 .707 r
F P
0 g
s
.4142 .56491 m .41436 .60198 L .38252 .60288 L p .707 .577 .707 r
F P
0 g
s
.34715 .63762 m .35017 .61969 L .37925 .61996 L p .707 .577 .707 r
F P
0 g
s
.37925 .61996 m .37623 .6379 L .34715 .63762 L p .707 .577 .707 r
F P
0 g
s
.44146 .6308 m .43843 .64873 L .40768 .64173 L p .707 .577 .707 r
F P
0 g
s
.40768 .64173 m .41071 .62379 L .44146 .6308 L p .707 .577 .707 r
F P
0 g
s
.37623 .6379 m .37925 .61996 L .41071 .62379 L p .707 .577 .707 r
F P
0 g
s
.41071 .62379 m .40768 .64173 L .37623 .6379 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Ioo`d008Yo
o`00OGoo2@001UYF00<005YFFUH015YF3000OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001gOol0079oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEP00001eOol006eoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001bOol006Uoo`@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP80071oo`00Igoo
0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`00KWoo001UOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001/Ool0
06=oo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Uoo`00HWoo0P001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001ROol20006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001ZOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yo
o`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00=oo`00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00
HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP0EFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVYoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF
JWoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH05EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIZOol0065oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1XOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0E
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1X
Ool0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00
HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0?0007
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069o
o`04001JEUYF0005FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001ROol01@00
FUIJEP00FUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001QOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol005eoo`@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005]oo`8000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005Uoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF000=FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JGoo001G
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP003EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001FOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001EOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001DOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Aoo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo
001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUHF0002FUH0
1@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001E
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPL0
00UJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF
00=JEQL000MJEP03001JEUYF00AJEP03001JEUYF009JEP@000YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8001iooaD003Eoo`00EGoo00@005YFFUH000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001JEUYF00=JEP<000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@0035oo`00EGoo00@005YFFUH000=JEPL00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000COol70006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000_Ool005Eoo`05001JEUYF001JEP050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000=Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`9JEP@00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yoo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005Ioo`04FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20007Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001FOol00eYF00000004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P001Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001AOol80004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0018Ool90004FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0041oo`P000AJEP03001JEUYF00IJ
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=Woo100000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000Aoo`00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=7oo0P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF000015YF00<005YFFUH00eYF
1P000eYF00<005YFFUH01eYF00<005YFFUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005Ool005YFFUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo000bOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH400000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200001Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0002aoo`00<7oo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`0000=JEP0000000`0000=JEP00FUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF20000eYF0`000eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000Eoo`00FUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;goo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF001JEP8000EJEP04001JEUYFFUH80009FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool002ioo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0015YF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQP000=JEP03001JEUYF008002]oo`00;Goo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF1@000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH2000[Ool0
02eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP80009JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002]oo`00;Goo00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool0
0`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0003FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJEUYF4000
15YF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20003FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70006FUH00`00
FUIJEP05FUH20004FUH00`00FUH00002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP8002aoo`00;Woo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@0000=JEP00
00000`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1UYF0`0000AJEP000000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=oo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP05001JEUYFFUH0000]Ool002ioo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT0009JEP06001JEP00001JEP000eYF1@001UYF
00<005YFFUH01EYF00<005YFFUH01UYF10001eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
000^Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPP000QJEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003Ool015YF001JEP001EYF00<005YFFUH01EYF4`0025YF00<0
05YFFUH00eYF0`00<7oo000^Ool00`00FUH00005FUH00`00FUIJEP03FUH60007FUH:0002FUH20000
15YF001JEP001UYF00<005YF00000UYF6@0000IJEP00000005YF0006FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP02FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000eYF00000002000cOol002ioo`03001J
EP0000EJEP03001JEP0000<000AJEP03001JEP0000L000AJEP03001JEUYF009JEP@0009JEP<000EJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP<000IJEP04001J
EP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH01000
FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Ao
o`00;Woo00@005YFFUH000AJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH800001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP<0009JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000aOol002ioo`04001JEUYF0002FUH60003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P0000=JEP00FUH0
0UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;goo000_Ool2FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF0`000eYF00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP80009JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<002eoo`00;goo0UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF
0`0000EJEP00FUIJEP0000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP05001J
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH0
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000_Ool00eYF00000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUH000040005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002]oo`00;goo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001UYF00<005YFFUH00eYF10000eYF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP80009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000ZOol002mo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00T000AJEP03001JEUYF00QJEP03001J
EUYF00MJEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00:Woo000_Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP06FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2000015YF0000
000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000ZOol002moo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03001JEUYF00AJ
EPD0009JEPP000EJEP03001JEUYF00D000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF
00<005YFFUH00eYF00@005YFFUIJEP8002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF00<005YF00000`000UYF00<005YFFUH01EYF0`001eYF00@005YFFUIJEPP0
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF009JEPH001Yoo`D000AJEP04001JEUYFFUH2
000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPX001=oo`@0009JEP06001JEUYFFUH005YF
10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF0000
15YF00<005YF000020007Woo100000=JEP00FUH00UYF0P00:Woo000_Ool00`00FUH00004FUH00`00
FUH00003000QOol500001EYF001JEUYF00000UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP00009JEPD000=JEP04001JEUYFFUH9000?Ool70003
FUH30003FUH2000ZOol002moo`03001JEP0000=JEP<00003FUH0000000<0021oo`H0009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF0000000ZOol002moo`04001JEP00FUH20005FUH01000FUIJEUYF20004Woo1P001EYF00@0
05YFFUH000IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000ZOol002moo`06001JEP00001JEP0015YF7`0015YF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEUYF00IJEPl000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002Yoo`00;goo0P000eYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF009J
EP03001JEP0002Yoo`00;goo0P000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEQD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF
009JEP03001JEP0002Yoo`00;goo10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH00000FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80006
FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP02FUH2000[Ool0031oo`80009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04
FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000000P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00`000eYF0P00;7oo000_Ool00`00FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH40005FUH00`00FUIJEP03FUH4
000^Ool002moo`8000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEPL000IJEP03001JEUYF
00EJEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH0
1EYF0P00;goo000_Ool200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP06FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300001UYF001JEP00FUH0009JEPD000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP03001JEP0002ioo`00;Woo00@005YF000000Aoo`<00003
FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP@000MJEP03001JEUYF00800005OomJEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUH00006FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH01@00FUIJEUYF0000;Goo000^Ool3
0008Ool50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP<000EJEP<0
009ooaT000Moo`04001JEUYF0004FUH00`00Oomoo`0ZOol002ioo`800003FUH007oo00]ooaX00006
Ool00000001JEP002EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF2P002eYF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH01@009Woo0`0015YF00<007oo
Ool0:Woo000^Ool20002FUH00`00Oomoo`0WOol20009FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF1P002EYF00<005YFFUH02EYF00<005YFFUH02EYF1`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF00001EYF0`00:7oo00<005YFFUH00UYF00<007ooOol0:Woo000_Ool01@00FUIJEUYF
0000:Woo0P000eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP8000=JEP80
00IJEP04001JEP00000WOol00`00FUIJEP02000/Ool002moo`04001JEUYFFUH3000ZOol200000eYF
001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH20003FUH20006FUH01000FUIJEUYF
0`009Goo1000;7oo000`Ool01000FUIJEP000UYF0P00:Woo0P000eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEP000003FUH00`00FUIJEP05FUH4000ROol3000/Ool0031o
o`03001JEP0000EJEP<002Uoo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF
00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00@001aoo`@002eoo`00<Goo0P001UYF00@0
05YF000002Moo`=JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP04FUH7000@Ool50002FUH2000]Ool0039oo`03001JEUYF00AJEP04001JEUYFFUH2
0009Ool3000IOol3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04FUH0
1000FUH0000015YF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00H005YFFUH005YF000]Ool0
03=oo`8000=JEP03001JEUYF00AJEP@000Aoo`D001Qoo`9JEP05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000eOol200000eYF001JEP06FUH0
0`00FUIJEP09000GOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol30006FUH00`00FUIJEP04FUH7000@Ool500000eYF
00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000050005FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000jOol20004FUH00`00FUIJEP05FUH30003FUH@0003FUH00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006Ool400000eYF001JEP04FUH01000FUIJEUYF0P000goo1`00
15YF00<005YFFUH01EYF00@005YFFUIJEPH0035oo`00?7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P002Woo10000eYF00@005YFFUIJEP8000Yooa0003Moo`00?goo0`001UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000]oo`P000=JEP80055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20008Ool5
0005FUH01000FUIJEP000UYF0P00DGoo0016Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1Goo0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00D005YF000005YF00T000=JEP03001JEUYF00AJEP04001JEUYFFUH4
001AOol004eooa4000]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00AJEP@000AJEP03001JEUYF00AJEP03001J
EUYF009JEP<0055oo`00K7oo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YF000010001UYF00<0
05YFFUH00UYF0`00DGoo001^Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUH0000800000eYF001JEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP02FUH00`00FUH0001AOol0075oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000EJEPP000IJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP80059oo`00N7oo3000
1UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00H0
05YFFUH005YF0003FUH2001COol008Aoo`h00004Ool000000005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH50007FUH40005FUH00`00FUIJEP02FUH200000eYF0000001EOol008moo`@0009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000QJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00Oomoo`1EOol008moo`05001JEP00FUH00003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH2001FOol008moo`8000=JEP03001o
ogoo00=oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000IJEP04001J
EP00001DOol0091oo`04001JEUYFFUH30008OolK0005Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1AOol0091oo`05001JEUYFFUH00002FUH00`00Oomoo`0WOol200000eYF001JEP03FUH00`00Oomo
o`1AOol0095oo`03001JEP0000AJEP8002Uoo`8000AJEP03001oogoo055oo`00TWoo0P001UYF0P00
:Goo00<005YFFUH00P00Dgoo002COol00`00FUIJEP04FUH00`00FUH00003000VOol4001COol009Ao
o`8000AJEP03001JEUYF00=JEPD002=oo`8005=oo`00UWoo00@005YFFUH000QJEP03001JEUYF00@0
01eoo`<005Aoo`00Ugoo0`0025YF00<005YFFUH015YF1`0047oo1P0000=JEP000000E7oo002IOol2
0006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH@0003FUH01000FUIJEUYF0P00E7oo002KOol40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
001EOol009moo`D000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2001EOol00:Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH0001FOol00:Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol0
0:mooaD005Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61036 .76917 m .6008 .71345 L .5701 .71703 L p .707 .577 .707 r
F P
0 g
s
.6008 .71345 m .61036 .76917 L .64177 .76345 L p .707 .577 .707 r
F P
0 g
s
.64177 .76345 m .63221 .70773 L .6008 .71345 L p .707 .577 .707 r
F P
0 g
s
.63221 .70773 m .64177 .76345 L .67082 .75615 L p .707 .577 .707 r
F P
0 g
s
.67082 .75615 m .66126 .70043 L .63221 .70773 L p .707 .577 .707 r
F P
0 g
s
.57966 .77274 m .5701 .71703 L .54311 .71811 L p .707 .577 .707 r
F P
0 g
s
.5701 .71703 m .57966 .77274 L .61036 .76917 L p .707 .577 .707 r
F P
0 g
s
.66126 .70043 m .67082 .75615 L .69466 .74798 L p .707 .577 .707 r
F P
0 g
s
.69466 .74798 m .6851 .69226 L .66126 .70043 L p .707 .577 .707 r
F P
0 g
s
.54311 .71811 m .55267 .77383 L .57966 .77274 L p .707 .577 .707 r
F P
0 g
s
.6131 .85284 m .61284 .81575 L .58167 .81408 L p .707 .577 .707 r
F P
0 g
s
.61284 .81575 m .6131 .85284 L .64494 .85186 L p .707 .577 .707 r
F P
0 g
s
.64494 .85186 m .64467 .81477 L .61284 .81575 L p .707 .577 .707 r
F P
0 g
s
.55267 .77383 m .54311 .71811 L .52248 .7166 L p .707 .577 .707 r
F P
0 g
s
.64467 .81477 m .64494 .85186 L .67432 .84832 L p .707 .577 .707 r
F P
0 g
s
.67432 .84832 m .67405 .81123 L .64467 .81477 L p .707 .577 .707 r
F P
0 g
s
.58193 .85116 m .58167 .81408 L .55421 .80991 L p .707 .577 .707 r
F P
0 g
s
.58167 .81408 m .58193 .85116 L .6131 .85284 L p .707 .577 .707 r
F P
0 g
s
.6851 .69226 m .69466 .74798 L .71095 .73975 L p .707 .577 .707 r
F P
0 g
s
.71095 .73975 m .70139 .68403 L .6851 .69226 L p .707 .577 .707 r
F P
0 g
s
.52248 .7166 m .53204 .77232 L .55267 .77383 L p .707 .577 .707 r
F P
0 g
s
.67405 .81123 m .67432 .84832 L .69837 .84256 L p .707 .577 .707 r
F P
0 g
s
.69837 .84256 m .69811 .80548 L .67405 .81123 L p .707 .577 .707 r
F P
0 g
s
.55421 .80991 m .55447 .84699 L .58193 .85116 L p .707 .577 .707 r
F P
0 g
s
.60053 .89492 m .60538 .87761 L .57531 .86756 L p .707 .577 .707 r
F P
0 g
s
.60538 .87761 m .60053 .89492 L .63137 .90149 L p .707 .577 .707 r
F P
0 g
s
.63137 .90149 m .63622 .88418 L .60538 .87761 L p .707 .577 .707 r
F P
0 g
s
.55447 .84699 m .55421 .80991 L .53315 .80366 L p .707 .577 .707 r
F P
0 g
s
.57046 .88487 m .57531 .86756 L .54896 .85501 L p .707 .577 .707 r
F P
0 g
s
.57531 .86756 m .57046 .88487 L .60053 .89492 L p .707 .577 .707 r
F P
0 g
s
.63622 .88418 m .63137 .90149 L .65996 .90395 L p .707 .577 .707 r
F P
0 g
s
.65996 .90395 m .66481 .88664 L .63622 .88418 L p .707 .577 .707 r
F P
0 g
s
.53204 .77232 m .52248 .7166 L .51023 .71264 L p .707 .577 .707 r
F P
0 g
s
.54896 .85501 m .54411 .87232 L .57046 .88487 L p .707 .577 .707 r
F P
0 g
s
.53315 .80366 m .53342 .84074 L .55447 .84699 L p .707 .577 .707 r
F P
0 g
s
.69811 .80548 m .69837 .84256 L .71474 .83516 L p .707 .577 .707 r
F P
0 g
s
.71474 .83516 m .71447 .79808 L .69811 .80548 L p .707 .577 .707 r
F P
0 g
s
.70139 .68403 m .71095 .73975 L .71811 .73225 L p .707 .577 .707 r
F P
0 g
s
.71811 .73225 m .70855 .67653 L .70139 .68403 L p .707 .577 .707 r
F P
0 g
s
.54411 .87232 m .54896 .85501 L .5289 .84121 L p .707 .577 .707 r
F P
0 g
s
.51023 .71264 m .51979 .76835 L .53204 .77232 L p .707 .577 .707 r
F P
0 g
s
.66481 .88664 m .65996 .90395 L .6835 .90204 L p .707 .577 .707 r
F P
0 g
s
.6835 .90204 m .68836 .88474 L .66481 .88664 L p .707 .577 .707 r
F P
0 g
s
.5289 .84121 m .52405 .85852 L .54411 .87232 L p .707 .577 .707 r
F P
0 g
s
.53342 .84074 m .53315 .80366 L .52056 .79594 L p .707 .577 .707 r
F P
0 g
s
.51979 .76835 m .51023 .71264 L .50755 .70661 L p .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5289 .84121 L .5217 .83284 L p .707 .577 .707 r
F P
0 g
s
.5217 .83284 m .5171 .82749 L p .52282 .85305 L .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5217 .83284 L .52282 .85305 L .707 .577 .707 r
F
.52083 .83302 m .52069 .81467 L p .51767 .7875 L F P
0 g
s
.52069 .81467 m .52056 .79594 L .51948 .79279 L p .707 .577 .707 r
F P
0 g
s
.51948 .79279 m .51767 .7875 L p .52069 .81467 L .707 .577 .707 r
F P
0 g
s
.52056 .79594 m .52083 .83302 L .53342 .84074 L p .707 .577 .707 r
F P
0 g
s
.68836 .88474 m .6835 .90204 L .6997 .89597 L p .707 .577 .707 r
F P
0 g
s
.6997 .89597 m .70455 .87866 L .68836 .88474 L p .707 .577 .707 r
F P
0 g
s
.71447 .79808 m .71474 .83516 L .72182 .82683 L p .707 .577 .707 r
F P
0 g
s
.72182 .82683 m .72156 .78975 L .71447 .79808 L p .707 .577 .707 r
F P
0 g
s
.5171 .82749 m .51224 .8448 L .52405 .85852 L p .707 .577 .707 r
F P
0 g
s
.70855 .67653 m .71811 .73225 L .71543 .72622 L p .707 .577 .707 r
F P
0 g
s
.71543 .72622 m .70587 .67051 L .70855 .67653 L p .707 .577 .707 r
F P
0 g
s
.50755 .70661 m .51711 .76233 L .51979 .76835 L p .707 .577 .707 r
F P
0 g
s
.48447 .81944 m .46656 .31597 L .42258 .31488 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .52083 .83302 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51767 .7875 m .51778 .80424 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51778 .80424 m .51793 .82458 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51224 .8448 m .5171 .82749 L .51471 .8152 L p .707 .577 .707 r
F P
0 g
s
.51471 .8152 m .50986 .83251 L .51224 .8448 L p .707 .577 .707 r
F P
0 g
s
.50986 .83251 m .51471 .8152 L .5169 .81229 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .51767 .7875 L .52475 .77917 L p .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .51793 .82458 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52475 .77917 m .52486 .79522 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52486 .79522 m .52501 .81625 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .52475 .77917 L .54112 .77176 L p .707 .577 .707 r
F P
0 g
s
.51711 .82285 m .52197 .80555 L .52725 .80356 L p .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .52501 .81625 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54112 .77176 m .54124 .78851 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54124 .78851 m .54138 .80885 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .54112 .77176 L .56517 .76601 L p .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .53816 .79947 L .54665 .79878 L p .707 .577 .707 r
F P
0 g
s
.56517 .76601 m .56543 .80309 L .54138 .80885 L p .707 .577 .707 r
F P
0 g
s
.54665 .79878 m .56171 .79757 L p .55013 .80539 L .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .54665 .79878 L .55013 .80539 L .707 .577 .707 r
F
.52725 .80356 m .53816 .79947 L p .529 .80965 L F P
0 g
s
.51711 .82285 m .52725 .80356 L .529 .80965 L .707 .577 .707 r
F
.5169 .81229 m .52197 .80555 L p .51623 .81832 L F P
0 g
s
.50986 .83251 m .5169 .81229 L .51623 .81832 L .707 .577 .707 r
F
.51711 .76233 m .50755 .70661 L .5147 .69912 L p F P
0 g
s
.5147 .69912 m .52426 .75483 L .51711 .76233 L p .707 .577 .707 r
F P
0 g
s
.52197 .80555 m .51711 .82285 L .50986 .83251 L p .707 .577 .707 r
F P
0 g
s
.53816 .79947 m .53331 .81678 L .51711 .82285 L p .707 .577 .707 r
F P
0 g
s
.46656 .31597 m .48447 .81944 L .52938 .8169 L p .707 .577 .707 r
F P
0 g
s
.52426 .75483 m .5147 .69912 L .531 .69088 L p .707 .577 .707 r
F P
0 g
s
.531 .69088 m .54056 .7466 L .52426 .75483 L p .707 .577 .707 r
F P
0 g
s
.52938 .8169 m .51148 .31344 L .46656 .31597 L p .707 .577 .707 r
F P
0 g
s
.54056 .7466 m .531 .69088 L .55484 .68271 L p .707 .577 .707 r
F P
0 g
s
.55484 .68271 m .56439 .73843 L .54056 .7466 L p .707 .577 .707 r
F P
0 g
s
.56439 .73843 m .55484 .68271 L .58388 .67541 L p .707 .577 .707 r
F P
0 g
s
.56171 .79757 m .55685 .81487 L .53331 .81678 L p .707 .577 .707 r
F P
0 g
s
.56543 .80309 m .56517 .76601 L .59455 .76247 L p .707 .577 .707 r
F P
0 g
s
.59455 .76247 m .59482 .79955 L .56543 .80309 L p .707 .577 .707 r
F P
0 g
s
.55685 .81487 m .56171 .79757 L .5903 .80002 L p .707 .577 .707 r
F P
0 g
s
.5903 .80002 m .58544 .81733 L .55685 .81487 L p .707 .577 .707 r
F P
0 g
s
.51148 .31344 m .52938 .8169 L .57084 .81099 L p .707 .577 .707 r
F P
0 g
s
.58388 .67541 m .59344 .73113 L .56439 .73843 L p .707 .577 .707 r
F P
0 g
s
.57084 .81099 m .55294 .30753 L .51148 .31344 L p .707 .577 .707 r
F P
0 g
s
.70455 .87866 m .6997 .89597 L .70696 .88631 L p .707 .577 .707 r
F P
0 g
s
.70696 .88631 m .71181 .869 L .70455 .87866 L p .707 .577 .707 r
F P
0 g
s
.72156 .78975 m .72182 .82683 L .71893 .81839 L p .707 .577 .707 r
F P
0 g
s
.71893 .81839 m .71866 .78131 L .72156 .78975 L p .707 .577 .707 r
F P
0 g
s
.44049 .81834 m .42258 .31488 L .38384 .31027 L p .707 .577 .707 r
F P
0 g
s
.42258 .31488 m .44049 .81834 L .48447 .81944 L p .707 .577 .707 r
F P
0 g
s
.26735 .68432 m .2578 .6286 L .22709 .63218 L p .707 .577 .707 r
F P
0 g
s
.2578 .6286 m .26735 .68432 L .29876 .6786 L p .707 .577 .707 r
F P
0 g
s
.29876 .6786 m .28921 .62288 L .2578 .6286 L p .707 .577 .707 r
F P
0 g
s
.70587 .67051 m .71543 .72622 L .70317 .72226 L p .707 .577 .707 r
F P
0 g
s
.70317 .72226 m .69361 .66655 L .70587 .67051 L p .707 .577 .707 r
F P
0 g
s
.28921 .62288 m .29876 .6786 L .32781 .6713 L p .707 .577 .707 r
F P
0 g
s
.32781 .6713 m .31825 .61558 L .28921 .62288 L p .707 .577 .707 r
F P
0 g
s
.23665 .6879 m .22709 .63218 L .20011 .63327 L p .707 .577 .707 r
F P
0 g
s
.22709 .63218 m .23665 .6879 L .26735 .68432 L p .707 .577 .707 r
F P
0 g
s
.59344 .73113 m .58388 .67541 L .61529 .66969 L p .707 .577 .707 r
F P
0 g
s
.61529 .66969 m .62485 .72541 L .59344 .73113 L p .707 .577 .707 r
F P
0 g
s
.59482 .79955 m .59455 .76247 L .62639 .76149 L p .707 .577 .707 r
F P
0 g
s
.62639 .76149 m .62665 .79857 L .59482 .79955 L p .707 .577 .707 r
F P
0 g
s
.58544 .81733 m .5903 .80002 L .62114 .8066 L p .707 .577 .707 r
F P
0 g
s
.55294 .30753 m .57084 .81099 L .60479 .80228 L p .707 .577 .707 r
F P
0 g
s
.60479 .80228 m .58688 .29882 L .55294 .30753 L p .707 .577 .707 r
F P
0 g
s
.31825 .61558 m .32781 .6713 L .35165 .66313 L p .707 .577 .707 r
F P
0 g
s
.35165 .66313 m .34209 .60742 L .31825 .61558 L p .707 .577 .707 r
F P
0 g
s
.27009 .73326 m .26983 .69618 L .23866 .6945 L p .707 .577 .707 r
F P
0 g
s
.26983 .69618 m .27009 .73326 L .30193 .73228 L p .707 .577 .707 r
F P
0 g
s
.30193 .73228 m .30166 .6952 L .26983 .69618 L p .707 .577 .707 r
F P
0 g
s
.30166 .6952 m .30193 .73228 L .33131 .72874 L p .707 .577 .707 r
F P
0 g
s
.33131 .72874 m .33104 .69166 L .30166 .6952 L p .707 .577 .707 r
F P
0 g
s
.20011 .63327 m .20966 .68898 L .23665 .6879 L p .707 .577 .707 r
F P
0 g
s
.23892 .73158 m .23866 .6945 L .2112 .69033 L p .707 .577 .707 r
F P
0 g
s
.23866 .6945 m .23892 .73158 L .27009 .73326 L p .707 .577 .707 r
F P
0 g
s
.40175 .81374 m .38384 .31027 L .35414 .3026 L p .707 .577 .707 r
F P
0 g
s
.38384 .31027 m .40175 .81374 L .44049 .81834 L p .707 .577 .707 r
F P
0 g
s
.71181 .869 m .70696 .88631 L .70457 .87402 L p .707 .577 .707 r
F P
0 g
s
.70457 .87402 m .70942 .85672 L .71181 .869 L p .707 .577 .707 r
F P
0 g
s
.20966 .68898 m .20011 .63327 L .17947 .63175 L p .707 .577 .707 r
F P
0 g
s
.71866 .78131 m .71893 .81839 L .70633 .81067 L p .707 .577 .707 r
F P
0 g
s
.70633 .81067 m .70607 .77359 L .71866 .78131 L p .707 .577 .707 r
F P
0 g
s
.33104 .69166 m .33131 .72874 L .35536 .72299 L p .707 .577 .707 r
F P
0 g
s
.35536 .72299 m .3551 .6859 L .33104 .69166 L p .707 .577 .707 r
F P
0 g
s
.69361 .66655 m .70317 .72226 L .68254 .72075 L p .707 .577 .707 r
F P
0 g
s
.68254 .72075 m .67298 .66503 L .69361 .66655 L p .707 .577 .707 r
F P
0 g
s
.2112 .69033 m .21146 .72741 L .23892 .73158 L p .707 .577 .707 r
F P
0 g
s
.34209 .60742 m .35165 .66313 L .36794 .6549 L p .707 .577 .707 r
F P
0 g
s
.36794 .6549 m .35838 .59918 L .34209 .60742 L p .707 .577 .707 r
F P
0 g
s
.17947 .63175 m .18903 .68747 L .1909 .68761 L p .707 .577 .707 r
F P
0 g
s
.1909 .68761 m .20966 .68898 L p .19378 .65887 L .707 .577 .707 r
F P
0 g
s
.19378 .65887 m .17947 .63175 L .1909 .68761 L .707 .577 .707 r
F
.18903 .68747 m .17947 .63175 L .16722 .62779 L p F P
0 g
s
.16722 .62779 m .17678 .68351 L .17779 .68383 L p .707 .577 .707 r
F P
0 g
s
.17779 .68383 m .18903 .68747 L p .1786 .65894 L .707 .577 .707 r
F P
0 g
s
.1786 .65894 m .16722 .62779 L .17779 .68383 L .707 .577 .707 r
F
.17678 .68351 m .16722 .62779 L .16454 .62176 L p F P
0 g
s
.16454 .62176 m .1741 .67748 L .17428 .6779 L p .707 .577 .707 r
F P
0 g
s
.17428 .6779 m .17678 .68351 L p .17111 .6549 L .707 .577 .707 r
F P
0 g
s
.17111 .6549 m .16454 .62176 L .17428 .6779 L .707 .577 .707 r
F
.17755 .67636 m .17466 .66792 L p .17714 .70375 L F P
0 g
s
.17764 .68853 m .17755 .67636 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .17755 .67636 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.17755 .67636 m .17782 .71344 L .19041 .72116 L p .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .18174 .65959 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .17475 .6813 L p .17782 .71344 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17492 .705 L .17616 .70863 L p .707 .577 .707 r
F P
0 g
s
.17616 .70863 m .17782 .71344 L p .17475 .6813 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17466 .66792 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17782 .71344 m .17764 .68853 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.18174 .65959 m .18184 .67339 L p .17492 .705 L .707 .577 .707 r
F P
0 g
s
.18184 .67339 m .182 .69667 L .17905 .70014 L p .707 .577 .707 r
F P
0 g
s
.17905 .70014 m .17492 .705 L p .18184 .67339 L .707 .577 .707 r
F P
0 g
s
.182 .69667 m .18174 .65959 L .19811 .65219 L p .707 .577 .707 r
F P
0 g
s
.18799 .60603 m .18852 .60914 L p .18125 .66998 L .707 .577 .707 r
F P
0 g
s
.19022 .69438 m .19014 .68408 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.21146 .72741 m .2112 .69033 L .19014 .68408 L p .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .19041 .72116 L .21146 .72741 L p .707 .577 .707 r
F P
0 g
s
.19811 .65219 m .1982 .66557 L p .182 .69667 L .707 .577 .707 r
F P
0 g
s
.1982 .66557 m .19837 .68927 L .1922 .69206 L p .707 .577 .707 r
F P
0 g
s
.1922 .69206 m .182 .69667 L p .1982 .66557 L .707 .577 .707 r
F P
0 g
s
.19837 .68927 m .19811 .65219 L .22216 .64643 L p .707 .577 .707 r
F P
0 g
s
.21183 .59787 m .21257 .60218 L p .19755 .66175 L .707 .577 .707 r
F P
0 g
s
.22216 .64643 m .22225 .65861 L p .19837 .68927 L .707 .577 .707 r
F P
0 g
s
.22225 .65861 m .22242 .68352 L .21493 .68531 L p .707 .577 .707 r
F P
0 g
s
.21493 .68531 m .19837 .68927 L p .22225 .65861 L .707 .577 .707 r
F P
0 g
s
.22242 .68352 m .22216 .64643 L .25154 .64289 L p .707 .577 .707 r
F P
0 g
s
.24087 .59057 m .24089 .59064 L p .22139 .65358 L .707 .577 .707 r
F P
0 g
s
.25154 .64289 m .25162 .65319 L p .22242 .68352 L .707 .577 .707 r
F P
0 g
s
.25162 .65319 m .25181 .67998 L .24548 .68074 L p .707 .577 .707 r
F P
0 g
s
.24548 .68074 m .22242 .68352 L p .25162 .65319 L .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .24087 .59057 L .2666 .58588 L p .707 .577 .707 r
F P
0 g
s
.2666 .58588 m .27228 .58485 L p .25771 .62581 L .707 .577 .707 r
F P
0 g
s
.25181 .67998 m .25154 .64289 L .28338 .64191 L p .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .2666 .58588 L .25771 .62581 L .707 .577 .707 r
F
.24089 .59064 m .25043 .64628 L .22379 .65298 L p F P
0 g
s
.22379 .65298 m .22139 .65358 L p .24089 .59064 L .707 .577 .707 r
F P
0 g
s
.21257 .60218 m .22139 .65358 L .1992 .66118 L p .707 .577 .707 r
F P
0 g
s
.1992 .66118 m .19755 .66175 L p .21257 .60218 L .707 .577 .707 r
F P
0 g
s
.18852 .60914 m .19755 .66175 L .18224 .66948 L p .707 .577 .707 r
F P
0 g
s
.18224 .66948 m .18125 .66998 L p .18852 .60914 L .707 .577 .707 r
F P
0 g
s
.1717 .61427 m .18125 .66998 L .17453 .67703 L p .707 .577 .707 r
F P
0 g
s
.17453 .67703 m .1741 .67748 L p .17283 .64419 L .707 .577 .707 r
F P
0 g
s
.17283 .64419 m .1717 .61427 L .17453 .67703 L .707 .577 .707 r
F
.17492 .705 m .17475 .6813 L p .17654 .69423 L F P
0 g
s
.19041 .72116 m .19022 .69438 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.62485 .72541 m .61529 .66969 L .64599 .66612 L p .707 .577 .707 r
F P
0 g
s
.62665 .79857 m .62639 .76149 L .65756 .76317 L p .707 .577 .707 r
F P
0 g
s
.58688 .29882 m .60479 .80228 L .62789 .79163 L p .707 .577 .707 r
F P
0 g
s
.64599 .66612 m .65555 .72183 L .62485 .72541 L p .707 .577 .707 r
F P
0 g
s
.62789 .79163 m .60999 .28816 L .58688 .29882 L p .707 .577 .707 r
F P
0 g
s
.25752 .78844 m .26237 .77113 L .23231 .76108 L p .707 .577 .707 r
F P
0 g
s
.26237 .77113 m .25752 .78844 L .28836 .79501 L p .707 .577 .707 r
F P
0 g
s
.28836 .79501 m .29321 .7777 L .26237 .77113 L p .707 .577 .707 r
F P
0 g
s
.22745 .77839 m .23231 .76108 L .20595 .74854 L p .707 .577 .707 r
F P
0 g
s
.23231 .76108 m .22745 .77839 L .25752 .78844 L p .707 .577 .707 r
F P
0 g
s
.29321 .7777 m .28836 .79501 L .31695 .79747 L p .707 .577 .707 r
F P
0 g
s
.31695 .79747 m .3218 .78016 L .29321 .7777 L p .707 .577 .707 r
F P
0 g
s
.20595 .74854 m .2011 .76585 L .22745 .77839 L p .707 .577 .707 r
F P
0 g
s
.3551 .6859 m .35536 .72299 L .37173 .71558 L p .707 .577 .707 r
F P
0 g
s
.37173 .71558 m .37147 .6785 L .3551 .6859 L p .707 .577 .707 r
F P
0 g
s
.70942 .85672 m .70457 .87402 L .69277 .8603 L p .707 .577 .707 r
F P
0 g
s
.69277 .8603 m .69762 .843 L .70942 .85672 L p .707 .577 .707 r
F P
0 g
s
.35838 .59918 m .36794 .6549 L .3751 .6474 L p .707 .577 .707 r
F P
0 g
s
.3751 .6474 m .36554 .59169 L .35838 .59918 L p .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .36554 .59169 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .37004 .62752 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37004 .62752 m .36286 .58566 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.35414 .3026 m .33639 .2926 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .36563 .62558 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .40175 .81374 L p .39549 .7465 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .36928 .64036 L p .36774 .63412 L .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .37004 .62752 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.37147 .6785 m .37173 .71558 L .37881 .70725 L p .707 .577 .707 r
F P
0 g
s
.37881 .70725 m .37855 .67017 L .37147 .6785 L p .707 .577 .707 r
F P
0 g
s
.37855 .67017 m .37881 .70725 L .37592 .69881 L p .707 .577 .707 r
F P
0 g
s
.37592 .69881 m .37565 .66173 L .37855 .67017 L p .707 .577 .707 r
F P
0 g
s
.36563 .62558 m .37205 .80606 L p .3724 .80516 L .707 .577 .707 r
F P
0 g
s
.37565 .66173 m .37592 .69881 L .37357 .69738 L p .707 .577 .707 r
F P
0 g
s
.37391 .66589 m .37565 .66173 L .37357 .69738 L .707 .577 .707 r
F
.37398 .65939 m .36563 .62558 L .3724 .80516 L F
.34535 .77826 m .3405 .79557 L .35669 .78949 L p F P
0 g
s
.35669 .78949 m .36154 .77218 L .34535 .77826 L p .707 .577 .707 r
F P
0 g
s
.36154 .77218 m .35669 .78949 L .36395 .77983 L p .707 .577 .707 r
F P
0 g
s
.36395 .77983 m .3688 .76253 L .36154 .77218 L p .707 .577 .707 r
F P
0 g
s
.3688 .76253 m .36395 .77983 L .36156 .76755 L p .707 .577 .707 r
F P
0 g
s
.36156 .76755 m .36641 .75024 L .3688 .76253 L p .707 .577 .707 r
F P
0 g
s
.36641 .75024 m .36156 .76755 L .35564 .76067 L p .707 .577 .707 r
F P
0 g
s
.35564 .76067 m .34976 .75383 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35497 .7527 m .36641 .75024 L .35564 .76067 L .707 .577 .707 r
F
.35787 .68947 m .34227 .68484 L p .35651 .66372 L F P
0 g
s
.35461 .73652 m .36641 .75024 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.34976 .75383 m .35385 .73924 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35385 .73924 m .35461 .73652 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35461 .73652 m .34976 .75383 L .33746 .74537 L p .707 .577 .707 r
F P
0 g
s
.33746 .74537 m .3297 .74002 L p .33749 .73893 L .707 .577 .707 r
F P
0 g
s
.33749 .73893 m .35461 .73652 L .33746 .74537 L .707 .577 .707 r
F
.3506 .5817 m .35752 .62201 L p .33953 .6359 L F P
0 g
s
.35675 .63716 m .33953 .6359 L p .35752 .62201 L .707 .577 .707 r
F P
0 g
s
.33953 .6359 m .32997 .58018 L .3506 .5817 L p .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .35932 .6228 L .35756 .68358 L .707 .577 .707 r
F
.34227 .68484 m .34201 .64776 L .35588 .65188 L p F P
0 g
s
.35932 .6228 m .35423 .62056 L .35756 .68358 L .707 .577 .707 r
F
.35588 .65188 m .36306 .65401 L p .35651 .66372 L F P
0 g
s
.34227 .68484 m .35588 .65188 L .35651 .66372 L .707 .577 .707 r
F
.3297 .74002 m .33455 .72271 L .35461 .73652 L p F P
0 g
s
.34795 .61779 m .35429 .79607 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.35423 .62056 m .34795 .61779 L .35756 .68358 L .707 .577 .707 r
F
.33231 .28128 m .34471 .62993 L p .34979 .69075 L F P
0 g
s
.34471 .62993 m .35022 .78474 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .33231 .28128 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3511 .70639 m .33639 .2926 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3506 .5817 m .36286 .58566 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .3506 .5817 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .34795 .61779 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .33852 .45592 L p .34231 .26972 L .707 .577 .707 r
F P
0 g
s
.33852 .45592 m .33231 .28128 L .33919 .27333 L p .707 .577 .707 r
F P
0 g
s
.33919 .27333 m .34231 .26972 L p .33852 .45592 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .35429 .79607 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .36016 .63741 L .35675 .63716 L p .707 .577 .707 r
F P
0 g
s
.35429 .79607 m .3511 .70639 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.36377 .80141 m .37205 .80606 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.36306 .65401 m .36332 .69109 L .35787 .68947 L p .707 .577 .707 r
F P
0 g
s
.35651 .66372 m .36306 .65401 L .35787 .68947 L .707 .577 .707 r
F
.35429 .79607 m .36377 .80141 L p .35756 .68358 L F P
0 g
s
.36016 .63741 m .35752 .62201 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .36306 .65401 L .37397 .6607 L p .707 .577 .707 r
F P
0 g
s
.37397 .6607 m .37565 .66173 L p .37391 .66589 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .37397 .6607 L .37391 .66589 L .707 .577 .707 r
F
.37004 .62752 m .37242 .64138 L p .36774 .63412 L F P
0 g
s
.36089 .62349 m .36563 .62558 L .36774 .63412 L .707 .577 .707 r
F
.36563 .62558 m .37004 .62752 L .36774 .63412 L F
.36554 .59169 m .3751 .6474 L .37242 .64138 L p F P
0 g
s
.35414 .3026 m .36563 .62558 L p .37398 .65939 L .707 .577 .707 r
F P
0 g
s
.39549 .7465 m .37537 .53052 L .37398 .65939 L .707 .577 .707 r
F
.37537 .53052 m .35414 .3026 L .37398 .65939 L F
.39549 .7465 m .37398 .65939 L .3724 .80516 L F
.37357 .69738 m .36332 .69109 L p .37391 .66589 L F P
0 g
s
.36016 .63741 m .36089 .62349 L .36774 .63412 L .707 .577 .707 r
F
.36928 .64036 m .36016 .63741 L p .36774 .63412 L F P
0 g
s
.35932 .6228 m .36468 .59898 L .35354 .53961 L .707 .577 .707 r
F
.36563 .62558 m .36468 .59898 L p .35932 .6228 L F P
0 g
s
.36468 .59898 m .35414 .3026 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.2011 .76585 m .20595 .74854 L .18589 .73473 L p .707 .577 .707 r
F P
0 g
s
.67298 .66503 m .68254 .72075 L .65555 .72183 L p .707 .577 .707 r
F P
0 g
s
.65555 .72183 m .64599 .66612 L .67298 .66503 L p .707 .577 .707 r
F P
0 g
s
.70607 .77359 m .70633 .81067 L .68528 .80442 L p .707 .577 .707 r
F P
0 g
s
.68528 .80442 m .68502 .76734 L .70607 .77359 L p .707 .577 .707 r
F P
0 g
s
.3218 .78016 m .31695 .79747 L .3405 .79557 L p .707 .577 .707 r
F P
0 g
s
.3405 .79557 m .34535 .77826 L .3218 .78016 L p .707 .577 .707 r
F P
0 g
s
.18589 .73473 m .18104 .75204 L .2011 .76585 L p .707 .577 .707 r
F P
0 g
s
.60999 .28816 m .62789 .79163 L .6379 .78007 L p .707 .577 .707 r
F P
0 g
s
.6379 .78007 m .61999 .27661 L .60999 .28816 L p .707 .577 .707 r
F P
0 g
s
.18104 .75204 m .18589 .73473 L .17409 .72101 L p .707 .577 .707 r
F P
0 g
s
.69762 .843 m .69277 .8603 L .67271 .8465 L p .707 .577 .707 r
F P
0 g
s
.67271 .8465 m .67756 .82919 L .69762 .843 L p .707 .577 .707 r
F P
0 g
s
.68502 .76734 m .68528 .80442 L .65782 .80025 L p .707 .577 .707 r
F P
0 g
s
.65782 .80025 m .65756 .76317 L .68502 .76734 L p .707 .577 .707 r
F P
0 g
s
.17409 .72101 m .16924 .73832 L .18104 .75204 L p .707 .577 .707 r
F P
0 g
s
.65756 .76317 m .65782 .80025 L .62665 .79857 L p .707 .577 .707 r
F P
0 g
s
.67756 .82919 m .67271 .8465 L .64635 .83396 L p .707 .577 .707 r
F P
0 g
s
.64635 .83396 m .65121 .81665 L .67756 .82919 L p .707 .577 .707 r
F P
0 g
s
.16924 .73832 m .17409 .72101 L .1717 .70872 L p .707 .577 .707 r
F P
0 g
s
.1717 .70872 m .16685 .72603 L .16924 .73832 L p .707 .577 .707 r
F P
0 g
s
.1741 .67748 m .16454 .62176 L .1717 .61427 L p .707 .577 .707 r
F P
0 g
s
.65121 .81665 m .64635 .83396 L .61628 .8239 L p .707 .577 .707 r
F P
0 g
s
.61628 .8239 m .62114 .8066 L .65121 .81665 L p .707 .577 .707 r
F P
0 g
s
.62114 .8066 m .61628 .8239 L .58544 .81733 L p .707 .577 .707 r
F P
0 g
s
.61999 .27661 m .6379 .78007 L .63382 .76875 L p .707 .577 .707 r
F P
0 g
s
.63382 .76875 m .61591 .26528 L .61999 .27661 L p .707 .577 .707 r
F P
0 g
s
.16685 .72603 m .1717 .70872 L .17896 .69907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17896 .69907 m .1741 .71638 L .16685 .72603 L p .707 .577 .707 r
F P
0 g
s
.18125 .66998 m .1717 .61427 L .18799 .60603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.61591 .26528 m .63382 .76875 L .61606 .75876 L p .707 .577 .707 r
F P
0 g
s
.61606 .75876 m .59816 .25529 L .61591 .26528 L p .707 .577 .707 r
F P
0 g
s
.1741 .71638 m .17896 .69907 L .19515 .69299 L p .707 .577 .707 r
F P
0 g
s
.19755 .66175 m .18799 .60603 L .21183 .59787 L p .707 .577 .707 r
F P
0 g
s
.19515 .69299 m .1903 .7103 L .1741 .71638 L p .707 .577 .707 r
F P
0 g
s
.32997 .58018 m .33953 .6359 L .31254 .63699 L p .707 .577 .707 r
F P
0 g
s
.31254 .63699 m .30299 .58127 L .32997 .58018 L p .707 .577 .707 r
F P
0 g
s
.36022 .77319 m .34231 .26972 L .36542 .25907 L p .707 .577 .707 r
F P
0 g
s
.34231 .26972 m .36022 .77319 L .35022 .78474 L p .707 .577 .707 r
F P
0 g
s
.22139 .65358 m .21183 .59787 L .24087 .59057 L p .707 .577 .707 r
F P
0 g
s
.34201 .64776 m .34227 .68484 L .31481 .68067 L p .707 .577 .707 r
F P
0 g
s
.31481 .68067 m .31455 .64359 L .34201 .64776 L p .707 .577 .707 r
F P
0 g
s
.1903 .7103 m .19515 .69299 L .2187 .69109 L p .707 .577 .707 r
F P
0 g
s
.30299 .58127 m .31254 .63699 L .28184 .64056 L p .707 .577 .707 r
F P
0 g
s
.28184 .64056 m .27228 .58485 L .30299 .58127 L p .707 .577 .707 r
F P
0 g
s
.2187 .69109 m .21384 .7084 L .1903 .7103 L p .707 .577 .707 r
F P
0 g
s
.27228 .58485 m .28184 .64056 L .25043 .64628 L p .707 .577 .707 r
F P
0 g
s
.59816 .25529 m .61606 .75876 L .58636 .75108 L p .707 .577 .707 r
F P
0 g
s
.58636 .75108 m .56846 .24761 L .59816 .25529 L p .707 .577 .707 r
F P
0 g
s
.31455 .64359 m .31481 .68067 L .28364 .679 L p .707 .577 .707 r
F P
0 g
s
.28364 .679 m .28338 .64191 L .31455 .64359 L p .707 .577 .707 r
F P
0 g
s
.21384 .7084 m .2187 .69109 L .24729 .69354 L p .707 .577 .707 r
F P
0 g
s
.28338 .64191 m .28364 .679 L .25181 .67998 L p .707 .577 .707 r
F P
0 g
s
.33455 .72271 m .3297 .74002 L .30334 .72748 L p .707 .577 .707 r
F P
0 g
s
.30334 .72748 m .3082 .71017 L .33455 .72271 L p .707 .577 .707 r
F P
0 g
s
.74757 .67713 m .73801 .62141 L .70731 .62499 L p .707 .577 .707 r
F P
0 g
s
.73801 .62141 m .74757 .67713 L .77898 .67141 L p .707 .577 .707 r
F P
0 g
s
.77898 .67141 m .76942 .61569 L .73801 .62141 L p .707 .577 .707 r
F P
0 g
s
.76942 .61569 m .77898 .67141 L .80802 .66411 L p .707 .577 .707 r
F P
0 g
s
.80802 .66411 m .79846 .60839 L .76942 .61569 L p .707 .577 .707 r
F P
0 g
s
.24729 .69354 m .24244 .71085 L .21384 .7084 L p .707 .577 .707 r
F P
0 g
s
.36542 .25907 m .38332 .76253 L .36022 .77319 L p .707 .577 .707 r
F P
0 g
s
.38332 .76253 m .36542 .25907 L .39936 .25036 L p .707 .577 .707 r
F P
0 g
s
.71686 .68071 m .70731 .62499 L .68032 .62607 L p .707 .577 .707 r
F P
0 g
s
.70731 .62499 m .71686 .68071 L .74757 .67713 L p .707 .577 .707 r
F P
0 g
s
.24244 .71085 m .24729 .69354 L .27813 .70012 L p .707 .577 .707 r
F P
0 g
s
.79846 .60839 m .80802 .66411 L .83186 .65594 L p .707 .577 .707 r
F P
0 g
s
.83186 .65594 m .8223 .60023 L .79846 .60839 L p .707 .577 .707 r
F P
0 g
s
.3082 .71017 m .30334 .72748 L .27327 .71743 L p .707 .577 .707 r
F P
0 g
s
.27327 .71743 m .27813 .70012 L .3082 .71017 L p .707 .577 .707 r
F P
0 g
s
.27813 .70012 m .27327 .71743 L .24244 .71085 L p .707 .577 .707 r
F P
0 g
s
.68032 .62607 m .68988 .68179 L .71686 .68071 L p .707 .577 .707 r
F P
0 g
s
.56846 .24761 m .58636 .75108 L .54763 .74647 L p .707 .577 .707 r
F P
0 g
s
.54763 .74647 m .52972 .243 L .56846 .24761 L p .707 .577 .707 r
F P
0 g
s
.7503 .7608 m .75004 .72372 L .71887 .72204 L p .707 .577 .707 r
F P
0 g
s
.75004 .72372 m .7503 .7608 L .78214 .75982 L p .707 .577 .707 r
F P
0 g
s
.78214 .75982 m .78188 .72274 L .75004 .72372 L p .707 .577 .707 r
F P
0 g
s
.68988 .68179 m .68032 .62607 L .65969 .62456 L p .707 .577 .707 r
F P
0 g
s
.78188 .72274 m .78214 .75982 L .81152 .75628 L p .707 .577 .707 r
F P
0 g
s
.81152 .75628 m .81126 .7192 L .78188 .72274 L p .707 .577 .707 r
F P
0 g
s
.71913 .75912 m .71887 .72204 L .69141 .71787 L p .707 .577 .707 r
F P
0 g
s
.71887 .72204 m .71913 .75912 L .7503 .7608 L p .707 .577 .707 r
F P
0 g
s
.8223 .60023 m .83186 .65594 L .84815 .64771 L p .707 .577 .707 r
F P
0 g
s
.84815 .64771 m .8386 .59199 L .8223 .60023 L p .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .44082 .24445 L p .42565 .57266 L .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .41858 .57404 L .42563 .57266 L .707 .577 .707 r
F
.42252 .64037 m .42563 .57266 L .42564 .57281 L F
.41727 .75383 m .41496 .68878 L p .42252 .64037 L F P
0 g
s
.41496 .68878 m .39936 .25036 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .41496 .68878 L p .38332 .76253 L .707 .577 .707 r
F P
0 g
s
.41496 .68878 m .41727 .75383 L .41174 .75524 L p .707 .577 .707 r
F P
0 g
s
.41174 .75524 m .38332 .76253 L p .41496 .68878 L .707 .577 .707 r
F P
0 g
s
.395 .53656 m .40456 .59228 L .41976 .58951 L p .707 .577 .707 r
F P
0 g
s
.41858 .57404 m .39936 .25036 L .42565 .57266 L .707 .577 .707 r
F
.43088 .64049 m .43913 .64024 L p .43007 .63005 L F P
0 g
s
.46641 .6041 m .4649 .5829 L .48574 .24191 L .707 .577 .707 r
F
.44082 .24445 m .47655 .24243 L p .4649 .5829 L F P
0 g
s
.47655 .24243 m .48574 .24191 L p .4649 .5829 L .707 .577 .707 r
F P
0 g
s
.46431 .60009 m .43887 .60316 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.43597 .58656 m .45758 .58113 L p .45296 .56912 L .707 .577 .707 r
F P
0 g
s
.45231 .56743 m .44082 .24445 L p .46641 .6041 L .707 .577 .707 r
F P
0 g
s
.43332 .57115 m .43597 .58656 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.43887 .60316 m .43913 .64024 L .46303 .63736 L p .707 .577 .707 r
F P
0 g
s
.46326 .63076 m .43887 .60316 L .46303 .63736 L .707 .577 .707 r
F
.45873 .74792 m .45571 .66309 L p .46227 .65417 L F P
0 g
s
.45873 .74792 m .41727 .75383 L p .42142 .66396 L .707 .577 .707 r
F P
0 g
s
.43077 .58751 m .43597 .58656 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.44082 .24445 m .4489 .47144 L p .43332 .57115 L .707 .577 .707 r
F P
0 g
s
.43913 .64024 m .43887 .60316 L .42802 .60349 L p .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .42564 .57281 L .4281 .6046 L .707 .577 .707 r
F
.43913 .64024 m .42802 .60349 L .43007 .63005 L F
.43597 .58656 m .43332 .57115 L p .43173 .58139 L F P
0 g
s
.4489 .47144 m .45571 .66309 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.42802 .60349 m .40703 .60414 L p .43007 .63005 L .707 .577 .707 r
F P
0 g
s
.4281 .6046 m .42565 .57266 L .43332 .57115 L .707 .577 .707 r
F
.42564 .57281 m .42565 .57266 L .4281 .6046 L F
.42565 .57266 m .44082 .24445 L .43332 .57115 L F
.45546 .52355 m .42641 .53085 L p .45514 .56688 L F P
0 g
s
.46501 .57926 m .46264 .56541 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.46264 .56541 m .45546 .52355 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.42564 .57281 m .42563 .57266 L .42565 .57266 L .707 .577 .707 r
F
.42641 .53085 m .395 .53656 L p .43173 .58139 L F P
0 g
s
.43332 .57115 m .42641 .53085 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.42142 .66396 m .42252 .64037 L .45571 .66309 L .707 .577 .707 r
F
.45571 .66309 m .45873 .74792 L p .42142 .66396 L F P
0 g
s
.45415 .70543 m .45901 .68812 L .43861 .68637 L p .707 .577 .707 r
F P
0 g
s
.43861 .68637 m .43042 .68567 L p .43582 .69017 L .707 .577 .707 r
F P
0 g
s
.45415 .70543 m .43861 .68637 L .43582 .69017 L .707 .577 .707 r
F
.46227 .65417 m .45231 .56743 L .46436 .59877 L F
.45571 .66309 m .45231 .56743 L p .46227 .65417 L F P
0 g
s
.46018 .72077 m .46436 .59877 L .46641 .6041 L .707 .577 .707 r
F
.45873 .74792 m .46436 .59877 L .46018 .72077 L F
.48574 .24191 m .50365 .74538 L .45873 .74792 L p F P
0 g
s
.46303 .63736 m .46851 .6367 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46825 .59962 L .46431 .60009 L p .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46431 .60009 L .46326 .63076 L .707 .577 .707 r
F
.46501 .57926 m .45514 .56688 L .45296 .56912 L F
.45758 .58113 m .46501 .57926 L p .45296 .56912 L F P
0 g
s
.41976 .58951 m .43077 .58751 L p .42056 .57296 L .707 .577 .707 r
F P
0 g
s
.42056 .57296 m .395 .53656 L .41976 .58951 L .707 .577 .707 r
F
.40703 .60414 m .40729 .64122 L .43088 .64049 L p F P
0 g
s
.43007 .63005 m .40703 .60414 L .43088 .64049 L .707 .577 .707 r
F
.42641 .53085 m .43332 .57115 L p .45514 .56688 L F P
0 g
s
.43173 .58139 m .395 .53656 L .43077 .58751 L .707 .577 .707 r
F
.65969 .62456 m .66925 .68028 L .68988 .68179 L p F P
0 g
s
.81126 .7192 m .81152 .75628 L .83557 .75053 L p .707 .577 .707 r
F P
0 g
s
.83557 .75053 m .83531 .71344 L .81126 .7192 L p .707 .577 .707 r
F P
0 g
s
.69141 .71787 m .69168 .75495 L .71913 .75912 L p .707 .577 .707 r
F P
0 g
s
.73773 .80288 m .74259 .78557 L .71252 .77552 L p .707 .577 .707 r
F P
0 g
s
.74259 .78557 m .73773 .80288 L .76857 .80945 L p .707 .577 .707 r
F P
0 g
s
.76857 .80945 m .77343 .79215 L .74259 .78557 L p .707 .577 .707 r
F P
0 g
s
.52972 .243 m .54763 .74647 L .50365 .74538 L p .707 .577 .707 r
F P
0 g
s
.50365 .74538 m .48574 .24191 L .52972 .243 L p .707 .577 .707 r
F P
0 g
s
.69168 .75495 m .69141 .71787 L .67036 .71162 L p .707 .577 .707 r
F P
0 g
s
.70766 .79283 m .71252 .77552 L .68616 .76298 L p .707 .577 .707 r
F P
0 g
s
.71252 .77552 m .70766 .79283 L .73773 .80288 L p .707 .577 .707 r
F P
0 g
s
.77343 .79215 m .76857 .80945 L .79716 .81191 L p .707 .577 .707 r
F P
0 g
s
.79716 .81191 m .80202 .7946 L .77343 .79215 L p .707 .577 .707 r
F P
0 g
s
.66925 .68028 m .65969 .62456 L .64743 .6206 L p .707 .577 .707 r
F P
0 g
s
.68616 .76298 m .68131 .78029 L .70766 .79283 L p .707 .577 .707 r
F P
0 g
s
.67036 .71162 m .67062 .7487 L .69168 .75495 L p .707 .577 .707 r
F P
0 g
s
.83531 .71344 m .83557 .75053 L .85194 .74312 L p .707 .577 .707 r
F P
0 g
s
.85194 .74312 m .85168 .70604 L .83531 .71344 L p .707 .577 .707 r
F P
0 g
s
.8386 .59199 m .84815 .64771 L .85531 .64021 L p .707 .577 .707 r
F P
0 g
s
.85531 .64021 m .84575 .58449 L .8386 .59199 L p .707 .577 .707 r
F P
0 g
s
.68131 .78029 m .68616 .76298 L .6661 .74917 L p .707 .577 .707 r
F P
0 g
s
.64743 .6206 m .65699 .67632 L .66925 .68028 L p .707 .577 .707 r
F P
0 g
s
.80202 .7946 m .79716 .81191 L .82071 .81001 L p .707 .577 .707 r
F P
0 g
s
.82071 .81001 m .82556 .7927 L .80202 .7946 L p .707 .577 .707 r
F P
0 g
s
.6661 .74917 m .66125 .76648 L .68131 .78029 L p .707 .577 .707 r
F P
0 g
s
.67062 .7487 m .67036 .71162 L .65777 .7039 L p .707 .577 .707 r
F P
0 g
s
.65699 .67632 m .64743 .6206 L .64475 .61457 L p .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .6661 .74917 L .65891 .7408 L p .707 .577 .707 r
F P
0 g
s
.65891 .7408 m .6543 .73545 L p .66003 .76101 L .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .65891 .7408 L .66003 .76101 L .707 .577 .707 r
F
.65803 .74098 m .6579 .72263 L p .65487 .69546 L F P
0 g
s
.6579 .72263 m .65777 .7039 L .65669 .70075 L p .707 .577 .707 r
F P
0 g
s
.65669 .70075 m .65487 .69546 L p .6579 .72263 L .707 .577 .707 r
F P
0 g
s
.65777 .7039 m .65803 .74098 L .67062 .7487 L p .707 .577 .707 r
F P
0 g
s
.82556 .7927 m .82071 .81001 L .8369 .80393 L p .707 .577 .707 r
F P
0 g
s
.8369 .80393 m .84176 .78662 L .82556 .7927 L p .707 .577 .707 r
F P
0 g
s
.85168 .70604 m .85194 .74312 L .85903 .73479 L p .707 .577 .707 r
F P
0 g
s
.85903 .73479 m .85876 .69771 L .85168 .70604 L p .707 .577 .707 r
F P
0 g
s
.6543 .73545 m .64945 .75276 L .66125 .76648 L p .707 .577 .707 r
F P
0 g
s
.84575 .58449 m .85531 .64021 L .85263 .63419 L p .707 .577 .707 r
F P
0 g
s
.85263 .63419 m .84307 .57847 L .84575 .58449 L p .707 .577 .707 r
F P
0 g
s
.64475 .61457 m .65431 .67029 L .65699 .67632 L p .707 .577 .707 r
F P
0 g
s
.64945 .75276 m .6543 .73545 L .65191 .72316 L p .707 .577 .707 r
F P
0 g
s
.65191 .72316 m .64706 .74047 L .64945 .75276 L p .707 .577 .707 r
F P
0 g
s
.64706 .74047 m .65191 .72316 L .6541 .72026 L p .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65803 .74098 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65499 .7122 m .65513 .73254 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65487 .69546 m .65499 .7122 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65487 .69546 L .66195 .68713 L p .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .65513 .73254 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66195 .68713 m .66207 .70319 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66207 .70319 m .66222 .72421 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .66195 .68713 L .67832 .67973 L p .707 .577 .707 r
F P
0 g
s
.65432 .73082 m .65917 .71351 L .66446 .71152 L p .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .66222 .72421 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67832 .67973 m .67844 .69647 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67844 .69647 m .67859 .71681 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .67832 .67973 L .70237 .67397 L p .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .67537 .70743 L .68385 .70674 L p .707 .577 .707 r
F P
0 g
s
.70237 .67397 m .70264 .71106 L .67859 .71681 L p .707 .577 .707 r
F P
0 g
s
.68385 .70674 m .69891 .70553 L p .68734 .71336 L .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .68385 .70674 L .68734 .71336 L .707 .577 .707 r
F
.66446 .71152 m .67537 .70743 L p .6662 .71761 L F P
0 g
s
.65432 .73082 m .66446 .71152 L .6662 .71761 L .707 .577 .707 r
F
.6541 .72026 m .65917 .71351 L p .65343 .72628 L F P
0 g
s
.64706 .74047 m .6541 .72026 L .65343 .72628 L .707 .577 .707 r
F
.65431 .67029 m .64475 .61457 L .65191 .60708 L p F P
0 g
s
.84176 .78662 m .8369 .80393 L .84416 .79427 L p .707 .577 .707 r
F P
0 g
s
.84416 .79427 m .84902 .77697 L .84176 .78662 L p .707 .577 .707 r
F P
0 g
s
.85876 .69771 m .85903 .73479 L .85613 .72635 L p .707 .577 .707 r
F P
0 g
s
.85613 .72635 m .85587 .68927 L .85876 .69771 L p .707 .577 .707 r
F P
0 g
s
.40456 .59228 m .395 .53656 L .3643 .54014 L p .707 .577 .707 r
F P
0 g
s
.84307 .57847 m .85263 .63419 L .84038 .63022 L p .707 .577 .707 r
F P
0 g
s
.84038 .63022 m .83082 .57451 L .84307 .57847 L p .707 .577 .707 r
F P
0 g
s
.65191 .60708 m .66147 .66279 L .65431 .67029 L p .707 .577 .707 r
F P
0 g
s
.37385 .59586 m .3643 .54014 L .33731 .54123 L p .707 .577 .707 r
F P
0 g
s
.3643 .54014 m .37385 .59586 L .40456 .59228 L p .707 .577 .707 r
F P
0 g
s
.45546 .52355 m .46501 .57926 L .48885 .57109 L p .707 .577 .707 r
F P
0 g
s
.48885 .57109 m .47929 .51538 L .45546 .52355 L p .707 .577 .707 r
F P
0 g
s
.40729 .64122 m .40703 .60414 L .37586 .60246 L p .707 .577 .707 r
F P
0 g
s
.33731 .54123 m .34687 .59694 L .37385 .59586 L p .707 .577 .707 r
F P
0 g
s
.37612 .63954 m .37586 .60246 L .3484 .59829 L p .707 .577 .707 r
F P
0 g
s
.37586 .60246 m .37612 .63954 L .40729 .64122 L p .707 .577 .707 r
F P
0 g
s
.66147 .66279 m .65191 .60708 L .6682 .59884 L p .707 .577 .707 r
F P
0 g
s
.84902 .77697 m .84416 .79427 L .84177 .78199 L p .707 .577 .707 r
F P
0 g
s
.84177 .78199 m .84663 .76468 L .84902 .77697 L p .707 .577 .707 r
F P
0 g
s
.34687 .59694 m .33731 .54123 L .31668 .53971 L p .707 .577 .707 r
F P
0 g
s
.65917 .71351 m .65432 .73082 L .64706 .74047 L p .707 .577 .707 r
F P
0 g
s
.85587 .68927 m .85613 .72635 L .84354 .71863 L p .707 .577 .707 r
F P
0 g
s
.84354 .71863 m .84328 .68155 L .85587 .68927 L p .707 .577 .707 r
F P
0 g
s
.46825 .59962 m .46851 .6367 L .49256 .63095 L p .707 .577 .707 r
F P
0 g
s
.49256 .63095 m .4923 .59387 L .46825 .59962 L p .707 .577 .707 r
F P
0 g
s
.83082 .57451 m .84038 .63022 L .81975 .62871 L p .707 .577 .707 r
F P
0 g
s
.81975 .62871 m .81019 .57299 L .83082 .57451 L p .707 .577 .707 r
F P
0 g
s
.3484 .59829 m .34867 .63538 L .37612 .63954 L p .707 .577 .707 r
F P
0 g
s
.47929 .51538 m .48885 .57109 L .50515 .56286 L p .707 .577 .707 r
F P
0 g
s
.50515 .56286 m .49559 .50714 L .47929 .51538 L p .707 .577 .707 r
F P
0 g
s
.6682 .59884 m .67776 .65456 L .66147 .66279 L p .707 .577 .707 r
F P
0 g
s
.31668 .53971 m .32624 .59543 L .3281 .59557 L p .707 .577 .707 r
F P
0 g
s
.3281 .59557 m .34687 .59694 L p .33098 .56683 L .707 .577 .707 r
F P
0 g
s
.33098 .56683 m .31668 .53971 L .3281 .59557 L .707 .577 .707 r
F
.32624 .59543 m .31668 .53971 L .30442 .53575 L p F P
0 g
s
.30442 .53575 m .31398 .59147 L .315 .5918 L p .707 .577 .707 r
F P
0 g
s
.315 .5918 m .32624 .59543 L p .31581 .5669 L .707 .577 .707 r
F P
0 g
s
.31581 .5669 m .30442 .53575 L .315 .5918 L .707 .577 .707 r
F
.31398 .59147 m .30442 .53575 L .30174 .52973 L p F P
0 g
s
.30174 .52973 m .3113 .58544 L .31148 .58586 L p .707 .577 .707 r
F P
0 g
s
.31148 .58586 m .31398 .59147 L p .30831 .56286 L .707 .577 .707 r
F P
0 g
s
.30831 .56286 m .30174 .52973 L .31148 .58586 L .707 .577 .707 r
F
.31476 .58432 m .31186 .57588 L p .31435 .61171 L F P
0 g
s
.31484 .59649 m .31476 .58432 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .31476 .58432 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.31476 .58432 m .31502 .6214 L .32761 .62912 L p .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31894 .56755 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31195 .58926 L p .31502 .6214 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31212 .61296 L .31337 .61659 L p .707 .577 .707 r
F P
0 g
s
.31337 .61659 m .31502 .6214 L p .31195 .58926 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31186 .57588 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31502 .6214 m .31484 .59649 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.31894 .56755 m .31904 .58135 L p .31212 .61296 L .707 .577 .707 r
F P
0 g
s
.31904 .58135 m .31921 .60463 L .31626 .6081 L p .707 .577 .707 r
F P
0 g
s
.31626 .6081 m .31212 .61296 L p .31904 .58135 L .707 .577 .707 r
F P
0 g
s
.31921 .60463 m .31894 .56755 L .33531 .56015 L p .707 .577 .707 r
F P
0 g
s
.32519 .51399 m .32573 .5171 L p .31846 .57795 L .707 .577 .707 r
F P
0 g
s
.32742 .60234 m .32735 .59204 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.34867 .63538 m .3484 .59829 L .32735 .59204 L p .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .32761 .62912 L .34867 .63538 L p .707 .577 .707 r
F P
0 g
s
.33531 .56015 m .33541 .57353 L p .31921 .60463 L .707 .577 .707 r
F P
0 g
s
.33541 .57353 m .33557 .59723 L .3294 .60002 L p .707 .577 .707 r
F P
0 g
s
.3294 .60002 m .31921 .60463 L p .33541 .57353 L .707 .577 .707 r
F P
0 g
s
.33557 .59723 m .33531 .56015 L .35936 .55439 L p .707 .577 .707 r
F P
0 g
s
.34903 .50583 m .34977 .51014 L p .33475 .56971 L .707 .577 .707 r
F P
0 g
s
.35936 .55439 m .35945 .56657 L p .33557 .59723 L .707 .577 .707 r
F P
0 g
s
.35945 .56657 m .35963 .59148 L .35213 .59327 L p .707 .577 .707 r
F P
0 g
s
.35213 .59327 m .33557 .59723 L p .35945 .56657 L .707 .577 .707 r
F P
0 g
s
.35963 .59148 m .35936 .55439 L .38875 .55085 L p .707 .577 .707 r
F P
0 g
s
.37808 .49853 m .37809 .4986 L p .35859 .56154 L .707 .577 .707 r
F P
0 g
s
.38875 .55085 m .38882 .56115 L p .35963 .59148 L .707 .577 .707 r
F P
0 g
s
.38882 .56115 m .38901 .58794 L .38268 .5887 L p .707 .577 .707 r
F P
0 g
s
.38268 .5887 m .35963 .59148 L p .38882 .56115 L .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .37808 .49853 L .40381 .49384 L p .707 .577 .707 r
F P
0 g
s
.40381 .49384 m .40949 .49281 L p .39492 .53377 L .707 .577 .707 r
F P
0 g
s
.38901 .58794 m .38875 .55085 L .42058 .54987 L p .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .40381 .49384 L .39492 .53377 L .707 .577 .707 r
F
.37809 .4986 m .38763 .55424 L .36099 .56094 L p F P
0 g
s
.36099 .56094 m .35859 .56154 L p .37809 .4986 L .707 .577 .707 r
F P
0 g
s
.34977 .51014 m .35859 .56154 L .3364 .56915 L p .707 .577 .707 r
F P
0 g
s
.3364 .56915 m .33475 .56971 L p .34977 .51014 L .707 .577 .707 r
F P
0 g
s
.32573 .5171 m .33475 .56971 L .31945 .57745 L p .707 .577 .707 r
F P
0 g
s
.31945 .57745 m .31846 .57795 L p .32573 .5171 L .707 .577 .707 r
F P
0 g
s
.3089 .52223 m .31846 .57795 L .31173 .58499 L p .707 .577 .707 r
F P
0 g
s
.31173 .58499 m .3113 .58544 L p .31004 .55215 L .707 .577 .707 r
F P
0 g
s
.31004 .55215 m .3089 .52223 L .31173 .58499 L .707 .577 .707 r
F
.31212 .61296 m .31195 .58926 L p .31374 .60219 L F P
0 g
s
.32761 .62912 m .32742 .60234 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.39472 .6964 m .39958 .67909 L .36951 .66904 L p .707 .577 .707 r
F P
0 g
s
.39958 .67909 m .39472 .6964 L .42556 .70298 L p .707 .577 .707 r
F P
0 g
s
.42556 .70298 m .43042 .68567 L .39958 .67909 L p .707 .577 .707 r
F P
0 g
s
.36465 .68635 m .36951 .66904 L .34315 .6565 L p .707 .577 .707 r
F P
0 g
s
.36951 .66904 m .36465 .68635 L .39472 .6964 L p .707 .577 .707 r
F P
0 g
s
.43042 .68567 m .42556 .70298 L .45415 .70543 L p .707 .577 .707 r
F P
0 g
s
.67776 .65456 m .6682 .59884 L .69204 .59067 L p .707 .577 .707 r
F P
0 g
s
.34315 .6565 m .3383 .67381 L .36465 .68635 L p .707 .577 .707 r
F P
0 g
s
.4923 .59387 m .49256 .63095 L .50893 .62354 L p .707 .577 .707 r
F P
0 g
s
.50893 .62354 m .50867 .58646 L .4923 .59387 L p .707 .577 .707 r
F P
0 g
s
.84663 .76468 m .84177 .78199 L .82997 .76827 L p .707 .577 .707 r
F P
0 g
s
.82997 .76827 m .83483 .75096 L .84663 .76468 L p .707 .577 .707 r
F P
0 g
s
.3383 .67381 m .34315 .6565 L .32309 .64269 L p .707 .577 .707 r
F P
0 g
s
.81019 .57299 m .81975 .62871 L .79276 .6298 L p .707 .577 .707 r
F P
0 g
s
.79276 .6298 m .7832 .57408 L .81019 .57299 L p .707 .577 .707 r
F P
0 g
s
.67537 .70743 m .67051 .72474 L .65432 .73082 L p .707 .577 .707 r
F P
0 g
s
.84328 .68155 m .84354 .71863 L .82248 .71238 L p .707 .577 .707 r
F P
0 g
s
.82248 .71238 m .82222 .6753 L .84328 .68155 L p .707 .577 .707 r
F P
0 g
s
.45901 .68812 m .45415 .70543 L .4777 .70353 L p .707 .577 .707 r
F P
0 g
s
.4777 .70353 m .48255 .68622 L .45901 .68812 L p .707 .577 .707 r
F P
0 g
s
.49559 .50714 m .50515 .56286 L .5123 .55536 L p .707 .577 .707 r
F P
0 g
s
.5123 .55536 m .50274 .49965 L .49559 .50714 L p .707 .577 .707 r
F P
0 g
s
.69204 .59067 m .7016 .64639 L .67776 .65456 L p .707 .577 .707 r
F P
0 g
s
.32309 .64269 m .31824 .66 L .3383 .67381 L p .707 .577 .707 r
F P
0 g
s
.7016 .64639 m .69204 .59067 L .72109 .58337 L p .707 .577 .707 r
F P
0 g
s
.7832 .57408 m .79276 .6298 L .76206 .63337 L p .707 .577 .707 r
F P
0 g
s
.76206 .63337 m .7525 .57766 L .7832 .57408 L p .707 .577 .707 r
F P
0 g
s
.50867 .58646 m .50893 .62354 L .51602 .61522 L p .707 .577 .707 r
F P
0 g
s
.51602 .61522 m .51575 .57813 L .50867 .58646 L p .707 .577 .707 r
F P
0 g
s
.31824 .66 m .32309 .64269 L .31129 .62897 L p .707 .577 .707 r
F P
0 g
s
.83483 .75096 m .82997 .76827 L .80991 .75446 L p .707 .577 .707 r
F P
0 g
s
.80991 .75446 m .81477 .73715 L .83483 .75096 L p .707 .577 .707 r
F P
0 g
s
.82222 .6753 m .82248 .71238 L .79503 .70821 L p .707 .577 .707 r
F P
0 g
s
.79503 .70821 m .79476 .67113 L .82222 .6753 L p .707 .577 .707 r
F P
0 g
s
.48255 .68622 m .4777 .70353 L .49389 .69745 L p .707 .577 .707 r
F P
0 g
s
.49389 .69745 m .49875 .68014 L .48255 .68622 L p .707 .577 .707 r
F P
0 g
s
.73064 .63909 m .72109 .58337 L .7525 .57766 L p .707 .577 .707 r
F P
0 g
s
.72109 .58337 m .73064 .63909 L .7016 .64639 L p .707 .577 .707 r
F P
0 g
s
.7525 .57766 m .76206 .63337 L .73064 .63909 L p .707 .577 .707 r
F P
0 g
s
.69891 .70553 m .69406 .72284 L .67051 .72474 L p .707 .577 .707 r
F P
0 g
s
.31129 .62897 m .30644 .64628 L .31824 .66 L p .707 .577 .707 r
F P
0 g
s
.70264 .71106 m .70237 .67397 L .73176 .67043 L p .707 .577 .707 r
F P
0 g
s
.50274 .49965 m .5123 .55536 L .50962 .54934 L p .707 .577 .707 r
F P
0 g
s
.50962 .54934 m .50006 .49362 L .50274 .49965 L p .707 .577 .707 r
F P
0 g
s
.79476 .67113 m .79503 .70821 L .76385 .70654 L p .707 .577 .707 r
F P
0 g
s
.76385 .70654 m .76359 .66945 L .79476 .67113 L p .707 .577 .707 r
F P
0 g
s
.73176 .67043 m .73202 .70752 L .70264 .71106 L p .707 .577 .707 r
F P
0 g
s
.69406 .72284 m .69891 .70553 L .7275 .70798 L p .707 .577 .707 r
F P
0 g
s
.73202 .70752 m .73176 .67043 L .76359 .66945 L p .707 .577 .707 r
F P
0 g
s
.81477 .73715 m .80991 .75446 L .78356 .74192 L p .707 .577 .707 r
F P
0 g
s
.78356 .74192 m .78841 .72461 L .81477 .73715 L p .707 .577 .707 r
F P
0 g
s
.76359 .66945 m .76385 .70654 L .73202 .70752 L p .707 .577 .707 r
F P
0 g
s
.30644 .64628 m .31129 .62897 L .3089 .61668 L p .707 .577 .707 r
F P
0 g
s
.7275 .70798 m .72265 .72529 L .69406 .72284 L p .707 .577 .707 r
F P
0 g
s
.51575 .57813 m .51602 .61522 L .51312 .60678 L p .707 .577 .707 r
F P
0 g
s
.51312 .60678 m .51286 .56969 L .51575 .57813 L p .707 .577 .707 r
F P
0 g
s
.49875 .68014 m .49389 .69745 L .50115 .6878 L p .707 .577 .707 r
F P
0 g
s
.50115 .6878 m .50601 .67049 L .49875 .68014 L p .707 .577 .707 r
F P
0 g
s
.3089 .61668 m .30405 .63399 L .30644 .64628 L p .707 .577 .707 r
F P
0 g
s
.3113 .58544 m .30174 .52973 L .3089 .52223 L p .707 .577 .707 r
F P
0 g
s
.72265 .72529 m .7275 .70798 L .75834 .71456 L p .707 .577 .707 r
F P
0 g
s
.78841 .72461 m .78356 .74192 L .75349 .73187 L p .707 .577 .707 r
F P
0 g
s
.75349 .73187 m .75834 .71456 L .78841 .72461 L p .707 .577 .707 r
F P
0 g
s
.75834 .71456 m .75349 .73187 L .72265 .72529 L p .707 .577 .707 r
F P
0 g
s
.50006 .49362 m .50962 .54934 L .49737 .54537 L p .707 .577 .707 r
F P
0 g
s
.49737 .54537 m .48781 .48966 L .50006 .49362 L p .707 .577 .707 r
F P
0 g
s
.30405 .63399 m .3089 .61668 L .31616 .60703 L p .707 .577 .707 r
F P
0 g
s
.50601 .67049 m .50115 .6878 L .49876 .67551 L p .707 .577 .707 r
F P
0 g
s
.49876 .67551 m .50362 .6582 L .50601 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.51286 .56969 m .51312 .60678 L .50053 .59905 L p .707 .577 .707 r
F P
0 g
s
.50053 .59905 m .50026 .56197 L .51286 .56969 L p .707 .577 .707 r
F P
0 g
s
.31616 .60703 m .31131 .62434 L .30405 .63399 L p .707 .577 .707 r
F P
0 g
s
.31846 .57795 m .3089 .52223 L .32519 .51399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48781 .48966 m .49737 .54537 L .47674 .54386 L p .707 .577 .707 r
F P
0 g
s
.47674 .54386 m .46718 .48815 L .48781 .48966 L p .707 .577 .707 r
F P
0 g
s
.31131 .62434 m .31616 .60703 L .33236 .60095 L p .707 .577 .707 r
F P
0 g
s
.50026 .56197 m .50053 .59905 L .47947 .5928 L p .707 .577 .707 r
F P
0 g
s
.47947 .5928 m .47921 .55572 L .50026 .56197 L p .707 .577 .707 r
F P
0 g
s
.50362 .6582 m .49876 .67551 L .48696 .66179 L p .707 .577 .707 r
F P
0 g
s
.48696 .66179 m .49182 .64448 L .50362 .6582 L p .707 .577 .707 r
F P
0 g
s
.33475 .56971 m .32519 .51399 L .34903 .50583 L p .707 .577 .707 r
F P
0 g
s
.33236 .60095 m .3275 .61826 L .31131 .62434 L p .707 .577 .707 r
F P
0 g
s
.46718 .48815 m .47674 .54386 L .44975 .54495 L p .707 .577 .707 r
F P
0 g
s
.44975 .54495 m .44019 .48923 L .46718 .48815 L p .707 .577 .707 r
F P
0 g
s
.35859 .56154 m .34903 .50583 L .37808 .49853 L p .707 .577 .707 r
F P
0 g
s
.47921 .55572 m .47947 .5928 L .45202 .58863 L p .707 .577 .707 r
F P
0 g
s
.45202 .58863 m .45175 .55155 L .47921 .55572 L p .707 .577 .707 r
F P
0 g
s
.3275 .61826 m .33236 .60095 L .3559 .59905 L p .707 .577 .707 r
F P
0 g
s
.49182 .64448 m .48696 .66179 L .4669 .64798 L p .707 .577 .707 r
F P
0 g
s
.4669 .64798 m .47176 .63067 L .49182 .64448 L p .707 .577 .707 r
F P
0 g
s
.44019 .48923 m .44975 .54495 L .41905 .54852 L p .707 .577 .707 r
F P
0 g
s
.41905 .54852 m .40949 .49281 L .44019 .48923 L p .707 .577 .707 r
F P
0 g
s
.3559 .59905 m .35105 .61636 L .3275 .61826 L p .707 .577 .707 r
F P
0 g
s
.40949 .49281 m .41905 .54852 L .38763 .55424 L p .707 .577 .707 r
F P
0 g
s
.45175 .55155 m .45202 .58863 L .42084 .58696 L p .707 .577 .707 r
F P
0 g
s
.42084 .58696 m .42058 .54987 L .45175 .55155 L p .707 .577 .707 r
F P
0 g
s
.35105 .61636 m .3559 .59905 L .38449 .6015 L p .707 .577 .707 r
F P
0 g
s
.42058 .54987 m .42084 .58696 L .38901 .58794 L p .707 .577 .707 r
F P
0 g
s
.47176 .63067 m .4669 .64798 L .44055 .63544 L p .707 .577 .707 r
F P
0 g
s
.44055 .63544 m .4454 .61813 L .47176 .63067 L p .707 .577 .707 r
F P
0 g
s
.38449 .6015 m .37964 .61881 L .35105 .61636 L p .707 .577 .707 r
F P
0 g
s
.37964 .61881 m .38449 .6015 L .41533 .60808 L p .707 .577 .707 r
F P
0 g
s
.4454 .61813 m .44055 .63544 L .41048 .62539 L p .707 .577 .707 r
F P
0 g
s
.41048 .62539 m .41533 .60808 L .4454 .61813 L p .707 .577 .707 r
F P
0 g
s
.41533 .60808 m .41048 .62539 L .37964 .61881 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Uoo`L008eo
o`00Ngoo3P0000=JEP00FUH015YF3000PGoo001eOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH8001iOol006moo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00@007Eoo`00JWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00LWoo001WOol30007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001`Ool006Eo
o`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF008006ioo`00Hgoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Jgoo001QOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1[Ool0061o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool0
05ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00OomJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP0DFUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVaoo`00GWoo00@005YFFUH000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFK7oo001NOol01000FUIJEP001UYF00<0
05YFFUH04eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUI/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1Z
Ool005ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00GWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Jgoo001NOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001[Ool005ioo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Yoo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJgoo001OOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005moo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Uo
o`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00
Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YF00001@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00eYF20000eYF00<0
05YFFUH01P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH00eYF2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00000P002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000
FUIJEP001EYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YF
FUH0009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061oo`03
001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JWoo001N
Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Yoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Moo`8000=JEP03001JEUYF00AJEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Ioo`80
00AJEP8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EGoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Uoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
30000eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uo
o`00EWoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH015YF1P0000=JEP0000001eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JGoo001FOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH@0006FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001YOol005Ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo001FOol01000FUIJEP0015YF00<0
05YFFUH015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEPD0
00AJEP8000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00<0
05YF000015YF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P0025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo
001GOol00`00FUH00005FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol005Moo`03001JEP0000EJEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00@005YFFUH000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000_Ool6000d
Ool005Moo`05001JEUYF001JEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P009Woo2@000eYF00<005YFFUH01@00;goo001HOol01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P007Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002eo
o`00DWoo2@0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P005goo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00B7oo2P0015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`@00003FUH005YF00MJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00@goo1@00
1EYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH:0002FUH5
00000eYF000000060004FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo0011Ool200000eYF001JEP07FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH02@0015YF1`002UYF00@005YFFUIJEPH000AJ
EP03001JEUYF008000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000/Ool003ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH0
0004FUH@0005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH6000015YF001JEUYF0P001UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo0P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000k
Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP0=00000eYF001JEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP040004FUH01000FUH000000UYF0P001eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002Goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000gOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001UYF00000000FUH000IJEP04001JEUYF
FUHA0006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF10001eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000dOol30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005Ool20002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000[Ool0039oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEP000006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0017oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002]oo`00<7oo0P000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
0eYF00<005YFFUH00UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002]oo`00;goo0P0015YF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
0P000eYF4P001eYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH20008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000ZOol002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800005FUH00000FUH00005FUH00`00FUIJEP04FUH0
1000FUIJEUYF10000UYF00<005YFFUH01eYF10000eYF00<005YFFUH015YF00@005YFFUIJEP8000QJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001oogooOol00002FUH01@00FUIJ
EUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH01UYF00@005YFFUIoo`EJEP03001JEUYF00EJEPD00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEP@000QJEP03001JEUYF0080009JEP03001JEUYF00AJEP05001JEUYFFUH00009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00Oomoogoo00000UYF00D005YFFUIJ
EP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002Yoo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP<000AJEP03001JEUYF00AJEP03001JEUYF
009JEP<00004FUH005YFFUH30004FUH00`00FUIJEP03FUH30006FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D007ooOomoo`00009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF
FUIJEP0002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF10001EYF0`0000=JEP00FUH01EYF00@005YFFUIJEPH000EJEP<00003FUH0
05YF00IJEP8000AJEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPP000IJEPD0009JEP03001oogoo02Qoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEPX000=JEP04001JEUYFFUH6
0008FUH20008FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000YOol002moo`03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP<000AJEP80009JEP03
001JEP0000`000YJEP8000EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo
000_Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90002FUH0
1@00FUIJEUYF00001EYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEP`000EJEP8000=JEP03001J
EUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000:Goo000_Ool01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF1P0015YF00<005YFFUH00UYF0`000eYF0`000eYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF10001UYF00@005YFFUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000ZOol002moo`04001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEPD0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP04001JEUYF0006FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000[Ool0031oo`03001J
EP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYFFUH20004FUH0
1000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo00@005YF
FUH000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01000FUH00000;Goo000`Ool00`00FUH00005FUH01000FUIJEUYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`05001JEUYFFUH00003FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000_Ool0
031oo`03001JEP0000EJEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH300000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH30004FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool3FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00<Woo000`Ool01000FUIJEP000eYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF008000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`=JEP8000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00<7oo00D005YFFUH005YF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600001EYF000005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Goo000aOol0
1000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`001eYF10002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P00
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00EJEQP003Yoo`00<Goo0`0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF0000
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUH00005
0003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000fOol0035oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEP000002FUH01000
FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@00
<Goo000aOol00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF6P0015YF10000eYF00<005YF
FUH015YF1`002eYF00<005YFFUH02EYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000eYF00@005YFFUIJEPH000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00@002eoo`00<Goo00<005YF000015YF00@005YFFUIJEPP0
00AJEPL000ioo`H0009JEP<000IJEPD000=JEPD000IJEP03001JEUYF00MJEP@000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP8002aoo`00
<Goo00<005YF000015YF00<005YF00003@006Woo00D005YFFUH005YF008000EJEPD000MJEP03001J
EP0000h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04
001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:Woo000aOol00`00FUH00002FUH40000
0eYF00000005000HOol90002FUH01000FUIJEUYF0`000UYF1@001UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Uoo`00<Goo00<005YF0000
1`000eYF00@005YFFUIJEQP000AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH0000YOol0035oo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00@000QJ
EP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002Qoo`00<Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
100015YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEPT0
00AJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00:7oo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0
00040008FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01EYF
30001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
0P0000=JEP00FUH00UYF2P001UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002Qoo`00<7oo0P000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH015YF
0`001UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH200000eYF001JEP030005FUH01000FUIJEUYF2`0027oo200015YF00<005YFFUH00eYF00@005YF
FUIJEP8002Qoo`00<7oo0P0000EJEP00001JEP0000EJEP04001JEUYFFUH70007FUH00`00FUIJEP06
FUH30004FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEPD00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@0011oo`H000AJEP04001JEUYF
FUH2000XOol0031oo`@0009JEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH40002FUH0
0`00FUIJEP07FUH00`00FUIJEP020002FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00AJEP@000moo`H00003FUH005YF009JEP8002Qoo`00;goo0`000Woo0`001EYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH00eYF0`000eYF00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF01MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP00008000Moo`D000EJEP<000=JEP8002Qoo`00;goo0`0017oo0`000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF10000UYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF009JEP04001JEUYFFUH70004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000X
Ool002moo`04001JEP000006Ool50005FUH01000FUIJEUYF1P001eYF0`0025YF10000eYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01P000UYF00<005YFFUH00UYF1`001UYF00<0
05YFFUH01UYF0`0015YF00<005YFFUH015YF00<005YFFUH00UYF0`00:7oo000_Ool20002FUH00`00
Oomoo`08Ool400000eYF001JEP02FUH60008FUH01000FUH000001EYF00<005YFFUH00P000eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF
009JEP<002Qoo`00<7oo00D005YFFUIJEP0000eooaT000=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40007FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0000XOol0031oo`04
001JEUYFFUH3000AOol3000@Ool30004FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000000`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF0P00:Goo000aOol01000FUIJEP000UYF00<0
07ooOol08goo00<007ooFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF01IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000QJ
EP<000=JEP03001JEUYF009JEP8002Uoo`00<Goo00<005YF000015YF0P0097oo0P000UYF00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF011JEP`000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800004FUH005YF0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH30006FUH01000FUIJEP000UYF00@005YFFUIJEP8002Yoo`00<Woo0P001UYF
00<007ooOol08goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF
2@0035YF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF
0`0000=JEP000000;7oo000cOol00`00FUIJEP04FUH3000TOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00UYF0P0000IJEP00000005YF0007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH2000^Ool003Aoo`8000AJEP03001JEUYF
008002Aoo`=JEP03001JEUYF00=JEP03001JEUYF00AJEPL0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF009JEP80009JEP06001JEUYF
FUH005YF100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P001UYF0P00;Woo000fOol01000FUIJEP001EYF0P008Woo0eYF00<005YFFUH00eYF00<005YFFUH0
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
00000P0015YF0`000UYF00@005YFFUH000=JEP8000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD000AJEP03001JEP0002ioo`00=goo0`001eYF0`007goo0eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF0`000UYF0P001eYF0P003Goo4P001Goo0P000UYF00@005YFFUH002eo
o`00>Goo00<005YFFUH01UYF00@005YF000001eoo`=JEP04001JEUYFFUH20006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH:0007FUH3000TOol20004FUH00`00Oomoo`0ZOol003Yoo`8000EJEP03001JEUYF009JEP<001Yo
o`=JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YF000000AJEP04001J
EUYFFUH2000SOol00`00FUIJEP02FUH00`00Oomoo`0ZOol003aoo`8000=JEP03001JEUYF00AJEPD0
01Ioo`=JEP8000EJEP03OomJEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P008Woo00@005YFFUIJEP8002]oo`00?Woo0`001UYF1@0000=JEP00
00000P004Woo0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF009J
EP<000QJEP80025oo`05001JEP00FUH0000[Ool0041oo`8000EJEPD000EJEQ800003FUH005YF00]J
EP03Ool005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH00002
000OOol200000eYF001oo`0ZOol0049oo`<0009JEPD000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00EJEP8000IJEP03001J
EUYF009JEP<001eoo`8002aoo`00AGoo1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
000000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP06
FUH3000IOol3000/Ool004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006
FUH00gooFUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH025YF00<005YF00000`004goo0P0000=JEP00Ool0;7oo001;Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00002000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30007FUH00`00FUIJEP04FUHC0002FUH2000]Ool004mooa<0009oo`8000AJEP03
OomJEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Woo001VOol2000:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH0000@0004FUH00`00FUIJEP03FUH01000FUIJEUYF100000=J
EP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo001XOol20008FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH5
000@Ool60004FUH01000FUIJEUYF0P000Woo10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00JGoo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH010001EYF10004Goo100000=JEP00FUH00UYF0P001Woo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000031oo`00K7oo10000UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=JEP00FUH025YF00<005YF0000
0P001goo1`000eYF0`000eYF0P002Woo4`00<Woo001`Ool80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000Cgoo001hOol;0006FUH00`00FUIJEP04FUH;0002FUH00`00
FUIJEP02FUH70006FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001?
Ool008=oo`d00003OomJEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH4
0002FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0`00Cgoo
002AOol40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40007FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0001?Ool0091oo`D0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00AJEP8000EJEP03001J
EUYF009JEP03001JEP0004moo`00T7oo00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF0`000eYF00<005YFFUH00UYF
0P00D7oo002@Ool00`00FUH00002FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30007FUH01000FUIJEP000UYF00@005YFFUIJEP80055oo`00T7oo00<005YFFUH0
0UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03
001JEUYF009JEP<00003FUH0000005=oo`00TGoo00<005YFOol00UYF10000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00EJEP8005Eoo`00TGoo
00<005YFFUH00UYF0`0000=oo`0000000`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0P001UYF0P00EGoo002BOol01000FUIJEP000eYF00<007ooOol00goo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0015YF00<005YF0000EGoo002BOol01000FUIJ
EP0015YF0P001goo6@001Goo0P000UYF00@005YFFUH005Aoo`00Tgoo00<005YFFUH01UYF0P009Goo
0P0015YF00<007ooOol0DGoo002DOol00`00FUIJEP05FUH01000FUH0000097oo00<005YFFUH00UYF
00<007ooOol0DGoo002EOol20004FUH00`00FUIJEP02FUH2000SOol01@00FUIJEUYF0000Dgoo002G
Ool01@00FUIJEUYF00001UYF0`008Goo00D005YF001JEP00059oo`00V7oo0`0025YF00<005YF0000
0P007goo0P0000=JEP00Ool0DGoo002JOol20007FUH00`00FUIJEP02FUH3000MOol00`00FUH0001B
Ool009aoo`8000AJEP03001JEUYF00IJEP<001Uoo`<005=oo`00WWoo0`0000=JEP00FUH025YF00<0
05YF00000`004goo0P0000=JEP000000Dgoo002QOol30007FUH00`00FUIJEP04FUH60008Ool50002
FUH2001DOol00:Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00
E7oo002VOol300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001E
Ool00:Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:eoo`@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol00;5oo`H000AJEP04001JEUYF
FUH5001IOol00;Moo`P005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61036 .76917 m .6008 .71345 L .5701 .71703 L p .707 .577 .707 r
F P
0 g
s
.6008 .71345 m .61036 .76917 L .64177 .76345 L p .707 .577 .707 r
F P
0 g
s
.64177 .76345 m .63221 .70773 L .6008 .71345 L p .707 .577 .707 r
F P
0 g
s
.63221 .70773 m .64177 .76345 L .67082 .75615 L p .707 .577 .707 r
F P
0 g
s
.67082 .75615 m .66126 .70043 L .63221 .70773 L p .707 .577 .707 r
F P
0 g
s
.57966 .77274 m .5701 .71703 L .54311 .71811 L p .707 .577 .707 r
F P
0 g
s
.5701 .71703 m .57966 .77274 L .61036 .76917 L p .707 .577 .707 r
F P
0 g
s
.66126 .70043 m .67082 .75615 L .69466 .74798 L p .707 .577 .707 r
F P
0 g
s
.69466 .74798 m .6851 .69226 L .66126 .70043 L p .707 .577 .707 r
F P
0 g
s
.54311 .71811 m .55267 .77383 L .57966 .77274 L p .707 .577 .707 r
F P
0 g
s
.6131 .85284 m .61284 .81575 L .58167 .81408 L p .707 .577 .707 r
F P
0 g
s
.61284 .81575 m .6131 .85284 L .64494 .85186 L p .707 .577 .707 r
F P
0 g
s
.64494 .85186 m .64467 .81477 L .61284 .81575 L p .707 .577 .707 r
F P
0 g
s
.55267 .77383 m .54311 .71811 L .52248 .7166 L p .707 .577 .707 r
F P
0 g
s
.64467 .81477 m .64494 .85186 L .67432 .84832 L p .707 .577 .707 r
F P
0 g
s
.67432 .84832 m .67405 .81123 L .64467 .81477 L p .707 .577 .707 r
F P
0 g
s
.58193 .85116 m .58167 .81408 L .55421 .80991 L p .707 .577 .707 r
F P
0 g
s
.58167 .81408 m .58193 .85116 L .6131 .85284 L p .707 .577 .707 r
F P
0 g
s
.6851 .69226 m .69466 .74798 L .71095 .73975 L p .707 .577 .707 r
F P
0 g
s
.71095 .73975 m .70139 .68403 L .6851 .69226 L p .707 .577 .707 r
F P
0 g
s
.52248 .7166 m .53204 .77232 L .55267 .77383 L p .707 .577 .707 r
F P
0 g
s
.67405 .81123 m .67432 .84832 L .69837 .84256 L p .707 .577 .707 r
F P
0 g
s
.69837 .84256 m .69811 .80548 L .67405 .81123 L p .707 .577 .707 r
F P
0 g
s
.55421 .80991 m .55447 .84699 L .58193 .85116 L p .707 .577 .707 r
F P
0 g
s
.60053 .89492 m .60538 .87761 L .57531 .86756 L p .707 .577 .707 r
F P
0 g
s
.60538 .87761 m .60053 .89492 L .63137 .90149 L p .707 .577 .707 r
F P
0 g
s
.63137 .90149 m .63622 .88418 L .60538 .87761 L p .707 .577 .707 r
F P
0 g
s
.55447 .84699 m .55421 .80991 L .53315 .80366 L p .707 .577 .707 r
F P
0 g
s
.57046 .88487 m .57531 .86756 L .54896 .85501 L p .707 .577 .707 r
F P
0 g
s
.57531 .86756 m .57046 .88487 L .60053 .89492 L p .707 .577 .707 r
F P
0 g
s
.63622 .88418 m .63137 .90149 L .65996 .90395 L p .707 .577 .707 r
F P
0 g
s
.65996 .90395 m .66481 .88664 L .63622 .88418 L p .707 .577 .707 r
F P
0 g
s
.53204 .77232 m .52248 .7166 L .51023 .71264 L p .707 .577 .707 r
F P
0 g
s
.54896 .85501 m .54411 .87232 L .57046 .88487 L p .707 .577 .707 r
F P
0 g
s
.53315 .80366 m .53342 .84074 L .55447 .84699 L p .707 .577 .707 r
F P
0 g
s
.69811 .80548 m .69837 .84256 L .71474 .83516 L p .707 .577 .707 r
F P
0 g
s
.71474 .83516 m .71447 .79808 L .69811 .80548 L p .707 .577 .707 r
F P
0 g
s
.70139 .68403 m .71095 .73975 L .71811 .73225 L p .707 .577 .707 r
F P
0 g
s
.71811 .73225 m .70855 .67653 L .70139 .68403 L p .707 .577 .707 r
F P
0 g
s
.54411 .87232 m .54896 .85501 L .5289 .84121 L p .707 .577 .707 r
F P
0 g
s
.51023 .71264 m .51979 .76835 L .53204 .77232 L p .707 .577 .707 r
F P
0 g
s
.66481 .88664 m .65996 .90395 L .6835 .90204 L p .707 .577 .707 r
F P
0 g
s
.6835 .90204 m .68836 .88474 L .66481 .88664 L p .707 .577 .707 r
F P
0 g
s
.5289 .84121 m .52405 .85852 L .54411 .87232 L p .707 .577 .707 r
F P
0 g
s
.53342 .84074 m .53315 .80366 L .52056 .79594 L p .707 .577 .707 r
F P
0 g
s
.51979 .76835 m .51023 .71264 L .50755 .70661 L p .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5289 .84121 L .5217 .83284 L p .707 .577 .707 r
F P
0 g
s
.5217 .83284 m .5171 .82749 L p .52282 .85305 L .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5217 .83284 L .52282 .85305 L .707 .577 .707 r
F
.52083 .83302 m .52069 .81467 L p .51767 .7875 L F P
0 g
s
.52069 .81467 m .52056 .79594 L .51948 .79279 L p .707 .577 .707 r
F P
0 g
s
.51948 .79279 m .51767 .7875 L p .52069 .81467 L .707 .577 .707 r
F P
0 g
s
.52056 .79594 m .52083 .83302 L .53342 .84074 L p .707 .577 .707 r
F P
0 g
s
.68836 .88474 m .6835 .90204 L .6997 .89597 L p .707 .577 .707 r
F P
0 g
s
.6997 .89597 m .70455 .87866 L .68836 .88474 L p .707 .577 .707 r
F P
0 g
s
.71447 .79808 m .71474 .83516 L .72182 .82683 L p .707 .577 .707 r
F P
0 g
s
.72182 .82683 m .72156 .78975 L .71447 .79808 L p .707 .577 .707 r
F P
0 g
s
.5171 .82749 m .51224 .8448 L .52405 .85852 L p .707 .577 .707 r
F P
0 g
s
.70855 .67653 m .71811 .73225 L .71543 .72622 L p .707 .577 .707 r
F P
0 g
s
.71543 .72622 m .70587 .67051 L .70855 .67653 L p .707 .577 .707 r
F P
0 g
s
.50755 .70661 m .51711 .76233 L .51979 .76835 L p .707 .577 .707 r
F P
0 g
s
.48447 .81944 m .46656 .31597 L .42258 .31488 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .52083 .83302 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51767 .7875 m .51778 .80424 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51778 .80424 m .51793 .82458 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51224 .8448 m .5171 .82749 L .51471 .8152 L p .707 .577 .707 r
F P
0 g
s
.51471 .8152 m .50986 .83251 L .51224 .8448 L p .707 .577 .707 r
F P
0 g
s
.50986 .83251 m .51471 .8152 L .5169 .81229 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .51767 .7875 L .52475 .77917 L p .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .51793 .82458 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52475 .77917 m .52486 .79522 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52486 .79522 m .52501 .81625 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .52475 .77917 L .54112 .77176 L p .707 .577 .707 r
F P
0 g
s
.51711 .82285 m .52197 .80555 L .52725 .80356 L p .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .52501 .81625 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54112 .77176 m .54124 .78851 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54124 .78851 m .54138 .80885 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .54112 .77176 L .56517 .76601 L p .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .53816 .79947 L .54665 .79878 L p .707 .577 .707 r
F P
0 g
s
.56517 .76601 m .56543 .80309 L .54138 .80885 L p .707 .577 .707 r
F P
0 g
s
.54665 .79878 m .56171 .79757 L p .55013 .80539 L .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .54665 .79878 L .55013 .80539 L .707 .577 .707 r
F
.52725 .80356 m .53816 .79947 L p .529 .80965 L F P
0 g
s
.51711 .82285 m .52725 .80356 L .529 .80965 L .707 .577 .707 r
F
.5169 .81229 m .52197 .80555 L p .51623 .81832 L F P
0 g
s
.50986 .83251 m .5169 .81229 L .51623 .81832 L .707 .577 .707 r
F
.51711 .76233 m .50755 .70661 L .5147 .69912 L p F P
0 g
s
.5147 .69912 m .52426 .75483 L .51711 .76233 L p .707 .577 .707 r
F P
0 g
s
.52197 .80555 m .51711 .82285 L .50986 .83251 L p .707 .577 .707 r
F P
0 g
s
.53816 .79947 m .53331 .81678 L .51711 .82285 L p .707 .577 .707 r
F P
0 g
s
.46656 .31597 m .48447 .81944 L .52938 .8169 L p .707 .577 .707 r
F P
0 g
s
.52426 .75483 m .5147 .69912 L .531 .69088 L p .707 .577 .707 r
F P
0 g
s
.531 .69088 m .54056 .7466 L .52426 .75483 L p .707 .577 .707 r
F P
0 g
s
.52938 .8169 m .51148 .31344 L .46656 .31597 L p .707 .577 .707 r
F P
0 g
s
.54056 .7466 m .531 .69088 L .55484 .68271 L p .707 .577 .707 r
F P
0 g
s
.55484 .68271 m .56439 .73843 L .54056 .7466 L p .707 .577 .707 r
F P
0 g
s
.56439 .73843 m .55484 .68271 L .58388 .67541 L p .707 .577 .707 r
F P
0 g
s
.56171 .79757 m .55685 .81487 L .53331 .81678 L p .707 .577 .707 r
F P
0 g
s
.56543 .80309 m .56517 .76601 L .59455 .76247 L p .707 .577 .707 r
F P
0 g
s
.59455 .76247 m .59482 .79955 L .56543 .80309 L p .707 .577 .707 r
F P
0 g
s
.55685 .81487 m .56171 .79757 L .5903 .80002 L p .707 .577 .707 r
F P
0 g
s
.5903 .80002 m .58544 .81733 L .55685 .81487 L p .707 .577 .707 r
F P
0 g
s
.51148 .31344 m .52938 .8169 L .57084 .81099 L p .707 .577 .707 r
F P
0 g
s
.58388 .67541 m .59344 .73113 L .56439 .73843 L p .707 .577 .707 r
F P
0 g
s
.57084 .81099 m .55294 .30753 L .51148 .31344 L p .707 .577 .707 r
F P
0 g
s
.70455 .87866 m .6997 .89597 L .70696 .88631 L p .707 .577 .707 r
F P
0 g
s
.70696 .88631 m .71181 .869 L .70455 .87866 L p .707 .577 .707 r
F P
0 g
s
.72156 .78975 m .72182 .82683 L .71893 .81839 L p .707 .577 .707 r
F P
0 g
s
.71893 .81839 m .71866 .78131 L .72156 .78975 L p .707 .577 .707 r
F P
0 g
s
.44049 .81834 m .42258 .31488 L .38384 .31027 L p .707 .577 .707 r
F P
0 g
s
.42258 .31488 m .44049 .81834 L .48447 .81944 L p .707 .577 .707 r
F P
0 g
s
.26735 .68432 m .2578 .6286 L .22709 .63218 L p .707 .577 .707 r
F P
0 g
s
.2578 .6286 m .26735 .68432 L .29876 .6786 L p .707 .577 .707 r
F P
0 g
s
.29876 .6786 m .28921 .62288 L .2578 .6286 L p .707 .577 .707 r
F P
0 g
s
.70587 .67051 m .71543 .72622 L .70317 .72226 L p .707 .577 .707 r
F P
0 g
s
.70317 .72226 m .69361 .66655 L .70587 .67051 L p .707 .577 .707 r
F P
0 g
s
.28921 .62288 m .29876 .6786 L .32781 .6713 L p .707 .577 .707 r
F P
0 g
s
.32781 .6713 m .31825 .61558 L .28921 .62288 L p .707 .577 .707 r
F P
0 g
s
.23665 .6879 m .22709 .63218 L .20011 .63327 L p .707 .577 .707 r
F P
0 g
s
.22709 .63218 m .23665 .6879 L .26735 .68432 L p .707 .577 .707 r
F P
0 g
s
.59344 .73113 m .58388 .67541 L .61529 .66969 L p .707 .577 .707 r
F P
0 g
s
.61529 .66969 m .62485 .72541 L .59344 .73113 L p .707 .577 .707 r
F P
0 g
s
.59482 .79955 m .59455 .76247 L .62639 .76149 L p .707 .577 .707 r
F P
0 g
s
.62639 .76149 m .62665 .79857 L .59482 .79955 L p .707 .577 .707 r
F P
0 g
s
.58544 .81733 m .5903 .80002 L .62114 .8066 L p .707 .577 .707 r
F P
0 g
s
.55294 .30753 m .57084 .81099 L .60479 .80228 L p .707 .577 .707 r
F P
0 g
s
.60479 .80228 m .58688 .29882 L .55294 .30753 L p .707 .577 .707 r
F P
0 g
s
.31825 .61558 m .32781 .6713 L .35165 .66313 L p .707 .577 .707 r
F P
0 g
s
.35165 .66313 m .34209 .60742 L .31825 .61558 L p .707 .577 .707 r
F P
0 g
s
.27009 .73326 m .26983 .69618 L .23866 .6945 L p .707 .577 .707 r
F P
0 g
s
.26983 .69618 m .27009 .73326 L .30193 .73228 L p .707 .577 .707 r
F P
0 g
s
.30193 .73228 m .30166 .6952 L .26983 .69618 L p .707 .577 .707 r
F P
0 g
s
.30166 .6952 m .30193 .73228 L .33131 .72874 L p .707 .577 .707 r
F P
0 g
s
.33131 .72874 m .33104 .69166 L .30166 .6952 L p .707 .577 .707 r
F P
0 g
s
.20011 .63327 m .20966 .68898 L .23665 .6879 L p .707 .577 .707 r
F P
0 g
s
.23892 .73158 m .23866 .6945 L .2112 .69033 L p .707 .577 .707 r
F P
0 g
s
.23866 .6945 m .23892 .73158 L .27009 .73326 L p .707 .577 .707 r
F P
0 g
s
.40175 .81374 m .38384 .31027 L .35414 .3026 L p .707 .577 .707 r
F P
0 g
s
.38384 .31027 m .40175 .81374 L .44049 .81834 L p .707 .577 .707 r
F P
0 g
s
.71181 .869 m .70696 .88631 L .70457 .87402 L p .707 .577 .707 r
F P
0 g
s
.70457 .87402 m .70942 .85672 L .71181 .869 L p .707 .577 .707 r
F P
0 g
s
.20966 .68898 m .20011 .63327 L .17947 .63175 L p .707 .577 .707 r
F P
0 g
s
.71866 .78131 m .71893 .81839 L .70633 .81067 L p .707 .577 .707 r
F P
0 g
s
.70633 .81067 m .70607 .77359 L .71866 .78131 L p .707 .577 .707 r
F P
0 g
s
.33104 .69166 m .33131 .72874 L .35536 .72299 L p .707 .577 .707 r
F P
0 g
s
.35536 .72299 m .3551 .6859 L .33104 .69166 L p .707 .577 .707 r
F P
0 g
s
.69361 .66655 m .70317 .72226 L .68254 .72075 L p .707 .577 .707 r
F P
0 g
s
.68254 .72075 m .67298 .66503 L .69361 .66655 L p .707 .577 .707 r
F P
0 g
s
.2112 .69033 m .21146 .72741 L .23892 .73158 L p .707 .577 .707 r
F P
0 g
s
.34209 .60742 m .35165 .66313 L .36794 .6549 L p .707 .577 .707 r
F P
0 g
s
.36794 .6549 m .35838 .59918 L .34209 .60742 L p .707 .577 .707 r
F P
0 g
s
.17947 .63175 m .18903 .68747 L .1909 .68761 L p .707 .577 .707 r
F P
0 g
s
.1909 .68761 m .20966 .68898 L p .19378 .65887 L .707 .577 .707 r
F P
0 g
s
.19378 .65887 m .17947 .63175 L .1909 .68761 L .707 .577 .707 r
F
.18903 .68747 m .17947 .63175 L .16722 .62779 L p F P
0 g
s
.16722 .62779 m .17678 .68351 L .17779 .68383 L p .707 .577 .707 r
F P
0 g
s
.17779 .68383 m .18903 .68747 L p .1786 .65894 L .707 .577 .707 r
F P
0 g
s
.1786 .65894 m .16722 .62779 L .17779 .68383 L .707 .577 .707 r
F
.17678 .68351 m .16722 .62779 L .16454 .62176 L p F P
0 g
s
.16454 .62176 m .1741 .67748 L .17428 .6779 L p .707 .577 .707 r
F P
0 g
s
.17428 .6779 m .17678 .68351 L p .17111 .6549 L .707 .577 .707 r
F P
0 g
s
.17111 .6549 m .16454 .62176 L .17428 .6779 L .707 .577 .707 r
F
.17755 .67636 m .17466 .66792 L p .17714 .70375 L F P
0 g
s
.17764 .68853 m .17755 .67636 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .17755 .67636 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.17755 .67636 m .17782 .71344 L .19041 .72116 L p .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .18174 .65959 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .17475 .6813 L p .17782 .71344 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17492 .705 L .17616 .70863 L p .707 .577 .707 r
F P
0 g
s
.17616 .70863 m .17782 .71344 L p .17475 .6813 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17466 .66792 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17782 .71344 m .17764 .68853 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.18174 .65959 m .18184 .67339 L p .17492 .705 L .707 .577 .707 r
F P
0 g
s
.18184 .67339 m .182 .69667 L .17905 .70014 L p .707 .577 .707 r
F P
0 g
s
.17905 .70014 m .17492 .705 L p .18184 .67339 L .707 .577 .707 r
F P
0 g
s
.182 .69667 m .18174 .65959 L .19811 .65219 L p .707 .577 .707 r
F P
0 g
s
.18799 .60603 m .18852 .60914 L p .18125 .66998 L .707 .577 .707 r
F P
0 g
s
.19022 .69438 m .19014 .68408 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.21146 .72741 m .2112 .69033 L .19014 .68408 L p .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .19041 .72116 L .21146 .72741 L p .707 .577 .707 r
F P
0 g
s
.19811 .65219 m .1982 .66557 L p .182 .69667 L .707 .577 .707 r
F P
0 g
s
.1982 .66557 m .19837 .68927 L .1922 .69206 L p .707 .577 .707 r
F P
0 g
s
.1922 .69206 m .182 .69667 L p .1982 .66557 L .707 .577 .707 r
F P
0 g
s
.19837 .68927 m .19811 .65219 L .22216 .64643 L p .707 .577 .707 r
F P
0 g
s
.21183 .59787 m .21257 .60218 L p .19755 .66175 L .707 .577 .707 r
F P
0 g
s
.22216 .64643 m .22225 .65861 L p .19837 .68927 L .707 .577 .707 r
F P
0 g
s
.22225 .65861 m .22242 .68352 L .21493 .68531 L p .707 .577 .707 r
F P
0 g
s
.21493 .68531 m .19837 .68927 L p .22225 .65861 L .707 .577 .707 r
F P
0 g
s
.22242 .68352 m .22216 .64643 L .25154 .64289 L p .707 .577 .707 r
F P
0 g
s
.24087 .59057 m .24089 .59064 L p .22139 .65358 L .707 .577 .707 r
F P
0 g
s
.25154 .64289 m .25162 .65319 L p .22242 .68352 L .707 .577 .707 r
F P
0 g
s
.25162 .65319 m .25181 .67998 L .24548 .68074 L p .707 .577 .707 r
F P
0 g
s
.24548 .68074 m .22242 .68352 L p .25162 .65319 L .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .24087 .59057 L .2666 .58588 L p .707 .577 .707 r
F P
0 g
s
.2666 .58588 m .27228 .58485 L p .25771 .62581 L .707 .577 .707 r
F P
0 g
s
.25181 .67998 m .25154 .64289 L .28338 .64191 L p .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .2666 .58588 L .25771 .62581 L .707 .577 .707 r
F
.24089 .59064 m .25043 .64628 L .22379 .65298 L p F P
0 g
s
.22379 .65298 m .22139 .65358 L p .24089 .59064 L .707 .577 .707 r
F P
0 g
s
.21257 .60218 m .22139 .65358 L .1992 .66118 L p .707 .577 .707 r
F P
0 g
s
.1992 .66118 m .19755 .66175 L p .21257 .60218 L .707 .577 .707 r
F P
0 g
s
.18852 .60914 m .19755 .66175 L .18224 .66948 L p .707 .577 .707 r
F P
0 g
s
.18224 .66948 m .18125 .66998 L p .18852 .60914 L .707 .577 .707 r
F P
0 g
s
.1717 .61427 m .18125 .66998 L .17453 .67703 L p .707 .577 .707 r
F P
0 g
s
.17453 .67703 m .1741 .67748 L p .17283 .64419 L .707 .577 .707 r
F P
0 g
s
.17283 .64419 m .1717 .61427 L .17453 .67703 L .707 .577 .707 r
F
.17492 .705 m .17475 .6813 L p .17654 .69423 L F P
0 g
s
.19041 .72116 m .19022 .69438 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.62485 .72541 m .61529 .66969 L .64599 .66612 L p .707 .577 .707 r
F P
0 g
s
.62665 .79857 m .62639 .76149 L .65756 .76317 L p .707 .577 .707 r
F P
0 g
s
.58688 .29882 m .60479 .80228 L .62789 .79163 L p .707 .577 .707 r
F P
0 g
s
.64599 .66612 m .65555 .72183 L .62485 .72541 L p .707 .577 .707 r
F P
0 g
s
.62789 .79163 m .60999 .28816 L .58688 .29882 L p .707 .577 .707 r
F P
0 g
s
.25752 .78844 m .26237 .77113 L .23231 .76108 L p .707 .577 .707 r
F P
0 g
s
.26237 .77113 m .25752 .78844 L .28836 .79501 L p .707 .577 .707 r
F P
0 g
s
.28836 .79501 m .29321 .7777 L .26237 .77113 L p .707 .577 .707 r
F P
0 g
s
.22745 .77839 m .23231 .76108 L .20595 .74854 L p .707 .577 .707 r
F P
0 g
s
.23231 .76108 m .22745 .77839 L .25752 .78844 L p .707 .577 .707 r
F P
0 g
s
.29321 .7777 m .28836 .79501 L .31695 .79747 L p .707 .577 .707 r
F P
0 g
s
.31695 .79747 m .3218 .78016 L .29321 .7777 L p .707 .577 .707 r
F P
0 g
s
.20595 .74854 m .2011 .76585 L .22745 .77839 L p .707 .577 .707 r
F P
0 g
s
.3551 .6859 m .35536 .72299 L .37173 .71558 L p .707 .577 .707 r
F P
0 g
s
.37173 .71558 m .37147 .6785 L .3551 .6859 L p .707 .577 .707 r
F P
0 g
s
.70942 .85672 m .70457 .87402 L .69277 .8603 L p .707 .577 .707 r
F P
0 g
s
.69277 .8603 m .69762 .843 L .70942 .85672 L p .707 .577 .707 r
F P
0 g
s
.35838 .59918 m .36794 .6549 L .3751 .6474 L p .707 .577 .707 r
F P
0 g
s
.3751 .6474 m .36554 .59169 L .35838 .59918 L p .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .36554 .59169 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .37004 .62752 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37004 .62752 m .36286 .58566 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.35414 .3026 m .33639 .2926 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .36563 .62558 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .40175 .81374 L p .39549 .7465 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .36928 .64036 L p .36774 .63412 L .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .37004 .62752 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.37147 .6785 m .37173 .71558 L .37881 .70725 L p .707 .577 .707 r
F P
0 g
s
.37881 .70725 m .37855 .67017 L .37147 .6785 L p .707 .577 .707 r
F P
0 g
s
.37855 .67017 m .37881 .70725 L .37592 .69881 L p .707 .577 .707 r
F P
0 g
s
.37592 .69881 m .37565 .66173 L .37855 .67017 L p .707 .577 .707 r
F P
0 g
s
.36563 .62558 m .37205 .80606 L p .3724 .80516 L .707 .577 .707 r
F P
0 g
s
.37565 .66173 m .37592 .69881 L .37357 .69738 L p .707 .577 .707 r
F P
0 g
s
.37391 .66589 m .37565 .66173 L .37357 .69738 L .707 .577 .707 r
F
.37398 .65939 m .36563 .62558 L .3724 .80516 L F
.34535 .77826 m .3405 .79557 L .35669 .78949 L p F P
0 g
s
.35669 .78949 m .36154 .77218 L .34535 .77826 L p .707 .577 .707 r
F P
0 g
s
.36154 .77218 m .35669 .78949 L .36395 .77983 L p .707 .577 .707 r
F P
0 g
s
.36395 .77983 m .3688 .76253 L .36154 .77218 L p .707 .577 .707 r
F P
0 g
s
.3688 .76253 m .36395 .77983 L .36156 .76755 L p .707 .577 .707 r
F P
0 g
s
.36156 .76755 m .36641 .75024 L .3688 .76253 L p .707 .577 .707 r
F P
0 g
s
.36641 .75024 m .36156 .76755 L .35564 .76067 L p .707 .577 .707 r
F P
0 g
s
.35564 .76067 m .34976 .75383 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35497 .7527 m .36641 .75024 L .35564 .76067 L .707 .577 .707 r
F
.35787 .68947 m .34227 .68484 L p .35651 .66372 L F P
0 g
s
.35461 .73652 m .36641 .75024 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.34976 .75383 m .35385 .73924 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35385 .73924 m .35461 .73652 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35461 .73652 m .34976 .75383 L .33746 .74537 L p .707 .577 .707 r
F P
0 g
s
.33746 .74537 m .3297 .74002 L p .33749 .73893 L .707 .577 .707 r
F P
0 g
s
.33749 .73893 m .35461 .73652 L .33746 .74537 L .707 .577 .707 r
F
.3506 .5817 m .35752 .62201 L p .33953 .6359 L F P
0 g
s
.35675 .63716 m .33953 .6359 L p .35752 .62201 L .707 .577 .707 r
F P
0 g
s
.33953 .6359 m .32997 .58018 L .3506 .5817 L p .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .35932 .6228 L .35756 .68358 L .707 .577 .707 r
F
.34227 .68484 m .34201 .64776 L .35588 .65188 L p F P
0 g
s
.35932 .6228 m .35423 .62056 L .35756 .68358 L .707 .577 .707 r
F
.35588 .65188 m .36306 .65401 L p .35651 .66372 L F P
0 g
s
.34227 .68484 m .35588 .65188 L .35651 .66372 L .707 .577 .707 r
F
.3297 .74002 m .33455 .72271 L .35461 .73652 L p F P
0 g
s
.34795 .61779 m .35429 .79607 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.35423 .62056 m .34795 .61779 L .35756 .68358 L .707 .577 .707 r
F
.33231 .28128 m .34471 .62993 L p .34979 .69075 L F P
0 g
s
.34471 .62993 m .35022 .78474 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .33231 .28128 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3511 .70639 m .33639 .2926 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3506 .5817 m .36286 .58566 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .3506 .5817 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .34795 .61779 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .33852 .45592 L p .34231 .26972 L .707 .577 .707 r
F P
0 g
s
.33852 .45592 m .33231 .28128 L .33919 .27333 L p .707 .577 .707 r
F P
0 g
s
.33919 .27333 m .34231 .26972 L p .33852 .45592 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .35429 .79607 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .36016 .63741 L .35675 .63716 L p .707 .577 .707 r
F P
0 g
s
.35429 .79607 m .3511 .70639 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.36377 .80141 m .37205 .80606 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.36306 .65401 m .36332 .69109 L .35787 .68947 L p .707 .577 .707 r
F P
0 g
s
.35651 .66372 m .36306 .65401 L .35787 .68947 L .707 .577 .707 r
F
.35429 .79607 m .36377 .80141 L p .35756 .68358 L F P
0 g
s
.36016 .63741 m .35752 .62201 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .36306 .65401 L .37397 .6607 L p .707 .577 .707 r
F P
0 g
s
.37397 .6607 m .37565 .66173 L p .37391 .66589 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .37397 .6607 L .37391 .66589 L .707 .577 .707 r
F
.37004 .62752 m .37242 .64138 L p .36774 .63412 L F P
0 g
s
.36089 .62349 m .36563 .62558 L .36774 .63412 L .707 .577 .707 r
F
.36563 .62558 m .37004 .62752 L .36774 .63412 L F
.36554 .59169 m .3751 .6474 L .37242 .64138 L p F P
0 g
s
.35414 .3026 m .36563 .62558 L p .37398 .65939 L .707 .577 .707 r
F P
0 g
s
.39549 .7465 m .37537 .53052 L .37398 .65939 L .707 .577 .707 r
F
.37537 .53052 m .35414 .3026 L .37398 .65939 L F
.39549 .7465 m .37398 .65939 L .3724 .80516 L F
.37357 .69738 m .36332 .69109 L p .37391 .66589 L F P
0 g
s
.36016 .63741 m .36089 .62349 L .36774 .63412 L .707 .577 .707 r
F
.36928 .64036 m .36016 .63741 L p .36774 .63412 L F P
0 g
s
.35932 .6228 m .36468 .59898 L .35354 .53961 L .707 .577 .707 r
F
.36563 .62558 m .36468 .59898 L p .35932 .6228 L F P
0 g
s
.36468 .59898 m .35414 .3026 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.2011 .76585 m .20595 .74854 L .18589 .73473 L p .707 .577 .707 r
F P
0 g
s
.67298 .66503 m .68254 .72075 L .65555 .72183 L p .707 .577 .707 r
F P
0 g
s
.65555 .72183 m .64599 .66612 L .67298 .66503 L p .707 .577 .707 r
F P
0 g
s
.70607 .77359 m .70633 .81067 L .68528 .80442 L p .707 .577 .707 r
F P
0 g
s
.68528 .80442 m .68502 .76734 L .70607 .77359 L p .707 .577 .707 r
F P
0 g
s
.3218 .78016 m .31695 .79747 L .3405 .79557 L p .707 .577 .707 r
F P
0 g
s
.3405 .79557 m .34535 .77826 L .3218 .78016 L p .707 .577 .707 r
F P
0 g
s
.18589 .73473 m .18104 .75204 L .2011 .76585 L p .707 .577 .707 r
F P
0 g
s
.60999 .28816 m .62789 .79163 L .6379 .78007 L p .707 .577 .707 r
F P
0 g
s
.6379 .78007 m .61999 .27661 L .60999 .28816 L p .707 .577 .707 r
F P
0 g
s
.18104 .75204 m .18589 .73473 L .17409 .72101 L p .707 .577 .707 r
F P
0 g
s
.69762 .843 m .69277 .8603 L .67271 .8465 L p .707 .577 .707 r
F P
0 g
s
.67271 .8465 m .67756 .82919 L .69762 .843 L p .707 .577 .707 r
F P
0 g
s
.68502 .76734 m .68528 .80442 L .65782 .80025 L p .707 .577 .707 r
F P
0 g
s
.65782 .80025 m .65756 .76317 L .68502 .76734 L p .707 .577 .707 r
F P
0 g
s
.17409 .72101 m .16924 .73832 L .18104 .75204 L p .707 .577 .707 r
F P
0 g
s
.65756 .76317 m .65782 .80025 L .62665 .79857 L p .707 .577 .707 r
F P
0 g
s
.67756 .82919 m .67271 .8465 L .64635 .83396 L p .707 .577 .707 r
F P
0 g
s
.64635 .83396 m .65121 .81665 L .67756 .82919 L p .707 .577 .707 r
F P
0 g
s
.16924 .73832 m .17409 .72101 L .1717 .70872 L p .707 .577 .707 r
F P
0 g
s
.1717 .70872 m .16685 .72603 L .16924 .73832 L p .707 .577 .707 r
F P
0 g
s
.1741 .67748 m .16454 .62176 L .1717 .61427 L p .707 .577 .707 r
F P
0 g
s
.65121 .81665 m .64635 .83396 L .61628 .8239 L p .707 .577 .707 r
F P
0 g
s
.61628 .8239 m .62114 .8066 L .65121 .81665 L p .707 .577 .707 r
F P
0 g
s
.62114 .8066 m .61628 .8239 L .58544 .81733 L p .707 .577 .707 r
F P
0 g
s
.61999 .27661 m .6379 .78007 L .63382 .76875 L p .707 .577 .707 r
F P
0 g
s
.63382 .76875 m .61591 .26528 L .61999 .27661 L p .707 .577 .707 r
F P
0 g
s
.16685 .72603 m .1717 .70872 L .17896 .69907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17896 .69907 m .1741 .71638 L .16685 .72603 L p .707 .577 .707 r
F P
0 g
s
.18125 .66998 m .1717 .61427 L .18799 .60603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.61591 .26528 m .63382 .76875 L .61606 .75876 L p .707 .577 .707 r
F P
0 g
s
.61606 .75876 m .59816 .25529 L .61591 .26528 L p .707 .577 .707 r
F P
0 g
s
.1741 .71638 m .17896 .69907 L .19515 .69299 L p .707 .577 .707 r
F P
0 g
s
.19755 .66175 m .18799 .60603 L .21183 .59787 L p .707 .577 .707 r
F P
0 g
s
.19515 .69299 m .1903 .7103 L .1741 .71638 L p .707 .577 .707 r
F P
0 g
s
.32997 .58018 m .33953 .6359 L .31254 .63699 L p .707 .577 .707 r
F P
0 g
s
.31254 .63699 m .30299 .58127 L .32997 .58018 L p .707 .577 .707 r
F P
0 g
s
.36022 .77319 m .34231 .26972 L .36542 .25907 L p .707 .577 .707 r
F P
0 g
s
.34231 .26972 m .36022 .77319 L .35022 .78474 L p .707 .577 .707 r
F P
0 g
s
.22139 .65358 m .21183 .59787 L .24087 .59057 L p .707 .577 .707 r
F P
0 g
s
.34201 .64776 m .34227 .68484 L .31481 .68067 L p .707 .577 .707 r
F P
0 g
s
.31481 .68067 m .31455 .64359 L .34201 .64776 L p .707 .577 .707 r
F P
0 g
s
.1903 .7103 m .19515 .69299 L .2187 .69109 L p .707 .577 .707 r
F P
0 g
s
.30299 .58127 m .31254 .63699 L .28184 .64056 L p .707 .577 .707 r
F P
0 g
s
.28184 .64056 m .27228 .58485 L .30299 .58127 L p .707 .577 .707 r
F P
0 g
s
.2187 .69109 m .21384 .7084 L .1903 .7103 L p .707 .577 .707 r
F P
0 g
s
.27228 .58485 m .28184 .64056 L .25043 .64628 L p .707 .577 .707 r
F P
0 g
s
.59816 .25529 m .61606 .75876 L .58636 .75108 L p .707 .577 .707 r
F P
0 g
s
.58636 .75108 m .56846 .24761 L .59816 .25529 L p .707 .577 .707 r
F P
0 g
s
.31455 .64359 m .31481 .68067 L .28364 .679 L p .707 .577 .707 r
F P
0 g
s
.28364 .679 m .28338 .64191 L .31455 .64359 L p .707 .577 .707 r
F P
0 g
s
.21384 .7084 m .2187 .69109 L .24729 .69354 L p .707 .577 .707 r
F P
0 g
s
.28338 .64191 m .28364 .679 L .25181 .67998 L p .707 .577 .707 r
F P
0 g
s
.33455 .72271 m .3297 .74002 L .30334 .72748 L p .707 .577 .707 r
F P
0 g
s
.30334 .72748 m .3082 .71017 L .33455 .72271 L p .707 .577 .707 r
F P
0 g
s
.74757 .67713 m .73801 .62141 L .70731 .62499 L p .707 .577 .707 r
F P
0 g
s
.73801 .62141 m .74757 .67713 L .77898 .67141 L p .707 .577 .707 r
F P
0 g
s
.77898 .67141 m .76942 .61569 L .73801 .62141 L p .707 .577 .707 r
F P
0 g
s
.76942 .61569 m .77898 .67141 L .80802 .66411 L p .707 .577 .707 r
F P
0 g
s
.80802 .66411 m .79846 .60839 L .76942 .61569 L p .707 .577 .707 r
F P
0 g
s
.24729 .69354 m .24244 .71085 L .21384 .7084 L p .707 .577 .707 r
F P
0 g
s
.36542 .25907 m .38332 .76253 L .36022 .77319 L p .707 .577 .707 r
F P
0 g
s
.38332 .76253 m .36542 .25907 L .39936 .25036 L p .707 .577 .707 r
F P
0 g
s
.71686 .68071 m .70731 .62499 L .68032 .62607 L p .707 .577 .707 r
F P
0 g
s
.70731 .62499 m .71686 .68071 L .74757 .67713 L p .707 .577 .707 r
F P
0 g
s
.24244 .71085 m .24729 .69354 L .27813 .70012 L p .707 .577 .707 r
F P
0 g
s
.79846 .60839 m .80802 .66411 L .83186 .65594 L p .707 .577 .707 r
F P
0 g
s
.83186 .65594 m .8223 .60023 L .79846 .60839 L p .707 .577 .707 r
F P
0 g
s
.3082 .71017 m .30334 .72748 L .27327 .71743 L p .707 .577 .707 r
F P
0 g
s
.27327 .71743 m .27813 .70012 L .3082 .71017 L p .707 .577 .707 r
F P
0 g
s
.27813 .70012 m .27327 .71743 L .24244 .71085 L p .707 .577 .707 r
F P
0 g
s
.68032 .62607 m .68988 .68179 L .71686 .68071 L p .707 .577 .707 r
F P
0 g
s
.56846 .24761 m .58636 .75108 L .54763 .74647 L p .707 .577 .707 r
F P
0 g
s
.54763 .74647 m .52972 .243 L .56846 .24761 L p .707 .577 .707 r
F P
0 g
s
.7503 .7608 m .75004 .72372 L .71887 .72204 L p .707 .577 .707 r
F P
0 g
s
.75004 .72372 m .7503 .7608 L .78214 .75982 L p .707 .577 .707 r
F P
0 g
s
.78214 .75982 m .78188 .72274 L .75004 .72372 L p .707 .577 .707 r
F P
0 g
s
.68988 .68179 m .68032 .62607 L .65969 .62456 L p .707 .577 .707 r
F P
0 g
s
.78188 .72274 m .78214 .75982 L .81152 .75628 L p .707 .577 .707 r
F P
0 g
s
.81152 .75628 m .81126 .7192 L .78188 .72274 L p .707 .577 .707 r
F P
0 g
s
.71913 .75912 m .71887 .72204 L .69141 .71787 L p .707 .577 .707 r
F P
0 g
s
.71887 .72204 m .71913 .75912 L .7503 .7608 L p .707 .577 .707 r
F P
0 g
s
.8223 .60023 m .83186 .65594 L .84815 .64771 L p .707 .577 .707 r
F P
0 g
s
.84815 .64771 m .8386 .59199 L .8223 .60023 L p .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .44082 .24445 L p .42565 .57266 L .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .41858 .57404 L .42563 .57266 L .707 .577 .707 r
F
.42252 .64037 m .42563 .57266 L .42564 .57281 L F
.41727 .75383 m .41496 .68878 L p .42252 .64037 L F P
0 g
s
.41496 .68878 m .39936 .25036 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .41496 .68878 L p .38332 .76253 L .707 .577 .707 r
F P
0 g
s
.41496 .68878 m .41727 .75383 L .41174 .75524 L p .707 .577 .707 r
F P
0 g
s
.41174 .75524 m .38332 .76253 L p .41496 .68878 L .707 .577 .707 r
F P
0 g
s
.395 .53656 m .40456 .59228 L .41976 .58951 L p .707 .577 .707 r
F P
0 g
s
.41858 .57404 m .39936 .25036 L .42565 .57266 L .707 .577 .707 r
F
.43088 .64049 m .43913 .64024 L p .43007 .63005 L F P
0 g
s
.46641 .6041 m .4649 .5829 L .48574 .24191 L .707 .577 .707 r
F
.44082 .24445 m .47655 .24243 L p .4649 .5829 L F P
0 g
s
.47655 .24243 m .48574 .24191 L p .4649 .5829 L .707 .577 .707 r
F P
0 g
s
.46431 .60009 m .43887 .60316 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.43597 .58656 m .45758 .58113 L p .45296 .56912 L .707 .577 .707 r
F P
0 g
s
.45231 .56743 m .44082 .24445 L p .46641 .6041 L .707 .577 .707 r
F P
0 g
s
.43332 .57115 m .43597 .58656 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.43887 .60316 m .43913 .64024 L .46303 .63736 L p .707 .577 .707 r
F P
0 g
s
.46326 .63076 m .43887 .60316 L .46303 .63736 L .707 .577 .707 r
F
.45873 .74792 m .45571 .66309 L p .46227 .65417 L F P
0 g
s
.45873 .74792 m .41727 .75383 L p .42142 .66396 L .707 .577 .707 r
F P
0 g
s
.43077 .58751 m .43597 .58656 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.44082 .24445 m .4489 .47144 L p .43332 .57115 L .707 .577 .707 r
F P
0 g
s
.43913 .64024 m .43887 .60316 L .42802 .60349 L p .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .42564 .57281 L .4281 .6046 L .707 .577 .707 r
F
.43913 .64024 m .42802 .60349 L .43007 .63005 L F
.43597 .58656 m .43332 .57115 L p .43173 .58139 L F P
0 g
s
.4489 .47144 m .45571 .66309 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.42802 .60349 m .40703 .60414 L p .43007 .63005 L .707 .577 .707 r
F P
0 g
s
.4281 .6046 m .42565 .57266 L .43332 .57115 L .707 .577 .707 r
F
.42564 .57281 m .42565 .57266 L .4281 .6046 L F
.42565 .57266 m .44082 .24445 L .43332 .57115 L F
.45546 .52355 m .42641 .53085 L p .45514 .56688 L F P
0 g
s
.46501 .57926 m .46264 .56541 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.46264 .56541 m .45546 .52355 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.42564 .57281 m .42563 .57266 L .42565 .57266 L .707 .577 .707 r
F
.42641 .53085 m .395 .53656 L p .43173 .58139 L F P
0 g
s
.43332 .57115 m .42641 .53085 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.42142 .66396 m .42252 .64037 L .45571 .66309 L .707 .577 .707 r
F
.45571 .66309 m .45873 .74792 L p .42142 .66396 L F P
0 g
s
.45415 .70543 m .45901 .68812 L .43861 .68637 L p .707 .577 .707 r
F P
0 g
s
.43861 .68637 m .43042 .68567 L p .43582 .69017 L .707 .577 .707 r
F P
0 g
s
.45415 .70543 m .43861 .68637 L .43582 .69017 L .707 .577 .707 r
F
.46227 .65417 m .45231 .56743 L .46436 .59877 L F
.45571 .66309 m .45231 .56743 L p .46227 .65417 L F P
0 g
s
.46018 .72077 m .46436 .59877 L .46641 .6041 L .707 .577 .707 r
F
.45873 .74792 m .46436 .59877 L .46018 .72077 L F
.48574 .24191 m .50365 .74538 L .45873 .74792 L p F P
0 g
s
.46303 .63736 m .46851 .6367 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46825 .59962 L .46431 .60009 L p .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46431 .60009 L .46326 .63076 L .707 .577 .707 r
F
.46501 .57926 m .45514 .56688 L .45296 .56912 L F
.45758 .58113 m .46501 .57926 L p .45296 .56912 L F P
0 g
s
.41976 .58951 m .43077 .58751 L p .42056 .57296 L .707 .577 .707 r
F P
0 g
s
.42056 .57296 m .395 .53656 L .41976 .58951 L .707 .577 .707 r
F
.40703 .60414 m .40729 .64122 L .43088 .64049 L p F P
0 g
s
.43007 .63005 m .40703 .60414 L .43088 .64049 L .707 .577 .707 r
F
.42641 .53085 m .43332 .57115 L p .45514 .56688 L F P
0 g
s
.43173 .58139 m .395 .53656 L .43077 .58751 L .707 .577 .707 r
F
.65969 .62456 m .66925 .68028 L .68988 .68179 L p F P
0 g
s
.81126 .7192 m .81152 .75628 L .83557 .75053 L p .707 .577 .707 r
F P
0 g
s
.83557 .75053 m .83531 .71344 L .81126 .7192 L p .707 .577 .707 r
F P
0 g
s
.69141 .71787 m .69168 .75495 L .71913 .75912 L p .707 .577 .707 r
F P
0 g
s
.73773 .80288 m .74259 .78557 L .71252 .77552 L p .707 .577 .707 r
F P
0 g
s
.74259 .78557 m .73773 .80288 L .76857 .80945 L p .707 .577 .707 r
F P
0 g
s
.76857 .80945 m .77343 .79215 L .74259 .78557 L p .707 .577 .707 r
F P
0 g
s
.52972 .243 m .54763 .74647 L .50365 .74538 L p .707 .577 .707 r
F P
0 g
s
.50365 .74538 m .48574 .24191 L .52972 .243 L p .707 .577 .707 r
F P
0 g
s
.69168 .75495 m .69141 .71787 L .67036 .71162 L p .707 .577 .707 r
F P
0 g
s
.70766 .79283 m .71252 .77552 L .68616 .76298 L p .707 .577 .707 r
F P
0 g
s
.71252 .77552 m .70766 .79283 L .73773 .80288 L p .707 .577 .707 r
F P
0 g
s
.77343 .79215 m .76857 .80945 L .79716 .81191 L p .707 .577 .707 r
F P
0 g
s
.79716 .81191 m .80202 .7946 L .77343 .79215 L p .707 .577 .707 r
F P
0 g
s
.66925 .68028 m .65969 .62456 L .64743 .6206 L p .707 .577 .707 r
F P
0 g
s
.68616 .76298 m .68131 .78029 L .70766 .79283 L p .707 .577 .707 r
F P
0 g
s
.67036 .71162 m .67062 .7487 L .69168 .75495 L p .707 .577 .707 r
F P
0 g
s
.83531 .71344 m .83557 .75053 L .85194 .74312 L p .707 .577 .707 r
F P
0 g
s
.85194 .74312 m .85168 .70604 L .83531 .71344 L p .707 .577 .707 r
F P
0 g
s
.8386 .59199 m .84815 .64771 L .85531 .64021 L p .707 .577 .707 r
F P
0 g
s
.85531 .64021 m .84575 .58449 L .8386 .59199 L p .707 .577 .707 r
F P
0 g
s
.68131 .78029 m .68616 .76298 L .6661 .74917 L p .707 .577 .707 r
F P
0 g
s
.64743 .6206 m .65699 .67632 L .66925 .68028 L p .707 .577 .707 r
F P
0 g
s
.80202 .7946 m .79716 .81191 L .82071 .81001 L p .707 .577 .707 r
F P
0 g
s
.82071 .81001 m .82556 .7927 L .80202 .7946 L p .707 .577 .707 r
F P
0 g
s
.6661 .74917 m .66125 .76648 L .68131 .78029 L p .707 .577 .707 r
F P
0 g
s
.67062 .7487 m .67036 .71162 L .65777 .7039 L p .707 .577 .707 r
F P
0 g
s
.65699 .67632 m .64743 .6206 L .64475 .61457 L p .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .6661 .74917 L .65891 .7408 L p .707 .577 .707 r
F P
0 g
s
.65891 .7408 m .6543 .73545 L p .66003 .76101 L .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .65891 .7408 L .66003 .76101 L .707 .577 .707 r
F
.65803 .74098 m .6579 .72263 L p .65487 .69546 L F P
0 g
s
.6579 .72263 m .65777 .7039 L .65669 .70075 L p .707 .577 .707 r
F P
0 g
s
.65669 .70075 m .65487 .69546 L p .6579 .72263 L .707 .577 .707 r
F P
0 g
s
.65777 .7039 m .65803 .74098 L .67062 .7487 L p .707 .577 .707 r
F P
0 g
s
.82556 .7927 m .82071 .81001 L .8369 .80393 L p .707 .577 .707 r
F P
0 g
s
.8369 .80393 m .84176 .78662 L .82556 .7927 L p .707 .577 .707 r
F P
0 g
s
.85168 .70604 m .85194 .74312 L .85903 .73479 L p .707 .577 .707 r
F P
0 g
s
.85903 .73479 m .85876 .69771 L .85168 .70604 L p .707 .577 .707 r
F P
0 g
s
.6543 .73545 m .64945 .75276 L .66125 .76648 L p .707 .577 .707 r
F P
0 g
s
.84575 .58449 m .85531 .64021 L .85263 .63419 L p .707 .577 .707 r
F P
0 g
s
.85263 .63419 m .84307 .57847 L .84575 .58449 L p .707 .577 .707 r
F P
0 g
s
.64475 .61457 m .65431 .67029 L .65699 .67632 L p .707 .577 .707 r
F P
0 g
s
.64945 .75276 m .6543 .73545 L .65191 .72316 L p .707 .577 .707 r
F P
0 g
s
.65191 .72316 m .64706 .74047 L .64945 .75276 L p .707 .577 .707 r
F P
0 g
s
.64706 .74047 m .65191 .72316 L .6541 .72026 L p .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65803 .74098 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65499 .7122 m .65513 .73254 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65487 .69546 m .65499 .7122 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65487 .69546 L .66195 .68713 L p .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .65513 .73254 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66195 .68713 m .66207 .70319 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66207 .70319 m .66222 .72421 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .66195 .68713 L .67832 .67973 L p .707 .577 .707 r
F P
0 g
s
.65432 .73082 m .65917 .71351 L .66446 .71152 L p .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .66222 .72421 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67832 .67973 m .67844 .69647 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67844 .69647 m .67859 .71681 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .67832 .67973 L .70237 .67397 L p .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .67537 .70743 L .68385 .70674 L p .707 .577 .707 r
F P
0 g
s
.70237 .67397 m .70264 .71106 L .67859 .71681 L p .707 .577 .707 r
F P
0 g
s
.68385 .70674 m .69891 .70553 L p .68734 .71336 L .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .68385 .70674 L .68734 .71336 L .707 .577 .707 r
F
.66446 .71152 m .67537 .70743 L p .6662 .71761 L F P
0 g
s
.65432 .73082 m .66446 .71152 L .6662 .71761 L .707 .577 .707 r
F
.6541 .72026 m .65917 .71351 L p .65343 .72628 L F P
0 g
s
.64706 .74047 m .6541 .72026 L .65343 .72628 L .707 .577 .707 r
F
.65431 .67029 m .64475 .61457 L .65191 .60708 L p F P
0 g
s
.84176 .78662 m .8369 .80393 L .84416 .79427 L p .707 .577 .707 r
F P
0 g
s
.84416 .79427 m .84902 .77697 L .84176 .78662 L p .707 .577 .707 r
F P
0 g
s
.85876 .69771 m .85903 .73479 L .85613 .72635 L p .707 .577 .707 r
F P
0 g
s
.85613 .72635 m .85587 .68927 L .85876 .69771 L p .707 .577 .707 r
F P
0 g
s
.40456 .59228 m .395 .53656 L .3643 .54014 L p .707 .577 .707 r
F P
0 g
s
.84307 .57847 m .85263 .63419 L .84038 .63022 L p .707 .577 .707 r
F P
0 g
s
.84038 .63022 m .83082 .57451 L .84307 .57847 L p .707 .577 .707 r
F P
0 g
s
.65191 .60708 m .66147 .66279 L .65431 .67029 L p .707 .577 .707 r
F P
0 g
s
.37385 .59586 m .3643 .54014 L .33731 .54123 L p .707 .577 .707 r
F P
0 g
s
.3643 .54014 m .37385 .59586 L .40456 .59228 L p .707 .577 .707 r
F P
0 g
s
.45546 .52355 m .46501 .57926 L .48885 .57109 L p .707 .577 .707 r
F P
0 g
s
.48885 .57109 m .47929 .51538 L .45546 .52355 L p .707 .577 .707 r
F P
0 g
s
.40729 .64122 m .40703 .60414 L .37586 .60246 L p .707 .577 .707 r
F P
0 g
s
.33731 .54123 m .34687 .59694 L .37385 .59586 L p .707 .577 .707 r
F P
0 g
s
.37612 .63954 m .37586 .60246 L .3484 .59829 L p .707 .577 .707 r
F P
0 g
s
.37586 .60246 m .37612 .63954 L .40729 .64122 L p .707 .577 .707 r
F P
0 g
s
.66147 .66279 m .65191 .60708 L .6682 .59884 L p .707 .577 .707 r
F P
0 g
s
.84902 .77697 m .84416 .79427 L .84177 .78199 L p .707 .577 .707 r
F P
0 g
s
.84177 .78199 m .84663 .76468 L .84902 .77697 L p .707 .577 .707 r
F P
0 g
s
.34687 .59694 m .33731 .54123 L .31668 .53971 L p .707 .577 .707 r
F P
0 g
s
.65917 .71351 m .65432 .73082 L .64706 .74047 L p .707 .577 .707 r
F P
0 g
s
.85587 .68927 m .85613 .72635 L .84354 .71863 L p .707 .577 .707 r
F P
0 g
s
.84354 .71863 m .84328 .68155 L .85587 .68927 L p .707 .577 .707 r
F P
0 g
s
.46825 .59962 m .46851 .6367 L .49256 .63095 L p .707 .577 .707 r
F P
0 g
s
.49256 .63095 m .4923 .59387 L .46825 .59962 L p .707 .577 .707 r
F P
0 g
s
.83082 .57451 m .84038 .63022 L .81975 .62871 L p .707 .577 .707 r
F P
0 g
s
.81975 .62871 m .81019 .57299 L .83082 .57451 L p .707 .577 .707 r
F P
0 g
s
.3484 .59829 m .34867 .63538 L .37612 .63954 L p .707 .577 .707 r
F P
0 g
s
.47929 .51538 m .48885 .57109 L .50515 .56286 L p .707 .577 .707 r
F P
0 g
s
.50515 .56286 m .49559 .50714 L .47929 .51538 L p .707 .577 .707 r
F P
0 g
s
.6682 .59884 m .67776 .65456 L .66147 .66279 L p .707 .577 .707 r
F P
0 g
s
.31668 .53971 m .32624 .59543 L .3281 .59557 L p .707 .577 .707 r
F P
0 g
s
.3281 .59557 m .34687 .59694 L p .33098 .56683 L .707 .577 .707 r
F P
0 g
s
.33098 .56683 m .31668 .53971 L .3281 .59557 L .707 .577 .707 r
F
.32624 .59543 m .31668 .53971 L .30442 .53575 L p F P
0 g
s
.30442 .53575 m .31398 .59147 L .315 .5918 L p .707 .577 .707 r
F P
0 g
s
.315 .5918 m .32624 .59543 L p .31581 .5669 L .707 .577 .707 r
F P
0 g
s
.31581 .5669 m .30442 .53575 L .315 .5918 L .707 .577 .707 r
F
.31398 .59147 m .30442 .53575 L .30174 .52973 L p F P
0 g
s
.30174 .52973 m .3113 .58544 L .31148 .58586 L p .707 .577 .707 r
F P
0 g
s
.31148 .58586 m .31398 .59147 L p .30831 .56286 L .707 .577 .707 r
F P
0 g
s
.30831 .56286 m .30174 .52973 L .31148 .58586 L .707 .577 .707 r
F
.31476 .58432 m .31186 .57588 L p .31435 .61171 L F P
0 g
s
.31484 .59649 m .31476 .58432 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .31476 .58432 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.31476 .58432 m .31502 .6214 L .32761 .62912 L p .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31894 .56755 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31195 .58926 L p .31502 .6214 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31212 .61296 L .31337 .61659 L p .707 .577 .707 r
F P
0 g
s
.31337 .61659 m .31502 .6214 L p .31195 .58926 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31186 .57588 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31502 .6214 m .31484 .59649 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.31894 .56755 m .31904 .58135 L p .31212 .61296 L .707 .577 .707 r
F P
0 g
s
.31904 .58135 m .31921 .60463 L .31626 .6081 L p .707 .577 .707 r
F P
0 g
s
.31626 .6081 m .31212 .61296 L p .31904 .58135 L .707 .577 .707 r
F P
0 g
s
.31921 .60463 m .31894 .56755 L .33531 .56015 L p .707 .577 .707 r
F P
0 g
s
.32519 .51399 m .32573 .5171 L p .31846 .57795 L .707 .577 .707 r
F P
0 g
s
.32742 .60234 m .32735 .59204 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.34867 .63538 m .3484 .59829 L .32735 .59204 L p .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .32761 .62912 L .34867 .63538 L p .707 .577 .707 r
F P
0 g
s
.33531 .56015 m .33541 .57353 L p .31921 .60463 L .707 .577 .707 r
F P
0 g
s
.33541 .57353 m .33557 .59723 L .3294 .60002 L p .707 .577 .707 r
F P
0 g
s
.3294 .60002 m .31921 .60463 L p .33541 .57353 L .707 .577 .707 r
F P
0 g
s
.33557 .59723 m .33531 .56015 L .35936 .55439 L p .707 .577 .707 r
F P
0 g
s
.34903 .50583 m .34977 .51014 L p .33475 .56971 L .707 .577 .707 r
F P
0 g
s
.35936 .55439 m .35945 .56657 L p .33557 .59723 L .707 .577 .707 r
F P
0 g
s
.35945 .56657 m .35963 .59148 L .35213 .59327 L p .707 .577 .707 r
F P
0 g
s
.35213 .59327 m .33557 .59723 L p .35945 .56657 L .707 .577 .707 r
F P
0 g
s
.35963 .59148 m .35936 .55439 L .38875 .55085 L p .707 .577 .707 r
F P
0 g
s
.37808 .49853 m .37809 .4986 L p .35859 .56154 L .707 .577 .707 r
F P
0 g
s
.38875 .55085 m .38882 .56115 L p .35963 .59148 L .707 .577 .707 r
F P
0 g
s
.38882 .56115 m .38901 .58794 L .38268 .5887 L p .707 .577 .707 r
F P
0 g
s
.38268 .5887 m .35963 .59148 L p .38882 .56115 L .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .37808 .49853 L .40381 .49384 L p .707 .577 .707 r
F P
0 g
s
.40381 .49384 m .40949 .49281 L p .39492 .53377 L .707 .577 .707 r
F P
0 g
s
.38901 .58794 m .38875 .55085 L .42058 .54987 L p .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .40381 .49384 L .39492 .53377 L .707 .577 .707 r
F
.37809 .4986 m .38763 .55424 L .36099 .56094 L p F P
0 g
s
.36099 .56094 m .35859 .56154 L p .37809 .4986 L .707 .577 .707 r
F P
0 g
s
.34977 .51014 m .35859 .56154 L .3364 .56915 L p .707 .577 .707 r
F P
0 g
s
.3364 .56915 m .33475 .56971 L p .34977 .51014 L .707 .577 .707 r
F P
0 g
s
.32573 .5171 m .33475 .56971 L .31945 .57745 L p .707 .577 .707 r
F P
0 g
s
.31945 .57745 m .31846 .57795 L p .32573 .5171 L .707 .577 .707 r
F P
0 g
s
.3089 .52223 m .31846 .57795 L .31173 .58499 L p .707 .577 .707 r
F P
0 g
s
.31173 .58499 m .3113 .58544 L p .31004 .55215 L .707 .577 .707 r
F P
0 g
s
.31004 .55215 m .3089 .52223 L .31173 .58499 L .707 .577 .707 r
F
.31212 .61296 m .31195 .58926 L p .31374 .60219 L F P
0 g
s
.32761 .62912 m .32742 .60234 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.39472 .6964 m .39958 .67909 L .36951 .66904 L p .707 .577 .707 r
F P
0 g
s
.39958 .67909 m .39472 .6964 L .42556 .70298 L p .707 .577 .707 r
F P
0 g
s
.42556 .70298 m .43042 .68567 L .39958 .67909 L p .707 .577 .707 r
F P
0 g
s
.36465 .68635 m .36951 .66904 L .34315 .6565 L p .707 .577 .707 r
F P
0 g
s
.36951 .66904 m .36465 .68635 L .39472 .6964 L p .707 .577 .707 r
F P
0 g
s
.43042 .68567 m .42556 .70298 L .45415 .70543 L p .707 .577 .707 r
F P
0 g
s
.67776 .65456 m .6682 .59884 L .69204 .59067 L p .707 .577 .707 r
F P
0 g
s
.34315 .6565 m .3383 .67381 L .36465 .68635 L p .707 .577 .707 r
F P
0 g
s
.4923 .59387 m .49256 .63095 L .50893 .62354 L p .707 .577 .707 r
F P
0 g
s
.50893 .62354 m .50867 .58646 L .4923 .59387 L p .707 .577 .707 r
F P
0 g
s
.84663 .76468 m .84177 .78199 L .82997 .76827 L p .707 .577 .707 r
F P
0 g
s
.82997 .76827 m .83483 .75096 L .84663 .76468 L p .707 .577 .707 r
F P
0 g
s
.3383 .67381 m .34315 .6565 L .32309 .64269 L p .707 .577 .707 r
F P
0 g
s
.81019 .57299 m .81975 .62871 L .79276 .6298 L p .707 .577 .707 r
F P
0 g
s
.79276 .6298 m .7832 .57408 L .81019 .57299 L p .707 .577 .707 r
F P
0 g
s
.67537 .70743 m .67051 .72474 L .65432 .73082 L p .707 .577 .707 r
F P
0 g
s
.84328 .68155 m .84354 .71863 L .82248 .71238 L p .707 .577 .707 r
F P
0 g
s
.82248 .71238 m .82222 .6753 L .84328 .68155 L p .707 .577 .707 r
F P
0 g
s
.45901 .68812 m .45415 .70543 L .4777 .70353 L p .707 .577 .707 r
F P
0 g
s
.4777 .70353 m .48255 .68622 L .45901 .68812 L p .707 .577 .707 r
F P
0 g
s
.49559 .50714 m .50515 .56286 L .5123 .55536 L p .707 .577 .707 r
F P
0 g
s
.5123 .55536 m .50274 .49965 L .49559 .50714 L p .707 .577 .707 r
F P
0 g
s
.69204 .59067 m .7016 .64639 L .67776 .65456 L p .707 .577 .707 r
F P
0 g
s
.32309 .64269 m .31824 .66 L .3383 .67381 L p .707 .577 .707 r
F P
0 g
s
.7016 .64639 m .69204 .59067 L .72109 .58337 L p .707 .577 .707 r
F P
0 g
s
.7832 .57408 m .79276 .6298 L .76206 .63337 L p .707 .577 .707 r
F P
0 g
s
.76206 .63337 m .7525 .57766 L .7832 .57408 L p .707 .577 .707 r
F P
0 g
s
.50867 .58646 m .50893 .62354 L .51602 .61522 L p .707 .577 .707 r
F P
0 g
s
.51602 .61522 m .51575 .57813 L .50867 .58646 L p .707 .577 .707 r
F P
0 g
s
.31824 .66 m .32309 .64269 L .31129 .62897 L p .707 .577 .707 r
F P
0 g
s
.83483 .75096 m .82997 .76827 L .80991 .75446 L p .707 .577 .707 r
F P
0 g
s
.80991 .75446 m .81477 .73715 L .83483 .75096 L p .707 .577 .707 r
F P
0 g
s
.82222 .6753 m .82248 .71238 L .79503 .70821 L p .707 .577 .707 r
F P
0 g
s
.79503 .70821 m .79476 .67113 L .82222 .6753 L p .707 .577 .707 r
F P
0 g
s
.48255 .68622 m .4777 .70353 L .49389 .69745 L p .707 .577 .707 r
F P
0 g
s
.49389 .69745 m .49875 .68014 L .48255 .68622 L p .707 .577 .707 r
F P
0 g
s
.73064 .63909 m .72109 .58337 L .7525 .57766 L p .707 .577 .707 r
F P
0 g
s
.72109 .58337 m .73064 .63909 L .7016 .64639 L p .707 .577 .707 r
F P
0 g
s
.7525 .57766 m .76206 .63337 L .73064 .63909 L p .707 .577 .707 r
F P
0 g
s
.69891 .70553 m .69406 .72284 L .67051 .72474 L p .707 .577 .707 r
F P
0 g
s
.31129 .62897 m .30644 .64628 L .31824 .66 L p .707 .577 .707 r
F P
0 g
s
.70264 .71106 m .70237 .67397 L .73176 .67043 L p .707 .577 .707 r
F P
0 g
s
.50274 .49965 m .5123 .55536 L .50962 .54934 L p .707 .577 .707 r
F P
0 g
s
.50962 .54934 m .50006 .49362 L .50274 .49965 L p .707 .577 .707 r
F P
0 g
s
.79476 .67113 m .79503 .70821 L .76385 .70654 L p .707 .577 .707 r
F P
0 g
s
.76385 .70654 m .76359 .66945 L .79476 .67113 L p .707 .577 .707 r
F P
0 g
s
.73176 .67043 m .73202 .70752 L .70264 .71106 L p .707 .577 .707 r
F P
0 g
s
.69406 .72284 m .69891 .70553 L .7275 .70798 L p .707 .577 .707 r
F P
0 g
s
.73202 .70752 m .73176 .67043 L .76359 .66945 L p .707 .577 .707 r
F P
0 g
s
.81477 .73715 m .80991 .75446 L .78356 .74192 L p .707 .577 .707 r
F P
0 g
s
.78356 .74192 m .78841 .72461 L .81477 .73715 L p .707 .577 .707 r
F P
0 g
s
.76359 .66945 m .76385 .70654 L .73202 .70752 L p .707 .577 .707 r
F P
0 g
s
.30644 .64628 m .31129 .62897 L .3089 .61668 L p .707 .577 .707 r
F P
0 g
s
.7275 .70798 m .72265 .72529 L .69406 .72284 L p .707 .577 .707 r
F P
0 g
s
.51575 .57813 m .51602 .61522 L .51312 .60678 L p .707 .577 .707 r
F P
0 g
s
.51312 .60678 m .51286 .56969 L .51575 .57813 L p .707 .577 .707 r
F P
0 g
s
.49875 .68014 m .49389 .69745 L .50115 .6878 L p .707 .577 .707 r
F P
0 g
s
.50115 .6878 m .50601 .67049 L .49875 .68014 L p .707 .577 .707 r
F P
0 g
s
.3089 .61668 m .30405 .63399 L .30644 .64628 L p .707 .577 .707 r
F P
0 g
s
.3113 .58544 m .30174 .52973 L .3089 .52223 L p .707 .577 .707 r
F P
0 g
s
.72265 .72529 m .7275 .70798 L .75834 .71456 L p .707 .577 .707 r
F P
0 g
s
.78841 .72461 m .78356 .74192 L .75349 .73187 L p .707 .577 .707 r
F P
0 g
s
.75349 .73187 m .75834 .71456 L .78841 .72461 L p .707 .577 .707 r
F P
0 g
s
.75834 .71456 m .75349 .73187 L .72265 .72529 L p .707 .577 .707 r
F P
0 g
s
.50006 .49362 m .50962 .54934 L .49737 .54537 L p .707 .577 .707 r
F P
0 g
s
.49737 .54537 m .48781 .48966 L .50006 .49362 L p .707 .577 .707 r
F P
0 g
s
.30405 .63399 m .3089 .61668 L .31616 .60703 L p .707 .577 .707 r
F P
0 g
s
.50601 .67049 m .50115 .6878 L .49876 .67551 L p .707 .577 .707 r
F P
0 g
s
.49876 .67551 m .50362 .6582 L .50601 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.51286 .56969 m .51312 .60678 L .50053 .59905 L p .707 .577 .707 r
F P
0 g
s
.50053 .59905 m .50026 .56197 L .51286 .56969 L p .707 .577 .707 r
F P
0 g
s
.31616 .60703 m .31131 .62434 L .30405 .63399 L p .707 .577 .707 r
F P
0 g
s
.31846 .57795 m .3089 .52223 L .32519 .51399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48781 .48966 m .49737 .54537 L .47674 .54386 L p .707 .577 .707 r
F P
0 g
s
.47674 .54386 m .46718 .48815 L .48781 .48966 L p .707 .577 .707 r
F P
0 g
s
.31131 .62434 m .31616 .60703 L .33236 .60095 L p .707 .577 .707 r
F P
0 g
s
.50026 .56197 m .50053 .59905 L .47947 .5928 L p .707 .577 .707 r
F P
0 g
s
.47947 .5928 m .47921 .55572 L .50026 .56197 L p .707 .577 .707 r
F P
0 g
s
.50362 .6582 m .49876 .67551 L .48696 .66179 L p .707 .577 .707 r
F P
0 g
s
.48696 .66179 m .49182 .64448 L .50362 .6582 L p .707 .577 .707 r
F P
0 g
s
.33475 .56971 m .32519 .51399 L .34903 .50583 L p .707 .577 .707 r
F P
0 g
s
.33236 .60095 m .3275 .61826 L .31131 .62434 L p .707 .577 .707 r
F P
0 g
s
.46718 .48815 m .47674 .54386 L .44975 .54495 L p .707 .577 .707 r
F P
0 g
s
.44975 .54495 m .44019 .48923 L .46718 .48815 L p .707 .577 .707 r
F P
0 g
s
.35859 .56154 m .34903 .50583 L .37808 .49853 L p .707 .577 .707 r
F P
0 g
s
.47921 .55572 m .47947 .5928 L .45202 .58863 L p .707 .577 .707 r
F P
0 g
s
.45202 .58863 m .45175 .55155 L .47921 .55572 L p .707 .577 .707 r
F P
0 g
s
.3275 .61826 m .33236 .60095 L .3559 .59905 L p .707 .577 .707 r
F P
0 g
s
.49182 .64448 m .48696 .66179 L .4669 .64798 L p .707 .577 .707 r
F P
0 g
s
.4669 .64798 m .47176 .63067 L .49182 .64448 L p .707 .577 .707 r
F P
0 g
s
.44019 .48923 m .44975 .54495 L .41905 .54852 L p .707 .577 .707 r
F P
0 g
s
.41905 .54852 m .40949 .49281 L .44019 .48923 L p .707 .577 .707 r
F P
0 g
s
.3559 .59905 m .35105 .61636 L .3275 .61826 L p .707 .577 .707 r
F P
0 g
s
.40949 .49281 m .41905 .54852 L .38763 .55424 L p .707 .577 .707 r
F P
0 g
s
.45175 .55155 m .45202 .58863 L .42084 .58696 L p .707 .577 .707 r
F P
0 g
s
.42084 .58696 m .42058 .54987 L .45175 .55155 L p .707 .577 .707 r
F P
0 g
s
.35105 .61636 m .3559 .59905 L .38449 .6015 L p .707 .577 .707 r
F P
0 g
s
.42058 .54987 m .42084 .58696 L .38901 .58794 L p .707 .577 .707 r
F P
0 g
s
.47176 .63067 m .4669 .64798 L .44055 .63544 L p .707 .577 .707 r
F P
0 g
s
.44055 .63544 m .4454 .61813 L .47176 .63067 L p .707 .577 .707 r
F P
0 g
s
.38449 .6015 m .37964 .61881 L .35105 .61636 L p .707 .577 .707 r
F P
0 g
s
.37964 .61881 m .38449 .6015 L .41533 .60808 L p .707 .577 .707 r
F P
0 g
s
.4454 .61813 m .44055 .63544 L .41048 .62539 L p .707 .577 .707 r
F P
0 g
s
.41048 .62539 m .41533 .60808 L .4454 .61813 L p .707 .577 .707 r
F P
0 g
s
.41533 .60808 m .41048 .62539 L .37964 .61881 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Uoo`L008eo
o`00Ngoo3P0000=JEP00FUH015YF3000PGoo001eOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH8001iOol006moo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00@007Eoo`00JWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00LWoo001WOol30007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001`Ool006Eo
o`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF008006ioo`00Hgoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Jgoo001QOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1[Ool0061o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool0
05ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00OomJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP0DFUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVaoo`00GWoo00@005YFFUH000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFK7oo001NOol01000FUIJEP001UYF00<0
05YFFUH04eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUI/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1Z
Ool005ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00GWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Jgoo001NOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001[Ool005ioo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Yoo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJgoo001OOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005moo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Uo
o`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00
Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YF00001@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00eYF20000eYF00<0
05YFFUH01P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH00eYF2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00000P002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000
FUIJEP001EYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YF
FUH0009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061oo`03
001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JWoo001N
Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Yoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Moo`8000=JEP03001JEUYF00AJEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Ioo`80
00AJEP8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EGoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Uoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
30000eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uo
o`00EWoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH015YF1P0000=JEP0000001eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JGoo001FOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH@0006FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001YOol005Ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo001FOol01000FUIJEP0015YF00<0
05YFFUH015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEPD0
00AJEP8000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00<0
05YF000015YF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P0025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo
001GOol00`00FUH00005FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol005Moo`03001JEP0000EJEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00@005YFFUH000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000_Ool6000d
Ool005Moo`05001JEUYF001JEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P009Woo2@000eYF00<005YFFUH01@00;goo001HOol01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P007Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002eo
o`00DWoo2@0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P005goo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00B7oo2P0015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`@00003FUH005YF00MJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00@goo1@00
1EYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH:0002FUH5
00000eYF000000060004FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo0011Ool200000eYF001JEP07FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH02@0015YF1`002UYF00@005YFFUIJEPH000AJ
EP03001JEUYF008000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000/Ool003ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH0
0004FUH@0005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH6000015YF001JEUYF0P001UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo0P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000k
Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP0=00000eYF001JEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP040004FUH01000FUH000000UYF0P001eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002Goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000gOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001UYF00000000FUH000IJEP04001JEUYF
FUHA0006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF10001eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000dOol30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005Ool20002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000[Ool0039oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEP000006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0017oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002]oo`00<7oo0P000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
0eYF00<005YFFUH00UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002]oo`00;goo0P0015YF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
0P000eYF4P001eYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH20008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000ZOol002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800005FUH00000FUH00005FUH00`00FUIJEP04FUH0
1000FUIJEUYF10000UYF00<005YFFUH01eYF10000eYF00<005YFFUH015YF00@005YFFUIJEP8000QJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001oogooOol00002FUH01@00FUIJ
EUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH01UYF00@005YFFUIoo`EJEP03001JEUYF00EJEPD00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEP@000QJEP03001JEUYF0080009JEP03001JEUYF00AJEP05001JEUYFFUH00009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00Oomoogoo00000UYF00D005YFFUIJ
EP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002Yoo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP<000AJEP03001JEUYF00AJEP03001JEUYF
009JEP<00004FUH005YFFUH30004FUH00`00FUIJEP03FUH30006FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D007ooOomoo`00009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF
FUIJEP0002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF10001EYF0`0000=JEP00FUH01EYF00@005YFFUIJEPH000EJEP<00003FUH0
05YF00IJEP8000AJEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPP000IJEPD0009JEP03001oogoo02Qoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEPX000=JEP04001JEUYFFUH6
0008FUH20008FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000YOol002moo`03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP<000AJEP80009JEP03
001JEP0000`000YJEP8000EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo
000_Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90002FUH0
1@00FUIJEUYF00001EYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEP`000EJEP8000=JEP03001J
EUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000:Goo000_Ool01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF1P0015YF00<005YFFUH00UYF0`000eYF0`000eYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF10001UYF00@005YFFUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000ZOol002moo`04001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEPD0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP04001JEUYF0006FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000[Ool0031oo`03001J
EP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYFFUH20004FUH0
1000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo00@005YF
FUH000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01000FUH00000;Goo000`Ool00`00FUH00005FUH01000FUIJEUYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`05001JEUYFFUH00003FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000_Ool0
031oo`03001JEP0000EJEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH300000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH30004FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool3FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00<Woo000`Ool01000FUIJEP000eYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF008000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`=JEP8000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00<7oo00D005YFFUH005YF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600001EYF000005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Goo000aOol0
1000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`001eYF10002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P00
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00EJEQP003Yoo`00<Goo0`0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF0000
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUH00005
0003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000fOol0035oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEP000002FUH01000
FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@00
<Goo000aOol00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF6P0015YF10000eYF00<005YF
FUH015YF1`002eYF00<005YFFUH02EYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000eYF00@005YFFUIJEPH000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00@002eoo`00<Goo00<005YF000015YF00@005YFFUIJEPP0
00AJEPL000ioo`H0009JEP<000IJEPD000=JEPD000IJEP03001JEUYF00MJEP@000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP8002aoo`00
<Goo00<005YF000015YF00<005YF00003@006Woo00D005YFFUH005YF008000EJEPD000MJEP03001J
EP0000h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04
001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:Woo000aOol00`00FUH00002FUH40000
0eYF00000005000HOol90002FUH01000FUIJEUYF0`000UYF1@001UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Uoo`00<Goo00<005YF0000
1`000eYF00@005YFFUIJEQP000AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH0000YOol0035oo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00@000QJ
EP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002Qoo`00<Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
100015YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEPT0
00AJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00:7oo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0
00040008FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01EYF
30001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
0P0000=JEP00FUH00UYF2P001UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002Qoo`00<7oo0P000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH015YF
0`001UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH200000eYF001JEP030005FUH01000FUIJEUYF2`0027oo200015YF00<005YFFUH00eYF00@005YF
FUIJEP8002Qoo`00<7oo0P0000EJEP00001JEP0000EJEP04001JEUYFFUH70007FUH00`00FUIJEP06
FUH30004FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEPD00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@0011oo`H000AJEP04001JEUYF
FUH2000XOol0031oo`@0009JEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH40002FUH0
0`00FUIJEP07FUH00`00FUIJEP020002FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00AJEP@000moo`H00003FUH005YF009JEP8002Qoo`00;goo0`000Woo0`001EYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH00eYF0`000eYF00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF01MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP00008000Moo`D000EJEP<000=JEP8002Qoo`00;goo0`0017oo0`000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF10000UYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF009JEP04001JEUYFFUH70004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000X
Ool002moo`04001JEP000006Ool50005FUH01000FUIJEUYF1P001eYF0`0025YF10000eYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01P000UYF00<005YFFUH00UYF1`001UYF00<0
05YFFUH01UYF0`0015YF00<005YFFUH015YF00<005YFFUH00UYF0`00:7oo000_Ool20002FUH00`00
Oomoo`08Ool400000eYF001JEP02FUH60008FUH01000FUH000001EYF00<005YFFUH00P000eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF
009JEP<002Qoo`00<7oo00D005YFFUIJEP0000eooaT000=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40007FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0000XOol0031oo`04
001JEUYFFUH3000AOol3000@Ool30004FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000000`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF0P00:Goo000aOol01000FUIJEP000UYF00<0
07ooOol08goo00<007ooFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF01IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000QJ
EP<000=JEP03001JEUYF009JEP8002Uoo`00<Goo00<005YF000015YF0P0097oo0P000UYF00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF011JEP`000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800004FUH005YF0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH30006FUH01000FUIJEP000UYF00@005YFFUIJEP8002Yoo`00<Woo0P001UYF
00<007ooOol08goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF
2@0035YF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF
0`0000=JEP000000;7oo000cOol00`00FUIJEP04FUH3000TOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00UYF0P0000IJEP00000005YF0007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH2000^Ool003Aoo`8000AJEP03001JEUYF
008002Aoo`=JEP03001JEUYF00=JEP03001JEUYF00AJEPL0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF009JEP80009JEP06001JEUYF
FUH005YF100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P001UYF0P00;Woo000fOol01000FUIJEP001EYF0P008Woo0eYF00<005YFFUH00eYF00<005YFFUH0
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
00000P0015YF0`000UYF00@005YFFUH000=JEP8000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD000AJEP03001JEP0002ioo`00=goo0`001eYF0`007goo0eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF0`000UYF0P001eYF0P003Goo4P001Goo0P000UYF00@005YFFUH002eo
o`00>Goo00<005YFFUH01UYF00@005YF000001eoo`=JEP04001JEUYFFUH20006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH:0007FUH3000TOol20004FUH00`00Oomoo`0ZOol003Yoo`8000EJEP03001JEUYF009JEP<001Yo
o`=JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YF000000AJEP04001J
EUYFFUH2000SOol00`00FUIJEP02FUH00`00Oomoo`0ZOol003aoo`8000=JEP03001JEUYF00AJEPD0
01Ioo`=JEP8000EJEP03OomJEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P008Woo00@005YFFUIJEP8002]oo`00?Woo0`001UYF1@0000=JEP00
00000P004Woo0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF009J
EP<000QJEP80025oo`05001JEP00FUH0000[Ool0041oo`8000EJEPD000EJEQ800003FUH005YF00]J
EP03Ool005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH00002
000OOol200000eYF001oo`0ZOol0049oo`<0009JEPD000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00EJEP8000IJEP03001J
EUYF009JEP<001eoo`8002aoo`00AGoo1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
000000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP06
FUH3000IOol3000/Ool004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006
FUH00gooFUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH025YF00<005YF00000`004goo0P0000=JEP00Ool0;7oo001;Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00002000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30007FUH00`00FUIJEP04FUHC0002FUH2000]Ool004mooa<0009oo`8000AJEP03
OomJEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Woo001VOol2000:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH0000@0004FUH00`00FUIJEP03FUH01000FUIJEUYF100000=J
EP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo001XOol20008FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH5
000@Ool60004FUH01000FUIJEUYF0P000Woo10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00JGoo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH010001EYF10004Goo100000=JEP00FUH00UYF0P001Woo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000031oo`00K7oo10000UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=JEP00FUH025YF00<005YF0000
0P001goo1`000eYF0`000eYF0P002Woo4`00<Woo001`Ool80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000Cgoo001hOol;0006FUH00`00FUIJEP04FUH;0002FUH00`00
FUIJEP02FUH70006FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001?
Ool008=oo`d00003OomJEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH4
0002FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0`00Cgoo
002AOol40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40007FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0001?Ool0091oo`D0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00AJEP8000EJEP03001J
EUYF009JEP03001JEP0004moo`00T7oo00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF0`000eYF00<005YFFUH00UYF
0P00D7oo002@Ool00`00FUH00002FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30007FUH01000FUIJEP000UYF00@005YFFUIJEP80055oo`00T7oo00<005YFFUH0
0UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03
001JEUYF009JEP<00003FUH0000005=oo`00TGoo00<005YFOol00UYF10000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00EJEP8005Eoo`00TGoo
00<005YFFUH00UYF0`0000=oo`0000000`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0P001UYF0P00EGoo002BOol01000FUIJEP000eYF00<007ooOol00goo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0015YF00<005YF0000EGoo002BOol01000FUIJ
EP0015YF0P001goo6@001Goo0P000UYF00@005YFFUH005Aoo`00Tgoo00<005YFFUH01UYF0P009Goo
0P0015YF00<007ooOol0DGoo002DOol00`00FUIJEP05FUH01000FUH0000097oo00<005YFFUH00UYF
00<007ooOol0DGoo002EOol20004FUH00`00FUIJEP02FUH2000SOol01@00FUIJEUYF0000Dgoo002G
Ool01@00FUIJEUYF00001UYF0`008Goo00D005YF001JEP00059oo`00V7oo0`0025YF00<005YF0000
0P007goo0P0000=JEP00Ool0DGoo002JOol20007FUH00`00FUIJEP02FUH3000MOol00`00FUH0001B
Ool009aoo`8000AJEP03001JEUYF00IJEP<001Uoo`<005=oo`00WWoo0`0000=JEP00FUH025YF00<0
05YF00000`004goo0P0000=JEP000000Dgoo002QOol30007FUH00`00FUIJEP04FUH60008Ool50002
FUH2001DOol00:Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00
E7oo002VOol300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001E
Ool00:Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:eoo`@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol00;5oo`H000AJEP04001JEUYF
FUH5001IOol00;Moo`P005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60505 .76176 m .59912 .70588 L .56813 .70737 L p .707 .577 .707 r
F P
0 g
s
.59912 .70588 m .60505 .76176 L .63672 .75793 L p .707 .577 .707 r
F P
0 g
s
.63672 .75793 m .63079 .70205 L .59912 .70588 L p .707 .577 .707 r
F P
0 g
s
.63079 .70205 m .63672 .75793 L .66597 .75213 L p .707 .577 .707 r
F P
0 g
s
.66597 .75213 m .66004 .69625 L .63079 .70205 L p .707 .577 .707 r
F P
0 g
s
.57405 .76324 m .56813 .70737 L .54085 .70636 L p .707 .577 .707 r
F P
0 g
s
.56813 .70737 m .57405 .76324 L .60505 .76176 L p .707 .577 .707 r
F P
0 g
s
.66004 .69625 m .66597 .75213 L .68994 .74492 L p .707 .577 .707 r
F P
0 g
s
.68994 .74492 m .68402 .68905 L .66004 .69625 L p .707 .577 .707 r
F P
0 g
s
.54085 .70636 m .54678 .76224 L .57405 .76324 L p .707 .577 .707 r
F P
0 g
s
.60662 .83642 m .60645 .79935 L .57528 .79759 L p .707 .577 .707 r
F P
0 g
s
.60645 .79935 m .60662 .83642 L .63845 .83552 L p .707 .577 .707 r
F P
0 g
s
.63845 .83552 m .63829 .79845 L .60645 .79935 L p .707 .577 .707 r
F P
0 g
s
.54678 .76224 m .54085 .70636 L .51996 .70296 L p .707 .577 .707 r
F P
0 g
s
.63829 .79845 m .63845 .83552 L .66783 .83204 L p .707 .577 .707 r
F P
0 g
s
.66783 .83204 m .66767 .79497 L .63829 .79845 L p .707 .577 .707 r
F P
0 g
s
.57545 .83466 m .57528 .79759 L .54783 .79333 L p .707 .577 .707 r
F P
0 g
s
.57528 .79759 m .57545 .83466 L .60662 .83642 L p .707 .577 .707 r
F P
0 g
s
.68402 .68905 m .68994 .74492 L .70628 .73702 L p .707 .577 .707 r
F P
0 g
s
.70628 .73702 m .70036 .68114 L .68402 .68905 L p .707 .577 .707 r
F P
0 g
s
.51996 .70296 m .52588 .75884 L .54678 .76224 L p .707 .577 .707 r
F P
0 g
s
.66767 .79497 m .66783 .83204 L .69189 .82633 L p .707 .577 .707 r
F P
0 g
s
.69189 .82633 m .69172 .78925 L .66767 .79497 L p .707 .577 .707 r
F P
0 g
s
.54783 .79333 m .54799 .8304 L .57545 .83466 L p .707 .577 .707 r
F P
0 g
s
.59909 .87855 m .60212 .86062 L .57137 .85361 L p .707 .577 .707 r
F P
0 g
s
.60212 .86062 m .59909 .87855 L .63055 .88238 L p .707 .577 .707 r
F P
0 g
s
.63055 .88238 m .63357 .86445 L .60212 .86062 L p .707 .577 .707 r
F P
0 g
s
.54799 .8304 m .54783 .79333 L .52677 .787 L p .707 .577 .707 r
F P
0 g
s
.63357 .86445 m .63055 .88238 L .65963 .88266 L p .707 .577 .707 r
F P
0 g
s
.65963 .88266 m .66265 .86472 L .63357 .86445 L p .707 .577 .707 r
F P
0 g
s
.56835 .87155 m .57137 .85361 L .54433 .84412 L p .707 .577 .707 r
F P
0 g
s
.57137 .85361 m .56835 .87155 L .59909 .87855 L p .707 .577 .707 r
F P
0 g
s
.52588 .75884 m .51996 .70296 L .50749 .6975 L p .707 .577 .707 r
F P
0 g
s
.54433 .84412 m .54131 .86205 L .56835 .87155 L p .707 .577 .707 r
F P
0 g
s
.52677 .787 m .52693 .82408 L .54799 .8304 L p .707 .577 .707 r
F P
0 g
s
.69172 .78925 m .69189 .82633 L .70826 .81894 L p .707 .577 .707 r
F P
0 g
s
.70826 .81894 m .70809 .78186 L .69172 .78925 L p .707 .577 .707 r
F P
0 g
s
.66265 .86472 m .65963 .88266 L .68349 .87936 L p .707 .577 .707 r
F P
0 g
s
.68349 .87936 m .68651 .86142 L .66265 .86472 L p .707 .577 .707 r
F P
0 g
s
.70036 .68114 m .70628 .73702 L .71339 .72919 L p .707 .577 .707 r
F P
0 g
s
.71339 .72919 m .70747 .67331 L .70036 .68114 L p .707 .577 .707 r
F P
0 g
s
.54131 .86205 m .54433 .84412 L .52366 .83306 L p .707 .577 .707 r
F P
0 g
s
.50749 .6975 m .51342 .75337 L .52588 .75884 L p .707 .577 .707 r
F P
0 g
s
.52366 .83306 m .52064 .85099 L .54131 .86205 L p .707 .577 .707 r
F P
0 g
s
.52693 .82408 m .52677 .787 L .51418 .77922 L p .707 .577 .707 r
F P
0 g
s
.51342 .75337 m .50749 .6975 L .50468 .69051 L p .707 .577 .707 r
F P
0 g
s
.51418 .77922 m .51434 .81629 L .52693 .82408 L p .707 .577 .707 r
F P
0 g
s
.68651 .86142 m .68349 .87936 L .69979 .8728 L p .707 .577 .707 r
F P
0 g
s
.69979 .8728 m .70281 .85486 L .68651 .86142 L p .707 .577 .707 r
F P
0 g
s
.52064 .85099 m .52366 .83306 L .51137 .82152 L p .707 .577 .707 r
F P
0 g
s
.70809 .78186 m .70826 .81894 L .71534 .81059 L p .707 .577 .707 r
F P
0 g
s
.71534 .81059 m .71518 .77352 L .70809 .78186 L p .707 .577 .707 r
F P
0 g
s
.51137 .82152 m .50835 .83945 L .52064 .85099 L p .707 .577 .707 r
F P
0 g
s
.70747 .67331 m .71339 .72919 L .71058 .7222 L p .707 .577 .707 r
F P
0 g
s
.71058 .7222 m .70465 .66633 L .70747 .67331 L p .707 .577 .707 r
F P
0 g
s
.50468 .69051 m .5106 .74639 L .51342 .75337 L p .707 .577 .707 r
F P
0 g
s
.51434 .81629 m .51418 .77922 L .51128 .77074 L p .707 .577 .707 r
F P
0 g
s
.48675 .82039 m .47568 .31745 L .43169 .31575 L p .707 .577 .707 r
F P
0 g
s
.51128 .77074 m .51144 .80781 L .51434 .81629 L p .707 .577 .707 r
F P
0 g
s
.5106 .74639 m .50468 .69051 L .51179 .68268 L p .707 .577 .707 r
F P
0 g
s
.50835 .83945 m .51137 .82152 L .50867 .81063 L p .707 .577 .707 r
F P
0 g
s
.50867 .81063 m .50565 .82856 L .50835 .83945 L p .707 .577 .707 r
F P
0 g
s
.51179 .68268 m .51772 .73856 L .5106 .74639 L p .707 .577 .707 r
F P
0 g
s
.51144 .80781 m .51128 .77074 L .51836 .7624 L p .707 .577 .707 r
F P
0 g
s
.51836 .7624 m .51853 .79947 L .51144 .80781 L p .707 .577 .707 r
F P
0 g
s
.51772 .73856 m .51179 .68268 L .52813 .67478 L p .707 .577 .707 r
F P
0 g
s
.50565 .82856 m .50867 .81063 L .51582 .80146 L p .707 .577 .707 r
F P
0 g
s
.51582 .80146 m .5128 .81939 L .50565 .82856 L p .707 .577 .707 r
F P
0 g
s
.52813 .67478 m .53406 .73066 L .51772 .73856 L p .707 .577 .707 r
F P
0 g
s
.51853 .79947 m .51836 .7624 L .53473 .75501 L p .707 .577 .707 r
F P
0 g
s
.53473 .75501 m .5349 .79208 L .51853 .79947 L p .707 .577 .707 r
F P
0 g
s
.5128 .81939 m .51582 .80146 L .53212 .7949 L p .707 .577 .707 r
F P
0 g
s
.53212 .7949 m .5291 .81283 L .5128 .81939 L p .707 .577 .707 r
F P
0 g
s
.5291 .81283 m .53212 .7949 L .55598 .79159 L p .707 .577 .707 r
F P
0 g
s
.55598 .79159 m .55296 .80953 L .5291 .81283 L p .707 .577 .707 r
F P
0 g
s
.47568 .31745 m .48675 .82039 L .53169 .81841 L p .707 .577 .707 r
F P
0 g
s
.53406 .73066 m .52813 .67478 L .5521 .66757 L p .707 .577 .707 r
F P
0 g
s
.53169 .81841 m .52062 .31546 L .47568 .31745 L p .707 .577 .707 r
F P
0 g
s
.70281 .85486 m .69979 .8728 L .70694 .86362 L p .707 .577 .707 r
F P
0 g
s
.70694 .86362 m .70996 .84569 L .70281 .85486 L p .707 .577 .707 r
F P
0 g
s
.5521 .66757 m .55803 .72345 L .53406 .73066 L p .707 .577 .707 r
F P
0 g
s
.5349 .79208 m .53473 .75501 L .55879 .7493 L p .707 .577 .707 r
F P
0 g
s
.55803 .72345 m .5521 .66757 L .58135 .66177 L p .707 .577 .707 r
F P
0 g
s
.55879 .7493 m .55895 .78637 L .5349 .79208 L p .707 .577 .707 r
F P
0 g
s
.58135 .66177 m .58728 .71765 L .55803 .72345 L p .707 .577 .707 r
F P
0 g
s
.55895 .78637 m .55879 .7493 L .58817 .74582 L p .707 .577 .707 r
F P
0 g
s
.58817 .74582 m .58833 .78289 L .55895 .78637 L p .707 .577 .707 r
F P
0 g
s
.55296 .80953 m .55598 .79159 L .58506 .79187 L p .707 .577 .707 r
F P
0 g
s
.58506 .79187 m .58204 .80981 L .55296 .80953 L p .707 .577 .707 r
F P
0 g
s
.52062 .31546 m .53169 .81841 L .57316 .81294 L p .707 .577 .707 r
F P
0 g
s
.57316 .81294 m .56209 .30999 L .52062 .31546 L p .707 .577 .707 r
F P
0 g
s
.71518 .77352 m .71534 .81059 L .71244 .80212 L p .707 .577 .707 r
F P
0 g
s
.71244 .80212 m .71228 .76504 L .71518 .77352 L p .707 .577 .707 r
F P
0 g
s
.44276 .81869 m .43169 .31575 L .39293 .31053 L p .707 .577 .707 r
F P
0 g
s
.43169 .31575 m .44276 .81869 L .48675 .82039 L p .707 .577 .707 r
F P
0 g
s
.70465 .66633 m .71058 .7222 L .69812 .71674 L p .707 .577 .707 r
F P
0 g
s
.69812 .71674 m .69219 .66087 L .70465 .66633 L p .707 .577 .707 r
F P
0 g
s
.26204 .69526 m .25611 .63938 L .22512 .64087 L p .707 .577 .707 r
F P
0 g
s
.25611 .63938 m .26204 .69526 L .29371 .69143 L p .707 .577 .707 r
F P
0 g
s
.29371 .69143 m .28778 .63555 L .25611 .63938 L p .707 .577 .707 r
F P
0 g
s
.58728 .71765 m .58135 .66177 L .61303 .65794 L p .707 .577 .707 r
F P
0 g
s
.61303 .65794 m .61895 .71382 L .58728 .71765 L p .707 .577 .707 r
F P
0 g
s
.58833 .78289 m .58817 .74582 L .62 .74491 L p .707 .577 .707 r
F P
0 g
s
.62 .74491 m .62017 .78199 L .58833 .78289 L p .707 .577 .707 r
F P
0 g
s
.58204 .80981 m .58506 .79187 L .61651 .7957 L p .707 .577 .707 r
F P
0 g
s
.61651 .7957 m .61349 .81363 L .58204 .80981 L p .707 .577 .707 r
F P
0 g
s
.56209 .30999 m .57316 .81294 L .60711 .80451 L p .707 .577 .707 r
F P
0 g
s
.60711 .80451 m .59604 .30156 L .56209 .30999 L p .707 .577 .707 r
F P
0 g
s
.28778 .63555 m .29371 .69143 L .32296 .68563 L p .707 .577 .707 r
F P
0 g
s
.32296 .68563 m .31704 .62975 L .28778 .63555 L p .707 .577 .707 r
F P
0 g
s
.23104 .69674 m .22512 .64087 L .19784 .63986 L p .707 .577 .707 r
F P
0 g
s
.22512 .64087 m .23104 .69674 L .26204 .69526 L p .707 .577 .707 r
F P
0 g
s
.70996 .84569 m .70694 .86362 L .70424 .85274 L p .707 .577 .707 r
F P
0 g
s
.70424 .85274 m .70726 .8348 L .70996 .84569 L p .707 .577 .707 r
F P
0 g
s
.404 .81348 m .39293 .31053 L .36322 .30231 L p .707 .577 .707 r
F P
0 g
s
.39293 .31053 m .404 .81348 L .44276 .81869 L p .707 .577 .707 r
F P
0 g
s
.31704 .62975 m .32296 .68563 L .34693 .67842 L p .707 .577 .707 r
F P
0 g
s
.34693 .67842 m .34101 .62254 L .31704 .62975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26361 .74845 m .26345 .71138 L .23227 .70962 L p .707 .577 .707 r
F P
0 g
s
.26345 .71138 m .26361 .74845 L .29544 .74755 L p .707 .577 .707 r
F P
0 g
s
.29544 .74755 m .29528 .71048 L .26345 .71138 L p .707 .577 .707 r
F P
0 g
s
.29528 .71048 m .29544 .74755 L .32483 .74407 L p .707 .577 .707 r
F P
0 g
s
.32483 .74407 m .32466 .707 L .29528 .71048 L p .707 .577 .707 r
F P
0 g
s
.19784 .63986 m .20377 .69574 L .23104 .69674 L p .707 .577 .707 r
F P
0 g
s
.71228 .76504 m .71244 .80212 L .69985 .79433 L p .707 .577 .707 r
F P
0 g
s
.69985 .79433 m .69969 .75726 L .71228 .76504 L p .707 .577 .707 r
F P
0 g
s
.23244 .74669 m .23227 .70962 L .20482 .70537 L p .707 .577 .707 r
F P
0 g
s
.23227 .70962 m .23244 .74669 L .26361 .74845 L p .707 .577 .707 r
F P
0 g
s
.20377 .69574 m .19784 .63986 L .17695 .63646 L p .707 .577 .707 r
F P
0 g
s
.69219 .66087 m .69812 .71674 L .67722 .71334 L p .707 .577 .707 r
F P
0 g
s
.67722 .71334 m .6713 .65746 L .69219 .66087 L p .707 .577 .707 r
F P
0 g
s
.64402 .65646 m .64995 .71233 L .61895 .71382 L p .707 .577 .707 r
F P
0 g
s
.61895 .71382 m .61303 .65794 L .64402 .65646 L p .707 .577 .707 r
F P
0 g
s
.65118 .74668 m .65134 .78375 L .62017 .78199 L p .707 .577 .707 r
F P
0 g
s
.62017 .78199 m .62 .74491 L .65118 .74668 L p .707 .577 .707 r
F P
0 g
s
.61349 .81363 m .61651 .7957 L .64726 .8027 L p .707 .577 .707 r
F P
0 g
s
.59604 .30156 m .60711 .80451 L .63022 .79395 L p .707 .577 .707 r
F P
0 g
s
.63022 .79395 m .61915 .291 L .59604 .30156 L p .707 .577 .707 r
F P
0 g
s
.32466 .707 m .32483 .74407 L .34888 .73836 L p .707 .577 .707 r
F P
0 g
s
.34888 .73836 m .34872 .70129 L .32466 .707 L p .707 .577 .707 r
F P
0 g
s
.34101 .62254 m .34693 .67842 L .36327 .67052 L p .707 .577 .707 r
F P
0 g
s
.36327 .67052 m .35735 .61464 L .34101 .62254 L p .707 .577 .707 r
F P
0 g
s
.20482 .70537 m .20498 .74244 L .23244 .74669 L p .707 .577 .707 r
F P
0 g
s
.17695 .63646 m .18287 .69233 L .20377 .69574 L p .707 .577 .707 r
F P
0 g
s
.25609 .79869 m .25911 .78075 L .22836 .77374 L p .707 .577 .707 r
F P
0 g
s
.25911 .78075 m .25609 .79869 L .28754 .80251 L p .707 .577 .707 r
F P
0 g
s
.28754 .80251 m .29056 .78458 L .25911 .78075 L p .707 .577 .707 r
F P
0 g
s
.20498 .74244 m .20482 .70537 L .18376 .69904 L p .707 .577 .707 r
F P
0 g
s
.29056 .78458 m .28754 .80251 L .31662 .80279 L p .707 .577 .707 r
F P
0 g
s
.31662 .80279 m .31964 .78485 L .29056 .78458 L p .707 .577 .707 r
F P
0 g
s
.70726 .8348 m .70424 .85274 L .69195 .8412 L p .707 .577 .707 r
F P
0 g
s
.69195 .8412 m .69497 .82326 L .70726 .8348 L p .707 .577 .707 r
F P
0 g
s
.22534 .79168 m .22836 .77374 L .20133 .76425 L p .707 .577 .707 r
F P
0 g
s
.22836 .77374 m .22534 .79168 L .25609 .79869 L p .707 .577 .707 r
F P
0 g
s
.35735 .61464 m .36327 .67052 L .37039 .66269 L p .707 .577 .707 r
F P
0 g
s
.37039 .66269 m .36446 .60681 L .35735 .61464 L p .707 .577 .707 r
F P
0 g
s
.36508 .6939 m .36525 .73097 L .37233 .72263 L p .707 .577 .707 r
F P
0 g
s
.37233 .72263 m .37217 .68556 L .36508 .6939 L p .707 .577 .707 r
F P
0 g
s
.36446 .60681 m .37039 .66269 L .36757 .6557 L p .707 .577 .707 r
F P
0 g
s
.36757 .6557 m .36164 .59983 L .36446 .60681 L p .707 .577 .707 r
F P
0 g
s
.37217 .68556 m .37233 .72263 L .36943 .71415 L p .707 .577 .707 r
F P
0 g
s
.36943 .71415 m .36927 .67708 L .37217 .68556 L p .707 .577 .707 r
F P
0 g
s
.36164 .59983 m .36757 .6557 L .35511 .65024 L p .707 .577 .707 r
F P
0 g
s
.36525 .73097 m .36508 .6939 L .34872 .70129 L p .707 .577 .707 r
F P
0 g
s
.36927 .67708 m .36943 .71415 L .35684 .70637 L p .707 .577 .707 r
F P
0 g
s
.35684 .70637 m .35668 .66929 L .36927 .67708 L p .707 .577 .707 r
F P
0 g
s
.37429 .80525 m .36322 .30231 L .34545 .29188 L p .707 .577 .707 r
F P
0 g
s
.36322 .30231 m .37429 .80525 L .404 .81348 L p .707 .577 .707 r
F P
0 g
s
.18287 .69233 m .17695 .63646 L .16448 .631 L p .707 .577 .707 r
F P
0 g
s
.20133 .76425 m .1983 .78218 L .22534 .79168 L p .707 .577 .707 r
F P
0 g
s
.69969 .75726 m .69985 .79433 L .6788 .788 L p .707 .577 .707 r
F P
0 g
s
.6788 .788 m .67863 .75093 L .69969 .75726 L p .707 .577 .707 r
F P
0 g
s
.6713 .65746 m .67722 .71334 L .64995 .71233 L p .707 .577 .707 r
F P
0 g
s
.64995 .71233 m .64402 .65646 L .6713 .65746 L p .707 .577 .707 r
F P
0 g
s
.18376 .69904 m .18392 .73611 L .20498 .74244 L p .707 .577 .707 r
F P
0 g
s
.34872 .70129 m .34888 .73836 L .36525 .73097 L p .707 .577 .707 r
F P
0 g
s
.31964 .78485 m .31662 .80279 L .34048 .79949 L p .707 .577 .707 r
F P
0 g
s
.34048 .79949 m .3435 .78155 L .31964 .78485 L p .707 .577 .707 r
F P
0 g
s
.1983 .78218 m .20133 .76425 L .18065 .75319 L p .707 .577 .707 r
F P
0 g
s
.16448 .631 m .17041 .68687 L .18287 .69233 L p .707 .577 .707 r
F P
0 g
s
.18392 .73611 m .18376 .69904 L .17117 .69125 L p .707 .577 .707 r
F P
0 g
s
.18065 .75319 m .17763 .77112 L .1983 .78218 L p .707 .577 .707 r
F P
0 g
s
.61915 .291 m .63022 .79395 L .64022 .7823 L p .707 .577 .707 r
F P
0 g
s
.64022 .7823 m .62915 .27935 L .61915 .291 L p .707 .577 .707 r
F P
0 g
s
.69497 .82326 m .69195 .8412 L .67127 .83014 L p .707 .577 .707 r
F P
0 g
s
.67127 .83014 m .6743 .8122 L .69497 .82326 L p .707 .577 .707 r
F P
0 g
s
.67863 .75093 m .6788 .788 L .65134 .78375 L p .707 .577 .707 r
F P
0 g
s
.65134 .78375 m .65118 .74668 L .67863 .75093 L p .707 .577 .707 r
F P
0 g
s
.17117 .69125 m .17133 .72833 L .18392 .73611 L p .707 .577 .707 r
F P
0 g
s
.3435 .78155 m .34048 .79949 L .35678 .79293 L p .707 .577 .707 r
F P
0 g
s
.35678 .79293 m .3598 .77499 L .3435 .78155 L p .707 .577 .707 r
F P
0 g
s
.17041 .68687 m .16448 .631 L .16167 .62401 L p .707 .577 .707 r
F P
0 g
s
.17763 .77112 m .18065 .75319 L .16836 .74165 L p .707 .577 .707 r
F P
0 g
s
.16836 .74165 m .16534 .75958 L .17763 .77112 L p .707 .577 .707 r
F P
0 g
s
.35511 .65024 m .35495 .64871 L p .36164 .59983 L .707 .577 .707 r
F P
0 g
s
.35495 .64871 m .34918 .59436 L .35477 .59681 L p .707 .577 .707 r
F P
0 g
s
.35477 .59681 m .36164 .59983 L p .35495 .64871 L .707 .577 .707 r
F P
0 g
s
.34918 .59436 m .35511 .65024 L .33421 .64684 L p .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35196 .74339 L .35826 .74931 L p .707 .577 .707 r
F P
0 g
s
.35826 .74931 m .36425 .75493 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35826 .74931 L .35871 .75725 L .707 .577 .707 r
F
.34545 .29188 m .34136 .28027 L p .35175 .63288 L F P
0 g
s
.35668 .66929 m .35684 .70637 L .33579 .70004 L p .707 .577 .707 r
F P
0 g
s
.33579 .70004 m .33562 .66296 L .35668 .66929 L p .707 .577 .707 r
F P
0 g
s
.3553 .75364 m .35333 .66115 L .35175 .63288 L .707 .577 .707 r
F
.35333 .66115 m .34545 .29188 L .35175 .63288 L F
.36425 .75493 m .36123 .77287 L .35949 .77124 L p F P
0 g
s
.35949 .77124 m .34894 .76133 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.35871 .75725 m .36425 .75493 L .35949 .77124 L .707 .577 .707 r
F
.35243 .78322 m .35652 .79483 L p .35175 .63288 L F P
0 g
s
.34136 .28027 m .34742 .5556 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.33421 .64684 m .32829 .59096 L .34918 .59436 L p .707 .577 .707 r
F P
0 g
s
.35196 .74339 m .34894 .76133 L .32826 .75027 L p .707 .577 .707 r
F P
0 g
s
.32826 .75027 m .33129 .73233 L .35196 .74339 L p .707 .577 .707 r
F P
0 g
s
.34742 .5556 m .35243 .78322 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.35652 .79483 m .35525 .73716 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.35525 .73716 m .34545 .29188 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.3598 .77499 m .35678 .79293 L .36393 .78375 L p .707 .577 .707 r
F P
0 g
s
.36393 .78375 m .36695 .76582 L .3598 .77499 L p .707 .577 .707 r
F P
0 g
s
.36695 .76582 m .36393 .78375 L .36123 .77287 L p .707 .577 .707 r
F P
0 g
s
.36123 .77287 m .36425 .75493 L .36695 .76582 L p .707 .577 .707 r
F P
0 g
s
.34545 .29188 m .35652 .79483 L .37429 .80525 L p .707 .577 .707 r
F P
0 g
s
.16167 .62401 m .1676 .67989 L .17041 .68687 L p .707 .577 .707 r
F P
0 g
s
.17133 .72833 m .17117 .69125 L .16827 .68278 L p .707 .577 .707 r
F P
0 g
s
.6743 .8122 m .67127 .83014 L .64424 .82064 L p .707 .577 .707 r
F P
0 g
s
.64424 .82064 m .64726 .8027 L .6743 .8122 L p .707 .577 .707 r
F P
0 g
s
.16827 .68278 m .16843 .71985 L .17133 .72833 L p .707 .577 .707 r
F P
0 g
s
.64726 .8027 m .64424 .82064 L .61349 .81363 L p .707 .577 .707 r
F P
0 g
s
.16534 .75958 m .16836 .74165 L .16566 .73076 L p .707 .577 .707 r
F P
0 g
s
.1676 .67989 m .16167 .62401 L .16878 .61618 L p .707 .577 .707 r
F P
0 g
s
.62915 .27935 m .64022 .7823 L .63614 .77069 L p .707 .577 .707 r
F P
0 g
s
.63614 .77069 m .62507 .26774 L .62915 .27935 L p .707 .577 .707 r
F P
0 g
s
.16566 .73076 m .16264 .7487 L .16534 .75958 L p .707 .577 .707 r
F P
0 g
s
.16878 .61618 m .17471 .67206 L .1676 .67989 L p .707 .577 .707 r
F P
0 g
s
.16843 .71985 m .16827 .68278 L .17535 .67443 L p .707 .577 .707 r
F P
0 g
s
.35243 .78322 m .34136 .28027 L .35137 .26862 L p .707 .577 .707 r
F P
0 g
s
.17535 .67443 m .17552 .7115 L .16843 .71985 L p .707 .577 .707 r
F P
0 g
s
.16264 .7487 m .16566 .73076 L .17281 .72159 L p .707 .577 .707 r
F P
0 g
s
.17471 .67206 m .16878 .61618 L .18512 .60828 L p .707 .577 .707 r
F P
0 g
s
.17281 .72159 m .16979 .73952 L .16264 .7487 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18512 .60828 m .19105 .66415 L .17471 .67206 L p .707 .577 .707 r
F P
0 g
s
.17552 .7115 m .17535 .67443 L .19172 .66704 L p .707 .577 .707 r
F P
0 g
s
.62507 .26774 m .63614 .77069 L .61837 .76026 L p .707 .577 .707 r
F P
0 g
s
.61837 .76026 m .6073 .25732 L .62507 .26774 L p .707 .577 .707 r
F P
0 g
s
.19172 .66704 m .19189 .70411 L .17552 .7115 L p .707 .577 .707 r
F P
0 g
s
.19105 .66415 m .18512 .60828 L .20909 .60107 L p .707 .577 .707 r
F P
0 g
s
.16979 .73952 m .17281 .72159 L .18911 .71503 L p .707 .577 .707 r
F P
0 g
s
.36243 .77157 m .35137 .26862 L .37447 .25806 L p .707 .577 .707 r
F P
0 g
s
.35137 .26862 m .36243 .77157 L .35243 .78322 L p .707 .577 .707 r
F P
0 g
s
.18911 .71503 m .18609 .73296 L .16979 .73952 L p .707 .577 .707 r
F P
0 g
s
.32829 .59096 m .33421 .64684 L .30694 .64583 L p .707 .577 .707 r
F P
0 g
s
.30694 .64583 m .30101 .58996 L .32829 .59096 L p .707 .577 .707 r
F P
0 g
s
.20909 .60107 m .21502 .65695 L .19105 .66415 L p .707 .577 .707 r
F P
0 g
s
.19189 .70411 m .19172 .66704 L .21578 .66133 L p .707 .577 .707 r
F P
0 g
s
.21502 .65695 m .20909 .60107 L .23834 .59527 L p .707 .577 .707 r
F P
0 g
s
.21578 .66133 m .21594 .6984 L .19189 .70411 L p .707 .577 .707 r
F P
0 g
s
.30101 .58996 m .30694 .64583 L .27594 .64732 L p .707 .577 .707 r
F P
0 g
s
.27594 .64732 m .27002 .59144 L .30101 .58996 L p .707 .577 .707 r
F P
0 g
s
.33562 .66296 m .33579 .70004 L .30833 .69578 L p .707 .577 .707 r
F P
0 g
s
.30833 .69578 m .30817 .65871 L .33562 .66296 L p .707 .577 .707 r
F P
0 g
s
.18609 .73296 m .18911 .71503 L .21297 .71173 L p .707 .577 .707 r
F P
0 g
s
.6073 .25732 m .61837 .76026 L .58865 .75204 L p .707 .577 .707 r
F P
0 g
s
.58865 .75204 m .57758 .24909 L .6073 .25732 L p .707 .577 .707 r
F P
0 g
s
.24427 .65115 m .23834 .59527 L .27002 .59144 L p .707 .577 .707 r
F P
0 g
s
.23834 .59527 m .24427 .65115 L .21502 .65695 L p .707 .577 .707 r
F P
0 g
s
.27002 .59144 m .27594 .64732 L .24427 .65115 L p .707 .577 .707 r
F P
0 g
s
.21594 .6984 m .21578 .66133 L .24516 .65785 L p .707 .577 .707 r
F P
0 g
s
.21297 .71173 m .20995 .72966 L .18609 .73296 L p .707 .577 .707 r
F P
0 g
s
.74225 .66972 m .73632 .61384 L .70533 .61533 L p .707 .577 .707 r
F P
0 g
s
.73632 .61384 m .74225 .66972 L .77392 .66589 L p .707 .577 .707 r
F P
0 g
s
.77392 .66589 m .768 .61001 L .73632 .61384 L p .707 .577 .707 r
F P
0 g
s
.30817 .65871 m .30833 .69578 L .27716 .69402 L p .707 .577 .707 r
F P
0 g
s
.27716 .69402 m .27699 .65695 L .30817 .65871 L p .707 .577 .707 r
F P
0 g
s
.768 .61001 m .77392 .66589 L .80318 .66009 L p .707 .577 .707 r
F P
0 g
s
.80318 .66009 m .79725 .60421 L .768 .61001 L p .707 .577 .707 r
F P
0 g
s
.24516 .65785 m .24532 .69492 L .21594 .6984 L p .707 .577 .707 r
F P
0 g
s
.37447 .25806 m .38554 .76101 L .36243 .77157 L p .707 .577 .707 r
F P
0 g
s
.38554 .76101 m .37447 .25806 L .40843 .24964 L p .707 .577 .707 r
F P
0 g
s
.24532 .69492 m .24516 .65785 L .27699 .65695 L p .707 .577 .707 r
F P
0 g
s
.33129 .73233 m .32826 .75027 L .30123 .74077 L p .707 .577 .707 r
F P
0 g
s
.30123 .74077 m .30425 .72283 L .33129 .73233 L p .707 .577 .707 r
F P
0 g
s
.27699 .65695 m .27716 .69402 L .24532 .69492 L p .707 .577 .707 r
F P
0 g
s
.20995 .72966 m .21297 .71173 L .24205 .712 L p .707 .577 .707 r
F P
0 g
s
.71126 .67121 m .70533 .61533 L .67805 .61432 L p .707 .577 .707 r
F P
0 g
s
.70533 .61533 m .71126 .67121 L .74225 .66972 L p .707 .577 .707 r
F P
0 g
s
.79725 .60421 m .80318 .66009 L .82715 .65288 L p .707 .577 .707 r
F P
0 g
s
.82715 .65288 m .82122 .59701 L .79725 .60421 L p .707 .577 .707 r
F P
0 g
s
.24205 .712 m .23903 .72994 L .20995 .72966 L p .707 .577 .707 r
F P
0 g
s
.30425 .72283 m .30123 .74077 L .27048 .73376 L p .707 .577 .707 r
F P
0 g
s
.27048 .73376 m .2735 .71583 L .30425 .72283 L p .707 .577 .707 r
F P
0 g
s
.57758 .24909 m .58865 .75204 L .5499 .74682 L p .707 .577 .707 r
F P
0 g
s
.5499 .74682 m .53883 .24388 L .57758 .24909 L p .707 .577 .707 r
F P
0 g
s
.23903 .72994 m .24205 .712 L .2735 .71583 L p .707 .577 .707 r
F P
0 g
s
.67805 .61432 m .68398 .6702 L .71126 .67121 L p .707 .577 .707 r
F P
0 g
s
.74382 .74438 m .74366 .70731 L .71249 .70555 L p .707 .577 .707 r
F P
0 g
s
.74366 .70731 m .74382 .74438 L .77566 .74348 L p .707 .577 .707 r
F P
0 g
s
.77566 .74348 m .77549 .70641 L .74366 .70731 L p .707 .577 .707 r
F P
0 g
s
.68398 .6702 m .67805 .61432 L .65716 .61092 L p .707 .577 .707 r
F P
0 g
s
.2735 .71583 m .27048 .73376 L .23903 .72994 L p .707 .577 .707 r
F P
0 g
s
.77549 .70641 m .77566 .74348 L .80504 .74 L p .707 .577 .707 r
F P
0 g
s
.80504 .74 m .80488 .70293 L .77549 .70641 L p .707 .577 .707 r
F P
0 g
s
.71265 .74262 m .71249 .70555 L .68503 .70129 L p .707 .577 .707 r
F P
0 g
s
.71249 .70555 m .71265 .74262 L .74382 .74438 L p .707 .577 .707 r
F P
0 g
s
.41949 .75258 m .40843 .24964 L .4499 .24416 L p .707 .577 .707 r
F P
0 g
s
.40843 .24964 m .41949 .75258 L .38554 .76101 L p .707 .577 .707 r
F P
0 g
s
.82122 .59701 m .82715 .65288 L .84349 .64498 L p .707 .577 .707 r
F P
0 g
s
.84349 .64498 m .83756 .5891 L .82122 .59701 L p .707 .577 .707 r
F P
0 g
s
.65716 .61092 m .66309 .6668 L .68398 .6702 L p .707 .577 .707 r
F P
0 g
s
.80488 .70293 m .80504 .74 L .82909 .73429 L p .707 .577 .707 r
F P
0 g
s
.82909 .73429 m .82893 .69722 L .80488 .70293 L p .707 .577 .707 r
F P
0 g
s
.68503 .70129 m .68519 .73837 L .71265 .74262 L p .707 .577 .707 r
F P
0 g
s
.7363 .78652 m .73932 .76858 L .70857 .76158 L p .707 .577 .707 r
F P
0 g
s
.73932 .76858 m .7363 .78652 L .76775 .79035 L p .707 .577 .707 r
F P
0 g
s
.76775 .79035 m .77078 .77241 L .73932 .76858 L p .707 .577 .707 r
F P
0 g
s
.53883 .24388 m .5499 .74682 L .5059 .74512 L p .707 .577 .707 r
F P
0 g
s
.5059 .74512 m .49483 .24218 L .53883 .24388 L p .707 .577 .707 r
F P
0 g
s
.68519 .73837 m .68503 .70129 L .66397 .69497 L p .707 .577 .707 r
F P
0 g
s
.77078 .77241 m .76775 .79035 L .79683 .79062 L p .707 .577 .707 r
F P
0 g
s
.79683 .79062 m .79986 .77269 L .77078 .77241 L p .707 .577 .707 r
F P
0 g
s
.70555 .77951 m .70857 .76158 L .68154 .75208 L p .707 .577 .707 r
F P
0 g
s
.70857 .76158 m .70555 .77951 L .7363 .78652 L p .707 .577 .707 r
F P
0 g
s
.66309 .6668 m .65716 .61092 L .6447 .60546 L p .707 .577 .707 r
F P
0 g
s
.4499 .24416 m .46097 .74711 L .41949 .75258 L p .707 .577 .707 r
F P
0 g
s
.42499 .54351 m .43091 .59939 L .43863 .59786 L p .707 .577 .707 r
F P
0 g
s
.45967 .68809 m .4499 .24416 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.43863 .59786 m .46017 .59359 L p .42644 .54558 L .707 .577 .707 r
F P
0 g
s
.42644 .54558 m .42499 .54351 L .43863 .59786 L .707 .577 .707 r
F
.4499 .24416 m .49483 .24218 L p .46375 .7056 L F P
0 g
s
.46097 .74711 m .45967 .68809 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.49483 .24218 m .5059 .74512 L .46097 .74711 L p .707 .577 .707 r
F P
0 g
s
.68154 .75208 m .67851 .77001 L .70555 .77951 L p .707 .577 .707 r
F P
0 g
s
.66397 .69497 m .66414 .73204 L .68519 .73837 L p .707 .577 .707 r
F P
0 g
s
.82893 .69722 m .82909 .73429 L .84546 .7269 L p .707 .577 .707 r
F P
0 g
s
.84546 .7269 m .8453 .68983 L .82893 .69722 L p .707 .577 .707 r
F P
0 g
s
.79986 .77269 m .79683 .79062 L .82069 .78732 L p .707 .577 .707 r
F P
0 g
s
.82069 .78732 m .82371 .76938 L .79986 .77269 L p .707 .577 .707 r
F P
0 g
s
.83756 .5891 m .84349 .64498 L .8506 .63715 L p .707 .577 .707 r
F P
0 g
s
.8506 .63715 m .84467 .58127 L .83756 .5891 L p .707 .577 .707 r
F P
0 g
s
.67851 .77001 m .68154 .75208 L .66087 .74102 L p .707 .577 .707 r
F P
0 g
s
.6447 .60546 m .65062 .66134 L .66309 .6668 L p .707 .577 .707 r
F P
0 g
s
.66087 .74102 m .65784 .75895 L .67851 .77001 L p .707 .577 .707 r
F P
0 g
s
.66414 .73204 m .66397 .69497 L .65138 .68718 L p .707 .577 .707 r
F P
0 g
s
.65062 .66134 m .6447 .60546 L .64188 .59847 L p .707 .577 .707 r
F P
0 g
s
.65138 .68718 m .65154 .72425 L .66414 .73204 L p .707 .577 .707 r
F P
0 g
s
.82371 .76938 m .82069 .78732 L .83699 .78076 L p .707 .577 .707 r
F P
0 g
s
.83699 .78076 m .84002 .76282 L .82371 .76938 L p .707 .577 .707 r
F P
0 g
s
.65784 .75895 m .66087 .74102 L .64858 .72948 L p .707 .577 .707 r
F P
0 g
s
.8453 .68983 m .84546 .7269 L .85254 .71856 L p .707 .577 .707 r
F P
0 g
s
.85254 .71856 m .85238 .68148 L .8453 .68983 L p .707 .577 .707 r
F P
0 g
s
.64858 .72948 m .64555 .74742 L .65784 .75895 L p .707 .577 .707 r
F P
0 g
s
.84467 .58127 m .8506 .63715 L .84779 .63017 L p .707 .577 .707 r
F P
0 g
s
.84779 .63017 m .84186 .57429 L .84467 .58127 L p .707 .577 .707 r
F P
0 g
s
.64188 .59847 m .64781 .65435 L .65062 .66134 L p .707 .577 .707 r
F P
0 g
s
.65154 .72425 m .65138 .68718 L .64849 .6787 L p .707 .577 .707 r
F P
0 g
s
.84002 .76282 m .83699 .78076 L .84414 .77159 L p .707 .577 .707 r
F P
0 g
s
.84414 .77159 m .84717 .75365 L .84002 .76282 L p .707 .577 .707 r
F P
0 g
s
.64849 .6787 m .64865 .71577 L .65154 .72425 L p .707 .577 .707 r
F P
0 g
s
.64781 .65435 m .64188 .59847 L .64899 .59064 L p .707 .577 .707 r
F P
0 g
s
.64555 .74742 m .64858 .72948 L .64587 .71859 L p .707 .577 .707 r
F P
0 g
s
.85238 .68148 m .85254 .71856 L .84965 .71008 L p .707 .577 .707 r
F P
0 g
s
.84965 .71008 m .84949 .67301 L .85238 .68148 L p .707 .577 .707 r
F P
0 g
s
.64587 .71859 m .64285 .73653 L .64555 .74742 L p .707 .577 .707 r
F P
0 g
s
.84186 .57429 m .84779 .63017 L .83532 .6247 L p .707 .577 .707 r
F P
0 g
s
.83532 .6247 m .8294 .56883 L .84186 .57429 L p .707 .577 .707 r
F P
0 g
s
.64899 .59064 m .65492 .64652 L .64781 .65435 L p .707 .577 .707 r
F P
0 g
s
.39924 .60322 m .39331 .54734 L .36232 .54883 L p .707 .577 .707 r
F P
0 g
s
.39331 .54734 m .39924 .60322 L .43091 .59939 L p .707 .577 .707 r
F P
0 g
s
.43091 .59939 m .42499 .54351 L .39331 .54734 L p .707 .577 .707 r
F P
0 g
s
.46017 .59359 m .45424 .53771 L .42499 .54351 L p .707 .577 .707 r
F P
0 g
s
.64865 .71577 m .64849 .6787 L .65557 .67036 L p .707 .577 .707 r
F P
0 g
s
.36825 .6047 m .36232 .54883 L .33504 .54782 L p .707 .577 .707 r
F P
0 g
s
.36232 .54883 m .36825 .6047 L .39924 .60322 L p .707 .577 .707 r
F P
0 g
s
.84717 .75365 m .84414 .77159 L .84144 .7607 L p .707 .577 .707 r
F P
0 g
s
.84144 .7607 m .84446 .74276 L .84717 .75365 L p .707 .577 .707 r
F P
0 g
s
.45424 .53771 m .46017 .59359 L .48414 .58638 L p .707 .577 .707 r
F P
0 g
s
.48414 .58638 m .47821 .53051 L .45424 .53771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65557 .67036 m .65573 .70743 L .64865 .71577 L p .707 .577 .707 r
F P
0 g
s
.65492 .64652 m .64899 .59064 L .66533 .58274 L p .707 .577 .707 r
F P
0 g
s
.64285 .73653 m .64587 .71859 L .65302 .70942 L p .707 .577 .707 r
F P
0 g
s
.40081 .65642 m .40065 .61934 L .36948 .61758 L p .707 .577 .707 r
F P
0 g
s
.40065 .61934 m .40081 .65642 L .43265 .65551 L p .707 .577 .707 r
F P
0 g
s
.43265 .65551 m .43248 .61844 L .40065 .61934 L p .707 .577 .707 r
F P
0 g
s
.43248 .61844 m .43265 .65551 L .46203 .65204 L p .707 .577 .707 r
F P
0 g
s
.46203 .65204 m .46187 .61496 L .43248 .61844 L p .707 .577 .707 r
F P
0 g
s
.33504 .54782 m .34097 .6037 L .36825 .6047 L p .707 .577 .707 r
F P
0 g
s
.84949 .67301 m .84965 .71008 L .83706 .70229 L p .707 .577 .707 r
F P
0 g
s
.83706 .70229 m .83689 .66522 L .84949 .67301 L p .707 .577 .707 r
F P
0 g
s
.65302 .70942 m .65 .72735 L .64285 .73653 L p .707 .577 .707 r
F P
0 g
s
.36964 .65465 m .36948 .61758 L .34202 .61333 L p .707 .577 .707 r
F P
0 g
s
.36948 .61758 m .36964 .65465 L .40081 .65642 L p .707 .577 .707 r
F P
0 g
s
.34097 .6037 m .33504 .54782 L .31415 .54442 L p .707 .577 .707 r
F P
0 g
s
.8294 .56883 m .83532 .6247 L .81443 .6213 L p .707 .577 .707 r
F P
0 g
s
.81443 .6213 m .8085 .56543 L .8294 .56883 L p .707 .577 .707 r
F P
0 g
s
.66533 .58274 m .67126 .63862 L .65492 .64652 L p .707 .577 .707 r
F P
0 g
s
.46187 .61496 m .46203 .65204 L .48608 .64632 L p .707 .577 .707 r
F P
0 g
s
.48608 .64632 m .48592 .60925 L .46187 .61496 L p .707 .577 .707 r
F P
0 g
s
.47821 .53051 m .48414 .58638 L .50048 .57848 L p .707 .577 .707 r
F P
0 g
s
.50048 .57848 m .49455 .5226 L .47821 .53051 L p .707 .577 .707 r
F P
0 g
s
.65573 .70743 m .65557 .67036 L .67194 .66297 L p .707 .577 .707 r
F P
0 g
s
.34202 .61333 m .34218 .6504 L .36964 .65465 L p .707 .577 .707 r
F P
0 g
s
.31415 .54442 m .32008 .6003 L .34097 .6037 L p .707 .577 .707 r
F P
0 g
s
.39329 .70665 m .39631 .68871 L .36556 .68171 L p .707 .577 .707 r
F P
0 g
s
.39631 .68871 m .39329 .70665 L .42474 .71048 L p .707 .577 .707 r
F P
0 g
s
.42474 .71048 m .42777 .69254 L .39631 .68871 L p .707 .577 .707 r
F P
0 g
s
.34218 .6504 m .34202 .61333 L .32096 .607 L p .707 .577 .707 r
F P
0 g
s
.67126 .63862 m .66533 .58274 L .6893 .57553 L p .707 .577 .707 r
F P
0 g
s
.42777 .69254 m .42474 .71048 L .45382 .71075 L p .707 .577 .707 r
F P
0 g
s
.45382 .71075 m .45685 .69282 L .42777 .69254 L p .707 .577 .707 r
F P
0 g
s
.84446 .74276 m .84144 .7607 L .82915 .74916 L p .707 .577 .707 r
F P
0 g
s
.82915 .74916 m .83218 .73122 L .84446 .74276 L p .707 .577 .707 r
F P
0 g
s
.36254 .69964 m .36556 .68171 L .33853 .67221 L p .707 .577 .707 r
F P
0 g
s
.36556 .68171 m .36254 .69964 L .39329 .70665 L p .707 .577 .707 r
F P
0 g
s
.67194 .66297 m .6721 .70004 L .65573 .70743 L p .707 .577 .707 r
F P
0 g
s
.65 .72735 m .65302 .70942 L .66933 .70286 L p .707 .577 .707 r
F P
0 g
s
.32008 .6003 m .31415 .54442 L .30169 .53896 L p .707 .577 .707 r
F P
0 g
s
.33853 .67221 m .3355 .69014 L .36254 .69964 L p .707 .577 .707 r
F P
0 g
s
.83689 .66522 m .83706 .70229 L .816 .69596 L p .707 .577 .707 r
F P
0 g
s
.816 .69596 m .81584 .65889 L .83689 .66522 L p .707 .577 .707 r
F P
0 g
s
.8085 .56543 m .81443 .6213 L .78715 .6203 L p .707 .577 .707 r
F P
0 g
s
.78715 .6203 m .78122 .56442 L .8085 .56543 L p .707 .577 .707 r
F P
0 g
s
.32096 .607 m .32113 .64407 L .34218 .6504 L p .707 .577 .707 r
F P
0 g
s
.48592 .60925 m .48608 .64632 L .50245 .63893 L p .707 .577 .707 r
F P
0 g
s
.50245 .63893 m .50229 .60186 L .48592 .60925 L p .707 .577 .707 r
F P
0 g
s
.66933 .70286 m .6663 .72079 L .65 .72735 L p .707 .577 .707 r
F P
0 g
s
.6893 .57553 m .69523 .63141 L .67126 .63862 L p .707 .577 .707 r
F P
0 g
s
.45685 .69282 m .45382 .71075 L .47768 .70745 L p .707 .577 .707 r
F P
0 g
s
.47768 .70745 m .4807 .68951 L .45685 .69282 L p .707 .577 .707 r
F P
0 g
s
.3355 .69014 m .33853 .67221 L .31785 .66115 L p .707 .577 .707 r
F P
0 g
s
.49455 .5226 m .50048 .57848 L .50759 .57065 L p .707 .577 .707 r
F P
0 g
s
.50759 .57065 m .50166 .51477 L .49455 .5226 L p .707 .577 .707 r
F P
0 g
s
.6721 .70004 m .67194 .66297 L .69599 .65726 L p .707 .577 .707 r
F P
0 g
s
.69523 .63141 m .6893 .57553 L .71856 .56973 L p .707 .577 .707 r
F P
0 g
s
.30169 .53896 m .30761 .59483 L .32008 .6003 L p .707 .577 .707 r
F P
0 g
s
.32113 .64407 m .32096 .607 L .30837 .59921 L p .707 .577 .707 r
F P
0 g
s
.31785 .66115 m .31483 .67908 L .3355 .69014 L p .707 .577 .707 r
F P
0 g
s
.78122 .56442 m .78715 .6203 L .75616 .62178 L p .707 .577 .707 r
F P
0 g
s
.75616 .62178 m .75023 .5659 L .78122 .56442 L p .707 .577 .707 r
F P
0 g
s
.83218 .73122 m .82915 .74916 L .80848 .7381 L p .707 .577 .707 r
F P
0 g
s
.80848 .7381 m .8115 .72016 L .83218 .73122 L p .707 .577 .707 r
F P
0 g
s
.69599 .65726 m .69615 .69433 L .6721 .70004 L p .707 .577 .707 r
F P
0 g
s
.72449 .62561 m .71856 .56973 L .75023 .5659 L p .707 .577 .707 r
F P
0 g
s
.71856 .56973 m .72449 .62561 L .69523 .63141 L p .707 .577 .707 r
F P
0 g
s
.6663 .72079 m .66933 .70286 L .69318 .69956 L p .707 .577 .707 r
F P
0 g
s
.81584 .65889 m .816 .69596 L .78854 .69171 L p .707 .577 .707 r
F P
0 g
s
.78854 .69171 m .78838 .65464 L .81584 .65889 L p .707 .577 .707 r
F P
0 g
s
.30837 .59921 m .30853 .63629 L .32113 .64407 L p .707 .577 .707 r
F P
0 g
s
.75023 .5659 m .75616 .62178 L .72449 .62561 L p .707 .577 .707 r
F P
0 g
s
.4807 .68951 m .47768 .70745 L .49398 .70089 L p .707 .577 .707 r
F P
0 g
s
.49398 .70089 m .49701 .68295 L .4807 .68951 L p .707 .577 .707 r
F P
0 g
s
.30761 .59483 m .30169 .53896 L .29887 .53197 L p .707 .577 .707 r
F P
0 g
s
.50229 .60186 m .50245 .63893 L .50953 .63059 L p .707 .577 .707 r
F P
0 g
s
.50953 .63059 m .50937 .59352 L .50229 .60186 L p .707 .577 .707 r
F P
0 g
s
.69318 .69956 m .69016 .71749 L .6663 .72079 L p .707 .577 .707 r
F P
0 g
s
.31483 .67908 m .31785 .66115 L .30557 .64961 L p .707 .577 .707 r
F P
0 g
s
.69615 .69433 m .69599 .65726 L .72537 .65378 L p .707 .577 .707 r
F P
0 g
s
.30557 .64961 m .30254 .66755 L .31483 .67908 L p .707 .577 .707 r
F P
0 g
s
.78838 .65464 m .78854 .69171 L .75737 .68995 L p .707 .577 .707 r
F P
0 g
s
.75737 .68995 m .75721 .65288 L .78838 .65464 L p .707 .577 .707 r
F P
0 g
s
.50166 .51477 m .50759 .57065 L .50478 .56366 L p .707 .577 .707 r
F P
0 g
s
.50478 .56366 m .49885 .50779 L .50166 .51477 L p .707 .577 .707 r
F P
0 g
s
.29887 .53197 m .3048 .58785 L .30761 .59483 L p .707 .577 .707 r
F P
0 g
s
.72537 .65378 m .72554 .69085 L .69615 .69433 L p .707 .577 .707 r
F P
0 g
s
.30853 .63629 m .30837 .59921 L .30547 .59074 L p .707 .577 .707 r
F P
0 g
s
.8115 .72016 m .80848 .7381 L .78144 .7286 L p .707 .577 .707 r
F P
0 g
s
.78144 .7286 m .78447 .71067 L .8115 .72016 L p .707 .577 .707 r
F P
0 g
s
.72554 .69085 m .72537 .65378 L .75721 .65288 L p .707 .577 .707 r
F P
0 g
s
.69016 .71749 m .69318 .69956 L .72226 .69983 L p .707 .577 .707 r
F P
0 g
s
.75721 .65288 m .75737 .68995 L .72554 .69085 L p .707 .577 .707 r
F P
0 g
s
.72226 .69983 m .71924 .71777 L .69016 .71749 L p .707 .577 .707 r
F P
0 g
s
.30547 .59074 m .30564 .62781 L .30853 .63629 L p .707 .577 .707 r
F P
0 g
s
.49701 .68295 m .49398 .70089 L .50113 .69172 L p .707 .577 .707 r
F P
0 g
s
.50113 .69172 m .50416 .67378 L .49701 .68295 L p .707 .577 .707 r
F P
0 g
s
.78447 .71067 m .78144 .7286 L .75069 .7216 L p .707 .577 .707 r
F P
0 g
s
.75069 .7216 m .75372 .70366 L .78447 .71067 L p .707 .577 .707 r
F P
0 g
s
.30254 .66755 m .30557 .64961 L .30286 .63872 L p .707 .577 .707 r
F P
0 g
s
.71924 .71777 m .72226 .69983 L .75372 .70366 L p .707 .577 .707 r
F P
0 g
s
.3048 .58785 m .29887 .53197 L .30598 .52414 L p .707 .577 .707 r
F P
0 g
s
.50937 .59352 m .50953 .63059 L .50664 .62211 L p .707 .577 .707 r
F P
0 g
s
.50664 .62211 m .50648 .58504 L .50937 .59352 L p .707 .577 .707 r
F P
0 g
s
.75372 .70366 m .75069 .7216 L .71924 .71777 L p .707 .577 .707 r
F P
0 g
s
.30286 .63872 m .29984 .65666 L .30254 .66755 L p .707 .577 .707 r
F P
0 g
s
.49885 .50779 m .50478 .56366 L .49231 .5582 L p .707 .577 .707 r
F P
0 g
s
.49231 .5582 m .48638 .50233 L .49885 .50779 L p .707 .577 .707 r
F P
0 g
s
.30598 .52414 m .31191 .58002 L .3048 .58785 L p .707 .577 .707 r
F P
0 g
s
.30564 .62781 m .30547 .59074 L .31256 .58239 L p .707 .577 .707 r
F P
0 g
s
.31256 .58239 m .31272 .61947 L .30564 .62781 L p .707 .577 .707 r
F P
0 g
s
.50416 .67378 m .50113 .69172 L .49843 .68083 L p .707 .577 .707 r
F P
0 g
s
.49843 .68083 m .50145 .66289 L .50416 .67378 L p .707 .577 .707 r
F P
0 g
s
.29984 .65666 m .30286 .63872 L .31001 .62955 L p .707 .577 .707 r
F P
0 g
s
.31191 .58002 m .30598 .52414 L .32232 .51624 L p .707 .577 .707 r
F P
0 g
s
.50648 .58504 m .50664 .62211 L .49405 .61433 L p .707 .577 .707 r
F P
0 g
s
.49405 .61433 m .49388 .57725 L .50648 .58504 L p .707 .577 .707 r
F P
0 g
s
.31001 .62955 m .30699 .64748 L .29984 .65666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48638 .50233 m .49231 .5582 L .47142 .5548 L p .707 .577 .707 r
F P
0 g
s
.47142 .5548 m .46549 .49892 L .48638 .50233 L p .707 .577 .707 r
F P
0 g
s
.32232 .51624 m .32825 .57212 L .31191 .58002 L p .707 .577 .707 r
F P
0 g
s
.31272 .61947 m .31256 .58239 L .32893 .575 L p .707 .577 .707 r
F P
0 g
s
.32893 .575 m .32909 .61208 L .31272 .61947 L p .707 .577 .707 r
F P
0 g
s
.50145 .66289 m .49843 .68083 L .48614 .66929 L p .707 .577 .707 r
F P
0 g
s
.48614 .66929 m .48916 .65135 L .50145 .66289 L p .707 .577 .707 r
F P
0 g
s
.32825 .57212 m .32232 .51624 L .34629 .50903 L p .707 .577 .707 r
F P
0 g
s
.30699 .64748 m .31001 .62955 L .32632 .62299 L p .707 .577 .707 r
F P
0 g
s
.49388 .57725 m .49405 .61433 L .47299 .608 L p .707 .577 .707 r
F P
0 g
s
.47299 .608 m .47283 .57093 L .49388 .57725 L p .707 .577 .707 r
F P
0 g
s
.32632 .62299 m .32329 .64092 L .30699 .64748 L p .707 .577 .707 r
F P
0 g
s
.46549 .49892 m .47142 .5548 L .44414 .55379 L p .707 .577 .707 r
F P
0 g
s
.44414 .55379 m .43821 .49792 L .46549 .49892 L p .707 .577 .707 r
F P
0 g
s
.34629 .50903 m .35222 .56491 L .32825 .57212 L p .707 .577 .707 r
F P
0 g
s
.32909 .61208 m .32893 .575 L .35298 .56929 L p .707 .577 .707 r
F P
0 g
s
.35222 .56491 m .34629 .50903 L .37555 .50323 L p .707 .577 .707 r
F P
0 g
s
.35298 .56929 m .35314 .60636 L .32909 .61208 L p .707 .577 .707 r
F P
0 g
s
.48916 .65135 m .48614 .66929 L .46547 .65823 L p .707 .577 .707 r
F P
0 g
s
.46547 .65823 m .46849 .64029 L .48916 .65135 L p .707 .577 .707 r
F P
0 g
s
.43821 .49792 m .44414 .55379 L .41315 .55528 L p .707 .577 .707 r
F P
0 g
s
.41315 .55528 m .40722 .4994 L .43821 .49792 L p .707 .577 .707 r
F P
0 g
s
.47283 .57093 m .47299 .608 L .44553 .60374 L p .707 .577 .707 r
F P
0 g
s
.44553 .60374 m .44537 .56667 L .47283 .57093 L p .707 .577 .707 r
F P
0 g
s
.32329 .64092 m .32632 .62299 L .35017 .61969 L p .707 .577 .707 r
F P
0 g
s
.38147 .55911 m .37555 .50323 L .40722 .4994 L p .707 .577 .707 r
F P
0 g
s
.37555 .50323 m .38147 .55911 L .35222 .56491 L p .707 .577 .707 r
F P
0 g
s
.40722 .4994 m .41315 .55528 L .38147 .55911 L p .707 .577 .707 r
F P
0 g
s
.35314 .60636 m .35298 .56929 L .38236 .56581 L p .707 .577 .707 r
F P
0 g
s
.35017 .61969 m .34715 .63762 L .32329 .64092 L p .707 .577 .707 r
F P
0 g
s
.44537 .56667 m .44553 .60374 L .41436 .60198 L p .707 .577 .707 r
F P
0 g
s
.41436 .60198 m .4142 .56491 L .44537 .56667 L p .707 .577 .707 r
F P
0 g
s
.38236 .56581 m .38252 .60288 L .35314 .60636 L p .707 .577 .707 r
F P
0 g
s
.38252 .60288 m .38236 .56581 L .4142 .56491 L p .707 .577 .707 r
F P
0 g
s
.46849 .64029 m .46547 .65823 L .43843 .64873 L p .707 .577 .707 r
F P
0 g
s
.43843 .64873 m .44146 .6308 L .46849 .64029 L p .707 .577 .707 r
F P
0 g
s
.4142 .56491 m .41436 .60198 L .38252 .60288 L p .707 .577 .707 r
F P
0 g
s
.34715 .63762 m .35017 .61969 L .37925 .61996 L p .707 .577 .707 r
F P
0 g
s
.37925 .61996 m .37623 .6379 L .34715 .63762 L p .707 .577 .707 r
F P
0 g
s
.44146 .6308 m .43843 .64873 L .40768 .64173 L p .707 .577 .707 r
F P
0 g
s
.40768 .64173 m .41071 .62379 L .44146 .6308 L p .707 .577 .707 r
F P
0 g
s
.37623 .6379 m .37925 .61996 L .41071 .62379 L p .707 .577 .707 r
F P
0 g
s
.41071 .62379 m .40768 .64173 L .37623 .6379 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Ioo`d008Yo
o`00OGoo2@001UYF00<005YFFUH015YF3000OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001gOol0079oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEP00001eOol006eoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001bOol006Uoo`@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP80071oo`00Igoo
0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`00KWoo001UOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001/Ool0
06=oo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Uoo`00HWoo0P001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001ROol20006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001ZOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yo
o`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00=oo`00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00
HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP0EFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVYoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF
JWoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH05EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIZOol0065oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1XOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0E
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1X
Ool0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00
HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0?0007
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069o
o`04001JEUYF0005FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001ROol01@00
FUIJEP00FUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001QOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol005eoo`@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005]oo`8000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005Uoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF000=FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JGoo001G
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP003EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001FOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001EOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001DOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Aoo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo
001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUHF0002FUH0
1@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001E
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPL0
00UJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF
00=JEQL000MJEP03001JEUYF00AJEP03001JEUYF009JEP@000YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8001iooaD003Eoo`00EGoo00@005YFFUH000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001JEUYF00=JEP<000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@0035oo`00EGoo00@005YFFUH000=JEPL00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000COol70006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000_Ool005Eoo`05001JEUYF001JEP050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000=Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`9JEP@00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yoo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005Ioo`04FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20007Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001FOol00eYF00000004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P001Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001AOol80004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0018Ool90004FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0041oo`P000AJEP03001JEUYF00IJ
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=Woo100000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000Aoo`00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=7oo0P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF000015YF00<005YFFUH00eYF
1P000eYF00<005YFFUH01eYF00<005YFFUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005Ool005YFFUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo000bOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH400000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200001Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0002aoo`00<7oo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`0000=JEP0000000`0000=JEP00FUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF20000eYF0`000eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000Eoo`00FUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;goo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF001JEP8000EJEP04001JEUYFFUH80009FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool002ioo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0015YF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQP000=JEP03001JEUYF008002]oo`00;Goo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF1@000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH2000[Ool0
02eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP80009JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002]oo`00;Goo00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool0
0`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0003FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJEUYF4000
15YF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20003FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70006FUH00`00
FUIJEP05FUH20004FUH00`00FUH00002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP8002aoo`00;Woo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@0000=JEP00
00000`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1UYF0`0000AJEP000000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=oo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP05001JEUYFFUH0000]Ool002ioo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT0009JEP06001JEP00001JEP000eYF1@001UYF
00<005YFFUH01EYF00<005YFFUH01UYF10001eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
000^Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPP000QJEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003Ool015YF001JEP001EYF00<005YFFUH01EYF4`0025YF00<0
05YFFUH00eYF0`00<7oo000^Ool00`00FUH00005FUH00`00FUIJEP03FUH60007FUH:0002FUH20000
15YF001JEP001UYF00<005YF00000UYF6@0000IJEP00000005YF0006FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP02FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000eYF00000002000cOol002ioo`03001J
EP0000EJEP03001JEP0000<000AJEP03001JEP0000L000AJEP03001JEUYF009JEP@0009JEP<000EJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP<000IJEP04001J
EP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH01000
FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Ao
o`00;Woo00@005YFFUH000AJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH800001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP<0009JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000aOol002ioo`04001JEUYF0002FUH60003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P0000=JEP00FUH0
0UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;goo000_Ool2FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF0`000eYF00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP80009JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<002eoo`00;goo0UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF
0`0000EJEP00FUIJEP0000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP05001J
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH0
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000_Ool00eYF00000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUH000040005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002]oo`00;goo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001UYF00<005YFFUH00eYF10000eYF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP80009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000ZOol002mo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00T000AJEP03001JEUYF00QJEP03001J
EUYF00MJEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00:Woo000_Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP06FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2000015YF0000
000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000ZOol002moo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03001JEUYF00AJ
EPD0009JEPP000EJEP03001JEUYF00D000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF
00<005YFFUH00eYF00@005YFFUIJEP8002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF00<005YF00000`000UYF00<005YFFUH01EYF0`001eYF00@005YFFUIJEPP0
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF009JEPH001Yoo`D000AJEP04001JEUYFFUH2
000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPX001=oo`@0009JEP06001JEUYFFUH005YF
10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF0000
15YF00<005YF000020007Woo100000=JEP00FUH00UYF0P00:Woo000_Ool00`00FUH00004FUH00`00
FUH00003000QOol500001EYF001JEUYF00000UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP00009JEPD000=JEP04001JEUYFFUH9000?Ool70003
FUH30003FUH2000ZOol002moo`03001JEP0000=JEP<00003FUH0000000<0021oo`H0009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF0000000ZOol002moo`04001JEP00FUH20005FUH01000FUIJEUYF20004Woo1P001EYF00@0
05YFFUH000IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000ZOol002moo`06001JEP00001JEP0015YF7`0015YF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEUYF00IJEPl000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002Yoo`00;goo0P000eYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF009J
EP03001JEP0002Yoo`00;goo0P000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEQD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF
009JEP03001JEP0002Yoo`00;goo10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH00000FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80006
FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP02FUH2000[Ool0031oo`80009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04
FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000000P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00`000eYF0P00;7oo000_Ool00`00FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH40005FUH00`00FUIJEP03FUH4
000^Ool002moo`8000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEPL000IJEP03001JEUYF
00EJEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH0
1EYF0P00;goo000_Ool200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP06FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300001UYF001JEP00FUH0009JEPD000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP03001JEP0002ioo`00;Woo00@005YF000000Aoo`<00003
FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP@000MJEP03001JEUYF00800005OomJEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUH00006FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH01@00FUIJEUYF0000;Goo000^Ool3
0008Ool50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP<000EJEP<0
009ooaT000Moo`04001JEUYF0004FUH00`00Oomoo`0ZOol002ioo`800003FUH007oo00]ooaX00006
Ool00000001JEP002EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF2P002eYF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH01@009Woo0`0015YF00<007oo
Ool0:Woo000^Ool20002FUH00`00Oomoo`0WOol20009FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF1P002EYF00<005YFFUH02EYF00<005YFFUH02EYF1`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF00001EYF0`00:7oo00<005YFFUH00UYF00<007ooOol0:Woo000_Ool01@00FUIJEUYF
0000:Woo0P000eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP8000=JEP80
00IJEP04001JEP00000WOol00`00FUIJEP02000/Ool002moo`04001JEUYFFUH3000ZOol200000eYF
001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH20003FUH20006FUH01000FUIJEUYF
0`009Goo1000;7oo000`Ool01000FUIJEP000UYF0P00:Woo0P000eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEP000003FUH00`00FUIJEP05FUH4000ROol3000/Ool0031o
o`03001JEP0000EJEP<002Uoo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF
00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00@001aoo`@002eoo`00<Goo0P001UYF00@0
05YF000002Moo`=JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP04FUH7000@Ool50002FUH2000]Ool0039oo`03001JEUYF00AJEP04001JEUYFFUH2
0009Ool3000IOol3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04FUH0
1000FUH0000015YF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00H005YFFUH005YF000]Ool0
03=oo`8000=JEP03001JEUYF00AJEP@000Aoo`D001Qoo`9JEP05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000eOol200000eYF001JEP06FUH0
0`00FUIJEP09000GOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol30006FUH00`00FUIJEP04FUH7000@Ool500000eYF
00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000050005FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000jOol20004FUH00`00FUIJEP05FUH30003FUH@0003FUH00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006Ool400000eYF001JEP04FUH01000FUIJEUYF0P000goo1`00
15YF00<005YFFUH01EYF00@005YFFUIJEPH0035oo`00?7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P002Woo10000eYF00@005YFFUIJEP8000Yooa0003Moo`00?goo0`001UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000]oo`P000=JEP80055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20008Ool5
0005FUH01000FUIJEP000UYF0P00DGoo0016Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1Goo0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00D005YF000005YF00T000=JEP03001JEUYF00AJEP04001JEUYFFUH4
001AOol004eooa4000]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00AJEP@000AJEP03001JEUYF00AJEP03001J
EUYF009JEP<0055oo`00K7oo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YF000010001UYF00<0
05YFFUH00UYF0`00DGoo001^Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUH0000800000eYF001JEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP02FUH00`00FUH0001AOol0075oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000EJEPP000IJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP80059oo`00N7oo3000
1UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00H0
05YFFUH005YF0003FUH2001COol008Aoo`h00004Ool000000005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH50007FUH40005FUH00`00FUIJEP02FUH200000eYF0000001EOol008moo`@0009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000QJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00Oomoo`1EOol008moo`05001JEP00FUH00003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH2001FOol008moo`8000=JEP03001o
ogoo00=oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000IJEP04001J
EP00001DOol0091oo`04001JEUYFFUH30008OolK0005Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1AOol0091oo`05001JEUYFFUH00002FUH00`00Oomoo`0WOol200000eYF001JEP03FUH00`00Oomo
o`1AOol0095oo`03001JEP0000AJEP8002Uoo`8000AJEP03001oogoo055oo`00TWoo0P001UYF0P00
:Goo00<005YFFUH00P00Dgoo002COol00`00FUIJEP04FUH00`00FUH00003000VOol4001COol009Ao
o`8000AJEP03001JEUYF00=JEPD002=oo`8005=oo`00UWoo00@005YFFUH000QJEP03001JEUYF00@0
01eoo`<005Aoo`00Ugoo0`0025YF00<005YFFUH015YF1`0047oo1P0000=JEP000000E7oo002IOol2
0006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH@0003FUH01000FUIJEUYF0P00E7oo002KOol40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
001EOol009moo`D000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2001EOol00:Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH0001FOol00:Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol0
0:mooaD005Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58685 .73685 m .59278 .68225 L .56178 .677 L p .707 .577 .707 r
F P
0 g
s
.59278 .68225 m .58685 .73685 L .61852 .73909 L p .707 .577 .707 r
F P
0 g
s
.61852 .73909 m .62445 .68449 L .59278 .68225 L p .707 .577 .707 r
F P
0 g
s
.62445 .68449 m .61852 .73909 L .64778 .73811 L p .707 .577 .707 r
F P
0 g
s
.64778 .73811 m .6537 .6835 L .62445 .68449 L p .707 .577 .707 r
F P
0 g
s
.55586 .73161 m .56178 .677 L .53451 .66926 L p .707 .577 .707 r
F P
0 g
s
.56178 .677 m .55586 .73161 L .58685 .73685 L p .707 .577 .707 r
F P
0 g
s
.6537 .6835 m .64778 .73811 L .67175 .734 L p .707 .577 .707 r
F P
0 g
s
.67175 .734 m .67767 .67939 L .6537 .6835 L p .707 .577 .707 r
F P
0 g
s
.52858 .72387 m .53451 .66926 L .51361 .65979 L p .707 .577 .707 r
F P
0 g
s
.53451 .66926 m .52858 .72387 L .55586 .73161 L p .707 .577 .707 r
F P
0 g
s
.58564 .7833 m .5858 .74626 L .55463 .74422 L p .707 .577 .707 r
F P
0 g
s
.5858 .74626 m .58564 .7833 L .61747 .78264 L p .707 .577 .707 r
F P
0 g
s
.61747 .78264 m .61763 .74561 L .5858 .74626 L p .707 .577 .707 r
F P
0 g
s
.61763 .74561 m .61747 .78264 L .64685 .77936 L p .707 .577 .707 r
F P
0 g
s
.64685 .77936 m .64702 .74233 L .61763 .74561 L p .707 .577 .707 r
F P
0 g
s
.55446 .78126 m .55463 .74422 L .52717 .73969 L p .707 .577 .707 r
F P
0 g
s
.55463 .74422 m .55446 .78126 L .58564 .7833 L p .707 .577 .707 r
F P
0 g
s
.64702 .74233 m .64685 .77936 L .67091 .77378 L p .707 .577 .707 r
F P
0 g
s
.67091 .77378 m .67107 .73674 L .64702 .74233 L p .707 .577 .707 r
F P
0 g
s
.59231 .82447 m .58929 .80589 L .55854 .80918 L p .707 .577 .707 r
F P
0 g
s
.58929 .80589 m .59231 .82447 L .62377 .81901 L p .707 .577 .707 r
F P
0 g
s
.62377 .81901 m .62074 .80042 L .58929 .80589 L p .707 .577 .707 r
F P
0 g
s
.67767 .67939 m .67175 .734 L .68809 .72716 L p .707 .577 .707 r
F P
0 g
s
.68809 .72716 m .69401 .67255 L .67767 .67939 L p .707 .577 .707 r
F P
0 g
s
.62074 .80042 m .62377 .81901 L .65285 .81191 L p .707 .577 .707 r
F P
0 g
s
.65285 .81191 m .64982 .79332 L .62074 .80042 L p .707 .577 .707 r
F P
0 g
s
.52717 .73969 m .52701 .77673 L .55446 .78126 L p .707 .577 .707 r
F P
0 g
s
.51361 .65979 m .50769 .71439 L .52858 .72387 L p .707 .577 .707 r
F P
0 g
s
.55854 .80918 m .56156 .82777 L .59231 .82447 L p .707 .577 .707 r
F P
0 g
s
.50769 .71439 m .51361 .65979 L .50115 .64951 L p .707 .577 .707 r
F P
0 g
s
.52701 .77673 m .52717 .73969 L .50611 .73311 L p .707 .577 .707 r
F P
0 g
s
.56156 .82777 m .55854 .80918 L .53151 .80999 L p .707 .577 .707 r
F P
0 g
s
.53151 .80999 m .53453 .82857 L .56156 .82777 L p .707 .577 .707 r
F P
0 g
s
.64982 .79332 m .65285 .81191 L .6767 .80387 L p .707 .577 .707 r
F P
0 g
s
.6767 .80387 m .67368 .78529 L .64982 .79332 L p .707 .577 .707 r
F P
0 g
s
.50611 .73311 m .50595 .77015 L .52701 .77673 L p .707 .577 .707 r
F P
0 g
s
.67107 .73674 m .67091 .77378 L .68728 .76643 L p .707 .577 .707 r
F P
0 g
s
.68728 .76643 m .68744 .72939 L .67107 .73674 L p .707 .577 .707 r
F P
0 g
s
.50115 .64951 m .49522 .70412 L .50769 .71439 L p .707 .577 .707 r
F P
0 g
s
.53453 .82857 m .53151 .80999 L .51083 .80822 L p .707 .577 .707 r
F P
0 g
s
.69401 .67255 m .68809 .72716 L .6952 .71827 L p .707 .577 .707 r
F P
0 g
s
.6952 .71827 m .70113 .66366 L .69401 .67255 L p .707 .577 .707 r
F P
0 g
s
.51083 .80822 m .51386 .8268 L .53453 .82857 L p .707 .577 .707 r
F P
0 g
s
.50595 .77015 m .50611 .73311 L .49352 .72513 L p .707 .577 .707 r
F P
0 g
s
.67368 .78529 m .6767 .80387 L .69301 .79568 L p .707 .577 .707 r
F P
0 g
s
.69301 .79568 m .68998 .7771 L .67368 .78529 L p .707 .577 .707 r
F P
0 g
s
.49522 .70412 m .50115 .64951 L .49834 .63943 L p .707 .577 .707 r
F P
0 g
s
.49352 .72513 m .49336 .76216 L .50595 .77015 L p .707 .577 .707 r
F P
0 g
s
.68744 .72939 m .68728 .76643 L .69436 .75805 L p .707 .577 .707 r
F P
0 g
s
.69436 .75805 m .69452 .72101 L .68744 .72939 L p .707 .577 .707 r
F P
0 g
s
.51386 .8268 m .51083 .80822 L .49854 .80406 L p .707 .577 .707 r
F P
0 g
s
.49834 .63943 m .49241 .69404 L .49522 .70412 L p .707 .577 .707 r
F P
0 g
s
.49854 .80406 m .50157 .82264 L .51386 .8268 L p .707 .577 .707 r
F P
0 g
s
.70113 .66366 m .6952 .71827 L .69238 .70819 L p .707 .577 .707 r
F P
0 g
s
.69238 .70819 m .69831 .65358 L .70113 .66366 L p .707 .577 .707 r
F P
0 g
s
.49336 .76216 m .49352 .72513 L .49063 .71652 L p .707 .577 .707 r
F P
0 g
s
.68998 .7771 m .69301 .79568 L .70016 .78814 L p .707 .577 .707 r
F P
0 g
s
.70016 .78814 m .69713 .76955 L .68998 .7771 L p .707 .577 .707 r
F P
0 g
s
.49241 .69404 m .49834 .63943 L .50545 .63054 L p .707 .577 .707 r
F P
0 g
s
.49063 .71652 m .49046 .75356 L .49336 .76216 L p .707 .577 .707 r
F P
0 g
s
.50545 .63054 m .49952 .68514 L .49241 .69404 L p .707 .577 .707 r
F P
0 g
s
.49046 .75356 m .49063 .71652 L .49771 .70813 L p .707 .577 .707 r
F P
0 g
s
.49771 .70813 m .49755 .74517 L .49046 .75356 L p .707 .577 .707 r
F P
0 g
s
.4941 .82315 m .50516 .32258 L .46117 .31891 L p .707 .577 .707 r
F P
0 g
s
.50157 .82264 m .49854 .80406 L .49584 .7979 L p .707 .577 .707 r
F P
0 g
s
.49584 .7979 m .49887 .81649 L .50157 .82264 L p .707 .577 .707 r
F P
0 g
s
.49952 .68514 m .50545 .63054 L .52179 .6237 L p .707 .577 .707 r
F P
0 g
s
.49887 .81649 m .49584 .7979 L .50299 .79036 L p .707 .577 .707 r
F P
0 g
s
.52179 .6237 m .51586 .6783 L .49952 .68514 L p .707 .577 .707 r
F P
0 g
s
.50299 .79036 m .50602 .80895 L .49887 .81649 L p .707 .577 .707 r
F P
0 g
s
.49755 .74517 m .49771 .70813 L .51408 .70079 L p .707 .577 .707 r
F P
0 g
s
.51586 .6783 m .52179 .6237 L .54576 .61959 L p .707 .577 .707 r
F P
0 g
s
.51408 .70079 m .51392 .73782 L .49755 .74517 L p .707 .577 .707 r
F P
0 g
s
.54576 .61959 m .53983 .67419 L .51586 .6783 L p .707 .577 .707 r
F P
0 g
s
.50602 .80895 m .50299 .79036 L .51929 .78217 L p .707 .577 .707 r
F P
0 g
s
.51929 .78217 m .52232 .80075 L .50602 .80895 L p .707 .577 .707 r
F P
0 g
s
.51392 .73782 m .51408 .70079 L .53813 .6952 L p .707 .577 .707 r
F P
0 g
s
.53813 .6952 m .53797 .73224 L .51392 .73782 L p .707 .577 .707 r
F P
0 g
s
.52232 .80075 m .51929 .78217 L .54315 .77413 L p .707 .577 .707 r
F P
0 g
s
.54315 .77413 m .54618 .79272 L .52232 .80075 L p .707 .577 .707 r
F P
0 g
s
.50516 .32258 m .4941 .82315 L .53903 .82294 L p .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .54576 .61959 L .57408 .61863 L p .707 .577 .707 r
F P
0 g
s
.57408 .61863 m .57501 .6186 L p .57356 .6209 L .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .57408 .61863 L .57356 .6209 L .707 .577 .707 r
F
.53797 .73224 m .53813 .6952 L .56751 .69192 L p F P
0 g
s
.5501 .32237 m .50516 .32258 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.53903 .82294 m .54033 .76419 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.57501 .6186 m .56908 .67321 L .53983 .67419 L p .707 .577 .707 r
F P
0 g
s
.56751 .69192 m .56735 .72896 L .53797 .73224 L p .707 .577 .707 r
F P
0 g
s
.54033 .76419 m .5501 .32237 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.56908 .67321 m .57501 .6186 L .60668 .62084 L p .707 .577 .707 r
F P
0 g
s
.60668 .62084 m .60076 .67545 L .56908 .67321 L p .707 .577 .707 r
F P
0 g
s
.56735 .72896 m .56751 .69192 L .59935 .69127 L p .707 .577 .707 r
F P
0 g
s
.59935 .69127 m .59919 .72831 L .56735 .72896 L p .707 .577 .707 r
F P
0 g
s
.54618 .79272 m .54315 .77413 L .57223 .76703 L p .707 .577 .707 r
F P
0 g
s
.57223 .76703 m .57526 .78562 L .54618 .79272 L p .707 .577 .707 r
F P
0 g
s
.57526 .78562 m .57223 .76703 L .60368 .76157 L p .707 .577 .707 r
F P
0 g
s
.60368 .76157 m .60671 .78015 L .57526 .78562 L p .707 .577 .707 r
F P
0 g
s
.5501 .32237 m .53903 .82294 L .5805 .81887 L p .707 .577 .707 r
F P
0 g
s
.5805 .81887 m .59157 .3183 L .5501 .32237 L p .707 .577 .707 r
F P
0 g
s
.4501 .81948 m .46117 .31891 L .42241 .31173 L p .707 .577 .707 r
F P
0 g
s
.46117 .31891 m .4501 .81948 L .4941 .82315 L p .707 .577 .707 r
F P
0 g
s
.69452 .72101 m .69436 .75805 L .69146 .74944 L p .707 .577 .707 r
F P
0 g
s
.69146 .74944 m .69163 .7124 L .69452 .72101 L p .707 .577 .707 r
F P
0 g
s
.63768 .62609 m .63175 .6807 L .60076 .67545 L p .707 .577 .707 r
F P
0 g
s
.60076 .67545 m .60668 .62084 L .63768 .62609 L p .707 .577 .707 r
F P
0 g
s
.63052 .69331 m .63036 .73035 L .59919 .72831 L p .707 .577 .707 r
F P
0 g
s
.59919 .72831 m .59935 .69127 L .63052 .69331 L p .707 .577 .707 r
F P
0 g
s
.63443 .75827 m .63746 .77686 L .60671 .78015 L p .707 .577 .707 r
F P
0 g
s
.60671 .78015 m .60368 .76157 L .63443 .75827 L p .707 .577 .707 r
F P
0 g
s
.59157 .3183 m .5805 .81887 L .61446 .81134 L p .707 .577 .707 r
F P
0 g
s
.61446 .81134 m .62552 .31077 L .59157 .3183 L p .707 .577 .707 r
F P
0 g
s
.69831 .65358 m .69238 .70819 L .67992 .69791 L p .707 .577 .707 r
F P
0 g
s
.67992 .69791 m .68585 .6433 L .69831 .65358 L p .707 .577 .707 r
F P
0 g
s
.69713 .76955 m .70016 .78814 L .69746 .78198 L p .707 .577 .707 r
F P
0 g
s
.69746 .78198 m .69443 .7634 L .69713 .76955 L p .707 .577 .707 r
F P
0 g
s
.41135 .8123 m .42241 .31173 L .3927 .30173 L p .707 .577 .707 r
F P
0 g
s
.42241 .31173 m .41135 .8123 L .4501 .81948 L p .707 .577 .707 r
F P
0 g
s
.24384 .72972 m .24977 .67512 L .21878 .66987 L p .707 .577 .707 r
F P
0 g
s
.24977 .67512 m .24384 .72972 L .27551 .73196 L p .707 .577 .707 r
F P
0 g
s
.27551 .73196 m .28144 .67736 L .24977 .67512 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69163 .7124 m .69146 .74944 L .67887 .74146 L p .707 .577 .707 r
F P
0 g
s
.67887 .74146 m .67903 .70442 L .69163 .7124 L p .707 .577 .707 r
F P
0 g
s
.28144 .67736 m .27551 .73196 L .30477 .73098 L p .707 .577 .707 r
F P
0 g
s
.30477 .73098 m .31069 .67637 L .28144 .67736 L p .707 .577 .707 r
F P
0 g
s
.21285 .72448 m .21878 .66987 L .1915 .66213 L p .707 .577 .707 r
F P
0 g
s
.21878 .66987 m .21285 .72448 L .24384 .72972 L p .707 .577 .707 r
F P
0 g
s
.66495 .63383 m .65903 .68843 L .63175 .6807 L p .707 .577 .707 r
F P
0 g
s
.63175 .6807 m .63768 .62609 L .66495 .63383 L p .707 .577 .707 r
F P
0 g
s
.65798 .69784 m .65782 .73488 L .63036 .73035 L p .707 .577 .707 r
F P
0 g
s
.63036 .73035 m .63052 .69331 L .65798 .69784 L p .707 .577 .707 r
F P
0 g
s
.63746 .77686 m .63443 .75827 L .66147 .75747 L p .707 .577 .707 r
F P
0 g
s
.62552 .31077 m .61446 .81134 L .63756 .8011 L p .707 .577 .707 r
F P
0 g
s
.66147 .75747 m .66449 .77605 L .63746 .77686 L p .707 .577 .707 r
F P
0 g
s
.63756 .8011 m .64863 .30053 L .62552 .31077 L p .707 .577 .707 r
F P
0 g
s
.68585 .6433 m .67992 .69791 L .65903 .68843 L p .707 .577 .707 r
F P
0 g
s
.65903 .68843 m .66495 .63383 L .68585 .6433 L p .707 .577 .707 r
F P
0 g
s
.69443 .7634 m .69746 .78198 L .68517 .77782 L p .707 .577 .707 r
F P
0 g
s
.68517 .77782 m .68214 .75924 L .69443 .7634 L p .707 .577 .707 r
F P
0 g
s
.31069 .67637 m .30477 .73098 L .32874 .72687 L p .707 .577 .707 r
F P
0 g
s
.32874 .72687 m .33466 .67226 L .31069 .67637 L p .707 .577 .707 r
F P
0 g
s
.18557 .71674 m .1915 .66213 L .1706 .65266 L p .707 .577 .707 r
F P
0 g
s
.1915 .66213 m .18557 .71674 L .21285 .72448 L p .707 .577 .707 r
F P
0 g
s
.38163 .8023 m .3927 .30173 L .37493 .2899 L p .707 .577 .707 r
F P
0 g
s
.3927 .30173 m .38163 .8023 L .41135 .8123 L p .707 .577 .707 r
F P
0 g
s
.24263 .79763 m .24279 .76059 L .21162 .75855 L p .707 .577 .707 r
F P
0 g
s
.24279 .76059 m .24263 .79763 L .27446 .79698 L p .707 .577 .707 r
F P
0 g
s
.27446 .79698 m .27463 .75994 L .24279 .76059 L p .707 .577 .707 r
F P
0 g
s
.27463 .75994 m .27446 .79698 L .30385 .7937 L p .707 .577 .707 r
F P
0 g
s
.30385 .7937 m .30401 .75666 L .27463 .75994 L p .707 .577 .707 r
F P
0 g
s
.67903 .70442 m .67887 .74146 L .65782 .73488 L p .707 .577 .707 r
F P
0 g
s
.65782 .73488 m .65798 .69784 L .67903 .70442 L p .707 .577 .707 r
F P
0 g
s
.21146 .79559 m .21162 .75855 L .18416 .75402 L p .707 .577 .707 r
F P
0 g
s
.21162 .75855 m .21146 .79559 L .24263 .79763 L p .707 .577 .707 r
F P
0 g
s
.33466 .67226 m .32874 .72687 L .34508 .72003 L p .707 .577 .707 r
F P
0 g
s
.34508 .72003 m .351 .66543 L .33466 .67226 L p .707 .577 .707 r
F P
0 g
s
.1706 .65266 m .16468 .70727 L .18557 .71674 L p .707 .577 .707 r
F P
0 g
s
.2493 .83071 m .24628 .81213 L .21553 .81542 L p .707 .577 .707 r
F P
0 g
s
.24628 .81213 m .2493 .83071 L .28076 .82525 L p .707 .577 .707 r
F P
0 g
s
.28076 .82525 m .27773 .80666 L .24628 .81213 L p .707 .577 .707 r
F P
0 g
s
.27773 .80666 m .28076 .82525 L .30984 .81815 L p .707 .577 .707 r
F P
0 g
s
.30984 .81815 m .30681 .79956 L .27773 .80666 L p .707 .577 .707 r
F P
0 g
s
.30401 .75666 m .30385 .7937 L .3279 .78811 L p .707 .577 .707 r
F P
0 g
s
.3279 .78811 m .32806 .75108 L .30401 .75666 L p .707 .577 .707 r
F P
0 g
s
.16468 .70727 m .1706 .65266 L .15814 .64238 L p .707 .577 .707 r
F P
0 g
s
.21553 .81542 m .21856 .83401 L .2493 .83071 L p .707 .577 .707 r
F P
0 g
s
.18416 .75402 m .184 .79106 L .21146 .79559 L p .707 .577 .707 r
F P
0 g
s
.68214 .75924 m .68517 .77782 L .66449 .77605 L p .707 .577 .707 r
F P
0 g
s
.66449 .77605 m .66147 .75747 L .68214 .75924 L p .707 .577 .707 r
F P
0 g
s
.64863 .30053 m .63756 .8011 L .64757 .78913 L p .707 .577 .707 r
F P
0 g
s
.64757 .78913 m .65863 .28856 L .64863 .30053 L p .707 .577 .707 r
F P
0 g
s
.21856 .83401 m .21553 .81542 L .1885 .81623 L p .707 .577 .707 r
F P
0 g
s
.184 .79106 m .18416 .75402 L .16311 .74744 L p .707 .577 .707 r
F P
0 g
s
.1885 .81623 m .19152 .83481 L .21856 .83401 L p .707 .577 .707 r
F P
0 g
s
.30681 .79956 m .30984 .81815 L .3337 .81011 L p .707 .577 .707 r
F P
0 g
s
.3337 .81011 m .33067 .79153 L .30681 .79956 L p .707 .577 .707 r
F P
0 g
s
.16311 .74744 m .16294 .78448 L .184 .79106 L p .707 .577 .707 r
F P
0 g
s
.15814 .64238 m .15221 .69699 L .16468 .70727 L p .707 .577 .707 r
F P
0 g
s
.36386 .79047 m .37493 .2899 L .37084 .27739 L p .707 .577 .707 r
F P
0 g
s
.37493 .2899 m .36386 .79047 L .38163 .8023 L p .707 .577 .707 r
F P
0 g
s
.32806 .75108 m .3279 .78811 L .34427 .78077 L p .707 .577 .707 r
F P
0 g
s
.34427 .78077 m .34443 .74373 L .32806 .75108 L p .707 .577 .707 r
F P
0 g
s
.351 .66543 m .34508 .72003 L .35219 .71114 L p .707 .577 .707 r
F P
0 g
s
.35219 .71114 m .35812 .65653 L .351 .66543 L p .707 .577 .707 r
F P
0 g
s
.19152 .83481 m .1885 .81623 L .16782 .81446 L p .707 .577 .707 r
F P
0 g
s
.16782 .81446 m .17085 .83304 L .19152 .83481 L p .707 .577 .707 r
F P
0 g
s
.15221 .69699 m .15814 .64238 L .15533 .6323 L p .707 .577 .707 r
F P
0 g
s
.33067 .79153 m .3337 .81011 L .35 .80192 L p .707 .577 .707 r
F P
0 g
s
.35 .80192 m .34697 .78333 L .33067 .79153 L p .707 .577 .707 r
F P
0 g
s
.16294 .78448 m .16311 .74744 L .15051 .73946 L p .707 .577 .707 r
F P
0 g
s
.15051 .73946 m .15035 .7765 L .16294 .78448 L p .707 .577 .707 r
F P
0 g
s
.65455 .27605 m .64348 .77662 L .62571 .76479 L p .707 .577 .707 r
F P
0 g
s
.64489 .62236 m .64505 .62086 L p .63835 .55747 L .707 .577 .707 r
F P
0 g
s
.65863 .28856 m .64757 .78913 L .64456 .77994 L p .707 .577 .707 r
F P
0 g
s
.64469 .73756 m .65863 .28856 L .64456 .77994 L .707 .577 .707 r
F
.64348 .77662 m .65455 .27605 L .65863 .28856 L p F P
0 g
s
.64505 .62086 m .65082 .56775 L .64523 .56314 L p .707 .577 .707 r
F P
0 g
s
.64523 .56314 m .63835 .55747 L p .64505 .62086 L .707 .577 .707 r
F P
0 g
s
.64456 .77994 m .64348 .77662 L p .64469 .73756 L .707 .577 .707 r
F P
0 g
s
.15533 .6323 m .1494 .68691 L .15221 .69699 L p .707 .577 .707 r
F P
0 g
s
.34443 .74373 m .34427 .78077 L .35135 .77238 L p .707 .577 .707 r
F P
0 g
s
.35135 .77238 m .35151 .73534 L .34443 .74373 L p .707 .577 .707 r
F P
0 g
s
.17085 .83304 m .16782 .81446 L .15553 .8103 L p .707 .577 .707 r
F P
0 g
s
.15553 .8103 m .15856 .82888 L .17085 .83304 L p .707 .577 .707 r
F P
0 g
s
.35812 .65653 m .35219 .71114 L .34938 .70106 L p .707 .577 .707 r
F P
0 g
s
.34938 .70106 m .3553 .64645 L .35812 .65653 L p .707 .577 .707 r
F P
0 g
s
.34697 .78333 m .35 .80192 L .35715 .79438 L p .707 .577 .707 r
F P
0 g
s
.35715 .79438 m .35412 .77579 L .34697 .78333 L p .707 .577 .707 r
F P
0 g
s
.1494 .68691 m .15533 .6323 L .16244 .62341 L p .707 .577 .707 r
F P
0 g
s
.15035 .7765 m .15051 .73946 L .14762 .73086 L p .707 .577 .707 r
F P
0 g
s
.37084 .27739 m .35978 .77796 L .36386 .79047 L p .707 .577 .707 r
F P
0 g
s
.35978 .77796 m .37084 .27739 L .38085 .26543 L p .707 .577 .707 r
F P
0 g
s
.14762 .73086 m .14745 .76789 L .15035 .7765 L p .707 .577 .707 r
F P
0 g
s
.15856 .82888 m .15553 .8103 L .15283 .80414 L p .707 .577 .707 r
F P
0 g
s
.16244 .62341 m .15651 .67801 L .1494 .68691 L p .707 .577 .707 r
F P
0 g
s
.35151 .73534 m .35135 .77238 L .34845 .76377 L p .707 .577 .707 r
F P
0 g
s
.34845 .76377 m .34862 .72674 L .35151 .73534 L p .707 .577 .707 r
F P
0 g
s
.15283 .80414 m .15586 .82273 L .15856 .82888 L p .707 .577 .707 r
F P
0 g
s
.3553 .64645 m .34938 .70106 L .33691 .69078 L p .707 .577 .707 r
F P
0 g
s
.33691 .69078 m .34284 .63617 L .3553 .64645 L p .707 .577 .707 r
F P
0 g
s
.35412 .77579 m .35715 .79438 L .35445 .78822 L p .707 .577 .707 r
F P
0 g
s
.35445 .78822 m .35142 .76964 L .35412 .77579 L p .707 .577 .707 r
F P
0 g
s
.15651 .67801 m .16244 .62341 L .17878 .61657 L p .707 .577 .707 r
F P
0 g
s
.62571 .76479 m .63678 .26422 L .65455 .27605 L p .707 .577 .707 r
F P
0 g
s
.14745 .76789 m .14762 .73086 L .1547 .72247 L p .707 .577 .707 r
F P
0 g
s
.1547 .72247 m .15454 .75951 L .14745 .76789 L p .707 .577 .707 r
F P
0 g
s
.36978 .766 m .38085 .26543 L .40395 .25518 L p .707 .577 .707 r
F P
0 g
s
.38085 .26543 m .36978 .766 L .35978 .77796 L p .707 .577 .707 r
F P
0 g
s
.17878 .61657 m .17285 .67117 L .15651 .67801 L p .707 .577 .707 r
F P
0 g
s
.34862 .72674 m .34845 .76377 L .33586 .75579 L p .707 .577 .707 r
F P
0 g
s
.33586 .75579 m .33602 .71875 L .34862 .72674 L p .707 .577 .707 r
F P
0 g
s
.15586 .82273 m .15283 .80414 L .15998 .7966 L p .707 .577 .707 r
F P
0 g
s
.34284 .63617 m .33691 .69078 L .31602 .6813 L p .707 .577 .707 r
F P
0 g
s
.31602 .6813 m .32195 .6267 L .34284 .63617 L p .707 .577 .707 r
F P
0 g
s
.15998 .7966 m .16301 .81518 L .15586 .82273 L p .707 .577 .707 r
F P
0 g
s
.17285 .67117 m .17878 .61657 L .20275 .61246 L p .707 .577 .707 r
F P
0 g
s
.35142 .76964 m .35445 .78822 L .34216 .78406 L p .707 .577 .707 r
F P
0 g
s
.34216 .78406 m .33913 .76548 L .35142 .76964 L p .707 .577 .707 r
F P
0 g
s
.15454 .75951 m .1547 .72247 L .17107 .71512 L p .707 .577 .707 r
F P
0 g
s
.63678 .26422 m .62571 .76479 L .596 .75479 L p .707 .577 .707 r
F P
0 g
s
.596 .75479 m .60706 .25422 L .63678 .26422 L p .707 .577 .707 r
F P
0 g
s
.17107 .71512 m .17091 .75216 L .15454 .75951 L p .707 .577 .707 r
F P
0 g
s
.32195 .6267 m .31602 .6813 L .28874 .67357 L p .707 .577 .707 r
F P
0 g
s
.28874 .67357 m .29467 .61896 L .32195 .6267 L p .707 .577 .707 r
F P
0 g
s
.20275 .61246 m .19682 .66706 L .17285 .67117 L p .707 .577 .707 r
F P
0 g
s
.33602 .71875 m .33586 .75579 L .31481 .74921 L p .707 .577 .707 r
F P
0 g
s
.31481 .74921 m .31497 .71218 L .33602 .71875 L p .707 .577 .707 r
F P
0 g
s
.19682 .66706 m .20275 .61246 L .232 .61147 L p .707 .577 .707 r
F P
0 g
s
.16301 .81518 m .15998 .7966 L .17628 .78841 L p .707 .577 .707 r
F P
0 g
s
.17628 .78841 m .17931 .80699 L .16301 .81518 L p .707 .577 .707 r
F P
0 g
s
.40395 .25518 m .39288 .75575 L .36978 .766 L p .707 .577 .707 r
F P
0 g
s
.39288 .75575 m .40395 .25518 L .43791 .24766 L p .707 .577 .707 r
F P
0 g
s
.17091 .75216 m .17107 .71512 L .19512 .70954 L p .707 .577 .707 r
F P
0 g
s
.29467 .61896 m .28874 .67357 L .25775 .66832 L p .707 .577 .707 r
F P
0 g
s
.25775 .66832 m .26367 .61371 L .29467 .61896 L p .707 .577 .707 r
F P
0 g
s
.33913 .76548 m .34216 .78406 L .32148 .78229 L p .707 .577 .707 r
F P
0 g
s
.32148 .78229 m .31846 .76371 L .33913 .76548 L p .707 .577 .707 r
F P
0 g
s
.72405 .64481 m .72998 .59021 L .69899 .58496 L p .707 .577 .707 r
F P
0 g
s
.72998 .59021 m .72405 .64481 L .75573 .64705 L p .707 .577 .707 r
F P
0 g
s
.75573 .64705 m .76165 .59245 L .72998 .59021 L p .707 .577 .707 r
F P
0 g
s
.22607 .66608 m .232 .61147 L .26367 .61371 L p .707 .577 .707 r
F P
0 g
s
.232 .61147 m .22607 .66608 L .19682 .66706 L p .707 .577 .707 r
F P
0 g
s
.76165 .59245 m .75573 .64705 L .78498 .64607 L p .707 .577 .707 r
F P
0 g
s
.78498 .64607 m .79091 .59147 L .76165 .59245 L p .707 .577 .707 r
F P
0 g
s
.26367 .61371 m .25775 .66832 L .22607 .66608 L p .707 .577 .707 r
F P
0 g
s
.69306 .63957 m .69899 .58496 L .67171 .57722 L p .707 .577 .707 r
F P
0 g
s
.69899 .58496 m .69306 .63957 L .72405 .64481 L p .707 .577 .707 r
F P
0 g
s
.19512 .70954 m .19496 .74657 L .17091 .75216 L p .707 .577 .707 r
F P
0 g
s
.31497 .71218 m .31481 .74921 L .28735 .74468 L p .707 .577 .707 r
F P
0 g
s
.28735 .74468 m .28751 .70764 L .31497 .71218 L p .707 .577 .707 r
F P
0 g
s
.60706 .25422 m .596 .75479 L .55724 .74761 L p .707 .577 .707 r
F P
0 g
s
.55724 .74761 m .56831 .24704 L .60706 .25422 L p .707 .577 .707 r
F P
0 g
s
.17931 .80699 m .17628 .78841 L .20014 .78037 L p .707 .577 .707 r
F P
0 g
s
.79091 .59147 m .78498 .64607 L .80895 .64196 L p .707 .577 .707 r
F P
0 g
s
.80895 .64196 m .81488 .58735 L .79091 .59147 L p .707 .577 .707 r
F P
0 g
s
.19496 .74657 m .19512 .70954 L .2245 .70626 L p .707 .577 .707 r
F P
0 g
s
.20014 .78037 m .20317 .79896 L .17931 .80699 L p .707 .577 .707 r
F P
0 g
s
.66578 .63183 m .67171 .57722 L .65082 .56775 L p .707 .577 .707 r
F P
0 g
s
.67171 .57722 m .66578 .63183 L .69306 .63957 L p .707 .577 .707 r
F P
0 g
s
.72284 .69126 m .723 .65422 L .69183 .65218 L p .707 .577 .707 r
F P
0 g
s
.723 .65422 m .72284 .69126 L .75468 .6906 L p .707 .577 .707 r
F P
0 g
s
.75468 .6906 m .75484 .65357 L .723 .65422 L p .707 .577 .707 r
F P
0 g
s
.42684 .74823 m .43791 .24766 L .47938 .24359 L p .707 .577 .707 r
F P
0 g
s
.43791 .24766 m .42684 .74823 L .39288 .75575 L p .707 .577 .707 r
F P
0 g
s
.31846 .76371 m .32148 .78229 L .29445 .7831 L p .707 .577 .707 r
F P
0 g
s
.29445 .7831 m .29142 .76451 L .31846 .76371 L p .707 .577 .707 r
F P
0 g
s
.75484 .65357 m .75468 .6906 L .78406 .68733 L p .707 .577 .707 r
F P
0 g
s
.78406 .68733 m .78422 .65029 L .75484 .65357 L p .707 .577 .707 r
F P
0 g
s
.28751 .70764 m .28735 .74468 L .25618 .74264 L p .707 .577 .707 r
F P
0 g
s
.25618 .74264 m .25634 .70561 L .28751 .70764 L p .707 .577 .707 r
F P
0 g
s
.69167 .68922 m .69183 .65218 L .66437 .64765 L p .707 .577 .707 r
F P
0 g
s
.69183 .65218 m .69167 .68922 L .72284 .69126 L p .707 .577 .707 r
F P
0 g
s
.2245 .70626 m .22434 .74329 L .19496 .74657 L p .707 .577 .707 r
F P
0 g
s
.22434 .74329 m .2245 .70626 L .25634 .70561 L p .707 .577 .707 r
F P
0 g
s
.25634 .70561 m .25618 .74264 L .22434 .74329 L p .707 .577 .707 r
F P
0 g
s
.56831 .24704 m .55724 .74761 L .51324 .74395 L p .707 .577 .707 r
F P
0 g
s
.51324 .74395 m .52431 .24338 L .56831 .24704 L p .707 .577 .707 r
F P
0 g
s
.78422 .65029 m .78406 .68733 L .80811 .68174 L p .707 .577 .707 r
F P
0 g
s
.80811 .68174 m .80827 .6447 L .78422 .65029 L p .707 .577 .707 r
F P
0 g
s
.20317 .79896 m .20014 .78037 L .22922 .77327 L p .707 .577 .707 r
F P
0 g
s
.72952 .73243 m .72649 .71385 L .69575 .71715 L p .707 .577 .707 r
F P
0 g
s
.72649 .71385 m .72952 .73243 L .76097 .72697 L p .707 .577 .707 r
F P
0 g
s
.76097 .72697 m .75795 .70839 L .72649 .71385 L p .707 .577 .707 r
F P
0 g
s
.81488 .58735 m .80895 .64196 L .82529 .63512 L p .707 .577 .707 r
F P
0 g
s
.82529 .63512 m .83122 .58052 L .81488 .58735 L p .707 .577 .707 r
F P
0 g
s
.75795 .70839 m .76097 .72697 L .79005 .71987 L p .707 .577 .707 r
F P
0 g
s
.79005 .71987 m .78703 .70129 L .75795 .70839 L p .707 .577 .707 r
F P
0 g
s
.66437 .64765 m .66421 .68469 L .69167 .68922 L p .707 .577 .707 r
F P
0 g
s
.65082 .56775 m .64489 .62236 L .66578 .63183 L p .707 .577 .707 r
F P
0 g
s
.22922 .77327 m .23225 .79186 L .20317 .79896 L p .707 .577 .707 r
F P
0 g
s
.69575 .71715 m .69877 .73573 L .72952 .73243 L p .707 .577 .707 r
F P
0 g
s
.46831 .74416 m .47938 .24359 L .52431 .24338 L p .707 .577 .707 r
F P
0 g
s
.47938 .24359 m .46831 .74416 L .42684 .74823 L p .707 .577 .707 r
F P
0 g
s
.29142 .76451 m .29445 .7831 L .2637 .78639 L p .707 .577 .707 r
F P
0 g
s
.2637 .78639 m .26068 .76781 L .29142 .76451 L p .707 .577 .707 r
F P
0 g
s
.66421 .68469 m .66437 .64765 L .64332 .64107 L p .707 .577 .707 r
F P
0 g
s
.69877 .73573 m .69575 .71715 L .66871 .71795 L p .707 .577 .707 r
F P
0 g
s
.52431 .24338 m .51324 .74395 L .46831 .74416 L p .707 .577 .707 r
F P
0 g
s
.23225 .79186 m .22922 .77327 L .26068 .76781 L p .707 .577 .707 r
F P
0 g
s
.66871 .71795 m .67173 .73653 L .69877 .73573 L p .707 .577 .707 r
F P
0 g
s
.26068 .76781 m .2637 .78639 L .23225 .79186 L p .707 .577 .707 r
F P
0 g
s
.78703 .70129 m .79005 .71987 L .81391 .71183 L p .707 .577 .707 r
F P
0 g
s
.81391 .71183 m .81089 .69325 L .78703 .70129 L p .707 .577 .707 r
F P
0 g
s
.64332 .64107 m .64316 .67811 L .66421 .68469 L p .707 .577 .707 r
F P
0 g
s
.80827 .6447 m .80811 .68174 L .82448 .67439 L p .707 .577 .707 r
F P
0 g
s
.82448 .67439 m .82464 .63736 L .80827 .6447 L p .707 .577 .707 r
F P
0 g
s
.63835 .55747 m .63243 .61208 L .64489 .62236 L p .707 .577 .707 r
F P
0 g
s
.67173 .73653 m .66871 .71795 L .64804 .71618 L p .707 .577 .707 r
F P
0 g
s
.83122 .58052 m .82529 .63512 L .8324 .62623 L p .707 .577 .707 r
F P
0 g
s
.8324 .62623 m .83833 .57162 L .83122 .58052 L p .707 .577 .707 r
F P
0 g
s
.64804 .71618 m .65106 .73477 L .67173 .73653 L p .707 .577 .707 r
F P
0 g
s
.64316 .67811 m .64332 .64107 L .63073 .63309 L p .707 .577 .707 r
F P
0 g
s
.81089 .69325 m .81391 .71183 L .83021 .70364 L p .707 .577 .707 r
F P
0 g
s
.83021 .70364 m .82719 .68506 L .81089 .69325 L p .707 .577 .707 r
F P
0 g
s
.63243 .61208 m .63835 .55747 L .63554 .54739 L p .707 .577 .707 r
F P
0 g
s
.63073 .63309 m .63056 .67012 L .64316 .67811 L p .707 .577 .707 r
F P
0 g
s
.82464 .63736 m .82448 .67439 L .83156 .66601 L p .707 .577 .707 r
F P
0 g
s
.83156 .66601 m .83173 .62897 L .82464 .63736 L p .707 .577 .707 r
F P
0 g
s
.65106 .73477 m .64804 .71618 L .63575 .71202 L p .707 .577 .707 r
F P
0 g
s
.63554 .54739 m .62961 .602 L .63243 .61208 L p .707 .577 .707 r
F P
0 g
s
.63575 .71202 m .63877 .7306 L .65106 .73477 L p .707 .577 .707 r
F P
0 g
s
.83833 .57162 m .8324 .62623 L .82959 .61615 L p .707 .577 .707 r
F P
0 g
s
.82959 .61615 m .83552 .56154 L .83833 .57162 L p .707 .577 .707 r
F P
0 g
s
.63056 .67012 m .63073 .63309 L .62783 .62448 L p .707 .577 .707 r
F P
0 g
s
.82719 .68506 m .83021 .70364 L .83736 .6961 L p .707 .577 .707 r
F P
0 g
s
.83736 .6961 m .83434 .67752 L .82719 .68506 L p .707 .577 .707 r
F P
0 g
s
.62961 .602 m .63554 .54739 L .64265 .5385 L p .707 .577 .707 r
F P
0 g
s
.62783 .62448 m .62767 .66152 L .63056 .67012 L p .707 .577 .707 r
F P
0 g
s
.83173 .62897 m .83156 .66601 L .82867 .6574 L p .707 .577 .707 r
F P
0 g
s
.82867 .6574 m .82883 .62036 L .83173 .62897 L p .707 .577 .707 r
F P
0 g
s
.63877 .7306 m .63575 .71202 L .63305 .70586 L p .707 .577 .707 r
F P
0 g
s
.64265 .5385 m .63672 .5931 L .62961 .602 L p .707 .577 .707 r
F P
0 g
s
.63305 .70586 m .63607 .72445 L .63877 .7306 L p .707 .577 .707 r
F P
0 g
s
.83552 .56154 m .82959 .61615 L .81713 .60587 L p .707 .577 .707 r
F P
0 g
s
.81713 .60587 m .82305 .55126 L .83552 .56154 L p .707 .577 .707 r
F P
0 g
s
.83434 .67752 m .83736 .6961 L .83466 .68995 L p .707 .577 .707 r
F P
0 g
s
.83466 .68995 m .83164 .67136 L .83434 .67752 L p .707 .577 .707 r
F P
0 g
s
.62767 .66152 m .62783 .62448 L .63491 .6161 L p .707 .577 .707 r
F P
0 g
s
.63672 .5931 m .64265 .5385 L .65899 .53166 L p .707 .577 .707 r
F P
0 g
s
.63491 .6161 m .63475 .65313 L .62767 .66152 L p .707 .577 .707 r
F P
0 g
s
.38104 .63768 m .38697 .58308 L .35598 .57783 L p .707 .577 .707 r
F P
0 g
s
.38697 .58308 m .38104 .63768 L .41272 .63992 L p .707 .577 .707 r
F P
0 g
s
.41272 .63992 m .41864 .58532 L .38697 .58308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82883 .62036 m .82867 .6574 L .81608 .64942 L p .707 .577 .707 r
F P
0 g
s
.81608 .64942 m .81624 .61238 L .82883 .62036 L p .707 .577 .707 r
F P
0 g
s
.41864 .58532 m .41272 .63992 L .44197 .63894 L p .707 .577 .707 r
F P
0 g
s
.44197 .63894 m .4479 .58434 L .41864 .58532 L p .707 .577 .707 r
F P
0 g
s
.63607 .72445 m .63305 .70586 L .6402 .69832 L p .707 .577 .707 r
F P
0 g
s
.35005 .63244 m .35598 .57783 L .3287 .57009 L p .707 .577 .707 r
F P
0 g
s
.35598 .57783 m .35005 .63244 L .38104 .63768 L p .707 .577 .707 r
F P
0 g
s
.65899 .53166 m .65306 .58626 L .63672 .5931 L p .707 .577 .707 r
F P
0 g
s
.6402 .69832 m .64322 .71691 L .63607 .72445 L p .707 .577 .707 r
F P
0 g
s
.82305 .55126 m .81713 .60587 L .79623 .59639 L p .707 .577 .707 r
F P
0 g
s
.79623 .59639 m .80216 .54179 L .82305 .55126 L p .707 .577 .707 r
F P
0 g
s
.63475 .65313 m .63491 .6161 L .65128 .60875 L p .707 .577 .707 r
F P
0 g
s
.83164 .67136 m .83466 .68995 L .82237 .68578 L p .707 .577 .707 r
F P
0 g
s
.82237 .68578 m .81935 .6672 L .83164 .67136 L p .707 .577 .707 r
F P
0 g
s
.4479 .58434 m .44197 .63894 L .46594 .63483 L p .707 .577 .707 r
F P
0 g
s
.46594 .63483 m .47187 .58022 L .4479 .58434 L p .707 .577 .707 r
F P
0 g
s
.65306 .58626 m .65899 .53166 L .68296 .52755 L p .707 .577 .707 r
F P
0 g
s
.32277 .6247 m .3287 .57009 L .30781 .56062 L p .707 .577 .707 r
F P
0 g
s
.3287 .57009 m .32277 .6247 L .35005 .63244 L p .707 .577 .707 r
F P
0 g
s
.65128 .60875 m .65112 .64579 L .63475 .65313 L p .707 .577 .707 r
F P
0 g
s
.37983 .70559 m .37999 .66856 L .34882 .66652 L p .707 .577 .707 r
F P
0 g
s
.37999 .66856 m .37983 .70559 L .41167 .70494 L p .707 .577 .707 r
F P
0 g
s
.41167 .70494 m .41183 .6679 L .37999 .66856 L p .707 .577 .707 r
F P
0 g
s
.41183 .6679 m .41167 .70494 L .44105 .70166 L p .707 .577 .707 r
F P
0 g
s
.44105 .70166 m .44121 .66462 L .41183 .6679 L p .707 .577 .707 r
F P
0 g
s
.81624 .61238 m .81608 .64942 L .79502 .64284 L p .707 .577 .707 r
F P
0 g
s
.79502 .64284 m .79518 .6058 L .81624 .61238 L p .707 .577 .707 r
F P
0 g
s
.80216 .54179 m .79623 .59639 L .76895 .58866 L p .707 .577 .707 r
F P
0 g
s
.76895 .58866 m .77488 .53405 L .80216 .54179 L p .707 .577 .707 r
F P
0 g
s
.34866 .70355 m .34882 .66652 L .32136 .66199 L p .707 .577 .707 r
F P
0 g
s
.34882 .66652 m .34866 .70355 L .37983 .70559 L p .707 .577 .707 r
F P
0 g
s
.68296 .52755 m .67704 .58215 L .65306 .58626 L p .707 .577 .707 r
F P
0 g
s
.64322 .71691 m .6402 .69832 L .6565 .69013 L p .707 .577 .707 r
F P
0 g
s
.47187 .58022 m .46594 .63483 L .48228 .62799 L p .707 .577 .707 r
F P
0 g
s
.48228 .62799 m .48821 .57339 L .47187 .58022 L p .707 .577 .707 r
F P
0 g
s
.67704 .58215 m .68296 .52755 L .71222 .52656 L p .707 .577 .707 r
F P
0 g
s
.30781 .56062 m .30188 .61523 L .32277 .6247 L p .707 .577 .707 r
F P
0 g
s
.6565 .69013 m .65952 .70872 L .64322 .71691 L p .707 .577 .707 r
F P
0 g
s
.38651 .73867 m .38348 .72009 L .35274 .72338 L p .707 .577 .707 r
F P
0 g
s
.38348 .72009 m .38651 .73867 L .41796 .73321 L p .707 .577 .707 r
F P
0 g
s
.41796 .73321 m .41494 .71462 L .38348 .72009 L p .707 .577 .707 r
F P
0 g
s
.41494 .71462 m .41796 .73321 L .44704 .72611 L p .707 .577 .707 r
F P
0 g
s
.44704 .72611 m .44402 .70752 L .41494 .71462 L p .707 .577 .707 r
F P
0 g
s
.65112 .64579 m .65128 .60875 L .67534 .60316 L p .707 .577 .707 r
F P
0 g
s
.44121 .66462 m .44105 .70166 L .4651 .69607 L p .707 .577 .707 r
F P
0 g
s
.4651 .69607 m .46526 .65904 L .44121 .66462 L p .707 .577 .707 r
F P
0 g
s
.30188 .61523 m .30781 .56062 L .29534 .55034 L p .707 .577 .707 r
F P
0 g
s
.35274 .72338 m .35576 .74197 L .38651 .73867 L p .707 .577 .707 r
F P
0 g
s
.32136 .66199 m .3212 .69902 L .34866 .70355 L p .707 .577 .707 r
F P
0 g
s
.81935 .6672 m .82237 .68578 L .8017 .68402 L p .707 .577 .707 r
F P
0 g
s
.8017 .68402 m .79867 .66543 L .81935 .6672 L p .707 .577 .707 r
F P
0 g
s
.35576 .74197 m .35274 .72338 L .3257 .72419 L p .707 .577 .707 r
F P
0 g
s
.77488 .53405 m .76895 .58866 L .73796 .58341 L p .707 .577 .707 r
F P
0 g
s
.73796 .58341 m .74389 .52881 L .77488 .53405 L p .707 .577 .707 r
F P
0 g
s
.3212 .69902 m .32136 .66199 L .30031 .65541 L p .707 .577 .707 r
F P
0 g
s
.70629 .58117 m .71222 .52656 L .74389 .52881 L p .707 .577 .707 r
F P
0 g
s
.71222 .52656 m .70629 .58117 L .67704 .58215 L p .707 .577 .707 r
F P
0 g
s
.3257 .72419 m .32872 .74277 L .35576 .74197 L p .707 .577 .707 r
F P
0 g
s
.67534 .60316 m .67517 .6402 L .65112 .64579 L p .707 .577 .707 r
F P
0 g
s
.44402 .70752 m .44704 .72611 L .4709 .71807 L p .707 .577 .707 r
F P
0 g
s
.4709 .71807 m .46788 .69949 L .44402 .70752 L p .707 .577 .707 r
F P
0 g
s
.74389 .52881 m .73796 .58341 L .70629 .58117 L p .707 .577 .707 r
F P
0 g
s
.79518 .6058 m .79502 .64284 L .76756 .63831 L p .707 .577 .707 r
F P
0 g
s
.76756 .63831 m .76772 .60127 L .79518 .6058 L p .707 .577 .707 r
F P
0 g
s
.30031 .65541 m .30015 .69244 L .3212 .69902 L p .707 .577 .707 r
F P
0 g
s
.29534 .55034 m .28942 .60495 L .30188 .61523 L p .707 .577 .707 r
F P
0 g
s
.67517 .6402 m .67534 .60316 L .70472 .59988 L p .707 .577 .707 r
F P
0 g
s
.65952 .70872 m .6565 .69013 L .68036 .68209 L p .707 .577 .707 r
F P
0 g
s
.46526 .65904 m .4651 .69607 L .48147 .68873 L p .707 .577 .707 r
F P
0 g
s
.48147 .68873 m .48163 .65169 L .46526 .65904 L p .707 .577 .707 r
F P
0 g
s
.48821 .57339 m .48228 .62799 L .48939 .6191 L p .707 .577 .707 r
F P
0 g
s
.48939 .6191 m .49532 .56449 L .48821 .57339 L p .707 .577 .707 r
F P
0 g
s
.32872 .74277 m .3257 .72419 L .30503 .72242 L p .707 .577 .707 r
F P
0 g
s
.68036 .68209 m .68338 .70068 L .65952 .70872 L p .707 .577 .707 r
F P
0 g
s
.30503 .72242 m .30805 .74101 L .32872 .74277 L p .707 .577 .707 r
F P
0 g
s
.79867 .66543 m .8017 .68402 L .77466 .68482 L p .707 .577 .707 r
F P
0 g
s
.77466 .68482 m .77164 .66623 L .79867 .66543 L p .707 .577 .707 r
F P
0 g
s
.76772 .60127 m .76756 .63831 L .73639 .63627 L p .707 .577 .707 r
F P
0 g
s
.73639 .63627 m .73655 .59923 L .76772 .60127 L p .707 .577 .707 r
F P
0 g
s
.28942 .60495 m .29534 .55034 L .29253 .54026 L p .707 .577 .707 r
F P
0 g
s
.70472 .59988 m .70455 .63692 L .67517 .6402 L p .707 .577 .707 r
F P
0 g
s
.46788 .69949 m .4709 .71807 L .4872 .70988 L p .707 .577 .707 r
F P
0 g
s
.4872 .70988 m .48418 .6913 L .46788 .69949 L p .707 .577 .707 r
F P
0 g
s
.30015 .69244 m .30031 .65541 L .28772 .64742 L p .707 .577 .707 r
F P
0 g
s
.70455 .63692 m .70472 .59988 L .73655 .59923 L p .707 .577 .707 r
F P
0 g
s
.73655 .59923 m .73639 .63627 L .70455 .63692 L p .707 .577 .707 r
F P
0 g
s
.68338 .70068 m .68036 .68209 L .70944 .675 L p .707 .577 .707 r
F P
0 g
s
.28772 .64742 m .28755 .68446 L .30015 .69244 L p .707 .577 .707 r
F P
0 g
s
.70944 .675 m .71246 .69358 L .68338 .70068 L p .707 .577 .707 r
F P
0 g
s
.77164 .66623 m .77466 .68482 L .74391 .68811 L p .707 .577 .707 r
F P
0 g
s
.74391 .68811 m .74089 .66953 L .77164 .66623 L p .707 .577 .707 r
F P
0 g
s
.29253 .54026 m .2866 .59487 L .28942 .60495 L p .707 .577 .707 r
F P
0 g
s
.48163 .65169 m .48147 .68873 L .48855 .68034 L p .707 .577 .707 r
F P
0 g
s
.48855 .68034 m .48872 .64331 L .48163 .65169 L p .707 .577 .707 r
F P
0 g
s
.30805 .74101 m .30503 .72242 L .29274 .71826 L p .707 .577 .707 r
F P
0 g
s
.71246 .69358 m .70944 .675 L .74089 .66953 L p .707 .577 .707 r
F P
0 g
s
.29274 .71826 m .29576 .73684 L .30805 .74101 L p .707 .577 .707 r
F P
0 g
s
.49532 .56449 m .48939 .6191 L .48658 .60902 L p .707 .577 .707 r
F P
0 g
s
.48658 .60902 m .49251 .55441 L .49532 .56449 L p .707 .577 .707 r
F P
0 g
s
.74089 .66953 m .74391 .68811 L .71246 .69358 L p .707 .577 .707 r
F P
0 g
s
.48418 .6913 m .4872 .70988 L .49435 .70234 L p .707 .577 .707 r
F P
0 g
s
.49435 .70234 m .49133 .68375 L .48418 .6913 L p .707 .577 .707 r
F P
0 g
s
.2866 .59487 m .29253 .54026 L .29964 .53137 L p .707 .577 .707 r
F P
0 g
s
.28755 .68446 m .28772 .64742 L .28482 .63882 L p .707 .577 .707 r
F P
0 g
s
.28482 .63882 m .28466 .67585 L .28755 .68446 L p .707 .577 .707 r
F P
0 g
s
.29576 .73684 m .29274 .71826 L .29004 .7121 L p .707 .577 .707 r
F P
0 g
s
.29964 .53137 m .29371 .58597 L .2866 .59487 L p .707 .577 .707 r
F P
0 g
s
.48872 .64331 m .48855 .68034 L .48566 .67174 L p .707 .577 .707 r
F P
0 g
s
.48566 .67174 m .48582 .6347 L .48872 .64331 L p .707 .577 .707 r
F P
0 g
s
.29004 .7121 m .29306 .73069 L .29576 .73684 L p .707 .577 .707 r
F P
0 g
s
.49251 .55441 m .48658 .60902 L .47412 .59874 L p .707 .577 .707 r
F P
0 g
s
.47412 .59874 m .48004 .54413 L .49251 .55441 L p .707 .577 .707 r
F P
0 g
s
.49133 .68375 m .49435 .70234 L .49165 .69619 L p .707 .577 .707 r
F P
0 g
s
.49165 .69619 m .48863 .6776 L .49133 .68375 L p .707 .577 .707 r
F P
0 g
s
.29371 .58597 m .29964 .53137 L .31598 .52453 L p .707 .577 .707 r
F P
0 g
s
.28466 .67585 m .28482 .63882 L .2919 .63043 L p .707 .577 .707 r
F P
0 g
s
.2919 .63043 m .29174 .66747 L .28466 .67585 L p .707 .577 .707 r
F P
0 g
s
.31598 .52453 m .31005 .57913 L .29371 .58597 L p .707 .577 .707 r
F P
0 g
s
.48582 .6347 m .48566 .67174 L .47306 .66375 L p .707 .577 .707 r
F P
0 g
s
.47306 .66375 m .47323 .62672 L .48582 .6347 L p .707 .577 .707 r
F P
0 g
s
.29306 .73069 m .29004 .7121 L .29719 .70456 L p .707 .577 .707 r
F P
0 g
s
.48004 .54413 m .47412 .59874 L .45322 .58926 L p .707 .577 .707 r
F P
0 g
s
.45322 .58926 m .45915 .53466 L .48004 .54413 L p .707 .577 .707 r
F P
0 g
s
.29719 .70456 m .30021 .72315 L .29306 .73069 L p .707 .577 .707 r
F P
0 g
s
.31005 .57913 m .31598 .52453 L .33995 .52042 L p .707 .577 .707 r
F P
0 g
s
.48863 .6776 m .49165 .69619 L .47936 .69202 L p .707 .577 .707 r
F P
0 g
s
.47936 .69202 m .47634 .67344 L .48863 .6776 L p .707 .577 .707 r
F P
0 g
s
.29174 .66747 m .2919 .63043 L .30827 .62308 L p .707 .577 .707 r
F P
0 g
s
.30827 .62308 m .30811 .66012 L .29174 .66747 L p .707 .577 .707 r
F P
0 g
s
.45915 .53466 m .45322 .58926 L .42594 .58153 L p .707 .577 .707 r
F P
0 g
s
.42594 .58153 m .43187 .52692 L .45915 .53466 L p .707 .577 .707 r
F P
0 g
s
.33995 .52042 m .33402 .57502 L .31005 .57913 L p .707 .577 .707 r
F P
0 g
s
.47323 .62672 m .47306 .66375 L .45201 .65717 L p .707 .577 .707 r
F P
0 g
s
.45201 .65717 m .45217 .62014 L .47323 .62672 L p .707 .577 .707 r
F P
0 g
s
.33402 .57502 m .33995 .52042 L .36921 .51943 L p .707 .577 .707 r
F P
0 g
s
.30021 .72315 m .29719 .70456 L .31349 .69637 L p .707 .577 .707 r
F P
0 g
s
.31349 .69637 m .31651 .71496 L .30021 .72315 L p .707 .577 .707 r
F P
0 g
s
.30811 .66012 m .30827 .62308 L .33232 .6175 L p .707 .577 .707 r
F P
0 g
s
.43187 .52692 m .42594 .58153 L .39495 .57628 L p .707 .577 .707 r
F P
0 g
s
.39495 .57628 m .40088 .52168 L .43187 .52692 L p .707 .577 .707 r
F P
0 g
s
.47634 .67344 m .47936 .69202 L .45869 .69025 L p .707 .577 .707 r
F P
0 g
s
.45869 .69025 m .45566 .67167 L .47634 .67344 L p .707 .577 .707 r
F P
0 g
s
.36328 .57404 m .36921 .51943 L .40088 .52168 L p .707 .577 .707 r
F P
0 g
s
.36921 .51943 m .36328 .57404 L .33402 .57502 L p .707 .577 .707 r
F P
0 g
s
.40088 .52168 m .39495 .57628 L .36328 .57404 L p .707 .577 .707 r
F P
0 g
s
.33232 .6175 m .33216 .65454 L .30811 .66012 L p .707 .577 .707 r
F P
0 g
s
.45217 .62014 m .45201 .65717 L .42455 .65264 L p .707 .577 .707 r
F P
0 g
s
.42455 .65264 m .42471 .61561 L .45217 .62014 L p .707 .577 .707 r
F P
0 g
s
.31651 .71496 m .31349 .69637 L .33735 .68833 L p .707 .577 .707 r
F P
0 g
s
.33216 .65454 m .33232 .6175 L .36171 .61422 L p .707 .577 .707 r
F P
0 g
s
.33735 .68833 m .34037 .70692 L .31651 .71496 L p .707 .577 .707 r
F P
0 g
s
.45566 .67167 m .45869 .69025 L .43165 .69106 L p .707 .577 .707 r
F P
0 g
s
.43165 .69106 m .42863 .67247 L .45566 .67167 L p .707 .577 .707 r
F P
0 g
s
.42471 .61561 m .42455 .65264 L .39338 .6506 L p .707 .577 .707 r
F P
0 g
s
.39338 .6506 m .39354 .61357 L .42471 .61561 L p .707 .577 .707 r
F P
0 g
s
.36171 .61422 m .36154 .65126 L .33216 .65454 L p .707 .577 .707 r
F P
0 g
s
.36154 .65126 m .36171 .61422 L .39354 .61357 L p .707 .577 .707 r
F P
0 g
s
.39354 .61357 m .39338 .6506 L .36154 .65126 L p .707 .577 .707 r
F P
0 g
s
.34037 .70692 m .33735 .68833 L .36642 .68123 L p .707 .577 .707 r
F P
0 g
s
.36642 .68123 m .36945 .69982 L .34037 .70692 L p .707 .577 .707 r
F P
0 g
s
.42863 .67247 m .43165 .69106 L .4009 .69435 L p .707 .577 .707 r
F P
0 g
s
.4009 .69435 m .39788 .67577 L .42863 .67247 L p .707 .577 .707 r
F P
0 g
s
.36945 .69982 m .36642 .68123 L .39788 .67577 L p .707 .577 .707 r
F P
0 g
s
.39788 .67577 m .4009 .69435 L .36945 .69982 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Eoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007=oo`00LWoo0`00
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000Kgoo001`
Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000
FUH00000KGoo001^Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0`00JWoo001/Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2
001XOol006]oo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Ioo`00JWoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P00I7oo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HWoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo
001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJ
EP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJEP0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0001QOol006Uoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00065oo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001ROol006Eoo`P000=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00GGoo20000eYF00<005YFFUH00UYF
2@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001IOol40003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH6000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000<Ool8001>Ool005Moo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004Ool80003FUH0
0`00FUIJEP02FUH90015Ool005Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000040003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH6000oOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000mOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00>goo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000hOol005=oo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00002000eOol005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP0000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000cOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Woo
001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0
059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002moo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00;Woo001BOol20004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00;Woo001BOol20003FUH500000eYF
001JEP04FUH80005FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool0055oo`04001JEP00FUH20006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH40005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP04001JEUYFFUHG0006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00DGoo00H005YF000005YF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<00000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000=JEPD00003
FUH005YF00AJEPL000Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF
;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20005FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
Ool40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF
00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
1EYF00@005YFFUIJEP8002moo`00DGoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YF
FUH00eYF4P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002moo`00DWoo
00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJEP03001JEUYF009J
EPP0009JEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;goo001BOol01000FUIJEP001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH60002FUH30002FUH00`00FUH0000_Ool003ioo`P000eoo`<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH40004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01@00FUH005YF
0000;goo000fOol80003FUH00`00FUIJEP02FUH70008Ool00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P000UYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP000000031oo`00
<Woo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010001Goo0P000eYF00<005YF
00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF1@00<7oo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40003Ool500000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP8000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF0080031oo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP80031o
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH70003Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000eYF1P0015YF0P001goo1`0015YF00<005YFFUH00UYF2`0000=JEP00FUH00UYF0P00<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000=JEPD0009JEP04001JEP00000<Ool@0003
FUH30003FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF00<005YFFUH015YF00<005YF
FUH00P0000=JEP000000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF20000UYF00<007oo0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF00001@0015YF00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF1@001EYF00@005YFFUIJEP800005Ool005YFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000`Ool0
02]oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00FUH20004FUH500000eYF001JEP02FUH200001Goo001JEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
031oo`00:goo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00@005YFFUIJEPT0009JEP03001JEUYF00=JEPl000EJEP04001JEUYF0002FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE00000eYF001oo`0_Ool002]oo`8000=JEPD00003
FUH005YF00AJEPL0009oo`T0009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30007FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000`Ool002Yoo`04
001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002Ool40003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHD00000eYF001JEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000
FUIJEUYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
031oo`00:Woo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000_Ool002Yoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
00000eYF001JEP02FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000_Ool002Yoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1@00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF3P000eYF00D005YFFUIJEP0002moo`00
:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00H005YF000005YF0005FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEPD000Ioo`D0009JEP8002ioo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH00UYF500000=JEP00FUH015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01UYF
00<005YFFUH03P0037oo0P000UYF1000;Woo000[Ool01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP0000000UYF00<005YFFUH01eYF
00<005YFFUH015YF1P001eYF00<005YFFUH00eYF1@0000=JEP0000000P0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH0
15YF100067oo0P0015YF00@005YFFUH002ioo`00:goo00@005YFFUH000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00MJEP03001JEUYF
00@000EJEP03001JEUYF00EJEP03001JEP0000<00003FUH0000000=JEP04001JEP000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF
00<005YFFUH0100067oo100000=JEP00FUH00eYF00<005YF0000;goo000/Ool00`00FUH00006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP05
FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP02FUH50003FUH30005FUH00`00FUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH4
00000eYF001oo`0FOol30005FUH00`00FUIJEP02FUH2000`Ool002eoo`8000EJEP03001JEUYF00EJ
EQ40009JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF01L000IJEP80009JEP03
001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00005FUH00`00FUH00004000015YF0000000057oo100000=JEP00FUH01UYF00D005YFFUIJEP00
035oo`00;Woo0P0015YF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF
00<005YFFUH00eYF100000AJEP00Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00@000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP04001JEUYFFUH30004FUH5000=Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000<Woo000`Ool600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP03FUH00`00FUH000030003FUH01@00FUH007oo00000UYF00<005YFFUH00eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00H005YF000005YF0005FUH00`00FUIJEP020004Ool9
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000dOol002moo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP80009JEP04001JEUYFFUH50004FUH20002Ool01000FUIJEP00
1EYF00<005YFFUH01P001UYF00<005YFFUH015YF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000UYF1@001UYF2@0015YF00<005YFFUH00`000eYF00<005YFFUH0
1UYF00<005YF00000`00=goo000]Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUH000020004FUH200000eYF00000003Ool00`00FUIJEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP070003FUH00`00FUIJEP06FUH00`00FUH0
00040003FUH00`00FUIJEP04FUH3000kOol002]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUHD0004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUH000040003FUH00`00FUIJEP04000nOol002Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01eYF1P0000=JEP0000000`00@Woo000YOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000040017Ool002Uoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6000;FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH7001;Ool002Uoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000180
059oo`00:Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00UYF3P002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000100000AJEP00000000=JEP8005Moo`00:Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF2@0000EJEP00Oomoo`00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00EJEP04001JEUYF0002FUH2001GOol002Uoo`03001JEP0000AJEP04001JEUYFFUH8000GOol40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo00@005YFFUH000EJEP03001JEUYF00EJEPX000]J
EP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH4001GOol002Uoo`03001JEP0000=JEPD002=oo`D000=JEP05001JEUYFFUH00002Ool01000
FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF
1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00UYF0`00Egoo
000YOol01000FUH005YF0P0015YF1@0087oo20000eYF00@007ooOol0009JEP03001JEUYF00=JEP<0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
00<000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<005Moo`00:Goo00H005YF
000005YF0005FUH01000FUIJEUYF2@004Woo1@001EYF00@005YFFUH0009JEP04001oogoo0002FUH0
1000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF00002@0000AJEP00FUH005Moo`00
:Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4P000eYF00<005YFFUH0
15YF00@005YFFUIJEP<0009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0
0003FUH00`00FUIJEP02FUH4001HOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEQ@00005FUH007ooOol00002FUH200000eYF001JEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000
FUH0000015YF00<005YF00000eYF00<005YFFUH00UYF00<005YFFUH00P00Egoo000YOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH000000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEP0000=JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002Uoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP02001FOol002Yoo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUH00000Ool00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001@000eYF00D0
05YFFUIJEP0005Ioo`00:goo00@005YFFUH000EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH00000Ool000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<000Aoo`D0009JEP03001oogoo05Aoo`00;7oo0`001EYF
00<005YF00000P0025YF00<005YFFUH01UYF00<005YFFUH00UYF4`000UYF00<007oo00001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000000Moo`80009JEP@005Eoo`00;Woo0`000eYF0P00
0UYF00<005YFFUH01eYF00<005YFFUH015YF1P001eYF00<005YFFUH015YF00<005YF00001P0000=o
o`00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Eoo`8000AJEP04001JEP00
001EOol0035oo`<000AJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00EJEP04001J
EUYFFUH700000eYF001JEP0200000goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00
FUIJEP00Ool0100000=JEP00FUH00eYF00@005YFFUH005Eoo`00;goo0P0000=JEP00FUH01EYF00<0
05YFFUH015YF1@002EYF00<005YFFUH00UYF1`000goo0P000eYF00@005YFFUH0009oo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020005FUH00`00FUIJEP02FUH3001FOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF01L000Ioo`@00003FUH005YF00=JEP8000Aoo`800003FUH0
05YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP05001JEUYFFUH0001HOol002aoo`8000AJ
EP03001JEUYF00=JEP@001Uoo`@000EJEP03001JEUYF009JEP8000Ioo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00EJEP04001JEP00001IOol002]oo`03001JEP0000AJEP03001JEP0000<0
01Uoo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH20008Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0`00Fgoo000[Ool01000FUIJEP000eYF0P005goo1P001UYF00<005YFFUH015YF
00@005YF000000aoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUH00003001NOol002]oo`05001JEUYF
001JEP02000@Ool90003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000BOol40009FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH600000eYF001JEP05FUH3001R
Ool002aoo`03001JEP0000<000Qoo`P000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
008001Uoo`@000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H0
00=JEP03001JEUYF00@006Eoo`00;7oo0P0000AJEP00FUIJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0021oo`@00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00AJEPh00003FUH0000000<006Uoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01000:7oo20001UYF00<005YFFUH015YF3@0025YF1`00
KWoo000/Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH5000dOol=0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001`Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@004Aooa<007Uoo`00;goo10000eYF
00<005YFFUH01EYF00<005YFFUH00UYF1P00e7oo000cOol@003JOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58095 .72883 m .59051 .67517 L .55981 .66789 L p .707 .577 .707 r
F P
0 g
s
.60952 .73254 m .61236 .7329 L p .60508 .71366 L .707 .577 .707 r
F P
0 g
s
.61236 .7329 m .62192 .67924 L .59051 .67517 L p .707 .577 .707 r
F P
0 g
s
.62192 .67924 m .62191 .67931 L p .64141 .73337 L .707 .577 .707 r
F P
0 g
s
.62191 .67931 m .61236 .7329 L .639 .73334 L p .707 .577 .707 r
F P
0 g
s
.639 .73334 m .64141 .73337 L p .62191 .67931 L .707 .577 .707 r
F P
0 g
s
.64141 .73337 m .65097 .67971 L .62192 .67924 L p .707 .577 .707 r
F P
0 g
s
.65097 .67971 m .65023 .68387 L p .66524 .7302 L .707 .577 .707 r
F P
0 g
s
.65023 .68387 m .64141 .73337 L .6636 .73042 L p .707 .577 .707 r
F P
0 g
s
.6636 .73042 m .66524 .7302 L p .65023 .68387 L .707 .577 .707 r
F P
0 g
s
.66524 .7302 m .6748 .67653 L .65097 .67971 L p .707 .577 .707 r
F P
0 g
s
.6748 .67653 m .67427 .67953 L p .68154 .72368 L .707 .577 .707 r
F P
0 g
s
.67427 .67953 m .66524 .7302 L .68055 .72408 L p .707 .577 .707 r
F P
0 g
s
.68055 .72408 m .68154 .72368 L p .67427 .67953 L .707 .577 .707 r
F P
0 g
s
.68154 .72368 m .6911 .67002 L .6748 .67653 L p .707 .577 .707 r
F P
0 g
s
.6911 .67002 m .68154 .72368 L .68826 .71502 L p .707 .577 .707 r
F P
0 g
s
.68826 .71502 m .6887 .71446 L p .68996 .69106 L .707 .577 .707 r
F P
0 g
s
.68996 .69106 m .6911 .67002 L .68826 .71502 L .707 .577 .707 r
F
.68105 .71318 m .68096 .72696 L p .68787 .74181 L F P
0 g
s
.68814 .70478 m .68105 .71318 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68787 .74181 m .68804 .71814 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68804 .71814 m .68814 .70478 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.6887 .71446 m .69826 .6608 L .6911 .67002 L p .707 .577 .707 r
F P
0 g
s
.69826 .6608 m .6887 .71446 L .68851 .7137 L p .707 .577 .707 r
F P
0 g
s
.68814 .70478 m .68804 .71814 L p .68498 .73316 L .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68814 .70478 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68498 .73316 m .68515 .70829 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68515 .70829 m .68524 .69614 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68096 .72696 m .68079 .75021 L .68374 .74671 L p .707 .577 .707 r
F P
0 g
s
.68374 .74671 m .68787 .74181 L p .68096 .72696 L .707 .577 .707 r
F P
0 g
s
.68079 .75021 m .68105 .71318 L .66469 .72051 L p .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68498 .73316 L .67239 .72512 L p .707 .577 .707 r
F P
0 g
s
.69558 .64979 m .68602 .70345 L .685 .70248 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .68524 .69614 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67239 .72512 m .67258 .69837 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67258 .69837 m .67265 .68809 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.66469 .72051 m .66459 .73387 L p .68079 .75021 L .707 .577 .707 r
F P
0 g
s
.66442 .75754 m .66469 .72051 L .64063 .72606 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .67239 .72512 L .65133 .71846 L p .707 .577 .707 r
F P
0 g
s
.65133 .71846 m .65159 .68143 L .67265 .68809 L p .707 .577 .707 r
F P
0 g
s
.68332 .63805 m .67376 .69172 L .6719 .6907 L p .707 .577 .707 r
F P
0 g
s
.6719 .6907 m .65313 .68041 L p .66901 .65813 L .707 .577 .707 r
F P
0 g
s
.66901 .65813 m .68332 .63805 L .6719 .6907 L .707 .577 .707 r
F
.685 .70248 m .67376 .69172 L p .68419 .67167 L F P
0 g
s
.68419 .67167 m .69558 .64979 L .685 .70248 L .707 .577 .707 r
F
.68851 .7137 m .68602 .70345 L p .69169 .68369 L F P
0 g
s
.69169 .68369 m .69826 .6608 L .68851 .7137 L .707 .577 .707 r
F
.68804 .71814 m .68787 .74181 L .68663 .73809 L p F P
0 g
s
.68663 .73809 m .68498 .73316 L p .68804 .71814 L .707 .577 .707 r
F P
0 g
s
.66459 .73387 m .66442 .75754 L .67059 .75477 L p .707 .577 .707 r
F P
0 g
s
.67059 .75477 m .68079 .75021 L p .66459 .73387 L .707 .577 .707 r
F P
0 g
s
.64063 .72606 m .64055 .73822 L p .66442 .75754 L .707 .577 .707 r
F P
0 g
s
.64055 .73822 m .64037 .76309 L .64787 .76136 L p .707 .577 .707 r
F P
0 g
s
.64787 .76136 m .66442 .75754 L p .64055 .73822 L .707 .577 .707 r
F P
0 g
s
.61125 .72928 m .61118 .73956 L p .64037 .76309 L .707 .577 .707 r
F P
0 g
s
.61118 .73956 m .61099 .7663 L .61731 .76561 L p .707 .577 .707 r
F P
0 g
s
.61731 .76561 m .64037 .76309 L p .61118 .73956 L .707 .577 .707 r
F P
0 g
s
.59051 .67517 m .58095 .72883 L .60952 .73254 L p .707 .577 .707 r
F P
0 g
s
.60508 .71366 m .59051 .67517 L .60952 .73254 L .707 .577 .707 r
F
.55025 .72155 m .55981 .66789 L .53282 .65812 L p F P
0 g
s
.55981 .66789 m .55025 .72155 L .58095 .72883 L p .707 .577 .707 r
F P
0 g
s
.52326 .71179 m .53282 .65812 L .51219 .64682 L p .707 .577 .707 r
F P
0 g
s
.53282 .65812 m .52326 .71179 L .55025 .72155 L p .707 .577 .707 r
F P
0 g
s
.57915 .76688 m .57942 .72985 L .54824 .72773 L p .707 .577 .707 r
F P
0 g
s
.57942 .72985 m .57915 .76688 L .61099 .7663 L p .707 .577 .707 r
F P
0 g
s
.61099 .7663 m .61125 .72928 L .57942 .72985 L p .707 .577 .707 r
F P
0 g
s
.64037 .76309 m .64063 .72606 L .61125 .72928 L p .707 .577 .707 r
F P
0 g
s
.54798 .76475 m .54824 .72773 L .52079 .72311 L p .707 .577 .707 r
F P
0 g
s
.54824 .72773 m .54798 .76475 L .57915 .76688 L p .707 .577 .707 r
F P
0 g
s
.58952 .80753 m .58466 .78918 L .5546 .79567 L p .707 .577 .707 r
F P
0 g
s
.58466 .78918 m .58952 .80753 L .62036 .79919 L p .707 .577 .707 r
F P
0 g
s
.62036 .79919 m .6155 .78084 L .58466 .78918 L p .707 .577 .707 r
F P
0 g
s
.6155 .78084 m .62036 .79919 L .64895 .78981 L p .707 .577 .707 r
F P
0 g
s
.64895 .78981 m .6441 .77146 L .6155 .78084 L p .707 .577 .707 r
F P
0 g
s
.52079 .72311 m .52052 .76014 L .54798 .76475 L p .707 .577 .707 r
F P
0 g
s
.5546 .79567 m .55945 .81402 L .58952 .80753 L p .707 .577 .707 r
F P
0 g
s
.51219 .64682 m .50263 .70048 L .52326 .71179 L p .707 .577 .707 r
F P
0 g
s
.50263 .70048 m .51219 .64682 L .49993 .63508 L p .707 .577 .707 r
F P
0 g
s
.52052 .76014 m .52079 .72311 L .49973 .71646 L p .707 .577 .707 r
F P
0 g
s
.55945 .81402 m .5546 .79567 L .52824 .79967 L p .707 .577 .707 r
F P
0 g
s
.52824 .79967 m .5331 .81802 L .55945 .81402 L p .707 .577 .707 r
F P
0 g
s
.6441 .77146 m .64895 .78981 L .6725 .7803 L p .707 .577 .707 r
F P
0 g
s
.6725 .7803 m .66764 .76195 L .6441 .77146 L p .707 .577 .707 r
F P
0 g
s
.49973 .71646 m .49947 .75348 L .52052 .76014 L p .707 .577 .707 r
F P
0 g
s
.49993 .63508 m .49038 .68875 L .50263 .70048 L p .707 .577 .707 r
F P
0 g
s
.5331 .81802 m .52824 .79967 L .50818 .80078 L p .707 .577 .707 r
F P
0 g
s
.50818 .80078 m .51304 .81913 L .5331 .81802 L p .707 .577 .707 r
F P
0 g
s
.49947 .75348 m .49973 .71646 L .48714 .70841 L p .707 .577 .707 r
F P
0 g
s
.66764 .76195 m .6725 .7803 L .68869 .77161 L p .707 .577 .707 r
F P
0 g
s
.68869 .77161 m .68383 .75326 L .66764 .76195 L p .707 .577 .707 r
F P
0 g
s
.49038 .68875 m .49993 .63508 L .49725 .62407 L p .707 .577 .707 r
F P
0 g
s
.48714 .70841 m .48688 .74544 L .49947 .75348 L p .707 .577 .707 r
F P
0 g
s
.51304 .81913 m .50818 .80078 L .49638 .7989 L p .707 .577 .707 r
F P
0 g
s
.49725 .62407 m .4877 .67774 L .49038 .68875 L p .707 .577 .707 r
F P
0 g
s
.49638 .7989 m .50124 .81725 L .51304 .81913 L p .707 .577 .707 r
F P
0 g
s
.68383 .75326 m .68869 .77161 L .69595 .76457 L p .707 .577 .707 r
F P
0 g
s
.69595 .76457 m .69109 .74622 L .68383 .75326 L p .707 .577 .707 r
F P
0 g
s
.48688 .74544 m .48714 .70841 L .48424 .69977 L p .707 .577 .707 r
F P
0 g
s
.68602 .70345 m .69558 .64979 L .69826 .6608 L p .707 .577 .707 r
F P
0 g
s
.4877 .67774 m .49725 .62407 L .50441 .61486 L p .707 .577 .707 r
F P
0 g
s
.50124 .81725 m .49638 .7989 L .49399 .79421 L p .707 .577 .707 r
F P
0 g
s
.50441 .61486 m .49485 .66852 L .4877 .67774 L p .707 .577 .707 r
F P
0 g
s
.49399 .79421 m .49885 .81256 L .50124 .81725 L p .707 .577 .707 r
F P
0 g
s
.48424 .69977 m .48398 .73679 L .48688 .74544 L p .707 .577 .707 r
F P
0 g
s
.48398 .73679 m .48424 .69977 L .49133 .69137 L p .707 .577 .707 r
F P
0 g
s
.49485 .66852 m .50441 .61486 L .52071 .60834 L p .707 .577 .707 r
F P
0 g
s
.49133 .69137 m .49106 .72839 L .48398 .73679 L p .707 .577 .707 r
F P
0 g
s
.52071 .60834 m .51115 .662 L .49485 .66852 L p .707 .577 .707 r
F P
0 g
s
.49885 .81256 m .49399 .79421 L .50125 .78718 L p .707 .577 .707 r
F P
0 g
s
.49106 .72839 m .49133 .69137 L .5077 .68403 L p .707 .577 .707 r
F P
0 g
s
.5077 .68403 m .50743 .72106 L .49106 .72839 L p .707 .577 .707 r
F P
0 g
s
.49635 .82389 m .51426 .32427 L .47028 .32 L p .707 .577 .707 r
F P
0 g
s
.50125 .78718 m .5061 .80553 L .49885 .81256 L p .707 .577 .707 r
F P
0 g
s
.51115 .662 m .52071 .60834 L .54454 .60516 L p .707 .577 .707 r
F P
0 g
s
.54454 .60516 m .53498 .65882 L .51115 .662 L p .707 .577 .707 r
F P
0 g
s
.5061 .80553 m .50125 .78718 L .51744 .77848 L p .707 .577 .707 r
F P
0 g
s
.51744 .77848 m .5223 .79683 L .5061 .80553 L p .707 .577 .707 r
F P
0 g
s
.50743 .72106 m .5077 .68403 L .53175 .67849 L p .707 .577 .707 r
F P
0 g
s
.53175 .67849 m .53149 .71551 L .50743 .72106 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53175 .67849 L .53569 .67806 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53569 .67806 L .53674 .70838 L .707 .577 .707 r
F
.54454 .60516 m .56279 .60546 L p .54202 .64532 L F P
0 g
s
.53498 .65882 m .53736 .64548 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.53736 .64548 m .54454 .60516 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.57744 .60613 m .605 .6097 L p .5792 .64093 L .707 .577 .707 r
F P
0 g
s
.6357 .61698 m .62614 .67064 L .59544 .66337 L p .707 .577 .707 r
F P
0 g
s
.59544 .66337 m .605 .6097 L .6357 .61698 L p .707 .577 .707 r
F P
0 g
s
.605 .6097 m .59544 .66337 L .56923 .65997 L p .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .54769 .64512 L .57028 .66635 L .707 .577 .707 r
F
.56923 .65997 m .56403 .65929 L p .56827 .65416 L F P
0 g
s
.56827 .65416 m .605 .6097 L .56923 .65997 L .707 .577 .707 r
F
.54099 .76897 m .54584 .78732 L .5223 .79683 L p F P
0 g
s
.54584 .78732 m .54099 .76897 L .56138 .76228 L p .707 .577 .707 r
F P
0 g
s
.56138 .76228 m .56958 .75959 L p .56417 .76591 L .707 .577 .707 r
F P
0 g
s
.54584 .78732 m .56138 .76228 L .56417 .76591 L .707 .577 .707 r
F
.5372 .72178 m .54769 .64512 L .53564 .67674 L F
.54428 .74005 m .54769 .64512 L p .53615 .72947 L F P
0 g
s
.56958 .75959 m .57444 .77794 L .54584 .78732 L p .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .54127 .82422 L p .57028 .66635 L .707 .577 .707 r
F P
0 g
s
.56113 .67527 m .56087 .71229 L .53696 .71491 L p .707 .577 .707 r
F P
0 g
s
.53696 .71491 m .53149 .71551 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.53674 .70838 m .56113 .67527 L .53696 .71491 L .707 .577 .707 r
F
.53615 .72947 m .5372 .72178 L .53359 .68213 L F
.5372 .72178 m .53564 .67674 L .53359 .68213 L F
.5223 .79683 m .51744 .77848 L .54099 .76897 L p F P
0 g
s
.54127 .82422 m .54428 .74005 L p .53615 .72947 L .707 .577 .707 r
F P
0 g
s
.57359 .60563 m .57744 .60613 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.56827 .65416 m .57744 .60613 L .5792 .64093 L .707 .577 .707 r
F
.56667 .64445 m .57359 .60563 L p .56827 .65416 L F P
0 g
s
.57435 .64418 m .56667 .64445 L .57028 .66635 L .707 .577 .707 r
F
.62414 .67682 m .62387 .71384 L .5927 .71172 L p F P
0 g
s
.5927 .71172 m .59297 .67469 L .62414 .67682 L p .707 .577 .707 r
F P
0 g
s
.5719 .67619 m .57435 .64418 L .57028 .66635 L .707 .577 .707 r
F
.57436 .64433 m .57435 .64418 L .5719 .67619 L F
.57198 .67507 m .59297 .67469 L p .56993 .70168 L F P
0 g
s
.56663 .7443 m .57028 .66635 L .54127 .82422 L .707 .577 .707 r
F
.59297 .67469 m .5927 .71172 L .56912 .71214 L p F P
0 g
s
.56993 .70168 m .59297 .67469 L .56912 .71214 L .707 .577 .707 r
F
.57748 .71012 m .5719 .67619 L .56663 .7443 L F
.5719 .67619 m .57028 .66635 L .56663 .7443 L F
.56912 .71214 m .56087 .71229 L p .56993 .70168 L F P
0 g
s
.56087 .71229 m .56113 .67527 L .57198 .67507 L p .707 .577 .707 r
F P
0 g
s
.56087 .71229 m .57198 .67507 L .56993 .70168 L .707 .577 .707 r
F
.57748 .71012 m .57436 .64433 L .5719 .67619 L F
.63049 .74476 m .63534 .76311 L .60528 .7696 L p F P
0 g
s
.60528 .7696 m .60042 .75125 L .63049 .74476 L p .707 .577 .707 r
F P
0 g
s
.57444 .77794 m .57034 .76247 L p .60042 .75125 L .707 .577 .707 r
F P
0 g
s
.57034 .76247 m .56958 .75959 L .57103 .7592 L p .707 .577 .707 r
F P
0 g
s
.57103 .7592 m .60042 .75125 L p .57034 .76247 L .707 .577 .707 r
F P
0 g
s
.60042 .75125 m .60528 .7696 L .57444 .77794 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .60903 .57881 L .58504 .75604 L .707 .577 .707 r
F
.60063 .32097 m .58778 .67972 L p .60903 .57881 L F P
0 g
s
.58778 .67972 m .58504 .75604 L p .60903 .57881 L .707 .577 .707 r
F P
0 g
s
.58504 .75604 m .58273 .82059 L .58826 .81941 L p .707 .577 .707 r
F P
0 g
s
.58826 .81941 m .61667 .81334 L p .58504 .75604 L .707 .577 .707 r
F P
0 g
s
.56403 .65929 m .56667 .64445 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.54127 .82422 m .58273 .82059 L p .57748 .71012 L .707 .577 .707 r
F P
0 g
s
.56279 .60546 m .57359 .60563 L p .55073 .63712 L .707 .577 .707 r
F P
0 g
s
.53498 .65882 m .56279 .60546 L .55073 .63712 L .707 .577 .707 r
F
.56403 .65929 m .53498 .65882 L p .54486 .64522 L F P
0 g
s
.57359 .60563 m .56667 .64445 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .56403 .65929 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.60063 .32097 m .55917 .3246 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58273 .82059 m .58907 .64367 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58907 .64367 m .60063 .32097 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .54769 .64512 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .51426 .32427 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .55917 .3246 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.53569 .67806 m .56113 .67527 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.51426 .32427 m .49635 .82389 L .54075 .82422 L p .707 .577 .707 r
F P
0 g
s
.54075 .82422 m .54127 .82422 L p .53982 .7974 L .707 .577 .707 r
F P
0 g
s
.53982 .7974 m .51426 .32427 L .54075 .82422 L .707 .577 .707 r
F
.45237 .81962 m .47028 .32 L .43154 .31221 L p F P
0 g
s
.47028 .32 m .45237 .81962 L .49635 .82389 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .63458 .31372 L .60063 .32097 L p .707 .577 .707 r
F P
0 g
s
.69109 .74622 m .69595 .76457 L .69356 .75988 L p .707 .577 .707 r
F P
0 g
s
.69356 .75988 m .6887 .74153 L .69109 .74622 L p .707 .577 .707 r
F P
0 g
s
.67376 .69172 m .68332 .63805 L .69558 .64979 L p .707 .577 .707 r
F P
0 g
s
.41363 .81183 m .43154 .31221 L .40184 .30167 L p .707 .577 .707 r
F P
0 g
s
.43154 .31221 m .41363 .81183 L .45237 .81962 L p .707 .577 .707 r
F P
0 g
s
.23794 .74005 m .2475 .68638 L .2168 .67911 L p .707 .577 .707 r
F P
0 g
s
.2475 .68638 m .23794 .74005 L .26935 .74412 L p .707 .577 .707 r
F P
0 g
s
.26935 .74412 m .27891 .69046 L .2475 .68638 L p .707 .577 .707 r
F P
0 g
s
.66269 .62675 m .65313 .68041 L .62614 .67064 L p .707 .577 .707 r
F P
0 g
s
.62614 .67064 m .6357 .61698 L .66269 .62675 L p .707 .577 .707 r
F P
0 g
s
.65159 .68143 m .65133 .71846 L .62387 .71384 L p .707 .577 .707 r
F P
0 g
s
.62387 .71384 m .62414 .67682 L .65159 .68143 L p .707 .577 .707 r
F P
0 g
s
.65684 .74077 m .6617 .75912 L .63534 .76311 L p .707 .577 .707 r
F P
0 g
s
.63534 .76311 m .63049 .74476 L .65684 .74077 L p .707 .577 .707 r
F P
0 g
s
.63458 .31372 m .61667 .81334 L .63978 .80319 L p .707 .577 .707 r
F P
0 g
s
.63978 .80319 m .65768 .30357 L .63458 .31372 L p .707 .577 .707 r
F P
0 g
s
.27891 .69046 m .26935 .74412 L .2984 .74459 L p .707 .577 .707 r
F P
0 g
s
.2984 .74459 m .30796 .69093 L .27891 .69046 L p .707 .577 .707 r
F P
0 g
s
.20724 .73277 m .2168 .67911 L .18981 .66934 L p .707 .577 .707 r
F P
0 g
s
.2168 .67911 m .20724 .73277 L .23794 .74005 L p .707 .577 .707 r
F P
0 g
s
.65313 .68041 m .66269 .62675 L .68332 .63805 L p .707 .577 .707 r
F P
0 g
s
.6887 .74153 m .69356 .75988 L .68176 .758 L p .707 .577 .707 r
F P
0 g
s
.68176 .758 m .6769 .73965 L .6887 .74153 L p .707 .577 .707 r
F P
0 g
s
.38393 .80129 m .40184 .30167 L .38408 .2894 L p .707 .577 .707 r
F P
0 g
s
.40184 .30167 m .38393 .80129 L .41363 .81183 L p .707 .577 .707 r
F P
0 g
s
.30796 .69093 m .2984 .74459 L .32224 .74141 L p .707 .577 .707 r
F P
0 g
s
.32224 .74141 m .33179 .68775 L .30796 .69093 L p .707 .577 .707 r
F P
0 g
s
.18025 .723 m .18981 .66934 L .16918 .65803 L p .707 .577 .707 r
F P
0 g
s
.18981 .66934 m .18025 .723 L .20724 .73277 L p .707 .577 .707 r
F P
0 g
s
.23614 .81283 m .23641 .7758 L .20524 .77368 L p .707 .577 .707 r
F P
0 g
s
.23641 .7758 m .23614 .81283 L .26798 .81225 L p .707 .577 .707 r
F P
0 g
s
.26798 .81225 m .26824 .77523 L .23641 .7758 L p .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .30109 .8043 L .28994 .80796 L p .707 .577 .707 r
F P
0 g
s
.28994 .80796 m .27249 .81369 L p .28586 .81727 L .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .28994 .80796 L .28586 .81727 L .707 .577 .707 r
F
.30109 .8043 m .30594 .82266 L .32949 .81315 L p F P
0 g
s
.32949 .81315 m .32463 .7948 L .31614 .79823 L p .707 .577 .707 r
F P
0 g
s
.31614 .79823 m .30109 .8043 L p .31266 .80791 L .707 .577 .707 r
F P
0 g
s
.32949 .81315 m .31614 .79823 L .31266 .80791 L .707 .577 .707 r
F
.32463 .7948 m .32949 .81315 L .34568 .80445 L p F P
0 g
s
.34568 .80445 m .34083 .7861 L .33554 .78894 L p .707 .577 .707 r
F P
0 g
s
.33554 .78894 m .32463 .7948 L p .3338 .799 L .707 .577 .707 r
F P
0 g
s
.34568 .80445 m .33554 .78894 L .3338 .799 L .707 .577 .707 r
F
.34083 .7861 m .34568 .80445 L .35294 .79742 L p F P
0 g
s
.35294 .79742 m .34808 .77907 L .3459 .78119 L p .707 .577 .707 r
F P
0 g
s
.3459 .78119 m .34083 .7861 L p .34656 .79146 L .707 .577 .707 r
F P
0 g
s
.35294 .79742 m .3459 .78119 L .34656 .79146 L .707 .577 .707 r
F
.33778 .79615 m .34486 .78775 L p .33959 .76561 L F P
0 g
s
.34486 .78775 m .34513 .75073 L .33805 .75913 L p .707 .577 .707 r
F P
0 g
s
.34486 .78775 m .34197 .77911 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34513 .75073 m .34501 .76745 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34501 .76745 m .34486 .78775 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.33805 .75913 m .33793 .77516 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.33793 .77516 m .33778 .79615 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .33778 .79615 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32168 .76646 m .32156 .78318 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32156 .78318 m .32141 .80349 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .32141 .80349 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29762 .77201 m .29749 .79071 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29749 .79071 m .29736 .80903 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.26824 .77523 m .26798 .81225 L .29736 .80903 L p .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .29762 .77201 L .26824 .77523 L p .707 .577 .707 r
F P
0 g
s
.20497 .8107 m .20524 .77368 L .17778 .76906 L p .707 .577 .707 r
F P
0 g
s
.20524 .77368 m .20497 .8107 L .23614 .81283 L p .707 .577 .707 r
F P
0 g
s
.6769 .73965 m .68176 .758 L .6617 .75912 L p .707 .577 .707 r
F P
0 g
s
.6617 .75912 m .65684 .74077 L .6769 .73965 L p .707 .577 .707 r
F P
0 g
s
.16918 .65803 m .15962 .7117 L .18025 .723 L p .707 .577 .707 r
F P
0 g
s
.65768 .30357 m .63978 .80319 L .64978 .79113 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .66769 .29151 L .65768 .30357 L p .707 .577 .707 r
F P
0 g
s
.33179 .68775 m .32224 .74141 L .33853 .7349 L p .707 .577 .707 r
F P
0 g
s
.33853 .7349 m .34809 .68123 L .33179 .68775 L p .707 .577 .707 r
F P
0 g
s
.24651 .84038 m .24166 .82203 L .21159 .82852 L p .707 .577 .707 r
F P
0 g
s
.24166 .82203 m .24651 .84038 L .27735 .83204 L p .707 .577 .707 r
F P
0 g
s
.27735 .83204 m .27249 .81369 L .24166 .82203 L p .707 .577 .707 r
F P
0 g
s
.15962 .7117 m .16918 .65803 L .15692 .6463 L p .707 .577 .707 r
F P
0 g
s
.27249 .81369 m .27735 .83204 L .30594 .82266 L p .707 .577 .707 r
F P
0 g
s
.21159 .82852 m .21644 .84687 L .24651 .84038 L p .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .32168 .76646 L .29762 .77201 L p .707 .577 .707 r
F P
0 g
s
.17778 .76906 m .17752 .80608 L .20497 .8107 L p .707 .577 .707 r
F P
0 g
s
.21644 .84687 m .21159 .82852 L .18523 .83251 L p .707 .577 .707 r
F P
0 g
s
.17752 .80608 m .17778 .76906 L .15672 .7624 L p .707 .577 .707 r
F P
0 g
s
.18523 .83251 m .19009 .85086 L .21644 .84687 L p .707 .577 .707 r
F P
0 g
s
.36618 .78902 m .38408 .2894 L .38001 .27661 L p .707 .577 .707 r
F P
0 g
s
.38408 .2894 m .36618 .78902 L .38393 .80129 L p .707 .577 .707 r
F P
0 g
s
.15692 .6463 m .14737 .69997 L .15962 .7117 L p .707 .577 .707 r
F P
0 g
s
.15672 .7624 m .15646 .79943 L .17752 .80608 L p .707 .577 .707 r
F P
0 g
s
.33778 .79615 m .33805 .75913 L .32168 .76646 L p .707 .577 .707 r
F P
0 g
s
.34809 .68123 m .33853 .7349 L .34569 .72568 L p .707 .577 .707 r
F P
0 g
s
.34569 .72568 m .35525 .67202 L .34809 .68123 L p .707 .577 .707 r
F P
0 g
s
.19009 .85086 m .18523 .83251 L .16517 .83363 L p .707 .577 .707 r
F P
0 g
s
.14737 .69997 m .15692 .6463 L .15424 .63529 L p .707 .577 .707 r
F P
0 g
s
.16517 .83363 m .17003 .85198 L .19009 .85086 L p .707 .577 .707 r
F P
0 g
s
.15646 .79943 m .15672 .7624 L .14413 .75436 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .64637 .78043 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66769 .29151 m .66148 .46482 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66148 .46482 m .64978 .79113 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.64729 .74327 m .65556 .56006 L .64637 .78043 L .707 .577 .707 r
F
.65556 .56006 m .66769 .29151 L .65696 .53756 L F
.65556 .56006 m .65696 .53756 L .64637 .78043 L F
.66361 .27872 m .66769 .29151 L p .64729 .74327 L F P
0 g
s
.64571 .77834 m .64802 .71379 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .66361 .27872 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64248 .5936 m .63983 .60844 L .64325 .61031 L p .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64174 .5776 L .64205 .59325 L .707 .577 .707 r
F
.66361 .27872 m .64802 .71379 L p .64405 .62778 L F P
0 g
s
.64411 .62669 m .63694 .62442 L p .64349 .63818 L .707 .577 .707 r
F P
0 g
s
.64174 .5776 m .66136 .30948 L .64405 .62778 L .707 .577 .707 r
F
.66136 .30948 m .66361 .27872 L .64405 .62778 L F
.65773 .6681 m .65799 .63107 L .64411 .62669 L p F P
0 g
s
.63983 .60844 m .64248 .5936 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .64571 .77834 L p .64308 .64562 L .707 .577 .707 r
F P
0 g
s
.64349 .63818 m .63694 .62442 L .64213 .66317 L .707 .577 .707 r
F
.64174 .5776 m .64405 .62778 L .64308 .64562 L F
.64405 .62778 m .64802 .71379 L .64308 .64562 L F
.63694 .62442 m .63667 .66144 L .64213 .66317 L p F P
0 g
s
.62795 .76608 m .59825 .75553 L p .60451 .6912 L .707 .577 .707 r
F P
0 g
s
.63667 .66144 m .63694 .62442 L .62603 .61745 L p .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62463 .48454 L .62602 .61612 L .707 .577 .707 r
F
.63667 .66144 m .62603 .61745 L .62609 .62275 L F
.63983 .60844 m .63911 .59085 L .63226 .59433 L F
.63072 .59971 m .63983 .60844 L p .63226 .59433 L F P
0 g
s
.64585 .26645 m .63437 .58697 L p .62602 .61612 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .62758 .59671 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.62643 .6549 m .63667 .66144 L p .62609 .62275 L .707 .577 .707 r
F P
0 g
s
.63437 .58697 m .62795 .76608 L p .62759 .76494 L .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62602 .61612 L .62759 .76494 L .707 .577 .707 r
F
.62602 .61612 m .63437 .58697 L .62759 .76494 L F
.62434 .61637 m .62408 .6534 L .62643 .6549 L p F P
0 g
s
.62609 .62275 m .62434 .61637 L .62643 .6549 L .707 .577 .707 r
F
.62603 .61745 m .62434 .61637 L p .62609 .62275 L F P
0 g
s
.62463 .48454 m .64585 .26645 L .62602 .61612 L .707 .577 .707 r
F
.62758 .59671 m .63072 .59971 L p .63226 .59433 L F P
0 g
s
.63437 .58697 m .63531 .56057 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .64585 .26645 L p .6416 .53381 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .6416 .53381 L .64068 .59213 L .707 .577 .707 r
F
.63714 .54305 m .63446 .53203 L p .62821 .59081 L F P
0 g
s
.62758 .59671 m .62996 .58337 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .63714 .54305 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.63714 .54305 m .62996 .58337 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64585 .26645 m .66361 .27872 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.62795 .76608 m .63437 .58697 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64571 .77834 m .62795 .76608 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64205 .59325 L .64571 .77834 L .707 .577 .707 r
F
.64213 .66317 m .65773 .6681 L p .64349 .63818 L F P
0 g
s
.65773 .6681 m .64411 .62669 L .64349 .63818 L .707 .577 .707 r
F
.64939 .55478 m .63714 .54305 L p .63911 .59085 L F P
0 g
s
.64248 .5936 m .64939 .55478 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64939 .55478 m .64248 .5936 L p .65048 .61428 L .707 .577 .707 r
F P
0 g
s
.64325 .61031 m .65048 .61428 L p .64248 .5936 L .707 .577 .707 r
F P
0 g
s
.65048 .61428 m .66047 .61975 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.65163 .56791 m .64939 .55478 L .65048 .61428 L .707 .577 .707 r
F
.65024 .72709 m .6703 .72598 L p .64629 .70936 L F P
0 g
s
.64539 .70874 m .64615 .71162 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.64615 .71162 m .65024 .72709 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .66545 .70763 L .64633 .70869 L p .707 .577 .707 r
F P
0 g
s
.64633 .70869 m .64539 .70874 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .64633 .70869 L .64629 .70936 L .707 .577 .707 r
F
.66047 .61975 m .67002 .56608 L .65192 .55616 L p F P
0 g
s
.65192 .55616 m .64939 .55478 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.66047 .61975 m .65192 .55616 L .65163 .56791 L .707 .577 .707 r
F
.64637 .78043 m .64571 .77834 L p .64729 .74327 L F P
0 g
s
.14413 .75436 m .14387 .79138 L .15646 .79943 L p .707 .577 .707 r
F P
0 g
s
.15424 .63529 m .14469 .68895 L .14737 .69997 L p .707 .577 .707 r
F P
0 g
s
.17003 .85198 m .16517 .83363 L .15337 .83175 L p .707 .577 .707 r
F P
0 g
s
.15337 .83175 m .15823 .8501 L .17003 .85198 L p .707 .577 .707 r
F P
0 g
s
.35525 .67202 m .34569 .72568 L .34301 .71467 L p .707 .577 .707 r
F P
0 g
s
.34301 .71467 m .35257 .661 L .35525 .67202 L p .707 .577 .707 r
F P
0 g
s
.38001 .27661 m .3621 .77624 L .36618 .78902 L p .707 .577 .707 r
F P
0 g
s
.3621 .77624 m .38001 .27661 L .39001 .26455 L p .707 .577 .707 r
F P
0 g
s
.14469 .68895 m .15424 .63529 L .1614 .62607 L p .707 .577 .707 r
F P
0 g
s
.14387 .79138 m .14413 .75436 L .14124 .74571 L p .707 .577 .707 r
F P
0 g
s
.14124 .74571 m .14097 .78274 L .14387 .79138 L p .707 .577 .707 r
F P
0 g
s
.1614 .62607 m .15184 .67974 L .14469 .68895 L p .707 .577 .707 r
F P
0 g
s
.15823 .8501 m .15337 .83175 L .15098 .82706 L p .707 .577 .707 r
F P
0 g
s
.34223 .74208 m .34197 .77911 L .32938 .77106 L p .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .33389 .7725 L .34109 .77365 L p .707 .577 .707 r
F P
0 g
s
.34197 .77911 m .3421 .76079 L p .34513 .75073 L .707 .577 .707 r
F P
0 g
s
.34109 .77365 m .34569 .77438 L p .33997 .78795 L .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .34109 .77365 L .33997 .78795 L .707 .577 .707 r
F
.3421 .76079 m .34223 .74208 L .34331 .74531 L p F P
0 g
s
.34331 .74531 m .34513 .75073 L p .3421 .76079 L .707 .577 .707 r
F P
0 g
s
.15098 .82706 m .15584 .84541 L .15823 .8501 L p .707 .577 .707 r
F P
0 g
s
.35257 .661 m .34301 .71467 L .33075 .70293 L p .707 .577 .707 r
F P
0 g
s
.33075 .70293 m .34031 .64927 L .35257 .661 L p .707 .577 .707 r
F P
0 g
s
.15184 .67974 m .1614 .62607 L .1777 .61956 L p .707 .577 .707 r
F P
0 g
s
.34808 .77907 m .35294 .79742 L .35055 .79273 L p .707 .577 .707 r
F P
0 g
s
.35055 .79273 m .34569 .77438 L .34808 .77907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14097 .78274 m .14124 .74571 L .14832 .73731 L p .707 .577 .707 r
F P
0 g
s
.3721 .76418 m .39001 .26455 L .41312 .2544 L p .707 .577 .707 r
F P
0 g
s
.39001 .26455 m .3721 .76418 L .3621 .77624 L p .707 .577 .707 r
F P
0 g
s
.14832 .73731 m .14805 .77434 L .14097 .78274 L p .707 .577 .707 r
F P
0 g
s
.1777 .61956 m .16814 .67322 L .15184 .67974 L p .707 .577 .707 r
F P
0 g
s
.32938 .77106 m .32964 .73404 L .34223 .74208 L p .707 .577 .707 r
F P
0 g
s
.34031 .64927 m .33075 .70293 L .31012 .69163 L p .707 .577 .707 r
F P
0 g
s
.31012 .69163 m .31968 .63797 L .34031 .64927 L p .707 .577 .707 r
F P
0 g
s
.15584 .84541 m .15098 .82706 L .15824 .82002 L p .707 .577 .707 r
F P
0 g
s
.16814 .67322 m .1777 .61956 L .20153 .61638 L p .707 .577 .707 r
F P
0 g
s
.15824 .82002 m .16309 .83837 L .15584 .84541 L p .707 .577 .707 r
F P
0 g
s
.34569 .77438 m .35055 .79273 L .33875 .79085 L p .707 .577 .707 r
F P
0 g
s
.59825 .75553 m .61615 .25591 L .64585 .26645 L p .707 .577 .707 r
F P
0 g
s
.14805 .77434 m .14832 .73731 L .16469 .72998 L p .707 .577 .707 r
F P
0 g
s
.20153 .61638 m .19197 .67004 L .16814 .67322 L p .707 .577 .707 r
F P
0 g
s
.31968 .63797 m .31012 .69163 L .28313 .68186 L p .707 .577 .707 r
F P
0 g
s
.28313 .68186 m .29269 .6282 L .31968 .63797 L p .707 .577 .707 r
F P
0 g
s
.16469 .72998 m .16442 .76701 L .14805 .77434 L p .707 .577 .707 r
F P
0 g
s
.19197 .67004 m .20153 .61638 L .23058 .61685 L p .707 .577 .707 r
F P
0 g
s
.41312 .2544 m .39521 .75403 L .3721 .76418 L p .707 .577 .707 r
F P
0 g
s
.39521 .75403 m .41312 .2544 L .44706 .24715 L p .707 .577 .707 r
F P
0 g
s
.32964 .73404 m .32938 .77106 L .30832 .76441 L p .707 .577 .707 r
F P
0 g
s
.30832 .76441 m .30859 .72738 L .32964 .73404 L p .707 .577 .707 r
F P
0 g
s
.16309 .83837 m .15824 .82002 L .17443 .81133 L p .707 .577 .707 r
F P
0 g
s
.71816 .63679 m .72771 .58313 L .69701 .57585 L p .707 .577 .707 r
F P
0 g
s
.74673 .6405 m .74957 .64087 L p .74228 .62163 L .707 .577 .707 r
F P
0 g
s
.74957 .64087 m .75913 .5872 L .72771 .58313 L p .707 .577 .707 r
F P
0 g
s
.75913 .5872 m .75911 .58727 L p .77861 .64134 L .707 .577 .707 r
F P
0 g
s
.75911 .58727 m .74957 .64087 L .77621 .6413 L p .707 .577 .707 r
F P
0 g
s
.77621 .6413 m .77861 .64134 L p .75911 .58727 L .707 .577 .707 r
F P
0 g
s
.77861 .64134 m .78817 .58767 L .75913 .5872 L p .707 .577 .707 r
F P
0 g
s
.78817 .58767 m .78743 .59183 L p .80245 .63816 L .707 .577 .707 r
F P
0 g
s
.78743 .59183 m .77861 .64134 L .8008 .63838 L p .707 .577 .707 r
F P
0 g
s
.8008 .63838 m .80245 .63816 L p .78743 .59183 L .707 .577 .707 r
F P
0 g
s
.80245 .63816 m .81201 .58449 L .78817 .58767 L p .707 .577 .707 r
F P
0 g
s
.81201 .58449 m .81147 .58749 L p .81874 .63164 L .707 .577 .707 r
F P
0 g
s
.81147 .58749 m .80245 .63816 L .81775 .63204 L p .707 .577 .707 r
F P
0 g
s
.81775 .63204 m .81874 .63164 L p .81147 .58749 L .707 .577 .707 r
F P
0 g
s
.81874 .63164 m .8283 .57798 L .81201 .58449 L p .707 .577 .707 r
F P
0 g
s
.8283 .57798 m .81874 .63164 L .82547 .62298 L p .707 .577 .707 r
F P
0 g
s
.82547 .62298 m .8259 .62243 L p .82717 .59902 L .707 .577 .707 r
F P
0 g
s
.82717 .59902 m .8283 .57798 L .82547 .62298 L .707 .577 .707 r
F
.81826 .62114 m .81816 .63492 L p .82508 .64977 L F P
0 g
s
.82534 .61274 m .81826 .62114 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82508 .64977 m .82525 .6261 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82525 .6261 m .82534 .61274 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.8259 .62243 m .83546 .56876 L .8283 .57798 L p .707 .577 .707 r
F P
0 g
s
.83546 .56876 m .8259 .62243 L .82572 .62166 L p .707 .577 .707 r
F P
0 g
s
.82534 .61274 m .82525 .6261 L p .82218 .64112 L .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82534 .61274 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82218 .64112 m .82236 .61625 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82236 .61625 m .82245 .6041 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.81816 .63492 m .818 .65817 L .82095 .65467 L p .707 .577 .707 r
F P
0 g
s
.82095 .65467 m .82508 .64977 L p .81816 .63492 L .707 .577 .707 r
F P
0 g
s
.818 .65817 m .81826 .62114 L .80189 .62847 L p .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82218 .64112 L .80959 .63308 L p .707 .577 .707 r
F P
0 g
s
.83278 .55775 m .82322 .61141 L .82221 .61044 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .82245 .6041 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80959 .63308 m .80978 .60633 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80978 .60633 m .80985 .59605 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80189 .62847 m .80179 .64183 L p .818 .65817 L .707 .577 .707 r
F P
0 g
s
.80163 .6655 m .80189 .62847 L .77784 .63402 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .80959 .63308 L .78854 .62642 L p .707 .577 .707 r
F P
0 g
s
.78854 .62642 m .7888 .5894 L .80985 .59605 L p .707 .577 .707 r
F P
0 g
s
.82052 .54601 m .81097 .59968 L .8091 .59866 L p .707 .577 .707 r
F P
0 g
s
.8091 .59866 m .79033 .58837 L p .80622 .56609 L .707 .577 .707 r
F P
0 g
s
.80622 .56609 m .82052 .54601 L .8091 .59866 L .707 .577 .707 r
F
.82221 .61044 m .81097 .59968 L p .8214 .57963 L F P
0 g
s
.8214 .57963 m .83278 .55775 L .82221 .61044 L .707 .577 .707 r
F
.82572 .62166 m .82322 .61141 L p .82889 .59165 L F P
0 g
s
.82889 .59165 m .83546 .56876 L .82572 .62166 L .707 .577 .707 r
F
.82525 .6261 m .82508 .64977 L .82383 .64605 L p F P
0 g
s
.82383 .64605 m .82218 .64112 L p .82525 .6261 L .707 .577 .707 r
F P
0 g
s
.80179 .64183 m .80163 .6655 L .8078 .66274 L p .707 .577 .707 r
F P
0 g
s
.8078 .66274 m .818 .65817 L p .80179 .64183 L .707 .577 .707 r
F P
0 g
s
.77784 .63402 m .77775 .64618 L p .80163 .6655 L .707 .577 .707 r
F P
0 g
s
.77775 .64618 m .77757 .67105 L .78507 .66932 L p .707 .577 .707 r
F P
0 g
s
.78507 .66932 m .80163 .6655 L p .77775 .64618 L .707 .577 .707 r
F P
0 g
s
.74846 .63724 m .74838 .64752 L p .77757 .67105 L .707 .577 .707 r
F P
0 g
s
.74838 .64752 m .74819 .67427 L .75452 .67357 L p .707 .577 .707 r
F P
0 g
s
.75452 .67357 m .77757 .67105 L p .74838 .64752 L .707 .577 .707 r
F P
0 g
s
.72771 .58313 m .71816 .63679 L .74673 .6405 L p .707 .577 .707 r
F P
0 g
s
.74228 .62163 m .72771 .58313 L .74673 .6405 L .707 .577 .707 r
F
.17443 .81133 m .17929 .82968 L .16309 .83837 L p F P
0 g
s
.29269 .6282 m .28313 .68186 L .25243 .67458 L p .707 .577 .707 r
F P
0 g
s
.25243 .67458 m .26199 .62092 L .29269 .6282 L p .707 .577 .707 r
F P
0 g
s
.22102 .67051 m .23058 .61685 L .26199 .62092 L p .707 .577 .707 r
F P
0 g
s
.23058 .61685 m .22102 .67051 L .19197 .67004 L p .707 .577 .707 r
F P
0 g
s
.33389 .7725 m .33875 .79085 L .31869 .79196 L p .707 .577 .707 r
F P
0 g
s
.31869 .79196 m .31383 .77361 L .33389 .7725 L p .707 .577 .707 r
F P
0 g
s
.68745 .62952 m .69701 .57585 L .67002 .56608 L p .707 .577 .707 r
F P
0 g
s
.69701 .57585 m .68745 .62952 L .71816 .63679 L p .707 .577 .707 r
F P
0 g
s
.16442 .76701 m .16469 .72998 L .18874 .72443 L p .707 .577 .707 r
F P
0 g
s
.26199 .62092 m .25243 .67458 L .22102 .67051 L p .707 .577 .707 r
F P
0 g
s
.61615 .25591 m .59825 .75553 L .55951 .74775 L p .707 .577 .707 r
F P
0 g
s
.55951 .74775 m .57742 .24812 L .61615 .25591 L p .707 .577 .707 r
F P
0 g
s
.18874 .72443 m .18848 .76146 L .16442 .76701 L p .707 .577 .707 r
F P
0 g
s
.30859 .72738 m .30832 .76441 L .28086 .75979 L p .707 .577 .707 r
F P
0 g
s
.28086 .75979 m .28113 .72277 L .30859 .72738 L p .707 .577 .707 r
F P
0 g
s
.67002 .56608 m .66047 .61975 L .68745 .62952 L p .707 .577 .707 r
F P
0 g
s
.71636 .67484 m .71662 .63781 L .68545 .63569 L p .707 .577 .707 r
F P
0 g
s
.71662 .63781 m .71636 .67484 L .74819 .67427 L p .707 .577 .707 r
F P
0 g
s
.74819 .67427 m .74846 .63724 L .71662 .63781 L p .707 .577 .707 r
F P
0 g
s
.42915 .74678 m .44706 .24715 L .48852 .24352 L p .707 .577 .707 r
F P
0 g
s
.44706 .24715 m .42915 .74678 L .39521 .75403 L p .707 .577 .707 r
F P
0 g
s
.77757 .67105 m .77784 .63402 L .74846 .63724 L p .707 .577 .707 r
F P
0 g
s
.17929 .82968 m .17443 .81133 L .19798 .80182 L p .707 .577 .707 r
F P
0 g
s
.18848 .76146 m .18874 .72443 L .21812 .72122 L p .707 .577 .707 r
F P
0 g
s
.68519 .67272 m .68545 .63569 L .65799 .63107 L p .707 .577 .707 r
F P
0 g
s
.68545 .63569 m .68519 .67272 L .71636 .67484 L p .707 .577 .707 r
F P
0 g
s
.19798 .80182 m .20283 .82017 L .17929 .82968 L p .707 .577 .707 r
F P
0 g
s
.31383 .77361 m .31869 .79196 L .29233 .79596 L p .707 .577 .707 r
F P
0 g
s
.29233 .79596 m .28748 .77761 L .31383 .77361 L p .707 .577 .707 r
F P
0 g
s
.57742 .24812 m .55951 .74775 L .51553 .74348 L p .707 .577 .707 r
F P
0 g
s
.51553 .74348 m .53344 .24385 L .57742 .24812 L p .707 .577 .707 r
F P
0 g
s
.28113 .72277 m .28086 .75979 L .24969 .75767 L p .707 .577 .707 r
F P
0 g
s
.24969 .75767 m .24996 .72064 L .28113 .72277 L p .707 .577 .707 r
F P
0 g
s
.72672 .7155 m .72187 .69715 L .6918 .70363 L p .707 .577 .707 r
F P
0 g
s
.72187 .69715 m .72672 .7155 L .75756 .70715 L p .707 .577 .707 r
F P
0 g
s
.75756 .70715 m .75271 .6888 L .72187 .69715 L p .707 .577 .707 r
F P
0 g
s
.75271 .6888 m .75756 .70715 L .78615 .69777 L p .707 .577 .707 r
F P
0 g
s
.78615 .69777 m .7813 .67942 L .75271 .6888 L p .707 .577 .707 r
F P
0 g
s
.21812 .72122 m .21786 .75824 L .18848 .76146 L p .707 .577 .707 r
F P
0 g
s
.65799 .63107 m .65773 .6681 L .68519 .67272 L p .707 .577 .707 r
F P
0 g
s
.6918 .70363 m .69665 .72198 L .72672 .7155 L p .707 .577 .707 r
F P
0 g
s
.47061 .74314 m .48852 .24352 L .53344 .24385 L p .707 .577 .707 r
F P
0 g
s
.48852 .24352 m .47061 .74314 L .42915 .74678 L p .707 .577 .707 r
F P
0 g
s
.21786 .75824 m .21812 .72122 L .24996 .72064 L p .707 .577 .707 r
F P
0 g
s
.24996 .72064 m .24969 .75767 L .21786 .75824 L p .707 .577 .707 r
F P
0 g
s
.53344 .24385 m .51553 .74348 L .47061 .74314 L p .707 .577 .707 r
F P
0 g
s
.69665 .72198 m .6918 .70363 L .66545 .70763 L p .707 .577 .707 r
F P
0 g
s
.20283 .82017 m .19798 .80182 L .22657 .79244 L p .707 .577 .707 r
F P
0 g
s
.66545 .70763 m .6703 .72598 L .69665 .72198 L p .707 .577 .707 r
F P
0 g
s
.7813 .67942 m .78615 .69777 L .8097 .68826 L p .707 .577 .707 r
F P
0 g
s
.8097 .68826 m .80485 .66991 L .7813 .67942 L p .707 .577 .707 r
F P
0 g
s
.22657 .79244 m .23143 .81079 L .20283 .82017 L p .707 .577 .707 r
F P
0 g
s
.28748 .77761 m .29233 .79596 L .26227 .80245 L p .707 .577 .707 r
F P
0 g
s
.26227 .80245 m .25741 .78409 L .28748 .77761 L p .707 .577 .707 r
F P
0 g
s
.23143 .81079 m .22657 .79244 L .25741 .78409 L p .707 .577 .707 r
F P
0 g
s
.25741 .78409 m .26227 .80245 L .23143 .81079 L p .707 .577 .707 r
F P
0 g
s
.80485 .66991 m .8097 .68826 L .82589 .67957 L p .707 .577 .707 r
F P
0 g
s
.82589 .67957 m .82104 .66122 L .80485 .66991 L p .707 .577 .707 r
F P
0 g
s
.65024 .72709 m .64539 .70874 L .63358 .70686 L p .707 .577 .707 r
F P
0 g
s
.63446 .53203 m .6249 .5857 L .62758 .59671 L p .707 .577 .707 r
F P
0 g
s
.63358 .70686 m .63844 .72521 L .65024 .72709 L p .707 .577 .707 r
F P
0 g
s
.82104 .66122 m .82589 .67957 L .83315 .67253 L p .707 .577 .707 r
F P
0 g
s
.83315 .67253 m .8283 .65418 L .82104 .66122 L p .707 .577 .707 r
F P
0 g
s
.62408 .6534 m .62434 .61637 L .62145 .60773 L p .707 .577 .707 r
F P
0 g
s
.82322 .61141 m .83278 .55775 L .83546 .56876 L p .707 .577 .707 r
F P
0 g
s
.6249 .5857 m .63446 .53203 L .64162 .52282 L p .707 .577 .707 r
F P
0 g
s
.62145 .60773 m .62119 .64475 L .62408 .6534 L p .707 .577 .707 r
F P
0 g
s
.63844 .72521 m .63358 .70686 L .6312 .70217 L p .707 .577 .707 r
F P
0 g
s
.64162 .52282 m .63206 .57648 L .6249 .5857 L p .707 .577 .707 r
F P
0 g
s
.6312 .70217 m .63605 .72052 L .63844 .72521 L p .707 .577 .707 r
F P
0 g
s
.8283 .65418 m .83315 .67253 L .83076 .66785 L p .707 .577 .707 r
F P
0 g
s
.83076 .66785 m .82591 .64949 L .8283 .65418 L p .707 .577 .707 r
F P
0 g
s
.62119 .64475 m .62145 .60773 L .62853 .59933 L p .707 .577 .707 r
F P
0 g
s
.81097 .59968 m .82052 .54601 L .83278 .55775 L p .707 .577 .707 r
F P
0 g
s
.63206 .57648 m .64162 .52282 L .65791 .5163 L p .707 .577 .707 r
F P
0 g
s
.62853 .59933 m .62827 .63635 L .62119 .64475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.37515 .64801 m .3847 .59435 L .354 .58707 L p .707 .577 .707 r
F P
0 g
s
.3847 .59435 m .37515 .64801 L .40656 .65208 L p .707 .577 .707 r
F P
0 g
s
.40656 .65208 m .41612 .59842 L .3847 .59435 L p .707 .577 .707 r
F P
0 g
s
.65791 .5163 m .64835 .56996 L .63206 .57648 L p .707 .577 .707 r
F P
0 g
s
.63605 .72052 m .6312 .70217 L .63845 .69514 L p .707 .577 .707 r
F P
0 g
s
.63845 .69514 m .64331 .71349 L .63605 .72052 L p .707 .577 .707 r
F P
0 g
s
.41612 .59842 m .40656 .65208 L .4356 .65255 L p .707 .577 .707 r
F P
0 g
s
.4356 .65255 m .44516 .59889 L .41612 .59842 L p .707 .577 .707 r
F P
0 g
s
.34444 .64073 m .354 .58707 L .32701 .5773 L p .707 .577 .707 r
F P
0 g
s
.354 .58707 m .34444 .64073 L .37515 .64801 L p .707 .577 .707 r
F P
0 g
s
.79033 .58837 m .79989 .53471 L .82052 .54601 L p .707 .577 .707 r
F P
0 g
s
.82591 .64949 m .83076 .66785 L .81896 .66597 L p .707 .577 .707 r
F P
0 g
s
.81896 .66597 m .81411 .64761 L .82591 .64949 L p .707 .577 .707 r
F P
0 g
s
.64835 .56996 m .65791 .5163 L .68175 .51312 L p .707 .577 .707 r
F P
0 g
s
.62827 .63635 m .62853 .59933 L .6449 .59199 L p .707 .577 .707 r
F P
0 g
s
.44516 .59889 m .4356 .65255 L .45944 .64937 L p .707 .577 .707 r
F P
0 g
s
.45944 .64937 m .469 .59571 L .44516 .59889 L p .707 .577 .707 r
F P
0 g
s
.31746 .63096 m .32701 .5773 L .30638 .566 L p .707 .577 .707 r
F P
0 g
s
.32701 .5773 m .31746 .63096 L .34444 .64073 L p .707 .577 .707 r
F P
0 g
s
.6449 .59199 m .64464 .62902 L .62827 .63635 L p .707 .577 .707 r
F P
0 g
s
.68175 .51312 m .67219 .56679 L .64835 .56996 L p .707 .577 .707 r
F P
0 g
s
.79989 .53471 m .79033 .58837 L .76335 .57861 L p .707 .577 .707 r
F P
0 g
s
.76335 .57861 m .77291 .52494 L .79989 .53471 L p .707 .577 .707 r
F P
0 g
s
.37335 .72079 m .37361 .68376 L .34244 .68164 L p .707 .577 .707 r
F P
0 g
s
.37361 .68376 m .37335 .72079 L .40518 .72021 L p .707 .577 .707 r
F P
0 g
s
.40518 .72021 m .40545 .68319 L .37361 .68376 L p .707 .577 .707 r
F P
0 g
s
.67219 .56679 m .68175 .51312 L .71079 .51359 L p .707 .577 .707 r
F P
0 g
s
.64331 .71349 m .63845 .69514 L .65465 .68644 L p .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .43829 .71227 L .42714 .71593 L p .707 .577 .707 r
F P
0 g
s
.42714 .71593 m .4097 .72165 L p .42306 .72523 L .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .42714 .71593 L .42306 .72523 L .707 .577 .707 r
F
.43829 .71227 m .44314 .73062 L .46669 .72111 L p F P
0 g
s
.46669 .72111 m .46184 .70276 L .45335 .70619 L p .707 .577 .707 r
F P
0 g
s
.45335 .70619 m .43829 .71227 L p .44986 .71587 L .707 .577 .707 r
F P
0 g
s
.46669 .72111 m .45335 .70619 L .44986 .71587 L .707 .577 .707 r
F
.46184 .70276 m .46669 .72111 L .48288 .71242 L p F P
0 g
s
.48288 .71242 m .47803 .69407 L .47274 .6969 L p .707 .577 .707 r
F P
0 g
s
.47274 .6969 m .46184 .70276 L p .471 .70696 L .707 .577 .707 r
F P
0 g
s
.48288 .71242 m .47274 .6969 L .471 .70696 L .707 .577 .707 r
F
.47803 .69407 m .48288 .71242 L .49014 .70538 L p F P
0 g
s
.49014 .70538 m .48529 .68703 L .4831 .68915 L p .707 .577 .707 r
F P
0 g
s
.4831 .68915 m .47803 .69407 L p .48377 .69943 L .707 .577 .707 r
F P
0 g
s
.49014 .70538 m .4831 .68915 L .48377 .69943 L .707 .577 .707 r
F
.47499 .70412 m .48207 .69572 L p .47679 .67357 L F P
0 g
s
.48207 .69572 m .48233 .65869 L .47525 .66709 L p .707 .577 .707 r
F P
0 g
s
.48207 .69572 m .47917 .68707 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48233 .65869 m .48221 .67541 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48221 .67541 m .48207 .69572 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.47525 .66709 m .47513 .68312 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.47513 .68312 m .47499 .70412 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .47499 .70412 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45888 .67442 m .45876 .69114 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45876 .69114 m .45862 .71145 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .45862 .71145 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43483 .67997 m .43469 .69867 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43469 .69867 m .43456 .71699 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.40545 .68319 m .40518 .72021 L .43456 .71699 L p .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .43483 .67997 L .40545 .68319 L p .707 .577 .707 r
F P
0 g
s
.65465 .68644 m .6595 .70479 L .64331 .71349 L p .707 .577 .707 r
F P
0 g
s
.64464 .62902 m .6449 .59199 L .66895 .58645 L p .707 .577 .707 r
F P
0 g
s
.34218 .71866 m .34244 .68164 L .31498 .67702 L p .707 .577 .707 r
F P
0 g
s
.34244 .68164 m .34218 .71866 L .37335 .72079 L p .707 .577 .707 r
F P
0 g
s
.81411 .64761 m .81896 .66597 L .7989 .66708 L p .707 .577 .707 r
F P
0 g
s
.7989 .66708 m .79405 .64873 L .81411 .64761 L p .707 .577 .707 r
F P
0 g
s
.30638 .566 m .29682 .61966 L .31746 .63096 L p .707 .577 .707 r
F P
0 g
s
.469 .59571 m .45944 .64937 L .47573 .64286 L p .707 .577 .707 r
F P
0 g
s
.47573 .64286 m .48529 .58919 L .469 .59571 L p .707 .577 .707 r
F P
0 g
s
.38371 .74834 m .37886 .72999 L .34879 .73648 L p .707 .577 .707 r
F P
0 g
s
.37886 .72999 m .38371 .74834 L .41455 .74 L p .707 .577 .707 r
F P
0 g
s
.41455 .74 m .4097 .72165 L .37886 .72999 L p .707 .577 .707 r
F P
0 g
s
.29682 .61966 m .30638 .566 L .29413 .55426 L p .707 .577 .707 r
F P
0 g
s
.4097 .72165 m .41455 .74 L .44314 .73062 L p .707 .577 .707 r
F P
0 g
s
.77291 .52494 m .76335 .57861 L .73265 .57133 L p .707 .577 .707 r
F P
0 g
s
.73265 .57133 m .7422 .51766 L .77291 .52494 L p .707 .577 .707 r
F P
0 g
s
.70123 .56726 m .71079 .51359 L .7422 .51766 L p .707 .577 .707 r
F P
0 g
s
.71079 .51359 m .70123 .56726 L .67219 .56679 L p .707 .577 .707 r
F P
0 g
s
.34879 .73648 m .35364 .75483 L .38371 .74834 L p .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .45888 .67442 L .43483 .67997 L p .707 .577 .707 r
F P
0 g
s
.66895 .58645 m .66869 .62347 L .64464 .62902 L p .707 .577 .707 r
F P
0 g
s
.31498 .67702 m .31472 .71405 L .34218 .71866 L p .707 .577 .707 r
F P
0 g
s
.7422 .51766 m .73265 .57133 L .70123 .56726 L p .707 .577 .707 r
F P
0 g
s
.7888 .5894 m .78854 .62642 L .76108 .62181 L p .707 .577 .707 r
F P
0 g
s
.76108 .62181 m .76134 .58478 L .7888 .5894 L p .707 .577 .707 r
F P
0 g
s
.35364 .75483 m .34879 .73648 L .32244 .74047 L p .707 .577 .707 r
F P
0 g
s
.31472 .71405 m .31498 .67702 L .29393 .67036 L p .707 .577 .707 r
F P
0 g
s
.32244 .74047 m .32729 .75883 L .35364 .75483 L p .707 .577 .707 r
F P
0 g
s
.66869 .62347 m .66895 .58645 L .69834 .58323 L p .707 .577 .707 r
F P
0 g
s
.6595 .70479 m .65465 .68644 L .67819 .67694 L p .707 .577 .707 r
F P
0 g
s
.29413 .55426 m .28457 .60793 L .29682 .61966 L p .707 .577 .707 r
F P
0 g
s
.67819 .67694 m .68305 .69529 L .6595 .70479 L p .707 .577 .707 r
F P
0 g
s
.29393 .67036 m .29366 .70739 L .31472 .71405 L p .707 .577 .707 r
F P
0 g
s
.79405 .64873 m .7989 .66708 L .77255 .67107 L p .707 .577 .707 r
F P
0 g
s
.77255 .67107 m .76769 .65272 L .79405 .64873 L p .707 .577 .707 r
F P
0 g
s
.76134 .58478 m .76108 .62181 L .72991 .61968 L p .707 .577 .707 r
F P
0 g
s
.72991 .61968 m .73017 .58265 L .76134 .58478 L p .707 .577 .707 r
F P
0 g
s
.47499 .70412 m .47525 .66709 L .45888 .67442 L p .707 .577 .707 r
F P
0 g
s
.48529 .58919 m .47573 .64286 L .48289 .63364 L p .707 .577 .707 r
F P
0 g
s
.48289 .63364 m .49245 .57998 L .48529 .58919 L p .707 .577 .707 r
F P
0 g
s
.69834 .58323 m .69807 .62026 L .66869 .62347 L p .707 .577 .707 r
F P
0 g
s
.32729 .75883 m .32244 .74047 L .30238 .74159 L p .707 .577 .707 r
F P
0 g
s
.69807 .62026 m .69834 .58323 L .73017 .58265 L p .707 .577 .707 r
F P
0 g
s
.28457 .60793 m .29413 .55426 L .29145 .54325 L p .707 .577 .707 r
F P
0 g
s
.30238 .74159 m .30723 .75994 L .32729 .75883 L p .707 .577 .707 r
F P
0 g
s
.73017 .58265 m .72991 .61968 L .69807 .62026 L p .707 .577 .707 r
F P
0 g
s
.29366 .70739 m .29393 .67036 L .28133 .66232 L p .707 .577 .707 r
F P
0 g
s
.68305 .69529 m .67819 .67694 L .70679 .66755 L p .707 .577 .707 r
F P
0 g
s
.70679 .66755 m .71164 .6859 L .68305 .69529 L p .707 .577 .707 r
F P
0 g
s
.76769 .65272 m .77255 .67107 L .74248 .67756 L p .707 .577 .707 r
F P
0 g
s
.74248 .67756 m .73762 .65921 L .76769 .65272 L p .707 .577 .707 r
F P
0 g
s
.28133 .66232 m .28107 .69935 L .29366 .70739 L p .707 .577 .707 r
F P
0 g
s
.29145 .54325 m .28189 .59691 L .28457 .60793 L p .707 .577 .707 r
F P
0 g
s
.71164 .6859 m .70679 .66755 L .73762 .65921 L p .707 .577 .707 r
F P
0 g
s
.73762 .65921 m .74248 .67756 L .71164 .6859 L p .707 .577 .707 r
F P
0 g
s
.30723 .75994 m .30238 .74159 L .29057 .73971 L p .707 .577 .707 r
F P
0 g
s
.29057 .73971 m .29543 .75806 L .30723 .75994 L p .707 .577 .707 r
F P
0 g
s
.49245 .57998 m .48289 .63364 L .48021 .62263 L p .707 .577 .707 r
F P
0 g
s
.48021 .62263 m .48977 .56896 L .49245 .57998 L p .707 .577 .707 r
F P
0 g
s
.28189 .59691 m .29145 .54325 L .2986 .53403 L p .707 .577 .707 r
F P
0 g
s
.28107 .69935 m .28133 .66232 L .27844 .65367 L p .707 .577 .707 r
F P
0 g
s
.27844 .65367 m .27817 .6907 L .28107 .69935 L p .707 .577 .707 r
F P
0 g
s
.2986 .53403 m .28905 .5877 L .28189 .59691 L p .707 .577 .707 r
F P
0 g
s
.29543 .75806 m .29057 .73971 L .28819 .73502 L p .707 .577 .707 r
F P
0 g
s
.47944 .65004 m .47917 .68707 L .46658 .67903 L p .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4711 .68046 L .4783 .68161 L p .707 .577 .707 r
F P
0 g
s
.47917 .68707 m .4793 .66875 L p .48233 .65869 L .707 .577 .707 r
F P
0 g
s
.4783 .68161 m .4829 .68234 L p .47718 .69591 L .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4783 .68161 L .47718 .69591 L .707 .577 .707 r
F
.4793 .66875 m .47944 .65004 L .48052 .65327 L p F P
0 g
s
.48052 .65327 m .48233 .65869 L p .4793 .66875 L .707 .577 .707 r
F P
0 g
s
.28819 .73502 m .29304 .75337 L .29543 .75806 L p .707 .577 .707 r
F P
0 g
s
.48977 .56896 m .48021 .62263 L .46796 .6109 L p .707 .577 .707 r
F P
0 g
s
.46796 .6109 m .47751 .55723 L .48977 .56896 L p .707 .577 .707 r
F P
0 g
s
.28905 .5877 m .2986 .53403 L .3149 .52752 L p .707 .577 .707 r
F P
0 g
s
.48529 .68703 m .49014 .70538 L .48775 .70069 L p .707 .577 .707 r
F P
0 g
s
.48775 .70069 m .4829 .68234 L .48529 .68703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27817 .6907 m .27844 .65367 L .28552 .64527 L p .707 .577 .707 r
F P
0 g
s
.28552 .64527 m .28526 .6823 L .27817 .6907 L p .707 .577 .707 r
F P
0 g
s
.3149 .52752 m .30534 .58118 L .28905 .5877 L p .707 .577 .707 r
F P
0 g
s
.46658 .67903 m .46684 .642 L .47944 .65004 L p .707 .577 .707 r
F P
0 g
s
.47751 .55723 m .46796 .6109 L .44732 .59959 L p .707 .577 .707 r
F P
0 g
s
.44732 .59959 m .45688 .54593 L .47751 .55723 L p .707 .577 .707 r
F P
0 g
s
.29304 .75337 m .28819 .73502 L .29544 .72798 L p .707 .577 .707 r
F P
0 g
s
.30534 .58118 m .3149 .52752 L .33874 .52434 L p .707 .577 .707 r
F P
0 g
s
.29544 .72798 m .3003 .74634 L .29304 .75337 L p .707 .577 .707 r
F P
0 g
s
.4829 .68234 m .48775 .70069 L .47595 .69881 L p .707 .577 .707 r
F P
0 g
s
.28526 .6823 m .28552 .64527 L .30189 .63794 L p .707 .577 .707 r
F P
0 g
s
.33874 .52434 m .32918 .578 L .30534 .58118 L p .707 .577 .707 r
F P
0 g
s
.45688 .54593 m .44732 .59959 L .42034 .58982 L p .707 .577 .707 r
F P
0 g
s
.42034 .58982 m .4299 .53616 L .45688 .54593 L p .707 .577 .707 r
F P
0 g
s
.30189 .63794 m .30163 .67497 L .28526 .6823 L p .707 .577 .707 r
F P
0 g
s
.32918 .578 m .33874 .52434 L .36778 .52481 L p .707 .577 .707 r
F P
0 g
s
.46684 .642 m .46658 .67903 L .44553 .67237 L p .707 .577 .707 r
F P
0 g
s
.44553 .67237 m .44579 .63534 L .46684 .642 L p .707 .577 .707 r
F P
0 g
s
.3003 .74634 m .29544 .72798 L .31164 .71929 L p .707 .577 .707 r
F P
0 g
s
.31164 .71929 m .31649 .73764 L .3003 .74634 L p .707 .577 .707 r
F P
0 g
s
.4299 .53616 m .42034 .58982 L .38963 .58255 L p .707 .577 .707 r
F P
0 g
s
.38963 .58255 m .39919 .52888 L .4299 .53616 L p .707 .577 .707 r
F P
0 g
s
.35822 .57847 m .36778 .52481 L .39919 .52888 L p .707 .577 .707 r
F P
0 g
s
.36778 .52481 m .35822 .57847 L .32918 .578 L p .707 .577 .707 r
F P
0 g
s
.4711 .68046 m .47595 .69881 L .45589 .69993 L p .707 .577 .707 r
F P
0 g
s
.45589 .69993 m .45104 .68157 L .4711 .68046 L p .707 .577 .707 r
F P
0 g
s
.30163 .67497 m .30189 .63794 L .32594 .6324 L p .707 .577 .707 r
F P
0 g
s
.39919 .52888 m .38963 .58255 L .35822 .57847 L p .707 .577 .707 r
F P
0 g
s
.32594 .6324 m .32568 .66942 L .30163 .67497 L p .707 .577 .707 r
F P
0 g
s
.44579 .63534 m .44553 .67237 L .41807 .66775 L p .707 .577 .707 r
F P
0 g
s
.41807 .66775 m .41833 .63073 L .44579 .63534 L p .707 .577 .707 r
F P
0 g
s
.31649 .73764 m .31164 .71929 L .33518 .70978 L p .707 .577 .707 r
F P
0 g
s
.32568 .66942 m .32594 .6324 L .35532 .62918 L p .707 .577 .707 r
F P
0 g
s
.33518 .70978 m .34004 .72813 L .31649 .73764 L p .707 .577 .707 r
F P
0 g
s
.45104 .68157 m .45589 .69993 L .42954 .70392 L p .707 .577 .707 r
F P
0 g
s
.42954 .70392 m .42468 .68557 L .45104 .68157 L p .707 .577 .707 r
F P
0 g
s
.41833 .63073 m .41807 .66775 L .3869 .66563 L p .707 .577 .707 r
F P
0 g
s
.3869 .66563 m .38716 .6286 L .41833 .63073 L p .707 .577 .707 r
F P
0 g
s
.35532 .62918 m .35506 .6662 L .32568 .66942 L p .707 .577 .707 r
F P
0 g
s
.35506 .6662 m .35532 .62918 L .38716 .6286 L p .707 .577 .707 r
F P
0 g
s
.38716 .6286 m .3869 .66563 L .35506 .6662 L p .707 .577 .707 r
F P
0 g
s
.34004 .72813 m .33518 .70978 L .36377 .7004 L p .707 .577 .707 r
F P
0 g
s
.36377 .7004 m .36863 .71875 L .34004 .72813 L p .707 .577 .707 r
F P
0 g
s
.42468 .68557 m .42954 .70392 L .39947 .71041 L p .707 .577 .707 r
F P
0 g
s
.39947 .71041 m .39461 .69206 L .42468 .68557 L p .707 .577 .707 r
F P
0 g
s
.36863 .71875 m .36377 .7004 L .39461 .69206 L p .707 .577 .707 r
F P
0 g
s
.39461 .69206 m .39947 .71041 L .36863 .71875 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
QGoo6@00Ogoo001mOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001fOol007Qoo`D0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H0071oo`00M7oo1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000K7oo001b
Ool200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH01000FUH00000JWoo001`Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00Igoo001^Ool20005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH2001UOol006eoo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001oogoo069oo`00KGoo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF0P00HWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00Oomoo`1OOol0
06aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00YJEP03001oogoo05ioo`00K7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<007ooOol0GWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006ao
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF
0P00Ggoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF0P00Ggoo001/Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH2001OOol006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00]JEP8005mo
o`00K7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]o
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001oogoo05eoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005mo
o`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Ggoo001[Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001OOol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0005moo`00Jgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0Ggoo
001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001POol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001P
Ool006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00H7oo001Z
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001POol006Yoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00
JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80065oo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000=oo`L005Moo`00JGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1@000UYF00<005YFFUH00UYF2000Cgoo001YOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00@005YFFUIJEPL004Qo
o`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@004Aoo`00GGoo40001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000@7oo001G
Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000?Woo001DOol30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF0`00>goo001C
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000i
Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH3000gOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000eOol0059oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8003=oo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Woo001BOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000aOol0055oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP07001JEUYFFUIooeYF0000
0eYF00<007ooOol0;Woo001AOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8002moo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002moo`00DGoo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF0P000UYF1P000UYF00<005YF00000`0027oo1P001UYF00<005YFFUH0
1UYF00@005YFFUIoo`=JEP06001JEUYF001JEP00;goo001AOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH30000
0eYF001JEP05FUH00`00FUIJEP03FUH4000:Ool40002FUH00`00FUIJEP06FUH00`00FUIoo`03FUH0
1`00FUIJEUYF001JEP0002moo`00DGoo0P000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH00003000:Ool4
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo001AOol00eYF001JEP02FUH40002FUH00`00
FUH000030006Ool00`00FUH000060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF
00<005YFFUH00eYF4@001Woo0P0015YF00<005YFFUH015YF00H005YFFUIJEP00FUH`Ool0051oo`04
001JEP00FUH30005FUH00`00FUIJEP03FUH40002Ool01000FUIJEP001EYF10000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF009JEP06001JEP00001JEP001UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2`0000=J
EP00FUH01EYF00H005YFFUH005YF000`Ool0051oo`04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF
FUH005YF0002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@001UYF00H005YFFUH005YF000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF009JEP<000IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH00009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00L005YFFUIJEP00
FUH0000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPL000QJ
EP<00003FUH005YF00EJEP03001JEUYF008000QJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFOol0<7oo001@Ool00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0005FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFOol0<7oo001@Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00@0
05YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF000aOol0051oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUH00000FUH0035oo`00DGoo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP06001JEUYF001JEP00<Goo001BOol00`00FUH00006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH0035oo`00=Woo40003Goo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF001JEP00FUH00008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000b
Ool0035oo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000Moo`03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP800003FUH00000039oo`00;goo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF
000015YF00@005YFFUIJEPT000QJEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH00`00FUIJEP02000bOol002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00EJEQ40009JEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009J
EP03001JEP0000=JEPL0009oo`<00003FUH005YF00MJEP03001JEUYF00AJEP04OomJEUYF0007FUH4
0004FUH00`00FUIJEP02000bOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEP000002Ool80004FUH00`00FUIJEP06FUH01000FUIJEUYF
20000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH01000FUH005YF0P000eYF1P000goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00001@0000AJEP00FUIJEP80039oo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP04001JEP000007FUH01000FUIJ
EUYF2`000UYF00<005YFFUH01EYF00=oo`00FUH00UYF1P0015YF00@005YF0000009JEP80039oo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YF00000`000eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF
00@005YFFUIJEP@0039oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00<Woo000[Ool20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000bOol002Yoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEPh0039oo`00:Woo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH60003FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP00035oo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF000aOol002Yoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
0080009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000`Ool002Yoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP@0
00MJEP03001JEUYF00IJEP03001JEUYF009JEPd0031oo`00:Woo0P000eYF00@005YFFUIJEQ0000AJ
EP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH80002FUH20002Ool01000FUIJEP001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH000000080009JEP03001JEUYF
00800003FUH005YF00QJEP03001JEUYF00EJEPP0009oo`8000=JEP04001JEUYF000`Ool002Yoo`03
FUH005YF009JEP@0009JEP04001JEP00000:Ool70005FUH00`00FUH00003FUH50005FUH01000FUIJ
EUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH5
0004FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool30005FUH00`00FUH0000`Ool002Uoo`04001J
EP00FUH30005FUH01000FUIJEUYF0`003Woo100000AJEP00FUH0009JEP04001JEUYFFUH50002FUH0
1000FUIJEUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00H00003FUH005YF
009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00IJEP8000MJEP03001JEUYF00IJEP@000Yoo`8000=JEP03001JEUYF009JEP80035oo`00:Goo00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP@000ioo`800004FUH000000005FUH01000
FUIJEUYF2@0000Eoo`00FUIJEP0000AJEP<000IJEPl00003FUH0000000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<000QJEP03001JEUYF00=JEP<0
00Yoo`@000EJEP03001JEUYF009JEP03001oogoo031oo`00:Goo0P0015YF00<005YFFUH00UYF00<0
05YFFUH01UYF00<005YFFUH010002goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
009JEQL000=JEP03001JEUYF009JEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEP00008000Uoo`@0
009JEP03001JEUYF00EJEP04001JEP00000cOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH900000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
0`0027oo10001UYF00<005YFFUH015YF0`00=Goo000YOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP06FUH00`00FUIJEP040009Ool200000eYF001JEP08FUH01000FUIJEUYF0P00>7oo000YOol00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH4000:Ool30004FUH00`00FUIJEP06
FUH01000FUH00000>Woo000YOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF00IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001oo`05
Ool40007FUH00`00FUIJEP05FUH3000lOol002Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00MJEP04001JEUYFFUH70002FUH50006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020002
FUH00`00FUH00002Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000oOol002Yoo`04001J
EUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030005FUH0
0`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH01000FUIJEUYF0`000UYF
00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=J
EP<0009JEP03001JEP0000D000IJEP03001JEUYF00MJEP03001JEP000080045oo`00:goo0`001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00UYF10001EYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00@005YF0000
00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40014Ool002eoo`03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP<00004FUH005YFFUH200000eYF
001JEP07FUH00`00FUIJEP04FUH50007FUH01000FUIJEUYF1@001EYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP0000001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01000B7oo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH70019Ool0
031oo`800003FUH005YF00IJEP03001JEUYF00EJEPP0009JEP03001JEUYF00EJEP03001JEUYF0080
00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@000=o
o`D004Qoo`00<Woo0`001EYF2@0015YF00@005YFFUIJEPP0009JEP@000MJEP03001JEUYF009JEP80
009JEP03001JEUYF00AJEP03001JEP0000<000MJEP03001JEUYF00=JEP<000aJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH60007Ool50018Ool0039oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP05FUH00`00FUH000020002Ool2FUH00`00FUIJEP02FUH40002FUH00`00FUIJ
EP06FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0?000<Ool50018Ool002ioo`@000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP03FUH30005Ool2FUH50006FUH0
0`00FUIJEP05FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEUYF10003Goo0`00BGoo000/Ool30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUH000050005
Ool400000eYF001JEP08FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH3001IOol0
02Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP03001JEUYF009JEP80009JEP800003Ool0000000@000IJEP03001JEUYF00IJEP03
001JEP00008000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEP0005Uoo`00:Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YF
FUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP`005Uoo`00
:Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001J
EUYF00AJEQT000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP04001J
EUYF001IOol002Qoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60006
FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUH00004FUH01@00FUIJEUYF0000F7oo000XOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00@0
05YFFUH005Qoo`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP04001JEUYFFUH60002FUH0
0`00FUIJEP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUH000030006FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00@005YFFUH005Qo
o`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00@005YFFUIJEP80
009JEP04001JEUYFFUH600000eYF001oo`02Ool01000FUIJEP000eYF0P001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YF
FUH00eYF2`000UYF00<007ooOol0EGoo000XOol00`00FUH00003FUH00`00FUIJEP03FUH6000AOol8
0002FUH60002FUH01000FUIJEUYF0P000goo00D005YFFUH005YF00<000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00AJ
EP<0009oo`8000=JEP@005Moo`00:7oo00<005YF00000eYF00<005YF00000`007goo1P0015YF00@0
05YFFUIJEP8000=oo`03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000005FUH00`00Oomo
o`030005FUH00`00FUH0001GOol002Qoo`03001JEP0000=JEP800004FUH00000000ROol600000eYF
001JEP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF0`000eYF
00<005YFFUH00UYF0P00F7oo000XOol01000FUH005YF0P0015YF00<005YF00000`0047oo0`001Woo
1@000UYF200000=JEP0000000goo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0Egoo000XOol00`00FUH000020005FUH00`00FUIJ
EP03FUHI0003FUH400000eYF001JEP03FUH00`00FUIJEP020003Ool00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000FUH00000FWoo000XOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00000010001EYF
00<005YFFUH00eYF00@005YFFUH000=oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000QJEP03001JEUYF00=JEP04001J
EP000005FUH3001LOol002Qoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000Aoo`03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP8000QJEP03001JEUYF00=JEP04001JEP000003FUH2001OOol002Qoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP000goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YFFUH00eYF00D0
05YFFUH005YF0080065oo`00:7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001oo`03Ool00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02001SOol002Qoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF
1`000UYF1@0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo000YOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH0
1000FUIJEUYF0`000UYF00<007ooOol017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00IWoo000[Ool30004FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUH000000eYF
0P002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P00IWoo000^Ool3000015YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF1@001eYF00<005YFFUH00eYF0`001EYF00<007ooOol02Woo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0IGoo000a
Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH00`00FUH000030003
FUH00`00FUIJEP02000?Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00
FUIJEP07FUH01000FUIJEUYF0P00J7oo000aOol20005FUH00`00FUIJEP05FUH40004FUH>0007FUH3
000DOol30009FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP07FUH01000FUH00000JWoo
000`Ool20007FUH00`00FUIJEP02FUH:0003Ool40007FUH00`00FUIJEP03FUH2000IOol40005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP04FUH5001/Ool002ioo`800003FUH005YF00IJ
EP03001JEP00008000Uoo`@0009JEP03001JEUYF00IJEP03001JEP0000<001moo`@00003FUH005YF
00]JEP03001JEUYF01EJEP03001JEP0000@0075oo`00;Goo00<005YFFUH00UYF00<005YFFUH00eYF
0`0027oo10001UYF00<005YFFUH01EYF0`009goo20001UYF00<005YFFUH045YF1`00MWoo000[Ool3
0004FUH00`00FUH000030007Ool400000eYF001JEP08FUH00`00FUIJEP02FUH2000bOolI001mOol0
02Yoo`04001JEUYF0004FUH20005Ool60006FUH00`00FUIJEP06FUH00`00FUH00002003:Ool002Yo
o`05001JEUYFFUH00002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3003=Ool002]oo`03
001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@00=1oo`00:goo00@0
05YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD00=Aoo`00;7oo0P0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01000fGoo000/Ool01000FUIJEP001UYF00@005YFFUIJEPH00=eo
o`00;7oo0P000UYF00@005YFFUIJEPH00>=oo`00;Woo1P00jGoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58095 .72883 m .59051 .67517 L .55981 .66789 L p .707 .577 .707 r
F P
0 g
s
.60952 .73254 m .61236 .7329 L p .60508 .71366 L .707 .577 .707 r
F P
0 g
s
.61236 .7329 m .62192 .67924 L .59051 .67517 L p .707 .577 .707 r
F P
0 g
s
.62192 .67924 m .62191 .67931 L p .64141 .73337 L .707 .577 .707 r
F P
0 g
s
.62191 .67931 m .61236 .7329 L .639 .73334 L p .707 .577 .707 r
F P
0 g
s
.639 .73334 m .64141 .73337 L p .62191 .67931 L .707 .577 .707 r
F P
0 g
s
.64141 .73337 m .65097 .67971 L .62192 .67924 L p .707 .577 .707 r
F P
0 g
s
.65097 .67971 m .65023 .68387 L p .66524 .7302 L .707 .577 .707 r
F P
0 g
s
.65023 .68387 m .64141 .73337 L .6636 .73042 L p .707 .577 .707 r
F P
0 g
s
.6636 .73042 m .66524 .7302 L p .65023 .68387 L .707 .577 .707 r
F P
0 g
s
.66524 .7302 m .6748 .67653 L .65097 .67971 L p .707 .577 .707 r
F P
0 g
s
.6748 .67653 m .67427 .67953 L p .68154 .72368 L .707 .577 .707 r
F P
0 g
s
.67427 .67953 m .66524 .7302 L .68055 .72408 L p .707 .577 .707 r
F P
0 g
s
.68055 .72408 m .68154 .72368 L p .67427 .67953 L .707 .577 .707 r
F P
0 g
s
.68154 .72368 m .6911 .67002 L .6748 .67653 L p .707 .577 .707 r
F P
0 g
s
.6911 .67002 m .68154 .72368 L .68826 .71502 L p .707 .577 .707 r
F P
0 g
s
.68826 .71502 m .6887 .71446 L p .68996 .69106 L .707 .577 .707 r
F P
0 g
s
.68996 .69106 m .6911 .67002 L .68826 .71502 L .707 .577 .707 r
F
.68105 .71318 m .68096 .72696 L p .68787 .74181 L F P
0 g
s
.68814 .70478 m .68105 .71318 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68787 .74181 m .68804 .71814 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.68804 .71814 m .68814 .70478 L p .68626 .73502 L .707 .577 .707 r
F P
0 g
s
.6887 .71446 m .69826 .6608 L .6911 .67002 L p .707 .577 .707 r
F P
0 g
s
.69826 .6608 m .6887 .71446 L .68851 .7137 L p .707 .577 .707 r
F P
0 g
s
.68814 .70478 m .68804 .71814 L p .68498 .73316 L .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68814 .70478 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68498 .73316 m .68515 .70829 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68515 .70829 m .68524 .69614 L p .68565 .72712 L .707 .577 .707 r
F P
0 g
s
.68096 .72696 m .68079 .75021 L .68374 .74671 L p .707 .577 .707 r
F P
0 g
s
.68374 .74671 m .68787 .74181 L p .68096 .72696 L .707 .577 .707 r
F P
0 g
s
.68079 .75021 m .68105 .71318 L .66469 .72051 L p .707 .577 .707 r
F P
0 g
s
.68524 .69614 m .68498 .73316 L .67239 .72512 L p .707 .577 .707 r
F P
0 g
s
.69558 .64979 m .68602 .70345 L .685 .70248 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .68524 .69614 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67239 .72512 m .67258 .69837 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.67258 .69837 m .67265 .68809 L p .67452 .72031 L .707 .577 .707 r
F P
0 g
s
.66469 .72051 m .66459 .73387 L p .68079 .75021 L .707 .577 .707 r
F P
0 g
s
.66442 .75754 m .66469 .72051 L .64063 .72606 L p .707 .577 .707 r
F P
0 g
s
.67265 .68809 m .67239 .72512 L .65133 .71846 L p .707 .577 .707 r
F P
0 g
s
.65133 .71846 m .65159 .68143 L .67265 .68809 L p .707 .577 .707 r
F P
0 g
s
.68332 .63805 m .67376 .69172 L .6719 .6907 L p .707 .577 .707 r
F P
0 g
s
.6719 .6907 m .65313 .68041 L p .66901 .65813 L .707 .577 .707 r
F P
0 g
s
.66901 .65813 m .68332 .63805 L .6719 .6907 L .707 .577 .707 r
F
.685 .70248 m .67376 .69172 L p .68419 .67167 L F P
0 g
s
.68419 .67167 m .69558 .64979 L .685 .70248 L .707 .577 .707 r
F
.68851 .7137 m .68602 .70345 L p .69169 .68369 L F P
0 g
s
.69169 .68369 m .69826 .6608 L .68851 .7137 L .707 .577 .707 r
F
.68804 .71814 m .68787 .74181 L .68663 .73809 L p F P
0 g
s
.68663 .73809 m .68498 .73316 L p .68804 .71814 L .707 .577 .707 r
F P
0 g
s
.66459 .73387 m .66442 .75754 L .67059 .75477 L p .707 .577 .707 r
F P
0 g
s
.67059 .75477 m .68079 .75021 L p .66459 .73387 L .707 .577 .707 r
F P
0 g
s
.64063 .72606 m .64055 .73822 L p .66442 .75754 L .707 .577 .707 r
F P
0 g
s
.64055 .73822 m .64037 .76309 L .64787 .76136 L p .707 .577 .707 r
F P
0 g
s
.64787 .76136 m .66442 .75754 L p .64055 .73822 L .707 .577 .707 r
F P
0 g
s
.61125 .72928 m .61118 .73956 L p .64037 .76309 L .707 .577 .707 r
F P
0 g
s
.61118 .73956 m .61099 .7663 L .61731 .76561 L p .707 .577 .707 r
F P
0 g
s
.61731 .76561 m .64037 .76309 L p .61118 .73956 L .707 .577 .707 r
F P
0 g
s
.59051 .67517 m .58095 .72883 L .60952 .73254 L p .707 .577 .707 r
F P
0 g
s
.60508 .71366 m .59051 .67517 L .60952 .73254 L .707 .577 .707 r
F
.55025 .72155 m .55981 .66789 L .53282 .65812 L p F P
0 g
s
.55981 .66789 m .55025 .72155 L .58095 .72883 L p .707 .577 .707 r
F P
0 g
s
.52326 .71179 m .53282 .65812 L .51219 .64682 L p .707 .577 .707 r
F P
0 g
s
.53282 .65812 m .52326 .71179 L .55025 .72155 L p .707 .577 .707 r
F P
0 g
s
.57915 .76688 m .57942 .72985 L .54824 .72773 L p .707 .577 .707 r
F P
0 g
s
.57942 .72985 m .57915 .76688 L .61099 .7663 L p .707 .577 .707 r
F P
0 g
s
.61099 .7663 m .61125 .72928 L .57942 .72985 L p .707 .577 .707 r
F P
0 g
s
.64037 .76309 m .64063 .72606 L .61125 .72928 L p .707 .577 .707 r
F P
0 g
s
.54798 .76475 m .54824 .72773 L .52079 .72311 L p .707 .577 .707 r
F P
0 g
s
.54824 .72773 m .54798 .76475 L .57915 .76688 L p .707 .577 .707 r
F P
0 g
s
.58952 .80753 m .58466 .78918 L .5546 .79567 L p .707 .577 .707 r
F P
0 g
s
.58466 .78918 m .58952 .80753 L .62036 .79919 L p .707 .577 .707 r
F P
0 g
s
.62036 .79919 m .6155 .78084 L .58466 .78918 L p .707 .577 .707 r
F P
0 g
s
.6155 .78084 m .62036 .79919 L .64895 .78981 L p .707 .577 .707 r
F P
0 g
s
.64895 .78981 m .6441 .77146 L .6155 .78084 L p .707 .577 .707 r
F P
0 g
s
.52079 .72311 m .52052 .76014 L .54798 .76475 L p .707 .577 .707 r
F P
0 g
s
.5546 .79567 m .55945 .81402 L .58952 .80753 L p .707 .577 .707 r
F P
0 g
s
.51219 .64682 m .50263 .70048 L .52326 .71179 L p .707 .577 .707 r
F P
0 g
s
.50263 .70048 m .51219 .64682 L .49993 .63508 L p .707 .577 .707 r
F P
0 g
s
.52052 .76014 m .52079 .72311 L .49973 .71646 L p .707 .577 .707 r
F P
0 g
s
.55945 .81402 m .5546 .79567 L .52824 .79967 L p .707 .577 .707 r
F P
0 g
s
.52824 .79967 m .5331 .81802 L .55945 .81402 L p .707 .577 .707 r
F P
0 g
s
.6441 .77146 m .64895 .78981 L .6725 .7803 L p .707 .577 .707 r
F P
0 g
s
.6725 .7803 m .66764 .76195 L .6441 .77146 L p .707 .577 .707 r
F P
0 g
s
.49973 .71646 m .49947 .75348 L .52052 .76014 L p .707 .577 .707 r
F P
0 g
s
.49993 .63508 m .49038 .68875 L .50263 .70048 L p .707 .577 .707 r
F P
0 g
s
.5331 .81802 m .52824 .79967 L .50818 .80078 L p .707 .577 .707 r
F P
0 g
s
.50818 .80078 m .51304 .81913 L .5331 .81802 L p .707 .577 .707 r
F P
0 g
s
.49947 .75348 m .49973 .71646 L .48714 .70841 L p .707 .577 .707 r
F P
0 g
s
.66764 .76195 m .6725 .7803 L .68869 .77161 L p .707 .577 .707 r
F P
0 g
s
.68869 .77161 m .68383 .75326 L .66764 .76195 L p .707 .577 .707 r
F P
0 g
s
.49038 .68875 m .49993 .63508 L .49725 .62407 L p .707 .577 .707 r
F P
0 g
s
.48714 .70841 m .48688 .74544 L .49947 .75348 L p .707 .577 .707 r
F P
0 g
s
.51304 .81913 m .50818 .80078 L .49638 .7989 L p .707 .577 .707 r
F P
0 g
s
.49725 .62407 m .4877 .67774 L .49038 .68875 L p .707 .577 .707 r
F P
0 g
s
.49638 .7989 m .50124 .81725 L .51304 .81913 L p .707 .577 .707 r
F P
0 g
s
.68383 .75326 m .68869 .77161 L .69595 .76457 L p .707 .577 .707 r
F P
0 g
s
.69595 .76457 m .69109 .74622 L .68383 .75326 L p .707 .577 .707 r
F P
0 g
s
.48688 .74544 m .48714 .70841 L .48424 .69977 L p .707 .577 .707 r
F P
0 g
s
.68602 .70345 m .69558 .64979 L .69826 .6608 L p .707 .577 .707 r
F P
0 g
s
.4877 .67774 m .49725 .62407 L .50441 .61486 L p .707 .577 .707 r
F P
0 g
s
.50124 .81725 m .49638 .7989 L .49399 .79421 L p .707 .577 .707 r
F P
0 g
s
.50441 .61486 m .49485 .66852 L .4877 .67774 L p .707 .577 .707 r
F P
0 g
s
.49399 .79421 m .49885 .81256 L .50124 .81725 L p .707 .577 .707 r
F P
0 g
s
.48424 .69977 m .48398 .73679 L .48688 .74544 L p .707 .577 .707 r
F P
0 g
s
.48398 .73679 m .48424 .69977 L .49133 .69137 L p .707 .577 .707 r
F P
0 g
s
.49485 .66852 m .50441 .61486 L .52071 .60834 L p .707 .577 .707 r
F P
0 g
s
.49133 .69137 m .49106 .72839 L .48398 .73679 L p .707 .577 .707 r
F P
0 g
s
.52071 .60834 m .51115 .662 L .49485 .66852 L p .707 .577 .707 r
F P
0 g
s
.49885 .81256 m .49399 .79421 L .50125 .78718 L p .707 .577 .707 r
F P
0 g
s
.49106 .72839 m .49133 .69137 L .5077 .68403 L p .707 .577 .707 r
F P
0 g
s
.5077 .68403 m .50743 .72106 L .49106 .72839 L p .707 .577 .707 r
F P
0 g
s
.49635 .82389 m .51426 .32427 L .47028 .32 L p .707 .577 .707 r
F P
0 g
s
.50125 .78718 m .5061 .80553 L .49885 .81256 L p .707 .577 .707 r
F P
0 g
s
.51115 .662 m .52071 .60834 L .54454 .60516 L p .707 .577 .707 r
F P
0 g
s
.54454 .60516 m .53498 .65882 L .51115 .662 L p .707 .577 .707 r
F P
0 g
s
.5061 .80553 m .50125 .78718 L .51744 .77848 L p .707 .577 .707 r
F P
0 g
s
.51744 .77848 m .5223 .79683 L .5061 .80553 L p .707 .577 .707 r
F P
0 g
s
.50743 .72106 m .5077 .68403 L .53175 .67849 L p .707 .577 .707 r
F P
0 g
s
.53175 .67849 m .53149 .71551 L .50743 .72106 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53175 .67849 L .53569 .67806 L p .707 .577 .707 r
F P
0 g
s
.53149 .71551 m .53569 .67806 L .53674 .70838 L .707 .577 .707 r
F
.54454 .60516 m .56279 .60546 L p .54202 .64532 L F P
0 g
s
.53498 .65882 m .53736 .64548 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.53736 .64548 m .54454 .60516 L p .54202 .64532 L .707 .577 .707 r
F P
0 g
s
.57744 .60613 m .605 .6097 L p .5792 .64093 L .707 .577 .707 r
F P
0 g
s
.6357 .61698 m .62614 .67064 L .59544 .66337 L p .707 .577 .707 r
F P
0 g
s
.59544 .66337 m .605 .6097 L .6357 .61698 L p .707 .577 .707 r
F P
0 g
s
.605 .6097 m .59544 .66337 L .56923 .65997 L p .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .54769 .64512 L .57028 .66635 L .707 .577 .707 r
F
.56923 .65997 m .56403 .65929 L p .56827 .65416 L F P
0 g
s
.56827 .65416 m .605 .6097 L .56923 .65997 L .707 .577 .707 r
F
.54099 .76897 m .54584 .78732 L .5223 .79683 L p F P
0 g
s
.54584 .78732 m .54099 .76897 L .56138 .76228 L p .707 .577 .707 r
F P
0 g
s
.56138 .76228 m .56958 .75959 L p .56417 .76591 L .707 .577 .707 r
F P
0 g
s
.54584 .78732 m .56138 .76228 L .56417 .76591 L .707 .577 .707 r
F
.5372 .72178 m .54769 .64512 L .53564 .67674 L F
.54428 .74005 m .54769 .64512 L p .53615 .72947 L F P
0 g
s
.56958 .75959 m .57444 .77794 L .54584 .78732 L p .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .54127 .82422 L p .57028 .66635 L .707 .577 .707 r
F P
0 g
s
.56113 .67527 m .56087 .71229 L .53696 .71491 L p .707 .577 .707 r
F P
0 g
s
.53696 .71491 m .53149 .71551 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.53674 .70838 m .56113 .67527 L .53696 .71491 L .707 .577 .707 r
F
.53615 .72947 m .5372 .72178 L .53359 .68213 L F
.5372 .72178 m .53564 .67674 L .53359 .68213 L F
.5223 .79683 m .51744 .77848 L .54099 .76897 L p F P
0 g
s
.54127 .82422 m .54428 .74005 L p .53615 .72947 L .707 .577 .707 r
F P
0 g
s
.57359 .60563 m .57744 .60613 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.56827 .65416 m .57744 .60613 L .5792 .64093 L .707 .577 .707 r
F
.56667 .64445 m .57359 .60563 L p .56827 .65416 L F P
0 g
s
.57435 .64418 m .56667 .64445 L .57028 .66635 L .707 .577 .707 r
F
.62414 .67682 m .62387 .71384 L .5927 .71172 L p F P
0 g
s
.5927 .71172 m .59297 .67469 L .62414 .67682 L p .707 .577 .707 r
F P
0 g
s
.5719 .67619 m .57435 .64418 L .57028 .66635 L .707 .577 .707 r
F
.57436 .64433 m .57435 .64418 L .5719 .67619 L F
.57198 .67507 m .59297 .67469 L p .56993 .70168 L F P
0 g
s
.56663 .7443 m .57028 .66635 L .54127 .82422 L .707 .577 .707 r
F
.59297 .67469 m .5927 .71172 L .56912 .71214 L p F P
0 g
s
.56993 .70168 m .59297 .67469 L .56912 .71214 L .707 .577 .707 r
F
.57748 .71012 m .5719 .67619 L .56663 .7443 L F
.5719 .67619 m .57028 .66635 L .56663 .7443 L F
.56912 .71214 m .56087 .71229 L p .56993 .70168 L F P
0 g
s
.56087 .71229 m .56113 .67527 L .57198 .67507 L p .707 .577 .707 r
F P
0 g
s
.56087 .71229 m .57198 .67507 L .56993 .70168 L .707 .577 .707 r
F
.57748 .71012 m .57436 .64433 L .5719 .67619 L F
.63049 .74476 m .63534 .76311 L .60528 .7696 L p F P
0 g
s
.60528 .7696 m .60042 .75125 L .63049 .74476 L p .707 .577 .707 r
F P
0 g
s
.57444 .77794 m .57034 .76247 L p .60042 .75125 L .707 .577 .707 r
F P
0 g
s
.57034 .76247 m .56958 .75959 L .57103 .7592 L p .707 .577 .707 r
F P
0 g
s
.57103 .7592 m .60042 .75125 L p .57034 .76247 L .707 .577 .707 r
F P
0 g
s
.60042 .75125 m .60528 .7696 L .57444 .77794 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .60903 .57881 L .58504 .75604 L .707 .577 .707 r
F
.60063 .32097 m .58778 .67972 L p .60903 .57881 L F P
0 g
s
.58778 .67972 m .58504 .75604 L p .60903 .57881 L .707 .577 .707 r
F P
0 g
s
.58504 .75604 m .58273 .82059 L .58826 .81941 L p .707 .577 .707 r
F P
0 g
s
.58826 .81941 m .61667 .81334 L p .58504 .75604 L .707 .577 .707 r
F P
0 g
s
.56403 .65929 m .56667 .64445 L p .56827 .65416 L .707 .577 .707 r
F P
0 g
s
.54127 .82422 m .58273 .82059 L p .57748 .71012 L .707 .577 .707 r
F P
0 g
s
.56279 .60546 m .57359 .60563 L p .55073 .63712 L .707 .577 .707 r
F P
0 g
s
.53498 .65882 m .56279 .60546 L .55073 .63712 L .707 .577 .707 r
F
.56403 .65929 m .53498 .65882 L p .54486 .64522 L F P
0 g
s
.57359 .60563 m .56667 .64445 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.56667 .64445 m .56403 .65929 L p .54486 .64522 L .707 .577 .707 r
F P
0 g
s
.60063 .32097 m .55917 .3246 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58273 .82059 m .58907 .64367 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.58907 .64367 m .60063 .32097 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .54769 .64512 L p .57435 .64418 L .707 .577 .707 r
F P
0 g
s
.55917 .3246 m .51426 .32427 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.54769 .64512 m .55917 .3246 L p .53359 .68213 L .707 .577 .707 r
F P
0 g
s
.53569 .67806 m .56113 .67527 L p .53674 .70838 L .707 .577 .707 r
F P
0 g
s
.51426 .32427 m .49635 .82389 L .54075 .82422 L p .707 .577 .707 r
F P
0 g
s
.54075 .82422 m .54127 .82422 L p .53982 .7974 L .707 .577 .707 r
F P
0 g
s
.53982 .7974 m .51426 .32427 L .54075 .82422 L .707 .577 .707 r
F
.45237 .81962 m .47028 .32 L .43154 .31221 L p F P
0 g
s
.47028 .32 m .45237 .81962 L .49635 .82389 L p .707 .577 .707 r
F P
0 g
s
.61667 .81334 m .63458 .31372 L .60063 .32097 L p .707 .577 .707 r
F P
0 g
s
.69109 .74622 m .69595 .76457 L .69356 .75988 L p .707 .577 .707 r
F P
0 g
s
.69356 .75988 m .6887 .74153 L .69109 .74622 L p .707 .577 .707 r
F P
0 g
s
.67376 .69172 m .68332 .63805 L .69558 .64979 L p .707 .577 .707 r
F P
0 g
s
.41363 .81183 m .43154 .31221 L .40184 .30167 L p .707 .577 .707 r
F P
0 g
s
.43154 .31221 m .41363 .81183 L .45237 .81962 L p .707 .577 .707 r
F P
0 g
s
.23794 .74005 m .2475 .68638 L .2168 .67911 L p .707 .577 .707 r
F P
0 g
s
.2475 .68638 m .23794 .74005 L .26935 .74412 L p .707 .577 .707 r
F P
0 g
s
.26935 .74412 m .27891 .69046 L .2475 .68638 L p .707 .577 .707 r
F P
0 g
s
.66269 .62675 m .65313 .68041 L .62614 .67064 L p .707 .577 .707 r
F P
0 g
s
.62614 .67064 m .6357 .61698 L .66269 .62675 L p .707 .577 .707 r
F P
0 g
s
.65159 .68143 m .65133 .71846 L .62387 .71384 L p .707 .577 .707 r
F P
0 g
s
.62387 .71384 m .62414 .67682 L .65159 .68143 L p .707 .577 .707 r
F P
0 g
s
.65684 .74077 m .6617 .75912 L .63534 .76311 L p .707 .577 .707 r
F P
0 g
s
.63534 .76311 m .63049 .74476 L .65684 .74077 L p .707 .577 .707 r
F P
0 g
s
.63458 .31372 m .61667 .81334 L .63978 .80319 L p .707 .577 .707 r
F P
0 g
s
.63978 .80319 m .65768 .30357 L .63458 .31372 L p .707 .577 .707 r
F P
0 g
s
.27891 .69046 m .26935 .74412 L .2984 .74459 L p .707 .577 .707 r
F P
0 g
s
.2984 .74459 m .30796 .69093 L .27891 .69046 L p .707 .577 .707 r
F P
0 g
s
.20724 .73277 m .2168 .67911 L .18981 .66934 L p .707 .577 .707 r
F P
0 g
s
.2168 .67911 m .20724 .73277 L .23794 .74005 L p .707 .577 .707 r
F P
0 g
s
.65313 .68041 m .66269 .62675 L .68332 .63805 L p .707 .577 .707 r
F P
0 g
s
.6887 .74153 m .69356 .75988 L .68176 .758 L p .707 .577 .707 r
F P
0 g
s
.68176 .758 m .6769 .73965 L .6887 .74153 L p .707 .577 .707 r
F P
0 g
s
.38393 .80129 m .40184 .30167 L .38408 .2894 L p .707 .577 .707 r
F P
0 g
s
.40184 .30167 m .38393 .80129 L .41363 .81183 L p .707 .577 .707 r
F P
0 g
s
.30796 .69093 m .2984 .74459 L .32224 .74141 L p .707 .577 .707 r
F P
0 g
s
.32224 .74141 m .33179 .68775 L .30796 .69093 L p .707 .577 .707 r
F P
0 g
s
.18025 .723 m .18981 .66934 L .16918 .65803 L p .707 .577 .707 r
F P
0 g
s
.18981 .66934 m .18025 .723 L .20724 .73277 L p .707 .577 .707 r
F P
0 g
s
.23614 .81283 m .23641 .7758 L .20524 .77368 L p .707 .577 .707 r
F P
0 g
s
.23641 .7758 m .23614 .81283 L .26798 .81225 L p .707 .577 .707 r
F P
0 g
s
.26798 .81225 m .26824 .77523 L .23641 .7758 L p .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .30109 .8043 L .28994 .80796 L p .707 .577 .707 r
F P
0 g
s
.28994 .80796 m .27249 .81369 L p .28586 .81727 L .707 .577 .707 r
F P
0 g
s
.30594 .82266 m .28994 .80796 L .28586 .81727 L .707 .577 .707 r
F
.30109 .8043 m .30594 .82266 L .32949 .81315 L p F P
0 g
s
.32949 .81315 m .32463 .7948 L .31614 .79823 L p .707 .577 .707 r
F P
0 g
s
.31614 .79823 m .30109 .8043 L p .31266 .80791 L .707 .577 .707 r
F P
0 g
s
.32949 .81315 m .31614 .79823 L .31266 .80791 L .707 .577 .707 r
F
.32463 .7948 m .32949 .81315 L .34568 .80445 L p F P
0 g
s
.34568 .80445 m .34083 .7861 L .33554 .78894 L p .707 .577 .707 r
F P
0 g
s
.33554 .78894 m .32463 .7948 L p .3338 .799 L .707 .577 .707 r
F P
0 g
s
.34568 .80445 m .33554 .78894 L .3338 .799 L .707 .577 .707 r
F
.34083 .7861 m .34568 .80445 L .35294 .79742 L p F P
0 g
s
.35294 .79742 m .34808 .77907 L .3459 .78119 L p .707 .577 .707 r
F P
0 g
s
.3459 .78119 m .34083 .7861 L p .34656 .79146 L .707 .577 .707 r
F P
0 g
s
.35294 .79742 m .3459 .78119 L .34656 .79146 L .707 .577 .707 r
F
.33778 .79615 m .34486 .78775 L p .33959 .76561 L F P
0 g
s
.34486 .78775 m .34513 .75073 L .33805 .75913 L p .707 .577 .707 r
F P
0 g
s
.34486 .78775 m .34197 .77911 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34513 .75073 m .34501 .76745 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.34501 .76745 m .34486 .78775 L p .34437 .75755 L .707 .577 .707 r
F P
0 g
s
.33805 .75913 m .33793 .77516 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.33793 .77516 m .33778 .79615 L p .33959 .76561 L .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .33778 .79615 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32168 .76646 m .32156 .78318 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.32156 .78318 m .32141 .80349 L p .32522 .77299 L .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .32141 .80349 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29762 .77201 m .29749 .79071 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.29749 .79071 m .29736 .80903 L p .30273 .77876 L .707 .577 .707 r
F P
0 g
s
.26824 .77523 m .26798 .81225 L .29736 .80903 L p .707 .577 .707 r
F P
0 g
s
.29736 .80903 m .29762 .77201 L .26824 .77523 L p .707 .577 .707 r
F P
0 g
s
.20497 .8107 m .20524 .77368 L .17778 .76906 L p .707 .577 .707 r
F P
0 g
s
.20524 .77368 m .20497 .8107 L .23614 .81283 L p .707 .577 .707 r
F P
0 g
s
.6769 .73965 m .68176 .758 L .6617 .75912 L p .707 .577 .707 r
F P
0 g
s
.6617 .75912 m .65684 .74077 L .6769 .73965 L p .707 .577 .707 r
F P
0 g
s
.16918 .65803 m .15962 .7117 L .18025 .723 L p .707 .577 .707 r
F P
0 g
s
.65768 .30357 m .63978 .80319 L .64978 .79113 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .66769 .29151 L .65768 .30357 L p .707 .577 .707 r
F P
0 g
s
.33179 .68775 m .32224 .74141 L .33853 .7349 L p .707 .577 .707 r
F P
0 g
s
.33853 .7349 m .34809 .68123 L .33179 .68775 L p .707 .577 .707 r
F P
0 g
s
.24651 .84038 m .24166 .82203 L .21159 .82852 L p .707 .577 .707 r
F P
0 g
s
.24166 .82203 m .24651 .84038 L .27735 .83204 L p .707 .577 .707 r
F P
0 g
s
.27735 .83204 m .27249 .81369 L .24166 .82203 L p .707 .577 .707 r
F P
0 g
s
.15962 .7117 m .16918 .65803 L .15692 .6463 L p .707 .577 .707 r
F P
0 g
s
.27249 .81369 m .27735 .83204 L .30594 .82266 L p .707 .577 .707 r
F P
0 g
s
.21159 .82852 m .21644 .84687 L .24651 .84038 L p .707 .577 .707 r
F P
0 g
s
.32141 .80349 m .32168 .76646 L .29762 .77201 L p .707 .577 .707 r
F P
0 g
s
.17778 .76906 m .17752 .80608 L .20497 .8107 L p .707 .577 .707 r
F P
0 g
s
.21644 .84687 m .21159 .82852 L .18523 .83251 L p .707 .577 .707 r
F P
0 g
s
.17752 .80608 m .17778 .76906 L .15672 .7624 L p .707 .577 .707 r
F P
0 g
s
.18523 .83251 m .19009 .85086 L .21644 .84687 L p .707 .577 .707 r
F P
0 g
s
.36618 .78902 m .38408 .2894 L .38001 .27661 L p .707 .577 .707 r
F P
0 g
s
.38408 .2894 m .36618 .78902 L .38393 .80129 L p .707 .577 .707 r
F P
0 g
s
.15692 .6463 m .14737 .69997 L .15962 .7117 L p .707 .577 .707 r
F P
0 g
s
.15672 .7624 m .15646 .79943 L .17752 .80608 L p .707 .577 .707 r
F P
0 g
s
.33778 .79615 m .33805 .75913 L .32168 .76646 L p .707 .577 .707 r
F P
0 g
s
.34809 .68123 m .33853 .7349 L .34569 .72568 L p .707 .577 .707 r
F P
0 g
s
.34569 .72568 m .35525 .67202 L .34809 .68123 L p .707 .577 .707 r
F P
0 g
s
.19009 .85086 m .18523 .83251 L .16517 .83363 L p .707 .577 .707 r
F P
0 g
s
.14737 .69997 m .15692 .6463 L .15424 .63529 L p .707 .577 .707 r
F P
0 g
s
.16517 .83363 m .17003 .85198 L .19009 .85086 L p .707 .577 .707 r
F P
0 g
s
.15646 .79943 m .15672 .7624 L .14413 .75436 L p .707 .577 .707 r
F P
0 g
s
.64978 .79113 m .64637 .78043 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66769 .29151 m .66148 .46482 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.66148 .46482 m .64978 .79113 L p .65696 .53756 L .707 .577 .707 r
F P
0 g
s
.64729 .74327 m .65556 .56006 L .64637 .78043 L .707 .577 .707 r
F
.65556 .56006 m .66769 .29151 L .65696 .53756 L F
.65556 .56006 m .65696 .53756 L .64637 .78043 L F
.66361 .27872 m .66769 .29151 L p .64729 .74327 L F P
0 g
s
.64571 .77834 m .64802 .71379 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .66361 .27872 L p .64729 .74327 L .707 .577 .707 r
F P
0 g
s
.64248 .5936 m .63983 .60844 L .64325 .61031 L p .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64174 .5776 L .64205 .59325 L .707 .577 .707 r
F
.66361 .27872 m .64802 .71379 L p .64405 .62778 L F P
0 g
s
.64411 .62669 m .63694 .62442 L p .64349 .63818 L .707 .577 .707 r
F P
0 g
s
.64174 .5776 m .66136 .30948 L .64405 .62778 L .707 .577 .707 r
F
.66136 .30948 m .66361 .27872 L .64405 .62778 L F
.65773 .6681 m .65799 .63107 L .64411 .62669 L p F P
0 g
s
.63983 .60844 m .64248 .5936 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64802 .71379 m .64571 .77834 L p .64308 .64562 L .707 .577 .707 r
F P
0 g
s
.64349 .63818 m .63694 .62442 L .64213 .66317 L .707 .577 .707 r
F
.64174 .5776 m .64405 .62778 L .64308 .64562 L F
.64405 .62778 m .64802 .71379 L .64308 .64562 L F
.63694 .62442 m .63667 .66144 L .64213 .66317 L p F P
0 g
s
.62795 .76608 m .59825 .75553 L p .60451 .6912 L .707 .577 .707 r
F P
0 g
s
.63667 .66144 m .63694 .62442 L .62603 .61745 L p .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62463 .48454 L .62602 .61612 L .707 .577 .707 r
F
.63667 .66144 m .62603 .61745 L .62609 .62275 L F
.63983 .60844 m .63911 .59085 L .63226 .59433 L F
.63072 .59971 m .63983 .60844 L p .63226 .59433 L F P
0 g
s
.64585 .26645 m .63437 .58697 L p .62602 .61612 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .62758 .59671 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.62643 .6549 m .63667 .66144 L p .62609 .62275 L .707 .577 .707 r
F P
0 g
s
.63437 .58697 m .62795 .76608 L p .62759 .76494 L .707 .577 .707 r
F P
0 g
s
.60451 .6912 m .62602 .61612 L .62759 .76494 L .707 .577 .707 r
F
.62602 .61612 m .63437 .58697 L .62759 .76494 L F
.62434 .61637 m .62408 .6534 L .62643 .6549 L p F P
0 g
s
.62609 .62275 m .62434 .61637 L .62643 .6549 L .707 .577 .707 r
F
.62603 .61745 m .62434 .61637 L p .62609 .62275 L F P
0 g
s
.62463 .48454 m .64585 .26645 L .62602 .61612 L .707 .577 .707 r
F
.62758 .59671 m .63072 .59971 L p .63226 .59433 L F P
0 g
s
.63437 .58697 m .63531 .56057 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .64585 .26645 L p .6416 .53381 L .707 .577 .707 r
F P
0 g
s
.63531 .56057 m .6416 .53381 L .64068 .59213 L .707 .577 .707 r
F
.63714 .54305 m .63446 .53203 L p .62821 .59081 L F P
0 g
s
.62758 .59671 m .62996 .58337 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.62996 .58337 m .63714 .54305 L p .62821 .59081 L .707 .577 .707 r
F P
0 g
s
.63714 .54305 m .62996 .58337 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64585 .26645 m .66361 .27872 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.62795 .76608 m .63437 .58697 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64571 .77834 m .62795 .76608 L p .64068 .59213 L .707 .577 .707 r
F P
0 g
s
.64068 .59213 m .64205 .59325 L .64571 .77834 L .707 .577 .707 r
F
.64213 .66317 m .65773 .6681 L p .64349 .63818 L F P
0 g
s
.65773 .6681 m .64411 .62669 L .64349 .63818 L .707 .577 .707 r
F
.64939 .55478 m .63714 .54305 L p .63911 .59085 L F P
0 g
s
.64248 .5936 m .64939 .55478 L p .63911 .59085 L .707 .577 .707 r
F P
0 g
s
.64939 .55478 m .64248 .5936 L p .65048 .61428 L .707 .577 .707 r
F P
0 g
s
.64325 .61031 m .65048 .61428 L p .64248 .5936 L .707 .577 .707 r
F P
0 g
s
.65048 .61428 m .66047 .61975 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.65163 .56791 m .64939 .55478 L .65048 .61428 L .707 .577 .707 r
F
.65024 .72709 m .6703 .72598 L p .64629 .70936 L F P
0 g
s
.64539 .70874 m .64615 .71162 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.64615 .71162 m .65024 .72709 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .66545 .70763 L .64633 .70869 L p .707 .577 .707 r
F P
0 g
s
.64633 .70869 m .64539 .70874 L p .64629 .70936 L .707 .577 .707 r
F P
0 g
s
.6703 .72598 m .64633 .70869 L .64629 .70936 L .707 .577 .707 r
F
.66047 .61975 m .67002 .56608 L .65192 .55616 L p F P
0 g
s
.65192 .55616 m .64939 .55478 L p .65163 .56791 L .707 .577 .707 r
F P
0 g
s
.66047 .61975 m .65192 .55616 L .65163 .56791 L .707 .577 .707 r
F
.64637 .78043 m .64571 .77834 L p .64729 .74327 L F P
0 g
s
.14413 .75436 m .14387 .79138 L .15646 .79943 L p .707 .577 .707 r
F P
0 g
s
.15424 .63529 m .14469 .68895 L .14737 .69997 L p .707 .577 .707 r
F P
0 g
s
.17003 .85198 m .16517 .83363 L .15337 .83175 L p .707 .577 .707 r
F P
0 g
s
.15337 .83175 m .15823 .8501 L .17003 .85198 L p .707 .577 .707 r
F P
0 g
s
.35525 .67202 m .34569 .72568 L .34301 .71467 L p .707 .577 .707 r
F P
0 g
s
.34301 .71467 m .35257 .661 L .35525 .67202 L p .707 .577 .707 r
F P
0 g
s
.38001 .27661 m .3621 .77624 L .36618 .78902 L p .707 .577 .707 r
F P
0 g
s
.3621 .77624 m .38001 .27661 L .39001 .26455 L p .707 .577 .707 r
F P
0 g
s
.14469 .68895 m .15424 .63529 L .1614 .62607 L p .707 .577 .707 r
F P
0 g
s
.14387 .79138 m .14413 .75436 L .14124 .74571 L p .707 .577 .707 r
F P
0 g
s
.14124 .74571 m .14097 .78274 L .14387 .79138 L p .707 .577 .707 r
F P
0 g
s
.1614 .62607 m .15184 .67974 L .14469 .68895 L p .707 .577 .707 r
F P
0 g
s
.15823 .8501 m .15337 .83175 L .15098 .82706 L p .707 .577 .707 r
F P
0 g
s
.34223 .74208 m .34197 .77911 L .32938 .77106 L p .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .33389 .7725 L .34109 .77365 L p .707 .577 .707 r
F P
0 g
s
.34197 .77911 m .3421 .76079 L p .34513 .75073 L .707 .577 .707 r
F P
0 g
s
.34109 .77365 m .34569 .77438 L p .33997 .78795 L .707 .577 .707 r
F P
0 g
s
.33875 .79085 m .34109 .77365 L .33997 .78795 L .707 .577 .707 r
F
.3421 .76079 m .34223 .74208 L .34331 .74531 L p F P
0 g
s
.34331 .74531 m .34513 .75073 L p .3421 .76079 L .707 .577 .707 r
F P
0 g
s
.15098 .82706 m .15584 .84541 L .15823 .8501 L p .707 .577 .707 r
F P
0 g
s
.35257 .661 m .34301 .71467 L .33075 .70293 L p .707 .577 .707 r
F P
0 g
s
.33075 .70293 m .34031 .64927 L .35257 .661 L p .707 .577 .707 r
F P
0 g
s
.15184 .67974 m .1614 .62607 L .1777 .61956 L p .707 .577 .707 r
F P
0 g
s
.34808 .77907 m .35294 .79742 L .35055 .79273 L p .707 .577 .707 r
F P
0 g
s
.35055 .79273 m .34569 .77438 L .34808 .77907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14097 .78274 m .14124 .74571 L .14832 .73731 L p .707 .577 .707 r
F P
0 g
s
.3721 .76418 m .39001 .26455 L .41312 .2544 L p .707 .577 .707 r
F P
0 g
s
.39001 .26455 m .3721 .76418 L .3621 .77624 L p .707 .577 .707 r
F P
0 g
s
.14832 .73731 m .14805 .77434 L .14097 .78274 L p .707 .577 .707 r
F P
0 g
s
.1777 .61956 m .16814 .67322 L .15184 .67974 L p .707 .577 .707 r
F P
0 g
s
.32938 .77106 m .32964 .73404 L .34223 .74208 L p .707 .577 .707 r
F P
0 g
s
.34031 .64927 m .33075 .70293 L .31012 .69163 L p .707 .577 .707 r
F P
0 g
s
.31012 .69163 m .31968 .63797 L .34031 .64927 L p .707 .577 .707 r
F P
0 g
s
.15584 .84541 m .15098 .82706 L .15824 .82002 L p .707 .577 .707 r
F P
0 g
s
.16814 .67322 m .1777 .61956 L .20153 .61638 L p .707 .577 .707 r
F P
0 g
s
.15824 .82002 m .16309 .83837 L .15584 .84541 L p .707 .577 .707 r
F P
0 g
s
.34569 .77438 m .35055 .79273 L .33875 .79085 L p .707 .577 .707 r
F P
0 g
s
.59825 .75553 m .61615 .25591 L .64585 .26645 L p .707 .577 .707 r
F P
0 g
s
.14805 .77434 m .14832 .73731 L .16469 .72998 L p .707 .577 .707 r
F P
0 g
s
.20153 .61638 m .19197 .67004 L .16814 .67322 L p .707 .577 .707 r
F P
0 g
s
.31968 .63797 m .31012 .69163 L .28313 .68186 L p .707 .577 .707 r
F P
0 g
s
.28313 .68186 m .29269 .6282 L .31968 .63797 L p .707 .577 .707 r
F P
0 g
s
.16469 .72998 m .16442 .76701 L .14805 .77434 L p .707 .577 .707 r
F P
0 g
s
.19197 .67004 m .20153 .61638 L .23058 .61685 L p .707 .577 .707 r
F P
0 g
s
.41312 .2544 m .39521 .75403 L .3721 .76418 L p .707 .577 .707 r
F P
0 g
s
.39521 .75403 m .41312 .2544 L .44706 .24715 L p .707 .577 .707 r
F P
0 g
s
.32964 .73404 m .32938 .77106 L .30832 .76441 L p .707 .577 .707 r
F P
0 g
s
.30832 .76441 m .30859 .72738 L .32964 .73404 L p .707 .577 .707 r
F P
0 g
s
.16309 .83837 m .15824 .82002 L .17443 .81133 L p .707 .577 .707 r
F P
0 g
s
.71816 .63679 m .72771 .58313 L .69701 .57585 L p .707 .577 .707 r
F P
0 g
s
.74673 .6405 m .74957 .64087 L p .74228 .62163 L .707 .577 .707 r
F P
0 g
s
.74957 .64087 m .75913 .5872 L .72771 .58313 L p .707 .577 .707 r
F P
0 g
s
.75913 .5872 m .75911 .58727 L p .77861 .64134 L .707 .577 .707 r
F P
0 g
s
.75911 .58727 m .74957 .64087 L .77621 .6413 L p .707 .577 .707 r
F P
0 g
s
.77621 .6413 m .77861 .64134 L p .75911 .58727 L .707 .577 .707 r
F P
0 g
s
.77861 .64134 m .78817 .58767 L .75913 .5872 L p .707 .577 .707 r
F P
0 g
s
.78817 .58767 m .78743 .59183 L p .80245 .63816 L .707 .577 .707 r
F P
0 g
s
.78743 .59183 m .77861 .64134 L .8008 .63838 L p .707 .577 .707 r
F P
0 g
s
.8008 .63838 m .80245 .63816 L p .78743 .59183 L .707 .577 .707 r
F P
0 g
s
.80245 .63816 m .81201 .58449 L .78817 .58767 L p .707 .577 .707 r
F P
0 g
s
.81201 .58449 m .81147 .58749 L p .81874 .63164 L .707 .577 .707 r
F P
0 g
s
.81147 .58749 m .80245 .63816 L .81775 .63204 L p .707 .577 .707 r
F P
0 g
s
.81775 .63204 m .81874 .63164 L p .81147 .58749 L .707 .577 .707 r
F P
0 g
s
.81874 .63164 m .8283 .57798 L .81201 .58449 L p .707 .577 .707 r
F P
0 g
s
.8283 .57798 m .81874 .63164 L .82547 .62298 L p .707 .577 .707 r
F P
0 g
s
.82547 .62298 m .8259 .62243 L p .82717 .59902 L .707 .577 .707 r
F P
0 g
s
.82717 .59902 m .8283 .57798 L .82547 .62298 L .707 .577 .707 r
F
.81826 .62114 m .81816 .63492 L p .82508 .64977 L F P
0 g
s
.82534 .61274 m .81826 .62114 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82508 .64977 m .82525 .6261 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.82525 .6261 m .82534 .61274 L p .82346 .64298 L .707 .577 .707 r
F P
0 g
s
.8259 .62243 m .83546 .56876 L .8283 .57798 L p .707 .577 .707 r
F P
0 g
s
.83546 .56876 m .8259 .62243 L .82572 .62166 L p .707 .577 .707 r
F P
0 g
s
.82534 .61274 m .82525 .6261 L p .82218 .64112 L .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82534 .61274 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82218 .64112 m .82236 .61625 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.82236 .61625 m .82245 .6041 L p .82286 .63508 L .707 .577 .707 r
F P
0 g
s
.81816 .63492 m .818 .65817 L .82095 .65467 L p .707 .577 .707 r
F P
0 g
s
.82095 .65467 m .82508 .64977 L p .81816 .63492 L .707 .577 .707 r
F P
0 g
s
.818 .65817 m .81826 .62114 L .80189 .62847 L p .707 .577 .707 r
F P
0 g
s
.82245 .6041 m .82218 .64112 L .80959 .63308 L p .707 .577 .707 r
F P
0 g
s
.83278 .55775 m .82322 .61141 L .82221 .61044 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .82245 .6041 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80959 .63308 m .80978 .60633 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80978 .60633 m .80985 .59605 L p .81172 .62827 L .707 .577 .707 r
F P
0 g
s
.80189 .62847 m .80179 .64183 L p .818 .65817 L .707 .577 .707 r
F P
0 g
s
.80163 .6655 m .80189 .62847 L .77784 .63402 L p .707 .577 .707 r
F P
0 g
s
.80985 .59605 m .80959 .63308 L .78854 .62642 L p .707 .577 .707 r
F P
0 g
s
.78854 .62642 m .7888 .5894 L .80985 .59605 L p .707 .577 .707 r
F P
0 g
s
.82052 .54601 m .81097 .59968 L .8091 .59866 L p .707 .577 .707 r
F P
0 g
s
.8091 .59866 m .79033 .58837 L p .80622 .56609 L .707 .577 .707 r
F P
0 g
s
.80622 .56609 m .82052 .54601 L .8091 .59866 L .707 .577 .707 r
F
.82221 .61044 m .81097 .59968 L p .8214 .57963 L F P
0 g
s
.8214 .57963 m .83278 .55775 L .82221 .61044 L .707 .577 .707 r
F
.82572 .62166 m .82322 .61141 L p .82889 .59165 L F P
0 g
s
.82889 .59165 m .83546 .56876 L .82572 .62166 L .707 .577 .707 r
F
.82525 .6261 m .82508 .64977 L .82383 .64605 L p F P
0 g
s
.82383 .64605 m .82218 .64112 L p .82525 .6261 L .707 .577 .707 r
F P
0 g
s
.80179 .64183 m .80163 .6655 L .8078 .66274 L p .707 .577 .707 r
F P
0 g
s
.8078 .66274 m .818 .65817 L p .80179 .64183 L .707 .577 .707 r
F P
0 g
s
.77784 .63402 m .77775 .64618 L p .80163 .6655 L .707 .577 .707 r
F P
0 g
s
.77775 .64618 m .77757 .67105 L .78507 .66932 L p .707 .577 .707 r
F P
0 g
s
.78507 .66932 m .80163 .6655 L p .77775 .64618 L .707 .577 .707 r
F P
0 g
s
.74846 .63724 m .74838 .64752 L p .77757 .67105 L .707 .577 .707 r
F P
0 g
s
.74838 .64752 m .74819 .67427 L .75452 .67357 L p .707 .577 .707 r
F P
0 g
s
.75452 .67357 m .77757 .67105 L p .74838 .64752 L .707 .577 .707 r
F P
0 g
s
.72771 .58313 m .71816 .63679 L .74673 .6405 L p .707 .577 .707 r
F P
0 g
s
.74228 .62163 m .72771 .58313 L .74673 .6405 L .707 .577 .707 r
F
.17443 .81133 m .17929 .82968 L .16309 .83837 L p F P
0 g
s
.29269 .6282 m .28313 .68186 L .25243 .67458 L p .707 .577 .707 r
F P
0 g
s
.25243 .67458 m .26199 .62092 L .29269 .6282 L p .707 .577 .707 r
F P
0 g
s
.22102 .67051 m .23058 .61685 L .26199 .62092 L p .707 .577 .707 r
F P
0 g
s
.23058 .61685 m .22102 .67051 L .19197 .67004 L p .707 .577 .707 r
F P
0 g
s
.33389 .7725 m .33875 .79085 L .31869 .79196 L p .707 .577 .707 r
F P
0 g
s
.31869 .79196 m .31383 .77361 L .33389 .7725 L p .707 .577 .707 r
F P
0 g
s
.68745 .62952 m .69701 .57585 L .67002 .56608 L p .707 .577 .707 r
F P
0 g
s
.69701 .57585 m .68745 .62952 L .71816 .63679 L p .707 .577 .707 r
F P
0 g
s
.16442 .76701 m .16469 .72998 L .18874 .72443 L p .707 .577 .707 r
F P
0 g
s
.26199 .62092 m .25243 .67458 L .22102 .67051 L p .707 .577 .707 r
F P
0 g
s
.61615 .25591 m .59825 .75553 L .55951 .74775 L p .707 .577 .707 r
F P
0 g
s
.55951 .74775 m .57742 .24812 L .61615 .25591 L p .707 .577 .707 r
F P
0 g
s
.18874 .72443 m .18848 .76146 L .16442 .76701 L p .707 .577 .707 r
F P
0 g
s
.30859 .72738 m .30832 .76441 L .28086 .75979 L p .707 .577 .707 r
F P
0 g
s
.28086 .75979 m .28113 .72277 L .30859 .72738 L p .707 .577 .707 r
F P
0 g
s
.67002 .56608 m .66047 .61975 L .68745 .62952 L p .707 .577 .707 r
F P
0 g
s
.71636 .67484 m .71662 .63781 L .68545 .63569 L p .707 .577 .707 r
F P
0 g
s
.71662 .63781 m .71636 .67484 L .74819 .67427 L p .707 .577 .707 r
F P
0 g
s
.74819 .67427 m .74846 .63724 L .71662 .63781 L p .707 .577 .707 r
F P
0 g
s
.42915 .74678 m .44706 .24715 L .48852 .24352 L p .707 .577 .707 r
F P
0 g
s
.44706 .24715 m .42915 .74678 L .39521 .75403 L p .707 .577 .707 r
F P
0 g
s
.77757 .67105 m .77784 .63402 L .74846 .63724 L p .707 .577 .707 r
F P
0 g
s
.17929 .82968 m .17443 .81133 L .19798 .80182 L p .707 .577 .707 r
F P
0 g
s
.18848 .76146 m .18874 .72443 L .21812 .72122 L p .707 .577 .707 r
F P
0 g
s
.68519 .67272 m .68545 .63569 L .65799 .63107 L p .707 .577 .707 r
F P
0 g
s
.68545 .63569 m .68519 .67272 L .71636 .67484 L p .707 .577 .707 r
F P
0 g
s
.19798 .80182 m .20283 .82017 L .17929 .82968 L p .707 .577 .707 r
F P
0 g
s
.31383 .77361 m .31869 .79196 L .29233 .79596 L p .707 .577 .707 r
F P
0 g
s
.29233 .79596 m .28748 .77761 L .31383 .77361 L p .707 .577 .707 r
F P
0 g
s
.57742 .24812 m .55951 .74775 L .51553 .74348 L p .707 .577 .707 r
F P
0 g
s
.51553 .74348 m .53344 .24385 L .57742 .24812 L p .707 .577 .707 r
F P
0 g
s
.28113 .72277 m .28086 .75979 L .24969 .75767 L p .707 .577 .707 r
F P
0 g
s
.24969 .75767 m .24996 .72064 L .28113 .72277 L p .707 .577 .707 r
F P
0 g
s
.72672 .7155 m .72187 .69715 L .6918 .70363 L p .707 .577 .707 r
F P
0 g
s
.72187 .69715 m .72672 .7155 L .75756 .70715 L p .707 .577 .707 r
F P
0 g
s
.75756 .70715 m .75271 .6888 L .72187 .69715 L p .707 .577 .707 r
F P
0 g
s
.75271 .6888 m .75756 .70715 L .78615 .69777 L p .707 .577 .707 r
F P
0 g
s
.78615 .69777 m .7813 .67942 L .75271 .6888 L p .707 .577 .707 r
F P
0 g
s
.21812 .72122 m .21786 .75824 L .18848 .76146 L p .707 .577 .707 r
F P
0 g
s
.65799 .63107 m .65773 .6681 L .68519 .67272 L p .707 .577 .707 r
F P
0 g
s
.6918 .70363 m .69665 .72198 L .72672 .7155 L p .707 .577 .707 r
F P
0 g
s
.47061 .74314 m .48852 .24352 L .53344 .24385 L p .707 .577 .707 r
F P
0 g
s
.48852 .24352 m .47061 .74314 L .42915 .74678 L p .707 .577 .707 r
F P
0 g
s
.21786 .75824 m .21812 .72122 L .24996 .72064 L p .707 .577 .707 r
F P
0 g
s
.24996 .72064 m .24969 .75767 L .21786 .75824 L p .707 .577 .707 r
F P
0 g
s
.53344 .24385 m .51553 .74348 L .47061 .74314 L p .707 .577 .707 r
F P
0 g
s
.69665 .72198 m .6918 .70363 L .66545 .70763 L p .707 .577 .707 r
F P
0 g
s
.20283 .82017 m .19798 .80182 L .22657 .79244 L p .707 .577 .707 r
F P
0 g
s
.66545 .70763 m .6703 .72598 L .69665 .72198 L p .707 .577 .707 r
F P
0 g
s
.7813 .67942 m .78615 .69777 L .8097 .68826 L p .707 .577 .707 r
F P
0 g
s
.8097 .68826 m .80485 .66991 L .7813 .67942 L p .707 .577 .707 r
F P
0 g
s
.22657 .79244 m .23143 .81079 L .20283 .82017 L p .707 .577 .707 r
F P
0 g
s
.28748 .77761 m .29233 .79596 L .26227 .80245 L p .707 .577 .707 r
F P
0 g
s
.26227 .80245 m .25741 .78409 L .28748 .77761 L p .707 .577 .707 r
F P
0 g
s
.23143 .81079 m .22657 .79244 L .25741 .78409 L p .707 .577 .707 r
F P
0 g
s
.25741 .78409 m .26227 .80245 L .23143 .81079 L p .707 .577 .707 r
F P
0 g
s
.80485 .66991 m .8097 .68826 L .82589 .67957 L p .707 .577 .707 r
F P
0 g
s
.82589 .67957 m .82104 .66122 L .80485 .66991 L p .707 .577 .707 r
F P
0 g
s
.65024 .72709 m .64539 .70874 L .63358 .70686 L p .707 .577 .707 r
F P
0 g
s
.63446 .53203 m .6249 .5857 L .62758 .59671 L p .707 .577 .707 r
F P
0 g
s
.63358 .70686 m .63844 .72521 L .65024 .72709 L p .707 .577 .707 r
F P
0 g
s
.82104 .66122 m .82589 .67957 L .83315 .67253 L p .707 .577 .707 r
F P
0 g
s
.83315 .67253 m .8283 .65418 L .82104 .66122 L p .707 .577 .707 r
F P
0 g
s
.62408 .6534 m .62434 .61637 L .62145 .60773 L p .707 .577 .707 r
F P
0 g
s
.82322 .61141 m .83278 .55775 L .83546 .56876 L p .707 .577 .707 r
F P
0 g
s
.6249 .5857 m .63446 .53203 L .64162 .52282 L p .707 .577 .707 r
F P
0 g
s
.62145 .60773 m .62119 .64475 L .62408 .6534 L p .707 .577 .707 r
F P
0 g
s
.63844 .72521 m .63358 .70686 L .6312 .70217 L p .707 .577 .707 r
F P
0 g
s
.64162 .52282 m .63206 .57648 L .6249 .5857 L p .707 .577 .707 r
F P
0 g
s
.6312 .70217 m .63605 .72052 L .63844 .72521 L p .707 .577 .707 r
F P
0 g
s
.8283 .65418 m .83315 .67253 L .83076 .66785 L p .707 .577 .707 r
F P
0 g
s
.83076 .66785 m .82591 .64949 L .8283 .65418 L p .707 .577 .707 r
F P
0 g
s
.62119 .64475 m .62145 .60773 L .62853 .59933 L p .707 .577 .707 r
F P
0 g
s
.81097 .59968 m .82052 .54601 L .83278 .55775 L p .707 .577 .707 r
F P
0 g
s
.63206 .57648 m .64162 .52282 L .65791 .5163 L p .707 .577 .707 r
F P
0 g
s
.62853 .59933 m .62827 .63635 L .62119 .64475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.37515 .64801 m .3847 .59435 L .354 .58707 L p .707 .577 .707 r
F P
0 g
s
.3847 .59435 m .37515 .64801 L .40656 .65208 L p .707 .577 .707 r
F P
0 g
s
.40656 .65208 m .41612 .59842 L .3847 .59435 L p .707 .577 .707 r
F P
0 g
s
.65791 .5163 m .64835 .56996 L .63206 .57648 L p .707 .577 .707 r
F P
0 g
s
.63605 .72052 m .6312 .70217 L .63845 .69514 L p .707 .577 .707 r
F P
0 g
s
.63845 .69514 m .64331 .71349 L .63605 .72052 L p .707 .577 .707 r
F P
0 g
s
.41612 .59842 m .40656 .65208 L .4356 .65255 L p .707 .577 .707 r
F P
0 g
s
.4356 .65255 m .44516 .59889 L .41612 .59842 L p .707 .577 .707 r
F P
0 g
s
.34444 .64073 m .354 .58707 L .32701 .5773 L p .707 .577 .707 r
F P
0 g
s
.354 .58707 m .34444 .64073 L .37515 .64801 L p .707 .577 .707 r
F P
0 g
s
.79033 .58837 m .79989 .53471 L .82052 .54601 L p .707 .577 .707 r
F P
0 g
s
.82591 .64949 m .83076 .66785 L .81896 .66597 L p .707 .577 .707 r
F P
0 g
s
.81896 .66597 m .81411 .64761 L .82591 .64949 L p .707 .577 .707 r
F P
0 g
s
.64835 .56996 m .65791 .5163 L .68175 .51312 L p .707 .577 .707 r
F P
0 g
s
.62827 .63635 m .62853 .59933 L .6449 .59199 L p .707 .577 .707 r
F P
0 g
s
.44516 .59889 m .4356 .65255 L .45944 .64937 L p .707 .577 .707 r
F P
0 g
s
.45944 .64937 m .469 .59571 L .44516 .59889 L p .707 .577 .707 r
F P
0 g
s
.31746 .63096 m .32701 .5773 L .30638 .566 L p .707 .577 .707 r
F P
0 g
s
.32701 .5773 m .31746 .63096 L .34444 .64073 L p .707 .577 .707 r
F P
0 g
s
.6449 .59199 m .64464 .62902 L .62827 .63635 L p .707 .577 .707 r
F P
0 g
s
.68175 .51312 m .67219 .56679 L .64835 .56996 L p .707 .577 .707 r
F P
0 g
s
.79989 .53471 m .79033 .58837 L .76335 .57861 L p .707 .577 .707 r
F P
0 g
s
.76335 .57861 m .77291 .52494 L .79989 .53471 L p .707 .577 .707 r
F P
0 g
s
.37335 .72079 m .37361 .68376 L .34244 .68164 L p .707 .577 .707 r
F P
0 g
s
.37361 .68376 m .37335 .72079 L .40518 .72021 L p .707 .577 .707 r
F P
0 g
s
.40518 .72021 m .40545 .68319 L .37361 .68376 L p .707 .577 .707 r
F P
0 g
s
.67219 .56679 m .68175 .51312 L .71079 .51359 L p .707 .577 .707 r
F P
0 g
s
.64331 .71349 m .63845 .69514 L .65465 .68644 L p .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .43829 .71227 L .42714 .71593 L p .707 .577 .707 r
F P
0 g
s
.42714 .71593 m .4097 .72165 L p .42306 .72523 L .707 .577 .707 r
F P
0 g
s
.44314 .73062 m .42714 .71593 L .42306 .72523 L .707 .577 .707 r
F
.43829 .71227 m .44314 .73062 L .46669 .72111 L p F P
0 g
s
.46669 .72111 m .46184 .70276 L .45335 .70619 L p .707 .577 .707 r
F P
0 g
s
.45335 .70619 m .43829 .71227 L p .44986 .71587 L .707 .577 .707 r
F P
0 g
s
.46669 .72111 m .45335 .70619 L .44986 .71587 L .707 .577 .707 r
F
.46184 .70276 m .46669 .72111 L .48288 .71242 L p F P
0 g
s
.48288 .71242 m .47803 .69407 L .47274 .6969 L p .707 .577 .707 r
F P
0 g
s
.47274 .6969 m .46184 .70276 L p .471 .70696 L .707 .577 .707 r
F P
0 g
s
.48288 .71242 m .47274 .6969 L .471 .70696 L .707 .577 .707 r
F
.47803 .69407 m .48288 .71242 L .49014 .70538 L p F P
0 g
s
.49014 .70538 m .48529 .68703 L .4831 .68915 L p .707 .577 .707 r
F P
0 g
s
.4831 .68915 m .47803 .69407 L p .48377 .69943 L .707 .577 .707 r
F P
0 g
s
.49014 .70538 m .4831 .68915 L .48377 .69943 L .707 .577 .707 r
F
.47499 .70412 m .48207 .69572 L p .47679 .67357 L F P
0 g
s
.48207 .69572 m .48233 .65869 L .47525 .66709 L p .707 .577 .707 r
F P
0 g
s
.48207 .69572 m .47917 .68707 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48233 .65869 m .48221 .67541 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.48221 .67541 m .48207 .69572 L p .48157 .66551 L .707 .577 .707 r
F P
0 g
s
.47525 .66709 m .47513 .68312 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.47513 .68312 m .47499 .70412 L p .47679 .67357 L .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .47499 .70412 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45888 .67442 m .45876 .69114 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.45876 .69114 m .45862 .71145 L p .46242 .68096 L .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .45862 .71145 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43483 .67997 m .43469 .69867 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.43469 .69867 m .43456 .71699 L p .43993 .68672 L .707 .577 .707 r
F P
0 g
s
.40545 .68319 m .40518 .72021 L .43456 .71699 L p .707 .577 .707 r
F P
0 g
s
.43456 .71699 m .43483 .67997 L .40545 .68319 L p .707 .577 .707 r
F P
0 g
s
.65465 .68644 m .6595 .70479 L .64331 .71349 L p .707 .577 .707 r
F P
0 g
s
.64464 .62902 m .6449 .59199 L .66895 .58645 L p .707 .577 .707 r
F P
0 g
s
.34218 .71866 m .34244 .68164 L .31498 .67702 L p .707 .577 .707 r
F P
0 g
s
.34244 .68164 m .34218 .71866 L .37335 .72079 L p .707 .577 .707 r
F P
0 g
s
.81411 .64761 m .81896 .66597 L .7989 .66708 L p .707 .577 .707 r
F P
0 g
s
.7989 .66708 m .79405 .64873 L .81411 .64761 L p .707 .577 .707 r
F P
0 g
s
.30638 .566 m .29682 .61966 L .31746 .63096 L p .707 .577 .707 r
F P
0 g
s
.469 .59571 m .45944 .64937 L .47573 .64286 L p .707 .577 .707 r
F P
0 g
s
.47573 .64286 m .48529 .58919 L .469 .59571 L p .707 .577 .707 r
F P
0 g
s
.38371 .74834 m .37886 .72999 L .34879 .73648 L p .707 .577 .707 r
F P
0 g
s
.37886 .72999 m .38371 .74834 L .41455 .74 L p .707 .577 .707 r
F P
0 g
s
.41455 .74 m .4097 .72165 L .37886 .72999 L p .707 .577 .707 r
F P
0 g
s
.29682 .61966 m .30638 .566 L .29413 .55426 L p .707 .577 .707 r
F P
0 g
s
.4097 .72165 m .41455 .74 L .44314 .73062 L p .707 .577 .707 r
F P
0 g
s
.77291 .52494 m .76335 .57861 L .73265 .57133 L p .707 .577 .707 r
F P
0 g
s
.73265 .57133 m .7422 .51766 L .77291 .52494 L p .707 .577 .707 r
F P
0 g
s
.70123 .56726 m .71079 .51359 L .7422 .51766 L p .707 .577 .707 r
F P
0 g
s
.71079 .51359 m .70123 .56726 L .67219 .56679 L p .707 .577 .707 r
F P
0 g
s
.34879 .73648 m .35364 .75483 L .38371 .74834 L p .707 .577 .707 r
F P
0 g
s
.45862 .71145 m .45888 .67442 L .43483 .67997 L p .707 .577 .707 r
F P
0 g
s
.66895 .58645 m .66869 .62347 L .64464 .62902 L p .707 .577 .707 r
F P
0 g
s
.31498 .67702 m .31472 .71405 L .34218 .71866 L p .707 .577 .707 r
F P
0 g
s
.7422 .51766 m .73265 .57133 L .70123 .56726 L p .707 .577 .707 r
F P
0 g
s
.7888 .5894 m .78854 .62642 L .76108 .62181 L p .707 .577 .707 r
F P
0 g
s
.76108 .62181 m .76134 .58478 L .7888 .5894 L p .707 .577 .707 r
F P
0 g
s
.35364 .75483 m .34879 .73648 L .32244 .74047 L p .707 .577 .707 r
F P
0 g
s
.31472 .71405 m .31498 .67702 L .29393 .67036 L p .707 .577 .707 r
F P
0 g
s
.32244 .74047 m .32729 .75883 L .35364 .75483 L p .707 .577 .707 r
F P
0 g
s
.66869 .62347 m .66895 .58645 L .69834 .58323 L p .707 .577 .707 r
F P
0 g
s
.6595 .70479 m .65465 .68644 L .67819 .67694 L p .707 .577 .707 r
F P
0 g
s
.29413 .55426 m .28457 .60793 L .29682 .61966 L p .707 .577 .707 r
F P
0 g
s
.67819 .67694 m .68305 .69529 L .6595 .70479 L p .707 .577 .707 r
F P
0 g
s
.29393 .67036 m .29366 .70739 L .31472 .71405 L p .707 .577 .707 r
F P
0 g
s
.79405 .64873 m .7989 .66708 L .77255 .67107 L p .707 .577 .707 r
F P
0 g
s
.77255 .67107 m .76769 .65272 L .79405 .64873 L p .707 .577 .707 r
F P
0 g
s
.76134 .58478 m .76108 .62181 L .72991 .61968 L p .707 .577 .707 r
F P
0 g
s
.72991 .61968 m .73017 .58265 L .76134 .58478 L p .707 .577 .707 r
F P
0 g
s
.47499 .70412 m .47525 .66709 L .45888 .67442 L p .707 .577 .707 r
F P
0 g
s
.48529 .58919 m .47573 .64286 L .48289 .63364 L p .707 .577 .707 r
F P
0 g
s
.48289 .63364 m .49245 .57998 L .48529 .58919 L p .707 .577 .707 r
F P
0 g
s
.69834 .58323 m .69807 .62026 L .66869 .62347 L p .707 .577 .707 r
F P
0 g
s
.32729 .75883 m .32244 .74047 L .30238 .74159 L p .707 .577 .707 r
F P
0 g
s
.69807 .62026 m .69834 .58323 L .73017 .58265 L p .707 .577 .707 r
F P
0 g
s
.28457 .60793 m .29413 .55426 L .29145 .54325 L p .707 .577 .707 r
F P
0 g
s
.30238 .74159 m .30723 .75994 L .32729 .75883 L p .707 .577 .707 r
F P
0 g
s
.73017 .58265 m .72991 .61968 L .69807 .62026 L p .707 .577 .707 r
F P
0 g
s
.29366 .70739 m .29393 .67036 L .28133 .66232 L p .707 .577 .707 r
F P
0 g
s
.68305 .69529 m .67819 .67694 L .70679 .66755 L p .707 .577 .707 r
F P
0 g
s
.70679 .66755 m .71164 .6859 L .68305 .69529 L p .707 .577 .707 r
F P
0 g
s
.76769 .65272 m .77255 .67107 L .74248 .67756 L p .707 .577 .707 r
F P
0 g
s
.74248 .67756 m .73762 .65921 L .76769 .65272 L p .707 .577 .707 r
F P
0 g
s
.28133 .66232 m .28107 .69935 L .29366 .70739 L p .707 .577 .707 r
F P
0 g
s
.29145 .54325 m .28189 .59691 L .28457 .60793 L p .707 .577 .707 r
F P
0 g
s
.71164 .6859 m .70679 .66755 L .73762 .65921 L p .707 .577 .707 r
F P
0 g
s
.73762 .65921 m .74248 .67756 L .71164 .6859 L p .707 .577 .707 r
F P
0 g
s
.30723 .75994 m .30238 .74159 L .29057 .73971 L p .707 .577 .707 r
F P
0 g
s
.29057 .73971 m .29543 .75806 L .30723 .75994 L p .707 .577 .707 r
F P
0 g
s
.49245 .57998 m .48289 .63364 L .48021 .62263 L p .707 .577 .707 r
F P
0 g
s
.48021 .62263 m .48977 .56896 L .49245 .57998 L p .707 .577 .707 r
F P
0 g
s
.28189 .59691 m .29145 .54325 L .2986 .53403 L p .707 .577 .707 r
F P
0 g
s
.28107 .69935 m .28133 .66232 L .27844 .65367 L p .707 .577 .707 r
F P
0 g
s
.27844 .65367 m .27817 .6907 L .28107 .69935 L p .707 .577 .707 r
F P
0 g
s
.2986 .53403 m .28905 .5877 L .28189 .59691 L p .707 .577 .707 r
F P
0 g
s
.29543 .75806 m .29057 .73971 L .28819 .73502 L p .707 .577 .707 r
F P
0 g
s
.47944 .65004 m .47917 .68707 L .46658 .67903 L p .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4711 .68046 L .4783 .68161 L p .707 .577 .707 r
F P
0 g
s
.47917 .68707 m .4793 .66875 L p .48233 .65869 L .707 .577 .707 r
F P
0 g
s
.4783 .68161 m .4829 .68234 L p .47718 .69591 L .707 .577 .707 r
F P
0 g
s
.47595 .69881 m .4783 .68161 L .47718 .69591 L .707 .577 .707 r
F
.4793 .66875 m .47944 .65004 L .48052 .65327 L p F P
0 g
s
.48052 .65327 m .48233 .65869 L p .4793 .66875 L .707 .577 .707 r
F P
0 g
s
.28819 .73502 m .29304 .75337 L .29543 .75806 L p .707 .577 .707 r
F P
0 g
s
.48977 .56896 m .48021 .62263 L .46796 .6109 L p .707 .577 .707 r
F P
0 g
s
.46796 .6109 m .47751 .55723 L .48977 .56896 L p .707 .577 .707 r
F P
0 g
s
.28905 .5877 m .2986 .53403 L .3149 .52752 L p .707 .577 .707 r
F P
0 g
s
.48529 .68703 m .49014 .70538 L .48775 .70069 L p .707 .577 .707 r
F P
0 g
s
.48775 .70069 m .4829 .68234 L .48529 .68703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27817 .6907 m .27844 .65367 L .28552 .64527 L p .707 .577 .707 r
F P
0 g
s
.28552 .64527 m .28526 .6823 L .27817 .6907 L p .707 .577 .707 r
F P
0 g
s
.3149 .52752 m .30534 .58118 L .28905 .5877 L p .707 .577 .707 r
F P
0 g
s
.46658 .67903 m .46684 .642 L .47944 .65004 L p .707 .577 .707 r
F P
0 g
s
.47751 .55723 m .46796 .6109 L .44732 .59959 L p .707 .577 .707 r
F P
0 g
s
.44732 .59959 m .45688 .54593 L .47751 .55723 L p .707 .577 .707 r
F P
0 g
s
.29304 .75337 m .28819 .73502 L .29544 .72798 L p .707 .577 .707 r
F P
0 g
s
.30534 .58118 m .3149 .52752 L .33874 .52434 L p .707 .577 .707 r
F P
0 g
s
.29544 .72798 m .3003 .74634 L .29304 .75337 L p .707 .577 .707 r
F P
0 g
s
.4829 .68234 m .48775 .70069 L .47595 .69881 L p .707 .577 .707 r
F P
0 g
s
.28526 .6823 m .28552 .64527 L .30189 .63794 L p .707 .577 .707 r
F P
0 g
s
.33874 .52434 m .32918 .578 L .30534 .58118 L p .707 .577 .707 r
F P
0 g
s
.45688 .54593 m .44732 .59959 L .42034 .58982 L p .707 .577 .707 r
F P
0 g
s
.42034 .58982 m .4299 .53616 L .45688 .54593 L p .707 .577 .707 r
F P
0 g
s
.30189 .63794 m .30163 .67497 L .28526 .6823 L p .707 .577 .707 r
F P
0 g
s
.32918 .578 m .33874 .52434 L .36778 .52481 L p .707 .577 .707 r
F P
0 g
s
.46684 .642 m .46658 .67903 L .44553 .67237 L p .707 .577 .707 r
F P
0 g
s
.44553 .67237 m .44579 .63534 L .46684 .642 L p .707 .577 .707 r
F P
0 g
s
.3003 .74634 m .29544 .72798 L .31164 .71929 L p .707 .577 .707 r
F P
0 g
s
.31164 .71929 m .31649 .73764 L .3003 .74634 L p .707 .577 .707 r
F P
0 g
s
.4299 .53616 m .42034 .58982 L .38963 .58255 L p .707 .577 .707 r
F P
0 g
s
.38963 .58255 m .39919 .52888 L .4299 .53616 L p .707 .577 .707 r
F P
0 g
s
.35822 .57847 m .36778 .52481 L .39919 .52888 L p .707 .577 .707 r
F P
0 g
s
.36778 .52481 m .35822 .57847 L .32918 .578 L p .707 .577 .707 r
F P
0 g
s
.4711 .68046 m .47595 .69881 L .45589 .69993 L p .707 .577 .707 r
F P
0 g
s
.45589 .69993 m .45104 .68157 L .4711 .68046 L p .707 .577 .707 r
F P
0 g
s
.30163 .67497 m .30189 .63794 L .32594 .6324 L p .707 .577 .707 r
F P
0 g
s
.39919 .52888 m .38963 .58255 L .35822 .57847 L p .707 .577 .707 r
F P
0 g
s
.32594 .6324 m .32568 .66942 L .30163 .67497 L p .707 .577 .707 r
F P
0 g
s
.44579 .63534 m .44553 .67237 L .41807 .66775 L p .707 .577 .707 r
F P
0 g
s
.41807 .66775 m .41833 .63073 L .44579 .63534 L p .707 .577 .707 r
F P
0 g
s
.31649 .73764 m .31164 .71929 L .33518 .70978 L p .707 .577 .707 r
F P
0 g
s
.32568 .66942 m .32594 .6324 L .35532 .62918 L p .707 .577 .707 r
F P
0 g
s
.33518 .70978 m .34004 .72813 L .31649 .73764 L p .707 .577 .707 r
F P
0 g
s
.45104 .68157 m .45589 .69993 L .42954 .70392 L p .707 .577 .707 r
F P
0 g
s
.42954 .70392 m .42468 .68557 L .45104 .68157 L p .707 .577 .707 r
F P
0 g
s
.41833 .63073 m .41807 .66775 L .3869 .66563 L p .707 .577 .707 r
F P
0 g
s
.3869 .66563 m .38716 .6286 L .41833 .63073 L p .707 .577 .707 r
F P
0 g
s
.35532 .62918 m .35506 .6662 L .32568 .66942 L p .707 .577 .707 r
F P
0 g
s
.35506 .6662 m .35532 .62918 L .38716 .6286 L p .707 .577 .707 r
F P
0 g
s
.38716 .6286 m .3869 .66563 L .35506 .6662 L p .707 .577 .707 r
F P
0 g
s
.34004 .72813 m .33518 .70978 L .36377 .7004 L p .707 .577 .707 r
F P
0 g
s
.36377 .7004 m .36863 .71875 L .34004 .72813 L p .707 .577 .707 r
F P
0 g
s
.42468 .68557 m .42954 .70392 L .39947 .71041 L p .707 .577 .707 r
F P
0 g
s
.39947 .71041 m .39461 .69206 L .42468 .68557 L p .707 .577 .707 r
F P
0 g
s
.36863 .71875 m .36377 .7004 L .39461 .69206 L p .707 .577 .707 r
F P
0 g
s
.39461 .69206 m .39947 .71041 L .36863 .71875 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
QGoo6@00Ogoo001mOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001fOol007Qoo`D0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H0071oo`00M7oo1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000K7oo001b
Ool200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH01000FUH00000JWoo001`Ool20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00Igoo001^Ool20005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH2001UOol006eoo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001oogoo069oo`00KGoo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF0P00HWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00Oomoo`1OOol0
06aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00YJEP03001oogoo05ioo`00K7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<007ooOol0GWoo001/Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006ao
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF
0P00Ggoo001/Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH2001OOol006aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP8005moo`00K7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF0P00Ggoo001/Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH2001OOol006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00]JEP8005mo
o`00K7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Ggoo001[Ool00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001OOol006]o
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8005moo`00Jgoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001oogoo05eoo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0GGoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005mo
o`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Ggoo001[Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005moo`00Jgoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001OOol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0005moo`00Jgoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0Ggoo
001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001POol006]oo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00H7oo001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001POol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80061oo`00Jgoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00H7oo001ZOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001P
Ool006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00H7oo001ZOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP80061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00H7oo001Z
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001POol006Yoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<0061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
H7oo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
061oo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00
JGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80065oo`00JGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000=oo`L005Moo`00JGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1@000UYF00<005YFFUH00UYF2000Cgoo001YOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00@005YFFUIJEPL004Qo
o`00JGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@004Aoo`00GGoo40001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000@7oo001G
Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000?Woo001DOol30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF0`00>goo001C
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000i
Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH3000gOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000eOol0059oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8003=oo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P00<Woo001BOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000aOol0055oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP07001JEUYFFUIooeYF0000
0eYF00<007ooOol0;Woo001AOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8002moo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEP00FUH002moo`00DGoo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF0P000UYF1P000UYF00<005YF00000`0027oo1P001UYF00<005YFFUH0
1UYF00@005YFFUIoo`=JEP06001JEUYF001JEP00;goo001AOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH30000
0eYF001JEP05FUH00`00FUIJEP03FUH4000:Ool40002FUH00`00FUIJEP06FUH00`00FUIoo`03FUH0
1`00FUIJEUYF001JEP0002moo`00DGoo0P000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH00003000:Ool4
0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo001AOol00eYF001JEP02FUH40002FUH00`00
FUH000030006Ool00`00FUH000060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF
00<005YFFUH00eYF4@001Woo0P0015YF00<005YFFUH015YF00H005YFFUIJEP00FUH`Ool0051oo`04
001JEP00FUH30005FUH00`00FUIJEP03FUH40002Ool01000FUIJEP001EYF10000UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF009JEP06001JEP00001JEP001UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2`0000=J
EP00FUH01EYF00H005YFFUH005YF000`Ool0051oo`04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF
FUH005YF0002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@001UYF00H005YFFUH005YF000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF009JEP<000IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH00009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00L005YFFUIJEP00
FUH0000`Ool0051oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPL000QJ
EP<00003FUH005YF00EJEP03001JEUYF008000QJEP03001JEUYF00]JEP03001JEUYF00QJEP03001J
EUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFOol0<7oo001@Ool00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0005FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFOol0<7oo001@Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF00@0
05YFFUIJEP8000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF000aOol0051oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUH00000FUH0035oo`00DGoo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP06001JEUYF001JEP00<Goo001BOol00`00FUH00006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH0035oo`00=Woo40003Goo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF001JEP00FUH00008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000b
Ool0035oo`D000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000Moo`03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP800003FUH00000039oo`00;goo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF
000015YF00@005YFFUIJEPT000QJEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP03
FUH00`00FUIJEP02000bOol002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00EJEQ40009JEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009J
EP03001JEP0000=JEPL0009oo`<00003FUH005YF00MJEP03001JEUYF00AJEP04OomJEUYF0007FUH4
0004FUH00`00FUIJEP02000bOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEP000002Ool80004FUH00`00FUIJEP06FUH01000FUIJEUYF
20000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP02FUH01000FUH005YF0P000eYF1P000goo10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00001@0000AJEP00FUIJEP80039oo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP04001JEP000007FUH01000FUIJ
EUYF2`000UYF00<005YFFUH01EYF00=oo`00FUH00UYF1P0015YF00@005YF0000009JEP80039oo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YF00000`000eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF
00@005YFFUIJEP@0039oo`00:goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00<Woo000[Ool20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000bOol002Yoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEPh0039oo`00:Woo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH60003FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP00035oo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF000aOol002Yoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
0080009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000`Ool002Yoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP@0
00MJEP03001JEUYF00IJEP03001JEUYF009JEPd0031oo`00:Woo0P000eYF00@005YFFUIJEQ0000AJ
EP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH80002FUH20002Ool01000FUIJEP001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH000000080009JEP03001JEUYF
00800003FUH005YF00QJEP03001JEUYF00EJEPP0009oo`8000=JEP04001JEUYF000`Ool002Yoo`03
FUH005YF009JEP@0009JEP04001JEP00000:Ool70005FUH00`00FUH00003FUH50005FUH01000FUIJ
EUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH5
0004FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool30005FUH00`00FUH0000`Ool002Uoo`04001J
EP00FUH30005FUH01000FUIJEUYF0`003Woo100000AJEP00FUH0009JEP04001JEUYFFUH50002FUH0
1000FUIJEUYF0P000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00H00003FUH005YF
009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00IJEP8000MJEP03001JEUYF00IJEP@000Yoo`8000=JEP03001JEUYF009JEP80035oo`00:Goo00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP@000ioo`800004FUH000000005FUH01000
FUIJEUYF2@0000Eoo`00FUIJEP0000AJEP<000IJEPl00003FUH0000000UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<000QJEP03001JEUYF00=JEP<0
00Yoo`@000EJEP03001JEUYF009JEP03001oogoo031oo`00:Goo0P0015YF00<005YFFUH00UYF00<0
05YFFUH01UYF00<005YFFUH010002goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
009JEQL000=JEP03001JEUYF009JEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEP00008000Uoo`@0
009JEP03001JEUYF00EJEP04001JEP00000cOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH900000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
0`0027oo10001UYF00<005YFFUH015YF0`00=Goo000YOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP06FUH00`00FUIJEP040009Ool200000eYF001JEP08FUH01000FUIJEUYF0P00>7oo000YOol00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH4000:Ool30004FUH00`00FUIJEP06
FUH01000FUH00000>Woo000YOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF00IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001oo`05
Ool40007FUH00`00FUIJEP05FUH3000lOol002Uoo`03001JEUYF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00MJEP04001JEUYFFUH70002FUH50006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUH000020002
FUH00`00FUH00002Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000oOol002Yoo`04001J
EUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030005FUH0
0`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH01000FUIJEUYF0`000UYF
00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=J
EP<0009JEP03001JEP0000D000IJEP03001JEUYF00MJEP03001JEP000080045oo`00:goo0`001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00UYF10001EYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00@005YF0000
00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40014Ool002eoo`03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP<00004FUH005YFFUH200000eYF
001JEP07FUH00`00FUIJEP04FUH50007FUH01000FUIJEUYF1@001EYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP0000001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01000B7oo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH70019Ool0
031oo`800003FUH005YF00IJEP03001JEUYF00EJEPP0009JEP03001JEUYF00EJEP03001JEUYF0080
00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@000=o
o`D004Qoo`00<Woo0`001EYF2@0015YF00@005YFFUIJEPP0009JEP@000MJEP03001JEUYF009JEP80
009JEP03001JEUYF00AJEP03001JEP0000<000MJEP03001JEUYF00=JEP<000aJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH60007Ool50018Ool0039oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP05FUH00`00FUH000020002Ool2FUH00`00FUIJEP02FUH40002FUH00`00FUIJ
EP06FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0?000<Ool50018Ool002ioo`@000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP03FUH30005Ool2FUH50006FUH0
0`00FUIJEP05FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEUYF10003Goo0`00BGoo000/Ool30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUH000050005
Ool400000eYF001JEP08FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH3001IOol0
02Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00009JEP03001JEUYF009JEP80009JEP800003Ool0000000@000IJEP03001JEUYF00IJEP03
001JEP00008000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEP0005Uoo`00:Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YF
FUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP`005Uoo`00
:Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001J
EUYF00AJEQT000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP04001J
EUYF001IOol002Qoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60006
FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUH00004FUH01@00FUIJEUYF0000F7oo000XOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00@0
05YFFUH005Qoo`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP04001JEUYFFUH60002FUH0
0`00FUIJEP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUH000030006FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00@005YFFUH005Qo
o`00:7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00@005YFFUIJEP80
009JEP04001JEUYFFUH600000eYF001oo`02Ool01000FUIJEP000eYF0P001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YF
FUH00eYF2`000UYF00<007ooOol0EGoo000XOol00`00FUH00003FUH00`00FUIJEP03FUH6000AOol8
0002FUH60002FUH01000FUIJEUYF0P000goo00D005YFFUH005YF00<000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00AJ
EP<0009oo`8000=JEP@005Moo`00:7oo00<005YF00000eYF00<005YF00000`007goo1P0015YF00@0
05YFFUIJEP8000=oo`03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000005FUH00`00Oomo
o`030005FUH00`00FUH0001GOol002Qoo`03001JEP0000=JEP800004FUH00000000ROol600000eYF
001JEP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF0`000eYF
00<005YFFUH00UYF0P00F7oo000XOol01000FUH005YF0P0015YF00<005YF00000`0047oo0`001Woo
1@000UYF200000=JEP0000000goo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0Egoo000XOol00`00FUH000020005FUH00`00FUIJ
EP03FUHI0003FUH400000eYF001JEP03FUH00`00FUIJEP020003Ool00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000FUH00000FWoo000XOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00000010001EYF
00<005YFFUH00eYF00@005YFFUH000=oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000QJEP03001JEUYF00=JEP04001J
EP000005FUH3001LOol002Qoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000Aoo`03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP8000QJEP03001JEUYF00=JEP04001JEP000003FUH2001OOol002Qoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP000goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YFFUH00eYF00D0
05YFFUH005YF0080065oo`00:7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001oo`03Ool00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02001SOol002Qoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF
1`000UYF1@0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo000YOol2
00000eYF001JEP04FUH00`00FUIJEP05FUH500000eYF001JEP08FUH00`00FUIJEP04FUH60004FUH0
1000FUIJEUYF0`000UYF00<007ooOol017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00IWoo000[Ool30004FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUH000000eYF
0P002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P00IWoo000^Ool3000015YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF1@001eYF00<005YFFUH00eYF0`001EYF00<007ooOol02Woo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH05EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0IGoo000a
Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH00`00FUH000030003
FUH00`00FUIJEP02000?Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00
FUIJEP07FUH01000FUIJEUYF0P00J7oo000aOol20005FUH00`00FUIJEP05FUH40004FUH>0007FUH3
000DOol30009FUH00`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP07FUH01000FUH00000JWoo
000`Ool20007FUH00`00FUIJEP02FUH:0003Ool40007FUH00`00FUIJEP03FUH2000IOol40005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0EFUH00`00FUIJEP04FUH5001/Ool002ioo`800003FUH005YF00IJ
EP03001JEP00008000Uoo`@0009JEP03001JEUYF00IJEP03001JEP0000<001moo`@00003FUH005YF
00]JEP03001JEUYF01EJEP03001JEP0000@0075oo`00;Goo00<005YFFUH00UYF00<005YFFUH00eYF
0`0027oo10001UYF00<005YFFUH01EYF0`009goo20001UYF00<005YFFUH045YF1`00MWoo000[Ool3
0004FUH00`00FUH000030007Ool400000eYF001JEP08FUH00`00FUIJEP02FUH2000bOolI001mOol0
02Yoo`04001JEUYF0004FUH20005Ool60006FUH00`00FUIJEP06FUH00`00FUH00002003:Ool002Yo
o`05001JEUYFFUH00002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3003=Ool002]oo`03
001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@00=1oo`00:goo00@0
05YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD00=Aoo`00;7oo0P0000=JEP00FUH015YF
00<005YFFUH01EYF00<005YFFUH01000fGoo000/Ool01000FUIJEP001UYF00@005YFFUIJEPH00=eo
o`00;7oo0P000UYF00@005YFFUIJEPH00>=oo`00;Woo1P00jGoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58685 .73685 m .59278 .68225 L .56178 .677 L p .707 .577 .707 r
F P
0 g
s
.59278 .68225 m .58685 .73685 L .61852 .73909 L p .707 .577 .707 r
F P
0 g
s
.61852 .73909 m .62445 .68449 L .59278 .68225 L p .707 .577 .707 r
F P
0 g
s
.62445 .68449 m .61852 .73909 L .64778 .73811 L p .707 .577 .707 r
F P
0 g
s
.64778 .73811 m .6537 .6835 L .62445 .68449 L p .707 .577 .707 r
F P
0 g
s
.55586 .73161 m .56178 .677 L .53451 .66926 L p .707 .577 .707 r
F P
0 g
s
.56178 .677 m .55586 .73161 L .58685 .73685 L p .707 .577 .707 r
F P
0 g
s
.6537 .6835 m .64778 .73811 L .67175 .734 L p .707 .577 .707 r
F P
0 g
s
.67175 .734 m .67767 .67939 L .6537 .6835 L p .707 .577 .707 r
F P
0 g
s
.52858 .72387 m .53451 .66926 L .51361 .65979 L p .707 .577 .707 r
F P
0 g
s
.53451 .66926 m .52858 .72387 L .55586 .73161 L p .707 .577 .707 r
F P
0 g
s
.58564 .7833 m .5858 .74626 L .55463 .74422 L p .707 .577 .707 r
F P
0 g
s
.5858 .74626 m .58564 .7833 L .61747 .78264 L p .707 .577 .707 r
F P
0 g
s
.61747 .78264 m .61763 .74561 L .5858 .74626 L p .707 .577 .707 r
F P
0 g
s
.61763 .74561 m .61747 .78264 L .64685 .77936 L p .707 .577 .707 r
F P
0 g
s
.64685 .77936 m .64702 .74233 L .61763 .74561 L p .707 .577 .707 r
F P
0 g
s
.55446 .78126 m .55463 .74422 L .52717 .73969 L p .707 .577 .707 r
F P
0 g
s
.55463 .74422 m .55446 .78126 L .58564 .7833 L p .707 .577 .707 r
F P
0 g
s
.64702 .74233 m .64685 .77936 L .67091 .77378 L p .707 .577 .707 r
F P
0 g
s
.67091 .77378 m .67107 .73674 L .64702 .74233 L p .707 .577 .707 r
F P
0 g
s
.59231 .82447 m .58929 .80589 L .55854 .80918 L p .707 .577 .707 r
F P
0 g
s
.58929 .80589 m .59231 .82447 L .62377 .81901 L p .707 .577 .707 r
F P
0 g
s
.62377 .81901 m .62074 .80042 L .58929 .80589 L p .707 .577 .707 r
F P
0 g
s
.67767 .67939 m .67175 .734 L .68809 .72716 L p .707 .577 .707 r
F P
0 g
s
.68809 .72716 m .69401 .67255 L .67767 .67939 L p .707 .577 .707 r
F P
0 g
s
.62074 .80042 m .62377 .81901 L .65285 .81191 L p .707 .577 .707 r
F P
0 g
s
.65285 .81191 m .64982 .79332 L .62074 .80042 L p .707 .577 .707 r
F P
0 g
s
.52717 .73969 m .52701 .77673 L .55446 .78126 L p .707 .577 .707 r
F P
0 g
s
.51361 .65979 m .50769 .71439 L .52858 .72387 L p .707 .577 .707 r
F P
0 g
s
.55854 .80918 m .56156 .82777 L .59231 .82447 L p .707 .577 .707 r
F P
0 g
s
.50769 .71439 m .51361 .65979 L .50115 .64951 L p .707 .577 .707 r
F P
0 g
s
.52701 .77673 m .52717 .73969 L .50611 .73311 L p .707 .577 .707 r
F P
0 g
s
.56156 .82777 m .55854 .80918 L .53151 .80999 L p .707 .577 .707 r
F P
0 g
s
.53151 .80999 m .53453 .82857 L .56156 .82777 L p .707 .577 .707 r
F P
0 g
s
.64982 .79332 m .65285 .81191 L .6767 .80387 L p .707 .577 .707 r
F P
0 g
s
.6767 .80387 m .67368 .78529 L .64982 .79332 L p .707 .577 .707 r
F P
0 g
s
.50611 .73311 m .50595 .77015 L .52701 .77673 L p .707 .577 .707 r
F P
0 g
s
.67107 .73674 m .67091 .77378 L .68728 .76643 L p .707 .577 .707 r
F P
0 g
s
.68728 .76643 m .68744 .72939 L .67107 .73674 L p .707 .577 .707 r
F P
0 g
s
.50115 .64951 m .49522 .70412 L .50769 .71439 L p .707 .577 .707 r
F P
0 g
s
.53453 .82857 m .53151 .80999 L .51083 .80822 L p .707 .577 .707 r
F P
0 g
s
.69401 .67255 m .68809 .72716 L .6952 .71827 L p .707 .577 .707 r
F P
0 g
s
.6952 .71827 m .70113 .66366 L .69401 .67255 L p .707 .577 .707 r
F P
0 g
s
.51083 .80822 m .51386 .8268 L .53453 .82857 L p .707 .577 .707 r
F P
0 g
s
.50595 .77015 m .50611 .73311 L .49352 .72513 L p .707 .577 .707 r
F P
0 g
s
.67368 .78529 m .6767 .80387 L .69301 .79568 L p .707 .577 .707 r
F P
0 g
s
.69301 .79568 m .68998 .7771 L .67368 .78529 L p .707 .577 .707 r
F P
0 g
s
.49522 .70412 m .50115 .64951 L .49834 .63943 L p .707 .577 .707 r
F P
0 g
s
.49352 .72513 m .49336 .76216 L .50595 .77015 L p .707 .577 .707 r
F P
0 g
s
.68744 .72939 m .68728 .76643 L .69436 .75805 L p .707 .577 .707 r
F P
0 g
s
.69436 .75805 m .69452 .72101 L .68744 .72939 L p .707 .577 .707 r
F P
0 g
s
.51386 .8268 m .51083 .80822 L .49854 .80406 L p .707 .577 .707 r
F P
0 g
s
.49834 .63943 m .49241 .69404 L .49522 .70412 L p .707 .577 .707 r
F P
0 g
s
.49854 .80406 m .50157 .82264 L .51386 .8268 L p .707 .577 .707 r
F P
0 g
s
.70113 .66366 m .6952 .71827 L .69238 .70819 L p .707 .577 .707 r
F P
0 g
s
.69238 .70819 m .69831 .65358 L .70113 .66366 L p .707 .577 .707 r
F P
0 g
s
.49336 .76216 m .49352 .72513 L .49063 .71652 L p .707 .577 .707 r
F P
0 g
s
.68998 .7771 m .69301 .79568 L .70016 .78814 L p .707 .577 .707 r
F P
0 g
s
.70016 .78814 m .69713 .76955 L .68998 .7771 L p .707 .577 .707 r
F P
0 g
s
.49241 .69404 m .49834 .63943 L .50545 .63054 L p .707 .577 .707 r
F P
0 g
s
.49063 .71652 m .49046 .75356 L .49336 .76216 L p .707 .577 .707 r
F P
0 g
s
.50545 .63054 m .49952 .68514 L .49241 .69404 L p .707 .577 .707 r
F P
0 g
s
.49046 .75356 m .49063 .71652 L .49771 .70813 L p .707 .577 .707 r
F P
0 g
s
.49771 .70813 m .49755 .74517 L .49046 .75356 L p .707 .577 .707 r
F P
0 g
s
.4941 .82315 m .50516 .32258 L .46117 .31891 L p .707 .577 .707 r
F P
0 g
s
.50157 .82264 m .49854 .80406 L .49584 .7979 L p .707 .577 .707 r
F P
0 g
s
.49584 .7979 m .49887 .81649 L .50157 .82264 L p .707 .577 .707 r
F P
0 g
s
.49952 .68514 m .50545 .63054 L .52179 .6237 L p .707 .577 .707 r
F P
0 g
s
.49887 .81649 m .49584 .7979 L .50299 .79036 L p .707 .577 .707 r
F P
0 g
s
.52179 .6237 m .51586 .6783 L .49952 .68514 L p .707 .577 .707 r
F P
0 g
s
.50299 .79036 m .50602 .80895 L .49887 .81649 L p .707 .577 .707 r
F P
0 g
s
.49755 .74517 m .49771 .70813 L .51408 .70079 L p .707 .577 .707 r
F P
0 g
s
.51586 .6783 m .52179 .6237 L .54576 .61959 L p .707 .577 .707 r
F P
0 g
s
.51408 .70079 m .51392 .73782 L .49755 .74517 L p .707 .577 .707 r
F P
0 g
s
.54576 .61959 m .53983 .67419 L .51586 .6783 L p .707 .577 .707 r
F P
0 g
s
.50602 .80895 m .50299 .79036 L .51929 .78217 L p .707 .577 .707 r
F P
0 g
s
.51929 .78217 m .52232 .80075 L .50602 .80895 L p .707 .577 .707 r
F P
0 g
s
.51392 .73782 m .51408 .70079 L .53813 .6952 L p .707 .577 .707 r
F P
0 g
s
.53813 .6952 m .53797 .73224 L .51392 .73782 L p .707 .577 .707 r
F P
0 g
s
.52232 .80075 m .51929 .78217 L .54315 .77413 L p .707 .577 .707 r
F P
0 g
s
.54315 .77413 m .54618 .79272 L .52232 .80075 L p .707 .577 .707 r
F P
0 g
s
.50516 .32258 m .4941 .82315 L .53903 .82294 L p .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .54576 .61959 L .57408 .61863 L p .707 .577 .707 r
F P
0 g
s
.57408 .61863 m .57501 .6186 L p .57356 .6209 L .707 .577 .707 r
F P
0 g
s
.53983 .67419 m .57408 .61863 L .57356 .6209 L .707 .577 .707 r
F
.53797 .73224 m .53813 .6952 L .56751 .69192 L p F P
0 g
s
.5501 .32237 m .50516 .32258 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.53903 .82294 m .54033 .76419 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.57501 .6186 m .56908 .67321 L .53983 .67419 L p .707 .577 .707 r
F P
0 g
s
.56751 .69192 m .56735 .72896 L .53797 .73224 L p .707 .577 .707 r
F P
0 g
s
.54033 .76419 m .5501 .32237 L p .53625 .7818 L .707 .577 .707 r
F P
0 g
s
.56908 .67321 m .57501 .6186 L .60668 .62084 L p .707 .577 .707 r
F P
0 g
s
.60668 .62084 m .60076 .67545 L .56908 .67321 L p .707 .577 .707 r
F P
0 g
s
.56735 .72896 m .56751 .69192 L .59935 .69127 L p .707 .577 .707 r
F P
0 g
s
.59935 .69127 m .59919 .72831 L .56735 .72896 L p .707 .577 .707 r
F P
0 g
s
.54618 .79272 m .54315 .77413 L .57223 .76703 L p .707 .577 .707 r
F P
0 g
s
.57223 .76703 m .57526 .78562 L .54618 .79272 L p .707 .577 .707 r
F P
0 g
s
.57526 .78562 m .57223 .76703 L .60368 .76157 L p .707 .577 .707 r
F P
0 g
s
.60368 .76157 m .60671 .78015 L .57526 .78562 L p .707 .577 .707 r
F P
0 g
s
.5501 .32237 m .53903 .82294 L .5805 .81887 L p .707 .577 .707 r
F P
0 g
s
.5805 .81887 m .59157 .3183 L .5501 .32237 L p .707 .577 .707 r
F P
0 g
s
.4501 .81948 m .46117 .31891 L .42241 .31173 L p .707 .577 .707 r
F P
0 g
s
.46117 .31891 m .4501 .81948 L .4941 .82315 L p .707 .577 .707 r
F P
0 g
s
.69452 .72101 m .69436 .75805 L .69146 .74944 L p .707 .577 .707 r
F P
0 g
s
.69146 .74944 m .69163 .7124 L .69452 .72101 L p .707 .577 .707 r
F P
0 g
s
.63768 .62609 m .63175 .6807 L .60076 .67545 L p .707 .577 .707 r
F P
0 g
s
.60076 .67545 m .60668 .62084 L .63768 .62609 L p .707 .577 .707 r
F P
0 g
s
.63052 .69331 m .63036 .73035 L .59919 .72831 L p .707 .577 .707 r
F P
0 g
s
.59919 .72831 m .59935 .69127 L .63052 .69331 L p .707 .577 .707 r
F P
0 g
s
.63443 .75827 m .63746 .77686 L .60671 .78015 L p .707 .577 .707 r
F P
0 g
s
.60671 .78015 m .60368 .76157 L .63443 .75827 L p .707 .577 .707 r
F P
0 g
s
.59157 .3183 m .5805 .81887 L .61446 .81134 L p .707 .577 .707 r
F P
0 g
s
.61446 .81134 m .62552 .31077 L .59157 .3183 L p .707 .577 .707 r
F P
0 g
s
.69831 .65358 m .69238 .70819 L .67992 .69791 L p .707 .577 .707 r
F P
0 g
s
.67992 .69791 m .68585 .6433 L .69831 .65358 L p .707 .577 .707 r
F P
0 g
s
.69713 .76955 m .70016 .78814 L .69746 .78198 L p .707 .577 .707 r
F P
0 g
s
.69746 .78198 m .69443 .7634 L .69713 .76955 L p .707 .577 .707 r
F P
0 g
s
.41135 .8123 m .42241 .31173 L .3927 .30173 L p .707 .577 .707 r
F P
0 g
s
.42241 .31173 m .41135 .8123 L .4501 .81948 L p .707 .577 .707 r
F P
0 g
s
.24384 .72972 m .24977 .67512 L .21878 .66987 L p .707 .577 .707 r
F P
0 g
s
.24977 .67512 m .24384 .72972 L .27551 .73196 L p .707 .577 .707 r
F P
0 g
s
.27551 .73196 m .28144 .67736 L .24977 .67512 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69163 .7124 m .69146 .74944 L .67887 .74146 L p .707 .577 .707 r
F P
0 g
s
.67887 .74146 m .67903 .70442 L .69163 .7124 L p .707 .577 .707 r
F P
0 g
s
.28144 .67736 m .27551 .73196 L .30477 .73098 L p .707 .577 .707 r
F P
0 g
s
.30477 .73098 m .31069 .67637 L .28144 .67736 L p .707 .577 .707 r
F P
0 g
s
.21285 .72448 m .21878 .66987 L .1915 .66213 L p .707 .577 .707 r
F P
0 g
s
.21878 .66987 m .21285 .72448 L .24384 .72972 L p .707 .577 .707 r
F P
0 g
s
.66495 .63383 m .65903 .68843 L .63175 .6807 L p .707 .577 .707 r
F P
0 g
s
.63175 .6807 m .63768 .62609 L .66495 .63383 L p .707 .577 .707 r
F P
0 g
s
.65798 .69784 m .65782 .73488 L .63036 .73035 L p .707 .577 .707 r
F P
0 g
s
.63036 .73035 m .63052 .69331 L .65798 .69784 L p .707 .577 .707 r
F P
0 g
s
.63746 .77686 m .63443 .75827 L .66147 .75747 L p .707 .577 .707 r
F P
0 g
s
.62552 .31077 m .61446 .81134 L .63756 .8011 L p .707 .577 .707 r
F P
0 g
s
.66147 .75747 m .66449 .77605 L .63746 .77686 L p .707 .577 .707 r
F P
0 g
s
.63756 .8011 m .64863 .30053 L .62552 .31077 L p .707 .577 .707 r
F P
0 g
s
.68585 .6433 m .67992 .69791 L .65903 .68843 L p .707 .577 .707 r
F P
0 g
s
.65903 .68843 m .66495 .63383 L .68585 .6433 L p .707 .577 .707 r
F P
0 g
s
.69443 .7634 m .69746 .78198 L .68517 .77782 L p .707 .577 .707 r
F P
0 g
s
.68517 .77782 m .68214 .75924 L .69443 .7634 L p .707 .577 .707 r
F P
0 g
s
.31069 .67637 m .30477 .73098 L .32874 .72687 L p .707 .577 .707 r
F P
0 g
s
.32874 .72687 m .33466 .67226 L .31069 .67637 L p .707 .577 .707 r
F P
0 g
s
.18557 .71674 m .1915 .66213 L .1706 .65266 L p .707 .577 .707 r
F P
0 g
s
.1915 .66213 m .18557 .71674 L .21285 .72448 L p .707 .577 .707 r
F P
0 g
s
.38163 .8023 m .3927 .30173 L .37493 .2899 L p .707 .577 .707 r
F P
0 g
s
.3927 .30173 m .38163 .8023 L .41135 .8123 L p .707 .577 .707 r
F P
0 g
s
.24263 .79763 m .24279 .76059 L .21162 .75855 L p .707 .577 .707 r
F P
0 g
s
.24279 .76059 m .24263 .79763 L .27446 .79698 L p .707 .577 .707 r
F P
0 g
s
.27446 .79698 m .27463 .75994 L .24279 .76059 L p .707 .577 .707 r
F P
0 g
s
.27463 .75994 m .27446 .79698 L .30385 .7937 L p .707 .577 .707 r
F P
0 g
s
.30385 .7937 m .30401 .75666 L .27463 .75994 L p .707 .577 .707 r
F P
0 g
s
.67903 .70442 m .67887 .74146 L .65782 .73488 L p .707 .577 .707 r
F P
0 g
s
.65782 .73488 m .65798 .69784 L .67903 .70442 L p .707 .577 .707 r
F P
0 g
s
.21146 .79559 m .21162 .75855 L .18416 .75402 L p .707 .577 .707 r
F P
0 g
s
.21162 .75855 m .21146 .79559 L .24263 .79763 L p .707 .577 .707 r
F P
0 g
s
.33466 .67226 m .32874 .72687 L .34508 .72003 L p .707 .577 .707 r
F P
0 g
s
.34508 .72003 m .351 .66543 L .33466 .67226 L p .707 .577 .707 r
F P
0 g
s
.1706 .65266 m .16468 .70727 L .18557 .71674 L p .707 .577 .707 r
F P
0 g
s
.2493 .83071 m .24628 .81213 L .21553 .81542 L p .707 .577 .707 r
F P
0 g
s
.24628 .81213 m .2493 .83071 L .28076 .82525 L p .707 .577 .707 r
F P
0 g
s
.28076 .82525 m .27773 .80666 L .24628 .81213 L p .707 .577 .707 r
F P
0 g
s
.27773 .80666 m .28076 .82525 L .30984 .81815 L p .707 .577 .707 r
F P
0 g
s
.30984 .81815 m .30681 .79956 L .27773 .80666 L p .707 .577 .707 r
F P
0 g
s
.30401 .75666 m .30385 .7937 L .3279 .78811 L p .707 .577 .707 r
F P
0 g
s
.3279 .78811 m .32806 .75108 L .30401 .75666 L p .707 .577 .707 r
F P
0 g
s
.16468 .70727 m .1706 .65266 L .15814 .64238 L p .707 .577 .707 r
F P
0 g
s
.21553 .81542 m .21856 .83401 L .2493 .83071 L p .707 .577 .707 r
F P
0 g
s
.18416 .75402 m .184 .79106 L .21146 .79559 L p .707 .577 .707 r
F P
0 g
s
.68214 .75924 m .68517 .77782 L .66449 .77605 L p .707 .577 .707 r
F P
0 g
s
.66449 .77605 m .66147 .75747 L .68214 .75924 L p .707 .577 .707 r
F P
0 g
s
.64863 .30053 m .63756 .8011 L .64757 .78913 L p .707 .577 .707 r
F P
0 g
s
.64757 .78913 m .65863 .28856 L .64863 .30053 L p .707 .577 .707 r
F P
0 g
s
.21856 .83401 m .21553 .81542 L .1885 .81623 L p .707 .577 .707 r
F P
0 g
s
.184 .79106 m .18416 .75402 L .16311 .74744 L p .707 .577 .707 r
F P
0 g
s
.1885 .81623 m .19152 .83481 L .21856 .83401 L p .707 .577 .707 r
F P
0 g
s
.30681 .79956 m .30984 .81815 L .3337 .81011 L p .707 .577 .707 r
F P
0 g
s
.3337 .81011 m .33067 .79153 L .30681 .79956 L p .707 .577 .707 r
F P
0 g
s
.16311 .74744 m .16294 .78448 L .184 .79106 L p .707 .577 .707 r
F P
0 g
s
.15814 .64238 m .15221 .69699 L .16468 .70727 L p .707 .577 .707 r
F P
0 g
s
.36386 .79047 m .37493 .2899 L .37084 .27739 L p .707 .577 .707 r
F P
0 g
s
.37493 .2899 m .36386 .79047 L .38163 .8023 L p .707 .577 .707 r
F P
0 g
s
.32806 .75108 m .3279 .78811 L .34427 .78077 L p .707 .577 .707 r
F P
0 g
s
.34427 .78077 m .34443 .74373 L .32806 .75108 L p .707 .577 .707 r
F P
0 g
s
.351 .66543 m .34508 .72003 L .35219 .71114 L p .707 .577 .707 r
F P
0 g
s
.35219 .71114 m .35812 .65653 L .351 .66543 L p .707 .577 .707 r
F P
0 g
s
.19152 .83481 m .1885 .81623 L .16782 .81446 L p .707 .577 .707 r
F P
0 g
s
.16782 .81446 m .17085 .83304 L .19152 .83481 L p .707 .577 .707 r
F P
0 g
s
.15221 .69699 m .15814 .64238 L .15533 .6323 L p .707 .577 .707 r
F P
0 g
s
.33067 .79153 m .3337 .81011 L .35 .80192 L p .707 .577 .707 r
F P
0 g
s
.35 .80192 m .34697 .78333 L .33067 .79153 L p .707 .577 .707 r
F P
0 g
s
.16294 .78448 m .16311 .74744 L .15051 .73946 L p .707 .577 .707 r
F P
0 g
s
.15051 .73946 m .15035 .7765 L .16294 .78448 L p .707 .577 .707 r
F P
0 g
s
.65455 .27605 m .64348 .77662 L .62571 .76479 L p .707 .577 .707 r
F P
0 g
s
.64489 .62236 m .64505 .62086 L p .63835 .55747 L .707 .577 .707 r
F P
0 g
s
.65863 .28856 m .64757 .78913 L .64456 .77994 L p .707 .577 .707 r
F P
0 g
s
.64469 .73756 m .65863 .28856 L .64456 .77994 L .707 .577 .707 r
F
.64348 .77662 m .65455 .27605 L .65863 .28856 L p F P
0 g
s
.64505 .62086 m .65082 .56775 L .64523 .56314 L p .707 .577 .707 r
F P
0 g
s
.64523 .56314 m .63835 .55747 L p .64505 .62086 L .707 .577 .707 r
F P
0 g
s
.64456 .77994 m .64348 .77662 L p .64469 .73756 L .707 .577 .707 r
F P
0 g
s
.15533 .6323 m .1494 .68691 L .15221 .69699 L p .707 .577 .707 r
F P
0 g
s
.34443 .74373 m .34427 .78077 L .35135 .77238 L p .707 .577 .707 r
F P
0 g
s
.35135 .77238 m .35151 .73534 L .34443 .74373 L p .707 .577 .707 r
F P
0 g
s
.17085 .83304 m .16782 .81446 L .15553 .8103 L p .707 .577 .707 r
F P
0 g
s
.15553 .8103 m .15856 .82888 L .17085 .83304 L p .707 .577 .707 r
F P
0 g
s
.35812 .65653 m .35219 .71114 L .34938 .70106 L p .707 .577 .707 r
F P
0 g
s
.34938 .70106 m .3553 .64645 L .35812 .65653 L p .707 .577 .707 r
F P
0 g
s
.34697 .78333 m .35 .80192 L .35715 .79438 L p .707 .577 .707 r
F P
0 g
s
.35715 .79438 m .35412 .77579 L .34697 .78333 L p .707 .577 .707 r
F P
0 g
s
.1494 .68691 m .15533 .6323 L .16244 .62341 L p .707 .577 .707 r
F P
0 g
s
.15035 .7765 m .15051 .73946 L .14762 .73086 L p .707 .577 .707 r
F P
0 g
s
.37084 .27739 m .35978 .77796 L .36386 .79047 L p .707 .577 .707 r
F P
0 g
s
.35978 .77796 m .37084 .27739 L .38085 .26543 L p .707 .577 .707 r
F P
0 g
s
.14762 .73086 m .14745 .76789 L .15035 .7765 L p .707 .577 .707 r
F P
0 g
s
.15856 .82888 m .15553 .8103 L .15283 .80414 L p .707 .577 .707 r
F P
0 g
s
.16244 .62341 m .15651 .67801 L .1494 .68691 L p .707 .577 .707 r
F P
0 g
s
.35151 .73534 m .35135 .77238 L .34845 .76377 L p .707 .577 .707 r
F P
0 g
s
.34845 .76377 m .34862 .72674 L .35151 .73534 L p .707 .577 .707 r
F P
0 g
s
.15283 .80414 m .15586 .82273 L .15856 .82888 L p .707 .577 .707 r
F P
0 g
s
.3553 .64645 m .34938 .70106 L .33691 .69078 L p .707 .577 .707 r
F P
0 g
s
.33691 .69078 m .34284 .63617 L .3553 .64645 L p .707 .577 .707 r
F P
0 g
s
.35412 .77579 m .35715 .79438 L .35445 .78822 L p .707 .577 .707 r
F P
0 g
s
.35445 .78822 m .35142 .76964 L .35412 .77579 L p .707 .577 .707 r
F P
0 g
s
.15651 .67801 m .16244 .62341 L .17878 .61657 L p .707 .577 .707 r
F P
0 g
s
.62571 .76479 m .63678 .26422 L .65455 .27605 L p .707 .577 .707 r
F P
0 g
s
.14745 .76789 m .14762 .73086 L .1547 .72247 L p .707 .577 .707 r
F P
0 g
s
.1547 .72247 m .15454 .75951 L .14745 .76789 L p .707 .577 .707 r
F P
0 g
s
.36978 .766 m .38085 .26543 L .40395 .25518 L p .707 .577 .707 r
F P
0 g
s
.38085 .26543 m .36978 .766 L .35978 .77796 L p .707 .577 .707 r
F P
0 g
s
.17878 .61657 m .17285 .67117 L .15651 .67801 L p .707 .577 .707 r
F P
0 g
s
.34862 .72674 m .34845 .76377 L .33586 .75579 L p .707 .577 .707 r
F P
0 g
s
.33586 .75579 m .33602 .71875 L .34862 .72674 L p .707 .577 .707 r
F P
0 g
s
.15586 .82273 m .15283 .80414 L .15998 .7966 L p .707 .577 .707 r
F P
0 g
s
.34284 .63617 m .33691 .69078 L .31602 .6813 L p .707 .577 .707 r
F P
0 g
s
.31602 .6813 m .32195 .6267 L .34284 .63617 L p .707 .577 .707 r
F P
0 g
s
.15998 .7966 m .16301 .81518 L .15586 .82273 L p .707 .577 .707 r
F P
0 g
s
.17285 .67117 m .17878 .61657 L .20275 .61246 L p .707 .577 .707 r
F P
0 g
s
.35142 .76964 m .35445 .78822 L .34216 .78406 L p .707 .577 .707 r
F P
0 g
s
.34216 .78406 m .33913 .76548 L .35142 .76964 L p .707 .577 .707 r
F P
0 g
s
.15454 .75951 m .1547 .72247 L .17107 .71512 L p .707 .577 .707 r
F P
0 g
s
.63678 .26422 m .62571 .76479 L .596 .75479 L p .707 .577 .707 r
F P
0 g
s
.596 .75479 m .60706 .25422 L .63678 .26422 L p .707 .577 .707 r
F P
0 g
s
.17107 .71512 m .17091 .75216 L .15454 .75951 L p .707 .577 .707 r
F P
0 g
s
.32195 .6267 m .31602 .6813 L .28874 .67357 L p .707 .577 .707 r
F P
0 g
s
.28874 .67357 m .29467 .61896 L .32195 .6267 L p .707 .577 .707 r
F P
0 g
s
.20275 .61246 m .19682 .66706 L .17285 .67117 L p .707 .577 .707 r
F P
0 g
s
.33602 .71875 m .33586 .75579 L .31481 .74921 L p .707 .577 .707 r
F P
0 g
s
.31481 .74921 m .31497 .71218 L .33602 .71875 L p .707 .577 .707 r
F P
0 g
s
.19682 .66706 m .20275 .61246 L .232 .61147 L p .707 .577 .707 r
F P
0 g
s
.16301 .81518 m .15998 .7966 L .17628 .78841 L p .707 .577 .707 r
F P
0 g
s
.17628 .78841 m .17931 .80699 L .16301 .81518 L p .707 .577 .707 r
F P
0 g
s
.40395 .25518 m .39288 .75575 L .36978 .766 L p .707 .577 .707 r
F P
0 g
s
.39288 .75575 m .40395 .25518 L .43791 .24766 L p .707 .577 .707 r
F P
0 g
s
.17091 .75216 m .17107 .71512 L .19512 .70954 L p .707 .577 .707 r
F P
0 g
s
.29467 .61896 m .28874 .67357 L .25775 .66832 L p .707 .577 .707 r
F P
0 g
s
.25775 .66832 m .26367 .61371 L .29467 .61896 L p .707 .577 .707 r
F P
0 g
s
.33913 .76548 m .34216 .78406 L .32148 .78229 L p .707 .577 .707 r
F P
0 g
s
.32148 .78229 m .31846 .76371 L .33913 .76548 L p .707 .577 .707 r
F P
0 g
s
.72405 .64481 m .72998 .59021 L .69899 .58496 L p .707 .577 .707 r
F P
0 g
s
.72998 .59021 m .72405 .64481 L .75573 .64705 L p .707 .577 .707 r
F P
0 g
s
.75573 .64705 m .76165 .59245 L .72998 .59021 L p .707 .577 .707 r
F P
0 g
s
.22607 .66608 m .232 .61147 L .26367 .61371 L p .707 .577 .707 r
F P
0 g
s
.232 .61147 m .22607 .66608 L .19682 .66706 L p .707 .577 .707 r
F P
0 g
s
.76165 .59245 m .75573 .64705 L .78498 .64607 L p .707 .577 .707 r
F P
0 g
s
.78498 .64607 m .79091 .59147 L .76165 .59245 L p .707 .577 .707 r
F P
0 g
s
.26367 .61371 m .25775 .66832 L .22607 .66608 L p .707 .577 .707 r
F P
0 g
s
.69306 .63957 m .69899 .58496 L .67171 .57722 L p .707 .577 .707 r
F P
0 g
s
.69899 .58496 m .69306 .63957 L .72405 .64481 L p .707 .577 .707 r
F P
0 g
s
.19512 .70954 m .19496 .74657 L .17091 .75216 L p .707 .577 .707 r
F P
0 g
s
.31497 .71218 m .31481 .74921 L .28735 .74468 L p .707 .577 .707 r
F P
0 g
s
.28735 .74468 m .28751 .70764 L .31497 .71218 L p .707 .577 .707 r
F P
0 g
s
.60706 .25422 m .596 .75479 L .55724 .74761 L p .707 .577 .707 r
F P
0 g
s
.55724 .74761 m .56831 .24704 L .60706 .25422 L p .707 .577 .707 r
F P
0 g
s
.17931 .80699 m .17628 .78841 L .20014 .78037 L p .707 .577 .707 r
F P
0 g
s
.79091 .59147 m .78498 .64607 L .80895 .64196 L p .707 .577 .707 r
F P
0 g
s
.80895 .64196 m .81488 .58735 L .79091 .59147 L p .707 .577 .707 r
F P
0 g
s
.19496 .74657 m .19512 .70954 L .2245 .70626 L p .707 .577 .707 r
F P
0 g
s
.20014 .78037 m .20317 .79896 L .17931 .80699 L p .707 .577 .707 r
F P
0 g
s
.66578 .63183 m .67171 .57722 L .65082 .56775 L p .707 .577 .707 r
F P
0 g
s
.67171 .57722 m .66578 .63183 L .69306 .63957 L p .707 .577 .707 r
F P
0 g
s
.72284 .69126 m .723 .65422 L .69183 .65218 L p .707 .577 .707 r
F P
0 g
s
.723 .65422 m .72284 .69126 L .75468 .6906 L p .707 .577 .707 r
F P
0 g
s
.75468 .6906 m .75484 .65357 L .723 .65422 L p .707 .577 .707 r
F P
0 g
s
.42684 .74823 m .43791 .24766 L .47938 .24359 L p .707 .577 .707 r
F P
0 g
s
.43791 .24766 m .42684 .74823 L .39288 .75575 L p .707 .577 .707 r
F P
0 g
s
.31846 .76371 m .32148 .78229 L .29445 .7831 L p .707 .577 .707 r
F P
0 g
s
.29445 .7831 m .29142 .76451 L .31846 .76371 L p .707 .577 .707 r
F P
0 g
s
.75484 .65357 m .75468 .6906 L .78406 .68733 L p .707 .577 .707 r
F P
0 g
s
.78406 .68733 m .78422 .65029 L .75484 .65357 L p .707 .577 .707 r
F P
0 g
s
.28751 .70764 m .28735 .74468 L .25618 .74264 L p .707 .577 .707 r
F P
0 g
s
.25618 .74264 m .25634 .70561 L .28751 .70764 L p .707 .577 .707 r
F P
0 g
s
.69167 .68922 m .69183 .65218 L .66437 .64765 L p .707 .577 .707 r
F P
0 g
s
.69183 .65218 m .69167 .68922 L .72284 .69126 L p .707 .577 .707 r
F P
0 g
s
.2245 .70626 m .22434 .74329 L .19496 .74657 L p .707 .577 .707 r
F P
0 g
s
.22434 .74329 m .2245 .70626 L .25634 .70561 L p .707 .577 .707 r
F P
0 g
s
.25634 .70561 m .25618 .74264 L .22434 .74329 L p .707 .577 .707 r
F P
0 g
s
.56831 .24704 m .55724 .74761 L .51324 .74395 L p .707 .577 .707 r
F P
0 g
s
.51324 .74395 m .52431 .24338 L .56831 .24704 L p .707 .577 .707 r
F P
0 g
s
.78422 .65029 m .78406 .68733 L .80811 .68174 L p .707 .577 .707 r
F P
0 g
s
.80811 .68174 m .80827 .6447 L .78422 .65029 L p .707 .577 .707 r
F P
0 g
s
.20317 .79896 m .20014 .78037 L .22922 .77327 L p .707 .577 .707 r
F P
0 g
s
.72952 .73243 m .72649 .71385 L .69575 .71715 L p .707 .577 .707 r
F P
0 g
s
.72649 .71385 m .72952 .73243 L .76097 .72697 L p .707 .577 .707 r
F P
0 g
s
.76097 .72697 m .75795 .70839 L .72649 .71385 L p .707 .577 .707 r
F P
0 g
s
.81488 .58735 m .80895 .64196 L .82529 .63512 L p .707 .577 .707 r
F P
0 g
s
.82529 .63512 m .83122 .58052 L .81488 .58735 L p .707 .577 .707 r
F P
0 g
s
.75795 .70839 m .76097 .72697 L .79005 .71987 L p .707 .577 .707 r
F P
0 g
s
.79005 .71987 m .78703 .70129 L .75795 .70839 L p .707 .577 .707 r
F P
0 g
s
.66437 .64765 m .66421 .68469 L .69167 .68922 L p .707 .577 .707 r
F P
0 g
s
.65082 .56775 m .64489 .62236 L .66578 .63183 L p .707 .577 .707 r
F P
0 g
s
.22922 .77327 m .23225 .79186 L .20317 .79896 L p .707 .577 .707 r
F P
0 g
s
.69575 .71715 m .69877 .73573 L .72952 .73243 L p .707 .577 .707 r
F P
0 g
s
.46831 .74416 m .47938 .24359 L .52431 .24338 L p .707 .577 .707 r
F P
0 g
s
.47938 .24359 m .46831 .74416 L .42684 .74823 L p .707 .577 .707 r
F P
0 g
s
.29142 .76451 m .29445 .7831 L .2637 .78639 L p .707 .577 .707 r
F P
0 g
s
.2637 .78639 m .26068 .76781 L .29142 .76451 L p .707 .577 .707 r
F P
0 g
s
.66421 .68469 m .66437 .64765 L .64332 .64107 L p .707 .577 .707 r
F P
0 g
s
.69877 .73573 m .69575 .71715 L .66871 .71795 L p .707 .577 .707 r
F P
0 g
s
.52431 .24338 m .51324 .74395 L .46831 .74416 L p .707 .577 .707 r
F P
0 g
s
.23225 .79186 m .22922 .77327 L .26068 .76781 L p .707 .577 .707 r
F P
0 g
s
.66871 .71795 m .67173 .73653 L .69877 .73573 L p .707 .577 .707 r
F P
0 g
s
.26068 .76781 m .2637 .78639 L .23225 .79186 L p .707 .577 .707 r
F P
0 g
s
.78703 .70129 m .79005 .71987 L .81391 .71183 L p .707 .577 .707 r
F P
0 g
s
.81391 .71183 m .81089 .69325 L .78703 .70129 L p .707 .577 .707 r
F P
0 g
s
.64332 .64107 m .64316 .67811 L .66421 .68469 L p .707 .577 .707 r
F P
0 g
s
.80827 .6447 m .80811 .68174 L .82448 .67439 L p .707 .577 .707 r
F P
0 g
s
.82448 .67439 m .82464 .63736 L .80827 .6447 L p .707 .577 .707 r
F P
0 g
s
.63835 .55747 m .63243 .61208 L .64489 .62236 L p .707 .577 .707 r
F P
0 g
s
.67173 .73653 m .66871 .71795 L .64804 .71618 L p .707 .577 .707 r
F P
0 g
s
.83122 .58052 m .82529 .63512 L .8324 .62623 L p .707 .577 .707 r
F P
0 g
s
.8324 .62623 m .83833 .57162 L .83122 .58052 L p .707 .577 .707 r
F P
0 g
s
.64804 .71618 m .65106 .73477 L .67173 .73653 L p .707 .577 .707 r
F P
0 g
s
.64316 .67811 m .64332 .64107 L .63073 .63309 L p .707 .577 .707 r
F P
0 g
s
.81089 .69325 m .81391 .71183 L .83021 .70364 L p .707 .577 .707 r
F P
0 g
s
.83021 .70364 m .82719 .68506 L .81089 .69325 L p .707 .577 .707 r
F P
0 g
s
.63243 .61208 m .63835 .55747 L .63554 .54739 L p .707 .577 .707 r
F P
0 g
s
.63073 .63309 m .63056 .67012 L .64316 .67811 L p .707 .577 .707 r
F P
0 g
s
.82464 .63736 m .82448 .67439 L .83156 .66601 L p .707 .577 .707 r
F P
0 g
s
.83156 .66601 m .83173 .62897 L .82464 .63736 L p .707 .577 .707 r
F P
0 g
s
.65106 .73477 m .64804 .71618 L .63575 .71202 L p .707 .577 .707 r
F P
0 g
s
.63554 .54739 m .62961 .602 L .63243 .61208 L p .707 .577 .707 r
F P
0 g
s
.63575 .71202 m .63877 .7306 L .65106 .73477 L p .707 .577 .707 r
F P
0 g
s
.83833 .57162 m .8324 .62623 L .82959 .61615 L p .707 .577 .707 r
F P
0 g
s
.82959 .61615 m .83552 .56154 L .83833 .57162 L p .707 .577 .707 r
F P
0 g
s
.63056 .67012 m .63073 .63309 L .62783 .62448 L p .707 .577 .707 r
F P
0 g
s
.82719 .68506 m .83021 .70364 L .83736 .6961 L p .707 .577 .707 r
F P
0 g
s
.83736 .6961 m .83434 .67752 L .82719 .68506 L p .707 .577 .707 r
F P
0 g
s
.62961 .602 m .63554 .54739 L .64265 .5385 L p .707 .577 .707 r
F P
0 g
s
.62783 .62448 m .62767 .66152 L .63056 .67012 L p .707 .577 .707 r
F P
0 g
s
.83173 .62897 m .83156 .66601 L .82867 .6574 L p .707 .577 .707 r
F P
0 g
s
.82867 .6574 m .82883 .62036 L .83173 .62897 L p .707 .577 .707 r
F P
0 g
s
.63877 .7306 m .63575 .71202 L .63305 .70586 L p .707 .577 .707 r
F P
0 g
s
.64265 .5385 m .63672 .5931 L .62961 .602 L p .707 .577 .707 r
F P
0 g
s
.63305 .70586 m .63607 .72445 L .63877 .7306 L p .707 .577 .707 r
F P
0 g
s
.83552 .56154 m .82959 .61615 L .81713 .60587 L p .707 .577 .707 r
F P
0 g
s
.81713 .60587 m .82305 .55126 L .83552 .56154 L p .707 .577 .707 r
F P
0 g
s
.83434 .67752 m .83736 .6961 L .83466 .68995 L p .707 .577 .707 r
F P
0 g
s
.83466 .68995 m .83164 .67136 L .83434 .67752 L p .707 .577 .707 r
F P
0 g
s
.62767 .66152 m .62783 .62448 L .63491 .6161 L p .707 .577 .707 r
F P
0 g
s
.63672 .5931 m .64265 .5385 L .65899 .53166 L p .707 .577 .707 r
F P
0 g
s
.63491 .6161 m .63475 .65313 L .62767 .66152 L p .707 .577 .707 r
F P
0 g
s
.38104 .63768 m .38697 .58308 L .35598 .57783 L p .707 .577 .707 r
F P
0 g
s
.38697 .58308 m .38104 .63768 L .41272 .63992 L p .707 .577 .707 r
F P
0 g
s
.41272 .63992 m .41864 .58532 L .38697 .58308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82883 .62036 m .82867 .6574 L .81608 .64942 L p .707 .577 .707 r
F P
0 g
s
.81608 .64942 m .81624 .61238 L .82883 .62036 L p .707 .577 .707 r
F P
0 g
s
.41864 .58532 m .41272 .63992 L .44197 .63894 L p .707 .577 .707 r
F P
0 g
s
.44197 .63894 m .4479 .58434 L .41864 .58532 L p .707 .577 .707 r
F P
0 g
s
.63607 .72445 m .63305 .70586 L .6402 .69832 L p .707 .577 .707 r
F P
0 g
s
.35005 .63244 m .35598 .57783 L .3287 .57009 L p .707 .577 .707 r
F P
0 g
s
.35598 .57783 m .35005 .63244 L .38104 .63768 L p .707 .577 .707 r
F P
0 g
s
.65899 .53166 m .65306 .58626 L .63672 .5931 L p .707 .577 .707 r
F P
0 g
s
.6402 .69832 m .64322 .71691 L .63607 .72445 L p .707 .577 .707 r
F P
0 g
s
.82305 .55126 m .81713 .60587 L .79623 .59639 L p .707 .577 .707 r
F P
0 g
s
.79623 .59639 m .80216 .54179 L .82305 .55126 L p .707 .577 .707 r
F P
0 g
s
.63475 .65313 m .63491 .6161 L .65128 .60875 L p .707 .577 .707 r
F P
0 g
s
.83164 .67136 m .83466 .68995 L .82237 .68578 L p .707 .577 .707 r
F P
0 g
s
.82237 .68578 m .81935 .6672 L .83164 .67136 L p .707 .577 .707 r
F P
0 g
s
.4479 .58434 m .44197 .63894 L .46594 .63483 L p .707 .577 .707 r
F P
0 g
s
.46594 .63483 m .47187 .58022 L .4479 .58434 L p .707 .577 .707 r
F P
0 g
s
.65306 .58626 m .65899 .53166 L .68296 .52755 L p .707 .577 .707 r
F P
0 g
s
.32277 .6247 m .3287 .57009 L .30781 .56062 L p .707 .577 .707 r
F P
0 g
s
.3287 .57009 m .32277 .6247 L .35005 .63244 L p .707 .577 .707 r
F P
0 g
s
.65128 .60875 m .65112 .64579 L .63475 .65313 L p .707 .577 .707 r
F P
0 g
s
.37983 .70559 m .37999 .66856 L .34882 .66652 L p .707 .577 .707 r
F P
0 g
s
.37999 .66856 m .37983 .70559 L .41167 .70494 L p .707 .577 .707 r
F P
0 g
s
.41167 .70494 m .41183 .6679 L .37999 .66856 L p .707 .577 .707 r
F P
0 g
s
.41183 .6679 m .41167 .70494 L .44105 .70166 L p .707 .577 .707 r
F P
0 g
s
.44105 .70166 m .44121 .66462 L .41183 .6679 L p .707 .577 .707 r
F P
0 g
s
.81624 .61238 m .81608 .64942 L .79502 .64284 L p .707 .577 .707 r
F P
0 g
s
.79502 .64284 m .79518 .6058 L .81624 .61238 L p .707 .577 .707 r
F P
0 g
s
.80216 .54179 m .79623 .59639 L .76895 .58866 L p .707 .577 .707 r
F P
0 g
s
.76895 .58866 m .77488 .53405 L .80216 .54179 L p .707 .577 .707 r
F P
0 g
s
.34866 .70355 m .34882 .66652 L .32136 .66199 L p .707 .577 .707 r
F P
0 g
s
.34882 .66652 m .34866 .70355 L .37983 .70559 L p .707 .577 .707 r
F P
0 g
s
.68296 .52755 m .67704 .58215 L .65306 .58626 L p .707 .577 .707 r
F P
0 g
s
.64322 .71691 m .6402 .69832 L .6565 .69013 L p .707 .577 .707 r
F P
0 g
s
.47187 .58022 m .46594 .63483 L .48228 .62799 L p .707 .577 .707 r
F P
0 g
s
.48228 .62799 m .48821 .57339 L .47187 .58022 L p .707 .577 .707 r
F P
0 g
s
.67704 .58215 m .68296 .52755 L .71222 .52656 L p .707 .577 .707 r
F P
0 g
s
.30781 .56062 m .30188 .61523 L .32277 .6247 L p .707 .577 .707 r
F P
0 g
s
.6565 .69013 m .65952 .70872 L .64322 .71691 L p .707 .577 .707 r
F P
0 g
s
.38651 .73867 m .38348 .72009 L .35274 .72338 L p .707 .577 .707 r
F P
0 g
s
.38348 .72009 m .38651 .73867 L .41796 .73321 L p .707 .577 .707 r
F P
0 g
s
.41796 .73321 m .41494 .71462 L .38348 .72009 L p .707 .577 .707 r
F P
0 g
s
.41494 .71462 m .41796 .73321 L .44704 .72611 L p .707 .577 .707 r
F P
0 g
s
.44704 .72611 m .44402 .70752 L .41494 .71462 L p .707 .577 .707 r
F P
0 g
s
.65112 .64579 m .65128 .60875 L .67534 .60316 L p .707 .577 .707 r
F P
0 g
s
.44121 .66462 m .44105 .70166 L .4651 .69607 L p .707 .577 .707 r
F P
0 g
s
.4651 .69607 m .46526 .65904 L .44121 .66462 L p .707 .577 .707 r
F P
0 g
s
.30188 .61523 m .30781 .56062 L .29534 .55034 L p .707 .577 .707 r
F P
0 g
s
.35274 .72338 m .35576 .74197 L .38651 .73867 L p .707 .577 .707 r
F P
0 g
s
.32136 .66199 m .3212 .69902 L .34866 .70355 L p .707 .577 .707 r
F P
0 g
s
.81935 .6672 m .82237 .68578 L .8017 .68402 L p .707 .577 .707 r
F P
0 g
s
.8017 .68402 m .79867 .66543 L .81935 .6672 L p .707 .577 .707 r
F P
0 g
s
.35576 .74197 m .35274 .72338 L .3257 .72419 L p .707 .577 .707 r
F P
0 g
s
.77488 .53405 m .76895 .58866 L .73796 .58341 L p .707 .577 .707 r
F P
0 g
s
.73796 .58341 m .74389 .52881 L .77488 .53405 L p .707 .577 .707 r
F P
0 g
s
.3212 .69902 m .32136 .66199 L .30031 .65541 L p .707 .577 .707 r
F P
0 g
s
.70629 .58117 m .71222 .52656 L .74389 .52881 L p .707 .577 .707 r
F P
0 g
s
.71222 .52656 m .70629 .58117 L .67704 .58215 L p .707 .577 .707 r
F P
0 g
s
.3257 .72419 m .32872 .74277 L .35576 .74197 L p .707 .577 .707 r
F P
0 g
s
.67534 .60316 m .67517 .6402 L .65112 .64579 L p .707 .577 .707 r
F P
0 g
s
.44402 .70752 m .44704 .72611 L .4709 .71807 L p .707 .577 .707 r
F P
0 g
s
.4709 .71807 m .46788 .69949 L .44402 .70752 L p .707 .577 .707 r
F P
0 g
s
.74389 .52881 m .73796 .58341 L .70629 .58117 L p .707 .577 .707 r
F P
0 g
s
.79518 .6058 m .79502 .64284 L .76756 .63831 L p .707 .577 .707 r
F P
0 g
s
.76756 .63831 m .76772 .60127 L .79518 .6058 L p .707 .577 .707 r
F P
0 g
s
.30031 .65541 m .30015 .69244 L .3212 .69902 L p .707 .577 .707 r
F P
0 g
s
.29534 .55034 m .28942 .60495 L .30188 .61523 L p .707 .577 .707 r
F P
0 g
s
.67517 .6402 m .67534 .60316 L .70472 .59988 L p .707 .577 .707 r
F P
0 g
s
.65952 .70872 m .6565 .69013 L .68036 .68209 L p .707 .577 .707 r
F P
0 g
s
.46526 .65904 m .4651 .69607 L .48147 .68873 L p .707 .577 .707 r
F P
0 g
s
.48147 .68873 m .48163 .65169 L .46526 .65904 L p .707 .577 .707 r
F P
0 g
s
.48821 .57339 m .48228 .62799 L .48939 .6191 L p .707 .577 .707 r
F P
0 g
s
.48939 .6191 m .49532 .56449 L .48821 .57339 L p .707 .577 .707 r
F P
0 g
s
.32872 .74277 m .3257 .72419 L .30503 .72242 L p .707 .577 .707 r
F P
0 g
s
.68036 .68209 m .68338 .70068 L .65952 .70872 L p .707 .577 .707 r
F P
0 g
s
.30503 .72242 m .30805 .74101 L .32872 .74277 L p .707 .577 .707 r
F P
0 g
s
.79867 .66543 m .8017 .68402 L .77466 .68482 L p .707 .577 .707 r
F P
0 g
s
.77466 .68482 m .77164 .66623 L .79867 .66543 L p .707 .577 .707 r
F P
0 g
s
.76772 .60127 m .76756 .63831 L .73639 .63627 L p .707 .577 .707 r
F P
0 g
s
.73639 .63627 m .73655 .59923 L .76772 .60127 L p .707 .577 .707 r
F P
0 g
s
.28942 .60495 m .29534 .55034 L .29253 .54026 L p .707 .577 .707 r
F P
0 g
s
.70472 .59988 m .70455 .63692 L .67517 .6402 L p .707 .577 .707 r
F P
0 g
s
.46788 .69949 m .4709 .71807 L .4872 .70988 L p .707 .577 .707 r
F P
0 g
s
.4872 .70988 m .48418 .6913 L .46788 .69949 L p .707 .577 .707 r
F P
0 g
s
.30015 .69244 m .30031 .65541 L .28772 .64742 L p .707 .577 .707 r
F P
0 g
s
.70455 .63692 m .70472 .59988 L .73655 .59923 L p .707 .577 .707 r
F P
0 g
s
.73655 .59923 m .73639 .63627 L .70455 .63692 L p .707 .577 .707 r
F P
0 g
s
.68338 .70068 m .68036 .68209 L .70944 .675 L p .707 .577 .707 r
F P
0 g
s
.28772 .64742 m .28755 .68446 L .30015 .69244 L p .707 .577 .707 r
F P
0 g
s
.70944 .675 m .71246 .69358 L .68338 .70068 L p .707 .577 .707 r
F P
0 g
s
.77164 .66623 m .77466 .68482 L .74391 .68811 L p .707 .577 .707 r
F P
0 g
s
.74391 .68811 m .74089 .66953 L .77164 .66623 L p .707 .577 .707 r
F P
0 g
s
.29253 .54026 m .2866 .59487 L .28942 .60495 L p .707 .577 .707 r
F P
0 g
s
.48163 .65169 m .48147 .68873 L .48855 .68034 L p .707 .577 .707 r
F P
0 g
s
.48855 .68034 m .48872 .64331 L .48163 .65169 L p .707 .577 .707 r
F P
0 g
s
.30805 .74101 m .30503 .72242 L .29274 .71826 L p .707 .577 .707 r
F P
0 g
s
.71246 .69358 m .70944 .675 L .74089 .66953 L p .707 .577 .707 r
F P
0 g
s
.29274 .71826 m .29576 .73684 L .30805 .74101 L p .707 .577 .707 r
F P
0 g
s
.49532 .56449 m .48939 .6191 L .48658 .60902 L p .707 .577 .707 r
F P
0 g
s
.48658 .60902 m .49251 .55441 L .49532 .56449 L p .707 .577 .707 r
F P
0 g
s
.74089 .66953 m .74391 .68811 L .71246 .69358 L p .707 .577 .707 r
F P
0 g
s
.48418 .6913 m .4872 .70988 L .49435 .70234 L p .707 .577 .707 r
F P
0 g
s
.49435 .70234 m .49133 .68375 L .48418 .6913 L p .707 .577 .707 r
F P
0 g
s
.2866 .59487 m .29253 .54026 L .29964 .53137 L p .707 .577 .707 r
F P
0 g
s
.28755 .68446 m .28772 .64742 L .28482 .63882 L p .707 .577 .707 r
F P
0 g
s
.28482 .63882 m .28466 .67585 L .28755 .68446 L p .707 .577 .707 r
F P
0 g
s
.29576 .73684 m .29274 .71826 L .29004 .7121 L p .707 .577 .707 r
F P
0 g
s
.29964 .53137 m .29371 .58597 L .2866 .59487 L p .707 .577 .707 r
F P
0 g
s
.48872 .64331 m .48855 .68034 L .48566 .67174 L p .707 .577 .707 r
F P
0 g
s
.48566 .67174 m .48582 .6347 L .48872 .64331 L p .707 .577 .707 r
F P
0 g
s
.29004 .7121 m .29306 .73069 L .29576 .73684 L p .707 .577 .707 r
F P
0 g
s
.49251 .55441 m .48658 .60902 L .47412 .59874 L p .707 .577 .707 r
F P
0 g
s
.47412 .59874 m .48004 .54413 L .49251 .55441 L p .707 .577 .707 r
F P
0 g
s
.49133 .68375 m .49435 .70234 L .49165 .69619 L p .707 .577 .707 r
F P
0 g
s
.49165 .69619 m .48863 .6776 L .49133 .68375 L p .707 .577 .707 r
F P
0 g
s
.29371 .58597 m .29964 .53137 L .31598 .52453 L p .707 .577 .707 r
F P
0 g
s
.28466 .67585 m .28482 .63882 L .2919 .63043 L p .707 .577 .707 r
F P
0 g
s
.2919 .63043 m .29174 .66747 L .28466 .67585 L p .707 .577 .707 r
F P
0 g
s
.31598 .52453 m .31005 .57913 L .29371 .58597 L p .707 .577 .707 r
F P
0 g
s
.48582 .6347 m .48566 .67174 L .47306 .66375 L p .707 .577 .707 r
F P
0 g
s
.47306 .66375 m .47323 .62672 L .48582 .6347 L p .707 .577 .707 r
F P
0 g
s
.29306 .73069 m .29004 .7121 L .29719 .70456 L p .707 .577 .707 r
F P
0 g
s
.48004 .54413 m .47412 .59874 L .45322 .58926 L p .707 .577 .707 r
F P
0 g
s
.45322 .58926 m .45915 .53466 L .48004 .54413 L p .707 .577 .707 r
F P
0 g
s
.29719 .70456 m .30021 .72315 L .29306 .73069 L p .707 .577 .707 r
F P
0 g
s
.31005 .57913 m .31598 .52453 L .33995 .52042 L p .707 .577 .707 r
F P
0 g
s
.48863 .6776 m .49165 .69619 L .47936 .69202 L p .707 .577 .707 r
F P
0 g
s
.47936 .69202 m .47634 .67344 L .48863 .6776 L p .707 .577 .707 r
F P
0 g
s
.29174 .66747 m .2919 .63043 L .30827 .62308 L p .707 .577 .707 r
F P
0 g
s
.30827 .62308 m .30811 .66012 L .29174 .66747 L p .707 .577 .707 r
F P
0 g
s
.45915 .53466 m .45322 .58926 L .42594 .58153 L p .707 .577 .707 r
F P
0 g
s
.42594 .58153 m .43187 .52692 L .45915 .53466 L p .707 .577 .707 r
F P
0 g
s
.33995 .52042 m .33402 .57502 L .31005 .57913 L p .707 .577 .707 r
F P
0 g
s
.47323 .62672 m .47306 .66375 L .45201 .65717 L p .707 .577 .707 r
F P
0 g
s
.45201 .65717 m .45217 .62014 L .47323 .62672 L p .707 .577 .707 r
F P
0 g
s
.33402 .57502 m .33995 .52042 L .36921 .51943 L p .707 .577 .707 r
F P
0 g
s
.30021 .72315 m .29719 .70456 L .31349 .69637 L p .707 .577 .707 r
F P
0 g
s
.31349 .69637 m .31651 .71496 L .30021 .72315 L p .707 .577 .707 r
F P
0 g
s
.30811 .66012 m .30827 .62308 L .33232 .6175 L p .707 .577 .707 r
F P
0 g
s
.43187 .52692 m .42594 .58153 L .39495 .57628 L p .707 .577 .707 r
F P
0 g
s
.39495 .57628 m .40088 .52168 L .43187 .52692 L p .707 .577 .707 r
F P
0 g
s
.47634 .67344 m .47936 .69202 L .45869 .69025 L p .707 .577 .707 r
F P
0 g
s
.45869 .69025 m .45566 .67167 L .47634 .67344 L p .707 .577 .707 r
F P
0 g
s
.36328 .57404 m .36921 .51943 L .40088 .52168 L p .707 .577 .707 r
F P
0 g
s
.36921 .51943 m .36328 .57404 L .33402 .57502 L p .707 .577 .707 r
F P
0 g
s
.40088 .52168 m .39495 .57628 L .36328 .57404 L p .707 .577 .707 r
F P
0 g
s
.33232 .6175 m .33216 .65454 L .30811 .66012 L p .707 .577 .707 r
F P
0 g
s
.45217 .62014 m .45201 .65717 L .42455 .65264 L p .707 .577 .707 r
F P
0 g
s
.42455 .65264 m .42471 .61561 L .45217 .62014 L p .707 .577 .707 r
F P
0 g
s
.31651 .71496 m .31349 .69637 L .33735 .68833 L p .707 .577 .707 r
F P
0 g
s
.33216 .65454 m .33232 .6175 L .36171 .61422 L p .707 .577 .707 r
F P
0 g
s
.33735 .68833 m .34037 .70692 L .31651 .71496 L p .707 .577 .707 r
F P
0 g
s
.45566 .67167 m .45869 .69025 L .43165 .69106 L p .707 .577 .707 r
F P
0 g
s
.43165 .69106 m .42863 .67247 L .45566 .67167 L p .707 .577 .707 r
F P
0 g
s
.42471 .61561 m .42455 .65264 L .39338 .6506 L p .707 .577 .707 r
F P
0 g
s
.39338 .6506 m .39354 .61357 L .42471 .61561 L p .707 .577 .707 r
F P
0 g
s
.36171 .61422 m .36154 .65126 L .33216 .65454 L p .707 .577 .707 r
F P
0 g
s
.36154 .65126 m .36171 .61422 L .39354 .61357 L p .707 .577 .707 r
F P
0 g
s
.39354 .61357 m .39338 .6506 L .36154 .65126 L p .707 .577 .707 r
F P
0 g
s
.34037 .70692 m .33735 .68833 L .36642 .68123 L p .707 .577 .707 r
F P
0 g
s
.36642 .68123 m .36945 .69982 L .34037 .70692 L p .707 .577 .707 r
F P
0 g
s
.42863 .67247 m .43165 .69106 L .4009 .69435 L p .707 .577 .707 r
F P
0 g
s
.4009 .69435 m .39788 .67577 L .42863 .67247 L p .707 .577 .707 r
F P
0 g
s
.36945 .69982 m .36642 .68123 L .39788 .67577 L p .707 .577 .707 r
F P
0 g
s
.39788 .67577 m .4009 .69435 L .36945 .69982 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Eoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007=oo`00LWoo0`00
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000Kgoo001`
Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000
FUH00000KGoo001^Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0`00JWoo001/Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2
001XOol006]oo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Ioo`00JWoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P00I7oo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00HWoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo
001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0H7oo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HGoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00HGoo001YOol0
1000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJ
EP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol01000FUIJEP0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo001YOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0001QOol006Uoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00065oo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF0000HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HGoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFOol0HGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000HWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
HWoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HWoo001X
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001ROol006Eoo`P000=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00GGoo20000eYF00<005YFFUH00UYF
2@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001IOol40003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH6000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000<Ool8001>Ool005Moo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004Ool80003FUH0
0`00FUIJEP02FUH90015Ool005Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000040003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH6000oOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000mOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00>goo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000hOol005=oo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00002000eOol005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP0000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000cOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Woo
001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0
059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002moo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00;Woo001BOol20004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00;Woo001BOol20003FUH500000eYF
001JEP04FUH80005FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool0055oo`04001JEP00FUH20006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH40005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP04001JEUYFFUHG0006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00DGoo00H005YF000005YF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<00000eYF001JEP04FUH01`00FUIJ
EUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000=JEPD00003
FUH005YF00AJEPL000Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF
;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20005FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
Ool40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000eYF
00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
1EYF00@005YFFUIJEP8002moo`00DGoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YF
FUH00eYF4P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002moo`00DWoo
00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJEP03001JEUYF009J
EPP0009JEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;goo001BOol01000FUIJEP001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH60002FUH30002FUH00`00FUH0000_Ool003ioo`P000eoo`<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH40004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01@00FUH005YF
0000;goo000fOol80003FUH00`00FUIJEP02FUH70008Ool00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P000UYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP000000031oo`00
<Woo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010001Goo0P000eYF00<005YF
00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF1@00<7oo000`Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40003Ool500000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000AJEP8000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF0080031oo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00000025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP80031o
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH70003Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00<7oo000[Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000eYF1P0015YF0P001goo1`0015YF00<005YFFUH00UYF2`0000=JEP00FUH00UYF0P00<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000=JEPD0009JEP04001JEP00000<Ool@0003
FUH30003FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF00<005YFFUH015YF00<005YF
FUH00P0000=JEP000000<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF20000UYF00<007oo0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF00001@0015YF00D005YFFUIJEP0000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000eYF1@001EYF00@005YFFUIJEP800005Ool005YFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH300000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000`Ool0
02]oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00FUH20004FUH500000eYF001JEP02FUH200001Goo001JEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
031oo`00:goo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00@005YFFUIJEPT0009JEP03001JEUYF00=JEPl000EJEP04001JEUYF0002FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHE00000eYF001oo`0_Ool002]oo`8000=JEPD00003
FUH005YF00AJEPL0009oo`T0009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30007FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000`Ool002Yoo`04
001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002Ool40003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUHD00000eYF001JEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000
FUIJEUYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
031oo`00:Woo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000_Ool002Yoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
00000eYF001JEP02FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000_Ool002Yoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF1@00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF3P000eYF00D005YFFUIJEP0002moo`00
:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00H005YF000005YF0005FUH01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEPD000Ioo`D0009JEP8002ioo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YF0000
0P0025YF00<005YFFUH01UYF00<005YFFUH00UYF500000=JEP00FUH015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01UYF
00<005YFFUH03P0037oo0P000UYF1000;Woo000[Ool01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP0000000UYF00<005YFFUH01eYF
00<005YFFUH015YF1P001eYF00<005YFFUH00eYF1@0000=JEP0000000P0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH0
15YF100067oo0P0015YF00@005YFFUH002ioo`00:goo00@005YFFUH000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00MJEP03001JEUYF
00@000EJEP03001JEUYF00EJEP03001JEP0000<00003FUH0000000=JEP04001JEP000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF
00<005YFFUH0100067oo100000=JEP00FUH00eYF00<005YF0000;goo000/Ool00`00FUH00006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP05
FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP02FUH50003FUH30005FUH00`00FUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH4
00000eYF001oo`0FOol30005FUH00`00FUIJEP02FUH2000`Ool002eoo`8000EJEP03001JEUYF00EJ
EQ40009JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF01L000IJEP80009JEP03
001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00005FUH00`00FUH00004000015YF0000000057oo100000=JEP00FUH01UYF00D005YFFUIJEP00
035oo`00;Woo0P0015YF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF
00<005YFFUH00eYF100000AJEP00Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00@000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP00009JEP04001JEUYFFUH30004FUH5000=Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000<Woo000`Ool600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP03FUH00`00FUH000030003FUH01@00FUH007oo00000UYF00<005YFFUH00eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00H005YF000005YF0005FUH00`00FUIJEP020004Ool9
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000dOol002moo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP80009JEP04001JEUYFFUH50004FUH20002Ool01000FUIJEP00
1EYF00<005YFFUH01P001UYF00<005YFFUH015YF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000UYF1@001UYF2@0015YF00<005YFFUH00`000eYF00<005YFFUH0
1UYF00<005YF00000`00=goo000]Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUH000020004FUH200000eYF00000003Ool00`00FUIJEP09
0003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP070003FUH00`00FUIJEP06FUH00`00FUH0
00040003FUH00`00FUIJEP04FUH3000kOol002]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUHD0004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUH000040003FUH00`00FUIJEP04000nOol002Yoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01eYF1P0000=JEP0000000`00@Woo000YOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000040017Ool002Uoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6000;FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH7001;Ool002Uoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000180
059oo`00:Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00UYF3P002EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000100000AJEP00000000=JEP8005Moo`00:Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF2@0000EJEP00Oomoo`00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00EJEP04001JEUYF0002FUH2001GOol002Uoo`03001JEP0000AJEP04001JEUYFFUH8000GOol40002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000Woo00@005YFFUH000EJEP03001JEUYF00EJEPX000]J
EP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH4001GOol002Uoo`03001JEP0000=JEPD002=oo`D000=JEP05001JEUYFFUH00002Ool01000
FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF
1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00UYF0`00Egoo
000YOol01000FUH005YF0P0015YF1@0087oo20000eYF00@007ooOol0009JEP03001JEUYF00=JEP<0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
00<000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<005Moo`00:Goo00H005YF
000005YF0005FUH01000FUIJEUYF2@004Woo1@001EYF00@005YFFUH0009JEP04001oogoo0002FUH0
1000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF00002@0000AJEP00FUH005Moo`00
:Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4P000eYF00<005YFFUH0
15YF00@005YFFUIJEP<0009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0
0003FUH00`00FUIJEP02FUH4001HOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEQ@00005FUH007ooOol00002FUH200000eYF001JEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000
FUH0000015YF00<005YF00000eYF00<005YFFUH00UYF00<005YFFUH00P00Egoo000YOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH000000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEP0000=JEP03001JEUYF009JEP04001JEUYFFUH2001FOol002Uoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP02001FOol002Yoo`05001JEUYFFUH00005FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUH00000Ool00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001@000eYF00D0
05YFFUIJEP0005Ioo`00:goo00@005YFFUH000EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH00000Ool000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<000Aoo`D0009JEP03001oogoo05Aoo`00;7oo0`001EYF
00<005YF00000P0025YF00<005YFFUH01UYF00<005YFFUH00UYF4`000UYF00<007oo00001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000000Moo`80009JEP@005Eoo`00;Woo0`000eYF0P00
0UYF00<005YFFUH01eYF00<005YFFUH015YF1P001eYF00<005YFFUH015YF00<005YF00001P0000=o
o`00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Eoo`8000AJEP04001JEP00
001EOol0035oo`<000AJEP03001JEUYF00MJEP03001JEUYF00@000EJEP03001JEUYF00EJEP04001J
EUYFFUH700000eYF001JEP0200000goo001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00
FUIJEP00Ool0100000=JEP00FUH00eYF00@005YFFUH005Eoo`00;goo0P0000=JEP00FUH01EYF00<0
05YFFUH015YF1@002EYF00<005YFFUH00UYF1`000goo0P000eYF00@005YFFUH0009oo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020005FUH00`00FUIJEP02FUH3001FOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF01L000Ioo`@00003FUH005YF00=JEP8000Aoo`800003FUH0
05YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP05001JEUYFFUH0001HOol002aoo`8000AJ
EP03001JEUYF00=JEP@001Uoo`@000EJEP03001JEUYF009JEP8000Ioo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00EJEP04001JEP00001IOol002]oo`03001JEP0000AJEP03001JEP0000<0
01Uoo`@0009JEP03001JEUYF00AJEP04001JEUYFFUH20008Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF
00<005YFFUH00eYF0`00Fgoo000[Ool01000FUIJEP000eYF0P005goo1P001UYF00<005YFFUH015YF
00@005YF000000aoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUH00003001NOol002]oo`05001JEUYF
001JEP02000@Ool90003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000BOol40009FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH600000eYF001JEP05FUH3001R
Ool002aoo`03001JEP0000<000Qoo`P000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00
008001Uoo`@000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H0
00=JEP03001JEUYF00@006Eoo`00;7oo0P0000AJEP00FUIJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0021oo`@00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF
00AJEPh00003FUH0000000<006Uoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01000:7oo20001UYF00<005YFFUH015YF3@0025YF1`00
KWoo000/Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH5000dOol=0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001`Ool002eoo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@004Aooa<007Uoo`00;goo10000eYF
00<005YFFUH01EYF00<005YFFUH00UYF1P00e7oo000cOol@003JOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60505 .76176 m .59912 .70588 L .56813 .70737 L p .707 .577 .707 r
F P
0 g
s
.59912 .70588 m .60505 .76176 L .63672 .75793 L p .707 .577 .707 r
F P
0 g
s
.63672 .75793 m .63079 .70205 L .59912 .70588 L p .707 .577 .707 r
F P
0 g
s
.63079 .70205 m .63672 .75793 L .66597 .75213 L p .707 .577 .707 r
F P
0 g
s
.66597 .75213 m .66004 .69625 L .63079 .70205 L p .707 .577 .707 r
F P
0 g
s
.57405 .76324 m .56813 .70737 L .54085 .70636 L p .707 .577 .707 r
F P
0 g
s
.56813 .70737 m .57405 .76324 L .60505 .76176 L p .707 .577 .707 r
F P
0 g
s
.66004 .69625 m .66597 .75213 L .68994 .74492 L p .707 .577 .707 r
F P
0 g
s
.68994 .74492 m .68402 .68905 L .66004 .69625 L p .707 .577 .707 r
F P
0 g
s
.54085 .70636 m .54678 .76224 L .57405 .76324 L p .707 .577 .707 r
F P
0 g
s
.60662 .83642 m .60645 .79935 L .57528 .79759 L p .707 .577 .707 r
F P
0 g
s
.60645 .79935 m .60662 .83642 L .63845 .83552 L p .707 .577 .707 r
F P
0 g
s
.63845 .83552 m .63829 .79845 L .60645 .79935 L p .707 .577 .707 r
F P
0 g
s
.54678 .76224 m .54085 .70636 L .51996 .70296 L p .707 .577 .707 r
F P
0 g
s
.63829 .79845 m .63845 .83552 L .66783 .83204 L p .707 .577 .707 r
F P
0 g
s
.66783 .83204 m .66767 .79497 L .63829 .79845 L p .707 .577 .707 r
F P
0 g
s
.57545 .83466 m .57528 .79759 L .54783 .79333 L p .707 .577 .707 r
F P
0 g
s
.57528 .79759 m .57545 .83466 L .60662 .83642 L p .707 .577 .707 r
F P
0 g
s
.68402 .68905 m .68994 .74492 L .70628 .73702 L p .707 .577 .707 r
F P
0 g
s
.70628 .73702 m .70036 .68114 L .68402 .68905 L p .707 .577 .707 r
F P
0 g
s
.51996 .70296 m .52588 .75884 L .54678 .76224 L p .707 .577 .707 r
F P
0 g
s
.66767 .79497 m .66783 .83204 L .69189 .82633 L p .707 .577 .707 r
F P
0 g
s
.69189 .82633 m .69172 .78925 L .66767 .79497 L p .707 .577 .707 r
F P
0 g
s
.54783 .79333 m .54799 .8304 L .57545 .83466 L p .707 .577 .707 r
F P
0 g
s
.59909 .87855 m .60212 .86062 L .57137 .85361 L p .707 .577 .707 r
F P
0 g
s
.60212 .86062 m .59909 .87855 L .63055 .88238 L p .707 .577 .707 r
F P
0 g
s
.63055 .88238 m .63357 .86445 L .60212 .86062 L p .707 .577 .707 r
F P
0 g
s
.54799 .8304 m .54783 .79333 L .52677 .787 L p .707 .577 .707 r
F P
0 g
s
.63357 .86445 m .63055 .88238 L .65963 .88266 L p .707 .577 .707 r
F P
0 g
s
.65963 .88266 m .66265 .86472 L .63357 .86445 L p .707 .577 .707 r
F P
0 g
s
.56835 .87155 m .57137 .85361 L .54433 .84412 L p .707 .577 .707 r
F P
0 g
s
.57137 .85361 m .56835 .87155 L .59909 .87855 L p .707 .577 .707 r
F P
0 g
s
.52588 .75884 m .51996 .70296 L .50749 .6975 L p .707 .577 .707 r
F P
0 g
s
.54433 .84412 m .54131 .86205 L .56835 .87155 L p .707 .577 .707 r
F P
0 g
s
.52677 .787 m .52693 .82408 L .54799 .8304 L p .707 .577 .707 r
F P
0 g
s
.69172 .78925 m .69189 .82633 L .70826 .81894 L p .707 .577 .707 r
F P
0 g
s
.70826 .81894 m .70809 .78186 L .69172 .78925 L p .707 .577 .707 r
F P
0 g
s
.66265 .86472 m .65963 .88266 L .68349 .87936 L p .707 .577 .707 r
F P
0 g
s
.68349 .87936 m .68651 .86142 L .66265 .86472 L p .707 .577 .707 r
F P
0 g
s
.70036 .68114 m .70628 .73702 L .71339 .72919 L p .707 .577 .707 r
F P
0 g
s
.71339 .72919 m .70747 .67331 L .70036 .68114 L p .707 .577 .707 r
F P
0 g
s
.54131 .86205 m .54433 .84412 L .52366 .83306 L p .707 .577 .707 r
F P
0 g
s
.50749 .6975 m .51342 .75337 L .52588 .75884 L p .707 .577 .707 r
F P
0 g
s
.52366 .83306 m .52064 .85099 L .54131 .86205 L p .707 .577 .707 r
F P
0 g
s
.52693 .82408 m .52677 .787 L .51418 .77922 L p .707 .577 .707 r
F P
0 g
s
.51342 .75337 m .50749 .6975 L .50468 .69051 L p .707 .577 .707 r
F P
0 g
s
.51418 .77922 m .51434 .81629 L .52693 .82408 L p .707 .577 .707 r
F P
0 g
s
.68651 .86142 m .68349 .87936 L .69979 .8728 L p .707 .577 .707 r
F P
0 g
s
.69979 .8728 m .70281 .85486 L .68651 .86142 L p .707 .577 .707 r
F P
0 g
s
.52064 .85099 m .52366 .83306 L .51137 .82152 L p .707 .577 .707 r
F P
0 g
s
.70809 .78186 m .70826 .81894 L .71534 .81059 L p .707 .577 .707 r
F P
0 g
s
.71534 .81059 m .71518 .77352 L .70809 .78186 L p .707 .577 .707 r
F P
0 g
s
.51137 .82152 m .50835 .83945 L .52064 .85099 L p .707 .577 .707 r
F P
0 g
s
.70747 .67331 m .71339 .72919 L .71058 .7222 L p .707 .577 .707 r
F P
0 g
s
.71058 .7222 m .70465 .66633 L .70747 .67331 L p .707 .577 .707 r
F P
0 g
s
.50468 .69051 m .5106 .74639 L .51342 .75337 L p .707 .577 .707 r
F P
0 g
s
.51434 .81629 m .51418 .77922 L .51128 .77074 L p .707 .577 .707 r
F P
0 g
s
.48675 .82039 m .47568 .31745 L .43169 .31575 L p .707 .577 .707 r
F P
0 g
s
.51128 .77074 m .51144 .80781 L .51434 .81629 L p .707 .577 .707 r
F P
0 g
s
.5106 .74639 m .50468 .69051 L .51179 .68268 L p .707 .577 .707 r
F P
0 g
s
.50835 .83945 m .51137 .82152 L .50867 .81063 L p .707 .577 .707 r
F P
0 g
s
.50867 .81063 m .50565 .82856 L .50835 .83945 L p .707 .577 .707 r
F P
0 g
s
.51179 .68268 m .51772 .73856 L .5106 .74639 L p .707 .577 .707 r
F P
0 g
s
.51144 .80781 m .51128 .77074 L .51836 .7624 L p .707 .577 .707 r
F P
0 g
s
.51836 .7624 m .51853 .79947 L .51144 .80781 L p .707 .577 .707 r
F P
0 g
s
.51772 .73856 m .51179 .68268 L .52813 .67478 L p .707 .577 .707 r
F P
0 g
s
.50565 .82856 m .50867 .81063 L .51582 .80146 L p .707 .577 .707 r
F P
0 g
s
.51582 .80146 m .5128 .81939 L .50565 .82856 L p .707 .577 .707 r
F P
0 g
s
.52813 .67478 m .53406 .73066 L .51772 .73856 L p .707 .577 .707 r
F P
0 g
s
.51853 .79947 m .51836 .7624 L .53473 .75501 L p .707 .577 .707 r
F P
0 g
s
.53473 .75501 m .5349 .79208 L .51853 .79947 L p .707 .577 .707 r
F P
0 g
s
.5128 .81939 m .51582 .80146 L .53212 .7949 L p .707 .577 .707 r
F P
0 g
s
.53212 .7949 m .5291 .81283 L .5128 .81939 L p .707 .577 .707 r
F P
0 g
s
.5291 .81283 m .53212 .7949 L .55598 .79159 L p .707 .577 .707 r
F P
0 g
s
.55598 .79159 m .55296 .80953 L .5291 .81283 L p .707 .577 .707 r
F P
0 g
s
.47568 .31745 m .48675 .82039 L .53169 .81841 L p .707 .577 .707 r
F P
0 g
s
.53406 .73066 m .52813 .67478 L .5521 .66757 L p .707 .577 .707 r
F P
0 g
s
.53169 .81841 m .52062 .31546 L .47568 .31745 L p .707 .577 .707 r
F P
0 g
s
.70281 .85486 m .69979 .8728 L .70694 .86362 L p .707 .577 .707 r
F P
0 g
s
.70694 .86362 m .70996 .84569 L .70281 .85486 L p .707 .577 .707 r
F P
0 g
s
.5521 .66757 m .55803 .72345 L .53406 .73066 L p .707 .577 .707 r
F P
0 g
s
.5349 .79208 m .53473 .75501 L .55879 .7493 L p .707 .577 .707 r
F P
0 g
s
.55803 .72345 m .5521 .66757 L .58135 .66177 L p .707 .577 .707 r
F P
0 g
s
.55879 .7493 m .55895 .78637 L .5349 .79208 L p .707 .577 .707 r
F P
0 g
s
.58135 .66177 m .58728 .71765 L .55803 .72345 L p .707 .577 .707 r
F P
0 g
s
.55895 .78637 m .55879 .7493 L .58817 .74582 L p .707 .577 .707 r
F P
0 g
s
.58817 .74582 m .58833 .78289 L .55895 .78637 L p .707 .577 .707 r
F P
0 g
s
.55296 .80953 m .55598 .79159 L .58506 .79187 L p .707 .577 .707 r
F P
0 g
s
.58506 .79187 m .58204 .80981 L .55296 .80953 L p .707 .577 .707 r
F P
0 g
s
.52062 .31546 m .53169 .81841 L .57316 .81294 L p .707 .577 .707 r
F P
0 g
s
.57316 .81294 m .56209 .30999 L .52062 .31546 L p .707 .577 .707 r
F P
0 g
s
.71518 .77352 m .71534 .81059 L .71244 .80212 L p .707 .577 .707 r
F P
0 g
s
.71244 .80212 m .71228 .76504 L .71518 .77352 L p .707 .577 .707 r
F P
0 g
s
.44276 .81869 m .43169 .31575 L .39293 .31053 L p .707 .577 .707 r
F P
0 g
s
.43169 .31575 m .44276 .81869 L .48675 .82039 L p .707 .577 .707 r
F P
0 g
s
.70465 .66633 m .71058 .7222 L .69812 .71674 L p .707 .577 .707 r
F P
0 g
s
.69812 .71674 m .69219 .66087 L .70465 .66633 L p .707 .577 .707 r
F P
0 g
s
.26204 .69526 m .25611 .63938 L .22512 .64087 L p .707 .577 .707 r
F P
0 g
s
.25611 .63938 m .26204 .69526 L .29371 .69143 L p .707 .577 .707 r
F P
0 g
s
.29371 .69143 m .28778 .63555 L .25611 .63938 L p .707 .577 .707 r
F P
0 g
s
.58728 .71765 m .58135 .66177 L .61303 .65794 L p .707 .577 .707 r
F P
0 g
s
.61303 .65794 m .61895 .71382 L .58728 .71765 L p .707 .577 .707 r
F P
0 g
s
.58833 .78289 m .58817 .74582 L .62 .74491 L p .707 .577 .707 r
F P
0 g
s
.62 .74491 m .62017 .78199 L .58833 .78289 L p .707 .577 .707 r
F P
0 g
s
.58204 .80981 m .58506 .79187 L .61651 .7957 L p .707 .577 .707 r
F P
0 g
s
.61651 .7957 m .61349 .81363 L .58204 .80981 L p .707 .577 .707 r
F P
0 g
s
.56209 .30999 m .57316 .81294 L .60711 .80451 L p .707 .577 .707 r
F P
0 g
s
.60711 .80451 m .59604 .30156 L .56209 .30999 L p .707 .577 .707 r
F P
0 g
s
.28778 .63555 m .29371 .69143 L .32296 .68563 L p .707 .577 .707 r
F P
0 g
s
.32296 .68563 m .31704 .62975 L .28778 .63555 L p .707 .577 .707 r
F P
0 g
s
.23104 .69674 m .22512 .64087 L .19784 .63986 L p .707 .577 .707 r
F P
0 g
s
.22512 .64087 m .23104 .69674 L .26204 .69526 L p .707 .577 .707 r
F P
0 g
s
.70996 .84569 m .70694 .86362 L .70424 .85274 L p .707 .577 .707 r
F P
0 g
s
.70424 .85274 m .70726 .8348 L .70996 .84569 L p .707 .577 .707 r
F P
0 g
s
.404 .81348 m .39293 .31053 L .36322 .30231 L p .707 .577 .707 r
F P
0 g
s
.39293 .31053 m .404 .81348 L .44276 .81869 L p .707 .577 .707 r
F P
0 g
s
.31704 .62975 m .32296 .68563 L .34693 .67842 L p .707 .577 .707 r
F P
0 g
s
.34693 .67842 m .34101 .62254 L .31704 .62975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26361 .74845 m .26345 .71138 L .23227 .70962 L p .707 .577 .707 r
F P
0 g
s
.26345 .71138 m .26361 .74845 L .29544 .74755 L p .707 .577 .707 r
F P
0 g
s
.29544 .74755 m .29528 .71048 L .26345 .71138 L p .707 .577 .707 r
F P
0 g
s
.29528 .71048 m .29544 .74755 L .32483 .74407 L p .707 .577 .707 r
F P
0 g
s
.32483 .74407 m .32466 .707 L .29528 .71048 L p .707 .577 .707 r
F P
0 g
s
.19784 .63986 m .20377 .69574 L .23104 .69674 L p .707 .577 .707 r
F P
0 g
s
.71228 .76504 m .71244 .80212 L .69985 .79433 L p .707 .577 .707 r
F P
0 g
s
.69985 .79433 m .69969 .75726 L .71228 .76504 L p .707 .577 .707 r
F P
0 g
s
.23244 .74669 m .23227 .70962 L .20482 .70537 L p .707 .577 .707 r
F P
0 g
s
.23227 .70962 m .23244 .74669 L .26361 .74845 L p .707 .577 .707 r
F P
0 g
s
.20377 .69574 m .19784 .63986 L .17695 .63646 L p .707 .577 .707 r
F P
0 g
s
.69219 .66087 m .69812 .71674 L .67722 .71334 L p .707 .577 .707 r
F P
0 g
s
.67722 .71334 m .6713 .65746 L .69219 .66087 L p .707 .577 .707 r
F P
0 g
s
.64402 .65646 m .64995 .71233 L .61895 .71382 L p .707 .577 .707 r
F P
0 g
s
.61895 .71382 m .61303 .65794 L .64402 .65646 L p .707 .577 .707 r
F P
0 g
s
.65118 .74668 m .65134 .78375 L .62017 .78199 L p .707 .577 .707 r
F P
0 g
s
.62017 .78199 m .62 .74491 L .65118 .74668 L p .707 .577 .707 r
F P
0 g
s
.61349 .81363 m .61651 .7957 L .64726 .8027 L p .707 .577 .707 r
F P
0 g
s
.59604 .30156 m .60711 .80451 L .63022 .79395 L p .707 .577 .707 r
F P
0 g
s
.63022 .79395 m .61915 .291 L .59604 .30156 L p .707 .577 .707 r
F P
0 g
s
.32466 .707 m .32483 .74407 L .34888 .73836 L p .707 .577 .707 r
F P
0 g
s
.34888 .73836 m .34872 .70129 L .32466 .707 L p .707 .577 .707 r
F P
0 g
s
.34101 .62254 m .34693 .67842 L .36327 .67052 L p .707 .577 .707 r
F P
0 g
s
.36327 .67052 m .35735 .61464 L .34101 .62254 L p .707 .577 .707 r
F P
0 g
s
.20482 .70537 m .20498 .74244 L .23244 .74669 L p .707 .577 .707 r
F P
0 g
s
.17695 .63646 m .18287 .69233 L .20377 .69574 L p .707 .577 .707 r
F P
0 g
s
.25609 .79869 m .25911 .78075 L .22836 .77374 L p .707 .577 .707 r
F P
0 g
s
.25911 .78075 m .25609 .79869 L .28754 .80251 L p .707 .577 .707 r
F P
0 g
s
.28754 .80251 m .29056 .78458 L .25911 .78075 L p .707 .577 .707 r
F P
0 g
s
.20498 .74244 m .20482 .70537 L .18376 .69904 L p .707 .577 .707 r
F P
0 g
s
.29056 .78458 m .28754 .80251 L .31662 .80279 L p .707 .577 .707 r
F P
0 g
s
.31662 .80279 m .31964 .78485 L .29056 .78458 L p .707 .577 .707 r
F P
0 g
s
.70726 .8348 m .70424 .85274 L .69195 .8412 L p .707 .577 .707 r
F P
0 g
s
.69195 .8412 m .69497 .82326 L .70726 .8348 L p .707 .577 .707 r
F P
0 g
s
.22534 .79168 m .22836 .77374 L .20133 .76425 L p .707 .577 .707 r
F P
0 g
s
.22836 .77374 m .22534 .79168 L .25609 .79869 L p .707 .577 .707 r
F P
0 g
s
.35735 .61464 m .36327 .67052 L .37039 .66269 L p .707 .577 .707 r
F P
0 g
s
.37039 .66269 m .36446 .60681 L .35735 .61464 L p .707 .577 .707 r
F P
0 g
s
.36508 .6939 m .36525 .73097 L .37233 .72263 L p .707 .577 .707 r
F P
0 g
s
.37233 .72263 m .37217 .68556 L .36508 .6939 L p .707 .577 .707 r
F P
0 g
s
.36446 .60681 m .37039 .66269 L .36757 .6557 L p .707 .577 .707 r
F P
0 g
s
.36757 .6557 m .36164 .59983 L .36446 .60681 L p .707 .577 .707 r
F P
0 g
s
.37217 .68556 m .37233 .72263 L .36943 .71415 L p .707 .577 .707 r
F P
0 g
s
.36943 .71415 m .36927 .67708 L .37217 .68556 L p .707 .577 .707 r
F P
0 g
s
.36164 .59983 m .36757 .6557 L .35511 .65024 L p .707 .577 .707 r
F P
0 g
s
.36525 .73097 m .36508 .6939 L .34872 .70129 L p .707 .577 .707 r
F P
0 g
s
.36927 .67708 m .36943 .71415 L .35684 .70637 L p .707 .577 .707 r
F P
0 g
s
.35684 .70637 m .35668 .66929 L .36927 .67708 L p .707 .577 .707 r
F P
0 g
s
.37429 .80525 m .36322 .30231 L .34545 .29188 L p .707 .577 .707 r
F P
0 g
s
.36322 .30231 m .37429 .80525 L .404 .81348 L p .707 .577 .707 r
F P
0 g
s
.18287 .69233 m .17695 .63646 L .16448 .631 L p .707 .577 .707 r
F P
0 g
s
.20133 .76425 m .1983 .78218 L .22534 .79168 L p .707 .577 .707 r
F P
0 g
s
.69969 .75726 m .69985 .79433 L .6788 .788 L p .707 .577 .707 r
F P
0 g
s
.6788 .788 m .67863 .75093 L .69969 .75726 L p .707 .577 .707 r
F P
0 g
s
.6713 .65746 m .67722 .71334 L .64995 .71233 L p .707 .577 .707 r
F P
0 g
s
.64995 .71233 m .64402 .65646 L .6713 .65746 L p .707 .577 .707 r
F P
0 g
s
.18376 .69904 m .18392 .73611 L .20498 .74244 L p .707 .577 .707 r
F P
0 g
s
.34872 .70129 m .34888 .73836 L .36525 .73097 L p .707 .577 .707 r
F P
0 g
s
.31964 .78485 m .31662 .80279 L .34048 .79949 L p .707 .577 .707 r
F P
0 g
s
.34048 .79949 m .3435 .78155 L .31964 .78485 L p .707 .577 .707 r
F P
0 g
s
.1983 .78218 m .20133 .76425 L .18065 .75319 L p .707 .577 .707 r
F P
0 g
s
.16448 .631 m .17041 .68687 L .18287 .69233 L p .707 .577 .707 r
F P
0 g
s
.18392 .73611 m .18376 .69904 L .17117 .69125 L p .707 .577 .707 r
F P
0 g
s
.18065 .75319 m .17763 .77112 L .1983 .78218 L p .707 .577 .707 r
F P
0 g
s
.61915 .291 m .63022 .79395 L .64022 .7823 L p .707 .577 .707 r
F P
0 g
s
.64022 .7823 m .62915 .27935 L .61915 .291 L p .707 .577 .707 r
F P
0 g
s
.69497 .82326 m .69195 .8412 L .67127 .83014 L p .707 .577 .707 r
F P
0 g
s
.67127 .83014 m .6743 .8122 L .69497 .82326 L p .707 .577 .707 r
F P
0 g
s
.67863 .75093 m .6788 .788 L .65134 .78375 L p .707 .577 .707 r
F P
0 g
s
.65134 .78375 m .65118 .74668 L .67863 .75093 L p .707 .577 .707 r
F P
0 g
s
.17117 .69125 m .17133 .72833 L .18392 .73611 L p .707 .577 .707 r
F P
0 g
s
.3435 .78155 m .34048 .79949 L .35678 .79293 L p .707 .577 .707 r
F P
0 g
s
.35678 .79293 m .3598 .77499 L .3435 .78155 L p .707 .577 .707 r
F P
0 g
s
.17041 .68687 m .16448 .631 L .16167 .62401 L p .707 .577 .707 r
F P
0 g
s
.17763 .77112 m .18065 .75319 L .16836 .74165 L p .707 .577 .707 r
F P
0 g
s
.16836 .74165 m .16534 .75958 L .17763 .77112 L p .707 .577 .707 r
F P
0 g
s
.35511 .65024 m .35495 .64871 L p .36164 .59983 L .707 .577 .707 r
F P
0 g
s
.35495 .64871 m .34918 .59436 L .35477 .59681 L p .707 .577 .707 r
F P
0 g
s
.35477 .59681 m .36164 .59983 L p .35495 .64871 L .707 .577 .707 r
F P
0 g
s
.34918 .59436 m .35511 .65024 L .33421 .64684 L p .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35196 .74339 L .35826 .74931 L p .707 .577 .707 r
F P
0 g
s
.35826 .74931 m .36425 .75493 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35826 .74931 L .35871 .75725 L .707 .577 .707 r
F
.34545 .29188 m .34136 .28027 L p .35175 .63288 L F P
0 g
s
.35668 .66929 m .35684 .70637 L .33579 .70004 L p .707 .577 .707 r
F P
0 g
s
.33579 .70004 m .33562 .66296 L .35668 .66929 L p .707 .577 .707 r
F P
0 g
s
.3553 .75364 m .35333 .66115 L .35175 .63288 L .707 .577 .707 r
F
.35333 .66115 m .34545 .29188 L .35175 .63288 L F
.36425 .75493 m .36123 .77287 L .35949 .77124 L p F P
0 g
s
.35949 .77124 m .34894 .76133 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.35871 .75725 m .36425 .75493 L .35949 .77124 L .707 .577 .707 r
F
.35243 .78322 m .35652 .79483 L p .35175 .63288 L F P
0 g
s
.34136 .28027 m .34742 .5556 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.33421 .64684 m .32829 .59096 L .34918 .59436 L p .707 .577 .707 r
F P
0 g
s
.35196 .74339 m .34894 .76133 L .32826 .75027 L p .707 .577 .707 r
F P
0 g
s
.32826 .75027 m .33129 .73233 L .35196 .74339 L p .707 .577 .707 r
F P
0 g
s
.34742 .5556 m .35243 .78322 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.35652 .79483 m .35525 .73716 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.35525 .73716 m .34545 .29188 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.3598 .77499 m .35678 .79293 L .36393 .78375 L p .707 .577 .707 r
F P
0 g
s
.36393 .78375 m .36695 .76582 L .3598 .77499 L p .707 .577 .707 r
F P
0 g
s
.36695 .76582 m .36393 .78375 L .36123 .77287 L p .707 .577 .707 r
F P
0 g
s
.36123 .77287 m .36425 .75493 L .36695 .76582 L p .707 .577 .707 r
F P
0 g
s
.34545 .29188 m .35652 .79483 L .37429 .80525 L p .707 .577 .707 r
F P
0 g
s
.16167 .62401 m .1676 .67989 L .17041 .68687 L p .707 .577 .707 r
F P
0 g
s
.17133 .72833 m .17117 .69125 L .16827 .68278 L p .707 .577 .707 r
F P
0 g
s
.6743 .8122 m .67127 .83014 L .64424 .82064 L p .707 .577 .707 r
F P
0 g
s
.64424 .82064 m .64726 .8027 L .6743 .8122 L p .707 .577 .707 r
F P
0 g
s
.16827 .68278 m .16843 .71985 L .17133 .72833 L p .707 .577 .707 r
F P
0 g
s
.64726 .8027 m .64424 .82064 L .61349 .81363 L p .707 .577 .707 r
F P
0 g
s
.16534 .75958 m .16836 .74165 L .16566 .73076 L p .707 .577 .707 r
F P
0 g
s
.1676 .67989 m .16167 .62401 L .16878 .61618 L p .707 .577 .707 r
F P
0 g
s
.62915 .27935 m .64022 .7823 L .63614 .77069 L p .707 .577 .707 r
F P
0 g
s
.63614 .77069 m .62507 .26774 L .62915 .27935 L p .707 .577 .707 r
F P
0 g
s
.16566 .73076 m .16264 .7487 L .16534 .75958 L p .707 .577 .707 r
F P
0 g
s
.16878 .61618 m .17471 .67206 L .1676 .67989 L p .707 .577 .707 r
F P
0 g
s
.16843 .71985 m .16827 .68278 L .17535 .67443 L p .707 .577 .707 r
F P
0 g
s
.35243 .78322 m .34136 .28027 L .35137 .26862 L p .707 .577 .707 r
F P
0 g
s
.17535 .67443 m .17552 .7115 L .16843 .71985 L p .707 .577 .707 r
F P
0 g
s
.16264 .7487 m .16566 .73076 L .17281 .72159 L p .707 .577 .707 r
F P
0 g
s
.17471 .67206 m .16878 .61618 L .18512 .60828 L p .707 .577 .707 r
F P
0 g
s
.17281 .72159 m .16979 .73952 L .16264 .7487 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18512 .60828 m .19105 .66415 L .17471 .67206 L p .707 .577 .707 r
F P
0 g
s
.17552 .7115 m .17535 .67443 L .19172 .66704 L p .707 .577 .707 r
F P
0 g
s
.62507 .26774 m .63614 .77069 L .61837 .76026 L p .707 .577 .707 r
F P
0 g
s
.61837 .76026 m .6073 .25732 L .62507 .26774 L p .707 .577 .707 r
F P
0 g
s
.19172 .66704 m .19189 .70411 L .17552 .7115 L p .707 .577 .707 r
F P
0 g
s
.19105 .66415 m .18512 .60828 L .20909 .60107 L p .707 .577 .707 r
F P
0 g
s
.16979 .73952 m .17281 .72159 L .18911 .71503 L p .707 .577 .707 r
F P
0 g
s
.36243 .77157 m .35137 .26862 L .37447 .25806 L p .707 .577 .707 r
F P
0 g
s
.35137 .26862 m .36243 .77157 L .35243 .78322 L p .707 .577 .707 r
F P
0 g
s
.18911 .71503 m .18609 .73296 L .16979 .73952 L p .707 .577 .707 r
F P
0 g
s
.32829 .59096 m .33421 .64684 L .30694 .64583 L p .707 .577 .707 r
F P
0 g
s
.30694 .64583 m .30101 .58996 L .32829 .59096 L p .707 .577 .707 r
F P
0 g
s
.20909 .60107 m .21502 .65695 L .19105 .66415 L p .707 .577 .707 r
F P
0 g
s
.19189 .70411 m .19172 .66704 L .21578 .66133 L p .707 .577 .707 r
F P
0 g
s
.21502 .65695 m .20909 .60107 L .23834 .59527 L p .707 .577 .707 r
F P
0 g
s
.21578 .66133 m .21594 .6984 L .19189 .70411 L p .707 .577 .707 r
F P
0 g
s
.30101 .58996 m .30694 .64583 L .27594 .64732 L p .707 .577 .707 r
F P
0 g
s
.27594 .64732 m .27002 .59144 L .30101 .58996 L p .707 .577 .707 r
F P
0 g
s
.33562 .66296 m .33579 .70004 L .30833 .69578 L p .707 .577 .707 r
F P
0 g
s
.30833 .69578 m .30817 .65871 L .33562 .66296 L p .707 .577 .707 r
F P
0 g
s
.18609 .73296 m .18911 .71503 L .21297 .71173 L p .707 .577 .707 r
F P
0 g
s
.6073 .25732 m .61837 .76026 L .58865 .75204 L p .707 .577 .707 r
F P
0 g
s
.58865 .75204 m .57758 .24909 L .6073 .25732 L p .707 .577 .707 r
F P
0 g
s
.24427 .65115 m .23834 .59527 L .27002 .59144 L p .707 .577 .707 r
F P
0 g
s
.23834 .59527 m .24427 .65115 L .21502 .65695 L p .707 .577 .707 r
F P
0 g
s
.27002 .59144 m .27594 .64732 L .24427 .65115 L p .707 .577 .707 r
F P
0 g
s
.21594 .6984 m .21578 .66133 L .24516 .65785 L p .707 .577 .707 r
F P
0 g
s
.21297 .71173 m .20995 .72966 L .18609 .73296 L p .707 .577 .707 r
F P
0 g
s
.74225 .66972 m .73632 .61384 L .70533 .61533 L p .707 .577 .707 r
F P
0 g
s
.73632 .61384 m .74225 .66972 L .77392 .66589 L p .707 .577 .707 r
F P
0 g
s
.77392 .66589 m .768 .61001 L .73632 .61384 L p .707 .577 .707 r
F P
0 g
s
.30817 .65871 m .30833 .69578 L .27716 .69402 L p .707 .577 .707 r
F P
0 g
s
.27716 .69402 m .27699 .65695 L .30817 .65871 L p .707 .577 .707 r
F P
0 g
s
.768 .61001 m .77392 .66589 L .80318 .66009 L p .707 .577 .707 r
F P
0 g
s
.80318 .66009 m .79725 .60421 L .768 .61001 L p .707 .577 .707 r
F P
0 g
s
.24516 .65785 m .24532 .69492 L .21594 .6984 L p .707 .577 .707 r
F P
0 g
s
.37447 .25806 m .38554 .76101 L .36243 .77157 L p .707 .577 .707 r
F P
0 g
s
.38554 .76101 m .37447 .25806 L .40843 .24964 L p .707 .577 .707 r
F P
0 g
s
.24532 .69492 m .24516 .65785 L .27699 .65695 L p .707 .577 .707 r
F P
0 g
s
.33129 .73233 m .32826 .75027 L .30123 .74077 L p .707 .577 .707 r
F P
0 g
s
.30123 .74077 m .30425 .72283 L .33129 .73233 L p .707 .577 .707 r
F P
0 g
s
.27699 .65695 m .27716 .69402 L .24532 .69492 L p .707 .577 .707 r
F P
0 g
s
.20995 .72966 m .21297 .71173 L .24205 .712 L p .707 .577 .707 r
F P
0 g
s
.71126 .67121 m .70533 .61533 L .67805 .61432 L p .707 .577 .707 r
F P
0 g
s
.70533 .61533 m .71126 .67121 L .74225 .66972 L p .707 .577 .707 r
F P
0 g
s
.79725 .60421 m .80318 .66009 L .82715 .65288 L p .707 .577 .707 r
F P
0 g
s
.82715 .65288 m .82122 .59701 L .79725 .60421 L p .707 .577 .707 r
F P
0 g
s
.24205 .712 m .23903 .72994 L .20995 .72966 L p .707 .577 .707 r
F P
0 g
s
.30425 .72283 m .30123 .74077 L .27048 .73376 L p .707 .577 .707 r
F P
0 g
s
.27048 .73376 m .2735 .71583 L .30425 .72283 L p .707 .577 .707 r
F P
0 g
s
.57758 .24909 m .58865 .75204 L .5499 .74682 L p .707 .577 .707 r
F P
0 g
s
.5499 .74682 m .53883 .24388 L .57758 .24909 L p .707 .577 .707 r
F P
0 g
s
.23903 .72994 m .24205 .712 L .2735 .71583 L p .707 .577 .707 r
F P
0 g
s
.67805 .61432 m .68398 .6702 L .71126 .67121 L p .707 .577 .707 r
F P
0 g
s
.74382 .74438 m .74366 .70731 L .71249 .70555 L p .707 .577 .707 r
F P
0 g
s
.74366 .70731 m .74382 .74438 L .77566 .74348 L p .707 .577 .707 r
F P
0 g
s
.77566 .74348 m .77549 .70641 L .74366 .70731 L p .707 .577 .707 r
F P
0 g
s
.68398 .6702 m .67805 .61432 L .65716 .61092 L p .707 .577 .707 r
F P
0 g
s
.2735 .71583 m .27048 .73376 L .23903 .72994 L p .707 .577 .707 r
F P
0 g
s
.77549 .70641 m .77566 .74348 L .80504 .74 L p .707 .577 .707 r
F P
0 g
s
.80504 .74 m .80488 .70293 L .77549 .70641 L p .707 .577 .707 r
F P
0 g
s
.71265 .74262 m .71249 .70555 L .68503 .70129 L p .707 .577 .707 r
F P
0 g
s
.71249 .70555 m .71265 .74262 L .74382 .74438 L p .707 .577 .707 r
F P
0 g
s
.41949 .75258 m .40843 .24964 L .4499 .24416 L p .707 .577 .707 r
F P
0 g
s
.40843 .24964 m .41949 .75258 L .38554 .76101 L p .707 .577 .707 r
F P
0 g
s
.82122 .59701 m .82715 .65288 L .84349 .64498 L p .707 .577 .707 r
F P
0 g
s
.84349 .64498 m .83756 .5891 L .82122 .59701 L p .707 .577 .707 r
F P
0 g
s
.65716 .61092 m .66309 .6668 L .68398 .6702 L p .707 .577 .707 r
F P
0 g
s
.80488 .70293 m .80504 .74 L .82909 .73429 L p .707 .577 .707 r
F P
0 g
s
.82909 .73429 m .82893 .69722 L .80488 .70293 L p .707 .577 .707 r
F P
0 g
s
.68503 .70129 m .68519 .73837 L .71265 .74262 L p .707 .577 .707 r
F P
0 g
s
.7363 .78652 m .73932 .76858 L .70857 .76158 L p .707 .577 .707 r
F P
0 g
s
.73932 .76858 m .7363 .78652 L .76775 .79035 L p .707 .577 .707 r
F P
0 g
s
.76775 .79035 m .77078 .77241 L .73932 .76858 L p .707 .577 .707 r
F P
0 g
s
.53883 .24388 m .5499 .74682 L .5059 .74512 L p .707 .577 .707 r
F P
0 g
s
.5059 .74512 m .49483 .24218 L .53883 .24388 L p .707 .577 .707 r
F P
0 g
s
.68519 .73837 m .68503 .70129 L .66397 .69497 L p .707 .577 .707 r
F P
0 g
s
.77078 .77241 m .76775 .79035 L .79683 .79062 L p .707 .577 .707 r
F P
0 g
s
.79683 .79062 m .79986 .77269 L .77078 .77241 L p .707 .577 .707 r
F P
0 g
s
.70555 .77951 m .70857 .76158 L .68154 .75208 L p .707 .577 .707 r
F P
0 g
s
.70857 .76158 m .70555 .77951 L .7363 .78652 L p .707 .577 .707 r
F P
0 g
s
.66309 .6668 m .65716 .61092 L .6447 .60546 L p .707 .577 .707 r
F P
0 g
s
.4499 .24416 m .46097 .74711 L .41949 .75258 L p .707 .577 .707 r
F P
0 g
s
.42499 .54351 m .43091 .59939 L .43863 .59786 L p .707 .577 .707 r
F P
0 g
s
.45967 .68809 m .4499 .24416 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.43863 .59786 m .46017 .59359 L p .42644 .54558 L .707 .577 .707 r
F P
0 g
s
.42644 .54558 m .42499 .54351 L .43863 .59786 L .707 .577 .707 r
F
.4499 .24416 m .49483 .24218 L p .46375 .7056 L F P
0 g
s
.46097 .74711 m .45967 .68809 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.49483 .24218 m .5059 .74512 L .46097 .74711 L p .707 .577 .707 r
F P
0 g
s
.68154 .75208 m .67851 .77001 L .70555 .77951 L p .707 .577 .707 r
F P
0 g
s
.66397 .69497 m .66414 .73204 L .68519 .73837 L p .707 .577 .707 r
F P
0 g
s
.82893 .69722 m .82909 .73429 L .84546 .7269 L p .707 .577 .707 r
F P
0 g
s
.84546 .7269 m .8453 .68983 L .82893 .69722 L p .707 .577 .707 r
F P
0 g
s
.79986 .77269 m .79683 .79062 L .82069 .78732 L p .707 .577 .707 r
F P
0 g
s
.82069 .78732 m .82371 .76938 L .79986 .77269 L p .707 .577 .707 r
F P
0 g
s
.83756 .5891 m .84349 .64498 L .8506 .63715 L p .707 .577 .707 r
F P
0 g
s
.8506 .63715 m .84467 .58127 L .83756 .5891 L p .707 .577 .707 r
F P
0 g
s
.67851 .77001 m .68154 .75208 L .66087 .74102 L p .707 .577 .707 r
F P
0 g
s
.6447 .60546 m .65062 .66134 L .66309 .6668 L p .707 .577 .707 r
F P
0 g
s
.66087 .74102 m .65784 .75895 L .67851 .77001 L p .707 .577 .707 r
F P
0 g
s
.66414 .73204 m .66397 .69497 L .65138 .68718 L p .707 .577 .707 r
F P
0 g
s
.65062 .66134 m .6447 .60546 L .64188 .59847 L p .707 .577 .707 r
F P
0 g
s
.65138 .68718 m .65154 .72425 L .66414 .73204 L p .707 .577 .707 r
F P
0 g
s
.82371 .76938 m .82069 .78732 L .83699 .78076 L p .707 .577 .707 r
F P
0 g
s
.83699 .78076 m .84002 .76282 L .82371 .76938 L p .707 .577 .707 r
F P
0 g
s
.65784 .75895 m .66087 .74102 L .64858 .72948 L p .707 .577 .707 r
F P
0 g
s
.8453 .68983 m .84546 .7269 L .85254 .71856 L p .707 .577 .707 r
F P
0 g
s
.85254 .71856 m .85238 .68148 L .8453 .68983 L p .707 .577 .707 r
F P
0 g
s
.64858 .72948 m .64555 .74742 L .65784 .75895 L p .707 .577 .707 r
F P
0 g
s
.84467 .58127 m .8506 .63715 L .84779 .63017 L p .707 .577 .707 r
F P
0 g
s
.84779 .63017 m .84186 .57429 L .84467 .58127 L p .707 .577 .707 r
F P
0 g
s
.64188 .59847 m .64781 .65435 L .65062 .66134 L p .707 .577 .707 r
F P
0 g
s
.65154 .72425 m .65138 .68718 L .64849 .6787 L p .707 .577 .707 r
F P
0 g
s
.84002 .76282 m .83699 .78076 L .84414 .77159 L p .707 .577 .707 r
F P
0 g
s
.84414 .77159 m .84717 .75365 L .84002 .76282 L p .707 .577 .707 r
F P
0 g
s
.64849 .6787 m .64865 .71577 L .65154 .72425 L p .707 .577 .707 r
F P
0 g
s
.64781 .65435 m .64188 .59847 L .64899 .59064 L p .707 .577 .707 r
F P
0 g
s
.64555 .74742 m .64858 .72948 L .64587 .71859 L p .707 .577 .707 r
F P
0 g
s
.85238 .68148 m .85254 .71856 L .84965 .71008 L p .707 .577 .707 r
F P
0 g
s
.84965 .71008 m .84949 .67301 L .85238 .68148 L p .707 .577 .707 r
F P
0 g
s
.64587 .71859 m .64285 .73653 L .64555 .74742 L p .707 .577 .707 r
F P
0 g
s
.84186 .57429 m .84779 .63017 L .83532 .6247 L p .707 .577 .707 r
F P
0 g
s
.83532 .6247 m .8294 .56883 L .84186 .57429 L p .707 .577 .707 r
F P
0 g
s
.64899 .59064 m .65492 .64652 L .64781 .65435 L p .707 .577 .707 r
F P
0 g
s
.39924 .60322 m .39331 .54734 L .36232 .54883 L p .707 .577 .707 r
F P
0 g
s
.39331 .54734 m .39924 .60322 L .43091 .59939 L p .707 .577 .707 r
F P
0 g
s
.43091 .59939 m .42499 .54351 L .39331 .54734 L p .707 .577 .707 r
F P
0 g
s
.46017 .59359 m .45424 .53771 L .42499 .54351 L p .707 .577 .707 r
F P
0 g
s
.64865 .71577 m .64849 .6787 L .65557 .67036 L p .707 .577 .707 r
F P
0 g
s
.36825 .6047 m .36232 .54883 L .33504 .54782 L p .707 .577 .707 r
F P
0 g
s
.36232 .54883 m .36825 .6047 L .39924 .60322 L p .707 .577 .707 r
F P
0 g
s
.84717 .75365 m .84414 .77159 L .84144 .7607 L p .707 .577 .707 r
F P
0 g
s
.84144 .7607 m .84446 .74276 L .84717 .75365 L p .707 .577 .707 r
F P
0 g
s
.45424 .53771 m .46017 .59359 L .48414 .58638 L p .707 .577 .707 r
F P
0 g
s
.48414 .58638 m .47821 .53051 L .45424 .53771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65557 .67036 m .65573 .70743 L .64865 .71577 L p .707 .577 .707 r
F P
0 g
s
.65492 .64652 m .64899 .59064 L .66533 .58274 L p .707 .577 .707 r
F P
0 g
s
.64285 .73653 m .64587 .71859 L .65302 .70942 L p .707 .577 .707 r
F P
0 g
s
.40081 .65642 m .40065 .61934 L .36948 .61758 L p .707 .577 .707 r
F P
0 g
s
.40065 .61934 m .40081 .65642 L .43265 .65551 L p .707 .577 .707 r
F P
0 g
s
.43265 .65551 m .43248 .61844 L .40065 .61934 L p .707 .577 .707 r
F P
0 g
s
.43248 .61844 m .43265 .65551 L .46203 .65204 L p .707 .577 .707 r
F P
0 g
s
.46203 .65204 m .46187 .61496 L .43248 .61844 L p .707 .577 .707 r
F P
0 g
s
.33504 .54782 m .34097 .6037 L .36825 .6047 L p .707 .577 .707 r
F P
0 g
s
.84949 .67301 m .84965 .71008 L .83706 .70229 L p .707 .577 .707 r
F P
0 g
s
.83706 .70229 m .83689 .66522 L .84949 .67301 L p .707 .577 .707 r
F P
0 g
s
.65302 .70942 m .65 .72735 L .64285 .73653 L p .707 .577 .707 r
F P
0 g
s
.36964 .65465 m .36948 .61758 L .34202 .61333 L p .707 .577 .707 r
F P
0 g
s
.36948 .61758 m .36964 .65465 L .40081 .65642 L p .707 .577 .707 r
F P
0 g
s
.34097 .6037 m .33504 .54782 L .31415 .54442 L p .707 .577 .707 r
F P
0 g
s
.8294 .56883 m .83532 .6247 L .81443 .6213 L p .707 .577 .707 r
F P
0 g
s
.81443 .6213 m .8085 .56543 L .8294 .56883 L p .707 .577 .707 r
F P
0 g
s
.66533 .58274 m .67126 .63862 L .65492 .64652 L p .707 .577 .707 r
F P
0 g
s
.46187 .61496 m .46203 .65204 L .48608 .64632 L p .707 .577 .707 r
F P
0 g
s
.48608 .64632 m .48592 .60925 L .46187 .61496 L p .707 .577 .707 r
F P
0 g
s
.47821 .53051 m .48414 .58638 L .50048 .57848 L p .707 .577 .707 r
F P
0 g
s
.50048 .57848 m .49455 .5226 L .47821 .53051 L p .707 .577 .707 r
F P
0 g
s
.65573 .70743 m .65557 .67036 L .67194 .66297 L p .707 .577 .707 r
F P
0 g
s
.34202 .61333 m .34218 .6504 L .36964 .65465 L p .707 .577 .707 r
F P
0 g
s
.31415 .54442 m .32008 .6003 L .34097 .6037 L p .707 .577 .707 r
F P
0 g
s
.39329 .70665 m .39631 .68871 L .36556 .68171 L p .707 .577 .707 r
F P
0 g
s
.39631 .68871 m .39329 .70665 L .42474 .71048 L p .707 .577 .707 r
F P
0 g
s
.42474 .71048 m .42777 .69254 L .39631 .68871 L p .707 .577 .707 r
F P
0 g
s
.34218 .6504 m .34202 .61333 L .32096 .607 L p .707 .577 .707 r
F P
0 g
s
.67126 .63862 m .66533 .58274 L .6893 .57553 L p .707 .577 .707 r
F P
0 g
s
.42777 .69254 m .42474 .71048 L .45382 .71075 L p .707 .577 .707 r
F P
0 g
s
.45382 .71075 m .45685 .69282 L .42777 .69254 L p .707 .577 .707 r
F P
0 g
s
.84446 .74276 m .84144 .7607 L .82915 .74916 L p .707 .577 .707 r
F P
0 g
s
.82915 .74916 m .83218 .73122 L .84446 .74276 L p .707 .577 .707 r
F P
0 g
s
.36254 .69964 m .36556 .68171 L .33853 .67221 L p .707 .577 .707 r
F P
0 g
s
.36556 .68171 m .36254 .69964 L .39329 .70665 L p .707 .577 .707 r
F P
0 g
s
.67194 .66297 m .6721 .70004 L .65573 .70743 L p .707 .577 .707 r
F P
0 g
s
.65 .72735 m .65302 .70942 L .66933 .70286 L p .707 .577 .707 r
F P
0 g
s
.32008 .6003 m .31415 .54442 L .30169 .53896 L p .707 .577 .707 r
F P
0 g
s
.33853 .67221 m .3355 .69014 L .36254 .69964 L p .707 .577 .707 r
F P
0 g
s
.83689 .66522 m .83706 .70229 L .816 .69596 L p .707 .577 .707 r
F P
0 g
s
.816 .69596 m .81584 .65889 L .83689 .66522 L p .707 .577 .707 r
F P
0 g
s
.8085 .56543 m .81443 .6213 L .78715 .6203 L p .707 .577 .707 r
F P
0 g
s
.78715 .6203 m .78122 .56442 L .8085 .56543 L p .707 .577 .707 r
F P
0 g
s
.32096 .607 m .32113 .64407 L .34218 .6504 L p .707 .577 .707 r
F P
0 g
s
.48592 .60925 m .48608 .64632 L .50245 .63893 L p .707 .577 .707 r
F P
0 g
s
.50245 .63893 m .50229 .60186 L .48592 .60925 L p .707 .577 .707 r
F P
0 g
s
.66933 .70286 m .6663 .72079 L .65 .72735 L p .707 .577 .707 r
F P
0 g
s
.6893 .57553 m .69523 .63141 L .67126 .63862 L p .707 .577 .707 r
F P
0 g
s
.45685 .69282 m .45382 .71075 L .47768 .70745 L p .707 .577 .707 r
F P
0 g
s
.47768 .70745 m .4807 .68951 L .45685 .69282 L p .707 .577 .707 r
F P
0 g
s
.3355 .69014 m .33853 .67221 L .31785 .66115 L p .707 .577 .707 r
F P
0 g
s
.49455 .5226 m .50048 .57848 L .50759 .57065 L p .707 .577 .707 r
F P
0 g
s
.50759 .57065 m .50166 .51477 L .49455 .5226 L p .707 .577 .707 r
F P
0 g
s
.6721 .70004 m .67194 .66297 L .69599 .65726 L p .707 .577 .707 r
F P
0 g
s
.69523 .63141 m .6893 .57553 L .71856 .56973 L p .707 .577 .707 r
F P
0 g
s
.30169 .53896 m .30761 .59483 L .32008 .6003 L p .707 .577 .707 r
F P
0 g
s
.32113 .64407 m .32096 .607 L .30837 .59921 L p .707 .577 .707 r
F P
0 g
s
.31785 .66115 m .31483 .67908 L .3355 .69014 L p .707 .577 .707 r
F P
0 g
s
.78122 .56442 m .78715 .6203 L .75616 .62178 L p .707 .577 .707 r
F P
0 g
s
.75616 .62178 m .75023 .5659 L .78122 .56442 L p .707 .577 .707 r
F P
0 g
s
.83218 .73122 m .82915 .74916 L .80848 .7381 L p .707 .577 .707 r
F P
0 g
s
.80848 .7381 m .8115 .72016 L .83218 .73122 L p .707 .577 .707 r
F P
0 g
s
.69599 .65726 m .69615 .69433 L .6721 .70004 L p .707 .577 .707 r
F P
0 g
s
.72449 .62561 m .71856 .56973 L .75023 .5659 L p .707 .577 .707 r
F P
0 g
s
.71856 .56973 m .72449 .62561 L .69523 .63141 L p .707 .577 .707 r
F P
0 g
s
.6663 .72079 m .66933 .70286 L .69318 .69956 L p .707 .577 .707 r
F P
0 g
s
.81584 .65889 m .816 .69596 L .78854 .69171 L p .707 .577 .707 r
F P
0 g
s
.78854 .69171 m .78838 .65464 L .81584 .65889 L p .707 .577 .707 r
F P
0 g
s
.30837 .59921 m .30853 .63629 L .32113 .64407 L p .707 .577 .707 r
F P
0 g
s
.75023 .5659 m .75616 .62178 L .72449 .62561 L p .707 .577 .707 r
F P
0 g
s
.4807 .68951 m .47768 .70745 L .49398 .70089 L p .707 .577 .707 r
F P
0 g
s
.49398 .70089 m .49701 .68295 L .4807 .68951 L p .707 .577 .707 r
F P
0 g
s
.30761 .59483 m .30169 .53896 L .29887 .53197 L p .707 .577 .707 r
F P
0 g
s
.50229 .60186 m .50245 .63893 L .50953 .63059 L p .707 .577 .707 r
F P
0 g
s
.50953 .63059 m .50937 .59352 L .50229 .60186 L p .707 .577 .707 r
F P
0 g
s
.69318 .69956 m .69016 .71749 L .6663 .72079 L p .707 .577 .707 r
F P
0 g
s
.31483 .67908 m .31785 .66115 L .30557 .64961 L p .707 .577 .707 r
F P
0 g
s
.69615 .69433 m .69599 .65726 L .72537 .65378 L p .707 .577 .707 r
F P
0 g
s
.30557 .64961 m .30254 .66755 L .31483 .67908 L p .707 .577 .707 r
F P
0 g
s
.78838 .65464 m .78854 .69171 L .75737 .68995 L p .707 .577 .707 r
F P
0 g
s
.75737 .68995 m .75721 .65288 L .78838 .65464 L p .707 .577 .707 r
F P
0 g
s
.50166 .51477 m .50759 .57065 L .50478 .56366 L p .707 .577 .707 r
F P
0 g
s
.50478 .56366 m .49885 .50779 L .50166 .51477 L p .707 .577 .707 r
F P
0 g
s
.29887 .53197 m .3048 .58785 L .30761 .59483 L p .707 .577 .707 r
F P
0 g
s
.72537 .65378 m .72554 .69085 L .69615 .69433 L p .707 .577 .707 r
F P
0 g
s
.30853 .63629 m .30837 .59921 L .30547 .59074 L p .707 .577 .707 r
F P
0 g
s
.8115 .72016 m .80848 .7381 L .78144 .7286 L p .707 .577 .707 r
F P
0 g
s
.78144 .7286 m .78447 .71067 L .8115 .72016 L p .707 .577 .707 r
F P
0 g
s
.72554 .69085 m .72537 .65378 L .75721 .65288 L p .707 .577 .707 r
F P
0 g
s
.69016 .71749 m .69318 .69956 L .72226 .69983 L p .707 .577 .707 r
F P
0 g
s
.75721 .65288 m .75737 .68995 L .72554 .69085 L p .707 .577 .707 r
F P
0 g
s
.72226 .69983 m .71924 .71777 L .69016 .71749 L p .707 .577 .707 r
F P
0 g
s
.30547 .59074 m .30564 .62781 L .30853 .63629 L p .707 .577 .707 r
F P
0 g
s
.49701 .68295 m .49398 .70089 L .50113 .69172 L p .707 .577 .707 r
F P
0 g
s
.50113 .69172 m .50416 .67378 L .49701 .68295 L p .707 .577 .707 r
F P
0 g
s
.78447 .71067 m .78144 .7286 L .75069 .7216 L p .707 .577 .707 r
F P
0 g
s
.75069 .7216 m .75372 .70366 L .78447 .71067 L p .707 .577 .707 r
F P
0 g
s
.30254 .66755 m .30557 .64961 L .30286 .63872 L p .707 .577 .707 r
F P
0 g
s
.71924 .71777 m .72226 .69983 L .75372 .70366 L p .707 .577 .707 r
F P
0 g
s
.3048 .58785 m .29887 .53197 L .30598 .52414 L p .707 .577 .707 r
F P
0 g
s
.50937 .59352 m .50953 .63059 L .50664 .62211 L p .707 .577 .707 r
F P
0 g
s
.50664 .62211 m .50648 .58504 L .50937 .59352 L p .707 .577 .707 r
F P
0 g
s
.75372 .70366 m .75069 .7216 L .71924 .71777 L p .707 .577 .707 r
F P
0 g
s
.30286 .63872 m .29984 .65666 L .30254 .66755 L p .707 .577 .707 r
F P
0 g
s
.49885 .50779 m .50478 .56366 L .49231 .5582 L p .707 .577 .707 r
F P
0 g
s
.49231 .5582 m .48638 .50233 L .49885 .50779 L p .707 .577 .707 r
F P
0 g
s
.30598 .52414 m .31191 .58002 L .3048 .58785 L p .707 .577 .707 r
F P
0 g
s
.30564 .62781 m .30547 .59074 L .31256 .58239 L p .707 .577 .707 r
F P
0 g
s
.31256 .58239 m .31272 .61947 L .30564 .62781 L p .707 .577 .707 r
F P
0 g
s
.50416 .67378 m .50113 .69172 L .49843 .68083 L p .707 .577 .707 r
F P
0 g
s
.49843 .68083 m .50145 .66289 L .50416 .67378 L p .707 .577 .707 r
F P
0 g
s
.29984 .65666 m .30286 .63872 L .31001 .62955 L p .707 .577 .707 r
F P
0 g
s
.31191 .58002 m .30598 .52414 L .32232 .51624 L p .707 .577 .707 r
F P
0 g
s
.50648 .58504 m .50664 .62211 L .49405 .61433 L p .707 .577 .707 r
F P
0 g
s
.49405 .61433 m .49388 .57725 L .50648 .58504 L p .707 .577 .707 r
F P
0 g
s
.31001 .62955 m .30699 .64748 L .29984 .65666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48638 .50233 m .49231 .5582 L .47142 .5548 L p .707 .577 .707 r
F P
0 g
s
.47142 .5548 m .46549 .49892 L .48638 .50233 L p .707 .577 .707 r
F P
0 g
s
.32232 .51624 m .32825 .57212 L .31191 .58002 L p .707 .577 .707 r
F P
0 g
s
.31272 .61947 m .31256 .58239 L .32893 .575 L p .707 .577 .707 r
F P
0 g
s
.32893 .575 m .32909 .61208 L .31272 .61947 L p .707 .577 .707 r
F P
0 g
s
.50145 .66289 m .49843 .68083 L .48614 .66929 L p .707 .577 .707 r
F P
0 g
s
.48614 .66929 m .48916 .65135 L .50145 .66289 L p .707 .577 .707 r
F P
0 g
s
.32825 .57212 m .32232 .51624 L .34629 .50903 L p .707 .577 .707 r
F P
0 g
s
.30699 .64748 m .31001 .62955 L .32632 .62299 L p .707 .577 .707 r
F P
0 g
s
.49388 .57725 m .49405 .61433 L .47299 .608 L p .707 .577 .707 r
F P
0 g
s
.47299 .608 m .47283 .57093 L .49388 .57725 L p .707 .577 .707 r
F P
0 g
s
.32632 .62299 m .32329 .64092 L .30699 .64748 L p .707 .577 .707 r
F P
0 g
s
.46549 .49892 m .47142 .5548 L .44414 .55379 L p .707 .577 .707 r
F P
0 g
s
.44414 .55379 m .43821 .49792 L .46549 .49892 L p .707 .577 .707 r
F P
0 g
s
.34629 .50903 m .35222 .56491 L .32825 .57212 L p .707 .577 .707 r
F P
0 g
s
.32909 .61208 m .32893 .575 L .35298 .56929 L p .707 .577 .707 r
F P
0 g
s
.35222 .56491 m .34629 .50903 L .37555 .50323 L p .707 .577 .707 r
F P
0 g
s
.35298 .56929 m .35314 .60636 L .32909 .61208 L p .707 .577 .707 r
F P
0 g
s
.48916 .65135 m .48614 .66929 L .46547 .65823 L p .707 .577 .707 r
F P
0 g
s
.46547 .65823 m .46849 .64029 L .48916 .65135 L p .707 .577 .707 r
F P
0 g
s
.43821 .49792 m .44414 .55379 L .41315 .55528 L p .707 .577 .707 r
F P
0 g
s
.41315 .55528 m .40722 .4994 L .43821 .49792 L p .707 .577 .707 r
F P
0 g
s
.47283 .57093 m .47299 .608 L .44553 .60374 L p .707 .577 .707 r
F P
0 g
s
.44553 .60374 m .44537 .56667 L .47283 .57093 L p .707 .577 .707 r
F P
0 g
s
.32329 .64092 m .32632 .62299 L .35017 .61969 L p .707 .577 .707 r
F P
0 g
s
.38147 .55911 m .37555 .50323 L .40722 .4994 L p .707 .577 .707 r
F P
0 g
s
.37555 .50323 m .38147 .55911 L .35222 .56491 L p .707 .577 .707 r
F P
0 g
s
.40722 .4994 m .41315 .55528 L .38147 .55911 L p .707 .577 .707 r
F P
0 g
s
.35314 .60636 m .35298 .56929 L .38236 .56581 L p .707 .577 .707 r
F P
0 g
s
.35017 .61969 m .34715 .63762 L .32329 .64092 L p .707 .577 .707 r
F P
0 g
s
.44537 .56667 m .44553 .60374 L .41436 .60198 L p .707 .577 .707 r
F P
0 g
s
.41436 .60198 m .4142 .56491 L .44537 .56667 L p .707 .577 .707 r
F P
0 g
s
.38236 .56581 m .38252 .60288 L .35314 .60636 L p .707 .577 .707 r
F P
0 g
s
.38252 .60288 m .38236 .56581 L .4142 .56491 L p .707 .577 .707 r
F P
0 g
s
.46849 .64029 m .46547 .65823 L .43843 .64873 L p .707 .577 .707 r
F P
0 g
s
.43843 .64873 m .44146 .6308 L .46849 .64029 L p .707 .577 .707 r
F P
0 g
s
.4142 .56491 m .41436 .60198 L .38252 .60288 L p .707 .577 .707 r
F P
0 g
s
.34715 .63762 m .35017 .61969 L .37925 .61996 L p .707 .577 .707 r
F P
0 g
s
.37925 .61996 m .37623 .6379 L .34715 .63762 L p .707 .577 .707 r
F P
0 g
s
.44146 .6308 m .43843 .64873 L .40768 .64173 L p .707 .577 .707 r
F P
0 g
s
.40768 .64173 m .41071 .62379 L .44146 .6308 L p .707 .577 .707 r
F P
0 g
s
.37623 .6379 m .37925 .61996 L .41071 .62379 L p .707 .577 .707 r
F P
0 g
s
.41071 .62379 m .40768 .64173 L .37623 .6379 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Ioo`d008Yo
o`00OGoo2@001UYF00<005YFFUH015YF3000OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001gOol0079oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEP00001eOol006eoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001bOol006Uoo`@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP80071oo`00Igoo
0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`00KWoo001UOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001/Ool0
06=oo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Uoo`00HWoo0P001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001ROol20006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001ZOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yo
o`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00=oo`00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00
HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP0EFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVYoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF
JWoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH05EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIZOol0065oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1XOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0E
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1X
Ool0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00
HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0?0007
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069o
o`04001JEUYF0005FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001ROol01@00
FUIJEP00FUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001QOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol005eoo`@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005]oo`8000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005Uoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF000=FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JGoo001G
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP003EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001FOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001EOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001DOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Aoo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo
001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUHF0002FUH0
1@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001E
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPL0
00UJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF
00=JEQL000MJEP03001JEUYF00AJEP03001JEUYF009JEP@000YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8001iooaD003Eoo`00EGoo00@005YFFUH000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001JEUYF00=JEP<000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@0035oo`00EGoo00@005YFFUH000=JEPL00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000COol70006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000_Ool005Eoo`05001JEUYF001JEP050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000=Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`9JEP@00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yoo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005Ioo`04FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20007Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001FOol00eYF00000004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P001Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001AOol80004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0018Ool90004FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0041oo`P000AJEP03001JEUYF00IJ
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=Woo100000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000Aoo`00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=7oo0P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF000015YF00<005YFFUH00eYF
1P000eYF00<005YFFUH01eYF00<005YFFUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005Ool005YFFUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo000bOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH400000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200001Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0002aoo`00<7oo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`0000=JEP0000000`0000=JEP00FUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF20000eYF0`000eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000Eoo`00FUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;goo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF001JEP8000EJEP04001JEUYFFUH80009FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool002ioo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0015YF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQP000=JEP03001JEUYF008002]oo`00;Goo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF1@000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH2000[Ool0
02eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP80009JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002]oo`00;Goo00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool0
0`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0003FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJEUYF4000
15YF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20003FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70006FUH00`00
FUIJEP05FUH20004FUH00`00FUH00002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP8002aoo`00;Woo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@0000=JEP00
00000`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1UYF0`0000AJEP000000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=oo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP05001JEUYFFUH0000]Ool002ioo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT0009JEP06001JEP00001JEP000eYF1@001UYF
00<005YFFUH01EYF00<005YFFUH01UYF10001eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
000^Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPP000QJEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003Ool015YF001JEP001EYF00<005YFFUH01EYF4`0025YF00<0
05YFFUH00eYF0`00<7oo000^Ool00`00FUH00005FUH00`00FUIJEP03FUH60007FUH:0002FUH20000
15YF001JEP001UYF00<005YF00000UYF6@0000IJEP00000005YF0006FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP02FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000eYF00000002000cOol002ioo`03001J
EP0000EJEP03001JEP0000<000AJEP03001JEP0000L000AJEP03001JEUYF009JEP@0009JEP<000EJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP<000IJEP04001J
EP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH01000
FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Ao
o`00;Woo00@005YFFUH000AJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH800001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP<0009JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000aOol002ioo`04001JEUYF0002FUH60003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P0000=JEP00FUH0
0UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;goo000_Ool2FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF0`000eYF00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP80009JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<002eoo`00;goo0UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF
0`0000EJEP00FUIJEP0000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP05001J
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH0
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000_Ool00eYF00000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUH000040005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002]oo`00;goo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001UYF00<005YFFUH00eYF10000eYF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP80009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000ZOol002mo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00T000AJEP03001JEUYF00QJEP03001J
EUYF00MJEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00:Woo000_Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP06FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2000015YF0000
000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000ZOol002moo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03001JEUYF00AJ
EPD0009JEPP000EJEP03001JEUYF00D000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF
00<005YFFUH00eYF00@005YFFUIJEP8002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF00<005YF00000`000UYF00<005YFFUH01EYF0`001eYF00@005YFFUIJEPP0
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF009JEPH001Yoo`D000AJEP04001JEUYFFUH2
000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPX001=oo`@0009JEP06001JEUYFFUH005YF
10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF0000
15YF00<005YF000020007Woo100000=JEP00FUH00UYF0P00:Woo000_Ool00`00FUH00004FUH00`00
FUH00003000QOol500001EYF001JEUYF00000UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP00009JEPD000=JEP04001JEUYFFUH9000?Ool70003
FUH30003FUH2000ZOol002moo`03001JEP0000=JEP<00003FUH0000000<0021oo`H0009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF0000000ZOol002moo`04001JEP00FUH20005FUH01000FUIJEUYF20004Woo1P001EYF00@0
05YFFUH000IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000ZOol002moo`06001JEP00001JEP0015YF7`0015YF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEUYF00IJEPl000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002Yoo`00;goo0P000eYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF009J
EP03001JEP0002Yoo`00;goo0P000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEQD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF
009JEP03001JEP0002Yoo`00;goo10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH00000FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80006
FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP02FUH2000[Ool0031oo`80009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04
FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000000P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00`000eYF0P00;7oo000_Ool00`00FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH40005FUH00`00FUIJEP03FUH4
000^Ool002moo`8000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEPL000IJEP03001JEUYF
00EJEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH0
1EYF0P00;goo000_Ool200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP06FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300001UYF001JEP00FUH0009JEPD000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP03001JEP0002ioo`00;Woo00@005YF000000Aoo`<00003
FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP@000MJEP03001JEUYF00800005OomJEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUH00006FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH01@00FUIJEUYF0000;Goo000^Ool3
0008Ool50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP<000EJEP<0
009ooaT000Moo`04001JEUYF0004FUH00`00Oomoo`0ZOol002ioo`800003FUH007oo00]ooaX00006
Ool00000001JEP002EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF2P002eYF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH01@009Woo0`0015YF00<007oo
Ool0:Woo000^Ool20002FUH00`00Oomoo`0WOol20009FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF1P002EYF00<005YFFUH02EYF00<005YFFUH02EYF1`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF00001EYF0`00:7oo00<005YFFUH00UYF00<007ooOol0:Woo000_Ool01@00FUIJEUYF
0000:Woo0P000eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP8000=JEP80
00IJEP04001JEP00000WOol00`00FUIJEP02000/Ool002moo`04001JEUYFFUH3000ZOol200000eYF
001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH20003FUH20006FUH01000FUIJEUYF
0`009Goo1000;7oo000`Ool01000FUIJEP000UYF0P00:Woo0P000eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEP000003FUH00`00FUIJEP05FUH4000ROol3000/Ool0031o
o`03001JEP0000EJEP<002Uoo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF
00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00@001aoo`@002eoo`00<Goo0P001UYF00@0
05YF000002Moo`=JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP04FUH7000@Ool50002FUH2000]Ool0039oo`03001JEUYF00AJEP04001JEUYFFUH2
0009Ool3000IOol3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04FUH0
1000FUH0000015YF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00H005YFFUH005YF000]Ool0
03=oo`8000=JEP03001JEUYF00AJEP@000Aoo`D001Qoo`9JEP05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000eOol200000eYF001JEP06FUH0
0`00FUIJEP09000GOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol30006FUH00`00FUIJEP04FUH7000@Ool500000eYF
00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000050005FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000jOol20004FUH00`00FUIJEP05FUH30003FUH@0003FUH00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006Ool400000eYF001JEP04FUH01000FUIJEUYF0P000goo1`00
15YF00<005YFFUH01EYF00@005YFFUIJEPH0035oo`00?7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P002Woo10000eYF00@005YFFUIJEP8000Yooa0003Moo`00?goo0`001UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000]oo`P000=JEP80055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20008Ool5
0005FUH01000FUIJEP000UYF0P00DGoo0016Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1Goo0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00D005YF000005YF00T000=JEP03001JEUYF00AJEP04001JEUYFFUH4
001AOol004eooa4000]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00AJEP@000AJEP03001JEUYF00AJEP03001J
EUYF009JEP<0055oo`00K7oo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YF000010001UYF00<0
05YFFUH00UYF0`00DGoo001^Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUH0000800000eYF001JEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP02FUH00`00FUH0001AOol0075oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000EJEPP000IJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP80059oo`00N7oo3000
1UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00H0
05YFFUH005YF0003FUH2001COol008Aoo`h00004Ool000000005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH50007FUH40005FUH00`00FUIJEP02FUH200000eYF0000001EOol008moo`@0009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000QJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00Oomoo`1EOol008moo`05001JEP00FUH00003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH2001FOol008moo`8000=JEP03001o
ogoo00=oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000IJEP04001J
EP00001DOol0091oo`04001JEUYFFUH30008OolK0005Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1AOol0091oo`05001JEUYFFUH00002FUH00`00Oomoo`0WOol200000eYF001JEP03FUH00`00Oomo
o`1AOol0095oo`03001JEP0000AJEP8002Uoo`8000AJEP03001oogoo055oo`00TWoo0P001UYF0P00
:Goo00<005YFFUH00P00Dgoo002COol00`00FUIJEP04FUH00`00FUH00003000VOol4001COol009Ao
o`8000AJEP03001JEUYF00=JEPD002=oo`8005=oo`00UWoo00@005YFFUH000QJEP03001JEUYF00@0
01eoo`<005Aoo`00Ugoo0`0025YF00<005YFFUH015YF1`0047oo1P0000=JEP000000E7oo002IOol2
0006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH@0003FUH01000FUIJEUYF0P00E7oo002KOol40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
001EOol009moo`D000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2001EOol00:Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH0001FOol00:Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol0
0:mooaD005Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61036 .76917 m .6008 .71345 L .5701 .71703 L p .707 .577 .707 r
F P
0 g
s
.6008 .71345 m .61036 .76917 L .64177 .76345 L p .707 .577 .707 r
F P
0 g
s
.64177 .76345 m .63221 .70773 L .6008 .71345 L p .707 .577 .707 r
F P
0 g
s
.63221 .70773 m .64177 .76345 L .67082 .75615 L p .707 .577 .707 r
F P
0 g
s
.67082 .75615 m .66126 .70043 L .63221 .70773 L p .707 .577 .707 r
F P
0 g
s
.57966 .77274 m .5701 .71703 L .54311 .71811 L p .707 .577 .707 r
F P
0 g
s
.5701 .71703 m .57966 .77274 L .61036 .76917 L p .707 .577 .707 r
F P
0 g
s
.66126 .70043 m .67082 .75615 L .69466 .74798 L p .707 .577 .707 r
F P
0 g
s
.69466 .74798 m .6851 .69226 L .66126 .70043 L p .707 .577 .707 r
F P
0 g
s
.54311 .71811 m .55267 .77383 L .57966 .77274 L p .707 .577 .707 r
F P
0 g
s
.6131 .85284 m .61284 .81575 L .58167 .81408 L p .707 .577 .707 r
F P
0 g
s
.61284 .81575 m .6131 .85284 L .64494 .85186 L p .707 .577 .707 r
F P
0 g
s
.64494 .85186 m .64467 .81477 L .61284 .81575 L p .707 .577 .707 r
F P
0 g
s
.55267 .77383 m .54311 .71811 L .52248 .7166 L p .707 .577 .707 r
F P
0 g
s
.64467 .81477 m .64494 .85186 L .67432 .84832 L p .707 .577 .707 r
F P
0 g
s
.67432 .84832 m .67405 .81123 L .64467 .81477 L p .707 .577 .707 r
F P
0 g
s
.58193 .85116 m .58167 .81408 L .55421 .80991 L p .707 .577 .707 r
F P
0 g
s
.58167 .81408 m .58193 .85116 L .6131 .85284 L p .707 .577 .707 r
F P
0 g
s
.6851 .69226 m .69466 .74798 L .71095 .73975 L p .707 .577 .707 r
F P
0 g
s
.71095 .73975 m .70139 .68403 L .6851 .69226 L p .707 .577 .707 r
F P
0 g
s
.52248 .7166 m .53204 .77232 L .55267 .77383 L p .707 .577 .707 r
F P
0 g
s
.67405 .81123 m .67432 .84832 L .69837 .84256 L p .707 .577 .707 r
F P
0 g
s
.69837 .84256 m .69811 .80548 L .67405 .81123 L p .707 .577 .707 r
F P
0 g
s
.55421 .80991 m .55447 .84699 L .58193 .85116 L p .707 .577 .707 r
F P
0 g
s
.60053 .89492 m .60538 .87761 L .57531 .86756 L p .707 .577 .707 r
F P
0 g
s
.60538 .87761 m .60053 .89492 L .63137 .90149 L p .707 .577 .707 r
F P
0 g
s
.63137 .90149 m .63622 .88418 L .60538 .87761 L p .707 .577 .707 r
F P
0 g
s
.55447 .84699 m .55421 .80991 L .53315 .80366 L p .707 .577 .707 r
F P
0 g
s
.57046 .88487 m .57531 .86756 L .54896 .85501 L p .707 .577 .707 r
F P
0 g
s
.57531 .86756 m .57046 .88487 L .60053 .89492 L p .707 .577 .707 r
F P
0 g
s
.63622 .88418 m .63137 .90149 L .65996 .90395 L p .707 .577 .707 r
F P
0 g
s
.65996 .90395 m .66481 .88664 L .63622 .88418 L p .707 .577 .707 r
F P
0 g
s
.53204 .77232 m .52248 .7166 L .51023 .71264 L p .707 .577 .707 r
F P
0 g
s
.54896 .85501 m .54411 .87232 L .57046 .88487 L p .707 .577 .707 r
F P
0 g
s
.53315 .80366 m .53342 .84074 L .55447 .84699 L p .707 .577 .707 r
F P
0 g
s
.69811 .80548 m .69837 .84256 L .71474 .83516 L p .707 .577 .707 r
F P
0 g
s
.71474 .83516 m .71447 .79808 L .69811 .80548 L p .707 .577 .707 r
F P
0 g
s
.70139 .68403 m .71095 .73975 L .71811 .73225 L p .707 .577 .707 r
F P
0 g
s
.71811 .73225 m .70855 .67653 L .70139 .68403 L p .707 .577 .707 r
F P
0 g
s
.54411 .87232 m .54896 .85501 L .5289 .84121 L p .707 .577 .707 r
F P
0 g
s
.51023 .71264 m .51979 .76835 L .53204 .77232 L p .707 .577 .707 r
F P
0 g
s
.66481 .88664 m .65996 .90395 L .6835 .90204 L p .707 .577 .707 r
F P
0 g
s
.6835 .90204 m .68836 .88474 L .66481 .88664 L p .707 .577 .707 r
F P
0 g
s
.5289 .84121 m .52405 .85852 L .54411 .87232 L p .707 .577 .707 r
F P
0 g
s
.53342 .84074 m .53315 .80366 L .52056 .79594 L p .707 .577 .707 r
F P
0 g
s
.51979 .76835 m .51023 .71264 L .50755 .70661 L p .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5289 .84121 L .5217 .83284 L p .707 .577 .707 r
F P
0 g
s
.5217 .83284 m .5171 .82749 L p .52282 .85305 L .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5217 .83284 L .52282 .85305 L .707 .577 .707 r
F
.52083 .83302 m .52069 .81467 L p .51767 .7875 L F P
0 g
s
.52069 .81467 m .52056 .79594 L .51948 .79279 L p .707 .577 .707 r
F P
0 g
s
.51948 .79279 m .51767 .7875 L p .52069 .81467 L .707 .577 .707 r
F P
0 g
s
.52056 .79594 m .52083 .83302 L .53342 .84074 L p .707 .577 .707 r
F P
0 g
s
.68836 .88474 m .6835 .90204 L .6997 .89597 L p .707 .577 .707 r
F P
0 g
s
.6997 .89597 m .70455 .87866 L .68836 .88474 L p .707 .577 .707 r
F P
0 g
s
.71447 .79808 m .71474 .83516 L .72182 .82683 L p .707 .577 .707 r
F P
0 g
s
.72182 .82683 m .72156 .78975 L .71447 .79808 L p .707 .577 .707 r
F P
0 g
s
.5171 .82749 m .51224 .8448 L .52405 .85852 L p .707 .577 .707 r
F P
0 g
s
.70855 .67653 m .71811 .73225 L .71543 .72622 L p .707 .577 .707 r
F P
0 g
s
.71543 .72622 m .70587 .67051 L .70855 .67653 L p .707 .577 .707 r
F P
0 g
s
.50755 .70661 m .51711 .76233 L .51979 .76835 L p .707 .577 .707 r
F P
0 g
s
.48447 .81944 m .46656 .31597 L .42258 .31488 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .52083 .83302 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51767 .7875 m .51778 .80424 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51778 .80424 m .51793 .82458 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51224 .8448 m .5171 .82749 L .51471 .8152 L p .707 .577 .707 r
F P
0 g
s
.51471 .8152 m .50986 .83251 L .51224 .8448 L p .707 .577 .707 r
F P
0 g
s
.50986 .83251 m .51471 .8152 L .5169 .81229 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .51767 .7875 L .52475 .77917 L p .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .51793 .82458 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52475 .77917 m .52486 .79522 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52486 .79522 m .52501 .81625 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .52475 .77917 L .54112 .77176 L p .707 .577 .707 r
F P
0 g
s
.51711 .82285 m .52197 .80555 L .52725 .80356 L p .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .52501 .81625 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54112 .77176 m .54124 .78851 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54124 .78851 m .54138 .80885 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .54112 .77176 L .56517 .76601 L p .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .53816 .79947 L .54665 .79878 L p .707 .577 .707 r
F P
0 g
s
.56517 .76601 m .56543 .80309 L .54138 .80885 L p .707 .577 .707 r
F P
0 g
s
.54665 .79878 m .56171 .79757 L p .55013 .80539 L .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .54665 .79878 L .55013 .80539 L .707 .577 .707 r
F
.52725 .80356 m .53816 .79947 L p .529 .80965 L F P
0 g
s
.51711 .82285 m .52725 .80356 L .529 .80965 L .707 .577 .707 r
F
.5169 .81229 m .52197 .80555 L p .51623 .81832 L F P
0 g
s
.50986 .83251 m .5169 .81229 L .51623 .81832 L .707 .577 .707 r
F
.51711 .76233 m .50755 .70661 L .5147 .69912 L p F P
0 g
s
.5147 .69912 m .52426 .75483 L .51711 .76233 L p .707 .577 .707 r
F P
0 g
s
.52197 .80555 m .51711 .82285 L .50986 .83251 L p .707 .577 .707 r
F P
0 g
s
.53816 .79947 m .53331 .81678 L .51711 .82285 L p .707 .577 .707 r
F P
0 g
s
.46656 .31597 m .48447 .81944 L .52938 .8169 L p .707 .577 .707 r
F P
0 g
s
.52426 .75483 m .5147 .69912 L .531 .69088 L p .707 .577 .707 r
F P
0 g
s
.531 .69088 m .54056 .7466 L .52426 .75483 L p .707 .577 .707 r
F P
0 g
s
.52938 .8169 m .51148 .31344 L .46656 .31597 L p .707 .577 .707 r
F P
0 g
s
.54056 .7466 m .531 .69088 L .55484 .68271 L p .707 .577 .707 r
F P
0 g
s
.55484 .68271 m .56439 .73843 L .54056 .7466 L p .707 .577 .707 r
F P
0 g
s
.56439 .73843 m .55484 .68271 L .58388 .67541 L p .707 .577 .707 r
F P
0 g
s
.56171 .79757 m .55685 .81487 L .53331 .81678 L p .707 .577 .707 r
F P
0 g
s
.56543 .80309 m .56517 .76601 L .59455 .76247 L p .707 .577 .707 r
F P
0 g
s
.59455 .76247 m .59482 .79955 L .56543 .80309 L p .707 .577 .707 r
F P
0 g
s
.55685 .81487 m .56171 .79757 L .5903 .80002 L p .707 .577 .707 r
F P
0 g
s
.5903 .80002 m .58544 .81733 L .55685 .81487 L p .707 .577 .707 r
F P
0 g
s
.51148 .31344 m .52938 .8169 L .57084 .81099 L p .707 .577 .707 r
F P
0 g
s
.58388 .67541 m .59344 .73113 L .56439 .73843 L p .707 .577 .707 r
F P
0 g
s
.57084 .81099 m .55294 .30753 L .51148 .31344 L p .707 .577 .707 r
F P
0 g
s
.70455 .87866 m .6997 .89597 L .70696 .88631 L p .707 .577 .707 r
F P
0 g
s
.70696 .88631 m .71181 .869 L .70455 .87866 L p .707 .577 .707 r
F P
0 g
s
.72156 .78975 m .72182 .82683 L .71893 .81839 L p .707 .577 .707 r
F P
0 g
s
.71893 .81839 m .71866 .78131 L .72156 .78975 L p .707 .577 .707 r
F P
0 g
s
.44049 .81834 m .42258 .31488 L .38384 .31027 L p .707 .577 .707 r
F P
0 g
s
.42258 .31488 m .44049 .81834 L .48447 .81944 L p .707 .577 .707 r
F P
0 g
s
.26735 .68432 m .2578 .6286 L .22709 .63218 L p .707 .577 .707 r
F P
0 g
s
.2578 .6286 m .26735 .68432 L .29876 .6786 L p .707 .577 .707 r
F P
0 g
s
.29876 .6786 m .28921 .62288 L .2578 .6286 L p .707 .577 .707 r
F P
0 g
s
.70587 .67051 m .71543 .72622 L .70317 .72226 L p .707 .577 .707 r
F P
0 g
s
.70317 .72226 m .69361 .66655 L .70587 .67051 L p .707 .577 .707 r
F P
0 g
s
.28921 .62288 m .29876 .6786 L .32781 .6713 L p .707 .577 .707 r
F P
0 g
s
.32781 .6713 m .31825 .61558 L .28921 .62288 L p .707 .577 .707 r
F P
0 g
s
.23665 .6879 m .22709 .63218 L .20011 .63327 L p .707 .577 .707 r
F P
0 g
s
.22709 .63218 m .23665 .6879 L .26735 .68432 L p .707 .577 .707 r
F P
0 g
s
.59344 .73113 m .58388 .67541 L .61529 .66969 L p .707 .577 .707 r
F P
0 g
s
.61529 .66969 m .62485 .72541 L .59344 .73113 L p .707 .577 .707 r
F P
0 g
s
.59482 .79955 m .59455 .76247 L .62639 .76149 L p .707 .577 .707 r
F P
0 g
s
.62639 .76149 m .62665 .79857 L .59482 .79955 L p .707 .577 .707 r
F P
0 g
s
.58544 .81733 m .5903 .80002 L .62114 .8066 L p .707 .577 .707 r
F P
0 g
s
.55294 .30753 m .57084 .81099 L .60479 .80228 L p .707 .577 .707 r
F P
0 g
s
.60479 .80228 m .58688 .29882 L .55294 .30753 L p .707 .577 .707 r
F P
0 g
s
.31825 .61558 m .32781 .6713 L .35165 .66313 L p .707 .577 .707 r
F P
0 g
s
.35165 .66313 m .34209 .60742 L .31825 .61558 L p .707 .577 .707 r
F P
0 g
s
.27009 .73326 m .26983 .69618 L .23866 .6945 L p .707 .577 .707 r
F P
0 g
s
.26983 .69618 m .27009 .73326 L .30193 .73228 L p .707 .577 .707 r
F P
0 g
s
.30193 .73228 m .30166 .6952 L .26983 .69618 L p .707 .577 .707 r
F P
0 g
s
.30166 .6952 m .30193 .73228 L .33131 .72874 L p .707 .577 .707 r
F P
0 g
s
.33131 .72874 m .33104 .69166 L .30166 .6952 L p .707 .577 .707 r
F P
0 g
s
.20011 .63327 m .20966 .68898 L .23665 .6879 L p .707 .577 .707 r
F P
0 g
s
.23892 .73158 m .23866 .6945 L .2112 .69033 L p .707 .577 .707 r
F P
0 g
s
.23866 .6945 m .23892 .73158 L .27009 .73326 L p .707 .577 .707 r
F P
0 g
s
.40175 .81374 m .38384 .31027 L .35414 .3026 L p .707 .577 .707 r
F P
0 g
s
.38384 .31027 m .40175 .81374 L .44049 .81834 L p .707 .577 .707 r
F P
0 g
s
.71181 .869 m .70696 .88631 L .70457 .87402 L p .707 .577 .707 r
F P
0 g
s
.70457 .87402 m .70942 .85672 L .71181 .869 L p .707 .577 .707 r
F P
0 g
s
.20966 .68898 m .20011 .63327 L .17947 .63175 L p .707 .577 .707 r
F P
0 g
s
.71866 .78131 m .71893 .81839 L .70633 .81067 L p .707 .577 .707 r
F P
0 g
s
.70633 .81067 m .70607 .77359 L .71866 .78131 L p .707 .577 .707 r
F P
0 g
s
.33104 .69166 m .33131 .72874 L .35536 .72299 L p .707 .577 .707 r
F P
0 g
s
.35536 .72299 m .3551 .6859 L .33104 .69166 L p .707 .577 .707 r
F P
0 g
s
.69361 .66655 m .70317 .72226 L .68254 .72075 L p .707 .577 .707 r
F P
0 g
s
.68254 .72075 m .67298 .66503 L .69361 .66655 L p .707 .577 .707 r
F P
0 g
s
.2112 .69033 m .21146 .72741 L .23892 .73158 L p .707 .577 .707 r
F P
0 g
s
.34209 .60742 m .35165 .66313 L .36794 .6549 L p .707 .577 .707 r
F P
0 g
s
.36794 .6549 m .35838 .59918 L .34209 .60742 L p .707 .577 .707 r
F P
0 g
s
.17947 .63175 m .18903 .68747 L .1909 .68761 L p .707 .577 .707 r
F P
0 g
s
.1909 .68761 m .20966 .68898 L p .19378 .65887 L .707 .577 .707 r
F P
0 g
s
.19378 .65887 m .17947 .63175 L .1909 .68761 L .707 .577 .707 r
F
.18903 .68747 m .17947 .63175 L .16722 .62779 L p F P
0 g
s
.16722 .62779 m .17678 .68351 L .17779 .68383 L p .707 .577 .707 r
F P
0 g
s
.17779 .68383 m .18903 .68747 L p .1786 .65894 L .707 .577 .707 r
F P
0 g
s
.1786 .65894 m .16722 .62779 L .17779 .68383 L .707 .577 .707 r
F
.17678 .68351 m .16722 .62779 L .16454 .62176 L p F P
0 g
s
.16454 .62176 m .1741 .67748 L .17428 .6779 L p .707 .577 .707 r
F P
0 g
s
.17428 .6779 m .17678 .68351 L p .17111 .6549 L .707 .577 .707 r
F P
0 g
s
.17111 .6549 m .16454 .62176 L .17428 .6779 L .707 .577 .707 r
F
.17755 .67636 m .17466 .66792 L p .17714 .70375 L F P
0 g
s
.17764 .68853 m .17755 .67636 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .17755 .67636 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.17755 .67636 m .17782 .71344 L .19041 .72116 L p .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .18174 .65959 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .17475 .6813 L p .17782 .71344 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17492 .705 L .17616 .70863 L p .707 .577 .707 r
F P
0 g
s
.17616 .70863 m .17782 .71344 L p .17475 .6813 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17466 .66792 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17782 .71344 m .17764 .68853 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.18174 .65959 m .18184 .67339 L p .17492 .705 L .707 .577 .707 r
F P
0 g
s
.18184 .67339 m .182 .69667 L .17905 .70014 L p .707 .577 .707 r
F P
0 g
s
.17905 .70014 m .17492 .705 L p .18184 .67339 L .707 .577 .707 r
F P
0 g
s
.182 .69667 m .18174 .65959 L .19811 .65219 L p .707 .577 .707 r
F P
0 g
s
.18799 .60603 m .18852 .60914 L p .18125 .66998 L .707 .577 .707 r
F P
0 g
s
.19022 .69438 m .19014 .68408 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.21146 .72741 m .2112 .69033 L .19014 .68408 L p .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .19041 .72116 L .21146 .72741 L p .707 .577 .707 r
F P
0 g
s
.19811 .65219 m .1982 .66557 L p .182 .69667 L .707 .577 .707 r
F P
0 g
s
.1982 .66557 m .19837 .68927 L .1922 .69206 L p .707 .577 .707 r
F P
0 g
s
.1922 .69206 m .182 .69667 L p .1982 .66557 L .707 .577 .707 r
F P
0 g
s
.19837 .68927 m .19811 .65219 L .22216 .64643 L p .707 .577 .707 r
F P
0 g
s
.21183 .59787 m .21257 .60218 L p .19755 .66175 L .707 .577 .707 r
F P
0 g
s
.22216 .64643 m .22225 .65861 L p .19837 .68927 L .707 .577 .707 r
F P
0 g
s
.22225 .65861 m .22242 .68352 L .21493 .68531 L p .707 .577 .707 r
F P
0 g
s
.21493 .68531 m .19837 .68927 L p .22225 .65861 L .707 .577 .707 r
F P
0 g
s
.22242 .68352 m .22216 .64643 L .25154 .64289 L p .707 .577 .707 r
F P
0 g
s
.24087 .59057 m .24089 .59064 L p .22139 .65358 L .707 .577 .707 r
F P
0 g
s
.25154 .64289 m .25162 .65319 L p .22242 .68352 L .707 .577 .707 r
F P
0 g
s
.25162 .65319 m .25181 .67998 L .24548 .68074 L p .707 .577 .707 r
F P
0 g
s
.24548 .68074 m .22242 .68352 L p .25162 .65319 L .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .24087 .59057 L .2666 .58588 L p .707 .577 .707 r
F P
0 g
s
.2666 .58588 m .27228 .58485 L p .25771 .62581 L .707 .577 .707 r
F P
0 g
s
.25181 .67998 m .25154 .64289 L .28338 .64191 L p .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .2666 .58588 L .25771 .62581 L .707 .577 .707 r
F
.24089 .59064 m .25043 .64628 L .22379 .65298 L p F P
0 g
s
.22379 .65298 m .22139 .65358 L p .24089 .59064 L .707 .577 .707 r
F P
0 g
s
.21257 .60218 m .22139 .65358 L .1992 .66118 L p .707 .577 .707 r
F P
0 g
s
.1992 .66118 m .19755 .66175 L p .21257 .60218 L .707 .577 .707 r
F P
0 g
s
.18852 .60914 m .19755 .66175 L .18224 .66948 L p .707 .577 .707 r
F P
0 g
s
.18224 .66948 m .18125 .66998 L p .18852 .60914 L .707 .577 .707 r
F P
0 g
s
.1717 .61427 m .18125 .66998 L .17453 .67703 L p .707 .577 .707 r
F P
0 g
s
.17453 .67703 m .1741 .67748 L p .17283 .64419 L .707 .577 .707 r
F P
0 g
s
.17283 .64419 m .1717 .61427 L .17453 .67703 L .707 .577 .707 r
F
.17492 .705 m .17475 .6813 L p .17654 .69423 L F P
0 g
s
.19041 .72116 m .19022 .69438 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.62485 .72541 m .61529 .66969 L .64599 .66612 L p .707 .577 .707 r
F P
0 g
s
.62665 .79857 m .62639 .76149 L .65756 .76317 L p .707 .577 .707 r
F P
0 g
s
.58688 .29882 m .60479 .80228 L .62789 .79163 L p .707 .577 .707 r
F P
0 g
s
.64599 .66612 m .65555 .72183 L .62485 .72541 L p .707 .577 .707 r
F P
0 g
s
.62789 .79163 m .60999 .28816 L .58688 .29882 L p .707 .577 .707 r
F P
0 g
s
.25752 .78844 m .26237 .77113 L .23231 .76108 L p .707 .577 .707 r
F P
0 g
s
.26237 .77113 m .25752 .78844 L .28836 .79501 L p .707 .577 .707 r
F P
0 g
s
.28836 .79501 m .29321 .7777 L .26237 .77113 L p .707 .577 .707 r
F P
0 g
s
.22745 .77839 m .23231 .76108 L .20595 .74854 L p .707 .577 .707 r
F P
0 g
s
.23231 .76108 m .22745 .77839 L .25752 .78844 L p .707 .577 .707 r
F P
0 g
s
.29321 .7777 m .28836 .79501 L .31695 .79747 L p .707 .577 .707 r
F P
0 g
s
.31695 .79747 m .3218 .78016 L .29321 .7777 L p .707 .577 .707 r
F P
0 g
s
.20595 .74854 m .2011 .76585 L .22745 .77839 L p .707 .577 .707 r
F P
0 g
s
.3551 .6859 m .35536 .72299 L .37173 .71558 L p .707 .577 .707 r
F P
0 g
s
.37173 .71558 m .37147 .6785 L .3551 .6859 L p .707 .577 .707 r
F P
0 g
s
.70942 .85672 m .70457 .87402 L .69277 .8603 L p .707 .577 .707 r
F P
0 g
s
.69277 .8603 m .69762 .843 L .70942 .85672 L p .707 .577 .707 r
F P
0 g
s
.35838 .59918 m .36794 .6549 L .3751 .6474 L p .707 .577 .707 r
F P
0 g
s
.3751 .6474 m .36554 .59169 L .35838 .59918 L p .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .36554 .59169 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .37004 .62752 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37004 .62752 m .36286 .58566 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.35414 .3026 m .33639 .2926 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .36563 .62558 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .40175 .81374 L p .39549 .7465 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .36928 .64036 L p .36774 .63412 L .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .37004 .62752 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.37147 .6785 m .37173 .71558 L .37881 .70725 L p .707 .577 .707 r
F P
0 g
s
.37881 .70725 m .37855 .67017 L .37147 .6785 L p .707 .577 .707 r
F P
0 g
s
.37855 .67017 m .37881 .70725 L .37592 .69881 L p .707 .577 .707 r
F P
0 g
s
.37592 .69881 m .37565 .66173 L .37855 .67017 L p .707 .577 .707 r
F P
0 g
s
.36563 .62558 m .37205 .80606 L p .3724 .80516 L .707 .577 .707 r
F P
0 g
s
.37565 .66173 m .37592 .69881 L .37357 .69738 L p .707 .577 .707 r
F P
0 g
s
.37391 .66589 m .37565 .66173 L .37357 .69738 L .707 .577 .707 r
F
.37398 .65939 m .36563 .62558 L .3724 .80516 L F
.34535 .77826 m .3405 .79557 L .35669 .78949 L p F P
0 g
s
.35669 .78949 m .36154 .77218 L .34535 .77826 L p .707 .577 .707 r
F P
0 g
s
.36154 .77218 m .35669 .78949 L .36395 .77983 L p .707 .577 .707 r
F P
0 g
s
.36395 .77983 m .3688 .76253 L .36154 .77218 L p .707 .577 .707 r
F P
0 g
s
.3688 .76253 m .36395 .77983 L .36156 .76755 L p .707 .577 .707 r
F P
0 g
s
.36156 .76755 m .36641 .75024 L .3688 .76253 L p .707 .577 .707 r
F P
0 g
s
.36641 .75024 m .36156 .76755 L .35564 .76067 L p .707 .577 .707 r
F P
0 g
s
.35564 .76067 m .34976 .75383 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35497 .7527 m .36641 .75024 L .35564 .76067 L .707 .577 .707 r
F
.35787 .68947 m .34227 .68484 L p .35651 .66372 L F P
0 g
s
.35461 .73652 m .36641 .75024 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.34976 .75383 m .35385 .73924 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35385 .73924 m .35461 .73652 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35461 .73652 m .34976 .75383 L .33746 .74537 L p .707 .577 .707 r
F P
0 g
s
.33746 .74537 m .3297 .74002 L p .33749 .73893 L .707 .577 .707 r
F P
0 g
s
.33749 .73893 m .35461 .73652 L .33746 .74537 L .707 .577 .707 r
F
.3506 .5817 m .35752 .62201 L p .33953 .6359 L F P
0 g
s
.35675 .63716 m .33953 .6359 L p .35752 .62201 L .707 .577 .707 r
F P
0 g
s
.33953 .6359 m .32997 .58018 L .3506 .5817 L p .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .35932 .6228 L .35756 .68358 L .707 .577 .707 r
F
.34227 .68484 m .34201 .64776 L .35588 .65188 L p F P
0 g
s
.35932 .6228 m .35423 .62056 L .35756 .68358 L .707 .577 .707 r
F
.35588 .65188 m .36306 .65401 L p .35651 .66372 L F P
0 g
s
.34227 .68484 m .35588 .65188 L .35651 .66372 L .707 .577 .707 r
F
.3297 .74002 m .33455 .72271 L .35461 .73652 L p F P
0 g
s
.34795 .61779 m .35429 .79607 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.35423 .62056 m .34795 .61779 L .35756 .68358 L .707 .577 .707 r
F
.33231 .28128 m .34471 .62993 L p .34979 .69075 L F P
0 g
s
.34471 .62993 m .35022 .78474 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .33231 .28128 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3511 .70639 m .33639 .2926 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3506 .5817 m .36286 .58566 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .3506 .5817 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .34795 .61779 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .33852 .45592 L p .34231 .26972 L .707 .577 .707 r
F P
0 g
s
.33852 .45592 m .33231 .28128 L .33919 .27333 L p .707 .577 .707 r
F P
0 g
s
.33919 .27333 m .34231 .26972 L p .33852 .45592 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .35429 .79607 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .36016 .63741 L .35675 .63716 L p .707 .577 .707 r
F P
0 g
s
.35429 .79607 m .3511 .70639 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.36377 .80141 m .37205 .80606 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.36306 .65401 m .36332 .69109 L .35787 .68947 L p .707 .577 .707 r
F P
0 g
s
.35651 .66372 m .36306 .65401 L .35787 .68947 L .707 .577 .707 r
F
.35429 .79607 m .36377 .80141 L p .35756 .68358 L F P
0 g
s
.36016 .63741 m .35752 .62201 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .36306 .65401 L .37397 .6607 L p .707 .577 .707 r
F P
0 g
s
.37397 .6607 m .37565 .66173 L p .37391 .66589 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .37397 .6607 L .37391 .66589 L .707 .577 .707 r
F
.37004 .62752 m .37242 .64138 L p .36774 .63412 L F P
0 g
s
.36089 .62349 m .36563 .62558 L .36774 .63412 L .707 .577 .707 r
F
.36563 .62558 m .37004 .62752 L .36774 .63412 L F
.36554 .59169 m .3751 .6474 L .37242 .64138 L p F P
0 g
s
.35414 .3026 m .36563 .62558 L p .37398 .65939 L .707 .577 .707 r
F P
0 g
s
.39549 .7465 m .37537 .53052 L .37398 .65939 L .707 .577 .707 r
F
.37537 .53052 m .35414 .3026 L .37398 .65939 L F
.39549 .7465 m .37398 .65939 L .3724 .80516 L F
.37357 .69738 m .36332 .69109 L p .37391 .66589 L F P
0 g
s
.36016 .63741 m .36089 .62349 L .36774 .63412 L .707 .577 .707 r
F
.36928 .64036 m .36016 .63741 L p .36774 .63412 L F P
0 g
s
.35932 .6228 m .36468 .59898 L .35354 .53961 L .707 .577 .707 r
F
.36563 .62558 m .36468 .59898 L p .35932 .6228 L F P
0 g
s
.36468 .59898 m .35414 .3026 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.2011 .76585 m .20595 .74854 L .18589 .73473 L p .707 .577 .707 r
F P
0 g
s
.67298 .66503 m .68254 .72075 L .65555 .72183 L p .707 .577 .707 r
F P
0 g
s
.65555 .72183 m .64599 .66612 L .67298 .66503 L p .707 .577 .707 r
F P
0 g
s
.70607 .77359 m .70633 .81067 L .68528 .80442 L p .707 .577 .707 r
F P
0 g
s
.68528 .80442 m .68502 .76734 L .70607 .77359 L p .707 .577 .707 r
F P
0 g
s
.3218 .78016 m .31695 .79747 L .3405 .79557 L p .707 .577 .707 r
F P
0 g
s
.3405 .79557 m .34535 .77826 L .3218 .78016 L p .707 .577 .707 r
F P
0 g
s
.18589 .73473 m .18104 .75204 L .2011 .76585 L p .707 .577 .707 r
F P
0 g
s
.60999 .28816 m .62789 .79163 L .6379 .78007 L p .707 .577 .707 r
F P
0 g
s
.6379 .78007 m .61999 .27661 L .60999 .28816 L p .707 .577 .707 r
F P
0 g
s
.18104 .75204 m .18589 .73473 L .17409 .72101 L p .707 .577 .707 r
F P
0 g
s
.69762 .843 m .69277 .8603 L .67271 .8465 L p .707 .577 .707 r
F P
0 g
s
.67271 .8465 m .67756 .82919 L .69762 .843 L p .707 .577 .707 r
F P
0 g
s
.68502 .76734 m .68528 .80442 L .65782 .80025 L p .707 .577 .707 r
F P
0 g
s
.65782 .80025 m .65756 .76317 L .68502 .76734 L p .707 .577 .707 r
F P
0 g
s
.17409 .72101 m .16924 .73832 L .18104 .75204 L p .707 .577 .707 r
F P
0 g
s
.65756 .76317 m .65782 .80025 L .62665 .79857 L p .707 .577 .707 r
F P
0 g
s
.67756 .82919 m .67271 .8465 L .64635 .83396 L p .707 .577 .707 r
F P
0 g
s
.64635 .83396 m .65121 .81665 L .67756 .82919 L p .707 .577 .707 r
F P
0 g
s
.16924 .73832 m .17409 .72101 L .1717 .70872 L p .707 .577 .707 r
F P
0 g
s
.1717 .70872 m .16685 .72603 L .16924 .73832 L p .707 .577 .707 r
F P
0 g
s
.1741 .67748 m .16454 .62176 L .1717 .61427 L p .707 .577 .707 r
F P
0 g
s
.65121 .81665 m .64635 .83396 L .61628 .8239 L p .707 .577 .707 r
F P
0 g
s
.61628 .8239 m .62114 .8066 L .65121 .81665 L p .707 .577 .707 r
F P
0 g
s
.62114 .8066 m .61628 .8239 L .58544 .81733 L p .707 .577 .707 r
F P
0 g
s
.61999 .27661 m .6379 .78007 L .63382 .76875 L p .707 .577 .707 r
F P
0 g
s
.63382 .76875 m .61591 .26528 L .61999 .27661 L p .707 .577 .707 r
F P
0 g
s
.16685 .72603 m .1717 .70872 L .17896 .69907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17896 .69907 m .1741 .71638 L .16685 .72603 L p .707 .577 .707 r
F P
0 g
s
.18125 .66998 m .1717 .61427 L .18799 .60603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.61591 .26528 m .63382 .76875 L .61606 .75876 L p .707 .577 .707 r
F P
0 g
s
.61606 .75876 m .59816 .25529 L .61591 .26528 L p .707 .577 .707 r
F P
0 g
s
.1741 .71638 m .17896 .69907 L .19515 .69299 L p .707 .577 .707 r
F P
0 g
s
.19755 .66175 m .18799 .60603 L .21183 .59787 L p .707 .577 .707 r
F P
0 g
s
.19515 .69299 m .1903 .7103 L .1741 .71638 L p .707 .577 .707 r
F P
0 g
s
.32997 .58018 m .33953 .6359 L .31254 .63699 L p .707 .577 .707 r
F P
0 g
s
.31254 .63699 m .30299 .58127 L .32997 .58018 L p .707 .577 .707 r
F P
0 g
s
.36022 .77319 m .34231 .26972 L .36542 .25907 L p .707 .577 .707 r
F P
0 g
s
.34231 .26972 m .36022 .77319 L .35022 .78474 L p .707 .577 .707 r
F P
0 g
s
.22139 .65358 m .21183 .59787 L .24087 .59057 L p .707 .577 .707 r
F P
0 g
s
.34201 .64776 m .34227 .68484 L .31481 .68067 L p .707 .577 .707 r
F P
0 g
s
.31481 .68067 m .31455 .64359 L .34201 .64776 L p .707 .577 .707 r
F P
0 g
s
.1903 .7103 m .19515 .69299 L .2187 .69109 L p .707 .577 .707 r
F P
0 g
s
.30299 .58127 m .31254 .63699 L .28184 .64056 L p .707 .577 .707 r
F P
0 g
s
.28184 .64056 m .27228 .58485 L .30299 .58127 L p .707 .577 .707 r
F P
0 g
s
.2187 .69109 m .21384 .7084 L .1903 .7103 L p .707 .577 .707 r
F P
0 g
s
.27228 .58485 m .28184 .64056 L .25043 .64628 L p .707 .577 .707 r
F P
0 g
s
.59816 .25529 m .61606 .75876 L .58636 .75108 L p .707 .577 .707 r
F P
0 g
s
.58636 .75108 m .56846 .24761 L .59816 .25529 L p .707 .577 .707 r
F P
0 g
s
.31455 .64359 m .31481 .68067 L .28364 .679 L p .707 .577 .707 r
F P
0 g
s
.28364 .679 m .28338 .64191 L .31455 .64359 L p .707 .577 .707 r
F P
0 g
s
.21384 .7084 m .2187 .69109 L .24729 .69354 L p .707 .577 .707 r
F P
0 g
s
.28338 .64191 m .28364 .679 L .25181 .67998 L p .707 .577 .707 r
F P
0 g
s
.33455 .72271 m .3297 .74002 L .30334 .72748 L p .707 .577 .707 r
F P
0 g
s
.30334 .72748 m .3082 .71017 L .33455 .72271 L p .707 .577 .707 r
F P
0 g
s
.74757 .67713 m .73801 .62141 L .70731 .62499 L p .707 .577 .707 r
F P
0 g
s
.73801 .62141 m .74757 .67713 L .77898 .67141 L p .707 .577 .707 r
F P
0 g
s
.77898 .67141 m .76942 .61569 L .73801 .62141 L p .707 .577 .707 r
F P
0 g
s
.76942 .61569 m .77898 .67141 L .80802 .66411 L p .707 .577 .707 r
F P
0 g
s
.80802 .66411 m .79846 .60839 L .76942 .61569 L p .707 .577 .707 r
F P
0 g
s
.24729 .69354 m .24244 .71085 L .21384 .7084 L p .707 .577 .707 r
F P
0 g
s
.36542 .25907 m .38332 .76253 L .36022 .77319 L p .707 .577 .707 r
F P
0 g
s
.38332 .76253 m .36542 .25907 L .39936 .25036 L p .707 .577 .707 r
F P
0 g
s
.71686 .68071 m .70731 .62499 L .68032 .62607 L p .707 .577 .707 r
F P
0 g
s
.70731 .62499 m .71686 .68071 L .74757 .67713 L p .707 .577 .707 r
F P
0 g
s
.24244 .71085 m .24729 .69354 L .27813 .70012 L p .707 .577 .707 r
F P
0 g
s
.79846 .60839 m .80802 .66411 L .83186 .65594 L p .707 .577 .707 r
F P
0 g
s
.83186 .65594 m .8223 .60023 L .79846 .60839 L p .707 .577 .707 r
F P
0 g
s
.3082 .71017 m .30334 .72748 L .27327 .71743 L p .707 .577 .707 r
F P
0 g
s
.27327 .71743 m .27813 .70012 L .3082 .71017 L p .707 .577 .707 r
F P
0 g
s
.27813 .70012 m .27327 .71743 L .24244 .71085 L p .707 .577 .707 r
F P
0 g
s
.68032 .62607 m .68988 .68179 L .71686 .68071 L p .707 .577 .707 r
F P
0 g
s
.56846 .24761 m .58636 .75108 L .54763 .74647 L p .707 .577 .707 r
F P
0 g
s
.54763 .74647 m .52972 .243 L .56846 .24761 L p .707 .577 .707 r
F P
0 g
s
.7503 .7608 m .75004 .72372 L .71887 .72204 L p .707 .577 .707 r
F P
0 g
s
.75004 .72372 m .7503 .7608 L .78214 .75982 L p .707 .577 .707 r
F P
0 g
s
.78214 .75982 m .78188 .72274 L .75004 .72372 L p .707 .577 .707 r
F P
0 g
s
.68988 .68179 m .68032 .62607 L .65969 .62456 L p .707 .577 .707 r
F P
0 g
s
.78188 .72274 m .78214 .75982 L .81152 .75628 L p .707 .577 .707 r
F P
0 g
s
.81152 .75628 m .81126 .7192 L .78188 .72274 L p .707 .577 .707 r
F P
0 g
s
.71913 .75912 m .71887 .72204 L .69141 .71787 L p .707 .577 .707 r
F P
0 g
s
.71887 .72204 m .71913 .75912 L .7503 .7608 L p .707 .577 .707 r
F P
0 g
s
.8223 .60023 m .83186 .65594 L .84815 .64771 L p .707 .577 .707 r
F P
0 g
s
.84815 .64771 m .8386 .59199 L .8223 .60023 L p .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .44082 .24445 L p .42565 .57266 L .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .41858 .57404 L .42563 .57266 L .707 .577 .707 r
F
.42252 .64037 m .42563 .57266 L .42564 .57281 L F
.41727 .75383 m .41496 .68878 L p .42252 .64037 L F P
0 g
s
.41496 .68878 m .39936 .25036 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .41496 .68878 L p .38332 .76253 L .707 .577 .707 r
F P
0 g
s
.41496 .68878 m .41727 .75383 L .41174 .75524 L p .707 .577 .707 r
F P
0 g
s
.41174 .75524 m .38332 .76253 L p .41496 .68878 L .707 .577 .707 r
F P
0 g
s
.395 .53656 m .40456 .59228 L .41976 .58951 L p .707 .577 .707 r
F P
0 g
s
.41858 .57404 m .39936 .25036 L .42565 .57266 L .707 .577 .707 r
F
.43088 .64049 m .43913 .64024 L p .43007 .63005 L F P
0 g
s
.46641 .6041 m .4649 .5829 L .48574 .24191 L .707 .577 .707 r
F
.44082 .24445 m .47655 .24243 L p .4649 .5829 L F P
0 g
s
.47655 .24243 m .48574 .24191 L p .4649 .5829 L .707 .577 .707 r
F P
0 g
s
.46431 .60009 m .43887 .60316 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.43597 .58656 m .45758 .58113 L p .45296 .56912 L .707 .577 .707 r
F P
0 g
s
.45231 .56743 m .44082 .24445 L p .46641 .6041 L .707 .577 .707 r
F P
0 g
s
.43332 .57115 m .43597 .58656 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.43887 .60316 m .43913 .64024 L .46303 .63736 L p .707 .577 .707 r
F P
0 g
s
.46326 .63076 m .43887 .60316 L .46303 .63736 L .707 .577 .707 r
F
.45873 .74792 m .45571 .66309 L p .46227 .65417 L F P
0 g
s
.45873 .74792 m .41727 .75383 L p .42142 .66396 L .707 .577 .707 r
F P
0 g
s
.43077 .58751 m .43597 .58656 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.44082 .24445 m .4489 .47144 L p .43332 .57115 L .707 .577 .707 r
F P
0 g
s
.43913 .64024 m .43887 .60316 L .42802 .60349 L p .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .42564 .57281 L .4281 .6046 L .707 .577 .707 r
F
.43913 .64024 m .42802 .60349 L .43007 .63005 L F
.43597 .58656 m .43332 .57115 L p .43173 .58139 L F P
0 g
s
.4489 .47144 m .45571 .66309 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.42802 .60349 m .40703 .60414 L p .43007 .63005 L .707 .577 .707 r
F P
0 g
s
.4281 .6046 m .42565 .57266 L .43332 .57115 L .707 .577 .707 r
F
.42564 .57281 m .42565 .57266 L .4281 .6046 L F
.42565 .57266 m .44082 .24445 L .43332 .57115 L F
.45546 .52355 m .42641 .53085 L p .45514 .56688 L F P
0 g
s
.46501 .57926 m .46264 .56541 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.46264 .56541 m .45546 .52355 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.42564 .57281 m .42563 .57266 L .42565 .57266 L .707 .577 .707 r
F
.42641 .53085 m .395 .53656 L p .43173 .58139 L F P
0 g
s
.43332 .57115 m .42641 .53085 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.42142 .66396 m .42252 .64037 L .45571 .66309 L .707 .577 .707 r
F
.45571 .66309 m .45873 .74792 L p .42142 .66396 L F P
0 g
s
.45415 .70543 m .45901 .68812 L .43861 .68637 L p .707 .577 .707 r
F P
0 g
s
.43861 .68637 m .43042 .68567 L p .43582 .69017 L .707 .577 .707 r
F P
0 g
s
.45415 .70543 m .43861 .68637 L .43582 .69017 L .707 .577 .707 r
F
.46227 .65417 m .45231 .56743 L .46436 .59877 L F
.45571 .66309 m .45231 .56743 L p .46227 .65417 L F P
0 g
s
.46018 .72077 m .46436 .59877 L .46641 .6041 L .707 .577 .707 r
F
.45873 .74792 m .46436 .59877 L .46018 .72077 L F
.48574 .24191 m .50365 .74538 L .45873 .74792 L p F P
0 g
s
.46303 .63736 m .46851 .6367 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46825 .59962 L .46431 .60009 L p .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46431 .60009 L .46326 .63076 L .707 .577 .707 r
F
.46501 .57926 m .45514 .56688 L .45296 .56912 L F
.45758 .58113 m .46501 .57926 L p .45296 .56912 L F P
0 g
s
.41976 .58951 m .43077 .58751 L p .42056 .57296 L .707 .577 .707 r
F P
0 g
s
.42056 .57296 m .395 .53656 L .41976 .58951 L .707 .577 .707 r
F
.40703 .60414 m .40729 .64122 L .43088 .64049 L p F P
0 g
s
.43007 .63005 m .40703 .60414 L .43088 .64049 L .707 .577 .707 r
F
.42641 .53085 m .43332 .57115 L p .45514 .56688 L F P
0 g
s
.43173 .58139 m .395 .53656 L .43077 .58751 L .707 .577 .707 r
F
.65969 .62456 m .66925 .68028 L .68988 .68179 L p F P
0 g
s
.81126 .7192 m .81152 .75628 L .83557 .75053 L p .707 .577 .707 r
F P
0 g
s
.83557 .75053 m .83531 .71344 L .81126 .7192 L p .707 .577 .707 r
F P
0 g
s
.69141 .71787 m .69168 .75495 L .71913 .75912 L p .707 .577 .707 r
F P
0 g
s
.73773 .80288 m .74259 .78557 L .71252 .77552 L p .707 .577 .707 r
F P
0 g
s
.74259 .78557 m .73773 .80288 L .76857 .80945 L p .707 .577 .707 r
F P
0 g
s
.76857 .80945 m .77343 .79215 L .74259 .78557 L p .707 .577 .707 r
F P
0 g
s
.52972 .243 m .54763 .74647 L .50365 .74538 L p .707 .577 .707 r
F P
0 g
s
.50365 .74538 m .48574 .24191 L .52972 .243 L p .707 .577 .707 r
F P
0 g
s
.69168 .75495 m .69141 .71787 L .67036 .71162 L p .707 .577 .707 r
F P
0 g
s
.70766 .79283 m .71252 .77552 L .68616 .76298 L p .707 .577 .707 r
F P
0 g
s
.71252 .77552 m .70766 .79283 L .73773 .80288 L p .707 .577 .707 r
F P
0 g
s
.77343 .79215 m .76857 .80945 L .79716 .81191 L p .707 .577 .707 r
F P
0 g
s
.79716 .81191 m .80202 .7946 L .77343 .79215 L p .707 .577 .707 r
F P
0 g
s
.66925 .68028 m .65969 .62456 L .64743 .6206 L p .707 .577 .707 r
F P
0 g
s
.68616 .76298 m .68131 .78029 L .70766 .79283 L p .707 .577 .707 r
F P
0 g
s
.67036 .71162 m .67062 .7487 L .69168 .75495 L p .707 .577 .707 r
F P
0 g
s
.83531 .71344 m .83557 .75053 L .85194 .74312 L p .707 .577 .707 r
F P
0 g
s
.85194 .74312 m .85168 .70604 L .83531 .71344 L p .707 .577 .707 r
F P
0 g
s
.8386 .59199 m .84815 .64771 L .85531 .64021 L p .707 .577 .707 r
F P
0 g
s
.85531 .64021 m .84575 .58449 L .8386 .59199 L p .707 .577 .707 r
F P
0 g
s
.68131 .78029 m .68616 .76298 L .6661 .74917 L p .707 .577 .707 r
F P
0 g
s
.64743 .6206 m .65699 .67632 L .66925 .68028 L p .707 .577 .707 r
F P
0 g
s
.80202 .7946 m .79716 .81191 L .82071 .81001 L p .707 .577 .707 r
F P
0 g
s
.82071 .81001 m .82556 .7927 L .80202 .7946 L p .707 .577 .707 r
F P
0 g
s
.6661 .74917 m .66125 .76648 L .68131 .78029 L p .707 .577 .707 r
F P
0 g
s
.67062 .7487 m .67036 .71162 L .65777 .7039 L p .707 .577 .707 r
F P
0 g
s
.65699 .67632 m .64743 .6206 L .64475 .61457 L p .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .6661 .74917 L .65891 .7408 L p .707 .577 .707 r
F P
0 g
s
.65891 .7408 m .6543 .73545 L p .66003 .76101 L .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .65891 .7408 L .66003 .76101 L .707 .577 .707 r
F
.65803 .74098 m .6579 .72263 L p .65487 .69546 L F P
0 g
s
.6579 .72263 m .65777 .7039 L .65669 .70075 L p .707 .577 .707 r
F P
0 g
s
.65669 .70075 m .65487 .69546 L p .6579 .72263 L .707 .577 .707 r
F P
0 g
s
.65777 .7039 m .65803 .74098 L .67062 .7487 L p .707 .577 .707 r
F P
0 g
s
.82556 .7927 m .82071 .81001 L .8369 .80393 L p .707 .577 .707 r
F P
0 g
s
.8369 .80393 m .84176 .78662 L .82556 .7927 L p .707 .577 .707 r
F P
0 g
s
.85168 .70604 m .85194 .74312 L .85903 .73479 L p .707 .577 .707 r
F P
0 g
s
.85903 .73479 m .85876 .69771 L .85168 .70604 L p .707 .577 .707 r
F P
0 g
s
.6543 .73545 m .64945 .75276 L .66125 .76648 L p .707 .577 .707 r
F P
0 g
s
.84575 .58449 m .85531 .64021 L .85263 .63419 L p .707 .577 .707 r
F P
0 g
s
.85263 .63419 m .84307 .57847 L .84575 .58449 L p .707 .577 .707 r
F P
0 g
s
.64475 .61457 m .65431 .67029 L .65699 .67632 L p .707 .577 .707 r
F P
0 g
s
.64945 .75276 m .6543 .73545 L .65191 .72316 L p .707 .577 .707 r
F P
0 g
s
.65191 .72316 m .64706 .74047 L .64945 .75276 L p .707 .577 .707 r
F P
0 g
s
.64706 .74047 m .65191 .72316 L .6541 .72026 L p .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65803 .74098 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65499 .7122 m .65513 .73254 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65487 .69546 m .65499 .7122 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65487 .69546 L .66195 .68713 L p .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .65513 .73254 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66195 .68713 m .66207 .70319 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66207 .70319 m .66222 .72421 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .66195 .68713 L .67832 .67973 L p .707 .577 .707 r
F P
0 g
s
.65432 .73082 m .65917 .71351 L .66446 .71152 L p .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .66222 .72421 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67832 .67973 m .67844 .69647 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67844 .69647 m .67859 .71681 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .67832 .67973 L .70237 .67397 L p .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .67537 .70743 L .68385 .70674 L p .707 .577 .707 r
F P
0 g
s
.70237 .67397 m .70264 .71106 L .67859 .71681 L p .707 .577 .707 r
F P
0 g
s
.68385 .70674 m .69891 .70553 L p .68734 .71336 L .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .68385 .70674 L .68734 .71336 L .707 .577 .707 r
F
.66446 .71152 m .67537 .70743 L p .6662 .71761 L F P
0 g
s
.65432 .73082 m .66446 .71152 L .6662 .71761 L .707 .577 .707 r
F
.6541 .72026 m .65917 .71351 L p .65343 .72628 L F P
0 g
s
.64706 .74047 m .6541 .72026 L .65343 .72628 L .707 .577 .707 r
F
.65431 .67029 m .64475 .61457 L .65191 .60708 L p F P
0 g
s
.84176 .78662 m .8369 .80393 L .84416 .79427 L p .707 .577 .707 r
F P
0 g
s
.84416 .79427 m .84902 .77697 L .84176 .78662 L p .707 .577 .707 r
F P
0 g
s
.85876 .69771 m .85903 .73479 L .85613 .72635 L p .707 .577 .707 r
F P
0 g
s
.85613 .72635 m .85587 .68927 L .85876 .69771 L p .707 .577 .707 r
F P
0 g
s
.40456 .59228 m .395 .53656 L .3643 .54014 L p .707 .577 .707 r
F P
0 g
s
.84307 .57847 m .85263 .63419 L .84038 .63022 L p .707 .577 .707 r
F P
0 g
s
.84038 .63022 m .83082 .57451 L .84307 .57847 L p .707 .577 .707 r
F P
0 g
s
.65191 .60708 m .66147 .66279 L .65431 .67029 L p .707 .577 .707 r
F P
0 g
s
.37385 .59586 m .3643 .54014 L .33731 .54123 L p .707 .577 .707 r
F P
0 g
s
.3643 .54014 m .37385 .59586 L .40456 .59228 L p .707 .577 .707 r
F P
0 g
s
.45546 .52355 m .46501 .57926 L .48885 .57109 L p .707 .577 .707 r
F P
0 g
s
.48885 .57109 m .47929 .51538 L .45546 .52355 L p .707 .577 .707 r
F P
0 g
s
.40729 .64122 m .40703 .60414 L .37586 .60246 L p .707 .577 .707 r
F P
0 g
s
.33731 .54123 m .34687 .59694 L .37385 .59586 L p .707 .577 .707 r
F P
0 g
s
.37612 .63954 m .37586 .60246 L .3484 .59829 L p .707 .577 .707 r
F P
0 g
s
.37586 .60246 m .37612 .63954 L .40729 .64122 L p .707 .577 .707 r
F P
0 g
s
.66147 .66279 m .65191 .60708 L .6682 .59884 L p .707 .577 .707 r
F P
0 g
s
.84902 .77697 m .84416 .79427 L .84177 .78199 L p .707 .577 .707 r
F P
0 g
s
.84177 .78199 m .84663 .76468 L .84902 .77697 L p .707 .577 .707 r
F P
0 g
s
.34687 .59694 m .33731 .54123 L .31668 .53971 L p .707 .577 .707 r
F P
0 g
s
.65917 .71351 m .65432 .73082 L .64706 .74047 L p .707 .577 .707 r
F P
0 g
s
.85587 .68927 m .85613 .72635 L .84354 .71863 L p .707 .577 .707 r
F P
0 g
s
.84354 .71863 m .84328 .68155 L .85587 .68927 L p .707 .577 .707 r
F P
0 g
s
.46825 .59962 m .46851 .6367 L .49256 .63095 L p .707 .577 .707 r
F P
0 g
s
.49256 .63095 m .4923 .59387 L .46825 .59962 L p .707 .577 .707 r
F P
0 g
s
.83082 .57451 m .84038 .63022 L .81975 .62871 L p .707 .577 .707 r
F P
0 g
s
.81975 .62871 m .81019 .57299 L .83082 .57451 L p .707 .577 .707 r
F P
0 g
s
.3484 .59829 m .34867 .63538 L .37612 .63954 L p .707 .577 .707 r
F P
0 g
s
.47929 .51538 m .48885 .57109 L .50515 .56286 L p .707 .577 .707 r
F P
0 g
s
.50515 .56286 m .49559 .50714 L .47929 .51538 L p .707 .577 .707 r
F P
0 g
s
.6682 .59884 m .67776 .65456 L .66147 .66279 L p .707 .577 .707 r
F P
0 g
s
.31668 .53971 m .32624 .59543 L .3281 .59557 L p .707 .577 .707 r
F P
0 g
s
.3281 .59557 m .34687 .59694 L p .33098 .56683 L .707 .577 .707 r
F P
0 g
s
.33098 .56683 m .31668 .53971 L .3281 .59557 L .707 .577 .707 r
F
.32624 .59543 m .31668 .53971 L .30442 .53575 L p F P
0 g
s
.30442 .53575 m .31398 .59147 L .315 .5918 L p .707 .577 .707 r
F P
0 g
s
.315 .5918 m .32624 .59543 L p .31581 .5669 L .707 .577 .707 r
F P
0 g
s
.31581 .5669 m .30442 .53575 L .315 .5918 L .707 .577 .707 r
F
.31398 .59147 m .30442 .53575 L .30174 .52973 L p F P
0 g
s
.30174 .52973 m .3113 .58544 L .31148 .58586 L p .707 .577 .707 r
F P
0 g
s
.31148 .58586 m .31398 .59147 L p .30831 .56286 L .707 .577 .707 r
F P
0 g
s
.30831 .56286 m .30174 .52973 L .31148 .58586 L .707 .577 .707 r
F
.31476 .58432 m .31186 .57588 L p .31435 .61171 L F P
0 g
s
.31484 .59649 m .31476 .58432 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .31476 .58432 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.31476 .58432 m .31502 .6214 L .32761 .62912 L p .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31894 .56755 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31195 .58926 L p .31502 .6214 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31212 .61296 L .31337 .61659 L p .707 .577 .707 r
F P
0 g
s
.31337 .61659 m .31502 .6214 L p .31195 .58926 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31186 .57588 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31502 .6214 m .31484 .59649 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.31894 .56755 m .31904 .58135 L p .31212 .61296 L .707 .577 .707 r
F P
0 g
s
.31904 .58135 m .31921 .60463 L .31626 .6081 L p .707 .577 .707 r
F P
0 g
s
.31626 .6081 m .31212 .61296 L p .31904 .58135 L .707 .577 .707 r
F P
0 g
s
.31921 .60463 m .31894 .56755 L .33531 .56015 L p .707 .577 .707 r
F P
0 g
s
.32519 .51399 m .32573 .5171 L p .31846 .57795 L .707 .577 .707 r
F P
0 g
s
.32742 .60234 m .32735 .59204 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.34867 .63538 m .3484 .59829 L .32735 .59204 L p .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .32761 .62912 L .34867 .63538 L p .707 .577 .707 r
F P
0 g
s
.33531 .56015 m .33541 .57353 L p .31921 .60463 L .707 .577 .707 r
F P
0 g
s
.33541 .57353 m .33557 .59723 L .3294 .60002 L p .707 .577 .707 r
F P
0 g
s
.3294 .60002 m .31921 .60463 L p .33541 .57353 L .707 .577 .707 r
F P
0 g
s
.33557 .59723 m .33531 .56015 L .35936 .55439 L p .707 .577 .707 r
F P
0 g
s
.34903 .50583 m .34977 .51014 L p .33475 .56971 L .707 .577 .707 r
F P
0 g
s
.35936 .55439 m .35945 .56657 L p .33557 .59723 L .707 .577 .707 r
F P
0 g
s
.35945 .56657 m .35963 .59148 L .35213 .59327 L p .707 .577 .707 r
F P
0 g
s
.35213 .59327 m .33557 .59723 L p .35945 .56657 L .707 .577 .707 r
F P
0 g
s
.35963 .59148 m .35936 .55439 L .38875 .55085 L p .707 .577 .707 r
F P
0 g
s
.37808 .49853 m .37809 .4986 L p .35859 .56154 L .707 .577 .707 r
F P
0 g
s
.38875 .55085 m .38882 .56115 L p .35963 .59148 L .707 .577 .707 r
F P
0 g
s
.38882 .56115 m .38901 .58794 L .38268 .5887 L p .707 .577 .707 r
F P
0 g
s
.38268 .5887 m .35963 .59148 L p .38882 .56115 L .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .37808 .49853 L .40381 .49384 L p .707 .577 .707 r
F P
0 g
s
.40381 .49384 m .40949 .49281 L p .39492 .53377 L .707 .577 .707 r
F P
0 g
s
.38901 .58794 m .38875 .55085 L .42058 .54987 L p .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .40381 .49384 L .39492 .53377 L .707 .577 .707 r
F
.37809 .4986 m .38763 .55424 L .36099 .56094 L p F P
0 g
s
.36099 .56094 m .35859 .56154 L p .37809 .4986 L .707 .577 .707 r
F P
0 g
s
.34977 .51014 m .35859 .56154 L .3364 .56915 L p .707 .577 .707 r
F P
0 g
s
.3364 .56915 m .33475 .56971 L p .34977 .51014 L .707 .577 .707 r
F P
0 g
s
.32573 .5171 m .33475 .56971 L .31945 .57745 L p .707 .577 .707 r
F P
0 g
s
.31945 .57745 m .31846 .57795 L p .32573 .5171 L .707 .577 .707 r
F P
0 g
s
.3089 .52223 m .31846 .57795 L .31173 .58499 L p .707 .577 .707 r
F P
0 g
s
.31173 .58499 m .3113 .58544 L p .31004 .55215 L .707 .577 .707 r
F P
0 g
s
.31004 .55215 m .3089 .52223 L .31173 .58499 L .707 .577 .707 r
F
.31212 .61296 m .31195 .58926 L p .31374 .60219 L F P
0 g
s
.32761 .62912 m .32742 .60234 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.39472 .6964 m .39958 .67909 L .36951 .66904 L p .707 .577 .707 r
F P
0 g
s
.39958 .67909 m .39472 .6964 L .42556 .70298 L p .707 .577 .707 r
F P
0 g
s
.42556 .70298 m .43042 .68567 L .39958 .67909 L p .707 .577 .707 r
F P
0 g
s
.36465 .68635 m .36951 .66904 L .34315 .6565 L p .707 .577 .707 r
F P
0 g
s
.36951 .66904 m .36465 .68635 L .39472 .6964 L p .707 .577 .707 r
F P
0 g
s
.43042 .68567 m .42556 .70298 L .45415 .70543 L p .707 .577 .707 r
F P
0 g
s
.67776 .65456 m .6682 .59884 L .69204 .59067 L p .707 .577 .707 r
F P
0 g
s
.34315 .6565 m .3383 .67381 L .36465 .68635 L p .707 .577 .707 r
F P
0 g
s
.4923 .59387 m .49256 .63095 L .50893 .62354 L p .707 .577 .707 r
F P
0 g
s
.50893 .62354 m .50867 .58646 L .4923 .59387 L p .707 .577 .707 r
F P
0 g
s
.84663 .76468 m .84177 .78199 L .82997 .76827 L p .707 .577 .707 r
F P
0 g
s
.82997 .76827 m .83483 .75096 L .84663 .76468 L p .707 .577 .707 r
F P
0 g
s
.3383 .67381 m .34315 .6565 L .32309 .64269 L p .707 .577 .707 r
F P
0 g
s
.81019 .57299 m .81975 .62871 L .79276 .6298 L p .707 .577 .707 r
F P
0 g
s
.79276 .6298 m .7832 .57408 L .81019 .57299 L p .707 .577 .707 r
F P
0 g
s
.67537 .70743 m .67051 .72474 L .65432 .73082 L p .707 .577 .707 r
F P
0 g
s
.84328 .68155 m .84354 .71863 L .82248 .71238 L p .707 .577 .707 r
F P
0 g
s
.82248 .71238 m .82222 .6753 L .84328 .68155 L p .707 .577 .707 r
F P
0 g
s
.45901 .68812 m .45415 .70543 L .4777 .70353 L p .707 .577 .707 r
F P
0 g
s
.4777 .70353 m .48255 .68622 L .45901 .68812 L p .707 .577 .707 r
F P
0 g
s
.49559 .50714 m .50515 .56286 L .5123 .55536 L p .707 .577 .707 r
F P
0 g
s
.5123 .55536 m .50274 .49965 L .49559 .50714 L p .707 .577 .707 r
F P
0 g
s
.69204 .59067 m .7016 .64639 L .67776 .65456 L p .707 .577 .707 r
F P
0 g
s
.32309 .64269 m .31824 .66 L .3383 .67381 L p .707 .577 .707 r
F P
0 g
s
.7016 .64639 m .69204 .59067 L .72109 .58337 L p .707 .577 .707 r
F P
0 g
s
.7832 .57408 m .79276 .6298 L .76206 .63337 L p .707 .577 .707 r
F P
0 g
s
.76206 .63337 m .7525 .57766 L .7832 .57408 L p .707 .577 .707 r
F P
0 g
s
.50867 .58646 m .50893 .62354 L .51602 .61522 L p .707 .577 .707 r
F P
0 g
s
.51602 .61522 m .51575 .57813 L .50867 .58646 L p .707 .577 .707 r
F P
0 g
s
.31824 .66 m .32309 .64269 L .31129 .62897 L p .707 .577 .707 r
F P
0 g
s
.83483 .75096 m .82997 .76827 L .80991 .75446 L p .707 .577 .707 r
F P
0 g
s
.80991 .75446 m .81477 .73715 L .83483 .75096 L p .707 .577 .707 r
F P
0 g
s
.82222 .6753 m .82248 .71238 L .79503 .70821 L p .707 .577 .707 r
F P
0 g
s
.79503 .70821 m .79476 .67113 L .82222 .6753 L p .707 .577 .707 r
F P
0 g
s
.48255 .68622 m .4777 .70353 L .49389 .69745 L p .707 .577 .707 r
F P
0 g
s
.49389 .69745 m .49875 .68014 L .48255 .68622 L p .707 .577 .707 r
F P
0 g
s
.73064 .63909 m .72109 .58337 L .7525 .57766 L p .707 .577 .707 r
F P
0 g
s
.72109 .58337 m .73064 .63909 L .7016 .64639 L p .707 .577 .707 r
F P
0 g
s
.7525 .57766 m .76206 .63337 L .73064 .63909 L p .707 .577 .707 r
F P
0 g
s
.69891 .70553 m .69406 .72284 L .67051 .72474 L p .707 .577 .707 r
F P
0 g
s
.31129 .62897 m .30644 .64628 L .31824 .66 L p .707 .577 .707 r
F P
0 g
s
.70264 .71106 m .70237 .67397 L .73176 .67043 L p .707 .577 .707 r
F P
0 g
s
.50274 .49965 m .5123 .55536 L .50962 .54934 L p .707 .577 .707 r
F P
0 g
s
.50962 .54934 m .50006 .49362 L .50274 .49965 L p .707 .577 .707 r
F P
0 g
s
.79476 .67113 m .79503 .70821 L .76385 .70654 L p .707 .577 .707 r
F P
0 g
s
.76385 .70654 m .76359 .66945 L .79476 .67113 L p .707 .577 .707 r
F P
0 g
s
.73176 .67043 m .73202 .70752 L .70264 .71106 L p .707 .577 .707 r
F P
0 g
s
.69406 .72284 m .69891 .70553 L .7275 .70798 L p .707 .577 .707 r
F P
0 g
s
.73202 .70752 m .73176 .67043 L .76359 .66945 L p .707 .577 .707 r
F P
0 g
s
.81477 .73715 m .80991 .75446 L .78356 .74192 L p .707 .577 .707 r
F P
0 g
s
.78356 .74192 m .78841 .72461 L .81477 .73715 L p .707 .577 .707 r
F P
0 g
s
.76359 .66945 m .76385 .70654 L .73202 .70752 L p .707 .577 .707 r
F P
0 g
s
.30644 .64628 m .31129 .62897 L .3089 .61668 L p .707 .577 .707 r
F P
0 g
s
.7275 .70798 m .72265 .72529 L .69406 .72284 L p .707 .577 .707 r
F P
0 g
s
.51575 .57813 m .51602 .61522 L .51312 .60678 L p .707 .577 .707 r
F P
0 g
s
.51312 .60678 m .51286 .56969 L .51575 .57813 L p .707 .577 .707 r
F P
0 g
s
.49875 .68014 m .49389 .69745 L .50115 .6878 L p .707 .577 .707 r
F P
0 g
s
.50115 .6878 m .50601 .67049 L .49875 .68014 L p .707 .577 .707 r
F P
0 g
s
.3089 .61668 m .30405 .63399 L .30644 .64628 L p .707 .577 .707 r
F P
0 g
s
.3113 .58544 m .30174 .52973 L .3089 .52223 L p .707 .577 .707 r
F P
0 g
s
.72265 .72529 m .7275 .70798 L .75834 .71456 L p .707 .577 .707 r
F P
0 g
s
.78841 .72461 m .78356 .74192 L .75349 .73187 L p .707 .577 .707 r
F P
0 g
s
.75349 .73187 m .75834 .71456 L .78841 .72461 L p .707 .577 .707 r
F P
0 g
s
.75834 .71456 m .75349 .73187 L .72265 .72529 L p .707 .577 .707 r
F P
0 g
s
.50006 .49362 m .50962 .54934 L .49737 .54537 L p .707 .577 .707 r
F P
0 g
s
.49737 .54537 m .48781 .48966 L .50006 .49362 L p .707 .577 .707 r
F P
0 g
s
.30405 .63399 m .3089 .61668 L .31616 .60703 L p .707 .577 .707 r
F P
0 g
s
.50601 .67049 m .50115 .6878 L .49876 .67551 L p .707 .577 .707 r
F P
0 g
s
.49876 .67551 m .50362 .6582 L .50601 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.51286 .56969 m .51312 .60678 L .50053 .59905 L p .707 .577 .707 r
F P
0 g
s
.50053 .59905 m .50026 .56197 L .51286 .56969 L p .707 .577 .707 r
F P
0 g
s
.31616 .60703 m .31131 .62434 L .30405 .63399 L p .707 .577 .707 r
F P
0 g
s
.31846 .57795 m .3089 .52223 L .32519 .51399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48781 .48966 m .49737 .54537 L .47674 .54386 L p .707 .577 .707 r
F P
0 g
s
.47674 .54386 m .46718 .48815 L .48781 .48966 L p .707 .577 .707 r
F P
0 g
s
.31131 .62434 m .31616 .60703 L .33236 .60095 L p .707 .577 .707 r
F P
0 g
s
.50026 .56197 m .50053 .59905 L .47947 .5928 L p .707 .577 .707 r
F P
0 g
s
.47947 .5928 m .47921 .55572 L .50026 .56197 L p .707 .577 .707 r
F P
0 g
s
.50362 .6582 m .49876 .67551 L .48696 .66179 L p .707 .577 .707 r
F P
0 g
s
.48696 .66179 m .49182 .64448 L .50362 .6582 L p .707 .577 .707 r
F P
0 g
s
.33475 .56971 m .32519 .51399 L .34903 .50583 L p .707 .577 .707 r
F P
0 g
s
.33236 .60095 m .3275 .61826 L .31131 .62434 L p .707 .577 .707 r
F P
0 g
s
.46718 .48815 m .47674 .54386 L .44975 .54495 L p .707 .577 .707 r
F P
0 g
s
.44975 .54495 m .44019 .48923 L .46718 .48815 L p .707 .577 .707 r
F P
0 g
s
.35859 .56154 m .34903 .50583 L .37808 .49853 L p .707 .577 .707 r
F P
0 g
s
.47921 .55572 m .47947 .5928 L .45202 .58863 L p .707 .577 .707 r
F P
0 g
s
.45202 .58863 m .45175 .55155 L .47921 .55572 L p .707 .577 .707 r
F P
0 g
s
.3275 .61826 m .33236 .60095 L .3559 .59905 L p .707 .577 .707 r
F P
0 g
s
.49182 .64448 m .48696 .66179 L .4669 .64798 L p .707 .577 .707 r
F P
0 g
s
.4669 .64798 m .47176 .63067 L .49182 .64448 L p .707 .577 .707 r
F P
0 g
s
.44019 .48923 m .44975 .54495 L .41905 .54852 L p .707 .577 .707 r
F P
0 g
s
.41905 .54852 m .40949 .49281 L .44019 .48923 L p .707 .577 .707 r
F P
0 g
s
.3559 .59905 m .35105 .61636 L .3275 .61826 L p .707 .577 .707 r
F P
0 g
s
.40949 .49281 m .41905 .54852 L .38763 .55424 L p .707 .577 .707 r
F P
0 g
s
.45175 .55155 m .45202 .58863 L .42084 .58696 L p .707 .577 .707 r
F P
0 g
s
.42084 .58696 m .42058 .54987 L .45175 .55155 L p .707 .577 .707 r
F P
0 g
s
.35105 .61636 m .3559 .59905 L .38449 .6015 L p .707 .577 .707 r
F P
0 g
s
.42058 .54987 m .42084 .58696 L .38901 .58794 L p .707 .577 .707 r
F P
0 g
s
.47176 .63067 m .4669 .64798 L .44055 .63544 L p .707 .577 .707 r
F P
0 g
s
.44055 .63544 m .4454 .61813 L .47176 .63067 L p .707 .577 .707 r
F P
0 g
s
.38449 .6015 m .37964 .61881 L .35105 .61636 L p .707 .577 .707 r
F P
0 g
s
.37964 .61881 m .38449 .6015 L .41533 .60808 L p .707 .577 .707 r
F P
0 g
s
.4454 .61813 m .44055 .63544 L .41048 .62539 L p .707 .577 .707 r
F P
0 g
s
.41048 .62539 m .41533 .60808 L .4454 .61813 L p .707 .577 .707 r
F P
0 g
s
.41533 .60808 m .41048 .62539 L .37964 .61881 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Uoo`L008eo
o`00Ngoo3P0000=JEP00FUH015YF3000PGoo001eOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH8001iOol006moo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00@007Eoo`00JWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00LWoo001WOol30007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001`Ool006Eo
o`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF008006ioo`00Hgoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Jgoo001QOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1[Ool0061o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool0
05ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00OomJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP0DFUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVaoo`00GWoo00@005YFFUH000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFK7oo001NOol01000FUIJEP001UYF00<0
05YFFUH04eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUI/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1Z
Ool005ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00GWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Jgoo001NOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001[Ool005ioo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Yoo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJgoo001OOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005moo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Uo
o`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00
Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YF00001@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00eYF20000eYF00<0
05YFFUH01P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH00eYF2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00000P002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000
FUIJEP001EYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YF
FUH0009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061oo`03
001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JWoo001N
Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Yoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Moo`8000=JEP03001JEUYF00AJEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Ioo`80
00AJEP8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EGoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Uoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
30000eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uo
o`00EWoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH015YF1P0000=JEP0000001eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JGoo001FOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH@0006FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001YOol005Ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo001FOol01000FUIJEP0015YF00<0
05YFFUH015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEPD0
00AJEP8000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00<0
05YF000015YF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P0025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo
001GOol00`00FUH00005FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol005Moo`03001JEP0000EJEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00@005YFFUH000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000_Ool6000d
Ool005Moo`05001JEUYF001JEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P009Woo2@000eYF00<005YFFUH01@00;goo001HOol01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P007Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002eo
o`00DWoo2@0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P005goo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00B7oo2P0015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`@00003FUH005YF00MJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00@goo1@00
1EYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH:0002FUH5
00000eYF000000060004FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo0011Ool200000eYF001JEP07FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH02@0015YF1`002UYF00@005YFFUIJEPH000AJ
EP03001JEUYF008000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000/Ool003ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH0
0004FUH@0005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH6000015YF001JEUYF0P001UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo0P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000k
Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP0=00000eYF001JEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP040004FUH01000FUH000000UYF0P001eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002Goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000gOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001UYF00000000FUH000IJEP04001JEUYF
FUHA0006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF10001eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000dOol30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005Ool20002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000[Ool0039oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEP000006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0017oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002]oo`00<7oo0P000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
0eYF00<005YFFUH00UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002]oo`00;goo0P0015YF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
0P000eYF4P001eYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH20008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000ZOol002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800005FUH00000FUH00005FUH00`00FUIJEP04FUH0
1000FUIJEUYF10000UYF00<005YFFUH01eYF10000eYF00<005YFFUH015YF00@005YFFUIJEP8000QJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001oogooOol00002FUH01@00FUIJ
EUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH01UYF00@005YFFUIoo`EJEP03001JEUYF00EJEPD00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEP@000QJEP03001JEUYF0080009JEP03001JEUYF00AJEP05001JEUYFFUH00009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00Oomoogoo00000UYF00D005YFFUIJ
EP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002Yoo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP<000AJEP03001JEUYF00AJEP03001JEUYF
009JEP<00004FUH005YFFUH30004FUH00`00FUIJEP03FUH30006FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D007ooOomoo`00009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF
FUIJEP0002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF10001EYF0`0000=JEP00FUH01EYF00@005YFFUIJEPH000EJEP<00003FUH0
05YF00IJEP8000AJEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPP000IJEPD0009JEP03001oogoo02Qoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEPX000=JEP04001JEUYFFUH6
0008FUH20008FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000YOol002moo`03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP<000AJEP80009JEP03
001JEP0000`000YJEP8000EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo
000_Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90002FUH0
1@00FUIJEUYF00001EYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEP`000EJEP8000=JEP03001J
EUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000:Goo000_Ool01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF1P0015YF00<005YFFUH00UYF0`000eYF0`000eYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF10001UYF00@005YFFUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000ZOol002moo`04001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEPD0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP04001JEUYF0006FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000[Ool0031oo`03001J
EP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYFFUH20004FUH0
1000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo00@005YF
FUH000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01000FUH00000;Goo000`Ool00`00FUH00005FUH01000FUIJEUYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`05001JEUYFFUH00003FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000_Ool0
031oo`03001JEP0000EJEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH300000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH30004FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool3FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00<Woo000`Ool01000FUIJEP000eYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF008000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`=JEP8000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00<7oo00D005YFFUH005YF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600001EYF000005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Goo000aOol0
1000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`001eYF10002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P00
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00EJEQP003Yoo`00<Goo0`0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF0000
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUH00005
0003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000fOol0035oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEP000002FUH01000
FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@00
<Goo000aOol00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF6P0015YF10000eYF00<005YF
FUH015YF1`002eYF00<005YFFUH02EYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000eYF00@005YFFUIJEPH000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00@002eoo`00<Goo00<005YF000015YF00@005YFFUIJEPP0
00AJEPL000ioo`H0009JEP<000IJEPD000=JEPD000IJEP03001JEUYF00MJEP@000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP8002aoo`00
<Goo00<005YF000015YF00<005YF00003@006Woo00D005YFFUH005YF008000EJEPD000MJEP03001J
EP0000h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04
001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:Woo000aOol00`00FUH00002FUH40000
0eYF00000005000HOol90002FUH01000FUIJEUYF0`000UYF1@001UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Uoo`00<Goo00<005YF0000
1`000eYF00@005YFFUIJEQP000AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH0000YOol0035oo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00@000QJ
EP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002Qoo`00<Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
100015YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEPT0
00AJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00:7oo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0
00040008FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01EYF
30001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
0P0000=JEP00FUH00UYF2P001UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002Qoo`00<7oo0P000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH015YF
0`001UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH200000eYF001JEP030005FUH01000FUIJEUYF2`0027oo200015YF00<005YFFUH00eYF00@005YF
FUIJEP8002Qoo`00<7oo0P0000EJEP00001JEP0000EJEP04001JEUYFFUH70007FUH00`00FUIJEP06
FUH30004FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEPD00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@0011oo`H000AJEP04001JEUYF
FUH2000XOol0031oo`@0009JEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH40002FUH0
0`00FUIJEP07FUH00`00FUIJEP020002FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00AJEP@000moo`H00003FUH005YF009JEP8002Qoo`00;goo0`000Woo0`001EYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH00eYF0`000eYF00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF01MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP00008000Moo`D000EJEP<000=JEP8002Qoo`00;goo0`0017oo0`000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF10000UYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF009JEP04001JEUYFFUH70004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000X
Ool002moo`04001JEP000006Ool50005FUH01000FUIJEUYF1P001eYF0`0025YF10000eYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01P000UYF00<005YFFUH00UYF1`001UYF00<0
05YFFUH01UYF0`0015YF00<005YFFUH015YF00<005YFFUH00UYF0`00:7oo000_Ool20002FUH00`00
Oomoo`08Ool400000eYF001JEP02FUH60008FUH01000FUH000001EYF00<005YFFUH00P000eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF
009JEP<002Qoo`00<7oo00D005YFFUIJEP0000eooaT000=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40007FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0000XOol0031oo`04
001JEUYFFUH3000AOol3000@Ool30004FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000000`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF0P00:Goo000aOol01000FUIJEP000UYF00<0
07ooOol08goo00<007ooFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF01IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000QJ
EP<000=JEP03001JEUYF009JEP8002Uoo`00<Goo00<005YF000015YF0P0097oo0P000UYF00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF011JEP`000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800004FUH005YF0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH30006FUH01000FUIJEP000UYF00@005YFFUIJEP8002Yoo`00<Woo0P001UYF
00<007ooOol08goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF
2@0035YF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF
0`0000=JEP000000;7oo000cOol00`00FUIJEP04FUH3000TOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00UYF0P0000IJEP00000005YF0007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH2000^Ool003Aoo`8000AJEP03001JEUYF
008002Aoo`=JEP03001JEUYF00=JEP03001JEUYF00AJEPL0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF009JEP80009JEP06001JEUYF
FUH005YF100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P001UYF0P00;Woo000fOol01000FUIJEP001EYF0P008Woo0eYF00<005YFFUH00eYF00<005YFFUH0
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
00000P0015YF0`000UYF00@005YFFUH000=JEP8000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD000AJEP03001JEP0002ioo`00=goo0`001eYF0`007goo0eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF0`000UYF0P001eYF0P003Goo4P001Goo0P000UYF00@005YFFUH002eo
o`00>Goo00<005YFFUH01UYF00@005YF000001eoo`=JEP04001JEUYFFUH20006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH:0007FUH3000TOol20004FUH00`00Oomoo`0ZOol003Yoo`8000EJEP03001JEUYF009JEP<001Yo
o`=JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YF000000AJEP04001J
EUYFFUH2000SOol00`00FUIJEP02FUH00`00Oomoo`0ZOol003aoo`8000=JEP03001JEUYF00AJEPD0
01Ioo`=JEP8000EJEP03OomJEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P008Woo00@005YFFUIJEP8002]oo`00?Woo0`001UYF1@0000=JEP00
00000P004Woo0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF009J
EP<000QJEP80025oo`05001JEP00FUH0000[Ool0041oo`8000EJEPD000EJEQ800003FUH005YF00]J
EP03Ool005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH00002
000OOol200000eYF001oo`0ZOol0049oo`<0009JEPD000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00EJEP8000IJEP03001J
EUYF009JEP<001eoo`8002aoo`00AGoo1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
000000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP06
FUH3000IOol3000/Ool004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006
FUH00gooFUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH025YF00<005YF00000`004goo0P0000=JEP00Ool0;7oo001;Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00002000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30007FUH00`00FUIJEP04FUHC0002FUH2000]Ool004mooa<0009oo`8000AJEP03
OomJEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Woo001VOol2000:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH0000@0004FUH00`00FUIJEP03FUH01000FUIJEUYF100000=J
EP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo001XOol20008FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH5
000@Ool60004FUH01000FUIJEUYF0P000Woo10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00JGoo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH010001EYF10004Goo100000=JEP00FUH00UYF0P001Woo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000031oo`00K7oo10000UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=JEP00FUH025YF00<005YF0000
0P001goo1`000eYF0`000eYF0P002Woo4`00<Woo001`Ool80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000Cgoo001hOol;0006FUH00`00FUIJEP04FUH;0002FUH00`00
FUIJEP02FUH70006FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001?
Ool008=oo`d00003OomJEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH4
0002FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0`00Cgoo
002AOol40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40007FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0001?Ool0091oo`D0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00AJEP8000EJEP03001J
EUYF009JEP03001JEP0004moo`00T7oo00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF0`000eYF00<005YFFUH00UYF
0P00D7oo002@Ool00`00FUH00002FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30007FUH01000FUIJEP000UYF00@005YFFUIJEP80055oo`00T7oo00<005YFFUH0
0UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03
001JEUYF009JEP<00003FUH0000005=oo`00TGoo00<005YFOol00UYF10000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00EJEP8005Eoo`00TGoo
00<005YFFUH00UYF0`0000=oo`0000000`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0P001UYF0P00EGoo002BOol01000FUIJEP000eYF00<007ooOol00goo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0015YF00<005YF0000EGoo002BOol01000FUIJ
EP0015YF0P001goo6@001Goo0P000UYF00@005YFFUH005Aoo`00Tgoo00<005YFFUH01UYF0P009Goo
0P0015YF00<007ooOol0DGoo002DOol00`00FUIJEP05FUH01000FUH0000097oo00<005YFFUH00UYF
00<007ooOol0DGoo002EOol20004FUH00`00FUIJEP02FUH2000SOol01@00FUIJEUYF0000Dgoo002G
Ool01@00FUIJEUYF00001UYF0`008Goo00D005YF001JEP00059oo`00V7oo0`0025YF00<005YF0000
0P007goo0P0000=JEP00Ool0DGoo002JOol20007FUH00`00FUIJEP02FUH3000MOol00`00FUH0001B
Ool009aoo`8000AJEP03001JEUYF00IJEP<001Uoo`<005=oo`00WWoo0`0000=JEP00FUH025YF00<0
05YF00000`004goo0P0000=JEP000000Dgoo002QOol30007FUH00`00FUIJEP04FUH60008Ool50002
FUH2001DOol00:Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00
E7oo002VOol300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001E
Ool00:Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:eoo`@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol00;5oo`H000AJEP04001JEUYF
FUH5001IOol00;Moo`P005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61036 .76917 m .6008 .71345 L .5701 .71703 L p .707 .577 .707 r
F P
0 g
s
.6008 .71345 m .61036 .76917 L .64177 .76345 L p .707 .577 .707 r
F P
0 g
s
.64177 .76345 m .63221 .70773 L .6008 .71345 L p .707 .577 .707 r
F P
0 g
s
.63221 .70773 m .64177 .76345 L .67082 .75615 L p .707 .577 .707 r
F P
0 g
s
.67082 .75615 m .66126 .70043 L .63221 .70773 L p .707 .577 .707 r
F P
0 g
s
.57966 .77274 m .5701 .71703 L .54311 .71811 L p .707 .577 .707 r
F P
0 g
s
.5701 .71703 m .57966 .77274 L .61036 .76917 L p .707 .577 .707 r
F P
0 g
s
.66126 .70043 m .67082 .75615 L .69466 .74798 L p .707 .577 .707 r
F P
0 g
s
.69466 .74798 m .6851 .69226 L .66126 .70043 L p .707 .577 .707 r
F P
0 g
s
.54311 .71811 m .55267 .77383 L .57966 .77274 L p .707 .577 .707 r
F P
0 g
s
.6131 .85284 m .61284 .81575 L .58167 .81408 L p .707 .577 .707 r
F P
0 g
s
.61284 .81575 m .6131 .85284 L .64494 .85186 L p .707 .577 .707 r
F P
0 g
s
.64494 .85186 m .64467 .81477 L .61284 .81575 L p .707 .577 .707 r
F P
0 g
s
.55267 .77383 m .54311 .71811 L .52248 .7166 L p .707 .577 .707 r
F P
0 g
s
.64467 .81477 m .64494 .85186 L .67432 .84832 L p .707 .577 .707 r
F P
0 g
s
.67432 .84832 m .67405 .81123 L .64467 .81477 L p .707 .577 .707 r
F P
0 g
s
.58193 .85116 m .58167 .81408 L .55421 .80991 L p .707 .577 .707 r
F P
0 g
s
.58167 .81408 m .58193 .85116 L .6131 .85284 L p .707 .577 .707 r
F P
0 g
s
.6851 .69226 m .69466 .74798 L .71095 .73975 L p .707 .577 .707 r
F P
0 g
s
.71095 .73975 m .70139 .68403 L .6851 .69226 L p .707 .577 .707 r
F P
0 g
s
.52248 .7166 m .53204 .77232 L .55267 .77383 L p .707 .577 .707 r
F P
0 g
s
.67405 .81123 m .67432 .84832 L .69837 .84256 L p .707 .577 .707 r
F P
0 g
s
.69837 .84256 m .69811 .80548 L .67405 .81123 L p .707 .577 .707 r
F P
0 g
s
.55421 .80991 m .55447 .84699 L .58193 .85116 L p .707 .577 .707 r
F P
0 g
s
.60053 .89492 m .60538 .87761 L .57531 .86756 L p .707 .577 .707 r
F P
0 g
s
.60538 .87761 m .60053 .89492 L .63137 .90149 L p .707 .577 .707 r
F P
0 g
s
.63137 .90149 m .63622 .88418 L .60538 .87761 L p .707 .577 .707 r
F P
0 g
s
.55447 .84699 m .55421 .80991 L .53315 .80366 L p .707 .577 .707 r
F P
0 g
s
.57046 .88487 m .57531 .86756 L .54896 .85501 L p .707 .577 .707 r
F P
0 g
s
.57531 .86756 m .57046 .88487 L .60053 .89492 L p .707 .577 .707 r
F P
0 g
s
.63622 .88418 m .63137 .90149 L .65996 .90395 L p .707 .577 .707 r
F P
0 g
s
.65996 .90395 m .66481 .88664 L .63622 .88418 L p .707 .577 .707 r
F P
0 g
s
.53204 .77232 m .52248 .7166 L .51023 .71264 L p .707 .577 .707 r
F P
0 g
s
.54896 .85501 m .54411 .87232 L .57046 .88487 L p .707 .577 .707 r
F P
0 g
s
.53315 .80366 m .53342 .84074 L .55447 .84699 L p .707 .577 .707 r
F P
0 g
s
.69811 .80548 m .69837 .84256 L .71474 .83516 L p .707 .577 .707 r
F P
0 g
s
.71474 .83516 m .71447 .79808 L .69811 .80548 L p .707 .577 .707 r
F P
0 g
s
.70139 .68403 m .71095 .73975 L .71811 .73225 L p .707 .577 .707 r
F P
0 g
s
.71811 .73225 m .70855 .67653 L .70139 .68403 L p .707 .577 .707 r
F P
0 g
s
.54411 .87232 m .54896 .85501 L .5289 .84121 L p .707 .577 .707 r
F P
0 g
s
.51023 .71264 m .51979 .76835 L .53204 .77232 L p .707 .577 .707 r
F P
0 g
s
.66481 .88664 m .65996 .90395 L .6835 .90204 L p .707 .577 .707 r
F P
0 g
s
.6835 .90204 m .68836 .88474 L .66481 .88664 L p .707 .577 .707 r
F P
0 g
s
.5289 .84121 m .52405 .85852 L .54411 .87232 L p .707 .577 .707 r
F P
0 g
s
.53342 .84074 m .53315 .80366 L .52056 .79594 L p .707 .577 .707 r
F P
0 g
s
.51979 .76835 m .51023 .71264 L .50755 .70661 L p .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5289 .84121 L .5217 .83284 L p .707 .577 .707 r
F P
0 g
s
.5217 .83284 m .5171 .82749 L p .52282 .85305 L .707 .577 .707 r
F P
0 g
s
.52405 .85852 m .5217 .83284 L .52282 .85305 L .707 .577 .707 r
F
.52083 .83302 m .52069 .81467 L p .51767 .7875 L F P
0 g
s
.52069 .81467 m .52056 .79594 L .51948 .79279 L p .707 .577 .707 r
F P
0 g
s
.51948 .79279 m .51767 .7875 L p .52069 .81467 L .707 .577 .707 r
F P
0 g
s
.52056 .79594 m .52083 .83302 L .53342 .84074 L p .707 .577 .707 r
F P
0 g
s
.68836 .88474 m .6835 .90204 L .6997 .89597 L p .707 .577 .707 r
F P
0 g
s
.6997 .89597 m .70455 .87866 L .68836 .88474 L p .707 .577 .707 r
F P
0 g
s
.71447 .79808 m .71474 .83516 L .72182 .82683 L p .707 .577 .707 r
F P
0 g
s
.72182 .82683 m .72156 .78975 L .71447 .79808 L p .707 .577 .707 r
F P
0 g
s
.5171 .82749 m .51224 .8448 L .52405 .85852 L p .707 .577 .707 r
F P
0 g
s
.70855 .67653 m .71811 .73225 L .71543 .72622 L p .707 .577 .707 r
F P
0 g
s
.71543 .72622 m .70587 .67051 L .70855 .67653 L p .707 .577 .707 r
F P
0 g
s
.50755 .70661 m .51711 .76233 L .51979 .76835 L p .707 .577 .707 r
F P
0 g
s
.48447 .81944 m .46656 .31597 L .42258 .31488 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .52083 .83302 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51767 .7875 m .51778 .80424 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51778 .80424 m .51793 .82458 L p .51842 .79844 L .707 .577 .707 r
F P
0 g
s
.51224 .8448 m .5171 .82749 L .51471 .8152 L p .707 .577 .707 r
F P
0 g
s
.51471 .8152 m .50986 .83251 L .51224 .8448 L p .707 .577 .707 r
F P
0 g
s
.50986 .83251 m .51471 .8152 L .5169 .81229 L p .707 .577 .707 r
F P
0 g
s
.51793 .82458 m .51767 .7875 L .52475 .77917 L p .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .51793 .82458 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52475 .77917 m .52486 .79522 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52486 .79522 m .52501 .81625 L p .52321 .78944 L .707 .577 .707 r
F P
0 g
s
.52501 .81625 m .52475 .77917 L .54112 .77176 L p .707 .577 .707 r
F P
0 g
s
.51711 .82285 m .52197 .80555 L .52725 .80356 L p .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .52501 .81625 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54112 .77176 m .54124 .78851 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54124 .78851 m .54138 .80885 L p .53757 .78155 L .707 .577 .707 r
F P
0 g
s
.54138 .80885 m .54112 .77176 L .56517 .76601 L p .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .53816 .79947 L .54665 .79878 L p .707 .577 .707 r
F P
0 g
s
.56517 .76601 m .56543 .80309 L .54138 .80885 L p .707 .577 .707 r
F P
0 g
s
.54665 .79878 m .56171 .79757 L p .55013 .80539 L .707 .577 .707 r
F P
0 g
s
.53331 .81678 m .54665 .79878 L .55013 .80539 L .707 .577 .707 r
F
.52725 .80356 m .53816 .79947 L p .529 .80965 L F P
0 g
s
.51711 .82285 m .52725 .80356 L .529 .80965 L .707 .577 .707 r
F
.5169 .81229 m .52197 .80555 L p .51623 .81832 L F P
0 g
s
.50986 .83251 m .5169 .81229 L .51623 .81832 L .707 .577 .707 r
F
.51711 .76233 m .50755 .70661 L .5147 .69912 L p F P
0 g
s
.5147 .69912 m .52426 .75483 L .51711 .76233 L p .707 .577 .707 r
F P
0 g
s
.52197 .80555 m .51711 .82285 L .50986 .83251 L p .707 .577 .707 r
F P
0 g
s
.53816 .79947 m .53331 .81678 L .51711 .82285 L p .707 .577 .707 r
F P
0 g
s
.46656 .31597 m .48447 .81944 L .52938 .8169 L p .707 .577 .707 r
F P
0 g
s
.52426 .75483 m .5147 .69912 L .531 .69088 L p .707 .577 .707 r
F P
0 g
s
.531 .69088 m .54056 .7466 L .52426 .75483 L p .707 .577 .707 r
F P
0 g
s
.52938 .8169 m .51148 .31344 L .46656 .31597 L p .707 .577 .707 r
F P
0 g
s
.54056 .7466 m .531 .69088 L .55484 .68271 L p .707 .577 .707 r
F P
0 g
s
.55484 .68271 m .56439 .73843 L .54056 .7466 L p .707 .577 .707 r
F P
0 g
s
.56439 .73843 m .55484 .68271 L .58388 .67541 L p .707 .577 .707 r
F P
0 g
s
.56171 .79757 m .55685 .81487 L .53331 .81678 L p .707 .577 .707 r
F P
0 g
s
.56543 .80309 m .56517 .76601 L .59455 .76247 L p .707 .577 .707 r
F P
0 g
s
.59455 .76247 m .59482 .79955 L .56543 .80309 L p .707 .577 .707 r
F P
0 g
s
.55685 .81487 m .56171 .79757 L .5903 .80002 L p .707 .577 .707 r
F P
0 g
s
.5903 .80002 m .58544 .81733 L .55685 .81487 L p .707 .577 .707 r
F P
0 g
s
.51148 .31344 m .52938 .8169 L .57084 .81099 L p .707 .577 .707 r
F P
0 g
s
.58388 .67541 m .59344 .73113 L .56439 .73843 L p .707 .577 .707 r
F P
0 g
s
.57084 .81099 m .55294 .30753 L .51148 .31344 L p .707 .577 .707 r
F P
0 g
s
.70455 .87866 m .6997 .89597 L .70696 .88631 L p .707 .577 .707 r
F P
0 g
s
.70696 .88631 m .71181 .869 L .70455 .87866 L p .707 .577 .707 r
F P
0 g
s
.72156 .78975 m .72182 .82683 L .71893 .81839 L p .707 .577 .707 r
F P
0 g
s
.71893 .81839 m .71866 .78131 L .72156 .78975 L p .707 .577 .707 r
F P
0 g
s
.44049 .81834 m .42258 .31488 L .38384 .31027 L p .707 .577 .707 r
F P
0 g
s
.42258 .31488 m .44049 .81834 L .48447 .81944 L p .707 .577 .707 r
F P
0 g
s
.26735 .68432 m .2578 .6286 L .22709 .63218 L p .707 .577 .707 r
F P
0 g
s
.2578 .6286 m .26735 .68432 L .29876 .6786 L p .707 .577 .707 r
F P
0 g
s
.29876 .6786 m .28921 .62288 L .2578 .6286 L p .707 .577 .707 r
F P
0 g
s
.70587 .67051 m .71543 .72622 L .70317 .72226 L p .707 .577 .707 r
F P
0 g
s
.70317 .72226 m .69361 .66655 L .70587 .67051 L p .707 .577 .707 r
F P
0 g
s
.28921 .62288 m .29876 .6786 L .32781 .6713 L p .707 .577 .707 r
F P
0 g
s
.32781 .6713 m .31825 .61558 L .28921 .62288 L p .707 .577 .707 r
F P
0 g
s
.23665 .6879 m .22709 .63218 L .20011 .63327 L p .707 .577 .707 r
F P
0 g
s
.22709 .63218 m .23665 .6879 L .26735 .68432 L p .707 .577 .707 r
F P
0 g
s
.59344 .73113 m .58388 .67541 L .61529 .66969 L p .707 .577 .707 r
F P
0 g
s
.61529 .66969 m .62485 .72541 L .59344 .73113 L p .707 .577 .707 r
F P
0 g
s
.59482 .79955 m .59455 .76247 L .62639 .76149 L p .707 .577 .707 r
F P
0 g
s
.62639 .76149 m .62665 .79857 L .59482 .79955 L p .707 .577 .707 r
F P
0 g
s
.58544 .81733 m .5903 .80002 L .62114 .8066 L p .707 .577 .707 r
F P
0 g
s
.55294 .30753 m .57084 .81099 L .60479 .80228 L p .707 .577 .707 r
F P
0 g
s
.60479 .80228 m .58688 .29882 L .55294 .30753 L p .707 .577 .707 r
F P
0 g
s
.31825 .61558 m .32781 .6713 L .35165 .66313 L p .707 .577 .707 r
F P
0 g
s
.35165 .66313 m .34209 .60742 L .31825 .61558 L p .707 .577 .707 r
F P
0 g
s
.27009 .73326 m .26983 .69618 L .23866 .6945 L p .707 .577 .707 r
F P
0 g
s
.26983 .69618 m .27009 .73326 L .30193 .73228 L p .707 .577 .707 r
F P
0 g
s
.30193 .73228 m .30166 .6952 L .26983 .69618 L p .707 .577 .707 r
F P
0 g
s
.30166 .6952 m .30193 .73228 L .33131 .72874 L p .707 .577 .707 r
F P
0 g
s
.33131 .72874 m .33104 .69166 L .30166 .6952 L p .707 .577 .707 r
F P
0 g
s
.20011 .63327 m .20966 .68898 L .23665 .6879 L p .707 .577 .707 r
F P
0 g
s
.23892 .73158 m .23866 .6945 L .2112 .69033 L p .707 .577 .707 r
F P
0 g
s
.23866 .6945 m .23892 .73158 L .27009 .73326 L p .707 .577 .707 r
F P
0 g
s
.40175 .81374 m .38384 .31027 L .35414 .3026 L p .707 .577 .707 r
F P
0 g
s
.38384 .31027 m .40175 .81374 L .44049 .81834 L p .707 .577 .707 r
F P
0 g
s
.71181 .869 m .70696 .88631 L .70457 .87402 L p .707 .577 .707 r
F P
0 g
s
.70457 .87402 m .70942 .85672 L .71181 .869 L p .707 .577 .707 r
F P
0 g
s
.20966 .68898 m .20011 .63327 L .17947 .63175 L p .707 .577 .707 r
F P
0 g
s
.71866 .78131 m .71893 .81839 L .70633 .81067 L p .707 .577 .707 r
F P
0 g
s
.70633 .81067 m .70607 .77359 L .71866 .78131 L p .707 .577 .707 r
F P
0 g
s
.33104 .69166 m .33131 .72874 L .35536 .72299 L p .707 .577 .707 r
F P
0 g
s
.35536 .72299 m .3551 .6859 L .33104 .69166 L p .707 .577 .707 r
F P
0 g
s
.69361 .66655 m .70317 .72226 L .68254 .72075 L p .707 .577 .707 r
F P
0 g
s
.68254 .72075 m .67298 .66503 L .69361 .66655 L p .707 .577 .707 r
F P
0 g
s
.2112 .69033 m .21146 .72741 L .23892 .73158 L p .707 .577 .707 r
F P
0 g
s
.34209 .60742 m .35165 .66313 L .36794 .6549 L p .707 .577 .707 r
F P
0 g
s
.36794 .6549 m .35838 .59918 L .34209 .60742 L p .707 .577 .707 r
F P
0 g
s
.17947 .63175 m .18903 .68747 L .1909 .68761 L p .707 .577 .707 r
F P
0 g
s
.1909 .68761 m .20966 .68898 L p .19378 .65887 L .707 .577 .707 r
F P
0 g
s
.19378 .65887 m .17947 .63175 L .1909 .68761 L .707 .577 .707 r
F
.18903 .68747 m .17947 .63175 L .16722 .62779 L p F P
0 g
s
.16722 .62779 m .17678 .68351 L .17779 .68383 L p .707 .577 .707 r
F P
0 g
s
.17779 .68383 m .18903 .68747 L p .1786 .65894 L .707 .577 .707 r
F P
0 g
s
.1786 .65894 m .16722 .62779 L .17779 .68383 L .707 .577 .707 r
F
.17678 .68351 m .16722 .62779 L .16454 .62176 L p F P
0 g
s
.16454 .62176 m .1741 .67748 L .17428 .6779 L p .707 .577 .707 r
F P
0 g
s
.17428 .6779 m .17678 .68351 L p .17111 .6549 L .707 .577 .707 r
F P
0 g
s
.17111 .6549 m .16454 .62176 L .17428 .6779 L .707 .577 .707 r
F
.17755 .67636 m .17466 .66792 L p .17714 .70375 L F P
0 g
s
.17764 .68853 m .17755 .67636 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .17755 .67636 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.17755 .67636 m .17782 .71344 L .19041 .72116 L p .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .18174 .65959 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17466 .66792 m .17475 .6813 L p .17782 .71344 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17492 .705 L .17616 .70863 L p .707 .577 .707 r
F P
0 g
s
.17616 .70863 m .17782 .71344 L p .17475 .6813 L .707 .577 .707 r
F P
0 g
s
.17475 .6813 m .17466 .66792 L p .17654 .69423 L .707 .577 .707 r
F P
0 g
s
.17782 .71344 m .17764 .68853 L p .17714 .70375 L .707 .577 .707 r
F P
0 g
s
.18174 .65959 m .18184 .67339 L p .17492 .705 L .707 .577 .707 r
F P
0 g
s
.18184 .67339 m .182 .69667 L .17905 .70014 L p .707 .577 .707 r
F P
0 g
s
.17905 .70014 m .17492 .705 L p .18184 .67339 L .707 .577 .707 r
F P
0 g
s
.182 .69667 m .18174 .65959 L .19811 .65219 L p .707 .577 .707 r
F P
0 g
s
.18799 .60603 m .18852 .60914 L p .18125 .66998 L .707 .577 .707 r
F P
0 g
s
.19022 .69438 m .19014 .68408 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.21146 .72741 m .2112 .69033 L .19014 .68408 L p .707 .577 .707 r
F P
0 g
s
.19014 .68408 m .19041 .72116 L .21146 .72741 L p .707 .577 .707 r
F P
0 g
s
.19811 .65219 m .1982 .66557 L p .182 .69667 L .707 .577 .707 r
F P
0 g
s
.1982 .66557 m .19837 .68927 L .1922 .69206 L p .707 .577 .707 r
F P
0 g
s
.1922 .69206 m .182 .69667 L p .1982 .66557 L .707 .577 .707 r
F P
0 g
s
.19837 .68927 m .19811 .65219 L .22216 .64643 L p .707 .577 .707 r
F P
0 g
s
.21183 .59787 m .21257 .60218 L p .19755 .66175 L .707 .577 .707 r
F P
0 g
s
.22216 .64643 m .22225 .65861 L p .19837 .68927 L .707 .577 .707 r
F P
0 g
s
.22225 .65861 m .22242 .68352 L .21493 .68531 L p .707 .577 .707 r
F P
0 g
s
.21493 .68531 m .19837 .68927 L p .22225 .65861 L .707 .577 .707 r
F P
0 g
s
.22242 .68352 m .22216 .64643 L .25154 .64289 L p .707 .577 .707 r
F P
0 g
s
.24087 .59057 m .24089 .59064 L p .22139 .65358 L .707 .577 .707 r
F P
0 g
s
.25154 .64289 m .25162 .65319 L p .22242 .68352 L .707 .577 .707 r
F P
0 g
s
.25162 .65319 m .25181 .67998 L .24548 .68074 L p .707 .577 .707 r
F P
0 g
s
.24548 .68074 m .22242 .68352 L p .25162 .65319 L .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .24087 .59057 L .2666 .58588 L p .707 .577 .707 r
F P
0 g
s
.2666 .58588 m .27228 .58485 L p .25771 .62581 L .707 .577 .707 r
F P
0 g
s
.25181 .67998 m .25154 .64289 L .28338 .64191 L p .707 .577 .707 r
F P
0 g
s
.25043 .64628 m .2666 .58588 L .25771 .62581 L .707 .577 .707 r
F
.24089 .59064 m .25043 .64628 L .22379 .65298 L p F P
0 g
s
.22379 .65298 m .22139 .65358 L p .24089 .59064 L .707 .577 .707 r
F P
0 g
s
.21257 .60218 m .22139 .65358 L .1992 .66118 L p .707 .577 .707 r
F P
0 g
s
.1992 .66118 m .19755 .66175 L p .21257 .60218 L .707 .577 .707 r
F P
0 g
s
.18852 .60914 m .19755 .66175 L .18224 .66948 L p .707 .577 .707 r
F P
0 g
s
.18224 .66948 m .18125 .66998 L p .18852 .60914 L .707 .577 .707 r
F P
0 g
s
.1717 .61427 m .18125 .66998 L .17453 .67703 L p .707 .577 .707 r
F P
0 g
s
.17453 .67703 m .1741 .67748 L p .17283 .64419 L .707 .577 .707 r
F P
0 g
s
.17283 .64419 m .1717 .61427 L .17453 .67703 L .707 .577 .707 r
F
.17492 .705 m .17475 .6813 L p .17654 .69423 L F P
0 g
s
.19041 .72116 m .19022 .69438 L p .18828 .71373 L .707 .577 .707 r
F P
0 g
s
.62485 .72541 m .61529 .66969 L .64599 .66612 L p .707 .577 .707 r
F P
0 g
s
.62665 .79857 m .62639 .76149 L .65756 .76317 L p .707 .577 .707 r
F P
0 g
s
.58688 .29882 m .60479 .80228 L .62789 .79163 L p .707 .577 .707 r
F P
0 g
s
.64599 .66612 m .65555 .72183 L .62485 .72541 L p .707 .577 .707 r
F P
0 g
s
.62789 .79163 m .60999 .28816 L .58688 .29882 L p .707 .577 .707 r
F P
0 g
s
.25752 .78844 m .26237 .77113 L .23231 .76108 L p .707 .577 .707 r
F P
0 g
s
.26237 .77113 m .25752 .78844 L .28836 .79501 L p .707 .577 .707 r
F P
0 g
s
.28836 .79501 m .29321 .7777 L .26237 .77113 L p .707 .577 .707 r
F P
0 g
s
.22745 .77839 m .23231 .76108 L .20595 .74854 L p .707 .577 .707 r
F P
0 g
s
.23231 .76108 m .22745 .77839 L .25752 .78844 L p .707 .577 .707 r
F P
0 g
s
.29321 .7777 m .28836 .79501 L .31695 .79747 L p .707 .577 .707 r
F P
0 g
s
.31695 .79747 m .3218 .78016 L .29321 .7777 L p .707 .577 .707 r
F P
0 g
s
.20595 .74854 m .2011 .76585 L .22745 .77839 L p .707 .577 .707 r
F P
0 g
s
.3551 .6859 m .35536 .72299 L .37173 .71558 L p .707 .577 .707 r
F P
0 g
s
.37173 .71558 m .37147 .6785 L .3551 .6859 L p .707 .577 .707 r
F P
0 g
s
.70942 .85672 m .70457 .87402 L .69277 .8603 L p .707 .577 .707 r
F P
0 g
s
.69277 .8603 m .69762 .843 L .70942 .85672 L p .707 .577 .707 r
F P
0 g
s
.35838 .59918 m .36794 .6549 L .3751 .6474 L p .707 .577 .707 r
F P
0 g
s
.3751 .6474 m .36554 .59169 L .35838 .59918 L p .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .36554 .59169 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .37004 .62752 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.37004 .62752 m .36286 .58566 L p .37179 .63684 L .707 .577 .707 r
F P
0 g
s
.35414 .3026 m .33639 .2926 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .36563 .62558 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .40175 .81374 L p .39549 .7465 L .707 .577 .707 r
F P
0 g
s
.37242 .64138 m .36928 .64036 L p .36774 .63412 L .707 .577 .707 r
F P
0 g
s
.36286 .58566 m .37004 .62752 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.37147 .6785 m .37173 .71558 L .37881 .70725 L p .707 .577 .707 r
F P
0 g
s
.37881 .70725 m .37855 .67017 L .37147 .6785 L p .707 .577 .707 r
F P
0 g
s
.37855 .67017 m .37881 .70725 L .37592 .69881 L p .707 .577 .707 r
F P
0 g
s
.37592 .69881 m .37565 .66173 L .37855 .67017 L p .707 .577 .707 r
F P
0 g
s
.36563 .62558 m .37205 .80606 L p .3724 .80516 L .707 .577 .707 r
F P
0 g
s
.37565 .66173 m .37592 .69881 L .37357 .69738 L p .707 .577 .707 r
F P
0 g
s
.37391 .66589 m .37565 .66173 L .37357 .69738 L .707 .577 .707 r
F
.37398 .65939 m .36563 .62558 L .3724 .80516 L F
.34535 .77826 m .3405 .79557 L .35669 .78949 L p F P
0 g
s
.35669 .78949 m .36154 .77218 L .34535 .77826 L p .707 .577 .707 r
F P
0 g
s
.36154 .77218 m .35669 .78949 L .36395 .77983 L p .707 .577 .707 r
F P
0 g
s
.36395 .77983 m .3688 .76253 L .36154 .77218 L p .707 .577 .707 r
F P
0 g
s
.3688 .76253 m .36395 .77983 L .36156 .76755 L p .707 .577 .707 r
F P
0 g
s
.36156 .76755 m .36641 .75024 L .3688 .76253 L p .707 .577 .707 r
F P
0 g
s
.36641 .75024 m .36156 .76755 L .35564 .76067 L p .707 .577 .707 r
F P
0 g
s
.35564 .76067 m .34976 .75383 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35497 .7527 m .36641 .75024 L .35564 .76067 L .707 .577 .707 r
F
.35787 .68947 m .34227 .68484 L p .35651 .66372 L F P
0 g
s
.35461 .73652 m .36641 .75024 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.34976 .75383 m .35385 .73924 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35385 .73924 m .35461 .73652 L p .35497 .7527 L .707 .577 .707 r
F P
0 g
s
.35461 .73652 m .34976 .75383 L .33746 .74537 L p .707 .577 .707 r
F P
0 g
s
.33746 .74537 m .3297 .74002 L p .33749 .73893 L .707 .577 .707 r
F P
0 g
s
.33749 .73893 m .35461 .73652 L .33746 .74537 L .707 .577 .707 r
F
.3506 .5817 m .35752 .62201 L p .33953 .6359 L F P
0 g
s
.35675 .63716 m .33953 .6359 L p .35752 .62201 L .707 .577 .707 r
F P
0 g
s
.33953 .6359 m .32997 .58018 L .3506 .5817 L p .707 .577 .707 r
F P
0 g
s
.37205 .80606 m .35932 .6228 L .35756 .68358 L .707 .577 .707 r
F
.34227 .68484 m .34201 .64776 L .35588 .65188 L p F P
0 g
s
.35932 .6228 m .35423 .62056 L .35756 .68358 L .707 .577 .707 r
F
.35588 .65188 m .36306 .65401 L p .35651 .66372 L F P
0 g
s
.34227 .68484 m .35588 .65188 L .35651 .66372 L .707 .577 .707 r
F
.3297 .74002 m .33455 .72271 L .35461 .73652 L p F P
0 g
s
.34795 .61779 m .35429 .79607 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.35423 .62056 m .34795 .61779 L .35756 .68358 L .707 .577 .707 r
F
.33231 .28128 m .34471 .62993 L p .34979 .69075 L F P
0 g
s
.34471 .62993 m .35022 .78474 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .33231 .28128 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3511 .70639 m .33639 .2926 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.3506 .5817 m .36286 .58566 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .3506 .5817 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.33639 .2926 m .34795 .61779 L p .35932 .6228 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .33852 .45592 L p .34231 .26972 L .707 .577 .707 r
F P
0 g
s
.33852 .45592 m .33231 .28128 L .33919 .27333 L p .707 .577 .707 r
F P
0 g
s
.33919 .27333 m .34231 .26972 L p .33852 .45592 L .707 .577 .707 r
F P
0 g
s
.35022 .78474 m .35429 .79607 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.35752 .62201 m .36016 .63741 L .35675 .63716 L p .707 .577 .707 r
F P
0 g
s
.35429 .79607 m .3511 .70639 L p .34979 .69075 L .707 .577 .707 r
F P
0 g
s
.36377 .80141 m .37205 .80606 L p .35756 .68358 L .707 .577 .707 r
F P
0 g
s
.36306 .65401 m .36332 .69109 L .35787 .68947 L p .707 .577 .707 r
F P
0 g
s
.35651 .66372 m .36306 .65401 L .35787 .68947 L .707 .577 .707 r
F
.35429 .79607 m .36377 .80141 L p .35756 .68358 L F P
0 g
s
.36016 .63741 m .35752 .62201 L p .36089 .62349 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .36306 .65401 L .37397 .6607 L p .707 .577 .707 r
F P
0 g
s
.37397 .6607 m .37565 .66173 L p .37391 .66589 L .707 .577 .707 r
F P
0 g
s
.36332 .69109 m .37397 .6607 L .37391 .66589 L .707 .577 .707 r
F
.37004 .62752 m .37242 .64138 L p .36774 .63412 L F P
0 g
s
.36089 .62349 m .36563 .62558 L .36774 .63412 L .707 .577 .707 r
F
.36563 .62558 m .37004 .62752 L .36774 .63412 L F
.36554 .59169 m .3751 .6474 L .37242 .64138 L p F P
0 g
s
.35414 .3026 m .36563 .62558 L p .37398 .65939 L .707 .577 .707 r
F P
0 g
s
.39549 .7465 m .37537 .53052 L .37398 .65939 L .707 .577 .707 r
F
.37537 .53052 m .35414 .3026 L .37398 .65939 L F
.39549 .7465 m .37398 .65939 L .3724 .80516 L F
.37357 .69738 m .36332 .69109 L p .37391 .66589 L F P
0 g
s
.36016 .63741 m .36089 .62349 L .36774 .63412 L .707 .577 .707 r
F
.36928 .64036 m .36016 .63741 L p .36774 .63412 L F P
0 g
s
.35932 .6228 m .36468 .59898 L .35354 .53961 L .707 .577 .707 r
F
.36563 .62558 m .36468 .59898 L p .35932 .6228 L F P
0 g
s
.36468 .59898 m .35414 .3026 L p .35354 .53961 L .707 .577 .707 r
F P
0 g
s
.2011 .76585 m .20595 .74854 L .18589 .73473 L p .707 .577 .707 r
F P
0 g
s
.67298 .66503 m .68254 .72075 L .65555 .72183 L p .707 .577 .707 r
F P
0 g
s
.65555 .72183 m .64599 .66612 L .67298 .66503 L p .707 .577 .707 r
F P
0 g
s
.70607 .77359 m .70633 .81067 L .68528 .80442 L p .707 .577 .707 r
F P
0 g
s
.68528 .80442 m .68502 .76734 L .70607 .77359 L p .707 .577 .707 r
F P
0 g
s
.3218 .78016 m .31695 .79747 L .3405 .79557 L p .707 .577 .707 r
F P
0 g
s
.3405 .79557 m .34535 .77826 L .3218 .78016 L p .707 .577 .707 r
F P
0 g
s
.18589 .73473 m .18104 .75204 L .2011 .76585 L p .707 .577 .707 r
F P
0 g
s
.60999 .28816 m .62789 .79163 L .6379 .78007 L p .707 .577 .707 r
F P
0 g
s
.6379 .78007 m .61999 .27661 L .60999 .28816 L p .707 .577 .707 r
F P
0 g
s
.18104 .75204 m .18589 .73473 L .17409 .72101 L p .707 .577 .707 r
F P
0 g
s
.69762 .843 m .69277 .8603 L .67271 .8465 L p .707 .577 .707 r
F P
0 g
s
.67271 .8465 m .67756 .82919 L .69762 .843 L p .707 .577 .707 r
F P
0 g
s
.68502 .76734 m .68528 .80442 L .65782 .80025 L p .707 .577 .707 r
F P
0 g
s
.65782 .80025 m .65756 .76317 L .68502 .76734 L p .707 .577 .707 r
F P
0 g
s
.17409 .72101 m .16924 .73832 L .18104 .75204 L p .707 .577 .707 r
F P
0 g
s
.65756 .76317 m .65782 .80025 L .62665 .79857 L p .707 .577 .707 r
F P
0 g
s
.67756 .82919 m .67271 .8465 L .64635 .83396 L p .707 .577 .707 r
F P
0 g
s
.64635 .83396 m .65121 .81665 L .67756 .82919 L p .707 .577 .707 r
F P
0 g
s
.16924 .73832 m .17409 .72101 L .1717 .70872 L p .707 .577 .707 r
F P
0 g
s
.1717 .70872 m .16685 .72603 L .16924 .73832 L p .707 .577 .707 r
F P
0 g
s
.1741 .67748 m .16454 .62176 L .1717 .61427 L p .707 .577 .707 r
F P
0 g
s
.65121 .81665 m .64635 .83396 L .61628 .8239 L p .707 .577 .707 r
F P
0 g
s
.61628 .8239 m .62114 .8066 L .65121 .81665 L p .707 .577 .707 r
F P
0 g
s
.62114 .8066 m .61628 .8239 L .58544 .81733 L p .707 .577 .707 r
F P
0 g
s
.61999 .27661 m .6379 .78007 L .63382 .76875 L p .707 .577 .707 r
F P
0 g
s
.63382 .76875 m .61591 .26528 L .61999 .27661 L p .707 .577 .707 r
F P
0 g
s
.16685 .72603 m .1717 .70872 L .17896 .69907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17896 .69907 m .1741 .71638 L .16685 .72603 L p .707 .577 .707 r
F P
0 g
s
.18125 .66998 m .1717 .61427 L .18799 .60603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.61591 .26528 m .63382 .76875 L .61606 .75876 L p .707 .577 .707 r
F P
0 g
s
.61606 .75876 m .59816 .25529 L .61591 .26528 L p .707 .577 .707 r
F P
0 g
s
.1741 .71638 m .17896 .69907 L .19515 .69299 L p .707 .577 .707 r
F P
0 g
s
.19755 .66175 m .18799 .60603 L .21183 .59787 L p .707 .577 .707 r
F P
0 g
s
.19515 .69299 m .1903 .7103 L .1741 .71638 L p .707 .577 .707 r
F P
0 g
s
.32997 .58018 m .33953 .6359 L .31254 .63699 L p .707 .577 .707 r
F P
0 g
s
.31254 .63699 m .30299 .58127 L .32997 .58018 L p .707 .577 .707 r
F P
0 g
s
.36022 .77319 m .34231 .26972 L .36542 .25907 L p .707 .577 .707 r
F P
0 g
s
.34231 .26972 m .36022 .77319 L .35022 .78474 L p .707 .577 .707 r
F P
0 g
s
.22139 .65358 m .21183 .59787 L .24087 .59057 L p .707 .577 .707 r
F P
0 g
s
.34201 .64776 m .34227 .68484 L .31481 .68067 L p .707 .577 .707 r
F P
0 g
s
.31481 .68067 m .31455 .64359 L .34201 .64776 L p .707 .577 .707 r
F P
0 g
s
.1903 .7103 m .19515 .69299 L .2187 .69109 L p .707 .577 .707 r
F P
0 g
s
.30299 .58127 m .31254 .63699 L .28184 .64056 L p .707 .577 .707 r
F P
0 g
s
.28184 .64056 m .27228 .58485 L .30299 .58127 L p .707 .577 .707 r
F P
0 g
s
.2187 .69109 m .21384 .7084 L .1903 .7103 L p .707 .577 .707 r
F P
0 g
s
.27228 .58485 m .28184 .64056 L .25043 .64628 L p .707 .577 .707 r
F P
0 g
s
.59816 .25529 m .61606 .75876 L .58636 .75108 L p .707 .577 .707 r
F P
0 g
s
.58636 .75108 m .56846 .24761 L .59816 .25529 L p .707 .577 .707 r
F P
0 g
s
.31455 .64359 m .31481 .68067 L .28364 .679 L p .707 .577 .707 r
F P
0 g
s
.28364 .679 m .28338 .64191 L .31455 .64359 L p .707 .577 .707 r
F P
0 g
s
.21384 .7084 m .2187 .69109 L .24729 .69354 L p .707 .577 .707 r
F P
0 g
s
.28338 .64191 m .28364 .679 L .25181 .67998 L p .707 .577 .707 r
F P
0 g
s
.33455 .72271 m .3297 .74002 L .30334 .72748 L p .707 .577 .707 r
F P
0 g
s
.30334 .72748 m .3082 .71017 L .33455 .72271 L p .707 .577 .707 r
F P
0 g
s
.74757 .67713 m .73801 .62141 L .70731 .62499 L p .707 .577 .707 r
F P
0 g
s
.73801 .62141 m .74757 .67713 L .77898 .67141 L p .707 .577 .707 r
F P
0 g
s
.77898 .67141 m .76942 .61569 L .73801 .62141 L p .707 .577 .707 r
F P
0 g
s
.76942 .61569 m .77898 .67141 L .80802 .66411 L p .707 .577 .707 r
F P
0 g
s
.80802 .66411 m .79846 .60839 L .76942 .61569 L p .707 .577 .707 r
F P
0 g
s
.24729 .69354 m .24244 .71085 L .21384 .7084 L p .707 .577 .707 r
F P
0 g
s
.36542 .25907 m .38332 .76253 L .36022 .77319 L p .707 .577 .707 r
F P
0 g
s
.38332 .76253 m .36542 .25907 L .39936 .25036 L p .707 .577 .707 r
F P
0 g
s
.71686 .68071 m .70731 .62499 L .68032 .62607 L p .707 .577 .707 r
F P
0 g
s
.70731 .62499 m .71686 .68071 L .74757 .67713 L p .707 .577 .707 r
F P
0 g
s
.24244 .71085 m .24729 .69354 L .27813 .70012 L p .707 .577 .707 r
F P
0 g
s
.79846 .60839 m .80802 .66411 L .83186 .65594 L p .707 .577 .707 r
F P
0 g
s
.83186 .65594 m .8223 .60023 L .79846 .60839 L p .707 .577 .707 r
F P
0 g
s
.3082 .71017 m .30334 .72748 L .27327 .71743 L p .707 .577 .707 r
F P
0 g
s
.27327 .71743 m .27813 .70012 L .3082 .71017 L p .707 .577 .707 r
F P
0 g
s
.27813 .70012 m .27327 .71743 L .24244 .71085 L p .707 .577 .707 r
F P
0 g
s
.68032 .62607 m .68988 .68179 L .71686 .68071 L p .707 .577 .707 r
F P
0 g
s
.56846 .24761 m .58636 .75108 L .54763 .74647 L p .707 .577 .707 r
F P
0 g
s
.54763 .74647 m .52972 .243 L .56846 .24761 L p .707 .577 .707 r
F P
0 g
s
.7503 .7608 m .75004 .72372 L .71887 .72204 L p .707 .577 .707 r
F P
0 g
s
.75004 .72372 m .7503 .7608 L .78214 .75982 L p .707 .577 .707 r
F P
0 g
s
.78214 .75982 m .78188 .72274 L .75004 .72372 L p .707 .577 .707 r
F P
0 g
s
.68988 .68179 m .68032 .62607 L .65969 .62456 L p .707 .577 .707 r
F P
0 g
s
.78188 .72274 m .78214 .75982 L .81152 .75628 L p .707 .577 .707 r
F P
0 g
s
.81152 .75628 m .81126 .7192 L .78188 .72274 L p .707 .577 .707 r
F P
0 g
s
.71913 .75912 m .71887 .72204 L .69141 .71787 L p .707 .577 .707 r
F P
0 g
s
.71887 .72204 m .71913 .75912 L .7503 .7608 L p .707 .577 .707 r
F P
0 g
s
.8223 .60023 m .83186 .65594 L .84815 .64771 L p .707 .577 .707 r
F P
0 g
s
.84815 .64771 m .8386 .59199 L .8223 .60023 L p .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .44082 .24445 L p .42565 .57266 L .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .41858 .57404 L .42563 .57266 L .707 .577 .707 r
F
.42252 .64037 m .42563 .57266 L .42564 .57281 L F
.41727 .75383 m .41496 .68878 L p .42252 .64037 L F P
0 g
s
.41496 .68878 m .39936 .25036 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.39936 .25036 m .41496 .68878 L p .38332 .76253 L .707 .577 .707 r
F P
0 g
s
.41496 .68878 m .41727 .75383 L .41174 .75524 L p .707 .577 .707 r
F P
0 g
s
.41174 .75524 m .38332 .76253 L p .41496 .68878 L .707 .577 .707 r
F P
0 g
s
.395 .53656 m .40456 .59228 L .41976 .58951 L p .707 .577 .707 r
F P
0 g
s
.41858 .57404 m .39936 .25036 L .42565 .57266 L .707 .577 .707 r
F
.43088 .64049 m .43913 .64024 L p .43007 .63005 L F P
0 g
s
.46641 .6041 m .4649 .5829 L .48574 .24191 L .707 .577 .707 r
F
.44082 .24445 m .47655 .24243 L p .4649 .5829 L F P
0 g
s
.47655 .24243 m .48574 .24191 L p .4649 .5829 L .707 .577 .707 r
F P
0 g
s
.46431 .60009 m .43887 .60316 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.43597 .58656 m .45758 .58113 L p .45296 .56912 L .707 .577 .707 r
F P
0 g
s
.45231 .56743 m .44082 .24445 L p .46641 .6041 L .707 .577 .707 r
F P
0 g
s
.43332 .57115 m .43597 .58656 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.43887 .60316 m .43913 .64024 L .46303 .63736 L p .707 .577 .707 r
F P
0 g
s
.46326 .63076 m .43887 .60316 L .46303 .63736 L .707 .577 .707 r
F
.45873 .74792 m .45571 .66309 L p .46227 .65417 L F P
0 g
s
.45873 .74792 m .41727 .75383 L p .42142 .66396 L .707 .577 .707 r
F P
0 g
s
.43077 .58751 m .43597 .58656 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.44082 .24445 m .4489 .47144 L p .43332 .57115 L .707 .577 .707 r
F P
0 g
s
.43913 .64024 m .43887 .60316 L .42802 .60349 L p .707 .577 .707 r
F P
0 g
s
.42252 .64037 m .42564 .57281 L .4281 .6046 L .707 .577 .707 r
F
.43913 .64024 m .42802 .60349 L .43007 .63005 L F
.43597 .58656 m .43332 .57115 L p .43173 .58139 L F P
0 g
s
.4489 .47144 m .45571 .66309 L p .42252 .64037 L .707 .577 .707 r
F P
0 g
s
.42802 .60349 m .40703 .60414 L p .43007 .63005 L .707 .577 .707 r
F P
0 g
s
.4281 .6046 m .42565 .57266 L .43332 .57115 L .707 .577 .707 r
F
.42564 .57281 m .42565 .57266 L .4281 .6046 L F
.42565 .57266 m .44082 .24445 L .43332 .57115 L F
.45546 .52355 m .42641 .53085 L p .45514 .56688 L F P
0 g
s
.46501 .57926 m .46264 .56541 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.46264 .56541 m .45546 .52355 L p .45514 .56688 L .707 .577 .707 r
F P
0 g
s
.42564 .57281 m .42563 .57266 L .42565 .57266 L .707 .577 .707 r
F
.42641 .53085 m .395 .53656 L p .43173 .58139 L F P
0 g
s
.43332 .57115 m .42641 .53085 L p .43173 .58139 L .707 .577 .707 r
F P
0 g
s
.42142 .66396 m .42252 .64037 L .45571 .66309 L .707 .577 .707 r
F
.45571 .66309 m .45873 .74792 L p .42142 .66396 L F P
0 g
s
.45415 .70543 m .45901 .68812 L .43861 .68637 L p .707 .577 .707 r
F P
0 g
s
.43861 .68637 m .43042 .68567 L p .43582 .69017 L .707 .577 .707 r
F P
0 g
s
.45415 .70543 m .43861 .68637 L .43582 .69017 L .707 .577 .707 r
F
.46227 .65417 m .45231 .56743 L .46436 .59877 L F
.45571 .66309 m .45231 .56743 L p .46227 .65417 L F P
0 g
s
.46018 .72077 m .46436 .59877 L .46641 .6041 L .707 .577 .707 r
F
.45873 .74792 m .46436 .59877 L .46018 .72077 L F
.48574 .24191 m .50365 .74538 L .45873 .74792 L p F P
0 g
s
.46303 .63736 m .46851 .6367 L p .46326 .63076 L .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46825 .59962 L .46431 .60009 L p .707 .577 .707 r
F P
0 g
s
.46851 .6367 m .46431 .60009 L .46326 .63076 L .707 .577 .707 r
F
.46501 .57926 m .45514 .56688 L .45296 .56912 L F
.45758 .58113 m .46501 .57926 L p .45296 .56912 L F P
0 g
s
.41976 .58951 m .43077 .58751 L p .42056 .57296 L .707 .577 .707 r
F P
0 g
s
.42056 .57296 m .395 .53656 L .41976 .58951 L .707 .577 .707 r
F
.40703 .60414 m .40729 .64122 L .43088 .64049 L p F P
0 g
s
.43007 .63005 m .40703 .60414 L .43088 .64049 L .707 .577 .707 r
F
.42641 .53085 m .43332 .57115 L p .45514 .56688 L F P
0 g
s
.43173 .58139 m .395 .53656 L .43077 .58751 L .707 .577 .707 r
F
.65969 .62456 m .66925 .68028 L .68988 .68179 L p F P
0 g
s
.81126 .7192 m .81152 .75628 L .83557 .75053 L p .707 .577 .707 r
F P
0 g
s
.83557 .75053 m .83531 .71344 L .81126 .7192 L p .707 .577 .707 r
F P
0 g
s
.69141 .71787 m .69168 .75495 L .71913 .75912 L p .707 .577 .707 r
F P
0 g
s
.73773 .80288 m .74259 .78557 L .71252 .77552 L p .707 .577 .707 r
F P
0 g
s
.74259 .78557 m .73773 .80288 L .76857 .80945 L p .707 .577 .707 r
F P
0 g
s
.76857 .80945 m .77343 .79215 L .74259 .78557 L p .707 .577 .707 r
F P
0 g
s
.52972 .243 m .54763 .74647 L .50365 .74538 L p .707 .577 .707 r
F P
0 g
s
.50365 .74538 m .48574 .24191 L .52972 .243 L p .707 .577 .707 r
F P
0 g
s
.69168 .75495 m .69141 .71787 L .67036 .71162 L p .707 .577 .707 r
F P
0 g
s
.70766 .79283 m .71252 .77552 L .68616 .76298 L p .707 .577 .707 r
F P
0 g
s
.71252 .77552 m .70766 .79283 L .73773 .80288 L p .707 .577 .707 r
F P
0 g
s
.77343 .79215 m .76857 .80945 L .79716 .81191 L p .707 .577 .707 r
F P
0 g
s
.79716 .81191 m .80202 .7946 L .77343 .79215 L p .707 .577 .707 r
F P
0 g
s
.66925 .68028 m .65969 .62456 L .64743 .6206 L p .707 .577 .707 r
F P
0 g
s
.68616 .76298 m .68131 .78029 L .70766 .79283 L p .707 .577 .707 r
F P
0 g
s
.67036 .71162 m .67062 .7487 L .69168 .75495 L p .707 .577 .707 r
F P
0 g
s
.83531 .71344 m .83557 .75053 L .85194 .74312 L p .707 .577 .707 r
F P
0 g
s
.85194 .74312 m .85168 .70604 L .83531 .71344 L p .707 .577 .707 r
F P
0 g
s
.8386 .59199 m .84815 .64771 L .85531 .64021 L p .707 .577 .707 r
F P
0 g
s
.85531 .64021 m .84575 .58449 L .8386 .59199 L p .707 .577 .707 r
F P
0 g
s
.68131 .78029 m .68616 .76298 L .6661 .74917 L p .707 .577 .707 r
F P
0 g
s
.64743 .6206 m .65699 .67632 L .66925 .68028 L p .707 .577 .707 r
F P
0 g
s
.80202 .7946 m .79716 .81191 L .82071 .81001 L p .707 .577 .707 r
F P
0 g
s
.82071 .81001 m .82556 .7927 L .80202 .7946 L p .707 .577 .707 r
F P
0 g
s
.6661 .74917 m .66125 .76648 L .68131 .78029 L p .707 .577 .707 r
F P
0 g
s
.67062 .7487 m .67036 .71162 L .65777 .7039 L p .707 .577 .707 r
F P
0 g
s
.65699 .67632 m .64743 .6206 L .64475 .61457 L p .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .6661 .74917 L .65891 .7408 L p .707 .577 .707 r
F P
0 g
s
.65891 .7408 m .6543 .73545 L p .66003 .76101 L .707 .577 .707 r
F P
0 g
s
.66125 .76648 m .65891 .7408 L .66003 .76101 L .707 .577 .707 r
F
.65803 .74098 m .6579 .72263 L p .65487 .69546 L F P
0 g
s
.6579 .72263 m .65777 .7039 L .65669 .70075 L p .707 .577 .707 r
F P
0 g
s
.65669 .70075 m .65487 .69546 L p .6579 .72263 L .707 .577 .707 r
F P
0 g
s
.65777 .7039 m .65803 .74098 L .67062 .7487 L p .707 .577 .707 r
F P
0 g
s
.82556 .7927 m .82071 .81001 L .8369 .80393 L p .707 .577 .707 r
F P
0 g
s
.8369 .80393 m .84176 .78662 L .82556 .7927 L p .707 .577 .707 r
F P
0 g
s
.85168 .70604 m .85194 .74312 L .85903 .73479 L p .707 .577 .707 r
F P
0 g
s
.85903 .73479 m .85876 .69771 L .85168 .70604 L p .707 .577 .707 r
F P
0 g
s
.6543 .73545 m .64945 .75276 L .66125 .76648 L p .707 .577 .707 r
F P
0 g
s
.84575 .58449 m .85531 .64021 L .85263 .63419 L p .707 .577 .707 r
F P
0 g
s
.85263 .63419 m .84307 .57847 L .84575 .58449 L p .707 .577 .707 r
F P
0 g
s
.64475 .61457 m .65431 .67029 L .65699 .67632 L p .707 .577 .707 r
F P
0 g
s
.64945 .75276 m .6543 .73545 L .65191 .72316 L p .707 .577 .707 r
F P
0 g
s
.65191 .72316 m .64706 .74047 L .64945 .75276 L p .707 .577 .707 r
F P
0 g
s
.64706 .74047 m .65191 .72316 L .6541 .72026 L p .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65803 .74098 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65499 .7122 m .65513 .73254 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65487 .69546 m .65499 .7122 L p .65563 .7064 L .707 .577 .707 r
F P
0 g
s
.65513 .73254 m .65487 .69546 L .66195 .68713 L p .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .65513 .73254 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66195 .68713 m .66207 .70319 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66207 .70319 m .66222 .72421 L p .66041 .6974 L .707 .577 .707 r
F P
0 g
s
.66222 .72421 m .66195 .68713 L .67832 .67973 L p .707 .577 .707 r
F P
0 g
s
.65432 .73082 m .65917 .71351 L .66446 .71152 L p .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .66222 .72421 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67832 .67973 m .67844 .69647 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67844 .69647 m .67859 .71681 L p .67478 .68952 L .707 .577 .707 r
F P
0 g
s
.67859 .71681 m .67832 .67973 L .70237 .67397 L p .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .67537 .70743 L .68385 .70674 L p .707 .577 .707 r
F P
0 g
s
.70237 .67397 m .70264 .71106 L .67859 .71681 L p .707 .577 .707 r
F P
0 g
s
.68385 .70674 m .69891 .70553 L p .68734 .71336 L .707 .577 .707 r
F P
0 g
s
.67051 .72474 m .68385 .70674 L .68734 .71336 L .707 .577 .707 r
F
.66446 .71152 m .67537 .70743 L p .6662 .71761 L F P
0 g
s
.65432 .73082 m .66446 .71152 L .6662 .71761 L .707 .577 .707 r
F
.6541 .72026 m .65917 .71351 L p .65343 .72628 L F P
0 g
s
.64706 .74047 m .6541 .72026 L .65343 .72628 L .707 .577 .707 r
F
.65431 .67029 m .64475 .61457 L .65191 .60708 L p F P
0 g
s
.84176 .78662 m .8369 .80393 L .84416 .79427 L p .707 .577 .707 r
F P
0 g
s
.84416 .79427 m .84902 .77697 L .84176 .78662 L p .707 .577 .707 r
F P
0 g
s
.85876 .69771 m .85903 .73479 L .85613 .72635 L p .707 .577 .707 r
F P
0 g
s
.85613 .72635 m .85587 .68927 L .85876 .69771 L p .707 .577 .707 r
F P
0 g
s
.40456 .59228 m .395 .53656 L .3643 .54014 L p .707 .577 .707 r
F P
0 g
s
.84307 .57847 m .85263 .63419 L .84038 .63022 L p .707 .577 .707 r
F P
0 g
s
.84038 .63022 m .83082 .57451 L .84307 .57847 L p .707 .577 .707 r
F P
0 g
s
.65191 .60708 m .66147 .66279 L .65431 .67029 L p .707 .577 .707 r
F P
0 g
s
.37385 .59586 m .3643 .54014 L .33731 .54123 L p .707 .577 .707 r
F P
0 g
s
.3643 .54014 m .37385 .59586 L .40456 .59228 L p .707 .577 .707 r
F P
0 g
s
.45546 .52355 m .46501 .57926 L .48885 .57109 L p .707 .577 .707 r
F P
0 g
s
.48885 .57109 m .47929 .51538 L .45546 .52355 L p .707 .577 .707 r
F P
0 g
s
.40729 .64122 m .40703 .60414 L .37586 .60246 L p .707 .577 .707 r
F P
0 g
s
.33731 .54123 m .34687 .59694 L .37385 .59586 L p .707 .577 .707 r
F P
0 g
s
.37612 .63954 m .37586 .60246 L .3484 .59829 L p .707 .577 .707 r
F P
0 g
s
.37586 .60246 m .37612 .63954 L .40729 .64122 L p .707 .577 .707 r
F P
0 g
s
.66147 .66279 m .65191 .60708 L .6682 .59884 L p .707 .577 .707 r
F P
0 g
s
.84902 .77697 m .84416 .79427 L .84177 .78199 L p .707 .577 .707 r
F P
0 g
s
.84177 .78199 m .84663 .76468 L .84902 .77697 L p .707 .577 .707 r
F P
0 g
s
.34687 .59694 m .33731 .54123 L .31668 .53971 L p .707 .577 .707 r
F P
0 g
s
.65917 .71351 m .65432 .73082 L .64706 .74047 L p .707 .577 .707 r
F P
0 g
s
.85587 .68927 m .85613 .72635 L .84354 .71863 L p .707 .577 .707 r
F P
0 g
s
.84354 .71863 m .84328 .68155 L .85587 .68927 L p .707 .577 .707 r
F P
0 g
s
.46825 .59962 m .46851 .6367 L .49256 .63095 L p .707 .577 .707 r
F P
0 g
s
.49256 .63095 m .4923 .59387 L .46825 .59962 L p .707 .577 .707 r
F P
0 g
s
.83082 .57451 m .84038 .63022 L .81975 .62871 L p .707 .577 .707 r
F P
0 g
s
.81975 .62871 m .81019 .57299 L .83082 .57451 L p .707 .577 .707 r
F P
0 g
s
.3484 .59829 m .34867 .63538 L .37612 .63954 L p .707 .577 .707 r
F P
0 g
s
.47929 .51538 m .48885 .57109 L .50515 .56286 L p .707 .577 .707 r
F P
0 g
s
.50515 .56286 m .49559 .50714 L .47929 .51538 L p .707 .577 .707 r
F P
0 g
s
.6682 .59884 m .67776 .65456 L .66147 .66279 L p .707 .577 .707 r
F P
0 g
s
.31668 .53971 m .32624 .59543 L .3281 .59557 L p .707 .577 .707 r
F P
0 g
s
.3281 .59557 m .34687 .59694 L p .33098 .56683 L .707 .577 .707 r
F P
0 g
s
.33098 .56683 m .31668 .53971 L .3281 .59557 L .707 .577 .707 r
F
.32624 .59543 m .31668 .53971 L .30442 .53575 L p F P
0 g
s
.30442 .53575 m .31398 .59147 L .315 .5918 L p .707 .577 .707 r
F P
0 g
s
.315 .5918 m .32624 .59543 L p .31581 .5669 L .707 .577 .707 r
F P
0 g
s
.31581 .5669 m .30442 .53575 L .315 .5918 L .707 .577 .707 r
F
.31398 .59147 m .30442 .53575 L .30174 .52973 L p F P
0 g
s
.30174 .52973 m .3113 .58544 L .31148 .58586 L p .707 .577 .707 r
F P
0 g
s
.31148 .58586 m .31398 .59147 L p .30831 .56286 L .707 .577 .707 r
F P
0 g
s
.30831 .56286 m .30174 .52973 L .31148 .58586 L .707 .577 .707 r
F
.31476 .58432 m .31186 .57588 L p .31435 .61171 L F P
0 g
s
.31484 .59649 m .31476 .58432 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .31476 .58432 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.31476 .58432 m .31502 .6214 L .32761 .62912 L p .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31894 .56755 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31186 .57588 m .31195 .58926 L p .31502 .6214 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31212 .61296 L .31337 .61659 L p .707 .577 .707 r
F P
0 g
s
.31337 .61659 m .31502 .6214 L p .31195 .58926 L .707 .577 .707 r
F P
0 g
s
.31195 .58926 m .31186 .57588 L p .31374 .60219 L .707 .577 .707 r
F P
0 g
s
.31502 .6214 m .31484 .59649 L p .31435 .61171 L .707 .577 .707 r
F P
0 g
s
.31894 .56755 m .31904 .58135 L p .31212 .61296 L .707 .577 .707 r
F P
0 g
s
.31904 .58135 m .31921 .60463 L .31626 .6081 L p .707 .577 .707 r
F P
0 g
s
.31626 .6081 m .31212 .61296 L p .31904 .58135 L .707 .577 .707 r
F P
0 g
s
.31921 .60463 m .31894 .56755 L .33531 .56015 L p .707 .577 .707 r
F P
0 g
s
.32519 .51399 m .32573 .5171 L p .31846 .57795 L .707 .577 .707 r
F P
0 g
s
.32742 .60234 m .32735 .59204 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.34867 .63538 m .3484 .59829 L .32735 .59204 L p .707 .577 .707 r
F P
0 g
s
.32735 .59204 m .32761 .62912 L .34867 .63538 L p .707 .577 .707 r
F P
0 g
s
.33531 .56015 m .33541 .57353 L p .31921 .60463 L .707 .577 .707 r
F P
0 g
s
.33541 .57353 m .33557 .59723 L .3294 .60002 L p .707 .577 .707 r
F P
0 g
s
.3294 .60002 m .31921 .60463 L p .33541 .57353 L .707 .577 .707 r
F P
0 g
s
.33557 .59723 m .33531 .56015 L .35936 .55439 L p .707 .577 .707 r
F P
0 g
s
.34903 .50583 m .34977 .51014 L p .33475 .56971 L .707 .577 .707 r
F P
0 g
s
.35936 .55439 m .35945 .56657 L p .33557 .59723 L .707 .577 .707 r
F P
0 g
s
.35945 .56657 m .35963 .59148 L .35213 .59327 L p .707 .577 .707 r
F P
0 g
s
.35213 .59327 m .33557 .59723 L p .35945 .56657 L .707 .577 .707 r
F P
0 g
s
.35963 .59148 m .35936 .55439 L .38875 .55085 L p .707 .577 .707 r
F P
0 g
s
.37808 .49853 m .37809 .4986 L p .35859 .56154 L .707 .577 .707 r
F P
0 g
s
.38875 .55085 m .38882 .56115 L p .35963 .59148 L .707 .577 .707 r
F P
0 g
s
.38882 .56115 m .38901 .58794 L .38268 .5887 L p .707 .577 .707 r
F P
0 g
s
.38268 .5887 m .35963 .59148 L p .38882 .56115 L .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .37808 .49853 L .40381 .49384 L p .707 .577 .707 r
F P
0 g
s
.40381 .49384 m .40949 .49281 L p .39492 .53377 L .707 .577 .707 r
F P
0 g
s
.38901 .58794 m .38875 .55085 L .42058 .54987 L p .707 .577 .707 r
F P
0 g
s
.38763 .55424 m .40381 .49384 L .39492 .53377 L .707 .577 .707 r
F
.37809 .4986 m .38763 .55424 L .36099 .56094 L p F P
0 g
s
.36099 .56094 m .35859 .56154 L p .37809 .4986 L .707 .577 .707 r
F P
0 g
s
.34977 .51014 m .35859 .56154 L .3364 .56915 L p .707 .577 .707 r
F P
0 g
s
.3364 .56915 m .33475 .56971 L p .34977 .51014 L .707 .577 .707 r
F P
0 g
s
.32573 .5171 m .33475 .56971 L .31945 .57745 L p .707 .577 .707 r
F P
0 g
s
.31945 .57745 m .31846 .57795 L p .32573 .5171 L .707 .577 .707 r
F P
0 g
s
.3089 .52223 m .31846 .57795 L .31173 .58499 L p .707 .577 .707 r
F P
0 g
s
.31173 .58499 m .3113 .58544 L p .31004 .55215 L .707 .577 .707 r
F P
0 g
s
.31004 .55215 m .3089 .52223 L .31173 .58499 L .707 .577 .707 r
F
.31212 .61296 m .31195 .58926 L p .31374 .60219 L F P
0 g
s
.32761 .62912 m .32742 .60234 L p .32548 .62169 L .707 .577 .707 r
F P
0 g
s
.39472 .6964 m .39958 .67909 L .36951 .66904 L p .707 .577 .707 r
F P
0 g
s
.39958 .67909 m .39472 .6964 L .42556 .70298 L p .707 .577 .707 r
F P
0 g
s
.42556 .70298 m .43042 .68567 L .39958 .67909 L p .707 .577 .707 r
F P
0 g
s
.36465 .68635 m .36951 .66904 L .34315 .6565 L p .707 .577 .707 r
F P
0 g
s
.36951 .66904 m .36465 .68635 L .39472 .6964 L p .707 .577 .707 r
F P
0 g
s
.43042 .68567 m .42556 .70298 L .45415 .70543 L p .707 .577 .707 r
F P
0 g
s
.67776 .65456 m .6682 .59884 L .69204 .59067 L p .707 .577 .707 r
F P
0 g
s
.34315 .6565 m .3383 .67381 L .36465 .68635 L p .707 .577 .707 r
F P
0 g
s
.4923 .59387 m .49256 .63095 L .50893 .62354 L p .707 .577 .707 r
F P
0 g
s
.50893 .62354 m .50867 .58646 L .4923 .59387 L p .707 .577 .707 r
F P
0 g
s
.84663 .76468 m .84177 .78199 L .82997 .76827 L p .707 .577 .707 r
F P
0 g
s
.82997 .76827 m .83483 .75096 L .84663 .76468 L p .707 .577 .707 r
F P
0 g
s
.3383 .67381 m .34315 .6565 L .32309 .64269 L p .707 .577 .707 r
F P
0 g
s
.81019 .57299 m .81975 .62871 L .79276 .6298 L p .707 .577 .707 r
F P
0 g
s
.79276 .6298 m .7832 .57408 L .81019 .57299 L p .707 .577 .707 r
F P
0 g
s
.67537 .70743 m .67051 .72474 L .65432 .73082 L p .707 .577 .707 r
F P
0 g
s
.84328 .68155 m .84354 .71863 L .82248 .71238 L p .707 .577 .707 r
F P
0 g
s
.82248 .71238 m .82222 .6753 L .84328 .68155 L p .707 .577 .707 r
F P
0 g
s
.45901 .68812 m .45415 .70543 L .4777 .70353 L p .707 .577 .707 r
F P
0 g
s
.4777 .70353 m .48255 .68622 L .45901 .68812 L p .707 .577 .707 r
F P
0 g
s
.49559 .50714 m .50515 .56286 L .5123 .55536 L p .707 .577 .707 r
F P
0 g
s
.5123 .55536 m .50274 .49965 L .49559 .50714 L p .707 .577 .707 r
F P
0 g
s
.69204 .59067 m .7016 .64639 L .67776 .65456 L p .707 .577 .707 r
F P
0 g
s
.32309 .64269 m .31824 .66 L .3383 .67381 L p .707 .577 .707 r
F P
0 g
s
.7016 .64639 m .69204 .59067 L .72109 .58337 L p .707 .577 .707 r
F P
0 g
s
.7832 .57408 m .79276 .6298 L .76206 .63337 L p .707 .577 .707 r
F P
0 g
s
.76206 .63337 m .7525 .57766 L .7832 .57408 L p .707 .577 .707 r
F P
0 g
s
.50867 .58646 m .50893 .62354 L .51602 .61522 L p .707 .577 .707 r
F P
0 g
s
.51602 .61522 m .51575 .57813 L .50867 .58646 L p .707 .577 .707 r
F P
0 g
s
.31824 .66 m .32309 .64269 L .31129 .62897 L p .707 .577 .707 r
F P
0 g
s
.83483 .75096 m .82997 .76827 L .80991 .75446 L p .707 .577 .707 r
F P
0 g
s
.80991 .75446 m .81477 .73715 L .83483 .75096 L p .707 .577 .707 r
F P
0 g
s
.82222 .6753 m .82248 .71238 L .79503 .70821 L p .707 .577 .707 r
F P
0 g
s
.79503 .70821 m .79476 .67113 L .82222 .6753 L p .707 .577 .707 r
F P
0 g
s
.48255 .68622 m .4777 .70353 L .49389 .69745 L p .707 .577 .707 r
F P
0 g
s
.49389 .69745 m .49875 .68014 L .48255 .68622 L p .707 .577 .707 r
F P
0 g
s
.73064 .63909 m .72109 .58337 L .7525 .57766 L p .707 .577 .707 r
F P
0 g
s
.72109 .58337 m .73064 .63909 L .7016 .64639 L p .707 .577 .707 r
F P
0 g
s
.7525 .57766 m .76206 .63337 L .73064 .63909 L p .707 .577 .707 r
F P
0 g
s
.69891 .70553 m .69406 .72284 L .67051 .72474 L p .707 .577 .707 r
F P
0 g
s
.31129 .62897 m .30644 .64628 L .31824 .66 L p .707 .577 .707 r
F P
0 g
s
.70264 .71106 m .70237 .67397 L .73176 .67043 L p .707 .577 .707 r
F P
0 g
s
.50274 .49965 m .5123 .55536 L .50962 .54934 L p .707 .577 .707 r
F P
0 g
s
.50962 .54934 m .50006 .49362 L .50274 .49965 L p .707 .577 .707 r
F P
0 g
s
.79476 .67113 m .79503 .70821 L .76385 .70654 L p .707 .577 .707 r
F P
0 g
s
.76385 .70654 m .76359 .66945 L .79476 .67113 L p .707 .577 .707 r
F P
0 g
s
.73176 .67043 m .73202 .70752 L .70264 .71106 L p .707 .577 .707 r
F P
0 g
s
.69406 .72284 m .69891 .70553 L .7275 .70798 L p .707 .577 .707 r
F P
0 g
s
.73202 .70752 m .73176 .67043 L .76359 .66945 L p .707 .577 .707 r
F P
0 g
s
.81477 .73715 m .80991 .75446 L .78356 .74192 L p .707 .577 .707 r
F P
0 g
s
.78356 .74192 m .78841 .72461 L .81477 .73715 L p .707 .577 .707 r
F P
0 g
s
.76359 .66945 m .76385 .70654 L .73202 .70752 L p .707 .577 .707 r
F P
0 g
s
.30644 .64628 m .31129 .62897 L .3089 .61668 L p .707 .577 .707 r
F P
0 g
s
.7275 .70798 m .72265 .72529 L .69406 .72284 L p .707 .577 .707 r
F P
0 g
s
.51575 .57813 m .51602 .61522 L .51312 .60678 L p .707 .577 .707 r
F P
0 g
s
.51312 .60678 m .51286 .56969 L .51575 .57813 L p .707 .577 .707 r
F P
0 g
s
.49875 .68014 m .49389 .69745 L .50115 .6878 L p .707 .577 .707 r
F P
0 g
s
.50115 .6878 m .50601 .67049 L .49875 .68014 L p .707 .577 .707 r
F P
0 g
s
.3089 .61668 m .30405 .63399 L .30644 .64628 L p .707 .577 .707 r
F P
0 g
s
.3113 .58544 m .30174 .52973 L .3089 .52223 L p .707 .577 .707 r
F P
0 g
s
.72265 .72529 m .7275 .70798 L .75834 .71456 L p .707 .577 .707 r
F P
0 g
s
.78841 .72461 m .78356 .74192 L .75349 .73187 L p .707 .577 .707 r
F P
0 g
s
.75349 .73187 m .75834 .71456 L .78841 .72461 L p .707 .577 .707 r
F P
0 g
s
.75834 .71456 m .75349 .73187 L .72265 .72529 L p .707 .577 .707 r
F P
0 g
s
.50006 .49362 m .50962 .54934 L .49737 .54537 L p .707 .577 .707 r
F P
0 g
s
.49737 .54537 m .48781 .48966 L .50006 .49362 L p .707 .577 .707 r
F P
0 g
s
.30405 .63399 m .3089 .61668 L .31616 .60703 L p .707 .577 .707 r
F P
0 g
s
.50601 .67049 m .50115 .6878 L .49876 .67551 L p .707 .577 .707 r
F P
0 g
s
.49876 .67551 m .50362 .6582 L .50601 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.51286 .56969 m .51312 .60678 L .50053 .59905 L p .707 .577 .707 r
F P
0 g
s
.50053 .59905 m .50026 .56197 L .51286 .56969 L p .707 .577 .707 r
F P
0 g
s
.31616 .60703 m .31131 .62434 L .30405 .63399 L p .707 .577 .707 r
F P
0 g
s
.31846 .57795 m .3089 .52223 L .32519 .51399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48781 .48966 m .49737 .54537 L .47674 .54386 L p .707 .577 .707 r
F P
0 g
s
.47674 .54386 m .46718 .48815 L .48781 .48966 L p .707 .577 .707 r
F P
0 g
s
.31131 .62434 m .31616 .60703 L .33236 .60095 L p .707 .577 .707 r
F P
0 g
s
.50026 .56197 m .50053 .59905 L .47947 .5928 L p .707 .577 .707 r
F P
0 g
s
.47947 .5928 m .47921 .55572 L .50026 .56197 L p .707 .577 .707 r
F P
0 g
s
.50362 .6582 m .49876 .67551 L .48696 .66179 L p .707 .577 .707 r
F P
0 g
s
.48696 .66179 m .49182 .64448 L .50362 .6582 L p .707 .577 .707 r
F P
0 g
s
.33475 .56971 m .32519 .51399 L .34903 .50583 L p .707 .577 .707 r
F P
0 g
s
.33236 .60095 m .3275 .61826 L .31131 .62434 L p .707 .577 .707 r
F P
0 g
s
.46718 .48815 m .47674 .54386 L .44975 .54495 L p .707 .577 .707 r
F P
0 g
s
.44975 .54495 m .44019 .48923 L .46718 .48815 L p .707 .577 .707 r
F P
0 g
s
.35859 .56154 m .34903 .50583 L .37808 .49853 L p .707 .577 .707 r
F P
0 g
s
.47921 .55572 m .47947 .5928 L .45202 .58863 L p .707 .577 .707 r
F P
0 g
s
.45202 .58863 m .45175 .55155 L .47921 .55572 L p .707 .577 .707 r
F P
0 g
s
.3275 .61826 m .33236 .60095 L .3559 .59905 L p .707 .577 .707 r
F P
0 g
s
.49182 .64448 m .48696 .66179 L .4669 .64798 L p .707 .577 .707 r
F P
0 g
s
.4669 .64798 m .47176 .63067 L .49182 .64448 L p .707 .577 .707 r
F P
0 g
s
.44019 .48923 m .44975 .54495 L .41905 .54852 L p .707 .577 .707 r
F P
0 g
s
.41905 .54852 m .40949 .49281 L .44019 .48923 L p .707 .577 .707 r
F P
0 g
s
.3559 .59905 m .35105 .61636 L .3275 .61826 L p .707 .577 .707 r
F P
0 g
s
.40949 .49281 m .41905 .54852 L .38763 .55424 L p .707 .577 .707 r
F P
0 g
s
.45175 .55155 m .45202 .58863 L .42084 .58696 L p .707 .577 .707 r
F P
0 g
s
.42084 .58696 m .42058 .54987 L .45175 .55155 L p .707 .577 .707 r
F P
0 g
s
.35105 .61636 m .3559 .59905 L .38449 .6015 L p .707 .577 .707 r
F P
0 g
s
.42058 .54987 m .42084 .58696 L .38901 .58794 L p .707 .577 .707 r
F P
0 g
s
.47176 .63067 m .4669 .64798 L .44055 .63544 L p .707 .577 .707 r
F P
0 g
s
.44055 .63544 m .4454 .61813 L .47176 .63067 L p .707 .577 .707 r
F P
0 g
s
.38449 .6015 m .37964 .61881 L .35105 .61636 L p .707 .577 .707 r
F P
0 g
s
.37964 .61881 m .38449 .6015 L .41533 .60808 L p .707 .577 .707 r
F P
0 g
s
.4454 .61813 m .44055 .63544 L .41048 .62539 L p .707 .577 .707 r
F P
0 g
s
.41048 .62539 m .41533 .60808 L .4454 .61813 L p .707 .577 .707 r
F P
0 g
s
.41533 .60808 m .41048 .62539 L .37964 .61881 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Uoo`L008eo
o`00Ngoo3P0000=JEP00FUH015YF3000PGoo001eOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH8001iOol006moo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00@007Eoo`00JWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00LWoo001WOol30007FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001`Ool006Eo
o`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF008006ioo`00Hgoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Jgoo001QOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1[Ool0061o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool0
05ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00OomJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1[Ool005ioo`04001JEUYF0005FUH00`00FUIJEP0DFUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001J
EVaoo`00GWoo00@005YFFUH000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFK7oo001NOol01000FUIJEP001UYF00<0
05YFFUH04eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUI/Ool005ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1ZOol005ioo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1Z
Ool005ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00GWoo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Jgoo001NOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001[Ool005ioo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00
Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006]oo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Yoo`00Ggoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFJgoo001OOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUI[Ool005moo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Uoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Uo
o`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Yoo`00Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00
Ggoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00Ggoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YF00001@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00JWoo001POol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00eYF20000eYF00<0
05YFFUH01P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol0
1000FUIJEP001EYF00<005YFFUH00eYF2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00000P002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JWoo001POol01000
FUIJEP001EYF1P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0000YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YF
FUH0009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061oo`03
001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001ZOol0061o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JWoo001N
Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
06Yoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001ZOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Moo`8000=JEP03001JEUYF00AJEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol005Ioo`80
00AJEP8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EGoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Uoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00EWoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
30000eYF00@005YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uo
o`00EWoo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH015YF1P0000=JEP0000001eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JGoo001FOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH@0006FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001YOol005Ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo001FOol01000FUIJEP0015YF00<0
05YFFUH015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEPD0
00AJEP8000QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00<0
05YF000015YF00<005YFFUH00eYF1@001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01P0025YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00JGoo
001GOol00`00FUH00005FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001YOol005Moo`03001JEP0000EJEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000QJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00@005YFFUH000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000_Ool6000d
Ool005Moo`05001JEUYF001JEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P009Woo2@000eYF00<005YFFUH01@00;goo001HOol01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P007Goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002eo
o`00DWoo2@0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P005goo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002eoo`00B7oo2P0015YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`@00003FUH005YF00MJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00@goo1@00
1EYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH:0002FUH5
00000eYF000000060004FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo0011Ool200000eYF001JEP07FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH02@0015YF1`002UYF00@005YFFUIJEPH000AJ
EP03001JEUYF008000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000eoo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000/Ool003ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH0
0004FUH@0005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH6000015YF001JEUYF0P001UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo0P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000k
Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP0=00000eYF001JEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP040004FUH01000FUH000000UYF0P001eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002Goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000gOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001UYF00000000FUH000IJEP04001JEUYF
FUHA0006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF10001eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000dOol30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH60008FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005Ool20002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000[Ool0039oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEP000006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0017oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002]oo`00<7oo0P000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
0eYF00<005YFFUH00UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002]oo`00;goo0P0015YF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
0P000eYF4P001eYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH20008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000goo00@005YFFUH000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000ZOol002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800005FUH00000FUH00005FUH00`00FUIJEP04FUH0
1000FUIJEUYF10000UYF00<005YFFUH01eYF10000eYF00<005YFFUH015YF00@005YFFUIJEP8000QJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001oogooOol00002FUH01@00FUIJ
EUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH01UYF00@005YFFUIoo`EJEP03001JEUYF00EJEPD00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEP@000QJEP03001JEUYF0080009JEP03001JEUYF00AJEP05001JEUYFFUH00009FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00Oomoogoo00000UYF00D005YFFUIJ
EP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002Yoo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP<000AJEP03001JEUYF00AJEP03001JEUYF
009JEP<00004FUH005YFFUH30004FUH00`00FUIJEP03FUH30006FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D007ooOomoo`00009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF
FUIJEP0002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF10001EYF0`0000=JEP00FUH01EYF00@005YFFUIJEPH000EJEP<00003FUH0
05YF00IJEP8000AJEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EPP000IJEPD0009JEP03001oogoo02Qoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEPX000=JEP04001JEUYFFUH6
0008FUH20008FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000YOol002moo`03001JEP0000EJEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP<000AJEP80009JEP03
001JEP0000`000YJEP8000EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000:Goo
000_Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90002FUH0
1@00FUIJEUYF00001EYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEP`000EJEP8000=JEP03001J
EUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000:Goo000_Ool01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF1P0015YF00<005YFFUH00UYF0`000eYF0`000eYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF10001UYF00@005YFFUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`04001JEUYF0003FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000ZOol002moo`04001JEUYF0004FUH00`00FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEPD0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP04001JEUYF0006FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003Ool01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000[Ool0031oo`03001J
EP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYFFUH20004FUH0
1000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo00@005YF
FUH000AJEP04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01000FUH00000;Goo000`Ool00`00FUH00005FUH01000FUIJEUYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`05001JEUYFFUH00003FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000_Ool0
031oo`03001JEP0000EJEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH300000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH30004FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool3FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00<Woo000`Ool01000FUIJEP000eYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF008000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`=JEP8000EJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00<7oo00D005YFFUH005YF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600001EYF000005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Goo000aOol0
1000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`001eYF10002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P00
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF0000009JEP03
001JEUYF00=JEP03001JEUYF00EJEQP003Yoo`00<Goo0`0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF0000
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUH00005
0003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000fOol0035oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEP000002FUH01000
FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF1@00
<Goo000aOol00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF6P0015YF10000eYF00<005YF
FUH015YF1`002eYF00<005YFFUH02EYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000eYF00@005YFFUIJEPH000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00@002eoo`00<Goo00<005YF000015YF00@005YFFUIJEPP0
00AJEPL000ioo`H0009JEP<000IJEPD000=JEPD000IJEP03001JEUYF00MJEP@000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP8002aoo`00
<Goo00<005YF000015YF00<005YF00003@006Woo00D005YFFUH005YF008000EJEPD000MJEP03001J
EP0000h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04
001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:Woo000aOol00`00FUH00002FUH40000
0eYF00000005000HOol90002FUH01000FUIJEUYF0`000UYF1@001UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Uoo`00<Goo00<005YF0000
1`000eYF00@005YFFUIJEQP000AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH0000YOol0035oo`@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00@000QJ
EP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002Qoo`00<Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
100015YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEPT0
00AJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00:7oo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0
00040008FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01EYF
30001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
0P0000=JEP00FUH00UYF2P001UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002Qoo`00<7oo0P000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH015YF
0`001UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH200000eYF001JEP030005FUH01000FUIJEUYF2`0027oo200015YF00<005YFFUH00eYF00@005YF
FUIJEP8002Qoo`00<7oo0P0000EJEP00001JEP0000EJEP04001JEUYFFUH70007FUH00`00FUIJEP06
FUH30004FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80
00AJEPD00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@0011oo`H000AJEP04001JEUYF
FUH2000XOol0031oo`@0009JEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH40002FUH0
0`00FUIJEP07FUH00`00FUIJEP020002FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00AJEP@000moo`H00003FUH005YF009JEP8002Qoo`00;goo0`000Woo0`001EYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH00eYF0`000eYF00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF01MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP00008000Moo`D000EJEP<000=JEP8002Qoo`00;goo0`0017oo0`000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF10000UYF00<005YFFUH01EYF0P000UYF00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF009JEP04001JEUYFFUH70004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000X
Ool002moo`04001JEP000006Ool50005FUH01000FUIJEUYF1P001eYF0`0025YF10000eYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01P000UYF00<005YFFUH00UYF1`001UYF00<0
05YFFUH01UYF0`0015YF00<005YFFUH015YF00<005YFFUH00UYF0`00:7oo000_Ool20002FUH00`00
Oomoo`08Ool400000eYF001JEP02FUH60008FUH01000FUH000001EYF00<005YFFUH00P000eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF
009JEP<002Qoo`00<7oo00D005YFFUIJEP0000eooaT000=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40007FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0000XOol0031oo`04
001JEUYFFUH3000AOol3000@Ool30004FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000000`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01EYF0P001EYF00<005YFFUH00UYF0P00:Goo000aOol01000FUIJEP000UYF00<0
07ooOol08goo00<007ooFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF01IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
00<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000QJ
EP<000=JEP03001JEUYF009JEP8002Uoo`00<Goo00<005YF000015YF0P0097oo0P000UYF00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF011JEP`000IJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800004FUH005YF0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH30006FUH01000FUIJEP000UYF00@005YFFUIJEP8002Yoo`00<Woo0P001UYF
00<007ooOol08goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF
2@0035YF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF100015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF
0`0000=JEP000000;7oo000cOol00`00FUIJEP04FUH3000TOol20003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF20001UYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00UYF0P0000IJEP00000005YF0007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH2000^Ool003Aoo`8000AJEP03001JEUYF
008002Aoo`=JEP03001JEUYF00=JEP03001JEUYF00AJEPL0009JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF009JEP80009JEP06001JEUYF
FUH005YF100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P001UYF0P00;Woo000fOol01000FUIJEP001EYF0P008Woo0eYF00<005YFFUH00eYF00<005YFFUH0
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
00000P0015YF0`000UYF00@005YFFUH000=JEP8000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD000AJEP03001JEP0002ioo`00=goo0`001eYF0`007goo0eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF0`000UYF0P001eYF0P003Goo4P001Goo0P000UYF00@005YFFUH002eo
o`00>Goo00<005YFFUH01UYF00@005YF000001eoo`=JEP04001JEUYFFUH20006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH:0007FUH3000TOol20004FUH00`00Oomoo`0ZOol003Yoo`8000EJEP03001JEUYF009JEP<001Yo
o`=JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00@005YF000000AJEP04001J
EUYFFUH2000SOol00`00FUIJEP02FUH00`00Oomoo`0ZOol003aoo`8000=JEP03001JEUYF00AJEPD0
01Ioo`=JEP8000EJEP03OomJEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P008Woo00@005YFFUIJEP8002]oo`00?Woo0`001UYF1@0000=JEP00
00000P004Woo0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF009J
EP<000QJEP80025oo`05001JEP00FUH0000[Ool0041oo`8000EJEPD000EJEQ800003FUH005YF00]J
EP03Ool005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH00002
000OOol200000eYF001oo`0ZOol0049oo`<0009JEPD000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00EJEP8000IJEP03001J
EUYF009JEP<001eoo`8002aoo`00AGoo1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
000000eJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP06
FUH3000IOol3000/Ool004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006
FUH00gooFUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH025YF00<005YF00000`004goo0P0000=JEP00Ool0;7oo001;Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00002000=FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30007FUH00`00FUIJEP04FUHC0002FUH2000]Ool004mooa<0009oo`8000AJEP03
OomJEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Woo001VOol2000:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH0000@0004FUH00`00FUIJEP03FUH01000FUIJEUYF100000=J
EP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo001XOol20008FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH5
000@Ool60004FUH01000FUIJEUYF0P000Woo10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00JGoo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH010001EYF10004Goo100000=JEP00FUH00UYF0P001Woo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000031oo`00K7oo10000UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=JEP00FUH025YF00<005YF0000
0P001goo1`000eYF0`000eYF0P002Woo4`00<Woo001`Ool80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000Cgoo001hOol;0006FUH00`00FUIJEP04FUH;0002FUH00`00
FUIJEP02FUH70006FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001?
Ool008=oo`d00003OomJEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH4
0002FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0`00Cgoo
002AOol40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40007FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH00`00FUH0001?Ool0091oo`D0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00AJEP8000EJEP03001J
EUYF009JEP03001JEP0004moo`00T7oo00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF0`000eYF00<005YFFUH00UYF
0P00D7oo002@Ool00`00FUH00002FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH30007FUH01000FUIJEP000UYF00@005YFFUIJEP80055oo`00T7oo00<005YFFUH0
0UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJEP03
001JEUYF009JEP<00003FUH0000005=oo`00TGoo00<005YFOol00UYF10000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00EJEP8005Eoo`00TGoo
00<005YFFUH00UYF0`0000=oo`0000000`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0P001UYF0P00EGoo002BOol01000FUIJEP000eYF00<007ooOol00goo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@0015YF00<005YF0000EGoo002BOol01000FUIJ
EP0015YF0P001goo6@001Goo0P000UYF00@005YFFUH005Aoo`00Tgoo00<005YFFUH01UYF0P009Goo
0P0015YF00<007ooOol0DGoo002DOol00`00FUIJEP05FUH01000FUH0000097oo00<005YFFUH00UYF
00<007ooOol0DGoo002EOol20004FUH00`00FUIJEP02FUH2000SOol01@00FUIJEUYF0000Dgoo002G
Ool01@00FUIJEUYF00001UYF0`008Goo00D005YF001JEP00059oo`00V7oo0`0025YF00<005YF0000
0P007goo0P0000=JEP00Ool0DGoo002JOol20007FUH00`00FUIJEP02FUH3000MOol00`00FUH0001B
Ool009aoo`8000AJEP03001JEUYF00IJEP<001Uoo`<005=oo`00WWoo0`0000=JEP00FUH025YF00<0
05YF00000`004goo0P0000=JEP000000Dgoo002QOol30007FUH00`00FUIJEP04FUH60008Ool50002
FUH2001DOol00:Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00
E7oo002VOol300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001E
Ool00:Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:eoo`@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol00;5oo`H000AJEP04001JEUYF
FUH5001IOol00;Moo`P005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60505 .76176 m .59912 .70588 L .56813 .70737 L p .707 .577 .707 r
F P
0 g
s
.59912 .70588 m .60505 .76176 L .63672 .75793 L p .707 .577 .707 r
F P
0 g
s
.63672 .75793 m .63079 .70205 L .59912 .70588 L p .707 .577 .707 r
F P
0 g
s
.63079 .70205 m .63672 .75793 L .66597 .75213 L p .707 .577 .707 r
F P
0 g
s
.66597 .75213 m .66004 .69625 L .63079 .70205 L p .707 .577 .707 r
F P
0 g
s
.57405 .76324 m .56813 .70737 L .54085 .70636 L p .707 .577 .707 r
F P
0 g
s
.56813 .70737 m .57405 .76324 L .60505 .76176 L p .707 .577 .707 r
F P
0 g
s
.66004 .69625 m .66597 .75213 L .68994 .74492 L p .707 .577 .707 r
F P
0 g
s
.68994 .74492 m .68402 .68905 L .66004 .69625 L p .707 .577 .707 r
F P
0 g
s
.54085 .70636 m .54678 .76224 L .57405 .76324 L p .707 .577 .707 r
F P
0 g
s
.60662 .83642 m .60645 .79935 L .57528 .79759 L p .707 .577 .707 r
F P
0 g
s
.60645 .79935 m .60662 .83642 L .63845 .83552 L p .707 .577 .707 r
F P
0 g
s
.63845 .83552 m .63829 .79845 L .60645 .79935 L p .707 .577 .707 r
F P
0 g
s
.54678 .76224 m .54085 .70636 L .51996 .70296 L p .707 .577 .707 r
F P
0 g
s
.63829 .79845 m .63845 .83552 L .66783 .83204 L p .707 .577 .707 r
F P
0 g
s
.66783 .83204 m .66767 .79497 L .63829 .79845 L p .707 .577 .707 r
F P
0 g
s
.57545 .83466 m .57528 .79759 L .54783 .79333 L p .707 .577 .707 r
F P
0 g
s
.57528 .79759 m .57545 .83466 L .60662 .83642 L p .707 .577 .707 r
F P
0 g
s
.68402 .68905 m .68994 .74492 L .70628 .73702 L p .707 .577 .707 r
F P
0 g
s
.70628 .73702 m .70036 .68114 L .68402 .68905 L p .707 .577 .707 r
F P
0 g
s
.51996 .70296 m .52588 .75884 L .54678 .76224 L p .707 .577 .707 r
F P
0 g
s
.66767 .79497 m .66783 .83204 L .69189 .82633 L p .707 .577 .707 r
F P
0 g
s
.69189 .82633 m .69172 .78925 L .66767 .79497 L p .707 .577 .707 r
F P
0 g
s
.54783 .79333 m .54799 .8304 L .57545 .83466 L p .707 .577 .707 r
F P
0 g
s
.59909 .87855 m .60212 .86062 L .57137 .85361 L p .707 .577 .707 r
F P
0 g
s
.60212 .86062 m .59909 .87855 L .63055 .88238 L p .707 .577 .707 r
F P
0 g
s
.63055 .88238 m .63357 .86445 L .60212 .86062 L p .707 .577 .707 r
F P
0 g
s
.54799 .8304 m .54783 .79333 L .52677 .787 L p .707 .577 .707 r
F P
0 g
s
.63357 .86445 m .63055 .88238 L .65963 .88266 L p .707 .577 .707 r
F P
0 g
s
.65963 .88266 m .66265 .86472 L .63357 .86445 L p .707 .577 .707 r
F P
0 g
s
.56835 .87155 m .57137 .85361 L .54433 .84412 L p .707 .577 .707 r
F P
0 g
s
.57137 .85361 m .56835 .87155 L .59909 .87855 L p .707 .577 .707 r
F P
0 g
s
.52588 .75884 m .51996 .70296 L .50749 .6975 L p .707 .577 .707 r
F P
0 g
s
.54433 .84412 m .54131 .86205 L .56835 .87155 L p .707 .577 .707 r
F P
0 g
s
.52677 .787 m .52693 .82408 L .54799 .8304 L p .707 .577 .707 r
F P
0 g
s
.69172 .78925 m .69189 .82633 L .70826 .81894 L p .707 .577 .707 r
F P
0 g
s
.70826 .81894 m .70809 .78186 L .69172 .78925 L p .707 .577 .707 r
F P
0 g
s
.66265 .86472 m .65963 .88266 L .68349 .87936 L p .707 .577 .707 r
F P
0 g
s
.68349 .87936 m .68651 .86142 L .66265 .86472 L p .707 .577 .707 r
F P
0 g
s
.70036 .68114 m .70628 .73702 L .71339 .72919 L p .707 .577 .707 r
F P
0 g
s
.71339 .72919 m .70747 .67331 L .70036 .68114 L p .707 .577 .707 r
F P
0 g
s
.54131 .86205 m .54433 .84412 L .52366 .83306 L p .707 .577 .707 r
F P
0 g
s
.50749 .6975 m .51342 .75337 L .52588 .75884 L p .707 .577 .707 r
F P
0 g
s
.52366 .83306 m .52064 .85099 L .54131 .86205 L p .707 .577 .707 r
F P
0 g
s
.52693 .82408 m .52677 .787 L .51418 .77922 L p .707 .577 .707 r
F P
0 g
s
.51342 .75337 m .50749 .6975 L .50468 .69051 L p .707 .577 .707 r
F P
0 g
s
.51418 .77922 m .51434 .81629 L .52693 .82408 L p .707 .577 .707 r
F P
0 g
s
.68651 .86142 m .68349 .87936 L .69979 .8728 L p .707 .577 .707 r
F P
0 g
s
.69979 .8728 m .70281 .85486 L .68651 .86142 L p .707 .577 .707 r
F P
0 g
s
.52064 .85099 m .52366 .83306 L .51137 .82152 L p .707 .577 .707 r
F P
0 g
s
.70809 .78186 m .70826 .81894 L .71534 .81059 L p .707 .577 .707 r
F P
0 g
s
.71534 .81059 m .71518 .77352 L .70809 .78186 L p .707 .577 .707 r
F P
0 g
s
.51137 .82152 m .50835 .83945 L .52064 .85099 L p .707 .577 .707 r
F P
0 g
s
.70747 .67331 m .71339 .72919 L .71058 .7222 L p .707 .577 .707 r
F P
0 g
s
.71058 .7222 m .70465 .66633 L .70747 .67331 L p .707 .577 .707 r
F P
0 g
s
.50468 .69051 m .5106 .74639 L .51342 .75337 L p .707 .577 .707 r
F P
0 g
s
.51434 .81629 m .51418 .77922 L .51128 .77074 L p .707 .577 .707 r
F P
0 g
s
.48675 .82039 m .47568 .31745 L .43169 .31575 L p .707 .577 .707 r
F P
0 g
s
.51128 .77074 m .51144 .80781 L .51434 .81629 L p .707 .577 .707 r
F P
0 g
s
.5106 .74639 m .50468 .69051 L .51179 .68268 L p .707 .577 .707 r
F P
0 g
s
.50835 .83945 m .51137 .82152 L .50867 .81063 L p .707 .577 .707 r
F P
0 g
s
.50867 .81063 m .50565 .82856 L .50835 .83945 L p .707 .577 .707 r
F P
0 g
s
.51179 .68268 m .51772 .73856 L .5106 .74639 L p .707 .577 .707 r
F P
0 g
s
.51144 .80781 m .51128 .77074 L .51836 .7624 L p .707 .577 .707 r
F P
0 g
s
.51836 .7624 m .51853 .79947 L .51144 .80781 L p .707 .577 .707 r
F P
0 g
s
.51772 .73856 m .51179 .68268 L .52813 .67478 L p .707 .577 .707 r
F P
0 g
s
.50565 .82856 m .50867 .81063 L .51582 .80146 L p .707 .577 .707 r
F P
0 g
s
.51582 .80146 m .5128 .81939 L .50565 .82856 L p .707 .577 .707 r
F P
0 g
s
.52813 .67478 m .53406 .73066 L .51772 .73856 L p .707 .577 .707 r
F P
0 g
s
.51853 .79947 m .51836 .7624 L .53473 .75501 L p .707 .577 .707 r
F P
0 g
s
.53473 .75501 m .5349 .79208 L .51853 .79947 L p .707 .577 .707 r
F P
0 g
s
.5128 .81939 m .51582 .80146 L .53212 .7949 L p .707 .577 .707 r
F P
0 g
s
.53212 .7949 m .5291 .81283 L .5128 .81939 L p .707 .577 .707 r
F P
0 g
s
.5291 .81283 m .53212 .7949 L .55598 .79159 L p .707 .577 .707 r
F P
0 g
s
.55598 .79159 m .55296 .80953 L .5291 .81283 L p .707 .577 .707 r
F P
0 g
s
.47568 .31745 m .48675 .82039 L .53169 .81841 L p .707 .577 .707 r
F P
0 g
s
.53406 .73066 m .52813 .67478 L .5521 .66757 L p .707 .577 .707 r
F P
0 g
s
.53169 .81841 m .52062 .31546 L .47568 .31745 L p .707 .577 .707 r
F P
0 g
s
.70281 .85486 m .69979 .8728 L .70694 .86362 L p .707 .577 .707 r
F P
0 g
s
.70694 .86362 m .70996 .84569 L .70281 .85486 L p .707 .577 .707 r
F P
0 g
s
.5521 .66757 m .55803 .72345 L .53406 .73066 L p .707 .577 .707 r
F P
0 g
s
.5349 .79208 m .53473 .75501 L .55879 .7493 L p .707 .577 .707 r
F P
0 g
s
.55803 .72345 m .5521 .66757 L .58135 .66177 L p .707 .577 .707 r
F P
0 g
s
.55879 .7493 m .55895 .78637 L .5349 .79208 L p .707 .577 .707 r
F P
0 g
s
.58135 .66177 m .58728 .71765 L .55803 .72345 L p .707 .577 .707 r
F P
0 g
s
.55895 .78637 m .55879 .7493 L .58817 .74582 L p .707 .577 .707 r
F P
0 g
s
.58817 .74582 m .58833 .78289 L .55895 .78637 L p .707 .577 .707 r
F P
0 g
s
.55296 .80953 m .55598 .79159 L .58506 .79187 L p .707 .577 .707 r
F P
0 g
s
.58506 .79187 m .58204 .80981 L .55296 .80953 L p .707 .577 .707 r
F P
0 g
s
.52062 .31546 m .53169 .81841 L .57316 .81294 L p .707 .577 .707 r
F P
0 g
s
.57316 .81294 m .56209 .30999 L .52062 .31546 L p .707 .577 .707 r
F P
0 g
s
.71518 .77352 m .71534 .81059 L .71244 .80212 L p .707 .577 .707 r
F P
0 g
s
.71244 .80212 m .71228 .76504 L .71518 .77352 L p .707 .577 .707 r
F P
0 g
s
.44276 .81869 m .43169 .31575 L .39293 .31053 L p .707 .577 .707 r
F P
0 g
s
.43169 .31575 m .44276 .81869 L .48675 .82039 L p .707 .577 .707 r
F P
0 g
s
.70465 .66633 m .71058 .7222 L .69812 .71674 L p .707 .577 .707 r
F P
0 g
s
.69812 .71674 m .69219 .66087 L .70465 .66633 L p .707 .577 .707 r
F P
0 g
s
.26204 .69526 m .25611 .63938 L .22512 .64087 L p .707 .577 .707 r
F P
0 g
s
.25611 .63938 m .26204 .69526 L .29371 .69143 L p .707 .577 .707 r
F P
0 g
s
.29371 .69143 m .28778 .63555 L .25611 .63938 L p .707 .577 .707 r
F P
0 g
s
.58728 .71765 m .58135 .66177 L .61303 .65794 L p .707 .577 .707 r
F P
0 g
s
.61303 .65794 m .61895 .71382 L .58728 .71765 L p .707 .577 .707 r
F P
0 g
s
.58833 .78289 m .58817 .74582 L .62 .74491 L p .707 .577 .707 r
F P
0 g
s
.62 .74491 m .62017 .78199 L .58833 .78289 L p .707 .577 .707 r
F P
0 g
s
.58204 .80981 m .58506 .79187 L .61651 .7957 L p .707 .577 .707 r
F P
0 g
s
.61651 .7957 m .61349 .81363 L .58204 .80981 L p .707 .577 .707 r
F P
0 g
s
.56209 .30999 m .57316 .81294 L .60711 .80451 L p .707 .577 .707 r
F P
0 g
s
.60711 .80451 m .59604 .30156 L .56209 .30999 L p .707 .577 .707 r
F P
0 g
s
.28778 .63555 m .29371 .69143 L .32296 .68563 L p .707 .577 .707 r
F P
0 g
s
.32296 .68563 m .31704 .62975 L .28778 .63555 L p .707 .577 .707 r
F P
0 g
s
.23104 .69674 m .22512 .64087 L .19784 .63986 L p .707 .577 .707 r
F P
0 g
s
.22512 .64087 m .23104 .69674 L .26204 .69526 L p .707 .577 .707 r
F P
0 g
s
.70996 .84569 m .70694 .86362 L .70424 .85274 L p .707 .577 .707 r
F P
0 g
s
.70424 .85274 m .70726 .8348 L .70996 .84569 L p .707 .577 .707 r
F P
0 g
s
.404 .81348 m .39293 .31053 L .36322 .30231 L p .707 .577 .707 r
F P
0 g
s
.39293 .31053 m .404 .81348 L .44276 .81869 L p .707 .577 .707 r
F P
0 g
s
.31704 .62975 m .32296 .68563 L .34693 .67842 L p .707 .577 .707 r
F P
0 g
s
.34693 .67842 m .34101 .62254 L .31704 .62975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.26361 .74845 m .26345 .71138 L .23227 .70962 L p .707 .577 .707 r
F P
0 g
s
.26345 .71138 m .26361 .74845 L .29544 .74755 L p .707 .577 .707 r
F P
0 g
s
.29544 .74755 m .29528 .71048 L .26345 .71138 L p .707 .577 .707 r
F P
0 g
s
.29528 .71048 m .29544 .74755 L .32483 .74407 L p .707 .577 .707 r
F P
0 g
s
.32483 .74407 m .32466 .707 L .29528 .71048 L p .707 .577 .707 r
F P
0 g
s
.19784 .63986 m .20377 .69574 L .23104 .69674 L p .707 .577 .707 r
F P
0 g
s
.71228 .76504 m .71244 .80212 L .69985 .79433 L p .707 .577 .707 r
F P
0 g
s
.69985 .79433 m .69969 .75726 L .71228 .76504 L p .707 .577 .707 r
F P
0 g
s
.23244 .74669 m .23227 .70962 L .20482 .70537 L p .707 .577 .707 r
F P
0 g
s
.23227 .70962 m .23244 .74669 L .26361 .74845 L p .707 .577 .707 r
F P
0 g
s
.20377 .69574 m .19784 .63986 L .17695 .63646 L p .707 .577 .707 r
F P
0 g
s
.69219 .66087 m .69812 .71674 L .67722 .71334 L p .707 .577 .707 r
F P
0 g
s
.67722 .71334 m .6713 .65746 L .69219 .66087 L p .707 .577 .707 r
F P
0 g
s
.64402 .65646 m .64995 .71233 L .61895 .71382 L p .707 .577 .707 r
F P
0 g
s
.61895 .71382 m .61303 .65794 L .64402 .65646 L p .707 .577 .707 r
F P
0 g
s
.65118 .74668 m .65134 .78375 L .62017 .78199 L p .707 .577 .707 r
F P
0 g
s
.62017 .78199 m .62 .74491 L .65118 .74668 L p .707 .577 .707 r
F P
0 g
s
.61349 .81363 m .61651 .7957 L .64726 .8027 L p .707 .577 .707 r
F P
0 g
s
.59604 .30156 m .60711 .80451 L .63022 .79395 L p .707 .577 .707 r
F P
0 g
s
.63022 .79395 m .61915 .291 L .59604 .30156 L p .707 .577 .707 r
F P
0 g
s
.32466 .707 m .32483 .74407 L .34888 .73836 L p .707 .577 .707 r
F P
0 g
s
.34888 .73836 m .34872 .70129 L .32466 .707 L p .707 .577 .707 r
F P
0 g
s
.34101 .62254 m .34693 .67842 L .36327 .67052 L p .707 .577 .707 r
F P
0 g
s
.36327 .67052 m .35735 .61464 L .34101 .62254 L p .707 .577 .707 r
F P
0 g
s
.20482 .70537 m .20498 .74244 L .23244 .74669 L p .707 .577 .707 r
F P
0 g
s
.17695 .63646 m .18287 .69233 L .20377 .69574 L p .707 .577 .707 r
F P
0 g
s
.25609 .79869 m .25911 .78075 L .22836 .77374 L p .707 .577 .707 r
F P
0 g
s
.25911 .78075 m .25609 .79869 L .28754 .80251 L p .707 .577 .707 r
F P
0 g
s
.28754 .80251 m .29056 .78458 L .25911 .78075 L p .707 .577 .707 r
F P
0 g
s
.20498 .74244 m .20482 .70537 L .18376 .69904 L p .707 .577 .707 r
F P
0 g
s
.29056 .78458 m .28754 .80251 L .31662 .80279 L p .707 .577 .707 r
F P
0 g
s
.31662 .80279 m .31964 .78485 L .29056 .78458 L p .707 .577 .707 r
F P
0 g
s
.70726 .8348 m .70424 .85274 L .69195 .8412 L p .707 .577 .707 r
F P
0 g
s
.69195 .8412 m .69497 .82326 L .70726 .8348 L p .707 .577 .707 r
F P
0 g
s
.22534 .79168 m .22836 .77374 L .20133 .76425 L p .707 .577 .707 r
F P
0 g
s
.22836 .77374 m .22534 .79168 L .25609 .79869 L p .707 .577 .707 r
F P
0 g
s
.35735 .61464 m .36327 .67052 L .37039 .66269 L p .707 .577 .707 r
F P
0 g
s
.37039 .66269 m .36446 .60681 L .35735 .61464 L p .707 .577 .707 r
F P
0 g
s
.36508 .6939 m .36525 .73097 L .37233 .72263 L p .707 .577 .707 r
F P
0 g
s
.37233 .72263 m .37217 .68556 L .36508 .6939 L p .707 .577 .707 r
F P
0 g
s
.36446 .60681 m .37039 .66269 L .36757 .6557 L p .707 .577 .707 r
F P
0 g
s
.36757 .6557 m .36164 .59983 L .36446 .60681 L p .707 .577 .707 r
F P
0 g
s
.37217 .68556 m .37233 .72263 L .36943 .71415 L p .707 .577 .707 r
F P
0 g
s
.36943 .71415 m .36927 .67708 L .37217 .68556 L p .707 .577 .707 r
F P
0 g
s
.36164 .59983 m .36757 .6557 L .35511 .65024 L p .707 .577 .707 r
F P
0 g
s
.36525 .73097 m .36508 .6939 L .34872 .70129 L p .707 .577 .707 r
F P
0 g
s
.36927 .67708 m .36943 .71415 L .35684 .70637 L p .707 .577 .707 r
F P
0 g
s
.35684 .70637 m .35668 .66929 L .36927 .67708 L p .707 .577 .707 r
F P
0 g
s
.37429 .80525 m .36322 .30231 L .34545 .29188 L p .707 .577 .707 r
F P
0 g
s
.36322 .30231 m .37429 .80525 L .404 .81348 L p .707 .577 .707 r
F P
0 g
s
.18287 .69233 m .17695 .63646 L .16448 .631 L p .707 .577 .707 r
F P
0 g
s
.20133 .76425 m .1983 .78218 L .22534 .79168 L p .707 .577 .707 r
F P
0 g
s
.69969 .75726 m .69985 .79433 L .6788 .788 L p .707 .577 .707 r
F P
0 g
s
.6788 .788 m .67863 .75093 L .69969 .75726 L p .707 .577 .707 r
F P
0 g
s
.6713 .65746 m .67722 .71334 L .64995 .71233 L p .707 .577 .707 r
F P
0 g
s
.64995 .71233 m .64402 .65646 L .6713 .65746 L p .707 .577 .707 r
F P
0 g
s
.18376 .69904 m .18392 .73611 L .20498 .74244 L p .707 .577 .707 r
F P
0 g
s
.34872 .70129 m .34888 .73836 L .36525 .73097 L p .707 .577 .707 r
F P
0 g
s
.31964 .78485 m .31662 .80279 L .34048 .79949 L p .707 .577 .707 r
F P
0 g
s
.34048 .79949 m .3435 .78155 L .31964 .78485 L p .707 .577 .707 r
F P
0 g
s
.1983 .78218 m .20133 .76425 L .18065 .75319 L p .707 .577 .707 r
F P
0 g
s
.16448 .631 m .17041 .68687 L .18287 .69233 L p .707 .577 .707 r
F P
0 g
s
.18392 .73611 m .18376 .69904 L .17117 .69125 L p .707 .577 .707 r
F P
0 g
s
.18065 .75319 m .17763 .77112 L .1983 .78218 L p .707 .577 .707 r
F P
0 g
s
.61915 .291 m .63022 .79395 L .64022 .7823 L p .707 .577 .707 r
F P
0 g
s
.64022 .7823 m .62915 .27935 L .61915 .291 L p .707 .577 .707 r
F P
0 g
s
.69497 .82326 m .69195 .8412 L .67127 .83014 L p .707 .577 .707 r
F P
0 g
s
.67127 .83014 m .6743 .8122 L .69497 .82326 L p .707 .577 .707 r
F P
0 g
s
.67863 .75093 m .6788 .788 L .65134 .78375 L p .707 .577 .707 r
F P
0 g
s
.65134 .78375 m .65118 .74668 L .67863 .75093 L p .707 .577 .707 r
F P
0 g
s
.17117 .69125 m .17133 .72833 L .18392 .73611 L p .707 .577 .707 r
F P
0 g
s
.3435 .78155 m .34048 .79949 L .35678 .79293 L p .707 .577 .707 r
F P
0 g
s
.35678 .79293 m .3598 .77499 L .3435 .78155 L p .707 .577 .707 r
F P
0 g
s
.17041 .68687 m .16448 .631 L .16167 .62401 L p .707 .577 .707 r
F P
0 g
s
.17763 .77112 m .18065 .75319 L .16836 .74165 L p .707 .577 .707 r
F P
0 g
s
.16836 .74165 m .16534 .75958 L .17763 .77112 L p .707 .577 .707 r
F P
0 g
s
.35511 .65024 m .35495 .64871 L p .36164 .59983 L .707 .577 .707 r
F P
0 g
s
.35495 .64871 m .34918 .59436 L .35477 .59681 L p .707 .577 .707 r
F P
0 g
s
.35477 .59681 m .36164 .59983 L p .35495 .64871 L .707 .577 .707 r
F P
0 g
s
.34918 .59436 m .35511 .65024 L .33421 .64684 L p .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35196 .74339 L .35826 .74931 L p .707 .577 .707 r
F P
0 g
s
.35826 .74931 m .36425 .75493 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.34894 .76133 m .35826 .74931 L .35871 .75725 L .707 .577 .707 r
F
.34545 .29188 m .34136 .28027 L p .35175 .63288 L F P
0 g
s
.35668 .66929 m .35684 .70637 L .33579 .70004 L p .707 .577 .707 r
F P
0 g
s
.33579 .70004 m .33562 .66296 L .35668 .66929 L p .707 .577 .707 r
F P
0 g
s
.3553 .75364 m .35333 .66115 L .35175 .63288 L .707 .577 .707 r
F
.35333 .66115 m .34545 .29188 L .35175 .63288 L F
.36425 .75493 m .36123 .77287 L .35949 .77124 L p F P
0 g
s
.35949 .77124 m .34894 .76133 L p .35871 .75725 L .707 .577 .707 r
F P
0 g
s
.35871 .75725 m .36425 .75493 L .35949 .77124 L .707 .577 .707 r
F
.35243 .78322 m .35652 .79483 L p .35175 .63288 L F P
0 g
s
.34136 .28027 m .34742 .5556 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.33421 .64684 m .32829 .59096 L .34918 .59436 L p .707 .577 .707 r
F P
0 g
s
.35196 .74339 m .34894 .76133 L .32826 .75027 L p .707 .577 .707 r
F P
0 g
s
.32826 .75027 m .33129 .73233 L .35196 .74339 L p .707 .577 .707 r
F P
0 g
s
.34742 .5556 m .35243 .78322 L p .35175 .63288 L .707 .577 .707 r
F P
0 g
s
.35652 .79483 m .35525 .73716 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.35525 .73716 m .34545 .29188 L p .3553 .75364 L .707 .577 .707 r
F P
0 g
s
.3598 .77499 m .35678 .79293 L .36393 .78375 L p .707 .577 .707 r
F P
0 g
s
.36393 .78375 m .36695 .76582 L .3598 .77499 L p .707 .577 .707 r
F P
0 g
s
.36695 .76582 m .36393 .78375 L .36123 .77287 L p .707 .577 .707 r
F P
0 g
s
.36123 .77287 m .36425 .75493 L .36695 .76582 L p .707 .577 .707 r
F P
0 g
s
.34545 .29188 m .35652 .79483 L .37429 .80525 L p .707 .577 .707 r
F P
0 g
s
.16167 .62401 m .1676 .67989 L .17041 .68687 L p .707 .577 .707 r
F P
0 g
s
.17133 .72833 m .17117 .69125 L .16827 .68278 L p .707 .577 .707 r
F P
0 g
s
.6743 .8122 m .67127 .83014 L .64424 .82064 L p .707 .577 .707 r
F P
0 g
s
.64424 .82064 m .64726 .8027 L .6743 .8122 L p .707 .577 .707 r
F P
0 g
s
.16827 .68278 m .16843 .71985 L .17133 .72833 L p .707 .577 .707 r
F P
0 g
s
.64726 .8027 m .64424 .82064 L .61349 .81363 L p .707 .577 .707 r
F P
0 g
s
.16534 .75958 m .16836 .74165 L .16566 .73076 L p .707 .577 .707 r
F P
0 g
s
.1676 .67989 m .16167 .62401 L .16878 .61618 L p .707 .577 .707 r
F P
0 g
s
.62915 .27935 m .64022 .7823 L .63614 .77069 L p .707 .577 .707 r
F P
0 g
s
.63614 .77069 m .62507 .26774 L .62915 .27935 L p .707 .577 .707 r
F P
0 g
s
.16566 .73076 m .16264 .7487 L .16534 .75958 L p .707 .577 .707 r
F P
0 g
s
.16878 .61618 m .17471 .67206 L .1676 .67989 L p .707 .577 .707 r
F P
0 g
s
.16843 .71985 m .16827 .68278 L .17535 .67443 L p .707 .577 .707 r
F P
0 g
s
.35243 .78322 m .34136 .28027 L .35137 .26862 L p .707 .577 .707 r
F P
0 g
s
.17535 .67443 m .17552 .7115 L .16843 .71985 L p .707 .577 .707 r
F P
0 g
s
.16264 .7487 m .16566 .73076 L .17281 .72159 L p .707 .577 .707 r
F P
0 g
s
.17471 .67206 m .16878 .61618 L .18512 .60828 L p .707 .577 .707 r
F P
0 g
s
.17281 .72159 m .16979 .73952 L .16264 .7487 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18512 .60828 m .19105 .66415 L .17471 .67206 L p .707 .577 .707 r
F P
0 g
s
.17552 .7115 m .17535 .67443 L .19172 .66704 L p .707 .577 .707 r
F P
0 g
s
.62507 .26774 m .63614 .77069 L .61837 .76026 L p .707 .577 .707 r
F P
0 g
s
.61837 .76026 m .6073 .25732 L .62507 .26774 L p .707 .577 .707 r
F P
0 g
s
.19172 .66704 m .19189 .70411 L .17552 .7115 L p .707 .577 .707 r
F P
0 g
s
.19105 .66415 m .18512 .60828 L .20909 .60107 L p .707 .577 .707 r
F P
0 g
s
.16979 .73952 m .17281 .72159 L .18911 .71503 L p .707 .577 .707 r
F P
0 g
s
.36243 .77157 m .35137 .26862 L .37447 .25806 L p .707 .577 .707 r
F P
0 g
s
.35137 .26862 m .36243 .77157 L .35243 .78322 L p .707 .577 .707 r
F P
0 g
s
.18911 .71503 m .18609 .73296 L .16979 .73952 L p .707 .577 .707 r
F P
0 g
s
.32829 .59096 m .33421 .64684 L .30694 .64583 L p .707 .577 .707 r
F P
0 g
s
.30694 .64583 m .30101 .58996 L .32829 .59096 L p .707 .577 .707 r
F P
0 g
s
.20909 .60107 m .21502 .65695 L .19105 .66415 L p .707 .577 .707 r
F P
0 g
s
.19189 .70411 m .19172 .66704 L .21578 .66133 L p .707 .577 .707 r
F P
0 g
s
.21502 .65695 m .20909 .60107 L .23834 .59527 L p .707 .577 .707 r
F P
0 g
s
.21578 .66133 m .21594 .6984 L .19189 .70411 L p .707 .577 .707 r
F P
0 g
s
.30101 .58996 m .30694 .64583 L .27594 .64732 L p .707 .577 .707 r
F P
0 g
s
.27594 .64732 m .27002 .59144 L .30101 .58996 L p .707 .577 .707 r
F P
0 g
s
.33562 .66296 m .33579 .70004 L .30833 .69578 L p .707 .577 .707 r
F P
0 g
s
.30833 .69578 m .30817 .65871 L .33562 .66296 L p .707 .577 .707 r
F P
0 g
s
.18609 .73296 m .18911 .71503 L .21297 .71173 L p .707 .577 .707 r
F P
0 g
s
.6073 .25732 m .61837 .76026 L .58865 .75204 L p .707 .577 .707 r
F P
0 g
s
.58865 .75204 m .57758 .24909 L .6073 .25732 L p .707 .577 .707 r
F P
0 g
s
.24427 .65115 m .23834 .59527 L .27002 .59144 L p .707 .577 .707 r
F P
0 g
s
.23834 .59527 m .24427 .65115 L .21502 .65695 L p .707 .577 .707 r
F P
0 g
s
.27002 .59144 m .27594 .64732 L .24427 .65115 L p .707 .577 .707 r
F P
0 g
s
.21594 .6984 m .21578 .66133 L .24516 .65785 L p .707 .577 .707 r
F P
0 g
s
.21297 .71173 m .20995 .72966 L .18609 .73296 L p .707 .577 .707 r
F P
0 g
s
.74225 .66972 m .73632 .61384 L .70533 .61533 L p .707 .577 .707 r
F P
0 g
s
.73632 .61384 m .74225 .66972 L .77392 .66589 L p .707 .577 .707 r
F P
0 g
s
.77392 .66589 m .768 .61001 L .73632 .61384 L p .707 .577 .707 r
F P
0 g
s
.30817 .65871 m .30833 .69578 L .27716 .69402 L p .707 .577 .707 r
F P
0 g
s
.27716 .69402 m .27699 .65695 L .30817 .65871 L p .707 .577 .707 r
F P
0 g
s
.768 .61001 m .77392 .66589 L .80318 .66009 L p .707 .577 .707 r
F P
0 g
s
.80318 .66009 m .79725 .60421 L .768 .61001 L p .707 .577 .707 r
F P
0 g
s
.24516 .65785 m .24532 .69492 L .21594 .6984 L p .707 .577 .707 r
F P
0 g
s
.37447 .25806 m .38554 .76101 L .36243 .77157 L p .707 .577 .707 r
F P
0 g
s
.38554 .76101 m .37447 .25806 L .40843 .24964 L p .707 .577 .707 r
F P
0 g
s
.24532 .69492 m .24516 .65785 L .27699 .65695 L p .707 .577 .707 r
F P
0 g
s
.33129 .73233 m .32826 .75027 L .30123 .74077 L p .707 .577 .707 r
F P
0 g
s
.30123 .74077 m .30425 .72283 L .33129 .73233 L p .707 .577 .707 r
F P
0 g
s
.27699 .65695 m .27716 .69402 L .24532 .69492 L p .707 .577 .707 r
F P
0 g
s
.20995 .72966 m .21297 .71173 L .24205 .712 L p .707 .577 .707 r
F P
0 g
s
.71126 .67121 m .70533 .61533 L .67805 .61432 L p .707 .577 .707 r
F P
0 g
s
.70533 .61533 m .71126 .67121 L .74225 .66972 L p .707 .577 .707 r
F P
0 g
s
.79725 .60421 m .80318 .66009 L .82715 .65288 L p .707 .577 .707 r
F P
0 g
s
.82715 .65288 m .82122 .59701 L .79725 .60421 L p .707 .577 .707 r
F P
0 g
s
.24205 .712 m .23903 .72994 L .20995 .72966 L p .707 .577 .707 r
F P
0 g
s
.30425 .72283 m .30123 .74077 L .27048 .73376 L p .707 .577 .707 r
F P
0 g
s
.27048 .73376 m .2735 .71583 L .30425 .72283 L p .707 .577 .707 r
F P
0 g
s
.57758 .24909 m .58865 .75204 L .5499 .74682 L p .707 .577 .707 r
F P
0 g
s
.5499 .74682 m .53883 .24388 L .57758 .24909 L p .707 .577 .707 r
F P
0 g
s
.23903 .72994 m .24205 .712 L .2735 .71583 L p .707 .577 .707 r
F P
0 g
s
.67805 .61432 m .68398 .6702 L .71126 .67121 L p .707 .577 .707 r
F P
0 g
s
.74382 .74438 m .74366 .70731 L .71249 .70555 L p .707 .577 .707 r
F P
0 g
s
.74366 .70731 m .74382 .74438 L .77566 .74348 L p .707 .577 .707 r
F P
0 g
s
.77566 .74348 m .77549 .70641 L .74366 .70731 L p .707 .577 .707 r
F P
0 g
s
.68398 .6702 m .67805 .61432 L .65716 .61092 L p .707 .577 .707 r
F P
0 g
s
.2735 .71583 m .27048 .73376 L .23903 .72994 L p .707 .577 .707 r
F P
0 g
s
.77549 .70641 m .77566 .74348 L .80504 .74 L p .707 .577 .707 r
F P
0 g
s
.80504 .74 m .80488 .70293 L .77549 .70641 L p .707 .577 .707 r
F P
0 g
s
.71265 .74262 m .71249 .70555 L .68503 .70129 L p .707 .577 .707 r
F P
0 g
s
.71249 .70555 m .71265 .74262 L .74382 .74438 L p .707 .577 .707 r
F P
0 g
s
.41949 .75258 m .40843 .24964 L .4499 .24416 L p .707 .577 .707 r
F P
0 g
s
.40843 .24964 m .41949 .75258 L .38554 .76101 L p .707 .577 .707 r
F P
0 g
s
.82122 .59701 m .82715 .65288 L .84349 .64498 L p .707 .577 .707 r
F P
0 g
s
.84349 .64498 m .83756 .5891 L .82122 .59701 L p .707 .577 .707 r
F P
0 g
s
.65716 .61092 m .66309 .6668 L .68398 .6702 L p .707 .577 .707 r
F P
0 g
s
.80488 .70293 m .80504 .74 L .82909 .73429 L p .707 .577 .707 r
F P
0 g
s
.82909 .73429 m .82893 .69722 L .80488 .70293 L p .707 .577 .707 r
F P
0 g
s
.68503 .70129 m .68519 .73837 L .71265 .74262 L p .707 .577 .707 r
F P
0 g
s
.7363 .78652 m .73932 .76858 L .70857 .76158 L p .707 .577 .707 r
F P
0 g
s
.73932 .76858 m .7363 .78652 L .76775 .79035 L p .707 .577 .707 r
F P
0 g
s
.76775 .79035 m .77078 .77241 L .73932 .76858 L p .707 .577 .707 r
F P
0 g
s
.53883 .24388 m .5499 .74682 L .5059 .74512 L p .707 .577 .707 r
F P
0 g
s
.5059 .74512 m .49483 .24218 L .53883 .24388 L p .707 .577 .707 r
F P
0 g
s
.68519 .73837 m .68503 .70129 L .66397 .69497 L p .707 .577 .707 r
F P
0 g
s
.77078 .77241 m .76775 .79035 L .79683 .79062 L p .707 .577 .707 r
F P
0 g
s
.79683 .79062 m .79986 .77269 L .77078 .77241 L p .707 .577 .707 r
F P
0 g
s
.70555 .77951 m .70857 .76158 L .68154 .75208 L p .707 .577 .707 r
F P
0 g
s
.70857 .76158 m .70555 .77951 L .7363 .78652 L p .707 .577 .707 r
F P
0 g
s
.66309 .6668 m .65716 .61092 L .6447 .60546 L p .707 .577 .707 r
F P
0 g
s
.4499 .24416 m .46097 .74711 L .41949 .75258 L p .707 .577 .707 r
F P
0 g
s
.42499 .54351 m .43091 .59939 L .43863 .59786 L p .707 .577 .707 r
F P
0 g
s
.45967 .68809 m .4499 .24416 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.43863 .59786 m .46017 .59359 L p .42644 .54558 L .707 .577 .707 r
F P
0 g
s
.42644 .54558 m .42499 .54351 L .43863 .59786 L .707 .577 .707 r
F
.4499 .24416 m .49483 .24218 L p .46375 .7056 L F P
0 g
s
.46097 .74711 m .45967 .68809 L p .46375 .7056 L .707 .577 .707 r
F P
0 g
s
.49483 .24218 m .5059 .74512 L .46097 .74711 L p .707 .577 .707 r
F P
0 g
s
.68154 .75208 m .67851 .77001 L .70555 .77951 L p .707 .577 .707 r
F P
0 g
s
.66397 .69497 m .66414 .73204 L .68519 .73837 L p .707 .577 .707 r
F P
0 g
s
.82893 .69722 m .82909 .73429 L .84546 .7269 L p .707 .577 .707 r
F P
0 g
s
.84546 .7269 m .8453 .68983 L .82893 .69722 L p .707 .577 .707 r
F P
0 g
s
.79986 .77269 m .79683 .79062 L .82069 .78732 L p .707 .577 .707 r
F P
0 g
s
.82069 .78732 m .82371 .76938 L .79986 .77269 L p .707 .577 .707 r
F P
0 g
s
.83756 .5891 m .84349 .64498 L .8506 .63715 L p .707 .577 .707 r
F P
0 g
s
.8506 .63715 m .84467 .58127 L .83756 .5891 L p .707 .577 .707 r
F P
0 g
s
.67851 .77001 m .68154 .75208 L .66087 .74102 L p .707 .577 .707 r
F P
0 g
s
.6447 .60546 m .65062 .66134 L .66309 .6668 L p .707 .577 .707 r
F P
0 g
s
.66087 .74102 m .65784 .75895 L .67851 .77001 L p .707 .577 .707 r
F P
0 g
s
.66414 .73204 m .66397 .69497 L .65138 .68718 L p .707 .577 .707 r
F P
0 g
s
.65062 .66134 m .6447 .60546 L .64188 .59847 L p .707 .577 .707 r
F P
0 g
s
.65138 .68718 m .65154 .72425 L .66414 .73204 L p .707 .577 .707 r
F P
0 g
s
.82371 .76938 m .82069 .78732 L .83699 .78076 L p .707 .577 .707 r
F P
0 g
s
.83699 .78076 m .84002 .76282 L .82371 .76938 L p .707 .577 .707 r
F P
0 g
s
.65784 .75895 m .66087 .74102 L .64858 .72948 L p .707 .577 .707 r
F P
0 g
s
.8453 .68983 m .84546 .7269 L .85254 .71856 L p .707 .577 .707 r
F P
0 g
s
.85254 .71856 m .85238 .68148 L .8453 .68983 L p .707 .577 .707 r
F P
0 g
s
.64858 .72948 m .64555 .74742 L .65784 .75895 L p .707 .577 .707 r
F P
0 g
s
.84467 .58127 m .8506 .63715 L .84779 .63017 L p .707 .577 .707 r
F P
0 g
s
.84779 .63017 m .84186 .57429 L .84467 .58127 L p .707 .577 .707 r
F P
0 g
s
.64188 .59847 m .64781 .65435 L .65062 .66134 L p .707 .577 .707 r
F P
0 g
s
.65154 .72425 m .65138 .68718 L .64849 .6787 L p .707 .577 .707 r
F P
0 g
s
.84002 .76282 m .83699 .78076 L .84414 .77159 L p .707 .577 .707 r
F P
0 g
s
.84414 .77159 m .84717 .75365 L .84002 .76282 L p .707 .577 .707 r
F P
0 g
s
.64849 .6787 m .64865 .71577 L .65154 .72425 L p .707 .577 .707 r
F P
0 g
s
.64781 .65435 m .64188 .59847 L .64899 .59064 L p .707 .577 .707 r
F P
0 g
s
.64555 .74742 m .64858 .72948 L .64587 .71859 L p .707 .577 .707 r
F P
0 g
s
.85238 .68148 m .85254 .71856 L .84965 .71008 L p .707 .577 .707 r
F P
0 g
s
.84965 .71008 m .84949 .67301 L .85238 .68148 L p .707 .577 .707 r
F P
0 g
s
.64587 .71859 m .64285 .73653 L .64555 .74742 L p .707 .577 .707 r
F P
0 g
s
.84186 .57429 m .84779 .63017 L .83532 .6247 L p .707 .577 .707 r
F P
0 g
s
.83532 .6247 m .8294 .56883 L .84186 .57429 L p .707 .577 .707 r
F P
0 g
s
.64899 .59064 m .65492 .64652 L .64781 .65435 L p .707 .577 .707 r
F P
0 g
s
.39924 .60322 m .39331 .54734 L .36232 .54883 L p .707 .577 .707 r
F P
0 g
s
.39331 .54734 m .39924 .60322 L .43091 .59939 L p .707 .577 .707 r
F P
0 g
s
.43091 .59939 m .42499 .54351 L .39331 .54734 L p .707 .577 .707 r
F P
0 g
s
.46017 .59359 m .45424 .53771 L .42499 .54351 L p .707 .577 .707 r
F P
0 g
s
.64865 .71577 m .64849 .6787 L .65557 .67036 L p .707 .577 .707 r
F P
0 g
s
.36825 .6047 m .36232 .54883 L .33504 .54782 L p .707 .577 .707 r
F P
0 g
s
.36232 .54883 m .36825 .6047 L .39924 .60322 L p .707 .577 .707 r
F P
0 g
s
.84717 .75365 m .84414 .77159 L .84144 .7607 L p .707 .577 .707 r
F P
0 g
s
.84144 .7607 m .84446 .74276 L .84717 .75365 L p .707 .577 .707 r
F P
0 g
s
.45424 .53771 m .46017 .59359 L .48414 .58638 L p .707 .577 .707 r
F P
0 g
s
.48414 .58638 m .47821 .53051 L .45424 .53771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65557 .67036 m .65573 .70743 L .64865 .71577 L p .707 .577 .707 r
F P
0 g
s
.65492 .64652 m .64899 .59064 L .66533 .58274 L p .707 .577 .707 r
F P
0 g
s
.64285 .73653 m .64587 .71859 L .65302 .70942 L p .707 .577 .707 r
F P
0 g
s
.40081 .65642 m .40065 .61934 L .36948 .61758 L p .707 .577 .707 r
F P
0 g
s
.40065 .61934 m .40081 .65642 L .43265 .65551 L p .707 .577 .707 r
F P
0 g
s
.43265 .65551 m .43248 .61844 L .40065 .61934 L p .707 .577 .707 r
F P
0 g
s
.43248 .61844 m .43265 .65551 L .46203 .65204 L p .707 .577 .707 r
F P
0 g
s
.46203 .65204 m .46187 .61496 L .43248 .61844 L p .707 .577 .707 r
F P
0 g
s
.33504 .54782 m .34097 .6037 L .36825 .6047 L p .707 .577 .707 r
F P
0 g
s
.84949 .67301 m .84965 .71008 L .83706 .70229 L p .707 .577 .707 r
F P
0 g
s
.83706 .70229 m .83689 .66522 L .84949 .67301 L p .707 .577 .707 r
F P
0 g
s
.65302 .70942 m .65 .72735 L .64285 .73653 L p .707 .577 .707 r
F P
0 g
s
.36964 .65465 m .36948 .61758 L .34202 .61333 L p .707 .577 .707 r
F P
0 g
s
.36948 .61758 m .36964 .65465 L .40081 .65642 L p .707 .577 .707 r
F P
0 g
s
.34097 .6037 m .33504 .54782 L .31415 .54442 L p .707 .577 .707 r
F P
0 g
s
.8294 .56883 m .83532 .6247 L .81443 .6213 L p .707 .577 .707 r
F P
0 g
s
.81443 .6213 m .8085 .56543 L .8294 .56883 L p .707 .577 .707 r
F P
0 g
s
.66533 .58274 m .67126 .63862 L .65492 .64652 L p .707 .577 .707 r
F P
0 g
s
.46187 .61496 m .46203 .65204 L .48608 .64632 L p .707 .577 .707 r
F P
0 g
s
.48608 .64632 m .48592 .60925 L .46187 .61496 L p .707 .577 .707 r
F P
0 g
s
.47821 .53051 m .48414 .58638 L .50048 .57848 L p .707 .577 .707 r
F P
0 g
s
.50048 .57848 m .49455 .5226 L .47821 .53051 L p .707 .577 .707 r
F P
0 g
s
.65573 .70743 m .65557 .67036 L .67194 .66297 L p .707 .577 .707 r
F P
0 g
s
.34202 .61333 m .34218 .6504 L .36964 .65465 L p .707 .577 .707 r
F P
0 g
s
.31415 .54442 m .32008 .6003 L .34097 .6037 L p .707 .577 .707 r
F P
0 g
s
.39329 .70665 m .39631 .68871 L .36556 .68171 L p .707 .577 .707 r
F P
0 g
s
.39631 .68871 m .39329 .70665 L .42474 .71048 L p .707 .577 .707 r
F P
0 g
s
.42474 .71048 m .42777 .69254 L .39631 .68871 L p .707 .577 .707 r
F P
0 g
s
.34218 .6504 m .34202 .61333 L .32096 .607 L p .707 .577 .707 r
F P
0 g
s
.67126 .63862 m .66533 .58274 L .6893 .57553 L p .707 .577 .707 r
F P
0 g
s
.42777 .69254 m .42474 .71048 L .45382 .71075 L p .707 .577 .707 r
F P
0 g
s
.45382 .71075 m .45685 .69282 L .42777 .69254 L p .707 .577 .707 r
F P
0 g
s
.84446 .74276 m .84144 .7607 L .82915 .74916 L p .707 .577 .707 r
F P
0 g
s
.82915 .74916 m .83218 .73122 L .84446 .74276 L p .707 .577 .707 r
F P
0 g
s
.36254 .69964 m .36556 .68171 L .33853 .67221 L p .707 .577 .707 r
F P
0 g
s
.36556 .68171 m .36254 .69964 L .39329 .70665 L p .707 .577 .707 r
F P
0 g
s
.67194 .66297 m .6721 .70004 L .65573 .70743 L p .707 .577 .707 r
F P
0 g
s
.65 .72735 m .65302 .70942 L .66933 .70286 L p .707 .577 .707 r
F P
0 g
s
.32008 .6003 m .31415 .54442 L .30169 .53896 L p .707 .577 .707 r
F P
0 g
s
.33853 .67221 m .3355 .69014 L .36254 .69964 L p .707 .577 .707 r
F P
0 g
s
.83689 .66522 m .83706 .70229 L .816 .69596 L p .707 .577 .707 r
F P
0 g
s
.816 .69596 m .81584 .65889 L .83689 .66522 L p .707 .577 .707 r
F P
0 g
s
.8085 .56543 m .81443 .6213 L .78715 .6203 L p .707 .577 .707 r
F P
0 g
s
.78715 .6203 m .78122 .56442 L .8085 .56543 L p .707 .577 .707 r
F P
0 g
s
.32096 .607 m .32113 .64407 L .34218 .6504 L p .707 .577 .707 r
F P
0 g
s
.48592 .60925 m .48608 .64632 L .50245 .63893 L p .707 .577 .707 r
F P
0 g
s
.50245 .63893 m .50229 .60186 L .48592 .60925 L p .707 .577 .707 r
F P
0 g
s
.66933 .70286 m .6663 .72079 L .65 .72735 L p .707 .577 .707 r
F P
0 g
s
.6893 .57553 m .69523 .63141 L .67126 .63862 L p .707 .577 .707 r
F P
0 g
s
.45685 .69282 m .45382 .71075 L .47768 .70745 L p .707 .577 .707 r
F P
0 g
s
.47768 .70745 m .4807 .68951 L .45685 .69282 L p .707 .577 .707 r
F P
0 g
s
.3355 .69014 m .33853 .67221 L .31785 .66115 L p .707 .577 .707 r
F P
0 g
s
.49455 .5226 m .50048 .57848 L .50759 .57065 L p .707 .577 .707 r
F P
0 g
s
.50759 .57065 m .50166 .51477 L .49455 .5226 L p .707 .577 .707 r
F P
0 g
s
.6721 .70004 m .67194 .66297 L .69599 .65726 L p .707 .577 .707 r
F P
0 g
s
.69523 .63141 m .6893 .57553 L .71856 .56973 L p .707 .577 .707 r
F P
0 g
s
.30169 .53896 m .30761 .59483 L .32008 .6003 L p .707 .577 .707 r
F P
0 g
s
.32113 .64407 m .32096 .607 L .30837 .59921 L p .707 .577 .707 r
F P
0 g
s
.31785 .66115 m .31483 .67908 L .3355 .69014 L p .707 .577 .707 r
F P
0 g
s
.78122 .56442 m .78715 .6203 L .75616 .62178 L p .707 .577 .707 r
F P
0 g
s
.75616 .62178 m .75023 .5659 L .78122 .56442 L p .707 .577 .707 r
F P
0 g
s
.83218 .73122 m .82915 .74916 L .80848 .7381 L p .707 .577 .707 r
F P
0 g
s
.80848 .7381 m .8115 .72016 L .83218 .73122 L p .707 .577 .707 r
F P
0 g
s
.69599 .65726 m .69615 .69433 L .6721 .70004 L p .707 .577 .707 r
F P
0 g
s
.72449 .62561 m .71856 .56973 L .75023 .5659 L p .707 .577 .707 r
F P
0 g
s
.71856 .56973 m .72449 .62561 L .69523 .63141 L p .707 .577 .707 r
F P
0 g
s
.6663 .72079 m .66933 .70286 L .69318 .69956 L p .707 .577 .707 r
F P
0 g
s
.81584 .65889 m .816 .69596 L .78854 .69171 L p .707 .577 .707 r
F P
0 g
s
.78854 .69171 m .78838 .65464 L .81584 .65889 L p .707 .577 .707 r
F P
0 g
s
.30837 .59921 m .30853 .63629 L .32113 .64407 L p .707 .577 .707 r
F P
0 g
s
.75023 .5659 m .75616 .62178 L .72449 .62561 L p .707 .577 .707 r
F P
0 g
s
.4807 .68951 m .47768 .70745 L .49398 .70089 L p .707 .577 .707 r
F P
0 g
s
.49398 .70089 m .49701 .68295 L .4807 .68951 L p .707 .577 .707 r
F P
0 g
s
.30761 .59483 m .30169 .53896 L .29887 .53197 L p .707 .577 .707 r
F P
0 g
s
.50229 .60186 m .50245 .63893 L .50953 .63059 L p .707 .577 .707 r
F P
0 g
s
.50953 .63059 m .50937 .59352 L .50229 .60186 L p .707 .577 .707 r
F P
0 g
s
.69318 .69956 m .69016 .71749 L .6663 .72079 L p .707 .577 .707 r
F P
0 g
s
.31483 .67908 m .31785 .66115 L .30557 .64961 L p .707 .577 .707 r
F P
0 g
s
.69615 .69433 m .69599 .65726 L .72537 .65378 L p .707 .577 .707 r
F P
0 g
s
.30557 .64961 m .30254 .66755 L .31483 .67908 L p .707 .577 .707 r
F P
0 g
s
.78838 .65464 m .78854 .69171 L .75737 .68995 L p .707 .577 .707 r
F P
0 g
s
.75737 .68995 m .75721 .65288 L .78838 .65464 L p .707 .577 .707 r
F P
0 g
s
.50166 .51477 m .50759 .57065 L .50478 .56366 L p .707 .577 .707 r
F P
0 g
s
.50478 .56366 m .49885 .50779 L .50166 .51477 L p .707 .577 .707 r
F P
0 g
s
.29887 .53197 m .3048 .58785 L .30761 .59483 L p .707 .577 .707 r
F P
0 g
s
.72537 .65378 m .72554 .69085 L .69615 .69433 L p .707 .577 .707 r
F P
0 g
s
.30853 .63629 m .30837 .59921 L .30547 .59074 L p .707 .577 .707 r
F P
0 g
s
.8115 .72016 m .80848 .7381 L .78144 .7286 L p .707 .577 .707 r
F P
0 g
s
.78144 .7286 m .78447 .71067 L .8115 .72016 L p .707 .577 .707 r
F P
0 g
s
.72554 .69085 m .72537 .65378 L .75721 .65288 L p .707 .577 .707 r
F P
0 g
s
.69016 .71749 m .69318 .69956 L .72226 .69983 L p .707 .577 .707 r
F P
0 g
s
.75721 .65288 m .75737 .68995 L .72554 .69085 L p .707 .577 .707 r
F P
0 g
s
.72226 .69983 m .71924 .71777 L .69016 .71749 L p .707 .577 .707 r
F P
0 g
s
.30547 .59074 m .30564 .62781 L .30853 .63629 L p .707 .577 .707 r
F P
0 g
s
.49701 .68295 m .49398 .70089 L .50113 .69172 L p .707 .577 .707 r
F P
0 g
s
.50113 .69172 m .50416 .67378 L .49701 .68295 L p .707 .577 .707 r
F P
0 g
s
.78447 .71067 m .78144 .7286 L .75069 .7216 L p .707 .577 .707 r
F P
0 g
s
.75069 .7216 m .75372 .70366 L .78447 .71067 L p .707 .577 .707 r
F P
0 g
s
.30254 .66755 m .30557 .64961 L .30286 .63872 L p .707 .577 .707 r
F P
0 g
s
.71924 .71777 m .72226 .69983 L .75372 .70366 L p .707 .577 .707 r
F P
0 g
s
.3048 .58785 m .29887 .53197 L .30598 .52414 L p .707 .577 .707 r
F P
0 g
s
.50937 .59352 m .50953 .63059 L .50664 .62211 L p .707 .577 .707 r
F P
0 g
s
.50664 .62211 m .50648 .58504 L .50937 .59352 L p .707 .577 .707 r
F P
0 g
s
.75372 .70366 m .75069 .7216 L .71924 .71777 L p .707 .577 .707 r
F P
0 g
s
.30286 .63872 m .29984 .65666 L .30254 .66755 L p .707 .577 .707 r
F P
0 g
s
.49885 .50779 m .50478 .56366 L .49231 .5582 L p .707 .577 .707 r
F P
0 g
s
.49231 .5582 m .48638 .50233 L .49885 .50779 L p .707 .577 .707 r
F P
0 g
s
.30598 .52414 m .31191 .58002 L .3048 .58785 L p .707 .577 .707 r
F P
0 g
s
.30564 .62781 m .30547 .59074 L .31256 .58239 L p .707 .577 .707 r
F P
0 g
s
.31256 .58239 m .31272 .61947 L .30564 .62781 L p .707 .577 .707 r
F P
0 g
s
.50416 .67378 m .50113 .69172 L .49843 .68083 L p .707 .577 .707 r
F P
0 g
s
.49843 .68083 m .50145 .66289 L .50416 .67378 L p .707 .577 .707 r
F P
0 g
s
.29984 .65666 m .30286 .63872 L .31001 .62955 L p .707 .577 .707 r
F P
0 g
s
.31191 .58002 m .30598 .52414 L .32232 .51624 L p .707 .577 .707 r
F P
0 g
s
.50648 .58504 m .50664 .62211 L .49405 .61433 L p .707 .577 .707 r
F P
0 g
s
.49405 .61433 m .49388 .57725 L .50648 .58504 L p .707 .577 .707 r
F P
0 g
s
.31001 .62955 m .30699 .64748 L .29984 .65666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48638 .50233 m .49231 .5582 L .47142 .5548 L p .707 .577 .707 r
F P
0 g
s
.47142 .5548 m .46549 .49892 L .48638 .50233 L p .707 .577 .707 r
F P
0 g
s
.32232 .51624 m .32825 .57212 L .31191 .58002 L p .707 .577 .707 r
F P
0 g
s
.31272 .61947 m .31256 .58239 L .32893 .575 L p .707 .577 .707 r
F P
0 g
s
.32893 .575 m .32909 .61208 L .31272 .61947 L p .707 .577 .707 r
F P
0 g
s
.50145 .66289 m .49843 .68083 L .48614 .66929 L p .707 .577 .707 r
F P
0 g
s
.48614 .66929 m .48916 .65135 L .50145 .66289 L p .707 .577 .707 r
F P
0 g
s
.32825 .57212 m .32232 .51624 L .34629 .50903 L p .707 .577 .707 r
F P
0 g
s
.30699 .64748 m .31001 .62955 L .32632 .62299 L p .707 .577 .707 r
F P
0 g
s
.49388 .57725 m .49405 .61433 L .47299 .608 L p .707 .577 .707 r
F P
0 g
s
.47299 .608 m .47283 .57093 L .49388 .57725 L p .707 .577 .707 r
F P
0 g
s
.32632 .62299 m .32329 .64092 L .30699 .64748 L p .707 .577 .707 r
F P
0 g
s
.46549 .49892 m .47142 .5548 L .44414 .55379 L p .707 .577 .707 r
F P
0 g
s
.44414 .55379 m .43821 .49792 L .46549 .49892 L p .707 .577 .707 r
F P
0 g
s
.34629 .50903 m .35222 .56491 L .32825 .57212 L p .707 .577 .707 r
F P
0 g
s
.32909 .61208 m .32893 .575 L .35298 .56929 L p .707 .577 .707 r
F P
0 g
s
.35222 .56491 m .34629 .50903 L .37555 .50323 L p .707 .577 .707 r
F P
0 g
s
.35298 .56929 m .35314 .60636 L .32909 .61208 L p .707 .577 .707 r
F P
0 g
s
.48916 .65135 m .48614 .66929 L .46547 .65823 L p .707 .577 .707 r
F P
0 g
s
.46547 .65823 m .46849 .64029 L .48916 .65135 L p .707 .577 .707 r
F P
0 g
s
.43821 .49792 m .44414 .55379 L .41315 .55528 L p .707 .577 .707 r
F P
0 g
s
.41315 .55528 m .40722 .4994 L .43821 .49792 L p .707 .577 .707 r
F P
0 g
s
.47283 .57093 m .47299 .608 L .44553 .60374 L p .707 .577 .707 r
F P
0 g
s
.44553 .60374 m .44537 .56667 L .47283 .57093 L p .707 .577 .707 r
F P
0 g
s
.32329 .64092 m .32632 .62299 L .35017 .61969 L p .707 .577 .707 r
F P
0 g
s
.38147 .55911 m .37555 .50323 L .40722 .4994 L p .707 .577 .707 r
F P
0 g
s
.37555 .50323 m .38147 .55911 L .35222 .56491 L p .707 .577 .707 r
F P
0 g
s
.40722 .4994 m .41315 .55528 L .38147 .55911 L p .707 .577 .707 r
F P
0 g
s
.35314 .60636 m .35298 .56929 L .38236 .56581 L p .707 .577 .707 r
F P
0 g
s
.35017 .61969 m .34715 .63762 L .32329 .64092 L p .707 .577 .707 r
F P
0 g
s
.44537 .56667 m .44553 .60374 L .41436 .60198 L p .707 .577 .707 r
F P
0 g
s
.41436 .60198 m .4142 .56491 L .44537 .56667 L p .707 .577 .707 r
F P
0 g
s
.38236 .56581 m .38252 .60288 L .35314 .60636 L p .707 .577 .707 r
F P
0 g
s
.38252 .60288 m .38236 .56581 L .4142 .56491 L p .707 .577 .707 r
F P
0 g
s
.46849 .64029 m .46547 .65823 L .43843 .64873 L p .707 .577 .707 r
F P
0 g
s
.43843 .64873 m .44146 .6308 L .46849 .64029 L p .707 .577 .707 r
F P
0 g
s
.4142 .56491 m .41436 .60198 L .38252 .60288 L p .707 .577 .707 r
F P
0 g
s
.34715 .63762 m .35017 .61969 L .37925 .61996 L p .707 .577 .707 r
F P
0 g
s
.37925 .61996 m .37623 .6379 L .34715 .63762 L p .707 .577 .707 r
F P
0 g
s
.44146 .6308 m .43843 .64873 L .40768 .64173 L p .707 .577 .707 r
F P
0 g
s
.40768 .64173 m .41071 .62379 L .44146 .6308 L p .707 .577 .707 r
F P
0 g
s
.37623 .6379 m .37925 .61996 L .41071 .62379 L p .707 .577 .707 r
F P
0 g
s
.41071 .62379 m .40768 .64173 L .37623 .6379 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Ioo`d008Yo
o`00OGoo2@001UYF00<005YFFUH015YF3000OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001gOol0079oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP04001JEP00001eOol006eoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001bOol006Uoo`@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP80071oo`00Igoo
0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0`00KWoo001UOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001/Ool0
06=oo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Uoo`00HWoo0P001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0JGoo001ROol20006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001ZOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yo
o`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00=oo`00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1YOol0065oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Uoo`00
HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0JGoo001QOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Uoo`00HGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0JGoo001QOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0FFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIoo`1YOol0065oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP0EFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1YOol0065oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEUYF001JEVYoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF01EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF
JWoo001QOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH05EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIZOol0065oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1XOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0E
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1X
Ool0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00JGoo001QOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065o
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001QOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001YOol0065oo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00
HWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0EFUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001YOol0069oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0?0007
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001YOol0069o
o`04001JEUYF0005FUH01000FUIJEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001ROol01@00
FUIJEP00FUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00JGoo001QOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001YOol005eoo`@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005]oo`8000EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001YOol005Uoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF000=FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JGoo001G
Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP003EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001FOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001EOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0Igoo001DOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Aoo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo
001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUHF0002FUH0
1@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001E
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPL0
00UJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol005Eoo`03001JEP0000EJEP03001JEUYF
00=JEQL000MJEP03001JEUYF00AJEP03001JEUYF009JEP@000YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8001iooaD003Eoo`00EGoo00@005YFFUH000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF009JEPT000EJEP03001JEUYF00=JEP<000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@0035oo`00EGoo00@005YFFUH000=JEPL00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000COol70006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000_Ool005Eoo`05001JEUYF001JEP050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000=Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`9JEP@00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yoo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005Ioo`04FUH000000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20007Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo001FOol00eYF00000004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P001Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001AOol80004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0018Ool90004FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool0041oo`P000AJEP03001JEUYF00IJ
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=Woo100000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000Aoo`00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00=7oo0P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF000015YF00<005YFFUH00eYF
1P000eYF00<005YFFUH01eYF00<005YFFUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005Ool005YFFUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo000bOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH400000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200001Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP0002aoo`00<7oo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`0000=JEP0000000`0000=JEP00FUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF20000eYF0`000eYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000Eoo`00FUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;goo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF001JEP8000EJEP04001JEUYFFUH80009FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool002ioo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0015YF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQP000=JEP03001JEUYF008002]oo`00;Goo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF1@000eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH2000[Ool0
02eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP80009JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001J
EUYF00AJEP07001JEUYFFUH005YF00002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002]oo`00;Goo00<005YF00001EYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool0
0`00FUH00004FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0003FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000[Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJEUYF4000
15YF00<005YFFUH01eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF0000:goo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20003FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70006FUH00`00
FUIJEP05FUH20004FUH00`00FUH00002000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002Ool01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP8002aoo`00;Woo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@0000=JEP00
00000`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH0
1UYF0`0000AJEP000000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=oo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP05001JEUYFFUH0000]Ool002ioo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT0009JEP06001JEP00001JEP000eYF1@001UYF
00<005YFFUH01EYF00<005YFFUH01UYF10001eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
000^Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF009JEPP000QJEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003Ool015YF001JEP001EYF00<005YFFUH01EYF4`0025YF00<0
05YFFUH00eYF0`00<7oo000^Ool00`00FUH00005FUH00`00FUIJEP03FUH60007FUH:0002FUH20000
15YF001JEP001UYF00<005YF00000UYF6@0000IJEP00000005YF0006FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP02FUH00`00FUIJ
EP060004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000eYF00000002000cOol002ioo`03001J
EP0000EJEP03001JEP0000<000AJEP03001JEP0000L000AJEP03001JEUYF009JEP@0009JEP<000EJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP<000IJEP04001J
EP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH01000
FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Ao
o`00;Woo00@005YFFUH000AJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH800001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP<0009JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000aOol002ioo`04001JEUYF0002FUH60003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YF00000P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P0000=JEP00FUH0
0UYF0P0035YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;goo000_Ool2FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF0`000eYF00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00AJEP03001J
EUYF009JEP80009JEP03001JEUYF0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<002eoo`00;goo0UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF
0`0000EJEP00FUIJEP0000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP05001J
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH0
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000_Ool00eYF00000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUH000040005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002]oo`00;goo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001UYF00<005YFFUH00eYF10000eYF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH025YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP80009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000ZOol002mo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00EJEP03001JEUYF00T000AJEP03001JEUYF00QJEP03001J
EUYF00MJEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH200000eYF
001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00:Woo000_Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
001JEP06FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2000015YF0000
000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000ZOol002moo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03001JEUYF00AJ
EPD0009JEPP000EJEP03001JEUYF00D000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF
00<005YFFUH00eYF00@005YFFUIJEP8002Yoo`00;goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH00UYF5`001UYF00<005YF00000`000UYF00<005YFFUH01EYF0`001eYF00@005YFFUIJEPP0
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF009JEPH001Yoo`D000AJEP04001JEUYFFUH2
000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPX001=oo`@0009JEP06001JEUYFFUH005YF
10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF0000
15YF00<005YF000020007Woo100000=JEP00FUH00UYF0P00:Woo000_Ool00`00FUH00004FUH00`00
FUH00003000QOol500001EYF001JEUYF00000UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP00009JEPD000=JEP04001JEUYFFUH9000?Ool70003
FUH30003FUH2000ZOol002moo`03001JEP0000=JEP<00003FUH0000000<0021oo`H0009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF0000000ZOol002moo`04001JEP00FUH20005FUH01000FUIJEUYF20004Woo1P001EYF00@0
05YFFUH000IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000ZOol002moo`06001JEP00001JEP0015YF7`0015YF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEUYF00IJEPl000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002Yoo`00;goo0P000eYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000eYF00<005YFFUH01UYF00<005YFFUH015YF
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF009J
EP03001JEP0002Yoo`00;goo0P000UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH0100025YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEQD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF
009JEP03001JEP0002Yoo`00;goo10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH00000FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80006
FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP02FUH2000[Ool0031oo`80009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04
FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000000P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00<0
05YFFUH00`000eYF0P00;7oo000_Ool00`00FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH40005FUH00`00FUIJEP03FUH4
000^Ool002moo`8000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEPL000IJEP03001JEUYF
00EJEP8000AJEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH0
1EYF0P00;goo000_Ool200000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP06FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300001UYF001JEP00FUH0009JEPD000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP03001JEP0002ioo`00;Woo00@005YF000000Aoo`<00003
FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP@000MJEP03001JEUYF00800005OomJEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUH00006FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH01@00FUIJEUYF0000;Goo000^Ool3
0008Ool50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP<000EJEP<0
009ooaT000Moo`04001JEUYF0004FUH00`00Oomoo`0ZOol002ioo`800003FUH007oo00]ooaX00006
Ool00000001JEP002EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF2P002eYF3000
1EYF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH01@009Woo0`0015YF00<007oo
Ool0:Woo000^Ool20002FUH00`00Oomoo`0WOol20009FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
1000FUIJEUYF1P002EYF00<005YFFUH02EYF00<005YFFUH02EYF1`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF00001EYF0`00:7oo00<005YFFUH00UYF00<007ooOol0:Woo000_Ool01@00FUIJEUYF
0000:Woo0P000eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP8000=JEP80
00IJEP04001JEP00000WOol00`00FUIJEP02000/Ool002moo`04001JEUYFFUH3000ZOol200000eYF
001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH20003FUH20006FUH01000FUIJEUYF
0`009Goo1000;7oo000`Ool01000FUIJEP000UYF0P00:Woo0P000eYF00<005YFFUH00eYF0`000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEP000003FUH00`00FUIJEP05FUH4000ROol3000/Ool0031o
o`03001JEP0000EJEP<002Uoo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF
00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00@001aoo`@002eoo`00<Goo0P001UYF00@0
05YF000002Moo`=JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP04FUH7000@Ool50002FUH2000]Ool0039oo`03001JEUYF00AJEP04001JEUYFFUH2
0009Ool3000IOol3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04FUH0
1000FUH0000015YF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00H005YFFUH005YF000]Ool0
03=oo`8000=JEP03001JEUYF00AJEP@000Aoo`D001Qoo`9JEP05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000eOol200000eYF001JEP06FUH0
0`00FUIJEP09000GOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000gOol30006FUH00`00FUIJEP04FUH7000@Ool500000eYF
00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000050005FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000jOol20004FUH00`00FUIJEP05FUH30003FUH@0003FUH00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20006Ool400000eYF001JEP04FUH01000FUIJEUYF0P000goo1`00
15YF00<005YFFUH01EYF00@005YFFUIJEPH0035oo`00?7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF0P002Woo10000eYF00@005YFFUIJEP8000Yooa0003Moo`00?goo0`001UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000]oo`P000=JEP80055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YF000007oo008000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20008Ool5
0005FUH01000FUIJEP000UYF0P00DGoo0016Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1Goo0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00D005YF000005YF00T000=JEP03001JEUYF00AJEP04001JEUYFFUH4
001AOol004eooa4000]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00AJEP@000AJEP03001JEUYF00AJEP03001J
EUYF009JEP<0055oo`00K7oo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YF000010001UYF00<0
05YFFUH00UYF0`00DGoo001^Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUH0000800000eYF001JEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJ
EP02FUH00`00FUH0001AOol0075oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000EJEPP000IJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP80059oo`00N7oo3000
1UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF1@000eYF10000UYF00<005YFFUH01EYF00H0
05YFFUH005YF0003FUH2001COol008Aoo`h00004Ool000000005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH50007FUH40005FUH00`00FUIJEP02FUH200000eYF0000001EOol008moo`@0009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000QJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00Oomoo`1EOol008moo`05001JEP00FUH00003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH2001FOol008moo`8000=JEP03001o
ogoo00=oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000IJEP04001J
EP00001DOol0091oo`04001JEUYFFUH30008OolK0005Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1AOol0091oo`05001JEUYFFUH00002FUH00`00Oomoo`0WOol200000eYF001JEP03FUH00`00Oomo
o`1AOol0095oo`03001JEP0000AJEP8002Uoo`8000AJEP03001oogoo055oo`00TWoo0P001UYF0P00
:Goo00<005YFFUH00P00Dgoo002COol00`00FUIJEP04FUH00`00FUH00003000VOol4001COol009Ao
o`8000AJEP03001JEUYF00=JEPD002=oo`8005=oo`00UWoo00@005YFFUH000QJEP03001JEUYF00@0
01eoo`<005Aoo`00Ugoo0`0025YF00<005YFFUH015YF1`0047oo1P0000=JEP000000E7oo002IOol2
0006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH@0003FUH01000FUIJEUYF0P00E7oo002KOol40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
001EOol009moo`D000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2001EOol00:Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH0001FOol00:Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001GOol0
0:mooaD005Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]14\[InvisibleSpace]"     "\
\[InvisibleSpace]5.644402753529235`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 14, "     ", 5.6444027535292349, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60071 .7485 m .60249 .69273 L .57088 .69059 L p .707 .577 .707 r
F P
0 g
s
.60249 .69273 m .60071 .7485 L .63221 .74809 L p .707 .577 .707 r
F P
0 g
s
.63221 .74809 m .634 .69232 L .60249 .69273 L p .707 .577 .707 r
F P
0 g
s
.5691 .74637 m .57088 .69059 L .54227 .68612 L p .707 .577 .707 r
F P
0 g
s
.57088 .69059 m .5691 .74637 L .60071 .7485 L p .707 .577 .707 r
F P
0 g
s
.634 .69232 m .63221 .74809 L .66053 .74518 L p .707 .577 .707 r
F P
0 g
s
.66053 .74518 m .66232 .6894 L .634 .69232 L p .707 .577 .707 r
F P
0 g
s
.54048 .74189 m .54227 .68612 L .51945 .67975 L p .707 .577 .707 r
F P
0 g
s
.54227 .68612 m .54048 .74189 L .5691 .74637 L p .707 .577 .707 r
F P
0 g
s
.66232 .6894 m .66053 .74518 L .6829 .74005 L p .707 .577 .707 r
F P
0 g
s
.6829 .74005 m .68468 .68427 L .66232 .6894 L p .707 .577 .707 r
F P
0 g
s
.60948 .81143 m .60826 .77457 L .57638 .77494 L p .707 .577 .707 r
F P
0 g
s
.60826 .77457 m .60948 .81143 L .64046 .80826 L p .707 .577 .707 r
F P
0 g
s
.64046 .80826 m .63924 .7714 L .60826 .77457 L p .707 .577 .707 r
F P
0 g
s
.5776 .8118 m .57638 .77494 L .54672 .77246 L p .707 .577 .707 r
F P
0 g
s
.57638 .77494 m .5776 .8118 L .60948 .81143 L p .707 .577 .707 r
F P
0 g
s
.63924 .7714 m .64046 .80826 L .6675 .8026 L p .707 .577 .707 r
F P
0 g
s
.6675 .8026 m .66628 .76574 L .63924 .7714 L p .707 .577 .707 r
F P
0 g
s
.51945 .67975 m .51766 .73552 L .54048 .74189 L p .707 .577 .707 r
F P
0 g
s
.54672 .77246 m .54794 .80932 L .5776 .8118 L p .707 .577 .707 r
F P
0 g
s
.54794 .80932 m .54672 .77246 L .52218 .76739 L p .707 .577 .707 r
F P
0 g
s
.51766 .73552 m .51945 .67975 L .50466 .6721 L p .707 .577 .707 r
F P
0 g
s
.61753 .85569 m .61544 .83761 L .58367 .84064 L p .707 .577 .707 r
F P
0 g
s
.61544 .83761 m .61753 .85569 L .64797 .84956 L p .707 .577 .707 r
F P
0 g
s
.64797 .84956 m .64588 .83148 L .61544 .83761 L p .707 .577 .707 r
F P
0 g
s
.68468 .68427 m .6829 .74005 L .69711 .7332 L p .707 .577 .707 r
F P
0 g
s
.69711 .7332 m .6989 .67742 L .68468 .68427 L p .707 .577 .707 r
F P
0 g
s
.58576 .85872 m .58367 .84064 L .55368 .84029 L p .707 .577 .707 r
F P
0 g
s
.58367 .84064 m .58576 .85872 L .61753 .85569 L p .707 .577 .707 r
F P
0 g
s
.66628 .76574 m .6675 .8026 L .68796 .79499 L p .707 .577 .707 r
F P
0 g
s
.68796 .79499 m .68674 .75813 L .66628 .76574 L p .707 .577 .707 r
F P
0 g
s
.52218 .76739 m .5234 .80425 L .54794 .80932 L p .707 .577 .707 r
F P
0 g
s
.64588 .83148 m .64797 .84956 L .6741 .84095 L p .707 .577 .707 r
F P
0 g
s
.6741 .84095 m .67201 .82287 L .64588 .83148 L p .707 .577 .707 r
F P
0 g
s
.55368 .84029 m .55576 .85837 L .58576 .85872 L p .707 .577 .707 r
F P
0 g
s
.50466 .6721 m .50287 .72788 L .51766 .73552 L p .707 .577 .707 r
F P
0 g
s
.55576 .85837 m .55368 .84029 L .52841 .83658 L p .707 .577 .707 r
F P
0 g
s
.5234 .80425 m .52218 .76739 L .50516 .76021 L p .707 .577 .707 r
F P
0 g
s
.52841 .83658 m .53049 .85466 L .55576 .85837 L p .707 .577 .707 r
F P
0 g
s
.67201 .82287 m .6741 .84095 L .69336 .83068 L p .707 .577 .707 r
F P
0 g
s
.69336 .83068 m .69127 .8126 L .67201 .82287 L p .707 .577 .707 r
F P
0 g
s
.50287 .72788 m .50466 .6721 L .49934 .66393 L p .707 .577 .707 r
F P
0 g
s
.50516 .76021 m .50638 .79707 L .5234 .80425 L p .707 .577 .707 r
F P
0 g
s
.68674 .75813 m .68796 .79499 L .69984 .78619 L p .707 .577 .707 r
F P
0 g
s
.69984 .78619 m .69862 .74933 L .68674 .75813 L p .707 .577 .707 r
F P
0 g
s
.6989 .67742 m .69711 .7332 L .70179 .7253 L p .707 .577 .707 r
F P
0 g
s
.70179 .7253 m .70358 .66953 L .6989 .67742 L p .707 .577 .707 r
F P
0 g
s
.53049 .85466 m .52841 .83658 L .51032 .82989 L p .707 .577 .707 r
F P
0 g
s
.51032 .82989 m .5124 .84796 L .53049 .85466 L p .707 .577 .707 r
F P
0 g
s
.49934 .66393 m .49755 .71971 L .50287 .72788 L p .707 .577 .707 r
F P
0 g
s
.50638 .79707 m .50516 .76021 L .49734 .75164 L p .707 .577 .707 r
F P
0 g
s
.69127 .8126 m .69336 .83068 L .70386 .81978 L p .707 .577 .707 r
F P
0 g
s
.70386 .81978 m .70178 .8017 L .69127 .8126 L p .707 .577 .707 r
F P
0 g
s
.49734 .75164 m .49856 .7885 L .50638 .79707 L p .707 .577 .707 r
F P
0 g
s
.49755 .71971 m .49934 .66393 L .50402 .65604 L p .707 .577 .707 r
F P
0 g
s
.69862 .74933 m .69984 .78619 L .70197 .77706 L p .707 .577 .707 r
F P
0 g
s
.70197 .77706 m .70075 .7402 L .69862 .74933 L p .707 .577 .707 r
F P
0 g
s
.5124 .84796 m .51032 .82989 L .50119 .82086 L p .707 .577 .707 r
F P
0 g
s
.70358 .66953 m .70179 .7253 L .69647 .71713 L p .707 .577 .707 r
F P
0 g
s
.69647 .71713 m .69826 .66136 L .70358 .66953 L p .707 .577 .707 r
F P
0 g
s
.49464 .8219 m .49464 .32001 L .45036 .31767 L p .707 .577 .707 r
F P
0 g
s
.50119 .82086 m .50327 .83893 L .5124 .84796 L p .707 .577 .707 r
F P
0 g
s
.50402 .65604 m .50223 .71181 L .49755 .71971 L p .707 .577 .707 r
F P
0 g
s
.49856 .7885 m .49734 .75164 L .49946 .74251 L p .707 .577 .707 r
F P
0 g
s
.49946 .74251 m .50069 .77936 L .49856 .7885 L p .707 .577 .707 r
F P
0 g
s
.50223 .71181 m .50402 .65604 L .51823 .64919 L p .707 .577 .707 r
F P
0 g
s
.50327 .83893 m .50119 .82086 L .50191 .81037 L p .707 .577 .707 r
F P
0 g
s
.50191 .81037 m .504 .82845 L .50327 .83893 L p .707 .577 .707 r
F P
0 g
s
.51823 .64919 m .51645 .70496 L .50223 .71181 L p .707 .577 .707 r
F P
0 g
s
.50069 .77936 m .49946 .74251 L .51134 .73371 L p .707 .577 .707 r
F P
0 g
s
.51134 .73371 m .51256 .77056 L .50069 .77936 L p .707 .577 .707 r
F P
0 g
s
.51645 .70496 m .51823 .64919 L .5406 .64405 L p .707 .577 .707 r
F P
0 g
s
.504 .82845 m .50191 .81037 L .51242 .79947 L p .707 .577 .707 r
F P
0 g
s
.51242 .79947 m .5145 .81755 L .504 .82845 L p .707 .577 .707 r
F P
0 g
s
.5406 .64405 m .53881 .69983 L .51645 .70496 L p .707 .577 .707 r
F P
0 g
s
.51256 .77056 m .51134 .73371 L .5318 .7261 L p .707 .577 .707 r
F P
0 g
s
.5318 .7261 m .53302 .76296 L .51256 .77056 L p .707 .577 .707 r
F P
0 g
s
.5145 .81755 m .51242 .79947 L .53168 .7892 L p .707 .577 .707 r
F P
0 g
s
.53168 .7892 m .53376 .80728 L .5145 .81755 L p .707 .577 .707 r
F P
0 g
s
.53302 .76296 m .5318 .7261 L .55885 .72044 L p .707 .577 .707 r
F P
0 g
s
.55885 .72044 m .56007 .7573 L .53302 .76296 L p .707 .577 .707 r
F P
0 g
s
.53376 .80728 m .53168 .7892 L .55781 .78059 L p .707 .577 .707 r
F P
0 g
s
.55781 .78059 m .55989 .79867 L .53376 .80728 L p .707 .577 .707 r
F P
0 g
s
.49464 .32001 m .49464 .8219 L .53944 .82045 L p .707 .577 .707 r
F P
0 g
s
.53881 .69983 m .5406 .64405 L .56892 .64114 L p .707 .577 .707 r
F P
0 g
s
.56892 .64114 m .56713 .69692 L .53881 .69983 L p .707 .577 .707 r
F P
0 g
s
.53944 .82045 m .53944 .31856 L .49464 .32001 L p .707 .577 .707 r
F P
0 g
s
.56713 .69692 m .56892 .64114 L .60042 .64073 L p .707 .577 .707 r
F P
0 g
s
.60042 .64073 m .59864 .69651 L .56713 .69692 L p .707 .577 .707 r
F P
0 g
s
.56007 .7573 m .55885 .72044 L .58982 .71727 L p .707 .577 .707 r
F P
0 g
s
.58982 .71727 m .59105 .75412 L .56007 .7573 L p .707 .577 .707 r
F P
0 g
s
.55989 .79867 m .55781 .78059 L .58825 .77446 L p .707 .577 .707 r
F P
0 g
s
.58825 .77446 m .59033 .79254 L .55989 .79867 L p .707 .577 .707 r
F P
0 g
s
.53944 .31856 m .53944 .82045 L .58039 .81536 L p .707 .577 .707 r
F P
0 g
s
.58039 .81536 m .58039 .31347 L .53944 .31856 L p .707 .577 .707 r
F P
0 g
s
.45035 .81956 m .45036 .31767 L .41093 .31178 L p .707 .577 .707 r
F P
0 g
s
.45036 .31767 m .45035 .81956 L .49464 .8219 L p .707 .577 .707 r
F P
0 g
s
.70178 .8017 m .70386 .81978 L .70459 .80929 L p .707 .577 .707 r
F P
0 g
s
.70459 .80929 m .70251 .79122 L .70178 .8017 L p .707 .577 .707 r
F P
0 g
s
.63203 .64287 m .63024 .69865 L .59864 .69651 L p .707 .577 .707 r
F P
0 g
s
.59864 .69651 m .60042 .64073 L .63203 .64287 L p .707 .577 .707 r
F P
0 g
s
.6217 .7169 m .62292 .75376 L .59105 .75412 L p .707 .577 .707 r
F P
0 g
s
.59105 .75412 m .58982 .71727 L .6217 .7169 L p .707 .577 .707 r
F P
0 g
s
.62002 .77143 m .6221 .78951 L .59033 .79254 L p .707 .577 .707 r
F P
0 g
s
.59033 .79254 m .58825 .77446 L .62002 .77143 L p .707 .577 .707 r
F P
0 g
s
.58039 .31347 m .58039 .81536 L .61346 .80712 L p .707 .577 .707 r
F P
0 g
s
.61346 .80712 m .61346 .30523 L .58039 .31347 L p .707 .577 .707 r
F P
0 g
s
.70075 .7402 m .70197 .77706 L .69414 .76848 L p .707 .577 .707 r
F P
0 g
s
.69414 .76848 m .69292 .73162 L .70075 .7402 L p .707 .577 .707 r
F P
0 g
s
.69826 .66136 m .69647 .71713 L .68168 .70949 L p .707 .577 .707 r
F P
0 g
s
.68168 .70949 m .68347 .65371 L .69826 .66136 L p .707 .577 .707 r
F P
0 g
s
.41093 .81366 m .41093 .31178 L .38023 .3029 L p .707 .577 .707 r
F P
0 g
s
.41093 .31178 m .41093 .81366 L .45035 .81956 L p .707 .577 .707 r
F P
0 g
s
.25955 .7147 m .26033 .65959 L .22871 .6578 L p .707 .577 .707 r
F P
0 g
s
.26033 .65959 m .25955 .7147 L .29106 .71354 L p .707 .577 .707 r
F P
0 g
s
.29106 .71354 m .29185 .65843 L .26033 .65959 L p .707 .577 .707 r
F P
0 g
s
.22793 .71291 m .22871 .6578 L .20008 .65322 L p .707 .577 .707 r
F P
0 g
s
.22871 .6578 m .22793 .71291 L .25955 .7147 L p .707 .577 .707 r
F P
0 g
s
.29185 .65843 m .29106 .71354 L .31939 .70952 L p .707 .577 .707 r
F P
0 g
s
.31939 .70952 m .32018 .65441 L .29185 .65843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70251 .79122 m .70459 .80929 L .69546 .80026 L p .707 .577 .707 r
F P
0 g
s
.69546 .80026 m .69338 .78219 L .70251 .79122 L p .707 .577 .707 r
F P
0 g
s
.1993 .70833 m .20008 .65322 L .17725 .6463 L p .707 .577 .707 r
F P
0 g
s
.20008 .65322 m .1993 .70833 L .22793 .71291 L p .707 .577 .707 r
F P
0 g
s
.32018 .65441 m .31939 .70952 L .34176 .70306 L p .707 .577 .707 r
F P
0 g
s
.34176 .70306 m .34255 .64795 L .32018 .65441 L p .707 .577 .707 r
F P
0 g
s
.66064 .64734 m .65886 .70312 L .63024 .69865 L p .707 .577 .707 r
F P
0 g
s
.63024 .69865 m .63203 .64287 L .66064 .64734 L p .707 .577 .707 r
F P
0 g
s
.65136 .71938 m .65259 .75623 L .62292 .75376 L p .707 .577 .707 r
F P
0 g
s
.62292 .75376 m .6217 .7169 L .65136 .71938 L p .707 .577 .707 r
F P
0 g
s
.65001 .77178 m .6521 .78986 L .6221 .78951 L p .707 .577 .707 r
F P
0 g
s
.6221 .78951 m .62002 .77143 L .65001 .77178 L p .707 .577 .707 r
F P
0 g
s
.61346 .30523 m .61346 .80712 L .63543 .79654 L p .707 .577 .707 r
F P
0 g
s
.63543 .79654 m .63543 .29465 L .61346 .30523 L p .707 .577 .707 r
F P
0 g
s
.69292 .73162 m .69414 .76848 L .67713 .76131 L p .707 .577 .707 r
F P
0 g
s
.67713 .76131 m .6759 .72445 L .69292 .73162 L p .707 .577 .707 r
F P
0 g
s
.68347 .65371 m .68168 .70949 L .65886 .70312 L p .707 .577 .707 r
F P
0 g
s
.65886 .70312 m .66064 .64734 L .68347 .65371 L p .707 .577 .707 r
F P
0 g
s
.268 .76945 m .26746 .73214 L .23556 .73206 L p .707 .577 .707 r
F P
0 g
s
.26746 .73214 m .268 .76945 L .29899 .76713 L p .707 .577 .707 r
F P
0 g
s
.29899 .76713 m .29845 .72981 L .26746 .73214 L p .707 .577 .707 r
F P
0 g
s
.23611 .76938 m .23556 .73206 L .20589 .72959 L p .707 .577 .707 r
F P
0 g
s
.23556 .73206 m .23611 .76938 L .268 .76945 L p .707 .577 .707 r
F P
0 g
s
.38023 .80479 m .38023 .3029 L .36125 .29191 L p .707 .577 .707 r
F P
0 g
s
.38023 .3029 m .38023 .80479 L .41093 .81366 L p .707 .577 .707 r
F P
0 g
s
.29845 .72981 m .29899 .76713 L .32605 .76263 L p .707 .577 .707 r
F P
0 g
s
.32605 .76263 m .3255 .72531 L .29845 .72981 L p .707 .577 .707 r
F P
0 g
s
.20589 .72959 m .20644 .76691 L .23611 .76938 L p .707 .577 .707 r
F P
0 g
s
.17725 .6463 m .17647 .70141 L .1993 .70833 L p .707 .577 .707 r
F P
0 g
s
.27411 .80546 m .27316 .78658 L .24124 .78799 L p .707 .577 .707 r
F P
0 g
s
.27316 .78658 m .27411 .80546 L .30468 .80231 L p .707 .577 .707 r
F P
0 g
s
.30468 .80231 m .30374 .78342 L .27316 .78658 L p .707 .577 .707 r
F P
0 g
s
.20644 .76691 m .20589 .72959 L .18134 .72498 L p .707 .577 .707 r
F P
0 g
s
.24218 .80688 m .24124 .78799 L .2111 .78753 L p .707 .577 .707 r
F P
0 g
s
.24124 .78799 m .24218 .80688 L .27411 .80546 L p .707 .577 .707 r
F P
0 g
s
.17647 .70141 m .17725 .6463 L .16245 .63773 L p .707 .577 .707 r
F P
0 g
s
.2111 .78753 m .21204 .80641 L .24218 .80688 L p .707 .577 .707 r
F P
0 g
s
.69338 .78219 m .69546 .80026 L .67737 .79357 L p .707 .577 .707 r
F P
0 g
s
.67737 .79357 m .67529 .77549 L .69338 .78219 L p .707 .577 .707 r
F P
0 g
s
.34255 .64795 m .34176 .70306 L .35598 .69477 L p .707 .577 .707 r
F P
0 g
s
.35598 .69477 m .35677 .63966 L .34255 .64795 L p .707 .577 .707 r
F P
0 g
s
.30374 .78342 m .30468 .80231 L .33092 .79773 L p .707 .577 .707 r
F P
0 g
s
.33092 .79773 m .32997 .77884 L .30374 .78342 L p .707 .577 .707 r
F P
0 g
s
.18134 .72498 m .18189 .7623 L .20644 .76691 L p .707 .577 .707 r
F P
0 g
s
.3255 .72531 m .32605 .76263 L .34651 .75641 L p .707 .577 .707 r
F P
0 g
s
.34651 .75641 m .34596 .71909 L .3255 .72531 L p .707 .577 .707 r
F P
0 g
s
.21204 .80641 m .2111 .78753 L .18569 .78523 L p .707 .577 .707 r
F P
0 g
s
.6759 .72445 m .67713 .76131 L .65259 .75623 L p .707 .577 .707 r
F P
0 g
s
.65259 .75623 m .65136 .71938 L .6759 .72445 L p .707 .577 .707 r
F P
0 g
s
.18569 .78523 m .18663 .80412 L .21204 .80641 L p .707 .577 .707 r
F P
0 g
s
.16245 .63773 m .16166 .69284 L .17647 .70141 L p .707 .577 .707 r
F P
0 g
s
.18189 .7623 m .18134 .72498 L .16431 .71866 L p .707 .577 .707 r
F P
0 g
s
.63543 .29465 m .63543 .79654 L .64414 .78466 L p .707 .577 .707 r
F P
0 g
s
.64414 .78466 m .64414 .28277 L .63543 .29465 L p .707 .577 .707 r
F P
0 g
s
.32997 .77884 m .33092 .79773 L .35025 .79216 L p .707 .577 .707 r
F P
0 g
s
.35025 .79216 m .3493 .77327 L .32997 .77884 L p .707 .577 .707 r
F P
0 g
s
.16431 .71866 m .16486 .75598 L .18189 .7623 L p .707 .577 .707 r
F P
0 g
s
.16166 .69284 m .16245 .63773 L .15712 .62833 L p .707 .577 .707 r
F P
0 g
s
.67529 .77549 m .67737 .79357 L .6521 .78986 L p .707 .577 .707 r
F P
0 g
s
.6521 .78986 m .65001 .77178 L .67529 .77549 L p .707 .577 .707 r
F P
0 g
s
.18663 .80412 m .18569 .78523 L .16749 .78133 L p .707 .577 .707 r
F P
0 g
s
.35677 .63966 m .35598 .69477 L .36066 .68548 L p .707 .577 .707 r
F P
0 g
s
.36066 .68548 m .36144 .63037 L .35677 .63966 L p .707 .577 .707 r
F P
0 g
s
.36144 .63037 m .36066 .68548 L .35533 .67609 L p .707 .577 .707 r
F P
0 g
s
.35533 .67609 m .35612 .62098 L .36144 .63037 L p .707 .577 .707 r
F P
0 g
s
.35983 .76727 m .36078 .78616 L .36148 .78031 L p .707 .577 .707 r
F P
0 g
s
.36148 .78031 m .36054 .76142 L .35983 .76727 L p .707 .577 .707 r
F P
0 g
s
.36078 .78616 m .35983 .76727 L .3493 .77327 L p .707 .577 .707 r
F P
0 g
s
.36054 .76142 m .36148 .78031 L .35228 .77518 L p .707 .577 .707 r
F P
0 g
s
.36125 .7938 m .36125 .29191 L .35585 .27989 L p .707 .577 .707 r
F P
0 g
s
.36125 .29191 m .36125 .7938 L .38023 .80479 L p .707 .577 .707 r
F P
0 g
s
.16749 .78133 m .16844 .80022 L .18663 .80412 L p .707 .577 .707 r
F P
0 g
s
.34596 .71909 m .34651 .75641 L .35839 .74906 L p .707 .577 .707 r
F P
0 g
s
.35839 .74906 m .35784 .71174 L .34596 .71909 L p .707 .577 .707 r
F P
0 g
s
.16486 .75598 m .16431 .71866 L .15648 .71127 L p .707 .577 .707 r
F P
0 g
s
.15712 .62833 m .15634 .68344 L .16166 .69284 L p .707 .577 .707 r
F P
0 g
s
.3493 .77327 m .35025 .79216 L .36078 .78616 L p .707 .577 .707 r
F P
0 g
s
.15648 .71127 m .15703 .74859 L .16486 .75598 L p .707 .577 .707 r
F P
0 g
s
.16844 .80022 m .16749 .78133 L .15829 .7762 L p .707 .577 .707 r
F P
0 g
s
.15634 .68344 m .15712 .62833 L .1618 .61904 L p .707 .577 .707 r
F P
0 g
s
.15829 .7762 m .15924 .79509 L .16844 .80022 L p .707 .577 .707 r
F P
0 g
s
.35784 .71174 m .35839 .74906 L .36052 .74131 L p .707 .577 .707 r
F P
0 g
s
.36052 .74131 m .35997 .70399 L .35784 .71174 L p .707 .577 .707 r
F P
0 g
s
.64414 .28277 m .64414 .78466 L .63875 .77263 L p .707 .577 .707 r
F P
0 g
s
.63875 .77263 m .63875 .27075 L .64414 .28277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35612 .62098 m .35533 .67609 L .34053 .66751 L p .707 .577 .707 r
F P
0 g
s
.34053 .66751 m .34132 .6124 L .35612 .62098 L p .707 .577 .707 r
F P
0 g
s
.35997 .70399 m .36052 .74131 L .35269 .73391 L p .707 .577 .707 r
F P
0 g
s
.35269 .73391 m .35214 .69659 L .35997 .70399 L p .707 .577 .707 r
F P
0 g
s
.35228 .77518 m .35134 .75629 L .36054 .76142 L p .707 .577 .707 r
F P
0 g
s
.35585 .27989 m .35585 .78178 L .36125 .7938 L p .707 .577 .707 r
F P
0 g
s
.35585 .78178 m .35585 .27989 L .36457 .26801 L p .707 .577 .707 r
F P
0 g
s
.15703 .74859 m .15648 .71127 L .15861 .70352 L p .707 .577 .707 r
F P
0 g
s
.1618 .61904 m .16102 .67415 L .15634 .68344 L p .707 .577 .707 r
F P
0 g
s
.15861 .70352 m .15916 .74084 L .15703 .74859 L p .707 .577 .707 r
F P
0 g
s
.15924 .79509 m .15829 .7762 L .159 .77035 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16102 .67415 m .1618 .61904 L .17602 .61075 L p .707 .577 .707 r
F P
0 g
s
.159 .77035 m .15994 .78924 L .15924 .79509 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17602 .61075 m .17523 .66586 L .16102 .67415 L p .707 .577 .707 r
F P
0 g
s
.63875 .27075 m .63875 .77263 L .61977 .76165 L p .707 .577 .707 r
F P
0 g
s
.61977 .76165 m .61977 .25976 L .63875 .27075 L p .707 .577 .707 r
F P
0 g
s
.15916 .74084 m .15861 .70352 L .17049 .69617 L p .707 .577 .707 r
F P
0 g
s
.17049 .69617 m .17103 .73349 L .15916 .74084 L p .707 .577 .707 r
F P
0 g
s
.36457 .7699 m .36457 .26801 L .38653 .25743 L p .707 .577 .707 r
F P
0 g
s
.36457 .26801 m .36457 .7699 L .35585 .78178 L p .707 .577 .707 r
F P
0 g
s
.17523 .66586 m .17602 .61075 L .19839 .60429 L p .707 .577 .707 r
F P
0 g
s
.15994 .78924 m .159 .77035 L .16953 .76435 L p .707 .577 .707 r
F P
0 g
s
.34132 .6124 m .34053 .66751 L .3177 .6606 L p .707 .577 .707 r
F P
0 g
s
.3177 .6606 m .31848 .60549 L .34132 .6124 L p .707 .577 .707 r
F P
0 g
s
.16953 .76435 m .17047 .78324 L .15994 .78924 L p .707 .577 .707 r
F P
0 g
s
.35214 .69659 m .35269 .73391 L .33566 .7276 L p .707 .577 .707 r
F P
0 g
s
.33566 .7276 m .33511 .69028 L .35214 .69659 L p .707 .577 .707 r
F P
0 g
s
.19839 .60429 m .1976 .6594 L .17523 .66586 L p .707 .577 .707 r
F P
0 g
s
.17103 .73349 m .17049 .69617 L .19095 .68994 L p .707 .577 .707 r
F P
0 g
s
.1976 .6594 m .19839 .60429 L .22672 .60028 L p .707 .577 .707 r
F P
0 g
s
.31848 .60549 m .3177 .6606 L .28907 .65602 L p .707 .577 .707 r
F P
0 g
s
.28907 .65602 m .28986 .60091 L .31848 .60549 L p .707 .577 .707 r
F P
0 g
s
.35134 .75629 m .35228 .77518 L .33409 .77128 L p .707 .577 .707 r
F P
0 g
s
.33409 .77128 m .33314 .75239 L .35134 .75629 L p .707 .577 .707 r
F P
0 g
s
.19095 .68994 m .1915 .72726 L .17103 .73349 L p .707 .577 .707 r
F P
0 g
s
.61977 .25976 m .61977 .76165 L .58906 .75277 L p .707 .577 .707 r
F P
0 g
s
.58906 .75277 m .58906 .25088 L .61977 .25976 L p .707 .577 .707 r
F P
0 g
s
.17047 .78324 m .16953 .76435 L .18886 .75878 L p .707 .577 .707 r
F P
0 g
s
.33511 .69028 m .33566 .7276 L .31111 .72298 L p .707 .577 .707 r
F P
0 g
s
.31111 .72298 m .31056 .68566 L .33511 .69028 L p .707 .577 .707 r
F P
0 g
s
.18886 .75878 m .1898 .77767 L .17047 .78324 L p .707 .577 .707 r
F P
0 g
s
.22593 .65539 m .22672 .60028 L .25824 .59911 L p .707 .577 .707 r
F P
0 g
s
.22672 .60028 m .22593 .65539 L .1976 .6594 L p .707 .577 .707 r
F P
0 g
s
.28986 .60091 m .28907 .65602 L .25745 .65422 L p .707 .577 .707 r
F P
0 g
s
.25745 .65422 m .25824 .59911 L .28986 .60091 L p .707 .577 .707 r
F P
0 g
s
.38653 .25743 m .38653 .75932 L .36457 .7699 L p .707 .577 .707 r
F P
0 g
s
.38653 .75932 m .38653 .25743 L .41961 .24919 L p .707 .577 .707 r
F P
0 g
s
.74255 .6555 m .74176 .59951 L .71014 .5988 L p .707 .577 .707 r
F P
0 g
s
.74176 .59951 m .74255 .6555 L .77407 .65381 L p .707 .577 .707 r
F P
0 g
s
.77407 .65381 m .77328 .59781 L .74176 .59951 L p .707 .577 .707 r
F P
0 g
s
.25824 .59911 m .25745 .65422 L .22593 .65539 L p .707 .577 .707 r
F P
0 g
s
.1915 .72726 m .19095 .68994 L .21801 .68545 L p .707 .577 .707 r
F P
0 g
s
.71093 .6548 m .71014 .5988 L .68151 .59576 L p .707 .577 .707 r
F P
0 g
s
.71014 .5988 m .71093 .6548 L .74255 .6555 L p .707 .577 .707 r
F P
0 g
s
.77328 .59781 m .77407 .65381 L .8024 .64987 L p .707 .577 .707 r
F P
0 g
s
.8024 .64987 m .80161 .59387 L .77328 .59781 L p .707 .577 .707 r
F P
0 g
s
.33314 .75239 m .33409 .77128 L .30867 .76898 L p .707 .577 .707 r
F P
0 g
s
.30867 .76898 m .30773 .7501 L .33314 .75239 L p .707 .577 .707 r
F P
0 g
s
.21801 .68545 m .21855 .72277 L .1915 .72726 L p .707 .577 .707 r
F P
0 g
s
.31056 .68566 m .31111 .72298 L .28144 .72051 L p .707 .577 .707 r
F P
0 g
s
.28144 .72051 m .28089 .6832 L .31056 .68566 L p .707 .577 .707 r
F P
0 g
s
.1898 .77767 m .18886 .75878 L .21509 .7542 L p .707 .577 .707 r
F P
0 g
s
.68151 .59576 m .6823 .65175 L .71093 .6548 L p .707 .577 .707 r
F P
0 g
s
.6823 .65175 m .68151 .59576 L .65868 .59068 L p .707 .577 .707 r
F P
0 g
s
.21509 .7542 m .21604 .77309 L .1898 .77767 L p .707 .577 .707 r
F P
0 g
s
.21855 .72277 m .21801 .68545 L .24899 .68312 L p .707 .577 .707 r
F P
0 g
s
.80161 .59387 m .8024 .64987 L .82476 .64408 L p .707 .577 .707 r
F P
0 g
s
.82476 .64408 m .82398 .58808 L .80161 .59387 L p .707 .577 .707 r
F P
0 g
s
.58906 .25088 m .58906 .75277 L .54964 .74688 L p .707 .577 .707 r
F P
0 g
s
.54964 .74688 m .54964 .24499 L .58906 .25088 L p .707 .577 .707 r
F P
0 g
s
.75045 .72127 m .751 .68451 L .71911 .68345 L p .707 .577 .707 r
F P
0 g
s
.751 .68451 m .75045 .72127 L .78144 .71938 L p .707 .577 .707 r
F P
0 g
s
.78144 .71938 m .78199 .68263 L .751 .68451 L p .707 .577 .707 r
F P
0 g
s
.71856 .72021 m .71911 .68345 L .68944 .67955 L p .707 .577 .707 r
F P
0 g
s
.71911 .68345 m .71856 .72021 L .75045 .72127 L p .707 .577 .707 r
F P
0 g
s
.28089 .6832 m .28144 .72051 L .24954 .72044 L p .707 .577 .707 r
F P
0 g
s
.24954 .72044 m .24899 .68312 L .28089 .6832 L p .707 .577 .707 r
F P
0 g
s
.24899 .68312 m .24954 .72044 L .21855 .72277 L p .707 .577 .707 r
F P
0 g
s
.41961 .75108 m .41961 .24919 L .46056 .2441 L p .707 .577 .707 r
F P
0 g
s
.41961 .24919 m .41961 .75108 L .38653 .75932 L p .707 .577 .707 r
F P
0 g
s
.78199 .68263 m .78144 .71938 L .8085 .71474 L p .707 .577 .707 r
F P
0 g
s
.8085 .71474 m .80904 .67798 L .78199 .68263 L p .707 .577 .707 r
F P
0 g
s
.30773 .7501 m .30867 .76898 L .27853 .76852 L p .707 .577 .707 r
F P
0 g
s
.27853 .76852 m .27759 .74963 L .30773 .7501 L p .707 .577 .707 r
F P
0 g
s
.65868 .59068 m .65947 .64667 L .6823 .65175 L p .707 .577 .707 r
F P
0 g
s
.21604 .77309 m .21509 .7542 L .24567 .75105 L p .707 .577 .707 r
F P
0 g
s
.68889 .71631 m .68944 .67955 L .66488 .67319 L p .707 .577 .707 r
F P
0 g
s
.68944 .67955 m .68889 .71631 L .71856 .72021 L p .707 .577 .707 r
F P
0 g
s
.24567 .75105 m .24661 .76994 L .21604 .77309 L p .707 .577 .707 r
F P
0 g
s
.65947 .64667 m .65868 .59068 L .64388 .58405 L p .707 .577 .707 r
F P
0 g
s
.27759 .74963 m .27853 .76852 L .24661 .76994 L p .707 .577 .707 r
F P
0 g
s
.24661 .76994 m .24567 .75105 L .27759 .74963 L p .707 .577 .707 r
F P
0 g
s
.82398 .58808 m .82476 .64408 L .83898 .63701 L p .707 .577 .707 r
F P
0 g
s
.83898 .63701 m .8382 .58101 L .82398 .58808 L p .707 .577 .707 r
F P
0 g
s
.54964 .24499 m .54964 .74688 L .50536 .74454 L p .707 .577 .707 r
F P
0 g
s
.50536 .74454 m .50536 .24265 L .54964 .24499 L p .707 .577 .707 r
F P
0 g
s
.75339 .76835 m .75433 .75037 L .72241 .74866 L p .707 .577 .707 r
F P
0 g
s
.75433 .75037 m .75339 .76835 L .78396 .76651 L p .707 .577 .707 r
F P
0 g
s
.78396 .76651 m .7849 .74853 L .75433 .75037 L p .707 .577 .707 r
F P
0 g
s
.72147 .76663 m .72241 .74866 L .69227 .74356 L p .707 .577 .707 r
F P
0 g
s
.72241 .74866 m .72147 .76663 L .75339 .76835 L p .707 .577 .707 r
F P
0 g
s
.80904 .67798 m .8085 .71474 L .82896 .70779 L p .707 .577 .707 r
F P
0 g
s
.82896 .70779 m .82951 .67103 L .80904 .67798 L p .707 .577 .707 r
F P
0 g
s
.46056 .74599 m .46056 .2441 L .50536 .24265 L p .707 .577 .707 r
F P
0 g
s
.46056 .2441 m .46056 .74599 L .41961 .75108 L p .707 .577 .707 r
F P
0 g
s
.66488 .67319 m .66434 .70995 L .68889 .71631 L p .707 .577 .707 r
F P
0 g
s
.69227 .74356 m .69132 .76153 L .72147 .76663 L p .707 .577 .707 r
F P
0 g
s
.50536 .24265 m .50536 .74454 L .46056 .74599 L p .707 .577 .707 r
F P
0 g
s
.7849 .74853 m .78396 .76651 L .8102 .76129 L p .707 .577 .707 r
F P
0 g
s
.8102 .76129 m .81114 .74332 L .7849 .74853 L p .707 .577 .707 r
F P
0 g
s
.69132 .76153 m .69227 .74356 L .66685 .73557 L p .707 .577 .707 r
F P
0 g
s
.64388 .58405 m .64466 .64005 L .65947 .64667 L p .707 .577 .707 r
F P
0 g
s
.66434 .70995 m .66488 .67319 L .64786 .66499 L p .707 .577 .707 r
F P
0 g
s
.66685 .73557 m .66591 .75354 L .69132 .76153 L p .707 .577 .707 r
F P
0 g
s
.64786 .66499 m .64731 .70175 L .66434 .70995 L p .707 .577 .707 r
F P
0 g
s
.64466 .64005 m .64388 .58405 L .63856 .57654 L p .707 .577 .707 r
F P
0 g
s
.8382 .58101 m .83898 .63701 L .84366 .62933 L p .707 .577 .707 r
F P
0 g
s
.84366 .62933 m .84287 .57334 L .8382 .58101 L p .707 .577 .707 r
F P
0 g
s
.82951 .67103 m .82896 .70779 L .84084 .69922 L p .707 .577 .707 r
F P
0 g
s
.84084 .69922 m .84139 .66246 L .82951 .67103 L p .707 .577 .707 r
F P
0 g
s
.81114 .74332 m .8102 .76129 L .82953 .75321 L p .707 .577 .707 r
F P
0 g
s
.82953 .75321 m .83047 .73524 L .81114 .74332 L p .707 .577 .707 r
F P
0 g
s
.66591 .75354 m .66685 .73557 L .64866 .72547 L p .707 .577 .707 r
F P
0 g
s
.64866 .72547 m .64772 .74345 L .66591 .75354 L p .707 .577 .707 r
F P
0 g
s
.64731 .70175 m .64786 .66499 L .64003 .65576 L p .707 .577 .707 r
F P
0 g
s
.63856 .57654 m .63934 .63254 L .64466 .64005 L p .707 .577 .707 r
F P
0 g
s
.64003 .65576 m .63948 .69252 L .64731 .70175 L p .707 .577 .707 r
F P
0 g
s
.83047 .73524 m .82953 .75321 L .84006 .74306 L p .707 .577 .707 r
F P
0 g
s
.84006 .74306 m .841 .72508 L .83047 .73524 L p .707 .577 .707 r
F P
0 g
s
.64772 .74345 m .64866 .72547 L .63946 .71425 L p .707 .577 .707 r
F P
0 g
s
.84139 .66246 m .84084 .69922 L .84297 .68986 L p .707 .577 .707 r
F P
0 g
s
.84297 .68986 m .84352 .6531 L .84139 .66246 L p .707 .577 .707 r
F P
0 g
s
.63934 .63254 m .63856 .57654 L .64323 .56887 L p .707 .577 .707 r
F P
0 g
s
.84287 .57334 m .84366 .62933 L .83834 .62182 L p .707 .577 .707 r
F P
0 g
s
.83834 .62182 m .83755 .56582 L .84287 .57334 L p .707 .577 .707 r
F P
0 g
s
.63946 .71425 m .63852 .73223 L .64772 .74345 L p .707 .577 .707 r
F P
0 g
s
.63948 .69252 m .64003 .65576 L .64215 .6464 L p .707 .577 .707 r
F P
0 g
s
.64323 .56887 m .64402 .62487 L .63934 .63254 L p .707 .577 .707 r
F P
0 g
s
.64215 .6464 m .64161 .68316 L .63948 .69252 L p .707 .577 .707 r
F P
0 g
s
.841 .72508 m .84006 .74306 L .84076 .73182 L p .705 .576 .707 r
F P
0 g
s
.84076 .73182 m .8417 .71385 L .841 .72508 L p .705 .576 .707 r
F P
0 g
s
.63852 .73223 m .63946 .71425 L .64016 .70302 L p .705 .576 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84352 .6531 m .84297 .68986 L .83514 .68063 L p .707 .577 .707 r
F P
0 g
s
.83514 .68063 m .83569 .64387 L .84352 .6531 L p .707 .577 .707 r
F P
0 g
s
.64402 .62487 m .64323 .56887 L .65745 .56179 L p .707 .577 .707 r
F P
0 g
s
.83755 .56582 m .83834 .62182 L .82353 .6152 L p .707 .577 .707 r
F P
0 g
s
.82353 .6152 m .82275 .5592 L .83755 .56582 L p .707 .577 .707 r
F P
0 g
s
.64016 .70302 m .63922 .721 L .63852 .73223 L p .705 .576 .707 r
F P
0 g
s
.40136 .62171 m .39957 .56639 L .36797 .56601 L p .707 .577 .707 r
F P
0 g
s
.39957 .56639 m .40136 .62171 L .43287 .61928 L p .707 .577 .707 r
F P
0 g
s
.43287 .61928 m .43108 .56395 L .39957 .56639 L p .707 .577 .707 r
F P
0 g
s
.36975 .62133 m .36797 .56601 L .33935 .56284 L p .707 .577 .707 r
F P
0 g
s
.36797 .56601 m .36975 .62133 L .40136 .62171 L p .707 .577 .707 r
F P
0 g
s
.43108 .56395 m .43287 .61928 L .46119 .61425 L p .707 .577 .707 r
F P
0 g
s
.46119 .61425 m .4594 .55893 L .43108 .56395 L p .707 .577 .707 r
F P
0 g
s
.64161 .68316 m .64215 .6464 L .65403 .63783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65745 .56179 m .65824 .61779 L .64402 .62487 L p .707 .577 .707 r
F P
0 g
s
.65403 .63783 m .65349 .67459 L .64161 .68316 L p .707 .577 .707 r
F P
0 g
s
.8417 .71385 m .84076 .73182 L .83156 .72061 L p .707 .577 .707 r
F P
0 g
s
.83156 .72061 m .83251 .70263 L .8417 .71385 L p .707 .577 .707 r
F P
0 g
s
.63922 .721 m .64016 .70302 L .65069 .69287 L p .707 .577 .707 r
F P
0 g
s
.34114 .61816 m .33935 .56284 L .31653 .5572 L p .707 .577 .707 r
F P
0 g
s
.33935 .56284 m .34114 .61816 L .36975 .62133 L p .707 .577 .707 r
F P
0 g
s
.4594 .55893 m .46119 .61425 L .48355 .60714 L p .707 .577 .707 r
F P
0 g
s
.48355 .60714 m .48176 .55182 L .4594 .55893 L p .707 .577 .707 r
F P
0 g
s
.65824 .61779 m .65745 .56179 L .67982 .556 L p .707 .577 .707 r
F P
0 g
s
.83569 .64387 m .83514 .68063 L .81811 .67243 L p .707 .577 .707 r
F P
0 g
s
.81811 .67243 m .81866 .63567 L .83569 .64387 L p .707 .577 .707 r
F P
0 g
s
.82275 .5592 m .82353 .6152 L .8007 .61012 L p .707 .577 .707 r
F P
0 g
s
.8007 .61012 m .79991 .55412 L .82275 .5592 L p .707 .577 .707 r
F P
0 g
s
.40895 .6793 m .41017 .6421 L .37829 .64058 L p .707 .577 .707 r
F P
0 g
s
.41017 .6421 m .40895 .6793 L .43993 .67828 L p .707 .577 .707 r
F P
0 g
s
.43993 .67828 m .44115 .64107 L .41017 .6421 L p .707 .577 .707 r
F P
0 g
s
.37707 .67778 m .37829 .64058 L .34863 .63667 L p .707 .577 .707 r
F P
0 g
s
.37829 .64058 m .37707 .67778 L .40895 .6793 L p .707 .577 .707 r
F P
0 g
s
.65069 .69287 m .64975 .71084 L .63922 .721 L p .707 .577 .707 r
F P
0 g
s
.44115 .64107 m .43993 .67828 L .46697 .67481 L p .707 .577 .707 r
F P
0 g
s
.46697 .67481 m .46819 .63761 L .44115 .64107 L p .707 .577 .707 r
F P
0 g
s
.65349 .67459 m .65403 .63783 L .6745 .63088 L p .707 .577 .707 r
F P
0 g
s
.34863 .63667 m .34741 .67387 L .37707 .67778 L p .707 .577 .707 r
F P
0 g
s
.31653 .5572 m .31832 .61252 L .34114 .61816 L p .707 .577 .707 r
F P
0 g
s
.67982 .556 m .68061 .612 L .65824 .61779 L p .707 .577 .707 r
F P
0 g
s
.34741 .67387 m .34863 .63667 L .32409 .63075 L p .707 .577 .707 r
F P
0 g
s
.37789 .71474 m .37998 .69605 L .34998 .69064 L p .707 .577 .707 r
F P
0 g
s
.37998 .69605 m .37789 .71474 L .40966 .71828 L p .707 .577 .707 r
F P
0 g
s
.40966 .71828 m .41175 .69959 L .37998 .69605 L p .707 .577 .707 r
F P
0 g
s
.41175 .69959 m .40966 .71828 L .4401 .71959 L p .707 .577 .707 r
F P
0 g
s
.4401 .71959 m .44219 .7009 L .41175 .69959 L p .707 .577 .707 r
F P
0 g
s
.31832 .61252 m .31653 .5572 L .30174 .54964 L p .707 .577 .707 r
F P
0 g
s
.48176 .55182 m .48355 .60714 L .49777 .59863 L p .707 .577 .707 r
F P
0 g
s
.49777 .59863 m .49598 .54331 L .48176 .55182 L p .707 .577 .707 r
F P
0 g
s
.34998 .69064 m .3479 .70933 L .37789 .71474 L p .707 .577 .707 r
F P
0 g
s
.68061 .612 m .67982 .556 L .70815 .55207 L p .707 .577 .707 r
F P
0 g
s
.79991 .55412 m .8007 .61012 L .77207 .60708 L p .707 .577 .707 r
F P
0 g
s
.77207 .60708 m .77129 .55108 L .79991 .55412 L p .707 .577 .707 r
F P
0 g
s
.6745 .63088 m .67395 .66764 L .65349 .67459 L p .707 .577 .707 r
F P
0 g
s
.32409 .63075 m .32287 .66795 L .34741 .67387 L p .707 .577 .707 r
F P
0 g
s
.83251 .70263 m .83156 .72061 L .81337 .71051 L p .707 .577 .707 r
F P
0 g
s
.81337 .71051 m .81431 .69254 L .83251 .70263 L p .707 .577 .707 r
F P
0 g
s
.64975 .71084 m .65069 .69287 L .67002 .68478 L p .707 .577 .707 r
F P
0 g
s
.46819 .63761 m .46697 .67481 L .48743 .66925 L p .707 .577 .707 r
F P
0 g
s
.48743 .66925 m .48866 .63205 L .46819 .63761 L p .707 .577 .707 r
F P
0 g
s
.3479 .70933 m .34998 .69064 L .32471 .68388 L p .707 .577 .707 r
F P
0 g
s
.44219 .7009 m .4401 .71959 L .46623 .71855 L p .707 .577 .707 r
F P
0 g
s
.46623 .71855 m .46832 .69986 L .44219 .7009 L p .707 .577 .707 r
F P
0 g
s
.81866 .63567 m .81811 .67243 L .79356 .66607 L p .707 .577 .707 r
F P
0 g
s
.79356 .66607 m .79411 .62931 L .81866 .63567 L p .707 .577 .707 r
F P
0 g
s
.32471 .68388 m .32262 .70257 L .3479 .70933 L p .707 .577 .707 r
F P
0 g
s
.67002 .68478 m .66908 .70276 L .64975 .71084 L p .707 .577 .707 r
F P
0 g
s
.32287 .66795 m .32409 .63075 L .30708 .6234 L p .707 .577 .707 r
F P
0 g
s
.30174 .54964 m .30352 .60496 L .31832 .61252 L p .707 .577 .707 r
F P
0 g
s
.67395 .66764 m .6745 .63088 L .70155 .62623 L p .707 .577 .707 r
F P
0 g
s
.70815 .55207 m .70894 .60807 L .68061 .612 L p .707 .577 .707 r
F P
0 g
s
.70894 .60807 m .70815 .55207 L .73967 .55037 L p .707 .577 .707 r
F P
0 g
s
.77129 .55108 m .77207 .60708 L .74045 .60637 L p .707 .577 .707 r
F P
0 g
s
.74045 .60637 m .73967 .55037 L .77129 .55108 L p .707 .577 .707 r
F P
0 g
s
.73967 .55037 m .74045 .60637 L .70894 .60807 L p .707 .577 .707 r
F P
0 g
s
.30708 .6234 m .30586 .66061 L .32287 .66795 L p .707 .577 .707 r
F P
0 g
s
.32262 .70257 m .32471 .68388 L .30662 .67643 L p .707 .577 .707 r
F P
0 g
s
.46832 .69986 m .46623 .71855 L .48549 .71526 L p .707 .577 .707 r
F P
0 g
s
.48549 .71526 m .48758 .69657 L .46832 .69986 L p .707 .577 .707 r
F P
0 g
s
.30352 .60496 m .30174 .54964 L .29642 .54089 L p .707 .577 .707 r
F P
0 g
s
.79411 .62931 m .79356 .66607 L .76389 .66217 L p .707 .577 .707 r
F P
0 g
s
.76389 .66217 m .76444 .62541 L .79411 .62931 L p .707 .577 .707 r
F P
0 g
s
.49598 .54331 m .49777 .59863 L .50245 .58956 L p .707 .577 .707 r
F P
0 g
s
.50245 .58956 m .50066 .53424 L .49598 .54331 L p .707 .577 .707 r
F P
0 g
s
.70155 .62623 m .70101 .66299 L .67395 .66764 L p .707 .577 .707 r
F P
0 g
s
.30662 .67643 m .30454 .69512 L .32262 .70257 L p .707 .577 .707 r
F P
0 g
s
.81431 .69254 m .81337 .71051 L .78796 .70252 L p .707 .577 .707 r
F P
0 g
s
.78796 .70252 m .7889 .68455 L .81431 .69254 L p .707 .577 .707 r
F P
0 g
s
.66908 .70276 m .67002 .68478 L .69626 .67957 L p .707 .577 .707 r
F P
0 g
s
.48866 .63205 m .48743 .66925 L .49931 .66213 L p .707 .577 .707 r
F P
0 g
s
.49931 .66213 m .50053 .62493 L .48866 .63205 L p .707 .577 .707 r
F P
0 g
s
.70101 .66299 m .70155 .62623 L .73254 .62435 L p .707 .577 .707 r
F P
0 g
s
.69626 .67957 m .69532 .69755 L .66908 .70276 L p .707 .577 .707 r
F P
0 g
s
.76444 .62541 m .76389 .66217 L .73199 .66111 L p .707 .577 .707 r
F P
0 g
s
.73199 .66111 m .73254 .62435 L .76444 .62541 L p .707 .577 .707 r
F P
0 g
s
.73254 .62435 m .73199 .66111 L .70101 .66299 L p .707 .577 .707 r
F P
0 g
s
.30586 .66061 m .30708 .6234 L .29925 .61534 L p .707 .577 .707 r
F P
0 g
s
.29642 .54089 m .29821 .59621 L .30352 .60496 L p .707 .577 .707 r
F P
0 g
s
.7889 .68455 m .78796 .70252 L .75781 .69742 L p .707 .577 .707 r
F P
0 g
s
.75781 .69742 m .75876 .67944 L .7889 .68455 L p .707 .577 .707 r
F P
0 g
s
.69532 .69755 m .69626 .67957 L .72684 .67773 L p .707 .577 .707 r
F P
0 g
s
.29925 .61534 m .29803 .65255 L .30586 .66061 L p .707 .577 .707 r
F P
0 g
s
.30454 .69512 m .30662 .67643 L .29749 .66903 L p .707 .577 .707 r
F P
0 g
s
.48758 .69657 m .48549 .71526 L .496 .71005 L p .707 .577 .707 r
F P
0 g
s
.496 .71005 m .49808 .69135 L .48758 .69657 L p .707 .577 .707 r
F P
0 g
s
.72684 .67773 m .72589 .6957 L .69532 .69755 L p .707 .577 .707 r
F P
0 g
s
.29749 .66903 m .29541 .68772 L .30454 .69512 L p .707 .577 .707 r
F P
0 g
s
.75876 .67944 m .75781 .69742 L .72589 .6957 L p .707 .577 .707 r
F P
0 g
s
.72589 .6957 m .72684 .67773 L .75876 .67944 L p .707 .577 .707 r
F P
0 g
s
.29821 .59621 m .29642 .54089 L .3011 .53182 L p .707 .577 .707 r
F P
0 g
s
.50066 .53424 m .50245 .58956 L .49713 .58082 L p .707 .577 .707 r
F P
0 g
s
.49713 .58082 m .49534 .52549 L .50066 .53424 L p .707 .577 .707 r
F P
0 g
s
.50053 .62493 m .49931 .66213 L .50144 .65415 L p .707 .577 .707 r
F P
0 g
s
.50144 .65415 m .50266 .61695 L .50053 .62493 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29803 .65255 m .29925 .61534 L .30138 .60736 L p .707 .577 .707 r
F P
0 g
s
.3011 .53182 m .30288 .58714 L .29821 .59621 L p .707 .577 .707 r
F P
0 g
s
.30138 .60736 m .30016 .64457 L .29803 .65255 L p .707 .577 .707 r
F P
0 g
s
.29541 .68772 m .29749 .66903 L .29821 .66239 L p .721 .59 .709 r
F P
0 g
s
.49808 .69135 m .496 .71005 L .49673 .70341 L p .721 .59 .709 r
F P
0 g
s
.49673 .70341 m .49881 .68472 L .49808 .69135 L p .721 .59 .709 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29821 .66239 m .29613 .68108 L .29541 .68772 L p .721 .59 .709 r
F P
0 g
s
.30288 .58714 m .3011 .53182 L .31531 .52331 L p .707 .577 .707 r
F P
0 g
s
.49534 .52549 m .49713 .58082 L .48233 .57325 L p .707 .577 .707 r
F P
0 g
s
.48233 .57325 m .48055 .51793 L .49534 .52549 L p .707 .577 .707 r
F P
0 g
s
.50266 .61695 m .50144 .65415 L .49361 .64609 L p .707 .577 .707 r
F P
0 g
s
.49361 .64609 m .49484 .60889 L .50266 .61695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30016 .64457 m .30138 .60736 L .31326 .60024 L p .707 .577 .707 r
F P
0 g
s
.31531 .52331 m .3171 .57863 L .30288 .58714 L p .707 .577 .707 r
F P
0 g
s
.31326 .60024 m .31204 .63745 L .30016 .64457 L p .707 .577 .707 r
F P
0 g
s
.29613 .68108 m .29821 .66239 L .30872 .65717 L p .707 .577 .707 r
F P
0 g
s
.49881 .68472 m .49673 .70341 L .4876 .69601 L p .707 .577 .707 r
F P
0 g
s
.4876 .69601 m .48968 .67732 L .49881 .68472 L p .707 .577 .707 r
F P
0 g
s
.3171 .57863 m .31531 .52331 L .33768 .5162 L p .707 .577 .707 r
F P
0 g
s
.48055 .51793 m .48233 .57325 L .45951 .56761 L p .707 .577 .707 r
F P
0 g
s
.45951 .56761 m .45773 .51229 L .48055 .51793 L p .707 .577 .707 r
F P
0 g
s
.30872 .65717 m .30664 .67587 L .29613 .68108 L p .707 .577 .707 r
F P
0 g
s
.49484 .60889 m .49361 .64609 L .4766 .63874 L p .707 .577 .707 r
F P
0 g
s
.4766 .63874 m .47782 .60154 L .49484 .60889 L p .707 .577 .707 r
F P
0 g
s
.31204 .63745 m .31326 .60024 L .33372 .59468 L p .707 .577 .707 r
F P
0 g
s
.33768 .5162 m .33946 .57152 L .3171 .57863 L p .707 .577 .707 r
F P
0 g
s
.33946 .57152 m .33768 .5162 L .366 .51118 L p .707 .577 .707 r
F P
0 g
s
.45773 .51229 m .45951 .56761 L .4309 .56444 L p .707 .577 .707 r
F P
0 g
s
.4309 .56444 m .42911 .50912 L .45773 .51229 L p .707 .577 .707 r
F P
0 g
s
.33372 .59468 m .3325 .63188 L .31204 .63745 L p .707 .577 .707 r
F P
0 g
s
.30664 .67587 m .30872 .65717 L .32798 .65388 L p .707 .577 .707 r
F P
0 g
s
.48968 .67732 m .4876 .69601 L .46951 .68856 L p .707 .577 .707 r
F P
0 g
s
.46951 .68856 m .47159 .66987 L .48968 .67732 L p .707 .577 .707 r
F P
0 g
s
.32798 .65388 m .3259 .67258 L .30664 .67587 L p .707 .577 .707 r
F P
0 g
s
.47782 .60154 m .4766 .63874 L .45206 .63283 L p .707 .577 .707 r
F P
0 g
s
.45206 .63283 m .45328 .59562 L .47782 .60154 L p .707 .577 .707 r
F P
0 g
s
.36778 .5665 m .366 .51118 L .3975 .50874 L p .707 .577 .707 r
F P
0 g
s
.366 .51118 m .36778 .5665 L .33946 .57152 L p .707 .577 .707 r
F P
0 g
s
.42911 .50912 m .4309 .56444 L .39929 .56406 L p .707 .577 .707 r
F P
0 g
s
.39929 .56406 m .3975 .50874 L .42911 .50912 L p .707 .577 .707 r
F P
0 g
s
.3325 .63188 m .33372 .59468 L .36076 .59122 L p .707 .577 .707 r
F P
0 g
s
.3975 .50874 m .39929 .56406 L .36778 .5665 L p .707 .577 .707 r
F P
0 g
s
.36076 .59122 m .35954 .62842 L .3325 .63188 L p .707 .577 .707 r
F P
0 g
s
.45328 .59562 m .45206 .63283 L .4224 .62892 L p .707 .577 .707 r
F P
0 g
s
.4224 .62892 m .42362 .59171 L .45328 .59562 L p .707 .577 .707 r
F P
0 g
s
.3259 .67258 m .32798 .65388 L .35411 .65284 L p .707 .577 .707 r
F P
0 g
s
.47159 .66987 m .46951 .68856 L .44423 .6818 L p .707 .577 .707 r
F P
0 g
s
.44423 .6818 m .44632 .66311 L .47159 .66987 L p .707 .577 .707 r
F P
0 g
s
.35411 .65284 m .35203 .67154 L .3259 .67258 L p .707 .577 .707 r
F P
0 g
s
.35954 .62842 m .36076 .59122 L .39174 .5902 L p .707 .577 .707 r
F P
0 g
s
.42362 .59171 m .4224 .62892 L .39052 .6274 L p .707 .577 .707 r
F P
0 g
s
.39052 .6274 m .39174 .5902 L .42362 .59171 L p .707 .577 .707 r
F P
0 g
s
.39174 .5902 m .39052 .6274 L .35954 .62842 L p .707 .577 .707 r
F P
0 g
s
.35203 .67154 m .35411 .65284 L .38455 .65416 L p .707 .577 .707 r
F P
0 g
s
.44632 .66311 m .44423 .6818 L .41424 .67639 L p .707 .577 .707 r
F P
0 g
s
.41424 .67639 m .41632 .65769 L .44632 .66311 L p .707 .577 .707 r
F P
0 g
s
.38455 .65416 m .38247 .67285 L .35203 .67154 L p .707 .577 .707 r
F P
0 g
s
.38247 .67285 m .38455 .65416 L .41632 .65769 L p .707 .577 .707 r
F P
0 g
s
.41632 .65769 m .41424 .67639 L .38247 .67285 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`T000=JEP03001JEUYF00IJEP03001JEUYF009J
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GWoo1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001KOol300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00F7oo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00H005YFFUIJEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005Woo4@00?Woo001DOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00003Woo200015YF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00E7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000Ioo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008003Eoo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0035o
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002ioo`00E7oo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4@0015YF00@005YFFUIJEPH000EJEP04001JEUYFFUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00Oomoo`0/Ool005Aoo`03001JEP0000=JEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEPD0
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00
E7oo00<005YF00000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol00`00FUH00003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUH00000FUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01000FUH005YF0P001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000]Ool005Aoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00T000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001D
Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH00`00FUIJEP02FUH80007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<005YF00001P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH005YF00AJEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00?Goo5`0000=oo`0000000UYF0`000UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000eYF00L005YFFUIJ
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000gOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH400000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YF
FUIJEP8002eoo`00<Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF0P00;Goo000_Ool20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH0000002eoo`00;Woo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002eoo`00;Goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH04@001eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP03001JEUYF009JEPH0009JEP03001JEP0000EJEPH000AJEP03001JEUYF009JEPH0
00EJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<0
05YF00000P0000=JEP0000000P000eYF00<005YF00001EYF1P0015YF00<005YFFUH025YF100000=J
EP00FUH00eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001oogoo02aoo`00;7oo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP80009JEP03
001JEUYF00=JEPH000EJEPH000AJEP03001JEUYF00QJEPL000=JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00Oomoo`0/
Ool002aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<000AJEP03001JEUYF00AJEP04001JEUYFFUHK0003FUH01000FUIJEUYF
0P0000=JEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH>0002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEQh0009JEP03001JEUYF00AJEP03
001JEUYF009JEPT0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF1P000UYF6@001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH015YF00<005YF
FUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`8000=JEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00=JEPD000IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;7oo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF
00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF000010001EYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF1P000UYF00<007ooOol027oo0`002Goo1P00
1EYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool200001EYF000005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00@005YFFUIJEP8000Qoo`D000ioo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH03@0000=JEP0000001`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEPD0
00AJEP04001JEUYFFUH20008Ool5000BOol30003FUH00`00FUH0000]Ool002aoo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH400000eYF
001JEP04FUH01P00FUIJEUYF001JEPT00003FUH0000000L000AJEP03001JEUYF00EJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUH000040003FUH20002Ool;000?Ool30003FUH2000015YF001JEP00;Goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH4
00000eYF001JEP030005FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000T00003FUH0000000@0
00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@000=JEP03001JEUYF00=JEPP000AJEP03001JEUYF009JEPT000Aoo`@00003FUH0
05YF00AJEP<00003FUH007oo02aoo`00;7oo0P0015YF00<005YFFUH00eYF00@005YFFUIJEQP000=J
EP04001JEUYFFUH30003FUH01`00FUIJEUYF001JEP0000EJEPH000AJEP03001JEUYF00IJEP@00003
FUH005YF00AJEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30004FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000AJEP03001JEUYF00=JEP@00003
FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003
0003FUH00`00FUH00005FUH60004FUH00`00FUIJEP08FUH00`00FUH000020003FUH01P00FUIJEP00
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
008002eoo`00;Goo00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF1P001EYF1P0015YF00<005YFFUH025YF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02000]Ool002eoo`800003FUH0
00000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00EJEP03001JEUYF009JEPX000EJEP03001JEUYF00QJEP03001JEUYF00AJEP80
009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000AJEP03
001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP<00005FUH0
05YFFUH0000^Ool002moo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000UJEP03001J
EUYF00=JEP@00004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
0005FUH01000FUIJEUYF20000UYF00<005YFFUH015YF200015YF00<005YFFUH01EYF00<005YFFUH0
0P000UYF00<007ooOol0;7oo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF3`000UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1P001UYF00<005YFFUH00UYF0P00;goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P00;goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00eYF00<0
05YF0000;Woo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUH000030000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH01000FUIJ
EP00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP070004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF1P0015YF00<0
05YFFUH00UYF0`0000=JEP00FUH01eYF00@005YFFUIJEPD0009oo`800005FUH005YFFUH0000]Ool0
02aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00AJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF01P000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP04001JEUYFFUH@0004FUH80009
Ool20002FUH00`00Oomoo`0[Ool002aoo`80009JEP03001JEUYF00=JEP03001JEUYF009JEPP000Eo
o`<000Uoo`P000=JEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEP00FUH005YF10000eYF00@005YFFUIJEP8000Qoo`X0019oo`04001JEP00000]Ool0
02aoo`80009JEP03001JEUYF009JEPH000aoo`D000eoo`P000=JEP800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF008000EJEP800003FUH005YF009JEP8000Qoo`D001Qo
o`<002eoo`00;7oo0P000UYF00<005YF00000P000UYF1`002Goo1@001Goo20000eYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00<000EJ
EP<000=JEP03001oogoo00Qoo`<001Uoo`<002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00@0
05YFFUIJEQ<000=JEP03001JEUYF00EJEP03001JEUYF00=JEP@00003FUH005YF00AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP04001JEUYF0002FUH20003FUH00`00FUIJEP0200000eYF001oo`0UOol3
000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF0`0097oo0P0000=JEP00Ool0
;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP000004FUH00`00FUH0000300001EYF001JEUYF000087oo0`0000AJEP00FUH0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH=0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH00eYF1P006Woo1@0015YF00<005YF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00=JEP`000=JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP02FUH0
0`00FUH0000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEQh0009JEP06001JEUYF
001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
0eYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF001JEP00FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002ioo`80
00=JEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000D00003FUH005YF00AJEP03001JEUYF00D000]JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEPH000IJEP03001JEUYF009JEP05001JEP00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000`
Ool200000eYF000000050003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH015YF0`0015YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00<0
05YF00001@000UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YF000003=oo`00<Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000=JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<0
00AJEP03001JEP0000Eoo`D00003FUH0000000@000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPD003Eoo`00<7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00H005YF001JEP00FUH200000eYF
001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP020002FUH00`00FUH00004Ool30003FUH200001EYF001JEP00Ool02@00
15YF00<005YFFUH00UYF2000>Woo000^Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0003
FUH00`00FUIJEP03FUH200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF
0000000300000eYF001JEP04FUH300000eYF001oo`09Ool90012Ool002eoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH60006Ool3000@Ool60003FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF0000000300000eYF001JEP04FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0004FUH0
0`00FUIJEP04000;Ool5000COol80005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF0000
0003FUH50002FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0002FUH5000?Ool5000>Ool50004
FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P001UYF00<005YF
00000P000UYF0P00EGoo000]Ool00`00FUIJEP03000DOol50006Ool80003FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJ
EP02FUH3001FOol002eoo`<0009JEPh000Qoo`X000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF
009JEP8005Ioo`00;Goo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000H000=JEP03001JEUYF009JEP03001JEP0005Eoo`00;Goo00<005YF000015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`000Woo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`001UYF1@000eYF
00<005YF0000EGoo000]Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2000015YF001JEP00EGoo000^Ool40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2
00000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF00000P000Woo0P00
00=JEP00Ool0E7oo000bOol70003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
000BOol30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH0000015YF00@005YFFUIJEPD000Moo`03001JEP0005Aoo`00>Goo6@00
77oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF10000UYF20002goo00@005YF000005Aoo`00L7oo0`0000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02`004goo00@005YF000005Aoo`00
Lgoo10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1@000Woo1@005Goo0P00
0eYF00<007ooOol0DWoo001gOol60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06
0007Ool5000COol200000eYF001JEP02FUH00`00Oomoo`1BOol007eooal000eoo`D0011oo`<000=J
EP05001JEUYFFUH0001DOol008ioo`<001Uoo`<000moo`800003FUH005YF00AJEP03001JEP0005Eo
o`00SWoo0P0000=JEP0000009Woo0`000eYF00<005YFFUH00eYF0P00EWoo002?Ool01000FUH005YF
0P0087oo10001UYF00<005YFFUH00eYF00<007ooOol0EGoo002?Ool00`00FUH00003FUH5000GOol4
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P00F7oo002?Ool00`00FUH00004FUH01000FUIJEUYF
1`002Goo1`001UYF00<005YFFUH01EYF00@005YF000005Yoo`00T7oo0P0015YF00<005YFFUH015YF
00@005YFFUIJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP<005aoo`00T7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00Ggoo
002AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
001SOol009=oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06Moo`00UGoo1@000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Jgoo002JOolA001bOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60352 .74787 m .60643 .69198 L .57467 .68965 L p .707 .577 .707 r
F P
0 g
s
.60643 .69198 m .60352 .74787 L .63471 .74775 L p .707 .577 .707 r
F P
0 g
s
.63471 .74775 m .63763 .69186 L .60643 .69198 L p .707 .577 .707 r
F P
0 g
s
.57175 .74554 m .57467 .68965 L .54543 .68508 L p .707 .577 .707 r
F P
0 g
s
.57467 .68965 m .57175 .74554 L .60352 .74787 L p .707 .577 .707 r
F P
0 g
s
.63763 .69186 m .63471 .74775 L .66228 .74517 L p .707 .577 .707 r
F P
0 g
s
.66228 .74517 m .6652 .68928 L .63763 .69186 L p .707 .577 .707 r
F P
0 g
s
.54252 .74097 m .54543 .68508 L .5216 .67873 L p .707 .577 .707 r
F P
0 g
s
.54543 .68508 m .54252 .74097 L .57175 .74554 L p .707 .577 .707 r
F P
0 g
s
.58574 .81373 m .58374 .77706 L .55309 .77592 L p .707 .577 .707 r
F P
0 g
s
.58374 .77706 m .58574 .81373 L .61765 .81185 L p .707 .577 .707 r
F P
0 g
s
.61765 .81185 m .61565 .77518 L .58374 .77706 L p .707 .577 .707 r
F P
0 g
s
.61565 .77518 m .61765 .81185 L .6477 .80715 L p .707 .577 .707 r
F P
0 g
s
.6477 .80715 m .6457 .77048 L .61565 .77518 L p .707 .577 .707 r
F P
0 g
s
.6652 .68928 m .66228 .74517 L .68352 .7404 L p .707 .577 .707 r
F P
0 g
s
.68352 .7404 m .68644 .68451 L .6652 .68928 L p .707 .577 .707 r
F P
0 g
s
.5216 .67873 m .51868 .73462 L .54252 .74097 L p .707 .577 .707 r
F P
0 g
s
.55509 .81259 m .55309 .77592 L .52671 .77187 L p .707 .577 .707 r
F P
0 g
s
.55309 .77592 m .55509 .81259 L .58574 .81373 L p .707 .577 .707 r
F P
0 g
s
.6457 .77048 m .6477 .80715 L .67294 .80007 L p .707 .577 .707 r
F P
0 g
s
.67294 .80007 m .67094 .7634 L .6457 .77048 L p .707 .577 .707 r
F P
0 g
s
.51868 .73462 m .5216 .67873 L .5055 .67121 L p .707 .577 .707 r
F P
0 g
s
.52671 .77187 m .52871 .80854 L .55509 .81259 L p .707 .577 .707 r
F P
0 g
s
.59915 .86307 m .59576 .84553 L .56499 .84812 L p .707 .577 .707 r
F P
0 g
s
.59576 .84553 m .59915 .86307 L .63045 .85664 L p .707 .577 .707 r
F P
0 g
s
.63045 .85664 m .62706 .83909 L .59576 .84553 L p .707 .577 .707 r
F P
0 g
s
.62706 .83909 m .63045 .85664 L .65921 .84699 L p .707 .577 .707 r
F P
0 g
s
.65921 .84699 m .65582 .82945 L .62706 .83909 L p .707 .577 .707 r
F P
0 g
s
.68644 .68451 m .68352 .7404 L .69636 .7339 L p .707 .577 .707 r
F P
0 g
s
.69636 .7339 m .69928 .67801 L .68644 .68451 L p .707 .577 .707 r
F P
0 g
s
.52871 .80854 m .52671 .77187 L .50717 .76532 L p .707 .577 .707 r
F P
0 g
s
.5055 .67121 m .50258 .7271 L .51868 .73462 L p .707 .577 .707 r
F P
0 g
s
.56499 .84812 m .56838 .86567 L .59915 .86307 L p .707 .577 .707 r
F P
0 g
s
.67094 .7634 m .67294 .80007 L .69092 .79131 L p .707 .577 .707 r
F P
0 g
s
.69092 .79131 m .68892 .75464 L .67094 .7634 L p .707 .577 .707 r
F P
0 g
s
.56838 .86567 m .56499 .84812 L .53777 .84662 L p .707 .577 .707 r
F P
0 g
s
.65582 .82945 m .65921 .84699 L .68263 .83508 L p .707 .577 .707 r
F P
0 g
s
.68263 .83508 m .67924 .81754 L .65582 .82945 L p .707 .577 .707 r
F P
0 g
s
.53777 .84662 m .54116 .86417 L .56838 .86567 L p .707 .577 .707 r
F P
0 g
s
.50717 .76532 m .50917 .80199 L .52871 .80854 L p .707 .577 .707 r
F P
0 g
s
.50258 .7271 m .5055 .67121 L .4987 .66327 L p .707 .577 .707 r
F P
0 g
s
.54116 .86417 m .53777 .84662 L .51675 .84118 L p .707 .577 .707 r
F P
0 g
s
.67924 .81754 m .68263 .83508 L .69841 .82207 L p .707 .577 .707 r
F P
0 g
s
.69841 .82207 m .69502 .80453 L .67924 .81754 L p .707 .577 .707 r
F P
0 g
s
.50917 .80199 m .50717 .76532 L .49639 .75689 L p .707 .577 .707 r
F P
0 g
s
.69928 .67801 m .69636 .7339 L .69954 .7263 L p .707 .577 .707 r
F P
0 g
s
.69954 .7263 m .70245 .67041 L .69928 .67801 L p .707 .577 .707 r
F P
0 g
s
.51675 .84118 m .52014 .85872 L .54116 .86417 L p .707 .577 .707 r
F P
0 g
s
.4987 .66327 m .49579 .71915 L .50258 .7271 L p .707 .577 .707 r
F P
0 g
s
.68892 .75464 m .69092 .79131 L .69986 .78173 L p .707 .577 .707 r
F P
0 g
s
.69986 .78173 m .69786 .74506 L .68892 .75464 L p .707 .577 .707 r
F P
0 g
s
.49639 .75689 m .49839 .79357 L .50917 .80199 L p .707 .577 .707 r
F P
0 g
s
.52014 .85872 m .51675 .84118 L .504 .83232 L p .707 .577 .707 r
F P
0 g
s
.49579 .71915 m .4987 .66327 L .50188 .65567 L p .707 .577 .707 r
F P
0 g
s
.69502 .80453 m .69841 .82207 L .705 .80924 L p .707 .577 .707 r
F P
0 g
s
.705 .80924 m .70161 .79169 L .69502 .80453 L p .707 .577 .707 r
F P
0 g
s
.504 .83232 m .50739 .84987 L .52014 .85872 L p .707 .577 .707 r
F P
0 g
s
.49839 .79357 m .49639 .75689 L .49543 .74743 L p .708 .578 .707 r
F P
0 g
s
.50188 .65567 m .49896 .71156 L .49579 .71915 L p .707 .577 .707 r
F P
0 g
s
.49543 .74743 m .49743 .7841 L .49839 .79357 L p .708 .578 .707 r
F P
0 g
s
.49743 .7841 m .49543 .74743 L .50437 .73785 L p .707 .577 .707 r
F P
0 g
s
.49723 .82192 m .49723 .32003 L .4528 .3179 L p .707 .577 .707 r
F P
0 g
s
.50739 .84987 m .504 .83232 L .50076 .82092 L p .707 .577 .707 r
F P
0 g
s
.49896 .71156 m .50188 .65567 L .51472 .64917 L p .707 .577 .707 r
F P
0 g
s
.50076 .82092 m .50415 .83846 L .50739 .84987 L p .707 .577 .707 r
F P
0 g
s
.51472 .64917 m .5118 .70506 L .49896 .71156 L p .707 .577 .707 r
F P
0 g
s
.50437 .73785 m .50637 .77452 L .49743 .7841 L p .707 .577 .707 r
F P
0 g
s
.50415 .83846 m .50076 .82092 L .50735 .80808 L p .707 .577 .707 r
F P
0 g
s
.5118 .70506 m .51472 .64917 L .53596 .6444 L p .707 .577 .707 r
F P
0 g
s
.50735 .80808 m .51075 .82562 L .50415 .83846 L p .707 .577 .707 r
F P
0 g
s
.50637 .77452 m .50437 .73785 L .52234 .72909 L p .707 .577 .707 r
F P
0 g
s
.53596 .6444 m .53304 .70028 L .5118 .70506 L p .707 .577 .707 r
F P
0 g
s
.52234 .72909 m .52434 .76576 L .50637 .77452 L p .707 .577 .707 r
F P
0 g
s
.51075 .82562 m .50735 .80808 L .52313 .79507 L p .707 .577 .707 r
F P
0 g
s
.52313 .79507 m .52652 .81261 L .51075 .82562 L p .707 .577 .707 r
F P
0 g
s
.52434 .76576 m .52234 .72909 L .54759 .72201 L p .707 .577 .707 r
F P
0 g
s
.54759 .72201 m .54959 .75868 L .52434 .76576 L p .707 .577 .707 r
F P
0 g
s
.52652 .81261 m .52313 .79507 L .54655 .78316 L p .707 .577 .707 r
F P
0 g
s
.54655 .78316 m .54994 .8007 L .52652 .81261 L p .707 .577 .707 r
F P
0 g
s
.49723 .32003 m .49723 .82192 L .54194 .82025 L p .707 .577 .707 r
F P
0 g
s
.53304 .70028 m .53596 .6444 L .56353 .64182 L p .707 .577 .707 r
F P
0 g
s
.56353 .64182 m .56061 .69771 L .53304 .70028 L p .707 .577 .707 r
F P
0 g
s
.54194 .82025 m .54194 .31836 L .49723 .32003 L p .707 .577 .707 r
F P
0 g
s
.69786 .74506 m .69986 .78173 L .69889 .77226 L p .708 .578 .707 r
F P
0 g
s
.69889 .77226 m .69689 .73559 L .69786 .74506 L p .708 .578 .707 r
F P
0 g
s
.70245 .67041 m .69954 .7263 L .69274 .71836 L p .707 .577 .707 r
F P
0 g
s
.69274 .71836 m .69566 .66247 L .70245 .67041 L p .707 .577 .707 r
F P
0 g
s
.56061 .69771 m .56353 .64182 L .59472 .6417 L p .707 .577 .707 r
F P
0 g
s
.59472 .6417 m .59181 .69758 L .56061 .69771 L p .707 .577 .707 r
F P
0 g
s
.54959 .75868 m .54759 .72201 L .57764 .7173 L p .707 .577 .707 r
F P
0 g
s
.57764 .7173 m .57964 .75398 L .54959 .75868 L p .707 .577 .707 r
F P
0 g
s
.54994 .8007 m .54655 .78316 L .57531 .77352 L p .707 .577 .707 r
F P
0 g
s
.57531 .77352 m .57871 .79106 L .54994 .8007 L p .707 .577 .707 r
F P
0 g
s
.57871 .79106 m .57531 .77352 L .60661 .76708 L p .707 .577 .707 r
F P
0 g
s
.60661 .76708 m .61001 .78463 L .57871 .79106 L p .707 .577 .707 r
F P
0 g
s
.54194 .31836 m .54194 .82025 L .58253 .81496 L p .707 .577 .707 r
F P
0 g
s
.57964 .75398 m .57764 .7173 L .60955 .71543 L p .707 .577 .707 r
F P
0 g
s
.60955 .71543 m .61155 .7521 L .57964 .75398 L p .707 .577 .707 r
F P
0 g
s
.58253 .81496 m .58253 .31307 L .54194 .31836 L p .707 .577 .707 r
F P
0 g
s
.4528 .81979 m .4528 .3179 L .41299 .3122 L p .707 .577 .707 r
F P
0 g
s
.4528 .3179 m .4528 .81979 L .49723 .82192 L p .707 .577 .707 r
F P
0 g
s
.70161 .79169 m .705 .80924 L .70176 .79783 L p .707 .577 .707 r
F P
0 g
s
.70176 .79783 m .69837 .78029 L .70161 .79169 L p .707 .577 .707 r
F P
0 g
s
.62649 .64403 m .62357 .69992 L .59181 .69758 L p .707 .577 .707 r
F P
0 g
s
.59181 .69758 m .59472 .6417 L .62649 .64403 L p .707 .577 .707 r
F P
0 g
s
.63738 .76449 m .64077 .78203 L .61001 .78463 L p .707 .577 .707 r
F P
0 g
s
.61001 .78463 m .60661 .76708 L .63738 .76449 L p .707 .577 .707 r
F P
0 g
s
.58253 .31307 m .58253 .81496 L .61505 .80656 L p .707 .577 .707 r
F P
0 g
s
.64019 .71657 m .64219 .75324 L .61155 .7521 L p .707 .577 .707 r
F P
0 g
s
.61155 .7521 m .60955 .71543 L .64019 .71657 L p .707 .577 .707 r
F P
0 g
s
.61505 .80656 m .61505 .30468 L .58253 .31307 L p .707 .577 .707 r
F P
0 g
s
.41299 .81409 m .41299 .3122 L .3817 .30348 L p .707 .577 .707 r
F P
0 g
s
.41299 .3122 m .41299 .81409 L .4528 .81979 L p .707 .577 .707 r
F P
0 g
s
.69689 .73559 m .69889 .77226 L .68811 .76384 L p .707 .577 .707 r
F P
0 g
s
.68811 .76384 m .68611 .72717 L .69689 .73559 L p .707 .577 .707 r
F P
0 g
s
.69566 .66247 m .69274 .71836 L .67664 .71084 L p .707 .577 .707 r
F P
0 g
s
.67664 .71084 m .67956 .65495 L .69566 .66247 L p .707 .577 .707 r
F P
0 g
s
.26351 .71579 m .26481 .66097 L .23301 .6593 L p .707 .577 .707 r
F P
0 g
s
.26481 .66097 m .26351 .71579 L .29474 .71434 L p .707 .577 .707 r
F P
0 g
s
.29474 .71434 m .29603 .65952 L .26481 .66097 L p .707 .577 .707 r
F P
0 g
s
.23171 .71412 m .23301 .6593 L .20374 .65468 L p .707 .577 .707 r
F P
0 g
s
.23301 .6593 m .23171 .71412 L .26351 .71579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29603 .65952 m .29474 .71434 L .32233 .70991 L p .707 .577 .707 r
F P
0 g
s
.32233 .70991 m .32363 .65509 L .29603 .65952 L p .707 .577 .707 r
F P
0 g
s
.20245 .7095 m .20374 .65468 L .17988 .64755 L p .707 .577 .707 r
F P
0 g
s
.20374 .65468 m .20245 .7095 L .23171 .71412 L p .707 .577 .707 r
F P
0 g
s
.69837 .78029 m .70176 .79783 L .68901 .78897 L p .707 .577 .707 r
F P
0 g
s
.68901 .78897 m .68562 .77143 L .69837 .78029 L p .707 .577 .707 r
F P
0 g
s
.65572 .6486 m .6528 .70449 L .62357 .69992 L p .707 .577 .707 r
F P
0 g
s
.62357 .69992 m .62649 .64403 L .65572 .6486 L p .707 .577 .707 r
F P
0 g
s
.61505 .30468 m .61505 .80656 L .6363 .79588 L p .707 .577 .707 r
F P
0 g
s
.6363 .79588 m .6363 .29399 L .61505 .30468 L p .707 .577 .707 r
F P
0 g
s
.32363 .65509 m .32233 .70991 L .34359 .70294 L p .707 .577 .707 r
F P
0 g
s
.34359 .70294 m .34488 .64812 L .32363 .65509 L p .707 .577 .707 r
F P
0 g
s
.24519 .768 m .24428 .73057 L .2136 .72923 L p .707 .577 .707 r
F P
0 g
s
.24428 .73057 m .24519 .768 L .27713 .76704 L p .707 .577 .707 r
F P
0 g
s
.27713 .76704 m .27622 .72962 L .24428 .73057 L p .707 .577 .707 r
F P
0 g
s
.27622 .72962 m .27713 .76704 L .30721 .76387 L p .707 .577 .707 r
F P
0 g
s
.30721 .76387 m .3063 .72644 L .27622 .72962 L p .707 .577 .707 r
F P
0 g
s
.3817 .80536 m .3817 .30348 L .36198 .29258 L p .707 .577 .707 r
F P
0 g
s
.3817 .30348 m .3817 .80536 L .41299 .81409 L p .707 .577 .707 r
F P
0 g
s
.67956 .65495 m .67664 .71084 L .6528 .70449 L p .707 .577 .707 r
F P
0 g
s
.6528 .70449 m .65572 .6486 L .67956 .65495 L p .707 .577 .707 r
F P
0 g
s
.68611 .72717 m .68811 .76384 L .66858 .75729 L p .707 .577 .707 r
F P
0 g
s
.66858 .75729 m .66658 .72062 L .68611 .72717 L p .707 .577 .707 r
F P
0 g
s
.2136 .72923 m .21451 .76666 L .24519 .768 L p .707 .577 .707 r
F P
0 g
s
.21451 .76666 m .2136 .72923 L .18719 .72571 L p .707 .577 .707 r
F P
0 g
s
.17988 .64755 m .17858 .70237 L .20245 .7095 L p .707 .577 .707 r
F P
0 g
s
.25524 .80286 m .25368 .78389 L .22252 .78544 L p .707 .577 .707 r
F P
0 g
s
.25368 .78389 m .25524 .80286 L .28693 .79982 L p .707 .577 .707 r
F P
0 g
s
.28693 .79982 m .28536 .78085 L .25368 .78389 L p .707 .577 .707 r
F P
0 g
s
.3063 .72644 m .30721 .76387 L .33248 .7588 L p .707 .577 .707 r
F P
0 g
s
.33248 .7588 m .33157 .72137 L .3063 .72644 L p .707 .577 .707 r
F P
0 g
s
.17858 .70237 m .17988 .64755 L .16375 .63862 L p .707 .577 .707 r
F P
0 g
s
.22252 .78544 m .22408 .80441 L .25524 .80286 L p .707 .577 .707 r
F P
0 g
s
.28536 .78085 m .28693 .79982 L .31605 .79561 L p .707 .577 .707 r
F P
0 g
s
.31605 .79561 m .31448 .77664 L .28536 .78085 L p .707 .577 .707 r
F P
0 g
s
.22408 .80441 m .22252 .78544 L .19494 .78536 L p .707 .577 .707 r
F P
0 g
s
.18719 .72571 m .1881 .76314 L .21451 .76666 L p .707 .577 .707 r
F P
0 g
s
.19494 .78536 m .1965 .80433 L .22408 .80441 L p .707 .577 .707 r
F P
0 g
s
.34488 .64812 m .34359 .70294 L .35643 .69411 L p .707 .577 .707 r
F P
0 g
s
.35643 .69411 m .35773 .63929 L .34488 .64812 L p .707 .577 .707 r
F P
0 g
s
.68562 .77143 m .68901 .78897 L .668 .78353 L p .707 .577 .707 r
F P
0 g
s
.668 .78353 m .6646 .76598 L .68562 .77143 L p .707 .577 .707 r
F P
0 g
s
.31448 .77664 m .31605 .79561 L .33975 .79062 L p .707 .577 .707 r
F P
0 g
s
.33975 .79062 m .33818 .77165 L .31448 .77664 L p .707 .577 .707 r
F P
0 g
s
.1881 .76314 m .18719 .72571 L .16762 .72037 L p .707 .577 .707 r
F P
0 g
s
.66658 .72062 m .66858 .75729 L .64219 .75324 L p .707 .577 .707 r
F P
0 g
s
.64219 .75324 m .64019 .71657 L .66658 .72062 L p .707 .577 .707 r
F P
0 g
s
.16375 .63862 m .16245 .69344 L .17858 .70237 L p .707 .577 .707 r
F P
0 g
s
.33157 .72137 m .33248 .7588 L .35047 .75233 L p .707 .577 .707 r
F P
0 g
s
.35047 .75233 m .34956 .7149 L .33157 .72137 L p .707 .577 .707 r
F P
0 g
s
.1965 .80433 m .19494 .78536 L .17364 .78366 L p .707 .577 .707 r
F P
0 g
s
.6646 .76598 m .668 .78353 L .64077 .78203 L p .707 .577 .707 r
F P
0 g
s
.64077 .78203 m .63738 .76449 L .6646 .76598 L p .707 .577 .707 r
F P
0 g
s
.6363 .29399 m .6363 .79588 L .64422 .78396 L p .707 .577 .707 r
F P
0 g
s
.64422 .78396 m .64422 .28207 L .6363 .29399 L p .707 .577 .707 r
F P
0 g
s
.16762 .72037 m .16853 .7578 L .1881 .76314 L p .707 .577 .707 r
F P
0 g
s
.17364 .78366 m .17521 .80263 L .1965 .80433 L p .707 .577 .707 r
F P
0 g
s
.16245 .69344 m .16375 .63862 L .15694 .62876 L p .707 .577 .707 r
F P
0 g
s
.3596 .68428 m .3609 .62946 L .35773 .63929 L p .707 .577 .707 r
F P
0 g
s
.35414 .76638 m .3557 .78535 L .36236 .78031 L p .707 .577 .707 r
F P
0 g
s
.36236 .78031 m .36079 .76135 L .35414 .76638 L p .707 .577 .707 r
F P
0 g
s
.35773 .63929 m .35643 .69411 L .3596 .68428 L p .707 .577 .707 r
F P
0 g
s
.3609 .62946 m .3596 .68428 L .35279 .67442 L p .707 .577 .707 r
F P
0 g
s
.35279 .67442 m .35409 .6196 L .3609 .62946 L p .707 .577 .707 r
F P
0 g
s
.36079 .76135 m .36236 .78031 L .35906 .77601 L p .707 .577 .707 r
F P
0 g
s
.36198 .79447 m .36198 .29258 L .35578 .28059 L p .707 .577 .707 r
F P
0 g
s
.36198 .29258 m .36198 .79447 L .3817 .80536 L p .707 .577 .707 r
F P
0 g
s
.33818 .77165 m .33975 .79062 L .3557 .78535 L p .707 .577 .707 r
F P
0 g
s
.3557 .78535 m .35414 .76638 L .33818 .77165 L p .707 .577 .707 r
F P
0 g
s
.16853 .7578 m .16762 .72037 L .15683 .71372 L p .707 .577 .707 r
F P
0 g
s
.15694 .62876 m .15564 .68358 L .16245 .69344 L p .707 .577 .707 r
F P
0 g
s
.34956 .7149 m .35047 .75233 L .35942 .74509 L p .707 .577 .707 r
F P
0 g
s
.35942 .74509 m .35851 .70766 L .34956 .7149 L p .707 .577 .707 r
F P
0 g
s
.17521 .80263 m .17364 .78366 L .16071 .7805 L p .707 .577 .707 r
F P
0 g
s
.16071 .7805 m .16227 .79947 L .17521 .80263 L p .707 .577 .707 r
F P
0 g
s
.15683 .71372 m .15774 .75115 L .16853 .7578 L p .707 .577 .707 r
F P
0 g
s
.15564 .68358 m .15694 .62876 L .16011 .61893 L p .707 .577 .707 r
F P
0 g
s
.64422 .28207 m .64422 .78396 L .63801 .77197 L p .707 .577 .707 r
F P
0 g
s
.63801 .77197 m .63801 .27008 L .64422 .28207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15774 .75115 m .15683 .71372 L .15586 .70641 L p .707 .578 .707 r
F P
0 g
s
.35851 .70766 m .35942 .74509 L .35845 .73778 L p .707 .578 .707 r
F P
0 g
s
.35845 .73778 m .35754 .70035 L .35851 .70766 L p .707 .578 .707 r
F P
0 g
s
.35906 .77601 m .35749 .75704 L .36079 .76135 L p .707 .577 .707 r
F P
0 g
s
.35754 .70035 m .35845 .73778 L .34765 .73113 L p .707 .577 .707 r
F P
0 g
s
.34765 .73113 m .34674 .6937 L .35754 .70035 L p .707 .577 .707 r
F P
0 g
s
.35749 .75704 m .35906 .77601 L .34612 .77285 L p .707 .577 .707 r
F P
0 g
s
.34612 .77285 m .34456 .75388 L .35749 .75704 L p .707 .577 .707 r
F P
0 g
s
.35578 .28059 m .35578 .78248 L .36198 .79447 L p .707 .577 .707 r
F P
0 g
s
.35578 .78248 m .35578 .28059 L .36369 .26867 L p .707 .577 .707 r
F P
0 g
s
.16011 .61893 m .15882 .67375 L .15564 .68358 L p .707 .577 .707 r
F P
0 g
s
.16227 .79947 m .16071 .7805 L .15741 .77619 L p .707 .577 .707 r
F P
0 g
s
.15741 .77619 m .15897 .79516 L .16227 .79947 L p .707 .577 .707 r
F P
0 g
s
.15586 .70641 m .15677 .74384 L .15774 .75115 L p .707 .578 .707 r
F P
0 g
s
.15882 .67375 m .16011 .61893 L .17296 .6101 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35409 .6196 m .35279 .67442 L .33666 .66549 L p .707 .577 .707 r
F P
0 g
s
.33666 .66549 m .33796 .61067 L .35409 .6196 L p .707 .577 .707 r
F P
0 g
s
.15677 .74384 m .15586 .70641 L .1648 .69917 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17296 .6101 m .17166 .66492 L .15882 .67375 L p .707 .577 .707 r
F P
0 g
s
.15897 .79516 m .15741 .77619 L .16407 .77116 L p .707 .577 .707 r
F P
0 g
s
.16407 .77116 m .16563 .79013 L .15897 .79516 L p .707 .577 .707 r
F P
0 g
s
.1648 .69917 m .16571 .7366 L .15677 .74384 L p .707 .577 .707 r
F P
0 g
s
.63801 .27008 m .63801 .77197 L .6183 .76107 L p .707 .577 .707 r
F P
0 g
s
.6183 .76107 m .6183 .25918 L .63801 .27008 L p .707 .577 .707 r
F P
0 g
s
.17166 .66492 m .17296 .6101 L .19422 .60313 L p .707 .577 .707 r
F P
0 g
s
.36369 .77055 m .36369 .26867 L .38495 .25798 L p .707 .577 .707 r
F P
0 g
s
.36369 .26867 m .36369 .77055 L .35578 .78248 L p .707 .577 .707 r
F P
0 g
s
.33796 .61067 m .33666 .66549 L .3128 .65836 L p .707 .577 .707 r
F P
0 g
s
.3128 .65836 m .3141 .60354 L .33796 .61067 L p .707 .577 .707 r
F P
0 g
s
.16571 .7366 m .1648 .69917 L .18279 .69269 L p .707 .577 .707 r
F P
0 g
s
.19422 .60313 m .19292 .65795 L .17166 .66492 L p .707 .577 .707 r
F P
0 g
s
.34674 .6937 m .34765 .73113 L .32809 .72578 L p .707 .577 .707 r
F P
0 g
s
.32809 .72578 m .32718 .68835 L .34674 .6937 L p .707 .577 .707 r
F P
0 g
s
.19292 .65795 m .19422 .60313 L .22181 .5987 L p .707 .577 .707 r
F P
0 g
s
.16563 .79013 m .16407 .77116 L .18002 .76589 L p .707 .577 .707 r
F P
0 g
s
.18279 .69269 m .1837 .73012 L .16571 .7366 L p .707 .577 .707 r
F P
0 g
s
.18002 .76589 m .18159 .78486 L .16563 .79013 L p .707 .577 .707 r
F P
0 g
s
.3141 .60354 m .3128 .65836 L .28353 .65374 L p .707 .577 .707 r
F P
0 g
s
.28353 .65374 m .28483 .59892 L .3141 .60354 L p .707 .577 .707 r
F P
0 g
s
.6183 .25918 m .6183 .76107 L .58701 .75235 L p .707 .577 .707 r
F P
0 g
s
.58701 .75235 m .58701 .25046 L .6183 .25918 L p .707 .577 .707 r
F P
0 g
s
.22051 .65352 m .22181 .5987 L .25303 .59725 L p .707 .577 .707 r
F P
0 g
s
.22181 .5987 m .22051 .65352 L .19292 .65795 L p .707 .577 .707 r
F P
0 g
s
.38495 .25798 m .38495 .75987 L .36369 .77055 L p .707 .577 .707 r
F P
0 g
s
.38495 .75987 m .38495 .25798 L .41747 .24959 L p .707 .577 .707 r
F P
0 g
s
.34456 .75388 m .34612 .77285 L .32483 .77114 L p .707 .577 .707 r
F P
0 g
s
.32483 .77114 m .32326 .75217 L .34456 .75388 L p .707 .577 .707 r
F P
0 g
s
.1837 .73012 m .18279 .69269 L .20806 .68762 L p .707 .577 .707 r
F P
0 g
s
.74826 .65425 m .74697 .59805 L .71516 .59803 L p .707 .577 .707 r
F P
0 g
s
.74697 .59805 m .74826 .65425 L .77949 .65203 L p .707 .577 .707 r
F P
0 g
s
.77949 .65203 m .77819 .59583 L .74697 .59805 L p .707 .577 .707 r
F P
0 g
s
.28483 .59892 m .28353 .65374 L .25173 .65207 L p .707 .577 .707 r
F P
0 g
s
.25173 .65207 m .25303 .59725 L .28483 .59892 L p .707 .577 .707 r
F P
0 g
s
.25303 .59725 m .25173 .65207 L .22051 .65352 L p .707 .577 .707 r
F P
0 g
s
.71646 .65424 m .71516 .59803 L .6859 .59578 L p .707 .577 .707 r
F P
0 g
s
.71516 .59803 m .71646 .65424 L .74826 .65425 L p .707 .577 .707 r
F P
0 g
s
.32718 .68835 m .32809 .72578 L .30168 .72227 L p .707 .577 .707 r
F P
0 g
s
.30168 .72227 m .30077 .68484 L .32718 .68835 L p .707 .577 .707 r
F P
0 g
s
.77819 .59583 m .77949 .65203 L .80708 .6478 L p .707 .577 .707 r
F P
0 g
s
.80708 .6478 m .80578 .59159 L .77819 .59583 L p .707 .577 .707 r
F P
0 g
s
.18159 .78486 m .18002 .76589 L .20372 .7609 L p .707 .577 .707 r
F P
0 g
s
.20806 .68762 m .20898 .72505 L .1837 .73012 L p .707 .577 .707 r
F P
0 g
s
.20372 .7609 m .20528 .77987 L .18159 .78486 L p .707 .577 .707 r
F P
0 g
s
.6872 .65199 m .6859 .59578 L .66204 .59152 L p .707 .577 .707 r
F P
0 g
s
.6859 .59578 m .6872 .65199 L .71646 .65424 L p .707 .577 .707 r
F P
0 g
s
.20898 .72505 m .20806 .68762 L .23814 .68445 L p .707 .577 .707 r
F P
0 g
s
.30077 .68484 m .30168 .72227 L .271 .72092 L p .707 .577 .707 r
F P
0 g
s
.271 .72092 m .27009 .68349 L .30077 .68484 L p .707 .577 .707 r
F P
0 g
s
.32326 .75217 m .32483 .77114 L .29725 .77107 L p .707 .577 .707 r
F P
0 g
s
.29725 .77107 m .29569 .7521 L .32326 .75217 L p .707 .577 .707 r
F P
0 g
s
.729 .72246 m .72991 .68586 L .69923 .68242 L p .707 .577 .707 r
F P
0 g
s
.72991 .68586 m .729 .72246 L .76094 .72288 L p .707 .577 .707 r
F P
0 g
s
.76094 .72288 m .76185 .68628 L .72991 .68586 L p .707 .577 .707 r
F P
0 g
s
.80578 .59159 m .80708 .6478 L .82834 .64196 L p .707 .577 .707 r
F P
0 g
s
.82834 .64196 m .82704 .58576 L .80578 .59159 L p .707 .577 .707 r
F P
0 g
s
.76185 .68628 m .76094 .72288 L .79102 .72025 L p .707 .577 .707 r
F P
0 g
s
.79102 .72025 m .79193 .68365 L .76185 .68628 L p .707 .577 .707 r
F P
0 g
s
.58701 .25046 m .58701 .75235 L .54719 .74664 L p .707 .577 .707 r
F P
0 g
s
.54719 .74664 m .54719 .24475 L .58701 .25046 L p .707 .577 .707 r
F P
0 g
s
.41747 .75148 m .41747 .24959 L .45806 .2443 L p .707 .577 .707 r
F P
0 g
s
.41747 .24959 m .41747 .75148 L .38495 .75987 L p .707 .577 .707 r
F P
0 g
s
.23814 .68445 m .23905 .72188 L .20898 .72505 L p .707 .577 .707 r
F P
0 g
s
.66204 .59152 m .66334 .64773 L .6872 .65199 L p .707 .577 .707 r
F P
0 g
s
.20528 .77987 m .20372 .7609 L .23284 .75668 L p .707 .577 .707 r
F P
0 g
s
.23905 .72188 m .23814 .68445 L .27009 .68349 L p .707 .577 .707 r
F P
0 g
s
.69832 .71902 m .69923 .68242 L .67282 .67631 L p .707 .577 .707 r
F P
0 g
s
.69923 .68242 m .69832 .71902 L .729 .72246 L p .707 .577 .707 r
F P
0 g
s
.27009 .68349 m .271 .72092 L .23905 .72188 L p .707 .577 .707 r
F P
0 g
s
.23284 .75668 m .2344 .77565 L .20528 .77987 L p .707 .577 .707 r
F P
0 g
s
.79193 .68365 m .79102 .72025 L .81629 .71481 L p .707 .577 .707 r
F P
0 g
s
.81629 .71481 m .81721 .67821 L .79193 .68365 L p .707 .577 .707 r
F P
0 g
s
.66334 .64773 m .66204 .59152 L .64591 .58567 L p .707 .577 .707 r
F P
0 g
s
.29569 .7521 m .29725 .77107 L .26609 .77262 L p .707 .577 .707 r
F P
0 g
s
.26609 .77262 m .26453 .75365 L .29569 .7521 L p .707 .577 .707 r
F P
0 g
s
.67282 .67631 m .67191 .7129 L .69832 .71902 L p .707 .577 .707 r
F P
0 g
s
.2344 .77565 m .23284 .75668 L .26453 .75365 L p .707 .577 .707 r
F P
0 g
s
.26453 .75365 m .26609 .77262 L .2344 .77565 L p .707 .577 .707 r
F P
0 g
s
.54719 .24475 m .54719 .74664 L .50276 .74452 L p .707 .577 .707 r
F P
0 g
s
.50276 .74452 m .50276 .24263 L .54719 .24475 L p .707 .577 .707 r
F P
0 g
s
.82704 .58576 m .82834 .64196 L .84118 .63509 L p .707 .577 .707 r
F P
0 g
s
.84118 .63509 m .83988 .57889 L .82704 .58576 L p .707 .577 .707 r
F P
0 g
s
.73391 .7711 m .73547 .75343 L .70431 .7485 L p .707 .577 .707 r
F P
0 g
s
.73547 .75343 m .73391 .7711 L .7656 .77219 L p .707 .577 .707 r
F P
0 g
s
.7656 .77219 m .76716 .75453 L .73547 .75343 L p .707 .577 .707 r
F P
0 g
s
.45806 .74619 m .45806 .2443 L .50276 .24263 L p .707 .577 .707 r
F P
0 g
s
.45806 .2443 m .45806 .74619 L .41747 .75148 L p .707 .577 .707 r
F P
0 g
s
.67191 .7129 m .67282 .67631 L .65326 .66811 L p .707 .577 .707 r
F P
0 g
s
.76716 .75453 m .7656 .77219 L .79471 .76934 L p .707 .577 .707 r
F P
0 g
s
.79471 .76934 m .79628 .75168 L .76716 .75453 L p .707 .577 .707 r
F P
0 g
s
.64591 .58567 m .64721 .64187 L .66334 .64773 L p .707 .577 .707 r
F P
0 g
s
.70275 .76616 m .70431 .7485 L .67673 .74021 L p .707 .577 .707 r
F P
0 g
s
.70431 .7485 m .70275 .76616 L .73391 .7711 L p .707 .577 .707 r
F P
0 g
s
.81721 .67821 m .81629 .71481 L .83428 .70711 L p .707 .577 .707 r
F P
0 g
s
.83428 .70711 m .8352 .67051 L .81721 .67821 L p .707 .577 .707 r
F P
0 g
s
.50276 .24263 m .50276 .74452 L .45806 .74619 L p .707 .577 .707 r
F P
0 g
s
.67673 .74021 m .67517 .75787 L .70275 .76616 L p .707 .577 .707 r
F P
0 g
s
.65326 .66811 m .65234 .70471 L .67191 .7129 L p .707 .577 .707 r
F P
0 g
s
.79628 .75168 m .79471 .76934 L .81841 .76282 L p .707 .577 .707 r
F P
0 g
s
.81841 .76282 m .81998 .74516 L .79628 .75168 L p .707 .577 .707 r
F P
0 g
s
.64721 .64187 m .64591 .58567 L .6391 .57879 L p .707 .577 .707 r
F P
0 g
s
.67517 .75787 m .67673 .74021 L .65544 .72937 L p .707 .577 .707 r
F P
0 g
s
.65234 .70471 m .65326 .66811 L .64246 .65863 L p .707 .577 .707 r
F P
0 g
s
.65544 .72937 m .65387 .74703 L .67517 .75787 L p .707 .577 .707 r
F P
0 g
s
.83988 .57889 m .84118 .63509 L .84435 .62786 L p .707 .577 .707 r
F P
0 g
s
.84435 .62786 m .84305 .57166 L .83988 .57889 L p .707 .577 .707 r
F P
0 g
s
.6391 .57879 m .6404 .63499 L .64721 .64187 L p .707 .577 .707 r
F P
0 g
s
.8352 .67051 m .83428 .70711 L .84323 .69789 L p .707 .577 .707 r
F P
0 g
s
.84323 .69789 m .84414 .6613 L .8352 .67051 L p .707 .577 .707 r
F P
0 g
s
.64246 .65863 m .64155 .69523 L .65234 .70471 L p .707 .577 .707 r
F P
0 g
s
.81998 .74516 m .81841 .76282 L .83437 .75327 L p .707 .577 .707 r
F P
0 g
s
.83437 .75327 m .83593 .73561 L .81998 .74516 L p .707 .577 .707 r
F P
0 g
s
.65387 .74703 m .65544 .72937 L .6425 .71705 L p .707 .577 .707 r
F P
0 g
s
.6425 .71705 m .64094 .73471 L .65387 .74703 L p .707 .577 .707 r
F P
0 g
s
.6404 .63499 m .6391 .57879 L .64227 .57156 L p .707 .577 .707 r
F P
0 g
s
.64155 .69523 m .64246 .65863 L .64149 .6488 L p .707 .577 .707 r
F P
0 g
s
.84305 .57166 m .84435 .62786 L .83754 .62098 L p .707 .577 .707 r
F P
0 g
s
.83754 .62098 m .83624 .56478 L .84305 .57166 L p .707 .577 .707 r
F P
0 g
s
.84414 .6613 m .84323 .69789 L .84226 .68807 L p .707 .577 .707 r
F P
0 g
s
.84226 .68807 m .84317 .65147 L .84414 .6613 L p .707 .577 .707 r
F P
0 g
s
.64227 .57156 m .64357 .62776 L .6404 .63499 L p .707 .577 .707 r
F P
0 g
s
.83593 .73561 m .83437 .75327 L .84102 .74163 L p .707 .577 .707 r
F P
0 g
s
.84102 .74163 m .84259 .72397 L .83593 .73561 L p .707 .577 .707 r
F P
0 g
s
.64149 .6488 m .64058 .6854 L .64155 .69523 L p .707 .577 .707 r
F P
0 g
s
.64094 .73471 m .6425 .71705 L .6392 .70445 L p .707 .577 .707 r
F P
0 g
s
.6392 .70445 m .63764 .72212 L .64094 .73471 L p .707 .577 .707 r
F P
0 g
s
.64357 .62776 m .64227 .57156 L .65511 .56469 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64058 .6854 m .64149 .6488 L .65044 .63959 L p .707 .577 .707 r
F P
0 g
s
.83624 .56478 m .83754 .62098 L .82142 .61513 L p .707 .577 .707 r
F P
0 g
s
.82142 .61513 m .82012 .55892 L .83624 .56478 L p .707 .577 .707 r
F P
0 g
s
.84317 .65147 m .84226 .68807 L .83146 .67859 L p .707 .577 .707 r
F P
0 g
s
.83146 .67859 m .83238 .64199 L .84317 .65147 L p .707 .577 .707 r
F P
0 g
s
.40819 .62219 m .40527 .56709 L .37351 .5677 L p .707 .577 .707 r
F P
0 g
s
.40527 .56709 m .40819 .62219 L .43939 .61869 L p .707 .577 .707 r
F P
0 g
s
.43939 .61869 m .43647 .56359 L .40527 .56709 L p .707 .577 .707 r
F P
0 g
s
.84259 .72397 m .84102 .74163 L .83772 .72903 L p .707 .577 .707 r
F P
0 g
s
.83772 .72903 m .83929 .71137 L .84259 .72397 L p .707 .577 .707 r
F P
0 g
s
.65511 .56469 m .65641 .62089 L .64357 .62776 L p .707 .577 .707 r
F P
0 g
s
.37642 .6228 m .37351 .5677 L .34427 .56535 L p .707 .577 .707 r
F P
0 g
s
.37351 .5677 m .37642 .6228 L .40819 .62219 L p .707 .577 .707 r
F P
0 g
s
.63764 .72212 m .6392 .70445 L .64586 .69281 L p .707 .577 .707 r
F P
0 g
s
.65044 .63959 m .64952 .67618 L .64058 .6854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.43647 .56359 m .43939 .61869 L .46695 .61264 L p .707 .577 .707 r
F P
0 g
s
.46695 .61264 m .46404 .55754 L .43647 .56359 L p .707 .577 .707 r
F P
0 g
s
.64586 .69281 m .6443 .71047 L .63764 .72212 L p .707 .577 .707 r
F P
0 g
s
.34719 .62045 m .34427 .56535 L .32044 .56028 L p .707 .577 .707 r
F P
0 g
s
.34427 .56535 m .34719 .62045 L .37642 .6228 L p .707 .577 .707 r
F P
0 g
s
.65641 .62089 m .65511 .56469 L .67637 .55885 L p .707 .577 .707 r
F P
0 g
s
.46404 .55754 m .46695 .61264 L .4882 .60462 L p .707 .577 .707 r
F P
0 g
s
.4882 .60462 m .48528 .54952 L .46404 .55754 L p .707 .577 .707 r
F P
0 g
s
.64952 .67618 m .65044 .63959 L .66843 .63188 L p .707 .577 .707 r
F P
0 g
s
.38845 .67671 m .39045 .63941 L .3598 .63572 L p .707 .577 .707 r
F P
0 g
s
.39045 .63941 m .38845 .67671 L .42036 .67809 L p .707 .577 .707 r
F P
0 g
s
.42036 .67809 m .42236 .64079 L .39045 .63941 L p .707 .577 .707 r
F P
0 g
s
.42236 .64079 m .42036 .67809 L .45041 .67704 L p .707 .577 .707 r
F P
0 g
s
.45041 .67704 m .45241 .63973 L .42236 .64079 L p .707 .577 .707 r
F P
0 g
s
.82012 .55892 m .82142 .61513 L .79755 .61087 L p .707 .577 .707 r
F P
0 g
s
.79755 .61087 m .79625 .55466 L .82012 .55892 L p .707 .577 .707 r
F P
0 g
s
.83238 .64199 m .83146 .67859 L .8119 .67039 L p .707 .577 .707 r
F P
0 g
s
.8119 .67039 m .81281 .63379 L .83238 .64199 L p .707 .577 .707 r
F P
0 g
s
.67637 .55885 m .67767 .61506 L .65641 .62089 L p .707 .577 .707 r
F P
0 g
s
.83929 .71137 m .83772 .72903 L .82479 .71671 L p .707 .577 .707 r
F P
0 g
s
.82479 .71671 m .82636 .69905 L .83929 .71137 L p .707 .577 .707 r
F P
0 g
s
.3578 .67302 m .3598 .63572 L .33342 .63009 L p .707 .577 .707 r
F P
0 g
s
.3598 .63572 m .3578 .67302 L .38845 .67671 L p .707 .577 .707 r
F P
0 g
s
.6443 .71047 m .64586 .69281 L .66182 .68326 L p .707 .577 .707 r
F P
0 g
s
.32044 .56028 m .32336 .61538 L .34719 .62045 L p .707 .577 .707 r
F P
0 g
s
.66843 .63188 m .66751 .66848 L .64952 .67618 L p .707 .577 .707 r
F P
0 g
s
.45241 .63973 m .45041 .67704 L .47565 .67364 L p .707 .577 .707 r
F P
0 g
s
.47565 .67364 m .47766 .63634 L .45241 .63973 L p .707 .577 .707 r
F P
0 g
s
.38999 .71068 m .39339 .69199 L .36262 .68549 L p .707 .577 .707 r
F P
0 g
s
.39339 .69199 m .38999 .71068 L .42129 .7157 L p .707 .577 .707 r
F P
0 g
s
.42129 .7157 m .42468 .69701 L .39339 .69199 L p .707 .577 .707 r
F P
0 g
s
.32336 .61538 m .32044 .56028 L .30434 .55298 L p .707 .577 .707 r
F P
0 g
s
.36262 .68549 m .35922 .70418 L .38999 .71068 L p .707 .577 .707 r
F P
0 g
s
.67767 .61506 m .67637 .55885 L .70396 .55462 L p .707 .577 .707 r
F P
0 g
s
.42468 .69701 m .42129 .7157 L .45006 .71875 L p .707 .577 .707 r
F P
0 g
s
.45006 .71875 m .45345 .70006 L .42468 .69701 L p .707 .577 .707 r
F P
0 g
s
.33342 .63009 m .33142 .66739 L .3578 .67302 L p .707 .577 .707 r
F P
0 g
s
.66182 .68326 m .66025 .70092 L .6443 .71047 L p .707 .577 .707 r
F P
0 g
s
.35922 .70418 m .36262 .68549 L .33539 .67814 L p .707 .577 .707 r
F P
0 g
s
.48528 .54952 m .4882 .60462 L .50103 .59543 L p .707 .577 .707 r
F P
0 g
s
.50103 .59543 m .49812 .54033 L .48528 .54952 L p .707 .577 .707 r
F P
0 g
s
.33539 .67814 m .332 .69684 L .35922 .70418 L p .707 .577 .707 r
F P
0 g
s
.79625 .55466 m .79755 .61087 L .76829 .60862 L p .707 .577 .707 r
F P
0 g
s
.76829 .60862 m .76699 .55241 L .79625 .55466 L p .707 .577 .707 r
F P
0 g
s
.66751 .66848 m .66843 .63188 L .6937 .62645 L p .707 .577 .707 r
F P
0 g
s
.33142 .66739 m .33342 .63009 L .31388 .62306 L p .707 .577 .707 r
F P
0 g
s
.81281 .63379 m .8119 .67039 L .78549 .66427 L p .707 .577 .707 r
F P
0 g
s
.78549 .66427 m .7864 .62767 L .81281 .63379 L p .707 .577 .707 r
F P
0 g
s
.70396 .55462 m .70526 .61082 L .67767 .61506 L p .707 .577 .707 r
F P
0 g
s
.45345 .70006 m .45006 .71875 L .47347 .71954 L p .707 .577 .707 r
F P
0 g
s
.47347 .71954 m .47687 .70084 L .45345 .70006 L p .707 .577 .707 r
F P
0 g
s
.30434 .55298 m .30726 .60807 L .32336 .61538 L p .707 .577 .707 r
F P
0 g
s
.47766 .63634 m .47565 .67364 L .49363 .66825 L p .707 .577 .707 r
F P
0 g
s
.49363 .66825 m .49563 .63094 L .47766 .63634 L p .707 .577 .707 r
F P
0 g
s
.70526 .61082 m .70396 .55462 L .73519 .5524 L p .707 .577 .707 r
F P
0 g
s
.82636 .69905 m .82479 .71671 L .8035 .70588 L p .707 .577 .707 r
F P
0 g
s
.8035 .70588 m .80506 .68821 L .82636 .69905 L p .707 .577 .707 r
F P
0 g
s
.332 .69684 m .33539 .67814 L .31438 .67067 L p .707 .577 .707 r
F P
0 g
s
.31388 .62306 m .31188 .66037 L .33142 .66739 L p .707 .577 .707 r
F P
0 g
s
.76699 .55241 m .76829 .60862 L .73649 .6086 L p .707 .577 .707 r
F P
0 g
s
.73649 .6086 m .73519 .5524 L .76699 .55241 L p .707 .577 .707 r
F P
0 g
s
.6937 .62645 m .69279 .66305 L .66751 .66848 L p .707 .577 .707 r
F P
0 g
s
.66025 .70092 m .66182 .68326 L .68551 .67674 L p .707 .577 .707 r
F P
0 g
s
.31438 .67067 m .31098 .68937 L .332 .69684 L p .707 .577 .707 r
F P
0 g
s
.73519 .5524 m .73649 .6086 L .70526 .61082 L p .707 .577 .707 r
F P
0 g
s
.30726 .60807 m .30434 .55298 L .29754 .54416 L p .707 .577 .707 r
F P
0 g
s
.69279 .66305 m .6937 .62645 L .72378 .62381 L p .707 .577 .707 r
F P
0 g
s
.68551 .67674 m .68395 .69441 L .66025 .70092 L p .707 .577 .707 r
F P
0 g
s
.7864 .62767 m .78549 .66427 L .75481 .66083 L p .707 .577 .707 r
F P
0 g
s
.75481 .66083 m .75572 .62423 L .7864 .62767 L p .707 .577 .707 r
F P
0 g
s
.49812 .54033 m .50103 .59543 L .50421 .58596 L p .707 .577 .707 r
F P
0 g
s
.50421 .58596 m .50129 .53086 L .49812 .54033 L p .707 .577 .707 r
F P
0 g
s
.31188 .66037 m .31388 .62306 L .3031 .61534 L p .707 .577 .707 r
F P
0 g
s
.47687 .70084 m .47347 .71954 L .48925 .71797 L p .707 .577 .707 r
F P
0 g
s
.48925 .71797 m .49264 .69927 L .47687 .70084 L p .707 .577 .707 r
F P
0 g
s
.72287 .66041 m .72378 .62381 L .75572 .62423 L p .707 .577 .707 r
F P
0 g
s
.72378 .62381 m .72287 .66041 L .69279 .66305 L p .707 .577 .707 r
F P
0 g
s
.75572 .62423 m .75481 .66083 L .72287 .66041 L p .707 .577 .707 r
F P
0 g
s
.80506 .68821 m .8035 .70588 L .77592 .69758 L p .707 .577 .707 r
F P
0 g
s
.77592 .69758 m .77748 .67992 L .80506 .68821 L p .707 .577 .707 r
F P
0 g
s
.31098 .68937 m .31438 .67067 L .30163 .66381 L p .707 .577 .707 r
F P
0 g
s
.68395 .69441 m .68551 .67674 L .71463 .67389 L p .707 .577 .707 r
F P
0 g
s
.49563 .63094 m .49363 .66825 L .50257 .66137 L p .707 .577 .707 r
F P
0 g
s
.50257 .66137 m .50457 .62407 L .49563 .63094 L p .707 .577 .707 r
F P
0 g
s
.29754 .54416 m .30046 .59926 L .30726 .60807 L p .707 .577 .707 r
F P
0 g
s
.3031 .61534 m .3011 .65264 L .31188 .66037 L p .707 .577 .707 r
F P
0 g
s
.30163 .66381 m .29823 .6825 L .31098 .68937 L p .707 .577 .707 r
F P
0 g
s
.71463 .67389 m .71307 .69155 L .68395 .69441 L p .707 .577 .707 r
F P
0 g
s
.77748 .67992 m .77592 .69758 L .74476 .69265 L p .707 .577 .707 r
F P
0 g
s
.74476 .69265 m .74632 .67499 L .77748 .67992 L p .707 .577 .707 r
F P
0 g
s
.71307 .69155 m .71463 .67389 L .74632 .67499 L p .707 .577 .707 r
F P
0 g
s
.30046 .59926 m .29754 .54416 L .30072 .53469 L p .707 .577 .707 r
F P
0 g
s
.74632 .67499 m .74476 .69265 L .71307 .69155 L p .707 .577 .707 r
F P
0 g
s
.50129 .53086 m .50421 .58596 L .49742 .57714 L p .707 .577 .707 r
F P
0 g
s
.49742 .57714 m .4945 .52205 L .50129 .53086 L p .707 .577 .707 r
F P
0 g
s
.3011 .65264 m .3031 .61534 L .30214 .60766 L p .707 .577 .707 r
F P
0 g
s
.49264 .69927 m .48925 .71797 L .49584 .71421 L p .707 .577 .707 r
F P
0 g
s
.49584 .71421 m .49924 .69552 L .49264 .69927 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29823 .6825 m .30163 .66381 L .29839 .65823 L p .707 .577 .707 r
F P
0 g
s
.50457 .62407 m .50257 .66137 L .5016 .6537 L p .707 .577 .707 r
F P
0 g
s
.5016 .6537 m .5036 .61639 L .50457 .62407 L p .707 .577 .707 r
F P
0 g
s
.30072 .53469 m .30364 .58979 L .30046 .59926 L p .707 .577 .707 r
F P
0 g
s
.30214 .60766 m .30014 .64496 L .3011 .65264 L p .707 .577 .707 r
F P
0 g
s
.29839 .65823 m .29499 .67692 L .29823 .6825 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30364 .58979 m .30072 .53469 L .31356 .5255 L p .707 .577 .707 r
F P
0 g
s
.4945 .52205 m .49742 .57714 L .48131 .56984 L p .707 .577 .707 r
F P
0 g
s
.48131 .56984 m .4784 .51474 L .4945 .52205 L p .707 .577 .707 r
F P
0 g
s
.30014 .64496 m .30214 .60766 L .31108 .60079 L p .707 .577 .707 r
F P
0 g
s
.49924 .69552 m .49584 .71421 L .49261 .70863 L p .707 .577 .707 r
F P
0 g
s
.49261 .70863 m .496 .68993 L .49924 .69552 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29499 .67692 m .29839 .65823 L .30498 .65447 L p .707 .577 .707 r
F P
0 g
s
.31356 .5255 m .31648 .5806 L .30364 .58979 L p .707 .577 .707 r
F P
0 g
s
.5036 .61639 m .5016 .6537 L .49082 .64597 L p .707 .577 .707 r
F P
0 g
s
.49082 .64597 m .49283 .60867 L .5036 .61639 L p .707 .577 .707 r
F P
0 g
s
.31108 .60079 m .30908 .63809 L .30014 .64496 L p .707 .577 .707 r
F P
0 g
s
.30498 .65447 m .30159 .67316 L .29499 .67692 L p .707 .577 .707 r
F P
0 g
s
.31648 .5806 m .31356 .5255 L .3348 .51748 L p .707 .577 .707 r
F P
0 g
s
.4784 .51474 m .48131 .56984 L .45748 .56477 L p .707 .577 .707 r
F P
0 g
s
.45748 .56477 m .45456 .50967 L .4784 .51474 L p .707 .577 .707 r
F P
0 g
s
.30908 .63809 m .31108 .60079 L .32905 .59539 L p .707 .577 .707 r
F P
0 g
s
.496 .68993 m .49261 .70863 L .47985 .70176 L p .707 .577 .707 r
F P
0 g
s
.47985 .70176 m .48325 .68307 L .496 .68993 L p .707 .577 .707 r
F P
0 g
s
.3348 .51748 m .33772 .57258 L .31648 .5806 L p .707 .577 .707 r
F P
0 g
s
.49283 .60867 m .49082 .64597 L .47129 .63895 L p .707 .577 .707 r
F P
0 g
s
.47129 .63895 m .47329 .60164 L .49283 .60867 L p .707 .577 .707 r
F P
0 g
s
.30159 .67316 m .30498 .65447 L .32076 .6529 L p .707 .577 .707 r
F P
0 g
s
.32905 .59539 m .32705 .63269 L .30908 .63809 L p .707 .577 .707 r
F P
0 g
s
.32076 .6529 m .31736 .67159 L .30159 .67316 L p .707 .577 .707 r
F P
0 g
s
.33772 .57258 m .3348 .51748 L .36237 .51143 L p .707 .577 .707 r
F P
0 g
s
.45456 .50967 m .45748 .56477 L .42825 .56242 L p .707 .577 .707 r
F P
0 g
s
.42825 .56242 m .42533 .50732 L .45456 .50967 L p .707 .577 .707 r
F P
0 g
s
.32705 .63269 m .32905 .59539 L .3543 .592 L p .707 .577 .707 r
F P
0 g
s
.36529 .56653 m .36237 .51143 L .39356 .50793 L p .707 .577 .707 r
F P
0 g
s
.36237 .51143 m .36529 .56653 L .33772 .57258 L p .707 .577 .707 r
F P
0 g
s
.42533 .50732 m .42825 .56242 L .39648 .56303 L p .707 .577 .707 r
F P
0 g
s
.39648 .56303 m .39356 .50793 L .42533 .50732 L p .707 .577 .707 r
F P
0 g
s
.48325 .68307 m .47985 .70176 L .45884 .69429 L p .707 .577 .707 r
F P
0 g
s
.45884 .69429 m .46223 .6756 L .48325 .68307 L p .707 .577 .707 r
F P
0 g
s
.47329 .60164 m .47129 .63895 L .4449 .63331 L p .707 .577 .707 r
F P
0 g
s
.4449 .63331 m .4469 .59601 L .47329 .60164 L p .707 .577 .707 r
F P
0 g
s
.39356 .50793 m .39648 .56303 L .36529 .56653 L p .707 .577 .707 r
F P
0 g
s
.3543 .592 m .3523 .6293 L .32705 .63269 L p .707 .577 .707 r
F P
0 g
s
.31736 .67159 m .32076 .6529 L .34417 .65368 L p .707 .577 .707 r
F P
0 g
s
.34417 .65368 m .34078 .67237 L .31736 .67159 L p .707 .577 .707 r
F P
0 g
s
.3523 .6293 m .3543 .592 L .38435 .59094 L p .707 .577 .707 r
F P
0 g
s
.4469 .59601 m .4449 .63331 L .41426 .62963 L p .707 .577 .707 r
F P
0 g
s
.41426 .62963 m .41626 .59232 L .4469 .59601 L p .707 .577 .707 r
F P
0 g
s
.46223 .6756 m .45884 .69429 L .43161 .68695 L p .707 .577 .707 r
F P
0 g
s
.43161 .68695 m .43501 .66825 L .46223 .6756 L p .707 .577 .707 r
F P
0 g
s
.38435 .59094 m .38235 .62824 L .3523 .6293 L p .707 .577 .707 r
F P
0 g
s
.38235 .62824 m .38435 .59094 L .41626 .59232 L p .707 .577 .707 r
F P
0 g
s
.34078 .67237 m .34417 .65368 L .37294 .65673 L p .707 .577 .707 r
F P
0 g
s
.41626 .59232 m .41426 .62963 L .38235 .62824 L p .707 .577 .707 r
F P
0 g
s
.37294 .65673 m .36955 .67543 L .34078 .67237 L p .707 .577 .707 r
F P
0 g
s
.43501 .66825 m .43161 .68695 L .40085 .68045 L p .707 .577 .707 r
F P
0 g
s
.40085 .68045 m .40424 .66175 L .43501 .66825 L p .707 .577 .707 r
F P
0 g
s
.36955 .67543 m .37294 .65673 L .40424 .66175 L p .707 .577 .707 r
F P
0 g
s
.40424 .66175 m .40085 .68045 L .36955 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF5`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
069oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00GWoo10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00Fgoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00003Goo
8@00=goo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00007Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<goo001DOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000aOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
009JEPT00003FUH005YF00`000AJEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00E7oo
00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEQ@000AJEP03001JEUYF00AJEP@00003FUH0
05YF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH2000^Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP04001JEUYFFUH60008FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YF00002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`05FUH005YFFUH00003FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`06FUH005YFFUH005YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00H005YF000005YF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0002eoo`00EGoo00AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00AJEP000000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00=JEP0000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Goo001E
Ool00eYF00000003FUH00`00FUIJEP03FUHJ00000eYF001JEP06FUH00`00FUIJEP03FUH01@00FUIJ
EUYF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH0000]Ool004Aoo`P000Uoo`03001JEP0000=JEPH000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEUYFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool003aoo`P000=JEP03001JEUYF009JEPX00003FUH000000080009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03
001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8002eoo`00=Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000UYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF8@000eYF00<005YFFUH00UYF0P00;Goo000`Ool20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
0eYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP00008000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0
000002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH70002FUH200000eYF001JEP04FUH=
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`0015YF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001EYF00D005YFFUIJEP0002eoo`00;7oo0P000eYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001J
EP8000=JEP04001JEUYFFUH80003FUH60003FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00D005YFFUIJEP0002eoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000=JEP03001JEUYF00AJEPX000AJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH0000002ioo`00;7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF100000=JEP00000020000eYF
00<005YFFUH015YF0`0000AJEP00FUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<7oo000/Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF5@000eYF00<005YFFUH03`001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002Goo1@001Woo1`000UYF00<005YFFUH00eYF00<005YFFUH00UYF1P00
0UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YFFUH00UYF1@0015YF6@0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1@0025YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
1P004Woo1P001EYF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH00eYF100025YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF0P002Woo0`003Goo100000=JEP00FUH015YF00@005YFFUH002eoo`00;7oo10000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<0
05YFFUH00`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00UYF0`000UYF00L005YFFUIJEP00FUH00008Ool5000@Ool30004FUH01000FUIJEP00
;Goo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF001JEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
00030003FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH200000eYF001JEP040003FUH01P00FUIJEUYF001JEPl0019oo`<00005FUH005YFFUH0000]Ool0
02aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP@000=JEPP000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0000000AJ
EPT000AJEP03001JEUYF00IJEP03001JEP0000<000eoo`<00003FUH00000009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YF0000100000=JEP00FUH015YF1`001UYF00<005YF
FUH01UYF00<005YF00000P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF10001Goo100000=JEP00FUH00eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH600000eYF
000000020002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH3000]Ool0
02eoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEP0000T000=JEP03001JEP0000<000IJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=J
EP03001JEUYF009JEP03001JEP0002eoo`00;Goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00eYF1P00
0eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF00H005YFFUH005YF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0000]Ool002ioo`06001J
EP00001JEP001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF20002EYF100015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEPH000QJEP03001J
EUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF1P001UYF00<005YF00000P0000=JEP00FUH0
0UYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YF0000
0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01000FUIJEUYF3@000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF0P0000=JEP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH0
0000FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002
FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P001EYF00<005YF00000P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EP00FUH01@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080
0005FUH00000FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP00;goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJ
EP00FUH000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000EJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
009JEP03001oogoo02aoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP040002FUH00`00
FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00Oomo
o`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF009JEQ40009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH0000000@000=JEPT000AJEPH000=JEP03001JEUYF009JEPP000Ioo`03
001JEUYF008002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF009JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=J
EP00FUH00eYF00<005YF00000`000UYF0P0017oo4P003goo00@005YF000002eoo`00;7oo00@005YF
FUH000AJEP04001JEUYFFUH80007Ool50007Ool=0002FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00004FUH200000eYF00000009Ool5000HOol3
000]Ool002aoo`04001JEUYF0003FUH500000eYF0000000H0004FUH00`00FUIJEP04FUH00`00FUH0
00020002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH01000FUIJEP00
1EYF0`002goo0`006Woo0P00;Goo000/Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF10001EYF00<005YF0000
9goo0`00;Goo000/Ool00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00P0015YF00@005YFFUH0
02Ioo`03001JEP0002eoo`00;7oo10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00005FUH300001EYF001JEUYF000097oo0`0000=J
EP00Ool0;7oo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP00008000IJEP03001JEP0000@0025oo`<0009JEP8002ioo`00;7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEP`000AJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00006FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02FUH2000^Ool002aoo`04001JEUYF
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000>0003FUH20000
17oo001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF1`001eYF00<005YFFUH00eYF00<005YF00000UYF0P000eYF00<005YFFUH01UYF00<005YF
FUH0100047oo1@001EYF00D005YFFUIJEP0002moo`00;Goo0`001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01@000Woo00<005YF00001EYF
00<005YFFUH00UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH00`0015YF00<005YFFUH00eYF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF40000eYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;goo0P0015YF00<005YFFUH015YF
00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF00000Woo1`00
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
035oo`00<Goo0`0000=JEP00FUH01`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20005FUH00`00FUH00007Ool6
0002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000cOol0
039oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP000eYF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF000000=JEP03001JEP0000L000=J
EP800003FUH0000000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
<7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00L005YFFUH005YF001JEP0200000eYF001JEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000AJEP00FUH000AJEP03001JEP000080009JEP@000=oo`@0009JEP03001JEUYF00IJEP03001J
EUYF009JEPD003Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
7@0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00UYF0`000UYF00<007ooOol01Goo4000?goo000/Ool30004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH=000<Ool50003FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000EJEP03001JEUYF009JEP<00003FUH007oo05Eoo`00;7oo00<005YF000015YF00<0
05YFFUH00eYF1P0027oo1@0027oo100000=JEP00FUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF009JEP03001JEUYF008005Ioo`00
;7oo00@005YFFUH000=JEP03001JEP0000<000]ooa0000EJEP03001JEUYF00AJEP03001JEUYF009J
EP8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00P000AJEP04001JEUYF001FOol0
02aoo`04001JEUYF0002FUHB0004FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP040005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001eYF0`0000EJEP00FUIJEP00
05Ioo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000goo00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH00P000eYF00<007ooOol0Dgoo000]Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000030007Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000=JEP00Ool0E7oo000]Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000<Ool20003FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00@005YF000000=oo`8005Eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004goo00@0
05YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH30005Ool2001EOol0031ooad001eo
o`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEP000006FUH00`00FUH000030007Ool01000FUH00000E7oo001/Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH4
0004FUH6000:Ool20002FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00`000moo`03001JEP00009JEP03001o
ogoo059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`0057oo
00@005YFFUIJEP8005Eoo`00N7oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1P001Woo1@004Woo0P0015YF0P00EGoo001nOolO000<Ool5000@Ool200000eYF001JEP03FUH00`00
Oomoo`1DOol008ioo`04001JEUYF000HOol3000?Ool20003FUH01@00FUIJEUYF0000Egoo002>Ool0
0`00FUH0000XOol30006FUH00`00FUH0001HOol008moo`8002Ioo`800003FUH005YF00IJEP8005Uo
o`00Sgoo0P008goo0`000eYF00<005YFFUH015YF0P00FWoo002?Ool00`00FUH0000NOol40007FUH0
1000FUIJEUYF0P00G7oo002?Ool2000015YF000000005goo10000UYF00<005YFFUH01UYF00@005YF
000005ioo`00T7oo00<005YF00000UYF1`002Goo1`001UYF00<005YFFUH01EYF0`00H7oo002@Ool0
0`00FUH00005FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002A
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
001UOol0099oo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP@006Qoo`00
Tgoo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000K7oo002FOol70004FUH0
0`00FUIJEP02FUH7001`Ool009eoo`T007Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60352 .74787 m .60643 .69198 L .57467 .68965 L p .707 .577 .707 r
F P
0 g
s
.60643 .69198 m .60352 .74787 L .63471 .74775 L p .707 .577 .707 r
F P
0 g
s
.63471 .74775 m .63763 .69186 L .60643 .69198 L p .707 .577 .707 r
F P
0 g
s
.57175 .74554 m .57467 .68965 L .54543 .68508 L p .707 .577 .707 r
F P
0 g
s
.57467 .68965 m .57175 .74554 L .60352 .74787 L p .707 .577 .707 r
F P
0 g
s
.63763 .69186 m .63471 .74775 L .66228 .74517 L p .707 .577 .707 r
F P
0 g
s
.66228 .74517 m .6652 .68928 L .63763 .69186 L p .707 .577 .707 r
F P
0 g
s
.54252 .74097 m .54543 .68508 L .5216 .67873 L p .707 .577 .707 r
F P
0 g
s
.54543 .68508 m .54252 .74097 L .57175 .74554 L p .707 .577 .707 r
F P
0 g
s
.58574 .81373 m .58374 .77706 L .55309 .77592 L p .707 .577 .707 r
F P
0 g
s
.58374 .77706 m .58574 .81373 L .61765 .81185 L p .707 .577 .707 r
F P
0 g
s
.61765 .81185 m .61565 .77518 L .58374 .77706 L p .707 .577 .707 r
F P
0 g
s
.61565 .77518 m .61765 .81185 L .6477 .80715 L p .707 .577 .707 r
F P
0 g
s
.6477 .80715 m .6457 .77048 L .61565 .77518 L p .707 .577 .707 r
F P
0 g
s
.6652 .68928 m .66228 .74517 L .68352 .7404 L p .707 .577 .707 r
F P
0 g
s
.68352 .7404 m .68644 .68451 L .6652 .68928 L p .707 .577 .707 r
F P
0 g
s
.5216 .67873 m .51868 .73462 L .54252 .74097 L p .707 .577 .707 r
F P
0 g
s
.55509 .81259 m .55309 .77592 L .52671 .77187 L p .707 .577 .707 r
F P
0 g
s
.55309 .77592 m .55509 .81259 L .58574 .81373 L p .707 .577 .707 r
F P
0 g
s
.6457 .77048 m .6477 .80715 L .67294 .80007 L p .707 .577 .707 r
F P
0 g
s
.67294 .80007 m .67094 .7634 L .6457 .77048 L p .707 .577 .707 r
F P
0 g
s
.51868 .73462 m .5216 .67873 L .5055 .67121 L p .707 .577 .707 r
F P
0 g
s
.52671 .77187 m .52871 .80854 L .55509 .81259 L p .707 .577 .707 r
F P
0 g
s
.59915 .86307 m .59576 .84553 L .56499 .84812 L p .707 .577 .707 r
F P
0 g
s
.59576 .84553 m .59915 .86307 L .63045 .85664 L p .707 .577 .707 r
F P
0 g
s
.63045 .85664 m .62706 .83909 L .59576 .84553 L p .707 .577 .707 r
F P
0 g
s
.62706 .83909 m .63045 .85664 L .65921 .84699 L p .707 .577 .707 r
F P
0 g
s
.65921 .84699 m .65582 .82945 L .62706 .83909 L p .707 .577 .707 r
F P
0 g
s
.68644 .68451 m .68352 .7404 L .69636 .7339 L p .707 .577 .707 r
F P
0 g
s
.69636 .7339 m .69928 .67801 L .68644 .68451 L p .707 .577 .707 r
F P
0 g
s
.52871 .80854 m .52671 .77187 L .50717 .76532 L p .707 .577 .707 r
F P
0 g
s
.5055 .67121 m .50258 .7271 L .51868 .73462 L p .707 .577 .707 r
F P
0 g
s
.56499 .84812 m .56838 .86567 L .59915 .86307 L p .707 .577 .707 r
F P
0 g
s
.67094 .7634 m .67294 .80007 L .69092 .79131 L p .707 .577 .707 r
F P
0 g
s
.69092 .79131 m .68892 .75464 L .67094 .7634 L p .707 .577 .707 r
F P
0 g
s
.56838 .86567 m .56499 .84812 L .53777 .84662 L p .707 .577 .707 r
F P
0 g
s
.65582 .82945 m .65921 .84699 L .68263 .83508 L p .707 .577 .707 r
F P
0 g
s
.68263 .83508 m .67924 .81754 L .65582 .82945 L p .707 .577 .707 r
F P
0 g
s
.53777 .84662 m .54116 .86417 L .56838 .86567 L p .707 .577 .707 r
F P
0 g
s
.50717 .76532 m .50917 .80199 L .52871 .80854 L p .707 .577 .707 r
F P
0 g
s
.50258 .7271 m .5055 .67121 L .4987 .66327 L p .707 .577 .707 r
F P
0 g
s
.54116 .86417 m .53777 .84662 L .51675 .84118 L p .707 .577 .707 r
F P
0 g
s
.67924 .81754 m .68263 .83508 L .69841 .82207 L p .707 .577 .707 r
F P
0 g
s
.69841 .82207 m .69502 .80453 L .67924 .81754 L p .707 .577 .707 r
F P
0 g
s
.50917 .80199 m .50717 .76532 L .49639 .75689 L p .707 .577 .707 r
F P
0 g
s
.69928 .67801 m .69636 .7339 L .69954 .7263 L p .707 .577 .707 r
F P
0 g
s
.69954 .7263 m .70245 .67041 L .69928 .67801 L p .707 .577 .707 r
F P
0 g
s
.51675 .84118 m .52014 .85872 L .54116 .86417 L p .707 .577 .707 r
F P
0 g
s
.4987 .66327 m .49579 .71915 L .50258 .7271 L p .707 .577 .707 r
F P
0 g
s
.68892 .75464 m .69092 .79131 L .69986 .78173 L p .707 .577 .707 r
F P
0 g
s
.69986 .78173 m .69786 .74506 L .68892 .75464 L p .707 .577 .707 r
F P
0 g
s
.49639 .75689 m .49839 .79357 L .50917 .80199 L p .707 .577 .707 r
F P
0 g
s
.52014 .85872 m .51675 .84118 L .504 .83232 L p .707 .577 .707 r
F P
0 g
s
.49579 .71915 m .4987 .66327 L .50188 .65567 L p .707 .577 .707 r
F P
0 g
s
.69502 .80453 m .69841 .82207 L .705 .80924 L p .707 .577 .707 r
F P
0 g
s
.705 .80924 m .70161 .79169 L .69502 .80453 L p .707 .577 .707 r
F P
0 g
s
.504 .83232 m .50739 .84987 L .52014 .85872 L p .707 .577 .707 r
F P
0 g
s
.49839 .79357 m .49639 .75689 L .49543 .74743 L p .708 .578 .707 r
F P
0 g
s
.50188 .65567 m .49896 .71156 L .49579 .71915 L p .707 .577 .707 r
F P
0 g
s
.49543 .74743 m .49743 .7841 L .49839 .79357 L p .708 .578 .707 r
F P
0 g
s
.49743 .7841 m .49543 .74743 L .50437 .73785 L p .707 .577 .707 r
F P
0 g
s
.49723 .82192 m .49723 .32003 L .4528 .3179 L p .707 .577 .707 r
F P
0 g
s
.50739 .84987 m .504 .83232 L .50076 .82092 L p .707 .577 .707 r
F P
0 g
s
.49896 .71156 m .50188 .65567 L .51472 .64917 L p .707 .577 .707 r
F P
0 g
s
.50076 .82092 m .50415 .83846 L .50739 .84987 L p .707 .577 .707 r
F P
0 g
s
.51472 .64917 m .5118 .70506 L .49896 .71156 L p .707 .577 .707 r
F P
0 g
s
.50437 .73785 m .50637 .77452 L .49743 .7841 L p .707 .577 .707 r
F P
0 g
s
.50415 .83846 m .50076 .82092 L .50735 .80808 L p .707 .577 .707 r
F P
0 g
s
.5118 .70506 m .51472 .64917 L .53596 .6444 L p .707 .577 .707 r
F P
0 g
s
.50735 .80808 m .51075 .82562 L .50415 .83846 L p .707 .577 .707 r
F P
0 g
s
.50637 .77452 m .50437 .73785 L .52234 .72909 L p .707 .577 .707 r
F P
0 g
s
.53596 .6444 m .53304 .70028 L .5118 .70506 L p .707 .577 .707 r
F P
0 g
s
.52234 .72909 m .52434 .76576 L .50637 .77452 L p .707 .577 .707 r
F P
0 g
s
.51075 .82562 m .50735 .80808 L .52313 .79507 L p .707 .577 .707 r
F P
0 g
s
.52313 .79507 m .52652 .81261 L .51075 .82562 L p .707 .577 .707 r
F P
0 g
s
.52434 .76576 m .52234 .72909 L .54759 .72201 L p .707 .577 .707 r
F P
0 g
s
.54759 .72201 m .54959 .75868 L .52434 .76576 L p .707 .577 .707 r
F P
0 g
s
.52652 .81261 m .52313 .79507 L .54655 .78316 L p .707 .577 .707 r
F P
0 g
s
.54655 .78316 m .54994 .8007 L .52652 .81261 L p .707 .577 .707 r
F P
0 g
s
.49723 .32003 m .49723 .82192 L .54194 .82025 L p .707 .577 .707 r
F P
0 g
s
.53304 .70028 m .53596 .6444 L .56353 .64182 L p .707 .577 .707 r
F P
0 g
s
.56353 .64182 m .56061 .69771 L .53304 .70028 L p .707 .577 .707 r
F P
0 g
s
.54194 .82025 m .54194 .31836 L .49723 .32003 L p .707 .577 .707 r
F P
0 g
s
.69786 .74506 m .69986 .78173 L .69889 .77226 L p .708 .578 .707 r
F P
0 g
s
.69889 .77226 m .69689 .73559 L .69786 .74506 L p .708 .578 .707 r
F P
0 g
s
.70245 .67041 m .69954 .7263 L .69274 .71836 L p .707 .577 .707 r
F P
0 g
s
.69274 .71836 m .69566 .66247 L .70245 .67041 L p .707 .577 .707 r
F P
0 g
s
.56061 .69771 m .56353 .64182 L .59472 .6417 L p .707 .577 .707 r
F P
0 g
s
.59472 .6417 m .59181 .69758 L .56061 .69771 L p .707 .577 .707 r
F P
0 g
s
.54959 .75868 m .54759 .72201 L .57764 .7173 L p .707 .577 .707 r
F P
0 g
s
.57764 .7173 m .57964 .75398 L .54959 .75868 L p .707 .577 .707 r
F P
0 g
s
.54994 .8007 m .54655 .78316 L .57531 .77352 L p .707 .577 .707 r
F P
0 g
s
.57531 .77352 m .57871 .79106 L .54994 .8007 L p .707 .577 .707 r
F P
0 g
s
.57871 .79106 m .57531 .77352 L .60661 .76708 L p .707 .577 .707 r
F P
0 g
s
.60661 .76708 m .61001 .78463 L .57871 .79106 L p .707 .577 .707 r
F P
0 g
s
.54194 .31836 m .54194 .82025 L .58253 .81496 L p .707 .577 .707 r
F P
0 g
s
.57964 .75398 m .57764 .7173 L .60955 .71543 L p .707 .577 .707 r
F P
0 g
s
.60955 .71543 m .61155 .7521 L .57964 .75398 L p .707 .577 .707 r
F P
0 g
s
.58253 .81496 m .58253 .31307 L .54194 .31836 L p .707 .577 .707 r
F P
0 g
s
.4528 .81979 m .4528 .3179 L .41299 .3122 L p .707 .577 .707 r
F P
0 g
s
.4528 .3179 m .4528 .81979 L .49723 .82192 L p .707 .577 .707 r
F P
0 g
s
.70161 .79169 m .705 .80924 L .70176 .79783 L p .707 .577 .707 r
F P
0 g
s
.70176 .79783 m .69837 .78029 L .70161 .79169 L p .707 .577 .707 r
F P
0 g
s
.62649 .64403 m .62357 .69992 L .59181 .69758 L p .707 .577 .707 r
F P
0 g
s
.59181 .69758 m .59472 .6417 L .62649 .64403 L p .707 .577 .707 r
F P
0 g
s
.63738 .76449 m .64077 .78203 L .61001 .78463 L p .707 .577 .707 r
F P
0 g
s
.61001 .78463 m .60661 .76708 L .63738 .76449 L p .707 .577 .707 r
F P
0 g
s
.58253 .31307 m .58253 .81496 L .61505 .80656 L p .707 .577 .707 r
F P
0 g
s
.64019 .71657 m .64219 .75324 L .61155 .7521 L p .707 .577 .707 r
F P
0 g
s
.61155 .7521 m .60955 .71543 L .64019 .71657 L p .707 .577 .707 r
F P
0 g
s
.61505 .80656 m .61505 .30468 L .58253 .31307 L p .707 .577 .707 r
F P
0 g
s
.41299 .81409 m .41299 .3122 L .3817 .30348 L p .707 .577 .707 r
F P
0 g
s
.41299 .3122 m .41299 .81409 L .4528 .81979 L p .707 .577 .707 r
F P
0 g
s
.69689 .73559 m .69889 .77226 L .68811 .76384 L p .707 .577 .707 r
F P
0 g
s
.68811 .76384 m .68611 .72717 L .69689 .73559 L p .707 .577 .707 r
F P
0 g
s
.69566 .66247 m .69274 .71836 L .67664 .71084 L p .707 .577 .707 r
F P
0 g
s
.67664 .71084 m .67956 .65495 L .69566 .66247 L p .707 .577 .707 r
F P
0 g
s
.26351 .71579 m .26481 .66097 L .23301 .6593 L p .707 .577 .707 r
F P
0 g
s
.26481 .66097 m .26351 .71579 L .29474 .71434 L p .707 .577 .707 r
F P
0 g
s
.29474 .71434 m .29603 .65952 L .26481 .66097 L p .707 .577 .707 r
F P
0 g
s
.23171 .71412 m .23301 .6593 L .20374 .65468 L p .707 .577 .707 r
F P
0 g
s
.23301 .6593 m .23171 .71412 L .26351 .71579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29603 .65952 m .29474 .71434 L .32233 .70991 L p .707 .577 .707 r
F P
0 g
s
.32233 .70991 m .32363 .65509 L .29603 .65952 L p .707 .577 .707 r
F P
0 g
s
.20245 .7095 m .20374 .65468 L .17988 .64755 L p .707 .577 .707 r
F P
0 g
s
.20374 .65468 m .20245 .7095 L .23171 .71412 L p .707 .577 .707 r
F P
0 g
s
.69837 .78029 m .70176 .79783 L .68901 .78897 L p .707 .577 .707 r
F P
0 g
s
.68901 .78897 m .68562 .77143 L .69837 .78029 L p .707 .577 .707 r
F P
0 g
s
.65572 .6486 m .6528 .70449 L .62357 .69992 L p .707 .577 .707 r
F P
0 g
s
.62357 .69992 m .62649 .64403 L .65572 .6486 L p .707 .577 .707 r
F P
0 g
s
.61505 .30468 m .61505 .80656 L .6363 .79588 L p .707 .577 .707 r
F P
0 g
s
.6363 .79588 m .6363 .29399 L .61505 .30468 L p .707 .577 .707 r
F P
0 g
s
.32363 .65509 m .32233 .70991 L .34359 .70294 L p .707 .577 .707 r
F P
0 g
s
.34359 .70294 m .34488 .64812 L .32363 .65509 L p .707 .577 .707 r
F P
0 g
s
.24519 .768 m .24428 .73057 L .2136 .72923 L p .707 .577 .707 r
F P
0 g
s
.24428 .73057 m .24519 .768 L .27713 .76704 L p .707 .577 .707 r
F P
0 g
s
.27713 .76704 m .27622 .72962 L .24428 .73057 L p .707 .577 .707 r
F P
0 g
s
.27622 .72962 m .27713 .76704 L .30721 .76387 L p .707 .577 .707 r
F P
0 g
s
.30721 .76387 m .3063 .72644 L .27622 .72962 L p .707 .577 .707 r
F P
0 g
s
.3817 .80536 m .3817 .30348 L .36198 .29258 L p .707 .577 .707 r
F P
0 g
s
.3817 .30348 m .3817 .80536 L .41299 .81409 L p .707 .577 .707 r
F P
0 g
s
.67956 .65495 m .67664 .71084 L .6528 .70449 L p .707 .577 .707 r
F P
0 g
s
.6528 .70449 m .65572 .6486 L .67956 .65495 L p .707 .577 .707 r
F P
0 g
s
.68611 .72717 m .68811 .76384 L .66858 .75729 L p .707 .577 .707 r
F P
0 g
s
.66858 .75729 m .66658 .72062 L .68611 .72717 L p .707 .577 .707 r
F P
0 g
s
.2136 .72923 m .21451 .76666 L .24519 .768 L p .707 .577 .707 r
F P
0 g
s
.21451 .76666 m .2136 .72923 L .18719 .72571 L p .707 .577 .707 r
F P
0 g
s
.17988 .64755 m .17858 .70237 L .20245 .7095 L p .707 .577 .707 r
F P
0 g
s
.25524 .80286 m .25368 .78389 L .22252 .78544 L p .707 .577 .707 r
F P
0 g
s
.25368 .78389 m .25524 .80286 L .28693 .79982 L p .707 .577 .707 r
F P
0 g
s
.28693 .79982 m .28536 .78085 L .25368 .78389 L p .707 .577 .707 r
F P
0 g
s
.3063 .72644 m .30721 .76387 L .33248 .7588 L p .707 .577 .707 r
F P
0 g
s
.33248 .7588 m .33157 .72137 L .3063 .72644 L p .707 .577 .707 r
F P
0 g
s
.17858 .70237 m .17988 .64755 L .16375 .63862 L p .707 .577 .707 r
F P
0 g
s
.22252 .78544 m .22408 .80441 L .25524 .80286 L p .707 .577 .707 r
F P
0 g
s
.28536 .78085 m .28693 .79982 L .31605 .79561 L p .707 .577 .707 r
F P
0 g
s
.31605 .79561 m .31448 .77664 L .28536 .78085 L p .707 .577 .707 r
F P
0 g
s
.22408 .80441 m .22252 .78544 L .19494 .78536 L p .707 .577 .707 r
F P
0 g
s
.18719 .72571 m .1881 .76314 L .21451 .76666 L p .707 .577 .707 r
F P
0 g
s
.19494 .78536 m .1965 .80433 L .22408 .80441 L p .707 .577 .707 r
F P
0 g
s
.34488 .64812 m .34359 .70294 L .35643 .69411 L p .707 .577 .707 r
F P
0 g
s
.35643 .69411 m .35773 .63929 L .34488 .64812 L p .707 .577 .707 r
F P
0 g
s
.68562 .77143 m .68901 .78897 L .668 .78353 L p .707 .577 .707 r
F P
0 g
s
.668 .78353 m .6646 .76598 L .68562 .77143 L p .707 .577 .707 r
F P
0 g
s
.31448 .77664 m .31605 .79561 L .33975 .79062 L p .707 .577 .707 r
F P
0 g
s
.33975 .79062 m .33818 .77165 L .31448 .77664 L p .707 .577 .707 r
F P
0 g
s
.1881 .76314 m .18719 .72571 L .16762 .72037 L p .707 .577 .707 r
F P
0 g
s
.66658 .72062 m .66858 .75729 L .64219 .75324 L p .707 .577 .707 r
F P
0 g
s
.64219 .75324 m .64019 .71657 L .66658 .72062 L p .707 .577 .707 r
F P
0 g
s
.16375 .63862 m .16245 .69344 L .17858 .70237 L p .707 .577 .707 r
F P
0 g
s
.33157 .72137 m .33248 .7588 L .35047 .75233 L p .707 .577 .707 r
F P
0 g
s
.35047 .75233 m .34956 .7149 L .33157 .72137 L p .707 .577 .707 r
F P
0 g
s
.1965 .80433 m .19494 .78536 L .17364 .78366 L p .707 .577 .707 r
F P
0 g
s
.6646 .76598 m .668 .78353 L .64077 .78203 L p .707 .577 .707 r
F P
0 g
s
.64077 .78203 m .63738 .76449 L .6646 .76598 L p .707 .577 .707 r
F P
0 g
s
.6363 .29399 m .6363 .79588 L .64422 .78396 L p .707 .577 .707 r
F P
0 g
s
.64422 .78396 m .64422 .28207 L .6363 .29399 L p .707 .577 .707 r
F P
0 g
s
.16762 .72037 m .16853 .7578 L .1881 .76314 L p .707 .577 .707 r
F P
0 g
s
.17364 .78366 m .17521 .80263 L .1965 .80433 L p .707 .577 .707 r
F P
0 g
s
.16245 .69344 m .16375 .63862 L .15694 .62876 L p .707 .577 .707 r
F P
0 g
s
.3596 .68428 m .3609 .62946 L .35773 .63929 L p .707 .577 .707 r
F P
0 g
s
.35414 .76638 m .3557 .78535 L .36236 .78031 L p .707 .577 .707 r
F P
0 g
s
.36236 .78031 m .36079 .76135 L .35414 .76638 L p .707 .577 .707 r
F P
0 g
s
.35773 .63929 m .35643 .69411 L .3596 .68428 L p .707 .577 .707 r
F P
0 g
s
.3609 .62946 m .3596 .68428 L .35279 .67442 L p .707 .577 .707 r
F P
0 g
s
.35279 .67442 m .35409 .6196 L .3609 .62946 L p .707 .577 .707 r
F P
0 g
s
.36079 .76135 m .36236 .78031 L .35906 .77601 L p .707 .577 .707 r
F P
0 g
s
.36198 .79447 m .36198 .29258 L .35578 .28059 L p .707 .577 .707 r
F P
0 g
s
.36198 .29258 m .36198 .79447 L .3817 .80536 L p .707 .577 .707 r
F P
0 g
s
.33818 .77165 m .33975 .79062 L .3557 .78535 L p .707 .577 .707 r
F P
0 g
s
.3557 .78535 m .35414 .76638 L .33818 .77165 L p .707 .577 .707 r
F P
0 g
s
.16853 .7578 m .16762 .72037 L .15683 .71372 L p .707 .577 .707 r
F P
0 g
s
.15694 .62876 m .15564 .68358 L .16245 .69344 L p .707 .577 .707 r
F P
0 g
s
.34956 .7149 m .35047 .75233 L .35942 .74509 L p .707 .577 .707 r
F P
0 g
s
.35942 .74509 m .35851 .70766 L .34956 .7149 L p .707 .577 .707 r
F P
0 g
s
.17521 .80263 m .17364 .78366 L .16071 .7805 L p .707 .577 .707 r
F P
0 g
s
.16071 .7805 m .16227 .79947 L .17521 .80263 L p .707 .577 .707 r
F P
0 g
s
.15683 .71372 m .15774 .75115 L .16853 .7578 L p .707 .577 .707 r
F P
0 g
s
.15564 .68358 m .15694 .62876 L .16011 .61893 L p .707 .577 .707 r
F P
0 g
s
.64422 .28207 m .64422 .78396 L .63801 .77197 L p .707 .577 .707 r
F P
0 g
s
.63801 .77197 m .63801 .27008 L .64422 .28207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15774 .75115 m .15683 .71372 L .15586 .70641 L p .707 .578 .707 r
F P
0 g
s
.35851 .70766 m .35942 .74509 L .35845 .73778 L p .707 .578 .707 r
F P
0 g
s
.35845 .73778 m .35754 .70035 L .35851 .70766 L p .707 .578 .707 r
F P
0 g
s
.35906 .77601 m .35749 .75704 L .36079 .76135 L p .707 .577 .707 r
F P
0 g
s
.35754 .70035 m .35845 .73778 L .34765 .73113 L p .707 .577 .707 r
F P
0 g
s
.34765 .73113 m .34674 .6937 L .35754 .70035 L p .707 .577 .707 r
F P
0 g
s
.35749 .75704 m .35906 .77601 L .34612 .77285 L p .707 .577 .707 r
F P
0 g
s
.34612 .77285 m .34456 .75388 L .35749 .75704 L p .707 .577 .707 r
F P
0 g
s
.35578 .28059 m .35578 .78248 L .36198 .79447 L p .707 .577 .707 r
F P
0 g
s
.35578 .78248 m .35578 .28059 L .36369 .26867 L p .707 .577 .707 r
F P
0 g
s
.16011 .61893 m .15882 .67375 L .15564 .68358 L p .707 .577 .707 r
F P
0 g
s
.16227 .79947 m .16071 .7805 L .15741 .77619 L p .707 .577 .707 r
F P
0 g
s
.15741 .77619 m .15897 .79516 L .16227 .79947 L p .707 .577 .707 r
F P
0 g
s
.15586 .70641 m .15677 .74384 L .15774 .75115 L p .707 .578 .707 r
F P
0 g
s
.15882 .67375 m .16011 .61893 L .17296 .6101 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35409 .6196 m .35279 .67442 L .33666 .66549 L p .707 .577 .707 r
F P
0 g
s
.33666 .66549 m .33796 .61067 L .35409 .6196 L p .707 .577 .707 r
F P
0 g
s
.15677 .74384 m .15586 .70641 L .1648 .69917 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17296 .6101 m .17166 .66492 L .15882 .67375 L p .707 .577 .707 r
F P
0 g
s
.15897 .79516 m .15741 .77619 L .16407 .77116 L p .707 .577 .707 r
F P
0 g
s
.16407 .77116 m .16563 .79013 L .15897 .79516 L p .707 .577 .707 r
F P
0 g
s
.1648 .69917 m .16571 .7366 L .15677 .74384 L p .707 .577 .707 r
F P
0 g
s
.63801 .27008 m .63801 .77197 L .6183 .76107 L p .707 .577 .707 r
F P
0 g
s
.6183 .76107 m .6183 .25918 L .63801 .27008 L p .707 .577 .707 r
F P
0 g
s
.17166 .66492 m .17296 .6101 L .19422 .60313 L p .707 .577 .707 r
F P
0 g
s
.36369 .77055 m .36369 .26867 L .38495 .25798 L p .707 .577 .707 r
F P
0 g
s
.36369 .26867 m .36369 .77055 L .35578 .78248 L p .707 .577 .707 r
F P
0 g
s
.33796 .61067 m .33666 .66549 L .3128 .65836 L p .707 .577 .707 r
F P
0 g
s
.3128 .65836 m .3141 .60354 L .33796 .61067 L p .707 .577 .707 r
F P
0 g
s
.16571 .7366 m .1648 .69917 L .18279 .69269 L p .707 .577 .707 r
F P
0 g
s
.19422 .60313 m .19292 .65795 L .17166 .66492 L p .707 .577 .707 r
F P
0 g
s
.34674 .6937 m .34765 .73113 L .32809 .72578 L p .707 .577 .707 r
F P
0 g
s
.32809 .72578 m .32718 .68835 L .34674 .6937 L p .707 .577 .707 r
F P
0 g
s
.19292 .65795 m .19422 .60313 L .22181 .5987 L p .707 .577 .707 r
F P
0 g
s
.16563 .79013 m .16407 .77116 L .18002 .76589 L p .707 .577 .707 r
F P
0 g
s
.18279 .69269 m .1837 .73012 L .16571 .7366 L p .707 .577 .707 r
F P
0 g
s
.18002 .76589 m .18159 .78486 L .16563 .79013 L p .707 .577 .707 r
F P
0 g
s
.3141 .60354 m .3128 .65836 L .28353 .65374 L p .707 .577 .707 r
F P
0 g
s
.28353 .65374 m .28483 .59892 L .3141 .60354 L p .707 .577 .707 r
F P
0 g
s
.6183 .25918 m .6183 .76107 L .58701 .75235 L p .707 .577 .707 r
F P
0 g
s
.58701 .75235 m .58701 .25046 L .6183 .25918 L p .707 .577 .707 r
F P
0 g
s
.22051 .65352 m .22181 .5987 L .25303 .59725 L p .707 .577 .707 r
F P
0 g
s
.22181 .5987 m .22051 .65352 L .19292 .65795 L p .707 .577 .707 r
F P
0 g
s
.38495 .25798 m .38495 .75987 L .36369 .77055 L p .707 .577 .707 r
F P
0 g
s
.38495 .75987 m .38495 .25798 L .41747 .24959 L p .707 .577 .707 r
F P
0 g
s
.34456 .75388 m .34612 .77285 L .32483 .77114 L p .707 .577 .707 r
F P
0 g
s
.32483 .77114 m .32326 .75217 L .34456 .75388 L p .707 .577 .707 r
F P
0 g
s
.1837 .73012 m .18279 .69269 L .20806 .68762 L p .707 .577 .707 r
F P
0 g
s
.74826 .65425 m .74697 .59805 L .71516 .59803 L p .707 .577 .707 r
F P
0 g
s
.74697 .59805 m .74826 .65425 L .77949 .65203 L p .707 .577 .707 r
F P
0 g
s
.77949 .65203 m .77819 .59583 L .74697 .59805 L p .707 .577 .707 r
F P
0 g
s
.28483 .59892 m .28353 .65374 L .25173 .65207 L p .707 .577 .707 r
F P
0 g
s
.25173 .65207 m .25303 .59725 L .28483 .59892 L p .707 .577 .707 r
F P
0 g
s
.25303 .59725 m .25173 .65207 L .22051 .65352 L p .707 .577 .707 r
F P
0 g
s
.71646 .65424 m .71516 .59803 L .6859 .59578 L p .707 .577 .707 r
F P
0 g
s
.71516 .59803 m .71646 .65424 L .74826 .65425 L p .707 .577 .707 r
F P
0 g
s
.32718 .68835 m .32809 .72578 L .30168 .72227 L p .707 .577 .707 r
F P
0 g
s
.30168 .72227 m .30077 .68484 L .32718 .68835 L p .707 .577 .707 r
F P
0 g
s
.77819 .59583 m .77949 .65203 L .80708 .6478 L p .707 .577 .707 r
F P
0 g
s
.80708 .6478 m .80578 .59159 L .77819 .59583 L p .707 .577 .707 r
F P
0 g
s
.18159 .78486 m .18002 .76589 L .20372 .7609 L p .707 .577 .707 r
F P
0 g
s
.20806 .68762 m .20898 .72505 L .1837 .73012 L p .707 .577 .707 r
F P
0 g
s
.20372 .7609 m .20528 .77987 L .18159 .78486 L p .707 .577 .707 r
F P
0 g
s
.6872 .65199 m .6859 .59578 L .66204 .59152 L p .707 .577 .707 r
F P
0 g
s
.6859 .59578 m .6872 .65199 L .71646 .65424 L p .707 .577 .707 r
F P
0 g
s
.20898 .72505 m .20806 .68762 L .23814 .68445 L p .707 .577 .707 r
F P
0 g
s
.30077 .68484 m .30168 .72227 L .271 .72092 L p .707 .577 .707 r
F P
0 g
s
.271 .72092 m .27009 .68349 L .30077 .68484 L p .707 .577 .707 r
F P
0 g
s
.32326 .75217 m .32483 .77114 L .29725 .77107 L p .707 .577 .707 r
F P
0 g
s
.29725 .77107 m .29569 .7521 L .32326 .75217 L p .707 .577 .707 r
F P
0 g
s
.729 .72246 m .72991 .68586 L .69923 .68242 L p .707 .577 .707 r
F P
0 g
s
.72991 .68586 m .729 .72246 L .76094 .72288 L p .707 .577 .707 r
F P
0 g
s
.76094 .72288 m .76185 .68628 L .72991 .68586 L p .707 .577 .707 r
F P
0 g
s
.80578 .59159 m .80708 .6478 L .82834 .64196 L p .707 .577 .707 r
F P
0 g
s
.82834 .64196 m .82704 .58576 L .80578 .59159 L p .707 .577 .707 r
F P
0 g
s
.76185 .68628 m .76094 .72288 L .79102 .72025 L p .707 .577 .707 r
F P
0 g
s
.79102 .72025 m .79193 .68365 L .76185 .68628 L p .707 .577 .707 r
F P
0 g
s
.58701 .25046 m .58701 .75235 L .54719 .74664 L p .707 .577 .707 r
F P
0 g
s
.54719 .74664 m .54719 .24475 L .58701 .25046 L p .707 .577 .707 r
F P
0 g
s
.41747 .75148 m .41747 .24959 L .45806 .2443 L p .707 .577 .707 r
F P
0 g
s
.41747 .24959 m .41747 .75148 L .38495 .75987 L p .707 .577 .707 r
F P
0 g
s
.23814 .68445 m .23905 .72188 L .20898 .72505 L p .707 .577 .707 r
F P
0 g
s
.66204 .59152 m .66334 .64773 L .6872 .65199 L p .707 .577 .707 r
F P
0 g
s
.20528 .77987 m .20372 .7609 L .23284 .75668 L p .707 .577 .707 r
F P
0 g
s
.23905 .72188 m .23814 .68445 L .27009 .68349 L p .707 .577 .707 r
F P
0 g
s
.69832 .71902 m .69923 .68242 L .67282 .67631 L p .707 .577 .707 r
F P
0 g
s
.69923 .68242 m .69832 .71902 L .729 .72246 L p .707 .577 .707 r
F P
0 g
s
.27009 .68349 m .271 .72092 L .23905 .72188 L p .707 .577 .707 r
F P
0 g
s
.23284 .75668 m .2344 .77565 L .20528 .77987 L p .707 .577 .707 r
F P
0 g
s
.79193 .68365 m .79102 .72025 L .81629 .71481 L p .707 .577 .707 r
F P
0 g
s
.81629 .71481 m .81721 .67821 L .79193 .68365 L p .707 .577 .707 r
F P
0 g
s
.66334 .64773 m .66204 .59152 L .64591 .58567 L p .707 .577 .707 r
F P
0 g
s
.29569 .7521 m .29725 .77107 L .26609 .77262 L p .707 .577 .707 r
F P
0 g
s
.26609 .77262 m .26453 .75365 L .29569 .7521 L p .707 .577 .707 r
F P
0 g
s
.67282 .67631 m .67191 .7129 L .69832 .71902 L p .707 .577 .707 r
F P
0 g
s
.2344 .77565 m .23284 .75668 L .26453 .75365 L p .707 .577 .707 r
F P
0 g
s
.26453 .75365 m .26609 .77262 L .2344 .77565 L p .707 .577 .707 r
F P
0 g
s
.54719 .24475 m .54719 .74664 L .50276 .74452 L p .707 .577 .707 r
F P
0 g
s
.50276 .74452 m .50276 .24263 L .54719 .24475 L p .707 .577 .707 r
F P
0 g
s
.82704 .58576 m .82834 .64196 L .84118 .63509 L p .707 .577 .707 r
F P
0 g
s
.84118 .63509 m .83988 .57889 L .82704 .58576 L p .707 .577 .707 r
F P
0 g
s
.73391 .7711 m .73547 .75343 L .70431 .7485 L p .707 .577 .707 r
F P
0 g
s
.73547 .75343 m .73391 .7711 L .7656 .77219 L p .707 .577 .707 r
F P
0 g
s
.7656 .77219 m .76716 .75453 L .73547 .75343 L p .707 .577 .707 r
F P
0 g
s
.45806 .74619 m .45806 .2443 L .50276 .24263 L p .707 .577 .707 r
F P
0 g
s
.45806 .2443 m .45806 .74619 L .41747 .75148 L p .707 .577 .707 r
F P
0 g
s
.67191 .7129 m .67282 .67631 L .65326 .66811 L p .707 .577 .707 r
F P
0 g
s
.76716 .75453 m .7656 .77219 L .79471 .76934 L p .707 .577 .707 r
F P
0 g
s
.79471 .76934 m .79628 .75168 L .76716 .75453 L p .707 .577 .707 r
F P
0 g
s
.64591 .58567 m .64721 .64187 L .66334 .64773 L p .707 .577 .707 r
F P
0 g
s
.70275 .76616 m .70431 .7485 L .67673 .74021 L p .707 .577 .707 r
F P
0 g
s
.70431 .7485 m .70275 .76616 L .73391 .7711 L p .707 .577 .707 r
F P
0 g
s
.81721 .67821 m .81629 .71481 L .83428 .70711 L p .707 .577 .707 r
F P
0 g
s
.83428 .70711 m .8352 .67051 L .81721 .67821 L p .707 .577 .707 r
F P
0 g
s
.50276 .24263 m .50276 .74452 L .45806 .74619 L p .707 .577 .707 r
F P
0 g
s
.67673 .74021 m .67517 .75787 L .70275 .76616 L p .707 .577 .707 r
F P
0 g
s
.65326 .66811 m .65234 .70471 L .67191 .7129 L p .707 .577 .707 r
F P
0 g
s
.79628 .75168 m .79471 .76934 L .81841 .76282 L p .707 .577 .707 r
F P
0 g
s
.81841 .76282 m .81998 .74516 L .79628 .75168 L p .707 .577 .707 r
F P
0 g
s
.64721 .64187 m .64591 .58567 L .6391 .57879 L p .707 .577 .707 r
F P
0 g
s
.67517 .75787 m .67673 .74021 L .65544 .72937 L p .707 .577 .707 r
F P
0 g
s
.65234 .70471 m .65326 .66811 L .64246 .65863 L p .707 .577 .707 r
F P
0 g
s
.65544 .72937 m .65387 .74703 L .67517 .75787 L p .707 .577 .707 r
F P
0 g
s
.83988 .57889 m .84118 .63509 L .84435 .62786 L p .707 .577 .707 r
F P
0 g
s
.84435 .62786 m .84305 .57166 L .83988 .57889 L p .707 .577 .707 r
F P
0 g
s
.6391 .57879 m .6404 .63499 L .64721 .64187 L p .707 .577 .707 r
F P
0 g
s
.8352 .67051 m .83428 .70711 L .84323 .69789 L p .707 .577 .707 r
F P
0 g
s
.84323 .69789 m .84414 .6613 L .8352 .67051 L p .707 .577 .707 r
F P
0 g
s
.64246 .65863 m .64155 .69523 L .65234 .70471 L p .707 .577 .707 r
F P
0 g
s
.81998 .74516 m .81841 .76282 L .83437 .75327 L p .707 .577 .707 r
F P
0 g
s
.83437 .75327 m .83593 .73561 L .81998 .74516 L p .707 .577 .707 r
F P
0 g
s
.65387 .74703 m .65544 .72937 L .6425 .71705 L p .707 .577 .707 r
F P
0 g
s
.6425 .71705 m .64094 .73471 L .65387 .74703 L p .707 .577 .707 r
F P
0 g
s
.6404 .63499 m .6391 .57879 L .64227 .57156 L p .707 .577 .707 r
F P
0 g
s
.64155 .69523 m .64246 .65863 L .64149 .6488 L p .707 .577 .707 r
F P
0 g
s
.84305 .57166 m .84435 .62786 L .83754 .62098 L p .707 .577 .707 r
F P
0 g
s
.83754 .62098 m .83624 .56478 L .84305 .57166 L p .707 .577 .707 r
F P
0 g
s
.84414 .6613 m .84323 .69789 L .84226 .68807 L p .707 .577 .707 r
F P
0 g
s
.84226 .68807 m .84317 .65147 L .84414 .6613 L p .707 .577 .707 r
F P
0 g
s
.64227 .57156 m .64357 .62776 L .6404 .63499 L p .707 .577 .707 r
F P
0 g
s
.83593 .73561 m .83437 .75327 L .84102 .74163 L p .707 .577 .707 r
F P
0 g
s
.84102 .74163 m .84259 .72397 L .83593 .73561 L p .707 .577 .707 r
F P
0 g
s
.64149 .6488 m .64058 .6854 L .64155 .69523 L p .707 .577 .707 r
F P
0 g
s
.64094 .73471 m .6425 .71705 L .6392 .70445 L p .707 .577 .707 r
F P
0 g
s
.6392 .70445 m .63764 .72212 L .64094 .73471 L p .707 .577 .707 r
F P
0 g
s
.64357 .62776 m .64227 .57156 L .65511 .56469 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64058 .6854 m .64149 .6488 L .65044 .63959 L p .707 .577 .707 r
F P
0 g
s
.83624 .56478 m .83754 .62098 L .82142 .61513 L p .707 .577 .707 r
F P
0 g
s
.82142 .61513 m .82012 .55892 L .83624 .56478 L p .707 .577 .707 r
F P
0 g
s
.84317 .65147 m .84226 .68807 L .83146 .67859 L p .707 .577 .707 r
F P
0 g
s
.83146 .67859 m .83238 .64199 L .84317 .65147 L p .707 .577 .707 r
F P
0 g
s
.40819 .62219 m .40527 .56709 L .37351 .5677 L p .707 .577 .707 r
F P
0 g
s
.40527 .56709 m .40819 .62219 L .43939 .61869 L p .707 .577 .707 r
F P
0 g
s
.43939 .61869 m .43647 .56359 L .40527 .56709 L p .707 .577 .707 r
F P
0 g
s
.84259 .72397 m .84102 .74163 L .83772 .72903 L p .707 .577 .707 r
F P
0 g
s
.83772 .72903 m .83929 .71137 L .84259 .72397 L p .707 .577 .707 r
F P
0 g
s
.65511 .56469 m .65641 .62089 L .64357 .62776 L p .707 .577 .707 r
F P
0 g
s
.37642 .6228 m .37351 .5677 L .34427 .56535 L p .707 .577 .707 r
F P
0 g
s
.37351 .5677 m .37642 .6228 L .40819 .62219 L p .707 .577 .707 r
F P
0 g
s
.63764 .72212 m .6392 .70445 L .64586 .69281 L p .707 .577 .707 r
F P
0 g
s
.65044 .63959 m .64952 .67618 L .64058 .6854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.43647 .56359 m .43939 .61869 L .46695 .61264 L p .707 .577 .707 r
F P
0 g
s
.46695 .61264 m .46404 .55754 L .43647 .56359 L p .707 .577 .707 r
F P
0 g
s
.64586 .69281 m .6443 .71047 L .63764 .72212 L p .707 .577 .707 r
F P
0 g
s
.34719 .62045 m .34427 .56535 L .32044 .56028 L p .707 .577 .707 r
F P
0 g
s
.34427 .56535 m .34719 .62045 L .37642 .6228 L p .707 .577 .707 r
F P
0 g
s
.65641 .62089 m .65511 .56469 L .67637 .55885 L p .707 .577 .707 r
F P
0 g
s
.46404 .55754 m .46695 .61264 L .4882 .60462 L p .707 .577 .707 r
F P
0 g
s
.4882 .60462 m .48528 .54952 L .46404 .55754 L p .707 .577 .707 r
F P
0 g
s
.64952 .67618 m .65044 .63959 L .66843 .63188 L p .707 .577 .707 r
F P
0 g
s
.38845 .67671 m .39045 .63941 L .3598 .63572 L p .707 .577 .707 r
F P
0 g
s
.39045 .63941 m .38845 .67671 L .42036 .67809 L p .707 .577 .707 r
F P
0 g
s
.42036 .67809 m .42236 .64079 L .39045 .63941 L p .707 .577 .707 r
F P
0 g
s
.42236 .64079 m .42036 .67809 L .45041 .67704 L p .707 .577 .707 r
F P
0 g
s
.45041 .67704 m .45241 .63973 L .42236 .64079 L p .707 .577 .707 r
F P
0 g
s
.82012 .55892 m .82142 .61513 L .79755 .61087 L p .707 .577 .707 r
F P
0 g
s
.79755 .61087 m .79625 .55466 L .82012 .55892 L p .707 .577 .707 r
F P
0 g
s
.83238 .64199 m .83146 .67859 L .8119 .67039 L p .707 .577 .707 r
F P
0 g
s
.8119 .67039 m .81281 .63379 L .83238 .64199 L p .707 .577 .707 r
F P
0 g
s
.67637 .55885 m .67767 .61506 L .65641 .62089 L p .707 .577 .707 r
F P
0 g
s
.83929 .71137 m .83772 .72903 L .82479 .71671 L p .707 .577 .707 r
F P
0 g
s
.82479 .71671 m .82636 .69905 L .83929 .71137 L p .707 .577 .707 r
F P
0 g
s
.3578 .67302 m .3598 .63572 L .33342 .63009 L p .707 .577 .707 r
F P
0 g
s
.3598 .63572 m .3578 .67302 L .38845 .67671 L p .707 .577 .707 r
F P
0 g
s
.6443 .71047 m .64586 .69281 L .66182 .68326 L p .707 .577 .707 r
F P
0 g
s
.32044 .56028 m .32336 .61538 L .34719 .62045 L p .707 .577 .707 r
F P
0 g
s
.66843 .63188 m .66751 .66848 L .64952 .67618 L p .707 .577 .707 r
F P
0 g
s
.45241 .63973 m .45041 .67704 L .47565 .67364 L p .707 .577 .707 r
F P
0 g
s
.47565 .67364 m .47766 .63634 L .45241 .63973 L p .707 .577 .707 r
F P
0 g
s
.38999 .71068 m .39339 .69199 L .36262 .68549 L p .707 .577 .707 r
F P
0 g
s
.39339 .69199 m .38999 .71068 L .42129 .7157 L p .707 .577 .707 r
F P
0 g
s
.42129 .7157 m .42468 .69701 L .39339 .69199 L p .707 .577 .707 r
F P
0 g
s
.32336 .61538 m .32044 .56028 L .30434 .55298 L p .707 .577 .707 r
F P
0 g
s
.36262 .68549 m .35922 .70418 L .38999 .71068 L p .707 .577 .707 r
F P
0 g
s
.67767 .61506 m .67637 .55885 L .70396 .55462 L p .707 .577 .707 r
F P
0 g
s
.42468 .69701 m .42129 .7157 L .45006 .71875 L p .707 .577 .707 r
F P
0 g
s
.45006 .71875 m .45345 .70006 L .42468 .69701 L p .707 .577 .707 r
F P
0 g
s
.33342 .63009 m .33142 .66739 L .3578 .67302 L p .707 .577 .707 r
F P
0 g
s
.66182 .68326 m .66025 .70092 L .6443 .71047 L p .707 .577 .707 r
F P
0 g
s
.35922 .70418 m .36262 .68549 L .33539 .67814 L p .707 .577 .707 r
F P
0 g
s
.48528 .54952 m .4882 .60462 L .50103 .59543 L p .707 .577 .707 r
F P
0 g
s
.50103 .59543 m .49812 .54033 L .48528 .54952 L p .707 .577 .707 r
F P
0 g
s
.33539 .67814 m .332 .69684 L .35922 .70418 L p .707 .577 .707 r
F P
0 g
s
.79625 .55466 m .79755 .61087 L .76829 .60862 L p .707 .577 .707 r
F P
0 g
s
.76829 .60862 m .76699 .55241 L .79625 .55466 L p .707 .577 .707 r
F P
0 g
s
.66751 .66848 m .66843 .63188 L .6937 .62645 L p .707 .577 .707 r
F P
0 g
s
.33142 .66739 m .33342 .63009 L .31388 .62306 L p .707 .577 .707 r
F P
0 g
s
.81281 .63379 m .8119 .67039 L .78549 .66427 L p .707 .577 .707 r
F P
0 g
s
.78549 .66427 m .7864 .62767 L .81281 .63379 L p .707 .577 .707 r
F P
0 g
s
.70396 .55462 m .70526 .61082 L .67767 .61506 L p .707 .577 .707 r
F P
0 g
s
.45345 .70006 m .45006 .71875 L .47347 .71954 L p .707 .577 .707 r
F P
0 g
s
.47347 .71954 m .47687 .70084 L .45345 .70006 L p .707 .577 .707 r
F P
0 g
s
.30434 .55298 m .30726 .60807 L .32336 .61538 L p .707 .577 .707 r
F P
0 g
s
.47766 .63634 m .47565 .67364 L .49363 .66825 L p .707 .577 .707 r
F P
0 g
s
.49363 .66825 m .49563 .63094 L .47766 .63634 L p .707 .577 .707 r
F P
0 g
s
.70526 .61082 m .70396 .55462 L .73519 .5524 L p .707 .577 .707 r
F P
0 g
s
.82636 .69905 m .82479 .71671 L .8035 .70588 L p .707 .577 .707 r
F P
0 g
s
.8035 .70588 m .80506 .68821 L .82636 .69905 L p .707 .577 .707 r
F P
0 g
s
.332 .69684 m .33539 .67814 L .31438 .67067 L p .707 .577 .707 r
F P
0 g
s
.31388 .62306 m .31188 .66037 L .33142 .66739 L p .707 .577 .707 r
F P
0 g
s
.76699 .55241 m .76829 .60862 L .73649 .6086 L p .707 .577 .707 r
F P
0 g
s
.73649 .6086 m .73519 .5524 L .76699 .55241 L p .707 .577 .707 r
F P
0 g
s
.6937 .62645 m .69279 .66305 L .66751 .66848 L p .707 .577 .707 r
F P
0 g
s
.66025 .70092 m .66182 .68326 L .68551 .67674 L p .707 .577 .707 r
F P
0 g
s
.31438 .67067 m .31098 .68937 L .332 .69684 L p .707 .577 .707 r
F P
0 g
s
.73519 .5524 m .73649 .6086 L .70526 .61082 L p .707 .577 .707 r
F P
0 g
s
.30726 .60807 m .30434 .55298 L .29754 .54416 L p .707 .577 .707 r
F P
0 g
s
.69279 .66305 m .6937 .62645 L .72378 .62381 L p .707 .577 .707 r
F P
0 g
s
.68551 .67674 m .68395 .69441 L .66025 .70092 L p .707 .577 .707 r
F P
0 g
s
.7864 .62767 m .78549 .66427 L .75481 .66083 L p .707 .577 .707 r
F P
0 g
s
.75481 .66083 m .75572 .62423 L .7864 .62767 L p .707 .577 .707 r
F P
0 g
s
.49812 .54033 m .50103 .59543 L .50421 .58596 L p .707 .577 .707 r
F P
0 g
s
.50421 .58596 m .50129 .53086 L .49812 .54033 L p .707 .577 .707 r
F P
0 g
s
.31188 .66037 m .31388 .62306 L .3031 .61534 L p .707 .577 .707 r
F P
0 g
s
.47687 .70084 m .47347 .71954 L .48925 .71797 L p .707 .577 .707 r
F P
0 g
s
.48925 .71797 m .49264 .69927 L .47687 .70084 L p .707 .577 .707 r
F P
0 g
s
.72287 .66041 m .72378 .62381 L .75572 .62423 L p .707 .577 .707 r
F P
0 g
s
.72378 .62381 m .72287 .66041 L .69279 .66305 L p .707 .577 .707 r
F P
0 g
s
.75572 .62423 m .75481 .66083 L .72287 .66041 L p .707 .577 .707 r
F P
0 g
s
.80506 .68821 m .8035 .70588 L .77592 .69758 L p .707 .577 .707 r
F P
0 g
s
.77592 .69758 m .77748 .67992 L .80506 .68821 L p .707 .577 .707 r
F P
0 g
s
.31098 .68937 m .31438 .67067 L .30163 .66381 L p .707 .577 .707 r
F P
0 g
s
.68395 .69441 m .68551 .67674 L .71463 .67389 L p .707 .577 .707 r
F P
0 g
s
.49563 .63094 m .49363 .66825 L .50257 .66137 L p .707 .577 .707 r
F P
0 g
s
.50257 .66137 m .50457 .62407 L .49563 .63094 L p .707 .577 .707 r
F P
0 g
s
.29754 .54416 m .30046 .59926 L .30726 .60807 L p .707 .577 .707 r
F P
0 g
s
.3031 .61534 m .3011 .65264 L .31188 .66037 L p .707 .577 .707 r
F P
0 g
s
.30163 .66381 m .29823 .6825 L .31098 .68937 L p .707 .577 .707 r
F P
0 g
s
.71463 .67389 m .71307 .69155 L .68395 .69441 L p .707 .577 .707 r
F P
0 g
s
.77748 .67992 m .77592 .69758 L .74476 .69265 L p .707 .577 .707 r
F P
0 g
s
.74476 .69265 m .74632 .67499 L .77748 .67992 L p .707 .577 .707 r
F P
0 g
s
.71307 .69155 m .71463 .67389 L .74632 .67499 L p .707 .577 .707 r
F P
0 g
s
.30046 .59926 m .29754 .54416 L .30072 .53469 L p .707 .577 .707 r
F P
0 g
s
.74632 .67499 m .74476 .69265 L .71307 .69155 L p .707 .577 .707 r
F P
0 g
s
.50129 .53086 m .50421 .58596 L .49742 .57714 L p .707 .577 .707 r
F P
0 g
s
.49742 .57714 m .4945 .52205 L .50129 .53086 L p .707 .577 .707 r
F P
0 g
s
.3011 .65264 m .3031 .61534 L .30214 .60766 L p .707 .577 .707 r
F P
0 g
s
.49264 .69927 m .48925 .71797 L .49584 .71421 L p .707 .577 .707 r
F P
0 g
s
.49584 .71421 m .49924 .69552 L .49264 .69927 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29823 .6825 m .30163 .66381 L .29839 .65823 L p .707 .577 .707 r
F P
0 g
s
.50457 .62407 m .50257 .66137 L .5016 .6537 L p .707 .577 .707 r
F P
0 g
s
.5016 .6537 m .5036 .61639 L .50457 .62407 L p .707 .577 .707 r
F P
0 g
s
.30072 .53469 m .30364 .58979 L .30046 .59926 L p .707 .577 .707 r
F P
0 g
s
.30214 .60766 m .30014 .64496 L .3011 .65264 L p .707 .577 .707 r
F P
0 g
s
.29839 .65823 m .29499 .67692 L .29823 .6825 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30364 .58979 m .30072 .53469 L .31356 .5255 L p .707 .577 .707 r
F P
0 g
s
.4945 .52205 m .49742 .57714 L .48131 .56984 L p .707 .577 .707 r
F P
0 g
s
.48131 .56984 m .4784 .51474 L .4945 .52205 L p .707 .577 .707 r
F P
0 g
s
.30014 .64496 m .30214 .60766 L .31108 .60079 L p .707 .577 .707 r
F P
0 g
s
.49924 .69552 m .49584 .71421 L .49261 .70863 L p .707 .577 .707 r
F P
0 g
s
.49261 .70863 m .496 .68993 L .49924 .69552 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29499 .67692 m .29839 .65823 L .30498 .65447 L p .707 .577 .707 r
F P
0 g
s
.31356 .5255 m .31648 .5806 L .30364 .58979 L p .707 .577 .707 r
F P
0 g
s
.5036 .61639 m .5016 .6537 L .49082 .64597 L p .707 .577 .707 r
F P
0 g
s
.49082 .64597 m .49283 .60867 L .5036 .61639 L p .707 .577 .707 r
F P
0 g
s
.31108 .60079 m .30908 .63809 L .30014 .64496 L p .707 .577 .707 r
F P
0 g
s
.30498 .65447 m .30159 .67316 L .29499 .67692 L p .707 .577 .707 r
F P
0 g
s
.31648 .5806 m .31356 .5255 L .3348 .51748 L p .707 .577 .707 r
F P
0 g
s
.4784 .51474 m .48131 .56984 L .45748 .56477 L p .707 .577 .707 r
F P
0 g
s
.45748 .56477 m .45456 .50967 L .4784 .51474 L p .707 .577 .707 r
F P
0 g
s
.30908 .63809 m .31108 .60079 L .32905 .59539 L p .707 .577 .707 r
F P
0 g
s
.496 .68993 m .49261 .70863 L .47985 .70176 L p .707 .577 .707 r
F P
0 g
s
.47985 .70176 m .48325 .68307 L .496 .68993 L p .707 .577 .707 r
F P
0 g
s
.3348 .51748 m .33772 .57258 L .31648 .5806 L p .707 .577 .707 r
F P
0 g
s
.49283 .60867 m .49082 .64597 L .47129 .63895 L p .707 .577 .707 r
F P
0 g
s
.47129 .63895 m .47329 .60164 L .49283 .60867 L p .707 .577 .707 r
F P
0 g
s
.30159 .67316 m .30498 .65447 L .32076 .6529 L p .707 .577 .707 r
F P
0 g
s
.32905 .59539 m .32705 .63269 L .30908 .63809 L p .707 .577 .707 r
F P
0 g
s
.32076 .6529 m .31736 .67159 L .30159 .67316 L p .707 .577 .707 r
F P
0 g
s
.33772 .57258 m .3348 .51748 L .36237 .51143 L p .707 .577 .707 r
F P
0 g
s
.45456 .50967 m .45748 .56477 L .42825 .56242 L p .707 .577 .707 r
F P
0 g
s
.42825 .56242 m .42533 .50732 L .45456 .50967 L p .707 .577 .707 r
F P
0 g
s
.32705 .63269 m .32905 .59539 L .3543 .592 L p .707 .577 .707 r
F P
0 g
s
.36529 .56653 m .36237 .51143 L .39356 .50793 L p .707 .577 .707 r
F P
0 g
s
.36237 .51143 m .36529 .56653 L .33772 .57258 L p .707 .577 .707 r
F P
0 g
s
.42533 .50732 m .42825 .56242 L .39648 .56303 L p .707 .577 .707 r
F P
0 g
s
.39648 .56303 m .39356 .50793 L .42533 .50732 L p .707 .577 .707 r
F P
0 g
s
.48325 .68307 m .47985 .70176 L .45884 .69429 L p .707 .577 .707 r
F P
0 g
s
.45884 .69429 m .46223 .6756 L .48325 .68307 L p .707 .577 .707 r
F P
0 g
s
.47329 .60164 m .47129 .63895 L .4449 .63331 L p .707 .577 .707 r
F P
0 g
s
.4449 .63331 m .4469 .59601 L .47329 .60164 L p .707 .577 .707 r
F P
0 g
s
.39356 .50793 m .39648 .56303 L .36529 .56653 L p .707 .577 .707 r
F P
0 g
s
.3543 .592 m .3523 .6293 L .32705 .63269 L p .707 .577 .707 r
F P
0 g
s
.31736 .67159 m .32076 .6529 L .34417 .65368 L p .707 .577 .707 r
F P
0 g
s
.34417 .65368 m .34078 .67237 L .31736 .67159 L p .707 .577 .707 r
F P
0 g
s
.3523 .6293 m .3543 .592 L .38435 .59094 L p .707 .577 .707 r
F P
0 g
s
.4469 .59601 m .4449 .63331 L .41426 .62963 L p .707 .577 .707 r
F P
0 g
s
.41426 .62963 m .41626 .59232 L .4469 .59601 L p .707 .577 .707 r
F P
0 g
s
.46223 .6756 m .45884 .69429 L .43161 .68695 L p .707 .577 .707 r
F P
0 g
s
.43161 .68695 m .43501 .66825 L .46223 .6756 L p .707 .577 .707 r
F P
0 g
s
.38435 .59094 m .38235 .62824 L .3523 .6293 L p .707 .577 .707 r
F P
0 g
s
.38235 .62824 m .38435 .59094 L .41626 .59232 L p .707 .577 .707 r
F P
0 g
s
.34078 .67237 m .34417 .65368 L .37294 .65673 L p .707 .577 .707 r
F P
0 g
s
.41626 .59232 m .41426 .62963 L .38235 .62824 L p .707 .577 .707 r
F P
0 g
s
.37294 .65673 m .36955 .67543 L .34078 .67237 L p .707 .577 .707 r
F P
0 g
s
.43501 .66825 m .43161 .68695 L .40085 .68045 L p .707 .577 .707 r
F P
0 g
s
.40085 .68045 m .40424 .66175 L .43501 .66825 L p .707 .577 .707 r
F P
0 g
s
.36955 .67543 m .37294 .65673 L .40424 .66175 L p .707 .577 .707 r
F P
0 g
s
.40424 .66175 m .40085 .68045 L .36955 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF5`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
069oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00GWoo10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00Fgoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00003Goo
8@00=goo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00007Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<goo001DOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000aOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
009JEPT00003FUH005YF00`000AJEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00E7oo
00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEQ@000AJEP03001JEUYF00AJEP@00003FUH0
05YF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH2000^Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP04001JEUYFFUH60008FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YF00002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`05FUH005YFFUH00003FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`06FUH005YFFUH005YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00H005YF000005YF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0002eoo`00EGoo00AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00AJEP000000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00=JEP0000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Goo001E
Ool00eYF00000003FUH00`00FUIJEP03FUHJ00000eYF001JEP06FUH00`00FUIJEP03FUH01@00FUIJ
EUYF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH0000]Ool004Aoo`P000Uoo`03001JEP0000=JEPH000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEUYFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool003aoo`P000=JEP03001JEUYF009JEPX00003FUH000000080009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03
001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8002eoo`00=Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000UYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF8@000eYF00<005YFFUH00UYF0P00;Goo000`Ool20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
0eYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP00008000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0
000002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH70002FUH200000eYF001JEP04FUH=
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`0015YF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001EYF00D005YFFUIJEP0002eoo`00;7oo0P000eYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001J
EP8000=JEP04001JEUYFFUH80003FUH60003FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00D005YFFUIJEP0002eoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000=JEP03001JEUYF00AJEPX000AJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH0000002ioo`00;7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF100000=JEP00000020000eYF
00<005YFFUH015YF0`0000AJEP00FUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<7oo000/Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF5@000eYF00<005YFFUH03`001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002Goo1@001Woo1`000UYF00<005YFFUH00eYF00<005YFFUH00UYF1P00
0UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YFFUH00UYF1@0015YF6@0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1@0025YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
1P004Woo1P001EYF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH00eYF100025YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF0P002Woo0`003Goo100000=JEP00FUH015YF00@005YFFUH002eoo`00;7oo10000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<0
05YFFUH00`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00UYF0`000UYF00L005YFFUIJEP00FUH00008Ool5000@Ool30004FUH01000FUIJEP00
;Goo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF001JEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
00030003FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH200000eYF001JEP040003FUH01P00FUIJEUYF001JEPl0019oo`<00005FUH005YFFUH0000]Ool0
02aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP@000=JEPP000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0000000AJ
EPT000AJEP03001JEUYF00IJEP03001JEP0000<000eoo`<00003FUH00000009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YF0000100000=JEP00FUH015YF1`001UYF00<005YF
FUH01UYF00<005YF00000P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF10001Goo100000=JEP00FUH00eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH600000eYF
000000020002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH3000]Ool0
02eoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEP0000T000=JEP03001JEP0000<000IJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=J
EP03001JEUYF009JEP03001JEP0002eoo`00;Goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00eYF1P00
0eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF00H005YFFUH005YF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0000]Ool002ioo`06001J
EP00001JEP001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF20002EYF100015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEPH000QJEP03001J
EUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF1P001UYF00<005YF00000P0000=JEP00FUH0
0UYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YF0000
0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01000FUIJEUYF3@000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF0P0000=JEP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH0
0000FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002
FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P001EYF00<005YF00000P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EP00FUH01@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080
0005FUH00000FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP00;goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJ
EP00FUH000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000EJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
009JEP03001oogoo02aoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP040002FUH00`00
FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00Oomo
o`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF009JEQ40009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH0000000@000=JEPT000AJEPH000=JEP03001JEUYF009JEPP000Ioo`03
001JEUYF008002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF009JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=J
EP00FUH00eYF00<005YF00000`000UYF0P0017oo4P003goo00@005YF000002eoo`00;7oo00@005YF
FUH000AJEP04001JEUYFFUH80007Ool50007Ool=0002FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00004FUH200000eYF00000009Ool5000HOol3
000]Ool002aoo`04001JEUYF0003FUH500000eYF0000000H0004FUH00`00FUIJEP04FUH00`00FUH0
00020002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH01000FUIJEP00
1EYF0`002goo0`006Woo0P00;Goo000/Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF10001EYF00<005YF0000
9goo0`00;Goo000/Ool00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00P0015YF00@005YFFUH0
02Ioo`03001JEP0002eoo`00;7oo10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00005FUH300001EYF001JEUYF000097oo0`0000=J
EP00Ool0;7oo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP00008000IJEP03001JEP0000@0025oo`<0009JEP8002ioo`00;7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEP`000AJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00006FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02FUH2000^Ool002aoo`04001JEUYF
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000>0003FUH20000
17oo001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF1`001eYF00<005YFFUH00eYF00<005YF00000UYF0P000eYF00<005YFFUH01UYF00<005YF
FUH0100047oo1@001EYF00D005YFFUIJEP0002moo`00;Goo0`001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01@000Woo00<005YF00001EYF
00<005YFFUH00UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH00`0015YF00<005YFFUH00eYF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF40000eYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;goo0P0015YF00<005YFFUH015YF
00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF00000Woo1`00
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
035oo`00<Goo0`0000=JEP00FUH01`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20005FUH00`00FUH00007Ool6
0002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000cOol0
039oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP000eYF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF000000=JEP03001JEP0000L000=J
EP800003FUH0000000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
<7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00L005YFFUH005YF001JEP0200000eYF001JEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000AJEP00FUH000AJEP03001JEP000080009JEP@000=oo`@0009JEP03001JEUYF00IJEP03001J
EUYF009JEPD003Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
7@0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00UYF0`000UYF00<007ooOol01Goo4000?goo000/Ool30004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH=000<Ool50003FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000EJEP03001JEUYF009JEP<00003FUH007oo05Eoo`00;7oo00<005YF000015YF00<0
05YFFUH00eYF1P0027oo1@0027oo100000=JEP00FUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF009JEP03001JEUYF008005Ioo`00
;7oo00@005YFFUH000=JEP03001JEP0000<000]ooa0000EJEP03001JEUYF00AJEP03001JEUYF009J
EP8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00P000AJEP04001JEUYF001FOol0
02aoo`04001JEUYF0002FUHB0004FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP040005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001eYF0`0000EJEP00FUIJEP00
05Ioo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000goo00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH00P000eYF00<007ooOol0Dgoo000]Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000030007Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000=JEP00Ool0E7oo000]Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000<Ool20003FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00@005YF000000=oo`8005Eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004goo00@0
05YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH30005Ool2001EOol0031ooad001eo
o`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEP000006FUH00`00FUH000030007Ool01000FUH00000E7oo001/Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH4
0004FUH6000:Ool20002FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00`000moo`03001JEP00009JEP03001o
ogoo059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`0057oo
00@005YFFUIJEP8005Eoo`00N7oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1P001Woo1@004Woo0P0015YF0P00EGoo001nOolO000<Ool5000@Ool200000eYF001JEP03FUH00`00
Oomoo`1DOol008ioo`04001JEUYF000HOol3000?Ool20003FUH01@00FUIJEUYF0000Egoo002>Ool0
0`00FUH0000XOol30006FUH00`00FUH0001HOol008moo`8002Ioo`800003FUH005YF00IJEP8005Uo
o`00Sgoo0P008goo0`000eYF00<005YFFUH015YF0P00FWoo002?Ool00`00FUH0000NOol40007FUH0
1000FUIJEUYF0P00G7oo002?Ool2000015YF000000005goo10000UYF00<005YFFUH01UYF00@005YF
000005ioo`00T7oo00<005YF00000UYF1`002Goo1`001UYF00<005YFFUH01EYF0`00H7oo002@Ool0
0`00FUH00005FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002A
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
001UOol0099oo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP@006Qoo`00
Tgoo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000K7oo002FOol70004FUH0
0`00FUIJEP02FUH7001`Ool009eoo`T007Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60071 .7485 m .60249 .69273 L .57088 .69059 L p .707 .577 .707 r
F P
0 g
s
.60249 .69273 m .60071 .7485 L .63221 .74809 L p .707 .577 .707 r
F P
0 g
s
.63221 .74809 m .634 .69232 L .60249 .69273 L p .707 .577 .707 r
F P
0 g
s
.5691 .74637 m .57088 .69059 L .54227 .68612 L p .707 .577 .707 r
F P
0 g
s
.57088 .69059 m .5691 .74637 L .60071 .7485 L p .707 .577 .707 r
F P
0 g
s
.634 .69232 m .63221 .74809 L .66053 .74518 L p .707 .577 .707 r
F P
0 g
s
.66053 .74518 m .66232 .6894 L .634 .69232 L p .707 .577 .707 r
F P
0 g
s
.54048 .74189 m .54227 .68612 L .51945 .67975 L p .707 .577 .707 r
F P
0 g
s
.54227 .68612 m .54048 .74189 L .5691 .74637 L p .707 .577 .707 r
F P
0 g
s
.66232 .6894 m .66053 .74518 L .6829 .74005 L p .707 .577 .707 r
F P
0 g
s
.6829 .74005 m .68468 .68427 L .66232 .6894 L p .707 .577 .707 r
F P
0 g
s
.60948 .81143 m .60826 .77457 L .57638 .77494 L p .707 .577 .707 r
F P
0 g
s
.60826 .77457 m .60948 .81143 L .64046 .80826 L p .707 .577 .707 r
F P
0 g
s
.64046 .80826 m .63924 .7714 L .60826 .77457 L p .707 .577 .707 r
F P
0 g
s
.5776 .8118 m .57638 .77494 L .54672 .77246 L p .707 .577 .707 r
F P
0 g
s
.57638 .77494 m .5776 .8118 L .60948 .81143 L p .707 .577 .707 r
F P
0 g
s
.63924 .7714 m .64046 .80826 L .6675 .8026 L p .707 .577 .707 r
F P
0 g
s
.6675 .8026 m .66628 .76574 L .63924 .7714 L p .707 .577 .707 r
F P
0 g
s
.51945 .67975 m .51766 .73552 L .54048 .74189 L p .707 .577 .707 r
F P
0 g
s
.54672 .77246 m .54794 .80932 L .5776 .8118 L p .707 .577 .707 r
F P
0 g
s
.54794 .80932 m .54672 .77246 L .52218 .76739 L p .707 .577 .707 r
F P
0 g
s
.51766 .73552 m .51945 .67975 L .50466 .6721 L p .707 .577 .707 r
F P
0 g
s
.61753 .85569 m .61544 .83761 L .58367 .84064 L p .707 .577 .707 r
F P
0 g
s
.61544 .83761 m .61753 .85569 L .64797 .84956 L p .707 .577 .707 r
F P
0 g
s
.64797 .84956 m .64588 .83148 L .61544 .83761 L p .707 .577 .707 r
F P
0 g
s
.68468 .68427 m .6829 .74005 L .69711 .7332 L p .707 .577 .707 r
F P
0 g
s
.69711 .7332 m .6989 .67742 L .68468 .68427 L p .707 .577 .707 r
F P
0 g
s
.58576 .85872 m .58367 .84064 L .55368 .84029 L p .707 .577 .707 r
F P
0 g
s
.58367 .84064 m .58576 .85872 L .61753 .85569 L p .707 .577 .707 r
F P
0 g
s
.66628 .76574 m .6675 .8026 L .68796 .79499 L p .707 .577 .707 r
F P
0 g
s
.68796 .79499 m .68674 .75813 L .66628 .76574 L p .707 .577 .707 r
F P
0 g
s
.52218 .76739 m .5234 .80425 L .54794 .80932 L p .707 .577 .707 r
F P
0 g
s
.64588 .83148 m .64797 .84956 L .6741 .84095 L p .707 .577 .707 r
F P
0 g
s
.6741 .84095 m .67201 .82287 L .64588 .83148 L p .707 .577 .707 r
F P
0 g
s
.55368 .84029 m .55576 .85837 L .58576 .85872 L p .707 .577 .707 r
F P
0 g
s
.50466 .6721 m .50287 .72788 L .51766 .73552 L p .707 .577 .707 r
F P
0 g
s
.55576 .85837 m .55368 .84029 L .52841 .83658 L p .707 .577 .707 r
F P
0 g
s
.5234 .80425 m .52218 .76739 L .50516 .76021 L p .707 .577 .707 r
F P
0 g
s
.52841 .83658 m .53049 .85466 L .55576 .85837 L p .707 .577 .707 r
F P
0 g
s
.67201 .82287 m .6741 .84095 L .69336 .83068 L p .707 .577 .707 r
F P
0 g
s
.69336 .83068 m .69127 .8126 L .67201 .82287 L p .707 .577 .707 r
F P
0 g
s
.50287 .72788 m .50466 .6721 L .49934 .66393 L p .707 .577 .707 r
F P
0 g
s
.50516 .76021 m .50638 .79707 L .5234 .80425 L p .707 .577 .707 r
F P
0 g
s
.68674 .75813 m .68796 .79499 L .69984 .78619 L p .707 .577 .707 r
F P
0 g
s
.69984 .78619 m .69862 .74933 L .68674 .75813 L p .707 .577 .707 r
F P
0 g
s
.6989 .67742 m .69711 .7332 L .70179 .7253 L p .707 .577 .707 r
F P
0 g
s
.70179 .7253 m .70358 .66953 L .6989 .67742 L p .707 .577 .707 r
F P
0 g
s
.53049 .85466 m .52841 .83658 L .51032 .82989 L p .707 .577 .707 r
F P
0 g
s
.51032 .82989 m .5124 .84796 L .53049 .85466 L p .707 .577 .707 r
F P
0 g
s
.49934 .66393 m .49755 .71971 L .50287 .72788 L p .707 .577 .707 r
F P
0 g
s
.50638 .79707 m .50516 .76021 L .49734 .75164 L p .707 .577 .707 r
F P
0 g
s
.69127 .8126 m .69336 .83068 L .70386 .81978 L p .707 .577 .707 r
F P
0 g
s
.70386 .81978 m .70178 .8017 L .69127 .8126 L p .707 .577 .707 r
F P
0 g
s
.49734 .75164 m .49856 .7885 L .50638 .79707 L p .707 .577 .707 r
F P
0 g
s
.49755 .71971 m .49934 .66393 L .50402 .65604 L p .707 .577 .707 r
F P
0 g
s
.69862 .74933 m .69984 .78619 L .70197 .77706 L p .707 .577 .707 r
F P
0 g
s
.70197 .77706 m .70075 .7402 L .69862 .74933 L p .707 .577 .707 r
F P
0 g
s
.5124 .84796 m .51032 .82989 L .50119 .82086 L p .707 .577 .707 r
F P
0 g
s
.70358 .66953 m .70179 .7253 L .69647 .71713 L p .707 .577 .707 r
F P
0 g
s
.69647 .71713 m .69826 .66136 L .70358 .66953 L p .707 .577 .707 r
F P
0 g
s
.49464 .8219 m .49464 .32001 L .45036 .31767 L p .707 .577 .707 r
F P
0 g
s
.50119 .82086 m .50327 .83893 L .5124 .84796 L p .707 .577 .707 r
F P
0 g
s
.50402 .65604 m .50223 .71181 L .49755 .71971 L p .707 .577 .707 r
F P
0 g
s
.49856 .7885 m .49734 .75164 L .49946 .74251 L p .707 .577 .707 r
F P
0 g
s
.49946 .74251 m .50069 .77936 L .49856 .7885 L p .707 .577 .707 r
F P
0 g
s
.50223 .71181 m .50402 .65604 L .51823 .64919 L p .707 .577 .707 r
F P
0 g
s
.50327 .83893 m .50119 .82086 L .50191 .81037 L p .707 .577 .707 r
F P
0 g
s
.50191 .81037 m .504 .82845 L .50327 .83893 L p .707 .577 .707 r
F P
0 g
s
.51823 .64919 m .51645 .70496 L .50223 .71181 L p .707 .577 .707 r
F P
0 g
s
.50069 .77936 m .49946 .74251 L .51134 .73371 L p .707 .577 .707 r
F P
0 g
s
.51134 .73371 m .51256 .77056 L .50069 .77936 L p .707 .577 .707 r
F P
0 g
s
.51645 .70496 m .51823 .64919 L .5406 .64405 L p .707 .577 .707 r
F P
0 g
s
.504 .82845 m .50191 .81037 L .51242 .79947 L p .707 .577 .707 r
F P
0 g
s
.51242 .79947 m .5145 .81755 L .504 .82845 L p .707 .577 .707 r
F P
0 g
s
.5406 .64405 m .53881 .69983 L .51645 .70496 L p .707 .577 .707 r
F P
0 g
s
.51256 .77056 m .51134 .73371 L .5318 .7261 L p .707 .577 .707 r
F P
0 g
s
.5318 .7261 m .53302 .76296 L .51256 .77056 L p .707 .577 .707 r
F P
0 g
s
.5145 .81755 m .51242 .79947 L .53168 .7892 L p .707 .577 .707 r
F P
0 g
s
.53168 .7892 m .53376 .80728 L .5145 .81755 L p .707 .577 .707 r
F P
0 g
s
.53302 .76296 m .5318 .7261 L .55885 .72044 L p .707 .577 .707 r
F P
0 g
s
.55885 .72044 m .56007 .7573 L .53302 .76296 L p .707 .577 .707 r
F P
0 g
s
.53376 .80728 m .53168 .7892 L .55781 .78059 L p .707 .577 .707 r
F P
0 g
s
.55781 .78059 m .55989 .79867 L .53376 .80728 L p .707 .577 .707 r
F P
0 g
s
.49464 .32001 m .49464 .8219 L .53944 .82045 L p .707 .577 .707 r
F P
0 g
s
.53881 .69983 m .5406 .64405 L .56892 .64114 L p .707 .577 .707 r
F P
0 g
s
.56892 .64114 m .56713 .69692 L .53881 .69983 L p .707 .577 .707 r
F P
0 g
s
.53944 .82045 m .53944 .31856 L .49464 .32001 L p .707 .577 .707 r
F P
0 g
s
.56713 .69692 m .56892 .64114 L .60042 .64073 L p .707 .577 .707 r
F P
0 g
s
.60042 .64073 m .59864 .69651 L .56713 .69692 L p .707 .577 .707 r
F P
0 g
s
.56007 .7573 m .55885 .72044 L .58982 .71727 L p .707 .577 .707 r
F P
0 g
s
.58982 .71727 m .59105 .75412 L .56007 .7573 L p .707 .577 .707 r
F P
0 g
s
.55989 .79867 m .55781 .78059 L .58825 .77446 L p .707 .577 .707 r
F P
0 g
s
.58825 .77446 m .59033 .79254 L .55989 .79867 L p .707 .577 .707 r
F P
0 g
s
.53944 .31856 m .53944 .82045 L .58039 .81536 L p .707 .577 .707 r
F P
0 g
s
.58039 .81536 m .58039 .31347 L .53944 .31856 L p .707 .577 .707 r
F P
0 g
s
.45035 .81956 m .45036 .31767 L .41093 .31178 L p .707 .577 .707 r
F P
0 g
s
.45036 .31767 m .45035 .81956 L .49464 .8219 L p .707 .577 .707 r
F P
0 g
s
.70178 .8017 m .70386 .81978 L .70459 .80929 L p .707 .577 .707 r
F P
0 g
s
.70459 .80929 m .70251 .79122 L .70178 .8017 L p .707 .577 .707 r
F P
0 g
s
.63203 .64287 m .63024 .69865 L .59864 .69651 L p .707 .577 .707 r
F P
0 g
s
.59864 .69651 m .60042 .64073 L .63203 .64287 L p .707 .577 .707 r
F P
0 g
s
.6217 .7169 m .62292 .75376 L .59105 .75412 L p .707 .577 .707 r
F P
0 g
s
.59105 .75412 m .58982 .71727 L .6217 .7169 L p .707 .577 .707 r
F P
0 g
s
.62002 .77143 m .6221 .78951 L .59033 .79254 L p .707 .577 .707 r
F P
0 g
s
.59033 .79254 m .58825 .77446 L .62002 .77143 L p .707 .577 .707 r
F P
0 g
s
.58039 .31347 m .58039 .81536 L .61346 .80712 L p .707 .577 .707 r
F P
0 g
s
.61346 .80712 m .61346 .30523 L .58039 .31347 L p .707 .577 .707 r
F P
0 g
s
.70075 .7402 m .70197 .77706 L .69414 .76848 L p .707 .577 .707 r
F P
0 g
s
.69414 .76848 m .69292 .73162 L .70075 .7402 L p .707 .577 .707 r
F P
0 g
s
.69826 .66136 m .69647 .71713 L .68168 .70949 L p .707 .577 .707 r
F P
0 g
s
.68168 .70949 m .68347 .65371 L .69826 .66136 L p .707 .577 .707 r
F P
0 g
s
.41093 .81366 m .41093 .31178 L .38023 .3029 L p .707 .577 .707 r
F P
0 g
s
.41093 .31178 m .41093 .81366 L .45035 .81956 L p .707 .577 .707 r
F P
0 g
s
.25955 .7147 m .26033 .65959 L .22871 .6578 L p .707 .577 .707 r
F P
0 g
s
.26033 .65959 m .25955 .7147 L .29106 .71354 L p .707 .577 .707 r
F P
0 g
s
.29106 .71354 m .29185 .65843 L .26033 .65959 L p .707 .577 .707 r
F P
0 g
s
.22793 .71291 m .22871 .6578 L .20008 .65322 L p .707 .577 .707 r
F P
0 g
s
.22871 .6578 m .22793 .71291 L .25955 .7147 L p .707 .577 .707 r
F P
0 g
s
.29185 .65843 m .29106 .71354 L .31939 .70952 L p .707 .577 .707 r
F P
0 g
s
.31939 .70952 m .32018 .65441 L .29185 .65843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70251 .79122 m .70459 .80929 L .69546 .80026 L p .707 .577 .707 r
F P
0 g
s
.69546 .80026 m .69338 .78219 L .70251 .79122 L p .707 .577 .707 r
F P
0 g
s
.1993 .70833 m .20008 .65322 L .17725 .6463 L p .707 .577 .707 r
F P
0 g
s
.20008 .65322 m .1993 .70833 L .22793 .71291 L p .707 .577 .707 r
F P
0 g
s
.32018 .65441 m .31939 .70952 L .34176 .70306 L p .707 .577 .707 r
F P
0 g
s
.34176 .70306 m .34255 .64795 L .32018 .65441 L p .707 .577 .707 r
F P
0 g
s
.66064 .64734 m .65886 .70312 L .63024 .69865 L p .707 .577 .707 r
F P
0 g
s
.63024 .69865 m .63203 .64287 L .66064 .64734 L p .707 .577 .707 r
F P
0 g
s
.65136 .71938 m .65259 .75623 L .62292 .75376 L p .707 .577 .707 r
F P
0 g
s
.62292 .75376 m .6217 .7169 L .65136 .71938 L p .707 .577 .707 r
F P
0 g
s
.65001 .77178 m .6521 .78986 L .6221 .78951 L p .707 .577 .707 r
F P
0 g
s
.6221 .78951 m .62002 .77143 L .65001 .77178 L p .707 .577 .707 r
F P
0 g
s
.61346 .30523 m .61346 .80712 L .63543 .79654 L p .707 .577 .707 r
F P
0 g
s
.63543 .79654 m .63543 .29465 L .61346 .30523 L p .707 .577 .707 r
F P
0 g
s
.69292 .73162 m .69414 .76848 L .67713 .76131 L p .707 .577 .707 r
F P
0 g
s
.67713 .76131 m .6759 .72445 L .69292 .73162 L p .707 .577 .707 r
F P
0 g
s
.68347 .65371 m .68168 .70949 L .65886 .70312 L p .707 .577 .707 r
F P
0 g
s
.65886 .70312 m .66064 .64734 L .68347 .65371 L p .707 .577 .707 r
F P
0 g
s
.268 .76945 m .26746 .73214 L .23556 .73206 L p .707 .577 .707 r
F P
0 g
s
.26746 .73214 m .268 .76945 L .29899 .76713 L p .707 .577 .707 r
F P
0 g
s
.29899 .76713 m .29845 .72981 L .26746 .73214 L p .707 .577 .707 r
F P
0 g
s
.23611 .76938 m .23556 .73206 L .20589 .72959 L p .707 .577 .707 r
F P
0 g
s
.23556 .73206 m .23611 .76938 L .268 .76945 L p .707 .577 .707 r
F P
0 g
s
.38023 .80479 m .38023 .3029 L .36125 .29191 L p .707 .577 .707 r
F P
0 g
s
.38023 .3029 m .38023 .80479 L .41093 .81366 L p .707 .577 .707 r
F P
0 g
s
.29845 .72981 m .29899 .76713 L .32605 .76263 L p .707 .577 .707 r
F P
0 g
s
.32605 .76263 m .3255 .72531 L .29845 .72981 L p .707 .577 .707 r
F P
0 g
s
.20589 .72959 m .20644 .76691 L .23611 .76938 L p .707 .577 .707 r
F P
0 g
s
.17725 .6463 m .17647 .70141 L .1993 .70833 L p .707 .577 .707 r
F P
0 g
s
.27411 .80546 m .27316 .78658 L .24124 .78799 L p .707 .577 .707 r
F P
0 g
s
.27316 .78658 m .27411 .80546 L .30468 .80231 L p .707 .577 .707 r
F P
0 g
s
.30468 .80231 m .30374 .78342 L .27316 .78658 L p .707 .577 .707 r
F P
0 g
s
.20644 .76691 m .20589 .72959 L .18134 .72498 L p .707 .577 .707 r
F P
0 g
s
.24218 .80688 m .24124 .78799 L .2111 .78753 L p .707 .577 .707 r
F P
0 g
s
.24124 .78799 m .24218 .80688 L .27411 .80546 L p .707 .577 .707 r
F P
0 g
s
.17647 .70141 m .17725 .6463 L .16245 .63773 L p .707 .577 .707 r
F P
0 g
s
.2111 .78753 m .21204 .80641 L .24218 .80688 L p .707 .577 .707 r
F P
0 g
s
.69338 .78219 m .69546 .80026 L .67737 .79357 L p .707 .577 .707 r
F P
0 g
s
.67737 .79357 m .67529 .77549 L .69338 .78219 L p .707 .577 .707 r
F P
0 g
s
.34255 .64795 m .34176 .70306 L .35598 .69477 L p .707 .577 .707 r
F P
0 g
s
.35598 .69477 m .35677 .63966 L .34255 .64795 L p .707 .577 .707 r
F P
0 g
s
.30374 .78342 m .30468 .80231 L .33092 .79773 L p .707 .577 .707 r
F P
0 g
s
.33092 .79773 m .32997 .77884 L .30374 .78342 L p .707 .577 .707 r
F P
0 g
s
.18134 .72498 m .18189 .7623 L .20644 .76691 L p .707 .577 .707 r
F P
0 g
s
.3255 .72531 m .32605 .76263 L .34651 .75641 L p .707 .577 .707 r
F P
0 g
s
.34651 .75641 m .34596 .71909 L .3255 .72531 L p .707 .577 .707 r
F P
0 g
s
.21204 .80641 m .2111 .78753 L .18569 .78523 L p .707 .577 .707 r
F P
0 g
s
.6759 .72445 m .67713 .76131 L .65259 .75623 L p .707 .577 .707 r
F P
0 g
s
.65259 .75623 m .65136 .71938 L .6759 .72445 L p .707 .577 .707 r
F P
0 g
s
.18569 .78523 m .18663 .80412 L .21204 .80641 L p .707 .577 .707 r
F P
0 g
s
.16245 .63773 m .16166 .69284 L .17647 .70141 L p .707 .577 .707 r
F P
0 g
s
.18189 .7623 m .18134 .72498 L .16431 .71866 L p .707 .577 .707 r
F P
0 g
s
.63543 .29465 m .63543 .79654 L .64414 .78466 L p .707 .577 .707 r
F P
0 g
s
.64414 .78466 m .64414 .28277 L .63543 .29465 L p .707 .577 .707 r
F P
0 g
s
.32997 .77884 m .33092 .79773 L .35025 .79216 L p .707 .577 .707 r
F P
0 g
s
.35025 .79216 m .3493 .77327 L .32997 .77884 L p .707 .577 .707 r
F P
0 g
s
.16431 .71866 m .16486 .75598 L .18189 .7623 L p .707 .577 .707 r
F P
0 g
s
.16166 .69284 m .16245 .63773 L .15712 .62833 L p .707 .577 .707 r
F P
0 g
s
.67529 .77549 m .67737 .79357 L .6521 .78986 L p .707 .577 .707 r
F P
0 g
s
.6521 .78986 m .65001 .77178 L .67529 .77549 L p .707 .577 .707 r
F P
0 g
s
.18663 .80412 m .18569 .78523 L .16749 .78133 L p .707 .577 .707 r
F P
0 g
s
.35677 .63966 m .35598 .69477 L .36066 .68548 L p .707 .577 .707 r
F P
0 g
s
.36066 .68548 m .36144 .63037 L .35677 .63966 L p .707 .577 .707 r
F P
0 g
s
.36144 .63037 m .36066 .68548 L .35533 .67609 L p .707 .577 .707 r
F P
0 g
s
.35533 .67609 m .35612 .62098 L .36144 .63037 L p .707 .577 .707 r
F P
0 g
s
.35983 .76727 m .36078 .78616 L .36148 .78031 L p .707 .577 .707 r
F P
0 g
s
.36148 .78031 m .36054 .76142 L .35983 .76727 L p .707 .577 .707 r
F P
0 g
s
.36078 .78616 m .35983 .76727 L .3493 .77327 L p .707 .577 .707 r
F P
0 g
s
.36054 .76142 m .36148 .78031 L .35228 .77518 L p .707 .577 .707 r
F P
0 g
s
.36125 .7938 m .36125 .29191 L .35585 .27989 L p .707 .577 .707 r
F P
0 g
s
.36125 .29191 m .36125 .7938 L .38023 .80479 L p .707 .577 .707 r
F P
0 g
s
.16749 .78133 m .16844 .80022 L .18663 .80412 L p .707 .577 .707 r
F P
0 g
s
.34596 .71909 m .34651 .75641 L .35839 .74906 L p .707 .577 .707 r
F P
0 g
s
.35839 .74906 m .35784 .71174 L .34596 .71909 L p .707 .577 .707 r
F P
0 g
s
.16486 .75598 m .16431 .71866 L .15648 .71127 L p .707 .577 .707 r
F P
0 g
s
.15712 .62833 m .15634 .68344 L .16166 .69284 L p .707 .577 .707 r
F P
0 g
s
.3493 .77327 m .35025 .79216 L .36078 .78616 L p .707 .577 .707 r
F P
0 g
s
.15648 .71127 m .15703 .74859 L .16486 .75598 L p .707 .577 .707 r
F P
0 g
s
.16844 .80022 m .16749 .78133 L .15829 .7762 L p .707 .577 .707 r
F P
0 g
s
.15634 .68344 m .15712 .62833 L .1618 .61904 L p .707 .577 .707 r
F P
0 g
s
.15829 .7762 m .15924 .79509 L .16844 .80022 L p .707 .577 .707 r
F P
0 g
s
.35784 .71174 m .35839 .74906 L .36052 .74131 L p .707 .577 .707 r
F P
0 g
s
.36052 .74131 m .35997 .70399 L .35784 .71174 L p .707 .577 .707 r
F P
0 g
s
.64414 .28277 m .64414 .78466 L .63875 .77263 L p .707 .577 .707 r
F P
0 g
s
.63875 .77263 m .63875 .27075 L .64414 .28277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35612 .62098 m .35533 .67609 L .34053 .66751 L p .707 .577 .707 r
F P
0 g
s
.34053 .66751 m .34132 .6124 L .35612 .62098 L p .707 .577 .707 r
F P
0 g
s
.35997 .70399 m .36052 .74131 L .35269 .73391 L p .707 .577 .707 r
F P
0 g
s
.35269 .73391 m .35214 .69659 L .35997 .70399 L p .707 .577 .707 r
F P
0 g
s
.35228 .77518 m .35134 .75629 L .36054 .76142 L p .707 .577 .707 r
F P
0 g
s
.35585 .27989 m .35585 .78178 L .36125 .7938 L p .707 .577 .707 r
F P
0 g
s
.35585 .78178 m .35585 .27989 L .36457 .26801 L p .707 .577 .707 r
F P
0 g
s
.15703 .74859 m .15648 .71127 L .15861 .70352 L p .707 .577 .707 r
F P
0 g
s
.1618 .61904 m .16102 .67415 L .15634 .68344 L p .707 .577 .707 r
F P
0 g
s
.15861 .70352 m .15916 .74084 L .15703 .74859 L p .707 .577 .707 r
F P
0 g
s
.15924 .79509 m .15829 .7762 L .159 .77035 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16102 .67415 m .1618 .61904 L .17602 .61075 L p .707 .577 .707 r
F P
0 g
s
.159 .77035 m .15994 .78924 L .15924 .79509 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17602 .61075 m .17523 .66586 L .16102 .67415 L p .707 .577 .707 r
F P
0 g
s
.63875 .27075 m .63875 .77263 L .61977 .76165 L p .707 .577 .707 r
F P
0 g
s
.61977 .76165 m .61977 .25976 L .63875 .27075 L p .707 .577 .707 r
F P
0 g
s
.15916 .74084 m .15861 .70352 L .17049 .69617 L p .707 .577 .707 r
F P
0 g
s
.17049 .69617 m .17103 .73349 L .15916 .74084 L p .707 .577 .707 r
F P
0 g
s
.36457 .7699 m .36457 .26801 L .38653 .25743 L p .707 .577 .707 r
F P
0 g
s
.36457 .26801 m .36457 .7699 L .35585 .78178 L p .707 .577 .707 r
F P
0 g
s
.17523 .66586 m .17602 .61075 L .19839 .60429 L p .707 .577 .707 r
F P
0 g
s
.15994 .78924 m .159 .77035 L .16953 .76435 L p .707 .577 .707 r
F P
0 g
s
.34132 .6124 m .34053 .66751 L .3177 .6606 L p .707 .577 .707 r
F P
0 g
s
.3177 .6606 m .31848 .60549 L .34132 .6124 L p .707 .577 .707 r
F P
0 g
s
.16953 .76435 m .17047 .78324 L .15994 .78924 L p .707 .577 .707 r
F P
0 g
s
.35214 .69659 m .35269 .73391 L .33566 .7276 L p .707 .577 .707 r
F P
0 g
s
.33566 .7276 m .33511 .69028 L .35214 .69659 L p .707 .577 .707 r
F P
0 g
s
.19839 .60429 m .1976 .6594 L .17523 .66586 L p .707 .577 .707 r
F P
0 g
s
.17103 .73349 m .17049 .69617 L .19095 .68994 L p .707 .577 .707 r
F P
0 g
s
.1976 .6594 m .19839 .60429 L .22672 .60028 L p .707 .577 .707 r
F P
0 g
s
.31848 .60549 m .3177 .6606 L .28907 .65602 L p .707 .577 .707 r
F P
0 g
s
.28907 .65602 m .28986 .60091 L .31848 .60549 L p .707 .577 .707 r
F P
0 g
s
.35134 .75629 m .35228 .77518 L .33409 .77128 L p .707 .577 .707 r
F P
0 g
s
.33409 .77128 m .33314 .75239 L .35134 .75629 L p .707 .577 .707 r
F P
0 g
s
.19095 .68994 m .1915 .72726 L .17103 .73349 L p .707 .577 .707 r
F P
0 g
s
.61977 .25976 m .61977 .76165 L .58906 .75277 L p .707 .577 .707 r
F P
0 g
s
.58906 .75277 m .58906 .25088 L .61977 .25976 L p .707 .577 .707 r
F P
0 g
s
.17047 .78324 m .16953 .76435 L .18886 .75878 L p .707 .577 .707 r
F P
0 g
s
.33511 .69028 m .33566 .7276 L .31111 .72298 L p .707 .577 .707 r
F P
0 g
s
.31111 .72298 m .31056 .68566 L .33511 .69028 L p .707 .577 .707 r
F P
0 g
s
.18886 .75878 m .1898 .77767 L .17047 .78324 L p .707 .577 .707 r
F P
0 g
s
.22593 .65539 m .22672 .60028 L .25824 .59911 L p .707 .577 .707 r
F P
0 g
s
.22672 .60028 m .22593 .65539 L .1976 .6594 L p .707 .577 .707 r
F P
0 g
s
.28986 .60091 m .28907 .65602 L .25745 .65422 L p .707 .577 .707 r
F P
0 g
s
.25745 .65422 m .25824 .59911 L .28986 .60091 L p .707 .577 .707 r
F P
0 g
s
.38653 .25743 m .38653 .75932 L .36457 .7699 L p .707 .577 .707 r
F P
0 g
s
.38653 .75932 m .38653 .25743 L .41961 .24919 L p .707 .577 .707 r
F P
0 g
s
.74255 .6555 m .74176 .59951 L .71014 .5988 L p .707 .577 .707 r
F P
0 g
s
.74176 .59951 m .74255 .6555 L .77407 .65381 L p .707 .577 .707 r
F P
0 g
s
.77407 .65381 m .77328 .59781 L .74176 .59951 L p .707 .577 .707 r
F P
0 g
s
.25824 .59911 m .25745 .65422 L .22593 .65539 L p .707 .577 .707 r
F P
0 g
s
.1915 .72726 m .19095 .68994 L .21801 .68545 L p .707 .577 .707 r
F P
0 g
s
.71093 .6548 m .71014 .5988 L .68151 .59576 L p .707 .577 .707 r
F P
0 g
s
.71014 .5988 m .71093 .6548 L .74255 .6555 L p .707 .577 .707 r
F P
0 g
s
.77328 .59781 m .77407 .65381 L .8024 .64987 L p .707 .577 .707 r
F P
0 g
s
.8024 .64987 m .80161 .59387 L .77328 .59781 L p .707 .577 .707 r
F P
0 g
s
.33314 .75239 m .33409 .77128 L .30867 .76898 L p .707 .577 .707 r
F P
0 g
s
.30867 .76898 m .30773 .7501 L .33314 .75239 L p .707 .577 .707 r
F P
0 g
s
.21801 .68545 m .21855 .72277 L .1915 .72726 L p .707 .577 .707 r
F P
0 g
s
.31056 .68566 m .31111 .72298 L .28144 .72051 L p .707 .577 .707 r
F P
0 g
s
.28144 .72051 m .28089 .6832 L .31056 .68566 L p .707 .577 .707 r
F P
0 g
s
.1898 .77767 m .18886 .75878 L .21509 .7542 L p .707 .577 .707 r
F P
0 g
s
.68151 .59576 m .6823 .65175 L .71093 .6548 L p .707 .577 .707 r
F P
0 g
s
.6823 .65175 m .68151 .59576 L .65868 .59068 L p .707 .577 .707 r
F P
0 g
s
.21509 .7542 m .21604 .77309 L .1898 .77767 L p .707 .577 .707 r
F P
0 g
s
.21855 .72277 m .21801 .68545 L .24899 .68312 L p .707 .577 .707 r
F P
0 g
s
.80161 .59387 m .8024 .64987 L .82476 .64408 L p .707 .577 .707 r
F P
0 g
s
.82476 .64408 m .82398 .58808 L .80161 .59387 L p .707 .577 .707 r
F P
0 g
s
.58906 .25088 m .58906 .75277 L .54964 .74688 L p .707 .577 .707 r
F P
0 g
s
.54964 .74688 m .54964 .24499 L .58906 .25088 L p .707 .577 .707 r
F P
0 g
s
.75045 .72127 m .751 .68451 L .71911 .68345 L p .707 .577 .707 r
F P
0 g
s
.751 .68451 m .75045 .72127 L .78144 .71938 L p .707 .577 .707 r
F P
0 g
s
.78144 .71938 m .78199 .68263 L .751 .68451 L p .707 .577 .707 r
F P
0 g
s
.71856 .72021 m .71911 .68345 L .68944 .67955 L p .707 .577 .707 r
F P
0 g
s
.71911 .68345 m .71856 .72021 L .75045 .72127 L p .707 .577 .707 r
F P
0 g
s
.28089 .6832 m .28144 .72051 L .24954 .72044 L p .707 .577 .707 r
F P
0 g
s
.24954 .72044 m .24899 .68312 L .28089 .6832 L p .707 .577 .707 r
F P
0 g
s
.24899 .68312 m .24954 .72044 L .21855 .72277 L p .707 .577 .707 r
F P
0 g
s
.41961 .75108 m .41961 .24919 L .46056 .2441 L p .707 .577 .707 r
F P
0 g
s
.41961 .24919 m .41961 .75108 L .38653 .75932 L p .707 .577 .707 r
F P
0 g
s
.78199 .68263 m .78144 .71938 L .8085 .71474 L p .707 .577 .707 r
F P
0 g
s
.8085 .71474 m .80904 .67798 L .78199 .68263 L p .707 .577 .707 r
F P
0 g
s
.30773 .7501 m .30867 .76898 L .27853 .76852 L p .707 .577 .707 r
F P
0 g
s
.27853 .76852 m .27759 .74963 L .30773 .7501 L p .707 .577 .707 r
F P
0 g
s
.65868 .59068 m .65947 .64667 L .6823 .65175 L p .707 .577 .707 r
F P
0 g
s
.21604 .77309 m .21509 .7542 L .24567 .75105 L p .707 .577 .707 r
F P
0 g
s
.68889 .71631 m .68944 .67955 L .66488 .67319 L p .707 .577 .707 r
F P
0 g
s
.68944 .67955 m .68889 .71631 L .71856 .72021 L p .707 .577 .707 r
F P
0 g
s
.24567 .75105 m .24661 .76994 L .21604 .77309 L p .707 .577 .707 r
F P
0 g
s
.65947 .64667 m .65868 .59068 L .64388 .58405 L p .707 .577 .707 r
F P
0 g
s
.27759 .74963 m .27853 .76852 L .24661 .76994 L p .707 .577 .707 r
F P
0 g
s
.24661 .76994 m .24567 .75105 L .27759 .74963 L p .707 .577 .707 r
F P
0 g
s
.82398 .58808 m .82476 .64408 L .83898 .63701 L p .707 .577 .707 r
F P
0 g
s
.83898 .63701 m .8382 .58101 L .82398 .58808 L p .707 .577 .707 r
F P
0 g
s
.54964 .24499 m .54964 .74688 L .50536 .74454 L p .707 .577 .707 r
F P
0 g
s
.50536 .74454 m .50536 .24265 L .54964 .24499 L p .707 .577 .707 r
F P
0 g
s
.75339 .76835 m .75433 .75037 L .72241 .74866 L p .707 .577 .707 r
F P
0 g
s
.75433 .75037 m .75339 .76835 L .78396 .76651 L p .707 .577 .707 r
F P
0 g
s
.78396 .76651 m .7849 .74853 L .75433 .75037 L p .707 .577 .707 r
F P
0 g
s
.72147 .76663 m .72241 .74866 L .69227 .74356 L p .707 .577 .707 r
F P
0 g
s
.72241 .74866 m .72147 .76663 L .75339 .76835 L p .707 .577 .707 r
F P
0 g
s
.80904 .67798 m .8085 .71474 L .82896 .70779 L p .707 .577 .707 r
F P
0 g
s
.82896 .70779 m .82951 .67103 L .80904 .67798 L p .707 .577 .707 r
F P
0 g
s
.46056 .74599 m .46056 .2441 L .50536 .24265 L p .707 .577 .707 r
F P
0 g
s
.46056 .2441 m .46056 .74599 L .41961 .75108 L p .707 .577 .707 r
F P
0 g
s
.66488 .67319 m .66434 .70995 L .68889 .71631 L p .707 .577 .707 r
F P
0 g
s
.69227 .74356 m .69132 .76153 L .72147 .76663 L p .707 .577 .707 r
F P
0 g
s
.50536 .24265 m .50536 .74454 L .46056 .74599 L p .707 .577 .707 r
F P
0 g
s
.7849 .74853 m .78396 .76651 L .8102 .76129 L p .707 .577 .707 r
F P
0 g
s
.8102 .76129 m .81114 .74332 L .7849 .74853 L p .707 .577 .707 r
F P
0 g
s
.69132 .76153 m .69227 .74356 L .66685 .73557 L p .707 .577 .707 r
F P
0 g
s
.64388 .58405 m .64466 .64005 L .65947 .64667 L p .707 .577 .707 r
F P
0 g
s
.66434 .70995 m .66488 .67319 L .64786 .66499 L p .707 .577 .707 r
F P
0 g
s
.66685 .73557 m .66591 .75354 L .69132 .76153 L p .707 .577 .707 r
F P
0 g
s
.64786 .66499 m .64731 .70175 L .66434 .70995 L p .707 .577 .707 r
F P
0 g
s
.64466 .64005 m .64388 .58405 L .63856 .57654 L p .707 .577 .707 r
F P
0 g
s
.8382 .58101 m .83898 .63701 L .84366 .62933 L p .707 .577 .707 r
F P
0 g
s
.84366 .62933 m .84287 .57334 L .8382 .58101 L p .707 .577 .707 r
F P
0 g
s
.82951 .67103 m .82896 .70779 L .84084 .69922 L p .707 .577 .707 r
F P
0 g
s
.84084 .69922 m .84139 .66246 L .82951 .67103 L p .707 .577 .707 r
F P
0 g
s
.81114 .74332 m .8102 .76129 L .82953 .75321 L p .707 .577 .707 r
F P
0 g
s
.82953 .75321 m .83047 .73524 L .81114 .74332 L p .707 .577 .707 r
F P
0 g
s
.66591 .75354 m .66685 .73557 L .64866 .72547 L p .707 .577 .707 r
F P
0 g
s
.64866 .72547 m .64772 .74345 L .66591 .75354 L p .707 .577 .707 r
F P
0 g
s
.64731 .70175 m .64786 .66499 L .64003 .65576 L p .707 .577 .707 r
F P
0 g
s
.63856 .57654 m .63934 .63254 L .64466 .64005 L p .707 .577 .707 r
F P
0 g
s
.64003 .65576 m .63948 .69252 L .64731 .70175 L p .707 .577 .707 r
F P
0 g
s
.83047 .73524 m .82953 .75321 L .84006 .74306 L p .707 .577 .707 r
F P
0 g
s
.84006 .74306 m .841 .72508 L .83047 .73524 L p .707 .577 .707 r
F P
0 g
s
.64772 .74345 m .64866 .72547 L .63946 .71425 L p .707 .577 .707 r
F P
0 g
s
.84139 .66246 m .84084 .69922 L .84297 .68986 L p .707 .577 .707 r
F P
0 g
s
.84297 .68986 m .84352 .6531 L .84139 .66246 L p .707 .577 .707 r
F P
0 g
s
.63934 .63254 m .63856 .57654 L .64323 .56887 L p .707 .577 .707 r
F P
0 g
s
.84287 .57334 m .84366 .62933 L .83834 .62182 L p .707 .577 .707 r
F P
0 g
s
.83834 .62182 m .83755 .56582 L .84287 .57334 L p .707 .577 .707 r
F P
0 g
s
.63946 .71425 m .63852 .73223 L .64772 .74345 L p .707 .577 .707 r
F P
0 g
s
.63948 .69252 m .64003 .65576 L .64215 .6464 L p .707 .577 .707 r
F P
0 g
s
.64323 .56887 m .64402 .62487 L .63934 .63254 L p .707 .577 .707 r
F P
0 g
s
.64215 .6464 m .64161 .68316 L .63948 .69252 L p .707 .577 .707 r
F P
0 g
s
.841 .72508 m .84006 .74306 L .84076 .73182 L p .705 .576 .707 r
F P
0 g
s
.84076 .73182 m .8417 .71385 L .841 .72508 L p .705 .576 .707 r
F P
0 g
s
.63852 .73223 m .63946 .71425 L .64016 .70302 L p .705 .576 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84352 .6531 m .84297 .68986 L .83514 .68063 L p .707 .577 .707 r
F P
0 g
s
.83514 .68063 m .83569 .64387 L .84352 .6531 L p .707 .577 .707 r
F P
0 g
s
.64402 .62487 m .64323 .56887 L .65745 .56179 L p .707 .577 .707 r
F P
0 g
s
.83755 .56582 m .83834 .62182 L .82353 .6152 L p .707 .577 .707 r
F P
0 g
s
.82353 .6152 m .82275 .5592 L .83755 .56582 L p .707 .577 .707 r
F P
0 g
s
.64016 .70302 m .63922 .721 L .63852 .73223 L p .705 .576 .707 r
F P
0 g
s
.40136 .62171 m .39957 .56639 L .36797 .56601 L p .707 .577 .707 r
F P
0 g
s
.39957 .56639 m .40136 .62171 L .43287 .61928 L p .707 .577 .707 r
F P
0 g
s
.43287 .61928 m .43108 .56395 L .39957 .56639 L p .707 .577 .707 r
F P
0 g
s
.36975 .62133 m .36797 .56601 L .33935 .56284 L p .707 .577 .707 r
F P
0 g
s
.36797 .56601 m .36975 .62133 L .40136 .62171 L p .707 .577 .707 r
F P
0 g
s
.43108 .56395 m .43287 .61928 L .46119 .61425 L p .707 .577 .707 r
F P
0 g
s
.46119 .61425 m .4594 .55893 L .43108 .56395 L p .707 .577 .707 r
F P
0 g
s
.64161 .68316 m .64215 .6464 L .65403 .63783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65745 .56179 m .65824 .61779 L .64402 .62487 L p .707 .577 .707 r
F P
0 g
s
.65403 .63783 m .65349 .67459 L .64161 .68316 L p .707 .577 .707 r
F P
0 g
s
.8417 .71385 m .84076 .73182 L .83156 .72061 L p .707 .577 .707 r
F P
0 g
s
.83156 .72061 m .83251 .70263 L .8417 .71385 L p .707 .577 .707 r
F P
0 g
s
.63922 .721 m .64016 .70302 L .65069 .69287 L p .707 .577 .707 r
F P
0 g
s
.34114 .61816 m .33935 .56284 L .31653 .5572 L p .707 .577 .707 r
F P
0 g
s
.33935 .56284 m .34114 .61816 L .36975 .62133 L p .707 .577 .707 r
F P
0 g
s
.4594 .55893 m .46119 .61425 L .48355 .60714 L p .707 .577 .707 r
F P
0 g
s
.48355 .60714 m .48176 .55182 L .4594 .55893 L p .707 .577 .707 r
F P
0 g
s
.65824 .61779 m .65745 .56179 L .67982 .556 L p .707 .577 .707 r
F P
0 g
s
.83569 .64387 m .83514 .68063 L .81811 .67243 L p .707 .577 .707 r
F P
0 g
s
.81811 .67243 m .81866 .63567 L .83569 .64387 L p .707 .577 .707 r
F P
0 g
s
.82275 .5592 m .82353 .6152 L .8007 .61012 L p .707 .577 .707 r
F P
0 g
s
.8007 .61012 m .79991 .55412 L .82275 .5592 L p .707 .577 .707 r
F P
0 g
s
.40895 .6793 m .41017 .6421 L .37829 .64058 L p .707 .577 .707 r
F P
0 g
s
.41017 .6421 m .40895 .6793 L .43993 .67828 L p .707 .577 .707 r
F P
0 g
s
.43993 .67828 m .44115 .64107 L .41017 .6421 L p .707 .577 .707 r
F P
0 g
s
.37707 .67778 m .37829 .64058 L .34863 .63667 L p .707 .577 .707 r
F P
0 g
s
.37829 .64058 m .37707 .67778 L .40895 .6793 L p .707 .577 .707 r
F P
0 g
s
.65069 .69287 m .64975 .71084 L .63922 .721 L p .707 .577 .707 r
F P
0 g
s
.44115 .64107 m .43993 .67828 L .46697 .67481 L p .707 .577 .707 r
F P
0 g
s
.46697 .67481 m .46819 .63761 L .44115 .64107 L p .707 .577 .707 r
F P
0 g
s
.65349 .67459 m .65403 .63783 L .6745 .63088 L p .707 .577 .707 r
F P
0 g
s
.34863 .63667 m .34741 .67387 L .37707 .67778 L p .707 .577 .707 r
F P
0 g
s
.31653 .5572 m .31832 .61252 L .34114 .61816 L p .707 .577 .707 r
F P
0 g
s
.67982 .556 m .68061 .612 L .65824 .61779 L p .707 .577 .707 r
F P
0 g
s
.34741 .67387 m .34863 .63667 L .32409 .63075 L p .707 .577 .707 r
F P
0 g
s
.37789 .71474 m .37998 .69605 L .34998 .69064 L p .707 .577 .707 r
F P
0 g
s
.37998 .69605 m .37789 .71474 L .40966 .71828 L p .707 .577 .707 r
F P
0 g
s
.40966 .71828 m .41175 .69959 L .37998 .69605 L p .707 .577 .707 r
F P
0 g
s
.41175 .69959 m .40966 .71828 L .4401 .71959 L p .707 .577 .707 r
F P
0 g
s
.4401 .71959 m .44219 .7009 L .41175 .69959 L p .707 .577 .707 r
F P
0 g
s
.31832 .61252 m .31653 .5572 L .30174 .54964 L p .707 .577 .707 r
F P
0 g
s
.48176 .55182 m .48355 .60714 L .49777 .59863 L p .707 .577 .707 r
F P
0 g
s
.49777 .59863 m .49598 .54331 L .48176 .55182 L p .707 .577 .707 r
F P
0 g
s
.34998 .69064 m .3479 .70933 L .37789 .71474 L p .707 .577 .707 r
F P
0 g
s
.68061 .612 m .67982 .556 L .70815 .55207 L p .707 .577 .707 r
F P
0 g
s
.79991 .55412 m .8007 .61012 L .77207 .60708 L p .707 .577 .707 r
F P
0 g
s
.77207 .60708 m .77129 .55108 L .79991 .55412 L p .707 .577 .707 r
F P
0 g
s
.6745 .63088 m .67395 .66764 L .65349 .67459 L p .707 .577 .707 r
F P
0 g
s
.32409 .63075 m .32287 .66795 L .34741 .67387 L p .707 .577 .707 r
F P
0 g
s
.83251 .70263 m .83156 .72061 L .81337 .71051 L p .707 .577 .707 r
F P
0 g
s
.81337 .71051 m .81431 .69254 L .83251 .70263 L p .707 .577 .707 r
F P
0 g
s
.64975 .71084 m .65069 .69287 L .67002 .68478 L p .707 .577 .707 r
F P
0 g
s
.46819 .63761 m .46697 .67481 L .48743 .66925 L p .707 .577 .707 r
F P
0 g
s
.48743 .66925 m .48866 .63205 L .46819 .63761 L p .707 .577 .707 r
F P
0 g
s
.3479 .70933 m .34998 .69064 L .32471 .68388 L p .707 .577 .707 r
F P
0 g
s
.44219 .7009 m .4401 .71959 L .46623 .71855 L p .707 .577 .707 r
F P
0 g
s
.46623 .71855 m .46832 .69986 L .44219 .7009 L p .707 .577 .707 r
F P
0 g
s
.81866 .63567 m .81811 .67243 L .79356 .66607 L p .707 .577 .707 r
F P
0 g
s
.79356 .66607 m .79411 .62931 L .81866 .63567 L p .707 .577 .707 r
F P
0 g
s
.32471 .68388 m .32262 .70257 L .3479 .70933 L p .707 .577 .707 r
F P
0 g
s
.67002 .68478 m .66908 .70276 L .64975 .71084 L p .707 .577 .707 r
F P
0 g
s
.32287 .66795 m .32409 .63075 L .30708 .6234 L p .707 .577 .707 r
F P
0 g
s
.30174 .54964 m .30352 .60496 L .31832 .61252 L p .707 .577 .707 r
F P
0 g
s
.67395 .66764 m .6745 .63088 L .70155 .62623 L p .707 .577 .707 r
F P
0 g
s
.70815 .55207 m .70894 .60807 L .68061 .612 L p .707 .577 .707 r
F P
0 g
s
.70894 .60807 m .70815 .55207 L .73967 .55037 L p .707 .577 .707 r
F P
0 g
s
.77129 .55108 m .77207 .60708 L .74045 .60637 L p .707 .577 .707 r
F P
0 g
s
.74045 .60637 m .73967 .55037 L .77129 .55108 L p .707 .577 .707 r
F P
0 g
s
.73967 .55037 m .74045 .60637 L .70894 .60807 L p .707 .577 .707 r
F P
0 g
s
.30708 .6234 m .30586 .66061 L .32287 .66795 L p .707 .577 .707 r
F P
0 g
s
.32262 .70257 m .32471 .68388 L .30662 .67643 L p .707 .577 .707 r
F P
0 g
s
.46832 .69986 m .46623 .71855 L .48549 .71526 L p .707 .577 .707 r
F P
0 g
s
.48549 .71526 m .48758 .69657 L .46832 .69986 L p .707 .577 .707 r
F P
0 g
s
.30352 .60496 m .30174 .54964 L .29642 .54089 L p .707 .577 .707 r
F P
0 g
s
.79411 .62931 m .79356 .66607 L .76389 .66217 L p .707 .577 .707 r
F P
0 g
s
.76389 .66217 m .76444 .62541 L .79411 .62931 L p .707 .577 .707 r
F P
0 g
s
.49598 .54331 m .49777 .59863 L .50245 .58956 L p .707 .577 .707 r
F P
0 g
s
.50245 .58956 m .50066 .53424 L .49598 .54331 L p .707 .577 .707 r
F P
0 g
s
.70155 .62623 m .70101 .66299 L .67395 .66764 L p .707 .577 .707 r
F P
0 g
s
.30662 .67643 m .30454 .69512 L .32262 .70257 L p .707 .577 .707 r
F P
0 g
s
.81431 .69254 m .81337 .71051 L .78796 .70252 L p .707 .577 .707 r
F P
0 g
s
.78796 .70252 m .7889 .68455 L .81431 .69254 L p .707 .577 .707 r
F P
0 g
s
.66908 .70276 m .67002 .68478 L .69626 .67957 L p .707 .577 .707 r
F P
0 g
s
.48866 .63205 m .48743 .66925 L .49931 .66213 L p .707 .577 .707 r
F P
0 g
s
.49931 .66213 m .50053 .62493 L .48866 .63205 L p .707 .577 .707 r
F P
0 g
s
.70101 .66299 m .70155 .62623 L .73254 .62435 L p .707 .577 .707 r
F P
0 g
s
.69626 .67957 m .69532 .69755 L .66908 .70276 L p .707 .577 .707 r
F P
0 g
s
.76444 .62541 m .76389 .66217 L .73199 .66111 L p .707 .577 .707 r
F P
0 g
s
.73199 .66111 m .73254 .62435 L .76444 .62541 L p .707 .577 .707 r
F P
0 g
s
.73254 .62435 m .73199 .66111 L .70101 .66299 L p .707 .577 .707 r
F P
0 g
s
.30586 .66061 m .30708 .6234 L .29925 .61534 L p .707 .577 .707 r
F P
0 g
s
.29642 .54089 m .29821 .59621 L .30352 .60496 L p .707 .577 .707 r
F P
0 g
s
.7889 .68455 m .78796 .70252 L .75781 .69742 L p .707 .577 .707 r
F P
0 g
s
.75781 .69742 m .75876 .67944 L .7889 .68455 L p .707 .577 .707 r
F P
0 g
s
.69532 .69755 m .69626 .67957 L .72684 .67773 L p .707 .577 .707 r
F P
0 g
s
.29925 .61534 m .29803 .65255 L .30586 .66061 L p .707 .577 .707 r
F P
0 g
s
.30454 .69512 m .30662 .67643 L .29749 .66903 L p .707 .577 .707 r
F P
0 g
s
.48758 .69657 m .48549 .71526 L .496 .71005 L p .707 .577 .707 r
F P
0 g
s
.496 .71005 m .49808 .69135 L .48758 .69657 L p .707 .577 .707 r
F P
0 g
s
.72684 .67773 m .72589 .6957 L .69532 .69755 L p .707 .577 .707 r
F P
0 g
s
.29749 .66903 m .29541 .68772 L .30454 .69512 L p .707 .577 .707 r
F P
0 g
s
.75876 .67944 m .75781 .69742 L .72589 .6957 L p .707 .577 .707 r
F P
0 g
s
.72589 .6957 m .72684 .67773 L .75876 .67944 L p .707 .577 .707 r
F P
0 g
s
.29821 .59621 m .29642 .54089 L .3011 .53182 L p .707 .577 .707 r
F P
0 g
s
.50066 .53424 m .50245 .58956 L .49713 .58082 L p .707 .577 .707 r
F P
0 g
s
.49713 .58082 m .49534 .52549 L .50066 .53424 L p .707 .577 .707 r
F P
0 g
s
.50053 .62493 m .49931 .66213 L .50144 .65415 L p .707 .577 .707 r
F P
0 g
s
.50144 .65415 m .50266 .61695 L .50053 .62493 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29803 .65255 m .29925 .61534 L .30138 .60736 L p .707 .577 .707 r
F P
0 g
s
.3011 .53182 m .30288 .58714 L .29821 .59621 L p .707 .577 .707 r
F P
0 g
s
.30138 .60736 m .30016 .64457 L .29803 .65255 L p .707 .577 .707 r
F P
0 g
s
.29541 .68772 m .29749 .66903 L .29821 .66239 L p .721 .59 .709 r
F P
0 g
s
.49808 .69135 m .496 .71005 L .49673 .70341 L p .721 .59 .709 r
F P
0 g
s
.49673 .70341 m .49881 .68472 L .49808 .69135 L p .721 .59 .709 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29821 .66239 m .29613 .68108 L .29541 .68772 L p .721 .59 .709 r
F P
0 g
s
.30288 .58714 m .3011 .53182 L .31531 .52331 L p .707 .577 .707 r
F P
0 g
s
.49534 .52549 m .49713 .58082 L .48233 .57325 L p .707 .577 .707 r
F P
0 g
s
.48233 .57325 m .48055 .51793 L .49534 .52549 L p .707 .577 .707 r
F P
0 g
s
.50266 .61695 m .50144 .65415 L .49361 .64609 L p .707 .577 .707 r
F P
0 g
s
.49361 .64609 m .49484 .60889 L .50266 .61695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30016 .64457 m .30138 .60736 L .31326 .60024 L p .707 .577 .707 r
F P
0 g
s
.31531 .52331 m .3171 .57863 L .30288 .58714 L p .707 .577 .707 r
F P
0 g
s
.31326 .60024 m .31204 .63745 L .30016 .64457 L p .707 .577 .707 r
F P
0 g
s
.29613 .68108 m .29821 .66239 L .30872 .65717 L p .707 .577 .707 r
F P
0 g
s
.49881 .68472 m .49673 .70341 L .4876 .69601 L p .707 .577 .707 r
F P
0 g
s
.4876 .69601 m .48968 .67732 L .49881 .68472 L p .707 .577 .707 r
F P
0 g
s
.3171 .57863 m .31531 .52331 L .33768 .5162 L p .707 .577 .707 r
F P
0 g
s
.48055 .51793 m .48233 .57325 L .45951 .56761 L p .707 .577 .707 r
F P
0 g
s
.45951 .56761 m .45773 .51229 L .48055 .51793 L p .707 .577 .707 r
F P
0 g
s
.30872 .65717 m .30664 .67587 L .29613 .68108 L p .707 .577 .707 r
F P
0 g
s
.49484 .60889 m .49361 .64609 L .4766 .63874 L p .707 .577 .707 r
F P
0 g
s
.4766 .63874 m .47782 .60154 L .49484 .60889 L p .707 .577 .707 r
F P
0 g
s
.31204 .63745 m .31326 .60024 L .33372 .59468 L p .707 .577 .707 r
F P
0 g
s
.33768 .5162 m .33946 .57152 L .3171 .57863 L p .707 .577 .707 r
F P
0 g
s
.33946 .57152 m .33768 .5162 L .366 .51118 L p .707 .577 .707 r
F P
0 g
s
.45773 .51229 m .45951 .56761 L .4309 .56444 L p .707 .577 .707 r
F P
0 g
s
.4309 .56444 m .42911 .50912 L .45773 .51229 L p .707 .577 .707 r
F P
0 g
s
.33372 .59468 m .3325 .63188 L .31204 .63745 L p .707 .577 .707 r
F P
0 g
s
.30664 .67587 m .30872 .65717 L .32798 .65388 L p .707 .577 .707 r
F P
0 g
s
.48968 .67732 m .4876 .69601 L .46951 .68856 L p .707 .577 .707 r
F P
0 g
s
.46951 .68856 m .47159 .66987 L .48968 .67732 L p .707 .577 .707 r
F P
0 g
s
.32798 .65388 m .3259 .67258 L .30664 .67587 L p .707 .577 .707 r
F P
0 g
s
.47782 .60154 m .4766 .63874 L .45206 .63283 L p .707 .577 .707 r
F P
0 g
s
.45206 .63283 m .45328 .59562 L .47782 .60154 L p .707 .577 .707 r
F P
0 g
s
.36778 .5665 m .366 .51118 L .3975 .50874 L p .707 .577 .707 r
F P
0 g
s
.366 .51118 m .36778 .5665 L .33946 .57152 L p .707 .577 .707 r
F P
0 g
s
.42911 .50912 m .4309 .56444 L .39929 .56406 L p .707 .577 .707 r
F P
0 g
s
.39929 .56406 m .3975 .50874 L .42911 .50912 L p .707 .577 .707 r
F P
0 g
s
.3325 .63188 m .33372 .59468 L .36076 .59122 L p .707 .577 .707 r
F P
0 g
s
.3975 .50874 m .39929 .56406 L .36778 .5665 L p .707 .577 .707 r
F P
0 g
s
.36076 .59122 m .35954 .62842 L .3325 .63188 L p .707 .577 .707 r
F P
0 g
s
.45328 .59562 m .45206 .63283 L .4224 .62892 L p .707 .577 .707 r
F P
0 g
s
.4224 .62892 m .42362 .59171 L .45328 .59562 L p .707 .577 .707 r
F P
0 g
s
.3259 .67258 m .32798 .65388 L .35411 .65284 L p .707 .577 .707 r
F P
0 g
s
.47159 .66987 m .46951 .68856 L .44423 .6818 L p .707 .577 .707 r
F P
0 g
s
.44423 .6818 m .44632 .66311 L .47159 .66987 L p .707 .577 .707 r
F P
0 g
s
.35411 .65284 m .35203 .67154 L .3259 .67258 L p .707 .577 .707 r
F P
0 g
s
.35954 .62842 m .36076 .59122 L .39174 .5902 L p .707 .577 .707 r
F P
0 g
s
.42362 .59171 m .4224 .62892 L .39052 .6274 L p .707 .577 .707 r
F P
0 g
s
.39052 .6274 m .39174 .5902 L .42362 .59171 L p .707 .577 .707 r
F P
0 g
s
.39174 .5902 m .39052 .6274 L .35954 .62842 L p .707 .577 .707 r
F P
0 g
s
.35203 .67154 m .35411 .65284 L .38455 .65416 L p .707 .577 .707 r
F P
0 g
s
.44632 .66311 m .44423 .6818 L .41424 .67639 L p .707 .577 .707 r
F P
0 g
s
.41424 .67639 m .41632 .65769 L .44632 .66311 L p .707 .577 .707 r
F P
0 g
s
.38455 .65416 m .38247 .67285 L .35203 .67154 L p .707 .577 .707 r
F P
0 g
s
.38247 .67285 m .38455 .65416 L .41632 .65769 L p .707 .577 .707 r
F P
0 g
s
.41632 .65769 m .41424 .67639 L .38247 .67285 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`T000=JEP03001JEUYF00IJEP03001JEUYF009J
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GWoo1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001KOol300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00F7oo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00H005YFFUIJEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005Woo4@00?Woo001DOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00003Woo200015YF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00E7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000Ioo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008003Eoo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0035o
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002ioo`00E7oo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4@0015YF00@005YFFUIJEPH000EJEP04001JEUYFFUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00Oomoo`0/Ool005Aoo`03001JEP0000=JEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEPD0
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00
E7oo00<005YF00000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol00`00FUH00003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUH00000FUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01000FUH005YF0P001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000]Ool005Aoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00T000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001D
Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH00`00FUIJEP02FUH80007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<005YF00001P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH005YF00AJEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00?Goo5`0000=oo`0000000UYF0`000UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000eYF00L005YFFUIJ
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000gOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH400000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YF
FUIJEP8002eoo`00<Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF0P00;Goo000_Ool20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH0000002eoo`00;Woo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002eoo`00;Goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH04@001eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP03001JEUYF009JEPH0009JEP03001JEP0000EJEPH000AJEP03001JEUYF009JEPH0
00EJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<0
05YF00000P0000=JEP0000000P000eYF00<005YF00001EYF1P0015YF00<005YFFUH025YF100000=J
EP00FUH00eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001oogoo02aoo`00;7oo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP80009JEP03
001JEUYF00=JEPH000EJEPH000AJEP03001JEUYF00QJEPL000=JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00Oomoo`0/
Ool002aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<000AJEP03001JEUYF00AJEP04001JEUYFFUHK0003FUH01000FUIJEUYF
0P0000=JEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH>0002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEQh0009JEP03001JEUYF00AJEP03
001JEUYF009JEPT0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF1P000UYF6@001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH015YF00<005YF
FUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`8000=JEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00=JEPD000IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;7oo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF
00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF000010001EYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF1P000UYF00<007ooOol027oo0`002Goo1P00
1EYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool200001EYF000005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00@005YFFUIJEP8000Qoo`D000ioo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH03@0000=JEP0000001`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEPD0
00AJEP04001JEUYFFUH20008Ool5000BOol30003FUH00`00FUH0000]Ool002aoo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH400000eYF
001JEP04FUH01P00FUIJEUYF001JEPT00003FUH0000000L000AJEP03001JEUYF00EJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUH000040003FUH20002Ool;000?Ool30003FUH2000015YF001JEP00;Goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH4
00000eYF001JEP030005FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000T00003FUH0000000@0
00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@000=JEP03001JEUYF00=JEPP000AJEP03001JEUYF009JEPT000Aoo`@00003FUH0
05YF00AJEP<00003FUH007oo02aoo`00;7oo0P0015YF00<005YFFUH00eYF00@005YFFUIJEQP000=J
EP04001JEUYFFUH30003FUH01`00FUIJEUYF001JEP0000EJEPH000AJEP03001JEUYF00IJEP@00003
FUH005YF00AJEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30004FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000AJEP03001JEUYF00=JEP@00003
FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003
0003FUH00`00FUH00005FUH60004FUH00`00FUIJEP08FUH00`00FUH000020003FUH01P00FUIJEP00
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
008002eoo`00;Goo00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF1P001EYF1P0015YF00<005YFFUH025YF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02000]Ool002eoo`800003FUH0
00000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00EJEP03001JEUYF009JEPX000EJEP03001JEUYF00QJEP03001JEUYF00AJEP80
009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000AJEP03
001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP<00005FUH0
05YFFUH0000^Ool002moo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000UJEP03001J
EUYF00=JEP@00004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
0005FUH01000FUIJEUYF20000UYF00<005YFFUH015YF200015YF00<005YFFUH01EYF00<005YFFUH0
0P000UYF00<007ooOol0;7oo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF3`000UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1P001UYF00<005YFFUH00UYF0P00;goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P00;goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00eYF00<0
05YF0000;Woo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUH000030000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH01000FUIJ
EP00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP070004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF1P0015YF00<0
05YFFUH00UYF0`0000=JEP00FUH01eYF00@005YFFUIJEPD0009oo`800005FUH005YFFUH0000]Ool0
02aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00AJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF01P000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP04001JEUYFFUH@0004FUH80009
Ool20002FUH00`00Oomoo`0[Ool002aoo`80009JEP03001JEUYF00=JEP03001JEUYF009JEPP000Eo
o`<000Uoo`P000=JEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEP00FUH005YF10000eYF00@005YFFUIJEP8000Qoo`X0019oo`04001JEP00000]Ool0
02aoo`80009JEP03001JEUYF009JEPH000aoo`D000eoo`P000=JEP800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF008000EJEP800003FUH005YF009JEP8000Qoo`D001Qo
o`<002eoo`00;7oo0P000UYF00<005YF00000P000UYF1`002Goo1@001Goo20000eYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00<000EJ
EP<000=JEP03001oogoo00Qoo`<001Uoo`<002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00@0
05YFFUIJEQ<000=JEP03001JEUYF00EJEP03001JEUYF00=JEP@00003FUH005YF00AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP04001JEUYF0002FUH20003FUH00`00FUIJEP0200000eYF001oo`0UOol3
000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF0`0097oo0P0000=JEP00Ool0
;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP000004FUH00`00FUH0000300001EYF001JEUYF000087oo0`0000AJEP00FUH0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH=0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH00eYF1P006Woo1@0015YF00<005YF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00=JEP`000=JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP02FUH0
0`00FUH0000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEQh0009JEP06001JEUYF
001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
0eYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF001JEP00FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002ioo`80
00=JEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000D00003FUH005YF00AJEP03001JEUYF00D000]JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEPH000IJEP03001JEUYF009JEP05001JEP00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000`
Ool200000eYF000000050003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH015YF0`0015YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00<0
05YF00001@000UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YF000003=oo`00<Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000=JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<0
00AJEP03001JEP0000Eoo`D00003FUH0000000@000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPD003Eoo`00<7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00H005YF001JEP00FUH200000eYF
001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP020002FUH00`00FUH00004Ool30003FUH200001EYF001JEP00Ool02@00
15YF00<005YFFUH00UYF2000>Woo000^Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0003
FUH00`00FUIJEP03FUH200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF
0000000300000eYF001JEP04FUH300000eYF001oo`09Ool90012Ool002eoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH60006Ool3000@Ool60003FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF0000000300000eYF001JEP04FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0004FUH0
0`00FUIJEP04000;Ool5000COol80005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF0000
0003FUH50002FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0002FUH5000?Ool5000>Ool50004
FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P001UYF00<005YF
00000P000UYF0P00EGoo000]Ool00`00FUIJEP03000DOol50006Ool80003FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJ
EP02FUH3001FOol002eoo`<0009JEPh000Qoo`X000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF
009JEP8005Ioo`00;Goo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000H000=JEP03001JEUYF009JEP03001JEP0005Eoo`00;Goo00<005YF000015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`000Woo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`001UYF1@000eYF
00<005YF0000EGoo000]Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2000015YF001JEP00EGoo000^Ool40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2
00000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF00000P000Woo0P00
00=JEP00Ool0E7oo000bOol70003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
000BOol30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH0000015YF00@005YFFUIJEPD000Moo`03001JEP0005Aoo`00>Goo6@00
77oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF10000UYF20002goo00@005YF000005Aoo`00L7oo0`0000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02`004goo00@005YF000005Aoo`00
Lgoo10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1@000Woo1@005Goo0P00
0eYF00<007ooOol0DWoo001gOol60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06
0007Ool5000COol200000eYF001JEP02FUH00`00Oomoo`1BOol007eooal000eoo`D0011oo`<000=J
EP05001JEUYFFUH0001DOol008ioo`<001Uoo`<000moo`800003FUH005YF00AJEP03001JEP0005Eo
o`00SWoo0P0000=JEP0000009Woo0`000eYF00<005YFFUH00eYF0P00EWoo002?Ool01000FUH005YF
0P0087oo10001UYF00<005YFFUH00eYF00<007ooOol0EGoo002?Ool00`00FUH00003FUH5000GOol4
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P00F7oo002?Ool00`00FUH00004FUH01000FUIJEUYF
1`002Goo1`001UYF00<005YFFUH01EYF00@005YF000005Yoo`00T7oo0P0015YF00<005YFFUH015YF
00@005YFFUIJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP<005aoo`00T7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00Ggoo
002AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
001SOol009=oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06Moo`00UGoo1@000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Jgoo002JOolA001bOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59154 .75043 m .58983 .69505 L .55931 .69328 L p .707 .577 .707 r
F P
0 g
s
.58983 .69505 m .59154 .75043 L .62349 .74939 L p .707 .577 .707 r
F P
0 g
s
.62349 .74939 m .62178 .69401 L .58983 .69505 L p .707 .577 .707 r
F P
0 g
s
.62178 .69401 m .62349 .74939 L .65374 .74565 L p .707 .577 .707 r
F P
0 g
s
.65374 .74565 m .65203 .69027 L .62178 .69401 L p .707 .577 .707 r
F P
0 g
s
.56102 .74866 m .55931 .69328 L .53319 .68888 L p .707 .577 .707 r
F P
0 g
s
.55931 .69328 m .56102 .74866 L .59154 .75043 L p .707 .577 .707 r
F P
0 g
s
.65203 .69027 m .65374 .74565 L .67932 .73958 L p .707 .577 .707 r
F P
0 g
s
.67932 .73958 m .67761 .6842 L .65203 .69027 L p .707 .577 .707 r
F P
0 g
s
.61487 .80877 m .61598 .77163 L .5841 .77019 L p .707 .577 .707 r
F P
0 g
s
.61598 .77163 m .61487 .80877 L .64584 .80761 L p .707 .577 .707 r
F P
0 g
s
.64584 .80761 m .64696 .77047 L .61598 .77163 L p .707 .577 .707 r
F P
0 g
s
.58298 .80733 m .5841 .77019 L .55443 .76628 L p .707 .577 .707 r
F P
0 g
s
.5841 .77019 m .58298 .80733 L .61487 .80877 L p .707 .577 .707 r
F P
0 g
s
.53319 .68888 m .5349 .74425 L .56102 .74866 L p .707 .577 .707 r
F P
0 g
s
.5349 .74425 m .53319 .68888 L .51405 .68227 L p .707 .577 .707 r
F P
0 g
s
.67761 .6842 m .67932 .73958 L .69774 .73176 L p .707 .577 .707 r
F P
0 g
s
.69774 .73176 m .69603 .67638 L .67761 .6842 L p .707 .577 .707 r
F P
0 g
s
.64696 .77047 m .64584 .80761 L .67288 .80395 L p .707 .577 .707 r
F P
0 g
s
.67288 .80395 m .674 .76682 L .64696 .77047 L p .707 .577 .707 r
F P
0 g
s
.55443 .76628 m .55331 .80342 L .58298 .80733 L p .707 .577 .707 r
F P
0 g
s
.55331 .80342 m .55443 .76628 L .52988 .7603 L p .707 .577 .707 r
F P
0 g
s
.60663 .8492 m .60848 .83061 L .57686 .82678 L p .707 .577 .707 r
F P
0 g
s
.60848 .83061 m .60663 .8492 L .63779 .85059 L p .707 .577 .707 r
F P
0 g
s
.63779 .85059 m .63965 .832 L .60848 .83061 L p .707 .577 .707 r
F P
0 g
s
.57501 .84537 m .57686 .82678 L .54788 .8209 L p .707 .577 .707 r
F P
0 g
s
.57686 .82678 m .57501 .84537 L .60663 .8492 L p .707 .577 .707 r
F P
0 g
s
.51405 .68227 m .51576 .73765 L .5349 .74425 L p .707 .577 .707 r
F P
0 g
s
.63965 .832 m .63779 .85059 L .66545 .84942 L p .707 .577 .707 r
F P
0 g
s
.66545 .84942 m .66731 .83083 L .63965 .832 L p .707 .577 .707 r
F P
0 g
s
.54788 .8209 m .54603 .83949 L .57501 .84537 L p .707 .577 .707 r
F P
0 g
s
.52988 .7603 m .52876 .79744 L .55331 .80342 L p .707 .577 .707 r
F P
0 g
s
.674 .76682 m .67288 .80395 L .69333 .79817 L p .707 .577 .707 r
F P
0 g
s
.69333 .79817 m .69445 .76103 L .674 .76682 L p .707 .577 .707 r
F P
0 g
s
.54603 .83949 m .54788 .8209 L .52438 .81354 L p .707 .577 .707 r
F P
0 g
s
.51576 .73765 m .51405 .68227 L .50375 .67412 L p .707 .577 .707 r
F P
0 g
s
.69603 .67638 m .69774 .73176 L .70718 .72296 L p .707 .577 .707 r
F P
0 g
s
.70718 .72296 m .70547 .66758 L .69603 .67638 L p .707 .577 .707 r
F P
0 g
s
.52876 .79744 m .52988 .7603 L .51285 .75282 L p .707 .577 .707 r
F P
0 g
s
.52438 .81354 m .52252 .83213 L .54603 .83949 L p .707 .577 .707 r
F P
0 g
s
.66731 .83083 m .66545 .84942 L .6869 .8458 L p .707 .577 .707 r
F P
0 g
s
.6869 .8458 m .68876 .82721 L .66731 .83083 L p .707 .577 .707 r
F P
0 g
s
.51285 .75282 m .51173 .78996 L .52876 .79744 L p .707 .577 .707 r
F P
0 g
s
.50375 .67412 m .50546 .72949 L .51576 .73765 L p .707 .577 .707 r
F P
0 g
s
.69445 .76103 m .69333 .79817 L .70519 .79082 L p .707 .577 .707 r
F P
0 g
s
.70519 .79082 m .70631 .75368 L .69445 .76103 L p .707 .577 .707 r
F P
0 g
s
.52252 .83213 m .52438 .81354 L .50866 .80542 L p .707 .577 .707 r
F P
0 g
s
.50866 .80542 m .5068 .824 L .52252 .83213 L p .707 .577 .707 r
F P
0 g
s
.51173 .78996 m .51285 .75282 L .505 .74458 L p .707 .577 .707 r
F P
0 g
s
.50546 .72949 m .50375 .67412 L .5033 .6652 L p .708 .578 .707 r
F P
0 g
s
.70547 .66758 m .70718 .72296 L .70673 .71404 L p .708 .578 .707 r
F P
0 g
s
.70673 .71404 m .70502 .65867 L .70547 .66758 L p .708 .578 .707 r
F P
0 g
s
.68876 .82721 m .6869 .8458 L .70004 .84007 L p .707 .577 .707 r
F P
0 g
s
.70004 .84007 m .70189 .82149 L .68876 .82721 L p .707 .577 .707 r
F P
0 g
s
.505 .74458 m .50388 .78172 L .51173 .78996 L p .707 .577 .707 r
F P
0 g
s
.5033 .6652 m .50501 .72058 L .50546 .72949 L p .708 .578 .707 r
F P
0 g
s
.5068 .824 m .50866 .80542 L .50225 .79733 L p .707 .577 .707 r
F P
0 g
s
.70631 .75368 m .70519 .79082 L .7073 .78262 L p .707 .577 .707 r
F P
0 g
s
.7073 .78262 m .70842 .74548 L .70631 .75368 L p .707 .577 .707 r
F P
0 g
s
.48624 .82175 m .48624 .31986 L .44255 .31683 L p .707 .577 .707 r
F P
0 g
s
.50225 .79733 m .5004 .81592 L .5068 .824 L p .707 .577 .707 r
F P
0 g
s
.50388 .78172 m .505 .74458 L .50711 .73638 L p .707 .577 .707 r
F P
0 g
s
.50501 .72058 m .5033 .6652 L .51274 .65641 L p .707 .577 .707 r
F P
0 g
s
.50711 .73638 m .506 .77352 L .50388 .78172 L p .707 .577 .707 r
F P
0 g
s
.51274 .65641 m .51445 .71178 L .50501 .72058 L p .707 .577 .707 r
F P
0 g
s
.5004 .81592 m .50225 .79733 L .50579 .79007 L p .707 .577 .707 r
F P
0 g
s
.50579 .79007 m .50393 .80866 L .5004 .81592 L p .707 .577 .707 r
F P
0 g
s
.506 .77352 m .50711 .73638 L .51897 .72903 L p .707 .577 .707 r
F P
0 g
s
.51445 .71178 m .51274 .65641 L .53116 .64859 L p .707 .577 .707 r
F P
0 g
s
.51897 .72903 m .51786 .76617 L .506 .77352 L p .707 .577 .707 r
F P
0 g
s
.53116 .64859 m .53287 .70396 L .51445 .71178 L p .707 .577 .707 r
F P
0 g
s
.50393 .80866 m .50579 .79007 L .51893 .78435 L p .707 .577 .707 r
F P
0 g
s
.51893 .78435 m .51707 .80294 L .50393 .80866 L p .707 .577 .707 r
F P
0 g
s
.51786 .76617 m .51897 .72903 L .53942 .72325 L p .707 .577 .707 r
F P
0 g
s
.53942 .72325 m .53831 .76039 L .51786 .76617 L p .707 .577 .707 r
F P
0 g
s
.51707 .80294 m .51893 .78435 L .54037 .78072 L p .707 .577 .707 r
F P
0 g
s
.54037 .78072 m .53852 .79931 L .51707 .80294 L p .707 .577 .707 r
F P
0 g
s
.48624 .31986 m .48624 .82175 L .53129 .821 L p .707 .577 .707 r
F P
0 g
s
.53287 .70396 m .53116 .64859 L .55674 .64251 L p .707 .577 .707 r
F P
0 g
s
.53129 .821 m .53129 .31911 L .48624 .31986 L p .707 .577 .707 r
F P
0 g
s
.55674 .64251 m .55845 .69789 L .53287 .70396 L p .707 .577 .707 r
F P
0 g
s
.55845 .69789 m .55674 .64251 L .58699 .63877 L p .707 .577 .707 r
F P
0 g
s
.53831 .76039 m .53942 .72325 L .56646 .7196 L p .707 .577 .707 r
F P
0 g
s
.58699 .63877 m .5887 .69415 L .55845 .69789 L p .707 .577 .707 r
F P
0 g
s
.56646 .7196 m .56534 .75674 L .53831 .76039 L p .707 .577 .707 r
F P
0 g
s
.56534 .75674 m .56646 .7196 L .59743 .71843 L p .707 .577 .707 r
F P
0 g
s
.53852 .79931 m .54037 .78072 L .56804 .77955 L p .707 .577 .707 r
F P
0 g
s
.56804 .77955 m .56618 .79814 L .53852 .79931 L p .707 .577 .707 r
F P
0 g
s
.59743 .71843 m .59632 .75557 L .56534 .75674 L p .707 .577 .707 r
F P
0 g
s
.56618 .79814 m .56804 .77955 L .5992 .78095 L p .707 .577 .707 r
F P
0 g
s
.5992 .78095 m .59735 .79954 L .56618 .79814 L p .707 .577 .707 r
F P
0 g
s
.53129 .31911 m .53129 .821 L .57327 .81656 L p .707 .577 .707 r
F P
0 g
s
.57327 .81656 m .57327 .31467 L .53129 .31911 L p .707 .577 .707 r
F P
0 g
s
.44255 .81872 m .44255 .31683 L .40447 .31033 L p .707 .577 .707 r
F P
0 g
s
.44255 .31683 m .44255 .81872 L .48624 .82175 L p .707 .577 .707 r
F P
0 g
s
.70189 .82149 m .70004 .84007 L .70358 .83281 L p .707 .577 .707 r
F P
0 g
s
.70358 .83281 m .70543 .81423 L .70189 .82149 L p .707 .577 .707 r
F P
0 g
s
.70502 .65867 m .70673 .71404 L .69643 .70589 L p .707 .577 .707 r
F P
0 g
s
.69643 .70589 m .69472 .65051 L .70502 .65867 L p .707 .577 .707 r
F P
0 g
s
.5887 .69415 m .58699 .63877 L .61894 .63773 L p .707 .577 .707 r
F P
0 g
s
.61894 .63773 m .62065 .69311 L .5887 .69415 L p .707 .577 .707 r
F P
0 g
s
.62932 .71988 m .6282 .75701 L .59632 .75557 L p .707 .577 .707 r
F P
0 g
s
.59632 .75557 m .59743 .71843 L .62932 .71988 L p .707 .577 .707 r
F P
0 g
s
.63082 .78477 m .62897 .80336 L .59735 .79954 L p .707 .577 .707 r
F P
0 g
s
.59735 .79954 m .5992 .78095 L .63082 .78477 L p .707 .577 .707 r
F P
0 g
s
.57327 .31467 m .57327 .81656 L .60808 .80885 L p .707 .577 .707 r
F P
0 g
s
.60808 .80885 m .60808 .30696 L .57327 .31467 L p .707 .577 .707 r
F P
0 g
s
.24671 .71036 m .246 .65432 L .21546 .65244 L p .707 .577 .707 r
F P
0 g
s
.246 .65432 m .24671 .71036 L .27867 .70987 L p .707 .577 .707 r
F P
0 g
s
.27867 .70987 m .27796 .65383 L .246 .65432 L p .707 .577 .707 r
F P
0 g
s
.27796 .65383 m .27867 .70987 L .30893 .70706 L p .707 .577 .707 r
F P
0 g
s
.30893 .70706 m .30822 .65102 L .27796 .65383 L p .707 .577 .707 r
F P
0 g
s
.70842 .74548 m .7073 .78262 L .69946 .77438 L p .707 .577 .707 r
F P
0 g
s
.69946 .77438 m .70057 .73724 L .70842 .74548 L p .707 .577 .707 r
F P
0 g
s
.40447 .81222 m .40447 .31033 L .37575 .30099 L p .707 .577 .707 r
F P
0 g
s
.40447 .31033 m .40447 .81222 L .44255 .81872 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21617 .70849 m .21546 .65244 L .18934 .64838 L p .707 .577 .707 r
F P
0 g
s
.21546 .65244 m .21617 .70849 L .24671 .71036 L p .707 .577 .707 r
F P
0 g
s
.30822 .65102 m .30893 .70706 L .33452 .70221 L p .707 .577 .707 r
F P
0 g
s
.33452 .70221 m .33381 .64617 L .30822 .65102 L p .707 .577 .707 r
F P
0 g
s
.69472 .65051 m .69643 .70589 L .67728 .69928 L p .707 .577 .707 r
F P
0 g
s
.67728 .69928 m .67557 .64391 L .69472 .65051 L p .707 .577 .707 r
F P
0 g
s
.70543 .81423 m .70358 .83281 L .69717 .82473 L p .707 .577 .707 r
F P
0 g
s
.69717 .82473 m .69903 .80614 L .70543 .81423 L p .707 .577 .707 r
F P
0 g
s
.64946 .6395 m .65117 .69488 L .62065 .69311 L p .707 .577 .707 r
F P
0 g
s
.62065 .69311 m .61894 .63773 L .64946 .6395 L p .707 .577 .707 r
F P
0 g
s
.65899 .72378 m .65787 .76092 L .6282 .75701 L p .707 .577 .707 r
F P
0 g
s
.6282 .75701 m .62932 .71988 L .65899 .72378 L p .707 .577 .707 r
F P
0 g
s
.62897 .80336 m .63082 .78477 L .6598 .79066 L p .707 .577 .707 r
F P
0 g
s
.60808 .30696 m .60808 .80885 L .63231 .79863 L p .707 .577 .707 r
F P
0 g
s
.63231 .79863 m .63231 .29675 L .60808 .30696 L p .707 .577 .707 r
F P
0 g
s
.27036 .77709 m .27081 .74041 L .23891 .73943 L p .707 .577 .707 r
F P
0 g
s
.27081 .74041 m .27036 .77709 L .30135 .77507 L p .707 .577 .707 r
F P
0 g
s
.30135 .77507 m .30179 .73839 L .27081 .74041 L p .707 .577 .707 r
F P
0 g
s
.23847 .77611 m .23891 .73943 L .20923 .73553 L p .707 .577 .707 r
F P
0 g
s
.23891 .73943 m .23847 .77611 L .27036 .77709 L p .707 .577 .707 r
F P
0 g
s
.18934 .64838 m .19005 .70443 L .21617 .70849 L p .707 .577 .707 r
F P
0 g
s
.19005 .70443 m .18934 .64838 L .17018 .64254 L p .707 .577 .707 r
F P
0 g
s
.30179 .73839 m .30135 .77507 L .32839 .77024 L p .707 .577 .707 r
F P
0 g
s
.32839 .77024 m .32883 .73355 L .30179 .73839 L p .707 .577 .707 r
F P
0 g
s
.33381 .64617 m .33452 .70221 L .35293 .69579 L p .707 .577 .707 r
F P
0 g
s
.35293 .69579 m .35222 .63975 L .33381 .64617 L p .707 .577 .707 r
F P
0 g
s
.70057 .73724 m .69946 .77438 L .68243 .7669 L p .707 .577 .707 r
F P
0 g
s
.68243 .7669 m .68354 .72976 L .70057 .73724 L p .707 .577 .707 r
F P
0 g
s
.20878 .77221 m .20923 .73553 L .18466 .72911 L p .707 .577 .707 r
F P
0 g
s
.20923 .73553 m .20878 .77221 L .23847 .77611 L p .707 .577 .707 r
F P
0 g
s
.67557 .64391 m .67728 .69928 L .65117 .69488 L p .707 .577 .707 r
F P
0 g
s
.65117 .69488 m .64946 .6395 L .67557 .64391 L p .707 .577 .707 r
F P
0 g
s
.37575 .80288 m .37575 .30099 L .35919 .28973 L p .707 .577 .707 r
F P
0 g
s
.37575 .30099 m .37575 .80288 L .40447 .81222 L p .707 .577 .707 r
F P
0 g
s
.17018 .64254 m .17089 .69858 L .19005 .70443 L p .707 .577 .707 r
F P
0 g
s
.26446 .82611 m .26518 .80833 L .23343 .80592 L p .707 .577 .707 r
F P
0 g
s
.26518 .80833 m .26446 .82611 L .29574 .82471 L p .707 .577 .707 r
F P
0 g
s
.29574 .82471 m .29645 .80693 L .26518 .80833 L p .707 .577 .707 r
F P
0 g
s
.69903 .80614 m .69717 .82473 L .68145 .81661 L p .707 .577 .707 r
F P
0 g
s
.68145 .81661 m .6833 .79802 L .69903 .80614 L p .707 .577 .707 r
F P
0 g
s
.32883 .73355 m .32839 .77024 L .34884 .76307 L p .707 .577 .707 r
F P
0 g
s
.34884 .76307 m .34928 .72639 L .32883 .73355 L p .707 .577 .707 r
F P
0 g
s
.18466 .72911 m .18422 .76579 L .20878 .77221 L p .707 .577 .707 r
F P
0 g
s
.23271 .82369 m .23343 .80592 L .2043 .79993 L p .707 .577 .707 r
F P
0 g
s
.23343 .80592 m .23271 .82369 L .26446 .82611 L p .707 .577 .707 r
F P
0 g
s
.29645 .80693 m .29574 .82471 L .32347 .81964 L p .707 .577 .707 r
F P
0 g
s
.32347 .81964 m .32419 .80186 L .29645 .80693 L p .707 .577 .707 r
F P
0 g
s
.17089 .69858 m .17018 .64254 L .15987 .63548 L p .707 .577 .707 r
F P
0 g
s
.2043 .79993 m .20358 .8177 L .23271 .82369 L p .707 .577 .707 r
F P
0 g
s
.18422 .76579 m .18466 .72911 L .16762 .72078 L p .707 .577 .707 r
F P
0 g
s
.63231 .29675 m .63231 .79863 L .64359 .78691 L p .707 .577 .707 r
F P
0 g
s
.64359 .78691 m .64359 .28502 L .63231 .29675 L p .707 .577 .707 r
F P
0 g
s
.35222 .63975 m .35293 .69579 L .36237 .68843 L p .707 .577 .707 r
F P
0 g
s
.36237 .68843 m .36167 .63238 L .35222 .63975 L p .707 .577 .707 r
F P
0 g
s
.68354 .72976 m .68243 .7669 L .65787 .76092 L p .707 .577 .707 r
F P
0 g
s
.65787 .76092 m .65899 .72378 L .68354 .72976 L p .707 .577 .707 r
F P
0 g
s
.20358 .8177 m .2043 .79993 L .18064 .79094 L p .707 .577 .707 r
F P
0 g
s
.32419 .80186 m .32347 .81964 L .34494 .81138 L p .707 .577 .707 r
F P
0 g
s
.34494 .81138 m .34566 .7936 L .32419 .80186 L p .707 .577 .707 r
F P
0 g
s
.18064 .79094 m .17993 .80872 L .20358 .8177 L p .707 .577 .707 r
F P
0 g
s
.16762 .72078 m .16717 .75746 L .18422 .76579 L p .707 .577 .707 r
F P
0 g
s
.15987 .63548 m .16058 .69152 L .17089 .69858 L p .707 .577 .707 r
F P
0 g
s
.34928 .72639 m .34884 .76307 L .3607 .75427 L p .707 .577 .707 r
F P
0 g
s
.3607 .75427 m .36114 .71758 L .34928 .72639 L p .707 .577 .707 r
F P
0 g
s
.6833 .79802 m .68145 .81661 L .65795 .80924 L p .707 .577 .707 r
F P
0 g
s
.65795 .80924 m .6598 .79066 L .6833 .79802 L p .707 .577 .707 r
F P
0 g
s
.17993 .80872 m .18064 .79094 L .16479 .77985 L p .707 .577 .707 r
F P
0 g
s
.16717 .75746 m .16762 .72078 L .15976 .71137 L p .707 .577 .707 r
F P
0 g
s
.35877 .78298 m .35805 .80075 L .36152 .78879 L p .707 .577 .707 r
F P
0 g
s
.36152 .78879 m .36224 .77102 L .35877 .78298 L p .707 .577 .707 r
F P
0 g
s
.36121 .6248 m .36192 .68085 L .35161 .67379 L p .707 .577 .707 r
F P
0 g
s
.35161 .67379 m .3509 .61774 L .36121 .6248 L p .707 .577 .707 r
F P
0 g
s
.36114 .71758 m .3607 .75427 L .36281 .74469 L p .707 .577 .707 r
F P
0 g
s
.36281 .74469 m .36325 .70801 L .36114 .71758 L p .707 .577 .707 r
F P
0 g
s
.36325 .70801 m .36281 .74469 L .35495 .73528 L p .707 .577 .707 r
F P
0 g
s
.35495 .73528 m .3554 .6986 L .36325 .70801 L p .707 .577 .707 r
F P
0 g
s
.35805 .80075 m .35877 .78298 L .34566 .7936 L p .707 .577 .707 r
F P
0 g
s
.36224 .77102 m .36152 .78879 L .35501 .77668 L p .707 .577 .707 r
F P
0 g
s
.35501 .77668 m .35573 .7589 L .36224 .77102 L p .707 .577 .707 r
F P
0 g
s
.35919 .79161 m .35919 .28973 L .35641 .27764 L p .707 .577 .707 r
F P
0 g
s
.36167 .63238 m .36237 .68843 L .36192 .68085 L p .708 .578 .707 r
F P
0 g
s
.36192 .68085 m .36121 .6248 L .36167 .63238 L p .708 .578 .707 r
F P
0 g
s
.35919 .28973 m .35919 .79161 L .37575 .80288 L p .707 .577 .707 r
F P
0 g
s
.16058 .69152 m .15987 .63548 L .15941 .62789 L p .708 .578 .707 r
F P
0 g
s
.16479 .77985 m .16407 .79763 L .17993 .80872 L p .707 .577 .707 r
F P
0 g
s
.34566 .7936 m .34494 .81138 L .35805 .80075 L p .707 .577 .707 r
F P
0 g
s
.15976 .71137 m .15932 .74805 L .16717 .75746 L p .707 .577 .707 r
F P
0 g
s
.6598 .79066 m .65795 .80924 L .62897 .80336 L p .707 .577 .707 r
F P
0 g
s
.15941 .62789 m .16012 .68394 L .16058 .69152 L p .708 .578 .707 r
F P
0 g
s
.64359 .28502 m .64359 .78691 L .64081 .77482 L p .707 .577 .707 r
F P
0 g
s
.64081 .77482 m .64081 .27293 L .64359 .28502 L p .707 .577 .707 r
F P
0 g
s
.16407 .79763 m .16479 .77985 L .15827 .76773 L p .707 .577 .707 r
F P
0 g
s
.15932 .74805 m .15976 .71137 L .16187 .7018 L p .707 .577 .707 r
F P
0 g
s
.15827 .76773 m .15756 .78551 L .16407 .79763 L p .707 .577 .707 r
F P
0 g
s
.16012 .68394 m .15941 .62789 L .16886 .62053 L p .707 .577 .707 r
F P
0 g
s
.16187 .7018 m .16143 .73848 L .15932 .74805 L p .707 .577 .707 r
F P
0 g
s
.35641 .27764 m .35641 .77953 L .35919 .79161 L p .707 .577 .707 r
F P
0 g
s
.35641 .77953 m .35641 .27764 L .36769 .26591 L p .707 .577 .707 r
F P
0 g
s
.16886 .62053 m .16956 .67658 L .16012 .68394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15756 .78551 m .15827 .76773 L .16174 .75577 L p .707 .577 .707 r
F P
0 g
s
.16174 .75577 m .16102 .77355 L .15756 .78551 L p .707 .577 .707 r
F P
0 g
s
.16143 .73848 m .16187 .7018 L .17373 .693 L p .707 .577 .707 r
F P
0 g
s
.64081 .27293 m .64081 .77482 L .62425 .76356 L p .707 .577 .707 r
F P
0 g
s
.62425 .76356 m .62425 .26167 L .64081 .27293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16956 .67658 m .16886 .62053 L .18727 .61411 L p .707 .577 .707 r
F P
0 g
s
.3509 .61774 m .35161 .67379 L .33245 .66794 L p .707 .577 .707 r
F P
0 g
s
.33245 .66794 m .33174 .6119 L .3509 .61774 L p .707 .577 .707 r
F P
0 g
s
.17373 .693 m .17329 .72968 L .16143 .73848 L p .707 .577 .707 r
F P
0 g
s
.18727 .61411 m .18798 .67015 L .16956 .67658 L p .707 .577 .707 r
F P
0 g
s
.3554 .6986 m .35495 .73528 L .33791 .72696 L p .707 .577 .707 r
F P
0 g
s
.33791 .72696 m .33835 .69028 L .3554 .6986 L p .707 .577 .707 r
F P
0 g
s
.16102 .77355 m .16174 .75577 L .17485 .74514 L p .707 .577 .707 r
F P
0 g
s
.36769 .7678 m .36769 .26591 L .39192 .2557 L p .707 .577 .707 r
F P
0 g
s
.36769 .26591 m .36769 .7678 L .35641 .77953 L p .707 .577 .707 r
F P
0 g
s
.17329 .72968 m .17373 .693 L .19418 .68583 L p .707 .577 .707 r
F P
0 g
s
.18798 .67015 m .18727 .61411 L .21286 .60926 L p .707 .577 .707 r
F P
0 g
s
.17485 .74514 m .17414 .76292 L .16102 .77355 L p .707 .577 .707 r
F P
0 g
s
.33174 .6119 m .33245 .66794 L .30633 .66388 L p .707 .577 .707 r
F P
0 g
s
.30633 .66388 m .30562 .60784 L .33174 .6119 L p .707 .577 .707 r
F P
0 g
s
.35573 .7589 m .35501 .77668 L .33915 .76558 L p .707 .577 .707 r
F P
0 g
s
.33915 .76558 m .33987 .7478 L .35573 .7589 L p .707 .577 .707 r
F P
0 g
s
.19418 .68583 m .19374 .72251 L .17329 .72968 L p .707 .577 .707 r
F P
0 g
s
.62425 .26167 m .62425 .76356 L .59553 .75422 L p .707 .577 .707 r
F P
0 g
s
.59553 .75422 m .59553 .25233 L .62425 .26167 L p .707 .577 .707 r
F P
0 g
s
.21286 .60926 m .21357 .6653 L .18798 .67015 L p .707 .577 .707 r
F P
0 g
s
.33835 .69028 m .33791 .72696 L .31334 .72053 L p .707 .577 .707 r
F P
0 g
s
.31334 .72053 m .31379 .68385 L .33835 .69028 L p .707 .577 .707 r
F P
0 g
s
.21357 .6653 m .21286 .60926 L .24312 .60645 L p .707 .577 .707 r
F P
0 g
s
.30562 .60784 m .30633 .66388 L .27579 .662 L p .707 .577 .707 r
F P
0 g
s
.27579 .662 m .27508 .60596 L .30562 .60784 L p .707 .577 .707 r
F P
0 g
s
.17414 .76292 m .17485 .74514 L .19633 .73689 L p .707 .577 .707 r
F P
0 g
s
.19374 .72251 m .19418 .68583 L .22122 .681 L p .707 .577 .707 r
F P
0 g
s
.19633 .73689 m .19561 .75467 L .17414 .76292 L p .707 .577 .707 r
F P
0 g
s
.24383 .66249 m .24312 .60645 L .27508 .60596 L p .707 .577 .707 r
F P
0 g
s
.24312 .60645 m .24383 .66249 L .21357 .6653 L p .707 .577 .707 r
F P
0 g
s
.27508 .60596 m .27579 .662 L .24383 .66249 L p .707 .577 .707 r
F P
0 g
s
.33987 .7478 m .33915 .76558 L .3155 .7566 L p .707 .577 .707 r
F P
0 g
s
.3155 .7566 m .31622 .73882 L .33987 .7478 L p .707 .577 .707 r
F P
0 g
s
.39192 .2557 m .39192 .75759 L .36769 .7678 L p .707 .577 .707 r
F P
0 g
s
.39192 .75759 m .39192 .2557 L .42673 .24799 L p .707 .577 .707 r
F P
0 g
s
.31379 .68385 m .31334 .72053 L .28366 .71664 L p .707 .577 .707 r
F P
0 g
s
.28366 .71664 m .2841 .67996 L .31379 .68385 L p .707 .577 .707 r
F P
0 g
s
.22122 .681 m .22078 .71768 L .19374 .72251 L p .707 .577 .707 r
F P
0 g
s
.72421 .65928 m .72492 .60423 L .69438 .60104 L p .707 .577 .707 r
F P
0 g
s
.72492 .60423 m .72421 .65928 L .75617 .65952 L p .707 .577 .707 r
F P
0 g
s
.75617 .65952 m .75688 .60446 L .72492 .60423 L p .707 .577 .707 r
F P
0 g
s
.75688 .60446 m .75617 .65952 L .78643 .65679 L p .707 .577 .707 r
F P
0 g
s
.78643 .65679 m .78714 .60173 L .75688 .60446 L p .707 .577 .707 r
F P
0 g
s
.22078 .71768 m .22122 .681 L .25221 .67897 L p .707 .577 .707 r
F P
0 g
s
.19561 .75467 m .19633 .73689 L .22406 .73181 L p .707 .577 .707 r
F P
0 g
s
.69367 .6561 m .69438 .60104 L .66826 .59523 L p .707 .577 .707 r
F P
0 g
s
.69438 .60104 m .69367 .6561 L .72421 .65928 L p .707 .577 .707 r
F P
0 g
s
.2841 .67996 m .28366 .71664 L .25176 .71565 L p .707 .577 .707 r
F P
0 g
s
.25176 .71565 m .25221 .67897 L .2841 .67996 L p .707 .577 .707 r
F P
0 g
s
.78714 .60173 m .78643 .65679 L .81202 .65136 L p .707 .577 .707 r
F P
0 g
s
.81202 .65136 m .81273 .59631 L .78714 .60173 L p .707 .577 .707 r
F P
0 g
s
.59553 .25233 m .59553 .75422 L .55745 .74772 L p .707 .577 .707 r
F P
0 g
s
.55745 .74772 m .55745 .24583 L .59553 .25233 L p .707 .577 .707 r
F P
0 g
s
.25221 .67897 m .25176 .71565 L .22078 .71768 L p .707 .577 .707 r
F P
0 g
s
.31622 .73882 m .3155 .7566 L .28637 .75061 L p .707 .577 .707 r
F P
0 g
s
.28637 .75061 m .28709 .73283 L .31622 .73882 L p .707 .577 .707 r
F P
0 g
s
.22406 .73181 m .22334 .74959 L .19561 .75467 L p .707 .577 .707 r
F P
0 g
s
.74823 .71361 m .74779 .67623 L .7159 .67609 L p .707 .577 .707 r
F P
0 g
s
.74779 .67623 m .74823 .71361 L .77922 .71141 L p .707 .577 .707 r
F P
0 g
s
.77922 .71141 m .77878 .67403 L .74779 .67623 L p .707 .577 .707 r
F P
0 g
s
.22334 .74959 m .22406 .73181 L .25533 .73041 L p .707 .577 .707 r
F P
0 g
s
.71634 .71347 m .7159 .67609 L .68621 .67363 L p .707 .577 .707 r
F P
0 g
s
.7159 .67609 m .71634 .71347 L .74823 .71361 L p .707 .577 .707 r
F P
0 g
s
.66826 .59523 m .66755 .65028 L .69367 .6561 L p .707 .577 .707 r
F P
0 g
s
.28709 .73283 m .28637 .75061 L .25461 .74819 L p .707 .577 .707 r
F P
0 g
s
.25461 .74819 m .25533 .73041 L .28709 .73283 L p .707 .577 .707 r
F P
0 g
s
.66755 .65028 m .66826 .59523 L .6491 .58735 L p .707 .577 .707 r
F P
0 g
s
.42673 .74988 m .42673 .24799 L .46871 .24355 L p .707 .577 .707 r
F P
0 g
s
.42673 .24799 m .42673 .74988 L .39192 .75759 L p .707 .577 .707 r
F P
0 g
s
.81273 .59631 m .81202 .65136 L .83043 .64377 L p .707 .577 .707 r
F P
0 g
s
.83043 .64377 m .83114 .58871 L .81273 .59631 L p .707 .577 .707 r
F P
0 g
s
.25533 .73041 m .25461 .74819 L .22334 .74959 L p .707 .577 .707 r
F P
0 g
s
.77878 .67403 m .77922 .71141 L .80626 .7071 L p .707 .577 .707 r
F P
0 g
s
.80626 .7071 m .80582 .66971 L .77878 .67403 L p .707 .577 .707 r
F P
0 g
s
.68621 .67363 m .68666 .71101 L .71634 .71347 L p .707 .577 .707 r
F P
0 g
s
.55745 .24583 m .55745 .74772 L .51375 .74469 L p .707 .577 .707 r
F P
0 g
s
.51375 .74469 m .51375 .2428 L .55745 .24583 L p .707 .577 .707 r
F P
0 g
s
.74538 .74794 m .74467 .72895 L .71291 .72959 L p .707 .577 .707 r
F P
0 g
s
.74467 .72895 m .74538 .74794 L .77666 .7458 L p .707 .577 .707 r
F P
0 g
s
.77666 .7458 m .77594 .7268 L .74467 .72895 L p .707 .577 .707 r
F P
0 g
s
.68666 .71101 m .68621 .67363 L .66165 .66909 L p .707 .577 .707 r
F P
0 g
s
.71291 .72959 m .71363 .74858 L .74538 .74794 L p .707 .577 .707 r
F P
0 g
s
.71363 .74858 m .71291 .72959 L .68378 .72866 L p .707 .577 .707 r
F P
0 g
s
.77594 .7268 m .77666 .7458 L .80439 .74235 L p .707 .577 .707 r
F P
0 g
s
.80439 .74235 m .80367 .72335 L .77594 .7268 L p .707 .577 .707 r
F P
0 g
s
.68378 .72866 m .6845 .74765 L .71363 .74858 L p .707 .577 .707 r
F P
0 g
s
.46871 .74544 m .46871 .24355 L .51375 .2428 L p .707 .577 .707 r
F P
0 g
s
.46871 .24355 m .46871 .74544 L .42673 .74988 L p .707 .577 .707 r
F P
0 g
s
.6491 .58735 m .64839 .64241 L .66755 .65028 L p .707 .577 .707 r
F P
0 g
s
.66165 .66909 m .66209 .70647 L .68666 .71101 L p .707 .577 .707 r
F P
0 g
s
.51375 .2428 m .51375 .74469 L .46871 .74544 L p .707 .577 .707 r
F P
0 g
s
.80582 .66971 m .80626 .7071 L .82671 .70108 L p .707 .577 .707 r
F P
0 g
s
.82671 .70108 m .82627 .6637 L .80582 .66971 L p .707 .577 .707 r
F P
0 g
s
.64839 .64241 m .6491 .58735 L .63879 .57819 L p .707 .577 .707 r
F P
0 g
s
.6845 .74765 m .68378 .72866 L .66013 .72625 L p .707 .577 .707 r
F P
0 g
s
.83114 .58871 m .83043 .64377 L .83988 .63474 L p .707 .577 .707 r
F P
0 g
s
.83988 .63474 m .84058 .57969 L .83114 .58871 L p .707 .577 .707 r
F P
0 g
s
.66013 .72625 m .66085 .74524 L .6845 .74765 L p .707 .577 .707 r
F P
0 g
s
.66209 .70647 m .66165 .66909 L .6446 .66291 L p .707 .577 .707 r
F P
0 g
s
.80367 .72335 m .80439 .74235 L .82586 .73794 L p .707 .577 .707 r
F P
0 g
s
.82586 .73794 m .82514 .71895 L .80367 .72335 L p .707 .577 .707 r
F P
0 g
s
.6446 .66291 m .64504 .70029 L .66209 .70647 L p .707 .577 .707 r
F P
0 g
s
.63879 .57819 m .63808 .63324 L .64839 .64241 L p .707 .577 .707 r
F P
0 g
s
.82627 .6637 m .82671 .70108 L .83857 .69396 L p .707 .577 .707 r
F P
0 g
s
.83857 .69396 m .83813 .65658 L .82627 .6637 L p .707 .577 .707 r
F P
0 g
s
.66085 .74524 m .66013 .72625 L .64427 .72259 L p .707 .577 .707 r
F P
0 g
s
.64427 .72259 m .64499 .74158 L .66085 .74524 L p .707 .577 .707 r
F P
0 g
s
.82514 .71895 m .82586 .73794 L .83897 .733 L p .707 .577 .707 r
F P
0 g
s
.83897 .733 m .83826 .71401 L .82514 .71895 L p .707 .577 .707 r
F P
0 g
s
.63808 .63324 m .63879 .57819 L .63833 .56862 L p .707 .578 .707 r
F P
0 g
s
.64504 .70029 m .6446 .66291 L .63675 .6557 L p .707 .577 .707 r
F P
0 g
s
.84058 .57969 m .83988 .63474 L .83942 .62518 L p .707 .578 .707 r
F P
0 g
s
.83942 .62518 m .84013 .57013 L .84058 .57969 L p .707 .578 .707 r
F P
0 g
s
.63675 .6557 m .63719 .69308 L .64504 .70029 L p .707 .577 .707 r
F P
0 g
s
.63833 .56862 m .63762 .62368 L .63808 .63324 L p .707 .578 .707 r
F P
0 g
s
.83813 .65658 m .83857 .69396 L .84068 .68643 L p .707 .577 .707 r
F P
0 g
s
.84068 .68643 m .84023 .64905 L .83813 .65658 L p .707 .577 .707 r
F P
0 g
s
.64499 .74158 m .64427 .72259 L .63776 .71805 L p .707 .577 .707 r
F P
0 g
s
.63776 .71805 m .63847 .73704 L .64499 .74158 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83826 .71401 m .83897 .733 L .84244 .72802 L p .707 .577 .707 r
F P
0 g
s
.84244 .72802 m .84173 .70902 L .83826 .71401 L p .707 .577 .707 r
F P
0 g
s
.63762 .62368 m .63833 .56862 L .64777 .5596 L p .707 .577 .707 r
F P
0 g
s
.63719 .69308 m .63675 .6557 L .63885 .64817 L p .707 .577 .707 r
F P
0 g
s
.84013 .57013 m .83942 .62518 L .82911 .61601 L p .707 .577 .707 r
F P
0 g
s
.82911 .61601 m .82982 .56096 L .84013 .57013 L p .707 .577 .707 r
F P
0 g
s
.63885 .64817 m .6393 .68555 L .63719 .69308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64777 .5596 m .64707 .61466 L .63762 .62368 L p .707 .577 .707 r
F P
0 g
s
.37935 .61924 m .38106 .56351 L .35054 .5602 L p .707 .577 .707 r
F P
0 g
s
.38106 .56351 m .37935 .61924 L .4113 .62004 L p .707 .577 .707 r
F P
0 g
s
.4113 .62004 m .41301 .56431 L .38106 .56351 L p .707 .577 .707 r
F P
0 g
s
.41301 .56431 m .4113 .62004 L .44155 .61825 L p .707 .577 .707 r
F P
0 g
s
.44155 .61825 m .44326 .56252 L .41301 .56431 L p .707 .577 .707 r
F P
0 g
s
.84023 .64905 m .84068 .68643 L .83282 .67922 L p .707 .577 .707 r
F P
0 g
s
.83282 .67922 m .83238 .64184 L .84023 .64905 L p .707 .577 .707 r
F P
0 g
s
.63847 .73704 m .63776 .71805 L .64123 .71306 L p .707 .577 .707 r
F P
0 g
s
.64123 .71306 m .64194 .73206 L .63847 .73704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.34883 .61593 m .35054 .5602 L .32442 .55471 L p .707 .577 .707 r
F P
0 g
s
.35054 .5602 m .34883 .61593 L .37935 .61924 L p .707 .577 .707 r
F P
0 g
s
.64707 .61466 m .64777 .5596 L .66619 .55201 L p .707 .577 .707 r
F P
0 g
s
.84173 .70902 m .84244 .72802 L .83593 .72347 L p .707 .577 .707 r
F P
0 g
s
.83593 .72347 m .83521 .70448 L .84173 .70902 L p .707 .577 .707 r
F P
0 g
s
.44326 .56252 m .44155 .61825 L .46713 .61406 L p .707 .577 .707 r
F P
0 g
s
.46713 .61406 m .46884 .55833 L .44326 .56252 L p .707 .577 .707 r
F P
0 g
s
.82982 .56096 m .82911 .61601 L .80995 .60814 L p .707 .577 .707 r
F P
0 g
s
.80995 .60814 m .81066 .55308 L .82982 .56096 L p .707 .577 .707 r
F P
0 g
s
.6393 .68555 m .63885 .64817 L .65071 .64105 L p .707 .577 .707 r
F P
0 g
s
.40368 .68197 m .40256 .64503 L .37068 .64534 L p .707 .577 .707 r
F P
0 g
s
.40256 .64503 m .40368 .68197 L .43465 .67893 L p .707 .577 .707 r
F P
0 g
s
.43465 .67893 m .43354 .64199 L .40256 .64503 L p .707 .577 .707 r
F P
0 g
s
.65071 .64105 m .65116 .67843 L .6393 .68555 L p .707 .577 .707 r
F P
0 g
s
.3718 .68227 m .37068 .64534 L .34101 .64287 L p .707 .577 .707 r
F P
0 g
s
.37068 .64534 m .3718 .68227 L .40368 .68197 L p .707 .577 .707 r
F P
0 g
s
.32442 .55471 m .32271 .61044 L .34883 .61593 L p .707 .577 .707 r
F P
0 g
s
.32271 .61044 m .32442 .55471 L .30528 .54758 L p .707 .577 .707 r
F P
0 g
s
.66619 .55201 m .66548 .60706 L .64707 .61466 L p .707 .577 .707 r
F P
0 g
s
.43354 .64199 m .43465 .67893 L .46169 .67344 L p .707 .577 .707 r
F P
0 g
s
.46169 .67344 m .46057 .6365 L .43354 .64199 L p .707 .577 .707 r
F P
0 g
s
.46884 .55833 m .46713 .61406 L .48555 .60786 L p .707 .577 .707 r
F P
0 g
s
.48555 .60786 m .48726 .55213 L .46884 .55833 L p .707 .577 .707 r
F P
0 g
s
.83238 .64184 m .83282 .67922 L .81578 .67304 L p .707 .577 .707 r
F P
0 g
s
.81578 .67304 m .81534 .63566 L .83238 .64184 L p .707 .577 .707 r
F P
0 g
s
.64194 .73206 m .64123 .71306 L .65434 .70812 L p .707 .577 .707 r
F P
0 g
s
.34101 .64287 m .34212 .6798 L .3718 .68227 L p .707 .577 .707 r
F P
0 g
s
.34212 .6798 m .34101 .64287 L .31645 .63787 L p .707 .577 .707 r
F P
0 g
s
.66548 .60706 m .66619 .55201 L .69178 .54658 L p .707 .577 .707 r
F P
0 g
s
.65434 .70812 m .65506 .72712 L .64194 .73206 L p .707 .577 .707 r
F P
0 g
s
.81066 .55308 m .80995 .60814 L .78383 .60232 L p .707 .577 .707 r
F P
0 g
s
.78383 .60232 m .78454 .54727 L .81066 .55308 L p .707 .577 .707 r
F P
0 g
s
.40265 .72529 m .4008 .70701 L .36917 .70888 L p .707 .577 .707 r
F P
0 g
s
.4008 .70701 m .40265 .72529 L .43382 .72049 L p .707 .577 .707 r
F P
0 g
s
.43382 .72049 m .43196 .70221 L .4008 .70701 L p .707 .577 .707 r
F P
0 g
s
.30528 .54758 m .30357 .60331 L .32271 .61044 L p .707 .577 .707 r
F P
0 g
s
.83521 .70448 m .83593 .72347 L .82007 .71982 L p .707 .577 .707 r
F P
0 g
s
.82007 .71982 m .81935 .70082 L .83521 .70448 L p .707 .577 .707 r
F P
0 g
s
.65116 .67843 m .65071 .64105 L .67116 .63503 L p .707 .577 .707 r
F P
0 g
s
.37103 .72716 m .36917 .70888 L .3402 .70764 L p .707 .577 .707 r
F P
0 g
s
.36917 .70888 m .37103 .72716 L .40265 .72529 L p .707 .577 .707 r
F P
0 g
s
.46057 .6365 m .46169 .67344 L .48214 .66604 L p .707 .577 .707 r
F P
0 g
s
.48214 .66604 m .48102 .62911 L .46057 .6365 L p .707 .577 .707 r
F P
0 g
s
.43196 .70221 m .43382 .72049 L .46148 .71323 L p .707 .577 .707 r
F P
0 g
s
.46148 .71323 m .45962 .69495 L .43196 .70221 L p .707 .577 .707 r
F P
0 g
s
.31645 .63787 m .31757 .67481 L .34212 .6798 L p .707 .577 .707 r
F P
0 g
s
.3402 .70764 m .34205 .72591 L .37103 .72716 L p .707 .577 .707 r
F P
0 g
s
.30357 .60331 m .30528 .54758 L .29498 .5395 L p .707 .577 .707 r
F P
0 g
s
.67116 .63503 m .67161 .67241 L .65116 .67843 L p .707 .577 .707 r
F P
0 g
s
.69178 .54658 m .69107 .60163 L .66548 .60706 L p .707 .577 .707 r
F P
0 g
s
.69107 .60163 m .69178 .54658 L .72204 .54385 L p .707 .577 .707 r
F P
0 g
s
.31757 .67481 m .31645 .63787 L .29942 .63083 L p .707 .577 .707 r
F P
0 g
s
.48726 .55213 m .48555 .60786 L .49499 .60027 L p .707 .577 .707 r
F P
0 g
s
.49499 .60027 m .4967 .54454 L .48726 .55213 L p .707 .577 .707 r
F P
0 g
s
.78454 .54727 m .78383 .60232 L .75329 .59914 L p .707 .577 .707 r
F P
0 g
s
.75329 .59914 m .754 .54409 L .78454 .54727 L p .707 .577 .707 r
F P
0 g
s
.34205 .72591 m .3402 .70764 L .31669 .7034 L p .707 .577 .707 r
F P
0 g
s
.81534 .63566 m .81578 .67304 L .79121 .6685 L p .707 .577 .707 r
F P
0 g
s
.79121 .6685 m .79077 .63112 L .81534 .63566 L p .707 .577 .707 r
F P
0 g
s
.45962 .69495 m .46148 .71323 L .48293 .70422 L p .707 .577 .707 r
F P
0 g
s
.48293 .70422 m .48107 .68594 L .45962 .69495 L p .707 .577 .707 r
F P
0 g
s
.65506 .72712 m .65434 .70812 L .67581 .70372 L p .707 .577 .707 r
F P
0 g
s
.31669 .7034 m .31855 .72168 L .34205 .72591 L p .707 .577 .707 r
F P
0 g
s
.72133 .5989 m .72204 .54385 L .754 .54409 L p .707 .577 .707 r
F P
0 g
s
.72204 .54385 m .72133 .5989 L .69107 .60163 L p .707 .577 .707 r
F P
0 g
s
.754 .54409 m .75329 .59914 L .72133 .5989 L p .707 .577 .707 r
F P
0 g
s
.67581 .70372 m .67653 .72271 L .65506 .72712 L p .707 .577 .707 r
F P
0 g
s
.29942 .63083 m .30054 .66777 L .31757 .67481 L p .707 .577 .707 r
F P
0 g
s
.29498 .5395 m .29327 .59523 L .30357 .60331 L p .707 .577 .707 r
F P
0 g
s
.67161 .67241 m .67116 .63503 L .69821 .63072 L p .707 .577 .707 r
F P
0 g
s
.48102 .62911 m .48214 .66604 L .494 .65747 L p .707 .577 .707 r
F P
0 g
s
.494 .65747 m .49288 .62053 L .48102 .62911 L p .707 .577 .707 r
F P
0 g
s
.81935 .70082 m .82007 .71982 L .79642 .71741 L p .707 .577 .707 r
F P
0 g
s
.79642 .71741 m .7957 .69841 L .81935 .70082 L p .707 .577 .707 r
F P
0 g
s
.69821 .63072 m .69865 .6681 L .67161 .67241 L p .707 .577 .707 r
F P
0 g
s
.79077 .63112 m .79121 .6685 L .76153 .66604 L p .707 .577 .707 r
F P
0 g
s
.76153 .66604 m .76109 .62866 L .79077 .63112 L p .707 .577 .707 r
F P
0 g
s
.31855 .72168 m .31669 .7034 L .30097 .69659 L p .707 .577 .707 r
F P
0 g
s
.29327 .59523 m .29498 .5395 L .29453 .53126 L p .707 .578 .707 r
F P
0 g
s
.48107 .68594 m .48293 .70422 L .49606 .69435 L p .707 .577 .707 r
F P
0 g
s
.49606 .69435 m .49421 .67607 L .48107 .68594 L p .707 .577 .707 r
F P
0 g
s
.30054 .66777 m .29942 .63083 L .29158 .62244 L p .707 .577 .707 r
F P
0 g
s
.69865 .6681 m .69821 .63072 L .72919 .62852 L p .707 .577 .707 r
F P
0 g
s
.30097 .69659 m .30283 .71487 L .31855 .72168 L p .707 .577 .707 r
F P
0 g
s
.4967 .54454 m .49499 .60027 L .49454 .59203 L p .707 .578 .707 r
F P
0 g
s
.49454 .59203 m .49625 .5363 L .4967 .54454 L p .707 .578 .707 r
F P
0 g
s
.67653 .72271 m .67581 .70372 L .70354 .70027 L p .707 .577 .707 r
F P
0 g
s
.70354 .70027 m .70426 .71926 L .67653 .72271 L p .707 .577 .707 r
F P
0 g
s
.76109 .62866 m .76153 .66604 L .72963 .6659 L p .707 .577 .707 r
F P
0 g
s
.72963 .6659 m .72919 .62852 L .76109 .62866 L p .707 .577 .707 r
F P
0 g
s
.7957 .69841 m .79642 .71741 L .76729 .71647 L p .707 .577 .707 r
F P
0 g
s
.76729 .71647 m .76657 .69748 L .7957 .69841 L p .707 .577 .707 r
F P
0 g
s
.72919 .62852 m .72963 .6659 L .69865 .6681 L p .707 .577 .707 r
F P
0 g
s
.29158 .62244 m .29269 .65938 L .30054 .66777 L p .707 .577 .707 r
F P
0 g
s
.29453 .53126 m .29282 .58699 L .29327 .59523 L p .707 .578 .707 r
F P
0 g
s
.49288 .62053 m .494 .65747 L .49611 .64855 L p .707 .577 .707 r
F P
0 g
s
.49611 .64855 m .495 .61161 L .49288 .62053 L p .707 .577 .707 r
F P
0 g
s
.70426 .71926 m .70354 .70027 L .73482 .69812 L p .707 .577 .707 r
F P
0 g
s
.76657 .69748 m .76729 .71647 L .73553 .71711 L p .707 .577 .707 r
F P
0 g
s
.73553 .71711 m .73482 .69812 L .76657 .69748 L p .707 .577 .707 r
F P
0 g
s
.73482 .69812 m .73553 .71711 L .70426 .71926 L p .707 .577 .707 r
F P
0 g
s
.30283 .71487 m .30097 .69659 L .29456 .68787 L p .707 .577 .707 r
F P
0 g
s
.49421 .67607 m .49606 .69435 L .4996 .68457 L p .707 .577 .707 r
F P
0 g
s
.4996 .68457 m .49775 .66629 L .49421 .67607 L p .707 .577 .707 r
F P
0 g
s
.29269 .65938 m .29158 .62244 L .29369 .61352 L p .707 .577 .707 r
F P
0 g
s
.29456 .68787 m .29642 .70615 L .30283 .71487 L p .707 .577 .707 r
F P
0 g
s
.29282 .58699 m .29453 .53126 L .30397 .52367 L p .707 .577 .707 r
F P
0 g
s
.49625 .5363 m .49454 .59203 L .48424 .58395 L p .707 .577 .707 r
F P
0 g
s
.48424 .58395 m .48595 .52822 L .49625 .5363 L p .707 .577 .707 r
F P
0 g
s
.29369 .61352 m .29481 .65046 L .29269 .65938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30397 .52367 m .30226 .5794 L .29282 .58699 L p .707 .577 .707 r
F P
0 g
s
.495 .61161 m .49611 .64855 L .48827 .64016 L p .707 .577 .707 r
F P
0 g
s
.48827 .64016 m .48715 .60322 L .495 .61161 L p .707 .577 .707 r
F P
0 g
s
.29642 .70615 m .29456 .68787 L .2981 .6781 L p .707 .577 .707 r
F P
0 g
s
.49775 .66629 m .4996 .68457 L .4932 .67585 L p .707 .577 .707 r
F P
0 g
s
.4932 .67585 m .49134 .65757 L .49775 .66629 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30226 .5794 m .30397 .52367 L .32239 .51747 L p .707 .577 .707 r
F P
0 g
s
.2981 .6781 m .29996 .69637 L .29642 .70615 L p .707 .577 .707 r
F P
0 g
s
.29481 .65046 m .29369 .61352 L .30555 .60495 L p .707 .577 .707 r
F P
0 g
s
.48595 .52822 m .48424 .58395 L .46509 .57681 L p .707 .577 .707 r
F P
0 g
s
.46509 .57681 m .4668 .52108 L .48595 .52822 L p .707 .577 .707 r
F P
0 g
s
.30555 .60495 m .30667 .64188 L .29481 .65046 L p .707 .577 .707 r
F P
0 g
s
.32239 .51747 m .32068 .5732 L .30226 .5794 L p .707 .577 .707 r
F P
0 g
s
.48715 .60322 m .48827 .64016 L .47124 .63312 L p .707 .577 .707 r
F P
0 g
s
.47124 .63312 m .47012 .59618 L .48715 .60322 L p .707 .577 .707 r
F P
0 g
s
.29996 .69637 m .2981 .6781 L .31124 .66822 L p .707 .577 .707 r
F P
0 g
s
.32068 .5732 m .32239 .51747 L .34797 .51328 L p .707 .577 .707 r
F P
0 g
s
.49134 .65757 m .4932 .67585 L .47747 .66904 L p .707 .577 .707 r
F P
0 g
s
.47747 .66904 m .47562 .65076 L .49134 .65757 L p .707 .577 .707 r
F P
0 g
s
.4668 .52108 m .46509 .57681 L .43898 .57133 L p .707 .577 .707 r
F P
0 g
s
.43898 .57133 m .44069 .5156 L .4668 .52108 L p .707 .577 .707 r
F P
0 g
s
.30667 .64188 m .30555 .60495 L .326 .59755 L p .707 .577 .707 r
F P
0 g
s
.31124 .66822 m .31309 .6865 L .29996 .69637 L p .707 .577 .707 r
F P
0 g
s
.326 .59755 m .32712 .63449 L .30667 .64188 L p .707 .577 .707 r
F P
0 g
s
.34797 .51328 m .34626 .56901 L .32068 .5732 L p .707 .577 .707 r
F P
0 g
s
.47012 .59618 m .47124 .63312 L .44668 .62812 L p .707 .577 .707 r
F P
0 g
s
.44668 .62812 m .44557 .59119 L .47012 .59618 L p .707 .577 .707 r
F P
0 g
s
.34626 .56901 m .34797 .51328 L .37822 .51149 L p .707 .577 .707 r
F P
0 g
s
.44069 .5156 m .43898 .57133 L .40846 .56802 L p .707 .577 .707 r
F P
0 g
s
.40846 .56802 m .41017 .51229 L .44069 .5156 L p .707 .577 .707 r
F P
0 g
s
.31309 .6865 m .31124 .66822 L .33269 .65921 L p .707 .577 .707 r
F P
0 g
s
.32712 .63449 m .326 .59755 L .35304 .59206 L p .707 .577 .707 r
F P
0 g
s
.37651 .56722 m .37822 .51149 L .41017 .51229 L p .707 .577 .707 r
F P
0 g
s
.37822 .51149 m .37651 .56722 L .34626 .56901 L p .707 .577 .707 r
F P
0 g
s
.47562 .65076 m .47747 .66904 L .45397 .66481 L p .707 .577 .707 r
F P
0 g
s
.45397 .66481 m .45212 .64653 L .47562 .65076 L p .707 .577 .707 r
F P
0 g
s
.41017 .51229 m .40846 .56802 L .37651 .56722 L p .707 .577 .707 r
F P
0 g
s
.33269 .65921 m .33454 .67749 L .31309 .6865 L p .707 .577 .707 r
F P
0 g
s
.44557 .59119 m .44668 .62812 L .41701 .62565 L p .707 .577 .707 r
F P
0 g
s
.41701 .62565 m .4159 .58872 L .44557 .59119 L p .707 .577 .707 r
F P
0 g
s
.35304 .59206 m .35415 .629 L .32712 .63449 L p .707 .577 .707 r
F P
0 g
s
.35415 .629 m .35304 .59206 L .38401 .58902 L p .707 .577 .707 r
F P
0 g
s
.4159 .58872 m .41701 .62565 L .38513 .62596 L p .707 .577 .707 r
F P
0 g
s
.38513 .62596 m .38401 .58902 L .4159 .58872 L p .707 .577 .707 r
F P
0 g
s
.33454 .67749 m .33269 .65921 L .36035 .65196 L p .707 .577 .707 r
F P
0 g
s
.38401 .58902 m .38513 .62596 L .35415 .629 L p .707 .577 .707 r
F P
0 g
s
.45212 .64653 m .45397 .66481 L .42499 .66356 L p .707 .577 .707 r
F P
0 g
s
.42499 .66356 m .42314 .64529 L .45212 .64653 L p .707 .577 .707 r
F P
0 g
s
.36035 .65196 m .3622 .67023 L .33454 .67749 L p .707 .577 .707 r
F P
0 g
s
.3622 .67023 m .36035 .65196 L .39152 .64716 L p .707 .577 .707 r
F P
0 g
s
.42314 .64529 m .42499 .66356 L .39337 .66543 L p .707 .577 .707 r
F P
0 g
s
.39337 .66543 m .39152 .64716 L .42314 .64529 L p .707 .577 .707 r
F P
0 g
s
.39152 .64716 m .39337 .66543 L .3622 .67023 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo8@00O7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0065ooaT000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00GGoo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P002EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
05=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`0@OolA0013Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Woo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEPH003eoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00<003Uoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@003Eoo`00Dgoo00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001oogooOol200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000<goo001COol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@007oo000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000aOol005=oo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00Dgoo00<005YF0000
1EYF00<005YFFUH00eYF5`0015YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0002moo`00Dgoo00<005YF00001EYF00<005YF00000`000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00<005YFFUH00UYF00@005YFFUH0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00;Woo001COol00`00FUH00003FUH40006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`03001JEP0000<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`800003FUH005YF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
0005FUH005YFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002io
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJ
EP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH000AJEP03
001JEUYF00=JEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`04001JEUYF0004FUH60003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP00;Woo001DOol30003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005Ioo`@0009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000EJEP04001JEUYFFUH800000eYF0000000F0004FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo0011OolG0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEPD000AJEP03001JEUYF00IJEP03001JEP0000@0009J
EP03001JEUYF00EJEP03001JEUYF00D000AJEP04001JEUYF000^Ool003Uoo`P000AJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP08001JEUYFFUH005YF001JEP<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP04001JEUYF
000^Ool003Aoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080009JEP03001oogoo02aoo`00<Woo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<007ooOol0;7oo000`Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002ioo`00;Woo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00UYF00<005YFFUH015YF3`001eYF1`001EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP0500001EYF001JEUYF0000
1EYF1@001UYF00<005YFFUH015YF100000=JEP00FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH80004FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YF0000
;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP8000=JEP04001JEUYFFUH40004FUH00`00FUH00002FUH00`00FUIJEP03FUH50006FUH0
0`00FUIJEP08FUH30003FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH50003FUH00`00FUH0000^Ool002eoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
00000`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH00eYF
1@000eYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00006FUH00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008002moo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH30003FUH90002
FUH00`00FUIJEP04FUH30005FUH80003FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<002moo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUHN0005
FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000_Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUH000080004FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP020004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJ
EP00FUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03
001JEUYF00AJEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHE0004FUH00`00FUH000020007FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00@005YFFUIJEPP000AJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000=JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEPT000MJEP03
001JEP0000H000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP000eYF1@0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH00eYF1P001eYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH01@000UYF00<007ooOol01Goo
1@001goo20000eYF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01@00FUIJEP00FUH00P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YF0000
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF0P0000=JEP000000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YF
FUH02`0000=JEP00Ool01Woo1@0017oo2@000UYF1@000eYF00<005YF0000;Woo000]Ool00`00FUIJ
EP020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000eYF10001UYF00@005YFFUIJEQ8000AJEP03001JEUYF00EJEP04001JEUYF
FUH2000015YF001JEP00;Woo000]Ool40005FUH00`00FUIJEP04FUHH0004FUH01000FUIJEUYF2000
15YF00<005YFFUH00UYF40001eYF00<005YFFUH00eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001oo`0]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH01000FUH000000UYF00<005YFFUH00UYF3`001UYF00<005YFFUH02EYF00@005YFFUIJEP80
0004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000]Ool01000FUIJEP001EYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF1`0015YF0P000UYF00<005YFFUH00eYF
1@001UYF00<005YFFUH02EYF00@005YF000000AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;Goo00@005YFFUH0009JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEUYF001JEP000UYF0P001EYF0`000UYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH0
25YF0`0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000^Ool5
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00`0000=J
EP00FUH01EYF00<005YF00000`000UYF00<005YFFUH015YF0`001eYF00<005YFFUH01EYF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000_Ool30005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP@00003
FUH005YF00EJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHK0004FUH01000FUH00000;goo
000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP800004FUH000000006FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF1@00
1EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`00<Goo000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP@000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0;0003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000_Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF01L000IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@000=JEP03001JEUYF00AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP<002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000BOol400000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF00<005YFFUH00UYF20000goo1@002Goo3@000UYF00<005YF0000;Goo000]Ool01@00FUIJ
EUYF000015YF1@003Goo0`003Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP04001JEUYFFUH700001EYF001JEUYF00001Woo1@0037oo1`000UYF100000=JEP00
Ool0;7oo000]Ool01P00FUIJEUYF001JEP<0015oo`D0019ooaL000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH8
0004FUH00`00FUH00007Ool50003Ool90003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]
Ool01000FUIJEUYF0P0000=JEP0000003Woo2@004Woo0`000UYF0P000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800005FUH00000FUH00003FUHI0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool01000FUH000000eYF00<005YF00000`000Woo2000
15YF00<005YFFUH00UYF1P001goo1@000eYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;Goo0`0015YF00<005YF0000
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001P000eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
000`Ool002eoo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00;Goo00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<0
00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00H000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD003Moo`00;Goo00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEPH000MJEP03001J
EUYF00YJEPX000QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUHR000lOol0
02ioo`800003FUH005YF00AJEP03001JEUYF009JEPP000QJEPL000IJEP03001JEUYF00AJEP@00005
FUH005YFFUH00006FUH00`00FUIJEP05FUH7000<FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF00<005YF
0000Dgoo000]Ool01@00FUIJEUYF000015YF1P001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
0UYF00<005YFFUH015YF00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01@001UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF10001UYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00=JEP03001JEP0005=oo`00;Goo00H005YFFUIJEP00
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF1@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF
009JEP04001JEUYF001COol002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH01000FUIJEP00
0eYF0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF100000=JEP00FUH00eYF1P001EYF00<005YFFUH00UYF00@005YFFUH005=oo`00;Goo
00@005YFFUH0009oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000004FUH01@00FUIJEP00FUH00P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001o
ogoo00=oo`@00003FUH005YF00=JEP04001JEUYF001COol002eoo`<000Ioo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP80009JEP<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP80009JEP03001oogoo00=oo`L000=JEP04001JEUYF001COol002eoo`03
001oogoo00Yoo`D000AJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF009JEPD000=o
o`@00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH90003FUH01000FUIJEUYF0P0000EJEP00FUIJ
EP0005=oo`00;Goo0P0047oo6`002Woo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00P001eYF00<005YFFUH00eYF0P000UYF00<007ooOol0DGoo000/Ool00`00FUH0000HOol5000H
Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH0
0`00FUH00002001COol002aoo`03001JEP00008001Ioo`D001Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00=JEP03001JEUYF008005=oo`00;7oo00<0
05YF00000UYF0P005Goo0`006Goo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0P001eYF00<005YFFUH00eYF00@005YFFUH005Aoo`00;Goo0P0015YF0P00;Woo00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00FUH60002FUH00`00FUIJEP03FUH01000FUIJ
EP00E7oo000]Ool20004FUH01000FUH00000:goo00<005YFFUH00P000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P001UYF00<005YF00000`0015YF0`00EGoo000^Ool00`00FUIJEP02FUH01000FUIJ
EUYF0P009goo0`000UYF00<007oo00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00<0
05YFFUH00eYF0P0000=JEP000000Egoo000_Ool20002FUH00`00FUIJEP03FUH3000ROol20002FUH0
1000FUIJEP000Woo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH015YF0P00FGoo000aOol3
0006FUH00`00FUH00003000IOol50004FUH00`00FUH00005Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000060006FUH0
0`00FUIJEP04FUH01000FUH00000Egoo000cOol00`00FUIJEP04FUH00`00FUIJEP03FUHI0003FUH0
0`00FUIJEP03FUH20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`1DOol003Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00=JEPD000aoo`@000AJEP03001JEUYF009JEP8005Eoo`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8001Aoo`H0
009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<00003Ool00000
00<000moo`<00003FUH005YF00=JEP03001JEP0005Aoo`00>7oo10001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000001aoo`T000IJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000Eoo`D0019oo`<000=JEP03001JEP0005Aoo`00?7oo10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD002MooaT000aoo`D001Eoo`800004FUH005YF001DOol0041ooaP0
03Qoo`05001JEUYFFUH00006FUH00`00FUH000030009Ool3000HOol3001EOol0095oo`800003FUH0
05YF00EJEP03001JEUYF00=JEPL001Uoo`@00003FUH0000005Eoo`00Tgoo0`001EYF00<005YFFUH0
1EYF00<005YFFUH00UYF6@000UYF00<005YFFUH00P00EGoo002FOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EWoo002J
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00EWoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001GOol00:5oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
001IOol00:QooaT005aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62063 .74982 m .61791 .69456 L .586 .6957 L p .707 .577 .707 r
F P
0 g
s
.61791 .69456 m .62063 .74982 L .65131 .74591 L p .707 .577 .707 r
F P
0 g
s
.65131 .74591 m .6486 .69066 L .61791 .69456 L p .707 .577 .707 r
F P
0 g
s
.58872 .75096 m .586 .6957 L .55598 .69396 L p .707 .577 .707 r
F P
0 g
s
.586 .6957 m .58872 .75096 L .62063 .74982 L p .707 .577 .707 r
F P
0 g
s
.6486 .69066 m .65131 .74591 L .67776 .73962 L p .707 .577 .707 r
F P
0 g
s
.67776 .73962 m .67504 .68437 L .6486 .69066 L p .707 .577 .707 r
F P
0 g
s
.5587 .74922 m .55598 .69396 L .53079 .68951 L p .707 .577 .707 r
F P
0 g
s
.55598 .69396 m .5587 .74922 L .58872 .75096 L p .707 .577 .707 r
F P
0 g
s
.60666 .80807 m .60839 .77092 L .57688 .76822 L p .707 .577 .707 r
F P
0 g
s
.60839 .77092 m .60666 .80807 L .63823 .80821 L p .707 .577 .707 r
F P
0 g
s
.63823 .80821 m .63996 .77106 L .60839 .77092 L p .707 .577 .707 r
F P
0 g
s
.67504 .68437 m .67776 .73962 L .69738 .73156 L p .707 .577 .707 r
F P
0 g
s
.69738 .73156 m .69466 .6763 L .67504 .68437 L p .707 .577 .707 r
F P
0 g
s
.57515 .80537 m .57688 .76822 L .54852 .76323 L p .707 .577 .707 r
F P
0 g
s
.57688 .76822 m .57515 .80537 L .60666 .80807 L p .707 .577 .707 r
F P
0 g
s
.63996 .77106 m .63823 .80821 L .66678 .80578 L p .707 .577 .707 r
F P
0 g
s
.66678 .80578 m .6685 .76863 L .63996 .77106 L p .707 .577 .707 r
F P
0 g
s
.53079 .68951 m .5335 .74477 L .5587 .74922 L p .707 .577 .707 r
F P
0 g
s
.5335 .74477 m .53079 .68951 L .51289 .68279 L p .707 .577 .707 r
F P
0 g
s
.59325 .84691 m .59606 .82841 L .56533 .82223 L p .707 .577 .707 r
F P
0 g
s
.59606 .82841 m .59325 .84691 L .62478 .85088 L p .707 .577 .707 r
F P
0 g
s
.62478 .85088 m .62759 .83238 L .59606 .82841 L p .707 .577 .707 r
F P
0 g
s
.54852 .76323 m .54679 .80038 L .57515 .80537 L p .707 .577 .707 r
F P
0 g
s
.62759 .83238 m .62478 .85088 L .65404 .85225 L p .707 .577 .707 r
F P
0 g
s
.65404 .85225 m .65685 .83375 L .62759 .83238 L p .707 .577 .707 r
F P
0 g
s
.54679 .80038 m .54852 .76323 L .52608 .75643 L p .707 .577 .707 r
F P
0 g
s
.56533 .82223 m .56252 .84073 L .59325 .84691 L p .707 .577 .707 r
F P
0 g
s
.6685 .76863 m .66678 .80578 L .6895 .80102 L p .707 .577 .707 r
F P
0 g
s
.6895 .80102 m .69123 .76387 L .6685 .76863 L p .707 .577 .707 r
F P
0 g
s
.56252 .84073 m .56533 .82223 L .53842 .81445 L p .707 .577 .707 r
F P
0 g
s
.53842 .81445 m .53561 .83295 L .56252 .84073 L p .707 .577 .707 r
F P
0 g
s
.51289 .68279 m .51561 .73804 L .5335 .74477 L p .707 .577 .707 r
F P
0 g
s
.69466 .6763 m .69738 .73156 L .70826 .72251 L p .707 .577 .707 r
F P
0 g
s
.70826 .72251 m .70554 .66726 L .69466 .6763 L p .707 .577 .707 r
F P
0 g
s
.52608 .75643 m .52435 .79358 L .54679 .80038 L p .707 .577 .707 r
F P
0 g
s
.65685 .83375 m .65404 .85225 L .67815 .85088 L p .707 .577 .707 r
F P
0 g
s
.67815 .85088 m .68096 .83238 L .65685 .83375 L p .707 .577 .707 r
F P
0 g
s
.51561 .73804 m .51289 .68279 L .50404 .67445 L p .707 .577 .707 r
F P
0 g
s
.53561 .83295 m .53842 .81445 L .51797 .80582 L p .707 .577 .707 r
F P
0 g
s
.52435 .79358 m .52608 .75643 L .51175 .7485 L p .707 .577 .707 r
F P
0 g
s
.51797 .80582 m .51516 .82432 L .53561 .83295 L p .707 .577 .707 r
F P
0 g
s
.69123 .76387 m .6895 .80102 L .70417 .79439 L p .707 .577 .707 r
F P
0 g
s
.70417 .79439 m .7059 .75724 L .69123 .76387 L p .707 .577 .707 r
F P
0 g
s
.51175 .7485 m .51003 .78564 L .52435 .79358 L p .707 .577 .707 r
F P
0 g
s
.68096 .83238 m .67815 .85088 L .69477 .84692 L p .707 .577 .707 r
F P
0 g
s
.69477 .84692 m .69758 .82842 L .68096 .83238 L p .707 .577 .707 r
F P
0 g
s
.50404 .67445 m .50676 .7297 L .51561 .73804 L p .707 .577 .707 r
F P
0 g
s
.70554 .66726 m .70826 .72251 L .70932 .71338 L p .707 .577 .707 r
F P
0 g
s
.70932 .71338 m .7066 .65812 L .70554 .66726 L p .707 .577 .707 r
F P
0 g
s
.51516 .82432 m .51797 .80582 L .50596 .79719 L p .707 .577 .707 r
F P
0 g
s
.50596 .79719 m .50315 .81569 L .51516 .82432 L p .707 .577 .707 r
F P
0 g
s
.50676 .7297 m .50404 .67445 L .50511 .66531 L p .707 .577 .707 r
F P
0 g
s
.51003 .78564 m .51175 .7485 L .50696 .7402 L p .707 .577 .707 r
F P
0 g
s
.7059 .75724 m .70417 .79439 L .70936 .78654 L p .707 .577 .707 r
F P
0 g
s
.70936 .78654 m .71109 .7494 L .7059 .75724 L p .707 .577 .707 r
F P
0 g
s
.50696 .7402 m .50523 .77735 L .51003 .78564 L p .707 .577 .707 r
F P
0 g
s
.48366 .82167 m .48366 .31979 L .44017 .31655 L p .707 .577 .707 r
F P
0 g
s
.50511 .66531 m .50783 .72057 L .50676 .7297 L p .707 .577 .707 r
F P
0 g
s
.50315 .81569 m .50596 .79719 L .50359 .7894 L p .707 .577 .707 r
F P
0 g
s
.50359 .7894 m .50078 .8079 L .50315 .81569 L p .707 .577 .707 r
F P
0 g
s
.50783 .72057 m .50511 .66531 L .51599 .65627 L p .707 .577 .707 r
F P
0 g
s
.50523 .77735 m .50696 .7402 L .51215 .73235 L p .707 .577 .707 r
F P
0 g
s
.51215 .73235 m .51042 .7695 L .50523 .77735 L p .707 .577 .707 r
F P
0 g
s
.51599 .65627 m .5187 .71153 L .50783 .72057 L p .707 .577 .707 r
F P
0 g
s
.50078 .8079 m .50359 .7894 L .51107 .78322 L p .707 .577 .707 r
F P
0 g
s
.51107 .78322 m .50826 .80172 L .50078 .8079 L p .707 .577 .707 r
F P
0 g
s
.5187 .71153 m .51599 .65627 L .53561 .64821 L p .707 .577 .707 r
F P
0 g
s
.51042 .7695 m .51215 .73235 L .52682 .72572 L p .707 .577 .707 r
F P
0 g
s
.52682 .72572 m .52509 .76287 L .51042 .7695 L p .707 .577 .707 r
F P
0 g
s
.53561 .64821 m .53832 .70346 L .5187 .71153 L p .707 .577 .707 r
F P
0 g
s
.50826 .80172 m .51107 .78322 L .52769 .77926 L p .707 .577 .707 r
F P
0 g
s
.52769 .77926 m .52488 .79776 L .50826 .80172 L p .707 .577 .707 r
F P
0 g
s
.52488 .79776 m .52769 .77926 L .55181 .77789 L p .707 .577 .707 r
F P
0 g
s
.55181 .77789 m .549 .79639 L .52488 .79776 L p .707 .577 .707 r
F P
0 g
s
.48366 .31979 m .48366 .82167 L .52875 .82115 L p .707 .577 .707 r
F P
0 g
s
.52509 .76287 m .52682 .72572 L .54954 .72096 L p .707 .577 .707 r
F P
0 g
s
.54954 .72096 m .54781 .75811 L .52509 .76287 L p .707 .577 .707 r
F P
0 g
s
.52875 .82115 m .52875 .31926 L .48366 .31979 L p .707 .577 .707 r
F P
0 g
s
.69758 .82842 m .69477 .84692 L .70225 .84074 L p .707 .577 .707 r
F P
0 g
s
.70225 .84074 m .70506 .82224 L .69758 .82842 L p .707 .577 .707 r
F P
0 g
s
.53832 .70346 m .53561 .64821 L .56205 .64192 L p .707 .577 .707 r
F P
0 g
s
.56205 .64192 m .56477 .69717 L .53832 .70346 L p .707 .577 .707 r
F P
0 g
s
.54781 .75811 m .54954 .72096 L .57809 .71853 L p .707 .577 .707 r
F P
0 g
s
.57809 .71853 m .57636 .75568 L .54781 .75811 L p .707 .577 .707 r
F P
0 g
s
.549 .79639 m .55181 .77789 L .58106 .77926 L p .707 .577 .707 r
F P
0 g
s
.58106 .77926 m .57825 .79776 L .549 .79639 L p .707 .577 .707 r
F P
0 g
s
.52875 .31926 m .52875 .82115 L .57102 .81691 L p .707 .577 .707 r
F P
0 g
s
.56477 .69717 m .56205 .64192 L .59273 .63801 L p .707 .577 .707 r
F P
0 g
s
.59273 .63801 m .59545 .69326 L .56477 .69717 L p .707 .577 .707 r
F P
0 g
s
.57102 .81691 m .57102 .31502 L .52875 .31926 L p .707 .577 .707 r
F P
0 g
s
.7066 .65812 m .70932 .71338 L .70047 .70504 L p .707 .577 .707 r
F P
0 g
s
.70047 .70504 m .69776 .64979 L .7066 .65812 L p .707 .577 .707 r
F P
0 g
s
.44017 .81844 m .44017 .31655 L .40254 .30986 L p .707 .577 .707 r
F P
0 g
s
.44017 .31655 m .44017 .81844 L .48366 .82167 L p .707 .577 .707 r
F P
0 g
s
.62465 .63687 m .62737 .69213 L .59545 .69326 L p .707 .577 .707 r
F P
0 g
s
.59545 .69326 m .59273 .63801 L .62465 .63687 L p .707 .577 .707 r
F P
0 g
s
.57636 .75568 m .57809 .71853 L .60966 .71867 L p .707 .577 .707 r
F P
0 g
s
.60966 .71867 m .60793 .75582 L .57636 .75568 L p .707 .577 .707 r
F P
0 g
s
.57825 .79776 m .58106 .77926 L .6126 .78323 L p .707 .577 .707 r
F P
0 g
s
.6126 .78323 m .60979 .80173 L .57825 .79776 L p .707 .577 .707 r
F P
0 g
s
.57102 .31502 m .57102 .81691 L .60634 .80937 L p .707 .577 .707 r
F P
0 g
s
.60634 .80937 m .60634 .30748 L .57102 .31502 L p .707 .577 .707 r
F P
0 g
s
.71109 .7494 m .70936 .78654 L .70457 .77824 L p .707 .577 .707 r
F P
0 g
s
.70457 .77824 m .70629 .7411 L .71109 .7494 L p .707 .577 .707 r
F P
0 g
s
.27472 .70843 m .27362 .65211 L .24167 .65248 L p .707 .577 .707 r
F P
0 g
s
.27362 .65211 m .27472 .70843 L .30542 .70594 L p .707 .577 .707 r
F P
0 g
s
.30542 .70594 m .30432 .64962 L .27362 .65211 L p .707 .577 .707 r
F P
0 g
s
.24277 .7088 m .24167 .65248 L .21162 .65068 L p .707 .577 .707 r
F P
0 g
s
.24167 .65248 m .24277 .7088 L .27472 .70843 L p .707 .577 .707 r
F P
0 g
s
.70506 .82224 m .70225 .84074 L .69988 .83296 L p .707 .577 .707 r
F P
0 g
s
.69988 .83296 m .70269 .81445 L .70506 .82224 L p .707 .577 .707 r
F P
0 g
s
.40254 .81175 m .40254 .30986 L .37445 .30039 L p .707 .577 .707 r
F P
0 g
s
.40254 .30986 m .40254 .81175 L .44017 .81844 L p .707 .577 .707 r
F P
0 g
s
.30432 .64962 m .30542 .70594 L .33188 .70156 L p .707 .577 .707 r
F P
0 g
s
.33188 .70156 m .33078 .64524 L .30432 .64962 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69776 .64979 m .70047 .70504 L .68258 .69832 L p .707 .577 .707 r
F P
0 g
s
.68258 .69832 m .67986 .64306 L .69776 .64979 L p .707 .577 .707 r
F P
0 g
s
.21272 .707 m .21162 .65068 L .18639 .6469 L p .707 .577 .707 r
F P
0 g
s
.21162 .65068 m .21272 .707 L .24277 .7088 L p .707 .577 .707 r
F P
0 g
s
.64117 .72137 m .63944 .75852 L .60793 .75582 L p .707 .577 .707 r
F P
0 g
s
.60793 .75582 m .60966 .71867 L .64117 .72137 L p .707 .577 .707 r
F P
0 g
s
.64332 .78941 m .64051 .80791 L .60979 .80173 L p .707 .577 .707 r
F P
0 g
s
.60979 .80173 m .6126 .78323 L .64332 .78941 L p .707 .577 .707 r
F P
0 g
s
.60634 .30748 m .60634 .80937 L .63125 .79927 L p .707 .577 .707 r
F P
0 g
s
.65467 .63861 m .65739 .69387 L .62737 .69213 L p .707 .577 .707 r
F P
0 g
s
.62737 .69213 m .62465 .63687 L .65467 .63861 L p .707 .577 .707 r
F P
0 g
s
.63125 .79927 m .63125 .29738 L .60634 .30748 L p .707 .577 .707 r
F P
0 g
s
.26126 .77984 m .2619 .74345 L .23036 .74128 L p .707 .577 .707 r
F P
0 g
s
.2619 .74345 m .26126 .77984 L .29285 .77877 L p .707 .577 .707 r
F P
0 g
s
.29285 .77877 m .29349 .74238 L .2619 .74345 L p .707 .577 .707 r
F P
0 g
s
.18639 .6469 m .18749 .70322 L .21272 .707 L p .707 .577 .707 r
F P
0 g
s
.70629 .7411 m .70457 .77824 L .69024 .77031 L p .707 .577 .707 r
F P
0 g
s
.69024 .77031 m .69197 .73316 L .70629 .7411 L p .707 .577 .707 r
F P
0 g
s
.22972 .77767 m .23036 .74128 L .20196 .73608 L p .707 .577 .707 r
F P
0 g
s
.23036 .74128 m .22972 .77767 L .26126 .77984 L p .707 .577 .707 r
F P
0 g
s
.29349 .74238 m .29285 .77877 L .32141 .77457 L p .707 .577 .707 r
F P
0 g
s
.32141 .77457 m .32205 .73818 L .29349 .74238 L p .707 .577 .707 r
F P
0 g
s
.33078 .64524 m .33188 .70156 L .35151 .69573 L p .707 .577 .707 r
F P
0 g
s
.35151 .69573 m .35041 .63941 L .33078 .64524 L p .707 .577 .707 r
F P
0 g
s
.18749 .70322 m .18639 .6469 L .16847 .6415 L p .707 .577 .707 r
F P
0 g
s
.70269 .81445 m .69988 .83296 L .68788 .82432 L p .707 .577 .707 r
F P
0 g
s
.68788 .82432 m .69069 .80582 L .70269 .81445 L p .707 .577 .707 r
F P
0 g
s
.67986 .64306 m .68258 .69832 L .65739 .69387 L p .707 .577 .707 r
F P
0 g
s
.65739 .69387 m .65467 .63861 L .67986 .64306 L p .707 .577 .707 r
F P
0 g
s
.20196 .73608 m .20132 .77247 L .22972 .77767 L p .707 .577 .707 r
F P
0 g
s
.20132 .77247 m .20196 .73608 L .17948 .72837 L p .707 .577 .707 r
F P
0 g
s
.32205 .73818 m .32141 .77457 L .34414 .76765 L p .707 .577 .707 r
F P
0 g
s
.34414 .76765 m .34478 .73126 L .32205 .73818 L p .707 .577 .707 r
F P
0 g
s
.37445 .80227 m .37445 .30039 L .35865 .28904 L p .707 .577 .707 r
F P
0 g
s
.37445 .30039 m .37445 .80227 L .40254 .81175 L p .707 .577 .707 r
F P
0 g
s
.16847 .6415 m .16957 .69782 L .18749 .70322 L p .707 .577 .707 r
F P
0 g
s
.25188 .83312 m .25286 .81605 L .22179 .81129 L p .707 .577 .707 r
F P
0 g
s
.25286 .81605 m .25188 .83312 L .2837 .83335 L p .707 .577 .707 r
F P
0 g
s
.2837 .83335 m .28468 .81627 L .25286 .81605 L p .707 .577 .707 r
F P
0 g
s
.28468 .81627 m .2837 .83335 L .31314 .82902 L p .707 .577 .707 r
F P
0 g
s
.31314 .82902 m .31412 .81194 L .28468 .81627 L p .707 .577 .707 r
F P
0 g
s
.35041 .63941 m .35151 .69573 L .36238 .68902 L p .707 .577 .707 r
F P
0 g
s
.36238 .68902 m .36128 .6327 L .35041 .63941 L p .707 .577 .707 r
F P
0 g
s
.17948 .72837 m .17884 .76476 L .20132 .77247 L p .707 .577 .707 r
F P
0 g
s
.69197 .73316 m .69024 .77031 L .6678 .76351 L p .707 .577 .707 r
F P
0 g
s
.6678 .76351 m .66953 .72637 L .69197 .73316 L p .707 .577 .707 r
F P
0 g
s
.22081 .82836 m .22179 .81129 L .19449 .80246 L p .707 .577 .707 r
F P
0 g
s
.22179 .81129 m .22081 .82836 L .25188 .83312 L p .707 .577 .707 r
F P
0 g
s
.66953 .72637 m .6678 .76351 L .63944 .75852 L p .707 .577 .707 r
F P
0 g
s
.63944 .75852 m .64117 .72137 L .66953 .72637 L p .707 .577 .707 r
F P
0 g
s
.63125 .29738 m .63125 .79927 L .64332 .7876 L p .707 .577 .707 r
F P
0 g
s
.64332 .7876 m .64332 .28571 L .63125 .29738 L p .707 .577 .707 r
F P
0 g
s
.16957 .69782 m .16847 .6415 L .15959 .63502 L p .707 .577 .707 r
F P
0 g
s
.17884 .76476 m .17948 .72837 L .16513 .7189 L p .707 .577 .707 r
F P
0 g
s
.34478 .73126 m .34414 .76765 L .35881 .75868 L p .707 .577 .707 r
F P
0 g
s
.35881 .75868 m .35945 .7223 L .34478 .73126 L p .707 .577 .707 r
F P
0 g
s
.19449 .80246 m .19351 .81953 L .22081 .82836 L p .707 .577 .707 r
F P
0 g
s
.31412 .81194 m .31314 .82902 L .33731 .82055 L p .707 .577 .707 r
F P
0 g
s
.33731 .82055 m .33829 .80348 L .31412 .81194 L p .707 .577 .707 r
F P
0 g
s
.69069 .80582 m .68788 .82432 L .66742 .81569 L p .707 .577 .707 r
F P
0 g
s
.66742 .81569 m .67023 .79719 L .69069 .80582 L p .707 .577 .707 r
F P
0 g
s
.19351 .81953 m .19449 .80246 L .17364 .79043 L p .707 .577 .707 r
F P
0 g
s
.15959 .63502 m .16069 .69134 L .16957 .69782 L p .707 .577 .707 r
F P
0 g
s
.16513 .7189 m .16449 .75528 L .17884 .76476 L p .707 .577 .707 r
F P
0 g
s
.17364 .79043 m .17266 .8075 L .19351 .81953 L p .707 .577 .707 r
F P
0 g
s
.36128 .6327 m .36238 .68902 L .36343 .68208 L p .707 .577 .707 r
F P
0 g
s
.36343 .68208 m .36233 .62576 L .36128 .6327 L p .707 .577 .707 r
F P
0 g
s
.33829 .80348 m .33731 .82055 L .35387 .80879 L p .707 .577 .707 r
F P
0 g
s
.35387 .80879 m .35485 .79171 L .33829 .80348 L p .707 .577 .707 r
F P
0 g
s
.36117 .79487 m .36215 .77779 L .35485 .79171 L p .707 .577 .707 r
F P
0 g
s
.36233 .62576 m .36343 .68208 L .35456 .67559 L p .707 .577 .707 r
F P
0 g
s
.35456 .67559 m .35346 .61928 L .36233 .62576 L p .707 .577 .707 r
F P
0 g
s
.36215 .77779 m .36117 .79487 L .35852 .78016 L p .707 .577 .707 r
F P
0 g
s
.35852 .78016 m .3595 .76308 L .36215 .77779 L p .707 .577 .707 r
F P
0 g
s
.3598 .70186 m .35916 .73825 L .34481 .72877 L p .707 .577 .707 r
F P
0 g
s
.34481 .72877 m .34545 .69238 L .3598 .70186 L p .707 .577 .707 r
F P
0 g
s
.3595 .76308 m .35852 .78016 L .34616 .7661 L p .707 .577 .707 r
F P
0 g
s
.34616 .7661 m .34714 .74903 L .3595 .76308 L p .707 .577 .707 r
F P
0 g
s
.35865 .79093 m .35865 .28904 L .35668 .27694 L p .707 .577 .707 r
F P
0 g
s
.35945 .7223 m .35881 .75868 L .36399 .74855 L p .707 .577 .707 r
F P
0 g
s
.36399 .74855 m .36462 .71216 L .35945 .7223 L p .707 .577 .707 r
F P
0 g
s
.36462 .71216 m .36399 .74855 L .35916 .73825 L p .707 .577 .707 r
F P
0 g
s
.35916 .73825 m .3598 .70186 L .36462 .71216 L p .707 .577 .707 r
F P
0 g
s
.35865 .28904 m .35865 .79093 L .37445 .80227 L p .707 .577 .707 r
F P
0 g
s
.67023 .79719 m .66742 .81569 L .64051 .80791 L p .707 .577 .707 r
F P
0 g
s
.64051 .80791 m .64332 .78941 L .67023 .79719 L p .707 .577 .707 r
F P
0 g
s
.16069 .69134 m .15959 .63502 L .16065 .62808 L p .707 .577 .707 r
F P
0 g
s
.16449 .75528 m .16513 .7189 L .16031 .70859 L p .707 .577 .707 r
F P
0 g
s
.17266 .8075 m .17364 .79043 L .16128 .77637 L p .707 .577 .707 r
F P
0 g
s
.64332 .28571 m .64332 .7876 L .64135 .7755 L p .707 .577 .707 r
F P
0 g
s
.64135 .7755 m .64135 .27362 L .64332 .28571 L p .707 .577 .707 r
F P
0 g
s
.16128 .77637 m .1603 .79344 L .17266 .8075 L p .707 .577 .707 r
F P
0 g
s
.16065 .62808 m .16175 .6844 L .16069 .69134 L p .707 .577 .707 r
F P
0 g
s
.16031 .70859 m .15967 .74498 L .16449 .75528 L p .707 .577 .707 r
F P
0 g
s
.35485 .79171 m .35387 .80879 L .36117 .79487 L p .707 .577 .707 r
F P
0 g
s
.1603 .79344 m .16128 .77637 L .15863 .76166 L p .707 .577 .707 r
F P
0 g
s
.15967 .74498 m .16031 .70859 L .16548 .69846 L p .707 .577 .707 r
F P
0 g
s
.16175 .6844 m .16065 .62808 L .17152 .62136 L p .707 .577 .707 r
F P
0 g
s
.15863 .76166 m .15765 .77874 L .1603 .79344 L p .707 .577 .707 r
F P
0 g
s
.35668 .27694 m .35668 .77883 L .35865 .79093 L p .707 .577 .707 r
F P
0 g
s
.35668 .77883 m .35668 .27694 L .36875 .26528 L p .707 .577 .707 r
F P
0 g
s
.16548 .69846 m .16484 .73485 L .15967 .74498 L p .707 .577 .707 r
F P
0 g
s
.17152 .62136 m .17262 .67768 L .16175 .6844 L p .707 .577 .707 r
F P
0 g
s
.64135 .27362 m .64135 .7755 L .62555 .76416 L p .707 .577 .707 r
F P
0 g
s
.62555 .76416 m .62555 .26227 L .64135 .27362 L p .707 .577 .707 r
F P
0 g
s
.35346 .61928 m .35456 .67559 L .33663 .6702 L p .707 .577 .707 r
F P
0 g
s
.33663 .6702 m .33553 .61388 L .35346 .61928 L p .707 .577 .707 r
F P
0 g
s
.15765 .77874 m .15863 .76166 L .16593 .74774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16484 .73485 m .16548 .69846 L .18015 .68949 L p .707 .577 .707 r
F P
0 g
s
.17262 .67768 m .17152 .62136 L .19114 .61554 L p .707 .577 .707 r
F P
0 g
s
.16593 .74774 m .16495 .76482 L .15765 .77874 L p .707 .577 .707 r
F P
0 g
s
.18015 .68949 m .17951 .72588 L .16484 .73485 L p .707 .577 .707 r
F P
0 g
s
.19114 .61554 m .19224 .67185 L .17262 .67768 L p .707 .577 .707 r
F P
0 g
s
.33553 .61388 m .33663 .6702 L .31141 .66641 L p .707 .577 .707 r
F P
0 g
s
.31141 .66641 m .31031 .6101 L .33553 .61388 L p .707 .577 .707 r
F P
0 g
s
.36875 .76716 m .36875 .26528 L .39366 .25518 L p .707 .577 .707 r
F P
0 g
s
.36875 .26528 m .36875 .76716 L .35668 .77883 L p .707 .577 .707 r
F P
0 g
s
.16495 .76482 m .16593 .74774 L .18249 .73597 L p .707 .577 .707 r
F P
0 g
s
.19224 .67185 m .19114 .61554 L .2176 .61116 L p .707 .577 .707 r
F P
0 g
s
.17951 .72588 m .18015 .68949 L .20288 .68257 L p .707 .577 .707 r
F P
0 g
s
.34545 .69238 m .34481 .72877 L .32233 .72106 L p .707 .577 .707 r
F P
0 g
s
.32233 .72106 m .32297 .68467 L .34545 .69238 L p .707 .577 .707 r
F P
0 g
s
.18249 .73597 m .18151 .75305 L .16495 .76482 L p .707 .577 .707 r
F P
0 g
s
.62555 .26227 m .62555 .76416 L .59746 .75468 L p .707 .577 .707 r
F P
0 g
s
.59746 .75468 m .59746 .25279 L .62555 .26227 L p .707 .577 .707 r
F P
0 g
s
.2176 .61116 m .2187 .66748 L .19224 .67185 L p .707 .577 .707 r
F P
0 g
s
.31031 .6101 m .31141 .66641 L .28135 .66462 L p .707 .577 .707 r
F P
0 g
s
.28135 .66462 m .28025 .6083 L .31031 .6101 L p .707 .577 .707 r
F P
0 g
s
.20288 .68257 m .20224 .71896 L .17951 .72588 L p .707 .577 .707 r
F P
0 g
s
.34714 .74903 m .34616 .7661 L .32531 .75407 L p .707 .577 .707 r
F P
0 g
s
.32531 .75407 m .32629 .73699 L .34714 .74903 L p .707 .577 .707 r
F P
0 g
s
.2187 .66748 m .2176 .61116 L .24831 .60867 L p .707 .577 .707 r
F P
0 g
s
.18151 .75305 m .18249 .73597 L .20667 .72751 L p .707 .577 .707 r
F P
0 g
s
.20224 .71896 m .20288 .68257 L .23144 .67837 L p .707 .577 .707 r
F P
0 g
s
.32297 .68467 m .32233 .72106 L .29394 .71586 L p .707 .577 .707 r
F P
0 g
s
.29394 .71586 m .29457 .67948 L .32297 .68467 L p .707 .577 .707 r
F P
0 g
s
.28025 .6083 m .28135 .66462 L .24941 .66498 L p .707 .577 .707 r
F P
0 g
s
.24941 .66498 m .24831 .60867 L .28025 .6083 L p .707 .577 .707 r
F P
0 g
s
.24831 .60867 m .24941 .66498 L .2187 .66748 L p .707 .577 .707 r
F P
0 g
s
.20667 .72751 m .20569 .74459 L .18151 .75305 L p .707 .577 .707 r
F P
0 g
s
.39366 .25518 m .39366 .75707 L .36875 .76716 L p .707 .577 .707 r
F P
0 g
s
.39366 .75707 m .39366 .25518 L .42898 .24764 L p .707 .577 .707 r
F P
0 g
s
.75059 .66123 m .75169 .60656 L .71974 .60565 L p .707 .577 .707 r
F P
0 g
s
.75169 .60656 m .75059 .66123 L .78129 .65895 L p .707 .577 .707 r
F P
0 g
s
.78129 .65895 m .78239 .60429 L .75169 .60656 L p .707 .577 .707 r
F P
0 g
s
.71865 .66032 m .71974 .60565 L .68969 .60164 L p .707 .577 .707 r
F P
0 g
s
.71974 .60565 m .71865 .66032 L .75059 .66123 L p .707 .577 .707 r
F P
0 g
s
.23144 .67837 m .2308 .71476 L .20224 .71896 L p .707 .577 .707 r
F P
0 g
s
.2308 .71476 m .23144 .67837 L .26303 .67731 L p .707 .577 .707 r
F P
0 g
s
.29457 .67948 m .29394 .71586 L .2624 .71369 L p .707 .577 .707 r
F P
0 g
s
.2624 .71369 m .26303 .67731 L .29457 .67948 L p .707 .577 .707 r
F P
0 g
s
.32629 .73699 m .32531 .75407 L .29802 .74524 L p .707 .577 .707 r
F P
0 g
s
.29802 .74524 m .299 .72817 L .32629 .73699 L p .707 .577 .707 r
F P
0 g
s
.59746 .25279 m .59746 .75468 L .55983 .748 L p .707 .577 .707 r
F P
0 g
s
.55983 .748 m .55983 .24611 L .59746 .25279 L p .707 .577 .707 r
F P
0 g
s
.26303 .67731 m .2624 .71369 L .2308 .71476 L p .707 .577 .707 r
F P
0 g
s
.20569 .74459 m .20667 .72751 L .2361 .72318 L p .707 .577 .707 r
F P
0 g
s
.78239 .60429 m .78129 .65895 L .80776 .65371 L p .707 .577 .707 r
F P
0 g
s
.80776 .65371 m .80886 .59904 L .78239 .60429 L p .707 .577 .707 r
F P
0 g
s
.68859 .6563 m .68969 .60164 L .66446 .59491 L p .707 .577 .707 r
F P
0 g
s
.68969 .60164 m .68859 .6563 L .71865 .66032 L p .707 .577 .707 r
F P
0 g
s
.2361 .72318 m .23512 .74026 L .20569 .74459 L p .707 .577 .707 r
F P
0 g
s
.299 .72817 m .29802 .74524 L .26694 .74048 L p .707 .577 .707 r
F P
0 g
s
.26694 .74048 m .26792 .72341 L .299 .72817 L p .707 .577 .707 r
F P
0 g
s
.23512 .74026 m .2361 .72318 L .26792 .72341 L p .707 .577 .707 r
F P
0 g
s
.7376 .71099 m .73696 .6734 L .70542 .67281 L p .707 .577 .707 r
F P
0 g
s
.73696 .6734 m .7376 .71099 L .7692 .70945 L p .707 .577 .707 r
F P
0 g
s
.7692 .70945 m .76856 .67187 L .73696 .6734 L p .707 .577 .707 r
F P
0 g
s
.26792 .72341 m .26694 .74048 L .23512 .74026 L p .707 .577 .707 r
F P
0 g
s
.80886 .59904 m .80776 .65371 L .82738 .646 L p .707 .577 .707 r
F P
0 g
s
.82738 .646 m .82848 .59134 L .80886 .59904 L p .707 .577 .707 r
F P
0 g
s
.42898 .74953 m .42898 .24764 L .47125 .2434 L p .707 .577 .707 r
F P
0 g
s
.42898 .24764 m .42898 .74953 L .39366 .75707 L p .707 .577 .707 r
F P
0 g
s
.76856 .67187 m .7692 .70945 L .79776 .70595 L p .707 .577 .707 r
F P
0 g
s
.79776 .70595 m .79712 .66836 L .76856 .67187 L p .707 .577 .707 r
F P
0 g
s
.70606 .7104 m .70542 .67281 L .67703 .67016 L p .707 .577 .707 r
F P
0 g
s
.70542 .67281 m .70606 .7104 L .7376 .71099 L p .707 .577 .707 r
F P
0 g
s
.66446 .59491 m .66336 .64958 L .68859 .6563 L p .707 .577 .707 r
F P
0 g
s
.66336 .64958 m .66446 .59491 L .64654 .58614 L p .707 .577 .707 r
F P
0 g
s
.55983 .24611 m .55983 .748 L .51634 .74476 L p .707 .577 .707 r
F P
0 g
s
.51634 .74476 m .51634 .24287 L .55983 .24611 L p .707 .577 .707 r
F P
0 g
s
.73306 .73988 m .73208 .72072 L .701 .72181 L p .707 .577 .707 r
F P
0 g
s
.73208 .72072 m .73306 .73988 L .76488 .73808 L p .707 .577 .707 r
F P
0 g
s
.76488 .73808 m .7639 .71892 L .73208 .72072 L p .707 .577 .707 r
F P
0 g
s
.701 .72181 m .70198 .74097 L .73306 .73988 L p .707 .577 .707 r
F P
0 g
s
.67703 .67016 m .67766 .70775 L .70606 .7104 L p .707 .577 .707 r
F P
0 g
s
.7639 .71892 m .76488 .73808 L .79431 .73575 L p .707 .577 .707 r
F P
0 g
s
.79431 .73575 m .79333 .71659 L .7639 .71892 L p .707 .577 .707 r
F P
0 g
s
.70198 .74097 m .701 .72181 L .6737 .72208 L p .707 .577 .707 r
F P
0 g
s
.79712 .66836 m .79776 .70595 L .82048 .70081 L p .707 .577 .707 r
F P
0 g
s
.82048 .70081 m .81985 .66323 L .79712 .66836 L p .707 .577 .707 r
F P
0 g
s
.47125 .74529 m .47125 .2434 L .51634 .24287 L p .707 .577 .707 r
F P
0 g
s
.47125 .2434 m .47125 .74529 L .42898 .74953 L p .707 .577 .707 r
F P
0 g
s
.6737 .72208 m .67468 .74124 L .70198 .74097 L p .707 .577 .707 r
F P
0 g
s
.67766 .70775 m .67703 .67016 L .65455 .66571 L p .707 .577 .707 r
F P
0 g
s
.51634 .24287 m .51634 .74476 L .47125 .74529 L p .707 .577 .707 r
F P
0 g
s
.79333 .71659 m .79431 .73575 L .81849 .73311 L p .707 .577 .707 r
F P
0 g
s
.81849 .73311 m .81751 .71394 L .79333 .71659 L p .707 .577 .707 r
F P
0 g
s
.64654 .58614 m .64544 .64081 L .66336 .64958 L p .707 .577 .707 r
F P
0 g
s
.82848 .59134 m .82738 .646 L .83825 .6366 L p .707 .577 .707 r
F P
0 g
s
.83825 .6366 m .83935 .58193 L .82848 .59134 L p .707 .577 .707 r
F P
0 g
s
.65455 .66571 m .65519 .7033 L .67766 .70775 L p .707 .577 .707 r
F P
0 g
s
.64544 .64081 m .64654 .58614 L .63767 .57617 L p .707 .577 .707 r
F P
0 g
s
.67468 .74124 m .6737 .72208 L .65285 .7215 L p .707 .577 .707 r
F P
0 g
s
.65285 .7215 m .65383 .74066 L .67468 .74124 L p .707 .577 .707 r
F P
0 g
s
.81985 .66323 m .82048 .70081 L .83515 .69455 L p .707 .577 .707 r
F P
0 g
s
.83515 .69455 m .83452 .65697 L .81985 .66323 L p .707 .577 .707 r
F P
0 g
s
.65519 .7033 m .65455 .66571 L .6402 .65989 L p .707 .577 .707 r
F P
0 g
s
.81751 .71394 m .81849 .73311 L .83504 .73042 L p .707 .577 .707 r
F P
0 g
s
.83504 .73042 m .83406 .71125 L .81751 .71394 L p .707 .577 .707 r
F P
0 g
s
.6402 .65989 m .64084 .69747 L .65519 .7033 L p .707 .577 .707 r
F P
0 g
s
.63767 .57617 m .63657 .63084 L .64544 .64081 L p .707 .577 .707 r
F P
0 g
s
.83935 .58193 m .83825 .6366 L .8393 .62642 L p .707 .577 .707 r
F P
0 g
s
.8393 .62642 m .8404 .57175 L .83935 .58193 L p .707 .577 .707 r
F P
0 g
s
.65383 .74066 m .65285 .7215 L .6405 .72014 L p .707 .577 .707 r
F P
0 g
s
.6405 .72014 m .64148 .7393 L .65383 .74066 L p .707 .577 .707 r
F P
0 g
s
.63657 .63084 m .63767 .57617 L .63872 .56599 L p .707 .577 .707 r
F P
0 g
s
.83452 .65697 m .83515 .69455 L .84033 .68778 L p .707 .577 .707 r
F P
0 g
s
.84033 .68778 m .83969 .6502 L .83452 .65697 L p .707 .577 .707 r
F P
0 g
s
.64084 .69747 m .6402 .65989 L .63537 .65327 L p .707 .577 .707 r
F P
0 g
s
.83406 .71125 m .83504 .73042 L .84235 .72794 L p .707 .577 .707 r
F P
0 g
s
.84235 .72794 m .84137 .70878 L .83406 .71125 L p .707 .577 .707 r
F P
0 g
s
.63537 .65327 m .63601 .69085 L .64084 .69747 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63872 .56599 m .63762 .62066 L .63657 .63084 L p .707 .577 .707 r
F P
0 g
s
.8404 .57175 m .8393 .62642 L .83043 .61645 L p .707 .577 .707 r
F P
0 g
s
.83043 .61645 m .83153 .56179 L .8404 .57175 L p .707 .577 .707 r
F P
0 g
s
.64148 .7393 m .6405 .72014 L .63784 .71812 L p .707 .577 .707 r
F P
0 g
s
.63784 .71812 m .63882 .73728 L .64148 .7393 L p .707 .577 .707 r
F P
0 g
s
.63762 .62066 m .63872 .56599 L .64959 .55659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83969 .6502 m .84033 .68778 L .83551 .68116 L p .707 .577 .707 r
F P
0 g
s
.83551 .68116 m .83487 .64358 L .83969 .6502 L p .707 .577 .707 r
F P
0 g
s
.63601 .69085 m .63537 .65327 L .64055 .6465 L p .707 .577 .707 r
F P
0 g
s
.84137 .70878 m .84235 .72794 L .8397 .72592 L p .707 .577 .707 r
F P
0 g
s
.8397 .72592 m .83872 .70676 L .84137 .70878 L p .707 .577 .707 r
F P
0 g
s
.40455 .61995 m .40726 .56418 L .37535 .56245 L p .707 .577 .707 r
F P
0 g
s
.40726 .56418 m .40455 .61995 L .43523 .61912 L p .707 .577 .707 r
F P
0 g
s
.43523 .61912 m .43794 .56335 L .40726 .56418 L p .707 .577 .707 r
F P
0 g
s
.37263 .61823 m .37535 .56245 L .34533 .55834 L p .707 .577 .707 r
F P
0 g
s
.37535 .56245 m .37263 .61823 L .40455 .61995 L p .707 .577 .707 r
F P
0 g
s
.64055 .6465 m .64119 .68408 L .63601 .69085 L p .707 .577 .707 r
F P
0 g
s
.64959 .55659 m .64849 .61125 L .63762 .62066 L p .707 .577 .707 r
F P
0 g
s
.43794 .56335 m .43523 .61912 L .46167 .61581 L p .707 .577 .707 r
F P
0 g
s
.46167 .61581 m .46439 .56004 L .43794 .56335 L p .707 .577 .707 r
F P
0 g
s
.83153 .56179 m .83043 .61645 L .81251 .60768 L p .707 .577 .707 r
F P
0 g
s
.81251 .60768 m .81361 .55301 L .83153 .56179 L p .707 .577 .707 r
F P
0 g
s
.34261 .61411 m .34533 .55834 L .32014 .55224 L p .707 .577 .707 r
F P
0 g
s
.34533 .55834 m .34261 .61411 L .37263 .61823 L p .707 .577 .707 r
F P
0 g
s
.64849 .61125 m .64959 .55659 L .66921 .54889 L p .707 .577 .707 r
F P
0 g
s
.63882 .73728 m .63784 .71812 L .64515 .71564 L p .707 .577 .707 r
F P
0 g
s
.64515 .71564 m .64613 .73481 L .63882 .73728 L p .707 .577 .707 r
F P
0 g
s
.39207 .68287 m .39034 .64599 L .35883 .64589 L p .707 .577 .707 r
F P
0 g
s
.39034 .64599 m .39207 .68287 L .42364 .68016 L p .707 .577 .707 r
F P
0 g
s
.42364 .68016 m .42191 .64328 L .39034 .64599 L p .707 .577 .707 r
F P
0 g
s
.42191 .64328 m .42364 .68016 L .45218 .6749 L p .707 .577 .707 r
F P
0 g
s
.45218 .6749 m .45045 .63802 L .42191 .64328 L p .707 .577 .707 r
F P
0 g
s
.83487 .64358 m .83551 .68116 L .82115 .67534 L p .707 .577 .707 r
F P
0 g
s
.82115 .67534 m .82052 .63775 L .83487 .64358 L p .707 .577 .707 r
F P
0 g
s
.32014 .55224 m .31742 .60801 L .34261 .61411 L p .707 .577 .707 r
F P
0 g
s
.36056 .68277 m .35883 .64589 L .33047 .64299 L p .707 .577 .707 r
F P
0 g
s
.35883 .64589 m .36056 .68277 L .39207 .68287 L p .707 .577 .707 r
F P
0 g
s
.46439 .56004 m .46167 .61581 L .48129 .61035 L p .707 .577 .707 r
F P
0 g
s
.48129 .61035 m .48401 .55457 L .46439 .56004 L p .707 .577 .707 r
F P
0 g
s
.64119 .68408 m .64055 .6465 L .65522 .64024 L p .707 .577 .707 r
F P
0 g
s
.31742 .60801 m .32014 .55224 L .30224 .54475 L p .707 .577 .707 r
F P
0 g
s
.83872 .70676 m .8397 .72592 L .82734 .72456 L p .707 .577 .707 r
F P
0 g
s
.82734 .72456 m .82636 .7054 L .83872 .70676 L p .707 .577 .707 r
F P
0 g
s
.66921 .54889 m .66812 .60355 L .64849 .61125 L p .707 .577 .707 r
F P
0 g
s
.65522 .64024 m .65586 .67783 L .64119 .68408 L p .707 .577 .707 r
F P
0 g
s
.81361 .55301 m .81251 .60768 L .78728 .60095 L p .707 .577 .707 r
F P
0 g
s
.78728 .60095 m .78838 .54629 L .81361 .55301 L p .707 .577 .707 r
F P
0 g
s
.33047 .64299 m .33219 .67987 L .36056 .68277 L p .707 .577 .707 r
F P
0 g
s
.45045 .63802 m .45218 .6749 L .4749 .66762 L p .707 .577 .707 r
F P
0 g
s
.4749 .66762 m .47318 .63074 L .45045 .63802 L p .707 .577 .707 r
F P
0 g
s
.66812 .60355 m .66921 .54889 L .69568 .54364 L p .707 .577 .707 r
F P
0 g
s
.33219 .67987 m .33047 .64299 L .30802 .63757 L p .707 .577 .707 r
F P
0 g
s
.39021 .72729 m .3874 .70915 L .35667 .71119 L p .707 .577 .707 r
F P
0 g
s
.3874 .70915 m .39021 .72729 L .42174 .72212 L p .707 .577 .707 r
F P
0 g
s
.42174 .72212 m .41893 .70399 L .3874 .70915 L p .707 .577 .707 r
F P
0 g
s
.41893 .70399 m .42174 .72212 L .451 .71433 L p .707 .577 .707 r
F P
0 g
s
.451 .71433 m .44819 .69619 L .41893 .70399 L p .707 .577 .707 r
F P
0 g
s
.30224 .54475 m .29952 .60052 L .31742 .60801 L p .707 .577 .707 r
F P
0 g
s
.64613 .73481 m .64515 .71564 L .6617 .71295 L p .707 .577 .707 r
F P
0 g
s
.35667 .71119 m .35948 .72932 L .39021 .72729 L p .707 .577 .707 r
F P
0 g
s
.6617 .71295 m .66268 .73212 L .64613 .73481 L p .707 .577 .707 r
F P
0 g
s
.35948 .72932 m .35667 .71119 L .32977 .70989 L p .707 .577 .707 r
F P
0 g
s
.30802 .63757 m .30975 .67446 L .33219 .67987 L p .707 .577 .707 r
F P
0 g
s
.48401 .55457 m .48129 .61035 L .49217 .60327 L p .707 .577 .707 r
F P
0 g
s
.49217 .60327 m .49489 .54749 L .48401 .55457 L p .707 .577 .707 r
F P
0 g
s
.44819 .69619 m .451 .71433 L .47512 .70467 L p .707 .577 .707 r
F P
0 g
s
.47512 .70467 m .47231 .68654 L .44819 .69619 L p .707 .577 .707 r
F P
0 g
s
.82052 .63775 m .82115 .67534 L .79868 .67089 L p .707 .577 .707 r
F P
0 g
s
.79868 .67089 m .79804 .6333 L .82052 .63775 L p .707 .577 .707 r
F P
0 g
s
.78838 .54629 m .78728 .60095 L .75723 .59694 L p .707 .577 .707 r
F P
0 g
s
.75723 .59694 m .75832 .54227 L .78838 .54629 L p .707 .577 .707 r
F P
0 g
s
.65586 .67783 m .65522 .64024 L .67795 .63511 L p .707 .577 .707 r
F P
0 g
s
.29952 .60052 m .30224 .54475 L .29339 .5366 L p .707 .577 .707 r
F P
0 g
s
.32977 .70989 m .33258 .72802 L .35948 .72932 L p .707 .577 .707 r
F P
0 g
s
.69458 .59831 m .69568 .54364 L .72638 .54136 L p .707 .577 .707 r
F P
0 g
s
.69568 .54364 m .69458 .59831 L .66812 .60355 L p .707 .577 .707 r
F P
0 g
s
.47318 .63074 m .4749 .66762 L .48958 .65902 L p .707 .577 .707 r
F P
0 g
s
.48958 .65902 m .48785 .62213 L .47318 .63074 L p .707 .577 .707 r
F P
0 g
s
.82636 .7054 m .82734 .72456 L .80649 .72398 L p .707 .577 .707 r
F P
0 g
s
.80649 .72398 m .80551 .70482 L .82636 .7054 L p .707 .577 .707 r
F P
0 g
s
.30975 .67446 m .30802 .63757 L .2937 .63017 L p .707 .577 .707 r
F P
0 g
s
.67795 .63511 m .67858 .67269 L .65586 .67783 L p .707 .577 .707 r
F P
0 g
s
.75832 .54227 m .75723 .59694 L .72528 .59603 L p .707 .577 .707 r
F P
0 g
s
.72528 .59603 m .72638 .54136 L .75832 .54227 L p .707 .577 .707 r
F P
0 g
s
.72638 .54136 m .72528 .59603 L .69458 .59831 L p .707 .577 .707 r
F P
0 g
s
.33258 .72802 m .32977 .70989 L .30931 .70539 L p .707 .577 .707 r
F P
0 g
s
.29339 .5366 m .29067 .59237 L .29952 .60052 L p .707 .577 .707 r
F P
0 g
s
.47231 .68654 m .47512 .70467 L .49173 .6941 L p .707 .577 .707 r
F P
0 g
s
.49173 .6941 m .48892 .67597 L .47231 .68654 L p .707 .577 .707 r
F P
0 g
s
.30931 .70539 m .31212 .72352 L .33258 .72802 L p .707 .577 .707 r
F P
0 g
s
.2937 .63017 m .29543 .66706 L .30975 .67446 L p .707 .577 .707 r
F P
0 g
s
.66268 .73212 m .6617 .71295 L .68588 .71031 L p .707 .577 .707 r
F P
0 g
s
.68588 .71031 m .68686 .72947 L .66268 .73212 L p .707 .577 .707 r
F P
0 g
s
.79804 .6333 m .79868 .67089 L .77028 .66824 L p .707 .577 .707 r
F P
0 g
s
.77028 .66824 m .76964 .63065 L .79804 .6333 L p .707 .577 .707 r
F P
0 g
s
.67858 .67269 m .67795 .63511 L .70651 .6316 L p .707 .577 .707 r
F P
0 g
s
.49489 .54749 m .49217 .60327 L .49324 .59526 L p .707 .577 .707 r
F P
0 g
s
.49324 .59526 m .49595 .53949 L .49489 .54749 L p .707 .577 .707 r
F P
0 g
s
.70651 .6316 m .70714 .66919 L .67858 .67269 L p .707 .577 .707 r
F P
0 g
s
.29067 .59237 m .29339 .5366 L .29446 .52859 L p .707 .577 .707 r
F P
0 g
s
.80551 .70482 m .80649 .72398 L .77919 .72425 L p .707 .577 .707 r
F P
0 g
s
.77919 .72425 m .77821 .70509 L .80551 .70482 L p .707 .577 .707 r
F P
0 g
s
.48785 .62213 m .48958 .65902 L .49477 .64994 L p .707 .577 .707 r
F P
0 g
s
.49477 .64994 m .49304 .61306 L .48785 .62213 L p .707 .577 .707 r
F P
0 g
s
.76964 .63065 m .77028 .66824 L .73874 .66765 L p .707 .577 .707 r
F P
0 g
s
.73874 .66765 m .7381 .63007 L .76964 .63065 L p .707 .577 .707 r
F P
0 g
s
.29543 .66706 m .2937 .63017 L .2889 .62151 L p .707 .577 .707 r
F P
0 g
s
.70714 .66919 m .70651 .6316 L .7381 .63007 L p .707 .577 .707 r
F P
0 g
s
.31212 .72352 m .30931 .70539 L .29731 .69812 L p .707 .577 .707 r
F P
0 g
s
.68686 .72947 m .68588 .71031 L .71532 .70798 L p .707 .577 .707 r
F P
0 g
s
.7381 .63007 m .73874 .66765 L .70714 .66919 L p .707 .577 .707 r
F P
0 g
s
.71532 .70798 m .7163 .72714 L .68686 .72947 L p .707 .577 .707 r
F P
0 g
s
.48892 .67597 m .49173 .6941 L .49922 .68364 L p .707 .577 .707 r
F P
0 g
s
.49922 .68364 m .49641 .66551 L .48892 .67597 L p .707 .577 .707 r
F P
0 g
s
.29731 .69812 m .30012 .71625 L .31212 .72352 L p .707 .577 .707 r
F P
0 g
s
.29446 .52859 m .29174 .58437 L .29067 .59237 L p .707 .577 .707 r
F P
0 g
s
.2889 .62151 m .29063 .65839 L .29543 .66706 L p .707 .577 .707 r
F P
0 g
s
.77821 .70509 m .77919 .72425 L .74811 .72534 L p .707 .577 .707 r
F P
0 g
s
.74811 .72534 m .74713 .70618 L .77821 .70509 L p .707 .577 .707 r
F P
0 g
s
.7163 .72714 m .71532 .70798 L .74713 .70618 L p .707 .577 .707 r
F P
0 g
s
.74713 .70618 m .74811 .72534 L .7163 .72714 L p .707 .577 .707 r
F P
0 g
s
.49595 .53949 m .49324 .59526 L .48439 .58711 L p .707 .577 .707 r
F P
0 g
s
.48439 .58711 m .48711 .53134 L .49595 .53949 L p .707 .577 .707 r
F P
0 g
s
.29174 .58437 m .29446 .52859 L .30533 .52151 L p .707 .577 .707 r
F P
0 g
s
.49304 .61306 m .49477 .64994 L .48997 .64128 L p .707 .577 .707 r
F P
0 g
s
.48997 .64128 m .48824 .6044 L .49304 .61306 L p .707 .577 .707 r
F P
0 g
s
.30012 .71625 m .29731 .69812 L .29493 .6888 L p .707 .578 .707 r
F P
0 g
s
.29063 .65839 m .2889 .62151 L .2941 .61243 L p .707 .577 .707 r
F P
0 g
s
.49641 .66551 m .49922 .68364 L .49684 .67432 L p .707 .578 .707 r
F P
0 g
s
.49684 .67432 m .49403 .65619 L .49641 .66551 L p .707 .578 .707 r
F P
0 g
s
.29493 .6888 m .29774 .70694 L .30012 .71625 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30533 .52151 m .30262 .57729 L .29174 .58437 L p .707 .577 .707 r
F P
0 g
s
.2941 .61243 m .29582 .64932 L .29063 .65839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48711 .53134 m .48439 .58711 L .46649 .57962 L p .707 .577 .707 r
F P
0 g
s
.46649 .57962 m .46921 .52385 L .48711 .53134 L p .707 .577 .707 r
F P
0 g
s
.30262 .57729 m .30533 .52151 L .32496 .51605 L p .707 .577 .707 r
F P
0 g
s
.48824 .6044 m .48997 .64128 L .47565 .63388 L p .707 .577 .707 r
F P
0 g
s
.47565 .63388 m .47392 .59699 L .48824 .6044 L p .707 .577 .707 r
F P
0 g
s
.29774 .70694 m .29493 .6888 L .30242 .67835 L p .707 .577 .707 r
F P
0 g
s
.29582 .64932 m .2941 .61243 L .30877 .60383 L p .707 .577 .707 r
F P
0 g
s
.49403 .65619 m .49684 .67432 L .48484 .66706 L p .707 .577 .707 r
F P
0 g
s
.48484 .66706 m .48203 .64893 L .49403 .65619 L p .707 .577 .707 r
F P
0 g
s
.30242 .67835 m .30523 .69648 L .29774 .70694 L p .707 .577 .707 r
F P
0 g
s
.32496 .51605 m .32224 .57182 L .30262 .57729 L p .707 .577 .707 r
F P
0 g
s
.30877 .60383 m .3105 .64072 L .29582 .64932 L p .707 .577 .707 r
F P
0 g
s
.46921 .52385 m .46649 .57962 L .4413 .57352 L p .707 .577 .707 r
F P
0 g
s
.4413 .57352 m .44402 .51775 L .46921 .52385 L p .707 .577 .707 r
F P
0 g
s
.32224 .57182 m .32496 .51605 L .3514 .51274 L p .707 .577 .707 r
F P
0 g
s
.47392 .59699 m .47565 .63388 L .45321 .62846 L p .707 .577 .707 r
F P
0 g
s
.45321 .62846 m .45148 .59158 L .47392 .59699 L p .707 .577 .707 r
F P
0 g
s
.3105 .64072 m .30877 .60383 L .33149 .59655 L p .707 .577 .707 r
F P
0 g
s
.30523 .69648 m .30242 .67835 L .31903 .66777 L p .707 .577 .707 r
F P
0 g
s
.3514 .51274 m .34868 .56851 L .32224 .57182 L p .707 .577 .707 r
F P
0 g
s
.48203 .64893 m .48484 .66706 L .46438 .66256 L p .707 .577 .707 r
F P
0 g
s
.46438 .66256 m .46157 .64442 L .48203 .64893 L p .707 .577 .707 r
F P
0 g
s
.31903 .66777 m .32184 .68591 L .30523 .69648 L p .707 .577 .707 r
F P
0 g
s
.44402 .51775 m .4413 .57352 L .41128 .56941 L p .707 .577 .707 r
F P
0 g
s
.41128 .56941 m .414 .51363 L .44402 .51775 L p .707 .577 .707 r
F P
0 g
s
.34868 .56851 m .3514 .51274 L .38208 .51191 L p .707 .577 .707 r
F P
0 g
s
.33149 .59655 m .33322 .63343 L .3105 .64072 L p .707 .577 .707 r
F P
0 g
s
.414 .51363 m .41128 .56941 L .37936 .56768 L p .707 .577 .707 r
F P
0 g
s
.37936 .56768 m .38208 .51191 L .414 .51363 L p .707 .577 .707 r
F P
0 g
s
.38208 .51191 m .37936 .56768 L .34868 .56851 L p .707 .577 .707 r
F P
0 g
s
.45148 .59158 m .45321 .62846 L .42484 .62556 L p .707 .577 .707 r
F P
0 g
s
.42484 .62556 m .42312 .58868 L .45148 .59158 L p .707 .577 .707 r
F P
0 g
s
.33322 .63343 m .33149 .59655 L .36004 .59129 L p .707 .577 .707 r
F P
0 g
s
.32184 .68591 m .31903 .66777 L .34315 .65812 L p .707 .577 .707 r
F P
0 g
s
.46157 .64442 m .46438 .66256 L .43748 .66126 L p .707 .577 .707 r
F P
0 g
s
.43748 .66126 m .43467 .64313 L .46157 .64442 L p .707 .577 .707 r
F P
0 g
s
.36004 .59129 m .36176 .62818 L .33322 .63343 L p .707 .577 .707 r
F P
0 g
s
.34315 .65812 m .34596 .67625 L .32184 .68591 L p .707 .577 .707 r
F P
0 g
s
.42312 .58868 m .42484 .62556 L .39333 .62546 L p .707 .577 .707 r
F P
0 g
s
.39333 .62546 m .39161 .58858 L .42312 .58868 L p .707 .577 .707 r
F P
0 g
s
.36176 .62818 m .36004 .59129 L .39161 .58858 L p .707 .577 .707 r
F P
0 g
s
.39161 .58858 m .39333 .62546 L .36176 .62818 L p .707 .577 .707 r
F P
0 g
s
.34596 .67625 m .34315 .65812 L .37241 .65032 L p .707 .577 .707 r
F P
0 g
s
.43467 .64313 m .43748 .66126 L .40675 .66329 L p .707 .577 .707 r
F P
0 g
s
.40675 .66329 m .40394 .64516 L .43467 .64313 L p .707 .577 .707 r
F P
0 g
s
.37241 .65032 m .37522 .66846 L .34596 .67625 L p .707 .577 .707 r
F P
0 g
s
.37522 .66846 m .37241 .65032 L .40394 .64516 L p .707 .577 .707 r
F P
0 g
s
.40394 .64516 m .40675 .66329 L .37522 .66846 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001POolA0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001FOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol005=oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
4Goo2@00BWoo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02goo1P0015YF00<0
05YFFUH00UYF2@00@Goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01goo1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo001COol01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00=goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomo
o`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<003Aoo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001oo`000004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH00000<Woo001BOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000`Ool0059oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP8002moo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;goo001BOol01@00
FUIJEUYF00000eYF1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Woo001BOol01P00FUIJEUYF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEPH000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000;Woo001BOol01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000^Ool0059oo`04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH0009JEP03001J
EUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000;Woo001BOol01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00004@001UYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH01000FUIJEUYF200015YF00<0
05YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0002ioo`00Dgoo0`0015YF00<005YFFUH0
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0100000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH0000^Ool005Eoo`80009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH80006Ool50006Ool60005FUH00`00FUIJEP03FUH00`00FUH0000^Ool005Moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
0080009JEP04001JEUYFFUH<0008Ool50005Ool;00000eYF001JEP04FUH00`00FUH0000^Ool005Io
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUH000020007FUH01000FUIJEUYF4P0015YF00<005YFFUH015YF0P00
1EYF00<005YF0000;Woo000lOolJ00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P000UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YF0000
00=JEP03001JEP0002ioo`00>7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800004FUH005YF000^
Ool003Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH0100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP00Ool0;Goo000`Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00800003
FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool002ioo`<000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUH00000;Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF1P0015YF0`001eYF00<0
05YFFUH01P001EYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool0
1000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00<005YFFUH01@000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH01UYF
100000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEP0001T000IJEP03001JEUYF00=J
EP04001JEUYF000^Ool002eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF009JEP@000=JEP80009JEP03001JEUYF00=J
EPD000IJEP03001JEUYF00IJEP<00003FUH0000000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH01P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPP000EJEP04001JEUYF000^Ool002eoo`04001JEUYF0005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001J
EP000080009JEP03001JEUYF009JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00H000AJ
EP05001JEP00001JEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF100000EJEP00FUIJEP0002ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF2P000UYF0P000UYF00<0
05YFFUH015YF0`0000=JEP0000002P0000=JEP00FUH015YF00@005YFFUIJEP<000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPD002moo`00;Goo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP07001JEUYF001JEP00
FUH00P001EYF00<005YFFUH00UYF5@0015YF00@005YFFUIJEPP000AJEP8000EJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
008002moo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02ioo`00;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP800003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP02FUH00`00FUIJEP030006FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000]Ool01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEQH0009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00D005YFFUIJEP0000AJEP03001J
EUYF00AJEQP000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05001J
EUYFFUH00004FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000015YF0000
00001eYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
15YF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80003Ool500000goo0000000=0004FUH0
1000FUIJEUYF0P00;Woo000]Ool01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH0
1UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF8@000eYF00<005YFFUH00`00
00=JEP00FUH00UYF0P00;Woo000]Ool01000FUIJEUYF0`0000=JEP00FUH01EYF00@005YFFUIJEPl0
00IJEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00@000IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP8002ioo`00;Goo00@005YF000000AJEP03
001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEPL000EJEP04001JEUYFFUH30004FUH0
0`00FUIJEP06FUH30002FUH7000:FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003000^Ool0
02eoo`800003FUH005YF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00EJEP04001JEP000003FUHB0005FUH00`00FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF
009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP0015YF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF1P000UYF00<005YF00000UYF00<005YF
FUH00eYF1@001UYF00<005YFFUH02EYF0P0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo
00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0002FUH30005FUH300001EYF001JEUYF00001EYF1@001UYF00<005YFFUH01EYF100000=JEP00
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000^Ool60005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH30007FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEP000002FUH00`00FUIJEP04
FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP06FUH01000FUIJEP001eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF0000031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF100015YF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF
00MJEP<000=JEP03001JEUYF00EJEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002ioo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00006FUH00000001JEP001UYF00@005YF
FUH0009JEP03001JEUYF00AJEP04001JEUYFFUH60006FUH00`00FUIJEP04FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP05FUHO000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00004FUH005YFFUH700001EYF001JEUYF0000
0UYF00<005YF0000200015YF00<005YFFUH01UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEQ4000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP<00003FUH005YF00AJEP04
001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000aJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH60002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80009Ool70002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJ
EP02FUH6000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool20004FUH00`00FUH00002
0007Ool@0009Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=J
EP03001JEUYF008002eoo`00;Goo0P000eYF0`0017oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
10001goo0`0000=JEP00FUH01UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHB0007FUH00`00FUIJEP04FUH8000]Ool002eoo`800004FUH0
0000FUH20002Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool>0004
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`<000=JEP04001JEP00
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030002Ool40000
0eYF000000020002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEPT000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000bOol002eoo`8000AJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJ
EP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF4000>7oo000]Ool20003FUH2
0006FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH30003FUH01000FUIJEP000UYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF7`00B7oo000]Ool200001EYF000005YF00001EYF
1P000UYF00<005YFFUH00UYF40001UYF00<005YFFUH00P0000EJEP00FUIJEP00009JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`<000=J
EP04001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00
FUIJEP02FUH20002FUH01000FUIJEP001UYF00<005YFFUH01eYF00@005YFFUIJEPH000IJEP03001J
EUYF00YJEP03001JEUYF00T000MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH2001COol002ioo`8000=JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH200001EYF
001JEUYF00001UYF00<005YFFUH01EYF1`002eYF00<005YFFUH02UYF00<005YFFUH02EYF1@000UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00L005YFFUIJEP00
FUH0001BOol002ioo`8000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo0P000UYF
0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo1P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF100000=JEP00FUH00eYF1@000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
001BOol002eoo`8000=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYF001JEP020006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
15YF00<007ooOol00Woo10001EYF00L005YFFUIJEP00FUH0001BOol002eoo`03001oogoo00Aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP800004Ool005YF0002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH01000Oomoogoo2@0000=JEP00
FUH00UYF0P00Dgoo000/Ool2000:Ool30006FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH0
0`00FUH000020003Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF1`0015YF
00<005YFFUH00UYF0P000eYF0P00Dgoo000/Ool2000=Ool40002FUH00`00FUIJEP03FUH50007FUH0
0`00FUIJEP02FUH50007Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF
00<005YFFUH00eYF0`0000=JEP000000Dgoo000/Ool3000@OolI000=Ool00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF00<005YFFUH00eYF00<005YFFUH00`00Dgoo
000/Ool200000eYF001oo`0FOol5000IOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP001eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000/Ool20002FUH00`00
Oomoo`0EOol3000JOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
1eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000]Ool01@00FUIJEUYF0000<Woo0P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P001EYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0DWoo000]Ool01000FUIJEUYF0`00<7oo00<005YF00000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH0100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00;Woo
00@005YFFUH0009JEP03001oogoo02aoo`800006FUH00000001JEP001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH015YF0`0015YF00@005YF000005Ioo`00;goo00<005YF00000eYF0P00:Woo0P0000=J
EP0000000goo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF0`0000AJEP00000005Qo
o`00<7oo0P001EYF0P009Woo0P000eYF0P0017oo0P001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF
00EJEP03001JEUYF008005Yoo`00<Goo00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00
FUH00UYF00<007ooOol01Goo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00002@001EYF00<005YFFUH00eYF0P00F7oo000b
Ool20003FUH00`00FUIJEP03FUH4000FOol40005FUH01000FUIJEP0037oo1@0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10002Woo100000=JEP00FUH01EYF
0`00EWoo000dOol01000FUIJEP001eYF00<005YF00000`003Woo10000UYF00<005YFFUH00eYF00@0
05YF0000019oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000ioo`8000IJEP04001JEUYF001EOol003Eoo`<000MJEP03001JEUYF00=JEPh000IJEP03001J
EUYF00=JEP8001Yoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`8000=J
EP05001JEUYFFUH0001EOol003Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP8002=ooaX0009JEP@000Ioo`D0019oo`800003FUH005YF009JEP8005Ao
o`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=7oo
0P0015YF00<005YFFUH01EYF00<005YFFUH010000goo0`005Goo0P000UYF00<005YF0000E7oo000m
Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000iOol300000eYF001JEP06FUH00`00FUIJ
EP04FUH7000FOol300000eYF001oo`1COol004=ooa80049oo`<000EJEP03001JEUYF00MJEP03001J
EUYF009JEPP000Qoo`H0009JEP8005Eoo`00VWoo0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEPP000=JEP03001JEUYF009JEP8005Eoo`00W7oo0P0000=JEP00FUH01eYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009ioo`H000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Eo
o`00Y7oo2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000EWoo002]Ool80004
FUH01000FUIJEUYF1P00FWoo002eOol8001POol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62063 .74982 m .61791 .69456 L .586 .6957 L p .707 .577 .707 r
F P
0 g
s
.61791 .69456 m .62063 .74982 L .65131 .74591 L p .707 .577 .707 r
F P
0 g
s
.65131 .74591 m .6486 .69066 L .61791 .69456 L p .707 .577 .707 r
F P
0 g
s
.58872 .75096 m .586 .6957 L .55598 .69396 L p .707 .577 .707 r
F P
0 g
s
.586 .6957 m .58872 .75096 L .62063 .74982 L p .707 .577 .707 r
F P
0 g
s
.6486 .69066 m .65131 .74591 L .67776 .73962 L p .707 .577 .707 r
F P
0 g
s
.67776 .73962 m .67504 .68437 L .6486 .69066 L p .707 .577 .707 r
F P
0 g
s
.5587 .74922 m .55598 .69396 L .53079 .68951 L p .707 .577 .707 r
F P
0 g
s
.55598 .69396 m .5587 .74922 L .58872 .75096 L p .707 .577 .707 r
F P
0 g
s
.60666 .80807 m .60839 .77092 L .57688 .76822 L p .707 .577 .707 r
F P
0 g
s
.60839 .77092 m .60666 .80807 L .63823 .80821 L p .707 .577 .707 r
F P
0 g
s
.63823 .80821 m .63996 .77106 L .60839 .77092 L p .707 .577 .707 r
F P
0 g
s
.67504 .68437 m .67776 .73962 L .69738 .73156 L p .707 .577 .707 r
F P
0 g
s
.69738 .73156 m .69466 .6763 L .67504 .68437 L p .707 .577 .707 r
F P
0 g
s
.57515 .80537 m .57688 .76822 L .54852 .76323 L p .707 .577 .707 r
F P
0 g
s
.57688 .76822 m .57515 .80537 L .60666 .80807 L p .707 .577 .707 r
F P
0 g
s
.63996 .77106 m .63823 .80821 L .66678 .80578 L p .707 .577 .707 r
F P
0 g
s
.66678 .80578 m .6685 .76863 L .63996 .77106 L p .707 .577 .707 r
F P
0 g
s
.53079 .68951 m .5335 .74477 L .5587 .74922 L p .707 .577 .707 r
F P
0 g
s
.5335 .74477 m .53079 .68951 L .51289 .68279 L p .707 .577 .707 r
F P
0 g
s
.59325 .84691 m .59606 .82841 L .56533 .82223 L p .707 .577 .707 r
F P
0 g
s
.59606 .82841 m .59325 .84691 L .62478 .85088 L p .707 .577 .707 r
F P
0 g
s
.62478 .85088 m .62759 .83238 L .59606 .82841 L p .707 .577 .707 r
F P
0 g
s
.54852 .76323 m .54679 .80038 L .57515 .80537 L p .707 .577 .707 r
F P
0 g
s
.62759 .83238 m .62478 .85088 L .65404 .85225 L p .707 .577 .707 r
F P
0 g
s
.65404 .85225 m .65685 .83375 L .62759 .83238 L p .707 .577 .707 r
F P
0 g
s
.54679 .80038 m .54852 .76323 L .52608 .75643 L p .707 .577 .707 r
F P
0 g
s
.56533 .82223 m .56252 .84073 L .59325 .84691 L p .707 .577 .707 r
F P
0 g
s
.6685 .76863 m .66678 .80578 L .6895 .80102 L p .707 .577 .707 r
F P
0 g
s
.6895 .80102 m .69123 .76387 L .6685 .76863 L p .707 .577 .707 r
F P
0 g
s
.56252 .84073 m .56533 .82223 L .53842 .81445 L p .707 .577 .707 r
F P
0 g
s
.53842 .81445 m .53561 .83295 L .56252 .84073 L p .707 .577 .707 r
F P
0 g
s
.51289 .68279 m .51561 .73804 L .5335 .74477 L p .707 .577 .707 r
F P
0 g
s
.69466 .6763 m .69738 .73156 L .70826 .72251 L p .707 .577 .707 r
F P
0 g
s
.70826 .72251 m .70554 .66726 L .69466 .6763 L p .707 .577 .707 r
F P
0 g
s
.52608 .75643 m .52435 .79358 L .54679 .80038 L p .707 .577 .707 r
F P
0 g
s
.65685 .83375 m .65404 .85225 L .67815 .85088 L p .707 .577 .707 r
F P
0 g
s
.67815 .85088 m .68096 .83238 L .65685 .83375 L p .707 .577 .707 r
F P
0 g
s
.51561 .73804 m .51289 .68279 L .50404 .67445 L p .707 .577 .707 r
F P
0 g
s
.53561 .83295 m .53842 .81445 L .51797 .80582 L p .707 .577 .707 r
F P
0 g
s
.52435 .79358 m .52608 .75643 L .51175 .7485 L p .707 .577 .707 r
F P
0 g
s
.51797 .80582 m .51516 .82432 L .53561 .83295 L p .707 .577 .707 r
F P
0 g
s
.69123 .76387 m .6895 .80102 L .70417 .79439 L p .707 .577 .707 r
F P
0 g
s
.70417 .79439 m .7059 .75724 L .69123 .76387 L p .707 .577 .707 r
F P
0 g
s
.51175 .7485 m .51003 .78564 L .52435 .79358 L p .707 .577 .707 r
F P
0 g
s
.68096 .83238 m .67815 .85088 L .69477 .84692 L p .707 .577 .707 r
F P
0 g
s
.69477 .84692 m .69758 .82842 L .68096 .83238 L p .707 .577 .707 r
F P
0 g
s
.50404 .67445 m .50676 .7297 L .51561 .73804 L p .707 .577 .707 r
F P
0 g
s
.70554 .66726 m .70826 .72251 L .70932 .71338 L p .707 .577 .707 r
F P
0 g
s
.70932 .71338 m .7066 .65812 L .70554 .66726 L p .707 .577 .707 r
F P
0 g
s
.51516 .82432 m .51797 .80582 L .50596 .79719 L p .707 .577 .707 r
F P
0 g
s
.50596 .79719 m .50315 .81569 L .51516 .82432 L p .707 .577 .707 r
F P
0 g
s
.50676 .7297 m .50404 .67445 L .50511 .66531 L p .707 .577 .707 r
F P
0 g
s
.51003 .78564 m .51175 .7485 L .50696 .7402 L p .707 .577 .707 r
F P
0 g
s
.7059 .75724 m .70417 .79439 L .70936 .78654 L p .707 .577 .707 r
F P
0 g
s
.70936 .78654 m .71109 .7494 L .7059 .75724 L p .707 .577 .707 r
F P
0 g
s
.50696 .7402 m .50523 .77735 L .51003 .78564 L p .707 .577 .707 r
F P
0 g
s
.48366 .82167 m .48366 .31979 L .44017 .31655 L p .707 .577 .707 r
F P
0 g
s
.50511 .66531 m .50783 .72057 L .50676 .7297 L p .707 .577 .707 r
F P
0 g
s
.50315 .81569 m .50596 .79719 L .50359 .7894 L p .707 .577 .707 r
F P
0 g
s
.50359 .7894 m .50078 .8079 L .50315 .81569 L p .707 .577 .707 r
F P
0 g
s
.50783 .72057 m .50511 .66531 L .51599 .65627 L p .707 .577 .707 r
F P
0 g
s
.50523 .77735 m .50696 .7402 L .51215 .73235 L p .707 .577 .707 r
F P
0 g
s
.51215 .73235 m .51042 .7695 L .50523 .77735 L p .707 .577 .707 r
F P
0 g
s
.51599 .65627 m .5187 .71153 L .50783 .72057 L p .707 .577 .707 r
F P
0 g
s
.50078 .8079 m .50359 .7894 L .51107 .78322 L p .707 .577 .707 r
F P
0 g
s
.51107 .78322 m .50826 .80172 L .50078 .8079 L p .707 .577 .707 r
F P
0 g
s
.5187 .71153 m .51599 .65627 L .53561 .64821 L p .707 .577 .707 r
F P
0 g
s
.51042 .7695 m .51215 .73235 L .52682 .72572 L p .707 .577 .707 r
F P
0 g
s
.52682 .72572 m .52509 .76287 L .51042 .7695 L p .707 .577 .707 r
F P
0 g
s
.53561 .64821 m .53832 .70346 L .5187 .71153 L p .707 .577 .707 r
F P
0 g
s
.50826 .80172 m .51107 .78322 L .52769 .77926 L p .707 .577 .707 r
F P
0 g
s
.52769 .77926 m .52488 .79776 L .50826 .80172 L p .707 .577 .707 r
F P
0 g
s
.52488 .79776 m .52769 .77926 L .55181 .77789 L p .707 .577 .707 r
F P
0 g
s
.55181 .77789 m .549 .79639 L .52488 .79776 L p .707 .577 .707 r
F P
0 g
s
.48366 .31979 m .48366 .82167 L .52875 .82115 L p .707 .577 .707 r
F P
0 g
s
.52509 .76287 m .52682 .72572 L .54954 .72096 L p .707 .577 .707 r
F P
0 g
s
.54954 .72096 m .54781 .75811 L .52509 .76287 L p .707 .577 .707 r
F P
0 g
s
.52875 .82115 m .52875 .31926 L .48366 .31979 L p .707 .577 .707 r
F P
0 g
s
.69758 .82842 m .69477 .84692 L .70225 .84074 L p .707 .577 .707 r
F P
0 g
s
.70225 .84074 m .70506 .82224 L .69758 .82842 L p .707 .577 .707 r
F P
0 g
s
.53832 .70346 m .53561 .64821 L .56205 .64192 L p .707 .577 .707 r
F P
0 g
s
.56205 .64192 m .56477 .69717 L .53832 .70346 L p .707 .577 .707 r
F P
0 g
s
.54781 .75811 m .54954 .72096 L .57809 .71853 L p .707 .577 .707 r
F P
0 g
s
.57809 .71853 m .57636 .75568 L .54781 .75811 L p .707 .577 .707 r
F P
0 g
s
.549 .79639 m .55181 .77789 L .58106 .77926 L p .707 .577 .707 r
F P
0 g
s
.58106 .77926 m .57825 .79776 L .549 .79639 L p .707 .577 .707 r
F P
0 g
s
.52875 .31926 m .52875 .82115 L .57102 .81691 L p .707 .577 .707 r
F P
0 g
s
.56477 .69717 m .56205 .64192 L .59273 .63801 L p .707 .577 .707 r
F P
0 g
s
.59273 .63801 m .59545 .69326 L .56477 .69717 L p .707 .577 .707 r
F P
0 g
s
.57102 .81691 m .57102 .31502 L .52875 .31926 L p .707 .577 .707 r
F P
0 g
s
.7066 .65812 m .70932 .71338 L .70047 .70504 L p .707 .577 .707 r
F P
0 g
s
.70047 .70504 m .69776 .64979 L .7066 .65812 L p .707 .577 .707 r
F P
0 g
s
.44017 .81844 m .44017 .31655 L .40254 .30986 L p .707 .577 .707 r
F P
0 g
s
.44017 .31655 m .44017 .81844 L .48366 .82167 L p .707 .577 .707 r
F P
0 g
s
.62465 .63687 m .62737 .69213 L .59545 .69326 L p .707 .577 .707 r
F P
0 g
s
.59545 .69326 m .59273 .63801 L .62465 .63687 L p .707 .577 .707 r
F P
0 g
s
.57636 .75568 m .57809 .71853 L .60966 .71867 L p .707 .577 .707 r
F P
0 g
s
.60966 .71867 m .60793 .75582 L .57636 .75568 L p .707 .577 .707 r
F P
0 g
s
.57825 .79776 m .58106 .77926 L .6126 .78323 L p .707 .577 .707 r
F P
0 g
s
.6126 .78323 m .60979 .80173 L .57825 .79776 L p .707 .577 .707 r
F P
0 g
s
.57102 .31502 m .57102 .81691 L .60634 .80937 L p .707 .577 .707 r
F P
0 g
s
.60634 .80937 m .60634 .30748 L .57102 .31502 L p .707 .577 .707 r
F P
0 g
s
.71109 .7494 m .70936 .78654 L .70457 .77824 L p .707 .577 .707 r
F P
0 g
s
.70457 .77824 m .70629 .7411 L .71109 .7494 L p .707 .577 .707 r
F P
0 g
s
.27472 .70843 m .27362 .65211 L .24167 .65248 L p .707 .577 .707 r
F P
0 g
s
.27362 .65211 m .27472 .70843 L .30542 .70594 L p .707 .577 .707 r
F P
0 g
s
.30542 .70594 m .30432 .64962 L .27362 .65211 L p .707 .577 .707 r
F P
0 g
s
.24277 .7088 m .24167 .65248 L .21162 .65068 L p .707 .577 .707 r
F P
0 g
s
.24167 .65248 m .24277 .7088 L .27472 .70843 L p .707 .577 .707 r
F P
0 g
s
.70506 .82224 m .70225 .84074 L .69988 .83296 L p .707 .577 .707 r
F P
0 g
s
.69988 .83296 m .70269 .81445 L .70506 .82224 L p .707 .577 .707 r
F P
0 g
s
.40254 .81175 m .40254 .30986 L .37445 .30039 L p .707 .577 .707 r
F P
0 g
s
.40254 .30986 m .40254 .81175 L .44017 .81844 L p .707 .577 .707 r
F P
0 g
s
.30432 .64962 m .30542 .70594 L .33188 .70156 L p .707 .577 .707 r
F P
0 g
s
.33188 .70156 m .33078 .64524 L .30432 .64962 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69776 .64979 m .70047 .70504 L .68258 .69832 L p .707 .577 .707 r
F P
0 g
s
.68258 .69832 m .67986 .64306 L .69776 .64979 L p .707 .577 .707 r
F P
0 g
s
.21272 .707 m .21162 .65068 L .18639 .6469 L p .707 .577 .707 r
F P
0 g
s
.21162 .65068 m .21272 .707 L .24277 .7088 L p .707 .577 .707 r
F P
0 g
s
.64117 .72137 m .63944 .75852 L .60793 .75582 L p .707 .577 .707 r
F P
0 g
s
.60793 .75582 m .60966 .71867 L .64117 .72137 L p .707 .577 .707 r
F P
0 g
s
.64332 .78941 m .64051 .80791 L .60979 .80173 L p .707 .577 .707 r
F P
0 g
s
.60979 .80173 m .6126 .78323 L .64332 .78941 L p .707 .577 .707 r
F P
0 g
s
.60634 .30748 m .60634 .80937 L .63125 .79927 L p .707 .577 .707 r
F P
0 g
s
.65467 .63861 m .65739 .69387 L .62737 .69213 L p .707 .577 .707 r
F P
0 g
s
.62737 .69213 m .62465 .63687 L .65467 .63861 L p .707 .577 .707 r
F P
0 g
s
.63125 .79927 m .63125 .29738 L .60634 .30748 L p .707 .577 .707 r
F P
0 g
s
.26126 .77984 m .2619 .74345 L .23036 .74128 L p .707 .577 .707 r
F P
0 g
s
.2619 .74345 m .26126 .77984 L .29285 .77877 L p .707 .577 .707 r
F P
0 g
s
.29285 .77877 m .29349 .74238 L .2619 .74345 L p .707 .577 .707 r
F P
0 g
s
.18639 .6469 m .18749 .70322 L .21272 .707 L p .707 .577 .707 r
F P
0 g
s
.70629 .7411 m .70457 .77824 L .69024 .77031 L p .707 .577 .707 r
F P
0 g
s
.69024 .77031 m .69197 .73316 L .70629 .7411 L p .707 .577 .707 r
F P
0 g
s
.22972 .77767 m .23036 .74128 L .20196 .73608 L p .707 .577 .707 r
F P
0 g
s
.23036 .74128 m .22972 .77767 L .26126 .77984 L p .707 .577 .707 r
F P
0 g
s
.29349 .74238 m .29285 .77877 L .32141 .77457 L p .707 .577 .707 r
F P
0 g
s
.32141 .77457 m .32205 .73818 L .29349 .74238 L p .707 .577 .707 r
F P
0 g
s
.33078 .64524 m .33188 .70156 L .35151 .69573 L p .707 .577 .707 r
F P
0 g
s
.35151 .69573 m .35041 .63941 L .33078 .64524 L p .707 .577 .707 r
F P
0 g
s
.18749 .70322 m .18639 .6469 L .16847 .6415 L p .707 .577 .707 r
F P
0 g
s
.70269 .81445 m .69988 .83296 L .68788 .82432 L p .707 .577 .707 r
F P
0 g
s
.68788 .82432 m .69069 .80582 L .70269 .81445 L p .707 .577 .707 r
F P
0 g
s
.67986 .64306 m .68258 .69832 L .65739 .69387 L p .707 .577 .707 r
F P
0 g
s
.65739 .69387 m .65467 .63861 L .67986 .64306 L p .707 .577 .707 r
F P
0 g
s
.20196 .73608 m .20132 .77247 L .22972 .77767 L p .707 .577 .707 r
F P
0 g
s
.20132 .77247 m .20196 .73608 L .17948 .72837 L p .707 .577 .707 r
F P
0 g
s
.32205 .73818 m .32141 .77457 L .34414 .76765 L p .707 .577 .707 r
F P
0 g
s
.34414 .76765 m .34478 .73126 L .32205 .73818 L p .707 .577 .707 r
F P
0 g
s
.37445 .80227 m .37445 .30039 L .35865 .28904 L p .707 .577 .707 r
F P
0 g
s
.37445 .30039 m .37445 .80227 L .40254 .81175 L p .707 .577 .707 r
F P
0 g
s
.16847 .6415 m .16957 .69782 L .18749 .70322 L p .707 .577 .707 r
F P
0 g
s
.25188 .83312 m .25286 .81605 L .22179 .81129 L p .707 .577 .707 r
F P
0 g
s
.25286 .81605 m .25188 .83312 L .2837 .83335 L p .707 .577 .707 r
F P
0 g
s
.2837 .83335 m .28468 .81627 L .25286 .81605 L p .707 .577 .707 r
F P
0 g
s
.28468 .81627 m .2837 .83335 L .31314 .82902 L p .707 .577 .707 r
F P
0 g
s
.31314 .82902 m .31412 .81194 L .28468 .81627 L p .707 .577 .707 r
F P
0 g
s
.35041 .63941 m .35151 .69573 L .36238 .68902 L p .707 .577 .707 r
F P
0 g
s
.36238 .68902 m .36128 .6327 L .35041 .63941 L p .707 .577 .707 r
F P
0 g
s
.17948 .72837 m .17884 .76476 L .20132 .77247 L p .707 .577 .707 r
F P
0 g
s
.69197 .73316 m .69024 .77031 L .6678 .76351 L p .707 .577 .707 r
F P
0 g
s
.6678 .76351 m .66953 .72637 L .69197 .73316 L p .707 .577 .707 r
F P
0 g
s
.22081 .82836 m .22179 .81129 L .19449 .80246 L p .707 .577 .707 r
F P
0 g
s
.22179 .81129 m .22081 .82836 L .25188 .83312 L p .707 .577 .707 r
F P
0 g
s
.66953 .72637 m .6678 .76351 L .63944 .75852 L p .707 .577 .707 r
F P
0 g
s
.63944 .75852 m .64117 .72137 L .66953 .72637 L p .707 .577 .707 r
F P
0 g
s
.63125 .29738 m .63125 .79927 L .64332 .7876 L p .707 .577 .707 r
F P
0 g
s
.64332 .7876 m .64332 .28571 L .63125 .29738 L p .707 .577 .707 r
F P
0 g
s
.16957 .69782 m .16847 .6415 L .15959 .63502 L p .707 .577 .707 r
F P
0 g
s
.17884 .76476 m .17948 .72837 L .16513 .7189 L p .707 .577 .707 r
F P
0 g
s
.34478 .73126 m .34414 .76765 L .35881 .75868 L p .707 .577 .707 r
F P
0 g
s
.35881 .75868 m .35945 .7223 L .34478 .73126 L p .707 .577 .707 r
F P
0 g
s
.19449 .80246 m .19351 .81953 L .22081 .82836 L p .707 .577 .707 r
F P
0 g
s
.31412 .81194 m .31314 .82902 L .33731 .82055 L p .707 .577 .707 r
F P
0 g
s
.33731 .82055 m .33829 .80348 L .31412 .81194 L p .707 .577 .707 r
F P
0 g
s
.69069 .80582 m .68788 .82432 L .66742 .81569 L p .707 .577 .707 r
F P
0 g
s
.66742 .81569 m .67023 .79719 L .69069 .80582 L p .707 .577 .707 r
F P
0 g
s
.19351 .81953 m .19449 .80246 L .17364 .79043 L p .707 .577 .707 r
F P
0 g
s
.15959 .63502 m .16069 .69134 L .16957 .69782 L p .707 .577 .707 r
F P
0 g
s
.16513 .7189 m .16449 .75528 L .17884 .76476 L p .707 .577 .707 r
F P
0 g
s
.17364 .79043 m .17266 .8075 L .19351 .81953 L p .707 .577 .707 r
F P
0 g
s
.36128 .6327 m .36238 .68902 L .36343 .68208 L p .707 .577 .707 r
F P
0 g
s
.36343 .68208 m .36233 .62576 L .36128 .6327 L p .707 .577 .707 r
F P
0 g
s
.33829 .80348 m .33731 .82055 L .35387 .80879 L p .707 .577 .707 r
F P
0 g
s
.35387 .80879 m .35485 .79171 L .33829 .80348 L p .707 .577 .707 r
F P
0 g
s
.36117 .79487 m .36215 .77779 L .35485 .79171 L p .707 .577 .707 r
F P
0 g
s
.36233 .62576 m .36343 .68208 L .35456 .67559 L p .707 .577 .707 r
F P
0 g
s
.35456 .67559 m .35346 .61928 L .36233 .62576 L p .707 .577 .707 r
F P
0 g
s
.36215 .77779 m .36117 .79487 L .35852 .78016 L p .707 .577 .707 r
F P
0 g
s
.35852 .78016 m .3595 .76308 L .36215 .77779 L p .707 .577 .707 r
F P
0 g
s
.3598 .70186 m .35916 .73825 L .34481 .72877 L p .707 .577 .707 r
F P
0 g
s
.34481 .72877 m .34545 .69238 L .3598 .70186 L p .707 .577 .707 r
F P
0 g
s
.3595 .76308 m .35852 .78016 L .34616 .7661 L p .707 .577 .707 r
F P
0 g
s
.34616 .7661 m .34714 .74903 L .3595 .76308 L p .707 .577 .707 r
F P
0 g
s
.35865 .79093 m .35865 .28904 L .35668 .27694 L p .707 .577 .707 r
F P
0 g
s
.35945 .7223 m .35881 .75868 L .36399 .74855 L p .707 .577 .707 r
F P
0 g
s
.36399 .74855 m .36462 .71216 L .35945 .7223 L p .707 .577 .707 r
F P
0 g
s
.36462 .71216 m .36399 .74855 L .35916 .73825 L p .707 .577 .707 r
F P
0 g
s
.35916 .73825 m .3598 .70186 L .36462 .71216 L p .707 .577 .707 r
F P
0 g
s
.35865 .28904 m .35865 .79093 L .37445 .80227 L p .707 .577 .707 r
F P
0 g
s
.67023 .79719 m .66742 .81569 L .64051 .80791 L p .707 .577 .707 r
F P
0 g
s
.64051 .80791 m .64332 .78941 L .67023 .79719 L p .707 .577 .707 r
F P
0 g
s
.16069 .69134 m .15959 .63502 L .16065 .62808 L p .707 .577 .707 r
F P
0 g
s
.16449 .75528 m .16513 .7189 L .16031 .70859 L p .707 .577 .707 r
F P
0 g
s
.17266 .8075 m .17364 .79043 L .16128 .77637 L p .707 .577 .707 r
F P
0 g
s
.64332 .28571 m .64332 .7876 L .64135 .7755 L p .707 .577 .707 r
F P
0 g
s
.64135 .7755 m .64135 .27362 L .64332 .28571 L p .707 .577 .707 r
F P
0 g
s
.16128 .77637 m .1603 .79344 L .17266 .8075 L p .707 .577 .707 r
F P
0 g
s
.16065 .62808 m .16175 .6844 L .16069 .69134 L p .707 .577 .707 r
F P
0 g
s
.16031 .70859 m .15967 .74498 L .16449 .75528 L p .707 .577 .707 r
F P
0 g
s
.35485 .79171 m .35387 .80879 L .36117 .79487 L p .707 .577 .707 r
F P
0 g
s
.1603 .79344 m .16128 .77637 L .15863 .76166 L p .707 .577 .707 r
F P
0 g
s
.15967 .74498 m .16031 .70859 L .16548 .69846 L p .707 .577 .707 r
F P
0 g
s
.16175 .6844 m .16065 .62808 L .17152 .62136 L p .707 .577 .707 r
F P
0 g
s
.15863 .76166 m .15765 .77874 L .1603 .79344 L p .707 .577 .707 r
F P
0 g
s
.35668 .27694 m .35668 .77883 L .35865 .79093 L p .707 .577 .707 r
F P
0 g
s
.35668 .77883 m .35668 .27694 L .36875 .26528 L p .707 .577 .707 r
F P
0 g
s
.16548 .69846 m .16484 .73485 L .15967 .74498 L p .707 .577 .707 r
F P
0 g
s
.17152 .62136 m .17262 .67768 L .16175 .6844 L p .707 .577 .707 r
F P
0 g
s
.64135 .27362 m .64135 .7755 L .62555 .76416 L p .707 .577 .707 r
F P
0 g
s
.62555 .76416 m .62555 .26227 L .64135 .27362 L p .707 .577 .707 r
F P
0 g
s
.35346 .61928 m .35456 .67559 L .33663 .6702 L p .707 .577 .707 r
F P
0 g
s
.33663 .6702 m .33553 .61388 L .35346 .61928 L p .707 .577 .707 r
F P
0 g
s
.15765 .77874 m .15863 .76166 L .16593 .74774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16484 .73485 m .16548 .69846 L .18015 .68949 L p .707 .577 .707 r
F P
0 g
s
.17262 .67768 m .17152 .62136 L .19114 .61554 L p .707 .577 .707 r
F P
0 g
s
.16593 .74774 m .16495 .76482 L .15765 .77874 L p .707 .577 .707 r
F P
0 g
s
.18015 .68949 m .17951 .72588 L .16484 .73485 L p .707 .577 .707 r
F P
0 g
s
.19114 .61554 m .19224 .67185 L .17262 .67768 L p .707 .577 .707 r
F P
0 g
s
.33553 .61388 m .33663 .6702 L .31141 .66641 L p .707 .577 .707 r
F P
0 g
s
.31141 .66641 m .31031 .6101 L .33553 .61388 L p .707 .577 .707 r
F P
0 g
s
.36875 .76716 m .36875 .26528 L .39366 .25518 L p .707 .577 .707 r
F P
0 g
s
.36875 .26528 m .36875 .76716 L .35668 .77883 L p .707 .577 .707 r
F P
0 g
s
.16495 .76482 m .16593 .74774 L .18249 .73597 L p .707 .577 .707 r
F P
0 g
s
.19224 .67185 m .19114 .61554 L .2176 .61116 L p .707 .577 .707 r
F P
0 g
s
.17951 .72588 m .18015 .68949 L .20288 .68257 L p .707 .577 .707 r
F P
0 g
s
.34545 .69238 m .34481 .72877 L .32233 .72106 L p .707 .577 .707 r
F P
0 g
s
.32233 .72106 m .32297 .68467 L .34545 .69238 L p .707 .577 .707 r
F P
0 g
s
.18249 .73597 m .18151 .75305 L .16495 .76482 L p .707 .577 .707 r
F P
0 g
s
.62555 .26227 m .62555 .76416 L .59746 .75468 L p .707 .577 .707 r
F P
0 g
s
.59746 .75468 m .59746 .25279 L .62555 .26227 L p .707 .577 .707 r
F P
0 g
s
.2176 .61116 m .2187 .66748 L .19224 .67185 L p .707 .577 .707 r
F P
0 g
s
.31031 .6101 m .31141 .66641 L .28135 .66462 L p .707 .577 .707 r
F P
0 g
s
.28135 .66462 m .28025 .6083 L .31031 .6101 L p .707 .577 .707 r
F P
0 g
s
.20288 .68257 m .20224 .71896 L .17951 .72588 L p .707 .577 .707 r
F P
0 g
s
.34714 .74903 m .34616 .7661 L .32531 .75407 L p .707 .577 .707 r
F P
0 g
s
.32531 .75407 m .32629 .73699 L .34714 .74903 L p .707 .577 .707 r
F P
0 g
s
.2187 .66748 m .2176 .61116 L .24831 .60867 L p .707 .577 .707 r
F P
0 g
s
.18151 .75305 m .18249 .73597 L .20667 .72751 L p .707 .577 .707 r
F P
0 g
s
.20224 .71896 m .20288 .68257 L .23144 .67837 L p .707 .577 .707 r
F P
0 g
s
.32297 .68467 m .32233 .72106 L .29394 .71586 L p .707 .577 .707 r
F P
0 g
s
.29394 .71586 m .29457 .67948 L .32297 .68467 L p .707 .577 .707 r
F P
0 g
s
.28025 .6083 m .28135 .66462 L .24941 .66498 L p .707 .577 .707 r
F P
0 g
s
.24941 .66498 m .24831 .60867 L .28025 .6083 L p .707 .577 .707 r
F P
0 g
s
.24831 .60867 m .24941 .66498 L .2187 .66748 L p .707 .577 .707 r
F P
0 g
s
.20667 .72751 m .20569 .74459 L .18151 .75305 L p .707 .577 .707 r
F P
0 g
s
.39366 .25518 m .39366 .75707 L .36875 .76716 L p .707 .577 .707 r
F P
0 g
s
.39366 .75707 m .39366 .25518 L .42898 .24764 L p .707 .577 .707 r
F P
0 g
s
.75059 .66123 m .75169 .60656 L .71974 .60565 L p .707 .577 .707 r
F P
0 g
s
.75169 .60656 m .75059 .66123 L .78129 .65895 L p .707 .577 .707 r
F P
0 g
s
.78129 .65895 m .78239 .60429 L .75169 .60656 L p .707 .577 .707 r
F P
0 g
s
.71865 .66032 m .71974 .60565 L .68969 .60164 L p .707 .577 .707 r
F P
0 g
s
.71974 .60565 m .71865 .66032 L .75059 .66123 L p .707 .577 .707 r
F P
0 g
s
.23144 .67837 m .2308 .71476 L .20224 .71896 L p .707 .577 .707 r
F P
0 g
s
.2308 .71476 m .23144 .67837 L .26303 .67731 L p .707 .577 .707 r
F P
0 g
s
.29457 .67948 m .29394 .71586 L .2624 .71369 L p .707 .577 .707 r
F P
0 g
s
.2624 .71369 m .26303 .67731 L .29457 .67948 L p .707 .577 .707 r
F P
0 g
s
.32629 .73699 m .32531 .75407 L .29802 .74524 L p .707 .577 .707 r
F P
0 g
s
.29802 .74524 m .299 .72817 L .32629 .73699 L p .707 .577 .707 r
F P
0 g
s
.59746 .25279 m .59746 .75468 L .55983 .748 L p .707 .577 .707 r
F P
0 g
s
.55983 .748 m .55983 .24611 L .59746 .25279 L p .707 .577 .707 r
F P
0 g
s
.26303 .67731 m .2624 .71369 L .2308 .71476 L p .707 .577 .707 r
F P
0 g
s
.20569 .74459 m .20667 .72751 L .2361 .72318 L p .707 .577 .707 r
F P
0 g
s
.78239 .60429 m .78129 .65895 L .80776 .65371 L p .707 .577 .707 r
F P
0 g
s
.80776 .65371 m .80886 .59904 L .78239 .60429 L p .707 .577 .707 r
F P
0 g
s
.68859 .6563 m .68969 .60164 L .66446 .59491 L p .707 .577 .707 r
F P
0 g
s
.68969 .60164 m .68859 .6563 L .71865 .66032 L p .707 .577 .707 r
F P
0 g
s
.2361 .72318 m .23512 .74026 L .20569 .74459 L p .707 .577 .707 r
F P
0 g
s
.299 .72817 m .29802 .74524 L .26694 .74048 L p .707 .577 .707 r
F P
0 g
s
.26694 .74048 m .26792 .72341 L .299 .72817 L p .707 .577 .707 r
F P
0 g
s
.23512 .74026 m .2361 .72318 L .26792 .72341 L p .707 .577 .707 r
F P
0 g
s
.7376 .71099 m .73696 .6734 L .70542 .67281 L p .707 .577 .707 r
F P
0 g
s
.73696 .6734 m .7376 .71099 L .7692 .70945 L p .707 .577 .707 r
F P
0 g
s
.7692 .70945 m .76856 .67187 L .73696 .6734 L p .707 .577 .707 r
F P
0 g
s
.26792 .72341 m .26694 .74048 L .23512 .74026 L p .707 .577 .707 r
F P
0 g
s
.80886 .59904 m .80776 .65371 L .82738 .646 L p .707 .577 .707 r
F P
0 g
s
.82738 .646 m .82848 .59134 L .80886 .59904 L p .707 .577 .707 r
F P
0 g
s
.42898 .74953 m .42898 .24764 L .47125 .2434 L p .707 .577 .707 r
F P
0 g
s
.42898 .24764 m .42898 .74953 L .39366 .75707 L p .707 .577 .707 r
F P
0 g
s
.76856 .67187 m .7692 .70945 L .79776 .70595 L p .707 .577 .707 r
F P
0 g
s
.79776 .70595 m .79712 .66836 L .76856 .67187 L p .707 .577 .707 r
F P
0 g
s
.70606 .7104 m .70542 .67281 L .67703 .67016 L p .707 .577 .707 r
F P
0 g
s
.70542 .67281 m .70606 .7104 L .7376 .71099 L p .707 .577 .707 r
F P
0 g
s
.66446 .59491 m .66336 .64958 L .68859 .6563 L p .707 .577 .707 r
F P
0 g
s
.66336 .64958 m .66446 .59491 L .64654 .58614 L p .707 .577 .707 r
F P
0 g
s
.55983 .24611 m .55983 .748 L .51634 .74476 L p .707 .577 .707 r
F P
0 g
s
.51634 .74476 m .51634 .24287 L .55983 .24611 L p .707 .577 .707 r
F P
0 g
s
.73306 .73988 m .73208 .72072 L .701 .72181 L p .707 .577 .707 r
F P
0 g
s
.73208 .72072 m .73306 .73988 L .76488 .73808 L p .707 .577 .707 r
F P
0 g
s
.76488 .73808 m .7639 .71892 L .73208 .72072 L p .707 .577 .707 r
F P
0 g
s
.701 .72181 m .70198 .74097 L .73306 .73988 L p .707 .577 .707 r
F P
0 g
s
.67703 .67016 m .67766 .70775 L .70606 .7104 L p .707 .577 .707 r
F P
0 g
s
.7639 .71892 m .76488 .73808 L .79431 .73575 L p .707 .577 .707 r
F P
0 g
s
.79431 .73575 m .79333 .71659 L .7639 .71892 L p .707 .577 .707 r
F P
0 g
s
.70198 .74097 m .701 .72181 L .6737 .72208 L p .707 .577 .707 r
F P
0 g
s
.79712 .66836 m .79776 .70595 L .82048 .70081 L p .707 .577 .707 r
F P
0 g
s
.82048 .70081 m .81985 .66323 L .79712 .66836 L p .707 .577 .707 r
F P
0 g
s
.47125 .74529 m .47125 .2434 L .51634 .24287 L p .707 .577 .707 r
F P
0 g
s
.47125 .2434 m .47125 .74529 L .42898 .74953 L p .707 .577 .707 r
F P
0 g
s
.6737 .72208 m .67468 .74124 L .70198 .74097 L p .707 .577 .707 r
F P
0 g
s
.67766 .70775 m .67703 .67016 L .65455 .66571 L p .707 .577 .707 r
F P
0 g
s
.51634 .24287 m .51634 .74476 L .47125 .74529 L p .707 .577 .707 r
F P
0 g
s
.79333 .71659 m .79431 .73575 L .81849 .73311 L p .707 .577 .707 r
F P
0 g
s
.81849 .73311 m .81751 .71394 L .79333 .71659 L p .707 .577 .707 r
F P
0 g
s
.64654 .58614 m .64544 .64081 L .66336 .64958 L p .707 .577 .707 r
F P
0 g
s
.82848 .59134 m .82738 .646 L .83825 .6366 L p .707 .577 .707 r
F P
0 g
s
.83825 .6366 m .83935 .58193 L .82848 .59134 L p .707 .577 .707 r
F P
0 g
s
.65455 .66571 m .65519 .7033 L .67766 .70775 L p .707 .577 .707 r
F P
0 g
s
.64544 .64081 m .64654 .58614 L .63767 .57617 L p .707 .577 .707 r
F P
0 g
s
.67468 .74124 m .6737 .72208 L .65285 .7215 L p .707 .577 .707 r
F P
0 g
s
.65285 .7215 m .65383 .74066 L .67468 .74124 L p .707 .577 .707 r
F P
0 g
s
.81985 .66323 m .82048 .70081 L .83515 .69455 L p .707 .577 .707 r
F P
0 g
s
.83515 .69455 m .83452 .65697 L .81985 .66323 L p .707 .577 .707 r
F P
0 g
s
.65519 .7033 m .65455 .66571 L .6402 .65989 L p .707 .577 .707 r
F P
0 g
s
.81751 .71394 m .81849 .73311 L .83504 .73042 L p .707 .577 .707 r
F P
0 g
s
.83504 .73042 m .83406 .71125 L .81751 .71394 L p .707 .577 .707 r
F P
0 g
s
.6402 .65989 m .64084 .69747 L .65519 .7033 L p .707 .577 .707 r
F P
0 g
s
.63767 .57617 m .63657 .63084 L .64544 .64081 L p .707 .577 .707 r
F P
0 g
s
.83935 .58193 m .83825 .6366 L .8393 .62642 L p .707 .577 .707 r
F P
0 g
s
.8393 .62642 m .8404 .57175 L .83935 .58193 L p .707 .577 .707 r
F P
0 g
s
.65383 .74066 m .65285 .7215 L .6405 .72014 L p .707 .577 .707 r
F P
0 g
s
.6405 .72014 m .64148 .7393 L .65383 .74066 L p .707 .577 .707 r
F P
0 g
s
.63657 .63084 m .63767 .57617 L .63872 .56599 L p .707 .577 .707 r
F P
0 g
s
.83452 .65697 m .83515 .69455 L .84033 .68778 L p .707 .577 .707 r
F P
0 g
s
.84033 .68778 m .83969 .6502 L .83452 .65697 L p .707 .577 .707 r
F P
0 g
s
.64084 .69747 m .6402 .65989 L .63537 .65327 L p .707 .577 .707 r
F P
0 g
s
.83406 .71125 m .83504 .73042 L .84235 .72794 L p .707 .577 .707 r
F P
0 g
s
.84235 .72794 m .84137 .70878 L .83406 .71125 L p .707 .577 .707 r
F P
0 g
s
.63537 .65327 m .63601 .69085 L .64084 .69747 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63872 .56599 m .63762 .62066 L .63657 .63084 L p .707 .577 .707 r
F P
0 g
s
.8404 .57175 m .8393 .62642 L .83043 .61645 L p .707 .577 .707 r
F P
0 g
s
.83043 .61645 m .83153 .56179 L .8404 .57175 L p .707 .577 .707 r
F P
0 g
s
.64148 .7393 m .6405 .72014 L .63784 .71812 L p .707 .577 .707 r
F P
0 g
s
.63784 .71812 m .63882 .73728 L .64148 .7393 L p .707 .577 .707 r
F P
0 g
s
.63762 .62066 m .63872 .56599 L .64959 .55659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83969 .6502 m .84033 .68778 L .83551 .68116 L p .707 .577 .707 r
F P
0 g
s
.83551 .68116 m .83487 .64358 L .83969 .6502 L p .707 .577 .707 r
F P
0 g
s
.63601 .69085 m .63537 .65327 L .64055 .6465 L p .707 .577 .707 r
F P
0 g
s
.84137 .70878 m .84235 .72794 L .8397 .72592 L p .707 .577 .707 r
F P
0 g
s
.8397 .72592 m .83872 .70676 L .84137 .70878 L p .707 .577 .707 r
F P
0 g
s
.40455 .61995 m .40726 .56418 L .37535 .56245 L p .707 .577 .707 r
F P
0 g
s
.40726 .56418 m .40455 .61995 L .43523 .61912 L p .707 .577 .707 r
F P
0 g
s
.43523 .61912 m .43794 .56335 L .40726 .56418 L p .707 .577 .707 r
F P
0 g
s
.37263 .61823 m .37535 .56245 L .34533 .55834 L p .707 .577 .707 r
F P
0 g
s
.37535 .56245 m .37263 .61823 L .40455 .61995 L p .707 .577 .707 r
F P
0 g
s
.64055 .6465 m .64119 .68408 L .63601 .69085 L p .707 .577 .707 r
F P
0 g
s
.64959 .55659 m .64849 .61125 L .63762 .62066 L p .707 .577 .707 r
F P
0 g
s
.43794 .56335 m .43523 .61912 L .46167 .61581 L p .707 .577 .707 r
F P
0 g
s
.46167 .61581 m .46439 .56004 L .43794 .56335 L p .707 .577 .707 r
F P
0 g
s
.83153 .56179 m .83043 .61645 L .81251 .60768 L p .707 .577 .707 r
F P
0 g
s
.81251 .60768 m .81361 .55301 L .83153 .56179 L p .707 .577 .707 r
F P
0 g
s
.34261 .61411 m .34533 .55834 L .32014 .55224 L p .707 .577 .707 r
F P
0 g
s
.34533 .55834 m .34261 .61411 L .37263 .61823 L p .707 .577 .707 r
F P
0 g
s
.64849 .61125 m .64959 .55659 L .66921 .54889 L p .707 .577 .707 r
F P
0 g
s
.63882 .73728 m .63784 .71812 L .64515 .71564 L p .707 .577 .707 r
F P
0 g
s
.64515 .71564 m .64613 .73481 L .63882 .73728 L p .707 .577 .707 r
F P
0 g
s
.39207 .68287 m .39034 .64599 L .35883 .64589 L p .707 .577 .707 r
F P
0 g
s
.39034 .64599 m .39207 .68287 L .42364 .68016 L p .707 .577 .707 r
F P
0 g
s
.42364 .68016 m .42191 .64328 L .39034 .64599 L p .707 .577 .707 r
F P
0 g
s
.42191 .64328 m .42364 .68016 L .45218 .6749 L p .707 .577 .707 r
F P
0 g
s
.45218 .6749 m .45045 .63802 L .42191 .64328 L p .707 .577 .707 r
F P
0 g
s
.83487 .64358 m .83551 .68116 L .82115 .67534 L p .707 .577 .707 r
F P
0 g
s
.82115 .67534 m .82052 .63775 L .83487 .64358 L p .707 .577 .707 r
F P
0 g
s
.32014 .55224 m .31742 .60801 L .34261 .61411 L p .707 .577 .707 r
F P
0 g
s
.36056 .68277 m .35883 .64589 L .33047 .64299 L p .707 .577 .707 r
F P
0 g
s
.35883 .64589 m .36056 .68277 L .39207 .68287 L p .707 .577 .707 r
F P
0 g
s
.46439 .56004 m .46167 .61581 L .48129 .61035 L p .707 .577 .707 r
F P
0 g
s
.48129 .61035 m .48401 .55457 L .46439 .56004 L p .707 .577 .707 r
F P
0 g
s
.64119 .68408 m .64055 .6465 L .65522 .64024 L p .707 .577 .707 r
F P
0 g
s
.31742 .60801 m .32014 .55224 L .30224 .54475 L p .707 .577 .707 r
F P
0 g
s
.83872 .70676 m .8397 .72592 L .82734 .72456 L p .707 .577 .707 r
F P
0 g
s
.82734 .72456 m .82636 .7054 L .83872 .70676 L p .707 .577 .707 r
F P
0 g
s
.66921 .54889 m .66812 .60355 L .64849 .61125 L p .707 .577 .707 r
F P
0 g
s
.65522 .64024 m .65586 .67783 L .64119 .68408 L p .707 .577 .707 r
F P
0 g
s
.81361 .55301 m .81251 .60768 L .78728 .60095 L p .707 .577 .707 r
F P
0 g
s
.78728 .60095 m .78838 .54629 L .81361 .55301 L p .707 .577 .707 r
F P
0 g
s
.33047 .64299 m .33219 .67987 L .36056 .68277 L p .707 .577 .707 r
F P
0 g
s
.45045 .63802 m .45218 .6749 L .4749 .66762 L p .707 .577 .707 r
F P
0 g
s
.4749 .66762 m .47318 .63074 L .45045 .63802 L p .707 .577 .707 r
F P
0 g
s
.66812 .60355 m .66921 .54889 L .69568 .54364 L p .707 .577 .707 r
F P
0 g
s
.33219 .67987 m .33047 .64299 L .30802 .63757 L p .707 .577 .707 r
F P
0 g
s
.39021 .72729 m .3874 .70915 L .35667 .71119 L p .707 .577 .707 r
F P
0 g
s
.3874 .70915 m .39021 .72729 L .42174 .72212 L p .707 .577 .707 r
F P
0 g
s
.42174 .72212 m .41893 .70399 L .3874 .70915 L p .707 .577 .707 r
F P
0 g
s
.41893 .70399 m .42174 .72212 L .451 .71433 L p .707 .577 .707 r
F P
0 g
s
.451 .71433 m .44819 .69619 L .41893 .70399 L p .707 .577 .707 r
F P
0 g
s
.30224 .54475 m .29952 .60052 L .31742 .60801 L p .707 .577 .707 r
F P
0 g
s
.64613 .73481 m .64515 .71564 L .6617 .71295 L p .707 .577 .707 r
F P
0 g
s
.35667 .71119 m .35948 .72932 L .39021 .72729 L p .707 .577 .707 r
F P
0 g
s
.6617 .71295 m .66268 .73212 L .64613 .73481 L p .707 .577 .707 r
F P
0 g
s
.35948 .72932 m .35667 .71119 L .32977 .70989 L p .707 .577 .707 r
F P
0 g
s
.30802 .63757 m .30975 .67446 L .33219 .67987 L p .707 .577 .707 r
F P
0 g
s
.48401 .55457 m .48129 .61035 L .49217 .60327 L p .707 .577 .707 r
F P
0 g
s
.49217 .60327 m .49489 .54749 L .48401 .55457 L p .707 .577 .707 r
F P
0 g
s
.44819 .69619 m .451 .71433 L .47512 .70467 L p .707 .577 .707 r
F P
0 g
s
.47512 .70467 m .47231 .68654 L .44819 .69619 L p .707 .577 .707 r
F P
0 g
s
.82052 .63775 m .82115 .67534 L .79868 .67089 L p .707 .577 .707 r
F P
0 g
s
.79868 .67089 m .79804 .6333 L .82052 .63775 L p .707 .577 .707 r
F P
0 g
s
.78838 .54629 m .78728 .60095 L .75723 .59694 L p .707 .577 .707 r
F P
0 g
s
.75723 .59694 m .75832 .54227 L .78838 .54629 L p .707 .577 .707 r
F P
0 g
s
.65586 .67783 m .65522 .64024 L .67795 .63511 L p .707 .577 .707 r
F P
0 g
s
.29952 .60052 m .30224 .54475 L .29339 .5366 L p .707 .577 .707 r
F P
0 g
s
.32977 .70989 m .33258 .72802 L .35948 .72932 L p .707 .577 .707 r
F P
0 g
s
.69458 .59831 m .69568 .54364 L .72638 .54136 L p .707 .577 .707 r
F P
0 g
s
.69568 .54364 m .69458 .59831 L .66812 .60355 L p .707 .577 .707 r
F P
0 g
s
.47318 .63074 m .4749 .66762 L .48958 .65902 L p .707 .577 .707 r
F P
0 g
s
.48958 .65902 m .48785 .62213 L .47318 .63074 L p .707 .577 .707 r
F P
0 g
s
.82636 .7054 m .82734 .72456 L .80649 .72398 L p .707 .577 .707 r
F P
0 g
s
.80649 .72398 m .80551 .70482 L .82636 .7054 L p .707 .577 .707 r
F P
0 g
s
.30975 .67446 m .30802 .63757 L .2937 .63017 L p .707 .577 .707 r
F P
0 g
s
.67795 .63511 m .67858 .67269 L .65586 .67783 L p .707 .577 .707 r
F P
0 g
s
.75832 .54227 m .75723 .59694 L .72528 .59603 L p .707 .577 .707 r
F P
0 g
s
.72528 .59603 m .72638 .54136 L .75832 .54227 L p .707 .577 .707 r
F P
0 g
s
.72638 .54136 m .72528 .59603 L .69458 .59831 L p .707 .577 .707 r
F P
0 g
s
.33258 .72802 m .32977 .70989 L .30931 .70539 L p .707 .577 .707 r
F P
0 g
s
.29339 .5366 m .29067 .59237 L .29952 .60052 L p .707 .577 .707 r
F P
0 g
s
.47231 .68654 m .47512 .70467 L .49173 .6941 L p .707 .577 .707 r
F P
0 g
s
.49173 .6941 m .48892 .67597 L .47231 .68654 L p .707 .577 .707 r
F P
0 g
s
.30931 .70539 m .31212 .72352 L .33258 .72802 L p .707 .577 .707 r
F P
0 g
s
.2937 .63017 m .29543 .66706 L .30975 .67446 L p .707 .577 .707 r
F P
0 g
s
.66268 .73212 m .6617 .71295 L .68588 .71031 L p .707 .577 .707 r
F P
0 g
s
.68588 .71031 m .68686 .72947 L .66268 .73212 L p .707 .577 .707 r
F P
0 g
s
.79804 .6333 m .79868 .67089 L .77028 .66824 L p .707 .577 .707 r
F P
0 g
s
.77028 .66824 m .76964 .63065 L .79804 .6333 L p .707 .577 .707 r
F P
0 g
s
.67858 .67269 m .67795 .63511 L .70651 .6316 L p .707 .577 .707 r
F P
0 g
s
.49489 .54749 m .49217 .60327 L .49324 .59526 L p .707 .577 .707 r
F P
0 g
s
.49324 .59526 m .49595 .53949 L .49489 .54749 L p .707 .577 .707 r
F P
0 g
s
.70651 .6316 m .70714 .66919 L .67858 .67269 L p .707 .577 .707 r
F P
0 g
s
.29067 .59237 m .29339 .5366 L .29446 .52859 L p .707 .577 .707 r
F P
0 g
s
.80551 .70482 m .80649 .72398 L .77919 .72425 L p .707 .577 .707 r
F P
0 g
s
.77919 .72425 m .77821 .70509 L .80551 .70482 L p .707 .577 .707 r
F P
0 g
s
.48785 .62213 m .48958 .65902 L .49477 .64994 L p .707 .577 .707 r
F P
0 g
s
.49477 .64994 m .49304 .61306 L .48785 .62213 L p .707 .577 .707 r
F P
0 g
s
.76964 .63065 m .77028 .66824 L .73874 .66765 L p .707 .577 .707 r
F P
0 g
s
.73874 .66765 m .7381 .63007 L .76964 .63065 L p .707 .577 .707 r
F P
0 g
s
.29543 .66706 m .2937 .63017 L .2889 .62151 L p .707 .577 .707 r
F P
0 g
s
.70714 .66919 m .70651 .6316 L .7381 .63007 L p .707 .577 .707 r
F P
0 g
s
.31212 .72352 m .30931 .70539 L .29731 .69812 L p .707 .577 .707 r
F P
0 g
s
.68686 .72947 m .68588 .71031 L .71532 .70798 L p .707 .577 .707 r
F P
0 g
s
.7381 .63007 m .73874 .66765 L .70714 .66919 L p .707 .577 .707 r
F P
0 g
s
.71532 .70798 m .7163 .72714 L .68686 .72947 L p .707 .577 .707 r
F P
0 g
s
.48892 .67597 m .49173 .6941 L .49922 .68364 L p .707 .577 .707 r
F P
0 g
s
.49922 .68364 m .49641 .66551 L .48892 .67597 L p .707 .577 .707 r
F P
0 g
s
.29731 .69812 m .30012 .71625 L .31212 .72352 L p .707 .577 .707 r
F P
0 g
s
.29446 .52859 m .29174 .58437 L .29067 .59237 L p .707 .577 .707 r
F P
0 g
s
.2889 .62151 m .29063 .65839 L .29543 .66706 L p .707 .577 .707 r
F P
0 g
s
.77821 .70509 m .77919 .72425 L .74811 .72534 L p .707 .577 .707 r
F P
0 g
s
.74811 .72534 m .74713 .70618 L .77821 .70509 L p .707 .577 .707 r
F P
0 g
s
.7163 .72714 m .71532 .70798 L .74713 .70618 L p .707 .577 .707 r
F P
0 g
s
.74713 .70618 m .74811 .72534 L .7163 .72714 L p .707 .577 .707 r
F P
0 g
s
.49595 .53949 m .49324 .59526 L .48439 .58711 L p .707 .577 .707 r
F P
0 g
s
.48439 .58711 m .48711 .53134 L .49595 .53949 L p .707 .577 .707 r
F P
0 g
s
.29174 .58437 m .29446 .52859 L .30533 .52151 L p .707 .577 .707 r
F P
0 g
s
.49304 .61306 m .49477 .64994 L .48997 .64128 L p .707 .577 .707 r
F P
0 g
s
.48997 .64128 m .48824 .6044 L .49304 .61306 L p .707 .577 .707 r
F P
0 g
s
.30012 .71625 m .29731 .69812 L .29493 .6888 L p .707 .578 .707 r
F P
0 g
s
.29063 .65839 m .2889 .62151 L .2941 .61243 L p .707 .577 .707 r
F P
0 g
s
.49641 .66551 m .49922 .68364 L .49684 .67432 L p .707 .578 .707 r
F P
0 g
s
.49684 .67432 m .49403 .65619 L .49641 .66551 L p .707 .578 .707 r
F P
0 g
s
.29493 .6888 m .29774 .70694 L .30012 .71625 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30533 .52151 m .30262 .57729 L .29174 .58437 L p .707 .577 .707 r
F P
0 g
s
.2941 .61243 m .29582 .64932 L .29063 .65839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48711 .53134 m .48439 .58711 L .46649 .57962 L p .707 .577 .707 r
F P
0 g
s
.46649 .57962 m .46921 .52385 L .48711 .53134 L p .707 .577 .707 r
F P
0 g
s
.30262 .57729 m .30533 .52151 L .32496 .51605 L p .707 .577 .707 r
F P
0 g
s
.48824 .6044 m .48997 .64128 L .47565 .63388 L p .707 .577 .707 r
F P
0 g
s
.47565 .63388 m .47392 .59699 L .48824 .6044 L p .707 .577 .707 r
F P
0 g
s
.29774 .70694 m .29493 .6888 L .30242 .67835 L p .707 .577 .707 r
F P
0 g
s
.29582 .64932 m .2941 .61243 L .30877 .60383 L p .707 .577 .707 r
F P
0 g
s
.49403 .65619 m .49684 .67432 L .48484 .66706 L p .707 .577 .707 r
F P
0 g
s
.48484 .66706 m .48203 .64893 L .49403 .65619 L p .707 .577 .707 r
F P
0 g
s
.30242 .67835 m .30523 .69648 L .29774 .70694 L p .707 .577 .707 r
F P
0 g
s
.32496 .51605 m .32224 .57182 L .30262 .57729 L p .707 .577 .707 r
F P
0 g
s
.30877 .60383 m .3105 .64072 L .29582 .64932 L p .707 .577 .707 r
F P
0 g
s
.46921 .52385 m .46649 .57962 L .4413 .57352 L p .707 .577 .707 r
F P
0 g
s
.4413 .57352 m .44402 .51775 L .46921 .52385 L p .707 .577 .707 r
F P
0 g
s
.32224 .57182 m .32496 .51605 L .3514 .51274 L p .707 .577 .707 r
F P
0 g
s
.47392 .59699 m .47565 .63388 L .45321 .62846 L p .707 .577 .707 r
F P
0 g
s
.45321 .62846 m .45148 .59158 L .47392 .59699 L p .707 .577 .707 r
F P
0 g
s
.3105 .64072 m .30877 .60383 L .33149 .59655 L p .707 .577 .707 r
F P
0 g
s
.30523 .69648 m .30242 .67835 L .31903 .66777 L p .707 .577 .707 r
F P
0 g
s
.3514 .51274 m .34868 .56851 L .32224 .57182 L p .707 .577 .707 r
F P
0 g
s
.48203 .64893 m .48484 .66706 L .46438 .66256 L p .707 .577 .707 r
F P
0 g
s
.46438 .66256 m .46157 .64442 L .48203 .64893 L p .707 .577 .707 r
F P
0 g
s
.31903 .66777 m .32184 .68591 L .30523 .69648 L p .707 .577 .707 r
F P
0 g
s
.44402 .51775 m .4413 .57352 L .41128 .56941 L p .707 .577 .707 r
F P
0 g
s
.41128 .56941 m .414 .51363 L .44402 .51775 L p .707 .577 .707 r
F P
0 g
s
.34868 .56851 m .3514 .51274 L .38208 .51191 L p .707 .577 .707 r
F P
0 g
s
.33149 .59655 m .33322 .63343 L .3105 .64072 L p .707 .577 .707 r
F P
0 g
s
.414 .51363 m .41128 .56941 L .37936 .56768 L p .707 .577 .707 r
F P
0 g
s
.37936 .56768 m .38208 .51191 L .414 .51363 L p .707 .577 .707 r
F P
0 g
s
.38208 .51191 m .37936 .56768 L .34868 .56851 L p .707 .577 .707 r
F P
0 g
s
.45148 .59158 m .45321 .62846 L .42484 .62556 L p .707 .577 .707 r
F P
0 g
s
.42484 .62556 m .42312 .58868 L .45148 .59158 L p .707 .577 .707 r
F P
0 g
s
.33322 .63343 m .33149 .59655 L .36004 .59129 L p .707 .577 .707 r
F P
0 g
s
.32184 .68591 m .31903 .66777 L .34315 .65812 L p .707 .577 .707 r
F P
0 g
s
.46157 .64442 m .46438 .66256 L .43748 .66126 L p .707 .577 .707 r
F P
0 g
s
.43748 .66126 m .43467 .64313 L .46157 .64442 L p .707 .577 .707 r
F P
0 g
s
.36004 .59129 m .36176 .62818 L .33322 .63343 L p .707 .577 .707 r
F P
0 g
s
.34315 .65812 m .34596 .67625 L .32184 .68591 L p .707 .577 .707 r
F P
0 g
s
.42312 .58868 m .42484 .62556 L .39333 .62546 L p .707 .577 .707 r
F P
0 g
s
.39333 .62546 m .39161 .58858 L .42312 .58868 L p .707 .577 .707 r
F P
0 g
s
.36176 .62818 m .36004 .59129 L .39161 .58858 L p .707 .577 .707 r
F P
0 g
s
.39161 .58858 m .39333 .62546 L .36176 .62818 L p .707 .577 .707 r
F P
0 g
s
.34596 .67625 m .34315 .65812 L .37241 .65032 L p .707 .577 .707 r
F P
0 g
s
.43467 .64313 m .43748 .66126 L .40675 .66329 L p .707 .577 .707 r
F P
0 g
s
.40675 .66329 m .40394 .64516 L .43467 .64313 L p .707 .577 .707 r
F P
0 g
s
.37241 .65032 m .37522 .66846 L .34596 .67625 L p .707 .577 .707 r
F P
0 g
s
.37522 .66846 m .37241 .65032 L .40394 .64516 L p .707 .577 .707 r
F P
0 g
s
.40394 .64516 m .40675 .66329 L .37522 .66846 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001POolA0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001FOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol005=oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
4Goo2@00BWoo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02goo1P0015YF00<0
05YFFUH00UYF2@00@Goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01goo1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo001COol01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00=goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomo
o`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<003Aoo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001oo`000004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH00000<Woo001BOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000`Ool0059oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP8002moo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;goo001BOol01@00
FUIJEUYF00000eYF1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Woo001BOol01P00FUIJEUYF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEPH000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000;Woo001BOol01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000^Ool0059oo`04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH0009JEP03001J
EUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000;Woo001BOol01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00004@001UYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH01000FUIJEUYF200015YF00<0
05YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0002ioo`00Dgoo0`0015YF00<005YFFUH0
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0100000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH0000^Ool005Eoo`80009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH80006Ool50006Ool60005FUH00`00FUIJEP03FUH00`00FUH0000^Ool005Moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
0080009JEP04001JEUYFFUH<0008Ool50005Ool;00000eYF001JEP04FUH00`00FUH0000^Ool005Io
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUH000020007FUH01000FUIJEUYF4P0015YF00<005YFFUH015YF0P00
1EYF00<005YF0000;Woo000lOolJ00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P000UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YF0000
00=JEP03001JEP0002ioo`00>7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800004FUH005YF000^
Ool003Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH0100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP00Ool0;Goo000`Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00800003
FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool002ioo`<000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUH00000;Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF1P0015YF0`001eYF00<0
05YFFUH01P001EYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool0
1000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00<005YFFUH01@000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH01UYF
100000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEP0001T000IJEP03001JEUYF00=J
EP04001JEUYF000^Ool002eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF009JEP@000=JEP80009JEP03001JEUYF00=J
EPD000IJEP03001JEUYF00IJEP<00003FUH0000000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH01P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPP000EJEP04001JEUYF000^Ool002eoo`04001JEUYF0005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001J
EP000080009JEP03001JEUYF009JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00H000AJ
EP05001JEP00001JEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF100000EJEP00FUIJEP0002ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF2P000UYF0P000UYF00<0
05YFFUH015YF0`0000=JEP0000002P0000=JEP00FUH015YF00@005YFFUIJEP<000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPD002moo`00;Goo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP07001JEUYF001JEP00
FUH00P001EYF00<005YFFUH00UYF5@0015YF00@005YFFUIJEPP000AJEP8000EJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
008002moo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02ioo`00;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP800003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP02FUH00`00FUIJEP030006FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000]Ool01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEQH0009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00D005YFFUIJEP0000AJEP03001J
EUYF00AJEQP000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05001J
EUYFFUH00004FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000015YF0000
00001eYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
15YF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80003Ool500000goo0000000=0004FUH0
1000FUIJEUYF0P00;Woo000]Ool01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH0
1UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF8@000eYF00<005YFFUH00`00
00=JEP00FUH00UYF0P00;Woo000]Ool01000FUIJEUYF0`0000=JEP00FUH01EYF00@005YFFUIJEPl0
00IJEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00@000IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP8002ioo`00;Goo00@005YF000000AJEP03
001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEPL000EJEP04001JEUYFFUH30004FUH0
0`00FUIJEP06FUH30002FUH7000:FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003000^Ool0
02eoo`800003FUH005YF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00EJEP04001JEP000003FUHB0005FUH00`00FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF
009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP0015YF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF1P000UYF00<005YF00000UYF00<005YF
FUH00eYF1@001UYF00<005YFFUH02EYF0P0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo
00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0002FUH30005FUH300001EYF001JEUYF00001EYF1@001UYF00<005YFFUH01EYF100000=JEP00
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000^Ool60005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH30007FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEP000002FUH00`00FUIJEP04
FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP06FUH01000FUIJEP001eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF0000031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF100015YF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF
00MJEP<000=JEP03001JEUYF00EJEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002ioo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00006FUH00000001JEP001UYF00@005YF
FUH0009JEP03001JEUYF00AJEP04001JEUYFFUH60006FUH00`00FUIJEP04FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP05FUHO000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00004FUH005YFFUH700001EYF001JEUYF0000
0UYF00<005YF0000200015YF00<005YFFUH01UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEQ4000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP<00003FUH005YF00AJEP04
001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000aJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH60002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80009Ool70002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJ
EP02FUH6000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool20004FUH00`00FUH00002
0007Ool@0009Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=J
EP03001JEUYF008002eoo`00;Goo0P000eYF0`0017oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
10001goo0`0000=JEP00FUH01UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHB0007FUH00`00FUIJEP04FUH8000]Ool002eoo`800004FUH0
0000FUH20002Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool>0004
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`<000=JEP04001JEP00
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030002Ool40000
0eYF000000020002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEPT000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000bOol002eoo`8000AJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJ
EP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF4000>7oo000]Ool20003FUH2
0006FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH30003FUH01000FUIJEP000UYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF7`00B7oo000]Ool200001EYF000005YF00001EYF
1P000UYF00<005YFFUH00UYF40001UYF00<005YFFUH00P0000EJEP00FUIJEP00009JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`<000=J
EP04001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00
FUIJEP02FUH20002FUH01000FUIJEP001UYF00<005YFFUH01eYF00@005YFFUIJEPH000IJEP03001J
EUYF00YJEP03001JEUYF00T000MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH2001COol002ioo`8000=JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH200001EYF
001JEUYF00001UYF00<005YFFUH01EYF1`002eYF00<005YFFUH02UYF00<005YFFUH02EYF1@000UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00L005YFFUIJEP00
FUH0001BOol002ioo`8000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo0P000UYF
0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo1P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF100000=JEP00FUH00eYF1@000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
001BOol002eoo`8000=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYF001JEP020006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
15YF00<007ooOol00Woo10001EYF00L005YFFUIJEP00FUH0001BOol002eoo`03001oogoo00Aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP800004Ool005YF0002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH01000Oomoogoo2@0000=JEP00
FUH00UYF0P00Dgoo000/Ool2000:Ool30006FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH0
0`00FUH000020003Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF1`0015YF
00<005YFFUH00UYF0P000eYF0P00Dgoo000/Ool2000=Ool40002FUH00`00FUIJEP03FUH50007FUH0
0`00FUIJEP02FUH50007Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF
00<005YFFUH00eYF0`0000=JEP000000Dgoo000/Ool3000@OolI000=Ool00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF00<005YFFUH00eYF00<005YFFUH00`00Dgoo
000/Ool200000eYF001oo`0FOol5000IOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP001eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000/Ool20002FUH00`00
Oomoo`0EOol3000JOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
1eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000]Ool01@00FUIJEUYF0000<Woo0P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P001EYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0DWoo000]Ool01000FUIJEUYF0`00<7oo00<005YF00000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH0100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00;Woo
00@005YFFUH0009JEP03001oogoo02aoo`800006FUH00000001JEP001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH015YF0`0015YF00@005YF000005Ioo`00;goo00<005YF00000eYF0P00:Woo0P0000=J
EP0000000goo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF0`0000AJEP00000005Qo
o`00<7oo0P001EYF0P009Woo0P000eYF0P0017oo0P001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF
00EJEP03001JEUYF008005Yoo`00<Goo00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00
FUH00UYF00<007ooOol01Goo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00002@001EYF00<005YFFUH00eYF0P00F7oo000b
Ool20003FUH00`00FUIJEP03FUH4000FOol40005FUH01000FUIJEP0037oo1@0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10002Woo100000=JEP00FUH01EYF
0`00EWoo000dOol01000FUIJEP001eYF00<005YF00000`003Woo10000UYF00<005YFFUH00eYF00@0
05YF0000019oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000ioo`8000IJEP04001JEUYF001EOol003Eoo`<000MJEP03001JEUYF00=JEPh000IJEP03001J
EUYF00=JEP8001Yoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`8000=J
EP05001JEUYFFUH0001EOol003Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP8002=ooaX0009JEP@000Ioo`D0019oo`800003FUH005YF009JEP8005Ao
o`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=7oo
0P0015YF00<005YFFUH01EYF00<005YFFUH010000goo0`005Goo0P000UYF00<005YF0000E7oo000m
Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000iOol300000eYF001JEP06FUH00`00FUIJ
EP04FUH7000FOol300000eYF001oo`1COol004=ooa80049oo`<000EJEP03001JEUYF00MJEP03001J
EUYF009JEPP000Qoo`H0009JEP8005Eoo`00VWoo0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEPP000=JEP03001JEUYF009JEP8005Eoo`00W7oo0P0000=JEP00FUH01eYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009ioo`H000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Eo
o`00Y7oo2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000EWoo002]Ool80004
FUH01000FUIJEUYF1P00FWoo002eOol8001POol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59154 .75043 m .58983 .69505 L .55931 .69328 L p .707 .577 .707 r
F P
0 g
s
.58983 .69505 m .59154 .75043 L .62349 .74939 L p .707 .577 .707 r
F P
0 g
s
.62349 .74939 m .62178 .69401 L .58983 .69505 L p .707 .577 .707 r
F P
0 g
s
.62178 .69401 m .62349 .74939 L .65374 .74565 L p .707 .577 .707 r
F P
0 g
s
.65374 .74565 m .65203 .69027 L .62178 .69401 L p .707 .577 .707 r
F P
0 g
s
.56102 .74866 m .55931 .69328 L .53319 .68888 L p .707 .577 .707 r
F P
0 g
s
.55931 .69328 m .56102 .74866 L .59154 .75043 L p .707 .577 .707 r
F P
0 g
s
.65203 .69027 m .65374 .74565 L .67932 .73958 L p .707 .577 .707 r
F P
0 g
s
.67932 .73958 m .67761 .6842 L .65203 .69027 L p .707 .577 .707 r
F P
0 g
s
.61487 .80877 m .61598 .77163 L .5841 .77019 L p .707 .577 .707 r
F P
0 g
s
.61598 .77163 m .61487 .80877 L .64584 .80761 L p .707 .577 .707 r
F P
0 g
s
.64584 .80761 m .64696 .77047 L .61598 .77163 L p .707 .577 .707 r
F P
0 g
s
.58298 .80733 m .5841 .77019 L .55443 .76628 L p .707 .577 .707 r
F P
0 g
s
.5841 .77019 m .58298 .80733 L .61487 .80877 L p .707 .577 .707 r
F P
0 g
s
.53319 .68888 m .5349 .74425 L .56102 .74866 L p .707 .577 .707 r
F P
0 g
s
.5349 .74425 m .53319 .68888 L .51405 .68227 L p .707 .577 .707 r
F P
0 g
s
.67761 .6842 m .67932 .73958 L .69774 .73176 L p .707 .577 .707 r
F P
0 g
s
.69774 .73176 m .69603 .67638 L .67761 .6842 L p .707 .577 .707 r
F P
0 g
s
.64696 .77047 m .64584 .80761 L .67288 .80395 L p .707 .577 .707 r
F P
0 g
s
.67288 .80395 m .674 .76682 L .64696 .77047 L p .707 .577 .707 r
F P
0 g
s
.55443 .76628 m .55331 .80342 L .58298 .80733 L p .707 .577 .707 r
F P
0 g
s
.55331 .80342 m .55443 .76628 L .52988 .7603 L p .707 .577 .707 r
F P
0 g
s
.60663 .8492 m .60848 .83061 L .57686 .82678 L p .707 .577 .707 r
F P
0 g
s
.60848 .83061 m .60663 .8492 L .63779 .85059 L p .707 .577 .707 r
F P
0 g
s
.63779 .85059 m .63965 .832 L .60848 .83061 L p .707 .577 .707 r
F P
0 g
s
.57501 .84537 m .57686 .82678 L .54788 .8209 L p .707 .577 .707 r
F P
0 g
s
.57686 .82678 m .57501 .84537 L .60663 .8492 L p .707 .577 .707 r
F P
0 g
s
.51405 .68227 m .51576 .73765 L .5349 .74425 L p .707 .577 .707 r
F P
0 g
s
.63965 .832 m .63779 .85059 L .66545 .84942 L p .707 .577 .707 r
F P
0 g
s
.66545 .84942 m .66731 .83083 L .63965 .832 L p .707 .577 .707 r
F P
0 g
s
.54788 .8209 m .54603 .83949 L .57501 .84537 L p .707 .577 .707 r
F P
0 g
s
.52988 .7603 m .52876 .79744 L .55331 .80342 L p .707 .577 .707 r
F P
0 g
s
.674 .76682 m .67288 .80395 L .69333 .79817 L p .707 .577 .707 r
F P
0 g
s
.69333 .79817 m .69445 .76103 L .674 .76682 L p .707 .577 .707 r
F P
0 g
s
.54603 .83949 m .54788 .8209 L .52438 .81354 L p .707 .577 .707 r
F P
0 g
s
.51576 .73765 m .51405 .68227 L .50375 .67412 L p .707 .577 .707 r
F P
0 g
s
.69603 .67638 m .69774 .73176 L .70718 .72296 L p .707 .577 .707 r
F P
0 g
s
.70718 .72296 m .70547 .66758 L .69603 .67638 L p .707 .577 .707 r
F P
0 g
s
.52876 .79744 m .52988 .7603 L .51285 .75282 L p .707 .577 .707 r
F P
0 g
s
.52438 .81354 m .52252 .83213 L .54603 .83949 L p .707 .577 .707 r
F P
0 g
s
.66731 .83083 m .66545 .84942 L .6869 .8458 L p .707 .577 .707 r
F P
0 g
s
.6869 .8458 m .68876 .82721 L .66731 .83083 L p .707 .577 .707 r
F P
0 g
s
.51285 .75282 m .51173 .78996 L .52876 .79744 L p .707 .577 .707 r
F P
0 g
s
.50375 .67412 m .50546 .72949 L .51576 .73765 L p .707 .577 .707 r
F P
0 g
s
.69445 .76103 m .69333 .79817 L .70519 .79082 L p .707 .577 .707 r
F P
0 g
s
.70519 .79082 m .70631 .75368 L .69445 .76103 L p .707 .577 .707 r
F P
0 g
s
.52252 .83213 m .52438 .81354 L .50866 .80542 L p .707 .577 .707 r
F P
0 g
s
.50866 .80542 m .5068 .824 L .52252 .83213 L p .707 .577 .707 r
F P
0 g
s
.51173 .78996 m .51285 .75282 L .505 .74458 L p .707 .577 .707 r
F P
0 g
s
.50546 .72949 m .50375 .67412 L .5033 .6652 L p .708 .578 .707 r
F P
0 g
s
.70547 .66758 m .70718 .72296 L .70673 .71404 L p .708 .578 .707 r
F P
0 g
s
.70673 .71404 m .70502 .65867 L .70547 .66758 L p .708 .578 .707 r
F P
0 g
s
.68876 .82721 m .6869 .8458 L .70004 .84007 L p .707 .577 .707 r
F P
0 g
s
.70004 .84007 m .70189 .82149 L .68876 .82721 L p .707 .577 .707 r
F P
0 g
s
.505 .74458 m .50388 .78172 L .51173 .78996 L p .707 .577 .707 r
F P
0 g
s
.5033 .6652 m .50501 .72058 L .50546 .72949 L p .708 .578 .707 r
F P
0 g
s
.5068 .824 m .50866 .80542 L .50225 .79733 L p .707 .577 .707 r
F P
0 g
s
.70631 .75368 m .70519 .79082 L .7073 .78262 L p .707 .577 .707 r
F P
0 g
s
.7073 .78262 m .70842 .74548 L .70631 .75368 L p .707 .577 .707 r
F P
0 g
s
.48624 .82175 m .48624 .31986 L .44255 .31683 L p .707 .577 .707 r
F P
0 g
s
.50225 .79733 m .5004 .81592 L .5068 .824 L p .707 .577 .707 r
F P
0 g
s
.50388 .78172 m .505 .74458 L .50711 .73638 L p .707 .577 .707 r
F P
0 g
s
.50501 .72058 m .5033 .6652 L .51274 .65641 L p .707 .577 .707 r
F P
0 g
s
.50711 .73638 m .506 .77352 L .50388 .78172 L p .707 .577 .707 r
F P
0 g
s
.51274 .65641 m .51445 .71178 L .50501 .72058 L p .707 .577 .707 r
F P
0 g
s
.5004 .81592 m .50225 .79733 L .50579 .79007 L p .707 .577 .707 r
F P
0 g
s
.50579 .79007 m .50393 .80866 L .5004 .81592 L p .707 .577 .707 r
F P
0 g
s
.506 .77352 m .50711 .73638 L .51897 .72903 L p .707 .577 .707 r
F P
0 g
s
.51445 .71178 m .51274 .65641 L .53116 .64859 L p .707 .577 .707 r
F P
0 g
s
.51897 .72903 m .51786 .76617 L .506 .77352 L p .707 .577 .707 r
F P
0 g
s
.53116 .64859 m .53287 .70396 L .51445 .71178 L p .707 .577 .707 r
F P
0 g
s
.50393 .80866 m .50579 .79007 L .51893 .78435 L p .707 .577 .707 r
F P
0 g
s
.51893 .78435 m .51707 .80294 L .50393 .80866 L p .707 .577 .707 r
F P
0 g
s
.51786 .76617 m .51897 .72903 L .53942 .72325 L p .707 .577 .707 r
F P
0 g
s
.53942 .72325 m .53831 .76039 L .51786 .76617 L p .707 .577 .707 r
F P
0 g
s
.51707 .80294 m .51893 .78435 L .54037 .78072 L p .707 .577 .707 r
F P
0 g
s
.54037 .78072 m .53852 .79931 L .51707 .80294 L p .707 .577 .707 r
F P
0 g
s
.48624 .31986 m .48624 .82175 L .53129 .821 L p .707 .577 .707 r
F P
0 g
s
.53287 .70396 m .53116 .64859 L .55674 .64251 L p .707 .577 .707 r
F P
0 g
s
.53129 .821 m .53129 .31911 L .48624 .31986 L p .707 .577 .707 r
F P
0 g
s
.55674 .64251 m .55845 .69789 L .53287 .70396 L p .707 .577 .707 r
F P
0 g
s
.55845 .69789 m .55674 .64251 L .58699 .63877 L p .707 .577 .707 r
F P
0 g
s
.53831 .76039 m .53942 .72325 L .56646 .7196 L p .707 .577 .707 r
F P
0 g
s
.58699 .63877 m .5887 .69415 L .55845 .69789 L p .707 .577 .707 r
F P
0 g
s
.56646 .7196 m .56534 .75674 L .53831 .76039 L p .707 .577 .707 r
F P
0 g
s
.56534 .75674 m .56646 .7196 L .59743 .71843 L p .707 .577 .707 r
F P
0 g
s
.53852 .79931 m .54037 .78072 L .56804 .77955 L p .707 .577 .707 r
F P
0 g
s
.56804 .77955 m .56618 .79814 L .53852 .79931 L p .707 .577 .707 r
F P
0 g
s
.59743 .71843 m .59632 .75557 L .56534 .75674 L p .707 .577 .707 r
F P
0 g
s
.56618 .79814 m .56804 .77955 L .5992 .78095 L p .707 .577 .707 r
F P
0 g
s
.5992 .78095 m .59735 .79954 L .56618 .79814 L p .707 .577 .707 r
F P
0 g
s
.53129 .31911 m .53129 .821 L .57327 .81656 L p .707 .577 .707 r
F P
0 g
s
.57327 .81656 m .57327 .31467 L .53129 .31911 L p .707 .577 .707 r
F P
0 g
s
.44255 .81872 m .44255 .31683 L .40447 .31033 L p .707 .577 .707 r
F P
0 g
s
.44255 .31683 m .44255 .81872 L .48624 .82175 L p .707 .577 .707 r
F P
0 g
s
.70189 .82149 m .70004 .84007 L .70358 .83281 L p .707 .577 .707 r
F P
0 g
s
.70358 .83281 m .70543 .81423 L .70189 .82149 L p .707 .577 .707 r
F P
0 g
s
.70502 .65867 m .70673 .71404 L .69643 .70589 L p .707 .577 .707 r
F P
0 g
s
.69643 .70589 m .69472 .65051 L .70502 .65867 L p .707 .577 .707 r
F P
0 g
s
.5887 .69415 m .58699 .63877 L .61894 .63773 L p .707 .577 .707 r
F P
0 g
s
.61894 .63773 m .62065 .69311 L .5887 .69415 L p .707 .577 .707 r
F P
0 g
s
.62932 .71988 m .6282 .75701 L .59632 .75557 L p .707 .577 .707 r
F P
0 g
s
.59632 .75557 m .59743 .71843 L .62932 .71988 L p .707 .577 .707 r
F P
0 g
s
.63082 .78477 m .62897 .80336 L .59735 .79954 L p .707 .577 .707 r
F P
0 g
s
.59735 .79954 m .5992 .78095 L .63082 .78477 L p .707 .577 .707 r
F P
0 g
s
.57327 .31467 m .57327 .81656 L .60808 .80885 L p .707 .577 .707 r
F P
0 g
s
.60808 .80885 m .60808 .30696 L .57327 .31467 L p .707 .577 .707 r
F P
0 g
s
.24671 .71036 m .246 .65432 L .21546 .65244 L p .707 .577 .707 r
F P
0 g
s
.246 .65432 m .24671 .71036 L .27867 .70987 L p .707 .577 .707 r
F P
0 g
s
.27867 .70987 m .27796 .65383 L .246 .65432 L p .707 .577 .707 r
F P
0 g
s
.27796 .65383 m .27867 .70987 L .30893 .70706 L p .707 .577 .707 r
F P
0 g
s
.30893 .70706 m .30822 .65102 L .27796 .65383 L p .707 .577 .707 r
F P
0 g
s
.70842 .74548 m .7073 .78262 L .69946 .77438 L p .707 .577 .707 r
F P
0 g
s
.69946 .77438 m .70057 .73724 L .70842 .74548 L p .707 .577 .707 r
F P
0 g
s
.40447 .81222 m .40447 .31033 L .37575 .30099 L p .707 .577 .707 r
F P
0 g
s
.40447 .31033 m .40447 .81222 L .44255 .81872 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21617 .70849 m .21546 .65244 L .18934 .64838 L p .707 .577 .707 r
F P
0 g
s
.21546 .65244 m .21617 .70849 L .24671 .71036 L p .707 .577 .707 r
F P
0 g
s
.30822 .65102 m .30893 .70706 L .33452 .70221 L p .707 .577 .707 r
F P
0 g
s
.33452 .70221 m .33381 .64617 L .30822 .65102 L p .707 .577 .707 r
F P
0 g
s
.69472 .65051 m .69643 .70589 L .67728 .69928 L p .707 .577 .707 r
F P
0 g
s
.67728 .69928 m .67557 .64391 L .69472 .65051 L p .707 .577 .707 r
F P
0 g
s
.70543 .81423 m .70358 .83281 L .69717 .82473 L p .707 .577 .707 r
F P
0 g
s
.69717 .82473 m .69903 .80614 L .70543 .81423 L p .707 .577 .707 r
F P
0 g
s
.64946 .6395 m .65117 .69488 L .62065 .69311 L p .707 .577 .707 r
F P
0 g
s
.62065 .69311 m .61894 .63773 L .64946 .6395 L p .707 .577 .707 r
F P
0 g
s
.65899 .72378 m .65787 .76092 L .6282 .75701 L p .707 .577 .707 r
F P
0 g
s
.6282 .75701 m .62932 .71988 L .65899 .72378 L p .707 .577 .707 r
F P
0 g
s
.62897 .80336 m .63082 .78477 L .6598 .79066 L p .707 .577 .707 r
F P
0 g
s
.60808 .30696 m .60808 .80885 L .63231 .79863 L p .707 .577 .707 r
F P
0 g
s
.63231 .79863 m .63231 .29675 L .60808 .30696 L p .707 .577 .707 r
F P
0 g
s
.27036 .77709 m .27081 .74041 L .23891 .73943 L p .707 .577 .707 r
F P
0 g
s
.27081 .74041 m .27036 .77709 L .30135 .77507 L p .707 .577 .707 r
F P
0 g
s
.30135 .77507 m .30179 .73839 L .27081 .74041 L p .707 .577 .707 r
F P
0 g
s
.23847 .77611 m .23891 .73943 L .20923 .73553 L p .707 .577 .707 r
F P
0 g
s
.23891 .73943 m .23847 .77611 L .27036 .77709 L p .707 .577 .707 r
F P
0 g
s
.18934 .64838 m .19005 .70443 L .21617 .70849 L p .707 .577 .707 r
F P
0 g
s
.19005 .70443 m .18934 .64838 L .17018 .64254 L p .707 .577 .707 r
F P
0 g
s
.30179 .73839 m .30135 .77507 L .32839 .77024 L p .707 .577 .707 r
F P
0 g
s
.32839 .77024 m .32883 .73355 L .30179 .73839 L p .707 .577 .707 r
F P
0 g
s
.33381 .64617 m .33452 .70221 L .35293 .69579 L p .707 .577 .707 r
F P
0 g
s
.35293 .69579 m .35222 .63975 L .33381 .64617 L p .707 .577 .707 r
F P
0 g
s
.70057 .73724 m .69946 .77438 L .68243 .7669 L p .707 .577 .707 r
F P
0 g
s
.68243 .7669 m .68354 .72976 L .70057 .73724 L p .707 .577 .707 r
F P
0 g
s
.20878 .77221 m .20923 .73553 L .18466 .72911 L p .707 .577 .707 r
F P
0 g
s
.20923 .73553 m .20878 .77221 L .23847 .77611 L p .707 .577 .707 r
F P
0 g
s
.67557 .64391 m .67728 .69928 L .65117 .69488 L p .707 .577 .707 r
F P
0 g
s
.65117 .69488 m .64946 .6395 L .67557 .64391 L p .707 .577 .707 r
F P
0 g
s
.37575 .80288 m .37575 .30099 L .35919 .28973 L p .707 .577 .707 r
F P
0 g
s
.37575 .30099 m .37575 .80288 L .40447 .81222 L p .707 .577 .707 r
F P
0 g
s
.17018 .64254 m .17089 .69858 L .19005 .70443 L p .707 .577 .707 r
F P
0 g
s
.26446 .82611 m .26518 .80833 L .23343 .80592 L p .707 .577 .707 r
F P
0 g
s
.26518 .80833 m .26446 .82611 L .29574 .82471 L p .707 .577 .707 r
F P
0 g
s
.29574 .82471 m .29645 .80693 L .26518 .80833 L p .707 .577 .707 r
F P
0 g
s
.69903 .80614 m .69717 .82473 L .68145 .81661 L p .707 .577 .707 r
F P
0 g
s
.68145 .81661 m .6833 .79802 L .69903 .80614 L p .707 .577 .707 r
F P
0 g
s
.32883 .73355 m .32839 .77024 L .34884 .76307 L p .707 .577 .707 r
F P
0 g
s
.34884 .76307 m .34928 .72639 L .32883 .73355 L p .707 .577 .707 r
F P
0 g
s
.18466 .72911 m .18422 .76579 L .20878 .77221 L p .707 .577 .707 r
F P
0 g
s
.23271 .82369 m .23343 .80592 L .2043 .79993 L p .707 .577 .707 r
F P
0 g
s
.23343 .80592 m .23271 .82369 L .26446 .82611 L p .707 .577 .707 r
F P
0 g
s
.29645 .80693 m .29574 .82471 L .32347 .81964 L p .707 .577 .707 r
F P
0 g
s
.32347 .81964 m .32419 .80186 L .29645 .80693 L p .707 .577 .707 r
F P
0 g
s
.17089 .69858 m .17018 .64254 L .15987 .63548 L p .707 .577 .707 r
F P
0 g
s
.2043 .79993 m .20358 .8177 L .23271 .82369 L p .707 .577 .707 r
F P
0 g
s
.18422 .76579 m .18466 .72911 L .16762 .72078 L p .707 .577 .707 r
F P
0 g
s
.63231 .29675 m .63231 .79863 L .64359 .78691 L p .707 .577 .707 r
F P
0 g
s
.64359 .78691 m .64359 .28502 L .63231 .29675 L p .707 .577 .707 r
F P
0 g
s
.35222 .63975 m .35293 .69579 L .36237 .68843 L p .707 .577 .707 r
F P
0 g
s
.36237 .68843 m .36167 .63238 L .35222 .63975 L p .707 .577 .707 r
F P
0 g
s
.68354 .72976 m .68243 .7669 L .65787 .76092 L p .707 .577 .707 r
F P
0 g
s
.65787 .76092 m .65899 .72378 L .68354 .72976 L p .707 .577 .707 r
F P
0 g
s
.20358 .8177 m .2043 .79993 L .18064 .79094 L p .707 .577 .707 r
F P
0 g
s
.32419 .80186 m .32347 .81964 L .34494 .81138 L p .707 .577 .707 r
F P
0 g
s
.34494 .81138 m .34566 .7936 L .32419 .80186 L p .707 .577 .707 r
F P
0 g
s
.18064 .79094 m .17993 .80872 L .20358 .8177 L p .707 .577 .707 r
F P
0 g
s
.16762 .72078 m .16717 .75746 L .18422 .76579 L p .707 .577 .707 r
F P
0 g
s
.15987 .63548 m .16058 .69152 L .17089 .69858 L p .707 .577 .707 r
F P
0 g
s
.34928 .72639 m .34884 .76307 L .3607 .75427 L p .707 .577 .707 r
F P
0 g
s
.3607 .75427 m .36114 .71758 L .34928 .72639 L p .707 .577 .707 r
F P
0 g
s
.6833 .79802 m .68145 .81661 L .65795 .80924 L p .707 .577 .707 r
F P
0 g
s
.65795 .80924 m .6598 .79066 L .6833 .79802 L p .707 .577 .707 r
F P
0 g
s
.17993 .80872 m .18064 .79094 L .16479 .77985 L p .707 .577 .707 r
F P
0 g
s
.16717 .75746 m .16762 .72078 L .15976 .71137 L p .707 .577 .707 r
F P
0 g
s
.35877 .78298 m .35805 .80075 L .36152 .78879 L p .707 .577 .707 r
F P
0 g
s
.36152 .78879 m .36224 .77102 L .35877 .78298 L p .707 .577 .707 r
F P
0 g
s
.36121 .6248 m .36192 .68085 L .35161 .67379 L p .707 .577 .707 r
F P
0 g
s
.35161 .67379 m .3509 .61774 L .36121 .6248 L p .707 .577 .707 r
F P
0 g
s
.36114 .71758 m .3607 .75427 L .36281 .74469 L p .707 .577 .707 r
F P
0 g
s
.36281 .74469 m .36325 .70801 L .36114 .71758 L p .707 .577 .707 r
F P
0 g
s
.36325 .70801 m .36281 .74469 L .35495 .73528 L p .707 .577 .707 r
F P
0 g
s
.35495 .73528 m .3554 .6986 L .36325 .70801 L p .707 .577 .707 r
F P
0 g
s
.35805 .80075 m .35877 .78298 L .34566 .7936 L p .707 .577 .707 r
F P
0 g
s
.36224 .77102 m .36152 .78879 L .35501 .77668 L p .707 .577 .707 r
F P
0 g
s
.35501 .77668 m .35573 .7589 L .36224 .77102 L p .707 .577 .707 r
F P
0 g
s
.35919 .79161 m .35919 .28973 L .35641 .27764 L p .707 .577 .707 r
F P
0 g
s
.36167 .63238 m .36237 .68843 L .36192 .68085 L p .708 .578 .707 r
F P
0 g
s
.36192 .68085 m .36121 .6248 L .36167 .63238 L p .708 .578 .707 r
F P
0 g
s
.35919 .28973 m .35919 .79161 L .37575 .80288 L p .707 .577 .707 r
F P
0 g
s
.16058 .69152 m .15987 .63548 L .15941 .62789 L p .708 .578 .707 r
F P
0 g
s
.16479 .77985 m .16407 .79763 L .17993 .80872 L p .707 .577 .707 r
F P
0 g
s
.34566 .7936 m .34494 .81138 L .35805 .80075 L p .707 .577 .707 r
F P
0 g
s
.15976 .71137 m .15932 .74805 L .16717 .75746 L p .707 .577 .707 r
F P
0 g
s
.6598 .79066 m .65795 .80924 L .62897 .80336 L p .707 .577 .707 r
F P
0 g
s
.15941 .62789 m .16012 .68394 L .16058 .69152 L p .708 .578 .707 r
F P
0 g
s
.64359 .28502 m .64359 .78691 L .64081 .77482 L p .707 .577 .707 r
F P
0 g
s
.64081 .77482 m .64081 .27293 L .64359 .28502 L p .707 .577 .707 r
F P
0 g
s
.16407 .79763 m .16479 .77985 L .15827 .76773 L p .707 .577 .707 r
F P
0 g
s
.15932 .74805 m .15976 .71137 L .16187 .7018 L p .707 .577 .707 r
F P
0 g
s
.15827 .76773 m .15756 .78551 L .16407 .79763 L p .707 .577 .707 r
F P
0 g
s
.16012 .68394 m .15941 .62789 L .16886 .62053 L p .707 .577 .707 r
F P
0 g
s
.16187 .7018 m .16143 .73848 L .15932 .74805 L p .707 .577 .707 r
F P
0 g
s
.35641 .27764 m .35641 .77953 L .35919 .79161 L p .707 .577 .707 r
F P
0 g
s
.35641 .77953 m .35641 .27764 L .36769 .26591 L p .707 .577 .707 r
F P
0 g
s
.16886 .62053 m .16956 .67658 L .16012 .68394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15756 .78551 m .15827 .76773 L .16174 .75577 L p .707 .577 .707 r
F P
0 g
s
.16174 .75577 m .16102 .77355 L .15756 .78551 L p .707 .577 .707 r
F P
0 g
s
.16143 .73848 m .16187 .7018 L .17373 .693 L p .707 .577 .707 r
F P
0 g
s
.64081 .27293 m .64081 .77482 L .62425 .76356 L p .707 .577 .707 r
F P
0 g
s
.62425 .76356 m .62425 .26167 L .64081 .27293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16956 .67658 m .16886 .62053 L .18727 .61411 L p .707 .577 .707 r
F P
0 g
s
.3509 .61774 m .35161 .67379 L .33245 .66794 L p .707 .577 .707 r
F P
0 g
s
.33245 .66794 m .33174 .6119 L .3509 .61774 L p .707 .577 .707 r
F P
0 g
s
.17373 .693 m .17329 .72968 L .16143 .73848 L p .707 .577 .707 r
F P
0 g
s
.18727 .61411 m .18798 .67015 L .16956 .67658 L p .707 .577 .707 r
F P
0 g
s
.3554 .6986 m .35495 .73528 L .33791 .72696 L p .707 .577 .707 r
F P
0 g
s
.33791 .72696 m .33835 .69028 L .3554 .6986 L p .707 .577 .707 r
F P
0 g
s
.16102 .77355 m .16174 .75577 L .17485 .74514 L p .707 .577 .707 r
F P
0 g
s
.36769 .7678 m .36769 .26591 L .39192 .2557 L p .707 .577 .707 r
F P
0 g
s
.36769 .26591 m .36769 .7678 L .35641 .77953 L p .707 .577 .707 r
F P
0 g
s
.17329 .72968 m .17373 .693 L .19418 .68583 L p .707 .577 .707 r
F P
0 g
s
.18798 .67015 m .18727 .61411 L .21286 .60926 L p .707 .577 .707 r
F P
0 g
s
.17485 .74514 m .17414 .76292 L .16102 .77355 L p .707 .577 .707 r
F P
0 g
s
.33174 .6119 m .33245 .66794 L .30633 .66388 L p .707 .577 .707 r
F P
0 g
s
.30633 .66388 m .30562 .60784 L .33174 .6119 L p .707 .577 .707 r
F P
0 g
s
.35573 .7589 m .35501 .77668 L .33915 .76558 L p .707 .577 .707 r
F P
0 g
s
.33915 .76558 m .33987 .7478 L .35573 .7589 L p .707 .577 .707 r
F P
0 g
s
.19418 .68583 m .19374 .72251 L .17329 .72968 L p .707 .577 .707 r
F P
0 g
s
.62425 .26167 m .62425 .76356 L .59553 .75422 L p .707 .577 .707 r
F P
0 g
s
.59553 .75422 m .59553 .25233 L .62425 .26167 L p .707 .577 .707 r
F P
0 g
s
.21286 .60926 m .21357 .6653 L .18798 .67015 L p .707 .577 .707 r
F P
0 g
s
.33835 .69028 m .33791 .72696 L .31334 .72053 L p .707 .577 .707 r
F P
0 g
s
.31334 .72053 m .31379 .68385 L .33835 .69028 L p .707 .577 .707 r
F P
0 g
s
.21357 .6653 m .21286 .60926 L .24312 .60645 L p .707 .577 .707 r
F P
0 g
s
.30562 .60784 m .30633 .66388 L .27579 .662 L p .707 .577 .707 r
F P
0 g
s
.27579 .662 m .27508 .60596 L .30562 .60784 L p .707 .577 .707 r
F P
0 g
s
.17414 .76292 m .17485 .74514 L .19633 .73689 L p .707 .577 .707 r
F P
0 g
s
.19374 .72251 m .19418 .68583 L .22122 .681 L p .707 .577 .707 r
F P
0 g
s
.19633 .73689 m .19561 .75467 L .17414 .76292 L p .707 .577 .707 r
F P
0 g
s
.24383 .66249 m .24312 .60645 L .27508 .60596 L p .707 .577 .707 r
F P
0 g
s
.24312 .60645 m .24383 .66249 L .21357 .6653 L p .707 .577 .707 r
F P
0 g
s
.27508 .60596 m .27579 .662 L .24383 .66249 L p .707 .577 .707 r
F P
0 g
s
.33987 .7478 m .33915 .76558 L .3155 .7566 L p .707 .577 .707 r
F P
0 g
s
.3155 .7566 m .31622 .73882 L .33987 .7478 L p .707 .577 .707 r
F P
0 g
s
.39192 .2557 m .39192 .75759 L .36769 .7678 L p .707 .577 .707 r
F P
0 g
s
.39192 .75759 m .39192 .2557 L .42673 .24799 L p .707 .577 .707 r
F P
0 g
s
.31379 .68385 m .31334 .72053 L .28366 .71664 L p .707 .577 .707 r
F P
0 g
s
.28366 .71664 m .2841 .67996 L .31379 .68385 L p .707 .577 .707 r
F P
0 g
s
.22122 .681 m .22078 .71768 L .19374 .72251 L p .707 .577 .707 r
F P
0 g
s
.72421 .65928 m .72492 .60423 L .69438 .60104 L p .707 .577 .707 r
F P
0 g
s
.72492 .60423 m .72421 .65928 L .75617 .65952 L p .707 .577 .707 r
F P
0 g
s
.75617 .65952 m .75688 .60446 L .72492 .60423 L p .707 .577 .707 r
F P
0 g
s
.75688 .60446 m .75617 .65952 L .78643 .65679 L p .707 .577 .707 r
F P
0 g
s
.78643 .65679 m .78714 .60173 L .75688 .60446 L p .707 .577 .707 r
F P
0 g
s
.22078 .71768 m .22122 .681 L .25221 .67897 L p .707 .577 .707 r
F P
0 g
s
.19561 .75467 m .19633 .73689 L .22406 .73181 L p .707 .577 .707 r
F P
0 g
s
.69367 .6561 m .69438 .60104 L .66826 .59523 L p .707 .577 .707 r
F P
0 g
s
.69438 .60104 m .69367 .6561 L .72421 .65928 L p .707 .577 .707 r
F P
0 g
s
.2841 .67996 m .28366 .71664 L .25176 .71565 L p .707 .577 .707 r
F P
0 g
s
.25176 .71565 m .25221 .67897 L .2841 .67996 L p .707 .577 .707 r
F P
0 g
s
.78714 .60173 m .78643 .65679 L .81202 .65136 L p .707 .577 .707 r
F P
0 g
s
.81202 .65136 m .81273 .59631 L .78714 .60173 L p .707 .577 .707 r
F P
0 g
s
.59553 .25233 m .59553 .75422 L .55745 .74772 L p .707 .577 .707 r
F P
0 g
s
.55745 .74772 m .55745 .24583 L .59553 .25233 L p .707 .577 .707 r
F P
0 g
s
.25221 .67897 m .25176 .71565 L .22078 .71768 L p .707 .577 .707 r
F P
0 g
s
.31622 .73882 m .3155 .7566 L .28637 .75061 L p .707 .577 .707 r
F P
0 g
s
.28637 .75061 m .28709 .73283 L .31622 .73882 L p .707 .577 .707 r
F P
0 g
s
.22406 .73181 m .22334 .74959 L .19561 .75467 L p .707 .577 .707 r
F P
0 g
s
.74823 .71361 m .74779 .67623 L .7159 .67609 L p .707 .577 .707 r
F P
0 g
s
.74779 .67623 m .74823 .71361 L .77922 .71141 L p .707 .577 .707 r
F P
0 g
s
.77922 .71141 m .77878 .67403 L .74779 .67623 L p .707 .577 .707 r
F P
0 g
s
.22334 .74959 m .22406 .73181 L .25533 .73041 L p .707 .577 .707 r
F P
0 g
s
.71634 .71347 m .7159 .67609 L .68621 .67363 L p .707 .577 .707 r
F P
0 g
s
.7159 .67609 m .71634 .71347 L .74823 .71361 L p .707 .577 .707 r
F P
0 g
s
.66826 .59523 m .66755 .65028 L .69367 .6561 L p .707 .577 .707 r
F P
0 g
s
.28709 .73283 m .28637 .75061 L .25461 .74819 L p .707 .577 .707 r
F P
0 g
s
.25461 .74819 m .25533 .73041 L .28709 .73283 L p .707 .577 .707 r
F P
0 g
s
.66755 .65028 m .66826 .59523 L .6491 .58735 L p .707 .577 .707 r
F P
0 g
s
.42673 .74988 m .42673 .24799 L .46871 .24355 L p .707 .577 .707 r
F P
0 g
s
.42673 .24799 m .42673 .74988 L .39192 .75759 L p .707 .577 .707 r
F P
0 g
s
.81273 .59631 m .81202 .65136 L .83043 .64377 L p .707 .577 .707 r
F P
0 g
s
.83043 .64377 m .83114 .58871 L .81273 .59631 L p .707 .577 .707 r
F P
0 g
s
.25533 .73041 m .25461 .74819 L .22334 .74959 L p .707 .577 .707 r
F P
0 g
s
.77878 .67403 m .77922 .71141 L .80626 .7071 L p .707 .577 .707 r
F P
0 g
s
.80626 .7071 m .80582 .66971 L .77878 .67403 L p .707 .577 .707 r
F P
0 g
s
.68621 .67363 m .68666 .71101 L .71634 .71347 L p .707 .577 .707 r
F P
0 g
s
.55745 .24583 m .55745 .74772 L .51375 .74469 L p .707 .577 .707 r
F P
0 g
s
.51375 .74469 m .51375 .2428 L .55745 .24583 L p .707 .577 .707 r
F P
0 g
s
.74538 .74794 m .74467 .72895 L .71291 .72959 L p .707 .577 .707 r
F P
0 g
s
.74467 .72895 m .74538 .74794 L .77666 .7458 L p .707 .577 .707 r
F P
0 g
s
.77666 .7458 m .77594 .7268 L .74467 .72895 L p .707 .577 .707 r
F P
0 g
s
.68666 .71101 m .68621 .67363 L .66165 .66909 L p .707 .577 .707 r
F P
0 g
s
.71291 .72959 m .71363 .74858 L .74538 .74794 L p .707 .577 .707 r
F P
0 g
s
.71363 .74858 m .71291 .72959 L .68378 .72866 L p .707 .577 .707 r
F P
0 g
s
.77594 .7268 m .77666 .7458 L .80439 .74235 L p .707 .577 .707 r
F P
0 g
s
.80439 .74235 m .80367 .72335 L .77594 .7268 L p .707 .577 .707 r
F P
0 g
s
.68378 .72866 m .6845 .74765 L .71363 .74858 L p .707 .577 .707 r
F P
0 g
s
.46871 .74544 m .46871 .24355 L .51375 .2428 L p .707 .577 .707 r
F P
0 g
s
.46871 .24355 m .46871 .74544 L .42673 .74988 L p .707 .577 .707 r
F P
0 g
s
.6491 .58735 m .64839 .64241 L .66755 .65028 L p .707 .577 .707 r
F P
0 g
s
.66165 .66909 m .66209 .70647 L .68666 .71101 L p .707 .577 .707 r
F P
0 g
s
.51375 .2428 m .51375 .74469 L .46871 .74544 L p .707 .577 .707 r
F P
0 g
s
.80582 .66971 m .80626 .7071 L .82671 .70108 L p .707 .577 .707 r
F P
0 g
s
.82671 .70108 m .82627 .6637 L .80582 .66971 L p .707 .577 .707 r
F P
0 g
s
.64839 .64241 m .6491 .58735 L .63879 .57819 L p .707 .577 .707 r
F P
0 g
s
.6845 .74765 m .68378 .72866 L .66013 .72625 L p .707 .577 .707 r
F P
0 g
s
.83114 .58871 m .83043 .64377 L .83988 .63474 L p .707 .577 .707 r
F P
0 g
s
.83988 .63474 m .84058 .57969 L .83114 .58871 L p .707 .577 .707 r
F P
0 g
s
.66013 .72625 m .66085 .74524 L .6845 .74765 L p .707 .577 .707 r
F P
0 g
s
.66209 .70647 m .66165 .66909 L .6446 .66291 L p .707 .577 .707 r
F P
0 g
s
.80367 .72335 m .80439 .74235 L .82586 .73794 L p .707 .577 .707 r
F P
0 g
s
.82586 .73794 m .82514 .71895 L .80367 .72335 L p .707 .577 .707 r
F P
0 g
s
.6446 .66291 m .64504 .70029 L .66209 .70647 L p .707 .577 .707 r
F P
0 g
s
.63879 .57819 m .63808 .63324 L .64839 .64241 L p .707 .577 .707 r
F P
0 g
s
.82627 .6637 m .82671 .70108 L .83857 .69396 L p .707 .577 .707 r
F P
0 g
s
.83857 .69396 m .83813 .65658 L .82627 .6637 L p .707 .577 .707 r
F P
0 g
s
.66085 .74524 m .66013 .72625 L .64427 .72259 L p .707 .577 .707 r
F P
0 g
s
.64427 .72259 m .64499 .74158 L .66085 .74524 L p .707 .577 .707 r
F P
0 g
s
.82514 .71895 m .82586 .73794 L .83897 .733 L p .707 .577 .707 r
F P
0 g
s
.83897 .733 m .83826 .71401 L .82514 .71895 L p .707 .577 .707 r
F P
0 g
s
.63808 .63324 m .63879 .57819 L .63833 .56862 L p .707 .578 .707 r
F P
0 g
s
.64504 .70029 m .6446 .66291 L .63675 .6557 L p .707 .577 .707 r
F P
0 g
s
.84058 .57969 m .83988 .63474 L .83942 .62518 L p .707 .578 .707 r
F P
0 g
s
.83942 .62518 m .84013 .57013 L .84058 .57969 L p .707 .578 .707 r
F P
0 g
s
.63675 .6557 m .63719 .69308 L .64504 .70029 L p .707 .577 .707 r
F P
0 g
s
.63833 .56862 m .63762 .62368 L .63808 .63324 L p .707 .578 .707 r
F P
0 g
s
.83813 .65658 m .83857 .69396 L .84068 .68643 L p .707 .577 .707 r
F P
0 g
s
.84068 .68643 m .84023 .64905 L .83813 .65658 L p .707 .577 .707 r
F P
0 g
s
.64499 .74158 m .64427 .72259 L .63776 .71805 L p .707 .577 .707 r
F P
0 g
s
.63776 .71805 m .63847 .73704 L .64499 .74158 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83826 .71401 m .83897 .733 L .84244 .72802 L p .707 .577 .707 r
F P
0 g
s
.84244 .72802 m .84173 .70902 L .83826 .71401 L p .707 .577 .707 r
F P
0 g
s
.63762 .62368 m .63833 .56862 L .64777 .5596 L p .707 .577 .707 r
F P
0 g
s
.63719 .69308 m .63675 .6557 L .63885 .64817 L p .707 .577 .707 r
F P
0 g
s
.84013 .57013 m .83942 .62518 L .82911 .61601 L p .707 .577 .707 r
F P
0 g
s
.82911 .61601 m .82982 .56096 L .84013 .57013 L p .707 .577 .707 r
F P
0 g
s
.63885 .64817 m .6393 .68555 L .63719 .69308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64777 .5596 m .64707 .61466 L .63762 .62368 L p .707 .577 .707 r
F P
0 g
s
.37935 .61924 m .38106 .56351 L .35054 .5602 L p .707 .577 .707 r
F P
0 g
s
.38106 .56351 m .37935 .61924 L .4113 .62004 L p .707 .577 .707 r
F P
0 g
s
.4113 .62004 m .41301 .56431 L .38106 .56351 L p .707 .577 .707 r
F P
0 g
s
.41301 .56431 m .4113 .62004 L .44155 .61825 L p .707 .577 .707 r
F P
0 g
s
.44155 .61825 m .44326 .56252 L .41301 .56431 L p .707 .577 .707 r
F P
0 g
s
.84023 .64905 m .84068 .68643 L .83282 .67922 L p .707 .577 .707 r
F P
0 g
s
.83282 .67922 m .83238 .64184 L .84023 .64905 L p .707 .577 .707 r
F P
0 g
s
.63847 .73704 m .63776 .71805 L .64123 .71306 L p .707 .577 .707 r
F P
0 g
s
.64123 .71306 m .64194 .73206 L .63847 .73704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.34883 .61593 m .35054 .5602 L .32442 .55471 L p .707 .577 .707 r
F P
0 g
s
.35054 .5602 m .34883 .61593 L .37935 .61924 L p .707 .577 .707 r
F P
0 g
s
.64707 .61466 m .64777 .5596 L .66619 .55201 L p .707 .577 .707 r
F P
0 g
s
.84173 .70902 m .84244 .72802 L .83593 .72347 L p .707 .577 .707 r
F P
0 g
s
.83593 .72347 m .83521 .70448 L .84173 .70902 L p .707 .577 .707 r
F P
0 g
s
.44326 .56252 m .44155 .61825 L .46713 .61406 L p .707 .577 .707 r
F P
0 g
s
.46713 .61406 m .46884 .55833 L .44326 .56252 L p .707 .577 .707 r
F P
0 g
s
.82982 .56096 m .82911 .61601 L .80995 .60814 L p .707 .577 .707 r
F P
0 g
s
.80995 .60814 m .81066 .55308 L .82982 .56096 L p .707 .577 .707 r
F P
0 g
s
.6393 .68555 m .63885 .64817 L .65071 .64105 L p .707 .577 .707 r
F P
0 g
s
.40368 .68197 m .40256 .64503 L .37068 .64534 L p .707 .577 .707 r
F P
0 g
s
.40256 .64503 m .40368 .68197 L .43465 .67893 L p .707 .577 .707 r
F P
0 g
s
.43465 .67893 m .43354 .64199 L .40256 .64503 L p .707 .577 .707 r
F P
0 g
s
.65071 .64105 m .65116 .67843 L .6393 .68555 L p .707 .577 .707 r
F P
0 g
s
.3718 .68227 m .37068 .64534 L .34101 .64287 L p .707 .577 .707 r
F P
0 g
s
.37068 .64534 m .3718 .68227 L .40368 .68197 L p .707 .577 .707 r
F P
0 g
s
.32442 .55471 m .32271 .61044 L .34883 .61593 L p .707 .577 .707 r
F P
0 g
s
.32271 .61044 m .32442 .55471 L .30528 .54758 L p .707 .577 .707 r
F P
0 g
s
.66619 .55201 m .66548 .60706 L .64707 .61466 L p .707 .577 .707 r
F P
0 g
s
.43354 .64199 m .43465 .67893 L .46169 .67344 L p .707 .577 .707 r
F P
0 g
s
.46169 .67344 m .46057 .6365 L .43354 .64199 L p .707 .577 .707 r
F P
0 g
s
.46884 .55833 m .46713 .61406 L .48555 .60786 L p .707 .577 .707 r
F P
0 g
s
.48555 .60786 m .48726 .55213 L .46884 .55833 L p .707 .577 .707 r
F P
0 g
s
.83238 .64184 m .83282 .67922 L .81578 .67304 L p .707 .577 .707 r
F P
0 g
s
.81578 .67304 m .81534 .63566 L .83238 .64184 L p .707 .577 .707 r
F P
0 g
s
.64194 .73206 m .64123 .71306 L .65434 .70812 L p .707 .577 .707 r
F P
0 g
s
.34101 .64287 m .34212 .6798 L .3718 .68227 L p .707 .577 .707 r
F P
0 g
s
.34212 .6798 m .34101 .64287 L .31645 .63787 L p .707 .577 .707 r
F P
0 g
s
.66548 .60706 m .66619 .55201 L .69178 .54658 L p .707 .577 .707 r
F P
0 g
s
.65434 .70812 m .65506 .72712 L .64194 .73206 L p .707 .577 .707 r
F P
0 g
s
.81066 .55308 m .80995 .60814 L .78383 .60232 L p .707 .577 .707 r
F P
0 g
s
.78383 .60232 m .78454 .54727 L .81066 .55308 L p .707 .577 .707 r
F P
0 g
s
.40265 .72529 m .4008 .70701 L .36917 .70888 L p .707 .577 .707 r
F P
0 g
s
.4008 .70701 m .40265 .72529 L .43382 .72049 L p .707 .577 .707 r
F P
0 g
s
.43382 .72049 m .43196 .70221 L .4008 .70701 L p .707 .577 .707 r
F P
0 g
s
.30528 .54758 m .30357 .60331 L .32271 .61044 L p .707 .577 .707 r
F P
0 g
s
.83521 .70448 m .83593 .72347 L .82007 .71982 L p .707 .577 .707 r
F P
0 g
s
.82007 .71982 m .81935 .70082 L .83521 .70448 L p .707 .577 .707 r
F P
0 g
s
.65116 .67843 m .65071 .64105 L .67116 .63503 L p .707 .577 .707 r
F P
0 g
s
.37103 .72716 m .36917 .70888 L .3402 .70764 L p .707 .577 .707 r
F P
0 g
s
.36917 .70888 m .37103 .72716 L .40265 .72529 L p .707 .577 .707 r
F P
0 g
s
.46057 .6365 m .46169 .67344 L .48214 .66604 L p .707 .577 .707 r
F P
0 g
s
.48214 .66604 m .48102 .62911 L .46057 .6365 L p .707 .577 .707 r
F P
0 g
s
.43196 .70221 m .43382 .72049 L .46148 .71323 L p .707 .577 .707 r
F P
0 g
s
.46148 .71323 m .45962 .69495 L .43196 .70221 L p .707 .577 .707 r
F P
0 g
s
.31645 .63787 m .31757 .67481 L .34212 .6798 L p .707 .577 .707 r
F P
0 g
s
.3402 .70764 m .34205 .72591 L .37103 .72716 L p .707 .577 .707 r
F P
0 g
s
.30357 .60331 m .30528 .54758 L .29498 .5395 L p .707 .577 .707 r
F P
0 g
s
.67116 .63503 m .67161 .67241 L .65116 .67843 L p .707 .577 .707 r
F P
0 g
s
.69178 .54658 m .69107 .60163 L .66548 .60706 L p .707 .577 .707 r
F P
0 g
s
.69107 .60163 m .69178 .54658 L .72204 .54385 L p .707 .577 .707 r
F P
0 g
s
.31757 .67481 m .31645 .63787 L .29942 .63083 L p .707 .577 .707 r
F P
0 g
s
.48726 .55213 m .48555 .60786 L .49499 .60027 L p .707 .577 .707 r
F P
0 g
s
.49499 .60027 m .4967 .54454 L .48726 .55213 L p .707 .577 .707 r
F P
0 g
s
.78454 .54727 m .78383 .60232 L .75329 .59914 L p .707 .577 .707 r
F P
0 g
s
.75329 .59914 m .754 .54409 L .78454 .54727 L p .707 .577 .707 r
F P
0 g
s
.34205 .72591 m .3402 .70764 L .31669 .7034 L p .707 .577 .707 r
F P
0 g
s
.81534 .63566 m .81578 .67304 L .79121 .6685 L p .707 .577 .707 r
F P
0 g
s
.79121 .6685 m .79077 .63112 L .81534 .63566 L p .707 .577 .707 r
F P
0 g
s
.45962 .69495 m .46148 .71323 L .48293 .70422 L p .707 .577 .707 r
F P
0 g
s
.48293 .70422 m .48107 .68594 L .45962 .69495 L p .707 .577 .707 r
F P
0 g
s
.65506 .72712 m .65434 .70812 L .67581 .70372 L p .707 .577 .707 r
F P
0 g
s
.31669 .7034 m .31855 .72168 L .34205 .72591 L p .707 .577 .707 r
F P
0 g
s
.72133 .5989 m .72204 .54385 L .754 .54409 L p .707 .577 .707 r
F P
0 g
s
.72204 .54385 m .72133 .5989 L .69107 .60163 L p .707 .577 .707 r
F P
0 g
s
.754 .54409 m .75329 .59914 L .72133 .5989 L p .707 .577 .707 r
F P
0 g
s
.67581 .70372 m .67653 .72271 L .65506 .72712 L p .707 .577 .707 r
F P
0 g
s
.29942 .63083 m .30054 .66777 L .31757 .67481 L p .707 .577 .707 r
F P
0 g
s
.29498 .5395 m .29327 .59523 L .30357 .60331 L p .707 .577 .707 r
F P
0 g
s
.67161 .67241 m .67116 .63503 L .69821 .63072 L p .707 .577 .707 r
F P
0 g
s
.48102 .62911 m .48214 .66604 L .494 .65747 L p .707 .577 .707 r
F P
0 g
s
.494 .65747 m .49288 .62053 L .48102 .62911 L p .707 .577 .707 r
F P
0 g
s
.81935 .70082 m .82007 .71982 L .79642 .71741 L p .707 .577 .707 r
F P
0 g
s
.79642 .71741 m .7957 .69841 L .81935 .70082 L p .707 .577 .707 r
F P
0 g
s
.69821 .63072 m .69865 .6681 L .67161 .67241 L p .707 .577 .707 r
F P
0 g
s
.79077 .63112 m .79121 .6685 L .76153 .66604 L p .707 .577 .707 r
F P
0 g
s
.76153 .66604 m .76109 .62866 L .79077 .63112 L p .707 .577 .707 r
F P
0 g
s
.31855 .72168 m .31669 .7034 L .30097 .69659 L p .707 .577 .707 r
F P
0 g
s
.29327 .59523 m .29498 .5395 L .29453 .53126 L p .707 .578 .707 r
F P
0 g
s
.48107 .68594 m .48293 .70422 L .49606 .69435 L p .707 .577 .707 r
F P
0 g
s
.49606 .69435 m .49421 .67607 L .48107 .68594 L p .707 .577 .707 r
F P
0 g
s
.30054 .66777 m .29942 .63083 L .29158 .62244 L p .707 .577 .707 r
F P
0 g
s
.69865 .6681 m .69821 .63072 L .72919 .62852 L p .707 .577 .707 r
F P
0 g
s
.30097 .69659 m .30283 .71487 L .31855 .72168 L p .707 .577 .707 r
F P
0 g
s
.4967 .54454 m .49499 .60027 L .49454 .59203 L p .707 .578 .707 r
F P
0 g
s
.49454 .59203 m .49625 .5363 L .4967 .54454 L p .707 .578 .707 r
F P
0 g
s
.67653 .72271 m .67581 .70372 L .70354 .70027 L p .707 .577 .707 r
F P
0 g
s
.70354 .70027 m .70426 .71926 L .67653 .72271 L p .707 .577 .707 r
F P
0 g
s
.76109 .62866 m .76153 .66604 L .72963 .6659 L p .707 .577 .707 r
F P
0 g
s
.72963 .6659 m .72919 .62852 L .76109 .62866 L p .707 .577 .707 r
F P
0 g
s
.7957 .69841 m .79642 .71741 L .76729 .71647 L p .707 .577 .707 r
F P
0 g
s
.76729 .71647 m .76657 .69748 L .7957 .69841 L p .707 .577 .707 r
F P
0 g
s
.72919 .62852 m .72963 .6659 L .69865 .6681 L p .707 .577 .707 r
F P
0 g
s
.29158 .62244 m .29269 .65938 L .30054 .66777 L p .707 .577 .707 r
F P
0 g
s
.29453 .53126 m .29282 .58699 L .29327 .59523 L p .707 .578 .707 r
F P
0 g
s
.49288 .62053 m .494 .65747 L .49611 .64855 L p .707 .577 .707 r
F P
0 g
s
.49611 .64855 m .495 .61161 L .49288 .62053 L p .707 .577 .707 r
F P
0 g
s
.70426 .71926 m .70354 .70027 L .73482 .69812 L p .707 .577 .707 r
F P
0 g
s
.76657 .69748 m .76729 .71647 L .73553 .71711 L p .707 .577 .707 r
F P
0 g
s
.73553 .71711 m .73482 .69812 L .76657 .69748 L p .707 .577 .707 r
F P
0 g
s
.73482 .69812 m .73553 .71711 L .70426 .71926 L p .707 .577 .707 r
F P
0 g
s
.30283 .71487 m .30097 .69659 L .29456 .68787 L p .707 .577 .707 r
F P
0 g
s
.49421 .67607 m .49606 .69435 L .4996 .68457 L p .707 .577 .707 r
F P
0 g
s
.4996 .68457 m .49775 .66629 L .49421 .67607 L p .707 .577 .707 r
F P
0 g
s
.29269 .65938 m .29158 .62244 L .29369 .61352 L p .707 .577 .707 r
F P
0 g
s
.29456 .68787 m .29642 .70615 L .30283 .71487 L p .707 .577 .707 r
F P
0 g
s
.29282 .58699 m .29453 .53126 L .30397 .52367 L p .707 .577 .707 r
F P
0 g
s
.49625 .5363 m .49454 .59203 L .48424 .58395 L p .707 .577 .707 r
F P
0 g
s
.48424 .58395 m .48595 .52822 L .49625 .5363 L p .707 .577 .707 r
F P
0 g
s
.29369 .61352 m .29481 .65046 L .29269 .65938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30397 .52367 m .30226 .5794 L .29282 .58699 L p .707 .577 .707 r
F P
0 g
s
.495 .61161 m .49611 .64855 L .48827 .64016 L p .707 .577 .707 r
F P
0 g
s
.48827 .64016 m .48715 .60322 L .495 .61161 L p .707 .577 .707 r
F P
0 g
s
.29642 .70615 m .29456 .68787 L .2981 .6781 L p .707 .577 .707 r
F P
0 g
s
.49775 .66629 m .4996 .68457 L .4932 .67585 L p .707 .577 .707 r
F P
0 g
s
.4932 .67585 m .49134 .65757 L .49775 .66629 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30226 .5794 m .30397 .52367 L .32239 .51747 L p .707 .577 .707 r
F P
0 g
s
.2981 .6781 m .29996 .69637 L .29642 .70615 L p .707 .577 .707 r
F P
0 g
s
.29481 .65046 m .29369 .61352 L .30555 .60495 L p .707 .577 .707 r
F P
0 g
s
.48595 .52822 m .48424 .58395 L .46509 .57681 L p .707 .577 .707 r
F P
0 g
s
.46509 .57681 m .4668 .52108 L .48595 .52822 L p .707 .577 .707 r
F P
0 g
s
.30555 .60495 m .30667 .64188 L .29481 .65046 L p .707 .577 .707 r
F P
0 g
s
.32239 .51747 m .32068 .5732 L .30226 .5794 L p .707 .577 .707 r
F P
0 g
s
.48715 .60322 m .48827 .64016 L .47124 .63312 L p .707 .577 .707 r
F P
0 g
s
.47124 .63312 m .47012 .59618 L .48715 .60322 L p .707 .577 .707 r
F P
0 g
s
.29996 .69637 m .2981 .6781 L .31124 .66822 L p .707 .577 .707 r
F P
0 g
s
.32068 .5732 m .32239 .51747 L .34797 .51328 L p .707 .577 .707 r
F P
0 g
s
.49134 .65757 m .4932 .67585 L .47747 .66904 L p .707 .577 .707 r
F P
0 g
s
.47747 .66904 m .47562 .65076 L .49134 .65757 L p .707 .577 .707 r
F P
0 g
s
.4668 .52108 m .46509 .57681 L .43898 .57133 L p .707 .577 .707 r
F P
0 g
s
.43898 .57133 m .44069 .5156 L .4668 .52108 L p .707 .577 .707 r
F P
0 g
s
.30667 .64188 m .30555 .60495 L .326 .59755 L p .707 .577 .707 r
F P
0 g
s
.31124 .66822 m .31309 .6865 L .29996 .69637 L p .707 .577 .707 r
F P
0 g
s
.326 .59755 m .32712 .63449 L .30667 .64188 L p .707 .577 .707 r
F P
0 g
s
.34797 .51328 m .34626 .56901 L .32068 .5732 L p .707 .577 .707 r
F P
0 g
s
.47012 .59618 m .47124 .63312 L .44668 .62812 L p .707 .577 .707 r
F P
0 g
s
.44668 .62812 m .44557 .59119 L .47012 .59618 L p .707 .577 .707 r
F P
0 g
s
.34626 .56901 m .34797 .51328 L .37822 .51149 L p .707 .577 .707 r
F P
0 g
s
.44069 .5156 m .43898 .57133 L .40846 .56802 L p .707 .577 .707 r
F P
0 g
s
.40846 .56802 m .41017 .51229 L .44069 .5156 L p .707 .577 .707 r
F P
0 g
s
.31309 .6865 m .31124 .66822 L .33269 .65921 L p .707 .577 .707 r
F P
0 g
s
.32712 .63449 m .326 .59755 L .35304 .59206 L p .707 .577 .707 r
F P
0 g
s
.37651 .56722 m .37822 .51149 L .41017 .51229 L p .707 .577 .707 r
F P
0 g
s
.37822 .51149 m .37651 .56722 L .34626 .56901 L p .707 .577 .707 r
F P
0 g
s
.47562 .65076 m .47747 .66904 L .45397 .66481 L p .707 .577 .707 r
F P
0 g
s
.45397 .66481 m .45212 .64653 L .47562 .65076 L p .707 .577 .707 r
F P
0 g
s
.41017 .51229 m .40846 .56802 L .37651 .56722 L p .707 .577 .707 r
F P
0 g
s
.33269 .65921 m .33454 .67749 L .31309 .6865 L p .707 .577 .707 r
F P
0 g
s
.44557 .59119 m .44668 .62812 L .41701 .62565 L p .707 .577 .707 r
F P
0 g
s
.41701 .62565 m .4159 .58872 L .44557 .59119 L p .707 .577 .707 r
F P
0 g
s
.35304 .59206 m .35415 .629 L .32712 .63449 L p .707 .577 .707 r
F P
0 g
s
.35415 .629 m .35304 .59206 L .38401 .58902 L p .707 .577 .707 r
F P
0 g
s
.4159 .58872 m .41701 .62565 L .38513 .62596 L p .707 .577 .707 r
F P
0 g
s
.38513 .62596 m .38401 .58902 L .4159 .58872 L p .707 .577 .707 r
F P
0 g
s
.33454 .67749 m .33269 .65921 L .36035 .65196 L p .707 .577 .707 r
F P
0 g
s
.38401 .58902 m .38513 .62596 L .35415 .629 L p .707 .577 .707 r
F P
0 g
s
.45212 .64653 m .45397 .66481 L .42499 .66356 L p .707 .577 .707 r
F P
0 g
s
.42499 .66356 m .42314 .64529 L .45212 .64653 L p .707 .577 .707 r
F P
0 g
s
.36035 .65196 m .3622 .67023 L .33454 .67749 L p .707 .577 .707 r
F P
0 g
s
.3622 .67023 m .36035 .65196 L .39152 .64716 L p .707 .577 .707 r
F P
0 g
s
.42314 .64529 m .42499 .66356 L .39337 .66543 L p .707 .577 .707 r
F P
0 g
s
.39337 .66543 m .39152 .64716 L .42314 .64529 L p .707 .577 .707 r
F P
0 g
s
.39152 .64716 m .39337 .66543 L .3622 .67023 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo8@00O7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0065ooaT000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00GGoo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P002EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
05=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`0@OolA0013Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Woo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEPH003eoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00<003Uoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@003Eoo`00Dgoo00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001oogooOol200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000<goo001COol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@007oo000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000aOol005=oo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00Dgoo00<005YF0000
1EYF00<005YFFUH00eYF5`0015YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0002moo`00Dgoo00<005YF00001EYF00<005YF00000`000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00<005YFFUH00UYF00@005YFFUH0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00;Woo001COol00`00FUH00003FUH40006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`03001JEP0000<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`800003FUH005YF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
0005FUH005YFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002io
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJ
EP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH000AJEP03
001JEUYF00=JEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`04001JEUYF0004FUH60003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP00;Woo001DOol30003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005Ioo`@0009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000EJEP04001JEUYFFUH800000eYF0000000F0004FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo0011OolG0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEPD000AJEP03001JEUYF00IJEP03001JEP0000@0009J
EP03001JEUYF00EJEP03001JEUYF00D000AJEP04001JEUYF000^Ool003Uoo`P000AJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP08001JEUYFFUH005YF001JEP<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP04001JEUYF
000^Ool003Aoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080009JEP03001oogoo02aoo`00<Woo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<007ooOol0;7oo000`Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002ioo`00;Woo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00UYF00<005YFFUH015YF3`001eYF1`001EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP0500001EYF001JEUYF0000
1EYF1@001UYF00<005YFFUH015YF100000=JEP00FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH80004FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YF0000
;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP8000=JEP04001JEUYFFUH40004FUH00`00FUH00002FUH00`00FUIJEP03FUH50006FUH0
0`00FUIJEP08FUH30003FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH50003FUH00`00FUH0000^Ool002eoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
00000`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH00eYF
1@000eYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00006FUH00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008002moo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH30003FUH90002
FUH00`00FUIJEP04FUH30005FUH80003FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<002moo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUHN0005
FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000_Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUH000080004FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP020004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJ
EP00FUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03
001JEUYF00AJEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHE0004FUH00`00FUH000020007FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00@005YFFUIJEPP000AJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000=JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEPT000MJEP03
001JEP0000H000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP000eYF1@0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH00eYF1P001eYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH01@000UYF00<007ooOol01Goo
1@001goo20000eYF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01@00FUIJEP00FUH00P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YF0000
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF0P0000=JEP000000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YF
FUH02`0000=JEP00Ool01Woo1@0017oo2@000UYF1@000eYF00<005YF0000;Woo000]Ool00`00FUIJ
EP020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000eYF10001UYF00@005YFFUIJEQ8000AJEP03001JEUYF00EJEP04001JEUYF
FUH2000015YF001JEP00;Woo000]Ool40005FUH00`00FUIJEP04FUHH0004FUH01000FUIJEUYF2000
15YF00<005YFFUH00UYF40001eYF00<005YFFUH00eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001oo`0]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH01000FUH000000UYF00<005YFFUH00UYF3`001UYF00<005YFFUH02EYF00@005YFFUIJEP80
0004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000]Ool01000FUIJEP001EYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF1`0015YF0P000UYF00<005YFFUH00eYF
1@001UYF00<005YFFUH02EYF00@005YF000000AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;Goo00@005YFFUH0009JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEUYF001JEP000UYF0P001EYF0`000UYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH0
25YF0`0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000^Ool5
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00`0000=J
EP00FUH01EYF00<005YF00000`000UYF00<005YFFUH015YF0`001eYF00<005YFFUH01EYF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000_Ool30005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP@00003
FUH005YF00EJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHK0004FUH01000FUH00000;goo
000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP800004FUH000000006FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF1@00
1EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`00<Goo000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP@000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0;0003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000_Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF01L000IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@000=JEP03001JEUYF00AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP<002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000BOol400000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF00<005YFFUH00UYF20000goo1@002Goo3@000UYF00<005YF0000;Goo000]Ool01@00FUIJ
EUYF000015YF1@003Goo0`003Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP04001JEUYFFUH700001EYF001JEUYF00001Woo1@0037oo1`000UYF100000=JEP00
Ool0;7oo000]Ool01P00FUIJEUYF001JEP<0015oo`D0019ooaL000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH8
0004FUH00`00FUH00007Ool50003Ool90003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]
Ool01000FUIJEUYF0P0000=JEP0000003Woo2@004Woo0`000UYF0P000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800005FUH00000FUH00003FUHI0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool01000FUH000000eYF00<005YF00000`000Woo2000
15YF00<005YFFUH00UYF1P001goo1@000eYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;Goo0`0015YF00<005YF0000
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001P000eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
000`Ool002eoo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00;Goo00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<0
00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00H000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD003Moo`00;Goo00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEPH000MJEP03001J
EUYF00YJEPX000QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUHR000lOol0
02ioo`800003FUH005YF00AJEP03001JEUYF009JEPP000QJEPL000IJEP03001JEUYF00AJEP@00005
FUH005YFFUH00006FUH00`00FUIJEP05FUH7000<FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF00<005YF
0000Dgoo000]Ool01@00FUIJEUYF000015YF1P001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
0UYF00<005YFFUH015YF00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01@001UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF10001UYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00=JEP03001JEP0005=oo`00;Goo00H005YFFUIJEP00
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF1@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF
009JEP04001JEUYF001COol002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH01000FUIJEP00
0eYF0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF100000=JEP00FUH00eYF1P001EYF00<005YFFUH00UYF00@005YFFUH005=oo`00;Goo
00@005YFFUH0009oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000004FUH01@00FUIJEP00FUH00P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001o
ogoo00=oo`@00003FUH005YF00=JEP04001JEUYF001COol002eoo`<000Ioo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP80009JEP<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP80009JEP03001oogoo00=oo`L000=JEP04001JEUYF001COol002eoo`03
001oogoo00Yoo`D000AJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF009JEPD000=o
o`@00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH90003FUH01000FUIJEUYF0P0000EJEP00FUIJ
EP0005=oo`00;Goo0P0047oo6`002Woo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00P001eYF00<005YFFUH00eYF0P000UYF00<007ooOol0DGoo000/Ool00`00FUH0000HOol5000H
Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH0
0`00FUH00002001COol002aoo`03001JEP00008001Ioo`D001Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00=JEP03001JEUYF008005=oo`00;7oo00<0
05YF00000UYF0P005Goo0`006Goo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0P001eYF00<005YFFUH00eYF00@005YFFUH005Aoo`00;Goo0P0015YF0P00;Woo00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00FUH60002FUH00`00FUIJEP03FUH01000FUIJ
EP00E7oo000]Ool20004FUH01000FUH00000:goo00<005YFFUH00P000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P001UYF00<005YF00000`0015YF0`00EGoo000^Ool00`00FUIJEP02FUH01000FUIJ
EUYF0P009goo0`000UYF00<007oo00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00<0
05YFFUH00eYF0P0000=JEP000000Egoo000_Ool20002FUH00`00FUIJEP03FUH3000ROol20002FUH0
1000FUIJEP000Woo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH015YF0P00FGoo000aOol3
0006FUH00`00FUH00003000IOol50004FUH00`00FUH00005Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000060006FUH0
0`00FUIJEP04FUH01000FUH00000Egoo000cOol00`00FUIJEP04FUH00`00FUIJEP03FUHI0003FUH0
0`00FUIJEP03FUH20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`1DOol003Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00=JEPD000aoo`@000AJEP03001JEUYF009JEP8005Eoo`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8001Aoo`H0
009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<00003Ool00000
00<000moo`<00003FUH005YF00=JEP03001JEP0005Aoo`00>7oo10001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000001aoo`T000IJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000Eoo`D0019oo`<000=JEP03001JEP0005Aoo`00?7oo10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD002MooaT000aoo`D001Eoo`800004FUH005YF001DOol0041ooaP0
03Qoo`05001JEUYFFUH00006FUH00`00FUH000030009Ool3000HOol3001EOol0095oo`800003FUH0
05YF00EJEP03001JEUYF00=JEPL001Uoo`@00003FUH0000005Eoo`00Tgoo0`001EYF00<005YFFUH0
1EYF00<005YFFUH00UYF6@000UYF00<005YFFUH00P00EGoo002FOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EWoo002J
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00EWoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001GOol00:5oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
001IOol00:QooaT005aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60071 .7485 m .60249 .69273 L .57088 .69059 L p .707 .577 .707 r
F P
0 g
s
.60249 .69273 m .60071 .7485 L .63221 .74809 L p .707 .577 .707 r
F P
0 g
s
.63221 .74809 m .634 .69232 L .60249 .69273 L p .707 .577 .707 r
F P
0 g
s
.5691 .74637 m .57088 .69059 L .54227 .68612 L p .707 .577 .707 r
F P
0 g
s
.57088 .69059 m .5691 .74637 L .60071 .7485 L p .707 .577 .707 r
F P
0 g
s
.634 .69232 m .63221 .74809 L .66053 .74518 L p .707 .577 .707 r
F P
0 g
s
.66053 .74518 m .66232 .6894 L .634 .69232 L p .707 .577 .707 r
F P
0 g
s
.54048 .74189 m .54227 .68612 L .51945 .67975 L p .707 .577 .707 r
F P
0 g
s
.54227 .68612 m .54048 .74189 L .5691 .74637 L p .707 .577 .707 r
F P
0 g
s
.66232 .6894 m .66053 .74518 L .6829 .74005 L p .707 .577 .707 r
F P
0 g
s
.6829 .74005 m .68468 .68427 L .66232 .6894 L p .707 .577 .707 r
F P
0 g
s
.60948 .81143 m .60826 .77457 L .57638 .77494 L p .707 .577 .707 r
F P
0 g
s
.60826 .77457 m .60948 .81143 L .64046 .80826 L p .707 .577 .707 r
F P
0 g
s
.64046 .80826 m .63924 .7714 L .60826 .77457 L p .707 .577 .707 r
F P
0 g
s
.5776 .8118 m .57638 .77494 L .54672 .77246 L p .707 .577 .707 r
F P
0 g
s
.57638 .77494 m .5776 .8118 L .60948 .81143 L p .707 .577 .707 r
F P
0 g
s
.63924 .7714 m .64046 .80826 L .6675 .8026 L p .707 .577 .707 r
F P
0 g
s
.6675 .8026 m .66628 .76574 L .63924 .7714 L p .707 .577 .707 r
F P
0 g
s
.51945 .67975 m .51766 .73552 L .54048 .74189 L p .707 .577 .707 r
F P
0 g
s
.54672 .77246 m .54794 .80932 L .5776 .8118 L p .707 .577 .707 r
F P
0 g
s
.54794 .80932 m .54672 .77246 L .52218 .76739 L p .707 .577 .707 r
F P
0 g
s
.51766 .73552 m .51945 .67975 L .50466 .6721 L p .707 .577 .707 r
F P
0 g
s
.61753 .85569 m .61544 .83761 L .58367 .84064 L p .707 .577 .707 r
F P
0 g
s
.61544 .83761 m .61753 .85569 L .64797 .84956 L p .707 .577 .707 r
F P
0 g
s
.64797 .84956 m .64588 .83148 L .61544 .83761 L p .707 .577 .707 r
F P
0 g
s
.68468 .68427 m .6829 .74005 L .69711 .7332 L p .707 .577 .707 r
F P
0 g
s
.69711 .7332 m .6989 .67742 L .68468 .68427 L p .707 .577 .707 r
F P
0 g
s
.58576 .85872 m .58367 .84064 L .55368 .84029 L p .707 .577 .707 r
F P
0 g
s
.58367 .84064 m .58576 .85872 L .61753 .85569 L p .707 .577 .707 r
F P
0 g
s
.66628 .76574 m .6675 .8026 L .68796 .79499 L p .707 .577 .707 r
F P
0 g
s
.68796 .79499 m .68674 .75813 L .66628 .76574 L p .707 .577 .707 r
F P
0 g
s
.52218 .76739 m .5234 .80425 L .54794 .80932 L p .707 .577 .707 r
F P
0 g
s
.64588 .83148 m .64797 .84956 L .6741 .84095 L p .707 .577 .707 r
F P
0 g
s
.6741 .84095 m .67201 .82287 L .64588 .83148 L p .707 .577 .707 r
F P
0 g
s
.55368 .84029 m .55576 .85837 L .58576 .85872 L p .707 .577 .707 r
F P
0 g
s
.50466 .6721 m .50287 .72788 L .51766 .73552 L p .707 .577 .707 r
F P
0 g
s
.55576 .85837 m .55368 .84029 L .52841 .83658 L p .707 .577 .707 r
F P
0 g
s
.5234 .80425 m .52218 .76739 L .50516 .76021 L p .707 .577 .707 r
F P
0 g
s
.52841 .83658 m .53049 .85466 L .55576 .85837 L p .707 .577 .707 r
F P
0 g
s
.67201 .82287 m .6741 .84095 L .69336 .83068 L p .707 .577 .707 r
F P
0 g
s
.69336 .83068 m .69127 .8126 L .67201 .82287 L p .707 .577 .707 r
F P
0 g
s
.50287 .72788 m .50466 .6721 L .49934 .66393 L p .707 .577 .707 r
F P
0 g
s
.50516 .76021 m .50638 .79707 L .5234 .80425 L p .707 .577 .707 r
F P
0 g
s
.68674 .75813 m .68796 .79499 L .69984 .78619 L p .707 .577 .707 r
F P
0 g
s
.69984 .78619 m .69862 .74933 L .68674 .75813 L p .707 .577 .707 r
F P
0 g
s
.6989 .67742 m .69711 .7332 L .70179 .7253 L p .707 .577 .707 r
F P
0 g
s
.70179 .7253 m .70358 .66953 L .6989 .67742 L p .707 .577 .707 r
F P
0 g
s
.53049 .85466 m .52841 .83658 L .51032 .82989 L p .707 .577 .707 r
F P
0 g
s
.51032 .82989 m .5124 .84796 L .53049 .85466 L p .707 .577 .707 r
F P
0 g
s
.49934 .66393 m .49755 .71971 L .50287 .72788 L p .707 .577 .707 r
F P
0 g
s
.50638 .79707 m .50516 .76021 L .49734 .75164 L p .707 .577 .707 r
F P
0 g
s
.69127 .8126 m .69336 .83068 L .70386 .81978 L p .707 .577 .707 r
F P
0 g
s
.70386 .81978 m .70178 .8017 L .69127 .8126 L p .707 .577 .707 r
F P
0 g
s
.49734 .75164 m .49856 .7885 L .50638 .79707 L p .707 .577 .707 r
F P
0 g
s
.49755 .71971 m .49934 .66393 L .50402 .65604 L p .707 .577 .707 r
F P
0 g
s
.69862 .74933 m .69984 .78619 L .70197 .77706 L p .707 .577 .707 r
F P
0 g
s
.70197 .77706 m .70075 .7402 L .69862 .74933 L p .707 .577 .707 r
F P
0 g
s
.5124 .84796 m .51032 .82989 L .50119 .82086 L p .707 .577 .707 r
F P
0 g
s
.70358 .66953 m .70179 .7253 L .69647 .71713 L p .707 .577 .707 r
F P
0 g
s
.69647 .71713 m .69826 .66136 L .70358 .66953 L p .707 .577 .707 r
F P
0 g
s
.49464 .8219 m .49464 .32001 L .45036 .31767 L p .707 .577 .707 r
F P
0 g
s
.50119 .82086 m .50327 .83893 L .5124 .84796 L p .707 .577 .707 r
F P
0 g
s
.50402 .65604 m .50223 .71181 L .49755 .71971 L p .707 .577 .707 r
F P
0 g
s
.49856 .7885 m .49734 .75164 L .49946 .74251 L p .707 .577 .707 r
F P
0 g
s
.49946 .74251 m .50069 .77936 L .49856 .7885 L p .707 .577 .707 r
F P
0 g
s
.50223 .71181 m .50402 .65604 L .51823 .64919 L p .707 .577 .707 r
F P
0 g
s
.50327 .83893 m .50119 .82086 L .50191 .81037 L p .707 .577 .707 r
F P
0 g
s
.50191 .81037 m .504 .82845 L .50327 .83893 L p .707 .577 .707 r
F P
0 g
s
.51823 .64919 m .51645 .70496 L .50223 .71181 L p .707 .577 .707 r
F P
0 g
s
.50069 .77936 m .49946 .74251 L .51134 .73371 L p .707 .577 .707 r
F P
0 g
s
.51134 .73371 m .51256 .77056 L .50069 .77936 L p .707 .577 .707 r
F P
0 g
s
.51645 .70496 m .51823 .64919 L .5406 .64405 L p .707 .577 .707 r
F P
0 g
s
.504 .82845 m .50191 .81037 L .51242 .79947 L p .707 .577 .707 r
F P
0 g
s
.51242 .79947 m .5145 .81755 L .504 .82845 L p .707 .577 .707 r
F P
0 g
s
.5406 .64405 m .53881 .69983 L .51645 .70496 L p .707 .577 .707 r
F P
0 g
s
.51256 .77056 m .51134 .73371 L .5318 .7261 L p .707 .577 .707 r
F P
0 g
s
.5318 .7261 m .53302 .76296 L .51256 .77056 L p .707 .577 .707 r
F P
0 g
s
.5145 .81755 m .51242 .79947 L .53168 .7892 L p .707 .577 .707 r
F P
0 g
s
.53168 .7892 m .53376 .80728 L .5145 .81755 L p .707 .577 .707 r
F P
0 g
s
.53302 .76296 m .5318 .7261 L .55885 .72044 L p .707 .577 .707 r
F P
0 g
s
.55885 .72044 m .56007 .7573 L .53302 .76296 L p .707 .577 .707 r
F P
0 g
s
.53376 .80728 m .53168 .7892 L .55781 .78059 L p .707 .577 .707 r
F P
0 g
s
.55781 .78059 m .55989 .79867 L .53376 .80728 L p .707 .577 .707 r
F P
0 g
s
.49464 .32001 m .49464 .8219 L .53944 .82045 L p .707 .577 .707 r
F P
0 g
s
.53881 .69983 m .5406 .64405 L .56892 .64114 L p .707 .577 .707 r
F P
0 g
s
.56892 .64114 m .56713 .69692 L .53881 .69983 L p .707 .577 .707 r
F P
0 g
s
.53944 .82045 m .53944 .31856 L .49464 .32001 L p .707 .577 .707 r
F P
0 g
s
.56713 .69692 m .56892 .64114 L .60042 .64073 L p .707 .577 .707 r
F P
0 g
s
.60042 .64073 m .59864 .69651 L .56713 .69692 L p .707 .577 .707 r
F P
0 g
s
.56007 .7573 m .55885 .72044 L .58982 .71727 L p .707 .577 .707 r
F P
0 g
s
.58982 .71727 m .59105 .75412 L .56007 .7573 L p .707 .577 .707 r
F P
0 g
s
.55989 .79867 m .55781 .78059 L .58825 .77446 L p .707 .577 .707 r
F P
0 g
s
.58825 .77446 m .59033 .79254 L .55989 .79867 L p .707 .577 .707 r
F P
0 g
s
.53944 .31856 m .53944 .82045 L .58039 .81536 L p .707 .577 .707 r
F P
0 g
s
.58039 .81536 m .58039 .31347 L .53944 .31856 L p .707 .577 .707 r
F P
0 g
s
.45035 .81956 m .45036 .31767 L .41093 .31178 L p .707 .577 .707 r
F P
0 g
s
.45036 .31767 m .45035 .81956 L .49464 .8219 L p .707 .577 .707 r
F P
0 g
s
.70178 .8017 m .70386 .81978 L .70459 .80929 L p .707 .577 .707 r
F P
0 g
s
.70459 .80929 m .70251 .79122 L .70178 .8017 L p .707 .577 .707 r
F P
0 g
s
.63203 .64287 m .63024 .69865 L .59864 .69651 L p .707 .577 .707 r
F P
0 g
s
.59864 .69651 m .60042 .64073 L .63203 .64287 L p .707 .577 .707 r
F P
0 g
s
.6217 .7169 m .62292 .75376 L .59105 .75412 L p .707 .577 .707 r
F P
0 g
s
.59105 .75412 m .58982 .71727 L .6217 .7169 L p .707 .577 .707 r
F P
0 g
s
.62002 .77143 m .6221 .78951 L .59033 .79254 L p .707 .577 .707 r
F P
0 g
s
.59033 .79254 m .58825 .77446 L .62002 .77143 L p .707 .577 .707 r
F P
0 g
s
.58039 .31347 m .58039 .81536 L .61346 .80712 L p .707 .577 .707 r
F P
0 g
s
.61346 .80712 m .61346 .30523 L .58039 .31347 L p .707 .577 .707 r
F P
0 g
s
.70075 .7402 m .70197 .77706 L .69414 .76848 L p .707 .577 .707 r
F P
0 g
s
.69414 .76848 m .69292 .73162 L .70075 .7402 L p .707 .577 .707 r
F P
0 g
s
.69826 .66136 m .69647 .71713 L .68168 .70949 L p .707 .577 .707 r
F P
0 g
s
.68168 .70949 m .68347 .65371 L .69826 .66136 L p .707 .577 .707 r
F P
0 g
s
.41093 .81366 m .41093 .31178 L .38023 .3029 L p .707 .577 .707 r
F P
0 g
s
.41093 .31178 m .41093 .81366 L .45035 .81956 L p .707 .577 .707 r
F P
0 g
s
.25955 .7147 m .26033 .65959 L .22871 .6578 L p .707 .577 .707 r
F P
0 g
s
.26033 .65959 m .25955 .7147 L .29106 .71354 L p .707 .577 .707 r
F P
0 g
s
.29106 .71354 m .29185 .65843 L .26033 .65959 L p .707 .577 .707 r
F P
0 g
s
.22793 .71291 m .22871 .6578 L .20008 .65322 L p .707 .577 .707 r
F P
0 g
s
.22871 .6578 m .22793 .71291 L .25955 .7147 L p .707 .577 .707 r
F P
0 g
s
.29185 .65843 m .29106 .71354 L .31939 .70952 L p .707 .577 .707 r
F P
0 g
s
.31939 .70952 m .32018 .65441 L .29185 .65843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70251 .79122 m .70459 .80929 L .69546 .80026 L p .707 .577 .707 r
F P
0 g
s
.69546 .80026 m .69338 .78219 L .70251 .79122 L p .707 .577 .707 r
F P
0 g
s
.1993 .70833 m .20008 .65322 L .17725 .6463 L p .707 .577 .707 r
F P
0 g
s
.20008 .65322 m .1993 .70833 L .22793 .71291 L p .707 .577 .707 r
F P
0 g
s
.32018 .65441 m .31939 .70952 L .34176 .70306 L p .707 .577 .707 r
F P
0 g
s
.34176 .70306 m .34255 .64795 L .32018 .65441 L p .707 .577 .707 r
F P
0 g
s
.66064 .64734 m .65886 .70312 L .63024 .69865 L p .707 .577 .707 r
F P
0 g
s
.63024 .69865 m .63203 .64287 L .66064 .64734 L p .707 .577 .707 r
F P
0 g
s
.65136 .71938 m .65259 .75623 L .62292 .75376 L p .707 .577 .707 r
F P
0 g
s
.62292 .75376 m .6217 .7169 L .65136 .71938 L p .707 .577 .707 r
F P
0 g
s
.65001 .77178 m .6521 .78986 L .6221 .78951 L p .707 .577 .707 r
F P
0 g
s
.6221 .78951 m .62002 .77143 L .65001 .77178 L p .707 .577 .707 r
F P
0 g
s
.61346 .30523 m .61346 .80712 L .63543 .79654 L p .707 .577 .707 r
F P
0 g
s
.63543 .79654 m .63543 .29465 L .61346 .30523 L p .707 .577 .707 r
F P
0 g
s
.69292 .73162 m .69414 .76848 L .67713 .76131 L p .707 .577 .707 r
F P
0 g
s
.67713 .76131 m .6759 .72445 L .69292 .73162 L p .707 .577 .707 r
F P
0 g
s
.68347 .65371 m .68168 .70949 L .65886 .70312 L p .707 .577 .707 r
F P
0 g
s
.65886 .70312 m .66064 .64734 L .68347 .65371 L p .707 .577 .707 r
F P
0 g
s
.268 .76945 m .26746 .73214 L .23556 .73206 L p .707 .577 .707 r
F P
0 g
s
.26746 .73214 m .268 .76945 L .29899 .76713 L p .707 .577 .707 r
F P
0 g
s
.29899 .76713 m .29845 .72981 L .26746 .73214 L p .707 .577 .707 r
F P
0 g
s
.23611 .76938 m .23556 .73206 L .20589 .72959 L p .707 .577 .707 r
F P
0 g
s
.23556 .73206 m .23611 .76938 L .268 .76945 L p .707 .577 .707 r
F P
0 g
s
.38023 .80479 m .38023 .3029 L .36125 .29191 L p .707 .577 .707 r
F P
0 g
s
.38023 .3029 m .38023 .80479 L .41093 .81366 L p .707 .577 .707 r
F P
0 g
s
.29845 .72981 m .29899 .76713 L .32605 .76263 L p .707 .577 .707 r
F P
0 g
s
.32605 .76263 m .3255 .72531 L .29845 .72981 L p .707 .577 .707 r
F P
0 g
s
.20589 .72959 m .20644 .76691 L .23611 .76938 L p .707 .577 .707 r
F P
0 g
s
.17725 .6463 m .17647 .70141 L .1993 .70833 L p .707 .577 .707 r
F P
0 g
s
.27411 .80546 m .27316 .78658 L .24124 .78799 L p .707 .577 .707 r
F P
0 g
s
.27316 .78658 m .27411 .80546 L .30468 .80231 L p .707 .577 .707 r
F P
0 g
s
.30468 .80231 m .30374 .78342 L .27316 .78658 L p .707 .577 .707 r
F P
0 g
s
.20644 .76691 m .20589 .72959 L .18134 .72498 L p .707 .577 .707 r
F P
0 g
s
.24218 .80688 m .24124 .78799 L .2111 .78753 L p .707 .577 .707 r
F P
0 g
s
.24124 .78799 m .24218 .80688 L .27411 .80546 L p .707 .577 .707 r
F P
0 g
s
.17647 .70141 m .17725 .6463 L .16245 .63773 L p .707 .577 .707 r
F P
0 g
s
.2111 .78753 m .21204 .80641 L .24218 .80688 L p .707 .577 .707 r
F P
0 g
s
.69338 .78219 m .69546 .80026 L .67737 .79357 L p .707 .577 .707 r
F P
0 g
s
.67737 .79357 m .67529 .77549 L .69338 .78219 L p .707 .577 .707 r
F P
0 g
s
.34255 .64795 m .34176 .70306 L .35598 .69477 L p .707 .577 .707 r
F P
0 g
s
.35598 .69477 m .35677 .63966 L .34255 .64795 L p .707 .577 .707 r
F P
0 g
s
.30374 .78342 m .30468 .80231 L .33092 .79773 L p .707 .577 .707 r
F P
0 g
s
.33092 .79773 m .32997 .77884 L .30374 .78342 L p .707 .577 .707 r
F P
0 g
s
.18134 .72498 m .18189 .7623 L .20644 .76691 L p .707 .577 .707 r
F P
0 g
s
.3255 .72531 m .32605 .76263 L .34651 .75641 L p .707 .577 .707 r
F P
0 g
s
.34651 .75641 m .34596 .71909 L .3255 .72531 L p .707 .577 .707 r
F P
0 g
s
.21204 .80641 m .2111 .78753 L .18569 .78523 L p .707 .577 .707 r
F P
0 g
s
.6759 .72445 m .67713 .76131 L .65259 .75623 L p .707 .577 .707 r
F P
0 g
s
.65259 .75623 m .65136 .71938 L .6759 .72445 L p .707 .577 .707 r
F P
0 g
s
.18569 .78523 m .18663 .80412 L .21204 .80641 L p .707 .577 .707 r
F P
0 g
s
.16245 .63773 m .16166 .69284 L .17647 .70141 L p .707 .577 .707 r
F P
0 g
s
.18189 .7623 m .18134 .72498 L .16431 .71866 L p .707 .577 .707 r
F P
0 g
s
.63543 .29465 m .63543 .79654 L .64414 .78466 L p .707 .577 .707 r
F P
0 g
s
.64414 .78466 m .64414 .28277 L .63543 .29465 L p .707 .577 .707 r
F P
0 g
s
.32997 .77884 m .33092 .79773 L .35025 .79216 L p .707 .577 .707 r
F P
0 g
s
.35025 .79216 m .3493 .77327 L .32997 .77884 L p .707 .577 .707 r
F P
0 g
s
.16431 .71866 m .16486 .75598 L .18189 .7623 L p .707 .577 .707 r
F P
0 g
s
.16166 .69284 m .16245 .63773 L .15712 .62833 L p .707 .577 .707 r
F P
0 g
s
.67529 .77549 m .67737 .79357 L .6521 .78986 L p .707 .577 .707 r
F P
0 g
s
.6521 .78986 m .65001 .77178 L .67529 .77549 L p .707 .577 .707 r
F P
0 g
s
.18663 .80412 m .18569 .78523 L .16749 .78133 L p .707 .577 .707 r
F P
0 g
s
.35677 .63966 m .35598 .69477 L .36066 .68548 L p .707 .577 .707 r
F P
0 g
s
.36066 .68548 m .36144 .63037 L .35677 .63966 L p .707 .577 .707 r
F P
0 g
s
.36144 .63037 m .36066 .68548 L .35533 .67609 L p .707 .577 .707 r
F P
0 g
s
.35533 .67609 m .35612 .62098 L .36144 .63037 L p .707 .577 .707 r
F P
0 g
s
.35983 .76727 m .36078 .78616 L .36148 .78031 L p .707 .577 .707 r
F P
0 g
s
.36148 .78031 m .36054 .76142 L .35983 .76727 L p .707 .577 .707 r
F P
0 g
s
.36078 .78616 m .35983 .76727 L .3493 .77327 L p .707 .577 .707 r
F P
0 g
s
.36054 .76142 m .36148 .78031 L .35228 .77518 L p .707 .577 .707 r
F P
0 g
s
.36125 .7938 m .36125 .29191 L .35585 .27989 L p .707 .577 .707 r
F P
0 g
s
.36125 .29191 m .36125 .7938 L .38023 .80479 L p .707 .577 .707 r
F P
0 g
s
.16749 .78133 m .16844 .80022 L .18663 .80412 L p .707 .577 .707 r
F P
0 g
s
.34596 .71909 m .34651 .75641 L .35839 .74906 L p .707 .577 .707 r
F P
0 g
s
.35839 .74906 m .35784 .71174 L .34596 .71909 L p .707 .577 .707 r
F P
0 g
s
.16486 .75598 m .16431 .71866 L .15648 .71127 L p .707 .577 .707 r
F P
0 g
s
.15712 .62833 m .15634 .68344 L .16166 .69284 L p .707 .577 .707 r
F P
0 g
s
.3493 .77327 m .35025 .79216 L .36078 .78616 L p .707 .577 .707 r
F P
0 g
s
.15648 .71127 m .15703 .74859 L .16486 .75598 L p .707 .577 .707 r
F P
0 g
s
.16844 .80022 m .16749 .78133 L .15829 .7762 L p .707 .577 .707 r
F P
0 g
s
.15634 .68344 m .15712 .62833 L .1618 .61904 L p .707 .577 .707 r
F P
0 g
s
.15829 .7762 m .15924 .79509 L .16844 .80022 L p .707 .577 .707 r
F P
0 g
s
.35784 .71174 m .35839 .74906 L .36052 .74131 L p .707 .577 .707 r
F P
0 g
s
.36052 .74131 m .35997 .70399 L .35784 .71174 L p .707 .577 .707 r
F P
0 g
s
.64414 .28277 m .64414 .78466 L .63875 .77263 L p .707 .577 .707 r
F P
0 g
s
.63875 .77263 m .63875 .27075 L .64414 .28277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35612 .62098 m .35533 .67609 L .34053 .66751 L p .707 .577 .707 r
F P
0 g
s
.34053 .66751 m .34132 .6124 L .35612 .62098 L p .707 .577 .707 r
F P
0 g
s
.35997 .70399 m .36052 .74131 L .35269 .73391 L p .707 .577 .707 r
F P
0 g
s
.35269 .73391 m .35214 .69659 L .35997 .70399 L p .707 .577 .707 r
F P
0 g
s
.35228 .77518 m .35134 .75629 L .36054 .76142 L p .707 .577 .707 r
F P
0 g
s
.35585 .27989 m .35585 .78178 L .36125 .7938 L p .707 .577 .707 r
F P
0 g
s
.35585 .78178 m .35585 .27989 L .36457 .26801 L p .707 .577 .707 r
F P
0 g
s
.15703 .74859 m .15648 .71127 L .15861 .70352 L p .707 .577 .707 r
F P
0 g
s
.1618 .61904 m .16102 .67415 L .15634 .68344 L p .707 .577 .707 r
F P
0 g
s
.15861 .70352 m .15916 .74084 L .15703 .74859 L p .707 .577 .707 r
F P
0 g
s
.15924 .79509 m .15829 .7762 L .159 .77035 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16102 .67415 m .1618 .61904 L .17602 .61075 L p .707 .577 .707 r
F P
0 g
s
.159 .77035 m .15994 .78924 L .15924 .79509 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17602 .61075 m .17523 .66586 L .16102 .67415 L p .707 .577 .707 r
F P
0 g
s
.63875 .27075 m .63875 .77263 L .61977 .76165 L p .707 .577 .707 r
F P
0 g
s
.61977 .76165 m .61977 .25976 L .63875 .27075 L p .707 .577 .707 r
F P
0 g
s
.15916 .74084 m .15861 .70352 L .17049 .69617 L p .707 .577 .707 r
F P
0 g
s
.17049 .69617 m .17103 .73349 L .15916 .74084 L p .707 .577 .707 r
F P
0 g
s
.36457 .7699 m .36457 .26801 L .38653 .25743 L p .707 .577 .707 r
F P
0 g
s
.36457 .26801 m .36457 .7699 L .35585 .78178 L p .707 .577 .707 r
F P
0 g
s
.17523 .66586 m .17602 .61075 L .19839 .60429 L p .707 .577 .707 r
F P
0 g
s
.15994 .78924 m .159 .77035 L .16953 .76435 L p .707 .577 .707 r
F P
0 g
s
.34132 .6124 m .34053 .66751 L .3177 .6606 L p .707 .577 .707 r
F P
0 g
s
.3177 .6606 m .31848 .60549 L .34132 .6124 L p .707 .577 .707 r
F P
0 g
s
.16953 .76435 m .17047 .78324 L .15994 .78924 L p .707 .577 .707 r
F P
0 g
s
.35214 .69659 m .35269 .73391 L .33566 .7276 L p .707 .577 .707 r
F P
0 g
s
.33566 .7276 m .33511 .69028 L .35214 .69659 L p .707 .577 .707 r
F P
0 g
s
.19839 .60429 m .1976 .6594 L .17523 .66586 L p .707 .577 .707 r
F P
0 g
s
.17103 .73349 m .17049 .69617 L .19095 .68994 L p .707 .577 .707 r
F P
0 g
s
.1976 .6594 m .19839 .60429 L .22672 .60028 L p .707 .577 .707 r
F P
0 g
s
.31848 .60549 m .3177 .6606 L .28907 .65602 L p .707 .577 .707 r
F P
0 g
s
.28907 .65602 m .28986 .60091 L .31848 .60549 L p .707 .577 .707 r
F P
0 g
s
.35134 .75629 m .35228 .77518 L .33409 .77128 L p .707 .577 .707 r
F P
0 g
s
.33409 .77128 m .33314 .75239 L .35134 .75629 L p .707 .577 .707 r
F P
0 g
s
.19095 .68994 m .1915 .72726 L .17103 .73349 L p .707 .577 .707 r
F P
0 g
s
.61977 .25976 m .61977 .76165 L .58906 .75277 L p .707 .577 .707 r
F P
0 g
s
.58906 .75277 m .58906 .25088 L .61977 .25976 L p .707 .577 .707 r
F P
0 g
s
.17047 .78324 m .16953 .76435 L .18886 .75878 L p .707 .577 .707 r
F P
0 g
s
.33511 .69028 m .33566 .7276 L .31111 .72298 L p .707 .577 .707 r
F P
0 g
s
.31111 .72298 m .31056 .68566 L .33511 .69028 L p .707 .577 .707 r
F P
0 g
s
.18886 .75878 m .1898 .77767 L .17047 .78324 L p .707 .577 .707 r
F P
0 g
s
.22593 .65539 m .22672 .60028 L .25824 .59911 L p .707 .577 .707 r
F P
0 g
s
.22672 .60028 m .22593 .65539 L .1976 .6594 L p .707 .577 .707 r
F P
0 g
s
.28986 .60091 m .28907 .65602 L .25745 .65422 L p .707 .577 .707 r
F P
0 g
s
.25745 .65422 m .25824 .59911 L .28986 .60091 L p .707 .577 .707 r
F P
0 g
s
.38653 .25743 m .38653 .75932 L .36457 .7699 L p .707 .577 .707 r
F P
0 g
s
.38653 .75932 m .38653 .25743 L .41961 .24919 L p .707 .577 .707 r
F P
0 g
s
.74255 .6555 m .74176 .59951 L .71014 .5988 L p .707 .577 .707 r
F P
0 g
s
.74176 .59951 m .74255 .6555 L .77407 .65381 L p .707 .577 .707 r
F P
0 g
s
.77407 .65381 m .77328 .59781 L .74176 .59951 L p .707 .577 .707 r
F P
0 g
s
.25824 .59911 m .25745 .65422 L .22593 .65539 L p .707 .577 .707 r
F P
0 g
s
.1915 .72726 m .19095 .68994 L .21801 .68545 L p .707 .577 .707 r
F P
0 g
s
.71093 .6548 m .71014 .5988 L .68151 .59576 L p .707 .577 .707 r
F P
0 g
s
.71014 .5988 m .71093 .6548 L .74255 .6555 L p .707 .577 .707 r
F P
0 g
s
.77328 .59781 m .77407 .65381 L .8024 .64987 L p .707 .577 .707 r
F P
0 g
s
.8024 .64987 m .80161 .59387 L .77328 .59781 L p .707 .577 .707 r
F P
0 g
s
.33314 .75239 m .33409 .77128 L .30867 .76898 L p .707 .577 .707 r
F P
0 g
s
.30867 .76898 m .30773 .7501 L .33314 .75239 L p .707 .577 .707 r
F P
0 g
s
.21801 .68545 m .21855 .72277 L .1915 .72726 L p .707 .577 .707 r
F P
0 g
s
.31056 .68566 m .31111 .72298 L .28144 .72051 L p .707 .577 .707 r
F P
0 g
s
.28144 .72051 m .28089 .6832 L .31056 .68566 L p .707 .577 .707 r
F P
0 g
s
.1898 .77767 m .18886 .75878 L .21509 .7542 L p .707 .577 .707 r
F P
0 g
s
.68151 .59576 m .6823 .65175 L .71093 .6548 L p .707 .577 .707 r
F P
0 g
s
.6823 .65175 m .68151 .59576 L .65868 .59068 L p .707 .577 .707 r
F P
0 g
s
.21509 .7542 m .21604 .77309 L .1898 .77767 L p .707 .577 .707 r
F P
0 g
s
.21855 .72277 m .21801 .68545 L .24899 .68312 L p .707 .577 .707 r
F P
0 g
s
.80161 .59387 m .8024 .64987 L .82476 .64408 L p .707 .577 .707 r
F P
0 g
s
.82476 .64408 m .82398 .58808 L .80161 .59387 L p .707 .577 .707 r
F P
0 g
s
.58906 .25088 m .58906 .75277 L .54964 .74688 L p .707 .577 .707 r
F P
0 g
s
.54964 .74688 m .54964 .24499 L .58906 .25088 L p .707 .577 .707 r
F P
0 g
s
.75045 .72127 m .751 .68451 L .71911 .68345 L p .707 .577 .707 r
F P
0 g
s
.751 .68451 m .75045 .72127 L .78144 .71938 L p .707 .577 .707 r
F P
0 g
s
.78144 .71938 m .78199 .68263 L .751 .68451 L p .707 .577 .707 r
F P
0 g
s
.71856 .72021 m .71911 .68345 L .68944 .67955 L p .707 .577 .707 r
F P
0 g
s
.71911 .68345 m .71856 .72021 L .75045 .72127 L p .707 .577 .707 r
F P
0 g
s
.28089 .6832 m .28144 .72051 L .24954 .72044 L p .707 .577 .707 r
F P
0 g
s
.24954 .72044 m .24899 .68312 L .28089 .6832 L p .707 .577 .707 r
F P
0 g
s
.24899 .68312 m .24954 .72044 L .21855 .72277 L p .707 .577 .707 r
F P
0 g
s
.41961 .75108 m .41961 .24919 L .46056 .2441 L p .707 .577 .707 r
F P
0 g
s
.41961 .24919 m .41961 .75108 L .38653 .75932 L p .707 .577 .707 r
F P
0 g
s
.78199 .68263 m .78144 .71938 L .8085 .71474 L p .707 .577 .707 r
F P
0 g
s
.8085 .71474 m .80904 .67798 L .78199 .68263 L p .707 .577 .707 r
F P
0 g
s
.30773 .7501 m .30867 .76898 L .27853 .76852 L p .707 .577 .707 r
F P
0 g
s
.27853 .76852 m .27759 .74963 L .30773 .7501 L p .707 .577 .707 r
F P
0 g
s
.65868 .59068 m .65947 .64667 L .6823 .65175 L p .707 .577 .707 r
F P
0 g
s
.21604 .77309 m .21509 .7542 L .24567 .75105 L p .707 .577 .707 r
F P
0 g
s
.68889 .71631 m .68944 .67955 L .66488 .67319 L p .707 .577 .707 r
F P
0 g
s
.68944 .67955 m .68889 .71631 L .71856 .72021 L p .707 .577 .707 r
F P
0 g
s
.24567 .75105 m .24661 .76994 L .21604 .77309 L p .707 .577 .707 r
F P
0 g
s
.65947 .64667 m .65868 .59068 L .64388 .58405 L p .707 .577 .707 r
F P
0 g
s
.27759 .74963 m .27853 .76852 L .24661 .76994 L p .707 .577 .707 r
F P
0 g
s
.24661 .76994 m .24567 .75105 L .27759 .74963 L p .707 .577 .707 r
F P
0 g
s
.82398 .58808 m .82476 .64408 L .83898 .63701 L p .707 .577 .707 r
F P
0 g
s
.83898 .63701 m .8382 .58101 L .82398 .58808 L p .707 .577 .707 r
F P
0 g
s
.54964 .24499 m .54964 .74688 L .50536 .74454 L p .707 .577 .707 r
F P
0 g
s
.50536 .74454 m .50536 .24265 L .54964 .24499 L p .707 .577 .707 r
F P
0 g
s
.75339 .76835 m .75433 .75037 L .72241 .74866 L p .707 .577 .707 r
F P
0 g
s
.75433 .75037 m .75339 .76835 L .78396 .76651 L p .707 .577 .707 r
F P
0 g
s
.78396 .76651 m .7849 .74853 L .75433 .75037 L p .707 .577 .707 r
F P
0 g
s
.72147 .76663 m .72241 .74866 L .69227 .74356 L p .707 .577 .707 r
F P
0 g
s
.72241 .74866 m .72147 .76663 L .75339 .76835 L p .707 .577 .707 r
F P
0 g
s
.80904 .67798 m .8085 .71474 L .82896 .70779 L p .707 .577 .707 r
F P
0 g
s
.82896 .70779 m .82951 .67103 L .80904 .67798 L p .707 .577 .707 r
F P
0 g
s
.46056 .74599 m .46056 .2441 L .50536 .24265 L p .707 .577 .707 r
F P
0 g
s
.46056 .2441 m .46056 .74599 L .41961 .75108 L p .707 .577 .707 r
F P
0 g
s
.66488 .67319 m .66434 .70995 L .68889 .71631 L p .707 .577 .707 r
F P
0 g
s
.69227 .74356 m .69132 .76153 L .72147 .76663 L p .707 .577 .707 r
F P
0 g
s
.50536 .24265 m .50536 .74454 L .46056 .74599 L p .707 .577 .707 r
F P
0 g
s
.7849 .74853 m .78396 .76651 L .8102 .76129 L p .707 .577 .707 r
F P
0 g
s
.8102 .76129 m .81114 .74332 L .7849 .74853 L p .707 .577 .707 r
F P
0 g
s
.69132 .76153 m .69227 .74356 L .66685 .73557 L p .707 .577 .707 r
F P
0 g
s
.64388 .58405 m .64466 .64005 L .65947 .64667 L p .707 .577 .707 r
F P
0 g
s
.66434 .70995 m .66488 .67319 L .64786 .66499 L p .707 .577 .707 r
F P
0 g
s
.66685 .73557 m .66591 .75354 L .69132 .76153 L p .707 .577 .707 r
F P
0 g
s
.64786 .66499 m .64731 .70175 L .66434 .70995 L p .707 .577 .707 r
F P
0 g
s
.64466 .64005 m .64388 .58405 L .63856 .57654 L p .707 .577 .707 r
F P
0 g
s
.8382 .58101 m .83898 .63701 L .84366 .62933 L p .707 .577 .707 r
F P
0 g
s
.84366 .62933 m .84287 .57334 L .8382 .58101 L p .707 .577 .707 r
F P
0 g
s
.82951 .67103 m .82896 .70779 L .84084 .69922 L p .707 .577 .707 r
F P
0 g
s
.84084 .69922 m .84139 .66246 L .82951 .67103 L p .707 .577 .707 r
F P
0 g
s
.81114 .74332 m .8102 .76129 L .82953 .75321 L p .707 .577 .707 r
F P
0 g
s
.82953 .75321 m .83047 .73524 L .81114 .74332 L p .707 .577 .707 r
F P
0 g
s
.66591 .75354 m .66685 .73557 L .64866 .72547 L p .707 .577 .707 r
F P
0 g
s
.64866 .72547 m .64772 .74345 L .66591 .75354 L p .707 .577 .707 r
F P
0 g
s
.64731 .70175 m .64786 .66499 L .64003 .65576 L p .707 .577 .707 r
F P
0 g
s
.63856 .57654 m .63934 .63254 L .64466 .64005 L p .707 .577 .707 r
F P
0 g
s
.64003 .65576 m .63948 .69252 L .64731 .70175 L p .707 .577 .707 r
F P
0 g
s
.83047 .73524 m .82953 .75321 L .84006 .74306 L p .707 .577 .707 r
F P
0 g
s
.84006 .74306 m .841 .72508 L .83047 .73524 L p .707 .577 .707 r
F P
0 g
s
.64772 .74345 m .64866 .72547 L .63946 .71425 L p .707 .577 .707 r
F P
0 g
s
.84139 .66246 m .84084 .69922 L .84297 .68986 L p .707 .577 .707 r
F P
0 g
s
.84297 .68986 m .84352 .6531 L .84139 .66246 L p .707 .577 .707 r
F P
0 g
s
.63934 .63254 m .63856 .57654 L .64323 .56887 L p .707 .577 .707 r
F P
0 g
s
.84287 .57334 m .84366 .62933 L .83834 .62182 L p .707 .577 .707 r
F P
0 g
s
.83834 .62182 m .83755 .56582 L .84287 .57334 L p .707 .577 .707 r
F P
0 g
s
.63946 .71425 m .63852 .73223 L .64772 .74345 L p .707 .577 .707 r
F P
0 g
s
.63948 .69252 m .64003 .65576 L .64215 .6464 L p .707 .577 .707 r
F P
0 g
s
.64323 .56887 m .64402 .62487 L .63934 .63254 L p .707 .577 .707 r
F P
0 g
s
.64215 .6464 m .64161 .68316 L .63948 .69252 L p .707 .577 .707 r
F P
0 g
s
.841 .72508 m .84006 .74306 L .84076 .73182 L p .705 .576 .707 r
F P
0 g
s
.84076 .73182 m .8417 .71385 L .841 .72508 L p .705 .576 .707 r
F P
0 g
s
.63852 .73223 m .63946 .71425 L .64016 .70302 L p .705 .576 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84352 .6531 m .84297 .68986 L .83514 .68063 L p .707 .577 .707 r
F P
0 g
s
.83514 .68063 m .83569 .64387 L .84352 .6531 L p .707 .577 .707 r
F P
0 g
s
.64402 .62487 m .64323 .56887 L .65745 .56179 L p .707 .577 .707 r
F P
0 g
s
.83755 .56582 m .83834 .62182 L .82353 .6152 L p .707 .577 .707 r
F P
0 g
s
.82353 .6152 m .82275 .5592 L .83755 .56582 L p .707 .577 .707 r
F P
0 g
s
.64016 .70302 m .63922 .721 L .63852 .73223 L p .705 .576 .707 r
F P
0 g
s
.40136 .62171 m .39957 .56639 L .36797 .56601 L p .707 .577 .707 r
F P
0 g
s
.39957 .56639 m .40136 .62171 L .43287 .61928 L p .707 .577 .707 r
F P
0 g
s
.43287 .61928 m .43108 .56395 L .39957 .56639 L p .707 .577 .707 r
F P
0 g
s
.36975 .62133 m .36797 .56601 L .33935 .56284 L p .707 .577 .707 r
F P
0 g
s
.36797 .56601 m .36975 .62133 L .40136 .62171 L p .707 .577 .707 r
F P
0 g
s
.43108 .56395 m .43287 .61928 L .46119 .61425 L p .707 .577 .707 r
F P
0 g
s
.46119 .61425 m .4594 .55893 L .43108 .56395 L p .707 .577 .707 r
F P
0 g
s
.64161 .68316 m .64215 .6464 L .65403 .63783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65745 .56179 m .65824 .61779 L .64402 .62487 L p .707 .577 .707 r
F P
0 g
s
.65403 .63783 m .65349 .67459 L .64161 .68316 L p .707 .577 .707 r
F P
0 g
s
.8417 .71385 m .84076 .73182 L .83156 .72061 L p .707 .577 .707 r
F P
0 g
s
.83156 .72061 m .83251 .70263 L .8417 .71385 L p .707 .577 .707 r
F P
0 g
s
.63922 .721 m .64016 .70302 L .65069 .69287 L p .707 .577 .707 r
F P
0 g
s
.34114 .61816 m .33935 .56284 L .31653 .5572 L p .707 .577 .707 r
F P
0 g
s
.33935 .56284 m .34114 .61816 L .36975 .62133 L p .707 .577 .707 r
F P
0 g
s
.4594 .55893 m .46119 .61425 L .48355 .60714 L p .707 .577 .707 r
F P
0 g
s
.48355 .60714 m .48176 .55182 L .4594 .55893 L p .707 .577 .707 r
F P
0 g
s
.65824 .61779 m .65745 .56179 L .67982 .556 L p .707 .577 .707 r
F P
0 g
s
.83569 .64387 m .83514 .68063 L .81811 .67243 L p .707 .577 .707 r
F P
0 g
s
.81811 .67243 m .81866 .63567 L .83569 .64387 L p .707 .577 .707 r
F P
0 g
s
.82275 .5592 m .82353 .6152 L .8007 .61012 L p .707 .577 .707 r
F P
0 g
s
.8007 .61012 m .79991 .55412 L .82275 .5592 L p .707 .577 .707 r
F P
0 g
s
.40895 .6793 m .41017 .6421 L .37829 .64058 L p .707 .577 .707 r
F P
0 g
s
.41017 .6421 m .40895 .6793 L .43993 .67828 L p .707 .577 .707 r
F P
0 g
s
.43993 .67828 m .44115 .64107 L .41017 .6421 L p .707 .577 .707 r
F P
0 g
s
.37707 .67778 m .37829 .64058 L .34863 .63667 L p .707 .577 .707 r
F P
0 g
s
.37829 .64058 m .37707 .67778 L .40895 .6793 L p .707 .577 .707 r
F P
0 g
s
.65069 .69287 m .64975 .71084 L .63922 .721 L p .707 .577 .707 r
F P
0 g
s
.44115 .64107 m .43993 .67828 L .46697 .67481 L p .707 .577 .707 r
F P
0 g
s
.46697 .67481 m .46819 .63761 L .44115 .64107 L p .707 .577 .707 r
F P
0 g
s
.65349 .67459 m .65403 .63783 L .6745 .63088 L p .707 .577 .707 r
F P
0 g
s
.34863 .63667 m .34741 .67387 L .37707 .67778 L p .707 .577 .707 r
F P
0 g
s
.31653 .5572 m .31832 .61252 L .34114 .61816 L p .707 .577 .707 r
F P
0 g
s
.67982 .556 m .68061 .612 L .65824 .61779 L p .707 .577 .707 r
F P
0 g
s
.34741 .67387 m .34863 .63667 L .32409 .63075 L p .707 .577 .707 r
F P
0 g
s
.37789 .71474 m .37998 .69605 L .34998 .69064 L p .707 .577 .707 r
F P
0 g
s
.37998 .69605 m .37789 .71474 L .40966 .71828 L p .707 .577 .707 r
F P
0 g
s
.40966 .71828 m .41175 .69959 L .37998 .69605 L p .707 .577 .707 r
F P
0 g
s
.41175 .69959 m .40966 .71828 L .4401 .71959 L p .707 .577 .707 r
F P
0 g
s
.4401 .71959 m .44219 .7009 L .41175 .69959 L p .707 .577 .707 r
F P
0 g
s
.31832 .61252 m .31653 .5572 L .30174 .54964 L p .707 .577 .707 r
F P
0 g
s
.48176 .55182 m .48355 .60714 L .49777 .59863 L p .707 .577 .707 r
F P
0 g
s
.49777 .59863 m .49598 .54331 L .48176 .55182 L p .707 .577 .707 r
F P
0 g
s
.34998 .69064 m .3479 .70933 L .37789 .71474 L p .707 .577 .707 r
F P
0 g
s
.68061 .612 m .67982 .556 L .70815 .55207 L p .707 .577 .707 r
F P
0 g
s
.79991 .55412 m .8007 .61012 L .77207 .60708 L p .707 .577 .707 r
F P
0 g
s
.77207 .60708 m .77129 .55108 L .79991 .55412 L p .707 .577 .707 r
F P
0 g
s
.6745 .63088 m .67395 .66764 L .65349 .67459 L p .707 .577 .707 r
F P
0 g
s
.32409 .63075 m .32287 .66795 L .34741 .67387 L p .707 .577 .707 r
F P
0 g
s
.83251 .70263 m .83156 .72061 L .81337 .71051 L p .707 .577 .707 r
F P
0 g
s
.81337 .71051 m .81431 .69254 L .83251 .70263 L p .707 .577 .707 r
F P
0 g
s
.64975 .71084 m .65069 .69287 L .67002 .68478 L p .707 .577 .707 r
F P
0 g
s
.46819 .63761 m .46697 .67481 L .48743 .66925 L p .707 .577 .707 r
F P
0 g
s
.48743 .66925 m .48866 .63205 L .46819 .63761 L p .707 .577 .707 r
F P
0 g
s
.3479 .70933 m .34998 .69064 L .32471 .68388 L p .707 .577 .707 r
F P
0 g
s
.44219 .7009 m .4401 .71959 L .46623 .71855 L p .707 .577 .707 r
F P
0 g
s
.46623 .71855 m .46832 .69986 L .44219 .7009 L p .707 .577 .707 r
F P
0 g
s
.81866 .63567 m .81811 .67243 L .79356 .66607 L p .707 .577 .707 r
F P
0 g
s
.79356 .66607 m .79411 .62931 L .81866 .63567 L p .707 .577 .707 r
F P
0 g
s
.32471 .68388 m .32262 .70257 L .3479 .70933 L p .707 .577 .707 r
F P
0 g
s
.67002 .68478 m .66908 .70276 L .64975 .71084 L p .707 .577 .707 r
F P
0 g
s
.32287 .66795 m .32409 .63075 L .30708 .6234 L p .707 .577 .707 r
F P
0 g
s
.30174 .54964 m .30352 .60496 L .31832 .61252 L p .707 .577 .707 r
F P
0 g
s
.67395 .66764 m .6745 .63088 L .70155 .62623 L p .707 .577 .707 r
F P
0 g
s
.70815 .55207 m .70894 .60807 L .68061 .612 L p .707 .577 .707 r
F P
0 g
s
.70894 .60807 m .70815 .55207 L .73967 .55037 L p .707 .577 .707 r
F P
0 g
s
.77129 .55108 m .77207 .60708 L .74045 .60637 L p .707 .577 .707 r
F P
0 g
s
.74045 .60637 m .73967 .55037 L .77129 .55108 L p .707 .577 .707 r
F P
0 g
s
.73967 .55037 m .74045 .60637 L .70894 .60807 L p .707 .577 .707 r
F P
0 g
s
.30708 .6234 m .30586 .66061 L .32287 .66795 L p .707 .577 .707 r
F P
0 g
s
.32262 .70257 m .32471 .68388 L .30662 .67643 L p .707 .577 .707 r
F P
0 g
s
.46832 .69986 m .46623 .71855 L .48549 .71526 L p .707 .577 .707 r
F P
0 g
s
.48549 .71526 m .48758 .69657 L .46832 .69986 L p .707 .577 .707 r
F P
0 g
s
.30352 .60496 m .30174 .54964 L .29642 .54089 L p .707 .577 .707 r
F P
0 g
s
.79411 .62931 m .79356 .66607 L .76389 .66217 L p .707 .577 .707 r
F P
0 g
s
.76389 .66217 m .76444 .62541 L .79411 .62931 L p .707 .577 .707 r
F P
0 g
s
.49598 .54331 m .49777 .59863 L .50245 .58956 L p .707 .577 .707 r
F P
0 g
s
.50245 .58956 m .50066 .53424 L .49598 .54331 L p .707 .577 .707 r
F P
0 g
s
.70155 .62623 m .70101 .66299 L .67395 .66764 L p .707 .577 .707 r
F P
0 g
s
.30662 .67643 m .30454 .69512 L .32262 .70257 L p .707 .577 .707 r
F P
0 g
s
.81431 .69254 m .81337 .71051 L .78796 .70252 L p .707 .577 .707 r
F P
0 g
s
.78796 .70252 m .7889 .68455 L .81431 .69254 L p .707 .577 .707 r
F P
0 g
s
.66908 .70276 m .67002 .68478 L .69626 .67957 L p .707 .577 .707 r
F P
0 g
s
.48866 .63205 m .48743 .66925 L .49931 .66213 L p .707 .577 .707 r
F P
0 g
s
.49931 .66213 m .50053 .62493 L .48866 .63205 L p .707 .577 .707 r
F P
0 g
s
.70101 .66299 m .70155 .62623 L .73254 .62435 L p .707 .577 .707 r
F P
0 g
s
.69626 .67957 m .69532 .69755 L .66908 .70276 L p .707 .577 .707 r
F P
0 g
s
.76444 .62541 m .76389 .66217 L .73199 .66111 L p .707 .577 .707 r
F P
0 g
s
.73199 .66111 m .73254 .62435 L .76444 .62541 L p .707 .577 .707 r
F P
0 g
s
.73254 .62435 m .73199 .66111 L .70101 .66299 L p .707 .577 .707 r
F P
0 g
s
.30586 .66061 m .30708 .6234 L .29925 .61534 L p .707 .577 .707 r
F P
0 g
s
.29642 .54089 m .29821 .59621 L .30352 .60496 L p .707 .577 .707 r
F P
0 g
s
.7889 .68455 m .78796 .70252 L .75781 .69742 L p .707 .577 .707 r
F P
0 g
s
.75781 .69742 m .75876 .67944 L .7889 .68455 L p .707 .577 .707 r
F P
0 g
s
.69532 .69755 m .69626 .67957 L .72684 .67773 L p .707 .577 .707 r
F P
0 g
s
.29925 .61534 m .29803 .65255 L .30586 .66061 L p .707 .577 .707 r
F P
0 g
s
.30454 .69512 m .30662 .67643 L .29749 .66903 L p .707 .577 .707 r
F P
0 g
s
.48758 .69657 m .48549 .71526 L .496 .71005 L p .707 .577 .707 r
F P
0 g
s
.496 .71005 m .49808 .69135 L .48758 .69657 L p .707 .577 .707 r
F P
0 g
s
.72684 .67773 m .72589 .6957 L .69532 .69755 L p .707 .577 .707 r
F P
0 g
s
.29749 .66903 m .29541 .68772 L .30454 .69512 L p .707 .577 .707 r
F P
0 g
s
.75876 .67944 m .75781 .69742 L .72589 .6957 L p .707 .577 .707 r
F P
0 g
s
.72589 .6957 m .72684 .67773 L .75876 .67944 L p .707 .577 .707 r
F P
0 g
s
.29821 .59621 m .29642 .54089 L .3011 .53182 L p .707 .577 .707 r
F P
0 g
s
.50066 .53424 m .50245 .58956 L .49713 .58082 L p .707 .577 .707 r
F P
0 g
s
.49713 .58082 m .49534 .52549 L .50066 .53424 L p .707 .577 .707 r
F P
0 g
s
.50053 .62493 m .49931 .66213 L .50144 .65415 L p .707 .577 .707 r
F P
0 g
s
.50144 .65415 m .50266 .61695 L .50053 .62493 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29803 .65255 m .29925 .61534 L .30138 .60736 L p .707 .577 .707 r
F P
0 g
s
.3011 .53182 m .30288 .58714 L .29821 .59621 L p .707 .577 .707 r
F P
0 g
s
.30138 .60736 m .30016 .64457 L .29803 .65255 L p .707 .577 .707 r
F P
0 g
s
.29541 .68772 m .29749 .66903 L .29821 .66239 L p .721 .59 .709 r
F P
0 g
s
.49808 .69135 m .496 .71005 L .49673 .70341 L p .721 .59 .709 r
F P
0 g
s
.49673 .70341 m .49881 .68472 L .49808 .69135 L p .721 .59 .709 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29821 .66239 m .29613 .68108 L .29541 .68772 L p .721 .59 .709 r
F P
0 g
s
.30288 .58714 m .3011 .53182 L .31531 .52331 L p .707 .577 .707 r
F P
0 g
s
.49534 .52549 m .49713 .58082 L .48233 .57325 L p .707 .577 .707 r
F P
0 g
s
.48233 .57325 m .48055 .51793 L .49534 .52549 L p .707 .577 .707 r
F P
0 g
s
.50266 .61695 m .50144 .65415 L .49361 .64609 L p .707 .577 .707 r
F P
0 g
s
.49361 .64609 m .49484 .60889 L .50266 .61695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30016 .64457 m .30138 .60736 L .31326 .60024 L p .707 .577 .707 r
F P
0 g
s
.31531 .52331 m .3171 .57863 L .30288 .58714 L p .707 .577 .707 r
F P
0 g
s
.31326 .60024 m .31204 .63745 L .30016 .64457 L p .707 .577 .707 r
F P
0 g
s
.29613 .68108 m .29821 .66239 L .30872 .65717 L p .707 .577 .707 r
F P
0 g
s
.49881 .68472 m .49673 .70341 L .4876 .69601 L p .707 .577 .707 r
F P
0 g
s
.4876 .69601 m .48968 .67732 L .49881 .68472 L p .707 .577 .707 r
F P
0 g
s
.3171 .57863 m .31531 .52331 L .33768 .5162 L p .707 .577 .707 r
F P
0 g
s
.48055 .51793 m .48233 .57325 L .45951 .56761 L p .707 .577 .707 r
F P
0 g
s
.45951 .56761 m .45773 .51229 L .48055 .51793 L p .707 .577 .707 r
F P
0 g
s
.30872 .65717 m .30664 .67587 L .29613 .68108 L p .707 .577 .707 r
F P
0 g
s
.49484 .60889 m .49361 .64609 L .4766 .63874 L p .707 .577 .707 r
F P
0 g
s
.4766 .63874 m .47782 .60154 L .49484 .60889 L p .707 .577 .707 r
F P
0 g
s
.31204 .63745 m .31326 .60024 L .33372 .59468 L p .707 .577 .707 r
F P
0 g
s
.33768 .5162 m .33946 .57152 L .3171 .57863 L p .707 .577 .707 r
F P
0 g
s
.33946 .57152 m .33768 .5162 L .366 .51118 L p .707 .577 .707 r
F P
0 g
s
.45773 .51229 m .45951 .56761 L .4309 .56444 L p .707 .577 .707 r
F P
0 g
s
.4309 .56444 m .42911 .50912 L .45773 .51229 L p .707 .577 .707 r
F P
0 g
s
.33372 .59468 m .3325 .63188 L .31204 .63745 L p .707 .577 .707 r
F P
0 g
s
.30664 .67587 m .30872 .65717 L .32798 .65388 L p .707 .577 .707 r
F P
0 g
s
.48968 .67732 m .4876 .69601 L .46951 .68856 L p .707 .577 .707 r
F P
0 g
s
.46951 .68856 m .47159 .66987 L .48968 .67732 L p .707 .577 .707 r
F P
0 g
s
.32798 .65388 m .3259 .67258 L .30664 .67587 L p .707 .577 .707 r
F P
0 g
s
.47782 .60154 m .4766 .63874 L .45206 .63283 L p .707 .577 .707 r
F P
0 g
s
.45206 .63283 m .45328 .59562 L .47782 .60154 L p .707 .577 .707 r
F P
0 g
s
.36778 .5665 m .366 .51118 L .3975 .50874 L p .707 .577 .707 r
F P
0 g
s
.366 .51118 m .36778 .5665 L .33946 .57152 L p .707 .577 .707 r
F P
0 g
s
.42911 .50912 m .4309 .56444 L .39929 .56406 L p .707 .577 .707 r
F P
0 g
s
.39929 .56406 m .3975 .50874 L .42911 .50912 L p .707 .577 .707 r
F P
0 g
s
.3325 .63188 m .33372 .59468 L .36076 .59122 L p .707 .577 .707 r
F P
0 g
s
.3975 .50874 m .39929 .56406 L .36778 .5665 L p .707 .577 .707 r
F P
0 g
s
.36076 .59122 m .35954 .62842 L .3325 .63188 L p .707 .577 .707 r
F P
0 g
s
.45328 .59562 m .45206 .63283 L .4224 .62892 L p .707 .577 .707 r
F P
0 g
s
.4224 .62892 m .42362 .59171 L .45328 .59562 L p .707 .577 .707 r
F P
0 g
s
.3259 .67258 m .32798 .65388 L .35411 .65284 L p .707 .577 .707 r
F P
0 g
s
.47159 .66987 m .46951 .68856 L .44423 .6818 L p .707 .577 .707 r
F P
0 g
s
.44423 .6818 m .44632 .66311 L .47159 .66987 L p .707 .577 .707 r
F P
0 g
s
.35411 .65284 m .35203 .67154 L .3259 .67258 L p .707 .577 .707 r
F P
0 g
s
.35954 .62842 m .36076 .59122 L .39174 .5902 L p .707 .577 .707 r
F P
0 g
s
.42362 .59171 m .4224 .62892 L .39052 .6274 L p .707 .577 .707 r
F P
0 g
s
.39052 .6274 m .39174 .5902 L .42362 .59171 L p .707 .577 .707 r
F P
0 g
s
.39174 .5902 m .39052 .6274 L .35954 .62842 L p .707 .577 .707 r
F P
0 g
s
.35203 .67154 m .35411 .65284 L .38455 .65416 L p .707 .577 .707 r
F P
0 g
s
.44632 .66311 m .44423 .6818 L .41424 .67639 L p .707 .577 .707 r
F P
0 g
s
.41424 .67639 m .41632 .65769 L .44632 .66311 L p .707 .577 .707 r
F P
0 g
s
.38455 .65416 m .38247 .67285 L .35203 .67154 L p .707 .577 .707 r
F P
0 g
s
.38247 .67285 m .38455 .65416 L .41632 .65769 L p .707 .577 .707 r
F P
0 g
s
.41632 .65769 m .41424 .67639 L .38247 .67285 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`T000=JEP03001JEUYF00IJEP03001JEUYF009J
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GWoo1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001KOol300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00F7oo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00H005YFFUIJEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005Woo4@00?Woo001DOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00003Woo200015YF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00E7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000Ioo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008003Eoo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0035o
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002ioo`00E7oo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4@0015YF00@005YFFUIJEPH000EJEP04001JEUYFFUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00Oomoo`0/Ool005Aoo`03001JEP0000=JEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEPD0
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00
E7oo00<005YF00000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol00`00FUH00003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUH00000FUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01000FUH005YF0P001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000]Ool005Aoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00T000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001D
Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH00`00FUIJEP02FUH80007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<005YF00001P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH005YF00AJEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00?Goo5`0000=oo`0000000UYF0`000UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000eYF00L005YFFUIJ
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000gOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH400000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YF
FUIJEP8002eoo`00<Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF0P00;Goo000_Ool20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH0000002eoo`00;Woo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002eoo`00;Goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH04@001eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP03001JEUYF009JEPH0009JEP03001JEP0000EJEPH000AJEP03001JEUYF009JEPH0
00EJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<0
05YF00000P0000=JEP0000000P000eYF00<005YF00001EYF1P0015YF00<005YFFUH025YF100000=J
EP00FUH00eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001oogoo02aoo`00;7oo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP80009JEP03
001JEUYF00=JEPH000EJEPH000AJEP03001JEUYF00QJEPL000=JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00Oomoo`0/
Ool002aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<000AJEP03001JEUYF00AJEP04001JEUYFFUHK0003FUH01000FUIJEUYF
0P0000=JEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH>0002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEQh0009JEP03001JEUYF00AJEP03
001JEUYF009JEPT0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF1P000UYF6@001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH015YF00<005YF
FUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`8000=JEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00=JEPD000IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;7oo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF
00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF000010001EYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF1P000UYF00<007ooOol027oo0`002Goo1P00
1EYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool200001EYF000005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00@005YFFUIJEP8000Qoo`D000ioo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH03@0000=JEP0000001`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEPD0
00AJEP04001JEUYFFUH20008Ool5000BOol30003FUH00`00FUH0000]Ool002aoo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH400000eYF
001JEP04FUH01P00FUIJEUYF001JEPT00003FUH0000000L000AJEP03001JEUYF00EJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUH000040003FUH20002Ool;000?Ool30003FUH2000015YF001JEP00;Goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH4
00000eYF001JEP030005FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000T00003FUH0000000@0
00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@000=JEP03001JEUYF00=JEPP000AJEP03001JEUYF009JEPT000Aoo`@00003FUH0
05YF00AJEP<00003FUH007oo02aoo`00;7oo0P0015YF00<005YFFUH00eYF00@005YFFUIJEQP000=J
EP04001JEUYFFUH30003FUH01`00FUIJEUYF001JEP0000EJEPH000AJEP03001JEUYF00IJEP@00003
FUH005YF00AJEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30004FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000AJEP03001JEUYF00=JEP@00003
FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003
0003FUH00`00FUH00005FUH60004FUH00`00FUIJEP08FUH00`00FUH000020003FUH01P00FUIJEP00
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
008002eoo`00;Goo00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF1P001EYF1P0015YF00<005YFFUH025YF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02000]Ool002eoo`800003FUH0
00000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00EJEP03001JEUYF009JEPX000EJEP03001JEUYF00QJEP03001JEUYF00AJEP80
009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000AJEP03
001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP<00005FUH0
05YFFUH0000^Ool002moo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000UJEP03001J
EUYF00=JEP@00004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
0005FUH01000FUIJEUYF20000UYF00<005YFFUH015YF200015YF00<005YFFUH01EYF00<005YFFUH0
0P000UYF00<007ooOol0;7oo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF3`000UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1P001UYF00<005YFFUH00UYF0P00;goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P00;goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00eYF00<0
05YF0000;Woo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUH000030000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH01000FUIJ
EP00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP070004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF1P0015YF00<0
05YFFUH00UYF0`0000=JEP00FUH01eYF00@005YFFUIJEPD0009oo`800005FUH005YFFUH0000]Ool0
02aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00AJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF01P000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP04001JEUYFFUH@0004FUH80009
Ool20002FUH00`00Oomoo`0[Ool002aoo`80009JEP03001JEUYF00=JEP03001JEUYF009JEPP000Eo
o`<000Uoo`P000=JEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEP00FUH005YF10000eYF00@005YFFUIJEP8000Qoo`X0019oo`04001JEP00000]Ool0
02aoo`80009JEP03001JEUYF009JEPH000aoo`D000eoo`P000=JEP800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF008000EJEP800003FUH005YF009JEP8000Qoo`D001Qo
o`<002eoo`00;7oo0P000UYF00<005YF00000P000UYF1`002Goo1@001Goo20000eYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00<000EJ
EP<000=JEP03001oogoo00Qoo`<001Uoo`<002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00@0
05YFFUIJEQ<000=JEP03001JEUYF00EJEP03001JEUYF00=JEP@00003FUH005YF00AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP04001JEUYF0002FUH20003FUH00`00FUIJEP0200000eYF001oo`0UOol3
000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF0`0097oo0P0000=JEP00Ool0
;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP000004FUH00`00FUH0000300001EYF001JEUYF000087oo0`0000AJEP00FUH0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH=0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH00eYF1P006Woo1@0015YF00<005YF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00=JEP`000=JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP02FUH0
0`00FUH0000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEQh0009JEP06001JEUYF
001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
0eYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF001JEP00FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002ioo`80
00=JEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000D00003FUH005YF00AJEP03001JEUYF00D000]JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEPH000IJEP03001JEUYF009JEP05001JEP00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000`
Ool200000eYF000000050003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH015YF0`0015YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00<0
05YF00001@000UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YF000003=oo`00<Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000=JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<0
00AJEP03001JEP0000Eoo`D00003FUH0000000@000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPD003Eoo`00<7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00H005YF001JEP00FUH200000eYF
001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP020002FUH00`00FUH00004Ool30003FUH200001EYF001JEP00Ool02@00
15YF00<005YFFUH00UYF2000>Woo000^Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0003
FUH00`00FUIJEP03FUH200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF
0000000300000eYF001JEP04FUH300000eYF001oo`09Ool90012Ool002eoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH60006Ool3000@Ool60003FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF0000000300000eYF001JEP04FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0004FUH0
0`00FUIJEP04000;Ool5000COol80005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF0000
0003FUH50002FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0002FUH5000?Ool5000>Ool50004
FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P001UYF00<005YF
00000P000UYF0P00EGoo000]Ool00`00FUIJEP03000DOol50006Ool80003FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJ
EP02FUH3001FOol002eoo`<0009JEPh000Qoo`X000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF
009JEP8005Ioo`00;Goo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000H000=JEP03001JEUYF009JEP03001JEP0005Eoo`00;Goo00<005YF000015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`000Woo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`001UYF1@000eYF
00<005YF0000EGoo000]Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2000015YF001JEP00EGoo000^Ool40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2
00000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF00000P000Woo0P00
00=JEP00Ool0E7oo000bOol70003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
000BOol30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH0000015YF00@005YFFUIJEPD000Moo`03001JEP0005Aoo`00>Goo6@00
77oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF10000UYF20002goo00@005YF000005Aoo`00L7oo0`0000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02`004goo00@005YF000005Aoo`00
Lgoo10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1@000Woo1@005Goo0P00
0eYF00<007ooOol0DWoo001gOol60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06
0007Ool5000COol200000eYF001JEP02FUH00`00Oomoo`1BOol007eooal000eoo`D0011oo`<000=J
EP05001JEUYFFUH0001DOol008ioo`<001Uoo`<000moo`800003FUH005YF00AJEP03001JEP0005Eo
o`00SWoo0P0000=JEP0000009Woo0`000eYF00<005YFFUH00eYF0P00EWoo002?Ool01000FUH005YF
0P0087oo10001UYF00<005YFFUH00eYF00<007ooOol0EGoo002?Ool00`00FUH00003FUH5000GOol4
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P00F7oo002?Ool00`00FUH00004FUH01000FUIJEUYF
1`002Goo1`001UYF00<005YFFUH01EYF00@005YF000005Yoo`00T7oo0P0015YF00<005YFFUH015YF
00@005YFFUIJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP<005aoo`00T7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00Ggoo
002AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
001SOol009=oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06Moo`00UGoo1@000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Jgoo002JOolA001bOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60352 .74787 m .60643 .69198 L .57467 .68965 L p .707 .577 .707 r
F P
0 g
s
.60643 .69198 m .60352 .74787 L .63471 .74775 L p .707 .577 .707 r
F P
0 g
s
.63471 .74775 m .63763 .69186 L .60643 .69198 L p .707 .577 .707 r
F P
0 g
s
.57175 .74554 m .57467 .68965 L .54543 .68508 L p .707 .577 .707 r
F P
0 g
s
.57467 .68965 m .57175 .74554 L .60352 .74787 L p .707 .577 .707 r
F P
0 g
s
.63763 .69186 m .63471 .74775 L .66228 .74517 L p .707 .577 .707 r
F P
0 g
s
.66228 .74517 m .6652 .68928 L .63763 .69186 L p .707 .577 .707 r
F P
0 g
s
.54252 .74097 m .54543 .68508 L .5216 .67873 L p .707 .577 .707 r
F P
0 g
s
.54543 .68508 m .54252 .74097 L .57175 .74554 L p .707 .577 .707 r
F P
0 g
s
.58574 .81373 m .58374 .77706 L .55309 .77592 L p .707 .577 .707 r
F P
0 g
s
.58374 .77706 m .58574 .81373 L .61765 .81185 L p .707 .577 .707 r
F P
0 g
s
.61765 .81185 m .61565 .77518 L .58374 .77706 L p .707 .577 .707 r
F P
0 g
s
.61565 .77518 m .61765 .81185 L .6477 .80715 L p .707 .577 .707 r
F P
0 g
s
.6477 .80715 m .6457 .77048 L .61565 .77518 L p .707 .577 .707 r
F P
0 g
s
.6652 .68928 m .66228 .74517 L .68352 .7404 L p .707 .577 .707 r
F P
0 g
s
.68352 .7404 m .68644 .68451 L .6652 .68928 L p .707 .577 .707 r
F P
0 g
s
.5216 .67873 m .51868 .73462 L .54252 .74097 L p .707 .577 .707 r
F P
0 g
s
.55509 .81259 m .55309 .77592 L .52671 .77187 L p .707 .577 .707 r
F P
0 g
s
.55309 .77592 m .55509 .81259 L .58574 .81373 L p .707 .577 .707 r
F P
0 g
s
.6457 .77048 m .6477 .80715 L .67294 .80007 L p .707 .577 .707 r
F P
0 g
s
.67294 .80007 m .67094 .7634 L .6457 .77048 L p .707 .577 .707 r
F P
0 g
s
.51868 .73462 m .5216 .67873 L .5055 .67121 L p .707 .577 .707 r
F P
0 g
s
.52671 .77187 m .52871 .80854 L .55509 .81259 L p .707 .577 .707 r
F P
0 g
s
.59915 .86307 m .59576 .84553 L .56499 .84812 L p .707 .577 .707 r
F P
0 g
s
.59576 .84553 m .59915 .86307 L .63045 .85664 L p .707 .577 .707 r
F P
0 g
s
.63045 .85664 m .62706 .83909 L .59576 .84553 L p .707 .577 .707 r
F P
0 g
s
.62706 .83909 m .63045 .85664 L .65921 .84699 L p .707 .577 .707 r
F P
0 g
s
.65921 .84699 m .65582 .82945 L .62706 .83909 L p .707 .577 .707 r
F P
0 g
s
.68644 .68451 m .68352 .7404 L .69636 .7339 L p .707 .577 .707 r
F P
0 g
s
.69636 .7339 m .69928 .67801 L .68644 .68451 L p .707 .577 .707 r
F P
0 g
s
.52871 .80854 m .52671 .77187 L .50717 .76532 L p .707 .577 .707 r
F P
0 g
s
.5055 .67121 m .50258 .7271 L .51868 .73462 L p .707 .577 .707 r
F P
0 g
s
.56499 .84812 m .56838 .86567 L .59915 .86307 L p .707 .577 .707 r
F P
0 g
s
.67094 .7634 m .67294 .80007 L .69092 .79131 L p .707 .577 .707 r
F P
0 g
s
.69092 .79131 m .68892 .75464 L .67094 .7634 L p .707 .577 .707 r
F P
0 g
s
.56838 .86567 m .56499 .84812 L .53777 .84662 L p .707 .577 .707 r
F P
0 g
s
.65582 .82945 m .65921 .84699 L .68263 .83508 L p .707 .577 .707 r
F P
0 g
s
.68263 .83508 m .67924 .81754 L .65582 .82945 L p .707 .577 .707 r
F P
0 g
s
.53777 .84662 m .54116 .86417 L .56838 .86567 L p .707 .577 .707 r
F P
0 g
s
.50717 .76532 m .50917 .80199 L .52871 .80854 L p .707 .577 .707 r
F P
0 g
s
.50258 .7271 m .5055 .67121 L .4987 .66327 L p .707 .577 .707 r
F P
0 g
s
.54116 .86417 m .53777 .84662 L .51675 .84118 L p .707 .577 .707 r
F P
0 g
s
.67924 .81754 m .68263 .83508 L .69841 .82207 L p .707 .577 .707 r
F P
0 g
s
.69841 .82207 m .69502 .80453 L .67924 .81754 L p .707 .577 .707 r
F P
0 g
s
.50917 .80199 m .50717 .76532 L .49639 .75689 L p .707 .577 .707 r
F P
0 g
s
.69928 .67801 m .69636 .7339 L .69954 .7263 L p .707 .577 .707 r
F P
0 g
s
.69954 .7263 m .70245 .67041 L .69928 .67801 L p .707 .577 .707 r
F P
0 g
s
.51675 .84118 m .52014 .85872 L .54116 .86417 L p .707 .577 .707 r
F P
0 g
s
.4987 .66327 m .49579 .71915 L .50258 .7271 L p .707 .577 .707 r
F P
0 g
s
.68892 .75464 m .69092 .79131 L .69986 .78173 L p .707 .577 .707 r
F P
0 g
s
.69986 .78173 m .69786 .74506 L .68892 .75464 L p .707 .577 .707 r
F P
0 g
s
.49639 .75689 m .49839 .79357 L .50917 .80199 L p .707 .577 .707 r
F P
0 g
s
.52014 .85872 m .51675 .84118 L .504 .83232 L p .707 .577 .707 r
F P
0 g
s
.49579 .71915 m .4987 .66327 L .50188 .65567 L p .707 .577 .707 r
F P
0 g
s
.69502 .80453 m .69841 .82207 L .705 .80924 L p .707 .577 .707 r
F P
0 g
s
.705 .80924 m .70161 .79169 L .69502 .80453 L p .707 .577 .707 r
F P
0 g
s
.504 .83232 m .50739 .84987 L .52014 .85872 L p .707 .577 .707 r
F P
0 g
s
.49839 .79357 m .49639 .75689 L .49543 .74743 L p .708 .578 .707 r
F P
0 g
s
.50188 .65567 m .49896 .71156 L .49579 .71915 L p .707 .577 .707 r
F P
0 g
s
.49543 .74743 m .49743 .7841 L .49839 .79357 L p .708 .578 .707 r
F P
0 g
s
.49743 .7841 m .49543 .74743 L .50437 .73785 L p .707 .577 .707 r
F P
0 g
s
.49723 .82192 m .49723 .32003 L .4528 .3179 L p .707 .577 .707 r
F P
0 g
s
.50739 .84987 m .504 .83232 L .50076 .82092 L p .707 .577 .707 r
F P
0 g
s
.49896 .71156 m .50188 .65567 L .51472 .64917 L p .707 .577 .707 r
F P
0 g
s
.50076 .82092 m .50415 .83846 L .50739 .84987 L p .707 .577 .707 r
F P
0 g
s
.51472 .64917 m .5118 .70506 L .49896 .71156 L p .707 .577 .707 r
F P
0 g
s
.50437 .73785 m .50637 .77452 L .49743 .7841 L p .707 .577 .707 r
F P
0 g
s
.50415 .83846 m .50076 .82092 L .50735 .80808 L p .707 .577 .707 r
F P
0 g
s
.5118 .70506 m .51472 .64917 L .53596 .6444 L p .707 .577 .707 r
F P
0 g
s
.50735 .80808 m .51075 .82562 L .50415 .83846 L p .707 .577 .707 r
F P
0 g
s
.50637 .77452 m .50437 .73785 L .52234 .72909 L p .707 .577 .707 r
F P
0 g
s
.53596 .6444 m .53304 .70028 L .5118 .70506 L p .707 .577 .707 r
F P
0 g
s
.52234 .72909 m .52434 .76576 L .50637 .77452 L p .707 .577 .707 r
F P
0 g
s
.51075 .82562 m .50735 .80808 L .52313 .79507 L p .707 .577 .707 r
F P
0 g
s
.52313 .79507 m .52652 .81261 L .51075 .82562 L p .707 .577 .707 r
F P
0 g
s
.52434 .76576 m .52234 .72909 L .54759 .72201 L p .707 .577 .707 r
F P
0 g
s
.54759 .72201 m .54959 .75868 L .52434 .76576 L p .707 .577 .707 r
F P
0 g
s
.52652 .81261 m .52313 .79507 L .54655 .78316 L p .707 .577 .707 r
F P
0 g
s
.54655 .78316 m .54994 .8007 L .52652 .81261 L p .707 .577 .707 r
F P
0 g
s
.49723 .32003 m .49723 .82192 L .54194 .82025 L p .707 .577 .707 r
F P
0 g
s
.53304 .70028 m .53596 .6444 L .56353 .64182 L p .707 .577 .707 r
F P
0 g
s
.56353 .64182 m .56061 .69771 L .53304 .70028 L p .707 .577 .707 r
F P
0 g
s
.54194 .82025 m .54194 .31836 L .49723 .32003 L p .707 .577 .707 r
F P
0 g
s
.69786 .74506 m .69986 .78173 L .69889 .77226 L p .708 .578 .707 r
F P
0 g
s
.69889 .77226 m .69689 .73559 L .69786 .74506 L p .708 .578 .707 r
F P
0 g
s
.70245 .67041 m .69954 .7263 L .69274 .71836 L p .707 .577 .707 r
F P
0 g
s
.69274 .71836 m .69566 .66247 L .70245 .67041 L p .707 .577 .707 r
F P
0 g
s
.56061 .69771 m .56353 .64182 L .59472 .6417 L p .707 .577 .707 r
F P
0 g
s
.59472 .6417 m .59181 .69758 L .56061 .69771 L p .707 .577 .707 r
F P
0 g
s
.54959 .75868 m .54759 .72201 L .57764 .7173 L p .707 .577 .707 r
F P
0 g
s
.57764 .7173 m .57964 .75398 L .54959 .75868 L p .707 .577 .707 r
F P
0 g
s
.54994 .8007 m .54655 .78316 L .57531 .77352 L p .707 .577 .707 r
F P
0 g
s
.57531 .77352 m .57871 .79106 L .54994 .8007 L p .707 .577 .707 r
F P
0 g
s
.57871 .79106 m .57531 .77352 L .60661 .76708 L p .707 .577 .707 r
F P
0 g
s
.60661 .76708 m .61001 .78463 L .57871 .79106 L p .707 .577 .707 r
F P
0 g
s
.54194 .31836 m .54194 .82025 L .58253 .81496 L p .707 .577 .707 r
F P
0 g
s
.57964 .75398 m .57764 .7173 L .60955 .71543 L p .707 .577 .707 r
F P
0 g
s
.60955 .71543 m .61155 .7521 L .57964 .75398 L p .707 .577 .707 r
F P
0 g
s
.58253 .81496 m .58253 .31307 L .54194 .31836 L p .707 .577 .707 r
F P
0 g
s
.4528 .81979 m .4528 .3179 L .41299 .3122 L p .707 .577 .707 r
F P
0 g
s
.4528 .3179 m .4528 .81979 L .49723 .82192 L p .707 .577 .707 r
F P
0 g
s
.70161 .79169 m .705 .80924 L .70176 .79783 L p .707 .577 .707 r
F P
0 g
s
.70176 .79783 m .69837 .78029 L .70161 .79169 L p .707 .577 .707 r
F P
0 g
s
.62649 .64403 m .62357 .69992 L .59181 .69758 L p .707 .577 .707 r
F P
0 g
s
.59181 .69758 m .59472 .6417 L .62649 .64403 L p .707 .577 .707 r
F P
0 g
s
.63738 .76449 m .64077 .78203 L .61001 .78463 L p .707 .577 .707 r
F P
0 g
s
.61001 .78463 m .60661 .76708 L .63738 .76449 L p .707 .577 .707 r
F P
0 g
s
.58253 .31307 m .58253 .81496 L .61505 .80656 L p .707 .577 .707 r
F P
0 g
s
.64019 .71657 m .64219 .75324 L .61155 .7521 L p .707 .577 .707 r
F P
0 g
s
.61155 .7521 m .60955 .71543 L .64019 .71657 L p .707 .577 .707 r
F P
0 g
s
.61505 .80656 m .61505 .30468 L .58253 .31307 L p .707 .577 .707 r
F P
0 g
s
.41299 .81409 m .41299 .3122 L .3817 .30348 L p .707 .577 .707 r
F P
0 g
s
.41299 .3122 m .41299 .81409 L .4528 .81979 L p .707 .577 .707 r
F P
0 g
s
.69689 .73559 m .69889 .77226 L .68811 .76384 L p .707 .577 .707 r
F P
0 g
s
.68811 .76384 m .68611 .72717 L .69689 .73559 L p .707 .577 .707 r
F P
0 g
s
.69566 .66247 m .69274 .71836 L .67664 .71084 L p .707 .577 .707 r
F P
0 g
s
.67664 .71084 m .67956 .65495 L .69566 .66247 L p .707 .577 .707 r
F P
0 g
s
.26351 .71579 m .26481 .66097 L .23301 .6593 L p .707 .577 .707 r
F P
0 g
s
.26481 .66097 m .26351 .71579 L .29474 .71434 L p .707 .577 .707 r
F P
0 g
s
.29474 .71434 m .29603 .65952 L .26481 .66097 L p .707 .577 .707 r
F P
0 g
s
.23171 .71412 m .23301 .6593 L .20374 .65468 L p .707 .577 .707 r
F P
0 g
s
.23301 .6593 m .23171 .71412 L .26351 .71579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29603 .65952 m .29474 .71434 L .32233 .70991 L p .707 .577 .707 r
F P
0 g
s
.32233 .70991 m .32363 .65509 L .29603 .65952 L p .707 .577 .707 r
F P
0 g
s
.20245 .7095 m .20374 .65468 L .17988 .64755 L p .707 .577 .707 r
F P
0 g
s
.20374 .65468 m .20245 .7095 L .23171 .71412 L p .707 .577 .707 r
F P
0 g
s
.69837 .78029 m .70176 .79783 L .68901 .78897 L p .707 .577 .707 r
F P
0 g
s
.68901 .78897 m .68562 .77143 L .69837 .78029 L p .707 .577 .707 r
F P
0 g
s
.65572 .6486 m .6528 .70449 L .62357 .69992 L p .707 .577 .707 r
F P
0 g
s
.62357 .69992 m .62649 .64403 L .65572 .6486 L p .707 .577 .707 r
F P
0 g
s
.61505 .30468 m .61505 .80656 L .6363 .79588 L p .707 .577 .707 r
F P
0 g
s
.6363 .79588 m .6363 .29399 L .61505 .30468 L p .707 .577 .707 r
F P
0 g
s
.32363 .65509 m .32233 .70991 L .34359 .70294 L p .707 .577 .707 r
F P
0 g
s
.34359 .70294 m .34488 .64812 L .32363 .65509 L p .707 .577 .707 r
F P
0 g
s
.24519 .768 m .24428 .73057 L .2136 .72923 L p .707 .577 .707 r
F P
0 g
s
.24428 .73057 m .24519 .768 L .27713 .76704 L p .707 .577 .707 r
F P
0 g
s
.27713 .76704 m .27622 .72962 L .24428 .73057 L p .707 .577 .707 r
F P
0 g
s
.27622 .72962 m .27713 .76704 L .30721 .76387 L p .707 .577 .707 r
F P
0 g
s
.30721 .76387 m .3063 .72644 L .27622 .72962 L p .707 .577 .707 r
F P
0 g
s
.3817 .80536 m .3817 .30348 L .36198 .29258 L p .707 .577 .707 r
F P
0 g
s
.3817 .30348 m .3817 .80536 L .41299 .81409 L p .707 .577 .707 r
F P
0 g
s
.67956 .65495 m .67664 .71084 L .6528 .70449 L p .707 .577 .707 r
F P
0 g
s
.6528 .70449 m .65572 .6486 L .67956 .65495 L p .707 .577 .707 r
F P
0 g
s
.68611 .72717 m .68811 .76384 L .66858 .75729 L p .707 .577 .707 r
F P
0 g
s
.66858 .75729 m .66658 .72062 L .68611 .72717 L p .707 .577 .707 r
F P
0 g
s
.2136 .72923 m .21451 .76666 L .24519 .768 L p .707 .577 .707 r
F P
0 g
s
.21451 .76666 m .2136 .72923 L .18719 .72571 L p .707 .577 .707 r
F P
0 g
s
.17988 .64755 m .17858 .70237 L .20245 .7095 L p .707 .577 .707 r
F P
0 g
s
.25524 .80286 m .25368 .78389 L .22252 .78544 L p .707 .577 .707 r
F P
0 g
s
.25368 .78389 m .25524 .80286 L .28693 .79982 L p .707 .577 .707 r
F P
0 g
s
.28693 .79982 m .28536 .78085 L .25368 .78389 L p .707 .577 .707 r
F P
0 g
s
.3063 .72644 m .30721 .76387 L .33248 .7588 L p .707 .577 .707 r
F P
0 g
s
.33248 .7588 m .33157 .72137 L .3063 .72644 L p .707 .577 .707 r
F P
0 g
s
.17858 .70237 m .17988 .64755 L .16375 .63862 L p .707 .577 .707 r
F P
0 g
s
.22252 .78544 m .22408 .80441 L .25524 .80286 L p .707 .577 .707 r
F P
0 g
s
.28536 .78085 m .28693 .79982 L .31605 .79561 L p .707 .577 .707 r
F P
0 g
s
.31605 .79561 m .31448 .77664 L .28536 .78085 L p .707 .577 .707 r
F P
0 g
s
.22408 .80441 m .22252 .78544 L .19494 .78536 L p .707 .577 .707 r
F P
0 g
s
.18719 .72571 m .1881 .76314 L .21451 .76666 L p .707 .577 .707 r
F P
0 g
s
.19494 .78536 m .1965 .80433 L .22408 .80441 L p .707 .577 .707 r
F P
0 g
s
.34488 .64812 m .34359 .70294 L .35643 .69411 L p .707 .577 .707 r
F P
0 g
s
.35643 .69411 m .35773 .63929 L .34488 .64812 L p .707 .577 .707 r
F P
0 g
s
.68562 .77143 m .68901 .78897 L .668 .78353 L p .707 .577 .707 r
F P
0 g
s
.668 .78353 m .6646 .76598 L .68562 .77143 L p .707 .577 .707 r
F P
0 g
s
.31448 .77664 m .31605 .79561 L .33975 .79062 L p .707 .577 .707 r
F P
0 g
s
.33975 .79062 m .33818 .77165 L .31448 .77664 L p .707 .577 .707 r
F P
0 g
s
.1881 .76314 m .18719 .72571 L .16762 .72037 L p .707 .577 .707 r
F P
0 g
s
.66658 .72062 m .66858 .75729 L .64219 .75324 L p .707 .577 .707 r
F P
0 g
s
.64219 .75324 m .64019 .71657 L .66658 .72062 L p .707 .577 .707 r
F P
0 g
s
.16375 .63862 m .16245 .69344 L .17858 .70237 L p .707 .577 .707 r
F P
0 g
s
.33157 .72137 m .33248 .7588 L .35047 .75233 L p .707 .577 .707 r
F P
0 g
s
.35047 .75233 m .34956 .7149 L .33157 .72137 L p .707 .577 .707 r
F P
0 g
s
.1965 .80433 m .19494 .78536 L .17364 .78366 L p .707 .577 .707 r
F P
0 g
s
.6646 .76598 m .668 .78353 L .64077 .78203 L p .707 .577 .707 r
F P
0 g
s
.64077 .78203 m .63738 .76449 L .6646 .76598 L p .707 .577 .707 r
F P
0 g
s
.6363 .29399 m .6363 .79588 L .64422 .78396 L p .707 .577 .707 r
F P
0 g
s
.64422 .78396 m .64422 .28207 L .6363 .29399 L p .707 .577 .707 r
F P
0 g
s
.16762 .72037 m .16853 .7578 L .1881 .76314 L p .707 .577 .707 r
F P
0 g
s
.17364 .78366 m .17521 .80263 L .1965 .80433 L p .707 .577 .707 r
F P
0 g
s
.16245 .69344 m .16375 .63862 L .15694 .62876 L p .707 .577 .707 r
F P
0 g
s
.3596 .68428 m .3609 .62946 L .35773 .63929 L p .707 .577 .707 r
F P
0 g
s
.35414 .76638 m .3557 .78535 L .36236 .78031 L p .707 .577 .707 r
F P
0 g
s
.36236 .78031 m .36079 .76135 L .35414 .76638 L p .707 .577 .707 r
F P
0 g
s
.35773 .63929 m .35643 .69411 L .3596 .68428 L p .707 .577 .707 r
F P
0 g
s
.3609 .62946 m .3596 .68428 L .35279 .67442 L p .707 .577 .707 r
F P
0 g
s
.35279 .67442 m .35409 .6196 L .3609 .62946 L p .707 .577 .707 r
F P
0 g
s
.36079 .76135 m .36236 .78031 L .35906 .77601 L p .707 .577 .707 r
F P
0 g
s
.36198 .79447 m .36198 .29258 L .35578 .28059 L p .707 .577 .707 r
F P
0 g
s
.36198 .29258 m .36198 .79447 L .3817 .80536 L p .707 .577 .707 r
F P
0 g
s
.33818 .77165 m .33975 .79062 L .3557 .78535 L p .707 .577 .707 r
F P
0 g
s
.3557 .78535 m .35414 .76638 L .33818 .77165 L p .707 .577 .707 r
F P
0 g
s
.16853 .7578 m .16762 .72037 L .15683 .71372 L p .707 .577 .707 r
F P
0 g
s
.15694 .62876 m .15564 .68358 L .16245 .69344 L p .707 .577 .707 r
F P
0 g
s
.34956 .7149 m .35047 .75233 L .35942 .74509 L p .707 .577 .707 r
F P
0 g
s
.35942 .74509 m .35851 .70766 L .34956 .7149 L p .707 .577 .707 r
F P
0 g
s
.17521 .80263 m .17364 .78366 L .16071 .7805 L p .707 .577 .707 r
F P
0 g
s
.16071 .7805 m .16227 .79947 L .17521 .80263 L p .707 .577 .707 r
F P
0 g
s
.15683 .71372 m .15774 .75115 L .16853 .7578 L p .707 .577 .707 r
F P
0 g
s
.15564 .68358 m .15694 .62876 L .16011 .61893 L p .707 .577 .707 r
F P
0 g
s
.64422 .28207 m .64422 .78396 L .63801 .77197 L p .707 .577 .707 r
F P
0 g
s
.63801 .77197 m .63801 .27008 L .64422 .28207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15774 .75115 m .15683 .71372 L .15586 .70641 L p .707 .578 .707 r
F P
0 g
s
.35851 .70766 m .35942 .74509 L .35845 .73778 L p .707 .578 .707 r
F P
0 g
s
.35845 .73778 m .35754 .70035 L .35851 .70766 L p .707 .578 .707 r
F P
0 g
s
.35906 .77601 m .35749 .75704 L .36079 .76135 L p .707 .577 .707 r
F P
0 g
s
.35754 .70035 m .35845 .73778 L .34765 .73113 L p .707 .577 .707 r
F P
0 g
s
.34765 .73113 m .34674 .6937 L .35754 .70035 L p .707 .577 .707 r
F P
0 g
s
.35749 .75704 m .35906 .77601 L .34612 .77285 L p .707 .577 .707 r
F P
0 g
s
.34612 .77285 m .34456 .75388 L .35749 .75704 L p .707 .577 .707 r
F P
0 g
s
.35578 .28059 m .35578 .78248 L .36198 .79447 L p .707 .577 .707 r
F P
0 g
s
.35578 .78248 m .35578 .28059 L .36369 .26867 L p .707 .577 .707 r
F P
0 g
s
.16011 .61893 m .15882 .67375 L .15564 .68358 L p .707 .577 .707 r
F P
0 g
s
.16227 .79947 m .16071 .7805 L .15741 .77619 L p .707 .577 .707 r
F P
0 g
s
.15741 .77619 m .15897 .79516 L .16227 .79947 L p .707 .577 .707 r
F P
0 g
s
.15586 .70641 m .15677 .74384 L .15774 .75115 L p .707 .578 .707 r
F P
0 g
s
.15882 .67375 m .16011 .61893 L .17296 .6101 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35409 .6196 m .35279 .67442 L .33666 .66549 L p .707 .577 .707 r
F P
0 g
s
.33666 .66549 m .33796 .61067 L .35409 .6196 L p .707 .577 .707 r
F P
0 g
s
.15677 .74384 m .15586 .70641 L .1648 .69917 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17296 .6101 m .17166 .66492 L .15882 .67375 L p .707 .577 .707 r
F P
0 g
s
.15897 .79516 m .15741 .77619 L .16407 .77116 L p .707 .577 .707 r
F P
0 g
s
.16407 .77116 m .16563 .79013 L .15897 .79516 L p .707 .577 .707 r
F P
0 g
s
.1648 .69917 m .16571 .7366 L .15677 .74384 L p .707 .577 .707 r
F P
0 g
s
.63801 .27008 m .63801 .77197 L .6183 .76107 L p .707 .577 .707 r
F P
0 g
s
.6183 .76107 m .6183 .25918 L .63801 .27008 L p .707 .577 .707 r
F P
0 g
s
.17166 .66492 m .17296 .6101 L .19422 .60313 L p .707 .577 .707 r
F P
0 g
s
.36369 .77055 m .36369 .26867 L .38495 .25798 L p .707 .577 .707 r
F P
0 g
s
.36369 .26867 m .36369 .77055 L .35578 .78248 L p .707 .577 .707 r
F P
0 g
s
.33796 .61067 m .33666 .66549 L .3128 .65836 L p .707 .577 .707 r
F P
0 g
s
.3128 .65836 m .3141 .60354 L .33796 .61067 L p .707 .577 .707 r
F P
0 g
s
.16571 .7366 m .1648 .69917 L .18279 .69269 L p .707 .577 .707 r
F P
0 g
s
.19422 .60313 m .19292 .65795 L .17166 .66492 L p .707 .577 .707 r
F P
0 g
s
.34674 .6937 m .34765 .73113 L .32809 .72578 L p .707 .577 .707 r
F P
0 g
s
.32809 .72578 m .32718 .68835 L .34674 .6937 L p .707 .577 .707 r
F P
0 g
s
.19292 .65795 m .19422 .60313 L .22181 .5987 L p .707 .577 .707 r
F P
0 g
s
.16563 .79013 m .16407 .77116 L .18002 .76589 L p .707 .577 .707 r
F P
0 g
s
.18279 .69269 m .1837 .73012 L .16571 .7366 L p .707 .577 .707 r
F P
0 g
s
.18002 .76589 m .18159 .78486 L .16563 .79013 L p .707 .577 .707 r
F P
0 g
s
.3141 .60354 m .3128 .65836 L .28353 .65374 L p .707 .577 .707 r
F P
0 g
s
.28353 .65374 m .28483 .59892 L .3141 .60354 L p .707 .577 .707 r
F P
0 g
s
.6183 .25918 m .6183 .76107 L .58701 .75235 L p .707 .577 .707 r
F P
0 g
s
.58701 .75235 m .58701 .25046 L .6183 .25918 L p .707 .577 .707 r
F P
0 g
s
.22051 .65352 m .22181 .5987 L .25303 .59725 L p .707 .577 .707 r
F P
0 g
s
.22181 .5987 m .22051 .65352 L .19292 .65795 L p .707 .577 .707 r
F P
0 g
s
.38495 .25798 m .38495 .75987 L .36369 .77055 L p .707 .577 .707 r
F P
0 g
s
.38495 .75987 m .38495 .25798 L .41747 .24959 L p .707 .577 .707 r
F P
0 g
s
.34456 .75388 m .34612 .77285 L .32483 .77114 L p .707 .577 .707 r
F P
0 g
s
.32483 .77114 m .32326 .75217 L .34456 .75388 L p .707 .577 .707 r
F P
0 g
s
.1837 .73012 m .18279 .69269 L .20806 .68762 L p .707 .577 .707 r
F P
0 g
s
.74826 .65425 m .74697 .59805 L .71516 .59803 L p .707 .577 .707 r
F P
0 g
s
.74697 .59805 m .74826 .65425 L .77949 .65203 L p .707 .577 .707 r
F P
0 g
s
.77949 .65203 m .77819 .59583 L .74697 .59805 L p .707 .577 .707 r
F P
0 g
s
.28483 .59892 m .28353 .65374 L .25173 .65207 L p .707 .577 .707 r
F P
0 g
s
.25173 .65207 m .25303 .59725 L .28483 .59892 L p .707 .577 .707 r
F P
0 g
s
.25303 .59725 m .25173 .65207 L .22051 .65352 L p .707 .577 .707 r
F P
0 g
s
.71646 .65424 m .71516 .59803 L .6859 .59578 L p .707 .577 .707 r
F P
0 g
s
.71516 .59803 m .71646 .65424 L .74826 .65425 L p .707 .577 .707 r
F P
0 g
s
.32718 .68835 m .32809 .72578 L .30168 .72227 L p .707 .577 .707 r
F P
0 g
s
.30168 .72227 m .30077 .68484 L .32718 .68835 L p .707 .577 .707 r
F P
0 g
s
.77819 .59583 m .77949 .65203 L .80708 .6478 L p .707 .577 .707 r
F P
0 g
s
.80708 .6478 m .80578 .59159 L .77819 .59583 L p .707 .577 .707 r
F P
0 g
s
.18159 .78486 m .18002 .76589 L .20372 .7609 L p .707 .577 .707 r
F P
0 g
s
.20806 .68762 m .20898 .72505 L .1837 .73012 L p .707 .577 .707 r
F P
0 g
s
.20372 .7609 m .20528 .77987 L .18159 .78486 L p .707 .577 .707 r
F P
0 g
s
.6872 .65199 m .6859 .59578 L .66204 .59152 L p .707 .577 .707 r
F P
0 g
s
.6859 .59578 m .6872 .65199 L .71646 .65424 L p .707 .577 .707 r
F P
0 g
s
.20898 .72505 m .20806 .68762 L .23814 .68445 L p .707 .577 .707 r
F P
0 g
s
.30077 .68484 m .30168 .72227 L .271 .72092 L p .707 .577 .707 r
F P
0 g
s
.271 .72092 m .27009 .68349 L .30077 .68484 L p .707 .577 .707 r
F P
0 g
s
.32326 .75217 m .32483 .77114 L .29725 .77107 L p .707 .577 .707 r
F P
0 g
s
.29725 .77107 m .29569 .7521 L .32326 .75217 L p .707 .577 .707 r
F P
0 g
s
.729 .72246 m .72991 .68586 L .69923 .68242 L p .707 .577 .707 r
F P
0 g
s
.72991 .68586 m .729 .72246 L .76094 .72288 L p .707 .577 .707 r
F P
0 g
s
.76094 .72288 m .76185 .68628 L .72991 .68586 L p .707 .577 .707 r
F P
0 g
s
.80578 .59159 m .80708 .6478 L .82834 .64196 L p .707 .577 .707 r
F P
0 g
s
.82834 .64196 m .82704 .58576 L .80578 .59159 L p .707 .577 .707 r
F P
0 g
s
.76185 .68628 m .76094 .72288 L .79102 .72025 L p .707 .577 .707 r
F P
0 g
s
.79102 .72025 m .79193 .68365 L .76185 .68628 L p .707 .577 .707 r
F P
0 g
s
.58701 .25046 m .58701 .75235 L .54719 .74664 L p .707 .577 .707 r
F P
0 g
s
.54719 .74664 m .54719 .24475 L .58701 .25046 L p .707 .577 .707 r
F P
0 g
s
.41747 .75148 m .41747 .24959 L .45806 .2443 L p .707 .577 .707 r
F P
0 g
s
.41747 .24959 m .41747 .75148 L .38495 .75987 L p .707 .577 .707 r
F P
0 g
s
.23814 .68445 m .23905 .72188 L .20898 .72505 L p .707 .577 .707 r
F P
0 g
s
.66204 .59152 m .66334 .64773 L .6872 .65199 L p .707 .577 .707 r
F P
0 g
s
.20528 .77987 m .20372 .7609 L .23284 .75668 L p .707 .577 .707 r
F P
0 g
s
.23905 .72188 m .23814 .68445 L .27009 .68349 L p .707 .577 .707 r
F P
0 g
s
.69832 .71902 m .69923 .68242 L .67282 .67631 L p .707 .577 .707 r
F P
0 g
s
.69923 .68242 m .69832 .71902 L .729 .72246 L p .707 .577 .707 r
F P
0 g
s
.27009 .68349 m .271 .72092 L .23905 .72188 L p .707 .577 .707 r
F P
0 g
s
.23284 .75668 m .2344 .77565 L .20528 .77987 L p .707 .577 .707 r
F P
0 g
s
.79193 .68365 m .79102 .72025 L .81629 .71481 L p .707 .577 .707 r
F P
0 g
s
.81629 .71481 m .81721 .67821 L .79193 .68365 L p .707 .577 .707 r
F P
0 g
s
.66334 .64773 m .66204 .59152 L .64591 .58567 L p .707 .577 .707 r
F P
0 g
s
.29569 .7521 m .29725 .77107 L .26609 .77262 L p .707 .577 .707 r
F P
0 g
s
.26609 .77262 m .26453 .75365 L .29569 .7521 L p .707 .577 .707 r
F P
0 g
s
.67282 .67631 m .67191 .7129 L .69832 .71902 L p .707 .577 .707 r
F P
0 g
s
.2344 .77565 m .23284 .75668 L .26453 .75365 L p .707 .577 .707 r
F P
0 g
s
.26453 .75365 m .26609 .77262 L .2344 .77565 L p .707 .577 .707 r
F P
0 g
s
.54719 .24475 m .54719 .74664 L .50276 .74452 L p .707 .577 .707 r
F P
0 g
s
.50276 .74452 m .50276 .24263 L .54719 .24475 L p .707 .577 .707 r
F P
0 g
s
.82704 .58576 m .82834 .64196 L .84118 .63509 L p .707 .577 .707 r
F P
0 g
s
.84118 .63509 m .83988 .57889 L .82704 .58576 L p .707 .577 .707 r
F P
0 g
s
.73391 .7711 m .73547 .75343 L .70431 .7485 L p .707 .577 .707 r
F P
0 g
s
.73547 .75343 m .73391 .7711 L .7656 .77219 L p .707 .577 .707 r
F P
0 g
s
.7656 .77219 m .76716 .75453 L .73547 .75343 L p .707 .577 .707 r
F P
0 g
s
.45806 .74619 m .45806 .2443 L .50276 .24263 L p .707 .577 .707 r
F P
0 g
s
.45806 .2443 m .45806 .74619 L .41747 .75148 L p .707 .577 .707 r
F P
0 g
s
.67191 .7129 m .67282 .67631 L .65326 .66811 L p .707 .577 .707 r
F P
0 g
s
.76716 .75453 m .7656 .77219 L .79471 .76934 L p .707 .577 .707 r
F P
0 g
s
.79471 .76934 m .79628 .75168 L .76716 .75453 L p .707 .577 .707 r
F P
0 g
s
.64591 .58567 m .64721 .64187 L .66334 .64773 L p .707 .577 .707 r
F P
0 g
s
.70275 .76616 m .70431 .7485 L .67673 .74021 L p .707 .577 .707 r
F P
0 g
s
.70431 .7485 m .70275 .76616 L .73391 .7711 L p .707 .577 .707 r
F P
0 g
s
.81721 .67821 m .81629 .71481 L .83428 .70711 L p .707 .577 .707 r
F P
0 g
s
.83428 .70711 m .8352 .67051 L .81721 .67821 L p .707 .577 .707 r
F P
0 g
s
.50276 .24263 m .50276 .74452 L .45806 .74619 L p .707 .577 .707 r
F P
0 g
s
.67673 .74021 m .67517 .75787 L .70275 .76616 L p .707 .577 .707 r
F P
0 g
s
.65326 .66811 m .65234 .70471 L .67191 .7129 L p .707 .577 .707 r
F P
0 g
s
.79628 .75168 m .79471 .76934 L .81841 .76282 L p .707 .577 .707 r
F P
0 g
s
.81841 .76282 m .81998 .74516 L .79628 .75168 L p .707 .577 .707 r
F P
0 g
s
.64721 .64187 m .64591 .58567 L .6391 .57879 L p .707 .577 .707 r
F P
0 g
s
.67517 .75787 m .67673 .74021 L .65544 .72937 L p .707 .577 .707 r
F P
0 g
s
.65234 .70471 m .65326 .66811 L .64246 .65863 L p .707 .577 .707 r
F P
0 g
s
.65544 .72937 m .65387 .74703 L .67517 .75787 L p .707 .577 .707 r
F P
0 g
s
.83988 .57889 m .84118 .63509 L .84435 .62786 L p .707 .577 .707 r
F P
0 g
s
.84435 .62786 m .84305 .57166 L .83988 .57889 L p .707 .577 .707 r
F P
0 g
s
.6391 .57879 m .6404 .63499 L .64721 .64187 L p .707 .577 .707 r
F P
0 g
s
.8352 .67051 m .83428 .70711 L .84323 .69789 L p .707 .577 .707 r
F P
0 g
s
.84323 .69789 m .84414 .6613 L .8352 .67051 L p .707 .577 .707 r
F P
0 g
s
.64246 .65863 m .64155 .69523 L .65234 .70471 L p .707 .577 .707 r
F P
0 g
s
.81998 .74516 m .81841 .76282 L .83437 .75327 L p .707 .577 .707 r
F P
0 g
s
.83437 .75327 m .83593 .73561 L .81998 .74516 L p .707 .577 .707 r
F P
0 g
s
.65387 .74703 m .65544 .72937 L .6425 .71705 L p .707 .577 .707 r
F P
0 g
s
.6425 .71705 m .64094 .73471 L .65387 .74703 L p .707 .577 .707 r
F P
0 g
s
.6404 .63499 m .6391 .57879 L .64227 .57156 L p .707 .577 .707 r
F P
0 g
s
.64155 .69523 m .64246 .65863 L .64149 .6488 L p .707 .577 .707 r
F P
0 g
s
.84305 .57166 m .84435 .62786 L .83754 .62098 L p .707 .577 .707 r
F P
0 g
s
.83754 .62098 m .83624 .56478 L .84305 .57166 L p .707 .577 .707 r
F P
0 g
s
.84414 .6613 m .84323 .69789 L .84226 .68807 L p .707 .577 .707 r
F P
0 g
s
.84226 .68807 m .84317 .65147 L .84414 .6613 L p .707 .577 .707 r
F P
0 g
s
.64227 .57156 m .64357 .62776 L .6404 .63499 L p .707 .577 .707 r
F P
0 g
s
.83593 .73561 m .83437 .75327 L .84102 .74163 L p .707 .577 .707 r
F P
0 g
s
.84102 .74163 m .84259 .72397 L .83593 .73561 L p .707 .577 .707 r
F P
0 g
s
.64149 .6488 m .64058 .6854 L .64155 .69523 L p .707 .577 .707 r
F P
0 g
s
.64094 .73471 m .6425 .71705 L .6392 .70445 L p .707 .577 .707 r
F P
0 g
s
.6392 .70445 m .63764 .72212 L .64094 .73471 L p .707 .577 .707 r
F P
0 g
s
.64357 .62776 m .64227 .57156 L .65511 .56469 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64058 .6854 m .64149 .6488 L .65044 .63959 L p .707 .577 .707 r
F P
0 g
s
.83624 .56478 m .83754 .62098 L .82142 .61513 L p .707 .577 .707 r
F P
0 g
s
.82142 .61513 m .82012 .55892 L .83624 .56478 L p .707 .577 .707 r
F P
0 g
s
.84317 .65147 m .84226 .68807 L .83146 .67859 L p .707 .577 .707 r
F P
0 g
s
.83146 .67859 m .83238 .64199 L .84317 .65147 L p .707 .577 .707 r
F P
0 g
s
.40819 .62219 m .40527 .56709 L .37351 .5677 L p .707 .577 .707 r
F P
0 g
s
.40527 .56709 m .40819 .62219 L .43939 .61869 L p .707 .577 .707 r
F P
0 g
s
.43939 .61869 m .43647 .56359 L .40527 .56709 L p .707 .577 .707 r
F P
0 g
s
.84259 .72397 m .84102 .74163 L .83772 .72903 L p .707 .577 .707 r
F P
0 g
s
.83772 .72903 m .83929 .71137 L .84259 .72397 L p .707 .577 .707 r
F P
0 g
s
.65511 .56469 m .65641 .62089 L .64357 .62776 L p .707 .577 .707 r
F P
0 g
s
.37642 .6228 m .37351 .5677 L .34427 .56535 L p .707 .577 .707 r
F P
0 g
s
.37351 .5677 m .37642 .6228 L .40819 .62219 L p .707 .577 .707 r
F P
0 g
s
.63764 .72212 m .6392 .70445 L .64586 .69281 L p .707 .577 .707 r
F P
0 g
s
.65044 .63959 m .64952 .67618 L .64058 .6854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.43647 .56359 m .43939 .61869 L .46695 .61264 L p .707 .577 .707 r
F P
0 g
s
.46695 .61264 m .46404 .55754 L .43647 .56359 L p .707 .577 .707 r
F P
0 g
s
.64586 .69281 m .6443 .71047 L .63764 .72212 L p .707 .577 .707 r
F P
0 g
s
.34719 .62045 m .34427 .56535 L .32044 .56028 L p .707 .577 .707 r
F P
0 g
s
.34427 .56535 m .34719 .62045 L .37642 .6228 L p .707 .577 .707 r
F P
0 g
s
.65641 .62089 m .65511 .56469 L .67637 .55885 L p .707 .577 .707 r
F P
0 g
s
.46404 .55754 m .46695 .61264 L .4882 .60462 L p .707 .577 .707 r
F P
0 g
s
.4882 .60462 m .48528 .54952 L .46404 .55754 L p .707 .577 .707 r
F P
0 g
s
.64952 .67618 m .65044 .63959 L .66843 .63188 L p .707 .577 .707 r
F P
0 g
s
.38845 .67671 m .39045 .63941 L .3598 .63572 L p .707 .577 .707 r
F P
0 g
s
.39045 .63941 m .38845 .67671 L .42036 .67809 L p .707 .577 .707 r
F P
0 g
s
.42036 .67809 m .42236 .64079 L .39045 .63941 L p .707 .577 .707 r
F P
0 g
s
.42236 .64079 m .42036 .67809 L .45041 .67704 L p .707 .577 .707 r
F P
0 g
s
.45041 .67704 m .45241 .63973 L .42236 .64079 L p .707 .577 .707 r
F P
0 g
s
.82012 .55892 m .82142 .61513 L .79755 .61087 L p .707 .577 .707 r
F P
0 g
s
.79755 .61087 m .79625 .55466 L .82012 .55892 L p .707 .577 .707 r
F P
0 g
s
.83238 .64199 m .83146 .67859 L .8119 .67039 L p .707 .577 .707 r
F P
0 g
s
.8119 .67039 m .81281 .63379 L .83238 .64199 L p .707 .577 .707 r
F P
0 g
s
.67637 .55885 m .67767 .61506 L .65641 .62089 L p .707 .577 .707 r
F P
0 g
s
.83929 .71137 m .83772 .72903 L .82479 .71671 L p .707 .577 .707 r
F P
0 g
s
.82479 .71671 m .82636 .69905 L .83929 .71137 L p .707 .577 .707 r
F P
0 g
s
.3578 .67302 m .3598 .63572 L .33342 .63009 L p .707 .577 .707 r
F P
0 g
s
.3598 .63572 m .3578 .67302 L .38845 .67671 L p .707 .577 .707 r
F P
0 g
s
.6443 .71047 m .64586 .69281 L .66182 .68326 L p .707 .577 .707 r
F P
0 g
s
.32044 .56028 m .32336 .61538 L .34719 .62045 L p .707 .577 .707 r
F P
0 g
s
.66843 .63188 m .66751 .66848 L .64952 .67618 L p .707 .577 .707 r
F P
0 g
s
.45241 .63973 m .45041 .67704 L .47565 .67364 L p .707 .577 .707 r
F P
0 g
s
.47565 .67364 m .47766 .63634 L .45241 .63973 L p .707 .577 .707 r
F P
0 g
s
.38999 .71068 m .39339 .69199 L .36262 .68549 L p .707 .577 .707 r
F P
0 g
s
.39339 .69199 m .38999 .71068 L .42129 .7157 L p .707 .577 .707 r
F P
0 g
s
.42129 .7157 m .42468 .69701 L .39339 .69199 L p .707 .577 .707 r
F P
0 g
s
.32336 .61538 m .32044 .56028 L .30434 .55298 L p .707 .577 .707 r
F P
0 g
s
.36262 .68549 m .35922 .70418 L .38999 .71068 L p .707 .577 .707 r
F P
0 g
s
.67767 .61506 m .67637 .55885 L .70396 .55462 L p .707 .577 .707 r
F P
0 g
s
.42468 .69701 m .42129 .7157 L .45006 .71875 L p .707 .577 .707 r
F P
0 g
s
.45006 .71875 m .45345 .70006 L .42468 .69701 L p .707 .577 .707 r
F P
0 g
s
.33342 .63009 m .33142 .66739 L .3578 .67302 L p .707 .577 .707 r
F P
0 g
s
.66182 .68326 m .66025 .70092 L .6443 .71047 L p .707 .577 .707 r
F P
0 g
s
.35922 .70418 m .36262 .68549 L .33539 .67814 L p .707 .577 .707 r
F P
0 g
s
.48528 .54952 m .4882 .60462 L .50103 .59543 L p .707 .577 .707 r
F P
0 g
s
.50103 .59543 m .49812 .54033 L .48528 .54952 L p .707 .577 .707 r
F P
0 g
s
.33539 .67814 m .332 .69684 L .35922 .70418 L p .707 .577 .707 r
F P
0 g
s
.79625 .55466 m .79755 .61087 L .76829 .60862 L p .707 .577 .707 r
F P
0 g
s
.76829 .60862 m .76699 .55241 L .79625 .55466 L p .707 .577 .707 r
F P
0 g
s
.66751 .66848 m .66843 .63188 L .6937 .62645 L p .707 .577 .707 r
F P
0 g
s
.33142 .66739 m .33342 .63009 L .31388 .62306 L p .707 .577 .707 r
F P
0 g
s
.81281 .63379 m .8119 .67039 L .78549 .66427 L p .707 .577 .707 r
F P
0 g
s
.78549 .66427 m .7864 .62767 L .81281 .63379 L p .707 .577 .707 r
F P
0 g
s
.70396 .55462 m .70526 .61082 L .67767 .61506 L p .707 .577 .707 r
F P
0 g
s
.45345 .70006 m .45006 .71875 L .47347 .71954 L p .707 .577 .707 r
F P
0 g
s
.47347 .71954 m .47687 .70084 L .45345 .70006 L p .707 .577 .707 r
F P
0 g
s
.30434 .55298 m .30726 .60807 L .32336 .61538 L p .707 .577 .707 r
F P
0 g
s
.47766 .63634 m .47565 .67364 L .49363 .66825 L p .707 .577 .707 r
F P
0 g
s
.49363 .66825 m .49563 .63094 L .47766 .63634 L p .707 .577 .707 r
F P
0 g
s
.70526 .61082 m .70396 .55462 L .73519 .5524 L p .707 .577 .707 r
F P
0 g
s
.82636 .69905 m .82479 .71671 L .8035 .70588 L p .707 .577 .707 r
F P
0 g
s
.8035 .70588 m .80506 .68821 L .82636 .69905 L p .707 .577 .707 r
F P
0 g
s
.332 .69684 m .33539 .67814 L .31438 .67067 L p .707 .577 .707 r
F P
0 g
s
.31388 .62306 m .31188 .66037 L .33142 .66739 L p .707 .577 .707 r
F P
0 g
s
.76699 .55241 m .76829 .60862 L .73649 .6086 L p .707 .577 .707 r
F P
0 g
s
.73649 .6086 m .73519 .5524 L .76699 .55241 L p .707 .577 .707 r
F P
0 g
s
.6937 .62645 m .69279 .66305 L .66751 .66848 L p .707 .577 .707 r
F P
0 g
s
.66025 .70092 m .66182 .68326 L .68551 .67674 L p .707 .577 .707 r
F P
0 g
s
.31438 .67067 m .31098 .68937 L .332 .69684 L p .707 .577 .707 r
F P
0 g
s
.73519 .5524 m .73649 .6086 L .70526 .61082 L p .707 .577 .707 r
F P
0 g
s
.30726 .60807 m .30434 .55298 L .29754 .54416 L p .707 .577 .707 r
F P
0 g
s
.69279 .66305 m .6937 .62645 L .72378 .62381 L p .707 .577 .707 r
F P
0 g
s
.68551 .67674 m .68395 .69441 L .66025 .70092 L p .707 .577 .707 r
F P
0 g
s
.7864 .62767 m .78549 .66427 L .75481 .66083 L p .707 .577 .707 r
F P
0 g
s
.75481 .66083 m .75572 .62423 L .7864 .62767 L p .707 .577 .707 r
F P
0 g
s
.49812 .54033 m .50103 .59543 L .50421 .58596 L p .707 .577 .707 r
F P
0 g
s
.50421 .58596 m .50129 .53086 L .49812 .54033 L p .707 .577 .707 r
F P
0 g
s
.31188 .66037 m .31388 .62306 L .3031 .61534 L p .707 .577 .707 r
F P
0 g
s
.47687 .70084 m .47347 .71954 L .48925 .71797 L p .707 .577 .707 r
F P
0 g
s
.48925 .71797 m .49264 .69927 L .47687 .70084 L p .707 .577 .707 r
F P
0 g
s
.72287 .66041 m .72378 .62381 L .75572 .62423 L p .707 .577 .707 r
F P
0 g
s
.72378 .62381 m .72287 .66041 L .69279 .66305 L p .707 .577 .707 r
F P
0 g
s
.75572 .62423 m .75481 .66083 L .72287 .66041 L p .707 .577 .707 r
F P
0 g
s
.80506 .68821 m .8035 .70588 L .77592 .69758 L p .707 .577 .707 r
F P
0 g
s
.77592 .69758 m .77748 .67992 L .80506 .68821 L p .707 .577 .707 r
F P
0 g
s
.31098 .68937 m .31438 .67067 L .30163 .66381 L p .707 .577 .707 r
F P
0 g
s
.68395 .69441 m .68551 .67674 L .71463 .67389 L p .707 .577 .707 r
F P
0 g
s
.49563 .63094 m .49363 .66825 L .50257 .66137 L p .707 .577 .707 r
F P
0 g
s
.50257 .66137 m .50457 .62407 L .49563 .63094 L p .707 .577 .707 r
F P
0 g
s
.29754 .54416 m .30046 .59926 L .30726 .60807 L p .707 .577 .707 r
F P
0 g
s
.3031 .61534 m .3011 .65264 L .31188 .66037 L p .707 .577 .707 r
F P
0 g
s
.30163 .66381 m .29823 .6825 L .31098 .68937 L p .707 .577 .707 r
F P
0 g
s
.71463 .67389 m .71307 .69155 L .68395 .69441 L p .707 .577 .707 r
F P
0 g
s
.77748 .67992 m .77592 .69758 L .74476 .69265 L p .707 .577 .707 r
F P
0 g
s
.74476 .69265 m .74632 .67499 L .77748 .67992 L p .707 .577 .707 r
F P
0 g
s
.71307 .69155 m .71463 .67389 L .74632 .67499 L p .707 .577 .707 r
F P
0 g
s
.30046 .59926 m .29754 .54416 L .30072 .53469 L p .707 .577 .707 r
F P
0 g
s
.74632 .67499 m .74476 .69265 L .71307 .69155 L p .707 .577 .707 r
F P
0 g
s
.50129 .53086 m .50421 .58596 L .49742 .57714 L p .707 .577 .707 r
F P
0 g
s
.49742 .57714 m .4945 .52205 L .50129 .53086 L p .707 .577 .707 r
F P
0 g
s
.3011 .65264 m .3031 .61534 L .30214 .60766 L p .707 .577 .707 r
F P
0 g
s
.49264 .69927 m .48925 .71797 L .49584 .71421 L p .707 .577 .707 r
F P
0 g
s
.49584 .71421 m .49924 .69552 L .49264 .69927 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29823 .6825 m .30163 .66381 L .29839 .65823 L p .707 .577 .707 r
F P
0 g
s
.50457 .62407 m .50257 .66137 L .5016 .6537 L p .707 .577 .707 r
F P
0 g
s
.5016 .6537 m .5036 .61639 L .50457 .62407 L p .707 .577 .707 r
F P
0 g
s
.30072 .53469 m .30364 .58979 L .30046 .59926 L p .707 .577 .707 r
F P
0 g
s
.30214 .60766 m .30014 .64496 L .3011 .65264 L p .707 .577 .707 r
F P
0 g
s
.29839 .65823 m .29499 .67692 L .29823 .6825 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30364 .58979 m .30072 .53469 L .31356 .5255 L p .707 .577 .707 r
F P
0 g
s
.4945 .52205 m .49742 .57714 L .48131 .56984 L p .707 .577 .707 r
F P
0 g
s
.48131 .56984 m .4784 .51474 L .4945 .52205 L p .707 .577 .707 r
F P
0 g
s
.30014 .64496 m .30214 .60766 L .31108 .60079 L p .707 .577 .707 r
F P
0 g
s
.49924 .69552 m .49584 .71421 L .49261 .70863 L p .707 .577 .707 r
F P
0 g
s
.49261 .70863 m .496 .68993 L .49924 .69552 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29499 .67692 m .29839 .65823 L .30498 .65447 L p .707 .577 .707 r
F P
0 g
s
.31356 .5255 m .31648 .5806 L .30364 .58979 L p .707 .577 .707 r
F P
0 g
s
.5036 .61639 m .5016 .6537 L .49082 .64597 L p .707 .577 .707 r
F P
0 g
s
.49082 .64597 m .49283 .60867 L .5036 .61639 L p .707 .577 .707 r
F P
0 g
s
.31108 .60079 m .30908 .63809 L .30014 .64496 L p .707 .577 .707 r
F P
0 g
s
.30498 .65447 m .30159 .67316 L .29499 .67692 L p .707 .577 .707 r
F P
0 g
s
.31648 .5806 m .31356 .5255 L .3348 .51748 L p .707 .577 .707 r
F P
0 g
s
.4784 .51474 m .48131 .56984 L .45748 .56477 L p .707 .577 .707 r
F P
0 g
s
.45748 .56477 m .45456 .50967 L .4784 .51474 L p .707 .577 .707 r
F P
0 g
s
.30908 .63809 m .31108 .60079 L .32905 .59539 L p .707 .577 .707 r
F P
0 g
s
.496 .68993 m .49261 .70863 L .47985 .70176 L p .707 .577 .707 r
F P
0 g
s
.47985 .70176 m .48325 .68307 L .496 .68993 L p .707 .577 .707 r
F P
0 g
s
.3348 .51748 m .33772 .57258 L .31648 .5806 L p .707 .577 .707 r
F P
0 g
s
.49283 .60867 m .49082 .64597 L .47129 .63895 L p .707 .577 .707 r
F P
0 g
s
.47129 .63895 m .47329 .60164 L .49283 .60867 L p .707 .577 .707 r
F P
0 g
s
.30159 .67316 m .30498 .65447 L .32076 .6529 L p .707 .577 .707 r
F P
0 g
s
.32905 .59539 m .32705 .63269 L .30908 .63809 L p .707 .577 .707 r
F P
0 g
s
.32076 .6529 m .31736 .67159 L .30159 .67316 L p .707 .577 .707 r
F P
0 g
s
.33772 .57258 m .3348 .51748 L .36237 .51143 L p .707 .577 .707 r
F P
0 g
s
.45456 .50967 m .45748 .56477 L .42825 .56242 L p .707 .577 .707 r
F P
0 g
s
.42825 .56242 m .42533 .50732 L .45456 .50967 L p .707 .577 .707 r
F P
0 g
s
.32705 .63269 m .32905 .59539 L .3543 .592 L p .707 .577 .707 r
F P
0 g
s
.36529 .56653 m .36237 .51143 L .39356 .50793 L p .707 .577 .707 r
F P
0 g
s
.36237 .51143 m .36529 .56653 L .33772 .57258 L p .707 .577 .707 r
F P
0 g
s
.42533 .50732 m .42825 .56242 L .39648 .56303 L p .707 .577 .707 r
F P
0 g
s
.39648 .56303 m .39356 .50793 L .42533 .50732 L p .707 .577 .707 r
F P
0 g
s
.48325 .68307 m .47985 .70176 L .45884 .69429 L p .707 .577 .707 r
F P
0 g
s
.45884 .69429 m .46223 .6756 L .48325 .68307 L p .707 .577 .707 r
F P
0 g
s
.47329 .60164 m .47129 .63895 L .4449 .63331 L p .707 .577 .707 r
F P
0 g
s
.4449 .63331 m .4469 .59601 L .47329 .60164 L p .707 .577 .707 r
F P
0 g
s
.39356 .50793 m .39648 .56303 L .36529 .56653 L p .707 .577 .707 r
F P
0 g
s
.3543 .592 m .3523 .6293 L .32705 .63269 L p .707 .577 .707 r
F P
0 g
s
.31736 .67159 m .32076 .6529 L .34417 .65368 L p .707 .577 .707 r
F P
0 g
s
.34417 .65368 m .34078 .67237 L .31736 .67159 L p .707 .577 .707 r
F P
0 g
s
.3523 .6293 m .3543 .592 L .38435 .59094 L p .707 .577 .707 r
F P
0 g
s
.4469 .59601 m .4449 .63331 L .41426 .62963 L p .707 .577 .707 r
F P
0 g
s
.41426 .62963 m .41626 .59232 L .4469 .59601 L p .707 .577 .707 r
F P
0 g
s
.46223 .6756 m .45884 .69429 L .43161 .68695 L p .707 .577 .707 r
F P
0 g
s
.43161 .68695 m .43501 .66825 L .46223 .6756 L p .707 .577 .707 r
F P
0 g
s
.38435 .59094 m .38235 .62824 L .3523 .6293 L p .707 .577 .707 r
F P
0 g
s
.38235 .62824 m .38435 .59094 L .41626 .59232 L p .707 .577 .707 r
F P
0 g
s
.34078 .67237 m .34417 .65368 L .37294 .65673 L p .707 .577 .707 r
F P
0 g
s
.41626 .59232 m .41426 .62963 L .38235 .62824 L p .707 .577 .707 r
F P
0 g
s
.37294 .65673 m .36955 .67543 L .34078 .67237 L p .707 .577 .707 r
F P
0 g
s
.43501 .66825 m .43161 .68695 L .40085 .68045 L p .707 .577 .707 r
F P
0 g
s
.40085 .68045 m .40424 .66175 L .43501 .66825 L p .707 .577 .707 r
F P
0 g
s
.36955 .67543 m .37294 .65673 L .40424 .66175 L p .707 .577 .707 r
F P
0 g
s
.40424 .66175 m .40085 .68045 L .36955 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF5`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
069oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00GWoo10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00Fgoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00003Goo
8@00=goo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00007Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<goo001DOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000aOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
009JEPT00003FUH005YF00`000AJEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00E7oo
00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEQ@000AJEP03001JEUYF00AJEP@00003FUH0
05YF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH2000^Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP04001JEUYFFUH60008FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YF00002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`05FUH005YFFUH00003FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`06FUH005YFFUH005YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00H005YF000005YF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0002eoo`00EGoo00AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00AJEP000000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00=JEP0000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Goo001E
Ool00eYF00000003FUH00`00FUIJEP03FUHJ00000eYF001JEP06FUH00`00FUIJEP03FUH01@00FUIJ
EUYF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH0000]Ool004Aoo`P000Uoo`03001JEP0000=JEPH000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEUYFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool003aoo`P000=JEP03001JEUYF009JEPX00003FUH000000080009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03
001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8002eoo`00=Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000UYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF8@000eYF00<005YFFUH00UYF0P00;Goo000`Ool20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
0eYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP00008000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0
000002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH70002FUH200000eYF001JEP04FUH=
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`0015YF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001EYF00D005YFFUIJEP0002eoo`00;7oo0P000eYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001J
EP8000=JEP04001JEUYFFUH80003FUH60003FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00D005YFFUIJEP0002eoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000=JEP03001JEUYF00AJEPX000AJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH0000002ioo`00;7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF100000=JEP00000020000eYF
00<005YFFUH015YF0`0000AJEP00FUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<7oo000/Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF5@000eYF00<005YFFUH03`001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002Goo1@001Woo1`000UYF00<005YFFUH00eYF00<005YFFUH00UYF1P00
0UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YFFUH00UYF1@0015YF6@0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1@0025YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
1P004Woo1P001EYF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH00eYF100025YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF0P002Woo0`003Goo100000=JEP00FUH015YF00@005YFFUH002eoo`00;7oo10000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<0
05YFFUH00`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00UYF0`000UYF00L005YFFUIJEP00FUH00008Ool5000@Ool30004FUH01000FUIJEP00
;Goo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF001JEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
00030003FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH200000eYF001JEP040003FUH01P00FUIJEUYF001JEPl0019oo`<00005FUH005YFFUH0000]Ool0
02aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP@000=JEPP000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0000000AJ
EPT000AJEP03001JEUYF00IJEP03001JEP0000<000eoo`<00003FUH00000009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YF0000100000=JEP00FUH015YF1`001UYF00<005YF
FUH01UYF00<005YF00000P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF10001Goo100000=JEP00FUH00eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH600000eYF
000000020002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH3000]Ool0
02eoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEP0000T000=JEP03001JEP0000<000IJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=J
EP03001JEUYF009JEP03001JEP0002eoo`00;Goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00eYF1P00
0eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF00H005YFFUH005YF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0000]Ool002ioo`06001J
EP00001JEP001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF20002EYF100015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEPH000QJEP03001J
EUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF1P001UYF00<005YF00000P0000=JEP00FUH0
0UYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YF0000
0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01000FUIJEUYF3@000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF0P0000=JEP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH0
0000FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002
FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P001EYF00<005YF00000P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EP00FUH01@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080
0005FUH00000FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP00;goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJ
EP00FUH000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000EJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
009JEP03001oogoo02aoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP040002FUH00`00
FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00Oomo
o`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF009JEQ40009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH0000000@000=JEPT000AJEPH000=JEP03001JEUYF009JEPP000Ioo`03
001JEUYF008002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF009JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=J
EP00FUH00eYF00<005YF00000`000UYF0P0017oo4P003goo00@005YF000002eoo`00;7oo00@005YF
FUH000AJEP04001JEUYFFUH80007Ool50007Ool=0002FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00004FUH200000eYF00000009Ool5000HOol3
000]Ool002aoo`04001JEUYF0003FUH500000eYF0000000H0004FUH00`00FUIJEP04FUH00`00FUH0
00020002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH01000FUIJEP00
1EYF0`002goo0`006Woo0P00;Goo000/Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF10001EYF00<005YF0000
9goo0`00;Goo000/Ool00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00P0015YF00@005YFFUH0
02Ioo`03001JEP0002eoo`00;7oo10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00005FUH300001EYF001JEUYF000097oo0`0000=J
EP00Ool0;7oo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP00008000IJEP03001JEP0000@0025oo`<0009JEP8002ioo`00;7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEP`000AJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00006FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02FUH2000^Ool002aoo`04001JEUYF
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000>0003FUH20000
17oo001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF1`001eYF00<005YFFUH00eYF00<005YF00000UYF0P000eYF00<005YFFUH01UYF00<005YF
FUH0100047oo1@001EYF00D005YFFUIJEP0002moo`00;Goo0`001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01@000Woo00<005YF00001EYF
00<005YFFUH00UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH00`0015YF00<005YFFUH00eYF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF40000eYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;goo0P0015YF00<005YFFUH015YF
00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF00000Woo1`00
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
035oo`00<Goo0`0000=JEP00FUH01`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20005FUH00`00FUH00007Ool6
0002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000cOol0
039oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP000eYF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF000000=JEP03001JEP0000L000=J
EP800003FUH0000000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
<7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00L005YFFUH005YF001JEP0200000eYF001JEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000AJEP00FUH000AJEP03001JEP000080009JEP@000=oo`@0009JEP03001JEUYF00IJEP03001J
EUYF009JEPD003Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
7@0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00UYF0`000UYF00<007ooOol01Goo4000?goo000/Ool30004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH=000<Ool50003FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000EJEP03001JEUYF009JEP<00003FUH007oo05Eoo`00;7oo00<005YF000015YF00<0
05YFFUH00eYF1P0027oo1@0027oo100000=JEP00FUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF009JEP03001JEUYF008005Ioo`00
;7oo00@005YFFUH000=JEP03001JEP0000<000]ooa0000EJEP03001JEUYF00AJEP03001JEUYF009J
EP8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00P000AJEP04001JEUYF001FOol0
02aoo`04001JEUYF0002FUHB0004FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP040005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001eYF0`0000EJEP00FUIJEP00
05Ioo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000goo00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH00P000eYF00<007ooOol0Dgoo000]Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000030007Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000=JEP00Ool0E7oo000]Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000<Ool20003FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00@005YF000000=oo`8005Eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004goo00@0
05YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH30005Ool2001EOol0031ooad001eo
o`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEP000006FUH00`00FUH000030007Ool01000FUH00000E7oo001/Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH4
0004FUH6000:Ool20002FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00`000moo`03001JEP00009JEP03001o
ogoo059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`0057oo
00@005YFFUIJEP8005Eoo`00N7oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1P001Woo1@004Woo0P0015YF0P00EGoo001nOolO000<Ool5000@Ool200000eYF001JEP03FUH00`00
Oomoo`1DOol008ioo`04001JEUYF000HOol3000?Ool20003FUH01@00FUIJEUYF0000Egoo002>Ool0
0`00FUH0000XOol30006FUH00`00FUH0001HOol008moo`8002Ioo`800003FUH005YF00IJEP8005Uo
o`00Sgoo0P008goo0`000eYF00<005YFFUH015YF0P00FWoo002?Ool00`00FUH0000NOol40007FUH0
1000FUIJEUYF0P00G7oo002?Ool2000015YF000000005goo10000UYF00<005YFFUH01UYF00@005YF
000005ioo`00T7oo00<005YF00000UYF1`002Goo1`001UYF00<005YFFUH01EYF0`00H7oo002@Ool0
0`00FUH00005FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002A
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
001UOol0099oo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP@006Qoo`00
Tgoo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000K7oo002FOol70004FUH0
0`00FUIJEP02FUH7001`Ool009eoo`T007Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60352 .74787 m .60643 .69198 L .57467 .68965 L p .707 .577 .707 r
F P
0 g
s
.60643 .69198 m .60352 .74787 L .63471 .74775 L p .707 .577 .707 r
F P
0 g
s
.63471 .74775 m .63763 .69186 L .60643 .69198 L p .707 .577 .707 r
F P
0 g
s
.57175 .74554 m .57467 .68965 L .54543 .68508 L p .707 .577 .707 r
F P
0 g
s
.57467 .68965 m .57175 .74554 L .60352 .74787 L p .707 .577 .707 r
F P
0 g
s
.63763 .69186 m .63471 .74775 L .66228 .74517 L p .707 .577 .707 r
F P
0 g
s
.66228 .74517 m .6652 .68928 L .63763 .69186 L p .707 .577 .707 r
F P
0 g
s
.54252 .74097 m .54543 .68508 L .5216 .67873 L p .707 .577 .707 r
F P
0 g
s
.54543 .68508 m .54252 .74097 L .57175 .74554 L p .707 .577 .707 r
F P
0 g
s
.58574 .81373 m .58374 .77706 L .55309 .77592 L p .707 .577 .707 r
F P
0 g
s
.58374 .77706 m .58574 .81373 L .61765 .81185 L p .707 .577 .707 r
F P
0 g
s
.61765 .81185 m .61565 .77518 L .58374 .77706 L p .707 .577 .707 r
F P
0 g
s
.61565 .77518 m .61765 .81185 L .6477 .80715 L p .707 .577 .707 r
F P
0 g
s
.6477 .80715 m .6457 .77048 L .61565 .77518 L p .707 .577 .707 r
F P
0 g
s
.6652 .68928 m .66228 .74517 L .68352 .7404 L p .707 .577 .707 r
F P
0 g
s
.68352 .7404 m .68644 .68451 L .6652 .68928 L p .707 .577 .707 r
F P
0 g
s
.5216 .67873 m .51868 .73462 L .54252 .74097 L p .707 .577 .707 r
F P
0 g
s
.55509 .81259 m .55309 .77592 L .52671 .77187 L p .707 .577 .707 r
F P
0 g
s
.55309 .77592 m .55509 .81259 L .58574 .81373 L p .707 .577 .707 r
F P
0 g
s
.6457 .77048 m .6477 .80715 L .67294 .80007 L p .707 .577 .707 r
F P
0 g
s
.67294 .80007 m .67094 .7634 L .6457 .77048 L p .707 .577 .707 r
F P
0 g
s
.51868 .73462 m .5216 .67873 L .5055 .67121 L p .707 .577 .707 r
F P
0 g
s
.52671 .77187 m .52871 .80854 L .55509 .81259 L p .707 .577 .707 r
F P
0 g
s
.59915 .86307 m .59576 .84553 L .56499 .84812 L p .707 .577 .707 r
F P
0 g
s
.59576 .84553 m .59915 .86307 L .63045 .85664 L p .707 .577 .707 r
F P
0 g
s
.63045 .85664 m .62706 .83909 L .59576 .84553 L p .707 .577 .707 r
F P
0 g
s
.62706 .83909 m .63045 .85664 L .65921 .84699 L p .707 .577 .707 r
F P
0 g
s
.65921 .84699 m .65582 .82945 L .62706 .83909 L p .707 .577 .707 r
F P
0 g
s
.68644 .68451 m .68352 .7404 L .69636 .7339 L p .707 .577 .707 r
F P
0 g
s
.69636 .7339 m .69928 .67801 L .68644 .68451 L p .707 .577 .707 r
F P
0 g
s
.52871 .80854 m .52671 .77187 L .50717 .76532 L p .707 .577 .707 r
F P
0 g
s
.5055 .67121 m .50258 .7271 L .51868 .73462 L p .707 .577 .707 r
F P
0 g
s
.56499 .84812 m .56838 .86567 L .59915 .86307 L p .707 .577 .707 r
F P
0 g
s
.67094 .7634 m .67294 .80007 L .69092 .79131 L p .707 .577 .707 r
F P
0 g
s
.69092 .79131 m .68892 .75464 L .67094 .7634 L p .707 .577 .707 r
F P
0 g
s
.56838 .86567 m .56499 .84812 L .53777 .84662 L p .707 .577 .707 r
F P
0 g
s
.65582 .82945 m .65921 .84699 L .68263 .83508 L p .707 .577 .707 r
F P
0 g
s
.68263 .83508 m .67924 .81754 L .65582 .82945 L p .707 .577 .707 r
F P
0 g
s
.53777 .84662 m .54116 .86417 L .56838 .86567 L p .707 .577 .707 r
F P
0 g
s
.50717 .76532 m .50917 .80199 L .52871 .80854 L p .707 .577 .707 r
F P
0 g
s
.50258 .7271 m .5055 .67121 L .4987 .66327 L p .707 .577 .707 r
F P
0 g
s
.54116 .86417 m .53777 .84662 L .51675 .84118 L p .707 .577 .707 r
F P
0 g
s
.67924 .81754 m .68263 .83508 L .69841 .82207 L p .707 .577 .707 r
F P
0 g
s
.69841 .82207 m .69502 .80453 L .67924 .81754 L p .707 .577 .707 r
F P
0 g
s
.50917 .80199 m .50717 .76532 L .49639 .75689 L p .707 .577 .707 r
F P
0 g
s
.69928 .67801 m .69636 .7339 L .69954 .7263 L p .707 .577 .707 r
F P
0 g
s
.69954 .7263 m .70245 .67041 L .69928 .67801 L p .707 .577 .707 r
F P
0 g
s
.51675 .84118 m .52014 .85872 L .54116 .86417 L p .707 .577 .707 r
F P
0 g
s
.4987 .66327 m .49579 .71915 L .50258 .7271 L p .707 .577 .707 r
F P
0 g
s
.68892 .75464 m .69092 .79131 L .69986 .78173 L p .707 .577 .707 r
F P
0 g
s
.69986 .78173 m .69786 .74506 L .68892 .75464 L p .707 .577 .707 r
F P
0 g
s
.49639 .75689 m .49839 .79357 L .50917 .80199 L p .707 .577 .707 r
F P
0 g
s
.52014 .85872 m .51675 .84118 L .504 .83232 L p .707 .577 .707 r
F P
0 g
s
.49579 .71915 m .4987 .66327 L .50188 .65567 L p .707 .577 .707 r
F P
0 g
s
.69502 .80453 m .69841 .82207 L .705 .80924 L p .707 .577 .707 r
F P
0 g
s
.705 .80924 m .70161 .79169 L .69502 .80453 L p .707 .577 .707 r
F P
0 g
s
.504 .83232 m .50739 .84987 L .52014 .85872 L p .707 .577 .707 r
F P
0 g
s
.49839 .79357 m .49639 .75689 L .49543 .74743 L p .708 .578 .707 r
F P
0 g
s
.50188 .65567 m .49896 .71156 L .49579 .71915 L p .707 .577 .707 r
F P
0 g
s
.49543 .74743 m .49743 .7841 L .49839 .79357 L p .708 .578 .707 r
F P
0 g
s
.49743 .7841 m .49543 .74743 L .50437 .73785 L p .707 .577 .707 r
F P
0 g
s
.49723 .82192 m .49723 .32003 L .4528 .3179 L p .707 .577 .707 r
F P
0 g
s
.50739 .84987 m .504 .83232 L .50076 .82092 L p .707 .577 .707 r
F P
0 g
s
.49896 .71156 m .50188 .65567 L .51472 .64917 L p .707 .577 .707 r
F P
0 g
s
.50076 .82092 m .50415 .83846 L .50739 .84987 L p .707 .577 .707 r
F P
0 g
s
.51472 .64917 m .5118 .70506 L .49896 .71156 L p .707 .577 .707 r
F P
0 g
s
.50437 .73785 m .50637 .77452 L .49743 .7841 L p .707 .577 .707 r
F P
0 g
s
.50415 .83846 m .50076 .82092 L .50735 .80808 L p .707 .577 .707 r
F P
0 g
s
.5118 .70506 m .51472 .64917 L .53596 .6444 L p .707 .577 .707 r
F P
0 g
s
.50735 .80808 m .51075 .82562 L .50415 .83846 L p .707 .577 .707 r
F P
0 g
s
.50637 .77452 m .50437 .73785 L .52234 .72909 L p .707 .577 .707 r
F P
0 g
s
.53596 .6444 m .53304 .70028 L .5118 .70506 L p .707 .577 .707 r
F P
0 g
s
.52234 .72909 m .52434 .76576 L .50637 .77452 L p .707 .577 .707 r
F P
0 g
s
.51075 .82562 m .50735 .80808 L .52313 .79507 L p .707 .577 .707 r
F P
0 g
s
.52313 .79507 m .52652 .81261 L .51075 .82562 L p .707 .577 .707 r
F P
0 g
s
.52434 .76576 m .52234 .72909 L .54759 .72201 L p .707 .577 .707 r
F P
0 g
s
.54759 .72201 m .54959 .75868 L .52434 .76576 L p .707 .577 .707 r
F P
0 g
s
.52652 .81261 m .52313 .79507 L .54655 .78316 L p .707 .577 .707 r
F P
0 g
s
.54655 .78316 m .54994 .8007 L .52652 .81261 L p .707 .577 .707 r
F P
0 g
s
.49723 .32003 m .49723 .82192 L .54194 .82025 L p .707 .577 .707 r
F P
0 g
s
.53304 .70028 m .53596 .6444 L .56353 .64182 L p .707 .577 .707 r
F P
0 g
s
.56353 .64182 m .56061 .69771 L .53304 .70028 L p .707 .577 .707 r
F P
0 g
s
.54194 .82025 m .54194 .31836 L .49723 .32003 L p .707 .577 .707 r
F P
0 g
s
.69786 .74506 m .69986 .78173 L .69889 .77226 L p .708 .578 .707 r
F P
0 g
s
.69889 .77226 m .69689 .73559 L .69786 .74506 L p .708 .578 .707 r
F P
0 g
s
.70245 .67041 m .69954 .7263 L .69274 .71836 L p .707 .577 .707 r
F P
0 g
s
.69274 .71836 m .69566 .66247 L .70245 .67041 L p .707 .577 .707 r
F P
0 g
s
.56061 .69771 m .56353 .64182 L .59472 .6417 L p .707 .577 .707 r
F P
0 g
s
.59472 .6417 m .59181 .69758 L .56061 .69771 L p .707 .577 .707 r
F P
0 g
s
.54959 .75868 m .54759 .72201 L .57764 .7173 L p .707 .577 .707 r
F P
0 g
s
.57764 .7173 m .57964 .75398 L .54959 .75868 L p .707 .577 .707 r
F P
0 g
s
.54994 .8007 m .54655 .78316 L .57531 .77352 L p .707 .577 .707 r
F P
0 g
s
.57531 .77352 m .57871 .79106 L .54994 .8007 L p .707 .577 .707 r
F P
0 g
s
.57871 .79106 m .57531 .77352 L .60661 .76708 L p .707 .577 .707 r
F P
0 g
s
.60661 .76708 m .61001 .78463 L .57871 .79106 L p .707 .577 .707 r
F P
0 g
s
.54194 .31836 m .54194 .82025 L .58253 .81496 L p .707 .577 .707 r
F P
0 g
s
.57964 .75398 m .57764 .7173 L .60955 .71543 L p .707 .577 .707 r
F P
0 g
s
.60955 .71543 m .61155 .7521 L .57964 .75398 L p .707 .577 .707 r
F P
0 g
s
.58253 .81496 m .58253 .31307 L .54194 .31836 L p .707 .577 .707 r
F P
0 g
s
.4528 .81979 m .4528 .3179 L .41299 .3122 L p .707 .577 .707 r
F P
0 g
s
.4528 .3179 m .4528 .81979 L .49723 .82192 L p .707 .577 .707 r
F P
0 g
s
.70161 .79169 m .705 .80924 L .70176 .79783 L p .707 .577 .707 r
F P
0 g
s
.70176 .79783 m .69837 .78029 L .70161 .79169 L p .707 .577 .707 r
F P
0 g
s
.62649 .64403 m .62357 .69992 L .59181 .69758 L p .707 .577 .707 r
F P
0 g
s
.59181 .69758 m .59472 .6417 L .62649 .64403 L p .707 .577 .707 r
F P
0 g
s
.63738 .76449 m .64077 .78203 L .61001 .78463 L p .707 .577 .707 r
F P
0 g
s
.61001 .78463 m .60661 .76708 L .63738 .76449 L p .707 .577 .707 r
F P
0 g
s
.58253 .31307 m .58253 .81496 L .61505 .80656 L p .707 .577 .707 r
F P
0 g
s
.64019 .71657 m .64219 .75324 L .61155 .7521 L p .707 .577 .707 r
F P
0 g
s
.61155 .7521 m .60955 .71543 L .64019 .71657 L p .707 .577 .707 r
F P
0 g
s
.61505 .80656 m .61505 .30468 L .58253 .31307 L p .707 .577 .707 r
F P
0 g
s
.41299 .81409 m .41299 .3122 L .3817 .30348 L p .707 .577 .707 r
F P
0 g
s
.41299 .3122 m .41299 .81409 L .4528 .81979 L p .707 .577 .707 r
F P
0 g
s
.69689 .73559 m .69889 .77226 L .68811 .76384 L p .707 .577 .707 r
F P
0 g
s
.68811 .76384 m .68611 .72717 L .69689 .73559 L p .707 .577 .707 r
F P
0 g
s
.69566 .66247 m .69274 .71836 L .67664 .71084 L p .707 .577 .707 r
F P
0 g
s
.67664 .71084 m .67956 .65495 L .69566 .66247 L p .707 .577 .707 r
F P
0 g
s
.26351 .71579 m .26481 .66097 L .23301 .6593 L p .707 .577 .707 r
F P
0 g
s
.26481 .66097 m .26351 .71579 L .29474 .71434 L p .707 .577 .707 r
F P
0 g
s
.29474 .71434 m .29603 .65952 L .26481 .66097 L p .707 .577 .707 r
F P
0 g
s
.23171 .71412 m .23301 .6593 L .20374 .65468 L p .707 .577 .707 r
F P
0 g
s
.23301 .6593 m .23171 .71412 L .26351 .71579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29603 .65952 m .29474 .71434 L .32233 .70991 L p .707 .577 .707 r
F P
0 g
s
.32233 .70991 m .32363 .65509 L .29603 .65952 L p .707 .577 .707 r
F P
0 g
s
.20245 .7095 m .20374 .65468 L .17988 .64755 L p .707 .577 .707 r
F P
0 g
s
.20374 .65468 m .20245 .7095 L .23171 .71412 L p .707 .577 .707 r
F P
0 g
s
.69837 .78029 m .70176 .79783 L .68901 .78897 L p .707 .577 .707 r
F P
0 g
s
.68901 .78897 m .68562 .77143 L .69837 .78029 L p .707 .577 .707 r
F P
0 g
s
.65572 .6486 m .6528 .70449 L .62357 .69992 L p .707 .577 .707 r
F P
0 g
s
.62357 .69992 m .62649 .64403 L .65572 .6486 L p .707 .577 .707 r
F P
0 g
s
.61505 .30468 m .61505 .80656 L .6363 .79588 L p .707 .577 .707 r
F P
0 g
s
.6363 .79588 m .6363 .29399 L .61505 .30468 L p .707 .577 .707 r
F P
0 g
s
.32363 .65509 m .32233 .70991 L .34359 .70294 L p .707 .577 .707 r
F P
0 g
s
.34359 .70294 m .34488 .64812 L .32363 .65509 L p .707 .577 .707 r
F P
0 g
s
.24519 .768 m .24428 .73057 L .2136 .72923 L p .707 .577 .707 r
F P
0 g
s
.24428 .73057 m .24519 .768 L .27713 .76704 L p .707 .577 .707 r
F P
0 g
s
.27713 .76704 m .27622 .72962 L .24428 .73057 L p .707 .577 .707 r
F P
0 g
s
.27622 .72962 m .27713 .76704 L .30721 .76387 L p .707 .577 .707 r
F P
0 g
s
.30721 .76387 m .3063 .72644 L .27622 .72962 L p .707 .577 .707 r
F P
0 g
s
.3817 .80536 m .3817 .30348 L .36198 .29258 L p .707 .577 .707 r
F P
0 g
s
.3817 .30348 m .3817 .80536 L .41299 .81409 L p .707 .577 .707 r
F P
0 g
s
.67956 .65495 m .67664 .71084 L .6528 .70449 L p .707 .577 .707 r
F P
0 g
s
.6528 .70449 m .65572 .6486 L .67956 .65495 L p .707 .577 .707 r
F P
0 g
s
.68611 .72717 m .68811 .76384 L .66858 .75729 L p .707 .577 .707 r
F P
0 g
s
.66858 .75729 m .66658 .72062 L .68611 .72717 L p .707 .577 .707 r
F P
0 g
s
.2136 .72923 m .21451 .76666 L .24519 .768 L p .707 .577 .707 r
F P
0 g
s
.21451 .76666 m .2136 .72923 L .18719 .72571 L p .707 .577 .707 r
F P
0 g
s
.17988 .64755 m .17858 .70237 L .20245 .7095 L p .707 .577 .707 r
F P
0 g
s
.25524 .80286 m .25368 .78389 L .22252 .78544 L p .707 .577 .707 r
F P
0 g
s
.25368 .78389 m .25524 .80286 L .28693 .79982 L p .707 .577 .707 r
F P
0 g
s
.28693 .79982 m .28536 .78085 L .25368 .78389 L p .707 .577 .707 r
F P
0 g
s
.3063 .72644 m .30721 .76387 L .33248 .7588 L p .707 .577 .707 r
F P
0 g
s
.33248 .7588 m .33157 .72137 L .3063 .72644 L p .707 .577 .707 r
F P
0 g
s
.17858 .70237 m .17988 .64755 L .16375 .63862 L p .707 .577 .707 r
F P
0 g
s
.22252 .78544 m .22408 .80441 L .25524 .80286 L p .707 .577 .707 r
F P
0 g
s
.28536 .78085 m .28693 .79982 L .31605 .79561 L p .707 .577 .707 r
F P
0 g
s
.31605 .79561 m .31448 .77664 L .28536 .78085 L p .707 .577 .707 r
F P
0 g
s
.22408 .80441 m .22252 .78544 L .19494 .78536 L p .707 .577 .707 r
F P
0 g
s
.18719 .72571 m .1881 .76314 L .21451 .76666 L p .707 .577 .707 r
F P
0 g
s
.19494 .78536 m .1965 .80433 L .22408 .80441 L p .707 .577 .707 r
F P
0 g
s
.34488 .64812 m .34359 .70294 L .35643 .69411 L p .707 .577 .707 r
F P
0 g
s
.35643 .69411 m .35773 .63929 L .34488 .64812 L p .707 .577 .707 r
F P
0 g
s
.68562 .77143 m .68901 .78897 L .668 .78353 L p .707 .577 .707 r
F P
0 g
s
.668 .78353 m .6646 .76598 L .68562 .77143 L p .707 .577 .707 r
F P
0 g
s
.31448 .77664 m .31605 .79561 L .33975 .79062 L p .707 .577 .707 r
F P
0 g
s
.33975 .79062 m .33818 .77165 L .31448 .77664 L p .707 .577 .707 r
F P
0 g
s
.1881 .76314 m .18719 .72571 L .16762 .72037 L p .707 .577 .707 r
F P
0 g
s
.66658 .72062 m .66858 .75729 L .64219 .75324 L p .707 .577 .707 r
F P
0 g
s
.64219 .75324 m .64019 .71657 L .66658 .72062 L p .707 .577 .707 r
F P
0 g
s
.16375 .63862 m .16245 .69344 L .17858 .70237 L p .707 .577 .707 r
F P
0 g
s
.33157 .72137 m .33248 .7588 L .35047 .75233 L p .707 .577 .707 r
F P
0 g
s
.35047 .75233 m .34956 .7149 L .33157 .72137 L p .707 .577 .707 r
F P
0 g
s
.1965 .80433 m .19494 .78536 L .17364 .78366 L p .707 .577 .707 r
F P
0 g
s
.6646 .76598 m .668 .78353 L .64077 .78203 L p .707 .577 .707 r
F P
0 g
s
.64077 .78203 m .63738 .76449 L .6646 .76598 L p .707 .577 .707 r
F P
0 g
s
.6363 .29399 m .6363 .79588 L .64422 .78396 L p .707 .577 .707 r
F P
0 g
s
.64422 .78396 m .64422 .28207 L .6363 .29399 L p .707 .577 .707 r
F P
0 g
s
.16762 .72037 m .16853 .7578 L .1881 .76314 L p .707 .577 .707 r
F P
0 g
s
.17364 .78366 m .17521 .80263 L .1965 .80433 L p .707 .577 .707 r
F P
0 g
s
.16245 .69344 m .16375 .63862 L .15694 .62876 L p .707 .577 .707 r
F P
0 g
s
.3596 .68428 m .3609 .62946 L .35773 .63929 L p .707 .577 .707 r
F P
0 g
s
.35414 .76638 m .3557 .78535 L .36236 .78031 L p .707 .577 .707 r
F P
0 g
s
.36236 .78031 m .36079 .76135 L .35414 .76638 L p .707 .577 .707 r
F P
0 g
s
.35773 .63929 m .35643 .69411 L .3596 .68428 L p .707 .577 .707 r
F P
0 g
s
.3609 .62946 m .3596 .68428 L .35279 .67442 L p .707 .577 .707 r
F P
0 g
s
.35279 .67442 m .35409 .6196 L .3609 .62946 L p .707 .577 .707 r
F P
0 g
s
.36079 .76135 m .36236 .78031 L .35906 .77601 L p .707 .577 .707 r
F P
0 g
s
.36198 .79447 m .36198 .29258 L .35578 .28059 L p .707 .577 .707 r
F P
0 g
s
.36198 .29258 m .36198 .79447 L .3817 .80536 L p .707 .577 .707 r
F P
0 g
s
.33818 .77165 m .33975 .79062 L .3557 .78535 L p .707 .577 .707 r
F P
0 g
s
.3557 .78535 m .35414 .76638 L .33818 .77165 L p .707 .577 .707 r
F P
0 g
s
.16853 .7578 m .16762 .72037 L .15683 .71372 L p .707 .577 .707 r
F P
0 g
s
.15694 .62876 m .15564 .68358 L .16245 .69344 L p .707 .577 .707 r
F P
0 g
s
.34956 .7149 m .35047 .75233 L .35942 .74509 L p .707 .577 .707 r
F P
0 g
s
.35942 .74509 m .35851 .70766 L .34956 .7149 L p .707 .577 .707 r
F P
0 g
s
.17521 .80263 m .17364 .78366 L .16071 .7805 L p .707 .577 .707 r
F P
0 g
s
.16071 .7805 m .16227 .79947 L .17521 .80263 L p .707 .577 .707 r
F P
0 g
s
.15683 .71372 m .15774 .75115 L .16853 .7578 L p .707 .577 .707 r
F P
0 g
s
.15564 .68358 m .15694 .62876 L .16011 .61893 L p .707 .577 .707 r
F P
0 g
s
.64422 .28207 m .64422 .78396 L .63801 .77197 L p .707 .577 .707 r
F P
0 g
s
.63801 .77197 m .63801 .27008 L .64422 .28207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15774 .75115 m .15683 .71372 L .15586 .70641 L p .707 .578 .707 r
F P
0 g
s
.35851 .70766 m .35942 .74509 L .35845 .73778 L p .707 .578 .707 r
F P
0 g
s
.35845 .73778 m .35754 .70035 L .35851 .70766 L p .707 .578 .707 r
F P
0 g
s
.35906 .77601 m .35749 .75704 L .36079 .76135 L p .707 .577 .707 r
F P
0 g
s
.35754 .70035 m .35845 .73778 L .34765 .73113 L p .707 .577 .707 r
F P
0 g
s
.34765 .73113 m .34674 .6937 L .35754 .70035 L p .707 .577 .707 r
F P
0 g
s
.35749 .75704 m .35906 .77601 L .34612 .77285 L p .707 .577 .707 r
F P
0 g
s
.34612 .77285 m .34456 .75388 L .35749 .75704 L p .707 .577 .707 r
F P
0 g
s
.35578 .28059 m .35578 .78248 L .36198 .79447 L p .707 .577 .707 r
F P
0 g
s
.35578 .78248 m .35578 .28059 L .36369 .26867 L p .707 .577 .707 r
F P
0 g
s
.16011 .61893 m .15882 .67375 L .15564 .68358 L p .707 .577 .707 r
F P
0 g
s
.16227 .79947 m .16071 .7805 L .15741 .77619 L p .707 .577 .707 r
F P
0 g
s
.15741 .77619 m .15897 .79516 L .16227 .79947 L p .707 .577 .707 r
F P
0 g
s
.15586 .70641 m .15677 .74384 L .15774 .75115 L p .707 .578 .707 r
F P
0 g
s
.15882 .67375 m .16011 .61893 L .17296 .6101 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35409 .6196 m .35279 .67442 L .33666 .66549 L p .707 .577 .707 r
F P
0 g
s
.33666 .66549 m .33796 .61067 L .35409 .6196 L p .707 .577 .707 r
F P
0 g
s
.15677 .74384 m .15586 .70641 L .1648 .69917 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17296 .6101 m .17166 .66492 L .15882 .67375 L p .707 .577 .707 r
F P
0 g
s
.15897 .79516 m .15741 .77619 L .16407 .77116 L p .707 .577 .707 r
F P
0 g
s
.16407 .77116 m .16563 .79013 L .15897 .79516 L p .707 .577 .707 r
F P
0 g
s
.1648 .69917 m .16571 .7366 L .15677 .74384 L p .707 .577 .707 r
F P
0 g
s
.63801 .27008 m .63801 .77197 L .6183 .76107 L p .707 .577 .707 r
F P
0 g
s
.6183 .76107 m .6183 .25918 L .63801 .27008 L p .707 .577 .707 r
F P
0 g
s
.17166 .66492 m .17296 .6101 L .19422 .60313 L p .707 .577 .707 r
F P
0 g
s
.36369 .77055 m .36369 .26867 L .38495 .25798 L p .707 .577 .707 r
F P
0 g
s
.36369 .26867 m .36369 .77055 L .35578 .78248 L p .707 .577 .707 r
F P
0 g
s
.33796 .61067 m .33666 .66549 L .3128 .65836 L p .707 .577 .707 r
F P
0 g
s
.3128 .65836 m .3141 .60354 L .33796 .61067 L p .707 .577 .707 r
F P
0 g
s
.16571 .7366 m .1648 .69917 L .18279 .69269 L p .707 .577 .707 r
F P
0 g
s
.19422 .60313 m .19292 .65795 L .17166 .66492 L p .707 .577 .707 r
F P
0 g
s
.34674 .6937 m .34765 .73113 L .32809 .72578 L p .707 .577 .707 r
F P
0 g
s
.32809 .72578 m .32718 .68835 L .34674 .6937 L p .707 .577 .707 r
F P
0 g
s
.19292 .65795 m .19422 .60313 L .22181 .5987 L p .707 .577 .707 r
F P
0 g
s
.16563 .79013 m .16407 .77116 L .18002 .76589 L p .707 .577 .707 r
F P
0 g
s
.18279 .69269 m .1837 .73012 L .16571 .7366 L p .707 .577 .707 r
F P
0 g
s
.18002 .76589 m .18159 .78486 L .16563 .79013 L p .707 .577 .707 r
F P
0 g
s
.3141 .60354 m .3128 .65836 L .28353 .65374 L p .707 .577 .707 r
F P
0 g
s
.28353 .65374 m .28483 .59892 L .3141 .60354 L p .707 .577 .707 r
F P
0 g
s
.6183 .25918 m .6183 .76107 L .58701 .75235 L p .707 .577 .707 r
F P
0 g
s
.58701 .75235 m .58701 .25046 L .6183 .25918 L p .707 .577 .707 r
F P
0 g
s
.22051 .65352 m .22181 .5987 L .25303 .59725 L p .707 .577 .707 r
F P
0 g
s
.22181 .5987 m .22051 .65352 L .19292 .65795 L p .707 .577 .707 r
F P
0 g
s
.38495 .25798 m .38495 .75987 L .36369 .77055 L p .707 .577 .707 r
F P
0 g
s
.38495 .75987 m .38495 .25798 L .41747 .24959 L p .707 .577 .707 r
F P
0 g
s
.34456 .75388 m .34612 .77285 L .32483 .77114 L p .707 .577 .707 r
F P
0 g
s
.32483 .77114 m .32326 .75217 L .34456 .75388 L p .707 .577 .707 r
F P
0 g
s
.1837 .73012 m .18279 .69269 L .20806 .68762 L p .707 .577 .707 r
F P
0 g
s
.74826 .65425 m .74697 .59805 L .71516 .59803 L p .707 .577 .707 r
F P
0 g
s
.74697 .59805 m .74826 .65425 L .77949 .65203 L p .707 .577 .707 r
F P
0 g
s
.77949 .65203 m .77819 .59583 L .74697 .59805 L p .707 .577 .707 r
F P
0 g
s
.28483 .59892 m .28353 .65374 L .25173 .65207 L p .707 .577 .707 r
F P
0 g
s
.25173 .65207 m .25303 .59725 L .28483 .59892 L p .707 .577 .707 r
F P
0 g
s
.25303 .59725 m .25173 .65207 L .22051 .65352 L p .707 .577 .707 r
F P
0 g
s
.71646 .65424 m .71516 .59803 L .6859 .59578 L p .707 .577 .707 r
F P
0 g
s
.71516 .59803 m .71646 .65424 L .74826 .65425 L p .707 .577 .707 r
F P
0 g
s
.32718 .68835 m .32809 .72578 L .30168 .72227 L p .707 .577 .707 r
F P
0 g
s
.30168 .72227 m .30077 .68484 L .32718 .68835 L p .707 .577 .707 r
F P
0 g
s
.77819 .59583 m .77949 .65203 L .80708 .6478 L p .707 .577 .707 r
F P
0 g
s
.80708 .6478 m .80578 .59159 L .77819 .59583 L p .707 .577 .707 r
F P
0 g
s
.18159 .78486 m .18002 .76589 L .20372 .7609 L p .707 .577 .707 r
F P
0 g
s
.20806 .68762 m .20898 .72505 L .1837 .73012 L p .707 .577 .707 r
F P
0 g
s
.20372 .7609 m .20528 .77987 L .18159 .78486 L p .707 .577 .707 r
F P
0 g
s
.6872 .65199 m .6859 .59578 L .66204 .59152 L p .707 .577 .707 r
F P
0 g
s
.6859 .59578 m .6872 .65199 L .71646 .65424 L p .707 .577 .707 r
F P
0 g
s
.20898 .72505 m .20806 .68762 L .23814 .68445 L p .707 .577 .707 r
F P
0 g
s
.30077 .68484 m .30168 .72227 L .271 .72092 L p .707 .577 .707 r
F P
0 g
s
.271 .72092 m .27009 .68349 L .30077 .68484 L p .707 .577 .707 r
F P
0 g
s
.32326 .75217 m .32483 .77114 L .29725 .77107 L p .707 .577 .707 r
F P
0 g
s
.29725 .77107 m .29569 .7521 L .32326 .75217 L p .707 .577 .707 r
F P
0 g
s
.729 .72246 m .72991 .68586 L .69923 .68242 L p .707 .577 .707 r
F P
0 g
s
.72991 .68586 m .729 .72246 L .76094 .72288 L p .707 .577 .707 r
F P
0 g
s
.76094 .72288 m .76185 .68628 L .72991 .68586 L p .707 .577 .707 r
F P
0 g
s
.80578 .59159 m .80708 .6478 L .82834 .64196 L p .707 .577 .707 r
F P
0 g
s
.82834 .64196 m .82704 .58576 L .80578 .59159 L p .707 .577 .707 r
F P
0 g
s
.76185 .68628 m .76094 .72288 L .79102 .72025 L p .707 .577 .707 r
F P
0 g
s
.79102 .72025 m .79193 .68365 L .76185 .68628 L p .707 .577 .707 r
F P
0 g
s
.58701 .25046 m .58701 .75235 L .54719 .74664 L p .707 .577 .707 r
F P
0 g
s
.54719 .74664 m .54719 .24475 L .58701 .25046 L p .707 .577 .707 r
F P
0 g
s
.41747 .75148 m .41747 .24959 L .45806 .2443 L p .707 .577 .707 r
F P
0 g
s
.41747 .24959 m .41747 .75148 L .38495 .75987 L p .707 .577 .707 r
F P
0 g
s
.23814 .68445 m .23905 .72188 L .20898 .72505 L p .707 .577 .707 r
F P
0 g
s
.66204 .59152 m .66334 .64773 L .6872 .65199 L p .707 .577 .707 r
F P
0 g
s
.20528 .77987 m .20372 .7609 L .23284 .75668 L p .707 .577 .707 r
F P
0 g
s
.23905 .72188 m .23814 .68445 L .27009 .68349 L p .707 .577 .707 r
F P
0 g
s
.69832 .71902 m .69923 .68242 L .67282 .67631 L p .707 .577 .707 r
F P
0 g
s
.69923 .68242 m .69832 .71902 L .729 .72246 L p .707 .577 .707 r
F P
0 g
s
.27009 .68349 m .271 .72092 L .23905 .72188 L p .707 .577 .707 r
F P
0 g
s
.23284 .75668 m .2344 .77565 L .20528 .77987 L p .707 .577 .707 r
F P
0 g
s
.79193 .68365 m .79102 .72025 L .81629 .71481 L p .707 .577 .707 r
F P
0 g
s
.81629 .71481 m .81721 .67821 L .79193 .68365 L p .707 .577 .707 r
F P
0 g
s
.66334 .64773 m .66204 .59152 L .64591 .58567 L p .707 .577 .707 r
F P
0 g
s
.29569 .7521 m .29725 .77107 L .26609 .77262 L p .707 .577 .707 r
F P
0 g
s
.26609 .77262 m .26453 .75365 L .29569 .7521 L p .707 .577 .707 r
F P
0 g
s
.67282 .67631 m .67191 .7129 L .69832 .71902 L p .707 .577 .707 r
F P
0 g
s
.2344 .77565 m .23284 .75668 L .26453 .75365 L p .707 .577 .707 r
F P
0 g
s
.26453 .75365 m .26609 .77262 L .2344 .77565 L p .707 .577 .707 r
F P
0 g
s
.54719 .24475 m .54719 .74664 L .50276 .74452 L p .707 .577 .707 r
F P
0 g
s
.50276 .74452 m .50276 .24263 L .54719 .24475 L p .707 .577 .707 r
F P
0 g
s
.82704 .58576 m .82834 .64196 L .84118 .63509 L p .707 .577 .707 r
F P
0 g
s
.84118 .63509 m .83988 .57889 L .82704 .58576 L p .707 .577 .707 r
F P
0 g
s
.73391 .7711 m .73547 .75343 L .70431 .7485 L p .707 .577 .707 r
F P
0 g
s
.73547 .75343 m .73391 .7711 L .7656 .77219 L p .707 .577 .707 r
F P
0 g
s
.7656 .77219 m .76716 .75453 L .73547 .75343 L p .707 .577 .707 r
F P
0 g
s
.45806 .74619 m .45806 .2443 L .50276 .24263 L p .707 .577 .707 r
F P
0 g
s
.45806 .2443 m .45806 .74619 L .41747 .75148 L p .707 .577 .707 r
F P
0 g
s
.67191 .7129 m .67282 .67631 L .65326 .66811 L p .707 .577 .707 r
F P
0 g
s
.76716 .75453 m .7656 .77219 L .79471 .76934 L p .707 .577 .707 r
F P
0 g
s
.79471 .76934 m .79628 .75168 L .76716 .75453 L p .707 .577 .707 r
F P
0 g
s
.64591 .58567 m .64721 .64187 L .66334 .64773 L p .707 .577 .707 r
F P
0 g
s
.70275 .76616 m .70431 .7485 L .67673 .74021 L p .707 .577 .707 r
F P
0 g
s
.70431 .7485 m .70275 .76616 L .73391 .7711 L p .707 .577 .707 r
F P
0 g
s
.81721 .67821 m .81629 .71481 L .83428 .70711 L p .707 .577 .707 r
F P
0 g
s
.83428 .70711 m .8352 .67051 L .81721 .67821 L p .707 .577 .707 r
F P
0 g
s
.50276 .24263 m .50276 .74452 L .45806 .74619 L p .707 .577 .707 r
F P
0 g
s
.67673 .74021 m .67517 .75787 L .70275 .76616 L p .707 .577 .707 r
F P
0 g
s
.65326 .66811 m .65234 .70471 L .67191 .7129 L p .707 .577 .707 r
F P
0 g
s
.79628 .75168 m .79471 .76934 L .81841 .76282 L p .707 .577 .707 r
F P
0 g
s
.81841 .76282 m .81998 .74516 L .79628 .75168 L p .707 .577 .707 r
F P
0 g
s
.64721 .64187 m .64591 .58567 L .6391 .57879 L p .707 .577 .707 r
F P
0 g
s
.67517 .75787 m .67673 .74021 L .65544 .72937 L p .707 .577 .707 r
F P
0 g
s
.65234 .70471 m .65326 .66811 L .64246 .65863 L p .707 .577 .707 r
F P
0 g
s
.65544 .72937 m .65387 .74703 L .67517 .75787 L p .707 .577 .707 r
F P
0 g
s
.83988 .57889 m .84118 .63509 L .84435 .62786 L p .707 .577 .707 r
F P
0 g
s
.84435 .62786 m .84305 .57166 L .83988 .57889 L p .707 .577 .707 r
F P
0 g
s
.6391 .57879 m .6404 .63499 L .64721 .64187 L p .707 .577 .707 r
F P
0 g
s
.8352 .67051 m .83428 .70711 L .84323 .69789 L p .707 .577 .707 r
F P
0 g
s
.84323 .69789 m .84414 .6613 L .8352 .67051 L p .707 .577 .707 r
F P
0 g
s
.64246 .65863 m .64155 .69523 L .65234 .70471 L p .707 .577 .707 r
F P
0 g
s
.81998 .74516 m .81841 .76282 L .83437 .75327 L p .707 .577 .707 r
F P
0 g
s
.83437 .75327 m .83593 .73561 L .81998 .74516 L p .707 .577 .707 r
F P
0 g
s
.65387 .74703 m .65544 .72937 L .6425 .71705 L p .707 .577 .707 r
F P
0 g
s
.6425 .71705 m .64094 .73471 L .65387 .74703 L p .707 .577 .707 r
F P
0 g
s
.6404 .63499 m .6391 .57879 L .64227 .57156 L p .707 .577 .707 r
F P
0 g
s
.64155 .69523 m .64246 .65863 L .64149 .6488 L p .707 .577 .707 r
F P
0 g
s
.84305 .57166 m .84435 .62786 L .83754 .62098 L p .707 .577 .707 r
F P
0 g
s
.83754 .62098 m .83624 .56478 L .84305 .57166 L p .707 .577 .707 r
F P
0 g
s
.84414 .6613 m .84323 .69789 L .84226 .68807 L p .707 .577 .707 r
F P
0 g
s
.84226 .68807 m .84317 .65147 L .84414 .6613 L p .707 .577 .707 r
F P
0 g
s
.64227 .57156 m .64357 .62776 L .6404 .63499 L p .707 .577 .707 r
F P
0 g
s
.83593 .73561 m .83437 .75327 L .84102 .74163 L p .707 .577 .707 r
F P
0 g
s
.84102 .74163 m .84259 .72397 L .83593 .73561 L p .707 .577 .707 r
F P
0 g
s
.64149 .6488 m .64058 .6854 L .64155 .69523 L p .707 .577 .707 r
F P
0 g
s
.64094 .73471 m .6425 .71705 L .6392 .70445 L p .707 .577 .707 r
F P
0 g
s
.6392 .70445 m .63764 .72212 L .64094 .73471 L p .707 .577 .707 r
F P
0 g
s
.64357 .62776 m .64227 .57156 L .65511 .56469 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64058 .6854 m .64149 .6488 L .65044 .63959 L p .707 .577 .707 r
F P
0 g
s
.83624 .56478 m .83754 .62098 L .82142 .61513 L p .707 .577 .707 r
F P
0 g
s
.82142 .61513 m .82012 .55892 L .83624 .56478 L p .707 .577 .707 r
F P
0 g
s
.84317 .65147 m .84226 .68807 L .83146 .67859 L p .707 .577 .707 r
F P
0 g
s
.83146 .67859 m .83238 .64199 L .84317 .65147 L p .707 .577 .707 r
F P
0 g
s
.40819 .62219 m .40527 .56709 L .37351 .5677 L p .707 .577 .707 r
F P
0 g
s
.40527 .56709 m .40819 .62219 L .43939 .61869 L p .707 .577 .707 r
F P
0 g
s
.43939 .61869 m .43647 .56359 L .40527 .56709 L p .707 .577 .707 r
F P
0 g
s
.84259 .72397 m .84102 .74163 L .83772 .72903 L p .707 .577 .707 r
F P
0 g
s
.83772 .72903 m .83929 .71137 L .84259 .72397 L p .707 .577 .707 r
F P
0 g
s
.65511 .56469 m .65641 .62089 L .64357 .62776 L p .707 .577 .707 r
F P
0 g
s
.37642 .6228 m .37351 .5677 L .34427 .56535 L p .707 .577 .707 r
F P
0 g
s
.37351 .5677 m .37642 .6228 L .40819 .62219 L p .707 .577 .707 r
F P
0 g
s
.63764 .72212 m .6392 .70445 L .64586 .69281 L p .707 .577 .707 r
F P
0 g
s
.65044 .63959 m .64952 .67618 L .64058 .6854 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.43647 .56359 m .43939 .61869 L .46695 .61264 L p .707 .577 .707 r
F P
0 g
s
.46695 .61264 m .46404 .55754 L .43647 .56359 L p .707 .577 .707 r
F P
0 g
s
.64586 .69281 m .6443 .71047 L .63764 .72212 L p .707 .577 .707 r
F P
0 g
s
.34719 .62045 m .34427 .56535 L .32044 .56028 L p .707 .577 .707 r
F P
0 g
s
.34427 .56535 m .34719 .62045 L .37642 .6228 L p .707 .577 .707 r
F P
0 g
s
.65641 .62089 m .65511 .56469 L .67637 .55885 L p .707 .577 .707 r
F P
0 g
s
.46404 .55754 m .46695 .61264 L .4882 .60462 L p .707 .577 .707 r
F P
0 g
s
.4882 .60462 m .48528 .54952 L .46404 .55754 L p .707 .577 .707 r
F P
0 g
s
.64952 .67618 m .65044 .63959 L .66843 .63188 L p .707 .577 .707 r
F P
0 g
s
.38845 .67671 m .39045 .63941 L .3598 .63572 L p .707 .577 .707 r
F P
0 g
s
.39045 .63941 m .38845 .67671 L .42036 .67809 L p .707 .577 .707 r
F P
0 g
s
.42036 .67809 m .42236 .64079 L .39045 .63941 L p .707 .577 .707 r
F P
0 g
s
.42236 .64079 m .42036 .67809 L .45041 .67704 L p .707 .577 .707 r
F P
0 g
s
.45041 .67704 m .45241 .63973 L .42236 .64079 L p .707 .577 .707 r
F P
0 g
s
.82012 .55892 m .82142 .61513 L .79755 .61087 L p .707 .577 .707 r
F P
0 g
s
.79755 .61087 m .79625 .55466 L .82012 .55892 L p .707 .577 .707 r
F P
0 g
s
.83238 .64199 m .83146 .67859 L .8119 .67039 L p .707 .577 .707 r
F P
0 g
s
.8119 .67039 m .81281 .63379 L .83238 .64199 L p .707 .577 .707 r
F P
0 g
s
.67637 .55885 m .67767 .61506 L .65641 .62089 L p .707 .577 .707 r
F P
0 g
s
.83929 .71137 m .83772 .72903 L .82479 .71671 L p .707 .577 .707 r
F P
0 g
s
.82479 .71671 m .82636 .69905 L .83929 .71137 L p .707 .577 .707 r
F P
0 g
s
.3578 .67302 m .3598 .63572 L .33342 .63009 L p .707 .577 .707 r
F P
0 g
s
.3598 .63572 m .3578 .67302 L .38845 .67671 L p .707 .577 .707 r
F P
0 g
s
.6443 .71047 m .64586 .69281 L .66182 .68326 L p .707 .577 .707 r
F P
0 g
s
.32044 .56028 m .32336 .61538 L .34719 .62045 L p .707 .577 .707 r
F P
0 g
s
.66843 .63188 m .66751 .66848 L .64952 .67618 L p .707 .577 .707 r
F P
0 g
s
.45241 .63973 m .45041 .67704 L .47565 .67364 L p .707 .577 .707 r
F P
0 g
s
.47565 .67364 m .47766 .63634 L .45241 .63973 L p .707 .577 .707 r
F P
0 g
s
.38999 .71068 m .39339 .69199 L .36262 .68549 L p .707 .577 .707 r
F P
0 g
s
.39339 .69199 m .38999 .71068 L .42129 .7157 L p .707 .577 .707 r
F P
0 g
s
.42129 .7157 m .42468 .69701 L .39339 .69199 L p .707 .577 .707 r
F P
0 g
s
.32336 .61538 m .32044 .56028 L .30434 .55298 L p .707 .577 .707 r
F P
0 g
s
.36262 .68549 m .35922 .70418 L .38999 .71068 L p .707 .577 .707 r
F P
0 g
s
.67767 .61506 m .67637 .55885 L .70396 .55462 L p .707 .577 .707 r
F P
0 g
s
.42468 .69701 m .42129 .7157 L .45006 .71875 L p .707 .577 .707 r
F P
0 g
s
.45006 .71875 m .45345 .70006 L .42468 .69701 L p .707 .577 .707 r
F P
0 g
s
.33342 .63009 m .33142 .66739 L .3578 .67302 L p .707 .577 .707 r
F P
0 g
s
.66182 .68326 m .66025 .70092 L .6443 .71047 L p .707 .577 .707 r
F P
0 g
s
.35922 .70418 m .36262 .68549 L .33539 .67814 L p .707 .577 .707 r
F P
0 g
s
.48528 .54952 m .4882 .60462 L .50103 .59543 L p .707 .577 .707 r
F P
0 g
s
.50103 .59543 m .49812 .54033 L .48528 .54952 L p .707 .577 .707 r
F P
0 g
s
.33539 .67814 m .332 .69684 L .35922 .70418 L p .707 .577 .707 r
F P
0 g
s
.79625 .55466 m .79755 .61087 L .76829 .60862 L p .707 .577 .707 r
F P
0 g
s
.76829 .60862 m .76699 .55241 L .79625 .55466 L p .707 .577 .707 r
F P
0 g
s
.66751 .66848 m .66843 .63188 L .6937 .62645 L p .707 .577 .707 r
F P
0 g
s
.33142 .66739 m .33342 .63009 L .31388 .62306 L p .707 .577 .707 r
F P
0 g
s
.81281 .63379 m .8119 .67039 L .78549 .66427 L p .707 .577 .707 r
F P
0 g
s
.78549 .66427 m .7864 .62767 L .81281 .63379 L p .707 .577 .707 r
F P
0 g
s
.70396 .55462 m .70526 .61082 L .67767 .61506 L p .707 .577 .707 r
F P
0 g
s
.45345 .70006 m .45006 .71875 L .47347 .71954 L p .707 .577 .707 r
F P
0 g
s
.47347 .71954 m .47687 .70084 L .45345 .70006 L p .707 .577 .707 r
F P
0 g
s
.30434 .55298 m .30726 .60807 L .32336 .61538 L p .707 .577 .707 r
F P
0 g
s
.47766 .63634 m .47565 .67364 L .49363 .66825 L p .707 .577 .707 r
F P
0 g
s
.49363 .66825 m .49563 .63094 L .47766 .63634 L p .707 .577 .707 r
F P
0 g
s
.70526 .61082 m .70396 .55462 L .73519 .5524 L p .707 .577 .707 r
F P
0 g
s
.82636 .69905 m .82479 .71671 L .8035 .70588 L p .707 .577 .707 r
F P
0 g
s
.8035 .70588 m .80506 .68821 L .82636 .69905 L p .707 .577 .707 r
F P
0 g
s
.332 .69684 m .33539 .67814 L .31438 .67067 L p .707 .577 .707 r
F P
0 g
s
.31388 .62306 m .31188 .66037 L .33142 .66739 L p .707 .577 .707 r
F P
0 g
s
.76699 .55241 m .76829 .60862 L .73649 .6086 L p .707 .577 .707 r
F P
0 g
s
.73649 .6086 m .73519 .5524 L .76699 .55241 L p .707 .577 .707 r
F P
0 g
s
.6937 .62645 m .69279 .66305 L .66751 .66848 L p .707 .577 .707 r
F P
0 g
s
.66025 .70092 m .66182 .68326 L .68551 .67674 L p .707 .577 .707 r
F P
0 g
s
.31438 .67067 m .31098 .68937 L .332 .69684 L p .707 .577 .707 r
F P
0 g
s
.73519 .5524 m .73649 .6086 L .70526 .61082 L p .707 .577 .707 r
F P
0 g
s
.30726 .60807 m .30434 .55298 L .29754 .54416 L p .707 .577 .707 r
F P
0 g
s
.69279 .66305 m .6937 .62645 L .72378 .62381 L p .707 .577 .707 r
F P
0 g
s
.68551 .67674 m .68395 .69441 L .66025 .70092 L p .707 .577 .707 r
F P
0 g
s
.7864 .62767 m .78549 .66427 L .75481 .66083 L p .707 .577 .707 r
F P
0 g
s
.75481 .66083 m .75572 .62423 L .7864 .62767 L p .707 .577 .707 r
F P
0 g
s
.49812 .54033 m .50103 .59543 L .50421 .58596 L p .707 .577 .707 r
F P
0 g
s
.50421 .58596 m .50129 .53086 L .49812 .54033 L p .707 .577 .707 r
F P
0 g
s
.31188 .66037 m .31388 .62306 L .3031 .61534 L p .707 .577 .707 r
F P
0 g
s
.47687 .70084 m .47347 .71954 L .48925 .71797 L p .707 .577 .707 r
F P
0 g
s
.48925 .71797 m .49264 .69927 L .47687 .70084 L p .707 .577 .707 r
F P
0 g
s
.72287 .66041 m .72378 .62381 L .75572 .62423 L p .707 .577 .707 r
F P
0 g
s
.72378 .62381 m .72287 .66041 L .69279 .66305 L p .707 .577 .707 r
F P
0 g
s
.75572 .62423 m .75481 .66083 L .72287 .66041 L p .707 .577 .707 r
F P
0 g
s
.80506 .68821 m .8035 .70588 L .77592 .69758 L p .707 .577 .707 r
F P
0 g
s
.77592 .69758 m .77748 .67992 L .80506 .68821 L p .707 .577 .707 r
F P
0 g
s
.31098 .68937 m .31438 .67067 L .30163 .66381 L p .707 .577 .707 r
F P
0 g
s
.68395 .69441 m .68551 .67674 L .71463 .67389 L p .707 .577 .707 r
F P
0 g
s
.49563 .63094 m .49363 .66825 L .50257 .66137 L p .707 .577 .707 r
F P
0 g
s
.50257 .66137 m .50457 .62407 L .49563 .63094 L p .707 .577 .707 r
F P
0 g
s
.29754 .54416 m .30046 .59926 L .30726 .60807 L p .707 .577 .707 r
F P
0 g
s
.3031 .61534 m .3011 .65264 L .31188 .66037 L p .707 .577 .707 r
F P
0 g
s
.30163 .66381 m .29823 .6825 L .31098 .68937 L p .707 .577 .707 r
F P
0 g
s
.71463 .67389 m .71307 .69155 L .68395 .69441 L p .707 .577 .707 r
F P
0 g
s
.77748 .67992 m .77592 .69758 L .74476 .69265 L p .707 .577 .707 r
F P
0 g
s
.74476 .69265 m .74632 .67499 L .77748 .67992 L p .707 .577 .707 r
F P
0 g
s
.71307 .69155 m .71463 .67389 L .74632 .67499 L p .707 .577 .707 r
F P
0 g
s
.30046 .59926 m .29754 .54416 L .30072 .53469 L p .707 .577 .707 r
F P
0 g
s
.74632 .67499 m .74476 .69265 L .71307 .69155 L p .707 .577 .707 r
F P
0 g
s
.50129 .53086 m .50421 .58596 L .49742 .57714 L p .707 .577 .707 r
F P
0 g
s
.49742 .57714 m .4945 .52205 L .50129 .53086 L p .707 .577 .707 r
F P
0 g
s
.3011 .65264 m .3031 .61534 L .30214 .60766 L p .707 .577 .707 r
F P
0 g
s
.49264 .69927 m .48925 .71797 L .49584 .71421 L p .707 .577 .707 r
F P
0 g
s
.49584 .71421 m .49924 .69552 L .49264 .69927 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29823 .6825 m .30163 .66381 L .29839 .65823 L p .707 .577 .707 r
F P
0 g
s
.50457 .62407 m .50257 .66137 L .5016 .6537 L p .707 .577 .707 r
F P
0 g
s
.5016 .6537 m .5036 .61639 L .50457 .62407 L p .707 .577 .707 r
F P
0 g
s
.30072 .53469 m .30364 .58979 L .30046 .59926 L p .707 .577 .707 r
F P
0 g
s
.30214 .60766 m .30014 .64496 L .3011 .65264 L p .707 .577 .707 r
F P
0 g
s
.29839 .65823 m .29499 .67692 L .29823 .6825 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30364 .58979 m .30072 .53469 L .31356 .5255 L p .707 .577 .707 r
F P
0 g
s
.4945 .52205 m .49742 .57714 L .48131 .56984 L p .707 .577 .707 r
F P
0 g
s
.48131 .56984 m .4784 .51474 L .4945 .52205 L p .707 .577 .707 r
F P
0 g
s
.30014 .64496 m .30214 .60766 L .31108 .60079 L p .707 .577 .707 r
F P
0 g
s
.49924 .69552 m .49584 .71421 L .49261 .70863 L p .707 .577 .707 r
F P
0 g
s
.49261 .70863 m .496 .68993 L .49924 .69552 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29499 .67692 m .29839 .65823 L .30498 .65447 L p .707 .577 .707 r
F P
0 g
s
.31356 .5255 m .31648 .5806 L .30364 .58979 L p .707 .577 .707 r
F P
0 g
s
.5036 .61639 m .5016 .6537 L .49082 .64597 L p .707 .577 .707 r
F P
0 g
s
.49082 .64597 m .49283 .60867 L .5036 .61639 L p .707 .577 .707 r
F P
0 g
s
.31108 .60079 m .30908 .63809 L .30014 .64496 L p .707 .577 .707 r
F P
0 g
s
.30498 .65447 m .30159 .67316 L .29499 .67692 L p .707 .577 .707 r
F P
0 g
s
.31648 .5806 m .31356 .5255 L .3348 .51748 L p .707 .577 .707 r
F P
0 g
s
.4784 .51474 m .48131 .56984 L .45748 .56477 L p .707 .577 .707 r
F P
0 g
s
.45748 .56477 m .45456 .50967 L .4784 .51474 L p .707 .577 .707 r
F P
0 g
s
.30908 .63809 m .31108 .60079 L .32905 .59539 L p .707 .577 .707 r
F P
0 g
s
.496 .68993 m .49261 .70863 L .47985 .70176 L p .707 .577 .707 r
F P
0 g
s
.47985 .70176 m .48325 .68307 L .496 .68993 L p .707 .577 .707 r
F P
0 g
s
.3348 .51748 m .33772 .57258 L .31648 .5806 L p .707 .577 .707 r
F P
0 g
s
.49283 .60867 m .49082 .64597 L .47129 .63895 L p .707 .577 .707 r
F P
0 g
s
.47129 .63895 m .47329 .60164 L .49283 .60867 L p .707 .577 .707 r
F P
0 g
s
.30159 .67316 m .30498 .65447 L .32076 .6529 L p .707 .577 .707 r
F P
0 g
s
.32905 .59539 m .32705 .63269 L .30908 .63809 L p .707 .577 .707 r
F P
0 g
s
.32076 .6529 m .31736 .67159 L .30159 .67316 L p .707 .577 .707 r
F P
0 g
s
.33772 .57258 m .3348 .51748 L .36237 .51143 L p .707 .577 .707 r
F P
0 g
s
.45456 .50967 m .45748 .56477 L .42825 .56242 L p .707 .577 .707 r
F P
0 g
s
.42825 .56242 m .42533 .50732 L .45456 .50967 L p .707 .577 .707 r
F P
0 g
s
.32705 .63269 m .32905 .59539 L .3543 .592 L p .707 .577 .707 r
F P
0 g
s
.36529 .56653 m .36237 .51143 L .39356 .50793 L p .707 .577 .707 r
F P
0 g
s
.36237 .51143 m .36529 .56653 L .33772 .57258 L p .707 .577 .707 r
F P
0 g
s
.42533 .50732 m .42825 .56242 L .39648 .56303 L p .707 .577 .707 r
F P
0 g
s
.39648 .56303 m .39356 .50793 L .42533 .50732 L p .707 .577 .707 r
F P
0 g
s
.48325 .68307 m .47985 .70176 L .45884 .69429 L p .707 .577 .707 r
F P
0 g
s
.45884 .69429 m .46223 .6756 L .48325 .68307 L p .707 .577 .707 r
F P
0 g
s
.47329 .60164 m .47129 .63895 L .4449 .63331 L p .707 .577 .707 r
F P
0 g
s
.4449 .63331 m .4469 .59601 L .47329 .60164 L p .707 .577 .707 r
F P
0 g
s
.39356 .50793 m .39648 .56303 L .36529 .56653 L p .707 .577 .707 r
F P
0 g
s
.3543 .592 m .3523 .6293 L .32705 .63269 L p .707 .577 .707 r
F P
0 g
s
.31736 .67159 m .32076 .6529 L .34417 .65368 L p .707 .577 .707 r
F P
0 g
s
.34417 .65368 m .34078 .67237 L .31736 .67159 L p .707 .577 .707 r
F P
0 g
s
.3523 .6293 m .3543 .592 L .38435 .59094 L p .707 .577 .707 r
F P
0 g
s
.4469 .59601 m .4449 .63331 L .41426 .62963 L p .707 .577 .707 r
F P
0 g
s
.41426 .62963 m .41626 .59232 L .4469 .59601 L p .707 .577 .707 r
F P
0 g
s
.46223 .6756 m .45884 .69429 L .43161 .68695 L p .707 .577 .707 r
F P
0 g
s
.43161 .68695 m .43501 .66825 L .46223 .6756 L p .707 .577 .707 r
F P
0 g
s
.38435 .59094 m .38235 .62824 L .3523 .6293 L p .707 .577 .707 r
F P
0 g
s
.38235 .62824 m .38435 .59094 L .41626 .59232 L p .707 .577 .707 r
F P
0 g
s
.34078 .67237 m .34417 .65368 L .37294 .65673 L p .707 .577 .707 r
F P
0 g
s
.41626 .59232 m .41426 .62963 L .38235 .62824 L p .707 .577 .707 r
F P
0 g
s
.37294 .65673 m .36955 .67543 L .34078 .67237 L p .707 .577 .707 r
F P
0 g
s
.43501 .66825 m .43161 .68695 L .40085 .68045 L p .707 .577 .707 r
F P
0 g
s
.40085 .68045 m .40424 .66175 L .43501 .66825 L p .707 .577 .707 r
F P
0 g
s
.36955 .67543 m .37294 .65673 L .40424 .66175 L p .707 .577 .707 r
F P
0 g
s
.40424 .66175 m .40085 .68045 L .36955 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF5`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
069oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00GWoo10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00Fgoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00003Goo
8@00=goo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00007Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<goo001DOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH3000aOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
009JEPT00003FUH005YF00`000AJEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00E7oo
00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEQ@000AJEP03001JEUYF00AJEP@00003FUH0
05YF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH2000^Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP04001JEUYFFUH60008FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<005YF00002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`05FUH005YFFUH00003FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJ
EP00FUH0000]Ool005Eoo`06FUH005YFFUH005YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00H005YF000005YF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0002eoo`00EGoo00AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00AJEP000000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eoo`00
EGoo00=JEP0000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Goo001E
Ool00eYF00000003FUH00`00FUIJEP03FUHJ00000eYF001JEP06FUH00`00FUIJEP03FUH01@00FUIJ
EUYF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH0000]Ool004Aoo`P000Uoo`03001JEP0000=JEPH000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEUYFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool003aoo`P000=JEP03001JEUYF009JEPX00003FUH000000080009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03
001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP8002eoo`00=Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0`000UYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF8@000eYF00<005YFFUH00UYF0P00;Goo000`Ool20005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
0eYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP00008000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0
000002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHA
0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH70002FUH200000eYF001JEP04FUH=
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`0015YF1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001EYF00D005YFFUIJEP0002eoo`00;7oo0P000eYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001J
EP8000=JEP04001JEUYFFUH80003FUH60003FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00D005YFFUIJEP0002eoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000=JEP03001JEUYF00AJEPX000AJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH0000002ioo`00;7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF100000=JEP00000020000eYF
00<005YFFUH015YF0`0000AJEP00FUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<7oo000/Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF5@000eYF00<005YFFUH03`001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01@002Goo1@001Woo1`000UYF00<005YFFUH00eYF00<005YFFUH00UYF1P00
0UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YFFUH00UYF1@0015YF6@0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF00<005YF00000P0015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1@0025YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF
1P004Woo1P001EYF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo0P000UYF0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH00eYF100025YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF0P002Woo0`003Goo100000=JEP00FUH015YF00@005YFFUH002eoo`00;7oo10000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<0
05YFFUH00`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00UYF0`000UYF00L005YFFUIJEP00FUH00008Ool5000@Ool30004FUH01000FUIJEP00
;Goo000/Ool30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF001JEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
00030003FUH60004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH200000eYF001JEP040003FUH01P00FUIJEUYF001JEPl0019oo`<00005FUH005YFFUH0000]Ool0
02aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP@000=JEPP000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0000000AJ
EPT000AJEP03001JEUYF00IJEP03001JEP0000<000eoo`<00003FUH00000009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YF0000100000=JEP00FUH015YF1`001UYF00<005YF
FUH01UYF00<005YF00000P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF10001Goo100000=JEP00FUH00eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH600000eYF
000000020002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH00`00FUIJEP02FUH3000]Ool0
02eoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEP0000T000=JEP03001JEP0000<000IJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=J
EP03001JEUYF009JEP03001JEP0002eoo`00;Goo0P000eYF1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH00eYF1P00
0eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF00H005YFFUH005YF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0000]Ool002ioo`06001J
EP00001JEP001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF20002EYF100015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEPH000QJEP03001J
EUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF1P001UYF00<005YF00000P0000=JEP00FUH0
0UYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YF0000
0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0P00
0UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01000FUIJEUYF3@000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
10000UYF00<005YFFUH00eYF0P0000=JEP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH0
0000FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002
FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P001EYF00<005YF00000P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EP00FUH01@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080
0005FUH00000FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP00;goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJ
EP00FUH000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000EJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
009JEP03001oogoo02aoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP040002FUH00`00
FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00Oomo
o`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF009JEQ40009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH0000000@000=JEPT000AJEPH000=JEP03001JEUYF009JEPP000Ioo`03
001JEUYF008002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEQT000AJ
EP03001JEUYF009JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=J
EP00FUH00eYF00<005YF00000`000UYF0P0017oo4P003goo00@005YF000002eoo`00;7oo00@005YF
FUH000AJEP04001JEUYFFUH80007Ool50007Ool=0002FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00004FUH200000eYF00000009Ool5000HOol3
000]Ool002aoo`04001JEUYF0003FUH500000eYF0000000H0004FUH00`00FUIJEP04FUH00`00FUH0
00020002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH01000FUIJEP00
1EYF0`002goo0`006Woo0P00;Goo000/Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF10001EYF00<005YF0000
9goo0`00;Goo000/Ool00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00P0015YF00@005YFFUH0
02Ioo`03001JEP0002eoo`00;7oo10001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEP00FUH00005FUH300001EYF001JEUYF000097oo0`0000=J
EP00Ool0;7oo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP00008000IJEP03001JEP0000@0025oo`<0009JEP8002ioo`00;7oo
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEP`000AJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00006FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02FUH2000^Ool002aoo`04001JEUYF
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000>0003FUH20000
17oo001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF1`001eYF00<005YFFUH00eYF00<005YF00000UYF0P000eYF00<005YFFUH01UYF00<005YF
FUH0100047oo1@001EYF00D005YFFUIJEP0002moo`00;Goo0`001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH015YF00<005YFFUH01@000Woo00<005YF00001EYF
00<005YFFUH00UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH00`0015YF00<005YFFUH00eYF00<005YF00000P000UYF0P0000=JEP00FUH01eYF00<005YFFUH0
15YF40000eYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;goo0P0015YF00<005YFFUH015YF
00<005YF0000200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF00000Woo1`00
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
035oo`00<Goo0`0000=JEP00FUH01`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20005FUH00`00FUH00007Ool6
0002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000cOol0
039oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP000eYF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF000000=JEP03001JEP0000L000=J
EP800003FUH0000000<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
<7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00L005YFFUH005YF001JEP0200000eYF001JEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000AJEP00FUH000AJEP03001JEP000080009JEP@000=oo`@0009JEP03001JEUYF00IJEP03001J
EUYF009JEPD003Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
7@0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00UYF0`000UYF00<007ooOol01Goo4000?goo000/Ool30004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH=000<Ool50003FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000EJEP03001JEUYF009JEP<00003FUH007oo05Eoo`00;7oo00<005YF000015YF00<0
05YFFUH00eYF1P0027oo1@0027oo100000=JEP00FUH01EYF00<005YFFUH00UYF0P001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF009JEP03001JEUYF008005Ioo`00
;7oo00@005YFFUH000=JEP03001JEP0000<000]ooa0000EJEP03001JEUYF00AJEP03001JEUYF009J
EP8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00P000AJEP04001JEUYF001FOol0
02aoo`04001JEUYF0002FUHB0004FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP040005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001eYF0`0000EJEP00FUIJEP00
05Ioo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000goo00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH00P000eYF00<007ooOol0Dgoo000]Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000030007Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000=JEP00Ool0E7oo000]Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000<Ool20003FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00@005YF000000=oo`8005Eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@004goo00@0
05YFFUH000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH30005Ool2001EOol0031ooad001eo
o`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEP000006FUH00`00FUH000030007Ool01000FUH00000E7oo001/Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH4
0004FUH6000:Ool20002FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00`000moo`03001JEP00009JEP03001o
ogoo059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`0057oo
00@005YFFUIJEP8005Eoo`00N7oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1P001Woo1@004Woo0P0015YF0P00EGoo001nOolO000<Ool5000@Ool200000eYF001JEP03FUH00`00
Oomoo`1DOol008ioo`04001JEUYF000HOol3000?Ool20003FUH01@00FUIJEUYF0000Egoo002>Ool0
0`00FUH0000XOol30006FUH00`00FUH0001HOol008moo`8002Ioo`800003FUH005YF00IJEP8005Uo
o`00Sgoo0P008goo0`000eYF00<005YFFUH015YF0P00FWoo002?Ool00`00FUH0000NOol40007FUH0
1000FUIJEUYF0P00G7oo002?Ool2000015YF000000005goo10000UYF00<005YFFUH01UYF00@005YF
000005ioo`00T7oo00<005YF00000UYF1`002Goo1`001UYF00<005YFFUH01EYF0`00H7oo002@Ool0
0`00FUH00005FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002A
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
001UOol0099oo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP@006Qoo`00
Tgoo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000K7oo002FOol70004FUH0
0`00FUIJEP02FUH7001`Ool009eoo`T007Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60071 .7485 m .60249 .69273 L .57088 .69059 L p .707 .577 .707 r
F P
0 g
s
.60249 .69273 m .60071 .7485 L .63221 .74809 L p .707 .577 .707 r
F P
0 g
s
.63221 .74809 m .634 .69232 L .60249 .69273 L p .707 .577 .707 r
F P
0 g
s
.5691 .74637 m .57088 .69059 L .54227 .68612 L p .707 .577 .707 r
F P
0 g
s
.57088 .69059 m .5691 .74637 L .60071 .7485 L p .707 .577 .707 r
F P
0 g
s
.634 .69232 m .63221 .74809 L .66053 .74518 L p .707 .577 .707 r
F P
0 g
s
.66053 .74518 m .66232 .6894 L .634 .69232 L p .707 .577 .707 r
F P
0 g
s
.54048 .74189 m .54227 .68612 L .51945 .67975 L p .707 .577 .707 r
F P
0 g
s
.54227 .68612 m .54048 .74189 L .5691 .74637 L p .707 .577 .707 r
F P
0 g
s
.66232 .6894 m .66053 .74518 L .6829 .74005 L p .707 .577 .707 r
F P
0 g
s
.6829 .74005 m .68468 .68427 L .66232 .6894 L p .707 .577 .707 r
F P
0 g
s
.60948 .81143 m .60826 .77457 L .57638 .77494 L p .707 .577 .707 r
F P
0 g
s
.60826 .77457 m .60948 .81143 L .64046 .80826 L p .707 .577 .707 r
F P
0 g
s
.64046 .80826 m .63924 .7714 L .60826 .77457 L p .707 .577 .707 r
F P
0 g
s
.5776 .8118 m .57638 .77494 L .54672 .77246 L p .707 .577 .707 r
F P
0 g
s
.57638 .77494 m .5776 .8118 L .60948 .81143 L p .707 .577 .707 r
F P
0 g
s
.63924 .7714 m .64046 .80826 L .6675 .8026 L p .707 .577 .707 r
F P
0 g
s
.6675 .8026 m .66628 .76574 L .63924 .7714 L p .707 .577 .707 r
F P
0 g
s
.51945 .67975 m .51766 .73552 L .54048 .74189 L p .707 .577 .707 r
F P
0 g
s
.54672 .77246 m .54794 .80932 L .5776 .8118 L p .707 .577 .707 r
F P
0 g
s
.54794 .80932 m .54672 .77246 L .52218 .76739 L p .707 .577 .707 r
F P
0 g
s
.51766 .73552 m .51945 .67975 L .50466 .6721 L p .707 .577 .707 r
F P
0 g
s
.61753 .85569 m .61544 .83761 L .58367 .84064 L p .707 .577 .707 r
F P
0 g
s
.61544 .83761 m .61753 .85569 L .64797 .84956 L p .707 .577 .707 r
F P
0 g
s
.64797 .84956 m .64588 .83148 L .61544 .83761 L p .707 .577 .707 r
F P
0 g
s
.68468 .68427 m .6829 .74005 L .69711 .7332 L p .707 .577 .707 r
F P
0 g
s
.69711 .7332 m .6989 .67742 L .68468 .68427 L p .707 .577 .707 r
F P
0 g
s
.58576 .85872 m .58367 .84064 L .55368 .84029 L p .707 .577 .707 r
F P
0 g
s
.58367 .84064 m .58576 .85872 L .61753 .85569 L p .707 .577 .707 r
F P
0 g
s
.66628 .76574 m .6675 .8026 L .68796 .79499 L p .707 .577 .707 r
F P
0 g
s
.68796 .79499 m .68674 .75813 L .66628 .76574 L p .707 .577 .707 r
F P
0 g
s
.52218 .76739 m .5234 .80425 L .54794 .80932 L p .707 .577 .707 r
F P
0 g
s
.64588 .83148 m .64797 .84956 L .6741 .84095 L p .707 .577 .707 r
F P
0 g
s
.6741 .84095 m .67201 .82287 L .64588 .83148 L p .707 .577 .707 r
F P
0 g
s
.55368 .84029 m .55576 .85837 L .58576 .85872 L p .707 .577 .707 r
F P
0 g
s
.50466 .6721 m .50287 .72788 L .51766 .73552 L p .707 .577 .707 r
F P
0 g
s
.55576 .85837 m .55368 .84029 L .52841 .83658 L p .707 .577 .707 r
F P
0 g
s
.5234 .80425 m .52218 .76739 L .50516 .76021 L p .707 .577 .707 r
F P
0 g
s
.52841 .83658 m .53049 .85466 L .55576 .85837 L p .707 .577 .707 r
F P
0 g
s
.67201 .82287 m .6741 .84095 L .69336 .83068 L p .707 .577 .707 r
F P
0 g
s
.69336 .83068 m .69127 .8126 L .67201 .82287 L p .707 .577 .707 r
F P
0 g
s
.50287 .72788 m .50466 .6721 L .49934 .66393 L p .707 .577 .707 r
F P
0 g
s
.50516 .76021 m .50638 .79707 L .5234 .80425 L p .707 .577 .707 r
F P
0 g
s
.68674 .75813 m .68796 .79499 L .69984 .78619 L p .707 .577 .707 r
F P
0 g
s
.69984 .78619 m .69862 .74933 L .68674 .75813 L p .707 .577 .707 r
F P
0 g
s
.6989 .67742 m .69711 .7332 L .70179 .7253 L p .707 .577 .707 r
F P
0 g
s
.70179 .7253 m .70358 .66953 L .6989 .67742 L p .707 .577 .707 r
F P
0 g
s
.53049 .85466 m .52841 .83658 L .51032 .82989 L p .707 .577 .707 r
F P
0 g
s
.51032 .82989 m .5124 .84796 L .53049 .85466 L p .707 .577 .707 r
F P
0 g
s
.49934 .66393 m .49755 .71971 L .50287 .72788 L p .707 .577 .707 r
F P
0 g
s
.50638 .79707 m .50516 .76021 L .49734 .75164 L p .707 .577 .707 r
F P
0 g
s
.69127 .8126 m .69336 .83068 L .70386 .81978 L p .707 .577 .707 r
F P
0 g
s
.70386 .81978 m .70178 .8017 L .69127 .8126 L p .707 .577 .707 r
F P
0 g
s
.49734 .75164 m .49856 .7885 L .50638 .79707 L p .707 .577 .707 r
F P
0 g
s
.49755 .71971 m .49934 .66393 L .50402 .65604 L p .707 .577 .707 r
F P
0 g
s
.69862 .74933 m .69984 .78619 L .70197 .77706 L p .707 .577 .707 r
F P
0 g
s
.70197 .77706 m .70075 .7402 L .69862 .74933 L p .707 .577 .707 r
F P
0 g
s
.5124 .84796 m .51032 .82989 L .50119 .82086 L p .707 .577 .707 r
F P
0 g
s
.70358 .66953 m .70179 .7253 L .69647 .71713 L p .707 .577 .707 r
F P
0 g
s
.69647 .71713 m .69826 .66136 L .70358 .66953 L p .707 .577 .707 r
F P
0 g
s
.49464 .8219 m .49464 .32001 L .45036 .31767 L p .707 .577 .707 r
F P
0 g
s
.50119 .82086 m .50327 .83893 L .5124 .84796 L p .707 .577 .707 r
F P
0 g
s
.50402 .65604 m .50223 .71181 L .49755 .71971 L p .707 .577 .707 r
F P
0 g
s
.49856 .7885 m .49734 .75164 L .49946 .74251 L p .707 .577 .707 r
F P
0 g
s
.49946 .74251 m .50069 .77936 L .49856 .7885 L p .707 .577 .707 r
F P
0 g
s
.50223 .71181 m .50402 .65604 L .51823 .64919 L p .707 .577 .707 r
F P
0 g
s
.50327 .83893 m .50119 .82086 L .50191 .81037 L p .707 .577 .707 r
F P
0 g
s
.50191 .81037 m .504 .82845 L .50327 .83893 L p .707 .577 .707 r
F P
0 g
s
.51823 .64919 m .51645 .70496 L .50223 .71181 L p .707 .577 .707 r
F P
0 g
s
.50069 .77936 m .49946 .74251 L .51134 .73371 L p .707 .577 .707 r
F P
0 g
s
.51134 .73371 m .51256 .77056 L .50069 .77936 L p .707 .577 .707 r
F P
0 g
s
.51645 .70496 m .51823 .64919 L .5406 .64405 L p .707 .577 .707 r
F P
0 g
s
.504 .82845 m .50191 .81037 L .51242 .79947 L p .707 .577 .707 r
F P
0 g
s
.51242 .79947 m .5145 .81755 L .504 .82845 L p .707 .577 .707 r
F P
0 g
s
.5406 .64405 m .53881 .69983 L .51645 .70496 L p .707 .577 .707 r
F P
0 g
s
.51256 .77056 m .51134 .73371 L .5318 .7261 L p .707 .577 .707 r
F P
0 g
s
.5318 .7261 m .53302 .76296 L .51256 .77056 L p .707 .577 .707 r
F P
0 g
s
.5145 .81755 m .51242 .79947 L .53168 .7892 L p .707 .577 .707 r
F P
0 g
s
.53168 .7892 m .53376 .80728 L .5145 .81755 L p .707 .577 .707 r
F P
0 g
s
.53302 .76296 m .5318 .7261 L .55885 .72044 L p .707 .577 .707 r
F P
0 g
s
.55885 .72044 m .56007 .7573 L .53302 .76296 L p .707 .577 .707 r
F P
0 g
s
.53376 .80728 m .53168 .7892 L .55781 .78059 L p .707 .577 .707 r
F P
0 g
s
.55781 .78059 m .55989 .79867 L .53376 .80728 L p .707 .577 .707 r
F P
0 g
s
.49464 .32001 m .49464 .8219 L .53944 .82045 L p .707 .577 .707 r
F P
0 g
s
.53881 .69983 m .5406 .64405 L .56892 .64114 L p .707 .577 .707 r
F P
0 g
s
.56892 .64114 m .56713 .69692 L .53881 .69983 L p .707 .577 .707 r
F P
0 g
s
.53944 .82045 m .53944 .31856 L .49464 .32001 L p .707 .577 .707 r
F P
0 g
s
.56713 .69692 m .56892 .64114 L .60042 .64073 L p .707 .577 .707 r
F P
0 g
s
.60042 .64073 m .59864 .69651 L .56713 .69692 L p .707 .577 .707 r
F P
0 g
s
.56007 .7573 m .55885 .72044 L .58982 .71727 L p .707 .577 .707 r
F P
0 g
s
.58982 .71727 m .59105 .75412 L .56007 .7573 L p .707 .577 .707 r
F P
0 g
s
.55989 .79867 m .55781 .78059 L .58825 .77446 L p .707 .577 .707 r
F P
0 g
s
.58825 .77446 m .59033 .79254 L .55989 .79867 L p .707 .577 .707 r
F P
0 g
s
.53944 .31856 m .53944 .82045 L .58039 .81536 L p .707 .577 .707 r
F P
0 g
s
.58039 .81536 m .58039 .31347 L .53944 .31856 L p .707 .577 .707 r
F P
0 g
s
.45035 .81956 m .45036 .31767 L .41093 .31178 L p .707 .577 .707 r
F P
0 g
s
.45036 .31767 m .45035 .81956 L .49464 .8219 L p .707 .577 .707 r
F P
0 g
s
.70178 .8017 m .70386 .81978 L .70459 .80929 L p .707 .577 .707 r
F P
0 g
s
.70459 .80929 m .70251 .79122 L .70178 .8017 L p .707 .577 .707 r
F P
0 g
s
.63203 .64287 m .63024 .69865 L .59864 .69651 L p .707 .577 .707 r
F P
0 g
s
.59864 .69651 m .60042 .64073 L .63203 .64287 L p .707 .577 .707 r
F P
0 g
s
.6217 .7169 m .62292 .75376 L .59105 .75412 L p .707 .577 .707 r
F P
0 g
s
.59105 .75412 m .58982 .71727 L .6217 .7169 L p .707 .577 .707 r
F P
0 g
s
.62002 .77143 m .6221 .78951 L .59033 .79254 L p .707 .577 .707 r
F P
0 g
s
.59033 .79254 m .58825 .77446 L .62002 .77143 L p .707 .577 .707 r
F P
0 g
s
.58039 .31347 m .58039 .81536 L .61346 .80712 L p .707 .577 .707 r
F P
0 g
s
.61346 .80712 m .61346 .30523 L .58039 .31347 L p .707 .577 .707 r
F P
0 g
s
.70075 .7402 m .70197 .77706 L .69414 .76848 L p .707 .577 .707 r
F P
0 g
s
.69414 .76848 m .69292 .73162 L .70075 .7402 L p .707 .577 .707 r
F P
0 g
s
.69826 .66136 m .69647 .71713 L .68168 .70949 L p .707 .577 .707 r
F P
0 g
s
.68168 .70949 m .68347 .65371 L .69826 .66136 L p .707 .577 .707 r
F P
0 g
s
.41093 .81366 m .41093 .31178 L .38023 .3029 L p .707 .577 .707 r
F P
0 g
s
.41093 .31178 m .41093 .81366 L .45035 .81956 L p .707 .577 .707 r
F P
0 g
s
.25955 .7147 m .26033 .65959 L .22871 .6578 L p .707 .577 .707 r
F P
0 g
s
.26033 .65959 m .25955 .7147 L .29106 .71354 L p .707 .577 .707 r
F P
0 g
s
.29106 .71354 m .29185 .65843 L .26033 .65959 L p .707 .577 .707 r
F P
0 g
s
.22793 .71291 m .22871 .6578 L .20008 .65322 L p .707 .577 .707 r
F P
0 g
s
.22871 .6578 m .22793 .71291 L .25955 .7147 L p .707 .577 .707 r
F P
0 g
s
.29185 .65843 m .29106 .71354 L .31939 .70952 L p .707 .577 .707 r
F P
0 g
s
.31939 .70952 m .32018 .65441 L .29185 .65843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70251 .79122 m .70459 .80929 L .69546 .80026 L p .707 .577 .707 r
F P
0 g
s
.69546 .80026 m .69338 .78219 L .70251 .79122 L p .707 .577 .707 r
F P
0 g
s
.1993 .70833 m .20008 .65322 L .17725 .6463 L p .707 .577 .707 r
F P
0 g
s
.20008 .65322 m .1993 .70833 L .22793 .71291 L p .707 .577 .707 r
F P
0 g
s
.32018 .65441 m .31939 .70952 L .34176 .70306 L p .707 .577 .707 r
F P
0 g
s
.34176 .70306 m .34255 .64795 L .32018 .65441 L p .707 .577 .707 r
F P
0 g
s
.66064 .64734 m .65886 .70312 L .63024 .69865 L p .707 .577 .707 r
F P
0 g
s
.63024 .69865 m .63203 .64287 L .66064 .64734 L p .707 .577 .707 r
F P
0 g
s
.65136 .71938 m .65259 .75623 L .62292 .75376 L p .707 .577 .707 r
F P
0 g
s
.62292 .75376 m .6217 .7169 L .65136 .71938 L p .707 .577 .707 r
F P
0 g
s
.65001 .77178 m .6521 .78986 L .6221 .78951 L p .707 .577 .707 r
F P
0 g
s
.6221 .78951 m .62002 .77143 L .65001 .77178 L p .707 .577 .707 r
F P
0 g
s
.61346 .30523 m .61346 .80712 L .63543 .79654 L p .707 .577 .707 r
F P
0 g
s
.63543 .79654 m .63543 .29465 L .61346 .30523 L p .707 .577 .707 r
F P
0 g
s
.69292 .73162 m .69414 .76848 L .67713 .76131 L p .707 .577 .707 r
F P
0 g
s
.67713 .76131 m .6759 .72445 L .69292 .73162 L p .707 .577 .707 r
F P
0 g
s
.68347 .65371 m .68168 .70949 L .65886 .70312 L p .707 .577 .707 r
F P
0 g
s
.65886 .70312 m .66064 .64734 L .68347 .65371 L p .707 .577 .707 r
F P
0 g
s
.268 .76945 m .26746 .73214 L .23556 .73206 L p .707 .577 .707 r
F P
0 g
s
.26746 .73214 m .268 .76945 L .29899 .76713 L p .707 .577 .707 r
F P
0 g
s
.29899 .76713 m .29845 .72981 L .26746 .73214 L p .707 .577 .707 r
F P
0 g
s
.23611 .76938 m .23556 .73206 L .20589 .72959 L p .707 .577 .707 r
F P
0 g
s
.23556 .73206 m .23611 .76938 L .268 .76945 L p .707 .577 .707 r
F P
0 g
s
.38023 .80479 m .38023 .3029 L .36125 .29191 L p .707 .577 .707 r
F P
0 g
s
.38023 .3029 m .38023 .80479 L .41093 .81366 L p .707 .577 .707 r
F P
0 g
s
.29845 .72981 m .29899 .76713 L .32605 .76263 L p .707 .577 .707 r
F P
0 g
s
.32605 .76263 m .3255 .72531 L .29845 .72981 L p .707 .577 .707 r
F P
0 g
s
.20589 .72959 m .20644 .76691 L .23611 .76938 L p .707 .577 .707 r
F P
0 g
s
.17725 .6463 m .17647 .70141 L .1993 .70833 L p .707 .577 .707 r
F P
0 g
s
.27411 .80546 m .27316 .78658 L .24124 .78799 L p .707 .577 .707 r
F P
0 g
s
.27316 .78658 m .27411 .80546 L .30468 .80231 L p .707 .577 .707 r
F P
0 g
s
.30468 .80231 m .30374 .78342 L .27316 .78658 L p .707 .577 .707 r
F P
0 g
s
.20644 .76691 m .20589 .72959 L .18134 .72498 L p .707 .577 .707 r
F P
0 g
s
.24218 .80688 m .24124 .78799 L .2111 .78753 L p .707 .577 .707 r
F P
0 g
s
.24124 .78799 m .24218 .80688 L .27411 .80546 L p .707 .577 .707 r
F P
0 g
s
.17647 .70141 m .17725 .6463 L .16245 .63773 L p .707 .577 .707 r
F P
0 g
s
.2111 .78753 m .21204 .80641 L .24218 .80688 L p .707 .577 .707 r
F P
0 g
s
.69338 .78219 m .69546 .80026 L .67737 .79357 L p .707 .577 .707 r
F P
0 g
s
.67737 .79357 m .67529 .77549 L .69338 .78219 L p .707 .577 .707 r
F P
0 g
s
.34255 .64795 m .34176 .70306 L .35598 .69477 L p .707 .577 .707 r
F P
0 g
s
.35598 .69477 m .35677 .63966 L .34255 .64795 L p .707 .577 .707 r
F P
0 g
s
.30374 .78342 m .30468 .80231 L .33092 .79773 L p .707 .577 .707 r
F P
0 g
s
.33092 .79773 m .32997 .77884 L .30374 .78342 L p .707 .577 .707 r
F P
0 g
s
.18134 .72498 m .18189 .7623 L .20644 .76691 L p .707 .577 .707 r
F P
0 g
s
.3255 .72531 m .32605 .76263 L .34651 .75641 L p .707 .577 .707 r
F P
0 g
s
.34651 .75641 m .34596 .71909 L .3255 .72531 L p .707 .577 .707 r
F P
0 g
s
.21204 .80641 m .2111 .78753 L .18569 .78523 L p .707 .577 .707 r
F P
0 g
s
.6759 .72445 m .67713 .76131 L .65259 .75623 L p .707 .577 .707 r
F P
0 g
s
.65259 .75623 m .65136 .71938 L .6759 .72445 L p .707 .577 .707 r
F P
0 g
s
.18569 .78523 m .18663 .80412 L .21204 .80641 L p .707 .577 .707 r
F P
0 g
s
.16245 .63773 m .16166 .69284 L .17647 .70141 L p .707 .577 .707 r
F P
0 g
s
.18189 .7623 m .18134 .72498 L .16431 .71866 L p .707 .577 .707 r
F P
0 g
s
.63543 .29465 m .63543 .79654 L .64414 .78466 L p .707 .577 .707 r
F P
0 g
s
.64414 .78466 m .64414 .28277 L .63543 .29465 L p .707 .577 .707 r
F P
0 g
s
.32997 .77884 m .33092 .79773 L .35025 .79216 L p .707 .577 .707 r
F P
0 g
s
.35025 .79216 m .3493 .77327 L .32997 .77884 L p .707 .577 .707 r
F P
0 g
s
.16431 .71866 m .16486 .75598 L .18189 .7623 L p .707 .577 .707 r
F P
0 g
s
.16166 .69284 m .16245 .63773 L .15712 .62833 L p .707 .577 .707 r
F P
0 g
s
.67529 .77549 m .67737 .79357 L .6521 .78986 L p .707 .577 .707 r
F P
0 g
s
.6521 .78986 m .65001 .77178 L .67529 .77549 L p .707 .577 .707 r
F P
0 g
s
.18663 .80412 m .18569 .78523 L .16749 .78133 L p .707 .577 .707 r
F P
0 g
s
.35677 .63966 m .35598 .69477 L .36066 .68548 L p .707 .577 .707 r
F P
0 g
s
.36066 .68548 m .36144 .63037 L .35677 .63966 L p .707 .577 .707 r
F P
0 g
s
.36144 .63037 m .36066 .68548 L .35533 .67609 L p .707 .577 .707 r
F P
0 g
s
.35533 .67609 m .35612 .62098 L .36144 .63037 L p .707 .577 .707 r
F P
0 g
s
.35983 .76727 m .36078 .78616 L .36148 .78031 L p .707 .577 .707 r
F P
0 g
s
.36148 .78031 m .36054 .76142 L .35983 .76727 L p .707 .577 .707 r
F P
0 g
s
.36078 .78616 m .35983 .76727 L .3493 .77327 L p .707 .577 .707 r
F P
0 g
s
.36054 .76142 m .36148 .78031 L .35228 .77518 L p .707 .577 .707 r
F P
0 g
s
.36125 .7938 m .36125 .29191 L .35585 .27989 L p .707 .577 .707 r
F P
0 g
s
.36125 .29191 m .36125 .7938 L .38023 .80479 L p .707 .577 .707 r
F P
0 g
s
.16749 .78133 m .16844 .80022 L .18663 .80412 L p .707 .577 .707 r
F P
0 g
s
.34596 .71909 m .34651 .75641 L .35839 .74906 L p .707 .577 .707 r
F P
0 g
s
.35839 .74906 m .35784 .71174 L .34596 .71909 L p .707 .577 .707 r
F P
0 g
s
.16486 .75598 m .16431 .71866 L .15648 .71127 L p .707 .577 .707 r
F P
0 g
s
.15712 .62833 m .15634 .68344 L .16166 .69284 L p .707 .577 .707 r
F P
0 g
s
.3493 .77327 m .35025 .79216 L .36078 .78616 L p .707 .577 .707 r
F P
0 g
s
.15648 .71127 m .15703 .74859 L .16486 .75598 L p .707 .577 .707 r
F P
0 g
s
.16844 .80022 m .16749 .78133 L .15829 .7762 L p .707 .577 .707 r
F P
0 g
s
.15634 .68344 m .15712 .62833 L .1618 .61904 L p .707 .577 .707 r
F P
0 g
s
.15829 .7762 m .15924 .79509 L .16844 .80022 L p .707 .577 .707 r
F P
0 g
s
.35784 .71174 m .35839 .74906 L .36052 .74131 L p .707 .577 .707 r
F P
0 g
s
.36052 .74131 m .35997 .70399 L .35784 .71174 L p .707 .577 .707 r
F P
0 g
s
.64414 .28277 m .64414 .78466 L .63875 .77263 L p .707 .577 .707 r
F P
0 g
s
.63875 .77263 m .63875 .27075 L .64414 .28277 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35612 .62098 m .35533 .67609 L .34053 .66751 L p .707 .577 .707 r
F P
0 g
s
.34053 .66751 m .34132 .6124 L .35612 .62098 L p .707 .577 .707 r
F P
0 g
s
.35997 .70399 m .36052 .74131 L .35269 .73391 L p .707 .577 .707 r
F P
0 g
s
.35269 .73391 m .35214 .69659 L .35997 .70399 L p .707 .577 .707 r
F P
0 g
s
.35228 .77518 m .35134 .75629 L .36054 .76142 L p .707 .577 .707 r
F P
0 g
s
.35585 .27989 m .35585 .78178 L .36125 .7938 L p .707 .577 .707 r
F P
0 g
s
.35585 .78178 m .35585 .27989 L .36457 .26801 L p .707 .577 .707 r
F P
0 g
s
.15703 .74859 m .15648 .71127 L .15861 .70352 L p .707 .577 .707 r
F P
0 g
s
.1618 .61904 m .16102 .67415 L .15634 .68344 L p .707 .577 .707 r
F P
0 g
s
.15861 .70352 m .15916 .74084 L .15703 .74859 L p .707 .577 .707 r
F P
0 g
s
.15924 .79509 m .15829 .7762 L .159 .77035 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16102 .67415 m .1618 .61904 L .17602 .61075 L p .707 .577 .707 r
F P
0 g
s
.159 .77035 m .15994 .78924 L .15924 .79509 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17602 .61075 m .17523 .66586 L .16102 .67415 L p .707 .577 .707 r
F P
0 g
s
.63875 .27075 m .63875 .77263 L .61977 .76165 L p .707 .577 .707 r
F P
0 g
s
.61977 .76165 m .61977 .25976 L .63875 .27075 L p .707 .577 .707 r
F P
0 g
s
.15916 .74084 m .15861 .70352 L .17049 .69617 L p .707 .577 .707 r
F P
0 g
s
.17049 .69617 m .17103 .73349 L .15916 .74084 L p .707 .577 .707 r
F P
0 g
s
.36457 .7699 m .36457 .26801 L .38653 .25743 L p .707 .577 .707 r
F P
0 g
s
.36457 .26801 m .36457 .7699 L .35585 .78178 L p .707 .577 .707 r
F P
0 g
s
.17523 .66586 m .17602 .61075 L .19839 .60429 L p .707 .577 .707 r
F P
0 g
s
.15994 .78924 m .159 .77035 L .16953 .76435 L p .707 .577 .707 r
F P
0 g
s
.34132 .6124 m .34053 .66751 L .3177 .6606 L p .707 .577 .707 r
F P
0 g
s
.3177 .6606 m .31848 .60549 L .34132 .6124 L p .707 .577 .707 r
F P
0 g
s
.16953 .76435 m .17047 .78324 L .15994 .78924 L p .707 .577 .707 r
F P
0 g
s
.35214 .69659 m .35269 .73391 L .33566 .7276 L p .707 .577 .707 r
F P
0 g
s
.33566 .7276 m .33511 .69028 L .35214 .69659 L p .707 .577 .707 r
F P
0 g
s
.19839 .60429 m .1976 .6594 L .17523 .66586 L p .707 .577 .707 r
F P
0 g
s
.17103 .73349 m .17049 .69617 L .19095 .68994 L p .707 .577 .707 r
F P
0 g
s
.1976 .6594 m .19839 .60429 L .22672 .60028 L p .707 .577 .707 r
F P
0 g
s
.31848 .60549 m .3177 .6606 L .28907 .65602 L p .707 .577 .707 r
F P
0 g
s
.28907 .65602 m .28986 .60091 L .31848 .60549 L p .707 .577 .707 r
F P
0 g
s
.35134 .75629 m .35228 .77518 L .33409 .77128 L p .707 .577 .707 r
F P
0 g
s
.33409 .77128 m .33314 .75239 L .35134 .75629 L p .707 .577 .707 r
F P
0 g
s
.19095 .68994 m .1915 .72726 L .17103 .73349 L p .707 .577 .707 r
F P
0 g
s
.61977 .25976 m .61977 .76165 L .58906 .75277 L p .707 .577 .707 r
F P
0 g
s
.58906 .75277 m .58906 .25088 L .61977 .25976 L p .707 .577 .707 r
F P
0 g
s
.17047 .78324 m .16953 .76435 L .18886 .75878 L p .707 .577 .707 r
F P
0 g
s
.33511 .69028 m .33566 .7276 L .31111 .72298 L p .707 .577 .707 r
F P
0 g
s
.31111 .72298 m .31056 .68566 L .33511 .69028 L p .707 .577 .707 r
F P
0 g
s
.18886 .75878 m .1898 .77767 L .17047 .78324 L p .707 .577 .707 r
F P
0 g
s
.22593 .65539 m .22672 .60028 L .25824 .59911 L p .707 .577 .707 r
F P
0 g
s
.22672 .60028 m .22593 .65539 L .1976 .6594 L p .707 .577 .707 r
F P
0 g
s
.28986 .60091 m .28907 .65602 L .25745 .65422 L p .707 .577 .707 r
F P
0 g
s
.25745 .65422 m .25824 .59911 L .28986 .60091 L p .707 .577 .707 r
F P
0 g
s
.38653 .25743 m .38653 .75932 L .36457 .7699 L p .707 .577 .707 r
F P
0 g
s
.38653 .75932 m .38653 .25743 L .41961 .24919 L p .707 .577 .707 r
F P
0 g
s
.74255 .6555 m .74176 .59951 L .71014 .5988 L p .707 .577 .707 r
F P
0 g
s
.74176 .59951 m .74255 .6555 L .77407 .65381 L p .707 .577 .707 r
F P
0 g
s
.77407 .65381 m .77328 .59781 L .74176 .59951 L p .707 .577 .707 r
F P
0 g
s
.25824 .59911 m .25745 .65422 L .22593 .65539 L p .707 .577 .707 r
F P
0 g
s
.1915 .72726 m .19095 .68994 L .21801 .68545 L p .707 .577 .707 r
F P
0 g
s
.71093 .6548 m .71014 .5988 L .68151 .59576 L p .707 .577 .707 r
F P
0 g
s
.71014 .5988 m .71093 .6548 L .74255 .6555 L p .707 .577 .707 r
F P
0 g
s
.77328 .59781 m .77407 .65381 L .8024 .64987 L p .707 .577 .707 r
F P
0 g
s
.8024 .64987 m .80161 .59387 L .77328 .59781 L p .707 .577 .707 r
F P
0 g
s
.33314 .75239 m .33409 .77128 L .30867 .76898 L p .707 .577 .707 r
F P
0 g
s
.30867 .76898 m .30773 .7501 L .33314 .75239 L p .707 .577 .707 r
F P
0 g
s
.21801 .68545 m .21855 .72277 L .1915 .72726 L p .707 .577 .707 r
F P
0 g
s
.31056 .68566 m .31111 .72298 L .28144 .72051 L p .707 .577 .707 r
F P
0 g
s
.28144 .72051 m .28089 .6832 L .31056 .68566 L p .707 .577 .707 r
F P
0 g
s
.1898 .77767 m .18886 .75878 L .21509 .7542 L p .707 .577 .707 r
F P
0 g
s
.68151 .59576 m .6823 .65175 L .71093 .6548 L p .707 .577 .707 r
F P
0 g
s
.6823 .65175 m .68151 .59576 L .65868 .59068 L p .707 .577 .707 r
F P
0 g
s
.21509 .7542 m .21604 .77309 L .1898 .77767 L p .707 .577 .707 r
F P
0 g
s
.21855 .72277 m .21801 .68545 L .24899 .68312 L p .707 .577 .707 r
F P
0 g
s
.80161 .59387 m .8024 .64987 L .82476 .64408 L p .707 .577 .707 r
F P
0 g
s
.82476 .64408 m .82398 .58808 L .80161 .59387 L p .707 .577 .707 r
F P
0 g
s
.58906 .25088 m .58906 .75277 L .54964 .74688 L p .707 .577 .707 r
F P
0 g
s
.54964 .74688 m .54964 .24499 L .58906 .25088 L p .707 .577 .707 r
F P
0 g
s
.75045 .72127 m .751 .68451 L .71911 .68345 L p .707 .577 .707 r
F P
0 g
s
.751 .68451 m .75045 .72127 L .78144 .71938 L p .707 .577 .707 r
F P
0 g
s
.78144 .71938 m .78199 .68263 L .751 .68451 L p .707 .577 .707 r
F P
0 g
s
.71856 .72021 m .71911 .68345 L .68944 .67955 L p .707 .577 .707 r
F P
0 g
s
.71911 .68345 m .71856 .72021 L .75045 .72127 L p .707 .577 .707 r
F P
0 g
s
.28089 .6832 m .28144 .72051 L .24954 .72044 L p .707 .577 .707 r
F P
0 g
s
.24954 .72044 m .24899 .68312 L .28089 .6832 L p .707 .577 .707 r
F P
0 g
s
.24899 .68312 m .24954 .72044 L .21855 .72277 L p .707 .577 .707 r
F P
0 g
s
.41961 .75108 m .41961 .24919 L .46056 .2441 L p .707 .577 .707 r
F P
0 g
s
.41961 .24919 m .41961 .75108 L .38653 .75932 L p .707 .577 .707 r
F P
0 g
s
.78199 .68263 m .78144 .71938 L .8085 .71474 L p .707 .577 .707 r
F P
0 g
s
.8085 .71474 m .80904 .67798 L .78199 .68263 L p .707 .577 .707 r
F P
0 g
s
.30773 .7501 m .30867 .76898 L .27853 .76852 L p .707 .577 .707 r
F P
0 g
s
.27853 .76852 m .27759 .74963 L .30773 .7501 L p .707 .577 .707 r
F P
0 g
s
.65868 .59068 m .65947 .64667 L .6823 .65175 L p .707 .577 .707 r
F P
0 g
s
.21604 .77309 m .21509 .7542 L .24567 .75105 L p .707 .577 .707 r
F P
0 g
s
.68889 .71631 m .68944 .67955 L .66488 .67319 L p .707 .577 .707 r
F P
0 g
s
.68944 .67955 m .68889 .71631 L .71856 .72021 L p .707 .577 .707 r
F P
0 g
s
.24567 .75105 m .24661 .76994 L .21604 .77309 L p .707 .577 .707 r
F P
0 g
s
.65947 .64667 m .65868 .59068 L .64388 .58405 L p .707 .577 .707 r
F P
0 g
s
.27759 .74963 m .27853 .76852 L .24661 .76994 L p .707 .577 .707 r
F P
0 g
s
.24661 .76994 m .24567 .75105 L .27759 .74963 L p .707 .577 .707 r
F P
0 g
s
.82398 .58808 m .82476 .64408 L .83898 .63701 L p .707 .577 .707 r
F P
0 g
s
.83898 .63701 m .8382 .58101 L .82398 .58808 L p .707 .577 .707 r
F P
0 g
s
.54964 .24499 m .54964 .74688 L .50536 .74454 L p .707 .577 .707 r
F P
0 g
s
.50536 .74454 m .50536 .24265 L .54964 .24499 L p .707 .577 .707 r
F P
0 g
s
.75339 .76835 m .75433 .75037 L .72241 .74866 L p .707 .577 .707 r
F P
0 g
s
.75433 .75037 m .75339 .76835 L .78396 .76651 L p .707 .577 .707 r
F P
0 g
s
.78396 .76651 m .7849 .74853 L .75433 .75037 L p .707 .577 .707 r
F P
0 g
s
.72147 .76663 m .72241 .74866 L .69227 .74356 L p .707 .577 .707 r
F P
0 g
s
.72241 .74866 m .72147 .76663 L .75339 .76835 L p .707 .577 .707 r
F P
0 g
s
.80904 .67798 m .8085 .71474 L .82896 .70779 L p .707 .577 .707 r
F P
0 g
s
.82896 .70779 m .82951 .67103 L .80904 .67798 L p .707 .577 .707 r
F P
0 g
s
.46056 .74599 m .46056 .2441 L .50536 .24265 L p .707 .577 .707 r
F P
0 g
s
.46056 .2441 m .46056 .74599 L .41961 .75108 L p .707 .577 .707 r
F P
0 g
s
.66488 .67319 m .66434 .70995 L .68889 .71631 L p .707 .577 .707 r
F P
0 g
s
.69227 .74356 m .69132 .76153 L .72147 .76663 L p .707 .577 .707 r
F P
0 g
s
.50536 .24265 m .50536 .74454 L .46056 .74599 L p .707 .577 .707 r
F P
0 g
s
.7849 .74853 m .78396 .76651 L .8102 .76129 L p .707 .577 .707 r
F P
0 g
s
.8102 .76129 m .81114 .74332 L .7849 .74853 L p .707 .577 .707 r
F P
0 g
s
.69132 .76153 m .69227 .74356 L .66685 .73557 L p .707 .577 .707 r
F P
0 g
s
.64388 .58405 m .64466 .64005 L .65947 .64667 L p .707 .577 .707 r
F P
0 g
s
.66434 .70995 m .66488 .67319 L .64786 .66499 L p .707 .577 .707 r
F P
0 g
s
.66685 .73557 m .66591 .75354 L .69132 .76153 L p .707 .577 .707 r
F P
0 g
s
.64786 .66499 m .64731 .70175 L .66434 .70995 L p .707 .577 .707 r
F P
0 g
s
.64466 .64005 m .64388 .58405 L .63856 .57654 L p .707 .577 .707 r
F P
0 g
s
.8382 .58101 m .83898 .63701 L .84366 .62933 L p .707 .577 .707 r
F P
0 g
s
.84366 .62933 m .84287 .57334 L .8382 .58101 L p .707 .577 .707 r
F P
0 g
s
.82951 .67103 m .82896 .70779 L .84084 .69922 L p .707 .577 .707 r
F P
0 g
s
.84084 .69922 m .84139 .66246 L .82951 .67103 L p .707 .577 .707 r
F P
0 g
s
.81114 .74332 m .8102 .76129 L .82953 .75321 L p .707 .577 .707 r
F P
0 g
s
.82953 .75321 m .83047 .73524 L .81114 .74332 L p .707 .577 .707 r
F P
0 g
s
.66591 .75354 m .66685 .73557 L .64866 .72547 L p .707 .577 .707 r
F P
0 g
s
.64866 .72547 m .64772 .74345 L .66591 .75354 L p .707 .577 .707 r
F P
0 g
s
.64731 .70175 m .64786 .66499 L .64003 .65576 L p .707 .577 .707 r
F P
0 g
s
.63856 .57654 m .63934 .63254 L .64466 .64005 L p .707 .577 .707 r
F P
0 g
s
.64003 .65576 m .63948 .69252 L .64731 .70175 L p .707 .577 .707 r
F P
0 g
s
.83047 .73524 m .82953 .75321 L .84006 .74306 L p .707 .577 .707 r
F P
0 g
s
.84006 .74306 m .841 .72508 L .83047 .73524 L p .707 .577 .707 r
F P
0 g
s
.64772 .74345 m .64866 .72547 L .63946 .71425 L p .707 .577 .707 r
F P
0 g
s
.84139 .66246 m .84084 .69922 L .84297 .68986 L p .707 .577 .707 r
F P
0 g
s
.84297 .68986 m .84352 .6531 L .84139 .66246 L p .707 .577 .707 r
F P
0 g
s
.63934 .63254 m .63856 .57654 L .64323 .56887 L p .707 .577 .707 r
F P
0 g
s
.84287 .57334 m .84366 .62933 L .83834 .62182 L p .707 .577 .707 r
F P
0 g
s
.83834 .62182 m .83755 .56582 L .84287 .57334 L p .707 .577 .707 r
F P
0 g
s
.63946 .71425 m .63852 .73223 L .64772 .74345 L p .707 .577 .707 r
F P
0 g
s
.63948 .69252 m .64003 .65576 L .64215 .6464 L p .707 .577 .707 r
F P
0 g
s
.64323 .56887 m .64402 .62487 L .63934 .63254 L p .707 .577 .707 r
F P
0 g
s
.64215 .6464 m .64161 .68316 L .63948 .69252 L p .707 .577 .707 r
F P
0 g
s
.841 .72508 m .84006 .74306 L .84076 .73182 L p .705 .576 .707 r
F P
0 g
s
.84076 .73182 m .8417 .71385 L .841 .72508 L p .705 .576 .707 r
F P
0 g
s
.63852 .73223 m .63946 .71425 L .64016 .70302 L p .705 .576 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84352 .6531 m .84297 .68986 L .83514 .68063 L p .707 .577 .707 r
F P
0 g
s
.83514 .68063 m .83569 .64387 L .84352 .6531 L p .707 .577 .707 r
F P
0 g
s
.64402 .62487 m .64323 .56887 L .65745 .56179 L p .707 .577 .707 r
F P
0 g
s
.83755 .56582 m .83834 .62182 L .82353 .6152 L p .707 .577 .707 r
F P
0 g
s
.82353 .6152 m .82275 .5592 L .83755 .56582 L p .707 .577 .707 r
F P
0 g
s
.64016 .70302 m .63922 .721 L .63852 .73223 L p .705 .576 .707 r
F P
0 g
s
.40136 .62171 m .39957 .56639 L .36797 .56601 L p .707 .577 .707 r
F P
0 g
s
.39957 .56639 m .40136 .62171 L .43287 .61928 L p .707 .577 .707 r
F P
0 g
s
.43287 .61928 m .43108 .56395 L .39957 .56639 L p .707 .577 .707 r
F P
0 g
s
.36975 .62133 m .36797 .56601 L .33935 .56284 L p .707 .577 .707 r
F P
0 g
s
.36797 .56601 m .36975 .62133 L .40136 .62171 L p .707 .577 .707 r
F P
0 g
s
.43108 .56395 m .43287 .61928 L .46119 .61425 L p .707 .577 .707 r
F P
0 g
s
.46119 .61425 m .4594 .55893 L .43108 .56395 L p .707 .577 .707 r
F P
0 g
s
.64161 .68316 m .64215 .6464 L .65403 .63783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65745 .56179 m .65824 .61779 L .64402 .62487 L p .707 .577 .707 r
F P
0 g
s
.65403 .63783 m .65349 .67459 L .64161 .68316 L p .707 .577 .707 r
F P
0 g
s
.8417 .71385 m .84076 .73182 L .83156 .72061 L p .707 .577 .707 r
F P
0 g
s
.83156 .72061 m .83251 .70263 L .8417 .71385 L p .707 .577 .707 r
F P
0 g
s
.63922 .721 m .64016 .70302 L .65069 .69287 L p .707 .577 .707 r
F P
0 g
s
.34114 .61816 m .33935 .56284 L .31653 .5572 L p .707 .577 .707 r
F P
0 g
s
.33935 .56284 m .34114 .61816 L .36975 .62133 L p .707 .577 .707 r
F P
0 g
s
.4594 .55893 m .46119 .61425 L .48355 .60714 L p .707 .577 .707 r
F P
0 g
s
.48355 .60714 m .48176 .55182 L .4594 .55893 L p .707 .577 .707 r
F P
0 g
s
.65824 .61779 m .65745 .56179 L .67982 .556 L p .707 .577 .707 r
F P
0 g
s
.83569 .64387 m .83514 .68063 L .81811 .67243 L p .707 .577 .707 r
F P
0 g
s
.81811 .67243 m .81866 .63567 L .83569 .64387 L p .707 .577 .707 r
F P
0 g
s
.82275 .5592 m .82353 .6152 L .8007 .61012 L p .707 .577 .707 r
F P
0 g
s
.8007 .61012 m .79991 .55412 L .82275 .5592 L p .707 .577 .707 r
F P
0 g
s
.40895 .6793 m .41017 .6421 L .37829 .64058 L p .707 .577 .707 r
F P
0 g
s
.41017 .6421 m .40895 .6793 L .43993 .67828 L p .707 .577 .707 r
F P
0 g
s
.43993 .67828 m .44115 .64107 L .41017 .6421 L p .707 .577 .707 r
F P
0 g
s
.37707 .67778 m .37829 .64058 L .34863 .63667 L p .707 .577 .707 r
F P
0 g
s
.37829 .64058 m .37707 .67778 L .40895 .6793 L p .707 .577 .707 r
F P
0 g
s
.65069 .69287 m .64975 .71084 L .63922 .721 L p .707 .577 .707 r
F P
0 g
s
.44115 .64107 m .43993 .67828 L .46697 .67481 L p .707 .577 .707 r
F P
0 g
s
.46697 .67481 m .46819 .63761 L .44115 .64107 L p .707 .577 .707 r
F P
0 g
s
.65349 .67459 m .65403 .63783 L .6745 .63088 L p .707 .577 .707 r
F P
0 g
s
.34863 .63667 m .34741 .67387 L .37707 .67778 L p .707 .577 .707 r
F P
0 g
s
.31653 .5572 m .31832 .61252 L .34114 .61816 L p .707 .577 .707 r
F P
0 g
s
.67982 .556 m .68061 .612 L .65824 .61779 L p .707 .577 .707 r
F P
0 g
s
.34741 .67387 m .34863 .63667 L .32409 .63075 L p .707 .577 .707 r
F P
0 g
s
.37789 .71474 m .37998 .69605 L .34998 .69064 L p .707 .577 .707 r
F P
0 g
s
.37998 .69605 m .37789 .71474 L .40966 .71828 L p .707 .577 .707 r
F P
0 g
s
.40966 .71828 m .41175 .69959 L .37998 .69605 L p .707 .577 .707 r
F P
0 g
s
.41175 .69959 m .40966 .71828 L .4401 .71959 L p .707 .577 .707 r
F P
0 g
s
.4401 .71959 m .44219 .7009 L .41175 .69959 L p .707 .577 .707 r
F P
0 g
s
.31832 .61252 m .31653 .5572 L .30174 .54964 L p .707 .577 .707 r
F P
0 g
s
.48176 .55182 m .48355 .60714 L .49777 .59863 L p .707 .577 .707 r
F P
0 g
s
.49777 .59863 m .49598 .54331 L .48176 .55182 L p .707 .577 .707 r
F P
0 g
s
.34998 .69064 m .3479 .70933 L .37789 .71474 L p .707 .577 .707 r
F P
0 g
s
.68061 .612 m .67982 .556 L .70815 .55207 L p .707 .577 .707 r
F P
0 g
s
.79991 .55412 m .8007 .61012 L .77207 .60708 L p .707 .577 .707 r
F P
0 g
s
.77207 .60708 m .77129 .55108 L .79991 .55412 L p .707 .577 .707 r
F P
0 g
s
.6745 .63088 m .67395 .66764 L .65349 .67459 L p .707 .577 .707 r
F P
0 g
s
.32409 .63075 m .32287 .66795 L .34741 .67387 L p .707 .577 .707 r
F P
0 g
s
.83251 .70263 m .83156 .72061 L .81337 .71051 L p .707 .577 .707 r
F P
0 g
s
.81337 .71051 m .81431 .69254 L .83251 .70263 L p .707 .577 .707 r
F P
0 g
s
.64975 .71084 m .65069 .69287 L .67002 .68478 L p .707 .577 .707 r
F P
0 g
s
.46819 .63761 m .46697 .67481 L .48743 .66925 L p .707 .577 .707 r
F P
0 g
s
.48743 .66925 m .48866 .63205 L .46819 .63761 L p .707 .577 .707 r
F P
0 g
s
.3479 .70933 m .34998 .69064 L .32471 .68388 L p .707 .577 .707 r
F P
0 g
s
.44219 .7009 m .4401 .71959 L .46623 .71855 L p .707 .577 .707 r
F P
0 g
s
.46623 .71855 m .46832 .69986 L .44219 .7009 L p .707 .577 .707 r
F P
0 g
s
.81866 .63567 m .81811 .67243 L .79356 .66607 L p .707 .577 .707 r
F P
0 g
s
.79356 .66607 m .79411 .62931 L .81866 .63567 L p .707 .577 .707 r
F P
0 g
s
.32471 .68388 m .32262 .70257 L .3479 .70933 L p .707 .577 .707 r
F P
0 g
s
.67002 .68478 m .66908 .70276 L .64975 .71084 L p .707 .577 .707 r
F P
0 g
s
.32287 .66795 m .32409 .63075 L .30708 .6234 L p .707 .577 .707 r
F P
0 g
s
.30174 .54964 m .30352 .60496 L .31832 .61252 L p .707 .577 .707 r
F P
0 g
s
.67395 .66764 m .6745 .63088 L .70155 .62623 L p .707 .577 .707 r
F P
0 g
s
.70815 .55207 m .70894 .60807 L .68061 .612 L p .707 .577 .707 r
F P
0 g
s
.70894 .60807 m .70815 .55207 L .73967 .55037 L p .707 .577 .707 r
F P
0 g
s
.77129 .55108 m .77207 .60708 L .74045 .60637 L p .707 .577 .707 r
F P
0 g
s
.74045 .60637 m .73967 .55037 L .77129 .55108 L p .707 .577 .707 r
F P
0 g
s
.73967 .55037 m .74045 .60637 L .70894 .60807 L p .707 .577 .707 r
F P
0 g
s
.30708 .6234 m .30586 .66061 L .32287 .66795 L p .707 .577 .707 r
F P
0 g
s
.32262 .70257 m .32471 .68388 L .30662 .67643 L p .707 .577 .707 r
F P
0 g
s
.46832 .69986 m .46623 .71855 L .48549 .71526 L p .707 .577 .707 r
F P
0 g
s
.48549 .71526 m .48758 .69657 L .46832 .69986 L p .707 .577 .707 r
F P
0 g
s
.30352 .60496 m .30174 .54964 L .29642 .54089 L p .707 .577 .707 r
F P
0 g
s
.79411 .62931 m .79356 .66607 L .76389 .66217 L p .707 .577 .707 r
F P
0 g
s
.76389 .66217 m .76444 .62541 L .79411 .62931 L p .707 .577 .707 r
F P
0 g
s
.49598 .54331 m .49777 .59863 L .50245 .58956 L p .707 .577 .707 r
F P
0 g
s
.50245 .58956 m .50066 .53424 L .49598 .54331 L p .707 .577 .707 r
F P
0 g
s
.70155 .62623 m .70101 .66299 L .67395 .66764 L p .707 .577 .707 r
F P
0 g
s
.30662 .67643 m .30454 .69512 L .32262 .70257 L p .707 .577 .707 r
F P
0 g
s
.81431 .69254 m .81337 .71051 L .78796 .70252 L p .707 .577 .707 r
F P
0 g
s
.78796 .70252 m .7889 .68455 L .81431 .69254 L p .707 .577 .707 r
F P
0 g
s
.66908 .70276 m .67002 .68478 L .69626 .67957 L p .707 .577 .707 r
F P
0 g
s
.48866 .63205 m .48743 .66925 L .49931 .66213 L p .707 .577 .707 r
F P
0 g
s
.49931 .66213 m .50053 .62493 L .48866 .63205 L p .707 .577 .707 r
F P
0 g
s
.70101 .66299 m .70155 .62623 L .73254 .62435 L p .707 .577 .707 r
F P
0 g
s
.69626 .67957 m .69532 .69755 L .66908 .70276 L p .707 .577 .707 r
F P
0 g
s
.76444 .62541 m .76389 .66217 L .73199 .66111 L p .707 .577 .707 r
F P
0 g
s
.73199 .66111 m .73254 .62435 L .76444 .62541 L p .707 .577 .707 r
F P
0 g
s
.73254 .62435 m .73199 .66111 L .70101 .66299 L p .707 .577 .707 r
F P
0 g
s
.30586 .66061 m .30708 .6234 L .29925 .61534 L p .707 .577 .707 r
F P
0 g
s
.29642 .54089 m .29821 .59621 L .30352 .60496 L p .707 .577 .707 r
F P
0 g
s
.7889 .68455 m .78796 .70252 L .75781 .69742 L p .707 .577 .707 r
F P
0 g
s
.75781 .69742 m .75876 .67944 L .7889 .68455 L p .707 .577 .707 r
F P
0 g
s
.69532 .69755 m .69626 .67957 L .72684 .67773 L p .707 .577 .707 r
F P
0 g
s
.29925 .61534 m .29803 .65255 L .30586 .66061 L p .707 .577 .707 r
F P
0 g
s
.30454 .69512 m .30662 .67643 L .29749 .66903 L p .707 .577 .707 r
F P
0 g
s
.48758 .69657 m .48549 .71526 L .496 .71005 L p .707 .577 .707 r
F P
0 g
s
.496 .71005 m .49808 .69135 L .48758 .69657 L p .707 .577 .707 r
F P
0 g
s
.72684 .67773 m .72589 .6957 L .69532 .69755 L p .707 .577 .707 r
F P
0 g
s
.29749 .66903 m .29541 .68772 L .30454 .69512 L p .707 .577 .707 r
F P
0 g
s
.75876 .67944 m .75781 .69742 L .72589 .6957 L p .707 .577 .707 r
F P
0 g
s
.72589 .6957 m .72684 .67773 L .75876 .67944 L p .707 .577 .707 r
F P
0 g
s
.29821 .59621 m .29642 .54089 L .3011 .53182 L p .707 .577 .707 r
F P
0 g
s
.50066 .53424 m .50245 .58956 L .49713 .58082 L p .707 .577 .707 r
F P
0 g
s
.49713 .58082 m .49534 .52549 L .50066 .53424 L p .707 .577 .707 r
F P
0 g
s
.50053 .62493 m .49931 .66213 L .50144 .65415 L p .707 .577 .707 r
F P
0 g
s
.50144 .65415 m .50266 .61695 L .50053 .62493 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29803 .65255 m .29925 .61534 L .30138 .60736 L p .707 .577 .707 r
F P
0 g
s
.3011 .53182 m .30288 .58714 L .29821 .59621 L p .707 .577 .707 r
F P
0 g
s
.30138 .60736 m .30016 .64457 L .29803 .65255 L p .707 .577 .707 r
F P
0 g
s
.29541 .68772 m .29749 .66903 L .29821 .66239 L p .721 .59 .709 r
F P
0 g
s
.49808 .69135 m .496 .71005 L .49673 .70341 L p .721 .59 .709 r
F P
0 g
s
.49673 .70341 m .49881 .68472 L .49808 .69135 L p .721 .59 .709 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29821 .66239 m .29613 .68108 L .29541 .68772 L p .721 .59 .709 r
F P
0 g
s
.30288 .58714 m .3011 .53182 L .31531 .52331 L p .707 .577 .707 r
F P
0 g
s
.49534 .52549 m .49713 .58082 L .48233 .57325 L p .707 .577 .707 r
F P
0 g
s
.48233 .57325 m .48055 .51793 L .49534 .52549 L p .707 .577 .707 r
F P
0 g
s
.50266 .61695 m .50144 .65415 L .49361 .64609 L p .707 .577 .707 r
F P
0 g
s
.49361 .64609 m .49484 .60889 L .50266 .61695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30016 .64457 m .30138 .60736 L .31326 .60024 L p .707 .577 .707 r
F P
0 g
s
.31531 .52331 m .3171 .57863 L .30288 .58714 L p .707 .577 .707 r
F P
0 g
s
.31326 .60024 m .31204 .63745 L .30016 .64457 L p .707 .577 .707 r
F P
0 g
s
.29613 .68108 m .29821 .66239 L .30872 .65717 L p .707 .577 .707 r
F P
0 g
s
.49881 .68472 m .49673 .70341 L .4876 .69601 L p .707 .577 .707 r
F P
0 g
s
.4876 .69601 m .48968 .67732 L .49881 .68472 L p .707 .577 .707 r
F P
0 g
s
.3171 .57863 m .31531 .52331 L .33768 .5162 L p .707 .577 .707 r
F P
0 g
s
.48055 .51793 m .48233 .57325 L .45951 .56761 L p .707 .577 .707 r
F P
0 g
s
.45951 .56761 m .45773 .51229 L .48055 .51793 L p .707 .577 .707 r
F P
0 g
s
.30872 .65717 m .30664 .67587 L .29613 .68108 L p .707 .577 .707 r
F P
0 g
s
.49484 .60889 m .49361 .64609 L .4766 .63874 L p .707 .577 .707 r
F P
0 g
s
.4766 .63874 m .47782 .60154 L .49484 .60889 L p .707 .577 .707 r
F P
0 g
s
.31204 .63745 m .31326 .60024 L .33372 .59468 L p .707 .577 .707 r
F P
0 g
s
.33768 .5162 m .33946 .57152 L .3171 .57863 L p .707 .577 .707 r
F P
0 g
s
.33946 .57152 m .33768 .5162 L .366 .51118 L p .707 .577 .707 r
F P
0 g
s
.45773 .51229 m .45951 .56761 L .4309 .56444 L p .707 .577 .707 r
F P
0 g
s
.4309 .56444 m .42911 .50912 L .45773 .51229 L p .707 .577 .707 r
F P
0 g
s
.33372 .59468 m .3325 .63188 L .31204 .63745 L p .707 .577 .707 r
F P
0 g
s
.30664 .67587 m .30872 .65717 L .32798 .65388 L p .707 .577 .707 r
F P
0 g
s
.48968 .67732 m .4876 .69601 L .46951 .68856 L p .707 .577 .707 r
F P
0 g
s
.46951 .68856 m .47159 .66987 L .48968 .67732 L p .707 .577 .707 r
F P
0 g
s
.32798 .65388 m .3259 .67258 L .30664 .67587 L p .707 .577 .707 r
F P
0 g
s
.47782 .60154 m .4766 .63874 L .45206 .63283 L p .707 .577 .707 r
F P
0 g
s
.45206 .63283 m .45328 .59562 L .47782 .60154 L p .707 .577 .707 r
F P
0 g
s
.36778 .5665 m .366 .51118 L .3975 .50874 L p .707 .577 .707 r
F P
0 g
s
.366 .51118 m .36778 .5665 L .33946 .57152 L p .707 .577 .707 r
F P
0 g
s
.42911 .50912 m .4309 .56444 L .39929 .56406 L p .707 .577 .707 r
F P
0 g
s
.39929 .56406 m .3975 .50874 L .42911 .50912 L p .707 .577 .707 r
F P
0 g
s
.3325 .63188 m .33372 .59468 L .36076 .59122 L p .707 .577 .707 r
F P
0 g
s
.3975 .50874 m .39929 .56406 L .36778 .5665 L p .707 .577 .707 r
F P
0 g
s
.36076 .59122 m .35954 .62842 L .3325 .63188 L p .707 .577 .707 r
F P
0 g
s
.45328 .59562 m .45206 .63283 L .4224 .62892 L p .707 .577 .707 r
F P
0 g
s
.4224 .62892 m .42362 .59171 L .45328 .59562 L p .707 .577 .707 r
F P
0 g
s
.3259 .67258 m .32798 .65388 L .35411 .65284 L p .707 .577 .707 r
F P
0 g
s
.47159 .66987 m .46951 .68856 L .44423 .6818 L p .707 .577 .707 r
F P
0 g
s
.44423 .6818 m .44632 .66311 L .47159 .66987 L p .707 .577 .707 r
F P
0 g
s
.35411 .65284 m .35203 .67154 L .3259 .67258 L p .707 .577 .707 r
F P
0 g
s
.35954 .62842 m .36076 .59122 L .39174 .5902 L p .707 .577 .707 r
F P
0 g
s
.42362 .59171 m .4224 .62892 L .39052 .6274 L p .707 .577 .707 r
F P
0 g
s
.39052 .6274 m .39174 .5902 L .42362 .59171 L p .707 .577 .707 r
F P
0 g
s
.39174 .5902 m .39052 .6274 L .35954 .62842 L p .707 .577 .707 r
F P
0 g
s
.35203 .67154 m .35411 .65284 L .38455 .65416 L p .707 .577 .707 r
F P
0 g
s
.44632 .66311 m .44423 .6818 L .41424 .67639 L p .707 .577 .707 r
F P
0 g
s
.41424 .67639 m .41632 .65769 L .44632 .66311 L p .707 .577 .707 r
F P
0 g
s
.38455 .65416 m .38247 .67285 L .35203 .67154 L p .707 .577 .707 r
F P
0 g
s
.38247 .67285 m .38455 .65416 L .41632 .65769 L p .707 .577 .707 r
F P
0 g
s
.41632 .65769 m .41424 .67639 L .38247 .67285 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`T000=JEP03001JEUYF00IJEP03001JEUYF009J
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GWoo1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001KOol300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00F7oo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00H005YFFUIJEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005Woo4@00?Woo001DOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00003Woo200015YF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00E7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000Ioo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008003Eoo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0035o
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF
00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002ioo`00E7oo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH00UYF4@0015YF00@005YFFUIJEPH000EJEP04001JEUYFFUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00Oomoo`0/Ool005Aoo`03001JEP0000=JEP03001JEUYF009JEPH000=JEP03001JEUYF00=JEPD0
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00
E7oo00<005YF00000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH015YF0`0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol00`00FUH00003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUH00000FUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01000FUH005YF0P001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;Goo001DOol01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000]Ool005Aoo`<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00T000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001D
Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH00`00FUIJEP02FUH80007FUH00`00FUIJ
EP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000eYF00<005YF00001P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH005YF00AJEP07001JEUYF
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00?Goo5`0000=oo`0000000UYF0`000UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000eYF00L005YFFUIJ
EP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000gOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH400000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo
000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YF
FUIJEP8002eoo`00<Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF0P00;Goo000_Ool20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH0000002eoo`00;Woo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002eoo`00;Goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH04@001eYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP080004FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH0009JEP03001JEUYF009JEPH0009JEP03001JEP0000EJEPH000AJEP03001JEUYF009JEPH0
00EJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000030003FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF00<0
05YF00000P0000=JEP0000000P000eYF00<005YF00001EYF1P0015YF00<005YFFUH025YF100000=J
EP00FUH00eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001oogoo02aoo`00;7oo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP80009JEP03
001JEUYF00=JEPH000EJEPH000AJEP03001JEUYF00QJEPL000=JEP04001JEP00000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH00`00Oomoo`0/
Ool002aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<000AJEP03001JEUYF00AJEP04001JEUYFFUHK0003FUH01000FUIJEUYF
0P0000=JEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH>0002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEQh0009JEP03001JEUYF00AJEP03
001JEUYF009JEPT0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF1P000UYF6@001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH015YF00<005YF
FUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`8000=JEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00=JEPD000IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF009JEQT000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;7oo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH015YF0`001eYF00<005YF
00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF000010001EYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF1P000UYF00<007ooOol027oo0`002Goo1P00
1EYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool200001EYF000005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1`0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00@005YFFUIJEP8000Qoo`D000ioo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH03@0000=JEP0000001`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEPD0
00AJEP04001JEUYFFUH20008Ool5000BOol30003FUH00`00FUH0000]Ool002aoo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH400000eYF
001JEP04FUH01P00FUIJEUYF001JEPT00003FUH0000000L000AJEP03001JEUYF00EJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUH000040003FUH20002Ool;000?Ool30003FUH2000015YF001JEP00;Goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH4
00000eYF001JEP030005FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000T00003FUH0000000@0
00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@000=JEP03001JEUYF00=JEPP000AJEP03001JEUYF009JEPT000Aoo`@00003FUH0
05YF00AJEP<00003FUH007oo02aoo`00;7oo0P0015YF00<005YFFUH00eYF00@005YFFUIJEQP000=J
EP04001JEUYFFUH30003FUH01`00FUIJEUYF001JEP0000EJEPH000AJEP03001JEUYF00IJEP@00003
FUH005YF00AJEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30004FUH00`00FUH000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`8000AJEP03001JEUYF00=JEP@00003
FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003
0003FUH00`00FUH00005FUH60004FUH00`00FUIJEP08FUH00`00FUH000020003FUH01P00FUIJEP00
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
008002eoo`00;Goo00<005YFFUH00UYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF1P001EYF1P0015YF00<005YFFUH025YF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02000]Ool002eoo`800003FUH0
00000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00EJEP03001JEUYF009JEPX000EJEP03001JEUYF00QJEP03001JEUYF00AJEP80
009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000AJEP03
001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP<00005FUH0
05YFFUH0000^Ool002moo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000UJEP03001J
EUYF00=JEP@00004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH4
0005FUH01000FUIJEUYF20000UYF00<005YFFUH015YF200015YF00<005YFFUH01EYF00<005YFFUH0
0P000UYF00<007ooOol0;7oo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF3`000UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1P001UYF00<005YFFUH00UYF0P00;goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF
000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P00;goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000030006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00eYF00<0
05YF0000;Woo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUH000030000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH01000FUIJ
EP00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP070004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF1P0015YF00<0
05YFFUH00UYF0`0000=JEP00FUH01eYF00@005YFFUIJEPD0009oo`800005FUH005YFFUH0000]Ool0
02aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF
00AJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF01P000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP04001JEUYFFUH@0004FUH80009
Ool20002FUH00`00Oomoo`0[Ool002aoo`80009JEP03001JEUYF00=JEP03001JEUYF009JEPP000Eo
o`<000Uoo`P000=JEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEP00FUH005YF10000eYF00@005YFFUIJEP8000Qoo`X0019oo`04001JEP00000]Ool0
02aoo`80009JEP03001JEUYF009JEPH000aoo`D000eoo`P000=JEP800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF008000EJEP800003FUH005YF009JEP8000Qoo`D001Qo
o`<002eoo`00;7oo0P000UYF00<005YF00000P000UYF1`002Goo1@001Goo20000eYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00<000EJ
EP<000=JEP03001oogoo00Qoo`<001Uoo`<002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00@0
05YFFUIJEQ<000=JEP03001JEUYF00EJEP03001JEUYF00=JEP@00003FUH005YF00AJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP04001JEUYF0002FUH20003FUH00`00FUIJEP0200000eYF001oo`0UOol3
000]Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P0000=JEP00FUH00UYF0`0097oo0P0000=JEP00Ool0
;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP000004FUH00`00FUH0000300001EYF001JEUYF000087oo0`0000AJEP00FUH0
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH=0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH00eYF1P006Woo1@0015YF00<005YF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00=JEP`000=JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP02FUH0
0`00FUH0000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEQh0009JEP06001JEUYF
001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
0eYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF001JEP00FUH30006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002ioo`80
00=JEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000D00003FUH005YF00AJEP03001JEUYF00D000]JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEPH000IJEP03001JEUYF009JEP05001JEP00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000`
Ool200000eYF000000050003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF100000=JEP00FUH015YF0`0015YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00<0
05YF00001@000UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YF000003=oo`00<Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000=JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<0
00AJEP03001JEP0000Eoo`D00003FUH0000000@000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPD003Eoo`00<7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00H005YF001JEP00FUH200000eYF
001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP020002FUH00`00FUH00004Ool30003FUH200001EYF001JEP00Ool02@00
15YF00<005YFFUH00UYF2000>Woo000^Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0003
FUH00`00FUIJEP03FUH200000eYF00000003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF
0000000300000eYF001JEP04FUH300000eYF001oo`09Ool90012Ool002eoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH60006Ool3000@Ool60003FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF0000000300000eYF001JEP04FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0004FUH0
0`00FUIJEP04000;Ool5000COol80005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF0000
0003FUH50002FUH00`00FUIJEP02001EOol002eoo`04001JEUYF0002FUH5000?Ool5000>Ool50004
FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P001UYF00<005YF
00000P000UYF0P00EGoo000]Ool00`00FUIJEP03000DOol50006Ool80003FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJ
EP02FUH3001FOol002eoo`<0009JEPh000Qoo`X000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF
009JEP8005Ioo`00;Goo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000H000=JEP03001JEUYF009JEP03001JEP0005Eoo`00;Goo00<005YF000015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`000Woo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`001UYF1@000eYF
00<005YF0000EGoo000]Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2000015YF001JEP00EGoo000^Ool40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000<Ool2
00000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF00000P000Woo0P00
00=JEP00Ool0E7oo000bOol70003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
000BOol30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH0000015YF00@005YFFUIJEPD000Moo`03001JEP0005Aoo`00>Goo6@00
77oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF10000UYF20002goo00@005YF000005Aoo`00L7oo0`0000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02`004goo00@005YF000005Aoo`00
Lgoo10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1@000Woo1@005Goo0P00
0eYF00<007ooOol0DWoo001gOol60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06
0007Ool5000COol200000eYF001JEP02FUH00`00Oomoo`1BOol007eooal000eoo`D0011oo`<000=J
EP05001JEUYFFUH0001DOol008ioo`<001Uoo`<000moo`800003FUH005YF00AJEP03001JEP0005Eo
o`00SWoo0P0000=JEP0000009Woo0`000eYF00<005YFFUH00eYF0P00EWoo002?Ool01000FUH005YF
0P0087oo10001UYF00<005YFFUH00eYF00<007ooOol0EGoo002?Ool00`00FUH00003FUH5000GOol4
0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P00F7oo002?Ool00`00FUH00004FUH01000FUIJEUYF
1`002Goo1`001UYF00<005YFFUH01EYF00@005YF000005Yoo`00T7oo0P0015YF00<005YFFUH015YF
00@005YFFUIJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP<005aoo`00T7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00Ggoo
002AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
001SOol009=oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06Moo`00UGoo1@000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Jgoo002JOolA001bOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59154 .75043 m .58983 .69505 L .55931 .69328 L p .707 .577 .707 r
F P
0 g
s
.58983 .69505 m .59154 .75043 L .62349 .74939 L p .707 .577 .707 r
F P
0 g
s
.62349 .74939 m .62178 .69401 L .58983 .69505 L p .707 .577 .707 r
F P
0 g
s
.62178 .69401 m .62349 .74939 L .65374 .74565 L p .707 .577 .707 r
F P
0 g
s
.65374 .74565 m .65203 .69027 L .62178 .69401 L p .707 .577 .707 r
F P
0 g
s
.56102 .74866 m .55931 .69328 L .53319 .68888 L p .707 .577 .707 r
F P
0 g
s
.55931 .69328 m .56102 .74866 L .59154 .75043 L p .707 .577 .707 r
F P
0 g
s
.65203 .69027 m .65374 .74565 L .67932 .73958 L p .707 .577 .707 r
F P
0 g
s
.67932 .73958 m .67761 .6842 L .65203 .69027 L p .707 .577 .707 r
F P
0 g
s
.61487 .80877 m .61598 .77163 L .5841 .77019 L p .707 .577 .707 r
F P
0 g
s
.61598 .77163 m .61487 .80877 L .64584 .80761 L p .707 .577 .707 r
F P
0 g
s
.64584 .80761 m .64696 .77047 L .61598 .77163 L p .707 .577 .707 r
F P
0 g
s
.58298 .80733 m .5841 .77019 L .55443 .76628 L p .707 .577 .707 r
F P
0 g
s
.5841 .77019 m .58298 .80733 L .61487 .80877 L p .707 .577 .707 r
F P
0 g
s
.53319 .68888 m .5349 .74425 L .56102 .74866 L p .707 .577 .707 r
F P
0 g
s
.5349 .74425 m .53319 .68888 L .51405 .68227 L p .707 .577 .707 r
F P
0 g
s
.67761 .6842 m .67932 .73958 L .69774 .73176 L p .707 .577 .707 r
F P
0 g
s
.69774 .73176 m .69603 .67638 L .67761 .6842 L p .707 .577 .707 r
F P
0 g
s
.64696 .77047 m .64584 .80761 L .67288 .80395 L p .707 .577 .707 r
F P
0 g
s
.67288 .80395 m .674 .76682 L .64696 .77047 L p .707 .577 .707 r
F P
0 g
s
.55443 .76628 m .55331 .80342 L .58298 .80733 L p .707 .577 .707 r
F P
0 g
s
.55331 .80342 m .55443 .76628 L .52988 .7603 L p .707 .577 .707 r
F P
0 g
s
.60663 .8492 m .60848 .83061 L .57686 .82678 L p .707 .577 .707 r
F P
0 g
s
.60848 .83061 m .60663 .8492 L .63779 .85059 L p .707 .577 .707 r
F P
0 g
s
.63779 .85059 m .63965 .832 L .60848 .83061 L p .707 .577 .707 r
F P
0 g
s
.57501 .84537 m .57686 .82678 L .54788 .8209 L p .707 .577 .707 r
F P
0 g
s
.57686 .82678 m .57501 .84537 L .60663 .8492 L p .707 .577 .707 r
F P
0 g
s
.51405 .68227 m .51576 .73765 L .5349 .74425 L p .707 .577 .707 r
F P
0 g
s
.63965 .832 m .63779 .85059 L .66545 .84942 L p .707 .577 .707 r
F P
0 g
s
.66545 .84942 m .66731 .83083 L .63965 .832 L p .707 .577 .707 r
F P
0 g
s
.54788 .8209 m .54603 .83949 L .57501 .84537 L p .707 .577 .707 r
F P
0 g
s
.52988 .7603 m .52876 .79744 L .55331 .80342 L p .707 .577 .707 r
F P
0 g
s
.674 .76682 m .67288 .80395 L .69333 .79817 L p .707 .577 .707 r
F P
0 g
s
.69333 .79817 m .69445 .76103 L .674 .76682 L p .707 .577 .707 r
F P
0 g
s
.54603 .83949 m .54788 .8209 L .52438 .81354 L p .707 .577 .707 r
F P
0 g
s
.51576 .73765 m .51405 .68227 L .50375 .67412 L p .707 .577 .707 r
F P
0 g
s
.69603 .67638 m .69774 .73176 L .70718 .72296 L p .707 .577 .707 r
F P
0 g
s
.70718 .72296 m .70547 .66758 L .69603 .67638 L p .707 .577 .707 r
F P
0 g
s
.52876 .79744 m .52988 .7603 L .51285 .75282 L p .707 .577 .707 r
F P
0 g
s
.52438 .81354 m .52252 .83213 L .54603 .83949 L p .707 .577 .707 r
F P
0 g
s
.66731 .83083 m .66545 .84942 L .6869 .8458 L p .707 .577 .707 r
F P
0 g
s
.6869 .8458 m .68876 .82721 L .66731 .83083 L p .707 .577 .707 r
F P
0 g
s
.51285 .75282 m .51173 .78996 L .52876 .79744 L p .707 .577 .707 r
F P
0 g
s
.50375 .67412 m .50546 .72949 L .51576 .73765 L p .707 .577 .707 r
F P
0 g
s
.69445 .76103 m .69333 .79817 L .70519 .79082 L p .707 .577 .707 r
F P
0 g
s
.70519 .79082 m .70631 .75368 L .69445 .76103 L p .707 .577 .707 r
F P
0 g
s
.52252 .83213 m .52438 .81354 L .50866 .80542 L p .707 .577 .707 r
F P
0 g
s
.50866 .80542 m .5068 .824 L .52252 .83213 L p .707 .577 .707 r
F P
0 g
s
.51173 .78996 m .51285 .75282 L .505 .74458 L p .707 .577 .707 r
F P
0 g
s
.50546 .72949 m .50375 .67412 L .5033 .6652 L p .708 .578 .707 r
F P
0 g
s
.70547 .66758 m .70718 .72296 L .70673 .71404 L p .708 .578 .707 r
F P
0 g
s
.70673 .71404 m .70502 .65867 L .70547 .66758 L p .708 .578 .707 r
F P
0 g
s
.68876 .82721 m .6869 .8458 L .70004 .84007 L p .707 .577 .707 r
F P
0 g
s
.70004 .84007 m .70189 .82149 L .68876 .82721 L p .707 .577 .707 r
F P
0 g
s
.505 .74458 m .50388 .78172 L .51173 .78996 L p .707 .577 .707 r
F P
0 g
s
.5033 .6652 m .50501 .72058 L .50546 .72949 L p .708 .578 .707 r
F P
0 g
s
.5068 .824 m .50866 .80542 L .50225 .79733 L p .707 .577 .707 r
F P
0 g
s
.70631 .75368 m .70519 .79082 L .7073 .78262 L p .707 .577 .707 r
F P
0 g
s
.7073 .78262 m .70842 .74548 L .70631 .75368 L p .707 .577 .707 r
F P
0 g
s
.48624 .82175 m .48624 .31986 L .44255 .31683 L p .707 .577 .707 r
F P
0 g
s
.50225 .79733 m .5004 .81592 L .5068 .824 L p .707 .577 .707 r
F P
0 g
s
.50388 .78172 m .505 .74458 L .50711 .73638 L p .707 .577 .707 r
F P
0 g
s
.50501 .72058 m .5033 .6652 L .51274 .65641 L p .707 .577 .707 r
F P
0 g
s
.50711 .73638 m .506 .77352 L .50388 .78172 L p .707 .577 .707 r
F P
0 g
s
.51274 .65641 m .51445 .71178 L .50501 .72058 L p .707 .577 .707 r
F P
0 g
s
.5004 .81592 m .50225 .79733 L .50579 .79007 L p .707 .577 .707 r
F P
0 g
s
.50579 .79007 m .50393 .80866 L .5004 .81592 L p .707 .577 .707 r
F P
0 g
s
.506 .77352 m .50711 .73638 L .51897 .72903 L p .707 .577 .707 r
F P
0 g
s
.51445 .71178 m .51274 .65641 L .53116 .64859 L p .707 .577 .707 r
F P
0 g
s
.51897 .72903 m .51786 .76617 L .506 .77352 L p .707 .577 .707 r
F P
0 g
s
.53116 .64859 m .53287 .70396 L .51445 .71178 L p .707 .577 .707 r
F P
0 g
s
.50393 .80866 m .50579 .79007 L .51893 .78435 L p .707 .577 .707 r
F P
0 g
s
.51893 .78435 m .51707 .80294 L .50393 .80866 L p .707 .577 .707 r
F P
0 g
s
.51786 .76617 m .51897 .72903 L .53942 .72325 L p .707 .577 .707 r
F P
0 g
s
.53942 .72325 m .53831 .76039 L .51786 .76617 L p .707 .577 .707 r
F P
0 g
s
.51707 .80294 m .51893 .78435 L .54037 .78072 L p .707 .577 .707 r
F P
0 g
s
.54037 .78072 m .53852 .79931 L .51707 .80294 L p .707 .577 .707 r
F P
0 g
s
.48624 .31986 m .48624 .82175 L .53129 .821 L p .707 .577 .707 r
F P
0 g
s
.53287 .70396 m .53116 .64859 L .55674 .64251 L p .707 .577 .707 r
F P
0 g
s
.53129 .821 m .53129 .31911 L .48624 .31986 L p .707 .577 .707 r
F P
0 g
s
.55674 .64251 m .55845 .69789 L .53287 .70396 L p .707 .577 .707 r
F P
0 g
s
.55845 .69789 m .55674 .64251 L .58699 .63877 L p .707 .577 .707 r
F P
0 g
s
.53831 .76039 m .53942 .72325 L .56646 .7196 L p .707 .577 .707 r
F P
0 g
s
.58699 .63877 m .5887 .69415 L .55845 .69789 L p .707 .577 .707 r
F P
0 g
s
.56646 .7196 m .56534 .75674 L .53831 .76039 L p .707 .577 .707 r
F P
0 g
s
.56534 .75674 m .56646 .7196 L .59743 .71843 L p .707 .577 .707 r
F P
0 g
s
.53852 .79931 m .54037 .78072 L .56804 .77955 L p .707 .577 .707 r
F P
0 g
s
.56804 .77955 m .56618 .79814 L .53852 .79931 L p .707 .577 .707 r
F P
0 g
s
.59743 .71843 m .59632 .75557 L .56534 .75674 L p .707 .577 .707 r
F P
0 g
s
.56618 .79814 m .56804 .77955 L .5992 .78095 L p .707 .577 .707 r
F P
0 g
s
.5992 .78095 m .59735 .79954 L .56618 .79814 L p .707 .577 .707 r
F P
0 g
s
.53129 .31911 m .53129 .821 L .57327 .81656 L p .707 .577 .707 r
F P
0 g
s
.57327 .81656 m .57327 .31467 L .53129 .31911 L p .707 .577 .707 r
F P
0 g
s
.44255 .81872 m .44255 .31683 L .40447 .31033 L p .707 .577 .707 r
F P
0 g
s
.44255 .31683 m .44255 .81872 L .48624 .82175 L p .707 .577 .707 r
F P
0 g
s
.70189 .82149 m .70004 .84007 L .70358 .83281 L p .707 .577 .707 r
F P
0 g
s
.70358 .83281 m .70543 .81423 L .70189 .82149 L p .707 .577 .707 r
F P
0 g
s
.70502 .65867 m .70673 .71404 L .69643 .70589 L p .707 .577 .707 r
F P
0 g
s
.69643 .70589 m .69472 .65051 L .70502 .65867 L p .707 .577 .707 r
F P
0 g
s
.5887 .69415 m .58699 .63877 L .61894 .63773 L p .707 .577 .707 r
F P
0 g
s
.61894 .63773 m .62065 .69311 L .5887 .69415 L p .707 .577 .707 r
F P
0 g
s
.62932 .71988 m .6282 .75701 L .59632 .75557 L p .707 .577 .707 r
F P
0 g
s
.59632 .75557 m .59743 .71843 L .62932 .71988 L p .707 .577 .707 r
F P
0 g
s
.63082 .78477 m .62897 .80336 L .59735 .79954 L p .707 .577 .707 r
F P
0 g
s
.59735 .79954 m .5992 .78095 L .63082 .78477 L p .707 .577 .707 r
F P
0 g
s
.57327 .31467 m .57327 .81656 L .60808 .80885 L p .707 .577 .707 r
F P
0 g
s
.60808 .80885 m .60808 .30696 L .57327 .31467 L p .707 .577 .707 r
F P
0 g
s
.24671 .71036 m .246 .65432 L .21546 .65244 L p .707 .577 .707 r
F P
0 g
s
.246 .65432 m .24671 .71036 L .27867 .70987 L p .707 .577 .707 r
F P
0 g
s
.27867 .70987 m .27796 .65383 L .246 .65432 L p .707 .577 .707 r
F P
0 g
s
.27796 .65383 m .27867 .70987 L .30893 .70706 L p .707 .577 .707 r
F P
0 g
s
.30893 .70706 m .30822 .65102 L .27796 .65383 L p .707 .577 .707 r
F P
0 g
s
.70842 .74548 m .7073 .78262 L .69946 .77438 L p .707 .577 .707 r
F P
0 g
s
.69946 .77438 m .70057 .73724 L .70842 .74548 L p .707 .577 .707 r
F P
0 g
s
.40447 .81222 m .40447 .31033 L .37575 .30099 L p .707 .577 .707 r
F P
0 g
s
.40447 .31033 m .40447 .81222 L .44255 .81872 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21617 .70849 m .21546 .65244 L .18934 .64838 L p .707 .577 .707 r
F P
0 g
s
.21546 .65244 m .21617 .70849 L .24671 .71036 L p .707 .577 .707 r
F P
0 g
s
.30822 .65102 m .30893 .70706 L .33452 .70221 L p .707 .577 .707 r
F P
0 g
s
.33452 .70221 m .33381 .64617 L .30822 .65102 L p .707 .577 .707 r
F P
0 g
s
.69472 .65051 m .69643 .70589 L .67728 .69928 L p .707 .577 .707 r
F P
0 g
s
.67728 .69928 m .67557 .64391 L .69472 .65051 L p .707 .577 .707 r
F P
0 g
s
.70543 .81423 m .70358 .83281 L .69717 .82473 L p .707 .577 .707 r
F P
0 g
s
.69717 .82473 m .69903 .80614 L .70543 .81423 L p .707 .577 .707 r
F P
0 g
s
.64946 .6395 m .65117 .69488 L .62065 .69311 L p .707 .577 .707 r
F P
0 g
s
.62065 .69311 m .61894 .63773 L .64946 .6395 L p .707 .577 .707 r
F P
0 g
s
.65899 .72378 m .65787 .76092 L .6282 .75701 L p .707 .577 .707 r
F P
0 g
s
.6282 .75701 m .62932 .71988 L .65899 .72378 L p .707 .577 .707 r
F P
0 g
s
.62897 .80336 m .63082 .78477 L .6598 .79066 L p .707 .577 .707 r
F P
0 g
s
.60808 .30696 m .60808 .80885 L .63231 .79863 L p .707 .577 .707 r
F P
0 g
s
.63231 .79863 m .63231 .29675 L .60808 .30696 L p .707 .577 .707 r
F P
0 g
s
.27036 .77709 m .27081 .74041 L .23891 .73943 L p .707 .577 .707 r
F P
0 g
s
.27081 .74041 m .27036 .77709 L .30135 .77507 L p .707 .577 .707 r
F P
0 g
s
.30135 .77507 m .30179 .73839 L .27081 .74041 L p .707 .577 .707 r
F P
0 g
s
.23847 .77611 m .23891 .73943 L .20923 .73553 L p .707 .577 .707 r
F P
0 g
s
.23891 .73943 m .23847 .77611 L .27036 .77709 L p .707 .577 .707 r
F P
0 g
s
.18934 .64838 m .19005 .70443 L .21617 .70849 L p .707 .577 .707 r
F P
0 g
s
.19005 .70443 m .18934 .64838 L .17018 .64254 L p .707 .577 .707 r
F P
0 g
s
.30179 .73839 m .30135 .77507 L .32839 .77024 L p .707 .577 .707 r
F P
0 g
s
.32839 .77024 m .32883 .73355 L .30179 .73839 L p .707 .577 .707 r
F P
0 g
s
.33381 .64617 m .33452 .70221 L .35293 .69579 L p .707 .577 .707 r
F P
0 g
s
.35293 .69579 m .35222 .63975 L .33381 .64617 L p .707 .577 .707 r
F P
0 g
s
.70057 .73724 m .69946 .77438 L .68243 .7669 L p .707 .577 .707 r
F P
0 g
s
.68243 .7669 m .68354 .72976 L .70057 .73724 L p .707 .577 .707 r
F P
0 g
s
.20878 .77221 m .20923 .73553 L .18466 .72911 L p .707 .577 .707 r
F P
0 g
s
.20923 .73553 m .20878 .77221 L .23847 .77611 L p .707 .577 .707 r
F P
0 g
s
.67557 .64391 m .67728 .69928 L .65117 .69488 L p .707 .577 .707 r
F P
0 g
s
.65117 .69488 m .64946 .6395 L .67557 .64391 L p .707 .577 .707 r
F P
0 g
s
.37575 .80288 m .37575 .30099 L .35919 .28973 L p .707 .577 .707 r
F P
0 g
s
.37575 .30099 m .37575 .80288 L .40447 .81222 L p .707 .577 .707 r
F P
0 g
s
.17018 .64254 m .17089 .69858 L .19005 .70443 L p .707 .577 .707 r
F P
0 g
s
.26446 .82611 m .26518 .80833 L .23343 .80592 L p .707 .577 .707 r
F P
0 g
s
.26518 .80833 m .26446 .82611 L .29574 .82471 L p .707 .577 .707 r
F P
0 g
s
.29574 .82471 m .29645 .80693 L .26518 .80833 L p .707 .577 .707 r
F P
0 g
s
.69903 .80614 m .69717 .82473 L .68145 .81661 L p .707 .577 .707 r
F P
0 g
s
.68145 .81661 m .6833 .79802 L .69903 .80614 L p .707 .577 .707 r
F P
0 g
s
.32883 .73355 m .32839 .77024 L .34884 .76307 L p .707 .577 .707 r
F P
0 g
s
.34884 .76307 m .34928 .72639 L .32883 .73355 L p .707 .577 .707 r
F P
0 g
s
.18466 .72911 m .18422 .76579 L .20878 .77221 L p .707 .577 .707 r
F P
0 g
s
.23271 .82369 m .23343 .80592 L .2043 .79993 L p .707 .577 .707 r
F P
0 g
s
.23343 .80592 m .23271 .82369 L .26446 .82611 L p .707 .577 .707 r
F P
0 g
s
.29645 .80693 m .29574 .82471 L .32347 .81964 L p .707 .577 .707 r
F P
0 g
s
.32347 .81964 m .32419 .80186 L .29645 .80693 L p .707 .577 .707 r
F P
0 g
s
.17089 .69858 m .17018 .64254 L .15987 .63548 L p .707 .577 .707 r
F P
0 g
s
.2043 .79993 m .20358 .8177 L .23271 .82369 L p .707 .577 .707 r
F P
0 g
s
.18422 .76579 m .18466 .72911 L .16762 .72078 L p .707 .577 .707 r
F P
0 g
s
.63231 .29675 m .63231 .79863 L .64359 .78691 L p .707 .577 .707 r
F P
0 g
s
.64359 .78691 m .64359 .28502 L .63231 .29675 L p .707 .577 .707 r
F P
0 g
s
.35222 .63975 m .35293 .69579 L .36237 .68843 L p .707 .577 .707 r
F P
0 g
s
.36237 .68843 m .36167 .63238 L .35222 .63975 L p .707 .577 .707 r
F P
0 g
s
.68354 .72976 m .68243 .7669 L .65787 .76092 L p .707 .577 .707 r
F P
0 g
s
.65787 .76092 m .65899 .72378 L .68354 .72976 L p .707 .577 .707 r
F P
0 g
s
.20358 .8177 m .2043 .79993 L .18064 .79094 L p .707 .577 .707 r
F P
0 g
s
.32419 .80186 m .32347 .81964 L .34494 .81138 L p .707 .577 .707 r
F P
0 g
s
.34494 .81138 m .34566 .7936 L .32419 .80186 L p .707 .577 .707 r
F P
0 g
s
.18064 .79094 m .17993 .80872 L .20358 .8177 L p .707 .577 .707 r
F P
0 g
s
.16762 .72078 m .16717 .75746 L .18422 .76579 L p .707 .577 .707 r
F P
0 g
s
.15987 .63548 m .16058 .69152 L .17089 .69858 L p .707 .577 .707 r
F P
0 g
s
.34928 .72639 m .34884 .76307 L .3607 .75427 L p .707 .577 .707 r
F P
0 g
s
.3607 .75427 m .36114 .71758 L .34928 .72639 L p .707 .577 .707 r
F P
0 g
s
.6833 .79802 m .68145 .81661 L .65795 .80924 L p .707 .577 .707 r
F P
0 g
s
.65795 .80924 m .6598 .79066 L .6833 .79802 L p .707 .577 .707 r
F P
0 g
s
.17993 .80872 m .18064 .79094 L .16479 .77985 L p .707 .577 .707 r
F P
0 g
s
.16717 .75746 m .16762 .72078 L .15976 .71137 L p .707 .577 .707 r
F P
0 g
s
.35877 .78298 m .35805 .80075 L .36152 .78879 L p .707 .577 .707 r
F P
0 g
s
.36152 .78879 m .36224 .77102 L .35877 .78298 L p .707 .577 .707 r
F P
0 g
s
.36121 .6248 m .36192 .68085 L .35161 .67379 L p .707 .577 .707 r
F P
0 g
s
.35161 .67379 m .3509 .61774 L .36121 .6248 L p .707 .577 .707 r
F P
0 g
s
.36114 .71758 m .3607 .75427 L .36281 .74469 L p .707 .577 .707 r
F P
0 g
s
.36281 .74469 m .36325 .70801 L .36114 .71758 L p .707 .577 .707 r
F P
0 g
s
.36325 .70801 m .36281 .74469 L .35495 .73528 L p .707 .577 .707 r
F P
0 g
s
.35495 .73528 m .3554 .6986 L .36325 .70801 L p .707 .577 .707 r
F P
0 g
s
.35805 .80075 m .35877 .78298 L .34566 .7936 L p .707 .577 .707 r
F P
0 g
s
.36224 .77102 m .36152 .78879 L .35501 .77668 L p .707 .577 .707 r
F P
0 g
s
.35501 .77668 m .35573 .7589 L .36224 .77102 L p .707 .577 .707 r
F P
0 g
s
.35919 .79161 m .35919 .28973 L .35641 .27764 L p .707 .577 .707 r
F P
0 g
s
.36167 .63238 m .36237 .68843 L .36192 .68085 L p .708 .578 .707 r
F P
0 g
s
.36192 .68085 m .36121 .6248 L .36167 .63238 L p .708 .578 .707 r
F P
0 g
s
.35919 .28973 m .35919 .79161 L .37575 .80288 L p .707 .577 .707 r
F P
0 g
s
.16058 .69152 m .15987 .63548 L .15941 .62789 L p .708 .578 .707 r
F P
0 g
s
.16479 .77985 m .16407 .79763 L .17993 .80872 L p .707 .577 .707 r
F P
0 g
s
.34566 .7936 m .34494 .81138 L .35805 .80075 L p .707 .577 .707 r
F P
0 g
s
.15976 .71137 m .15932 .74805 L .16717 .75746 L p .707 .577 .707 r
F P
0 g
s
.6598 .79066 m .65795 .80924 L .62897 .80336 L p .707 .577 .707 r
F P
0 g
s
.15941 .62789 m .16012 .68394 L .16058 .69152 L p .708 .578 .707 r
F P
0 g
s
.64359 .28502 m .64359 .78691 L .64081 .77482 L p .707 .577 .707 r
F P
0 g
s
.64081 .77482 m .64081 .27293 L .64359 .28502 L p .707 .577 .707 r
F P
0 g
s
.16407 .79763 m .16479 .77985 L .15827 .76773 L p .707 .577 .707 r
F P
0 g
s
.15932 .74805 m .15976 .71137 L .16187 .7018 L p .707 .577 .707 r
F P
0 g
s
.15827 .76773 m .15756 .78551 L .16407 .79763 L p .707 .577 .707 r
F P
0 g
s
.16012 .68394 m .15941 .62789 L .16886 .62053 L p .707 .577 .707 r
F P
0 g
s
.16187 .7018 m .16143 .73848 L .15932 .74805 L p .707 .577 .707 r
F P
0 g
s
.35641 .27764 m .35641 .77953 L .35919 .79161 L p .707 .577 .707 r
F P
0 g
s
.35641 .77953 m .35641 .27764 L .36769 .26591 L p .707 .577 .707 r
F P
0 g
s
.16886 .62053 m .16956 .67658 L .16012 .68394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15756 .78551 m .15827 .76773 L .16174 .75577 L p .707 .577 .707 r
F P
0 g
s
.16174 .75577 m .16102 .77355 L .15756 .78551 L p .707 .577 .707 r
F P
0 g
s
.16143 .73848 m .16187 .7018 L .17373 .693 L p .707 .577 .707 r
F P
0 g
s
.64081 .27293 m .64081 .77482 L .62425 .76356 L p .707 .577 .707 r
F P
0 g
s
.62425 .76356 m .62425 .26167 L .64081 .27293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16956 .67658 m .16886 .62053 L .18727 .61411 L p .707 .577 .707 r
F P
0 g
s
.3509 .61774 m .35161 .67379 L .33245 .66794 L p .707 .577 .707 r
F P
0 g
s
.33245 .66794 m .33174 .6119 L .3509 .61774 L p .707 .577 .707 r
F P
0 g
s
.17373 .693 m .17329 .72968 L .16143 .73848 L p .707 .577 .707 r
F P
0 g
s
.18727 .61411 m .18798 .67015 L .16956 .67658 L p .707 .577 .707 r
F P
0 g
s
.3554 .6986 m .35495 .73528 L .33791 .72696 L p .707 .577 .707 r
F P
0 g
s
.33791 .72696 m .33835 .69028 L .3554 .6986 L p .707 .577 .707 r
F P
0 g
s
.16102 .77355 m .16174 .75577 L .17485 .74514 L p .707 .577 .707 r
F P
0 g
s
.36769 .7678 m .36769 .26591 L .39192 .2557 L p .707 .577 .707 r
F P
0 g
s
.36769 .26591 m .36769 .7678 L .35641 .77953 L p .707 .577 .707 r
F P
0 g
s
.17329 .72968 m .17373 .693 L .19418 .68583 L p .707 .577 .707 r
F P
0 g
s
.18798 .67015 m .18727 .61411 L .21286 .60926 L p .707 .577 .707 r
F P
0 g
s
.17485 .74514 m .17414 .76292 L .16102 .77355 L p .707 .577 .707 r
F P
0 g
s
.33174 .6119 m .33245 .66794 L .30633 .66388 L p .707 .577 .707 r
F P
0 g
s
.30633 .66388 m .30562 .60784 L .33174 .6119 L p .707 .577 .707 r
F P
0 g
s
.35573 .7589 m .35501 .77668 L .33915 .76558 L p .707 .577 .707 r
F P
0 g
s
.33915 .76558 m .33987 .7478 L .35573 .7589 L p .707 .577 .707 r
F P
0 g
s
.19418 .68583 m .19374 .72251 L .17329 .72968 L p .707 .577 .707 r
F P
0 g
s
.62425 .26167 m .62425 .76356 L .59553 .75422 L p .707 .577 .707 r
F P
0 g
s
.59553 .75422 m .59553 .25233 L .62425 .26167 L p .707 .577 .707 r
F P
0 g
s
.21286 .60926 m .21357 .6653 L .18798 .67015 L p .707 .577 .707 r
F P
0 g
s
.33835 .69028 m .33791 .72696 L .31334 .72053 L p .707 .577 .707 r
F P
0 g
s
.31334 .72053 m .31379 .68385 L .33835 .69028 L p .707 .577 .707 r
F P
0 g
s
.21357 .6653 m .21286 .60926 L .24312 .60645 L p .707 .577 .707 r
F P
0 g
s
.30562 .60784 m .30633 .66388 L .27579 .662 L p .707 .577 .707 r
F P
0 g
s
.27579 .662 m .27508 .60596 L .30562 .60784 L p .707 .577 .707 r
F P
0 g
s
.17414 .76292 m .17485 .74514 L .19633 .73689 L p .707 .577 .707 r
F P
0 g
s
.19374 .72251 m .19418 .68583 L .22122 .681 L p .707 .577 .707 r
F P
0 g
s
.19633 .73689 m .19561 .75467 L .17414 .76292 L p .707 .577 .707 r
F P
0 g
s
.24383 .66249 m .24312 .60645 L .27508 .60596 L p .707 .577 .707 r
F P
0 g
s
.24312 .60645 m .24383 .66249 L .21357 .6653 L p .707 .577 .707 r
F P
0 g
s
.27508 .60596 m .27579 .662 L .24383 .66249 L p .707 .577 .707 r
F P
0 g
s
.33987 .7478 m .33915 .76558 L .3155 .7566 L p .707 .577 .707 r
F P
0 g
s
.3155 .7566 m .31622 .73882 L .33987 .7478 L p .707 .577 .707 r
F P
0 g
s
.39192 .2557 m .39192 .75759 L .36769 .7678 L p .707 .577 .707 r
F P
0 g
s
.39192 .75759 m .39192 .2557 L .42673 .24799 L p .707 .577 .707 r
F P
0 g
s
.31379 .68385 m .31334 .72053 L .28366 .71664 L p .707 .577 .707 r
F P
0 g
s
.28366 .71664 m .2841 .67996 L .31379 .68385 L p .707 .577 .707 r
F P
0 g
s
.22122 .681 m .22078 .71768 L .19374 .72251 L p .707 .577 .707 r
F P
0 g
s
.72421 .65928 m .72492 .60423 L .69438 .60104 L p .707 .577 .707 r
F P
0 g
s
.72492 .60423 m .72421 .65928 L .75617 .65952 L p .707 .577 .707 r
F P
0 g
s
.75617 .65952 m .75688 .60446 L .72492 .60423 L p .707 .577 .707 r
F P
0 g
s
.75688 .60446 m .75617 .65952 L .78643 .65679 L p .707 .577 .707 r
F P
0 g
s
.78643 .65679 m .78714 .60173 L .75688 .60446 L p .707 .577 .707 r
F P
0 g
s
.22078 .71768 m .22122 .681 L .25221 .67897 L p .707 .577 .707 r
F P
0 g
s
.19561 .75467 m .19633 .73689 L .22406 .73181 L p .707 .577 .707 r
F P
0 g
s
.69367 .6561 m .69438 .60104 L .66826 .59523 L p .707 .577 .707 r
F P
0 g
s
.69438 .60104 m .69367 .6561 L .72421 .65928 L p .707 .577 .707 r
F P
0 g
s
.2841 .67996 m .28366 .71664 L .25176 .71565 L p .707 .577 .707 r
F P
0 g
s
.25176 .71565 m .25221 .67897 L .2841 .67996 L p .707 .577 .707 r
F P
0 g
s
.78714 .60173 m .78643 .65679 L .81202 .65136 L p .707 .577 .707 r
F P
0 g
s
.81202 .65136 m .81273 .59631 L .78714 .60173 L p .707 .577 .707 r
F P
0 g
s
.59553 .25233 m .59553 .75422 L .55745 .74772 L p .707 .577 .707 r
F P
0 g
s
.55745 .74772 m .55745 .24583 L .59553 .25233 L p .707 .577 .707 r
F P
0 g
s
.25221 .67897 m .25176 .71565 L .22078 .71768 L p .707 .577 .707 r
F P
0 g
s
.31622 .73882 m .3155 .7566 L .28637 .75061 L p .707 .577 .707 r
F P
0 g
s
.28637 .75061 m .28709 .73283 L .31622 .73882 L p .707 .577 .707 r
F P
0 g
s
.22406 .73181 m .22334 .74959 L .19561 .75467 L p .707 .577 .707 r
F P
0 g
s
.74823 .71361 m .74779 .67623 L .7159 .67609 L p .707 .577 .707 r
F P
0 g
s
.74779 .67623 m .74823 .71361 L .77922 .71141 L p .707 .577 .707 r
F P
0 g
s
.77922 .71141 m .77878 .67403 L .74779 .67623 L p .707 .577 .707 r
F P
0 g
s
.22334 .74959 m .22406 .73181 L .25533 .73041 L p .707 .577 .707 r
F P
0 g
s
.71634 .71347 m .7159 .67609 L .68621 .67363 L p .707 .577 .707 r
F P
0 g
s
.7159 .67609 m .71634 .71347 L .74823 .71361 L p .707 .577 .707 r
F P
0 g
s
.66826 .59523 m .66755 .65028 L .69367 .6561 L p .707 .577 .707 r
F P
0 g
s
.28709 .73283 m .28637 .75061 L .25461 .74819 L p .707 .577 .707 r
F P
0 g
s
.25461 .74819 m .25533 .73041 L .28709 .73283 L p .707 .577 .707 r
F P
0 g
s
.66755 .65028 m .66826 .59523 L .6491 .58735 L p .707 .577 .707 r
F P
0 g
s
.42673 .74988 m .42673 .24799 L .46871 .24355 L p .707 .577 .707 r
F P
0 g
s
.42673 .24799 m .42673 .74988 L .39192 .75759 L p .707 .577 .707 r
F P
0 g
s
.81273 .59631 m .81202 .65136 L .83043 .64377 L p .707 .577 .707 r
F P
0 g
s
.83043 .64377 m .83114 .58871 L .81273 .59631 L p .707 .577 .707 r
F P
0 g
s
.25533 .73041 m .25461 .74819 L .22334 .74959 L p .707 .577 .707 r
F P
0 g
s
.77878 .67403 m .77922 .71141 L .80626 .7071 L p .707 .577 .707 r
F P
0 g
s
.80626 .7071 m .80582 .66971 L .77878 .67403 L p .707 .577 .707 r
F P
0 g
s
.68621 .67363 m .68666 .71101 L .71634 .71347 L p .707 .577 .707 r
F P
0 g
s
.55745 .24583 m .55745 .74772 L .51375 .74469 L p .707 .577 .707 r
F P
0 g
s
.51375 .74469 m .51375 .2428 L .55745 .24583 L p .707 .577 .707 r
F P
0 g
s
.74538 .74794 m .74467 .72895 L .71291 .72959 L p .707 .577 .707 r
F P
0 g
s
.74467 .72895 m .74538 .74794 L .77666 .7458 L p .707 .577 .707 r
F P
0 g
s
.77666 .7458 m .77594 .7268 L .74467 .72895 L p .707 .577 .707 r
F P
0 g
s
.68666 .71101 m .68621 .67363 L .66165 .66909 L p .707 .577 .707 r
F P
0 g
s
.71291 .72959 m .71363 .74858 L .74538 .74794 L p .707 .577 .707 r
F P
0 g
s
.71363 .74858 m .71291 .72959 L .68378 .72866 L p .707 .577 .707 r
F P
0 g
s
.77594 .7268 m .77666 .7458 L .80439 .74235 L p .707 .577 .707 r
F P
0 g
s
.80439 .74235 m .80367 .72335 L .77594 .7268 L p .707 .577 .707 r
F P
0 g
s
.68378 .72866 m .6845 .74765 L .71363 .74858 L p .707 .577 .707 r
F P
0 g
s
.46871 .74544 m .46871 .24355 L .51375 .2428 L p .707 .577 .707 r
F P
0 g
s
.46871 .24355 m .46871 .74544 L .42673 .74988 L p .707 .577 .707 r
F P
0 g
s
.6491 .58735 m .64839 .64241 L .66755 .65028 L p .707 .577 .707 r
F P
0 g
s
.66165 .66909 m .66209 .70647 L .68666 .71101 L p .707 .577 .707 r
F P
0 g
s
.51375 .2428 m .51375 .74469 L .46871 .74544 L p .707 .577 .707 r
F P
0 g
s
.80582 .66971 m .80626 .7071 L .82671 .70108 L p .707 .577 .707 r
F P
0 g
s
.82671 .70108 m .82627 .6637 L .80582 .66971 L p .707 .577 .707 r
F P
0 g
s
.64839 .64241 m .6491 .58735 L .63879 .57819 L p .707 .577 .707 r
F P
0 g
s
.6845 .74765 m .68378 .72866 L .66013 .72625 L p .707 .577 .707 r
F P
0 g
s
.83114 .58871 m .83043 .64377 L .83988 .63474 L p .707 .577 .707 r
F P
0 g
s
.83988 .63474 m .84058 .57969 L .83114 .58871 L p .707 .577 .707 r
F P
0 g
s
.66013 .72625 m .66085 .74524 L .6845 .74765 L p .707 .577 .707 r
F P
0 g
s
.66209 .70647 m .66165 .66909 L .6446 .66291 L p .707 .577 .707 r
F P
0 g
s
.80367 .72335 m .80439 .74235 L .82586 .73794 L p .707 .577 .707 r
F P
0 g
s
.82586 .73794 m .82514 .71895 L .80367 .72335 L p .707 .577 .707 r
F P
0 g
s
.6446 .66291 m .64504 .70029 L .66209 .70647 L p .707 .577 .707 r
F P
0 g
s
.63879 .57819 m .63808 .63324 L .64839 .64241 L p .707 .577 .707 r
F P
0 g
s
.82627 .6637 m .82671 .70108 L .83857 .69396 L p .707 .577 .707 r
F P
0 g
s
.83857 .69396 m .83813 .65658 L .82627 .6637 L p .707 .577 .707 r
F P
0 g
s
.66085 .74524 m .66013 .72625 L .64427 .72259 L p .707 .577 .707 r
F P
0 g
s
.64427 .72259 m .64499 .74158 L .66085 .74524 L p .707 .577 .707 r
F P
0 g
s
.82514 .71895 m .82586 .73794 L .83897 .733 L p .707 .577 .707 r
F P
0 g
s
.83897 .733 m .83826 .71401 L .82514 .71895 L p .707 .577 .707 r
F P
0 g
s
.63808 .63324 m .63879 .57819 L .63833 .56862 L p .707 .578 .707 r
F P
0 g
s
.64504 .70029 m .6446 .66291 L .63675 .6557 L p .707 .577 .707 r
F P
0 g
s
.84058 .57969 m .83988 .63474 L .83942 .62518 L p .707 .578 .707 r
F P
0 g
s
.83942 .62518 m .84013 .57013 L .84058 .57969 L p .707 .578 .707 r
F P
0 g
s
.63675 .6557 m .63719 .69308 L .64504 .70029 L p .707 .577 .707 r
F P
0 g
s
.63833 .56862 m .63762 .62368 L .63808 .63324 L p .707 .578 .707 r
F P
0 g
s
.83813 .65658 m .83857 .69396 L .84068 .68643 L p .707 .577 .707 r
F P
0 g
s
.84068 .68643 m .84023 .64905 L .83813 .65658 L p .707 .577 .707 r
F P
0 g
s
.64499 .74158 m .64427 .72259 L .63776 .71805 L p .707 .577 .707 r
F P
0 g
s
.63776 .71805 m .63847 .73704 L .64499 .74158 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83826 .71401 m .83897 .733 L .84244 .72802 L p .707 .577 .707 r
F P
0 g
s
.84244 .72802 m .84173 .70902 L .83826 .71401 L p .707 .577 .707 r
F P
0 g
s
.63762 .62368 m .63833 .56862 L .64777 .5596 L p .707 .577 .707 r
F P
0 g
s
.63719 .69308 m .63675 .6557 L .63885 .64817 L p .707 .577 .707 r
F P
0 g
s
.84013 .57013 m .83942 .62518 L .82911 .61601 L p .707 .577 .707 r
F P
0 g
s
.82911 .61601 m .82982 .56096 L .84013 .57013 L p .707 .577 .707 r
F P
0 g
s
.63885 .64817 m .6393 .68555 L .63719 .69308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64777 .5596 m .64707 .61466 L .63762 .62368 L p .707 .577 .707 r
F P
0 g
s
.37935 .61924 m .38106 .56351 L .35054 .5602 L p .707 .577 .707 r
F P
0 g
s
.38106 .56351 m .37935 .61924 L .4113 .62004 L p .707 .577 .707 r
F P
0 g
s
.4113 .62004 m .41301 .56431 L .38106 .56351 L p .707 .577 .707 r
F P
0 g
s
.41301 .56431 m .4113 .62004 L .44155 .61825 L p .707 .577 .707 r
F P
0 g
s
.44155 .61825 m .44326 .56252 L .41301 .56431 L p .707 .577 .707 r
F P
0 g
s
.84023 .64905 m .84068 .68643 L .83282 .67922 L p .707 .577 .707 r
F P
0 g
s
.83282 .67922 m .83238 .64184 L .84023 .64905 L p .707 .577 .707 r
F P
0 g
s
.63847 .73704 m .63776 .71805 L .64123 .71306 L p .707 .577 .707 r
F P
0 g
s
.64123 .71306 m .64194 .73206 L .63847 .73704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.34883 .61593 m .35054 .5602 L .32442 .55471 L p .707 .577 .707 r
F P
0 g
s
.35054 .5602 m .34883 .61593 L .37935 .61924 L p .707 .577 .707 r
F P
0 g
s
.64707 .61466 m .64777 .5596 L .66619 .55201 L p .707 .577 .707 r
F P
0 g
s
.84173 .70902 m .84244 .72802 L .83593 .72347 L p .707 .577 .707 r
F P
0 g
s
.83593 .72347 m .83521 .70448 L .84173 .70902 L p .707 .577 .707 r
F P
0 g
s
.44326 .56252 m .44155 .61825 L .46713 .61406 L p .707 .577 .707 r
F P
0 g
s
.46713 .61406 m .46884 .55833 L .44326 .56252 L p .707 .577 .707 r
F P
0 g
s
.82982 .56096 m .82911 .61601 L .80995 .60814 L p .707 .577 .707 r
F P
0 g
s
.80995 .60814 m .81066 .55308 L .82982 .56096 L p .707 .577 .707 r
F P
0 g
s
.6393 .68555 m .63885 .64817 L .65071 .64105 L p .707 .577 .707 r
F P
0 g
s
.40368 .68197 m .40256 .64503 L .37068 .64534 L p .707 .577 .707 r
F P
0 g
s
.40256 .64503 m .40368 .68197 L .43465 .67893 L p .707 .577 .707 r
F P
0 g
s
.43465 .67893 m .43354 .64199 L .40256 .64503 L p .707 .577 .707 r
F P
0 g
s
.65071 .64105 m .65116 .67843 L .6393 .68555 L p .707 .577 .707 r
F P
0 g
s
.3718 .68227 m .37068 .64534 L .34101 .64287 L p .707 .577 .707 r
F P
0 g
s
.37068 .64534 m .3718 .68227 L .40368 .68197 L p .707 .577 .707 r
F P
0 g
s
.32442 .55471 m .32271 .61044 L .34883 .61593 L p .707 .577 .707 r
F P
0 g
s
.32271 .61044 m .32442 .55471 L .30528 .54758 L p .707 .577 .707 r
F P
0 g
s
.66619 .55201 m .66548 .60706 L .64707 .61466 L p .707 .577 .707 r
F P
0 g
s
.43354 .64199 m .43465 .67893 L .46169 .67344 L p .707 .577 .707 r
F P
0 g
s
.46169 .67344 m .46057 .6365 L .43354 .64199 L p .707 .577 .707 r
F P
0 g
s
.46884 .55833 m .46713 .61406 L .48555 .60786 L p .707 .577 .707 r
F P
0 g
s
.48555 .60786 m .48726 .55213 L .46884 .55833 L p .707 .577 .707 r
F P
0 g
s
.83238 .64184 m .83282 .67922 L .81578 .67304 L p .707 .577 .707 r
F P
0 g
s
.81578 .67304 m .81534 .63566 L .83238 .64184 L p .707 .577 .707 r
F P
0 g
s
.64194 .73206 m .64123 .71306 L .65434 .70812 L p .707 .577 .707 r
F P
0 g
s
.34101 .64287 m .34212 .6798 L .3718 .68227 L p .707 .577 .707 r
F P
0 g
s
.34212 .6798 m .34101 .64287 L .31645 .63787 L p .707 .577 .707 r
F P
0 g
s
.66548 .60706 m .66619 .55201 L .69178 .54658 L p .707 .577 .707 r
F P
0 g
s
.65434 .70812 m .65506 .72712 L .64194 .73206 L p .707 .577 .707 r
F P
0 g
s
.81066 .55308 m .80995 .60814 L .78383 .60232 L p .707 .577 .707 r
F P
0 g
s
.78383 .60232 m .78454 .54727 L .81066 .55308 L p .707 .577 .707 r
F P
0 g
s
.40265 .72529 m .4008 .70701 L .36917 .70888 L p .707 .577 .707 r
F P
0 g
s
.4008 .70701 m .40265 .72529 L .43382 .72049 L p .707 .577 .707 r
F P
0 g
s
.43382 .72049 m .43196 .70221 L .4008 .70701 L p .707 .577 .707 r
F P
0 g
s
.30528 .54758 m .30357 .60331 L .32271 .61044 L p .707 .577 .707 r
F P
0 g
s
.83521 .70448 m .83593 .72347 L .82007 .71982 L p .707 .577 .707 r
F P
0 g
s
.82007 .71982 m .81935 .70082 L .83521 .70448 L p .707 .577 .707 r
F P
0 g
s
.65116 .67843 m .65071 .64105 L .67116 .63503 L p .707 .577 .707 r
F P
0 g
s
.37103 .72716 m .36917 .70888 L .3402 .70764 L p .707 .577 .707 r
F P
0 g
s
.36917 .70888 m .37103 .72716 L .40265 .72529 L p .707 .577 .707 r
F P
0 g
s
.46057 .6365 m .46169 .67344 L .48214 .66604 L p .707 .577 .707 r
F P
0 g
s
.48214 .66604 m .48102 .62911 L .46057 .6365 L p .707 .577 .707 r
F P
0 g
s
.43196 .70221 m .43382 .72049 L .46148 .71323 L p .707 .577 .707 r
F P
0 g
s
.46148 .71323 m .45962 .69495 L .43196 .70221 L p .707 .577 .707 r
F P
0 g
s
.31645 .63787 m .31757 .67481 L .34212 .6798 L p .707 .577 .707 r
F P
0 g
s
.3402 .70764 m .34205 .72591 L .37103 .72716 L p .707 .577 .707 r
F P
0 g
s
.30357 .60331 m .30528 .54758 L .29498 .5395 L p .707 .577 .707 r
F P
0 g
s
.67116 .63503 m .67161 .67241 L .65116 .67843 L p .707 .577 .707 r
F P
0 g
s
.69178 .54658 m .69107 .60163 L .66548 .60706 L p .707 .577 .707 r
F P
0 g
s
.69107 .60163 m .69178 .54658 L .72204 .54385 L p .707 .577 .707 r
F P
0 g
s
.31757 .67481 m .31645 .63787 L .29942 .63083 L p .707 .577 .707 r
F P
0 g
s
.48726 .55213 m .48555 .60786 L .49499 .60027 L p .707 .577 .707 r
F P
0 g
s
.49499 .60027 m .4967 .54454 L .48726 .55213 L p .707 .577 .707 r
F P
0 g
s
.78454 .54727 m .78383 .60232 L .75329 .59914 L p .707 .577 .707 r
F P
0 g
s
.75329 .59914 m .754 .54409 L .78454 .54727 L p .707 .577 .707 r
F P
0 g
s
.34205 .72591 m .3402 .70764 L .31669 .7034 L p .707 .577 .707 r
F P
0 g
s
.81534 .63566 m .81578 .67304 L .79121 .6685 L p .707 .577 .707 r
F P
0 g
s
.79121 .6685 m .79077 .63112 L .81534 .63566 L p .707 .577 .707 r
F P
0 g
s
.45962 .69495 m .46148 .71323 L .48293 .70422 L p .707 .577 .707 r
F P
0 g
s
.48293 .70422 m .48107 .68594 L .45962 .69495 L p .707 .577 .707 r
F P
0 g
s
.65506 .72712 m .65434 .70812 L .67581 .70372 L p .707 .577 .707 r
F P
0 g
s
.31669 .7034 m .31855 .72168 L .34205 .72591 L p .707 .577 .707 r
F P
0 g
s
.72133 .5989 m .72204 .54385 L .754 .54409 L p .707 .577 .707 r
F P
0 g
s
.72204 .54385 m .72133 .5989 L .69107 .60163 L p .707 .577 .707 r
F P
0 g
s
.754 .54409 m .75329 .59914 L .72133 .5989 L p .707 .577 .707 r
F P
0 g
s
.67581 .70372 m .67653 .72271 L .65506 .72712 L p .707 .577 .707 r
F P
0 g
s
.29942 .63083 m .30054 .66777 L .31757 .67481 L p .707 .577 .707 r
F P
0 g
s
.29498 .5395 m .29327 .59523 L .30357 .60331 L p .707 .577 .707 r
F P
0 g
s
.67161 .67241 m .67116 .63503 L .69821 .63072 L p .707 .577 .707 r
F P
0 g
s
.48102 .62911 m .48214 .66604 L .494 .65747 L p .707 .577 .707 r
F P
0 g
s
.494 .65747 m .49288 .62053 L .48102 .62911 L p .707 .577 .707 r
F P
0 g
s
.81935 .70082 m .82007 .71982 L .79642 .71741 L p .707 .577 .707 r
F P
0 g
s
.79642 .71741 m .7957 .69841 L .81935 .70082 L p .707 .577 .707 r
F P
0 g
s
.69821 .63072 m .69865 .6681 L .67161 .67241 L p .707 .577 .707 r
F P
0 g
s
.79077 .63112 m .79121 .6685 L .76153 .66604 L p .707 .577 .707 r
F P
0 g
s
.76153 .66604 m .76109 .62866 L .79077 .63112 L p .707 .577 .707 r
F P
0 g
s
.31855 .72168 m .31669 .7034 L .30097 .69659 L p .707 .577 .707 r
F P
0 g
s
.29327 .59523 m .29498 .5395 L .29453 .53126 L p .707 .578 .707 r
F P
0 g
s
.48107 .68594 m .48293 .70422 L .49606 .69435 L p .707 .577 .707 r
F P
0 g
s
.49606 .69435 m .49421 .67607 L .48107 .68594 L p .707 .577 .707 r
F P
0 g
s
.30054 .66777 m .29942 .63083 L .29158 .62244 L p .707 .577 .707 r
F P
0 g
s
.69865 .6681 m .69821 .63072 L .72919 .62852 L p .707 .577 .707 r
F P
0 g
s
.30097 .69659 m .30283 .71487 L .31855 .72168 L p .707 .577 .707 r
F P
0 g
s
.4967 .54454 m .49499 .60027 L .49454 .59203 L p .707 .578 .707 r
F P
0 g
s
.49454 .59203 m .49625 .5363 L .4967 .54454 L p .707 .578 .707 r
F P
0 g
s
.67653 .72271 m .67581 .70372 L .70354 .70027 L p .707 .577 .707 r
F P
0 g
s
.70354 .70027 m .70426 .71926 L .67653 .72271 L p .707 .577 .707 r
F P
0 g
s
.76109 .62866 m .76153 .66604 L .72963 .6659 L p .707 .577 .707 r
F P
0 g
s
.72963 .6659 m .72919 .62852 L .76109 .62866 L p .707 .577 .707 r
F P
0 g
s
.7957 .69841 m .79642 .71741 L .76729 .71647 L p .707 .577 .707 r
F P
0 g
s
.76729 .71647 m .76657 .69748 L .7957 .69841 L p .707 .577 .707 r
F P
0 g
s
.72919 .62852 m .72963 .6659 L .69865 .6681 L p .707 .577 .707 r
F P
0 g
s
.29158 .62244 m .29269 .65938 L .30054 .66777 L p .707 .577 .707 r
F P
0 g
s
.29453 .53126 m .29282 .58699 L .29327 .59523 L p .707 .578 .707 r
F P
0 g
s
.49288 .62053 m .494 .65747 L .49611 .64855 L p .707 .577 .707 r
F P
0 g
s
.49611 .64855 m .495 .61161 L .49288 .62053 L p .707 .577 .707 r
F P
0 g
s
.70426 .71926 m .70354 .70027 L .73482 .69812 L p .707 .577 .707 r
F P
0 g
s
.76657 .69748 m .76729 .71647 L .73553 .71711 L p .707 .577 .707 r
F P
0 g
s
.73553 .71711 m .73482 .69812 L .76657 .69748 L p .707 .577 .707 r
F P
0 g
s
.73482 .69812 m .73553 .71711 L .70426 .71926 L p .707 .577 .707 r
F P
0 g
s
.30283 .71487 m .30097 .69659 L .29456 .68787 L p .707 .577 .707 r
F P
0 g
s
.49421 .67607 m .49606 .69435 L .4996 .68457 L p .707 .577 .707 r
F P
0 g
s
.4996 .68457 m .49775 .66629 L .49421 .67607 L p .707 .577 .707 r
F P
0 g
s
.29269 .65938 m .29158 .62244 L .29369 .61352 L p .707 .577 .707 r
F P
0 g
s
.29456 .68787 m .29642 .70615 L .30283 .71487 L p .707 .577 .707 r
F P
0 g
s
.29282 .58699 m .29453 .53126 L .30397 .52367 L p .707 .577 .707 r
F P
0 g
s
.49625 .5363 m .49454 .59203 L .48424 .58395 L p .707 .577 .707 r
F P
0 g
s
.48424 .58395 m .48595 .52822 L .49625 .5363 L p .707 .577 .707 r
F P
0 g
s
.29369 .61352 m .29481 .65046 L .29269 .65938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30397 .52367 m .30226 .5794 L .29282 .58699 L p .707 .577 .707 r
F P
0 g
s
.495 .61161 m .49611 .64855 L .48827 .64016 L p .707 .577 .707 r
F P
0 g
s
.48827 .64016 m .48715 .60322 L .495 .61161 L p .707 .577 .707 r
F P
0 g
s
.29642 .70615 m .29456 .68787 L .2981 .6781 L p .707 .577 .707 r
F P
0 g
s
.49775 .66629 m .4996 .68457 L .4932 .67585 L p .707 .577 .707 r
F P
0 g
s
.4932 .67585 m .49134 .65757 L .49775 .66629 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30226 .5794 m .30397 .52367 L .32239 .51747 L p .707 .577 .707 r
F P
0 g
s
.2981 .6781 m .29996 .69637 L .29642 .70615 L p .707 .577 .707 r
F P
0 g
s
.29481 .65046 m .29369 .61352 L .30555 .60495 L p .707 .577 .707 r
F P
0 g
s
.48595 .52822 m .48424 .58395 L .46509 .57681 L p .707 .577 .707 r
F P
0 g
s
.46509 .57681 m .4668 .52108 L .48595 .52822 L p .707 .577 .707 r
F P
0 g
s
.30555 .60495 m .30667 .64188 L .29481 .65046 L p .707 .577 .707 r
F P
0 g
s
.32239 .51747 m .32068 .5732 L .30226 .5794 L p .707 .577 .707 r
F P
0 g
s
.48715 .60322 m .48827 .64016 L .47124 .63312 L p .707 .577 .707 r
F P
0 g
s
.47124 .63312 m .47012 .59618 L .48715 .60322 L p .707 .577 .707 r
F P
0 g
s
.29996 .69637 m .2981 .6781 L .31124 .66822 L p .707 .577 .707 r
F P
0 g
s
.32068 .5732 m .32239 .51747 L .34797 .51328 L p .707 .577 .707 r
F P
0 g
s
.49134 .65757 m .4932 .67585 L .47747 .66904 L p .707 .577 .707 r
F P
0 g
s
.47747 .66904 m .47562 .65076 L .49134 .65757 L p .707 .577 .707 r
F P
0 g
s
.4668 .52108 m .46509 .57681 L .43898 .57133 L p .707 .577 .707 r
F P
0 g
s
.43898 .57133 m .44069 .5156 L .4668 .52108 L p .707 .577 .707 r
F P
0 g
s
.30667 .64188 m .30555 .60495 L .326 .59755 L p .707 .577 .707 r
F P
0 g
s
.31124 .66822 m .31309 .6865 L .29996 .69637 L p .707 .577 .707 r
F P
0 g
s
.326 .59755 m .32712 .63449 L .30667 .64188 L p .707 .577 .707 r
F P
0 g
s
.34797 .51328 m .34626 .56901 L .32068 .5732 L p .707 .577 .707 r
F P
0 g
s
.47012 .59618 m .47124 .63312 L .44668 .62812 L p .707 .577 .707 r
F P
0 g
s
.44668 .62812 m .44557 .59119 L .47012 .59618 L p .707 .577 .707 r
F P
0 g
s
.34626 .56901 m .34797 .51328 L .37822 .51149 L p .707 .577 .707 r
F P
0 g
s
.44069 .5156 m .43898 .57133 L .40846 .56802 L p .707 .577 .707 r
F P
0 g
s
.40846 .56802 m .41017 .51229 L .44069 .5156 L p .707 .577 .707 r
F P
0 g
s
.31309 .6865 m .31124 .66822 L .33269 .65921 L p .707 .577 .707 r
F P
0 g
s
.32712 .63449 m .326 .59755 L .35304 .59206 L p .707 .577 .707 r
F P
0 g
s
.37651 .56722 m .37822 .51149 L .41017 .51229 L p .707 .577 .707 r
F P
0 g
s
.37822 .51149 m .37651 .56722 L .34626 .56901 L p .707 .577 .707 r
F P
0 g
s
.47562 .65076 m .47747 .66904 L .45397 .66481 L p .707 .577 .707 r
F P
0 g
s
.45397 .66481 m .45212 .64653 L .47562 .65076 L p .707 .577 .707 r
F P
0 g
s
.41017 .51229 m .40846 .56802 L .37651 .56722 L p .707 .577 .707 r
F P
0 g
s
.33269 .65921 m .33454 .67749 L .31309 .6865 L p .707 .577 .707 r
F P
0 g
s
.44557 .59119 m .44668 .62812 L .41701 .62565 L p .707 .577 .707 r
F P
0 g
s
.41701 .62565 m .4159 .58872 L .44557 .59119 L p .707 .577 .707 r
F P
0 g
s
.35304 .59206 m .35415 .629 L .32712 .63449 L p .707 .577 .707 r
F P
0 g
s
.35415 .629 m .35304 .59206 L .38401 .58902 L p .707 .577 .707 r
F P
0 g
s
.4159 .58872 m .41701 .62565 L .38513 .62596 L p .707 .577 .707 r
F P
0 g
s
.38513 .62596 m .38401 .58902 L .4159 .58872 L p .707 .577 .707 r
F P
0 g
s
.33454 .67749 m .33269 .65921 L .36035 .65196 L p .707 .577 .707 r
F P
0 g
s
.38401 .58902 m .38513 .62596 L .35415 .629 L p .707 .577 .707 r
F P
0 g
s
.45212 .64653 m .45397 .66481 L .42499 .66356 L p .707 .577 .707 r
F P
0 g
s
.42499 .66356 m .42314 .64529 L .45212 .64653 L p .707 .577 .707 r
F P
0 g
s
.36035 .65196 m .3622 .67023 L .33454 .67749 L p .707 .577 .707 r
F P
0 g
s
.3622 .67023 m .36035 .65196 L .39152 .64716 L p .707 .577 .707 r
F P
0 g
s
.42314 .64529 m .42499 .66356 L .39337 .66543 L p .707 .577 .707 r
F P
0 g
s
.39337 .66543 m .39152 .64716 L .42314 .64529 L p .707 .577 .707 r
F P
0 g
s
.39152 .64716 m .39337 .66543 L .3622 .67023 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo8@00O7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0065ooaT000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00GGoo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P002EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
05=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`0@OolA0013Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Woo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEPH003eoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00<003Uoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@003Eoo`00Dgoo00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001oogooOol200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000<goo001COol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@007oo000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000aOol005=oo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00Dgoo00<005YF0000
1EYF00<005YFFUH00eYF5`0015YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0002moo`00Dgoo00<005YF00001EYF00<005YF00000`000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00<005YFFUH00UYF00@005YFFUH0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00;Woo001COol00`00FUH00003FUH40006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`03001JEP0000<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`800003FUH005YF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
0005FUH005YFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002io
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJ
EP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH000AJEP03
001JEUYF00=JEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`04001JEUYF0004FUH60003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP00;Woo001DOol30003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005Ioo`@0009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000EJEP04001JEUYFFUH800000eYF0000000F0004FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo0011OolG0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEPD000AJEP03001JEUYF00IJEP03001JEP0000@0009J
EP03001JEUYF00EJEP03001JEUYF00D000AJEP04001JEUYF000^Ool003Uoo`P000AJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP08001JEUYFFUH005YF001JEP<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP04001JEUYF
000^Ool003Aoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080009JEP03001oogoo02aoo`00<Woo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<007ooOol0;7oo000`Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002ioo`00;Woo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00UYF00<005YFFUH015YF3`001eYF1`001EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP0500001EYF001JEUYF0000
1EYF1@001UYF00<005YFFUH015YF100000=JEP00FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH80004FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YF0000
;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP8000=JEP04001JEUYFFUH40004FUH00`00FUH00002FUH00`00FUIJEP03FUH50006FUH0
0`00FUIJEP08FUH30003FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH50003FUH00`00FUH0000^Ool002eoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
00000`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH00eYF
1@000eYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00006FUH00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008002moo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH30003FUH90002
FUH00`00FUIJEP04FUH30005FUH80003FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<002moo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUHN0005
FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000_Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUH000080004FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP020004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJ
EP00FUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03
001JEUYF00AJEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHE0004FUH00`00FUH000020007FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00@005YFFUIJEPP000AJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000=JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEPT000MJEP03
001JEP0000H000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP000eYF1@0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH00eYF1P001eYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH01@000UYF00<007ooOol01Goo
1@001goo20000eYF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01@00FUIJEP00FUH00P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YF0000
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF0P0000=JEP000000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YF
FUH02`0000=JEP00Ool01Woo1@0017oo2@000UYF1@000eYF00<005YF0000;Woo000]Ool00`00FUIJ
EP020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000eYF10001UYF00@005YFFUIJEQ8000AJEP03001JEUYF00EJEP04001JEUYF
FUH2000015YF001JEP00;Woo000]Ool40005FUH00`00FUIJEP04FUHH0004FUH01000FUIJEUYF2000
15YF00<005YFFUH00UYF40001eYF00<005YFFUH00eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001oo`0]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH01000FUH000000UYF00<005YFFUH00UYF3`001UYF00<005YFFUH02EYF00@005YFFUIJEP80
0004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000]Ool01000FUIJEP001EYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF1`0015YF0P000UYF00<005YFFUH00eYF
1@001UYF00<005YFFUH02EYF00@005YF000000AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;Goo00@005YFFUH0009JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEUYF001JEP000UYF0P001EYF0`000UYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH0
25YF0`0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000^Ool5
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00`0000=J
EP00FUH01EYF00<005YF00000`000UYF00<005YFFUH015YF0`001eYF00<005YFFUH01EYF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000_Ool30005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP@00003
FUH005YF00EJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHK0004FUH01000FUH00000;goo
000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP800004FUH000000006FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF1@00
1EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`00<Goo000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP@000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0;0003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000_Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF01L000IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@000=JEP03001JEUYF00AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP<002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000BOol400000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF00<005YFFUH00UYF20000goo1@002Goo3@000UYF00<005YF0000;Goo000]Ool01@00FUIJ
EUYF000015YF1@003Goo0`003Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP04001JEUYFFUH700001EYF001JEUYF00001Woo1@0037oo1`000UYF100000=JEP00
Ool0;7oo000]Ool01P00FUIJEUYF001JEP<0015oo`D0019ooaL000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH8
0004FUH00`00FUH00007Ool50003Ool90003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]
Ool01000FUIJEUYF0P0000=JEP0000003Woo2@004Woo0`000UYF0P000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800005FUH00000FUH00003FUHI0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool01000FUH000000eYF00<005YF00000`000Woo2000
15YF00<005YFFUH00UYF1P001goo1@000eYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;Goo0`0015YF00<005YF0000
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001P000eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
000`Ool002eoo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00;Goo00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<0
00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00H000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD003Moo`00;Goo00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEPH000MJEP03001J
EUYF00YJEPX000QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUHR000lOol0
02ioo`800003FUH005YF00AJEP03001JEUYF009JEPP000QJEPL000IJEP03001JEUYF00AJEP@00005
FUH005YFFUH00006FUH00`00FUIJEP05FUH7000<FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF00<005YF
0000Dgoo000]Ool01@00FUIJEUYF000015YF1P001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
0UYF00<005YFFUH015YF00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01@001UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF10001UYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00=JEP03001JEP0005=oo`00;Goo00H005YFFUIJEP00
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF1@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF
009JEP04001JEUYF001COol002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH01000FUIJEP00
0eYF0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF100000=JEP00FUH00eYF1P001EYF00<005YFFUH00UYF00@005YFFUH005=oo`00;Goo
00@005YFFUH0009oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000004FUH01@00FUIJEP00FUH00P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001o
ogoo00=oo`@00003FUH005YF00=JEP04001JEUYF001COol002eoo`<000Ioo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP80009JEP<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP80009JEP03001oogoo00=oo`L000=JEP04001JEUYF001COol002eoo`03
001oogoo00Yoo`D000AJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF009JEPD000=o
o`@00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH90003FUH01000FUIJEUYF0P0000EJEP00FUIJ
EP0005=oo`00;Goo0P0047oo6`002Woo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00P001eYF00<005YFFUH00eYF0P000UYF00<007ooOol0DGoo000/Ool00`00FUH0000HOol5000H
Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH0
0`00FUH00002001COol002aoo`03001JEP00008001Ioo`D001Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00=JEP03001JEUYF008005=oo`00;7oo00<0
05YF00000UYF0P005Goo0`006Goo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0P001eYF00<005YFFUH00eYF00@005YFFUH005Aoo`00;Goo0P0015YF0P00;Woo00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00FUH60002FUH00`00FUIJEP03FUH01000FUIJ
EP00E7oo000]Ool20004FUH01000FUH00000:goo00<005YFFUH00P000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P001UYF00<005YF00000`0015YF0`00EGoo000^Ool00`00FUIJEP02FUH01000FUIJ
EUYF0P009goo0`000UYF00<007oo00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00<0
05YFFUH00eYF0P0000=JEP000000Egoo000_Ool20002FUH00`00FUIJEP03FUH3000ROol20002FUH0
1000FUIJEP000Woo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH015YF0P00FGoo000aOol3
0006FUH00`00FUH00003000IOol50004FUH00`00FUH00005Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000060006FUH0
0`00FUIJEP04FUH01000FUH00000Egoo000cOol00`00FUIJEP04FUH00`00FUIJEP03FUHI0003FUH0
0`00FUIJEP03FUH20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`1DOol003Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00=JEPD000aoo`@000AJEP03001JEUYF009JEP8005Eoo`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8001Aoo`H0
009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<00003Ool00000
00<000moo`<00003FUH005YF00=JEP03001JEP0005Aoo`00>7oo10001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000001aoo`T000IJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000Eoo`D0019oo`<000=JEP03001JEP0005Aoo`00?7oo10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD002MooaT000aoo`D001Eoo`800004FUH005YF001DOol0041ooaP0
03Qoo`05001JEUYFFUH00006FUH00`00FUH000030009Ool3000HOol3001EOol0095oo`800003FUH0
05YF00EJEP03001JEUYF00=JEPL001Uoo`@00003FUH0000005Eoo`00Tgoo0`001EYF00<005YFFUH0
1EYF00<005YFFUH00UYF6@000UYF00<005YFFUH00P00EGoo002FOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EWoo002J
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00EWoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001GOol00:5oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
001IOol00:QooaT005aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62063 .74982 m .61791 .69456 L .586 .6957 L p .707 .577 .707 r
F P
0 g
s
.61791 .69456 m .62063 .74982 L .65131 .74591 L p .707 .577 .707 r
F P
0 g
s
.65131 .74591 m .6486 .69066 L .61791 .69456 L p .707 .577 .707 r
F P
0 g
s
.58872 .75096 m .586 .6957 L .55598 .69396 L p .707 .577 .707 r
F P
0 g
s
.586 .6957 m .58872 .75096 L .62063 .74982 L p .707 .577 .707 r
F P
0 g
s
.6486 .69066 m .65131 .74591 L .67776 .73962 L p .707 .577 .707 r
F P
0 g
s
.67776 .73962 m .67504 .68437 L .6486 .69066 L p .707 .577 .707 r
F P
0 g
s
.5587 .74922 m .55598 .69396 L .53079 .68951 L p .707 .577 .707 r
F P
0 g
s
.55598 .69396 m .5587 .74922 L .58872 .75096 L p .707 .577 .707 r
F P
0 g
s
.60666 .80807 m .60839 .77092 L .57688 .76822 L p .707 .577 .707 r
F P
0 g
s
.60839 .77092 m .60666 .80807 L .63823 .80821 L p .707 .577 .707 r
F P
0 g
s
.63823 .80821 m .63996 .77106 L .60839 .77092 L p .707 .577 .707 r
F P
0 g
s
.67504 .68437 m .67776 .73962 L .69738 .73156 L p .707 .577 .707 r
F P
0 g
s
.69738 .73156 m .69466 .6763 L .67504 .68437 L p .707 .577 .707 r
F P
0 g
s
.57515 .80537 m .57688 .76822 L .54852 .76323 L p .707 .577 .707 r
F P
0 g
s
.57688 .76822 m .57515 .80537 L .60666 .80807 L p .707 .577 .707 r
F P
0 g
s
.63996 .77106 m .63823 .80821 L .66678 .80578 L p .707 .577 .707 r
F P
0 g
s
.66678 .80578 m .6685 .76863 L .63996 .77106 L p .707 .577 .707 r
F P
0 g
s
.53079 .68951 m .5335 .74477 L .5587 .74922 L p .707 .577 .707 r
F P
0 g
s
.5335 .74477 m .53079 .68951 L .51289 .68279 L p .707 .577 .707 r
F P
0 g
s
.59325 .84691 m .59606 .82841 L .56533 .82223 L p .707 .577 .707 r
F P
0 g
s
.59606 .82841 m .59325 .84691 L .62478 .85088 L p .707 .577 .707 r
F P
0 g
s
.62478 .85088 m .62759 .83238 L .59606 .82841 L p .707 .577 .707 r
F P
0 g
s
.54852 .76323 m .54679 .80038 L .57515 .80537 L p .707 .577 .707 r
F P
0 g
s
.62759 .83238 m .62478 .85088 L .65404 .85225 L p .707 .577 .707 r
F P
0 g
s
.65404 .85225 m .65685 .83375 L .62759 .83238 L p .707 .577 .707 r
F P
0 g
s
.54679 .80038 m .54852 .76323 L .52608 .75643 L p .707 .577 .707 r
F P
0 g
s
.56533 .82223 m .56252 .84073 L .59325 .84691 L p .707 .577 .707 r
F P
0 g
s
.6685 .76863 m .66678 .80578 L .6895 .80102 L p .707 .577 .707 r
F P
0 g
s
.6895 .80102 m .69123 .76387 L .6685 .76863 L p .707 .577 .707 r
F P
0 g
s
.56252 .84073 m .56533 .82223 L .53842 .81445 L p .707 .577 .707 r
F P
0 g
s
.53842 .81445 m .53561 .83295 L .56252 .84073 L p .707 .577 .707 r
F P
0 g
s
.51289 .68279 m .51561 .73804 L .5335 .74477 L p .707 .577 .707 r
F P
0 g
s
.69466 .6763 m .69738 .73156 L .70826 .72251 L p .707 .577 .707 r
F P
0 g
s
.70826 .72251 m .70554 .66726 L .69466 .6763 L p .707 .577 .707 r
F P
0 g
s
.52608 .75643 m .52435 .79358 L .54679 .80038 L p .707 .577 .707 r
F P
0 g
s
.65685 .83375 m .65404 .85225 L .67815 .85088 L p .707 .577 .707 r
F P
0 g
s
.67815 .85088 m .68096 .83238 L .65685 .83375 L p .707 .577 .707 r
F P
0 g
s
.51561 .73804 m .51289 .68279 L .50404 .67445 L p .707 .577 .707 r
F P
0 g
s
.53561 .83295 m .53842 .81445 L .51797 .80582 L p .707 .577 .707 r
F P
0 g
s
.52435 .79358 m .52608 .75643 L .51175 .7485 L p .707 .577 .707 r
F P
0 g
s
.51797 .80582 m .51516 .82432 L .53561 .83295 L p .707 .577 .707 r
F P
0 g
s
.69123 .76387 m .6895 .80102 L .70417 .79439 L p .707 .577 .707 r
F P
0 g
s
.70417 .79439 m .7059 .75724 L .69123 .76387 L p .707 .577 .707 r
F P
0 g
s
.51175 .7485 m .51003 .78564 L .52435 .79358 L p .707 .577 .707 r
F P
0 g
s
.68096 .83238 m .67815 .85088 L .69477 .84692 L p .707 .577 .707 r
F P
0 g
s
.69477 .84692 m .69758 .82842 L .68096 .83238 L p .707 .577 .707 r
F P
0 g
s
.50404 .67445 m .50676 .7297 L .51561 .73804 L p .707 .577 .707 r
F P
0 g
s
.70554 .66726 m .70826 .72251 L .70932 .71338 L p .707 .577 .707 r
F P
0 g
s
.70932 .71338 m .7066 .65812 L .70554 .66726 L p .707 .577 .707 r
F P
0 g
s
.51516 .82432 m .51797 .80582 L .50596 .79719 L p .707 .577 .707 r
F P
0 g
s
.50596 .79719 m .50315 .81569 L .51516 .82432 L p .707 .577 .707 r
F P
0 g
s
.50676 .7297 m .50404 .67445 L .50511 .66531 L p .707 .577 .707 r
F P
0 g
s
.51003 .78564 m .51175 .7485 L .50696 .7402 L p .707 .577 .707 r
F P
0 g
s
.7059 .75724 m .70417 .79439 L .70936 .78654 L p .707 .577 .707 r
F P
0 g
s
.70936 .78654 m .71109 .7494 L .7059 .75724 L p .707 .577 .707 r
F P
0 g
s
.50696 .7402 m .50523 .77735 L .51003 .78564 L p .707 .577 .707 r
F P
0 g
s
.48366 .82167 m .48366 .31979 L .44017 .31655 L p .707 .577 .707 r
F P
0 g
s
.50511 .66531 m .50783 .72057 L .50676 .7297 L p .707 .577 .707 r
F P
0 g
s
.50315 .81569 m .50596 .79719 L .50359 .7894 L p .707 .577 .707 r
F P
0 g
s
.50359 .7894 m .50078 .8079 L .50315 .81569 L p .707 .577 .707 r
F P
0 g
s
.50783 .72057 m .50511 .66531 L .51599 .65627 L p .707 .577 .707 r
F P
0 g
s
.50523 .77735 m .50696 .7402 L .51215 .73235 L p .707 .577 .707 r
F P
0 g
s
.51215 .73235 m .51042 .7695 L .50523 .77735 L p .707 .577 .707 r
F P
0 g
s
.51599 .65627 m .5187 .71153 L .50783 .72057 L p .707 .577 .707 r
F P
0 g
s
.50078 .8079 m .50359 .7894 L .51107 .78322 L p .707 .577 .707 r
F P
0 g
s
.51107 .78322 m .50826 .80172 L .50078 .8079 L p .707 .577 .707 r
F P
0 g
s
.5187 .71153 m .51599 .65627 L .53561 .64821 L p .707 .577 .707 r
F P
0 g
s
.51042 .7695 m .51215 .73235 L .52682 .72572 L p .707 .577 .707 r
F P
0 g
s
.52682 .72572 m .52509 .76287 L .51042 .7695 L p .707 .577 .707 r
F P
0 g
s
.53561 .64821 m .53832 .70346 L .5187 .71153 L p .707 .577 .707 r
F P
0 g
s
.50826 .80172 m .51107 .78322 L .52769 .77926 L p .707 .577 .707 r
F P
0 g
s
.52769 .77926 m .52488 .79776 L .50826 .80172 L p .707 .577 .707 r
F P
0 g
s
.52488 .79776 m .52769 .77926 L .55181 .77789 L p .707 .577 .707 r
F P
0 g
s
.55181 .77789 m .549 .79639 L .52488 .79776 L p .707 .577 .707 r
F P
0 g
s
.48366 .31979 m .48366 .82167 L .52875 .82115 L p .707 .577 .707 r
F P
0 g
s
.52509 .76287 m .52682 .72572 L .54954 .72096 L p .707 .577 .707 r
F P
0 g
s
.54954 .72096 m .54781 .75811 L .52509 .76287 L p .707 .577 .707 r
F P
0 g
s
.52875 .82115 m .52875 .31926 L .48366 .31979 L p .707 .577 .707 r
F P
0 g
s
.69758 .82842 m .69477 .84692 L .70225 .84074 L p .707 .577 .707 r
F P
0 g
s
.70225 .84074 m .70506 .82224 L .69758 .82842 L p .707 .577 .707 r
F P
0 g
s
.53832 .70346 m .53561 .64821 L .56205 .64192 L p .707 .577 .707 r
F P
0 g
s
.56205 .64192 m .56477 .69717 L .53832 .70346 L p .707 .577 .707 r
F P
0 g
s
.54781 .75811 m .54954 .72096 L .57809 .71853 L p .707 .577 .707 r
F P
0 g
s
.57809 .71853 m .57636 .75568 L .54781 .75811 L p .707 .577 .707 r
F P
0 g
s
.549 .79639 m .55181 .77789 L .58106 .77926 L p .707 .577 .707 r
F P
0 g
s
.58106 .77926 m .57825 .79776 L .549 .79639 L p .707 .577 .707 r
F P
0 g
s
.52875 .31926 m .52875 .82115 L .57102 .81691 L p .707 .577 .707 r
F P
0 g
s
.56477 .69717 m .56205 .64192 L .59273 .63801 L p .707 .577 .707 r
F P
0 g
s
.59273 .63801 m .59545 .69326 L .56477 .69717 L p .707 .577 .707 r
F P
0 g
s
.57102 .81691 m .57102 .31502 L .52875 .31926 L p .707 .577 .707 r
F P
0 g
s
.7066 .65812 m .70932 .71338 L .70047 .70504 L p .707 .577 .707 r
F P
0 g
s
.70047 .70504 m .69776 .64979 L .7066 .65812 L p .707 .577 .707 r
F P
0 g
s
.44017 .81844 m .44017 .31655 L .40254 .30986 L p .707 .577 .707 r
F P
0 g
s
.44017 .31655 m .44017 .81844 L .48366 .82167 L p .707 .577 .707 r
F P
0 g
s
.62465 .63687 m .62737 .69213 L .59545 .69326 L p .707 .577 .707 r
F P
0 g
s
.59545 .69326 m .59273 .63801 L .62465 .63687 L p .707 .577 .707 r
F P
0 g
s
.57636 .75568 m .57809 .71853 L .60966 .71867 L p .707 .577 .707 r
F P
0 g
s
.60966 .71867 m .60793 .75582 L .57636 .75568 L p .707 .577 .707 r
F P
0 g
s
.57825 .79776 m .58106 .77926 L .6126 .78323 L p .707 .577 .707 r
F P
0 g
s
.6126 .78323 m .60979 .80173 L .57825 .79776 L p .707 .577 .707 r
F P
0 g
s
.57102 .31502 m .57102 .81691 L .60634 .80937 L p .707 .577 .707 r
F P
0 g
s
.60634 .80937 m .60634 .30748 L .57102 .31502 L p .707 .577 .707 r
F P
0 g
s
.71109 .7494 m .70936 .78654 L .70457 .77824 L p .707 .577 .707 r
F P
0 g
s
.70457 .77824 m .70629 .7411 L .71109 .7494 L p .707 .577 .707 r
F P
0 g
s
.27472 .70843 m .27362 .65211 L .24167 .65248 L p .707 .577 .707 r
F P
0 g
s
.27362 .65211 m .27472 .70843 L .30542 .70594 L p .707 .577 .707 r
F P
0 g
s
.30542 .70594 m .30432 .64962 L .27362 .65211 L p .707 .577 .707 r
F P
0 g
s
.24277 .7088 m .24167 .65248 L .21162 .65068 L p .707 .577 .707 r
F P
0 g
s
.24167 .65248 m .24277 .7088 L .27472 .70843 L p .707 .577 .707 r
F P
0 g
s
.70506 .82224 m .70225 .84074 L .69988 .83296 L p .707 .577 .707 r
F P
0 g
s
.69988 .83296 m .70269 .81445 L .70506 .82224 L p .707 .577 .707 r
F P
0 g
s
.40254 .81175 m .40254 .30986 L .37445 .30039 L p .707 .577 .707 r
F P
0 g
s
.40254 .30986 m .40254 .81175 L .44017 .81844 L p .707 .577 .707 r
F P
0 g
s
.30432 .64962 m .30542 .70594 L .33188 .70156 L p .707 .577 .707 r
F P
0 g
s
.33188 .70156 m .33078 .64524 L .30432 .64962 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69776 .64979 m .70047 .70504 L .68258 .69832 L p .707 .577 .707 r
F P
0 g
s
.68258 .69832 m .67986 .64306 L .69776 .64979 L p .707 .577 .707 r
F P
0 g
s
.21272 .707 m .21162 .65068 L .18639 .6469 L p .707 .577 .707 r
F P
0 g
s
.21162 .65068 m .21272 .707 L .24277 .7088 L p .707 .577 .707 r
F P
0 g
s
.64117 .72137 m .63944 .75852 L .60793 .75582 L p .707 .577 .707 r
F P
0 g
s
.60793 .75582 m .60966 .71867 L .64117 .72137 L p .707 .577 .707 r
F P
0 g
s
.64332 .78941 m .64051 .80791 L .60979 .80173 L p .707 .577 .707 r
F P
0 g
s
.60979 .80173 m .6126 .78323 L .64332 .78941 L p .707 .577 .707 r
F P
0 g
s
.60634 .30748 m .60634 .80937 L .63125 .79927 L p .707 .577 .707 r
F P
0 g
s
.65467 .63861 m .65739 .69387 L .62737 .69213 L p .707 .577 .707 r
F P
0 g
s
.62737 .69213 m .62465 .63687 L .65467 .63861 L p .707 .577 .707 r
F P
0 g
s
.63125 .79927 m .63125 .29738 L .60634 .30748 L p .707 .577 .707 r
F P
0 g
s
.26126 .77984 m .2619 .74345 L .23036 .74128 L p .707 .577 .707 r
F P
0 g
s
.2619 .74345 m .26126 .77984 L .29285 .77877 L p .707 .577 .707 r
F P
0 g
s
.29285 .77877 m .29349 .74238 L .2619 .74345 L p .707 .577 .707 r
F P
0 g
s
.18639 .6469 m .18749 .70322 L .21272 .707 L p .707 .577 .707 r
F P
0 g
s
.70629 .7411 m .70457 .77824 L .69024 .77031 L p .707 .577 .707 r
F P
0 g
s
.69024 .77031 m .69197 .73316 L .70629 .7411 L p .707 .577 .707 r
F P
0 g
s
.22972 .77767 m .23036 .74128 L .20196 .73608 L p .707 .577 .707 r
F P
0 g
s
.23036 .74128 m .22972 .77767 L .26126 .77984 L p .707 .577 .707 r
F P
0 g
s
.29349 .74238 m .29285 .77877 L .32141 .77457 L p .707 .577 .707 r
F P
0 g
s
.32141 .77457 m .32205 .73818 L .29349 .74238 L p .707 .577 .707 r
F P
0 g
s
.33078 .64524 m .33188 .70156 L .35151 .69573 L p .707 .577 .707 r
F P
0 g
s
.35151 .69573 m .35041 .63941 L .33078 .64524 L p .707 .577 .707 r
F P
0 g
s
.18749 .70322 m .18639 .6469 L .16847 .6415 L p .707 .577 .707 r
F P
0 g
s
.70269 .81445 m .69988 .83296 L .68788 .82432 L p .707 .577 .707 r
F P
0 g
s
.68788 .82432 m .69069 .80582 L .70269 .81445 L p .707 .577 .707 r
F P
0 g
s
.67986 .64306 m .68258 .69832 L .65739 .69387 L p .707 .577 .707 r
F P
0 g
s
.65739 .69387 m .65467 .63861 L .67986 .64306 L p .707 .577 .707 r
F P
0 g
s
.20196 .73608 m .20132 .77247 L .22972 .77767 L p .707 .577 .707 r
F P
0 g
s
.20132 .77247 m .20196 .73608 L .17948 .72837 L p .707 .577 .707 r
F P
0 g
s
.32205 .73818 m .32141 .77457 L .34414 .76765 L p .707 .577 .707 r
F P
0 g
s
.34414 .76765 m .34478 .73126 L .32205 .73818 L p .707 .577 .707 r
F P
0 g
s
.37445 .80227 m .37445 .30039 L .35865 .28904 L p .707 .577 .707 r
F P
0 g
s
.37445 .30039 m .37445 .80227 L .40254 .81175 L p .707 .577 .707 r
F P
0 g
s
.16847 .6415 m .16957 .69782 L .18749 .70322 L p .707 .577 .707 r
F P
0 g
s
.25188 .83312 m .25286 .81605 L .22179 .81129 L p .707 .577 .707 r
F P
0 g
s
.25286 .81605 m .25188 .83312 L .2837 .83335 L p .707 .577 .707 r
F P
0 g
s
.2837 .83335 m .28468 .81627 L .25286 .81605 L p .707 .577 .707 r
F P
0 g
s
.28468 .81627 m .2837 .83335 L .31314 .82902 L p .707 .577 .707 r
F P
0 g
s
.31314 .82902 m .31412 .81194 L .28468 .81627 L p .707 .577 .707 r
F P
0 g
s
.35041 .63941 m .35151 .69573 L .36238 .68902 L p .707 .577 .707 r
F P
0 g
s
.36238 .68902 m .36128 .6327 L .35041 .63941 L p .707 .577 .707 r
F P
0 g
s
.17948 .72837 m .17884 .76476 L .20132 .77247 L p .707 .577 .707 r
F P
0 g
s
.69197 .73316 m .69024 .77031 L .6678 .76351 L p .707 .577 .707 r
F P
0 g
s
.6678 .76351 m .66953 .72637 L .69197 .73316 L p .707 .577 .707 r
F P
0 g
s
.22081 .82836 m .22179 .81129 L .19449 .80246 L p .707 .577 .707 r
F P
0 g
s
.22179 .81129 m .22081 .82836 L .25188 .83312 L p .707 .577 .707 r
F P
0 g
s
.66953 .72637 m .6678 .76351 L .63944 .75852 L p .707 .577 .707 r
F P
0 g
s
.63944 .75852 m .64117 .72137 L .66953 .72637 L p .707 .577 .707 r
F P
0 g
s
.63125 .29738 m .63125 .79927 L .64332 .7876 L p .707 .577 .707 r
F P
0 g
s
.64332 .7876 m .64332 .28571 L .63125 .29738 L p .707 .577 .707 r
F P
0 g
s
.16957 .69782 m .16847 .6415 L .15959 .63502 L p .707 .577 .707 r
F P
0 g
s
.17884 .76476 m .17948 .72837 L .16513 .7189 L p .707 .577 .707 r
F P
0 g
s
.34478 .73126 m .34414 .76765 L .35881 .75868 L p .707 .577 .707 r
F P
0 g
s
.35881 .75868 m .35945 .7223 L .34478 .73126 L p .707 .577 .707 r
F P
0 g
s
.19449 .80246 m .19351 .81953 L .22081 .82836 L p .707 .577 .707 r
F P
0 g
s
.31412 .81194 m .31314 .82902 L .33731 .82055 L p .707 .577 .707 r
F P
0 g
s
.33731 .82055 m .33829 .80348 L .31412 .81194 L p .707 .577 .707 r
F P
0 g
s
.69069 .80582 m .68788 .82432 L .66742 .81569 L p .707 .577 .707 r
F P
0 g
s
.66742 .81569 m .67023 .79719 L .69069 .80582 L p .707 .577 .707 r
F P
0 g
s
.19351 .81953 m .19449 .80246 L .17364 .79043 L p .707 .577 .707 r
F P
0 g
s
.15959 .63502 m .16069 .69134 L .16957 .69782 L p .707 .577 .707 r
F P
0 g
s
.16513 .7189 m .16449 .75528 L .17884 .76476 L p .707 .577 .707 r
F P
0 g
s
.17364 .79043 m .17266 .8075 L .19351 .81953 L p .707 .577 .707 r
F P
0 g
s
.36128 .6327 m .36238 .68902 L .36343 .68208 L p .707 .577 .707 r
F P
0 g
s
.36343 .68208 m .36233 .62576 L .36128 .6327 L p .707 .577 .707 r
F P
0 g
s
.33829 .80348 m .33731 .82055 L .35387 .80879 L p .707 .577 .707 r
F P
0 g
s
.35387 .80879 m .35485 .79171 L .33829 .80348 L p .707 .577 .707 r
F P
0 g
s
.36117 .79487 m .36215 .77779 L .35485 .79171 L p .707 .577 .707 r
F P
0 g
s
.36233 .62576 m .36343 .68208 L .35456 .67559 L p .707 .577 .707 r
F P
0 g
s
.35456 .67559 m .35346 .61928 L .36233 .62576 L p .707 .577 .707 r
F P
0 g
s
.36215 .77779 m .36117 .79487 L .35852 .78016 L p .707 .577 .707 r
F P
0 g
s
.35852 .78016 m .3595 .76308 L .36215 .77779 L p .707 .577 .707 r
F P
0 g
s
.3598 .70186 m .35916 .73825 L .34481 .72877 L p .707 .577 .707 r
F P
0 g
s
.34481 .72877 m .34545 .69238 L .3598 .70186 L p .707 .577 .707 r
F P
0 g
s
.3595 .76308 m .35852 .78016 L .34616 .7661 L p .707 .577 .707 r
F P
0 g
s
.34616 .7661 m .34714 .74903 L .3595 .76308 L p .707 .577 .707 r
F P
0 g
s
.35865 .79093 m .35865 .28904 L .35668 .27694 L p .707 .577 .707 r
F P
0 g
s
.35945 .7223 m .35881 .75868 L .36399 .74855 L p .707 .577 .707 r
F P
0 g
s
.36399 .74855 m .36462 .71216 L .35945 .7223 L p .707 .577 .707 r
F P
0 g
s
.36462 .71216 m .36399 .74855 L .35916 .73825 L p .707 .577 .707 r
F P
0 g
s
.35916 .73825 m .3598 .70186 L .36462 .71216 L p .707 .577 .707 r
F P
0 g
s
.35865 .28904 m .35865 .79093 L .37445 .80227 L p .707 .577 .707 r
F P
0 g
s
.67023 .79719 m .66742 .81569 L .64051 .80791 L p .707 .577 .707 r
F P
0 g
s
.64051 .80791 m .64332 .78941 L .67023 .79719 L p .707 .577 .707 r
F P
0 g
s
.16069 .69134 m .15959 .63502 L .16065 .62808 L p .707 .577 .707 r
F P
0 g
s
.16449 .75528 m .16513 .7189 L .16031 .70859 L p .707 .577 .707 r
F P
0 g
s
.17266 .8075 m .17364 .79043 L .16128 .77637 L p .707 .577 .707 r
F P
0 g
s
.64332 .28571 m .64332 .7876 L .64135 .7755 L p .707 .577 .707 r
F P
0 g
s
.64135 .7755 m .64135 .27362 L .64332 .28571 L p .707 .577 .707 r
F P
0 g
s
.16128 .77637 m .1603 .79344 L .17266 .8075 L p .707 .577 .707 r
F P
0 g
s
.16065 .62808 m .16175 .6844 L .16069 .69134 L p .707 .577 .707 r
F P
0 g
s
.16031 .70859 m .15967 .74498 L .16449 .75528 L p .707 .577 .707 r
F P
0 g
s
.35485 .79171 m .35387 .80879 L .36117 .79487 L p .707 .577 .707 r
F P
0 g
s
.1603 .79344 m .16128 .77637 L .15863 .76166 L p .707 .577 .707 r
F P
0 g
s
.15967 .74498 m .16031 .70859 L .16548 .69846 L p .707 .577 .707 r
F P
0 g
s
.16175 .6844 m .16065 .62808 L .17152 .62136 L p .707 .577 .707 r
F P
0 g
s
.15863 .76166 m .15765 .77874 L .1603 .79344 L p .707 .577 .707 r
F P
0 g
s
.35668 .27694 m .35668 .77883 L .35865 .79093 L p .707 .577 .707 r
F P
0 g
s
.35668 .77883 m .35668 .27694 L .36875 .26528 L p .707 .577 .707 r
F P
0 g
s
.16548 .69846 m .16484 .73485 L .15967 .74498 L p .707 .577 .707 r
F P
0 g
s
.17152 .62136 m .17262 .67768 L .16175 .6844 L p .707 .577 .707 r
F P
0 g
s
.64135 .27362 m .64135 .7755 L .62555 .76416 L p .707 .577 .707 r
F P
0 g
s
.62555 .76416 m .62555 .26227 L .64135 .27362 L p .707 .577 .707 r
F P
0 g
s
.35346 .61928 m .35456 .67559 L .33663 .6702 L p .707 .577 .707 r
F P
0 g
s
.33663 .6702 m .33553 .61388 L .35346 .61928 L p .707 .577 .707 r
F P
0 g
s
.15765 .77874 m .15863 .76166 L .16593 .74774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16484 .73485 m .16548 .69846 L .18015 .68949 L p .707 .577 .707 r
F P
0 g
s
.17262 .67768 m .17152 .62136 L .19114 .61554 L p .707 .577 .707 r
F P
0 g
s
.16593 .74774 m .16495 .76482 L .15765 .77874 L p .707 .577 .707 r
F P
0 g
s
.18015 .68949 m .17951 .72588 L .16484 .73485 L p .707 .577 .707 r
F P
0 g
s
.19114 .61554 m .19224 .67185 L .17262 .67768 L p .707 .577 .707 r
F P
0 g
s
.33553 .61388 m .33663 .6702 L .31141 .66641 L p .707 .577 .707 r
F P
0 g
s
.31141 .66641 m .31031 .6101 L .33553 .61388 L p .707 .577 .707 r
F P
0 g
s
.36875 .76716 m .36875 .26528 L .39366 .25518 L p .707 .577 .707 r
F P
0 g
s
.36875 .26528 m .36875 .76716 L .35668 .77883 L p .707 .577 .707 r
F P
0 g
s
.16495 .76482 m .16593 .74774 L .18249 .73597 L p .707 .577 .707 r
F P
0 g
s
.19224 .67185 m .19114 .61554 L .2176 .61116 L p .707 .577 .707 r
F P
0 g
s
.17951 .72588 m .18015 .68949 L .20288 .68257 L p .707 .577 .707 r
F P
0 g
s
.34545 .69238 m .34481 .72877 L .32233 .72106 L p .707 .577 .707 r
F P
0 g
s
.32233 .72106 m .32297 .68467 L .34545 .69238 L p .707 .577 .707 r
F P
0 g
s
.18249 .73597 m .18151 .75305 L .16495 .76482 L p .707 .577 .707 r
F P
0 g
s
.62555 .26227 m .62555 .76416 L .59746 .75468 L p .707 .577 .707 r
F P
0 g
s
.59746 .75468 m .59746 .25279 L .62555 .26227 L p .707 .577 .707 r
F P
0 g
s
.2176 .61116 m .2187 .66748 L .19224 .67185 L p .707 .577 .707 r
F P
0 g
s
.31031 .6101 m .31141 .66641 L .28135 .66462 L p .707 .577 .707 r
F P
0 g
s
.28135 .66462 m .28025 .6083 L .31031 .6101 L p .707 .577 .707 r
F P
0 g
s
.20288 .68257 m .20224 .71896 L .17951 .72588 L p .707 .577 .707 r
F P
0 g
s
.34714 .74903 m .34616 .7661 L .32531 .75407 L p .707 .577 .707 r
F P
0 g
s
.32531 .75407 m .32629 .73699 L .34714 .74903 L p .707 .577 .707 r
F P
0 g
s
.2187 .66748 m .2176 .61116 L .24831 .60867 L p .707 .577 .707 r
F P
0 g
s
.18151 .75305 m .18249 .73597 L .20667 .72751 L p .707 .577 .707 r
F P
0 g
s
.20224 .71896 m .20288 .68257 L .23144 .67837 L p .707 .577 .707 r
F P
0 g
s
.32297 .68467 m .32233 .72106 L .29394 .71586 L p .707 .577 .707 r
F P
0 g
s
.29394 .71586 m .29457 .67948 L .32297 .68467 L p .707 .577 .707 r
F P
0 g
s
.28025 .6083 m .28135 .66462 L .24941 .66498 L p .707 .577 .707 r
F P
0 g
s
.24941 .66498 m .24831 .60867 L .28025 .6083 L p .707 .577 .707 r
F P
0 g
s
.24831 .60867 m .24941 .66498 L .2187 .66748 L p .707 .577 .707 r
F P
0 g
s
.20667 .72751 m .20569 .74459 L .18151 .75305 L p .707 .577 .707 r
F P
0 g
s
.39366 .25518 m .39366 .75707 L .36875 .76716 L p .707 .577 .707 r
F P
0 g
s
.39366 .75707 m .39366 .25518 L .42898 .24764 L p .707 .577 .707 r
F P
0 g
s
.75059 .66123 m .75169 .60656 L .71974 .60565 L p .707 .577 .707 r
F P
0 g
s
.75169 .60656 m .75059 .66123 L .78129 .65895 L p .707 .577 .707 r
F P
0 g
s
.78129 .65895 m .78239 .60429 L .75169 .60656 L p .707 .577 .707 r
F P
0 g
s
.71865 .66032 m .71974 .60565 L .68969 .60164 L p .707 .577 .707 r
F P
0 g
s
.71974 .60565 m .71865 .66032 L .75059 .66123 L p .707 .577 .707 r
F P
0 g
s
.23144 .67837 m .2308 .71476 L .20224 .71896 L p .707 .577 .707 r
F P
0 g
s
.2308 .71476 m .23144 .67837 L .26303 .67731 L p .707 .577 .707 r
F P
0 g
s
.29457 .67948 m .29394 .71586 L .2624 .71369 L p .707 .577 .707 r
F P
0 g
s
.2624 .71369 m .26303 .67731 L .29457 .67948 L p .707 .577 .707 r
F P
0 g
s
.32629 .73699 m .32531 .75407 L .29802 .74524 L p .707 .577 .707 r
F P
0 g
s
.29802 .74524 m .299 .72817 L .32629 .73699 L p .707 .577 .707 r
F P
0 g
s
.59746 .25279 m .59746 .75468 L .55983 .748 L p .707 .577 .707 r
F P
0 g
s
.55983 .748 m .55983 .24611 L .59746 .25279 L p .707 .577 .707 r
F P
0 g
s
.26303 .67731 m .2624 .71369 L .2308 .71476 L p .707 .577 .707 r
F P
0 g
s
.20569 .74459 m .20667 .72751 L .2361 .72318 L p .707 .577 .707 r
F P
0 g
s
.78239 .60429 m .78129 .65895 L .80776 .65371 L p .707 .577 .707 r
F P
0 g
s
.80776 .65371 m .80886 .59904 L .78239 .60429 L p .707 .577 .707 r
F P
0 g
s
.68859 .6563 m .68969 .60164 L .66446 .59491 L p .707 .577 .707 r
F P
0 g
s
.68969 .60164 m .68859 .6563 L .71865 .66032 L p .707 .577 .707 r
F P
0 g
s
.2361 .72318 m .23512 .74026 L .20569 .74459 L p .707 .577 .707 r
F P
0 g
s
.299 .72817 m .29802 .74524 L .26694 .74048 L p .707 .577 .707 r
F P
0 g
s
.26694 .74048 m .26792 .72341 L .299 .72817 L p .707 .577 .707 r
F P
0 g
s
.23512 .74026 m .2361 .72318 L .26792 .72341 L p .707 .577 .707 r
F P
0 g
s
.7376 .71099 m .73696 .6734 L .70542 .67281 L p .707 .577 .707 r
F P
0 g
s
.73696 .6734 m .7376 .71099 L .7692 .70945 L p .707 .577 .707 r
F P
0 g
s
.7692 .70945 m .76856 .67187 L .73696 .6734 L p .707 .577 .707 r
F P
0 g
s
.26792 .72341 m .26694 .74048 L .23512 .74026 L p .707 .577 .707 r
F P
0 g
s
.80886 .59904 m .80776 .65371 L .82738 .646 L p .707 .577 .707 r
F P
0 g
s
.82738 .646 m .82848 .59134 L .80886 .59904 L p .707 .577 .707 r
F P
0 g
s
.42898 .74953 m .42898 .24764 L .47125 .2434 L p .707 .577 .707 r
F P
0 g
s
.42898 .24764 m .42898 .74953 L .39366 .75707 L p .707 .577 .707 r
F P
0 g
s
.76856 .67187 m .7692 .70945 L .79776 .70595 L p .707 .577 .707 r
F P
0 g
s
.79776 .70595 m .79712 .66836 L .76856 .67187 L p .707 .577 .707 r
F P
0 g
s
.70606 .7104 m .70542 .67281 L .67703 .67016 L p .707 .577 .707 r
F P
0 g
s
.70542 .67281 m .70606 .7104 L .7376 .71099 L p .707 .577 .707 r
F P
0 g
s
.66446 .59491 m .66336 .64958 L .68859 .6563 L p .707 .577 .707 r
F P
0 g
s
.66336 .64958 m .66446 .59491 L .64654 .58614 L p .707 .577 .707 r
F P
0 g
s
.55983 .24611 m .55983 .748 L .51634 .74476 L p .707 .577 .707 r
F P
0 g
s
.51634 .74476 m .51634 .24287 L .55983 .24611 L p .707 .577 .707 r
F P
0 g
s
.73306 .73988 m .73208 .72072 L .701 .72181 L p .707 .577 .707 r
F P
0 g
s
.73208 .72072 m .73306 .73988 L .76488 .73808 L p .707 .577 .707 r
F P
0 g
s
.76488 .73808 m .7639 .71892 L .73208 .72072 L p .707 .577 .707 r
F P
0 g
s
.701 .72181 m .70198 .74097 L .73306 .73988 L p .707 .577 .707 r
F P
0 g
s
.67703 .67016 m .67766 .70775 L .70606 .7104 L p .707 .577 .707 r
F P
0 g
s
.7639 .71892 m .76488 .73808 L .79431 .73575 L p .707 .577 .707 r
F P
0 g
s
.79431 .73575 m .79333 .71659 L .7639 .71892 L p .707 .577 .707 r
F P
0 g
s
.70198 .74097 m .701 .72181 L .6737 .72208 L p .707 .577 .707 r
F P
0 g
s
.79712 .66836 m .79776 .70595 L .82048 .70081 L p .707 .577 .707 r
F P
0 g
s
.82048 .70081 m .81985 .66323 L .79712 .66836 L p .707 .577 .707 r
F P
0 g
s
.47125 .74529 m .47125 .2434 L .51634 .24287 L p .707 .577 .707 r
F P
0 g
s
.47125 .2434 m .47125 .74529 L .42898 .74953 L p .707 .577 .707 r
F P
0 g
s
.6737 .72208 m .67468 .74124 L .70198 .74097 L p .707 .577 .707 r
F P
0 g
s
.67766 .70775 m .67703 .67016 L .65455 .66571 L p .707 .577 .707 r
F P
0 g
s
.51634 .24287 m .51634 .74476 L .47125 .74529 L p .707 .577 .707 r
F P
0 g
s
.79333 .71659 m .79431 .73575 L .81849 .73311 L p .707 .577 .707 r
F P
0 g
s
.81849 .73311 m .81751 .71394 L .79333 .71659 L p .707 .577 .707 r
F P
0 g
s
.64654 .58614 m .64544 .64081 L .66336 .64958 L p .707 .577 .707 r
F P
0 g
s
.82848 .59134 m .82738 .646 L .83825 .6366 L p .707 .577 .707 r
F P
0 g
s
.83825 .6366 m .83935 .58193 L .82848 .59134 L p .707 .577 .707 r
F P
0 g
s
.65455 .66571 m .65519 .7033 L .67766 .70775 L p .707 .577 .707 r
F P
0 g
s
.64544 .64081 m .64654 .58614 L .63767 .57617 L p .707 .577 .707 r
F P
0 g
s
.67468 .74124 m .6737 .72208 L .65285 .7215 L p .707 .577 .707 r
F P
0 g
s
.65285 .7215 m .65383 .74066 L .67468 .74124 L p .707 .577 .707 r
F P
0 g
s
.81985 .66323 m .82048 .70081 L .83515 .69455 L p .707 .577 .707 r
F P
0 g
s
.83515 .69455 m .83452 .65697 L .81985 .66323 L p .707 .577 .707 r
F P
0 g
s
.65519 .7033 m .65455 .66571 L .6402 .65989 L p .707 .577 .707 r
F P
0 g
s
.81751 .71394 m .81849 .73311 L .83504 .73042 L p .707 .577 .707 r
F P
0 g
s
.83504 .73042 m .83406 .71125 L .81751 .71394 L p .707 .577 .707 r
F P
0 g
s
.6402 .65989 m .64084 .69747 L .65519 .7033 L p .707 .577 .707 r
F P
0 g
s
.63767 .57617 m .63657 .63084 L .64544 .64081 L p .707 .577 .707 r
F P
0 g
s
.83935 .58193 m .83825 .6366 L .8393 .62642 L p .707 .577 .707 r
F P
0 g
s
.8393 .62642 m .8404 .57175 L .83935 .58193 L p .707 .577 .707 r
F P
0 g
s
.65383 .74066 m .65285 .7215 L .6405 .72014 L p .707 .577 .707 r
F P
0 g
s
.6405 .72014 m .64148 .7393 L .65383 .74066 L p .707 .577 .707 r
F P
0 g
s
.63657 .63084 m .63767 .57617 L .63872 .56599 L p .707 .577 .707 r
F P
0 g
s
.83452 .65697 m .83515 .69455 L .84033 .68778 L p .707 .577 .707 r
F P
0 g
s
.84033 .68778 m .83969 .6502 L .83452 .65697 L p .707 .577 .707 r
F P
0 g
s
.64084 .69747 m .6402 .65989 L .63537 .65327 L p .707 .577 .707 r
F P
0 g
s
.83406 .71125 m .83504 .73042 L .84235 .72794 L p .707 .577 .707 r
F P
0 g
s
.84235 .72794 m .84137 .70878 L .83406 .71125 L p .707 .577 .707 r
F P
0 g
s
.63537 .65327 m .63601 .69085 L .64084 .69747 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63872 .56599 m .63762 .62066 L .63657 .63084 L p .707 .577 .707 r
F P
0 g
s
.8404 .57175 m .8393 .62642 L .83043 .61645 L p .707 .577 .707 r
F P
0 g
s
.83043 .61645 m .83153 .56179 L .8404 .57175 L p .707 .577 .707 r
F P
0 g
s
.64148 .7393 m .6405 .72014 L .63784 .71812 L p .707 .577 .707 r
F P
0 g
s
.63784 .71812 m .63882 .73728 L .64148 .7393 L p .707 .577 .707 r
F P
0 g
s
.63762 .62066 m .63872 .56599 L .64959 .55659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83969 .6502 m .84033 .68778 L .83551 .68116 L p .707 .577 .707 r
F P
0 g
s
.83551 .68116 m .83487 .64358 L .83969 .6502 L p .707 .577 .707 r
F P
0 g
s
.63601 .69085 m .63537 .65327 L .64055 .6465 L p .707 .577 .707 r
F P
0 g
s
.84137 .70878 m .84235 .72794 L .8397 .72592 L p .707 .577 .707 r
F P
0 g
s
.8397 .72592 m .83872 .70676 L .84137 .70878 L p .707 .577 .707 r
F P
0 g
s
.40455 .61995 m .40726 .56418 L .37535 .56245 L p .707 .577 .707 r
F P
0 g
s
.40726 .56418 m .40455 .61995 L .43523 .61912 L p .707 .577 .707 r
F P
0 g
s
.43523 .61912 m .43794 .56335 L .40726 .56418 L p .707 .577 .707 r
F P
0 g
s
.37263 .61823 m .37535 .56245 L .34533 .55834 L p .707 .577 .707 r
F P
0 g
s
.37535 .56245 m .37263 .61823 L .40455 .61995 L p .707 .577 .707 r
F P
0 g
s
.64055 .6465 m .64119 .68408 L .63601 .69085 L p .707 .577 .707 r
F P
0 g
s
.64959 .55659 m .64849 .61125 L .63762 .62066 L p .707 .577 .707 r
F P
0 g
s
.43794 .56335 m .43523 .61912 L .46167 .61581 L p .707 .577 .707 r
F P
0 g
s
.46167 .61581 m .46439 .56004 L .43794 .56335 L p .707 .577 .707 r
F P
0 g
s
.83153 .56179 m .83043 .61645 L .81251 .60768 L p .707 .577 .707 r
F P
0 g
s
.81251 .60768 m .81361 .55301 L .83153 .56179 L p .707 .577 .707 r
F P
0 g
s
.34261 .61411 m .34533 .55834 L .32014 .55224 L p .707 .577 .707 r
F P
0 g
s
.34533 .55834 m .34261 .61411 L .37263 .61823 L p .707 .577 .707 r
F P
0 g
s
.64849 .61125 m .64959 .55659 L .66921 .54889 L p .707 .577 .707 r
F P
0 g
s
.63882 .73728 m .63784 .71812 L .64515 .71564 L p .707 .577 .707 r
F P
0 g
s
.64515 .71564 m .64613 .73481 L .63882 .73728 L p .707 .577 .707 r
F P
0 g
s
.39207 .68287 m .39034 .64599 L .35883 .64589 L p .707 .577 .707 r
F P
0 g
s
.39034 .64599 m .39207 .68287 L .42364 .68016 L p .707 .577 .707 r
F P
0 g
s
.42364 .68016 m .42191 .64328 L .39034 .64599 L p .707 .577 .707 r
F P
0 g
s
.42191 .64328 m .42364 .68016 L .45218 .6749 L p .707 .577 .707 r
F P
0 g
s
.45218 .6749 m .45045 .63802 L .42191 .64328 L p .707 .577 .707 r
F P
0 g
s
.83487 .64358 m .83551 .68116 L .82115 .67534 L p .707 .577 .707 r
F P
0 g
s
.82115 .67534 m .82052 .63775 L .83487 .64358 L p .707 .577 .707 r
F P
0 g
s
.32014 .55224 m .31742 .60801 L .34261 .61411 L p .707 .577 .707 r
F P
0 g
s
.36056 .68277 m .35883 .64589 L .33047 .64299 L p .707 .577 .707 r
F P
0 g
s
.35883 .64589 m .36056 .68277 L .39207 .68287 L p .707 .577 .707 r
F P
0 g
s
.46439 .56004 m .46167 .61581 L .48129 .61035 L p .707 .577 .707 r
F P
0 g
s
.48129 .61035 m .48401 .55457 L .46439 .56004 L p .707 .577 .707 r
F P
0 g
s
.64119 .68408 m .64055 .6465 L .65522 .64024 L p .707 .577 .707 r
F P
0 g
s
.31742 .60801 m .32014 .55224 L .30224 .54475 L p .707 .577 .707 r
F P
0 g
s
.83872 .70676 m .8397 .72592 L .82734 .72456 L p .707 .577 .707 r
F P
0 g
s
.82734 .72456 m .82636 .7054 L .83872 .70676 L p .707 .577 .707 r
F P
0 g
s
.66921 .54889 m .66812 .60355 L .64849 .61125 L p .707 .577 .707 r
F P
0 g
s
.65522 .64024 m .65586 .67783 L .64119 .68408 L p .707 .577 .707 r
F P
0 g
s
.81361 .55301 m .81251 .60768 L .78728 .60095 L p .707 .577 .707 r
F P
0 g
s
.78728 .60095 m .78838 .54629 L .81361 .55301 L p .707 .577 .707 r
F P
0 g
s
.33047 .64299 m .33219 .67987 L .36056 .68277 L p .707 .577 .707 r
F P
0 g
s
.45045 .63802 m .45218 .6749 L .4749 .66762 L p .707 .577 .707 r
F P
0 g
s
.4749 .66762 m .47318 .63074 L .45045 .63802 L p .707 .577 .707 r
F P
0 g
s
.66812 .60355 m .66921 .54889 L .69568 .54364 L p .707 .577 .707 r
F P
0 g
s
.33219 .67987 m .33047 .64299 L .30802 .63757 L p .707 .577 .707 r
F P
0 g
s
.39021 .72729 m .3874 .70915 L .35667 .71119 L p .707 .577 .707 r
F P
0 g
s
.3874 .70915 m .39021 .72729 L .42174 .72212 L p .707 .577 .707 r
F P
0 g
s
.42174 .72212 m .41893 .70399 L .3874 .70915 L p .707 .577 .707 r
F P
0 g
s
.41893 .70399 m .42174 .72212 L .451 .71433 L p .707 .577 .707 r
F P
0 g
s
.451 .71433 m .44819 .69619 L .41893 .70399 L p .707 .577 .707 r
F P
0 g
s
.30224 .54475 m .29952 .60052 L .31742 .60801 L p .707 .577 .707 r
F P
0 g
s
.64613 .73481 m .64515 .71564 L .6617 .71295 L p .707 .577 .707 r
F P
0 g
s
.35667 .71119 m .35948 .72932 L .39021 .72729 L p .707 .577 .707 r
F P
0 g
s
.6617 .71295 m .66268 .73212 L .64613 .73481 L p .707 .577 .707 r
F P
0 g
s
.35948 .72932 m .35667 .71119 L .32977 .70989 L p .707 .577 .707 r
F P
0 g
s
.30802 .63757 m .30975 .67446 L .33219 .67987 L p .707 .577 .707 r
F P
0 g
s
.48401 .55457 m .48129 .61035 L .49217 .60327 L p .707 .577 .707 r
F P
0 g
s
.49217 .60327 m .49489 .54749 L .48401 .55457 L p .707 .577 .707 r
F P
0 g
s
.44819 .69619 m .451 .71433 L .47512 .70467 L p .707 .577 .707 r
F P
0 g
s
.47512 .70467 m .47231 .68654 L .44819 .69619 L p .707 .577 .707 r
F P
0 g
s
.82052 .63775 m .82115 .67534 L .79868 .67089 L p .707 .577 .707 r
F P
0 g
s
.79868 .67089 m .79804 .6333 L .82052 .63775 L p .707 .577 .707 r
F P
0 g
s
.78838 .54629 m .78728 .60095 L .75723 .59694 L p .707 .577 .707 r
F P
0 g
s
.75723 .59694 m .75832 .54227 L .78838 .54629 L p .707 .577 .707 r
F P
0 g
s
.65586 .67783 m .65522 .64024 L .67795 .63511 L p .707 .577 .707 r
F P
0 g
s
.29952 .60052 m .30224 .54475 L .29339 .5366 L p .707 .577 .707 r
F P
0 g
s
.32977 .70989 m .33258 .72802 L .35948 .72932 L p .707 .577 .707 r
F P
0 g
s
.69458 .59831 m .69568 .54364 L .72638 .54136 L p .707 .577 .707 r
F P
0 g
s
.69568 .54364 m .69458 .59831 L .66812 .60355 L p .707 .577 .707 r
F P
0 g
s
.47318 .63074 m .4749 .66762 L .48958 .65902 L p .707 .577 .707 r
F P
0 g
s
.48958 .65902 m .48785 .62213 L .47318 .63074 L p .707 .577 .707 r
F P
0 g
s
.82636 .7054 m .82734 .72456 L .80649 .72398 L p .707 .577 .707 r
F P
0 g
s
.80649 .72398 m .80551 .70482 L .82636 .7054 L p .707 .577 .707 r
F P
0 g
s
.30975 .67446 m .30802 .63757 L .2937 .63017 L p .707 .577 .707 r
F P
0 g
s
.67795 .63511 m .67858 .67269 L .65586 .67783 L p .707 .577 .707 r
F P
0 g
s
.75832 .54227 m .75723 .59694 L .72528 .59603 L p .707 .577 .707 r
F P
0 g
s
.72528 .59603 m .72638 .54136 L .75832 .54227 L p .707 .577 .707 r
F P
0 g
s
.72638 .54136 m .72528 .59603 L .69458 .59831 L p .707 .577 .707 r
F P
0 g
s
.33258 .72802 m .32977 .70989 L .30931 .70539 L p .707 .577 .707 r
F P
0 g
s
.29339 .5366 m .29067 .59237 L .29952 .60052 L p .707 .577 .707 r
F P
0 g
s
.47231 .68654 m .47512 .70467 L .49173 .6941 L p .707 .577 .707 r
F P
0 g
s
.49173 .6941 m .48892 .67597 L .47231 .68654 L p .707 .577 .707 r
F P
0 g
s
.30931 .70539 m .31212 .72352 L .33258 .72802 L p .707 .577 .707 r
F P
0 g
s
.2937 .63017 m .29543 .66706 L .30975 .67446 L p .707 .577 .707 r
F P
0 g
s
.66268 .73212 m .6617 .71295 L .68588 .71031 L p .707 .577 .707 r
F P
0 g
s
.68588 .71031 m .68686 .72947 L .66268 .73212 L p .707 .577 .707 r
F P
0 g
s
.79804 .6333 m .79868 .67089 L .77028 .66824 L p .707 .577 .707 r
F P
0 g
s
.77028 .66824 m .76964 .63065 L .79804 .6333 L p .707 .577 .707 r
F P
0 g
s
.67858 .67269 m .67795 .63511 L .70651 .6316 L p .707 .577 .707 r
F P
0 g
s
.49489 .54749 m .49217 .60327 L .49324 .59526 L p .707 .577 .707 r
F P
0 g
s
.49324 .59526 m .49595 .53949 L .49489 .54749 L p .707 .577 .707 r
F P
0 g
s
.70651 .6316 m .70714 .66919 L .67858 .67269 L p .707 .577 .707 r
F P
0 g
s
.29067 .59237 m .29339 .5366 L .29446 .52859 L p .707 .577 .707 r
F P
0 g
s
.80551 .70482 m .80649 .72398 L .77919 .72425 L p .707 .577 .707 r
F P
0 g
s
.77919 .72425 m .77821 .70509 L .80551 .70482 L p .707 .577 .707 r
F P
0 g
s
.48785 .62213 m .48958 .65902 L .49477 .64994 L p .707 .577 .707 r
F P
0 g
s
.49477 .64994 m .49304 .61306 L .48785 .62213 L p .707 .577 .707 r
F P
0 g
s
.76964 .63065 m .77028 .66824 L .73874 .66765 L p .707 .577 .707 r
F P
0 g
s
.73874 .66765 m .7381 .63007 L .76964 .63065 L p .707 .577 .707 r
F P
0 g
s
.29543 .66706 m .2937 .63017 L .2889 .62151 L p .707 .577 .707 r
F P
0 g
s
.70714 .66919 m .70651 .6316 L .7381 .63007 L p .707 .577 .707 r
F P
0 g
s
.31212 .72352 m .30931 .70539 L .29731 .69812 L p .707 .577 .707 r
F P
0 g
s
.68686 .72947 m .68588 .71031 L .71532 .70798 L p .707 .577 .707 r
F P
0 g
s
.7381 .63007 m .73874 .66765 L .70714 .66919 L p .707 .577 .707 r
F P
0 g
s
.71532 .70798 m .7163 .72714 L .68686 .72947 L p .707 .577 .707 r
F P
0 g
s
.48892 .67597 m .49173 .6941 L .49922 .68364 L p .707 .577 .707 r
F P
0 g
s
.49922 .68364 m .49641 .66551 L .48892 .67597 L p .707 .577 .707 r
F P
0 g
s
.29731 .69812 m .30012 .71625 L .31212 .72352 L p .707 .577 .707 r
F P
0 g
s
.29446 .52859 m .29174 .58437 L .29067 .59237 L p .707 .577 .707 r
F P
0 g
s
.2889 .62151 m .29063 .65839 L .29543 .66706 L p .707 .577 .707 r
F P
0 g
s
.77821 .70509 m .77919 .72425 L .74811 .72534 L p .707 .577 .707 r
F P
0 g
s
.74811 .72534 m .74713 .70618 L .77821 .70509 L p .707 .577 .707 r
F P
0 g
s
.7163 .72714 m .71532 .70798 L .74713 .70618 L p .707 .577 .707 r
F P
0 g
s
.74713 .70618 m .74811 .72534 L .7163 .72714 L p .707 .577 .707 r
F P
0 g
s
.49595 .53949 m .49324 .59526 L .48439 .58711 L p .707 .577 .707 r
F P
0 g
s
.48439 .58711 m .48711 .53134 L .49595 .53949 L p .707 .577 .707 r
F P
0 g
s
.29174 .58437 m .29446 .52859 L .30533 .52151 L p .707 .577 .707 r
F P
0 g
s
.49304 .61306 m .49477 .64994 L .48997 .64128 L p .707 .577 .707 r
F P
0 g
s
.48997 .64128 m .48824 .6044 L .49304 .61306 L p .707 .577 .707 r
F P
0 g
s
.30012 .71625 m .29731 .69812 L .29493 .6888 L p .707 .578 .707 r
F P
0 g
s
.29063 .65839 m .2889 .62151 L .2941 .61243 L p .707 .577 .707 r
F P
0 g
s
.49641 .66551 m .49922 .68364 L .49684 .67432 L p .707 .578 .707 r
F P
0 g
s
.49684 .67432 m .49403 .65619 L .49641 .66551 L p .707 .578 .707 r
F P
0 g
s
.29493 .6888 m .29774 .70694 L .30012 .71625 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30533 .52151 m .30262 .57729 L .29174 .58437 L p .707 .577 .707 r
F P
0 g
s
.2941 .61243 m .29582 .64932 L .29063 .65839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48711 .53134 m .48439 .58711 L .46649 .57962 L p .707 .577 .707 r
F P
0 g
s
.46649 .57962 m .46921 .52385 L .48711 .53134 L p .707 .577 .707 r
F P
0 g
s
.30262 .57729 m .30533 .52151 L .32496 .51605 L p .707 .577 .707 r
F P
0 g
s
.48824 .6044 m .48997 .64128 L .47565 .63388 L p .707 .577 .707 r
F P
0 g
s
.47565 .63388 m .47392 .59699 L .48824 .6044 L p .707 .577 .707 r
F P
0 g
s
.29774 .70694 m .29493 .6888 L .30242 .67835 L p .707 .577 .707 r
F P
0 g
s
.29582 .64932 m .2941 .61243 L .30877 .60383 L p .707 .577 .707 r
F P
0 g
s
.49403 .65619 m .49684 .67432 L .48484 .66706 L p .707 .577 .707 r
F P
0 g
s
.48484 .66706 m .48203 .64893 L .49403 .65619 L p .707 .577 .707 r
F P
0 g
s
.30242 .67835 m .30523 .69648 L .29774 .70694 L p .707 .577 .707 r
F P
0 g
s
.32496 .51605 m .32224 .57182 L .30262 .57729 L p .707 .577 .707 r
F P
0 g
s
.30877 .60383 m .3105 .64072 L .29582 .64932 L p .707 .577 .707 r
F P
0 g
s
.46921 .52385 m .46649 .57962 L .4413 .57352 L p .707 .577 .707 r
F P
0 g
s
.4413 .57352 m .44402 .51775 L .46921 .52385 L p .707 .577 .707 r
F P
0 g
s
.32224 .57182 m .32496 .51605 L .3514 .51274 L p .707 .577 .707 r
F P
0 g
s
.47392 .59699 m .47565 .63388 L .45321 .62846 L p .707 .577 .707 r
F P
0 g
s
.45321 .62846 m .45148 .59158 L .47392 .59699 L p .707 .577 .707 r
F P
0 g
s
.3105 .64072 m .30877 .60383 L .33149 .59655 L p .707 .577 .707 r
F P
0 g
s
.30523 .69648 m .30242 .67835 L .31903 .66777 L p .707 .577 .707 r
F P
0 g
s
.3514 .51274 m .34868 .56851 L .32224 .57182 L p .707 .577 .707 r
F P
0 g
s
.48203 .64893 m .48484 .66706 L .46438 .66256 L p .707 .577 .707 r
F P
0 g
s
.46438 .66256 m .46157 .64442 L .48203 .64893 L p .707 .577 .707 r
F P
0 g
s
.31903 .66777 m .32184 .68591 L .30523 .69648 L p .707 .577 .707 r
F P
0 g
s
.44402 .51775 m .4413 .57352 L .41128 .56941 L p .707 .577 .707 r
F P
0 g
s
.41128 .56941 m .414 .51363 L .44402 .51775 L p .707 .577 .707 r
F P
0 g
s
.34868 .56851 m .3514 .51274 L .38208 .51191 L p .707 .577 .707 r
F P
0 g
s
.33149 .59655 m .33322 .63343 L .3105 .64072 L p .707 .577 .707 r
F P
0 g
s
.414 .51363 m .41128 .56941 L .37936 .56768 L p .707 .577 .707 r
F P
0 g
s
.37936 .56768 m .38208 .51191 L .414 .51363 L p .707 .577 .707 r
F P
0 g
s
.38208 .51191 m .37936 .56768 L .34868 .56851 L p .707 .577 .707 r
F P
0 g
s
.45148 .59158 m .45321 .62846 L .42484 .62556 L p .707 .577 .707 r
F P
0 g
s
.42484 .62556 m .42312 .58868 L .45148 .59158 L p .707 .577 .707 r
F P
0 g
s
.33322 .63343 m .33149 .59655 L .36004 .59129 L p .707 .577 .707 r
F P
0 g
s
.32184 .68591 m .31903 .66777 L .34315 .65812 L p .707 .577 .707 r
F P
0 g
s
.46157 .64442 m .46438 .66256 L .43748 .66126 L p .707 .577 .707 r
F P
0 g
s
.43748 .66126 m .43467 .64313 L .46157 .64442 L p .707 .577 .707 r
F P
0 g
s
.36004 .59129 m .36176 .62818 L .33322 .63343 L p .707 .577 .707 r
F P
0 g
s
.34315 .65812 m .34596 .67625 L .32184 .68591 L p .707 .577 .707 r
F P
0 g
s
.42312 .58868 m .42484 .62556 L .39333 .62546 L p .707 .577 .707 r
F P
0 g
s
.39333 .62546 m .39161 .58858 L .42312 .58868 L p .707 .577 .707 r
F P
0 g
s
.36176 .62818 m .36004 .59129 L .39161 .58858 L p .707 .577 .707 r
F P
0 g
s
.39161 .58858 m .39333 .62546 L .36176 .62818 L p .707 .577 .707 r
F P
0 g
s
.34596 .67625 m .34315 .65812 L .37241 .65032 L p .707 .577 .707 r
F P
0 g
s
.43467 .64313 m .43748 .66126 L .40675 .66329 L p .707 .577 .707 r
F P
0 g
s
.40675 .66329 m .40394 .64516 L .43467 .64313 L p .707 .577 .707 r
F P
0 g
s
.37241 .65032 m .37522 .66846 L .34596 .67625 L p .707 .577 .707 r
F P
0 g
s
.37522 .66846 m .37241 .65032 L .40394 .64516 L p .707 .577 .707 r
F P
0 g
s
.40394 .64516 m .40675 .66329 L .37522 .66846 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001POolA0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001FOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol005=oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
4Goo2@00BWoo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02goo1P0015YF00<0
05YFFUH00UYF2@00@Goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01goo1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo001COol01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00=goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomo
o`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<003Aoo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001oo`000004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH00000<Woo001BOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000`Ool0059oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP8002moo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;goo001BOol01@00
FUIJEUYF00000eYF1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Woo001BOol01P00FUIJEUYF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEPH000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000;Woo001BOol01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000^Ool0059oo`04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH0009JEP03001J
EUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000;Woo001BOol01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00004@001UYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH01000FUIJEUYF200015YF00<0
05YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0002ioo`00Dgoo0`0015YF00<005YFFUH0
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0100000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH0000^Ool005Eoo`80009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH80006Ool50006Ool60005FUH00`00FUIJEP03FUH00`00FUH0000^Ool005Moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
0080009JEP04001JEUYFFUH<0008Ool50005Ool;00000eYF001JEP04FUH00`00FUH0000^Ool005Io
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUH000020007FUH01000FUIJEUYF4P0015YF00<005YFFUH015YF0P00
1EYF00<005YF0000;Woo000lOolJ00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P000UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YF0000
00=JEP03001JEP0002ioo`00>7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800004FUH005YF000^
Ool003Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH0100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP00Ool0;Goo000`Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00800003
FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool002ioo`<000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUH00000;Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF1P0015YF0`001eYF00<0
05YFFUH01P001EYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool0
1000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00<005YFFUH01@000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH01UYF
100000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEP0001T000IJEP03001JEUYF00=J
EP04001JEUYF000^Ool002eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF009JEP@000=JEP80009JEP03001JEUYF00=J
EPD000IJEP03001JEUYF00IJEP<00003FUH0000000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH01P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPP000EJEP04001JEUYF000^Ool002eoo`04001JEUYF0005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001J
EP000080009JEP03001JEUYF009JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00H000AJ
EP05001JEP00001JEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF100000EJEP00FUIJEP0002ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF2P000UYF0P000UYF00<0
05YFFUH015YF0`0000=JEP0000002P0000=JEP00FUH015YF00@005YFFUIJEP<000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPD002moo`00;Goo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP07001JEUYF001JEP00
FUH00P001EYF00<005YFFUH00UYF5@0015YF00@005YFFUIJEPP000AJEP8000EJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
008002moo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02ioo`00;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP800003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP02FUH00`00FUIJEP030006FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000]Ool01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEQH0009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00D005YFFUIJEP0000AJEP03001J
EUYF00AJEQP000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05001J
EUYFFUH00004FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000015YF0000
00001eYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
15YF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80003Ool500000goo0000000=0004FUH0
1000FUIJEUYF0P00;Woo000]Ool01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH0
1UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF8@000eYF00<005YFFUH00`00
00=JEP00FUH00UYF0P00;Woo000]Ool01000FUIJEUYF0`0000=JEP00FUH01EYF00@005YFFUIJEPl0
00IJEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00@000IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP8002ioo`00;Goo00@005YF000000AJEP03
001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEPL000EJEP04001JEUYFFUH30004FUH0
0`00FUIJEP06FUH30002FUH7000:FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003000^Ool0
02eoo`800003FUH005YF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00EJEP04001JEP000003FUHB0005FUH00`00FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF
009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP0015YF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF1P000UYF00<005YF00000UYF00<005YF
FUH00eYF1@001UYF00<005YFFUH02EYF0P0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo
00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0002FUH30005FUH300001EYF001JEUYF00001EYF1@001UYF00<005YFFUH01EYF100000=JEP00
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000^Ool60005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH30007FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEP000002FUH00`00FUIJEP04
FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP06FUH01000FUIJEP001eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF0000031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF100015YF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF
00MJEP<000=JEP03001JEUYF00EJEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002ioo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00006FUH00000001JEP001UYF00@005YF
FUH0009JEP03001JEUYF00AJEP04001JEUYFFUH60006FUH00`00FUIJEP04FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP05FUHO000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00004FUH005YFFUH700001EYF001JEUYF0000
0UYF00<005YF0000200015YF00<005YFFUH01UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEQ4000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP<00003FUH005YF00AJEP04
001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000aJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH60002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80009Ool70002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJ
EP02FUH6000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool20004FUH00`00FUH00002
0007Ool@0009Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=J
EP03001JEUYF008002eoo`00;Goo0P000eYF0`0017oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
10001goo0`0000=JEP00FUH01UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHB0007FUH00`00FUIJEP04FUH8000]Ool002eoo`800004FUH0
0000FUH20002Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool>0004
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`<000=JEP04001JEP00
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030002Ool40000
0eYF000000020002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEPT000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000bOol002eoo`8000AJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJ
EP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF4000>7oo000]Ool20003FUH2
0006FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH30003FUH01000FUIJEP000UYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF7`00B7oo000]Ool200001EYF000005YF00001EYF
1P000UYF00<005YFFUH00UYF40001UYF00<005YFFUH00P0000EJEP00FUIJEP00009JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`<000=J
EP04001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00
FUIJEP02FUH20002FUH01000FUIJEP001UYF00<005YFFUH01eYF00@005YFFUIJEPH000IJEP03001J
EUYF00YJEP03001JEUYF00T000MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH2001COol002ioo`8000=JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH200001EYF
001JEUYF00001UYF00<005YFFUH01EYF1`002eYF00<005YFFUH02UYF00<005YFFUH02EYF1@000UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00L005YFFUIJEP00
FUH0001BOol002ioo`8000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo0P000UYF
0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo1P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF100000=JEP00FUH00eYF1@000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
001BOol002eoo`8000=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYF001JEP020006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
15YF00<007ooOol00Woo10001EYF00L005YFFUIJEP00FUH0001BOol002eoo`03001oogoo00Aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP800004Ool005YF0002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH01000Oomoogoo2@0000=JEP00
FUH00UYF0P00Dgoo000/Ool2000:Ool30006FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH0
0`00FUH000020003Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF1`0015YF
00<005YFFUH00UYF0P000eYF0P00Dgoo000/Ool2000=Ool40002FUH00`00FUIJEP03FUH50007FUH0
0`00FUIJEP02FUH50007Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF
00<005YFFUH00eYF0`0000=JEP000000Dgoo000/Ool3000@OolI000=Ool00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF00<005YFFUH00eYF00<005YFFUH00`00Dgoo
000/Ool200000eYF001oo`0FOol5000IOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP001eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000/Ool20002FUH00`00
Oomoo`0EOol3000JOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
1eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000]Ool01@00FUIJEUYF0000<Woo0P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P001EYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0DWoo000]Ool01000FUIJEUYF0`00<7oo00<005YF00000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH0100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00;Woo
00@005YFFUH0009JEP03001oogoo02aoo`800006FUH00000001JEP001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH015YF0`0015YF00@005YF000005Ioo`00;goo00<005YF00000eYF0P00:Woo0P0000=J
EP0000000goo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF0`0000AJEP00000005Qo
o`00<7oo0P001EYF0P009Woo0P000eYF0P0017oo0P001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF
00EJEP03001JEUYF008005Yoo`00<Goo00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00
FUH00UYF00<007ooOol01Goo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00002@001EYF00<005YFFUH00eYF0P00F7oo000b
Ool20003FUH00`00FUIJEP03FUH4000FOol40005FUH01000FUIJEP0037oo1@0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10002Woo100000=JEP00FUH01EYF
0`00EWoo000dOol01000FUIJEP001eYF00<005YF00000`003Woo10000UYF00<005YFFUH00eYF00@0
05YF0000019oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000ioo`8000IJEP04001JEUYF001EOol003Eoo`<000MJEP03001JEUYF00=JEPh000IJEP03001J
EUYF00=JEP8001Yoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`8000=J
EP05001JEUYFFUH0001EOol003Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP8002=ooaX0009JEP@000Ioo`D0019oo`800003FUH005YF009JEP8005Ao
o`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=7oo
0P0015YF00<005YFFUH01EYF00<005YFFUH010000goo0`005Goo0P000UYF00<005YF0000E7oo000m
Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000iOol300000eYF001JEP06FUH00`00FUIJ
EP04FUH7000FOol300000eYF001oo`1COol004=ooa80049oo`<000EJEP03001JEUYF00MJEP03001J
EUYF009JEPP000Qoo`H0009JEP8005Eoo`00VWoo0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEPP000=JEP03001JEUYF009JEP8005Eoo`00W7oo0P0000=JEP00FUH01eYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009ioo`H000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Eo
o`00Y7oo2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000EWoo002]Ool80004
FUH01000FUIJEUYF1P00FWoo002eOol8001POol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62063 .74982 m .61791 .69456 L .586 .6957 L p .707 .577 .707 r
F P
0 g
s
.61791 .69456 m .62063 .74982 L .65131 .74591 L p .707 .577 .707 r
F P
0 g
s
.65131 .74591 m .6486 .69066 L .61791 .69456 L p .707 .577 .707 r
F P
0 g
s
.58872 .75096 m .586 .6957 L .55598 .69396 L p .707 .577 .707 r
F P
0 g
s
.586 .6957 m .58872 .75096 L .62063 .74982 L p .707 .577 .707 r
F P
0 g
s
.6486 .69066 m .65131 .74591 L .67776 .73962 L p .707 .577 .707 r
F P
0 g
s
.67776 .73962 m .67504 .68437 L .6486 .69066 L p .707 .577 .707 r
F P
0 g
s
.5587 .74922 m .55598 .69396 L .53079 .68951 L p .707 .577 .707 r
F P
0 g
s
.55598 .69396 m .5587 .74922 L .58872 .75096 L p .707 .577 .707 r
F P
0 g
s
.60666 .80807 m .60839 .77092 L .57688 .76822 L p .707 .577 .707 r
F P
0 g
s
.60839 .77092 m .60666 .80807 L .63823 .80821 L p .707 .577 .707 r
F P
0 g
s
.63823 .80821 m .63996 .77106 L .60839 .77092 L p .707 .577 .707 r
F P
0 g
s
.67504 .68437 m .67776 .73962 L .69738 .73156 L p .707 .577 .707 r
F P
0 g
s
.69738 .73156 m .69466 .6763 L .67504 .68437 L p .707 .577 .707 r
F P
0 g
s
.57515 .80537 m .57688 .76822 L .54852 .76323 L p .707 .577 .707 r
F P
0 g
s
.57688 .76822 m .57515 .80537 L .60666 .80807 L p .707 .577 .707 r
F P
0 g
s
.63996 .77106 m .63823 .80821 L .66678 .80578 L p .707 .577 .707 r
F P
0 g
s
.66678 .80578 m .6685 .76863 L .63996 .77106 L p .707 .577 .707 r
F P
0 g
s
.53079 .68951 m .5335 .74477 L .5587 .74922 L p .707 .577 .707 r
F P
0 g
s
.5335 .74477 m .53079 .68951 L .51289 .68279 L p .707 .577 .707 r
F P
0 g
s
.59325 .84691 m .59606 .82841 L .56533 .82223 L p .707 .577 .707 r
F P
0 g
s
.59606 .82841 m .59325 .84691 L .62478 .85088 L p .707 .577 .707 r
F P
0 g
s
.62478 .85088 m .62759 .83238 L .59606 .82841 L p .707 .577 .707 r
F P
0 g
s
.54852 .76323 m .54679 .80038 L .57515 .80537 L p .707 .577 .707 r
F P
0 g
s
.62759 .83238 m .62478 .85088 L .65404 .85225 L p .707 .577 .707 r
F P
0 g
s
.65404 .85225 m .65685 .83375 L .62759 .83238 L p .707 .577 .707 r
F P
0 g
s
.54679 .80038 m .54852 .76323 L .52608 .75643 L p .707 .577 .707 r
F P
0 g
s
.56533 .82223 m .56252 .84073 L .59325 .84691 L p .707 .577 .707 r
F P
0 g
s
.6685 .76863 m .66678 .80578 L .6895 .80102 L p .707 .577 .707 r
F P
0 g
s
.6895 .80102 m .69123 .76387 L .6685 .76863 L p .707 .577 .707 r
F P
0 g
s
.56252 .84073 m .56533 .82223 L .53842 .81445 L p .707 .577 .707 r
F P
0 g
s
.53842 .81445 m .53561 .83295 L .56252 .84073 L p .707 .577 .707 r
F P
0 g
s
.51289 .68279 m .51561 .73804 L .5335 .74477 L p .707 .577 .707 r
F P
0 g
s
.69466 .6763 m .69738 .73156 L .70826 .72251 L p .707 .577 .707 r
F P
0 g
s
.70826 .72251 m .70554 .66726 L .69466 .6763 L p .707 .577 .707 r
F P
0 g
s
.52608 .75643 m .52435 .79358 L .54679 .80038 L p .707 .577 .707 r
F P
0 g
s
.65685 .83375 m .65404 .85225 L .67815 .85088 L p .707 .577 .707 r
F P
0 g
s
.67815 .85088 m .68096 .83238 L .65685 .83375 L p .707 .577 .707 r
F P
0 g
s
.51561 .73804 m .51289 .68279 L .50404 .67445 L p .707 .577 .707 r
F P
0 g
s
.53561 .83295 m .53842 .81445 L .51797 .80582 L p .707 .577 .707 r
F P
0 g
s
.52435 .79358 m .52608 .75643 L .51175 .7485 L p .707 .577 .707 r
F P
0 g
s
.51797 .80582 m .51516 .82432 L .53561 .83295 L p .707 .577 .707 r
F P
0 g
s
.69123 .76387 m .6895 .80102 L .70417 .79439 L p .707 .577 .707 r
F P
0 g
s
.70417 .79439 m .7059 .75724 L .69123 .76387 L p .707 .577 .707 r
F P
0 g
s
.51175 .7485 m .51003 .78564 L .52435 .79358 L p .707 .577 .707 r
F P
0 g
s
.68096 .83238 m .67815 .85088 L .69477 .84692 L p .707 .577 .707 r
F P
0 g
s
.69477 .84692 m .69758 .82842 L .68096 .83238 L p .707 .577 .707 r
F P
0 g
s
.50404 .67445 m .50676 .7297 L .51561 .73804 L p .707 .577 .707 r
F P
0 g
s
.70554 .66726 m .70826 .72251 L .70932 .71338 L p .707 .577 .707 r
F P
0 g
s
.70932 .71338 m .7066 .65812 L .70554 .66726 L p .707 .577 .707 r
F P
0 g
s
.51516 .82432 m .51797 .80582 L .50596 .79719 L p .707 .577 .707 r
F P
0 g
s
.50596 .79719 m .50315 .81569 L .51516 .82432 L p .707 .577 .707 r
F P
0 g
s
.50676 .7297 m .50404 .67445 L .50511 .66531 L p .707 .577 .707 r
F P
0 g
s
.51003 .78564 m .51175 .7485 L .50696 .7402 L p .707 .577 .707 r
F P
0 g
s
.7059 .75724 m .70417 .79439 L .70936 .78654 L p .707 .577 .707 r
F P
0 g
s
.70936 .78654 m .71109 .7494 L .7059 .75724 L p .707 .577 .707 r
F P
0 g
s
.50696 .7402 m .50523 .77735 L .51003 .78564 L p .707 .577 .707 r
F P
0 g
s
.48366 .82167 m .48366 .31979 L .44017 .31655 L p .707 .577 .707 r
F P
0 g
s
.50511 .66531 m .50783 .72057 L .50676 .7297 L p .707 .577 .707 r
F P
0 g
s
.50315 .81569 m .50596 .79719 L .50359 .7894 L p .707 .577 .707 r
F P
0 g
s
.50359 .7894 m .50078 .8079 L .50315 .81569 L p .707 .577 .707 r
F P
0 g
s
.50783 .72057 m .50511 .66531 L .51599 .65627 L p .707 .577 .707 r
F P
0 g
s
.50523 .77735 m .50696 .7402 L .51215 .73235 L p .707 .577 .707 r
F P
0 g
s
.51215 .73235 m .51042 .7695 L .50523 .77735 L p .707 .577 .707 r
F P
0 g
s
.51599 .65627 m .5187 .71153 L .50783 .72057 L p .707 .577 .707 r
F P
0 g
s
.50078 .8079 m .50359 .7894 L .51107 .78322 L p .707 .577 .707 r
F P
0 g
s
.51107 .78322 m .50826 .80172 L .50078 .8079 L p .707 .577 .707 r
F P
0 g
s
.5187 .71153 m .51599 .65627 L .53561 .64821 L p .707 .577 .707 r
F P
0 g
s
.51042 .7695 m .51215 .73235 L .52682 .72572 L p .707 .577 .707 r
F P
0 g
s
.52682 .72572 m .52509 .76287 L .51042 .7695 L p .707 .577 .707 r
F P
0 g
s
.53561 .64821 m .53832 .70346 L .5187 .71153 L p .707 .577 .707 r
F P
0 g
s
.50826 .80172 m .51107 .78322 L .52769 .77926 L p .707 .577 .707 r
F P
0 g
s
.52769 .77926 m .52488 .79776 L .50826 .80172 L p .707 .577 .707 r
F P
0 g
s
.52488 .79776 m .52769 .77926 L .55181 .77789 L p .707 .577 .707 r
F P
0 g
s
.55181 .77789 m .549 .79639 L .52488 .79776 L p .707 .577 .707 r
F P
0 g
s
.48366 .31979 m .48366 .82167 L .52875 .82115 L p .707 .577 .707 r
F P
0 g
s
.52509 .76287 m .52682 .72572 L .54954 .72096 L p .707 .577 .707 r
F P
0 g
s
.54954 .72096 m .54781 .75811 L .52509 .76287 L p .707 .577 .707 r
F P
0 g
s
.52875 .82115 m .52875 .31926 L .48366 .31979 L p .707 .577 .707 r
F P
0 g
s
.69758 .82842 m .69477 .84692 L .70225 .84074 L p .707 .577 .707 r
F P
0 g
s
.70225 .84074 m .70506 .82224 L .69758 .82842 L p .707 .577 .707 r
F P
0 g
s
.53832 .70346 m .53561 .64821 L .56205 .64192 L p .707 .577 .707 r
F P
0 g
s
.56205 .64192 m .56477 .69717 L .53832 .70346 L p .707 .577 .707 r
F P
0 g
s
.54781 .75811 m .54954 .72096 L .57809 .71853 L p .707 .577 .707 r
F P
0 g
s
.57809 .71853 m .57636 .75568 L .54781 .75811 L p .707 .577 .707 r
F P
0 g
s
.549 .79639 m .55181 .77789 L .58106 .77926 L p .707 .577 .707 r
F P
0 g
s
.58106 .77926 m .57825 .79776 L .549 .79639 L p .707 .577 .707 r
F P
0 g
s
.52875 .31926 m .52875 .82115 L .57102 .81691 L p .707 .577 .707 r
F P
0 g
s
.56477 .69717 m .56205 .64192 L .59273 .63801 L p .707 .577 .707 r
F P
0 g
s
.59273 .63801 m .59545 .69326 L .56477 .69717 L p .707 .577 .707 r
F P
0 g
s
.57102 .81691 m .57102 .31502 L .52875 .31926 L p .707 .577 .707 r
F P
0 g
s
.7066 .65812 m .70932 .71338 L .70047 .70504 L p .707 .577 .707 r
F P
0 g
s
.70047 .70504 m .69776 .64979 L .7066 .65812 L p .707 .577 .707 r
F P
0 g
s
.44017 .81844 m .44017 .31655 L .40254 .30986 L p .707 .577 .707 r
F P
0 g
s
.44017 .31655 m .44017 .81844 L .48366 .82167 L p .707 .577 .707 r
F P
0 g
s
.62465 .63687 m .62737 .69213 L .59545 .69326 L p .707 .577 .707 r
F P
0 g
s
.59545 .69326 m .59273 .63801 L .62465 .63687 L p .707 .577 .707 r
F P
0 g
s
.57636 .75568 m .57809 .71853 L .60966 .71867 L p .707 .577 .707 r
F P
0 g
s
.60966 .71867 m .60793 .75582 L .57636 .75568 L p .707 .577 .707 r
F P
0 g
s
.57825 .79776 m .58106 .77926 L .6126 .78323 L p .707 .577 .707 r
F P
0 g
s
.6126 .78323 m .60979 .80173 L .57825 .79776 L p .707 .577 .707 r
F P
0 g
s
.57102 .31502 m .57102 .81691 L .60634 .80937 L p .707 .577 .707 r
F P
0 g
s
.60634 .80937 m .60634 .30748 L .57102 .31502 L p .707 .577 .707 r
F P
0 g
s
.71109 .7494 m .70936 .78654 L .70457 .77824 L p .707 .577 .707 r
F P
0 g
s
.70457 .77824 m .70629 .7411 L .71109 .7494 L p .707 .577 .707 r
F P
0 g
s
.27472 .70843 m .27362 .65211 L .24167 .65248 L p .707 .577 .707 r
F P
0 g
s
.27362 .65211 m .27472 .70843 L .30542 .70594 L p .707 .577 .707 r
F P
0 g
s
.30542 .70594 m .30432 .64962 L .27362 .65211 L p .707 .577 .707 r
F P
0 g
s
.24277 .7088 m .24167 .65248 L .21162 .65068 L p .707 .577 .707 r
F P
0 g
s
.24167 .65248 m .24277 .7088 L .27472 .70843 L p .707 .577 .707 r
F P
0 g
s
.70506 .82224 m .70225 .84074 L .69988 .83296 L p .707 .577 .707 r
F P
0 g
s
.69988 .83296 m .70269 .81445 L .70506 .82224 L p .707 .577 .707 r
F P
0 g
s
.40254 .81175 m .40254 .30986 L .37445 .30039 L p .707 .577 .707 r
F P
0 g
s
.40254 .30986 m .40254 .81175 L .44017 .81844 L p .707 .577 .707 r
F P
0 g
s
.30432 .64962 m .30542 .70594 L .33188 .70156 L p .707 .577 .707 r
F P
0 g
s
.33188 .70156 m .33078 .64524 L .30432 .64962 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69776 .64979 m .70047 .70504 L .68258 .69832 L p .707 .577 .707 r
F P
0 g
s
.68258 .69832 m .67986 .64306 L .69776 .64979 L p .707 .577 .707 r
F P
0 g
s
.21272 .707 m .21162 .65068 L .18639 .6469 L p .707 .577 .707 r
F P
0 g
s
.21162 .65068 m .21272 .707 L .24277 .7088 L p .707 .577 .707 r
F P
0 g
s
.64117 .72137 m .63944 .75852 L .60793 .75582 L p .707 .577 .707 r
F P
0 g
s
.60793 .75582 m .60966 .71867 L .64117 .72137 L p .707 .577 .707 r
F P
0 g
s
.64332 .78941 m .64051 .80791 L .60979 .80173 L p .707 .577 .707 r
F P
0 g
s
.60979 .80173 m .6126 .78323 L .64332 .78941 L p .707 .577 .707 r
F P
0 g
s
.60634 .30748 m .60634 .80937 L .63125 .79927 L p .707 .577 .707 r
F P
0 g
s
.65467 .63861 m .65739 .69387 L .62737 .69213 L p .707 .577 .707 r
F P
0 g
s
.62737 .69213 m .62465 .63687 L .65467 .63861 L p .707 .577 .707 r
F P
0 g
s
.63125 .79927 m .63125 .29738 L .60634 .30748 L p .707 .577 .707 r
F P
0 g
s
.26126 .77984 m .2619 .74345 L .23036 .74128 L p .707 .577 .707 r
F P
0 g
s
.2619 .74345 m .26126 .77984 L .29285 .77877 L p .707 .577 .707 r
F P
0 g
s
.29285 .77877 m .29349 .74238 L .2619 .74345 L p .707 .577 .707 r
F P
0 g
s
.18639 .6469 m .18749 .70322 L .21272 .707 L p .707 .577 .707 r
F P
0 g
s
.70629 .7411 m .70457 .77824 L .69024 .77031 L p .707 .577 .707 r
F P
0 g
s
.69024 .77031 m .69197 .73316 L .70629 .7411 L p .707 .577 .707 r
F P
0 g
s
.22972 .77767 m .23036 .74128 L .20196 .73608 L p .707 .577 .707 r
F P
0 g
s
.23036 .74128 m .22972 .77767 L .26126 .77984 L p .707 .577 .707 r
F P
0 g
s
.29349 .74238 m .29285 .77877 L .32141 .77457 L p .707 .577 .707 r
F P
0 g
s
.32141 .77457 m .32205 .73818 L .29349 .74238 L p .707 .577 .707 r
F P
0 g
s
.33078 .64524 m .33188 .70156 L .35151 .69573 L p .707 .577 .707 r
F P
0 g
s
.35151 .69573 m .35041 .63941 L .33078 .64524 L p .707 .577 .707 r
F P
0 g
s
.18749 .70322 m .18639 .6469 L .16847 .6415 L p .707 .577 .707 r
F P
0 g
s
.70269 .81445 m .69988 .83296 L .68788 .82432 L p .707 .577 .707 r
F P
0 g
s
.68788 .82432 m .69069 .80582 L .70269 .81445 L p .707 .577 .707 r
F P
0 g
s
.67986 .64306 m .68258 .69832 L .65739 .69387 L p .707 .577 .707 r
F P
0 g
s
.65739 .69387 m .65467 .63861 L .67986 .64306 L p .707 .577 .707 r
F P
0 g
s
.20196 .73608 m .20132 .77247 L .22972 .77767 L p .707 .577 .707 r
F P
0 g
s
.20132 .77247 m .20196 .73608 L .17948 .72837 L p .707 .577 .707 r
F P
0 g
s
.32205 .73818 m .32141 .77457 L .34414 .76765 L p .707 .577 .707 r
F P
0 g
s
.34414 .76765 m .34478 .73126 L .32205 .73818 L p .707 .577 .707 r
F P
0 g
s
.37445 .80227 m .37445 .30039 L .35865 .28904 L p .707 .577 .707 r
F P
0 g
s
.37445 .30039 m .37445 .80227 L .40254 .81175 L p .707 .577 .707 r
F P
0 g
s
.16847 .6415 m .16957 .69782 L .18749 .70322 L p .707 .577 .707 r
F P
0 g
s
.25188 .83312 m .25286 .81605 L .22179 .81129 L p .707 .577 .707 r
F P
0 g
s
.25286 .81605 m .25188 .83312 L .2837 .83335 L p .707 .577 .707 r
F P
0 g
s
.2837 .83335 m .28468 .81627 L .25286 .81605 L p .707 .577 .707 r
F P
0 g
s
.28468 .81627 m .2837 .83335 L .31314 .82902 L p .707 .577 .707 r
F P
0 g
s
.31314 .82902 m .31412 .81194 L .28468 .81627 L p .707 .577 .707 r
F P
0 g
s
.35041 .63941 m .35151 .69573 L .36238 .68902 L p .707 .577 .707 r
F P
0 g
s
.36238 .68902 m .36128 .6327 L .35041 .63941 L p .707 .577 .707 r
F P
0 g
s
.17948 .72837 m .17884 .76476 L .20132 .77247 L p .707 .577 .707 r
F P
0 g
s
.69197 .73316 m .69024 .77031 L .6678 .76351 L p .707 .577 .707 r
F P
0 g
s
.6678 .76351 m .66953 .72637 L .69197 .73316 L p .707 .577 .707 r
F P
0 g
s
.22081 .82836 m .22179 .81129 L .19449 .80246 L p .707 .577 .707 r
F P
0 g
s
.22179 .81129 m .22081 .82836 L .25188 .83312 L p .707 .577 .707 r
F P
0 g
s
.66953 .72637 m .6678 .76351 L .63944 .75852 L p .707 .577 .707 r
F P
0 g
s
.63944 .75852 m .64117 .72137 L .66953 .72637 L p .707 .577 .707 r
F P
0 g
s
.63125 .29738 m .63125 .79927 L .64332 .7876 L p .707 .577 .707 r
F P
0 g
s
.64332 .7876 m .64332 .28571 L .63125 .29738 L p .707 .577 .707 r
F P
0 g
s
.16957 .69782 m .16847 .6415 L .15959 .63502 L p .707 .577 .707 r
F P
0 g
s
.17884 .76476 m .17948 .72837 L .16513 .7189 L p .707 .577 .707 r
F P
0 g
s
.34478 .73126 m .34414 .76765 L .35881 .75868 L p .707 .577 .707 r
F P
0 g
s
.35881 .75868 m .35945 .7223 L .34478 .73126 L p .707 .577 .707 r
F P
0 g
s
.19449 .80246 m .19351 .81953 L .22081 .82836 L p .707 .577 .707 r
F P
0 g
s
.31412 .81194 m .31314 .82902 L .33731 .82055 L p .707 .577 .707 r
F P
0 g
s
.33731 .82055 m .33829 .80348 L .31412 .81194 L p .707 .577 .707 r
F P
0 g
s
.69069 .80582 m .68788 .82432 L .66742 .81569 L p .707 .577 .707 r
F P
0 g
s
.66742 .81569 m .67023 .79719 L .69069 .80582 L p .707 .577 .707 r
F P
0 g
s
.19351 .81953 m .19449 .80246 L .17364 .79043 L p .707 .577 .707 r
F P
0 g
s
.15959 .63502 m .16069 .69134 L .16957 .69782 L p .707 .577 .707 r
F P
0 g
s
.16513 .7189 m .16449 .75528 L .17884 .76476 L p .707 .577 .707 r
F P
0 g
s
.17364 .79043 m .17266 .8075 L .19351 .81953 L p .707 .577 .707 r
F P
0 g
s
.36128 .6327 m .36238 .68902 L .36343 .68208 L p .707 .577 .707 r
F P
0 g
s
.36343 .68208 m .36233 .62576 L .36128 .6327 L p .707 .577 .707 r
F P
0 g
s
.33829 .80348 m .33731 .82055 L .35387 .80879 L p .707 .577 .707 r
F P
0 g
s
.35387 .80879 m .35485 .79171 L .33829 .80348 L p .707 .577 .707 r
F P
0 g
s
.36117 .79487 m .36215 .77779 L .35485 .79171 L p .707 .577 .707 r
F P
0 g
s
.36233 .62576 m .36343 .68208 L .35456 .67559 L p .707 .577 .707 r
F P
0 g
s
.35456 .67559 m .35346 .61928 L .36233 .62576 L p .707 .577 .707 r
F P
0 g
s
.36215 .77779 m .36117 .79487 L .35852 .78016 L p .707 .577 .707 r
F P
0 g
s
.35852 .78016 m .3595 .76308 L .36215 .77779 L p .707 .577 .707 r
F P
0 g
s
.3598 .70186 m .35916 .73825 L .34481 .72877 L p .707 .577 .707 r
F P
0 g
s
.34481 .72877 m .34545 .69238 L .3598 .70186 L p .707 .577 .707 r
F P
0 g
s
.3595 .76308 m .35852 .78016 L .34616 .7661 L p .707 .577 .707 r
F P
0 g
s
.34616 .7661 m .34714 .74903 L .3595 .76308 L p .707 .577 .707 r
F P
0 g
s
.35865 .79093 m .35865 .28904 L .35668 .27694 L p .707 .577 .707 r
F P
0 g
s
.35945 .7223 m .35881 .75868 L .36399 .74855 L p .707 .577 .707 r
F P
0 g
s
.36399 .74855 m .36462 .71216 L .35945 .7223 L p .707 .577 .707 r
F P
0 g
s
.36462 .71216 m .36399 .74855 L .35916 .73825 L p .707 .577 .707 r
F P
0 g
s
.35916 .73825 m .3598 .70186 L .36462 .71216 L p .707 .577 .707 r
F P
0 g
s
.35865 .28904 m .35865 .79093 L .37445 .80227 L p .707 .577 .707 r
F P
0 g
s
.67023 .79719 m .66742 .81569 L .64051 .80791 L p .707 .577 .707 r
F P
0 g
s
.64051 .80791 m .64332 .78941 L .67023 .79719 L p .707 .577 .707 r
F P
0 g
s
.16069 .69134 m .15959 .63502 L .16065 .62808 L p .707 .577 .707 r
F P
0 g
s
.16449 .75528 m .16513 .7189 L .16031 .70859 L p .707 .577 .707 r
F P
0 g
s
.17266 .8075 m .17364 .79043 L .16128 .77637 L p .707 .577 .707 r
F P
0 g
s
.64332 .28571 m .64332 .7876 L .64135 .7755 L p .707 .577 .707 r
F P
0 g
s
.64135 .7755 m .64135 .27362 L .64332 .28571 L p .707 .577 .707 r
F P
0 g
s
.16128 .77637 m .1603 .79344 L .17266 .8075 L p .707 .577 .707 r
F P
0 g
s
.16065 .62808 m .16175 .6844 L .16069 .69134 L p .707 .577 .707 r
F P
0 g
s
.16031 .70859 m .15967 .74498 L .16449 .75528 L p .707 .577 .707 r
F P
0 g
s
.35485 .79171 m .35387 .80879 L .36117 .79487 L p .707 .577 .707 r
F P
0 g
s
.1603 .79344 m .16128 .77637 L .15863 .76166 L p .707 .577 .707 r
F P
0 g
s
.15967 .74498 m .16031 .70859 L .16548 .69846 L p .707 .577 .707 r
F P
0 g
s
.16175 .6844 m .16065 .62808 L .17152 .62136 L p .707 .577 .707 r
F P
0 g
s
.15863 .76166 m .15765 .77874 L .1603 .79344 L p .707 .577 .707 r
F P
0 g
s
.35668 .27694 m .35668 .77883 L .35865 .79093 L p .707 .577 .707 r
F P
0 g
s
.35668 .77883 m .35668 .27694 L .36875 .26528 L p .707 .577 .707 r
F P
0 g
s
.16548 .69846 m .16484 .73485 L .15967 .74498 L p .707 .577 .707 r
F P
0 g
s
.17152 .62136 m .17262 .67768 L .16175 .6844 L p .707 .577 .707 r
F P
0 g
s
.64135 .27362 m .64135 .7755 L .62555 .76416 L p .707 .577 .707 r
F P
0 g
s
.62555 .76416 m .62555 .26227 L .64135 .27362 L p .707 .577 .707 r
F P
0 g
s
.35346 .61928 m .35456 .67559 L .33663 .6702 L p .707 .577 .707 r
F P
0 g
s
.33663 .6702 m .33553 .61388 L .35346 .61928 L p .707 .577 .707 r
F P
0 g
s
.15765 .77874 m .15863 .76166 L .16593 .74774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16484 .73485 m .16548 .69846 L .18015 .68949 L p .707 .577 .707 r
F P
0 g
s
.17262 .67768 m .17152 .62136 L .19114 .61554 L p .707 .577 .707 r
F P
0 g
s
.16593 .74774 m .16495 .76482 L .15765 .77874 L p .707 .577 .707 r
F P
0 g
s
.18015 .68949 m .17951 .72588 L .16484 .73485 L p .707 .577 .707 r
F P
0 g
s
.19114 .61554 m .19224 .67185 L .17262 .67768 L p .707 .577 .707 r
F P
0 g
s
.33553 .61388 m .33663 .6702 L .31141 .66641 L p .707 .577 .707 r
F P
0 g
s
.31141 .66641 m .31031 .6101 L .33553 .61388 L p .707 .577 .707 r
F P
0 g
s
.36875 .76716 m .36875 .26528 L .39366 .25518 L p .707 .577 .707 r
F P
0 g
s
.36875 .26528 m .36875 .76716 L .35668 .77883 L p .707 .577 .707 r
F P
0 g
s
.16495 .76482 m .16593 .74774 L .18249 .73597 L p .707 .577 .707 r
F P
0 g
s
.19224 .67185 m .19114 .61554 L .2176 .61116 L p .707 .577 .707 r
F P
0 g
s
.17951 .72588 m .18015 .68949 L .20288 .68257 L p .707 .577 .707 r
F P
0 g
s
.34545 .69238 m .34481 .72877 L .32233 .72106 L p .707 .577 .707 r
F P
0 g
s
.32233 .72106 m .32297 .68467 L .34545 .69238 L p .707 .577 .707 r
F P
0 g
s
.18249 .73597 m .18151 .75305 L .16495 .76482 L p .707 .577 .707 r
F P
0 g
s
.62555 .26227 m .62555 .76416 L .59746 .75468 L p .707 .577 .707 r
F P
0 g
s
.59746 .75468 m .59746 .25279 L .62555 .26227 L p .707 .577 .707 r
F P
0 g
s
.2176 .61116 m .2187 .66748 L .19224 .67185 L p .707 .577 .707 r
F P
0 g
s
.31031 .6101 m .31141 .66641 L .28135 .66462 L p .707 .577 .707 r
F P
0 g
s
.28135 .66462 m .28025 .6083 L .31031 .6101 L p .707 .577 .707 r
F P
0 g
s
.20288 .68257 m .20224 .71896 L .17951 .72588 L p .707 .577 .707 r
F P
0 g
s
.34714 .74903 m .34616 .7661 L .32531 .75407 L p .707 .577 .707 r
F P
0 g
s
.32531 .75407 m .32629 .73699 L .34714 .74903 L p .707 .577 .707 r
F P
0 g
s
.2187 .66748 m .2176 .61116 L .24831 .60867 L p .707 .577 .707 r
F P
0 g
s
.18151 .75305 m .18249 .73597 L .20667 .72751 L p .707 .577 .707 r
F P
0 g
s
.20224 .71896 m .20288 .68257 L .23144 .67837 L p .707 .577 .707 r
F P
0 g
s
.32297 .68467 m .32233 .72106 L .29394 .71586 L p .707 .577 .707 r
F P
0 g
s
.29394 .71586 m .29457 .67948 L .32297 .68467 L p .707 .577 .707 r
F P
0 g
s
.28025 .6083 m .28135 .66462 L .24941 .66498 L p .707 .577 .707 r
F P
0 g
s
.24941 .66498 m .24831 .60867 L .28025 .6083 L p .707 .577 .707 r
F P
0 g
s
.24831 .60867 m .24941 .66498 L .2187 .66748 L p .707 .577 .707 r
F P
0 g
s
.20667 .72751 m .20569 .74459 L .18151 .75305 L p .707 .577 .707 r
F P
0 g
s
.39366 .25518 m .39366 .75707 L .36875 .76716 L p .707 .577 .707 r
F P
0 g
s
.39366 .75707 m .39366 .25518 L .42898 .24764 L p .707 .577 .707 r
F P
0 g
s
.75059 .66123 m .75169 .60656 L .71974 .60565 L p .707 .577 .707 r
F P
0 g
s
.75169 .60656 m .75059 .66123 L .78129 .65895 L p .707 .577 .707 r
F P
0 g
s
.78129 .65895 m .78239 .60429 L .75169 .60656 L p .707 .577 .707 r
F P
0 g
s
.71865 .66032 m .71974 .60565 L .68969 .60164 L p .707 .577 .707 r
F P
0 g
s
.71974 .60565 m .71865 .66032 L .75059 .66123 L p .707 .577 .707 r
F P
0 g
s
.23144 .67837 m .2308 .71476 L .20224 .71896 L p .707 .577 .707 r
F P
0 g
s
.2308 .71476 m .23144 .67837 L .26303 .67731 L p .707 .577 .707 r
F P
0 g
s
.29457 .67948 m .29394 .71586 L .2624 .71369 L p .707 .577 .707 r
F P
0 g
s
.2624 .71369 m .26303 .67731 L .29457 .67948 L p .707 .577 .707 r
F P
0 g
s
.32629 .73699 m .32531 .75407 L .29802 .74524 L p .707 .577 .707 r
F P
0 g
s
.29802 .74524 m .299 .72817 L .32629 .73699 L p .707 .577 .707 r
F P
0 g
s
.59746 .25279 m .59746 .75468 L .55983 .748 L p .707 .577 .707 r
F P
0 g
s
.55983 .748 m .55983 .24611 L .59746 .25279 L p .707 .577 .707 r
F P
0 g
s
.26303 .67731 m .2624 .71369 L .2308 .71476 L p .707 .577 .707 r
F P
0 g
s
.20569 .74459 m .20667 .72751 L .2361 .72318 L p .707 .577 .707 r
F P
0 g
s
.78239 .60429 m .78129 .65895 L .80776 .65371 L p .707 .577 .707 r
F P
0 g
s
.80776 .65371 m .80886 .59904 L .78239 .60429 L p .707 .577 .707 r
F P
0 g
s
.68859 .6563 m .68969 .60164 L .66446 .59491 L p .707 .577 .707 r
F P
0 g
s
.68969 .60164 m .68859 .6563 L .71865 .66032 L p .707 .577 .707 r
F P
0 g
s
.2361 .72318 m .23512 .74026 L .20569 .74459 L p .707 .577 .707 r
F P
0 g
s
.299 .72817 m .29802 .74524 L .26694 .74048 L p .707 .577 .707 r
F P
0 g
s
.26694 .74048 m .26792 .72341 L .299 .72817 L p .707 .577 .707 r
F P
0 g
s
.23512 .74026 m .2361 .72318 L .26792 .72341 L p .707 .577 .707 r
F P
0 g
s
.7376 .71099 m .73696 .6734 L .70542 .67281 L p .707 .577 .707 r
F P
0 g
s
.73696 .6734 m .7376 .71099 L .7692 .70945 L p .707 .577 .707 r
F P
0 g
s
.7692 .70945 m .76856 .67187 L .73696 .6734 L p .707 .577 .707 r
F P
0 g
s
.26792 .72341 m .26694 .74048 L .23512 .74026 L p .707 .577 .707 r
F P
0 g
s
.80886 .59904 m .80776 .65371 L .82738 .646 L p .707 .577 .707 r
F P
0 g
s
.82738 .646 m .82848 .59134 L .80886 .59904 L p .707 .577 .707 r
F P
0 g
s
.42898 .74953 m .42898 .24764 L .47125 .2434 L p .707 .577 .707 r
F P
0 g
s
.42898 .24764 m .42898 .74953 L .39366 .75707 L p .707 .577 .707 r
F P
0 g
s
.76856 .67187 m .7692 .70945 L .79776 .70595 L p .707 .577 .707 r
F P
0 g
s
.79776 .70595 m .79712 .66836 L .76856 .67187 L p .707 .577 .707 r
F P
0 g
s
.70606 .7104 m .70542 .67281 L .67703 .67016 L p .707 .577 .707 r
F P
0 g
s
.70542 .67281 m .70606 .7104 L .7376 .71099 L p .707 .577 .707 r
F P
0 g
s
.66446 .59491 m .66336 .64958 L .68859 .6563 L p .707 .577 .707 r
F P
0 g
s
.66336 .64958 m .66446 .59491 L .64654 .58614 L p .707 .577 .707 r
F P
0 g
s
.55983 .24611 m .55983 .748 L .51634 .74476 L p .707 .577 .707 r
F P
0 g
s
.51634 .74476 m .51634 .24287 L .55983 .24611 L p .707 .577 .707 r
F P
0 g
s
.73306 .73988 m .73208 .72072 L .701 .72181 L p .707 .577 .707 r
F P
0 g
s
.73208 .72072 m .73306 .73988 L .76488 .73808 L p .707 .577 .707 r
F P
0 g
s
.76488 .73808 m .7639 .71892 L .73208 .72072 L p .707 .577 .707 r
F P
0 g
s
.701 .72181 m .70198 .74097 L .73306 .73988 L p .707 .577 .707 r
F P
0 g
s
.67703 .67016 m .67766 .70775 L .70606 .7104 L p .707 .577 .707 r
F P
0 g
s
.7639 .71892 m .76488 .73808 L .79431 .73575 L p .707 .577 .707 r
F P
0 g
s
.79431 .73575 m .79333 .71659 L .7639 .71892 L p .707 .577 .707 r
F P
0 g
s
.70198 .74097 m .701 .72181 L .6737 .72208 L p .707 .577 .707 r
F P
0 g
s
.79712 .66836 m .79776 .70595 L .82048 .70081 L p .707 .577 .707 r
F P
0 g
s
.82048 .70081 m .81985 .66323 L .79712 .66836 L p .707 .577 .707 r
F P
0 g
s
.47125 .74529 m .47125 .2434 L .51634 .24287 L p .707 .577 .707 r
F P
0 g
s
.47125 .2434 m .47125 .74529 L .42898 .74953 L p .707 .577 .707 r
F P
0 g
s
.6737 .72208 m .67468 .74124 L .70198 .74097 L p .707 .577 .707 r
F P
0 g
s
.67766 .70775 m .67703 .67016 L .65455 .66571 L p .707 .577 .707 r
F P
0 g
s
.51634 .24287 m .51634 .74476 L .47125 .74529 L p .707 .577 .707 r
F P
0 g
s
.79333 .71659 m .79431 .73575 L .81849 .73311 L p .707 .577 .707 r
F P
0 g
s
.81849 .73311 m .81751 .71394 L .79333 .71659 L p .707 .577 .707 r
F P
0 g
s
.64654 .58614 m .64544 .64081 L .66336 .64958 L p .707 .577 .707 r
F P
0 g
s
.82848 .59134 m .82738 .646 L .83825 .6366 L p .707 .577 .707 r
F P
0 g
s
.83825 .6366 m .83935 .58193 L .82848 .59134 L p .707 .577 .707 r
F P
0 g
s
.65455 .66571 m .65519 .7033 L .67766 .70775 L p .707 .577 .707 r
F P
0 g
s
.64544 .64081 m .64654 .58614 L .63767 .57617 L p .707 .577 .707 r
F P
0 g
s
.67468 .74124 m .6737 .72208 L .65285 .7215 L p .707 .577 .707 r
F P
0 g
s
.65285 .7215 m .65383 .74066 L .67468 .74124 L p .707 .577 .707 r
F P
0 g
s
.81985 .66323 m .82048 .70081 L .83515 .69455 L p .707 .577 .707 r
F P
0 g
s
.83515 .69455 m .83452 .65697 L .81985 .66323 L p .707 .577 .707 r
F P
0 g
s
.65519 .7033 m .65455 .66571 L .6402 .65989 L p .707 .577 .707 r
F P
0 g
s
.81751 .71394 m .81849 .73311 L .83504 .73042 L p .707 .577 .707 r
F P
0 g
s
.83504 .73042 m .83406 .71125 L .81751 .71394 L p .707 .577 .707 r
F P
0 g
s
.6402 .65989 m .64084 .69747 L .65519 .7033 L p .707 .577 .707 r
F P
0 g
s
.63767 .57617 m .63657 .63084 L .64544 .64081 L p .707 .577 .707 r
F P
0 g
s
.83935 .58193 m .83825 .6366 L .8393 .62642 L p .707 .577 .707 r
F P
0 g
s
.8393 .62642 m .8404 .57175 L .83935 .58193 L p .707 .577 .707 r
F P
0 g
s
.65383 .74066 m .65285 .7215 L .6405 .72014 L p .707 .577 .707 r
F P
0 g
s
.6405 .72014 m .64148 .7393 L .65383 .74066 L p .707 .577 .707 r
F P
0 g
s
.63657 .63084 m .63767 .57617 L .63872 .56599 L p .707 .577 .707 r
F P
0 g
s
.83452 .65697 m .83515 .69455 L .84033 .68778 L p .707 .577 .707 r
F P
0 g
s
.84033 .68778 m .83969 .6502 L .83452 .65697 L p .707 .577 .707 r
F P
0 g
s
.64084 .69747 m .6402 .65989 L .63537 .65327 L p .707 .577 .707 r
F P
0 g
s
.83406 .71125 m .83504 .73042 L .84235 .72794 L p .707 .577 .707 r
F P
0 g
s
.84235 .72794 m .84137 .70878 L .83406 .71125 L p .707 .577 .707 r
F P
0 g
s
.63537 .65327 m .63601 .69085 L .64084 .69747 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63872 .56599 m .63762 .62066 L .63657 .63084 L p .707 .577 .707 r
F P
0 g
s
.8404 .57175 m .8393 .62642 L .83043 .61645 L p .707 .577 .707 r
F P
0 g
s
.83043 .61645 m .83153 .56179 L .8404 .57175 L p .707 .577 .707 r
F P
0 g
s
.64148 .7393 m .6405 .72014 L .63784 .71812 L p .707 .577 .707 r
F P
0 g
s
.63784 .71812 m .63882 .73728 L .64148 .7393 L p .707 .577 .707 r
F P
0 g
s
.63762 .62066 m .63872 .56599 L .64959 .55659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83969 .6502 m .84033 .68778 L .83551 .68116 L p .707 .577 .707 r
F P
0 g
s
.83551 .68116 m .83487 .64358 L .83969 .6502 L p .707 .577 .707 r
F P
0 g
s
.63601 .69085 m .63537 .65327 L .64055 .6465 L p .707 .577 .707 r
F P
0 g
s
.84137 .70878 m .84235 .72794 L .8397 .72592 L p .707 .577 .707 r
F P
0 g
s
.8397 .72592 m .83872 .70676 L .84137 .70878 L p .707 .577 .707 r
F P
0 g
s
.40455 .61995 m .40726 .56418 L .37535 .56245 L p .707 .577 .707 r
F P
0 g
s
.40726 .56418 m .40455 .61995 L .43523 .61912 L p .707 .577 .707 r
F P
0 g
s
.43523 .61912 m .43794 .56335 L .40726 .56418 L p .707 .577 .707 r
F P
0 g
s
.37263 .61823 m .37535 .56245 L .34533 .55834 L p .707 .577 .707 r
F P
0 g
s
.37535 .56245 m .37263 .61823 L .40455 .61995 L p .707 .577 .707 r
F P
0 g
s
.64055 .6465 m .64119 .68408 L .63601 .69085 L p .707 .577 .707 r
F P
0 g
s
.64959 .55659 m .64849 .61125 L .63762 .62066 L p .707 .577 .707 r
F P
0 g
s
.43794 .56335 m .43523 .61912 L .46167 .61581 L p .707 .577 .707 r
F P
0 g
s
.46167 .61581 m .46439 .56004 L .43794 .56335 L p .707 .577 .707 r
F P
0 g
s
.83153 .56179 m .83043 .61645 L .81251 .60768 L p .707 .577 .707 r
F P
0 g
s
.81251 .60768 m .81361 .55301 L .83153 .56179 L p .707 .577 .707 r
F P
0 g
s
.34261 .61411 m .34533 .55834 L .32014 .55224 L p .707 .577 .707 r
F P
0 g
s
.34533 .55834 m .34261 .61411 L .37263 .61823 L p .707 .577 .707 r
F P
0 g
s
.64849 .61125 m .64959 .55659 L .66921 .54889 L p .707 .577 .707 r
F P
0 g
s
.63882 .73728 m .63784 .71812 L .64515 .71564 L p .707 .577 .707 r
F P
0 g
s
.64515 .71564 m .64613 .73481 L .63882 .73728 L p .707 .577 .707 r
F P
0 g
s
.39207 .68287 m .39034 .64599 L .35883 .64589 L p .707 .577 .707 r
F P
0 g
s
.39034 .64599 m .39207 .68287 L .42364 .68016 L p .707 .577 .707 r
F P
0 g
s
.42364 .68016 m .42191 .64328 L .39034 .64599 L p .707 .577 .707 r
F P
0 g
s
.42191 .64328 m .42364 .68016 L .45218 .6749 L p .707 .577 .707 r
F P
0 g
s
.45218 .6749 m .45045 .63802 L .42191 .64328 L p .707 .577 .707 r
F P
0 g
s
.83487 .64358 m .83551 .68116 L .82115 .67534 L p .707 .577 .707 r
F P
0 g
s
.82115 .67534 m .82052 .63775 L .83487 .64358 L p .707 .577 .707 r
F P
0 g
s
.32014 .55224 m .31742 .60801 L .34261 .61411 L p .707 .577 .707 r
F P
0 g
s
.36056 .68277 m .35883 .64589 L .33047 .64299 L p .707 .577 .707 r
F P
0 g
s
.35883 .64589 m .36056 .68277 L .39207 .68287 L p .707 .577 .707 r
F P
0 g
s
.46439 .56004 m .46167 .61581 L .48129 .61035 L p .707 .577 .707 r
F P
0 g
s
.48129 .61035 m .48401 .55457 L .46439 .56004 L p .707 .577 .707 r
F P
0 g
s
.64119 .68408 m .64055 .6465 L .65522 .64024 L p .707 .577 .707 r
F P
0 g
s
.31742 .60801 m .32014 .55224 L .30224 .54475 L p .707 .577 .707 r
F P
0 g
s
.83872 .70676 m .8397 .72592 L .82734 .72456 L p .707 .577 .707 r
F P
0 g
s
.82734 .72456 m .82636 .7054 L .83872 .70676 L p .707 .577 .707 r
F P
0 g
s
.66921 .54889 m .66812 .60355 L .64849 .61125 L p .707 .577 .707 r
F P
0 g
s
.65522 .64024 m .65586 .67783 L .64119 .68408 L p .707 .577 .707 r
F P
0 g
s
.81361 .55301 m .81251 .60768 L .78728 .60095 L p .707 .577 .707 r
F P
0 g
s
.78728 .60095 m .78838 .54629 L .81361 .55301 L p .707 .577 .707 r
F P
0 g
s
.33047 .64299 m .33219 .67987 L .36056 .68277 L p .707 .577 .707 r
F P
0 g
s
.45045 .63802 m .45218 .6749 L .4749 .66762 L p .707 .577 .707 r
F P
0 g
s
.4749 .66762 m .47318 .63074 L .45045 .63802 L p .707 .577 .707 r
F P
0 g
s
.66812 .60355 m .66921 .54889 L .69568 .54364 L p .707 .577 .707 r
F P
0 g
s
.33219 .67987 m .33047 .64299 L .30802 .63757 L p .707 .577 .707 r
F P
0 g
s
.39021 .72729 m .3874 .70915 L .35667 .71119 L p .707 .577 .707 r
F P
0 g
s
.3874 .70915 m .39021 .72729 L .42174 .72212 L p .707 .577 .707 r
F P
0 g
s
.42174 .72212 m .41893 .70399 L .3874 .70915 L p .707 .577 .707 r
F P
0 g
s
.41893 .70399 m .42174 .72212 L .451 .71433 L p .707 .577 .707 r
F P
0 g
s
.451 .71433 m .44819 .69619 L .41893 .70399 L p .707 .577 .707 r
F P
0 g
s
.30224 .54475 m .29952 .60052 L .31742 .60801 L p .707 .577 .707 r
F P
0 g
s
.64613 .73481 m .64515 .71564 L .6617 .71295 L p .707 .577 .707 r
F P
0 g
s
.35667 .71119 m .35948 .72932 L .39021 .72729 L p .707 .577 .707 r
F P
0 g
s
.6617 .71295 m .66268 .73212 L .64613 .73481 L p .707 .577 .707 r
F P
0 g
s
.35948 .72932 m .35667 .71119 L .32977 .70989 L p .707 .577 .707 r
F P
0 g
s
.30802 .63757 m .30975 .67446 L .33219 .67987 L p .707 .577 .707 r
F P
0 g
s
.48401 .55457 m .48129 .61035 L .49217 .60327 L p .707 .577 .707 r
F P
0 g
s
.49217 .60327 m .49489 .54749 L .48401 .55457 L p .707 .577 .707 r
F P
0 g
s
.44819 .69619 m .451 .71433 L .47512 .70467 L p .707 .577 .707 r
F P
0 g
s
.47512 .70467 m .47231 .68654 L .44819 .69619 L p .707 .577 .707 r
F P
0 g
s
.82052 .63775 m .82115 .67534 L .79868 .67089 L p .707 .577 .707 r
F P
0 g
s
.79868 .67089 m .79804 .6333 L .82052 .63775 L p .707 .577 .707 r
F P
0 g
s
.78838 .54629 m .78728 .60095 L .75723 .59694 L p .707 .577 .707 r
F P
0 g
s
.75723 .59694 m .75832 .54227 L .78838 .54629 L p .707 .577 .707 r
F P
0 g
s
.65586 .67783 m .65522 .64024 L .67795 .63511 L p .707 .577 .707 r
F P
0 g
s
.29952 .60052 m .30224 .54475 L .29339 .5366 L p .707 .577 .707 r
F P
0 g
s
.32977 .70989 m .33258 .72802 L .35948 .72932 L p .707 .577 .707 r
F P
0 g
s
.69458 .59831 m .69568 .54364 L .72638 .54136 L p .707 .577 .707 r
F P
0 g
s
.69568 .54364 m .69458 .59831 L .66812 .60355 L p .707 .577 .707 r
F P
0 g
s
.47318 .63074 m .4749 .66762 L .48958 .65902 L p .707 .577 .707 r
F P
0 g
s
.48958 .65902 m .48785 .62213 L .47318 .63074 L p .707 .577 .707 r
F P
0 g
s
.82636 .7054 m .82734 .72456 L .80649 .72398 L p .707 .577 .707 r
F P
0 g
s
.80649 .72398 m .80551 .70482 L .82636 .7054 L p .707 .577 .707 r
F P
0 g
s
.30975 .67446 m .30802 .63757 L .2937 .63017 L p .707 .577 .707 r
F P
0 g
s
.67795 .63511 m .67858 .67269 L .65586 .67783 L p .707 .577 .707 r
F P
0 g
s
.75832 .54227 m .75723 .59694 L .72528 .59603 L p .707 .577 .707 r
F P
0 g
s
.72528 .59603 m .72638 .54136 L .75832 .54227 L p .707 .577 .707 r
F P
0 g
s
.72638 .54136 m .72528 .59603 L .69458 .59831 L p .707 .577 .707 r
F P
0 g
s
.33258 .72802 m .32977 .70989 L .30931 .70539 L p .707 .577 .707 r
F P
0 g
s
.29339 .5366 m .29067 .59237 L .29952 .60052 L p .707 .577 .707 r
F P
0 g
s
.47231 .68654 m .47512 .70467 L .49173 .6941 L p .707 .577 .707 r
F P
0 g
s
.49173 .6941 m .48892 .67597 L .47231 .68654 L p .707 .577 .707 r
F P
0 g
s
.30931 .70539 m .31212 .72352 L .33258 .72802 L p .707 .577 .707 r
F P
0 g
s
.2937 .63017 m .29543 .66706 L .30975 .67446 L p .707 .577 .707 r
F P
0 g
s
.66268 .73212 m .6617 .71295 L .68588 .71031 L p .707 .577 .707 r
F P
0 g
s
.68588 .71031 m .68686 .72947 L .66268 .73212 L p .707 .577 .707 r
F P
0 g
s
.79804 .6333 m .79868 .67089 L .77028 .66824 L p .707 .577 .707 r
F P
0 g
s
.77028 .66824 m .76964 .63065 L .79804 .6333 L p .707 .577 .707 r
F P
0 g
s
.67858 .67269 m .67795 .63511 L .70651 .6316 L p .707 .577 .707 r
F P
0 g
s
.49489 .54749 m .49217 .60327 L .49324 .59526 L p .707 .577 .707 r
F P
0 g
s
.49324 .59526 m .49595 .53949 L .49489 .54749 L p .707 .577 .707 r
F P
0 g
s
.70651 .6316 m .70714 .66919 L .67858 .67269 L p .707 .577 .707 r
F P
0 g
s
.29067 .59237 m .29339 .5366 L .29446 .52859 L p .707 .577 .707 r
F P
0 g
s
.80551 .70482 m .80649 .72398 L .77919 .72425 L p .707 .577 .707 r
F P
0 g
s
.77919 .72425 m .77821 .70509 L .80551 .70482 L p .707 .577 .707 r
F P
0 g
s
.48785 .62213 m .48958 .65902 L .49477 .64994 L p .707 .577 .707 r
F P
0 g
s
.49477 .64994 m .49304 .61306 L .48785 .62213 L p .707 .577 .707 r
F P
0 g
s
.76964 .63065 m .77028 .66824 L .73874 .66765 L p .707 .577 .707 r
F P
0 g
s
.73874 .66765 m .7381 .63007 L .76964 .63065 L p .707 .577 .707 r
F P
0 g
s
.29543 .66706 m .2937 .63017 L .2889 .62151 L p .707 .577 .707 r
F P
0 g
s
.70714 .66919 m .70651 .6316 L .7381 .63007 L p .707 .577 .707 r
F P
0 g
s
.31212 .72352 m .30931 .70539 L .29731 .69812 L p .707 .577 .707 r
F P
0 g
s
.68686 .72947 m .68588 .71031 L .71532 .70798 L p .707 .577 .707 r
F P
0 g
s
.7381 .63007 m .73874 .66765 L .70714 .66919 L p .707 .577 .707 r
F P
0 g
s
.71532 .70798 m .7163 .72714 L .68686 .72947 L p .707 .577 .707 r
F P
0 g
s
.48892 .67597 m .49173 .6941 L .49922 .68364 L p .707 .577 .707 r
F P
0 g
s
.49922 .68364 m .49641 .66551 L .48892 .67597 L p .707 .577 .707 r
F P
0 g
s
.29731 .69812 m .30012 .71625 L .31212 .72352 L p .707 .577 .707 r
F P
0 g
s
.29446 .52859 m .29174 .58437 L .29067 .59237 L p .707 .577 .707 r
F P
0 g
s
.2889 .62151 m .29063 .65839 L .29543 .66706 L p .707 .577 .707 r
F P
0 g
s
.77821 .70509 m .77919 .72425 L .74811 .72534 L p .707 .577 .707 r
F P
0 g
s
.74811 .72534 m .74713 .70618 L .77821 .70509 L p .707 .577 .707 r
F P
0 g
s
.7163 .72714 m .71532 .70798 L .74713 .70618 L p .707 .577 .707 r
F P
0 g
s
.74713 .70618 m .74811 .72534 L .7163 .72714 L p .707 .577 .707 r
F P
0 g
s
.49595 .53949 m .49324 .59526 L .48439 .58711 L p .707 .577 .707 r
F P
0 g
s
.48439 .58711 m .48711 .53134 L .49595 .53949 L p .707 .577 .707 r
F P
0 g
s
.29174 .58437 m .29446 .52859 L .30533 .52151 L p .707 .577 .707 r
F P
0 g
s
.49304 .61306 m .49477 .64994 L .48997 .64128 L p .707 .577 .707 r
F P
0 g
s
.48997 .64128 m .48824 .6044 L .49304 .61306 L p .707 .577 .707 r
F P
0 g
s
.30012 .71625 m .29731 .69812 L .29493 .6888 L p .707 .578 .707 r
F P
0 g
s
.29063 .65839 m .2889 .62151 L .2941 .61243 L p .707 .577 .707 r
F P
0 g
s
.49641 .66551 m .49922 .68364 L .49684 .67432 L p .707 .578 .707 r
F P
0 g
s
.49684 .67432 m .49403 .65619 L .49641 .66551 L p .707 .578 .707 r
F P
0 g
s
.29493 .6888 m .29774 .70694 L .30012 .71625 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30533 .52151 m .30262 .57729 L .29174 .58437 L p .707 .577 .707 r
F P
0 g
s
.2941 .61243 m .29582 .64932 L .29063 .65839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48711 .53134 m .48439 .58711 L .46649 .57962 L p .707 .577 .707 r
F P
0 g
s
.46649 .57962 m .46921 .52385 L .48711 .53134 L p .707 .577 .707 r
F P
0 g
s
.30262 .57729 m .30533 .52151 L .32496 .51605 L p .707 .577 .707 r
F P
0 g
s
.48824 .6044 m .48997 .64128 L .47565 .63388 L p .707 .577 .707 r
F P
0 g
s
.47565 .63388 m .47392 .59699 L .48824 .6044 L p .707 .577 .707 r
F P
0 g
s
.29774 .70694 m .29493 .6888 L .30242 .67835 L p .707 .577 .707 r
F P
0 g
s
.29582 .64932 m .2941 .61243 L .30877 .60383 L p .707 .577 .707 r
F P
0 g
s
.49403 .65619 m .49684 .67432 L .48484 .66706 L p .707 .577 .707 r
F P
0 g
s
.48484 .66706 m .48203 .64893 L .49403 .65619 L p .707 .577 .707 r
F P
0 g
s
.30242 .67835 m .30523 .69648 L .29774 .70694 L p .707 .577 .707 r
F P
0 g
s
.32496 .51605 m .32224 .57182 L .30262 .57729 L p .707 .577 .707 r
F P
0 g
s
.30877 .60383 m .3105 .64072 L .29582 .64932 L p .707 .577 .707 r
F P
0 g
s
.46921 .52385 m .46649 .57962 L .4413 .57352 L p .707 .577 .707 r
F P
0 g
s
.4413 .57352 m .44402 .51775 L .46921 .52385 L p .707 .577 .707 r
F P
0 g
s
.32224 .57182 m .32496 .51605 L .3514 .51274 L p .707 .577 .707 r
F P
0 g
s
.47392 .59699 m .47565 .63388 L .45321 .62846 L p .707 .577 .707 r
F P
0 g
s
.45321 .62846 m .45148 .59158 L .47392 .59699 L p .707 .577 .707 r
F P
0 g
s
.3105 .64072 m .30877 .60383 L .33149 .59655 L p .707 .577 .707 r
F P
0 g
s
.30523 .69648 m .30242 .67835 L .31903 .66777 L p .707 .577 .707 r
F P
0 g
s
.3514 .51274 m .34868 .56851 L .32224 .57182 L p .707 .577 .707 r
F P
0 g
s
.48203 .64893 m .48484 .66706 L .46438 .66256 L p .707 .577 .707 r
F P
0 g
s
.46438 .66256 m .46157 .64442 L .48203 .64893 L p .707 .577 .707 r
F P
0 g
s
.31903 .66777 m .32184 .68591 L .30523 .69648 L p .707 .577 .707 r
F P
0 g
s
.44402 .51775 m .4413 .57352 L .41128 .56941 L p .707 .577 .707 r
F P
0 g
s
.41128 .56941 m .414 .51363 L .44402 .51775 L p .707 .577 .707 r
F P
0 g
s
.34868 .56851 m .3514 .51274 L .38208 .51191 L p .707 .577 .707 r
F P
0 g
s
.33149 .59655 m .33322 .63343 L .3105 .64072 L p .707 .577 .707 r
F P
0 g
s
.414 .51363 m .41128 .56941 L .37936 .56768 L p .707 .577 .707 r
F P
0 g
s
.37936 .56768 m .38208 .51191 L .414 .51363 L p .707 .577 .707 r
F P
0 g
s
.38208 .51191 m .37936 .56768 L .34868 .56851 L p .707 .577 .707 r
F P
0 g
s
.45148 .59158 m .45321 .62846 L .42484 .62556 L p .707 .577 .707 r
F P
0 g
s
.42484 .62556 m .42312 .58868 L .45148 .59158 L p .707 .577 .707 r
F P
0 g
s
.33322 .63343 m .33149 .59655 L .36004 .59129 L p .707 .577 .707 r
F P
0 g
s
.32184 .68591 m .31903 .66777 L .34315 .65812 L p .707 .577 .707 r
F P
0 g
s
.46157 .64442 m .46438 .66256 L .43748 .66126 L p .707 .577 .707 r
F P
0 g
s
.43748 .66126 m .43467 .64313 L .46157 .64442 L p .707 .577 .707 r
F P
0 g
s
.36004 .59129 m .36176 .62818 L .33322 .63343 L p .707 .577 .707 r
F P
0 g
s
.34315 .65812 m .34596 .67625 L .32184 .68591 L p .707 .577 .707 r
F P
0 g
s
.42312 .58868 m .42484 .62556 L .39333 .62546 L p .707 .577 .707 r
F P
0 g
s
.39333 .62546 m .39161 .58858 L .42312 .58868 L p .707 .577 .707 r
F P
0 g
s
.36176 .62818 m .36004 .59129 L .39161 .58858 L p .707 .577 .707 r
F P
0 g
s
.39161 .58858 m .39333 .62546 L .36176 .62818 L p .707 .577 .707 r
F P
0 g
s
.34596 .67625 m .34315 .65812 L .37241 .65032 L p .707 .577 .707 r
F P
0 g
s
.43467 .64313 m .43748 .66126 L .40675 .66329 L p .707 .577 .707 r
F P
0 g
s
.40675 .66329 m .40394 .64516 L .43467 .64313 L p .707 .577 .707 r
F P
0 g
s
.37241 .65032 m .37522 .66846 L .34596 .67625 L p .707 .577 .707 r
F P
0 g
s
.37522 .66846 m .37241 .65032 L .40394 .64516 L p .707 .577 .707 r
F P
0 g
s
.40394 .64516 m .40675 .66329 L .37522 .66846 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001POolA0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001FOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol005=oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
4Goo2@00BWoo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02goo1P0015YF00<0
05YFFUH00UYF2@00@Goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01goo1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo001COol01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`00=goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00@007ooOomo
o`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<003Aoo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001oo`000004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH00000<Woo001BOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000`Ool0059oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP8002moo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;goo001BOol01@00
FUIJEUYF00000eYF1P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Woo001BOol01P00FUIJEUYF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEPH000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000;Woo001BOol01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000^Ool0059oo`04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH0009JEP03001J
EUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000;Woo001BOol01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00004@001UYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH01000FUIJEUYF200015YF00<0
05YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0002ioo`00Dgoo0`0015YF00<005YFFUH0
1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0100000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH0000^Ool005Eoo`80009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH80006Ool50006Ool60005FUH00`00FUIJEP03FUH00`00FUH0000^Ool005Moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
0080009JEP04001JEUYFFUH<0008Ool50005Ool;00000eYF001JEP04FUH00`00FUH0000^Ool005Io
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUH000020007FUH01000FUIJEUYF4P0015YF00<005YFFUH015YF0P00
1EYF00<005YF0000;Woo000lOolJ00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P000UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YF0000
00=JEP03001JEP0002ioo`00>7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800004FUH005YF000^
Ool003Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH0100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP00Ool0;Goo000`Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00800003
FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool002ioo`<000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQ4000AJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUH00000;Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF1P0015YF0`001eYF00<0
05YFFUH01P001EYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool0
1000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
15YF00<005YFFUH00eYF00<005YFFUH01@000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH01UYF
100000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEP0001T000IJEP03001JEUYF00=J
EP04001JEUYF000^Ool002eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF009JEP@000=JEP80009JEP03001JEUYF00=J
EPD000IJEP03001JEUYF00IJEP<00003FUH0000000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH01P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPP000EJEP04001JEUYF000^Ool002eoo`04001JEUYF0005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001J
EP000080009JEP03001JEUYF009JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00H000AJ
EP05001JEP00001JEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF100000EJEP00FUIJEP0002ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF2P000UYF0P000UYF00<0
05YFFUH015YF0`0000=JEP0000002P0000=JEP00FUH015YF00@005YFFUIJEP<000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPD002moo`00;Goo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP07001JEUYF001JEP00
FUH00P001EYF00<005YFFUH00UYF5@0015YF00@005YFFUIJEPP000AJEP8000EJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
008002moo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02ioo`00;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP800003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP02FUH00`00FUIJEP030006FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000]Ool01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00@005YFFUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEQH0009JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001J
EP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00D005YFFUIJEP0000AJEP03001J
EUYF00AJEQP000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05001J
EUYFFUH00004FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000015YF0000
00001eYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
15YF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80003Ool500000goo0000000=0004FUH0
1000FUIJEUYF0P00;Woo000]Ool01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH0
1UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF8@000eYF00<005YFFUH00`00
00=JEP00FUH00UYF0P00;Woo000]Ool01000FUIJEUYF0`0000=JEP00FUH01EYF00@005YFFUIJEPl0
00IJEP03001JEUYF009JEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00@000IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP8002ioo`00;Goo00@005YF000000AJEP03
001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEPL000EJEP04001JEUYFFUH30004FUH0
0`00FUIJEP06FUH30002FUH7000:FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003000^Ool0
02eoo`800003FUH005YF00=JEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00EJEP04001JEP000003FUHB0005FUH00`00FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF
009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP0015YF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF1P000UYF00<005YF00000UYF00<005YF
FUH00eYF1@001UYF00<005YFFUH02EYF0P0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo
00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0002FUH30005FUH300001EYF001JEUYF00001EYF1@001UYF00<005YFFUH01EYF100000=JEP00
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;goo000^Ool60005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH30007FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D0
05YFFUIJEP0002moo`00;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEP000002FUH00`00FUIJEP04
FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP06FUH01000FUIJEP001eYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF0000031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF100015YF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF
00MJEP<000=JEP03001JEUYF00EJEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002ioo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00006FUH00000001JEP001UYF00@005YF
FUH0009JEP03001JEUYF00AJEP04001JEUYFFUH60006FUH00`00FUIJEP04FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP05FUHO000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00004FUH005YFFUH700001EYF001JEUYF0000
0UYF00<005YF0000200015YF00<005YFFUH01UYF00@005YFFUIJEP8000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEQ4000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP<00003FUH005YF00AJEP04
001JEUYFFUH90004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000aJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH60002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80009Ool70002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000]Ool20004FUH00`00FUIJ
EP02FUH6000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool20004FUH00`00FUH00002
0007Ool@0009Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPl000=J
EP03001JEUYF008002eoo`00;Goo0P000eYF0`0017oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
10001goo0`0000=JEP00FUH01UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHB0007FUH00`00FUIJEP04FUH8000]Ool002eoo`800004FUH0
0000FUH20002Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006Ool>0004
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`<000=JEP04001JEP00
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030002Ool40000
0eYF000000020002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEPT000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000bOol002eoo`8000AJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJ
EP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF4000>7oo000]Ool20003FUH2
0006FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH30003FUH01000FUIJEP000UYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF7`00B7oo000]Ool200001EYF000005YF00001EYF
1P000UYF00<005YFFUH00UYF40001UYF00<005YFFUH00P0000EJEP00FUIJEP00009JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`<000=J
EP04001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00
FUIJEP02FUH20002FUH01000FUIJEP001UYF00<005YFFUH01eYF00@005YFFUIJEPH000IJEP03001J
EUYF00YJEP03001JEUYF00T000MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH2001COol002ioo`8000=JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH200001EYF
001JEUYF00001UYF00<005YFFUH01EYF1`002eYF00<005YFFUH02UYF00<005YFFUH02EYF1@000UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00L005YFFUIJEP00
FUH0001BOol002ioo`8000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo0P000UYF
0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00059oo`00;Goo1P001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF100000=JEP00FUH00eYF1@000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
001BOol002eoo`8000=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYF001JEP020006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
15YF00<007ooOol00Woo10001EYF00L005YFFUIJEP00FUH0001BOol002eoo`03001oogoo00Aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP800004Ool005YF0002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH01000Oomoogoo2@0000=JEP00
FUH00UYF0P00Dgoo000/Ool2000:Ool30006FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH0
0`00FUH000020003Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF1`0015YF
00<005YFFUH00UYF0P000eYF0P00Dgoo000/Ool2000=Ool40002FUH00`00FUIJEP03FUH50007FUH0
0`00FUIJEP02FUH50007Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF
00<005YFFUH00eYF0`0000=JEP000000Dgoo000/Ool3000@OolI000=Ool00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001eYF00<005YFFUH00eYF00<005YFFUH00`00Dgoo
000/Ool200000eYF001oo`0FOol5000IOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEP001eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000/Ool20002FUH00`00
Oomoo`0EOol3000JOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00
1eYF00<005YFFUH00UYF00<005YFFUH00UYF0P00Dgoo000]Ool01@00FUIJEUYF0000<Woo0P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P001EYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0DWoo000]Ool01000FUIJEUYF0`00<7oo00<005YF00000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH0100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00;Woo
00@005YFFUH0009JEP03001oogoo02aoo`800006FUH00000001JEP001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH015YF0`0015YF00@005YF000005Ioo`00;goo00<005YF00000eYF0P00:Woo0P0000=J
EP0000000goo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF0`0000AJEP00000005Qo
o`00<7oo0P001EYF0P009Woo0P000eYF0P0017oo0P001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF
00EJEP03001JEUYF008005Yoo`00<Goo00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00
FUH00UYF00<007ooOol01Goo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00002@001EYF00<005YFFUH00eYF0P00F7oo000b
Ool20003FUH00`00FUIJEP03FUH4000FOol40005FUH01000FUIJEP0037oo1@0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10002Woo100000=JEP00FUH01EYF
0`00EWoo000dOol01000FUIJEP001eYF00<005YF00000`003Woo10000UYF00<005YFFUH00eYF00@0
05YF0000019oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000ioo`8000IJEP04001JEUYF001EOol003Eoo`<000MJEP03001JEUYF00=JEPh000IJEP03001J
EUYF00=JEP8001Yoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`8000=J
EP05001JEUYFFUH0001EOol003Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP8002=ooaX0009JEP@000Ioo`D0019oo`800003FUH005YF009JEP8005Ao
o`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=7oo
0P0015YF00<005YFFUH01EYF00<005YFFUH010000goo0`005Goo0P000UYF00<005YF0000E7oo000m
Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000iOol300000eYF001JEP06FUH00`00FUIJ
EP04FUH7000FOol300000eYF001oo`1COol004=ooa80049oo`<000EJEP03001JEUYF00MJEP03001J
EUYF009JEPP000Qoo`H0009JEP8005Eoo`00VWoo0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00@005YFFUIJEPP000=JEP03001JEUYF009JEP8005Eoo`00W7oo0P0000=JEP00FUH01eYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009ioo`H000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Eo
o`00Y7oo2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000EWoo002]Ool80004
FUH01000FUIJEUYF1P00FWoo002eOol8001POol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59154 .75043 m .58983 .69505 L .55931 .69328 L p .707 .577 .707 r
F P
0 g
s
.58983 .69505 m .59154 .75043 L .62349 .74939 L p .707 .577 .707 r
F P
0 g
s
.62349 .74939 m .62178 .69401 L .58983 .69505 L p .707 .577 .707 r
F P
0 g
s
.62178 .69401 m .62349 .74939 L .65374 .74565 L p .707 .577 .707 r
F P
0 g
s
.65374 .74565 m .65203 .69027 L .62178 .69401 L p .707 .577 .707 r
F P
0 g
s
.56102 .74866 m .55931 .69328 L .53319 .68888 L p .707 .577 .707 r
F P
0 g
s
.55931 .69328 m .56102 .74866 L .59154 .75043 L p .707 .577 .707 r
F P
0 g
s
.65203 .69027 m .65374 .74565 L .67932 .73958 L p .707 .577 .707 r
F P
0 g
s
.67932 .73958 m .67761 .6842 L .65203 .69027 L p .707 .577 .707 r
F P
0 g
s
.61487 .80877 m .61598 .77163 L .5841 .77019 L p .707 .577 .707 r
F P
0 g
s
.61598 .77163 m .61487 .80877 L .64584 .80761 L p .707 .577 .707 r
F P
0 g
s
.64584 .80761 m .64696 .77047 L .61598 .77163 L p .707 .577 .707 r
F P
0 g
s
.58298 .80733 m .5841 .77019 L .55443 .76628 L p .707 .577 .707 r
F P
0 g
s
.5841 .77019 m .58298 .80733 L .61487 .80877 L p .707 .577 .707 r
F P
0 g
s
.53319 .68888 m .5349 .74425 L .56102 .74866 L p .707 .577 .707 r
F P
0 g
s
.5349 .74425 m .53319 .68888 L .51405 .68227 L p .707 .577 .707 r
F P
0 g
s
.67761 .6842 m .67932 .73958 L .69774 .73176 L p .707 .577 .707 r
F P
0 g
s
.69774 .73176 m .69603 .67638 L .67761 .6842 L p .707 .577 .707 r
F P
0 g
s
.64696 .77047 m .64584 .80761 L .67288 .80395 L p .707 .577 .707 r
F P
0 g
s
.67288 .80395 m .674 .76682 L .64696 .77047 L p .707 .577 .707 r
F P
0 g
s
.55443 .76628 m .55331 .80342 L .58298 .80733 L p .707 .577 .707 r
F P
0 g
s
.55331 .80342 m .55443 .76628 L .52988 .7603 L p .707 .577 .707 r
F P
0 g
s
.60663 .8492 m .60848 .83061 L .57686 .82678 L p .707 .577 .707 r
F P
0 g
s
.60848 .83061 m .60663 .8492 L .63779 .85059 L p .707 .577 .707 r
F P
0 g
s
.63779 .85059 m .63965 .832 L .60848 .83061 L p .707 .577 .707 r
F P
0 g
s
.57501 .84537 m .57686 .82678 L .54788 .8209 L p .707 .577 .707 r
F P
0 g
s
.57686 .82678 m .57501 .84537 L .60663 .8492 L p .707 .577 .707 r
F P
0 g
s
.51405 .68227 m .51576 .73765 L .5349 .74425 L p .707 .577 .707 r
F P
0 g
s
.63965 .832 m .63779 .85059 L .66545 .84942 L p .707 .577 .707 r
F P
0 g
s
.66545 .84942 m .66731 .83083 L .63965 .832 L p .707 .577 .707 r
F P
0 g
s
.54788 .8209 m .54603 .83949 L .57501 .84537 L p .707 .577 .707 r
F P
0 g
s
.52988 .7603 m .52876 .79744 L .55331 .80342 L p .707 .577 .707 r
F P
0 g
s
.674 .76682 m .67288 .80395 L .69333 .79817 L p .707 .577 .707 r
F P
0 g
s
.69333 .79817 m .69445 .76103 L .674 .76682 L p .707 .577 .707 r
F P
0 g
s
.54603 .83949 m .54788 .8209 L .52438 .81354 L p .707 .577 .707 r
F P
0 g
s
.51576 .73765 m .51405 .68227 L .50375 .67412 L p .707 .577 .707 r
F P
0 g
s
.69603 .67638 m .69774 .73176 L .70718 .72296 L p .707 .577 .707 r
F P
0 g
s
.70718 .72296 m .70547 .66758 L .69603 .67638 L p .707 .577 .707 r
F P
0 g
s
.52876 .79744 m .52988 .7603 L .51285 .75282 L p .707 .577 .707 r
F P
0 g
s
.52438 .81354 m .52252 .83213 L .54603 .83949 L p .707 .577 .707 r
F P
0 g
s
.66731 .83083 m .66545 .84942 L .6869 .8458 L p .707 .577 .707 r
F P
0 g
s
.6869 .8458 m .68876 .82721 L .66731 .83083 L p .707 .577 .707 r
F P
0 g
s
.51285 .75282 m .51173 .78996 L .52876 .79744 L p .707 .577 .707 r
F P
0 g
s
.50375 .67412 m .50546 .72949 L .51576 .73765 L p .707 .577 .707 r
F P
0 g
s
.69445 .76103 m .69333 .79817 L .70519 .79082 L p .707 .577 .707 r
F P
0 g
s
.70519 .79082 m .70631 .75368 L .69445 .76103 L p .707 .577 .707 r
F P
0 g
s
.52252 .83213 m .52438 .81354 L .50866 .80542 L p .707 .577 .707 r
F P
0 g
s
.50866 .80542 m .5068 .824 L .52252 .83213 L p .707 .577 .707 r
F P
0 g
s
.51173 .78996 m .51285 .75282 L .505 .74458 L p .707 .577 .707 r
F P
0 g
s
.50546 .72949 m .50375 .67412 L .5033 .6652 L p .708 .578 .707 r
F P
0 g
s
.70547 .66758 m .70718 .72296 L .70673 .71404 L p .708 .578 .707 r
F P
0 g
s
.70673 .71404 m .70502 .65867 L .70547 .66758 L p .708 .578 .707 r
F P
0 g
s
.68876 .82721 m .6869 .8458 L .70004 .84007 L p .707 .577 .707 r
F P
0 g
s
.70004 .84007 m .70189 .82149 L .68876 .82721 L p .707 .577 .707 r
F P
0 g
s
.505 .74458 m .50388 .78172 L .51173 .78996 L p .707 .577 .707 r
F P
0 g
s
.5033 .6652 m .50501 .72058 L .50546 .72949 L p .708 .578 .707 r
F P
0 g
s
.5068 .824 m .50866 .80542 L .50225 .79733 L p .707 .577 .707 r
F P
0 g
s
.70631 .75368 m .70519 .79082 L .7073 .78262 L p .707 .577 .707 r
F P
0 g
s
.7073 .78262 m .70842 .74548 L .70631 .75368 L p .707 .577 .707 r
F P
0 g
s
.48624 .82175 m .48624 .31986 L .44255 .31683 L p .707 .577 .707 r
F P
0 g
s
.50225 .79733 m .5004 .81592 L .5068 .824 L p .707 .577 .707 r
F P
0 g
s
.50388 .78172 m .505 .74458 L .50711 .73638 L p .707 .577 .707 r
F P
0 g
s
.50501 .72058 m .5033 .6652 L .51274 .65641 L p .707 .577 .707 r
F P
0 g
s
.50711 .73638 m .506 .77352 L .50388 .78172 L p .707 .577 .707 r
F P
0 g
s
.51274 .65641 m .51445 .71178 L .50501 .72058 L p .707 .577 .707 r
F P
0 g
s
.5004 .81592 m .50225 .79733 L .50579 .79007 L p .707 .577 .707 r
F P
0 g
s
.50579 .79007 m .50393 .80866 L .5004 .81592 L p .707 .577 .707 r
F P
0 g
s
.506 .77352 m .50711 .73638 L .51897 .72903 L p .707 .577 .707 r
F P
0 g
s
.51445 .71178 m .51274 .65641 L .53116 .64859 L p .707 .577 .707 r
F P
0 g
s
.51897 .72903 m .51786 .76617 L .506 .77352 L p .707 .577 .707 r
F P
0 g
s
.53116 .64859 m .53287 .70396 L .51445 .71178 L p .707 .577 .707 r
F P
0 g
s
.50393 .80866 m .50579 .79007 L .51893 .78435 L p .707 .577 .707 r
F P
0 g
s
.51893 .78435 m .51707 .80294 L .50393 .80866 L p .707 .577 .707 r
F P
0 g
s
.51786 .76617 m .51897 .72903 L .53942 .72325 L p .707 .577 .707 r
F P
0 g
s
.53942 .72325 m .53831 .76039 L .51786 .76617 L p .707 .577 .707 r
F P
0 g
s
.51707 .80294 m .51893 .78435 L .54037 .78072 L p .707 .577 .707 r
F P
0 g
s
.54037 .78072 m .53852 .79931 L .51707 .80294 L p .707 .577 .707 r
F P
0 g
s
.48624 .31986 m .48624 .82175 L .53129 .821 L p .707 .577 .707 r
F P
0 g
s
.53287 .70396 m .53116 .64859 L .55674 .64251 L p .707 .577 .707 r
F P
0 g
s
.53129 .821 m .53129 .31911 L .48624 .31986 L p .707 .577 .707 r
F P
0 g
s
.55674 .64251 m .55845 .69789 L .53287 .70396 L p .707 .577 .707 r
F P
0 g
s
.55845 .69789 m .55674 .64251 L .58699 .63877 L p .707 .577 .707 r
F P
0 g
s
.53831 .76039 m .53942 .72325 L .56646 .7196 L p .707 .577 .707 r
F P
0 g
s
.58699 .63877 m .5887 .69415 L .55845 .69789 L p .707 .577 .707 r
F P
0 g
s
.56646 .7196 m .56534 .75674 L .53831 .76039 L p .707 .577 .707 r
F P
0 g
s
.56534 .75674 m .56646 .7196 L .59743 .71843 L p .707 .577 .707 r
F P
0 g
s
.53852 .79931 m .54037 .78072 L .56804 .77955 L p .707 .577 .707 r
F P
0 g
s
.56804 .77955 m .56618 .79814 L .53852 .79931 L p .707 .577 .707 r
F P
0 g
s
.59743 .71843 m .59632 .75557 L .56534 .75674 L p .707 .577 .707 r
F P
0 g
s
.56618 .79814 m .56804 .77955 L .5992 .78095 L p .707 .577 .707 r
F P
0 g
s
.5992 .78095 m .59735 .79954 L .56618 .79814 L p .707 .577 .707 r
F P
0 g
s
.53129 .31911 m .53129 .821 L .57327 .81656 L p .707 .577 .707 r
F P
0 g
s
.57327 .81656 m .57327 .31467 L .53129 .31911 L p .707 .577 .707 r
F P
0 g
s
.44255 .81872 m .44255 .31683 L .40447 .31033 L p .707 .577 .707 r
F P
0 g
s
.44255 .31683 m .44255 .81872 L .48624 .82175 L p .707 .577 .707 r
F P
0 g
s
.70189 .82149 m .70004 .84007 L .70358 .83281 L p .707 .577 .707 r
F P
0 g
s
.70358 .83281 m .70543 .81423 L .70189 .82149 L p .707 .577 .707 r
F P
0 g
s
.70502 .65867 m .70673 .71404 L .69643 .70589 L p .707 .577 .707 r
F P
0 g
s
.69643 .70589 m .69472 .65051 L .70502 .65867 L p .707 .577 .707 r
F P
0 g
s
.5887 .69415 m .58699 .63877 L .61894 .63773 L p .707 .577 .707 r
F P
0 g
s
.61894 .63773 m .62065 .69311 L .5887 .69415 L p .707 .577 .707 r
F P
0 g
s
.62932 .71988 m .6282 .75701 L .59632 .75557 L p .707 .577 .707 r
F P
0 g
s
.59632 .75557 m .59743 .71843 L .62932 .71988 L p .707 .577 .707 r
F P
0 g
s
.63082 .78477 m .62897 .80336 L .59735 .79954 L p .707 .577 .707 r
F P
0 g
s
.59735 .79954 m .5992 .78095 L .63082 .78477 L p .707 .577 .707 r
F P
0 g
s
.57327 .31467 m .57327 .81656 L .60808 .80885 L p .707 .577 .707 r
F P
0 g
s
.60808 .80885 m .60808 .30696 L .57327 .31467 L p .707 .577 .707 r
F P
0 g
s
.24671 .71036 m .246 .65432 L .21546 .65244 L p .707 .577 .707 r
F P
0 g
s
.246 .65432 m .24671 .71036 L .27867 .70987 L p .707 .577 .707 r
F P
0 g
s
.27867 .70987 m .27796 .65383 L .246 .65432 L p .707 .577 .707 r
F P
0 g
s
.27796 .65383 m .27867 .70987 L .30893 .70706 L p .707 .577 .707 r
F P
0 g
s
.30893 .70706 m .30822 .65102 L .27796 .65383 L p .707 .577 .707 r
F P
0 g
s
.70842 .74548 m .7073 .78262 L .69946 .77438 L p .707 .577 .707 r
F P
0 g
s
.69946 .77438 m .70057 .73724 L .70842 .74548 L p .707 .577 .707 r
F P
0 g
s
.40447 .81222 m .40447 .31033 L .37575 .30099 L p .707 .577 .707 r
F P
0 g
s
.40447 .31033 m .40447 .81222 L .44255 .81872 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21617 .70849 m .21546 .65244 L .18934 .64838 L p .707 .577 .707 r
F P
0 g
s
.21546 .65244 m .21617 .70849 L .24671 .71036 L p .707 .577 .707 r
F P
0 g
s
.30822 .65102 m .30893 .70706 L .33452 .70221 L p .707 .577 .707 r
F P
0 g
s
.33452 .70221 m .33381 .64617 L .30822 .65102 L p .707 .577 .707 r
F P
0 g
s
.69472 .65051 m .69643 .70589 L .67728 .69928 L p .707 .577 .707 r
F P
0 g
s
.67728 .69928 m .67557 .64391 L .69472 .65051 L p .707 .577 .707 r
F P
0 g
s
.70543 .81423 m .70358 .83281 L .69717 .82473 L p .707 .577 .707 r
F P
0 g
s
.69717 .82473 m .69903 .80614 L .70543 .81423 L p .707 .577 .707 r
F P
0 g
s
.64946 .6395 m .65117 .69488 L .62065 .69311 L p .707 .577 .707 r
F P
0 g
s
.62065 .69311 m .61894 .63773 L .64946 .6395 L p .707 .577 .707 r
F P
0 g
s
.65899 .72378 m .65787 .76092 L .6282 .75701 L p .707 .577 .707 r
F P
0 g
s
.6282 .75701 m .62932 .71988 L .65899 .72378 L p .707 .577 .707 r
F P
0 g
s
.62897 .80336 m .63082 .78477 L .6598 .79066 L p .707 .577 .707 r
F P
0 g
s
.60808 .30696 m .60808 .80885 L .63231 .79863 L p .707 .577 .707 r
F P
0 g
s
.63231 .79863 m .63231 .29675 L .60808 .30696 L p .707 .577 .707 r
F P
0 g
s
.27036 .77709 m .27081 .74041 L .23891 .73943 L p .707 .577 .707 r
F P
0 g
s
.27081 .74041 m .27036 .77709 L .30135 .77507 L p .707 .577 .707 r
F P
0 g
s
.30135 .77507 m .30179 .73839 L .27081 .74041 L p .707 .577 .707 r
F P
0 g
s
.23847 .77611 m .23891 .73943 L .20923 .73553 L p .707 .577 .707 r
F P
0 g
s
.23891 .73943 m .23847 .77611 L .27036 .77709 L p .707 .577 .707 r
F P
0 g
s
.18934 .64838 m .19005 .70443 L .21617 .70849 L p .707 .577 .707 r
F P
0 g
s
.19005 .70443 m .18934 .64838 L .17018 .64254 L p .707 .577 .707 r
F P
0 g
s
.30179 .73839 m .30135 .77507 L .32839 .77024 L p .707 .577 .707 r
F P
0 g
s
.32839 .77024 m .32883 .73355 L .30179 .73839 L p .707 .577 .707 r
F P
0 g
s
.33381 .64617 m .33452 .70221 L .35293 .69579 L p .707 .577 .707 r
F P
0 g
s
.35293 .69579 m .35222 .63975 L .33381 .64617 L p .707 .577 .707 r
F P
0 g
s
.70057 .73724 m .69946 .77438 L .68243 .7669 L p .707 .577 .707 r
F P
0 g
s
.68243 .7669 m .68354 .72976 L .70057 .73724 L p .707 .577 .707 r
F P
0 g
s
.20878 .77221 m .20923 .73553 L .18466 .72911 L p .707 .577 .707 r
F P
0 g
s
.20923 .73553 m .20878 .77221 L .23847 .77611 L p .707 .577 .707 r
F P
0 g
s
.67557 .64391 m .67728 .69928 L .65117 .69488 L p .707 .577 .707 r
F P
0 g
s
.65117 .69488 m .64946 .6395 L .67557 .64391 L p .707 .577 .707 r
F P
0 g
s
.37575 .80288 m .37575 .30099 L .35919 .28973 L p .707 .577 .707 r
F P
0 g
s
.37575 .30099 m .37575 .80288 L .40447 .81222 L p .707 .577 .707 r
F P
0 g
s
.17018 .64254 m .17089 .69858 L .19005 .70443 L p .707 .577 .707 r
F P
0 g
s
.26446 .82611 m .26518 .80833 L .23343 .80592 L p .707 .577 .707 r
F P
0 g
s
.26518 .80833 m .26446 .82611 L .29574 .82471 L p .707 .577 .707 r
F P
0 g
s
.29574 .82471 m .29645 .80693 L .26518 .80833 L p .707 .577 .707 r
F P
0 g
s
.69903 .80614 m .69717 .82473 L .68145 .81661 L p .707 .577 .707 r
F P
0 g
s
.68145 .81661 m .6833 .79802 L .69903 .80614 L p .707 .577 .707 r
F P
0 g
s
.32883 .73355 m .32839 .77024 L .34884 .76307 L p .707 .577 .707 r
F P
0 g
s
.34884 .76307 m .34928 .72639 L .32883 .73355 L p .707 .577 .707 r
F P
0 g
s
.18466 .72911 m .18422 .76579 L .20878 .77221 L p .707 .577 .707 r
F P
0 g
s
.23271 .82369 m .23343 .80592 L .2043 .79993 L p .707 .577 .707 r
F P
0 g
s
.23343 .80592 m .23271 .82369 L .26446 .82611 L p .707 .577 .707 r
F P
0 g
s
.29645 .80693 m .29574 .82471 L .32347 .81964 L p .707 .577 .707 r
F P
0 g
s
.32347 .81964 m .32419 .80186 L .29645 .80693 L p .707 .577 .707 r
F P
0 g
s
.17089 .69858 m .17018 .64254 L .15987 .63548 L p .707 .577 .707 r
F P
0 g
s
.2043 .79993 m .20358 .8177 L .23271 .82369 L p .707 .577 .707 r
F P
0 g
s
.18422 .76579 m .18466 .72911 L .16762 .72078 L p .707 .577 .707 r
F P
0 g
s
.63231 .29675 m .63231 .79863 L .64359 .78691 L p .707 .577 .707 r
F P
0 g
s
.64359 .78691 m .64359 .28502 L .63231 .29675 L p .707 .577 .707 r
F P
0 g
s
.35222 .63975 m .35293 .69579 L .36237 .68843 L p .707 .577 .707 r
F P
0 g
s
.36237 .68843 m .36167 .63238 L .35222 .63975 L p .707 .577 .707 r
F P
0 g
s
.68354 .72976 m .68243 .7669 L .65787 .76092 L p .707 .577 .707 r
F P
0 g
s
.65787 .76092 m .65899 .72378 L .68354 .72976 L p .707 .577 .707 r
F P
0 g
s
.20358 .8177 m .2043 .79993 L .18064 .79094 L p .707 .577 .707 r
F P
0 g
s
.32419 .80186 m .32347 .81964 L .34494 .81138 L p .707 .577 .707 r
F P
0 g
s
.34494 .81138 m .34566 .7936 L .32419 .80186 L p .707 .577 .707 r
F P
0 g
s
.18064 .79094 m .17993 .80872 L .20358 .8177 L p .707 .577 .707 r
F P
0 g
s
.16762 .72078 m .16717 .75746 L .18422 .76579 L p .707 .577 .707 r
F P
0 g
s
.15987 .63548 m .16058 .69152 L .17089 .69858 L p .707 .577 .707 r
F P
0 g
s
.34928 .72639 m .34884 .76307 L .3607 .75427 L p .707 .577 .707 r
F P
0 g
s
.3607 .75427 m .36114 .71758 L .34928 .72639 L p .707 .577 .707 r
F P
0 g
s
.6833 .79802 m .68145 .81661 L .65795 .80924 L p .707 .577 .707 r
F P
0 g
s
.65795 .80924 m .6598 .79066 L .6833 .79802 L p .707 .577 .707 r
F P
0 g
s
.17993 .80872 m .18064 .79094 L .16479 .77985 L p .707 .577 .707 r
F P
0 g
s
.16717 .75746 m .16762 .72078 L .15976 .71137 L p .707 .577 .707 r
F P
0 g
s
.35877 .78298 m .35805 .80075 L .36152 .78879 L p .707 .577 .707 r
F P
0 g
s
.36152 .78879 m .36224 .77102 L .35877 .78298 L p .707 .577 .707 r
F P
0 g
s
.36121 .6248 m .36192 .68085 L .35161 .67379 L p .707 .577 .707 r
F P
0 g
s
.35161 .67379 m .3509 .61774 L .36121 .6248 L p .707 .577 .707 r
F P
0 g
s
.36114 .71758 m .3607 .75427 L .36281 .74469 L p .707 .577 .707 r
F P
0 g
s
.36281 .74469 m .36325 .70801 L .36114 .71758 L p .707 .577 .707 r
F P
0 g
s
.36325 .70801 m .36281 .74469 L .35495 .73528 L p .707 .577 .707 r
F P
0 g
s
.35495 .73528 m .3554 .6986 L .36325 .70801 L p .707 .577 .707 r
F P
0 g
s
.35805 .80075 m .35877 .78298 L .34566 .7936 L p .707 .577 .707 r
F P
0 g
s
.36224 .77102 m .36152 .78879 L .35501 .77668 L p .707 .577 .707 r
F P
0 g
s
.35501 .77668 m .35573 .7589 L .36224 .77102 L p .707 .577 .707 r
F P
0 g
s
.35919 .79161 m .35919 .28973 L .35641 .27764 L p .707 .577 .707 r
F P
0 g
s
.36167 .63238 m .36237 .68843 L .36192 .68085 L p .708 .578 .707 r
F P
0 g
s
.36192 .68085 m .36121 .6248 L .36167 .63238 L p .708 .578 .707 r
F P
0 g
s
.35919 .28973 m .35919 .79161 L .37575 .80288 L p .707 .577 .707 r
F P
0 g
s
.16058 .69152 m .15987 .63548 L .15941 .62789 L p .708 .578 .707 r
F P
0 g
s
.16479 .77985 m .16407 .79763 L .17993 .80872 L p .707 .577 .707 r
F P
0 g
s
.34566 .7936 m .34494 .81138 L .35805 .80075 L p .707 .577 .707 r
F P
0 g
s
.15976 .71137 m .15932 .74805 L .16717 .75746 L p .707 .577 .707 r
F P
0 g
s
.6598 .79066 m .65795 .80924 L .62897 .80336 L p .707 .577 .707 r
F P
0 g
s
.15941 .62789 m .16012 .68394 L .16058 .69152 L p .708 .578 .707 r
F P
0 g
s
.64359 .28502 m .64359 .78691 L .64081 .77482 L p .707 .577 .707 r
F P
0 g
s
.64081 .77482 m .64081 .27293 L .64359 .28502 L p .707 .577 .707 r
F P
0 g
s
.16407 .79763 m .16479 .77985 L .15827 .76773 L p .707 .577 .707 r
F P
0 g
s
.15932 .74805 m .15976 .71137 L .16187 .7018 L p .707 .577 .707 r
F P
0 g
s
.15827 .76773 m .15756 .78551 L .16407 .79763 L p .707 .577 .707 r
F P
0 g
s
.16012 .68394 m .15941 .62789 L .16886 .62053 L p .707 .577 .707 r
F P
0 g
s
.16187 .7018 m .16143 .73848 L .15932 .74805 L p .707 .577 .707 r
F P
0 g
s
.35641 .27764 m .35641 .77953 L .35919 .79161 L p .707 .577 .707 r
F P
0 g
s
.35641 .77953 m .35641 .27764 L .36769 .26591 L p .707 .577 .707 r
F P
0 g
s
.16886 .62053 m .16956 .67658 L .16012 .68394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15756 .78551 m .15827 .76773 L .16174 .75577 L p .707 .577 .707 r
F P
0 g
s
.16174 .75577 m .16102 .77355 L .15756 .78551 L p .707 .577 .707 r
F P
0 g
s
.16143 .73848 m .16187 .7018 L .17373 .693 L p .707 .577 .707 r
F P
0 g
s
.64081 .27293 m .64081 .77482 L .62425 .76356 L p .707 .577 .707 r
F P
0 g
s
.62425 .76356 m .62425 .26167 L .64081 .27293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16956 .67658 m .16886 .62053 L .18727 .61411 L p .707 .577 .707 r
F P
0 g
s
.3509 .61774 m .35161 .67379 L .33245 .66794 L p .707 .577 .707 r
F P
0 g
s
.33245 .66794 m .33174 .6119 L .3509 .61774 L p .707 .577 .707 r
F P
0 g
s
.17373 .693 m .17329 .72968 L .16143 .73848 L p .707 .577 .707 r
F P
0 g
s
.18727 .61411 m .18798 .67015 L .16956 .67658 L p .707 .577 .707 r
F P
0 g
s
.3554 .6986 m .35495 .73528 L .33791 .72696 L p .707 .577 .707 r
F P
0 g
s
.33791 .72696 m .33835 .69028 L .3554 .6986 L p .707 .577 .707 r
F P
0 g
s
.16102 .77355 m .16174 .75577 L .17485 .74514 L p .707 .577 .707 r
F P
0 g
s
.36769 .7678 m .36769 .26591 L .39192 .2557 L p .707 .577 .707 r
F P
0 g
s
.36769 .26591 m .36769 .7678 L .35641 .77953 L p .707 .577 .707 r
F P
0 g
s
.17329 .72968 m .17373 .693 L .19418 .68583 L p .707 .577 .707 r
F P
0 g
s
.18798 .67015 m .18727 .61411 L .21286 .60926 L p .707 .577 .707 r
F P
0 g
s
.17485 .74514 m .17414 .76292 L .16102 .77355 L p .707 .577 .707 r
F P
0 g
s
.33174 .6119 m .33245 .66794 L .30633 .66388 L p .707 .577 .707 r
F P
0 g
s
.30633 .66388 m .30562 .60784 L .33174 .6119 L p .707 .577 .707 r
F P
0 g
s
.35573 .7589 m .35501 .77668 L .33915 .76558 L p .707 .577 .707 r
F P
0 g
s
.33915 .76558 m .33987 .7478 L .35573 .7589 L p .707 .577 .707 r
F P
0 g
s
.19418 .68583 m .19374 .72251 L .17329 .72968 L p .707 .577 .707 r
F P
0 g
s
.62425 .26167 m .62425 .76356 L .59553 .75422 L p .707 .577 .707 r
F P
0 g
s
.59553 .75422 m .59553 .25233 L .62425 .26167 L p .707 .577 .707 r
F P
0 g
s
.21286 .60926 m .21357 .6653 L .18798 .67015 L p .707 .577 .707 r
F P
0 g
s
.33835 .69028 m .33791 .72696 L .31334 .72053 L p .707 .577 .707 r
F P
0 g
s
.31334 .72053 m .31379 .68385 L .33835 .69028 L p .707 .577 .707 r
F P
0 g
s
.21357 .6653 m .21286 .60926 L .24312 .60645 L p .707 .577 .707 r
F P
0 g
s
.30562 .60784 m .30633 .66388 L .27579 .662 L p .707 .577 .707 r
F P
0 g
s
.27579 .662 m .27508 .60596 L .30562 .60784 L p .707 .577 .707 r
F P
0 g
s
.17414 .76292 m .17485 .74514 L .19633 .73689 L p .707 .577 .707 r
F P
0 g
s
.19374 .72251 m .19418 .68583 L .22122 .681 L p .707 .577 .707 r
F P
0 g
s
.19633 .73689 m .19561 .75467 L .17414 .76292 L p .707 .577 .707 r
F P
0 g
s
.24383 .66249 m .24312 .60645 L .27508 .60596 L p .707 .577 .707 r
F P
0 g
s
.24312 .60645 m .24383 .66249 L .21357 .6653 L p .707 .577 .707 r
F P
0 g
s
.27508 .60596 m .27579 .662 L .24383 .66249 L p .707 .577 .707 r
F P
0 g
s
.33987 .7478 m .33915 .76558 L .3155 .7566 L p .707 .577 .707 r
F P
0 g
s
.3155 .7566 m .31622 .73882 L .33987 .7478 L p .707 .577 .707 r
F P
0 g
s
.39192 .2557 m .39192 .75759 L .36769 .7678 L p .707 .577 .707 r
F P
0 g
s
.39192 .75759 m .39192 .2557 L .42673 .24799 L p .707 .577 .707 r
F P
0 g
s
.31379 .68385 m .31334 .72053 L .28366 .71664 L p .707 .577 .707 r
F P
0 g
s
.28366 .71664 m .2841 .67996 L .31379 .68385 L p .707 .577 .707 r
F P
0 g
s
.22122 .681 m .22078 .71768 L .19374 .72251 L p .707 .577 .707 r
F P
0 g
s
.72421 .65928 m .72492 .60423 L .69438 .60104 L p .707 .577 .707 r
F P
0 g
s
.72492 .60423 m .72421 .65928 L .75617 .65952 L p .707 .577 .707 r
F P
0 g
s
.75617 .65952 m .75688 .60446 L .72492 .60423 L p .707 .577 .707 r
F P
0 g
s
.75688 .60446 m .75617 .65952 L .78643 .65679 L p .707 .577 .707 r
F P
0 g
s
.78643 .65679 m .78714 .60173 L .75688 .60446 L p .707 .577 .707 r
F P
0 g
s
.22078 .71768 m .22122 .681 L .25221 .67897 L p .707 .577 .707 r
F P
0 g
s
.19561 .75467 m .19633 .73689 L .22406 .73181 L p .707 .577 .707 r
F P
0 g
s
.69367 .6561 m .69438 .60104 L .66826 .59523 L p .707 .577 .707 r
F P
0 g
s
.69438 .60104 m .69367 .6561 L .72421 .65928 L p .707 .577 .707 r
F P
0 g
s
.2841 .67996 m .28366 .71664 L .25176 .71565 L p .707 .577 .707 r
F P
0 g
s
.25176 .71565 m .25221 .67897 L .2841 .67996 L p .707 .577 .707 r
F P
0 g
s
.78714 .60173 m .78643 .65679 L .81202 .65136 L p .707 .577 .707 r
F P
0 g
s
.81202 .65136 m .81273 .59631 L .78714 .60173 L p .707 .577 .707 r
F P
0 g
s
.59553 .25233 m .59553 .75422 L .55745 .74772 L p .707 .577 .707 r
F P
0 g
s
.55745 .74772 m .55745 .24583 L .59553 .25233 L p .707 .577 .707 r
F P
0 g
s
.25221 .67897 m .25176 .71565 L .22078 .71768 L p .707 .577 .707 r
F P
0 g
s
.31622 .73882 m .3155 .7566 L .28637 .75061 L p .707 .577 .707 r
F P
0 g
s
.28637 .75061 m .28709 .73283 L .31622 .73882 L p .707 .577 .707 r
F P
0 g
s
.22406 .73181 m .22334 .74959 L .19561 .75467 L p .707 .577 .707 r
F P
0 g
s
.74823 .71361 m .74779 .67623 L .7159 .67609 L p .707 .577 .707 r
F P
0 g
s
.74779 .67623 m .74823 .71361 L .77922 .71141 L p .707 .577 .707 r
F P
0 g
s
.77922 .71141 m .77878 .67403 L .74779 .67623 L p .707 .577 .707 r
F P
0 g
s
.22334 .74959 m .22406 .73181 L .25533 .73041 L p .707 .577 .707 r
F P
0 g
s
.71634 .71347 m .7159 .67609 L .68621 .67363 L p .707 .577 .707 r
F P
0 g
s
.7159 .67609 m .71634 .71347 L .74823 .71361 L p .707 .577 .707 r
F P
0 g
s
.66826 .59523 m .66755 .65028 L .69367 .6561 L p .707 .577 .707 r
F P
0 g
s
.28709 .73283 m .28637 .75061 L .25461 .74819 L p .707 .577 .707 r
F P
0 g
s
.25461 .74819 m .25533 .73041 L .28709 .73283 L p .707 .577 .707 r
F P
0 g
s
.66755 .65028 m .66826 .59523 L .6491 .58735 L p .707 .577 .707 r
F P
0 g
s
.42673 .74988 m .42673 .24799 L .46871 .24355 L p .707 .577 .707 r
F P
0 g
s
.42673 .24799 m .42673 .74988 L .39192 .75759 L p .707 .577 .707 r
F P
0 g
s
.81273 .59631 m .81202 .65136 L .83043 .64377 L p .707 .577 .707 r
F P
0 g
s
.83043 .64377 m .83114 .58871 L .81273 .59631 L p .707 .577 .707 r
F P
0 g
s
.25533 .73041 m .25461 .74819 L .22334 .74959 L p .707 .577 .707 r
F P
0 g
s
.77878 .67403 m .77922 .71141 L .80626 .7071 L p .707 .577 .707 r
F P
0 g
s
.80626 .7071 m .80582 .66971 L .77878 .67403 L p .707 .577 .707 r
F P
0 g
s
.68621 .67363 m .68666 .71101 L .71634 .71347 L p .707 .577 .707 r
F P
0 g
s
.55745 .24583 m .55745 .74772 L .51375 .74469 L p .707 .577 .707 r
F P
0 g
s
.51375 .74469 m .51375 .2428 L .55745 .24583 L p .707 .577 .707 r
F P
0 g
s
.74538 .74794 m .74467 .72895 L .71291 .72959 L p .707 .577 .707 r
F P
0 g
s
.74467 .72895 m .74538 .74794 L .77666 .7458 L p .707 .577 .707 r
F P
0 g
s
.77666 .7458 m .77594 .7268 L .74467 .72895 L p .707 .577 .707 r
F P
0 g
s
.68666 .71101 m .68621 .67363 L .66165 .66909 L p .707 .577 .707 r
F P
0 g
s
.71291 .72959 m .71363 .74858 L .74538 .74794 L p .707 .577 .707 r
F P
0 g
s
.71363 .74858 m .71291 .72959 L .68378 .72866 L p .707 .577 .707 r
F P
0 g
s
.77594 .7268 m .77666 .7458 L .80439 .74235 L p .707 .577 .707 r
F P
0 g
s
.80439 .74235 m .80367 .72335 L .77594 .7268 L p .707 .577 .707 r
F P
0 g
s
.68378 .72866 m .6845 .74765 L .71363 .74858 L p .707 .577 .707 r
F P
0 g
s
.46871 .74544 m .46871 .24355 L .51375 .2428 L p .707 .577 .707 r
F P
0 g
s
.46871 .24355 m .46871 .74544 L .42673 .74988 L p .707 .577 .707 r
F P
0 g
s
.6491 .58735 m .64839 .64241 L .66755 .65028 L p .707 .577 .707 r
F P
0 g
s
.66165 .66909 m .66209 .70647 L .68666 .71101 L p .707 .577 .707 r
F P
0 g
s
.51375 .2428 m .51375 .74469 L .46871 .74544 L p .707 .577 .707 r
F P
0 g
s
.80582 .66971 m .80626 .7071 L .82671 .70108 L p .707 .577 .707 r
F P
0 g
s
.82671 .70108 m .82627 .6637 L .80582 .66971 L p .707 .577 .707 r
F P
0 g
s
.64839 .64241 m .6491 .58735 L .63879 .57819 L p .707 .577 .707 r
F P
0 g
s
.6845 .74765 m .68378 .72866 L .66013 .72625 L p .707 .577 .707 r
F P
0 g
s
.83114 .58871 m .83043 .64377 L .83988 .63474 L p .707 .577 .707 r
F P
0 g
s
.83988 .63474 m .84058 .57969 L .83114 .58871 L p .707 .577 .707 r
F P
0 g
s
.66013 .72625 m .66085 .74524 L .6845 .74765 L p .707 .577 .707 r
F P
0 g
s
.66209 .70647 m .66165 .66909 L .6446 .66291 L p .707 .577 .707 r
F P
0 g
s
.80367 .72335 m .80439 .74235 L .82586 .73794 L p .707 .577 .707 r
F P
0 g
s
.82586 .73794 m .82514 .71895 L .80367 .72335 L p .707 .577 .707 r
F P
0 g
s
.6446 .66291 m .64504 .70029 L .66209 .70647 L p .707 .577 .707 r
F P
0 g
s
.63879 .57819 m .63808 .63324 L .64839 .64241 L p .707 .577 .707 r
F P
0 g
s
.82627 .6637 m .82671 .70108 L .83857 .69396 L p .707 .577 .707 r
F P
0 g
s
.83857 .69396 m .83813 .65658 L .82627 .6637 L p .707 .577 .707 r
F P
0 g
s
.66085 .74524 m .66013 .72625 L .64427 .72259 L p .707 .577 .707 r
F P
0 g
s
.64427 .72259 m .64499 .74158 L .66085 .74524 L p .707 .577 .707 r
F P
0 g
s
.82514 .71895 m .82586 .73794 L .83897 .733 L p .707 .577 .707 r
F P
0 g
s
.83897 .733 m .83826 .71401 L .82514 .71895 L p .707 .577 .707 r
F P
0 g
s
.63808 .63324 m .63879 .57819 L .63833 .56862 L p .707 .578 .707 r
F P
0 g
s
.64504 .70029 m .6446 .66291 L .63675 .6557 L p .707 .577 .707 r
F P
0 g
s
.84058 .57969 m .83988 .63474 L .83942 .62518 L p .707 .578 .707 r
F P
0 g
s
.83942 .62518 m .84013 .57013 L .84058 .57969 L p .707 .578 .707 r
F P
0 g
s
.63675 .6557 m .63719 .69308 L .64504 .70029 L p .707 .577 .707 r
F P
0 g
s
.63833 .56862 m .63762 .62368 L .63808 .63324 L p .707 .578 .707 r
F P
0 g
s
.83813 .65658 m .83857 .69396 L .84068 .68643 L p .707 .577 .707 r
F P
0 g
s
.84068 .68643 m .84023 .64905 L .83813 .65658 L p .707 .577 .707 r
F P
0 g
s
.64499 .74158 m .64427 .72259 L .63776 .71805 L p .707 .577 .707 r
F P
0 g
s
.63776 .71805 m .63847 .73704 L .64499 .74158 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83826 .71401 m .83897 .733 L .84244 .72802 L p .707 .577 .707 r
F P
0 g
s
.84244 .72802 m .84173 .70902 L .83826 .71401 L p .707 .577 .707 r
F P
0 g
s
.63762 .62368 m .63833 .56862 L .64777 .5596 L p .707 .577 .707 r
F P
0 g
s
.63719 .69308 m .63675 .6557 L .63885 .64817 L p .707 .577 .707 r
F P
0 g
s
.84013 .57013 m .83942 .62518 L .82911 .61601 L p .707 .577 .707 r
F P
0 g
s
.82911 .61601 m .82982 .56096 L .84013 .57013 L p .707 .577 .707 r
F P
0 g
s
.63885 .64817 m .6393 .68555 L .63719 .69308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64777 .5596 m .64707 .61466 L .63762 .62368 L p .707 .577 .707 r
F P
0 g
s
.37935 .61924 m .38106 .56351 L .35054 .5602 L p .707 .577 .707 r
F P
0 g
s
.38106 .56351 m .37935 .61924 L .4113 .62004 L p .707 .577 .707 r
F P
0 g
s
.4113 .62004 m .41301 .56431 L .38106 .56351 L p .707 .577 .707 r
F P
0 g
s
.41301 .56431 m .4113 .62004 L .44155 .61825 L p .707 .577 .707 r
F P
0 g
s
.44155 .61825 m .44326 .56252 L .41301 .56431 L p .707 .577 .707 r
F P
0 g
s
.84023 .64905 m .84068 .68643 L .83282 .67922 L p .707 .577 .707 r
F P
0 g
s
.83282 .67922 m .83238 .64184 L .84023 .64905 L p .707 .577 .707 r
F P
0 g
s
.63847 .73704 m .63776 .71805 L .64123 .71306 L p .707 .577 .707 r
F P
0 g
s
.64123 .71306 m .64194 .73206 L .63847 .73704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.34883 .61593 m .35054 .5602 L .32442 .55471 L p .707 .577 .707 r
F P
0 g
s
.35054 .5602 m .34883 .61593 L .37935 .61924 L p .707 .577 .707 r
F P
0 g
s
.64707 .61466 m .64777 .5596 L .66619 .55201 L p .707 .577 .707 r
F P
0 g
s
.84173 .70902 m .84244 .72802 L .83593 .72347 L p .707 .577 .707 r
F P
0 g
s
.83593 .72347 m .83521 .70448 L .84173 .70902 L p .707 .577 .707 r
F P
0 g
s
.44326 .56252 m .44155 .61825 L .46713 .61406 L p .707 .577 .707 r
F P
0 g
s
.46713 .61406 m .46884 .55833 L .44326 .56252 L p .707 .577 .707 r
F P
0 g
s
.82982 .56096 m .82911 .61601 L .80995 .60814 L p .707 .577 .707 r
F P
0 g
s
.80995 .60814 m .81066 .55308 L .82982 .56096 L p .707 .577 .707 r
F P
0 g
s
.6393 .68555 m .63885 .64817 L .65071 .64105 L p .707 .577 .707 r
F P
0 g
s
.40368 .68197 m .40256 .64503 L .37068 .64534 L p .707 .577 .707 r
F P
0 g
s
.40256 .64503 m .40368 .68197 L .43465 .67893 L p .707 .577 .707 r
F P
0 g
s
.43465 .67893 m .43354 .64199 L .40256 .64503 L p .707 .577 .707 r
F P
0 g
s
.65071 .64105 m .65116 .67843 L .6393 .68555 L p .707 .577 .707 r
F P
0 g
s
.3718 .68227 m .37068 .64534 L .34101 .64287 L p .707 .577 .707 r
F P
0 g
s
.37068 .64534 m .3718 .68227 L .40368 .68197 L p .707 .577 .707 r
F P
0 g
s
.32442 .55471 m .32271 .61044 L .34883 .61593 L p .707 .577 .707 r
F P
0 g
s
.32271 .61044 m .32442 .55471 L .30528 .54758 L p .707 .577 .707 r
F P
0 g
s
.66619 .55201 m .66548 .60706 L .64707 .61466 L p .707 .577 .707 r
F P
0 g
s
.43354 .64199 m .43465 .67893 L .46169 .67344 L p .707 .577 .707 r
F P
0 g
s
.46169 .67344 m .46057 .6365 L .43354 .64199 L p .707 .577 .707 r
F P
0 g
s
.46884 .55833 m .46713 .61406 L .48555 .60786 L p .707 .577 .707 r
F P
0 g
s
.48555 .60786 m .48726 .55213 L .46884 .55833 L p .707 .577 .707 r
F P
0 g
s
.83238 .64184 m .83282 .67922 L .81578 .67304 L p .707 .577 .707 r
F P
0 g
s
.81578 .67304 m .81534 .63566 L .83238 .64184 L p .707 .577 .707 r
F P
0 g
s
.64194 .73206 m .64123 .71306 L .65434 .70812 L p .707 .577 .707 r
F P
0 g
s
.34101 .64287 m .34212 .6798 L .3718 .68227 L p .707 .577 .707 r
F P
0 g
s
.34212 .6798 m .34101 .64287 L .31645 .63787 L p .707 .577 .707 r
F P
0 g
s
.66548 .60706 m .66619 .55201 L .69178 .54658 L p .707 .577 .707 r
F P
0 g
s
.65434 .70812 m .65506 .72712 L .64194 .73206 L p .707 .577 .707 r
F P
0 g
s
.81066 .55308 m .80995 .60814 L .78383 .60232 L p .707 .577 .707 r
F P
0 g
s
.78383 .60232 m .78454 .54727 L .81066 .55308 L p .707 .577 .707 r
F P
0 g
s
.40265 .72529 m .4008 .70701 L .36917 .70888 L p .707 .577 .707 r
F P
0 g
s
.4008 .70701 m .40265 .72529 L .43382 .72049 L p .707 .577 .707 r
F P
0 g
s
.43382 .72049 m .43196 .70221 L .4008 .70701 L p .707 .577 .707 r
F P
0 g
s
.30528 .54758 m .30357 .60331 L .32271 .61044 L p .707 .577 .707 r
F P
0 g
s
.83521 .70448 m .83593 .72347 L .82007 .71982 L p .707 .577 .707 r
F P
0 g
s
.82007 .71982 m .81935 .70082 L .83521 .70448 L p .707 .577 .707 r
F P
0 g
s
.65116 .67843 m .65071 .64105 L .67116 .63503 L p .707 .577 .707 r
F P
0 g
s
.37103 .72716 m .36917 .70888 L .3402 .70764 L p .707 .577 .707 r
F P
0 g
s
.36917 .70888 m .37103 .72716 L .40265 .72529 L p .707 .577 .707 r
F P
0 g
s
.46057 .6365 m .46169 .67344 L .48214 .66604 L p .707 .577 .707 r
F P
0 g
s
.48214 .66604 m .48102 .62911 L .46057 .6365 L p .707 .577 .707 r
F P
0 g
s
.43196 .70221 m .43382 .72049 L .46148 .71323 L p .707 .577 .707 r
F P
0 g
s
.46148 .71323 m .45962 .69495 L .43196 .70221 L p .707 .577 .707 r
F P
0 g
s
.31645 .63787 m .31757 .67481 L .34212 .6798 L p .707 .577 .707 r
F P
0 g
s
.3402 .70764 m .34205 .72591 L .37103 .72716 L p .707 .577 .707 r
F P
0 g
s
.30357 .60331 m .30528 .54758 L .29498 .5395 L p .707 .577 .707 r
F P
0 g
s
.67116 .63503 m .67161 .67241 L .65116 .67843 L p .707 .577 .707 r
F P
0 g
s
.69178 .54658 m .69107 .60163 L .66548 .60706 L p .707 .577 .707 r
F P
0 g
s
.69107 .60163 m .69178 .54658 L .72204 .54385 L p .707 .577 .707 r
F P
0 g
s
.31757 .67481 m .31645 .63787 L .29942 .63083 L p .707 .577 .707 r
F P
0 g
s
.48726 .55213 m .48555 .60786 L .49499 .60027 L p .707 .577 .707 r
F P
0 g
s
.49499 .60027 m .4967 .54454 L .48726 .55213 L p .707 .577 .707 r
F P
0 g
s
.78454 .54727 m .78383 .60232 L .75329 .59914 L p .707 .577 .707 r
F P
0 g
s
.75329 .59914 m .754 .54409 L .78454 .54727 L p .707 .577 .707 r
F P
0 g
s
.34205 .72591 m .3402 .70764 L .31669 .7034 L p .707 .577 .707 r
F P
0 g
s
.81534 .63566 m .81578 .67304 L .79121 .6685 L p .707 .577 .707 r
F P
0 g
s
.79121 .6685 m .79077 .63112 L .81534 .63566 L p .707 .577 .707 r
F P
0 g
s
.45962 .69495 m .46148 .71323 L .48293 .70422 L p .707 .577 .707 r
F P
0 g
s
.48293 .70422 m .48107 .68594 L .45962 .69495 L p .707 .577 .707 r
F P
0 g
s
.65506 .72712 m .65434 .70812 L .67581 .70372 L p .707 .577 .707 r
F P
0 g
s
.31669 .7034 m .31855 .72168 L .34205 .72591 L p .707 .577 .707 r
F P
0 g
s
.72133 .5989 m .72204 .54385 L .754 .54409 L p .707 .577 .707 r
F P
0 g
s
.72204 .54385 m .72133 .5989 L .69107 .60163 L p .707 .577 .707 r
F P
0 g
s
.754 .54409 m .75329 .59914 L .72133 .5989 L p .707 .577 .707 r
F P
0 g
s
.67581 .70372 m .67653 .72271 L .65506 .72712 L p .707 .577 .707 r
F P
0 g
s
.29942 .63083 m .30054 .66777 L .31757 .67481 L p .707 .577 .707 r
F P
0 g
s
.29498 .5395 m .29327 .59523 L .30357 .60331 L p .707 .577 .707 r
F P
0 g
s
.67161 .67241 m .67116 .63503 L .69821 .63072 L p .707 .577 .707 r
F P
0 g
s
.48102 .62911 m .48214 .66604 L .494 .65747 L p .707 .577 .707 r
F P
0 g
s
.494 .65747 m .49288 .62053 L .48102 .62911 L p .707 .577 .707 r
F P
0 g
s
.81935 .70082 m .82007 .71982 L .79642 .71741 L p .707 .577 .707 r
F P
0 g
s
.79642 .71741 m .7957 .69841 L .81935 .70082 L p .707 .577 .707 r
F P
0 g
s
.69821 .63072 m .69865 .6681 L .67161 .67241 L p .707 .577 .707 r
F P
0 g
s
.79077 .63112 m .79121 .6685 L .76153 .66604 L p .707 .577 .707 r
F P
0 g
s
.76153 .66604 m .76109 .62866 L .79077 .63112 L p .707 .577 .707 r
F P
0 g
s
.31855 .72168 m .31669 .7034 L .30097 .69659 L p .707 .577 .707 r
F P
0 g
s
.29327 .59523 m .29498 .5395 L .29453 .53126 L p .707 .578 .707 r
F P
0 g
s
.48107 .68594 m .48293 .70422 L .49606 .69435 L p .707 .577 .707 r
F P
0 g
s
.49606 .69435 m .49421 .67607 L .48107 .68594 L p .707 .577 .707 r
F P
0 g
s
.30054 .66777 m .29942 .63083 L .29158 .62244 L p .707 .577 .707 r
F P
0 g
s
.69865 .6681 m .69821 .63072 L .72919 .62852 L p .707 .577 .707 r
F P
0 g
s
.30097 .69659 m .30283 .71487 L .31855 .72168 L p .707 .577 .707 r
F P
0 g
s
.4967 .54454 m .49499 .60027 L .49454 .59203 L p .707 .578 .707 r
F P
0 g
s
.49454 .59203 m .49625 .5363 L .4967 .54454 L p .707 .578 .707 r
F P
0 g
s
.67653 .72271 m .67581 .70372 L .70354 .70027 L p .707 .577 .707 r
F P
0 g
s
.70354 .70027 m .70426 .71926 L .67653 .72271 L p .707 .577 .707 r
F P
0 g
s
.76109 .62866 m .76153 .66604 L .72963 .6659 L p .707 .577 .707 r
F P
0 g
s
.72963 .6659 m .72919 .62852 L .76109 .62866 L p .707 .577 .707 r
F P
0 g
s
.7957 .69841 m .79642 .71741 L .76729 .71647 L p .707 .577 .707 r
F P
0 g
s
.76729 .71647 m .76657 .69748 L .7957 .69841 L p .707 .577 .707 r
F P
0 g
s
.72919 .62852 m .72963 .6659 L .69865 .6681 L p .707 .577 .707 r
F P
0 g
s
.29158 .62244 m .29269 .65938 L .30054 .66777 L p .707 .577 .707 r
F P
0 g
s
.29453 .53126 m .29282 .58699 L .29327 .59523 L p .707 .578 .707 r
F P
0 g
s
.49288 .62053 m .494 .65747 L .49611 .64855 L p .707 .577 .707 r
F P
0 g
s
.49611 .64855 m .495 .61161 L .49288 .62053 L p .707 .577 .707 r
F P
0 g
s
.70426 .71926 m .70354 .70027 L .73482 .69812 L p .707 .577 .707 r
F P
0 g
s
.76657 .69748 m .76729 .71647 L .73553 .71711 L p .707 .577 .707 r
F P
0 g
s
.73553 .71711 m .73482 .69812 L .76657 .69748 L p .707 .577 .707 r
F P
0 g
s
.73482 .69812 m .73553 .71711 L .70426 .71926 L p .707 .577 .707 r
F P
0 g
s
.30283 .71487 m .30097 .69659 L .29456 .68787 L p .707 .577 .707 r
F P
0 g
s
.49421 .67607 m .49606 .69435 L .4996 .68457 L p .707 .577 .707 r
F P
0 g
s
.4996 .68457 m .49775 .66629 L .49421 .67607 L p .707 .577 .707 r
F P
0 g
s
.29269 .65938 m .29158 .62244 L .29369 .61352 L p .707 .577 .707 r
F P
0 g
s
.29456 .68787 m .29642 .70615 L .30283 .71487 L p .707 .577 .707 r
F P
0 g
s
.29282 .58699 m .29453 .53126 L .30397 .52367 L p .707 .577 .707 r
F P
0 g
s
.49625 .5363 m .49454 .59203 L .48424 .58395 L p .707 .577 .707 r
F P
0 g
s
.48424 .58395 m .48595 .52822 L .49625 .5363 L p .707 .577 .707 r
F P
0 g
s
.29369 .61352 m .29481 .65046 L .29269 .65938 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30397 .52367 m .30226 .5794 L .29282 .58699 L p .707 .577 .707 r
F P
0 g
s
.495 .61161 m .49611 .64855 L .48827 .64016 L p .707 .577 .707 r
F P
0 g
s
.48827 .64016 m .48715 .60322 L .495 .61161 L p .707 .577 .707 r
F P
0 g
s
.29642 .70615 m .29456 .68787 L .2981 .6781 L p .707 .577 .707 r
F P
0 g
s
.49775 .66629 m .4996 .68457 L .4932 .67585 L p .707 .577 .707 r
F P
0 g
s
.4932 .67585 m .49134 .65757 L .49775 .66629 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30226 .5794 m .30397 .52367 L .32239 .51747 L p .707 .577 .707 r
F P
0 g
s
.2981 .6781 m .29996 .69637 L .29642 .70615 L p .707 .577 .707 r
F P
0 g
s
.29481 .65046 m .29369 .61352 L .30555 .60495 L p .707 .577 .707 r
F P
0 g
s
.48595 .52822 m .48424 .58395 L .46509 .57681 L p .707 .577 .707 r
F P
0 g
s
.46509 .57681 m .4668 .52108 L .48595 .52822 L p .707 .577 .707 r
F P
0 g
s
.30555 .60495 m .30667 .64188 L .29481 .65046 L p .707 .577 .707 r
F P
0 g
s
.32239 .51747 m .32068 .5732 L .30226 .5794 L p .707 .577 .707 r
F P
0 g
s
.48715 .60322 m .48827 .64016 L .47124 .63312 L p .707 .577 .707 r
F P
0 g
s
.47124 .63312 m .47012 .59618 L .48715 .60322 L p .707 .577 .707 r
F P
0 g
s
.29996 .69637 m .2981 .6781 L .31124 .66822 L p .707 .577 .707 r
F P
0 g
s
.32068 .5732 m .32239 .51747 L .34797 .51328 L p .707 .577 .707 r
F P
0 g
s
.49134 .65757 m .4932 .67585 L .47747 .66904 L p .707 .577 .707 r
F P
0 g
s
.47747 .66904 m .47562 .65076 L .49134 .65757 L p .707 .577 .707 r
F P
0 g
s
.4668 .52108 m .46509 .57681 L .43898 .57133 L p .707 .577 .707 r
F P
0 g
s
.43898 .57133 m .44069 .5156 L .4668 .52108 L p .707 .577 .707 r
F P
0 g
s
.30667 .64188 m .30555 .60495 L .326 .59755 L p .707 .577 .707 r
F P
0 g
s
.31124 .66822 m .31309 .6865 L .29996 .69637 L p .707 .577 .707 r
F P
0 g
s
.326 .59755 m .32712 .63449 L .30667 .64188 L p .707 .577 .707 r
F P
0 g
s
.34797 .51328 m .34626 .56901 L .32068 .5732 L p .707 .577 .707 r
F P
0 g
s
.47012 .59618 m .47124 .63312 L .44668 .62812 L p .707 .577 .707 r
F P
0 g
s
.44668 .62812 m .44557 .59119 L .47012 .59618 L p .707 .577 .707 r
F P
0 g
s
.34626 .56901 m .34797 .51328 L .37822 .51149 L p .707 .577 .707 r
F P
0 g
s
.44069 .5156 m .43898 .57133 L .40846 .56802 L p .707 .577 .707 r
F P
0 g
s
.40846 .56802 m .41017 .51229 L .44069 .5156 L p .707 .577 .707 r
F P
0 g
s
.31309 .6865 m .31124 .66822 L .33269 .65921 L p .707 .577 .707 r
F P
0 g
s
.32712 .63449 m .326 .59755 L .35304 .59206 L p .707 .577 .707 r
F P
0 g
s
.37651 .56722 m .37822 .51149 L .41017 .51229 L p .707 .577 .707 r
F P
0 g
s
.37822 .51149 m .37651 .56722 L .34626 .56901 L p .707 .577 .707 r
F P
0 g
s
.47562 .65076 m .47747 .66904 L .45397 .66481 L p .707 .577 .707 r
F P
0 g
s
.45397 .66481 m .45212 .64653 L .47562 .65076 L p .707 .577 .707 r
F P
0 g
s
.41017 .51229 m .40846 .56802 L .37651 .56722 L p .707 .577 .707 r
F P
0 g
s
.33269 .65921 m .33454 .67749 L .31309 .6865 L p .707 .577 .707 r
F P
0 g
s
.44557 .59119 m .44668 .62812 L .41701 .62565 L p .707 .577 .707 r
F P
0 g
s
.41701 .62565 m .4159 .58872 L .44557 .59119 L p .707 .577 .707 r
F P
0 g
s
.35304 .59206 m .35415 .629 L .32712 .63449 L p .707 .577 .707 r
F P
0 g
s
.35415 .629 m .35304 .59206 L .38401 .58902 L p .707 .577 .707 r
F P
0 g
s
.4159 .58872 m .41701 .62565 L .38513 .62596 L p .707 .577 .707 r
F P
0 g
s
.38513 .62596 m .38401 .58902 L .4159 .58872 L p .707 .577 .707 r
F P
0 g
s
.33454 .67749 m .33269 .65921 L .36035 .65196 L p .707 .577 .707 r
F P
0 g
s
.38401 .58902 m .38513 .62596 L .35415 .629 L p .707 .577 .707 r
F P
0 g
s
.45212 .64653 m .45397 .66481 L .42499 .66356 L p .707 .577 .707 r
F P
0 g
s
.42499 .66356 m .42314 .64529 L .45212 .64653 L p .707 .577 .707 r
F P
0 g
s
.36035 .65196 m .3622 .67023 L .33454 .67749 L p .707 .577 .707 r
F P
0 g
s
.3622 .67023 m .36035 .65196 L .39152 .64716 L p .707 .577 .707 r
F P
0 g
s
.42314 .64529 m .42499 .66356 L .39337 .66543 L p .707 .577 .707 r
F P
0 g
s
.39337 .66543 m .39152 .64716 L .42314 .64529 L p .707 .577 .707 r
F P
0 g
s
.39152 .64716 m .39337 .66543 L .3622 .67023 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo8@00O7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0065ooaT000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00GGoo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EGoo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P002EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
05=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`0@OolA0013Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Woo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEPH003eoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo00Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00<003Uoo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@003Eoo`00Dgoo00<005YF
00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001oogooOol200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000<goo001COol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@007oo000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000aOol005=oo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00Dgoo00<005YF0000
1EYF00<005YFFUH00eYF5`0015YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0002moo`00Dgoo00<005YF00001EYF00<005YF00000`000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00<005YFFUH00UYF00@005YFFUH0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00;Woo001COol00`00FUH00003FUH40006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`03001JEP0000<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40003FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`800003FUH005YF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
0005FUH005YFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002io
o`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJ
EP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00Dgoo00@005YFFUH000AJEP03
001JEUYF00=JEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF000^Ool005=oo`04001JEUYF0004FUH60003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP00;Woo001DOol30003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000^Ool005Ioo`@0009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000EJEP04001JEUYFFUH800000eYF0000000F0004FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo0011OolG0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEPD000AJEP03001JEUYF00IJEP03001JEP0000@0009J
EP03001JEUYF00EJEP03001JEUYF00D000AJEP04001JEUYF000^Ool003Uoo`P000AJEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP08001JEUYFFUH005YF001JEP<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP04001JEUYF
000^Ool003Aoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080009JEP03001oogoo02aoo`00<Woo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<007ooOol0;7oo000`Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002ioo`00;Woo0`00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000^Ool002eoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00UYF00<005YFFUH015YF3`001eYF1`001EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEQ4000=JEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP0500001EYF001JEUYF0000
1EYF1@001UYF00<005YFFUH015YF100000=JEP00FUH00eYF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH80004FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YF0000
;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP8000=JEP04001JEUYFFUH40004FUH00`00FUH00002FUH00`00FUIJEP03FUH50006FUH0
0`00FUIJEP08FUH30003FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH50003FUH00`00FUH0000^Ool002eoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
00000`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH00eYF
1@000eYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00006FUH00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YF000005YF008002moo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH30003FUH90002
FUH00`00FUIJEP04FUH30005FUH80003FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<002moo`00;Goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP02FUHN0005
FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000_Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUH000080004FUH00`00FUIJEP05FUH00`00FUH000030003FUH00`00FUIJEP020004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJ
EP00FUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03
001JEUYF00AJEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHE0004FUH00`00FUH000020007FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP0015YF00@005YFFUIJEPP000AJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000=JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEPT000MJEP03
001JEP0000H000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH015YF5`0015YF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01000FUIJEP000eYF1@0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH00eYF1P001eYF00<005YF
FUH01UYF00<005YFFUH01EYF1P000eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH01@000UYF00<007ooOol01Goo
1@001goo20000eYF00<005YFFUH00UYF00<005YF0000;Woo000]Ool01@00FUIJEP00FUH00P0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YF0000
0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF0P0000=JEP000000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YF
FUH02`0000=JEP00Ool01Woo1@0017oo2@000UYF1@000eYF00<005YF0000;Woo000]Ool00`00FUIJ
EP020003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000eYF10001UYF00@005YFFUIJEQ8000AJEP03001JEUYF00EJEP04001JEUYF
FUH2000015YF001JEP00;Woo000]Ool40005FUH00`00FUIJEP04FUHH0004FUH01000FUIJEUYF2000
15YF00<005YFFUH00UYF40001eYF00<005YFFUH00eYF10000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001oo`0]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
0004FUH01000FUH000000UYF00<005YFFUH00UYF3`001UYF00<005YFFUH02EYF00@005YFFUIJEP80
0004FUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000]Ool01000FUIJEP001EYF0`001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF1`0015YF0P000UYF00<005YFFUH00eYF
1@001UYF00<005YFFUH02EYF00@005YF000000AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;Goo00@005YFFUH0009JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEUYF001JEP000UYF0P001EYF0`000UYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH0
25YF0`0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000^Ool5
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00`0000=J
EP00FUH01EYF00<005YF00000`000UYF00<005YFFUH015YF0`001eYF00<005YFFUH01EYF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000_Ool30005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP@00003
FUH005YF00EJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHK0004FUH01000FUH00000;goo
000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP800004FUH000000006FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF1@00
1EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`00<Goo000^Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP@000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0;0003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000_Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP03001JEUYF01L000IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@000=JEP03001JEUYF00AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP<002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000BOol400000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF00<005YFFUH00UYF20000goo1@002Goo3@000UYF00<005YF0000;Goo000]Ool01@00FUIJ
EUYF000015YF1@003Goo0`003Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1@002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP04001JEUYFFUH700001EYF001JEUYF00001Woo1@0037oo1`000UYF100000=JEP00
Ool0;7oo000]Ool01P00FUIJEUYF001JEP<0015oo`D0019ooaL000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH8
0004FUH00`00FUH00007Ool50003Ool90003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]
Ool01000FUIJEUYF0P0000=JEP0000003Woo2@004Woo0`000UYF0P000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800005FUH00000FUH00003FUHI0004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool01000FUH000000eYF00<005YF00000`000Woo2000
15YF00<005YFFUH00UYF1P001goo1@000eYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;Goo0`0015YF00<005YF0000
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001P000eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
000`Ool002eoo`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00;Goo00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<0
00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00H000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD003Moo`00;Goo00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEPH000MJEP03001J
EUYF00YJEPX000QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUHR000lOol0
02ioo`800003FUH005YF00AJEP03001JEUYF009JEPP000QJEPL000IJEP03001JEUYF00AJEP@00005
FUH005YFFUH00006FUH00`00FUIJEP05FUH7000<FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF00<005YF
0000Dgoo000]Ool01@00FUIJEUYF000015YF1P001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
0UYF00<005YFFUH015YF00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01@001UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF10001UYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00=JEP03001JEP0005=oo`00;Goo00H005YFFUIJEP00
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH0
0`00FUIJEP02FUH01000FUIJEP001EYF1@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF
009JEP04001JEUYF001COol002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH01000FUIJEP00
0eYF0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF100000=JEP00FUH00eYF1P001EYF00<005YFFUH00UYF00@005YFFUH005=oo`00;Goo
00@005YFFUH0009oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEP000004FUH01@00FUIJEP00FUH00P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001o
ogoo00=oo`@00003FUH005YF00=JEP04001JEUYF001COol002eoo`<000Ioo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP80009JEP<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP80009JEP03001oogoo00=oo`L000=JEP04001JEUYF001COol002eoo`03
001oogoo00Yoo`D000AJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF009JEPD000=o
o`@00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH90003FUH01000FUIJEUYF0P0000EJEP00FUIJ
EP0005=oo`00;Goo0P0047oo6`002Woo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00P001eYF00<005YFFUH00eYF0P000UYF00<007ooOol0DGoo000/Ool00`00FUH0000HOol5000H
Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH0
0`00FUH00002001COol002aoo`03001JEP00008001Ioo`D001Uoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00=JEP03001JEUYF008005=oo`00;7oo00<0
05YF00000UYF0P005Goo0`006Goo0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0P001eYF00<005YFFUH00eYF00@005YFFUH005Aoo`00;Goo0P0015YF0P00;Woo00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00FUH60002FUH00`00FUIJEP03FUH01000FUIJ
EP00E7oo000]Ool20004FUH01000FUH00000:goo00<005YFFUH00P000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P001UYF00<005YF00000`0015YF0`00EGoo000^Ool00`00FUIJEP02FUH01000FUIJ
EUYF0P009goo0`000UYF00<007oo00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00<0
05YFFUH00eYF0P0000=JEP000000Egoo000_Ool20002FUH00`00FUIJEP03FUH3000ROol20002FUH0
1000FUIJEP000Woo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001eYF00<005YFFUH015YF0P00FGoo000aOol3
0006FUH00`00FUH00003000IOol50004FUH00`00FUH00005Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000060006FUH0
0`00FUIJEP04FUH01000FUH00000Egoo000cOol00`00FUIJEP04FUH00`00FUIJEP03FUHI0003FUH0
0`00FUIJEP03FUH20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH>0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`1DOol003Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00=JEPD000aoo`@000AJEP03001JEUYF009JEP8005Eoo`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8001Aoo`H0
009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<00003Ool00000
00<000moo`<00003FUH005YF00=JEP03001JEP0005Aoo`00>7oo10001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF000001aoo`T000IJEP03001JEUYF00YJEP03001JEUYF
00=JEPL000Eoo`D0019oo`<000=JEP03001JEP0005Aoo`00?7oo10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD002MooaT000aoo`D001Eoo`800004FUH005YF001DOol0041ooaP0
03Qoo`05001JEUYFFUH00006FUH00`00FUH000030009Ool3000HOol3001EOol0095oo`800003FUH0
05YF00EJEP03001JEUYF00=JEPL001Uoo`@00003FUH0000005Eoo`00Tgoo0`001EYF00<005YFFUH0
1EYF00<005YFFUH00UYF6@000UYF00<005YFFUH00P00EGoo002FOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EWoo002J
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00EWoo002MOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001GOol00:5oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH3
001IOol00:QooaT005aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]15\[InvisibleSpace]"     "\
\[InvisibleSpace]6.308757524070883`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 15, "     ", 6.3087575240708826, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72231 m .59613 .66673 L .56496 .66483 L p .707 .577 .707 r
F P
0 g
s
.59613 .66673 m .59613 .72231 L .62796 .72153 L p .707 .577 .707 r
F P
0 g
s
.62796 .72153 m .62796 .66595 L .59613 .66673 L p .707 .577 .707 r
F P
0 g
s
.62796 .66595 m .62796 .72153 L .65734 .71815 L p .707 .577 .707 r
F P
0 g
s
.65734 .71815 m .65734 .66257 L .62796 .66595 L p .707 .577 .707 r
F P
0 g
s
.56496 .72041 m .56496 .66483 L .5375 .66043 L p .707 .577 .707 r
F P
0 g
s
.56496 .66483 m .56496 .72041 L .59613 .72231 L p .707 .577 .707 r
F P
0 g
s
.65734 .66257 m .65734 .71815 L .6814 .7125 L p .707 .577 .707 r
F P
0 g
s
.6814 .7125 m .6814 .65692 L .65734 .66257 L p .707 .577 .707 r
F P
0 g
s
.59613 .76967 m .59613 .73262 L .56496 .73072 L p .707 .577 .707 r
F P
0 g
s
.59613 .73262 m .59613 .76967 L .62796 .7689 L p .707 .577 .707 r
F P
0 g
s
.62796 .7689 m .62796 .73184 L .59613 .73262 L p .707 .577 .707 r
F P
0 g
s
.62796 .73184 m .62796 .7689 L .65735 .76552 L p .707 .577 .707 r
F P
0 g
s
.65735 .76552 m .65734 .72846 L .62796 .73184 L p .707 .577 .707 r
F P
0 g
s
.5375 .66043 m .5375 .71602 L .56496 .72041 L p .707 .577 .707 r
F P
0 g
s
.5375 .71602 m .5375 .66043 L .51644 .65398 L p .707 .577 .707 r
F P
0 g
s
.56496 .76777 m .56496 .73072 L .5375 .72633 L p .707 .577 .707 r
F P
0 g
s
.56496 .73072 m .56496 .76777 L .59613 .76967 L p .707 .577 .707 r
F P
0 g
s
.65734 .72846 m .65735 .76552 L .6814 .75987 L p .707 .577 .707 r
F P
0 g
s
.6814 .75987 m .6814 .72281 L .65734 .72846 L p .707 .577 .707 r
F P
0 g
s
.6814 .65692 m .6814 .7125 L .69777 .70514 L p .707 .577 .707 r
F P
0 g
s
.69777 .70514 m .69777 .64955 L .6814 .65692 L p .707 .577 .707 r
F P
0 g
s
.5375 .72633 m .5375 .76338 L .56496 .76777 L p .707 .577 .707 r
F P
0 g
s
.51644 .65398 m .51644 .70956 L .5375 .71602 L p .707 .577 .707 r
F P
0 g
s
.5375 .76338 m .5375 .72633 L .51644 .71987 L p .707 .577 .707 r
F P
0 g
s
.59613 .83391 m .59613 .81539 L .56496 .81349 L p .707 .577 .707 r
F P
0 g
s
.59613 .81539 m .59613 .83391 L .62796 .83314 L p .707 .577 .707 r
F P
0 g
s
.62796 .83314 m .62796 .81461 L .59613 .81539 L p .707 .577 .707 r
F P
0 g
s
.62796 .81461 m .62796 .83314 L .65735 .82976 L p .707 .577 .707 r
F P
0 g
s
.65735 .82976 m .65735 .81123 L .62796 .81461 L p .707 .577 .707 r
F P
0 g
s
.51644 .70956 m .51644 .65398 L .50385 .6461 L p .707 .577 .707 r
F P
0 g
s
.56496 .81349 m .56496 .83201 L .59613 .83391 L p .707 .577 .707 r
F P
0 g
s
.56496 .83201 m .56496 .81349 L .5375 .80909 L p .707 .577 .707 r
F P
0 g
s
.51644 .71987 m .51644 .75693 L .5375 .76338 L p .707 .577 .707 r
F P
0 g
s
.5375 .80909 m .5375 .82762 L .56496 .83201 L p .707 .577 .707 r
F P
0 g
s
.6814 .72281 m .6814 .75987 L .69777 .7525 L p .707 .577 .707 r
F P
0 g
s
.69777 .7525 m .69777 .71545 L .6814 .72281 L p .707 .577 .707 r
F P
0 g
s
.65735 .81123 m .65735 .82976 L .6814 .82411 L p .707 .577 .707 r
F P
0 g
s
.6814 .82411 m .6814 .80558 L .65735 .81123 L p .707 .577 .707 r
F P
0 g
s
.50385 .6461 m .50385 .70168 L .51644 .70956 L p .707 .577 .707 r
F P
0 g
s
.69777 .64955 m .69777 .70514 L .70485 .69677 L p .707 .577 .707 r
F P
0 g
s
.70485 .69677 m .70485 .64119 L .69777 .64955 L p .707 .577 .707 r
F P
0 g
s
.5375 .82762 m .5375 .80909 L .51644 .80264 L p .707 .577 .707 r
F P
0 g
s
.51644 .75693 m .51644 .71987 L .50385 .71199 L p .707 .577 .707 r
F P
0 g
s
.51644 .80264 m .51644 .82117 L .5375 .82762 L p .707 .577 .707 r
F P
0 g
s
.50385 .70168 m .50385 .6461 L .50095 .63755 L p .707 .577 .707 r
F P
0 g
s
.50385 .71199 m .50385 .74904 L .51644 .75693 L p .707 .577 .707 r
F P
0 g
s
.6814 .80558 m .6814 .82411 L .69777 .81674 L p .707 .577 .707 r
F P
0 g
s
.69777 .81674 m .69777 .79821 L .6814 .80558 L p .707 .577 .707 r
F P
0 g
s
.69777 .71545 m .69777 .7525 L .70485 .74414 L p .707 .577 .707 r
F P
0 g
s
.70485 .74414 m .70485 .70708 L .69777 .71545 L p .707 .577 .707 r
F P
0 g
s
.51644 .82117 m .51644 .80264 L .50385 .79476 L p .707 .577 .707 r
F P
0 g
s
.50095 .63755 m .50095 .69314 L .50385 .70168 L p .707 .577 .707 r
F P
0 g
s
.70485 .64119 m .70485 .69677 L .70195 .68823 L p .707 .577 .707 r
F P
0 g
s
.70195 .68823 m .70195 .63265 L .70485 .64119 L p .707 .577 .707 r
F P
0 g
s
.50385 .79476 m .50385 .81328 L .51644 .82117 L p .707 .577 .707 r
F P
0 g
s
.50385 .74904 m .50385 .71199 L .50095 .70345 L p .707 .577 .707 r
F P
0 g
s
.50095 .70345 m .50095 .7405 L .50385 .74904 L p .707 .577 .707 r
F P
0 g
s
.69777 .79821 m .69777 .81674 L .70485 .80838 L p .707 .577 .707 r
F P
0 g
s
.70485 .80838 m .70485 .78985 L .69777 .79821 L p .707 .577 .707 r
F P
0 g
s
.50095 .69314 m .50095 .63755 L .50804 .62919 L p .707 .577 .707 r
F P
0 g
s
.70485 .70708 m .70485 .74414 L .70195 .73559 L p .707 .577 .707 r
F P
0 g
s
.70195 .73559 m .70195 .69854 L .70485 .70708 L p .707 .577 .707 r
F P
0 g
s
.50385 .81328 m .50385 .79476 L .50095 .78621 L p .707 .577 .707 r
F P
0 g
s
.49044 .85617 m .49044 .35428 L .44643 .3516 L p .707 .577 .707 r
F P
0 g
s
.50804 .62919 m .50804 .68477 L .50095 .69314 L p .707 .577 .707 r
F P
0 g
s
.50095 .78621 m .50095 .80474 L .50385 .81328 L p .707 .577 .707 r
F P
0 g
s
.50095 .7405 m .50095 .70345 L .50804 .69508 L p .707 .577 .707 r
F P
0 g
s
.50804 .69508 m .50804 .73214 L .50095 .7405 L p .707 .577 .707 r
F P
0 g
s
.50804 .68477 m .50804 .62919 L .5244 .62182 L p .707 .577 .707 r
F P
0 g
s
.50095 .80474 m .50095 .78621 L .50804 .77785 L p .707 .577 .707 r
F P
0 g
s
.5244 .62182 m .5244 .6774 L .50804 .68477 L p .707 .577 .707 r
F P
0 g
s
.50804 .77785 m .50804 .79638 L .50095 .80474 L p .707 .577 .707 r
F P
0 g
s
.50804 .73214 m .50804 .69508 L .5244 .68771 L p .707 .577 .707 r
F P
0 g
s
.5244 .68771 m .5244 .72477 L .50804 .73214 L p .707 .577 .707 r
F P
0 g
s
.50804 .79638 m .50804 .77785 L .5244 .77048 L p .707 .577 .707 r
F P
0 g
s
.5244 .77048 m .5244 .78901 L .50804 .79638 L p .707 .577 .707 r
F P
0 g
s
.5244 .78901 m .5244 .77048 L .54846 .76483 L p .707 .577 .707 r
F P
0 g
s
.54846 .76483 m .54846 .78336 L .5244 .78901 L p .707 .577 .707 r
F P
0 g
s
.49044 .35428 m .49044 .85617 L .53538 .85507 L p .707 .577 .707 r
F P
0 g
s
.5244 .6774 m .5244 .62182 L .54846 .61617 L p .707 .577 .707 r
F P
0 g
s
.54846 .61617 m .54846 .67175 L .5244 .6774 L p .707 .577 .707 r
F P
0 g
s
.5244 .72477 m .5244 .68771 L .54846 .68206 L p .707 .577 .707 r
F P
0 g
s
.54846 .68206 m .54846 .71912 L .5244 .72477 L p .707 .577 .707 r
F P
0 g
s
.53538 .85507 m .53538 .35318 L .49044 .35428 L p .707 .577 .707 r
F P
0 g
s
.70195 .63265 m .70195 .68823 L .68936 .68034 L p .707 .577 .707 r
F P
0 g
s
.68936 .68034 m .68936 .62476 L .70195 .63265 L p .707 .577 .707 r
F P
0 g
s
.54846 .67175 m .54846 .61617 L .57784 .61279 L p .707 .577 .707 r
F P
0 g
s
.57784 .61279 m .57784 .66838 L .54846 .67175 L p .707 .577 .707 r
F P
0 g
s
.54846 .71912 m .54846 .68206 L .57784 .67869 L p .707 .577 .707 r
F P
0 g
s
.57784 .67869 m .57784 .71574 L .54846 .71912 L p .707 .577 .707 r
F P
0 g
s
.54846 .78336 m .54846 .76483 L .57784 .76145 L p .707 .577 .707 r
F P
0 g
s
.57784 .76145 m .57784 .77998 L .54846 .78336 L p .707 .577 .707 r
F P
0 g
s
.53538 .35318 m .53538 .85507 L .57686 .8503 L p .707 .577 .707 r
F P
0 g
s
.57686 .8503 m .57686 .34841 L .53538 .35318 L p .707 .577 .707 r
F P
0 g
s
.44643 .85349 m .44643 .3516 L .40766 .3454 L p .707 .577 .707 r
F P
0 g
s
.44643 .3516 m .44643 .85349 L .49044 .85617 L p .707 .577 .707 r
F P
0 g
s
.25312 .68549 m .25312 .62991 L .22195 .62801 L p .707 .577 .707 r
F P
0 g
s
.25312 .62991 m .25312 .68549 L .28495 .68472 L p .707 .577 .707 r
F P
0 g
s
.28495 .68472 m .28495 .62913 L .25312 .62991 L p .707 .577 .707 r
F P
0 g
s
.70485 .78985 m .70485 .80838 L .70195 .79983 L p .707 .577 .707 r
F P
0 g
s
.70195 .79983 m .70195 .78131 L .70485 .78985 L p .707 .577 .707 r
F P
0 g
s
.28495 .62913 m .28495 .68472 L .31434 .68134 L p .707 .577 .707 r
F P
0 g
s
.31434 .68134 m .31434 .62576 L .28495 .62913 L p .707 .577 .707 r
F P
0 g
s
.22195 .68359 m .22195 .62801 L .19449 .62362 L p .707 .577 .707 r
F P
0 g
s
.22195 .62801 m .22195 .68359 L .25312 .68549 L p .707 .577 .707 r
F P
0 g
s
.57784 .66838 m .57784 .61279 L .60968 .61202 L p .707 .577 .707 r
F P
0 g
s
.60968 .61202 m .60968 .6676 L .57784 .66838 L p .707 .577 .707 r
F P
0 g
s
.57784 .71574 m .57784 .67869 L .60968 .67791 L p .707 .577 .707 r
F P
0 g
s
.60968 .67791 m .60968 .71496 L .57784 .71574 L p .707 .577 .707 r
F P
0 g
s
.57784 .77998 m .57784 .76145 L .60968 .76067 L p .707 .577 .707 r
F P
0 g
s
.60968 .76067 m .60968 .7792 L .57784 .77998 L p .707 .577 .707 r
F P
0 g
s
.57686 .34841 m .57686 .8503 L .61082 .84233 L p .707 .577 .707 r
F P
0 g
s
.64085 .61392 m .64085 .6695 L .60968 .6676 L p .707 .577 .707 r
F P
0 g
s
.60968 .6676 m .60968 .61202 L .64085 .61392 L p .707 .577 .707 r
F P
0 g
s
.64085 .67981 m .64085 .71686 L .60968 .71496 L p .707 .577 .707 r
F P
0 g
s
.60968 .71496 m .60968 .67791 L .64085 .67981 L p .707 .577 .707 r
F P
0 g
s
.64085 .76258 m .64085 .7811 L .60968 .7792 L p .707 .577 .707 r
F P
0 g
s
.60968 .7792 m .60968 .76067 L .64085 .76258 L p .707 .577 .707 r
F P
0 g
s
.61082 .84233 m .61082 .34044 L .57686 .34841 L p .707 .577 .707 r
F P
0 g
s
.70195 .69854 m .70195 .73559 L .68936 .72771 L p .707 .577 .707 r
F P
0 g
s
.68936 .72771 m .68936 .69066 L .70195 .69854 L p .707 .577 .707 r
F P
0 g
s
.31434 .62576 m .31434 .68134 L .33839 .67569 L p .707 .577 .707 r
F P
0 g
s
.33839 .67569 m .33839 .62011 L .31434 .62576 L p .707 .577 .707 r
F P
0 g
s
.25312 .73286 m .25312 .6958 L .22195 .6939 L p .707 .577 .707 r
F P
0 g
s
.25312 .6958 m .25312 .73286 L .28495 .73208 L p .707 .577 .707 r
F P
0 g
s
.28495 .73208 m .28495 .69503 L .25312 .6958 L p .707 .577 .707 r
F P
0 g
s
.40766 .84729 m .40766 .3454 L .37794 .33629 L p .707 .577 .707 r
F P
0 g
s
.40766 .3454 m .40766 .84729 L .44643 .85349 L p .707 .577 .707 r
F P
0 g
s
.68936 .62476 m .68936 .68034 L .66831 .67389 L p .707 .577 .707 r
F P
0 g
s
.66831 .67389 m .66831 .61831 L .68936 .62476 L p .707 .577 .707 r
F P
0 g
s
.28495 .69503 m .28495 .73208 L .31434 .7287 L p .707 .577 .707 r
F P
0 g
s
.31434 .7287 m .31434 .69165 L .28495 .69503 L p .707 .577 .707 r
F P
0 g
s
.19449 .62362 m .19449 .6792 L .22195 .68359 L p .707 .577 .707 r
F P
0 g
s
.19449 .6792 m .19449 .62362 L .17343 .61716 L p .707 .577 .707 r
F P
0 g
s
.22195 .73096 m .22195 .6939 L .19449 .68951 L p .707 .577 .707 r
F P
0 g
s
.22195 .6939 m .22195 .73096 L .25312 .73286 L p .707 .577 .707 r
F P
0 g
s
.70195 .78131 m .70195 .79983 L .68936 .79195 L p .707 .577 .707 r
F P
0 g
s
.68936 .79195 m .68936 .77342 L .70195 .78131 L p .707 .577 .707 r
F P
0 g
s
.31434 .69165 m .31434 .7287 L .33839 .72305 L p .707 .577 .707 r
F P
0 g
s
.33839 .72305 m .33839 .686 L .31434 .69165 L p .707 .577 .707 r
F P
0 g
s
.33839 .62011 m .33839 .67569 L .35476 .66832 L p .707 .577 .707 r
F P
0 g
s
.35476 .66832 m .35476 .61274 L .33839 .62011 L p .707 .577 .707 r
F P
0 g
s
.19449 .68951 m .19449 .72657 L .22195 .73096 L p .707 .577 .707 r
F P
0 g
s
.61082 .34044 m .61082 .84233 L .63393 .83192 L p .707 .577 .707 r
F P
0 g
s
.63393 .83192 m .63393 .33004 L .61082 .34044 L p .707 .577 .707 r
F P
0 g
s
.68936 .69066 m .68936 .72771 L .66831 .72126 L p .707 .577 .707 r
F P
0 g
s
.66831 .72126 m .66831 .6842 L .68936 .69066 L p .707 .577 .707 r
F P
0 g
s
.17343 .61716 m .17343 .67275 L .19449 .6792 L p .707 .577 .707 r
F P
0 g
s
.19449 .72657 m .19449 .68951 L .17343 .68306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7971 m .25312 .77857 L .22195 .77667 L p .707 .577 .707 r
F P
0 g
s
.25312 .77857 m .25312 .7971 L .28495 .79632 L p .707 .577 .707 r
F P
0 g
s
.28495 .79632 m .28495 .77779 L .25312 .77857 L p .707 .577 .707 r
F P
0 g
s
.66831 .61831 m .66831 .67389 L .64085 .6695 L p .707 .577 .707 r
F P
0 g
s
.64085 .6695 m .64085 .61392 L .66831 .61831 L p .707 .577 .707 r
F P
0 g
s
.28495 .77779 m .28495 .79632 L .31434 .79294 L p .707 .577 .707 r
F P
0 g
s
.31434 .79294 m .31434 .77441 L .28495 .77779 L p .707 .577 .707 r
F P
0 g
s
.17343 .67275 m .17343 .61716 L .16084 .60928 L p .707 .577 .707 r
F P
0 g
s
.22195 .77667 m .22195 .7952 L .25312 .7971 L p .707 .577 .707 r
F P
0 g
s
.22195 .7952 m .22195 .77667 L .19449 .77228 L p .707 .577 .707 r
F P
0 g
s
.37794 .83817 m .37794 .33629 L .36016 .32515 L p .707 .577 .707 r
F P
0 g
s
.37794 .33629 m .37794 .83817 L .40766 .84729 L p .707 .577 .707 r
F P
0 g
s
.17343 .68306 m .17343 .72011 L .19449 .72657 L p .707 .577 .707 r
F P
0 g
s
.19449 .77228 m .19449 .79081 L .22195 .7952 L p .707 .577 .707 r
F P
0 g
s
.33839 .686 m .33839 .72305 L .35476 .71569 L p .707 .577 .707 r
F P
0 g
s
.35476 .71569 m .35476 .67863 L .33839 .686 L p .707 .577 .707 r
F P
0 g
s
.31434 .77441 m .31434 .79294 L .33839 .78729 L p .707 .577 .707 r
F P
0 g
s
.33839 .78729 m .33839 .76876 L .31434 .77441 L p .707 .577 .707 r
F P
0 g
s
.68936 .77342 m .68936 .79195 L .66831 .7855 L p .707 .577 .707 r
F P
0 g
s
.66831 .7855 m .66831 .76697 L .68936 .77342 L p .707 .577 .707 r
F P
0 g
s
.66831 .6842 m .66831 .72126 L .64085 .71686 L p .707 .577 .707 r
F P
0 g
s
.64085 .71686 m .64085 .67981 L .66831 .6842 L p .707 .577 .707 r
F P
0 g
s
.16084 .60928 m .16084 .66486 L .17343 .67275 L p .707 .577 .707 r
F P
0 g
s
.35476 .61274 m .35476 .66832 L .36184 .65996 L p .707 .577 .707 r
F P
0 g
s
.36184 .65996 m .36184 .60437 L .35476 .61274 L p .707 .577 .707 r
F P
0 g
s
.19449 .79081 m .19449 .77228 L .17343 .76582 L p .707 .577 .707 r
F P
0 g
s
.17343 .72011 m .17343 .68306 L .16084 .67517 L p .707 .577 .707 r
F P
0 g
s
.17343 .76582 m .17343 .78435 L .19449 .79081 L p .707 .577 .707 r
F P
0 g
s
.66831 .76697 m .66831 .7855 L .64085 .7811 L p .707 .577 .707 r
F P
0 g
s
.64085 .7811 m .64085 .76258 L .66831 .76697 L p .707 .577 .707 r
F P
0 g
s
.63393 .33004 m .63393 .83192 L .64393 .82012 L p .707 .577 .707 r
F P
0 g
s
.64393 .82012 m .64393 .31823 L .63393 .33004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66486 m .16084 .60928 L .15794 .60074 L p .707 .577 .707 r
F P
0 g
s
.16084 .67517 m .16084 .71223 L .17343 .72011 L p .707 .577 .707 r
F P
0 g
s
.33839 .76876 m .33839 .78729 L .35476 .77992 L p .707 .577 .707 r
F P
0 g
s
.35476 .77992 m .35476 .7614 L .33839 .76876 L p .707 .577 .707 r
F P
0 g
s
.35476 .67863 m .35476 .71569 L .36184 .70732 L p .707 .577 .707 r
F P
0 g
s
.36184 .70732 m .36184 .67027 L .35476 .67863 L p .707 .577 .707 r
F P
0 g
s
.17343 .78435 m .17343 .76582 L .16084 .75794 L p .707 .577 .707 r
F P
0 g
s
.15794 .60074 m .15794 .65632 L .16084 .66486 L p .707 .577 .707 r
F P
0 g
s
.36184 .60437 m .36184 .65996 L .35894 .65141 L p .707 .577 .707 r
F P
0 g
s
.35894 .65141 m .35894 .59583 L .36184 .60437 L p .707 .577 .707 r
F P
0 g
s
.35476 .7614 m .35476 .77992 L .36184 .77156 L p .707 .577 .707 r
F P
0 g
s
.36184 .77156 m .36184 .75303 L .35476 .7614 L p .707 .577 .707 r
F P
0 g
s
.36184 .67027 m .36184 .70732 L .35894 .69878 L p .707 .577 .707 r
F P
0 g
s
.35894 .69878 m .35894 .66172 L .36184 .67027 L p .707 .577 .707 r
F P
0 g
s
.35894 .59583 m .35894 .65141 L .34635 .64353 L p .707 .577 .707 r
F P
0 g
s
.34635 .64353 m .34635 .58795 L .35894 .59583 L p .707 .577 .707 r
F P
0 g
s
.36184 .75303 m .36184 .77156 L .35894 .76302 L p .707 .577 .707 r
F P
0 g
s
.35894 .76302 m .35894 .74449 L .36184 .75303 L p .707 .577 .707 r
F P
0 g
s
.35894 .66172 m .35894 .69878 L .34635 .69089 L p .707 .577 .707 r
F P
0 g
s
.34635 .69089 m .34635 .65384 L .35894 .66172 L p .707 .577 .707 r
F P
0 g
s
.36016 .82704 m .36016 .32515 L .35607 .31309 L p .707 .577 .707 r
F P
0 g
s
.36016 .32515 m .36016 .82704 L .37794 .83817 L p .707 .577 .707 r
F P
0 g
s
.16084 .75794 m .16084 .77647 L .17343 .78435 L p .707 .577 .707 r
F P
0 g
s
.16084 .71223 m .16084 .67517 L .15794 .66663 L p .707 .577 .707 r
F P
0 g
s
.15794 .66663 m .15794 .70369 L .16084 .71223 L p .707 .577 .707 r
F P
0 g
s
.15794 .65632 m .15794 .60074 L .16503 .59237 L p .707 .577 .707 r
F P
0 g
s
.16084 .77647 m .16084 .75794 L .15794 .7494 L p .707 .577 .707 r
F P
0 g
s
.64393 .31823 m .64393 .82012 L .63984 .80806 L p .707 .577 .707 r
F P
0 g
s
.63984 .80806 m .63984 .30617 L .64393 .31823 L p .707 .577 .707 r
F P
0 g
s
.16503 .59237 m .16503 .64796 L .15794 .65632 L p .707 .577 .707 r
F P
0 g
s
.15794 .7494 m .15794 .76793 L .16084 .77647 L p .707 .577 .707 r
F P
0 g
s
.15794 .70369 m .15794 .66663 L .16503 .65827 L p .707 .577 .707 r
F P
0 g
s
.16503 .65827 m .16503 .69532 L .15794 .70369 L p .707 .577 .707 r
F P
0 g
s
.35894 .74449 m .35894 .76302 L .34635 .75513 L p .707 .577 .707 r
F P
0 g
s
.34635 .75513 m .34635 .73661 L .35894 .74449 L p .707 .577 .707 r
F P
0 g
s
.35607 .31309 m .35607 .81498 L .36016 .82704 L p .707 .577 .707 r
F P
0 g
s
.35607 .81498 m .35607 .31309 L .36607 .30129 L p .707 .577 .707 r
F P
0 g
s
.16503 .64796 m .16503 .59237 L .1814 .58501 L p .707 .577 .707 r
F P
0 g
s
.15794 .76793 m .15794 .7494 L .16503 .74103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58501 m .1814 .64059 L .16503 .64796 L p .707 .577 .707 r
F P
0 g
s
.34635 .58795 m .34635 .64353 L .3253 .63708 L p .707 .577 .707 r
F P
0 g
s
.3253 .63708 m .3253 .58149 L .34635 .58795 L p .707 .577 .707 r
F P
0 g
s
.16503 .74103 m .16503 .75956 L .15794 .76793 L p .707 .577 .707 r
F P
0 g
s
.16503 .69532 m .16503 .65827 L .1814 .6509 L p .707 .577 .707 r
F P
0 g
s
.63984 .30617 m .63984 .80806 L .62206 .79693 L p .707 .577 .707 r
F P
0 g
s
.62206 .79693 m .62206 .29504 L .63984 .30617 L p .707 .577 .707 r
F P
0 g
s
.1814 .64059 m .1814 .58501 L .20545 .57936 L p .707 .577 .707 r
F P
0 g
s
.1814 .6509 m .1814 .68795 L .16503 .69532 L p .707 .577 .707 r
F P
0 g
s
.34635 .65384 m .34635 .69089 L .3253 .68444 L p .707 .577 .707 r
F P
0 g
s
.3253 .68444 m .3253 .64739 L .34635 .65384 L p .707 .577 .707 r
F P
0 g
s
.3253 .58149 m .3253 .63708 L .29784 .63268 L p .707 .577 .707 r
F P
0 g
s
.29784 .63268 m .29784 .5771 L .3253 .58149 L p .707 .577 .707 r
F P
0 g
s
.16503 .75956 m .16503 .74103 L .1814 .73367 L p .707 .577 .707 r
F P
0 g
s
.20545 .57936 m .20545 .63494 L .1814 .64059 L p .707 .577 .707 r
F P
0 g
s
.36607 .80318 m .36607 .30129 L .38918 .29088 L p .707 .577 .707 r
F P
0 g
s
.36607 .30129 m .36607 .80318 L .35607 .81498 L p .707 .577 .707 r
F P
0 g
s
.1814 .68795 m .1814 .6509 L .20545 .64525 L p .707 .577 .707 r
F P
0 g
s
.1814 .73367 m .1814 .75219 L .16503 .75956 L p .707 .577 .707 r
F P
0 g
s
.20545 .63494 m .20545 .57936 L .23483 .57598 L p .707 .577 .707 r
F P
0 g
s
.29784 .5771 m .29784 .63268 L .26667 .63078 L p .707 .577 .707 r
F P
0 g
s
.26667 .63078 m .26667 .5752 L .29784 .5771 L p .707 .577 .707 r
F P
0 g
s
.20545 .64525 m .20545 .6823 L .1814 .68795 L p .707 .577 .707 r
F P
0 g
s
.34635 .73661 m .34635 .75513 L .3253 .74868 L p .707 .577 .707 r
F P
0 g
s
.3253 .74868 m .3253 .73015 L .34635 .73661 L p .707 .577 .707 r
F P
0 g
s
.3253 .64739 m .3253 .68444 L .29784 .68005 L p .707 .577 .707 r
F P
0 g
s
.29784 .68005 m .29784 .64299 L .3253 .64739 L p .707 .577 .707 r
F P
0 g
s
.23483 .63156 m .23483 .57598 L .26667 .5752 L p .707 .577 .707 r
F P
0 g
s
.23483 .57598 m .23483 .63156 L .20545 .63494 L p .707 .577 .707 r
F P
0 g
s
.26667 .5752 m .26667 .63078 L .23483 .63156 L p .707 .577 .707 r
F P
0 g
s
.73333 .63027 m .73333 .57469 L .70216 .57279 L p .707 .577 .707 r
F P
0 g
s
.73333 .57469 m .73333 .63027 L .76517 .62949 L p .707 .577 .707 r
F P
0 g
s
.76517 .62949 m .76517 .57391 L .73333 .57469 L p .707 .577 .707 r
F P
0 g
s
.62206 .29504 m .62206 .79693 L .59233 .78781 L p .707 .577 .707 r
F P
0 g
s
.59233 .78781 m .59233 .28592 L .62206 .29504 L p .707 .577 .707 r
F P
0 g
s
.20545 .6823 m .20545 .64525 L .23483 .64187 L p .707 .577 .707 r
F P
0 g
s
.76517 .57391 m .76517 .62949 L .79455 .62611 L p .707 .577 .707 r
F P
0 g
s
.79455 .62611 m .79455 .57053 L .76517 .57391 L p .707 .577 .707 r
F P
0 g
s
.1814 .75219 m .1814 .73367 L .20545 .72802 L p .707 .577 .707 r
F P
0 g
s
.70216 .62837 m .70216 .57279 L .6747 .5684 L p .707 .577 .707 r
F P
0 g
s
.70216 .57279 m .70216 .62837 L .73333 .63027 L p .707 .577 .707 r
F P
0 g
s
.20545 .72802 m .20545 .74654 L .1814 .75219 L p .707 .577 .707 r
F P
0 g
s
.29784 .64299 m .29784 .68005 L .26667 .67815 L p .707 .577 .707 r
F P
0 g
s
.26667 .67815 m .26667 .64109 L .29784 .64299 L p .707 .577 .707 r
F P
0 g
s
.23483 .64187 m .23483 .67893 L .20545 .6823 L p .707 .577 .707 r
F P
0 g
s
.23483 .67893 m .23483 .64187 L .26667 .64109 L p .707 .577 .707 r
F P
0 g
s
.79455 .57053 m .79455 .62611 L .8186 .62046 L p .707 .577 .707 r
F P
0 g
s
.8186 .62046 m .8186 .56488 L .79455 .57053 L p .707 .577 .707 r
F P
0 g
s
.38918 .29088 m .38918 .79277 L .36607 .80318 L p .707 .577 .707 r
F P
0 g
s
.38918 .79277 m .38918 .29088 L .42314 .28291 L p .707 .577 .707 r
F P
0 g
s
.26667 .64109 m .26667 .67815 L .23483 .67893 L p .707 .577 .707 r
F P
0 g
s
.3253 .73015 m .3253 .74868 L .29784 .74429 L p .707 .577 .707 r
F P
0 g
s
.29784 .74429 m .29784 .72576 L .3253 .73015 L p .707 .577 .707 r
F P
0 g
s
.73333 .67764 m .73333 .64058 L .70216 .63868 L p .707 .577 .707 r
F P
0 g
s
.73333 .64058 m .73333 .67764 L .76517 .67686 L p .707 .577 .707 r
F P
0 g
s
.76517 .67686 m .76517 .6398 L .73333 .64058 L p .707 .577 .707 r
F P
0 g
s
.76517 .6398 m .76517 .67686 L .79455 .67348 L p .707 .577 .707 r
F P
0 g
s
.79455 .67348 m .79455 .63643 L .76517 .6398 L p .707 .577 .707 r
F P
0 g
s
.6747 .5684 m .6747 .62398 L .70216 .62837 L p .707 .577 .707 r
F P
0 g
s
.6747 .62398 m .6747 .5684 L .65365 .56194 L p .707 .577 .707 r
F P
0 g
s
.20545 .74654 m .20545 .72802 L .23483 .72464 L p .707 .577 .707 r
F P
0 g
s
.70216 .67574 m .70216 .63868 L .6747 .63429 L p .707 .577 .707 r
F P
0 g
s
.70216 .63868 m .70216 .67574 L .73333 .67764 L p .707 .577 .707 r
F P
0 g
s
.23483 .72464 m .23483 .74316 L .20545 .74654 L p .707 .577 .707 r
F P
0 g
s
.29784 .72576 m .29784 .74429 L .26667 .74239 L p .707 .577 .707 r
F P
0 g
s
.26667 .74239 m .26667 .72386 L .29784 .72576 L p .707 .577 .707 r
F P
0 g
s
.79455 .63643 m .79455 .67348 L .8186 .66783 L p .707 .577 .707 r
F P
0 g
s
.8186 .66783 m .8186 .63078 L .79455 .63643 L p .707 .577 .707 r
F P
0 g
s
.59233 .28592 m .59233 .78781 L .55357 .78161 L p .707 .577 .707 r
F P
0 g
s
.55357 .78161 m .55357 .27972 L .59233 .28592 L p .707 .577 .707 r
F P
0 g
s
.8186 .56488 m .8186 .62046 L .83497 .6131 L p .707 .577 .707 r
F P
0 g
s
.83497 .6131 m .83497 .55751 L .8186 .56488 L p .707 .577 .707 r
F P
0 g
s
.6747 .63429 m .6747 .67134 L .70216 .67574 L p .707 .577 .707 r
F P
0 g
s
.23483 .74316 m .23483 .72464 L .26667 .72386 L p .707 .577 .707 r
F P
0 g
s
.65365 .56194 m .65365 .61752 L .6747 .62398 L p .707 .577 .707 r
F P
0 g
s
.26667 .72386 m .26667 .74239 L .23483 .74316 L p .707 .577 .707 r
F P
0 g
s
.6747 .67134 m .6747 .63429 L .65365 .62783 L p .707 .577 .707 r
F P
0 g
s
.73333 .74188 m .73333 .72335 L .70216 .72145 L p .707 .577 .707 r
F P
0 g
s
.73333 .72335 m .73333 .74188 L .76517 .7411 L p .707 .577 .707 r
F P
0 g
s
.76517 .7411 m .76517 .72257 L .73333 .72335 L p .707 .577 .707 r
F P
0 g
s
.76517 .72257 m .76517 .7411 L .79455 .73772 L p .707 .577 .707 r
F P
0 g
s
.79455 .73772 m .79455 .71919 L .76517 .72257 L p .707 .577 .707 r
F P
0 g
s
.42314 .7848 m .42314 .28291 L .46462 .27814 L p .707 .577 .707 r
F P
0 g
s
.42314 .28291 m .42314 .7848 L .38918 .79277 L p .707 .577 .707 r
F P
0 g
s
.65365 .61752 m .65365 .56194 L .64105 .55406 L p .707 .577 .707 r
F P
0 g
s
.70216 .72145 m .70216 .73997 L .73333 .74188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73997 m .70216 .72145 L .6747 .71705 L p .707 .577 .707 r
F P
0 g
s
.65365 .62783 m .65365 .66489 L .6747 .67134 L p .707 .577 .707 r
F P
0 g
s
.6747 .71705 m .6747 .73558 L .70216 .73997 L p .707 .577 .707 r
F P
0 g
s
.8186 .63078 m .8186 .66783 L .83497 .66046 L p .707 .577 .707 r
F P
0 g
s
.83497 .66046 m .83497 .62341 L .8186 .63078 L p .707 .577 .707 r
F P
0 g
s
.55357 .27972 m .55357 .78161 L .50956 .77893 L p .707 .577 .707 r
F P
0 g
s
.50956 .77893 m .50956 .27704 L .55357 .27972 L p .707 .577 .707 r
F P
0 g
s
.79455 .71919 m .79455 .73772 L .8186 .73207 L p .707 .577 .707 r
F P
0 g
s
.8186 .73207 m .8186 .71354 L .79455 .71919 L p .707 .577 .707 r
F P
0 g
s
.64105 .55406 m .64105 .60964 L .65365 .61752 L p .707 .577 .707 r
F P
0 g
s
.46462 .78003 m .46462 .27814 L .50956 .27704 L p .707 .577 .707 r
F P
0 g
s
.46462 .27814 m .46462 .78003 L .42314 .7848 L p .707 .577 .707 r
F P
0 g
s
.83497 .55751 m .83497 .6131 L .84205 .60473 L p .707 .577 .707 r
F P
0 g
s
.84205 .60473 m .84205 .54915 L .83497 .55751 L p .707 .577 .707 r
F P
0 g
s
.6747 .73558 m .6747 .71705 L .65365 .7106 L p .707 .577 .707 r
F P
0 g
s
.65365 .66489 m .65365 .62783 L .64105 .61995 L p .707 .577 .707 r
F P
0 g
s
.50956 .27704 m .50956 .77893 L .46462 .78003 L p .707 .577 .707 r
F P
0 g
s
.65365 .7106 m .65365 .72913 L .6747 .73558 L p .707 .577 .707 r
F P
0 g
s
.64105 .60964 m .64105 .55406 L .63816 .54551 L p .707 .577 .707 r
F P
0 g
s
.64105 .61995 m .64105 .65701 L .65365 .66489 L p .707 .577 .707 r
F P
0 g
s
.8186 .71354 m .8186 .73207 L .83497 .7247 L p .707 .577 .707 r
F P
0 g
s
.83497 .7247 m .83497 .70617 L .8186 .71354 L p .707 .577 .707 r
F P
0 g
s
.83497 .62341 m .83497 .66046 L .84205 .6521 L p .707 .577 .707 r
F P
0 g
s
.84205 .6521 m .84205 .61504 L .83497 .62341 L p .707 .577 .707 r
F P
0 g
s
.65365 .72913 m .65365 .7106 L .64105 .70272 L p .707 .577 .707 r
F P
0 g
s
.63816 .54551 m .63816 .6011 L .64105 .60964 L p .707 .577 .707 r
F P
0 g
s
.84205 .54915 m .84205 .60473 L .83916 .59619 L p .707 .577 .707 r
F P
0 g
s
.83916 .59619 m .83916 .54061 L .84205 .54915 L p .707 .577 .707 r
F P
0 g
s
.64105 .70272 m .64105 .72124 L .65365 .72913 L p .707 .577 .707 r
F P
0 g
s
.64105 .65701 m .64105 .61995 L .63816 .61141 L p .707 .577 .707 r
F P
0 g
s
.63816 .61141 m .63816 .64846 L .64105 .65701 L p .707 .577 .707 r
F P
0 g
s
.83497 .70617 m .83497 .7247 L .84206 .71634 L p .707 .577 .707 r
F P
0 g
s
.84206 .71634 m .84206 .69781 L .83497 .70617 L p .707 .577 .707 r
F P
0 g
s
.63816 .6011 m .63816 .54551 L .64524 .53715 L p .707 .577 .707 r
F P
0 g
s
.84205 .61504 m .84205 .6521 L .83916 .64356 L p .707 .577 .707 r
F P
0 g
s
.83916 .64356 m .83916 .6065 L .84205 .61504 L p .707 .577 .707 r
F P
0 g
s
.64105 .72124 m .64105 .70272 L .63816 .69417 L p .707 .577 .707 r
F P
0 g
s
.64524 .53715 m .64524 .59273 L .63816 .6011 L p .707 .577 .707 r
F P
0 g
s
.63816 .69417 m .63816 .7127 L .64105 .72124 L p .707 .577 .707 r
F P
0 g
s
.83916 .54061 m .83916 .59619 L .82657 .58831 L p .707 .577 .707 r
F P
0 g
s
.82657 .58831 m .82657 .53272 L .83916 .54061 L p .707 .577 .707 r
F P
0 g
s
.63816 .64846 m .63816 .61141 L .64524 .60304 L p .707 .577 .707 r
F P
0 g
s
.39032 .59345 m .39032 .53787 L .35915 .53597 L p .707 .577 .707 r
F P
0 g
s
.39032 .53787 m .39032 .59345 L .42216 .59268 L p .707 .577 .707 r
F P
0 g
s
.42216 .59268 m .42216 .5371 L .39032 .53787 L p .707 .577 .707 r
F P
0 g
s
.84206 .69781 m .84206 .71634 L .83916 .7078 L p .707 .577 .707 r
F P
0 g
s
.83916 .7078 m .83916 .68927 L .84206 .69781 L p .707 .577 .707 r
F P
0 g
s
.64524 .60304 m .64524 .6401 L .63816 .64846 L p .707 .577 .707 r
F P
0 g
s
.64524 .59273 m .64524 .53715 L .66161 .52978 L p .707 .577 .707 r
F P
0 g
s
.42216 .5371 m .42216 .59268 L .45154 .5893 L p .707 .577 .707 r
F P
0 g
s
.45154 .5893 m .45154 .53372 L .42216 .5371 L p .707 .577 .707 r
F P
0 g
s
.35915 .59155 m .35915 .53597 L .33169 .53158 L p .707 .577 .707 r
F P
0 g
s
.35915 .53597 m .35915 .59155 L .39032 .59345 L p .707 .577 .707 r
F P
0 g
s
.83916 .6065 m .83916 .64356 L .82657 .63567 L p .707 .577 .707 r
F P
0 g
s
.82657 .63567 m .82657 .59862 L .83916 .6065 L p .707 .577 .707 r
F P
0 g
s
.63816 .7127 m .63816 .69417 L .64524 .68581 L p .707 .577 .707 r
F P
0 g
s
.45154 .53372 m .45154 .5893 L .47559 .58365 L p .707 .577 .707 r
F P
0 g
s
.47559 .58365 m .47559 .52807 L .45154 .53372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52978 m .66161 .58537 L .64524 .59273 L p .707 .577 .707 r
F P
0 g
s
.39032 .64082 m .39032 .60377 L .35915 .60187 L p .707 .577 .707 r
F P
0 g
s
.39032 .60377 m .39032 .64082 L .42216 .64004 L p .707 .577 .707 r
F P
0 g
s
.42216 .64004 m .42216 .60299 L .39032 .60377 L p .707 .577 .707 r
F P
0 g
s
.82657 .53272 m .82657 .58831 L .80551 .58185 L p .707 .577 .707 r
F P
0 g
s
.80551 .58185 m .80551 .52627 L .82657 .53272 L p .707 .577 .707 r
F P
0 g
s
.64524 .68581 m .64524 .70434 L .63816 .7127 L p .707 .577 .707 r
F P
0 g
s
.64524 .6401 m .64524 .60304 L .66161 .59568 L p .707 .577 .707 r
F P
0 g
s
.42216 .60299 m .42216 .64004 L .45154 .63666 L p .707 .577 .707 r
F P
0 g
s
.45154 .63666 m .45154 .59961 L .42216 .60299 L p .707 .577 .707 r
F P
0 g
s
.33169 .53158 m .33169 .58716 L .35915 .59155 L p .707 .577 .707 r
F P
0 g
s
.33169 .58716 m .33169 .53158 L .31064 .52513 L p .707 .577 .707 r
F P
0 g
s
.35915 .63892 m .35915 .60187 L .33169 .59747 L p .707 .577 .707 r
F P
0 g
s
.35915 .60187 m .35915 .63892 L .39032 .64082 L p .707 .577 .707 r
F P
0 g
s
.66161 .58537 m .66161 .52978 L .68566 .52413 L p .707 .577 .707 r
F P
0 g
s
.66161 .59568 m .66161 .63273 L .64524 .6401 L p .707 .577 .707 r
F P
0 g
s
.83916 .68927 m .83916 .7078 L .82657 .69991 L p .707 .577 .707 r
F P
0 g
s
.82657 .69991 m .82657 .68138 L .83916 .68927 L p .707 .577 .707 r
F P
0 g
s
.45154 .59961 m .45154 .63666 L .47559 .63101 L p .707 .577 .707 r
F P
0 g
s
.47559 .63101 m .47559 .59396 L .45154 .59961 L p .707 .577 .707 r
F P
0 g
s
.47559 .52807 m .47559 .58365 L .49196 .57628 L p .707 .577 .707 r
F P
0 g
s
.49196 .57628 m .49196 .5207 L .47559 .52807 L p .707 .577 .707 r
F P
0 g
s
.33169 .59747 m .33169 .63453 L .35915 .63892 L p .707 .577 .707 r
F P
0 g
s
.82657 .59862 m .82657 .63567 L .80551 .62922 L p .707 .577 .707 r
F P
0 g
s
.80551 .62922 m .80551 .59216 L .82657 .59862 L p .707 .577 .707 r
F P
0 g
s
.31064 .52513 m .31064 .58071 L .33169 .58716 L p .707 .577 .707 r
F P
0 g
s
.33169 .63453 m .33169 .59747 L .31064 .59102 L p .707 .577 .707 r
F P
0 g
s
.39032 .70506 m .39032 .68653 L .35915 .68463 L p .707 .577 .707 r
F P
0 g
s
.39032 .68653 m .39032 .70506 L .42216 .70428 L p .707 .577 .707 r
F P
0 g
s
.42216 .70428 m .42216 .68576 L .39032 .68653 L p .707 .577 .707 r
F P
0 g
s
.80551 .52627 m .80551 .58185 L .77805 .57746 L p .707 .577 .707 r
F P
0 g
s
.77805 .57746 m .77805 .52188 L .80551 .52627 L p .707 .577 .707 r
F P
0 g
s
.64524 .70434 m .64524 .68581 L .66161 .67844 L p .707 .577 .707 r
F P
0 g
s
.42216 .68576 m .42216 .70428 L .45154 .7009 L p .707 .577 .707 r
F P
0 g
s
.45154 .7009 m .45154 .68238 L .42216 .68576 L p .707 .577 .707 r
F P
0 g
s
.68566 .52413 m .68566 .57972 L .66161 .58537 L p .707 .577 .707 r
F P
0 g
s
.31064 .58071 m .31064 .52513 L .29804 .51724 L p .707 .577 .707 r
F P
0 g
s
.35915 .68463 m .35915 .70316 L .39032 .70506 L p .707 .577 .707 r
F P
0 g
s
.66161 .63273 m .66161 .59568 L .68566 .59003 L p .707 .577 .707 r
F P
0 g
s
.35915 .70316 m .35915 .68463 L .33169 .68024 L p .707 .577 .707 r
F P
0 g
s
.66161 .67844 m .66161 .69697 L .64524 .70434 L p .707 .577 .707 r
F P
0 g
s
.68566 .57972 m .68566 .52413 L .71504 .52075 L p .707 .577 .707 r
F P
0 g
s
.31064 .59102 m .31064 .62807 L .33169 .63453 L p .707 .577 .707 r
F P
0 g
s
.33169 .68024 m .33169 .69877 L .35915 .70316 L p .707 .577 .707 r
F P
0 g
s
.47559 .59396 m .47559 .63101 L .49196 .62365 L p .707 .577 .707 r
F P
0 g
s
.49196 .62365 m .49196 .58659 L .47559 .59396 L p .707 .577 .707 r
F P
0 g
s
.45154 .68238 m .45154 .7009 L .47559 .69525 L p .707 .577 .707 r
F P
0 g
s
.47559 .69525 m .47559 .67673 L .45154 .68238 L p .707 .577 .707 r
F P
0 g
s
.77805 .52188 m .77805 .57746 L .74688 .57556 L p .707 .577 .707 r
F P
0 g
s
.74688 .57556 m .74688 .51998 L .77805 .52188 L p .707 .577 .707 r
F P
0 g
s
.68566 .59003 m .68566 .62708 L .66161 .63273 L p .707 .577 .707 r
F P
0 g
s
.82657 .68138 m .82657 .69991 L .80551 .69346 L p .707 .577 .707 r
F P
0 g
s
.80551 .69346 m .80551 .67493 L .82657 .68138 L p .707 .577 .707 r
F P
0 g
s
.80551 .59216 m .80551 .62922 L .77805 .62483 L p .707 .577 .707 r
F P
0 g
s
.77805 .62483 m .77805 .58777 L .80551 .59216 L p .707 .577 .707 r
F P
0 g
s
.29804 .51724 m .29804 .57282 L .31064 .58071 L p .707 .577 .707 r
F P
0 g
s
.71504 .57634 m .71504 .52075 L .74688 .51998 L p .707 .577 .707 r
F P
0 g
s
.71504 .52075 m .71504 .57634 L .68566 .57972 L p .707 .577 .707 r
F P
0 g
s
.49196 .5207 m .49196 .57628 L .49904 .56792 L p .707 .577 .707 r
F P
0 g
s
.49904 .56792 m .49904 .51233 L .49196 .5207 L p .707 .577 .707 r
F P
0 g
s
.33169 .69877 m .33169 .68024 L .31064 .67379 L p .707 .577 .707 r
F P
0 g
s
.31064 .62807 m .31064 .59102 L .29804 .58313 L p .707 .577 .707 r
F P
0 g
s
.74688 .51998 m .74688 .57556 L .71504 .57634 L p .707 .577 .707 r
F P
0 g
s
.68566 .62708 m .68566 .59003 L .71504 .58665 L p .707 .577 .707 r
F P
0 g
s
.31064 .67379 m .31064 .69231 L .33169 .69877 L p .707 .577 .707 r
F P
0 g
s
.66161 .69697 m .66161 .67844 L .68566 .67279 L p .707 .577 .707 r
F P
0 g
s
.29804 .57282 m .29804 .51724 L .29515 .5087 L p .707 .577 .707 r
F P
0 g
s
.29804 .58313 m .29804 .62019 L .31064 .62807 L p .707 .577 .707 r
F P
0 g
s
.68566 .67279 m .68566 .69132 L .66161 .69697 L p .707 .577 .707 r
F P
0 g
s
.77805 .58777 m .77805 .62483 L .74688 .62292 L p .707 .577 .707 r
F P
0 g
s
.74688 .62292 m .74688 .58587 L .77805 .58777 L p .707 .577 .707 r
F P
0 g
s
.47559 .67673 m .47559 .69525 L .49196 .68789 L p .707 .577 .707 r
F P
0 g
s
.49196 .68789 m .49196 .66936 L .47559 .67673 L p .707 .577 .707 r
F P
0 g
s
.71504 .58665 m .71504 .6237 L .68566 .62708 L p .707 .577 .707 r
F P
0 g
s
.71504 .6237 m .71504 .58665 L .74688 .58587 L p .707 .577 .707 r
F P
0 g
s
.49196 .58659 m .49196 .62365 L .49904 .61528 L p .707 .577 .707 r
F P
0 g
s
.49904 .61528 m .49904 .57823 L .49196 .58659 L p .707 .577 .707 r
F P
0 g
s
.74688 .58587 m .74688 .62292 L .71504 .6237 L p .707 .577 .707 r
F P
0 g
s
.80551 .67493 m .80551 .69346 L .77805 .68906 L p .707 .577 .707 r
F P
0 g
s
.77805 .68906 m .77805 .67054 L .80551 .67493 L p .707 .577 .707 r
F P
0 g
s
.31064 .69231 m .31064 .67379 L .29804 .6659 L p .707 .577 .707 r
F P
0 g
s
.29515 .5087 m .29515 .56428 L .29804 .57282 L p .707 .577 .707 r
F P
0 g
s
.68566 .69132 m .68566 .67279 L .71504 .66941 L p .707 .577 .707 r
F P
0 g
s
.49904 .51233 m .49904 .56792 L .49615 .55937 L p .707 .577 .707 r
F P
0 g
s
.49615 .55937 m .49615 .50379 L .49904 .51233 L p .707 .577 .707 r
F P
0 g
s
.29804 .6659 m .29804 .68443 L .31064 .69231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62019 m .29804 .58313 L .29515 .57459 L p .707 .577 .707 r
F P
0 g
s
.71504 .66941 m .71504 .68794 L .68566 .69132 L p .707 .577 .707 r
F P
0 g
s
.77805 .67054 m .77805 .68906 L .74688 .68716 L p .707 .577 .707 r
F P
0 g
s
.74688 .68716 m .74688 .66864 L .77805 .67054 L p .707 .577 .707 r
F P
0 g
s
.29515 .57459 m .29515 .61165 L .29804 .62019 L p .707 .577 .707 r
F P
0 g
s
.71504 .68794 m .71504 .66941 L .74688 .66864 L p .707 .577 .707 r
F P
0 g
s
.49196 .66936 m .49196 .68789 L .49904 .67952 L p .707 .577 .707 r
F P
0 g
s
.49904 .67952 m .49904 .66099 L .49196 .66936 L p .707 .577 .707 r
F P
0 g
s
.29515 .56428 m .29515 .5087 L .30223 .50033 L p .707 .577 .707 r
F P
0 g
s
.74688 .66864 m .74688 .68716 L .71504 .68794 L p .707 .577 .707 r
F P
0 g
s
.49904 .57823 m .49904 .61528 L .49615 .60674 L p .707 .577 .707 r
F P
0 g
s
.49615 .60674 m .49615 .56969 L .49904 .57823 L p .707 .577 .707 r
F P
0 g
s
.29804 .68443 m .29804 .6659 L .29515 .65736 L p .707 .577 .707 r
F P
0 g
s
.30223 .50033 m .30223 .55592 L .29515 .56428 L p .707 .577 .707 r
F P
0 g
s
.29515 .65736 m .29515 .67589 L .29804 .68443 L p .707 .577 .707 r
F P
0 g
s
.49615 .50379 m .49615 .55937 L .48356 .55149 L p .707 .577 .707 r
F P
0 g
s
.48356 .55149 m .48356 .49591 L .49615 .50379 L p .707 .577 .707 r
F P
0 g
s
.29515 .61165 m .29515 .57459 L .30223 .56623 L p .707 .577 .707 r
F P
0 g
s
.49904 .66099 m .49904 .67952 L .49615 .67098 L p .707 .577 .707 r
F P
0 g
s
.49615 .67098 m .49615 .65245 L .49904 .66099 L p .707 .577 .707 r
F P
0 g
s
.30223 .56623 m .30223 .60328 L .29515 .61165 L p .707 .577 .707 r
F P
0 g
s
.30223 .55592 m .30223 .50033 L .3186 .49297 L p .707 .577 .707 r
F P
0 g
s
.49615 .56969 m .49615 .60674 L .48356 .59886 L p .707 .577 .707 r
F P
0 g
s
.48356 .59886 m .48356 .5618 L .49615 .56969 L p .707 .577 .707 r
F P
0 g
s
.29515 .67589 m .29515 .65736 L .30223 .64899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49297 m .3186 .54855 L .30223 .55592 L p .707 .577 .707 r
F P
0 g
s
.48356 .49591 m .48356 .55149 L .4625 .54504 L p .707 .577 .707 r
F P
0 g
s
.4625 .54504 m .4625 .48945 L .48356 .49591 L p .707 .577 .707 r
F P
0 g
s
.30223 .64899 m .30223 .66752 L .29515 .67589 L p .707 .577 .707 r
F P
0 g
s
.30223 .60328 m .30223 .56623 L .3186 .55886 L p .707 .577 .707 r
F P
0 g
s
.3186 .54855 m .3186 .49297 L .34265 .48732 L p .707 .577 .707 r
F P
0 g
s
.3186 .55886 m .3186 .59591 L .30223 .60328 L p .707 .577 .707 r
F P
0 g
s
.49615 .65245 m .49615 .67098 L .48356 .6631 L p .707 .577 .707 r
F P
0 g
s
.48356 .6631 m .48356 .64457 L .49615 .65245 L p .707 .577 .707 r
F P
0 g
s
.48356 .5618 m .48356 .59886 L .4625 .5924 L p .707 .577 .707 r
F P
0 g
s
.4625 .5924 m .4625 .55535 L .48356 .5618 L p .707 .577 .707 r
F P
0 g
s
.4625 .48945 m .4625 .54504 L .43504 .54064 L p .707 .577 .707 r
F P
0 g
s
.43504 .54064 m .43504 .48506 L .4625 .48945 L p .707 .577 .707 r
F P
0 g
s
.30223 .66752 m .30223 .64899 L .3186 .64163 L p .707 .577 .707 r
F P
0 g
s
.34265 .48732 m .34265 .5429 L .3186 .54855 L p .707 .577 .707 r
F P
0 g
s
.3186 .59591 m .3186 .55886 L .34265 .55321 L p .707 .577 .707 r
F P
0 g
s
.3186 .64163 m .3186 .66015 L .30223 .66752 L p .707 .577 .707 r
F P
0 g
s
.34265 .5429 m .34265 .48732 L .37203 .48394 L p .707 .577 .707 r
F P
0 g
s
.43504 .48506 m .43504 .54064 L .40387 .53874 L p .707 .577 .707 r
F P
0 g
s
.40387 .53874 m .40387 .48316 L .43504 .48506 L p .707 .577 .707 r
F P
0 g
s
.34265 .55321 m .34265 .59027 L .3186 .59591 L p .707 .577 .707 r
F P
0 g
s
.48356 .64457 m .48356 .6631 L .4625 .65664 L p .707 .577 .707 r
F P
0 g
s
.4625 .65664 m .4625 .63811 L .48356 .64457 L p .707 .577 .707 r
F P
0 g
s
.4625 .55535 m .4625 .5924 L .43504 .58801 L p .707 .577 .707 r
F P
0 g
s
.43504 .58801 m .43504 .55095 L .4625 .55535 L p .707 .577 .707 r
F P
0 g
s
.37203 .53952 m .37203 .48394 L .40387 .48316 L p .707 .577 .707 r
F P
0 g
s
.37203 .48394 m .37203 .53952 L .34265 .5429 L p .707 .577 .707 r
F P
0 g
s
.40387 .48316 m .40387 .53874 L .37203 .53952 L p .707 .577 .707 r
F P
0 g
s
.34265 .59027 m .34265 .55321 L .37203 .54983 L p .707 .577 .707 r
F P
0 g
s
.3186 .66015 m .3186 .64163 L .34265 .63598 L p .707 .577 .707 r
F P
0 g
s
.34265 .63598 m .34265 .6545 L .3186 .66015 L p .707 .577 .707 r
F P
0 g
s
.43504 .55095 m .43504 .58801 L .40387 .58611 L p .707 .577 .707 r
F P
0 g
s
.40387 .58611 m .40387 .54905 L .43504 .55095 L p .707 .577 .707 r
F P
0 g
s
.37203 .54983 m .37203 .58689 L .34265 .59027 L p .707 .577 .707 r
F P
0 g
s
.37203 .58689 m .37203 .54983 L .40387 .54905 L p .707 .577 .707 r
F P
0 g
s
.40387 .54905 m .40387 .58611 L .37203 .58689 L p .707 .577 .707 r
F P
0 g
s
.4625 .63811 m .4625 .65664 L .43504 .65225 L p .707 .577 .707 r
F P
0 g
s
.43504 .65225 m .43504 .63372 L .4625 .63811 L p .707 .577 .707 r
F P
0 g
s
.34265 .6545 m .34265 .63598 L .37203 .6326 L p .707 .577 .707 r
F P
0 g
s
.37203 .6326 m .37203 .65113 L .34265 .6545 L p .707 .577 .707 r
F P
0 g
s
.43504 .63372 m .43504 .65225 L .40387 .65035 L p .707 .577 .707 r
F P
0 g
s
.40387 .65035 m .40387 .63182 L .43504 .63372 L p .707 .577 .707 r
F P
0 g
s
.37203 .65113 m .37203 .6326 L .40387 .63182 L p .707 .577 .707 r
F P
0 g
s
.40387 .63182 m .40387 .65035 L .37203 .65113 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUH00000JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000J7oo
001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo60001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<0
05YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQT00003FUH0
05YF00AJEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP04001JEUYF0002
FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00L005YF000005YF001JEP040003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003
FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P0000=JEP0000000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000o
OolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000b
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
0002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPL0009JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH01000FUIJEP00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00
15YF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH3000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP06001JEP00001JEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P00
00EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP@00003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P00
0eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0004FUH300000eYF
001JEP06FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH40003FUH00`00FUIJEP020004
OolB0007Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPL0
00MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEPP00003FUH005YF00@000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP80009JEPH000=JEP03001oogoo01Aoo`L000=JEP<000=JEP80
02eoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP04001JEUYFFUH90009Ool90003FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00
;Goo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUHG0003FUH30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eo
o`00;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`8000=JEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000=JEPD000AJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
1@001UYF6`0000=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH30002FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EPD00003FUH0000000D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP80
00=JEP03001JEP00008000EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH000030002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPD000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH40006FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000bOol002aoo`03001JEP0000AJEP04001JEUYFFUHN0003FUH00`00FUIJEP03FUH01000
FUIJEUYF200015YF1@001EYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP80035oo`00;7oo00<005YF00000eYF1@007Woo0P0000=JEP00FUH015YF00<005YFFUH0
1EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool01000FUH005YF0P00
15YF1@006goo100015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001JEUYFFUH0
000^Ool002aoo`06001JEP00001JEP001EYF00@005YFFUIJEQ/000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009J
EP@00003FUH007oo01Uoo`<000AJEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH30005
FUH00`00FUIJEP03000MOol300000eYF001JEP02FUH2000]Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000L000AJEP03001JEUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00008Goo0P000eYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YF00004P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol200000eYF0000000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Goo0P0000AJEP00000002eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH300000eYF001JEP04FUH01000FUIJEUYF0P007Woo0`000eYF0`00;Goo000^Ool200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH01@000UYF00@005YFFUIJEP8000Qoo`<000moo`@00003FUH005YF00=JEP03
001JEP0002eoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUH000030002FUH20007Ool50009Ool5
0005FUH00`00FUIJEP02FUH2000^Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEPT00003
FUH005YF00IJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool003Ioo`D000AJEPP000AJEP03001JEUYF009JEPP00003FUH005YF00@000Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo
000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00006P00?goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool20004FUH01000FUIJEUYF20006Goo1P0015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00;7oo00<005YF00000eYF1@009goo0`0000EJ
EP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05Aoo`00;7oo00@005YF001JEP8002moo`80
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP02001GOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`@003Ao
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH4001KOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H005moo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF1000GGoo000/
Ool20003FUH00`00FUIJEP02FUH5000=Ool3000@Ool400000eYF001JEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04001IOol002eo
o`05001JEUYFFUH00005FUH01000FUIJEUYF200017oo1@002Woo1@001EYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=J
EP8005Qoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF5@00
1UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YF000005Ioo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000eYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YF
FUH000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJ
EPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`D000AJEP05001JEUYFFUH0
001EOol003Aoo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
00Yoo`04001JEUYF0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2
001DOol003eooaT000moo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH0000<Ool200000eYF
0000001DOol006Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF000037oo
1@00E7oo001UOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`09
Ool20002FUH3001DOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH007oo00Eoo`@000AJEP03001JEP0005Aoo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF0P0000=JEP0000001@000eYF00<005YFFUH00UYF0P00EGoo001UOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001U
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00AJEP04001JEP00001HOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0000=JEP04001JEUYFFUH5001JOol006Ioo`03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP800003FUH0000000D005moo`00Igoo0P000UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF1000IWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
0000K7oo001]Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH4001^Ool0075oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF1@00Mgoo001lOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP06001lOol008Eo
oaH0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70551 m .59613 .64992 L .56496 .64802 L p .707 .577 .707 r
F P
0 g
s
.59613 .64992 m .59613 .70551 L .62796 .70473 L p .707 .577 .707 r
F P
0 g
s
.62796 .70473 m .62796 .64915 L .59613 .64992 L p .707 .577 .707 r
F P
0 g
s
.62796 .64915 m .62796 .70473 L .65734 .70135 L p .707 .577 .707 r
F P
0 g
s
.65734 .70135 m .65734 .64577 L .62796 .64915 L p .707 .577 .707 r
F P
0 g
s
.56496 .70361 m .56496 .64802 L .5375 .64363 L p .707 .577 .707 r
F P
0 g
s
.56496 .64802 m .56496 .70361 L .59613 .70551 L p .707 .577 .707 r
F P
0 g
s
.65734 .64577 m .65734 .70135 L .6814 .6957 L p .707 .577 .707 r
F P
0 g
s
.6814 .6957 m .6814 .64012 L .65734 .64577 L p .707 .577 .707 r
F P
0 g
s
.59613 .74484 m .59613 .70778 L .56496 .70588 L p .707 .577 .707 r
F P
0 g
s
.59613 .70778 m .59613 .74484 L .62796 .74406 L p .707 .577 .707 r
F P
0 g
s
.62796 .74406 m .62796 .70701 L .59613 .70778 L p .707 .577 .707 r
F P
0 g
s
.62796 .70701 m .62796 .74406 L .65735 .74068 L p .707 .577 .707 r
F P
0 g
s
.65735 .74068 m .65734 .70363 L .62796 .70701 L p .707 .577 .707 r
F P
0 g
s
.5375 .64363 m .5375 .69921 L .56496 .70361 L p .707 .577 .707 r
F P
0 g
s
.5375 .69921 m .5375 .64363 L .51644 .63718 L p .707 .577 .707 r
F P
0 g
s
.56496 .74294 m .56496 .70588 L .5375 .70149 L p .707 .577 .707 r
F P
0 g
s
.56496 .70588 m .56496 .74294 L .59613 .74484 L p .707 .577 .707 r
F P
0 g
s
.65734 .70363 m .65735 .74068 L .6814 .73503 L p .707 .577 .707 r
F P
0 g
s
.6814 .73503 m .6814 .69798 L .65734 .70363 L p .707 .577 .707 r
F P
0 g
s
.5375 .70149 m .5375 .73855 L .56496 .74294 L p .707 .577 .707 r
F P
0 g
s
.6814 .64012 m .6814 .6957 L .69777 .68833 L p .707 .577 .707 r
F P
0 g
s
.69777 .68833 m .69777 .63275 L .6814 .64012 L p .707 .577 .707 r
F P
0 g
s
.51644 .63718 m .51644 .69276 L .5375 .69921 L p .707 .577 .707 r
F P
0 g
s
.5375 .73855 m .5375 .70149 L .51644 .69504 L p .707 .577 .707 r
F P
0 g
s
.59613 .82292 m .59613 .8044 L .56496 .8025 L p .707 .577 .707 r
F P
0 g
s
.59613 .8044 m .59613 .82292 L .62796 .82215 L p .707 .577 .707 r
F P
0 g
s
.62796 .82215 m .62796 .80362 L .59613 .8044 L p .707 .577 .707 r
F P
0 g
s
.51644 .69276 m .51644 .63718 L .50385 .62929 L p .707 .577 .707 r
F P
0 g
s
.62796 .80362 m .62796 .82215 L .65735 .81877 L p .707 .577 .707 r
F P
0 g
s
.65735 .81877 m .65735 .80024 L .62796 .80362 L p .707 .577 .707 r
F P
0 g
s
.56496 .8025 m .56496 .82102 L .59613 .82292 L p .707 .577 .707 r
F P
0 g
s
.51644 .69504 m .51644 .73209 L .5375 .73855 L p .707 .577 .707 r
F P
0 g
s
.56496 .82102 m .56496 .8025 L .5375 .7981 L p .707 .577 .707 r
F P
0 g
s
.6814 .69798 m .6814 .73503 L .69777 .72767 L p .707 .577 .707 r
F P
0 g
s
.69777 .72767 m .69777 .69061 L .6814 .69798 L p .707 .577 .707 r
F P
0 g
s
.5375 .7981 m .5375 .81663 L .56496 .82102 L p .707 .577 .707 r
F P
0 g
s
.65735 .80024 m .65735 .81877 L .6814 .81312 L p .707 .577 .707 r
F P
0 g
s
.6814 .81312 m .6814 .79459 L .65735 .80024 L p .707 .577 .707 r
F P
0 g
s
.50385 .62929 m .50385 .68488 L .51644 .69276 L p .707 .577 .707 r
F P
0 g
s
.69777 .63275 m .69777 .68833 L .70485 .67997 L p .707 .577 .707 r
F P
0 g
s
.70485 .67997 m .70485 .62439 L .69777 .63275 L p .707 .577 .707 r
F P
0 g
s
.51644 .73209 m .51644 .69504 L .50385 .68715 L p .707 .577 .707 r
F P
0 g
s
.5375 .81663 m .5375 .7981 L .51644 .79165 L p .707 .577 .707 r
F P
0 g
s
.51644 .79165 m .51644 .81018 L .5375 .81663 L p .707 .577 .707 r
F P
0 g
s
.50385 .68715 m .50385 .72421 L .51644 .73209 L p .707 .577 .707 r
F P
0 g
s
.50385 .68488 m .50385 .62929 L .50095 .62075 L p .707 .577 .707 r
F P
0 g
s
.69777 .69061 m .69777 .72767 L .70485 .7193 L p .707 .577 .707 r
F P
0 g
s
.70485 .7193 m .70485 .68225 L .69777 .69061 L p .707 .577 .707 r
F P
0 g
s
.6814 .79459 m .6814 .81312 L .69777 .80575 L p .707 .577 .707 r
F P
0 g
s
.69777 .80575 m .69777 .78722 L .6814 .79459 L p .707 .577 .707 r
F P
0 g
s
.51644 .81018 m .51644 .79165 L .50385 .78377 L p .707 .577 .707 r
F P
0 g
s
.50095 .62075 m .50095 .67633 L .50385 .68488 L p .707 .577 .707 r
F P
0 g
s
.50385 .72421 m .50385 .68715 L .50095 .67861 L p .707 .577 .707 r
F P
0 g
s
.70485 .62439 m .70485 .67997 L .70195 .67143 L p .707 .577 .707 r
F P
0 g
s
.70195 .67143 m .70195 .61584 L .70485 .62439 L p .707 .577 .707 r
F P
0 g
s
.50385 .78377 m .50385 .80229 L .51644 .81018 L p .707 .577 .707 r
F P
0 g
s
.50095 .67861 m .50095 .71567 L .50385 .72421 L p .707 .577 .707 r
F P
0 g
s
.69777 .78722 m .69777 .80575 L .70485 .79739 L p .707 .577 .707 r
F P
0 g
s
.70485 .79739 m .70485 .77886 L .69777 .78722 L p .707 .577 .707 r
F P
0 g
s
.50095 .67633 m .50095 .62075 L .50804 .61239 L p .707 .577 .707 r
F P
0 g
s
.70485 .68225 m .70485 .7193 L .70195 .71076 L p .707 .577 .707 r
F P
0 g
s
.70195 .71076 m .70195 .6737 L .70485 .68225 L p .707 .577 .707 r
F P
0 g
s
.50385 .80229 m .50385 .78377 L .50095 .77522 L p .707 .577 .707 r
F P
0 g
s
.50804 .61239 m .50804 .66797 L .50095 .67633 L p .707 .577 .707 r
F P
0 g
s
.50095 .71567 m .50095 .67861 L .50804 .67025 L p .707 .577 .707 r
F P
0 g
s
.50095 .77522 m .50095 .79375 L .50385 .80229 L p .707 .577 .707 r
F P
0 g
s
.70195 .61584 m .70195 .67143 L .68936 .66354 L p .707 .577 .707 r
F P
0 g
s
.68936 .66354 m .68936 .60796 L .70195 .61584 L p .707 .577 .707 r
F P
0 g
s
.49044 .87739 m .49044 .3755 L .44643 .37282 L p .707 .577 .707 r
F P
0 g
s
.50804 .67025 m .50804 .7073 L .50095 .71567 L p .707 .577 .707 r
F P
0 g
s
.50804 .66797 m .50804 .61239 L .5244 .60502 L p .707 .577 .707 r
F P
0 g
s
.50095 .79375 m .50095 .77522 L .50804 .76686 L p .707 .577 .707 r
F P
0 g
s
.5244 .60502 m .5244 .6606 L .50804 .66797 L p .707 .577 .707 r
F P
0 g
s
.50804 .7073 m .50804 .67025 L .5244 .66288 L p .707 .577 .707 r
F P
0 g
s
.50804 .76686 m .50804 .78539 L .50095 .79375 L p .707 .577 .707 r
F P
0 g
s
.5244 .66288 m .5244 .69993 L .50804 .7073 L p .707 .577 .707 r
F P
0 g
s
.50804 .78539 m .50804 .76686 L .5244 .75949 L p .707 .577 .707 r
F P
0 g
s
.5244 .75949 m .5244 .77802 L .50804 .78539 L p .707 .577 .707 r
F P
0 g
s
.5244 .77802 m .5244 .75949 L .54846 .75384 L p .707 .577 .707 r
F P
0 g
s
.54846 .75384 m .54846 .77237 L .5244 .77802 L p .707 .577 .707 r
F P
0 g
s
.49044 .3755 m .49044 .87739 L .53538 .87629 L p .707 .577 .707 r
F P
0 g
s
.5244 .6606 m .5244 .60502 L .54846 .59937 L p .707 .577 .707 r
F P
0 g
s
.54846 .59937 m .54846 .65495 L .5244 .6606 L p .707 .577 .707 r
F P
0 g
s
.5244 .69993 m .5244 .66288 L .54846 .65723 L p .707 .577 .707 r
F P
0 g
s
.54846 .65723 m .54846 .69428 L .5244 .69993 L p .707 .577 .707 r
F P
0 g
s
.53538 .87629 m .53538 .3744 L .49044 .3755 L p .707 .577 .707 r
F P
0 g
s
.25312 .66869 m .25312 .61311 L .22195 .61121 L p .707 .577 .707 r
F P
0 g
s
.25312 .61311 m .25312 .66869 L .28495 .66791 L p .707 .577 .707 r
F P
0 g
s
.28495 .66791 m .28495 .61233 L .25312 .61311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65495 m .54846 .59937 L .57784 .59599 L p .707 .577 .707 r
F P
0 g
s
.57784 .59599 m .57784 .65157 L .54846 .65495 L p .707 .577 .707 r
F P
0 g
s
.54846 .69428 m .54846 .65723 L .57784 .65385 L p .707 .577 .707 r
F P
0 g
s
.57784 .65385 m .57784 .69091 L .54846 .69428 L p .707 .577 .707 r
F P
0 g
s
.54846 .77237 m .54846 .75384 L .57784 .75046 L p .707 .577 .707 r
F P
0 g
s
.57784 .75046 m .57784 .76899 L .54846 .77237 L p .707 .577 .707 r
F P
0 g
s
.53538 .3744 m .53538 .87629 L .57686 .87152 L p .707 .577 .707 r
F P
0 g
s
.57686 .87152 m .57686 .36963 L .53538 .3744 L p .707 .577 .707 r
F P
0 g
s
.70485 .77886 m .70485 .79739 L .70195 .78884 L p .707 .577 .707 r
F P
0 g
s
.70195 .78884 m .70195 .77032 L .70485 .77886 L p .707 .577 .707 r
F P
0 g
s
.28495 .61233 m .28495 .66791 L .31434 .66454 L p .707 .577 .707 r
F P
0 g
s
.31434 .66454 m .31434 .60895 L .28495 .61233 L p .707 .577 .707 r
F P
0 g
s
.70195 .6737 m .70195 .71076 L .68936 .70288 L p .707 .577 .707 r
F P
0 g
s
.68936 .70288 m .68936 .66582 L .70195 .6737 L p .707 .577 .707 r
F P
0 g
s
.44643 .8747 m .44643 .37282 L .40766 .36661 L p .707 .577 .707 r
F P
0 g
s
.44643 .37282 m .44643 .8747 L .49044 .87739 L p .707 .577 .707 r
F P
0 g
s
.22195 .66679 m .22195 .61121 L .19449 .60682 L p .707 .577 .707 r
F P
0 g
s
.22195 .61121 m .22195 .66679 L .25312 .66869 L p .707 .577 .707 r
F P
0 g
s
.31434 .60895 m .31434 .66454 L .33839 .65889 L p .707 .577 .707 r
F P
0 g
s
.33839 .65889 m .33839 .6033 L .31434 .60895 L p .707 .577 .707 r
F P
0 g
s
.25312 .70802 m .25312 .67097 L .22195 .66907 L p .707 .577 .707 r
F P
0 g
s
.25312 .67097 m .25312 .70802 L .28495 .70725 L p .707 .577 .707 r
F P
0 g
s
.28495 .70725 m .28495 .67019 L .25312 .67097 L p .707 .577 .707 r
F P
0 g
s
.57784 .65157 m .57784 .59599 L .60968 .59521 L p .707 .577 .707 r
F P
0 g
s
.60968 .59521 m .60968 .6508 L .57784 .65157 L p .707 .577 .707 r
F P
0 g
s
.57784 .69091 m .57784 .65385 L .60968 .65307 L p .707 .577 .707 r
F P
0 g
s
.60968 .65307 m .60968 .69013 L .57784 .69091 L p .707 .577 .707 r
F P
0 g
s
.57784 .76899 m .57784 .75046 L .60968 .74969 L p .707 .577 .707 r
F P
0 g
s
.60968 .74969 m .60968 .76821 L .57784 .76899 L p .707 .577 .707 r
F P
0 g
s
.57686 .36963 m .57686 .87152 L .61082 .86354 L p .707 .577 .707 r
F P
0 g
s
.64085 .59711 m .64085 .6527 L .60968 .6508 L p .707 .577 .707 r
F P
0 g
s
.60968 .6508 m .60968 .59521 L .64085 .59711 L p .707 .577 .707 r
F P
0 g
s
.64085 .65497 m .64085 .69203 L .60968 .69013 L p .707 .577 .707 r
F P
0 g
s
.60968 .69013 m .60968 .65307 L .64085 .65497 L p .707 .577 .707 r
F P
0 g
s
.64085 .75159 m .64085 .77011 L .60968 .76821 L p .707 .577 .707 r
F P
0 g
s
.60968 .76821 m .60968 .74969 L .64085 .75159 L p .707 .577 .707 r
F P
0 g
s
.61082 .86354 m .61082 .36165 L .57686 .36963 L p .707 .577 .707 r
F P
0 g
s
.68936 .60796 m .68936 .66354 L .66831 .65709 L p .707 .577 .707 r
F P
0 g
s
.66831 .65709 m .66831 .60151 L .68936 .60796 L p .707 .577 .707 r
F P
0 g
s
.28495 .67019 m .28495 .70725 L .31434 .70387 L p .707 .577 .707 r
F P
0 g
s
.31434 .70387 m .31434 .66681 L .28495 .67019 L p .707 .577 .707 r
F P
0 g
s
.19449 .60682 m .19449 .6624 L .22195 .66679 L p .707 .577 .707 r
F P
0 g
s
.19449 .6624 m .19449 .60682 L .17343 .60036 L p .707 .577 .707 r
F P
0 g
s
.22195 .70612 m .22195 .66907 L .19449 .66468 L p .707 .577 .707 r
F P
0 g
s
.22195 .66907 m .22195 .70612 L .25312 .70802 L p .707 .577 .707 r
F P
0 g
s
.40766 .8685 m .40766 .36661 L .37794 .3575 L p .707 .577 .707 r
F P
0 g
s
.40766 .36661 m .40766 .8685 L .44643 .8747 L p .707 .577 .707 r
F P
0 g
s
.31434 .66681 m .31434 .70387 L .33839 .69822 L p .707 .577 .707 r
F P
0 g
s
.33839 .69822 m .33839 .66116 L .31434 .66681 L p .707 .577 .707 r
F P
0 g
s
.70195 .77032 m .70195 .78884 L .68936 .78096 L p .707 .577 .707 r
F P
0 g
s
.68936 .78096 m .68936 .76243 L .70195 .77032 L p .707 .577 .707 r
F P
0 g
s
.19449 .66468 m .19449 .70173 L .22195 .70612 L p .707 .577 .707 r
F P
0 g
s
.68936 .66582 m .68936 .70288 L .66831 .69642 L p .707 .577 .707 r
F P
0 g
s
.66831 .69642 m .66831 .65937 L .68936 .66582 L p .707 .577 .707 r
F P
0 g
s
.33839 .6033 m .33839 .65889 L .35476 .65152 L p .707 .577 .707 r
F P
0 g
s
.35476 .65152 m .35476 .59594 L .33839 .6033 L p .707 .577 .707 r
F P
0 g
s
.17343 .60036 m .17343 .65594 L .19449 .6624 L p .707 .577 .707 r
F P
0 g
s
.19449 .70173 m .19449 .66468 L .17343 .65822 L p .707 .577 .707 r
F P
0 g
s
.66831 .60151 m .66831 .65709 L .64085 .6527 L p .707 .577 .707 r
F P
0 g
s
.64085 .6527 m .64085 .59711 L .66831 .60151 L p .707 .577 .707 r
F P
0 g
s
.25312 .78611 m .25312 .76758 L .22195 .76568 L p .707 .577 .707 r
F P
0 g
s
.25312 .76758 m .25312 .78611 L .28495 .78533 L p .707 .577 .707 r
F P
0 g
s
.28495 .78533 m .28495 .76681 L .25312 .76758 L p .707 .577 .707 r
F P
0 g
s
.17343 .65594 m .17343 .60036 L .16084 .59248 L p .707 .577 .707 r
F P
0 g
s
.28495 .76681 m .28495 .78533 L .31434 .78195 L p .707 .577 .707 r
F P
0 g
s
.31434 .78195 m .31434 .76343 L .28495 .76681 L p .707 .577 .707 r
F P
0 g
s
.61082 .36165 m .61082 .86354 L .63393 .85314 L p .707 .577 .707 r
F P
0 g
s
.63393 .85314 m .63393 .35125 L .61082 .36165 L p .707 .577 .707 r
F P
0 g
s
.22195 .76568 m .22195 .78421 L .25312 .78611 L p .707 .577 .707 r
F P
0 g
s
.17343 .65822 m .17343 .69528 L .19449 .70173 L p .707 .577 .707 r
F P
0 g
s
.22195 .78421 m .22195 .76568 L .19449 .76129 L p .707 .577 .707 r
F P
0 g
s
.33839 .66116 m .33839 .69822 L .35476 .69085 L p .707 .577 .707 r
F P
0 g
s
.35476 .69085 m .35476 .6538 L .33839 .66116 L p .707 .577 .707 r
F P
0 g
s
.19449 .76129 m .19449 .77982 L .22195 .78421 L p .707 .577 .707 r
F P
0 g
s
.66831 .65937 m .66831 .69642 L .64085 .69203 L p .707 .577 .707 r
F P
0 g
s
.64085 .69203 m .64085 .65497 L .66831 .65937 L p .707 .577 .707 r
F P
0 g
s
.31434 .76343 m .31434 .78195 L .33839 .7763 L p .707 .577 .707 r
F P
0 g
s
.33839 .7763 m .33839 .75778 L .31434 .76343 L p .707 .577 .707 r
F P
0 g
s
.16084 .59248 m .16084 .64806 L .17343 .65594 L p .707 .577 .707 r
F P
0 g
s
.68936 .76243 m .68936 .78096 L .66831 .77451 L p .707 .577 .707 r
F P
0 g
s
.66831 .77451 m .66831 .75598 L .68936 .76243 L p .707 .577 .707 r
F P
0 g
s
.35476 .59594 m .35476 .65152 L .36184 .64315 L p .707 .577 .707 r
F P
0 g
s
.36184 .64315 m .36184 .58757 L .35476 .59594 L p .707 .577 .707 r
F P
0 g
s
.37794 .85939 m .37794 .3575 L .36016 .34637 L p .707 .577 .707 r
F P
0 g
s
.37794 .3575 m .37794 .85939 L .40766 .8685 L p .707 .577 .707 r
F P
0 g
s
.17343 .69528 m .17343 .65822 L .16084 .65034 L p .707 .577 .707 r
F P
0 g
s
.19449 .77982 m .19449 .76129 L .17343 .75484 L p .707 .577 .707 r
F P
0 g
s
.17343 .75484 m .17343 .77336 L .19449 .77982 L p .707 .577 .707 r
F P
0 g
s
.16084 .65034 m .16084 .68739 L .17343 .69528 L p .707 .577 .707 r
F P
0 g
s
.16084 .64806 m .16084 .59248 L .15794 .58394 L p .707 .577 .707 r
F P
0 g
s
.35476 .6538 m .35476 .69085 L .36184 .68249 L p .707 .577 .707 r
F P
0 g
s
.36184 .68249 m .36184 .64543 L .35476 .6538 L p .707 .577 .707 r
F P
0 g
s
.33839 .75778 m .33839 .7763 L .35476 .76894 L p .707 .577 .707 r
F P
0 g
s
.35476 .76894 m .35476 .75041 L .33839 .75778 L p .707 .577 .707 r
F P
0 g
s
.66831 .75598 m .66831 .77451 L .64085 .77011 L p .707 .577 .707 r
F P
0 g
s
.64085 .77011 m .64085 .75159 L .66831 .75598 L p .707 .577 .707 r
F P
0 g
s
.63393 .35125 m .63393 .85314 L .64393 .84133 L p .707 .577 .707 r
F P
0 g
s
.64393 .84133 m .64393 .33944 L .63393 .35125 L p .707 .577 .707 r
F P
0 g
s
.17343 .77336 m .17343 .75484 L .16084 .74695 L p .707 .577 .707 r
F P
0 g
s
.15794 .58394 m .15794 .63952 L .16084 .64806 L p .707 .577 .707 r
F P
0 g
s
.16084 .68739 m .16084 .65034 L .15794 .6418 L p .707 .577 .707 r
F P
0 g
s
.36184 .58757 m .36184 .64315 L .35894 .63461 L p .707 .577 .707 r
F P
0 g
s
.35894 .63461 m .35894 .57903 L .36184 .58757 L p .707 .577 .707 r
F P
0 g
s
.16084 .74695 m .16084 .76548 L .17343 .77336 L p .707 .577 .707 r
F P
0 g
s
.15794 .6418 m .15794 .67885 L .16084 .68739 L p .707 .577 .707 r
F P
0 g
s
.35476 .75041 m .35476 .76894 L .36184 .76057 L p .707 .577 .707 r
F P
0 g
s
.36184 .76057 m .36184 .74204 L .35476 .75041 L p .707 .577 .707 r
F P
0 g
s
.36184 .64543 m .36184 .68249 L .35894 .67394 L p .707 .577 .707 r
F P
0 g
s
.35894 .67394 m .35894 .63689 L .36184 .64543 L p .707 .577 .707 r
F P
0 g
s
.35894 .57903 m .35894 .63461 L .34635 .62673 L p .707 .577 .707 r
F P
0 g
s
.34635 .62673 m .34635 .57114 L .35894 .57903 L p .707 .577 .707 r
F P
0 g
s
.36184 .74204 m .36184 .76057 L .35894 .75203 L p .707 .577 .707 r
F P
0 g
s
.35894 .75203 m .35894 .7335 L .36184 .74204 L p .707 .577 .707 r
F P
0 g
s
.35894 .63689 m .35894 .67394 L .34635 .66606 L p .707 .577 .707 r
F P
0 g
s
.34635 .66606 m .34635 .629 L .35894 .63689 L p .707 .577 .707 r
F P
0 g
s
.36016 .84826 m .36016 .34637 L .35607 .33431 L p .707 .577 .707 r
F P
0 g
s
.36016 .34637 m .36016 .84826 L .37794 .85939 L p .707 .577 .707 r
F P
0 g
s
.15794 .63952 m .15794 .58394 L .16503 .57557 L p .707 .577 .707 r
F P
0 g
s
.16084 .76548 m .16084 .74695 L .15794 .73841 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57557 m .16503 .63115 L .15794 .63952 L p .707 .577 .707 r
F P
0 g
s
.15794 .67885 m .15794 .6418 L .16503 .63343 L p .707 .577 .707 r
F P
0 g
s
.15794 .73841 m .15794 .75694 L .16084 .76548 L p .707 .577 .707 r
F P
0 g
s
.64393 .33944 m .64393 .84133 L .63984 .82927 L p .707 .577 .707 r
F P
0 g
s
.63984 .82927 m .63984 .32738 L .64393 .33944 L p .707 .577 .707 r
F P
0 g
s
.16503 .63343 m .16503 .67049 L .15794 .67885 L p .707 .577 .707 r
F P
0 g
s
.16503 .63115 m .16503 .57557 L .1814 .5682 L p .707 .577 .707 r
F P
0 g
s
.35894 .7335 m .35894 .75203 L .34635 .74415 L p .707 .577 .707 r
F P
0 g
s
.34635 .74415 m .34635 .72562 L .35894 .7335 L p .707 .577 .707 r
F P
0 g
s
.35607 .33431 m .35607 .8362 L .36016 .84826 L p .707 .577 .707 r
F P
0 g
s
.35607 .8362 m .35607 .33431 L .36607 .3225 L p .707 .577 .707 r
F P
0 g
s
.15794 .75694 m .15794 .73841 L .16503 .73004 L p .707 .577 .707 r
F P
0 g
s
.1814 .5682 m .1814 .62379 L .16503 .63115 L p .707 .577 .707 r
F P
0 g
s
.34635 .57114 m .34635 .62673 L .3253 .62027 L p .707 .577 .707 r
F P
0 g
s
.3253 .62027 m .3253 .56469 L .34635 .57114 L p .707 .577 .707 r
F P
0 g
s
.16503 .67049 m .16503 .63343 L .1814 .62606 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .73004 m .16503 .74857 L .15794 .75694 L p .707 .577 .707 r
F P
0 g
s
.1814 .62606 m .1814 .66312 L .16503 .67049 L p .707 .577 .707 r
F P
0 g
s
.1814 .62379 m .1814 .5682 L .20545 .56255 L p .707 .577 .707 r
F P
0 g
s
.34635 .629 m .34635 .66606 L .3253 .65961 L p .707 .577 .707 r
F P
0 g
s
.3253 .65961 m .3253 .62255 L .34635 .629 L p .707 .577 .707 r
F P
0 g
s
.63984 .32738 m .63984 .82927 L .62206 .81814 L p .707 .577 .707 r
F P
0 g
s
.62206 .81814 m .62206 .31625 L .63984 .32738 L p .707 .577 .707 r
F P
0 g
s
.3253 .56469 m .3253 .62027 L .29784 .61588 L p .707 .577 .707 r
F P
0 g
s
.29784 .61588 m .29784 .5603 L .3253 .56469 L p .707 .577 .707 r
F P
0 g
s
.20545 .56255 m .20545 .61814 L .1814 .62379 L p .707 .577 .707 r
F P
0 g
s
.1814 .66312 m .1814 .62606 L .20545 .62041 L p .707 .577 .707 r
F P
0 g
s
.16503 .74857 m .16503 .73004 L .1814 .72268 L p .707 .577 .707 r
F P
0 g
s
.20545 .61814 m .20545 .56255 L .23483 .55917 L p .707 .577 .707 r
F P
0 g
s
.1814 .72268 m .1814 .7412 L .16503 .74857 L p .707 .577 .707 r
F P
0 g
s
.36607 .82439 m .36607 .3225 L .38918 .3121 L p .707 .577 .707 r
F P
0 g
s
.36607 .3225 m .36607 .82439 L .35607 .8362 L p .707 .577 .707 r
F P
0 g
s
.20545 .62041 m .20545 .65747 L .1814 .66312 L p .707 .577 .707 r
F P
0 g
s
.29784 .5603 m .29784 .61588 L .26667 .61398 L p .707 .577 .707 r
F P
0 g
s
.26667 .61398 m .26667 .5584 L .29784 .5603 L p .707 .577 .707 r
F P
0 g
s
.3253 .62255 m .3253 .65961 L .29784 .65521 L p .707 .577 .707 r
F P
0 g
s
.29784 .65521 m .29784 .61816 L .3253 .62255 L p .707 .577 .707 r
F P
0 g
s
.23483 .61476 m .23483 .55917 L .26667 .5584 L p .707 .577 .707 r
F P
0 g
s
.23483 .55917 m .23483 .61476 L .20545 .61814 L p .707 .577 .707 r
F P
0 g
s
.34635 .72562 m .34635 .74415 L .3253 .73769 L p .707 .577 .707 r
F P
0 g
s
.3253 .73769 m .3253 .71916 L .34635 .72562 L p .707 .577 .707 r
F P
0 g
s
.26667 .5584 m .26667 .61398 L .23483 .61476 L p .707 .577 .707 r
F P
0 g
s
.20545 .65747 m .20545 .62041 L .23483 .61704 L p .707 .577 .707 r
F P
0 g
s
.73333 .61347 m .73333 .55789 L .70216 .55599 L p .707 .577 .707 r
F P
0 g
s
.73333 .55789 m .73333 .61347 L .76517 .61269 L p .707 .577 .707 r
F P
0 g
s
.76517 .61269 m .76517 .55711 L .73333 .55789 L p .707 .577 .707 r
F P
0 g
s
.76517 .55711 m .76517 .61269 L .79455 .60931 L p .707 .577 .707 r
F P
0 g
s
.79455 .60931 m .79455 .55373 L .76517 .55711 L p .707 .577 .707 r
F P
0 g
s
.1814 .7412 m .1814 .72268 L .20545 .71703 L p .707 .577 .707 r
F P
0 g
s
.70216 .61157 m .70216 .55599 L .6747 .55159 L p .707 .577 .707 r
F P
0 g
s
.70216 .55599 m .70216 .61157 L .73333 .61347 L p .707 .577 .707 r
F P
0 g
s
.29784 .61816 m .29784 .65521 L .26667 .65331 L p .707 .577 .707 r
F P
0 g
s
.26667 .65331 m .26667 .61626 L .29784 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61704 m .23483 .65409 L .20545 .65747 L p .707 .577 .707 r
F P
0 g
s
.20545 .71703 m .20545 .73555 L .1814 .7412 L p .707 .577 .707 r
F P
0 g
s
.23483 .65409 m .23483 .61704 L .26667 .61626 L p .707 .577 .707 r
F P
0 g
s
.62206 .31625 m .62206 .81814 L .59233 .80903 L p .707 .577 .707 r
F P
0 g
s
.59233 .80903 m .59233 .30714 L .62206 .31625 L p .707 .577 .707 r
F P
0 g
s
.26667 .61626 m .26667 .65331 L .23483 .65409 L p .707 .577 .707 r
F P
0 g
s
.79455 .55373 m .79455 .60931 L .8186 .60366 L p .707 .577 .707 r
F P
0 g
s
.8186 .60366 m .8186 .54808 L .79455 .55373 L p .707 .577 .707 r
F P
0 g
s
.73333 .6528 m .73333 .61575 L .70216 .61385 L p .707 .577 .707 r
F P
0 g
s
.73333 .61575 m .73333 .6528 L .76517 .65202 L p .707 .577 .707 r
F P
0 g
s
.76517 .65202 m .76517 .61497 L .73333 .61575 L p .707 .577 .707 r
F P
0 g
s
.3253 .71916 m .3253 .73769 L .29784 .7333 L p .707 .577 .707 r
F P
0 g
s
.29784 .7333 m .29784 .71477 L .3253 .71916 L p .707 .577 .707 r
F P
0 g
s
.76517 .61497 m .76517 .65202 L .79455 .64864 L p .707 .577 .707 r
F P
0 g
s
.79455 .64864 m .79455 .61159 L .76517 .61497 L p .707 .577 .707 r
F P
0 g
s
.6747 .55159 m .6747 .60718 L .70216 .61157 L p .707 .577 .707 r
F P
0 g
s
.6747 .60718 m .6747 .55159 L .65365 .54514 L p .707 .577 .707 r
F P
0 g
s
.70216 .6509 m .70216 .61385 L .6747 .60945 L p .707 .577 .707 r
F P
0 g
s
.70216 .61385 m .70216 .6509 L .73333 .6528 L p .707 .577 .707 r
F P
0 g
s
.20545 .73555 m .20545 .71703 L .23483 .71365 L p .707 .577 .707 r
F P
0 g
s
.38918 .3121 m .38918 .81399 L .36607 .82439 L p .707 .577 .707 r
F P
0 g
s
.38918 .81399 m .38918 .3121 L .42314 .30413 L p .707 .577 .707 r
F P
0 g
s
.79455 .61159 m .79455 .64864 L .8186 .643 L p .707 .577 .707 r
F P
0 g
s
.8186 .643 m .8186 .60594 L .79455 .61159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71365 m .23483 .73218 L .20545 .73555 L p .707 .577 .707 r
F P
0 g
s
.6747 .60945 m .6747 .64651 L .70216 .6509 L p .707 .577 .707 r
F P
0 g
s
.29784 .71477 m .29784 .7333 L .26667 .7314 L p .707 .577 .707 r
F P
0 g
s
.26667 .7314 m .26667 .71287 L .29784 .71477 L p .707 .577 .707 r
F P
0 g
s
.8186 .54808 m .8186 .60366 L .83497 .59629 L p .707 .577 .707 r
F P
0 g
s
.83497 .59629 m .83497 .54071 L .8186 .54808 L p .707 .577 .707 r
F P
0 g
s
.65365 .54514 m .65365 .60072 L .6747 .60718 L p .707 .577 .707 r
F P
0 g
s
.23483 .73218 m .23483 .71365 L .26667 .71287 L p .707 .577 .707 r
F P
0 g
s
.6747 .64651 m .6747 .60945 L .65365 .603 L p .707 .577 .707 r
F P
0 g
s
.26667 .71287 m .26667 .7314 L .23483 .73218 L p .707 .577 .707 r
F P
0 g
s
.73333 .73089 m .73333 .71236 L .70216 .71046 L p .707 .577 .707 r
F P
0 g
s
.73333 .71236 m .73333 .73089 L .76517 .73011 L p .707 .577 .707 r
F P
0 g
s
.76517 .73011 m .76517 .71158 L .73333 .71236 L p .707 .577 .707 r
F P
0 g
s
.59233 .30714 m .59233 .80903 L .55357 .80283 L p .707 .577 .707 r
F P
0 g
s
.55357 .80283 m .55357 .30094 L .59233 .30714 L p .707 .577 .707 r
F P
0 g
s
.65365 .60072 m .65365 .54514 L .64105 .53725 L p .707 .577 .707 r
F P
0 g
s
.76517 .71158 m .76517 .73011 L .79455 .72673 L p .707 .577 .707 r
F P
0 g
s
.79455 .72673 m .79455 .7082 L .76517 .71158 L p .707 .577 .707 r
F P
0 g
s
.70216 .71046 m .70216 .72899 L .73333 .73089 L p .707 .577 .707 r
F P
0 g
s
.65365 .603 m .65365 .64005 L .6747 .64651 L p .707 .577 .707 r
F P
0 g
s
.70216 .72899 m .70216 .71046 L .6747 .70607 L p .707 .577 .707 r
F P
0 g
s
.8186 .60594 m .8186 .643 L .83497 .63563 L p .707 .577 .707 r
F P
0 g
s
.83497 .63563 m .83497 .59857 L .8186 .60594 L p .707 .577 .707 r
F P
0 g
s
.6747 .70607 m .6747 .72459 L .70216 .72899 L p .707 .577 .707 r
F P
0 g
s
.42314 .80602 m .42314 .30413 L .46462 .29936 L p .707 .577 .707 r
F P
0 g
s
.42314 .30413 m .42314 .80602 L .38918 .81399 L p .707 .577 .707 r
F P
0 g
s
.79455 .7082 m .79455 .72673 L .8186 .72108 L p .707 .577 .707 r
F P
0 g
s
.8186 .72108 m .8186 .70255 L .79455 .7082 L p .707 .577 .707 r
F P
0 g
s
.64105 .53725 m .64105 .59284 L .65365 .60072 L p .707 .577 .707 r
F P
0 g
s
.83497 .54071 m .83497 .59629 L .84205 .58793 L p .707 .577 .707 r
F P
0 g
s
.84205 .58793 m .84205 .53235 L .83497 .54071 L p .707 .577 .707 r
F P
0 g
s
.65365 .64005 m .65365 .603 L .64105 .59512 L p .707 .577 .707 r
F P
0 g
s
.6747 .72459 m .6747 .70607 L .65365 .69961 L p .707 .577 .707 r
F P
0 g
s
.55357 .30094 m .55357 .80283 L .50956 .80015 L p .707 .577 .707 r
F P
0 g
s
.50956 .80015 m .50956 .29826 L .55357 .30094 L p .707 .577 .707 r
F P
0 g
s
.65365 .69961 m .65365 .71814 L .6747 .72459 L p .707 .577 .707 r
F P
0 g
s
.46462 .80125 m .46462 .29936 L .50956 .29826 L p .707 .577 .707 r
F P
0 g
s
.46462 .29936 m .46462 .80125 L .42314 .80602 L p .707 .577 .707 r
F P
0 g
s
.64105 .59512 m .64105 .63217 L .65365 .64005 L p .707 .577 .707 r
F P
0 g
s
.64105 .59284 m .64105 .53725 L .63816 .52871 L p .707 .577 .707 r
F P
0 g
s
.50956 .29826 m .50956 .80015 L .46462 .80125 L p .707 .577 .707 r
F P
0 g
s
.83497 .59857 m .83497 .63563 L .84205 .62726 L p .707 .577 .707 r
F P
0 g
s
.84205 .62726 m .84205 .59021 L .83497 .59857 L p .707 .577 .707 r
F P
0 g
s
.8186 .70255 m .8186 .72108 L .83497 .71371 L p .707 .577 .707 r
F P
0 g
s
.83497 .71371 m .83497 .69519 L .8186 .70255 L p .707 .577 .707 r
F P
0 g
s
.65365 .71814 m .65365 .69961 L .64105 .69173 L p .707 .577 .707 r
F P
0 g
s
.63816 .52871 m .63816 .58429 L .64105 .59284 L p .707 .577 .707 r
F P
0 g
s
.64105 .63217 m .64105 .59512 L .63816 .58657 L p .707 .577 .707 r
F P
0 g
s
.84205 .53235 m .84205 .58793 L .83916 .57939 L p .707 .577 .707 r
F P
0 g
s
.83916 .57939 m .83916 .52381 L .84205 .53235 L p .707 .577 .707 r
F P
0 g
s
.64105 .69173 m .64105 .71026 L .65365 .71814 L p .707 .577 .707 r
F P
0 g
s
.63816 .58657 m .63816 .62363 L .64105 .63217 L p .707 .577 .707 r
F P
0 g
s
.83497 .69519 m .83497 .71371 L .84206 .70535 L p .707 .577 .707 r
F P
0 g
s
.84206 .70535 m .84206 .68682 L .83497 .69519 L p .707 .577 .707 r
F P
0 g
s
.63816 .58429 m .63816 .52871 L .64524 .52035 L p .707 .577 .707 r
F P
0 g
s
.84205 .59021 m .84205 .62726 L .83916 .61872 L p .707 .577 .707 r
F P
0 g
s
.83916 .61872 m .83916 .58167 L .84205 .59021 L p .707 .577 .707 r
F P
0 g
s
.64105 .71026 m .64105 .69173 L .63816 .68319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .52035 m .64524 .57593 L .63816 .58429 L p .707 .577 .707 r
F P
0 g
s
.63816 .62363 m .63816 .58657 L .64524 .57821 L p .707 .577 .707 r
F P
0 g
s
.63816 .68319 m .63816 .70171 L .64105 .71026 L p .707 .577 .707 r
F P
0 g
s
.83916 .52381 m .83916 .57939 L .82657 .5715 L p .707 .577 .707 r
F P
0 g
s
.82657 .5715 m .82657 .51592 L .83916 .52381 L p .707 .577 .707 r
F P
0 g
s
.64524 .57821 m .64524 .61526 L .63816 .62363 L p .707 .577 .707 r
F P
0 g
s
.39032 .57665 m .39032 .52107 L .35915 .51917 L p .707 .577 .707 r
F P
0 g
s
.39032 .52107 m .39032 .57665 L .42216 .57588 L p .707 .577 .707 r
F P
0 g
s
.42216 .57588 m .42216 .52029 L .39032 .52107 L p .707 .577 .707 r
F P
0 g
s
.84206 .68682 m .84206 .70535 L .83916 .69681 L p .707 .577 .707 r
F P
0 g
s
.83916 .69681 m .83916 .67828 L .84206 .68682 L p .707 .577 .707 r
F P
0 g
s
.64524 .57593 m .64524 .52035 L .66161 .51298 L p .707 .577 .707 r
F P
0 g
s
.42216 .52029 m .42216 .57588 L .45154 .5725 L p .707 .577 .707 r
F P
0 g
s
.45154 .5725 m .45154 .51691 L .42216 .52029 L p .707 .577 .707 r
F P
0 g
s
.83916 .58167 m .83916 .61872 L .82657 .61084 L p .707 .577 .707 r
F P
0 g
s
.82657 .61084 m .82657 .57378 L .83916 .58167 L p .707 .577 .707 r
F P
0 g
s
.35915 .57475 m .35915 .51917 L .33169 .51478 L p .707 .577 .707 r
F P
0 g
s
.35915 .51917 m .35915 .57475 L .39032 .57665 L p .707 .577 .707 r
F P
0 g
s
.45154 .51691 m .45154 .5725 L .47559 .56685 L p .707 .577 .707 r
F P
0 g
s
.47559 .56685 m .47559 .51126 L .45154 .51691 L p .707 .577 .707 r
F P
0 g
s
.63816 .70171 m .63816 .68319 L .64524 .67482 L p .707 .577 .707 r
F P
0 g
s
.39032 .61599 m .39032 .57893 L .35915 .57703 L p .707 .577 .707 r
F P
0 g
s
.39032 .57893 m .39032 .61599 L .42216 .61521 L p .707 .577 .707 r
F P
0 g
s
.42216 .61521 m .42216 .57815 L .39032 .57893 L p .707 .577 .707 r
F P
0 g
s
.66161 .51298 m .66161 .56856 L .64524 .57593 L p .707 .577 .707 r
F P
0 g
s
.82657 .51592 m .82657 .5715 L .80551 .56505 L p .707 .577 .707 r
F P
0 g
s
.80551 .56505 m .80551 .50947 L .82657 .51592 L p .707 .577 .707 r
F P
0 g
s
.64524 .61526 m .64524 .57821 L .66161 .57084 L p .707 .577 .707 r
F P
0 g
s
.42216 .57815 m .42216 .61521 L .45154 .61183 L p .707 .577 .707 r
F P
0 g
s
.45154 .61183 m .45154 .57477 L .42216 .57815 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .67482 m .64524 .69335 L .63816 .70171 L p .707 .577 .707 r
F P
0 g
s
.33169 .51478 m .33169 .57036 L .35915 .57475 L p .707 .577 .707 r
F P
0 g
s
.33169 .57036 m .33169 .51478 L .31064 .50832 L p .707 .577 .707 r
F P
0 g
s
.35915 .61408 m .35915 .57703 L .33169 .57264 L p .707 .577 .707 r
F P
0 g
s
.35915 .57703 m .35915 .61408 L .39032 .61599 L p .707 .577 .707 r
F P
0 g
s
.66161 .57084 m .66161 .6079 L .64524 .61526 L p .707 .577 .707 r
F P
0 g
s
.66161 .56856 m .66161 .51298 L .68566 .50733 L p .707 .577 .707 r
F P
0 g
s
.45154 .57477 m .45154 .61183 L .47559 .60618 L p .707 .577 .707 r
F P
0 g
s
.47559 .60618 m .47559 .56912 L .45154 .57477 L p .707 .577 .707 r
F P
0 g
s
.83916 .67828 m .83916 .69681 L .82657 .68892 L p .707 .577 .707 r
F P
0 g
s
.82657 .68892 m .82657 .6704 L .83916 .67828 L p .707 .577 .707 r
F P
0 g
s
.33169 .57264 m .33169 .60969 L .35915 .61408 L p .707 .577 .707 r
F P
0 g
s
.82657 .57378 m .82657 .61084 L .80551 .60438 L p .707 .577 .707 r
F P
0 g
s
.80551 .60438 m .80551 .56733 L .82657 .57378 L p .707 .577 .707 r
F P
0 g
s
.47559 .51126 m .47559 .56685 L .49196 .55948 L p .707 .577 .707 r
F P
0 g
s
.49196 .55948 m .49196 .5039 L .47559 .51126 L p .707 .577 .707 r
F P
0 g
s
.31064 .50832 m .31064 .56391 L .33169 .57036 L p .707 .577 .707 r
F P
0 g
s
.33169 .60969 m .33169 .57264 L .31064 .56618 L p .707 .577 .707 r
F P
0 g
s
.80551 .50947 m .80551 .56505 L .77805 .56066 L p .707 .577 .707 r
F P
0 g
s
.77805 .56066 m .77805 .50507 L .80551 .50947 L p .707 .577 .707 r
F P
0 g
s
.39032 .69407 m .39032 .67554 L .35915 .67364 L p .707 .577 .707 r
F P
0 g
s
.39032 .67554 m .39032 .69407 L .42216 .69329 L p .707 .577 .707 r
F P
0 g
s
.42216 .69329 m .42216 .67477 L .39032 .67554 L p .707 .577 .707 r
F P
0 g
s
.68566 .50733 m .68566 .56291 L .66161 .56856 L p .707 .577 .707 r
F P
0 g
s
.66161 .6079 m .66161 .57084 L .68566 .56519 L p .707 .577 .707 r
F P
0 g
s
.64524 .69335 m .64524 .67482 L .66161 .66745 L p .707 .577 .707 r
F P
0 g
s
.31064 .56391 m .31064 .50832 L .29804 .50044 L p .707 .577 .707 r
F P
0 g
s
.42216 .67477 m .42216 .69329 L .45154 .68992 L p .707 .577 .707 r
F P
0 g
s
.45154 .68992 m .45154 .67139 L .42216 .67477 L p .707 .577 .707 r
F P
0 g
s
.35915 .67364 m .35915 .69217 L .39032 .69407 L p .707 .577 .707 r
F P
0 g
s
.31064 .56618 m .31064 .60324 L .33169 .60969 L p .707 .577 .707 r
F P
0 g
s
.68566 .56291 m .68566 .50733 L .71504 .50395 L p .707 .577 .707 r
F P
0 g
s
.35915 .69217 m .35915 .67364 L .33169 .66925 L p .707 .577 .707 r
F P
0 g
s
.66161 .66745 m .66161 .68598 L .64524 .69335 L p .707 .577 .707 r
F P
0 g
s
.47559 .56912 m .47559 .60618 L .49196 .59881 L p .707 .577 .707 r
F P
0 g
s
.49196 .59881 m .49196 .56176 L .47559 .56912 L p .707 .577 .707 r
F P
0 g
s
.33169 .66925 m .33169 .68778 L .35915 .69217 L p .707 .577 .707 r
F P
0 g
s
.68566 .56519 m .68566 .60225 L .66161 .6079 L p .707 .577 .707 r
F P
0 g
s
.77805 .50507 m .77805 .56066 L .74688 .55876 L p .707 .577 .707 r
F P
0 g
s
.74688 .55876 m .74688 .50317 L .77805 .50507 L p .707 .577 .707 r
F P
0 g
s
.80551 .56733 m .80551 .60438 L .77805 .59999 L p .707 .577 .707 r
F P
0 g
s
.77805 .59999 m .77805 .56294 L .80551 .56733 L p .707 .577 .707 r
F P
0 g
s
.45154 .67139 m .45154 .68992 L .47559 .68427 L p .707 .577 .707 r
F P
0 g
s
.47559 .68427 m .47559 .66574 L .45154 .67139 L p .707 .577 .707 r
F P
0 g
s
.29804 .50044 m .29804 .55602 L .31064 .56391 L p .707 .577 .707 r
F P
0 g
s
.71504 .55953 m .71504 .50395 L .74688 .50317 L p .707 .577 .707 r
F P
0 g
s
.71504 .50395 m .71504 .55953 L .68566 .56291 L p .707 .577 .707 r
F P
0 g
s
.82657 .6704 m .82657 .68892 L .80551 .68247 L p .707 .577 .707 r
F P
0 g
s
.80551 .68247 m .80551 .66394 L .82657 .6704 L p .707 .577 .707 r
F P
0 g
s
.49196 .5039 m .49196 .55948 L .49904 .55111 L p .707 .577 .707 r
F P
0 g
s
.49904 .55111 m .49904 .49553 L .49196 .5039 L p .707 .577 .707 r
F P
0 g
s
.31064 .60324 m .31064 .56618 L .29804 .5583 L p .707 .577 .707 r
F P
0 g
s
.74688 .50317 m .74688 .55876 L .71504 .55953 L p .707 .577 .707 r
F P
0 g
s
.68566 .60225 m .68566 .56519 L .71504 .56181 L p .707 .577 .707 r
F P
0 g
s
.33169 .68778 m .33169 .66925 L .31064 .6628 L p .707 .577 .707 r
F P
0 g
s
.31064 .6628 m .31064 .68132 L .33169 .68778 L p .707 .577 .707 r
F P
0 g
s
.66161 .68598 m .66161 .66745 L .68566 .6618 L p .707 .577 .707 r
F P
0 g
s
.29804 .5583 m .29804 .59535 L .31064 .60324 L p .707 .577 .707 r
F P
0 g
s
.77805 .56294 m .77805 .59999 L .74688 .59809 L p .707 .577 .707 r
F P
0 g
s
.74688 .59809 m .74688 .56103 L .77805 .56294 L p .707 .577 .707 r
F P
0 g
s
.29804 .55602 m .29804 .50044 L .29515 .4919 L p .707 .577 .707 r
F P
0 g
s
.71504 .56181 m .71504 .59887 L .68566 .60225 L p .707 .577 .707 r
F P
0 g
s
.68566 .6618 m .68566 .68033 L .66161 .68598 L p .707 .577 .707 r
F P
0 g
s
.71504 .59887 m .71504 .56181 L .74688 .56103 L p .707 .577 .707 r
F P
0 g
s
.49196 .56176 m .49196 .59881 L .49904 .59045 L p .707 .577 .707 r
F P
0 g
s
.49904 .59045 m .49904 .55339 L .49196 .56176 L p .707 .577 .707 r
F P
0 g
s
.47559 .66574 m .47559 .68427 L .49196 .6769 L p .707 .577 .707 r
F P
0 g
s
.49196 .6769 m .49196 .65837 L .47559 .66574 L p .707 .577 .707 r
F P
0 g
s
.74688 .56103 m .74688 .59809 L .71504 .59887 L p .707 .577 .707 r
F P
0 g
s
.80551 .66394 m .80551 .68247 L .77805 .67808 L p .707 .577 .707 r
F P
0 g
s
.77805 .67808 m .77805 .65955 L .80551 .66394 L p .707 .577 .707 r
F P
0 g
s
.31064 .68132 m .31064 .6628 L .29804 .65491 L p .707 .577 .707 r
F P
0 g
s
.29515 .4919 m .29515 .54748 L .29804 .55602 L p .707 .577 .707 r
F P
0 g
s
.29804 .59535 m .29804 .5583 L .29515 .54976 L p .707 .577 .707 r
F P
0 g
s
.49904 .49553 m .49904 .55111 L .49615 .54257 L p .707 .577 .707 r
F P
0 g
s
.49615 .54257 m .49615 .48699 L .49904 .49553 L p .707 .577 .707 r
F P
0 g
s
.68566 .68033 m .68566 .6618 L .71504 .65843 L p .707 .577 .707 r
F P
0 g
s
.29804 .65491 m .29804 .67344 L .31064 .68132 L p .707 .577 .707 r
F P
0 g
s
.71504 .65843 m .71504 .67695 L .68566 .68033 L p .707 .577 .707 r
F P
0 g
s
.77805 .65955 m .77805 .67808 L .74688 .67618 L p .707 .577 .707 r
F P
0 g
s
.74688 .67618 m .74688 .65765 L .77805 .65955 L p .707 .577 .707 r
F P
0 g
s
.29515 .54976 m .29515 .58681 L .29804 .59535 L p .707 .577 .707 r
F P
0 g
s
.71504 .67695 m .71504 .65843 L .74688 .65765 L p .707 .577 .707 r
F P
0 g
s
.49196 .65837 m .49196 .6769 L .49904 .66853 L p .707 .577 .707 r
F P
0 g
s
.49904 .66853 m .49904 .65001 L .49196 .65837 L p .707 .577 .707 r
F P
0 g
s
.29515 .54748 m .29515 .4919 L .30223 .48353 L p .707 .577 .707 r
F P
0 g
s
.74688 .65765 m .74688 .67618 L .71504 .67695 L p .707 .577 .707 r
F P
0 g
s
.49904 .55339 m .49904 .59045 L .49615 .58191 L p .707 .577 .707 r
F P
0 g
s
.49615 .58191 m .49615 .54485 L .49904 .55339 L p .707 .577 .707 r
F P
0 g
s
.29804 .67344 m .29804 .65491 L .29515 .64637 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48353 m .30223 .53911 L .29515 .54748 L p .707 .577 .707 r
F P
0 g
s
.29515 .58681 m .29515 .54976 L .30223 .54139 L p .707 .577 .707 r
F P
0 g
s
.29515 .64637 m .29515 .6649 L .29804 .67344 L p .707 .577 .707 r
F P
0 g
s
.49615 .48699 m .49615 .54257 L .48356 .53469 L p .707 .577 .707 r
F P
0 g
s
.48356 .53469 m .48356 .47911 L .49615 .48699 L p .707 .577 .707 r
F P
0 g
s
.30223 .54139 m .30223 .57845 L .29515 .58681 L p .707 .577 .707 r
F P
0 g
s
.49904 .65001 m .49904 .66853 L .49615 .65999 L p .707 .577 .707 r
F P
0 g
s
.49615 .65999 m .49615 .64146 L .49904 .65001 L p .707 .577 .707 r
F P
0 g
s
.30223 .53911 m .30223 .48353 L .3186 .47616 L p .707 .577 .707 r
F P
0 g
s
.49615 .54485 m .49615 .58191 L .48356 .57402 L p .707 .577 .707 r
F P
0 g
s
.48356 .57402 m .48356 .53697 L .49615 .54485 L p .707 .577 .707 r
F P
0 g
s
.29515 .6649 m .29515 .64637 L .30223 .63801 L p .707 .577 .707 r
F P
0 g
s
.3186 .47616 m .3186 .53175 L .30223 .53911 L p .707 .577 .707 r
F P
0 g
s
.48356 .47911 m .48356 .53469 L .4625 .52823 L p .707 .577 .707 r
F P
0 g
s
.4625 .52823 m .4625 .47265 L .48356 .47911 L p .707 .577 .707 r
F P
0 g
s
.30223 .57845 m .30223 .54139 L .3186 .53402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .63801 m .30223 .65653 L .29515 .6649 L p .707 .577 .707 r
F P
0 g
s
.3186 .53402 m .3186 .57108 L .30223 .57845 L p .707 .577 .707 r
F P
0 g
s
.3186 .53175 m .3186 .47616 L .34265 .47051 L p .707 .577 .707 r
F P
0 g
s
.49615 .64146 m .49615 .65999 L .48356 .65211 L p .707 .577 .707 r
F P
0 g
s
.48356 .65211 m .48356 .63358 L .49615 .64146 L p .707 .577 .707 r
F P
0 g
s
.48356 .53697 m .48356 .57402 L .4625 .56757 L p .707 .577 .707 r
F P
0 g
s
.4625 .56757 m .4625 .53051 L .48356 .53697 L p .707 .577 .707 r
F P
0 g
s
.4625 .47265 m .4625 .52823 L .43504 .52384 L p .707 .577 .707 r
F P
0 g
s
.43504 .52384 m .43504 .46826 L .4625 .47265 L p .707 .577 .707 r
F P
0 g
s
.34265 .47051 m .34265 .5261 L .3186 .53175 L p .707 .577 .707 r
F P
0 g
s
.3186 .57108 m .3186 .53402 L .34265 .52838 L p .707 .577 .707 r
F P
0 g
s
.30223 .65653 m .30223 .63801 L .3186 .63064 L p .707 .577 .707 r
F P
0 g
s
.34265 .5261 m .34265 .47051 L .37203 .46714 L p .707 .577 .707 r
F P
0 g
s
.3186 .63064 m .3186 .64917 L .30223 .65653 L p .707 .577 .707 r
F P
0 g
s
.34265 .52838 m .34265 .56543 L .3186 .57108 L p .707 .577 .707 r
F P
0 g
s
.43504 .46826 m .43504 .52384 L .40387 .52194 L p .707 .577 .707 r
F P
0 g
s
.40387 .52194 m .40387 .46636 L .43504 .46826 L p .707 .577 .707 r
F P
0 g
s
.4625 .53051 m .4625 .56757 L .43504 .56317 L p .707 .577 .707 r
F P
0 g
s
.43504 .56317 m .43504 .52612 L .4625 .53051 L p .707 .577 .707 r
F P
0 g
s
.37203 .52272 m .37203 .46714 L .40387 .46636 L p .707 .577 .707 r
F P
0 g
s
.37203 .46714 m .37203 .52272 L .34265 .5261 L p .707 .577 .707 r
F P
0 g
s
.48356 .63358 m .48356 .65211 L .4625 .64565 L p .707 .577 .707 r
F P
0 g
s
.4625 .64565 m .4625 .62713 L .48356 .63358 L p .707 .577 .707 r
F P
0 g
s
.40387 .46636 m .40387 .52194 L .37203 .52272 L p .707 .577 .707 r
F P
0 g
s
.34265 .56543 m .34265 .52838 L .37203 .525 L p .707 .577 .707 r
F P
0 g
s
.3186 .64917 m .3186 .63064 L .34265 .62499 L p .707 .577 .707 r
F P
0 g
s
.43504 .52612 m .43504 .56317 L .40387 .56127 L p .707 .577 .707 r
F P
0 g
s
.40387 .56127 m .40387 .52422 L .43504 .52612 L p .707 .577 .707 r
F P
0 g
s
.37203 .525 m .37203 .56205 L .34265 .56543 L p .707 .577 .707 r
F P
0 g
s
.34265 .62499 m .34265 .64352 L .3186 .64917 L p .707 .577 .707 r
F P
0 g
s
.37203 .56205 m .37203 .525 L .40387 .52422 L p .707 .577 .707 r
F P
0 g
s
.40387 .52422 m .40387 .56127 L .37203 .56205 L p .707 .577 .707 r
F P
0 g
s
.4625 .62713 m .4625 .64565 L .43504 .64126 L p .707 .577 .707 r
F P
0 g
s
.43504 .64126 m .43504 .62273 L .4625 .62713 L p .707 .577 .707 r
F P
0 g
s
.34265 .64352 m .34265 .62499 L .37203 .62161 L p .707 .577 .707 r
F P
0 g
s
.37203 .62161 m .37203 .64014 L .34265 .64352 L p .707 .577 .707 r
F P
0 g
s
.43504 .62273 m .43504 .64126 L .40387 .63936 L p .707 .577 .707 r
F P
0 g
s
.40387 .63936 m .40387 .62083 L .43504 .62273 L p .707 .577 .707 r
F P
0 g
s
.37203 .64014 m .37203 .62161 L .40387 .62083 L p .707 .577 .707 r
F P
0 g
s
.40387 .62083 m .40387 .63936 L .37203 .64014 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001/Ool30009FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03
001JEUYF00=JER40009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005=oo`03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo
2@000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool003Uoo`h000AJEP03001JEUYF009JEP@00003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03
FUH70007FUH50004FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPL0
00AJEP03001JEUYF00IJEP03001JEUYF009JEPd000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000<0
00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH60000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF200000=JEP00FUH00UYF
0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH90004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH;00000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEP0000T000AJEP@0009JEPh000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH400000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH0
0eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00;Goo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008FUH50004FUH00`00FUIJEP05FUH50004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH80004FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUH0000500000eYF001JEP02FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20003FUH>0004FUH40005FUH00`00FUIJEP02FUH70003FUH30003FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EPP000AJEP03001JEUYF00=JEPh0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUHK0003FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EQl000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH000090004FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF01800003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF00000eYF1`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF30000eYF00<005YF
FUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
0000;Goo000/Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF00000`0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF0000
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH50006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH40000
0eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2@000eYF00@005YF001JEP8000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP03
001JEP0001P003moo`00;7oo00<005YF000015YF00<005YFFUH00eYF4`0015YF100000AJEP000000
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001`0015YF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<005YF00000`0000=JEP000000100015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPP00003FUH005YF009JEQX003aoo`00;7oo00<005YF00000eYF2@0015YF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEPX00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00001`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;7oo00@005YF001JEP8000AJEPd000AJEP@0
009JEPP000=JEP03001JEP00008000=JEP<0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`06001JEP00001JEP001EYF00@0
05YFFUIJEQX000=JEP03001JEUYF009JEPD00004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000b
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH00eYF2@000eYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`8000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJ
EP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04001JEUYFFUH2000J
Ool40003FUH01000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPD000AJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000NOol40003
FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000L000AJEPD000EJEP03001JEUYF009J
EPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Woo00<005YFFUH0
0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEP00018000MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00AJEP04001JEUYFFUH2000SOol4000]Ool003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000020003FUH01000FUIJEUYF
0P008Goo0P0000AJEP00000002eoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF00000`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEP0000P000=JEP8001ioo`<000=JEP<002eoo`00>goo200015YF00<005YFFUH0
1eYF00<005YFFUH00UYF1@002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF009JEP@0009JEP03001JEUYF008001Yoo`@00003FUH005YF00=JEP03001JEP00
02eoo`00@goo4`003goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEP0000L001Eoo`D000EJEP03001JEUYF009JEP8002ioo`00?goo4@005Goo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uoo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000`Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP04001JEUYFFUH4000dOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF1@0015YF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH0000J000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000Uoo`P000AJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`03001JEP0000AJEP04001JEUYFFUH8000I
Ool60004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEP@005]oo`00;7oo00<005YF00000eYF1@009goo0`0000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H005moo`00
;7oo00@005YF001JEP8002moo`80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`@003Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008006=oo`00;7oo0P000UYF0`00;goo10000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool20003
FUH00`00FUH00002000YOol30002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00005FUH00`00FUH00002001KOol002aoo`8000=JEP03001JEUYF009JEPD0021o
o`@00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8
000COol50005FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF0P00F7oo000^Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEP00001F
Ool0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000100000=JEP00FUH015YF00D005YFFUIJEP0005Eoo`00<goo0`0000=JEP00FUH01UYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000AJEP05001JEUYFFUH0001EOol0
03Ioo`D000AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEP0000<000Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001JEP02FUH2
001DOol003]oo`P000AJEPD000EJEP03001JEUYF009JEPD000Yoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2001DOol004=ooa<000moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000<Ool200000eYF0000001DOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;Ool2000015YF0000
0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
0`000eYF0`00E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000017oo100000=JEP00FUH00eYF00<005YF0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH01eYF5@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010001EYF00<005YFFUH00UYF0P00EGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00@005YFFUIJEPH000UJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEUYFFUH2001F
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH01000FUH00000F7oo001UOol01000FUIJEP001EYF0`000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEPD005Yoo`00IGoo00@005YFFUH000=JEP8000EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001J
EP0000H005moo`00IGoo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0001U
Ool006Eoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo06Aoo`00
IGoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo001UOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`1TOol006Eoo`8000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Io
o`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00Igoo001WOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Uoo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2001ZOol006]o
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEP00001/Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00LGoo1@0025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@00LWoo001fOol60002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001gOol007aoo`T000IJEP03001JEUYF00YJEP03001J
EUYF00H007aoo`00QGoo5P00PWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70551 m .59613 .64992 L .56496 .64802 L p .707 .577 .707 r
F P
0 g
s
.59613 .64992 m .59613 .70551 L .62796 .70473 L p .707 .577 .707 r
F P
0 g
s
.62796 .70473 m .62796 .64915 L .59613 .64992 L p .707 .577 .707 r
F P
0 g
s
.62796 .64915 m .62796 .70473 L .65734 .70135 L p .707 .577 .707 r
F P
0 g
s
.65734 .70135 m .65734 .64577 L .62796 .64915 L p .707 .577 .707 r
F P
0 g
s
.56496 .70361 m .56496 .64802 L .5375 .64363 L p .707 .577 .707 r
F P
0 g
s
.56496 .64802 m .56496 .70361 L .59613 .70551 L p .707 .577 .707 r
F P
0 g
s
.65734 .64577 m .65734 .70135 L .6814 .6957 L p .707 .577 .707 r
F P
0 g
s
.6814 .6957 m .6814 .64012 L .65734 .64577 L p .707 .577 .707 r
F P
0 g
s
.59613 .74484 m .59613 .70778 L .56496 .70588 L p .707 .577 .707 r
F P
0 g
s
.59613 .70778 m .59613 .74484 L .62796 .74406 L p .707 .577 .707 r
F P
0 g
s
.62796 .74406 m .62796 .70701 L .59613 .70778 L p .707 .577 .707 r
F P
0 g
s
.62796 .70701 m .62796 .74406 L .65735 .74068 L p .707 .577 .707 r
F P
0 g
s
.65735 .74068 m .65734 .70363 L .62796 .70701 L p .707 .577 .707 r
F P
0 g
s
.5375 .64363 m .5375 .69921 L .56496 .70361 L p .707 .577 .707 r
F P
0 g
s
.5375 .69921 m .5375 .64363 L .51644 .63718 L p .707 .577 .707 r
F P
0 g
s
.56496 .74294 m .56496 .70588 L .5375 .70149 L p .707 .577 .707 r
F P
0 g
s
.56496 .70588 m .56496 .74294 L .59613 .74484 L p .707 .577 .707 r
F P
0 g
s
.65734 .70363 m .65735 .74068 L .6814 .73503 L p .707 .577 .707 r
F P
0 g
s
.6814 .73503 m .6814 .69798 L .65734 .70363 L p .707 .577 .707 r
F P
0 g
s
.5375 .70149 m .5375 .73855 L .56496 .74294 L p .707 .577 .707 r
F P
0 g
s
.6814 .64012 m .6814 .6957 L .69777 .68833 L p .707 .577 .707 r
F P
0 g
s
.69777 .68833 m .69777 .63275 L .6814 .64012 L p .707 .577 .707 r
F P
0 g
s
.51644 .63718 m .51644 .69276 L .5375 .69921 L p .707 .577 .707 r
F P
0 g
s
.5375 .73855 m .5375 .70149 L .51644 .69504 L p .707 .577 .707 r
F P
0 g
s
.59613 .82292 m .59613 .8044 L .56496 .8025 L p .707 .577 .707 r
F P
0 g
s
.59613 .8044 m .59613 .82292 L .62796 .82215 L p .707 .577 .707 r
F P
0 g
s
.62796 .82215 m .62796 .80362 L .59613 .8044 L p .707 .577 .707 r
F P
0 g
s
.51644 .69276 m .51644 .63718 L .50385 .62929 L p .707 .577 .707 r
F P
0 g
s
.62796 .80362 m .62796 .82215 L .65735 .81877 L p .707 .577 .707 r
F P
0 g
s
.65735 .81877 m .65735 .80024 L .62796 .80362 L p .707 .577 .707 r
F P
0 g
s
.56496 .8025 m .56496 .82102 L .59613 .82292 L p .707 .577 .707 r
F P
0 g
s
.51644 .69504 m .51644 .73209 L .5375 .73855 L p .707 .577 .707 r
F P
0 g
s
.56496 .82102 m .56496 .8025 L .5375 .7981 L p .707 .577 .707 r
F P
0 g
s
.6814 .69798 m .6814 .73503 L .69777 .72767 L p .707 .577 .707 r
F P
0 g
s
.69777 .72767 m .69777 .69061 L .6814 .69798 L p .707 .577 .707 r
F P
0 g
s
.5375 .7981 m .5375 .81663 L .56496 .82102 L p .707 .577 .707 r
F P
0 g
s
.65735 .80024 m .65735 .81877 L .6814 .81312 L p .707 .577 .707 r
F P
0 g
s
.6814 .81312 m .6814 .79459 L .65735 .80024 L p .707 .577 .707 r
F P
0 g
s
.50385 .62929 m .50385 .68488 L .51644 .69276 L p .707 .577 .707 r
F P
0 g
s
.69777 .63275 m .69777 .68833 L .70485 .67997 L p .707 .577 .707 r
F P
0 g
s
.70485 .67997 m .70485 .62439 L .69777 .63275 L p .707 .577 .707 r
F P
0 g
s
.51644 .73209 m .51644 .69504 L .50385 .68715 L p .707 .577 .707 r
F P
0 g
s
.5375 .81663 m .5375 .7981 L .51644 .79165 L p .707 .577 .707 r
F P
0 g
s
.51644 .79165 m .51644 .81018 L .5375 .81663 L p .707 .577 .707 r
F P
0 g
s
.50385 .68715 m .50385 .72421 L .51644 .73209 L p .707 .577 .707 r
F P
0 g
s
.50385 .68488 m .50385 .62929 L .50095 .62075 L p .707 .577 .707 r
F P
0 g
s
.69777 .69061 m .69777 .72767 L .70485 .7193 L p .707 .577 .707 r
F P
0 g
s
.70485 .7193 m .70485 .68225 L .69777 .69061 L p .707 .577 .707 r
F P
0 g
s
.6814 .79459 m .6814 .81312 L .69777 .80575 L p .707 .577 .707 r
F P
0 g
s
.69777 .80575 m .69777 .78722 L .6814 .79459 L p .707 .577 .707 r
F P
0 g
s
.51644 .81018 m .51644 .79165 L .50385 .78377 L p .707 .577 .707 r
F P
0 g
s
.50095 .62075 m .50095 .67633 L .50385 .68488 L p .707 .577 .707 r
F P
0 g
s
.50385 .72421 m .50385 .68715 L .50095 .67861 L p .707 .577 .707 r
F P
0 g
s
.70485 .62439 m .70485 .67997 L .70195 .67143 L p .707 .577 .707 r
F P
0 g
s
.70195 .67143 m .70195 .61584 L .70485 .62439 L p .707 .577 .707 r
F P
0 g
s
.50385 .78377 m .50385 .80229 L .51644 .81018 L p .707 .577 .707 r
F P
0 g
s
.50095 .67861 m .50095 .71567 L .50385 .72421 L p .707 .577 .707 r
F P
0 g
s
.69777 .78722 m .69777 .80575 L .70485 .79739 L p .707 .577 .707 r
F P
0 g
s
.70485 .79739 m .70485 .77886 L .69777 .78722 L p .707 .577 .707 r
F P
0 g
s
.50095 .67633 m .50095 .62075 L .50804 .61239 L p .707 .577 .707 r
F P
0 g
s
.70485 .68225 m .70485 .7193 L .70195 .71076 L p .707 .577 .707 r
F P
0 g
s
.70195 .71076 m .70195 .6737 L .70485 .68225 L p .707 .577 .707 r
F P
0 g
s
.50385 .80229 m .50385 .78377 L .50095 .77522 L p .707 .577 .707 r
F P
0 g
s
.50804 .61239 m .50804 .66797 L .50095 .67633 L p .707 .577 .707 r
F P
0 g
s
.50095 .71567 m .50095 .67861 L .50804 .67025 L p .707 .577 .707 r
F P
0 g
s
.50095 .77522 m .50095 .79375 L .50385 .80229 L p .707 .577 .707 r
F P
0 g
s
.70195 .61584 m .70195 .67143 L .68936 .66354 L p .707 .577 .707 r
F P
0 g
s
.68936 .66354 m .68936 .60796 L .70195 .61584 L p .707 .577 .707 r
F P
0 g
s
.49044 .87739 m .49044 .3755 L .44643 .37282 L p .707 .577 .707 r
F P
0 g
s
.50804 .67025 m .50804 .7073 L .50095 .71567 L p .707 .577 .707 r
F P
0 g
s
.50804 .66797 m .50804 .61239 L .5244 .60502 L p .707 .577 .707 r
F P
0 g
s
.50095 .79375 m .50095 .77522 L .50804 .76686 L p .707 .577 .707 r
F P
0 g
s
.5244 .60502 m .5244 .6606 L .50804 .66797 L p .707 .577 .707 r
F P
0 g
s
.50804 .7073 m .50804 .67025 L .5244 .66288 L p .707 .577 .707 r
F P
0 g
s
.50804 .76686 m .50804 .78539 L .50095 .79375 L p .707 .577 .707 r
F P
0 g
s
.5244 .66288 m .5244 .69993 L .50804 .7073 L p .707 .577 .707 r
F P
0 g
s
.50804 .78539 m .50804 .76686 L .5244 .75949 L p .707 .577 .707 r
F P
0 g
s
.5244 .75949 m .5244 .77802 L .50804 .78539 L p .707 .577 .707 r
F P
0 g
s
.5244 .77802 m .5244 .75949 L .54846 .75384 L p .707 .577 .707 r
F P
0 g
s
.54846 .75384 m .54846 .77237 L .5244 .77802 L p .707 .577 .707 r
F P
0 g
s
.49044 .3755 m .49044 .87739 L .53538 .87629 L p .707 .577 .707 r
F P
0 g
s
.5244 .6606 m .5244 .60502 L .54846 .59937 L p .707 .577 .707 r
F P
0 g
s
.54846 .59937 m .54846 .65495 L .5244 .6606 L p .707 .577 .707 r
F P
0 g
s
.5244 .69993 m .5244 .66288 L .54846 .65723 L p .707 .577 .707 r
F P
0 g
s
.54846 .65723 m .54846 .69428 L .5244 .69993 L p .707 .577 .707 r
F P
0 g
s
.53538 .87629 m .53538 .3744 L .49044 .3755 L p .707 .577 .707 r
F P
0 g
s
.25312 .66869 m .25312 .61311 L .22195 .61121 L p .707 .577 .707 r
F P
0 g
s
.25312 .61311 m .25312 .66869 L .28495 .66791 L p .707 .577 .707 r
F P
0 g
s
.28495 .66791 m .28495 .61233 L .25312 .61311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65495 m .54846 .59937 L .57784 .59599 L p .707 .577 .707 r
F P
0 g
s
.57784 .59599 m .57784 .65157 L .54846 .65495 L p .707 .577 .707 r
F P
0 g
s
.54846 .69428 m .54846 .65723 L .57784 .65385 L p .707 .577 .707 r
F P
0 g
s
.57784 .65385 m .57784 .69091 L .54846 .69428 L p .707 .577 .707 r
F P
0 g
s
.54846 .77237 m .54846 .75384 L .57784 .75046 L p .707 .577 .707 r
F P
0 g
s
.57784 .75046 m .57784 .76899 L .54846 .77237 L p .707 .577 .707 r
F P
0 g
s
.53538 .3744 m .53538 .87629 L .57686 .87152 L p .707 .577 .707 r
F P
0 g
s
.57686 .87152 m .57686 .36963 L .53538 .3744 L p .707 .577 .707 r
F P
0 g
s
.70485 .77886 m .70485 .79739 L .70195 .78884 L p .707 .577 .707 r
F P
0 g
s
.70195 .78884 m .70195 .77032 L .70485 .77886 L p .707 .577 .707 r
F P
0 g
s
.28495 .61233 m .28495 .66791 L .31434 .66454 L p .707 .577 .707 r
F P
0 g
s
.31434 .66454 m .31434 .60895 L .28495 .61233 L p .707 .577 .707 r
F P
0 g
s
.70195 .6737 m .70195 .71076 L .68936 .70288 L p .707 .577 .707 r
F P
0 g
s
.68936 .70288 m .68936 .66582 L .70195 .6737 L p .707 .577 .707 r
F P
0 g
s
.44643 .8747 m .44643 .37282 L .40766 .36661 L p .707 .577 .707 r
F P
0 g
s
.44643 .37282 m .44643 .8747 L .49044 .87739 L p .707 .577 .707 r
F P
0 g
s
.22195 .66679 m .22195 .61121 L .19449 .60682 L p .707 .577 .707 r
F P
0 g
s
.22195 .61121 m .22195 .66679 L .25312 .66869 L p .707 .577 .707 r
F P
0 g
s
.31434 .60895 m .31434 .66454 L .33839 .65889 L p .707 .577 .707 r
F P
0 g
s
.33839 .65889 m .33839 .6033 L .31434 .60895 L p .707 .577 .707 r
F P
0 g
s
.25312 .70802 m .25312 .67097 L .22195 .66907 L p .707 .577 .707 r
F P
0 g
s
.25312 .67097 m .25312 .70802 L .28495 .70725 L p .707 .577 .707 r
F P
0 g
s
.28495 .70725 m .28495 .67019 L .25312 .67097 L p .707 .577 .707 r
F P
0 g
s
.57784 .65157 m .57784 .59599 L .60968 .59521 L p .707 .577 .707 r
F P
0 g
s
.60968 .59521 m .60968 .6508 L .57784 .65157 L p .707 .577 .707 r
F P
0 g
s
.57784 .69091 m .57784 .65385 L .60968 .65307 L p .707 .577 .707 r
F P
0 g
s
.60968 .65307 m .60968 .69013 L .57784 .69091 L p .707 .577 .707 r
F P
0 g
s
.57784 .76899 m .57784 .75046 L .60968 .74969 L p .707 .577 .707 r
F P
0 g
s
.60968 .74969 m .60968 .76821 L .57784 .76899 L p .707 .577 .707 r
F P
0 g
s
.57686 .36963 m .57686 .87152 L .61082 .86354 L p .707 .577 .707 r
F P
0 g
s
.64085 .59711 m .64085 .6527 L .60968 .6508 L p .707 .577 .707 r
F P
0 g
s
.60968 .6508 m .60968 .59521 L .64085 .59711 L p .707 .577 .707 r
F P
0 g
s
.64085 .65497 m .64085 .69203 L .60968 .69013 L p .707 .577 .707 r
F P
0 g
s
.60968 .69013 m .60968 .65307 L .64085 .65497 L p .707 .577 .707 r
F P
0 g
s
.64085 .75159 m .64085 .77011 L .60968 .76821 L p .707 .577 .707 r
F P
0 g
s
.60968 .76821 m .60968 .74969 L .64085 .75159 L p .707 .577 .707 r
F P
0 g
s
.61082 .86354 m .61082 .36165 L .57686 .36963 L p .707 .577 .707 r
F P
0 g
s
.68936 .60796 m .68936 .66354 L .66831 .65709 L p .707 .577 .707 r
F P
0 g
s
.66831 .65709 m .66831 .60151 L .68936 .60796 L p .707 .577 .707 r
F P
0 g
s
.28495 .67019 m .28495 .70725 L .31434 .70387 L p .707 .577 .707 r
F P
0 g
s
.31434 .70387 m .31434 .66681 L .28495 .67019 L p .707 .577 .707 r
F P
0 g
s
.19449 .60682 m .19449 .6624 L .22195 .66679 L p .707 .577 .707 r
F P
0 g
s
.19449 .6624 m .19449 .60682 L .17343 .60036 L p .707 .577 .707 r
F P
0 g
s
.22195 .70612 m .22195 .66907 L .19449 .66468 L p .707 .577 .707 r
F P
0 g
s
.22195 .66907 m .22195 .70612 L .25312 .70802 L p .707 .577 .707 r
F P
0 g
s
.40766 .8685 m .40766 .36661 L .37794 .3575 L p .707 .577 .707 r
F P
0 g
s
.40766 .36661 m .40766 .8685 L .44643 .8747 L p .707 .577 .707 r
F P
0 g
s
.31434 .66681 m .31434 .70387 L .33839 .69822 L p .707 .577 .707 r
F P
0 g
s
.33839 .69822 m .33839 .66116 L .31434 .66681 L p .707 .577 .707 r
F P
0 g
s
.70195 .77032 m .70195 .78884 L .68936 .78096 L p .707 .577 .707 r
F P
0 g
s
.68936 .78096 m .68936 .76243 L .70195 .77032 L p .707 .577 .707 r
F P
0 g
s
.19449 .66468 m .19449 .70173 L .22195 .70612 L p .707 .577 .707 r
F P
0 g
s
.68936 .66582 m .68936 .70288 L .66831 .69642 L p .707 .577 .707 r
F P
0 g
s
.66831 .69642 m .66831 .65937 L .68936 .66582 L p .707 .577 .707 r
F P
0 g
s
.33839 .6033 m .33839 .65889 L .35476 .65152 L p .707 .577 .707 r
F P
0 g
s
.35476 .65152 m .35476 .59594 L .33839 .6033 L p .707 .577 .707 r
F P
0 g
s
.17343 .60036 m .17343 .65594 L .19449 .6624 L p .707 .577 .707 r
F P
0 g
s
.19449 .70173 m .19449 .66468 L .17343 .65822 L p .707 .577 .707 r
F P
0 g
s
.66831 .60151 m .66831 .65709 L .64085 .6527 L p .707 .577 .707 r
F P
0 g
s
.64085 .6527 m .64085 .59711 L .66831 .60151 L p .707 .577 .707 r
F P
0 g
s
.25312 .78611 m .25312 .76758 L .22195 .76568 L p .707 .577 .707 r
F P
0 g
s
.25312 .76758 m .25312 .78611 L .28495 .78533 L p .707 .577 .707 r
F P
0 g
s
.28495 .78533 m .28495 .76681 L .25312 .76758 L p .707 .577 .707 r
F P
0 g
s
.17343 .65594 m .17343 .60036 L .16084 .59248 L p .707 .577 .707 r
F P
0 g
s
.28495 .76681 m .28495 .78533 L .31434 .78195 L p .707 .577 .707 r
F P
0 g
s
.31434 .78195 m .31434 .76343 L .28495 .76681 L p .707 .577 .707 r
F P
0 g
s
.61082 .36165 m .61082 .86354 L .63393 .85314 L p .707 .577 .707 r
F P
0 g
s
.63393 .85314 m .63393 .35125 L .61082 .36165 L p .707 .577 .707 r
F P
0 g
s
.22195 .76568 m .22195 .78421 L .25312 .78611 L p .707 .577 .707 r
F P
0 g
s
.17343 .65822 m .17343 .69528 L .19449 .70173 L p .707 .577 .707 r
F P
0 g
s
.22195 .78421 m .22195 .76568 L .19449 .76129 L p .707 .577 .707 r
F P
0 g
s
.33839 .66116 m .33839 .69822 L .35476 .69085 L p .707 .577 .707 r
F P
0 g
s
.35476 .69085 m .35476 .6538 L .33839 .66116 L p .707 .577 .707 r
F P
0 g
s
.19449 .76129 m .19449 .77982 L .22195 .78421 L p .707 .577 .707 r
F P
0 g
s
.66831 .65937 m .66831 .69642 L .64085 .69203 L p .707 .577 .707 r
F P
0 g
s
.64085 .69203 m .64085 .65497 L .66831 .65937 L p .707 .577 .707 r
F P
0 g
s
.31434 .76343 m .31434 .78195 L .33839 .7763 L p .707 .577 .707 r
F P
0 g
s
.33839 .7763 m .33839 .75778 L .31434 .76343 L p .707 .577 .707 r
F P
0 g
s
.16084 .59248 m .16084 .64806 L .17343 .65594 L p .707 .577 .707 r
F P
0 g
s
.68936 .76243 m .68936 .78096 L .66831 .77451 L p .707 .577 .707 r
F P
0 g
s
.66831 .77451 m .66831 .75598 L .68936 .76243 L p .707 .577 .707 r
F P
0 g
s
.35476 .59594 m .35476 .65152 L .36184 .64315 L p .707 .577 .707 r
F P
0 g
s
.36184 .64315 m .36184 .58757 L .35476 .59594 L p .707 .577 .707 r
F P
0 g
s
.37794 .85939 m .37794 .3575 L .36016 .34637 L p .707 .577 .707 r
F P
0 g
s
.37794 .3575 m .37794 .85939 L .40766 .8685 L p .707 .577 .707 r
F P
0 g
s
.17343 .69528 m .17343 .65822 L .16084 .65034 L p .707 .577 .707 r
F P
0 g
s
.19449 .77982 m .19449 .76129 L .17343 .75484 L p .707 .577 .707 r
F P
0 g
s
.17343 .75484 m .17343 .77336 L .19449 .77982 L p .707 .577 .707 r
F P
0 g
s
.16084 .65034 m .16084 .68739 L .17343 .69528 L p .707 .577 .707 r
F P
0 g
s
.16084 .64806 m .16084 .59248 L .15794 .58394 L p .707 .577 .707 r
F P
0 g
s
.35476 .6538 m .35476 .69085 L .36184 .68249 L p .707 .577 .707 r
F P
0 g
s
.36184 .68249 m .36184 .64543 L .35476 .6538 L p .707 .577 .707 r
F P
0 g
s
.33839 .75778 m .33839 .7763 L .35476 .76894 L p .707 .577 .707 r
F P
0 g
s
.35476 .76894 m .35476 .75041 L .33839 .75778 L p .707 .577 .707 r
F P
0 g
s
.66831 .75598 m .66831 .77451 L .64085 .77011 L p .707 .577 .707 r
F P
0 g
s
.64085 .77011 m .64085 .75159 L .66831 .75598 L p .707 .577 .707 r
F P
0 g
s
.63393 .35125 m .63393 .85314 L .64393 .84133 L p .707 .577 .707 r
F P
0 g
s
.64393 .84133 m .64393 .33944 L .63393 .35125 L p .707 .577 .707 r
F P
0 g
s
.17343 .77336 m .17343 .75484 L .16084 .74695 L p .707 .577 .707 r
F P
0 g
s
.15794 .58394 m .15794 .63952 L .16084 .64806 L p .707 .577 .707 r
F P
0 g
s
.16084 .68739 m .16084 .65034 L .15794 .6418 L p .707 .577 .707 r
F P
0 g
s
.36184 .58757 m .36184 .64315 L .35894 .63461 L p .707 .577 .707 r
F P
0 g
s
.35894 .63461 m .35894 .57903 L .36184 .58757 L p .707 .577 .707 r
F P
0 g
s
.16084 .74695 m .16084 .76548 L .17343 .77336 L p .707 .577 .707 r
F P
0 g
s
.15794 .6418 m .15794 .67885 L .16084 .68739 L p .707 .577 .707 r
F P
0 g
s
.35476 .75041 m .35476 .76894 L .36184 .76057 L p .707 .577 .707 r
F P
0 g
s
.36184 .76057 m .36184 .74204 L .35476 .75041 L p .707 .577 .707 r
F P
0 g
s
.36184 .64543 m .36184 .68249 L .35894 .67394 L p .707 .577 .707 r
F P
0 g
s
.35894 .67394 m .35894 .63689 L .36184 .64543 L p .707 .577 .707 r
F P
0 g
s
.35894 .57903 m .35894 .63461 L .34635 .62673 L p .707 .577 .707 r
F P
0 g
s
.34635 .62673 m .34635 .57114 L .35894 .57903 L p .707 .577 .707 r
F P
0 g
s
.36184 .74204 m .36184 .76057 L .35894 .75203 L p .707 .577 .707 r
F P
0 g
s
.35894 .75203 m .35894 .7335 L .36184 .74204 L p .707 .577 .707 r
F P
0 g
s
.35894 .63689 m .35894 .67394 L .34635 .66606 L p .707 .577 .707 r
F P
0 g
s
.34635 .66606 m .34635 .629 L .35894 .63689 L p .707 .577 .707 r
F P
0 g
s
.36016 .84826 m .36016 .34637 L .35607 .33431 L p .707 .577 .707 r
F P
0 g
s
.36016 .34637 m .36016 .84826 L .37794 .85939 L p .707 .577 .707 r
F P
0 g
s
.15794 .63952 m .15794 .58394 L .16503 .57557 L p .707 .577 .707 r
F P
0 g
s
.16084 .76548 m .16084 .74695 L .15794 .73841 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57557 m .16503 .63115 L .15794 .63952 L p .707 .577 .707 r
F P
0 g
s
.15794 .67885 m .15794 .6418 L .16503 .63343 L p .707 .577 .707 r
F P
0 g
s
.15794 .73841 m .15794 .75694 L .16084 .76548 L p .707 .577 .707 r
F P
0 g
s
.64393 .33944 m .64393 .84133 L .63984 .82927 L p .707 .577 .707 r
F P
0 g
s
.63984 .82927 m .63984 .32738 L .64393 .33944 L p .707 .577 .707 r
F P
0 g
s
.16503 .63343 m .16503 .67049 L .15794 .67885 L p .707 .577 .707 r
F P
0 g
s
.16503 .63115 m .16503 .57557 L .1814 .5682 L p .707 .577 .707 r
F P
0 g
s
.35894 .7335 m .35894 .75203 L .34635 .74415 L p .707 .577 .707 r
F P
0 g
s
.34635 .74415 m .34635 .72562 L .35894 .7335 L p .707 .577 .707 r
F P
0 g
s
.35607 .33431 m .35607 .8362 L .36016 .84826 L p .707 .577 .707 r
F P
0 g
s
.35607 .8362 m .35607 .33431 L .36607 .3225 L p .707 .577 .707 r
F P
0 g
s
.15794 .75694 m .15794 .73841 L .16503 .73004 L p .707 .577 .707 r
F P
0 g
s
.1814 .5682 m .1814 .62379 L .16503 .63115 L p .707 .577 .707 r
F P
0 g
s
.34635 .57114 m .34635 .62673 L .3253 .62027 L p .707 .577 .707 r
F P
0 g
s
.3253 .62027 m .3253 .56469 L .34635 .57114 L p .707 .577 .707 r
F P
0 g
s
.16503 .67049 m .16503 .63343 L .1814 .62606 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .73004 m .16503 .74857 L .15794 .75694 L p .707 .577 .707 r
F P
0 g
s
.1814 .62606 m .1814 .66312 L .16503 .67049 L p .707 .577 .707 r
F P
0 g
s
.1814 .62379 m .1814 .5682 L .20545 .56255 L p .707 .577 .707 r
F P
0 g
s
.34635 .629 m .34635 .66606 L .3253 .65961 L p .707 .577 .707 r
F P
0 g
s
.3253 .65961 m .3253 .62255 L .34635 .629 L p .707 .577 .707 r
F P
0 g
s
.63984 .32738 m .63984 .82927 L .62206 .81814 L p .707 .577 .707 r
F P
0 g
s
.62206 .81814 m .62206 .31625 L .63984 .32738 L p .707 .577 .707 r
F P
0 g
s
.3253 .56469 m .3253 .62027 L .29784 .61588 L p .707 .577 .707 r
F P
0 g
s
.29784 .61588 m .29784 .5603 L .3253 .56469 L p .707 .577 .707 r
F P
0 g
s
.20545 .56255 m .20545 .61814 L .1814 .62379 L p .707 .577 .707 r
F P
0 g
s
.1814 .66312 m .1814 .62606 L .20545 .62041 L p .707 .577 .707 r
F P
0 g
s
.16503 .74857 m .16503 .73004 L .1814 .72268 L p .707 .577 .707 r
F P
0 g
s
.20545 .61814 m .20545 .56255 L .23483 .55917 L p .707 .577 .707 r
F P
0 g
s
.1814 .72268 m .1814 .7412 L .16503 .74857 L p .707 .577 .707 r
F P
0 g
s
.36607 .82439 m .36607 .3225 L .38918 .3121 L p .707 .577 .707 r
F P
0 g
s
.36607 .3225 m .36607 .82439 L .35607 .8362 L p .707 .577 .707 r
F P
0 g
s
.20545 .62041 m .20545 .65747 L .1814 .66312 L p .707 .577 .707 r
F P
0 g
s
.29784 .5603 m .29784 .61588 L .26667 .61398 L p .707 .577 .707 r
F P
0 g
s
.26667 .61398 m .26667 .5584 L .29784 .5603 L p .707 .577 .707 r
F P
0 g
s
.3253 .62255 m .3253 .65961 L .29784 .65521 L p .707 .577 .707 r
F P
0 g
s
.29784 .65521 m .29784 .61816 L .3253 .62255 L p .707 .577 .707 r
F P
0 g
s
.23483 .61476 m .23483 .55917 L .26667 .5584 L p .707 .577 .707 r
F P
0 g
s
.23483 .55917 m .23483 .61476 L .20545 .61814 L p .707 .577 .707 r
F P
0 g
s
.34635 .72562 m .34635 .74415 L .3253 .73769 L p .707 .577 .707 r
F P
0 g
s
.3253 .73769 m .3253 .71916 L .34635 .72562 L p .707 .577 .707 r
F P
0 g
s
.26667 .5584 m .26667 .61398 L .23483 .61476 L p .707 .577 .707 r
F P
0 g
s
.20545 .65747 m .20545 .62041 L .23483 .61704 L p .707 .577 .707 r
F P
0 g
s
.73333 .61347 m .73333 .55789 L .70216 .55599 L p .707 .577 .707 r
F P
0 g
s
.73333 .55789 m .73333 .61347 L .76517 .61269 L p .707 .577 .707 r
F P
0 g
s
.76517 .61269 m .76517 .55711 L .73333 .55789 L p .707 .577 .707 r
F P
0 g
s
.76517 .55711 m .76517 .61269 L .79455 .60931 L p .707 .577 .707 r
F P
0 g
s
.79455 .60931 m .79455 .55373 L .76517 .55711 L p .707 .577 .707 r
F P
0 g
s
.1814 .7412 m .1814 .72268 L .20545 .71703 L p .707 .577 .707 r
F P
0 g
s
.70216 .61157 m .70216 .55599 L .6747 .55159 L p .707 .577 .707 r
F P
0 g
s
.70216 .55599 m .70216 .61157 L .73333 .61347 L p .707 .577 .707 r
F P
0 g
s
.29784 .61816 m .29784 .65521 L .26667 .65331 L p .707 .577 .707 r
F P
0 g
s
.26667 .65331 m .26667 .61626 L .29784 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61704 m .23483 .65409 L .20545 .65747 L p .707 .577 .707 r
F P
0 g
s
.20545 .71703 m .20545 .73555 L .1814 .7412 L p .707 .577 .707 r
F P
0 g
s
.23483 .65409 m .23483 .61704 L .26667 .61626 L p .707 .577 .707 r
F P
0 g
s
.62206 .31625 m .62206 .81814 L .59233 .80903 L p .707 .577 .707 r
F P
0 g
s
.59233 .80903 m .59233 .30714 L .62206 .31625 L p .707 .577 .707 r
F P
0 g
s
.26667 .61626 m .26667 .65331 L .23483 .65409 L p .707 .577 .707 r
F P
0 g
s
.79455 .55373 m .79455 .60931 L .8186 .60366 L p .707 .577 .707 r
F P
0 g
s
.8186 .60366 m .8186 .54808 L .79455 .55373 L p .707 .577 .707 r
F P
0 g
s
.73333 .6528 m .73333 .61575 L .70216 .61385 L p .707 .577 .707 r
F P
0 g
s
.73333 .61575 m .73333 .6528 L .76517 .65202 L p .707 .577 .707 r
F P
0 g
s
.76517 .65202 m .76517 .61497 L .73333 .61575 L p .707 .577 .707 r
F P
0 g
s
.3253 .71916 m .3253 .73769 L .29784 .7333 L p .707 .577 .707 r
F P
0 g
s
.29784 .7333 m .29784 .71477 L .3253 .71916 L p .707 .577 .707 r
F P
0 g
s
.76517 .61497 m .76517 .65202 L .79455 .64864 L p .707 .577 .707 r
F P
0 g
s
.79455 .64864 m .79455 .61159 L .76517 .61497 L p .707 .577 .707 r
F P
0 g
s
.6747 .55159 m .6747 .60718 L .70216 .61157 L p .707 .577 .707 r
F P
0 g
s
.6747 .60718 m .6747 .55159 L .65365 .54514 L p .707 .577 .707 r
F P
0 g
s
.70216 .6509 m .70216 .61385 L .6747 .60945 L p .707 .577 .707 r
F P
0 g
s
.70216 .61385 m .70216 .6509 L .73333 .6528 L p .707 .577 .707 r
F P
0 g
s
.20545 .73555 m .20545 .71703 L .23483 .71365 L p .707 .577 .707 r
F P
0 g
s
.38918 .3121 m .38918 .81399 L .36607 .82439 L p .707 .577 .707 r
F P
0 g
s
.38918 .81399 m .38918 .3121 L .42314 .30413 L p .707 .577 .707 r
F P
0 g
s
.79455 .61159 m .79455 .64864 L .8186 .643 L p .707 .577 .707 r
F P
0 g
s
.8186 .643 m .8186 .60594 L .79455 .61159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71365 m .23483 .73218 L .20545 .73555 L p .707 .577 .707 r
F P
0 g
s
.6747 .60945 m .6747 .64651 L .70216 .6509 L p .707 .577 .707 r
F P
0 g
s
.29784 .71477 m .29784 .7333 L .26667 .7314 L p .707 .577 .707 r
F P
0 g
s
.26667 .7314 m .26667 .71287 L .29784 .71477 L p .707 .577 .707 r
F P
0 g
s
.8186 .54808 m .8186 .60366 L .83497 .59629 L p .707 .577 .707 r
F P
0 g
s
.83497 .59629 m .83497 .54071 L .8186 .54808 L p .707 .577 .707 r
F P
0 g
s
.65365 .54514 m .65365 .60072 L .6747 .60718 L p .707 .577 .707 r
F P
0 g
s
.23483 .73218 m .23483 .71365 L .26667 .71287 L p .707 .577 .707 r
F P
0 g
s
.6747 .64651 m .6747 .60945 L .65365 .603 L p .707 .577 .707 r
F P
0 g
s
.26667 .71287 m .26667 .7314 L .23483 .73218 L p .707 .577 .707 r
F P
0 g
s
.73333 .73089 m .73333 .71236 L .70216 .71046 L p .707 .577 .707 r
F P
0 g
s
.73333 .71236 m .73333 .73089 L .76517 .73011 L p .707 .577 .707 r
F P
0 g
s
.76517 .73011 m .76517 .71158 L .73333 .71236 L p .707 .577 .707 r
F P
0 g
s
.59233 .30714 m .59233 .80903 L .55357 .80283 L p .707 .577 .707 r
F P
0 g
s
.55357 .80283 m .55357 .30094 L .59233 .30714 L p .707 .577 .707 r
F P
0 g
s
.65365 .60072 m .65365 .54514 L .64105 .53725 L p .707 .577 .707 r
F P
0 g
s
.76517 .71158 m .76517 .73011 L .79455 .72673 L p .707 .577 .707 r
F P
0 g
s
.79455 .72673 m .79455 .7082 L .76517 .71158 L p .707 .577 .707 r
F P
0 g
s
.70216 .71046 m .70216 .72899 L .73333 .73089 L p .707 .577 .707 r
F P
0 g
s
.65365 .603 m .65365 .64005 L .6747 .64651 L p .707 .577 .707 r
F P
0 g
s
.70216 .72899 m .70216 .71046 L .6747 .70607 L p .707 .577 .707 r
F P
0 g
s
.8186 .60594 m .8186 .643 L .83497 .63563 L p .707 .577 .707 r
F P
0 g
s
.83497 .63563 m .83497 .59857 L .8186 .60594 L p .707 .577 .707 r
F P
0 g
s
.6747 .70607 m .6747 .72459 L .70216 .72899 L p .707 .577 .707 r
F P
0 g
s
.42314 .80602 m .42314 .30413 L .46462 .29936 L p .707 .577 .707 r
F P
0 g
s
.42314 .30413 m .42314 .80602 L .38918 .81399 L p .707 .577 .707 r
F P
0 g
s
.79455 .7082 m .79455 .72673 L .8186 .72108 L p .707 .577 .707 r
F P
0 g
s
.8186 .72108 m .8186 .70255 L .79455 .7082 L p .707 .577 .707 r
F P
0 g
s
.64105 .53725 m .64105 .59284 L .65365 .60072 L p .707 .577 .707 r
F P
0 g
s
.83497 .54071 m .83497 .59629 L .84205 .58793 L p .707 .577 .707 r
F P
0 g
s
.84205 .58793 m .84205 .53235 L .83497 .54071 L p .707 .577 .707 r
F P
0 g
s
.65365 .64005 m .65365 .603 L .64105 .59512 L p .707 .577 .707 r
F P
0 g
s
.6747 .72459 m .6747 .70607 L .65365 .69961 L p .707 .577 .707 r
F P
0 g
s
.55357 .30094 m .55357 .80283 L .50956 .80015 L p .707 .577 .707 r
F P
0 g
s
.50956 .80015 m .50956 .29826 L .55357 .30094 L p .707 .577 .707 r
F P
0 g
s
.65365 .69961 m .65365 .71814 L .6747 .72459 L p .707 .577 .707 r
F P
0 g
s
.46462 .80125 m .46462 .29936 L .50956 .29826 L p .707 .577 .707 r
F P
0 g
s
.46462 .29936 m .46462 .80125 L .42314 .80602 L p .707 .577 .707 r
F P
0 g
s
.64105 .59512 m .64105 .63217 L .65365 .64005 L p .707 .577 .707 r
F P
0 g
s
.64105 .59284 m .64105 .53725 L .63816 .52871 L p .707 .577 .707 r
F P
0 g
s
.50956 .29826 m .50956 .80015 L .46462 .80125 L p .707 .577 .707 r
F P
0 g
s
.83497 .59857 m .83497 .63563 L .84205 .62726 L p .707 .577 .707 r
F P
0 g
s
.84205 .62726 m .84205 .59021 L .83497 .59857 L p .707 .577 .707 r
F P
0 g
s
.8186 .70255 m .8186 .72108 L .83497 .71371 L p .707 .577 .707 r
F P
0 g
s
.83497 .71371 m .83497 .69519 L .8186 .70255 L p .707 .577 .707 r
F P
0 g
s
.65365 .71814 m .65365 .69961 L .64105 .69173 L p .707 .577 .707 r
F P
0 g
s
.63816 .52871 m .63816 .58429 L .64105 .59284 L p .707 .577 .707 r
F P
0 g
s
.64105 .63217 m .64105 .59512 L .63816 .58657 L p .707 .577 .707 r
F P
0 g
s
.84205 .53235 m .84205 .58793 L .83916 .57939 L p .707 .577 .707 r
F P
0 g
s
.83916 .57939 m .83916 .52381 L .84205 .53235 L p .707 .577 .707 r
F P
0 g
s
.64105 .69173 m .64105 .71026 L .65365 .71814 L p .707 .577 .707 r
F P
0 g
s
.63816 .58657 m .63816 .62363 L .64105 .63217 L p .707 .577 .707 r
F P
0 g
s
.83497 .69519 m .83497 .71371 L .84206 .70535 L p .707 .577 .707 r
F P
0 g
s
.84206 .70535 m .84206 .68682 L .83497 .69519 L p .707 .577 .707 r
F P
0 g
s
.63816 .58429 m .63816 .52871 L .64524 .52035 L p .707 .577 .707 r
F P
0 g
s
.84205 .59021 m .84205 .62726 L .83916 .61872 L p .707 .577 .707 r
F P
0 g
s
.83916 .61872 m .83916 .58167 L .84205 .59021 L p .707 .577 .707 r
F P
0 g
s
.64105 .71026 m .64105 .69173 L .63816 .68319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .52035 m .64524 .57593 L .63816 .58429 L p .707 .577 .707 r
F P
0 g
s
.63816 .62363 m .63816 .58657 L .64524 .57821 L p .707 .577 .707 r
F P
0 g
s
.63816 .68319 m .63816 .70171 L .64105 .71026 L p .707 .577 .707 r
F P
0 g
s
.83916 .52381 m .83916 .57939 L .82657 .5715 L p .707 .577 .707 r
F P
0 g
s
.82657 .5715 m .82657 .51592 L .83916 .52381 L p .707 .577 .707 r
F P
0 g
s
.64524 .57821 m .64524 .61526 L .63816 .62363 L p .707 .577 .707 r
F P
0 g
s
.39032 .57665 m .39032 .52107 L .35915 .51917 L p .707 .577 .707 r
F P
0 g
s
.39032 .52107 m .39032 .57665 L .42216 .57588 L p .707 .577 .707 r
F P
0 g
s
.42216 .57588 m .42216 .52029 L .39032 .52107 L p .707 .577 .707 r
F P
0 g
s
.84206 .68682 m .84206 .70535 L .83916 .69681 L p .707 .577 .707 r
F P
0 g
s
.83916 .69681 m .83916 .67828 L .84206 .68682 L p .707 .577 .707 r
F P
0 g
s
.64524 .57593 m .64524 .52035 L .66161 .51298 L p .707 .577 .707 r
F P
0 g
s
.42216 .52029 m .42216 .57588 L .45154 .5725 L p .707 .577 .707 r
F P
0 g
s
.45154 .5725 m .45154 .51691 L .42216 .52029 L p .707 .577 .707 r
F P
0 g
s
.83916 .58167 m .83916 .61872 L .82657 .61084 L p .707 .577 .707 r
F P
0 g
s
.82657 .61084 m .82657 .57378 L .83916 .58167 L p .707 .577 .707 r
F P
0 g
s
.35915 .57475 m .35915 .51917 L .33169 .51478 L p .707 .577 .707 r
F P
0 g
s
.35915 .51917 m .35915 .57475 L .39032 .57665 L p .707 .577 .707 r
F P
0 g
s
.45154 .51691 m .45154 .5725 L .47559 .56685 L p .707 .577 .707 r
F P
0 g
s
.47559 .56685 m .47559 .51126 L .45154 .51691 L p .707 .577 .707 r
F P
0 g
s
.63816 .70171 m .63816 .68319 L .64524 .67482 L p .707 .577 .707 r
F P
0 g
s
.39032 .61599 m .39032 .57893 L .35915 .57703 L p .707 .577 .707 r
F P
0 g
s
.39032 .57893 m .39032 .61599 L .42216 .61521 L p .707 .577 .707 r
F P
0 g
s
.42216 .61521 m .42216 .57815 L .39032 .57893 L p .707 .577 .707 r
F P
0 g
s
.66161 .51298 m .66161 .56856 L .64524 .57593 L p .707 .577 .707 r
F P
0 g
s
.82657 .51592 m .82657 .5715 L .80551 .56505 L p .707 .577 .707 r
F P
0 g
s
.80551 .56505 m .80551 .50947 L .82657 .51592 L p .707 .577 .707 r
F P
0 g
s
.64524 .61526 m .64524 .57821 L .66161 .57084 L p .707 .577 .707 r
F P
0 g
s
.42216 .57815 m .42216 .61521 L .45154 .61183 L p .707 .577 .707 r
F P
0 g
s
.45154 .61183 m .45154 .57477 L .42216 .57815 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .67482 m .64524 .69335 L .63816 .70171 L p .707 .577 .707 r
F P
0 g
s
.33169 .51478 m .33169 .57036 L .35915 .57475 L p .707 .577 .707 r
F P
0 g
s
.33169 .57036 m .33169 .51478 L .31064 .50832 L p .707 .577 .707 r
F P
0 g
s
.35915 .61408 m .35915 .57703 L .33169 .57264 L p .707 .577 .707 r
F P
0 g
s
.35915 .57703 m .35915 .61408 L .39032 .61599 L p .707 .577 .707 r
F P
0 g
s
.66161 .57084 m .66161 .6079 L .64524 .61526 L p .707 .577 .707 r
F P
0 g
s
.66161 .56856 m .66161 .51298 L .68566 .50733 L p .707 .577 .707 r
F P
0 g
s
.45154 .57477 m .45154 .61183 L .47559 .60618 L p .707 .577 .707 r
F P
0 g
s
.47559 .60618 m .47559 .56912 L .45154 .57477 L p .707 .577 .707 r
F P
0 g
s
.83916 .67828 m .83916 .69681 L .82657 .68892 L p .707 .577 .707 r
F P
0 g
s
.82657 .68892 m .82657 .6704 L .83916 .67828 L p .707 .577 .707 r
F P
0 g
s
.33169 .57264 m .33169 .60969 L .35915 .61408 L p .707 .577 .707 r
F P
0 g
s
.82657 .57378 m .82657 .61084 L .80551 .60438 L p .707 .577 .707 r
F P
0 g
s
.80551 .60438 m .80551 .56733 L .82657 .57378 L p .707 .577 .707 r
F P
0 g
s
.47559 .51126 m .47559 .56685 L .49196 .55948 L p .707 .577 .707 r
F P
0 g
s
.49196 .55948 m .49196 .5039 L .47559 .51126 L p .707 .577 .707 r
F P
0 g
s
.31064 .50832 m .31064 .56391 L .33169 .57036 L p .707 .577 .707 r
F P
0 g
s
.33169 .60969 m .33169 .57264 L .31064 .56618 L p .707 .577 .707 r
F P
0 g
s
.80551 .50947 m .80551 .56505 L .77805 .56066 L p .707 .577 .707 r
F P
0 g
s
.77805 .56066 m .77805 .50507 L .80551 .50947 L p .707 .577 .707 r
F P
0 g
s
.39032 .69407 m .39032 .67554 L .35915 .67364 L p .707 .577 .707 r
F P
0 g
s
.39032 .67554 m .39032 .69407 L .42216 .69329 L p .707 .577 .707 r
F P
0 g
s
.42216 .69329 m .42216 .67477 L .39032 .67554 L p .707 .577 .707 r
F P
0 g
s
.68566 .50733 m .68566 .56291 L .66161 .56856 L p .707 .577 .707 r
F P
0 g
s
.66161 .6079 m .66161 .57084 L .68566 .56519 L p .707 .577 .707 r
F P
0 g
s
.64524 .69335 m .64524 .67482 L .66161 .66745 L p .707 .577 .707 r
F P
0 g
s
.31064 .56391 m .31064 .50832 L .29804 .50044 L p .707 .577 .707 r
F P
0 g
s
.42216 .67477 m .42216 .69329 L .45154 .68992 L p .707 .577 .707 r
F P
0 g
s
.45154 .68992 m .45154 .67139 L .42216 .67477 L p .707 .577 .707 r
F P
0 g
s
.35915 .67364 m .35915 .69217 L .39032 .69407 L p .707 .577 .707 r
F P
0 g
s
.31064 .56618 m .31064 .60324 L .33169 .60969 L p .707 .577 .707 r
F P
0 g
s
.68566 .56291 m .68566 .50733 L .71504 .50395 L p .707 .577 .707 r
F P
0 g
s
.35915 .69217 m .35915 .67364 L .33169 .66925 L p .707 .577 .707 r
F P
0 g
s
.66161 .66745 m .66161 .68598 L .64524 .69335 L p .707 .577 .707 r
F P
0 g
s
.47559 .56912 m .47559 .60618 L .49196 .59881 L p .707 .577 .707 r
F P
0 g
s
.49196 .59881 m .49196 .56176 L .47559 .56912 L p .707 .577 .707 r
F P
0 g
s
.33169 .66925 m .33169 .68778 L .35915 .69217 L p .707 .577 .707 r
F P
0 g
s
.68566 .56519 m .68566 .60225 L .66161 .6079 L p .707 .577 .707 r
F P
0 g
s
.77805 .50507 m .77805 .56066 L .74688 .55876 L p .707 .577 .707 r
F P
0 g
s
.74688 .55876 m .74688 .50317 L .77805 .50507 L p .707 .577 .707 r
F P
0 g
s
.80551 .56733 m .80551 .60438 L .77805 .59999 L p .707 .577 .707 r
F P
0 g
s
.77805 .59999 m .77805 .56294 L .80551 .56733 L p .707 .577 .707 r
F P
0 g
s
.45154 .67139 m .45154 .68992 L .47559 .68427 L p .707 .577 .707 r
F P
0 g
s
.47559 .68427 m .47559 .66574 L .45154 .67139 L p .707 .577 .707 r
F P
0 g
s
.29804 .50044 m .29804 .55602 L .31064 .56391 L p .707 .577 .707 r
F P
0 g
s
.71504 .55953 m .71504 .50395 L .74688 .50317 L p .707 .577 .707 r
F P
0 g
s
.71504 .50395 m .71504 .55953 L .68566 .56291 L p .707 .577 .707 r
F P
0 g
s
.82657 .6704 m .82657 .68892 L .80551 .68247 L p .707 .577 .707 r
F P
0 g
s
.80551 .68247 m .80551 .66394 L .82657 .6704 L p .707 .577 .707 r
F P
0 g
s
.49196 .5039 m .49196 .55948 L .49904 .55111 L p .707 .577 .707 r
F P
0 g
s
.49904 .55111 m .49904 .49553 L .49196 .5039 L p .707 .577 .707 r
F P
0 g
s
.31064 .60324 m .31064 .56618 L .29804 .5583 L p .707 .577 .707 r
F P
0 g
s
.74688 .50317 m .74688 .55876 L .71504 .55953 L p .707 .577 .707 r
F P
0 g
s
.68566 .60225 m .68566 .56519 L .71504 .56181 L p .707 .577 .707 r
F P
0 g
s
.33169 .68778 m .33169 .66925 L .31064 .6628 L p .707 .577 .707 r
F P
0 g
s
.31064 .6628 m .31064 .68132 L .33169 .68778 L p .707 .577 .707 r
F P
0 g
s
.66161 .68598 m .66161 .66745 L .68566 .6618 L p .707 .577 .707 r
F P
0 g
s
.29804 .5583 m .29804 .59535 L .31064 .60324 L p .707 .577 .707 r
F P
0 g
s
.77805 .56294 m .77805 .59999 L .74688 .59809 L p .707 .577 .707 r
F P
0 g
s
.74688 .59809 m .74688 .56103 L .77805 .56294 L p .707 .577 .707 r
F P
0 g
s
.29804 .55602 m .29804 .50044 L .29515 .4919 L p .707 .577 .707 r
F P
0 g
s
.71504 .56181 m .71504 .59887 L .68566 .60225 L p .707 .577 .707 r
F P
0 g
s
.68566 .6618 m .68566 .68033 L .66161 .68598 L p .707 .577 .707 r
F P
0 g
s
.71504 .59887 m .71504 .56181 L .74688 .56103 L p .707 .577 .707 r
F P
0 g
s
.49196 .56176 m .49196 .59881 L .49904 .59045 L p .707 .577 .707 r
F P
0 g
s
.49904 .59045 m .49904 .55339 L .49196 .56176 L p .707 .577 .707 r
F P
0 g
s
.47559 .66574 m .47559 .68427 L .49196 .6769 L p .707 .577 .707 r
F P
0 g
s
.49196 .6769 m .49196 .65837 L .47559 .66574 L p .707 .577 .707 r
F P
0 g
s
.74688 .56103 m .74688 .59809 L .71504 .59887 L p .707 .577 .707 r
F P
0 g
s
.80551 .66394 m .80551 .68247 L .77805 .67808 L p .707 .577 .707 r
F P
0 g
s
.77805 .67808 m .77805 .65955 L .80551 .66394 L p .707 .577 .707 r
F P
0 g
s
.31064 .68132 m .31064 .6628 L .29804 .65491 L p .707 .577 .707 r
F P
0 g
s
.29515 .4919 m .29515 .54748 L .29804 .55602 L p .707 .577 .707 r
F P
0 g
s
.29804 .59535 m .29804 .5583 L .29515 .54976 L p .707 .577 .707 r
F P
0 g
s
.49904 .49553 m .49904 .55111 L .49615 .54257 L p .707 .577 .707 r
F P
0 g
s
.49615 .54257 m .49615 .48699 L .49904 .49553 L p .707 .577 .707 r
F P
0 g
s
.68566 .68033 m .68566 .6618 L .71504 .65843 L p .707 .577 .707 r
F P
0 g
s
.29804 .65491 m .29804 .67344 L .31064 .68132 L p .707 .577 .707 r
F P
0 g
s
.71504 .65843 m .71504 .67695 L .68566 .68033 L p .707 .577 .707 r
F P
0 g
s
.77805 .65955 m .77805 .67808 L .74688 .67618 L p .707 .577 .707 r
F P
0 g
s
.74688 .67618 m .74688 .65765 L .77805 .65955 L p .707 .577 .707 r
F P
0 g
s
.29515 .54976 m .29515 .58681 L .29804 .59535 L p .707 .577 .707 r
F P
0 g
s
.71504 .67695 m .71504 .65843 L .74688 .65765 L p .707 .577 .707 r
F P
0 g
s
.49196 .65837 m .49196 .6769 L .49904 .66853 L p .707 .577 .707 r
F P
0 g
s
.49904 .66853 m .49904 .65001 L .49196 .65837 L p .707 .577 .707 r
F P
0 g
s
.29515 .54748 m .29515 .4919 L .30223 .48353 L p .707 .577 .707 r
F P
0 g
s
.74688 .65765 m .74688 .67618 L .71504 .67695 L p .707 .577 .707 r
F P
0 g
s
.49904 .55339 m .49904 .59045 L .49615 .58191 L p .707 .577 .707 r
F P
0 g
s
.49615 .58191 m .49615 .54485 L .49904 .55339 L p .707 .577 .707 r
F P
0 g
s
.29804 .67344 m .29804 .65491 L .29515 .64637 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48353 m .30223 .53911 L .29515 .54748 L p .707 .577 .707 r
F P
0 g
s
.29515 .58681 m .29515 .54976 L .30223 .54139 L p .707 .577 .707 r
F P
0 g
s
.29515 .64637 m .29515 .6649 L .29804 .67344 L p .707 .577 .707 r
F P
0 g
s
.49615 .48699 m .49615 .54257 L .48356 .53469 L p .707 .577 .707 r
F P
0 g
s
.48356 .53469 m .48356 .47911 L .49615 .48699 L p .707 .577 .707 r
F P
0 g
s
.30223 .54139 m .30223 .57845 L .29515 .58681 L p .707 .577 .707 r
F P
0 g
s
.49904 .65001 m .49904 .66853 L .49615 .65999 L p .707 .577 .707 r
F P
0 g
s
.49615 .65999 m .49615 .64146 L .49904 .65001 L p .707 .577 .707 r
F P
0 g
s
.30223 .53911 m .30223 .48353 L .3186 .47616 L p .707 .577 .707 r
F P
0 g
s
.49615 .54485 m .49615 .58191 L .48356 .57402 L p .707 .577 .707 r
F P
0 g
s
.48356 .57402 m .48356 .53697 L .49615 .54485 L p .707 .577 .707 r
F P
0 g
s
.29515 .6649 m .29515 .64637 L .30223 .63801 L p .707 .577 .707 r
F P
0 g
s
.3186 .47616 m .3186 .53175 L .30223 .53911 L p .707 .577 .707 r
F P
0 g
s
.48356 .47911 m .48356 .53469 L .4625 .52823 L p .707 .577 .707 r
F P
0 g
s
.4625 .52823 m .4625 .47265 L .48356 .47911 L p .707 .577 .707 r
F P
0 g
s
.30223 .57845 m .30223 .54139 L .3186 .53402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .63801 m .30223 .65653 L .29515 .6649 L p .707 .577 .707 r
F P
0 g
s
.3186 .53402 m .3186 .57108 L .30223 .57845 L p .707 .577 .707 r
F P
0 g
s
.3186 .53175 m .3186 .47616 L .34265 .47051 L p .707 .577 .707 r
F P
0 g
s
.49615 .64146 m .49615 .65999 L .48356 .65211 L p .707 .577 .707 r
F P
0 g
s
.48356 .65211 m .48356 .63358 L .49615 .64146 L p .707 .577 .707 r
F P
0 g
s
.48356 .53697 m .48356 .57402 L .4625 .56757 L p .707 .577 .707 r
F P
0 g
s
.4625 .56757 m .4625 .53051 L .48356 .53697 L p .707 .577 .707 r
F P
0 g
s
.4625 .47265 m .4625 .52823 L .43504 .52384 L p .707 .577 .707 r
F P
0 g
s
.43504 .52384 m .43504 .46826 L .4625 .47265 L p .707 .577 .707 r
F P
0 g
s
.34265 .47051 m .34265 .5261 L .3186 .53175 L p .707 .577 .707 r
F P
0 g
s
.3186 .57108 m .3186 .53402 L .34265 .52838 L p .707 .577 .707 r
F P
0 g
s
.30223 .65653 m .30223 .63801 L .3186 .63064 L p .707 .577 .707 r
F P
0 g
s
.34265 .5261 m .34265 .47051 L .37203 .46714 L p .707 .577 .707 r
F P
0 g
s
.3186 .63064 m .3186 .64917 L .30223 .65653 L p .707 .577 .707 r
F P
0 g
s
.34265 .52838 m .34265 .56543 L .3186 .57108 L p .707 .577 .707 r
F P
0 g
s
.43504 .46826 m .43504 .52384 L .40387 .52194 L p .707 .577 .707 r
F P
0 g
s
.40387 .52194 m .40387 .46636 L .43504 .46826 L p .707 .577 .707 r
F P
0 g
s
.4625 .53051 m .4625 .56757 L .43504 .56317 L p .707 .577 .707 r
F P
0 g
s
.43504 .56317 m .43504 .52612 L .4625 .53051 L p .707 .577 .707 r
F P
0 g
s
.37203 .52272 m .37203 .46714 L .40387 .46636 L p .707 .577 .707 r
F P
0 g
s
.37203 .46714 m .37203 .52272 L .34265 .5261 L p .707 .577 .707 r
F P
0 g
s
.48356 .63358 m .48356 .65211 L .4625 .64565 L p .707 .577 .707 r
F P
0 g
s
.4625 .64565 m .4625 .62713 L .48356 .63358 L p .707 .577 .707 r
F P
0 g
s
.40387 .46636 m .40387 .52194 L .37203 .52272 L p .707 .577 .707 r
F P
0 g
s
.34265 .56543 m .34265 .52838 L .37203 .525 L p .707 .577 .707 r
F P
0 g
s
.3186 .64917 m .3186 .63064 L .34265 .62499 L p .707 .577 .707 r
F P
0 g
s
.43504 .52612 m .43504 .56317 L .40387 .56127 L p .707 .577 .707 r
F P
0 g
s
.40387 .56127 m .40387 .52422 L .43504 .52612 L p .707 .577 .707 r
F P
0 g
s
.37203 .525 m .37203 .56205 L .34265 .56543 L p .707 .577 .707 r
F P
0 g
s
.34265 .62499 m .34265 .64352 L .3186 .64917 L p .707 .577 .707 r
F P
0 g
s
.37203 .56205 m .37203 .525 L .40387 .52422 L p .707 .577 .707 r
F P
0 g
s
.40387 .52422 m .40387 .56127 L .37203 .56205 L p .707 .577 .707 r
F P
0 g
s
.4625 .62713 m .4625 .64565 L .43504 .64126 L p .707 .577 .707 r
F P
0 g
s
.43504 .64126 m .43504 .62273 L .4625 .62713 L p .707 .577 .707 r
F P
0 g
s
.34265 .64352 m .34265 .62499 L .37203 .62161 L p .707 .577 .707 r
F P
0 g
s
.37203 .62161 m .37203 .64014 L .34265 .64352 L p .707 .577 .707 r
F P
0 g
s
.43504 .62273 m .43504 .64126 L .40387 .63936 L p .707 .577 .707 r
F P
0 g
s
.40387 .63936 m .40387 .62083 L .43504 .62273 L p .707 .577 .707 r
F P
0 g
s
.37203 .64014 m .37203 .62161 L .40387 .62083 L p .707 .577 .707 r
F P
0 g
s
.40387 .62083 m .40387 .63936 L .37203 .64014 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001/Ool30009FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03
001JEUYF00=JER40009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005=oo`03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo
2@000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool003Uoo`h000AJEP03001JEUYF009JEP@00003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03
FUH70007FUH50004FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPL0
00AJEP03001JEUYF00IJEP03001JEUYF009JEPd000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000<0
00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH60000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF200000=JEP00FUH00UYF
0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH90004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH;00000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEP0000T000AJEP@0009JEPh000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH400000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH0
0eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00;Goo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008FUH50004FUH00`00FUIJEP05FUH50004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH80004FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUH0000500000eYF001JEP02FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20003FUH>0004FUH40005FUH00`00FUIJEP02FUH70003FUH30003FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EPP000AJEP03001JEUYF00=JEPh0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUHK0003FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EQl000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH000090004FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF01800003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF00000eYF1`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF30000eYF00<005YF
FUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
0000;Goo000/Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF00000`0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF0000
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH50006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH40000
0eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2@000eYF00@005YF001JEP8000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP03
001JEP0001P003moo`00;7oo00<005YF000015YF00<005YFFUH00eYF4`0015YF100000AJEP000000
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001`0015YF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<005YF00000`0000=JEP000000100015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPP00003FUH005YF009JEQX003aoo`00;7oo00<005YF00000eYF2@0015YF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEPX00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00001`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;7oo00@005YF001JEP8000AJEPd000AJEP@0
009JEPP000=JEP03001JEP00008000=JEP<0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`06001JEP00001JEP001EYF00@0
05YFFUIJEQX000=JEP03001JEUYF009JEPD00004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000b
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH00eYF2@000eYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`8000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJ
EP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04001JEUYFFUH2000J
Ool40003FUH01000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPD000AJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000NOol40003
FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000L000AJEPD000EJEP03001JEUYF009J
EPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Woo00<005YFFUH0
0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEP00018000MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00AJEP04001JEUYFFUH2000SOol4000]Ool003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000020003FUH01000FUIJEUYF
0P008Goo0P0000AJEP00000002eoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF00000`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEP0000P000=JEP8001ioo`<000=JEP<002eoo`00>goo200015YF00<005YFFUH0
1eYF00<005YFFUH00UYF1@002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF009JEP@0009JEP03001JEUYF008001Yoo`@00003FUH005YF00=JEP03001JEP00
02eoo`00@goo4`003goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEP0000L001Eoo`D000EJEP03001JEUYF009JEP8002ioo`00?goo4@005Goo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uoo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000`Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP04001JEUYFFUH4000dOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF1@0015YF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH0000J000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000Uoo`P000AJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`03001JEP0000AJEP04001JEUYFFUH8000I
Ool60004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEP@005]oo`00;7oo00<005YF00000eYF1@009goo0`0000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H005moo`00
;7oo00@005YF001JEP8002moo`80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`@003Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008006=oo`00;7oo0P000UYF0`00;goo10000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool20003
FUH00`00FUH00002000YOol30002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00005FUH00`00FUH00002001KOol002aoo`8000=JEP03001JEUYF009JEPD0021o
o`@00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8
000COol50005FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF0P00F7oo000^Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEP00001F
Ool0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000100000=JEP00FUH015YF00D005YFFUIJEP0005Eoo`00<goo0`0000=JEP00FUH01UYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000AJEP05001JEUYFFUH0001EOol0
03Ioo`D000AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEP0000<000Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001JEP02FUH2
001DOol003]oo`P000AJEPD000EJEP03001JEUYF009JEPD000Yoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2001DOol004=ooa<000moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000<Ool200000eYF0000001DOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;Ool2000015YF0000
0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
0`000eYF0`00E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000017oo100000=JEP00FUH00eYF00<005YF0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH01eYF5@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010001EYF00<005YFFUH00UYF0P00EGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00@005YFFUIJEPH000UJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEUYFFUH2001F
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH01000FUH00000F7oo001UOol01000FUIJEP001EYF0`000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEPD005Yoo`00IGoo00@005YFFUH000=JEP8000EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001J
EP0000H005moo`00IGoo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0001U
Ool006Eoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo06Aoo`00
IGoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo001UOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`1TOol006Eoo`8000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Io
o`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00Igoo001WOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Uoo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2001ZOol006]o
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEP00001/Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00LGoo1@0025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@00LWoo001fOol60002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001gOol007aoo`T000IJEP03001JEUYF00YJEP03001J
EUYF00H007aoo`00QGoo5P00PWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72231 m .59613 .66673 L .56496 .66483 L p .707 .577 .707 r
F P
0 g
s
.59613 .66673 m .59613 .72231 L .62796 .72153 L p .707 .577 .707 r
F P
0 g
s
.62796 .72153 m .62796 .66595 L .59613 .66673 L p .707 .577 .707 r
F P
0 g
s
.62796 .66595 m .62796 .72153 L .65734 .71815 L p .707 .577 .707 r
F P
0 g
s
.65734 .71815 m .65734 .66257 L .62796 .66595 L p .707 .577 .707 r
F P
0 g
s
.56496 .72041 m .56496 .66483 L .5375 .66043 L p .707 .577 .707 r
F P
0 g
s
.56496 .66483 m .56496 .72041 L .59613 .72231 L p .707 .577 .707 r
F P
0 g
s
.65734 .66257 m .65734 .71815 L .6814 .7125 L p .707 .577 .707 r
F P
0 g
s
.6814 .7125 m .6814 .65692 L .65734 .66257 L p .707 .577 .707 r
F P
0 g
s
.59613 .76967 m .59613 .73262 L .56496 .73072 L p .707 .577 .707 r
F P
0 g
s
.59613 .73262 m .59613 .76967 L .62796 .7689 L p .707 .577 .707 r
F P
0 g
s
.62796 .7689 m .62796 .73184 L .59613 .73262 L p .707 .577 .707 r
F P
0 g
s
.62796 .73184 m .62796 .7689 L .65735 .76552 L p .707 .577 .707 r
F P
0 g
s
.65735 .76552 m .65734 .72846 L .62796 .73184 L p .707 .577 .707 r
F P
0 g
s
.5375 .66043 m .5375 .71602 L .56496 .72041 L p .707 .577 .707 r
F P
0 g
s
.5375 .71602 m .5375 .66043 L .51644 .65398 L p .707 .577 .707 r
F P
0 g
s
.56496 .76777 m .56496 .73072 L .5375 .72633 L p .707 .577 .707 r
F P
0 g
s
.56496 .73072 m .56496 .76777 L .59613 .76967 L p .707 .577 .707 r
F P
0 g
s
.65734 .72846 m .65735 .76552 L .6814 .75987 L p .707 .577 .707 r
F P
0 g
s
.6814 .75987 m .6814 .72281 L .65734 .72846 L p .707 .577 .707 r
F P
0 g
s
.6814 .65692 m .6814 .7125 L .69777 .70514 L p .707 .577 .707 r
F P
0 g
s
.69777 .70514 m .69777 .64955 L .6814 .65692 L p .707 .577 .707 r
F P
0 g
s
.5375 .72633 m .5375 .76338 L .56496 .76777 L p .707 .577 .707 r
F P
0 g
s
.51644 .65398 m .51644 .70956 L .5375 .71602 L p .707 .577 .707 r
F P
0 g
s
.5375 .76338 m .5375 .72633 L .51644 .71987 L p .707 .577 .707 r
F P
0 g
s
.59613 .83391 m .59613 .81539 L .56496 .81349 L p .707 .577 .707 r
F P
0 g
s
.59613 .81539 m .59613 .83391 L .62796 .83314 L p .707 .577 .707 r
F P
0 g
s
.62796 .83314 m .62796 .81461 L .59613 .81539 L p .707 .577 .707 r
F P
0 g
s
.62796 .81461 m .62796 .83314 L .65735 .82976 L p .707 .577 .707 r
F P
0 g
s
.65735 .82976 m .65735 .81123 L .62796 .81461 L p .707 .577 .707 r
F P
0 g
s
.51644 .70956 m .51644 .65398 L .50385 .6461 L p .707 .577 .707 r
F P
0 g
s
.56496 .81349 m .56496 .83201 L .59613 .83391 L p .707 .577 .707 r
F P
0 g
s
.56496 .83201 m .56496 .81349 L .5375 .80909 L p .707 .577 .707 r
F P
0 g
s
.51644 .71987 m .51644 .75693 L .5375 .76338 L p .707 .577 .707 r
F P
0 g
s
.5375 .80909 m .5375 .82762 L .56496 .83201 L p .707 .577 .707 r
F P
0 g
s
.6814 .72281 m .6814 .75987 L .69777 .7525 L p .707 .577 .707 r
F P
0 g
s
.69777 .7525 m .69777 .71545 L .6814 .72281 L p .707 .577 .707 r
F P
0 g
s
.65735 .81123 m .65735 .82976 L .6814 .82411 L p .707 .577 .707 r
F P
0 g
s
.6814 .82411 m .6814 .80558 L .65735 .81123 L p .707 .577 .707 r
F P
0 g
s
.50385 .6461 m .50385 .70168 L .51644 .70956 L p .707 .577 .707 r
F P
0 g
s
.69777 .64955 m .69777 .70514 L .70485 .69677 L p .707 .577 .707 r
F P
0 g
s
.70485 .69677 m .70485 .64119 L .69777 .64955 L p .707 .577 .707 r
F P
0 g
s
.5375 .82762 m .5375 .80909 L .51644 .80264 L p .707 .577 .707 r
F P
0 g
s
.51644 .75693 m .51644 .71987 L .50385 .71199 L p .707 .577 .707 r
F P
0 g
s
.51644 .80264 m .51644 .82117 L .5375 .82762 L p .707 .577 .707 r
F P
0 g
s
.50385 .70168 m .50385 .6461 L .50095 .63755 L p .707 .577 .707 r
F P
0 g
s
.50385 .71199 m .50385 .74904 L .51644 .75693 L p .707 .577 .707 r
F P
0 g
s
.6814 .80558 m .6814 .82411 L .69777 .81674 L p .707 .577 .707 r
F P
0 g
s
.69777 .81674 m .69777 .79821 L .6814 .80558 L p .707 .577 .707 r
F P
0 g
s
.69777 .71545 m .69777 .7525 L .70485 .74414 L p .707 .577 .707 r
F P
0 g
s
.70485 .74414 m .70485 .70708 L .69777 .71545 L p .707 .577 .707 r
F P
0 g
s
.51644 .82117 m .51644 .80264 L .50385 .79476 L p .707 .577 .707 r
F P
0 g
s
.50095 .63755 m .50095 .69314 L .50385 .70168 L p .707 .577 .707 r
F P
0 g
s
.70485 .64119 m .70485 .69677 L .70195 .68823 L p .707 .577 .707 r
F P
0 g
s
.70195 .68823 m .70195 .63265 L .70485 .64119 L p .707 .577 .707 r
F P
0 g
s
.50385 .79476 m .50385 .81328 L .51644 .82117 L p .707 .577 .707 r
F P
0 g
s
.50385 .74904 m .50385 .71199 L .50095 .70345 L p .707 .577 .707 r
F P
0 g
s
.50095 .70345 m .50095 .7405 L .50385 .74904 L p .707 .577 .707 r
F P
0 g
s
.69777 .79821 m .69777 .81674 L .70485 .80838 L p .707 .577 .707 r
F P
0 g
s
.70485 .80838 m .70485 .78985 L .69777 .79821 L p .707 .577 .707 r
F P
0 g
s
.50095 .69314 m .50095 .63755 L .50804 .62919 L p .707 .577 .707 r
F P
0 g
s
.70485 .70708 m .70485 .74414 L .70195 .73559 L p .707 .577 .707 r
F P
0 g
s
.70195 .73559 m .70195 .69854 L .70485 .70708 L p .707 .577 .707 r
F P
0 g
s
.50385 .81328 m .50385 .79476 L .50095 .78621 L p .707 .577 .707 r
F P
0 g
s
.49044 .85617 m .49044 .35428 L .44643 .3516 L p .707 .577 .707 r
F P
0 g
s
.50804 .62919 m .50804 .68477 L .50095 .69314 L p .707 .577 .707 r
F P
0 g
s
.50095 .78621 m .50095 .80474 L .50385 .81328 L p .707 .577 .707 r
F P
0 g
s
.50095 .7405 m .50095 .70345 L .50804 .69508 L p .707 .577 .707 r
F P
0 g
s
.50804 .69508 m .50804 .73214 L .50095 .7405 L p .707 .577 .707 r
F P
0 g
s
.50804 .68477 m .50804 .62919 L .5244 .62182 L p .707 .577 .707 r
F P
0 g
s
.50095 .80474 m .50095 .78621 L .50804 .77785 L p .707 .577 .707 r
F P
0 g
s
.5244 .62182 m .5244 .6774 L .50804 .68477 L p .707 .577 .707 r
F P
0 g
s
.50804 .77785 m .50804 .79638 L .50095 .80474 L p .707 .577 .707 r
F P
0 g
s
.50804 .73214 m .50804 .69508 L .5244 .68771 L p .707 .577 .707 r
F P
0 g
s
.5244 .68771 m .5244 .72477 L .50804 .73214 L p .707 .577 .707 r
F P
0 g
s
.50804 .79638 m .50804 .77785 L .5244 .77048 L p .707 .577 .707 r
F P
0 g
s
.5244 .77048 m .5244 .78901 L .50804 .79638 L p .707 .577 .707 r
F P
0 g
s
.5244 .78901 m .5244 .77048 L .54846 .76483 L p .707 .577 .707 r
F P
0 g
s
.54846 .76483 m .54846 .78336 L .5244 .78901 L p .707 .577 .707 r
F P
0 g
s
.49044 .35428 m .49044 .85617 L .53538 .85507 L p .707 .577 .707 r
F P
0 g
s
.5244 .6774 m .5244 .62182 L .54846 .61617 L p .707 .577 .707 r
F P
0 g
s
.54846 .61617 m .54846 .67175 L .5244 .6774 L p .707 .577 .707 r
F P
0 g
s
.5244 .72477 m .5244 .68771 L .54846 .68206 L p .707 .577 .707 r
F P
0 g
s
.54846 .68206 m .54846 .71912 L .5244 .72477 L p .707 .577 .707 r
F P
0 g
s
.53538 .85507 m .53538 .35318 L .49044 .35428 L p .707 .577 .707 r
F P
0 g
s
.70195 .63265 m .70195 .68823 L .68936 .68034 L p .707 .577 .707 r
F P
0 g
s
.68936 .68034 m .68936 .62476 L .70195 .63265 L p .707 .577 .707 r
F P
0 g
s
.54846 .67175 m .54846 .61617 L .57784 .61279 L p .707 .577 .707 r
F P
0 g
s
.57784 .61279 m .57784 .66838 L .54846 .67175 L p .707 .577 .707 r
F P
0 g
s
.54846 .71912 m .54846 .68206 L .57784 .67869 L p .707 .577 .707 r
F P
0 g
s
.57784 .67869 m .57784 .71574 L .54846 .71912 L p .707 .577 .707 r
F P
0 g
s
.54846 .78336 m .54846 .76483 L .57784 .76145 L p .707 .577 .707 r
F P
0 g
s
.57784 .76145 m .57784 .77998 L .54846 .78336 L p .707 .577 .707 r
F P
0 g
s
.53538 .35318 m .53538 .85507 L .57686 .8503 L p .707 .577 .707 r
F P
0 g
s
.57686 .8503 m .57686 .34841 L .53538 .35318 L p .707 .577 .707 r
F P
0 g
s
.44643 .85349 m .44643 .3516 L .40766 .3454 L p .707 .577 .707 r
F P
0 g
s
.44643 .3516 m .44643 .85349 L .49044 .85617 L p .707 .577 .707 r
F P
0 g
s
.25312 .68549 m .25312 .62991 L .22195 .62801 L p .707 .577 .707 r
F P
0 g
s
.25312 .62991 m .25312 .68549 L .28495 .68472 L p .707 .577 .707 r
F P
0 g
s
.28495 .68472 m .28495 .62913 L .25312 .62991 L p .707 .577 .707 r
F P
0 g
s
.70485 .78985 m .70485 .80838 L .70195 .79983 L p .707 .577 .707 r
F P
0 g
s
.70195 .79983 m .70195 .78131 L .70485 .78985 L p .707 .577 .707 r
F P
0 g
s
.28495 .62913 m .28495 .68472 L .31434 .68134 L p .707 .577 .707 r
F P
0 g
s
.31434 .68134 m .31434 .62576 L .28495 .62913 L p .707 .577 .707 r
F P
0 g
s
.22195 .68359 m .22195 .62801 L .19449 .62362 L p .707 .577 .707 r
F P
0 g
s
.22195 .62801 m .22195 .68359 L .25312 .68549 L p .707 .577 .707 r
F P
0 g
s
.57784 .66838 m .57784 .61279 L .60968 .61202 L p .707 .577 .707 r
F P
0 g
s
.60968 .61202 m .60968 .6676 L .57784 .66838 L p .707 .577 .707 r
F P
0 g
s
.57784 .71574 m .57784 .67869 L .60968 .67791 L p .707 .577 .707 r
F P
0 g
s
.60968 .67791 m .60968 .71496 L .57784 .71574 L p .707 .577 .707 r
F P
0 g
s
.57784 .77998 m .57784 .76145 L .60968 .76067 L p .707 .577 .707 r
F P
0 g
s
.60968 .76067 m .60968 .7792 L .57784 .77998 L p .707 .577 .707 r
F P
0 g
s
.57686 .34841 m .57686 .8503 L .61082 .84233 L p .707 .577 .707 r
F P
0 g
s
.64085 .61392 m .64085 .6695 L .60968 .6676 L p .707 .577 .707 r
F P
0 g
s
.60968 .6676 m .60968 .61202 L .64085 .61392 L p .707 .577 .707 r
F P
0 g
s
.64085 .67981 m .64085 .71686 L .60968 .71496 L p .707 .577 .707 r
F P
0 g
s
.60968 .71496 m .60968 .67791 L .64085 .67981 L p .707 .577 .707 r
F P
0 g
s
.64085 .76258 m .64085 .7811 L .60968 .7792 L p .707 .577 .707 r
F P
0 g
s
.60968 .7792 m .60968 .76067 L .64085 .76258 L p .707 .577 .707 r
F P
0 g
s
.61082 .84233 m .61082 .34044 L .57686 .34841 L p .707 .577 .707 r
F P
0 g
s
.70195 .69854 m .70195 .73559 L .68936 .72771 L p .707 .577 .707 r
F P
0 g
s
.68936 .72771 m .68936 .69066 L .70195 .69854 L p .707 .577 .707 r
F P
0 g
s
.31434 .62576 m .31434 .68134 L .33839 .67569 L p .707 .577 .707 r
F P
0 g
s
.33839 .67569 m .33839 .62011 L .31434 .62576 L p .707 .577 .707 r
F P
0 g
s
.25312 .73286 m .25312 .6958 L .22195 .6939 L p .707 .577 .707 r
F P
0 g
s
.25312 .6958 m .25312 .73286 L .28495 .73208 L p .707 .577 .707 r
F P
0 g
s
.28495 .73208 m .28495 .69503 L .25312 .6958 L p .707 .577 .707 r
F P
0 g
s
.40766 .84729 m .40766 .3454 L .37794 .33629 L p .707 .577 .707 r
F P
0 g
s
.40766 .3454 m .40766 .84729 L .44643 .85349 L p .707 .577 .707 r
F P
0 g
s
.68936 .62476 m .68936 .68034 L .66831 .67389 L p .707 .577 .707 r
F P
0 g
s
.66831 .67389 m .66831 .61831 L .68936 .62476 L p .707 .577 .707 r
F P
0 g
s
.28495 .69503 m .28495 .73208 L .31434 .7287 L p .707 .577 .707 r
F P
0 g
s
.31434 .7287 m .31434 .69165 L .28495 .69503 L p .707 .577 .707 r
F P
0 g
s
.19449 .62362 m .19449 .6792 L .22195 .68359 L p .707 .577 .707 r
F P
0 g
s
.19449 .6792 m .19449 .62362 L .17343 .61716 L p .707 .577 .707 r
F P
0 g
s
.22195 .73096 m .22195 .6939 L .19449 .68951 L p .707 .577 .707 r
F P
0 g
s
.22195 .6939 m .22195 .73096 L .25312 .73286 L p .707 .577 .707 r
F P
0 g
s
.70195 .78131 m .70195 .79983 L .68936 .79195 L p .707 .577 .707 r
F P
0 g
s
.68936 .79195 m .68936 .77342 L .70195 .78131 L p .707 .577 .707 r
F P
0 g
s
.31434 .69165 m .31434 .7287 L .33839 .72305 L p .707 .577 .707 r
F P
0 g
s
.33839 .72305 m .33839 .686 L .31434 .69165 L p .707 .577 .707 r
F P
0 g
s
.33839 .62011 m .33839 .67569 L .35476 .66832 L p .707 .577 .707 r
F P
0 g
s
.35476 .66832 m .35476 .61274 L .33839 .62011 L p .707 .577 .707 r
F P
0 g
s
.19449 .68951 m .19449 .72657 L .22195 .73096 L p .707 .577 .707 r
F P
0 g
s
.61082 .34044 m .61082 .84233 L .63393 .83192 L p .707 .577 .707 r
F P
0 g
s
.63393 .83192 m .63393 .33004 L .61082 .34044 L p .707 .577 .707 r
F P
0 g
s
.68936 .69066 m .68936 .72771 L .66831 .72126 L p .707 .577 .707 r
F P
0 g
s
.66831 .72126 m .66831 .6842 L .68936 .69066 L p .707 .577 .707 r
F P
0 g
s
.17343 .61716 m .17343 .67275 L .19449 .6792 L p .707 .577 .707 r
F P
0 g
s
.19449 .72657 m .19449 .68951 L .17343 .68306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7971 m .25312 .77857 L .22195 .77667 L p .707 .577 .707 r
F P
0 g
s
.25312 .77857 m .25312 .7971 L .28495 .79632 L p .707 .577 .707 r
F P
0 g
s
.28495 .79632 m .28495 .77779 L .25312 .77857 L p .707 .577 .707 r
F P
0 g
s
.66831 .61831 m .66831 .67389 L .64085 .6695 L p .707 .577 .707 r
F P
0 g
s
.64085 .6695 m .64085 .61392 L .66831 .61831 L p .707 .577 .707 r
F P
0 g
s
.28495 .77779 m .28495 .79632 L .31434 .79294 L p .707 .577 .707 r
F P
0 g
s
.31434 .79294 m .31434 .77441 L .28495 .77779 L p .707 .577 .707 r
F P
0 g
s
.17343 .67275 m .17343 .61716 L .16084 .60928 L p .707 .577 .707 r
F P
0 g
s
.22195 .77667 m .22195 .7952 L .25312 .7971 L p .707 .577 .707 r
F P
0 g
s
.22195 .7952 m .22195 .77667 L .19449 .77228 L p .707 .577 .707 r
F P
0 g
s
.37794 .83817 m .37794 .33629 L .36016 .32515 L p .707 .577 .707 r
F P
0 g
s
.37794 .33629 m .37794 .83817 L .40766 .84729 L p .707 .577 .707 r
F P
0 g
s
.17343 .68306 m .17343 .72011 L .19449 .72657 L p .707 .577 .707 r
F P
0 g
s
.19449 .77228 m .19449 .79081 L .22195 .7952 L p .707 .577 .707 r
F P
0 g
s
.33839 .686 m .33839 .72305 L .35476 .71569 L p .707 .577 .707 r
F P
0 g
s
.35476 .71569 m .35476 .67863 L .33839 .686 L p .707 .577 .707 r
F P
0 g
s
.31434 .77441 m .31434 .79294 L .33839 .78729 L p .707 .577 .707 r
F P
0 g
s
.33839 .78729 m .33839 .76876 L .31434 .77441 L p .707 .577 .707 r
F P
0 g
s
.68936 .77342 m .68936 .79195 L .66831 .7855 L p .707 .577 .707 r
F P
0 g
s
.66831 .7855 m .66831 .76697 L .68936 .77342 L p .707 .577 .707 r
F P
0 g
s
.66831 .6842 m .66831 .72126 L .64085 .71686 L p .707 .577 .707 r
F P
0 g
s
.64085 .71686 m .64085 .67981 L .66831 .6842 L p .707 .577 .707 r
F P
0 g
s
.16084 .60928 m .16084 .66486 L .17343 .67275 L p .707 .577 .707 r
F P
0 g
s
.35476 .61274 m .35476 .66832 L .36184 .65996 L p .707 .577 .707 r
F P
0 g
s
.36184 .65996 m .36184 .60437 L .35476 .61274 L p .707 .577 .707 r
F P
0 g
s
.19449 .79081 m .19449 .77228 L .17343 .76582 L p .707 .577 .707 r
F P
0 g
s
.17343 .72011 m .17343 .68306 L .16084 .67517 L p .707 .577 .707 r
F P
0 g
s
.17343 .76582 m .17343 .78435 L .19449 .79081 L p .707 .577 .707 r
F P
0 g
s
.66831 .76697 m .66831 .7855 L .64085 .7811 L p .707 .577 .707 r
F P
0 g
s
.64085 .7811 m .64085 .76258 L .66831 .76697 L p .707 .577 .707 r
F P
0 g
s
.63393 .33004 m .63393 .83192 L .64393 .82012 L p .707 .577 .707 r
F P
0 g
s
.64393 .82012 m .64393 .31823 L .63393 .33004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66486 m .16084 .60928 L .15794 .60074 L p .707 .577 .707 r
F P
0 g
s
.16084 .67517 m .16084 .71223 L .17343 .72011 L p .707 .577 .707 r
F P
0 g
s
.33839 .76876 m .33839 .78729 L .35476 .77992 L p .707 .577 .707 r
F P
0 g
s
.35476 .77992 m .35476 .7614 L .33839 .76876 L p .707 .577 .707 r
F P
0 g
s
.35476 .67863 m .35476 .71569 L .36184 .70732 L p .707 .577 .707 r
F P
0 g
s
.36184 .70732 m .36184 .67027 L .35476 .67863 L p .707 .577 .707 r
F P
0 g
s
.17343 .78435 m .17343 .76582 L .16084 .75794 L p .707 .577 .707 r
F P
0 g
s
.15794 .60074 m .15794 .65632 L .16084 .66486 L p .707 .577 .707 r
F P
0 g
s
.36184 .60437 m .36184 .65996 L .35894 .65141 L p .707 .577 .707 r
F P
0 g
s
.35894 .65141 m .35894 .59583 L .36184 .60437 L p .707 .577 .707 r
F P
0 g
s
.35476 .7614 m .35476 .77992 L .36184 .77156 L p .707 .577 .707 r
F P
0 g
s
.36184 .77156 m .36184 .75303 L .35476 .7614 L p .707 .577 .707 r
F P
0 g
s
.36184 .67027 m .36184 .70732 L .35894 .69878 L p .707 .577 .707 r
F P
0 g
s
.35894 .69878 m .35894 .66172 L .36184 .67027 L p .707 .577 .707 r
F P
0 g
s
.35894 .59583 m .35894 .65141 L .34635 .64353 L p .707 .577 .707 r
F P
0 g
s
.34635 .64353 m .34635 .58795 L .35894 .59583 L p .707 .577 .707 r
F P
0 g
s
.36184 .75303 m .36184 .77156 L .35894 .76302 L p .707 .577 .707 r
F P
0 g
s
.35894 .76302 m .35894 .74449 L .36184 .75303 L p .707 .577 .707 r
F P
0 g
s
.35894 .66172 m .35894 .69878 L .34635 .69089 L p .707 .577 .707 r
F P
0 g
s
.34635 .69089 m .34635 .65384 L .35894 .66172 L p .707 .577 .707 r
F P
0 g
s
.36016 .82704 m .36016 .32515 L .35607 .31309 L p .707 .577 .707 r
F P
0 g
s
.36016 .32515 m .36016 .82704 L .37794 .83817 L p .707 .577 .707 r
F P
0 g
s
.16084 .75794 m .16084 .77647 L .17343 .78435 L p .707 .577 .707 r
F P
0 g
s
.16084 .71223 m .16084 .67517 L .15794 .66663 L p .707 .577 .707 r
F P
0 g
s
.15794 .66663 m .15794 .70369 L .16084 .71223 L p .707 .577 .707 r
F P
0 g
s
.15794 .65632 m .15794 .60074 L .16503 .59237 L p .707 .577 .707 r
F P
0 g
s
.16084 .77647 m .16084 .75794 L .15794 .7494 L p .707 .577 .707 r
F P
0 g
s
.64393 .31823 m .64393 .82012 L .63984 .80806 L p .707 .577 .707 r
F P
0 g
s
.63984 .80806 m .63984 .30617 L .64393 .31823 L p .707 .577 .707 r
F P
0 g
s
.16503 .59237 m .16503 .64796 L .15794 .65632 L p .707 .577 .707 r
F P
0 g
s
.15794 .7494 m .15794 .76793 L .16084 .77647 L p .707 .577 .707 r
F P
0 g
s
.15794 .70369 m .15794 .66663 L .16503 .65827 L p .707 .577 .707 r
F P
0 g
s
.16503 .65827 m .16503 .69532 L .15794 .70369 L p .707 .577 .707 r
F P
0 g
s
.35894 .74449 m .35894 .76302 L .34635 .75513 L p .707 .577 .707 r
F P
0 g
s
.34635 .75513 m .34635 .73661 L .35894 .74449 L p .707 .577 .707 r
F P
0 g
s
.35607 .31309 m .35607 .81498 L .36016 .82704 L p .707 .577 .707 r
F P
0 g
s
.35607 .81498 m .35607 .31309 L .36607 .30129 L p .707 .577 .707 r
F P
0 g
s
.16503 .64796 m .16503 .59237 L .1814 .58501 L p .707 .577 .707 r
F P
0 g
s
.15794 .76793 m .15794 .7494 L .16503 .74103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58501 m .1814 .64059 L .16503 .64796 L p .707 .577 .707 r
F P
0 g
s
.34635 .58795 m .34635 .64353 L .3253 .63708 L p .707 .577 .707 r
F P
0 g
s
.3253 .63708 m .3253 .58149 L .34635 .58795 L p .707 .577 .707 r
F P
0 g
s
.16503 .74103 m .16503 .75956 L .15794 .76793 L p .707 .577 .707 r
F P
0 g
s
.16503 .69532 m .16503 .65827 L .1814 .6509 L p .707 .577 .707 r
F P
0 g
s
.63984 .30617 m .63984 .80806 L .62206 .79693 L p .707 .577 .707 r
F P
0 g
s
.62206 .79693 m .62206 .29504 L .63984 .30617 L p .707 .577 .707 r
F P
0 g
s
.1814 .64059 m .1814 .58501 L .20545 .57936 L p .707 .577 .707 r
F P
0 g
s
.1814 .6509 m .1814 .68795 L .16503 .69532 L p .707 .577 .707 r
F P
0 g
s
.34635 .65384 m .34635 .69089 L .3253 .68444 L p .707 .577 .707 r
F P
0 g
s
.3253 .68444 m .3253 .64739 L .34635 .65384 L p .707 .577 .707 r
F P
0 g
s
.3253 .58149 m .3253 .63708 L .29784 .63268 L p .707 .577 .707 r
F P
0 g
s
.29784 .63268 m .29784 .5771 L .3253 .58149 L p .707 .577 .707 r
F P
0 g
s
.16503 .75956 m .16503 .74103 L .1814 .73367 L p .707 .577 .707 r
F P
0 g
s
.20545 .57936 m .20545 .63494 L .1814 .64059 L p .707 .577 .707 r
F P
0 g
s
.36607 .80318 m .36607 .30129 L .38918 .29088 L p .707 .577 .707 r
F P
0 g
s
.36607 .30129 m .36607 .80318 L .35607 .81498 L p .707 .577 .707 r
F P
0 g
s
.1814 .68795 m .1814 .6509 L .20545 .64525 L p .707 .577 .707 r
F P
0 g
s
.1814 .73367 m .1814 .75219 L .16503 .75956 L p .707 .577 .707 r
F P
0 g
s
.20545 .63494 m .20545 .57936 L .23483 .57598 L p .707 .577 .707 r
F P
0 g
s
.29784 .5771 m .29784 .63268 L .26667 .63078 L p .707 .577 .707 r
F P
0 g
s
.26667 .63078 m .26667 .5752 L .29784 .5771 L p .707 .577 .707 r
F P
0 g
s
.20545 .64525 m .20545 .6823 L .1814 .68795 L p .707 .577 .707 r
F P
0 g
s
.34635 .73661 m .34635 .75513 L .3253 .74868 L p .707 .577 .707 r
F P
0 g
s
.3253 .74868 m .3253 .73015 L .34635 .73661 L p .707 .577 .707 r
F P
0 g
s
.3253 .64739 m .3253 .68444 L .29784 .68005 L p .707 .577 .707 r
F P
0 g
s
.29784 .68005 m .29784 .64299 L .3253 .64739 L p .707 .577 .707 r
F P
0 g
s
.23483 .63156 m .23483 .57598 L .26667 .5752 L p .707 .577 .707 r
F P
0 g
s
.23483 .57598 m .23483 .63156 L .20545 .63494 L p .707 .577 .707 r
F P
0 g
s
.26667 .5752 m .26667 .63078 L .23483 .63156 L p .707 .577 .707 r
F P
0 g
s
.73333 .63027 m .73333 .57469 L .70216 .57279 L p .707 .577 .707 r
F P
0 g
s
.73333 .57469 m .73333 .63027 L .76517 .62949 L p .707 .577 .707 r
F P
0 g
s
.76517 .62949 m .76517 .57391 L .73333 .57469 L p .707 .577 .707 r
F P
0 g
s
.62206 .29504 m .62206 .79693 L .59233 .78781 L p .707 .577 .707 r
F P
0 g
s
.59233 .78781 m .59233 .28592 L .62206 .29504 L p .707 .577 .707 r
F P
0 g
s
.20545 .6823 m .20545 .64525 L .23483 .64187 L p .707 .577 .707 r
F P
0 g
s
.76517 .57391 m .76517 .62949 L .79455 .62611 L p .707 .577 .707 r
F P
0 g
s
.79455 .62611 m .79455 .57053 L .76517 .57391 L p .707 .577 .707 r
F P
0 g
s
.1814 .75219 m .1814 .73367 L .20545 .72802 L p .707 .577 .707 r
F P
0 g
s
.70216 .62837 m .70216 .57279 L .6747 .5684 L p .707 .577 .707 r
F P
0 g
s
.70216 .57279 m .70216 .62837 L .73333 .63027 L p .707 .577 .707 r
F P
0 g
s
.20545 .72802 m .20545 .74654 L .1814 .75219 L p .707 .577 .707 r
F P
0 g
s
.29784 .64299 m .29784 .68005 L .26667 .67815 L p .707 .577 .707 r
F P
0 g
s
.26667 .67815 m .26667 .64109 L .29784 .64299 L p .707 .577 .707 r
F P
0 g
s
.23483 .64187 m .23483 .67893 L .20545 .6823 L p .707 .577 .707 r
F P
0 g
s
.23483 .67893 m .23483 .64187 L .26667 .64109 L p .707 .577 .707 r
F P
0 g
s
.79455 .57053 m .79455 .62611 L .8186 .62046 L p .707 .577 .707 r
F P
0 g
s
.8186 .62046 m .8186 .56488 L .79455 .57053 L p .707 .577 .707 r
F P
0 g
s
.38918 .29088 m .38918 .79277 L .36607 .80318 L p .707 .577 .707 r
F P
0 g
s
.38918 .79277 m .38918 .29088 L .42314 .28291 L p .707 .577 .707 r
F P
0 g
s
.26667 .64109 m .26667 .67815 L .23483 .67893 L p .707 .577 .707 r
F P
0 g
s
.3253 .73015 m .3253 .74868 L .29784 .74429 L p .707 .577 .707 r
F P
0 g
s
.29784 .74429 m .29784 .72576 L .3253 .73015 L p .707 .577 .707 r
F P
0 g
s
.73333 .67764 m .73333 .64058 L .70216 .63868 L p .707 .577 .707 r
F P
0 g
s
.73333 .64058 m .73333 .67764 L .76517 .67686 L p .707 .577 .707 r
F P
0 g
s
.76517 .67686 m .76517 .6398 L .73333 .64058 L p .707 .577 .707 r
F P
0 g
s
.76517 .6398 m .76517 .67686 L .79455 .67348 L p .707 .577 .707 r
F P
0 g
s
.79455 .67348 m .79455 .63643 L .76517 .6398 L p .707 .577 .707 r
F P
0 g
s
.6747 .5684 m .6747 .62398 L .70216 .62837 L p .707 .577 .707 r
F P
0 g
s
.6747 .62398 m .6747 .5684 L .65365 .56194 L p .707 .577 .707 r
F P
0 g
s
.20545 .74654 m .20545 .72802 L .23483 .72464 L p .707 .577 .707 r
F P
0 g
s
.70216 .67574 m .70216 .63868 L .6747 .63429 L p .707 .577 .707 r
F P
0 g
s
.70216 .63868 m .70216 .67574 L .73333 .67764 L p .707 .577 .707 r
F P
0 g
s
.23483 .72464 m .23483 .74316 L .20545 .74654 L p .707 .577 .707 r
F P
0 g
s
.29784 .72576 m .29784 .74429 L .26667 .74239 L p .707 .577 .707 r
F P
0 g
s
.26667 .74239 m .26667 .72386 L .29784 .72576 L p .707 .577 .707 r
F P
0 g
s
.79455 .63643 m .79455 .67348 L .8186 .66783 L p .707 .577 .707 r
F P
0 g
s
.8186 .66783 m .8186 .63078 L .79455 .63643 L p .707 .577 .707 r
F P
0 g
s
.59233 .28592 m .59233 .78781 L .55357 .78161 L p .707 .577 .707 r
F P
0 g
s
.55357 .78161 m .55357 .27972 L .59233 .28592 L p .707 .577 .707 r
F P
0 g
s
.8186 .56488 m .8186 .62046 L .83497 .6131 L p .707 .577 .707 r
F P
0 g
s
.83497 .6131 m .83497 .55751 L .8186 .56488 L p .707 .577 .707 r
F P
0 g
s
.6747 .63429 m .6747 .67134 L .70216 .67574 L p .707 .577 .707 r
F P
0 g
s
.23483 .74316 m .23483 .72464 L .26667 .72386 L p .707 .577 .707 r
F P
0 g
s
.65365 .56194 m .65365 .61752 L .6747 .62398 L p .707 .577 .707 r
F P
0 g
s
.26667 .72386 m .26667 .74239 L .23483 .74316 L p .707 .577 .707 r
F P
0 g
s
.6747 .67134 m .6747 .63429 L .65365 .62783 L p .707 .577 .707 r
F P
0 g
s
.73333 .74188 m .73333 .72335 L .70216 .72145 L p .707 .577 .707 r
F P
0 g
s
.73333 .72335 m .73333 .74188 L .76517 .7411 L p .707 .577 .707 r
F P
0 g
s
.76517 .7411 m .76517 .72257 L .73333 .72335 L p .707 .577 .707 r
F P
0 g
s
.76517 .72257 m .76517 .7411 L .79455 .73772 L p .707 .577 .707 r
F P
0 g
s
.79455 .73772 m .79455 .71919 L .76517 .72257 L p .707 .577 .707 r
F P
0 g
s
.42314 .7848 m .42314 .28291 L .46462 .27814 L p .707 .577 .707 r
F P
0 g
s
.42314 .28291 m .42314 .7848 L .38918 .79277 L p .707 .577 .707 r
F P
0 g
s
.65365 .61752 m .65365 .56194 L .64105 .55406 L p .707 .577 .707 r
F P
0 g
s
.70216 .72145 m .70216 .73997 L .73333 .74188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73997 m .70216 .72145 L .6747 .71705 L p .707 .577 .707 r
F P
0 g
s
.65365 .62783 m .65365 .66489 L .6747 .67134 L p .707 .577 .707 r
F P
0 g
s
.6747 .71705 m .6747 .73558 L .70216 .73997 L p .707 .577 .707 r
F P
0 g
s
.8186 .63078 m .8186 .66783 L .83497 .66046 L p .707 .577 .707 r
F P
0 g
s
.83497 .66046 m .83497 .62341 L .8186 .63078 L p .707 .577 .707 r
F P
0 g
s
.55357 .27972 m .55357 .78161 L .50956 .77893 L p .707 .577 .707 r
F P
0 g
s
.50956 .77893 m .50956 .27704 L .55357 .27972 L p .707 .577 .707 r
F P
0 g
s
.79455 .71919 m .79455 .73772 L .8186 .73207 L p .707 .577 .707 r
F P
0 g
s
.8186 .73207 m .8186 .71354 L .79455 .71919 L p .707 .577 .707 r
F P
0 g
s
.64105 .55406 m .64105 .60964 L .65365 .61752 L p .707 .577 .707 r
F P
0 g
s
.46462 .78003 m .46462 .27814 L .50956 .27704 L p .707 .577 .707 r
F P
0 g
s
.46462 .27814 m .46462 .78003 L .42314 .7848 L p .707 .577 .707 r
F P
0 g
s
.83497 .55751 m .83497 .6131 L .84205 .60473 L p .707 .577 .707 r
F P
0 g
s
.84205 .60473 m .84205 .54915 L .83497 .55751 L p .707 .577 .707 r
F P
0 g
s
.6747 .73558 m .6747 .71705 L .65365 .7106 L p .707 .577 .707 r
F P
0 g
s
.65365 .66489 m .65365 .62783 L .64105 .61995 L p .707 .577 .707 r
F P
0 g
s
.50956 .27704 m .50956 .77893 L .46462 .78003 L p .707 .577 .707 r
F P
0 g
s
.65365 .7106 m .65365 .72913 L .6747 .73558 L p .707 .577 .707 r
F P
0 g
s
.64105 .60964 m .64105 .55406 L .63816 .54551 L p .707 .577 .707 r
F P
0 g
s
.64105 .61995 m .64105 .65701 L .65365 .66489 L p .707 .577 .707 r
F P
0 g
s
.8186 .71354 m .8186 .73207 L .83497 .7247 L p .707 .577 .707 r
F P
0 g
s
.83497 .7247 m .83497 .70617 L .8186 .71354 L p .707 .577 .707 r
F P
0 g
s
.83497 .62341 m .83497 .66046 L .84205 .6521 L p .707 .577 .707 r
F P
0 g
s
.84205 .6521 m .84205 .61504 L .83497 .62341 L p .707 .577 .707 r
F P
0 g
s
.65365 .72913 m .65365 .7106 L .64105 .70272 L p .707 .577 .707 r
F P
0 g
s
.63816 .54551 m .63816 .6011 L .64105 .60964 L p .707 .577 .707 r
F P
0 g
s
.84205 .54915 m .84205 .60473 L .83916 .59619 L p .707 .577 .707 r
F P
0 g
s
.83916 .59619 m .83916 .54061 L .84205 .54915 L p .707 .577 .707 r
F P
0 g
s
.64105 .70272 m .64105 .72124 L .65365 .72913 L p .707 .577 .707 r
F P
0 g
s
.64105 .65701 m .64105 .61995 L .63816 .61141 L p .707 .577 .707 r
F P
0 g
s
.63816 .61141 m .63816 .64846 L .64105 .65701 L p .707 .577 .707 r
F P
0 g
s
.83497 .70617 m .83497 .7247 L .84206 .71634 L p .707 .577 .707 r
F P
0 g
s
.84206 .71634 m .84206 .69781 L .83497 .70617 L p .707 .577 .707 r
F P
0 g
s
.63816 .6011 m .63816 .54551 L .64524 .53715 L p .707 .577 .707 r
F P
0 g
s
.84205 .61504 m .84205 .6521 L .83916 .64356 L p .707 .577 .707 r
F P
0 g
s
.83916 .64356 m .83916 .6065 L .84205 .61504 L p .707 .577 .707 r
F P
0 g
s
.64105 .72124 m .64105 .70272 L .63816 .69417 L p .707 .577 .707 r
F P
0 g
s
.64524 .53715 m .64524 .59273 L .63816 .6011 L p .707 .577 .707 r
F P
0 g
s
.63816 .69417 m .63816 .7127 L .64105 .72124 L p .707 .577 .707 r
F P
0 g
s
.83916 .54061 m .83916 .59619 L .82657 .58831 L p .707 .577 .707 r
F P
0 g
s
.82657 .58831 m .82657 .53272 L .83916 .54061 L p .707 .577 .707 r
F P
0 g
s
.63816 .64846 m .63816 .61141 L .64524 .60304 L p .707 .577 .707 r
F P
0 g
s
.39032 .59345 m .39032 .53787 L .35915 .53597 L p .707 .577 .707 r
F P
0 g
s
.39032 .53787 m .39032 .59345 L .42216 .59268 L p .707 .577 .707 r
F P
0 g
s
.42216 .59268 m .42216 .5371 L .39032 .53787 L p .707 .577 .707 r
F P
0 g
s
.84206 .69781 m .84206 .71634 L .83916 .7078 L p .707 .577 .707 r
F P
0 g
s
.83916 .7078 m .83916 .68927 L .84206 .69781 L p .707 .577 .707 r
F P
0 g
s
.64524 .60304 m .64524 .6401 L .63816 .64846 L p .707 .577 .707 r
F P
0 g
s
.64524 .59273 m .64524 .53715 L .66161 .52978 L p .707 .577 .707 r
F P
0 g
s
.42216 .5371 m .42216 .59268 L .45154 .5893 L p .707 .577 .707 r
F P
0 g
s
.45154 .5893 m .45154 .53372 L .42216 .5371 L p .707 .577 .707 r
F P
0 g
s
.35915 .59155 m .35915 .53597 L .33169 .53158 L p .707 .577 .707 r
F P
0 g
s
.35915 .53597 m .35915 .59155 L .39032 .59345 L p .707 .577 .707 r
F P
0 g
s
.83916 .6065 m .83916 .64356 L .82657 .63567 L p .707 .577 .707 r
F P
0 g
s
.82657 .63567 m .82657 .59862 L .83916 .6065 L p .707 .577 .707 r
F P
0 g
s
.63816 .7127 m .63816 .69417 L .64524 .68581 L p .707 .577 .707 r
F P
0 g
s
.45154 .53372 m .45154 .5893 L .47559 .58365 L p .707 .577 .707 r
F P
0 g
s
.47559 .58365 m .47559 .52807 L .45154 .53372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52978 m .66161 .58537 L .64524 .59273 L p .707 .577 .707 r
F P
0 g
s
.39032 .64082 m .39032 .60377 L .35915 .60187 L p .707 .577 .707 r
F P
0 g
s
.39032 .60377 m .39032 .64082 L .42216 .64004 L p .707 .577 .707 r
F P
0 g
s
.42216 .64004 m .42216 .60299 L .39032 .60377 L p .707 .577 .707 r
F P
0 g
s
.82657 .53272 m .82657 .58831 L .80551 .58185 L p .707 .577 .707 r
F P
0 g
s
.80551 .58185 m .80551 .52627 L .82657 .53272 L p .707 .577 .707 r
F P
0 g
s
.64524 .68581 m .64524 .70434 L .63816 .7127 L p .707 .577 .707 r
F P
0 g
s
.64524 .6401 m .64524 .60304 L .66161 .59568 L p .707 .577 .707 r
F P
0 g
s
.42216 .60299 m .42216 .64004 L .45154 .63666 L p .707 .577 .707 r
F P
0 g
s
.45154 .63666 m .45154 .59961 L .42216 .60299 L p .707 .577 .707 r
F P
0 g
s
.33169 .53158 m .33169 .58716 L .35915 .59155 L p .707 .577 .707 r
F P
0 g
s
.33169 .58716 m .33169 .53158 L .31064 .52513 L p .707 .577 .707 r
F P
0 g
s
.35915 .63892 m .35915 .60187 L .33169 .59747 L p .707 .577 .707 r
F P
0 g
s
.35915 .60187 m .35915 .63892 L .39032 .64082 L p .707 .577 .707 r
F P
0 g
s
.66161 .58537 m .66161 .52978 L .68566 .52413 L p .707 .577 .707 r
F P
0 g
s
.66161 .59568 m .66161 .63273 L .64524 .6401 L p .707 .577 .707 r
F P
0 g
s
.83916 .68927 m .83916 .7078 L .82657 .69991 L p .707 .577 .707 r
F P
0 g
s
.82657 .69991 m .82657 .68138 L .83916 .68927 L p .707 .577 .707 r
F P
0 g
s
.45154 .59961 m .45154 .63666 L .47559 .63101 L p .707 .577 .707 r
F P
0 g
s
.47559 .63101 m .47559 .59396 L .45154 .59961 L p .707 .577 .707 r
F P
0 g
s
.47559 .52807 m .47559 .58365 L .49196 .57628 L p .707 .577 .707 r
F P
0 g
s
.49196 .57628 m .49196 .5207 L .47559 .52807 L p .707 .577 .707 r
F P
0 g
s
.33169 .59747 m .33169 .63453 L .35915 .63892 L p .707 .577 .707 r
F P
0 g
s
.82657 .59862 m .82657 .63567 L .80551 .62922 L p .707 .577 .707 r
F P
0 g
s
.80551 .62922 m .80551 .59216 L .82657 .59862 L p .707 .577 .707 r
F P
0 g
s
.31064 .52513 m .31064 .58071 L .33169 .58716 L p .707 .577 .707 r
F P
0 g
s
.33169 .63453 m .33169 .59747 L .31064 .59102 L p .707 .577 .707 r
F P
0 g
s
.39032 .70506 m .39032 .68653 L .35915 .68463 L p .707 .577 .707 r
F P
0 g
s
.39032 .68653 m .39032 .70506 L .42216 .70428 L p .707 .577 .707 r
F P
0 g
s
.42216 .70428 m .42216 .68576 L .39032 .68653 L p .707 .577 .707 r
F P
0 g
s
.80551 .52627 m .80551 .58185 L .77805 .57746 L p .707 .577 .707 r
F P
0 g
s
.77805 .57746 m .77805 .52188 L .80551 .52627 L p .707 .577 .707 r
F P
0 g
s
.64524 .70434 m .64524 .68581 L .66161 .67844 L p .707 .577 .707 r
F P
0 g
s
.42216 .68576 m .42216 .70428 L .45154 .7009 L p .707 .577 .707 r
F P
0 g
s
.45154 .7009 m .45154 .68238 L .42216 .68576 L p .707 .577 .707 r
F P
0 g
s
.68566 .52413 m .68566 .57972 L .66161 .58537 L p .707 .577 .707 r
F P
0 g
s
.31064 .58071 m .31064 .52513 L .29804 .51724 L p .707 .577 .707 r
F P
0 g
s
.35915 .68463 m .35915 .70316 L .39032 .70506 L p .707 .577 .707 r
F P
0 g
s
.66161 .63273 m .66161 .59568 L .68566 .59003 L p .707 .577 .707 r
F P
0 g
s
.35915 .70316 m .35915 .68463 L .33169 .68024 L p .707 .577 .707 r
F P
0 g
s
.66161 .67844 m .66161 .69697 L .64524 .70434 L p .707 .577 .707 r
F P
0 g
s
.68566 .57972 m .68566 .52413 L .71504 .52075 L p .707 .577 .707 r
F P
0 g
s
.31064 .59102 m .31064 .62807 L .33169 .63453 L p .707 .577 .707 r
F P
0 g
s
.33169 .68024 m .33169 .69877 L .35915 .70316 L p .707 .577 .707 r
F P
0 g
s
.47559 .59396 m .47559 .63101 L .49196 .62365 L p .707 .577 .707 r
F P
0 g
s
.49196 .62365 m .49196 .58659 L .47559 .59396 L p .707 .577 .707 r
F P
0 g
s
.45154 .68238 m .45154 .7009 L .47559 .69525 L p .707 .577 .707 r
F P
0 g
s
.47559 .69525 m .47559 .67673 L .45154 .68238 L p .707 .577 .707 r
F P
0 g
s
.77805 .52188 m .77805 .57746 L .74688 .57556 L p .707 .577 .707 r
F P
0 g
s
.74688 .57556 m .74688 .51998 L .77805 .52188 L p .707 .577 .707 r
F P
0 g
s
.68566 .59003 m .68566 .62708 L .66161 .63273 L p .707 .577 .707 r
F P
0 g
s
.82657 .68138 m .82657 .69991 L .80551 .69346 L p .707 .577 .707 r
F P
0 g
s
.80551 .69346 m .80551 .67493 L .82657 .68138 L p .707 .577 .707 r
F P
0 g
s
.80551 .59216 m .80551 .62922 L .77805 .62483 L p .707 .577 .707 r
F P
0 g
s
.77805 .62483 m .77805 .58777 L .80551 .59216 L p .707 .577 .707 r
F P
0 g
s
.29804 .51724 m .29804 .57282 L .31064 .58071 L p .707 .577 .707 r
F P
0 g
s
.71504 .57634 m .71504 .52075 L .74688 .51998 L p .707 .577 .707 r
F P
0 g
s
.71504 .52075 m .71504 .57634 L .68566 .57972 L p .707 .577 .707 r
F P
0 g
s
.49196 .5207 m .49196 .57628 L .49904 .56792 L p .707 .577 .707 r
F P
0 g
s
.49904 .56792 m .49904 .51233 L .49196 .5207 L p .707 .577 .707 r
F P
0 g
s
.33169 .69877 m .33169 .68024 L .31064 .67379 L p .707 .577 .707 r
F P
0 g
s
.31064 .62807 m .31064 .59102 L .29804 .58313 L p .707 .577 .707 r
F P
0 g
s
.74688 .51998 m .74688 .57556 L .71504 .57634 L p .707 .577 .707 r
F P
0 g
s
.68566 .62708 m .68566 .59003 L .71504 .58665 L p .707 .577 .707 r
F P
0 g
s
.31064 .67379 m .31064 .69231 L .33169 .69877 L p .707 .577 .707 r
F P
0 g
s
.66161 .69697 m .66161 .67844 L .68566 .67279 L p .707 .577 .707 r
F P
0 g
s
.29804 .57282 m .29804 .51724 L .29515 .5087 L p .707 .577 .707 r
F P
0 g
s
.29804 .58313 m .29804 .62019 L .31064 .62807 L p .707 .577 .707 r
F P
0 g
s
.68566 .67279 m .68566 .69132 L .66161 .69697 L p .707 .577 .707 r
F P
0 g
s
.77805 .58777 m .77805 .62483 L .74688 .62292 L p .707 .577 .707 r
F P
0 g
s
.74688 .62292 m .74688 .58587 L .77805 .58777 L p .707 .577 .707 r
F P
0 g
s
.47559 .67673 m .47559 .69525 L .49196 .68789 L p .707 .577 .707 r
F P
0 g
s
.49196 .68789 m .49196 .66936 L .47559 .67673 L p .707 .577 .707 r
F P
0 g
s
.71504 .58665 m .71504 .6237 L .68566 .62708 L p .707 .577 .707 r
F P
0 g
s
.71504 .6237 m .71504 .58665 L .74688 .58587 L p .707 .577 .707 r
F P
0 g
s
.49196 .58659 m .49196 .62365 L .49904 .61528 L p .707 .577 .707 r
F P
0 g
s
.49904 .61528 m .49904 .57823 L .49196 .58659 L p .707 .577 .707 r
F P
0 g
s
.74688 .58587 m .74688 .62292 L .71504 .6237 L p .707 .577 .707 r
F P
0 g
s
.80551 .67493 m .80551 .69346 L .77805 .68906 L p .707 .577 .707 r
F P
0 g
s
.77805 .68906 m .77805 .67054 L .80551 .67493 L p .707 .577 .707 r
F P
0 g
s
.31064 .69231 m .31064 .67379 L .29804 .6659 L p .707 .577 .707 r
F P
0 g
s
.29515 .5087 m .29515 .56428 L .29804 .57282 L p .707 .577 .707 r
F P
0 g
s
.68566 .69132 m .68566 .67279 L .71504 .66941 L p .707 .577 .707 r
F P
0 g
s
.49904 .51233 m .49904 .56792 L .49615 .55937 L p .707 .577 .707 r
F P
0 g
s
.49615 .55937 m .49615 .50379 L .49904 .51233 L p .707 .577 .707 r
F P
0 g
s
.29804 .6659 m .29804 .68443 L .31064 .69231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62019 m .29804 .58313 L .29515 .57459 L p .707 .577 .707 r
F P
0 g
s
.71504 .66941 m .71504 .68794 L .68566 .69132 L p .707 .577 .707 r
F P
0 g
s
.77805 .67054 m .77805 .68906 L .74688 .68716 L p .707 .577 .707 r
F P
0 g
s
.74688 .68716 m .74688 .66864 L .77805 .67054 L p .707 .577 .707 r
F P
0 g
s
.29515 .57459 m .29515 .61165 L .29804 .62019 L p .707 .577 .707 r
F P
0 g
s
.71504 .68794 m .71504 .66941 L .74688 .66864 L p .707 .577 .707 r
F P
0 g
s
.49196 .66936 m .49196 .68789 L .49904 .67952 L p .707 .577 .707 r
F P
0 g
s
.49904 .67952 m .49904 .66099 L .49196 .66936 L p .707 .577 .707 r
F P
0 g
s
.29515 .56428 m .29515 .5087 L .30223 .50033 L p .707 .577 .707 r
F P
0 g
s
.74688 .66864 m .74688 .68716 L .71504 .68794 L p .707 .577 .707 r
F P
0 g
s
.49904 .57823 m .49904 .61528 L .49615 .60674 L p .707 .577 .707 r
F P
0 g
s
.49615 .60674 m .49615 .56969 L .49904 .57823 L p .707 .577 .707 r
F P
0 g
s
.29804 .68443 m .29804 .6659 L .29515 .65736 L p .707 .577 .707 r
F P
0 g
s
.30223 .50033 m .30223 .55592 L .29515 .56428 L p .707 .577 .707 r
F P
0 g
s
.29515 .65736 m .29515 .67589 L .29804 .68443 L p .707 .577 .707 r
F P
0 g
s
.49615 .50379 m .49615 .55937 L .48356 .55149 L p .707 .577 .707 r
F P
0 g
s
.48356 .55149 m .48356 .49591 L .49615 .50379 L p .707 .577 .707 r
F P
0 g
s
.29515 .61165 m .29515 .57459 L .30223 .56623 L p .707 .577 .707 r
F P
0 g
s
.49904 .66099 m .49904 .67952 L .49615 .67098 L p .707 .577 .707 r
F P
0 g
s
.49615 .67098 m .49615 .65245 L .49904 .66099 L p .707 .577 .707 r
F P
0 g
s
.30223 .56623 m .30223 .60328 L .29515 .61165 L p .707 .577 .707 r
F P
0 g
s
.30223 .55592 m .30223 .50033 L .3186 .49297 L p .707 .577 .707 r
F P
0 g
s
.49615 .56969 m .49615 .60674 L .48356 .59886 L p .707 .577 .707 r
F P
0 g
s
.48356 .59886 m .48356 .5618 L .49615 .56969 L p .707 .577 .707 r
F P
0 g
s
.29515 .67589 m .29515 .65736 L .30223 .64899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49297 m .3186 .54855 L .30223 .55592 L p .707 .577 .707 r
F P
0 g
s
.48356 .49591 m .48356 .55149 L .4625 .54504 L p .707 .577 .707 r
F P
0 g
s
.4625 .54504 m .4625 .48945 L .48356 .49591 L p .707 .577 .707 r
F P
0 g
s
.30223 .64899 m .30223 .66752 L .29515 .67589 L p .707 .577 .707 r
F P
0 g
s
.30223 .60328 m .30223 .56623 L .3186 .55886 L p .707 .577 .707 r
F P
0 g
s
.3186 .54855 m .3186 .49297 L .34265 .48732 L p .707 .577 .707 r
F P
0 g
s
.3186 .55886 m .3186 .59591 L .30223 .60328 L p .707 .577 .707 r
F P
0 g
s
.49615 .65245 m .49615 .67098 L .48356 .6631 L p .707 .577 .707 r
F P
0 g
s
.48356 .6631 m .48356 .64457 L .49615 .65245 L p .707 .577 .707 r
F P
0 g
s
.48356 .5618 m .48356 .59886 L .4625 .5924 L p .707 .577 .707 r
F P
0 g
s
.4625 .5924 m .4625 .55535 L .48356 .5618 L p .707 .577 .707 r
F P
0 g
s
.4625 .48945 m .4625 .54504 L .43504 .54064 L p .707 .577 .707 r
F P
0 g
s
.43504 .54064 m .43504 .48506 L .4625 .48945 L p .707 .577 .707 r
F P
0 g
s
.30223 .66752 m .30223 .64899 L .3186 .64163 L p .707 .577 .707 r
F P
0 g
s
.34265 .48732 m .34265 .5429 L .3186 .54855 L p .707 .577 .707 r
F P
0 g
s
.3186 .59591 m .3186 .55886 L .34265 .55321 L p .707 .577 .707 r
F P
0 g
s
.3186 .64163 m .3186 .66015 L .30223 .66752 L p .707 .577 .707 r
F P
0 g
s
.34265 .5429 m .34265 .48732 L .37203 .48394 L p .707 .577 .707 r
F P
0 g
s
.43504 .48506 m .43504 .54064 L .40387 .53874 L p .707 .577 .707 r
F P
0 g
s
.40387 .53874 m .40387 .48316 L .43504 .48506 L p .707 .577 .707 r
F P
0 g
s
.34265 .55321 m .34265 .59027 L .3186 .59591 L p .707 .577 .707 r
F P
0 g
s
.48356 .64457 m .48356 .6631 L .4625 .65664 L p .707 .577 .707 r
F P
0 g
s
.4625 .65664 m .4625 .63811 L .48356 .64457 L p .707 .577 .707 r
F P
0 g
s
.4625 .55535 m .4625 .5924 L .43504 .58801 L p .707 .577 .707 r
F P
0 g
s
.43504 .58801 m .43504 .55095 L .4625 .55535 L p .707 .577 .707 r
F P
0 g
s
.37203 .53952 m .37203 .48394 L .40387 .48316 L p .707 .577 .707 r
F P
0 g
s
.37203 .48394 m .37203 .53952 L .34265 .5429 L p .707 .577 .707 r
F P
0 g
s
.40387 .48316 m .40387 .53874 L .37203 .53952 L p .707 .577 .707 r
F P
0 g
s
.34265 .59027 m .34265 .55321 L .37203 .54983 L p .707 .577 .707 r
F P
0 g
s
.3186 .66015 m .3186 .64163 L .34265 .63598 L p .707 .577 .707 r
F P
0 g
s
.34265 .63598 m .34265 .6545 L .3186 .66015 L p .707 .577 .707 r
F P
0 g
s
.43504 .55095 m .43504 .58801 L .40387 .58611 L p .707 .577 .707 r
F P
0 g
s
.40387 .58611 m .40387 .54905 L .43504 .55095 L p .707 .577 .707 r
F P
0 g
s
.37203 .54983 m .37203 .58689 L .34265 .59027 L p .707 .577 .707 r
F P
0 g
s
.37203 .58689 m .37203 .54983 L .40387 .54905 L p .707 .577 .707 r
F P
0 g
s
.40387 .54905 m .40387 .58611 L .37203 .58689 L p .707 .577 .707 r
F P
0 g
s
.4625 .63811 m .4625 .65664 L .43504 .65225 L p .707 .577 .707 r
F P
0 g
s
.43504 .65225 m .43504 .63372 L .4625 .63811 L p .707 .577 .707 r
F P
0 g
s
.34265 .6545 m .34265 .63598 L .37203 .6326 L p .707 .577 .707 r
F P
0 g
s
.37203 .6326 m .37203 .65113 L .34265 .6545 L p .707 .577 .707 r
F P
0 g
s
.43504 .63372 m .43504 .65225 L .40387 .65035 L p .707 .577 .707 r
F P
0 g
s
.40387 .65035 m .40387 .63182 L .43504 .63372 L p .707 .577 .707 r
F P
0 g
s
.37203 .65113 m .37203 .6326 L .40387 .63182 L p .707 .577 .707 r
F P
0 g
s
.40387 .63182 m .40387 .65035 L .37203 .65113 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUH00000JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000J7oo
001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo60001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<0
05YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQT00003FUH0
05YF00AJEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP04001JEUYF0002
FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00L005YF000005YF001JEP040003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003
FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P0000=JEP0000000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000o
OolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000b
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
0002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPL0009JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH01000FUIJEP00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00
15YF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH3000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP06001JEP00001JEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P00
00EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP@00003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P00
0eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0004FUH300000eYF
001JEP06FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH40003FUH00`00FUIJEP020004
OolB0007Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPL0
00MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEPP00003FUH005YF00@000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP80009JEPH000=JEP03001oogoo01Aoo`L000=JEP<000=JEP80
02eoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP04001JEUYFFUH90009Ool90003FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00
;Goo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUHG0003FUH30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eo
o`00;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`8000=JEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000=JEPD000AJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
1@001UYF6`0000=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH30002FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EPD00003FUH0000000D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP80
00=JEP03001JEP00008000EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH000030002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPD000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH40006FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000bOol002aoo`03001JEP0000AJEP04001JEUYFFUHN0003FUH00`00FUIJEP03FUH01000
FUIJEUYF200015YF1@001EYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP80035oo`00;7oo00<005YF00000eYF1@007Woo0P0000=JEP00FUH015YF00<005YFFUH0
1EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool01000FUH005YF0P00
15YF1@006goo100015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001JEUYFFUH0
000^Ool002aoo`06001JEP00001JEP001EYF00@005YFFUIJEQ/000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009J
EP@00003FUH007oo01Uoo`<000AJEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH30005
FUH00`00FUIJEP03000MOol300000eYF001JEP02FUH2000]Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000L000AJEP03001JEUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00008Goo0P000eYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YF00004P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol200000eYF0000000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Goo0P0000AJEP00000002eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH300000eYF001JEP04FUH01000FUIJEUYF0P007Woo0`000eYF0`00;Goo000^Ool200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH01@000UYF00@005YFFUIJEP8000Qoo`<000moo`@00003FUH005YF00=JEP03
001JEP0002eoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUH000030002FUH20007Ool50009Ool5
0005FUH00`00FUIJEP02FUH2000^Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEPT00003
FUH005YF00IJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool003Ioo`D000AJEPP000AJEP03001JEUYF009JEPP00003FUH005YF00@000Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo
000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00006P00?goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool20004FUH01000FUIJEUYF20006Goo1P0015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00;7oo00<005YF00000eYF1@009goo0`0000EJ
EP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05Aoo`00;7oo00@005YF001JEP8002moo`80
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP02001GOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`@003Ao
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH4001KOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H005moo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF1000GGoo000/
Ool20003FUH00`00FUIJEP02FUH5000=Ool3000@Ool400000eYF001JEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04001IOol002eo
o`05001JEUYFFUH00005FUH01000FUIJEUYF200017oo1@002Woo1@001EYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=J
EP8005Qoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF5@00
1UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YF000005Ioo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000eYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YF
FUH000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJ
EPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`D000AJEP05001JEUYFFUH0
001EOol003Aoo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
00Yoo`04001JEUYF0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2
001DOol003eooaT000moo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH0000<Ool200000eYF
0000001DOol006Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF000037oo
1@00E7oo001UOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`09
Ool20002FUH3001DOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH007oo00Eoo`@000AJEP03001JEP0005Aoo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF0P0000=JEP0000001@000eYF00<005YFFUH00UYF0P00EGoo001UOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001U
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00AJEP04001JEP00001HOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0000=JEP04001JEUYFFUH5001JOol006Ioo`03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP800003FUH0000000D005moo`00Igoo0P000UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF1000IWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
0000K7oo001]Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH4001^Ool0075oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF1@00Mgoo001lOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP06001lOol008Eo
oaH0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77668 m .59613 .7211 L .56496 .7192 L p .707 .577 .707 r
F P
0 g
s
.59613 .7211 m .59613 .77668 L .62796 .77591 L p .707 .577 .707 r
F P
0 g
s
.62796 .77591 m .62796 .72032 L .59613 .7211 L p .707 .577 .707 r
F P
0 g
s
.62796 .72032 m .62796 .77591 L .65735 .77253 L p .707 .577 .707 r
F P
0 g
s
.65735 .77253 m .65734 .71694 L .62796 .72032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77478 m .56496 .7192 L .5375 .71481 L p .707 .577 .707 r
F P
0 g
s
.56496 .7192 m .56496 .77478 L .59613 .77668 L p .707 .577 .707 r
F P
0 g
s
.65734 .71694 m .65735 .77253 L .6814 .76688 L p .707 .577 .707 r
F P
0 g
s
.6814 .76688 m .6814 .71129 L .65734 .71694 L p .707 .577 .707 r
F P
0 g
s
.5375 .71481 m .5375 .77039 L .56496 .77478 L p .707 .577 .707 r
F P
0 g
s
.5375 .77039 m .5375 .71481 L .51644 .70835 L p .707 .577 .707 r
F P
0 g
s
.59613 .85004 m .59613 .81299 L .56496 .81109 L p .707 .577 .707 r
F P
0 g
s
.59613 .81299 m .59613 .85004 L .62796 .84926 L p .707 .577 .707 r
F P
0 g
s
.62796 .84926 m .62796 .81221 L .59613 .81299 L p .707 .577 .707 r
F P
0 g
s
.62796 .81221 m .62796 .84926 L .65735 .84589 L p .707 .577 .707 r
F P
0 g
s
.65735 .84589 m .65735 .80883 L .62796 .81221 L p .707 .577 .707 r
F P
0 g
s
.56496 .84814 m .56496 .81109 L .5375 .80669 L p .707 .577 .707 r
F P
0 g
s
.56496 .81109 m .56496 .84814 L .59613 .85004 L p .707 .577 .707 r
F P
0 g
s
.6814 .71129 m .6814 .76688 L .69777 .75951 L p .707 .577 .707 r
F P
0 g
s
.69777 .75951 m .69777 .70393 L .6814 .71129 L p .707 .577 .707 r
F P
0 g
s
.59613 .86947 m .59613 .85094 L .56496 .84904 L p .707 .577 .707 r
F P
0 g
s
.59613 .85094 m .59613 .86947 L .62796 .86869 L p .707 .577 .707 r
F P
0 g
s
.62796 .86869 m .62796 .85017 L .59613 .85094 L p .707 .577 .707 r
F P
0 g
s
.51644 .70835 m .51644 .76394 L .5375 .77039 L p .707 .577 .707 r
F P
0 g
s
.62796 .85017 m .62796 .86869 L .65735 .86532 L p .707 .577 .707 r
F P
0 g
s
.65735 .86532 m .65735 .84679 L .62796 .85017 L p .707 .577 .707 r
F P
0 g
s
.65735 .80883 m .65735 .84589 L .6814 .84024 L p .707 .577 .707 r
F P
0 g
s
.6814 .84024 m .6814 .80318 L .65735 .80883 L p .707 .577 .707 r
F P
0 g
s
.56496 .84904 m .56496 .86757 L .59613 .86947 L p .707 .577 .707 r
F P
0 g
s
.5375 .80669 m .5375 .84375 L .56496 .84814 L p .707 .577 .707 r
F P
0 g
s
.56496 .86757 m .56496 .84904 L .5375 .84465 L p .707 .577 .707 r
F P
0 g
s
.51644 .76394 m .51644 .70835 L .50385 .70047 L p .707 .577 .707 r
F P
0 g
s
.5375 .84465 m .5375 .86318 L .56496 .86757 L p .707 .577 .707 r
F P
0 g
s
.5375 .84375 m .5375 .80669 L .51644 .80024 L p .707 .577 .707 r
F P
0 g
s
.65735 .84679 m .65735 .86532 L .6814 .85967 L p .707 .577 .707 r
F P
0 g
s
.6814 .85967 m .6814 .84114 L .65735 .84679 L p .707 .577 .707 r
F P
0 g
s
.51644 .80024 m .51644 .83729 L .5375 .84375 L p .707 .577 .707 r
F P
0 g
s
.5375 .86318 m .5375 .84465 L .51644 .8382 L p .707 .577 .707 r
F P
0 g
s
.6814 .80318 m .6814 .84024 L .69777 .83287 L p .707 .577 .707 r
F P
0 g
s
.69777 .83287 m .69777 .79581 L .6814 .80318 L p .707 .577 .707 r
F P
0 g
s
.50385 .70047 m .50385 .75605 L .51644 .76394 L p .707 .577 .707 r
F P
0 g
s
.69777 .70393 m .69777 .75951 L .70485 .75114 L p .707 .577 .707 r
F P
0 g
s
.70485 .75114 m .70485 .69556 L .69777 .70393 L p .707 .577 .707 r
F P
0 g
s
.51644 .8382 m .51644 .85673 L .5375 .86318 L p .707 .577 .707 r
F P
0 g
s
.51644 .83729 m .51644 .80024 L .50385 .79236 L p .707 .577 .707 r
F P
0 g
s
.6814 .84114 m .6814 .85967 L .69777 .8523 L p .707 .577 .707 r
F P
0 g
s
.69777 .8523 m .69777 .83377 L .6814 .84114 L p .707 .577 .707 r
F P
0 g
s
.50385 .75605 m .50385 .70047 L .50095 .69193 L p .707 .577 .707 r
F P
0 g
s
.50385 .79236 m .50385 .82941 L .51644 .83729 L p .707 .577 .707 r
F P
0 g
s
.51644 .85673 m .51644 .8382 L .50385 .83031 L p .707 .577 .707 r
F P
0 g
s
.49044 .78751 m .49044 .28562 L .44643 .28294 L p .707 .577 .707 r
F P
0 g
s
.50095 .69193 m .50095 .74751 L .50385 .75605 L p .707 .577 .707 r
F P
0 g
s
.50385 .82941 m .50385 .79236 L .50095 .78381 L p .707 .577 .707 r
F P
0 g
s
.50095 .74751 m .50095 .69193 L .50804 .68356 L p .707 .577 .707 r
F P
0 g
s
.50095 .78381 m .50095 .82087 L .50385 .82941 L p .707 .577 .707 r
F P
0 g
s
.50804 .68356 m .50804 .73915 L .50095 .74751 L p .707 .577 .707 r
F P
0 g
s
.50095 .82087 m .50095 .78381 L .50804 .77545 L p .707 .577 .707 r
F P
0 g
s
.50804 .73915 m .50804 .68356 L .5244 .6762 L p .707 .577 .707 r
F P
0 g
s
.50804 .77545 m .50804 .8125 L .50095 .82087 L p .707 .577 .707 r
F P
0 g
s
.5244 .6762 m .5244 .73178 L .50804 .73915 L p .707 .577 .707 r
F P
0 g
s
.50804 .8125 m .50804 .77545 L .5244 .76808 L p .707 .577 .707 r
F P
0 g
s
.5244 .73178 m .5244 .6762 L .54846 .67055 L p .707 .577 .707 r
F P
0 g
s
.5244 .76808 m .5244 .80514 L .50804 .8125 L p .707 .577 .707 r
F P
0 g
s
.54846 .67055 m .54846 .72613 L .5244 .73178 L p .707 .577 .707 r
F P
0 g
s
.5244 .80514 m .5244 .76808 L .54846 .76243 L p .707 .577 .707 r
F P
0 g
s
.54846 .76243 m .54846 .79949 L .5244 .80514 L p .707 .577 .707 r
F P
0 g
s
.49044 .28562 m .49044 .78751 L .53538 .78641 L p .707 .577 .707 r
F P
0 g
s
.53538 .78641 m .53538 .28452 L .49044 .28562 L p .707 .577 .707 r
F P
0 g
s
.50385 .83031 m .50385 .84884 L .51644 .85673 L p .707 .577 .707 r
F P
0 g
s
.69777 .79581 m .69777 .83287 L .70485 .8245 L p .707 .577 .707 r
F P
0 g
s
.70485 .8245 m .70485 .78745 L .69777 .79581 L p .707 .577 .707 r
F P
0 g
s
.54846 .72613 m .54846 .67055 L .57784 .66717 L p .707 .577 .707 r
F P
0 g
s
.57784 .66717 m .57784 .72275 L .54846 .72613 L p .707 .577 .707 r
F P
0 g
s
.54846 .79949 m .54846 .76243 L .57784 .75905 L p .707 .577 .707 r
F P
0 g
s
.57784 .75905 m .57784 .79611 L .54846 .79949 L p .707 .577 .707 r
F P
0 g
s
.53538 .28452 m .53538 .78641 L .57686 .78164 L p .707 .577 .707 r
F P
0 g
s
.57686 .78164 m .57686 .27975 L .53538 .28452 L p .707 .577 .707 r
F P
0 g
s
.70485 .69556 m .70485 .75114 L .70195 .7426 L p .707 .577 .707 r
F P
0 g
s
.70195 .7426 m .70195 .68702 L .70485 .69556 L p .707 .577 .707 r
F P
0 g
s
.44643 .78482 m .44643 .28294 L .40766 .27673 L p .707 .577 .707 r
F P
0 g
s
.44643 .28294 m .44643 .78482 L .49044 .78751 L p .707 .577 .707 r
F P
0 g
s
.69777 .83377 m .69777 .8523 L .70485 .84393 L p .707 .577 .707 r
F P
0 g
s
.70485 .84393 m .70485 .82541 L .69777 .83377 L p .707 .577 .707 r
F P
0 g
s
.57784 .72275 m .57784 .66717 L .60968 .66639 L p .707 .577 .707 r
F P
0 g
s
.60968 .66639 m .60968 .72197 L .57784 .72275 L p .707 .577 .707 r
F P
0 g
s
.60968 .79533 m .60968 .75828 L .64085 .76018 L p .707 .577 .707 r
F P
0 g
s
.57784 .79611 m .57784 .75905 L .60968 .75828 L p .707 .577 .707 r
F P
0 g
s
.60968 .75828 m .60968 .79533 L .57784 .79611 L p .707 .577 .707 r
F P
0 g
s
.57686 .27975 m .57686 .78164 L .61082 .77366 L p .707 .577 .707 r
F P
0 g
s
.64085 .66829 m .64085 .72387 L .60968 .72197 L p .707 .577 .707 r
F P
0 g
s
.60968 .72197 m .60968 .66639 L .64085 .66829 L p .707 .577 .707 r
F P
0 g
s
.61082 .77366 m .61082 .27177 L .57686 .27975 L p .707 .577 .707 r
F P
0 g
s
.50385 .84884 m .50385 .83031 L .50095 .82177 L p .707 .577 .707 r
F P
0 g
s
.50095 .82177 m .50095 .8403 L .50385 .84884 L p .707 .577 .707 r
F P
0 g
s
.40766 .77862 m .40766 .27673 L .37794 .26762 L p .707 .577 .707 r
F P
0 g
s
.40766 .27673 m .40766 .77862 L .44643 .78482 L p .707 .577 .707 r
F P
0 g
s
.70485 .78745 m .70485 .8245 L .70195 .81596 L p .707 .577 .707 r
F P
0 g
s
.70195 .81596 m .70195 .77891 L .70485 .78745 L p .707 .577 .707 r
F P
0 g
s
.70195 .68702 m .70195 .7426 L .68936 .73472 L p .707 .577 .707 r
F P
0 g
s
.68936 .73472 m .68936 .67914 L .70195 .68702 L p .707 .577 .707 r
F P
0 g
s
.70485 .82541 m .70485 .84393 L .70195 .83539 L p .707 .577 .707 r
F P
0 g
s
.70195 .83539 m .70195 .81686 L .70485 .82541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25312 .73987 m .25312 .68429 L .22195 .68238 L p .707 .577 .707 r
F P
0 g
s
.25312 .68429 m .25312 .73987 L .28495 .73909 L p .707 .577 .707 r
F P
0 g
s
.28495 .73909 m .28495 .68351 L .25312 .68429 L p .707 .577 .707 r
F P
0 g
s
.61082 .27177 m .61082 .77366 L .63393 .76326 L p .707 .577 .707 r
F P
0 g
s
.63393 .76326 m .63393 .26137 L .61082 .27177 L p .707 .577 .707 r
F P
0 g
s
.28495 .68351 m .28495 .73909 L .31434 .73571 L p .707 .577 .707 r
F P
0 g
s
.31434 .73571 m .31434 .68013 L .28495 .68351 L p .707 .577 .707 r
F P
0 g
s
.22195 .73797 m .22195 .68238 L .19449 .67799 L p .707 .577 .707 r
F P
0 g
s
.22195 .68238 m .22195 .73797 L .25312 .73987 L p .707 .577 .707 r
F P
0 g
s
.50095 .8403 m .50095 .82177 L .50804 .81341 L p .707 .577 .707 r
F P
0 g
s
.50804 .81341 m .50804 .83193 L .50095 .8403 L p .707 .577 .707 r
F P
0 g
s
.31434 .68013 m .31434 .73571 L .33839 .73006 L p .707 .577 .707 r
F P
0 g
s
.33839 .73006 m .33839 .67448 L .31434 .68013 L p .707 .577 .707 r
F P
0 g
s
.70195 .77891 m .70195 .81596 L .68936 .80808 L p .707 .577 .707 r
F P
0 g
s
.68936 .80808 m .68936 .77102 L .70195 .77891 L p .707 .577 .707 r
F P
0 g
s
.37794 .76951 m .37794 .26762 L .36016 .25649 L p .707 .577 .707 r
F P
0 g
s
.37794 .26762 m .37794 .76951 L .40766 .77862 L p .707 .577 .707 r
F P
0 g
s
.68936 .67914 m .68936 .73472 L .66831 .72826 L p .707 .577 .707 r
F P
0 g
s
.66831 .72826 m .66831 .67268 L .68936 .67914 L p .707 .577 .707 r
F P
0 g
s
.19449 .67799 m .19449 .73357 L .22195 .73797 L p .707 .577 .707 r
F P
0 g
s
.19449 .73357 m .19449 .67799 L .17343 .67154 L p .707 .577 .707 r
F P
0 g
s
.25312 .81323 m .25312 .77617 L .22195 .77427 L p .707 .577 .707 r
F P
0 g
s
.25312 .77617 m .25312 .81323 L .28495 .81245 L p .707 .577 .707 r
F P
0 g
s
.28495 .81245 m .28495 .77539 L .25312 .77617 L p .707 .577 .707 r
F P
0 g
s
.70195 .81686 m .70195 .83539 L .68936 .82751 L p .707 .577 .707 r
F P
0 g
s
.68936 .82751 m .68936 .80898 L .70195 .81686 L p .707 .577 .707 r
F P
0 g
s
.28495 .77539 m .28495 .81245 L .31434 .80907 L p .707 .577 .707 r
F P
0 g
s
.31434 .80907 m .31434 .77202 L .28495 .77539 L p .707 .577 .707 r
F P
0 g
s
.22195 .81133 m .22195 .77427 L .19449 .76988 L p .707 .577 .707 r
F P
0 g
s
.22195 .77427 m .22195 .81133 L .25312 .81323 L p .707 .577 .707 r
F P
0 g
s
.33839 .67448 m .33839 .73006 L .35476 .72269 L p .707 .577 .707 r
F P
0 g
s
.35476 .72269 m .35476 .66711 L .33839 .67448 L p .707 .577 .707 r
F P
0 g
s
.25312 .83266 m .25312 .81413 L .22195 .81223 L p .707 .577 .707 r
F P
0 g
s
.25312 .81413 m .25312 .83266 L .28495 .83188 L p .707 .577 .707 r
F P
0 g
s
.28495 .83188 m .28495 .81335 L .25312 .81413 L p .707 .577 .707 r
F P
0 g
s
.17343 .67154 m .17343 .72712 L .19449 .73357 L p .707 .577 .707 r
F P
0 g
s
.50804 .83193 m .50804 .81341 L .5244 .80604 L p .707 .577 .707 r
F P
0 g
s
.28495 .81335 m .28495 .83188 L .31434 .8285 L p .707 .577 .707 r
F P
0 g
s
.31434 .8285 m .31434 .80997 L .28495 .81335 L p .707 .577 .707 r
F P
0 g
s
.66831 .67268 m .66831 .72826 L .64085 .72387 L p .707 .577 .707 r
F P
0 g
s
.64085 .72387 m .64085 .66829 L .66831 .67268 L p .707 .577 .707 r
F P
0 g
s
.63393 .26137 m .63393 .76326 L .64393 .75145 L p .707 .577 .707 r
F P
0 g
s
.64393 .75145 m .64393 .24956 L .63393 .26137 L p .707 .577 .707 r
F P
0 g
s
.31434 .77202 m .31434 .80907 L .33839 .80342 L p .707 .577 .707 r
F P
0 g
s
.33839 .80342 m .33839 .76637 L .31434 .77202 L p .707 .577 .707 r
F P
0 g
s
.22195 .81223 m .22195 .83076 L .25312 .83266 L p .707 .577 .707 r
F P
0 g
s
.19449 .76988 m .19449 .80693 L .22195 .81133 L p .707 .577 .707 r
F P
0 g
s
.22195 .83076 m .22195 .81223 L .19449 .80784 L p .707 .577 .707 r
F P
0 g
s
.5244 .80604 m .5244 .82457 L .50804 .83193 L p .707 .577 .707 r
F P
0 g
s
.68936 .77102 m .68936 .80808 L .66831 .80162 L p .707 .577 .707 r
F P
0 g
s
.66831 .80162 m .66831 .76457 L .68936 .77102 L p .707 .577 .707 r
F P
0 g
s
.17343 .72712 m .17343 .67154 L .16084 .66365 L p .707 .577 .707 r
F P
0 g
s
.19449 .80784 m .19449 .82636 L .22195 .83076 L p .707 .577 .707 r
F P
0 g
s
.19449 .80693 m .19449 .76988 L .17343 .76342 L p .707 .577 .707 r
F P
0 g
s
.31434 .80997 m .31434 .8285 L .33839 .82285 L p .707 .577 .707 r
F P
0 g
s
.33839 .82285 m .33839 .80432 L .31434 .80997 L p .707 .577 .707 r
F P
0 g
s
.68936 .80898 m .68936 .82751 L .66831 .82105 L p .707 .577 .707 r
F P
0 g
s
.66831 .82105 m .66831 .80253 L .68936 .80898 L p .707 .577 .707 r
F P
0 g
s
.35476 .66711 m .35476 .72269 L .36184 .71433 L p .707 .577 .707 r
F P
0 g
s
.36184 .71433 m .36184 .65875 L .35476 .66711 L p .707 .577 .707 r
F P
0 g
s
.36184 .78769 m .36184 .75063 L .35476 .759 L p .707 .577 .707 r
F P
0 g
s
.36184 .65875 m .36184 .71433 L .35894 .70579 L p .707 .577 .707 r
F P
0 g
s
.35894 .70579 m .35894 .65021 L .36184 .65875 L p .707 .577 .707 r
F P
0 g
s
.35476 .759 m .35476 .79605 L .36184 .78769 L p .707 .577 .707 r
F P
0 g
s
.35894 .77915 m .35894 .74209 L .36184 .75063 L p .707 .577 .707 r
F P
0 g
s
.36016 .75838 m .36016 .25649 L .35607 .24443 L p .707 .577 .707 r
F P
0 g
s
.36184 .75063 m .36184 .78769 L .35894 .77915 L p .707 .577 .707 r
F P
0 g
s
.36016 .25649 m .36016 .75838 L .37794 .76951 L p .707 .577 .707 r
F P
0 g
s
.17343 .76342 m .17343 .80048 L .19449 .80693 L p .707 .577 .707 r
F P
0 g
s
.19449 .82636 m .19449 .80784 L .17343 .80138 L p .707 .577 .707 r
F P
0 g
s
.33839 .76637 m .33839 .80342 L .35476 .79605 L p .707 .577 .707 r
F P
0 g
s
.35476 .79605 m .35476 .759 L .33839 .76637 L p .707 .577 .707 r
F P
0 g
s
.16084 .66365 m .16084 .71924 L .17343 .72712 L p .707 .577 .707 r
F P
0 g
s
.17343 .80138 m .17343 .81991 L .19449 .82636 L p .707 .577 .707 r
F P
0 g
s
.5244 .82457 m .5244 .80604 L .54846 .80039 L p .707 .577 .707 r
F P
0 g
s
.66831 .76457 m .66831 .80162 L .64085 .79723 L p .707 .577 .707 r
F P
0 g
s
.64085 .79723 m .64085 .76018 L .66831 .76457 L p .707 .577 .707 r
F P
0 g
s
.54846 .80039 m .54846 .81892 L .5244 .82457 L p .707 .577 .707 r
F P
0 g
s
.17343 .80048 m .17343 .76342 L .16084 .75554 L p .707 .577 .707 r
F P
0 g
s
.33839 .80432 m .33839 .82285 L .35476 .81548 L p .707 .577 .707 r
F P
0 g
s
.35476 .81548 m .35476 .79696 L .33839 .80432 L p .707 .577 .707 r
F P
0 g
s
.16084 .71924 m .16084 .66365 L .15794 .65511 L p .707 .577 .707 r
F P
0 g
s
.66831 .80253 m .66831 .82105 L .64085 .81666 L p .707 .577 .707 r
F P
0 g
s
.64085 .81666 m .64085 .79813 L .66831 .80253 L p .707 .577 .707 r
F P
0 g
s
.64393 .24956 m .64393 .75145 L .63984 .73939 L p .707 .577 .707 r
F P
0 g
s
.63984 .73939 m .63984 .2375 L .64393 .24956 L p .707 .577 .707 r
F P
0 g
s
.16084 .75554 m .16084 .7926 L .17343 .80048 L p .707 .577 .707 r
F P
0 g
s
.17343 .81991 m .17343 .80138 L .16084 .7935 L p .707 .577 .707 r
F P
0 g
s
.64085 .76018 m .64085 .79723 L .60968 .79533 L p .707 .577 .707 r
F P
0 g
s
.54846 .81892 m .54846 .80039 L .57784 .79701 L p .707 .577 .707 r
F P
0 g
s
.16084 .7935 m .16084 .81203 L .17343 .81991 L p .707 .577 .707 r
F P
0 g
s
.15794 .65511 m .15794 .71069 L .16084 .71924 L p .707 .577 .707 r
F P
0 g
s
.57784 .79701 m .57784 .81554 L .54846 .81892 L p .707 .577 .707 r
F P
0 g
s
.64085 .79813 m .64085 .81666 L .60968 .81476 L p .707 .577 .707 r
F P
0 g
s
.60968 .81476 m .60968 .79623 L .64085 .79813 L p .707 .577 .707 r
F P
0 g
s
.57784 .81554 m .57784 .79701 L .60968 .79623 L p .707 .577 .707 r
F P
0 g
s
.35476 .79696 m .35476 .81548 L .36184 .80712 L p .707 .577 .707 r
F P
0 g
s
.36184 .80712 m .36184 .78859 L .35476 .79696 L p .707 .577 .707 r
F P
0 g
s
.16084 .7926 m .16084 .75554 L .15794 .747 L p .707 .577 .707 r
F P
0 g
s
.35894 .65021 m .35894 .70579 L .34635 .6979 L p .707 .577 .707 r
F P
0 g
s
.34635 .6979 m .34635 .64232 L .35894 .65021 L p .707 .577 .707 r
F P
0 g
s
.35894 .74209 m .35894 .77915 L .34635 .77126 L p .707 .577 .707 r
F P
0 g
s
.34635 .77126 m .34635 .73421 L .35894 .74209 L p .707 .577 .707 r
F P
0 g
s
.35607 .24443 m .35607 .74632 L .36016 .75838 L p .707 .577 .707 r
F P
0 g
s
.35607 .74632 m .35607 .24443 L .36607 .23262 L p .707 .577 .707 r
F P
0 g
s
.60968 .79623 m .60968 .81476 L .57784 .81554 L p .707 .577 .707 r
F P
0 g
s
.15794 .71069 m .15794 .65511 L .16503 .64675 L p .707 .577 .707 r
F P
0 g
s
.15794 .747 m .15794 .78405 L .16084 .7926 L p .707 .577 .707 r
F P
0 g
s
.16084 .81203 m .16084 .7935 L .15794 .78496 L p .707 .577 .707 r
F P
0 g
s
.15794 .78496 m .15794 .80348 L .16084 .81203 L p .707 .577 .707 r
F P
0 g
s
.16503 .64675 m .16503 .70233 L .15794 .71069 L p .707 .577 .707 r
F P
0 g
s
.63984 .2375 m .63984 .73939 L .62206 .72826 L p .707 .577 .707 r
F P
0 g
s
.62206 .72826 m .62206 .22637 L .63984 .2375 L p .707 .577 .707 r
F P
0 g
s
.36184 .78859 m .36184 .80712 L .35894 .79858 L p .707 .577 .707 r
F P
0 g
s
.35894 .79858 m .35894 .78005 L .36184 .78859 L p .707 .577 .707 r
F P
0 g
s
.15794 .78405 m .15794 .747 L .16503 .73863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70233 m .16503 .64675 L .1814 .63938 L p .707 .577 .707 r
F P
0 g
s
.16503 .73863 m .16503 .77569 L .15794 .78405 L p .707 .577 .707 r
F P
0 g
s
.15794 .80348 m .15794 .78496 L .16503 .77659 L p .707 .577 .707 r
F P
0 g
s
.36607 .73451 m .36607 .23262 L .38918 .22222 L p .707 .577 .707 r
F P
0 g
s
.36607 .23262 m .36607 .73451 L .35607 .74632 L p .707 .577 .707 r
F P
0 g
s
.16503 .77659 m .16503 .79512 L .15794 .80348 L p .707 .577 .707 r
F P
0 g
s
.1814 .63938 m .1814 .69496 L .16503 .70233 L p .707 .577 .707 r
F P
0 g
s
.34635 .64232 m .34635 .6979 L .3253 .69145 L p .707 .577 .707 r
F P
0 g
s
.3253 .69145 m .3253 .63587 L .34635 .64232 L p .707 .577 .707 r
F P
0 g
s
.35894 .78005 m .35894 .79858 L .34635 .79069 L p .707 .577 .707 r
F P
0 g
s
.34635 .79069 m .34635 .77217 L .35894 .78005 L p .707 .577 .707 r
F P
0 g
s
.16503 .77569 m .16503 .73863 L .1814 .73127 L p .707 .577 .707 r
F P
0 g
s
.1814 .69496 m .1814 .63938 L .20545 .63373 L p .707 .577 .707 r
F P
0 g
s
.62206 .22637 m .62206 .72826 L .59233 .71915 L p .707 .577 .707 r
F P
0 g
s
.59233 .71915 m .59233 .21726 L .62206 .22637 L p .707 .577 .707 r
F P
0 g
s
.1814 .73127 m .1814 .76832 L .16503 .77569 L p .707 .577 .707 r
F P
0 g
s
.16503 .79512 m .16503 .77659 L .1814 .76922 L p .707 .577 .707 r
F P
0 g
s
.3253 .63587 m .3253 .69145 L .29784 .68706 L p .707 .577 .707 r
F P
0 g
s
.29784 .68706 m .29784 .63147 L .3253 .63587 L p .707 .577 .707 r
F P
0 g
s
.1814 .76922 m .1814 .78775 L .16503 .79512 L p .707 .577 .707 r
F P
0 g
s
.34635 .73421 m .34635 .77126 L .3253 .76481 L p .707 .577 .707 r
F P
0 g
s
.3253 .76481 m .3253 .72775 L .34635 .73421 L p .707 .577 .707 r
F P
0 g
s
.20545 .63373 m .20545 .68931 L .1814 .69496 L p .707 .577 .707 r
F P
0 g
s
.38918 .22222 m .38918 .72411 L .36607 .73451 L p .707 .577 .707 r
F P
0 g
s
.38918 .72411 m .38918 .22222 L .42314 .21425 L p .707 .577 .707 r
F P
0 g
s
.20545 .68931 m .20545 .63373 L .23483 .63035 L p .707 .577 .707 r
F P
0 g
s
.1814 .76832 m .1814 .73127 L .20545 .72562 L p .707 .577 .707 r
F P
0 g
s
.34635 .77217 m .34635 .79069 L .3253 .78424 L p .707 .577 .707 r
F P
0 g
s
.3253 .78424 m .3253 .76571 L .34635 .77217 L p .707 .577 .707 r
F P
0 g
s
.29784 .63147 m .29784 .68706 L .26667 .68516 L p .707 .577 .707 r
F P
0 g
s
.26667 .68516 m .26667 .62957 L .29784 .63147 L p .707 .577 .707 r
F P
0 g
s
.23483 .68593 m .23483 .63035 L .26667 .62957 L p .707 .577 .707 r
F P
0 g
s
.23483 .63035 m .23483 .68593 L .20545 .68931 L p .707 .577 .707 r
F P
0 g
s
.26667 .62957 m .26667 .68516 L .23483 .68593 L p .707 .577 .707 r
F P
0 g
s
.20545 .72562 m .20545 .76267 L .1814 .76832 L p .707 .577 .707 r
F P
0 g
s
.1814 .78775 m .1814 .76922 L .20545 .76357 L p .707 .577 .707 r
F P
0 g
s
.59233 .21726 m .59233 .71915 L .55357 .71295 L p .707 .577 .707 r
F P
0 g
s
.55357 .71295 m .55357 .21106 L .59233 .21726 L p .707 .577 .707 r
F P
0 g
s
.73333 .68464 m .73333 .62906 L .70216 .62716 L p .707 .577 .707 r
F P
0 g
s
.73333 .62906 m .73333 .68464 L .76517 .68387 L p .707 .577 .707 r
F P
0 g
s
.76517 .68387 m .76517 .62828 L .73333 .62906 L p .707 .577 .707 r
F P
0 g
s
.3253 .72775 m .3253 .76481 L .29784 .76042 L p .707 .577 .707 r
F P
0 g
s
.29784 .76042 m .29784 .72336 L .3253 .72775 L p .707 .577 .707 r
F P
0 g
s
.76517 .62828 m .76517 .68387 L .79455 .68049 L p .707 .577 .707 r
F P
0 g
s
.79455 .68049 m .79455 .62491 L .76517 .62828 L p .707 .577 .707 r
F P
0 g
s
.20545 .76357 m .20545 .7821 L .1814 .78775 L p .707 .577 .707 r
F P
0 g
s
.70216 .68274 m .70216 .62716 L .6747 .62277 L p .707 .577 .707 r
F P
0 g
s
.70216 .62716 m .70216 .68274 L .73333 .68464 L p .707 .577 .707 r
F P
0 g
s
.20545 .76267 m .20545 .72562 L .23483 .72224 L p .707 .577 .707 r
F P
0 g
s
.42314 .71613 m .42314 .21425 L .46462 .20948 L p .707 .577 .707 r
F P
0 g
s
.42314 .21425 m .42314 .71613 L .38918 .72411 L p .707 .577 .707 r
F P
0 g
s
.3253 .76571 m .3253 .78424 L .29784 .77985 L p .707 .577 .707 r
F P
0 g
s
.29784 .77985 m .29784 .76132 L .3253 .76571 L p .707 .577 .707 r
F P
0 g
s
.79455 .62491 m .79455 .68049 L .8186 .67484 L p .707 .577 .707 r
F P
0 g
s
.8186 .67484 m .8186 .61926 L .79455 .62491 L p .707 .577 .707 r
F P
0 g
s
.29784 .72336 m .29784 .76042 L .26667 .75852 L p .707 .577 .707 r
F P
0 g
s
.26667 .75852 m .26667 .72146 L .29784 .72336 L p .707 .577 .707 r
F P
0 g
s
.23483 .72224 m .23483 .75929 L .20545 .76267 L p .707 .577 .707 r
F P
0 g
s
.20545 .7821 m .20545 .76357 L .23483 .7602 L p .707 .577 .707 r
F P
0 g
s
.23483 .75929 m .23483 .72224 L .26667 .72146 L p .707 .577 .707 r
F P
0 g
s
.55357 .21106 m .55357 .71295 L .50956 .71027 L p .707 .577 .707 r
F P
0 g
s
.50956 .71027 m .50956 .20838 L .55357 .21106 L p .707 .577 .707 r
F P
0 g
s
.6747 .62277 m .6747 .67835 L .70216 .68274 L p .707 .577 .707 r
F P
0 g
s
.6747 .67835 m .6747 .62277 L .65365 .61632 L p .707 .577 .707 r
F P
0 g
s
.26667 .72146 m .26667 .75852 L .23483 .75929 L p .707 .577 .707 r
F P
0 g
s
.23483 .7602 m .23483 .77872 L .20545 .7821 L p .707 .577 .707 r
F P
0 g
s
.73333 .758 m .73333 .72095 L .70216 .71905 L p .707 .577 .707 r
F P
0 g
s
.73333 .72095 m .73333 .758 L .76517 .75723 L p .707 .577 .707 r
F P
0 g
s
.76517 .75723 m .76517 .72017 L .73333 .72095 L p .707 .577 .707 r
F P
0 g
s
.46462 .71136 m .46462 .20948 L .50956 .20838 L p .707 .577 .707 r
F P
0 g
s
.46462 .20948 m .46462 .71136 L .42314 .71613 L p .707 .577 .707 r
F P
0 g
s
.29784 .76132 m .29784 .77985 L .26667 .77795 L p .707 .577 .707 r
F P
0 g
s
.26667 .77795 m .26667 .75942 L .29784 .76132 L p .707 .577 .707 r
F P
0 g
s
.76517 .72017 m .76517 .75723 L .79455 .75385 L p .707 .577 .707 r
F P
0 g
s
.79455 .75385 m .79455 .71679 L .76517 .72017 L p .707 .577 .707 r
F P
0 g
s
.50956 .20838 m .50956 .71027 L .46462 .71136 L p .707 .577 .707 r
F P
0 g
s
.23483 .77872 m .23483 .7602 L .26667 .75942 L p .707 .577 .707 r
F P
0 g
s
.70216 .7561 m .70216 .71905 L .6747 .71466 L p .707 .577 .707 r
F P
0 g
s
.70216 .71905 m .70216 .7561 L .73333 .758 L p .707 .577 .707 r
F P
0 g
s
.26667 .75942 m .26667 .77795 L .23483 .77872 L p .707 .577 .707 r
F P
0 g
s
.8186 .61926 m .8186 .67484 L .83497 .66747 L p .707 .577 .707 r
F P
0 g
s
.83497 .66747 m .83497 .61189 L .8186 .61926 L p .707 .577 .707 r
F P
0 g
s
.73333 .77743 m .73333 .75891 L .70216 .75701 L p .707 .577 .707 r
F P
0 g
s
.73333 .75891 m .73333 .77743 L .76517 .77666 L p .707 .577 .707 r
F P
0 g
s
.76517 .77666 m .76517 .75813 L .73333 .75891 L p .707 .577 .707 r
F P
0 g
s
.65365 .61632 m .65365 .6719 L .6747 .67835 L p .707 .577 .707 r
F P
0 g
s
.76517 .75813 m .76517 .77666 L .79455 .77328 L p .707 .577 .707 r
F P
0 g
s
.79455 .77328 m .79455 .75475 L .76517 .75813 L p .707 .577 .707 r
F P
0 g
s
.79455 .71679 m .79455 .75385 L .8186 .7482 L p .707 .577 .707 r
F P
0 g
s
.8186 .7482 m .8186 .71114 L .79455 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75701 m .70216 .77553 L .73333 .77743 L p .707 .577 .707 r
F P
0 g
s
.6747 .71466 m .6747 .75171 L .70216 .7561 L p .707 .577 .707 r
F P
0 g
s
.70216 .77553 m .70216 .75701 L .6747 .75261 L p .707 .577 .707 r
F P
0 g
s
.65365 .6719 m .65365 .61632 L .64105 .60843 L p .707 .577 .707 r
F P
0 g
s
.6747 .75261 m .6747 .77114 L .70216 .77553 L p .707 .577 .707 r
F P
0 g
s
.6747 .75171 m .6747 .71466 L .65365 .7082 L p .707 .577 .707 r
F P
0 g
s
.79455 .75475 m .79455 .77328 L .8186 .76763 L p .707 .577 .707 r
F P
0 g
s
.8186 .76763 m .8186 .7491 L .79455 .75475 L p .707 .577 .707 r
F P
0 g
s
.65365 .7082 m .65365 .74526 L .6747 .75171 L p .707 .577 .707 r
F P
0 g
s
.6747 .77114 m .6747 .75261 L .65365 .74616 L p .707 .577 .707 r
F P
0 g
s
.8186 .71114 m .8186 .7482 L .83497 .74083 L p .707 .577 .707 r
F P
0 g
s
.83497 .74083 m .83497 .70378 L .8186 .71114 L p .707 .577 .707 r
F P
0 g
s
.64105 .60843 m .64105 .66401 L .65365 .6719 L p .707 .577 .707 r
F P
0 g
s
.83497 .61189 m .83497 .66747 L .84205 .65911 L p .707 .577 .707 r
F P
0 g
s
.84205 .65911 m .84205 .60352 L .83497 .61189 L p .707 .577 .707 r
F P
0 g
s
.65365 .74616 m .65365 .76469 L .6747 .77114 L p .707 .577 .707 r
F P
0 g
s
.65365 .74526 m .65365 .7082 L .64105 .70032 L p .707 .577 .707 r
F P
0 g
s
.8186 .7491 m .8186 .76763 L .83497 .76026 L p .707 .577 .707 r
F P
0 g
s
.83497 .76026 m .83497 .74173 L .8186 .7491 L p .707 .577 .707 r
F P
0 g
s
.64105 .66401 m .64105 .60843 L .63816 .59989 L p .707 .577 .707 r
F P
0 g
s
.64105 .70032 m .64105 .73737 L .65365 .74526 L p .707 .577 .707 r
F P
0 g
s
.65365 .76469 m .65365 .74616 L .64105 .73828 L p .707 .577 .707 r
F P
0 g
s
.64105 .73828 m .64105 .7568 L .65365 .76469 L p .707 .577 .707 r
F P
0 g
s
.83497 .70378 m .83497 .74083 L .84206 .73247 L p .707 .577 .707 r
F P
0 g
s
.84206 .73247 m .84206 .69541 L .83497 .70378 L p .707 .577 .707 r
F P
0 g
s
.63816 .59989 m .63816 .65547 L .64105 .66401 L p .707 .577 .707 r
F P
0 g
s
.84205 .60352 m .84205 .65911 L .83916 .65056 L p .707 .577 .707 r
F P
0 g
s
.83916 .65056 m .83916 .59498 L .84205 .60352 L p .707 .577 .707 r
F P
0 g
s
.83497 .74173 m .83497 .76026 L .84206 .7519 L p .707 .577 .707 r
F P
0 g
s
.84206 .7519 m .84206 .73337 L .83497 .74173 L p .707 .577 .707 r
F P
0 g
s
.64105 .73737 m .64105 .70032 L .63816 .69178 L p .707 .577 .707 r
F P
0 g
s
.63816 .65547 m .63816 .59989 L .64524 .59152 L p .707 .577 .707 r
F P
0 g
s
.63816 .69178 m .63816 .72883 L .64105 .73737 L p .707 .577 .707 r
F P
0 g
s
.64105 .7568 m .64105 .73828 L .63816 .72973 L p .707 .577 .707 r
F P
0 g
s
.63816 .72973 m .63816 .74826 L .64105 .7568 L p .707 .577 .707 r
F P
0 g
s
.84206 .69541 m .84206 .73247 L .83916 .72392 L p .707 .577 .707 r
F P
0 g
s
.83916 .72392 m .83916 .68687 L .84206 .69541 L p .707 .577 .707 r
F P
0 g
s
.64524 .59152 m .64524 .64711 L .63816 .65547 L p .707 .577 .707 r
F P
0 g
s
.83916 .59498 m .83916 .65056 L .82657 .64268 L p .707 .577 .707 r
F P
0 g
s
.82657 .64268 m .82657 .5871 L .83916 .59498 L p .707 .577 .707 r
F P
0 g
s
.84206 .73337 m .84206 .7519 L .83916 .74335 L p .707 .577 .707 r
F P
0 g
s
.83916 .74335 m .83916 .72483 L .84206 .73337 L p .707 .577 .707 r
F P
0 g
s
.63816 .72883 m .63816 .69178 L .64524 .68341 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64783 m .39032 .59225 L .35915 .59035 L p .707 .577 .707 r
F P
0 g
s
.39032 .59225 m .39032 .64783 L .42216 .64705 L p .707 .577 .707 r
F P
0 g
s
.42216 .64705 m .42216 .59147 L .39032 .59225 L p .707 .577 .707 r
F P
0 g
s
.64524 .64711 m .64524 .59152 L .66161 .58416 L p .707 .577 .707 r
F P
0 g
s
.42216 .59147 m .42216 .64705 L .45154 .64367 L p .707 .577 .707 r
F P
0 g
s
.45154 .64367 m .45154 .58809 L .42216 .59147 L p .707 .577 .707 r
F P
0 g
s
.35915 .64593 m .35915 .59035 L .33169 .58595 L p .707 .577 .707 r
F P
0 g
s
.35915 .59035 m .35915 .64593 L .39032 .64783 L p .707 .577 .707 r
F P
0 g
s
.64524 .68341 m .64524 .72047 L .63816 .72883 L p .707 .577 .707 r
F P
0 g
s
.63816 .74826 m .63816 .72973 L .64524 .72137 L p .707 .577 .707 r
F P
0 g
s
.64524 .72137 m .64524 .7399 L .63816 .74826 L p .707 .577 .707 r
F P
0 g
s
.45154 .58809 m .45154 .64367 L .47559 .63802 L p .707 .577 .707 r
F P
0 g
s
.47559 .63802 m .47559 .58244 L .45154 .58809 L p .707 .577 .707 r
F P
0 g
s
.83916 .68687 m .83916 .72392 L .82657 .71604 L p .707 .577 .707 r
F P
0 g
s
.82657 .71604 m .82657 .67898 L .83916 .68687 L p .707 .577 .707 r
F P
0 g
s
.66161 .58416 m .66161 .63974 L .64524 .64711 L p .707 .577 .707 r
F P
0 g
s
.82657 .5871 m .82657 .64268 L .80551 .63623 L p .707 .577 .707 r
F P
0 g
s
.80551 .63623 m .80551 .58064 L .82657 .5871 L p .707 .577 .707 r
F P
0 g
s
.33169 .58595 m .33169 .64154 L .35915 .64593 L p .707 .577 .707 r
F P
0 g
s
.33169 .64154 m .33169 .58595 L .31064 .5795 L p .707 .577 .707 r
F P
0 g
s
.39032 .72119 m .39032 .68413 L .35915 .68223 L p .707 .577 .707 r
F P
0 g
s
.39032 .68413 m .39032 .72119 L .42216 .72041 L p .707 .577 .707 r
F P
0 g
s
.42216 .72041 m .42216 .68336 L .39032 .68413 L p .707 .577 .707 r
F P
0 g
s
.83916 .72483 m .83916 .74335 L .82657 .73547 L p .707 .577 .707 r
F P
0 g
s
.82657 .73547 m .82657 .71694 L .83916 .72483 L p .707 .577 .707 r
F P
0 g
s
.64524 .72047 m .64524 .68341 L .66161 .67604 L p .707 .577 .707 r
F P
0 g
s
.42216 .68336 m .42216 .72041 L .45154 .71703 L p .707 .577 .707 r
F P
0 g
s
.45154 .71703 m .45154 .67998 L .42216 .68336 L p .707 .577 .707 r
F P
0 g
s
.66161 .63974 m .66161 .58416 L .68566 .57851 L p .707 .577 .707 r
F P
0 g
s
.35915 .71929 m .35915 .68223 L .33169 .67784 L p .707 .577 .707 r
F P
0 g
s
.35915 .68223 m .35915 .71929 L .39032 .72119 L p .707 .577 .707 r
F P
0 g
s
.47559 .58244 m .47559 .63802 L .49196 .63066 L p .707 .577 .707 r
F P
0 g
s
.49196 .63066 m .49196 .57507 L .47559 .58244 L p .707 .577 .707 r
F P
0 g
s
.39032 .74062 m .39032 .72209 L .35915 .72019 L p .707 .577 .707 r
F P
0 g
s
.39032 .72209 m .39032 .74062 L .42216 .73984 L p .707 .577 .707 r
F P
0 g
s
.42216 .73984 m .42216 .72131 L .39032 .72209 L p .707 .577 .707 r
F P
0 g
s
.31064 .5795 m .31064 .63508 L .33169 .64154 L p .707 .577 .707 r
F P
0 g
s
.66161 .67604 m .66161 .7131 L .64524 .72047 L p .707 .577 .707 r
F P
0 g
s
.64524 .7399 m .64524 .72137 L .66161 .714 L p .707 .577 .707 r
F P
0 g
s
.42216 .72131 m .42216 .73984 L .45154 .73646 L p .707 .577 .707 r
F P
0 g
s
.45154 .73646 m .45154 .71794 L .42216 .72131 L p .707 .577 .707 r
F P
0 g
s
.45154 .67998 m .45154 .71703 L .47559 .71138 L p .707 .577 .707 r
F P
0 g
s
.47559 .71138 m .47559 .67433 L .45154 .67998 L p .707 .577 .707 r
F P
0 g
s
.35915 .72019 m .35915 .73872 L .39032 .74062 L p .707 .577 .707 r
F P
0 g
s
.80551 .58064 m .80551 .63623 L .77805 .63183 L p .707 .577 .707 r
F P
0 g
s
.77805 .63183 m .77805 .57625 L .80551 .58064 L p .707 .577 .707 r
F P
0 g
s
.33169 .67784 m .33169 .7149 L .35915 .71929 L p .707 .577 .707 r
F P
0 g
s
.35915 .73872 m .35915 .72019 L .33169 .7158 L p .707 .577 .707 r
F P
0 g
s
.66161 .714 m .66161 .73253 L .64524 .7399 L p .707 .577 .707 r
F P
0 g
s
.82657 .67898 m .82657 .71604 L .80551 .70959 L p .707 .577 .707 r
F P
0 g
s
.80551 .70959 m .80551 .67253 L .82657 .67898 L p .707 .577 .707 r
F P
0 g
s
.68566 .57851 m .68566 .63409 L .66161 .63974 L p .707 .577 .707 r
F P
0 g
s
.31064 .63508 m .31064 .5795 L .29804 .57162 L p .707 .577 .707 r
F P
0 g
s
.33169 .7158 m .33169 .73433 L .35915 .73872 L p .707 .577 .707 r
F P
0 g
s
.33169 .7149 m .33169 .67784 L .31064 .67139 L p .707 .577 .707 r
F P
0 g
s
.68566 .63409 m .68566 .57851 L .71504 .57513 L p .707 .577 .707 r
F P
0 g
s
.45154 .71794 m .45154 .73646 L .47559 .73081 L p .707 .577 .707 r
F P
0 g
s
.47559 .73081 m .47559 .71229 L .45154 .71794 L p .707 .577 .707 r
F P
0 g
s
.66161 .7131 m .66161 .67604 L .68566 .67039 L p .707 .577 .707 r
F P
0 g
s
.82657 .71694 m .82657 .73547 L .80551 .72902 L p .707 .577 .707 r
F P
0 g
s
.80551 .72902 m .80551 .71049 L .82657 .71694 L p .707 .577 .707 r
F P
0 g
s
.77805 .57625 m .77805 .63183 L .74688 .62993 L p .707 .577 .707 r
F P
0 g
s
.74688 .62993 m .74688 .57435 L .77805 .57625 L p .707 .577 .707 r
F P
0 g
s
.31064 .67139 m .31064 .70844 L .33169 .7149 L p .707 .577 .707 r
F P
0 g
s
.33169 .73433 m .33169 .7158 L .31064 .70934 L p .707 .577 .707 r
F P
0 g
s
.47559 .67433 m .47559 .71138 L .49196 .70401 L p .707 .577 .707 r
F P
0 g
s
.49196 .70401 m .49196 .66696 L .47559 .67433 L p .707 .577 .707 r
F P
0 g
s
.29804 .57162 m .29804 .6272 L .31064 .63508 L p .707 .577 .707 r
F P
0 g
s
.71504 .63071 m .71504 .57513 L .74688 .57435 L p .707 .577 .707 r
F P
0 g
s
.71504 .57513 m .71504 .63071 L .68566 .63409 L p .707 .577 .707 r
F P
0 g
s
.49196 .57507 m .49196 .63066 L .49904 .62229 L p .707 .577 .707 r
F P
0 g
s
.49904 .62229 m .49904 .56671 L .49196 .57507 L p .707 .577 .707 r
F P
0 g
s
.31064 .70934 m .31064 .72787 L .33169 .73433 L p .707 .577 .707 r
F P
0 g
s
.74688 .57435 m .74688 .62993 L .71504 .63071 L p .707 .577 .707 r
F P
0 g
s
.68566 .67039 m .68566 .70745 L .66161 .7131 L p .707 .577 .707 r
F P
0 g
s
.66161 .73253 m .66161 .714 L .68566 .70835 L p .707 .577 .707 r
F P
0 g
s
.80551 .67253 m .80551 .70959 L .77805 .70519 L p .707 .577 .707 r
F P
0 g
s
.77805 .70519 m .77805 .66814 L .80551 .67253 L p .707 .577 .707 r
F P
0 g
s
.68566 .70835 m .68566 .72688 L .66161 .73253 L p .707 .577 .707 r
F P
0 g
s
.31064 .70844 m .31064 .67139 L .29804 .6635 L p .707 .577 .707 r
F P
0 g
s
.47559 .71229 m .47559 .73081 L .49196 .72345 L p .707 .577 .707 r
F P
0 g
s
.49196 .72345 m .49196 .70492 L .47559 .71229 L p .707 .577 .707 r
F P
0 g
s
.29804 .6272 m .29804 .57162 L .29515 .56307 L p .707 .577 .707 r
F P
0 g
s
.68566 .70745 m .68566 .67039 L .71504 .66701 L p .707 .577 .707 r
F P
0 g
s
.80551 .71049 m .80551 .72902 L .77805 .72462 L p .707 .577 .707 r
F P
0 g
s
.77805 .72462 m .77805 .7061 L .80551 .71049 L p .707 .577 .707 r
F P
0 g
s
.29804 .6635 m .29804 .70056 L .31064 .70844 L p .707 .577 .707 r
F P
0 g
s
.31064 .72787 m .31064 .70934 L .29804 .70146 L p .707 .577 .707 r
F P
0 g
s
.77805 .66814 m .77805 .70519 L .74688 .70329 L p .707 .577 .707 r
F P
0 g
s
.74688 .70329 m .74688 .66624 L .77805 .66814 L p .707 .577 .707 r
F P
0 g
s
.71504 .66701 m .71504 .70407 L .68566 .70745 L p .707 .577 .707 r
F P
0 g
s
.68566 .72688 m .68566 .70835 L .71504 .70497 L p .707 .577 .707 r
F P
0 g
s
.71504 .70407 m .71504 .66701 L .74688 .66624 L p .707 .577 .707 r
F P
0 g
s
.29804 .70146 m .29804 .71999 L .31064 .72787 L p .707 .577 .707 r
F P
0 g
s
.49196 .66696 m .49196 .70401 L .49904 .69565 L p .707 .577 .707 r
F P
0 g
s
.49904 .69565 m .49904 .6586 L .49196 .66696 L p .707 .577 .707 r
F P
0 g
s
.29515 .56307 m .29515 .61866 L .29804 .6272 L p .707 .577 .707 r
F P
0 g
s
.74688 .66624 m .74688 .70329 L .71504 .70407 L p .707 .577 .707 r
F P
0 g
s
.71504 .70497 m .71504 .7235 L .68566 .72688 L p .707 .577 .707 r
F P
0 g
s
.49904 .56671 m .49904 .62229 L .49615 .61375 L p .707 .577 .707 r
F P
0 g
s
.49615 .61375 m .49615 .55817 L .49904 .56671 L p .707 .577 .707 r
F P
0 g
s
.77805 .7061 m .77805 .72462 L .74688 .72272 L p .707 .577 .707 r
F P
0 g
s
.74688 .72272 m .74688 .7042 L .77805 .7061 L p .707 .577 .707 r
F P
0 g
s
.71504 .7235 m .71504 .70497 L .74688 .7042 L p .707 .577 .707 r
F P
0 g
s
.49196 .70492 m .49196 .72345 L .49904 .71508 L p .707 .577 .707 r
F P
0 g
s
.49904 .71508 m .49904 .69655 L .49196 .70492 L p .707 .577 .707 r
F P
0 g
s
.29804 .70056 m .29804 .6635 L .29515 .65496 L p .707 .577 .707 r
F P
0 g
s
.74688 .7042 m .74688 .72272 L .71504 .7235 L p .707 .577 .707 r
F P
0 g
s
.29515 .61866 m .29515 .56307 L .30223 .55471 L p .707 .577 .707 r
F P
0 g
s
.29515 .65496 m .29515 .69202 L .29804 .70056 L p .707 .577 .707 r
F P
0 g
s
.29804 .71999 m .29804 .70146 L .29515 .69292 L p .707 .577 .707 r
F P
0 g
s
.29515 .69292 m .29515 .71145 L .29804 .71999 L p .707 .577 .707 r
F P
0 g
s
.49904 .6586 m .49904 .69565 L .49615 .68711 L p .707 .577 .707 r
F P
0 g
s
.49615 .68711 m .49615 .65005 L .49904 .6586 L p .707 .577 .707 r
F P
0 g
s
.30223 .55471 m .30223 .61029 L .29515 .61866 L p .707 .577 .707 r
F P
0 g
s
.49615 .55817 m .49615 .61375 L .48356 .60586 L p .707 .577 .707 r
F P
0 g
s
.48356 .60586 m .48356 .55028 L .49615 .55817 L p .707 .577 .707 r
F P
0 g
s
.49904 .69655 m .49904 .71508 L .49615 .70654 L p .707 .577 .707 r
F P
0 g
s
.49615 .70654 m .49615 .68801 L .49904 .69655 L p .707 .577 .707 r
F P
0 g
s
.29515 .69202 m .29515 .65496 L .30223 .6466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61029 m .30223 .55471 L .3186 .54734 L p .707 .577 .707 r
F P
0 g
s
.30223 .6466 m .30223 .68365 L .29515 .69202 L p .707 .577 .707 r
F P
0 g
s
.29515 .71145 m .29515 .69292 L .30223 .68455 L p .707 .577 .707 r
F P
0 g
s
.30223 .68455 m .30223 .70308 L .29515 .71145 L p .707 .577 .707 r
F P
0 g
s
.49615 .65005 m .49615 .68711 L .48356 .67922 L p .707 .577 .707 r
F P
0 g
s
.48356 .67922 m .48356 .64217 L .49615 .65005 L p .707 .577 .707 r
F P
0 g
s
.3186 .54734 m .3186 .60292 L .30223 .61029 L p .707 .577 .707 r
F P
0 g
s
.48356 .55028 m .48356 .60586 L .4625 .59941 L p .707 .577 .707 r
F P
0 g
s
.4625 .59941 m .4625 .54383 L .48356 .55028 L p .707 .577 .707 r
F P
0 g
s
.49615 .68801 m .49615 .70654 L .48356 .69865 L p .707 .577 .707 r
F P
0 g
s
.48356 .69865 m .48356 .68013 L .49615 .68801 L p .707 .577 .707 r
F P
0 g
s
.30223 .68365 m .30223 .6466 L .3186 .63923 L p .707 .577 .707 r
F P
0 g
s
.3186 .60292 m .3186 .54734 L .34265 .54169 L p .707 .577 .707 r
F P
0 g
s
.3186 .63923 m .3186 .67628 L .30223 .68365 L p .707 .577 .707 r
F P
0 g
s
.30223 .70308 m .30223 .68455 L .3186 .67719 L p .707 .577 .707 r
F P
0 g
s
.4625 .54383 m .4625 .59941 L .43504 .59502 L p .707 .577 .707 r
F P
0 g
s
.43504 .59502 m .43504 .53944 L .4625 .54383 L p .707 .577 .707 r
F P
0 g
s
.3186 .67719 m .3186 .69571 L .30223 .70308 L p .707 .577 .707 r
F P
0 g
s
.48356 .64217 m .48356 .67922 L .4625 .67277 L p .707 .577 .707 r
F P
0 g
s
.4625 .67277 m .4625 .63571 L .48356 .64217 L p .707 .577 .707 r
F P
0 g
s
.34265 .54169 m .34265 .59727 L .3186 .60292 L p .707 .577 .707 r
F P
0 g
s
.34265 .59727 m .34265 .54169 L .37203 .53831 L p .707 .577 .707 r
F P
0 g
s
.3186 .67628 m .3186 .63923 L .34265 .63358 L p .707 .577 .707 r
F P
0 g
s
.48356 .68013 m .48356 .69865 L .4625 .6922 L p .707 .577 .707 r
F P
0 g
s
.4625 .6922 m .4625 .67367 L .48356 .68013 L p .707 .577 .707 r
F P
0 g
s
.43504 .53944 m .43504 .59502 L .40387 .59312 L p .707 .577 .707 r
F P
0 g
s
.40387 .59312 m .40387 .53754 L .43504 .53944 L p .707 .577 .707 r
F P
0 g
s
.37203 .59389 m .37203 .53831 L .40387 .53754 L p .707 .577 .707 r
F P
0 g
s
.37203 .53831 m .37203 .59389 L .34265 .59727 L p .707 .577 .707 r
F P
0 g
s
.40387 .53754 m .40387 .59312 L .37203 .59389 L p .707 .577 .707 r
F P
0 g
s
.34265 .63358 m .34265 .67063 L .3186 .67628 L p .707 .577 .707 r
F P
0 g
s
.3186 .69571 m .3186 .67719 L .34265 .67154 L p .707 .577 .707 r
F P
0 g
s
.4625 .63571 m .4625 .67277 L .43504 .66838 L p .707 .577 .707 r
F P
0 g
s
.43504 .66838 m .43504 .63132 L .4625 .63571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67154 m .34265 .69006 L .3186 .69571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67063 m .34265 .63358 L .37203 .6302 L p .707 .577 .707 r
F P
0 g
s
.4625 .67367 m .4625 .6922 L .43504 .68781 L p .707 .577 .707 r
F P
0 g
s
.43504 .68781 m .43504 .66928 L .4625 .67367 L p .707 .577 .707 r
F P
0 g
s
.43504 .63132 m .43504 .66838 L .40387 .66648 L p .707 .577 .707 r
F P
0 g
s
.40387 .66648 m .40387 .62942 L .43504 .63132 L p .707 .577 .707 r
F P
0 g
s
.37203 .6302 m .37203 .66725 L .34265 .67063 L p .707 .577 .707 r
F P
0 g
s
.34265 .69006 m .34265 .67154 L .37203 .66816 L p .707 .577 .707 r
F P
0 g
s
.37203 .66725 m .37203 .6302 L .40387 .62942 L p .707 .577 .707 r
F P
0 g
s
.40387 .62942 m .40387 .66648 L .37203 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66816 m .37203 .68668 L .34265 .69006 L p .707 .577 .707 r
F P
0 g
s
.43504 .66928 m .43504 .68781 L .40387 .68591 L p .707 .577 .707 r
F P
0 g
s
.40387 .68591 m .40387 .66738 L .43504 .66928 L p .707 .577 .707 r
F P
0 g
s
.37203 .68668 m .37203 .66816 L .40387 .66738 L p .707 .577 .707 r
F P
0 g
s
.40387 .66738 m .40387 .68591 L .37203 .68668 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Ioo`00O7oo1P000UYF
00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001fOol60008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF2@0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol90004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005ioo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP@003Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH0
1UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
05=oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001J
EP04FUH00`00FUIJEP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPH000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
;7oo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03001JEP00008000AJEP04
001JEUYFFUH90007FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000=JEPH000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF
001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000UYF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000=J
EP00000020001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000H000AJEP04001J
EUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEP000003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@000UYF00<005YF00002EYF2@0025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH00UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF2@0000=JEP00
FUH00UYF00<005YF00002UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@000=JEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF2000
15YF00<005YFFUH00eYF3P001EYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF600000=JEP00FUH015YF00<005YFFUH01EYF00@005YF
FUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH20004FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00003000]Ool0031oo`<000AJEPP000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP<00003FUH005YF00=JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEPP000=J
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00004FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH40005FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000aOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF00000eYF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0000H00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001@00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH500000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP<0009JEP03001JEP0000D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF
009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF
009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00=JEP04001JEUYFFUH30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009oo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH005YFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH50003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH00`00Oomoo`02Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP02FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/
Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<007ooOol017oo0P0015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`001eYF00<0
05YFFUH015YF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/
Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool01goo0`0000=JEP00FUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000/Ool30004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP02000;Ool40008
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000030004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool90018Ool002aoo`<000AJ
EP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;7oo00<005YF
000015YF1@001eYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00
01Eoob8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2001DOol002aoo`03001JEP00009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001oogoo02Eoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP0000<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0UOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH0000200000eYF001oo`0VOol00`00FUH00004FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00001P0015YF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00<005YF00009goo00<005YF000015YF1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00E7oo000/
Ool20003FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00002FUH40004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2
001DOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YF
FUH00UYF1@001EYF00@005YFFUIJEP8002Qoo`03001JEP0000<00003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<0009JEP80
05Aoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000:Goo00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEPH005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`<000AJ
EP03001JEUYF009JEPL000QJEPD000AJEPP000=JEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00
<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;7oo00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1@0015YF
00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8005Aoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000cOol0
1000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF0`000eYF0P00E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP0200000eYF0000001DOol008ioo`D000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000D005Aoo`00SWoo0P000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
1@0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00001P000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
0UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
05Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065o
o`00YGoo4P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79348 m .59613 .7379 L .56496 .736 L p .707 .577 .707 r
F P
0 g
s
.59613 .7379 m .59613 .79348 L .62796 .79271 L p .707 .577 .707 r
F P
0 g
s
.62796 .79271 m .62796 .73713 L .59613 .7379 L p .707 .577 .707 r
F P
0 g
s
.62796 .73713 m .62796 .79271 L .65735 .78933 L p .707 .577 .707 r
F P
0 g
s
.65735 .78933 m .65734 .73375 L .62796 .73713 L p .707 .577 .707 r
F P
0 g
s
.56496 .79158 m .56496 .736 L .5375 .73161 L p .707 .577 .707 r
F P
0 g
s
.56496 .736 m .56496 .79158 L .59613 .79348 L p .707 .577 .707 r
F P
0 g
s
.65734 .73375 m .65735 .78933 L .6814 .78368 L p .707 .577 .707 r
F P
0 g
s
.6814 .78368 m .6814 .7281 L .65734 .73375 L p .707 .577 .707 r
F P
0 g
s
.5375 .73161 m .5375 .78719 L .56496 .79158 L p .707 .577 .707 r
F P
0 g
s
.5375 .78719 m .5375 .73161 L .51644 .72516 L p .707 .577 .707 r
F P
0 g
s
.59613 .87488 m .59613 .83782 L .56496 .83592 L p .707 .577 .707 r
F P
0 g
s
.59613 .83782 m .59613 .87488 L .62796 .8741 L p .707 .577 .707 r
F P
0 g
s
.62796 .8741 m .62796 .83704 L .59613 .83782 L p .707 .577 .707 r
F P
0 g
s
.62796 .83704 m .62796 .8741 L .65735 .87072 L p .707 .577 .707 r
F P
0 g
s
.65735 .87072 m .65735 .83367 L .62796 .83704 L p .707 .577 .707 r
F P
0 g
s
.59613 .88046 m .59613 .86193 L .56496 .86003 L p .707 .577 .707 r
F P
0 g
s
.59613 .86193 m .59613 .88046 L .62796 .87968 L p .707 .577 .707 r
F P
0 g
s
.62796 .87968 m .62796 .86116 L .59613 .86193 L p .707 .577 .707 r
F P
0 g
s
.56496 .87298 m .56496 .83592 L .5375 .83153 L p .707 .577 .707 r
F P
0 g
s
.56496 .83592 m .56496 .87298 L .59613 .87488 L p .707 .577 .707 r
F P
0 g
s
.6814 .7281 m .6814 .78368 L .69777 .77631 L p .707 .577 .707 r
F P
0 g
s
.69777 .77631 m .69777 .72073 L .6814 .7281 L p .707 .577 .707 r
F P
0 g
s
.62796 .86116 m .62796 .87968 L .65735 .8763 L p .707 .577 .707 r
F P
0 g
s
.65735 .8763 m .65735 .85778 L .62796 .86116 L p .707 .577 .707 r
F P
0 g
s
.51644 .72516 m .51644 .78074 L .5375 .78719 L p .707 .577 .707 r
F P
0 g
s
.56496 .86003 m .56496 .87856 L .59613 .88046 L p .707 .577 .707 r
F P
0 g
s
.56496 .87856 m .56496 .86003 L .5375 .85564 L p .707 .577 .707 r
F P
0 g
s
.65735 .83367 m .65735 .87072 L .6814 .86507 L p .707 .577 .707 r
F P
0 g
s
.6814 .86507 m .6814 .82802 L .65735 .83367 L p .707 .577 .707 r
F P
0 g
s
.5375 .83153 m .5375 .86858 L .56496 .87298 L p .707 .577 .707 r
F P
0 g
s
.51644 .78074 m .51644 .72516 L .50385 .71727 L p .707 .577 .707 r
F P
0 g
s
.5375 .85564 m .5375 .87417 L .56496 .87856 L p .707 .577 .707 r
F P
0 g
s
.65735 .85778 m .65735 .8763 L .6814 .87065 L p .707 .577 .707 r
F P
0 g
s
.6814 .87065 m .6814 .85213 L .65735 .85778 L p .707 .577 .707 r
F P
0 g
s
.5375 .86858 m .5375 .83153 L .51644 .82507 L p .707 .577 .707 r
F P
0 g
s
.5375 .87417 m .5375 .85564 L .51644 .84919 L p .707 .577 .707 r
F P
0 g
s
.51644 .82507 m .51644 .86213 L .5375 .86858 L p .707 .577 .707 r
F P
0 g
s
.50385 .71727 m .50385 .77285 L .51644 .78074 L p .707 .577 .707 r
F P
0 g
s
.69777 .72073 m .69777 .77631 L .70485 .76795 L p .707 .577 .707 r
F P
0 g
s
.70485 .76795 m .70485 .71237 L .69777 .72073 L p .707 .577 .707 r
F P
0 g
s
.51644 .84919 m .51644 .86771 L .5375 .87417 L p .707 .577 .707 r
F P
0 g
s
.6814 .82802 m .6814 .86507 L .69777 .8577 L p .707 .577 .707 r
F P
0 g
s
.69777 .8577 m .69777 .82065 L .6814 .82802 L p .707 .577 .707 r
F P
0 g
s
.6814 .85213 m .6814 .87065 L .69777 .86329 L p .707 .577 .707 r
F P
0 g
s
.69777 .86329 m .69777 .84476 L .6814 .85213 L p .707 .577 .707 r
F P
0 g
s
.51644 .86213 m .51644 .82507 L .50385 .81719 L p .707 .577 .707 r
F P
0 g
s
.49044 .76629 m .49044 .2644 L .44643 .26172 L p .707 .577 .707 r
F P
0 g
s
.50385 .77285 m .50385 .71727 L .50095 .70873 L p .707 .577 .707 r
F P
0 g
s
.50095 .70873 m .50095 .76431 L .50385 .77285 L p .707 .577 .707 r
F P
0 g
s
.50095 .76431 m .50095 .70873 L .50804 .70037 L p .707 .577 .707 r
F P
0 g
s
.50804 .70037 m .50804 .75595 L .50095 .76431 L p .707 .577 .707 r
F P
0 g
s
.50804 .75595 m .50804 .70037 L .5244 .693 L p .707 .577 .707 r
F P
0 g
s
.5244 .693 m .5244 .74858 L .50804 .75595 L p .707 .577 .707 r
F P
0 g
s
.5244 .74858 m .5244 .693 L .54846 .68735 L p .707 .577 .707 r
F P
0 g
s
.54846 .68735 m .54846 .74293 L .5244 .74858 L p .707 .577 .707 r
F P
0 g
s
.49044 .2644 m .49044 .76629 L .53538 .76519 L p .707 .577 .707 r
F P
0 g
s
.53538 .76519 m .53538 .2633 L .49044 .2644 L p .707 .577 .707 r
F P
0 g
s
.54846 .74293 m .54846 .68735 L .57784 .68397 L p .707 .577 .707 r
F P
0 g
s
.57784 .68397 m .57784 .73955 L .54846 .74293 L p .707 .577 .707 r
F P
0 g
s
.53538 .2633 m .53538 .76519 L .57686 .76042 L p .707 .577 .707 r
F P
0 g
s
.57686 .76042 m .57686 .25853 L .53538 .2633 L p .707 .577 .707 r
F P
0 g
s
.51644 .86771 m .51644 .84919 L .50385 .8413 L p .707 .577 .707 r
F P
0 g
s
.44643 .76361 m .44643 .26172 L .40766 .25552 L p .707 .577 .707 r
F P
0 g
s
.44643 .26172 m .44643 .76361 L .49044 .76629 L p .707 .577 .707 r
F P
0 g
s
.50385 .81719 m .50385 .85425 L .51644 .86213 L p .707 .577 .707 r
F P
0 g
s
.50385 .8413 m .50385 .85983 L .51644 .86771 L p .707 .577 .707 r
F P
0 g
s
.69777 .82065 m .69777 .8577 L .70485 .84934 L p .707 .577 .707 r
F P
0 g
s
.70485 .84934 m .70485 .81228 L .69777 .82065 L p .707 .577 .707 r
F P
0 g
s
.70485 .71237 m .70485 .76795 L .70195 .7594 L p .707 .577 .707 r
F P
0 g
s
.70195 .7594 m .70195 .70382 L .70485 .71237 L p .707 .577 .707 r
F P
0 g
s
.64085 .68509 m .64085 .74067 L .60968 .73877 L p .707 .577 .707 r
F P
0 g
s
.60968 .73877 m .60968 .68319 L .64085 .68509 L p .707 .577 .707 r
F P
0 g
s
.57784 .73955 m .57784 .68397 L .60968 .68319 L p .707 .577 .707 r
F P
0 g
s
.60968 .68319 m .60968 .73877 L .57784 .73955 L p .707 .577 .707 r
F P
0 g
s
.57686 .25853 m .57686 .76042 L .61082 .75244 L p .707 .577 .707 r
F P
0 g
s
.61082 .75244 m .61082 .25056 L .57686 .25853 L p .707 .577 .707 r
F P
0 g
s
.69777 .84476 m .69777 .86329 L .70485 .85492 L p .707 .577 .707 r
F P
0 g
s
.70485 .85492 m .70485 .8364 L .69777 .84476 L p .707 .577 .707 r
F P
0 g
s
.50385 .85425 m .50385 .81719 L .50095 .80865 L p .707 .577 .707 r
F P
0 g
s
.40766 .7574 m .40766 .25552 L .37794 .2464 L p .707 .577 .707 r
F P
0 g
s
.40766 .25552 m .40766 .7574 L .44643 .76361 L p .707 .577 .707 r
F P
0 g
s
.50385 .85983 m .50385 .8413 L .50095 .83276 L p .707 .577 .707 r
F P
0 g
s
.50095 .80865 m .50095 .8457 L .50385 .85425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .83276 m .50095 .85129 L .50385 .85983 L p .707 .577 .707 r
F P
0 g
s
.70485 .81228 m .70485 .84934 L .70195 .8408 L p .707 .577 .707 r
F P
0 g
s
.70195 .8408 m .70195 .80374 L .70485 .81228 L p .707 .577 .707 r
F P
0 g
s
.70195 .70382 m .70195 .7594 L .68936 .75152 L p .707 .577 .707 r
F P
0 g
s
.68936 .75152 m .68936 .69594 L .70195 .70382 L p .707 .577 .707 r
F P
0 g
s
.61082 .25056 m .61082 .75244 L .63393 .74204 L p .707 .577 .707 r
F P
0 g
s
.63393 .74204 m .63393 .24016 L .61082 .25056 L p .707 .577 .707 r
F P
0 g
s
.70485 .8364 m .70485 .85492 L .70195 .84638 L p .707 .577 .707 r
F P
0 g
s
.70195 .84638 m .70195 .82785 L .70485 .8364 L p .707 .577 .707 r
F P
0 g
s
.25312 .75667 m .25312 .70109 L .22195 .69919 L p .707 .577 .707 r
F P
0 g
s
.25312 .70109 m .25312 .75667 L .28495 .75589 L p .707 .577 .707 r
F P
0 g
s
.28495 .75589 m .28495 .70031 L .25312 .70109 L p .707 .577 .707 r
F P
0 g
s
.50095 .8457 m .50095 .80865 L .50804 .80028 L p .707 .577 .707 r
F P
0 g
s
.28495 .70031 m .28495 .75589 L .31434 .75251 L p .707 .577 .707 r
F P
0 g
s
.31434 .75251 m .31434 .69693 L .28495 .70031 L p .707 .577 .707 r
F P
0 g
s
.37794 .74829 m .37794 .2464 L .36016 .23527 L p .707 .577 .707 r
F P
0 g
s
.37794 .2464 m .37794 .74829 L .40766 .7574 L p .707 .577 .707 r
F P
0 g
s
.22195 .75477 m .22195 .69919 L .19449 .69479 L p .707 .577 .707 r
F P
0 g
s
.22195 .69919 m .22195 .75477 L .25312 .75667 L p .707 .577 .707 r
F P
0 g
s
.50095 .85129 m .50095 .83276 L .50804 .8244 L p .707 .577 .707 r
F P
0 g
s
.50804 .80028 m .50804 .83734 L .50095 .8457 L p .707 .577 .707 r
F P
0 g
s
.50804 .8244 m .50804 .84292 L .50095 .85129 L p .707 .577 .707 r
F P
0 g
s
.31434 .69693 m .31434 .75251 L .33839 .74686 L p .707 .577 .707 r
F P
0 g
s
.33839 .74686 m .33839 .69128 L .31434 .69693 L p .707 .577 .707 r
F P
0 g
s
.70195 .80374 m .70195 .8408 L .68936 .83291 L p .707 .577 .707 r
F P
0 g
s
.68936 .83291 m .68936 .79586 L .70195 .80374 L p .707 .577 .707 r
F P
0 g
s
.68936 .69594 m .68936 .75152 L .66831 .74507 L p .707 .577 .707 r
F P
0 g
s
.66831 .74507 m .66831 .68948 L .68936 .69594 L p .707 .577 .707 r
F P
0 g
s
.19449 .69479 m .19449 .75038 L .22195 .75477 L p .707 .577 .707 r
F P
0 g
s
.19449 .75038 m .19449 .69479 L .17343 .68834 L p .707 .577 .707 r
F P
0 g
s
.70195 .82785 m .70195 .84638 L .68936 .8385 L p .707 .577 .707 r
F P
0 g
s
.68936 .8385 m .68936 .81997 L .70195 .82785 L p .707 .577 .707 r
F P
0 g
s
.25312 .83806 m .25312 .80101 L .22195 .79911 L p .707 .577 .707 r
F P
0 g
s
.25312 .80101 m .25312 .83806 L .28495 .83728 L p .707 .577 .707 r
F P
0 g
s
.28495 .83728 m .28495 .80023 L .25312 .80101 L p .707 .577 .707 r
F P
0 g
s
.64085 .74067 m .64085 .68509 L .66831 .68948 L p .707 .577 .707 r
F P
0 g
s
.63393 .24016 m .63393 .74204 L .64393 .73023 L p .707 .577 .707 r
F P
0 g
s
.64393 .73023 m .64393 .22835 L .63393 .24016 L p .707 .577 .707 r
F P
0 g
s
.50804 .83734 m .50804 .80028 L .5244 .79292 L p .707 .577 .707 r
F P
0 g
s
.28495 .80023 m .28495 .83728 L .31434 .83391 L p .707 .577 .707 r
F P
0 g
s
.31434 .83391 m .31434 .79685 L .28495 .80023 L p .707 .577 .707 r
F P
0 g
s
.25312 .84365 m .25312 .82512 L .22195 .82322 L p .707 .577 .707 r
F P
0 g
s
.25312 .82512 m .25312 .84365 L .28495 .84287 L p .707 .577 .707 r
F P
0 g
s
.28495 .84287 m .28495 .82434 L .25312 .82512 L p .707 .577 .707 r
F P
0 g
s
.22195 .83616 m .22195 .79911 L .19449 .79471 L p .707 .577 .707 r
F P
0 g
s
.22195 .79911 m .22195 .83616 L .25312 .83806 L p .707 .577 .707 r
F P
0 g
s
.33839 .69128 m .33839 .74686 L .35476 .7395 L p .707 .577 .707 r
F P
0 g
s
.35476 .7395 m .35476 .68391 L .33839 .69128 L p .707 .577 .707 r
F P
0 g
s
.50804 .84292 m .50804 .8244 L .5244 .81703 L p .707 .577 .707 r
F P
0 g
s
.28495 .82434 m .28495 .84287 L .31434 .83949 L p .707 .577 .707 r
F P
0 g
s
.31434 .83949 m .31434 .82096 L .28495 .82434 L p .707 .577 .707 r
F P
0 g
s
.17343 .68834 m .17343 .74392 L .19449 .75038 L p .707 .577 .707 r
F P
0 g
s
.22195 .82322 m .22195 .84174 L .25312 .84365 L p .707 .577 .707 r
F P
0 g
s
.5244 .79292 m .5244 .82997 L .50804 .83734 L p .707 .577 .707 r
F P
0 g
s
.22195 .84174 m .22195 .82322 L .19449 .81883 L p .707 .577 .707 r
F P
0 g
s
.66831 .68948 m .66831 .74507 L .64085 .74067 L p .707 .577 .707 r
F P
0 g
s
.5244 .81703 m .5244 .83556 L .50804 .84292 L p .707 .577 .707 r
F P
0 g
s
.31434 .79685 m .31434 .83391 L .33839 .82826 L p .707 .577 .707 r
F P
0 g
s
.33839 .82826 m .33839 .7912 L .31434 .79685 L p .707 .577 .707 r
F P
0 g
s
.19449 .79471 m .19449 .83177 L .22195 .83616 L p .707 .577 .707 r
F P
0 g
s
.17343 .74392 m .17343 .68834 L .16084 .68046 L p .707 .577 .707 r
F P
0 g
s
.35476 .68391 m .35476 .7395 L .36184 .73113 L p .707 .577 .707 r
F P
0 g
s
.36184 .73113 m .36184 .67555 L .35476 .68391 L p .707 .577 .707 r
F P
0 g
s
.36184 .67555 m .36184 .73113 L .35894 .72259 L p .707 .577 .707 r
F P
0 g
s
.35894 .72259 m .35894 .66701 L .36184 .67555 L p .707 .577 .707 r
F P
0 g
s
.36016 .73716 m .36016 .23527 L .35607 .22321 L p .707 .577 .707 r
F P
0 g
s
.36016 .23527 m .36016 .73716 L .37794 .74829 L p .707 .577 .707 r
F P
0 g
s
.68936 .79586 m .68936 .83291 L .66831 .82646 L p .707 .577 .707 r
F P
0 g
s
.66831 .82646 m .66831 .7894 L .68936 .79586 L p .707 .577 .707 r
F P
0 g
s
.19449 .81883 m .19449 .83735 L .22195 .84174 L p .707 .577 .707 r
F P
0 g
s
.31434 .82096 m .31434 .83949 L .33839 .83384 L p .707 .577 .707 r
F P
0 g
s
.33839 .83384 m .33839 .81531 L .31434 .82096 L p .707 .577 .707 r
F P
0 g
s
.19449 .83177 m .19449 .79471 L .17343 .78826 L p .707 .577 .707 r
F P
0 g
s
.68936 .81997 m .68936 .8385 L .66831 .83204 L p .707 .577 .707 r
F P
0 g
s
.66831 .83204 m .66831 .81352 L .68936 .81997 L p .707 .577 .707 r
F P
0 g
s
.5244 .82997 m .5244 .79292 L .54846 .78727 L p .707 .577 .707 r
F P
0 g
s
.19449 .83735 m .19449 .81883 L .17343 .81237 L p .707 .577 .707 r
F P
0 g
s
.17343 .78826 m .17343 .82531 L .19449 .83177 L p .707 .577 .707 r
F P
0 g
s
.16084 .68046 m .16084 .73604 L .17343 .74392 L p .707 .577 .707 r
F P
0 g
s
.17343 .81237 m .17343 .8309 L .19449 .83735 L p .707 .577 .707 r
F P
0 g
s
.33839 .7912 m .33839 .82826 L .35476 .82089 L p .707 .577 .707 r
F P
0 g
s
.35476 .82089 m .35476 .78383 L .33839 .7912 L p .707 .577 .707 r
F P
0 g
s
.5244 .83556 m .5244 .81703 L .54846 .81138 L p .707 .577 .707 r
F P
0 g
s
.54846 .78727 m .54846 .82432 L .5244 .82997 L p .707 .577 .707 r
F P
0 g
s
.54846 .81138 m .54846 .82991 L .5244 .83556 L p .707 .577 .707 r
F P
0 g
s
.66831 .7894 m .66831 .82646 L .64085 .82207 L p .707 .577 .707 r
F P
0 g
s
.64085 .82207 m .64085 .78501 L .66831 .7894 L p .707 .577 .707 r
F P
0 g
s
.33839 .81531 m .33839 .83384 L .35476 .82647 L p .707 .577 .707 r
F P
0 g
s
.35476 .82647 m .35476 .80794 L .33839 .81531 L p .707 .577 .707 r
F P
0 g
s
.64393 .22835 m .64393 .73023 L .63984 .71818 L p .707 .577 .707 r
F P
0 g
s
.63984 .71818 m .63984 .21629 L .64393 .22835 L p .707 .577 .707 r
F P
0 g
s
.17343 .82531 m .17343 .78826 L .16084 .78038 L p .707 .577 .707 r
F P
0 g
s
.16084 .73604 m .16084 .68046 L .15794 .67191 L p .707 .577 .707 r
F P
0 g
s
.66831 .81352 m .66831 .83204 L .64085 .82765 L p .707 .577 .707 r
F P
0 g
s
.64085 .82765 m .64085 .80912 L .66831 .81352 L p .707 .577 .707 r
F P
0 g
s
.54846 .82432 m .54846 .78727 L .57784 .78389 L p .707 .577 .707 r
F P
0 g
s
.17343 .8309 m .17343 .81237 L .16084 .80449 L p .707 .577 .707 r
F P
0 g
s
.54846 .82991 m .54846 .81138 L .57784 .808 L p .707 .577 .707 r
F P
0 g
s
.16084 .78038 m .16084 .81743 L .17343 .82531 L p .707 .577 .707 r
F P
0 g
s
.64085 .78501 m .64085 .82207 L .60968 .82017 L p .707 .577 .707 r
F P
0 g
s
.60968 .82017 m .60968 .78311 L .64085 .78501 L p .707 .577 .707 r
F P
0 g
s
.16084 .80449 m .16084 .82301 L .17343 .8309 L p .707 .577 .707 r
F P
0 g
s
.57784 .78389 m .57784 .82094 L .54846 .82432 L p .707 .577 .707 r
F P
0 g
s
.57784 .808 m .57784 .82653 L .54846 .82991 L p .707 .577 .707 r
F P
0 g
s
.57784 .82094 m .57784 .78389 L .60968 .78311 L p .707 .577 .707 r
F P
0 g
s
.35894 .66701 m .35894 .72259 L .34635 .71471 L p .707 .577 .707 r
F P
0 g
s
.34635 .71471 m .34635 .65912 L .35894 .66701 L p .707 .577 .707 r
F P
0 g
s
.35607 .22321 m .35607 .7251 L .36016 .73716 L p .707 .577 .707 r
F P
0 g
s
.35607 .7251 m .35607 .22321 L .36607 .21141 L p .707 .577 .707 r
F P
0 g
s
.35476 .78383 m .35476 .82089 L .36184 .81252 L p .707 .577 .707 r
F P
0 g
s
.36184 .81252 m .36184 .77547 L .35476 .78383 L p .707 .577 .707 r
F P
0 g
s
.15794 .67191 m .15794 .7275 L .16084 .73604 L p .707 .577 .707 r
F P
0 g
s
.64085 .80912 m .64085 .82765 L .60968 .82575 L p .707 .577 .707 r
F P
0 g
s
.60968 .82575 m .60968 .80722 L .64085 .80912 L p .707 .577 .707 r
F P
0 g
s
.60968 .78311 m .60968 .82017 L .57784 .82094 L p .707 .577 .707 r
F P
0 g
s
.57784 .82653 m .57784 .808 L .60968 .80722 L p .707 .577 .707 r
F P
0 g
s
.35476 .80794 m .35476 .82647 L .36184 .81811 L p .707 .577 .707 r
F P
0 g
s
.36184 .81811 m .36184 .79958 L .35476 .80794 L p .707 .577 .707 r
F P
0 g
s
.60968 .80722 m .60968 .82575 L .57784 .82653 L p .707 .577 .707 r
F P
0 g
s
.16084 .81743 m .16084 .78038 L .15794 .77183 L p .707 .577 .707 r
F P
0 g
s
.15794 .7275 m .15794 .67191 L .16503 .66355 L p .707 .577 .707 r
F P
0 g
s
.16084 .82301 m .16084 .80449 L .15794 .79594 L p .707 .577 .707 r
F P
0 g
s
.15794 .77183 m .15794 .80889 L .16084 .81743 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .79594 m .15794 .81447 L .16084 .82301 L p .707 .577 .707 r
F P
0 g
s
.63984 .21629 m .63984 .71818 L .62206 .70704 L p .707 .577 .707 r
F P
0 g
s
.62206 .70704 m .62206 .20516 L .63984 .21629 L p .707 .577 .707 r
F P
0 g
s
.36184 .77547 m .36184 .81252 L .35894 .80398 L p .707 .577 .707 r
F P
0 g
s
.35894 .80398 m .35894 .76693 L .36184 .77547 L p .707 .577 .707 r
F P
0 g
s
.16503 .66355 m .16503 .71913 L .15794 .7275 L p .707 .577 .707 r
F P
0 g
s
.36184 .79958 m .36184 .81811 L .35894 .80957 L p .707 .577 .707 r
F P
0 g
s
.35894 .80957 m .35894 .79104 L .36184 .79958 L p .707 .577 .707 r
F P
0 g
s
.36607 .71329 m .36607 .21141 L .38918 .201 L p .707 .577 .707 r
F P
0 g
s
.36607 .21141 m .36607 .71329 L .35607 .7251 L p .707 .577 .707 r
F P
0 g
s
.15794 .80889 m .15794 .77183 L .16503 .76347 L p .707 .577 .707 r
F P
0 g
s
.16503 .71913 m .16503 .66355 L .1814 .65618 L p .707 .577 .707 r
F P
0 g
s
.15794 .81447 m .15794 .79594 L .16503 .78758 L p .707 .577 .707 r
F P
0 g
s
.16503 .76347 m .16503 .80052 L .15794 .80889 L p .707 .577 .707 r
F P
0 g
s
.16503 .78758 m .16503 .80611 L .15794 .81447 L p .707 .577 .707 r
F P
0 g
s
.35894 .76693 m .35894 .80398 L .34635 .7961 L p .707 .577 .707 r
F P
0 g
s
.34635 .7961 m .34635 .75904 L .35894 .76693 L p .707 .577 .707 r
F P
0 g
s
.1814 .65618 m .1814 .71176 L .16503 .71913 L p .707 .577 .707 r
F P
0 g
s
.34635 .65912 m .34635 .71471 L .3253 .70825 L p .707 .577 .707 r
F P
0 g
s
.3253 .70825 m .3253 .65267 L .34635 .65912 L p .707 .577 .707 r
F P
0 g
s
.62206 .20516 m .62206 .70704 L .59233 .69793 L p .707 .577 .707 r
F P
0 g
s
.59233 .69793 m .59233 .19604 L .62206 .20516 L p .707 .577 .707 r
F P
0 g
s
.35894 .79104 m .35894 .80957 L .34635 .80168 L p .707 .577 .707 r
F P
0 g
s
.34635 .80168 m .34635 .78315 L .35894 .79104 L p .707 .577 .707 r
F P
0 g
s
.1814 .71176 m .1814 .65618 L .20545 .65053 L p .707 .577 .707 r
F P
0 g
s
.16503 .80052 m .16503 .76347 L .1814 .7561 L p .707 .577 .707 r
F P
0 g
s
.38918 .201 m .38918 .70289 L .36607 .71329 L p .707 .577 .707 r
F P
0 g
s
.38918 .70289 m .38918 .201 L .42314 .19303 L p .707 .577 .707 r
F P
0 g
s
.16503 .80611 m .16503 .78758 L .1814 .78021 L p .707 .577 .707 r
F P
0 g
s
.1814 .7561 m .1814 .79316 L .16503 .80052 L p .707 .577 .707 r
F P
0 g
s
.3253 .65267 m .3253 .70825 L .29784 .70386 L p .707 .577 .707 r
F P
0 g
s
.29784 .70386 m .29784 .64828 L .3253 .65267 L p .707 .577 .707 r
F P
0 g
s
.1814 .78021 m .1814 .79874 L .16503 .80611 L p .707 .577 .707 r
F P
0 g
s
.20545 .65053 m .20545 .70611 L .1814 .71176 L p .707 .577 .707 r
F P
0 g
s
.34635 .75904 m .34635 .7961 L .3253 .78964 L p .707 .577 .707 r
F P
0 g
s
.3253 .78964 m .3253 .75259 L .34635 .75904 L p .707 .577 .707 r
F P
0 g
s
.20545 .70611 m .20545 .65053 L .23483 .64715 L p .707 .577 .707 r
F P
0 g
s
.34635 .78315 m .34635 .80168 L .3253 .79523 L p .707 .577 .707 r
F P
0 g
s
.3253 .79523 m .3253 .7767 L .34635 .78315 L p .707 .577 .707 r
F P
0 g
s
.59233 .19604 m .59233 .69793 L .55357 .69173 L p .707 .577 .707 r
F P
0 g
s
.55357 .69173 m .55357 .18984 L .59233 .19604 L p .707 .577 .707 r
F P
0 g
s
.1814 .79316 m .1814 .7561 L .20545 .75045 L p .707 .577 .707 r
F P
0 g
s
.29784 .64828 m .29784 .70386 L .26667 .70196 L p .707 .577 .707 r
F P
0 g
s
.26667 .70196 m .26667 .64638 L .29784 .64828 L p .707 .577 .707 r
F P
0 g
s
.23483 .70274 m .23483 .64715 L .26667 .64638 L p .707 .577 .707 r
F P
0 g
s
.23483 .64715 m .23483 .70274 L .20545 .70611 L p .707 .577 .707 r
F P
0 g
s
.1814 .79874 m .1814 .78021 L .20545 .77456 L p .707 .577 .707 r
F P
0 g
s
.26667 .64638 m .26667 .70196 L .23483 .70274 L p .707 .577 .707 r
F P
0 g
s
.42314 .69492 m .42314 .19303 L .46462 .18826 L p .707 .577 .707 r
F P
0 g
s
.42314 .19303 m .42314 .69492 L .38918 .70289 L p .707 .577 .707 r
F P
0 g
s
.73333 .70145 m .73333 .64586 L .70216 .64396 L p .707 .577 .707 r
F P
0 g
s
.73333 .64586 m .73333 .70145 L .76517 .70067 L p .707 .577 .707 r
F P
0 g
s
.76517 .70067 m .76517 .64509 L .73333 .64586 L p .707 .577 .707 r
F P
0 g
s
.20545 .75045 m .20545 .78751 L .1814 .79316 L p .707 .577 .707 r
F P
0 g
s
.20545 .77456 m .20545 .79309 L .1814 .79874 L p .707 .577 .707 r
F P
0 g
s
.76517 .64509 m .76517 .70067 L .79455 .69729 L p .707 .577 .707 r
F P
0 g
s
.79455 .69729 m .79455 .64171 L .76517 .64509 L p .707 .577 .707 r
F P
0 g
s
.3253 .75259 m .3253 .78964 L .29784 .78525 L p .707 .577 .707 r
F P
0 g
s
.29784 .78525 m .29784 .7482 L .3253 .75259 L p .707 .577 .707 r
F P
0 g
s
.70216 .69955 m .70216 .64396 L .6747 .63957 L p .707 .577 .707 r
F P
0 g
s
.70216 .64396 m .70216 .69955 L .73333 .70145 L p .707 .577 .707 r
F P
0 g
s
.3253 .7767 m .3253 .79523 L .29784 .79084 L p .707 .577 .707 r
F P
0 g
s
.29784 .79084 m .29784 .77231 L .3253 .7767 L p .707 .577 .707 r
F P
0 g
s
.55357 .18984 m .55357 .69173 L .50956 .68905 L p .707 .577 .707 r
F P
0 g
s
.50956 .68905 m .50956 .18716 L .55357 .18984 L p .707 .577 .707 r
F P
0 g
s
.20545 .78751 m .20545 .75045 L .23483 .74707 L p .707 .577 .707 r
F P
0 g
s
.79455 .64171 m .79455 .69729 L .8186 .69164 L p .707 .577 .707 r
F P
0 g
s
.8186 .69164 m .8186 .63606 L .79455 .64171 L p .707 .577 .707 r
F P
0 g
s
.46462 .69015 m .46462 .18826 L .50956 .18716 L p .707 .577 .707 r
F P
0 g
s
.46462 .18826 m .46462 .69015 L .42314 .69492 L p .707 .577 .707 r
F P
0 g
s
.20545 .79309 m .20545 .77456 L .23483 .77118 L p .707 .577 .707 r
F P
0 g
s
.29784 .7482 m .29784 .78525 L .26667 .78335 L p .707 .577 .707 r
F P
0 g
s
.26667 .78335 m .26667 .7463 L .29784 .7482 L p .707 .577 .707 r
F P
0 g
s
.50956 .18716 m .50956 .68905 L .46462 .69015 L p .707 .577 .707 r
F P
0 g
s
.23483 .74707 m .23483 .78413 L .20545 .78751 L p .707 .577 .707 r
F P
0 g
s
.6747 .63957 m .6747 .69515 L .70216 .69955 L p .707 .577 .707 r
F P
0 g
s
.6747 .69515 m .6747 .63957 L .65365 .63312 L p .707 .577 .707 r
F P
0 g
s
.23483 .77118 m .23483 .78971 L .20545 .79309 L p .707 .577 .707 r
F P
0 g
s
.23483 .78413 m .23483 .74707 L .26667 .7463 L p .707 .577 .707 r
F P
0 g
s
.29784 .77231 m .29784 .79084 L .26667 .78893 L p .707 .577 .707 r
F P
0 g
s
.26667 .78893 m .26667 .77041 L .29784 .77231 L p .707 .577 .707 r
F P
0 g
s
.26667 .7463 m .26667 .78335 L .23483 .78413 L p .707 .577 .707 r
F P
0 g
s
.73333 .78284 m .73333 .74578 L .70216 .74388 L p .707 .577 .707 r
F P
0 g
s
.73333 .74578 m .73333 .78284 L .76517 .78206 L p .707 .577 .707 r
F P
0 g
s
.76517 .78206 m .76517 .74501 L .73333 .74578 L p .707 .577 .707 r
F P
0 g
s
.23483 .78971 m .23483 .77118 L .26667 .77041 L p .707 .577 .707 r
F P
0 g
s
.76517 .74501 m .76517 .78206 L .79455 .77868 L p .707 .577 .707 r
F P
0 g
s
.79455 .77868 m .79455 .74163 L .76517 .74501 L p .707 .577 .707 r
F P
0 g
s
.26667 .77041 m .26667 .78893 L .23483 .78971 L p .707 .577 .707 r
F P
0 g
s
.73333 .78842 m .73333 .7699 L .70216 .76799 L p .707 .577 .707 r
F P
0 g
s
.73333 .7699 m .73333 .78842 L .76517 .78765 L p .707 .577 .707 r
F P
0 g
s
.76517 .78765 m .76517 .76912 L .73333 .7699 L p .707 .577 .707 r
F P
0 g
s
.70216 .78094 m .70216 .74388 L .6747 .73949 L p .707 .577 .707 r
F P
0 g
s
.70216 .74388 m .70216 .78094 L .73333 .78284 L p .707 .577 .707 r
F P
0 g
s
.8186 .63606 m .8186 .69164 L .83497 .68427 L p .707 .577 .707 r
F P
0 g
s
.83497 .68427 m .83497 .62869 L .8186 .63606 L p .707 .577 .707 r
F P
0 g
s
.76517 .76912 m .76517 .78765 L .79455 .78427 L p .707 .577 .707 r
F P
0 g
s
.79455 .78427 m .79455 .76574 L .76517 .76912 L p .707 .577 .707 r
F P
0 g
s
.65365 .63312 m .65365 .6887 L .6747 .69515 L p .707 .577 .707 r
F P
0 g
s
.70216 .76799 m .70216 .78652 L .73333 .78842 L p .707 .577 .707 r
F P
0 g
s
.70216 .78652 m .70216 .76799 L .6747 .7636 L p .707 .577 .707 r
F P
0 g
s
.79455 .74163 m .79455 .77868 L .8186 .77303 L p .707 .577 .707 r
F P
0 g
s
.8186 .77303 m .8186 .73598 L .79455 .74163 L p .707 .577 .707 r
F P
0 g
s
.6747 .73949 m .6747 .77655 L .70216 .78094 L p .707 .577 .707 r
F P
0 g
s
.65365 .6887 m .65365 .63312 L .64105 .62523 L p .707 .577 .707 r
F P
0 g
s
.6747 .7636 m .6747 .78213 L .70216 .78652 L p .707 .577 .707 r
F P
0 g
s
.79455 .76574 m .79455 .78427 L .8186 .77862 L p .707 .577 .707 r
F P
0 g
s
.8186 .77862 m .8186 .76009 L .79455 .76574 L p .707 .577 .707 r
F P
0 g
s
.6747 .77655 m .6747 .73949 L .65365 .73304 L p .707 .577 .707 r
F P
0 g
s
.6747 .78213 m .6747 .7636 L .65365 .75715 L p .707 .577 .707 r
F P
0 g
s
.65365 .73304 m .65365 .77009 L .6747 .77655 L p .707 .577 .707 r
F P
0 g
s
.64105 .62523 m .64105 .68082 L .65365 .6887 L p .707 .577 .707 r
F P
0 g
s
.83497 .62869 m .83497 .68427 L .84206 .67591 L p .707 .577 .707 r
F P
0 g
s
.84206 .67591 m .84205 .62033 L .83497 .62869 L p .707 .577 .707 r
F P
0 g
s
.65365 .75715 m .65365 .77568 L .6747 .78213 L p .707 .577 .707 r
F P
0 g
s
.8186 .73598 m .8186 .77303 L .83497 .76567 L p .707 .577 .707 r
F P
0 g
s
.83497 .76567 m .83497 .72861 L .8186 .73598 L p .707 .577 .707 r
F P
0 g
s
.8186 .76009 m .8186 .77862 L .83497 .77125 L p .707 .577 .707 r
F P
0 g
s
.83497 .77125 m .83497 .75272 L .8186 .76009 L p .707 .577 .707 r
F P
0 g
s
.65365 .77009 m .65365 .73304 L .64105 .72515 L p .707 .577 .707 r
F P
0 g
s
.64105 .68082 m .64105 .62523 L .63816 .61669 L p .707 .577 .707 r
F P
0 g
s
.65365 .77568 m .65365 .75715 L .64105 .74926 L p .707 .577 .707 r
F P
0 g
s
.64105 .72515 m .64105 .76221 L .65365 .77009 L p .707 .577 .707 r
F P
0 g
s
.64105 .74926 m .64105 .76779 L .65365 .77568 L p .707 .577 .707 r
F P
0 g
s
.83497 .72861 m .83497 .76567 L .84206 .7573 L p .707 .577 .707 r
F P
0 g
s
.84206 .7573 m .84206 .72025 L .83497 .72861 L p .707 .577 .707 r
F P
0 g
s
.63816 .61669 m .63816 .67227 L .64105 .68082 L p .707 .577 .707 r
F P
0 g
s
.84205 .62033 m .84206 .67591 L .83916 .66737 L p .707 .577 .707 r
F P
0 g
s
.83916 .66737 m .83916 .61178 L .84205 .62033 L p .707 .577 .707 r
F P
0 g
s
.83497 .75272 m .83497 .77125 L .84206 .76288 L p .707 .577 .707 r
F P
0 g
s
.84206 .76288 m .84206 .74436 L .83497 .75272 L p .707 .577 .707 r
F P
0 g
s
.64105 .76221 m .64105 .72515 L .63816 .71661 L p .707 .577 .707 r
F P
0 g
s
.63816 .67227 m .63816 .61669 L .64524 .60833 L p .707 .577 .707 r
F P
0 g
s
.64105 .76779 m .64105 .74926 L .63816 .74072 L p .707 .577 .707 r
F P
0 g
s
.63816 .71661 m .63816 .75367 L .64105 .76221 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .74072 m .63816 .75925 L .64105 .76779 L p .707 .577 .707 r
F P
0 g
s
.84206 .72025 m .84206 .7573 L .83916 .74876 L p .707 .577 .707 r
F P
0 g
s
.83916 .74876 m .83916 .7117 L .84206 .72025 L p .707 .577 .707 r
F P
0 g
s
.64524 .60833 m .64524 .66391 L .63816 .67227 L p .707 .577 .707 r
F P
0 g
s
.83916 .61178 m .83916 .66737 L .82657 .65948 L p .707 .577 .707 r
F P
0 g
s
.82657 .65948 m .82657 .6039 L .83916 .61178 L p .707 .577 .707 r
F P
0 g
s
.84206 .74436 m .84206 .76288 L .83916 .75434 L p .707 .577 .707 r
F P
0 g
s
.83916 .75434 m .83916 .73581 L .84206 .74436 L p .707 .577 .707 r
F P
0 g
s
.39032 .66463 m .39032 .60905 L .35915 .60715 L p .707 .577 .707 r
F P
0 g
s
.39032 .60905 m .39032 .66463 L .42216 .66385 L p .707 .577 .707 r
F P
0 g
s
.42216 .66385 m .42216 .60827 L .39032 .60905 L p .707 .577 .707 r
F P
0 g
s
.63816 .75367 m .63816 .71661 L .64524 .70825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66391 m .64524 .60833 L .66161 .60096 L p .707 .577 .707 r
F P
0 g
s
.42216 .60827 m .42216 .66385 L .45154 .66048 L p .707 .577 .707 r
F P
0 g
s
.45154 .66048 m .45154 .60489 L .42216 .60827 L p .707 .577 .707 r
F P
0 g
s
.35915 .66273 m .35915 .60715 L .33169 .60276 L p .707 .577 .707 r
F P
0 g
s
.35915 .60715 m .35915 .66273 L .39032 .66463 L p .707 .577 .707 r
F P
0 g
s
.63816 .75925 m .63816 .74072 L .64524 .73236 L p .707 .577 .707 r
F P
0 g
s
.64524 .70825 m .64524 .7453 L .63816 .75367 L p .707 .577 .707 r
F P
0 g
s
.64524 .73236 m .64524 .75089 L .63816 .75925 L p .707 .577 .707 r
F P
0 g
s
.45154 .60489 m .45154 .66048 L .47559 .65483 L p .707 .577 .707 r
F P
0 g
s
.47559 .65483 m .47559 .59924 L .45154 .60489 L p .707 .577 .707 r
F P
0 g
s
.83916 .7117 m .83916 .74876 L .82657 .74087 L p .707 .577 .707 r
F P
0 g
s
.82657 .74087 m .82657 .70382 L .83916 .7117 L p .707 .577 .707 r
F P
0 g
s
.66161 .60096 m .66161 .65654 L .64524 .66391 L p .707 .577 .707 r
F P
0 g
s
.82657 .6039 m .82657 .65948 L .80551 .65303 L p .707 .577 .707 r
F P
0 g
s
.80551 .65303 m .80551 .59745 L .82657 .6039 L p .707 .577 .707 r
F P
0 g
s
.33169 .60276 m .33169 .65834 L .35915 .66273 L p .707 .577 .707 r
F P
0 g
s
.33169 .65834 m .33169 .60276 L .31064 .5963 L p .707 .577 .707 r
F P
0 g
s
.83916 .73581 m .83916 .75434 L .82657 .74646 L p .707 .577 .707 r
F P
0 g
s
.82657 .74646 m .82657 .72793 L .83916 .73581 L p .707 .577 .707 r
F P
0 g
s
.39032 .74602 m .39032 .70897 L .35915 .70707 L p .707 .577 .707 r
F P
0 g
s
.39032 .70897 m .39032 .74602 L .42216 .74525 L p .707 .577 .707 r
F P
0 g
s
.42216 .74525 m .42216 .70819 L .39032 .70897 L p .707 .577 .707 r
F P
0 g
s
.66161 .65654 m .66161 .60096 L .68566 .59531 L p .707 .577 .707 r
F P
0 g
s
.64524 .7453 m .64524 .70825 L .66161 .70088 L p .707 .577 .707 r
F P
0 g
s
.42216 .70819 m .42216 .74525 L .45154 .74187 L p .707 .577 .707 r
F P
0 g
s
.45154 .74187 m .45154 .70481 L .42216 .70819 L p .707 .577 .707 r
F P
0 g
s
.39032 .75161 m .39032 .73308 L .35915 .73118 L p .707 .577 .707 r
F P
0 g
s
.39032 .73308 m .39032 .75161 L .42216 .75083 L p .707 .577 .707 r
F P
0 g
s
.42216 .75083 m .42216 .7323 L .39032 .73308 L p .707 .577 .707 r
F P
0 g
s
.35915 .74412 m .35915 .70707 L .33169 .70268 L p .707 .577 .707 r
F P
0 g
s
.35915 .70707 m .35915 .74412 L .39032 .74602 L p .707 .577 .707 r
F P
0 g
s
.47559 .59924 m .47559 .65483 L .49196 .64746 L p .707 .577 .707 r
F P
0 g
s
.49196 .64746 m .49196 .59188 L .47559 .59924 L p .707 .577 .707 r
F P
0 g
s
.64524 .75089 m .64524 .73236 L .66161 .72499 L p .707 .577 .707 r
F P
0 g
s
.42216 .7323 m .42216 .75083 L .45154 .74745 L p .707 .577 .707 r
F P
0 g
s
.45154 .74745 m .45154 .72892 L .42216 .7323 L p .707 .577 .707 r
F P
0 g
s
.31064 .5963 m .31064 .65188 L .33169 .65834 L p .707 .577 .707 r
F P
0 g
s
.35915 .73118 m .35915 .74971 L .39032 .75161 L p .707 .577 .707 r
F P
0 g
s
.66161 .70088 m .66161 .73793 L .64524 .7453 L p .707 .577 .707 r
F P
0 g
s
.35915 .74971 m .35915 .73118 L .33169 .72679 L p .707 .577 .707 r
F P
0 g
s
.80551 .59745 m .80551 .65303 L .77805 .64864 L p .707 .577 .707 r
F P
0 g
s
.77805 .64864 m .77805 .59305 L .80551 .59745 L p .707 .577 .707 r
F P
0 g
s
.66161 .72499 m .66161 .74352 L .64524 .75089 L p .707 .577 .707 r
F P
0 g
s
.45154 .70481 m .45154 .74187 L .47559 .73622 L p .707 .577 .707 r
F P
0 g
s
.47559 .73622 m .47559 .69916 L .45154 .70481 L p .707 .577 .707 r
F P
0 g
s
.68566 .59531 m .68566 .65089 L .66161 .65654 L p .707 .577 .707 r
F P
0 g
s
.33169 .70268 m .33169 .73973 L .35915 .74412 L p .707 .577 .707 r
F P
0 g
s
.31064 .65188 m .31064 .5963 L .29804 .58842 L p .707 .577 .707 r
F P
0 g
s
.82657 .70382 m .82657 .74087 L .80551 .73442 L p .707 .577 .707 r
F P
0 g
s
.80551 .73442 m .80551 .69737 L .82657 .70382 L p .707 .577 .707 r
F P
0 g
s
.33169 .72679 m .33169 .74531 L .35915 .74971 L p .707 .577 .707 r
F P
0 g
s
.68566 .65089 m .68566 .59531 L .71504 .59193 L p .707 .577 .707 r
F P
0 g
s
.45154 .72892 m .45154 .74745 L .47559 .7418 L p .707 .577 .707 r
F P
0 g
s
.47559 .7418 m .47559 .72327 L .45154 .72892 L p .707 .577 .707 r
F P
0 g
s
.33169 .73973 m .33169 .70268 L .31064 .69622 L p .707 .577 .707 r
F P
0 g
s
.82657 .72793 m .82657 .74646 L .80551 .74 L p .707 .577 .707 r
F P
0 g
s
.80551 .74 m .80551 .72148 L .82657 .72793 L p .707 .577 .707 r
F P
0 g
s
.66161 .73793 m .66161 .70088 L .68566 .69523 L p .707 .577 .707 r
F P
0 g
s
.33169 .74531 m .33169 .72679 L .31064 .72033 L p .707 .577 .707 r
F P
0 g
s
.77805 .59305 m .77805 .64864 L .74688 .64674 L p .707 .577 .707 r
F P
0 g
s
.74688 .64674 m .74688 .59115 L .77805 .59305 L p .707 .577 .707 r
F P
0 g
s
.31064 .69622 m .31064 .73328 L .33169 .73973 L p .707 .577 .707 r
F P
0 g
s
.29804 .58842 m .29804 .644 L .31064 .65188 L p .707 .577 .707 r
F P
0 g
s
.71504 .64751 m .71504 .59193 L .74688 .59115 L p .707 .577 .707 r
F P
0 g
s
.71504 .59193 m .71504 .64751 L .68566 .65089 L p .707 .577 .707 r
F P
0 g
s
.49196 .59188 m .49196 .64746 L .49904 .63909 L p .707 .577 .707 r
F P
0 g
s
.49904 .63909 m .49904 .58351 L .49196 .59188 L p .707 .577 .707 r
F P
0 g
s
.31064 .72033 m .31064 .73886 L .33169 .74531 L p .707 .577 .707 r
F P
0 g
s
.47559 .69916 m .47559 .73622 L .49196 .72885 L p .707 .577 .707 r
F P
0 g
s
.49196 .72885 m .49196 .69179 L .47559 .69916 L p .707 .577 .707 r
F P
0 g
s
.66161 .74352 m .66161 .72499 L .68566 .71934 L p .707 .577 .707 r
F P
0 g
s
.74688 .59115 m .74688 .64674 L .71504 .64751 L p .707 .577 .707 r
F P
0 g
s
.68566 .69523 m .68566 .73228 L .66161 .73793 L p .707 .577 .707 r
F P
0 g
s
.68566 .71934 m .68566 .73787 L .66161 .74352 L p .707 .577 .707 r
F P
0 g
s
.80551 .69737 m .80551 .73442 L .77805 .73003 L p .707 .577 .707 r
F P
0 g
s
.77805 .73003 m .77805 .69297 L .80551 .69737 L p .707 .577 .707 r
F P
0 g
s
.47559 .72327 m .47559 .7418 L .49196 .73443 L p .707 .577 .707 r
F P
0 g
s
.49196 .73443 m .49196 .71591 L .47559 .72327 L p .707 .577 .707 r
F P
0 g
s
.31064 .73328 m .31064 .69622 L .29804 .68834 L p .707 .577 .707 r
F P
0 g
s
.29804 .644 m .29804 .58842 L .29515 .57988 L p .707 .577 .707 r
F P
0 g
s
.80551 .72148 m .80551 .74 L .77805 .73561 L p .707 .577 .707 r
F P
0 g
s
.77805 .73561 m .77805 .71708 L .80551 .72148 L p .707 .577 .707 r
F P
0 g
s
.68566 .73228 m .68566 .69523 L .71504 .69185 L p .707 .577 .707 r
F P
0 g
s
.31064 .73886 m .31064 .72033 L .29804 .71245 L p .707 .577 .707 r
F P
0 g
s
.68566 .73787 m .68566 .71934 L .71504 .71596 L p .707 .577 .707 r
F P
0 g
s
.29804 .68834 m .29804 .72539 L .31064 .73328 L p .707 .577 .707 r
F P
0 g
s
.77805 .69297 m .77805 .73003 L .74688 .72813 L p .707 .577 .707 r
F P
0 g
s
.74688 .72813 m .74688 .69107 L .77805 .69297 L p .707 .577 .707 r
F P
0 g
s
.29804 .71245 m .29804 .73098 L .31064 .73886 L p .707 .577 .707 r
F P
0 g
s
.71504 .69185 m .71504 .7289 L .68566 .73228 L p .707 .577 .707 r
F P
0 g
s
.71504 .71596 m .71504 .73449 L .68566 .73787 L p .707 .577 .707 r
F P
0 g
s
.71504 .7289 m .71504 .69185 L .74688 .69107 L p .707 .577 .707 r
F P
0 g
s
.49196 .69179 m .49196 .72885 L .49904 .72049 L p .707 .577 .707 r
F P
0 g
s
.49904 .72049 m .49904 .68343 L .49196 .69179 L p .707 .577 .707 r
F P
0 g
s
.29515 .57988 m .29515 .63546 L .29804 .644 L p .707 .577 .707 r
F P
0 g
s
.49904 .58351 m .49904 .63909 L .49615 .63055 L p .707 .577 .707 r
F P
0 g
s
.49615 .63055 m .49615 .57497 L .49904 .58351 L p .707 .577 .707 r
F P
0 g
s
.77805 .71708 m .77805 .73561 L .74688 .73371 L p .707 .577 .707 r
F P
0 g
s
.74688 .73371 m .74688 .71518 L .77805 .71708 L p .707 .577 .707 r
F P
0 g
s
.74688 .69107 m .74688 .72813 L .71504 .7289 L p .707 .577 .707 r
F P
0 g
s
.71504 .73449 m .71504 .71596 L .74688 .71518 L p .707 .577 .707 r
F P
0 g
s
.49196 .71591 m .49196 .73443 L .49904 .72607 L p .707 .577 .707 r
F P
0 g
s
.49904 .72607 m .49904 .70754 L .49196 .71591 L p .707 .577 .707 r
F P
0 g
s
.74688 .71518 m .74688 .73371 L .71504 .73449 L p .707 .577 .707 r
F P
0 g
s
.29804 .72539 m .29804 .68834 L .29515 .6798 L p .707 .577 .707 r
F P
0 g
s
.29515 .63546 m .29515 .57988 L .30223 .57151 L p .707 .577 .707 r
F P
0 g
s
.29804 .73098 m .29804 .71245 L .29515 .70391 L p .707 .577 .707 r
F P
0 g
s
.29515 .6798 m .29515 .71685 L .29804 .72539 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .70391 m .29515 .72243 L .29804 .73098 L p .707 .577 .707 r
F P
0 g
s
.49904 .68343 m .49904 .72049 L .49615 .71194 L p .707 .577 .707 r
F P
0 g
s
.49615 .71194 m .49615 .67489 L .49904 .68343 L p .707 .577 .707 r
F P
0 g
s
.30223 .57151 m .30223 .62709 L .29515 .63546 L p .707 .577 .707 r
F P
0 g
s
.49615 .57497 m .49615 .63055 L .48356 .62267 L p .707 .577 .707 r
F P
0 g
s
.48356 .62267 m .48356 .56708 L .49615 .57497 L p .707 .577 .707 r
F P
0 g
s
.49904 .70754 m .49904 .72607 L .49615 .71753 L p .707 .577 .707 r
F P
0 g
s
.49615 .71753 m .49615 .699 L .49904 .70754 L p .707 .577 .707 r
F P
0 g
s
.29515 .71685 m .29515 .6798 L .30223 .67143 L p .707 .577 .707 r
F P
0 g
s
.30223 .62709 m .30223 .57151 L .3186 .56414 L p .707 .577 .707 r
F P
0 g
s
.29515 .72243 m .29515 .70391 L .30223 .69554 L p .707 .577 .707 r
F P
0 g
s
.30223 .67143 m .30223 .70849 L .29515 .71685 L p .707 .577 .707 r
F P
0 g
s
.30223 .69554 m .30223 .71407 L .29515 .72243 L p .707 .577 .707 r
F P
0 g
s
.49615 .67489 m .49615 .71194 L .48356 .70406 L p .707 .577 .707 r
F P
0 g
s
.48356 .70406 m .48356 .667 L .49615 .67489 L p .707 .577 .707 r
F P
0 g
s
.3186 .56414 m .3186 .61973 L .30223 .62709 L p .707 .577 .707 r
F P
0 g
s
.48356 .56708 m .48356 .62267 L .4625 .61621 L p .707 .577 .707 r
F P
0 g
s
.4625 .61621 m .4625 .56063 L .48356 .56708 L p .707 .577 .707 r
F P
0 g
s
.49615 .699 m .49615 .71753 L .48356 .70964 L p .707 .577 .707 r
F P
0 g
s
.48356 .70964 m .48356 .69112 L .49615 .699 L p .707 .577 .707 r
F P
0 g
s
.3186 .61973 m .3186 .56414 L .34265 .55849 L p .707 .577 .707 r
F P
0 g
s
.30223 .70849 m .30223 .67143 L .3186 .66406 L p .707 .577 .707 r
F P
0 g
s
.30223 .71407 m .30223 .69554 L .3186 .68817 L p .707 .577 .707 r
F P
0 g
s
.3186 .66406 m .3186 .70112 L .30223 .70849 L p .707 .577 .707 r
F P
0 g
s
.4625 .56063 m .4625 .61621 L .43504 .61182 L p .707 .577 .707 r
F P
0 g
s
.43504 .61182 m .43504 .55624 L .4625 .56063 L p .707 .577 .707 r
F P
0 g
s
.3186 .68817 m .3186 .7067 L .30223 .71407 L p .707 .577 .707 r
F P
0 g
s
.34265 .55849 m .34265 .61408 L .3186 .61973 L p .707 .577 .707 r
F P
0 g
s
.48356 .667 m .48356 .70406 L .4625 .6976 L p .707 .577 .707 r
F P
0 g
s
.4625 .6976 m .4625 .66055 L .48356 .667 L p .707 .577 .707 r
F P
0 g
s
.34265 .61408 m .34265 .55849 L .37203 .55511 L p .707 .577 .707 r
F P
0 g
s
.48356 .69112 m .48356 .70964 L .4625 .70319 L p .707 .577 .707 r
F P
0 g
s
.4625 .70319 m .4625 .68466 L .48356 .69112 L p .707 .577 .707 r
F P
0 g
s
.3186 .70112 m .3186 .66406 L .34265 .65841 L p .707 .577 .707 r
F P
0 g
s
.43504 .55624 m .43504 .61182 L .40387 .60992 L p .707 .577 .707 r
F P
0 g
s
.40387 .60992 m .40387 .55434 L .43504 .55624 L p .707 .577 .707 r
F P
0 g
s
.37203 .6107 m .37203 .55511 L .40387 .55434 L p .707 .577 .707 r
F P
0 g
s
.37203 .55511 m .37203 .6107 L .34265 .61408 L p .707 .577 .707 r
F P
0 g
s
.3186 .7067 m .3186 .68817 L .34265 .68252 L p .707 .577 .707 r
F P
0 g
s
.40387 .55434 m .40387 .60992 L .37203 .6107 L p .707 .577 .707 r
F P
0 g
s
.34265 .65841 m .34265 .69547 L .3186 .70112 L p .707 .577 .707 r
F P
0 g
s
.34265 .68252 m .34265 .70105 L .3186 .7067 L p .707 .577 .707 r
F P
0 g
s
.4625 .66055 m .4625 .6976 L .43504 .69321 L p .707 .577 .707 r
F P
0 g
s
.43504 .69321 m .43504 .65616 L .4625 .66055 L p .707 .577 .707 r
F P
0 g
s
.4625 .68466 m .4625 .70319 L .43504 .6988 L p .707 .577 .707 r
F P
0 g
s
.43504 .6988 m .43504 .68027 L .4625 .68466 L p .707 .577 .707 r
F P
0 g
s
.34265 .69547 m .34265 .65841 L .37203 .65503 L p .707 .577 .707 r
F P
0 g
s
.34265 .70105 m .34265 .68252 L .37203 .67915 L p .707 .577 .707 r
F P
0 g
s
.43504 .65616 m .43504 .69321 L .40387 .69131 L p .707 .577 .707 r
F P
0 g
s
.40387 .69131 m .40387 .65426 L .43504 .65616 L p .707 .577 .707 r
F P
0 g
s
.37203 .65503 m .37203 .69209 L .34265 .69547 L p .707 .577 .707 r
F P
0 g
s
.37203 .67915 m .37203 .69767 L .34265 .70105 L p .707 .577 .707 r
F P
0 g
s
.37203 .69209 m .37203 .65503 L .40387 .65426 L p .707 .577 .707 r
F P
0 g
s
.43504 .68027 m .43504 .6988 L .40387 .6969 L p .707 .577 .707 r
F P
0 g
s
.40387 .6969 m .40387 .67837 L .43504 .68027 L p .707 .577 .707 r
F P
0 g
s
.40387 .65426 m .40387 .69131 L .37203 .69209 L p .707 .577 .707 r
F P
0 g
s
.37203 .69767 m .37203 .67915 L .40387 .67837 L p .707 .577 .707 r
F P
0 g
s
.40387 .67837 m .40387 .6969 L .37203 .69767 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001dOol300000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0071oo`@000AJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006io
o`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001J
EUYFFUH3001^Ool006aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001X
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00003
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@0
05YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH0
0000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Agoo2@0017oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000oOol80004FUH00`00FUIJEP02FUH700000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH300000eYF001JEP06FUHI00000eYF001JEP02FUH50007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031o
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EPD000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF2P001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000eYF00<005YFFUH01eYF2@0025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH000000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YFFUH01EYF1P000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH00004FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00
FUIJEP02FUH00`00FUH00005FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@00=goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0003
FUH00`00FUH00004FUH20002FUH80002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH70004
FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH400000eYF001JEP03FUH500000eYF0000000200001EYF001JEUYF00000eYF0P001EYF
00<005YFFUH01eYF1@000eYF0`0000=JEP00FUH00UYF00<005YFFUH025YF00<005YFFUH025YF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo
00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001J
EP800003FUH0000000AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP<000=JEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`00<7oo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUH005YF10001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000^Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJ
EQ@000EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`06001JEP00001JEP001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00
00800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
0003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP@000IJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000MJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04
001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040003FUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005
FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF1@001EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUHA0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP0000000eYF00<005YFFUH00eYF0P000eYF4P0015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YF00000`00;Goo000]Ool01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P000eYF2000
47oo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUH0009J
EP03001JEP0000D000=JEP8001Eoo`P000AJEP04001JEUYFFUH2000]Ool0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000@000AJEP<0
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH00000009JEP<00003FUH005YF009J
EPT000Uoo`T000=JEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<goo0`0000=JEP00
FUH01UYF5`000eYF00@005YFFUIJEPL0009JEP03001JEUYF00AJEP8000UJEP03001JEUYF009JEPD0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP0000<0009JEP04001J
EP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003FUH2000]Ool003Ioo`T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00H000MooaT00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
00=JEP05001JEUYF001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool003Eoo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD0011oo`<00003FUH005YF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<000IJEP03
001JEUYF00800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool0039oo`<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000moo`@000QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000L000EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]Ool0031oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80019o
o`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEPL000AJEPD000AJEP03001J
EUYF0080009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEPD000=JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000001Ioob80009JEP03001JEUYF00IJEPD000AJEP06001JEUYFFUH005YF0P0015YF0P001eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF0P00;Woo
000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00009goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00=JEP<000EJEQ4000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF5P0015YF00<005YFFUH00eYF00D005YFFUIJEP00
02Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH3
0003FUH00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP0002Uoo`03001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00
000aOol002aoo`03001JEP0000AJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP03001oogoo02Qoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo
00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001oogoo02Uoo`<000=JEP03001JEUYF
00EJEQ<000MJEP04001JEUYFFUH50003FUH20005FUH40008FUH00`00FUIJEP05FUH00`00FUH00003
000fOol002aoo`04001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool;0004FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF000000020003Ool90004FUH00`00FUIJEP02FUH>000jOol002ao
o`03001JEP0000AJEP03001JEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001J
EUYF0080031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
000=Ool90018Ool002aoo`03001JEP0000AJEP8000AJEPH001Moo`@0009JEP03001JEUYF00=JEP05
001JEUYFFUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002aoo`03001JEP0000AJEP03001JEP0000L001Uoo`T000=J
EP05001JEUYFFUH0000[Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001IOol002aoo`04001JEP000002FUH30002
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0WOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH3001GOol002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<007ooOol09Woo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH>0004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20002FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
00000eYF001oo`0VOol00`00FUH00004FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0002Moo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00E7oo000/Ool20003
FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00004FUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P00:7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00E7oo000]Ool00`00FUIJEP020005FUH00`00FUIJEP03FUH30005FUHA0003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00:7oo00@005YF000000=JEP03001JEUYF00=JEP8000MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000005Aoo`00;Woo
0P0000=JEP00FUH00UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002Uoo`03001JEP0000AJEP8000=JEPl000Uoo`P000=J
EP03001JEUYF00=JEP03001JEUYF00<005Aoo`00<7oo0`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`03001JEP0000AJEP03
001JEP0000@001ioo`D000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00AJEP<000MJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000/Ool01000FUH000000UYF0`0000=J
EP00FUH00UYF2@004Woo1@000eYF0`0000=JEP00FUH00UYF0P00E7oo000fOol50004FUH00`00FUIJ
EP04FUH20009FUH00`00FUIJEP02FUH7000aOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF4P000eYF00<005YFFUH015YF0`000eYF0P00E7oo000kOolK000hOol00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP0200000eYF0000001DOol008ioo`800003FUH0000000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4
001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03001DOol008ioo`80009JEP07
001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000=JEP03001JEP0005Aoo`00SWoo0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF00<005YF0000E7oo002?
Ool01000FUIJEP001EYF00<005YFFUH00eYF0`0025YF00<005YFFUH00UYF2@000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20003FUH20007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000F7oo
002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001JOol009Moo`D000=JEP8000EJEP@000QJEP03001JEUYF00EJEP03001JEP0000<0
05eoo`00W7oo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002UOolB001VOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79348 m .59613 .7379 L .56496 .736 L p .707 .577 .707 r
F P
0 g
s
.59613 .7379 m .59613 .79348 L .62796 .79271 L p .707 .577 .707 r
F P
0 g
s
.62796 .79271 m .62796 .73713 L .59613 .7379 L p .707 .577 .707 r
F P
0 g
s
.62796 .73713 m .62796 .79271 L .65735 .78933 L p .707 .577 .707 r
F P
0 g
s
.65735 .78933 m .65734 .73375 L .62796 .73713 L p .707 .577 .707 r
F P
0 g
s
.56496 .79158 m .56496 .736 L .5375 .73161 L p .707 .577 .707 r
F P
0 g
s
.56496 .736 m .56496 .79158 L .59613 .79348 L p .707 .577 .707 r
F P
0 g
s
.65734 .73375 m .65735 .78933 L .6814 .78368 L p .707 .577 .707 r
F P
0 g
s
.6814 .78368 m .6814 .7281 L .65734 .73375 L p .707 .577 .707 r
F P
0 g
s
.5375 .73161 m .5375 .78719 L .56496 .79158 L p .707 .577 .707 r
F P
0 g
s
.5375 .78719 m .5375 .73161 L .51644 .72516 L p .707 .577 .707 r
F P
0 g
s
.59613 .87488 m .59613 .83782 L .56496 .83592 L p .707 .577 .707 r
F P
0 g
s
.59613 .83782 m .59613 .87488 L .62796 .8741 L p .707 .577 .707 r
F P
0 g
s
.62796 .8741 m .62796 .83704 L .59613 .83782 L p .707 .577 .707 r
F P
0 g
s
.62796 .83704 m .62796 .8741 L .65735 .87072 L p .707 .577 .707 r
F P
0 g
s
.65735 .87072 m .65735 .83367 L .62796 .83704 L p .707 .577 .707 r
F P
0 g
s
.59613 .88046 m .59613 .86193 L .56496 .86003 L p .707 .577 .707 r
F P
0 g
s
.59613 .86193 m .59613 .88046 L .62796 .87968 L p .707 .577 .707 r
F P
0 g
s
.62796 .87968 m .62796 .86116 L .59613 .86193 L p .707 .577 .707 r
F P
0 g
s
.56496 .87298 m .56496 .83592 L .5375 .83153 L p .707 .577 .707 r
F P
0 g
s
.56496 .83592 m .56496 .87298 L .59613 .87488 L p .707 .577 .707 r
F P
0 g
s
.6814 .7281 m .6814 .78368 L .69777 .77631 L p .707 .577 .707 r
F P
0 g
s
.69777 .77631 m .69777 .72073 L .6814 .7281 L p .707 .577 .707 r
F P
0 g
s
.62796 .86116 m .62796 .87968 L .65735 .8763 L p .707 .577 .707 r
F P
0 g
s
.65735 .8763 m .65735 .85778 L .62796 .86116 L p .707 .577 .707 r
F P
0 g
s
.51644 .72516 m .51644 .78074 L .5375 .78719 L p .707 .577 .707 r
F P
0 g
s
.56496 .86003 m .56496 .87856 L .59613 .88046 L p .707 .577 .707 r
F P
0 g
s
.56496 .87856 m .56496 .86003 L .5375 .85564 L p .707 .577 .707 r
F P
0 g
s
.65735 .83367 m .65735 .87072 L .6814 .86507 L p .707 .577 .707 r
F P
0 g
s
.6814 .86507 m .6814 .82802 L .65735 .83367 L p .707 .577 .707 r
F P
0 g
s
.5375 .83153 m .5375 .86858 L .56496 .87298 L p .707 .577 .707 r
F P
0 g
s
.51644 .78074 m .51644 .72516 L .50385 .71727 L p .707 .577 .707 r
F P
0 g
s
.5375 .85564 m .5375 .87417 L .56496 .87856 L p .707 .577 .707 r
F P
0 g
s
.65735 .85778 m .65735 .8763 L .6814 .87065 L p .707 .577 .707 r
F P
0 g
s
.6814 .87065 m .6814 .85213 L .65735 .85778 L p .707 .577 .707 r
F P
0 g
s
.5375 .86858 m .5375 .83153 L .51644 .82507 L p .707 .577 .707 r
F P
0 g
s
.5375 .87417 m .5375 .85564 L .51644 .84919 L p .707 .577 .707 r
F P
0 g
s
.51644 .82507 m .51644 .86213 L .5375 .86858 L p .707 .577 .707 r
F P
0 g
s
.50385 .71727 m .50385 .77285 L .51644 .78074 L p .707 .577 .707 r
F P
0 g
s
.69777 .72073 m .69777 .77631 L .70485 .76795 L p .707 .577 .707 r
F P
0 g
s
.70485 .76795 m .70485 .71237 L .69777 .72073 L p .707 .577 .707 r
F P
0 g
s
.51644 .84919 m .51644 .86771 L .5375 .87417 L p .707 .577 .707 r
F P
0 g
s
.6814 .82802 m .6814 .86507 L .69777 .8577 L p .707 .577 .707 r
F P
0 g
s
.69777 .8577 m .69777 .82065 L .6814 .82802 L p .707 .577 .707 r
F P
0 g
s
.6814 .85213 m .6814 .87065 L .69777 .86329 L p .707 .577 .707 r
F P
0 g
s
.69777 .86329 m .69777 .84476 L .6814 .85213 L p .707 .577 .707 r
F P
0 g
s
.51644 .86213 m .51644 .82507 L .50385 .81719 L p .707 .577 .707 r
F P
0 g
s
.49044 .76629 m .49044 .2644 L .44643 .26172 L p .707 .577 .707 r
F P
0 g
s
.50385 .77285 m .50385 .71727 L .50095 .70873 L p .707 .577 .707 r
F P
0 g
s
.50095 .70873 m .50095 .76431 L .50385 .77285 L p .707 .577 .707 r
F P
0 g
s
.50095 .76431 m .50095 .70873 L .50804 .70037 L p .707 .577 .707 r
F P
0 g
s
.50804 .70037 m .50804 .75595 L .50095 .76431 L p .707 .577 .707 r
F P
0 g
s
.50804 .75595 m .50804 .70037 L .5244 .693 L p .707 .577 .707 r
F P
0 g
s
.5244 .693 m .5244 .74858 L .50804 .75595 L p .707 .577 .707 r
F P
0 g
s
.5244 .74858 m .5244 .693 L .54846 .68735 L p .707 .577 .707 r
F P
0 g
s
.54846 .68735 m .54846 .74293 L .5244 .74858 L p .707 .577 .707 r
F P
0 g
s
.49044 .2644 m .49044 .76629 L .53538 .76519 L p .707 .577 .707 r
F P
0 g
s
.53538 .76519 m .53538 .2633 L .49044 .2644 L p .707 .577 .707 r
F P
0 g
s
.54846 .74293 m .54846 .68735 L .57784 .68397 L p .707 .577 .707 r
F P
0 g
s
.57784 .68397 m .57784 .73955 L .54846 .74293 L p .707 .577 .707 r
F P
0 g
s
.53538 .2633 m .53538 .76519 L .57686 .76042 L p .707 .577 .707 r
F P
0 g
s
.57686 .76042 m .57686 .25853 L .53538 .2633 L p .707 .577 .707 r
F P
0 g
s
.51644 .86771 m .51644 .84919 L .50385 .8413 L p .707 .577 .707 r
F P
0 g
s
.44643 .76361 m .44643 .26172 L .40766 .25552 L p .707 .577 .707 r
F P
0 g
s
.44643 .26172 m .44643 .76361 L .49044 .76629 L p .707 .577 .707 r
F P
0 g
s
.50385 .81719 m .50385 .85425 L .51644 .86213 L p .707 .577 .707 r
F P
0 g
s
.50385 .8413 m .50385 .85983 L .51644 .86771 L p .707 .577 .707 r
F P
0 g
s
.69777 .82065 m .69777 .8577 L .70485 .84934 L p .707 .577 .707 r
F P
0 g
s
.70485 .84934 m .70485 .81228 L .69777 .82065 L p .707 .577 .707 r
F P
0 g
s
.70485 .71237 m .70485 .76795 L .70195 .7594 L p .707 .577 .707 r
F P
0 g
s
.70195 .7594 m .70195 .70382 L .70485 .71237 L p .707 .577 .707 r
F P
0 g
s
.64085 .68509 m .64085 .74067 L .60968 .73877 L p .707 .577 .707 r
F P
0 g
s
.60968 .73877 m .60968 .68319 L .64085 .68509 L p .707 .577 .707 r
F P
0 g
s
.57784 .73955 m .57784 .68397 L .60968 .68319 L p .707 .577 .707 r
F P
0 g
s
.60968 .68319 m .60968 .73877 L .57784 .73955 L p .707 .577 .707 r
F P
0 g
s
.57686 .25853 m .57686 .76042 L .61082 .75244 L p .707 .577 .707 r
F P
0 g
s
.61082 .75244 m .61082 .25056 L .57686 .25853 L p .707 .577 .707 r
F P
0 g
s
.69777 .84476 m .69777 .86329 L .70485 .85492 L p .707 .577 .707 r
F P
0 g
s
.70485 .85492 m .70485 .8364 L .69777 .84476 L p .707 .577 .707 r
F P
0 g
s
.50385 .85425 m .50385 .81719 L .50095 .80865 L p .707 .577 .707 r
F P
0 g
s
.40766 .7574 m .40766 .25552 L .37794 .2464 L p .707 .577 .707 r
F P
0 g
s
.40766 .25552 m .40766 .7574 L .44643 .76361 L p .707 .577 .707 r
F P
0 g
s
.50385 .85983 m .50385 .8413 L .50095 .83276 L p .707 .577 .707 r
F P
0 g
s
.50095 .80865 m .50095 .8457 L .50385 .85425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .83276 m .50095 .85129 L .50385 .85983 L p .707 .577 .707 r
F P
0 g
s
.70485 .81228 m .70485 .84934 L .70195 .8408 L p .707 .577 .707 r
F P
0 g
s
.70195 .8408 m .70195 .80374 L .70485 .81228 L p .707 .577 .707 r
F P
0 g
s
.70195 .70382 m .70195 .7594 L .68936 .75152 L p .707 .577 .707 r
F P
0 g
s
.68936 .75152 m .68936 .69594 L .70195 .70382 L p .707 .577 .707 r
F P
0 g
s
.61082 .25056 m .61082 .75244 L .63393 .74204 L p .707 .577 .707 r
F P
0 g
s
.63393 .74204 m .63393 .24016 L .61082 .25056 L p .707 .577 .707 r
F P
0 g
s
.70485 .8364 m .70485 .85492 L .70195 .84638 L p .707 .577 .707 r
F P
0 g
s
.70195 .84638 m .70195 .82785 L .70485 .8364 L p .707 .577 .707 r
F P
0 g
s
.25312 .75667 m .25312 .70109 L .22195 .69919 L p .707 .577 .707 r
F P
0 g
s
.25312 .70109 m .25312 .75667 L .28495 .75589 L p .707 .577 .707 r
F P
0 g
s
.28495 .75589 m .28495 .70031 L .25312 .70109 L p .707 .577 .707 r
F P
0 g
s
.50095 .8457 m .50095 .80865 L .50804 .80028 L p .707 .577 .707 r
F P
0 g
s
.28495 .70031 m .28495 .75589 L .31434 .75251 L p .707 .577 .707 r
F P
0 g
s
.31434 .75251 m .31434 .69693 L .28495 .70031 L p .707 .577 .707 r
F P
0 g
s
.37794 .74829 m .37794 .2464 L .36016 .23527 L p .707 .577 .707 r
F P
0 g
s
.37794 .2464 m .37794 .74829 L .40766 .7574 L p .707 .577 .707 r
F P
0 g
s
.22195 .75477 m .22195 .69919 L .19449 .69479 L p .707 .577 .707 r
F P
0 g
s
.22195 .69919 m .22195 .75477 L .25312 .75667 L p .707 .577 .707 r
F P
0 g
s
.50095 .85129 m .50095 .83276 L .50804 .8244 L p .707 .577 .707 r
F P
0 g
s
.50804 .80028 m .50804 .83734 L .50095 .8457 L p .707 .577 .707 r
F P
0 g
s
.50804 .8244 m .50804 .84292 L .50095 .85129 L p .707 .577 .707 r
F P
0 g
s
.31434 .69693 m .31434 .75251 L .33839 .74686 L p .707 .577 .707 r
F P
0 g
s
.33839 .74686 m .33839 .69128 L .31434 .69693 L p .707 .577 .707 r
F P
0 g
s
.70195 .80374 m .70195 .8408 L .68936 .83291 L p .707 .577 .707 r
F P
0 g
s
.68936 .83291 m .68936 .79586 L .70195 .80374 L p .707 .577 .707 r
F P
0 g
s
.68936 .69594 m .68936 .75152 L .66831 .74507 L p .707 .577 .707 r
F P
0 g
s
.66831 .74507 m .66831 .68948 L .68936 .69594 L p .707 .577 .707 r
F P
0 g
s
.19449 .69479 m .19449 .75038 L .22195 .75477 L p .707 .577 .707 r
F P
0 g
s
.19449 .75038 m .19449 .69479 L .17343 .68834 L p .707 .577 .707 r
F P
0 g
s
.70195 .82785 m .70195 .84638 L .68936 .8385 L p .707 .577 .707 r
F P
0 g
s
.68936 .8385 m .68936 .81997 L .70195 .82785 L p .707 .577 .707 r
F P
0 g
s
.25312 .83806 m .25312 .80101 L .22195 .79911 L p .707 .577 .707 r
F P
0 g
s
.25312 .80101 m .25312 .83806 L .28495 .83728 L p .707 .577 .707 r
F P
0 g
s
.28495 .83728 m .28495 .80023 L .25312 .80101 L p .707 .577 .707 r
F P
0 g
s
.64085 .74067 m .64085 .68509 L .66831 .68948 L p .707 .577 .707 r
F P
0 g
s
.63393 .24016 m .63393 .74204 L .64393 .73023 L p .707 .577 .707 r
F P
0 g
s
.64393 .73023 m .64393 .22835 L .63393 .24016 L p .707 .577 .707 r
F P
0 g
s
.50804 .83734 m .50804 .80028 L .5244 .79292 L p .707 .577 .707 r
F P
0 g
s
.28495 .80023 m .28495 .83728 L .31434 .83391 L p .707 .577 .707 r
F P
0 g
s
.31434 .83391 m .31434 .79685 L .28495 .80023 L p .707 .577 .707 r
F P
0 g
s
.25312 .84365 m .25312 .82512 L .22195 .82322 L p .707 .577 .707 r
F P
0 g
s
.25312 .82512 m .25312 .84365 L .28495 .84287 L p .707 .577 .707 r
F P
0 g
s
.28495 .84287 m .28495 .82434 L .25312 .82512 L p .707 .577 .707 r
F P
0 g
s
.22195 .83616 m .22195 .79911 L .19449 .79471 L p .707 .577 .707 r
F P
0 g
s
.22195 .79911 m .22195 .83616 L .25312 .83806 L p .707 .577 .707 r
F P
0 g
s
.33839 .69128 m .33839 .74686 L .35476 .7395 L p .707 .577 .707 r
F P
0 g
s
.35476 .7395 m .35476 .68391 L .33839 .69128 L p .707 .577 .707 r
F P
0 g
s
.50804 .84292 m .50804 .8244 L .5244 .81703 L p .707 .577 .707 r
F P
0 g
s
.28495 .82434 m .28495 .84287 L .31434 .83949 L p .707 .577 .707 r
F P
0 g
s
.31434 .83949 m .31434 .82096 L .28495 .82434 L p .707 .577 .707 r
F P
0 g
s
.17343 .68834 m .17343 .74392 L .19449 .75038 L p .707 .577 .707 r
F P
0 g
s
.22195 .82322 m .22195 .84174 L .25312 .84365 L p .707 .577 .707 r
F P
0 g
s
.5244 .79292 m .5244 .82997 L .50804 .83734 L p .707 .577 .707 r
F P
0 g
s
.22195 .84174 m .22195 .82322 L .19449 .81883 L p .707 .577 .707 r
F P
0 g
s
.66831 .68948 m .66831 .74507 L .64085 .74067 L p .707 .577 .707 r
F P
0 g
s
.5244 .81703 m .5244 .83556 L .50804 .84292 L p .707 .577 .707 r
F P
0 g
s
.31434 .79685 m .31434 .83391 L .33839 .82826 L p .707 .577 .707 r
F P
0 g
s
.33839 .82826 m .33839 .7912 L .31434 .79685 L p .707 .577 .707 r
F P
0 g
s
.19449 .79471 m .19449 .83177 L .22195 .83616 L p .707 .577 .707 r
F P
0 g
s
.17343 .74392 m .17343 .68834 L .16084 .68046 L p .707 .577 .707 r
F P
0 g
s
.35476 .68391 m .35476 .7395 L .36184 .73113 L p .707 .577 .707 r
F P
0 g
s
.36184 .73113 m .36184 .67555 L .35476 .68391 L p .707 .577 .707 r
F P
0 g
s
.36184 .67555 m .36184 .73113 L .35894 .72259 L p .707 .577 .707 r
F P
0 g
s
.35894 .72259 m .35894 .66701 L .36184 .67555 L p .707 .577 .707 r
F P
0 g
s
.36016 .73716 m .36016 .23527 L .35607 .22321 L p .707 .577 .707 r
F P
0 g
s
.36016 .23527 m .36016 .73716 L .37794 .74829 L p .707 .577 .707 r
F P
0 g
s
.68936 .79586 m .68936 .83291 L .66831 .82646 L p .707 .577 .707 r
F P
0 g
s
.66831 .82646 m .66831 .7894 L .68936 .79586 L p .707 .577 .707 r
F P
0 g
s
.19449 .81883 m .19449 .83735 L .22195 .84174 L p .707 .577 .707 r
F P
0 g
s
.31434 .82096 m .31434 .83949 L .33839 .83384 L p .707 .577 .707 r
F P
0 g
s
.33839 .83384 m .33839 .81531 L .31434 .82096 L p .707 .577 .707 r
F P
0 g
s
.19449 .83177 m .19449 .79471 L .17343 .78826 L p .707 .577 .707 r
F P
0 g
s
.68936 .81997 m .68936 .8385 L .66831 .83204 L p .707 .577 .707 r
F P
0 g
s
.66831 .83204 m .66831 .81352 L .68936 .81997 L p .707 .577 .707 r
F P
0 g
s
.5244 .82997 m .5244 .79292 L .54846 .78727 L p .707 .577 .707 r
F P
0 g
s
.19449 .83735 m .19449 .81883 L .17343 .81237 L p .707 .577 .707 r
F P
0 g
s
.17343 .78826 m .17343 .82531 L .19449 .83177 L p .707 .577 .707 r
F P
0 g
s
.16084 .68046 m .16084 .73604 L .17343 .74392 L p .707 .577 .707 r
F P
0 g
s
.17343 .81237 m .17343 .8309 L .19449 .83735 L p .707 .577 .707 r
F P
0 g
s
.33839 .7912 m .33839 .82826 L .35476 .82089 L p .707 .577 .707 r
F P
0 g
s
.35476 .82089 m .35476 .78383 L .33839 .7912 L p .707 .577 .707 r
F P
0 g
s
.5244 .83556 m .5244 .81703 L .54846 .81138 L p .707 .577 .707 r
F P
0 g
s
.54846 .78727 m .54846 .82432 L .5244 .82997 L p .707 .577 .707 r
F P
0 g
s
.54846 .81138 m .54846 .82991 L .5244 .83556 L p .707 .577 .707 r
F P
0 g
s
.66831 .7894 m .66831 .82646 L .64085 .82207 L p .707 .577 .707 r
F P
0 g
s
.64085 .82207 m .64085 .78501 L .66831 .7894 L p .707 .577 .707 r
F P
0 g
s
.33839 .81531 m .33839 .83384 L .35476 .82647 L p .707 .577 .707 r
F P
0 g
s
.35476 .82647 m .35476 .80794 L .33839 .81531 L p .707 .577 .707 r
F P
0 g
s
.64393 .22835 m .64393 .73023 L .63984 .71818 L p .707 .577 .707 r
F P
0 g
s
.63984 .71818 m .63984 .21629 L .64393 .22835 L p .707 .577 .707 r
F P
0 g
s
.17343 .82531 m .17343 .78826 L .16084 .78038 L p .707 .577 .707 r
F P
0 g
s
.16084 .73604 m .16084 .68046 L .15794 .67191 L p .707 .577 .707 r
F P
0 g
s
.66831 .81352 m .66831 .83204 L .64085 .82765 L p .707 .577 .707 r
F P
0 g
s
.64085 .82765 m .64085 .80912 L .66831 .81352 L p .707 .577 .707 r
F P
0 g
s
.54846 .82432 m .54846 .78727 L .57784 .78389 L p .707 .577 .707 r
F P
0 g
s
.17343 .8309 m .17343 .81237 L .16084 .80449 L p .707 .577 .707 r
F P
0 g
s
.54846 .82991 m .54846 .81138 L .57784 .808 L p .707 .577 .707 r
F P
0 g
s
.16084 .78038 m .16084 .81743 L .17343 .82531 L p .707 .577 .707 r
F P
0 g
s
.64085 .78501 m .64085 .82207 L .60968 .82017 L p .707 .577 .707 r
F P
0 g
s
.60968 .82017 m .60968 .78311 L .64085 .78501 L p .707 .577 .707 r
F P
0 g
s
.16084 .80449 m .16084 .82301 L .17343 .8309 L p .707 .577 .707 r
F P
0 g
s
.57784 .78389 m .57784 .82094 L .54846 .82432 L p .707 .577 .707 r
F P
0 g
s
.57784 .808 m .57784 .82653 L .54846 .82991 L p .707 .577 .707 r
F P
0 g
s
.57784 .82094 m .57784 .78389 L .60968 .78311 L p .707 .577 .707 r
F P
0 g
s
.35894 .66701 m .35894 .72259 L .34635 .71471 L p .707 .577 .707 r
F P
0 g
s
.34635 .71471 m .34635 .65912 L .35894 .66701 L p .707 .577 .707 r
F P
0 g
s
.35607 .22321 m .35607 .7251 L .36016 .73716 L p .707 .577 .707 r
F P
0 g
s
.35607 .7251 m .35607 .22321 L .36607 .21141 L p .707 .577 .707 r
F P
0 g
s
.35476 .78383 m .35476 .82089 L .36184 .81252 L p .707 .577 .707 r
F P
0 g
s
.36184 .81252 m .36184 .77547 L .35476 .78383 L p .707 .577 .707 r
F P
0 g
s
.15794 .67191 m .15794 .7275 L .16084 .73604 L p .707 .577 .707 r
F P
0 g
s
.64085 .80912 m .64085 .82765 L .60968 .82575 L p .707 .577 .707 r
F P
0 g
s
.60968 .82575 m .60968 .80722 L .64085 .80912 L p .707 .577 .707 r
F P
0 g
s
.60968 .78311 m .60968 .82017 L .57784 .82094 L p .707 .577 .707 r
F P
0 g
s
.57784 .82653 m .57784 .808 L .60968 .80722 L p .707 .577 .707 r
F P
0 g
s
.35476 .80794 m .35476 .82647 L .36184 .81811 L p .707 .577 .707 r
F P
0 g
s
.36184 .81811 m .36184 .79958 L .35476 .80794 L p .707 .577 .707 r
F P
0 g
s
.60968 .80722 m .60968 .82575 L .57784 .82653 L p .707 .577 .707 r
F P
0 g
s
.16084 .81743 m .16084 .78038 L .15794 .77183 L p .707 .577 .707 r
F P
0 g
s
.15794 .7275 m .15794 .67191 L .16503 .66355 L p .707 .577 .707 r
F P
0 g
s
.16084 .82301 m .16084 .80449 L .15794 .79594 L p .707 .577 .707 r
F P
0 g
s
.15794 .77183 m .15794 .80889 L .16084 .81743 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .79594 m .15794 .81447 L .16084 .82301 L p .707 .577 .707 r
F P
0 g
s
.63984 .21629 m .63984 .71818 L .62206 .70704 L p .707 .577 .707 r
F P
0 g
s
.62206 .70704 m .62206 .20516 L .63984 .21629 L p .707 .577 .707 r
F P
0 g
s
.36184 .77547 m .36184 .81252 L .35894 .80398 L p .707 .577 .707 r
F P
0 g
s
.35894 .80398 m .35894 .76693 L .36184 .77547 L p .707 .577 .707 r
F P
0 g
s
.16503 .66355 m .16503 .71913 L .15794 .7275 L p .707 .577 .707 r
F P
0 g
s
.36184 .79958 m .36184 .81811 L .35894 .80957 L p .707 .577 .707 r
F P
0 g
s
.35894 .80957 m .35894 .79104 L .36184 .79958 L p .707 .577 .707 r
F P
0 g
s
.36607 .71329 m .36607 .21141 L .38918 .201 L p .707 .577 .707 r
F P
0 g
s
.36607 .21141 m .36607 .71329 L .35607 .7251 L p .707 .577 .707 r
F P
0 g
s
.15794 .80889 m .15794 .77183 L .16503 .76347 L p .707 .577 .707 r
F P
0 g
s
.16503 .71913 m .16503 .66355 L .1814 .65618 L p .707 .577 .707 r
F P
0 g
s
.15794 .81447 m .15794 .79594 L .16503 .78758 L p .707 .577 .707 r
F P
0 g
s
.16503 .76347 m .16503 .80052 L .15794 .80889 L p .707 .577 .707 r
F P
0 g
s
.16503 .78758 m .16503 .80611 L .15794 .81447 L p .707 .577 .707 r
F P
0 g
s
.35894 .76693 m .35894 .80398 L .34635 .7961 L p .707 .577 .707 r
F P
0 g
s
.34635 .7961 m .34635 .75904 L .35894 .76693 L p .707 .577 .707 r
F P
0 g
s
.1814 .65618 m .1814 .71176 L .16503 .71913 L p .707 .577 .707 r
F P
0 g
s
.34635 .65912 m .34635 .71471 L .3253 .70825 L p .707 .577 .707 r
F P
0 g
s
.3253 .70825 m .3253 .65267 L .34635 .65912 L p .707 .577 .707 r
F P
0 g
s
.62206 .20516 m .62206 .70704 L .59233 .69793 L p .707 .577 .707 r
F P
0 g
s
.59233 .69793 m .59233 .19604 L .62206 .20516 L p .707 .577 .707 r
F P
0 g
s
.35894 .79104 m .35894 .80957 L .34635 .80168 L p .707 .577 .707 r
F P
0 g
s
.34635 .80168 m .34635 .78315 L .35894 .79104 L p .707 .577 .707 r
F P
0 g
s
.1814 .71176 m .1814 .65618 L .20545 .65053 L p .707 .577 .707 r
F P
0 g
s
.16503 .80052 m .16503 .76347 L .1814 .7561 L p .707 .577 .707 r
F P
0 g
s
.38918 .201 m .38918 .70289 L .36607 .71329 L p .707 .577 .707 r
F P
0 g
s
.38918 .70289 m .38918 .201 L .42314 .19303 L p .707 .577 .707 r
F P
0 g
s
.16503 .80611 m .16503 .78758 L .1814 .78021 L p .707 .577 .707 r
F P
0 g
s
.1814 .7561 m .1814 .79316 L .16503 .80052 L p .707 .577 .707 r
F P
0 g
s
.3253 .65267 m .3253 .70825 L .29784 .70386 L p .707 .577 .707 r
F P
0 g
s
.29784 .70386 m .29784 .64828 L .3253 .65267 L p .707 .577 .707 r
F P
0 g
s
.1814 .78021 m .1814 .79874 L .16503 .80611 L p .707 .577 .707 r
F P
0 g
s
.20545 .65053 m .20545 .70611 L .1814 .71176 L p .707 .577 .707 r
F P
0 g
s
.34635 .75904 m .34635 .7961 L .3253 .78964 L p .707 .577 .707 r
F P
0 g
s
.3253 .78964 m .3253 .75259 L .34635 .75904 L p .707 .577 .707 r
F P
0 g
s
.20545 .70611 m .20545 .65053 L .23483 .64715 L p .707 .577 .707 r
F P
0 g
s
.34635 .78315 m .34635 .80168 L .3253 .79523 L p .707 .577 .707 r
F P
0 g
s
.3253 .79523 m .3253 .7767 L .34635 .78315 L p .707 .577 .707 r
F P
0 g
s
.59233 .19604 m .59233 .69793 L .55357 .69173 L p .707 .577 .707 r
F P
0 g
s
.55357 .69173 m .55357 .18984 L .59233 .19604 L p .707 .577 .707 r
F P
0 g
s
.1814 .79316 m .1814 .7561 L .20545 .75045 L p .707 .577 .707 r
F P
0 g
s
.29784 .64828 m .29784 .70386 L .26667 .70196 L p .707 .577 .707 r
F P
0 g
s
.26667 .70196 m .26667 .64638 L .29784 .64828 L p .707 .577 .707 r
F P
0 g
s
.23483 .70274 m .23483 .64715 L .26667 .64638 L p .707 .577 .707 r
F P
0 g
s
.23483 .64715 m .23483 .70274 L .20545 .70611 L p .707 .577 .707 r
F P
0 g
s
.1814 .79874 m .1814 .78021 L .20545 .77456 L p .707 .577 .707 r
F P
0 g
s
.26667 .64638 m .26667 .70196 L .23483 .70274 L p .707 .577 .707 r
F P
0 g
s
.42314 .69492 m .42314 .19303 L .46462 .18826 L p .707 .577 .707 r
F P
0 g
s
.42314 .19303 m .42314 .69492 L .38918 .70289 L p .707 .577 .707 r
F P
0 g
s
.73333 .70145 m .73333 .64586 L .70216 .64396 L p .707 .577 .707 r
F P
0 g
s
.73333 .64586 m .73333 .70145 L .76517 .70067 L p .707 .577 .707 r
F P
0 g
s
.76517 .70067 m .76517 .64509 L .73333 .64586 L p .707 .577 .707 r
F P
0 g
s
.20545 .75045 m .20545 .78751 L .1814 .79316 L p .707 .577 .707 r
F P
0 g
s
.20545 .77456 m .20545 .79309 L .1814 .79874 L p .707 .577 .707 r
F P
0 g
s
.76517 .64509 m .76517 .70067 L .79455 .69729 L p .707 .577 .707 r
F P
0 g
s
.79455 .69729 m .79455 .64171 L .76517 .64509 L p .707 .577 .707 r
F P
0 g
s
.3253 .75259 m .3253 .78964 L .29784 .78525 L p .707 .577 .707 r
F P
0 g
s
.29784 .78525 m .29784 .7482 L .3253 .75259 L p .707 .577 .707 r
F P
0 g
s
.70216 .69955 m .70216 .64396 L .6747 .63957 L p .707 .577 .707 r
F P
0 g
s
.70216 .64396 m .70216 .69955 L .73333 .70145 L p .707 .577 .707 r
F P
0 g
s
.3253 .7767 m .3253 .79523 L .29784 .79084 L p .707 .577 .707 r
F P
0 g
s
.29784 .79084 m .29784 .77231 L .3253 .7767 L p .707 .577 .707 r
F P
0 g
s
.55357 .18984 m .55357 .69173 L .50956 .68905 L p .707 .577 .707 r
F P
0 g
s
.50956 .68905 m .50956 .18716 L .55357 .18984 L p .707 .577 .707 r
F P
0 g
s
.20545 .78751 m .20545 .75045 L .23483 .74707 L p .707 .577 .707 r
F P
0 g
s
.79455 .64171 m .79455 .69729 L .8186 .69164 L p .707 .577 .707 r
F P
0 g
s
.8186 .69164 m .8186 .63606 L .79455 .64171 L p .707 .577 .707 r
F P
0 g
s
.46462 .69015 m .46462 .18826 L .50956 .18716 L p .707 .577 .707 r
F P
0 g
s
.46462 .18826 m .46462 .69015 L .42314 .69492 L p .707 .577 .707 r
F P
0 g
s
.20545 .79309 m .20545 .77456 L .23483 .77118 L p .707 .577 .707 r
F P
0 g
s
.29784 .7482 m .29784 .78525 L .26667 .78335 L p .707 .577 .707 r
F P
0 g
s
.26667 .78335 m .26667 .7463 L .29784 .7482 L p .707 .577 .707 r
F P
0 g
s
.50956 .18716 m .50956 .68905 L .46462 .69015 L p .707 .577 .707 r
F P
0 g
s
.23483 .74707 m .23483 .78413 L .20545 .78751 L p .707 .577 .707 r
F P
0 g
s
.6747 .63957 m .6747 .69515 L .70216 .69955 L p .707 .577 .707 r
F P
0 g
s
.6747 .69515 m .6747 .63957 L .65365 .63312 L p .707 .577 .707 r
F P
0 g
s
.23483 .77118 m .23483 .78971 L .20545 .79309 L p .707 .577 .707 r
F P
0 g
s
.23483 .78413 m .23483 .74707 L .26667 .7463 L p .707 .577 .707 r
F P
0 g
s
.29784 .77231 m .29784 .79084 L .26667 .78893 L p .707 .577 .707 r
F P
0 g
s
.26667 .78893 m .26667 .77041 L .29784 .77231 L p .707 .577 .707 r
F P
0 g
s
.26667 .7463 m .26667 .78335 L .23483 .78413 L p .707 .577 .707 r
F P
0 g
s
.73333 .78284 m .73333 .74578 L .70216 .74388 L p .707 .577 .707 r
F P
0 g
s
.73333 .74578 m .73333 .78284 L .76517 .78206 L p .707 .577 .707 r
F P
0 g
s
.76517 .78206 m .76517 .74501 L .73333 .74578 L p .707 .577 .707 r
F P
0 g
s
.23483 .78971 m .23483 .77118 L .26667 .77041 L p .707 .577 .707 r
F P
0 g
s
.76517 .74501 m .76517 .78206 L .79455 .77868 L p .707 .577 .707 r
F P
0 g
s
.79455 .77868 m .79455 .74163 L .76517 .74501 L p .707 .577 .707 r
F P
0 g
s
.26667 .77041 m .26667 .78893 L .23483 .78971 L p .707 .577 .707 r
F P
0 g
s
.73333 .78842 m .73333 .7699 L .70216 .76799 L p .707 .577 .707 r
F P
0 g
s
.73333 .7699 m .73333 .78842 L .76517 .78765 L p .707 .577 .707 r
F P
0 g
s
.76517 .78765 m .76517 .76912 L .73333 .7699 L p .707 .577 .707 r
F P
0 g
s
.70216 .78094 m .70216 .74388 L .6747 .73949 L p .707 .577 .707 r
F P
0 g
s
.70216 .74388 m .70216 .78094 L .73333 .78284 L p .707 .577 .707 r
F P
0 g
s
.8186 .63606 m .8186 .69164 L .83497 .68427 L p .707 .577 .707 r
F P
0 g
s
.83497 .68427 m .83497 .62869 L .8186 .63606 L p .707 .577 .707 r
F P
0 g
s
.76517 .76912 m .76517 .78765 L .79455 .78427 L p .707 .577 .707 r
F P
0 g
s
.79455 .78427 m .79455 .76574 L .76517 .76912 L p .707 .577 .707 r
F P
0 g
s
.65365 .63312 m .65365 .6887 L .6747 .69515 L p .707 .577 .707 r
F P
0 g
s
.70216 .76799 m .70216 .78652 L .73333 .78842 L p .707 .577 .707 r
F P
0 g
s
.70216 .78652 m .70216 .76799 L .6747 .7636 L p .707 .577 .707 r
F P
0 g
s
.79455 .74163 m .79455 .77868 L .8186 .77303 L p .707 .577 .707 r
F P
0 g
s
.8186 .77303 m .8186 .73598 L .79455 .74163 L p .707 .577 .707 r
F P
0 g
s
.6747 .73949 m .6747 .77655 L .70216 .78094 L p .707 .577 .707 r
F P
0 g
s
.65365 .6887 m .65365 .63312 L .64105 .62523 L p .707 .577 .707 r
F P
0 g
s
.6747 .7636 m .6747 .78213 L .70216 .78652 L p .707 .577 .707 r
F P
0 g
s
.79455 .76574 m .79455 .78427 L .8186 .77862 L p .707 .577 .707 r
F P
0 g
s
.8186 .77862 m .8186 .76009 L .79455 .76574 L p .707 .577 .707 r
F P
0 g
s
.6747 .77655 m .6747 .73949 L .65365 .73304 L p .707 .577 .707 r
F P
0 g
s
.6747 .78213 m .6747 .7636 L .65365 .75715 L p .707 .577 .707 r
F P
0 g
s
.65365 .73304 m .65365 .77009 L .6747 .77655 L p .707 .577 .707 r
F P
0 g
s
.64105 .62523 m .64105 .68082 L .65365 .6887 L p .707 .577 .707 r
F P
0 g
s
.83497 .62869 m .83497 .68427 L .84206 .67591 L p .707 .577 .707 r
F P
0 g
s
.84206 .67591 m .84205 .62033 L .83497 .62869 L p .707 .577 .707 r
F P
0 g
s
.65365 .75715 m .65365 .77568 L .6747 .78213 L p .707 .577 .707 r
F P
0 g
s
.8186 .73598 m .8186 .77303 L .83497 .76567 L p .707 .577 .707 r
F P
0 g
s
.83497 .76567 m .83497 .72861 L .8186 .73598 L p .707 .577 .707 r
F P
0 g
s
.8186 .76009 m .8186 .77862 L .83497 .77125 L p .707 .577 .707 r
F P
0 g
s
.83497 .77125 m .83497 .75272 L .8186 .76009 L p .707 .577 .707 r
F P
0 g
s
.65365 .77009 m .65365 .73304 L .64105 .72515 L p .707 .577 .707 r
F P
0 g
s
.64105 .68082 m .64105 .62523 L .63816 .61669 L p .707 .577 .707 r
F P
0 g
s
.65365 .77568 m .65365 .75715 L .64105 .74926 L p .707 .577 .707 r
F P
0 g
s
.64105 .72515 m .64105 .76221 L .65365 .77009 L p .707 .577 .707 r
F P
0 g
s
.64105 .74926 m .64105 .76779 L .65365 .77568 L p .707 .577 .707 r
F P
0 g
s
.83497 .72861 m .83497 .76567 L .84206 .7573 L p .707 .577 .707 r
F P
0 g
s
.84206 .7573 m .84206 .72025 L .83497 .72861 L p .707 .577 .707 r
F P
0 g
s
.63816 .61669 m .63816 .67227 L .64105 .68082 L p .707 .577 .707 r
F P
0 g
s
.84205 .62033 m .84206 .67591 L .83916 .66737 L p .707 .577 .707 r
F P
0 g
s
.83916 .66737 m .83916 .61178 L .84205 .62033 L p .707 .577 .707 r
F P
0 g
s
.83497 .75272 m .83497 .77125 L .84206 .76288 L p .707 .577 .707 r
F P
0 g
s
.84206 .76288 m .84206 .74436 L .83497 .75272 L p .707 .577 .707 r
F P
0 g
s
.64105 .76221 m .64105 .72515 L .63816 .71661 L p .707 .577 .707 r
F P
0 g
s
.63816 .67227 m .63816 .61669 L .64524 .60833 L p .707 .577 .707 r
F P
0 g
s
.64105 .76779 m .64105 .74926 L .63816 .74072 L p .707 .577 .707 r
F P
0 g
s
.63816 .71661 m .63816 .75367 L .64105 .76221 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .74072 m .63816 .75925 L .64105 .76779 L p .707 .577 .707 r
F P
0 g
s
.84206 .72025 m .84206 .7573 L .83916 .74876 L p .707 .577 .707 r
F P
0 g
s
.83916 .74876 m .83916 .7117 L .84206 .72025 L p .707 .577 .707 r
F P
0 g
s
.64524 .60833 m .64524 .66391 L .63816 .67227 L p .707 .577 .707 r
F P
0 g
s
.83916 .61178 m .83916 .66737 L .82657 .65948 L p .707 .577 .707 r
F P
0 g
s
.82657 .65948 m .82657 .6039 L .83916 .61178 L p .707 .577 .707 r
F P
0 g
s
.84206 .74436 m .84206 .76288 L .83916 .75434 L p .707 .577 .707 r
F P
0 g
s
.83916 .75434 m .83916 .73581 L .84206 .74436 L p .707 .577 .707 r
F P
0 g
s
.39032 .66463 m .39032 .60905 L .35915 .60715 L p .707 .577 .707 r
F P
0 g
s
.39032 .60905 m .39032 .66463 L .42216 .66385 L p .707 .577 .707 r
F P
0 g
s
.42216 .66385 m .42216 .60827 L .39032 .60905 L p .707 .577 .707 r
F P
0 g
s
.63816 .75367 m .63816 .71661 L .64524 .70825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66391 m .64524 .60833 L .66161 .60096 L p .707 .577 .707 r
F P
0 g
s
.42216 .60827 m .42216 .66385 L .45154 .66048 L p .707 .577 .707 r
F P
0 g
s
.45154 .66048 m .45154 .60489 L .42216 .60827 L p .707 .577 .707 r
F P
0 g
s
.35915 .66273 m .35915 .60715 L .33169 .60276 L p .707 .577 .707 r
F P
0 g
s
.35915 .60715 m .35915 .66273 L .39032 .66463 L p .707 .577 .707 r
F P
0 g
s
.63816 .75925 m .63816 .74072 L .64524 .73236 L p .707 .577 .707 r
F P
0 g
s
.64524 .70825 m .64524 .7453 L .63816 .75367 L p .707 .577 .707 r
F P
0 g
s
.64524 .73236 m .64524 .75089 L .63816 .75925 L p .707 .577 .707 r
F P
0 g
s
.45154 .60489 m .45154 .66048 L .47559 .65483 L p .707 .577 .707 r
F P
0 g
s
.47559 .65483 m .47559 .59924 L .45154 .60489 L p .707 .577 .707 r
F P
0 g
s
.83916 .7117 m .83916 .74876 L .82657 .74087 L p .707 .577 .707 r
F P
0 g
s
.82657 .74087 m .82657 .70382 L .83916 .7117 L p .707 .577 .707 r
F P
0 g
s
.66161 .60096 m .66161 .65654 L .64524 .66391 L p .707 .577 .707 r
F P
0 g
s
.82657 .6039 m .82657 .65948 L .80551 .65303 L p .707 .577 .707 r
F P
0 g
s
.80551 .65303 m .80551 .59745 L .82657 .6039 L p .707 .577 .707 r
F P
0 g
s
.33169 .60276 m .33169 .65834 L .35915 .66273 L p .707 .577 .707 r
F P
0 g
s
.33169 .65834 m .33169 .60276 L .31064 .5963 L p .707 .577 .707 r
F P
0 g
s
.83916 .73581 m .83916 .75434 L .82657 .74646 L p .707 .577 .707 r
F P
0 g
s
.82657 .74646 m .82657 .72793 L .83916 .73581 L p .707 .577 .707 r
F P
0 g
s
.39032 .74602 m .39032 .70897 L .35915 .70707 L p .707 .577 .707 r
F P
0 g
s
.39032 .70897 m .39032 .74602 L .42216 .74525 L p .707 .577 .707 r
F P
0 g
s
.42216 .74525 m .42216 .70819 L .39032 .70897 L p .707 .577 .707 r
F P
0 g
s
.66161 .65654 m .66161 .60096 L .68566 .59531 L p .707 .577 .707 r
F P
0 g
s
.64524 .7453 m .64524 .70825 L .66161 .70088 L p .707 .577 .707 r
F P
0 g
s
.42216 .70819 m .42216 .74525 L .45154 .74187 L p .707 .577 .707 r
F P
0 g
s
.45154 .74187 m .45154 .70481 L .42216 .70819 L p .707 .577 .707 r
F P
0 g
s
.39032 .75161 m .39032 .73308 L .35915 .73118 L p .707 .577 .707 r
F P
0 g
s
.39032 .73308 m .39032 .75161 L .42216 .75083 L p .707 .577 .707 r
F P
0 g
s
.42216 .75083 m .42216 .7323 L .39032 .73308 L p .707 .577 .707 r
F P
0 g
s
.35915 .74412 m .35915 .70707 L .33169 .70268 L p .707 .577 .707 r
F P
0 g
s
.35915 .70707 m .35915 .74412 L .39032 .74602 L p .707 .577 .707 r
F P
0 g
s
.47559 .59924 m .47559 .65483 L .49196 .64746 L p .707 .577 .707 r
F P
0 g
s
.49196 .64746 m .49196 .59188 L .47559 .59924 L p .707 .577 .707 r
F P
0 g
s
.64524 .75089 m .64524 .73236 L .66161 .72499 L p .707 .577 .707 r
F P
0 g
s
.42216 .7323 m .42216 .75083 L .45154 .74745 L p .707 .577 .707 r
F P
0 g
s
.45154 .74745 m .45154 .72892 L .42216 .7323 L p .707 .577 .707 r
F P
0 g
s
.31064 .5963 m .31064 .65188 L .33169 .65834 L p .707 .577 .707 r
F P
0 g
s
.35915 .73118 m .35915 .74971 L .39032 .75161 L p .707 .577 .707 r
F P
0 g
s
.66161 .70088 m .66161 .73793 L .64524 .7453 L p .707 .577 .707 r
F P
0 g
s
.35915 .74971 m .35915 .73118 L .33169 .72679 L p .707 .577 .707 r
F P
0 g
s
.80551 .59745 m .80551 .65303 L .77805 .64864 L p .707 .577 .707 r
F P
0 g
s
.77805 .64864 m .77805 .59305 L .80551 .59745 L p .707 .577 .707 r
F P
0 g
s
.66161 .72499 m .66161 .74352 L .64524 .75089 L p .707 .577 .707 r
F P
0 g
s
.45154 .70481 m .45154 .74187 L .47559 .73622 L p .707 .577 .707 r
F P
0 g
s
.47559 .73622 m .47559 .69916 L .45154 .70481 L p .707 .577 .707 r
F P
0 g
s
.68566 .59531 m .68566 .65089 L .66161 .65654 L p .707 .577 .707 r
F P
0 g
s
.33169 .70268 m .33169 .73973 L .35915 .74412 L p .707 .577 .707 r
F P
0 g
s
.31064 .65188 m .31064 .5963 L .29804 .58842 L p .707 .577 .707 r
F P
0 g
s
.82657 .70382 m .82657 .74087 L .80551 .73442 L p .707 .577 .707 r
F P
0 g
s
.80551 .73442 m .80551 .69737 L .82657 .70382 L p .707 .577 .707 r
F P
0 g
s
.33169 .72679 m .33169 .74531 L .35915 .74971 L p .707 .577 .707 r
F P
0 g
s
.68566 .65089 m .68566 .59531 L .71504 .59193 L p .707 .577 .707 r
F P
0 g
s
.45154 .72892 m .45154 .74745 L .47559 .7418 L p .707 .577 .707 r
F P
0 g
s
.47559 .7418 m .47559 .72327 L .45154 .72892 L p .707 .577 .707 r
F P
0 g
s
.33169 .73973 m .33169 .70268 L .31064 .69622 L p .707 .577 .707 r
F P
0 g
s
.82657 .72793 m .82657 .74646 L .80551 .74 L p .707 .577 .707 r
F P
0 g
s
.80551 .74 m .80551 .72148 L .82657 .72793 L p .707 .577 .707 r
F P
0 g
s
.66161 .73793 m .66161 .70088 L .68566 .69523 L p .707 .577 .707 r
F P
0 g
s
.33169 .74531 m .33169 .72679 L .31064 .72033 L p .707 .577 .707 r
F P
0 g
s
.77805 .59305 m .77805 .64864 L .74688 .64674 L p .707 .577 .707 r
F P
0 g
s
.74688 .64674 m .74688 .59115 L .77805 .59305 L p .707 .577 .707 r
F P
0 g
s
.31064 .69622 m .31064 .73328 L .33169 .73973 L p .707 .577 .707 r
F P
0 g
s
.29804 .58842 m .29804 .644 L .31064 .65188 L p .707 .577 .707 r
F P
0 g
s
.71504 .64751 m .71504 .59193 L .74688 .59115 L p .707 .577 .707 r
F P
0 g
s
.71504 .59193 m .71504 .64751 L .68566 .65089 L p .707 .577 .707 r
F P
0 g
s
.49196 .59188 m .49196 .64746 L .49904 .63909 L p .707 .577 .707 r
F P
0 g
s
.49904 .63909 m .49904 .58351 L .49196 .59188 L p .707 .577 .707 r
F P
0 g
s
.31064 .72033 m .31064 .73886 L .33169 .74531 L p .707 .577 .707 r
F P
0 g
s
.47559 .69916 m .47559 .73622 L .49196 .72885 L p .707 .577 .707 r
F P
0 g
s
.49196 .72885 m .49196 .69179 L .47559 .69916 L p .707 .577 .707 r
F P
0 g
s
.66161 .74352 m .66161 .72499 L .68566 .71934 L p .707 .577 .707 r
F P
0 g
s
.74688 .59115 m .74688 .64674 L .71504 .64751 L p .707 .577 .707 r
F P
0 g
s
.68566 .69523 m .68566 .73228 L .66161 .73793 L p .707 .577 .707 r
F P
0 g
s
.68566 .71934 m .68566 .73787 L .66161 .74352 L p .707 .577 .707 r
F P
0 g
s
.80551 .69737 m .80551 .73442 L .77805 .73003 L p .707 .577 .707 r
F P
0 g
s
.77805 .73003 m .77805 .69297 L .80551 .69737 L p .707 .577 .707 r
F P
0 g
s
.47559 .72327 m .47559 .7418 L .49196 .73443 L p .707 .577 .707 r
F P
0 g
s
.49196 .73443 m .49196 .71591 L .47559 .72327 L p .707 .577 .707 r
F P
0 g
s
.31064 .73328 m .31064 .69622 L .29804 .68834 L p .707 .577 .707 r
F P
0 g
s
.29804 .644 m .29804 .58842 L .29515 .57988 L p .707 .577 .707 r
F P
0 g
s
.80551 .72148 m .80551 .74 L .77805 .73561 L p .707 .577 .707 r
F P
0 g
s
.77805 .73561 m .77805 .71708 L .80551 .72148 L p .707 .577 .707 r
F P
0 g
s
.68566 .73228 m .68566 .69523 L .71504 .69185 L p .707 .577 .707 r
F P
0 g
s
.31064 .73886 m .31064 .72033 L .29804 .71245 L p .707 .577 .707 r
F P
0 g
s
.68566 .73787 m .68566 .71934 L .71504 .71596 L p .707 .577 .707 r
F P
0 g
s
.29804 .68834 m .29804 .72539 L .31064 .73328 L p .707 .577 .707 r
F P
0 g
s
.77805 .69297 m .77805 .73003 L .74688 .72813 L p .707 .577 .707 r
F P
0 g
s
.74688 .72813 m .74688 .69107 L .77805 .69297 L p .707 .577 .707 r
F P
0 g
s
.29804 .71245 m .29804 .73098 L .31064 .73886 L p .707 .577 .707 r
F P
0 g
s
.71504 .69185 m .71504 .7289 L .68566 .73228 L p .707 .577 .707 r
F P
0 g
s
.71504 .71596 m .71504 .73449 L .68566 .73787 L p .707 .577 .707 r
F P
0 g
s
.71504 .7289 m .71504 .69185 L .74688 .69107 L p .707 .577 .707 r
F P
0 g
s
.49196 .69179 m .49196 .72885 L .49904 .72049 L p .707 .577 .707 r
F P
0 g
s
.49904 .72049 m .49904 .68343 L .49196 .69179 L p .707 .577 .707 r
F P
0 g
s
.29515 .57988 m .29515 .63546 L .29804 .644 L p .707 .577 .707 r
F P
0 g
s
.49904 .58351 m .49904 .63909 L .49615 .63055 L p .707 .577 .707 r
F P
0 g
s
.49615 .63055 m .49615 .57497 L .49904 .58351 L p .707 .577 .707 r
F P
0 g
s
.77805 .71708 m .77805 .73561 L .74688 .73371 L p .707 .577 .707 r
F P
0 g
s
.74688 .73371 m .74688 .71518 L .77805 .71708 L p .707 .577 .707 r
F P
0 g
s
.74688 .69107 m .74688 .72813 L .71504 .7289 L p .707 .577 .707 r
F P
0 g
s
.71504 .73449 m .71504 .71596 L .74688 .71518 L p .707 .577 .707 r
F P
0 g
s
.49196 .71591 m .49196 .73443 L .49904 .72607 L p .707 .577 .707 r
F P
0 g
s
.49904 .72607 m .49904 .70754 L .49196 .71591 L p .707 .577 .707 r
F P
0 g
s
.74688 .71518 m .74688 .73371 L .71504 .73449 L p .707 .577 .707 r
F P
0 g
s
.29804 .72539 m .29804 .68834 L .29515 .6798 L p .707 .577 .707 r
F P
0 g
s
.29515 .63546 m .29515 .57988 L .30223 .57151 L p .707 .577 .707 r
F P
0 g
s
.29804 .73098 m .29804 .71245 L .29515 .70391 L p .707 .577 .707 r
F P
0 g
s
.29515 .6798 m .29515 .71685 L .29804 .72539 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .70391 m .29515 .72243 L .29804 .73098 L p .707 .577 .707 r
F P
0 g
s
.49904 .68343 m .49904 .72049 L .49615 .71194 L p .707 .577 .707 r
F P
0 g
s
.49615 .71194 m .49615 .67489 L .49904 .68343 L p .707 .577 .707 r
F P
0 g
s
.30223 .57151 m .30223 .62709 L .29515 .63546 L p .707 .577 .707 r
F P
0 g
s
.49615 .57497 m .49615 .63055 L .48356 .62267 L p .707 .577 .707 r
F P
0 g
s
.48356 .62267 m .48356 .56708 L .49615 .57497 L p .707 .577 .707 r
F P
0 g
s
.49904 .70754 m .49904 .72607 L .49615 .71753 L p .707 .577 .707 r
F P
0 g
s
.49615 .71753 m .49615 .699 L .49904 .70754 L p .707 .577 .707 r
F P
0 g
s
.29515 .71685 m .29515 .6798 L .30223 .67143 L p .707 .577 .707 r
F P
0 g
s
.30223 .62709 m .30223 .57151 L .3186 .56414 L p .707 .577 .707 r
F P
0 g
s
.29515 .72243 m .29515 .70391 L .30223 .69554 L p .707 .577 .707 r
F P
0 g
s
.30223 .67143 m .30223 .70849 L .29515 .71685 L p .707 .577 .707 r
F P
0 g
s
.30223 .69554 m .30223 .71407 L .29515 .72243 L p .707 .577 .707 r
F P
0 g
s
.49615 .67489 m .49615 .71194 L .48356 .70406 L p .707 .577 .707 r
F P
0 g
s
.48356 .70406 m .48356 .667 L .49615 .67489 L p .707 .577 .707 r
F P
0 g
s
.3186 .56414 m .3186 .61973 L .30223 .62709 L p .707 .577 .707 r
F P
0 g
s
.48356 .56708 m .48356 .62267 L .4625 .61621 L p .707 .577 .707 r
F P
0 g
s
.4625 .61621 m .4625 .56063 L .48356 .56708 L p .707 .577 .707 r
F P
0 g
s
.49615 .699 m .49615 .71753 L .48356 .70964 L p .707 .577 .707 r
F P
0 g
s
.48356 .70964 m .48356 .69112 L .49615 .699 L p .707 .577 .707 r
F P
0 g
s
.3186 .61973 m .3186 .56414 L .34265 .55849 L p .707 .577 .707 r
F P
0 g
s
.30223 .70849 m .30223 .67143 L .3186 .66406 L p .707 .577 .707 r
F P
0 g
s
.30223 .71407 m .30223 .69554 L .3186 .68817 L p .707 .577 .707 r
F P
0 g
s
.3186 .66406 m .3186 .70112 L .30223 .70849 L p .707 .577 .707 r
F P
0 g
s
.4625 .56063 m .4625 .61621 L .43504 .61182 L p .707 .577 .707 r
F P
0 g
s
.43504 .61182 m .43504 .55624 L .4625 .56063 L p .707 .577 .707 r
F P
0 g
s
.3186 .68817 m .3186 .7067 L .30223 .71407 L p .707 .577 .707 r
F P
0 g
s
.34265 .55849 m .34265 .61408 L .3186 .61973 L p .707 .577 .707 r
F P
0 g
s
.48356 .667 m .48356 .70406 L .4625 .6976 L p .707 .577 .707 r
F P
0 g
s
.4625 .6976 m .4625 .66055 L .48356 .667 L p .707 .577 .707 r
F P
0 g
s
.34265 .61408 m .34265 .55849 L .37203 .55511 L p .707 .577 .707 r
F P
0 g
s
.48356 .69112 m .48356 .70964 L .4625 .70319 L p .707 .577 .707 r
F P
0 g
s
.4625 .70319 m .4625 .68466 L .48356 .69112 L p .707 .577 .707 r
F P
0 g
s
.3186 .70112 m .3186 .66406 L .34265 .65841 L p .707 .577 .707 r
F P
0 g
s
.43504 .55624 m .43504 .61182 L .40387 .60992 L p .707 .577 .707 r
F P
0 g
s
.40387 .60992 m .40387 .55434 L .43504 .55624 L p .707 .577 .707 r
F P
0 g
s
.37203 .6107 m .37203 .55511 L .40387 .55434 L p .707 .577 .707 r
F P
0 g
s
.37203 .55511 m .37203 .6107 L .34265 .61408 L p .707 .577 .707 r
F P
0 g
s
.3186 .7067 m .3186 .68817 L .34265 .68252 L p .707 .577 .707 r
F P
0 g
s
.40387 .55434 m .40387 .60992 L .37203 .6107 L p .707 .577 .707 r
F P
0 g
s
.34265 .65841 m .34265 .69547 L .3186 .70112 L p .707 .577 .707 r
F P
0 g
s
.34265 .68252 m .34265 .70105 L .3186 .7067 L p .707 .577 .707 r
F P
0 g
s
.4625 .66055 m .4625 .6976 L .43504 .69321 L p .707 .577 .707 r
F P
0 g
s
.43504 .69321 m .43504 .65616 L .4625 .66055 L p .707 .577 .707 r
F P
0 g
s
.4625 .68466 m .4625 .70319 L .43504 .6988 L p .707 .577 .707 r
F P
0 g
s
.43504 .6988 m .43504 .68027 L .4625 .68466 L p .707 .577 .707 r
F P
0 g
s
.34265 .69547 m .34265 .65841 L .37203 .65503 L p .707 .577 .707 r
F P
0 g
s
.34265 .70105 m .34265 .68252 L .37203 .67915 L p .707 .577 .707 r
F P
0 g
s
.43504 .65616 m .43504 .69321 L .40387 .69131 L p .707 .577 .707 r
F P
0 g
s
.40387 .69131 m .40387 .65426 L .43504 .65616 L p .707 .577 .707 r
F P
0 g
s
.37203 .65503 m .37203 .69209 L .34265 .69547 L p .707 .577 .707 r
F P
0 g
s
.37203 .67915 m .37203 .69767 L .34265 .70105 L p .707 .577 .707 r
F P
0 g
s
.37203 .69209 m .37203 .65503 L .40387 .65426 L p .707 .577 .707 r
F P
0 g
s
.43504 .68027 m .43504 .6988 L .40387 .6969 L p .707 .577 .707 r
F P
0 g
s
.40387 .6969 m .40387 .67837 L .43504 .68027 L p .707 .577 .707 r
F P
0 g
s
.40387 .65426 m .40387 .69131 L .37203 .69209 L p .707 .577 .707 r
F P
0 g
s
.37203 .69767 m .37203 .67915 L .40387 .67837 L p .707 .577 .707 r
F P
0 g
s
.40387 .67837 m .40387 .6969 L .37203 .69767 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001dOol300000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0071oo`@000AJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006io
o`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001J
EUYFFUH3001^Ool006aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001X
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00003
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@0
05YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH0
0000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Agoo2@0017oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000oOol80004FUH00`00FUIJEP02FUH700000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH300000eYF001JEP06FUHI00000eYF001JEP02FUH50007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031o
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EPD000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF2P001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000eYF00<005YFFUH01eYF2@0025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH000000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YFFUH01EYF1P000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH00004FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00
FUIJEP02FUH00`00FUH00005FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@00=goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0003
FUH00`00FUH00004FUH20002FUH80002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH70004
FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH400000eYF001JEP03FUH500000eYF0000000200001EYF001JEUYF00000eYF0P001EYF
00<005YFFUH01eYF1@000eYF0`0000=JEP00FUH00UYF00<005YFFUH025YF00<005YFFUH025YF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo
00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001J
EP800003FUH0000000AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP<000=JEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`00<7oo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUH005YF10001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000^Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJ
EQ@000EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`06001JEP00001JEP001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00
00800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
0003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP@000IJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000MJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04
001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040003FUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005
FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF1@001EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUHA0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP0000000eYF00<005YFFUH00eYF0P000eYF4P0015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YF00000`00;Goo000]Ool01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P000eYF2000
47oo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUH0009J
EP03001JEP0000D000=JEP8001Eoo`P000AJEP04001JEUYFFUH2000]Ool0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000@000AJEP<0
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH00000009JEP<00003FUH005YF009J
EPT000Uoo`T000=JEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<goo0`0000=JEP00
FUH01UYF5`000eYF00@005YFFUIJEPL0009JEP03001JEUYF00AJEP8000UJEP03001JEUYF009JEPD0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP0000<0009JEP04001J
EP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003FUH2000]Ool003Ioo`T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00H000MooaT00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
00=JEP05001JEUYF001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool003Eoo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD0011oo`<00003FUH005YF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<000IJEP03
001JEUYF00800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool0039oo`<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000moo`@000QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000L000EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]Ool0031oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80019o
o`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEPL000AJEPD000AJEP03001J
EUYF0080009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEPD000=JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000001Ioob80009JEP03001JEUYF00IJEPD000AJEP06001JEUYFFUH005YF0P0015YF0P001eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF0P00;Woo
000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00009goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00=JEP<000EJEQ4000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF5P0015YF00<005YFFUH00eYF00D005YFFUIJEP00
02Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH3
0003FUH00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP0002Uoo`03001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00
000aOol002aoo`03001JEP0000AJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP03001oogoo02Qoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo
00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001oogoo02Uoo`<000=JEP03001JEUYF
00EJEQ<000MJEP04001JEUYFFUH50003FUH20005FUH40008FUH00`00FUIJEP05FUH00`00FUH00003
000fOol002aoo`04001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool;0004FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF000000020003Ool90004FUH00`00FUIJEP02FUH>000jOol002ao
o`03001JEP0000AJEP03001JEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001J
EUYF0080031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
000=Ool90018Ool002aoo`03001JEP0000AJEP8000AJEPH001Moo`@0009JEP03001JEUYF00=JEP05
001JEUYFFUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002aoo`03001JEP0000AJEP03001JEP0000L001Uoo`T000=J
EP05001JEUYFFUH0000[Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001IOol002aoo`04001JEP000002FUH30002
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0WOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH3001GOol002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<007ooOol09Woo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH>0004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20002FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
00000eYF001oo`0VOol00`00FUH00004FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0002Moo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00E7oo000/Ool20003
FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00004FUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P00:7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00E7oo000]Ool00`00FUIJEP020005FUH00`00FUIJEP03FUH30005FUHA0003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00:7oo00@005YF000000=JEP03001JEUYF00=JEP8000MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000005Aoo`00;Woo
0P0000=JEP00FUH00UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002Uoo`03001JEP0000AJEP8000=JEPl000Uoo`P000=J
EP03001JEUYF00=JEP03001JEUYF00<005Aoo`00<7oo0`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`03001JEP0000AJEP03
001JEP0000@001ioo`D000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00AJEP<000MJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000/Ool01000FUH000000UYF0`0000=J
EP00FUH00UYF2@004Woo1@000eYF0`0000=JEP00FUH00UYF0P00E7oo000fOol50004FUH00`00FUIJ
EP04FUH20009FUH00`00FUIJEP02FUH7000aOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF4P000eYF00<005YFFUH015YF0`000eYF0P00E7oo000kOolK000hOol00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP0200000eYF0000001DOol008ioo`800003FUH0000000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4
001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03001DOol008ioo`80009JEP07
001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000=JEP03001JEP0005Aoo`00SWoo0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF00<005YF0000E7oo002?
Ool01000FUIJEP001EYF00<005YFFUH00eYF0`0025YF00<005YFFUH00UYF2@000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20003FUH20007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000F7oo
002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001JOol009Moo`D000=JEP8000EJEP@000QJEP03001JEUYF00EJEP03001JEP0000<0
05eoo`00W7oo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002UOolB001VOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77668 m .59613 .7211 L .56496 .7192 L p .707 .577 .707 r
F P
0 g
s
.59613 .7211 m .59613 .77668 L .62796 .77591 L p .707 .577 .707 r
F P
0 g
s
.62796 .77591 m .62796 .72032 L .59613 .7211 L p .707 .577 .707 r
F P
0 g
s
.62796 .72032 m .62796 .77591 L .65735 .77253 L p .707 .577 .707 r
F P
0 g
s
.65735 .77253 m .65734 .71694 L .62796 .72032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77478 m .56496 .7192 L .5375 .71481 L p .707 .577 .707 r
F P
0 g
s
.56496 .7192 m .56496 .77478 L .59613 .77668 L p .707 .577 .707 r
F P
0 g
s
.65734 .71694 m .65735 .77253 L .6814 .76688 L p .707 .577 .707 r
F P
0 g
s
.6814 .76688 m .6814 .71129 L .65734 .71694 L p .707 .577 .707 r
F P
0 g
s
.5375 .71481 m .5375 .77039 L .56496 .77478 L p .707 .577 .707 r
F P
0 g
s
.5375 .77039 m .5375 .71481 L .51644 .70835 L p .707 .577 .707 r
F P
0 g
s
.59613 .85004 m .59613 .81299 L .56496 .81109 L p .707 .577 .707 r
F P
0 g
s
.59613 .81299 m .59613 .85004 L .62796 .84926 L p .707 .577 .707 r
F P
0 g
s
.62796 .84926 m .62796 .81221 L .59613 .81299 L p .707 .577 .707 r
F P
0 g
s
.62796 .81221 m .62796 .84926 L .65735 .84589 L p .707 .577 .707 r
F P
0 g
s
.65735 .84589 m .65735 .80883 L .62796 .81221 L p .707 .577 .707 r
F P
0 g
s
.56496 .84814 m .56496 .81109 L .5375 .80669 L p .707 .577 .707 r
F P
0 g
s
.56496 .81109 m .56496 .84814 L .59613 .85004 L p .707 .577 .707 r
F P
0 g
s
.6814 .71129 m .6814 .76688 L .69777 .75951 L p .707 .577 .707 r
F P
0 g
s
.69777 .75951 m .69777 .70393 L .6814 .71129 L p .707 .577 .707 r
F P
0 g
s
.59613 .86947 m .59613 .85094 L .56496 .84904 L p .707 .577 .707 r
F P
0 g
s
.59613 .85094 m .59613 .86947 L .62796 .86869 L p .707 .577 .707 r
F P
0 g
s
.62796 .86869 m .62796 .85017 L .59613 .85094 L p .707 .577 .707 r
F P
0 g
s
.51644 .70835 m .51644 .76394 L .5375 .77039 L p .707 .577 .707 r
F P
0 g
s
.62796 .85017 m .62796 .86869 L .65735 .86532 L p .707 .577 .707 r
F P
0 g
s
.65735 .86532 m .65735 .84679 L .62796 .85017 L p .707 .577 .707 r
F P
0 g
s
.65735 .80883 m .65735 .84589 L .6814 .84024 L p .707 .577 .707 r
F P
0 g
s
.6814 .84024 m .6814 .80318 L .65735 .80883 L p .707 .577 .707 r
F P
0 g
s
.56496 .84904 m .56496 .86757 L .59613 .86947 L p .707 .577 .707 r
F P
0 g
s
.5375 .80669 m .5375 .84375 L .56496 .84814 L p .707 .577 .707 r
F P
0 g
s
.56496 .86757 m .56496 .84904 L .5375 .84465 L p .707 .577 .707 r
F P
0 g
s
.51644 .76394 m .51644 .70835 L .50385 .70047 L p .707 .577 .707 r
F P
0 g
s
.5375 .84465 m .5375 .86318 L .56496 .86757 L p .707 .577 .707 r
F P
0 g
s
.5375 .84375 m .5375 .80669 L .51644 .80024 L p .707 .577 .707 r
F P
0 g
s
.65735 .84679 m .65735 .86532 L .6814 .85967 L p .707 .577 .707 r
F P
0 g
s
.6814 .85967 m .6814 .84114 L .65735 .84679 L p .707 .577 .707 r
F P
0 g
s
.51644 .80024 m .51644 .83729 L .5375 .84375 L p .707 .577 .707 r
F P
0 g
s
.5375 .86318 m .5375 .84465 L .51644 .8382 L p .707 .577 .707 r
F P
0 g
s
.6814 .80318 m .6814 .84024 L .69777 .83287 L p .707 .577 .707 r
F P
0 g
s
.69777 .83287 m .69777 .79581 L .6814 .80318 L p .707 .577 .707 r
F P
0 g
s
.50385 .70047 m .50385 .75605 L .51644 .76394 L p .707 .577 .707 r
F P
0 g
s
.69777 .70393 m .69777 .75951 L .70485 .75114 L p .707 .577 .707 r
F P
0 g
s
.70485 .75114 m .70485 .69556 L .69777 .70393 L p .707 .577 .707 r
F P
0 g
s
.51644 .8382 m .51644 .85673 L .5375 .86318 L p .707 .577 .707 r
F P
0 g
s
.51644 .83729 m .51644 .80024 L .50385 .79236 L p .707 .577 .707 r
F P
0 g
s
.6814 .84114 m .6814 .85967 L .69777 .8523 L p .707 .577 .707 r
F P
0 g
s
.69777 .8523 m .69777 .83377 L .6814 .84114 L p .707 .577 .707 r
F P
0 g
s
.50385 .75605 m .50385 .70047 L .50095 .69193 L p .707 .577 .707 r
F P
0 g
s
.50385 .79236 m .50385 .82941 L .51644 .83729 L p .707 .577 .707 r
F P
0 g
s
.51644 .85673 m .51644 .8382 L .50385 .83031 L p .707 .577 .707 r
F P
0 g
s
.49044 .78751 m .49044 .28562 L .44643 .28294 L p .707 .577 .707 r
F P
0 g
s
.50095 .69193 m .50095 .74751 L .50385 .75605 L p .707 .577 .707 r
F P
0 g
s
.50385 .82941 m .50385 .79236 L .50095 .78381 L p .707 .577 .707 r
F P
0 g
s
.50095 .74751 m .50095 .69193 L .50804 .68356 L p .707 .577 .707 r
F P
0 g
s
.50095 .78381 m .50095 .82087 L .50385 .82941 L p .707 .577 .707 r
F P
0 g
s
.50804 .68356 m .50804 .73915 L .50095 .74751 L p .707 .577 .707 r
F P
0 g
s
.50095 .82087 m .50095 .78381 L .50804 .77545 L p .707 .577 .707 r
F P
0 g
s
.50804 .73915 m .50804 .68356 L .5244 .6762 L p .707 .577 .707 r
F P
0 g
s
.50804 .77545 m .50804 .8125 L .50095 .82087 L p .707 .577 .707 r
F P
0 g
s
.5244 .6762 m .5244 .73178 L .50804 .73915 L p .707 .577 .707 r
F P
0 g
s
.50804 .8125 m .50804 .77545 L .5244 .76808 L p .707 .577 .707 r
F P
0 g
s
.5244 .73178 m .5244 .6762 L .54846 .67055 L p .707 .577 .707 r
F P
0 g
s
.5244 .76808 m .5244 .80514 L .50804 .8125 L p .707 .577 .707 r
F P
0 g
s
.54846 .67055 m .54846 .72613 L .5244 .73178 L p .707 .577 .707 r
F P
0 g
s
.5244 .80514 m .5244 .76808 L .54846 .76243 L p .707 .577 .707 r
F P
0 g
s
.54846 .76243 m .54846 .79949 L .5244 .80514 L p .707 .577 .707 r
F P
0 g
s
.49044 .28562 m .49044 .78751 L .53538 .78641 L p .707 .577 .707 r
F P
0 g
s
.53538 .78641 m .53538 .28452 L .49044 .28562 L p .707 .577 .707 r
F P
0 g
s
.50385 .83031 m .50385 .84884 L .51644 .85673 L p .707 .577 .707 r
F P
0 g
s
.69777 .79581 m .69777 .83287 L .70485 .8245 L p .707 .577 .707 r
F P
0 g
s
.70485 .8245 m .70485 .78745 L .69777 .79581 L p .707 .577 .707 r
F P
0 g
s
.54846 .72613 m .54846 .67055 L .57784 .66717 L p .707 .577 .707 r
F P
0 g
s
.57784 .66717 m .57784 .72275 L .54846 .72613 L p .707 .577 .707 r
F P
0 g
s
.54846 .79949 m .54846 .76243 L .57784 .75905 L p .707 .577 .707 r
F P
0 g
s
.57784 .75905 m .57784 .79611 L .54846 .79949 L p .707 .577 .707 r
F P
0 g
s
.53538 .28452 m .53538 .78641 L .57686 .78164 L p .707 .577 .707 r
F P
0 g
s
.57686 .78164 m .57686 .27975 L .53538 .28452 L p .707 .577 .707 r
F P
0 g
s
.70485 .69556 m .70485 .75114 L .70195 .7426 L p .707 .577 .707 r
F P
0 g
s
.70195 .7426 m .70195 .68702 L .70485 .69556 L p .707 .577 .707 r
F P
0 g
s
.44643 .78482 m .44643 .28294 L .40766 .27673 L p .707 .577 .707 r
F P
0 g
s
.44643 .28294 m .44643 .78482 L .49044 .78751 L p .707 .577 .707 r
F P
0 g
s
.69777 .83377 m .69777 .8523 L .70485 .84393 L p .707 .577 .707 r
F P
0 g
s
.70485 .84393 m .70485 .82541 L .69777 .83377 L p .707 .577 .707 r
F P
0 g
s
.57784 .72275 m .57784 .66717 L .60968 .66639 L p .707 .577 .707 r
F P
0 g
s
.60968 .66639 m .60968 .72197 L .57784 .72275 L p .707 .577 .707 r
F P
0 g
s
.60968 .79533 m .60968 .75828 L .64085 .76018 L p .707 .577 .707 r
F P
0 g
s
.57784 .79611 m .57784 .75905 L .60968 .75828 L p .707 .577 .707 r
F P
0 g
s
.60968 .75828 m .60968 .79533 L .57784 .79611 L p .707 .577 .707 r
F P
0 g
s
.57686 .27975 m .57686 .78164 L .61082 .77366 L p .707 .577 .707 r
F P
0 g
s
.64085 .66829 m .64085 .72387 L .60968 .72197 L p .707 .577 .707 r
F P
0 g
s
.60968 .72197 m .60968 .66639 L .64085 .66829 L p .707 .577 .707 r
F P
0 g
s
.61082 .77366 m .61082 .27177 L .57686 .27975 L p .707 .577 .707 r
F P
0 g
s
.50385 .84884 m .50385 .83031 L .50095 .82177 L p .707 .577 .707 r
F P
0 g
s
.50095 .82177 m .50095 .8403 L .50385 .84884 L p .707 .577 .707 r
F P
0 g
s
.40766 .77862 m .40766 .27673 L .37794 .26762 L p .707 .577 .707 r
F P
0 g
s
.40766 .27673 m .40766 .77862 L .44643 .78482 L p .707 .577 .707 r
F P
0 g
s
.70485 .78745 m .70485 .8245 L .70195 .81596 L p .707 .577 .707 r
F P
0 g
s
.70195 .81596 m .70195 .77891 L .70485 .78745 L p .707 .577 .707 r
F P
0 g
s
.70195 .68702 m .70195 .7426 L .68936 .73472 L p .707 .577 .707 r
F P
0 g
s
.68936 .73472 m .68936 .67914 L .70195 .68702 L p .707 .577 .707 r
F P
0 g
s
.70485 .82541 m .70485 .84393 L .70195 .83539 L p .707 .577 .707 r
F P
0 g
s
.70195 .83539 m .70195 .81686 L .70485 .82541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25312 .73987 m .25312 .68429 L .22195 .68238 L p .707 .577 .707 r
F P
0 g
s
.25312 .68429 m .25312 .73987 L .28495 .73909 L p .707 .577 .707 r
F P
0 g
s
.28495 .73909 m .28495 .68351 L .25312 .68429 L p .707 .577 .707 r
F P
0 g
s
.61082 .27177 m .61082 .77366 L .63393 .76326 L p .707 .577 .707 r
F P
0 g
s
.63393 .76326 m .63393 .26137 L .61082 .27177 L p .707 .577 .707 r
F P
0 g
s
.28495 .68351 m .28495 .73909 L .31434 .73571 L p .707 .577 .707 r
F P
0 g
s
.31434 .73571 m .31434 .68013 L .28495 .68351 L p .707 .577 .707 r
F P
0 g
s
.22195 .73797 m .22195 .68238 L .19449 .67799 L p .707 .577 .707 r
F P
0 g
s
.22195 .68238 m .22195 .73797 L .25312 .73987 L p .707 .577 .707 r
F P
0 g
s
.50095 .8403 m .50095 .82177 L .50804 .81341 L p .707 .577 .707 r
F P
0 g
s
.50804 .81341 m .50804 .83193 L .50095 .8403 L p .707 .577 .707 r
F P
0 g
s
.31434 .68013 m .31434 .73571 L .33839 .73006 L p .707 .577 .707 r
F P
0 g
s
.33839 .73006 m .33839 .67448 L .31434 .68013 L p .707 .577 .707 r
F P
0 g
s
.70195 .77891 m .70195 .81596 L .68936 .80808 L p .707 .577 .707 r
F P
0 g
s
.68936 .80808 m .68936 .77102 L .70195 .77891 L p .707 .577 .707 r
F P
0 g
s
.37794 .76951 m .37794 .26762 L .36016 .25649 L p .707 .577 .707 r
F P
0 g
s
.37794 .26762 m .37794 .76951 L .40766 .77862 L p .707 .577 .707 r
F P
0 g
s
.68936 .67914 m .68936 .73472 L .66831 .72826 L p .707 .577 .707 r
F P
0 g
s
.66831 .72826 m .66831 .67268 L .68936 .67914 L p .707 .577 .707 r
F P
0 g
s
.19449 .67799 m .19449 .73357 L .22195 .73797 L p .707 .577 .707 r
F P
0 g
s
.19449 .73357 m .19449 .67799 L .17343 .67154 L p .707 .577 .707 r
F P
0 g
s
.25312 .81323 m .25312 .77617 L .22195 .77427 L p .707 .577 .707 r
F P
0 g
s
.25312 .77617 m .25312 .81323 L .28495 .81245 L p .707 .577 .707 r
F P
0 g
s
.28495 .81245 m .28495 .77539 L .25312 .77617 L p .707 .577 .707 r
F P
0 g
s
.70195 .81686 m .70195 .83539 L .68936 .82751 L p .707 .577 .707 r
F P
0 g
s
.68936 .82751 m .68936 .80898 L .70195 .81686 L p .707 .577 .707 r
F P
0 g
s
.28495 .77539 m .28495 .81245 L .31434 .80907 L p .707 .577 .707 r
F P
0 g
s
.31434 .80907 m .31434 .77202 L .28495 .77539 L p .707 .577 .707 r
F P
0 g
s
.22195 .81133 m .22195 .77427 L .19449 .76988 L p .707 .577 .707 r
F P
0 g
s
.22195 .77427 m .22195 .81133 L .25312 .81323 L p .707 .577 .707 r
F P
0 g
s
.33839 .67448 m .33839 .73006 L .35476 .72269 L p .707 .577 .707 r
F P
0 g
s
.35476 .72269 m .35476 .66711 L .33839 .67448 L p .707 .577 .707 r
F P
0 g
s
.25312 .83266 m .25312 .81413 L .22195 .81223 L p .707 .577 .707 r
F P
0 g
s
.25312 .81413 m .25312 .83266 L .28495 .83188 L p .707 .577 .707 r
F P
0 g
s
.28495 .83188 m .28495 .81335 L .25312 .81413 L p .707 .577 .707 r
F P
0 g
s
.17343 .67154 m .17343 .72712 L .19449 .73357 L p .707 .577 .707 r
F P
0 g
s
.50804 .83193 m .50804 .81341 L .5244 .80604 L p .707 .577 .707 r
F P
0 g
s
.28495 .81335 m .28495 .83188 L .31434 .8285 L p .707 .577 .707 r
F P
0 g
s
.31434 .8285 m .31434 .80997 L .28495 .81335 L p .707 .577 .707 r
F P
0 g
s
.66831 .67268 m .66831 .72826 L .64085 .72387 L p .707 .577 .707 r
F P
0 g
s
.64085 .72387 m .64085 .66829 L .66831 .67268 L p .707 .577 .707 r
F P
0 g
s
.63393 .26137 m .63393 .76326 L .64393 .75145 L p .707 .577 .707 r
F P
0 g
s
.64393 .75145 m .64393 .24956 L .63393 .26137 L p .707 .577 .707 r
F P
0 g
s
.31434 .77202 m .31434 .80907 L .33839 .80342 L p .707 .577 .707 r
F P
0 g
s
.33839 .80342 m .33839 .76637 L .31434 .77202 L p .707 .577 .707 r
F P
0 g
s
.22195 .81223 m .22195 .83076 L .25312 .83266 L p .707 .577 .707 r
F P
0 g
s
.19449 .76988 m .19449 .80693 L .22195 .81133 L p .707 .577 .707 r
F P
0 g
s
.22195 .83076 m .22195 .81223 L .19449 .80784 L p .707 .577 .707 r
F P
0 g
s
.5244 .80604 m .5244 .82457 L .50804 .83193 L p .707 .577 .707 r
F P
0 g
s
.68936 .77102 m .68936 .80808 L .66831 .80162 L p .707 .577 .707 r
F P
0 g
s
.66831 .80162 m .66831 .76457 L .68936 .77102 L p .707 .577 .707 r
F P
0 g
s
.17343 .72712 m .17343 .67154 L .16084 .66365 L p .707 .577 .707 r
F P
0 g
s
.19449 .80784 m .19449 .82636 L .22195 .83076 L p .707 .577 .707 r
F P
0 g
s
.19449 .80693 m .19449 .76988 L .17343 .76342 L p .707 .577 .707 r
F P
0 g
s
.31434 .80997 m .31434 .8285 L .33839 .82285 L p .707 .577 .707 r
F P
0 g
s
.33839 .82285 m .33839 .80432 L .31434 .80997 L p .707 .577 .707 r
F P
0 g
s
.68936 .80898 m .68936 .82751 L .66831 .82105 L p .707 .577 .707 r
F P
0 g
s
.66831 .82105 m .66831 .80253 L .68936 .80898 L p .707 .577 .707 r
F P
0 g
s
.35476 .66711 m .35476 .72269 L .36184 .71433 L p .707 .577 .707 r
F P
0 g
s
.36184 .71433 m .36184 .65875 L .35476 .66711 L p .707 .577 .707 r
F P
0 g
s
.36184 .78769 m .36184 .75063 L .35476 .759 L p .707 .577 .707 r
F P
0 g
s
.36184 .65875 m .36184 .71433 L .35894 .70579 L p .707 .577 .707 r
F P
0 g
s
.35894 .70579 m .35894 .65021 L .36184 .65875 L p .707 .577 .707 r
F P
0 g
s
.35476 .759 m .35476 .79605 L .36184 .78769 L p .707 .577 .707 r
F P
0 g
s
.35894 .77915 m .35894 .74209 L .36184 .75063 L p .707 .577 .707 r
F P
0 g
s
.36016 .75838 m .36016 .25649 L .35607 .24443 L p .707 .577 .707 r
F P
0 g
s
.36184 .75063 m .36184 .78769 L .35894 .77915 L p .707 .577 .707 r
F P
0 g
s
.36016 .25649 m .36016 .75838 L .37794 .76951 L p .707 .577 .707 r
F P
0 g
s
.17343 .76342 m .17343 .80048 L .19449 .80693 L p .707 .577 .707 r
F P
0 g
s
.19449 .82636 m .19449 .80784 L .17343 .80138 L p .707 .577 .707 r
F P
0 g
s
.33839 .76637 m .33839 .80342 L .35476 .79605 L p .707 .577 .707 r
F P
0 g
s
.35476 .79605 m .35476 .759 L .33839 .76637 L p .707 .577 .707 r
F P
0 g
s
.16084 .66365 m .16084 .71924 L .17343 .72712 L p .707 .577 .707 r
F P
0 g
s
.17343 .80138 m .17343 .81991 L .19449 .82636 L p .707 .577 .707 r
F P
0 g
s
.5244 .82457 m .5244 .80604 L .54846 .80039 L p .707 .577 .707 r
F P
0 g
s
.66831 .76457 m .66831 .80162 L .64085 .79723 L p .707 .577 .707 r
F P
0 g
s
.64085 .79723 m .64085 .76018 L .66831 .76457 L p .707 .577 .707 r
F P
0 g
s
.54846 .80039 m .54846 .81892 L .5244 .82457 L p .707 .577 .707 r
F P
0 g
s
.17343 .80048 m .17343 .76342 L .16084 .75554 L p .707 .577 .707 r
F P
0 g
s
.33839 .80432 m .33839 .82285 L .35476 .81548 L p .707 .577 .707 r
F P
0 g
s
.35476 .81548 m .35476 .79696 L .33839 .80432 L p .707 .577 .707 r
F P
0 g
s
.16084 .71924 m .16084 .66365 L .15794 .65511 L p .707 .577 .707 r
F P
0 g
s
.66831 .80253 m .66831 .82105 L .64085 .81666 L p .707 .577 .707 r
F P
0 g
s
.64085 .81666 m .64085 .79813 L .66831 .80253 L p .707 .577 .707 r
F P
0 g
s
.64393 .24956 m .64393 .75145 L .63984 .73939 L p .707 .577 .707 r
F P
0 g
s
.63984 .73939 m .63984 .2375 L .64393 .24956 L p .707 .577 .707 r
F P
0 g
s
.16084 .75554 m .16084 .7926 L .17343 .80048 L p .707 .577 .707 r
F P
0 g
s
.17343 .81991 m .17343 .80138 L .16084 .7935 L p .707 .577 .707 r
F P
0 g
s
.64085 .76018 m .64085 .79723 L .60968 .79533 L p .707 .577 .707 r
F P
0 g
s
.54846 .81892 m .54846 .80039 L .57784 .79701 L p .707 .577 .707 r
F P
0 g
s
.16084 .7935 m .16084 .81203 L .17343 .81991 L p .707 .577 .707 r
F P
0 g
s
.15794 .65511 m .15794 .71069 L .16084 .71924 L p .707 .577 .707 r
F P
0 g
s
.57784 .79701 m .57784 .81554 L .54846 .81892 L p .707 .577 .707 r
F P
0 g
s
.64085 .79813 m .64085 .81666 L .60968 .81476 L p .707 .577 .707 r
F P
0 g
s
.60968 .81476 m .60968 .79623 L .64085 .79813 L p .707 .577 .707 r
F P
0 g
s
.57784 .81554 m .57784 .79701 L .60968 .79623 L p .707 .577 .707 r
F P
0 g
s
.35476 .79696 m .35476 .81548 L .36184 .80712 L p .707 .577 .707 r
F P
0 g
s
.36184 .80712 m .36184 .78859 L .35476 .79696 L p .707 .577 .707 r
F P
0 g
s
.16084 .7926 m .16084 .75554 L .15794 .747 L p .707 .577 .707 r
F P
0 g
s
.35894 .65021 m .35894 .70579 L .34635 .6979 L p .707 .577 .707 r
F P
0 g
s
.34635 .6979 m .34635 .64232 L .35894 .65021 L p .707 .577 .707 r
F P
0 g
s
.35894 .74209 m .35894 .77915 L .34635 .77126 L p .707 .577 .707 r
F P
0 g
s
.34635 .77126 m .34635 .73421 L .35894 .74209 L p .707 .577 .707 r
F P
0 g
s
.35607 .24443 m .35607 .74632 L .36016 .75838 L p .707 .577 .707 r
F P
0 g
s
.35607 .74632 m .35607 .24443 L .36607 .23262 L p .707 .577 .707 r
F P
0 g
s
.60968 .79623 m .60968 .81476 L .57784 .81554 L p .707 .577 .707 r
F P
0 g
s
.15794 .71069 m .15794 .65511 L .16503 .64675 L p .707 .577 .707 r
F P
0 g
s
.15794 .747 m .15794 .78405 L .16084 .7926 L p .707 .577 .707 r
F P
0 g
s
.16084 .81203 m .16084 .7935 L .15794 .78496 L p .707 .577 .707 r
F P
0 g
s
.15794 .78496 m .15794 .80348 L .16084 .81203 L p .707 .577 .707 r
F P
0 g
s
.16503 .64675 m .16503 .70233 L .15794 .71069 L p .707 .577 .707 r
F P
0 g
s
.63984 .2375 m .63984 .73939 L .62206 .72826 L p .707 .577 .707 r
F P
0 g
s
.62206 .72826 m .62206 .22637 L .63984 .2375 L p .707 .577 .707 r
F P
0 g
s
.36184 .78859 m .36184 .80712 L .35894 .79858 L p .707 .577 .707 r
F P
0 g
s
.35894 .79858 m .35894 .78005 L .36184 .78859 L p .707 .577 .707 r
F P
0 g
s
.15794 .78405 m .15794 .747 L .16503 .73863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70233 m .16503 .64675 L .1814 .63938 L p .707 .577 .707 r
F P
0 g
s
.16503 .73863 m .16503 .77569 L .15794 .78405 L p .707 .577 .707 r
F P
0 g
s
.15794 .80348 m .15794 .78496 L .16503 .77659 L p .707 .577 .707 r
F P
0 g
s
.36607 .73451 m .36607 .23262 L .38918 .22222 L p .707 .577 .707 r
F P
0 g
s
.36607 .23262 m .36607 .73451 L .35607 .74632 L p .707 .577 .707 r
F P
0 g
s
.16503 .77659 m .16503 .79512 L .15794 .80348 L p .707 .577 .707 r
F P
0 g
s
.1814 .63938 m .1814 .69496 L .16503 .70233 L p .707 .577 .707 r
F P
0 g
s
.34635 .64232 m .34635 .6979 L .3253 .69145 L p .707 .577 .707 r
F P
0 g
s
.3253 .69145 m .3253 .63587 L .34635 .64232 L p .707 .577 .707 r
F P
0 g
s
.35894 .78005 m .35894 .79858 L .34635 .79069 L p .707 .577 .707 r
F P
0 g
s
.34635 .79069 m .34635 .77217 L .35894 .78005 L p .707 .577 .707 r
F P
0 g
s
.16503 .77569 m .16503 .73863 L .1814 .73127 L p .707 .577 .707 r
F P
0 g
s
.1814 .69496 m .1814 .63938 L .20545 .63373 L p .707 .577 .707 r
F P
0 g
s
.62206 .22637 m .62206 .72826 L .59233 .71915 L p .707 .577 .707 r
F P
0 g
s
.59233 .71915 m .59233 .21726 L .62206 .22637 L p .707 .577 .707 r
F P
0 g
s
.1814 .73127 m .1814 .76832 L .16503 .77569 L p .707 .577 .707 r
F P
0 g
s
.16503 .79512 m .16503 .77659 L .1814 .76922 L p .707 .577 .707 r
F P
0 g
s
.3253 .63587 m .3253 .69145 L .29784 .68706 L p .707 .577 .707 r
F P
0 g
s
.29784 .68706 m .29784 .63147 L .3253 .63587 L p .707 .577 .707 r
F P
0 g
s
.1814 .76922 m .1814 .78775 L .16503 .79512 L p .707 .577 .707 r
F P
0 g
s
.34635 .73421 m .34635 .77126 L .3253 .76481 L p .707 .577 .707 r
F P
0 g
s
.3253 .76481 m .3253 .72775 L .34635 .73421 L p .707 .577 .707 r
F P
0 g
s
.20545 .63373 m .20545 .68931 L .1814 .69496 L p .707 .577 .707 r
F P
0 g
s
.38918 .22222 m .38918 .72411 L .36607 .73451 L p .707 .577 .707 r
F P
0 g
s
.38918 .72411 m .38918 .22222 L .42314 .21425 L p .707 .577 .707 r
F P
0 g
s
.20545 .68931 m .20545 .63373 L .23483 .63035 L p .707 .577 .707 r
F P
0 g
s
.1814 .76832 m .1814 .73127 L .20545 .72562 L p .707 .577 .707 r
F P
0 g
s
.34635 .77217 m .34635 .79069 L .3253 .78424 L p .707 .577 .707 r
F P
0 g
s
.3253 .78424 m .3253 .76571 L .34635 .77217 L p .707 .577 .707 r
F P
0 g
s
.29784 .63147 m .29784 .68706 L .26667 .68516 L p .707 .577 .707 r
F P
0 g
s
.26667 .68516 m .26667 .62957 L .29784 .63147 L p .707 .577 .707 r
F P
0 g
s
.23483 .68593 m .23483 .63035 L .26667 .62957 L p .707 .577 .707 r
F P
0 g
s
.23483 .63035 m .23483 .68593 L .20545 .68931 L p .707 .577 .707 r
F P
0 g
s
.26667 .62957 m .26667 .68516 L .23483 .68593 L p .707 .577 .707 r
F P
0 g
s
.20545 .72562 m .20545 .76267 L .1814 .76832 L p .707 .577 .707 r
F P
0 g
s
.1814 .78775 m .1814 .76922 L .20545 .76357 L p .707 .577 .707 r
F P
0 g
s
.59233 .21726 m .59233 .71915 L .55357 .71295 L p .707 .577 .707 r
F P
0 g
s
.55357 .71295 m .55357 .21106 L .59233 .21726 L p .707 .577 .707 r
F P
0 g
s
.73333 .68464 m .73333 .62906 L .70216 .62716 L p .707 .577 .707 r
F P
0 g
s
.73333 .62906 m .73333 .68464 L .76517 .68387 L p .707 .577 .707 r
F P
0 g
s
.76517 .68387 m .76517 .62828 L .73333 .62906 L p .707 .577 .707 r
F P
0 g
s
.3253 .72775 m .3253 .76481 L .29784 .76042 L p .707 .577 .707 r
F P
0 g
s
.29784 .76042 m .29784 .72336 L .3253 .72775 L p .707 .577 .707 r
F P
0 g
s
.76517 .62828 m .76517 .68387 L .79455 .68049 L p .707 .577 .707 r
F P
0 g
s
.79455 .68049 m .79455 .62491 L .76517 .62828 L p .707 .577 .707 r
F P
0 g
s
.20545 .76357 m .20545 .7821 L .1814 .78775 L p .707 .577 .707 r
F P
0 g
s
.70216 .68274 m .70216 .62716 L .6747 .62277 L p .707 .577 .707 r
F P
0 g
s
.70216 .62716 m .70216 .68274 L .73333 .68464 L p .707 .577 .707 r
F P
0 g
s
.20545 .76267 m .20545 .72562 L .23483 .72224 L p .707 .577 .707 r
F P
0 g
s
.42314 .71613 m .42314 .21425 L .46462 .20948 L p .707 .577 .707 r
F P
0 g
s
.42314 .21425 m .42314 .71613 L .38918 .72411 L p .707 .577 .707 r
F P
0 g
s
.3253 .76571 m .3253 .78424 L .29784 .77985 L p .707 .577 .707 r
F P
0 g
s
.29784 .77985 m .29784 .76132 L .3253 .76571 L p .707 .577 .707 r
F P
0 g
s
.79455 .62491 m .79455 .68049 L .8186 .67484 L p .707 .577 .707 r
F P
0 g
s
.8186 .67484 m .8186 .61926 L .79455 .62491 L p .707 .577 .707 r
F P
0 g
s
.29784 .72336 m .29784 .76042 L .26667 .75852 L p .707 .577 .707 r
F P
0 g
s
.26667 .75852 m .26667 .72146 L .29784 .72336 L p .707 .577 .707 r
F P
0 g
s
.23483 .72224 m .23483 .75929 L .20545 .76267 L p .707 .577 .707 r
F P
0 g
s
.20545 .7821 m .20545 .76357 L .23483 .7602 L p .707 .577 .707 r
F P
0 g
s
.23483 .75929 m .23483 .72224 L .26667 .72146 L p .707 .577 .707 r
F P
0 g
s
.55357 .21106 m .55357 .71295 L .50956 .71027 L p .707 .577 .707 r
F P
0 g
s
.50956 .71027 m .50956 .20838 L .55357 .21106 L p .707 .577 .707 r
F P
0 g
s
.6747 .62277 m .6747 .67835 L .70216 .68274 L p .707 .577 .707 r
F P
0 g
s
.6747 .67835 m .6747 .62277 L .65365 .61632 L p .707 .577 .707 r
F P
0 g
s
.26667 .72146 m .26667 .75852 L .23483 .75929 L p .707 .577 .707 r
F P
0 g
s
.23483 .7602 m .23483 .77872 L .20545 .7821 L p .707 .577 .707 r
F P
0 g
s
.73333 .758 m .73333 .72095 L .70216 .71905 L p .707 .577 .707 r
F P
0 g
s
.73333 .72095 m .73333 .758 L .76517 .75723 L p .707 .577 .707 r
F P
0 g
s
.76517 .75723 m .76517 .72017 L .73333 .72095 L p .707 .577 .707 r
F P
0 g
s
.46462 .71136 m .46462 .20948 L .50956 .20838 L p .707 .577 .707 r
F P
0 g
s
.46462 .20948 m .46462 .71136 L .42314 .71613 L p .707 .577 .707 r
F P
0 g
s
.29784 .76132 m .29784 .77985 L .26667 .77795 L p .707 .577 .707 r
F P
0 g
s
.26667 .77795 m .26667 .75942 L .29784 .76132 L p .707 .577 .707 r
F P
0 g
s
.76517 .72017 m .76517 .75723 L .79455 .75385 L p .707 .577 .707 r
F P
0 g
s
.79455 .75385 m .79455 .71679 L .76517 .72017 L p .707 .577 .707 r
F P
0 g
s
.50956 .20838 m .50956 .71027 L .46462 .71136 L p .707 .577 .707 r
F P
0 g
s
.23483 .77872 m .23483 .7602 L .26667 .75942 L p .707 .577 .707 r
F P
0 g
s
.70216 .7561 m .70216 .71905 L .6747 .71466 L p .707 .577 .707 r
F P
0 g
s
.70216 .71905 m .70216 .7561 L .73333 .758 L p .707 .577 .707 r
F P
0 g
s
.26667 .75942 m .26667 .77795 L .23483 .77872 L p .707 .577 .707 r
F P
0 g
s
.8186 .61926 m .8186 .67484 L .83497 .66747 L p .707 .577 .707 r
F P
0 g
s
.83497 .66747 m .83497 .61189 L .8186 .61926 L p .707 .577 .707 r
F P
0 g
s
.73333 .77743 m .73333 .75891 L .70216 .75701 L p .707 .577 .707 r
F P
0 g
s
.73333 .75891 m .73333 .77743 L .76517 .77666 L p .707 .577 .707 r
F P
0 g
s
.76517 .77666 m .76517 .75813 L .73333 .75891 L p .707 .577 .707 r
F P
0 g
s
.65365 .61632 m .65365 .6719 L .6747 .67835 L p .707 .577 .707 r
F P
0 g
s
.76517 .75813 m .76517 .77666 L .79455 .77328 L p .707 .577 .707 r
F P
0 g
s
.79455 .77328 m .79455 .75475 L .76517 .75813 L p .707 .577 .707 r
F P
0 g
s
.79455 .71679 m .79455 .75385 L .8186 .7482 L p .707 .577 .707 r
F P
0 g
s
.8186 .7482 m .8186 .71114 L .79455 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75701 m .70216 .77553 L .73333 .77743 L p .707 .577 .707 r
F P
0 g
s
.6747 .71466 m .6747 .75171 L .70216 .7561 L p .707 .577 .707 r
F P
0 g
s
.70216 .77553 m .70216 .75701 L .6747 .75261 L p .707 .577 .707 r
F P
0 g
s
.65365 .6719 m .65365 .61632 L .64105 .60843 L p .707 .577 .707 r
F P
0 g
s
.6747 .75261 m .6747 .77114 L .70216 .77553 L p .707 .577 .707 r
F P
0 g
s
.6747 .75171 m .6747 .71466 L .65365 .7082 L p .707 .577 .707 r
F P
0 g
s
.79455 .75475 m .79455 .77328 L .8186 .76763 L p .707 .577 .707 r
F P
0 g
s
.8186 .76763 m .8186 .7491 L .79455 .75475 L p .707 .577 .707 r
F P
0 g
s
.65365 .7082 m .65365 .74526 L .6747 .75171 L p .707 .577 .707 r
F P
0 g
s
.6747 .77114 m .6747 .75261 L .65365 .74616 L p .707 .577 .707 r
F P
0 g
s
.8186 .71114 m .8186 .7482 L .83497 .74083 L p .707 .577 .707 r
F P
0 g
s
.83497 .74083 m .83497 .70378 L .8186 .71114 L p .707 .577 .707 r
F P
0 g
s
.64105 .60843 m .64105 .66401 L .65365 .6719 L p .707 .577 .707 r
F P
0 g
s
.83497 .61189 m .83497 .66747 L .84205 .65911 L p .707 .577 .707 r
F P
0 g
s
.84205 .65911 m .84205 .60352 L .83497 .61189 L p .707 .577 .707 r
F P
0 g
s
.65365 .74616 m .65365 .76469 L .6747 .77114 L p .707 .577 .707 r
F P
0 g
s
.65365 .74526 m .65365 .7082 L .64105 .70032 L p .707 .577 .707 r
F P
0 g
s
.8186 .7491 m .8186 .76763 L .83497 .76026 L p .707 .577 .707 r
F P
0 g
s
.83497 .76026 m .83497 .74173 L .8186 .7491 L p .707 .577 .707 r
F P
0 g
s
.64105 .66401 m .64105 .60843 L .63816 .59989 L p .707 .577 .707 r
F P
0 g
s
.64105 .70032 m .64105 .73737 L .65365 .74526 L p .707 .577 .707 r
F P
0 g
s
.65365 .76469 m .65365 .74616 L .64105 .73828 L p .707 .577 .707 r
F P
0 g
s
.64105 .73828 m .64105 .7568 L .65365 .76469 L p .707 .577 .707 r
F P
0 g
s
.83497 .70378 m .83497 .74083 L .84206 .73247 L p .707 .577 .707 r
F P
0 g
s
.84206 .73247 m .84206 .69541 L .83497 .70378 L p .707 .577 .707 r
F P
0 g
s
.63816 .59989 m .63816 .65547 L .64105 .66401 L p .707 .577 .707 r
F P
0 g
s
.84205 .60352 m .84205 .65911 L .83916 .65056 L p .707 .577 .707 r
F P
0 g
s
.83916 .65056 m .83916 .59498 L .84205 .60352 L p .707 .577 .707 r
F P
0 g
s
.83497 .74173 m .83497 .76026 L .84206 .7519 L p .707 .577 .707 r
F P
0 g
s
.84206 .7519 m .84206 .73337 L .83497 .74173 L p .707 .577 .707 r
F P
0 g
s
.64105 .73737 m .64105 .70032 L .63816 .69178 L p .707 .577 .707 r
F P
0 g
s
.63816 .65547 m .63816 .59989 L .64524 .59152 L p .707 .577 .707 r
F P
0 g
s
.63816 .69178 m .63816 .72883 L .64105 .73737 L p .707 .577 .707 r
F P
0 g
s
.64105 .7568 m .64105 .73828 L .63816 .72973 L p .707 .577 .707 r
F P
0 g
s
.63816 .72973 m .63816 .74826 L .64105 .7568 L p .707 .577 .707 r
F P
0 g
s
.84206 .69541 m .84206 .73247 L .83916 .72392 L p .707 .577 .707 r
F P
0 g
s
.83916 .72392 m .83916 .68687 L .84206 .69541 L p .707 .577 .707 r
F P
0 g
s
.64524 .59152 m .64524 .64711 L .63816 .65547 L p .707 .577 .707 r
F P
0 g
s
.83916 .59498 m .83916 .65056 L .82657 .64268 L p .707 .577 .707 r
F P
0 g
s
.82657 .64268 m .82657 .5871 L .83916 .59498 L p .707 .577 .707 r
F P
0 g
s
.84206 .73337 m .84206 .7519 L .83916 .74335 L p .707 .577 .707 r
F P
0 g
s
.83916 .74335 m .83916 .72483 L .84206 .73337 L p .707 .577 .707 r
F P
0 g
s
.63816 .72883 m .63816 .69178 L .64524 .68341 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64783 m .39032 .59225 L .35915 .59035 L p .707 .577 .707 r
F P
0 g
s
.39032 .59225 m .39032 .64783 L .42216 .64705 L p .707 .577 .707 r
F P
0 g
s
.42216 .64705 m .42216 .59147 L .39032 .59225 L p .707 .577 .707 r
F P
0 g
s
.64524 .64711 m .64524 .59152 L .66161 .58416 L p .707 .577 .707 r
F P
0 g
s
.42216 .59147 m .42216 .64705 L .45154 .64367 L p .707 .577 .707 r
F P
0 g
s
.45154 .64367 m .45154 .58809 L .42216 .59147 L p .707 .577 .707 r
F P
0 g
s
.35915 .64593 m .35915 .59035 L .33169 .58595 L p .707 .577 .707 r
F P
0 g
s
.35915 .59035 m .35915 .64593 L .39032 .64783 L p .707 .577 .707 r
F P
0 g
s
.64524 .68341 m .64524 .72047 L .63816 .72883 L p .707 .577 .707 r
F P
0 g
s
.63816 .74826 m .63816 .72973 L .64524 .72137 L p .707 .577 .707 r
F P
0 g
s
.64524 .72137 m .64524 .7399 L .63816 .74826 L p .707 .577 .707 r
F P
0 g
s
.45154 .58809 m .45154 .64367 L .47559 .63802 L p .707 .577 .707 r
F P
0 g
s
.47559 .63802 m .47559 .58244 L .45154 .58809 L p .707 .577 .707 r
F P
0 g
s
.83916 .68687 m .83916 .72392 L .82657 .71604 L p .707 .577 .707 r
F P
0 g
s
.82657 .71604 m .82657 .67898 L .83916 .68687 L p .707 .577 .707 r
F P
0 g
s
.66161 .58416 m .66161 .63974 L .64524 .64711 L p .707 .577 .707 r
F P
0 g
s
.82657 .5871 m .82657 .64268 L .80551 .63623 L p .707 .577 .707 r
F P
0 g
s
.80551 .63623 m .80551 .58064 L .82657 .5871 L p .707 .577 .707 r
F P
0 g
s
.33169 .58595 m .33169 .64154 L .35915 .64593 L p .707 .577 .707 r
F P
0 g
s
.33169 .64154 m .33169 .58595 L .31064 .5795 L p .707 .577 .707 r
F P
0 g
s
.39032 .72119 m .39032 .68413 L .35915 .68223 L p .707 .577 .707 r
F P
0 g
s
.39032 .68413 m .39032 .72119 L .42216 .72041 L p .707 .577 .707 r
F P
0 g
s
.42216 .72041 m .42216 .68336 L .39032 .68413 L p .707 .577 .707 r
F P
0 g
s
.83916 .72483 m .83916 .74335 L .82657 .73547 L p .707 .577 .707 r
F P
0 g
s
.82657 .73547 m .82657 .71694 L .83916 .72483 L p .707 .577 .707 r
F P
0 g
s
.64524 .72047 m .64524 .68341 L .66161 .67604 L p .707 .577 .707 r
F P
0 g
s
.42216 .68336 m .42216 .72041 L .45154 .71703 L p .707 .577 .707 r
F P
0 g
s
.45154 .71703 m .45154 .67998 L .42216 .68336 L p .707 .577 .707 r
F P
0 g
s
.66161 .63974 m .66161 .58416 L .68566 .57851 L p .707 .577 .707 r
F P
0 g
s
.35915 .71929 m .35915 .68223 L .33169 .67784 L p .707 .577 .707 r
F P
0 g
s
.35915 .68223 m .35915 .71929 L .39032 .72119 L p .707 .577 .707 r
F P
0 g
s
.47559 .58244 m .47559 .63802 L .49196 .63066 L p .707 .577 .707 r
F P
0 g
s
.49196 .63066 m .49196 .57507 L .47559 .58244 L p .707 .577 .707 r
F P
0 g
s
.39032 .74062 m .39032 .72209 L .35915 .72019 L p .707 .577 .707 r
F P
0 g
s
.39032 .72209 m .39032 .74062 L .42216 .73984 L p .707 .577 .707 r
F P
0 g
s
.42216 .73984 m .42216 .72131 L .39032 .72209 L p .707 .577 .707 r
F P
0 g
s
.31064 .5795 m .31064 .63508 L .33169 .64154 L p .707 .577 .707 r
F P
0 g
s
.66161 .67604 m .66161 .7131 L .64524 .72047 L p .707 .577 .707 r
F P
0 g
s
.64524 .7399 m .64524 .72137 L .66161 .714 L p .707 .577 .707 r
F P
0 g
s
.42216 .72131 m .42216 .73984 L .45154 .73646 L p .707 .577 .707 r
F P
0 g
s
.45154 .73646 m .45154 .71794 L .42216 .72131 L p .707 .577 .707 r
F P
0 g
s
.45154 .67998 m .45154 .71703 L .47559 .71138 L p .707 .577 .707 r
F P
0 g
s
.47559 .71138 m .47559 .67433 L .45154 .67998 L p .707 .577 .707 r
F P
0 g
s
.35915 .72019 m .35915 .73872 L .39032 .74062 L p .707 .577 .707 r
F P
0 g
s
.80551 .58064 m .80551 .63623 L .77805 .63183 L p .707 .577 .707 r
F P
0 g
s
.77805 .63183 m .77805 .57625 L .80551 .58064 L p .707 .577 .707 r
F P
0 g
s
.33169 .67784 m .33169 .7149 L .35915 .71929 L p .707 .577 .707 r
F P
0 g
s
.35915 .73872 m .35915 .72019 L .33169 .7158 L p .707 .577 .707 r
F P
0 g
s
.66161 .714 m .66161 .73253 L .64524 .7399 L p .707 .577 .707 r
F P
0 g
s
.82657 .67898 m .82657 .71604 L .80551 .70959 L p .707 .577 .707 r
F P
0 g
s
.80551 .70959 m .80551 .67253 L .82657 .67898 L p .707 .577 .707 r
F P
0 g
s
.68566 .57851 m .68566 .63409 L .66161 .63974 L p .707 .577 .707 r
F P
0 g
s
.31064 .63508 m .31064 .5795 L .29804 .57162 L p .707 .577 .707 r
F P
0 g
s
.33169 .7158 m .33169 .73433 L .35915 .73872 L p .707 .577 .707 r
F P
0 g
s
.33169 .7149 m .33169 .67784 L .31064 .67139 L p .707 .577 .707 r
F P
0 g
s
.68566 .63409 m .68566 .57851 L .71504 .57513 L p .707 .577 .707 r
F P
0 g
s
.45154 .71794 m .45154 .73646 L .47559 .73081 L p .707 .577 .707 r
F P
0 g
s
.47559 .73081 m .47559 .71229 L .45154 .71794 L p .707 .577 .707 r
F P
0 g
s
.66161 .7131 m .66161 .67604 L .68566 .67039 L p .707 .577 .707 r
F P
0 g
s
.82657 .71694 m .82657 .73547 L .80551 .72902 L p .707 .577 .707 r
F P
0 g
s
.80551 .72902 m .80551 .71049 L .82657 .71694 L p .707 .577 .707 r
F P
0 g
s
.77805 .57625 m .77805 .63183 L .74688 .62993 L p .707 .577 .707 r
F P
0 g
s
.74688 .62993 m .74688 .57435 L .77805 .57625 L p .707 .577 .707 r
F P
0 g
s
.31064 .67139 m .31064 .70844 L .33169 .7149 L p .707 .577 .707 r
F P
0 g
s
.33169 .73433 m .33169 .7158 L .31064 .70934 L p .707 .577 .707 r
F P
0 g
s
.47559 .67433 m .47559 .71138 L .49196 .70401 L p .707 .577 .707 r
F P
0 g
s
.49196 .70401 m .49196 .66696 L .47559 .67433 L p .707 .577 .707 r
F P
0 g
s
.29804 .57162 m .29804 .6272 L .31064 .63508 L p .707 .577 .707 r
F P
0 g
s
.71504 .63071 m .71504 .57513 L .74688 .57435 L p .707 .577 .707 r
F P
0 g
s
.71504 .57513 m .71504 .63071 L .68566 .63409 L p .707 .577 .707 r
F P
0 g
s
.49196 .57507 m .49196 .63066 L .49904 .62229 L p .707 .577 .707 r
F P
0 g
s
.49904 .62229 m .49904 .56671 L .49196 .57507 L p .707 .577 .707 r
F P
0 g
s
.31064 .70934 m .31064 .72787 L .33169 .73433 L p .707 .577 .707 r
F P
0 g
s
.74688 .57435 m .74688 .62993 L .71504 .63071 L p .707 .577 .707 r
F P
0 g
s
.68566 .67039 m .68566 .70745 L .66161 .7131 L p .707 .577 .707 r
F P
0 g
s
.66161 .73253 m .66161 .714 L .68566 .70835 L p .707 .577 .707 r
F P
0 g
s
.80551 .67253 m .80551 .70959 L .77805 .70519 L p .707 .577 .707 r
F P
0 g
s
.77805 .70519 m .77805 .66814 L .80551 .67253 L p .707 .577 .707 r
F P
0 g
s
.68566 .70835 m .68566 .72688 L .66161 .73253 L p .707 .577 .707 r
F P
0 g
s
.31064 .70844 m .31064 .67139 L .29804 .6635 L p .707 .577 .707 r
F P
0 g
s
.47559 .71229 m .47559 .73081 L .49196 .72345 L p .707 .577 .707 r
F P
0 g
s
.49196 .72345 m .49196 .70492 L .47559 .71229 L p .707 .577 .707 r
F P
0 g
s
.29804 .6272 m .29804 .57162 L .29515 .56307 L p .707 .577 .707 r
F P
0 g
s
.68566 .70745 m .68566 .67039 L .71504 .66701 L p .707 .577 .707 r
F P
0 g
s
.80551 .71049 m .80551 .72902 L .77805 .72462 L p .707 .577 .707 r
F P
0 g
s
.77805 .72462 m .77805 .7061 L .80551 .71049 L p .707 .577 .707 r
F P
0 g
s
.29804 .6635 m .29804 .70056 L .31064 .70844 L p .707 .577 .707 r
F P
0 g
s
.31064 .72787 m .31064 .70934 L .29804 .70146 L p .707 .577 .707 r
F P
0 g
s
.77805 .66814 m .77805 .70519 L .74688 .70329 L p .707 .577 .707 r
F P
0 g
s
.74688 .70329 m .74688 .66624 L .77805 .66814 L p .707 .577 .707 r
F P
0 g
s
.71504 .66701 m .71504 .70407 L .68566 .70745 L p .707 .577 .707 r
F P
0 g
s
.68566 .72688 m .68566 .70835 L .71504 .70497 L p .707 .577 .707 r
F P
0 g
s
.71504 .70407 m .71504 .66701 L .74688 .66624 L p .707 .577 .707 r
F P
0 g
s
.29804 .70146 m .29804 .71999 L .31064 .72787 L p .707 .577 .707 r
F P
0 g
s
.49196 .66696 m .49196 .70401 L .49904 .69565 L p .707 .577 .707 r
F P
0 g
s
.49904 .69565 m .49904 .6586 L .49196 .66696 L p .707 .577 .707 r
F P
0 g
s
.29515 .56307 m .29515 .61866 L .29804 .6272 L p .707 .577 .707 r
F P
0 g
s
.74688 .66624 m .74688 .70329 L .71504 .70407 L p .707 .577 .707 r
F P
0 g
s
.71504 .70497 m .71504 .7235 L .68566 .72688 L p .707 .577 .707 r
F P
0 g
s
.49904 .56671 m .49904 .62229 L .49615 .61375 L p .707 .577 .707 r
F P
0 g
s
.49615 .61375 m .49615 .55817 L .49904 .56671 L p .707 .577 .707 r
F P
0 g
s
.77805 .7061 m .77805 .72462 L .74688 .72272 L p .707 .577 .707 r
F P
0 g
s
.74688 .72272 m .74688 .7042 L .77805 .7061 L p .707 .577 .707 r
F P
0 g
s
.71504 .7235 m .71504 .70497 L .74688 .7042 L p .707 .577 .707 r
F P
0 g
s
.49196 .70492 m .49196 .72345 L .49904 .71508 L p .707 .577 .707 r
F P
0 g
s
.49904 .71508 m .49904 .69655 L .49196 .70492 L p .707 .577 .707 r
F P
0 g
s
.29804 .70056 m .29804 .6635 L .29515 .65496 L p .707 .577 .707 r
F P
0 g
s
.74688 .7042 m .74688 .72272 L .71504 .7235 L p .707 .577 .707 r
F P
0 g
s
.29515 .61866 m .29515 .56307 L .30223 .55471 L p .707 .577 .707 r
F P
0 g
s
.29515 .65496 m .29515 .69202 L .29804 .70056 L p .707 .577 .707 r
F P
0 g
s
.29804 .71999 m .29804 .70146 L .29515 .69292 L p .707 .577 .707 r
F P
0 g
s
.29515 .69292 m .29515 .71145 L .29804 .71999 L p .707 .577 .707 r
F P
0 g
s
.49904 .6586 m .49904 .69565 L .49615 .68711 L p .707 .577 .707 r
F P
0 g
s
.49615 .68711 m .49615 .65005 L .49904 .6586 L p .707 .577 .707 r
F P
0 g
s
.30223 .55471 m .30223 .61029 L .29515 .61866 L p .707 .577 .707 r
F P
0 g
s
.49615 .55817 m .49615 .61375 L .48356 .60586 L p .707 .577 .707 r
F P
0 g
s
.48356 .60586 m .48356 .55028 L .49615 .55817 L p .707 .577 .707 r
F P
0 g
s
.49904 .69655 m .49904 .71508 L .49615 .70654 L p .707 .577 .707 r
F P
0 g
s
.49615 .70654 m .49615 .68801 L .49904 .69655 L p .707 .577 .707 r
F P
0 g
s
.29515 .69202 m .29515 .65496 L .30223 .6466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61029 m .30223 .55471 L .3186 .54734 L p .707 .577 .707 r
F P
0 g
s
.30223 .6466 m .30223 .68365 L .29515 .69202 L p .707 .577 .707 r
F P
0 g
s
.29515 .71145 m .29515 .69292 L .30223 .68455 L p .707 .577 .707 r
F P
0 g
s
.30223 .68455 m .30223 .70308 L .29515 .71145 L p .707 .577 .707 r
F P
0 g
s
.49615 .65005 m .49615 .68711 L .48356 .67922 L p .707 .577 .707 r
F P
0 g
s
.48356 .67922 m .48356 .64217 L .49615 .65005 L p .707 .577 .707 r
F P
0 g
s
.3186 .54734 m .3186 .60292 L .30223 .61029 L p .707 .577 .707 r
F P
0 g
s
.48356 .55028 m .48356 .60586 L .4625 .59941 L p .707 .577 .707 r
F P
0 g
s
.4625 .59941 m .4625 .54383 L .48356 .55028 L p .707 .577 .707 r
F P
0 g
s
.49615 .68801 m .49615 .70654 L .48356 .69865 L p .707 .577 .707 r
F P
0 g
s
.48356 .69865 m .48356 .68013 L .49615 .68801 L p .707 .577 .707 r
F P
0 g
s
.30223 .68365 m .30223 .6466 L .3186 .63923 L p .707 .577 .707 r
F P
0 g
s
.3186 .60292 m .3186 .54734 L .34265 .54169 L p .707 .577 .707 r
F P
0 g
s
.3186 .63923 m .3186 .67628 L .30223 .68365 L p .707 .577 .707 r
F P
0 g
s
.30223 .70308 m .30223 .68455 L .3186 .67719 L p .707 .577 .707 r
F P
0 g
s
.4625 .54383 m .4625 .59941 L .43504 .59502 L p .707 .577 .707 r
F P
0 g
s
.43504 .59502 m .43504 .53944 L .4625 .54383 L p .707 .577 .707 r
F P
0 g
s
.3186 .67719 m .3186 .69571 L .30223 .70308 L p .707 .577 .707 r
F P
0 g
s
.48356 .64217 m .48356 .67922 L .4625 .67277 L p .707 .577 .707 r
F P
0 g
s
.4625 .67277 m .4625 .63571 L .48356 .64217 L p .707 .577 .707 r
F P
0 g
s
.34265 .54169 m .34265 .59727 L .3186 .60292 L p .707 .577 .707 r
F P
0 g
s
.34265 .59727 m .34265 .54169 L .37203 .53831 L p .707 .577 .707 r
F P
0 g
s
.3186 .67628 m .3186 .63923 L .34265 .63358 L p .707 .577 .707 r
F P
0 g
s
.48356 .68013 m .48356 .69865 L .4625 .6922 L p .707 .577 .707 r
F P
0 g
s
.4625 .6922 m .4625 .67367 L .48356 .68013 L p .707 .577 .707 r
F P
0 g
s
.43504 .53944 m .43504 .59502 L .40387 .59312 L p .707 .577 .707 r
F P
0 g
s
.40387 .59312 m .40387 .53754 L .43504 .53944 L p .707 .577 .707 r
F P
0 g
s
.37203 .59389 m .37203 .53831 L .40387 .53754 L p .707 .577 .707 r
F P
0 g
s
.37203 .53831 m .37203 .59389 L .34265 .59727 L p .707 .577 .707 r
F P
0 g
s
.40387 .53754 m .40387 .59312 L .37203 .59389 L p .707 .577 .707 r
F P
0 g
s
.34265 .63358 m .34265 .67063 L .3186 .67628 L p .707 .577 .707 r
F P
0 g
s
.3186 .69571 m .3186 .67719 L .34265 .67154 L p .707 .577 .707 r
F P
0 g
s
.4625 .63571 m .4625 .67277 L .43504 .66838 L p .707 .577 .707 r
F P
0 g
s
.43504 .66838 m .43504 .63132 L .4625 .63571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67154 m .34265 .69006 L .3186 .69571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67063 m .34265 .63358 L .37203 .6302 L p .707 .577 .707 r
F P
0 g
s
.4625 .67367 m .4625 .6922 L .43504 .68781 L p .707 .577 .707 r
F P
0 g
s
.43504 .68781 m .43504 .66928 L .4625 .67367 L p .707 .577 .707 r
F P
0 g
s
.43504 .63132 m .43504 .66838 L .40387 .66648 L p .707 .577 .707 r
F P
0 g
s
.40387 .66648 m .40387 .62942 L .43504 .63132 L p .707 .577 .707 r
F P
0 g
s
.37203 .6302 m .37203 .66725 L .34265 .67063 L p .707 .577 .707 r
F P
0 g
s
.34265 .69006 m .34265 .67154 L .37203 .66816 L p .707 .577 .707 r
F P
0 g
s
.37203 .66725 m .37203 .6302 L .40387 .62942 L p .707 .577 .707 r
F P
0 g
s
.40387 .62942 m .40387 .66648 L .37203 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66816 m .37203 .68668 L .34265 .69006 L p .707 .577 .707 r
F P
0 g
s
.43504 .66928 m .43504 .68781 L .40387 .68591 L p .707 .577 .707 r
F P
0 g
s
.40387 .68591 m .40387 .66738 L .43504 .66928 L p .707 .577 .707 r
F P
0 g
s
.37203 .68668 m .37203 .66816 L .40387 .66738 L p .707 .577 .707 r
F P
0 g
s
.40387 .66738 m .40387 .68591 L .37203 .68668 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Ioo`00O7oo1P000UYF
00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001fOol60008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF2@0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol90004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005ioo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP@003Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH0
1UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
05=oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001J
EP04FUH00`00FUIJEP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPH000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
;7oo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03001JEP00008000AJEP04
001JEUYFFUH90007FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000=JEPH000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF
001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000UYF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000=J
EP00000020001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000H000AJEP04001J
EUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEP000003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@000UYF00<005YF00002EYF2@0025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH00UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF2@0000=JEP00
FUH00UYF00<005YF00002UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@000=JEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF2000
15YF00<005YFFUH00eYF3P001EYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF600000=JEP00FUH015YF00<005YFFUH01EYF00@005YF
FUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH20004FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00003000]Ool0031oo`<000AJEPP000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP<00003FUH005YF00=JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEPP000=J
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00004FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH40005FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000aOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF00000eYF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0000H00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001@00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH500000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP<0009JEP03001JEP0000D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF
009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF
009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00=JEP04001JEUYFFUH30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009oo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH005YFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH50003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH00`00Oomoo`02Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP02FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/
Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<007ooOol017oo0P0015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`001eYF00<0
05YFFUH015YF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/
Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool01goo0`0000=JEP00FUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000/Ool30004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP02000;Ool40008
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000030004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool90018Ool002aoo`<000AJ
EP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;7oo00<005YF
000015YF1@001eYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00
01Eoob8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2001DOol002aoo`03001JEP00009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001oogoo02Eoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP0000<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0UOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH0000200000eYF001oo`0VOol00`00FUH00004FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00001P0015YF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00<005YF00009goo00<005YF000015YF1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00E7oo000/
Ool20003FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00002FUH40004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2
001DOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YF
FUH00UYF1@001EYF00@005YFFUIJEP8002Qoo`03001JEP0000<00003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<0009JEP80
05Aoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000:Goo00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEPH005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`<000AJ
EP03001JEUYF009JEPL000QJEPD000AJEPP000=JEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00
<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;7oo00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1@0015YF
00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8005Aoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000cOol0
1000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF0`000eYF0P00E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP0200000eYF0000001DOol008ioo`D000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000D005Aoo`00SWoo0P000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
1@0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00001P000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
0UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
05Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065o
o`00YGoo4P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72231 m .59613 .66673 L .56496 .66483 L p .707 .577 .707 r
F P
0 g
s
.59613 .66673 m .59613 .72231 L .62796 .72153 L p .707 .577 .707 r
F P
0 g
s
.62796 .72153 m .62796 .66595 L .59613 .66673 L p .707 .577 .707 r
F P
0 g
s
.62796 .66595 m .62796 .72153 L .65734 .71815 L p .707 .577 .707 r
F P
0 g
s
.65734 .71815 m .65734 .66257 L .62796 .66595 L p .707 .577 .707 r
F P
0 g
s
.56496 .72041 m .56496 .66483 L .5375 .66043 L p .707 .577 .707 r
F P
0 g
s
.56496 .66483 m .56496 .72041 L .59613 .72231 L p .707 .577 .707 r
F P
0 g
s
.65734 .66257 m .65734 .71815 L .6814 .7125 L p .707 .577 .707 r
F P
0 g
s
.6814 .7125 m .6814 .65692 L .65734 .66257 L p .707 .577 .707 r
F P
0 g
s
.59613 .76967 m .59613 .73262 L .56496 .73072 L p .707 .577 .707 r
F P
0 g
s
.59613 .73262 m .59613 .76967 L .62796 .7689 L p .707 .577 .707 r
F P
0 g
s
.62796 .7689 m .62796 .73184 L .59613 .73262 L p .707 .577 .707 r
F P
0 g
s
.62796 .73184 m .62796 .7689 L .65735 .76552 L p .707 .577 .707 r
F P
0 g
s
.65735 .76552 m .65734 .72846 L .62796 .73184 L p .707 .577 .707 r
F P
0 g
s
.5375 .66043 m .5375 .71602 L .56496 .72041 L p .707 .577 .707 r
F P
0 g
s
.5375 .71602 m .5375 .66043 L .51644 .65398 L p .707 .577 .707 r
F P
0 g
s
.56496 .76777 m .56496 .73072 L .5375 .72633 L p .707 .577 .707 r
F P
0 g
s
.56496 .73072 m .56496 .76777 L .59613 .76967 L p .707 .577 .707 r
F P
0 g
s
.65734 .72846 m .65735 .76552 L .6814 .75987 L p .707 .577 .707 r
F P
0 g
s
.6814 .75987 m .6814 .72281 L .65734 .72846 L p .707 .577 .707 r
F P
0 g
s
.6814 .65692 m .6814 .7125 L .69777 .70514 L p .707 .577 .707 r
F P
0 g
s
.69777 .70514 m .69777 .64955 L .6814 .65692 L p .707 .577 .707 r
F P
0 g
s
.5375 .72633 m .5375 .76338 L .56496 .76777 L p .707 .577 .707 r
F P
0 g
s
.51644 .65398 m .51644 .70956 L .5375 .71602 L p .707 .577 .707 r
F P
0 g
s
.5375 .76338 m .5375 .72633 L .51644 .71987 L p .707 .577 .707 r
F P
0 g
s
.59613 .83391 m .59613 .81539 L .56496 .81349 L p .707 .577 .707 r
F P
0 g
s
.59613 .81539 m .59613 .83391 L .62796 .83314 L p .707 .577 .707 r
F P
0 g
s
.62796 .83314 m .62796 .81461 L .59613 .81539 L p .707 .577 .707 r
F P
0 g
s
.62796 .81461 m .62796 .83314 L .65735 .82976 L p .707 .577 .707 r
F P
0 g
s
.65735 .82976 m .65735 .81123 L .62796 .81461 L p .707 .577 .707 r
F P
0 g
s
.51644 .70956 m .51644 .65398 L .50385 .6461 L p .707 .577 .707 r
F P
0 g
s
.56496 .81349 m .56496 .83201 L .59613 .83391 L p .707 .577 .707 r
F P
0 g
s
.56496 .83201 m .56496 .81349 L .5375 .80909 L p .707 .577 .707 r
F P
0 g
s
.51644 .71987 m .51644 .75693 L .5375 .76338 L p .707 .577 .707 r
F P
0 g
s
.5375 .80909 m .5375 .82762 L .56496 .83201 L p .707 .577 .707 r
F P
0 g
s
.6814 .72281 m .6814 .75987 L .69777 .7525 L p .707 .577 .707 r
F P
0 g
s
.69777 .7525 m .69777 .71545 L .6814 .72281 L p .707 .577 .707 r
F P
0 g
s
.65735 .81123 m .65735 .82976 L .6814 .82411 L p .707 .577 .707 r
F P
0 g
s
.6814 .82411 m .6814 .80558 L .65735 .81123 L p .707 .577 .707 r
F P
0 g
s
.50385 .6461 m .50385 .70168 L .51644 .70956 L p .707 .577 .707 r
F P
0 g
s
.69777 .64955 m .69777 .70514 L .70485 .69677 L p .707 .577 .707 r
F P
0 g
s
.70485 .69677 m .70485 .64119 L .69777 .64955 L p .707 .577 .707 r
F P
0 g
s
.5375 .82762 m .5375 .80909 L .51644 .80264 L p .707 .577 .707 r
F P
0 g
s
.51644 .75693 m .51644 .71987 L .50385 .71199 L p .707 .577 .707 r
F P
0 g
s
.51644 .80264 m .51644 .82117 L .5375 .82762 L p .707 .577 .707 r
F P
0 g
s
.50385 .70168 m .50385 .6461 L .50095 .63755 L p .707 .577 .707 r
F P
0 g
s
.50385 .71199 m .50385 .74904 L .51644 .75693 L p .707 .577 .707 r
F P
0 g
s
.6814 .80558 m .6814 .82411 L .69777 .81674 L p .707 .577 .707 r
F P
0 g
s
.69777 .81674 m .69777 .79821 L .6814 .80558 L p .707 .577 .707 r
F P
0 g
s
.69777 .71545 m .69777 .7525 L .70485 .74414 L p .707 .577 .707 r
F P
0 g
s
.70485 .74414 m .70485 .70708 L .69777 .71545 L p .707 .577 .707 r
F P
0 g
s
.51644 .82117 m .51644 .80264 L .50385 .79476 L p .707 .577 .707 r
F P
0 g
s
.50095 .63755 m .50095 .69314 L .50385 .70168 L p .707 .577 .707 r
F P
0 g
s
.70485 .64119 m .70485 .69677 L .70195 .68823 L p .707 .577 .707 r
F P
0 g
s
.70195 .68823 m .70195 .63265 L .70485 .64119 L p .707 .577 .707 r
F P
0 g
s
.50385 .79476 m .50385 .81328 L .51644 .82117 L p .707 .577 .707 r
F P
0 g
s
.50385 .74904 m .50385 .71199 L .50095 .70345 L p .707 .577 .707 r
F P
0 g
s
.50095 .70345 m .50095 .7405 L .50385 .74904 L p .707 .577 .707 r
F P
0 g
s
.69777 .79821 m .69777 .81674 L .70485 .80838 L p .707 .577 .707 r
F P
0 g
s
.70485 .80838 m .70485 .78985 L .69777 .79821 L p .707 .577 .707 r
F P
0 g
s
.50095 .69314 m .50095 .63755 L .50804 .62919 L p .707 .577 .707 r
F P
0 g
s
.70485 .70708 m .70485 .74414 L .70195 .73559 L p .707 .577 .707 r
F P
0 g
s
.70195 .73559 m .70195 .69854 L .70485 .70708 L p .707 .577 .707 r
F P
0 g
s
.50385 .81328 m .50385 .79476 L .50095 .78621 L p .707 .577 .707 r
F P
0 g
s
.49044 .85617 m .49044 .35428 L .44643 .3516 L p .707 .577 .707 r
F P
0 g
s
.50804 .62919 m .50804 .68477 L .50095 .69314 L p .707 .577 .707 r
F P
0 g
s
.50095 .78621 m .50095 .80474 L .50385 .81328 L p .707 .577 .707 r
F P
0 g
s
.50095 .7405 m .50095 .70345 L .50804 .69508 L p .707 .577 .707 r
F P
0 g
s
.50804 .69508 m .50804 .73214 L .50095 .7405 L p .707 .577 .707 r
F P
0 g
s
.50804 .68477 m .50804 .62919 L .5244 .62182 L p .707 .577 .707 r
F P
0 g
s
.50095 .80474 m .50095 .78621 L .50804 .77785 L p .707 .577 .707 r
F P
0 g
s
.5244 .62182 m .5244 .6774 L .50804 .68477 L p .707 .577 .707 r
F P
0 g
s
.50804 .77785 m .50804 .79638 L .50095 .80474 L p .707 .577 .707 r
F P
0 g
s
.50804 .73214 m .50804 .69508 L .5244 .68771 L p .707 .577 .707 r
F P
0 g
s
.5244 .68771 m .5244 .72477 L .50804 .73214 L p .707 .577 .707 r
F P
0 g
s
.50804 .79638 m .50804 .77785 L .5244 .77048 L p .707 .577 .707 r
F P
0 g
s
.5244 .77048 m .5244 .78901 L .50804 .79638 L p .707 .577 .707 r
F P
0 g
s
.5244 .78901 m .5244 .77048 L .54846 .76483 L p .707 .577 .707 r
F P
0 g
s
.54846 .76483 m .54846 .78336 L .5244 .78901 L p .707 .577 .707 r
F P
0 g
s
.49044 .35428 m .49044 .85617 L .53538 .85507 L p .707 .577 .707 r
F P
0 g
s
.5244 .6774 m .5244 .62182 L .54846 .61617 L p .707 .577 .707 r
F P
0 g
s
.54846 .61617 m .54846 .67175 L .5244 .6774 L p .707 .577 .707 r
F P
0 g
s
.5244 .72477 m .5244 .68771 L .54846 .68206 L p .707 .577 .707 r
F P
0 g
s
.54846 .68206 m .54846 .71912 L .5244 .72477 L p .707 .577 .707 r
F P
0 g
s
.53538 .85507 m .53538 .35318 L .49044 .35428 L p .707 .577 .707 r
F P
0 g
s
.70195 .63265 m .70195 .68823 L .68936 .68034 L p .707 .577 .707 r
F P
0 g
s
.68936 .68034 m .68936 .62476 L .70195 .63265 L p .707 .577 .707 r
F P
0 g
s
.54846 .67175 m .54846 .61617 L .57784 .61279 L p .707 .577 .707 r
F P
0 g
s
.57784 .61279 m .57784 .66838 L .54846 .67175 L p .707 .577 .707 r
F P
0 g
s
.54846 .71912 m .54846 .68206 L .57784 .67869 L p .707 .577 .707 r
F P
0 g
s
.57784 .67869 m .57784 .71574 L .54846 .71912 L p .707 .577 .707 r
F P
0 g
s
.54846 .78336 m .54846 .76483 L .57784 .76145 L p .707 .577 .707 r
F P
0 g
s
.57784 .76145 m .57784 .77998 L .54846 .78336 L p .707 .577 .707 r
F P
0 g
s
.53538 .35318 m .53538 .85507 L .57686 .8503 L p .707 .577 .707 r
F P
0 g
s
.57686 .8503 m .57686 .34841 L .53538 .35318 L p .707 .577 .707 r
F P
0 g
s
.44643 .85349 m .44643 .3516 L .40766 .3454 L p .707 .577 .707 r
F P
0 g
s
.44643 .3516 m .44643 .85349 L .49044 .85617 L p .707 .577 .707 r
F P
0 g
s
.25312 .68549 m .25312 .62991 L .22195 .62801 L p .707 .577 .707 r
F P
0 g
s
.25312 .62991 m .25312 .68549 L .28495 .68472 L p .707 .577 .707 r
F P
0 g
s
.28495 .68472 m .28495 .62913 L .25312 .62991 L p .707 .577 .707 r
F P
0 g
s
.70485 .78985 m .70485 .80838 L .70195 .79983 L p .707 .577 .707 r
F P
0 g
s
.70195 .79983 m .70195 .78131 L .70485 .78985 L p .707 .577 .707 r
F P
0 g
s
.28495 .62913 m .28495 .68472 L .31434 .68134 L p .707 .577 .707 r
F P
0 g
s
.31434 .68134 m .31434 .62576 L .28495 .62913 L p .707 .577 .707 r
F P
0 g
s
.22195 .68359 m .22195 .62801 L .19449 .62362 L p .707 .577 .707 r
F P
0 g
s
.22195 .62801 m .22195 .68359 L .25312 .68549 L p .707 .577 .707 r
F P
0 g
s
.57784 .66838 m .57784 .61279 L .60968 .61202 L p .707 .577 .707 r
F P
0 g
s
.60968 .61202 m .60968 .6676 L .57784 .66838 L p .707 .577 .707 r
F P
0 g
s
.57784 .71574 m .57784 .67869 L .60968 .67791 L p .707 .577 .707 r
F P
0 g
s
.60968 .67791 m .60968 .71496 L .57784 .71574 L p .707 .577 .707 r
F P
0 g
s
.57784 .77998 m .57784 .76145 L .60968 .76067 L p .707 .577 .707 r
F P
0 g
s
.60968 .76067 m .60968 .7792 L .57784 .77998 L p .707 .577 .707 r
F P
0 g
s
.57686 .34841 m .57686 .8503 L .61082 .84233 L p .707 .577 .707 r
F P
0 g
s
.64085 .61392 m .64085 .6695 L .60968 .6676 L p .707 .577 .707 r
F P
0 g
s
.60968 .6676 m .60968 .61202 L .64085 .61392 L p .707 .577 .707 r
F P
0 g
s
.64085 .67981 m .64085 .71686 L .60968 .71496 L p .707 .577 .707 r
F P
0 g
s
.60968 .71496 m .60968 .67791 L .64085 .67981 L p .707 .577 .707 r
F P
0 g
s
.64085 .76258 m .64085 .7811 L .60968 .7792 L p .707 .577 .707 r
F P
0 g
s
.60968 .7792 m .60968 .76067 L .64085 .76258 L p .707 .577 .707 r
F P
0 g
s
.61082 .84233 m .61082 .34044 L .57686 .34841 L p .707 .577 .707 r
F P
0 g
s
.70195 .69854 m .70195 .73559 L .68936 .72771 L p .707 .577 .707 r
F P
0 g
s
.68936 .72771 m .68936 .69066 L .70195 .69854 L p .707 .577 .707 r
F P
0 g
s
.31434 .62576 m .31434 .68134 L .33839 .67569 L p .707 .577 .707 r
F P
0 g
s
.33839 .67569 m .33839 .62011 L .31434 .62576 L p .707 .577 .707 r
F P
0 g
s
.25312 .73286 m .25312 .6958 L .22195 .6939 L p .707 .577 .707 r
F P
0 g
s
.25312 .6958 m .25312 .73286 L .28495 .73208 L p .707 .577 .707 r
F P
0 g
s
.28495 .73208 m .28495 .69503 L .25312 .6958 L p .707 .577 .707 r
F P
0 g
s
.40766 .84729 m .40766 .3454 L .37794 .33629 L p .707 .577 .707 r
F P
0 g
s
.40766 .3454 m .40766 .84729 L .44643 .85349 L p .707 .577 .707 r
F P
0 g
s
.68936 .62476 m .68936 .68034 L .66831 .67389 L p .707 .577 .707 r
F P
0 g
s
.66831 .67389 m .66831 .61831 L .68936 .62476 L p .707 .577 .707 r
F P
0 g
s
.28495 .69503 m .28495 .73208 L .31434 .7287 L p .707 .577 .707 r
F P
0 g
s
.31434 .7287 m .31434 .69165 L .28495 .69503 L p .707 .577 .707 r
F P
0 g
s
.19449 .62362 m .19449 .6792 L .22195 .68359 L p .707 .577 .707 r
F P
0 g
s
.19449 .6792 m .19449 .62362 L .17343 .61716 L p .707 .577 .707 r
F P
0 g
s
.22195 .73096 m .22195 .6939 L .19449 .68951 L p .707 .577 .707 r
F P
0 g
s
.22195 .6939 m .22195 .73096 L .25312 .73286 L p .707 .577 .707 r
F P
0 g
s
.70195 .78131 m .70195 .79983 L .68936 .79195 L p .707 .577 .707 r
F P
0 g
s
.68936 .79195 m .68936 .77342 L .70195 .78131 L p .707 .577 .707 r
F P
0 g
s
.31434 .69165 m .31434 .7287 L .33839 .72305 L p .707 .577 .707 r
F P
0 g
s
.33839 .72305 m .33839 .686 L .31434 .69165 L p .707 .577 .707 r
F P
0 g
s
.33839 .62011 m .33839 .67569 L .35476 .66832 L p .707 .577 .707 r
F P
0 g
s
.35476 .66832 m .35476 .61274 L .33839 .62011 L p .707 .577 .707 r
F P
0 g
s
.19449 .68951 m .19449 .72657 L .22195 .73096 L p .707 .577 .707 r
F P
0 g
s
.61082 .34044 m .61082 .84233 L .63393 .83192 L p .707 .577 .707 r
F P
0 g
s
.63393 .83192 m .63393 .33004 L .61082 .34044 L p .707 .577 .707 r
F P
0 g
s
.68936 .69066 m .68936 .72771 L .66831 .72126 L p .707 .577 .707 r
F P
0 g
s
.66831 .72126 m .66831 .6842 L .68936 .69066 L p .707 .577 .707 r
F P
0 g
s
.17343 .61716 m .17343 .67275 L .19449 .6792 L p .707 .577 .707 r
F P
0 g
s
.19449 .72657 m .19449 .68951 L .17343 .68306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7971 m .25312 .77857 L .22195 .77667 L p .707 .577 .707 r
F P
0 g
s
.25312 .77857 m .25312 .7971 L .28495 .79632 L p .707 .577 .707 r
F P
0 g
s
.28495 .79632 m .28495 .77779 L .25312 .77857 L p .707 .577 .707 r
F P
0 g
s
.66831 .61831 m .66831 .67389 L .64085 .6695 L p .707 .577 .707 r
F P
0 g
s
.64085 .6695 m .64085 .61392 L .66831 .61831 L p .707 .577 .707 r
F P
0 g
s
.28495 .77779 m .28495 .79632 L .31434 .79294 L p .707 .577 .707 r
F P
0 g
s
.31434 .79294 m .31434 .77441 L .28495 .77779 L p .707 .577 .707 r
F P
0 g
s
.17343 .67275 m .17343 .61716 L .16084 .60928 L p .707 .577 .707 r
F P
0 g
s
.22195 .77667 m .22195 .7952 L .25312 .7971 L p .707 .577 .707 r
F P
0 g
s
.22195 .7952 m .22195 .77667 L .19449 .77228 L p .707 .577 .707 r
F P
0 g
s
.37794 .83817 m .37794 .33629 L .36016 .32515 L p .707 .577 .707 r
F P
0 g
s
.37794 .33629 m .37794 .83817 L .40766 .84729 L p .707 .577 .707 r
F P
0 g
s
.17343 .68306 m .17343 .72011 L .19449 .72657 L p .707 .577 .707 r
F P
0 g
s
.19449 .77228 m .19449 .79081 L .22195 .7952 L p .707 .577 .707 r
F P
0 g
s
.33839 .686 m .33839 .72305 L .35476 .71569 L p .707 .577 .707 r
F P
0 g
s
.35476 .71569 m .35476 .67863 L .33839 .686 L p .707 .577 .707 r
F P
0 g
s
.31434 .77441 m .31434 .79294 L .33839 .78729 L p .707 .577 .707 r
F P
0 g
s
.33839 .78729 m .33839 .76876 L .31434 .77441 L p .707 .577 .707 r
F P
0 g
s
.68936 .77342 m .68936 .79195 L .66831 .7855 L p .707 .577 .707 r
F P
0 g
s
.66831 .7855 m .66831 .76697 L .68936 .77342 L p .707 .577 .707 r
F P
0 g
s
.66831 .6842 m .66831 .72126 L .64085 .71686 L p .707 .577 .707 r
F P
0 g
s
.64085 .71686 m .64085 .67981 L .66831 .6842 L p .707 .577 .707 r
F P
0 g
s
.16084 .60928 m .16084 .66486 L .17343 .67275 L p .707 .577 .707 r
F P
0 g
s
.35476 .61274 m .35476 .66832 L .36184 .65996 L p .707 .577 .707 r
F P
0 g
s
.36184 .65996 m .36184 .60437 L .35476 .61274 L p .707 .577 .707 r
F P
0 g
s
.19449 .79081 m .19449 .77228 L .17343 .76582 L p .707 .577 .707 r
F P
0 g
s
.17343 .72011 m .17343 .68306 L .16084 .67517 L p .707 .577 .707 r
F P
0 g
s
.17343 .76582 m .17343 .78435 L .19449 .79081 L p .707 .577 .707 r
F P
0 g
s
.66831 .76697 m .66831 .7855 L .64085 .7811 L p .707 .577 .707 r
F P
0 g
s
.64085 .7811 m .64085 .76258 L .66831 .76697 L p .707 .577 .707 r
F P
0 g
s
.63393 .33004 m .63393 .83192 L .64393 .82012 L p .707 .577 .707 r
F P
0 g
s
.64393 .82012 m .64393 .31823 L .63393 .33004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66486 m .16084 .60928 L .15794 .60074 L p .707 .577 .707 r
F P
0 g
s
.16084 .67517 m .16084 .71223 L .17343 .72011 L p .707 .577 .707 r
F P
0 g
s
.33839 .76876 m .33839 .78729 L .35476 .77992 L p .707 .577 .707 r
F P
0 g
s
.35476 .77992 m .35476 .7614 L .33839 .76876 L p .707 .577 .707 r
F P
0 g
s
.35476 .67863 m .35476 .71569 L .36184 .70732 L p .707 .577 .707 r
F P
0 g
s
.36184 .70732 m .36184 .67027 L .35476 .67863 L p .707 .577 .707 r
F P
0 g
s
.17343 .78435 m .17343 .76582 L .16084 .75794 L p .707 .577 .707 r
F P
0 g
s
.15794 .60074 m .15794 .65632 L .16084 .66486 L p .707 .577 .707 r
F P
0 g
s
.36184 .60437 m .36184 .65996 L .35894 .65141 L p .707 .577 .707 r
F P
0 g
s
.35894 .65141 m .35894 .59583 L .36184 .60437 L p .707 .577 .707 r
F P
0 g
s
.35476 .7614 m .35476 .77992 L .36184 .77156 L p .707 .577 .707 r
F P
0 g
s
.36184 .77156 m .36184 .75303 L .35476 .7614 L p .707 .577 .707 r
F P
0 g
s
.36184 .67027 m .36184 .70732 L .35894 .69878 L p .707 .577 .707 r
F P
0 g
s
.35894 .69878 m .35894 .66172 L .36184 .67027 L p .707 .577 .707 r
F P
0 g
s
.35894 .59583 m .35894 .65141 L .34635 .64353 L p .707 .577 .707 r
F P
0 g
s
.34635 .64353 m .34635 .58795 L .35894 .59583 L p .707 .577 .707 r
F P
0 g
s
.36184 .75303 m .36184 .77156 L .35894 .76302 L p .707 .577 .707 r
F P
0 g
s
.35894 .76302 m .35894 .74449 L .36184 .75303 L p .707 .577 .707 r
F P
0 g
s
.35894 .66172 m .35894 .69878 L .34635 .69089 L p .707 .577 .707 r
F P
0 g
s
.34635 .69089 m .34635 .65384 L .35894 .66172 L p .707 .577 .707 r
F P
0 g
s
.36016 .82704 m .36016 .32515 L .35607 .31309 L p .707 .577 .707 r
F P
0 g
s
.36016 .32515 m .36016 .82704 L .37794 .83817 L p .707 .577 .707 r
F P
0 g
s
.16084 .75794 m .16084 .77647 L .17343 .78435 L p .707 .577 .707 r
F P
0 g
s
.16084 .71223 m .16084 .67517 L .15794 .66663 L p .707 .577 .707 r
F P
0 g
s
.15794 .66663 m .15794 .70369 L .16084 .71223 L p .707 .577 .707 r
F P
0 g
s
.15794 .65632 m .15794 .60074 L .16503 .59237 L p .707 .577 .707 r
F P
0 g
s
.16084 .77647 m .16084 .75794 L .15794 .7494 L p .707 .577 .707 r
F P
0 g
s
.64393 .31823 m .64393 .82012 L .63984 .80806 L p .707 .577 .707 r
F P
0 g
s
.63984 .80806 m .63984 .30617 L .64393 .31823 L p .707 .577 .707 r
F P
0 g
s
.16503 .59237 m .16503 .64796 L .15794 .65632 L p .707 .577 .707 r
F P
0 g
s
.15794 .7494 m .15794 .76793 L .16084 .77647 L p .707 .577 .707 r
F P
0 g
s
.15794 .70369 m .15794 .66663 L .16503 .65827 L p .707 .577 .707 r
F P
0 g
s
.16503 .65827 m .16503 .69532 L .15794 .70369 L p .707 .577 .707 r
F P
0 g
s
.35894 .74449 m .35894 .76302 L .34635 .75513 L p .707 .577 .707 r
F P
0 g
s
.34635 .75513 m .34635 .73661 L .35894 .74449 L p .707 .577 .707 r
F P
0 g
s
.35607 .31309 m .35607 .81498 L .36016 .82704 L p .707 .577 .707 r
F P
0 g
s
.35607 .81498 m .35607 .31309 L .36607 .30129 L p .707 .577 .707 r
F P
0 g
s
.16503 .64796 m .16503 .59237 L .1814 .58501 L p .707 .577 .707 r
F P
0 g
s
.15794 .76793 m .15794 .7494 L .16503 .74103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58501 m .1814 .64059 L .16503 .64796 L p .707 .577 .707 r
F P
0 g
s
.34635 .58795 m .34635 .64353 L .3253 .63708 L p .707 .577 .707 r
F P
0 g
s
.3253 .63708 m .3253 .58149 L .34635 .58795 L p .707 .577 .707 r
F P
0 g
s
.16503 .74103 m .16503 .75956 L .15794 .76793 L p .707 .577 .707 r
F P
0 g
s
.16503 .69532 m .16503 .65827 L .1814 .6509 L p .707 .577 .707 r
F P
0 g
s
.63984 .30617 m .63984 .80806 L .62206 .79693 L p .707 .577 .707 r
F P
0 g
s
.62206 .79693 m .62206 .29504 L .63984 .30617 L p .707 .577 .707 r
F P
0 g
s
.1814 .64059 m .1814 .58501 L .20545 .57936 L p .707 .577 .707 r
F P
0 g
s
.1814 .6509 m .1814 .68795 L .16503 .69532 L p .707 .577 .707 r
F P
0 g
s
.34635 .65384 m .34635 .69089 L .3253 .68444 L p .707 .577 .707 r
F P
0 g
s
.3253 .68444 m .3253 .64739 L .34635 .65384 L p .707 .577 .707 r
F P
0 g
s
.3253 .58149 m .3253 .63708 L .29784 .63268 L p .707 .577 .707 r
F P
0 g
s
.29784 .63268 m .29784 .5771 L .3253 .58149 L p .707 .577 .707 r
F P
0 g
s
.16503 .75956 m .16503 .74103 L .1814 .73367 L p .707 .577 .707 r
F P
0 g
s
.20545 .57936 m .20545 .63494 L .1814 .64059 L p .707 .577 .707 r
F P
0 g
s
.36607 .80318 m .36607 .30129 L .38918 .29088 L p .707 .577 .707 r
F P
0 g
s
.36607 .30129 m .36607 .80318 L .35607 .81498 L p .707 .577 .707 r
F P
0 g
s
.1814 .68795 m .1814 .6509 L .20545 .64525 L p .707 .577 .707 r
F P
0 g
s
.1814 .73367 m .1814 .75219 L .16503 .75956 L p .707 .577 .707 r
F P
0 g
s
.20545 .63494 m .20545 .57936 L .23483 .57598 L p .707 .577 .707 r
F P
0 g
s
.29784 .5771 m .29784 .63268 L .26667 .63078 L p .707 .577 .707 r
F P
0 g
s
.26667 .63078 m .26667 .5752 L .29784 .5771 L p .707 .577 .707 r
F P
0 g
s
.20545 .64525 m .20545 .6823 L .1814 .68795 L p .707 .577 .707 r
F P
0 g
s
.34635 .73661 m .34635 .75513 L .3253 .74868 L p .707 .577 .707 r
F P
0 g
s
.3253 .74868 m .3253 .73015 L .34635 .73661 L p .707 .577 .707 r
F P
0 g
s
.3253 .64739 m .3253 .68444 L .29784 .68005 L p .707 .577 .707 r
F P
0 g
s
.29784 .68005 m .29784 .64299 L .3253 .64739 L p .707 .577 .707 r
F P
0 g
s
.23483 .63156 m .23483 .57598 L .26667 .5752 L p .707 .577 .707 r
F P
0 g
s
.23483 .57598 m .23483 .63156 L .20545 .63494 L p .707 .577 .707 r
F P
0 g
s
.26667 .5752 m .26667 .63078 L .23483 .63156 L p .707 .577 .707 r
F P
0 g
s
.73333 .63027 m .73333 .57469 L .70216 .57279 L p .707 .577 .707 r
F P
0 g
s
.73333 .57469 m .73333 .63027 L .76517 .62949 L p .707 .577 .707 r
F P
0 g
s
.76517 .62949 m .76517 .57391 L .73333 .57469 L p .707 .577 .707 r
F P
0 g
s
.62206 .29504 m .62206 .79693 L .59233 .78781 L p .707 .577 .707 r
F P
0 g
s
.59233 .78781 m .59233 .28592 L .62206 .29504 L p .707 .577 .707 r
F P
0 g
s
.20545 .6823 m .20545 .64525 L .23483 .64187 L p .707 .577 .707 r
F P
0 g
s
.76517 .57391 m .76517 .62949 L .79455 .62611 L p .707 .577 .707 r
F P
0 g
s
.79455 .62611 m .79455 .57053 L .76517 .57391 L p .707 .577 .707 r
F P
0 g
s
.1814 .75219 m .1814 .73367 L .20545 .72802 L p .707 .577 .707 r
F P
0 g
s
.70216 .62837 m .70216 .57279 L .6747 .5684 L p .707 .577 .707 r
F P
0 g
s
.70216 .57279 m .70216 .62837 L .73333 .63027 L p .707 .577 .707 r
F P
0 g
s
.20545 .72802 m .20545 .74654 L .1814 .75219 L p .707 .577 .707 r
F P
0 g
s
.29784 .64299 m .29784 .68005 L .26667 .67815 L p .707 .577 .707 r
F P
0 g
s
.26667 .67815 m .26667 .64109 L .29784 .64299 L p .707 .577 .707 r
F P
0 g
s
.23483 .64187 m .23483 .67893 L .20545 .6823 L p .707 .577 .707 r
F P
0 g
s
.23483 .67893 m .23483 .64187 L .26667 .64109 L p .707 .577 .707 r
F P
0 g
s
.79455 .57053 m .79455 .62611 L .8186 .62046 L p .707 .577 .707 r
F P
0 g
s
.8186 .62046 m .8186 .56488 L .79455 .57053 L p .707 .577 .707 r
F P
0 g
s
.38918 .29088 m .38918 .79277 L .36607 .80318 L p .707 .577 .707 r
F P
0 g
s
.38918 .79277 m .38918 .29088 L .42314 .28291 L p .707 .577 .707 r
F P
0 g
s
.26667 .64109 m .26667 .67815 L .23483 .67893 L p .707 .577 .707 r
F P
0 g
s
.3253 .73015 m .3253 .74868 L .29784 .74429 L p .707 .577 .707 r
F P
0 g
s
.29784 .74429 m .29784 .72576 L .3253 .73015 L p .707 .577 .707 r
F P
0 g
s
.73333 .67764 m .73333 .64058 L .70216 .63868 L p .707 .577 .707 r
F P
0 g
s
.73333 .64058 m .73333 .67764 L .76517 .67686 L p .707 .577 .707 r
F P
0 g
s
.76517 .67686 m .76517 .6398 L .73333 .64058 L p .707 .577 .707 r
F P
0 g
s
.76517 .6398 m .76517 .67686 L .79455 .67348 L p .707 .577 .707 r
F P
0 g
s
.79455 .67348 m .79455 .63643 L .76517 .6398 L p .707 .577 .707 r
F P
0 g
s
.6747 .5684 m .6747 .62398 L .70216 .62837 L p .707 .577 .707 r
F P
0 g
s
.6747 .62398 m .6747 .5684 L .65365 .56194 L p .707 .577 .707 r
F P
0 g
s
.20545 .74654 m .20545 .72802 L .23483 .72464 L p .707 .577 .707 r
F P
0 g
s
.70216 .67574 m .70216 .63868 L .6747 .63429 L p .707 .577 .707 r
F P
0 g
s
.70216 .63868 m .70216 .67574 L .73333 .67764 L p .707 .577 .707 r
F P
0 g
s
.23483 .72464 m .23483 .74316 L .20545 .74654 L p .707 .577 .707 r
F P
0 g
s
.29784 .72576 m .29784 .74429 L .26667 .74239 L p .707 .577 .707 r
F P
0 g
s
.26667 .74239 m .26667 .72386 L .29784 .72576 L p .707 .577 .707 r
F P
0 g
s
.79455 .63643 m .79455 .67348 L .8186 .66783 L p .707 .577 .707 r
F P
0 g
s
.8186 .66783 m .8186 .63078 L .79455 .63643 L p .707 .577 .707 r
F P
0 g
s
.59233 .28592 m .59233 .78781 L .55357 .78161 L p .707 .577 .707 r
F P
0 g
s
.55357 .78161 m .55357 .27972 L .59233 .28592 L p .707 .577 .707 r
F P
0 g
s
.8186 .56488 m .8186 .62046 L .83497 .6131 L p .707 .577 .707 r
F P
0 g
s
.83497 .6131 m .83497 .55751 L .8186 .56488 L p .707 .577 .707 r
F P
0 g
s
.6747 .63429 m .6747 .67134 L .70216 .67574 L p .707 .577 .707 r
F P
0 g
s
.23483 .74316 m .23483 .72464 L .26667 .72386 L p .707 .577 .707 r
F P
0 g
s
.65365 .56194 m .65365 .61752 L .6747 .62398 L p .707 .577 .707 r
F P
0 g
s
.26667 .72386 m .26667 .74239 L .23483 .74316 L p .707 .577 .707 r
F P
0 g
s
.6747 .67134 m .6747 .63429 L .65365 .62783 L p .707 .577 .707 r
F P
0 g
s
.73333 .74188 m .73333 .72335 L .70216 .72145 L p .707 .577 .707 r
F P
0 g
s
.73333 .72335 m .73333 .74188 L .76517 .7411 L p .707 .577 .707 r
F P
0 g
s
.76517 .7411 m .76517 .72257 L .73333 .72335 L p .707 .577 .707 r
F P
0 g
s
.76517 .72257 m .76517 .7411 L .79455 .73772 L p .707 .577 .707 r
F P
0 g
s
.79455 .73772 m .79455 .71919 L .76517 .72257 L p .707 .577 .707 r
F P
0 g
s
.42314 .7848 m .42314 .28291 L .46462 .27814 L p .707 .577 .707 r
F P
0 g
s
.42314 .28291 m .42314 .7848 L .38918 .79277 L p .707 .577 .707 r
F P
0 g
s
.65365 .61752 m .65365 .56194 L .64105 .55406 L p .707 .577 .707 r
F P
0 g
s
.70216 .72145 m .70216 .73997 L .73333 .74188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73997 m .70216 .72145 L .6747 .71705 L p .707 .577 .707 r
F P
0 g
s
.65365 .62783 m .65365 .66489 L .6747 .67134 L p .707 .577 .707 r
F P
0 g
s
.6747 .71705 m .6747 .73558 L .70216 .73997 L p .707 .577 .707 r
F P
0 g
s
.8186 .63078 m .8186 .66783 L .83497 .66046 L p .707 .577 .707 r
F P
0 g
s
.83497 .66046 m .83497 .62341 L .8186 .63078 L p .707 .577 .707 r
F P
0 g
s
.55357 .27972 m .55357 .78161 L .50956 .77893 L p .707 .577 .707 r
F P
0 g
s
.50956 .77893 m .50956 .27704 L .55357 .27972 L p .707 .577 .707 r
F P
0 g
s
.79455 .71919 m .79455 .73772 L .8186 .73207 L p .707 .577 .707 r
F P
0 g
s
.8186 .73207 m .8186 .71354 L .79455 .71919 L p .707 .577 .707 r
F P
0 g
s
.64105 .55406 m .64105 .60964 L .65365 .61752 L p .707 .577 .707 r
F P
0 g
s
.46462 .78003 m .46462 .27814 L .50956 .27704 L p .707 .577 .707 r
F P
0 g
s
.46462 .27814 m .46462 .78003 L .42314 .7848 L p .707 .577 .707 r
F P
0 g
s
.83497 .55751 m .83497 .6131 L .84205 .60473 L p .707 .577 .707 r
F P
0 g
s
.84205 .60473 m .84205 .54915 L .83497 .55751 L p .707 .577 .707 r
F P
0 g
s
.6747 .73558 m .6747 .71705 L .65365 .7106 L p .707 .577 .707 r
F P
0 g
s
.65365 .66489 m .65365 .62783 L .64105 .61995 L p .707 .577 .707 r
F P
0 g
s
.50956 .27704 m .50956 .77893 L .46462 .78003 L p .707 .577 .707 r
F P
0 g
s
.65365 .7106 m .65365 .72913 L .6747 .73558 L p .707 .577 .707 r
F P
0 g
s
.64105 .60964 m .64105 .55406 L .63816 .54551 L p .707 .577 .707 r
F P
0 g
s
.64105 .61995 m .64105 .65701 L .65365 .66489 L p .707 .577 .707 r
F P
0 g
s
.8186 .71354 m .8186 .73207 L .83497 .7247 L p .707 .577 .707 r
F P
0 g
s
.83497 .7247 m .83497 .70617 L .8186 .71354 L p .707 .577 .707 r
F P
0 g
s
.83497 .62341 m .83497 .66046 L .84205 .6521 L p .707 .577 .707 r
F P
0 g
s
.84205 .6521 m .84205 .61504 L .83497 .62341 L p .707 .577 .707 r
F P
0 g
s
.65365 .72913 m .65365 .7106 L .64105 .70272 L p .707 .577 .707 r
F P
0 g
s
.63816 .54551 m .63816 .6011 L .64105 .60964 L p .707 .577 .707 r
F P
0 g
s
.84205 .54915 m .84205 .60473 L .83916 .59619 L p .707 .577 .707 r
F P
0 g
s
.83916 .59619 m .83916 .54061 L .84205 .54915 L p .707 .577 .707 r
F P
0 g
s
.64105 .70272 m .64105 .72124 L .65365 .72913 L p .707 .577 .707 r
F P
0 g
s
.64105 .65701 m .64105 .61995 L .63816 .61141 L p .707 .577 .707 r
F P
0 g
s
.63816 .61141 m .63816 .64846 L .64105 .65701 L p .707 .577 .707 r
F P
0 g
s
.83497 .70617 m .83497 .7247 L .84206 .71634 L p .707 .577 .707 r
F P
0 g
s
.84206 .71634 m .84206 .69781 L .83497 .70617 L p .707 .577 .707 r
F P
0 g
s
.63816 .6011 m .63816 .54551 L .64524 .53715 L p .707 .577 .707 r
F P
0 g
s
.84205 .61504 m .84205 .6521 L .83916 .64356 L p .707 .577 .707 r
F P
0 g
s
.83916 .64356 m .83916 .6065 L .84205 .61504 L p .707 .577 .707 r
F P
0 g
s
.64105 .72124 m .64105 .70272 L .63816 .69417 L p .707 .577 .707 r
F P
0 g
s
.64524 .53715 m .64524 .59273 L .63816 .6011 L p .707 .577 .707 r
F P
0 g
s
.63816 .69417 m .63816 .7127 L .64105 .72124 L p .707 .577 .707 r
F P
0 g
s
.83916 .54061 m .83916 .59619 L .82657 .58831 L p .707 .577 .707 r
F P
0 g
s
.82657 .58831 m .82657 .53272 L .83916 .54061 L p .707 .577 .707 r
F P
0 g
s
.63816 .64846 m .63816 .61141 L .64524 .60304 L p .707 .577 .707 r
F P
0 g
s
.39032 .59345 m .39032 .53787 L .35915 .53597 L p .707 .577 .707 r
F P
0 g
s
.39032 .53787 m .39032 .59345 L .42216 .59268 L p .707 .577 .707 r
F P
0 g
s
.42216 .59268 m .42216 .5371 L .39032 .53787 L p .707 .577 .707 r
F P
0 g
s
.84206 .69781 m .84206 .71634 L .83916 .7078 L p .707 .577 .707 r
F P
0 g
s
.83916 .7078 m .83916 .68927 L .84206 .69781 L p .707 .577 .707 r
F P
0 g
s
.64524 .60304 m .64524 .6401 L .63816 .64846 L p .707 .577 .707 r
F P
0 g
s
.64524 .59273 m .64524 .53715 L .66161 .52978 L p .707 .577 .707 r
F P
0 g
s
.42216 .5371 m .42216 .59268 L .45154 .5893 L p .707 .577 .707 r
F P
0 g
s
.45154 .5893 m .45154 .53372 L .42216 .5371 L p .707 .577 .707 r
F P
0 g
s
.35915 .59155 m .35915 .53597 L .33169 .53158 L p .707 .577 .707 r
F P
0 g
s
.35915 .53597 m .35915 .59155 L .39032 .59345 L p .707 .577 .707 r
F P
0 g
s
.83916 .6065 m .83916 .64356 L .82657 .63567 L p .707 .577 .707 r
F P
0 g
s
.82657 .63567 m .82657 .59862 L .83916 .6065 L p .707 .577 .707 r
F P
0 g
s
.63816 .7127 m .63816 .69417 L .64524 .68581 L p .707 .577 .707 r
F P
0 g
s
.45154 .53372 m .45154 .5893 L .47559 .58365 L p .707 .577 .707 r
F P
0 g
s
.47559 .58365 m .47559 .52807 L .45154 .53372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52978 m .66161 .58537 L .64524 .59273 L p .707 .577 .707 r
F P
0 g
s
.39032 .64082 m .39032 .60377 L .35915 .60187 L p .707 .577 .707 r
F P
0 g
s
.39032 .60377 m .39032 .64082 L .42216 .64004 L p .707 .577 .707 r
F P
0 g
s
.42216 .64004 m .42216 .60299 L .39032 .60377 L p .707 .577 .707 r
F P
0 g
s
.82657 .53272 m .82657 .58831 L .80551 .58185 L p .707 .577 .707 r
F P
0 g
s
.80551 .58185 m .80551 .52627 L .82657 .53272 L p .707 .577 .707 r
F P
0 g
s
.64524 .68581 m .64524 .70434 L .63816 .7127 L p .707 .577 .707 r
F P
0 g
s
.64524 .6401 m .64524 .60304 L .66161 .59568 L p .707 .577 .707 r
F P
0 g
s
.42216 .60299 m .42216 .64004 L .45154 .63666 L p .707 .577 .707 r
F P
0 g
s
.45154 .63666 m .45154 .59961 L .42216 .60299 L p .707 .577 .707 r
F P
0 g
s
.33169 .53158 m .33169 .58716 L .35915 .59155 L p .707 .577 .707 r
F P
0 g
s
.33169 .58716 m .33169 .53158 L .31064 .52513 L p .707 .577 .707 r
F P
0 g
s
.35915 .63892 m .35915 .60187 L .33169 .59747 L p .707 .577 .707 r
F P
0 g
s
.35915 .60187 m .35915 .63892 L .39032 .64082 L p .707 .577 .707 r
F P
0 g
s
.66161 .58537 m .66161 .52978 L .68566 .52413 L p .707 .577 .707 r
F P
0 g
s
.66161 .59568 m .66161 .63273 L .64524 .6401 L p .707 .577 .707 r
F P
0 g
s
.83916 .68927 m .83916 .7078 L .82657 .69991 L p .707 .577 .707 r
F P
0 g
s
.82657 .69991 m .82657 .68138 L .83916 .68927 L p .707 .577 .707 r
F P
0 g
s
.45154 .59961 m .45154 .63666 L .47559 .63101 L p .707 .577 .707 r
F P
0 g
s
.47559 .63101 m .47559 .59396 L .45154 .59961 L p .707 .577 .707 r
F P
0 g
s
.47559 .52807 m .47559 .58365 L .49196 .57628 L p .707 .577 .707 r
F P
0 g
s
.49196 .57628 m .49196 .5207 L .47559 .52807 L p .707 .577 .707 r
F P
0 g
s
.33169 .59747 m .33169 .63453 L .35915 .63892 L p .707 .577 .707 r
F P
0 g
s
.82657 .59862 m .82657 .63567 L .80551 .62922 L p .707 .577 .707 r
F P
0 g
s
.80551 .62922 m .80551 .59216 L .82657 .59862 L p .707 .577 .707 r
F P
0 g
s
.31064 .52513 m .31064 .58071 L .33169 .58716 L p .707 .577 .707 r
F P
0 g
s
.33169 .63453 m .33169 .59747 L .31064 .59102 L p .707 .577 .707 r
F P
0 g
s
.39032 .70506 m .39032 .68653 L .35915 .68463 L p .707 .577 .707 r
F P
0 g
s
.39032 .68653 m .39032 .70506 L .42216 .70428 L p .707 .577 .707 r
F P
0 g
s
.42216 .70428 m .42216 .68576 L .39032 .68653 L p .707 .577 .707 r
F P
0 g
s
.80551 .52627 m .80551 .58185 L .77805 .57746 L p .707 .577 .707 r
F P
0 g
s
.77805 .57746 m .77805 .52188 L .80551 .52627 L p .707 .577 .707 r
F P
0 g
s
.64524 .70434 m .64524 .68581 L .66161 .67844 L p .707 .577 .707 r
F P
0 g
s
.42216 .68576 m .42216 .70428 L .45154 .7009 L p .707 .577 .707 r
F P
0 g
s
.45154 .7009 m .45154 .68238 L .42216 .68576 L p .707 .577 .707 r
F P
0 g
s
.68566 .52413 m .68566 .57972 L .66161 .58537 L p .707 .577 .707 r
F P
0 g
s
.31064 .58071 m .31064 .52513 L .29804 .51724 L p .707 .577 .707 r
F P
0 g
s
.35915 .68463 m .35915 .70316 L .39032 .70506 L p .707 .577 .707 r
F P
0 g
s
.66161 .63273 m .66161 .59568 L .68566 .59003 L p .707 .577 .707 r
F P
0 g
s
.35915 .70316 m .35915 .68463 L .33169 .68024 L p .707 .577 .707 r
F P
0 g
s
.66161 .67844 m .66161 .69697 L .64524 .70434 L p .707 .577 .707 r
F P
0 g
s
.68566 .57972 m .68566 .52413 L .71504 .52075 L p .707 .577 .707 r
F P
0 g
s
.31064 .59102 m .31064 .62807 L .33169 .63453 L p .707 .577 .707 r
F P
0 g
s
.33169 .68024 m .33169 .69877 L .35915 .70316 L p .707 .577 .707 r
F P
0 g
s
.47559 .59396 m .47559 .63101 L .49196 .62365 L p .707 .577 .707 r
F P
0 g
s
.49196 .62365 m .49196 .58659 L .47559 .59396 L p .707 .577 .707 r
F P
0 g
s
.45154 .68238 m .45154 .7009 L .47559 .69525 L p .707 .577 .707 r
F P
0 g
s
.47559 .69525 m .47559 .67673 L .45154 .68238 L p .707 .577 .707 r
F P
0 g
s
.77805 .52188 m .77805 .57746 L .74688 .57556 L p .707 .577 .707 r
F P
0 g
s
.74688 .57556 m .74688 .51998 L .77805 .52188 L p .707 .577 .707 r
F P
0 g
s
.68566 .59003 m .68566 .62708 L .66161 .63273 L p .707 .577 .707 r
F P
0 g
s
.82657 .68138 m .82657 .69991 L .80551 .69346 L p .707 .577 .707 r
F P
0 g
s
.80551 .69346 m .80551 .67493 L .82657 .68138 L p .707 .577 .707 r
F P
0 g
s
.80551 .59216 m .80551 .62922 L .77805 .62483 L p .707 .577 .707 r
F P
0 g
s
.77805 .62483 m .77805 .58777 L .80551 .59216 L p .707 .577 .707 r
F P
0 g
s
.29804 .51724 m .29804 .57282 L .31064 .58071 L p .707 .577 .707 r
F P
0 g
s
.71504 .57634 m .71504 .52075 L .74688 .51998 L p .707 .577 .707 r
F P
0 g
s
.71504 .52075 m .71504 .57634 L .68566 .57972 L p .707 .577 .707 r
F P
0 g
s
.49196 .5207 m .49196 .57628 L .49904 .56792 L p .707 .577 .707 r
F P
0 g
s
.49904 .56792 m .49904 .51233 L .49196 .5207 L p .707 .577 .707 r
F P
0 g
s
.33169 .69877 m .33169 .68024 L .31064 .67379 L p .707 .577 .707 r
F P
0 g
s
.31064 .62807 m .31064 .59102 L .29804 .58313 L p .707 .577 .707 r
F P
0 g
s
.74688 .51998 m .74688 .57556 L .71504 .57634 L p .707 .577 .707 r
F P
0 g
s
.68566 .62708 m .68566 .59003 L .71504 .58665 L p .707 .577 .707 r
F P
0 g
s
.31064 .67379 m .31064 .69231 L .33169 .69877 L p .707 .577 .707 r
F P
0 g
s
.66161 .69697 m .66161 .67844 L .68566 .67279 L p .707 .577 .707 r
F P
0 g
s
.29804 .57282 m .29804 .51724 L .29515 .5087 L p .707 .577 .707 r
F P
0 g
s
.29804 .58313 m .29804 .62019 L .31064 .62807 L p .707 .577 .707 r
F P
0 g
s
.68566 .67279 m .68566 .69132 L .66161 .69697 L p .707 .577 .707 r
F P
0 g
s
.77805 .58777 m .77805 .62483 L .74688 .62292 L p .707 .577 .707 r
F P
0 g
s
.74688 .62292 m .74688 .58587 L .77805 .58777 L p .707 .577 .707 r
F P
0 g
s
.47559 .67673 m .47559 .69525 L .49196 .68789 L p .707 .577 .707 r
F P
0 g
s
.49196 .68789 m .49196 .66936 L .47559 .67673 L p .707 .577 .707 r
F P
0 g
s
.71504 .58665 m .71504 .6237 L .68566 .62708 L p .707 .577 .707 r
F P
0 g
s
.71504 .6237 m .71504 .58665 L .74688 .58587 L p .707 .577 .707 r
F P
0 g
s
.49196 .58659 m .49196 .62365 L .49904 .61528 L p .707 .577 .707 r
F P
0 g
s
.49904 .61528 m .49904 .57823 L .49196 .58659 L p .707 .577 .707 r
F P
0 g
s
.74688 .58587 m .74688 .62292 L .71504 .6237 L p .707 .577 .707 r
F P
0 g
s
.80551 .67493 m .80551 .69346 L .77805 .68906 L p .707 .577 .707 r
F P
0 g
s
.77805 .68906 m .77805 .67054 L .80551 .67493 L p .707 .577 .707 r
F P
0 g
s
.31064 .69231 m .31064 .67379 L .29804 .6659 L p .707 .577 .707 r
F P
0 g
s
.29515 .5087 m .29515 .56428 L .29804 .57282 L p .707 .577 .707 r
F P
0 g
s
.68566 .69132 m .68566 .67279 L .71504 .66941 L p .707 .577 .707 r
F P
0 g
s
.49904 .51233 m .49904 .56792 L .49615 .55937 L p .707 .577 .707 r
F P
0 g
s
.49615 .55937 m .49615 .50379 L .49904 .51233 L p .707 .577 .707 r
F P
0 g
s
.29804 .6659 m .29804 .68443 L .31064 .69231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62019 m .29804 .58313 L .29515 .57459 L p .707 .577 .707 r
F P
0 g
s
.71504 .66941 m .71504 .68794 L .68566 .69132 L p .707 .577 .707 r
F P
0 g
s
.77805 .67054 m .77805 .68906 L .74688 .68716 L p .707 .577 .707 r
F P
0 g
s
.74688 .68716 m .74688 .66864 L .77805 .67054 L p .707 .577 .707 r
F P
0 g
s
.29515 .57459 m .29515 .61165 L .29804 .62019 L p .707 .577 .707 r
F P
0 g
s
.71504 .68794 m .71504 .66941 L .74688 .66864 L p .707 .577 .707 r
F P
0 g
s
.49196 .66936 m .49196 .68789 L .49904 .67952 L p .707 .577 .707 r
F P
0 g
s
.49904 .67952 m .49904 .66099 L .49196 .66936 L p .707 .577 .707 r
F P
0 g
s
.29515 .56428 m .29515 .5087 L .30223 .50033 L p .707 .577 .707 r
F P
0 g
s
.74688 .66864 m .74688 .68716 L .71504 .68794 L p .707 .577 .707 r
F P
0 g
s
.49904 .57823 m .49904 .61528 L .49615 .60674 L p .707 .577 .707 r
F P
0 g
s
.49615 .60674 m .49615 .56969 L .49904 .57823 L p .707 .577 .707 r
F P
0 g
s
.29804 .68443 m .29804 .6659 L .29515 .65736 L p .707 .577 .707 r
F P
0 g
s
.30223 .50033 m .30223 .55592 L .29515 .56428 L p .707 .577 .707 r
F P
0 g
s
.29515 .65736 m .29515 .67589 L .29804 .68443 L p .707 .577 .707 r
F P
0 g
s
.49615 .50379 m .49615 .55937 L .48356 .55149 L p .707 .577 .707 r
F P
0 g
s
.48356 .55149 m .48356 .49591 L .49615 .50379 L p .707 .577 .707 r
F P
0 g
s
.29515 .61165 m .29515 .57459 L .30223 .56623 L p .707 .577 .707 r
F P
0 g
s
.49904 .66099 m .49904 .67952 L .49615 .67098 L p .707 .577 .707 r
F P
0 g
s
.49615 .67098 m .49615 .65245 L .49904 .66099 L p .707 .577 .707 r
F P
0 g
s
.30223 .56623 m .30223 .60328 L .29515 .61165 L p .707 .577 .707 r
F P
0 g
s
.30223 .55592 m .30223 .50033 L .3186 .49297 L p .707 .577 .707 r
F P
0 g
s
.49615 .56969 m .49615 .60674 L .48356 .59886 L p .707 .577 .707 r
F P
0 g
s
.48356 .59886 m .48356 .5618 L .49615 .56969 L p .707 .577 .707 r
F P
0 g
s
.29515 .67589 m .29515 .65736 L .30223 .64899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49297 m .3186 .54855 L .30223 .55592 L p .707 .577 .707 r
F P
0 g
s
.48356 .49591 m .48356 .55149 L .4625 .54504 L p .707 .577 .707 r
F P
0 g
s
.4625 .54504 m .4625 .48945 L .48356 .49591 L p .707 .577 .707 r
F P
0 g
s
.30223 .64899 m .30223 .66752 L .29515 .67589 L p .707 .577 .707 r
F P
0 g
s
.30223 .60328 m .30223 .56623 L .3186 .55886 L p .707 .577 .707 r
F P
0 g
s
.3186 .54855 m .3186 .49297 L .34265 .48732 L p .707 .577 .707 r
F P
0 g
s
.3186 .55886 m .3186 .59591 L .30223 .60328 L p .707 .577 .707 r
F P
0 g
s
.49615 .65245 m .49615 .67098 L .48356 .6631 L p .707 .577 .707 r
F P
0 g
s
.48356 .6631 m .48356 .64457 L .49615 .65245 L p .707 .577 .707 r
F P
0 g
s
.48356 .5618 m .48356 .59886 L .4625 .5924 L p .707 .577 .707 r
F P
0 g
s
.4625 .5924 m .4625 .55535 L .48356 .5618 L p .707 .577 .707 r
F P
0 g
s
.4625 .48945 m .4625 .54504 L .43504 .54064 L p .707 .577 .707 r
F P
0 g
s
.43504 .54064 m .43504 .48506 L .4625 .48945 L p .707 .577 .707 r
F P
0 g
s
.30223 .66752 m .30223 .64899 L .3186 .64163 L p .707 .577 .707 r
F P
0 g
s
.34265 .48732 m .34265 .5429 L .3186 .54855 L p .707 .577 .707 r
F P
0 g
s
.3186 .59591 m .3186 .55886 L .34265 .55321 L p .707 .577 .707 r
F P
0 g
s
.3186 .64163 m .3186 .66015 L .30223 .66752 L p .707 .577 .707 r
F P
0 g
s
.34265 .5429 m .34265 .48732 L .37203 .48394 L p .707 .577 .707 r
F P
0 g
s
.43504 .48506 m .43504 .54064 L .40387 .53874 L p .707 .577 .707 r
F P
0 g
s
.40387 .53874 m .40387 .48316 L .43504 .48506 L p .707 .577 .707 r
F P
0 g
s
.34265 .55321 m .34265 .59027 L .3186 .59591 L p .707 .577 .707 r
F P
0 g
s
.48356 .64457 m .48356 .6631 L .4625 .65664 L p .707 .577 .707 r
F P
0 g
s
.4625 .65664 m .4625 .63811 L .48356 .64457 L p .707 .577 .707 r
F P
0 g
s
.4625 .55535 m .4625 .5924 L .43504 .58801 L p .707 .577 .707 r
F P
0 g
s
.43504 .58801 m .43504 .55095 L .4625 .55535 L p .707 .577 .707 r
F P
0 g
s
.37203 .53952 m .37203 .48394 L .40387 .48316 L p .707 .577 .707 r
F P
0 g
s
.37203 .48394 m .37203 .53952 L .34265 .5429 L p .707 .577 .707 r
F P
0 g
s
.40387 .48316 m .40387 .53874 L .37203 .53952 L p .707 .577 .707 r
F P
0 g
s
.34265 .59027 m .34265 .55321 L .37203 .54983 L p .707 .577 .707 r
F P
0 g
s
.3186 .66015 m .3186 .64163 L .34265 .63598 L p .707 .577 .707 r
F P
0 g
s
.34265 .63598 m .34265 .6545 L .3186 .66015 L p .707 .577 .707 r
F P
0 g
s
.43504 .55095 m .43504 .58801 L .40387 .58611 L p .707 .577 .707 r
F P
0 g
s
.40387 .58611 m .40387 .54905 L .43504 .55095 L p .707 .577 .707 r
F P
0 g
s
.37203 .54983 m .37203 .58689 L .34265 .59027 L p .707 .577 .707 r
F P
0 g
s
.37203 .58689 m .37203 .54983 L .40387 .54905 L p .707 .577 .707 r
F P
0 g
s
.40387 .54905 m .40387 .58611 L .37203 .58689 L p .707 .577 .707 r
F P
0 g
s
.4625 .63811 m .4625 .65664 L .43504 .65225 L p .707 .577 .707 r
F P
0 g
s
.43504 .65225 m .43504 .63372 L .4625 .63811 L p .707 .577 .707 r
F P
0 g
s
.34265 .6545 m .34265 .63598 L .37203 .6326 L p .707 .577 .707 r
F P
0 g
s
.37203 .6326 m .37203 .65113 L .34265 .6545 L p .707 .577 .707 r
F P
0 g
s
.43504 .63372 m .43504 .65225 L .40387 .65035 L p .707 .577 .707 r
F P
0 g
s
.40387 .65035 m .40387 .63182 L .43504 .63372 L p .707 .577 .707 r
F P
0 g
s
.37203 .65113 m .37203 .6326 L .40387 .63182 L p .707 .577 .707 r
F P
0 g
s
.40387 .63182 m .40387 .65035 L .37203 .65113 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUH00000JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000J7oo
001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo60001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<0
05YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQT00003FUH0
05YF00AJEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP04001JEUYF0002
FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00L005YF000005YF001JEP040003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003
FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P0000=JEP0000000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000o
OolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000b
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
0002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPL0009JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH01000FUIJEP00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00
15YF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH3000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP06001JEP00001JEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P00
00EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP@00003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P00
0eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0004FUH300000eYF
001JEP06FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH40003FUH00`00FUIJEP020004
OolB0007Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPL0
00MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEPP00003FUH005YF00@000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP80009JEPH000=JEP03001oogoo01Aoo`L000=JEP<000=JEP80
02eoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP04001JEUYFFUH90009Ool90003FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00
;Goo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUHG0003FUH30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eo
o`00;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`8000=JEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000=JEPD000AJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
1@001UYF6`0000=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH30002FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EPD00003FUH0000000D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP80
00=JEP03001JEP00008000EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH000030002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPD000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH40006FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000bOol002aoo`03001JEP0000AJEP04001JEUYFFUHN0003FUH00`00FUIJEP03FUH01000
FUIJEUYF200015YF1@001EYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP80035oo`00;7oo00<005YF00000eYF1@007Woo0P0000=JEP00FUH015YF00<005YFFUH0
1EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool01000FUH005YF0P00
15YF1@006goo100015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001JEUYFFUH0
000^Ool002aoo`06001JEP00001JEP001EYF00@005YFFUIJEQ/000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009J
EP@00003FUH007oo01Uoo`<000AJEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH30005
FUH00`00FUIJEP03000MOol300000eYF001JEP02FUH2000]Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000L000AJEP03001JEUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00008Goo0P000eYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YF00004P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol200000eYF0000000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Goo0P0000AJEP00000002eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH300000eYF001JEP04FUH01000FUIJEUYF0P007Woo0`000eYF0`00;Goo000^Ool200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH01@000UYF00@005YFFUIJEP8000Qoo`<000moo`@00003FUH005YF00=JEP03
001JEP0002eoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUH000030002FUH20007Ool50009Ool5
0005FUH00`00FUIJEP02FUH2000^Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEPT00003
FUH005YF00IJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool003Ioo`D000AJEPP000AJEP03001JEUYF009JEPP00003FUH005YF00@000Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo
000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00006P00?goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool20004FUH01000FUIJEUYF20006Goo1P0015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00;7oo00<005YF00000eYF1@009goo0`0000EJ
EP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05Aoo`00;7oo00@005YF001JEP8002moo`80
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP02001GOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`@003Ao
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH4001KOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H005moo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF1000GGoo000/
Ool20003FUH00`00FUIJEP02FUH5000=Ool3000@Ool400000eYF001JEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04001IOol002eo
o`05001JEUYFFUH00005FUH01000FUIJEUYF200017oo1@002Woo1@001EYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=J
EP8005Qoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF5@00
1UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YF000005Ioo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000eYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YF
FUH000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJ
EPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`D000AJEP05001JEUYFFUH0
001EOol003Aoo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
00Yoo`04001JEUYF0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2
001DOol003eooaT000moo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH0000<Ool200000eYF
0000001DOol006Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF000037oo
1@00E7oo001UOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`09
Ool20002FUH3001DOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH007oo00Eoo`@000AJEP03001JEP0005Aoo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF0P0000=JEP0000001@000eYF00<005YFFUH00UYF0P00EGoo001UOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001U
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00AJEP04001JEP00001HOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0000=JEP04001JEUYFFUH5001JOol006Ioo`03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP800003FUH0000000D005moo`00Igoo0P000UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF1000IWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
0000K7oo001]Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH4001^Ool0075oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF1@00Mgoo001lOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP06001lOol008Eo
oaH0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70551 m .59613 .64992 L .56496 .64802 L p .707 .577 .707 r
F P
0 g
s
.59613 .64992 m .59613 .70551 L .62796 .70473 L p .707 .577 .707 r
F P
0 g
s
.62796 .70473 m .62796 .64915 L .59613 .64992 L p .707 .577 .707 r
F P
0 g
s
.62796 .64915 m .62796 .70473 L .65734 .70135 L p .707 .577 .707 r
F P
0 g
s
.65734 .70135 m .65734 .64577 L .62796 .64915 L p .707 .577 .707 r
F P
0 g
s
.56496 .70361 m .56496 .64802 L .5375 .64363 L p .707 .577 .707 r
F P
0 g
s
.56496 .64802 m .56496 .70361 L .59613 .70551 L p .707 .577 .707 r
F P
0 g
s
.65734 .64577 m .65734 .70135 L .6814 .6957 L p .707 .577 .707 r
F P
0 g
s
.6814 .6957 m .6814 .64012 L .65734 .64577 L p .707 .577 .707 r
F P
0 g
s
.59613 .74484 m .59613 .70778 L .56496 .70588 L p .707 .577 .707 r
F P
0 g
s
.59613 .70778 m .59613 .74484 L .62796 .74406 L p .707 .577 .707 r
F P
0 g
s
.62796 .74406 m .62796 .70701 L .59613 .70778 L p .707 .577 .707 r
F P
0 g
s
.62796 .70701 m .62796 .74406 L .65735 .74068 L p .707 .577 .707 r
F P
0 g
s
.65735 .74068 m .65734 .70363 L .62796 .70701 L p .707 .577 .707 r
F P
0 g
s
.5375 .64363 m .5375 .69921 L .56496 .70361 L p .707 .577 .707 r
F P
0 g
s
.5375 .69921 m .5375 .64363 L .51644 .63718 L p .707 .577 .707 r
F P
0 g
s
.56496 .74294 m .56496 .70588 L .5375 .70149 L p .707 .577 .707 r
F P
0 g
s
.56496 .70588 m .56496 .74294 L .59613 .74484 L p .707 .577 .707 r
F P
0 g
s
.65734 .70363 m .65735 .74068 L .6814 .73503 L p .707 .577 .707 r
F P
0 g
s
.6814 .73503 m .6814 .69798 L .65734 .70363 L p .707 .577 .707 r
F P
0 g
s
.5375 .70149 m .5375 .73855 L .56496 .74294 L p .707 .577 .707 r
F P
0 g
s
.6814 .64012 m .6814 .6957 L .69777 .68833 L p .707 .577 .707 r
F P
0 g
s
.69777 .68833 m .69777 .63275 L .6814 .64012 L p .707 .577 .707 r
F P
0 g
s
.51644 .63718 m .51644 .69276 L .5375 .69921 L p .707 .577 .707 r
F P
0 g
s
.5375 .73855 m .5375 .70149 L .51644 .69504 L p .707 .577 .707 r
F P
0 g
s
.59613 .82292 m .59613 .8044 L .56496 .8025 L p .707 .577 .707 r
F P
0 g
s
.59613 .8044 m .59613 .82292 L .62796 .82215 L p .707 .577 .707 r
F P
0 g
s
.62796 .82215 m .62796 .80362 L .59613 .8044 L p .707 .577 .707 r
F P
0 g
s
.51644 .69276 m .51644 .63718 L .50385 .62929 L p .707 .577 .707 r
F P
0 g
s
.62796 .80362 m .62796 .82215 L .65735 .81877 L p .707 .577 .707 r
F P
0 g
s
.65735 .81877 m .65735 .80024 L .62796 .80362 L p .707 .577 .707 r
F P
0 g
s
.56496 .8025 m .56496 .82102 L .59613 .82292 L p .707 .577 .707 r
F P
0 g
s
.51644 .69504 m .51644 .73209 L .5375 .73855 L p .707 .577 .707 r
F P
0 g
s
.56496 .82102 m .56496 .8025 L .5375 .7981 L p .707 .577 .707 r
F P
0 g
s
.6814 .69798 m .6814 .73503 L .69777 .72767 L p .707 .577 .707 r
F P
0 g
s
.69777 .72767 m .69777 .69061 L .6814 .69798 L p .707 .577 .707 r
F P
0 g
s
.5375 .7981 m .5375 .81663 L .56496 .82102 L p .707 .577 .707 r
F P
0 g
s
.65735 .80024 m .65735 .81877 L .6814 .81312 L p .707 .577 .707 r
F P
0 g
s
.6814 .81312 m .6814 .79459 L .65735 .80024 L p .707 .577 .707 r
F P
0 g
s
.50385 .62929 m .50385 .68488 L .51644 .69276 L p .707 .577 .707 r
F P
0 g
s
.69777 .63275 m .69777 .68833 L .70485 .67997 L p .707 .577 .707 r
F P
0 g
s
.70485 .67997 m .70485 .62439 L .69777 .63275 L p .707 .577 .707 r
F P
0 g
s
.51644 .73209 m .51644 .69504 L .50385 .68715 L p .707 .577 .707 r
F P
0 g
s
.5375 .81663 m .5375 .7981 L .51644 .79165 L p .707 .577 .707 r
F P
0 g
s
.51644 .79165 m .51644 .81018 L .5375 .81663 L p .707 .577 .707 r
F P
0 g
s
.50385 .68715 m .50385 .72421 L .51644 .73209 L p .707 .577 .707 r
F P
0 g
s
.50385 .68488 m .50385 .62929 L .50095 .62075 L p .707 .577 .707 r
F P
0 g
s
.69777 .69061 m .69777 .72767 L .70485 .7193 L p .707 .577 .707 r
F P
0 g
s
.70485 .7193 m .70485 .68225 L .69777 .69061 L p .707 .577 .707 r
F P
0 g
s
.6814 .79459 m .6814 .81312 L .69777 .80575 L p .707 .577 .707 r
F P
0 g
s
.69777 .80575 m .69777 .78722 L .6814 .79459 L p .707 .577 .707 r
F P
0 g
s
.51644 .81018 m .51644 .79165 L .50385 .78377 L p .707 .577 .707 r
F P
0 g
s
.50095 .62075 m .50095 .67633 L .50385 .68488 L p .707 .577 .707 r
F P
0 g
s
.50385 .72421 m .50385 .68715 L .50095 .67861 L p .707 .577 .707 r
F P
0 g
s
.70485 .62439 m .70485 .67997 L .70195 .67143 L p .707 .577 .707 r
F P
0 g
s
.70195 .67143 m .70195 .61584 L .70485 .62439 L p .707 .577 .707 r
F P
0 g
s
.50385 .78377 m .50385 .80229 L .51644 .81018 L p .707 .577 .707 r
F P
0 g
s
.50095 .67861 m .50095 .71567 L .50385 .72421 L p .707 .577 .707 r
F P
0 g
s
.69777 .78722 m .69777 .80575 L .70485 .79739 L p .707 .577 .707 r
F P
0 g
s
.70485 .79739 m .70485 .77886 L .69777 .78722 L p .707 .577 .707 r
F P
0 g
s
.50095 .67633 m .50095 .62075 L .50804 .61239 L p .707 .577 .707 r
F P
0 g
s
.70485 .68225 m .70485 .7193 L .70195 .71076 L p .707 .577 .707 r
F P
0 g
s
.70195 .71076 m .70195 .6737 L .70485 .68225 L p .707 .577 .707 r
F P
0 g
s
.50385 .80229 m .50385 .78377 L .50095 .77522 L p .707 .577 .707 r
F P
0 g
s
.50804 .61239 m .50804 .66797 L .50095 .67633 L p .707 .577 .707 r
F P
0 g
s
.50095 .71567 m .50095 .67861 L .50804 .67025 L p .707 .577 .707 r
F P
0 g
s
.50095 .77522 m .50095 .79375 L .50385 .80229 L p .707 .577 .707 r
F P
0 g
s
.70195 .61584 m .70195 .67143 L .68936 .66354 L p .707 .577 .707 r
F P
0 g
s
.68936 .66354 m .68936 .60796 L .70195 .61584 L p .707 .577 .707 r
F P
0 g
s
.49044 .87739 m .49044 .3755 L .44643 .37282 L p .707 .577 .707 r
F P
0 g
s
.50804 .67025 m .50804 .7073 L .50095 .71567 L p .707 .577 .707 r
F P
0 g
s
.50804 .66797 m .50804 .61239 L .5244 .60502 L p .707 .577 .707 r
F P
0 g
s
.50095 .79375 m .50095 .77522 L .50804 .76686 L p .707 .577 .707 r
F P
0 g
s
.5244 .60502 m .5244 .6606 L .50804 .66797 L p .707 .577 .707 r
F P
0 g
s
.50804 .7073 m .50804 .67025 L .5244 .66288 L p .707 .577 .707 r
F P
0 g
s
.50804 .76686 m .50804 .78539 L .50095 .79375 L p .707 .577 .707 r
F P
0 g
s
.5244 .66288 m .5244 .69993 L .50804 .7073 L p .707 .577 .707 r
F P
0 g
s
.50804 .78539 m .50804 .76686 L .5244 .75949 L p .707 .577 .707 r
F P
0 g
s
.5244 .75949 m .5244 .77802 L .50804 .78539 L p .707 .577 .707 r
F P
0 g
s
.5244 .77802 m .5244 .75949 L .54846 .75384 L p .707 .577 .707 r
F P
0 g
s
.54846 .75384 m .54846 .77237 L .5244 .77802 L p .707 .577 .707 r
F P
0 g
s
.49044 .3755 m .49044 .87739 L .53538 .87629 L p .707 .577 .707 r
F P
0 g
s
.5244 .6606 m .5244 .60502 L .54846 .59937 L p .707 .577 .707 r
F P
0 g
s
.54846 .59937 m .54846 .65495 L .5244 .6606 L p .707 .577 .707 r
F P
0 g
s
.5244 .69993 m .5244 .66288 L .54846 .65723 L p .707 .577 .707 r
F P
0 g
s
.54846 .65723 m .54846 .69428 L .5244 .69993 L p .707 .577 .707 r
F P
0 g
s
.53538 .87629 m .53538 .3744 L .49044 .3755 L p .707 .577 .707 r
F P
0 g
s
.25312 .66869 m .25312 .61311 L .22195 .61121 L p .707 .577 .707 r
F P
0 g
s
.25312 .61311 m .25312 .66869 L .28495 .66791 L p .707 .577 .707 r
F P
0 g
s
.28495 .66791 m .28495 .61233 L .25312 .61311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65495 m .54846 .59937 L .57784 .59599 L p .707 .577 .707 r
F P
0 g
s
.57784 .59599 m .57784 .65157 L .54846 .65495 L p .707 .577 .707 r
F P
0 g
s
.54846 .69428 m .54846 .65723 L .57784 .65385 L p .707 .577 .707 r
F P
0 g
s
.57784 .65385 m .57784 .69091 L .54846 .69428 L p .707 .577 .707 r
F P
0 g
s
.54846 .77237 m .54846 .75384 L .57784 .75046 L p .707 .577 .707 r
F P
0 g
s
.57784 .75046 m .57784 .76899 L .54846 .77237 L p .707 .577 .707 r
F P
0 g
s
.53538 .3744 m .53538 .87629 L .57686 .87152 L p .707 .577 .707 r
F P
0 g
s
.57686 .87152 m .57686 .36963 L .53538 .3744 L p .707 .577 .707 r
F P
0 g
s
.70485 .77886 m .70485 .79739 L .70195 .78884 L p .707 .577 .707 r
F P
0 g
s
.70195 .78884 m .70195 .77032 L .70485 .77886 L p .707 .577 .707 r
F P
0 g
s
.28495 .61233 m .28495 .66791 L .31434 .66454 L p .707 .577 .707 r
F P
0 g
s
.31434 .66454 m .31434 .60895 L .28495 .61233 L p .707 .577 .707 r
F P
0 g
s
.70195 .6737 m .70195 .71076 L .68936 .70288 L p .707 .577 .707 r
F P
0 g
s
.68936 .70288 m .68936 .66582 L .70195 .6737 L p .707 .577 .707 r
F P
0 g
s
.44643 .8747 m .44643 .37282 L .40766 .36661 L p .707 .577 .707 r
F P
0 g
s
.44643 .37282 m .44643 .8747 L .49044 .87739 L p .707 .577 .707 r
F P
0 g
s
.22195 .66679 m .22195 .61121 L .19449 .60682 L p .707 .577 .707 r
F P
0 g
s
.22195 .61121 m .22195 .66679 L .25312 .66869 L p .707 .577 .707 r
F P
0 g
s
.31434 .60895 m .31434 .66454 L .33839 .65889 L p .707 .577 .707 r
F P
0 g
s
.33839 .65889 m .33839 .6033 L .31434 .60895 L p .707 .577 .707 r
F P
0 g
s
.25312 .70802 m .25312 .67097 L .22195 .66907 L p .707 .577 .707 r
F P
0 g
s
.25312 .67097 m .25312 .70802 L .28495 .70725 L p .707 .577 .707 r
F P
0 g
s
.28495 .70725 m .28495 .67019 L .25312 .67097 L p .707 .577 .707 r
F P
0 g
s
.57784 .65157 m .57784 .59599 L .60968 .59521 L p .707 .577 .707 r
F P
0 g
s
.60968 .59521 m .60968 .6508 L .57784 .65157 L p .707 .577 .707 r
F P
0 g
s
.57784 .69091 m .57784 .65385 L .60968 .65307 L p .707 .577 .707 r
F P
0 g
s
.60968 .65307 m .60968 .69013 L .57784 .69091 L p .707 .577 .707 r
F P
0 g
s
.57784 .76899 m .57784 .75046 L .60968 .74969 L p .707 .577 .707 r
F P
0 g
s
.60968 .74969 m .60968 .76821 L .57784 .76899 L p .707 .577 .707 r
F P
0 g
s
.57686 .36963 m .57686 .87152 L .61082 .86354 L p .707 .577 .707 r
F P
0 g
s
.64085 .59711 m .64085 .6527 L .60968 .6508 L p .707 .577 .707 r
F P
0 g
s
.60968 .6508 m .60968 .59521 L .64085 .59711 L p .707 .577 .707 r
F P
0 g
s
.64085 .65497 m .64085 .69203 L .60968 .69013 L p .707 .577 .707 r
F P
0 g
s
.60968 .69013 m .60968 .65307 L .64085 .65497 L p .707 .577 .707 r
F P
0 g
s
.64085 .75159 m .64085 .77011 L .60968 .76821 L p .707 .577 .707 r
F P
0 g
s
.60968 .76821 m .60968 .74969 L .64085 .75159 L p .707 .577 .707 r
F P
0 g
s
.61082 .86354 m .61082 .36165 L .57686 .36963 L p .707 .577 .707 r
F P
0 g
s
.68936 .60796 m .68936 .66354 L .66831 .65709 L p .707 .577 .707 r
F P
0 g
s
.66831 .65709 m .66831 .60151 L .68936 .60796 L p .707 .577 .707 r
F P
0 g
s
.28495 .67019 m .28495 .70725 L .31434 .70387 L p .707 .577 .707 r
F P
0 g
s
.31434 .70387 m .31434 .66681 L .28495 .67019 L p .707 .577 .707 r
F P
0 g
s
.19449 .60682 m .19449 .6624 L .22195 .66679 L p .707 .577 .707 r
F P
0 g
s
.19449 .6624 m .19449 .60682 L .17343 .60036 L p .707 .577 .707 r
F P
0 g
s
.22195 .70612 m .22195 .66907 L .19449 .66468 L p .707 .577 .707 r
F P
0 g
s
.22195 .66907 m .22195 .70612 L .25312 .70802 L p .707 .577 .707 r
F P
0 g
s
.40766 .8685 m .40766 .36661 L .37794 .3575 L p .707 .577 .707 r
F P
0 g
s
.40766 .36661 m .40766 .8685 L .44643 .8747 L p .707 .577 .707 r
F P
0 g
s
.31434 .66681 m .31434 .70387 L .33839 .69822 L p .707 .577 .707 r
F P
0 g
s
.33839 .69822 m .33839 .66116 L .31434 .66681 L p .707 .577 .707 r
F P
0 g
s
.70195 .77032 m .70195 .78884 L .68936 .78096 L p .707 .577 .707 r
F P
0 g
s
.68936 .78096 m .68936 .76243 L .70195 .77032 L p .707 .577 .707 r
F P
0 g
s
.19449 .66468 m .19449 .70173 L .22195 .70612 L p .707 .577 .707 r
F P
0 g
s
.68936 .66582 m .68936 .70288 L .66831 .69642 L p .707 .577 .707 r
F P
0 g
s
.66831 .69642 m .66831 .65937 L .68936 .66582 L p .707 .577 .707 r
F P
0 g
s
.33839 .6033 m .33839 .65889 L .35476 .65152 L p .707 .577 .707 r
F P
0 g
s
.35476 .65152 m .35476 .59594 L .33839 .6033 L p .707 .577 .707 r
F P
0 g
s
.17343 .60036 m .17343 .65594 L .19449 .6624 L p .707 .577 .707 r
F P
0 g
s
.19449 .70173 m .19449 .66468 L .17343 .65822 L p .707 .577 .707 r
F P
0 g
s
.66831 .60151 m .66831 .65709 L .64085 .6527 L p .707 .577 .707 r
F P
0 g
s
.64085 .6527 m .64085 .59711 L .66831 .60151 L p .707 .577 .707 r
F P
0 g
s
.25312 .78611 m .25312 .76758 L .22195 .76568 L p .707 .577 .707 r
F P
0 g
s
.25312 .76758 m .25312 .78611 L .28495 .78533 L p .707 .577 .707 r
F P
0 g
s
.28495 .78533 m .28495 .76681 L .25312 .76758 L p .707 .577 .707 r
F P
0 g
s
.17343 .65594 m .17343 .60036 L .16084 .59248 L p .707 .577 .707 r
F P
0 g
s
.28495 .76681 m .28495 .78533 L .31434 .78195 L p .707 .577 .707 r
F P
0 g
s
.31434 .78195 m .31434 .76343 L .28495 .76681 L p .707 .577 .707 r
F P
0 g
s
.61082 .36165 m .61082 .86354 L .63393 .85314 L p .707 .577 .707 r
F P
0 g
s
.63393 .85314 m .63393 .35125 L .61082 .36165 L p .707 .577 .707 r
F P
0 g
s
.22195 .76568 m .22195 .78421 L .25312 .78611 L p .707 .577 .707 r
F P
0 g
s
.17343 .65822 m .17343 .69528 L .19449 .70173 L p .707 .577 .707 r
F P
0 g
s
.22195 .78421 m .22195 .76568 L .19449 .76129 L p .707 .577 .707 r
F P
0 g
s
.33839 .66116 m .33839 .69822 L .35476 .69085 L p .707 .577 .707 r
F P
0 g
s
.35476 .69085 m .35476 .6538 L .33839 .66116 L p .707 .577 .707 r
F P
0 g
s
.19449 .76129 m .19449 .77982 L .22195 .78421 L p .707 .577 .707 r
F P
0 g
s
.66831 .65937 m .66831 .69642 L .64085 .69203 L p .707 .577 .707 r
F P
0 g
s
.64085 .69203 m .64085 .65497 L .66831 .65937 L p .707 .577 .707 r
F P
0 g
s
.31434 .76343 m .31434 .78195 L .33839 .7763 L p .707 .577 .707 r
F P
0 g
s
.33839 .7763 m .33839 .75778 L .31434 .76343 L p .707 .577 .707 r
F P
0 g
s
.16084 .59248 m .16084 .64806 L .17343 .65594 L p .707 .577 .707 r
F P
0 g
s
.68936 .76243 m .68936 .78096 L .66831 .77451 L p .707 .577 .707 r
F P
0 g
s
.66831 .77451 m .66831 .75598 L .68936 .76243 L p .707 .577 .707 r
F P
0 g
s
.35476 .59594 m .35476 .65152 L .36184 .64315 L p .707 .577 .707 r
F P
0 g
s
.36184 .64315 m .36184 .58757 L .35476 .59594 L p .707 .577 .707 r
F P
0 g
s
.37794 .85939 m .37794 .3575 L .36016 .34637 L p .707 .577 .707 r
F P
0 g
s
.37794 .3575 m .37794 .85939 L .40766 .8685 L p .707 .577 .707 r
F P
0 g
s
.17343 .69528 m .17343 .65822 L .16084 .65034 L p .707 .577 .707 r
F P
0 g
s
.19449 .77982 m .19449 .76129 L .17343 .75484 L p .707 .577 .707 r
F P
0 g
s
.17343 .75484 m .17343 .77336 L .19449 .77982 L p .707 .577 .707 r
F P
0 g
s
.16084 .65034 m .16084 .68739 L .17343 .69528 L p .707 .577 .707 r
F P
0 g
s
.16084 .64806 m .16084 .59248 L .15794 .58394 L p .707 .577 .707 r
F P
0 g
s
.35476 .6538 m .35476 .69085 L .36184 .68249 L p .707 .577 .707 r
F P
0 g
s
.36184 .68249 m .36184 .64543 L .35476 .6538 L p .707 .577 .707 r
F P
0 g
s
.33839 .75778 m .33839 .7763 L .35476 .76894 L p .707 .577 .707 r
F P
0 g
s
.35476 .76894 m .35476 .75041 L .33839 .75778 L p .707 .577 .707 r
F P
0 g
s
.66831 .75598 m .66831 .77451 L .64085 .77011 L p .707 .577 .707 r
F P
0 g
s
.64085 .77011 m .64085 .75159 L .66831 .75598 L p .707 .577 .707 r
F P
0 g
s
.63393 .35125 m .63393 .85314 L .64393 .84133 L p .707 .577 .707 r
F P
0 g
s
.64393 .84133 m .64393 .33944 L .63393 .35125 L p .707 .577 .707 r
F P
0 g
s
.17343 .77336 m .17343 .75484 L .16084 .74695 L p .707 .577 .707 r
F P
0 g
s
.15794 .58394 m .15794 .63952 L .16084 .64806 L p .707 .577 .707 r
F P
0 g
s
.16084 .68739 m .16084 .65034 L .15794 .6418 L p .707 .577 .707 r
F P
0 g
s
.36184 .58757 m .36184 .64315 L .35894 .63461 L p .707 .577 .707 r
F P
0 g
s
.35894 .63461 m .35894 .57903 L .36184 .58757 L p .707 .577 .707 r
F P
0 g
s
.16084 .74695 m .16084 .76548 L .17343 .77336 L p .707 .577 .707 r
F P
0 g
s
.15794 .6418 m .15794 .67885 L .16084 .68739 L p .707 .577 .707 r
F P
0 g
s
.35476 .75041 m .35476 .76894 L .36184 .76057 L p .707 .577 .707 r
F P
0 g
s
.36184 .76057 m .36184 .74204 L .35476 .75041 L p .707 .577 .707 r
F P
0 g
s
.36184 .64543 m .36184 .68249 L .35894 .67394 L p .707 .577 .707 r
F P
0 g
s
.35894 .67394 m .35894 .63689 L .36184 .64543 L p .707 .577 .707 r
F P
0 g
s
.35894 .57903 m .35894 .63461 L .34635 .62673 L p .707 .577 .707 r
F P
0 g
s
.34635 .62673 m .34635 .57114 L .35894 .57903 L p .707 .577 .707 r
F P
0 g
s
.36184 .74204 m .36184 .76057 L .35894 .75203 L p .707 .577 .707 r
F P
0 g
s
.35894 .75203 m .35894 .7335 L .36184 .74204 L p .707 .577 .707 r
F P
0 g
s
.35894 .63689 m .35894 .67394 L .34635 .66606 L p .707 .577 .707 r
F P
0 g
s
.34635 .66606 m .34635 .629 L .35894 .63689 L p .707 .577 .707 r
F P
0 g
s
.36016 .84826 m .36016 .34637 L .35607 .33431 L p .707 .577 .707 r
F P
0 g
s
.36016 .34637 m .36016 .84826 L .37794 .85939 L p .707 .577 .707 r
F P
0 g
s
.15794 .63952 m .15794 .58394 L .16503 .57557 L p .707 .577 .707 r
F P
0 g
s
.16084 .76548 m .16084 .74695 L .15794 .73841 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57557 m .16503 .63115 L .15794 .63952 L p .707 .577 .707 r
F P
0 g
s
.15794 .67885 m .15794 .6418 L .16503 .63343 L p .707 .577 .707 r
F P
0 g
s
.15794 .73841 m .15794 .75694 L .16084 .76548 L p .707 .577 .707 r
F P
0 g
s
.64393 .33944 m .64393 .84133 L .63984 .82927 L p .707 .577 .707 r
F P
0 g
s
.63984 .82927 m .63984 .32738 L .64393 .33944 L p .707 .577 .707 r
F P
0 g
s
.16503 .63343 m .16503 .67049 L .15794 .67885 L p .707 .577 .707 r
F P
0 g
s
.16503 .63115 m .16503 .57557 L .1814 .5682 L p .707 .577 .707 r
F P
0 g
s
.35894 .7335 m .35894 .75203 L .34635 .74415 L p .707 .577 .707 r
F P
0 g
s
.34635 .74415 m .34635 .72562 L .35894 .7335 L p .707 .577 .707 r
F P
0 g
s
.35607 .33431 m .35607 .8362 L .36016 .84826 L p .707 .577 .707 r
F P
0 g
s
.35607 .8362 m .35607 .33431 L .36607 .3225 L p .707 .577 .707 r
F P
0 g
s
.15794 .75694 m .15794 .73841 L .16503 .73004 L p .707 .577 .707 r
F P
0 g
s
.1814 .5682 m .1814 .62379 L .16503 .63115 L p .707 .577 .707 r
F P
0 g
s
.34635 .57114 m .34635 .62673 L .3253 .62027 L p .707 .577 .707 r
F P
0 g
s
.3253 .62027 m .3253 .56469 L .34635 .57114 L p .707 .577 .707 r
F P
0 g
s
.16503 .67049 m .16503 .63343 L .1814 .62606 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .73004 m .16503 .74857 L .15794 .75694 L p .707 .577 .707 r
F P
0 g
s
.1814 .62606 m .1814 .66312 L .16503 .67049 L p .707 .577 .707 r
F P
0 g
s
.1814 .62379 m .1814 .5682 L .20545 .56255 L p .707 .577 .707 r
F P
0 g
s
.34635 .629 m .34635 .66606 L .3253 .65961 L p .707 .577 .707 r
F P
0 g
s
.3253 .65961 m .3253 .62255 L .34635 .629 L p .707 .577 .707 r
F P
0 g
s
.63984 .32738 m .63984 .82927 L .62206 .81814 L p .707 .577 .707 r
F P
0 g
s
.62206 .81814 m .62206 .31625 L .63984 .32738 L p .707 .577 .707 r
F P
0 g
s
.3253 .56469 m .3253 .62027 L .29784 .61588 L p .707 .577 .707 r
F P
0 g
s
.29784 .61588 m .29784 .5603 L .3253 .56469 L p .707 .577 .707 r
F P
0 g
s
.20545 .56255 m .20545 .61814 L .1814 .62379 L p .707 .577 .707 r
F P
0 g
s
.1814 .66312 m .1814 .62606 L .20545 .62041 L p .707 .577 .707 r
F P
0 g
s
.16503 .74857 m .16503 .73004 L .1814 .72268 L p .707 .577 .707 r
F P
0 g
s
.20545 .61814 m .20545 .56255 L .23483 .55917 L p .707 .577 .707 r
F P
0 g
s
.1814 .72268 m .1814 .7412 L .16503 .74857 L p .707 .577 .707 r
F P
0 g
s
.36607 .82439 m .36607 .3225 L .38918 .3121 L p .707 .577 .707 r
F P
0 g
s
.36607 .3225 m .36607 .82439 L .35607 .8362 L p .707 .577 .707 r
F P
0 g
s
.20545 .62041 m .20545 .65747 L .1814 .66312 L p .707 .577 .707 r
F P
0 g
s
.29784 .5603 m .29784 .61588 L .26667 .61398 L p .707 .577 .707 r
F P
0 g
s
.26667 .61398 m .26667 .5584 L .29784 .5603 L p .707 .577 .707 r
F P
0 g
s
.3253 .62255 m .3253 .65961 L .29784 .65521 L p .707 .577 .707 r
F P
0 g
s
.29784 .65521 m .29784 .61816 L .3253 .62255 L p .707 .577 .707 r
F P
0 g
s
.23483 .61476 m .23483 .55917 L .26667 .5584 L p .707 .577 .707 r
F P
0 g
s
.23483 .55917 m .23483 .61476 L .20545 .61814 L p .707 .577 .707 r
F P
0 g
s
.34635 .72562 m .34635 .74415 L .3253 .73769 L p .707 .577 .707 r
F P
0 g
s
.3253 .73769 m .3253 .71916 L .34635 .72562 L p .707 .577 .707 r
F P
0 g
s
.26667 .5584 m .26667 .61398 L .23483 .61476 L p .707 .577 .707 r
F P
0 g
s
.20545 .65747 m .20545 .62041 L .23483 .61704 L p .707 .577 .707 r
F P
0 g
s
.73333 .61347 m .73333 .55789 L .70216 .55599 L p .707 .577 .707 r
F P
0 g
s
.73333 .55789 m .73333 .61347 L .76517 .61269 L p .707 .577 .707 r
F P
0 g
s
.76517 .61269 m .76517 .55711 L .73333 .55789 L p .707 .577 .707 r
F P
0 g
s
.76517 .55711 m .76517 .61269 L .79455 .60931 L p .707 .577 .707 r
F P
0 g
s
.79455 .60931 m .79455 .55373 L .76517 .55711 L p .707 .577 .707 r
F P
0 g
s
.1814 .7412 m .1814 .72268 L .20545 .71703 L p .707 .577 .707 r
F P
0 g
s
.70216 .61157 m .70216 .55599 L .6747 .55159 L p .707 .577 .707 r
F P
0 g
s
.70216 .55599 m .70216 .61157 L .73333 .61347 L p .707 .577 .707 r
F P
0 g
s
.29784 .61816 m .29784 .65521 L .26667 .65331 L p .707 .577 .707 r
F P
0 g
s
.26667 .65331 m .26667 .61626 L .29784 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61704 m .23483 .65409 L .20545 .65747 L p .707 .577 .707 r
F P
0 g
s
.20545 .71703 m .20545 .73555 L .1814 .7412 L p .707 .577 .707 r
F P
0 g
s
.23483 .65409 m .23483 .61704 L .26667 .61626 L p .707 .577 .707 r
F P
0 g
s
.62206 .31625 m .62206 .81814 L .59233 .80903 L p .707 .577 .707 r
F P
0 g
s
.59233 .80903 m .59233 .30714 L .62206 .31625 L p .707 .577 .707 r
F P
0 g
s
.26667 .61626 m .26667 .65331 L .23483 .65409 L p .707 .577 .707 r
F P
0 g
s
.79455 .55373 m .79455 .60931 L .8186 .60366 L p .707 .577 .707 r
F P
0 g
s
.8186 .60366 m .8186 .54808 L .79455 .55373 L p .707 .577 .707 r
F P
0 g
s
.73333 .6528 m .73333 .61575 L .70216 .61385 L p .707 .577 .707 r
F P
0 g
s
.73333 .61575 m .73333 .6528 L .76517 .65202 L p .707 .577 .707 r
F P
0 g
s
.76517 .65202 m .76517 .61497 L .73333 .61575 L p .707 .577 .707 r
F P
0 g
s
.3253 .71916 m .3253 .73769 L .29784 .7333 L p .707 .577 .707 r
F P
0 g
s
.29784 .7333 m .29784 .71477 L .3253 .71916 L p .707 .577 .707 r
F P
0 g
s
.76517 .61497 m .76517 .65202 L .79455 .64864 L p .707 .577 .707 r
F P
0 g
s
.79455 .64864 m .79455 .61159 L .76517 .61497 L p .707 .577 .707 r
F P
0 g
s
.6747 .55159 m .6747 .60718 L .70216 .61157 L p .707 .577 .707 r
F P
0 g
s
.6747 .60718 m .6747 .55159 L .65365 .54514 L p .707 .577 .707 r
F P
0 g
s
.70216 .6509 m .70216 .61385 L .6747 .60945 L p .707 .577 .707 r
F P
0 g
s
.70216 .61385 m .70216 .6509 L .73333 .6528 L p .707 .577 .707 r
F P
0 g
s
.20545 .73555 m .20545 .71703 L .23483 .71365 L p .707 .577 .707 r
F P
0 g
s
.38918 .3121 m .38918 .81399 L .36607 .82439 L p .707 .577 .707 r
F P
0 g
s
.38918 .81399 m .38918 .3121 L .42314 .30413 L p .707 .577 .707 r
F P
0 g
s
.79455 .61159 m .79455 .64864 L .8186 .643 L p .707 .577 .707 r
F P
0 g
s
.8186 .643 m .8186 .60594 L .79455 .61159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71365 m .23483 .73218 L .20545 .73555 L p .707 .577 .707 r
F P
0 g
s
.6747 .60945 m .6747 .64651 L .70216 .6509 L p .707 .577 .707 r
F P
0 g
s
.29784 .71477 m .29784 .7333 L .26667 .7314 L p .707 .577 .707 r
F P
0 g
s
.26667 .7314 m .26667 .71287 L .29784 .71477 L p .707 .577 .707 r
F P
0 g
s
.8186 .54808 m .8186 .60366 L .83497 .59629 L p .707 .577 .707 r
F P
0 g
s
.83497 .59629 m .83497 .54071 L .8186 .54808 L p .707 .577 .707 r
F P
0 g
s
.65365 .54514 m .65365 .60072 L .6747 .60718 L p .707 .577 .707 r
F P
0 g
s
.23483 .73218 m .23483 .71365 L .26667 .71287 L p .707 .577 .707 r
F P
0 g
s
.6747 .64651 m .6747 .60945 L .65365 .603 L p .707 .577 .707 r
F P
0 g
s
.26667 .71287 m .26667 .7314 L .23483 .73218 L p .707 .577 .707 r
F P
0 g
s
.73333 .73089 m .73333 .71236 L .70216 .71046 L p .707 .577 .707 r
F P
0 g
s
.73333 .71236 m .73333 .73089 L .76517 .73011 L p .707 .577 .707 r
F P
0 g
s
.76517 .73011 m .76517 .71158 L .73333 .71236 L p .707 .577 .707 r
F P
0 g
s
.59233 .30714 m .59233 .80903 L .55357 .80283 L p .707 .577 .707 r
F P
0 g
s
.55357 .80283 m .55357 .30094 L .59233 .30714 L p .707 .577 .707 r
F P
0 g
s
.65365 .60072 m .65365 .54514 L .64105 .53725 L p .707 .577 .707 r
F P
0 g
s
.76517 .71158 m .76517 .73011 L .79455 .72673 L p .707 .577 .707 r
F P
0 g
s
.79455 .72673 m .79455 .7082 L .76517 .71158 L p .707 .577 .707 r
F P
0 g
s
.70216 .71046 m .70216 .72899 L .73333 .73089 L p .707 .577 .707 r
F P
0 g
s
.65365 .603 m .65365 .64005 L .6747 .64651 L p .707 .577 .707 r
F P
0 g
s
.70216 .72899 m .70216 .71046 L .6747 .70607 L p .707 .577 .707 r
F P
0 g
s
.8186 .60594 m .8186 .643 L .83497 .63563 L p .707 .577 .707 r
F P
0 g
s
.83497 .63563 m .83497 .59857 L .8186 .60594 L p .707 .577 .707 r
F P
0 g
s
.6747 .70607 m .6747 .72459 L .70216 .72899 L p .707 .577 .707 r
F P
0 g
s
.42314 .80602 m .42314 .30413 L .46462 .29936 L p .707 .577 .707 r
F P
0 g
s
.42314 .30413 m .42314 .80602 L .38918 .81399 L p .707 .577 .707 r
F P
0 g
s
.79455 .7082 m .79455 .72673 L .8186 .72108 L p .707 .577 .707 r
F P
0 g
s
.8186 .72108 m .8186 .70255 L .79455 .7082 L p .707 .577 .707 r
F P
0 g
s
.64105 .53725 m .64105 .59284 L .65365 .60072 L p .707 .577 .707 r
F P
0 g
s
.83497 .54071 m .83497 .59629 L .84205 .58793 L p .707 .577 .707 r
F P
0 g
s
.84205 .58793 m .84205 .53235 L .83497 .54071 L p .707 .577 .707 r
F P
0 g
s
.65365 .64005 m .65365 .603 L .64105 .59512 L p .707 .577 .707 r
F P
0 g
s
.6747 .72459 m .6747 .70607 L .65365 .69961 L p .707 .577 .707 r
F P
0 g
s
.55357 .30094 m .55357 .80283 L .50956 .80015 L p .707 .577 .707 r
F P
0 g
s
.50956 .80015 m .50956 .29826 L .55357 .30094 L p .707 .577 .707 r
F P
0 g
s
.65365 .69961 m .65365 .71814 L .6747 .72459 L p .707 .577 .707 r
F P
0 g
s
.46462 .80125 m .46462 .29936 L .50956 .29826 L p .707 .577 .707 r
F P
0 g
s
.46462 .29936 m .46462 .80125 L .42314 .80602 L p .707 .577 .707 r
F P
0 g
s
.64105 .59512 m .64105 .63217 L .65365 .64005 L p .707 .577 .707 r
F P
0 g
s
.64105 .59284 m .64105 .53725 L .63816 .52871 L p .707 .577 .707 r
F P
0 g
s
.50956 .29826 m .50956 .80015 L .46462 .80125 L p .707 .577 .707 r
F P
0 g
s
.83497 .59857 m .83497 .63563 L .84205 .62726 L p .707 .577 .707 r
F P
0 g
s
.84205 .62726 m .84205 .59021 L .83497 .59857 L p .707 .577 .707 r
F P
0 g
s
.8186 .70255 m .8186 .72108 L .83497 .71371 L p .707 .577 .707 r
F P
0 g
s
.83497 .71371 m .83497 .69519 L .8186 .70255 L p .707 .577 .707 r
F P
0 g
s
.65365 .71814 m .65365 .69961 L .64105 .69173 L p .707 .577 .707 r
F P
0 g
s
.63816 .52871 m .63816 .58429 L .64105 .59284 L p .707 .577 .707 r
F P
0 g
s
.64105 .63217 m .64105 .59512 L .63816 .58657 L p .707 .577 .707 r
F P
0 g
s
.84205 .53235 m .84205 .58793 L .83916 .57939 L p .707 .577 .707 r
F P
0 g
s
.83916 .57939 m .83916 .52381 L .84205 .53235 L p .707 .577 .707 r
F P
0 g
s
.64105 .69173 m .64105 .71026 L .65365 .71814 L p .707 .577 .707 r
F P
0 g
s
.63816 .58657 m .63816 .62363 L .64105 .63217 L p .707 .577 .707 r
F P
0 g
s
.83497 .69519 m .83497 .71371 L .84206 .70535 L p .707 .577 .707 r
F P
0 g
s
.84206 .70535 m .84206 .68682 L .83497 .69519 L p .707 .577 .707 r
F P
0 g
s
.63816 .58429 m .63816 .52871 L .64524 .52035 L p .707 .577 .707 r
F P
0 g
s
.84205 .59021 m .84205 .62726 L .83916 .61872 L p .707 .577 .707 r
F P
0 g
s
.83916 .61872 m .83916 .58167 L .84205 .59021 L p .707 .577 .707 r
F P
0 g
s
.64105 .71026 m .64105 .69173 L .63816 .68319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .52035 m .64524 .57593 L .63816 .58429 L p .707 .577 .707 r
F P
0 g
s
.63816 .62363 m .63816 .58657 L .64524 .57821 L p .707 .577 .707 r
F P
0 g
s
.63816 .68319 m .63816 .70171 L .64105 .71026 L p .707 .577 .707 r
F P
0 g
s
.83916 .52381 m .83916 .57939 L .82657 .5715 L p .707 .577 .707 r
F P
0 g
s
.82657 .5715 m .82657 .51592 L .83916 .52381 L p .707 .577 .707 r
F P
0 g
s
.64524 .57821 m .64524 .61526 L .63816 .62363 L p .707 .577 .707 r
F P
0 g
s
.39032 .57665 m .39032 .52107 L .35915 .51917 L p .707 .577 .707 r
F P
0 g
s
.39032 .52107 m .39032 .57665 L .42216 .57588 L p .707 .577 .707 r
F P
0 g
s
.42216 .57588 m .42216 .52029 L .39032 .52107 L p .707 .577 .707 r
F P
0 g
s
.84206 .68682 m .84206 .70535 L .83916 .69681 L p .707 .577 .707 r
F P
0 g
s
.83916 .69681 m .83916 .67828 L .84206 .68682 L p .707 .577 .707 r
F P
0 g
s
.64524 .57593 m .64524 .52035 L .66161 .51298 L p .707 .577 .707 r
F P
0 g
s
.42216 .52029 m .42216 .57588 L .45154 .5725 L p .707 .577 .707 r
F P
0 g
s
.45154 .5725 m .45154 .51691 L .42216 .52029 L p .707 .577 .707 r
F P
0 g
s
.83916 .58167 m .83916 .61872 L .82657 .61084 L p .707 .577 .707 r
F P
0 g
s
.82657 .61084 m .82657 .57378 L .83916 .58167 L p .707 .577 .707 r
F P
0 g
s
.35915 .57475 m .35915 .51917 L .33169 .51478 L p .707 .577 .707 r
F P
0 g
s
.35915 .51917 m .35915 .57475 L .39032 .57665 L p .707 .577 .707 r
F P
0 g
s
.45154 .51691 m .45154 .5725 L .47559 .56685 L p .707 .577 .707 r
F P
0 g
s
.47559 .56685 m .47559 .51126 L .45154 .51691 L p .707 .577 .707 r
F P
0 g
s
.63816 .70171 m .63816 .68319 L .64524 .67482 L p .707 .577 .707 r
F P
0 g
s
.39032 .61599 m .39032 .57893 L .35915 .57703 L p .707 .577 .707 r
F P
0 g
s
.39032 .57893 m .39032 .61599 L .42216 .61521 L p .707 .577 .707 r
F P
0 g
s
.42216 .61521 m .42216 .57815 L .39032 .57893 L p .707 .577 .707 r
F P
0 g
s
.66161 .51298 m .66161 .56856 L .64524 .57593 L p .707 .577 .707 r
F P
0 g
s
.82657 .51592 m .82657 .5715 L .80551 .56505 L p .707 .577 .707 r
F P
0 g
s
.80551 .56505 m .80551 .50947 L .82657 .51592 L p .707 .577 .707 r
F P
0 g
s
.64524 .61526 m .64524 .57821 L .66161 .57084 L p .707 .577 .707 r
F P
0 g
s
.42216 .57815 m .42216 .61521 L .45154 .61183 L p .707 .577 .707 r
F P
0 g
s
.45154 .61183 m .45154 .57477 L .42216 .57815 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .67482 m .64524 .69335 L .63816 .70171 L p .707 .577 .707 r
F P
0 g
s
.33169 .51478 m .33169 .57036 L .35915 .57475 L p .707 .577 .707 r
F P
0 g
s
.33169 .57036 m .33169 .51478 L .31064 .50832 L p .707 .577 .707 r
F P
0 g
s
.35915 .61408 m .35915 .57703 L .33169 .57264 L p .707 .577 .707 r
F P
0 g
s
.35915 .57703 m .35915 .61408 L .39032 .61599 L p .707 .577 .707 r
F P
0 g
s
.66161 .57084 m .66161 .6079 L .64524 .61526 L p .707 .577 .707 r
F P
0 g
s
.66161 .56856 m .66161 .51298 L .68566 .50733 L p .707 .577 .707 r
F P
0 g
s
.45154 .57477 m .45154 .61183 L .47559 .60618 L p .707 .577 .707 r
F P
0 g
s
.47559 .60618 m .47559 .56912 L .45154 .57477 L p .707 .577 .707 r
F P
0 g
s
.83916 .67828 m .83916 .69681 L .82657 .68892 L p .707 .577 .707 r
F P
0 g
s
.82657 .68892 m .82657 .6704 L .83916 .67828 L p .707 .577 .707 r
F P
0 g
s
.33169 .57264 m .33169 .60969 L .35915 .61408 L p .707 .577 .707 r
F P
0 g
s
.82657 .57378 m .82657 .61084 L .80551 .60438 L p .707 .577 .707 r
F P
0 g
s
.80551 .60438 m .80551 .56733 L .82657 .57378 L p .707 .577 .707 r
F P
0 g
s
.47559 .51126 m .47559 .56685 L .49196 .55948 L p .707 .577 .707 r
F P
0 g
s
.49196 .55948 m .49196 .5039 L .47559 .51126 L p .707 .577 .707 r
F P
0 g
s
.31064 .50832 m .31064 .56391 L .33169 .57036 L p .707 .577 .707 r
F P
0 g
s
.33169 .60969 m .33169 .57264 L .31064 .56618 L p .707 .577 .707 r
F P
0 g
s
.80551 .50947 m .80551 .56505 L .77805 .56066 L p .707 .577 .707 r
F P
0 g
s
.77805 .56066 m .77805 .50507 L .80551 .50947 L p .707 .577 .707 r
F P
0 g
s
.39032 .69407 m .39032 .67554 L .35915 .67364 L p .707 .577 .707 r
F P
0 g
s
.39032 .67554 m .39032 .69407 L .42216 .69329 L p .707 .577 .707 r
F P
0 g
s
.42216 .69329 m .42216 .67477 L .39032 .67554 L p .707 .577 .707 r
F P
0 g
s
.68566 .50733 m .68566 .56291 L .66161 .56856 L p .707 .577 .707 r
F P
0 g
s
.66161 .6079 m .66161 .57084 L .68566 .56519 L p .707 .577 .707 r
F P
0 g
s
.64524 .69335 m .64524 .67482 L .66161 .66745 L p .707 .577 .707 r
F P
0 g
s
.31064 .56391 m .31064 .50832 L .29804 .50044 L p .707 .577 .707 r
F P
0 g
s
.42216 .67477 m .42216 .69329 L .45154 .68992 L p .707 .577 .707 r
F P
0 g
s
.45154 .68992 m .45154 .67139 L .42216 .67477 L p .707 .577 .707 r
F P
0 g
s
.35915 .67364 m .35915 .69217 L .39032 .69407 L p .707 .577 .707 r
F P
0 g
s
.31064 .56618 m .31064 .60324 L .33169 .60969 L p .707 .577 .707 r
F P
0 g
s
.68566 .56291 m .68566 .50733 L .71504 .50395 L p .707 .577 .707 r
F P
0 g
s
.35915 .69217 m .35915 .67364 L .33169 .66925 L p .707 .577 .707 r
F P
0 g
s
.66161 .66745 m .66161 .68598 L .64524 .69335 L p .707 .577 .707 r
F P
0 g
s
.47559 .56912 m .47559 .60618 L .49196 .59881 L p .707 .577 .707 r
F P
0 g
s
.49196 .59881 m .49196 .56176 L .47559 .56912 L p .707 .577 .707 r
F P
0 g
s
.33169 .66925 m .33169 .68778 L .35915 .69217 L p .707 .577 .707 r
F P
0 g
s
.68566 .56519 m .68566 .60225 L .66161 .6079 L p .707 .577 .707 r
F P
0 g
s
.77805 .50507 m .77805 .56066 L .74688 .55876 L p .707 .577 .707 r
F P
0 g
s
.74688 .55876 m .74688 .50317 L .77805 .50507 L p .707 .577 .707 r
F P
0 g
s
.80551 .56733 m .80551 .60438 L .77805 .59999 L p .707 .577 .707 r
F P
0 g
s
.77805 .59999 m .77805 .56294 L .80551 .56733 L p .707 .577 .707 r
F P
0 g
s
.45154 .67139 m .45154 .68992 L .47559 .68427 L p .707 .577 .707 r
F P
0 g
s
.47559 .68427 m .47559 .66574 L .45154 .67139 L p .707 .577 .707 r
F P
0 g
s
.29804 .50044 m .29804 .55602 L .31064 .56391 L p .707 .577 .707 r
F P
0 g
s
.71504 .55953 m .71504 .50395 L .74688 .50317 L p .707 .577 .707 r
F P
0 g
s
.71504 .50395 m .71504 .55953 L .68566 .56291 L p .707 .577 .707 r
F P
0 g
s
.82657 .6704 m .82657 .68892 L .80551 .68247 L p .707 .577 .707 r
F P
0 g
s
.80551 .68247 m .80551 .66394 L .82657 .6704 L p .707 .577 .707 r
F P
0 g
s
.49196 .5039 m .49196 .55948 L .49904 .55111 L p .707 .577 .707 r
F P
0 g
s
.49904 .55111 m .49904 .49553 L .49196 .5039 L p .707 .577 .707 r
F P
0 g
s
.31064 .60324 m .31064 .56618 L .29804 .5583 L p .707 .577 .707 r
F P
0 g
s
.74688 .50317 m .74688 .55876 L .71504 .55953 L p .707 .577 .707 r
F P
0 g
s
.68566 .60225 m .68566 .56519 L .71504 .56181 L p .707 .577 .707 r
F P
0 g
s
.33169 .68778 m .33169 .66925 L .31064 .6628 L p .707 .577 .707 r
F P
0 g
s
.31064 .6628 m .31064 .68132 L .33169 .68778 L p .707 .577 .707 r
F P
0 g
s
.66161 .68598 m .66161 .66745 L .68566 .6618 L p .707 .577 .707 r
F P
0 g
s
.29804 .5583 m .29804 .59535 L .31064 .60324 L p .707 .577 .707 r
F P
0 g
s
.77805 .56294 m .77805 .59999 L .74688 .59809 L p .707 .577 .707 r
F P
0 g
s
.74688 .59809 m .74688 .56103 L .77805 .56294 L p .707 .577 .707 r
F P
0 g
s
.29804 .55602 m .29804 .50044 L .29515 .4919 L p .707 .577 .707 r
F P
0 g
s
.71504 .56181 m .71504 .59887 L .68566 .60225 L p .707 .577 .707 r
F P
0 g
s
.68566 .6618 m .68566 .68033 L .66161 .68598 L p .707 .577 .707 r
F P
0 g
s
.71504 .59887 m .71504 .56181 L .74688 .56103 L p .707 .577 .707 r
F P
0 g
s
.49196 .56176 m .49196 .59881 L .49904 .59045 L p .707 .577 .707 r
F P
0 g
s
.49904 .59045 m .49904 .55339 L .49196 .56176 L p .707 .577 .707 r
F P
0 g
s
.47559 .66574 m .47559 .68427 L .49196 .6769 L p .707 .577 .707 r
F P
0 g
s
.49196 .6769 m .49196 .65837 L .47559 .66574 L p .707 .577 .707 r
F P
0 g
s
.74688 .56103 m .74688 .59809 L .71504 .59887 L p .707 .577 .707 r
F P
0 g
s
.80551 .66394 m .80551 .68247 L .77805 .67808 L p .707 .577 .707 r
F P
0 g
s
.77805 .67808 m .77805 .65955 L .80551 .66394 L p .707 .577 .707 r
F P
0 g
s
.31064 .68132 m .31064 .6628 L .29804 .65491 L p .707 .577 .707 r
F P
0 g
s
.29515 .4919 m .29515 .54748 L .29804 .55602 L p .707 .577 .707 r
F P
0 g
s
.29804 .59535 m .29804 .5583 L .29515 .54976 L p .707 .577 .707 r
F P
0 g
s
.49904 .49553 m .49904 .55111 L .49615 .54257 L p .707 .577 .707 r
F P
0 g
s
.49615 .54257 m .49615 .48699 L .49904 .49553 L p .707 .577 .707 r
F P
0 g
s
.68566 .68033 m .68566 .6618 L .71504 .65843 L p .707 .577 .707 r
F P
0 g
s
.29804 .65491 m .29804 .67344 L .31064 .68132 L p .707 .577 .707 r
F P
0 g
s
.71504 .65843 m .71504 .67695 L .68566 .68033 L p .707 .577 .707 r
F P
0 g
s
.77805 .65955 m .77805 .67808 L .74688 .67618 L p .707 .577 .707 r
F P
0 g
s
.74688 .67618 m .74688 .65765 L .77805 .65955 L p .707 .577 .707 r
F P
0 g
s
.29515 .54976 m .29515 .58681 L .29804 .59535 L p .707 .577 .707 r
F P
0 g
s
.71504 .67695 m .71504 .65843 L .74688 .65765 L p .707 .577 .707 r
F P
0 g
s
.49196 .65837 m .49196 .6769 L .49904 .66853 L p .707 .577 .707 r
F P
0 g
s
.49904 .66853 m .49904 .65001 L .49196 .65837 L p .707 .577 .707 r
F P
0 g
s
.29515 .54748 m .29515 .4919 L .30223 .48353 L p .707 .577 .707 r
F P
0 g
s
.74688 .65765 m .74688 .67618 L .71504 .67695 L p .707 .577 .707 r
F P
0 g
s
.49904 .55339 m .49904 .59045 L .49615 .58191 L p .707 .577 .707 r
F P
0 g
s
.49615 .58191 m .49615 .54485 L .49904 .55339 L p .707 .577 .707 r
F P
0 g
s
.29804 .67344 m .29804 .65491 L .29515 .64637 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48353 m .30223 .53911 L .29515 .54748 L p .707 .577 .707 r
F P
0 g
s
.29515 .58681 m .29515 .54976 L .30223 .54139 L p .707 .577 .707 r
F P
0 g
s
.29515 .64637 m .29515 .6649 L .29804 .67344 L p .707 .577 .707 r
F P
0 g
s
.49615 .48699 m .49615 .54257 L .48356 .53469 L p .707 .577 .707 r
F P
0 g
s
.48356 .53469 m .48356 .47911 L .49615 .48699 L p .707 .577 .707 r
F P
0 g
s
.30223 .54139 m .30223 .57845 L .29515 .58681 L p .707 .577 .707 r
F P
0 g
s
.49904 .65001 m .49904 .66853 L .49615 .65999 L p .707 .577 .707 r
F P
0 g
s
.49615 .65999 m .49615 .64146 L .49904 .65001 L p .707 .577 .707 r
F P
0 g
s
.30223 .53911 m .30223 .48353 L .3186 .47616 L p .707 .577 .707 r
F P
0 g
s
.49615 .54485 m .49615 .58191 L .48356 .57402 L p .707 .577 .707 r
F P
0 g
s
.48356 .57402 m .48356 .53697 L .49615 .54485 L p .707 .577 .707 r
F P
0 g
s
.29515 .6649 m .29515 .64637 L .30223 .63801 L p .707 .577 .707 r
F P
0 g
s
.3186 .47616 m .3186 .53175 L .30223 .53911 L p .707 .577 .707 r
F P
0 g
s
.48356 .47911 m .48356 .53469 L .4625 .52823 L p .707 .577 .707 r
F P
0 g
s
.4625 .52823 m .4625 .47265 L .48356 .47911 L p .707 .577 .707 r
F P
0 g
s
.30223 .57845 m .30223 .54139 L .3186 .53402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .63801 m .30223 .65653 L .29515 .6649 L p .707 .577 .707 r
F P
0 g
s
.3186 .53402 m .3186 .57108 L .30223 .57845 L p .707 .577 .707 r
F P
0 g
s
.3186 .53175 m .3186 .47616 L .34265 .47051 L p .707 .577 .707 r
F P
0 g
s
.49615 .64146 m .49615 .65999 L .48356 .65211 L p .707 .577 .707 r
F P
0 g
s
.48356 .65211 m .48356 .63358 L .49615 .64146 L p .707 .577 .707 r
F P
0 g
s
.48356 .53697 m .48356 .57402 L .4625 .56757 L p .707 .577 .707 r
F P
0 g
s
.4625 .56757 m .4625 .53051 L .48356 .53697 L p .707 .577 .707 r
F P
0 g
s
.4625 .47265 m .4625 .52823 L .43504 .52384 L p .707 .577 .707 r
F P
0 g
s
.43504 .52384 m .43504 .46826 L .4625 .47265 L p .707 .577 .707 r
F P
0 g
s
.34265 .47051 m .34265 .5261 L .3186 .53175 L p .707 .577 .707 r
F P
0 g
s
.3186 .57108 m .3186 .53402 L .34265 .52838 L p .707 .577 .707 r
F P
0 g
s
.30223 .65653 m .30223 .63801 L .3186 .63064 L p .707 .577 .707 r
F P
0 g
s
.34265 .5261 m .34265 .47051 L .37203 .46714 L p .707 .577 .707 r
F P
0 g
s
.3186 .63064 m .3186 .64917 L .30223 .65653 L p .707 .577 .707 r
F P
0 g
s
.34265 .52838 m .34265 .56543 L .3186 .57108 L p .707 .577 .707 r
F P
0 g
s
.43504 .46826 m .43504 .52384 L .40387 .52194 L p .707 .577 .707 r
F P
0 g
s
.40387 .52194 m .40387 .46636 L .43504 .46826 L p .707 .577 .707 r
F P
0 g
s
.4625 .53051 m .4625 .56757 L .43504 .56317 L p .707 .577 .707 r
F P
0 g
s
.43504 .56317 m .43504 .52612 L .4625 .53051 L p .707 .577 .707 r
F P
0 g
s
.37203 .52272 m .37203 .46714 L .40387 .46636 L p .707 .577 .707 r
F P
0 g
s
.37203 .46714 m .37203 .52272 L .34265 .5261 L p .707 .577 .707 r
F P
0 g
s
.48356 .63358 m .48356 .65211 L .4625 .64565 L p .707 .577 .707 r
F P
0 g
s
.4625 .64565 m .4625 .62713 L .48356 .63358 L p .707 .577 .707 r
F P
0 g
s
.40387 .46636 m .40387 .52194 L .37203 .52272 L p .707 .577 .707 r
F P
0 g
s
.34265 .56543 m .34265 .52838 L .37203 .525 L p .707 .577 .707 r
F P
0 g
s
.3186 .64917 m .3186 .63064 L .34265 .62499 L p .707 .577 .707 r
F P
0 g
s
.43504 .52612 m .43504 .56317 L .40387 .56127 L p .707 .577 .707 r
F P
0 g
s
.40387 .56127 m .40387 .52422 L .43504 .52612 L p .707 .577 .707 r
F P
0 g
s
.37203 .525 m .37203 .56205 L .34265 .56543 L p .707 .577 .707 r
F P
0 g
s
.34265 .62499 m .34265 .64352 L .3186 .64917 L p .707 .577 .707 r
F P
0 g
s
.37203 .56205 m .37203 .525 L .40387 .52422 L p .707 .577 .707 r
F P
0 g
s
.40387 .52422 m .40387 .56127 L .37203 .56205 L p .707 .577 .707 r
F P
0 g
s
.4625 .62713 m .4625 .64565 L .43504 .64126 L p .707 .577 .707 r
F P
0 g
s
.43504 .64126 m .43504 .62273 L .4625 .62713 L p .707 .577 .707 r
F P
0 g
s
.34265 .64352 m .34265 .62499 L .37203 .62161 L p .707 .577 .707 r
F P
0 g
s
.37203 .62161 m .37203 .64014 L .34265 .64352 L p .707 .577 .707 r
F P
0 g
s
.43504 .62273 m .43504 .64126 L .40387 .63936 L p .707 .577 .707 r
F P
0 g
s
.40387 .63936 m .40387 .62083 L .43504 .62273 L p .707 .577 .707 r
F P
0 g
s
.37203 .64014 m .37203 .62161 L .40387 .62083 L p .707 .577 .707 r
F P
0 g
s
.40387 .62083 m .40387 .63936 L .37203 .64014 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001/Ool30009FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03
001JEUYF00=JER40009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005=oo`03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo
2@000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool003Uoo`h000AJEP03001JEUYF009JEP@00003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03
FUH70007FUH50004FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPL0
00AJEP03001JEUYF00IJEP03001JEUYF009JEPd000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000<0
00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH60000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF200000=JEP00FUH00UYF
0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH90004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH;00000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEP0000T000AJEP@0009JEPh000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH400000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH0
0eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00;Goo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008FUH50004FUH00`00FUIJEP05FUH50004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH80004FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUH0000500000eYF001JEP02FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20003FUH>0004FUH40005FUH00`00FUIJEP02FUH70003FUH30003FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EPP000AJEP03001JEUYF00=JEPh0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUHK0003FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EQl000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH000090004FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF01800003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF00000eYF1`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF30000eYF00<005YF
FUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
0000;Goo000/Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF00000`0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF0000
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH50006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH40000
0eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2@000eYF00@005YF001JEP8000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP03
001JEP0001P003moo`00;7oo00<005YF000015YF00<005YFFUH00eYF4`0015YF100000AJEP000000
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001`0015YF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<005YF00000`0000=JEP000000100015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPP00003FUH005YF009JEQX003aoo`00;7oo00<005YF00000eYF2@0015YF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEPX00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00001`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;7oo00@005YF001JEP8000AJEPd000AJEP@0
009JEPP000=JEP03001JEP00008000=JEP<0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`06001JEP00001JEP001EYF00@0
05YFFUIJEQX000=JEP03001JEUYF009JEPD00004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000b
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH00eYF2@000eYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`8000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJ
EP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04001JEUYFFUH2000J
Ool40003FUH01000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPD000AJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000NOol40003
FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000L000AJEPD000EJEP03001JEUYF009J
EPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Woo00<005YFFUH0
0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEP00018000MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00AJEP04001JEUYFFUH2000SOol4000]Ool003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000020003FUH01000FUIJEUYF
0P008Goo0P0000AJEP00000002eoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF00000`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEP0000P000=JEP8001ioo`<000=JEP<002eoo`00>goo200015YF00<005YFFUH0
1eYF00<005YFFUH00UYF1@002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF009JEP@0009JEP03001JEUYF008001Yoo`@00003FUH005YF00=JEP03001JEP00
02eoo`00@goo4`003goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEP0000L001Eoo`D000EJEP03001JEUYF009JEP8002ioo`00?goo4@005Goo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uoo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000`Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP04001JEUYFFUH4000dOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF1@0015YF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH0000J000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000Uoo`P000AJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`03001JEP0000AJEP04001JEUYFFUH8000I
Ool60004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEP@005]oo`00;7oo00<005YF00000eYF1@009goo0`0000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H005moo`00
;7oo00@005YF001JEP8002moo`80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`@003Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008006=oo`00;7oo0P000UYF0`00;goo10000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool20003
FUH00`00FUH00002000YOol30002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00005FUH00`00FUH00002001KOol002aoo`8000=JEP03001JEUYF009JEPD0021o
o`@00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8
000COol50005FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF0P00F7oo000^Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEP00001F
Ool0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000100000=JEP00FUH015YF00D005YFFUIJEP0005Eoo`00<goo0`0000=JEP00FUH01UYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000AJEP05001JEUYFFUH0001EOol0
03Ioo`D000AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEP0000<000Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001JEP02FUH2
001DOol003]oo`P000AJEPD000EJEP03001JEUYF009JEPD000Yoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2001DOol004=ooa<000moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000<Ool200000eYF0000001DOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;Ool2000015YF0000
0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
0`000eYF0`00E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000017oo100000=JEP00FUH00eYF00<005YF0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH01eYF5@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010001EYF00<005YFFUH00UYF0P00EGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00@005YFFUIJEPH000UJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEUYFFUH2001F
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH01000FUH00000F7oo001UOol01000FUIJEP001EYF0`000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEPD005Yoo`00IGoo00@005YFFUH000=JEP8000EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001J
EP0000H005moo`00IGoo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0001U
Ool006Eoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo06Aoo`00
IGoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo001UOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`1TOol006Eoo`8000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Io
o`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00Igoo001WOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Uoo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2001ZOol006]o
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEP00001/Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00LGoo1@0025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@00LWoo001fOol60002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001gOol007aoo`T000IJEP03001JEUYF00YJEP03001J
EUYF00H007aoo`00QGoo5P00PWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70551 m .59613 .64992 L .56496 .64802 L p .707 .577 .707 r
F P
0 g
s
.59613 .64992 m .59613 .70551 L .62796 .70473 L p .707 .577 .707 r
F P
0 g
s
.62796 .70473 m .62796 .64915 L .59613 .64992 L p .707 .577 .707 r
F P
0 g
s
.62796 .64915 m .62796 .70473 L .65734 .70135 L p .707 .577 .707 r
F P
0 g
s
.65734 .70135 m .65734 .64577 L .62796 .64915 L p .707 .577 .707 r
F P
0 g
s
.56496 .70361 m .56496 .64802 L .5375 .64363 L p .707 .577 .707 r
F P
0 g
s
.56496 .64802 m .56496 .70361 L .59613 .70551 L p .707 .577 .707 r
F P
0 g
s
.65734 .64577 m .65734 .70135 L .6814 .6957 L p .707 .577 .707 r
F P
0 g
s
.6814 .6957 m .6814 .64012 L .65734 .64577 L p .707 .577 .707 r
F P
0 g
s
.59613 .74484 m .59613 .70778 L .56496 .70588 L p .707 .577 .707 r
F P
0 g
s
.59613 .70778 m .59613 .74484 L .62796 .74406 L p .707 .577 .707 r
F P
0 g
s
.62796 .74406 m .62796 .70701 L .59613 .70778 L p .707 .577 .707 r
F P
0 g
s
.62796 .70701 m .62796 .74406 L .65735 .74068 L p .707 .577 .707 r
F P
0 g
s
.65735 .74068 m .65734 .70363 L .62796 .70701 L p .707 .577 .707 r
F P
0 g
s
.5375 .64363 m .5375 .69921 L .56496 .70361 L p .707 .577 .707 r
F P
0 g
s
.5375 .69921 m .5375 .64363 L .51644 .63718 L p .707 .577 .707 r
F P
0 g
s
.56496 .74294 m .56496 .70588 L .5375 .70149 L p .707 .577 .707 r
F P
0 g
s
.56496 .70588 m .56496 .74294 L .59613 .74484 L p .707 .577 .707 r
F P
0 g
s
.65734 .70363 m .65735 .74068 L .6814 .73503 L p .707 .577 .707 r
F P
0 g
s
.6814 .73503 m .6814 .69798 L .65734 .70363 L p .707 .577 .707 r
F P
0 g
s
.5375 .70149 m .5375 .73855 L .56496 .74294 L p .707 .577 .707 r
F P
0 g
s
.6814 .64012 m .6814 .6957 L .69777 .68833 L p .707 .577 .707 r
F P
0 g
s
.69777 .68833 m .69777 .63275 L .6814 .64012 L p .707 .577 .707 r
F P
0 g
s
.51644 .63718 m .51644 .69276 L .5375 .69921 L p .707 .577 .707 r
F P
0 g
s
.5375 .73855 m .5375 .70149 L .51644 .69504 L p .707 .577 .707 r
F P
0 g
s
.59613 .82292 m .59613 .8044 L .56496 .8025 L p .707 .577 .707 r
F P
0 g
s
.59613 .8044 m .59613 .82292 L .62796 .82215 L p .707 .577 .707 r
F P
0 g
s
.62796 .82215 m .62796 .80362 L .59613 .8044 L p .707 .577 .707 r
F P
0 g
s
.51644 .69276 m .51644 .63718 L .50385 .62929 L p .707 .577 .707 r
F P
0 g
s
.62796 .80362 m .62796 .82215 L .65735 .81877 L p .707 .577 .707 r
F P
0 g
s
.65735 .81877 m .65735 .80024 L .62796 .80362 L p .707 .577 .707 r
F P
0 g
s
.56496 .8025 m .56496 .82102 L .59613 .82292 L p .707 .577 .707 r
F P
0 g
s
.51644 .69504 m .51644 .73209 L .5375 .73855 L p .707 .577 .707 r
F P
0 g
s
.56496 .82102 m .56496 .8025 L .5375 .7981 L p .707 .577 .707 r
F P
0 g
s
.6814 .69798 m .6814 .73503 L .69777 .72767 L p .707 .577 .707 r
F P
0 g
s
.69777 .72767 m .69777 .69061 L .6814 .69798 L p .707 .577 .707 r
F P
0 g
s
.5375 .7981 m .5375 .81663 L .56496 .82102 L p .707 .577 .707 r
F P
0 g
s
.65735 .80024 m .65735 .81877 L .6814 .81312 L p .707 .577 .707 r
F P
0 g
s
.6814 .81312 m .6814 .79459 L .65735 .80024 L p .707 .577 .707 r
F P
0 g
s
.50385 .62929 m .50385 .68488 L .51644 .69276 L p .707 .577 .707 r
F P
0 g
s
.69777 .63275 m .69777 .68833 L .70485 .67997 L p .707 .577 .707 r
F P
0 g
s
.70485 .67997 m .70485 .62439 L .69777 .63275 L p .707 .577 .707 r
F P
0 g
s
.51644 .73209 m .51644 .69504 L .50385 .68715 L p .707 .577 .707 r
F P
0 g
s
.5375 .81663 m .5375 .7981 L .51644 .79165 L p .707 .577 .707 r
F P
0 g
s
.51644 .79165 m .51644 .81018 L .5375 .81663 L p .707 .577 .707 r
F P
0 g
s
.50385 .68715 m .50385 .72421 L .51644 .73209 L p .707 .577 .707 r
F P
0 g
s
.50385 .68488 m .50385 .62929 L .50095 .62075 L p .707 .577 .707 r
F P
0 g
s
.69777 .69061 m .69777 .72767 L .70485 .7193 L p .707 .577 .707 r
F P
0 g
s
.70485 .7193 m .70485 .68225 L .69777 .69061 L p .707 .577 .707 r
F P
0 g
s
.6814 .79459 m .6814 .81312 L .69777 .80575 L p .707 .577 .707 r
F P
0 g
s
.69777 .80575 m .69777 .78722 L .6814 .79459 L p .707 .577 .707 r
F P
0 g
s
.51644 .81018 m .51644 .79165 L .50385 .78377 L p .707 .577 .707 r
F P
0 g
s
.50095 .62075 m .50095 .67633 L .50385 .68488 L p .707 .577 .707 r
F P
0 g
s
.50385 .72421 m .50385 .68715 L .50095 .67861 L p .707 .577 .707 r
F P
0 g
s
.70485 .62439 m .70485 .67997 L .70195 .67143 L p .707 .577 .707 r
F P
0 g
s
.70195 .67143 m .70195 .61584 L .70485 .62439 L p .707 .577 .707 r
F P
0 g
s
.50385 .78377 m .50385 .80229 L .51644 .81018 L p .707 .577 .707 r
F P
0 g
s
.50095 .67861 m .50095 .71567 L .50385 .72421 L p .707 .577 .707 r
F P
0 g
s
.69777 .78722 m .69777 .80575 L .70485 .79739 L p .707 .577 .707 r
F P
0 g
s
.70485 .79739 m .70485 .77886 L .69777 .78722 L p .707 .577 .707 r
F P
0 g
s
.50095 .67633 m .50095 .62075 L .50804 .61239 L p .707 .577 .707 r
F P
0 g
s
.70485 .68225 m .70485 .7193 L .70195 .71076 L p .707 .577 .707 r
F P
0 g
s
.70195 .71076 m .70195 .6737 L .70485 .68225 L p .707 .577 .707 r
F P
0 g
s
.50385 .80229 m .50385 .78377 L .50095 .77522 L p .707 .577 .707 r
F P
0 g
s
.50804 .61239 m .50804 .66797 L .50095 .67633 L p .707 .577 .707 r
F P
0 g
s
.50095 .71567 m .50095 .67861 L .50804 .67025 L p .707 .577 .707 r
F P
0 g
s
.50095 .77522 m .50095 .79375 L .50385 .80229 L p .707 .577 .707 r
F P
0 g
s
.70195 .61584 m .70195 .67143 L .68936 .66354 L p .707 .577 .707 r
F P
0 g
s
.68936 .66354 m .68936 .60796 L .70195 .61584 L p .707 .577 .707 r
F P
0 g
s
.49044 .87739 m .49044 .3755 L .44643 .37282 L p .707 .577 .707 r
F P
0 g
s
.50804 .67025 m .50804 .7073 L .50095 .71567 L p .707 .577 .707 r
F P
0 g
s
.50804 .66797 m .50804 .61239 L .5244 .60502 L p .707 .577 .707 r
F P
0 g
s
.50095 .79375 m .50095 .77522 L .50804 .76686 L p .707 .577 .707 r
F P
0 g
s
.5244 .60502 m .5244 .6606 L .50804 .66797 L p .707 .577 .707 r
F P
0 g
s
.50804 .7073 m .50804 .67025 L .5244 .66288 L p .707 .577 .707 r
F P
0 g
s
.50804 .76686 m .50804 .78539 L .50095 .79375 L p .707 .577 .707 r
F P
0 g
s
.5244 .66288 m .5244 .69993 L .50804 .7073 L p .707 .577 .707 r
F P
0 g
s
.50804 .78539 m .50804 .76686 L .5244 .75949 L p .707 .577 .707 r
F P
0 g
s
.5244 .75949 m .5244 .77802 L .50804 .78539 L p .707 .577 .707 r
F P
0 g
s
.5244 .77802 m .5244 .75949 L .54846 .75384 L p .707 .577 .707 r
F P
0 g
s
.54846 .75384 m .54846 .77237 L .5244 .77802 L p .707 .577 .707 r
F P
0 g
s
.49044 .3755 m .49044 .87739 L .53538 .87629 L p .707 .577 .707 r
F P
0 g
s
.5244 .6606 m .5244 .60502 L .54846 .59937 L p .707 .577 .707 r
F P
0 g
s
.54846 .59937 m .54846 .65495 L .5244 .6606 L p .707 .577 .707 r
F P
0 g
s
.5244 .69993 m .5244 .66288 L .54846 .65723 L p .707 .577 .707 r
F P
0 g
s
.54846 .65723 m .54846 .69428 L .5244 .69993 L p .707 .577 .707 r
F P
0 g
s
.53538 .87629 m .53538 .3744 L .49044 .3755 L p .707 .577 .707 r
F P
0 g
s
.25312 .66869 m .25312 .61311 L .22195 .61121 L p .707 .577 .707 r
F P
0 g
s
.25312 .61311 m .25312 .66869 L .28495 .66791 L p .707 .577 .707 r
F P
0 g
s
.28495 .66791 m .28495 .61233 L .25312 .61311 L p .707 .577 .707 r
F P
0 g
s
.54846 .65495 m .54846 .59937 L .57784 .59599 L p .707 .577 .707 r
F P
0 g
s
.57784 .59599 m .57784 .65157 L .54846 .65495 L p .707 .577 .707 r
F P
0 g
s
.54846 .69428 m .54846 .65723 L .57784 .65385 L p .707 .577 .707 r
F P
0 g
s
.57784 .65385 m .57784 .69091 L .54846 .69428 L p .707 .577 .707 r
F P
0 g
s
.54846 .77237 m .54846 .75384 L .57784 .75046 L p .707 .577 .707 r
F P
0 g
s
.57784 .75046 m .57784 .76899 L .54846 .77237 L p .707 .577 .707 r
F P
0 g
s
.53538 .3744 m .53538 .87629 L .57686 .87152 L p .707 .577 .707 r
F P
0 g
s
.57686 .87152 m .57686 .36963 L .53538 .3744 L p .707 .577 .707 r
F P
0 g
s
.70485 .77886 m .70485 .79739 L .70195 .78884 L p .707 .577 .707 r
F P
0 g
s
.70195 .78884 m .70195 .77032 L .70485 .77886 L p .707 .577 .707 r
F P
0 g
s
.28495 .61233 m .28495 .66791 L .31434 .66454 L p .707 .577 .707 r
F P
0 g
s
.31434 .66454 m .31434 .60895 L .28495 .61233 L p .707 .577 .707 r
F P
0 g
s
.70195 .6737 m .70195 .71076 L .68936 .70288 L p .707 .577 .707 r
F P
0 g
s
.68936 .70288 m .68936 .66582 L .70195 .6737 L p .707 .577 .707 r
F P
0 g
s
.44643 .8747 m .44643 .37282 L .40766 .36661 L p .707 .577 .707 r
F P
0 g
s
.44643 .37282 m .44643 .8747 L .49044 .87739 L p .707 .577 .707 r
F P
0 g
s
.22195 .66679 m .22195 .61121 L .19449 .60682 L p .707 .577 .707 r
F P
0 g
s
.22195 .61121 m .22195 .66679 L .25312 .66869 L p .707 .577 .707 r
F P
0 g
s
.31434 .60895 m .31434 .66454 L .33839 .65889 L p .707 .577 .707 r
F P
0 g
s
.33839 .65889 m .33839 .6033 L .31434 .60895 L p .707 .577 .707 r
F P
0 g
s
.25312 .70802 m .25312 .67097 L .22195 .66907 L p .707 .577 .707 r
F P
0 g
s
.25312 .67097 m .25312 .70802 L .28495 .70725 L p .707 .577 .707 r
F P
0 g
s
.28495 .70725 m .28495 .67019 L .25312 .67097 L p .707 .577 .707 r
F P
0 g
s
.57784 .65157 m .57784 .59599 L .60968 .59521 L p .707 .577 .707 r
F P
0 g
s
.60968 .59521 m .60968 .6508 L .57784 .65157 L p .707 .577 .707 r
F P
0 g
s
.57784 .69091 m .57784 .65385 L .60968 .65307 L p .707 .577 .707 r
F P
0 g
s
.60968 .65307 m .60968 .69013 L .57784 .69091 L p .707 .577 .707 r
F P
0 g
s
.57784 .76899 m .57784 .75046 L .60968 .74969 L p .707 .577 .707 r
F P
0 g
s
.60968 .74969 m .60968 .76821 L .57784 .76899 L p .707 .577 .707 r
F P
0 g
s
.57686 .36963 m .57686 .87152 L .61082 .86354 L p .707 .577 .707 r
F P
0 g
s
.64085 .59711 m .64085 .6527 L .60968 .6508 L p .707 .577 .707 r
F P
0 g
s
.60968 .6508 m .60968 .59521 L .64085 .59711 L p .707 .577 .707 r
F P
0 g
s
.64085 .65497 m .64085 .69203 L .60968 .69013 L p .707 .577 .707 r
F P
0 g
s
.60968 .69013 m .60968 .65307 L .64085 .65497 L p .707 .577 .707 r
F P
0 g
s
.64085 .75159 m .64085 .77011 L .60968 .76821 L p .707 .577 .707 r
F P
0 g
s
.60968 .76821 m .60968 .74969 L .64085 .75159 L p .707 .577 .707 r
F P
0 g
s
.61082 .86354 m .61082 .36165 L .57686 .36963 L p .707 .577 .707 r
F P
0 g
s
.68936 .60796 m .68936 .66354 L .66831 .65709 L p .707 .577 .707 r
F P
0 g
s
.66831 .65709 m .66831 .60151 L .68936 .60796 L p .707 .577 .707 r
F P
0 g
s
.28495 .67019 m .28495 .70725 L .31434 .70387 L p .707 .577 .707 r
F P
0 g
s
.31434 .70387 m .31434 .66681 L .28495 .67019 L p .707 .577 .707 r
F P
0 g
s
.19449 .60682 m .19449 .6624 L .22195 .66679 L p .707 .577 .707 r
F P
0 g
s
.19449 .6624 m .19449 .60682 L .17343 .60036 L p .707 .577 .707 r
F P
0 g
s
.22195 .70612 m .22195 .66907 L .19449 .66468 L p .707 .577 .707 r
F P
0 g
s
.22195 .66907 m .22195 .70612 L .25312 .70802 L p .707 .577 .707 r
F P
0 g
s
.40766 .8685 m .40766 .36661 L .37794 .3575 L p .707 .577 .707 r
F P
0 g
s
.40766 .36661 m .40766 .8685 L .44643 .8747 L p .707 .577 .707 r
F P
0 g
s
.31434 .66681 m .31434 .70387 L .33839 .69822 L p .707 .577 .707 r
F P
0 g
s
.33839 .69822 m .33839 .66116 L .31434 .66681 L p .707 .577 .707 r
F P
0 g
s
.70195 .77032 m .70195 .78884 L .68936 .78096 L p .707 .577 .707 r
F P
0 g
s
.68936 .78096 m .68936 .76243 L .70195 .77032 L p .707 .577 .707 r
F P
0 g
s
.19449 .66468 m .19449 .70173 L .22195 .70612 L p .707 .577 .707 r
F P
0 g
s
.68936 .66582 m .68936 .70288 L .66831 .69642 L p .707 .577 .707 r
F P
0 g
s
.66831 .69642 m .66831 .65937 L .68936 .66582 L p .707 .577 .707 r
F P
0 g
s
.33839 .6033 m .33839 .65889 L .35476 .65152 L p .707 .577 .707 r
F P
0 g
s
.35476 .65152 m .35476 .59594 L .33839 .6033 L p .707 .577 .707 r
F P
0 g
s
.17343 .60036 m .17343 .65594 L .19449 .6624 L p .707 .577 .707 r
F P
0 g
s
.19449 .70173 m .19449 .66468 L .17343 .65822 L p .707 .577 .707 r
F P
0 g
s
.66831 .60151 m .66831 .65709 L .64085 .6527 L p .707 .577 .707 r
F P
0 g
s
.64085 .6527 m .64085 .59711 L .66831 .60151 L p .707 .577 .707 r
F P
0 g
s
.25312 .78611 m .25312 .76758 L .22195 .76568 L p .707 .577 .707 r
F P
0 g
s
.25312 .76758 m .25312 .78611 L .28495 .78533 L p .707 .577 .707 r
F P
0 g
s
.28495 .78533 m .28495 .76681 L .25312 .76758 L p .707 .577 .707 r
F P
0 g
s
.17343 .65594 m .17343 .60036 L .16084 .59248 L p .707 .577 .707 r
F P
0 g
s
.28495 .76681 m .28495 .78533 L .31434 .78195 L p .707 .577 .707 r
F P
0 g
s
.31434 .78195 m .31434 .76343 L .28495 .76681 L p .707 .577 .707 r
F P
0 g
s
.61082 .36165 m .61082 .86354 L .63393 .85314 L p .707 .577 .707 r
F P
0 g
s
.63393 .85314 m .63393 .35125 L .61082 .36165 L p .707 .577 .707 r
F P
0 g
s
.22195 .76568 m .22195 .78421 L .25312 .78611 L p .707 .577 .707 r
F P
0 g
s
.17343 .65822 m .17343 .69528 L .19449 .70173 L p .707 .577 .707 r
F P
0 g
s
.22195 .78421 m .22195 .76568 L .19449 .76129 L p .707 .577 .707 r
F P
0 g
s
.33839 .66116 m .33839 .69822 L .35476 .69085 L p .707 .577 .707 r
F P
0 g
s
.35476 .69085 m .35476 .6538 L .33839 .66116 L p .707 .577 .707 r
F P
0 g
s
.19449 .76129 m .19449 .77982 L .22195 .78421 L p .707 .577 .707 r
F P
0 g
s
.66831 .65937 m .66831 .69642 L .64085 .69203 L p .707 .577 .707 r
F P
0 g
s
.64085 .69203 m .64085 .65497 L .66831 .65937 L p .707 .577 .707 r
F P
0 g
s
.31434 .76343 m .31434 .78195 L .33839 .7763 L p .707 .577 .707 r
F P
0 g
s
.33839 .7763 m .33839 .75778 L .31434 .76343 L p .707 .577 .707 r
F P
0 g
s
.16084 .59248 m .16084 .64806 L .17343 .65594 L p .707 .577 .707 r
F P
0 g
s
.68936 .76243 m .68936 .78096 L .66831 .77451 L p .707 .577 .707 r
F P
0 g
s
.66831 .77451 m .66831 .75598 L .68936 .76243 L p .707 .577 .707 r
F P
0 g
s
.35476 .59594 m .35476 .65152 L .36184 .64315 L p .707 .577 .707 r
F P
0 g
s
.36184 .64315 m .36184 .58757 L .35476 .59594 L p .707 .577 .707 r
F P
0 g
s
.37794 .85939 m .37794 .3575 L .36016 .34637 L p .707 .577 .707 r
F P
0 g
s
.37794 .3575 m .37794 .85939 L .40766 .8685 L p .707 .577 .707 r
F P
0 g
s
.17343 .69528 m .17343 .65822 L .16084 .65034 L p .707 .577 .707 r
F P
0 g
s
.19449 .77982 m .19449 .76129 L .17343 .75484 L p .707 .577 .707 r
F P
0 g
s
.17343 .75484 m .17343 .77336 L .19449 .77982 L p .707 .577 .707 r
F P
0 g
s
.16084 .65034 m .16084 .68739 L .17343 .69528 L p .707 .577 .707 r
F P
0 g
s
.16084 .64806 m .16084 .59248 L .15794 .58394 L p .707 .577 .707 r
F P
0 g
s
.35476 .6538 m .35476 .69085 L .36184 .68249 L p .707 .577 .707 r
F P
0 g
s
.36184 .68249 m .36184 .64543 L .35476 .6538 L p .707 .577 .707 r
F P
0 g
s
.33839 .75778 m .33839 .7763 L .35476 .76894 L p .707 .577 .707 r
F P
0 g
s
.35476 .76894 m .35476 .75041 L .33839 .75778 L p .707 .577 .707 r
F P
0 g
s
.66831 .75598 m .66831 .77451 L .64085 .77011 L p .707 .577 .707 r
F P
0 g
s
.64085 .77011 m .64085 .75159 L .66831 .75598 L p .707 .577 .707 r
F P
0 g
s
.63393 .35125 m .63393 .85314 L .64393 .84133 L p .707 .577 .707 r
F P
0 g
s
.64393 .84133 m .64393 .33944 L .63393 .35125 L p .707 .577 .707 r
F P
0 g
s
.17343 .77336 m .17343 .75484 L .16084 .74695 L p .707 .577 .707 r
F P
0 g
s
.15794 .58394 m .15794 .63952 L .16084 .64806 L p .707 .577 .707 r
F P
0 g
s
.16084 .68739 m .16084 .65034 L .15794 .6418 L p .707 .577 .707 r
F P
0 g
s
.36184 .58757 m .36184 .64315 L .35894 .63461 L p .707 .577 .707 r
F P
0 g
s
.35894 .63461 m .35894 .57903 L .36184 .58757 L p .707 .577 .707 r
F P
0 g
s
.16084 .74695 m .16084 .76548 L .17343 .77336 L p .707 .577 .707 r
F P
0 g
s
.15794 .6418 m .15794 .67885 L .16084 .68739 L p .707 .577 .707 r
F P
0 g
s
.35476 .75041 m .35476 .76894 L .36184 .76057 L p .707 .577 .707 r
F P
0 g
s
.36184 .76057 m .36184 .74204 L .35476 .75041 L p .707 .577 .707 r
F P
0 g
s
.36184 .64543 m .36184 .68249 L .35894 .67394 L p .707 .577 .707 r
F P
0 g
s
.35894 .67394 m .35894 .63689 L .36184 .64543 L p .707 .577 .707 r
F P
0 g
s
.35894 .57903 m .35894 .63461 L .34635 .62673 L p .707 .577 .707 r
F P
0 g
s
.34635 .62673 m .34635 .57114 L .35894 .57903 L p .707 .577 .707 r
F P
0 g
s
.36184 .74204 m .36184 .76057 L .35894 .75203 L p .707 .577 .707 r
F P
0 g
s
.35894 .75203 m .35894 .7335 L .36184 .74204 L p .707 .577 .707 r
F P
0 g
s
.35894 .63689 m .35894 .67394 L .34635 .66606 L p .707 .577 .707 r
F P
0 g
s
.34635 .66606 m .34635 .629 L .35894 .63689 L p .707 .577 .707 r
F P
0 g
s
.36016 .84826 m .36016 .34637 L .35607 .33431 L p .707 .577 .707 r
F P
0 g
s
.36016 .34637 m .36016 .84826 L .37794 .85939 L p .707 .577 .707 r
F P
0 g
s
.15794 .63952 m .15794 .58394 L .16503 .57557 L p .707 .577 .707 r
F P
0 g
s
.16084 .76548 m .16084 .74695 L .15794 .73841 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57557 m .16503 .63115 L .15794 .63952 L p .707 .577 .707 r
F P
0 g
s
.15794 .67885 m .15794 .6418 L .16503 .63343 L p .707 .577 .707 r
F P
0 g
s
.15794 .73841 m .15794 .75694 L .16084 .76548 L p .707 .577 .707 r
F P
0 g
s
.64393 .33944 m .64393 .84133 L .63984 .82927 L p .707 .577 .707 r
F P
0 g
s
.63984 .82927 m .63984 .32738 L .64393 .33944 L p .707 .577 .707 r
F P
0 g
s
.16503 .63343 m .16503 .67049 L .15794 .67885 L p .707 .577 .707 r
F P
0 g
s
.16503 .63115 m .16503 .57557 L .1814 .5682 L p .707 .577 .707 r
F P
0 g
s
.35894 .7335 m .35894 .75203 L .34635 .74415 L p .707 .577 .707 r
F P
0 g
s
.34635 .74415 m .34635 .72562 L .35894 .7335 L p .707 .577 .707 r
F P
0 g
s
.35607 .33431 m .35607 .8362 L .36016 .84826 L p .707 .577 .707 r
F P
0 g
s
.35607 .8362 m .35607 .33431 L .36607 .3225 L p .707 .577 .707 r
F P
0 g
s
.15794 .75694 m .15794 .73841 L .16503 .73004 L p .707 .577 .707 r
F P
0 g
s
.1814 .5682 m .1814 .62379 L .16503 .63115 L p .707 .577 .707 r
F P
0 g
s
.34635 .57114 m .34635 .62673 L .3253 .62027 L p .707 .577 .707 r
F P
0 g
s
.3253 .62027 m .3253 .56469 L .34635 .57114 L p .707 .577 .707 r
F P
0 g
s
.16503 .67049 m .16503 .63343 L .1814 .62606 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .73004 m .16503 .74857 L .15794 .75694 L p .707 .577 .707 r
F P
0 g
s
.1814 .62606 m .1814 .66312 L .16503 .67049 L p .707 .577 .707 r
F P
0 g
s
.1814 .62379 m .1814 .5682 L .20545 .56255 L p .707 .577 .707 r
F P
0 g
s
.34635 .629 m .34635 .66606 L .3253 .65961 L p .707 .577 .707 r
F P
0 g
s
.3253 .65961 m .3253 .62255 L .34635 .629 L p .707 .577 .707 r
F P
0 g
s
.63984 .32738 m .63984 .82927 L .62206 .81814 L p .707 .577 .707 r
F P
0 g
s
.62206 .81814 m .62206 .31625 L .63984 .32738 L p .707 .577 .707 r
F P
0 g
s
.3253 .56469 m .3253 .62027 L .29784 .61588 L p .707 .577 .707 r
F P
0 g
s
.29784 .61588 m .29784 .5603 L .3253 .56469 L p .707 .577 .707 r
F P
0 g
s
.20545 .56255 m .20545 .61814 L .1814 .62379 L p .707 .577 .707 r
F P
0 g
s
.1814 .66312 m .1814 .62606 L .20545 .62041 L p .707 .577 .707 r
F P
0 g
s
.16503 .74857 m .16503 .73004 L .1814 .72268 L p .707 .577 .707 r
F P
0 g
s
.20545 .61814 m .20545 .56255 L .23483 .55917 L p .707 .577 .707 r
F P
0 g
s
.1814 .72268 m .1814 .7412 L .16503 .74857 L p .707 .577 .707 r
F P
0 g
s
.36607 .82439 m .36607 .3225 L .38918 .3121 L p .707 .577 .707 r
F P
0 g
s
.36607 .3225 m .36607 .82439 L .35607 .8362 L p .707 .577 .707 r
F P
0 g
s
.20545 .62041 m .20545 .65747 L .1814 .66312 L p .707 .577 .707 r
F P
0 g
s
.29784 .5603 m .29784 .61588 L .26667 .61398 L p .707 .577 .707 r
F P
0 g
s
.26667 .61398 m .26667 .5584 L .29784 .5603 L p .707 .577 .707 r
F P
0 g
s
.3253 .62255 m .3253 .65961 L .29784 .65521 L p .707 .577 .707 r
F P
0 g
s
.29784 .65521 m .29784 .61816 L .3253 .62255 L p .707 .577 .707 r
F P
0 g
s
.23483 .61476 m .23483 .55917 L .26667 .5584 L p .707 .577 .707 r
F P
0 g
s
.23483 .55917 m .23483 .61476 L .20545 .61814 L p .707 .577 .707 r
F P
0 g
s
.34635 .72562 m .34635 .74415 L .3253 .73769 L p .707 .577 .707 r
F P
0 g
s
.3253 .73769 m .3253 .71916 L .34635 .72562 L p .707 .577 .707 r
F P
0 g
s
.26667 .5584 m .26667 .61398 L .23483 .61476 L p .707 .577 .707 r
F P
0 g
s
.20545 .65747 m .20545 .62041 L .23483 .61704 L p .707 .577 .707 r
F P
0 g
s
.73333 .61347 m .73333 .55789 L .70216 .55599 L p .707 .577 .707 r
F P
0 g
s
.73333 .55789 m .73333 .61347 L .76517 .61269 L p .707 .577 .707 r
F P
0 g
s
.76517 .61269 m .76517 .55711 L .73333 .55789 L p .707 .577 .707 r
F P
0 g
s
.76517 .55711 m .76517 .61269 L .79455 .60931 L p .707 .577 .707 r
F P
0 g
s
.79455 .60931 m .79455 .55373 L .76517 .55711 L p .707 .577 .707 r
F P
0 g
s
.1814 .7412 m .1814 .72268 L .20545 .71703 L p .707 .577 .707 r
F P
0 g
s
.70216 .61157 m .70216 .55599 L .6747 .55159 L p .707 .577 .707 r
F P
0 g
s
.70216 .55599 m .70216 .61157 L .73333 .61347 L p .707 .577 .707 r
F P
0 g
s
.29784 .61816 m .29784 .65521 L .26667 .65331 L p .707 .577 .707 r
F P
0 g
s
.26667 .65331 m .26667 .61626 L .29784 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .61704 m .23483 .65409 L .20545 .65747 L p .707 .577 .707 r
F P
0 g
s
.20545 .71703 m .20545 .73555 L .1814 .7412 L p .707 .577 .707 r
F P
0 g
s
.23483 .65409 m .23483 .61704 L .26667 .61626 L p .707 .577 .707 r
F P
0 g
s
.62206 .31625 m .62206 .81814 L .59233 .80903 L p .707 .577 .707 r
F P
0 g
s
.59233 .80903 m .59233 .30714 L .62206 .31625 L p .707 .577 .707 r
F P
0 g
s
.26667 .61626 m .26667 .65331 L .23483 .65409 L p .707 .577 .707 r
F P
0 g
s
.79455 .55373 m .79455 .60931 L .8186 .60366 L p .707 .577 .707 r
F P
0 g
s
.8186 .60366 m .8186 .54808 L .79455 .55373 L p .707 .577 .707 r
F P
0 g
s
.73333 .6528 m .73333 .61575 L .70216 .61385 L p .707 .577 .707 r
F P
0 g
s
.73333 .61575 m .73333 .6528 L .76517 .65202 L p .707 .577 .707 r
F P
0 g
s
.76517 .65202 m .76517 .61497 L .73333 .61575 L p .707 .577 .707 r
F P
0 g
s
.3253 .71916 m .3253 .73769 L .29784 .7333 L p .707 .577 .707 r
F P
0 g
s
.29784 .7333 m .29784 .71477 L .3253 .71916 L p .707 .577 .707 r
F P
0 g
s
.76517 .61497 m .76517 .65202 L .79455 .64864 L p .707 .577 .707 r
F P
0 g
s
.79455 .64864 m .79455 .61159 L .76517 .61497 L p .707 .577 .707 r
F P
0 g
s
.6747 .55159 m .6747 .60718 L .70216 .61157 L p .707 .577 .707 r
F P
0 g
s
.6747 .60718 m .6747 .55159 L .65365 .54514 L p .707 .577 .707 r
F P
0 g
s
.70216 .6509 m .70216 .61385 L .6747 .60945 L p .707 .577 .707 r
F P
0 g
s
.70216 .61385 m .70216 .6509 L .73333 .6528 L p .707 .577 .707 r
F P
0 g
s
.20545 .73555 m .20545 .71703 L .23483 .71365 L p .707 .577 .707 r
F P
0 g
s
.38918 .3121 m .38918 .81399 L .36607 .82439 L p .707 .577 .707 r
F P
0 g
s
.38918 .81399 m .38918 .3121 L .42314 .30413 L p .707 .577 .707 r
F P
0 g
s
.79455 .61159 m .79455 .64864 L .8186 .643 L p .707 .577 .707 r
F P
0 g
s
.8186 .643 m .8186 .60594 L .79455 .61159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71365 m .23483 .73218 L .20545 .73555 L p .707 .577 .707 r
F P
0 g
s
.6747 .60945 m .6747 .64651 L .70216 .6509 L p .707 .577 .707 r
F P
0 g
s
.29784 .71477 m .29784 .7333 L .26667 .7314 L p .707 .577 .707 r
F P
0 g
s
.26667 .7314 m .26667 .71287 L .29784 .71477 L p .707 .577 .707 r
F P
0 g
s
.8186 .54808 m .8186 .60366 L .83497 .59629 L p .707 .577 .707 r
F P
0 g
s
.83497 .59629 m .83497 .54071 L .8186 .54808 L p .707 .577 .707 r
F P
0 g
s
.65365 .54514 m .65365 .60072 L .6747 .60718 L p .707 .577 .707 r
F P
0 g
s
.23483 .73218 m .23483 .71365 L .26667 .71287 L p .707 .577 .707 r
F P
0 g
s
.6747 .64651 m .6747 .60945 L .65365 .603 L p .707 .577 .707 r
F P
0 g
s
.26667 .71287 m .26667 .7314 L .23483 .73218 L p .707 .577 .707 r
F P
0 g
s
.73333 .73089 m .73333 .71236 L .70216 .71046 L p .707 .577 .707 r
F P
0 g
s
.73333 .71236 m .73333 .73089 L .76517 .73011 L p .707 .577 .707 r
F P
0 g
s
.76517 .73011 m .76517 .71158 L .73333 .71236 L p .707 .577 .707 r
F P
0 g
s
.59233 .30714 m .59233 .80903 L .55357 .80283 L p .707 .577 .707 r
F P
0 g
s
.55357 .80283 m .55357 .30094 L .59233 .30714 L p .707 .577 .707 r
F P
0 g
s
.65365 .60072 m .65365 .54514 L .64105 .53725 L p .707 .577 .707 r
F P
0 g
s
.76517 .71158 m .76517 .73011 L .79455 .72673 L p .707 .577 .707 r
F P
0 g
s
.79455 .72673 m .79455 .7082 L .76517 .71158 L p .707 .577 .707 r
F P
0 g
s
.70216 .71046 m .70216 .72899 L .73333 .73089 L p .707 .577 .707 r
F P
0 g
s
.65365 .603 m .65365 .64005 L .6747 .64651 L p .707 .577 .707 r
F P
0 g
s
.70216 .72899 m .70216 .71046 L .6747 .70607 L p .707 .577 .707 r
F P
0 g
s
.8186 .60594 m .8186 .643 L .83497 .63563 L p .707 .577 .707 r
F P
0 g
s
.83497 .63563 m .83497 .59857 L .8186 .60594 L p .707 .577 .707 r
F P
0 g
s
.6747 .70607 m .6747 .72459 L .70216 .72899 L p .707 .577 .707 r
F P
0 g
s
.42314 .80602 m .42314 .30413 L .46462 .29936 L p .707 .577 .707 r
F P
0 g
s
.42314 .30413 m .42314 .80602 L .38918 .81399 L p .707 .577 .707 r
F P
0 g
s
.79455 .7082 m .79455 .72673 L .8186 .72108 L p .707 .577 .707 r
F P
0 g
s
.8186 .72108 m .8186 .70255 L .79455 .7082 L p .707 .577 .707 r
F P
0 g
s
.64105 .53725 m .64105 .59284 L .65365 .60072 L p .707 .577 .707 r
F P
0 g
s
.83497 .54071 m .83497 .59629 L .84205 .58793 L p .707 .577 .707 r
F P
0 g
s
.84205 .58793 m .84205 .53235 L .83497 .54071 L p .707 .577 .707 r
F P
0 g
s
.65365 .64005 m .65365 .603 L .64105 .59512 L p .707 .577 .707 r
F P
0 g
s
.6747 .72459 m .6747 .70607 L .65365 .69961 L p .707 .577 .707 r
F P
0 g
s
.55357 .30094 m .55357 .80283 L .50956 .80015 L p .707 .577 .707 r
F P
0 g
s
.50956 .80015 m .50956 .29826 L .55357 .30094 L p .707 .577 .707 r
F P
0 g
s
.65365 .69961 m .65365 .71814 L .6747 .72459 L p .707 .577 .707 r
F P
0 g
s
.46462 .80125 m .46462 .29936 L .50956 .29826 L p .707 .577 .707 r
F P
0 g
s
.46462 .29936 m .46462 .80125 L .42314 .80602 L p .707 .577 .707 r
F P
0 g
s
.64105 .59512 m .64105 .63217 L .65365 .64005 L p .707 .577 .707 r
F P
0 g
s
.64105 .59284 m .64105 .53725 L .63816 .52871 L p .707 .577 .707 r
F P
0 g
s
.50956 .29826 m .50956 .80015 L .46462 .80125 L p .707 .577 .707 r
F P
0 g
s
.83497 .59857 m .83497 .63563 L .84205 .62726 L p .707 .577 .707 r
F P
0 g
s
.84205 .62726 m .84205 .59021 L .83497 .59857 L p .707 .577 .707 r
F P
0 g
s
.8186 .70255 m .8186 .72108 L .83497 .71371 L p .707 .577 .707 r
F P
0 g
s
.83497 .71371 m .83497 .69519 L .8186 .70255 L p .707 .577 .707 r
F P
0 g
s
.65365 .71814 m .65365 .69961 L .64105 .69173 L p .707 .577 .707 r
F P
0 g
s
.63816 .52871 m .63816 .58429 L .64105 .59284 L p .707 .577 .707 r
F P
0 g
s
.64105 .63217 m .64105 .59512 L .63816 .58657 L p .707 .577 .707 r
F P
0 g
s
.84205 .53235 m .84205 .58793 L .83916 .57939 L p .707 .577 .707 r
F P
0 g
s
.83916 .57939 m .83916 .52381 L .84205 .53235 L p .707 .577 .707 r
F P
0 g
s
.64105 .69173 m .64105 .71026 L .65365 .71814 L p .707 .577 .707 r
F P
0 g
s
.63816 .58657 m .63816 .62363 L .64105 .63217 L p .707 .577 .707 r
F P
0 g
s
.83497 .69519 m .83497 .71371 L .84206 .70535 L p .707 .577 .707 r
F P
0 g
s
.84206 .70535 m .84206 .68682 L .83497 .69519 L p .707 .577 .707 r
F P
0 g
s
.63816 .58429 m .63816 .52871 L .64524 .52035 L p .707 .577 .707 r
F P
0 g
s
.84205 .59021 m .84205 .62726 L .83916 .61872 L p .707 .577 .707 r
F P
0 g
s
.83916 .61872 m .83916 .58167 L .84205 .59021 L p .707 .577 .707 r
F P
0 g
s
.64105 .71026 m .64105 .69173 L .63816 .68319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .52035 m .64524 .57593 L .63816 .58429 L p .707 .577 .707 r
F P
0 g
s
.63816 .62363 m .63816 .58657 L .64524 .57821 L p .707 .577 .707 r
F P
0 g
s
.63816 .68319 m .63816 .70171 L .64105 .71026 L p .707 .577 .707 r
F P
0 g
s
.83916 .52381 m .83916 .57939 L .82657 .5715 L p .707 .577 .707 r
F P
0 g
s
.82657 .5715 m .82657 .51592 L .83916 .52381 L p .707 .577 .707 r
F P
0 g
s
.64524 .57821 m .64524 .61526 L .63816 .62363 L p .707 .577 .707 r
F P
0 g
s
.39032 .57665 m .39032 .52107 L .35915 .51917 L p .707 .577 .707 r
F P
0 g
s
.39032 .52107 m .39032 .57665 L .42216 .57588 L p .707 .577 .707 r
F P
0 g
s
.42216 .57588 m .42216 .52029 L .39032 .52107 L p .707 .577 .707 r
F P
0 g
s
.84206 .68682 m .84206 .70535 L .83916 .69681 L p .707 .577 .707 r
F P
0 g
s
.83916 .69681 m .83916 .67828 L .84206 .68682 L p .707 .577 .707 r
F P
0 g
s
.64524 .57593 m .64524 .52035 L .66161 .51298 L p .707 .577 .707 r
F P
0 g
s
.42216 .52029 m .42216 .57588 L .45154 .5725 L p .707 .577 .707 r
F P
0 g
s
.45154 .5725 m .45154 .51691 L .42216 .52029 L p .707 .577 .707 r
F P
0 g
s
.83916 .58167 m .83916 .61872 L .82657 .61084 L p .707 .577 .707 r
F P
0 g
s
.82657 .61084 m .82657 .57378 L .83916 .58167 L p .707 .577 .707 r
F P
0 g
s
.35915 .57475 m .35915 .51917 L .33169 .51478 L p .707 .577 .707 r
F P
0 g
s
.35915 .51917 m .35915 .57475 L .39032 .57665 L p .707 .577 .707 r
F P
0 g
s
.45154 .51691 m .45154 .5725 L .47559 .56685 L p .707 .577 .707 r
F P
0 g
s
.47559 .56685 m .47559 .51126 L .45154 .51691 L p .707 .577 .707 r
F P
0 g
s
.63816 .70171 m .63816 .68319 L .64524 .67482 L p .707 .577 .707 r
F P
0 g
s
.39032 .61599 m .39032 .57893 L .35915 .57703 L p .707 .577 .707 r
F P
0 g
s
.39032 .57893 m .39032 .61599 L .42216 .61521 L p .707 .577 .707 r
F P
0 g
s
.42216 .61521 m .42216 .57815 L .39032 .57893 L p .707 .577 .707 r
F P
0 g
s
.66161 .51298 m .66161 .56856 L .64524 .57593 L p .707 .577 .707 r
F P
0 g
s
.82657 .51592 m .82657 .5715 L .80551 .56505 L p .707 .577 .707 r
F P
0 g
s
.80551 .56505 m .80551 .50947 L .82657 .51592 L p .707 .577 .707 r
F P
0 g
s
.64524 .61526 m .64524 .57821 L .66161 .57084 L p .707 .577 .707 r
F P
0 g
s
.42216 .57815 m .42216 .61521 L .45154 .61183 L p .707 .577 .707 r
F P
0 g
s
.45154 .61183 m .45154 .57477 L .42216 .57815 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .67482 m .64524 .69335 L .63816 .70171 L p .707 .577 .707 r
F P
0 g
s
.33169 .51478 m .33169 .57036 L .35915 .57475 L p .707 .577 .707 r
F P
0 g
s
.33169 .57036 m .33169 .51478 L .31064 .50832 L p .707 .577 .707 r
F P
0 g
s
.35915 .61408 m .35915 .57703 L .33169 .57264 L p .707 .577 .707 r
F P
0 g
s
.35915 .57703 m .35915 .61408 L .39032 .61599 L p .707 .577 .707 r
F P
0 g
s
.66161 .57084 m .66161 .6079 L .64524 .61526 L p .707 .577 .707 r
F P
0 g
s
.66161 .56856 m .66161 .51298 L .68566 .50733 L p .707 .577 .707 r
F P
0 g
s
.45154 .57477 m .45154 .61183 L .47559 .60618 L p .707 .577 .707 r
F P
0 g
s
.47559 .60618 m .47559 .56912 L .45154 .57477 L p .707 .577 .707 r
F P
0 g
s
.83916 .67828 m .83916 .69681 L .82657 .68892 L p .707 .577 .707 r
F P
0 g
s
.82657 .68892 m .82657 .6704 L .83916 .67828 L p .707 .577 .707 r
F P
0 g
s
.33169 .57264 m .33169 .60969 L .35915 .61408 L p .707 .577 .707 r
F P
0 g
s
.82657 .57378 m .82657 .61084 L .80551 .60438 L p .707 .577 .707 r
F P
0 g
s
.80551 .60438 m .80551 .56733 L .82657 .57378 L p .707 .577 .707 r
F P
0 g
s
.47559 .51126 m .47559 .56685 L .49196 .55948 L p .707 .577 .707 r
F P
0 g
s
.49196 .55948 m .49196 .5039 L .47559 .51126 L p .707 .577 .707 r
F P
0 g
s
.31064 .50832 m .31064 .56391 L .33169 .57036 L p .707 .577 .707 r
F P
0 g
s
.33169 .60969 m .33169 .57264 L .31064 .56618 L p .707 .577 .707 r
F P
0 g
s
.80551 .50947 m .80551 .56505 L .77805 .56066 L p .707 .577 .707 r
F P
0 g
s
.77805 .56066 m .77805 .50507 L .80551 .50947 L p .707 .577 .707 r
F P
0 g
s
.39032 .69407 m .39032 .67554 L .35915 .67364 L p .707 .577 .707 r
F P
0 g
s
.39032 .67554 m .39032 .69407 L .42216 .69329 L p .707 .577 .707 r
F P
0 g
s
.42216 .69329 m .42216 .67477 L .39032 .67554 L p .707 .577 .707 r
F P
0 g
s
.68566 .50733 m .68566 .56291 L .66161 .56856 L p .707 .577 .707 r
F P
0 g
s
.66161 .6079 m .66161 .57084 L .68566 .56519 L p .707 .577 .707 r
F P
0 g
s
.64524 .69335 m .64524 .67482 L .66161 .66745 L p .707 .577 .707 r
F P
0 g
s
.31064 .56391 m .31064 .50832 L .29804 .50044 L p .707 .577 .707 r
F P
0 g
s
.42216 .67477 m .42216 .69329 L .45154 .68992 L p .707 .577 .707 r
F P
0 g
s
.45154 .68992 m .45154 .67139 L .42216 .67477 L p .707 .577 .707 r
F P
0 g
s
.35915 .67364 m .35915 .69217 L .39032 .69407 L p .707 .577 .707 r
F P
0 g
s
.31064 .56618 m .31064 .60324 L .33169 .60969 L p .707 .577 .707 r
F P
0 g
s
.68566 .56291 m .68566 .50733 L .71504 .50395 L p .707 .577 .707 r
F P
0 g
s
.35915 .69217 m .35915 .67364 L .33169 .66925 L p .707 .577 .707 r
F P
0 g
s
.66161 .66745 m .66161 .68598 L .64524 .69335 L p .707 .577 .707 r
F P
0 g
s
.47559 .56912 m .47559 .60618 L .49196 .59881 L p .707 .577 .707 r
F P
0 g
s
.49196 .59881 m .49196 .56176 L .47559 .56912 L p .707 .577 .707 r
F P
0 g
s
.33169 .66925 m .33169 .68778 L .35915 .69217 L p .707 .577 .707 r
F P
0 g
s
.68566 .56519 m .68566 .60225 L .66161 .6079 L p .707 .577 .707 r
F P
0 g
s
.77805 .50507 m .77805 .56066 L .74688 .55876 L p .707 .577 .707 r
F P
0 g
s
.74688 .55876 m .74688 .50317 L .77805 .50507 L p .707 .577 .707 r
F P
0 g
s
.80551 .56733 m .80551 .60438 L .77805 .59999 L p .707 .577 .707 r
F P
0 g
s
.77805 .59999 m .77805 .56294 L .80551 .56733 L p .707 .577 .707 r
F P
0 g
s
.45154 .67139 m .45154 .68992 L .47559 .68427 L p .707 .577 .707 r
F P
0 g
s
.47559 .68427 m .47559 .66574 L .45154 .67139 L p .707 .577 .707 r
F P
0 g
s
.29804 .50044 m .29804 .55602 L .31064 .56391 L p .707 .577 .707 r
F P
0 g
s
.71504 .55953 m .71504 .50395 L .74688 .50317 L p .707 .577 .707 r
F P
0 g
s
.71504 .50395 m .71504 .55953 L .68566 .56291 L p .707 .577 .707 r
F P
0 g
s
.82657 .6704 m .82657 .68892 L .80551 .68247 L p .707 .577 .707 r
F P
0 g
s
.80551 .68247 m .80551 .66394 L .82657 .6704 L p .707 .577 .707 r
F P
0 g
s
.49196 .5039 m .49196 .55948 L .49904 .55111 L p .707 .577 .707 r
F P
0 g
s
.49904 .55111 m .49904 .49553 L .49196 .5039 L p .707 .577 .707 r
F P
0 g
s
.31064 .60324 m .31064 .56618 L .29804 .5583 L p .707 .577 .707 r
F P
0 g
s
.74688 .50317 m .74688 .55876 L .71504 .55953 L p .707 .577 .707 r
F P
0 g
s
.68566 .60225 m .68566 .56519 L .71504 .56181 L p .707 .577 .707 r
F P
0 g
s
.33169 .68778 m .33169 .66925 L .31064 .6628 L p .707 .577 .707 r
F P
0 g
s
.31064 .6628 m .31064 .68132 L .33169 .68778 L p .707 .577 .707 r
F P
0 g
s
.66161 .68598 m .66161 .66745 L .68566 .6618 L p .707 .577 .707 r
F P
0 g
s
.29804 .5583 m .29804 .59535 L .31064 .60324 L p .707 .577 .707 r
F P
0 g
s
.77805 .56294 m .77805 .59999 L .74688 .59809 L p .707 .577 .707 r
F P
0 g
s
.74688 .59809 m .74688 .56103 L .77805 .56294 L p .707 .577 .707 r
F P
0 g
s
.29804 .55602 m .29804 .50044 L .29515 .4919 L p .707 .577 .707 r
F P
0 g
s
.71504 .56181 m .71504 .59887 L .68566 .60225 L p .707 .577 .707 r
F P
0 g
s
.68566 .6618 m .68566 .68033 L .66161 .68598 L p .707 .577 .707 r
F P
0 g
s
.71504 .59887 m .71504 .56181 L .74688 .56103 L p .707 .577 .707 r
F P
0 g
s
.49196 .56176 m .49196 .59881 L .49904 .59045 L p .707 .577 .707 r
F P
0 g
s
.49904 .59045 m .49904 .55339 L .49196 .56176 L p .707 .577 .707 r
F P
0 g
s
.47559 .66574 m .47559 .68427 L .49196 .6769 L p .707 .577 .707 r
F P
0 g
s
.49196 .6769 m .49196 .65837 L .47559 .66574 L p .707 .577 .707 r
F P
0 g
s
.74688 .56103 m .74688 .59809 L .71504 .59887 L p .707 .577 .707 r
F P
0 g
s
.80551 .66394 m .80551 .68247 L .77805 .67808 L p .707 .577 .707 r
F P
0 g
s
.77805 .67808 m .77805 .65955 L .80551 .66394 L p .707 .577 .707 r
F P
0 g
s
.31064 .68132 m .31064 .6628 L .29804 .65491 L p .707 .577 .707 r
F P
0 g
s
.29515 .4919 m .29515 .54748 L .29804 .55602 L p .707 .577 .707 r
F P
0 g
s
.29804 .59535 m .29804 .5583 L .29515 .54976 L p .707 .577 .707 r
F P
0 g
s
.49904 .49553 m .49904 .55111 L .49615 .54257 L p .707 .577 .707 r
F P
0 g
s
.49615 .54257 m .49615 .48699 L .49904 .49553 L p .707 .577 .707 r
F P
0 g
s
.68566 .68033 m .68566 .6618 L .71504 .65843 L p .707 .577 .707 r
F P
0 g
s
.29804 .65491 m .29804 .67344 L .31064 .68132 L p .707 .577 .707 r
F P
0 g
s
.71504 .65843 m .71504 .67695 L .68566 .68033 L p .707 .577 .707 r
F P
0 g
s
.77805 .65955 m .77805 .67808 L .74688 .67618 L p .707 .577 .707 r
F P
0 g
s
.74688 .67618 m .74688 .65765 L .77805 .65955 L p .707 .577 .707 r
F P
0 g
s
.29515 .54976 m .29515 .58681 L .29804 .59535 L p .707 .577 .707 r
F P
0 g
s
.71504 .67695 m .71504 .65843 L .74688 .65765 L p .707 .577 .707 r
F P
0 g
s
.49196 .65837 m .49196 .6769 L .49904 .66853 L p .707 .577 .707 r
F P
0 g
s
.49904 .66853 m .49904 .65001 L .49196 .65837 L p .707 .577 .707 r
F P
0 g
s
.29515 .54748 m .29515 .4919 L .30223 .48353 L p .707 .577 .707 r
F P
0 g
s
.74688 .65765 m .74688 .67618 L .71504 .67695 L p .707 .577 .707 r
F P
0 g
s
.49904 .55339 m .49904 .59045 L .49615 .58191 L p .707 .577 .707 r
F P
0 g
s
.49615 .58191 m .49615 .54485 L .49904 .55339 L p .707 .577 .707 r
F P
0 g
s
.29804 .67344 m .29804 .65491 L .29515 .64637 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48353 m .30223 .53911 L .29515 .54748 L p .707 .577 .707 r
F P
0 g
s
.29515 .58681 m .29515 .54976 L .30223 .54139 L p .707 .577 .707 r
F P
0 g
s
.29515 .64637 m .29515 .6649 L .29804 .67344 L p .707 .577 .707 r
F P
0 g
s
.49615 .48699 m .49615 .54257 L .48356 .53469 L p .707 .577 .707 r
F P
0 g
s
.48356 .53469 m .48356 .47911 L .49615 .48699 L p .707 .577 .707 r
F P
0 g
s
.30223 .54139 m .30223 .57845 L .29515 .58681 L p .707 .577 .707 r
F P
0 g
s
.49904 .65001 m .49904 .66853 L .49615 .65999 L p .707 .577 .707 r
F P
0 g
s
.49615 .65999 m .49615 .64146 L .49904 .65001 L p .707 .577 .707 r
F P
0 g
s
.30223 .53911 m .30223 .48353 L .3186 .47616 L p .707 .577 .707 r
F P
0 g
s
.49615 .54485 m .49615 .58191 L .48356 .57402 L p .707 .577 .707 r
F P
0 g
s
.48356 .57402 m .48356 .53697 L .49615 .54485 L p .707 .577 .707 r
F P
0 g
s
.29515 .6649 m .29515 .64637 L .30223 .63801 L p .707 .577 .707 r
F P
0 g
s
.3186 .47616 m .3186 .53175 L .30223 .53911 L p .707 .577 .707 r
F P
0 g
s
.48356 .47911 m .48356 .53469 L .4625 .52823 L p .707 .577 .707 r
F P
0 g
s
.4625 .52823 m .4625 .47265 L .48356 .47911 L p .707 .577 .707 r
F P
0 g
s
.30223 .57845 m .30223 .54139 L .3186 .53402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .63801 m .30223 .65653 L .29515 .6649 L p .707 .577 .707 r
F P
0 g
s
.3186 .53402 m .3186 .57108 L .30223 .57845 L p .707 .577 .707 r
F P
0 g
s
.3186 .53175 m .3186 .47616 L .34265 .47051 L p .707 .577 .707 r
F P
0 g
s
.49615 .64146 m .49615 .65999 L .48356 .65211 L p .707 .577 .707 r
F P
0 g
s
.48356 .65211 m .48356 .63358 L .49615 .64146 L p .707 .577 .707 r
F P
0 g
s
.48356 .53697 m .48356 .57402 L .4625 .56757 L p .707 .577 .707 r
F P
0 g
s
.4625 .56757 m .4625 .53051 L .48356 .53697 L p .707 .577 .707 r
F P
0 g
s
.4625 .47265 m .4625 .52823 L .43504 .52384 L p .707 .577 .707 r
F P
0 g
s
.43504 .52384 m .43504 .46826 L .4625 .47265 L p .707 .577 .707 r
F P
0 g
s
.34265 .47051 m .34265 .5261 L .3186 .53175 L p .707 .577 .707 r
F P
0 g
s
.3186 .57108 m .3186 .53402 L .34265 .52838 L p .707 .577 .707 r
F P
0 g
s
.30223 .65653 m .30223 .63801 L .3186 .63064 L p .707 .577 .707 r
F P
0 g
s
.34265 .5261 m .34265 .47051 L .37203 .46714 L p .707 .577 .707 r
F P
0 g
s
.3186 .63064 m .3186 .64917 L .30223 .65653 L p .707 .577 .707 r
F P
0 g
s
.34265 .52838 m .34265 .56543 L .3186 .57108 L p .707 .577 .707 r
F P
0 g
s
.43504 .46826 m .43504 .52384 L .40387 .52194 L p .707 .577 .707 r
F P
0 g
s
.40387 .52194 m .40387 .46636 L .43504 .46826 L p .707 .577 .707 r
F P
0 g
s
.4625 .53051 m .4625 .56757 L .43504 .56317 L p .707 .577 .707 r
F P
0 g
s
.43504 .56317 m .43504 .52612 L .4625 .53051 L p .707 .577 .707 r
F P
0 g
s
.37203 .52272 m .37203 .46714 L .40387 .46636 L p .707 .577 .707 r
F P
0 g
s
.37203 .46714 m .37203 .52272 L .34265 .5261 L p .707 .577 .707 r
F P
0 g
s
.48356 .63358 m .48356 .65211 L .4625 .64565 L p .707 .577 .707 r
F P
0 g
s
.4625 .64565 m .4625 .62713 L .48356 .63358 L p .707 .577 .707 r
F P
0 g
s
.40387 .46636 m .40387 .52194 L .37203 .52272 L p .707 .577 .707 r
F P
0 g
s
.34265 .56543 m .34265 .52838 L .37203 .525 L p .707 .577 .707 r
F P
0 g
s
.3186 .64917 m .3186 .63064 L .34265 .62499 L p .707 .577 .707 r
F P
0 g
s
.43504 .52612 m .43504 .56317 L .40387 .56127 L p .707 .577 .707 r
F P
0 g
s
.40387 .56127 m .40387 .52422 L .43504 .52612 L p .707 .577 .707 r
F P
0 g
s
.37203 .525 m .37203 .56205 L .34265 .56543 L p .707 .577 .707 r
F P
0 g
s
.34265 .62499 m .34265 .64352 L .3186 .64917 L p .707 .577 .707 r
F P
0 g
s
.37203 .56205 m .37203 .525 L .40387 .52422 L p .707 .577 .707 r
F P
0 g
s
.40387 .52422 m .40387 .56127 L .37203 .56205 L p .707 .577 .707 r
F P
0 g
s
.4625 .62713 m .4625 .64565 L .43504 .64126 L p .707 .577 .707 r
F P
0 g
s
.43504 .64126 m .43504 .62273 L .4625 .62713 L p .707 .577 .707 r
F P
0 g
s
.34265 .64352 m .34265 .62499 L .37203 .62161 L p .707 .577 .707 r
F P
0 g
s
.37203 .62161 m .37203 .64014 L .34265 .64352 L p .707 .577 .707 r
F P
0 g
s
.43504 .62273 m .43504 .64126 L .40387 .63936 L p .707 .577 .707 r
F P
0 g
s
.40387 .63936 m .40387 .62083 L .43504 .62273 L p .707 .577 .707 r
F P
0 g
s
.37203 .64014 m .37203 .62161 L .40387 .62083 L p .707 .577 .707 r
F P
0 g
s
.40387 .62083 m .40387 .63936 L .37203 .64014 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001/Ool30009FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KWoo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaX003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03
001JEUYF00=JER40009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005=oo`03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo
2@000goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool003Uoo`h000AJEP03001JEUYF009JEP@00003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03
FUH70007FUH50004FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPL0
00AJEP03001JEUYF00IJEP03001JEUYF009JEPd000AJEP04001JEUYFFUH2000]Ool0039oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000<0
00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH60000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF200000=JEP00FUH00UYF
0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH90004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH;00000eYF001J
EP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEP0000T000AJEP@0009JEPh000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH400000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH0
0eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPH002eoo`00;Goo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008FUH50004FUH00`00FUIJEP05FUH50004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH80004FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUH0000500000eYF001JEP02FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20003FUH>0004FUH40005FUH00`00FUIJEP02FUH70003FUH30003FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EPP000AJEP03001JEUYF00=JEPh0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUHK0003FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EQl000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUH000090004FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEP0000T000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF01800003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF00000eYF1`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF30000eYF00<005YF
FUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
0000;Goo000/Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF00000`0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF0000
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH50006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH40000
0eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2@000eYF00@005YF001JEP8000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP03
001JEP0001P003moo`00;7oo00<005YF000015YF00<005YFFUH00eYF4`0015YF100000AJEP000000
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001`0015YF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<005YF00000`0000=JEP000000100015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPP00003FUH005YF009JEQX003aoo`00;7oo00<005YF00000eYF2@0015YF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEPX00005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00001`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;7oo00@005YF001JEP8000AJEPd000AJEP@0
009JEPP000=JEP03001JEP00008000=JEP<0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH50002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`06001JEP00001JEP001EYF00@0
05YFFUIJEQX000=JEP03001JEUYF009JEPD00004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70003FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000b
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH00eYF2@000eYF
00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`8000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEQP000EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJ
EP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP@00003FUH005YF00IJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04001JEUYFFUH2000J
Ool40003FUH01000FUIJEUYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPD000AJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000NOol40003
FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000L000AJEPD000EJEP03001JEUYF009J
EPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Woo00<005YFFUH0
0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01P00FUH00000Ool0009JEP03001JEP00018000MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00AJEP04001JEUYFFUH2000SOol4000]Ool003=oo`<00003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF000000020003FUH01000FUIJEUYF
0P008Goo0P0000AJEP00000002eoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YF00000`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEP0000P000=JEP8001ioo`<000=JEP<002eoo`00>goo200015YF00<005YFFUH0
1eYF00<005YFFUH00UYF1@002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP03001JEUYF009JEP@0009JEP03001JEUYF008001Yoo`@00003FUH005YF00=JEP03001JEP00
02eoo`00@goo4`003goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEP0000L001Eoo`D000EJEP03001JEUYF009JEP8002ioo`00?goo4@005Goo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJ
EP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uoo`H000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000`Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0017oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP04001JEUYFFUH4000dOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<0
05YFFUH01UYF1@0015YF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUH0000J000oOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000Uoo`P000AJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`03001JEP0000AJEP04001JEUYFFUH8000I
Ool60004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEP@005]oo`00;7oo00<005YF00000eYF1@009goo0`0000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H005moo`00
;7oo00@005YF001JEP8002moo`80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`@003Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008006=oo`00;7oo0P000UYF0`00;goo10000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@00GWoo000/Ool20003
FUH00`00FUH00002000YOol30002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00005FUH00`00FUH00002001KOol002aoo`8000=JEP03001JEUYF009JEPD0021o
o`@00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF009JEP8005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8
000COol50005FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF0P00F7oo000^Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEP00001F
Ool0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001J
EUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000100000=JEP00FUH015YF00D005YFFUIJEP0005Eoo`00<goo0`0000=JEP00FUH01UYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<000AJEP05001JEUYFFUH0001EOol0
03Ioo`D000AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEP0000<000Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001JEP02FUH2
001DOol003]oo`P000AJEPD000EJEP03001JEUYF009JEPD000Yoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2001DOol004=ooa<000moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000<Ool200000eYF0000001DOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;Ool2000015YF0000
0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
0`000eYF0`00E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000017oo100000=JEP00FUH00eYF00<005YF0000E7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH01eYF5@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010001EYF00<005YFFUH00UYF0P00EGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00@005YFFUIJEPH000UJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEUYFFUH2001F
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH01000FUH00000F7oo001UOol01000FUIJEP001EYF0`000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<0
05YF00000UYF00@005YFFUIJEPD005Yoo`00IGoo00@005YFFUH000=JEP8000EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001J
EP0000H005moo`00IGoo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0001U
Ool006Eoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo06Aoo`00
IGoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo001UOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`1TOol006Eoo`8000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF001UOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0006Io
o`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00Igoo001WOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Uoo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2001ZOol006]o
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEP00001/Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00LGoo1@0025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@00LWoo001fOol60002FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001gOol007aoo`T000IJEP03001JEUYF00YJEP03001J
EUYF00H007aoo`00QGoo5P00PWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72231 m .59613 .66673 L .56496 .66483 L p .707 .577 .707 r
F P
0 g
s
.59613 .66673 m .59613 .72231 L .62796 .72153 L p .707 .577 .707 r
F P
0 g
s
.62796 .72153 m .62796 .66595 L .59613 .66673 L p .707 .577 .707 r
F P
0 g
s
.62796 .66595 m .62796 .72153 L .65734 .71815 L p .707 .577 .707 r
F P
0 g
s
.65734 .71815 m .65734 .66257 L .62796 .66595 L p .707 .577 .707 r
F P
0 g
s
.56496 .72041 m .56496 .66483 L .5375 .66043 L p .707 .577 .707 r
F P
0 g
s
.56496 .66483 m .56496 .72041 L .59613 .72231 L p .707 .577 .707 r
F P
0 g
s
.65734 .66257 m .65734 .71815 L .6814 .7125 L p .707 .577 .707 r
F P
0 g
s
.6814 .7125 m .6814 .65692 L .65734 .66257 L p .707 .577 .707 r
F P
0 g
s
.59613 .76967 m .59613 .73262 L .56496 .73072 L p .707 .577 .707 r
F P
0 g
s
.59613 .73262 m .59613 .76967 L .62796 .7689 L p .707 .577 .707 r
F P
0 g
s
.62796 .7689 m .62796 .73184 L .59613 .73262 L p .707 .577 .707 r
F P
0 g
s
.62796 .73184 m .62796 .7689 L .65735 .76552 L p .707 .577 .707 r
F P
0 g
s
.65735 .76552 m .65734 .72846 L .62796 .73184 L p .707 .577 .707 r
F P
0 g
s
.5375 .66043 m .5375 .71602 L .56496 .72041 L p .707 .577 .707 r
F P
0 g
s
.5375 .71602 m .5375 .66043 L .51644 .65398 L p .707 .577 .707 r
F P
0 g
s
.56496 .76777 m .56496 .73072 L .5375 .72633 L p .707 .577 .707 r
F P
0 g
s
.56496 .73072 m .56496 .76777 L .59613 .76967 L p .707 .577 .707 r
F P
0 g
s
.65734 .72846 m .65735 .76552 L .6814 .75987 L p .707 .577 .707 r
F P
0 g
s
.6814 .75987 m .6814 .72281 L .65734 .72846 L p .707 .577 .707 r
F P
0 g
s
.6814 .65692 m .6814 .7125 L .69777 .70514 L p .707 .577 .707 r
F P
0 g
s
.69777 .70514 m .69777 .64955 L .6814 .65692 L p .707 .577 .707 r
F P
0 g
s
.5375 .72633 m .5375 .76338 L .56496 .76777 L p .707 .577 .707 r
F P
0 g
s
.51644 .65398 m .51644 .70956 L .5375 .71602 L p .707 .577 .707 r
F P
0 g
s
.5375 .76338 m .5375 .72633 L .51644 .71987 L p .707 .577 .707 r
F P
0 g
s
.59613 .83391 m .59613 .81539 L .56496 .81349 L p .707 .577 .707 r
F P
0 g
s
.59613 .81539 m .59613 .83391 L .62796 .83314 L p .707 .577 .707 r
F P
0 g
s
.62796 .83314 m .62796 .81461 L .59613 .81539 L p .707 .577 .707 r
F P
0 g
s
.62796 .81461 m .62796 .83314 L .65735 .82976 L p .707 .577 .707 r
F P
0 g
s
.65735 .82976 m .65735 .81123 L .62796 .81461 L p .707 .577 .707 r
F P
0 g
s
.51644 .70956 m .51644 .65398 L .50385 .6461 L p .707 .577 .707 r
F P
0 g
s
.56496 .81349 m .56496 .83201 L .59613 .83391 L p .707 .577 .707 r
F P
0 g
s
.56496 .83201 m .56496 .81349 L .5375 .80909 L p .707 .577 .707 r
F P
0 g
s
.51644 .71987 m .51644 .75693 L .5375 .76338 L p .707 .577 .707 r
F P
0 g
s
.5375 .80909 m .5375 .82762 L .56496 .83201 L p .707 .577 .707 r
F P
0 g
s
.6814 .72281 m .6814 .75987 L .69777 .7525 L p .707 .577 .707 r
F P
0 g
s
.69777 .7525 m .69777 .71545 L .6814 .72281 L p .707 .577 .707 r
F P
0 g
s
.65735 .81123 m .65735 .82976 L .6814 .82411 L p .707 .577 .707 r
F P
0 g
s
.6814 .82411 m .6814 .80558 L .65735 .81123 L p .707 .577 .707 r
F P
0 g
s
.50385 .6461 m .50385 .70168 L .51644 .70956 L p .707 .577 .707 r
F P
0 g
s
.69777 .64955 m .69777 .70514 L .70485 .69677 L p .707 .577 .707 r
F P
0 g
s
.70485 .69677 m .70485 .64119 L .69777 .64955 L p .707 .577 .707 r
F P
0 g
s
.5375 .82762 m .5375 .80909 L .51644 .80264 L p .707 .577 .707 r
F P
0 g
s
.51644 .75693 m .51644 .71987 L .50385 .71199 L p .707 .577 .707 r
F P
0 g
s
.51644 .80264 m .51644 .82117 L .5375 .82762 L p .707 .577 .707 r
F P
0 g
s
.50385 .70168 m .50385 .6461 L .50095 .63755 L p .707 .577 .707 r
F P
0 g
s
.50385 .71199 m .50385 .74904 L .51644 .75693 L p .707 .577 .707 r
F P
0 g
s
.6814 .80558 m .6814 .82411 L .69777 .81674 L p .707 .577 .707 r
F P
0 g
s
.69777 .81674 m .69777 .79821 L .6814 .80558 L p .707 .577 .707 r
F P
0 g
s
.69777 .71545 m .69777 .7525 L .70485 .74414 L p .707 .577 .707 r
F P
0 g
s
.70485 .74414 m .70485 .70708 L .69777 .71545 L p .707 .577 .707 r
F P
0 g
s
.51644 .82117 m .51644 .80264 L .50385 .79476 L p .707 .577 .707 r
F P
0 g
s
.50095 .63755 m .50095 .69314 L .50385 .70168 L p .707 .577 .707 r
F P
0 g
s
.70485 .64119 m .70485 .69677 L .70195 .68823 L p .707 .577 .707 r
F P
0 g
s
.70195 .68823 m .70195 .63265 L .70485 .64119 L p .707 .577 .707 r
F P
0 g
s
.50385 .79476 m .50385 .81328 L .51644 .82117 L p .707 .577 .707 r
F P
0 g
s
.50385 .74904 m .50385 .71199 L .50095 .70345 L p .707 .577 .707 r
F P
0 g
s
.50095 .70345 m .50095 .7405 L .50385 .74904 L p .707 .577 .707 r
F P
0 g
s
.69777 .79821 m .69777 .81674 L .70485 .80838 L p .707 .577 .707 r
F P
0 g
s
.70485 .80838 m .70485 .78985 L .69777 .79821 L p .707 .577 .707 r
F P
0 g
s
.50095 .69314 m .50095 .63755 L .50804 .62919 L p .707 .577 .707 r
F P
0 g
s
.70485 .70708 m .70485 .74414 L .70195 .73559 L p .707 .577 .707 r
F P
0 g
s
.70195 .73559 m .70195 .69854 L .70485 .70708 L p .707 .577 .707 r
F P
0 g
s
.50385 .81328 m .50385 .79476 L .50095 .78621 L p .707 .577 .707 r
F P
0 g
s
.49044 .85617 m .49044 .35428 L .44643 .3516 L p .707 .577 .707 r
F P
0 g
s
.50804 .62919 m .50804 .68477 L .50095 .69314 L p .707 .577 .707 r
F P
0 g
s
.50095 .78621 m .50095 .80474 L .50385 .81328 L p .707 .577 .707 r
F P
0 g
s
.50095 .7405 m .50095 .70345 L .50804 .69508 L p .707 .577 .707 r
F P
0 g
s
.50804 .69508 m .50804 .73214 L .50095 .7405 L p .707 .577 .707 r
F P
0 g
s
.50804 .68477 m .50804 .62919 L .5244 .62182 L p .707 .577 .707 r
F P
0 g
s
.50095 .80474 m .50095 .78621 L .50804 .77785 L p .707 .577 .707 r
F P
0 g
s
.5244 .62182 m .5244 .6774 L .50804 .68477 L p .707 .577 .707 r
F P
0 g
s
.50804 .77785 m .50804 .79638 L .50095 .80474 L p .707 .577 .707 r
F P
0 g
s
.50804 .73214 m .50804 .69508 L .5244 .68771 L p .707 .577 .707 r
F P
0 g
s
.5244 .68771 m .5244 .72477 L .50804 .73214 L p .707 .577 .707 r
F P
0 g
s
.50804 .79638 m .50804 .77785 L .5244 .77048 L p .707 .577 .707 r
F P
0 g
s
.5244 .77048 m .5244 .78901 L .50804 .79638 L p .707 .577 .707 r
F P
0 g
s
.5244 .78901 m .5244 .77048 L .54846 .76483 L p .707 .577 .707 r
F P
0 g
s
.54846 .76483 m .54846 .78336 L .5244 .78901 L p .707 .577 .707 r
F P
0 g
s
.49044 .35428 m .49044 .85617 L .53538 .85507 L p .707 .577 .707 r
F P
0 g
s
.5244 .6774 m .5244 .62182 L .54846 .61617 L p .707 .577 .707 r
F P
0 g
s
.54846 .61617 m .54846 .67175 L .5244 .6774 L p .707 .577 .707 r
F P
0 g
s
.5244 .72477 m .5244 .68771 L .54846 .68206 L p .707 .577 .707 r
F P
0 g
s
.54846 .68206 m .54846 .71912 L .5244 .72477 L p .707 .577 .707 r
F P
0 g
s
.53538 .85507 m .53538 .35318 L .49044 .35428 L p .707 .577 .707 r
F P
0 g
s
.70195 .63265 m .70195 .68823 L .68936 .68034 L p .707 .577 .707 r
F P
0 g
s
.68936 .68034 m .68936 .62476 L .70195 .63265 L p .707 .577 .707 r
F P
0 g
s
.54846 .67175 m .54846 .61617 L .57784 .61279 L p .707 .577 .707 r
F P
0 g
s
.57784 .61279 m .57784 .66838 L .54846 .67175 L p .707 .577 .707 r
F P
0 g
s
.54846 .71912 m .54846 .68206 L .57784 .67869 L p .707 .577 .707 r
F P
0 g
s
.57784 .67869 m .57784 .71574 L .54846 .71912 L p .707 .577 .707 r
F P
0 g
s
.54846 .78336 m .54846 .76483 L .57784 .76145 L p .707 .577 .707 r
F P
0 g
s
.57784 .76145 m .57784 .77998 L .54846 .78336 L p .707 .577 .707 r
F P
0 g
s
.53538 .35318 m .53538 .85507 L .57686 .8503 L p .707 .577 .707 r
F P
0 g
s
.57686 .8503 m .57686 .34841 L .53538 .35318 L p .707 .577 .707 r
F P
0 g
s
.44643 .85349 m .44643 .3516 L .40766 .3454 L p .707 .577 .707 r
F P
0 g
s
.44643 .3516 m .44643 .85349 L .49044 .85617 L p .707 .577 .707 r
F P
0 g
s
.25312 .68549 m .25312 .62991 L .22195 .62801 L p .707 .577 .707 r
F P
0 g
s
.25312 .62991 m .25312 .68549 L .28495 .68472 L p .707 .577 .707 r
F P
0 g
s
.28495 .68472 m .28495 .62913 L .25312 .62991 L p .707 .577 .707 r
F P
0 g
s
.70485 .78985 m .70485 .80838 L .70195 .79983 L p .707 .577 .707 r
F P
0 g
s
.70195 .79983 m .70195 .78131 L .70485 .78985 L p .707 .577 .707 r
F P
0 g
s
.28495 .62913 m .28495 .68472 L .31434 .68134 L p .707 .577 .707 r
F P
0 g
s
.31434 .68134 m .31434 .62576 L .28495 .62913 L p .707 .577 .707 r
F P
0 g
s
.22195 .68359 m .22195 .62801 L .19449 .62362 L p .707 .577 .707 r
F P
0 g
s
.22195 .62801 m .22195 .68359 L .25312 .68549 L p .707 .577 .707 r
F P
0 g
s
.57784 .66838 m .57784 .61279 L .60968 .61202 L p .707 .577 .707 r
F P
0 g
s
.60968 .61202 m .60968 .6676 L .57784 .66838 L p .707 .577 .707 r
F P
0 g
s
.57784 .71574 m .57784 .67869 L .60968 .67791 L p .707 .577 .707 r
F P
0 g
s
.60968 .67791 m .60968 .71496 L .57784 .71574 L p .707 .577 .707 r
F P
0 g
s
.57784 .77998 m .57784 .76145 L .60968 .76067 L p .707 .577 .707 r
F P
0 g
s
.60968 .76067 m .60968 .7792 L .57784 .77998 L p .707 .577 .707 r
F P
0 g
s
.57686 .34841 m .57686 .8503 L .61082 .84233 L p .707 .577 .707 r
F P
0 g
s
.64085 .61392 m .64085 .6695 L .60968 .6676 L p .707 .577 .707 r
F P
0 g
s
.60968 .6676 m .60968 .61202 L .64085 .61392 L p .707 .577 .707 r
F P
0 g
s
.64085 .67981 m .64085 .71686 L .60968 .71496 L p .707 .577 .707 r
F P
0 g
s
.60968 .71496 m .60968 .67791 L .64085 .67981 L p .707 .577 .707 r
F P
0 g
s
.64085 .76258 m .64085 .7811 L .60968 .7792 L p .707 .577 .707 r
F P
0 g
s
.60968 .7792 m .60968 .76067 L .64085 .76258 L p .707 .577 .707 r
F P
0 g
s
.61082 .84233 m .61082 .34044 L .57686 .34841 L p .707 .577 .707 r
F P
0 g
s
.70195 .69854 m .70195 .73559 L .68936 .72771 L p .707 .577 .707 r
F P
0 g
s
.68936 .72771 m .68936 .69066 L .70195 .69854 L p .707 .577 .707 r
F P
0 g
s
.31434 .62576 m .31434 .68134 L .33839 .67569 L p .707 .577 .707 r
F P
0 g
s
.33839 .67569 m .33839 .62011 L .31434 .62576 L p .707 .577 .707 r
F P
0 g
s
.25312 .73286 m .25312 .6958 L .22195 .6939 L p .707 .577 .707 r
F P
0 g
s
.25312 .6958 m .25312 .73286 L .28495 .73208 L p .707 .577 .707 r
F P
0 g
s
.28495 .73208 m .28495 .69503 L .25312 .6958 L p .707 .577 .707 r
F P
0 g
s
.40766 .84729 m .40766 .3454 L .37794 .33629 L p .707 .577 .707 r
F P
0 g
s
.40766 .3454 m .40766 .84729 L .44643 .85349 L p .707 .577 .707 r
F P
0 g
s
.68936 .62476 m .68936 .68034 L .66831 .67389 L p .707 .577 .707 r
F P
0 g
s
.66831 .67389 m .66831 .61831 L .68936 .62476 L p .707 .577 .707 r
F P
0 g
s
.28495 .69503 m .28495 .73208 L .31434 .7287 L p .707 .577 .707 r
F P
0 g
s
.31434 .7287 m .31434 .69165 L .28495 .69503 L p .707 .577 .707 r
F P
0 g
s
.19449 .62362 m .19449 .6792 L .22195 .68359 L p .707 .577 .707 r
F P
0 g
s
.19449 .6792 m .19449 .62362 L .17343 .61716 L p .707 .577 .707 r
F P
0 g
s
.22195 .73096 m .22195 .6939 L .19449 .68951 L p .707 .577 .707 r
F P
0 g
s
.22195 .6939 m .22195 .73096 L .25312 .73286 L p .707 .577 .707 r
F P
0 g
s
.70195 .78131 m .70195 .79983 L .68936 .79195 L p .707 .577 .707 r
F P
0 g
s
.68936 .79195 m .68936 .77342 L .70195 .78131 L p .707 .577 .707 r
F P
0 g
s
.31434 .69165 m .31434 .7287 L .33839 .72305 L p .707 .577 .707 r
F P
0 g
s
.33839 .72305 m .33839 .686 L .31434 .69165 L p .707 .577 .707 r
F P
0 g
s
.33839 .62011 m .33839 .67569 L .35476 .66832 L p .707 .577 .707 r
F P
0 g
s
.35476 .66832 m .35476 .61274 L .33839 .62011 L p .707 .577 .707 r
F P
0 g
s
.19449 .68951 m .19449 .72657 L .22195 .73096 L p .707 .577 .707 r
F P
0 g
s
.61082 .34044 m .61082 .84233 L .63393 .83192 L p .707 .577 .707 r
F P
0 g
s
.63393 .83192 m .63393 .33004 L .61082 .34044 L p .707 .577 .707 r
F P
0 g
s
.68936 .69066 m .68936 .72771 L .66831 .72126 L p .707 .577 .707 r
F P
0 g
s
.66831 .72126 m .66831 .6842 L .68936 .69066 L p .707 .577 .707 r
F P
0 g
s
.17343 .61716 m .17343 .67275 L .19449 .6792 L p .707 .577 .707 r
F P
0 g
s
.19449 .72657 m .19449 .68951 L .17343 .68306 L p .707 .577 .707 r
F P
0 g
s
.25312 .7971 m .25312 .77857 L .22195 .77667 L p .707 .577 .707 r
F P
0 g
s
.25312 .77857 m .25312 .7971 L .28495 .79632 L p .707 .577 .707 r
F P
0 g
s
.28495 .79632 m .28495 .77779 L .25312 .77857 L p .707 .577 .707 r
F P
0 g
s
.66831 .61831 m .66831 .67389 L .64085 .6695 L p .707 .577 .707 r
F P
0 g
s
.64085 .6695 m .64085 .61392 L .66831 .61831 L p .707 .577 .707 r
F P
0 g
s
.28495 .77779 m .28495 .79632 L .31434 .79294 L p .707 .577 .707 r
F P
0 g
s
.31434 .79294 m .31434 .77441 L .28495 .77779 L p .707 .577 .707 r
F P
0 g
s
.17343 .67275 m .17343 .61716 L .16084 .60928 L p .707 .577 .707 r
F P
0 g
s
.22195 .77667 m .22195 .7952 L .25312 .7971 L p .707 .577 .707 r
F P
0 g
s
.22195 .7952 m .22195 .77667 L .19449 .77228 L p .707 .577 .707 r
F P
0 g
s
.37794 .83817 m .37794 .33629 L .36016 .32515 L p .707 .577 .707 r
F P
0 g
s
.37794 .33629 m .37794 .83817 L .40766 .84729 L p .707 .577 .707 r
F P
0 g
s
.17343 .68306 m .17343 .72011 L .19449 .72657 L p .707 .577 .707 r
F P
0 g
s
.19449 .77228 m .19449 .79081 L .22195 .7952 L p .707 .577 .707 r
F P
0 g
s
.33839 .686 m .33839 .72305 L .35476 .71569 L p .707 .577 .707 r
F P
0 g
s
.35476 .71569 m .35476 .67863 L .33839 .686 L p .707 .577 .707 r
F P
0 g
s
.31434 .77441 m .31434 .79294 L .33839 .78729 L p .707 .577 .707 r
F P
0 g
s
.33839 .78729 m .33839 .76876 L .31434 .77441 L p .707 .577 .707 r
F P
0 g
s
.68936 .77342 m .68936 .79195 L .66831 .7855 L p .707 .577 .707 r
F P
0 g
s
.66831 .7855 m .66831 .76697 L .68936 .77342 L p .707 .577 .707 r
F P
0 g
s
.66831 .6842 m .66831 .72126 L .64085 .71686 L p .707 .577 .707 r
F P
0 g
s
.64085 .71686 m .64085 .67981 L .66831 .6842 L p .707 .577 .707 r
F P
0 g
s
.16084 .60928 m .16084 .66486 L .17343 .67275 L p .707 .577 .707 r
F P
0 g
s
.35476 .61274 m .35476 .66832 L .36184 .65996 L p .707 .577 .707 r
F P
0 g
s
.36184 .65996 m .36184 .60437 L .35476 .61274 L p .707 .577 .707 r
F P
0 g
s
.19449 .79081 m .19449 .77228 L .17343 .76582 L p .707 .577 .707 r
F P
0 g
s
.17343 .72011 m .17343 .68306 L .16084 .67517 L p .707 .577 .707 r
F P
0 g
s
.17343 .76582 m .17343 .78435 L .19449 .79081 L p .707 .577 .707 r
F P
0 g
s
.66831 .76697 m .66831 .7855 L .64085 .7811 L p .707 .577 .707 r
F P
0 g
s
.64085 .7811 m .64085 .76258 L .66831 .76697 L p .707 .577 .707 r
F P
0 g
s
.63393 .33004 m .63393 .83192 L .64393 .82012 L p .707 .577 .707 r
F P
0 g
s
.64393 .82012 m .64393 .31823 L .63393 .33004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66486 m .16084 .60928 L .15794 .60074 L p .707 .577 .707 r
F P
0 g
s
.16084 .67517 m .16084 .71223 L .17343 .72011 L p .707 .577 .707 r
F P
0 g
s
.33839 .76876 m .33839 .78729 L .35476 .77992 L p .707 .577 .707 r
F P
0 g
s
.35476 .77992 m .35476 .7614 L .33839 .76876 L p .707 .577 .707 r
F P
0 g
s
.35476 .67863 m .35476 .71569 L .36184 .70732 L p .707 .577 .707 r
F P
0 g
s
.36184 .70732 m .36184 .67027 L .35476 .67863 L p .707 .577 .707 r
F P
0 g
s
.17343 .78435 m .17343 .76582 L .16084 .75794 L p .707 .577 .707 r
F P
0 g
s
.15794 .60074 m .15794 .65632 L .16084 .66486 L p .707 .577 .707 r
F P
0 g
s
.36184 .60437 m .36184 .65996 L .35894 .65141 L p .707 .577 .707 r
F P
0 g
s
.35894 .65141 m .35894 .59583 L .36184 .60437 L p .707 .577 .707 r
F P
0 g
s
.35476 .7614 m .35476 .77992 L .36184 .77156 L p .707 .577 .707 r
F P
0 g
s
.36184 .77156 m .36184 .75303 L .35476 .7614 L p .707 .577 .707 r
F P
0 g
s
.36184 .67027 m .36184 .70732 L .35894 .69878 L p .707 .577 .707 r
F P
0 g
s
.35894 .69878 m .35894 .66172 L .36184 .67027 L p .707 .577 .707 r
F P
0 g
s
.35894 .59583 m .35894 .65141 L .34635 .64353 L p .707 .577 .707 r
F P
0 g
s
.34635 .64353 m .34635 .58795 L .35894 .59583 L p .707 .577 .707 r
F P
0 g
s
.36184 .75303 m .36184 .77156 L .35894 .76302 L p .707 .577 .707 r
F P
0 g
s
.35894 .76302 m .35894 .74449 L .36184 .75303 L p .707 .577 .707 r
F P
0 g
s
.35894 .66172 m .35894 .69878 L .34635 .69089 L p .707 .577 .707 r
F P
0 g
s
.34635 .69089 m .34635 .65384 L .35894 .66172 L p .707 .577 .707 r
F P
0 g
s
.36016 .82704 m .36016 .32515 L .35607 .31309 L p .707 .577 .707 r
F P
0 g
s
.36016 .32515 m .36016 .82704 L .37794 .83817 L p .707 .577 .707 r
F P
0 g
s
.16084 .75794 m .16084 .77647 L .17343 .78435 L p .707 .577 .707 r
F P
0 g
s
.16084 .71223 m .16084 .67517 L .15794 .66663 L p .707 .577 .707 r
F P
0 g
s
.15794 .66663 m .15794 .70369 L .16084 .71223 L p .707 .577 .707 r
F P
0 g
s
.15794 .65632 m .15794 .60074 L .16503 .59237 L p .707 .577 .707 r
F P
0 g
s
.16084 .77647 m .16084 .75794 L .15794 .7494 L p .707 .577 .707 r
F P
0 g
s
.64393 .31823 m .64393 .82012 L .63984 .80806 L p .707 .577 .707 r
F P
0 g
s
.63984 .80806 m .63984 .30617 L .64393 .31823 L p .707 .577 .707 r
F P
0 g
s
.16503 .59237 m .16503 .64796 L .15794 .65632 L p .707 .577 .707 r
F P
0 g
s
.15794 .7494 m .15794 .76793 L .16084 .77647 L p .707 .577 .707 r
F P
0 g
s
.15794 .70369 m .15794 .66663 L .16503 .65827 L p .707 .577 .707 r
F P
0 g
s
.16503 .65827 m .16503 .69532 L .15794 .70369 L p .707 .577 .707 r
F P
0 g
s
.35894 .74449 m .35894 .76302 L .34635 .75513 L p .707 .577 .707 r
F P
0 g
s
.34635 .75513 m .34635 .73661 L .35894 .74449 L p .707 .577 .707 r
F P
0 g
s
.35607 .31309 m .35607 .81498 L .36016 .82704 L p .707 .577 .707 r
F P
0 g
s
.35607 .81498 m .35607 .31309 L .36607 .30129 L p .707 .577 .707 r
F P
0 g
s
.16503 .64796 m .16503 .59237 L .1814 .58501 L p .707 .577 .707 r
F P
0 g
s
.15794 .76793 m .15794 .7494 L .16503 .74103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58501 m .1814 .64059 L .16503 .64796 L p .707 .577 .707 r
F P
0 g
s
.34635 .58795 m .34635 .64353 L .3253 .63708 L p .707 .577 .707 r
F P
0 g
s
.3253 .63708 m .3253 .58149 L .34635 .58795 L p .707 .577 .707 r
F P
0 g
s
.16503 .74103 m .16503 .75956 L .15794 .76793 L p .707 .577 .707 r
F P
0 g
s
.16503 .69532 m .16503 .65827 L .1814 .6509 L p .707 .577 .707 r
F P
0 g
s
.63984 .30617 m .63984 .80806 L .62206 .79693 L p .707 .577 .707 r
F P
0 g
s
.62206 .79693 m .62206 .29504 L .63984 .30617 L p .707 .577 .707 r
F P
0 g
s
.1814 .64059 m .1814 .58501 L .20545 .57936 L p .707 .577 .707 r
F P
0 g
s
.1814 .6509 m .1814 .68795 L .16503 .69532 L p .707 .577 .707 r
F P
0 g
s
.34635 .65384 m .34635 .69089 L .3253 .68444 L p .707 .577 .707 r
F P
0 g
s
.3253 .68444 m .3253 .64739 L .34635 .65384 L p .707 .577 .707 r
F P
0 g
s
.3253 .58149 m .3253 .63708 L .29784 .63268 L p .707 .577 .707 r
F P
0 g
s
.29784 .63268 m .29784 .5771 L .3253 .58149 L p .707 .577 .707 r
F P
0 g
s
.16503 .75956 m .16503 .74103 L .1814 .73367 L p .707 .577 .707 r
F P
0 g
s
.20545 .57936 m .20545 .63494 L .1814 .64059 L p .707 .577 .707 r
F P
0 g
s
.36607 .80318 m .36607 .30129 L .38918 .29088 L p .707 .577 .707 r
F P
0 g
s
.36607 .30129 m .36607 .80318 L .35607 .81498 L p .707 .577 .707 r
F P
0 g
s
.1814 .68795 m .1814 .6509 L .20545 .64525 L p .707 .577 .707 r
F P
0 g
s
.1814 .73367 m .1814 .75219 L .16503 .75956 L p .707 .577 .707 r
F P
0 g
s
.20545 .63494 m .20545 .57936 L .23483 .57598 L p .707 .577 .707 r
F P
0 g
s
.29784 .5771 m .29784 .63268 L .26667 .63078 L p .707 .577 .707 r
F P
0 g
s
.26667 .63078 m .26667 .5752 L .29784 .5771 L p .707 .577 .707 r
F P
0 g
s
.20545 .64525 m .20545 .6823 L .1814 .68795 L p .707 .577 .707 r
F P
0 g
s
.34635 .73661 m .34635 .75513 L .3253 .74868 L p .707 .577 .707 r
F P
0 g
s
.3253 .74868 m .3253 .73015 L .34635 .73661 L p .707 .577 .707 r
F P
0 g
s
.3253 .64739 m .3253 .68444 L .29784 .68005 L p .707 .577 .707 r
F P
0 g
s
.29784 .68005 m .29784 .64299 L .3253 .64739 L p .707 .577 .707 r
F P
0 g
s
.23483 .63156 m .23483 .57598 L .26667 .5752 L p .707 .577 .707 r
F P
0 g
s
.23483 .57598 m .23483 .63156 L .20545 .63494 L p .707 .577 .707 r
F P
0 g
s
.26667 .5752 m .26667 .63078 L .23483 .63156 L p .707 .577 .707 r
F P
0 g
s
.73333 .63027 m .73333 .57469 L .70216 .57279 L p .707 .577 .707 r
F P
0 g
s
.73333 .57469 m .73333 .63027 L .76517 .62949 L p .707 .577 .707 r
F P
0 g
s
.76517 .62949 m .76517 .57391 L .73333 .57469 L p .707 .577 .707 r
F P
0 g
s
.62206 .29504 m .62206 .79693 L .59233 .78781 L p .707 .577 .707 r
F P
0 g
s
.59233 .78781 m .59233 .28592 L .62206 .29504 L p .707 .577 .707 r
F P
0 g
s
.20545 .6823 m .20545 .64525 L .23483 .64187 L p .707 .577 .707 r
F P
0 g
s
.76517 .57391 m .76517 .62949 L .79455 .62611 L p .707 .577 .707 r
F P
0 g
s
.79455 .62611 m .79455 .57053 L .76517 .57391 L p .707 .577 .707 r
F P
0 g
s
.1814 .75219 m .1814 .73367 L .20545 .72802 L p .707 .577 .707 r
F P
0 g
s
.70216 .62837 m .70216 .57279 L .6747 .5684 L p .707 .577 .707 r
F P
0 g
s
.70216 .57279 m .70216 .62837 L .73333 .63027 L p .707 .577 .707 r
F P
0 g
s
.20545 .72802 m .20545 .74654 L .1814 .75219 L p .707 .577 .707 r
F P
0 g
s
.29784 .64299 m .29784 .68005 L .26667 .67815 L p .707 .577 .707 r
F P
0 g
s
.26667 .67815 m .26667 .64109 L .29784 .64299 L p .707 .577 .707 r
F P
0 g
s
.23483 .64187 m .23483 .67893 L .20545 .6823 L p .707 .577 .707 r
F P
0 g
s
.23483 .67893 m .23483 .64187 L .26667 .64109 L p .707 .577 .707 r
F P
0 g
s
.79455 .57053 m .79455 .62611 L .8186 .62046 L p .707 .577 .707 r
F P
0 g
s
.8186 .62046 m .8186 .56488 L .79455 .57053 L p .707 .577 .707 r
F P
0 g
s
.38918 .29088 m .38918 .79277 L .36607 .80318 L p .707 .577 .707 r
F P
0 g
s
.38918 .79277 m .38918 .29088 L .42314 .28291 L p .707 .577 .707 r
F P
0 g
s
.26667 .64109 m .26667 .67815 L .23483 .67893 L p .707 .577 .707 r
F P
0 g
s
.3253 .73015 m .3253 .74868 L .29784 .74429 L p .707 .577 .707 r
F P
0 g
s
.29784 .74429 m .29784 .72576 L .3253 .73015 L p .707 .577 .707 r
F P
0 g
s
.73333 .67764 m .73333 .64058 L .70216 .63868 L p .707 .577 .707 r
F P
0 g
s
.73333 .64058 m .73333 .67764 L .76517 .67686 L p .707 .577 .707 r
F P
0 g
s
.76517 .67686 m .76517 .6398 L .73333 .64058 L p .707 .577 .707 r
F P
0 g
s
.76517 .6398 m .76517 .67686 L .79455 .67348 L p .707 .577 .707 r
F P
0 g
s
.79455 .67348 m .79455 .63643 L .76517 .6398 L p .707 .577 .707 r
F P
0 g
s
.6747 .5684 m .6747 .62398 L .70216 .62837 L p .707 .577 .707 r
F P
0 g
s
.6747 .62398 m .6747 .5684 L .65365 .56194 L p .707 .577 .707 r
F P
0 g
s
.20545 .74654 m .20545 .72802 L .23483 .72464 L p .707 .577 .707 r
F P
0 g
s
.70216 .67574 m .70216 .63868 L .6747 .63429 L p .707 .577 .707 r
F P
0 g
s
.70216 .63868 m .70216 .67574 L .73333 .67764 L p .707 .577 .707 r
F P
0 g
s
.23483 .72464 m .23483 .74316 L .20545 .74654 L p .707 .577 .707 r
F P
0 g
s
.29784 .72576 m .29784 .74429 L .26667 .74239 L p .707 .577 .707 r
F P
0 g
s
.26667 .74239 m .26667 .72386 L .29784 .72576 L p .707 .577 .707 r
F P
0 g
s
.79455 .63643 m .79455 .67348 L .8186 .66783 L p .707 .577 .707 r
F P
0 g
s
.8186 .66783 m .8186 .63078 L .79455 .63643 L p .707 .577 .707 r
F P
0 g
s
.59233 .28592 m .59233 .78781 L .55357 .78161 L p .707 .577 .707 r
F P
0 g
s
.55357 .78161 m .55357 .27972 L .59233 .28592 L p .707 .577 .707 r
F P
0 g
s
.8186 .56488 m .8186 .62046 L .83497 .6131 L p .707 .577 .707 r
F P
0 g
s
.83497 .6131 m .83497 .55751 L .8186 .56488 L p .707 .577 .707 r
F P
0 g
s
.6747 .63429 m .6747 .67134 L .70216 .67574 L p .707 .577 .707 r
F P
0 g
s
.23483 .74316 m .23483 .72464 L .26667 .72386 L p .707 .577 .707 r
F P
0 g
s
.65365 .56194 m .65365 .61752 L .6747 .62398 L p .707 .577 .707 r
F P
0 g
s
.26667 .72386 m .26667 .74239 L .23483 .74316 L p .707 .577 .707 r
F P
0 g
s
.6747 .67134 m .6747 .63429 L .65365 .62783 L p .707 .577 .707 r
F P
0 g
s
.73333 .74188 m .73333 .72335 L .70216 .72145 L p .707 .577 .707 r
F P
0 g
s
.73333 .72335 m .73333 .74188 L .76517 .7411 L p .707 .577 .707 r
F P
0 g
s
.76517 .7411 m .76517 .72257 L .73333 .72335 L p .707 .577 .707 r
F P
0 g
s
.76517 .72257 m .76517 .7411 L .79455 .73772 L p .707 .577 .707 r
F P
0 g
s
.79455 .73772 m .79455 .71919 L .76517 .72257 L p .707 .577 .707 r
F P
0 g
s
.42314 .7848 m .42314 .28291 L .46462 .27814 L p .707 .577 .707 r
F P
0 g
s
.42314 .28291 m .42314 .7848 L .38918 .79277 L p .707 .577 .707 r
F P
0 g
s
.65365 .61752 m .65365 .56194 L .64105 .55406 L p .707 .577 .707 r
F P
0 g
s
.70216 .72145 m .70216 .73997 L .73333 .74188 L p .707 .577 .707 r
F P
0 g
s
.70216 .73997 m .70216 .72145 L .6747 .71705 L p .707 .577 .707 r
F P
0 g
s
.65365 .62783 m .65365 .66489 L .6747 .67134 L p .707 .577 .707 r
F P
0 g
s
.6747 .71705 m .6747 .73558 L .70216 .73997 L p .707 .577 .707 r
F P
0 g
s
.8186 .63078 m .8186 .66783 L .83497 .66046 L p .707 .577 .707 r
F P
0 g
s
.83497 .66046 m .83497 .62341 L .8186 .63078 L p .707 .577 .707 r
F P
0 g
s
.55357 .27972 m .55357 .78161 L .50956 .77893 L p .707 .577 .707 r
F P
0 g
s
.50956 .77893 m .50956 .27704 L .55357 .27972 L p .707 .577 .707 r
F P
0 g
s
.79455 .71919 m .79455 .73772 L .8186 .73207 L p .707 .577 .707 r
F P
0 g
s
.8186 .73207 m .8186 .71354 L .79455 .71919 L p .707 .577 .707 r
F P
0 g
s
.64105 .55406 m .64105 .60964 L .65365 .61752 L p .707 .577 .707 r
F P
0 g
s
.46462 .78003 m .46462 .27814 L .50956 .27704 L p .707 .577 .707 r
F P
0 g
s
.46462 .27814 m .46462 .78003 L .42314 .7848 L p .707 .577 .707 r
F P
0 g
s
.83497 .55751 m .83497 .6131 L .84205 .60473 L p .707 .577 .707 r
F P
0 g
s
.84205 .60473 m .84205 .54915 L .83497 .55751 L p .707 .577 .707 r
F P
0 g
s
.6747 .73558 m .6747 .71705 L .65365 .7106 L p .707 .577 .707 r
F P
0 g
s
.65365 .66489 m .65365 .62783 L .64105 .61995 L p .707 .577 .707 r
F P
0 g
s
.50956 .27704 m .50956 .77893 L .46462 .78003 L p .707 .577 .707 r
F P
0 g
s
.65365 .7106 m .65365 .72913 L .6747 .73558 L p .707 .577 .707 r
F P
0 g
s
.64105 .60964 m .64105 .55406 L .63816 .54551 L p .707 .577 .707 r
F P
0 g
s
.64105 .61995 m .64105 .65701 L .65365 .66489 L p .707 .577 .707 r
F P
0 g
s
.8186 .71354 m .8186 .73207 L .83497 .7247 L p .707 .577 .707 r
F P
0 g
s
.83497 .7247 m .83497 .70617 L .8186 .71354 L p .707 .577 .707 r
F P
0 g
s
.83497 .62341 m .83497 .66046 L .84205 .6521 L p .707 .577 .707 r
F P
0 g
s
.84205 .6521 m .84205 .61504 L .83497 .62341 L p .707 .577 .707 r
F P
0 g
s
.65365 .72913 m .65365 .7106 L .64105 .70272 L p .707 .577 .707 r
F P
0 g
s
.63816 .54551 m .63816 .6011 L .64105 .60964 L p .707 .577 .707 r
F P
0 g
s
.84205 .54915 m .84205 .60473 L .83916 .59619 L p .707 .577 .707 r
F P
0 g
s
.83916 .59619 m .83916 .54061 L .84205 .54915 L p .707 .577 .707 r
F P
0 g
s
.64105 .70272 m .64105 .72124 L .65365 .72913 L p .707 .577 .707 r
F P
0 g
s
.64105 .65701 m .64105 .61995 L .63816 .61141 L p .707 .577 .707 r
F P
0 g
s
.63816 .61141 m .63816 .64846 L .64105 .65701 L p .707 .577 .707 r
F P
0 g
s
.83497 .70617 m .83497 .7247 L .84206 .71634 L p .707 .577 .707 r
F P
0 g
s
.84206 .71634 m .84206 .69781 L .83497 .70617 L p .707 .577 .707 r
F P
0 g
s
.63816 .6011 m .63816 .54551 L .64524 .53715 L p .707 .577 .707 r
F P
0 g
s
.84205 .61504 m .84205 .6521 L .83916 .64356 L p .707 .577 .707 r
F P
0 g
s
.83916 .64356 m .83916 .6065 L .84205 .61504 L p .707 .577 .707 r
F P
0 g
s
.64105 .72124 m .64105 .70272 L .63816 .69417 L p .707 .577 .707 r
F P
0 g
s
.64524 .53715 m .64524 .59273 L .63816 .6011 L p .707 .577 .707 r
F P
0 g
s
.63816 .69417 m .63816 .7127 L .64105 .72124 L p .707 .577 .707 r
F P
0 g
s
.83916 .54061 m .83916 .59619 L .82657 .58831 L p .707 .577 .707 r
F P
0 g
s
.82657 .58831 m .82657 .53272 L .83916 .54061 L p .707 .577 .707 r
F P
0 g
s
.63816 .64846 m .63816 .61141 L .64524 .60304 L p .707 .577 .707 r
F P
0 g
s
.39032 .59345 m .39032 .53787 L .35915 .53597 L p .707 .577 .707 r
F P
0 g
s
.39032 .53787 m .39032 .59345 L .42216 .59268 L p .707 .577 .707 r
F P
0 g
s
.42216 .59268 m .42216 .5371 L .39032 .53787 L p .707 .577 .707 r
F P
0 g
s
.84206 .69781 m .84206 .71634 L .83916 .7078 L p .707 .577 .707 r
F P
0 g
s
.83916 .7078 m .83916 .68927 L .84206 .69781 L p .707 .577 .707 r
F P
0 g
s
.64524 .60304 m .64524 .6401 L .63816 .64846 L p .707 .577 .707 r
F P
0 g
s
.64524 .59273 m .64524 .53715 L .66161 .52978 L p .707 .577 .707 r
F P
0 g
s
.42216 .5371 m .42216 .59268 L .45154 .5893 L p .707 .577 .707 r
F P
0 g
s
.45154 .5893 m .45154 .53372 L .42216 .5371 L p .707 .577 .707 r
F P
0 g
s
.35915 .59155 m .35915 .53597 L .33169 .53158 L p .707 .577 .707 r
F P
0 g
s
.35915 .53597 m .35915 .59155 L .39032 .59345 L p .707 .577 .707 r
F P
0 g
s
.83916 .6065 m .83916 .64356 L .82657 .63567 L p .707 .577 .707 r
F P
0 g
s
.82657 .63567 m .82657 .59862 L .83916 .6065 L p .707 .577 .707 r
F P
0 g
s
.63816 .7127 m .63816 .69417 L .64524 .68581 L p .707 .577 .707 r
F P
0 g
s
.45154 .53372 m .45154 .5893 L .47559 .58365 L p .707 .577 .707 r
F P
0 g
s
.47559 .58365 m .47559 .52807 L .45154 .53372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52978 m .66161 .58537 L .64524 .59273 L p .707 .577 .707 r
F P
0 g
s
.39032 .64082 m .39032 .60377 L .35915 .60187 L p .707 .577 .707 r
F P
0 g
s
.39032 .60377 m .39032 .64082 L .42216 .64004 L p .707 .577 .707 r
F P
0 g
s
.42216 .64004 m .42216 .60299 L .39032 .60377 L p .707 .577 .707 r
F P
0 g
s
.82657 .53272 m .82657 .58831 L .80551 .58185 L p .707 .577 .707 r
F P
0 g
s
.80551 .58185 m .80551 .52627 L .82657 .53272 L p .707 .577 .707 r
F P
0 g
s
.64524 .68581 m .64524 .70434 L .63816 .7127 L p .707 .577 .707 r
F P
0 g
s
.64524 .6401 m .64524 .60304 L .66161 .59568 L p .707 .577 .707 r
F P
0 g
s
.42216 .60299 m .42216 .64004 L .45154 .63666 L p .707 .577 .707 r
F P
0 g
s
.45154 .63666 m .45154 .59961 L .42216 .60299 L p .707 .577 .707 r
F P
0 g
s
.33169 .53158 m .33169 .58716 L .35915 .59155 L p .707 .577 .707 r
F P
0 g
s
.33169 .58716 m .33169 .53158 L .31064 .52513 L p .707 .577 .707 r
F P
0 g
s
.35915 .63892 m .35915 .60187 L .33169 .59747 L p .707 .577 .707 r
F P
0 g
s
.35915 .60187 m .35915 .63892 L .39032 .64082 L p .707 .577 .707 r
F P
0 g
s
.66161 .58537 m .66161 .52978 L .68566 .52413 L p .707 .577 .707 r
F P
0 g
s
.66161 .59568 m .66161 .63273 L .64524 .6401 L p .707 .577 .707 r
F P
0 g
s
.83916 .68927 m .83916 .7078 L .82657 .69991 L p .707 .577 .707 r
F P
0 g
s
.82657 .69991 m .82657 .68138 L .83916 .68927 L p .707 .577 .707 r
F P
0 g
s
.45154 .59961 m .45154 .63666 L .47559 .63101 L p .707 .577 .707 r
F P
0 g
s
.47559 .63101 m .47559 .59396 L .45154 .59961 L p .707 .577 .707 r
F P
0 g
s
.47559 .52807 m .47559 .58365 L .49196 .57628 L p .707 .577 .707 r
F P
0 g
s
.49196 .57628 m .49196 .5207 L .47559 .52807 L p .707 .577 .707 r
F P
0 g
s
.33169 .59747 m .33169 .63453 L .35915 .63892 L p .707 .577 .707 r
F P
0 g
s
.82657 .59862 m .82657 .63567 L .80551 .62922 L p .707 .577 .707 r
F P
0 g
s
.80551 .62922 m .80551 .59216 L .82657 .59862 L p .707 .577 .707 r
F P
0 g
s
.31064 .52513 m .31064 .58071 L .33169 .58716 L p .707 .577 .707 r
F P
0 g
s
.33169 .63453 m .33169 .59747 L .31064 .59102 L p .707 .577 .707 r
F P
0 g
s
.39032 .70506 m .39032 .68653 L .35915 .68463 L p .707 .577 .707 r
F P
0 g
s
.39032 .68653 m .39032 .70506 L .42216 .70428 L p .707 .577 .707 r
F P
0 g
s
.42216 .70428 m .42216 .68576 L .39032 .68653 L p .707 .577 .707 r
F P
0 g
s
.80551 .52627 m .80551 .58185 L .77805 .57746 L p .707 .577 .707 r
F P
0 g
s
.77805 .57746 m .77805 .52188 L .80551 .52627 L p .707 .577 .707 r
F P
0 g
s
.64524 .70434 m .64524 .68581 L .66161 .67844 L p .707 .577 .707 r
F P
0 g
s
.42216 .68576 m .42216 .70428 L .45154 .7009 L p .707 .577 .707 r
F P
0 g
s
.45154 .7009 m .45154 .68238 L .42216 .68576 L p .707 .577 .707 r
F P
0 g
s
.68566 .52413 m .68566 .57972 L .66161 .58537 L p .707 .577 .707 r
F P
0 g
s
.31064 .58071 m .31064 .52513 L .29804 .51724 L p .707 .577 .707 r
F P
0 g
s
.35915 .68463 m .35915 .70316 L .39032 .70506 L p .707 .577 .707 r
F P
0 g
s
.66161 .63273 m .66161 .59568 L .68566 .59003 L p .707 .577 .707 r
F P
0 g
s
.35915 .70316 m .35915 .68463 L .33169 .68024 L p .707 .577 .707 r
F P
0 g
s
.66161 .67844 m .66161 .69697 L .64524 .70434 L p .707 .577 .707 r
F P
0 g
s
.68566 .57972 m .68566 .52413 L .71504 .52075 L p .707 .577 .707 r
F P
0 g
s
.31064 .59102 m .31064 .62807 L .33169 .63453 L p .707 .577 .707 r
F P
0 g
s
.33169 .68024 m .33169 .69877 L .35915 .70316 L p .707 .577 .707 r
F P
0 g
s
.47559 .59396 m .47559 .63101 L .49196 .62365 L p .707 .577 .707 r
F P
0 g
s
.49196 .62365 m .49196 .58659 L .47559 .59396 L p .707 .577 .707 r
F P
0 g
s
.45154 .68238 m .45154 .7009 L .47559 .69525 L p .707 .577 .707 r
F P
0 g
s
.47559 .69525 m .47559 .67673 L .45154 .68238 L p .707 .577 .707 r
F P
0 g
s
.77805 .52188 m .77805 .57746 L .74688 .57556 L p .707 .577 .707 r
F P
0 g
s
.74688 .57556 m .74688 .51998 L .77805 .52188 L p .707 .577 .707 r
F P
0 g
s
.68566 .59003 m .68566 .62708 L .66161 .63273 L p .707 .577 .707 r
F P
0 g
s
.82657 .68138 m .82657 .69991 L .80551 .69346 L p .707 .577 .707 r
F P
0 g
s
.80551 .69346 m .80551 .67493 L .82657 .68138 L p .707 .577 .707 r
F P
0 g
s
.80551 .59216 m .80551 .62922 L .77805 .62483 L p .707 .577 .707 r
F P
0 g
s
.77805 .62483 m .77805 .58777 L .80551 .59216 L p .707 .577 .707 r
F P
0 g
s
.29804 .51724 m .29804 .57282 L .31064 .58071 L p .707 .577 .707 r
F P
0 g
s
.71504 .57634 m .71504 .52075 L .74688 .51998 L p .707 .577 .707 r
F P
0 g
s
.71504 .52075 m .71504 .57634 L .68566 .57972 L p .707 .577 .707 r
F P
0 g
s
.49196 .5207 m .49196 .57628 L .49904 .56792 L p .707 .577 .707 r
F P
0 g
s
.49904 .56792 m .49904 .51233 L .49196 .5207 L p .707 .577 .707 r
F P
0 g
s
.33169 .69877 m .33169 .68024 L .31064 .67379 L p .707 .577 .707 r
F P
0 g
s
.31064 .62807 m .31064 .59102 L .29804 .58313 L p .707 .577 .707 r
F P
0 g
s
.74688 .51998 m .74688 .57556 L .71504 .57634 L p .707 .577 .707 r
F P
0 g
s
.68566 .62708 m .68566 .59003 L .71504 .58665 L p .707 .577 .707 r
F P
0 g
s
.31064 .67379 m .31064 .69231 L .33169 .69877 L p .707 .577 .707 r
F P
0 g
s
.66161 .69697 m .66161 .67844 L .68566 .67279 L p .707 .577 .707 r
F P
0 g
s
.29804 .57282 m .29804 .51724 L .29515 .5087 L p .707 .577 .707 r
F P
0 g
s
.29804 .58313 m .29804 .62019 L .31064 .62807 L p .707 .577 .707 r
F P
0 g
s
.68566 .67279 m .68566 .69132 L .66161 .69697 L p .707 .577 .707 r
F P
0 g
s
.77805 .58777 m .77805 .62483 L .74688 .62292 L p .707 .577 .707 r
F P
0 g
s
.74688 .62292 m .74688 .58587 L .77805 .58777 L p .707 .577 .707 r
F P
0 g
s
.47559 .67673 m .47559 .69525 L .49196 .68789 L p .707 .577 .707 r
F P
0 g
s
.49196 .68789 m .49196 .66936 L .47559 .67673 L p .707 .577 .707 r
F P
0 g
s
.71504 .58665 m .71504 .6237 L .68566 .62708 L p .707 .577 .707 r
F P
0 g
s
.71504 .6237 m .71504 .58665 L .74688 .58587 L p .707 .577 .707 r
F P
0 g
s
.49196 .58659 m .49196 .62365 L .49904 .61528 L p .707 .577 .707 r
F P
0 g
s
.49904 .61528 m .49904 .57823 L .49196 .58659 L p .707 .577 .707 r
F P
0 g
s
.74688 .58587 m .74688 .62292 L .71504 .6237 L p .707 .577 .707 r
F P
0 g
s
.80551 .67493 m .80551 .69346 L .77805 .68906 L p .707 .577 .707 r
F P
0 g
s
.77805 .68906 m .77805 .67054 L .80551 .67493 L p .707 .577 .707 r
F P
0 g
s
.31064 .69231 m .31064 .67379 L .29804 .6659 L p .707 .577 .707 r
F P
0 g
s
.29515 .5087 m .29515 .56428 L .29804 .57282 L p .707 .577 .707 r
F P
0 g
s
.68566 .69132 m .68566 .67279 L .71504 .66941 L p .707 .577 .707 r
F P
0 g
s
.49904 .51233 m .49904 .56792 L .49615 .55937 L p .707 .577 .707 r
F P
0 g
s
.49615 .55937 m .49615 .50379 L .49904 .51233 L p .707 .577 .707 r
F P
0 g
s
.29804 .6659 m .29804 .68443 L .31064 .69231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62019 m .29804 .58313 L .29515 .57459 L p .707 .577 .707 r
F P
0 g
s
.71504 .66941 m .71504 .68794 L .68566 .69132 L p .707 .577 .707 r
F P
0 g
s
.77805 .67054 m .77805 .68906 L .74688 .68716 L p .707 .577 .707 r
F P
0 g
s
.74688 .68716 m .74688 .66864 L .77805 .67054 L p .707 .577 .707 r
F P
0 g
s
.29515 .57459 m .29515 .61165 L .29804 .62019 L p .707 .577 .707 r
F P
0 g
s
.71504 .68794 m .71504 .66941 L .74688 .66864 L p .707 .577 .707 r
F P
0 g
s
.49196 .66936 m .49196 .68789 L .49904 .67952 L p .707 .577 .707 r
F P
0 g
s
.49904 .67952 m .49904 .66099 L .49196 .66936 L p .707 .577 .707 r
F P
0 g
s
.29515 .56428 m .29515 .5087 L .30223 .50033 L p .707 .577 .707 r
F P
0 g
s
.74688 .66864 m .74688 .68716 L .71504 .68794 L p .707 .577 .707 r
F P
0 g
s
.49904 .57823 m .49904 .61528 L .49615 .60674 L p .707 .577 .707 r
F P
0 g
s
.49615 .60674 m .49615 .56969 L .49904 .57823 L p .707 .577 .707 r
F P
0 g
s
.29804 .68443 m .29804 .6659 L .29515 .65736 L p .707 .577 .707 r
F P
0 g
s
.30223 .50033 m .30223 .55592 L .29515 .56428 L p .707 .577 .707 r
F P
0 g
s
.29515 .65736 m .29515 .67589 L .29804 .68443 L p .707 .577 .707 r
F P
0 g
s
.49615 .50379 m .49615 .55937 L .48356 .55149 L p .707 .577 .707 r
F P
0 g
s
.48356 .55149 m .48356 .49591 L .49615 .50379 L p .707 .577 .707 r
F P
0 g
s
.29515 .61165 m .29515 .57459 L .30223 .56623 L p .707 .577 .707 r
F P
0 g
s
.49904 .66099 m .49904 .67952 L .49615 .67098 L p .707 .577 .707 r
F P
0 g
s
.49615 .67098 m .49615 .65245 L .49904 .66099 L p .707 .577 .707 r
F P
0 g
s
.30223 .56623 m .30223 .60328 L .29515 .61165 L p .707 .577 .707 r
F P
0 g
s
.30223 .55592 m .30223 .50033 L .3186 .49297 L p .707 .577 .707 r
F P
0 g
s
.49615 .56969 m .49615 .60674 L .48356 .59886 L p .707 .577 .707 r
F P
0 g
s
.48356 .59886 m .48356 .5618 L .49615 .56969 L p .707 .577 .707 r
F P
0 g
s
.29515 .67589 m .29515 .65736 L .30223 .64899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49297 m .3186 .54855 L .30223 .55592 L p .707 .577 .707 r
F P
0 g
s
.48356 .49591 m .48356 .55149 L .4625 .54504 L p .707 .577 .707 r
F P
0 g
s
.4625 .54504 m .4625 .48945 L .48356 .49591 L p .707 .577 .707 r
F P
0 g
s
.30223 .64899 m .30223 .66752 L .29515 .67589 L p .707 .577 .707 r
F P
0 g
s
.30223 .60328 m .30223 .56623 L .3186 .55886 L p .707 .577 .707 r
F P
0 g
s
.3186 .54855 m .3186 .49297 L .34265 .48732 L p .707 .577 .707 r
F P
0 g
s
.3186 .55886 m .3186 .59591 L .30223 .60328 L p .707 .577 .707 r
F P
0 g
s
.49615 .65245 m .49615 .67098 L .48356 .6631 L p .707 .577 .707 r
F P
0 g
s
.48356 .6631 m .48356 .64457 L .49615 .65245 L p .707 .577 .707 r
F P
0 g
s
.48356 .5618 m .48356 .59886 L .4625 .5924 L p .707 .577 .707 r
F P
0 g
s
.4625 .5924 m .4625 .55535 L .48356 .5618 L p .707 .577 .707 r
F P
0 g
s
.4625 .48945 m .4625 .54504 L .43504 .54064 L p .707 .577 .707 r
F P
0 g
s
.43504 .54064 m .43504 .48506 L .4625 .48945 L p .707 .577 .707 r
F P
0 g
s
.30223 .66752 m .30223 .64899 L .3186 .64163 L p .707 .577 .707 r
F P
0 g
s
.34265 .48732 m .34265 .5429 L .3186 .54855 L p .707 .577 .707 r
F P
0 g
s
.3186 .59591 m .3186 .55886 L .34265 .55321 L p .707 .577 .707 r
F P
0 g
s
.3186 .64163 m .3186 .66015 L .30223 .66752 L p .707 .577 .707 r
F P
0 g
s
.34265 .5429 m .34265 .48732 L .37203 .48394 L p .707 .577 .707 r
F P
0 g
s
.43504 .48506 m .43504 .54064 L .40387 .53874 L p .707 .577 .707 r
F P
0 g
s
.40387 .53874 m .40387 .48316 L .43504 .48506 L p .707 .577 .707 r
F P
0 g
s
.34265 .55321 m .34265 .59027 L .3186 .59591 L p .707 .577 .707 r
F P
0 g
s
.48356 .64457 m .48356 .6631 L .4625 .65664 L p .707 .577 .707 r
F P
0 g
s
.4625 .65664 m .4625 .63811 L .48356 .64457 L p .707 .577 .707 r
F P
0 g
s
.4625 .55535 m .4625 .5924 L .43504 .58801 L p .707 .577 .707 r
F P
0 g
s
.43504 .58801 m .43504 .55095 L .4625 .55535 L p .707 .577 .707 r
F P
0 g
s
.37203 .53952 m .37203 .48394 L .40387 .48316 L p .707 .577 .707 r
F P
0 g
s
.37203 .48394 m .37203 .53952 L .34265 .5429 L p .707 .577 .707 r
F P
0 g
s
.40387 .48316 m .40387 .53874 L .37203 .53952 L p .707 .577 .707 r
F P
0 g
s
.34265 .59027 m .34265 .55321 L .37203 .54983 L p .707 .577 .707 r
F P
0 g
s
.3186 .66015 m .3186 .64163 L .34265 .63598 L p .707 .577 .707 r
F P
0 g
s
.34265 .63598 m .34265 .6545 L .3186 .66015 L p .707 .577 .707 r
F P
0 g
s
.43504 .55095 m .43504 .58801 L .40387 .58611 L p .707 .577 .707 r
F P
0 g
s
.40387 .58611 m .40387 .54905 L .43504 .55095 L p .707 .577 .707 r
F P
0 g
s
.37203 .54983 m .37203 .58689 L .34265 .59027 L p .707 .577 .707 r
F P
0 g
s
.37203 .58689 m .37203 .54983 L .40387 .54905 L p .707 .577 .707 r
F P
0 g
s
.40387 .54905 m .40387 .58611 L .37203 .58689 L p .707 .577 .707 r
F P
0 g
s
.4625 .63811 m .4625 .65664 L .43504 .65225 L p .707 .577 .707 r
F P
0 g
s
.43504 .65225 m .43504 .63372 L .4625 .63811 L p .707 .577 .707 r
F P
0 g
s
.34265 .6545 m .34265 .63598 L .37203 .6326 L p .707 .577 .707 r
F P
0 g
s
.37203 .6326 m .37203 .65113 L .34265 .6545 L p .707 .577 .707 r
F P
0 g
s
.43504 .63372 m .43504 .65225 L .40387 .65035 L p .707 .577 .707 r
F P
0 g
s
.40387 .65035 m .40387 .63182 L .43504 .63372 L p .707 .577 .707 r
F P
0 g
s
.37203 .65113 m .37203 .6326 L .40387 .63182 L p .707 .577 .707 r
F P
0 g
s
.40387 .63182 m .40387 .65035 L .37203 .65113 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00Rgoo3000QWoo001oOol<0005FUH00`00FUIJEP04FUH9001mOol007Ioo`T000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUH00000JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000J7oo
001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo60001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo
2@00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<0
05YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo
1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool005=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEQT00003FUH0
05YF00AJEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP04001JEUYF0002
FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00L005YF000005YF001JEP040003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003
FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF
001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P0000=JEP0000000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000o
OolA0003Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000b
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEP8000AJEP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF000015YF00<005YF00000`000UYF6`000UYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
0002FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPL0009JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH600000eYF001JEP02FUH01000FUIJEP00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00
15YF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUH005YF0P001EYF00<005YF00000`0000EJEP00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH3000]Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP06001JEP00001JEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P00
00EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP@00003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P00
0eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0004FUH300000eYF
001JEP06FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH40003FUH00`00FUIJEP020004
OolB0007Ool400000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPL0
00MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEPP00003FUH005YF00@000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP80009JEPH000=JEP03001oogoo01Aoo`L000=JEP<000=JEP80
02eoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP04001JEUYFFUH90009Ool90003FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00
;Goo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUHG0003FUH30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJ
EP@002eoo`00;7oo00@005YF001JEP8000EJEP03001JEP0000D000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eo
o`00;7oo00H005YF000005YF0003FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`8000=JEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002eoo`00;7oo0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000=JEPD000AJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH2
0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF
1@001UYF6`0000=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH30002FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EPD00003FUH0000000D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP80
00=JEP03001JEP00008000EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUH000030002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPD000=JEP03001JEUYF009JEPH0
009JEP04001JEUYF0005FUH40006FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000bOol002aoo`03001JEP0000AJEP04001JEUYFFUHN0003FUH00`00FUIJEP03FUH01000
FUIJEUYF200015YF1@001EYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP80035oo`00;7oo00<005YF00000eYF1@007Woo0P0000=JEP00FUH015YF00<005YFFUH0
1EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool01000FUH005YF0P00
15YF1@006goo100015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001JEUYFFUH0
000^Ool002aoo`06001JEP00001JEP001EYF00@005YFFUIJEQ/000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009J
EP@00003FUH007oo01Uoo`<000AJEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH30005
FUH00`00FUIJEP03000MOol300000eYF001JEP02FUH2000]Ool002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000L000AJEP03001JEUYF00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002
FUH00`00FUIJEP03FUH01@00FUIJEUYF00008Goo0P000eYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YF00004P001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol200000eYF0000000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Goo0P0000AJEP00000002eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH300000eYF001JEP04FUH01000FUIJEUYF0P007Woo0`000eYF0`00;Goo000^Ool200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH01@000UYF00@005YFFUIJEP8000Qoo`<000moo`@00003FUH005YF00=JEP03
001JEP0002eoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUH000030002FUH20007Ool50009Ool5
0005FUH00`00FUIJEP02FUH2000^Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEPT00003
FUH005YF00IJEP03001JEUYF00=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool003Ioo`D000AJEPP000AJEP03001JEUYF009JEPP00003FUH005YF00@000Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo
000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00006P00?goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool20004FUH01000FUIJEUYF20006Goo1P0015YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00;7oo00<005YF00000eYF1@009goo0`0000EJ
EP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05Aoo`00;7oo00@005YF001JEP8002moo`80
009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP02001GOol002aoo`04001JEP00000cOol30002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol002aoo`@003Ao
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH4001KOol002aoo`80009JEP<002moo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H005moo`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF1000GGoo000/
Ool20003FUH00`00FUIJEP02FUH5000=Ool3000@Ool400000eYF001JEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04001IOol002eo
o`05001JEUYFFUH00005FUH01000FUIJEUYF200017oo1@002Woo1@001EYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=J
EP8005Qoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF5@00
1UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YF000005Ioo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000eYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YF
FUH000EJEP03001JEUYF00EJEPH0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJ
EPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`D000AJEP05001JEUYFFUH0
001EOol003Aoo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
00Yoo`04001JEUYF0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2
001DOol003eooaT000moo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004FUH00`00FUH0000<Ool200000eYF
0000001DOol006Eoo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF000037oo
1@00E7oo001UOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`09
Ool20002FUH3001DOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH007oo00Eoo`@000AJEP03001JEP0005Aoo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF0P0000=JEP0000001@000eYF00<005YFFUH00UYF0P00EGoo001UOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo001U
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00AJEP04001JEP00001HOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEP0000=JEP04001JEUYFFUH5001JOol006Ioo`03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP800003FUH0000000D005moo`00Igoo0P000UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF1000IWoo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
0000K7oo001]Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH4001^Ool0075oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF1@00Mgoo001lOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP06001lOol008Eo
oaH0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77668 m .59613 .7211 L .56496 .7192 L p .707 .577 .707 r
F P
0 g
s
.59613 .7211 m .59613 .77668 L .62796 .77591 L p .707 .577 .707 r
F P
0 g
s
.62796 .77591 m .62796 .72032 L .59613 .7211 L p .707 .577 .707 r
F P
0 g
s
.62796 .72032 m .62796 .77591 L .65735 .77253 L p .707 .577 .707 r
F P
0 g
s
.65735 .77253 m .65734 .71694 L .62796 .72032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77478 m .56496 .7192 L .5375 .71481 L p .707 .577 .707 r
F P
0 g
s
.56496 .7192 m .56496 .77478 L .59613 .77668 L p .707 .577 .707 r
F P
0 g
s
.65734 .71694 m .65735 .77253 L .6814 .76688 L p .707 .577 .707 r
F P
0 g
s
.6814 .76688 m .6814 .71129 L .65734 .71694 L p .707 .577 .707 r
F P
0 g
s
.5375 .71481 m .5375 .77039 L .56496 .77478 L p .707 .577 .707 r
F P
0 g
s
.5375 .77039 m .5375 .71481 L .51644 .70835 L p .707 .577 .707 r
F P
0 g
s
.59613 .85004 m .59613 .81299 L .56496 .81109 L p .707 .577 .707 r
F P
0 g
s
.59613 .81299 m .59613 .85004 L .62796 .84926 L p .707 .577 .707 r
F P
0 g
s
.62796 .84926 m .62796 .81221 L .59613 .81299 L p .707 .577 .707 r
F P
0 g
s
.62796 .81221 m .62796 .84926 L .65735 .84589 L p .707 .577 .707 r
F P
0 g
s
.65735 .84589 m .65735 .80883 L .62796 .81221 L p .707 .577 .707 r
F P
0 g
s
.56496 .84814 m .56496 .81109 L .5375 .80669 L p .707 .577 .707 r
F P
0 g
s
.56496 .81109 m .56496 .84814 L .59613 .85004 L p .707 .577 .707 r
F P
0 g
s
.6814 .71129 m .6814 .76688 L .69777 .75951 L p .707 .577 .707 r
F P
0 g
s
.69777 .75951 m .69777 .70393 L .6814 .71129 L p .707 .577 .707 r
F P
0 g
s
.59613 .86947 m .59613 .85094 L .56496 .84904 L p .707 .577 .707 r
F P
0 g
s
.59613 .85094 m .59613 .86947 L .62796 .86869 L p .707 .577 .707 r
F P
0 g
s
.62796 .86869 m .62796 .85017 L .59613 .85094 L p .707 .577 .707 r
F P
0 g
s
.51644 .70835 m .51644 .76394 L .5375 .77039 L p .707 .577 .707 r
F P
0 g
s
.62796 .85017 m .62796 .86869 L .65735 .86532 L p .707 .577 .707 r
F P
0 g
s
.65735 .86532 m .65735 .84679 L .62796 .85017 L p .707 .577 .707 r
F P
0 g
s
.65735 .80883 m .65735 .84589 L .6814 .84024 L p .707 .577 .707 r
F P
0 g
s
.6814 .84024 m .6814 .80318 L .65735 .80883 L p .707 .577 .707 r
F P
0 g
s
.56496 .84904 m .56496 .86757 L .59613 .86947 L p .707 .577 .707 r
F P
0 g
s
.5375 .80669 m .5375 .84375 L .56496 .84814 L p .707 .577 .707 r
F P
0 g
s
.56496 .86757 m .56496 .84904 L .5375 .84465 L p .707 .577 .707 r
F P
0 g
s
.51644 .76394 m .51644 .70835 L .50385 .70047 L p .707 .577 .707 r
F P
0 g
s
.5375 .84465 m .5375 .86318 L .56496 .86757 L p .707 .577 .707 r
F P
0 g
s
.5375 .84375 m .5375 .80669 L .51644 .80024 L p .707 .577 .707 r
F P
0 g
s
.65735 .84679 m .65735 .86532 L .6814 .85967 L p .707 .577 .707 r
F P
0 g
s
.6814 .85967 m .6814 .84114 L .65735 .84679 L p .707 .577 .707 r
F P
0 g
s
.51644 .80024 m .51644 .83729 L .5375 .84375 L p .707 .577 .707 r
F P
0 g
s
.5375 .86318 m .5375 .84465 L .51644 .8382 L p .707 .577 .707 r
F P
0 g
s
.6814 .80318 m .6814 .84024 L .69777 .83287 L p .707 .577 .707 r
F P
0 g
s
.69777 .83287 m .69777 .79581 L .6814 .80318 L p .707 .577 .707 r
F P
0 g
s
.50385 .70047 m .50385 .75605 L .51644 .76394 L p .707 .577 .707 r
F P
0 g
s
.69777 .70393 m .69777 .75951 L .70485 .75114 L p .707 .577 .707 r
F P
0 g
s
.70485 .75114 m .70485 .69556 L .69777 .70393 L p .707 .577 .707 r
F P
0 g
s
.51644 .8382 m .51644 .85673 L .5375 .86318 L p .707 .577 .707 r
F P
0 g
s
.51644 .83729 m .51644 .80024 L .50385 .79236 L p .707 .577 .707 r
F P
0 g
s
.6814 .84114 m .6814 .85967 L .69777 .8523 L p .707 .577 .707 r
F P
0 g
s
.69777 .8523 m .69777 .83377 L .6814 .84114 L p .707 .577 .707 r
F P
0 g
s
.50385 .75605 m .50385 .70047 L .50095 .69193 L p .707 .577 .707 r
F P
0 g
s
.50385 .79236 m .50385 .82941 L .51644 .83729 L p .707 .577 .707 r
F P
0 g
s
.51644 .85673 m .51644 .8382 L .50385 .83031 L p .707 .577 .707 r
F P
0 g
s
.49044 .78751 m .49044 .28562 L .44643 .28294 L p .707 .577 .707 r
F P
0 g
s
.50095 .69193 m .50095 .74751 L .50385 .75605 L p .707 .577 .707 r
F P
0 g
s
.50385 .82941 m .50385 .79236 L .50095 .78381 L p .707 .577 .707 r
F P
0 g
s
.50095 .74751 m .50095 .69193 L .50804 .68356 L p .707 .577 .707 r
F P
0 g
s
.50095 .78381 m .50095 .82087 L .50385 .82941 L p .707 .577 .707 r
F P
0 g
s
.50804 .68356 m .50804 .73915 L .50095 .74751 L p .707 .577 .707 r
F P
0 g
s
.50095 .82087 m .50095 .78381 L .50804 .77545 L p .707 .577 .707 r
F P
0 g
s
.50804 .73915 m .50804 .68356 L .5244 .6762 L p .707 .577 .707 r
F P
0 g
s
.50804 .77545 m .50804 .8125 L .50095 .82087 L p .707 .577 .707 r
F P
0 g
s
.5244 .6762 m .5244 .73178 L .50804 .73915 L p .707 .577 .707 r
F P
0 g
s
.50804 .8125 m .50804 .77545 L .5244 .76808 L p .707 .577 .707 r
F P
0 g
s
.5244 .73178 m .5244 .6762 L .54846 .67055 L p .707 .577 .707 r
F P
0 g
s
.5244 .76808 m .5244 .80514 L .50804 .8125 L p .707 .577 .707 r
F P
0 g
s
.54846 .67055 m .54846 .72613 L .5244 .73178 L p .707 .577 .707 r
F P
0 g
s
.5244 .80514 m .5244 .76808 L .54846 .76243 L p .707 .577 .707 r
F P
0 g
s
.54846 .76243 m .54846 .79949 L .5244 .80514 L p .707 .577 .707 r
F P
0 g
s
.49044 .28562 m .49044 .78751 L .53538 .78641 L p .707 .577 .707 r
F P
0 g
s
.53538 .78641 m .53538 .28452 L .49044 .28562 L p .707 .577 .707 r
F P
0 g
s
.50385 .83031 m .50385 .84884 L .51644 .85673 L p .707 .577 .707 r
F P
0 g
s
.69777 .79581 m .69777 .83287 L .70485 .8245 L p .707 .577 .707 r
F P
0 g
s
.70485 .8245 m .70485 .78745 L .69777 .79581 L p .707 .577 .707 r
F P
0 g
s
.54846 .72613 m .54846 .67055 L .57784 .66717 L p .707 .577 .707 r
F P
0 g
s
.57784 .66717 m .57784 .72275 L .54846 .72613 L p .707 .577 .707 r
F P
0 g
s
.54846 .79949 m .54846 .76243 L .57784 .75905 L p .707 .577 .707 r
F P
0 g
s
.57784 .75905 m .57784 .79611 L .54846 .79949 L p .707 .577 .707 r
F P
0 g
s
.53538 .28452 m .53538 .78641 L .57686 .78164 L p .707 .577 .707 r
F P
0 g
s
.57686 .78164 m .57686 .27975 L .53538 .28452 L p .707 .577 .707 r
F P
0 g
s
.70485 .69556 m .70485 .75114 L .70195 .7426 L p .707 .577 .707 r
F P
0 g
s
.70195 .7426 m .70195 .68702 L .70485 .69556 L p .707 .577 .707 r
F P
0 g
s
.44643 .78482 m .44643 .28294 L .40766 .27673 L p .707 .577 .707 r
F P
0 g
s
.44643 .28294 m .44643 .78482 L .49044 .78751 L p .707 .577 .707 r
F P
0 g
s
.69777 .83377 m .69777 .8523 L .70485 .84393 L p .707 .577 .707 r
F P
0 g
s
.70485 .84393 m .70485 .82541 L .69777 .83377 L p .707 .577 .707 r
F P
0 g
s
.57784 .72275 m .57784 .66717 L .60968 .66639 L p .707 .577 .707 r
F P
0 g
s
.60968 .66639 m .60968 .72197 L .57784 .72275 L p .707 .577 .707 r
F P
0 g
s
.60968 .79533 m .60968 .75828 L .64085 .76018 L p .707 .577 .707 r
F P
0 g
s
.57784 .79611 m .57784 .75905 L .60968 .75828 L p .707 .577 .707 r
F P
0 g
s
.60968 .75828 m .60968 .79533 L .57784 .79611 L p .707 .577 .707 r
F P
0 g
s
.57686 .27975 m .57686 .78164 L .61082 .77366 L p .707 .577 .707 r
F P
0 g
s
.64085 .66829 m .64085 .72387 L .60968 .72197 L p .707 .577 .707 r
F P
0 g
s
.60968 .72197 m .60968 .66639 L .64085 .66829 L p .707 .577 .707 r
F P
0 g
s
.61082 .77366 m .61082 .27177 L .57686 .27975 L p .707 .577 .707 r
F P
0 g
s
.50385 .84884 m .50385 .83031 L .50095 .82177 L p .707 .577 .707 r
F P
0 g
s
.50095 .82177 m .50095 .8403 L .50385 .84884 L p .707 .577 .707 r
F P
0 g
s
.40766 .77862 m .40766 .27673 L .37794 .26762 L p .707 .577 .707 r
F P
0 g
s
.40766 .27673 m .40766 .77862 L .44643 .78482 L p .707 .577 .707 r
F P
0 g
s
.70485 .78745 m .70485 .8245 L .70195 .81596 L p .707 .577 .707 r
F P
0 g
s
.70195 .81596 m .70195 .77891 L .70485 .78745 L p .707 .577 .707 r
F P
0 g
s
.70195 .68702 m .70195 .7426 L .68936 .73472 L p .707 .577 .707 r
F P
0 g
s
.68936 .73472 m .68936 .67914 L .70195 .68702 L p .707 .577 .707 r
F P
0 g
s
.70485 .82541 m .70485 .84393 L .70195 .83539 L p .707 .577 .707 r
F P
0 g
s
.70195 .83539 m .70195 .81686 L .70485 .82541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25312 .73987 m .25312 .68429 L .22195 .68238 L p .707 .577 .707 r
F P
0 g
s
.25312 .68429 m .25312 .73987 L .28495 .73909 L p .707 .577 .707 r
F P
0 g
s
.28495 .73909 m .28495 .68351 L .25312 .68429 L p .707 .577 .707 r
F P
0 g
s
.61082 .27177 m .61082 .77366 L .63393 .76326 L p .707 .577 .707 r
F P
0 g
s
.63393 .76326 m .63393 .26137 L .61082 .27177 L p .707 .577 .707 r
F P
0 g
s
.28495 .68351 m .28495 .73909 L .31434 .73571 L p .707 .577 .707 r
F P
0 g
s
.31434 .73571 m .31434 .68013 L .28495 .68351 L p .707 .577 .707 r
F P
0 g
s
.22195 .73797 m .22195 .68238 L .19449 .67799 L p .707 .577 .707 r
F P
0 g
s
.22195 .68238 m .22195 .73797 L .25312 .73987 L p .707 .577 .707 r
F P
0 g
s
.50095 .8403 m .50095 .82177 L .50804 .81341 L p .707 .577 .707 r
F P
0 g
s
.50804 .81341 m .50804 .83193 L .50095 .8403 L p .707 .577 .707 r
F P
0 g
s
.31434 .68013 m .31434 .73571 L .33839 .73006 L p .707 .577 .707 r
F P
0 g
s
.33839 .73006 m .33839 .67448 L .31434 .68013 L p .707 .577 .707 r
F P
0 g
s
.70195 .77891 m .70195 .81596 L .68936 .80808 L p .707 .577 .707 r
F P
0 g
s
.68936 .80808 m .68936 .77102 L .70195 .77891 L p .707 .577 .707 r
F P
0 g
s
.37794 .76951 m .37794 .26762 L .36016 .25649 L p .707 .577 .707 r
F P
0 g
s
.37794 .26762 m .37794 .76951 L .40766 .77862 L p .707 .577 .707 r
F P
0 g
s
.68936 .67914 m .68936 .73472 L .66831 .72826 L p .707 .577 .707 r
F P
0 g
s
.66831 .72826 m .66831 .67268 L .68936 .67914 L p .707 .577 .707 r
F P
0 g
s
.19449 .67799 m .19449 .73357 L .22195 .73797 L p .707 .577 .707 r
F P
0 g
s
.19449 .73357 m .19449 .67799 L .17343 .67154 L p .707 .577 .707 r
F P
0 g
s
.25312 .81323 m .25312 .77617 L .22195 .77427 L p .707 .577 .707 r
F P
0 g
s
.25312 .77617 m .25312 .81323 L .28495 .81245 L p .707 .577 .707 r
F P
0 g
s
.28495 .81245 m .28495 .77539 L .25312 .77617 L p .707 .577 .707 r
F P
0 g
s
.70195 .81686 m .70195 .83539 L .68936 .82751 L p .707 .577 .707 r
F P
0 g
s
.68936 .82751 m .68936 .80898 L .70195 .81686 L p .707 .577 .707 r
F P
0 g
s
.28495 .77539 m .28495 .81245 L .31434 .80907 L p .707 .577 .707 r
F P
0 g
s
.31434 .80907 m .31434 .77202 L .28495 .77539 L p .707 .577 .707 r
F P
0 g
s
.22195 .81133 m .22195 .77427 L .19449 .76988 L p .707 .577 .707 r
F P
0 g
s
.22195 .77427 m .22195 .81133 L .25312 .81323 L p .707 .577 .707 r
F P
0 g
s
.33839 .67448 m .33839 .73006 L .35476 .72269 L p .707 .577 .707 r
F P
0 g
s
.35476 .72269 m .35476 .66711 L .33839 .67448 L p .707 .577 .707 r
F P
0 g
s
.25312 .83266 m .25312 .81413 L .22195 .81223 L p .707 .577 .707 r
F P
0 g
s
.25312 .81413 m .25312 .83266 L .28495 .83188 L p .707 .577 .707 r
F P
0 g
s
.28495 .83188 m .28495 .81335 L .25312 .81413 L p .707 .577 .707 r
F P
0 g
s
.17343 .67154 m .17343 .72712 L .19449 .73357 L p .707 .577 .707 r
F P
0 g
s
.50804 .83193 m .50804 .81341 L .5244 .80604 L p .707 .577 .707 r
F P
0 g
s
.28495 .81335 m .28495 .83188 L .31434 .8285 L p .707 .577 .707 r
F P
0 g
s
.31434 .8285 m .31434 .80997 L .28495 .81335 L p .707 .577 .707 r
F P
0 g
s
.66831 .67268 m .66831 .72826 L .64085 .72387 L p .707 .577 .707 r
F P
0 g
s
.64085 .72387 m .64085 .66829 L .66831 .67268 L p .707 .577 .707 r
F P
0 g
s
.63393 .26137 m .63393 .76326 L .64393 .75145 L p .707 .577 .707 r
F P
0 g
s
.64393 .75145 m .64393 .24956 L .63393 .26137 L p .707 .577 .707 r
F P
0 g
s
.31434 .77202 m .31434 .80907 L .33839 .80342 L p .707 .577 .707 r
F P
0 g
s
.33839 .80342 m .33839 .76637 L .31434 .77202 L p .707 .577 .707 r
F P
0 g
s
.22195 .81223 m .22195 .83076 L .25312 .83266 L p .707 .577 .707 r
F P
0 g
s
.19449 .76988 m .19449 .80693 L .22195 .81133 L p .707 .577 .707 r
F P
0 g
s
.22195 .83076 m .22195 .81223 L .19449 .80784 L p .707 .577 .707 r
F P
0 g
s
.5244 .80604 m .5244 .82457 L .50804 .83193 L p .707 .577 .707 r
F P
0 g
s
.68936 .77102 m .68936 .80808 L .66831 .80162 L p .707 .577 .707 r
F P
0 g
s
.66831 .80162 m .66831 .76457 L .68936 .77102 L p .707 .577 .707 r
F P
0 g
s
.17343 .72712 m .17343 .67154 L .16084 .66365 L p .707 .577 .707 r
F P
0 g
s
.19449 .80784 m .19449 .82636 L .22195 .83076 L p .707 .577 .707 r
F P
0 g
s
.19449 .80693 m .19449 .76988 L .17343 .76342 L p .707 .577 .707 r
F P
0 g
s
.31434 .80997 m .31434 .8285 L .33839 .82285 L p .707 .577 .707 r
F P
0 g
s
.33839 .82285 m .33839 .80432 L .31434 .80997 L p .707 .577 .707 r
F P
0 g
s
.68936 .80898 m .68936 .82751 L .66831 .82105 L p .707 .577 .707 r
F P
0 g
s
.66831 .82105 m .66831 .80253 L .68936 .80898 L p .707 .577 .707 r
F P
0 g
s
.35476 .66711 m .35476 .72269 L .36184 .71433 L p .707 .577 .707 r
F P
0 g
s
.36184 .71433 m .36184 .65875 L .35476 .66711 L p .707 .577 .707 r
F P
0 g
s
.36184 .78769 m .36184 .75063 L .35476 .759 L p .707 .577 .707 r
F P
0 g
s
.36184 .65875 m .36184 .71433 L .35894 .70579 L p .707 .577 .707 r
F P
0 g
s
.35894 .70579 m .35894 .65021 L .36184 .65875 L p .707 .577 .707 r
F P
0 g
s
.35476 .759 m .35476 .79605 L .36184 .78769 L p .707 .577 .707 r
F P
0 g
s
.35894 .77915 m .35894 .74209 L .36184 .75063 L p .707 .577 .707 r
F P
0 g
s
.36016 .75838 m .36016 .25649 L .35607 .24443 L p .707 .577 .707 r
F P
0 g
s
.36184 .75063 m .36184 .78769 L .35894 .77915 L p .707 .577 .707 r
F P
0 g
s
.36016 .25649 m .36016 .75838 L .37794 .76951 L p .707 .577 .707 r
F P
0 g
s
.17343 .76342 m .17343 .80048 L .19449 .80693 L p .707 .577 .707 r
F P
0 g
s
.19449 .82636 m .19449 .80784 L .17343 .80138 L p .707 .577 .707 r
F P
0 g
s
.33839 .76637 m .33839 .80342 L .35476 .79605 L p .707 .577 .707 r
F P
0 g
s
.35476 .79605 m .35476 .759 L .33839 .76637 L p .707 .577 .707 r
F P
0 g
s
.16084 .66365 m .16084 .71924 L .17343 .72712 L p .707 .577 .707 r
F P
0 g
s
.17343 .80138 m .17343 .81991 L .19449 .82636 L p .707 .577 .707 r
F P
0 g
s
.5244 .82457 m .5244 .80604 L .54846 .80039 L p .707 .577 .707 r
F P
0 g
s
.66831 .76457 m .66831 .80162 L .64085 .79723 L p .707 .577 .707 r
F P
0 g
s
.64085 .79723 m .64085 .76018 L .66831 .76457 L p .707 .577 .707 r
F P
0 g
s
.54846 .80039 m .54846 .81892 L .5244 .82457 L p .707 .577 .707 r
F P
0 g
s
.17343 .80048 m .17343 .76342 L .16084 .75554 L p .707 .577 .707 r
F P
0 g
s
.33839 .80432 m .33839 .82285 L .35476 .81548 L p .707 .577 .707 r
F P
0 g
s
.35476 .81548 m .35476 .79696 L .33839 .80432 L p .707 .577 .707 r
F P
0 g
s
.16084 .71924 m .16084 .66365 L .15794 .65511 L p .707 .577 .707 r
F P
0 g
s
.66831 .80253 m .66831 .82105 L .64085 .81666 L p .707 .577 .707 r
F P
0 g
s
.64085 .81666 m .64085 .79813 L .66831 .80253 L p .707 .577 .707 r
F P
0 g
s
.64393 .24956 m .64393 .75145 L .63984 .73939 L p .707 .577 .707 r
F P
0 g
s
.63984 .73939 m .63984 .2375 L .64393 .24956 L p .707 .577 .707 r
F P
0 g
s
.16084 .75554 m .16084 .7926 L .17343 .80048 L p .707 .577 .707 r
F P
0 g
s
.17343 .81991 m .17343 .80138 L .16084 .7935 L p .707 .577 .707 r
F P
0 g
s
.64085 .76018 m .64085 .79723 L .60968 .79533 L p .707 .577 .707 r
F P
0 g
s
.54846 .81892 m .54846 .80039 L .57784 .79701 L p .707 .577 .707 r
F P
0 g
s
.16084 .7935 m .16084 .81203 L .17343 .81991 L p .707 .577 .707 r
F P
0 g
s
.15794 .65511 m .15794 .71069 L .16084 .71924 L p .707 .577 .707 r
F P
0 g
s
.57784 .79701 m .57784 .81554 L .54846 .81892 L p .707 .577 .707 r
F P
0 g
s
.64085 .79813 m .64085 .81666 L .60968 .81476 L p .707 .577 .707 r
F P
0 g
s
.60968 .81476 m .60968 .79623 L .64085 .79813 L p .707 .577 .707 r
F P
0 g
s
.57784 .81554 m .57784 .79701 L .60968 .79623 L p .707 .577 .707 r
F P
0 g
s
.35476 .79696 m .35476 .81548 L .36184 .80712 L p .707 .577 .707 r
F P
0 g
s
.36184 .80712 m .36184 .78859 L .35476 .79696 L p .707 .577 .707 r
F P
0 g
s
.16084 .7926 m .16084 .75554 L .15794 .747 L p .707 .577 .707 r
F P
0 g
s
.35894 .65021 m .35894 .70579 L .34635 .6979 L p .707 .577 .707 r
F P
0 g
s
.34635 .6979 m .34635 .64232 L .35894 .65021 L p .707 .577 .707 r
F P
0 g
s
.35894 .74209 m .35894 .77915 L .34635 .77126 L p .707 .577 .707 r
F P
0 g
s
.34635 .77126 m .34635 .73421 L .35894 .74209 L p .707 .577 .707 r
F P
0 g
s
.35607 .24443 m .35607 .74632 L .36016 .75838 L p .707 .577 .707 r
F P
0 g
s
.35607 .74632 m .35607 .24443 L .36607 .23262 L p .707 .577 .707 r
F P
0 g
s
.60968 .79623 m .60968 .81476 L .57784 .81554 L p .707 .577 .707 r
F P
0 g
s
.15794 .71069 m .15794 .65511 L .16503 .64675 L p .707 .577 .707 r
F P
0 g
s
.15794 .747 m .15794 .78405 L .16084 .7926 L p .707 .577 .707 r
F P
0 g
s
.16084 .81203 m .16084 .7935 L .15794 .78496 L p .707 .577 .707 r
F P
0 g
s
.15794 .78496 m .15794 .80348 L .16084 .81203 L p .707 .577 .707 r
F P
0 g
s
.16503 .64675 m .16503 .70233 L .15794 .71069 L p .707 .577 .707 r
F P
0 g
s
.63984 .2375 m .63984 .73939 L .62206 .72826 L p .707 .577 .707 r
F P
0 g
s
.62206 .72826 m .62206 .22637 L .63984 .2375 L p .707 .577 .707 r
F P
0 g
s
.36184 .78859 m .36184 .80712 L .35894 .79858 L p .707 .577 .707 r
F P
0 g
s
.35894 .79858 m .35894 .78005 L .36184 .78859 L p .707 .577 .707 r
F P
0 g
s
.15794 .78405 m .15794 .747 L .16503 .73863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70233 m .16503 .64675 L .1814 .63938 L p .707 .577 .707 r
F P
0 g
s
.16503 .73863 m .16503 .77569 L .15794 .78405 L p .707 .577 .707 r
F P
0 g
s
.15794 .80348 m .15794 .78496 L .16503 .77659 L p .707 .577 .707 r
F P
0 g
s
.36607 .73451 m .36607 .23262 L .38918 .22222 L p .707 .577 .707 r
F P
0 g
s
.36607 .23262 m .36607 .73451 L .35607 .74632 L p .707 .577 .707 r
F P
0 g
s
.16503 .77659 m .16503 .79512 L .15794 .80348 L p .707 .577 .707 r
F P
0 g
s
.1814 .63938 m .1814 .69496 L .16503 .70233 L p .707 .577 .707 r
F P
0 g
s
.34635 .64232 m .34635 .6979 L .3253 .69145 L p .707 .577 .707 r
F P
0 g
s
.3253 .69145 m .3253 .63587 L .34635 .64232 L p .707 .577 .707 r
F P
0 g
s
.35894 .78005 m .35894 .79858 L .34635 .79069 L p .707 .577 .707 r
F P
0 g
s
.34635 .79069 m .34635 .77217 L .35894 .78005 L p .707 .577 .707 r
F P
0 g
s
.16503 .77569 m .16503 .73863 L .1814 .73127 L p .707 .577 .707 r
F P
0 g
s
.1814 .69496 m .1814 .63938 L .20545 .63373 L p .707 .577 .707 r
F P
0 g
s
.62206 .22637 m .62206 .72826 L .59233 .71915 L p .707 .577 .707 r
F P
0 g
s
.59233 .71915 m .59233 .21726 L .62206 .22637 L p .707 .577 .707 r
F P
0 g
s
.1814 .73127 m .1814 .76832 L .16503 .77569 L p .707 .577 .707 r
F P
0 g
s
.16503 .79512 m .16503 .77659 L .1814 .76922 L p .707 .577 .707 r
F P
0 g
s
.3253 .63587 m .3253 .69145 L .29784 .68706 L p .707 .577 .707 r
F P
0 g
s
.29784 .68706 m .29784 .63147 L .3253 .63587 L p .707 .577 .707 r
F P
0 g
s
.1814 .76922 m .1814 .78775 L .16503 .79512 L p .707 .577 .707 r
F P
0 g
s
.34635 .73421 m .34635 .77126 L .3253 .76481 L p .707 .577 .707 r
F P
0 g
s
.3253 .76481 m .3253 .72775 L .34635 .73421 L p .707 .577 .707 r
F P
0 g
s
.20545 .63373 m .20545 .68931 L .1814 .69496 L p .707 .577 .707 r
F P
0 g
s
.38918 .22222 m .38918 .72411 L .36607 .73451 L p .707 .577 .707 r
F P
0 g
s
.38918 .72411 m .38918 .22222 L .42314 .21425 L p .707 .577 .707 r
F P
0 g
s
.20545 .68931 m .20545 .63373 L .23483 .63035 L p .707 .577 .707 r
F P
0 g
s
.1814 .76832 m .1814 .73127 L .20545 .72562 L p .707 .577 .707 r
F P
0 g
s
.34635 .77217 m .34635 .79069 L .3253 .78424 L p .707 .577 .707 r
F P
0 g
s
.3253 .78424 m .3253 .76571 L .34635 .77217 L p .707 .577 .707 r
F P
0 g
s
.29784 .63147 m .29784 .68706 L .26667 .68516 L p .707 .577 .707 r
F P
0 g
s
.26667 .68516 m .26667 .62957 L .29784 .63147 L p .707 .577 .707 r
F P
0 g
s
.23483 .68593 m .23483 .63035 L .26667 .62957 L p .707 .577 .707 r
F P
0 g
s
.23483 .63035 m .23483 .68593 L .20545 .68931 L p .707 .577 .707 r
F P
0 g
s
.26667 .62957 m .26667 .68516 L .23483 .68593 L p .707 .577 .707 r
F P
0 g
s
.20545 .72562 m .20545 .76267 L .1814 .76832 L p .707 .577 .707 r
F P
0 g
s
.1814 .78775 m .1814 .76922 L .20545 .76357 L p .707 .577 .707 r
F P
0 g
s
.59233 .21726 m .59233 .71915 L .55357 .71295 L p .707 .577 .707 r
F P
0 g
s
.55357 .71295 m .55357 .21106 L .59233 .21726 L p .707 .577 .707 r
F P
0 g
s
.73333 .68464 m .73333 .62906 L .70216 .62716 L p .707 .577 .707 r
F P
0 g
s
.73333 .62906 m .73333 .68464 L .76517 .68387 L p .707 .577 .707 r
F P
0 g
s
.76517 .68387 m .76517 .62828 L .73333 .62906 L p .707 .577 .707 r
F P
0 g
s
.3253 .72775 m .3253 .76481 L .29784 .76042 L p .707 .577 .707 r
F P
0 g
s
.29784 .76042 m .29784 .72336 L .3253 .72775 L p .707 .577 .707 r
F P
0 g
s
.76517 .62828 m .76517 .68387 L .79455 .68049 L p .707 .577 .707 r
F P
0 g
s
.79455 .68049 m .79455 .62491 L .76517 .62828 L p .707 .577 .707 r
F P
0 g
s
.20545 .76357 m .20545 .7821 L .1814 .78775 L p .707 .577 .707 r
F P
0 g
s
.70216 .68274 m .70216 .62716 L .6747 .62277 L p .707 .577 .707 r
F P
0 g
s
.70216 .62716 m .70216 .68274 L .73333 .68464 L p .707 .577 .707 r
F P
0 g
s
.20545 .76267 m .20545 .72562 L .23483 .72224 L p .707 .577 .707 r
F P
0 g
s
.42314 .71613 m .42314 .21425 L .46462 .20948 L p .707 .577 .707 r
F P
0 g
s
.42314 .21425 m .42314 .71613 L .38918 .72411 L p .707 .577 .707 r
F P
0 g
s
.3253 .76571 m .3253 .78424 L .29784 .77985 L p .707 .577 .707 r
F P
0 g
s
.29784 .77985 m .29784 .76132 L .3253 .76571 L p .707 .577 .707 r
F P
0 g
s
.79455 .62491 m .79455 .68049 L .8186 .67484 L p .707 .577 .707 r
F P
0 g
s
.8186 .67484 m .8186 .61926 L .79455 .62491 L p .707 .577 .707 r
F P
0 g
s
.29784 .72336 m .29784 .76042 L .26667 .75852 L p .707 .577 .707 r
F P
0 g
s
.26667 .75852 m .26667 .72146 L .29784 .72336 L p .707 .577 .707 r
F P
0 g
s
.23483 .72224 m .23483 .75929 L .20545 .76267 L p .707 .577 .707 r
F P
0 g
s
.20545 .7821 m .20545 .76357 L .23483 .7602 L p .707 .577 .707 r
F P
0 g
s
.23483 .75929 m .23483 .72224 L .26667 .72146 L p .707 .577 .707 r
F P
0 g
s
.55357 .21106 m .55357 .71295 L .50956 .71027 L p .707 .577 .707 r
F P
0 g
s
.50956 .71027 m .50956 .20838 L .55357 .21106 L p .707 .577 .707 r
F P
0 g
s
.6747 .62277 m .6747 .67835 L .70216 .68274 L p .707 .577 .707 r
F P
0 g
s
.6747 .67835 m .6747 .62277 L .65365 .61632 L p .707 .577 .707 r
F P
0 g
s
.26667 .72146 m .26667 .75852 L .23483 .75929 L p .707 .577 .707 r
F P
0 g
s
.23483 .7602 m .23483 .77872 L .20545 .7821 L p .707 .577 .707 r
F P
0 g
s
.73333 .758 m .73333 .72095 L .70216 .71905 L p .707 .577 .707 r
F P
0 g
s
.73333 .72095 m .73333 .758 L .76517 .75723 L p .707 .577 .707 r
F P
0 g
s
.76517 .75723 m .76517 .72017 L .73333 .72095 L p .707 .577 .707 r
F P
0 g
s
.46462 .71136 m .46462 .20948 L .50956 .20838 L p .707 .577 .707 r
F P
0 g
s
.46462 .20948 m .46462 .71136 L .42314 .71613 L p .707 .577 .707 r
F P
0 g
s
.29784 .76132 m .29784 .77985 L .26667 .77795 L p .707 .577 .707 r
F P
0 g
s
.26667 .77795 m .26667 .75942 L .29784 .76132 L p .707 .577 .707 r
F P
0 g
s
.76517 .72017 m .76517 .75723 L .79455 .75385 L p .707 .577 .707 r
F P
0 g
s
.79455 .75385 m .79455 .71679 L .76517 .72017 L p .707 .577 .707 r
F P
0 g
s
.50956 .20838 m .50956 .71027 L .46462 .71136 L p .707 .577 .707 r
F P
0 g
s
.23483 .77872 m .23483 .7602 L .26667 .75942 L p .707 .577 .707 r
F P
0 g
s
.70216 .7561 m .70216 .71905 L .6747 .71466 L p .707 .577 .707 r
F P
0 g
s
.70216 .71905 m .70216 .7561 L .73333 .758 L p .707 .577 .707 r
F P
0 g
s
.26667 .75942 m .26667 .77795 L .23483 .77872 L p .707 .577 .707 r
F P
0 g
s
.8186 .61926 m .8186 .67484 L .83497 .66747 L p .707 .577 .707 r
F P
0 g
s
.83497 .66747 m .83497 .61189 L .8186 .61926 L p .707 .577 .707 r
F P
0 g
s
.73333 .77743 m .73333 .75891 L .70216 .75701 L p .707 .577 .707 r
F P
0 g
s
.73333 .75891 m .73333 .77743 L .76517 .77666 L p .707 .577 .707 r
F P
0 g
s
.76517 .77666 m .76517 .75813 L .73333 .75891 L p .707 .577 .707 r
F P
0 g
s
.65365 .61632 m .65365 .6719 L .6747 .67835 L p .707 .577 .707 r
F P
0 g
s
.76517 .75813 m .76517 .77666 L .79455 .77328 L p .707 .577 .707 r
F P
0 g
s
.79455 .77328 m .79455 .75475 L .76517 .75813 L p .707 .577 .707 r
F P
0 g
s
.79455 .71679 m .79455 .75385 L .8186 .7482 L p .707 .577 .707 r
F P
0 g
s
.8186 .7482 m .8186 .71114 L .79455 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75701 m .70216 .77553 L .73333 .77743 L p .707 .577 .707 r
F P
0 g
s
.6747 .71466 m .6747 .75171 L .70216 .7561 L p .707 .577 .707 r
F P
0 g
s
.70216 .77553 m .70216 .75701 L .6747 .75261 L p .707 .577 .707 r
F P
0 g
s
.65365 .6719 m .65365 .61632 L .64105 .60843 L p .707 .577 .707 r
F P
0 g
s
.6747 .75261 m .6747 .77114 L .70216 .77553 L p .707 .577 .707 r
F P
0 g
s
.6747 .75171 m .6747 .71466 L .65365 .7082 L p .707 .577 .707 r
F P
0 g
s
.79455 .75475 m .79455 .77328 L .8186 .76763 L p .707 .577 .707 r
F P
0 g
s
.8186 .76763 m .8186 .7491 L .79455 .75475 L p .707 .577 .707 r
F P
0 g
s
.65365 .7082 m .65365 .74526 L .6747 .75171 L p .707 .577 .707 r
F P
0 g
s
.6747 .77114 m .6747 .75261 L .65365 .74616 L p .707 .577 .707 r
F P
0 g
s
.8186 .71114 m .8186 .7482 L .83497 .74083 L p .707 .577 .707 r
F P
0 g
s
.83497 .74083 m .83497 .70378 L .8186 .71114 L p .707 .577 .707 r
F P
0 g
s
.64105 .60843 m .64105 .66401 L .65365 .6719 L p .707 .577 .707 r
F P
0 g
s
.83497 .61189 m .83497 .66747 L .84205 .65911 L p .707 .577 .707 r
F P
0 g
s
.84205 .65911 m .84205 .60352 L .83497 .61189 L p .707 .577 .707 r
F P
0 g
s
.65365 .74616 m .65365 .76469 L .6747 .77114 L p .707 .577 .707 r
F P
0 g
s
.65365 .74526 m .65365 .7082 L .64105 .70032 L p .707 .577 .707 r
F P
0 g
s
.8186 .7491 m .8186 .76763 L .83497 .76026 L p .707 .577 .707 r
F P
0 g
s
.83497 .76026 m .83497 .74173 L .8186 .7491 L p .707 .577 .707 r
F P
0 g
s
.64105 .66401 m .64105 .60843 L .63816 .59989 L p .707 .577 .707 r
F P
0 g
s
.64105 .70032 m .64105 .73737 L .65365 .74526 L p .707 .577 .707 r
F P
0 g
s
.65365 .76469 m .65365 .74616 L .64105 .73828 L p .707 .577 .707 r
F P
0 g
s
.64105 .73828 m .64105 .7568 L .65365 .76469 L p .707 .577 .707 r
F P
0 g
s
.83497 .70378 m .83497 .74083 L .84206 .73247 L p .707 .577 .707 r
F P
0 g
s
.84206 .73247 m .84206 .69541 L .83497 .70378 L p .707 .577 .707 r
F P
0 g
s
.63816 .59989 m .63816 .65547 L .64105 .66401 L p .707 .577 .707 r
F P
0 g
s
.84205 .60352 m .84205 .65911 L .83916 .65056 L p .707 .577 .707 r
F P
0 g
s
.83916 .65056 m .83916 .59498 L .84205 .60352 L p .707 .577 .707 r
F P
0 g
s
.83497 .74173 m .83497 .76026 L .84206 .7519 L p .707 .577 .707 r
F P
0 g
s
.84206 .7519 m .84206 .73337 L .83497 .74173 L p .707 .577 .707 r
F P
0 g
s
.64105 .73737 m .64105 .70032 L .63816 .69178 L p .707 .577 .707 r
F P
0 g
s
.63816 .65547 m .63816 .59989 L .64524 .59152 L p .707 .577 .707 r
F P
0 g
s
.63816 .69178 m .63816 .72883 L .64105 .73737 L p .707 .577 .707 r
F P
0 g
s
.64105 .7568 m .64105 .73828 L .63816 .72973 L p .707 .577 .707 r
F P
0 g
s
.63816 .72973 m .63816 .74826 L .64105 .7568 L p .707 .577 .707 r
F P
0 g
s
.84206 .69541 m .84206 .73247 L .83916 .72392 L p .707 .577 .707 r
F P
0 g
s
.83916 .72392 m .83916 .68687 L .84206 .69541 L p .707 .577 .707 r
F P
0 g
s
.64524 .59152 m .64524 .64711 L .63816 .65547 L p .707 .577 .707 r
F P
0 g
s
.83916 .59498 m .83916 .65056 L .82657 .64268 L p .707 .577 .707 r
F P
0 g
s
.82657 .64268 m .82657 .5871 L .83916 .59498 L p .707 .577 .707 r
F P
0 g
s
.84206 .73337 m .84206 .7519 L .83916 .74335 L p .707 .577 .707 r
F P
0 g
s
.83916 .74335 m .83916 .72483 L .84206 .73337 L p .707 .577 .707 r
F P
0 g
s
.63816 .72883 m .63816 .69178 L .64524 .68341 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64783 m .39032 .59225 L .35915 .59035 L p .707 .577 .707 r
F P
0 g
s
.39032 .59225 m .39032 .64783 L .42216 .64705 L p .707 .577 .707 r
F P
0 g
s
.42216 .64705 m .42216 .59147 L .39032 .59225 L p .707 .577 .707 r
F P
0 g
s
.64524 .64711 m .64524 .59152 L .66161 .58416 L p .707 .577 .707 r
F P
0 g
s
.42216 .59147 m .42216 .64705 L .45154 .64367 L p .707 .577 .707 r
F P
0 g
s
.45154 .64367 m .45154 .58809 L .42216 .59147 L p .707 .577 .707 r
F P
0 g
s
.35915 .64593 m .35915 .59035 L .33169 .58595 L p .707 .577 .707 r
F P
0 g
s
.35915 .59035 m .35915 .64593 L .39032 .64783 L p .707 .577 .707 r
F P
0 g
s
.64524 .68341 m .64524 .72047 L .63816 .72883 L p .707 .577 .707 r
F P
0 g
s
.63816 .74826 m .63816 .72973 L .64524 .72137 L p .707 .577 .707 r
F P
0 g
s
.64524 .72137 m .64524 .7399 L .63816 .74826 L p .707 .577 .707 r
F P
0 g
s
.45154 .58809 m .45154 .64367 L .47559 .63802 L p .707 .577 .707 r
F P
0 g
s
.47559 .63802 m .47559 .58244 L .45154 .58809 L p .707 .577 .707 r
F P
0 g
s
.83916 .68687 m .83916 .72392 L .82657 .71604 L p .707 .577 .707 r
F P
0 g
s
.82657 .71604 m .82657 .67898 L .83916 .68687 L p .707 .577 .707 r
F P
0 g
s
.66161 .58416 m .66161 .63974 L .64524 .64711 L p .707 .577 .707 r
F P
0 g
s
.82657 .5871 m .82657 .64268 L .80551 .63623 L p .707 .577 .707 r
F P
0 g
s
.80551 .63623 m .80551 .58064 L .82657 .5871 L p .707 .577 .707 r
F P
0 g
s
.33169 .58595 m .33169 .64154 L .35915 .64593 L p .707 .577 .707 r
F P
0 g
s
.33169 .64154 m .33169 .58595 L .31064 .5795 L p .707 .577 .707 r
F P
0 g
s
.39032 .72119 m .39032 .68413 L .35915 .68223 L p .707 .577 .707 r
F P
0 g
s
.39032 .68413 m .39032 .72119 L .42216 .72041 L p .707 .577 .707 r
F P
0 g
s
.42216 .72041 m .42216 .68336 L .39032 .68413 L p .707 .577 .707 r
F P
0 g
s
.83916 .72483 m .83916 .74335 L .82657 .73547 L p .707 .577 .707 r
F P
0 g
s
.82657 .73547 m .82657 .71694 L .83916 .72483 L p .707 .577 .707 r
F P
0 g
s
.64524 .72047 m .64524 .68341 L .66161 .67604 L p .707 .577 .707 r
F P
0 g
s
.42216 .68336 m .42216 .72041 L .45154 .71703 L p .707 .577 .707 r
F P
0 g
s
.45154 .71703 m .45154 .67998 L .42216 .68336 L p .707 .577 .707 r
F P
0 g
s
.66161 .63974 m .66161 .58416 L .68566 .57851 L p .707 .577 .707 r
F P
0 g
s
.35915 .71929 m .35915 .68223 L .33169 .67784 L p .707 .577 .707 r
F P
0 g
s
.35915 .68223 m .35915 .71929 L .39032 .72119 L p .707 .577 .707 r
F P
0 g
s
.47559 .58244 m .47559 .63802 L .49196 .63066 L p .707 .577 .707 r
F P
0 g
s
.49196 .63066 m .49196 .57507 L .47559 .58244 L p .707 .577 .707 r
F P
0 g
s
.39032 .74062 m .39032 .72209 L .35915 .72019 L p .707 .577 .707 r
F P
0 g
s
.39032 .72209 m .39032 .74062 L .42216 .73984 L p .707 .577 .707 r
F P
0 g
s
.42216 .73984 m .42216 .72131 L .39032 .72209 L p .707 .577 .707 r
F P
0 g
s
.31064 .5795 m .31064 .63508 L .33169 .64154 L p .707 .577 .707 r
F P
0 g
s
.66161 .67604 m .66161 .7131 L .64524 .72047 L p .707 .577 .707 r
F P
0 g
s
.64524 .7399 m .64524 .72137 L .66161 .714 L p .707 .577 .707 r
F P
0 g
s
.42216 .72131 m .42216 .73984 L .45154 .73646 L p .707 .577 .707 r
F P
0 g
s
.45154 .73646 m .45154 .71794 L .42216 .72131 L p .707 .577 .707 r
F P
0 g
s
.45154 .67998 m .45154 .71703 L .47559 .71138 L p .707 .577 .707 r
F P
0 g
s
.47559 .71138 m .47559 .67433 L .45154 .67998 L p .707 .577 .707 r
F P
0 g
s
.35915 .72019 m .35915 .73872 L .39032 .74062 L p .707 .577 .707 r
F P
0 g
s
.80551 .58064 m .80551 .63623 L .77805 .63183 L p .707 .577 .707 r
F P
0 g
s
.77805 .63183 m .77805 .57625 L .80551 .58064 L p .707 .577 .707 r
F P
0 g
s
.33169 .67784 m .33169 .7149 L .35915 .71929 L p .707 .577 .707 r
F P
0 g
s
.35915 .73872 m .35915 .72019 L .33169 .7158 L p .707 .577 .707 r
F P
0 g
s
.66161 .714 m .66161 .73253 L .64524 .7399 L p .707 .577 .707 r
F P
0 g
s
.82657 .67898 m .82657 .71604 L .80551 .70959 L p .707 .577 .707 r
F P
0 g
s
.80551 .70959 m .80551 .67253 L .82657 .67898 L p .707 .577 .707 r
F P
0 g
s
.68566 .57851 m .68566 .63409 L .66161 .63974 L p .707 .577 .707 r
F P
0 g
s
.31064 .63508 m .31064 .5795 L .29804 .57162 L p .707 .577 .707 r
F P
0 g
s
.33169 .7158 m .33169 .73433 L .35915 .73872 L p .707 .577 .707 r
F P
0 g
s
.33169 .7149 m .33169 .67784 L .31064 .67139 L p .707 .577 .707 r
F P
0 g
s
.68566 .63409 m .68566 .57851 L .71504 .57513 L p .707 .577 .707 r
F P
0 g
s
.45154 .71794 m .45154 .73646 L .47559 .73081 L p .707 .577 .707 r
F P
0 g
s
.47559 .73081 m .47559 .71229 L .45154 .71794 L p .707 .577 .707 r
F P
0 g
s
.66161 .7131 m .66161 .67604 L .68566 .67039 L p .707 .577 .707 r
F P
0 g
s
.82657 .71694 m .82657 .73547 L .80551 .72902 L p .707 .577 .707 r
F P
0 g
s
.80551 .72902 m .80551 .71049 L .82657 .71694 L p .707 .577 .707 r
F P
0 g
s
.77805 .57625 m .77805 .63183 L .74688 .62993 L p .707 .577 .707 r
F P
0 g
s
.74688 .62993 m .74688 .57435 L .77805 .57625 L p .707 .577 .707 r
F P
0 g
s
.31064 .67139 m .31064 .70844 L .33169 .7149 L p .707 .577 .707 r
F P
0 g
s
.33169 .73433 m .33169 .7158 L .31064 .70934 L p .707 .577 .707 r
F P
0 g
s
.47559 .67433 m .47559 .71138 L .49196 .70401 L p .707 .577 .707 r
F P
0 g
s
.49196 .70401 m .49196 .66696 L .47559 .67433 L p .707 .577 .707 r
F P
0 g
s
.29804 .57162 m .29804 .6272 L .31064 .63508 L p .707 .577 .707 r
F P
0 g
s
.71504 .63071 m .71504 .57513 L .74688 .57435 L p .707 .577 .707 r
F P
0 g
s
.71504 .57513 m .71504 .63071 L .68566 .63409 L p .707 .577 .707 r
F P
0 g
s
.49196 .57507 m .49196 .63066 L .49904 .62229 L p .707 .577 .707 r
F P
0 g
s
.49904 .62229 m .49904 .56671 L .49196 .57507 L p .707 .577 .707 r
F P
0 g
s
.31064 .70934 m .31064 .72787 L .33169 .73433 L p .707 .577 .707 r
F P
0 g
s
.74688 .57435 m .74688 .62993 L .71504 .63071 L p .707 .577 .707 r
F P
0 g
s
.68566 .67039 m .68566 .70745 L .66161 .7131 L p .707 .577 .707 r
F P
0 g
s
.66161 .73253 m .66161 .714 L .68566 .70835 L p .707 .577 .707 r
F P
0 g
s
.80551 .67253 m .80551 .70959 L .77805 .70519 L p .707 .577 .707 r
F P
0 g
s
.77805 .70519 m .77805 .66814 L .80551 .67253 L p .707 .577 .707 r
F P
0 g
s
.68566 .70835 m .68566 .72688 L .66161 .73253 L p .707 .577 .707 r
F P
0 g
s
.31064 .70844 m .31064 .67139 L .29804 .6635 L p .707 .577 .707 r
F P
0 g
s
.47559 .71229 m .47559 .73081 L .49196 .72345 L p .707 .577 .707 r
F P
0 g
s
.49196 .72345 m .49196 .70492 L .47559 .71229 L p .707 .577 .707 r
F P
0 g
s
.29804 .6272 m .29804 .57162 L .29515 .56307 L p .707 .577 .707 r
F P
0 g
s
.68566 .70745 m .68566 .67039 L .71504 .66701 L p .707 .577 .707 r
F P
0 g
s
.80551 .71049 m .80551 .72902 L .77805 .72462 L p .707 .577 .707 r
F P
0 g
s
.77805 .72462 m .77805 .7061 L .80551 .71049 L p .707 .577 .707 r
F P
0 g
s
.29804 .6635 m .29804 .70056 L .31064 .70844 L p .707 .577 .707 r
F P
0 g
s
.31064 .72787 m .31064 .70934 L .29804 .70146 L p .707 .577 .707 r
F P
0 g
s
.77805 .66814 m .77805 .70519 L .74688 .70329 L p .707 .577 .707 r
F P
0 g
s
.74688 .70329 m .74688 .66624 L .77805 .66814 L p .707 .577 .707 r
F P
0 g
s
.71504 .66701 m .71504 .70407 L .68566 .70745 L p .707 .577 .707 r
F P
0 g
s
.68566 .72688 m .68566 .70835 L .71504 .70497 L p .707 .577 .707 r
F P
0 g
s
.71504 .70407 m .71504 .66701 L .74688 .66624 L p .707 .577 .707 r
F P
0 g
s
.29804 .70146 m .29804 .71999 L .31064 .72787 L p .707 .577 .707 r
F P
0 g
s
.49196 .66696 m .49196 .70401 L .49904 .69565 L p .707 .577 .707 r
F P
0 g
s
.49904 .69565 m .49904 .6586 L .49196 .66696 L p .707 .577 .707 r
F P
0 g
s
.29515 .56307 m .29515 .61866 L .29804 .6272 L p .707 .577 .707 r
F P
0 g
s
.74688 .66624 m .74688 .70329 L .71504 .70407 L p .707 .577 .707 r
F P
0 g
s
.71504 .70497 m .71504 .7235 L .68566 .72688 L p .707 .577 .707 r
F P
0 g
s
.49904 .56671 m .49904 .62229 L .49615 .61375 L p .707 .577 .707 r
F P
0 g
s
.49615 .61375 m .49615 .55817 L .49904 .56671 L p .707 .577 .707 r
F P
0 g
s
.77805 .7061 m .77805 .72462 L .74688 .72272 L p .707 .577 .707 r
F P
0 g
s
.74688 .72272 m .74688 .7042 L .77805 .7061 L p .707 .577 .707 r
F P
0 g
s
.71504 .7235 m .71504 .70497 L .74688 .7042 L p .707 .577 .707 r
F P
0 g
s
.49196 .70492 m .49196 .72345 L .49904 .71508 L p .707 .577 .707 r
F P
0 g
s
.49904 .71508 m .49904 .69655 L .49196 .70492 L p .707 .577 .707 r
F P
0 g
s
.29804 .70056 m .29804 .6635 L .29515 .65496 L p .707 .577 .707 r
F P
0 g
s
.74688 .7042 m .74688 .72272 L .71504 .7235 L p .707 .577 .707 r
F P
0 g
s
.29515 .61866 m .29515 .56307 L .30223 .55471 L p .707 .577 .707 r
F P
0 g
s
.29515 .65496 m .29515 .69202 L .29804 .70056 L p .707 .577 .707 r
F P
0 g
s
.29804 .71999 m .29804 .70146 L .29515 .69292 L p .707 .577 .707 r
F P
0 g
s
.29515 .69292 m .29515 .71145 L .29804 .71999 L p .707 .577 .707 r
F P
0 g
s
.49904 .6586 m .49904 .69565 L .49615 .68711 L p .707 .577 .707 r
F P
0 g
s
.49615 .68711 m .49615 .65005 L .49904 .6586 L p .707 .577 .707 r
F P
0 g
s
.30223 .55471 m .30223 .61029 L .29515 .61866 L p .707 .577 .707 r
F P
0 g
s
.49615 .55817 m .49615 .61375 L .48356 .60586 L p .707 .577 .707 r
F P
0 g
s
.48356 .60586 m .48356 .55028 L .49615 .55817 L p .707 .577 .707 r
F P
0 g
s
.49904 .69655 m .49904 .71508 L .49615 .70654 L p .707 .577 .707 r
F P
0 g
s
.49615 .70654 m .49615 .68801 L .49904 .69655 L p .707 .577 .707 r
F P
0 g
s
.29515 .69202 m .29515 .65496 L .30223 .6466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61029 m .30223 .55471 L .3186 .54734 L p .707 .577 .707 r
F P
0 g
s
.30223 .6466 m .30223 .68365 L .29515 .69202 L p .707 .577 .707 r
F P
0 g
s
.29515 .71145 m .29515 .69292 L .30223 .68455 L p .707 .577 .707 r
F P
0 g
s
.30223 .68455 m .30223 .70308 L .29515 .71145 L p .707 .577 .707 r
F P
0 g
s
.49615 .65005 m .49615 .68711 L .48356 .67922 L p .707 .577 .707 r
F P
0 g
s
.48356 .67922 m .48356 .64217 L .49615 .65005 L p .707 .577 .707 r
F P
0 g
s
.3186 .54734 m .3186 .60292 L .30223 .61029 L p .707 .577 .707 r
F P
0 g
s
.48356 .55028 m .48356 .60586 L .4625 .59941 L p .707 .577 .707 r
F P
0 g
s
.4625 .59941 m .4625 .54383 L .48356 .55028 L p .707 .577 .707 r
F P
0 g
s
.49615 .68801 m .49615 .70654 L .48356 .69865 L p .707 .577 .707 r
F P
0 g
s
.48356 .69865 m .48356 .68013 L .49615 .68801 L p .707 .577 .707 r
F P
0 g
s
.30223 .68365 m .30223 .6466 L .3186 .63923 L p .707 .577 .707 r
F P
0 g
s
.3186 .60292 m .3186 .54734 L .34265 .54169 L p .707 .577 .707 r
F P
0 g
s
.3186 .63923 m .3186 .67628 L .30223 .68365 L p .707 .577 .707 r
F P
0 g
s
.30223 .70308 m .30223 .68455 L .3186 .67719 L p .707 .577 .707 r
F P
0 g
s
.4625 .54383 m .4625 .59941 L .43504 .59502 L p .707 .577 .707 r
F P
0 g
s
.43504 .59502 m .43504 .53944 L .4625 .54383 L p .707 .577 .707 r
F P
0 g
s
.3186 .67719 m .3186 .69571 L .30223 .70308 L p .707 .577 .707 r
F P
0 g
s
.48356 .64217 m .48356 .67922 L .4625 .67277 L p .707 .577 .707 r
F P
0 g
s
.4625 .67277 m .4625 .63571 L .48356 .64217 L p .707 .577 .707 r
F P
0 g
s
.34265 .54169 m .34265 .59727 L .3186 .60292 L p .707 .577 .707 r
F P
0 g
s
.34265 .59727 m .34265 .54169 L .37203 .53831 L p .707 .577 .707 r
F P
0 g
s
.3186 .67628 m .3186 .63923 L .34265 .63358 L p .707 .577 .707 r
F P
0 g
s
.48356 .68013 m .48356 .69865 L .4625 .6922 L p .707 .577 .707 r
F P
0 g
s
.4625 .6922 m .4625 .67367 L .48356 .68013 L p .707 .577 .707 r
F P
0 g
s
.43504 .53944 m .43504 .59502 L .40387 .59312 L p .707 .577 .707 r
F P
0 g
s
.40387 .59312 m .40387 .53754 L .43504 .53944 L p .707 .577 .707 r
F P
0 g
s
.37203 .59389 m .37203 .53831 L .40387 .53754 L p .707 .577 .707 r
F P
0 g
s
.37203 .53831 m .37203 .59389 L .34265 .59727 L p .707 .577 .707 r
F P
0 g
s
.40387 .53754 m .40387 .59312 L .37203 .59389 L p .707 .577 .707 r
F P
0 g
s
.34265 .63358 m .34265 .67063 L .3186 .67628 L p .707 .577 .707 r
F P
0 g
s
.3186 .69571 m .3186 .67719 L .34265 .67154 L p .707 .577 .707 r
F P
0 g
s
.4625 .63571 m .4625 .67277 L .43504 .66838 L p .707 .577 .707 r
F P
0 g
s
.43504 .66838 m .43504 .63132 L .4625 .63571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67154 m .34265 .69006 L .3186 .69571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67063 m .34265 .63358 L .37203 .6302 L p .707 .577 .707 r
F P
0 g
s
.4625 .67367 m .4625 .6922 L .43504 .68781 L p .707 .577 .707 r
F P
0 g
s
.43504 .68781 m .43504 .66928 L .4625 .67367 L p .707 .577 .707 r
F P
0 g
s
.43504 .63132 m .43504 .66838 L .40387 .66648 L p .707 .577 .707 r
F P
0 g
s
.40387 .66648 m .40387 .62942 L .43504 .63132 L p .707 .577 .707 r
F P
0 g
s
.37203 .6302 m .37203 .66725 L .34265 .67063 L p .707 .577 .707 r
F P
0 g
s
.34265 .69006 m .34265 .67154 L .37203 .66816 L p .707 .577 .707 r
F P
0 g
s
.37203 .66725 m .37203 .6302 L .40387 .62942 L p .707 .577 .707 r
F P
0 g
s
.40387 .62942 m .40387 .66648 L .37203 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66816 m .37203 .68668 L .34265 .69006 L p .707 .577 .707 r
F P
0 g
s
.43504 .66928 m .43504 .68781 L .40387 .68591 L p .707 .577 .707 r
F P
0 g
s
.40387 .68591 m .40387 .66738 L .43504 .66928 L p .707 .577 .707 r
F P
0 g
s
.37203 .68668 m .37203 .66816 L .40387 .66738 L p .707 .577 .707 r
F P
0 g
s
.40387 .66738 m .40387 .68591 L .37203 .68668 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Ioo`00O7oo1P000UYF
00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001fOol60008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF2@0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol90004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005ioo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP@003Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH0
1UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
05=oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001J
EP04FUH00`00FUIJEP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPH000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
;7oo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03001JEP00008000AJEP04
001JEUYFFUH90007FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000=JEPH000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF
001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000UYF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000=J
EP00000020001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000H000AJEP04001J
EUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEP000003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@000UYF00<005YF00002EYF2@0025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH00UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF2@0000=JEP00
FUH00UYF00<005YF00002UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@000=JEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF2000
15YF00<005YFFUH00eYF3P001EYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF600000=JEP00FUH015YF00<005YFFUH01EYF00@005YF
FUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH20004FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00003000]Ool0031oo`<000AJEPP000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP<00003FUH005YF00=JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEPP000=J
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00004FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH40005FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000aOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF00000eYF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0000H00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001@00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH500000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP<0009JEP03001JEP0000D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF
009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF
009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00=JEP04001JEUYFFUH30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009oo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH005YFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH50003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH00`00Oomoo`02Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP02FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/
Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<007ooOol017oo0P0015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`001eYF00<0
05YFFUH015YF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/
Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool01goo0`0000=JEP00FUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000/Ool30004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP02000;Ool40008
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000030004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool90018Ool002aoo`<000AJ
EP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;7oo00<005YF
000015YF1@001eYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00
01Eoob8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2001DOol002aoo`03001JEP00009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001oogoo02Eoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP0000<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0UOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH0000200000eYF001oo`0VOol00`00FUH00004FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00001P0015YF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00<005YF00009goo00<005YF000015YF1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00E7oo000/
Ool20003FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00002FUH40004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2
001DOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YF
FUH00UYF1@001EYF00@005YFFUIJEP8002Qoo`03001JEP0000<00003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<0009JEP80
05Aoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000:Goo00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEPH005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`<000AJ
EP03001JEUYF009JEPL000QJEPD000AJEPP000=JEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00
<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;7oo00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1@0015YF
00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8005Aoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000cOol0
1000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF0`000eYF0P00E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP0200000eYF0000001DOol008ioo`D000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000D005Aoo`00SWoo0P000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
1@0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00001P000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
0UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
05Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065o
o`00YGoo4P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79348 m .59613 .7379 L .56496 .736 L p .707 .577 .707 r
F P
0 g
s
.59613 .7379 m .59613 .79348 L .62796 .79271 L p .707 .577 .707 r
F P
0 g
s
.62796 .79271 m .62796 .73713 L .59613 .7379 L p .707 .577 .707 r
F P
0 g
s
.62796 .73713 m .62796 .79271 L .65735 .78933 L p .707 .577 .707 r
F P
0 g
s
.65735 .78933 m .65734 .73375 L .62796 .73713 L p .707 .577 .707 r
F P
0 g
s
.56496 .79158 m .56496 .736 L .5375 .73161 L p .707 .577 .707 r
F P
0 g
s
.56496 .736 m .56496 .79158 L .59613 .79348 L p .707 .577 .707 r
F P
0 g
s
.65734 .73375 m .65735 .78933 L .6814 .78368 L p .707 .577 .707 r
F P
0 g
s
.6814 .78368 m .6814 .7281 L .65734 .73375 L p .707 .577 .707 r
F P
0 g
s
.5375 .73161 m .5375 .78719 L .56496 .79158 L p .707 .577 .707 r
F P
0 g
s
.5375 .78719 m .5375 .73161 L .51644 .72516 L p .707 .577 .707 r
F P
0 g
s
.59613 .87488 m .59613 .83782 L .56496 .83592 L p .707 .577 .707 r
F P
0 g
s
.59613 .83782 m .59613 .87488 L .62796 .8741 L p .707 .577 .707 r
F P
0 g
s
.62796 .8741 m .62796 .83704 L .59613 .83782 L p .707 .577 .707 r
F P
0 g
s
.62796 .83704 m .62796 .8741 L .65735 .87072 L p .707 .577 .707 r
F P
0 g
s
.65735 .87072 m .65735 .83367 L .62796 .83704 L p .707 .577 .707 r
F P
0 g
s
.59613 .88046 m .59613 .86193 L .56496 .86003 L p .707 .577 .707 r
F P
0 g
s
.59613 .86193 m .59613 .88046 L .62796 .87968 L p .707 .577 .707 r
F P
0 g
s
.62796 .87968 m .62796 .86116 L .59613 .86193 L p .707 .577 .707 r
F P
0 g
s
.56496 .87298 m .56496 .83592 L .5375 .83153 L p .707 .577 .707 r
F P
0 g
s
.56496 .83592 m .56496 .87298 L .59613 .87488 L p .707 .577 .707 r
F P
0 g
s
.6814 .7281 m .6814 .78368 L .69777 .77631 L p .707 .577 .707 r
F P
0 g
s
.69777 .77631 m .69777 .72073 L .6814 .7281 L p .707 .577 .707 r
F P
0 g
s
.62796 .86116 m .62796 .87968 L .65735 .8763 L p .707 .577 .707 r
F P
0 g
s
.65735 .8763 m .65735 .85778 L .62796 .86116 L p .707 .577 .707 r
F P
0 g
s
.51644 .72516 m .51644 .78074 L .5375 .78719 L p .707 .577 .707 r
F P
0 g
s
.56496 .86003 m .56496 .87856 L .59613 .88046 L p .707 .577 .707 r
F P
0 g
s
.56496 .87856 m .56496 .86003 L .5375 .85564 L p .707 .577 .707 r
F P
0 g
s
.65735 .83367 m .65735 .87072 L .6814 .86507 L p .707 .577 .707 r
F P
0 g
s
.6814 .86507 m .6814 .82802 L .65735 .83367 L p .707 .577 .707 r
F P
0 g
s
.5375 .83153 m .5375 .86858 L .56496 .87298 L p .707 .577 .707 r
F P
0 g
s
.51644 .78074 m .51644 .72516 L .50385 .71727 L p .707 .577 .707 r
F P
0 g
s
.5375 .85564 m .5375 .87417 L .56496 .87856 L p .707 .577 .707 r
F P
0 g
s
.65735 .85778 m .65735 .8763 L .6814 .87065 L p .707 .577 .707 r
F P
0 g
s
.6814 .87065 m .6814 .85213 L .65735 .85778 L p .707 .577 .707 r
F P
0 g
s
.5375 .86858 m .5375 .83153 L .51644 .82507 L p .707 .577 .707 r
F P
0 g
s
.5375 .87417 m .5375 .85564 L .51644 .84919 L p .707 .577 .707 r
F P
0 g
s
.51644 .82507 m .51644 .86213 L .5375 .86858 L p .707 .577 .707 r
F P
0 g
s
.50385 .71727 m .50385 .77285 L .51644 .78074 L p .707 .577 .707 r
F P
0 g
s
.69777 .72073 m .69777 .77631 L .70485 .76795 L p .707 .577 .707 r
F P
0 g
s
.70485 .76795 m .70485 .71237 L .69777 .72073 L p .707 .577 .707 r
F P
0 g
s
.51644 .84919 m .51644 .86771 L .5375 .87417 L p .707 .577 .707 r
F P
0 g
s
.6814 .82802 m .6814 .86507 L .69777 .8577 L p .707 .577 .707 r
F P
0 g
s
.69777 .8577 m .69777 .82065 L .6814 .82802 L p .707 .577 .707 r
F P
0 g
s
.6814 .85213 m .6814 .87065 L .69777 .86329 L p .707 .577 .707 r
F P
0 g
s
.69777 .86329 m .69777 .84476 L .6814 .85213 L p .707 .577 .707 r
F P
0 g
s
.51644 .86213 m .51644 .82507 L .50385 .81719 L p .707 .577 .707 r
F P
0 g
s
.49044 .76629 m .49044 .2644 L .44643 .26172 L p .707 .577 .707 r
F P
0 g
s
.50385 .77285 m .50385 .71727 L .50095 .70873 L p .707 .577 .707 r
F P
0 g
s
.50095 .70873 m .50095 .76431 L .50385 .77285 L p .707 .577 .707 r
F P
0 g
s
.50095 .76431 m .50095 .70873 L .50804 .70037 L p .707 .577 .707 r
F P
0 g
s
.50804 .70037 m .50804 .75595 L .50095 .76431 L p .707 .577 .707 r
F P
0 g
s
.50804 .75595 m .50804 .70037 L .5244 .693 L p .707 .577 .707 r
F P
0 g
s
.5244 .693 m .5244 .74858 L .50804 .75595 L p .707 .577 .707 r
F P
0 g
s
.5244 .74858 m .5244 .693 L .54846 .68735 L p .707 .577 .707 r
F P
0 g
s
.54846 .68735 m .54846 .74293 L .5244 .74858 L p .707 .577 .707 r
F P
0 g
s
.49044 .2644 m .49044 .76629 L .53538 .76519 L p .707 .577 .707 r
F P
0 g
s
.53538 .76519 m .53538 .2633 L .49044 .2644 L p .707 .577 .707 r
F P
0 g
s
.54846 .74293 m .54846 .68735 L .57784 .68397 L p .707 .577 .707 r
F P
0 g
s
.57784 .68397 m .57784 .73955 L .54846 .74293 L p .707 .577 .707 r
F P
0 g
s
.53538 .2633 m .53538 .76519 L .57686 .76042 L p .707 .577 .707 r
F P
0 g
s
.57686 .76042 m .57686 .25853 L .53538 .2633 L p .707 .577 .707 r
F P
0 g
s
.51644 .86771 m .51644 .84919 L .50385 .8413 L p .707 .577 .707 r
F P
0 g
s
.44643 .76361 m .44643 .26172 L .40766 .25552 L p .707 .577 .707 r
F P
0 g
s
.44643 .26172 m .44643 .76361 L .49044 .76629 L p .707 .577 .707 r
F P
0 g
s
.50385 .81719 m .50385 .85425 L .51644 .86213 L p .707 .577 .707 r
F P
0 g
s
.50385 .8413 m .50385 .85983 L .51644 .86771 L p .707 .577 .707 r
F P
0 g
s
.69777 .82065 m .69777 .8577 L .70485 .84934 L p .707 .577 .707 r
F P
0 g
s
.70485 .84934 m .70485 .81228 L .69777 .82065 L p .707 .577 .707 r
F P
0 g
s
.70485 .71237 m .70485 .76795 L .70195 .7594 L p .707 .577 .707 r
F P
0 g
s
.70195 .7594 m .70195 .70382 L .70485 .71237 L p .707 .577 .707 r
F P
0 g
s
.64085 .68509 m .64085 .74067 L .60968 .73877 L p .707 .577 .707 r
F P
0 g
s
.60968 .73877 m .60968 .68319 L .64085 .68509 L p .707 .577 .707 r
F P
0 g
s
.57784 .73955 m .57784 .68397 L .60968 .68319 L p .707 .577 .707 r
F P
0 g
s
.60968 .68319 m .60968 .73877 L .57784 .73955 L p .707 .577 .707 r
F P
0 g
s
.57686 .25853 m .57686 .76042 L .61082 .75244 L p .707 .577 .707 r
F P
0 g
s
.61082 .75244 m .61082 .25056 L .57686 .25853 L p .707 .577 .707 r
F P
0 g
s
.69777 .84476 m .69777 .86329 L .70485 .85492 L p .707 .577 .707 r
F P
0 g
s
.70485 .85492 m .70485 .8364 L .69777 .84476 L p .707 .577 .707 r
F P
0 g
s
.50385 .85425 m .50385 .81719 L .50095 .80865 L p .707 .577 .707 r
F P
0 g
s
.40766 .7574 m .40766 .25552 L .37794 .2464 L p .707 .577 .707 r
F P
0 g
s
.40766 .25552 m .40766 .7574 L .44643 .76361 L p .707 .577 .707 r
F P
0 g
s
.50385 .85983 m .50385 .8413 L .50095 .83276 L p .707 .577 .707 r
F P
0 g
s
.50095 .80865 m .50095 .8457 L .50385 .85425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .83276 m .50095 .85129 L .50385 .85983 L p .707 .577 .707 r
F P
0 g
s
.70485 .81228 m .70485 .84934 L .70195 .8408 L p .707 .577 .707 r
F P
0 g
s
.70195 .8408 m .70195 .80374 L .70485 .81228 L p .707 .577 .707 r
F P
0 g
s
.70195 .70382 m .70195 .7594 L .68936 .75152 L p .707 .577 .707 r
F P
0 g
s
.68936 .75152 m .68936 .69594 L .70195 .70382 L p .707 .577 .707 r
F P
0 g
s
.61082 .25056 m .61082 .75244 L .63393 .74204 L p .707 .577 .707 r
F P
0 g
s
.63393 .74204 m .63393 .24016 L .61082 .25056 L p .707 .577 .707 r
F P
0 g
s
.70485 .8364 m .70485 .85492 L .70195 .84638 L p .707 .577 .707 r
F P
0 g
s
.70195 .84638 m .70195 .82785 L .70485 .8364 L p .707 .577 .707 r
F P
0 g
s
.25312 .75667 m .25312 .70109 L .22195 .69919 L p .707 .577 .707 r
F P
0 g
s
.25312 .70109 m .25312 .75667 L .28495 .75589 L p .707 .577 .707 r
F P
0 g
s
.28495 .75589 m .28495 .70031 L .25312 .70109 L p .707 .577 .707 r
F P
0 g
s
.50095 .8457 m .50095 .80865 L .50804 .80028 L p .707 .577 .707 r
F P
0 g
s
.28495 .70031 m .28495 .75589 L .31434 .75251 L p .707 .577 .707 r
F P
0 g
s
.31434 .75251 m .31434 .69693 L .28495 .70031 L p .707 .577 .707 r
F P
0 g
s
.37794 .74829 m .37794 .2464 L .36016 .23527 L p .707 .577 .707 r
F P
0 g
s
.37794 .2464 m .37794 .74829 L .40766 .7574 L p .707 .577 .707 r
F P
0 g
s
.22195 .75477 m .22195 .69919 L .19449 .69479 L p .707 .577 .707 r
F P
0 g
s
.22195 .69919 m .22195 .75477 L .25312 .75667 L p .707 .577 .707 r
F P
0 g
s
.50095 .85129 m .50095 .83276 L .50804 .8244 L p .707 .577 .707 r
F P
0 g
s
.50804 .80028 m .50804 .83734 L .50095 .8457 L p .707 .577 .707 r
F P
0 g
s
.50804 .8244 m .50804 .84292 L .50095 .85129 L p .707 .577 .707 r
F P
0 g
s
.31434 .69693 m .31434 .75251 L .33839 .74686 L p .707 .577 .707 r
F P
0 g
s
.33839 .74686 m .33839 .69128 L .31434 .69693 L p .707 .577 .707 r
F P
0 g
s
.70195 .80374 m .70195 .8408 L .68936 .83291 L p .707 .577 .707 r
F P
0 g
s
.68936 .83291 m .68936 .79586 L .70195 .80374 L p .707 .577 .707 r
F P
0 g
s
.68936 .69594 m .68936 .75152 L .66831 .74507 L p .707 .577 .707 r
F P
0 g
s
.66831 .74507 m .66831 .68948 L .68936 .69594 L p .707 .577 .707 r
F P
0 g
s
.19449 .69479 m .19449 .75038 L .22195 .75477 L p .707 .577 .707 r
F P
0 g
s
.19449 .75038 m .19449 .69479 L .17343 .68834 L p .707 .577 .707 r
F P
0 g
s
.70195 .82785 m .70195 .84638 L .68936 .8385 L p .707 .577 .707 r
F P
0 g
s
.68936 .8385 m .68936 .81997 L .70195 .82785 L p .707 .577 .707 r
F P
0 g
s
.25312 .83806 m .25312 .80101 L .22195 .79911 L p .707 .577 .707 r
F P
0 g
s
.25312 .80101 m .25312 .83806 L .28495 .83728 L p .707 .577 .707 r
F P
0 g
s
.28495 .83728 m .28495 .80023 L .25312 .80101 L p .707 .577 .707 r
F P
0 g
s
.64085 .74067 m .64085 .68509 L .66831 .68948 L p .707 .577 .707 r
F P
0 g
s
.63393 .24016 m .63393 .74204 L .64393 .73023 L p .707 .577 .707 r
F P
0 g
s
.64393 .73023 m .64393 .22835 L .63393 .24016 L p .707 .577 .707 r
F P
0 g
s
.50804 .83734 m .50804 .80028 L .5244 .79292 L p .707 .577 .707 r
F P
0 g
s
.28495 .80023 m .28495 .83728 L .31434 .83391 L p .707 .577 .707 r
F P
0 g
s
.31434 .83391 m .31434 .79685 L .28495 .80023 L p .707 .577 .707 r
F P
0 g
s
.25312 .84365 m .25312 .82512 L .22195 .82322 L p .707 .577 .707 r
F P
0 g
s
.25312 .82512 m .25312 .84365 L .28495 .84287 L p .707 .577 .707 r
F P
0 g
s
.28495 .84287 m .28495 .82434 L .25312 .82512 L p .707 .577 .707 r
F P
0 g
s
.22195 .83616 m .22195 .79911 L .19449 .79471 L p .707 .577 .707 r
F P
0 g
s
.22195 .79911 m .22195 .83616 L .25312 .83806 L p .707 .577 .707 r
F P
0 g
s
.33839 .69128 m .33839 .74686 L .35476 .7395 L p .707 .577 .707 r
F P
0 g
s
.35476 .7395 m .35476 .68391 L .33839 .69128 L p .707 .577 .707 r
F P
0 g
s
.50804 .84292 m .50804 .8244 L .5244 .81703 L p .707 .577 .707 r
F P
0 g
s
.28495 .82434 m .28495 .84287 L .31434 .83949 L p .707 .577 .707 r
F P
0 g
s
.31434 .83949 m .31434 .82096 L .28495 .82434 L p .707 .577 .707 r
F P
0 g
s
.17343 .68834 m .17343 .74392 L .19449 .75038 L p .707 .577 .707 r
F P
0 g
s
.22195 .82322 m .22195 .84174 L .25312 .84365 L p .707 .577 .707 r
F P
0 g
s
.5244 .79292 m .5244 .82997 L .50804 .83734 L p .707 .577 .707 r
F P
0 g
s
.22195 .84174 m .22195 .82322 L .19449 .81883 L p .707 .577 .707 r
F P
0 g
s
.66831 .68948 m .66831 .74507 L .64085 .74067 L p .707 .577 .707 r
F P
0 g
s
.5244 .81703 m .5244 .83556 L .50804 .84292 L p .707 .577 .707 r
F P
0 g
s
.31434 .79685 m .31434 .83391 L .33839 .82826 L p .707 .577 .707 r
F P
0 g
s
.33839 .82826 m .33839 .7912 L .31434 .79685 L p .707 .577 .707 r
F P
0 g
s
.19449 .79471 m .19449 .83177 L .22195 .83616 L p .707 .577 .707 r
F P
0 g
s
.17343 .74392 m .17343 .68834 L .16084 .68046 L p .707 .577 .707 r
F P
0 g
s
.35476 .68391 m .35476 .7395 L .36184 .73113 L p .707 .577 .707 r
F P
0 g
s
.36184 .73113 m .36184 .67555 L .35476 .68391 L p .707 .577 .707 r
F P
0 g
s
.36184 .67555 m .36184 .73113 L .35894 .72259 L p .707 .577 .707 r
F P
0 g
s
.35894 .72259 m .35894 .66701 L .36184 .67555 L p .707 .577 .707 r
F P
0 g
s
.36016 .73716 m .36016 .23527 L .35607 .22321 L p .707 .577 .707 r
F P
0 g
s
.36016 .23527 m .36016 .73716 L .37794 .74829 L p .707 .577 .707 r
F P
0 g
s
.68936 .79586 m .68936 .83291 L .66831 .82646 L p .707 .577 .707 r
F P
0 g
s
.66831 .82646 m .66831 .7894 L .68936 .79586 L p .707 .577 .707 r
F P
0 g
s
.19449 .81883 m .19449 .83735 L .22195 .84174 L p .707 .577 .707 r
F P
0 g
s
.31434 .82096 m .31434 .83949 L .33839 .83384 L p .707 .577 .707 r
F P
0 g
s
.33839 .83384 m .33839 .81531 L .31434 .82096 L p .707 .577 .707 r
F P
0 g
s
.19449 .83177 m .19449 .79471 L .17343 .78826 L p .707 .577 .707 r
F P
0 g
s
.68936 .81997 m .68936 .8385 L .66831 .83204 L p .707 .577 .707 r
F P
0 g
s
.66831 .83204 m .66831 .81352 L .68936 .81997 L p .707 .577 .707 r
F P
0 g
s
.5244 .82997 m .5244 .79292 L .54846 .78727 L p .707 .577 .707 r
F P
0 g
s
.19449 .83735 m .19449 .81883 L .17343 .81237 L p .707 .577 .707 r
F P
0 g
s
.17343 .78826 m .17343 .82531 L .19449 .83177 L p .707 .577 .707 r
F P
0 g
s
.16084 .68046 m .16084 .73604 L .17343 .74392 L p .707 .577 .707 r
F P
0 g
s
.17343 .81237 m .17343 .8309 L .19449 .83735 L p .707 .577 .707 r
F P
0 g
s
.33839 .7912 m .33839 .82826 L .35476 .82089 L p .707 .577 .707 r
F P
0 g
s
.35476 .82089 m .35476 .78383 L .33839 .7912 L p .707 .577 .707 r
F P
0 g
s
.5244 .83556 m .5244 .81703 L .54846 .81138 L p .707 .577 .707 r
F P
0 g
s
.54846 .78727 m .54846 .82432 L .5244 .82997 L p .707 .577 .707 r
F P
0 g
s
.54846 .81138 m .54846 .82991 L .5244 .83556 L p .707 .577 .707 r
F P
0 g
s
.66831 .7894 m .66831 .82646 L .64085 .82207 L p .707 .577 .707 r
F P
0 g
s
.64085 .82207 m .64085 .78501 L .66831 .7894 L p .707 .577 .707 r
F P
0 g
s
.33839 .81531 m .33839 .83384 L .35476 .82647 L p .707 .577 .707 r
F P
0 g
s
.35476 .82647 m .35476 .80794 L .33839 .81531 L p .707 .577 .707 r
F P
0 g
s
.64393 .22835 m .64393 .73023 L .63984 .71818 L p .707 .577 .707 r
F P
0 g
s
.63984 .71818 m .63984 .21629 L .64393 .22835 L p .707 .577 .707 r
F P
0 g
s
.17343 .82531 m .17343 .78826 L .16084 .78038 L p .707 .577 .707 r
F P
0 g
s
.16084 .73604 m .16084 .68046 L .15794 .67191 L p .707 .577 .707 r
F P
0 g
s
.66831 .81352 m .66831 .83204 L .64085 .82765 L p .707 .577 .707 r
F P
0 g
s
.64085 .82765 m .64085 .80912 L .66831 .81352 L p .707 .577 .707 r
F P
0 g
s
.54846 .82432 m .54846 .78727 L .57784 .78389 L p .707 .577 .707 r
F P
0 g
s
.17343 .8309 m .17343 .81237 L .16084 .80449 L p .707 .577 .707 r
F P
0 g
s
.54846 .82991 m .54846 .81138 L .57784 .808 L p .707 .577 .707 r
F P
0 g
s
.16084 .78038 m .16084 .81743 L .17343 .82531 L p .707 .577 .707 r
F P
0 g
s
.64085 .78501 m .64085 .82207 L .60968 .82017 L p .707 .577 .707 r
F P
0 g
s
.60968 .82017 m .60968 .78311 L .64085 .78501 L p .707 .577 .707 r
F P
0 g
s
.16084 .80449 m .16084 .82301 L .17343 .8309 L p .707 .577 .707 r
F P
0 g
s
.57784 .78389 m .57784 .82094 L .54846 .82432 L p .707 .577 .707 r
F P
0 g
s
.57784 .808 m .57784 .82653 L .54846 .82991 L p .707 .577 .707 r
F P
0 g
s
.57784 .82094 m .57784 .78389 L .60968 .78311 L p .707 .577 .707 r
F P
0 g
s
.35894 .66701 m .35894 .72259 L .34635 .71471 L p .707 .577 .707 r
F P
0 g
s
.34635 .71471 m .34635 .65912 L .35894 .66701 L p .707 .577 .707 r
F P
0 g
s
.35607 .22321 m .35607 .7251 L .36016 .73716 L p .707 .577 .707 r
F P
0 g
s
.35607 .7251 m .35607 .22321 L .36607 .21141 L p .707 .577 .707 r
F P
0 g
s
.35476 .78383 m .35476 .82089 L .36184 .81252 L p .707 .577 .707 r
F P
0 g
s
.36184 .81252 m .36184 .77547 L .35476 .78383 L p .707 .577 .707 r
F P
0 g
s
.15794 .67191 m .15794 .7275 L .16084 .73604 L p .707 .577 .707 r
F P
0 g
s
.64085 .80912 m .64085 .82765 L .60968 .82575 L p .707 .577 .707 r
F P
0 g
s
.60968 .82575 m .60968 .80722 L .64085 .80912 L p .707 .577 .707 r
F P
0 g
s
.60968 .78311 m .60968 .82017 L .57784 .82094 L p .707 .577 .707 r
F P
0 g
s
.57784 .82653 m .57784 .808 L .60968 .80722 L p .707 .577 .707 r
F P
0 g
s
.35476 .80794 m .35476 .82647 L .36184 .81811 L p .707 .577 .707 r
F P
0 g
s
.36184 .81811 m .36184 .79958 L .35476 .80794 L p .707 .577 .707 r
F P
0 g
s
.60968 .80722 m .60968 .82575 L .57784 .82653 L p .707 .577 .707 r
F P
0 g
s
.16084 .81743 m .16084 .78038 L .15794 .77183 L p .707 .577 .707 r
F P
0 g
s
.15794 .7275 m .15794 .67191 L .16503 .66355 L p .707 .577 .707 r
F P
0 g
s
.16084 .82301 m .16084 .80449 L .15794 .79594 L p .707 .577 .707 r
F P
0 g
s
.15794 .77183 m .15794 .80889 L .16084 .81743 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .79594 m .15794 .81447 L .16084 .82301 L p .707 .577 .707 r
F P
0 g
s
.63984 .21629 m .63984 .71818 L .62206 .70704 L p .707 .577 .707 r
F P
0 g
s
.62206 .70704 m .62206 .20516 L .63984 .21629 L p .707 .577 .707 r
F P
0 g
s
.36184 .77547 m .36184 .81252 L .35894 .80398 L p .707 .577 .707 r
F P
0 g
s
.35894 .80398 m .35894 .76693 L .36184 .77547 L p .707 .577 .707 r
F P
0 g
s
.16503 .66355 m .16503 .71913 L .15794 .7275 L p .707 .577 .707 r
F P
0 g
s
.36184 .79958 m .36184 .81811 L .35894 .80957 L p .707 .577 .707 r
F P
0 g
s
.35894 .80957 m .35894 .79104 L .36184 .79958 L p .707 .577 .707 r
F P
0 g
s
.36607 .71329 m .36607 .21141 L .38918 .201 L p .707 .577 .707 r
F P
0 g
s
.36607 .21141 m .36607 .71329 L .35607 .7251 L p .707 .577 .707 r
F P
0 g
s
.15794 .80889 m .15794 .77183 L .16503 .76347 L p .707 .577 .707 r
F P
0 g
s
.16503 .71913 m .16503 .66355 L .1814 .65618 L p .707 .577 .707 r
F P
0 g
s
.15794 .81447 m .15794 .79594 L .16503 .78758 L p .707 .577 .707 r
F P
0 g
s
.16503 .76347 m .16503 .80052 L .15794 .80889 L p .707 .577 .707 r
F P
0 g
s
.16503 .78758 m .16503 .80611 L .15794 .81447 L p .707 .577 .707 r
F P
0 g
s
.35894 .76693 m .35894 .80398 L .34635 .7961 L p .707 .577 .707 r
F P
0 g
s
.34635 .7961 m .34635 .75904 L .35894 .76693 L p .707 .577 .707 r
F P
0 g
s
.1814 .65618 m .1814 .71176 L .16503 .71913 L p .707 .577 .707 r
F P
0 g
s
.34635 .65912 m .34635 .71471 L .3253 .70825 L p .707 .577 .707 r
F P
0 g
s
.3253 .70825 m .3253 .65267 L .34635 .65912 L p .707 .577 .707 r
F P
0 g
s
.62206 .20516 m .62206 .70704 L .59233 .69793 L p .707 .577 .707 r
F P
0 g
s
.59233 .69793 m .59233 .19604 L .62206 .20516 L p .707 .577 .707 r
F P
0 g
s
.35894 .79104 m .35894 .80957 L .34635 .80168 L p .707 .577 .707 r
F P
0 g
s
.34635 .80168 m .34635 .78315 L .35894 .79104 L p .707 .577 .707 r
F P
0 g
s
.1814 .71176 m .1814 .65618 L .20545 .65053 L p .707 .577 .707 r
F P
0 g
s
.16503 .80052 m .16503 .76347 L .1814 .7561 L p .707 .577 .707 r
F P
0 g
s
.38918 .201 m .38918 .70289 L .36607 .71329 L p .707 .577 .707 r
F P
0 g
s
.38918 .70289 m .38918 .201 L .42314 .19303 L p .707 .577 .707 r
F P
0 g
s
.16503 .80611 m .16503 .78758 L .1814 .78021 L p .707 .577 .707 r
F P
0 g
s
.1814 .7561 m .1814 .79316 L .16503 .80052 L p .707 .577 .707 r
F P
0 g
s
.3253 .65267 m .3253 .70825 L .29784 .70386 L p .707 .577 .707 r
F P
0 g
s
.29784 .70386 m .29784 .64828 L .3253 .65267 L p .707 .577 .707 r
F P
0 g
s
.1814 .78021 m .1814 .79874 L .16503 .80611 L p .707 .577 .707 r
F P
0 g
s
.20545 .65053 m .20545 .70611 L .1814 .71176 L p .707 .577 .707 r
F P
0 g
s
.34635 .75904 m .34635 .7961 L .3253 .78964 L p .707 .577 .707 r
F P
0 g
s
.3253 .78964 m .3253 .75259 L .34635 .75904 L p .707 .577 .707 r
F P
0 g
s
.20545 .70611 m .20545 .65053 L .23483 .64715 L p .707 .577 .707 r
F P
0 g
s
.34635 .78315 m .34635 .80168 L .3253 .79523 L p .707 .577 .707 r
F P
0 g
s
.3253 .79523 m .3253 .7767 L .34635 .78315 L p .707 .577 .707 r
F P
0 g
s
.59233 .19604 m .59233 .69793 L .55357 .69173 L p .707 .577 .707 r
F P
0 g
s
.55357 .69173 m .55357 .18984 L .59233 .19604 L p .707 .577 .707 r
F P
0 g
s
.1814 .79316 m .1814 .7561 L .20545 .75045 L p .707 .577 .707 r
F P
0 g
s
.29784 .64828 m .29784 .70386 L .26667 .70196 L p .707 .577 .707 r
F P
0 g
s
.26667 .70196 m .26667 .64638 L .29784 .64828 L p .707 .577 .707 r
F P
0 g
s
.23483 .70274 m .23483 .64715 L .26667 .64638 L p .707 .577 .707 r
F P
0 g
s
.23483 .64715 m .23483 .70274 L .20545 .70611 L p .707 .577 .707 r
F P
0 g
s
.1814 .79874 m .1814 .78021 L .20545 .77456 L p .707 .577 .707 r
F P
0 g
s
.26667 .64638 m .26667 .70196 L .23483 .70274 L p .707 .577 .707 r
F P
0 g
s
.42314 .69492 m .42314 .19303 L .46462 .18826 L p .707 .577 .707 r
F P
0 g
s
.42314 .19303 m .42314 .69492 L .38918 .70289 L p .707 .577 .707 r
F P
0 g
s
.73333 .70145 m .73333 .64586 L .70216 .64396 L p .707 .577 .707 r
F P
0 g
s
.73333 .64586 m .73333 .70145 L .76517 .70067 L p .707 .577 .707 r
F P
0 g
s
.76517 .70067 m .76517 .64509 L .73333 .64586 L p .707 .577 .707 r
F P
0 g
s
.20545 .75045 m .20545 .78751 L .1814 .79316 L p .707 .577 .707 r
F P
0 g
s
.20545 .77456 m .20545 .79309 L .1814 .79874 L p .707 .577 .707 r
F P
0 g
s
.76517 .64509 m .76517 .70067 L .79455 .69729 L p .707 .577 .707 r
F P
0 g
s
.79455 .69729 m .79455 .64171 L .76517 .64509 L p .707 .577 .707 r
F P
0 g
s
.3253 .75259 m .3253 .78964 L .29784 .78525 L p .707 .577 .707 r
F P
0 g
s
.29784 .78525 m .29784 .7482 L .3253 .75259 L p .707 .577 .707 r
F P
0 g
s
.70216 .69955 m .70216 .64396 L .6747 .63957 L p .707 .577 .707 r
F P
0 g
s
.70216 .64396 m .70216 .69955 L .73333 .70145 L p .707 .577 .707 r
F P
0 g
s
.3253 .7767 m .3253 .79523 L .29784 .79084 L p .707 .577 .707 r
F P
0 g
s
.29784 .79084 m .29784 .77231 L .3253 .7767 L p .707 .577 .707 r
F P
0 g
s
.55357 .18984 m .55357 .69173 L .50956 .68905 L p .707 .577 .707 r
F P
0 g
s
.50956 .68905 m .50956 .18716 L .55357 .18984 L p .707 .577 .707 r
F P
0 g
s
.20545 .78751 m .20545 .75045 L .23483 .74707 L p .707 .577 .707 r
F P
0 g
s
.79455 .64171 m .79455 .69729 L .8186 .69164 L p .707 .577 .707 r
F P
0 g
s
.8186 .69164 m .8186 .63606 L .79455 .64171 L p .707 .577 .707 r
F P
0 g
s
.46462 .69015 m .46462 .18826 L .50956 .18716 L p .707 .577 .707 r
F P
0 g
s
.46462 .18826 m .46462 .69015 L .42314 .69492 L p .707 .577 .707 r
F P
0 g
s
.20545 .79309 m .20545 .77456 L .23483 .77118 L p .707 .577 .707 r
F P
0 g
s
.29784 .7482 m .29784 .78525 L .26667 .78335 L p .707 .577 .707 r
F P
0 g
s
.26667 .78335 m .26667 .7463 L .29784 .7482 L p .707 .577 .707 r
F P
0 g
s
.50956 .18716 m .50956 .68905 L .46462 .69015 L p .707 .577 .707 r
F P
0 g
s
.23483 .74707 m .23483 .78413 L .20545 .78751 L p .707 .577 .707 r
F P
0 g
s
.6747 .63957 m .6747 .69515 L .70216 .69955 L p .707 .577 .707 r
F P
0 g
s
.6747 .69515 m .6747 .63957 L .65365 .63312 L p .707 .577 .707 r
F P
0 g
s
.23483 .77118 m .23483 .78971 L .20545 .79309 L p .707 .577 .707 r
F P
0 g
s
.23483 .78413 m .23483 .74707 L .26667 .7463 L p .707 .577 .707 r
F P
0 g
s
.29784 .77231 m .29784 .79084 L .26667 .78893 L p .707 .577 .707 r
F P
0 g
s
.26667 .78893 m .26667 .77041 L .29784 .77231 L p .707 .577 .707 r
F P
0 g
s
.26667 .7463 m .26667 .78335 L .23483 .78413 L p .707 .577 .707 r
F P
0 g
s
.73333 .78284 m .73333 .74578 L .70216 .74388 L p .707 .577 .707 r
F P
0 g
s
.73333 .74578 m .73333 .78284 L .76517 .78206 L p .707 .577 .707 r
F P
0 g
s
.76517 .78206 m .76517 .74501 L .73333 .74578 L p .707 .577 .707 r
F P
0 g
s
.23483 .78971 m .23483 .77118 L .26667 .77041 L p .707 .577 .707 r
F P
0 g
s
.76517 .74501 m .76517 .78206 L .79455 .77868 L p .707 .577 .707 r
F P
0 g
s
.79455 .77868 m .79455 .74163 L .76517 .74501 L p .707 .577 .707 r
F P
0 g
s
.26667 .77041 m .26667 .78893 L .23483 .78971 L p .707 .577 .707 r
F P
0 g
s
.73333 .78842 m .73333 .7699 L .70216 .76799 L p .707 .577 .707 r
F P
0 g
s
.73333 .7699 m .73333 .78842 L .76517 .78765 L p .707 .577 .707 r
F P
0 g
s
.76517 .78765 m .76517 .76912 L .73333 .7699 L p .707 .577 .707 r
F P
0 g
s
.70216 .78094 m .70216 .74388 L .6747 .73949 L p .707 .577 .707 r
F P
0 g
s
.70216 .74388 m .70216 .78094 L .73333 .78284 L p .707 .577 .707 r
F P
0 g
s
.8186 .63606 m .8186 .69164 L .83497 .68427 L p .707 .577 .707 r
F P
0 g
s
.83497 .68427 m .83497 .62869 L .8186 .63606 L p .707 .577 .707 r
F P
0 g
s
.76517 .76912 m .76517 .78765 L .79455 .78427 L p .707 .577 .707 r
F P
0 g
s
.79455 .78427 m .79455 .76574 L .76517 .76912 L p .707 .577 .707 r
F P
0 g
s
.65365 .63312 m .65365 .6887 L .6747 .69515 L p .707 .577 .707 r
F P
0 g
s
.70216 .76799 m .70216 .78652 L .73333 .78842 L p .707 .577 .707 r
F P
0 g
s
.70216 .78652 m .70216 .76799 L .6747 .7636 L p .707 .577 .707 r
F P
0 g
s
.79455 .74163 m .79455 .77868 L .8186 .77303 L p .707 .577 .707 r
F P
0 g
s
.8186 .77303 m .8186 .73598 L .79455 .74163 L p .707 .577 .707 r
F P
0 g
s
.6747 .73949 m .6747 .77655 L .70216 .78094 L p .707 .577 .707 r
F P
0 g
s
.65365 .6887 m .65365 .63312 L .64105 .62523 L p .707 .577 .707 r
F P
0 g
s
.6747 .7636 m .6747 .78213 L .70216 .78652 L p .707 .577 .707 r
F P
0 g
s
.79455 .76574 m .79455 .78427 L .8186 .77862 L p .707 .577 .707 r
F P
0 g
s
.8186 .77862 m .8186 .76009 L .79455 .76574 L p .707 .577 .707 r
F P
0 g
s
.6747 .77655 m .6747 .73949 L .65365 .73304 L p .707 .577 .707 r
F P
0 g
s
.6747 .78213 m .6747 .7636 L .65365 .75715 L p .707 .577 .707 r
F P
0 g
s
.65365 .73304 m .65365 .77009 L .6747 .77655 L p .707 .577 .707 r
F P
0 g
s
.64105 .62523 m .64105 .68082 L .65365 .6887 L p .707 .577 .707 r
F P
0 g
s
.83497 .62869 m .83497 .68427 L .84206 .67591 L p .707 .577 .707 r
F P
0 g
s
.84206 .67591 m .84205 .62033 L .83497 .62869 L p .707 .577 .707 r
F P
0 g
s
.65365 .75715 m .65365 .77568 L .6747 .78213 L p .707 .577 .707 r
F P
0 g
s
.8186 .73598 m .8186 .77303 L .83497 .76567 L p .707 .577 .707 r
F P
0 g
s
.83497 .76567 m .83497 .72861 L .8186 .73598 L p .707 .577 .707 r
F P
0 g
s
.8186 .76009 m .8186 .77862 L .83497 .77125 L p .707 .577 .707 r
F P
0 g
s
.83497 .77125 m .83497 .75272 L .8186 .76009 L p .707 .577 .707 r
F P
0 g
s
.65365 .77009 m .65365 .73304 L .64105 .72515 L p .707 .577 .707 r
F P
0 g
s
.64105 .68082 m .64105 .62523 L .63816 .61669 L p .707 .577 .707 r
F P
0 g
s
.65365 .77568 m .65365 .75715 L .64105 .74926 L p .707 .577 .707 r
F P
0 g
s
.64105 .72515 m .64105 .76221 L .65365 .77009 L p .707 .577 .707 r
F P
0 g
s
.64105 .74926 m .64105 .76779 L .65365 .77568 L p .707 .577 .707 r
F P
0 g
s
.83497 .72861 m .83497 .76567 L .84206 .7573 L p .707 .577 .707 r
F P
0 g
s
.84206 .7573 m .84206 .72025 L .83497 .72861 L p .707 .577 .707 r
F P
0 g
s
.63816 .61669 m .63816 .67227 L .64105 .68082 L p .707 .577 .707 r
F P
0 g
s
.84205 .62033 m .84206 .67591 L .83916 .66737 L p .707 .577 .707 r
F P
0 g
s
.83916 .66737 m .83916 .61178 L .84205 .62033 L p .707 .577 .707 r
F P
0 g
s
.83497 .75272 m .83497 .77125 L .84206 .76288 L p .707 .577 .707 r
F P
0 g
s
.84206 .76288 m .84206 .74436 L .83497 .75272 L p .707 .577 .707 r
F P
0 g
s
.64105 .76221 m .64105 .72515 L .63816 .71661 L p .707 .577 .707 r
F P
0 g
s
.63816 .67227 m .63816 .61669 L .64524 .60833 L p .707 .577 .707 r
F P
0 g
s
.64105 .76779 m .64105 .74926 L .63816 .74072 L p .707 .577 .707 r
F P
0 g
s
.63816 .71661 m .63816 .75367 L .64105 .76221 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .74072 m .63816 .75925 L .64105 .76779 L p .707 .577 .707 r
F P
0 g
s
.84206 .72025 m .84206 .7573 L .83916 .74876 L p .707 .577 .707 r
F P
0 g
s
.83916 .74876 m .83916 .7117 L .84206 .72025 L p .707 .577 .707 r
F P
0 g
s
.64524 .60833 m .64524 .66391 L .63816 .67227 L p .707 .577 .707 r
F P
0 g
s
.83916 .61178 m .83916 .66737 L .82657 .65948 L p .707 .577 .707 r
F P
0 g
s
.82657 .65948 m .82657 .6039 L .83916 .61178 L p .707 .577 .707 r
F P
0 g
s
.84206 .74436 m .84206 .76288 L .83916 .75434 L p .707 .577 .707 r
F P
0 g
s
.83916 .75434 m .83916 .73581 L .84206 .74436 L p .707 .577 .707 r
F P
0 g
s
.39032 .66463 m .39032 .60905 L .35915 .60715 L p .707 .577 .707 r
F P
0 g
s
.39032 .60905 m .39032 .66463 L .42216 .66385 L p .707 .577 .707 r
F P
0 g
s
.42216 .66385 m .42216 .60827 L .39032 .60905 L p .707 .577 .707 r
F P
0 g
s
.63816 .75367 m .63816 .71661 L .64524 .70825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66391 m .64524 .60833 L .66161 .60096 L p .707 .577 .707 r
F P
0 g
s
.42216 .60827 m .42216 .66385 L .45154 .66048 L p .707 .577 .707 r
F P
0 g
s
.45154 .66048 m .45154 .60489 L .42216 .60827 L p .707 .577 .707 r
F P
0 g
s
.35915 .66273 m .35915 .60715 L .33169 .60276 L p .707 .577 .707 r
F P
0 g
s
.35915 .60715 m .35915 .66273 L .39032 .66463 L p .707 .577 .707 r
F P
0 g
s
.63816 .75925 m .63816 .74072 L .64524 .73236 L p .707 .577 .707 r
F P
0 g
s
.64524 .70825 m .64524 .7453 L .63816 .75367 L p .707 .577 .707 r
F P
0 g
s
.64524 .73236 m .64524 .75089 L .63816 .75925 L p .707 .577 .707 r
F P
0 g
s
.45154 .60489 m .45154 .66048 L .47559 .65483 L p .707 .577 .707 r
F P
0 g
s
.47559 .65483 m .47559 .59924 L .45154 .60489 L p .707 .577 .707 r
F P
0 g
s
.83916 .7117 m .83916 .74876 L .82657 .74087 L p .707 .577 .707 r
F P
0 g
s
.82657 .74087 m .82657 .70382 L .83916 .7117 L p .707 .577 .707 r
F P
0 g
s
.66161 .60096 m .66161 .65654 L .64524 .66391 L p .707 .577 .707 r
F P
0 g
s
.82657 .6039 m .82657 .65948 L .80551 .65303 L p .707 .577 .707 r
F P
0 g
s
.80551 .65303 m .80551 .59745 L .82657 .6039 L p .707 .577 .707 r
F P
0 g
s
.33169 .60276 m .33169 .65834 L .35915 .66273 L p .707 .577 .707 r
F P
0 g
s
.33169 .65834 m .33169 .60276 L .31064 .5963 L p .707 .577 .707 r
F P
0 g
s
.83916 .73581 m .83916 .75434 L .82657 .74646 L p .707 .577 .707 r
F P
0 g
s
.82657 .74646 m .82657 .72793 L .83916 .73581 L p .707 .577 .707 r
F P
0 g
s
.39032 .74602 m .39032 .70897 L .35915 .70707 L p .707 .577 .707 r
F P
0 g
s
.39032 .70897 m .39032 .74602 L .42216 .74525 L p .707 .577 .707 r
F P
0 g
s
.42216 .74525 m .42216 .70819 L .39032 .70897 L p .707 .577 .707 r
F P
0 g
s
.66161 .65654 m .66161 .60096 L .68566 .59531 L p .707 .577 .707 r
F P
0 g
s
.64524 .7453 m .64524 .70825 L .66161 .70088 L p .707 .577 .707 r
F P
0 g
s
.42216 .70819 m .42216 .74525 L .45154 .74187 L p .707 .577 .707 r
F P
0 g
s
.45154 .74187 m .45154 .70481 L .42216 .70819 L p .707 .577 .707 r
F P
0 g
s
.39032 .75161 m .39032 .73308 L .35915 .73118 L p .707 .577 .707 r
F P
0 g
s
.39032 .73308 m .39032 .75161 L .42216 .75083 L p .707 .577 .707 r
F P
0 g
s
.42216 .75083 m .42216 .7323 L .39032 .73308 L p .707 .577 .707 r
F P
0 g
s
.35915 .74412 m .35915 .70707 L .33169 .70268 L p .707 .577 .707 r
F P
0 g
s
.35915 .70707 m .35915 .74412 L .39032 .74602 L p .707 .577 .707 r
F P
0 g
s
.47559 .59924 m .47559 .65483 L .49196 .64746 L p .707 .577 .707 r
F P
0 g
s
.49196 .64746 m .49196 .59188 L .47559 .59924 L p .707 .577 .707 r
F P
0 g
s
.64524 .75089 m .64524 .73236 L .66161 .72499 L p .707 .577 .707 r
F P
0 g
s
.42216 .7323 m .42216 .75083 L .45154 .74745 L p .707 .577 .707 r
F P
0 g
s
.45154 .74745 m .45154 .72892 L .42216 .7323 L p .707 .577 .707 r
F P
0 g
s
.31064 .5963 m .31064 .65188 L .33169 .65834 L p .707 .577 .707 r
F P
0 g
s
.35915 .73118 m .35915 .74971 L .39032 .75161 L p .707 .577 .707 r
F P
0 g
s
.66161 .70088 m .66161 .73793 L .64524 .7453 L p .707 .577 .707 r
F P
0 g
s
.35915 .74971 m .35915 .73118 L .33169 .72679 L p .707 .577 .707 r
F P
0 g
s
.80551 .59745 m .80551 .65303 L .77805 .64864 L p .707 .577 .707 r
F P
0 g
s
.77805 .64864 m .77805 .59305 L .80551 .59745 L p .707 .577 .707 r
F P
0 g
s
.66161 .72499 m .66161 .74352 L .64524 .75089 L p .707 .577 .707 r
F P
0 g
s
.45154 .70481 m .45154 .74187 L .47559 .73622 L p .707 .577 .707 r
F P
0 g
s
.47559 .73622 m .47559 .69916 L .45154 .70481 L p .707 .577 .707 r
F P
0 g
s
.68566 .59531 m .68566 .65089 L .66161 .65654 L p .707 .577 .707 r
F P
0 g
s
.33169 .70268 m .33169 .73973 L .35915 .74412 L p .707 .577 .707 r
F P
0 g
s
.31064 .65188 m .31064 .5963 L .29804 .58842 L p .707 .577 .707 r
F P
0 g
s
.82657 .70382 m .82657 .74087 L .80551 .73442 L p .707 .577 .707 r
F P
0 g
s
.80551 .73442 m .80551 .69737 L .82657 .70382 L p .707 .577 .707 r
F P
0 g
s
.33169 .72679 m .33169 .74531 L .35915 .74971 L p .707 .577 .707 r
F P
0 g
s
.68566 .65089 m .68566 .59531 L .71504 .59193 L p .707 .577 .707 r
F P
0 g
s
.45154 .72892 m .45154 .74745 L .47559 .7418 L p .707 .577 .707 r
F P
0 g
s
.47559 .7418 m .47559 .72327 L .45154 .72892 L p .707 .577 .707 r
F P
0 g
s
.33169 .73973 m .33169 .70268 L .31064 .69622 L p .707 .577 .707 r
F P
0 g
s
.82657 .72793 m .82657 .74646 L .80551 .74 L p .707 .577 .707 r
F P
0 g
s
.80551 .74 m .80551 .72148 L .82657 .72793 L p .707 .577 .707 r
F P
0 g
s
.66161 .73793 m .66161 .70088 L .68566 .69523 L p .707 .577 .707 r
F P
0 g
s
.33169 .74531 m .33169 .72679 L .31064 .72033 L p .707 .577 .707 r
F P
0 g
s
.77805 .59305 m .77805 .64864 L .74688 .64674 L p .707 .577 .707 r
F P
0 g
s
.74688 .64674 m .74688 .59115 L .77805 .59305 L p .707 .577 .707 r
F P
0 g
s
.31064 .69622 m .31064 .73328 L .33169 .73973 L p .707 .577 .707 r
F P
0 g
s
.29804 .58842 m .29804 .644 L .31064 .65188 L p .707 .577 .707 r
F P
0 g
s
.71504 .64751 m .71504 .59193 L .74688 .59115 L p .707 .577 .707 r
F P
0 g
s
.71504 .59193 m .71504 .64751 L .68566 .65089 L p .707 .577 .707 r
F P
0 g
s
.49196 .59188 m .49196 .64746 L .49904 .63909 L p .707 .577 .707 r
F P
0 g
s
.49904 .63909 m .49904 .58351 L .49196 .59188 L p .707 .577 .707 r
F P
0 g
s
.31064 .72033 m .31064 .73886 L .33169 .74531 L p .707 .577 .707 r
F P
0 g
s
.47559 .69916 m .47559 .73622 L .49196 .72885 L p .707 .577 .707 r
F P
0 g
s
.49196 .72885 m .49196 .69179 L .47559 .69916 L p .707 .577 .707 r
F P
0 g
s
.66161 .74352 m .66161 .72499 L .68566 .71934 L p .707 .577 .707 r
F P
0 g
s
.74688 .59115 m .74688 .64674 L .71504 .64751 L p .707 .577 .707 r
F P
0 g
s
.68566 .69523 m .68566 .73228 L .66161 .73793 L p .707 .577 .707 r
F P
0 g
s
.68566 .71934 m .68566 .73787 L .66161 .74352 L p .707 .577 .707 r
F P
0 g
s
.80551 .69737 m .80551 .73442 L .77805 .73003 L p .707 .577 .707 r
F P
0 g
s
.77805 .73003 m .77805 .69297 L .80551 .69737 L p .707 .577 .707 r
F P
0 g
s
.47559 .72327 m .47559 .7418 L .49196 .73443 L p .707 .577 .707 r
F P
0 g
s
.49196 .73443 m .49196 .71591 L .47559 .72327 L p .707 .577 .707 r
F P
0 g
s
.31064 .73328 m .31064 .69622 L .29804 .68834 L p .707 .577 .707 r
F P
0 g
s
.29804 .644 m .29804 .58842 L .29515 .57988 L p .707 .577 .707 r
F P
0 g
s
.80551 .72148 m .80551 .74 L .77805 .73561 L p .707 .577 .707 r
F P
0 g
s
.77805 .73561 m .77805 .71708 L .80551 .72148 L p .707 .577 .707 r
F P
0 g
s
.68566 .73228 m .68566 .69523 L .71504 .69185 L p .707 .577 .707 r
F P
0 g
s
.31064 .73886 m .31064 .72033 L .29804 .71245 L p .707 .577 .707 r
F P
0 g
s
.68566 .73787 m .68566 .71934 L .71504 .71596 L p .707 .577 .707 r
F P
0 g
s
.29804 .68834 m .29804 .72539 L .31064 .73328 L p .707 .577 .707 r
F P
0 g
s
.77805 .69297 m .77805 .73003 L .74688 .72813 L p .707 .577 .707 r
F P
0 g
s
.74688 .72813 m .74688 .69107 L .77805 .69297 L p .707 .577 .707 r
F P
0 g
s
.29804 .71245 m .29804 .73098 L .31064 .73886 L p .707 .577 .707 r
F P
0 g
s
.71504 .69185 m .71504 .7289 L .68566 .73228 L p .707 .577 .707 r
F P
0 g
s
.71504 .71596 m .71504 .73449 L .68566 .73787 L p .707 .577 .707 r
F P
0 g
s
.71504 .7289 m .71504 .69185 L .74688 .69107 L p .707 .577 .707 r
F P
0 g
s
.49196 .69179 m .49196 .72885 L .49904 .72049 L p .707 .577 .707 r
F P
0 g
s
.49904 .72049 m .49904 .68343 L .49196 .69179 L p .707 .577 .707 r
F P
0 g
s
.29515 .57988 m .29515 .63546 L .29804 .644 L p .707 .577 .707 r
F P
0 g
s
.49904 .58351 m .49904 .63909 L .49615 .63055 L p .707 .577 .707 r
F P
0 g
s
.49615 .63055 m .49615 .57497 L .49904 .58351 L p .707 .577 .707 r
F P
0 g
s
.77805 .71708 m .77805 .73561 L .74688 .73371 L p .707 .577 .707 r
F P
0 g
s
.74688 .73371 m .74688 .71518 L .77805 .71708 L p .707 .577 .707 r
F P
0 g
s
.74688 .69107 m .74688 .72813 L .71504 .7289 L p .707 .577 .707 r
F P
0 g
s
.71504 .73449 m .71504 .71596 L .74688 .71518 L p .707 .577 .707 r
F P
0 g
s
.49196 .71591 m .49196 .73443 L .49904 .72607 L p .707 .577 .707 r
F P
0 g
s
.49904 .72607 m .49904 .70754 L .49196 .71591 L p .707 .577 .707 r
F P
0 g
s
.74688 .71518 m .74688 .73371 L .71504 .73449 L p .707 .577 .707 r
F P
0 g
s
.29804 .72539 m .29804 .68834 L .29515 .6798 L p .707 .577 .707 r
F P
0 g
s
.29515 .63546 m .29515 .57988 L .30223 .57151 L p .707 .577 .707 r
F P
0 g
s
.29804 .73098 m .29804 .71245 L .29515 .70391 L p .707 .577 .707 r
F P
0 g
s
.29515 .6798 m .29515 .71685 L .29804 .72539 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .70391 m .29515 .72243 L .29804 .73098 L p .707 .577 .707 r
F P
0 g
s
.49904 .68343 m .49904 .72049 L .49615 .71194 L p .707 .577 .707 r
F P
0 g
s
.49615 .71194 m .49615 .67489 L .49904 .68343 L p .707 .577 .707 r
F P
0 g
s
.30223 .57151 m .30223 .62709 L .29515 .63546 L p .707 .577 .707 r
F P
0 g
s
.49615 .57497 m .49615 .63055 L .48356 .62267 L p .707 .577 .707 r
F P
0 g
s
.48356 .62267 m .48356 .56708 L .49615 .57497 L p .707 .577 .707 r
F P
0 g
s
.49904 .70754 m .49904 .72607 L .49615 .71753 L p .707 .577 .707 r
F P
0 g
s
.49615 .71753 m .49615 .699 L .49904 .70754 L p .707 .577 .707 r
F P
0 g
s
.29515 .71685 m .29515 .6798 L .30223 .67143 L p .707 .577 .707 r
F P
0 g
s
.30223 .62709 m .30223 .57151 L .3186 .56414 L p .707 .577 .707 r
F P
0 g
s
.29515 .72243 m .29515 .70391 L .30223 .69554 L p .707 .577 .707 r
F P
0 g
s
.30223 .67143 m .30223 .70849 L .29515 .71685 L p .707 .577 .707 r
F P
0 g
s
.30223 .69554 m .30223 .71407 L .29515 .72243 L p .707 .577 .707 r
F P
0 g
s
.49615 .67489 m .49615 .71194 L .48356 .70406 L p .707 .577 .707 r
F P
0 g
s
.48356 .70406 m .48356 .667 L .49615 .67489 L p .707 .577 .707 r
F P
0 g
s
.3186 .56414 m .3186 .61973 L .30223 .62709 L p .707 .577 .707 r
F P
0 g
s
.48356 .56708 m .48356 .62267 L .4625 .61621 L p .707 .577 .707 r
F P
0 g
s
.4625 .61621 m .4625 .56063 L .48356 .56708 L p .707 .577 .707 r
F P
0 g
s
.49615 .699 m .49615 .71753 L .48356 .70964 L p .707 .577 .707 r
F P
0 g
s
.48356 .70964 m .48356 .69112 L .49615 .699 L p .707 .577 .707 r
F P
0 g
s
.3186 .61973 m .3186 .56414 L .34265 .55849 L p .707 .577 .707 r
F P
0 g
s
.30223 .70849 m .30223 .67143 L .3186 .66406 L p .707 .577 .707 r
F P
0 g
s
.30223 .71407 m .30223 .69554 L .3186 .68817 L p .707 .577 .707 r
F P
0 g
s
.3186 .66406 m .3186 .70112 L .30223 .70849 L p .707 .577 .707 r
F P
0 g
s
.4625 .56063 m .4625 .61621 L .43504 .61182 L p .707 .577 .707 r
F P
0 g
s
.43504 .61182 m .43504 .55624 L .4625 .56063 L p .707 .577 .707 r
F P
0 g
s
.3186 .68817 m .3186 .7067 L .30223 .71407 L p .707 .577 .707 r
F P
0 g
s
.34265 .55849 m .34265 .61408 L .3186 .61973 L p .707 .577 .707 r
F P
0 g
s
.48356 .667 m .48356 .70406 L .4625 .6976 L p .707 .577 .707 r
F P
0 g
s
.4625 .6976 m .4625 .66055 L .48356 .667 L p .707 .577 .707 r
F P
0 g
s
.34265 .61408 m .34265 .55849 L .37203 .55511 L p .707 .577 .707 r
F P
0 g
s
.48356 .69112 m .48356 .70964 L .4625 .70319 L p .707 .577 .707 r
F P
0 g
s
.4625 .70319 m .4625 .68466 L .48356 .69112 L p .707 .577 .707 r
F P
0 g
s
.3186 .70112 m .3186 .66406 L .34265 .65841 L p .707 .577 .707 r
F P
0 g
s
.43504 .55624 m .43504 .61182 L .40387 .60992 L p .707 .577 .707 r
F P
0 g
s
.40387 .60992 m .40387 .55434 L .43504 .55624 L p .707 .577 .707 r
F P
0 g
s
.37203 .6107 m .37203 .55511 L .40387 .55434 L p .707 .577 .707 r
F P
0 g
s
.37203 .55511 m .37203 .6107 L .34265 .61408 L p .707 .577 .707 r
F P
0 g
s
.3186 .7067 m .3186 .68817 L .34265 .68252 L p .707 .577 .707 r
F P
0 g
s
.40387 .55434 m .40387 .60992 L .37203 .6107 L p .707 .577 .707 r
F P
0 g
s
.34265 .65841 m .34265 .69547 L .3186 .70112 L p .707 .577 .707 r
F P
0 g
s
.34265 .68252 m .34265 .70105 L .3186 .7067 L p .707 .577 .707 r
F P
0 g
s
.4625 .66055 m .4625 .6976 L .43504 .69321 L p .707 .577 .707 r
F P
0 g
s
.43504 .69321 m .43504 .65616 L .4625 .66055 L p .707 .577 .707 r
F P
0 g
s
.4625 .68466 m .4625 .70319 L .43504 .6988 L p .707 .577 .707 r
F P
0 g
s
.43504 .6988 m .43504 .68027 L .4625 .68466 L p .707 .577 .707 r
F P
0 g
s
.34265 .69547 m .34265 .65841 L .37203 .65503 L p .707 .577 .707 r
F P
0 g
s
.34265 .70105 m .34265 .68252 L .37203 .67915 L p .707 .577 .707 r
F P
0 g
s
.43504 .65616 m .43504 .69321 L .40387 .69131 L p .707 .577 .707 r
F P
0 g
s
.40387 .69131 m .40387 .65426 L .43504 .65616 L p .707 .577 .707 r
F P
0 g
s
.37203 .65503 m .37203 .69209 L .34265 .69547 L p .707 .577 .707 r
F P
0 g
s
.37203 .67915 m .37203 .69767 L .34265 .70105 L p .707 .577 .707 r
F P
0 g
s
.37203 .69209 m .37203 .65503 L .40387 .65426 L p .707 .577 .707 r
F P
0 g
s
.43504 .68027 m .43504 .6988 L .40387 .6969 L p .707 .577 .707 r
F P
0 g
s
.40387 .6969 m .40387 .67837 L .43504 .68027 L p .707 .577 .707 r
F P
0 g
s
.40387 .65426 m .40387 .69131 L .37203 .69209 L p .707 .577 .707 r
F P
0 g
s
.37203 .69767 m .37203 .67915 L .40387 .67837 L p .707 .577 .707 r
F P
0 g
s
.40387 .67837 m .40387 .6969 L .37203 .69767 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001dOol300000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0071oo`@000AJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006io
o`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001J
EUYFFUH3001^Ool006aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001X
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00003
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@0
05YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH0
0000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Agoo2@0017oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000oOol80004FUH00`00FUIJEP02FUH700000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH300000eYF001JEP06FUHI00000eYF001JEP02FUH50007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031o
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EPD000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF2P001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000eYF00<005YFFUH01eYF2@0025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH000000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YFFUH01EYF1P000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH00004FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00
FUIJEP02FUH00`00FUH00005FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@00=goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0003
FUH00`00FUH00004FUH20002FUH80002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH70004
FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH400000eYF001JEP03FUH500000eYF0000000200001EYF001JEUYF00000eYF0P001EYF
00<005YFFUH01eYF1@000eYF0`0000=JEP00FUH00UYF00<005YFFUH025YF00<005YFFUH025YF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo
00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001J
EP800003FUH0000000AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP<000=JEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`00<7oo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUH005YF10001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000^Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJ
EQ@000EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`06001JEP00001JEP001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00
00800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
0003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP@000IJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000MJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04
001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040003FUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005
FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF1@001EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUHA0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP0000000eYF00<005YFFUH00eYF0P000eYF4P0015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YF00000`00;Goo000]Ool01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P000eYF2000
47oo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUH0009J
EP03001JEP0000D000=JEP8001Eoo`P000AJEP04001JEUYFFUH2000]Ool0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000@000AJEP<0
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH00000009JEP<00003FUH005YF009J
EPT000Uoo`T000=JEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<goo0`0000=JEP00
FUH01UYF5`000eYF00@005YFFUIJEPL0009JEP03001JEUYF00AJEP8000UJEP03001JEUYF009JEPD0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP0000<0009JEP04001J
EP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003FUH2000]Ool003Ioo`T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00H000MooaT00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
00=JEP05001JEUYF001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool003Eoo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD0011oo`<00003FUH005YF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<000IJEP03
001JEUYF00800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool0039oo`<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000moo`@000QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000L000EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]Ool0031oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80019o
o`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEPL000AJEPD000AJEP03001J
EUYF0080009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEPD000=JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000001Ioob80009JEP03001JEUYF00IJEPD000AJEP06001JEUYFFUH005YF0P0015YF0P001eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF0P00;Woo
000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00009goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00=JEP<000EJEQ4000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF5P0015YF00<005YFFUH00eYF00D005YFFUIJEP00
02Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH3
0003FUH00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP0002Uoo`03001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00
000aOol002aoo`03001JEP0000AJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP03001oogoo02Qoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo
00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001oogoo02Uoo`<000=JEP03001JEUYF
00EJEQ<000MJEP04001JEUYFFUH50003FUH20005FUH40008FUH00`00FUIJEP05FUH00`00FUH00003
000fOol002aoo`04001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool;0004FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF000000020003Ool90004FUH00`00FUIJEP02FUH>000jOol002ao
o`03001JEP0000AJEP03001JEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001J
EUYF0080031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
000=Ool90018Ool002aoo`03001JEP0000AJEP8000AJEPH001Moo`@0009JEP03001JEUYF00=JEP05
001JEUYFFUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002aoo`03001JEP0000AJEP03001JEP0000L001Uoo`T000=J
EP05001JEUYFFUH0000[Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001IOol002aoo`04001JEP000002FUH30002
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0WOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH3001GOol002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<007ooOol09Woo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH>0004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20002FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
00000eYF001oo`0VOol00`00FUH00004FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0002Moo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00E7oo000/Ool20003
FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00004FUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P00:7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00E7oo000]Ool00`00FUIJEP020005FUH00`00FUIJEP03FUH30005FUHA0003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00:7oo00@005YF000000=JEP03001JEUYF00=JEP8000MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000005Aoo`00;Woo
0P0000=JEP00FUH00UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002Uoo`03001JEP0000AJEP8000=JEPl000Uoo`P000=J
EP03001JEUYF00=JEP03001JEUYF00<005Aoo`00<7oo0`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`03001JEP0000AJEP03
001JEP0000@001ioo`D000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00AJEP<000MJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000/Ool01000FUH000000UYF0`0000=J
EP00FUH00UYF2@004Woo1@000eYF0`0000=JEP00FUH00UYF0P00E7oo000fOol50004FUH00`00FUIJ
EP04FUH20009FUH00`00FUIJEP02FUH7000aOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF4P000eYF00<005YFFUH015YF0`000eYF0P00E7oo000kOolK000hOol00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP0200000eYF0000001DOol008ioo`800003FUH0000000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4
001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03001DOol008ioo`80009JEP07
001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000=JEP03001JEP0005Aoo`00SWoo0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF00<005YF0000E7oo002?
Ool01000FUIJEP001EYF00<005YFFUH00eYF0`0025YF00<005YFFUH00UYF2@000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20003FUH20007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000F7oo
002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001JOol009Moo`D000=JEP8000EJEP@000QJEP03001JEUYF00EJEP03001JEP0000<0
05eoo`00W7oo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002UOolB001VOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79348 m .59613 .7379 L .56496 .736 L p .707 .577 .707 r
F P
0 g
s
.59613 .7379 m .59613 .79348 L .62796 .79271 L p .707 .577 .707 r
F P
0 g
s
.62796 .79271 m .62796 .73713 L .59613 .7379 L p .707 .577 .707 r
F P
0 g
s
.62796 .73713 m .62796 .79271 L .65735 .78933 L p .707 .577 .707 r
F P
0 g
s
.65735 .78933 m .65734 .73375 L .62796 .73713 L p .707 .577 .707 r
F P
0 g
s
.56496 .79158 m .56496 .736 L .5375 .73161 L p .707 .577 .707 r
F P
0 g
s
.56496 .736 m .56496 .79158 L .59613 .79348 L p .707 .577 .707 r
F P
0 g
s
.65734 .73375 m .65735 .78933 L .6814 .78368 L p .707 .577 .707 r
F P
0 g
s
.6814 .78368 m .6814 .7281 L .65734 .73375 L p .707 .577 .707 r
F P
0 g
s
.5375 .73161 m .5375 .78719 L .56496 .79158 L p .707 .577 .707 r
F P
0 g
s
.5375 .78719 m .5375 .73161 L .51644 .72516 L p .707 .577 .707 r
F P
0 g
s
.59613 .87488 m .59613 .83782 L .56496 .83592 L p .707 .577 .707 r
F P
0 g
s
.59613 .83782 m .59613 .87488 L .62796 .8741 L p .707 .577 .707 r
F P
0 g
s
.62796 .8741 m .62796 .83704 L .59613 .83782 L p .707 .577 .707 r
F P
0 g
s
.62796 .83704 m .62796 .8741 L .65735 .87072 L p .707 .577 .707 r
F P
0 g
s
.65735 .87072 m .65735 .83367 L .62796 .83704 L p .707 .577 .707 r
F P
0 g
s
.59613 .88046 m .59613 .86193 L .56496 .86003 L p .707 .577 .707 r
F P
0 g
s
.59613 .86193 m .59613 .88046 L .62796 .87968 L p .707 .577 .707 r
F P
0 g
s
.62796 .87968 m .62796 .86116 L .59613 .86193 L p .707 .577 .707 r
F P
0 g
s
.56496 .87298 m .56496 .83592 L .5375 .83153 L p .707 .577 .707 r
F P
0 g
s
.56496 .83592 m .56496 .87298 L .59613 .87488 L p .707 .577 .707 r
F P
0 g
s
.6814 .7281 m .6814 .78368 L .69777 .77631 L p .707 .577 .707 r
F P
0 g
s
.69777 .77631 m .69777 .72073 L .6814 .7281 L p .707 .577 .707 r
F P
0 g
s
.62796 .86116 m .62796 .87968 L .65735 .8763 L p .707 .577 .707 r
F P
0 g
s
.65735 .8763 m .65735 .85778 L .62796 .86116 L p .707 .577 .707 r
F P
0 g
s
.51644 .72516 m .51644 .78074 L .5375 .78719 L p .707 .577 .707 r
F P
0 g
s
.56496 .86003 m .56496 .87856 L .59613 .88046 L p .707 .577 .707 r
F P
0 g
s
.56496 .87856 m .56496 .86003 L .5375 .85564 L p .707 .577 .707 r
F P
0 g
s
.65735 .83367 m .65735 .87072 L .6814 .86507 L p .707 .577 .707 r
F P
0 g
s
.6814 .86507 m .6814 .82802 L .65735 .83367 L p .707 .577 .707 r
F P
0 g
s
.5375 .83153 m .5375 .86858 L .56496 .87298 L p .707 .577 .707 r
F P
0 g
s
.51644 .78074 m .51644 .72516 L .50385 .71727 L p .707 .577 .707 r
F P
0 g
s
.5375 .85564 m .5375 .87417 L .56496 .87856 L p .707 .577 .707 r
F P
0 g
s
.65735 .85778 m .65735 .8763 L .6814 .87065 L p .707 .577 .707 r
F P
0 g
s
.6814 .87065 m .6814 .85213 L .65735 .85778 L p .707 .577 .707 r
F P
0 g
s
.5375 .86858 m .5375 .83153 L .51644 .82507 L p .707 .577 .707 r
F P
0 g
s
.5375 .87417 m .5375 .85564 L .51644 .84919 L p .707 .577 .707 r
F P
0 g
s
.51644 .82507 m .51644 .86213 L .5375 .86858 L p .707 .577 .707 r
F P
0 g
s
.50385 .71727 m .50385 .77285 L .51644 .78074 L p .707 .577 .707 r
F P
0 g
s
.69777 .72073 m .69777 .77631 L .70485 .76795 L p .707 .577 .707 r
F P
0 g
s
.70485 .76795 m .70485 .71237 L .69777 .72073 L p .707 .577 .707 r
F P
0 g
s
.51644 .84919 m .51644 .86771 L .5375 .87417 L p .707 .577 .707 r
F P
0 g
s
.6814 .82802 m .6814 .86507 L .69777 .8577 L p .707 .577 .707 r
F P
0 g
s
.69777 .8577 m .69777 .82065 L .6814 .82802 L p .707 .577 .707 r
F P
0 g
s
.6814 .85213 m .6814 .87065 L .69777 .86329 L p .707 .577 .707 r
F P
0 g
s
.69777 .86329 m .69777 .84476 L .6814 .85213 L p .707 .577 .707 r
F P
0 g
s
.51644 .86213 m .51644 .82507 L .50385 .81719 L p .707 .577 .707 r
F P
0 g
s
.49044 .76629 m .49044 .2644 L .44643 .26172 L p .707 .577 .707 r
F P
0 g
s
.50385 .77285 m .50385 .71727 L .50095 .70873 L p .707 .577 .707 r
F P
0 g
s
.50095 .70873 m .50095 .76431 L .50385 .77285 L p .707 .577 .707 r
F P
0 g
s
.50095 .76431 m .50095 .70873 L .50804 .70037 L p .707 .577 .707 r
F P
0 g
s
.50804 .70037 m .50804 .75595 L .50095 .76431 L p .707 .577 .707 r
F P
0 g
s
.50804 .75595 m .50804 .70037 L .5244 .693 L p .707 .577 .707 r
F P
0 g
s
.5244 .693 m .5244 .74858 L .50804 .75595 L p .707 .577 .707 r
F P
0 g
s
.5244 .74858 m .5244 .693 L .54846 .68735 L p .707 .577 .707 r
F P
0 g
s
.54846 .68735 m .54846 .74293 L .5244 .74858 L p .707 .577 .707 r
F P
0 g
s
.49044 .2644 m .49044 .76629 L .53538 .76519 L p .707 .577 .707 r
F P
0 g
s
.53538 .76519 m .53538 .2633 L .49044 .2644 L p .707 .577 .707 r
F P
0 g
s
.54846 .74293 m .54846 .68735 L .57784 .68397 L p .707 .577 .707 r
F P
0 g
s
.57784 .68397 m .57784 .73955 L .54846 .74293 L p .707 .577 .707 r
F P
0 g
s
.53538 .2633 m .53538 .76519 L .57686 .76042 L p .707 .577 .707 r
F P
0 g
s
.57686 .76042 m .57686 .25853 L .53538 .2633 L p .707 .577 .707 r
F P
0 g
s
.51644 .86771 m .51644 .84919 L .50385 .8413 L p .707 .577 .707 r
F P
0 g
s
.44643 .76361 m .44643 .26172 L .40766 .25552 L p .707 .577 .707 r
F P
0 g
s
.44643 .26172 m .44643 .76361 L .49044 .76629 L p .707 .577 .707 r
F P
0 g
s
.50385 .81719 m .50385 .85425 L .51644 .86213 L p .707 .577 .707 r
F P
0 g
s
.50385 .8413 m .50385 .85983 L .51644 .86771 L p .707 .577 .707 r
F P
0 g
s
.69777 .82065 m .69777 .8577 L .70485 .84934 L p .707 .577 .707 r
F P
0 g
s
.70485 .84934 m .70485 .81228 L .69777 .82065 L p .707 .577 .707 r
F P
0 g
s
.70485 .71237 m .70485 .76795 L .70195 .7594 L p .707 .577 .707 r
F P
0 g
s
.70195 .7594 m .70195 .70382 L .70485 .71237 L p .707 .577 .707 r
F P
0 g
s
.64085 .68509 m .64085 .74067 L .60968 .73877 L p .707 .577 .707 r
F P
0 g
s
.60968 .73877 m .60968 .68319 L .64085 .68509 L p .707 .577 .707 r
F P
0 g
s
.57784 .73955 m .57784 .68397 L .60968 .68319 L p .707 .577 .707 r
F P
0 g
s
.60968 .68319 m .60968 .73877 L .57784 .73955 L p .707 .577 .707 r
F P
0 g
s
.57686 .25853 m .57686 .76042 L .61082 .75244 L p .707 .577 .707 r
F P
0 g
s
.61082 .75244 m .61082 .25056 L .57686 .25853 L p .707 .577 .707 r
F P
0 g
s
.69777 .84476 m .69777 .86329 L .70485 .85492 L p .707 .577 .707 r
F P
0 g
s
.70485 .85492 m .70485 .8364 L .69777 .84476 L p .707 .577 .707 r
F P
0 g
s
.50385 .85425 m .50385 .81719 L .50095 .80865 L p .707 .577 .707 r
F P
0 g
s
.40766 .7574 m .40766 .25552 L .37794 .2464 L p .707 .577 .707 r
F P
0 g
s
.40766 .25552 m .40766 .7574 L .44643 .76361 L p .707 .577 .707 r
F P
0 g
s
.50385 .85983 m .50385 .8413 L .50095 .83276 L p .707 .577 .707 r
F P
0 g
s
.50095 .80865 m .50095 .8457 L .50385 .85425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .83276 m .50095 .85129 L .50385 .85983 L p .707 .577 .707 r
F P
0 g
s
.70485 .81228 m .70485 .84934 L .70195 .8408 L p .707 .577 .707 r
F P
0 g
s
.70195 .8408 m .70195 .80374 L .70485 .81228 L p .707 .577 .707 r
F P
0 g
s
.70195 .70382 m .70195 .7594 L .68936 .75152 L p .707 .577 .707 r
F P
0 g
s
.68936 .75152 m .68936 .69594 L .70195 .70382 L p .707 .577 .707 r
F P
0 g
s
.61082 .25056 m .61082 .75244 L .63393 .74204 L p .707 .577 .707 r
F P
0 g
s
.63393 .74204 m .63393 .24016 L .61082 .25056 L p .707 .577 .707 r
F P
0 g
s
.70485 .8364 m .70485 .85492 L .70195 .84638 L p .707 .577 .707 r
F P
0 g
s
.70195 .84638 m .70195 .82785 L .70485 .8364 L p .707 .577 .707 r
F P
0 g
s
.25312 .75667 m .25312 .70109 L .22195 .69919 L p .707 .577 .707 r
F P
0 g
s
.25312 .70109 m .25312 .75667 L .28495 .75589 L p .707 .577 .707 r
F P
0 g
s
.28495 .75589 m .28495 .70031 L .25312 .70109 L p .707 .577 .707 r
F P
0 g
s
.50095 .8457 m .50095 .80865 L .50804 .80028 L p .707 .577 .707 r
F P
0 g
s
.28495 .70031 m .28495 .75589 L .31434 .75251 L p .707 .577 .707 r
F P
0 g
s
.31434 .75251 m .31434 .69693 L .28495 .70031 L p .707 .577 .707 r
F P
0 g
s
.37794 .74829 m .37794 .2464 L .36016 .23527 L p .707 .577 .707 r
F P
0 g
s
.37794 .2464 m .37794 .74829 L .40766 .7574 L p .707 .577 .707 r
F P
0 g
s
.22195 .75477 m .22195 .69919 L .19449 .69479 L p .707 .577 .707 r
F P
0 g
s
.22195 .69919 m .22195 .75477 L .25312 .75667 L p .707 .577 .707 r
F P
0 g
s
.50095 .85129 m .50095 .83276 L .50804 .8244 L p .707 .577 .707 r
F P
0 g
s
.50804 .80028 m .50804 .83734 L .50095 .8457 L p .707 .577 .707 r
F P
0 g
s
.50804 .8244 m .50804 .84292 L .50095 .85129 L p .707 .577 .707 r
F P
0 g
s
.31434 .69693 m .31434 .75251 L .33839 .74686 L p .707 .577 .707 r
F P
0 g
s
.33839 .74686 m .33839 .69128 L .31434 .69693 L p .707 .577 .707 r
F P
0 g
s
.70195 .80374 m .70195 .8408 L .68936 .83291 L p .707 .577 .707 r
F P
0 g
s
.68936 .83291 m .68936 .79586 L .70195 .80374 L p .707 .577 .707 r
F P
0 g
s
.68936 .69594 m .68936 .75152 L .66831 .74507 L p .707 .577 .707 r
F P
0 g
s
.66831 .74507 m .66831 .68948 L .68936 .69594 L p .707 .577 .707 r
F P
0 g
s
.19449 .69479 m .19449 .75038 L .22195 .75477 L p .707 .577 .707 r
F P
0 g
s
.19449 .75038 m .19449 .69479 L .17343 .68834 L p .707 .577 .707 r
F P
0 g
s
.70195 .82785 m .70195 .84638 L .68936 .8385 L p .707 .577 .707 r
F P
0 g
s
.68936 .8385 m .68936 .81997 L .70195 .82785 L p .707 .577 .707 r
F P
0 g
s
.25312 .83806 m .25312 .80101 L .22195 .79911 L p .707 .577 .707 r
F P
0 g
s
.25312 .80101 m .25312 .83806 L .28495 .83728 L p .707 .577 .707 r
F P
0 g
s
.28495 .83728 m .28495 .80023 L .25312 .80101 L p .707 .577 .707 r
F P
0 g
s
.64085 .74067 m .64085 .68509 L .66831 .68948 L p .707 .577 .707 r
F P
0 g
s
.63393 .24016 m .63393 .74204 L .64393 .73023 L p .707 .577 .707 r
F P
0 g
s
.64393 .73023 m .64393 .22835 L .63393 .24016 L p .707 .577 .707 r
F P
0 g
s
.50804 .83734 m .50804 .80028 L .5244 .79292 L p .707 .577 .707 r
F P
0 g
s
.28495 .80023 m .28495 .83728 L .31434 .83391 L p .707 .577 .707 r
F P
0 g
s
.31434 .83391 m .31434 .79685 L .28495 .80023 L p .707 .577 .707 r
F P
0 g
s
.25312 .84365 m .25312 .82512 L .22195 .82322 L p .707 .577 .707 r
F P
0 g
s
.25312 .82512 m .25312 .84365 L .28495 .84287 L p .707 .577 .707 r
F P
0 g
s
.28495 .84287 m .28495 .82434 L .25312 .82512 L p .707 .577 .707 r
F P
0 g
s
.22195 .83616 m .22195 .79911 L .19449 .79471 L p .707 .577 .707 r
F P
0 g
s
.22195 .79911 m .22195 .83616 L .25312 .83806 L p .707 .577 .707 r
F P
0 g
s
.33839 .69128 m .33839 .74686 L .35476 .7395 L p .707 .577 .707 r
F P
0 g
s
.35476 .7395 m .35476 .68391 L .33839 .69128 L p .707 .577 .707 r
F P
0 g
s
.50804 .84292 m .50804 .8244 L .5244 .81703 L p .707 .577 .707 r
F P
0 g
s
.28495 .82434 m .28495 .84287 L .31434 .83949 L p .707 .577 .707 r
F P
0 g
s
.31434 .83949 m .31434 .82096 L .28495 .82434 L p .707 .577 .707 r
F P
0 g
s
.17343 .68834 m .17343 .74392 L .19449 .75038 L p .707 .577 .707 r
F P
0 g
s
.22195 .82322 m .22195 .84174 L .25312 .84365 L p .707 .577 .707 r
F P
0 g
s
.5244 .79292 m .5244 .82997 L .50804 .83734 L p .707 .577 .707 r
F P
0 g
s
.22195 .84174 m .22195 .82322 L .19449 .81883 L p .707 .577 .707 r
F P
0 g
s
.66831 .68948 m .66831 .74507 L .64085 .74067 L p .707 .577 .707 r
F P
0 g
s
.5244 .81703 m .5244 .83556 L .50804 .84292 L p .707 .577 .707 r
F P
0 g
s
.31434 .79685 m .31434 .83391 L .33839 .82826 L p .707 .577 .707 r
F P
0 g
s
.33839 .82826 m .33839 .7912 L .31434 .79685 L p .707 .577 .707 r
F P
0 g
s
.19449 .79471 m .19449 .83177 L .22195 .83616 L p .707 .577 .707 r
F P
0 g
s
.17343 .74392 m .17343 .68834 L .16084 .68046 L p .707 .577 .707 r
F P
0 g
s
.35476 .68391 m .35476 .7395 L .36184 .73113 L p .707 .577 .707 r
F P
0 g
s
.36184 .73113 m .36184 .67555 L .35476 .68391 L p .707 .577 .707 r
F P
0 g
s
.36184 .67555 m .36184 .73113 L .35894 .72259 L p .707 .577 .707 r
F P
0 g
s
.35894 .72259 m .35894 .66701 L .36184 .67555 L p .707 .577 .707 r
F P
0 g
s
.36016 .73716 m .36016 .23527 L .35607 .22321 L p .707 .577 .707 r
F P
0 g
s
.36016 .23527 m .36016 .73716 L .37794 .74829 L p .707 .577 .707 r
F P
0 g
s
.68936 .79586 m .68936 .83291 L .66831 .82646 L p .707 .577 .707 r
F P
0 g
s
.66831 .82646 m .66831 .7894 L .68936 .79586 L p .707 .577 .707 r
F P
0 g
s
.19449 .81883 m .19449 .83735 L .22195 .84174 L p .707 .577 .707 r
F P
0 g
s
.31434 .82096 m .31434 .83949 L .33839 .83384 L p .707 .577 .707 r
F P
0 g
s
.33839 .83384 m .33839 .81531 L .31434 .82096 L p .707 .577 .707 r
F P
0 g
s
.19449 .83177 m .19449 .79471 L .17343 .78826 L p .707 .577 .707 r
F P
0 g
s
.68936 .81997 m .68936 .8385 L .66831 .83204 L p .707 .577 .707 r
F P
0 g
s
.66831 .83204 m .66831 .81352 L .68936 .81997 L p .707 .577 .707 r
F P
0 g
s
.5244 .82997 m .5244 .79292 L .54846 .78727 L p .707 .577 .707 r
F P
0 g
s
.19449 .83735 m .19449 .81883 L .17343 .81237 L p .707 .577 .707 r
F P
0 g
s
.17343 .78826 m .17343 .82531 L .19449 .83177 L p .707 .577 .707 r
F P
0 g
s
.16084 .68046 m .16084 .73604 L .17343 .74392 L p .707 .577 .707 r
F P
0 g
s
.17343 .81237 m .17343 .8309 L .19449 .83735 L p .707 .577 .707 r
F P
0 g
s
.33839 .7912 m .33839 .82826 L .35476 .82089 L p .707 .577 .707 r
F P
0 g
s
.35476 .82089 m .35476 .78383 L .33839 .7912 L p .707 .577 .707 r
F P
0 g
s
.5244 .83556 m .5244 .81703 L .54846 .81138 L p .707 .577 .707 r
F P
0 g
s
.54846 .78727 m .54846 .82432 L .5244 .82997 L p .707 .577 .707 r
F P
0 g
s
.54846 .81138 m .54846 .82991 L .5244 .83556 L p .707 .577 .707 r
F P
0 g
s
.66831 .7894 m .66831 .82646 L .64085 .82207 L p .707 .577 .707 r
F P
0 g
s
.64085 .82207 m .64085 .78501 L .66831 .7894 L p .707 .577 .707 r
F P
0 g
s
.33839 .81531 m .33839 .83384 L .35476 .82647 L p .707 .577 .707 r
F P
0 g
s
.35476 .82647 m .35476 .80794 L .33839 .81531 L p .707 .577 .707 r
F P
0 g
s
.64393 .22835 m .64393 .73023 L .63984 .71818 L p .707 .577 .707 r
F P
0 g
s
.63984 .71818 m .63984 .21629 L .64393 .22835 L p .707 .577 .707 r
F P
0 g
s
.17343 .82531 m .17343 .78826 L .16084 .78038 L p .707 .577 .707 r
F P
0 g
s
.16084 .73604 m .16084 .68046 L .15794 .67191 L p .707 .577 .707 r
F P
0 g
s
.66831 .81352 m .66831 .83204 L .64085 .82765 L p .707 .577 .707 r
F P
0 g
s
.64085 .82765 m .64085 .80912 L .66831 .81352 L p .707 .577 .707 r
F P
0 g
s
.54846 .82432 m .54846 .78727 L .57784 .78389 L p .707 .577 .707 r
F P
0 g
s
.17343 .8309 m .17343 .81237 L .16084 .80449 L p .707 .577 .707 r
F P
0 g
s
.54846 .82991 m .54846 .81138 L .57784 .808 L p .707 .577 .707 r
F P
0 g
s
.16084 .78038 m .16084 .81743 L .17343 .82531 L p .707 .577 .707 r
F P
0 g
s
.64085 .78501 m .64085 .82207 L .60968 .82017 L p .707 .577 .707 r
F P
0 g
s
.60968 .82017 m .60968 .78311 L .64085 .78501 L p .707 .577 .707 r
F P
0 g
s
.16084 .80449 m .16084 .82301 L .17343 .8309 L p .707 .577 .707 r
F P
0 g
s
.57784 .78389 m .57784 .82094 L .54846 .82432 L p .707 .577 .707 r
F P
0 g
s
.57784 .808 m .57784 .82653 L .54846 .82991 L p .707 .577 .707 r
F P
0 g
s
.57784 .82094 m .57784 .78389 L .60968 .78311 L p .707 .577 .707 r
F P
0 g
s
.35894 .66701 m .35894 .72259 L .34635 .71471 L p .707 .577 .707 r
F P
0 g
s
.34635 .71471 m .34635 .65912 L .35894 .66701 L p .707 .577 .707 r
F P
0 g
s
.35607 .22321 m .35607 .7251 L .36016 .73716 L p .707 .577 .707 r
F P
0 g
s
.35607 .7251 m .35607 .22321 L .36607 .21141 L p .707 .577 .707 r
F P
0 g
s
.35476 .78383 m .35476 .82089 L .36184 .81252 L p .707 .577 .707 r
F P
0 g
s
.36184 .81252 m .36184 .77547 L .35476 .78383 L p .707 .577 .707 r
F P
0 g
s
.15794 .67191 m .15794 .7275 L .16084 .73604 L p .707 .577 .707 r
F P
0 g
s
.64085 .80912 m .64085 .82765 L .60968 .82575 L p .707 .577 .707 r
F P
0 g
s
.60968 .82575 m .60968 .80722 L .64085 .80912 L p .707 .577 .707 r
F P
0 g
s
.60968 .78311 m .60968 .82017 L .57784 .82094 L p .707 .577 .707 r
F P
0 g
s
.57784 .82653 m .57784 .808 L .60968 .80722 L p .707 .577 .707 r
F P
0 g
s
.35476 .80794 m .35476 .82647 L .36184 .81811 L p .707 .577 .707 r
F P
0 g
s
.36184 .81811 m .36184 .79958 L .35476 .80794 L p .707 .577 .707 r
F P
0 g
s
.60968 .80722 m .60968 .82575 L .57784 .82653 L p .707 .577 .707 r
F P
0 g
s
.16084 .81743 m .16084 .78038 L .15794 .77183 L p .707 .577 .707 r
F P
0 g
s
.15794 .7275 m .15794 .67191 L .16503 .66355 L p .707 .577 .707 r
F P
0 g
s
.16084 .82301 m .16084 .80449 L .15794 .79594 L p .707 .577 .707 r
F P
0 g
s
.15794 .77183 m .15794 .80889 L .16084 .81743 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .79594 m .15794 .81447 L .16084 .82301 L p .707 .577 .707 r
F P
0 g
s
.63984 .21629 m .63984 .71818 L .62206 .70704 L p .707 .577 .707 r
F P
0 g
s
.62206 .70704 m .62206 .20516 L .63984 .21629 L p .707 .577 .707 r
F P
0 g
s
.36184 .77547 m .36184 .81252 L .35894 .80398 L p .707 .577 .707 r
F P
0 g
s
.35894 .80398 m .35894 .76693 L .36184 .77547 L p .707 .577 .707 r
F P
0 g
s
.16503 .66355 m .16503 .71913 L .15794 .7275 L p .707 .577 .707 r
F P
0 g
s
.36184 .79958 m .36184 .81811 L .35894 .80957 L p .707 .577 .707 r
F P
0 g
s
.35894 .80957 m .35894 .79104 L .36184 .79958 L p .707 .577 .707 r
F P
0 g
s
.36607 .71329 m .36607 .21141 L .38918 .201 L p .707 .577 .707 r
F P
0 g
s
.36607 .21141 m .36607 .71329 L .35607 .7251 L p .707 .577 .707 r
F P
0 g
s
.15794 .80889 m .15794 .77183 L .16503 .76347 L p .707 .577 .707 r
F P
0 g
s
.16503 .71913 m .16503 .66355 L .1814 .65618 L p .707 .577 .707 r
F P
0 g
s
.15794 .81447 m .15794 .79594 L .16503 .78758 L p .707 .577 .707 r
F P
0 g
s
.16503 .76347 m .16503 .80052 L .15794 .80889 L p .707 .577 .707 r
F P
0 g
s
.16503 .78758 m .16503 .80611 L .15794 .81447 L p .707 .577 .707 r
F P
0 g
s
.35894 .76693 m .35894 .80398 L .34635 .7961 L p .707 .577 .707 r
F P
0 g
s
.34635 .7961 m .34635 .75904 L .35894 .76693 L p .707 .577 .707 r
F P
0 g
s
.1814 .65618 m .1814 .71176 L .16503 .71913 L p .707 .577 .707 r
F P
0 g
s
.34635 .65912 m .34635 .71471 L .3253 .70825 L p .707 .577 .707 r
F P
0 g
s
.3253 .70825 m .3253 .65267 L .34635 .65912 L p .707 .577 .707 r
F P
0 g
s
.62206 .20516 m .62206 .70704 L .59233 .69793 L p .707 .577 .707 r
F P
0 g
s
.59233 .69793 m .59233 .19604 L .62206 .20516 L p .707 .577 .707 r
F P
0 g
s
.35894 .79104 m .35894 .80957 L .34635 .80168 L p .707 .577 .707 r
F P
0 g
s
.34635 .80168 m .34635 .78315 L .35894 .79104 L p .707 .577 .707 r
F P
0 g
s
.1814 .71176 m .1814 .65618 L .20545 .65053 L p .707 .577 .707 r
F P
0 g
s
.16503 .80052 m .16503 .76347 L .1814 .7561 L p .707 .577 .707 r
F P
0 g
s
.38918 .201 m .38918 .70289 L .36607 .71329 L p .707 .577 .707 r
F P
0 g
s
.38918 .70289 m .38918 .201 L .42314 .19303 L p .707 .577 .707 r
F P
0 g
s
.16503 .80611 m .16503 .78758 L .1814 .78021 L p .707 .577 .707 r
F P
0 g
s
.1814 .7561 m .1814 .79316 L .16503 .80052 L p .707 .577 .707 r
F P
0 g
s
.3253 .65267 m .3253 .70825 L .29784 .70386 L p .707 .577 .707 r
F P
0 g
s
.29784 .70386 m .29784 .64828 L .3253 .65267 L p .707 .577 .707 r
F P
0 g
s
.1814 .78021 m .1814 .79874 L .16503 .80611 L p .707 .577 .707 r
F P
0 g
s
.20545 .65053 m .20545 .70611 L .1814 .71176 L p .707 .577 .707 r
F P
0 g
s
.34635 .75904 m .34635 .7961 L .3253 .78964 L p .707 .577 .707 r
F P
0 g
s
.3253 .78964 m .3253 .75259 L .34635 .75904 L p .707 .577 .707 r
F P
0 g
s
.20545 .70611 m .20545 .65053 L .23483 .64715 L p .707 .577 .707 r
F P
0 g
s
.34635 .78315 m .34635 .80168 L .3253 .79523 L p .707 .577 .707 r
F P
0 g
s
.3253 .79523 m .3253 .7767 L .34635 .78315 L p .707 .577 .707 r
F P
0 g
s
.59233 .19604 m .59233 .69793 L .55357 .69173 L p .707 .577 .707 r
F P
0 g
s
.55357 .69173 m .55357 .18984 L .59233 .19604 L p .707 .577 .707 r
F P
0 g
s
.1814 .79316 m .1814 .7561 L .20545 .75045 L p .707 .577 .707 r
F P
0 g
s
.29784 .64828 m .29784 .70386 L .26667 .70196 L p .707 .577 .707 r
F P
0 g
s
.26667 .70196 m .26667 .64638 L .29784 .64828 L p .707 .577 .707 r
F P
0 g
s
.23483 .70274 m .23483 .64715 L .26667 .64638 L p .707 .577 .707 r
F P
0 g
s
.23483 .64715 m .23483 .70274 L .20545 .70611 L p .707 .577 .707 r
F P
0 g
s
.1814 .79874 m .1814 .78021 L .20545 .77456 L p .707 .577 .707 r
F P
0 g
s
.26667 .64638 m .26667 .70196 L .23483 .70274 L p .707 .577 .707 r
F P
0 g
s
.42314 .69492 m .42314 .19303 L .46462 .18826 L p .707 .577 .707 r
F P
0 g
s
.42314 .19303 m .42314 .69492 L .38918 .70289 L p .707 .577 .707 r
F P
0 g
s
.73333 .70145 m .73333 .64586 L .70216 .64396 L p .707 .577 .707 r
F P
0 g
s
.73333 .64586 m .73333 .70145 L .76517 .70067 L p .707 .577 .707 r
F P
0 g
s
.76517 .70067 m .76517 .64509 L .73333 .64586 L p .707 .577 .707 r
F P
0 g
s
.20545 .75045 m .20545 .78751 L .1814 .79316 L p .707 .577 .707 r
F P
0 g
s
.20545 .77456 m .20545 .79309 L .1814 .79874 L p .707 .577 .707 r
F P
0 g
s
.76517 .64509 m .76517 .70067 L .79455 .69729 L p .707 .577 .707 r
F P
0 g
s
.79455 .69729 m .79455 .64171 L .76517 .64509 L p .707 .577 .707 r
F P
0 g
s
.3253 .75259 m .3253 .78964 L .29784 .78525 L p .707 .577 .707 r
F P
0 g
s
.29784 .78525 m .29784 .7482 L .3253 .75259 L p .707 .577 .707 r
F P
0 g
s
.70216 .69955 m .70216 .64396 L .6747 .63957 L p .707 .577 .707 r
F P
0 g
s
.70216 .64396 m .70216 .69955 L .73333 .70145 L p .707 .577 .707 r
F P
0 g
s
.3253 .7767 m .3253 .79523 L .29784 .79084 L p .707 .577 .707 r
F P
0 g
s
.29784 .79084 m .29784 .77231 L .3253 .7767 L p .707 .577 .707 r
F P
0 g
s
.55357 .18984 m .55357 .69173 L .50956 .68905 L p .707 .577 .707 r
F P
0 g
s
.50956 .68905 m .50956 .18716 L .55357 .18984 L p .707 .577 .707 r
F P
0 g
s
.20545 .78751 m .20545 .75045 L .23483 .74707 L p .707 .577 .707 r
F P
0 g
s
.79455 .64171 m .79455 .69729 L .8186 .69164 L p .707 .577 .707 r
F P
0 g
s
.8186 .69164 m .8186 .63606 L .79455 .64171 L p .707 .577 .707 r
F P
0 g
s
.46462 .69015 m .46462 .18826 L .50956 .18716 L p .707 .577 .707 r
F P
0 g
s
.46462 .18826 m .46462 .69015 L .42314 .69492 L p .707 .577 .707 r
F P
0 g
s
.20545 .79309 m .20545 .77456 L .23483 .77118 L p .707 .577 .707 r
F P
0 g
s
.29784 .7482 m .29784 .78525 L .26667 .78335 L p .707 .577 .707 r
F P
0 g
s
.26667 .78335 m .26667 .7463 L .29784 .7482 L p .707 .577 .707 r
F P
0 g
s
.50956 .18716 m .50956 .68905 L .46462 .69015 L p .707 .577 .707 r
F P
0 g
s
.23483 .74707 m .23483 .78413 L .20545 .78751 L p .707 .577 .707 r
F P
0 g
s
.6747 .63957 m .6747 .69515 L .70216 .69955 L p .707 .577 .707 r
F P
0 g
s
.6747 .69515 m .6747 .63957 L .65365 .63312 L p .707 .577 .707 r
F P
0 g
s
.23483 .77118 m .23483 .78971 L .20545 .79309 L p .707 .577 .707 r
F P
0 g
s
.23483 .78413 m .23483 .74707 L .26667 .7463 L p .707 .577 .707 r
F P
0 g
s
.29784 .77231 m .29784 .79084 L .26667 .78893 L p .707 .577 .707 r
F P
0 g
s
.26667 .78893 m .26667 .77041 L .29784 .77231 L p .707 .577 .707 r
F P
0 g
s
.26667 .7463 m .26667 .78335 L .23483 .78413 L p .707 .577 .707 r
F P
0 g
s
.73333 .78284 m .73333 .74578 L .70216 .74388 L p .707 .577 .707 r
F P
0 g
s
.73333 .74578 m .73333 .78284 L .76517 .78206 L p .707 .577 .707 r
F P
0 g
s
.76517 .78206 m .76517 .74501 L .73333 .74578 L p .707 .577 .707 r
F P
0 g
s
.23483 .78971 m .23483 .77118 L .26667 .77041 L p .707 .577 .707 r
F P
0 g
s
.76517 .74501 m .76517 .78206 L .79455 .77868 L p .707 .577 .707 r
F P
0 g
s
.79455 .77868 m .79455 .74163 L .76517 .74501 L p .707 .577 .707 r
F P
0 g
s
.26667 .77041 m .26667 .78893 L .23483 .78971 L p .707 .577 .707 r
F P
0 g
s
.73333 .78842 m .73333 .7699 L .70216 .76799 L p .707 .577 .707 r
F P
0 g
s
.73333 .7699 m .73333 .78842 L .76517 .78765 L p .707 .577 .707 r
F P
0 g
s
.76517 .78765 m .76517 .76912 L .73333 .7699 L p .707 .577 .707 r
F P
0 g
s
.70216 .78094 m .70216 .74388 L .6747 .73949 L p .707 .577 .707 r
F P
0 g
s
.70216 .74388 m .70216 .78094 L .73333 .78284 L p .707 .577 .707 r
F P
0 g
s
.8186 .63606 m .8186 .69164 L .83497 .68427 L p .707 .577 .707 r
F P
0 g
s
.83497 .68427 m .83497 .62869 L .8186 .63606 L p .707 .577 .707 r
F P
0 g
s
.76517 .76912 m .76517 .78765 L .79455 .78427 L p .707 .577 .707 r
F P
0 g
s
.79455 .78427 m .79455 .76574 L .76517 .76912 L p .707 .577 .707 r
F P
0 g
s
.65365 .63312 m .65365 .6887 L .6747 .69515 L p .707 .577 .707 r
F P
0 g
s
.70216 .76799 m .70216 .78652 L .73333 .78842 L p .707 .577 .707 r
F P
0 g
s
.70216 .78652 m .70216 .76799 L .6747 .7636 L p .707 .577 .707 r
F P
0 g
s
.79455 .74163 m .79455 .77868 L .8186 .77303 L p .707 .577 .707 r
F P
0 g
s
.8186 .77303 m .8186 .73598 L .79455 .74163 L p .707 .577 .707 r
F P
0 g
s
.6747 .73949 m .6747 .77655 L .70216 .78094 L p .707 .577 .707 r
F P
0 g
s
.65365 .6887 m .65365 .63312 L .64105 .62523 L p .707 .577 .707 r
F P
0 g
s
.6747 .7636 m .6747 .78213 L .70216 .78652 L p .707 .577 .707 r
F P
0 g
s
.79455 .76574 m .79455 .78427 L .8186 .77862 L p .707 .577 .707 r
F P
0 g
s
.8186 .77862 m .8186 .76009 L .79455 .76574 L p .707 .577 .707 r
F P
0 g
s
.6747 .77655 m .6747 .73949 L .65365 .73304 L p .707 .577 .707 r
F P
0 g
s
.6747 .78213 m .6747 .7636 L .65365 .75715 L p .707 .577 .707 r
F P
0 g
s
.65365 .73304 m .65365 .77009 L .6747 .77655 L p .707 .577 .707 r
F P
0 g
s
.64105 .62523 m .64105 .68082 L .65365 .6887 L p .707 .577 .707 r
F P
0 g
s
.83497 .62869 m .83497 .68427 L .84206 .67591 L p .707 .577 .707 r
F P
0 g
s
.84206 .67591 m .84205 .62033 L .83497 .62869 L p .707 .577 .707 r
F P
0 g
s
.65365 .75715 m .65365 .77568 L .6747 .78213 L p .707 .577 .707 r
F P
0 g
s
.8186 .73598 m .8186 .77303 L .83497 .76567 L p .707 .577 .707 r
F P
0 g
s
.83497 .76567 m .83497 .72861 L .8186 .73598 L p .707 .577 .707 r
F P
0 g
s
.8186 .76009 m .8186 .77862 L .83497 .77125 L p .707 .577 .707 r
F P
0 g
s
.83497 .77125 m .83497 .75272 L .8186 .76009 L p .707 .577 .707 r
F P
0 g
s
.65365 .77009 m .65365 .73304 L .64105 .72515 L p .707 .577 .707 r
F P
0 g
s
.64105 .68082 m .64105 .62523 L .63816 .61669 L p .707 .577 .707 r
F P
0 g
s
.65365 .77568 m .65365 .75715 L .64105 .74926 L p .707 .577 .707 r
F P
0 g
s
.64105 .72515 m .64105 .76221 L .65365 .77009 L p .707 .577 .707 r
F P
0 g
s
.64105 .74926 m .64105 .76779 L .65365 .77568 L p .707 .577 .707 r
F P
0 g
s
.83497 .72861 m .83497 .76567 L .84206 .7573 L p .707 .577 .707 r
F P
0 g
s
.84206 .7573 m .84206 .72025 L .83497 .72861 L p .707 .577 .707 r
F P
0 g
s
.63816 .61669 m .63816 .67227 L .64105 .68082 L p .707 .577 .707 r
F P
0 g
s
.84205 .62033 m .84206 .67591 L .83916 .66737 L p .707 .577 .707 r
F P
0 g
s
.83916 .66737 m .83916 .61178 L .84205 .62033 L p .707 .577 .707 r
F P
0 g
s
.83497 .75272 m .83497 .77125 L .84206 .76288 L p .707 .577 .707 r
F P
0 g
s
.84206 .76288 m .84206 .74436 L .83497 .75272 L p .707 .577 .707 r
F P
0 g
s
.64105 .76221 m .64105 .72515 L .63816 .71661 L p .707 .577 .707 r
F P
0 g
s
.63816 .67227 m .63816 .61669 L .64524 .60833 L p .707 .577 .707 r
F P
0 g
s
.64105 .76779 m .64105 .74926 L .63816 .74072 L p .707 .577 .707 r
F P
0 g
s
.63816 .71661 m .63816 .75367 L .64105 .76221 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .74072 m .63816 .75925 L .64105 .76779 L p .707 .577 .707 r
F P
0 g
s
.84206 .72025 m .84206 .7573 L .83916 .74876 L p .707 .577 .707 r
F P
0 g
s
.83916 .74876 m .83916 .7117 L .84206 .72025 L p .707 .577 .707 r
F P
0 g
s
.64524 .60833 m .64524 .66391 L .63816 .67227 L p .707 .577 .707 r
F P
0 g
s
.83916 .61178 m .83916 .66737 L .82657 .65948 L p .707 .577 .707 r
F P
0 g
s
.82657 .65948 m .82657 .6039 L .83916 .61178 L p .707 .577 .707 r
F P
0 g
s
.84206 .74436 m .84206 .76288 L .83916 .75434 L p .707 .577 .707 r
F P
0 g
s
.83916 .75434 m .83916 .73581 L .84206 .74436 L p .707 .577 .707 r
F P
0 g
s
.39032 .66463 m .39032 .60905 L .35915 .60715 L p .707 .577 .707 r
F P
0 g
s
.39032 .60905 m .39032 .66463 L .42216 .66385 L p .707 .577 .707 r
F P
0 g
s
.42216 .66385 m .42216 .60827 L .39032 .60905 L p .707 .577 .707 r
F P
0 g
s
.63816 .75367 m .63816 .71661 L .64524 .70825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66391 m .64524 .60833 L .66161 .60096 L p .707 .577 .707 r
F P
0 g
s
.42216 .60827 m .42216 .66385 L .45154 .66048 L p .707 .577 .707 r
F P
0 g
s
.45154 .66048 m .45154 .60489 L .42216 .60827 L p .707 .577 .707 r
F P
0 g
s
.35915 .66273 m .35915 .60715 L .33169 .60276 L p .707 .577 .707 r
F P
0 g
s
.35915 .60715 m .35915 .66273 L .39032 .66463 L p .707 .577 .707 r
F P
0 g
s
.63816 .75925 m .63816 .74072 L .64524 .73236 L p .707 .577 .707 r
F P
0 g
s
.64524 .70825 m .64524 .7453 L .63816 .75367 L p .707 .577 .707 r
F P
0 g
s
.64524 .73236 m .64524 .75089 L .63816 .75925 L p .707 .577 .707 r
F P
0 g
s
.45154 .60489 m .45154 .66048 L .47559 .65483 L p .707 .577 .707 r
F P
0 g
s
.47559 .65483 m .47559 .59924 L .45154 .60489 L p .707 .577 .707 r
F P
0 g
s
.83916 .7117 m .83916 .74876 L .82657 .74087 L p .707 .577 .707 r
F P
0 g
s
.82657 .74087 m .82657 .70382 L .83916 .7117 L p .707 .577 .707 r
F P
0 g
s
.66161 .60096 m .66161 .65654 L .64524 .66391 L p .707 .577 .707 r
F P
0 g
s
.82657 .6039 m .82657 .65948 L .80551 .65303 L p .707 .577 .707 r
F P
0 g
s
.80551 .65303 m .80551 .59745 L .82657 .6039 L p .707 .577 .707 r
F P
0 g
s
.33169 .60276 m .33169 .65834 L .35915 .66273 L p .707 .577 .707 r
F P
0 g
s
.33169 .65834 m .33169 .60276 L .31064 .5963 L p .707 .577 .707 r
F P
0 g
s
.83916 .73581 m .83916 .75434 L .82657 .74646 L p .707 .577 .707 r
F P
0 g
s
.82657 .74646 m .82657 .72793 L .83916 .73581 L p .707 .577 .707 r
F P
0 g
s
.39032 .74602 m .39032 .70897 L .35915 .70707 L p .707 .577 .707 r
F P
0 g
s
.39032 .70897 m .39032 .74602 L .42216 .74525 L p .707 .577 .707 r
F P
0 g
s
.42216 .74525 m .42216 .70819 L .39032 .70897 L p .707 .577 .707 r
F P
0 g
s
.66161 .65654 m .66161 .60096 L .68566 .59531 L p .707 .577 .707 r
F P
0 g
s
.64524 .7453 m .64524 .70825 L .66161 .70088 L p .707 .577 .707 r
F P
0 g
s
.42216 .70819 m .42216 .74525 L .45154 .74187 L p .707 .577 .707 r
F P
0 g
s
.45154 .74187 m .45154 .70481 L .42216 .70819 L p .707 .577 .707 r
F P
0 g
s
.39032 .75161 m .39032 .73308 L .35915 .73118 L p .707 .577 .707 r
F P
0 g
s
.39032 .73308 m .39032 .75161 L .42216 .75083 L p .707 .577 .707 r
F P
0 g
s
.42216 .75083 m .42216 .7323 L .39032 .73308 L p .707 .577 .707 r
F P
0 g
s
.35915 .74412 m .35915 .70707 L .33169 .70268 L p .707 .577 .707 r
F P
0 g
s
.35915 .70707 m .35915 .74412 L .39032 .74602 L p .707 .577 .707 r
F P
0 g
s
.47559 .59924 m .47559 .65483 L .49196 .64746 L p .707 .577 .707 r
F P
0 g
s
.49196 .64746 m .49196 .59188 L .47559 .59924 L p .707 .577 .707 r
F P
0 g
s
.64524 .75089 m .64524 .73236 L .66161 .72499 L p .707 .577 .707 r
F P
0 g
s
.42216 .7323 m .42216 .75083 L .45154 .74745 L p .707 .577 .707 r
F P
0 g
s
.45154 .74745 m .45154 .72892 L .42216 .7323 L p .707 .577 .707 r
F P
0 g
s
.31064 .5963 m .31064 .65188 L .33169 .65834 L p .707 .577 .707 r
F P
0 g
s
.35915 .73118 m .35915 .74971 L .39032 .75161 L p .707 .577 .707 r
F P
0 g
s
.66161 .70088 m .66161 .73793 L .64524 .7453 L p .707 .577 .707 r
F P
0 g
s
.35915 .74971 m .35915 .73118 L .33169 .72679 L p .707 .577 .707 r
F P
0 g
s
.80551 .59745 m .80551 .65303 L .77805 .64864 L p .707 .577 .707 r
F P
0 g
s
.77805 .64864 m .77805 .59305 L .80551 .59745 L p .707 .577 .707 r
F P
0 g
s
.66161 .72499 m .66161 .74352 L .64524 .75089 L p .707 .577 .707 r
F P
0 g
s
.45154 .70481 m .45154 .74187 L .47559 .73622 L p .707 .577 .707 r
F P
0 g
s
.47559 .73622 m .47559 .69916 L .45154 .70481 L p .707 .577 .707 r
F P
0 g
s
.68566 .59531 m .68566 .65089 L .66161 .65654 L p .707 .577 .707 r
F P
0 g
s
.33169 .70268 m .33169 .73973 L .35915 .74412 L p .707 .577 .707 r
F P
0 g
s
.31064 .65188 m .31064 .5963 L .29804 .58842 L p .707 .577 .707 r
F P
0 g
s
.82657 .70382 m .82657 .74087 L .80551 .73442 L p .707 .577 .707 r
F P
0 g
s
.80551 .73442 m .80551 .69737 L .82657 .70382 L p .707 .577 .707 r
F P
0 g
s
.33169 .72679 m .33169 .74531 L .35915 .74971 L p .707 .577 .707 r
F P
0 g
s
.68566 .65089 m .68566 .59531 L .71504 .59193 L p .707 .577 .707 r
F P
0 g
s
.45154 .72892 m .45154 .74745 L .47559 .7418 L p .707 .577 .707 r
F P
0 g
s
.47559 .7418 m .47559 .72327 L .45154 .72892 L p .707 .577 .707 r
F P
0 g
s
.33169 .73973 m .33169 .70268 L .31064 .69622 L p .707 .577 .707 r
F P
0 g
s
.82657 .72793 m .82657 .74646 L .80551 .74 L p .707 .577 .707 r
F P
0 g
s
.80551 .74 m .80551 .72148 L .82657 .72793 L p .707 .577 .707 r
F P
0 g
s
.66161 .73793 m .66161 .70088 L .68566 .69523 L p .707 .577 .707 r
F P
0 g
s
.33169 .74531 m .33169 .72679 L .31064 .72033 L p .707 .577 .707 r
F P
0 g
s
.77805 .59305 m .77805 .64864 L .74688 .64674 L p .707 .577 .707 r
F P
0 g
s
.74688 .64674 m .74688 .59115 L .77805 .59305 L p .707 .577 .707 r
F P
0 g
s
.31064 .69622 m .31064 .73328 L .33169 .73973 L p .707 .577 .707 r
F P
0 g
s
.29804 .58842 m .29804 .644 L .31064 .65188 L p .707 .577 .707 r
F P
0 g
s
.71504 .64751 m .71504 .59193 L .74688 .59115 L p .707 .577 .707 r
F P
0 g
s
.71504 .59193 m .71504 .64751 L .68566 .65089 L p .707 .577 .707 r
F P
0 g
s
.49196 .59188 m .49196 .64746 L .49904 .63909 L p .707 .577 .707 r
F P
0 g
s
.49904 .63909 m .49904 .58351 L .49196 .59188 L p .707 .577 .707 r
F P
0 g
s
.31064 .72033 m .31064 .73886 L .33169 .74531 L p .707 .577 .707 r
F P
0 g
s
.47559 .69916 m .47559 .73622 L .49196 .72885 L p .707 .577 .707 r
F P
0 g
s
.49196 .72885 m .49196 .69179 L .47559 .69916 L p .707 .577 .707 r
F P
0 g
s
.66161 .74352 m .66161 .72499 L .68566 .71934 L p .707 .577 .707 r
F P
0 g
s
.74688 .59115 m .74688 .64674 L .71504 .64751 L p .707 .577 .707 r
F P
0 g
s
.68566 .69523 m .68566 .73228 L .66161 .73793 L p .707 .577 .707 r
F P
0 g
s
.68566 .71934 m .68566 .73787 L .66161 .74352 L p .707 .577 .707 r
F P
0 g
s
.80551 .69737 m .80551 .73442 L .77805 .73003 L p .707 .577 .707 r
F P
0 g
s
.77805 .73003 m .77805 .69297 L .80551 .69737 L p .707 .577 .707 r
F P
0 g
s
.47559 .72327 m .47559 .7418 L .49196 .73443 L p .707 .577 .707 r
F P
0 g
s
.49196 .73443 m .49196 .71591 L .47559 .72327 L p .707 .577 .707 r
F P
0 g
s
.31064 .73328 m .31064 .69622 L .29804 .68834 L p .707 .577 .707 r
F P
0 g
s
.29804 .644 m .29804 .58842 L .29515 .57988 L p .707 .577 .707 r
F P
0 g
s
.80551 .72148 m .80551 .74 L .77805 .73561 L p .707 .577 .707 r
F P
0 g
s
.77805 .73561 m .77805 .71708 L .80551 .72148 L p .707 .577 .707 r
F P
0 g
s
.68566 .73228 m .68566 .69523 L .71504 .69185 L p .707 .577 .707 r
F P
0 g
s
.31064 .73886 m .31064 .72033 L .29804 .71245 L p .707 .577 .707 r
F P
0 g
s
.68566 .73787 m .68566 .71934 L .71504 .71596 L p .707 .577 .707 r
F P
0 g
s
.29804 .68834 m .29804 .72539 L .31064 .73328 L p .707 .577 .707 r
F P
0 g
s
.77805 .69297 m .77805 .73003 L .74688 .72813 L p .707 .577 .707 r
F P
0 g
s
.74688 .72813 m .74688 .69107 L .77805 .69297 L p .707 .577 .707 r
F P
0 g
s
.29804 .71245 m .29804 .73098 L .31064 .73886 L p .707 .577 .707 r
F P
0 g
s
.71504 .69185 m .71504 .7289 L .68566 .73228 L p .707 .577 .707 r
F P
0 g
s
.71504 .71596 m .71504 .73449 L .68566 .73787 L p .707 .577 .707 r
F P
0 g
s
.71504 .7289 m .71504 .69185 L .74688 .69107 L p .707 .577 .707 r
F P
0 g
s
.49196 .69179 m .49196 .72885 L .49904 .72049 L p .707 .577 .707 r
F P
0 g
s
.49904 .72049 m .49904 .68343 L .49196 .69179 L p .707 .577 .707 r
F P
0 g
s
.29515 .57988 m .29515 .63546 L .29804 .644 L p .707 .577 .707 r
F P
0 g
s
.49904 .58351 m .49904 .63909 L .49615 .63055 L p .707 .577 .707 r
F P
0 g
s
.49615 .63055 m .49615 .57497 L .49904 .58351 L p .707 .577 .707 r
F P
0 g
s
.77805 .71708 m .77805 .73561 L .74688 .73371 L p .707 .577 .707 r
F P
0 g
s
.74688 .73371 m .74688 .71518 L .77805 .71708 L p .707 .577 .707 r
F P
0 g
s
.74688 .69107 m .74688 .72813 L .71504 .7289 L p .707 .577 .707 r
F P
0 g
s
.71504 .73449 m .71504 .71596 L .74688 .71518 L p .707 .577 .707 r
F P
0 g
s
.49196 .71591 m .49196 .73443 L .49904 .72607 L p .707 .577 .707 r
F P
0 g
s
.49904 .72607 m .49904 .70754 L .49196 .71591 L p .707 .577 .707 r
F P
0 g
s
.74688 .71518 m .74688 .73371 L .71504 .73449 L p .707 .577 .707 r
F P
0 g
s
.29804 .72539 m .29804 .68834 L .29515 .6798 L p .707 .577 .707 r
F P
0 g
s
.29515 .63546 m .29515 .57988 L .30223 .57151 L p .707 .577 .707 r
F P
0 g
s
.29804 .73098 m .29804 .71245 L .29515 .70391 L p .707 .577 .707 r
F P
0 g
s
.29515 .6798 m .29515 .71685 L .29804 .72539 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .70391 m .29515 .72243 L .29804 .73098 L p .707 .577 .707 r
F P
0 g
s
.49904 .68343 m .49904 .72049 L .49615 .71194 L p .707 .577 .707 r
F P
0 g
s
.49615 .71194 m .49615 .67489 L .49904 .68343 L p .707 .577 .707 r
F P
0 g
s
.30223 .57151 m .30223 .62709 L .29515 .63546 L p .707 .577 .707 r
F P
0 g
s
.49615 .57497 m .49615 .63055 L .48356 .62267 L p .707 .577 .707 r
F P
0 g
s
.48356 .62267 m .48356 .56708 L .49615 .57497 L p .707 .577 .707 r
F P
0 g
s
.49904 .70754 m .49904 .72607 L .49615 .71753 L p .707 .577 .707 r
F P
0 g
s
.49615 .71753 m .49615 .699 L .49904 .70754 L p .707 .577 .707 r
F P
0 g
s
.29515 .71685 m .29515 .6798 L .30223 .67143 L p .707 .577 .707 r
F P
0 g
s
.30223 .62709 m .30223 .57151 L .3186 .56414 L p .707 .577 .707 r
F P
0 g
s
.29515 .72243 m .29515 .70391 L .30223 .69554 L p .707 .577 .707 r
F P
0 g
s
.30223 .67143 m .30223 .70849 L .29515 .71685 L p .707 .577 .707 r
F P
0 g
s
.30223 .69554 m .30223 .71407 L .29515 .72243 L p .707 .577 .707 r
F P
0 g
s
.49615 .67489 m .49615 .71194 L .48356 .70406 L p .707 .577 .707 r
F P
0 g
s
.48356 .70406 m .48356 .667 L .49615 .67489 L p .707 .577 .707 r
F P
0 g
s
.3186 .56414 m .3186 .61973 L .30223 .62709 L p .707 .577 .707 r
F P
0 g
s
.48356 .56708 m .48356 .62267 L .4625 .61621 L p .707 .577 .707 r
F P
0 g
s
.4625 .61621 m .4625 .56063 L .48356 .56708 L p .707 .577 .707 r
F P
0 g
s
.49615 .699 m .49615 .71753 L .48356 .70964 L p .707 .577 .707 r
F P
0 g
s
.48356 .70964 m .48356 .69112 L .49615 .699 L p .707 .577 .707 r
F P
0 g
s
.3186 .61973 m .3186 .56414 L .34265 .55849 L p .707 .577 .707 r
F P
0 g
s
.30223 .70849 m .30223 .67143 L .3186 .66406 L p .707 .577 .707 r
F P
0 g
s
.30223 .71407 m .30223 .69554 L .3186 .68817 L p .707 .577 .707 r
F P
0 g
s
.3186 .66406 m .3186 .70112 L .30223 .70849 L p .707 .577 .707 r
F P
0 g
s
.4625 .56063 m .4625 .61621 L .43504 .61182 L p .707 .577 .707 r
F P
0 g
s
.43504 .61182 m .43504 .55624 L .4625 .56063 L p .707 .577 .707 r
F P
0 g
s
.3186 .68817 m .3186 .7067 L .30223 .71407 L p .707 .577 .707 r
F P
0 g
s
.34265 .55849 m .34265 .61408 L .3186 .61973 L p .707 .577 .707 r
F P
0 g
s
.48356 .667 m .48356 .70406 L .4625 .6976 L p .707 .577 .707 r
F P
0 g
s
.4625 .6976 m .4625 .66055 L .48356 .667 L p .707 .577 .707 r
F P
0 g
s
.34265 .61408 m .34265 .55849 L .37203 .55511 L p .707 .577 .707 r
F P
0 g
s
.48356 .69112 m .48356 .70964 L .4625 .70319 L p .707 .577 .707 r
F P
0 g
s
.4625 .70319 m .4625 .68466 L .48356 .69112 L p .707 .577 .707 r
F P
0 g
s
.3186 .70112 m .3186 .66406 L .34265 .65841 L p .707 .577 .707 r
F P
0 g
s
.43504 .55624 m .43504 .61182 L .40387 .60992 L p .707 .577 .707 r
F P
0 g
s
.40387 .60992 m .40387 .55434 L .43504 .55624 L p .707 .577 .707 r
F P
0 g
s
.37203 .6107 m .37203 .55511 L .40387 .55434 L p .707 .577 .707 r
F P
0 g
s
.37203 .55511 m .37203 .6107 L .34265 .61408 L p .707 .577 .707 r
F P
0 g
s
.3186 .7067 m .3186 .68817 L .34265 .68252 L p .707 .577 .707 r
F P
0 g
s
.40387 .55434 m .40387 .60992 L .37203 .6107 L p .707 .577 .707 r
F P
0 g
s
.34265 .65841 m .34265 .69547 L .3186 .70112 L p .707 .577 .707 r
F P
0 g
s
.34265 .68252 m .34265 .70105 L .3186 .7067 L p .707 .577 .707 r
F P
0 g
s
.4625 .66055 m .4625 .6976 L .43504 .69321 L p .707 .577 .707 r
F P
0 g
s
.43504 .69321 m .43504 .65616 L .4625 .66055 L p .707 .577 .707 r
F P
0 g
s
.4625 .68466 m .4625 .70319 L .43504 .6988 L p .707 .577 .707 r
F P
0 g
s
.43504 .6988 m .43504 .68027 L .4625 .68466 L p .707 .577 .707 r
F P
0 g
s
.34265 .69547 m .34265 .65841 L .37203 .65503 L p .707 .577 .707 r
F P
0 g
s
.34265 .70105 m .34265 .68252 L .37203 .67915 L p .707 .577 .707 r
F P
0 g
s
.43504 .65616 m .43504 .69321 L .40387 .69131 L p .707 .577 .707 r
F P
0 g
s
.40387 .69131 m .40387 .65426 L .43504 .65616 L p .707 .577 .707 r
F P
0 g
s
.37203 .65503 m .37203 .69209 L .34265 .69547 L p .707 .577 .707 r
F P
0 g
s
.37203 .67915 m .37203 .69767 L .34265 .70105 L p .707 .577 .707 r
F P
0 g
s
.37203 .69209 m .37203 .65503 L .40387 .65426 L p .707 .577 .707 r
F P
0 g
s
.43504 .68027 m .43504 .6988 L .40387 .6969 L p .707 .577 .707 r
F P
0 g
s
.40387 .6969 m .40387 .67837 L .43504 .68027 L p .707 .577 .707 r
F P
0 g
s
.40387 .65426 m .40387 .69131 L .37203 .69209 L p .707 .577 .707 r
F P
0 g
s
.37203 .69767 m .37203 .67915 L .40387 .67837 L p .707 .577 .707 r
F P
0 g
s
.40387 .67837 m .40387 .6969 L .37203 .69767 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20001EYF00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001dOol300000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0071oo`@000AJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006io
o`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001J
EUYFFUH3001^Ool006aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001X
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00G7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00FGoo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`<000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80
039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP000080009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF200015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00003
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@0
05YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH0
0000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Agoo2@0017oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000oOol80004FUH00`00FUIJEP02FUH700000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH300000eYF001JEP06FUHI00000eYF001JEP02FUH50007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH50007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031o
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EPD000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF2P001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000eYF00<005YFFUH01eYF2@0025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0000=JEP00FUH01UYF4`001eYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH000000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YFFUH01EYF1P000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF2P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
00=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH00004FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00
FUIJEP02FUH00`00FUH00005FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@00=goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0003
FUH00`00FUH00004FUH20002FUH80002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH70004
FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00
FUIJEP06FUH400000eYF001JEP03FUH500000eYF0000000200001EYF001JEUYF00000eYF0P001EYF
00<005YFFUH01eYF1@000eYF0`0000=JEP00FUH00UYF00<005YFFUH025YF00<005YFFUH025YF00<0
05YFFUH01UYF0`0000=JEP00FUH00eYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo
00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001J
EP800003FUH0000000AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP<000=JEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0`00<7oo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUH005YF10001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000^Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJ
EQ@000EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`06001JEP00001JEP001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP8000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00
00800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
0003FUH005YF00AJEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP@000IJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000MJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP04
001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040003FUH2000]Ool002ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005
FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF1@001EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUHA0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP0000000eYF00<005YFFUH00eYF0P000eYF4P0015YF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YF00000`00;Goo000]Ool01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P000eYF2000
47oo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUH0009J
EP03001JEP0000D000=JEP8001Eoo`P000AJEP04001JEUYFFUH2000]Ool0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000@000AJEP<0
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH00000009JEP<00003FUH005YF009J
EPT000Uoo`T000=JEP03001JEUYF009JEP<00003FUH005YF009JEP8002eoo`00<goo0`0000=JEP00
FUH01UYF5`000eYF00@005YFFUIJEPL0009JEP03001JEUYF00AJEP8000UJEP03001JEUYF009JEPD0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP0000<0009JEP04001J
EP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH30003FUH2000]Ool003Ioo`T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00H000MooaT00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
00=JEP05001JEUYF001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool003Eoo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD0011oo`<00003FUH005YF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP<000IJEP03
001JEUYF00800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool0039oo`<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000moo`@000QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000L000EJEP03001JEUYF0080
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEP00001JEP03000]Ool0031oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80019o
o`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEPL000AJEPD000AJEP03001J
EUYF0080009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEPD000=JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000001Ioob80009JEP03001JEUYF00IJEPD000AJEP06001JEUYFFUH005YF0P0015YF0P001eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF0P00;Woo
000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00009goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00=JEP<000EJEQ4000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF5P0015YF00<005YFFUH00eYF00D005YFFUIJEP00
02Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH3
0003FUH00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP0002Uoo`03001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00
000aOol002aoo`03001JEP0000AJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP03001oogoo02Qoo`8000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo
00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001oogoo02Uoo`<000=JEP03001JEUYF
00EJEQ<000MJEP04001JEUYFFUH50003FUH20005FUH40008FUH00`00FUIJEP05FUH00`00FUH00003
000fOol002aoo`04001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`0]Ool;0004FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF000000020003Ool90004FUH00`00FUIJEP02FUH>000jOol002ao
o`03001JEP0000AJEP03001JEP0000AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP03001J
EUYF0080031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5
000=Ool90018Ool002aoo`03001JEP0000AJEP8000AJEPH001Moo`@0009JEP03001JEUYF00=JEP05
001JEUYFFUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002aoo`03001JEP0000AJEP03001JEP0000L001Uoo`T000=J
EP05001JEUYFFUH0000[Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001IOol002aoo`04001JEP000002FUH30002
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP03FUH40003FUH00`00Oomoo`0WOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH3001GOol002aoo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<007ooOol09Woo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH>0004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20002FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
00000eYF001oo`0VOol00`00FUH00004FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP<0009JEP03001JEP0002Moo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00E7oo000/Ool20003
FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00004FUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH50005FUH01000FUIJEUYF0P00:7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00E7oo000]Ool00`00FUIJEP020005FUH00`00FUIJEP03FUH30005FUHA0003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00:7oo00@005YF000000=JEP03001JEUYF00=JEP8000MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000005Aoo`00;Woo
0P0000=JEP00FUH00UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002Uoo`03001JEP0000AJEP8000=JEPl000Uoo`P000=J
EP03001JEUYF00=JEP03001JEUYF00<005Aoo`00<7oo0`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`03001JEP0000AJEP03
001JEP0000@001ioo`D000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00AJEP<000MJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000/Ool01000FUH000000UYF0`0000=J
EP00FUH00UYF2@004Woo1@000eYF0`0000=JEP00FUH00UYF0P00E7oo000fOol50004FUH00`00FUIJ
EP04FUH20009FUH00`00FUIJEP02FUH7000aOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF4P000eYF00<005YFFUH015YF0`000eYF0P00E7oo000kOolK000hOol00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP0200000eYF0000001DOol008ioo`800003FUH0000000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4
001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00001JEP03001DOol008ioo`80009JEP07
001JEUYFFUH005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000=JEP03001JEP0005Aoo`00SWoo0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF00<005YF0000E7oo002?
Ool01000FUIJEP001EYF00<005YFFUH00eYF0`0025YF00<005YFFUH00UYF2@000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20003FUH20007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000F7oo
002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3001JOol009Moo`D000=JEP8000EJEP@000QJEP03001JEUYF00EJEP03001JEP0000<0
05eoo`00W7oo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002UOolB001VOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77668 m .59613 .7211 L .56496 .7192 L p .707 .577 .707 r
F P
0 g
s
.59613 .7211 m .59613 .77668 L .62796 .77591 L p .707 .577 .707 r
F P
0 g
s
.62796 .77591 m .62796 .72032 L .59613 .7211 L p .707 .577 .707 r
F P
0 g
s
.62796 .72032 m .62796 .77591 L .65735 .77253 L p .707 .577 .707 r
F P
0 g
s
.65735 .77253 m .65734 .71694 L .62796 .72032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77478 m .56496 .7192 L .5375 .71481 L p .707 .577 .707 r
F P
0 g
s
.56496 .7192 m .56496 .77478 L .59613 .77668 L p .707 .577 .707 r
F P
0 g
s
.65734 .71694 m .65735 .77253 L .6814 .76688 L p .707 .577 .707 r
F P
0 g
s
.6814 .76688 m .6814 .71129 L .65734 .71694 L p .707 .577 .707 r
F P
0 g
s
.5375 .71481 m .5375 .77039 L .56496 .77478 L p .707 .577 .707 r
F P
0 g
s
.5375 .77039 m .5375 .71481 L .51644 .70835 L p .707 .577 .707 r
F P
0 g
s
.59613 .85004 m .59613 .81299 L .56496 .81109 L p .707 .577 .707 r
F P
0 g
s
.59613 .81299 m .59613 .85004 L .62796 .84926 L p .707 .577 .707 r
F P
0 g
s
.62796 .84926 m .62796 .81221 L .59613 .81299 L p .707 .577 .707 r
F P
0 g
s
.62796 .81221 m .62796 .84926 L .65735 .84589 L p .707 .577 .707 r
F P
0 g
s
.65735 .84589 m .65735 .80883 L .62796 .81221 L p .707 .577 .707 r
F P
0 g
s
.56496 .84814 m .56496 .81109 L .5375 .80669 L p .707 .577 .707 r
F P
0 g
s
.56496 .81109 m .56496 .84814 L .59613 .85004 L p .707 .577 .707 r
F P
0 g
s
.6814 .71129 m .6814 .76688 L .69777 .75951 L p .707 .577 .707 r
F P
0 g
s
.69777 .75951 m .69777 .70393 L .6814 .71129 L p .707 .577 .707 r
F P
0 g
s
.59613 .86947 m .59613 .85094 L .56496 .84904 L p .707 .577 .707 r
F P
0 g
s
.59613 .85094 m .59613 .86947 L .62796 .86869 L p .707 .577 .707 r
F P
0 g
s
.62796 .86869 m .62796 .85017 L .59613 .85094 L p .707 .577 .707 r
F P
0 g
s
.51644 .70835 m .51644 .76394 L .5375 .77039 L p .707 .577 .707 r
F P
0 g
s
.62796 .85017 m .62796 .86869 L .65735 .86532 L p .707 .577 .707 r
F P
0 g
s
.65735 .86532 m .65735 .84679 L .62796 .85017 L p .707 .577 .707 r
F P
0 g
s
.65735 .80883 m .65735 .84589 L .6814 .84024 L p .707 .577 .707 r
F P
0 g
s
.6814 .84024 m .6814 .80318 L .65735 .80883 L p .707 .577 .707 r
F P
0 g
s
.56496 .84904 m .56496 .86757 L .59613 .86947 L p .707 .577 .707 r
F P
0 g
s
.5375 .80669 m .5375 .84375 L .56496 .84814 L p .707 .577 .707 r
F P
0 g
s
.56496 .86757 m .56496 .84904 L .5375 .84465 L p .707 .577 .707 r
F P
0 g
s
.51644 .76394 m .51644 .70835 L .50385 .70047 L p .707 .577 .707 r
F P
0 g
s
.5375 .84465 m .5375 .86318 L .56496 .86757 L p .707 .577 .707 r
F P
0 g
s
.5375 .84375 m .5375 .80669 L .51644 .80024 L p .707 .577 .707 r
F P
0 g
s
.65735 .84679 m .65735 .86532 L .6814 .85967 L p .707 .577 .707 r
F P
0 g
s
.6814 .85967 m .6814 .84114 L .65735 .84679 L p .707 .577 .707 r
F P
0 g
s
.51644 .80024 m .51644 .83729 L .5375 .84375 L p .707 .577 .707 r
F P
0 g
s
.5375 .86318 m .5375 .84465 L .51644 .8382 L p .707 .577 .707 r
F P
0 g
s
.6814 .80318 m .6814 .84024 L .69777 .83287 L p .707 .577 .707 r
F P
0 g
s
.69777 .83287 m .69777 .79581 L .6814 .80318 L p .707 .577 .707 r
F P
0 g
s
.50385 .70047 m .50385 .75605 L .51644 .76394 L p .707 .577 .707 r
F P
0 g
s
.69777 .70393 m .69777 .75951 L .70485 .75114 L p .707 .577 .707 r
F P
0 g
s
.70485 .75114 m .70485 .69556 L .69777 .70393 L p .707 .577 .707 r
F P
0 g
s
.51644 .8382 m .51644 .85673 L .5375 .86318 L p .707 .577 .707 r
F P
0 g
s
.51644 .83729 m .51644 .80024 L .50385 .79236 L p .707 .577 .707 r
F P
0 g
s
.6814 .84114 m .6814 .85967 L .69777 .8523 L p .707 .577 .707 r
F P
0 g
s
.69777 .8523 m .69777 .83377 L .6814 .84114 L p .707 .577 .707 r
F P
0 g
s
.50385 .75605 m .50385 .70047 L .50095 .69193 L p .707 .577 .707 r
F P
0 g
s
.50385 .79236 m .50385 .82941 L .51644 .83729 L p .707 .577 .707 r
F P
0 g
s
.51644 .85673 m .51644 .8382 L .50385 .83031 L p .707 .577 .707 r
F P
0 g
s
.49044 .78751 m .49044 .28562 L .44643 .28294 L p .707 .577 .707 r
F P
0 g
s
.50095 .69193 m .50095 .74751 L .50385 .75605 L p .707 .577 .707 r
F P
0 g
s
.50385 .82941 m .50385 .79236 L .50095 .78381 L p .707 .577 .707 r
F P
0 g
s
.50095 .74751 m .50095 .69193 L .50804 .68356 L p .707 .577 .707 r
F P
0 g
s
.50095 .78381 m .50095 .82087 L .50385 .82941 L p .707 .577 .707 r
F P
0 g
s
.50804 .68356 m .50804 .73915 L .50095 .74751 L p .707 .577 .707 r
F P
0 g
s
.50095 .82087 m .50095 .78381 L .50804 .77545 L p .707 .577 .707 r
F P
0 g
s
.50804 .73915 m .50804 .68356 L .5244 .6762 L p .707 .577 .707 r
F P
0 g
s
.50804 .77545 m .50804 .8125 L .50095 .82087 L p .707 .577 .707 r
F P
0 g
s
.5244 .6762 m .5244 .73178 L .50804 .73915 L p .707 .577 .707 r
F P
0 g
s
.50804 .8125 m .50804 .77545 L .5244 .76808 L p .707 .577 .707 r
F P
0 g
s
.5244 .73178 m .5244 .6762 L .54846 .67055 L p .707 .577 .707 r
F P
0 g
s
.5244 .76808 m .5244 .80514 L .50804 .8125 L p .707 .577 .707 r
F P
0 g
s
.54846 .67055 m .54846 .72613 L .5244 .73178 L p .707 .577 .707 r
F P
0 g
s
.5244 .80514 m .5244 .76808 L .54846 .76243 L p .707 .577 .707 r
F P
0 g
s
.54846 .76243 m .54846 .79949 L .5244 .80514 L p .707 .577 .707 r
F P
0 g
s
.49044 .28562 m .49044 .78751 L .53538 .78641 L p .707 .577 .707 r
F P
0 g
s
.53538 .78641 m .53538 .28452 L .49044 .28562 L p .707 .577 .707 r
F P
0 g
s
.50385 .83031 m .50385 .84884 L .51644 .85673 L p .707 .577 .707 r
F P
0 g
s
.69777 .79581 m .69777 .83287 L .70485 .8245 L p .707 .577 .707 r
F P
0 g
s
.70485 .8245 m .70485 .78745 L .69777 .79581 L p .707 .577 .707 r
F P
0 g
s
.54846 .72613 m .54846 .67055 L .57784 .66717 L p .707 .577 .707 r
F P
0 g
s
.57784 .66717 m .57784 .72275 L .54846 .72613 L p .707 .577 .707 r
F P
0 g
s
.54846 .79949 m .54846 .76243 L .57784 .75905 L p .707 .577 .707 r
F P
0 g
s
.57784 .75905 m .57784 .79611 L .54846 .79949 L p .707 .577 .707 r
F P
0 g
s
.53538 .28452 m .53538 .78641 L .57686 .78164 L p .707 .577 .707 r
F P
0 g
s
.57686 .78164 m .57686 .27975 L .53538 .28452 L p .707 .577 .707 r
F P
0 g
s
.70485 .69556 m .70485 .75114 L .70195 .7426 L p .707 .577 .707 r
F P
0 g
s
.70195 .7426 m .70195 .68702 L .70485 .69556 L p .707 .577 .707 r
F P
0 g
s
.44643 .78482 m .44643 .28294 L .40766 .27673 L p .707 .577 .707 r
F P
0 g
s
.44643 .28294 m .44643 .78482 L .49044 .78751 L p .707 .577 .707 r
F P
0 g
s
.69777 .83377 m .69777 .8523 L .70485 .84393 L p .707 .577 .707 r
F P
0 g
s
.70485 .84393 m .70485 .82541 L .69777 .83377 L p .707 .577 .707 r
F P
0 g
s
.57784 .72275 m .57784 .66717 L .60968 .66639 L p .707 .577 .707 r
F P
0 g
s
.60968 .66639 m .60968 .72197 L .57784 .72275 L p .707 .577 .707 r
F P
0 g
s
.60968 .79533 m .60968 .75828 L .64085 .76018 L p .707 .577 .707 r
F P
0 g
s
.57784 .79611 m .57784 .75905 L .60968 .75828 L p .707 .577 .707 r
F P
0 g
s
.60968 .75828 m .60968 .79533 L .57784 .79611 L p .707 .577 .707 r
F P
0 g
s
.57686 .27975 m .57686 .78164 L .61082 .77366 L p .707 .577 .707 r
F P
0 g
s
.64085 .66829 m .64085 .72387 L .60968 .72197 L p .707 .577 .707 r
F P
0 g
s
.60968 .72197 m .60968 .66639 L .64085 .66829 L p .707 .577 .707 r
F P
0 g
s
.61082 .77366 m .61082 .27177 L .57686 .27975 L p .707 .577 .707 r
F P
0 g
s
.50385 .84884 m .50385 .83031 L .50095 .82177 L p .707 .577 .707 r
F P
0 g
s
.50095 .82177 m .50095 .8403 L .50385 .84884 L p .707 .577 .707 r
F P
0 g
s
.40766 .77862 m .40766 .27673 L .37794 .26762 L p .707 .577 .707 r
F P
0 g
s
.40766 .27673 m .40766 .77862 L .44643 .78482 L p .707 .577 .707 r
F P
0 g
s
.70485 .78745 m .70485 .8245 L .70195 .81596 L p .707 .577 .707 r
F P
0 g
s
.70195 .81596 m .70195 .77891 L .70485 .78745 L p .707 .577 .707 r
F P
0 g
s
.70195 .68702 m .70195 .7426 L .68936 .73472 L p .707 .577 .707 r
F P
0 g
s
.68936 .73472 m .68936 .67914 L .70195 .68702 L p .707 .577 .707 r
F P
0 g
s
.70485 .82541 m .70485 .84393 L .70195 .83539 L p .707 .577 .707 r
F P
0 g
s
.70195 .83539 m .70195 .81686 L .70485 .82541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25312 .73987 m .25312 .68429 L .22195 .68238 L p .707 .577 .707 r
F P
0 g
s
.25312 .68429 m .25312 .73987 L .28495 .73909 L p .707 .577 .707 r
F P
0 g
s
.28495 .73909 m .28495 .68351 L .25312 .68429 L p .707 .577 .707 r
F P
0 g
s
.61082 .27177 m .61082 .77366 L .63393 .76326 L p .707 .577 .707 r
F P
0 g
s
.63393 .76326 m .63393 .26137 L .61082 .27177 L p .707 .577 .707 r
F P
0 g
s
.28495 .68351 m .28495 .73909 L .31434 .73571 L p .707 .577 .707 r
F P
0 g
s
.31434 .73571 m .31434 .68013 L .28495 .68351 L p .707 .577 .707 r
F P
0 g
s
.22195 .73797 m .22195 .68238 L .19449 .67799 L p .707 .577 .707 r
F P
0 g
s
.22195 .68238 m .22195 .73797 L .25312 .73987 L p .707 .577 .707 r
F P
0 g
s
.50095 .8403 m .50095 .82177 L .50804 .81341 L p .707 .577 .707 r
F P
0 g
s
.50804 .81341 m .50804 .83193 L .50095 .8403 L p .707 .577 .707 r
F P
0 g
s
.31434 .68013 m .31434 .73571 L .33839 .73006 L p .707 .577 .707 r
F P
0 g
s
.33839 .73006 m .33839 .67448 L .31434 .68013 L p .707 .577 .707 r
F P
0 g
s
.70195 .77891 m .70195 .81596 L .68936 .80808 L p .707 .577 .707 r
F P
0 g
s
.68936 .80808 m .68936 .77102 L .70195 .77891 L p .707 .577 .707 r
F P
0 g
s
.37794 .76951 m .37794 .26762 L .36016 .25649 L p .707 .577 .707 r
F P
0 g
s
.37794 .26762 m .37794 .76951 L .40766 .77862 L p .707 .577 .707 r
F P
0 g
s
.68936 .67914 m .68936 .73472 L .66831 .72826 L p .707 .577 .707 r
F P
0 g
s
.66831 .72826 m .66831 .67268 L .68936 .67914 L p .707 .577 .707 r
F P
0 g
s
.19449 .67799 m .19449 .73357 L .22195 .73797 L p .707 .577 .707 r
F P
0 g
s
.19449 .73357 m .19449 .67799 L .17343 .67154 L p .707 .577 .707 r
F P
0 g
s
.25312 .81323 m .25312 .77617 L .22195 .77427 L p .707 .577 .707 r
F P
0 g
s
.25312 .77617 m .25312 .81323 L .28495 .81245 L p .707 .577 .707 r
F P
0 g
s
.28495 .81245 m .28495 .77539 L .25312 .77617 L p .707 .577 .707 r
F P
0 g
s
.70195 .81686 m .70195 .83539 L .68936 .82751 L p .707 .577 .707 r
F P
0 g
s
.68936 .82751 m .68936 .80898 L .70195 .81686 L p .707 .577 .707 r
F P
0 g
s
.28495 .77539 m .28495 .81245 L .31434 .80907 L p .707 .577 .707 r
F P
0 g
s
.31434 .80907 m .31434 .77202 L .28495 .77539 L p .707 .577 .707 r
F P
0 g
s
.22195 .81133 m .22195 .77427 L .19449 .76988 L p .707 .577 .707 r
F P
0 g
s
.22195 .77427 m .22195 .81133 L .25312 .81323 L p .707 .577 .707 r
F P
0 g
s
.33839 .67448 m .33839 .73006 L .35476 .72269 L p .707 .577 .707 r
F P
0 g
s
.35476 .72269 m .35476 .66711 L .33839 .67448 L p .707 .577 .707 r
F P
0 g
s
.25312 .83266 m .25312 .81413 L .22195 .81223 L p .707 .577 .707 r
F P
0 g
s
.25312 .81413 m .25312 .83266 L .28495 .83188 L p .707 .577 .707 r
F P
0 g
s
.28495 .83188 m .28495 .81335 L .25312 .81413 L p .707 .577 .707 r
F P
0 g
s
.17343 .67154 m .17343 .72712 L .19449 .73357 L p .707 .577 .707 r
F P
0 g
s
.50804 .83193 m .50804 .81341 L .5244 .80604 L p .707 .577 .707 r
F P
0 g
s
.28495 .81335 m .28495 .83188 L .31434 .8285 L p .707 .577 .707 r
F P
0 g
s
.31434 .8285 m .31434 .80997 L .28495 .81335 L p .707 .577 .707 r
F P
0 g
s
.66831 .67268 m .66831 .72826 L .64085 .72387 L p .707 .577 .707 r
F P
0 g
s
.64085 .72387 m .64085 .66829 L .66831 .67268 L p .707 .577 .707 r
F P
0 g
s
.63393 .26137 m .63393 .76326 L .64393 .75145 L p .707 .577 .707 r
F P
0 g
s
.64393 .75145 m .64393 .24956 L .63393 .26137 L p .707 .577 .707 r
F P
0 g
s
.31434 .77202 m .31434 .80907 L .33839 .80342 L p .707 .577 .707 r
F P
0 g
s
.33839 .80342 m .33839 .76637 L .31434 .77202 L p .707 .577 .707 r
F P
0 g
s
.22195 .81223 m .22195 .83076 L .25312 .83266 L p .707 .577 .707 r
F P
0 g
s
.19449 .76988 m .19449 .80693 L .22195 .81133 L p .707 .577 .707 r
F P
0 g
s
.22195 .83076 m .22195 .81223 L .19449 .80784 L p .707 .577 .707 r
F P
0 g
s
.5244 .80604 m .5244 .82457 L .50804 .83193 L p .707 .577 .707 r
F P
0 g
s
.68936 .77102 m .68936 .80808 L .66831 .80162 L p .707 .577 .707 r
F P
0 g
s
.66831 .80162 m .66831 .76457 L .68936 .77102 L p .707 .577 .707 r
F P
0 g
s
.17343 .72712 m .17343 .67154 L .16084 .66365 L p .707 .577 .707 r
F P
0 g
s
.19449 .80784 m .19449 .82636 L .22195 .83076 L p .707 .577 .707 r
F P
0 g
s
.19449 .80693 m .19449 .76988 L .17343 .76342 L p .707 .577 .707 r
F P
0 g
s
.31434 .80997 m .31434 .8285 L .33839 .82285 L p .707 .577 .707 r
F P
0 g
s
.33839 .82285 m .33839 .80432 L .31434 .80997 L p .707 .577 .707 r
F P
0 g
s
.68936 .80898 m .68936 .82751 L .66831 .82105 L p .707 .577 .707 r
F P
0 g
s
.66831 .82105 m .66831 .80253 L .68936 .80898 L p .707 .577 .707 r
F P
0 g
s
.35476 .66711 m .35476 .72269 L .36184 .71433 L p .707 .577 .707 r
F P
0 g
s
.36184 .71433 m .36184 .65875 L .35476 .66711 L p .707 .577 .707 r
F P
0 g
s
.36184 .78769 m .36184 .75063 L .35476 .759 L p .707 .577 .707 r
F P
0 g
s
.36184 .65875 m .36184 .71433 L .35894 .70579 L p .707 .577 .707 r
F P
0 g
s
.35894 .70579 m .35894 .65021 L .36184 .65875 L p .707 .577 .707 r
F P
0 g
s
.35476 .759 m .35476 .79605 L .36184 .78769 L p .707 .577 .707 r
F P
0 g
s
.35894 .77915 m .35894 .74209 L .36184 .75063 L p .707 .577 .707 r
F P
0 g
s
.36016 .75838 m .36016 .25649 L .35607 .24443 L p .707 .577 .707 r
F P
0 g
s
.36184 .75063 m .36184 .78769 L .35894 .77915 L p .707 .577 .707 r
F P
0 g
s
.36016 .25649 m .36016 .75838 L .37794 .76951 L p .707 .577 .707 r
F P
0 g
s
.17343 .76342 m .17343 .80048 L .19449 .80693 L p .707 .577 .707 r
F P
0 g
s
.19449 .82636 m .19449 .80784 L .17343 .80138 L p .707 .577 .707 r
F P
0 g
s
.33839 .76637 m .33839 .80342 L .35476 .79605 L p .707 .577 .707 r
F P
0 g
s
.35476 .79605 m .35476 .759 L .33839 .76637 L p .707 .577 .707 r
F P
0 g
s
.16084 .66365 m .16084 .71924 L .17343 .72712 L p .707 .577 .707 r
F P
0 g
s
.17343 .80138 m .17343 .81991 L .19449 .82636 L p .707 .577 .707 r
F P
0 g
s
.5244 .82457 m .5244 .80604 L .54846 .80039 L p .707 .577 .707 r
F P
0 g
s
.66831 .76457 m .66831 .80162 L .64085 .79723 L p .707 .577 .707 r
F P
0 g
s
.64085 .79723 m .64085 .76018 L .66831 .76457 L p .707 .577 .707 r
F P
0 g
s
.54846 .80039 m .54846 .81892 L .5244 .82457 L p .707 .577 .707 r
F P
0 g
s
.17343 .80048 m .17343 .76342 L .16084 .75554 L p .707 .577 .707 r
F P
0 g
s
.33839 .80432 m .33839 .82285 L .35476 .81548 L p .707 .577 .707 r
F P
0 g
s
.35476 .81548 m .35476 .79696 L .33839 .80432 L p .707 .577 .707 r
F P
0 g
s
.16084 .71924 m .16084 .66365 L .15794 .65511 L p .707 .577 .707 r
F P
0 g
s
.66831 .80253 m .66831 .82105 L .64085 .81666 L p .707 .577 .707 r
F P
0 g
s
.64085 .81666 m .64085 .79813 L .66831 .80253 L p .707 .577 .707 r
F P
0 g
s
.64393 .24956 m .64393 .75145 L .63984 .73939 L p .707 .577 .707 r
F P
0 g
s
.63984 .73939 m .63984 .2375 L .64393 .24956 L p .707 .577 .707 r
F P
0 g
s
.16084 .75554 m .16084 .7926 L .17343 .80048 L p .707 .577 .707 r
F P
0 g
s
.17343 .81991 m .17343 .80138 L .16084 .7935 L p .707 .577 .707 r
F P
0 g
s
.64085 .76018 m .64085 .79723 L .60968 .79533 L p .707 .577 .707 r
F P
0 g
s
.54846 .81892 m .54846 .80039 L .57784 .79701 L p .707 .577 .707 r
F P
0 g
s
.16084 .7935 m .16084 .81203 L .17343 .81991 L p .707 .577 .707 r
F P
0 g
s
.15794 .65511 m .15794 .71069 L .16084 .71924 L p .707 .577 .707 r
F P
0 g
s
.57784 .79701 m .57784 .81554 L .54846 .81892 L p .707 .577 .707 r
F P
0 g
s
.64085 .79813 m .64085 .81666 L .60968 .81476 L p .707 .577 .707 r
F P
0 g
s
.60968 .81476 m .60968 .79623 L .64085 .79813 L p .707 .577 .707 r
F P
0 g
s
.57784 .81554 m .57784 .79701 L .60968 .79623 L p .707 .577 .707 r
F P
0 g
s
.35476 .79696 m .35476 .81548 L .36184 .80712 L p .707 .577 .707 r
F P
0 g
s
.36184 .80712 m .36184 .78859 L .35476 .79696 L p .707 .577 .707 r
F P
0 g
s
.16084 .7926 m .16084 .75554 L .15794 .747 L p .707 .577 .707 r
F P
0 g
s
.35894 .65021 m .35894 .70579 L .34635 .6979 L p .707 .577 .707 r
F P
0 g
s
.34635 .6979 m .34635 .64232 L .35894 .65021 L p .707 .577 .707 r
F P
0 g
s
.35894 .74209 m .35894 .77915 L .34635 .77126 L p .707 .577 .707 r
F P
0 g
s
.34635 .77126 m .34635 .73421 L .35894 .74209 L p .707 .577 .707 r
F P
0 g
s
.35607 .24443 m .35607 .74632 L .36016 .75838 L p .707 .577 .707 r
F P
0 g
s
.35607 .74632 m .35607 .24443 L .36607 .23262 L p .707 .577 .707 r
F P
0 g
s
.60968 .79623 m .60968 .81476 L .57784 .81554 L p .707 .577 .707 r
F P
0 g
s
.15794 .71069 m .15794 .65511 L .16503 .64675 L p .707 .577 .707 r
F P
0 g
s
.15794 .747 m .15794 .78405 L .16084 .7926 L p .707 .577 .707 r
F P
0 g
s
.16084 .81203 m .16084 .7935 L .15794 .78496 L p .707 .577 .707 r
F P
0 g
s
.15794 .78496 m .15794 .80348 L .16084 .81203 L p .707 .577 .707 r
F P
0 g
s
.16503 .64675 m .16503 .70233 L .15794 .71069 L p .707 .577 .707 r
F P
0 g
s
.63984 .2375 m .63984 .73939 L .62206 .72826 L p .707 .577 .707 r
F P
0 g
s
.62206 .72826 m .62206 .22637 L .63984 .2375 L p .707 .577 .707 r
F P
0 g
s
.36184 .78859 m .36184 .80712 L .35894 .79858 L p .707 .577 .707 r
F P
0 g
s
.35894 .79858 m .35894 .78005 L .36184 .78859 L p .707 .577 .707 r
F P
0 g
s
.15794 .78405 m .15794 .747 L .16503 .73863 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70233 m .16503 .64675 L .1814 .63938 L p .707 .577 .707 r
F P
0 g
s
.16503 .73863 m .16503 .77569 L .15794 .78405 L p .707 .577 .707 r
F P
0 g
s
.15794 .80348 m .15794 .78496 L .16503 .77659 L p .707 .577 .707 r
F P
0 g
s
.36607 .73451 m .36607 .23262 L .38918 .22222 L p .707 .577 .707 r
F P
0 g
s
.36607 .23262 m .36607 .73451 L .35607 .74632 L p .707 .577 .707 r
F P
0 g
s
.16503 .77659 m .16503 .79512 L .15794 .80348 L p .707 .577 .707 r
F P
0 g
s
.1814 .63938 m .1814 .69496 L .16503 .70233 L p .707 .577 .707 r
F P
0 g
s
.34635 .64232 m .34635 .6979 L .3253 .69145 L p .707 .577 .707 r
F P
0 g
s
.3253 .69145 m .3253 .63587 L .34635 .64232 L p .707 .577 .707 r
F P
0 g
s
.35894 .78005 m .35894 .79858 L .34635 .79069 L p .707 .577 .707 r
F P
0 g
s
.34635 .79069 m .34635 .77217 L .35894 .78005 L p .707 .577 .707 r
F P
0 g
s
.16503 .77569 m .16503 .73863 L .1814 .73127 L p .707 .577 .707 r
F P
0 g
s
.1814 .69496 m .1814 .63938 L .20545 .63373 L p .707 .577 .707 r
F P
0 g
s
.62206 .22637 m .62206 .72826 L .59233 .71915 L p .707 .577 .707 r
F P
0 g
s
.59233 .71915 m .59233 .21726 L .62206 .22637 L p .707 .577 .707 r
F P
0 g
s
.1814 .73127 m .1814 .76832 L .16503 .77569 L p .707 .577 .707 r
F P
0 g
s
.16503 .79512 m .16503 .77659 L .1814 .76922 L p .707 .577 .707 r
F P
0 g
s
.3253 .63587 m .3253 .69145 L .29784 .68706 L p .707 .577 .707 r
F P
0 g
s
.29784 .68706 m .29784 .63147 L .3253 .63587 L p .707 .577 .707 r
F P
0 g
s
.1814 .76922 m .1814 .78775 L .16503 .79512 L p .707 .577 .707 r
F P
0 g
s
.34635 .73421 m .34635 .77126 L .3253 .76481 L p .707 .577 .707 r
F P
0 g
s
.3253 .76481 m .3253 .72775 L .34635 .73421 L p .707 .577 .707 r
F P
0 g
s
.20545 .63373 m .20545 .68931 L .1814 .69496 L p .707 .577 .707 r
F P
0 g
s
.38918 .22222 m .38918 .72411 L .36607 .73451 L p .707 .577 .707 r
F P
0 g
s
.38918 .72411 m .38918 .22222 L .42314 .21425 L p .707 .577 .707 r
F P
0 g
s
.20545 .68931 m .20545 .63373 L .23483 .63035 L p .707 .577 .707 r
F P
0 g
s
.1814 .76832 m .1814 .73127 L .20545 .72562 L p .707 .577 .707 r
F P
0 g
s
.34635 .77217 m .34635 .79069 L .3253 .78424 L p .707 .577 .707 r
F P
0 g
s
.3253 .78424 m .3253 .76571 L .34635 .77217 L p .707 .577 .707 r
F P
0 g
s
.29784 .63147 m .29784 .68706 L .26667 .68516 L p .707 .577 .707 r
F P
0 g
s
.26667 .68516 m .26667 .62957 L .29784 .63147 L p .707 .577 .707 r
F P
0 g
s
.23483 .68593 m .23483 .63035 L .26667 .62957 L p .707 .577 .707 r
F P
0 g
s
.23483 .63035 m .23483 .68593 L .20545 .68931 L p .707 .577 .707 r
F P
0 g
s
.26667 .62957 m .26667 .68516 L .23483 .68593 L p .707 .577 .707 r
F P
0 g
s
.20545 .72562 m .20545 .76267 L .1814 .76832 L p .707 .577 .707 r
F P
0 g
s
.1814 .78775 m .1814 .76922 L .20545 .76357 L p .707 .577 .707 r
F P
0 g
s
.59233 .21726 m .59233 .71915 L .55357 .71295 L p .707 .577 .707 r
F P
0 g
s
.55357 .71295 m .55357 .21106 L .59233 .21726 L p .707 .577 .707 r
F P
0 g
s
.73333 .68464 m .73333 .62906 L .70216 .62716 L p .707 .577 .707 r
F P
0 g
s
.73333 .62906 m .73333 .68464 L .76517 .68387 L p .707 .577 .707 r
F P
0 g
s
.76517 .68387 m .76517 .62828 L .73333 .62906 L p .707 .577 .707 r
F P
0 g
s
.3253 .72775 m .3253 .76481 L .29784 .76042 L p .707 .577 .707 r
F P
0 g
s
.29784 .76042 m .29784 .72336 L .3253 .72775 L p .707 .577 .707 r
F P
0 g
s
.76517 .62828 m .76517 .68387 L .79455 .68049 L p .707 .577 .707 r
F P
0 g
s
.79455 .68049 m .79455 .62491 L .76517 .62828 L p .707 .577 .707 r
F P
0 g
s
.20545 .76357 m .20545 .7821 L .1814 .78775 L p .707 .577 .707 r
F P
0 g
s
.70216 .68274 m .70216 .62716 L .6747 .62277 L p .707 .577 .707 r
F P
0 g
s
.70216 .62716 m .70216 .68274 L .73333 .68464 L p .707 .577 .707 r
F P
0 g
s
.20545 .76267 m .20545 .72562 L .23483 .72224 L p .707 .577 .707 r
F P
0 g
s
.42314 .71613 m .42314 .21425 L .46462 .20948 L p .707 .577 .707 r
F P
0 g
s
.42314 .21425 m .42314 .71613 L .38918 .72411 L p .707 .577 .707 r
F P
0 g
s
.3253 .76571 m .3253 .78424 L .29784 .77985 L p .707 .577 .707 r
F P
0 g
s
.29784 .77985 m .29784 .76132 L .3253 .76571 L p .707 .577 .707 r
F P
0 g
s
.79455 .62491 m .79455 .68049 L .8186 .67484 L p .707 .577 .707 r
F P
0 g
s
.8186 .67484 m .8186 .61926 L .79455 .62491 L p .707 .577 .707 r
F P
0 g
s
.29784 .72336 m .29784 .76042 L .26667 .75852 L p .707 .577 .707 r
F P
0 g
s
.26667 .75852 m .26667 .72146 L .29784 .72336 L p .707 .577 .707 r
F P
0 g
s
.23483 .72224 m .23483 .75929 L .20545 .76267 L p .707 .577 .707 r
F P
0 g
s
.20545 .7821 m .20545 .76357 L .23483 .7602 L p .707 .577 .707 r
F P
0 g
s
.23483 .75929 m .23483 .72224 L .26667 .72146 L p .707 .577 .707 r
F P
0 g
s
.55357 .21106 m .55357 .71295 L .50956 .71027 L p .707 .577 .707 r
F P
0 g
s
.50956 .71027 m .50956 .20838 L .55357 .21106 L p .707 .577 .707 r
F P
0 g
s
.6747 .62277 m .6747 .67835 L .70216 .68274 L p .707 .577 .707 r
F P
0 g
s
.6747 .67835 m .6747 .62277 L .65365 .61632 L p .707 .577 .707 r
F P
0 g
s
.26667 .72146 m .26667 .75852 L .23483 .75929 L p .707 .577 .707 r
F P
0 g
s
.23483 .7602 m .23483 .77872 L .20545 .7821 L p .707 .577 .707 r
F P
0 g
s
.73333 .758 m .73333 .72095 L .70216 .71905 L p .707 .577 .707 r
F P
0 g
s
.73333 .72095 m .73333 .758 L .76517 .75723 L p .707 .577 .707 r
F P
0 g
s
.76517 .75723 m .76517 .72017 L .73333 .72095 L p .707 .577 .707 r
F P
0 g
s
.46462 .71136 m .46462 .20948 L .50956 .20838 L p .707 .577 .707 r
F P
0 g
s
.46462 .20948 m .46462 .71136 L .42314 .71613 L p .707 .577 .707 r
F P
0 g
s
.29784 .76132 m .29784 .77985 L .26667 .77795 L p .707 .577 .707 r
F P
0 g
s
.26667 .77795 m .26667 .75942 L .29784 .76132 L p .707 .577 .707 r
F P
0 g
s
.76517 .72017 m .76517 .75723 L .79455 .75385 L p .707 .577 .707 r
F P
0 g
s
.79455 .75385 m .79455 .71679 L .76517 .72017 L p .707 .577 .707 r
F P
0 g
s
.50956 .20838 m .50956 .71027 L .46462 .71136 L p .707 .577 .707 r
F P
0 g
s
.23483 .77872 m .23483 .7602 L .26667 .75942 L p .707 .577 .707 r
F P
0 g
s
.70216 .7561 m .70216 .71905 L .6747 .71466 L p .707 .577 .707 r
F P
0 g
s
.70216 .71905 m .70216 .7561 L .73333 .758 L p .707 .577 .707 r
F P
0 g
s
.26667 .75942 m .26667 .77795 L .23483 .77872 L p .707 .577 .707 r
F P
0 g
s
.8186 .61926 m .8186 .67484 L .83497 .66747 L p .707 .577 .707 r
F P
0 g
s
.83497 .66747 m .83497 .61189 L .8186 .61926 L p .707 .577 .707 r
F P
0 g
s
.73333 .77743 m .73333 .75891 L .70216 .75701 L p .707 .577 .707 r
F P
0 g
s
.73333 .75891 m .73333 .77743 L .76517 .77666 L p .707 .577 .707 r
F P
0 g
s
.76517 .77666 m .76517 .75813 L .73333 .75891 L p .707 .577 .707 r
F P
0 g
s
.65365 .61632 m .65365 .6719 L .6747 .67835 L p .707 .577 .707 r
F P
0 g
s
.76517 .75813 m .76517 .77666 L .79455 .77328 L p .707 .577 .707 r
F P
0 g
s
.79455 .77328 m .79455 .75475 L .76517 .75813 L p .707 .577 .707 r
F P
0 g
s
.79455 .71679 m .79455 .75385 L .8186 .7482 L p .707 .577 .707 r
F P
0 g
s
.8186 .7482 m .8186 .71114 L .79455 .71679 L p .707 .577 .707 r
F P
0 g
s
.70216 .75701 m .70216 .77553 L .73333 .77743 L p .707 .577 .707 r
F P
0 g
s
.6747 .71466 m .6747 .75171 L .70216 .7561 L p .707 .577 .707 r
F P
0 g
s
.70216 .77553 m .70216 .75701 L .6747 .75261 L p .707 .577 .707 r
F P
0 g
s
.65365 .6719 m .65365 .61632 L .64105 .60843 L p .707 .577 .707 r
F P
0 g
s
.6747 .75261 m .6747 .77114 L .70216 .77553 L p .707 .577 .707 r
F P
0 g
s
.6747 .75171 m .6747 .71466 L .65365 .7082 L p .707 .577 .707 r
F P
0 g
s
.79455 .75475 m .79455 .77328 L .8186 .76763 L p .707 .577 .707 r
F P
0 g
s
.8186 .76763 m .8186 .7491 L .79455 .75475 L p .707 .577 .707 r
F P
0 g
s
.65365 .7082 m .65365 .74526 L .6747 .75171 L p .707 .577 .707 r
F P
0 g
s
.6747 .77114 m .6747 .75261 L .65365 .74616 L p .707 .577 .707 r
F P
0 g
s
.8186 .71114 m .8186 .7482 L .83497 .74083 L p .707 .577 .707 r
F P
0 g
s
.83497 .74083 m .83497 .70378 L .8186 .71114 L p .707 .577 .707 r
F P
0 g
s
.64105 .60843 m .64105 .66401 L .65365 .6719 L p .707 .577 .707 r
F P
0 g
s
.83497 .61189 m .83497 .66747 L .84205 .65911 L p .707 .577 .707 r
F P
0 g
s
.84205 .65911 m .84205 .60352 L .83497 .61189 L p .707 .577 .707 r
F P
0 g
s
.65365 .74616 m .65365 .76469 L .6747 .77114 L p .707 .577 .707 r
F P
0 g
s
.65365 .74526 m .65365 .7082 L .64105 .70032 L p .707 .577 .707 r
F P
0 g
s
.8186 .7491 m .8186 .76763 L .83497 .76026 L p .707 .577 .707 r
F P
0 g
s
.83497 .76026 m .83497 .74173 L .8186 .7491 L p .707 .577 .707 r
F P
0 g
s
.64105 .66401 m .64105 .60843 L .63816 .59989 L p .707 .577 .707 r
F P
0 g
s
.64105 .70032 m .64105 .73737 L .65365 .74526 L p .707 .577 .707 r
F P
0 g
s
.65365 .76469 m .65365 .74616 L .64105 .73828 L p .707 .577 .707 r
F P
0 g
s
.64105 .73828 m .64105 .7568 L .65365 .76469 L p .707 .577 .707 r
F P
0 g
s
.83497 .70378 m .83497 .74083 L .84206 .73247 L p .707 .577 .707 r
F P
0 g
s
.84206 .73247 m .84206 .69541 L .83497 .70378 L p .707 .577 .707 r
F P
0 g
s
.63816 .59989 m .63816 .65547 L .64105 .66401 L p .707 .577 .707 r
F P
0 g
s
.84205 .60352 m .84205 .65911 L .83916 .65056 L p .707 .577 .707 r
F P
0 g
s
.83916 .65056 m .83916 .59498 L .84205 .60352 L p .707 .577 .707 r
F P
0 g
s
.83497 .74173 m .83497 .76026 L .84206 .7519 L p .707 .577 .707 r
F P
0 g
s
.84206 .7519 m .84206 .73337 L .83497 .74173 L p .707 .577 .707 r
F P
0 g
s
.64105 .73737 m .64105 .70032 L .63816 .69178 L p .707 .577 .707 r
F P
0 g
s
.63816 .65547 m .63816 .59989 L .64524 .59152 L p .707 .577 .707 r
F P
0 g
s
.63816 .69178 m .63816 .72883 L .64105 .73737 L p .707 .577 .707 r
F P
0 g
s
.64105 .7568 m .64105 .73828 L .63816 .72973 L p .707 .577 .707 r
F P
0 g
s
.63816 .72973 m .63816 .74826 L .64105 .7568 L p .707 .577 .707 r
F P
0 g
s
.84206 .69541 m .84206 .73247 L .83916 .72392 L p .707 .577 .707 r
F P
0 g
s
.83916 .72392 m .83916 .68687 L .84206 .69541 L p .707 .577 .707 r
F P
0 g
s
.64524 .59152 m .64524 .64711 L .63816 .65547 L p .707 .577 .707 r
F P
0 g
s
.83916 .59498 m .83916 .65056 L .82657 .64268 L p .707 .577 .707 r
F P
0 g
s
.82657 .64268 m .82657 .5871 L .83916 .59498 L p .707 .577 .707 r
F P
0 g
s
.84206 .73337 m .84206 .7519 L .83916 .74335 L p .707 .577 .707 r
F P
0 g
s
.83916 .74335 m .83916 .72483 L .84206 .73337 L p .707 .577 .707 r
F P
0 g
s
.63816 .72883 m .63816 .69178 L .64524 .68341 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64783 m .39032 .59225 L .35915 .59035 L p .707 .577 .707 r
F P
0 g
s
.39032 .59225 m .39032 .64783 L .42216 .64705 L p .707 .577 .707 r
F P
0 g
s
.42216 .64705 m .42216 .59147 L .39032 .59225 L p .707 .577 .707 r
F P
0 g
s
.64524 .64711 m .64524 .59152 L .66161 .58416 L p .707 .577 .707 r
F P
0 g
s
.42216 .59147 m .42216 .64705 L .45154 .64367 L p .707 .577 .707 r
F P
0 g
s
.45154 .64367 m .45154 .58809 L .42216 .59147 L p .707 .577 .707 r
F P
0 g
s
.35915 .64593 m .35915 .59035 L .33169 .58595 L p .707 .577 .707 r
F P
0 g
s
.35915 .59035 m .35915 .64593 L .39032 .64783 L p .707 .577 .707 r
F P
0 g
s
.64524 .68341 m .64524 .72047 L .63816 .72883 L p .707 .577 .707 r
F P
0 g
s
.63816 .74826 m .63816 .72973 L .64524 .72137 L p .707 .577 .707 r
F P
0 g
s
.64524 .72137 m .64524 .7399 L .63816 .74826 L p .707 .577 .707 r
F P
0 g
s
.45154 .58809 m .45154 .64367 L .47559 .63802 L p .707 .577 .707 r
F P
0 g
s
.47559 .63802 m .47559 .58244 L .45154 .58809 L p .707 .577 .707 r
F P
0 g
s
.83916 .68687 m .83916 .72392 L .82657 .71604 L p .707 .577 .707 r
F P
0 g
s
.82657 .71604 m .82657 .67898 L .83916 .68687 L p .707 .577 .707 r
F P
0 g
s
.66161 .58416 m .66161 .63974 L .64524 .64711 L p .707 .577 .707 r
F P
0 g
s
.82657 .5871 m .82657 .64268 L .80551 .63623 L p .707 .577 .707 r
F P
0 g
s
.80551 .63623 m .80551 .58064 L .82657 .5871 L p .707 .577 .707 r
F P
0 g
s
.33169 .58595 m .33169 .64154 L .35915 .64593 L p .707 .577 .707 r
F P
0 g
s
.33169 .64154 m .33169 .58595 L .31064 .5795 L p .707 .577 .707 r
F P
0 g
s
.39032 .72119 m .39032 .68413 L .35915 .68223 L p .707 .577 .707 r
F P
0 g
s
.39032 .68413 m .39032 .72119 L .42216 .72041 L p .707 .577 .707 r
F P
0 g
s
.42216 .72041 m .42216 .68336 L .39032 .68413 L p .707 .577 .707 r
F P
0 g
s
.83916 .72483 m .83916 .74335 L .82657 .73547 L p .707 .577 .707 r
F P
0 g
s
.82657 .73547 m .82657 .71694 L .83916 .72483 L p .707 .577 .707 r
F P
0 g
s
.64524 .72047 m .64524 .68341 L .66161 .67604 L p .707 .577 .707 r
F P
0 g
s
.42216 .68336 m .42216 .72041 L .45154 .71703 L p .707 .577 .707 r
F P
0 g
s
.45154 .71703 m .45154 .67998 L .42216 .68336 L p .707 .577 .707 r
F P
0 g
s
.66161 .63974 m .66161 .58416 L .68566 .57851 L p .707 .577 .707 r
F P
0 g
s
.35915 .71929 m .35915 .68223 L .33169 .67784 L p .707 .577 .707 r
F P
0 g
s
.35915 .68223 m .35915 .71929 L .39032 .72119 L p .707 .577 .707 r
F P
0 g
s
.47559 .58244 m .47559 .63802 L .49196 .63066 L p .707 .577 .707 r
F P
0 g
s
.49196 .63066 m .49196 .57507 L .47559 .58244 L p .707 .577 .707 r
F P
0 g
s
.39032 .74062 m .39032 .72209 L .35915 .72019 L p .707 .577 .707 r
F P
0 g
s
.39032 .72209 m .39032 .74062 L .42216 .73984 L p .707 .577 .707 r
F P
0 g
s
.42216 .73984 m .42216 .72131 L .39032 .72209 L p .707 .577 .707 r
F P
0 g
s
.31064 .5795 m .31064 .63508 L .33169 .64154 L p .707 .577 .707 r
F P
0 g
s
.66161 .67604 m .66161 .7131 L .64524 .72047 L p .707 .577 .707 r
F P
0 g
s
.64524 .7399 m .64524 .72137 L .66161 .714 L p .707 .577 .707 r
F P
0 g
s
.42216 .72131 m .42216 .73984 L .45154 .73646 L p .707 .577 .707 r
F P
0 g
s
.45154 .73646 m .45154 .71794 L .42216 .72131 L p .707 .577 .707 r
F P
0 g
s
.45154 .67998 m .45154 .71703 L .47559 .71138 L p .707 .577 .707 r
F P
0 g
s
.47559 .71138 m .47559 .67433 L .45154 .67998 L p .707 .577 .707 r
F P
0 g
s
.35915 .72019 m .35915 .73872 L .39032 .74062 L p .707 .577 .707 r
F P
0 g
s
.80551 .58064 m .80551 .63623 L .77805 .63183 L p .707 .577 .707 r
F P
0 g
s
.77805 .63183 m .77805 .57625 L .80551 .58064 L p .707 .577 .707 r
F P
0 g
s
.33169 .67784 m .33169 .7149 L .35915 .71929 L p .707 .577 .707 r
F P
0 g
s
.35915 .73872 m .35915 .72019 L .33169 .7158 L p .707 .577 .707 r
F P
0 g
s
.66161 .714 m .66161 .73253 L .64524 .7399 L p .707 .577 .707 r
F P
0 g
s
.82657 .67898 m .82657 .71604 L .80551 .70959 L p .707 .577 .707 r
F P
0 g
s
.80551 .70959 m .80551 .67253 L .82657 .67898 L p .707 .577 .707 r
F P
0 g
s
.68566 .57851 m .68566 .63409 L .66161 .63974 L p .707 .577 .707 r
F P
0 g
s
.31064 .63508 m .31064 .5795 L .29804 .57162 L p .707 .577 .707 r
F P
0 g
s
.33169 .7158 m .33169 .73433 L .35915 .73872 L p .707 .577 .707 r
F P
0 g
s
.33169 .7149 m .33169 .67784 L .31064 .67139 L p .707 .577 .707 r
F P
0 g
s
.68566 .63409 m .68566 .57851 L .71504 .57513 L p .707 .577 .707 r
F P
0 g
s
.45154 .71794 m .45154 .73646 L .47559 .73081 L p .707 .577 .707 r
F P
0 g
s
.47559 .73081 m .47559 .71229 L .45154 .71794 L p .707 .577 .707 r
F P
0 g
s
.66161 .7131 m .66161 .67604 L .68566 .67039 L p .707 .577 .707 r
F P
0 g
s
.82657 .71694 m .82657 .73547 L .80551 .72902 L p .707 .577 .707 r
F P
0 g
s
.80551 .72902 m .80551 .71049 L .82657 .71694 L p .707 .577 .707 r
F P
0 g
s
.77805 .57625 m .77805 .63183 L .74688 .62993 L p .707 .577 .707 r
F P
0 g
s
.74688 .62993 m .74688 .57435 L .77805 .57625 L p .707 .577 .707 r
F P
0 g
s
.31064 .67139 m .31064 .70844 L .33169 .7149 L p .707 .577 .707 r
F P
0 g
s
.33169 .73433 m .33169 .7158 L .31064 .70934 L p .707 .577 .707 r
F P
0 g
s
.47559 .67433 m .47559 .71138 L .49196 .70401 L p .707 .577 .707 r
F P
0 g
s
.49196 .70401 m .49196 .66696 L .47559 .67433 L p .707 .577 .707 r
F P
0 g
s
.29804 .57162 m .29804 .6272 L .31064 .63508 L p .707 .577 .707 r
F P
0 g
s
.71504 .63071 m .71504 .57513 L .74688 .57435 L p .707 .577 .707 r
F P
0 g
s
.71504 .57513 m .71504 .63071 L .68566 .63409 L p .707 .577 .707 r
F P
0 g
s
.49196 .57507 m .49196 .63066 L .49904 .62229 L p .707 .577 .707 r
F P
0 g
s
.49904 .62229 m .49904 .56671 L .49196 .57507 L p .707 .577 .707 r
F P
0 g
s
.31064 .70934 m .31064 .72787 L .33169 .73433 L p .707 .577 .707 r
F P
0 g
s
.74688 .57435 m .74688 .62993 L .71504 .63071 L p .707 .577 .707 r
F P
0 g
s
.68566 .67039 m .68566 .70745 L .66161 .7131 L p .707 .577 .707 r
F P
0 g
s
.66161 .73253 m .66161 .714 L .68566 .70835 L p .707 .577 .707 r
F P
0 g
s
.80551 .67253 m .80551 .70959 L .77805 .70519 L p .707 .577 .707 r
F P
0 g
s
.77805 .70519 m .77805 .66814 L .80551 .67253 L p .707 .577 .707 r
F P
0 g
s
.68566 .70835 m .68566 .72688 L .66161 .73253 L p .707 .577 .707 r
F P
0 g
s
.31064 .70844 m .31064 .67139 L .29804 .6635 L p .707 .577 .707 r
F P
0 g
s
.47559 .71229 m .47559 .73081 L .49196 .72345 L p .707 .577 .707 r
F P
0 g
s
.49196 .72345 m .49196 .70492 L .47559 .71229 L p .707 .577 .707 r
F P
0 g
s
.29804 .6272 m .29804 .57162 L .29515 .56307 L p .707 .577 .707 r
F P
0 g
s
.68566 .70745 m .68566 .67039 L .71504 .66701 L p .707 .577 .707 r
F P
0 g
s
.80551 .71049 m .80551 .72902 L .77805 .72462 L p .707 .577 .707 r
F P
0 g
s
.77805 .72462 m .77805 .7061 L .80551 .71049 L p .707 .577 .707 r
F P
0 g
s
.29804 .6635 m .29804 .70056 L .31064 .70844 L p .707 .577 .707 r
F P
0 g
s
.31064 .72787 m .31064 .70934 L .29804 .70146 L p .707 .577 .707 r
F P
0 g
s
.77805 .66814 m .77805 .70519 L .74688 .70329 L p .707 .577 .707 r
F P
0 g
s
.74688 .70329 m .74688 .66624 L .77805 .66814 L p .707 .577 .707 r
F P
0 g
s
.71504 .66701 m .71504 .70407 L .68566 .70745 L p .707 .577 .707 r
F P
0 g
s
.68566 .72688 m .68566 .70835 L .71504 .70497 L p .707 .577 .707 r
F P
0 g
s
.71504 .70407 m .71504 .66701 L .74688 .66624 L p .707 .577 .707 r
F P
0 g
s
.29804 .70146 m .29804 .71999 L .31064 .72787 L p .707 .577 .707 r
F P
0 g
s
.49196 .66696 m .49196 .70401 L .49904 .69565 L p .707 .577 .707 r
F P
0 g
s
.49904 .69565 m .49904 .6586 L .49196 .66696 L p .707 .577 .707 r
F P
0 g
s
.29515 .56307 m .29515 .61866 L .29804 .6272 L p .707 .577 .707 r
F P
0 g
s
.74688 .66624 m .74688 .70329 L .71504 .70407 L p .707 .577 .707 r
F P
0 g
s
.71504 .70497 m .71504 .7235 L .68566 .72688 L p .707 .577 .707 r
F P
0 g
s
.49904 .56671 m .49904 .62229 L .49615 .61375 L p .707 .577 .707 r
F P
0 g
s
.49615 .61375 m .49615 .55817 L .49904 .56671 L p .707 .577 .707 r
F P
0 g
s
.77805 .7061 m .77805 .72462 L .74688 .72272 L p .707 .577 .707 r
F P
0 g
s
.74688 .72272 m .74688 .7042 L .77805 .7061 L p .707 .577 .707 r
F P
0 g
s
.71504 .7235 m .71504 .70497 L .74688 .7042 L p .707 .577 .707 r
F P
0 g
s
.49196 .70492 m .49196 .72345 L .49904 .71508 L p .707 .577 .707 r
F P
0 g
s
.49904 .71508 m .49904 .69655 L .49196 .70492 L p .707 .577 .707 r
F P
0 g
s
.29804 .70056 m .29804 .6635 L .29515 .65496 L p .707 .577 .707 r
F P
0 g
s
.74688 .7042 m .74688 .72272 L .71504 .7235 L p .707 .577 .707 r
F P
0 g
s
.29515 .61866 m .29515 .56307 L .30223 .55471 L p .707 .577 .707 r
F P
0 g
s
.29515 .65496 m .29515 .69202 L .29804 .70056 L p .707 .577 .707 r
F P
0 g
s
.29804 .71999 m .29804 .70146 L .29515 .69292 L p .707 .577 .707 r
F P
0 g
s
.29515 .69292 m .29515 .71145 L .29804 .71999 L p .707 .577 .707 r
F P
0 g
s
.49904 .6586 m .49904 .69565 L .49615 .68711 L p .707 .577 .707 r
F P
0 g
s
.49615 .68711 m .49615 .65005 L .49904 .6586 L p .707 .577 .707 r
F P
0 g
s
.30223 .55471 m .30223 .61029 L .29515 .61866 L p .707 .577 .707 r
F P
0 g
s
.49615 .55817 m .49615 .61375 L .48356 .60586 L p .707 .577 .707 r
F P
0 g
s
.48356 .60586 m .48356 .55028 L .49615 .55817 L p .707 .577 .707 r
F P
0 g
s
.49904 .69655 m .49904 .71508 L .49615 .70654 L p .707 .577 .707 r
F P
0 g
s
.49615 .70654 m .49615 .68801 L .49904 .69655 L p .707 .577 .707 r
F P
0 g
s
.29515 .69202 m .29515 .65496 L .30223 .6466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61029 m .30223 .55471 L .3186 .54734 L p .707 .577 .707 r
F P
0 g
s
.30223 .6466 m .30223 .68365 L .29515 .69202 L p .707 .577 .707 r
F P
0 g
s
.29515 .71145 m .29515 .69292 L .30223 .68455 L p .707 .577 .707 r
F P
0 g
s
.30223 .68455 m .30223 .70308 L .29515 .71145 L p .707 .577 .707 r
F P
0 g
s
.49615 .65005 m .49615 .68711 L .48356 .67922 L p .707 .577 .707 r
F P
0 g
s
.48356 .67922 m .48356 .64217 L .49615 .65005 L p .707 .577 .707 r
F P
0 g
s
.3186 .54734 m .3186 .60292 L .30223 .61029 L p .707 .577 .707 r
F P
0 g
s
.48356 .55028 m .48356 .60586 L .4625 .59941 L p .707 .577 .707 r
F P
0 g
s
.4625 .59941 m .4625 .54383 L .48356 .55028 L p .707 .577 .707 r
F P
0 g
s
.49615 .68801 m .49615 .70654 L .48356 .69865 L p .707 .577 .707 r
F P
0 g
s
.48356 .69865 m .48356 .68013 L .49615 .68801 L p .707 .577 .707 r
F P
0 g
s
.30223 .68365 m .30223 .6466 L .3186 .63923 L p .707 .577 .707 r
F P
0 g
s
.3186 .60292 m .3186 .54734 L .34265 .54169 L p .707 .577 .707 r
F P
0 g
s
.3186 .63923 m .3186 .67628 L .30223 .68365 L p .707 .577 .707 r
F P
0 g
s
.30223 .70308 m .30223 .68455 L .3186 .67719 L p .707 .577 .707 r
F P
0 g
s
.4625 .54383 m .4625 .59941 L .43504 .59502 L p .707 .577 .707 r
F P
0 g
s
.43504 .59502 m .43504 .53944 L .4625 .54383 L p .707 .577 .707 r
F P
0 g
s
.3186 .67719 m .3186 .69571 L .30223 .70308 L p .707 .577 .707 r
F P
0 g
s
.48356 .64217 m .48356 .67922 L .4625 .67277 L p .707 .577 .707 r
F P
0 g
s
.4625 .67277 m .4625 .63571 L .48356 .64217 L p .707 .577 .707 r
F P
0 g
s
.34265 .54169 m .34265 .59727 L .3186 .60292 L p .707 .577 .707 r
F P
0 g
s
.34265 .59727 m .34265 .54169 L .37203 .53831 L p .707 .577 .707 r
F P
0 g
s
.3186 .67628 m .3186 .63923 L .34265 .63358 L p .707 .577 .707 r
F P
0 g
s
.48356 .68013 m .48356 .69865 L .4625 .6922 L p .707 .577 .707 r
F P
0 g
s
.4625 .6922 m .4625 .67367 L .48356 .68013 L p .707 .577 .707 r
F P
0 g
s
.43504 .53944 m .43504 .59502 L .40387 .59312 L p .707 .577 .707 r
F P
0 g
s
.40387 .59312 m .40387 .53754 L .43504 .53944 L p .707 .577 .707 r
F P
0 g
s
.37203 .59389 m .37203 .53831 L .40387 .53754 L p .707 .577 .707 r
F P
0 g
s
.37203 .53831 m .37203 .59389 L .34265 .59727 L p .707 .577 .707 r
F P
0 g
s
.40387 .53754 m .40387 .59312 L .37203 .59389 L p .707 .577 .707 r
F P
0 g
s
.34265 .63358 m .34265 .67063 L .3186 .67628 L p .707 .577 .707 r
F P
0 g
s
.3186 .69571 m .3186 .67719 L .34265 .67154 L p .707 .577 .707 r
F P
0 g
s
.4625 .63571 m .4625 .67277 L .43504 .66838 L p .707 .577 .707 r
F P
0 g
s
.43504 .66838 m .43504 .63132 L .4625 .63571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67154 m .34265 .69006 L .3186 .69571 L p .707 .577 .707 r
F P
0 g
s
.34265 .67063 m .34265 .63358 L .37203 .6302 L p .707 .577 .707 r
F P
0 g
s
.4625 .67367 m .4625 .6922 L .43504 .68781 L p .707 .577 .707 r
F P
0 g
s
.43504 .68781 m .43504 .66928 L .4625 .67367 L p .707 .577 .707 r
F P
0 g
s
.43504 .63132 m .43504 .66838 L .40387 .66648 L p .707 .577 .707 r
F P
0 g
s
.40387 .66648 m .40387 .62942 L .43504 .63132 L p .707 .577 .707 r
F P
0 g
s
.37203 .6302 m .37203 .66725 L .34265 .67063 L p .707 .577 .707 r
F P
0 g
s
.34265 .69006 m .34265 .67154 L .37203 .66816 L p .707 .577 .707 r
F P
0 g
s
.37203 .66725 m .37203 .6302 L .40387 .62942 L p .707 .577 .707 r
F P
0 g
s
.40387 .62942 m .40387 .66648 L .37203 .66725 L p .707 .577 .707 r
F P
0 g
s
.37203 .66816 m .37203 .68668 L .34265 .69006 L p .707 .577 .707 r
F P
0 g
s
.43504 .66928 m .43504 .68781 L .40387 .68591 L p .707 .577 .707 r
F P
0 g
s
.40387 .68591 m .40387 .66738 L .43504 .66928 L p .707 .577 .707 r
F P
0 g
s
.37203 .68668 m .37203 .66816 L .40387 .66738 L p .707 .577 .707 r
F P
0 g
s
.40387 .66738 m .40387 .68591 L .37203 .68668 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Ioo`00O7oo1P000UYF
00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001fOol60008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000UJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJ
EP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF2@0000=JEP00FUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol90004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005ioo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP@003Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH0
1UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
05=oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001C
Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001J
EP04FUH00`00FUIJEP05FUHI00000eYF001JEP05FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF20000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPH0009JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF10001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo
000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYF0002FUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEQ<000MJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUH000050004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH30002FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@0000AJEP00000003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000
FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPH000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
;7oo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03001JEP00008000AJEP04
001JEUYFFUH90007FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000=JEPH000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF
001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00H005YF
000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000UYF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000=J
EP00000020001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000H000AJEP04001J
EUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEP000003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@000UYF00<005YF00002EYF2@0025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00;Goo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH00UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF2@0000=JEP00
FUH00UYF00<005YF00002UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@000=JEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF2000
15YF00<005YFFUH00eYF3P001EYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF600000=JEP00FUH015YF00<005YFFUH01EYF00@005YF
FUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH20004FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00003000]Ool0031oo`<000AJEPP000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP<00003FUH005YF00=JEP<000AJEP03001JEUYF009JEPL000QJEPD000AJEPP000=J
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00004FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH40005FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000aOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF00000eYF0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P00;Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0000H00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3
000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001@00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH500000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP<0009JEP03001JEP0000D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF
009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF
009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPh000AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00=JEP04001JEUYFFUH30002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009oo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH005YFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00003FUH50003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001J
EP02FUH00`00Oomoo`02Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP02FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/
Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<007ooOol017oo0P0015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`001eYF00<0
05YFFUH015YF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/
Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool01goo0`0000=JEP00FUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000/Ool30004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP02000;Ool40008
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000030004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool90018Ool002aoo`<000AJ
EP04001JEUYFFUH90007FUH50005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;7oo00<005YF
000015YF1@001eYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF1P000eYF00D005YFFUIJEP00
01Eoob8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2001DOol002aoo`03001JEP00009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001oogoo02Eoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`03001JEP0000<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0UOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH0000200000eYF001oo`0VOol00`00FUH00004FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00001P0015YF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00<005YF00009goo00<005YF000015YF1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF0P00E7oo000/
Ool20003FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH0000300000eYF001JEP02FUH00`00FUH0000WOol00`00FUH00002FUH40004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040003FUH2
001DOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00<005YF
FUH00UYF1@001EYF00@005YFFUIJEP8002Qoo`03001JEP0000<00003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<0009JEP80
05Aoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000:Goo00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEPH005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002Yoo`<000AJ
EP03001JEUYF009JEPL000QJEPD000AJEPP000=JEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00
<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`00;7oo00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1@0015YF
00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8005Aoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000cOol0
1000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF0`000eYF0P00E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP0200000eYF0000001DOol008ioo`D000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000D005Aoo`00SWoo0P000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
1@0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00001@001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00001P000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH0
0UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001J
EUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
05Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065o
o`00YGoo4P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]16\[InvisibleSpace]"     "\
\[InvisibleSpace]6.382330995002581`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 16, "     ", 6.3823309950025813, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59849 .75361 m .59772 .69859 L .56654 .69686 L p .707 .577 .707 r
F P
0 g
s
.59772 .69859 m .59849 .75361 L .63032 .75233 L p .707 .577 .707 r
F P
0 g
s
.63032 .75233 m .62955 .69731 L .59772 .69859 L p .707 .577 .707 r
F P
0 g
s
.62955 .69731 m .63032 .75233 L .6597 .74817 L p .707 .577 .707 r
F P
0 g
s
.6597 .74817 m .65892 .69314 L .62955 .69731 L p .707 .577 .707 r
F P
0 g
s
.56732 .75189 m .56654 .69686 L .53909 .6923 L p .707 .577 .707 r
F P
0 g
s
.56654 .69686 m .56732 .75189 L .59849 .75361 L p .707 .577 .707 r
F P
0 g
s
.65892 .69314 m .6597 .74817 L .68375 .74153 L p .707 .577 .707 r
F P
0 g
s
.68375 .74153 m .68297 .68651 L .65892 .69314 L p .707 .577 .707 r
F P
0 g
s
.5976 .80134 m .59923 .76343 L .56807 .76097 L p .707 .577 .707 r
F P
0 g
s
.59923 .76343 m .5976 .80134 L .6294 .80218 L p .707 .577 .707 r
F P
0 g
s
.6294 .80218 m .63103 .76427 L .59923 .76343 L p .707 .577 .707 r
F P
0 g
s
.53986 .74732 m .53909 .6923 L .51803 .68534 L p .707 .577 .707 r
F P
0 g
s
.53909 .6923 m .53986 .74732 L .56732 .75189 L p .707 .577 .707 r
F P
0 g
s
.63103 .76427 m .6294 .80218 L .65873 .80133 L p .707 .577 .707 r
F P
0 g
s
.65873 .80133 m .66036 .76342 L .63103 .76427 L p .707 .577 .707 r
F P
0 g
s
.56807 .76097 m .56644 .79888 L .5976 .80134 L p .707 .577 .707 r
F P
0 g
s
.56644 .79888 m .56807 .76097 L .5406 .75714 L p .707 .577 .707 r
F P
0 g
s
.59564 .82854 m .5975 .80941 L .56639 .80621 L p .707 .577 .707 r
F P
0 g
s
.5975 .80941 m .59564 .82854 L .62729 .83153 L p .707 .577 .707 r
F P
0 g
s
.62729 .83153 m .62915 .81239 L .5975 .80941 L p .707 .577 .707 r
F P
0 g
s
.56639 .80621 m .56453 .82534 L .59564 .82854 L p .707 .577 .707 r
F P
0 g
s
.62915 .81239 m .62729 .83153 L .65638 .83401 L p .707 .577 .707 r
F P
0 g
s
.65638 .83401 m .65824 .81488 L .62915 .81239 L p .707 .577 .707 r
F P
0 g
s
.68297 .68651 m .68375 .74153 L .70011 .73307 L p .707 .577 .707 r
F P
0 g
s
.70011 .73307 m .69933 .67804 L .68297 .68651 L p .707 .577 .707 r
F P
0 g
s
.5406 .75714 m .53897 .79504 L .56644 .79888 L p .707 .577 .707 r
F P
0 g
s
.56453 .82534 m .56639 .80621 L .53887 .80311 L p .707 .577 .707 r
F P
0 g
s
.53887 .80311 m .53701 .82225 L .56453 .82534 L p .707 .577 .707 r
F P
0 g
s
.66036 .76342 m .65873 .80133 L .68271 .79886 L p .707 .577 .707 r
F P
0 g
s
.68271 .79886 m .68434 .76095 L .66036 .76342 L p .707 .577 .707 r
F P
0 g
s
.51803 .68534 m .5188 .74036 L .53986 .74732 L p .707 .577 .707 r
F P
0 g
s
.53897 .79504 m .5406 .75714 L .51951 .7523 L p .707 .577 .707 r
F P
0 g
s
.5188 .74036 m .51803 .68534 L .50543 .67667 L p .707 .577 .707 r
F P
0 g
s
.65824 .81488 m .65638 .83401 L .68007 .83575 L p .707 .577 .707 r
F P
0 g
s
.68007 .83575 m .68193 .81662 L .65824 .81488 L p .707 .577 .707 r
F P
0 g
s
.51951 .7523 m .51788 .79021 L .53897 .79504 L p .707 .577 .707 r
F P
0 g
s
.53701 .82225 m .53887 .80311 L .51763 .80042 L p .707 .577 .707 r
F P
0 g
s
.51763 .80042 m .51577 .81956 L .53701 .82225 L p .707 .577 .707 r
F P
0 g
s
.68434 .76095 m .68271 .79886 L .699 .79502 L p .707 .577 .707 r
F P
0 g
s
.699 .79502 m .70063 .75712 L .68434 .76095 L p .707 .577 .707 r
F P
0 g
s
.69933 .67804 m .70011 .73307 L .70718 .72361 L p .707 .577 .707 r
F P
0 g
s
.70718 .72361 m .70641 .66858 L .69933 .67804 L p .707 .577 .707 r
F P
0 g
s
.50543 .67667 m .5062 .7317 L .5188 .74036 L p .707 .577 .707 r
F P
0 g
s
.68193 .81662 m .68007 .83575 L .69603 .83657 L p .707 .577 .707 r
F P
0 g
s
.69603 .83657 m .69789 .81744 L .68193 .81662 L p .707 .577 .707 r
F P
0 g
s
.51788 .79021 m .51951 .7523 L .50686 .74695 L p .707 .577 .707 r
F P
0 g
s
.5062 .7317 m .50543 .67667 L .50253 .66714 L p .707 .577 .707 r
F P
0 g
s
.50686 .74695 m .50523 .78485 L .51788 .79021 L p .707 .577 .707 r
F P
0 g
s
.51577 .81956 m .51763 .80042 L .50474 .7984 L p .707 .577 .707 r
F P
0 g
s
.50474 .7984 m .50288 .81754 L .51577 .81956 L p .707 .577 .707 r
F P
0 g
s
.70063 .75712 m .699 .79502 L .70601 .79019 L p .707 .577 .707 r
F P
0 g
s
.70601 .79019 m .70764 .75228 L .70063 .75712 L p .707 .577 .707 r
F P
0 g
s
.70641 .66858 m .70718 .72361 L .70428 .71408 L p .707 .577 .707 r
F P
0 g
s
.70428 .71408 m .7035 .65905 L .70641 .66858 L p .707 .577 .707 r
F P
0 g
s
.50253 .66714 m .5033 .72216 L .5062 .7317 L p .707 .577 .707 r
F P
0 g
s
.69789 .81744 m .69603 .83657 L .70271 .8364 L p .707 .577 .707 r
F P
0 g
s
.70271 .8364 m .70457 .81726 L .69789 .81744 L p .707 .577 .707 r
F P
0 g
s
.50523 .78485 m .50686 .74695 L .5039 .74159 L p .707 .577 .707 r
F P
0 g
s
.48631 .81979 m .49313 .31364 L .44912 .31072 L p .707 .577 .707 r
F P
0 g
s
.5039 .74159 m .50226 .77949 L .50523 .78485 L p .707 .577 .707 r
F P
0 g
s
.5033 .72216 m .50253 .66714 L .5096 .65768 L p .707 .577 .707 r
F P
0 g
s
.50288 .81754 m .50474 .7984 L .50148 .79725 L p .707 .577 .707 r
F P
0 g
s
.50148 .79725 m .49962 .81638 L .50288 .81754 L p .707 .577 .707 r
F P
0 g
s
.5096 .65768 m .51038 .7127 L .5033 .72216 L p .707 .577 .707 r
F P
0 g
s
.50226 .77949 m .5039 .74159 L .5109 .73675 L p .707 .577 .707 r
F P
0 g
s
.51038 .7127 m .5096 .65768 L .52596 .64922 L p .707 .577 .707 r
F P
0 g
s
.5109 .73675 m .50927 .77466 L .50226 .77949 L p .707 .577 .707 r
F P
0 g
s
.49962 .81638 m .50148 .79725 L .50816 .79707 L p .707 .577 .707 r
F P
0 g
s
.50816 .79707 m .5063 .81621 L .49962 .81638 L p .707 .577 .707 r
F P
0 g
s
.52596 .64922 m .52674 .70424 L .51038 .7127 L p .707 .577 .707 r
F P
0 g
s
.50927 .77466 m .5109 .73675 L .5272 .73291 L p .707 .577 .707 r
F P
0 g
s
.5272 .73291 m .52556 .77082 L .50927 .77466 L p .707 .577 .707 r
F P
0 g
s
.5063 .81621 m .50816 .79707 L .52413 .7979 L p .707 .577 .707 r
F P
0 g
s
.52413 .7979 m .52227 .81703 L .5063 .81621 L p .707 .577 .707 r
F P
0 g
s
.52556 .77082 m .5272 .73291 L .55118 .73045 L p .707 .577 .707 r
F P
0 g
s
.55118 .73045 m .54955 .76835 L .52556 .77082 L p .707 .577 .707 r
F P
0 g
s
.52227 .81703 m .52413 .7979 L .54781 .79964 L p .707 .577 .707 r
F P
0 g
s
.54781 .79964 m .54595 .81877 L .52227 .81703 L p .707 .577 .707 r
F P
0 g
s
.49313 .31364 m .48631 .81979 L .53125 .81939 L p .707 .577 .707 r
F P
0 g
s
.52674 .70424 m .52596 .64922 L .55001 .64258 L p .707 .577 .707 r
F P
0 g
s
.55001 .64258 m .55078 .6976 L .52674 .70424 L p .707 .577 .707 r
F P
0 g
s
.53125 .81939 m .53807 .31324 L .49313 .31364 L p .707 .577 .707 r
F P
0 g
s
.55078 .6976 m .55001 .64258 L .57938 .63841 L p .707 .577 .707 r
F P
0 g
s
.57938 .63841 m .58016 .69344 L .55078 .6976 L p .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55118 .73045 L .55665 .73029 L p .707 .577 .707 r
F P
0 g
s
.55665 .73029 m .58051 .72959 L p .55124 .76624 L .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55665 .73029 L .55124 .76624 L .707 .577 .707 r
F
.58016 .69344 m .57938 .63841 L .61122 .63713 L p F P
0 g
s
.61122 .63713 m .61199 .69216 L .58016 .69344 L p .707 .577 .707 r
F P
0 g
s
.58051 .72959 m .57887 .7675 L .54955 .76835 L p .707 .577 .707 r
F P
0 g
s
.54595 .81877 m .54781 .79964 L .57691 .80212 L p .707 .577 .707 r
F P
0 g
s
.57691 .80212 m .57505 .82126 L .54595 .81877 L p .707 .577 .707 r
F P
0 g
s
.57887 .7675 m .58051 .72959 L .61231 .73044 L p .707 .577 .707 r
F P
0 g
s
.61231 .73044 m .61067 .76835 L .57887 .7675 L p .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .57691 .80212 L .58257 .80265 L p .707 .577 .707 r
F P
0 g
s
.58257 .80265 m .60856 .80511 L p .5803 .81873 L .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .58257 .80265 L .5803 .81873 L .707 .577 .707 r
F
.64239 .63886 m .64316 .69389 L .61199 .69216 L p F P
0 g
s
.61199 .69216 m .61122 .63713 L .64239 .63886 L p .707 .577 .707 r
F P
0 g
s
.64347 .7329 m .64183 .7708 L .61067 .76835 L p .707 .577 .707 r
F P
0 g
s
.61067 .76835 m .61231 .73044 L .64347 .7329 L p .707 .577 .707 r
F P
0 g
s
.6067 .82424 m .60856 .80511 L .63967 .80831 L p .707 .577 .707 r
F P
0 g
s
.60856 .80511 m .6067 .82424 L .57505 .82126 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .62977 .80022 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.61349 .30296 m .60931 .61321 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.60931 .61321 m .60667 .80911 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .60667 .80911 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57954 .30956 m .57557 .60473 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57557 .60473 m .57273 .81571 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.53807 .31324 m .53125 .81939 L .57273 .81571 L p .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .57954 .30956 L .53807 .31324 L p .707 .577 .707 r
F P
0 g
s
.44231 .81687 m .44912 .31072 L .41036 .30476 L p .707 .577 .707 r
F P
0 g
s
.44912 .31072 m .44231 .81687 L .48631 .81979 L p .707 .577 .707 r
F P
0 g
s
.70764 .75228 m .70601 .79019 L .70304 .78483 L p .707 .577 .707 r
F P
0 g
s
.70304 .78483 m .70468 .74692 L .70764 .75228 L p .707 .577 .707 r
F P
0 g
s
.7035 .65905 m .70428 .71408 L .69168 .70541 L p .707 .577 .707 r
F P
0 g
s
.69168 .70541 m .69091 .65038 L .7035 .65905 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .61349 .30296 L .57954 .30956 L p .707 .577 .707 r
F P
0 g
s
.70457 .81726 m .70271 .8364 L .69945 .83525 L p .707 .577 .707 r
F P
0 g
s
.69945 .83525 m .70131 .81611 L .70457 .81726 L p .707 .577 .707 r
F P
0 g
s
.25548 .7168 m .25471 .66177 L .22354 .66005 L p .707 .577 .707 r
F P
0 g
s
.25471 .66177 m .25548 .7168 L .28731 .71552 L p .707 .577 .707 r
F P
0 g
s
.28731 .71552 m .28654 .66049 L .25471 .66177 L p .707 .577 .707 r
F P
0 g
s
.40354 .81091 m .41036 .30476 L .38063 .29635 L p .707 .577 .707 r
F P
0 g
s
.41036 .30476 m .40354 .81091 L .44231 .81687 L p .707 .577 .707 r
F P
0 g
s
.28654 .66049 m .28731 .71552 L .31669 .71135 L p .707 .577 .707 r
F P
0 g
s
.31669 .71135 m .31592 .65633 L .28654 .66049 L p .707 .577 .707 r
F P
0 g
s
.22431 .71507 m .22354 .66005 L .19608 .65548 L p .707 .577 .707 r
F P
0 g
s
.22354 .66005 m .22431 .71507 L .25548 .7168 L p .707 .577 .707 r
F P
0 g
s
.31592 .65633 m .31669 .71135 L .34074 .70472 L p .707 .577 .707 r
F P
0 g
s
.34074 .70472 m .33996 .64969 L .31592 .65633 L p .707 .577 .707 r
F P
0 g
s
.70468 .74692 m .70304 .78483 L .69039 .77947 L p .707 .577 .707 r
F P
0 g
s
.69039 .77947 m .69203 .74156 L .70468 .74692 L p .707 .577 .707 r
F P
0 g
s
.69091 .65038 m .69168 .70541 L .67062 .69845 L p .707 .577 .707 r
F P
0 g
s
.67062 .69845 m .66985 .64343 L .69091 .65038 L p .707 .577 .707 r
F P
0 g
s
.62977 .80022 m .63659 .29407 L .61349 .30296 L p .707 .577 .707 r
F P
0 g
s
.25459 .76452 m .25622 .72661 L .22506 .72415 L p .707 .577 .707 r
F P
0 g
s
.25622 .72661 m .25459 .76452 L .28639 .76537 L p .707 .577 .707 r
F P
0 g
s
.28639 .76537 m .28802 .72746 L .25622 .72661 L p .707 .577 .707 r
F P
0 g
s
.19685 .71051 m .19608 .65548 L .17502 .64852 L p .707 .577 .707 r
F P
0 g
s
.19608 .65548 m .19685 .71051 L .22431 .71507 L p .707 .577 .707 r
F P
0 g
s
.28802 .72746 m .28639 .76537 L .31572 .76451 L p .707 .577 .707 r
F P
0 g
s
.31572 .76451 m .31735 .72661 L .28802 .72746 L p .707 .577 .707 r
F P
0 g
s
.70131 .81611 m .69945 .83525 L .68657 .83323 L p .707 .577 .707 r
F P
0 g
s
.68657 .83323 m .68843 .81409 L .70131 .81611 L p .707 .577 .707 r
F P
0 g
s
.22506 .72415 m .22343 .76206 L .25459 .76452 L p .707 .577 .707 r
F P
0 g
s
.22343 .76206 m .22506 .72415 L .19759 .72032 L p .707 .577 .707 r
F P
0 g
s
.25263 .79173 m .25449 .77259 L .22338 .76939 L p .707 .577 .707 r
F P
0 g
s
.25449 .77259 m .25263 .79173 L .28428 .79471 L p .707 .577 .707 r
F P
0 g
s
.28428 .79471 m .28614 .77558 L .25449 .77259 L p .707 .577 .707 r
F P
0 g
s
.22338 .76939 m .22152 .78853 L .25263 .79173 L p .707 .577 .707 r
F P
0 g
s
.28614 .77558 m .28428 .79471 L .31337 .7972 L p .707 .577 .707 r
F P
0 g
s
.31337 .7972 m .31523 .77806 L .28614 .77558 L p .707 .577 .707 r
F P
0 g
s
.37381 .8025 m .38063 .29635 L .36284 .2863 L p .707 .577 .707 r
F P
0 g
s
.38063 .29635 m .37381 .8025 L .40354 .81091 L p .707 .577 .707 r
F P
0 g
s
.33996 .64969 m .34074 .70472 L .3571 .69625 L p .707 .577 .707 r
F P
0 g
s
.3571 .69625 m .35632 .64123 L .33996 .64969 L p .707 .577 .707 r
F P
0 g
s
.19759 .72032 m .19596 .75823 L .22343 .76206 L p .707 .577 .707 r
F P
0 g
s
.22152 .78853 m .22338 .76939 L .19586 .7663 L p .707 .577 .707 r
F P
0 g
s
.19586 .7663 m .194 .78543 L .22152 .78853 L p .707 .577 .707 r
F P
0 g
s
.31735 .72661 m .31572 .76451 L .3397 .76205 L p .707 .577 .707 r
F P
0 g
s
.3397 .76205 m .34133 .72414 L .31735 .72661 L p .707 .577 .707 r
F P
0 g
s
.66985 .64343 m .67062 .69845 L .64316 .69389 L p .707 .577 .707 r
F P
0 g
s
.64316 .69389 m .64239 .63886 L .66985 .64343 L p .707 .577 .707 r
F P
0 g
s
.17502 .64852 m .17579 .70355 L .19685 .71051 L p .707 .577 .707 r
F P
0 g
s
.19596 .75823 m .19759 .72032 L .1765 .71549 L p .707 .577 .707 r
F P
0 g
s
.69203 .74156 m .69039 .77947 L .6693 .77464 L p .707 .577 .707 r
F P
0 g
s
.6693 .77464 m .67094 .73673 L .69203 .74156 L p .707 .577 .707 r
F P
0 g
s
.17579 .70355 m .17502 .64852 L .16242 .63985 L p .707 .577 .707 r
F P
0 g
s
.31523 .77806 m .31337 .7972 L .33706 .79894 L p .707 .577 .707 r
F P
0 g
s
.33706 .79894 m .33892 .7798 L .31523 .77806 L p .707 .577 .707 r
F P
0 g
s
.1765 .71549 m .17487 .7534 L .19596 .75823 L p .707 .577 .707 r
F P
0 g
s
.194 .78543 m .19586 .7663 L .17462 .76361 L p .707 .577 .707 r
F P
0 g
s
.17462 .76361 m .17276 .78274 L .194 .78543 L p .707 .577 .707 r
F P
0 g
s
.68843 .81409 m .68657 .83323 L .66533 .83054 L p .707 .577 .707 r
F P
0 g
s
.66533 .83054 m .66719 .8114 L .68843 .81409 L p .707 .577 .707 r
F P
0 g
s
.63659 .29407 m .62977 .80022 L .63976 .78993 L p .707 .577 .707 r
F P
0 g
s
.63976 .78993 m .64658 .28379 L .63659 .29407 L p .707 .577 .707 r
F P
0 g
s
.34133 .72414 m .3397 .76205 L .35599 .75821 L p .707 .577 .707 r
F P
0 g
s
.35599 .75821 m .35763 .7203 L .34133 .72414 L p .707 .577 .707 r
F P
0 g
s
.35632 .64123 m .3571 .69625 L .36417 .68679 L p .707 .577 .707 r
F P
0 g
s
.36417 .68679 m .3634 .63177 L .35632 .64123 L p .707 .577 .707 r
F P
0 g
s
.16242 .63985 m .16319 .69488 L .17579 .70355 L p .707 .577 .707 r
F P
0 g
s
.33892 .7798 m .33706 .79894 L .35302 .79976 L p .707 .577 .707 r
F P
0 g
s
.35302 .79976 m .35488 .78062 L .33892 .7798 L p .707 .577 .707 r
F P
0 g
s
.17487 .7534 m .1765 .71549 L .16385 .71013 L p .707 .577 .707 r
F P
0 g
s
.67094 .73673 m .6693 .77464 L .64183 .7708 L p .707 .577 .707 r
F P
0 g
s
.64183 .7708 m .64347 .7329 L .67094 .73673 L p .707 .577 .707 r
F P
0 g
s
.16319 .69488 m .16242 .63985 L .15952 .63032 L p .707 .577 .707 r
F P
0 g
s
.35763 .7203 m .35599 .75821 L .363 .75337 L p .707 .577 .707 r
F P
0 g
s
.35488 .78062 m .35302 .79976 L .3597 .79959 L p .707 .577 .707 r
F P
0 g
s
.3597 .79959 m .36156 .78045 L .35488 .78062 L p .707 .577 .707 r
F P
0 g
s
.3605 .62224 m .36127 .67726 L .34867 .66859 L p .707 .577 .707 r
F P
0 g
s
.34867 .66859 m .3479 .61357 L .3605 .62224 L p .707 .577 .707 r
F P
0 g
s
.363 .75337 m .36463 .71546 L .35763 .7203 L p .707 .577 .707 r
F P
0 g
s
.36167 .71011 m .36003 .74801 L .35944 .74776 L p .707 .577 .707 r
F P
0 g
s
.35944 .74776 m .34739 .74266 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.35933 .71544 m .36167 .71011 L .35944 .74776 L .707 .577 .707 r
F
.36284 .2863 m .35874 .27561 L p .35818 .38242 L F P
0 g
s
.34739 .74266 m .34902 .70475 L .35931 .70911 L p .707 .577 .707 r
F P
0 g
s
.35931 .70911 m .36167 .71011 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.34739 .74266 m .35931 .70911 L .35933 .71544 L .707 .577 .707 r
F
.3583 .7793 m .35644 .79843 L .34356 .79641 L p F P
0 g
s
.34356 .79641 m .34542 .77728 L .3583 .7793 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35603 .79245 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35874 .27561 m .358 .33057 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.358 .33057 m .35193 .78176 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35603 .79245 m .35887 .58147 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35887 .58147 m .36284 .2863 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.3634 .63177 m .36417 .68679 L .36127 .67726 L p .707 .577 .707 r
F P
0 g
s
.36127 .67726 m .3605 .62224 L .3634 .63177 L p .707 .577 .707 r
F P
0 g
s
.36463 .71546 m .363 .75337 L .36003 .74801 L p .707 .577 .707 r
F P
0 g
s
.36003 .74801 m .36167 .71011 L .36463 .71546 L p .707 .577 .707 r
F P
0 g
s
.36156 .78045 m .3597 .79959 L .35644 .79843 L p .707 .577 .707 r
F P
0 g
s
.35644 .79843 m .3583 .7793 L .36156 .78045 L p .707 .577 .707 r
F P
0 g
s
.36284 .2863 m .35603 .79245 L .37381 .8025 L p .707 .577 .707 r
F P
0 g
s
.16385 .71013 m .16222 .74804 L .17487 .7534 L p .707 .577 .707 r
F P
0 g
s
.17276 .78274 m .17462 .76361 L .16173 .76159 L p .707 .577 .707 r
F P
0 g
s
.16173 .76159 m .15988 .78072 L .17276 .78274 L p .707 .577 .707 r
F P
0 g
s
.66719 .8114 m .66533 .83054 L .63781 .82744 L p .707 .577 .707 r
F P
0 g
s
.63781 .82744 m .63967 .80831 L .66719 .8114 L p .707 .577 .707 r
F P
0 g
s
.15952 .63032 m .16029 .68535 L .16319 .69488 L p .707 .577 .707 r
F P
0 g
s
.63967 .80831 m .63781 .82744 L .6067 .82424 L p .707 .577 .707 r
F P
0 g
s
.16222 .74804 m .16385 .71013 L .16089 .70477 L p .707 .577 .707 r
F P
0 g
s
.64658 .28379 m .63976 .78993 L .63566 .77925 L p .707 .577 .707 r
F P
0 g
s
.63566 .77925 m .64248 .2731 L .64658 .28379 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16089 .70477 m .15925 .74268 L .16222 .74804 L p .707 .577 .707 r
F P
0 g
s
.16029 .68535 m .15952 .63032 L .16659 .62086 L p .707 .577 .707 r
F P
0 g
s
.15988 .78072 m .16173 .76159 L .15847 .76043 L p .707 .577 .707 r
F P
0 g
s
.15847 .76043 m .15661 .77957 L .15988 .78072 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35874 .27561 L .36873 .26532 L p .707 .577 .707 r
F P
0 g
s
.16659 .62086 m .16737 .67589 L .16029 .68535 L p .707 .577 .707 r
F P
0 g
s
.15925 .74268 m .16089 .70477 L .16789 .69994 L p .707 .577 .707 r
F P
0 g
s
.16737 .67589 m .16659 .62086 L .18295 .6124 L p .707 .577 .707 r
F P
0 g
s
.16789 .69994 m .16626 .73784 L .15925 .74268 L p .707 .577 .707 r
F P
0 g
s
.15661 .77957 m .15847 .76043 L .16515 .76026 L p .707 .577 .707 r
F P
0 g
s
.16515 .76026 m .16329 .7794 L .15661 .77957 L p .707 .577 .707 r
F P
0 g
s
.64248 .2731 m .63566 .77925 L .61788 .7692 L p .707 .577 .707 r
F P
0 g
s
.61788 .7692 m .62469 .26305 L .64248 .2731 L p .707 .577 .707 r
F P
0 g
s
.3479 .61357 m .34867 .66859 L .32761 .66164 L p .707 .577 .707 r
F P
0 g
s
.32761 .66164 m .32684 .60661 L .3479 .61357 L p .707 .577 .707 r
F P
0 g
s
.18295 .6124 m .18373 .66743 L .16737 .67589 L p .707 .577 .707 r
F P
0 g
s
.16626 .73784 m .16789 .69994 L .18419 .6961 L p .707 .577 .707 r
F P
0 g
s
.18373 .66743 m .18295 .6124 L .207 .60576 L p .707 .577 .707 r
F P
0 g
s
.36192 .77147 m .36873 .26532 L .39183 .25644 L p .707 .577 .707 r
F P
0 g
s
.36873 .26532 m .36192 .77147 L .35193 .78176 L p .707 .577 .707 r
F P
0 g
s
.18419 .6961 m .18255 .734 L .16626 .73784 L p .707 .577 .707 r
F P
0 g
s
.16329 .7794 m .16515 .76026 L .18112 .76108 L p .707 .577 .707 r
F P
0 g
s
.18112 .76108 m .17926 .78022 L .16329 .7794 L p .707 .577 .707 r
F P
0 g
s
.32684 .60661 m .32761 .66164 L .30015 .65707 L p .707 .577 .707 r
F P
0 g
s
.30015 .65707 m .29938 .60205 L .32684 .60661 L p .707 .577 .707 r
F P
0 g
s
.34902 .70475 m .34739 .74266 L .32629 .73782 L p .707 .577 .707 r
F P
0 g
s
.32629 .73782 m .32793 .69992 L .34902 .70475 L p .707 .577 .707 r
F P
0 g
s
.207 .60576 m .20777 .66079 L .18373 .66743 L p .707 .577 .707 r
F P
0 g
s
.20777 .66079 m .207 .60576 L .23638 .6016 L p .707 .577 .707 r
F P
0 g
s
.62469 .26305 m .61788 .7692 L .58815 .76079 L p .707 .577 .707 r
F P
0 g
s
.58815 .76079 m .59496 .25464 L .62469 .26305 L p .707 .577 .707 r
F P
0 g
s
.18255 .734 m .18419 .6961 L .20817 .69363 L p .707 .577 .707 r
F P
0 g
s
.29938 .60205 m .30015 .65707 L .26898 .65534 L p .707 .577 .707 r
F P
0 g
s
.26898 .65534 m .26821 .60032 L .29938 .60205 L p .707 .577 .707 r
F P
0 g
s
.34542 .77728 m .34356 .79641 L .32232 .79372 L p .707 .577 .707 r
F P
0 g
s
.32232 .79372 m .32418 .77459 L .34542 .77728 L p .707 .577 .707 r
F P
0 g
s
.23715 .65662 m .23638 .6016 L .26821 .60032 L p .707 .577 .707 r
F P
0 g
s
.23638 .6016 m .23715 .65662 L .20777 .66079 L p .707 .577 .707 r
F P
0 g
s
.20817 .69363 m .20654 .73154 L .18255 .734 L p .707 .577 .707 r
F P
0 g
s
.26821 .60032 m .26898 .65534 L .23715 .65662 L p .707 .577 .707 r
F P
0 g
s
.17926 .78022 m .18112 .76108 L .2048 .76282 L p .707 .577 .707 r
F P
0 g
s
.7357 .65691 m .73492 .60188 L .70375 .60015 L p .707 .577 .707 r
F P
0 g
s
.73492 .60188 m .7357 .65691 L .76753 .65563 L p .707 .577 .707 r
F P
0 g
s
.76753 .65563 m .76675 .6006 L .73492 .60188 L p .707 .577 .707 r
F P
0 g
s
.2048 .76282 m .20295 .78196 L .17926 .78022 L p .707 .577 .707 r
F P
0 g
s
.39183 .25644 m .38502 .76259 L .36192 .77147 L p .707 .577 .707 r
F P
0 g
s
.38502 .76259 m .39183 .25644 L .42578 .24984 L p .707 .577 .707 r
F P
0 g
s
.76675 .6006 m .76753 .65563 L .7969 .65146 L p .707 .577 .707 r
F P
0 g
s
.7969 .65146 m .79613 .59644 L .76675 .6006 L p .707 .577 .707 r
F P
0 g
s
.32793 .69992 m .32629 .73782 L .29882 .73399 L p .707 .577 .707 r
F P
0 g
s
.29882 .73399 m .30046 .69608 L .32793 .69992 L p .707 .577 .707 r
F P
0 g
s
.70452 .65518 m .70375 .60015 L .67629 .59559 L p .707 .577 .707 r
F P
0 g
s
.70375 .60015 m .70452 .65518 L .7357 .65691 L p .707 .577 .707 r
F P
0 g
s
.20654 .73154 m .20817 .69363 L .2375 .69278 L p .707 .577 .707 r
F P
0 g
s
.79613 .59644 m .7969 .65146 L .82095 .64482 L p .707 .577 .707 r
F P
0 g
s
.82095 .64482 m .82018 .5898 L .79613 .59644 L p .707 .577 .707 r
F P
0 g
s
.32418 .77459 m .32232 .79372 L .2948 .79063 L p .707 .577 .707 r
F P
0 g
s
.2948 .79063 m .29666 .77149 L .32418 .77459 L p .707 .577 .707 r
F P
0 g
s
.2375 .69278 m .23586 .73069 L .20654 .73154 L p .707 .577 .707 r
F P
0 g
s
.30046 .69608 m .29882 .73399 L .26766 .73153 L p .707 .577 .707 r
F P
0 g
s
.26766 .73153 m .2693 .69362 L .30046 .69608 L p .707 .577 .707 r
F P
0 g
s
.59496 .25464 m .58815 .76079 L .54938 .75483 L p .707 .577 .707 r
F P
0 g
s
.54938 .75483 m .5562 .24868 L .59496 .25464 L p .707 .577 .707 r
F P
0 g
s
.20295 .78196 m .2048 .76282 L .2339 .76531 L p .707 .577 .707 r
F P
0 g
s
.7348 .70272 m .73644 .66481 L .70528 .66236 L p .707 .577 .707 r
F P
0 g
s
.73644 .66481 m .7348 .70272 L .7666 .70357 L p .707 .577 .707 r
F P
0 g
s
.7666 .70357 m .76824 .66566 L .73644 .66481 L p .707 .577 .707 r
F P
0 g
s
.2339 .76531 m .23204 .78444 L .20295 .78196 L p .707 .577 .707 r
F P
0 g
s
.67707 .65061 m .67629 .59559 L .65523 .58863 L p .707 .577 .707 r
F P
0 g
s
.67629 .59559 m .67707 .65061 L .70452 .65518 L p .707 .577 .707 r
F P
0 g
s
.23586 .73069 m .2375 .69278 L .2693 .69362 L p .707 .577 .707 r
F P
0 g
s
.76824 .66566 m .7666 .70357 L .79593 .70271 L p .707 .577 .707 r
F P
0 g
s
.79593 .70271 m .79756 .66481 L .76824 .66566 L p .707 .577 .707 r
F P
0 g
s
.2693 .69362 m .26766 .73153 L .23586 .73069 L p .707 .577 .707 r
F P
0 g
s
.70528 .66236 m .70364 .70026 L .7348 .70272 L p .707 .577 .707 r
F P
0 g
s
.70364 .70026 m .70528 .66236 L .67781 .65852 L p .707 .577 .707 r
F P
0 g
s
.41896 .75599 m .42578 .24984 L .46725 .24615 L p .707 .577 .707 r
F P
0 g
s
.42578 .24984 m .41896 .75599 L .38502 .76259 L p .707 .577 .707 r
F P
0 g
s
.29666 .77149 m .2948 .79063 L .26369 .78743 L p .707 .577 .707 r
F P
0 g
s
.26369 .78743 m .26555 .76829 L .29666 .77149 L p .707 .577 .707 r
F P
0 g
s
.73284 .73408 m .7347 .71494 L .70359 .71175 L p .707 .577 .707 r
F P
0 g
s
.7347 .71494 m .73284 .73408 L .76449 .73707 L p .707 .577 .707 r
F P
0 g
s
.76449 .73707 m .76635 .71793 L .7347 .71494 L p .707 .577 .707 r
F P
0 g
s
.70359 .71175 m .70173 .73088 L .73284 .73408 L p .707 .577 .707 r
F P
0 g
s
.23204 .78444 m .2339 .76531 L .26555 .76829 L p .707 .577 .707 r
F P
0 g
s
.76635 .71793 m .76449 .73707 L .79358 .73955 L p .707 .577 .707 r
F P
0 g
s
.79358 .73955 m .79544 .72042 L .76635 .71793 L p .707 .577 .707 r
F P
0 g
s
.67781 .65852 m .67617 .69643 L .70364 .70026 L p .707 .577 .707 r
F P
0 g
s
.26555 .76829 m .26369 .78743 L .23204 .78444 L p .707 .577 .707 r
F P
0 g
s
.82018 .5898 m .82095 .64482 L .83731 .63636 L p .707 .577 .707 r
F P
0 g
s
.83731 .63636 m .83654 .58134 L .82018 .5898 L p .707 .577 .707 r
F P
0 g
s
.79756 .66481 m .79593 .70271 L .81991 .70025 L p .707 .577 .707 r
F P
0 g
s
.81991 .70025 m .82155 .66234 L .79756 .66481 L p .707 .577 .707 r
F P
0 g
s
.70173 .73088 m .70359 .71175 L .67607 .70865 L p .707 .577 .707 r
F P
0 g
s
.67607 .70865 m .67421 .72779 L .70173 .73088 L p .707 .577 .707 r
F P
0 g
s
.65523 .58863 m .65601 .64366 L .67707 .65061 L p .707 .577 .707 r
F P
0 g
s
.5562 .24868 m .54938 .75483 L .50538 .75191 L p .707 .577 .707 r
F P
0 g
s
.50538 .75191 m .51219 .24576 L .5562 .24868 L p .707 .577 .707 r
F P
0 g
s
.67617 .69643 m .67781 .65852 L .65671 .65369 L p .707 .577 .707 r
F P
0 g
s
.65601 .64366 m .65523 .58863 L .64263 .57996 L p .707 .577 .707 r
F P
0 g
s
.79544 .72042 m .79358 .73955 L .81727 .74129 L p .707 .577 .707 r
F P
0 g
s
.81727 .74129 m .81913 .72215 L .79544 .72042 L p .707 .577 .707 r
F P
0 g
s
.46044 .7523 m .46725 .24615 L .51219 .24576 L p .707 .577 .707 r
F P
0 g
s
.46725 .24615 m .46044 .7523 L .41896 .75599 L p .707 .577 .707 r
F P
0 g
s
.65671 .65369 m .65508 .6916 L .67617 .69643 L p .707 .577 .707 r
F P
0 g
s
.51219 .24576 m .50538 .75191 L .46044 .7523 L p .707 .577 .707 r
F P
0 g
s
.67421 .72779 m .67607 .70865 L .65483 .70596 L p .707 .577 .707 r
F P
0 g
s
.65483 .70596 m .65297 .7251 L .67421 .72779 L p .707 .577 .707 r
F P
0 g
s
.82155 .66234 m .81991 .70025 L .83621 .69641 L p .707 .577 .707 r
F P
0 g
s
.83621 .69641 m .83784 .6585 L .82155 .66234 L p .707 .577 .707 r
F P
0 g
s
.83654 .58134 m .83731 .63636 L .84439 .6269 L p .707 .577 .707 r
F P
0 g
s
.84439 .6269 m .84361 .57188 L .83654 .58134 L p .707 .577 .707 r
F P
0 g
s
.64263 .57996 m .64341 .63499 L .65601 .64366 L p .707 .577 .707 r
F P
0 g
s
.65508 .6916 m .65671 .65369 L .64407 .64833 L p .707 .577 .707 r
F P
0 g
s
.81913 .72215 m .81727 .74129 L .83324 .74211 L p .707 .577 .707 r
F P
0 g
s
.83324 .74211 m .8351 .72298 L .81913 .72215 L p .707 .577 .707 r
F P
0 g
s
.64341 .63499 m .64263 .57996 L .63973 .57043 L p .707 .577 .707 r
F P
0 g
s
.64407 .64833 m .64243 .68624 L .65508 .6916 L p .707 .577 .707 r
F P
0 g
s
.65297 .7251 m .65483 .70596 L .64195 .70394 L p .707 .577 .707 r
F P
0 g
s
.64195 .70394 m .64009 .72308 L .65297 .7251 L p .707 .577 .707 r
F P
0 g
s
.83784 .6585 m .83621 .69641 L .84321 .69157 L p .707 .577 .707 r
F P
0 g
s
.84321 .69157 m .84485 .65367 L .83784 .6585 L p .707 .577 .707 r
F P
0 g
s
.84361 .57188 m .84439 .6269 L .84148 .61737 L p .707 .577 .707 r
F P
0 g
s
.84148 .61737 m .84071 .56234 L .84361 .57188 L p .707 .577 .707 r
F P
0 g
s
.63973 .57043 m .6405 .62546 L .64341 .63499 L p .707 .577 .707 r
F P
0 g
s
.8351 .72298 m .83324 .74211 L .83992 .74194 L p .707 .577 .707 r
F P
0 g
s
.83992 .74194 m .84178 .7228 L .8351 .72298 L p .707 .577 .707 r
F P
0 g
s
.64243 .68624 m .64407 .64833 L .6411 .64297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6411 .64297 m .63947 .68088 L .64243 .68624 L p .707 .577 .707 r
F P
0 g
s
.6405 .62546 m .63973 .57043 L .6468 .56097 L p .707 .577 .707 r
F P
0 g
s
.64009 .72308 m .64195 .70394 L .63869 .70279 L p .707 .577 .707 r
F P
0 g
s
.63869 .70279 m .63683 .72192 L .64009 .72308 L p .707 .577 .707 r
F P
0 g
s
.84485 .65367 m .84321 .69157 L .84025 .68621 L p .707 .577 .707 r
F P
0 g
s
.84025 .68621 m .84188 .64831 L .84485 .65367 L p .707 .577 .707 r
F P
0 g
s
.84071 .56234 m .84148 .61737 L .82889 .6087 L p .707 .577 .707 r
F P
0 g
s
.82889 .6087 m .82811 .55368 L .84071 .56234 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6468 .56097 m .64758 .616 L .6405 .62546 L p .707 .577 .707 r
F P
0 g
s
.84178 .7228 m .83992 .74194 L .83666 .74079 L p .707 .577 .707 r
F P
0 g
s
.83666 .74079 m .83852 .72165 L .84178 .7228 L p .707 .577 .707 r
F P
0 g
s
.63947 .68088 m .6411 .64297 L .64811 .63814 L p .707 .577 .707 r
F P
0 g
s
.39269 .62009 m .39191 .56507 L .36074 .56334 L p .707 .577 .707 r
F P
0 g
s
.39191 .56507 m .39269 .62009 L .42452 .61881 L p .707 .577 .707 r
F P
0 g
s
.42452 .61881 m .42374 .56378 L .39191 .56507 L p .707 .577 .707 r
F P
0 g
s
.64758 .616 m .6468 .56097 L .66317 .55251 L p .707 .577 .707 r
F P
0 g
s
.64811 .63814 m .64647 .67604 L .63947 .68088 L p .707 .577 .707 r
F P
0 g
s
.42374 .56378 m .42452 .61881 L .45389 .61465 L p .707 .577 .707 r
F P
0 g
s
.45389 .61465 m .45312 .55962 L .42374 .56378 L p .707 .577 .707 r
F P
0 g
s
.63683 .72192 m .63869 .70279 L .64537 .70261 L p .707 .577 .707 r
F P
0 g
s
.64537 .70261 m .64351 .72175 L .63683 .72192 L p .707 .577 .707 r
F P
0 g
s
.36151 .61836 m .36074 .56334 L .33328 .55877 L p .707 .577 .707 r
F P
0 g
s
.36074 .56334 m .36151 .61836 L .39269 .62009 L p .707 .577 .707 r
F P
0 g
s
.45312 .55962 m .45389 .61465 L .47794 .60801 L p .707 .577 .707 r
F P
0 g
s
.47794 .60801 m .47717 .55298 L .45312 .55962 L p .707 .577 .707 r
F P
0 g
s
.84188 .64831 m .84025 .68621 L .8276 .68086 L p .707 .577 .707 r
F P
0 g
s
.8276 .68086 m .82923 .64295 L .84188 .64831 L p .707 .577 .707 r
F P
0 g
s
.82811 .55368 m .82889 .6087 L .80783 .60174 L p .707 .577 .707 r
F P
0 g
s
.80783 .60174 m .80705 .54672 L .82811 .55368 L p .707 .577 .707 r
F P
0 g
s
.66317 .55251 m .66394 .60753 L .64758 .616 L p .707 .577 .707 r
F P
0 g
s
.39179 .66591 m .39343 .628 L .36227 .62554 L p .707 .577 .707 r
F P
0 g
s
.39343 .628 m .39179 .66591 L .42359 .66675 L p .707 .577 .707 r
F P
0 g
s
.42359 .66675 m .42523 .62884 L .39343 .628 L p .707 .577 .707 r
F P
0 g
s
.33406 .6138 m .33328 .55877 L .31222 .55181 L p .707 .577 .707 r
F P
0 g
s
.33328 .55877 m .33406 .6138 L .36151 .61836 L p .707 .577 .707 r
F P
0 g
s
.42523 .62884 m .42359 .66675 L .45292 .6659 L p .707 .577 .707 r
F P
0 g
s
.45292 .6659 m .45455 .62799 L .42523 .62884 L p .707 .577 .707 r
F P
0 g
s
.64647 .67604 m .64811 .63814 L .6644 .6343 L p .707 .577 .707 r
F P
0 g
s
.83852 .72165 m .83666 .74079 L .82377 .73876 L p .707 .577 .707 r
F P
0 g
s
.82377 .73876 m .82563 .71963 L .83852 .72165 L p .707 .577 .707 r
F P
0 g
s
.66394 .60753 m .66317 .55251 L .68721 .54587 L p .707 .577 .707 r
F P
0 g
s
.36227 .62554 m .36063 .66345 L .39179 .66591 L p .707 .577 .707 r
F P
0 g
s
.36063 .66345 m .36227 .62554 L .3348 .62171 L p .707 .577 .707 r
F P
0 g
s
.38983 .69726 m .39169 .67813 L .36058 .67493 L p .707 .577 .707 r
F P
0 g
s
.39169 .67813 m .38983 .69726 L .42148 .70025 L p .707 .577 .707 r
F P
0 g
s
.42148 .70025 m .42334 .68112 L .39169 .67813 L p .707 .577 .707 r
F P
0 g
s
.36058 .67493 m .35872 .69407 L .38983 .69726 L p .707 .577 .707 r
F P
0 g
s
.6644 .6343 m .66277 .67221 L .64647 .67604 L p .707 .577 .707 r
F P
0 g
s
.42334 .68112 m .42148 .70025 L .45058 .70274 L p .707 .577 .707 r
F P
0 g
s
.45058 .70274 m .45243 .6836 L .42334 .68112 L p .707 .577 .707 r
F P
0 g
s
.3348 .62171 m .33316 .65961 L .36063 .66345 L p .707 .577 .707 r
F P
0 g
s
.47717 .55298 m .47794 .60801 L .4943 .59955 L p .707 .577 .707 r
F P
0 g
s
.4943 .59955 m .49353 .54452 L .47717 .55298 L p .707 .577 .707 r
F P
0 g
s
.45455 .62799 m .45292 .6659 L .4769 .66343 L p .707 .577 .707 r
F P
0 g
s
.4769 .66343 m .47854 .62552 L .45455 .62799 L p .707 .577 .707 r
F P
0 g
s
.64351 .72175 m .64537 .70261 L .66133 .70344 L p .707 .577 .707 r
F P
0 g
s
.35872 .69407 m .36058 .67493 L .33306 .67184 L p .707 .577 .707 r
F P
0 g
s
.66133 .70344 m .65947 .72257 L .64351 .72175 L p .707 .577 .707 r
F P
0 g
s
.33306 .67184 m .3312 .69097 L .35872 .69407 L p .707 .577 .707 r
F P
0 g
s
.80705 .54672 m .80783 .60174 L .78037 .59718 L p .707 .577 .707 r
F P
0 g
s
.78037 .59718 m .77959 .54215 L .80705 .54672 L p .707 .577 .707 r
F P
0 g
s
.31222 .55181 m .313 .60684 L .33406 .6138 L p .707 .577 .707 r
F P
0 g
s
.33316 .65961 m .3348 .62171 L .3137 .61687 L p .707 .577 .707 r
F P
0 g
s
.82923 .64295 m .8276 .68086 L .80651 .67602 L p .707 .577 .707 r
F P
0 g
s
.80651 .67602 m .80814 .63812 L .82923 .64295 L p .707 .577 .707 r
F P
0 g
s
.68721 .54587 m .68799 .6009 L .66394 .60753 L p .707 .577 .707 r
F P
0 g
s
.313 .60684 m .31222 .55181 L .29962 .54315 L p .707 .577 .707 r
F P
0 g
s
.45243 .6836 m .45058 .70274 L .47426 .70448 L p .707 .577 .707 r
F P
0 g
s
.47426 .70448 m .47612 .68534 L .45243 .6836 L p .707 .577 .707 r
F P
0 g
s
.68799 .6009 m .68721 .54587 L .71659 .54171 L p .707 .577 .707 r
F P
0 g
s
.3137 .61687 m .31207 .65478 L .33316 .65961 L p .707 .577 .707 r
F P
0 g
s
.3312 .69097 m .33306 .67184 L .31182 .66915 L p .707 .577 .707 r
F P
0 g
s
.66277 .67221 m .6644 .6343 L .68838 .63183 L p .707 .577 .707 r
F P
0 g
s
.31182 .66915 m .30996 .68828 L .3312 .69097 L p .707 .577 .707 r
F P
0 g
s
.77959 .54215 m .78037 .59718 L .7492 .59545 L p .707 .577 .707 r
F P
0 g
s
.7492 .59545 m .74842 .54043 L .77959 .54215 L p .707 .577 .707 r
F P
0 g
s
.82563 .71963 m .82377 .73876 L .80253 .73608 L p .707 .577 .707 r
F P
0 g
s
.80253 .73608 m .80439 .71694 L .82563 .71963 L p .707 .577 .707 r
F P
0 g
s
.47854 .62552 m .4769 .66343 L .4932 .65959 L p .707 .577 .707 r
F P
0 g
s
.4932 .65959 m .49483 .62169 L .47854 .62552 L p .707 .577 .707 r
F P
0 g
s
.71736 .59673 m .71659 .54171 L .74842 .54043 L p .707 .577 .707 r
F P
0 g
s
.71659 .54171 m .71736 .59673 L .68799 .6009 L p .707 .577 .707 r
F P
0 g
s
.68838 .63183 m .68675 .66974 L .66277 .67221 L p .707 .577 .707 r
F P
0 g
s
.49353 .54452 m .4943 .59955 L .50138 .59009 L p .707 .577 .707 r
F P
0 g
s
.50138 .59009 m .5006 .53506 L .49353 .54452 L p .707 .577 .707 r
F P
0 g
s
.74842 .54043 m .7492 .59545 L .71736 .59673 L p .707 .577 .707 r
F P
0 g
s
.29962 .54315 m .3004 .59817 L .313 .60684 L p .707 .577 .707 r
F P
0 g
s
.65947 .72257 m .66133 .70344 L .68502 .70517 L p .707 .577 .707 r
F P
0 g
s
.68502 .70517 m .68316 .72431 L .65947 .72257 L p .707 .577 .707 r
F P
0 g
s
.31207 .65478 m .3137 .61687 L .30106 .61152 L p .707 .577 .707 r
F P
0 g
s
.80814 .63812 m .80651 .67602 L .77904 .67219 L p .707 .577 .707 r
F P
0 g
s
.77904 .67219 m .78067 .63428 L .80814 .63812 L p .707 .577 .707 r
F P
0 g
s
.47612 .68534 m .47426 .70448 L .49023 .7053 L p .707 .577 .707 r
F P
0 g
s
.49023 .7053 m .49209 .68616 L .47612 .68534 L p .707 .577 .707 r
F P
0 g
s
.3004 .59817 m .29962 .54315 L .29672 .53362 L p .707 .577 .707 r
F P
0 g
s
.30106 .61152 m .29942 .64942 L .31207 .65478 L p .707 .577 .707 r
F P
0 g
s
.68675 .66974 m .68838 .63183 L .71771 .63098 L p .707 .577 .707 r
F P
0 g
s
.30996 .68828 m .31182 .66915 L .29894 .66713 L p .707 .577 .707 r
F P
0 g
s
.29894 .66713 m .29708 .68626 L .30996 .68828 L p .707 .577 .707 r
F P
0 g
s
.80439 .71694 m .80253 .73608 L .77501 .73298 L p .707 .577 .707 r
F P
0 g
s
.77501 .73298 m .77687 .71384 L .80439 .71694 L p .707 .577 .707 r
F P
0 g
s
.71771 .63098 m .71608 .66889 L .68675 .66974 L p .707 .577 .707 r
F P
0 g
s
.78067 .63428 m .77904 .67219 L .74788 .66973 L p .707 .577 .707 r
F P
0 g
s
.74788 .66973 m .74951 .63182 L .78067 .63428 L p .707 .577 .707 r
F P
0 g
s
.49483 .62169 m .4932 .65959 L .5002 .65476 L p .707 .577 .707 r
F P
0 g
s
.5002 .65476 m .50184 .61685 L .49483 .62169 L p .707 .577 .707 r
F P
0 g
s
.68316 .72431 m .68502 .70517 L .71411 .70766 L p .707 .577 .707 r
F P
0 g
s
.71411 .70766 m .71225 .72679 L .68316 .72431 L p .707 .577 .707 r
F P
0 g
s
.71608 .66889 m .71771 .63098 L .74951 .63182 L p .707 .577 .707 r
F P
0 g
s
.5006 .53506 m .50138 .59009 L .49847 .58056 L p .707 .577 .707 r
F P
0 g
s
.49847 .58056 m .4977 .52553 L .5006 .53506 L p .707 .577 .707 r
F P
0 g
s
.74951 .63182 m .74788 .66973 L .71608 .66889 L p .707 .577 .707 r
F P
0 g
s
.29672 .53362 m .29749 .58864 L .3004 .59817 L p .707 .577 .707 r
F P
0 g
s
.77687 .71384 m .77501 .73298 L .7439 .72978 L p .707 .577 .707 r
F P
0 g
s
.7439 .72978 m .74576 .71065 L .77687 .71384 L p .707 .577 .707 r
F P
0 g
s
.49209 .68616 m .49023 .7053 L .49691 .70512 L p .707 .577 .707 r
F P
0 g
s
.49691 .70512 m .49877 .68599 L .49209 .68616 L p .707 .577 .707 r
F P
0 g
s
.29942 .64942 m .30106 .61152 L .29809 .60616 L p .707 .577 .707 r
F P
0 g
s
.71225 .72679 m .71411 .70766 L .74576 .71065 L p .707 .577 .707 r
F P
0 g
s
.74576 .71065 m .7439 .72978 L .71225 .72679 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29809 .60616 m .29646 .64406 L .29942 .64942 L p .707 .577 .707 r
F P
0 g
s
.29749 .58864 m .29672 .53362 L .30379 .52416 L p .707 .577 .707 r
F P
0 g
s
.29708 .68626 m .29894 .66713 L .29568 .66597 L p .707 .577 .707 r
F P
0 g
s
.29568 .66597 m .29382 .68511 L .29708 .68626 L p .707 .577 .707 r
F P
0 g
s
.50184 .61685 m .5002 .65476 L .49724 .6494 L p .707 .577 .707 r
F P
0 g
s
.49724 .6494 m .49887 .61149 L .50184 .61685 L p .707 .577 .707 r
F P
0 g
s
.4977 .52553 m .49847 .58056 L .48588 .57189 L p .707 .577 .707 r
F P
0 g
s
.48588 .57189 m .4851 .51686 L .4977 .52553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30379 .52416 m .30457 .57918 L .29749 .58864 L p .707 .577 .707 r
F P
0 g
s
.49877 .68599 m .49691 .70512 L .49365 .70397 L p .707 .577 .707 r
F P
0 g
s
.49365 .70397 m .49551 .68483 L .49877 .68599 L p .707 .577 .707 r
F P
0 g
s
.29646 .64406 m .29809 .60616 L .3051 .60132 L p .707 .577 .707 r
F P
0 g
s
.30457 .57918 m .30379 .52416 L .32016 .51569 L p .707 .577 .707 r
F P
0 g
s
.3051 .60132 m .30346 .63923 L .29646 .64406 L p .707 .577 .707 r
F P
0 g
s
.29382 .68511 m .29568 .66597 L .30236 .6658 L p .707 .577 .707 r
F P
0 g
s
.30236 .6658 m .3005 .68493 L .29382 .68511 L p .707 .577 .707 r
F P
0 g
s
.49887 .61149 m .49724 .6494 L .48459 .64404 L p .707 .577 .707 r
F P
0 g
s
.48459 .64404 m .48622 .60613 L .49887 .61149 L p .707 .577 .707 r
F P
0 g
s
.4851 .51686 m .48588 .57189 L .46482 .56493 L p .707 .577 .707 r
F P
0 g
s
.46482 .56493 m .46404 .5099 L .4851 .51686 L p .707 .577 .707 r
F P
0 g
s
.32016 .51569 m .32093 .57072 L .30457 .57918 L p .707 .577 .707 r
F P
0 g
s
.30346 .63923 m .3051 .60132 L .32139 .59748 L p .707 .577 .707 r
F P
0 g
s
.49551 .68483 m .49365 .70397 L .48076 .70195 L p .707 .577 .707 r
F P
0 g
s
.48076 .70195 m .48262 .68281 L .49551 .68483 L p .707 .577 .707 r
F P
0 g
s
.32093 .57072 m .32016 .51569 L .3442 .50905 L p .707 .577 .707 r
F P
0 g
s
.32139 .59748 m .31976 .63539 L .30346 .63923 L p .707 .577 .707 r
F P
0 g
s
.3005 .68493 m .30236 .6658 L .31832 .66662 L p .707 .577 .707 r
F P
0 g
s
.31832 .66662 m .31646 .68576 L .3005 .68493 L p .707 .577 .707 r
F P
0 g
s
.46404 .5099 m .46482 .56493 L .43736 .56036 L p .707 .577 .707 r
F P
0 g
s
.43736 .56036 m .43658 .50534 L .46404 .5099 L p .707 .577 .707 r
F P
0 g
s
.48622 .60613 m .48459 .64404 L .4635 .63921 L p .707 .577 .707 r
F P
0 g
s
.4635 .63921 m .46513 .6013 L .48622 .60613 L p .707 .577 .707 r
F P
0 g
s
.3442 .50905 m .34498 .56408 L .32093 .57072 L p .707 .577 .707 r
F P
0 g
s
.34498 .56408 m .3442 .50905 L .37358 .50489 L p .707 .577 .707 r
F P
0 g
s
.31976 .63539 m .32139 .59748 L .34537 .59502 L p .707 .577 .707 r
F P
0 g
s
.43658 .50534 m .43736 .56036 L .40619 .55864 L p .707 .577 .707 r
F P
0 g
s
.40619 .55864 m .40541 .50361 L .43658 .50534 L p .707 .577 .707 r
F P
0 g
s
.48262 .68281 m .48076 .70195 L .45952 .69926 L p .707 .577 .707 r
F P
0 g
s
.45952 .69926 m .46138 .68012 L .48262 .68281 L p .707 .577 .707 r
F P
0 g
s
.37435 .55992 m .37358 .50489 L .40541 .50361 L p .707 .577 .707 r
F P
0 g
s
.37358 .50489 m .37435 .55992 L .34498 .56408 L p .707 .577 .707 r
F P
0 g
s
.34537 .59502 m .34374 .63292 L .31976 .63539 L p .707 .577 .707 r
F P
0 g
s
.40541 .50361 m .40619 .55864 L .37435 .55992 L p .707 .577 .707 r
F P
0 g
s
.31646 .68576 m .31832 .66662 L .34201 .66836 L p .707 .577 .707 r
F P
0 g
s
.34201 .66836 m .34015 .68749 L .31646 .68576 L p .707 .577 .707 r
F P
0 g
s
.46513 .6013 m .4635 .63921 L .43603 .63537 L p .707 .577 .707 r
F P
0 g
s
.43603 .63537 m .43766 .59747 L .46513 .6013 L p .707 .577 .707 r
F P
0 g
s
.34374 .63292 m .34537 .59502 L .3747 .59416 L p .707 .577 .707 r
F P
0 g
s
.46138 .68012 m .45952 .69926 L .432 .69616 L p .707 .577 .707 r
F P
0 g
s
.432 .69616 m .43386 .67703 L .46138 .68012 L p .707 .577 .707 r
F P
0 g
s
.3747 .59416 m .37307 .63207 L .34374 .63292 L p .707 .577 .707 r
F P
0 g
s
.43766 .59747 m .43603 .63537 L .40487 .63292 L p .707 .577 .707 r
F P
0 g
s
.40487 .63292 m .4065 .59501 L .43766 .59747 L p .707 .577 .707 r
F P
0 g
s
.34015 .68749 m .34201 .66836 L .3711 .67084 L p .707 .577 .707 r
F P
0 g
s
.3711 .67084 m .36924 .68998 L .34015 .68749 L p .707 .577 .707 r
F P
0 g
s
.37307 .63207 m .3747 .59416 L .4065 .59501 L p .707 .577 .707 r
F P
0 g
s
.4065 .59501 m .40487 .63292 L .37307 .63207 L p .707 .577 .707 r
F P
0 g
s
.43386 .67703 m .432 .69616 L .40089 .69297 L p .707 .577 .707 r
F P
0 g
s
.40089 .69297 m .40275 .67383 L .43386 .67703 L p .707 .577 .707 r
F P
0 g
s
.36924 .68998 m .3711 .67084 L .40275 .67383 L p .707 .577 .707 r
F P
0 g
s
.40275 .67383 m .40089 .69297 L .36924 .68998 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3@00QGoo001oOol<0006FUH00`00FUIJEP04FUH9001lOol007Moo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Ioo`00LWoo1@000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1000LWoo001^Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001^Ool006Yoo`@00003FUH0
05YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<006]oo`00J7oo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JGoo001WOol20006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006EooaT000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00H7oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001MOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol005]oo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00FGoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001GOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
05Ioo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00EGoo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Uoo`T0
04Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF009JEPP0
03aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH003Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<002moo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF2`001UYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF70000eYF1P0015YF
00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YF00000`00
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00E7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo001DOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000]Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH:0008FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00D005YFFUH005YF00d000=JEP03001JEUYF
009JEPl000=JEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo0018Ool90004Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF2P0017oo3P0000=JEP0000000P000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?goo2@0015YF00<005YFFUH00UYF1`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P00
00=JEP0000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YF00000`001UYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEPD0
00AJEP04001JEUYFFUH2000/Ool003Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP8002aoo`00=Woo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH005YF
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH30003FUH2000/Ool003=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000;7oo000aOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00
;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000/Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000eJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEQT00003FUH005YF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEPD00003FUH005YF00EJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YFFUIJ
EP0002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF00<0
05YFFUH015YF1P0015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH700001EYF001JEUYF0000<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000<Goo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF5`0000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002aoo`00;Goo00<005YF000015YF00<005YFFUH00eYF2P000goo1@0000=oo`0000001`0000=J
EP0000002@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002eoo`03001JEP0000AJEP03
001JEP0000<000EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEP0000<000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;7oo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP0:00001EYF00000000FUH00P0000=JEP00FUH00eYF6@002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00@005YFFUIJEQ0000UJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00FUIJEPL000MJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00;Goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000]Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
1`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000UYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP070002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP04000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF010000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002ioo`04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80002FUH90004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF000000020004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Woo00D005YFFUH005YF02@000=JEP03001JEUYF00=JEP03001JEP00
00L000=JEQ4000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH300000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000_Ool01P00
FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
00EJEP03001JEUYF00800003FUH005YF009JEPT000AJEP03001JEUYF00AJEPL000=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02000_Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPP00004Ool005YF0006FUH00`00FUIJEP03FUH@0002FUH50002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH300000eYF0000000?0004FUH00`00FUIJEP02FUH>000aOol002eoo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP`00003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00d0009JEP8000]oo`T0
03moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00@005YFFUIJEPT004ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@00?Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<002eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH0000000X000=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH:0003FUH90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00002FUH>0008FUH@0004
FUH00`00FUIJEP03FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=J
EP00FUH01EYF00D005YFFUIJEP0000Eoo`T000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00;Goo00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF1P0015YF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00=JEPL00003FUH005YF008000moo`P000=JEPL000=JEP03001JEUYF008002ioo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP<00006FUH005YF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF
00<005YFFUH0100067oo4P00;Woo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH500000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP03FUH3000SOol4000_Ool002ioo`04
001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJ
EP03001JEUYF00=JEP03001JEUYF008005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHI0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000aOol30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00EJEPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol003Aoo`L000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0
009JEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001C
Ool002eooaL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000017oo001JEP00
1EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH010001UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00
;Goo0P0015YF00<005YFFUH015YF00@005YFFUIJEQl000Moo`03001JEP0000=JEP8000IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT001Aoo`04001JEP00FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004
FUH30007FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005=oo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200037oo00@005YF0000009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEUYFFUH20002FUH60004FUH00`00FUIJEP03FUH00`00FUIJEP02001D
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEUYFFUH70005Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40004FUH7
0003FUH00`00FUIJEP02001DOol002aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<0
00EJEP03001JEUYF00=JEP@0009JEP8005Aoo`00;Goo1`000UYF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00AJEP03001JEUYF00@005Aoo`00=7oo1`000UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003]oo`P000AJEP03001JEUYF
00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Aoo`00@goo4P000UYF1`00
0eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJ
EP04001JEUYFFUH2001EOol005Eoo`L0009JEPD0009JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF008005Ioo`00G7oo2`0000Aoo`00000000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000=JEPh005Qoo`00JWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEPL006Ioo`00K7oo10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YF000005YF00P006Aoo`00L7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF1P001eYF00@005YFFUIJEPL005eoo`00MGoo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH00eYF2`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01@00F7oo001kOol90006FUH00`00FUIJEP04FUH>0004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001DOol008AooaP000=JEPT000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol009aoo`T0
00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol00:Eoo`T000=J
EPP000AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00[Woo20000eYF300000=JEP000000EGoo
002fOolB001EOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59998 .75612 m .59872 .70148 L .56755 .69986 L p .707 .577 .707 r
F P
0 g
s
.59872 .70148 m .59998 .75612 L .6318 .75453 L p .707 .577 .707 r
F P
0 g
s
.6318 .75453 m .63055 .69989 L .59872 .70148 L p .707 .577 .707 r
F P
0 g
s
.63055 .69989 m .6318 .75453 L .66117 .74989 L p .707 .577 .707 r
F P
0 g
s
.66117 .74989 m .65992 .69524 L .63055 .69989 L p .707 .577 .707 r
F P
0 g
s
.56881 .7545 m .56755 .69986 L .54009 .69518 L p .707 .577 .707 r
F P
0 g
s
.56755 .69986 m .56881 .7545 L .59998 .75612 L p .707 .577 .707 r
F P
0 g
s
.65992 .69524 m .66117 .74989 L .6852 .74265 L p .707 .577 .707 r
F P
0 g
s
.6852 .74265 m .68395 .688 L .65992 .69524 L p .707 .577 .707 r
F P
0 g
s
.59875 .79585 m .60138 .75766 L .57024 .75485 L p .707 .577 .707 r
F P
0 g
s
.60138 .75766 m .59875 .79585 L .60461 .79619 L p .707 .577 .707 r
F P
0 g
s
.57024 .75485 m .56761 .79304 L .57274 .7935 L p .707 .577 .707 r
F P
0 g
s
.57274 .7935 m .59875 .79585 L p .58642 .77812 L .707 .577 .707 r
F P
0 g
s
.58642 .77812 m .57024 .75485 L .57274 .7935 L .707 .577 .707 r
F
.56761 .79304 m .57024 .75485 L .54275 .75137 L p F P
0 g
s
.54275 .75137 m .54012 .78956 L .54445 .79011 L p .707 .577 .707 r
F P
0 g
s
.54445 .79011 m .56761 .79304 L p .55608 .77372 L .707 .577 .707 r
F P
0 g
s
.55608 .77372 m .54275 .75137 L .54445 .79011 L .707 .577 .707 r
F
.54012 .78956 m .54275 .75137 L .5216 .74755 L p F P
0 g
s
.5216 .74755 m .51897 .78574 L .54012 .78956 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .51936 .78833 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53795 .80753 m .53961 .79692 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53961 .79692 m .5409 .78868 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .5409 .78868 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56557 .80982 m .56714 .7998 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56714 .7998 m .56852 .79097 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .56852 .79097 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59658 .81382 m .59824 .80322 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59824 .80322 m .59953 .79497 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.60461 .79619 m .63049 .79771 L p .61836 .78103 L .707 .577 .707 r
F P
0 g
s
.61836 .78103 m .60138 .75766 L .60461 .79619 L .707 .577 .707 r
F
.63049 .79771 m .63312 .75952 L .60138 .75766 L p F P
0 g
s
.54135 .74983 m .54009 .69518 L .51903 .68792 L p .707 .577 .707 r
F P
0 g
s
.54009 .69518 m .54135 .74983 L .56881 .7545 L p .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .56557 .80982 L .59658 .81382 L p .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .59658 .81382 L .62793 .81915 L p .707 .577 .707 r
F P
0 g
s
.63312 .75952 m .63049 .79771 L .65973 .79844 L p .707 .577 .707 r
F P
0 g
s
.65973 .79844 m .66236 .76026 L .63312 .75952 L p .707 .577 .707 r
F P
0 g
s
.62793 .81915 m .63088 .8003 L .59953 .79497 L p .707 .577 .707 r
F P
0 g
s
.63088 .8003 m .62793 .81915 L .65656 .82528 L p .707 .577 .707 r
F P
0 g
s
.65656 .82528 m .65952 .80643 L .63088 .8003 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .53795 .80753 L .56557 .80982 L p .707 .577 .707 r
F P
0 g
s
.68395 .688 m .6852 .74265 L .70155 .73351 L p .707 .577 .707 r
F P
0 g
s
.70155 .73351 m .7003 .67887 L .68395 .688 L p .707 .577 .707 r
F P
0 g
s
.66236 .76026 m .65973 .79844 L .6836 .79797 L p .707 .577 .707 r
F P
0 g
s
.6836 .79797 m .68623 .75978 L .66236 .76026 L p .707 .577 .707 r
F P
0 g
s
.51903 .68792 m .52028 .74256 L .54135 .74983 L p .707 .577 .707 r
F P
0 g
s
.65952 .80643 m .65656 .82528 L .67967 .8316 L p .707 .577 .707 r
F P
0 g
s
.67967 .8316 m .68262 .81275 L .65952 .80643 L p .707 .577 .707 r
F P
0 g
s
.52028 .74256 m .51903 .68792 L .50642 .67877 L p .707 .577 .707 r
F P
0 g
s
.51936 .78833 m .51641 .80718 L .53795 .80753 L p .707 .577 .707 r
F P
0 g
s
.7003 .67887 m .70155 .73351 L .70862 .72338 L p .707 .577 .707 r
F P
0 g
s
.70862 .72338 m .70736 .66874 L .7003 .67887 L p .707 .577 .707 r
F P
0 g
s
.68623 .75978 m .6836 .79797 L .69977 .79634 L p .707 .577 .707 r
F P
0 g
s
.69977 .79634 m .7024 .75816 L .68623 .75978 L p .707 .577 .707 r
F P
0 g
s
.68262 .81275 m .67967 .8316 L .69499 .83751 L p .707 .577 .707 r
F P
0 g
s
.50642 .67877 m .50767 .73342 L .52028 .74256 L p .707 .577 .707 r
F P
0 g
s
.69499 .83751 m .69794 .81866 L .68262 .81275 L p .707 .577 .707 r
F P
0 g
s
.51897 .78574 m .5216 .74755 L .50887 .74378 L p .707 .577 .707 r
F P
0 g
s
.50602 .78995 m .50307 .8088 L .51641 .80718 L p .707 .577 .707 r
F P
0 g
s
.51641 .80718 m .51936 .78833 L .50602 .78995 L p .707 .577 .707 r
F P
0 g
s
.50887 .74378 m .50623 .78197 L .51897 .78574 L p .707 .577 .707 r
F P
0 g
s
.50767 .73342 m .50642 .67877 L .50351 .66863 L p .707 .577 .707 r
F P
0 g
s
.7024 .75816 m .69977 .79634 L .70665 .79372 L p .707 .577 .707 r
F P
0 g
s
.70665 .79372 m .70928 .75553 L .7024 .75816 L p .707 .577 .707 r
F P
0 g
s
.70736 .66874 m .70862 .72338 L .7057 .71324 L p .707 .577 .707 r
F P
0 g
s
.7057 .71324 m .70445 .6586 L .70736 .66874 L p .707 .577 .707 r
F P
0 g
s
.69794 .81866 m .69499 .83751 L .70102 .84243 L p .707 .577 .707 r
F P
0 g
s
.50351 .66863 m .50476 .72328 L .50767 .73342 L p .707 .577 .707 r
F P
0 g
s
.70102 .84243 m .70398 .82358 L .69794 .81866 L p .707 .577 .707 r
F P
0 g
s
.50623 .78197 m .50887 .74378 L .50579 .74042 L p .707 .577 .707 r
F P
0 g
s
.50218 .79339 m .49922 .81224 L .50307 .8088 L p .707 .577 .707 r
F P
0 g
s
.50307 .8088 m .50602 .78995 L .50218 .79339 L p .707 .577 .707 r
F P
0 g
s
.4838 .81835 m .49482 .30988 L .45082 .30681 L p .707 .577 .707 r
F P
0 g
s
.50579 .74042 m .50316 .7786 L .50623 .78197 L p .707 .577 .707 r
F P
0 g
s
.50476 .72328 m .50351 .66863 L .51057 .6585 L p .707 .577 .707 r
F P
0 g
s
.51057 .6585 m .51182 .71315 L .50476 .72328 L p .707 .577 .707 r
F P
0 g
s
.50316 .7786 m .50579 .74042 L .51267 .73779 L p .707 .577 .707 r
F P
0 g
s
.50821 .7983 m .50526 .81715 L .49922 .81224 L p .707 .577 .707 r
F P
0 g
s
.49922 .81224 m .50218 .79339 L .50821 .7983 L p .707 .577 .707 r
F P
0 g
s
.51182 .71315 m .51057 .6585 L .52692 .64937 L p .707 .577 .707 r
F P
0 g
s
.51267 .73779 m .51004 .77598 L .50316 .7786 L p .707 .577 .707 r
F P
0 g
s
.52692 .64937 m .52817 .70401 L .51182 .71315 L p .707 .577 .707 r
F P
0 g
s
.51004 .77598 m .51267 .73779 L .52884 .73617 L p .707 .577 .707 r
F P
0 g
s
.52353 .80421 m .52058 .82306 L .50526 .81715 L p .707 .577 .707 r
F P
0 g
s
.50526 .81715 m .50821 .7983 L .52353 .80421 L p .707 .577 .707 r
F P
0 g
s
.52884 .73617 m .52621 .77435 L .51004 .77598 L p .707 .577 .707 r
F P
0 g
s
.52058 .82306 m .52353 .80421 L .54664 .81054 L p .707 .577 .707 r
F P
0 g
s
.49482 .30988 m .4838 .81835 L .52873 .81839 L p .707 .577 .707 r
F P
0 g
s
.52817 .70401 m .52692 .64937 L .55095 .64212 L p .707 .577 .707 r
F P
0 g
s
.55095 .64212 m .55221 .69677 L .52817 .70401 L p .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .52884 .73617 L .54369 .73587 L p .707 .577 .707 r
F P
0 g
s
.54369 .73587 m .55271 .7357 L p .54461 .74752 L .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .54369 .73587 L .54461 .74752 L .707 .577 .707 r
F
.55271 .7357 m .55008 .77388 L .52621 .77435 L p F P
0 g
s
.52873 .81839 m .53336 .60492 L p .49482 .30988 L .707 .577 .707 r
F P
0 g
s
.53336 .60492 m .53976 .30992 L .51008 .3099 L p .707 .577 .707 r
F P
0 g
s
.51008 .3099 m .49482 .30988 L p .53336 .60492 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .55095 .64212 L .5552 .64145 L p .707 .577 .707 r
F P
0 g
s
.5552 .64145 m .58032 .63748 L p .56188 .67638 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .5552 .64145 L .56188 .67638 L .707 .577 .707 r
F
.58157 .69213 m .58032 .63748 L .61215 .63589 L p F P
0 g
s
.58032 .63748 m .58157 .69213 L .55221 .69677 L p .707 .577 .707 r
F P
0 g
s
.61215 .63589 m .6134 .69054 L .58157 .69213 L p .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .55271 .7357 L .5707 .73615 L p .707 .577 .707 r
F P
0 g
s
.5707 .73615 m .58195 .73643 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .5707 .73615 L .56614 .755 L .707 .577 .707 r
F
.58122 .30691 m .57205 .72963 L p .57219 .72998 L F P
0 g
s
.58195 .73643 m .57932 .77461 L .56151 .77417 L p .707 .577 .707 r
F P
0 g
s
.56151 .77417 m .55008 .77388 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.56614 .755 m .58195 .73643 L .56151 .77417 L .707 .577 .707 r
F
.57932 .77461 m .58195 .73643 L .59079 .73695 L p F P
0 g
s
.59079 .73695 m .61369 .73829 L p .58813 .76531 L .707 .577 .707 r
F P
0 g
s
.57932 .77461 m .59079 .73695 L .58813 .76531 L .707 .577 .707 r
F
.64332 .63751 m .64457 .69216 L .6134 .69054 L p F P
0 g
s
.6134 .69054 m .61215 .63589 L .64332 .63751 L p .707 .577 .707 r
F P
0 g
s
.64483 .7411 m .6422 .77929 L .61106 .77648 L p .707 .577 .707 r
F P
0 g
s
.61106 .77648 m .61369 .73829 L .64483 .7411 L p .707 .577 .707 r
F P
0 g
s
.61369 .73829 m .61106 .77648 L .57932 .77461 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .62721 .80169 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61515 .30116 m .61018 .53024 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61018 .53024 m .60412 .80963 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58787 .81239 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57205 .72963 m .57203 .73066 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57203 .73066 m .57019 .81538 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .59601 .6315 L .57219 .72998 L .707 .577 .707 r
F
.59601 .6315 m .58122 .30691 L .57219 .72998 L F
.58787 .81239 m .60412 .80963 L p .57205 .72963 L F P
0 g
s
.54664 .81054 m .54369 .82939 L .52058 .82306 L p .707 .577 .707 r
F P
0 g
s
.54369 .82939 m .54664 .81054 L .57527 .81666 L p .707 .577 .707 r
F P
0 g
s
.53976 .30992 m .52873 .81839 L .57019 .81538 L p .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58122 .30691 L .53976 .30992 L p .707 .577 .707 r
F P
0 g
s
.43979 .81528 m .45082 .30681 L .41205 .301 L p .707 .577 .707 r
F P
0 g
s
.45082 .30681 m .43979 .81528 L .4838 .81835 L p .707 .577 .707 r
F P
0 g
s
.70928 .75553 m .70665 .79372 L .70357 .79036 L p .707 .577 .707 r
F P
0 g
s
.70357 .79036 m .70621 .75217 L .70928 .75553 L p .707 .577 .707 r
F P
0 g
s
.70445 .6586 m .7057 .71324 L .6931 .7041 L p .707 .577 .707 r
F P
0 g
s
.6931 .7041 m .69184 .64945 L .70445 .6586 L p .707 .577 .707 r
F P
0 g
s
.70398 .82358 m .70102 .84243 L .69718 .84586 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .61515 .30116 L .58122 .30691 L p .707 .577 .707 r
F P
0 g
s
.69718 .84586 m .70013 .82701 L .70398 .82358 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25697 .71931 m .25571 .66466 L .22454 .66304 L p .707 .577 .707 r
F P
0 g
s
.25571 .66466 m .25697 .71931 L .28879 .71772 L p .707 .577 .707 r
F P
0 g
s
.28879 .71772 m .28754 .66307 L .25571 .66466 L p .707 .577 .707 r
F P
0 g
s
.40103 .80947 m .41205 .301 L .38231 .29302 L p .707 .577 .707 r
F P
0 g
s
.41205 .301 m .40103 .80947 L .43979 .81528 L p .707 .577 .707 r
F P
0 g
s
.28754 .66307 m .28879 .71772 L .31816 .71307 L p .707 .577 .707 r
F P
0 g
s
.31816 .71307 m .31691 .65843 L .28754 .66307 L p .707 .577 .707 r
F P
0 g
s
.2258 .71769 m .22454 .66304 L .19708 .65837 L p .707 .577 .707 r
F P
0 g
s
.22454 .66304 m .2258 .71769 L .25697 .71931 L p .707 .577 .707 r
F P
0 g
s
.31691 .65843 m .31816 .71307 L .3422 .70583 L p .707 .577 .707 r
F P
0 g
s
.3422 .70583 m .34094 .65119 L .31691 .65843 L p .707 .577 .707 r
F P
0 g
s
.69184 .64945 m .6931 .7041 L .67203 .69683 L p .707 .577 .707 r
F P
0 g
s
.67203 .69683 m .67078 .64218 L .69184 .64945 L p .707 .577 .707 r
F P
0 g
s
.70621 .75217 m .70357 .79036 L .69084 .78658 L p .707 .577 .707 r
F P
0 g
s
.69084 .78658 m .69347 .7484 L .70621 .75217 L p .707 .577 .707 r
F P
0 g
s
.62721 .80169 m .63823 .29322 L .61515 .30116 L p .707 .577 .707 r
F P
0 g
s
.70013 .82701 m .69718 .84586 L .68384 .84748 L p .707 .577 .707 r
F P
0 g
s
.25574 .75903 m .25837 .72085 L .22723 .71804 L p .707 .577 .707 r
F P
0 g
s
.25837 .72085 m .25574 .75903 L .2616 .75938 L p .707 .577 .707 r
F P
0 g
s
.22723 .71804 m .2246 .75622 L .22973 .75669 L p .707 .577 .707 r
F P
0 g
s
.22973 .75669 m .25574 .75903 L p .24341 .7413 L .707 .577 .707 r
F P
0 g
s
.24341 .7413 m .22723 .71804 L .22973 .75669 L .707 .577 .707 r
F
.2246 .75622 m .22723 .71804 L .19974 .71455 L p F P
0 g
s
.19974 .71455 m .19711 .75274 L .20144 .75329 L p .707 .577 .707 r
F P
0 g
s
.20144 .75329 m .2246 .75622 L p .21307 .7369 L .707 .577 .707 r
F P
0 g
s
.21307 .7369 m .19974 .71455 L .20144 .75329 L .707 .577 .707 r
F
.19711 .75274 m .19974 .71455 L .17859 .71074 L p F P
0 g
s
.17859 .71074 m .17596 .74893 L .19711 .75274 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .17635 .75151 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.19494 .77072 m .1966 .76011 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.1966 .76011 m .19789 .75187 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .19789 .75187 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22256 .77301 m .22413 .76299 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22413 .76299 m .22552 .75416 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .22552 .75416 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25357 .77701 m .25523 .7664 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25523 .7664 m .25652 .75816 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.2616 .75938 m .28748 .7609 L p .27536 .74421 L .707 .577 .707 r
F P
0 g
s
.27536 .74421 m .25837 .72085 L .2616 .75938 L .707 .577 .707 r
F
.28748 .7609 m .29012 .72271 L .25837 .72085 L p F P
0 g
s
.19834 .71301 m .19708 .65837 L .17602 .6511 L p .707 .577 .707 r
F P
0 g
s
.19708 .65837 m .19834 .71301 L .2258 .71769 L p .707 .577 .707 r
F P
0 g
s
.68384 .84748 m .68679 .82863 L .70013 .82701 L p .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .22256 .77301 L .25357 .77701 L p .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .25357 .77701 L .28492 .78234 L p .707 .577 .707 r
F P
0 g
s
.29012 .72271 m .28748 .7609 L .31672 .76163 L p .707 .577 .707 r
F P
0 g
s
.31672 .76163 m .31935 .72344 L .29012 .72271 L p .707 .577 .707 r
F P
0 g
s
.28492 .78234 m .28788 .76348 L .25652 .75816 L p .707 .577 .707 r
F P
0 g
s
.28788 .76348 m .28492 .78234 L .31355 .78846 L p .707 .577 .707 r
F P
0 g
s
.31355 .78846 m .31651 .76961 L .28788 .76348 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .19494 .77072 L .22256 .77301 L p .707 .577 .707 r
F P
0 g
s
.37129 .80149 m .38231 .29302 L .36452 .28365 L p .707 .577 .707 r
F P
0 g
s
.38231 .29302 m .37129 .80149 L .40103 .80947 L p .707 .577 .707 r
F P
0 g
s
.34094 .65119 m .3422 .70583 L .35854 .6967 L p .707 .577 .707 r
F P
0 g
s
.35854 .6967 m .35729 .64205 L .34094 .65119 L p .707 .577 .707 r
F P
0 g
s
.67078 .64218 m .67203 .69683 L .64457 .69216 L p .707 .577 .707 r
F P
0 g
s
.64457 .69216 m .64332 .63751 L .67078 .64218 L p .707 .577 .707 r
F P
0 g
s
.31935 .72344 m .31672 .76163 L .34059 .76116 L p .707 .577 .707 r
F P
0 g
s
.34059 .76116 m .34323 .72297 L .31935 .72344 L p .707 .577 .707 r
F P
0 g
s
.17602 .6511 m .17727 .70575 L .19834 .71301 L p .707 .577 .707 r
F P
0 g
s
.31651 .76961 m .31355 .78846 L .33666 .79479 L p .707 .577 .707 r
F P
0 g
s
.33666 .79479 m .33961 .77594 L .31651 .76961 L p .707 .577 .707 r
F P
0 g
s
.17727 .70575 m .17602 .6511 L .16341 .64195 L p .707 .577 .707 r
F P
0 g
s
.69347 .7484 m .69084 .78658 L .66969 .78277 L p .707 .577 .707 r
F P
0 g
s
.66969 .78277 m .67232 .74458 L .69347 .7484 L p .707 .577 .707 r
F P
0 g
s
.17635 .75151 m .1734 .77037 L .19494 .77072 L p .707 .577 .707 r
F P
0 g
s
.68679 .82863 m .68384 .84748 L .6623 .84713 L p .707 .577 .707 r
F P
0 g
s
.6623 .84713 m .66525 .82828 L .68679 .82863 L p .707 .577 .707 r
F P
0 g
s
.63823 .29322 m .62721 .80169 L .63718 .79235 L p .707 .577 .707 r
F P
0 g
s
.63718 .79235 m .6482 .28388 L .63823 .29322 L p .707 .577 .707 r
F P
0 g
s
.35729 .64205 m .35854 .6967 L .36561 .68657 L p .707 .577 .707 r
F P
0 g
s
.36561 .68657 m .36435 .63192 L .35729 .64205 L p .707 .577 .707 r
F P
0 g
s
.34323 .72297 m .34059 .76116 L .35676 .75953 L p .707 .577 .707 r
F P
0 g
s
.35676 .75953 m .35939 .72134 L .34323 .72297 L p .707 .577 .707 r
F P
0 g
s
.33961 .77594 m .33666 .79479 L .35198 .8007 L p .707 .577 .707 r
F P
0 g
s
.16341 .64195 m .16466 .6966 L .17727 .70575 L p .707 .577 .707 r
F P
0 g
s
.35198 .8007 m .35493 .78185 L .33961 .77594 L p .707 .577 .707 r
F P
0 g
s
.17596 .74893 m .17859 .71074 L .16586 .70697 L p .707 .577 .707 r
F P
0 g
s
.67232 .74458 m .66969 .78277 L .6422 .77929 L p .707 .577 .707 r
F P
0 g
s
.6422 .77929 m .64483 .7411 L .67232 .74458 L p .707 .577 .707 r
F P
0 g
s
.16301 .75314 m .16006 .77199 L .1734 .77037 L p .707 .577 .707 r
F P
0 g
s
.1734 .77037 m .17635 .75151 L .16301 .75314 L p .707 .577 .707 r
F P
0 g
s
.16586 .70697 m .16322 .74515 L .17596 .74893 L p .707 .577 .707 r
F P
0 g
s
.66525 .82828 m .6623 .84713 L .63468 .84484 L p .707 .577 .707 r
F P
0 g
s
.16466 .6966 m .16341 .64195 L .1605 .63182 L p .707 .577 .707 r
F P
0 g
s
.35493 .78185 m .35198 .8007 L .35801 .80561 L p .707 .577 .707 r
F P
0 g
s
.36144 .62178 m .36269 .67643 L .35704 .67233 L p .707 .577 .707 r
F P
0 g
s
.35704 .67233 m .35009 .66728 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35908 .63124 m .36144 .62178 L .35704 .67233 L .707 .577 .707 r
F
.35009 .66728 m .34883 .61263 L .35961 .62046 L p F P
0 g
s
.35961 .62046 m .36144 .62178 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35009 .66728 m .35961 .62046 L .35908 .63124 L .707 .577 .707 r
F
.35939 .72134 m .35676 .75953 L .36364 .75691 L p F P
0 g
s
.36364 .75691 m .36628 .71872 L .35939 .72134 L p .707 .577 .707 r
F P
0 g
s
.3632 .71536 m .36056 .75354 L .35559 .75207 L p .707 .577 .707 r
F P
0 g
s
.35559 .75207 m .34783 .74977 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.35547 .73265 m .3632 .71536 L .35559 .75207 L .707 .577 .707 r
F
.34783 .74977 m .35046 .71158 L .35536 .71303 L p F P
0 g
s
.35536 .71303 m .3632 .71536 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.34783 .74977 m .35536 .71303 L .35547 .73265 L .707 .577 .707 r
F
.35437 .72609 m .35511 .67036 L .35135 .787 L F
.35511 .67036 m .3604 .27382 L .35469 .59736 L F
.35511 .67036 m .35469 .59736 L .35135 .787 L F
.34938 .78229 m .35135 .787 L p .35469 .59736 L F P
0 g
s
.3604 .27382 m .35442 .54973 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35442 .54973 m .34938 .78229 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35801 .80561 m .36097 .78676 L .35493 .78185 L p .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .34378 .79182 L .35634 .79029 L p .707 .577 .707 r
F P
0 g
s
.35634 .79029 m .35713 .7902 L p .35639 .79112 L .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .35634 .79029 L .35639 .79112 L .707 .577 .707 r
F
.35135 .787 m .35349 .79212 L p .35406 .74939 L F P
0 g
s
.35406 .74939 m .35437 .72609 L .35361 .74137 L .707 .577 .707 r
F
.35406 .74939 m .35361 .74137 L .35135 .787 L F
.36452 .28365 m .3604 .27382 L p .35437 .72609 L F P
0 g
s
.35349 .79212 m .35535 .70637 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.35535 .70637 m .36452 .28365 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.36435 .63192 m .36561 .68657 L .36269 .67643 L p .707 .577 .707 r
F P
0 g
s
.36269 .67643 m .36144 .62178 L .36435 .63192 L p .707 .577 .707 r
F P
0 g
s
.36628 .71872 m .36364 .75691 L .36056 .75354 L p .707 .577 .707 r
F P
0 g
s
.36056 .75354 m .3632 .71536 L .36628 .71872 L p .707 .577 .707 r
F P
0 g
s
.36097 .78676 m .35801 .80561 L .35417 .80905 L p .707 .577 .707 r
F P
0 g
s
.35417 .80905 m .35713 .7902 L .36097 .78676 L p .707 .577 .707 r
F P
0 g
s
.35713 .7902 m .35417 .80905 L .34083 .81067 L p .707 .577 .707 r
F P
0 g
s
.36452 .28365 m .35349 .79212 L .37129 .80149 L p .707 .577 .707 r
F P
0 g
s
.63468 .84484 m .63763 .82599 L .66525 .82828 L p .707 .577 .707 r
F P
0 g
s
.57527 .81666 m .57232 .83551 L .54369 .82939 L p .707 .577 .707 r
F P
0 g
s
.63763 .82599 m .63468 .84484 L .60367 .84084 L p .707 .577 .707 r
F P
0 g
s
.60367 .84084 m .60662 .82199 L .63763 .82599 L p .707 .577 .707 r
F P
0 g
s
.1605 .63182 m .16175 .68646 L .16466 .6966 L p .707 .577 .707 r
F P
0 g
s
.60662 .82199 m .60367 .84084 L .57232 .83551 L p .707 .577 .707 r
F P
0 g
s
.57232 .83551 m .57527 .81666 L .60662 .82199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16322 .74515 m .16586 .70697 L .16278 .7036 L p .707 .577 .707 r
F P
0 g
s
.15917 .75657 m .15621 .77542 L .16006 .77199 L p .707 .577 .707 r
F P
0 g
s
.16006 .77199 m .16301 .75314 L .15917 .75657 L p .707 .577 .707 r
F P
0 g
s
.6482 .28388 m .63718 .79235 L .63307 .78251 L p .707 .577 .707 r
F P
0 g
s
.63307 .78251 m .64409 .27404 L .6482 .28388 L p .707 .577 .707 r
F P
0 g
s
.16278 .7036 m .16015 .74179 L .16322 .74515 L p .707 .577 .707 r
F P
0 g
s
.16175 .68646 m .1605 .63182 L .16756 .62169 L p .707 .577 .707 r
F P
0 g
s
.34938 .78229 m .3604 .27382 L .37038 .26447 L p .707 .577 .707 r
F P
0 g
s
.16756 .62169 m .16881 .67633 L .16175 .68646 L p .707 .577 .707 r
F P
0 g
s
.16015 .74179 m .16278 .7036 L .16966 .70098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1652 .76148 m .16225 .78034 L .15621 .77542 L p .707 .577 .707 r
F P
0 g
s
.15621 .77542 m .15917 .75657 L .1652 .76148 L p .707 .577 .707 r
F P
0 g
s
.16881 .67633 m .16756 .62169 L .18391 .61255 L p .707 .577 .707 r
F P
0 g
s
.16966 .70098 m .16703 .73917 L .16015 .74179 L p .707 .577 .707 r
F P
0 g
s
.64409 .27404 m .63307 .78251 L .61527 .77315 L p .707 .577 .707 r
F P
0 g
s
.61527 .77315 m .62629 .26468 L .64409 .27404 L p .707 .577 .707 r
F P
0 g
s
.34883 .61263 m .35009 .66728 L .32902 .66001 L p .707 .577 .707 r
F P
0 g
s
.32902 .66001 m .32777 .60537 L .34883 .61263 L p .707 .577 .707 r
F P
0 g
s
.18391 .61255 m .18516 .6672 L .16881 .67633 L p .707 .577 .707 r
F P
0 g
s
.18516 .6672 m .18391 .61255 L .20794 .60531 L p .707 .577 .707 r
F P
0 g
s
.16703 .73917 m .16966 .70098 L .18583 .69935 L p .707 .577 .707 r
F P
0 g
s
.35935 .77294 m .37038 .26447 L .39346 .25654 L p .707 .577 .707 r
F P
0 g
s
.37038 .26447 m .35935 .77294 L .34938 .78229 L p .707 .577 .707 r
F P
0 g
s
.18052 .76739 m .17757 .78624 L .16225 .78034 L p .707 .577 .707 r
F P
0 g
s
.16225 .78034 m .1652 .76148 L .18052 .76739 L p .707 .577 .707 r
F P
0 g
s
.18583 .69935 m .1832 .73754 L .16703 .73917 L p .707 .577 .707 r
F P
0 g
s
.32777 .60537 m .32902 .66001 L .30156 .65534 L p .707 .577 .707 r
F P
0 g
s
.30156 .65534 m .30031 .6007 L .32777 .60537 L p .707 .577 .707 r
F P
0 g
s
.20794 .60531 m .2092 .65995 L .18516 .6672 L p .707 .577 .707 r
F P
0 g
s
.2092 .65995 m .20794 .60531 L .23731 .60067 L p .707 .577 .707 r
F P
0 g
s
.35046 .71158 m .34783 .74977 L .32668 .74595 L p .707 .577 .707 r
F P
0 g
s
.32668 .74595 m .32931 .70777 L .35046 .71158 L p .707 .577 .707 r
F P
0 g
s
.34378 .79182 m .34083 .81067 L .31929 .81032 L p .707 .577 .707 r
F P
0 g
s
.31929 .81032 m .32224 .79147 L .34378 .79182 L p .707 .577 .707 r
F P
0 g
s
.62629 .26468 m .61527 .77315 L .58553 .76517 L p .707 .577 .707 r
F P
0 g
s
.58553 .76517 m .59656 .2567 L .62629 .26468 L p .707 .577 .707 r
F P
0 g
s
.30031 .6007 m .30156 .65534 L .27039 .65372 L p .707 .577 .707 r
F P
0 g
s
.27039 .65372 m .26914 .59908 L .30031 .6007 L p .707 .577 .707 r
F P
0 g
s
.1832 .73754 m .18583 .69935 L .2097 .69888 L p .707 .577 .707 r
F P
0 g
s
.23856 .65531 m .23731 .60067 L .26914 .59908 L p .707 .577 .707 r
F P
0 g
s
.23731 .60067 m .23856 .65531 L .2092 .65995 L p .707 .577 .707 r
F P
0 g
s
.20363 .77372 m .20068 .79257 L .17757 .78624 L p .707 .577 .707 r
F P
0 g
s
.17757 .78624 m .18052 .76739 L .20363 .77372 L p .707 .577 .707 r
F P
0 g
s
.2097 .69888 m .20707 .73707 L .1832 .73754 L p .707 .577 .707 r
F P
0 g
s
.26914 .59908 m .27039 .65372 L .23856 .65531 L p .707 .577 .707 r
F P
0 g
s
.73718 .65653 m .73593 .60188 L .70476 .60026 L p .707 .577 .707 r
F P
0 g
s
.73593 .60188 m .73718 .65653 L .76901 .65494 L p .707 .577 .707 r
F P
0 g
s
.76901 .65494 m .76775 .6003 L .73593 .60188 L p .707 .577 .707 r
F P
0 g
s
.76775 .6003 m .76901 .65494 L .79837 .6503 L p .707 .577 .707 r
F P
0 g
s
.79837 .6503 m .79712 .59565 L .76775 .6003 L p .707 .577 .707 r
F P
0 g
s
.39346 .25654 m .38243 .76501 L .35935 .77294 L p .707 .577 .707 r
F P
0 g
s
.38243 .76501 m .39346 .25654 L .42739 .25078 L p .707 .577 .707 r
F P
0 g
s
.32931 .70777 m .32668 .74595 L .29919 .74247 L p .707 .577 .707 r
F P
0 g
s
.29919 .74247 m .30182 .70428 L .32931 .70777 L p .707 .577 .707 r
F P
0 g
s
.70601 .65491 m .70476 .60026 L .6773 .59559 L p .707 .577 .707 r
F P
0 g
s
.70476 .60026 m .70601 .65491 L .73718 .65653 L p .707 .577 .707 r
F P
0 g
s
.32224 .79147 m .31929 .81032 L .29167 .80803 L p .707 .577 .707 r
F P
0 g
s
.29167 .80803 m .29462 .78918 L .32224 .79147 L p .707 .577 .707 r
F P
0 g
s
.20707 .73707 m .2097 .69888 L .23894 .69961 L p .707 .577 .707 r
F P
0 g
s
.79712 .59565 m .79837 .6503 L .82241 .64305 L p .707 .577 .707 r
F P
0 g
s
.82241 .64305 m .82116 .58841 L .79712 .59565 L p .707 .577 .707 r
F P
0 g
s
.23226 .77985 m .22931 .7987 L .20068 .79257 L p .707 .577 .707 r
F P
0 g
s
.20068 .79257 m .20363 .77372 L .23226 .77985 L p .707 .577 .707 r
F P
0 g
s
.23894 .69961 m .23631 .7378 L .20707 .73707 L p .707 .577 .707 r
F P
0 g
s
.73595 .69317 m .73859 .65498 L .70744 .65217 L p .707 .577 .707 r
F P
0 g
s
.73859 .65498 m .73595 .69317 L .7677 .69503 L p .707 .577 .707 r
F P
0 g
s
.7677 .69503 m .77033 .65685 L .73859 .65498 L p .707 .577 .707 r
F P
0 g
s
.59656 .2567 m .58553 .76517 L .54676 .75936 L p .707 .577 .707 r
F P
0 g
s
.54676 .75936 m .55779 .25089 L .59656 .2567 L p .707 .577 .707 r
F P
0 g
s
.67855 .65024 m .6773 .59559 L .65623 .58833 L p .707 .577 .707 r
F P
0 g
s
.6773 .59559 m .67855 .65024 L .70601 .65491 L p .707 .577 .707 r
F P
0 g
s
.30182 .70428 m .29919 .74247 L .26805 .73966 L p .707 .577 .707 r
F P
0 g
s
.26805 .73966 m .27068 .70147 L .30182 .70428 L p .707 .577 .707 r
F P
0 g
s
.77033 .65685 m .7677 .69503 L .79693 .69576 L p .707 .577 .707 r
F P
0 g
s
.79693 .69576 m .79957 .65758 L .77033 .65685 L p .707 .577 .707 r
F P
0 g
s
.29462 .78918 m .29167 .80803 L .26066 .80402 L p .707 .577 .707 r
F P
0 g
s
.70744 .65217 m .70481 .69036 L .73595 .69317 L p .707 .577 .707 r
F P
0 g
s
.23631 .7378 m .23894 .69961 L .27068 .70147 L p .707 .577 .707 r
F P
0 g
s
.70573 .69501 m .70278 .71386 L .73378 .71787 L p .707 .577 .707 r
F P
0 g
s
.73378 .71787 m .73674 .69901 L .70573 .69501 L p .707 .577 .707 r
F P
0 g
s
.73674 .69901 m .73378 .71787 L .76514 .72319 L p .707 .577 .707 r
F P
0 g
s
.26066 .80402 m .26361 .78517 L .29462 .78918 L p .707 .577 .707 r
F P
0 g
s
.70481 .69036 m .70744 .65217 L .67995 .64869 L p .707 .577 .707 r
F P
0 g
s
.26361 .78517 m .26066 .80402 L .22931 .7987 L p .707 .577 .707 r
F P
0 g
s
.22931 .7987 m .23226 .77985 L .26361 .78517 L p .707 .577 .707 r
F P
0 g
s
.76514 .72319 m .76809 .70434 L .73674 .69901 L p .707 .577 .707 r
F P
0 g
s
.27068 .70147 m .26805 .73966 L .23631 .7378 L p .707 .577 .707 r
F P
0 g
s
.76809 .70434 m .76514 .72319 L .79377 .72932 L p .707 .577 .707 r
F P
0 g
s
.67995 .64869 m .67732 .68688 L .70481 .69036 L p .707 .577 .707 r
F P
0 g
s
.41637 .75925 m .42739 .25078 L .46885 .24778 L p .707 .577 .707 r
F P
0 g
s
.42739 .25078 m .41637 .75925 L .38243 .76501 L p .707 .577 .707 r
F P
0 g
s
.79377 .72932 m .79672 .71047 L .76809 .70434 L p .707 .577 .707 r
F P
0 g
s
.6781 .69272 m .67515 .71157 L .70278 .71386 L p .707 .577 .707 r
F P
0 g
s
.70278 .71386 m .70573 .69501 L .6781 .69272 L p .707 .577 .707 r
F P
0 g
s
.82116 .58841 m .82241 .64305 L .83876 .63392 L p .707 .577 .707 r
F P
0 g
s
.83876 .63392 m .8375 .57927 L .82116 .58841 L p .707 .577 .707 r
F P
0 g
s
.79957 .65758 m .79693 .69576 L .82081 .69529 L p .707 .577 .707 r
F P
0 g
s
.82081 .69529 m .82344 .65711 L .79957 .65758 L p .707 .577 .707 r
F P
0 g
s
.65623 .58833 m .65748 .64297 L .67855 .65024 L p .707 .577 .707 r
F P
0 g
s
.79672 .71047 m .79377 .72932 L .81687 .73565 L p .707 .577 .707 r
F P
0 g
s
.67732 .68688 m .67995 .64869 L .65881 .64488 L p .707 .577 .707 r
F P
0 g
s
.55779 .25089 m .54676 .75936 L .50276 .75628 L p .707 .577 .707 r
F P
0 g
s
.50276 .75628 m .51378 .24781 L .55779 .25089 L p .707 .577 .707 r
F P
0 g
s
.81687 .73565 m .81983 .71679 L .79672 .71047 L p .707 .577 .707 r
F P
0 g
s
.65748 .64297 m .65623 .58833 L .64362 .57918 L p .707 .577 .707 r
F P
0 g
s
.65881 .64488 m .65617 .68306 L .67732 .68688 L p .707 .577 .707 r
F P
0 g
s
.65657 .69237 m .65361 .71122 L .67515 .71157 L p .707 .577 .707 r
F P
0 g
s
.67515 .71157 m .6781 .69272 L .65657 .69237 L p .707 .577 .707 r
F P
0 g
s
.45783 .75625 m .46885 .24778 L .51378 .24781 L p .707 .577 .707 r
F P
0 g
s
.46885 .24778 m .45783 .75625 L .41637 .75925 L p .707 .577 .707 r
F P
0 g
s
.51378 .24781 m .50276 .75628 L .45783 .75625 L p .707 .577 .707 r
F P
0 g
s
.82344 .65711 m .82081 .69529 L .83697 .69367 L p .707 .577 .707 r
F P
0 g
s
.83697 .69367 m .83961 .65548 L .82344 .65711 L p .707 .577 .707 r
F P
0 g
s
.8375 .57927 m .83876 .63392 L .84582 .62379 L p .707 .577 .707 r
F P
0 g
s
.84582 .62379 m .84457 .56914 L .8375 .57927 L p .707 .577 .707 r
F P
0 g
s
.81983 .71679 m .81687 .73565 L .83219 .74155 L p .707 .577 .707 r
F P
0 g
s
.64362 .57918 m .64488 .63382 L .65748 .64297 L p .707 .577 .707 r
F P
0 g
s
.83219 .74155 m .83515 .7227 L .81983 .71679 L p .707 .577 .707 r
F P
0 g
s
.65617 .68306 m .65881 .64488 L .64607 .6411 L p .707 .577 .707 r
F P
0 g
s
.64607 .6411 m .64344 .67929 L .65617 .68306 L p .707 .577 .707 r
F P
0 g
s
.64322 .69399 m .64027 .71284 L .65361 .71122 L p .707 .577 .707 r
F P
0 g
s
.65361 .71122 m .65657 .69237 L .64322 .69399 L p .707 .577 .707 r
F P
0 g
s
.64488 .63382 m .64362 .57918 L .64071 .56904 L p .707 .577 .707 r
F P
0 g
s
.83961 .65548 m .83697 .69367 L .84386 .69104 L p .707 .577 .707 r
F P
0 g
s
.84386 .69104 m .84649 .65286 L .83961 .65548 L p .707 .577 .707 r
F P
0 g
s
.84457 .56914 m .84582 .62379 L .84291 .61365 L p .707 .577 .707 r
F P
0 g
s
.84291 .61365 m .84165 .55901 L .84457 .56914 L p .707 .577 .707 r
F P
0 g
s
.83515 .7227 m .83219 .74155 L .83823 .74647 L p .707 .577 .707 r
F P
0 g
s
.64071 .56904 m .64196 .62369 L .64488 .63382 L p .707 .577 .707 r
F P
0 g
s
.83823 .74647 m .84118 .72762 L .83515 .7227 L p .707 .577 .707 r
F P
0 g
s
.64344 .67929 m .64607 .6411 L .64299 .63774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64299 .63774 m .64036 .67592 L .64344 .67929 L p .707 .577 .707 r
F P
0 g
s
.63938 .69743 m .63643 .71628 L .64027 .71284 L p .707 .577 .707 r
F P
0 g
s
.64027 .71284 m .64322 .69399 L .63938 .69743 L p .707 .577 .707 r
F P
0 g
s
.64196 .62369 m .64071 .56904 L .64777 .55891 L p .707 .577 .707 r
F P
0 g
s
.84649 .65286 m .84386 .69104 L .84078 .68768 L p .707 .577 .707 r
F P
0 g
s
.84078 .68768 m .84341 .64949 L .84649 .65286 L p .707 .577 .707 r
F P
0 g
s
.84165 .55901 m .84291 .61365 L .8303 .6045 L p .707 .577 .707 r
F P
0 g
s
.8303 .6045 m .82905 .54986 L .84165 .55901 L p .707 .577 .707 r
F P
0 g
s
.64777 .55891 m .64903 .61355 L .64196 .62369 L p .707 .577 .707 r
F P
0 g
s
.84118 .72762 m .83823 .74647 L .83439 .7499 L p .707 .577 .707 r
F P
0 g
s
.83439 .7499 m .83734 .73105 L .84118 .72762 L p .707 .577 .707 r
F P
0 g
s
.64036 .67592 m .64299 .63774 L .64988 .63511 L p .707 .577 .707 r
F P
0 g
s
.39417 .61971 m .39292 .56507 L .36175 .56345 L p .707 .577 .707 r
F P
0 g
s
.39292 .56507 m .39417 .61971 L .426 .61813 L p .707 .577 .707 r
F P
0 g
s
.426 .61813 m .42474 .56348 L .39292 .56507 L p .707 .577 .707 r
F P
0 g
s
.64988 .63511 m .64724 .6733 L .64036 .67592 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64903 .61355 m .64777 .55891 L .66412 .54977 L p .707 .577 .707 r
F P
0 g
s
.64542 .70234 m .64246 .72119 L .63643 .71628 L p .707 .577 .707 r
F P
0 g
s
.63643 .71628 m .63938 .69743 L .64542 .70234 L p .707 .577 .707 r
F P
0 g
s
.42474 .56348 m .426 .61813 L .45536 .61348 L p .707 .577 .707 r
F P
0 g
s
.45536 .61348 m .45411 .55884 L .42474 .56348 L p .707 .577 .707 r
F P
0 g
s
.363 .61809 m .36175 .56345 L .33429 .55878 L p .707 .577 .707 r
F P
0 g
s
.36175 .56345 m .363 .61809 L .39417 .61971 L p .707 .577 .707 r
F P
0 g
s
.45411 .55884 m .45536 .61348 L .4794 .60624 L p .707 .577 .707 r
F P
0 g
s
.4794 .60624 m .47815 .55159 L .45411 .55884 L p .707 .577 .707 r
F P
0 g
s
.82905 .54986 m .8303 .6045 L .80924 .59724 L p .707 .577 .707 r
F P
0 g
s
.80924 .59724 m .80798 .54259 L .82905 .54986 L p .707 .577 .707 r
F P
0 g
s
.84341 .64949 m .84078 .68768 L .82804 .6839 L p .707 .577 .707 r
F P
0 g
s
.82804 .6839 m .83068 .64572 L .84341 .64949 L p .707 .577 .707 r
F P
0 g
s
.66412 .54977 m .66538 .60442 L .64903 .61355 L p .707 .577 .707 r
F P
0 g
s
.39294 .65635 m .39558 .61817 L .36443 .61536 L p .707 .577 .707 r
F P
0 g
s
.39558 .61817 m .39294 .65635 L .42469 .65822 L p .707 .577 .707 r
F P
0 g
s
.42469 .65822 m .42732 .62003 L .39558 .61817 L p .707 .577 .707 r
F P
0 g
s
.83734 .73105 m .83439 .7499 L .82104 .75152 L p .707 .577 .707 r
F P
0 g
s
.33554 .61342 m .33429 .55878 L .31322 .55151 L p .707 .577 .707 r
F P
0 g
s
.33429 .55878 m .33554 .61342 L .363 .61809 L p .707 .577 .707 r
F P
0 g
s
.82104 .75152 m .824 .73267 L .83734 .73105 L p .707 .577 .707 r
F P
0 g
s
.42732 .62003 m .42469 .65822 L .45392 .65895 L p .707 .577 .707 r
F P
0 g
s
.45392 .65895 m .45656 .62076 L .42732 .62003 L p .707 .577 .707 r
F P
0 g
s
.36443 .61536 m .3618 .65355 L .39294 .65635 L p .707 .577 .707 r
F P
0 g
s
.36272 .6582 m .35977 .67705 L .39077 .68105 L p .707 .577 .707 r
F P
0 g
s
.39077 .68105 m .39373 .6622 L .36272 .6582 L p .707 .577 .707 r
F P
0 g
s
.39373 .6622 m .39077 .68105 L .42213 .68638 L p .707 .577 .707 r
F P
0 g
s
.66538 .60442 m .66412 .54977 L .68816 .54253 L p .707 .577 .707 r
F P
0 g
s
.64724 .6733 m .64988 .63511 L .66604 .63349 L p .707 .577 .707 r
F P
0 g
s
.3618 .65355 m .36443 .61536 L .33694 .61188 L p .707 .577 .707 r
F P
0 g
s
.42213 .68638 m .42508 .66752 L .39373 .6622 L p .707 .577 .707 r
F P
0 g
s
.42508 .66752 m .42213 .68638 L .45076 .6925 L p .707 .577 .707 r
F P
0 g
s
.66604 .63349 m .66341 .67167 L .64724 .6733 L p .707 .577 .707 r
F P
0 g
s
.33694 .61188 m .33431 .65006 L .3618 .65355 L p .707 .577 .707 r
F P
0 g
s
.66074 .70825 m .65778 .7271 L .64246 .72119 L p .707 .577 .707 r
F P
0 g
s
.64246 .72119 m .64542 .70234 L .66074 .70825 L p .707 .577 .707 r
F P
0 g
s
.45076 .6925 m .45371 .67365 L .42508 .66752 L p .707 .577 .707 r
F P
0 g
s
.33509 .65591 m .33214 .67476 L .35977 .67705 L p .707 .577 .707 r
F P
0 g
s
.35977 .67705 m .36272 .6582 L .33509 .65591 L p .707 .577 .707 r
F P
0 g
s
.47815 .55159 m .4794 .60624 L .49575 .5971 L p .707 .577 .707 r
F P
0 g
s
.49575 .5971 m .49449 .54246 L .47815 .55159 L p .707 .577 .707 r
F P
0 g
s
.45656 .62076 m .45392 .65895 L .4778 .65848 L p .707 .577 .707 r
F P
0 g
s
.4778 .65848 m .48043 .62029 L .45656 .62076 L p .707 .577 .707 r
F P
0 g
s
.80798 .54259 m .80924 .59724 L .78177 .59256 L p .707 .577 .707 r
F P
0 g
s
.78177 .59256 m .78052 .53792 L .80798 .54259 L p .707 .577 .707 r
F P
0 g
s
.31322 .55151 m .31447 .60616 L .33554 .61342 L p .707 .577 .707 r
F P
0 g
s
.45371 .67365 m .45076 .6925 L .47386 .69883 L p .707 .577 .707 r
F P
0 g
s
.33431 .65006 m .33694 .61188 L .3158 .60806 L p .707 .577 .707 r
F P
0 g
s
.47386 .69883 m .47682 .67998 L .45371 .67365 L p .707 .577 .707 r
F P
0 g
s
.68816 .54253 m .68941 .59718 L .66538 .60442 L p .707 .577 .707 r
F P
0 g
s
.31447 .60616 m .31322 .55151 L .30061 .54236 L p .707 .577 .707 r
F P
0 g
s
.83068 .64572 m .82804 .6839 L .80689 .68009 L p .707 .577 .707 r
F P
0 g
s
.80689 .68009 m .80953 .6419 L .83068 .64572 L p .707 .577 .707 r
F P
0 g
s
.68941 .59718 m .68816 .54253 L .71752 .53789 L p .707 .577 .707 r
F P
0 g
s
.3158 .60806 m .31316 .64625 L .33431 .65006 L p .707 .577 .707 r
F P
0 g
s
.31356 .65556 m .3106 .67441 L .33214 .67476 L p .707 .577 .707 r
F P
0 g
s
.33214 .67476 m .33509 .65591 L .31356 .65556 L p .707 .577 .707 r
F P
0 g
s
.824 .73267 m .82104 .75152 L .79951 .75117 L p .707 .577 .707 r
F P
0 g
s
.79951 .75117 m .80246 .73232 L .824 .73267 L p .707 .577 .707 r
F P
0 g
s
.78052 .53792 m .78177 .59256 L .7506 .59094 L p .707 .577 .707 r
F P
0 g
s
.7506 .59094 m .74935 .5363 L .78052 .53792 L p .707 .577 .707 r
F P
0 g
s
.66341 .67167 m .66604 .63349 L .68992 .63302 L p .707 .577 .707 r
F P
0 g
s
.71878 .59253 m .71752 .53789 L .74935 .5363 L p .707 .577 .707 r
F P
0 g
s
.71752 .53789 m .71878 .59253 L .68941 .59718 L p .707 .577 .707 r
F P
0 g
s
.68992 .63302 m .68728 .6712 L .66341 .67167 L p .707 .577 .707 r
F P
0 g
s
.48043 .62029 m .4778 .65848 L .49396 .65685 L p .707 .577 .707 r
F P
0 g
s
.49396 .65685 m .4966 .61866 L .48043 .62029 L p .707 .577 .707 r
F P
0 g
s
.68384 .71458 m .68089 .73343 L .65778 .7271 L p .707 .577 .707 r
F P
0 g
s
.65778 .7271 m .66074 .70825 L .68384 .71458 L p .707 .577 .707 r
F P
0 g
s
.49449 .54246 m .49575 .5971 L .50281 .58697 L p .707 .577 .707 r
F P
0 g
s
.50281 .58697 m .50156 .53233 L .49449 .54246 L p .707 .577 .707 r
F P
0 g
s
.74935 .5363 m .7506 .59094 L .71878 .59253 L p .707 .577 .707 r
F P
0 g
s
.47682 .67998 m .47386 .69883 L .48918 .70474 L p .707 .577 .707 r
F P
0 g
s
.30061 .54236 m .30187 .59701 L .31447 .60616 L p .707 .577 .707 r
F P
0 g
s
.48918 .70474 m .49214 .68589 L .47682 .67998 L p .707 .577 .707 r
F P
0 g
s
.31316 .64625 m .3158 .60806 L .30306 .60429 L p .707 .577 .707 r
F P
0 g
s
.80953 .6419 m .80689 .68009 L .7794 .67661 L p .707 .577 .707 r
F P
0 g
s
.7794 .67661 m .78204 .63842 L .80953 .6419 L p .707 .577 .707 r
F P
0 g
s
.30306 .60429 m .30043 .64247 L .31316 .64625 L p .707 .577 .707 r
F P
0 g
s
.30021 .65718 m .29726 .67603 L .3106 .67441 L p .707 .577 .707 r
F P
0 g
s
.3106 .67441 m .31356 .65556 L .30021 .65718 L p .707 .577 .707 r
F P
0 g
s
.30187 .59701 m .30061 .54236 L .2977 .53222 L p .707 .577 .707 r
F P
0 g
s
.80246 .73232 m .79951 .75117 L .77188 .74888 L p .707 .577 .707 r
F P
0 g
s
.68728 .6712 m .68992 .63302 L .71915 .63375 L p .707 .577 .707 r
F P
0 g
s
.77188 .74888 m .77483 .73003 L .80246 .73232 L p .707 .577 .707 r
F P
0 g
s
.71915 .63375 m .71652 .67193 L .68728 .6712 L p .707 .577 .707 r
F P
0 g
s
.71247 .7207 m .70952 .73955 L .68089 .73343 L p .707 .577 .707 r
F P
0 g
s
.68089 .73343 m .68384 .71458 L .71247 .7207 L p .707 .577 .707 r
F P
0 g
s
.78204 .63842 m .7794 .67661 L .74826 .6738 L p .707 .577 .707 r
F P
0 g
s
.74826 .6738 m .7509 .63561 L .78204 .63842 L p .707 .577 .707 r
F P
0 g
s
.4966 .61866 m .49396 .65685 L .50085 .65423 L p .707 .577 .707 r
F P
0 g
s
.50085 .65423 m .50348 .61604 L .4966 .61866 L p .707 .577 .707 r
F P
0 g
s
.71652 .67193 m .71915 .63375 L .7509 .63561 L p .707 .577 .707 r
F P
0 g
s
.50156 .53233 m .50281 .58697 L .4999 .57684 L p .707 .577 .707 r
F P
0 g
s
.4999 .57684 m .49864 .52219 L .50156 .53233 L p .707 .577 .707 r
F P
0 g
s
.77483 .73003 m .77188 .74888 L .74087 .74488 L p .707 .577 .707 r
F P
0 g
s
.49214 .68589 m .48918 .70474 L .49522 .70965 L p .707 .577 .707 r
F P
0 g
s
.2977 .53222 m .29895 .58687 L .30187 .59701 L p .707 .577 .707 r
F P
0 g
s
.7509 .63561 m .74826 .6738 L .71652 .67193 L p .707 .577 .707 r
F P
0 g
s
.74087 .74488 m .74383 .72603 L .77483 .73003 L p .707 .577 .707 r
F P
0 g
s
.74383 .72603 m .74087 .74488 L .70952 .73955 L p .707 .577 .707 r
F P
0 g
s
.70952 .73955 m .71247 .7207 L .74383 .72603 L p .707 .577 .707 r
F P
0 g
s
.49522 .70965 m .49817 .6908 L .49214 .68589 L p .707 .577 .707 r
F P
0 g
s
.30043 .64247 m .30306 .60429 L .29998 .60092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29998 .60092 m .29735 .63911 L .30043 .64247 L p .707 .577 .707 r
F P
0 g
s
.29637 .66061 m .29342 .67946 L .29726 .67603 L p .707 .577 .707 r
F P
0 g
s
.29726 .67603 m .30021 .65718 L .29637 .66061 L p .707 .577 .707 r
F P
0 g
s
.29895 .58687 m .2977 .53222 L .30476 .52209 L p .707 .577 .707 r
F P
0 g
s
.50348 .61604 m .50085 .65423 L .49777 .65086 L p .707 .577 .707 r
F P
0 g
s
.49777 .65086 m .5004 .61268 L .50348 .61604 L p .707 .577 .707 r
F P
0 g
s
.49864 .52219 m .4999 .57684 L .48729 .56769 L p .707 .577 .707 r
F P
0 g
s
.48729 .56769 m .48604 .51304 L .49864 .52219 L p .707 .577 .707 r
F P
0 g
s
.30476 .52209 m .30602 .57674 L .29895 .58687 L p .707 .577 .707 r
F P
0 g
s
.49817 .6908 m .49522 .70965 L .49138 .71309 L p .707 .577 .707 r
F P
0 g
s
.49138 .71309 m .49433 .69424 L .49817 .6908 L p .707 .577 .707 r
F P
0 g
s
.29735 .63911 m .29998 .60092 L .30686 .5983 L p .707 .577 .707 r
F P
0 g
s
.30686 .5983 m .30423 .63649 L .29735 .63911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30602 .57674 m .30476 .52209 L .32111 .51296 L p .707 .577 .707 r
F P
0 g
s
.3024 .66552 m .29945 .68438 L .29342 .67946 L p .707 .577 .707 r
F P
0 g
s
.29342 .67946 m .29637 .66061 L .3024 .66552 L p .707 .577 .707 r
F P
0 g
s
.48604 .51304 m .48729 .56769 L .46622 .56042 L p .707 .577 .707 r
F P
0 g
s
.46622 .56042 m .46497 .50577 L .48604 .51304 L p .707 .577 .707 r
F P
0 g
s
.5004 .61268 m .49777 .65086 L .48503 .64709 L p .707 .577 .707 r
F P
0 g
s
.48503 .64709 m .48767 .6089 L .5004 .61268 L p .707 .577 .707 r
F P
0 g
s
.32111 .51296 m .32236 .5676 L .30602 .57674 L p .707 .577 .707 r
F P
0 g
s
.49433 .69424 m .49138 .71309 L .47803 .71471 L p .707 .577 .707 r
F P
0 g
s
.47803 .71471 m .48099 .69586 L .49433 .69424 L p .707 .577 .707 r
F P
0 g
s
.32236 .5676 m .32111 .51296 L .34515 .50572 L p .707 .577 .707 r
F P
0 g
s
.30423 .63649 m .30686 .5983 L .32303 .59667 L p .707 .577 .707 r
F P
0 g
s
.32303 .59667 m .3204 .63486 L .30423 .63649 L p .707 .577 .707 r
F P
0 g
s
.31772 .67143 m .31477 .69028 L .29945 .68438 L p .707 .577 .707 r
F P
0 g
s
.29945 .68438 m .3024 .66552 L .31772 .67143 L p .707 .577 .707 r
F P
0 g
s
.46497 .50577 m .46622 .56042 L .43876 .55575 L p .707 .577 .707 r
F P
0 g
s
.43876 .55575 m .43751 .5011 L .46497 .50577 L p .707 .577 .707 r
F P
0 g
s
.34515 .50572 m .3464 .56036 L .32236 .5676 L p .707 .577 .707 r
F P
0 g
s
.48767 .6089 m .48503 .64709 L .46388 .64327 L p .707 .577 .707 r
F P
0 g
s
.46388 .64327 m .46652 .60509 L .48767 .6089 L p .707 .577 .707 r
F P
0 g
s
.3464 .56036 m .34515 .50572 L .37451 .50107 L p .707 .577 .707 r
F P
0 g
s
.48099 .69586 m .47803 .71471 L .45649 .71436 L p .707 .577 .707 r
F P
0 g
s
.45649 .71436 m .45945 .69551 L .48099 .69586 L p .707 .577 .707 r
F P
0 g
s
.43751 .5011 m .43876 .55575 L .40759 .55413 L p .707 .577 .707 r
F P
0 g
s
.40759 .55413 m .40634 .49948 L .43751 .5011 L p .707 .577 .707 r
F P
0 g
s
.3204 .63486 m .32303 .59667 L .3469 .5962 L p .707 .577 .707 r
F P
0 g
s
.37577 .55572 m .37451 .50107 L .40634 .49948 L p .707 .577 .707 r
F P
0 g
s
.37451 .50107 m .37577 .55572 L .3464 .56036 L p .707 .577 .707 r
F P
0 g
s
.3469 .5962 m .34427 .63439 L .3204 .63486 L p .707 .577 .707 r
F P
0 g
s
.34083 .67776 m .33788 .69661 L .31477 .69028 L p .707 .577 .707 r
F P
0 g
s
.31477 .69028 m .31772 .67143 L .34083 .67776 L p .707 .577 .707 r
F P
0 g
s
.40634 .49948 m .40759 .55413 L .37577 .55572 L p .707 .577 .707 r
F P
0 g
s
.46652 .60509 m .46388 .64327 L .43639 .63979 L p .707 .577 .707 r
F P
0 g
s
.43639 .63979 m .43903 .6016 L .46652 .60509 L p .707 .577 .707 r
F P
0 g
s
.45945 .69551 m .45649 .71436 L .42887 .71207 L p .707 .577 .707 r
F P
0 g
s
.34427 .63439 m .3469 .5962 L .37614 .59693 L p .707 .577 .707 r
F P
0 g
s
.42887 .71207 m .43182 .69322 L .45945 .69551 L p .707 .577 .707 r
F P
0 g
s
.37614 .59693 m .37351 .63512 L .34427 .63439 L p .707 .577 .707 r
F P
0 g
s
.36946 .68389 m .36651 .70274 L .33788 .69661 L p .707 .577 .707 r
F P
0 g
s
.33788 .69661 m .34083 .67776 L .36946 .68389 L p .707 .577 .707 r
F P
0 g
s
.43903 .6016 m .43639 .63979 L .40525 .63698 L p .707 .577 .707 r
F P
0 g
s
.40525 .63698 m .40789 .59879 L .43903 .6016 L p .707 .577 .707 r
F P
0 g
s
.37351 .63512 m .37614 .59693 L .40789 .59879 L p .707 .577 .707 r
F P
0 g
s
.43182 .69322 m .42887 .71207 L .39786 .70806 L p .707 .577 .707 r
F P
0 g
s
.40789 .59879 m .40525 .63698 L .37351 .63512 L p .707 .577 .707 r
F P
0 g
s
.39786 .70806 m .40082 .68921 L .43182 .69322 L p .707 .577 .707 r
F P
0 g
s
.40082 .68921 m .39786 .70806 L .36651 .70274 L p .707 .577 .707 r
F P
0 g
s
.36651 .70274 m .36946 .68389 L .40082 .68921 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001aOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00JWoo001W
Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`80009JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP0000005`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001QOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000BOolE000nOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000moo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo10001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000c
Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEPT000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH70005FUH00`00FUH000020005FUH0
1000FUIJEUYF100000=JEP000000100015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001D
Ool00`00FUH00004FUH00`00FUH000030004FUHF0006FUH00`00FUIJEP02FUH300000eYF001JEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001DOol00`00FUH00004FUH20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002aoo`00E7oo00<005YF00000UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000/Ool005Aoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;7oo001DOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000/Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP8002aoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Eoo`04001JEUYFFUHF00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000AJEP03001JEUYF009JEPH000Uoo`<000]oo`T000=JEP04001JEUYF
FUH2000/Ool0049ooaP00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH0
05YF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YF00000P000UYF2@000goo1@00
00=oo`0000001`000eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P00;7oo000nOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF0P0000=JEP00FUH01UYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;7oo000jOol4
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002
FUH2000/Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;7oo000cOol30005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009JEQH000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000090001eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF1P001EYF00<005YFFUH015YF00<005YFFUH01UYF4@000eYF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP04001JEP00
000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT0039oo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH0
05YF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05000_Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH01EYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH<0005OolD0002FUH01000FUIJEUYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH01P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000Moo`D000Qoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH80002
FUH00`00FUIJEP04FUHF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000]Ool01000FUIJ
EP000eYF00<005YF00000`000UYF20000goo1@0000=oo`0000001`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00@005YFFUIJEPT000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP050005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH60009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00@005YF
FUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001J
EP00FUH00002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;7oo000]Ool00`00FUIJEP030005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
00001@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0035YF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002P001UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01P00FUIJEP00FUH000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJ
EP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000030009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP050003FUH7
0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P00;Goo000]
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH600000eYF000000050002FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF0000000]Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF000000050004FUH00`00FUIJEP04FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH0100015YF1P0015YF00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005P0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002ioo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH500000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUHG000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH01000FUIJEUYF:`00;Woo000^Ool01000
FUIJEUYF5P0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL004Uoo`00;goo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YF00001`001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00AJEP@0009JEP03001JEUYF009JEP@0009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF1000@Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000goo00@005YFFUH000EJEP03
001JEUYF00H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00?Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03
FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00004FUH00`00FUH0000<0006FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000g
Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH=0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH500000eYF000000050002FUH40005FUH00`00FUIJEP06
FUH01000FUIJEUYF1000<goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJEP04001JEUYFFUH7
00000goo000000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000aOol002eoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0>0006FUH00`00FUIJEP05FUH0
0`00FUIJEP02000_Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH;0005FUH01000FUIJEUYF1000
;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUIJEUYF300000AJEP00FUH002eoo`00;Goo00<005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00;Goo1P001EYF
00<005YFFUH015YF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P001UYF0`000Woo1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH0
05YF00000eYF20002goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002io
o`00<7oo100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1P000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00MJEP03001JEUYF00D0011oo`P000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`/0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03
FUH01000FUH000005Woo3`00;goo000^Ool300000eYF001JEP04FUH01000FUIJEUYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03FUH00`00FUIJEP02
001COol002eoo`8000=JEP03001JEUYF009JEP8000IJEP8000=JEPX000=JEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHZ0008FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00001eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo
000]Ool300000eYF001JEP04FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP0I0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000025YF00<005YFFUH00eYF00<005YFFUH0
0P00Dgoo000]Ool200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH6000>Ool01000FUIJEP0015YF10000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF00@005YF000000MJEP03001J
EUYF00AJEP03001JEUYF008005=oo`00;7oo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`05001JEUYF001JEP030007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP02FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00;7oo00<005YF
000015YF00<005YF00003P0015YF0`001UYF00<005YFFUH01EYF00<005YF00000`0017oo00<005YF
FUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF
00<005YFFUH01UYF100015YF00@005YF000000MJEP03001JEUYF00=JEP06001JEUYF001JEP00Dgoo
000/Ool00`00FUH00004FUH00`00FUIJEP02FUH60006Ool80005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20002Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00@005YF000000MJEP03
001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF
1P000goo20000UYF00<005YFFUH01EYF00<005YFFUH015YF1@0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0000=JEP0000000`0015YF00<005YFFUH00eYF00<005YFFUH00P00E7oo000_Ool20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070003Ool40006FUH00`00FUIJEP04FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH70003FUH00`00
FUIJEP02001DOol0035oo`<000EJEP03001JEUYF00IJEP03001JEUYF00=JEPL000Aoo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF1@0000=JEP000000E7oo000dOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH=0003FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF000000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003Qoo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH?0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001DOol003]oo`@0009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001J
EP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF2@00EGoo000oOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002Ool8001NOol004Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005
Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YF00000`00I7oo001>Ool80004FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0027oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00=JEP@0061oo`00EWoo3`00
37oo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF0`00
1EYF00<005YFFUH01UYF00<005YF00000`00G7oo001hOol;0006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3001IOol008=ooaX000AJEPL00003Ool0
000000T000IJEP03001JEUYF00EJEP03001JEP00008005Ioo`00T7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF2@000goo10000UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00TWoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2`001EYF00<005YF
FUH00UYF00<005YF0000E7oo002GOol50006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF4000E7oo002LOol40002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002POol50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000EGoo002UOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo002YOol70004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00EGoo002`OolG001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59998 .75612 m .59872 .70148 L .56755 .69986 L p .707 .577 .707 r
F P
0 g
s
.59872 .70148 m .59998 .75612 L .6318 .75453 L p .707 .577 .707 r
F P
0 g
s
.6318 .75453 m .63055 .69989 L .59872 .70148 L p .707 .577 .707 r
F P
0 g
s
.63055 .69989 m .6318 .75453 L .66117 .74989 L p .707 .577 .707 r
F P
0 g
s
.66117 .74989 m .65992 .69524 L .63055 .69989 L p .707 .577 .707 r
F P
0 g
s
.56881 .7545 m .56755 .69986 L .54009 .69518 L p .707 .577 .707 r
F P
0 g
s
.56755 .69986 m .56881 .7545 L .59998 .75612 L p .707 .577 .707 r
F P
0 g
s
.65992 .69524 m .66117 .74989 L .6852 .74265 L p .707 .577 .707 r
F P
0 g
s
.6852 .74265 m .68395 .688 L .65992 .69524 L p .707 .577 .707 r
F P
0 g
s
.59875 .79585 m .60138 .75766 L .57024 .75485 L p .707 .577 .707 r
F P
0 g
s
.60138 .75766 m .59875 .79585 L .60461 .79619 L p .707 .577 .707 r
F P
0 g
s
.57024 .75485 m .56761 .79304 L .57274 .7935 L p .707 .577 .707 r
F P
0 g
s
.57274 .7935 m .59875 .79585 L p .58642 .77812 L .707 .577 .707 r
F P
0 g
s
.58642 .77812 m .57024 .75485 L .57274 .7935 L .707 .577 .707 r
F
.56761 .79304 m .57024 .75485 L .54275 .75137 L p F P
0 g
s
.54275 .75137 m .54012 .78956 L .54445 .79011 L p .707 .577 .707 r
F P
0 g
s
.54445 .79011 m .56761 .79304 L p .55608 .77372 L .707 .577 .707 r
F P
0 g
s
.55608 .77372 m .54275 .75137 L .54445 .79011 L .707 .577 .707 r
F
.54012 .78956 m .54275 .75137 L .5216 .74755 L p F P
0 g
s
.5216 .74755 m .51897 .78574 L .54012 .78956 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .51936 .78833 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53795 .80753 m .53961 .79692 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53961 .79692 m .5409 .78868 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .5409 .78868 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56557 .80982 m .56714 .7998 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56714 .7998 m .56852 .79097 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .56852 .79097 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59658 .81382 m .59824 .80322 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59824 .80322 m .59953 .79497 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.60461 .79619 m .63049 .79771 L p .61836 .78103 L .707 .577 .707 r
F P
0 g
s
.61836 .78103 m .60138 .75766 L .60461 .79619 L .707 .577 .707 r
F
.63049 .79771 m .63312 .75952 L .60138 .75766 L p F P
0 g
s
.54135 .74983 m .54009 .69518 L .51903 .68792 L p .707 .577 .707 r
F P
0 g
s
.54009 .69518 m .54135 .74983 L .56881 .7545 L p .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .56557 .80982 L .59658 .81382 L p .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .59658 .81382 L .62793 .81915 L p .707 .577 .707 r
F P
0 g
s
.63312 .75952 m .63049 .79771 L .65973 .79844 L p .707 .577 .707 r
F P
0 g
s
.65973 .79844 m .66236 .76026 L .63312 .75952 L p .707 .577 .707 r
F P
0 g
s
.62793 .81915 m .63088 .8003 L .59953 .79497 L p .707 .577 .707 r
F P
0 g
s
.63088 .8003 m .62793 .81915 L .65656 .82528 L p .707 .577 .707 r
F P
0 g
s
.65656 .82528 m .65952 .80643 L .63088 .8003 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .53795 .80753 L .56557 .80982 L p .707 .577 .707 r
F P
0 g
s
.68395 .688 m .6852 .74265 L .70155 .73351 L p .707 .577 .707 r
F P
0 g
s
.70155 .73351 m .7003 .67887 L .68395 .688 L p .707 .577 .707 r
F P
0 g
s
.66236 .76026 m .65973 .79844 L .6836 .79797 L p .707 .577 .707 r
F P
0 g
s
.6836 .79797 m .68623 .75978 L .66236 .76026 L p .707 .577 .707 r
F P
0 g
s
.51903 .68792 m .52028 .74256 L .54135 .74983 L p .707 .577 .707 r
F P
0 g
s
.65952 .80643 m .65656 .82528 L .67967 .8316 L p .707 .577 .707 r
F P
0 g
s
.67967 .8316 m .68262 .81275 L .65952 .80643 L p .707 .577 .707 r
F P
0 g
s
.52028 .74256 m .51903 .68792 L .50642 .67877 L p .707 .577 .707 r
F P
0 g
s
.51936 .78833 m .51641 .80718 L .53795 .80753 L p .707 .577 .707 r
F P
0 g
s
.7003 .67887 m .70155 .73351 L .70862 .72338 L p .707 .577 .707 r
F P
0 g
s
.70862 .72338 m .70736 .66874 L .7003 .67887 L p .707 .577 .707 r
F P
0 g
s
.68623 .75978 m .6836 .79797 L .69977 .79634 L p .707 .577 .707 r
F P
0 g
s
.69977 .79634 m .7024 .75816 L .68623 .75978 L p .707 .577 .707 r
F P
0 g
s
.68262 .81275 m .67967 .8316 L .69499 .83751 L p .707 .577 .707 r
F P
0 g
s
.50642 .67877 m .50767 .73342 L .52028 .74256 L p .707 .577 .707 r
F P
0 g
s
.69499 .83751 m .69794 .81866 L .68262 .81275 L p .707 .577 .707 r
F P
0 g
s
.51897 .78574 m .5216 .74755 L .50887 .74378 L p .707 .577 .707 r
F P
0 g
s
.50602 .78995 m .50307 .8088 L .51641 .80718 L p .707 .577 .707 r
F P
0 g
s
.51641 .80718 m .51936 .78833 L .50602 .78995 L p .707 .577 .707 r
F P
0 g
s
.50887 .74378 m .50623 .78197 L .51897 .78574 L p .707 .577 .707 r
F P
0 g
s
.50767 .73342 m .50642 .67877 L .50351 .66863 L p .707 .577 .707 r
F P
0 g
s
.7024 .75816 m .69977 .79634 L .70665 .79372 L p .707 .577 .707 r
F P
0 g
s
.70665 .79372 m .70928 .75553 L .7024 .75816 L p .707 .577 .707 r
F P
0 g
s
.70736 .66874 m .70862 .72338 L .7057 .71324 L p .707 .577 .707 r
F P
0 g
s
.7057 .71324 m .70445 .6586 L .70736 .66874 L p .707 .577 .707 r
F P
0 g
s
.69794 .81866 m .69499 .83751 L .70102 .84243 L p .707 .577 .707 r
F P
0 g
s
.50351 .66863 m .50476 .72328 L .50767 .73342 L p .707 .577 .707 r
F P
0 g
s
.70102 .84243 m .70398 .82358 L .69794 .81866 L p .707 .577 .707 r
F P
0 g
s
.50623 .78197 m .50887 .74378 L .50579 .74042 L p .707 .577 .707 r
F P
0 g
s
.50218 .79339 m .49922 .81224 L .50307 .8088 L p .707 .577 .707 r
F P
0 g
s
.50307 .8088 m .50602 .78995 L .50218 .79339 L p .707 .577 .707 r
F P
0 g
s
.4838 .81835 m .49482 .30988 L .45082 .30681 L p .707 .577 .707 r
F P
0 g
s
.50579 .74042 m .50316 .7786 L .50623 .78197 L p .707 .577 .707 r
F P
0 g
s
.50476 .72328 m .50351 .66863 L .51057 .6585 L p .707 .577 .707 r
F P
0 g
s
.51057 .6585 m .51182 .71315 L .50476 .72328 L p .707 .577 .707 r
F P
0 g
s
.50316 .7786 m .50579 .74042 L .51267 .73779 L p .707 .577 .707 r
F P
0 g
s
.50821 .7983 m .50526 .81715 L .49922 .81224 L p .707 .577 .707 r
F P
0 g
s
.49922 .81224 m .50218 .79339 L .50821 .7983 L p .707 .577 .707 r
F P
0 g
s
.51182 .71315 m .51057 .6585 L .52692 .64937 L p .707 .577 .707 r
F P
0 g
s
.51267 .73779 m .51004 .77598 L .50316 .7786 L p .707 .577 .707 r
F P
0 g
s
.52692 .64937 m .52817 .70401 L .51182 .71315 L p .707 .577 .707 r
F P
0 g
s
.51004 .77598 m .51267 .73779 L .52884 .73617 L p .707 .577 .707 r
F P
0 g
s
.52353 .80421 m .52058 .82306 L .50526 .81715 L p .707 .577 .707 r
F P
0 g
s
.50526 .81715 m .50821 .7983 L .52353 .80421 L p .707 .577 .707 r
F P
0 g
s
.52884 .73617 m .52621 .77435 L .51004 .77598 L p .707 .577 .707 r
F P
0 g
s
.52058 .82306 m .52353 .80421 L .54664 .81054 L p .707 .577 .707 r
F P
0 g
s
.49482 .30988 m .4838 .81835 L .52873 .81839 L p .707 .577 .707 r
F P
0 g
s
.52817 .70401 m .52692 .64937 L .55095 .64212 L p .707 .577 .707 r
F P
0 g
s
.55095 .64212 m .55221 .69677 L .52817 .70401 L p .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .52884 .73617 L .54369 .73587 L p .707 .577 .707 r
F P
0 g
s
.54369 .73587 m .55271 .7357 L p .54461 .74752 L .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .54369 .73587 L .54461 .74752 L .707 .577 .707 r
F
.55271 .7357 m .55008 .77388 L .52621 .77435 L p F P
0 g
s
.52873 .81839 m .53336 .60492 L p .49482 .30988 L .707 .577 .707 r
F P
0 g
s
.53336 .60492 m .53976 .30992 L .51008 .3099 L p .707 .577 .707 r
F P
0 g
s
.51008 .3099 m .49482 .30988 L p .53336 .60492 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .55095 .64212 L .5552 .64145 L p .707 .577 .707 r
F P
0 g
s
.5552 .64145 m .58032 .63748 L p .56188 .67638 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .5552 .64145 L .56188 .67638 L .707 .577 .707 r
F
.58157 .69213 m .58032 .63748 L .61215 .63589 L p F P
0 g
s
.58032 .63748 m .58157 .69213 L .55221 .69677 L p .707 .577 .707 r
F P
0 g
s
.61215 .63589 m .6134 .69054 L .58157 .69213 L p .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .55271 .7357 L .5707 .73615 L p .707 .577 .707 r
F P
0 g
s
.5707 .73615 m .58195 .73643 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .5707 .73615 L .56614 .755 L .707 .577 .707 r
F
.58122 .30691 m .57205 .72963 L p .57219 .72998 L F P
0 g
s
.58195 .73643 m .57932 .77461 L .56151 .77417 L p .707 .577 .707 r
F P
0 g
s
.56151 .77417 m .55008 .77388 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.56614 .755 m .58195 .73643 L .56151 .77417 L .707 .577 .707 r
F
.57932 .77461 m .58195 .73643 L .59079 .73695 L p F P
0 g
s
.59079 .73695 m .61369 .73829 L p .58813 .76531 L .707 .577 .707 r
F P
0 g
s
.57932 .77461 m .59079 .73695 L .58813 .76531 L .707 .577 .707 r
F
.64332 .63751 m .64457 .69216 L .6134 .69054 L p F P
0 g
s
.6134 .69054 m .61215 .63589 L .64332 .63751 L p .707 .577 .707 r
F P
0 g
s
.64483 .7411 m .6422 .77929 L .61106 .77648 L p .707 .577 .707 r
F P
0 g
s
.61106 .77648 m .61369 .73829 L .64483 .7411 L p .707 .577 .707 r
F P
0 g
s
.61369 .73829 m .61106 .77648 L .57932 .77461 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .62721 .80169 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61515 .30116 m .61018 .53024 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61018 .53024 m .60412 .80963 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58787 .81239 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57205 .72963 m .57203 .73066 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57203 .73066 m .57019 .81538 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .59601 .6315 L .57219 .72998 L .707 .577 .707 r
F
.59601 .6315 m .58122 .30691 L .57219 .72998 L F
.58787 .81239 m .60412 .80963 L p .57205 .72963 L F P
0 g
s
.54664 .81054 m .54369 .82939 L .52058 .82306 L p .707 .577 .707 r
F P
0 g
s
.54369 .82939 m .54664 .81054 L .57527 .81666 L p .707 .577 .707 r
F P
0 g
s
.53976 .30992 m .52873 .81839 L .57019 .81538 L p .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58122 .30691 L .53976 .30992 L p .707 .577 .707 r
F P
0 g
s
.43979 .81528 m .45082 .30681 L .41205 .301 L p .707 .577 .707 r
F P
0 g
s
.45082 .30681 m .43979 .81528 L .4838 .81835 L p .707 .577 .707 r
F P
0 g
s
.70928 .75553 m .70665 .79372 L .70357 .79036 L p .707 .577 .707 r
F P
0 g
s
.70357 .79036 m .70621 .75217 L .70928 .75553 L p .707 .577 .707 r
F P
0 g
s
.70445 .6586 m .7057 .71324 L .6931 .7041 L p .707 .577 .707 r
F P
0 g
s
.6931 .7041 m .69184 .64945 L .70445 .6586 L p .707 .577 .707 r
F P
0 g
s
.70398 .82358 m .70102 .84243 L .69718 .84586 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .61515 .30116 L .58122 .30691 L p .707 .577 .707 r
F P
0 g
s
.69718 .84586 m .70013 .82701 L .70398 .82358 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25697 .71931 m .25571 .66466 L .22454 .66304 L p .707 .577 .707 r
F P
0 g
s
.25571 .66466 m .25697 .71931 L .28879 .71772 L p .707 .577 .707 r
F P
0 g
s
.28879 .71772 m .28754 .66307 L .25571 .66466 L p .707 .577 .707 r
F P
0 g
s
.40103 .80947 m .41205 .301 L .38231 .29302 L p .707 .577 .707 r
F P
0 g
s
.41205 .301 m .40103 .80947 L .43979 .81528 L p .707 .577 .707 r
F P
0 g
s
.28754 .66307 m .28879 .71772 L .31816 .71307 L p .707 .577 .707 r
F P
0 g
s
.31816 .71307 m .31691 .65843 L .28754 .66307 L p .707 .577 .707 r
F P
0 g
s
.2258 .71769 m .22454 .66304 L .19708 .65837 L p .707 .577 .707 r
F P
0 g
s
.22454 .66304 m .2258 .71769 L .25697 .71931 L p .707 .577 .707 r
F P
0 g
s
.31691 .65843 m .31816 .71307 L .3422 .70583 L p .707 .577 .707 r
F P
0 g
s
.3422 .70583 m .34094 .65119 L .31691 .65843 L p .707 .577 .707 r
F P
0 g
s
.69184 .64945 m .6931 .7041 L .67203 .69683 L p .707 .577 .707 r
F P
0 g
s
.67203 .69683 m .67078 .64218 L .69184 .64945 L p .707 .577 .707 r
F P
0 g
s
.70621 .75217 m .70357 .79036 L .69084 .78658 L p .707 .577 .707 r
F P
0 g
s
.69084 .78658 m .69347 .7484 L .70621 .75217 L p .707 .577 .707 r
F P
0 g
s
.62721 .80169 m .63823 .29322 L .61515 .30116 L p .707 .577 .707 r
F P
0 g
s
.70013 .82701 m .69718 .84586 L .68384 .84748 L p .707 .577 .707 r
F P
0 g
s
.25574 .75903 m .25837 .72085 L .22723 .71804 L p .707 .577 .707 r
F P
0 g
s
.25837 .72085 m .25574 .75903 L .2616 .75938 L p .707 .577 .707 r
F P
0 g
s
.22723 .71804 m .2246 .75622 L .22973 .75669 L p .707 .577 .707 r
F P
0 g
s
.22973 .75669 m .25574 .75903 L p .24341 .7413 L .707 .577 .707 r
F P
0 g
s
.24341 .7413 m .22723 .71804 L .22973 .75669 L .707 .577 .707 r
F
.2246 .75622 m .22723 .71804 L .19974 .71455 L p F P
0 g
s
.19974 .71455 m .19711 .75274 L .20144 .75329 L p .707 .577 .707 r
F P
0 g
s
.20144 .75329 m .2246 .75622 L p .21307 .7369 L .707 .577 .707 r
F P
0 g
s
.21307 .7369 m .19974 .71455 L .20144 .75329 L .707 .577 .707 r
F
.19711 .75274 m .19974 .71455 L .17859 .71074 L p F P
0 g
s
.17859 .71074 m .17596 .74893 L .19711 .75274 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .17635 .75151 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.19494 .77072 m .1966 .76011 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.1966 .76011 m .19789 .75187 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .19789 .75187 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22256 .77301 m .22413 .76299 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22413 .76299 m .22552 .75416 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .22552 .75416 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25357 .77701 m .25523 .7664 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25523 .7664 m .25652 .75816 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.2616 .75938 m .28748 .7609 L p .27536 .74421 L .707 .577 .707 r
F P
0 g
s
.27536 .74421 m .25837 .72085 L .2616 .75938 L .707 .577 .707 r
F
.28748 .7609 m .29012 .72271 L .25837 .72085 L p F P
0 g
s
.19834 .71301 m .19708 .65837 L .17602 .6511 L p .707 .577 .707 r
F P
0 g
s
.19708 .65837 m .19834 .71301 L .2258 .71769 L p .707 .577 .707 r
F P
0 g
s
.68384 .84748 m .68679 .82863 L .70013 .82701 L p .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .22256 .77301 L .25357 .77701 L p .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .25357 .77701 L .28492 .78234 L p .707 .577 .707 r
F P
0 g
s
.29012 .72271 m .28748 .7609 L .31672 .76163 L p .707 .577 .707 r
F P
0 g
s
.31672 .76163 m .31935 .72344 L .29012 .72271 L p .707 .577 .707 r
F P
0 g
s
.28492 .78234 m .28788 .76348 L .25652 .75816 L p .707 .577 .707 r
F P
0 g
s
.28788 .76348 m .28492 .78234 L .31355 .78846 L p .707 .577 .707 r
F P
0 g
s
.31355 .78846 m .31651 .76961 L .28788 .76348 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .19494 .77072 L .22256 .77301 L p .707 .577 .707 r
F P
0 g
s
.37129 .80149 m .38231 .29302 L .36452 .28365 L p .707 .577 .707 r
F P
0 g
s
.38231 .29302 m .37129 .80149 L .40103 .80947 L p .707 .577 .707 r
F P
0 g
s
.34094 .65119 m .3422 .70583 L .35854 .6967 L p .707 .577 .707 r
F P
0 g
s
.35854 .6967 m .35729 .64205 L .34094 .65119 L p .707 .577 .707 r
F P
0 g
s
.67078 .64218 m .67203 .69683 L .64457 .69216 L p .707 .577 .707 r
F P
0 g
s
.64457 .69216 m .64332 .63751 L .67078 .64218 L p .707 .577 .707 r
F P
0 g
s
.31935 .72344 m .31672 .76163 L .34059 .76116 L p .707 .577 .707 r
F P
0 g
s
.34059 .76116 m .34323 .72297 L .31935 .72344 L p .707 .577 .707 r
F P
0 g
s
.17602 .6511 m .17727 .70575 L .19834 .71301 L p .707 .577 .707 r
F P
0 g
s
.31651 .76961 m .31355 .78846 L .33666 .79479 L p .707 .577 .707 r
F P
0 g
s
.33666 .79479 m .33961 .77594 L .31651 .76961 L p .707 .577 .707 r
F P
0 g
s
.17727 .70575 m .17602 .6511 L .16341 .64195 L p .707 .577 .707 r
F P
0 g
s
.69347 .7484 m .69084 .78658 L .66969 .78277 L p .707 .577 .707 r
F P
0 g
s
.66969 .78277 m .67232 .74458 L .69347 .7484 L p .707 .577 .707 r
F P
0 g
s
.17635 .75151 m .1734 .77037 L .19494 .77072 L p .707 .577 .707 r
F P
0 g
s
.68679 .82863 m .68384 .84748 L .6623 .84713 L p .707 .577 .707 r
F P
0 g
s
.6623 .84713 m .66525 .82828 L .68679 .82863 L p .707 .577 .707 r
F P
0 g
s
.63823 .29322 m .62721 .80169 L .63718 .79235 L p .707 .577 .707 r
F P
0 g
s
.63718 .79235 m .6482 .28388 L .63823 .29322 L p .707 .577 .707 r
F P
0 g
s
.35729 .64205 m .35854 .6967 L .36561 .68657 L p .707 .577 .707 r
F P
0 g
s
.36561 .68657 m .36435 .63192 L .35729 .64205 L p .707 .577 .707 r
F P
0 g
s
.34323 .72297 m .34059 .76116 L .35676 .75953 L p .707 .577 .707 r
F P
0 g
s
.35676 .75953 m .35939 .72134 L .34323 .72297 L p .707 .577 .707 r
F P
0 g
s
.33961 .77594 m .33666 .79479 L .35198 .8007 L p .707 .577 .707 r
F P
0 g
s
.16341 .64195 m .16466 .6966 L .17727 .70575 L p .707 .577 .707 r
F P
0 g
s
.35198 .8007 m .35493 .78185 L .33961 .77594 L p .707 .577 .707 r
F P
0 g
s
.17596 .74893 m .17859 .71074 L .16586 .70697 L p .707 .577 .707 r
F P
0 g
s
.67232 .74458 m .66969 .78277 L .6422 .77929 L p .707 .577 .707 r
F P
0 g
s
.6422 .77929 m .64483 .7411 L .67232 .74458 L p .707 .577 .707 r
F P
0 g
s
.16301 .75314 m .16006 .77199 L .1734 .77037 L p .707 .577 .707 r
F P
0 g
s
.1734 .77037 m .17635 .75151 L .16301 .75314 L p .707 .577 .707 r
F P
0 g
s
.16586 .70697 m .16322 .74515 L .17596 .74893 L p .707 .577 .707 r
F P
0 g
s
.66525 .82828 m .6623 .84713 L .63468 .84484 L p .707 .577 .707 r
F P
0 g
s
.16466 .6966 m .16341 .64195 L .1605 .63182 L p .707 .577 .707 r
F P
0 g
s
.35493 .78185 m .35198 .8007 L .35801 .80561 L p .707 .577 .707 r
F P
0 g
s
.36144 .62178 m .36269 .67643 L .35704 .67233 L p .707 .577 .707 r
F P
0 g
s
.35704 .67233 m .35009 .66728 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35908 .63124 m .36144 .62178 L .35704 .67233 L .707 .577 .707 r
F
.35009 .66728 m .34883 .61263 L .35961 .62046 L p F P
0 g
s
.35961 .62046 m .36144 .62178 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35009 .66728 m .35961 .62046 L .35908 .63124 L .707 .577 .707 r
F
.35939 .72134 m .35676 .75953 L .36364 .75691 L p F P
0 g
s
.36364 .75691 m .36628 .71872 L .35939 .72134 L p .707 .577 .707 r
F P
0 g
s
.3632 .71536 m .36056 .75354 L .35559 .75207 L p .707 .577 .707 r
F P
0 g
s
.35559 .75207 m .34783 .74977 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.35547 .73265 m .3632 .71536 L .35559 .75207 L .707 .577 .707 r
F
.34783 .74977 m .35046 .71158 L .35536 .71303 L p F P
0 g
s
.35536 .71303 m .3632 .71536 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.34783 .74977 m .35536 .71303 L .35547 .73265 L .707 .577 .707 r
F
.35437 .72609 m .35511 .67036 L .35135 .787 L F
.35511 .67036 m .3604 .27382 L .35469 .59736 L F
.35511 .67036 m .35469 .59736 L .35135 .787 L F
.34938 .78229 m .35135 .787 L p .35469 .59736 L F P
0 g
s
.3604 .27382 m .35442 .54973 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35442 .54973 m .34938 .78229 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35801 .80561 m .36097 .78676 L .35493 .78185 L p .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .34378 .79182 L .35634 .79029 L p .707 .577 .707 r
F P
0 g
s
.35634 .79029 m .35713 .7902 L p .35639 .79112 L .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .35634 .79029 L .35639 .79112 L .707 .577 .707 r
F
.35135 .787 m .35349 .79212 L p .35406 .74939 L F P
0 g
s
.35406 .74939 m .35437 .72609 L .35361 .74137 L .707 .577 .707 r
F
.35406 .74939 m .35361 .74137 L .35135 .787 L F
.36452 .28365 m .3604 .27382 L p .35437 .72609 L F P
0 g
s
.35349 .79212 m .35535 .70637 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.35535 .70637 m .36452 .28365 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.36435 .63192 m .36561 .68657 L .36269 .67643 L p .707 .577 .707 r
F P
0 g
s
.36269 .67643 m .36144 .62178 L .36435 .63192 L p .707 .577 .707 r
F P
0 g
s
.36628 .71872 m .36364 .75691 L .36056 .75354 L p .707 .577 .707 r
F P
0 g
s
.36056 .75354 m .3632 .71536 L .36628 .71872 L p .707 .577 .707 r
F P
0 g
s
.36097 .78676 m .35801 .80561 L .35417 .80905 L p .707 .577 .707 r
F P
0 g
s
.35417 .80905 m .35713 .7902 L .36097 .78676 L p .707 .577 .707 r
F P
0 g
s
.35713 .7902 m .35417 .80905 L .34083 .81067 L p .707 .577 .707 r
F P
0 g
s
.36452 .28365 m .35349 .79212 L .37129 .80149 L p .707 .577 .707 r
F P
0 g
s
.63468 .84484 m .63763 .82599 L .66525 .82828 L p .707 .577 .707 r
F P
0 g
s
.57527 .81666 m .57232 .83551 L .54369 .82939 L p .707 .577 .707 r
F P
0 g
s
.63763 .82599 m .63468 .84484 L .60367 .84084 L p .707 .577 .707 r
F P
0 g
s
.60367 .84084 m .60662 .82199 L .63763 .82599 L p .707 .577 .707 r
F P
0 g
s
.1605 .63182 m .16175 .68646 L .16466 .6966 L p .707 .577 .707 r
F P
0 g
s
.60662 .82199 m .60367 .84084 L .57232 .83551 L p .707 .577 .707 r
F P
0 g
s
.57232 .83551 m .57527 .81666 L .60662 .82199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16322 .74515 m .16586 .70697 L .16278 .7036 L p .707 .577 .707 r
F P
0 g
s
.15917 .75657 m .15621 .77542 L .16006 .77199 L p .707 .577 .707 r
F P
0 g
s
.16006 .77199 m .16301 .75314 L .15917 .75657 L p .707 .577 .707 r
F P
0 g
s
.6482 .28388 m .63718 .79235 L .63307 .78251 L p .707 .577 .707 r
F P
0 g
s
.63307 .78251 m .64409 .27404 L .6482 .28388 L p .707 .577 .707 r
F P
0 g
s
.16278 .7036 m .16015 .74179 L .16322 .74515 L p .707 .577 .707 r
F P
0 g
s
.16175 .68646 m .1605 .63182 L .16756 .62169 L p .707 .577 .707 r
F P
0 g
s
.34938 .78229 m .3604 .27382 L .37038 .26447 L p .707 .577 .707 r
F P
0 g
s
.16756 .62169 m .16881 .67633 L .16175 .68646 L p .707 .577 .707 r
F P
0 g
s
.16015 .74179 m .16278 .7036 L .16966 .70098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1652 .76148 m .16225 .78034 L .15621 .77542 L p .707 .577 .707 r
F P
0 g
s
.15621 .77542 m .15917 .75657 L .1652 .76148 L p .707 .577 .707 r
F P
0 g
s
.16881 .67633 m .16756 .62169 L .18391 .61255 L p .707 .577 .707 r
F P
0 g
s
.16966 .70098 m .16703 .73917 L .16015 .74179 L p .707 .577 .707 r
F P
0 g
s
.64409 .27404 m .63307 .78251 L .61527 .77315 L p .707 .577 .707 r
F P
0 g
s
.61527 .77315 m .62629 .26468 L .64409 .27404 L p .707 .577 .707 r
F P
0 g
s
.34883 .61263 m .35009 .66728 L .32902 .66001 L p .707 .577 .707 r
F P
0 g
s
.32902 .66001 m .32777 .60537 L .34883 .61263 L p .707 .577 .707 r
F P
0 g
s
.18391 .61255 m .18516 .6672 L .16881 .67633 L p .707 .577 .707 r
F P
0 g
s
.18516 .6672 m .18391 .61255 L .20794 .60531 L p .707 .577 .707 r
F P
0 g
s
.16703 .73917 m .16966 .70098 L .18583 .69935 L p .707 .577 .707 r
F P
0 g
s
.35935 .77294 m .37038 .26447 L .39346 .25654 L p .707 .577 .707 r
F P
0 g
s
.37038 .26447 m .35935 .77294 L .34938 .78229 L p .707 .577 .707 r
F P
0 g
s
.18052 .76739 m .17757 .78624 L .16225 .78034 L p .707 .577 .707 r
F P
0 g
s
.16225 .78034 m .1652 .76148 L .18052 .76739 L p .707 .577 .707 r
F P
0 g
s
.18583 .69935 m .1832 .73754 L .16703 .73917 L p .707 .577 .707 r
F P
0 g
s
.32777 .60537 m .32902 .66001 L .30156 .65534 L p .707 .577 .707 r
F P
0 g
s
.30156 .65534 m .30031 .6007 L .32777 .60537 L p .707 .577 .707 r
F P
0 g
s
.20794 .60531 m .2092 .65995 L .18516 .6672 L p .707 .577 .707 r
F P
0 g
s
.2092 .65995 m .20794 .60531 L .23731 .60067 L p .707 .577 .707 r
F P
0 g
s
.35046 .71158 m .34783 .74977 L .32668 .74595 L p .707 .577 .707 r
F P
0 g
s
.32668 .74595 m .32931 .70777 L .35046 .71158 L p .707 .577 .707 r
F P
0 g
s
.34378 .79182 m .34083 .81067 L .31929 .81032 L p .707 .577 .707 r
F P
0 g
s
.31929 .81032 m .32224 .79147 L .34378 .79182 L p .707 .577 .707 r
F P
0 g
s
.62629 .26468 m .61527 .77315 L .58553 .76517 L p .707 .577 .707 r
F P
0 g
s
.58553 .76517 m .59656 .2567 L .62629 .26468 L p .707 .577 .707 r
F P
0 g
s
.30031 .6007 m .30156 .65534 L .27039 .65372 L p .707 .577 .707 r
F P
0 g
s
.27039 .65372 m .26914 .59908 L .30031 .6007 L p .707 .577 .707 r
F P
0 g
s
.1832 .73754 m .18583 .69935 L .2097 .69888 L p .707 .577 .707 r
F P
0 g
s
.23856 .65531 m .23731 .60067 L .26914 .59908 L p .707 .577 .707 r
F P
0 g
s
.23731 .60067 m .23856 .65531 L .2092 .65995 L p .707 .577 .707 r
F P
0 g
s
.20363 .77372 m .20068 .79257 L .17757 .78624 L p .707 .577 .707 r
F P
0 g
s
.17757 .78624 m .18052 .76739 L .20363 .77372 L p .707 .577 .707 r
F P
0 g
s
.2097 .69888 m .20707 .73707 L .1832 .73754 L p .707 .577 .707 r
F P
0 g
s
.26914 .59908 m .27039 .65372 L .23856 .65531 L p .707 .577 .707 r
F P
0 g
s
.73718 .65653 m .73593 .60188 L .70476 .60026 L p .707 .577 .707 r
F P
0 g
s
.73593 .60188 m .73718 .65653 L .76901 .65494 L p .707 .577 .707 r
F P
0 g
s
.76901 .65494 m .76775 .6003 L .73593 .60188 L p .707 .577 .707 r
F P
0 g
s
.76775 .6003 m .76901 .65494 L .79837 .6503 L p .707 .577 .707 r
F P
0 g
s
.79837 .6503 m .79712 .59565 L .76775 .6003 L p .707 .577 .707 r
F P
0 g
s
.39346 .25654 m .38243 .76501 L .35935 .77294 L p .707 .577 .707 r
F P
0 g
s
.38243 .76501 m .39346 .25654 L .42739 .25078 L p .707 .577 .707 r
F P
0 g
s
.32931 .70777 m .32668 .74595 L .29919 .74247 L p .707 .577 .707 r
F P
0 g
s
.29919 .74247 m .30182 .70428 L .32931 .70777 L p .707 .577 .707 r
F P
0 g
s
.70601 .65491 m .70476 .60026 L .6773 .59559 L p .707 .577 .707 r
F P
0 g
s
.70476 .60026 m .70601 .65491 L .73718 .65653 L p .707 .577 .707 r
F P
0 g
s
.32224 .79147 m .31929 .81032 L .29167 .80803 L p .707 .577 .707 r
F P
0 g
s
.29167 .80803 m .29462 .78918 L .32224 .79147 L p .707 .577 .707 r
F P
0 g
s
.20707 .73707 m .2097 .69888 L .23894 .69961 L p .707 .577 .707 r
F P
0 g
s
.79712 .59565 m .79837 .6503 L .82241 .64305 L p .707 .577 .707 r
F P
0 g
s
.82241 .64305 m .82116 .58841 L .79712 .59565 L p .707 .577 .707 r
F P
0 g
s
.23226 .77985 m .22931 .7987 L .20068 .79257 L p .707 .577 .707 r
F P
0 g
s
.20068 .79257 m .20363 .77372 L .23226 .77985 L p .707 .577 .707 r
F P
0 g
s
.23894 .69961 m .23631 .7378 L .20707 .73707 L p .707 .577 .707 r
F P
0 g
s
.73595 .69317 m .73859 .65498 L .70744 .65217 L p .707 .577 .707 r
F P
0 g
s
.73859 .65498 m .73595 .69317 L .7677 .69503 L p .707 .577 .707 r
F P
0 g
s
.7677 .69503 m .77033 .65685 L .73859 .65498 L p .707 .577 .707 r
F P
0 g
s
.59656 .2567 m .58553 .76517 L .54676 .75936 L p .707 .577 .707 r
F P
0 g
s
.54676 .75936 m .55779 .25089 L .59656 .2567 L p .707 .577 .707 r
F P
0 g
s
.67855 .65024 m .6773 .59559 L .65623 .58833 L p .707 .577 .707 r
F P
0 g
s
.6773 .59559 m .67855 .65024 L .70601 .65491 L p .707 .577 .707 r
F P
0 g
s
.30182 .70428 m .29919 .74247 L .26805 .73966 L p .707 .577 .707 r
F P
0 g
s
.26805 .73966 m .27068 .70147 L .30182 .70428 L p .707 .577 .707 r
F P
0 g
s
.77033 .65685 m .7677 .69503 L .79693 .69576 L p .707 .577 .707 r
F P
0 g
s
.79693 .69576 m .79957 .65758 L .77033 .65685 L p .707 .577 .707 r
F P
0 g
s
.29462 .78918 m .29167 .80803 L .26066 .80402 L p .707 .577 .707 r
F P
0 g
s
.70744 .65217 m .70481 .69036 L .73595 .69317 L p .707 .577 .707 r
F P
0 g
s
.23631 .7378 m .23894 .69961 L .27068 .70147 L p .707 .577 .707 r
F P
0 g
s
.70573 .69501 m .70278 .71386 L .73378 .71787 L p .707 .577 .707 r
F P
0 g
s
.73378 .71787 m .73674 .69901 L .70573 .69501 L p .707 .577 .707 r
F P
0 g
s
.73674 .69901 m .73378 .71787 L .76514 .72319 L p .707 .577 .707 r
F P
0 g
s
.26066 .80402 m .26361 .78517 L .29462 .78918 L p .707 .577 .707 r
F P
0 g
s
.70481 .69036 m .70744 .65217 L .67995 .64869 L p .707 .577 .707 r
F P
0 g
s
.26361 .78517 m .26066 .80402 L .22931 .7987 L p .707 .577 .707 r
F P
0 g
s
.22931 .7987 m .23226 .77985 L .26361 .78517 L p .707 .577 .707 r
F P
0 g
s
.76514 .72319 m .76809 .70434 L .73674 .69901 L p .707 .577 .707 r
F P
0 g
s
.27068 .70147 m .26805 .73966 L .23631 .7378 L p .707 .577 .707 r
F P
0 g
s
.76809 .70434 m .76514 .72319 L .79377 .72932 L p .707 .577 .707 r
F P
0 g
s
.67995 .64869 m .67732 .68688 L .70481 .69036 L p .707 .577 .707 r
F P
0 g
s
.41637 .75925 m .42739 .25078 L .46885 .24778 L p .707 .577 .707 r
F P
0 g
s
.42739 .25078 m .41637 .75925 L .38243 .76501 L p .707 .577 .707 r
F P
0 g
s
.79377 .72932 m .79672 .71047 L .76809 .70434 L p .707 .577 .707 r
F P
0 g
s
.6781 .69272 m .67515 .71157 L .70278 .71386 L p .707 .577 .707 r
F P
0 g
s
.70278 .71386 m .70573 .69501 L .6781 .69272 L p .707 .577 .707 r
F P
0 g
s
.82116 .58841 m .82241 .64305 L .83876 .63392 L p .707 .577 .707 r
F P
0 g
s
.83876 .63392 m .8375 .57927 L .82116 .58841 L p .707 .577 .707 r
F P
0 g
s
.79957 .65758 m .79693 .69576 L .82081 .69529 L p .707 .577 .707 r
F P
0 g
s
.82081 .69529 m .82344 .65711 L .79957 .65758 L p .707 .577 .707 r
F P
0 g
s
.65623 .58833 m .65748 .64297 L .67855 .65024 L p .707 .577 .707 r
F P
0 g
s
.79672 .71047 m .79377 .72932 L .81687 .73565 L p .707 .577 .707 r
F P
0 g
s
.67732 .68688 m .67995 .64869 L .65881 .64488 L p .707 .577 .707 r
F P
0 g
s
.55779 .25089 m .54676 .75936 L .50276 .75628 L p .707 .577 .707 r
F P
0 g
s
.50276 .75628 m .51378 .24781 L .55779 .25089 L p .707 .577 .707 r
F P
0 g
s
.81687 .73565 m .81983 .71679 L .79672 .71047 L p .707 .577 .707 r
F P
0 g
s
.65748 .64297 m .65623 .58833 L .64362 .57918 L p .707 .577 .707 r
F P
0 g
s
.65881 .64488 m .65617 .68306 L .67732 .68688 L p .707 .577 .707 r
F P
0 g
s
.65657 .69237 m .65361 .71122 L .67515 .71157 L p .707 .577 .707 r
F P
0 g
s
.67515 .71157 m .6781 .69272 L .65657 .69237 L p .707 .577 .707 r
F P
0 g
s
.45783 .75625 m .46885 .24778 L .51378 .24781 L p .707 .577 .707 r
F P
0 g
s
.46885 .24778 m .45783 .75625 L .41637 .75925 L p .707 .577 .707 r
F P
0 g
s
.51378 .24781 m .50276 .75628 L .45783 .75625 L p .707 .577 .707 r
F P
0 g
s
.82344 .65711 m .82081 .69529 L .83697 .69367 L p .707 .577 .707 r
F P
0 g
s
.83697 .69367 m .83961 .65548 L .82344 .65711 L p .707 .577 .707 r
F P
0 g
s
.8375 .57927 m .83876 .63392 L .84582 .62379 L p .707 .577 .707 r
F P
0 g
s
.84582 .62379 m .84457 .56914 L .8375 .57927 L p .707 .577 .707 r
F P
0 g
s
.81983 .71679 m .81687 .73565 L .83219 .74155 L p .707 .577 .707 r
F P
0 g
s
.64362 .57918 m .64488 .63382 L .65748 .64297 L p .707 .577 .707 r
F P
0 g
s
.83219 .74155 m .83515 .7227 L .81983 .71679 L p .707 .577 .707 r
F P
0 g
s
.65617 .68306 m .65881 .64488 L .64607 .6411 L p .707 .577 .707 r
F P
0 g
s
.64607 .6411 m .64344 .67929 L .65617 .68306 L p .707 .577 .707 r
F P
0 g
s
.64322 .69399 m .64027 .71284 L .65361 .71122 L p .707 .577 .707 r
F P
0 g
s
.65361 .71122 m .65657 .69237 L .64322 .69399 L p .707 .577 .707 r
F P
0 g
s
.64488 .63382 m .64362 .57918 L .64071 .56904 L p .707 .577 .707 r
F P
0 g
s
.83961 .65548 m .83697 .69367 L .84386 .69104 L p .707 .577 .707 r
F P
0 g
s
.84386 .69104 m .84649 .65286 L .83961 .65548 L p .707 .577 .707 r
F P
0 g
s
.84457 .56914 m .84582 .62379 L .84291 .61365 L p .707 .577 .707 r
F P
0 g
s
.84291 .61365 m .84165 .55901 L .84457 .56914 L p .707 .577 .707 r
F P
0 g
s
.83515 .7227 m .83219 .74155 L .83823 .74647 L p .707 .577 .707 r
F P
0 g
s
.64071 .56904 m .64196 .62369 L .64488 .63382 L p .707 .577 .707 r
F P
0 g
s
.83823 .74647 m .84118 .72762 L .83515 .7227 L p .707 .577 .707 r
F P
0 g
s
.64344 .67929 m .64607 .6411 L .64299 .63774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64299 .63774 m .64036 .67592 L .64344 .67929 L p .707 .577 .707 r
F P
0 g
s
.63938 .69743 m .63643 .71628 L .64027 .71284 L p .707 .577 .707 r
F P
0 g
s
.64027 .71284 m .64322 .69399 L .63938 .69743 L p .707 .577 .707 r
F P
0 g
s
.64196 .62369 m .64071 .56904 L .64777 .55891 L p .707 .577 .707 r
F P
0 g
s
.84649 .65286 m .84386 .69104 L .84078 .68768 L p .707 .577 .707 r
F P
0 g
s
.84078 .68768 m .84341 .64949 L .84649 .65286 L p .707 .577 .707 r
F P
0 g
s
.84165 .55901 m .84291 .61365 L .8303 .6045 L p .707 .577 .707 r
F P
0 g
s
.8303 .6045 m .82905 .54986 L .84165 .55901 L p .707 .577 .707 r
F P
0 g
s
.64777 .55891 m .64903 .61355 L .64196 .62369 L p .707 .577 .707 r
F P
0 g
s
.84118 .72762 m .83823 .74647 L .83439 .7499 L p .707 .577 .707 r
F P
0 g
s
.83439 .7499 m .83734 .73105 L .84118 .72762 L p .707 .577 .707 r
F P
0 g
s
.64036 .67592 m .64299 .63774 L .64988 .63511 L p .707 .577 .707 r
F P
0 g
s
.39417 .61971 m .39292 .56507 L .36175 .56345 L p .707 .577 .707 r
F P
0 g
s
.39292 .56507 m .39417 .61971 L .426 .61813 L p .707 .577 .707 r
F P
0 g
s
.426 .61813 m .42474 .56348 L .39292 .56507 L p .707 .577 .707 r
F P
0 g
s
.64988 .63511 m .64724 .6733 L .64036 .67592 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64903 .61355 m .64777 .55891 L .66412 .54977 L p .707 .577 .707 r
F P
0 g
s
.64542 .70234 m .64246 .72119 L .63643 .71628 L p .707 .577 .707 r
F P
0 g
s
.63643 .71628 m .63938 .69743 L .64542 .70234 L p .707 .577 .707 r
F P
0 g
s
.42474 .56348 m .426 .61813 L .45536 .61348 L p .707 .577 .707 r
F P
0 g
s
.45536 .61348 m .45411 .55884 L .42474 .56348 L p .707 .577 .707 r
F P
0 g
s
.363 .61809 m .36175 .56345 L .33429 .55878 L p .707 .577 .707 r
F P
0 g
s
.36175 .56345 m .363 .61809 L .39417 .61971 L p .707 .577 .707 r
F P
0 g
s
.45411 .55884 m .45536 .61348 L .4794 .60624 L p .707 .577 .707 r
F P
0 g
s
.4794 .60624 m .47815 .55159 L .45411 .55884 L p .707 .577 .707 r
F P
0 g
s
.82905 .54986 m .8303 .6045 L .80924 .59724 L p .707 .577 .707 r
F P
0 g
s
.80924 .59724 m .80798 .54259 L .82905 .54986 L p .707 .577 .707 r
F P
0 g
s
.84341 .64949 m .84078 .68768 L .82804 .6839 L p .707 .577 .707 r
F P
0 g
s
.82804 .6839 m .83068 .64572 L .84341 .64949 L p .707 .577 .707 r
F P
0 g
s
.66412 .54977 m .66538 .60442 L .64903 .61355 L p .707 .577 .707 r
F P
0 g
s
.39294 .65635 m .39558 .61817 L .36443 .61536 L p .707 .577 .707 r
F P
0 g
s
.39558 .61817 m .39294 .65635 L .42469 .65822 L p .707 .577 .707 r
F P
0 g
s
.42469 .65822 m .42732 .62003 L .39558 .61817 L p .707 .577 .707 r
F P
0 g
s
.83734 .73105 m .83439 .7499 L .82104 .75152 L p .707 .577 .707 r
F P
0 g
s
.33554 .61342 m .33429 .55878 L .31322 .55151 L p .707 .577 .707 r
F P
0 g
s
.33429 .55878 m .33554 .61342 L .363 .61809 L p .707 .577 .707 r
F P
0 g
s
.82104 .75152 m .824 .73267 L .83734 .73105 L p .707 .577 .707 r
F P
0 g
s
.42732 .62003 m .42469 .65822 L .45392 .65895 L p .707 .577 .707 r
F P
0 g
s
.45392 .65895 m .45656 .62076 L .42732 .62003 L p .707 .577 .707 r
F P
0 g
s
.36443 .61536 m .3618 .65355 L .39294 .65635 L p .707 .577 .707 r
F P
0 g
s
.36272 .6582 m .35977 .67705 L .39077 .68105 L p .707 .577 .707 r
F P
0 g
s
.39077 .68105 m .39373 .6622 L .36272 .6582 L p .707 .577 .707 r
F P
0 g
s
.39373 .6622 m .39077 .68105 L .42213 .68638 L p .707 .577 .707 r
F P
0 g
s
.66538 .60442 m .66412 .54977 L .68816 .54253 L p .707 .577 .707 r
F P
0 g
s
.64724 .6733 m .64988 .63511 L .66604 .63349 L p .707 .577 .707 r
F P
0 g
s
.3618 .65355 m .36443 .61536 L .33694 .61188 L p .707 .577 .707 r
F P
0 g
s
.42213 .68638 m .42508 .66752 L .39373 .6622 L p .707 .577 .707 r
F P
0 g
s
.42508 .66752 m .42213 .68638 L .45076 .6925 L p .707 .577 .707 r
F P
0 g
s
.66604 .63349 m .66341 .67167 L .64724 .6733 L p .707 .577 .707 r
F P
0 g
s
.33694 .61188 m .33431 .65006 L .3618 .65355 L p .707 .577 .707 r
F P
0 g
s
.66074 .70825 m .65778 .7271 L .64246 .72119 L p .707 .577 .707 r
F P
0 g
s
.64246 .72119 m .64542 .70234 L .66074 .70825 L p .707 .577 .707 r
F P
0 g
s
.45076 .6925 m .45371 .67365 L .42508 .66752 L p .707 .577 .707 r
F P
0 g
s
.33509 .65591 m .33214 .67476 L .35977 .67705 L p .707 .577 .707 r
F P
0 g
s
.35977 .67705 m .36272 .6582 L .33509 .65591 L p .707 .577 .707 r
F P
0 g
s
.47815 .55159 m .4794 .60624 L .49575 .5971 L p .707 .577 .707 r
F P
0 g
s
.49575 .5971 m .49449 .54246 L .47815 .55159 L p .707 .577 .707 r
F P
0 g
s
.45656 .62076 m .45392 .65895 L .4778 .65848 L p .707 .577 .707 r
F P
0 g
s
.4778 .65848 m .48043 .62029 L .45656 .62076 L p .707 .577 .707 r
F P
0 g
s
.80798 .54259 m .80924 .59724 L .78177 .59256 L p .707 .577 .707 r
F P
0 g
s
.78177 .59256 m .78052 .53792 L .80798 .54259 L p .707 .577 .707 r
F P
0 g
s
.31322 .55151 m .31447 .60616 L .33554 .61342 L p .707 .577 .707 r
F P
0 g
s
.45371 .67365 m .45076 .6925 L .47386 .69883 L p .707 .577 .707 r
F P
0 g
s
.33431 .65006 m .33694 .61188 L .3158 .60806 L p .707 .577 .707 r
F P
0 g
s
.47386 .69883 m .47682 .67998 L .45371 .67365 L p .707 .577 .707 r
F P
0 g
s
.68816 .54253 m .68941 .59718 L .66538 .60442 L p .707 .577 .707 r
F P
0 g
s
.31447 .60616 m .31322 .55151 L .30061 .54236 L p .707 .577 .707 r
F P
0 g
s
.83068 .64572 m .82804 .6839 L .80689 .68009 L p .707 .577 .707 r
F P
0 g
s
.80689 .68009 m .80953 .6419 L .83068 .64572 L p .707 .577 .707 r
F P
0 g
s
.68941 .59718 m .68816 .54253 L .71752 .53789 L p .707 .577 .707 r
F P
0 g
s
.3158 .60806 m .31316 .64625 L .33431 .65006 L p .707 .577 .707 r
F P
0 g
s
.31356 .65556 m .3106 .67441 L .33214 .67476 L p .707 .577 .707 r
F P
0 g
s
.33214 .67476 m .33509 .65591 L .31356 .65556 L p .707 .577 .707 r
F P
0 g
s
.824 .73267 m .82104 .75152 L .79951 .75117 L p .707 .577 .707 r
F P
0 g
s
.79951 .75117 m .80246 .73232 L .824 .73267 L p .707 .577 .707 r
F P
0 g
s
.78052 .53792 m .78177 .59256 L .7506 .59094 L p .707 .577 .707 r
F P
0 g
s
.7506 .59094 m .74935 .5363 L .78052 .53792 L p .707 .577 .707 r
F P
0 g
s
.66341 .67167 m .66604 .63349 L .68992 .63302 L p .707 .577 .707 r
F P
0 g
s
.71878 .59253 m .71752 .53789 L .74935 .5363 L p .707 .577 .707 r
F P
0 g
s
.71752 .53789 m .71878 .59253 L .68941 .59718 L p .707 .577 .707 r
F P
0 g
s
.68992 .63302 m .68728 .6712 L .66341 .67167 L p .707 .577 .707 r
F P
0 g
s
.48043 .62029 m .4778 .65848 L .49396 .65685 L p .707 .577 .707 r
F P
0 g
s
.49396 .65685 m .4966 .61866 L .48043 .62029 L p .707 .577 .707 r
F P
0 g
s
.68384 .71458 m .68089 .73343 L .65778 .7271 L p .707 .577 .707 r
F P
0 g
s
.65778 .7271 m .66074 .70825 L .68384 .71458 L p .707 .577 .707 r
F P
0 g
s
.49449 .54246 m .49575 .5971 L .50281 .58697 L p .707 .577 .707 r
F P
0 g
s
.50281 .58697 m .50156 .53233 L .49449 .54246 L p .707 .577 .707 r
F P
0 g
s
.74935 .5363 m .7506 .59094 L .71878 .59253 L p .707 .577 .707 r
F P
0 g
s
.47682 .67998 m .47386 .69883 L .48918 .70474 L p .707 .577 .707 r
F P
0 g
s
.30061 .54236 m .30187 .59701 L .31447 .60616 L p .707 .577 .707 r
F P
0 g
s
.48918 .70474 m .49214 .68589 L .47682 .67998 L p .707 .577 .707 r
F P
0 g
s
.31316 .64625 m .3158 .60806 L .30306 .60429 L p .707 .577 .707 r
F P
0 g
s
.80953 .6419 m .80689 .68009 L .7794 .67661 L p .707 .577 .707 r
F P
0 g
s
.7794 .67661 m .78204 .63842 L .80953 .6419 L p .707 .577 .707 r
F P
0 g
s
.30306 .60429 m .30043 .64247 L .31316 .64625 L p .707 .577 .707 r
F P
0 g
s
.30021 .65718 m .29726 .67603 L .3106 .67441 L p .707 .577 .707 r
F P
0 g
s
.3106 .67441 m .31356 .65556 L .30021 .65718 L p .707 .577 .707 r
F P
0 g
s
.30187 .59701 m .30061 .54236 L .2977 .53222 L p .707 .577 .707 r
F P
0 g
s
.80246 .73232 m .79951 .75117 L .77188 .74888 L p .707 .577 .707 r
F P
0 g
s
.68728 .6712 m .68992 .63302 L .71915 .63375 L p .707 .577 .707 r
F P
0 g
s
.77188 .74888 m .77483 .73003 L .80246 .73232 L p .707 .577 .707 r
F P
0 g
s
.71915 .63375 m .71652 .67193 L .68728 .6712 L p .707 .577 .707 r
F P
0 g
s
.71247 .7207 m .70952 .73955 L .68089 .73343 L p .707 .577 .707 r
F P
0 g
s
.68089 .73343 m .68384 .71458 L .71247 .7207 L p .707 .577 .707 r
F P
0 g
s
.78204 .63842 m .7794 .67661 L .74826 .6738 L p .707 .577 .707 r
F P
0 g
s
.74826 .6738 m .7509 .63561 L .78204 .63842 L p .707 .577 .707 r
F P
0 g
s
.4966 .61866 m .49396 .65685 L .50085 .65423 L p .707 .577 .707 r
F P
0 g
s
.50085 .65423 m .50348 .61604 L .4966 .61866 L p .707 .577 .707 r
F P
0 g
s
.71652 .67193 m .71915 .63375 L .7509 .63561 L p .707 .577 .707 r
F P
0 g
s
.50156 .53233 m .50281 .58697 L .4999 .57684 L p .707 .577 .707 r
F P
0 g
s
.4999 .57684 m .49864 .52219 L .50156 .53233 L p .707 .577 .707 r
F P
0 g
s
.77483 .73003 m .77188 .74888 L .74087 .74488 L p .707 .577 .707 r
F P
0 g
s
.49214 .68589 m .48918 .70474 L .49522 .70965 L p .707 .577 .707 r
F P
0 g
s
.2977 .53222 m .29895 .58687 L .30187 .59701 L p .707 .577 .707 r
F P
0 g
s
.7509 .63561 m .74826 .6738 L .71652 .67193 L p .707 .577 .707 r
F P
0 g
s
.74087 .74488 m .74383 .72603 L .77483 .73003 L p .707 .577 .707 r
F P
0 g
s
.74383 .72603 m .74087 .74488 L .70952 .73955 L p .707 .577 .707 r
F P
0 g
s
.70952 .73955 m .71247 .7207 L .74383 .72603 L p .707 .577 .707 r
F P
0 g
s
.49522 .70965 m .49817 .6908 L .49214 .68589 L p .707 .577 .707 r
F P
0 g
s
.30043 .64247 m .30306 .60429 L .29998 .60092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29998 .60092 m .29735 .63911 L .30043 .64247 L p .707 .577 .707 r
F P
0 g
s
.29637 .66061 m .29342 .67946 L .29726 .67603 L p .707 .577 .707 r
F P
0 g
s
.29726 .67603 m .30021 .65718 L .29637 .66061 L p .707 .577 .707 r
F P
0 g
s
.29895 .58687 m .2977 .53222 L .30476 .52209 L p .707 .577 .707 r
F P
0 g
s
.50348 .61604 m .50085 .65423 L .49777 .65086 L p .707 .577 .707 r
F P
0 g
s
.49777 .65086 m .5004 .61268 L .50348 .61604 L p .707 .577 .707 r
F P
0 g
s
.49864 .52219 m .4999 .57684 L .48729 .56769 L p .707 .577 .707 r
F P
0 g
s
.48729 .56769 m .48604 .51304 L .49864 .52219 L p .707 .577 .707 r
F P
0 g
s
.30476 .52209 m .30602 .57674 L .29895 .58687 L p .707 .577 .707 r
F P
0 g
s
.49817 .6908 m .49522 .70965 L .49138 .71309 L p .707 .577 .707 r
F P
0 g
s
.49138 .71309 m .49433 .69424 L .49817 .6908 L p .707 .577 .707 r
F P
0 g
s
.29735 .63911 m .29998 .60092 L .30686 .5983 L p .707 .577 .707 r
F P
0 g
s
.30686 .5983 m .30423 .63649 L .29735 .63911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30602 .57674 m .30476 .52209 L .32111 .51296 L p .707 .577 .707 r
F P
0 g
s
.3024 .66552 m .29945 .68438 L .29342 .67946 L p .707 .577 .707 r
F P
0 g
s
.29342 .67946 m .29637 .66061 L .3024 .66552 L p .707 .577 .707 r
F P
0 g
s
.48604 .51304 m .48729 .56769 L .46622 .56042 L p .707 .577 .707 r
F P
0 g
s
.46622 .56042 m .46497 .50577 L .48604 .51304 L p .707 .577 .707 r
F P
0 g
s
.5004 .61268 m .49777 .65086 L .48503 .64709 L p .707 .577 .707 r
F P
0 g
s
.48503 .64709 m .48767 .6089 L .5004 .61268 L p .707 .577 .707 r
F P
0 g
s
.32111 .51296 m .32236 .5676 L .30602 .57674 L p .707 .577 .707 r
F P
0 g
s
.49433 .69424 m .49138 .71309 L .47803 .71471 L p .707 .577 .707 r
F P
0 g
s
.47803 .71471 m .48099 .69586 L .49433 .69424 L p .707 .577 .707 r
F P
0 g
s
.32236 .5676 m .32111 .51296 L .34515 .50572 L p .707 .577 .707 r
F P
0 g
s
.30423 .63649 m .30686 .5983 L .32303 .59667 L p .707 .577 .707 r
F P
0 g
s
.32303 .59667 m .3204 .63486 L .30423 .63649 L p .707 .577 .707 r
F P
0 g
s
.31772 .67143 m .31477 .69028 L .29945 .68438 L p .707 .577 .707 r
F P
0 g
s
.29945 .68438 m .3024 .66552 L .31772 .67143 L p .707 .577 .707 r
F P
0 g
s
.46497 .50577 m .46622 .56042 L .43876 .55575 L p .707 .577 .707 r
F P
0 g
s
.43876 .55575 m .43751 .5011 L .46497 .50577 L p .707 .577 .707 r
F P
0 g
s
.34515 .50572 m .3464 .56036 L .32236 .5676 L p .707 .577 .707 r
F P
0 g
s
.48767 .6089 m .48503 .64709 L .46388 .64327 L p .707 .577 .707 r
F P
0 g
s
.46388 .64327 m .46652 .60509 L .48767 .6089 L p .707 .577 .707 r
F P
0 g
s
.3464 .56036 m .34515 .50572 L .37451 .50107 L p .707 .577 .707 r
F P
0 g
s
.48099 .69586 m .47803 .71471 L .45649 .71436 L p .707 .577 .707 r
F P
0 g
s
.45649 .71436 m .45945 .69551 L .48099 .69586 L p .707 .577 .707 r
F P
0 g
s
.43751 .5011 m .43876 .55575 L .40759 .55413 L p .707 .577 .707 r
F P
0 g
s
.40759 .55413 m .40634 .49948 L .43751 .5011 L p .707 .577 .707 r
F P
0 g
s
.3204 .63486 m .32303 .59667 L .3469 .5962 L p .707 .577 .707 r
F P
0 g
s
.37577 .55572 m .37451 .50107 L .40634 .49948 L p .707 .577 .707 r
F P
0 g
s
.37451 .50107 m .37577 .55572 L .3464 .56036 L p .707 .577 .707 r
F P
0 g
s
.3469 .5962 m .34427 .63439 L .3204 .63486 L p .707 .577 .707 r
F P
0 g
s
.34083 .67776 m .33788 .69661 L .31477 .69028 L p .707 .577 .707 r
F P
0 g
s
.31477 .69028 m .31772 .67143 L .34083 .67776 L p .707 .577 .707 r
F P
0 g
s
.40634 .49948 m .40759 .55413 L .37577 .55572 L p .707 .577 .707 r
F P
0 g
s
.46652 .60509 m .46388 .64327 L .43639 .63979 L p .707 .577 .707 r
F P
0 g
s
.43639 .63979 m .43903 .6016 L .46652 .60509 L p .707 .577 .707 r
F P
0 g
s
.45945 .69551 m .45649 .71436 L .42887 .71207 L p .707 .577 .707 r
F P
0 g
s
.34427 .63439 m .3469 .5962 L .37614 .59693 L p .707 .577 .707 r
F P
0 g
s
.42887 .71207 m .43182 .69322 L .45945 .69551 L p .707 .577 .707 r
F P
0 g
s
.37614 .59693 m .37351 .63512 L .34427 .63439 L p .707 .577 .707 r
F P
0 g
s
.36946 .68389 m .36651 .70274 L .33788 .69661 L p .707 .577 .707 r
F P
0 g
s
.33788 .69661 m .34083 .67776 L .36946 .68389 L p .707 .577 .707 r
F P
0 g
s
.43903 .6016 m .43639 .63979 L .40525 .63698 L p .707 .577 .707 r
F P
0 g
s
.40525 .63698 m .40789 .59879 L .43903 .6016 L p .707 .577 .707 r
F P
0 g
s
.37351 .63512 m .37614 .59693 L .40789 .59879 L p .707 .577 .707 r
F P
0 g
s
.43182 .69322 m .42887 .71207 L .39786 .70806 L p .707 .577 .707 r
F P
0 g
s
.40789 .59879 m .40525 .63698 L .37351 .63512 L p .707 .577 .707 r
F P
0 g
s
.39786 .70806 m .40082 .68921 L .43182 .69322 L p .707 .577 .707 r
F P
0 g
s
.40082 .68921 m .39786 .70806 L .36651 .70274 L p .707 .577 .707 r
F P
0 g
s
.36651 .70274 m .36946 .68389 L .40082 .68921 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001aOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00JWoo001W
Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`80009JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP0000005`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001QOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000BOolE000nOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000moo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo10001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000c
Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEPT000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH70005FUH00`00FUH000020005FUH0
1000FUIJEUYF100000=JEP000000100015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001D
Ool00`00FUH00004FUH00`00FUH000030004FUHF0006FUH00`00FUIJEP02FUH300000eYF001JEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001DOol00`00FUH00004FUH20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002aoo`00E7oo00<005YF00000UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000/Ool005Aoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;7oo001DOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000/Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP8002aoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Eoo`04001JEUYFFUHF00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000AJEP03001JEUYF009JEPH000Uoo`<000]oo`T000=JEP04001JEUYF
FUH2000/Ool0049ooaP00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH0
05YF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YF00000P000UYF2@000goo1@00
00=oo`0000001`000eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P00;7oo000nOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF0P0000=JEP00FUH01UYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;7oo000jOol4
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002
FUH2000/Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;7oo000cOol30005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009JEQH000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000090001eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF1P001EYF00<005YFFUH015YF00<005YFFUH01UYF4@000eYF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP04001JEP00
000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT0039oo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH0
05YF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05000_Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH01EYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH<0005OolD0002FUH01000FUIJEUYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH01P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000Moo`D000Qoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH80002
FUH00`00FUIJEP04FUHF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000]Ool01000FUIJ
EP000eYF00<005YF00000`000UYF20000goo1@0000=oo`0000001`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00@005YFFUIJEPT000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP050005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH60009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00@005YF
FUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001J
EP00FUH00002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;7oo000]Ool00`00FUIJEP030005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
00001@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0035YF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002P001UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01P00FUIJEP00FUH000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJ
EP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000030009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP050003FUH7
0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P00;Goo000]
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH600000eYF000000050002FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF0000000]Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF000000050004FUH00`00FUIJEP04FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH0100015YF1P0015YF00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005P0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002ioo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH500000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUHG000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH01000FUIJEUYF:`00;Woo000^Ool01000
FUIJEUYF5P0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL004Uoo`00;goo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YF00001`001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00AJEP@0009JEP03001JEUYF009JEP@0009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF1000@Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000goo00@005YFFUH000EJEP03
001JEUYF00H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00?Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03
FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00004FUH00`00FUH0000<0006FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000g
Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH=0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH500000eYF000000050002FUH40005FUH00`00FUIJEP06
FUH01000FUIJEUYF1000<goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJEP04001JEUYFFUH7
00000goo000000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000aOol002eoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0>0006FUH00`00FUIJEP05FUH0
0`00FUIJEP02000_Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH;0005FUH01000FUIJEUYF1000
;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUIJEUYF300000AJEP00FUH002eoo`00;Goo00<005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00;Goo1P001EYF
00<005YFFUH015YF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P001UYF0`000Woo1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH0
05YF00000eYF20002goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002io
o`00<7oo100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1P000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00MJEP03001JEUYF00D0011oo`P000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`/0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03
FUH01000FUH000005Woo3`00;goo000^Ool300000eYF001JEP04FUH01000FUIJEUYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03FUH00`00FUIJEP02
001COol002eoo`8000=JEP03001JEUYF009JEP8000IJEP8000=JEPX000=JEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHZ0008FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00001eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo
000]Ool300000eYF001JEP04FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP0I0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000025YF00<005YFFUH00eYF00<005YFFUH0
0P00Dgoo000]Ool200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH6000>Ool01000FUIJEP0015YF10000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF00@005YF000000MJEP03001J
EUYF00AJEP03001JEUYF008005=oo`00;7oo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`05001JEUYF001JEP030007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP02FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00;7oo00<005YF
000015YF00<005YF00003P0015YF0`001UYF00<005YFFUH01EYF00<005YF00000`0017oo00<005YF
FUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF
00<005YFFUH01UYF100015YF00@005YF000000MJEP03001JEUYF00=JEP06001JEUYF001JEP00Dgoo
000/Ool00`00FUH00004FUH00`00FUIJEP02FUH60006Ool80005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20002Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00@005YF000000MJEP03
001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF
1P000goo20000UYF00<005YFFUH01EYF00<005YFFUH015YF1@0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0000=JEP0000000`0015YF00<005YFFUH00eYF00<005YFFUH00P00E7oo000_Ool20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070003Ool40006FUH00`00FUIJEP04FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH70003FUH00`00
FUIJEP02001DOol0035oo`<000EJEP03001JEUYF00IJEP03001JEUYF00=JEPL000Aoo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF1@0000=JEP000000E7oo000dOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH=0003FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF000000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003Qoo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH?0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001DOol003]oo`@0009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001J
EP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF2@00EGoo000oOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002Ool8001NOol004Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005
Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YF00000`00I7oo001>Ool80004FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0027oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00=JEP@0061oo`00EWoo3`00
37oo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF0`00
1EYF00<005YFFUH01UYF00<005YF00000`00G7oo001hOol;0006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3001IOol008=ooaX000AJEPL00003Ool0
000000T000IJEP03001JEUYF00EJEP03001JEP00008005Ioo`00T7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF2@000goo10000UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00TWoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2`001EYF00<005YF
FUH00UYF00<005YF0000E7oo002GOol50006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF4000E7oo002LOol40002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002POol50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000EGoo002UOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo002YOol70004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00EGoo002`OolG001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59849 .75361 m .59772 .69859 L .56654 .69686 L p .707 .577 .707 r
F P
0 g
s
.59772 .69859 m .59849 .75361 L .63032 .75233 L p .707 .577 .707 r
F P
0 g
s
.63032 .75233 m .62955 .69731 L .59772 .69859 L p .707 .577 .707 r
F P
0 g
s
.62955 .69731 m .63032 .75233 L .6597 .74817 L p .707 .577 .707 r
F P
0 g
s
.6597 .74817 m .65892 .69314 L .62955 .69731 L p .707 .577 .707 r
F P
0 g
s
.56732 .75189 m .56654 .69686 L .53909 .6923 L p .707 .577 .707 r
F P
0 g
s
.56654 .69686 m .56732 .75189 L .59849 .75361 L p .707 .577 .707 r
F P
0 g
s
.65892 .69314 m .6597 .74817 L .68375 .74153 L p .707 .577 .707 r
F P
0 g
s
.68375 .74153 m .68297 .68651 L .65892 .69314 L p .707 .577 .707 r
F P
0 g
s
.5976 .80134 m .59923 .76343 L .56807 .76097 L p .707 .577 .707 r
F P
0 g
s
.59923 .76343 m .5976 .80134 L .6294 .80218 L p .707 .577 .707 r
F P
0 g
s
.6294 .80218 m .63103 .76427 L .59923 .76343 L p .707 .577 .707 r
F P
0 g
s
.53986 .74732 m .53909 .6923 L .51803 .68534 L p .707 .577 .707 r
F P
0 g
s
.53909 .6923 m .53986 .74732 L .56732 .75189 L p .707 .577 .707 r
F P
0 g
s
.63103 .76427 m .6294 .80218 L .65873 .80133 L p .707 .577 .707 r
F P
0 g
s
.65873 .80133 m .66036 .76342 L .63103 .76427 L p .707 .577 .707 r
F P
0 g
s
.56807 .76097 m .56644 .79888 L .5976 .80134 L p .707 .577 .707 r
F P
0 g
s
.56644 .79888 m .56807 .76097 L .5406 .75714 L p .707 .577 .707 r
F P
0 g
s
.59564 .82854 m .5975 .80941 L .56639 .80621 L p .707 .577 .707 r
F P
0 g
s
.5975 .80941 m .59564 .82854 L .62729 .83153 L p .707 .577 .707 r
F P
0 g
s
.62729 .83153 m .62915 .81239 L .5975 .80941 L p .707 .577 .707 r
F P
0 g
s
.56639 .80621 m .56453 .82534 L .59564 .82854 L p .707 .577 .707 r
F P
0 g
s
.62915 .81239 m .62729 .83153 L .65638 .83401 L p .707 .577 .707 r
F P
0 g
s
.65638 .83401 m .65824 .81488 L .62915 .81239 L p .707 .577 .707 r
F P
0 g
s
.68297 .68651 m .68375 .74153 L .70011 .73307 L p .707 .577 .707 r
F P
0 g
s
.70011 .73307 m .69933 .67804 L .68297 .68651 L p .707 .577 .707 r
F P
0 g
s
.5406 .75714 m .53897 .79504 L .56644 .79888 L p .707 .577 .707 r
F P
0 g
s
.56453 .82534 m .56639 .80621 L .53887 .80311 L p .707 .577 .707 r
F P
0 g
s
.53887 .80311 m .53701 .82225 L .56453 .82534 L p .707 .577 .707 r
F P
0 g
s
.66036 .76342 m .65873 .80133 L .68271 .79886 L p .707 .577 .707 r
F P
0 g
s
.68271 .79886 m .68434 .76095 L .66036 .76342 L p .707 .577 .707 r
F P
0 g
s
.51803 .68534 m .5188 .74036 L .53986 .74732 L p .707 .577 .707 r
F P
0 g
s
.53897 .79504 m .5406 .75714 L .51951 .7523 L p .707 .577 .707 r
F P
0 g
s
.5188 .74036 m .51803 .68534 L .50543 .67667 L p .707 .577 .707 r
F P
0 g
s
.65824 .81488 m .65638 .83401 L .68007 .83575 L p .707 .577 .707 r
F P
0 g
s
.68007 .83575 m .68193 .81662 L .65824 .81488 L p .707 .577 .707 r
F P
0 g
s
.51951 .7523 m .51788 .79021 L .53897 .79504 L p .707 .577 .707 r
F P
0 g
s
.53701 .82225 m .53887 .80311 L .51763 .80042 L p .707 .577 .707 r
F P
0 g
s
.51763 .80042 m .51577 .81956 L .53701 .82225 L p .707 .577 .707 r
F P
0 g
s
.68434 .76095 m .68271 .79886 L .699 .79502 L p .707 .577 .707 r
F P
0 g
s
.699 .79502 m .70063 .75712 L .68434 .76095 L p .707 .577 .707 r
F P
0 g
s
.69933 .67804 m .70011 .73307 L .70718 .72361 L p .707 .577 .707 r
F P
0 g
s
.70718 .72361 m .70641 .66858 L .69933 .67804 L p .707 .577 .707 r
F P
0 g
s
.50543 .67667 m .5062 .7317 L .5188 .74036 L p .707 .577 .707 r
F P
0 g
s
.68193 .81662 m .68007 .83575 L .69603 .83657 L p .707 .577 .707 r
F P
0 g
s
.69603 .83657 m .69789 .81744 L .68193 .81662 L p .707 .577 .707 r
F P
0 g
s
.51788 .79021 m .51951 .7523 L .50686 .74695 L p .707 .577 .707 r
F P
0 g
s
.5062 .7317 m .50543 .67667 L .50253 .66714 L p .707 .577 .707 r
F P
0 g
s
.50686 .74695 m .50523 .78485 L .51788 .79021 L p .707 .577 .707 r
F P
0 g
s
.51577 .81956 m .51763 .80042 L .50474 .7984 L p .707 .577 .707 r
F P
0 g
s
.50474 .7984 m .50288 .81754 L .51577 .81956 L p .707 .577 .707 r
F P
0 g
s
.70063 .75712 m .699 .79502 L .70601 .79019 L p .707 .577 .707 r
F P
0 g
s
.70601 .79019 m .70764 .75228 L .70063 .75712 L p .707 .577 .707 r
F P
0 g
s
.70641 .66858 m .70718 .72361 L .70428 .71408 L p .707 .577 .707 r
F P
0 g
s
.70428 .71408 m .7035 .65905 L .70641 .66858 L p .707 .577 .707 r
F P
0 g
s
.50253 .66714 m .5033 .72216 L .5062 .7317 L p .707 .577 .707 r
F P
0 g
s
.69789 .81744 m .69603 .83657 L .70271 .8364 L p .707 .577 .707 r
F P
0 g
s
.70271 .8364 m .70457 .81726 L .69789 .81744 L p .707 .577 .707 r
F P
0 g
s
.50523 .78485 m .50686 .74695 L .5039 .74159 L p .707 .577 .707 r
F P
0 g
s
.48631 .81979 m .49313 .31364 L .44912 .31072 L p .707 .577 .707 r
F P
0 g
s
.5039 .74159 m .50226 .77949 L .50523 .78485 L p .707 .577 .707 r
F P
0 g
s
.5033 .72216 m .50253 .66714 L .5096 .65768 L p .707 .577 .707 r
F P
0 g
s
.50288 .81754 m .50474 .7984 L .50148 .79725 L p .707 .577 .707 r
F P
0 g
s
.50148 .79725 m .49962 .81638 L .50288 .81754 L p .707 .577 .707 r
F P
0 g
s
.5096 .65768 m .51038 .7127 L .5033 .72216 L p .707 .577 .707 r
F P
0 g
s
.50226 .77949 m .5039 .74159 L .5109 .73675 L p .707 .577 .707 r
F P
0 g
s
.51038 .7127 m .5096 .65768 L .52596 .64922 L p .707 .577 .707 r
F P
0 g
s
.5109 .73675 m .50927 .77466 L .50226 .77949 L p .707 .577 .707 r
F P
0 g
s
.49962 .81638 m .50148 .79725 L .50816 .79707 L p .707 .577 .707 r
F P
0 g
s
.50816 .79707 m .5063 .81621 L .49962 .81638 L p .707 .577 .707 r
F P
0 g
s
.52596 .64922 m .52674 .70424 L .51038 .7127 L p .707 .577 .707 r
F P
0 g
s
.50927 .77466 m .5109 .73675 L .5272 .73291 L p .707 .577 .707 r
F P
0 g
s
.5272 .73291 m .52556 .77082 L .50927 .77466 L p .707 .577 .707 r
F P
0 g
s
.5063 .81621 m .50816 .79707 L .52413 .7979 L p .707 .577 .707 r
F P
0 g
s
.52413 .7979 m .52227 .81703 L .5063 .81621 L p .707 .577 .707 r
F P
0 g
s
.52556 .77082 m .5272 .73291 L .55118 .73045 L p .707 .577 .707 r
F P
0 g
s
.55118 .73045 m .54955 .76835 L .52556 .77082 L p .707 .577 .707 r
F P
0 g
s
.52227 .81703 m .52413 .7979 L .54781 .79964 L p .707 .577 .707 r
F P
0 g
s
.54781 .79964 m .54595 .81877 L .52227 .81703 L p .707 .577 .707 r
F P
0 g
s
.49313 .31364 m .48631 .81979 L .53125 .81939 L p .707 .577 .707 r
F P
0 g
s
.52674 .70424 m .52596 .64922 L .55001 .64258 L p .707 .577 .707 r
F P
0 g
s
.55001 .64258 m .55078 .6976 L .52674 .70424 L p .707 .577 .707 r
F P
0 g
s
.53125 .81939 m .53807 .31324 L .49313 .31364 L p .707 .577 .707 r
F P
0 g
s
.55078 .6976 m .55001 .64258 L .57938 .63841 L p .707 .577 .707 r
F P
0 g
s
.57938 .63841 m .58016 .69344 L .55078 .6976 L p .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55118 .73045 L .55665 .73029 L p .707 .577 .707 r
F P
0 g
s
.55665 .73029 m .58051 .72959 L p .55124 .76624 L .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55665 .73029 L .55124 .76624 L .707 .577 .707 r
F
.58016 .69344 m .57938 .63841 L .61122 .63713 L p F P
0 g
s
.61122 .63713 m .61199 .69216 L .58016 .69344 L p .707 .577 .707 r
F P
0 g
s
.58051 .72959 m .57887 .7675 L .54955 .76835 L p .707 .577 .707 r
F P
0 g
s
.54595 .81877 m .54781 .79964 L .57691 .80212 L p .707 .577 .707 r
F P
0 g
s
.57691 .80212 m .57505 .82126 L .54595 .81877 L p .707 .577 .707 r
F P
0 g
s
.57887 .7675 m .58051 .72959 L .61231 .73044 L p .707 .577 .707 r
F P
0 g
s
.61231 .73044 m .61067 .76835 L .57887 .7675 L p .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .57691 .80212 L .58257 .80265 L p .707 .577 .707 r
F P
0 g
s
.58257 .80265 m .60856 .80511 L p .5803 .81873 L .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .58257 .80265 L .5803 .81873 L .707 .577 .707 r
F
.64239 .63886 m .64316 .69389 L .61199 .69216 L p F P
0 g
s
.61199 .69216 m .61122 .63713 L .64239 .63886 L p .707 .577 .707 r
F P
0 g
s
.64347 .7329 m .64183 .7708 L .61067 .76835 L p .707 .577 .707 r
F P
0 g
s
.61067 .76835 m .61231 .73044 L .64347 .7329 L p .707 .577 .707 r
F P
0 g
s
.6067 .82424 m .60856 .80511 L .63967 .80831 L p .707 .577 .707 r
F P
0 g
s
.60856 .80511 m .6067 .82424 L .57505 .82126 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .62977 .80022 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.61349 .30296 m .60931 .61321 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.60931 .61321 m .60667 .80911 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .60667 .80911 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57954 .30956 m .57557 .60473 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57557 .60473 m .57273 .81571 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.53807 .31324 m .53125 .81939 L .57273 .81571 L p .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .57954 .30956 L .53807 .31324 L p .707 .577 .707 r
F P
0 g
s
.44231 .81687 m .44912 .31072 L .41036 .30476 L p .707 .577 .707 r
F P
0 g
s
.44912 .31072 m .44231 .81687 L .48631 .81979 L p .707 .577 .707 r
F P
0 g
s
.70764 .75228 m .70601 .79019 L .70304 .78483 L p .707 .577 .707 r
F P
0 g
s
.70304 .78483 m .70468 .74692 L .70764 .75228 L p .707 .577 .707 r
F P
0 g
s
.7035 .65905 m .70428 .71408 L .69168 .70541 L p .707 .577 .707 r
F P
0 g
s
.69168 .70541 m .69091 .65038 L .7035 .65905 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .61349 .30296 L .57954 .30956 L p .707 .577 .707 r
F P
0 g
s
.70457 .81726 m .70271 .8364 L .69945 .83525 L p .707 .577 .707 r
F P
0 g
s
.69945 .83525 m .70131 .81611 L .70457 .81726 L p .707 .577 .707 r
F P
0 g
s
.25548 .7168 m .25471 .66177 L .22354 .66005 L p .707 .577 .707 r
F P
0 g
s
.25471 .66177 m .25548 .7168 L .28731 .71552 L p .707 .577 .707 r
F P
0 g
s
.28731 .71552 m .28654 .66049 L .25471 .66177 L p .707 .577 .707 r
F P
0 g
s
.40354 .81091 m .41036 .30476 L .38063 .29635 L p .707 .577 .707 r
F P
0 g
s
.41036 .30476 m .40354 .81091 L .44231 .81687 L p .707 .577 .707 r
F P
0 g
s
.28654 .66049 m .28731 .71552 L .31669 .71135 L p .707 .577 .707 r
F P
0 g
s
.31669 .71135 m .31592 .65633 L .28654 .66049 L p .707 .577 .707 r
F P
0 g
s
.22431 .71507 m .22354 .66005 L .19608 .65548 L p .707 .577 .707 r
F P
0 g
s
.22354 .66005 m .22431 .71507 L .25548 .7168 L p .707 .577 .707 r
F P
0 g
s
.31592 .65633 m .31669 .71135 L .34074 .70472 L p .707 .577 .707 r
F P
0 g
s
.34074 .70472 m .33996 .64969 L .31592 .65633 L p .707 .577 .707 r
F P
0 g
s
.70468 .74692 m .70304 .78483 L .69039 .77947 L p .707 .577 .707 r
F P
0 g
s
.69039 .77947 m .69203 .74156 L .70468 .74692 L p .707 .577 .707 r
F P
0 g
s
.69091 .65038 m .69168 .70541 L .67062 .69845 L p .707 .577 .707 r
F P
0 g
s
.67062 .69845 m .66985 .64343 L .69091 .65038 L p .707 .577 .707 r
F P
0 g
s
.62977 .80022 m .63659 .29407 L .61349 .30296 L p .707 .577 .707 r
F P
0 g
s
.25459 .76452 m .25622 .72661 L .22506 .72415 L p .707 .577 .707 r
F P
0 g
s
.25622 .72661 m .25459 .76452 L .28639 .76537 L p .707 .577 .707 r
F P
0 g
s
.28639 .76537 m .28802 .72746 L .25622 .72661 L p .707 .577 .707 r
F P
0 g
s
.19685 .71051 m .19608 .65548 L .17502 .64852 L p .707 .577 .707 r
F P
0 g
s
.19608 .65548 m .19685 .71051 L .22431 .71507 L p .707 .577 .707 r
F P
0 g
s
.28802 .72746 m .28639 .76537 L .31572 .76451 L p .707 .577 .707 r
F P
0 g
s
.31572 .76451 m .31735 .72661 L .28802 .72746 L p .707 .577 .707 r
F P
0 g
s
.70131 .81611 m .69945 .83525 L .68657 .83323 L p .707 .577 .707 r
F P
0 g
s
.68657 .83323 m .68843 .81409 L .70131 .81611 L p .707 .577 .707 r
F P
0 g
s
.22506 .72415 m .22343 .76206 L .25459 .76452 L p .707 .577 .707 r
F P
0 g
s
.22343 .76206 m .22506 .72415 L .19759 .72032 L p .707 .577 .707 r
F P
0 g
s
.25263 .79173 m .25449 .77259 L .22338 .76939 L p .707 .577 .707 r
F P
0 g
s
.25449 .77259 m .25263 .79173 L .28428 .79471 L p .707 .577 .707 r
F P
0 g
s
.28428 .79471 m .28614 .77558 L .25449 .77259 L p .707 .577 .707 r
F P
0 g
s
.22338 .76939 m .22152 .78853 L .25263 .79173 L p .707 .577 .707 r
F P
0 g
s
.28614 .77558 m .28428 .79471 L .31337 .7972 L p .707 .577 .707 r
F P
0 g
s
.31337 .7972 m .31523 .77806 L .28614 .77558 L p .707 .577 .707 r
F P
0 g
s
.37381 .8025 m .38063 .29635 L .36284 .2863 L p .707 .577 .707 r
F P
0 g
s
.38063 .29635 m .37381 .8025 L .40354 .81091 L p .707 .577 .707 r
F P
0 g
s
.33996 .64969 m .34074 .70472 L .3571 .69625 L p .707 .577 .707 r
F P
0 g
s
.3571 .69625 m .35632 .64123 L .33996 .64969 L p .707 .577 .707 r
F P
0 g
s
.19759 .72032 m .19596 .75823 L .22343 .76206 L p .707 .577 .707 r
F P
0 g
s
.22152 .78853 m .22338 .76939 L .19586 .7663 L p .707 .577 .707 r
F P
0 g
s
.19586 .7663 m .194 .78543 L .22152 .78853 L p .707 .577 .707 r
F P
0 g
s
.31735 .72661 m .31572 .76451 L .3397 .76205 L p .707 .577 .707 r
F P
0 g
s
.3397 .76205 m .34133 .72414 L .31735 .72661 L p .707 .577 .707 r
F P
0 g
s
.66985 .64343 m .67062 .69845 L .64316 .69389 L p .707 .577 .707 r
F P
0 g
s
.64316 .69389 m .64239 .63886 L .66985 .64343 L p .707 .577 .707 r
F P
0 g
s
.17502 .64852 m .17579 .70355 L .19685 .71051 L p .707 .577 .707 r
F P
0 g
s
.19596 .75823 m .19759 .72032 L .1765 .71549 L p .707 .577 .707 r
F P
0 g
s
.69203 .74156 m .69039 .77947 L .6693 .77464 L p .707 .577 .707 r
F P
0 g
s
.6693 .77464 m .67094 .73673 L .69203 .74156 L p .707 .577 .707 r
F P
0 g
s
.17579 .70355 m .17502 .64852 L .16242 .63985 L p .707 .577 .707 r
F P
0 g
s
.31523 .77806 m .31337 .7972 L .33706 .79894 L p .707 .577 .707 r
F P
0 g
s
.33706 .79894 m .33892 .7798 L .31523 .77806 L p .707 .577 .707 r
F P
0 g
s
.1765 .71549 m .17487 .7534 L .19596 .75823 L p .707 .577 .707 r
F P
0 g
s
.194 .78543 m .19586 .7663 L .17462 .76361 L p .707 .577 .707 r
F P
0 g
s
.17462 .76361 m .17276 .78274 L .194 .78543 L p .707 .577 .707 r
F P
0 g
s
.68843 .81409 m .68657 .83323 L .66533 .83054 L p .707 .577 .707 r
F P
0 g
s
.66533 .83054 m .66719 .8114 L .68843 .81409 L p .707 .577 .707 r
F P
0 g
s
.63659 .29407 m .62977 .80022 L .63976 .78993 L p .707 .577 .707 r
F P
0 g
s
.63976 .78993 m .64658 .28379 L .63659 .29407 L p .707 .577 .707 r
F P
0 g
s
.34133 .72414 m .3397 .76205 L .35599 .75821 L p .707 .577 .707 r
F P
0 g
s
.35599 .75821 m .35763 .7203 L .34133 .72414 L p .707 .577 .707 r
F P
0 g
s
.35632 .64123 m .3571 .69625 L .36417 .68679 L p .707 .577 .707 r
F P
0 g
s
.36417 .68679 m .3634 .63177 L .35632 .64123 L p .707 .577 .707 r
F P
0 g
s
.16242 .63985 m .16319 .69488 L .17579 .70355 L p .707 .577 .707 r
F P
0 g
s
.33892 .7798 m .33706 .79894 L .35302 .79976 L p .707 .577 .707 r
F P
0 g
s
.35302 .79976 m .35488 .78062 L .33892 .7798 L p .707 .577 .707 r
F P
0 g
s
.17487 .7534 m .1765 .71549 L .16385 .71013 L p .707 .577 .707 r
F P
0 g
s
.67094 .73673 m .6693 .77464 L .64183 .7708 L p .707 .577 .707 r
F P
0 g
s
.64183 .7708 m .64347 .7329 L .67094 .73673 L p .707 .577 .707 r
F P
0 g
s
.16319 .69488 m .16242 .63985 L .15952 .63032 L p .707 .577 .707 r
F P
0 g
s
.35763 .7203 m .35599 .75821 L .363 .75337 L p .707 .577 .707 r
F P
0 g
s
.35488 .78062 m .35302 .79976 L .3597 .79959 L p .707 .577 .707 r
F P
0 g
s
.3597 .79959 m .36156 .78045 L .35488 .78062 L p .707 .577 .707 r
F P
0 g
s
.3605 .62224 m .36127 .67726 L .34867 .66859 L p .707 .577 .707 r
F P
0 g
s
.34867 .66859 m .3479 .61357 L .3605 .62224 L p .707 .577 .707 r
F P
0 g
s
.363 .75337 m .36463 .71546 L .35763 .7203 L p .707 .577 .707 r
F P
0 g
s
.36167 .71011 m .36003 .74801 L .35944 .74776 L p .707 .577 .707 r
F P
0 g
s
.35944 .74776 m .34739 .74266 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.35933 .71544 m .36167 .71011 L .35944 .74776 L .707 .577 .707 r
F
.36284 .2863 m .35874 .27561 L p .35818 .38242 L F P
0 g
s
.34739 .74266 m .34902 .70475 L .35931 .70911 L p .707 .577 .707 r
F P
0 g
s
.35931 .70911 m .36167 .71011 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.34739 .74266 m .35931 .70911 L .35933 .71544 L .707 .577 .707 r
F
.3583 .7793 m .35644 .79843 L .34356 .79641 L p F P
0 g
s
.34356 .79641 m .34542 .77728 L .3583 .7793 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35603 .79245 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35874 .27561 m .358 .33057 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.358 .33057 m .35193 .78176 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35603 .79245 m .35887 .58147 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35887 .58147 m .36284 .2863 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.3634 .63177 m .36417 .68679 L .36127 .67726 L p .707 .577 .707 r
F P
0 g
s
.36127 .67726 m .3605 .62224 L .3634 .63177 L p .707 .577 .707 r
F P
0 g
s
.36463 .71546 m .363 .75337 L .36003 .74801 L p .707 .577 .707 r
F P
0 g
s
.36003 .74801 m .36167 .71011 L .36463 .71546 L p .707 .577 .707 r
F P
0 g
s
.36156 .78045 m .3597 .79959 L .35644 .79843 L p .707 .577 .707 r
F P
0 g
s
.35644 .79843 m .3583 .7793 L .36156 .78045 L p .707 .577 .707 r
F P
0 g
s
.36284 .2863 m .35603 .79245 L .37381 .8025 L p .707 .577 .707 r
F P
0 g
s
.16385 .71013 m .16222 .74804 L .17487 .7534 L p .707 .577 .707 r
F P
0 g
s
.17276 .78274 m .17462 .76361 L .16173 .76159 L p .707 .577 .707 r
F P
0 g
s
.16173 .76159 m .15988 .78072 L .17276 .78274 L p .707 .577 .707 r
F P
0 g
s
.66719 .8114 m .66533 .83054 L .63781 .82744 L p .707 .577 .707 r
F P
0 g
s
.63781 .82744 m .63967 .80831 L .66719 .8114 L p .707 .577 .707 r
F P
0 g
s
.15952 .63032 m .16029 .68535 L .16319 .69488 L p .707 .577 .707 r
F P
0 g
s
.63967 .80831 m .63781 .82744 L .6067 .82424 L p .707 .577 .707 r
F P
0 g
s
.16222 .74804 m .16385 .71013 L .16089 .70477 L p .707 .577 .707 r
F P
0 g
s
.64658 .28379 m .63976 .78993 L .63566 .77925 L p .707 .577 .707 r
F P
0 g
s
.63566 .77925 m .64248 .2731 L .64658 .28379 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16089 .70477 m .15925 .74268 L .16222 .74804 L p .707 .577 .707 r
F P
0 g
s
.16029 .68535 m .15952 .63032 L .16659 .62086 L p .707 .577 .707 r
F P
0 g
s
.15988 .78072 m .16173 .76159 L .15847 .76043 L p .707 .577 .707 r
F P
0 g
s
.15847 .76043 m .15661 .77957 L .15988 .78072 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35874 .27561 L .36873 .26532 L p .707 .577 .707 r
F P
0 g
s
.16659 .62086 m .16737 .67589 L .16029 .68535 L p .707 .577 .707 r
F P
0 g
s
.15925 .74268 m .16089 .70477 L .16789 .69994 L p .707 .577 .707 r
F P
0 g
s
.16737 .67589 m .16659 .62086 L .18295 .6124 L p .707 .577 .707 r
F P
0 g
s
.16789 .69994 m .16626 .73784 L .15925 .74268 L p .707 .577 .707 r
F P
0 g
s
.15661 .77957 m .15847 .76043 L .16515 .76026 L p .707 .577 .707 r
F P
0 g
s
.16515 .76026 m .16329 .7794 L .15661 .77957 L p .707 .577 .707 r
F P
0 g
s
.64248 .2731 m .63566 .77925 L .61788 .7692 L p .707 .577 .707 r
F P
0 g
s
.61788 .7692 m .62469 .26305 L .64248 .2731 L p .707 .577 .707 r
F P
0 g
s
.3479 .61357 m .34867 .66859 L .32761 .66164 L p .707 .577 .707 r
F P
0 g
s
.32761 .66164 m .32684 .60661 L .3479 .61357 L p .707 .577 .707 r
F P
0 g
s
.18295 .6124 m .18373 .66743 L .16737 .67589 L p .707 .577 .707 r
F P
0 g
s
.16626 .73784 m .16789 .69994 L .18419 .6961 L p .707 .577 .707 r
F P
0 g
s
.18373 .66743 m .18295 .6124 L .207 .60576 L p .707 .577 .707 r
F P
0 g
s
.36192 .77147 m .36873 .26532 L .39183 .25644 L p .707 .577 .707 r
F P
0 g
s
.36873 .26532 m .36192 .77147 L .35193 .78176 L p .707 .577 .707 r
F P
0 g
s
.18419 .6961 m .18255 .734 L .16626 .73784 L p .707 .577 .707 r
F P
0 g
s
.16329 .7794 m .16515 .76026 L .18112 .76108 L p .707 .577 .707 r
F P
0 g
s
.18112 .76108 m .17926 .78022 L .16329 .7794 L p .707 .577 .707 r
F P
0 g
s
.32684 .60661 m .32761 .66164 L .30015 .65707 L p .707 .577 .707 r
F P
0 g
s
.30015 .65707 m .29938 .60205 L .32684 .60661 L p .707 .577 .707 r
F P
0 g
s
.34902 .70475 m .34739 .74266 L .32629 .73782 L p .707 .577 .707 r
F P
0 g
s
.32629 .73782 m .32793 .69992 L .34902 .70475 L p .707 .577 .707 r
F P
0 g
s
.207 .60576 m .20777 .66079 L .18373 .66743 L p .707 .577 .707 r
F P
0 g
s
.20777 .66079 m .207 .60576 L .23638 .6016 L p .707 .577 .707 r
F P
0 g
s
.62469 .26305 m .61788 .7692 L .58815 .76079 L p .707 .577 .707 r
F P
0 g
s
.58815 .76079 m .59496 .25464 L .62469 .26305 L p .707 .577 .707 r
F P
0 g
s
.18255 .734 m .18419 .6961 L .20817 .69363 L p .707 .577 .707 r
F P
0 g
s
.29938 .60205 m .30015 .65707 L .26898 .65534 L p .707 .577 .707 r
F P
0 g
s
.26898 .65534 m .26821 .60032 L .29938 .60205 L p .707 .577 .707 r
F P
0 g
s
.34542 .77728 m .34356 .79641 L .32232 .79372 L p .707 .577 .707 r
F P
0 g
s
.32232 .79372 m .32418 .77459 L .34542 .77728 L p .707 .577 .707 r
F P
0 g
s
.23715 .65662 m .23638 .6016 L .26821 .60032 L p .707 .577 .707 r
F P
0 g
s
.23638 .6016 m .23715 .65662 L .20777 .66079 L p .707 .577 .707 r
F P
0 g
s
.20817 .69363 m .20654 .73154 L .18255 .734 L p .707 .577 .707 r
F P
0 g
s
.26821 .60032 m .26898 .65534 L .23715 .65662 L p .707 .577 .707 r
F P
0 g
s
.17926 .78022 m .18112 .76108 L .2048 .76282 L p .707 .577 .707 r
F P
0 g
s
.7357 .65691 m .73492 .60188 L .70375 .60015 L p .707 .577 .707 r
F P
0 g
s
.73492 .60188 m .7357 .65691 L .76753 .65563 L p .707 .577 .707 r
F P
0 g
s
.76753 .65563 m .76675 .6006 L .73492 .60188 L p .707 .577 .707 r
F P
0 g
s
.2048 .76282 m .20295 .78196 L .17926 .78022 L p .707 .577 .707 r
F P
0 g
s
.39183 .25644 m .38502 .76259 L .36192 .77147 L p .707 .577 .707 r
F P
0 g
s
.38502 .76259 m .39183 .25644 L .42578 .24984 L p .707 .577 .707 r
F P
0 g
s
.76675 .6006 m .76753 .65563 L .7969 .65146 L p .707 .577 .707 r
F P
0 g
s
.7969 .65146 m .79613 .59644 L .76675 .6006 L p .707 .577 .707 r
F P
0 g
s
.32793 .69992 m .32629 .73782 L .29882 .73399 L p .707 .577 .707 r
F P
0 g
s
.29882 .73399 m .30046 .69608 L .32793 .69992 L p .707 .577 .707 r
F P
0 g
s
.70452 .65518 m .70375 .60015 L .67629 .59559 L p .707 .577 .707 r
F P
0 g
s
.70375 .60015 m .70452 .65518 L .7357 .65691 L p .707 .577 .707 r
F P
0 g
s
.20654 .73154 m .20817 .69363 L .2375 .69278 L p .707 .577 .707 r
F P
0 g
s
.79613 .59644 m .7969 .65146 L .82095 .64482 L p .707 .577 .707 r
F P
0 g
s
.82095 .64482 m .82018 .5898 L .79613 .59644 L p .707 .577 .707 r
F P
0 g
s
.32418 .77459 m .32232 .79372 L .2948 .79063 L p .707 .577 .707 r
F P
0 g
s
.2948 .79063 m .29666 .77149 L .32418 .77459 L p .707 .577 .707 r
F P
0 g
s
.2375 .69278 m .23586 .73069 L .20654 .73154 L p .707 .577 .707 r
F P
0 g
s
.30046 .69608 m .29882 .73399 L .26766 .73153 L p .707 .577 .707 r
F P
0 g
s
.26766 .73153 m .2693 .69362 L .30046 .69608 L p .707 .577 .707 r
F P
0 g
s
.59496 .25464 m .58815 .76079 L .54938 .75483 L p .707 .577 .707 r
F P
0 g
s
.54938 .75483 m .5562 .24868 L .59496 .25464 L p .707 .577 .707 r
F P
0 g
s
.20295 .78196 m .2048 .76282 L .2339 .76531 L p .707 .577 .707 r
F P
0 g
s
.7348 .70272 m .73644 .66481 L .70528 .66236 L p .707 .577 .707 r
F P
0 g
s
.73644 .66481 m .7348 .70272 L .7666 .70357 L p .707 .577 .707 r
F P
0 g
s
.7666 .70357 m .76824 .66566 L .73644 .66481 L p .707 .577 .707 r
F P
0 g
s
.2339 .76531 m .23204 .78444 L .20295 .78196 L p .707 .577 .707 r
F P
0 g
s
.67707 .65061 m .67629 .59559 L .65523 .58863 L p .707 .577 .707 r
F P
0 g
s
.67629 .59559 m .67707 .65061 L .70452 .65518 L p .707 .577 .707 r
F P
0 g
s
.23586 .73069 m .2375 .69278 L .2693 .69362 L p .707 .577 .707 r
F P
0 g
s
.76824 .66566 m .7666 .70357 L .79593 .70271 L p .707 .577 .707 r
F P
0 g
s
.79593 .70271 m .79756 .66481 L .76824 .66566 L p .707 .577 .707 r
F P
0 g
s
.2693 .69362 m .26766 .73153 L .23586 .73069 L p .707 .577 .707 r
F P
0 g
s
.70528 .66236 m .70364 .70026 L .7348 .70272 L p .707 .577 .707 r
F P
0 g
s
.70364 .70026 m .70528 .66236 L .67781 .65852 L p .707 .577 .707 r
F P
0 g
s
.41896 .75599 m .42578 .24984 L .46725 .24615 L p .707 .577 .707 r
F P
0 g
s
.42578 .24984 m .41896 .75599 L .38502 .76259 L p .707 .577 .707 r
F P
0 g
s
.29666 .77149 m .2948 .79063 L .26369 .78743 L p .707 .577 .707 r
F P
0 g
s
.26369 .78743 m .26555 .76829 L .29666 .77149 L p .707 .577 .707 r
F P
0 g
s
.73284 .73408 m .7347 .71494 L .70359 .71175 L p .707 .577 .707 r
F P
0 g
s
.7347 .71494 m .73284 .73408 L .76449 .73707 L p .707 .577 .707 r
F P
0 g
s
.76449 .73707 m .76635 .71793 L .7347 .71494 L p .707 .577 .707 r
F P
0 g
s
.70359 .71175 m .70173 .73088 L .73284 .73408 L p .707 .577 .707 r
F P
0 g
s
.23204 .78444 m .2339 .76531 L .26555 .76829 L p .707 .577 .707 r
F P
0 g
s
.76635 .71793 m .76449 .73707 L .79358 .73955 L p .707 .577 .707 r
F P
0 g
s
.79358 .73955 m .79544 .72042 L .76635 .71793 L p .707 .577 .707 r
F P
0 g
s
.67781 .65852 m .67617 .69643 L .70364 .70026 L p .707 .577 .707 r
F P
0 g
s
.26555 .76829 m .26369 .78743 L .23204 .78444 L p .707 .577 .707 r
F P
0 g
s
.82018 .5898 m .82095 .64482 L .83731 .63636 L p .707 .577 .707 r
F P
0 g
s
.83731 .63636 m .83654 .58134 L .82018 .5898 L p .707 .577 .707 r
F P
0 g
s
.79756 .66481 m .79593 .70271 L .81991 .70025 L p .707 .577 .707 r
F P
0 g
s
.81991 .70025 m .82155 .66234 L .79756 .66481 L p .707 .577 .707 r
F P
0 g
s
.70173 .73088 m .70359 .71175 L .67607 .70865 L p .707 .577 .707 r
F P
0 g
s
.67607 .70865 m .67421 .72779 L .70173 .73088 L p .707 .577 .707 r
F P
0 g
s
.65523 .58863 m .65601 .64366 L .67707 .65061 L p .707 .577 .707 r
F P
0 g
s
.5562 .24868 m .54938 .75483 L .50538 .75191 L p .707 .577 .707 r
F P
0 g
s
.50538 .75191 m .51219 .24576 L .5562 .24868 L p .707 .577 .707 r
F P
0 g
s
.67617 .69643 m .67781 .65852 L .65671 .65369 L p .707 .577 .707 r
F P
0 g
s
.65601 .64366 m .65523 .58863 L .64263 .57996 L p .707 .577 .707 r
F P
0 g
s
.79544 .72042 m .79358 .73955 L .81727 .74129 L p .707 .577 .707 r
F P
0 g
s
.81727 .74129 m .81913 .72215 L .79544 .72042 L p .707 .577 .707 r
F P
0 g
s
.46044 .7523 m .46725 .24615 L .51219 .24576 L p .707 .577 .707 r
F P
0 g
s
.46725 .24615 m .46044 .7523 L .41896 .75599 L p .707 .577 .707 r
F P
0 g
s
.65671 .65369 m .65508 .6916 L .67617 .69643 L p .707 .577 .707 r
F P
0 g
s
.51219 .24576 m .50538 .75191 L .46044 .7523 L p .707 .577 .707 r
F P
0 g
s
.67421 .72779 m .67607 .70865 L .65483 .70596 L p .707 .577 .707 r
F P
0 g
s
.65483 .70596 m .65297 .7251 L .67421 .72779 L p .707 .577 .707 r
F P
0 g
s
.82155 .66234 m .81991 .70025 L .83621 .69641 L p .707 .577 .707 r
F P
0 g
s
.83621 .69641 m .83784 .6585 L .82155 .66234 L p .707 .577 .707 r
F P
0 g
s
.83654 .58134 m .83731 .63636 L .84439 .6269 L p .707 .577 .707 r
F P
0 g
s
.84439 .6269 m .84361 .57188 L .83654 .58134 L p .707 .577 .707 r
F P
0 g
s
.64263 .57996 m .64341 .63499 L .65601 .64366 L p .707 .577 .707 r
F P
0 g
s
.65508 .6916 m .65671 .65369 L .64407 .64833 L p .707 .577 .707 r
F P
0 g
s
.81913 .72215 m .81727 .74129 L .83324 .74211 L p .707 .577 .707 r
F P
0 g
s
.83324 .74211 m .8351 .72298 L .81913 .72215 L p .707 .577 .707 r
F P
0 g
s
.64341 .63499 m .64263 .57996 L .63973 .57043 L p .707 .577 .707 r
F P
0 g
s
.64407 .64833 m .64243 .68624 L .65508 .6916 L p .707 .577 .707 r
F P
0 g
s
.65297 .7251 m .65483 .70596 L .64195 .70394 L p .707 .577 .707 r
F P
0 g
s
.64195 .70394 m .64009 .72308 L .65297 .7251 L p .707 .577 .707 r
F P
0 g
s
.83784 .6585 m .83621 .69641 L .84321 .69157 L p .707 .577 .707 r
F P
0 g
s
.84321 .69157 m .84485 .65367 L .83784 .6585 L p .707 .577 .707 r
F P
0 g
s
.84361 .57188 m .84439 .6269 L .84148 .61737 L p .707 .577 .707 r
F P
0 g
s
.84148 .61737 m .84071 .56234 L .84361 .57188 L p .707 .577 .707 r
F P
0 g
s
.63973 .57043 m .6405 .62546 L .64341 .63499 L p .707 .577 .707 r
F P
0 g
s
.8351 .72298 m .83324 .74211 L .83992 .74194 L p .707 .577 .707 r
F P
0 g
s
.83992 .74194 m .84178 .7228 L .8351 .72298 L p .707 .577 .707 r
F P
0 g
s
.64243 .68624 m .64407 .64833 L .6411 .64297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6411 .64297 m .63947 .68088 L .64243 .68624 L p .707 .577 .707 r
F P
0 g
s
.6405 .62546 m .63973 .57043 L .6468 .56097 L p .707 .577 .707 r
F P
0 g
s
.64009 .72308 m .64195 .70394 L .63869 .70279 L p .707 .577 .707 r
F P
0 g
s
.63869 .70279 m .63683 .72192 L .64009 .72308 L p .707 .577 .707 r
F P
0 g
s
.84485 .65367 m .84321 .69157 L .84025 .68621 L p .707 .577 .707 r
F P
0 g
s
.84025 .68621 m .84188 .64831 L .84485 .65367 L p .707 .577 .707 r
F P
0 g
s
.84071 .56234 m .84148 .61737 L .82889 .6087 L p .707 .577 .707 r
F P
0 g
s
.82889 .6087 m .82811 .55368 L .84071 .56234 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6468 .56097 m .64758 .616 L .6405 .62546 L p .707 .577 .707 r
F P
0 g
s
.84178 .7228 m .83992 .74194 L .83666 .74079 L p .707 .577 .707 r
F P
0 g
s
.83666 .74079 m .83852 .72165 L .84178 .7228 L p .707 .577 .707 r
F P
0 g
s
.63947 .68088 m .6411 .64297 L .64811 .63814 L p .707 .577 .707 r
F P
0 g
s
.39269 .62009 m .39191 .56507 L .36074 .56334 L p .707 .577 .707 r
F P
0 g
s
.39191 .56507 m .39269 .62009 L .42452 .61881 L p .707 .577 .707 r
F P
0 g
s
.42452 .61881 m .42374 .56378 L .39191 .56507 L p .707 .577 .707 r
F P
0 g
s
.64758 .616 m .6468 .56097 L .66317 .55251 L p .707 .577 .707 r
F P
0 g
s
.64811 .63814 m .64647 .67604 L .63947 .68088 L p .707 .577 .707 r
F P
0 g
s
.42374 .56378 m .42452 .61881 L .45389 .61465 L p .707 .577 .707 r
F P
0 g
s
.45389 .61465 m .45312 .55962 L .42374 .56378 L p .707 .577 .707 r
F P
0 g
s
.63683 .72192 m .63869 .70279 L .64537 .70261 L p .707 .577 .707 r
F P
0 g
s
.64537 .70261 m .64351 .72175 L .63683 .72192 L p .707 .577 .707 r
F P
0 g
s
.36151 .61836 m .36074 .56334 L .33328 .55877 L p .707 .577 .707 r
F P
0 g
s
.36074 .56334 m .36151 .61836 L .39269 .62009 L p .707 .577 .707 r
F P
0 g
s
.45312 .55962 m .45389 .61465 L .47794 .60801 L p .707 .577 .707 r
F P
0 g
s
.47794 .60801 m .47717 .55298 L .45312 .55962 L p .707 .577 .707 r
F P
0 g
s
.84188 .64831 m .84025 .68621 L .8276 .68086 L p .707 .577 .707 r
F P
0 g
s
.8276 .68086 m .82923 .64295 L .84188 .64831 L p .707 .577 .707 r
F P
0 g
s
.82811 .55368 m .82889 .6087 L .80783 .60174 L p .707 .577 .707 r
F P
0 g
s
.80783 .60174 m .80705 .54672 L .82811 .55368 L p .707 .577 .707 r
F P
0 g
s
.66317 .55251 m .66394 .60753 L .64758 .616 L p .707 .577 .707 r
F P
0 g
s
.39179 .66591 m .39343 .628 L .36227 .62554 L p .707 .577 .707 r
F P
0 g
s
.39343 .628 m .39179 .66591 L .42359 .66675 L p .707 .577 .707 r
F P
0 g
s
.42359 .66675 m .42523 .62884 L .39343 .628 L p .707 .577 .707 r
F P
0 g
s
.33406 .6138 m .33328 .55877 L .31222 .55181 L p .707 .577 .707 r
F P
0 g
s
.33328 .55877 m .33406 .6138 L .36151 .61836 L p .707 .577 .707 r
F P
0 g
s
.42523 .62884 m .42359 .66675 L .45292 .6659 L p .707 .577 .707 r
F P
0 g
s
.45292 .6659 m .45455 .62799 L .42523 .62884 L p .707 .577 .707 r
F P
0 g
s
.64647 .67604 m .64811 .63814 L .6644 .6343 L p .707 .577 .707 r
F P
0 g
s
.83852 .72165 m .83666 .74079 L .82377 .73876 L p .707 .577 .707 r
F P
0 g
s
.82377 .73876 m .82563 .71963 L .83852 .72165 L p .707 .577 .707 r
F P
0 g
s
.66394 .60753 m .66317 .55251 L .68721 .54587 L p .707 .577 .707 r
F P
0 g
s
.36227 .62554 m .36063 .66345 L .39179 .66591 L p .707 .577 .707 r
F P
0 g
s
.36063 .66345 m .36227 .62554 L .3348 .62171 L p .707 .577 .707 r
F P
0 g
s
.38983 .69726 m .39169 .67813 L .36058 .67493 L p .707 .577 .707 r
F P
0 g
s
.39169 .67813 m .38983 .69726 L .42148 .70025 L p .707 .577 .707 r
F P
0 g
s
.42148 .70025 m .42334 .68112 L .39169 .67813 L p .707 .577 .707 r
F P
0 g
s
.36058 .67493 m .35872 .69407 L .38983 .69726 L p .707 .577 .707 r
F P
0 g
s
.6644 .6343 m .66277 .67221 L .64647 .67604 L p .707 .577 .707 r
F P
0 g
s
.42334 .68112 m .42148 .70025 L .45058 .70274 L p .707 .577 .707 r
F P
0 g
s
.45058 .70274 m .45243 .6836 L .42334 .68112 L p .707 .577 .707 r
F P
0 g
s
.3348 .62171 m .33316 .65961 L .36063 .66345 L p .707 .577 .707 r
F P
0 g
s
.47717 .55298 m .47794 .60801 L .4943 .59955 L p .707 .577 .707 r
F P
0 g
s
.4943 .59955 m .49353 .54452 L .47717 .55298 L p .707 .577 .707 r
F P
0 g
s
.45455 .62799 m .45292 .6659 L .4769 .66343 L p .707 .577 .707 r
F P
0 g
s
.4769 .66343 m .47854 .62552 L .45455 .62799 L p .707 .577 .707 r
F P
0 g
s
.64351 .72175 m .64537 .70261 L .66133 .70344 L p .707 .577 .707 r
F P
0 g
s
.35872 .69407 m .36058 .67493 L .33306 .67184 L p .707 .577 .707 r
F P
0 g
s
.66133 .70344 m .65947 .72257 L .64351 .72175 L p .707 .577 .707 r
F P
0 g
s
.33306 .67184 m .3312 .69097 L .35872 .69407 L p .707 .577 .707 r
F P
0 g
s
.80705 .54672 m .80783 .60174 L .78037 .59718 L p .707 .577 .707 r
F P
0 g
s
.78037 .59718 m .77959 .54215 L .80705 .54672 L p .707 .577 .707 r
F P
0 g
s
.31222 .55181 m .313 .60684 L .33406 .6138 L p .707 .577 .707 r
F P
0 g
s
.33316 .65961 m .3348 .62171 L .3137 .61687 L p .707 .577 .707 r
F P
0 g
s
.82923 .64295 m .8276 .68086 L .80651 .67602 L p .707 .577 .707 r
F P
0 g
s
.80651 .67602 m .80814 .63812 L .82923 .64295 L p .707 .577 .707 r
F P
0 g
s
.68721 .54587 m .68799 .6009 L .66394 .60753 L p .707 .577 .707 r
F P
0 g
s
.313 .60684 m .31222 .55181 L .29962 .54315 L p .707 .577 .707 r
F P
0 g
s
.45243 .6836 m .45058 .70274 L .47426 .70448 L p .707 .577 .707 r
F P
0 g
s
.47426 .70448 m .47612 .68534 L .45243 .6836 L p .707 .577 .707 r
F P
0 g
s
.68799 .6009 m .68721 .54587 L .71659 .54171 L p .707 .577 .707 r
F P
0 g
s
.3137 .61687 m .31207 .65478 L .33316 .65961 L p .707 .577 .707 r
F P
0 g
s
.3312 .69097 m .33306 .67184 L .31182 .66915 L p .707 .577 .707 r
F P
0 g
s
.66277 .67221 m .6644 .6343 L .68838 .63183 L p .707 .577 .707 r
F P
0 g
s
.31182 .66915 m .30996 .68828 L .3312 .69097 L p .707 .577 .707 r
F P
0 g
s
.77959 .54215 m .78037 .59718 L .7492 .59545 L p .707 .577 .707 r
F P
0 g
s
.7492 .59545 m .74842 .54043 L .77959 .54215 L p .707 .577 .707 r
F P
0 g
s
.82563 .71963 m .82377 .73876 L .80253 .73608 L p .707 .577 .707 r
F P
0 g
s
.80253 .73608 m .80439 .71694 L .82563 .71963 L p .707 .577 .707 r
F P
0 g
s
.47854 .62552 m .4769 .66343 L .4932 .65959 L p .707 .577 .707 r
F P
0 g
s
.4932 .65959 m .49483 .62169 L .47854 .62552 L p .707 .577 .707 r
F P
0 g
s
.71736 .59673 m .71659 .54171 L .74842 .54043 L p .707 .577 .707 r
F P
0 g
s
.71659 .54171 m .71736 .59673 L .68799 .6009 L p .707 .577 .707 r
F P
0 g
s
.68838 .63183 m .68675 .66974 L .66277 .67221 L p .707 .577 .707 r
F P
0 g
s
.49353 .54452 m .4943 .59955 L .50138 .59009 L p .707 .577 .707 r
F P
0 g
s
.50138 .59009 m .5006 .53506 L .49353 .54452 L p .707 .577 .707 r
F P
0 g
s
.74842 .54043 m .7492 .59545 L .71736 .59673 L p .707 .577 .707 r
F P
0 g
s
.29962 .54315 m .3004 .59817 L .313 .60684 L p .707 .577 .707 r
F P
0 g
s
.65947 .72257 m .66133 .70344 L .68502 .70517 L p .707 .577 .707 r
F P
0 g
s
.68502 .70517 m .68316 .72431 L .65947 .72257 L p .707 .577 .707 r
F P
0 g
s
.31207 .65478 m .3137 .61687 L .30106 .61152 L p .707 .577 .707 r
F P
0 g
s
.80814 .63812 m .80651 .67602 L .77904 .67219 L p .707 .577 .707 r
F P
0 g
s
.77904 .67219 m .78067 .63428 L .80814 .63812 L p .707 .577 .707 r
F P
0 g
s
.47612 .68534 m .47426 .70448 L .49023 .7053 L p .707 .577 .707 r
F P
0 g
s
.49023 .7053 m .49209 .68616 L .47612 .68534 L p .707 .577 .707 r
F P
0 g
s
.3004 .59817 m .29962 .54315 L .29672 .53362 L p .707 .577 .707 r
F P
0 g
s
.30106 .61152 m .29942 .64942 L .31207 .65478 L p .707 .577 .707 r
F P
0 g
s
.68675 .66974 m .68838 .63183 L .71771 .63098 L p .707 .577 .707 r
F P
0 g
s
.30996 .68828 m .31182 .66915 L .29894 .66713 L p .707 .577 .707 r
F P
0 g
s
.29894 .66713 m .29708 .68626 L .30996 .68828 L p .707 .577 .707 r
F P
0 g
s
.80439 .71694 m .80253 .73608 L .77501 .73298 L p .707 .577 .707 r
F P
0 g
s
.77501 .73298 m .77687 .71384 L .80439 .71694 L p .707 .577 .707 r
F P
0 g
s
.71771 .63098 m .71608 .66889 L .68675 .66974 L p .707 .577 .707 r
F P
0 g
s
.78067 .63428 m .77904 .67219 L .74788 .66973 L p .707 .577 .707 r
F P
0 g
s
.74788 .66973 m .74951 .63182 L .78067 .63428 L p .707 .577 .707 r
F P
0 g
s
.49483 .62169 m .4932 .65959 L .5002 .65476 L p .707 .577 .707 r
F P
0 g
s
.5002 .65476 m .50184 .61685 L .49483 .62169 L p .707 .577 .707 r
F P
0 g
s
.68316 .72431 m .68502 .70517 L .71411 .70766 L p .707 .577 .707 r
F P
0 g
s
.71411 .70766 m .71225 .72679 L .68316 .72431 L p .707 .577 .707 r
F P
0 g
s
.71608 .66889 m .71771 .63098 L .74951 .63182 L p .707 .577 .707 r
F P
0 g
s
.5006 .53506 m .50138 .59009 L .49847 .58056 L p .707 .577 .707 r
F P
0 g
s
.49847 .58056 m .4977 .52553 L .5006 .53506 L p .707 .577 .707 r
F P
0 g
s
.74951 .63182 m .74788 .66973 L .71608 .66889 L p .707 .577 .707 r
F P
0 g
s
.29672 .53362 m .29749 .58864 L .3004 .59817 L p .707 .577 .707 r
F P
0 g
s
.77687 .71384 m .77501 .73298 L .7439 .72978 L p .707 .577 .707 r
F P
0 g
s
.7439 .72978 m .74576 .71065 L .77687 .71384 L p .707 .577 .707 r
F P
0 g
s
.49209 .68616 m .49023 .7053 L .49691 .70512 L p .707 .577 .707 r
F P
0 g
s
.49691 .70512 m .49877 .68599 L .49209 .68616 L p .707 .577 .707 r
F P
0 g
s
.29942 .64942 m .30106 .61152 L .29809 .60616 L p .707 .577 .707 r
F P
0 g
s
.71225 .72679 m .71411 .70766 L .74576 .71065 L p .707 .577 .707 r
F P
0 g
s
.74576 .71065 m .7439 .72978 L .71225 .72679 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29809 .60616 m .29646 .64406 L .29942 .64942 L p .707 .577 .707 r
F P
0 g
s
.29749 .58864 m .29672 .53362 L .30379 .52416 L p .707 .577 .707 r
F P
0 g
s
.29708 .68626 m .29894 .66713 L .29568 .66597 L p .707 .577 .707 r
F P
0 g
s
.29568 .66597 m .29382 .68511 L .29708 .68626 L p .707 .577 .707 r
F P
0 g
s
.50184 .61685 m .5002 .65476 L .49724 .6494 L p .707 .577 .707 r
F P
0 g
s
.49724 .6494 m .49887 .61149 L .50184 .61685 L p .707 .577 .707 r
F P
0 g
s
.4977 .52553 m .49847 .58056 L .48588 .57189 L p .707 .577 .707 r
F P
0 g
s
.48588 .57189 m .4851 .51686 L .4977 .52553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30379 .52416 m .30457 .57918 L .29749 .58864 L p .707 .577 .707 r
F P
0 g
s
.49877 .68599 m .49691 .70512 L .49365 .70397 L p .707 .577 .707 r
F P
0 g
s
.49365 .70397 m .49551 .68483 L .49877 .68599 L p .707 .577 .707 r
F P
0 g
s
.29646 .64406 m .29809 .60616 L .3051 .60132 L p .707 .577 .707 r
F P
0 g
s
.30457 .57918 m .30379 .52416 L .32016 .51569 L p .707 .577 .707 r
F P
0 g
s
.3051 .60132 m .30346 .63923 L .29646 .64406 L p .707 .577 .707 r
F P
0 g
s
.29382 .68511 m .29568 .66597 L .30236 .6658 L p .707 .577 .707 r
F P
0 g
s
.30236 .6658 m .3005 .68493 L .29382 .68511 L p .707 .577 .707 r
F P
0 g
s
.49887 .61149 m .49724 .6494 L .48459 .64404 L p .707 .577 .707 r
F P
0 g
s
.48459 .64404 m .48622 .60613 L .49887 .61149 L p .707 .577 .707 r
F P
0 g
s
.4851 .51686 m .48588 .57189 L .46482 .56493 L p .707 .577 .707 r
F P
0 g
s
.46482 .56493 m .46404 .5099 L .4851 .51686 L p .707 .577 .707 r
F P
0 g
s
.32016 .51569 m .32093 .57072 L .30457 .57918 L p .707 .577 .707 r
F P
0 g
s
.30346 .63923 m .3051 .60132 L .32139 .59748 L p .707 .577 .707 r
F P
0 g
s
.49551 .68483 m .49365 .70397 L .48076 .70195 L p .707 .577 .707 r
F P
0 g
s
.48076 .70195 m .48262 .68281 L .49551 .68483 L p .707 .577 .707 r
F P
0 g
s
.32093 .57072 m .32016 .51569 L .3442 .50905 L p .707 .577 .707 r
F P
0 g
s
.32139 .59748 m .31976 .63539 L .30346 .63923 L p .707 .577 .707 r
F P
0 g
s
.3005 .68493 m .30236 .6658 L .31832 .66662 L p .707 .577 .707 r
F P
0 g
s
.31832 .66662 m .31646 .68576 L .3005 .68493 L p .707 .577 .707 r
F P
0 g
s
.46404 .5099 m .46482 .56493 L .43736 .56036 L p .707 .577 .707 r
F P
0 g
s
.43736 .56036 m .43658 .50534 L .46404 .5099 L p .707 .577 .707 r
F P
0 g
s
.48622 .60613 m .48459 .64404 L .4635 .63921 L p .707 .577 .707 r
F P
0 g
s
.4635 .63921 m .46513 .6013 L .48622 .60613 L p .707 .577 .707 r
F P
0 g
s
.3442 .50905 m .34498 .56408 L .32093 .57072 L p .707 .577 .707 r
F P
0 g
s
.34498 .56408 m .3442 .50905 L .37358 .50489 L p .707 .577 .707 r
F P
0 g
s
.31976 .63539 m .32139 .59748 L .34537 .59502 L p .707 .577 .707 r
F P
0 g
s
.43658 .50534 m .43736 .56036 L .40619 .55864 L p .707 .577 .707 r
F P
0 g
s
.40619 .55864 m .40541 .50361 L .43658 .50534 L p .707 .577 .707 r
F P
0 g
s
.48262 .68281 m .48076 .70195 L .45952 .69926 L p .707 .577 .707 r
F P
0 g
s
.45952 .69926 m .46138 .68012 L .48262 .68281 L p .707 .577 .707 r
F P
0 g
s
.37435 .55992 m .37358 .50489 L .40541 .50361 L p .707 .577 .707 r
F P
0 g
s
.37358 .50489 m .37435 .55992 L .34498 .56408 L p .707 .577 .707 r
F P
0 g
s
.34537 .59502 m .34374 .63292 L .31976 .63539 L p .707 .577 .707 r
F P
0 g
s
.40541 .50361 m .40619 .55864 L .37435 .55992 L p .707 .577 .707 r
F P
0 g
s
.31646 .68576 m .31832 .66662 L .34201 .66836 L p .707 .577 .707 r
F P
0 g
s
.34201 .66836 m .34015 .68749 L .31646 .68576 L p .707 .577 .707 r
F P
0 g
s
.46513 .6013 m .4635 .63921 L .43603 .63537 L p .707 .577 .707 r
F P
0 g
s
.43603 .63537 m .43766 .59747 L .46513 .6013 L p .707 .577 .707 r
F P
0 g
s
.34374 .63292 m .34537 .59502 L .3747 .59416 L p .707 .577 .707 r
F P
0 g
s
.46138 .68012 m .45952 .69926 L .432 .69616 L p .707 .577 .707 r
F P
0 g
s
.432 .69616 m .43386 .67703 L .46138 .68012 L p .707 .577 .707 r
F P
0 g
s
.3747 .59416 m .37307 .63207 L .34374 .63292 L p .707 .577 .707 r
F P
0 g
s
.43766 .59747 m .43603 .63537 L .40487 .63292 L p .707 .577 .707 r
F P
0 g
s
.40487 .63292 m .4065 .59501 L .43766 .59747 L p .707 .577 .707 r
F P
0 g
s
.34015 .68749 m .34201 .66836 L .3711 .67084 L p .707 .577 .707 r
F P
0 g
s
.3711 .67084 m .36924 .68998 L .34015 .68749 L p .707 .577 .707 r
F P
0 g
s
.37307 .63207 m .3747 .59416 L .4065 .59501 L p .707 .577 .707 r
F P
0 g
s
.4065 .59501 m .40487 .63292 L .37307 .63207 L p .707 .577 .707 r
F P
0 g
s
.43386 .67703 m .432 .69616 L .40089 .69297 L p .707 .577 .707 r
F P
0 g
s
.40089 .69297 m .40275 .67383 L .43386 .67703 L p .707 .577 .707 r
F P
0 g
s
.36924 .68998 m .3711 .67084 L .40275 .67383 L p .707 .577 .707 r
F P
0 g
s
.40275 .67383 m .40089 .69297 L .36924 .68998 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3@00QGoo001oOol<0006FUH00`00FUIJEP04FUH9001lOol007Moo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Ioo`00LWoo1@000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1000LWoo001^Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001^Ool006Yoo`@00003FUH0
05YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<006]oo`00J7oo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JGoo001WOol20006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006EooaT000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00H7oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001MOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol005]oo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00FGoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001GOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
05Ioo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00EGoo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Uoo`T0
04Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF009JEPP0
03aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH003Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<002moo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF2`001UYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF70000eYF1P0015YF
00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YF00000`00
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00E7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo001DOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000]Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH:0008FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00D005YFFUH005YF00d000=JEP03001JEUYF
009JEPl000=JEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo0018Ool90004Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF2P0017oo3P0000=JEP0000000P000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?goo2@0015YF00<005YFFUH00UYF1`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P00
00=JEP0000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YF00000`001UYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEPD0
00AJEP04001JEUYFFUH2000/Ool003Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP8002aoo`00=Woo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH005YF
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH30003FUH2000/Ool003=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000;7oo000aOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00
;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000/Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000eJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEQT00003FUH005YF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEPD00003FUH005YF00EJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YFFUIJ
EP0002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF00<0
05YFFUH015YF1P0015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH700001EYF001JEUYF0000<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000<Goo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF5`0000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002aoo`00;Goo00<005YF000015YF00<005YFFUH00eYF2P000goo1@0000=oo`0000001`0000=J
EP0000002@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002eoo`03001JEP0000AJEP03
001JEP0000<000EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEP0000<000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;7oo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP0:00001EYF00000000FUH00P0000=JEP00FUH00eYF6@002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00@005YFFUIJEQ0000UJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00FUIJEPL000MJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00;Goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000]Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
1`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000UYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP070002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP04000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF010000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002ioo`04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80002FUH90004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF000000020004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Woo00D005YFFUH005YF02@000=JEP03001JEUYF00=JEP03001JEP00
00L000=JEQ4000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH300000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000_Ool01P00
FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
00EJEP03001JEUYF00800003FUH005YF009JEPT000AJEP03001JEUYF00AJEPL000=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02000_Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPP00004Ool005YF0006FUH00`00FUIJEP03FUH@0002FUH50002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH300000eYF0000000?0004FUH00`00FUIJEP02FUH>000aOol002eoo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP`00003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00d0009JEP8000]oo`T0
03moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00@005YFFUIJEPT004ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@00?Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<002eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH0000000X000=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH:0003FUH90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00002FUH>0008FUH@0004
FUH00`00FUIJEP03FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=J
EP00FUH01EYF00D005YFFUIJEP0000Eoo`T000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00;Goo00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF1P0015YF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00=JEPL00003FUH005YF008000moo`P000=JEPL000=JEP03001JEUYF008002ioo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP<00006FUH005YF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF
00<005YFFUH0100067oo4P00;Woo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH500000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP03FUH3000SOol4000_Ool002ioo`04
001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJ
EP03001JEUYF00=JEP03001JEUYF008005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHI0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000aOol30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00EJEPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol003Aoo`L000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0
009JEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001C
Ool002eooaL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000017oo001JEP00
1EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH010001UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00
;Goo0P0015YF00<005YFFUH015YF00@005YFFUIJEQl000Moo`03001JEP0000=JEP8000IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT001Aoo`04001JEP00FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004
FUH30007FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005=oo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200037oo00@005YF0000009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEUYFFUH20002FUH60004FUH00`00FUIJEP03FUH00`00FUIJEP02001D
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEUYFFUH70005Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40004FUH7
0003FUH00`00FUIJEP02001DOol002aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<0
00EJEP03001JEUYF00=JEP@0009JEP8005Aoo`00;Goo1`000UYF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00AJEP03001JEUYF00@005Aoo`00=7oo1`000UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003]oo`P000AJEP03001JEUYF
00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Aoo`00@goo4P000UYF1`00
0eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJ
EP04001JEUYFFUH2001EOol005Eoo`L0009JEPD0009JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF008005Ioo`00G7oo2`0000Aoo`00000000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000=JEPh005Qoo`00JWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEPL006Ioo`00K7oo10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YF000005YF00P006Aoo`00L7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF1P001eYF00@005YFFUIJEPL005eoo`00MGoo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH00eYF2`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01@00F7oo001kOol90006FUH00`00FUIJEP04FUH>0004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001DOol008AooaP000=JEPT000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol009aoo`T0
00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol00:Eoo`T000=J
EPP000AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00[Woo20000eYF300000=JEP000000EGoo
002fOolB001EOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59381 .74531 m .59459 .68924 L .56341 .68717 L p .707 .577 .707 r
F P
0 g
s
.59459 .68924 m .59381 .74531 L .62564 .74504 L p .707 .577 .707 r
F P
0 g
s
.62564 .74504 m .62642 .68897 L .59459 .68924 L p .707 .577 .707 r
F P
0 g
s
.62642 .68897 m .62564 .74504 L .65502 .74245 L p .707 .577 .707 r
F P
0 g
s
.65502 .74245 m .65579 .68639 L .62642 .68897 L p .707 .577 .707 r
F P
0 g
s
.56264 .74323 m .56341 .68717 L .53596 .68295 L p .707 .577 .707 r
F P
0 g
s
.56341 .68717 m .56264 .74323 L .59381 .74531 L p .707 .577 .707 r
F P
0 g
s
.65579 .68639 m .65502 .74245 L .67907 .7378 L p .707 .577 .707 r
F P
0 g
s
.67907 .7378 m .67984 .68174 L .65579 .68639 L p .707 .577 .707 r
F P
0 g
s
.53596 .68295 m .53518 .73902 L .56264 .74323 L p .707 .577 .707 r
F P
0 g
s
.53518 .73902 m .53596 .68295 L .5149 .67701 L p .707 .577 .707 r
F P
0 g
s
.59513 .81782 m .5935 .7821 L .56234 .78074 L p .707 .577 .707 r
F P
0 g
s
.5935 .7821 m .59513 .81782 L .62693 .81547 L p .707 .577 .707 r
F P
0 g
s
.62693 .81547 m .6253 .77975 L .5935 .7821 L p .707 .577 .707 r
F P
0 g
s
.6253 .77975 m .62693 .81547 L .65626 .80964 L p .707 .577 .707 r
F P
0 g
s
.65626 .80964 m .65462 .77392 L .6253 .77975 L p .707 .577 .707 r
F P
0 g
s
.56397 .81646 m .56234 .78074 L .53487 .77581 L p .707 .577 .707 r
F P
0 g
s
.56234 .78074 m .56397 .81646 L .59513 .81782 L p .707 .577 .707 r
F P
0 g
s
.67984 .68174 m .67907 .7378 L .69543 .73154 L p .707 .577 .707 r
F P
0 g
s
.69543 .73154 m .6962 .67547 L .67984 .68174 L p .707 .577 .707 r
F P
0 g
s
.5149 .67701 m .51412 .73307 L .53518 .73902 L p .707 .577 .707 r
F P
0 g
s
.65462 .77392 m .65626 .80964 L .68024 .8009 L p .707 .577 .707 r
F P
0 g
s
.68024 .8009 m .67861 .76518 L .65462 .77392 L p .707 .577 .707 r
F P
0 g
s
.53487 .77581 m .5365 .81153 L .56397 .81646 L p .707 .577 .707 r
F P
0 g
s
.5365 .81153 m .53487 .77581 L .51378 .76778 L p .707 .577 .707 r
F P
0 g
s
.51412 .73307 m .5149 .67701 L .5023 .66991 L p .707 .577 .707 r
F P
0 g
s
.59911 .87254 m .59725 .85589 L .56614 .85521 L p .707 .577 .707 r
F P
0 g
s
.59725 .85589 m .59911 .87254 L .63076 .86824 L p .707 .577 .707 r
F P
0 g
s
.63076 .86824 m .6289 .8516 L .59725 .85589 L p .707 .577 .707 r
F P
0 g
s
.6289 .8516 m .63076 .86824 L .65985 .85939 L p .707 .577 .707 r
F P
0 g
s
.65985 .85939 m .65799 .84275 L .6289 .8516 L p .707 .577 .707 r
F P
0 g
s
.67861 .76518 m .68024 .8009 L .69653 .7901 L p .707 .577 .707 r
F P
0 g
s
.69653 .7901 m .6949 .75439 L .67861 .76518 L p .707 .577 .707 r
F P
0 g
s
.5023 .66991 m .50152 .72598 L .51412 .73307 L p .707 .577 .707 r
F P
0 g
s
.51378 .76778 m .51541 .8035 L .5365 .81153 L p .707 .577 .707 r
F P
0 g
s
.568 .87185 m .56614 .85521 L .53862 .8496 L p .707 .577 .707 r
F P
0 g
s
.56614 .85521 m .568 .87185 L .59911 .87254 L p .707 .577 .707 r
F P
0 g
s
.6962 .67547 m .69543 .73154 L .7025 .72428 L p .707 .577 .707 r
F P
0 g
s
.7025 .72428 m .70328 .66822 L .6962 .67547 L p .707 .577 .707 r
F P
0 g
s
.65799 .84275 m .65985 .85939 L .68354 .84684 L p .707 .577 .707 r
F P
0 g
s
.68354 .84684 m .68168 .8302 L .65799 .84275 L p .707 .577 .707 r
F P
0 g
s
.51541 .8035 m .51378 .76778 L .50113 .75744 L p .707 .577 .707 r
F P
0 g
s
.53862 .8496 m .54048 .86624 L .568 .87185 L p .707 .577 .707 r
F P
0 g
s
.50152 .72598 m .5023 .66991 L .4994 .66237 L p .707 .577 .707 r
F P
0 g
s
.54048 .86624 m .53862 .8496 L .51737 .83963 L p .707 .577 .707 r
F P
0 g
s
.6949 .75439 m .69653 .7901 L .70354 .77831 L p .707 .577 .707 r
F P
0 g
s
.70354 .77831 m .70191 .7426 L .6949 .75439 L p .707 .577 .707 r
F P
0 g
s
.68168 .8302 m .68354 .84684 L .6995 .83182 L p .707 .577 .707 r
F P
0 g
s
.6995 .83182 m .69764 .81518 L .68168 .8302 L p .707 .577 .707 r
F P
0 g
s
.50113 .75744 m .50276 .79316 L .51541 .8035 L p .707 .577 .707 r
F P
0 g
s
.51737 .83963 m .51923 .85627 L .54048 .86624 L p .707 .577 .707 r
F P
0 g
s
.4994 .66237 m .49862 .71843 L .50152 .72598 L p .707 .577 .707 r
F P
0 g
s
.70328 .66822 m .7025 .72428 L .6996 .71674 L p .707 .577 .707 r
F P
0 g
s
.6996 .71674 m .70037 .66067 L .70328 .66822 L p .707 .577 .707 r
F P
0 g
s
.50276 .79316 m .50113 .75744 L .49816 .74581 L p .707 .577 .707 r
F P
0 g
s
.51923 .85627 m .51737 .83963 L .50449 .82627 L p .707 .577 .707 r
F P
0 g
s
.49462 .82353 m .48781 .32652 L .4438 .32408 L p .707 .577 .707 r
F P
0 g
s
.49862 .71843 m .4994 .66237 L .50647 .65511 L p .707 .577 .707 r
F P
0 g
s
.49816 .74581 m .49979 .78153 L .50276 .79316 L p .707 .577 .707 r
F P
0 g
s
.50647 .65511 m .5057 .71118 L .49862 .71843 L p .707 .577 .707 r
F P
0 g
s
.50635 .84291 m .50449 .82627 L .50123 .81083 L p .707 .577 .707 r
F P
0 g
s
.49979 .78153 m .49816 .74581 L .50517 .73402 L p .707 .577 .707 r
F P
0 g
s
.50123 .81083 m .50309 .82747 L .50635 .84291 L p .707 .577 .707 r
F P
0 g
s
.5057 .71118 m .50647 .65511 L .52283 .64885 L p .707 .577 .707 r
F P
0 g
s
.50517 .73402 m .5068 .76974 L .49979 .78153 L p .707 .577 .707 r
F P
0 g
s
.52283 .64885 m .52206 .70491 L .5057 .71118 L p .707 .577 .707 r
F P
0 g
s
.50309 .82747 m .50123 .81083 L .50791 .79482 L p .707 .577 .707 r
F P
0 g
s
.5068 .76974 m .50517 .73402 L .52146 .72323 L p .707 .577 .707 r
F P
0 g
s
.50791 .79482 m .50977 .81146 L .50309 .82747 L p .707 .577 .707 r
F P
0 g
s
.52206 .70491 m .52283 .64885 L .54688 .6442 L p .707 .577 .707 r
F P
0 g
s
.52146 .72323 m .52309 .75895 L .5068 .76974 L p .707 .577 .707 r
F P
0 g
s
.54688 .6442 m .5461 .70026 L .52206 .70491 L p .707 .577 .707 r
F P
0 g
s
.50977 .81146 m .50791 .79482 L .52387 .7798 L p .707 .577 .707 r
F P
0 g
s
.52309 .75895 m .52146 .72323 L .54544 .71449 L p .707 .577 .707 r
F P
0 g
s
.52387 .7798 m .52573 .79645 L .50977 .81146 L p .707 .577 .707 r
F P
0 g
s
.54544 .71449 m .54708 .75021 L .52309 .75895 L p .707 .577 .707 r
F P
0 g
s
.52573 .79645 m .52387 .7798 L .54756 .76726 L p .707 .577 .707 r
F P
0 g
s
.54756 .76726 m .54942 .7839 L .52573 .79645 L p .707 .577 .707 r
F P
0 g
s
.48781 .32652 m .49462 .82353 L .53956 .82174 L p .707 .577 .707 r
F P
0 g
s
.53956 .82174 m .53274 .32474 L .48781 .32652 L p .707 .577 .707 r
F P
0 g
s
.69764 .81518 m .6995 .83182 L .70618 .81581 L p .707 .577 .707 r
F P
0 g
s
.70618 .81581 m .70432 .79917 L .69764 .81518 L p .707 .577 .707 r
F P
0 g
s
.5461 .70026 m .54688 .6442 L .57625 .64161 L p .707 .577 .707 r
F P
0 g
s
.57625 .64161 m .57548 .69767 L .5461 .70026 L p .707 .577 .707 r
F P
0 g
s
.54708 .75021 m .54544 .71449 L .57477 .70866 L p .707 .577 .707 r
F P
0 g
s
.57477 .70866 m .5764 .74437 L .54708 .75021 L p .707 .577 .707 r
F P
0 g
s
.54942 .7839 m .54756 .76726 L .57666 .7584 L p .707 .577 .707 r
F P
0 g
s
.57666 .7584 m .57852 .77504 L .54942 .7839 L p .707 .577 .707 r
F P
0 g
s
.53274 .32474 m .53956 .82174 L .58103 .81589 L p .707 .577 .707 r
F P
0 g
s
.57548 .69767 m .57625 .64161 L .60809 .64134 L p .707 .577 .707 r
F P
0 g
s
.60809 .64134 m .60731 .69741 L .57548 .69767 L p .707 .577 .707 r
F P
0 g
s
.5764 .74437 m .57477 .70866 L .60657 .70631 L p .707 .577 .707 r
F P
0 g
s
.60657 .70631 m .6082 .74202 L .5764 .74437 L p .707 .577 .707 r
F P
0 g
s
.57852 .77504 m .57666 .7584 L .60831 .75411 L p .707 .577 .707 r
F P
0 g
s
.60831 .75411 m .61016 .77075 L .57852 .77504 L p .707 .577 .707 r
F P
0 g
s
.58103 .81589 m .57422 .31889 L .53274 .32474 L p .707 .577 .707 r
F P
0 g
s
.50449 .82627 m .50635 .84291 L .51923 .85627 L p .707 .577 .707 r
F P
0 g
s
.70191 .7426 m .70354 .77831 L .70057 .76668 L p .707 .577 .707 r
F P
0 g
s
.70057 .76668 m .69894 .73096 L .70191 .7426 L p .707 .577 .707 r
F P
0 g
s
.45061 .82108 m .4438 .32408 L .40503 .31764 L p .707 .577 .707 r
F P
0 g
s
.4438 .32408 m .45061 .82108 L .49462 .82353 L p .707 .577 .707 r
F P
0 g
s
.63773 .70766 m .63936 .74338 L .6082 .74202 L p .707 .577 .707 r
F P
0 g
s
.6082 .74202 m .60657 .70631 L .63773 .70766 L p .707 .577 .707 r
F P
0 g
s
.63941 .7548 m .64127 .77144 L .61016 .77075 L p .707 .577 .707 r
F P
0 g
s
.61016 .77075 m .60831 .75411 L .63941 .7548 L p .707 .577 .707 r
F P
0 g
s
.57422 .31889 m .58103 .81589 L .61498 .80656 L p .707 .577 .707 r
F P
0 g
s
.63926 .64342 m .63848 .69948 L .60731 .69741 L p .707 .577 .707 r
F P
0 g
s
.60731 .69741 m .60809 .64134 L .63926 .64342 L p .707 .577 .707 r
F P
0 g
s
.61498 .80656 m .60817 .30955 L .57422 .31889 L p .707 .577 .707 r
F P
0 g
s
.70037 .66067 m .6996 .71674 L .687 .70964 L p .707 .577 .707 r
F P
0 g
s
.687 .70964 m .68778 .65358 L .70037 .66067 L p .707 .577 .707 r
F P
0 g
s
.70432 .79917 m .70618 .81581 L .70292 .80037 L p .707 .577 .707 r
F P
0 g
s
.70292 .80037 m .70106 .78373 L .70432 .79917 L p .707 .577 .707 r
F P
0 g
s
.2508 .70849 m .25158 .65243 L .22041 .65035 L p .707 .577 .707 r
F P
0 g
s
.25158 .65243 m .2508 .70849 L .28263 .70823 L p .707 .577 .707 r
F P
0 g
s
.28263 .70823 m .28341 .65216 L .25158 .65243 L p .707 .577 .707 r
F P
0 g
s
.41185 .81465 m .40503 .31764 L .3753 .30784 L p .707 .577 .707 r
F P
0 g
s
.40503 .31764 m .41185 .81465 L .45061 .82108 L p .707 .577 .707 r
F P
0 g
s
.28341 .65216 m .28263 .70823 L .31201 .70564 L p .707 .577 .707 r
F P
0 g
s
.31201 .70564 m .31279 .64957 L .28341 .65216 L p .707 .577 .707 r
F P
0 g
s
.21963 .70642 m .22041 .65035 L .19295 .64614 L p .707 .577 .707 r
F P
0 g
s
.22041 .65035 m .21963 .70642 L .2508 .70849 L p .707 .577 .707 r
F P
0 g
s
.69894 .73096 m .70057 .76668 L .68793 .75634 L p .707 .577 .707 r
F P
0 g
s
.68793 .75634 m .68629 .72063 L .69894 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31279 .64957 m .31201 .70564 L .33606 .70099 L p .707 .577 .707 r
F P
0 g
s
.33606 .70099 m .33683 .64492 L .31279 .64957 L p .707 .577 .707 r
F P
0 g
s
.60817 .30955 m .61498 .80656 L .63808 .79465 L p .707 .577 .707 r
F P
0 g
s
.63808 .79465 m .63127 .29765 L .60817 .30955 L p .707 .577 .707 r
F P
0 g
s
.68778 .65358 m .687 .70964 L .66594 .7037 L p .707 .577 .707 r
F P
0 g
s
.66594 .7037 m .66672 .64763 L .68778 .65358 L p .707 .577 .707 r
F P
0 g
s
.19295 .64614 m .19217 .7022 L .21963 .70642 L p .707 .577 .707 r
F P
0 g
s
.19217 .7022 m .19295 .64614 L .17189 .64019 L p .707 .577 .707 r
F P
0 g
s
.25212 .781 m .25049 .74529 L .21933 .74393 L p .707 .577 .707 r
F P
0 g
s
.25049 .74529 m .25212 .781 L .28392 .77865 L p .707 .577 .707 r
F P
0 g
s
.28392 .77865 m .28229 .74294 L .25049 .74529 L p .707 .577 .707 r
F P
0 g
s
.28229 .74294 m .28392 .77865 L .31325 .77282 L p .707 .577 .707 r
F P
0 g
s
.31325 .77282 m .31161 .7371 L .28229 .74294 L p .707 .577 .707 r
F P
0 g
s
.70106 .78373 m .70292 .80037 L .69004 .78701 L p .707 .577 .707 r
F P
0 g
s
.69004 .78701 m .68818 .77037 L .70106 .78373 L p .707 .577 .707 r
F P
0 g
s
.22096 .77965 m .21933 .74393 L .19186 .73899 L p .707 .577 .707 r
F P
0 g
s
.21933 .74393 m .22096 .77965 L .25212 .781 L p .707 .577 .707 r
F P
0 g
s
.38212 .80484 m .3753 .30784 L .35752 .29563 L p .707 .577 .707 r
F P
0 g
s
.3753 .30784 m .38212 .80484 L .41185 .81465 L p .707 .577 .707 r
F P
0 g
s
.68629 .72063 m .68793 .75634 L .66683 .74832 L p .707 .577 .707 r
F P
0 g
s
.66683 .74832 m .6652 .7126 L .68629 .72063 L p .707 .577 .707 r
F P
0 g
s
.33683 .64492 m .33606 .70099 L .35242 .69472 L p .707 .577 .707 r
F P
0 g
s
.35242 .69472 m .35319 .63866 L .33683 .64492 L p .707 .577 .707 r
F P
0 g
s
.17189 .64019 m .17111 .69626 L .19217 .7022 L p .707 .577 .707 r
F P
0 g
s
.31161 .7371 m .31325 .77282 L .33723 .76408 L p .707 .577 .707 r
F P
0 g
s
.33723 .76408 m .3356 .72836 L .31161 .7371 L p .707 .577 .707 r
F P
0 g
s
.66672 .64763 m .66594 .7037 L .63848 .69948 L p .707 .577 .707 r
F P
0 g
s
.63848 .69948 m .63926 .64342 L .66672 .64763 L p .707 .577 .707 r
F P
0 g
s
.19186 .73899 m .19349 .77471 L .22096 .77965 L p .707 .577 .707 r
F P
0 g
s
.19349 .77471 m .19186 .73899 L .17077 .73097 L p .707 .577 .707 r
F P
0 g
s
.17111 .69626 m .17189 .64019 L .15929 .6331 L p .707 .577 .707 r
F P
0 g
s
.2561 .83572 m .25424 .81908 L .22313 .81839 L p .707 .577 .707 r
F P
0 g
s
.25424 .81908 m .2561 .83572 L .28775 .83143 L p .707 .577 .707 r
F P
0 g
s
.28775 .83143 m .28589 .81479 L .25424 .81908 L p .707 .577 .707 r
F P
0 g
s
.68818 .77037 m .69004 .78701 L .6688 .77704 L p .707 .577 .707 r
F P
0 g
s
.6688 .77704 m .66694 .7604 L .68818 .77037 L p .707 .577 .707 r
F P
0 g
s
.28589 .81479 m .28775 .83143 L .31684 .82257 L p .707 .577 .707 r
F P
0 g
s
.31684 .82257 m .31498 .80593 L .28589 .81479 L p .707 .577 .707 r
F P
0 g
s
.6652 .7126 m .66683 .74832 L .63936 .74338 L p .707 .577 .707 r
F P
0 g
s
.63936 .74338 m .63773 .70766 L .6652 .7126 L p .707 .577 .707 r
F P
0 g
s
.66694 .7604 m .6688 .77704 L .64127 .77144 L p .707 .577 .707 r
F P
0 g
s
.64127 .77144 m .63941 .7548 L .66694 .7604 L p .707 .577 .707 r
F P
0 g
s
.63127 .29765 m .63808 .79465 L .64807 .78134 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64125 .28433 L .63127 .29765 L p .707 .577 .707 r
F P
0 g
s
.3356 .72836 m .33723 .76408 L .35352 .75329 L p .707 .577 .707 r
F P
0 g
s
.35352 .75329 m .35189 .71757 L .3356 .72836 L p .707 .577 .707 r
F P
0 g
s
.15929 .6331 m .15851 .68916 L .17111 .69626 L p .707 .577 .707 r
F P
0 g
s
.17077 .73097 m .1724 .76668 L .19349 .77471 L p .707 .577 .707 r
F P
0 g
s
.22499 .83503 m .22313 .81839 L .19561 .81279 L p .707 .577 .707 r
F P
0 g
s
.22313 .81839 m .22499 .83503 L .2561 .83572 L p .707 .577 .707 r
F P
0 g
s
.35319 .63866 m .35242 .69472 L .35949 .68747 L p .707 .577 .707 r
F P
0 g
s
.35949 .68747 m .36027 .6314 L .35319 .63866 L p .707 .577 .707 r
F P
0 g
s
.31498 .80593 m .31684 .82257 L .34053 .81002 L p .707 .577 .707 r
F P
0 g
s
.34053 .81002 m .33867 .79338 L .31498 .80593 L p .707 .577 .707 r
F P
0 g
s
.1724 .76668 m .17077 .73097 L .15812 .72063 L p .707 .577 .707 r
F P
0 g
s
.19561 .81279 m .19747 .82943 L .22499 .83503 L p .707 .577 .707 r
F P
0 g
s
.36433 .79263 m .35752 .29563 L .35342 .28221 L p .707 .577 .707 r
F P
0 g
s
.35752 .29563 m .36433 .79263 L .38212 .80484 L p .707 .577 .707 r
F P
0 g
s
.15851 .68916 m .15929 .6331 L .15639 .62555 L p .707 .577 .707 r
F P
0 g
s
.19747 .82943 m .19561 .81279 L .17437 .80282 L p .707 .577 .707 r
F P
0 g
s
.35189 .71757 m .35352 .75329 L .36053 .7415 L p .707 .577 .707 r
F P
0 g
s
.36053 .7415 m .3589 .70578 L .35189 .71757 L p .707 .577 .707 r
F P
0 g
s
.33867 .79338 m .34053 .81002 L .35649 .79501 L p .707 .577 .707 r
F P
0 g
s
.35649 .79501 m .35463 .77837 L .33867 .79338 L p .707 .577 .707 r
F P
0 g
s
.15812 .72063 m .15975 .75635 L .1724 .76668 L p .707 .577 .707 r
F P
0 g
s
.17437 .80282 m .17622 .81946 L .19747 .82943 L p .707 .577 .707 r
F P
0 g
s
.15639 .62555 m .15561 .68162 L .15851 .68916 L p .707 .577 .707 r
F P
0 g
s
.36027 .6314 m .35949 .68747 L .35659 .67992 L p .707 .577 .707 r
F P
0 g
s
.35659 .67992 m .35737 .62385 L .36027 .6314 L p .707 .577 .707 r
F P
0 g
s
.15975 .75635 m .15812 .72063 L .15515 .709 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64397 .76792 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64199 .33829 m .64807 .78134 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64125 .28433 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64397 .76792 m .64113 .56075 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64113 .56075 m .63716 .27091 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64397 .76792 L .62619 .75571 L p .707 .577 .707 r
F P
0 g
s
.63833 .67198 m .63996 .7077 L .64056 .70819 L p .707 .577 .707 r
F P
0 g
s
.64056 .70819 m .65261 .71804 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.64067 .67952 m .63833 .67198 L .64056 .70819 L .707 .577 .707 r
F
.65261 .71804 m .65098 .68232 L .64069 .67391 L p F P
0 g
s
.64069 .67391 m .63833 .67198 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.65261 .71804 m .64069 .67391 L .64067 .67952 L .707 .577 .707 r
F
.64125 .28433 m .64199 .33829 L p .64182 .38426 L F P
0 g
s
.17622 .81946 m .17437 .80282 L .16148 .78946 L p .707 .577 .707 r
F P
0 g
s
.35463 .77837 m .35649 .79501 L .36317 .779 L p .707 .577 .707 r
F P
0 g
s
.36317 .779 m .36131 .76236 L .35463 .77837 L p .707 .577 .707 r
F P
0 g
s
.15561 .68162 m .15639 .62555 L .16346 .61829 L p .707 .577 .707 r
F P
0 g
s
.16148 .78946 m .16334 .8061 L .17622 .81946 L p .707 .577 .707 r
F P
0 g
s
.15515 .709 m .15679 .74471 L .15975 .75635 L p .707 .577 .707 r
F P
0 g
s
.3589 .70578 m .36053 .7415 L .35756 .72987 L p .707 .577 .707 r
F P
0 g
s
.35756 .72987 m .35593 .69415 L .3589 .70578 L p .707 .577 .707 r
F P
0 g
s
.36131 .76236 m .36317 .779 L .35991 .76356 L p .707 .577 .707 r
F P
0 g
s
.35991 .76356 m .35805 .74692 L .36131 .76236 L p .707 .577 .707 r
F P
0 g
s
.35342 .28221 m .36024 .77922 L .36433 .79263 L p .707 .577 .707 r
F P
0 g
s
.36024 .77922 m .35342 .28221 L .36341 .2689 L p .707 .577 .707 r
F P
0 g
s
.16346 .61829 m .16269 .67436 L .15561 .68162 L p .707 .577 .707 r
F P
0 g
s
.16334 .8061 m .16148 .78946 L .15822 .77402 L p .707 .577 .707 r
F P
0 g
s
.35737 .62385 m .35659 .67992 L .34399 .67283 L p .707 .577 .707 r
F P
0 g
s
.34399 .67283 m .34477 .61676 L .35737 .62385 L p .707 .577 .707 r
F P
0 g
s
.15679 .74471 m .15515 .709 L .16216 .69721 L p .707 .577 .707 r
F P
0 g
s
.15822 .77402 m .16008 .79066 L .16334 .8061 L p .707 .577 .707 r
F P
0 g
s
.16269 .67436 m .16346 .61829 L .17982 .61203 L p .707 .577 .707 r
F P
0 g
s
.16216 .69721 m .16379 .73292 L .15679 .74471 L p .707 .577 .707 r
F P
0 g
s
.35593 .69415 m .35756 .72987 L .34492 .71953 L p .707 .577 .707 r
F P
0 g
s
.34492 .71953 m .34328 .68381 L .35593 .69415 L p .707 .577 .707 r
F P
0 g
s
.62619 .75571 m .61937 .2587 L .63716 .27091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17982 .61203 m .17905 .6681 L .16269 .67436 L p .707 .577 .707 r
F P
0 g
s
.16008 .79066 m .15822 .77402 L .1649 .758 L p .707 .577 .707 r
F P
0 g
s
.34477 .61676 m .34399 .67283 L .32293 .66688 L p .707 .577 .707 r
F P
0 g
s
.32293 .66688 m .32371 .61082 L .34477 .61676 L p .707 .577 .707 r
F P
0 g
s
.16379 .73292 m .16216 .69721 L .17845 .68641 L p .707 .577 .707 r
F P
0 g
s
.37022 .7659 m .36341 .2689 L .38651 .25699 L p .707 .577 .707 r
F P
0 g
s
.36341 .2689 m .37022 .7659 L .36024 .77922 L p .707 .577 .707 r
F P
0 g
s
.35805 .74692 m .35991 .76356 L .34703 .7502 L p .707 .577 .707 r
F P
0 g
s
.34703 .7502 m .34517 .73356 L .35805 .74692 L p .707 .577 .707 r
F P
0 g
s
.1649 .758 m .16676 .77465 L .16008 .79066 L p .707 .577 .707 r
F P
0 g
s
.17905 .6681 m .17982 .61203 L .20387 .60738 L p .707 .577 .707 r
F P
0 g
s
.34328 .68381 m .34492 .71953 L .32383 .7115 L p .707 .577 .707 r
F P
0 g
s
.32383 .7115 m .32219 .67578 L .34328 .68381 L p .707 .577 .707 r
F P
0 g
s
.17845 .68641 m .18008 .72213 L .16379 .73292 L p .707 .577 .707 r
F P
0 g
s
.32371 .61082 m .32293 .66688 L .29547 .66267 L p .707 .577 .707 r
F P
0 g
s
.29547 .66267 m .29625 .6066 L .32371 .61082 L p .707 .577 .707 r
F P
0 g
s
.20387 .60738 m .20309 .66345 L .17905 .6681 L p .707 .577 .707 r
F P
0 g
s
.16676 .77465 m .1649 .758 L .18087 .74299 L p .707 .577 .707 r
F P
0 g
s
.18008 .72213 m .17845 .68641 L .20243 .67767 L p .707 .577 .707 r
F P
0 g
s
.61937 .2587 m .62619 .75571 L .59646 .74591 L p .707 .577 .707 r
F P
0 g
s
.59646 .74591 m .58964 .2489 L .61937 .2587 L p .707 .577 .707 r
F P
0 g
s
.20309 .66345 m .20387 .60738 L .23325 .60479 L p .707 .577 .707 r
F P
0 g
s
.34517 .73356 m .34703 .7502 L .32579 .74023 L p .707 .577 .707 r
F P
0 g
s
.32579 .74023 m .32393 .72359 L .34517 .73356 L p .707 .577 .707 r
F P
0 g
s
.18087 .74299 m .18272 .75963 L .16676 .77465 L p .707 .577 .707 r
F P
0 g
s
.32219 .67578 m .32383 .7115 L .29636 .70657 L p .707 .577 .707 r
F P
0 g
s
.29636 .70657 m .29472 .67085 L .32219 .67578 L p .707 .577 .707 r
F P
0 g
s
.29625 .6066 m .29547 .66267 L .2643 .66059 L p .707 .577 .707 r
F P
0 g
s
.2643 .66059 m .26508 .60452 L .29625 .6066 L p .707 .577 .707 r
F P
0 g
s
.20243 .67767 m .20407 .71339 L .18008 .72213 L p .707 .577 .707 r
F P
0 g
s
.23247 .66086 m .23325 .60479 L .26508 .60452 L p .707 .577 .707 r
F P
0 g
s
.23325 .60479 m .23247 .66086 L .20309 .66345 L p .707 .577 .707 r
F P
0 g
s
.38651 .25699 m .39332 .75399 L .37022 .7659 L p .707 .577 .707 r
F P
0 g
s
.39332 .75399 m .38651 .25699 L .42046 .24765 L p .707 .577 .707 r
F P
0 g
s
.26508 .60452 m .2643 .66059 L .23247 .66086 L p .707 .577 .707 r
F P
0 g
s
.20407 .71339 m .20243 .67767 L .23176 .67184 L p .707 .577 .707 r
F P
0 g
s
.73101 .65794 m .73179 .60187 L .70062 .5998 L p .707 .577 .707 r
F P
0 g
s
.73179 .60187 m .73101 .65794 L .76285 .65767 L p .707 .577 .707 r
F P
0 g
s
.76285 .65767 m .76362 .60161 L .73179 .60187 L p .707 .577 .707 r
F P
0 g
s
.18272 .75963 m .18087 .74299 L .20455 .73044 L p .707 .577 .707 r
F P
0 g
s
.76362 .60161 m .76285 .65767 L .79222 .65508 L p .707 .577 .707 r
F P
0 g
s
.79222 .65508 m .793 .59902 L .76362 .60161 L p .707 .577 .707 r
F P
0 g
s
.29472 .67085 m .29636 .70657 L .26519 .70521 L p .707 .577 .707 r
F P
0 g
s
.26519 .70521 m .26356 .66949 L .29472 .67085 L p .707 .577 .707 r
F P
0 g
s
.69984 .65586 m .70062 .5998 L .67316 .59558 L p .707 .577 .707 r
F P
0 g
s
.70062 .5998 m .69984 .65586 L .73101 .65794 L p .707 .577 .707 r
F P
0 g
s
.32393 .72359 m .32579 .74023 L .29826 .73462 L p .707 .577 .707 r
F P
0 g
s
.29826 .73462 m .2964 .71798 L .32393 .72359 L p .707 .577 .707 r
F P
0 g
s
.23339 .70756 m .23176 .67184 L .26356 .66949 L p .707 .577 .707 r
F P
0 g
s
.23176 .67184 m .23339 .70756 L .20407 .71339 L p .707 .577 .707 r
F P
0 g
s
.20455 .73044 m .20641 .74708 L .18272 .75963 L p .707 .577 .707 r
F P
0 g
s
.58964 .2489 m .59646 .74591 L .55769 .73947 L p .707 .577 .707 r
F P
0 g
s
.55769 .73947 m .55088 .24246 L .58964 .2489 L p .707 .577 .707 r
F P
0 g
s
.26356 .66949 m .26519 .70521 L .23339 .70756 L p .707 .577 .707 r
F P
0 g
s
.793 .59902 m .79222 .65508 L .81627 .65043 L p .707 .577 .707 r
F P
0 g
s
.81627 .65043 m .81705 .59437 L .793 .59902 L p .707 .577 .707 r
F P
0 g
s
.20641 .74708 m .20455 .73044 L .23365 .72159 L p .707 .577 .707 r
F P
0 g
s
.67316 .59558 m .67238 .65165 L .69984 .65586 L p .707 .577 .707 r
F P
0 g
s
.67238 .65165 m .67316 .59558 L .6521 .58964 L p .707 .577 .707 r
F P
0 g
s
.2964 .71798 m .29826 .73462 L .26716 .73394 L p .707 .577 .707 r
F P
0 g
s
.26716 .73394 m .2653 .71729 L .2964 .71798 L p .707 .577 .707 r
F P
0 g
s
.73233 .73236 m .7307 .69664 L .69954 .69528 L p .707 .577 .707 r
F P
0 g
s
.7307 .69664 m .73233 .73236 L .76413 .73001 L p .707 .577 .707 r
F P
0 g
s
.76413 .73001 m .7625 .69429 L .7307 .69664 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .42046 .24765 L .46193 .24181 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .39332 .75399 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.42443 .53749 m .42727 .74466 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.46193 .24181 m .46875 .73881 L .42727 .74466 L p .707 .577 .707 r
F P
0 g
s
.41949 .65747 m .42112 .69319 L .44907 .68763 L p .707 .577 .707 r
F P
0 g
s
.44907 .68763 m .45045 .68736 L p .44876 .68573 L .707 .577 .707 r
F P
0 g
s
.44876 .68573 m .41949 .65747 L .44907 .68763 L .707 .577 .707 r
F
.42046 .24765 m .42443 .53749 L p .40973 .4479 L F P
0 g
s
.7625 .69429 m .76413 .73001 L .79346 .72417 L p .707 .577 .707 r
F P
0 g
s
.79346 .72417 m .79183 .68846 L .7625 .69429 L p .707 .577 .707 r
F P
0 g
s
.23365 .72159 m .23551 .73823 L .20641 .74708 L p .707 .577 .707 r
F P
0 g
s
.23551 .73823 m .23365 .72159 L .2653 .71729 L p .707 .577 .707 r
F P
0 g
s
.70117 .731 m .69954 .69528 L .67207 .69035 L p .707 .577 .707 r
F P
0 g
s
.69954 .69528 m .70117 .731 L .73233 .73236 L p .707 .577 .707 r
F P
0 g
s
.2653 .71729 m .26716 .73394 L .23551 .73823 L p .707 .577 .707 r
F P
0 g
s
.55088 .24246 m .55769 .73947 L .51368 .73702 L p .707 .577 .707 r
F P
0 g
s
.51368 .73702 m .50687 .24002 L .55088 .24246 L p .707 .577 .707 r
F P
0 g
s
.81705 .59437 m .81627 .65043 L .83263 .64417 L p .707 .577 .707 r
F P
0 g
s
.83263 .64417 m .83341 .5881 L .81705 .59437 L p .707 .577 .707 r
F P
0 g
s
.6521 .58964 m .65133 .6457 L .67238 .65165 L p .707 .577 .707 r
F P
0 g
s
.79183 .68846 m .79346 .72417 L .81744 .71543 L p .707 .577 .707 r
F P
0 g
s
.81744 .71543 m .81581 .67972 L .79183 .68846 L p .707 .577 .707 r
F P
0 g
s
.46875 .73881 m .46193 .24181 L .50687 .24002 L p .707 .577 .707 r
F P
0 g
s
.50687 .24002 m .51368 .73702 L .46875 .73881 L p .707 .577 .707 r
F P
0 g
s
.67207 .69035 m .6737 .72606 L .70117 .731 L p .707 .577 .707 r
F P
0 g
s
.65133 .6457 m .6521 .58964 L .6395 .58254 L p .707 .577 .707 r
F P
0 g
s
.6737 .72606 m .67207 .69035 L .65098 .68232 L p .707 .577 .707 r
F P
0 g
s
.73631 .78292 m .73445 .76628 L .70334 .76559 L p .707 .577 .707 r
F P
0 g
s
.73445 .76628 m .73631 .78292 L .76796 .77863 L p .707 .577 .707 r
F P
0 g
s
.76796 .77863 m .7661 .76199 L .73445 .76628 L p .707 .577 .707 r
F P
0 g
s
.7661 .76199 m .76796 .77863 L .79705 .76977 L p .707 .577 .707 r
F P
0 g
s
.79705 .76977 m .79519 .75313 L .7661 .76199 L p .707 .577 .707 r
F P
0 g
s
.81581 .67972 m .81744 .71543 L .83374 .70464 L p .707 .577 .707 r
F P
0 g
s
.83374 .70464 m .8321 .66892 L .81581 .67972 L p .707 .577 .707 r
F P
0 g
s
.6395 .58254 m .63873 .63861 L .65133 .6457 L p .707 .577 .707 r
F P
0 g
s
.7052 .78223 m .70334 .76559 L .67582 .75999 L p .707 .577 .707 r
F P
0 g
s
.70334 .76559 m .7052 .78223 L .73631 .78292 L p .707 .577 .707 r
F P
0 g
s
.65098 .68232 m .65261 .71804 L .6737 .72606 L p .707 .577 .707 r
F P
0 g
s
.83341 .5881 m .83263 .64417 L .83971 .63691 L p .707 .577 .707 r
F P
0 g
s
.83971 .63691 m .84048 .58085 L .83341 .5881 L p .707 .577 .707 r
F P
0 g
s
.79519 .75313 m .79705 .76977 L .82074 .75723 L p .707 .577 .707 r
F P
0 g
s
.82074 .75723 m .81888 .74058 L .79519 .75313 L p .707 .577 .707 r
F P
0 g
s
.67582 .75999 m .67768 .77663 L .7052 .78223 L p .707 .577 .707 r
F P
0 g
s
.63873 .63861 m .6395 .58254 L .6366 .575 L p .707 .577 .707 r
F P
0 g
s
.67768 .77663 m .67582 .75999 L .65458 .75002 L p .707 .577 .707 r
F P
0 g
s
.81888 .74058 m .82074 .75723 L .83671 .74221 L p .707 .577 .707 r
F P
0 g
s
.83671 .74221 m .83485 .72557 L .81888 .74058 L p .707 .577 .707 r
F P
0 g
s
.8321 .66892 m .83374 .70464 L .84074 .69285 L p .707 .577 .707 r
F P
0 g
s
.84074 .69285 m .83911 .65713 L .8321 .66892 L p .707 .577 .707 r
F P
0 g
s
.65458 .75002 m .65644 .76666 L .67768 .77663 L p .707 .577 .707 r
F P
0 g
s
.6366 .575 m .63582 .63106 L .63873 .63861 L p .707 .577 .707 r
F P
0 g
s
.84048 .58085 m .83971 .63691 L .8368 .62937 L p .707 .577 .707 r
F P
0 g
s
.8368 .62937 m .83758 .5733 L .84048 .58085 L p .707 .577 .707 r
F P
0 g
s
.63996 .7077 m .63833 .67198 L .63537 .66035 L p .707 .577 .707 r
F P
0 g
s
.65644 .76666 m .65458 .75002 L .6417 .73666 L p .707 .577 .707 r
F P
0 g
s
.83485 .72557 m .83671 .74221 L .84338 .7262 L p .707 .577 .707 r
F P
0 g
s
.84338 .7262 m .84152 .70956 L .83485 .72557 L p .707 .577 .707 r
F P
0 g
s
.63582 .63106 m .6366 .575 L .64367 .56774 L p .707 .577 .707 r
F P
0 g
s
.6417 .73666 m .64356 .7533 L .65644 .76666 L p .707 .577 .707 r
F P
0 g
s
.63537 .66035 m .637 .69607 L .63996 .7077 L p .707 .577 .707 r
F P
0 g
s
.83911 .65713 m .84074 .69285 L .83778 .68122 L p .707 .577 .707 r
F P
0 g
s
.83778 .68122 m .83614 .6455 L .83911 .65713 L p .707 .577 .707 r
F P
0 g
s
.64367 .56774 m .6429 .62381 L .63582 .63106 L p .707 .577 .707 r
F P
0 g
s
.64356 .7533 m .6417 .73666 L .63844 .72122 L p .707 .577 .707 r
F P
0 g
s
.83758 .5733 m .8368 .62937 L .82421 .62227 L p .707 .577 .707 r
F P
0 g
s
.82421 .62227 m .82498 .56621 L .83758 .5733 L p .707 .577 .707 r
F P
0 g
s
.637 .69607 m .63537 .66035 L .64237 .64856 L p .707 .577 .707 r
F P
0 g
s
.84152 .70956 m .84338 .7262 L .84012 .71076 L p .707 .577 .707 r
F P
0 g
s
.84012 .71076 m .83826 .69412 L .84152 .70956 L p .707 .577 .707 r
F P
0 g
s
.38801 .62113 m .38878 .56506 L .35761 .56298 L p .707 .577 .707 r
F P
0 g
s
.38878 .56506 m .38801 .62113 L .41984 .62086 L p .707 .577 .707 r
F P
0 g
s
.41984 .62086 m .42061 .56479 L .38878 .56506 L p .707 .577 .707 r
F P
0 g
s
.63844 .72122 m .6403 .73786 L .64356 .7533 L p .707 .577 .707 r
F P
0 g
s
.42061 .56479 m .41984 .62086 L .44921 .61827 L p .707 .577 .707 r
F P
0 g
s
.44921 .61827 m .44999 .5622 L .42061 .56479 L p .707 .577 .707 r
F P
0 g
s
.6429 .62381 m .64367 .56774 L .66004 .56148 L p .707 .577 .707 r
F P
0 g
s
.35683 .61905 m .35761 .56298 L .33015 .55877 L p .707 .577 .707 r
F P
0 g
s
.35761 .56298 m .35683 .61905 L .38801 .62113 L p .707 .577 .707 r
F P
0 g
s
.64237 .64856 m .64401 .68428 L .637 .69607 L p .707 .577 .707 r
F P
0 g
s
.83614 .6455 m .83778 .68122 L .82513 .67088 L p .707 .577 .707 r
F P
0 g
s
.82513 .67088 m .8235 .63517 L .83614 .6455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44999 .5622 m .44921 .61827 L .47326 .61362 L p .707 .577 .707 r
F P
0 g
s
.47326 .61362 m .47404 .55755 L .44999 .5622 L p .707 .577 .707 r
F P
0 g
s
.66004 .56148 m .65926 .61754 L .6429 .62381 L p .707 .577 .707 r
F P
0 g
s
.6403 .73786 m .63844 .72122 L .64511 .70521 L p .707 .577 .707 r
F P
0 g
s
.82498 .56621 m .82421 .62227 L .80315 .61633 L p .707 .577 .707 r
F P
0 g
s
.80315 .61633 m .80392 .56026 L .82498 .56621 L p .707 .577 .707 r
F P
0 g
s
.33015 .55877 m .32937 .61483 L .35683 .61905 L p .707 .577 .707 r
F P
0 g
s
.32937 .61483 m .33015 .55877 L .30909 .55282 L p .707 .577 .707 r
F P
0 g
s
.64401 .68428 m .64237 .64856 L .65866 .63777 L p .707 .577 .707 r
F P
0 g
s
.38932 .69554 m .38769 .65983 L .35653 .65847 L p .707 .577 .707 r
F P
0 g
s
.38769 .65983 m .38932 .69554 L .42112 .69319 L p .707 .577 .707 r
F P
0 g
s
.42112 .69319 m .41949 .65747 L .38769 .65983 L p .707 .577 .707 r
F P
0 g
s
.45045 .68736 m .44882 .65164 L .41949 .65747 L p .707 .577 .707 r
F P
0 g
s
.83826 .69412 m .84012 .71076 L .82724 .6974 L p .707 .577 .707 r
F P
0 g
s
.82724 .6974 m .82538 .68076 L .83826 .69412 L p .707 .577 .707 r
F P
0 g
s
.64511 .70521 m .64697 .72185 L .6403 .73786 L p .707 .577 .707 r
F P
0 g
s
.65926 .61754 m .66004 .56148 L .68408 .55683 L p .707 .577 .707 r
F P
0 g
s
.35816 .69418 m .35653 .65847 L .32906 .65353 L p .707 .577 .707 r
F P
0 g
s
.35653 .65847 m .35816 .69418 L .38932 .69554 L p .707 .577 .707 r
F P
0 g
s
.8235 .63517 m .82513 .67088 L .80404 .66285 L p .707 .577 .707 r
F P
0 g
s
.80404 .66285 m .80241 .62714 L .8235 .63517 L p .707 .577 .707 r
F P
0 g
s
.47404 .55755 m .47326 .61362 L .48962 .60735 L p .707 .577 .707 r
F P
0 g
s
.48962 .60735 m .4904 .55129 L .47404 .55755 L p .707 .577 .707 r
F P
0 g
s
.30909 .55282 m .30832 .60889 L .32937 .61483 L p .707 .577 .707 r
F P
0 g
s
.65866 .63777 m .6603 .67348 L .64401 .68428 L p .707 .577 .707 r
F P
0 g
s
.44882 .65164 m .45045 .68736 L .47443 .67862 L p .707 .577 .707 r
F P
0 g
s
.47443 .67862 m .4728 .6429 L .44882 .65164 L p .707 .577 .707 r
F P
0 g
s
.80392 .56026 m .80315 .61633 L .77569 .61211 L p .707 .577 .707 r
F P
0 g
s
.77569 .61211 m .77646 .55605 L .80392 .56026 L p .707 .577 .707 r
F P
0 g
s
.68408 .55683 m .68331 .61289 L .65926 .61754 L p .707 .577 .707 r
F P
0 g
s
.32906 .65353 m .33069 .68925 L .35816 .69418 L p .707 .577 .707 r
F P
0 g
s
.64697 .72185 m .64511 .70521 L .66108 .69019 L p .707 .577 .707 r
F P
0 g
s
.30832 .60889 m .30909 .55282 L .29649 .54573 L p .707 .577 .707 r
F P
0 g
s
.33069 .68925 m .32906 .65353 L .30797 .6455 L p .707 .577 .707 r
F P
0 g
s
.6603 .67348 m .65866 .63777 L .68265 .62903 L p .707 .577 .707 r
F P
0 g
s
.68331 .61289 m .68408 .55683 L .71346 .55424 L p .707 .577 .707 r
F P
0 g
s
.3933 .74611 m .39144 .72946 L .36033 .72878 L p .707 .577 .707 r
F P
0 g
s
.39144 .72946 m .3933 .74611 L .42495 .74181 L p .707 .577 .707 r
F P
0 g
s
.42495 .74181 m .42309 .72517 L .39144 .72946 L p .707 .577 .707 r
F P
0 g
s
.82538 .68076 m .82724 .6974 L .806 .68743 L p .707 .577 .707 r
F P
0 g
s
.806 .68743 m .80414 .67079 L .82538 .68076 L p .707 .577 .707 r
F P
0 g
s
.42309 .72517 m .42495 .74181 L .45404 .73296 L p .707 .577 .707 r
F P
0 g
s
.45404 .73296 m .45218 .71632 L .42309 .72517 L p .707 .577 .707 r
F P
0 g
s
.66108 .69019 m .66294 .70683 L .64697 .72185 L p .707 .577 .707 r
F P
0 g
s
.4728 .6429 m .47443 .67862 L .49073 .66783 L p .707 .577 .707 r
F P
0 g
s
.49073 .66783 m .48909 .63211 L .4728 .6429 L p .707 .577 .707 r
F P
0 g
s
.80241 .62714 m .80404 .66285 L .77657 .65792 L p .707 .577 .707 r
F P
0 g
s
.77657 .65792 m .77494 .6222 L .80241 .62714 L p .707 .577 .707 r
F P
0 g
s
.77646 .55605 m .77569 .61211 L .74452 .61004 L p .707 .577 .707 r
F P
0 g
s
.74452 .61004 m .74529 .55397 L .77646 .55605 L p .707 .577 .707 r
F P
0 g
s
.29649 .54573 m .29572 .60179 L .30832 .60889 L p .707 .577 .707 r
F P
0 g
s
.36219 .74542 m .36033 .72878 L .33281 .72317 L p .707 .577 .707 r
F P
0 g
s
.36033 .72878 m .36219 .74542 L .3933 .74611 L p .707 .577 .707 r
F P
0 g
s
.30797 .6455 m .3096 .68122 L .33069 .68925 L p .707 .577 .707 r
F P
0 g
s
.68265 .62903 m .68428 .66474 L .6603 .67348 L p .707 .577 .707 r
F P
0 g
s
.4904 .55129 m .48962 .60735 L .4967 .6001 L p .707 .577 .707 r
F P
0 g
s
.4967 .6001 m .49747 .54403 L .4904 .55129 L p .707 .577 .707 r
F P
0 g
s
.71268 .6103 m .71346 .55424 L .74529 .55397 L p .707 .577 .707 r
F P
0 g
s
.71346 .55424 m .71268 .6103 L .68331 .61289 L p .707 .577 .707 r
F P
0 g
s
.45218 .71632 m .45404 .73296 L .47773 .72041 L p .707 .577 .707 r
F P
0 g
s
.47773 .72041 m .47587 .70377 L .45218 .71632 L p .707 .577 .707 r
F P
0 g
s
.74529 .55397 m .74452 .61004 L .71268 .6103 L p .707 .577 .707 r
F P
0 g
s
.68428 .66474 m .68265 .62903 L .71198 .6232 L p .707 .577 .707 r
F P
0 g
s
.66294 .70683 m .66108 .69019 L .68477 .67764 L p .707 .577 .707 r
F P
0 g
s
.3096 .68122 m .30797 .6455 L .29532 .63517 L p .707 .577 .707 r
F P
0 g
s
.33281 .72317 m .33467 .73981 L .36219 .74542 L p .707 .577 .707 r
F P
0 g
s
.77494 .6222 m .77657 .65792 L .74541 .65656 L p .707 .577 .707 r
F P
0 g
s
.74541 .65656 m .74378 .62084 L .77494 .6222 L p .707 .577 .707 r
F P
0 g
s
.29572 .60179 m .29649 .54573 L .29359 .53818 L p .707 .577 .707 r
F P
0 g
s
.80414 .67079 m .806 .68743 L .77848 .68183 L p .707 .577 .707 r
F P
0 g
s
.77848 .68183 m .77662 .66518 L .80414 .67079 L p .707 .577 .707 r
F P
0 g
s
.33467 .73981 m .33281 .72317 L .31157 .7132 L p .707 .577 .707 r
F P
0 g
s
.68477 .67764 m .68663 .69428 L .66294 .70683 L p .707 .577 .707 r
F P
0 g
s
.71361 .65891 m .71198 .6232 L .74378 .62084 L p .707 .577 .707 r
F P
0 g
s
.71198 .6232 m .71361 .65891 L .68428 .66474 L p .707 .577 .707 r
F P
0 g
s
.74378 .62084 m .74541 .65656 L .71361 .65891 L p .707 .577 .707 r
F P
0 g
s
.47587 .70377 m .47773 .72041 L .4937 .7054 L p .707 .577 .707 r
F P
0 g
s
.4937 .7054 m .49184 .68875 L .47587 .70377 L p .707 .577 .707 r
F P
0 g
s
.48909 .63211 m .49073 .66783 L .49773 .65604 L p .707 .577 .707 r
F P
0 g
s
.49773 .65604 m .4961 .62032 L .48909 .63211 L p .707 .577 .707 r
F P
0 g
s
.29532 .63517 m .29695 .67088 L .3096 .68122 L p .707 .577 .707 r
F P
0 g
s
.31157 .7132 m .31343 .72984 L .33467 .73981 L p .707 .577 .707 r
F P
0 g
s
.68663 .69428 m .68477 .67764 L .71386 .66879 L p .707 .577 .707 r
F P
0 g
s
.29359 .53818 m .29281 .59425 L .29572 .60179 L p .707 .577 .707 r
F P
0 g
s
.77662 .66518 m .77848 .68183 L .74737 .68114 L p .707 .577 .707 r
F P
0 g
s
.74737 .68114 m .74551 .66449 L .77662 .66518 L p .707 .577 .707 r
F P
0 g
s
.49747 .54403 m .4967 .6001 L .49379 .59255 L p .707 .577 .707 r
F P
0 g
s
.49379 .59255 m .49457 .53649 L .49747 .54403 L p .707 .577 .707 r
F P
0 g
s
.71386 .66879 m .71572 .68543 L .68663 .69428 L p .707 .577 .707 r
F P
0 g
s
.71572 .68543 m .71386 .66879 L .74551 .66449 L p .707 .577 .707 r
F P
0 g
s
.29695 .67088 m .29532 .63517 L .29236 .62354 L p .707 .577 .707 r
F P
0 g
s
.31343 .72984 m .31157 .7132 L .29869 .69984 L p .707 .577 .707 r
F P
0 g
s
.74551 .66449 m .74737 .68114 L .71572 .68543 L p .707 .577 .707 r
F P
0 g
s
.49184 .68875 m .4937 .7054 L .50037 .68938 L p .707 .577 .707 r
F P
0 g
s
.50037 .68938 m .49851 .67274 L .49184 .68875 L p .707 .577 .707 r
F P
0 g
s
.29281 .59425 m .29359 .53818 L .30066 .53092 L p .707 .577 .707 r
F P
0 g
s
.29869 .69984 m .30055 .71648 L .31343 .72984 L p .707 .577 .707 r
F P
0 g
s
.29236 .62354 m .29399 .65925 L .29695 .67088 L p .707 .577 .707 r
F P
0 g
s
.4961 .62032 m .49773 .65604 L .49477 .6444 L p .707 .577 .707 r
F P
0 g
s
.49477 .6444 m .49313 .60869 L .4961 .62032 L p .707 .577 .707 r
F P
0 g
s
.30066 .53092 m .29989 .58699 L .29281 .59425 L p .707 .577 .707 r
F P
0 g
s
.30055 .71648 m .29869 .69984 L .29542 .6844 L p .707 .577 .707 r
F P
0 g
s
.49457 .53649 m .49379 .59255 L .4812 .58546 L p .707 .577 .707 r
F P
0 g
s
.4812 .58546 m .48197 .52939 L .49457 .53649 L p .707 .577 .707 r
F P
0 g
s
.29399 .65925 m .29236 .62354 L .29936 .61175 L p .707 .577 .707 r
F P
0 g
s
.49851 .67274 m .50037 .68938 L .49711 .67394 L p .707 .577 .707 r
F P
0 g
s
.49711 .67394 m .49525 .6573 L .49851 .67274 L p .707 .577 .707 r
F P
0 g
s
.29542 .6844 m .29728 .70104 L .30055 .71648 L p .707 .577 .707 r
F P
0 g
s
.29989 .58699 m .30066 .53092 L .31703 .52466 L p .707 .577 .707 r
F P
0 g
s
.29936 .61175 m .30099 .64746 L .29399 .65925 L p .707 .577 .707 r
F P
0 g
s
.49313 .60869 m .49477 .6444 L .48212 .63407 L p .707 .577 .707 r
F P
0 g
s
.48212 .63407 m .48049 .59835 L .49313 .60869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31703 .52466 m .31625 .58073 L .29989 .58699 L p .707 .577 .707 r
F P
0 g
s
.29728 .70104 m .29542 .6844 L .3021 .66839 L p .707 .577 .707 r
F P
0 g
s
.48197 .52939 m .4812 .58546 L .46014 .57951 L p .707 .577 .707 r
F P
0 g
s
.46014 .57951 m .46091 .52345 L .48197 .52939 L p .707 .577 .707 r
F P
0 g
s
.30099 .64746 m .29936 .61175 L .31565 .60095 L p .707 .577 .707 r
F P
0 g
s
.49525 .6573 m .49711 .67394 L .48423 .66058 L p .707 .577 .707 r
F P
0 g
s
.48423 .66058 m .48237 .64394 L .49525 .6573 L p .707 .577 .707 r
F P
0 g
s
.3021 .66839 m .30396 .68503 L .29728 .70104 L p .707 .577 .707 r
F P
0 g
s
.31625 .58073 m .31703 .52466 L .34107 .52001 L p .707 .577 .707 r
F P
0 g
s
.48049 .59835 m .48212 .63407 L .46103 .62604 L p .707 .577 .707 r
F P
0 g
s
.46103 .62604 m .4594 .59032 L .48049 .59835 L p .707 .577 .707 r
F P
0 g
s
.31565 .60095 m .31729 .63667 L .30099 .64746 L p .707 .577 .707 r
F P
0 g
s
.46091 .52345 m .46014 .57951 L .43268 .5753 L p .707 .577 .707 r
F P
0 g
s
.43268 .5753 m .43345 .51923 L .46091 .52345 L p .707 .577 .707 r
F P
0 g
s
.34107 .52001 m .3403 .57608 L .31625 .58073 L p .707 .577 .707 r
F P
0 g
s
.30396 .68503 m .3021 .66839 L .31807 .65337 L p .707 .577 .707 r
F P
0 g
s
.31729 .63667 m .31565 .60095 L .33964 .59221 L p .707 .577 .707 r
F P
0 g
s
.3403 .57608 m .34107 .52001 L .37045 .51742 L p .707 .577 .707 r
F P
0 g
s
.48237 .64394 m .48423 .66058 L .46299 .65061 L p .707 .577 .707 r
F P
0 g
s
.46299 .65061 m .46113 .63397 L .48237 .64394 L p .707 .577 .707 r
F P
0 g
s
.31807 .65337 m .31993 .67002 L .30396 .68503 L p .707 .577 .707 r
F P
0 g
s
.4594 .59032 m .46103 .62604 L .43356 .6211 L p .707 .577 .707 r
F P
0 g
s
.43356 .6211 m .43193 .58539 L .4594 .59032 L p .707 .577 .707 r
F P
0 g
s
.43345 .51923 m .43268 .5753 L .40151 .57322 L p .707 .577 .707 r
F P
0 g
s
.40151 .57322 m .40228 .51715 L .43345 .51923 L p .707 .577 .707 r
F P
0 g
s
.33964 .59221 m .34127 .62793 L .31729 .63667 L p .707 .577 .707 r
F P
0 g
s
.36967 .57349 m .37045 .51742 L .40228 .51715 L p .707 .577 .707 r
F P
0 g
s
.37045 .51742 m .36967 .57349 L .3403 .57608 L p .707 .577 .707 r
F P
0 g
s
.40228 .51715 m .40151 .57322 L .36967 .57349 L p .707 .577 .707 r
F P
0 g
s
.34127 .62793 m .33964 .59221 L .36896 .58638 L p .707 .577 .707 r
F P
0 g
s
.31993 .67002 m .31807 .65337 L .34176 .64083 L p .707 .577 .707 r
F P
0 g
s
.43193 .58539 m .43356 .6211 L .4024 .61975 L p .707 .577 .707 r
F P
0 g
s
.4024 .61975 m .40077 .58403 L .43193 .58539 L p .707 .577 .707 r
F P
0 g
s
.46113 .63397 m .46299 .65061 L .43547 .64501 L p .707 .577 .707 r
F P
0 g
s
.43547 .64501 m .43361 .62837 L .46113 .63397 L p .707 .577 .707 r
F P
0 g
s
.34176 .64083 m .34362 .65747 L .31993 .67002 L p .707 .577 .707 r
F P
0 g
s
.3706 .6221 m .36896 .58638 L .40077 .58403 L p .707 .577 .707 r
F P
0 g
s
.36896 .58638 m .3706 .6221 L .34127 .62793 L p .707 .577 .707 r
F P
0 g
s
.40077 .58403 m .4024 .61975 L .3706 .6221 L p .707 .577 .707 r
F P
0 g
s
.34362 .65747 m .34176 .64083 L .37085 .63197 L p .707 .577 .707 r
F P
0 g
s
.43361 .62837 m .43547 .64501 L .40436 .64432 L p .707 .577 .707 r
F P
0 g
s
.40436 .64432 m .4025 .62768 L .43361 .62837 L p .707 .577 .707 r
F P
0 g
s
.37085 .63197 m .37271 .64861 L .34362 .65747 L p .707 .577 .707 r
F P
0 g
s
.37271 .64861 m .37085 .63197 L .4025 .62768 L p .707 .577 .707 r
F P
0 g
s
.4025 .62768 m .40436 .64432 L .37271 .64861 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00Kgoo100015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qoo`00IWoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YFFUIJ
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005moob0000EJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00G7oo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00FGoo0`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001GOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P003goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo20000eYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH003Moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00
Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool005=oo`03001J
EP0000=JEP03001JEUYF00=JEQl000AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00Dgoo00<005YF00000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUH0000F00000eYF001J
EP05FUH30003FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF00=J
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00
FUIJEP0200000eYF00000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF
00=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00=JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YFFUIJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080
00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YF000000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Agoo2@0017oo00<005YFFUH00`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`l000AJEP03001JEUYF009JEPP0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF200015YF00<005YF
FUH00eYF00<005YFFUH00P00;Woo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEQD000IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF3`000eYF00<005YFFUH00eYF10000UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH00`00FUIJEP07FUH20003FUH40002FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEP00FUH00P0000=JEP00FUH015YF00<005YFFUH01EYF200015YF00<005YFFUH01UYF
00<005YF00000`001UYF00<005YFFUH01000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH4
00001EYF001JEUYF00001EYF3`0015YF100015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF00001@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@005YFFUIJEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00@005YFFUIJEP80009JEP04001JEUYF0002FUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030004FUH3000015YF001JEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0`00;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH01000FUH0000015YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000AJEP00FUIJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH20006FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300001UYF000005YF001JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0002FUH200000eYF001JEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000UYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJ
EP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00FUH005YF1@000eYF00<005YF
FUH015YF1P0000=JEP00FUH025YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF008000EJEP03001JEUYF00@00003
FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00T000AJEP05001JEP00FUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH01000FUH000001UYF0`0000=JEP0000000UYF00<005YFFUH0
0eYF00@005YFFUIJEPT000=JEP03001JEUYF00=JEP<00004FUH005YFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0003FUH20002FUH20000
0eYF001JEP03FUH20002FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF
00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH50002FUH01000FUIJ
EP000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00@000Qoo`L000Qoo`H000AJEP03001JEUYF
008002ioo`00;7oo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP@0009JEP03001oogoo00=oo`@0009J
EP03001JEUYF009JEPP000Ioo`<00003FUH005YF009JEP03001oogoo02aoo`00;7oo00@005YF001J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEQ0000AJEP04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF00000004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YFFUIJ
EP00FUH40002FUH01P00FUIJEUYF001oo`@000IJEP03001JEUYF00IJEP04001JEUYFFUH50004Ool2
0003FUH00`00Oomoo`0/Ool002aoo`03001JEP00008000EJEP03001JEUYF00EJEPP000AJEP03001J
EUYF00IJEP<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF0`000goo0P000UYF00<007ooOol0;7oo
000/Ool20002FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUH0009JEP03001JEUYF009JEP<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0009JEP<002ioo`00;7oo
0P000UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00@005YF
FUIJEP8000IJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF0`000eYF00<005YFFUH00`0025YF00<005YFFUH00UYF3`001UYF00@005YFFUIJEP800004
FUH005YF000^Ool002aoo`80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF1@00
15YF00<005YFFUH01UYF00H005YF000005YF0005FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P000UYF0`000UYF00<005YFFUH0
1EYF1P003goo10000UYF00<005YFFUH00UYF0`0000=JEP00Ool0;Goo000]Ool01@00FUIJEP00FUH0
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP800003
FUH005YF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00AJEP@000=JEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YF00000P001EYF00<005YFFUH00UYF0P005Goo1`0015YF00D005YF001JEP0002ioo`00
;Woo1@001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YF000010000eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010001eYF00<005YFFUH00UYF0P00
0UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH0
0`00FUH00007FUH00`00FUH00002000COol40002FUH00`00FUIJEP02FUH20003FUH01000FUH00000
;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0005FUH00`00FUIJEP03FUHI000;FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001eYF20002Goo1`001UYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0002ioo`00;Woo00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP0000EJEP8000=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001oogoo02aoo`00;Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YF
FUIJEP00009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHF00000eYF000000020002FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP05001JEUYF001oo`03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPH0
01Ioo`05001JEUYF001oo`040004FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH20003FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=oo`8002eoo`00;7oo00<005YF000015YF
00@005YFFUIJEP80011oo`L000Eoo`03001JEUYF00<000=oo`<00004FUH005YFFUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool2000]
Ool002aoo`03001JEP0000AJEP04001JEP00000>Ool40002FUH00`00FUIJEP02FUH7000015YF001J
EUYF0P0017oo0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEP800003
FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YF100015YF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF
00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00004FUH2000<Ool40006FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP<0009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00MJEP@000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF1@0015YF00<0
05YFFUH015YF0`002Woo00<005YF0000;Goo000/Ool00`00FUH00002FUH2000:Ool400000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF00001P000UYF00<005YFFUH00eYF
00<005YFFUH00UYF1P001eYF00<005YFFUH00P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP@000AJEPH000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00@0
00eoo`03001JEP0002eoo`00;7oo00<005YF00000P002Goo0`001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
0`0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP@000AJEP03001JEUYF00=JEPT000AJEP@00003FUH0000000D0011oo`800003FUH007oo02aoo`00
;7oo00@005YF001JEP<000Eoo`<000MJEP03001JEUYF009JEPl000AJEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH40004FUH00`00FUIJEP03FUH0
1000FUIJEP001Goo2@005Goo0P0000=JEP000000;Woo000/Ool20002FUH00`00FUIJEP0200000goo
00000002FUH00`00FUIJEP04FUH6000?Ool40002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00@005YFFUH0029oo`04001JEUYFFUH2
000^Ool002aoo`80009JEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH2000BOol400000eYF001J
EP0300000eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005FUH=000;FUH90008
FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH00P0087oo00<0
05YFFUH00UYF00<007ooOol0;Goo000/Ool20002FUH01000FUIJEP001UYF00<005YF00005P001EYF
00<005YFFUH00UYF0P000eYF2@0015YF00<005YFFUH010000UYF2@002eYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF008001ioo`<000AJEP03001oogoo02eoo`00;7oo0P000UYF00@005YF000000IJ
EP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800004
FUH005YFFUH20002FUH00`00FUH000060003FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUIJEP050005FUH00`00FUIJ
EP02000MOol01000FUIJEP000eYF00<007ooOol0;Woo000/Ool20002FUH200000eYF001JEP03FUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
00000UYF0P000UYF00<005YFFUH00eYF00<005YF000010002UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00D005YFFUIJEP0000=o
o`8000=JEP05001JEUYFFUH0000KOol20004FUH00`00FUH0000aOol002eoo`03001JEP0000=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP06001JEUYFFUH005YF0P000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF100015YF00@005YFFUIJEP<000=o
o`800003FUH005YF009JEP03001oogoo01Ioo`<000IJEP80039oo`00;Goo0P0015YF10001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00`0000EJ
EP00FUIJEP0000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEP0000QJEP04001JEUYFFUH20003FUH01000FUIJEP000UYF0P000goo0P000eYF
00<007ooOol04Woo10000UYF00<005YFFUH00eYF0P00<goo000^Ool00`00FUIJEP02FUH01@00FUIJ
EUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
0goo0P000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00=JEPH0
009JEP03001oogoo00]oo`L000IJEP04001JEUYFFUH2000eOol002eoo`8000=JEP03001JEUYF009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Ioo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00AJEPH000EJEP04001JEUYFFUHA
0004FUH00`00FUIJEP06FUH01000FUH00000=goo000]Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001goo0P0000=J
EP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF008000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00<005YFFUH0
0P000Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF10002Woo0`00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P000UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?7oo000/Ool01000FUIJEP001Woo1@00
0eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000X000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008003ioo`00;7oo00<005YF000037oo200015YF30004Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF0P0000=JEP0000000P000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P00@Goo000/Ool00`00FUH0000DOol9000GOol200000eYF00000004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP<00003FUH005YF010004Moo`00;Goo
00<007ooOol067oo0`005goo00@005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00009JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomoo`1COol002eoo`03001oogoo
035oo`04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0005Eoo`00;Goo0P00<Goo00<005YFFUH00UYF00<007oo000015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo000]Ool00`00FUH0000^Ool30004FUH00`00Oomoo`020002FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH30002Ool3001DOol002ioo`03001JEP0002]oo`80
009JEP05001JEUYFFUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH20005Ool2
001DOol002ioo`04001JEUYF000XOol20004FUH01000FUH0000027oo0P001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
1UYF00@005YFFUIJEP8000Moo`8005Aoo`00;Woo00<005YFFUH00`0097oo0P001UYF0P0037oo0`00
15YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0`000eYF00<005YFFUH01EYF00@005YF000000Uoo`8005Aoo`00;goo00<005YF00000UYF0P00
7Woo100000=JEP00FUH01EYF00<007ooOol03Woo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001EYF00<005YFFUH00UYF1@002Woo00<005YF
0000E7oo000`Ool00`00FUH00003FUH5000BOol70005FUH00`00FUIJEP02FUH2000DOol40008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH500000eYF0000000<000?Ool00`00FUH0
001DOol0035oo`8000AJEP04001JEUYFFUHB0004FUH00`00FUIJEP06FUH01000FUH000006Woo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEQ4001Moo`800003FUH007oo05=oo`00
<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
8Woo20001UYF00<005YFFUH015YF2P0037oo1@005Woo00@005YF000005Eoo`00=7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo3@005goo0`005Woo
00<005YFFUH00P00EGoo000gOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002
000iOol2000aOol01@00FUIJEUYF0000EWoo000jOol400000eYF001JEP07FUH00`00FUIJEP02FUH6
000lOol00`00FUH0000_Ool00`00FUIJEP02FUH00`00Oomoo`1DOol003ioo`l0049oo`04001JEUYF
000/Ool30003FUH00`00Oomoo`1EOol008moo`05001JEUYFFUH0000YOol20002FUH01000FUIJEP00
F7oo002?Ool01000FUIJEUYF0`0097oo0`001EYF0P00FGoo002@Ool01000FUIJEP000UYF0P007goo
0`0000=JEP00FUH01EYF00<007ooOol0F7oo002AOol00`00FUH00004FUH3000IOol30004FUH00`00
FUIJEP02FUH2001KOol0099oo`8000EJEP03001JEP0000<000moo`H000MJEP03001JEUYF008005eo
o`00Tgoo00<005YFFUH00eYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF0`00Ggoo002DOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2001QOol0
09Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00
V7oo1@0015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Igoo002MOol90004FUH00`00FUIJEP04
001/Ool00:Ioo`L0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5924 .74269 m .59366 .68636 L .56249 .68418 L p .707 .577 .707 r
F P
0 g
s
.59366 .68636 m .5924 .74269 L .62423 .74274 L p .707 .577 .707 r
F P
0 g
s
.62423 .74274 m .62548 .68641 L .59366 .68636 L p .707 .577 .707 r
F P
0 g
s
.62548 .68641 m .62423 .74274 L .6536 .74064 L p .707 .577 .707 r
F P
0 g
s
.6536 .74064 m .65485 .68431 L .62548 .68641 L p .707 .577 .707 r
F P
0 g
s
.56123 .74051 m .56249 .68418 L .53503 .68007 L p .707 .577 .707 r
F P
0 g
s
.56249 .68418 m .56123 .74051 L .5924 .74269 L p .707 .577 .707 r
F P
0 g
s
.65485 .68431 m .6536 .74064 L .67763 .73661 L p .707 .577 .707 r
F P
0 g
s
.67763 .73661 m .67889 .68028 L .65485 .68431 L p .707 .577 .707 r
F P
0 g
s
.53503 .68007 m .53377 .7364 L .56123 .74051 L p .707 .577 .707 r
F P
0 g
s
.53377 .7364 m .53503 .68007 L .51396 .67444 L p .707 .577 .707 r
F P
0 g
s
.59474 .8224 m .59211 .78775 L .56097 .78671 L p .707 .577 .707 r
F P
0 g
s
.59211 .78775 m .59474 .8224 L .62649 .81911 L p .707 .577 .707 r
F P
0 g
s
.62649 .81911 m .62385 .78446 L .59211 .78775 L p .707 .577 .707 r
F P
0 g
s
.62385 .78446 m .62649 .81911 L .65572 .81181 L p .707 .577 .707 r
F P
0 g
s
.65572 .81181 m .65309 .77716 L .62385 .78446 L p .707 .577 .707 r
F P
0 g
s
.5636 .82137 m .56097 .78671 L .53348 .78146 L p .707 .577 .707 r
F P
0 g
s
.56097 .78671 m .5636 .82137 L .59474 .8224 L p .707 .577 .707 r
F P
0 g
s
.51396 .67444 m .51271 .73077 L .53377 .7364 L p .707 .577 .707 r
F P
0 g
s
.67889 .68028 m .67763 .73661 L .69398 .73104 L p .707 .577 .707 r
F P
0 g
s
.69398 .73104 m .69523 .67471 L .67889 .68028 L p .707 .577 .707 r
F P
0 g
s
.65309 .77716 m .65572 .81181 L .6796 .80123 L p .707 .577 .707 r
F P
0 g
s
.6796 .80123 m .67696 .76658 L .65309 .77716 L p .707 .577 .707 r
F P
0 g
s
.51271 .73077 m .51396 .67444 L .50136 .66784 L p .707 .577 .707 r
F P
0 g
s
.53611 .81611 m .53348 .78146 L .51233 .77249 L p .707 .577 .707 r
F P
0 g
s
.53348 .78146 m .53611 .81611 L .5636 .82137 L p .707 .577 .707 r
F P
0 g
s
.67696 .76658 m .6796 .80123 L .69576 .78839 L p .707 .577 .707 r
F P
0 g
s
.69576 .78839 m .69313 .75374 L .67696 .76658 L p .707 .577 .707 r
F P
0 g
s
.50136 .66784 m .5001 .72417 L .51271 .73077 L p .707 .577 .707 r
F P
0 g
s
.69523 .67471 m .69398 .73104 L .70104 .72447 L p .707 .577 .707 r
F P
0 g
s
.70104 .72447 m .7023 .66814 L .69523 .67471 L p .707 .577 .707 r
F P
0 g
s
.51233 .77249 m .51497 .80714 L .53611 .81611 L p .707 .577 .707 r
F P
0 g
s
.60213 .88357 m .59918 .86868 L .56817 .86866 L p .707 .577 .707 r
F P
0 g
s
.59918 .86868 m .60213 .88357 L .63349 .87734 L p .707 .577 .707 r
F P
0 g
s
.63349 .87734 m .63053 .86245 L .59918 .86868 L p .707 .577 .707 r
F P
0 g
s
.63053 .86245 m .63349 .87734 L .66212 .86546 L p .707 .577 .707 r
F P
0 g
s
.66212 .86546 m .65916 .85057 L .63053 .86245 L p .707 .577 .707 r
F P
0 g
s
.51497 .80714 m .51233 .77249 L .4996 .76069 L p .707 .577 .707 r
F P
0 g
s
.57113 .88355 m .56817 .86866 L .54055 .86239 L p .707 .577 .707 r
F P
0 g
s
.56817 .86866 m .57113 .88355 L .60213 .88357 L p .707 .577 .707 r
F P
0 g
s
.65916 .85057 m .66212 .86546 L .68522 .8491 L p .707 .577 .707 r
F P
0 g
s
.68522 .8491 m .68227 .83422 L .65916 .85057 L p .707 .577 .707 r
F P
0 g
s
.5001 .72417 m .50136 .66784 L .49844 .66092 L p .707 .577 .707 r
F P
0 g
s
.69313 .75374 m .69576 .78839 L .70265 .77455 L p .707 .577 .707 r
F P
0 g
s
.70265 .77455 m .70001 .7399 L .69313 .75374 L p .707 .577 .707 r
F P
0 g
s
.54055 .86239 m .5435 .87728 L .57113 .88355 L p .707 .577 .707 r
F P
0 g
s
.4996 .76069 m .50223 .79534 L .51497 .80714 L p .707 .577 .707 r
F P
0 g
s
.49844 .66092 m .49719 .71724 L .5001 .72417 L p .707 .577 .707 r
F P
0 g
s
.5435 .87728 m .54055 .86239 L .51901 .85048 L p .707 .577 .707 r
F P
0 g
s
.68227 .83422 m .68522 .8491 L .70054 .82987 L p .707 .577 .707 r
F P
0 g
s
.70054 .82987 m .69759 .81498 L .68227 .83422 L p .707 .577 .707 r
F P
0 g
s
.7023 .66814 m .70104 .72447 L .69813 .71754 L p .707 .577 .707 r
F P
0 g
s
.69813 .71754 m .69938 .66121 L .7023 .66814 L p .707 .577 .707 r
F P
0 g
s
.50223 .79534 m .4996 .76069 L .49652 .74721 L p .707 .577 .707 r
F P
0 g
s
.51901 .85048 m .52196 .86537 L .5435 .87728 L p .707 .577 .707 r
F P
0 g
s
.49724 .8244 m .48621 .33072 L .44221 .32842 L p .707 .577 .707 r
F P
0 g
s
.49719 .71724 m .49844 .66092 L .5055 .65435 L p .707 .577 .707 r
F P
0 g
s
.49652 .74721 m .49915 .78186 L .50223 .79534 L p .707 .577 .707 r
F P
0 g
s
.5055 .65435 m .50425 .71067 L .49719 .71724 L p .707 .577 .707 r
F P
0 g
s
.49915 .78186 m .49652 .74721 L .5034 .73337 L p .707 .577 .707 r
F P
0 g
s
.50862 .84899 m .50567 .8341 L .50183 .81485 L p .717 .584 .705 r
F P
0 g
s
.50425 .71067 m .5055 .65435 L .52185 .64877 L p .707 .577 .707 r
F P
0 g
s
.5034 .73337 m .50603 .76803 L .49915 .78186 L p .707 .577 .707 r
F P
0 g
s
.50183 .81485 m .50478 .82974 L .50862 .84899 L p .717 .584 .705 r
F P
0 g
s
.52185 .64877 m .5206 .7051 L .50425 .71067 L p .707 .577 .707 r
F P
0 g
s
.50603 .76803 m .5034 .73337 L .51957 .72053 L p .707 .577 .707 r
F P
0 g
s
.50478 .82974 m .50183 .81485 L .50786 .79461 L p .707 .577 .707 r
F P
0 g
s
.5206 .7051 m .52185 .64877 L .54589 .64474 L p .707 .577 .707 r
F P
0 g
s
.50786 .79461 m .51081 .8095 L .50478 .82974 L p .707 .577 .707 r
F P
0 g
s
.51957 .72053 m .5222 .75519 L .50603 .76803 L p .707 .577 .707 r
F P
0 g
s
.54589 .64474 m .54463 .70107 L .5206 .7051 L p .707 .577 .707 r
F P
0 g
s
.5222 .75519 m .51957 .72053 L .54344 .70995 L p .707 .577 .707 r
F P
0 g
s
.51081 .8095 m .50786 .79461 L .52318 .77538 L p .707 .577 .707 r
F P
0 g
s
.52318 .77538 m .52613 .79027 L .51081 .8095 L p .707 .577 .707 r
F P
0 g
s
.54344 .70995 m .54607 .7446 L .5222 .75519 L p .707 .577 .707 r
F P
0 g
s
.52613 .79027 m .52318 .77538 L .54629 .75902 L p .707 .577 .707 r
F P
0 g
s
.54629 .75902 m .54924 .77391 L .52613 .79027 L p .707 .577 .707 r
F P
0 g
s
.48621 .33072 m .49724 .8244 L .54217 .82218 L p .707 .577 .707 r
F P
0 g
s
.54217 .82218 m .53115 .32851 L .48621 .33072 L p .707 .577 .707 r
F P
0 g
s
.54463 .70107 m .54589 .64474 L .57526 .64264 L p .707 .577 .707 r
F P
0 g
s
.54607 .7446 m .54344 .70995 L .57268 .70265 L p .707 .577 .707 r
F P
0 g
s
.57526 .64264 m .574 .69897 L .54463 .70107 L p .707 .577 .707 r
F P
0 g
s
.57268 .70265 m .57531 .73731 L .54607 .7446 L p .707 .577 .707 r
F P
0 g
s
.54924 .77391 m .54629 .75902 L .57492 .74714 L p .707 .577 .707 r
F P
0 g
s
.57787 .76203 m .57492 .74714 L .60627 .74091 L p .707 .577 .707 r
F P
0 g
s
.57492 .74714 m .57787 .76203 L .54924 .77391 L p .707 .577 .707 r
F P
0 g
s
.53115 .32851 m .54217 .82218 L .58363 .81567 L p .707 .577 .707 r
F P
0 g
s
.574 .69897 m .57526 .64264 L .60708 .64269 L p .707 .577 .707 r
F P
0 g
s
.60708 .64269 m .60583 .69902 L .574 .69897 L p .707 .577 .707 r
F P
0 g
s
.57531 .73731 m .57268 .70265 L .60442 .69936 L p .707 .577 .707 r
F P
0 g
s
.60442 .69936 m .60705 .73401 L .57531 .73731 L p .707 .577 .707 r
F P
0 g
s
.60627 .74091 m .60922 .7558 L .57787 .76203 L p .707 .577 .707 r
F P
0 g
s
.58363 .81567 m .57261 .322 L .53115 .32851 L p .707 .577 .707 r
F P
0 g
s
.70001 .7399 m .70265 .77455 L .69957 .76108 L p .707 .577 .707 r
F P
0 g
s
.69957 .76108 m .69694 .72642 L .70001 .7399 L p .707 .577 .707 r
F P
0 g
s
.52196 .86537 m .51901 .85048 L .50567 .8341 L p .707 .577 .707 r
F P
0 g
s
.69759 .81498 m .70054 .82987 L .70658 .80963 L p .707 .577 .707 r
F P
0 g
s
.70658 .80963 m .70363 .79474 L .69759 .81498 L p .707 .577 .707 r
F P
0 g
s
.45323 .8221 m .44221 .32842 L .40344 .32184 L p .707 .577 .707 r
F P
0 g
s
.44221 .32842 m .45323 .8221 L .49724 .8244 L p .707 .577 .707 r
F P
0 g
s
.50567 .8341 m .50862 .84899 L .52196 .86537 L p .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .66305 .70565 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63669 .71517 m .63556 .70039 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .6382 .73505 L .60705 .73401 L p .707 .577 .707 r
F P
0 g
s
.60705 .73401 m .60442 .69936 L .63556 .70039 L p .707 .577 .707 r
F P
0 g
s
.63825 .64488 m .637 .70121 L .62607 .70044 L p .707 .577 .707 r
F P
0 g
s
.62607 .70044 m .60583 .69902 L p .61455 .68446 L .707 .577 .707 r
F P
0 g
s
.61455 .68446 m .63825 .64488 L .62607 .70044 L .707 .577 .707 r
F
.6382 .73505 m .63669 .71517 L p .64511 .72687 L F P
0 g
s
.60583 .69902 m .60708 .64269 L .63825 .64488 L p .707 .577 .707 r
F P
0 g
s
.63728 .74093 m .64023 .75582 L .60922 .7558 L p .707 .577 .707 r
F P
0 g
s
.60922 .7558 m .60627 .74091 L .63728 .74093 L p .707 .577 .707 r
F P
0 g
s
.57261 .322 m .58363 .81567 L .61756 .80551 L p .707 .577 .707 r
F P
0 g
s
.61756 .80551 m .60654 .31183 L .57261 .322 L p .707 .577 .707 r
F P
0 g
s
.69938 .66121 m .69813 .71754 L .68552 .71094 L p .707 .577 .707 r
F P
0 g
s
.68552 .71094 m .68678 .65461 L .69938 .66121 L p .707 .577 .707 r
F P
0 g
s
.24939 .70588 m .25065 .64955 L .21948 .64736 L p .707 .577 .707 r
F P
0 g
s
.25065 .64955 m .24939 .70588 L .28122 .70592 L p .707 .577 .707 r
F P
0 g
s
.28122 .70592 m .28247 .64959 L .25065 .64955 L p .707 .577 .707 r
F P
0 g
s
.70363 .79474 m .70658 .80963 L .70274 .79038 L p .717 .584 .705 r
F P
0 g
s
.70274 .79038 m .69978 .77549 L .70363 .79474 L p .717 .584 .705 r
F P
0 g
s
.41447 .81551 m .40344 .32184 L .3737 .31161 L p .707 .577 .707 r
F P
0 g
s
.40344 .32184 m .41447 .81551 L .45323 .8221 L p .707 .577 .707 r
F P
0 g
s
.28247 .64959 m .28122 .70592 L .31059 .70383 L p .707 .577 .707 r
F P
0 g
s
.31059 .70383 m .31184 .6475 L .28247 .64959 L p .707 .577 .707 r
F P
0 g
s
.69694 .72642 m .69957 .76108 L .68683 .74928 L p .707 .577 .707 r
F P
0 g
s
.68683 .74928 m .6842 .71462 L .69694 .72642 L p .707 .577 .707 r
F P
0 g
s
.21822 .70369 m .21948 .64736 L .19202 .64325 L p .707 .577 .707 r
F P
0 g
s
.21948 .64736 m .21822 .70369 L .24939 .70588 L p .707 .577 .707 r
F P
0 g
s
.31184 .6475 m .31059 .70383 L .33462 .6998 L p .707 .577 .707 r
F P
0 g
s
.33462 .6998 m .33588 .64347 L .31184 .6475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60654 .31183 m .61756 .80551 L .64065 .79268 L p .707 .577 .707 r
F P
0 g
s
.66571 .64899 m .66446 .70531 L .637 .70121 L p .707 .577 .707 r
F P
0 g
s
.637 .70121 m .63825 .64488 L .66571 .64899 L p .707 .577 .707 r
F P
0 g
s
.66305 .70565 m .66569 .74031 L .6382 .73505 L p .707 .577 .707 r
F P
0 g
s
.64023 .75582 m .63728 .74093 L .6649 .7472 L p .707 .577 .707 r
F P
0 g
s
.64065 .79268 m .62962 .299 L .60654 .31183 L p .707 .577 .707 r
F P
0 g
s
.19202 .64325 m .19076 .69958 L .21822 .70369 L p .707 .577 .707 r
F P
0 g
s
.68678 .65461 m .68552 .71094 L .66446 .70531 L p .707 .577 .707 r
F P
0 g
s
.66446 .70531 m .66571 .64899 L .68678 .65461 L p .707 .577 .707 r
F P
0 g
s
.19076 .69958 m .19202 .64325 L .17095 .63762 L p .707 .577 .707 r
F P
0 g
s
.25173 .78559 m .2491 .75093 L .21796 .7499 L p .707 .577 .707 r
F P
0 g
s
.2491 .75093 m .25173 .78559 L .28348 .78229 L p .707 .577 .707 r
F P
0 g
s
.28348 .78229 m .28084 .74764 L .2491 .75093 L p .707 .577 .707 r
F P
0 g
s
.69978 .77549 m .70274 .79038 L .68939 .774 L p .707 .577 .707 r
F P
0 g
s
.68939 .774 m .68644 .75911 L .69978 .77549 L p .707 .577 .707 r
F P
0 g
s
.28084 .74764 m .28348 .78229 L .31272 .775 L p .707 .577 .707 r
F P
0 g
s
.31272 .775 m .31008 .74035 L .28084 .74764 L p .707 .577 .707 r
F P
0 g
s
.6842 .71462 m .68683 .74928 L .66569 .74031 L p .707 .577 .707 r
F P
0 g
s
.66569 .74031 m .66305 .70565 L .6842 .71462 L p .707 .577 .707 r
F P
0 g
s
.22059 .78455 m .21796 .7499 L .19047 .74464 L p .707 .577 .707 r
F P
0 g
s
.21796 .7499 m .22059 .78455 L .25173 .78559 L p .707 .577 .707 r
F P
0 g
s
.38473 .80528 m .3737 .31161 L .35591 .29874 L p .707 .577 .707 r
F P
0 g
s
.3737 .31161 m .38473 .80528 L .41447 .81551 L p .707 .577 .707 r
F P
0 g
s
.17095 .63762 m .1697 .69395 L .19076 .69958 L p .707 .577 .707 r
F P
0 g
s
.33588 .64347 m .33462 .6998 L .35097 .69422 L p .707 .577 .707 r
F P
0 g
s
.35097 .69422 m .35223 .63789 L .33588 .64347 L p .707 .577 .707 r
F P
0 g
s
.31008 .74035 m .31272 .775 L .33659 .76441 L p .707 .577 .707 r
F P
0 g
s
.33659 .76441 m .33395 .72976 L .31008 .74035 L p .707 .577 .707 r
F P
0 g
s
.1697 .69395 m .17095 .63762 L .15835 .63102 L p .707 .577 .707 r
F P
0 g
s
.1931 .77929 m .19047 .74464 L .16932 .73567 L p .707 .577 .707 r
F P
0 g
s
.19047 .74464 m .1931 .77929 L .22059 .78455 L p .707 .577 .707 r
F P
0 g
s
.68644 .75911 m .68939 .774 L .66786 .76209 L p .707 .577 .707 r
F P
0 g
s
.66786 .76209 m .6649 .7472 L .68644 .75911 L p .707 .577 .707 r
F P
0 g
s
.6649 .7472 m .66786 .76209 L .64023 .75582 L p .707 .577 .707 r
F P
0 g
s
.62962 .299 m .64065 .79268 L .65062 .77844 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .63959 .28476 L .62962 .299 L p .707 .577 .707 r
F P
0 g
s
.33395 .72976 m .33659 .76441 L .35276 .75157 L p .707 .577 .707 r
F P
0 g
s
.35276 .75157 m .35012 .71692 L .33395 .72976 L p .707 .577 .707 r
F P
0 g
s
.15835 .63102 m .15709 .68735 L .1697 .69395 L p .707 .577 .707 r
F P
0 g
s
.35223 .63789 m .35097 .69422 L .35803 .68765 L p .707 .577 .707 r
F P
0 g
s
.35803 .68765 m .35929 .63132 L .35223 .63789 L p .707 .577 .707 r
F P
0 g
s
.16932 .73567 m .17196 .77033 L .1931 .77929 L p .707 .577 .707 r
F P
0 g
s
.25912 .84676 m .25617 .83187 L .22516 .83185 L p .707 .577 .707 r
F P
0 g
s
.25617 .83187 m .25912 .84676 L .29048 .84052 L p .707 .577 .707 r
F P
0 g
s
.29048 .84052 m .28752 .82563 L .25617 .83187 L p .707 .577 .707 r
F P
0 g
s
.28752 .82563 m .29048 .84052 L .31911 .82865 L p .707 .577 .707 r
F P
0 g
s
.31911 .82865 m .31616 .81376 L .28752 .82563 L p .707 .577 .707 r
F P
0 g
s
.17196 .77033 m .16932 .73567 L .15659 .72387 L p .707 .577 .707 r
F P
0 g
s
.22812 .84674 m .22516 .83185 L .19754 .82558 L p .707 .577 .707 r
F P
0 g
s
.22516 .83185 m .22812 .84674 L .25912 .84676 L p .707 .577 .707 r
F P
0 g
s
.31616 .81376 m .31911 .82865 L .34222 .81229 L p .707 .577 .707 r
F P
0 g
s
.34222 .81229 m .33926 .7974 L .31616 .81376 L p .707 .577 .707 r
F P
0 g
s
.36693 .79242 m .35591 .29874 L .35179 .28449 L p .707 .577 .707 r
F P
0 g
s
.35591 .29874 m .36693 .79242 L .38473 .80528 L p .707 .577 .707 r
F P
0 g
s
.15709 .68735 m .15835 .63102 L .15543 .6241 L p .707 .577 .707 r
F P
0 g
s
.35012 .71692 m .35276 .75157 L .35964 .73774 L p .707 .577 .707 r
F P
0 g
s
.35964 .73774 m .357 .70309 L .35012 .71692 L p .707 .577 .707 r
F P
0 g
s
.19754 .82558 m .20049 .84046 L .22812 .84674 L p .707 .577 .707 r
F P
0 g
s
.15659 .72387 m .15922 .75852 L .17196 .77033 L p .707 .577 .707 r
F P
0 g
s
.15543 .6241 m .15418 .68043 L .15709 .68735 L p .707 .577 .707 r
F P
0 g
s
.20049 .84046 m .19754 .82558 L .176 .81367 L p .707 .577 .707 r
F P
0 g
s
.33926 .7974 m .34222 .81229 L .35754 .79305 L p .707 .577 .707 r
F P
0 g
s
.35754 .79305 m .35458 .77816 L .33926 .7974 L p .707 .577 .707 r
F P
0 g
s
.35929 .63132 m .35803 .68765 L .35512 .68073 L p .707 .577 .707 r
F P
0 g
s
.35512 .68073 m .35637 .6244 L .35929 .63132 L p .707 .577 .707 r
F P
0 g
s
.15922 .75852 m .15659 .72387 L .15351 .71039 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .64865 .77161 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.63959 .28476 m .64558 .55265 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64558 .55265 m .65062 .77844 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64563 .70311 m .63959 .28476 L .64865 .77161 L .707 .577 .707 r
F
.63548 .27051 m .63959 .28476 L p .64563 .70311 L F P
0 g
s
.63548 .27051 m .64651 .76419 L .62871 .75132 L p .707 .577 .707 r
F P
0 g
s
.6368 .67929 m .63943 .71394 L .64441 .71856 L p .707 .577 .707 r
F P
0 g
s
.64651 .76419 m .64467 .68193 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64865 .77161 m .64651 .76419 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64441 .71856 m .65217 .72574 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.64452 .70264 m .6368 .67929 L .64441 .71856 L .707 .577 .707 r
F
.64467 .68193 m .64465 .68093 L p .64467 .68151 L F P
0 g
s
.64467 .68193 m .64467 .68151 L .64563 .70311 L .707 .577 .707 r
F
.64465 .68093 m .63548 .27051 L p .64563 .70311 L F P
0 g
s
.63856 .58336 m .6373 .63968 L .64296 .64264 L p .707 .577 .707 r
F P
0 g
s
.64296 .64264 m .64991 .64628 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64092 .59643 m .63856 .58336 L .64296 .64264 L .707 .577 .707 r
F
.65217 .72574 m .64954 .69109 L .64464 .68655 L p F P
0 g
s
.64464 .68655 m .6368 .67929 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.65217 .72574 m .64464 .68655 L .64452 .70264 L .707 .577 .707 r
F
.64991 .64628 m .65117 .58996 L .64038 .58431 L p F P
0 g
s
.64038 .58431 m .63856 .58336 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64991 .64628 m .64038 .58431 L .64092 .59643 L .707 .577 .707 r
F
.176 .81367 m .17896 .82855 L .20049 .84046 L p F P
0 g
s
.15418 .68043 m .15543 .6241 L .16249 .61753 L p .707 .577 .707 r
F P
0 g
s
.357 .70309 m .35964 .73774 L .35656 .72426 L p .707 .577 .707 r
F P
0 g
s
.35656 .72426 m .35393 .68961 L .357 .70309 L p .707 .577 .707 r
F P
0 g
s
.17896 .82855 m .176 .81367 L .16266 .79728 L p .707 .577 .707 r
F P
0 g
s
.35458 .77816 m .35754 .79305 L .36357 .77282 L p .707 .577 .707 r
F P
0 g
s
.36357 .77282 m .36062 .75793 L .35458 .77816 L p .707 .577 .707 r
F P
0 g
s
.15351 .71039 m .15614 .74505 L .15922 .75852 L p .707 .577 .707 r
F P
0 g
s
.36062 .75793 m .36357 .77282 L .35973 .75357 L p .717 .584 .705 r
F P
0 g
s
.35179 .28449 m .36282 .77817 L .36693 .79242 L p .707 .577 .707 r
F P
0 g
s
.36282 .77817 m .35179 .28449 L .36177 .27025 L p .707 .577 .707 r
F P
0 g
s
.16249 .61753 m .16124 .67386 L .15418 .68043 L p .707 .577 .707 r
F P
0 g
s
.16266 .79728 m .16561 .81217 L .17896 .82855 L p .707 .577 .707 r
F P
0 g
s
.35637 .6244 m .35512 .68073 L .34251 .67413 L p .707 .577 .707 r
F P
0 g
s
.34251 .67413 m .34377 .6178 L .35637 .6244 L p .707 .577 .707 r
F P
0 g
s
.15614 .74505 m .15351 .71039 L .16039 .69656 L p .707 .577 .707 r
F P
0 g
s
.16561 .81217 m .16266 .79728 L .15882 .77803 L p .717 .584 .705 r
F P
0 g
s
.35973 .75357 m .35677 .73868 L .36062 .75793 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16124 .67386 m .16249 .61753 L .17884 .61196 L p .707 .577 .707 r
F P
0 g
s
.35393 .68961 m .35656 .72426 L .34382 .71246 L p .707 .577 .707 r
F P
0 g
s
.34382 .71246 m .34119 .67781 L .35393 .68961 L p .707 .577 .707 r
F P
0 g
s
.62871 .75132 m .61768 .25764 L .63548 .27051 L p .707 .577 .707 r
F P
0 g
s
.16039 .69656 m .16302 .73121 L .15614 .74505 L p .707 .577 .707 r
F P
0 g
s
.15882 .77803 m .16177 .79292 L .16561 .81217 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17884 .61196 m .17759 .66828 L .16124 .67386 L p .707 .577 .707 r
F P
0 g
s
.16302 .73121 m .16039 .69656 L .17656 .68372 L p .707 .577 .707 r
F P
0 g
s
.34377 .6178 m .34251 .67413 L .32145 .6685 L p .707 .577 .707 r
F P
0 g
s
.32145 .6685 m .3227 .61217 L .34377 .6178 L p .707 .577 .707 r
F P
0 g
s
.16177 .79292 m .15882 .77803 L .16485 .7578 L p .707 .577 .707 r
F P
0 g
s
.35677 .73868 m .35973 .75357 L .34638 .73718 L p .707 .577 .707 r
F P
0 g
s
.34638 .73718 m .34343 .7223 L .35677 .73868 L p .707 .577 .707 r
F P
0 g
s
.37279 .76393 m .36177 .27025 L .38485 .25742 L p .707 .577 .707 r
F P
0 g
s
.36177 .27025 m .37279 .76393 L .36282 .77817 L p .707 .577 .707 r
F P
0 g
s
.17759 .66828 m .17884 .61196 L .20288 .60792 L p .707 .577 .707 r
F P
0 g
s
.34119 .67781 m .34382 .71246 L .32268 .70349 L p .707 .577 .707 r
F P
0 g
s
.32268 .70349 m .32004 .66884 L .34119 .67781 L p .707 .577 .707 r
F P
0 g
s
.16485 .7578 m .1678 .77269 L .16177 .79292 L p .707 .577 .707 r
F P
0 g
s
.17656 .68372 m .17919 .71837 L .16302 .73121 L p .707 .577 .707 r
F P
0 g
s
.20288 .60792 m .20162 .66425 L .17759 .66828 L p .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .32004 .66884 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29519 .69823 m .29368 .67836 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29368 .67836 m .29255 .66358 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .29519 .69823 L .26405 .6972 L p .707 .577 .707 r
F P
0 g
s
.26405 .6972 m .26141 .66254 L .29255 .66358 L p .707 .577 .707 r
F P
0 g
s
.29524 .60806 m .29399 .66439 L .28306 .66362 L p .707 .577 .707 r
F P
0 g
s
.28306 .66362 m .26282 .66221 L p .27154 .64764 L .707 .577 .707 r
F P
0 g
s
.27154 .64764 m .29524 .60806 L .28306 .66362 L .707 .577 .707 r
F
.3227 .61217 m .32145 .6685 L .29399 .66439 L p F P
0 g
s
.29399 .66439 m .29524 .60806 L .3227 .61217 L p .707 .577 .707 r
F P
0 g
s
.17919 .71837 m .17656 .68372 L .20043 .67313 L p .707 .577 .707 r
F P
0 g
s
.61768 .25764 m .62871 .75132 L .59897 .74109 L p .707 .577 .707 r
F P
0 g
s
.59897 .74109 m .58795 .24741 L .61768 .25764 L p .707 .577 .707 r
F P
0 g
s
.1678 .77269 m .16485 .7578 L .18017 .73856 L p .707 .577 .707 r
F P
0 g
s
.34343 .7223 m .34638 .73718 L .32485 .72527 L p .707 .577 .707 r
F P
0 g
s
.32485 .72527 m .32189 .71039 L .34343 .7223 L p .707 .577 .707 r
F P
0 g
s
.20162 .66425 m .20288 .60792 L .23225 .60583 L p .707 .577 .707 r
F P
0 g
s
.32004 .66884 m .32268 .70349 L .29519 .69823 L p .707 .577 .707 r
F P
0 g
s
.26282 .66221 m .26407 .60588 L .29524 .60806 L p .707 .577 .707 r
F P
0 g
s
.18017 .73856 m .18312 .75345 L .1678 .77269 L p .707 .577 .707 r
F P
0 g
s
.20043 .67313 m .20306 .70779 L .17919 .71837 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .37279 .76393 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.38981 .47983 m .39587 .7511 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .38485 .25742 L .41878 .24725 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .40399 .57256 L .4278 .65808 L .707 .577 .707 r
F
.42981 .74093 m .41213 .74623 L p .42785 .65823 L F P
0 g
s
.42795 .65767 m .42797 .65868 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42797 .65868 m .42981 .74093 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42981 .74093 m .41878 .24725 L .46024 .24074 L p .707 .577 .707 r
F P
0 g
s
.46024 .24074 m .47127 .73442 L .42981 .74093 L p .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .44729 .65895 L .42929 .66344 L p .707 .577 .707 r
F P
0 g
s
.41213 .74623 m .39587 .7511 L p .42795 .65767 L .707 .577 .707 r
F P
0 g
s
.42929 .66344 m .41805 .66624 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .42929 .66344 L .43385 .67981 L .707 .577 .707 r
F
.41805 .66624 m .42068 .7009 L .43849 .69645 L p F P
0 g
s
.43849 .69645 m .44992 .6936 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.43385 .67981 m .41805 .66624 L .43849 .69645 L .707 .577 .707 r
F
.41878 .24725 m .42795 .65767 L p .4278 .65808 L F P
0 g
s
.40399 .57256 m .41878 .24725 L .4278 .65808 L .707 .577 .707 r
F
.41968 .56511 m .41842 .62144 L .43462 .62028 L p F P
0 g
s
.43462 .62028 m .44779 .61934 L p .43812 .60069 L .707 .577 .707 r
F P
0 g
s
.43812 .60069 m .41968 .56511 L .43462 .62028 L .707 .577 .707 r
F
.3863 .66954 m .38894 .70419 L .41279 .70172 L p F P
0 g
s
.41279 .70172 m .42068 .7009 L p .41187 .69286 L .707 .577 .707 r
F P
0 g
s
.41187 .69286 m .3863 .66954 L .41279 .70172 L .707 .577 .707 r
F
.38485 .25742 m .38981 .47983 L p .38147 .39925 L F P
0 g
s
.20306 .70779 m .20043 .67313 L .22967 .66584 L p .707 .577 .707 r
F P
0 g
s
.23225 .60583 m .23099 .66216 L .20162 .66425 L p .707 .577 .707 r
F P
0 g
s
.23099 .66216 m .23225 .60583 L .26407 .60588 L p .707 .577 .707 r
F P
0 g
s
.26407 .60588 m .26282 .66221 L .23099 .66216 L p .707 .577 .707 r
F P
0 g
s
.72961 .65821 m .73086 .60188 L .69969 .59969 L p .707 .577 .707 r
F P
0 g
s
.73086 .60188 m .72961 .65821 L .76143 .65825 L p .707 .577 .707 r
F P
0 g
s
.76143 .65825 m .76269 .60193 L .73086 .60188 L p .707 .577 .707 r
F P
0 g
s
.18312 .75345 m .18017 .73856 L .20328 .7222 L p .707 .577 .707 r
F P
0 g
s
.32189 .71039 m .32485 .72527 L .29722 .719 L p .707 .577 .707 r
F P
0 g
s
.29722 .719 m .29427 .70411 L .32189 .71039 L p .707 .577 .707 r
F P
0 g
s
.76269 .60193 m .76143 .65825 L .7908 .65616 L p .707 .577 .707 r
F P
0 g
s
.7908 .65616 m .79206 .59983 L .76269 .60193 L p .707 .577 .707 r
F P
0 g
s
.2323 .70049 m .22967 .66584 L .26141 .66254 L p .707 .577 .707 r
F P
0 g
s
.22967 .66584 m .2323 .70049 L .20306 .70779 L p .707 .577 .707 r
F P
0 g
s
.69844 .65602 m .69969 .59969 L .67223 .59559 L p .707 .577 .707 r
F P
0 g
s
.69969 .59969 m .69844 .65602 L .72961 .65821 L p .707 .577 .707 r
F P
0 g
s
.26141 .66254 m .26405 .6972 L .2323 .70049 L p .707 .577 .707 r
F P
0 g
s
.58795 .24741 m .59897 .74109 L .5602 .73451 L p .707 .577 .707 r
F P
0 g
s
.5602 .73451 m .54918 .24083 L .58795 .24741 L p .707 .577 .707 r
F P
0 g
s
.20328 .7222 m .20623 .73709 L .18312 .75345 L p .707 .577 .707 r
F P
0 g
s
.79206 .59983 m .7908 .65616 L .81484 .65213 L p .707 .577 .707 r
F P
0 g
s
.81484 .65213 m .81609 .5958 L .79206 .59983 L p .707 .577 .707 r
F P
0 g
s
.20623 .73709 m .20328 .7222 L .23191 .71033 L p .707 .577 .707 r
F P
0 g
s
.29427 .70411 m .29722 .719 L .26622 .71898 L p .707 .577 .707 r
F P
0 g
s
.26622 .71898 m .26326 .70409 L .29427 .70411 L p .707 .577 .707 r
F P
0 g
s
.67223 .59559 m .67098 .65191 L .69844 .65602 L p .707 .577 .707 r
F P
0 g
s
.67098 .65191 m .67223 .59559 L .65117 .58996 L p .707 .577 .707 r
F P
0 g
s
.23486 .72522 m .23191 .71033 L .26326 .70409 L p .707 .577 .707 r
F P
0 g
s
.23191 .71033 m .23486 .72522 L .20623 .73709 L p .707 .577 .707 r
F P
0 g
s
.26326 .70409 m .26622 .71898 L .23486 .72522 L p .707 .577 .707 r
F P
0 g
s
.73195 .741 m .72931 .70635 L .69817 .70532 L p .707 .577 .707 r
F P
0 g
s
.72931 .70635 m .73195 .741 L .76369 .73771 L p .707 .577 .707 r
F P
0 g
s
.76369 .73771 m .76106 .70306 L .72931 .70635 L p .707 .577 .707 r
F P
0 g
s
.76106 .70306 m .76369 .73771 L .79293 .73042 L p .707 .577 .707 r
F P
0 g
s
.79293 .73042 m .7903 .69576 L .76106 .70306 L p .707 .577 .707 r
F P
0 g
s
.70081 .73997 m .69817 .70532 L .67068 .70006 L p .707 .577 .707 r
F P
0 g
s
.69817 .70532 m .70081 .73997 L .73195 .741 L p .707 .577 .707 r
F P
0 g
s
.54918 .24083 m .5602 .73451 L .5162 .73221 L p .707 .577 .707 r
F P
0 g
s
.5162 .73221 m .50517 .23853 L .54918 .24083 L p .707 .577 .707 r
F P
0 g
s
.65117 .58996 m .64991 .64628 L .67098 .65191 L p .707 .577 .707 r
F P
0 g
s
.81609 .5958 m .81484 .65213 L .83119 .64655 L p .707 .577 .707 r
F P
0 g
s
.83119 .64655 m .83244 .59023 L .81609 .5958 L p .707 .577 .707 r
F P
0 g
s
.7903 .69576 m .79293 .73042 L .8168 .71983 L p .707 .577 .707 r
F P
0 g
s
.8168 .71983 m .81417 .68518 L .7903 .69576 L p .707 .577 .707 r
F P
0 g
s
.44729 .65895 m .44992 .6936 L .4533 .6921 L p .707 .577 .707 r
F P
0 g
s
.47127 .73442 m .46664 .52717 L p .50517 .23853 L .707 .577 .707 r
F P
0 g
s
.4533 .6921 m .47379 .68302 L p .45539 .66631 L .707 .577 .707 r
F P
0 g
s
.45539 .66631 m .44729 .65895 L .4533 .6921 L .707 .577 .707 r
F
.46664 .52717 m .46024 .24074 L .48991 .23928 L p F P
0 g
s
.48991 .23928 m .50517 .23853 L p .46664 .52717 L .707 .577 .707 r
F P
0 g
s
.50517 .23853 m .5162 .73221 L .47127 .73442 L p .707 .577 .707 r
F P
0 g
s
.67332 .73471 m .67068 .70006 L .64954 .69109 L p .707 .577 .707 r
F P
0 g
s
.67068 .70006 m .67332 .73471 L .70081 .73997 L p .707 .577 .707 r
F P
0 g
s
.81417 .68518 m .8168 .71983 L .83297 .70699 L p .707 .577 .707 r
F P
0 g
s
.83297 .70699 m .83034 .67234 L .81417 .68518 L p .707 .577 .707 r
F P
0 g
s
.83244 .59023 m .83119 .64655 L .83825 .63998 L p .707 .577 .707 r
F P
0 g
s
.83825 .63998 m .8395 .58365 L .83244 .59023 L p .707 .577 .707 r
F P
0 g
s
.73934 .79546 m .73638 .78057 L .70538 .78055 L p .707 .577 .707 r
F P
0 g
s
.73638 .78057 m .73934 .79546 L .77069 .78922 L p .707 .577 .707 r
F P
0 g
s
.77069 .78922 m .76774 .77433 L .73638 .78057 L p .707 .577 .707 r
F P
0 g
s
.76774 .77433 m .77069 .78922 L .79932 .77735 L p .707 .577 .707 r
F P
0 g
s
.79932 .77735 m .79637 .76246 L .76774 .77433 L p .707 .577 .707 r
F P
0 g
s
.64954 .69109 m .65217 .72574 L .67332 .73471 L p .707 .577 .707 r
F P
0 g
s
.70833 .79544 m .70538 .78055 L .67775 .77427 L p .707 .577 .707 r
F P
0 g
s
.70538 .78055 m .70833 .79544 L .73934 .79546 L p .707 .577 .707 r
F P
0 g
s
.79637 .76246 m .79932 .77735 L .82243 .76099 L p .707 .577 .707 r
F P
0 g
s
.82243 .76099 m .81948 .7461 L .79637 .76246 L p .707 .577 .707 r
F P
0 g
s
.6373 .63968 m .63856 .58336 L .63564 .57643 L p .707 .577 .707 r
F P
0 g
s
.83034 .67234 m .83297 .70699 L .83985 .69316 L p .707 .577 .707 r
F P
0 g
s
.83985 .69316 m .83722 .6585 L .83034 .67234 L p .707 .577 .707 r
F P
0 g
s
.67775 .77427 m .68071 .78916 L .70833 .79544 L p .707 .577 .707 r
F P
0 g
s
.68071 .78916 m .67775 .77427 L .65622 .76236 L p .707 .577 .707 r
F P
0 g
s
.81948 .7461 m .82243 .76099 L .83775 .74175 L p .707 .577 .707 r
F P
0 g
s
.83775 .74175 m .8348 .72686 L .81948 .7461 L p .707 .577 .707 r
F P
0 g
s
.63564 .57643 m .63439 .63276 L .6373 .63968 L p .707 .577 .707 r
F P
0 g
s
.8395 .58365 m .83825 .63998 L .83533 .63306 L p .707 .577 .707 r
F P
0 g
s
.83533 .63306 m .83659 .57673 L .8395 .58365 L p .707 .577 .707 r
F P
0 g
s
.63943 .71394 m .6368 .67929 L .63372 .66581 L p .707 .577 .707 r
F P
0 g
s
.65622 .76236 m .65917 .77725 L .68071 .78916 L p .707 .577 .707 r
F P
0 g
s
.63439 .63276 m .63564 .57643 L .64271 .56986 L p .707 .577 .707 r
F P
0 g
s
.65917 .77725 m .65622 .76236 L .64287 .74598 L p .707 .577 .707 r
F P
0 g
s
.8348 .72686 m .83775 .74175 L .84378 .72152 L p .707 .577 .707 r
F P
0 g
s
.84378 .72152 m .84083 .70663 L .8348 .72686 L p .707 .577 .707 r
F P
0 g
s
.83722 .6585 m .83985 .69316 L .83677 .67968 L p .707 .577 .707 r
F P
0 g
s
.83677 .67968 m .83414 .64502 L .83722 .6585 L p .707 .577 .707 r
F P
0 g
s
.63372 .66581 m .63636 .70046 L .63943 .71394 L p .707 .577 .707 r
F P
0 g
s
.64271 .56986 m .64145 .62619 L .63439 .63276 L p .707 .577 .707 r
F P
0 g
s
.64287 .74598 m .64583 .76087 L .65917 .77725 L p .707 .577 .707 r
F P
0 g
s
.83659 .57673 m .83533 .63306 L .82273 .62646 L p .707 .577 .707 r
F P
0 g
s
.82273 .62646 m .82398 .57013 L .83659 .57673 L p .707 .577 .707 r
F P
0 g
s
.63636 .70046 m .63372 .66581 L .6406 .65197 L p .707 .577 .707 r
F P
0 g
s
.64583 .76087 m .64287 .74598 L .63903 .72673 L p .717 .584 .705 r
F P
0 g
s
.84083 .70663 m .84378 .72152 L .83994 .70227 L p .717 .584 .705 r
F P
0 g
s
.83994 .70227 m .83699 .68738 L .84083 .70663 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3866 .62139 m .38785 .56506 L .35668 .56288 L p .707 .577 .707 r
F P
0 g
s
.38785 .56506 m .3866 .62139 L .41842 .62144 L p .707 .577 .707 r
F P
0 g
s
.41842 .62144 m .41968 .56511 L .38785 .56506 L p .707 .577 .707 r
F P
0 g
s
.44779 .61934 m .44905 .56302 L .41968 .56511 L p .707 .577 .707 r
F P
0 g
s
.64145 .62619 m .64271 .56986 L .65906 .56429 L p .707 .577 .707 r
F P
0 g
s
.83414 .64502 m .83677 .67968 L .82404 .66788 L p .707 .577 .707 r
F P
0 g
s
.82404 .66788 m .8214 .63322 L .83414 .64502 L p .707 .577 .707 r
F P
0 g
s
.35543 .61921 m .35668 .56288 L .32922 .55877 L p .707 .577 .707 r
F P
0 g
s
.35668 .56288 m .35543 .61921 L .3866 .62139 L p .707 .577 .707 r
F P
0 g
s
.6406 .65197 m .64324 .68663 L .63636 .70046 L p .707 .577 .707 r
F P
0 g
s
.63903 .72673 m .64198 .74162 L .64583 .76087 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44905 .56302 m .44779 .61934 L .47183 .61531 L p .707 .577 .707 r
F P
0 g
s
.47183 .61531 m .47308 .55898 L .44905 .56302 L p .707 .577 .707 r
F P
0 g
s
.65906 .56429 m .6578 .62062 L .64145 .62619 L p .707 .577 .707 r
F P
0 g
s
.32922 .55877 m .32797 .6151 L .35543 .61921 L p .707 .577 .707 r
F P
0 g
s
.82398 .57013 m .82273 .62646 L .80166 .62083 L p .707 .577 .707 r
F P
0 g
s
.80166 .62083 m .80292 .5645 L .82398 .57013 L p .707 .577 .707 r
F P
0 g
s
.64324 .68663 m .6406 .65197 L .65677 .63914 L p .707 .577 .707 r
F P
0 g
s
.32797 .6151 m .32922 .55877 L .30816 .55314 L p .707 .577 .707 r
F P
0 g
s
.64198 .74162 m .63903 .72673 L .64506 .7065 L p .707 .577 .707 r
F P
0 g
s
.83699 .68738 m .83994 .70227 L .8266 .68588 L p .707 .577 .707 r
F P
0 g
s
.8266 .68588 m .82364 .67099 L .83699 .68738 L p .707 .577 .707 r
F P
0 g
s
.38894 .70419 m .3863 .66954 L .35516 .6685 L p .707 .577 .707 r
F P
0 g
s
.42068 .7009 m .41805 .66624 L .3863 .66954 L p .707 .577 .707 r
F P
0 g
s
.6578 .62062 m .65906 .56429 L .68309 .56026 L p .707 .577 .707 r
F P
0 g
s
.8214 .63322 m .82404 .66788 L .80289 .65891 L p .707 .577 .707 r
F P
0 g
s
.80289 .65891 m .80026 .62425 L .8214 .63322 L p .707 .577 .707 r
F P
0 g
s
.3578 .70316 m .35516 .6685 L .32767 .66324 L p .707 .577 .707 r
F P
0 g
s
.35516 .6685 m .3578 .70316 L .38894 .70419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55314 m .3069 .60947 L .32797 .6151 L p .707 .577 .707 r
F P
0 g
s
.64506 .7065 m .64802 .72139 L .64198 .74162 L p .707 .577 .707 r
F P
0 g
s
.47308 .55898 m .47183 .61531 L .48818 .60974 L p .707 .577 .707 r
F P
0 g
s
.48818 .60974 m .48943 .55341 L .47308 .55898 L p .707 .577 .707 r
F P
0 g
s
.47379 .68302 m .47116 .64836 L .44729 .65895 L p .707 .577 .707 r
F P
0 g
s
.65677 .63914 m .65941 .67379 L .64324 .68663 L p .707 .577 .707 r
F P
0 g
s
.68309 .56026 m .68184 .61658 L .6578 .62062 L p .707 .577 .707 r
F P
0 g
s
.80292 .5645 m .80166 .62083 L .7742 .61672 L p .707 .577 .707 r
F P
0 g
s
.7742 .61672 m .77546 .56039 L .80292 .5645 L p .707 .577 .707 r
F P
0 g
s
.65941 .67379 m .65677 .63914 L .68064 .62855 L p .707 .577 .707 r
F P
0 g
s
.3069 .60947 m .30816 .55314 L .29555 .54654 L p .707 .577 .707 r
F P
0 g
s
.33031 .6979 m .32767 .66324 L .30653 .65427 L p .707 .577 .707 r
F P
0 g
s
.32767 .66324 m .33031 .6979 L .3578 .70316 L p .707 .577 .707 r
F P
0 g
s
.64802 .72139 m .64506 .7065 L .66038 .68726 L p .707 .577 .707 r
F P
0 g
s
.82364 .67099 m .8266 .68588 L .80506 .67397 L p .707 .577 .707 r
F P
0 g
s
.80506 .67397 m .80211 .65908 L .82364 .67099 L p .707 .577 .707 r
F P
0 g
s
.68184 .61658 m .68309 .56026 L .71246 .55816 L p .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .80211 .65908 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77744 .6677 m .77587 .65979 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77587 .65979 m .77448 .65281 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .77744 .6677 L .74643 .66768 L p .707 .577 .707 r
F P
0 g
s
.74643 .66768 m .74348 .65279 L .77448 .65281 L p .707 .577 .707 r
F P
0 g
s
.77277 .619 m .7754 .65365 L .77027 .65348 L p .707 .577 .707 r
F P
0 g
s
.77027 .65348 m .74426 .65262 L p .75659 .63807 L .707 .577 .707 r
F P
0 g
s
.75659 .63807 m .77277 .619 L .77027 .65348 L .707 .577 .707 r
F
.80026 .62425 m .80289 .65891 L .7754 .65365 L p F P
0 g
s
.7754 .65365 m .77277 .619 L .80026 .62425 L p .707 .577 .707 r
F P
0 g
s
.47116 .64836 m .47379 .68302 L .48996 .67018 L p .707 .577 .707 r
F P
0 g
s
.48996 .67018 m .48733 .63552 L .47116 .64836 L p .707 .577 .707 r
F P
0 g
s
.29555 .54654 m .29429 .60287 L .3069 .60947 L p .707 .577 .707 r
F P
0 g
s
.66038 .68726 m .66334 .70215 L .64802 .72139 L p .707 .577 .707 r
F P
0 g
s
.77546 .56039 m .7742 .61672 L .74303 .61454 L p .707 .577 .707 r
F P
0 g
s
.74303 .61454 m .74429 .55821 L .77546 .56039 L p .707 .577 .707 r
F P
0 g
s
.68064 .62855 m .68328 .6632 L .65941 .67379 L p .707 .577 .707 r
F P
0 g
s
.48943 .55341 m .48818 .60974 L .49524 .60317 L p .707 .577 .707 r
F P
0 g
s
.49524 .60317 m .49649 .54684 L .48943 .55341 L p .707 .577 .707 r
F P
0 g
s
.71246 .55816 m .71121 .61449 L .68184 .61658 L p .707 .577 .707 r
F P
0 g
s
.71121 .61449 m .71246 .55816 L .74429 .55821 L p .707 .577 .707 r
F P
0 g
s
.39633 .75864 m .39337 .74375 L .36237 .74373 L p .707 .577 .707 r
F P
0 g
s
.39337 .74375 m .39633 .75864 L .42768 .75241 L p .707 .577 .707 r
F P
0 g
s
.42768 .75241 m .42473 .73752 L .39337 .74375 L p .707 .577 .707 r
F P
0 g
s
.42473 .73752 m .42768 .75241 L .45631 .74053 L p .707 .577 .707 r
F P
0 g
s
.45631 .74053 m .45336 .72564 L .42473 .73752 L p .707 .577 .707 r
F P
0 g
s
.30653 .65427 m .30916 .68893 L .33031 .6979 L p .707 .577 .707 r
F P
0 g
s
.68328 .6632 m .68064 .62855 L .70988 .62125 L p .707 .577 .707 r
F P
0 g
s
.74429 .55821 m .74303 .61454 L .71121 .61449 L p .707 .577 .707 r
F P
0 g
s
.66334 .70215 m .66038 .68726 L .68349 .6709 L p .707 .577 .707 r
F P
0 g
s
.80211 .65908 m .80506 .67397 L .77744 .6677 L p .707 .577 .707 r
F P
0 g
s
.74426 .65262 m .74163 .61796 L .77277 .619 L p .707 .577 .707 r
F P
0 g
s
.30916 .68893 m .30653 .65427 L .29379 .64247 L p .707 .577 .707 r
F P
0 g
s
.36532 .75862 m .36237 .74373 L .33474 .73746 L p .707 .577 .707 r
F P
0 g
s
.36237 .74373 m .36532 .75862 L .39633 .75864 L p .707 .577 .707 r
F P
0 g
s
.45336 .72564 m .45631 .74053 L .47942 .72417 L p .707 .577 .707 r
F P
0 g
s
.47942 .72417 m .47647 .70928 L .45336 .72564 L p .707 .577 .707 r
F P
0 g
s
.29429 .60287 m .29555 .54654 L .29263 .53962 L p .707 .577 .707 r
F P
0 g
s
.71252 .65591 m .70988 .62125 L .74163 .61796 L p .707 .577 .707 r
F P
0 g
s
.70988 .62125 m .71252 .65591 L .68328 .6632 L p .707 .577 .707 r
F P
0 g
s
.74163 .61796 m .74426 .65262 L .71252 .65591 L p .707 .577 .707 r
F P
0 g
s
.68349 .6709 m .68644 .68579 L .66334 .70215 L p .707 .577 .707 r
F P
0 g
s
.48733 .63552 m .48996 .67018 L .49684 .65634 L p .707 .577 .707 r
F P
0 g
s
.49684 .65634 m .49421 .62169 L .48733 .63552 L p .707 .577 .707 r
F P
0 g
s
.68644 .68579 m .68349 .6709 L .71212 .65902 L p .707 .577 .707 r
F P
0 g
s
.33474 .73746 m .3377 .75235 L .36532 .75862 L p .707 .577 .707 r
F P
0 g
s
.29379 .64247 m .29642 .67713 L .30916 .68893 L p .707 .577 .707 r
F P
0 g
s
.3377 .75235 m .33474 .73746 L .31321 .72555 L p .707 .577 .707 r
F P
0 g
s
.47647 .70928 m .47942 .72417 L .49474 .70493 L p .707 .577 .707 r
F P
0 g
s
.49474 .70493 m .49179 .69005 L .47647 .70928 L p .707 .577 .707 r
F P
0 g
s
.29263 .53962 m .29138 .59594 L .29429 .60287 L p .707 .577 .707 r
F P
0 g
s
.71508 .67391 m .71212 .65902 L .74348 .65279 L p .707 .577 .707 r
F P
0 g
s
.71212 .65902 m .71508 .67391 L .68644 .68579 L p .707 .577 .707 r
F P
0 g
s
.74348 .65279 m .74643 .66768 L .71508 .67391 L p .707 .577 .707 r
F P
0 g
s
.49649 .54684 m .49524 .60317 L .49232 .59624 L p .707 .577 .707 r
F P
0 g
s
.49232 .59624 m .49358 .53991 L .49649 .54684 L p .707 .577 .707 r
F P
0 g
s
.29642 .67713 m .29379 .64247 L .29071 .62899 L p .707 .577 .707 r
F P
0 g
s
.31321 .72555 m .31616 .74044 L .3377 .75235 L p .707 .577 .707 r
F P
0 g
s
.29138 .59594 m .29263 .53962 L .2997 .53305 L p .707 .577 .707 r
F P
0 g
s
.31616 .74044 m .31321 .72555 L .29986 .70917 L p .707 .577 .707 r
F P
0 g
s
.49179 .69005 m .49474 .70493 L .50077 .6847 L p .707 .577 .707 r
F P
0 g
s
.50077 .6847 m .49782 .66981 L .49179 .69005 L p .707 .577 .707 r
F P
0 g
s
.49421 .62169 m .49684 .65634 L .49376 .64286 L p .707 .577 .707 r
F P
0 g
s
.49376 .64286 m .49113 .60821 L .49421 .62169 L p .707 .577 .707 r
F P
0 g
s
.29071 .62899 m .29334 .66365 L .29642 .67713 L p .707 .577 .707 r
F P
0 g
s
.2997 .53305 m .29844 .58937 L .29138 .59594 L p .707 .577 .707 r
F P
0 g
s
.29986 .70917 m .30282 .72406 L .31616 .74044 L p .707 .577 .707 r
F P
0 g
s
.49358 .53991 m .49232 .59624 L .47972 .58964 L p .707 .577 .707 r
F P
0 g
s
.47972 .58964 m .48097 .53331 L .49358 .53991 L p .707 .577 .707 r
F P
0 g
s
.29334 .66365 m .29071 .62899 L .29759 .61516 L p .707 .577 .707 r
F P
0 g
s
.30282 .72406 m .29986 .70917 L .29602 .68992 L p .717 .584 .705 r
F P
0 g
s
.49782 .66981 m .50077 .6847 L .49693 .66545 L p .717 .584 .705 r
F P
0 g
s
.49693 .66545 m .49398 .65056 L .49782 .66981 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29844 .58937 m .2997 .53305 L .31605 .52747 L p .707 .577 .707 r
F P
0 g
s
.49113 .60821 m .49376 .64286 L .48103 .63106 L p .707 .577 .707 r
F P
0 g
s
.48103 .63106 m .47839 .59641 L .49113 .60821 L p .707 .577 .707 r
F P
0 g
s
.29759 .61516 m .30023 .64981 L .29334 .66365 L p .707 .577 .707 r
F P
0 g
s
.29602 .68992 m .29897 .70481 L .30282 .72406 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31605 .52747 m .31479 .5838 L .29844 .58937 L p .707 .577 .707 r
F P
0 g
s
.48097 .53331 m .47972 .58964 L .45865 .58401 L p .707 .577 .707 r
F P
0 g
s
.45865 .58401 m .45991 .52769 L .48097 .53331 L p .707 .577 .707 r
F P
0 g
s
.30023 .64981 m .29759 .61516 L .31376 .60232 L p .707 .577 .707 r
F P
0 g
s
.29897 .70481 m .29602 .68992 L .30205 .66968 L p .707 .577 .707 r
F P
0 g
s
.49398 .65056 m .49693 .66545 L .48359 .64907 L p .707 .577 .707 r
F P
0 g
s
.48359 .64907 m .48063 .63418 L .49398 .65056 L p .707 .577 .707 r
F P
0 g
s
.31479 .5838 m .31605 .52747 L .34008 .52344 L p .707 .577 .707 r
F P
0 g
s
.47839 .59641 m .48103 .63106 L .45988 .62209 L p .707 .577 .707 r
F P
0 g
s
.45988 .62209 m .45725 .58744 L .47839 .59641 L p .707 .577 .707 r
F P
0 g
s
.30205 .66968 m .30501 .68457 L .29897 .70481 L p .707 .577 .707 r
F P
0 g
s
.31376 .60232 m .3164 .63697 L .30023 .64981 L p .707 .577 .707 r
F P
0 g
s
.34008 .52344 m .33883 .57977 L .31479 .5838 L p .707 .577 .707 r
F P
0 g
s
.45991 .52769 m .45865 .58401 L .43119 .57991 L p .707 .577 .707 r
F P
0 g
s
.43119 .57991 m .43244 .52358 L .45991 .52769 L p .707 .577 .707 r
F P
0 g
s
.3164 .63697 m .31376 .60232 L .33763 .59173 L p .707 .577 .707 r
F P
0 g
s
.30501 .68457 m .30205 .66968 L .31737 .65044 L p .707 .577 .707 r
F P
0 g
s
.48063 .63418 m .48359 .64907 L .46205 .63716 L p .707 .577 .707 r
F P
0 g
s
.46205 .63716 m .4591 .62227 L .48063 .63418 L p .707 .577 .707 r
F P
0 g
s
.33883 .57977 m .34008 .52344 L .36945 .52135 L p .707 .577 .707 r
F P
0 g
s
.43147 .616 m .4591 .62227 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43443 .63089 m .43286 .62297 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43286 .62297 m .43147 .616 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43147 .616 m .43443 .63089 L .40342 .63086 L p .707 .577 .707 r
F P
0 g
s
.40342 .63086 m .40047 .61598 L .43147 .616 L p .707 .577 .707 r
F P
0 g
s
.42976 .58218 m .43239 .61683 L .42726 .61666 L p .707 .577 .707 r
F P
0 g
s
.42726 .61666 m .40125 .6158 L p .41358 .60126 L .707 .577 .707 r
F P
0 g
s
.41358 .60126 m .42976 .58218 L .42726 .61666 L .707 .577 .707 r
F
.45725 .58744 m .45988 .62209 L .43239 .61683 L p F P
0 g
s
.43239 .61683 m .42976 .58218 L .45725 .58744 L p .707 .577 .707 r
F P
0 g
s
.31737 .65044 m .32033 .66533 L .30501 .68457 L p .707 .577 .707 r
F P
0 g
s
.43244 .52358 m .43119 .57991 L .40002 .57772 L p .707 .577 .707 r
F P
0 g
s
.40002 .57772 m .40128 .52139 L .43244 .52358 L p .707 .577 .707 r
F P
0 g
s
.33763 .59173 m .34027 .62639 L .3164 .63697 L p .707 .577 .707 r
F P
0 g
s
.36945 .52135 m .36819 .57767 L .33883 .57977 L p .707 .577 .707 r
F P
0 g
s
.36819 .57767 m .36945 .52135 L .40128 .52139 L p .707 .577 .707 r
F P
0 g
s
.34027 .62639 m .33763 .59173 L .36687 .58444 L p .707 .577 .707 r
F P
0 g
s
.40128 .52139 m .40002 .57772 L .36819 .57767 L p .707 .577 .707 r
F P
0 g
s
.32033 .66533 m .31737 .65044 L .34048 .63409 L p .707 .577 .707 r
F P
0 g
s
.4591 .62227 m .46205 .63716 L .43443 .63089 L p .707 .577 .707 r
F P
0 g
s
.40125 .6158 m .39862 .58115 L .42976 .58218 L p .707 .577 .707 r
F P
0 g
s
.36951 .61909 m .36687 .58444 L .39862 .58115 L p .707 .577 .707 r
F P
0 g
s
.36687 .58444 m .36951 .61909 L .34027 .62639 L p .707 .577 .707 r
F P
0 g
s
.39862 .58115 m .40125 .6158 L .36951 .61909 L p .707 .577 .707 r
F P
0 g
s
.34048 .63409 m .34343 .64898 L .32033 .66533 L p .707 .577 .707 r
F P
0 g
s
.34343 .64898 m .34048 .63409 L .36911 .62221 L p .707 .577 .707 r
F P
0 g
s
.37207 .6371 m .36911 .62221 L .40047 .61598 L p .707 .577 .707 r
F P
0 g
s
.36911 .62221 m .37207 .6371 L .34343 .64898 L p .707 .577 .707 r
F P
0 g
s
.40047 .61598 m .40342 .63086 L .37207 .6371 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002>Ool80027Ool0081oo`h0
0003FUH005YF00EJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001d
Ool007=oo`<000aJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001b
Ool006moo`@000mJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3
001_Ool006aoo`<001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP8006eoo`00JWoo0P0000=JEP00FUH04eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF0P00K7oo001XOol20003FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000JWoo001VOol20005FUH0
0`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000JGoo001UOol20006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJ
EP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001T
Ool00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo
001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001TOol00`00FUH0
0006FUH00`00FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF01=JEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF
00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00@005YFFUH0
00EJEP8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001WOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP8000UJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YF
FUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF
00000eYF00<005YFFUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF00000eYF00<005YF
FUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0009JEP03001JEUYF008000UJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH3001UOol005mooad000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Fgoo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001HOol30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000?OolA0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool80003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH8000mOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0031oo`00DWoo00<005YF000015YF00<005YF
FUH00eYF7@001UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001B
Ool00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUHC0002FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00<005YF00000UYF10000UYF00<0
05YFFUH01EYF200015YF00<005YFFUH01UYF00<005YF000020000eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP0000<000EJEP03001JEUYF009JEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@0009JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030002FUH40004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF0080
02ioo`00DWoo0P000eYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool0059oo`80
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF0000000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001C
Ool01P00FUIJEUYF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001JEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000hOolN000015YF000000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
=7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUHA0004FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP04001JEUYFFUH90007FUH900000eYF000000060003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@001EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP05FUH00`00FUH000050004FUH00`00FUIJ
EP02FUH800000eYF000000030004FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP060008FUH00`00FUIJEP06FUH20006FUH30003FUH00`00FUIJEP020004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJ
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH500001UYF0000
0000FUH000=JEP8002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF100000=JEP0000000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00UYF
00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF
00<000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
0004FUH000000003FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH20002FUH30005FUH0
0`00FUIJEP04FUH=0006FUH00`00FUIJEP030003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH200000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH200000eYF
0000000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH01000FUH000000eYF0P001eYF00<005YFFUH01`001UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH3
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05
001JEUYFFUIoo`03FUH01000FUIJEP000eYF0`000UYF0`001eYF10000UYF1@001UYF00<005YFFUH0
1EYF0`0015YF1@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP00009JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF00000000;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YF
FUH005YF0002FUH00`00FUIJEP03FUH30006FUH30007FUH00`00FUIJEP08FUH20002FUH01000FUH0
05YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00H005YF000005YF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP04001JEUYFOol4FUH00`00FUIJEP030003FUH20004FUH00`00FUH00003
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000015YF000005YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH01EYF
00<005YFFUH01eYF00<005YFFUH025YF0P000UYF0P0000AJEP00000000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP800004FUH005YFFUH20005FUH20002FUH01@00FUH005YF00001UYF00<005YF
FUH01eYF00<005YFFUH01eYF0`0015YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP03
FUH00`00FUH00002FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF00IJEP03001JEP00
00<0009JEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUH0
00000UYF00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01eYF0P000UYF100015YF00<005YF
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP03001JEUYF00P000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJ
EP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEQd0009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP0300000eYF001JEP05FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00=JEP@00006FUH00000001JEP002EYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YF00000`0000EJEP00FUIJEP0002moo`00:goo00<005YF000015YF00<005YF0000
0`001UYF200015YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00@005YF001JEP@00006FUH00000
001JEP001UYF00<005YFFUH01`001UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00H005YFFUH005YF0004FUH01000FUIJ
EUYF0P000UYF10000eYF00<005YFFUH01EYF30001EYF00@005YFFUIJEP@0009JEP03001oogoo02eo
o`00:goo00<005YF00000UYF10000UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0015YF00@005YFFUH000EJEPl000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00004FUH01000FUH000000eYF0P001eYF00<005YFFUH01`002Goo10000UYF00<005YFFUH0
0UYF0`0000=JEP00Ool0;Woo000[Ool00`00FUH000030005FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH30002FUH30008FUH3
0002Ool5000=Ool30005FUH200000eYF001oo`0^Ool002]oo`8000=JEP03001JEUYF00=JEP<000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH30003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YF
00000UYF00@005YFFUH000IJEP8000Eoo`D0011oo`8000=JEP@002moo`00:goo0P000eYF00@005YF
FUIJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0000000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEP00FUH005YF0P000UYF00<005YF000015YF00@005YFFUIJEP8000Qoo`<001=oo`05001JEUYF
001JEP03000^Ool002]oo`8000=JEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH005YF0`000eYF0P001EYF00<005YF00000P007Woo1@0000AJEP00
000002ioo`00;7oo00@005YFFUIJEP<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJ
EP03001JEUYF00@000EJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH005YF0`000UYF00<005YFFUH01EYF0P0000=JEP00000077oo0P0000EJEP00FUIJ
EP00009JEP8002ioo`00;Goo100000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`000UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF0`000eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP04001JEP000005FUH20003FUH2000JOol20003FUH01P00FUIJ
EUYF001JEP8002ioo`00;Woo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP<000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000002FUH200000eYF001JEP02FUH200000eYF001JEP02FUH2000GOol3
0005FUH00`00FUIJEP02FUH3000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPl000EJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00@000MJEP09001JEUYFFUH005YF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000002FUH20002FUH30003FUH01000FUIJEUYF0P004goo100000=JEP00FUH0
1EYF00<005YFFUH00UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008
FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH90004FUH01000FUIJEUYF2@002UYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEP000002FUH01000FUIJEUYF1`000eYF0P0037oo1`001EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP0Q0004FUH00`00FUIJEP020000
0gooFUIJEP090008FUH00`00FUIJEP08FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF000005YF0003FUH01000FUIJEP000eYF4P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00=JEP@000Eoo`D000AJEP03001JEUYF00IJEP800004FUH000000004Ool30000
0eYF001JEP02FUH01@00OomJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF0000
05YF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP0000AJEP04001JEUYFFUH20007
Ool30008FUH00`00FUIJEP06FUH01000FUH000000UYF0`0017oo0P000eYF00D007ooFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP<0009JEP03001JEUYF00EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00<0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP000Woo00<007ooOol0
;7oo000[Ool01000FUIJEP000eYF00@005YF000000Moo`80009JEP03001JEUYF00MJEP03001JEUYF
00IJEP800003FUH005YF009JEP<000Aoo`05001JEUYF001oo`02FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo00<005YF0000
;Goo000[Ool01000FUIJEP000eYF0P001goo0P001EYF00<005YFFUH015YF3`000eYF00<005YFFUH0
0P000Woo100000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo
00<005YF0000;Goo000[Ool01000FUIJEP000UYF00<007ooOol01Goo0P001eYF00<005YFFUH01P00
2goo00@005YF0000009JEP04001JEUYFFUH200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH01EYF00@005YFFUIJEP8000Ioo`03001JEP0002eoo`00:goo00<005YFFUH00`00
1goo0P001eYF10000Woo1@002goo00<005YF00000`0015YF0`0000=JEP0000000UYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00UYF0P001EYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP04001JEP000008Ool00`00FUH0000]Ool002aoo`03001JEP0000Qoo`03
001JEP0000EJEP8000Ioo`D000]oo`03001JEP0000800003Ool00000009JEP04001JEP00FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF0`002Goo0P0000=JEP00Ool0
;7oo000/Ool200000eYF001oo`04Ool20003FUH00`00FUH000020008Ool5000<Ool20002FUH50000
0eYF00000002FUH01000FUIJEP001UYF00<005YFFUH01eYF0`000eYF00@005YFFUIJEQh000QJEP03
001JEUYF00EJEP05001JEUYF001JEP020004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000;Ool01000FUH00000;Woo000/Ool20002FUH20002Ool00`00FUIJEP03FUH2000<
Ool3000=Ool20004FUH5000015YF001JEP000UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF
0`0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000ioo`05
001JEUYFFUH0000^Ool002aoo`06001JEUYFFUH005YF0P001EYF00<007ooOol06Woo1@0015YF00<0
05YF0000100000AooeYFFUH000IJEP03001JEP0000<0009JEP03001JEUYF00EJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00@000IJEP06001JEUYFFUH005YF1P001EYF00<005YF
00003`005Goo00D005YFFUIJEP0002ioo`00;7oo0P000UYF00@005YF000000AJEP03001oogoo01Mo
o`@0009JEP03001JEUYF0080009JEP03001JEUYF00=JEPd000IJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP06001JEUYFFUH005YF0`000goo
0P000eYF00@005YFFUH0029oo`05001JEUYFFUH0000_Ool002aoo`80009JEP800004FUH005YFFUH6
000?Ool70006FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH300000eYF001JEP02FUH00`00FUH00002FUH30002Ool200001EYF001JEUYF00008Goo00D0
05YFFUIJEP00031oo`00;7oo0P000UYF00@005YFFUIJEP<000EJEPl000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000003FUH30003FUH01000FUH0
00000Woo0P000UYF00<007ooOol07Goo0`000UYF00<007ooOol0;goo000]Ool00`00FUH00004FUH0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP040009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000UYF0`000eYF00@005YFFUIJEP80
009oo`03001JEP0001ioo`04001JEUYF0002FUH00`00Oomoo`0_Ool002eoo`8000AJEP04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0
00000goo3@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00P000UYF00<005YFFUH00UYF1@0077oo
0P0015YF0P00<Woo000^Ool01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo00<005YFFUH00`0000=JEP00FUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P000UYF10001EYF1@006Woo00<005YFFUH015YF00<007ooOol0<Goo000^
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P001Goo0P000UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00005
FUH00000001oo`020003FUH5000HOol30005FUH00`00Oomoo`0bOol002eoo`04001JEP000005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
1goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD0009JEP800006FUH005YFFUH0
05YF0`005Woo0P000UYF00<005YFFUH00UYF00<007ooOol0<goo000]Ool00`00FUH000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUH000002Goo00@005YF
FUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP000UYF1P0000AJEP00FUH0
01Aoo`8000EJEP04001JEP00000fOol002eoo`03001JEP00009oo`<00003FUH005YF00IJEP03001J
EUYF00IJEPD000AJEP03001JEUYF00AJEP<000Yoo`03001JEUYF008000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<000AJEP@0009JEP8000ioo`H000MJEP8003Qoo`00;Goo00<005YF
00001Goo0`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00<005YF00000P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0004FUH01000FUIJEUYF4P0015YF00<0
05YFFUH01EYF0P00>Goo000]Ool20009Ool40002FUH00`00FUIJEP06FUH<000@Ool2000015YF0000
000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUIJEP80009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003]oo`00;Goo0P003Goo40005Woo
00@005YF001JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP800003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003eoo`00;Woo00<007oo
Ool0<Goo00@005YFFUH0009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0006FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40010Ool002ioo`03001oogoo031o
o`05001JEUYFFUH00002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001eYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01000A7oo000^Ool00`00Oomo
o`0_Ool01@00FUIJEUYF000017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH015YF0`000goo3P00B7oo000^Ool2000^Ool30002FUH00`00Oomoo`05Ool30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP020006FUH00`00FUIJEP03FUH20005Ool00`00Oomoo`1COol002ioo`<002aoo`04001JEUYF
0002FUH00`00Oomoo`07Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH40007FUH01000FUIJEUYF0P001Woo00<005YF0000E7oo000_
Ool2000[Ool00`00FUIJEP02FUH2000<Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH01000FUH00000
27oo00<005YF0000E7oo000_Ool00`00FUH0000XOol20005FUH00`00Oomoo`0=Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050005FUH00`00
FUIJEP04FUH3000:Ool00`00FUH0001DOol0031oo`03001JEP0002Eoo`8000EJEP8001=oo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD00003FUH0000000<000AJEP03001J
EUYF00@000eoo`03001JEP0005Aoo`00<7oo00<005YF00000P008Goo0P0000=JEP00FUH00eYF00<0
07ooOol05goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P001UYF300047oo
0P0000=JEP00Ool0Dgoo000aOol20002FUH2000LOol30003FUH01@00FUIJEUYF000087oo2@001UYF
00<005YFFUH015YF6P005Woo00@005YF000005Eoo`00<Goo0P0015YF0`005Goo10001eYF0`00:Woo
3@005Woo0`005Woo00D005YFFUIJEP0005Eoo`00<Woo0P0015YF00<005YF00000`003Goo10000UYF
00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo00D005YFFUIJEP0005Eoo`00=7oo0P000UYF00<0
05YFFUH00eYF3@001UYF00<005YFFUH00eYF0P00=Woo00<007ooOol0<7oo00D005YFFUIJEP0005Io
o`00=Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00>7oo
00<007ooOol0;goo00D005YFFUIJEP0005Moo`00>7oo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF1000>goo0P00;Woo0`000UYF00<007ooOol0EWoo000kOol400000eYF001JEP07FUH00`00FUIJ
EP04000oOol00`00FUH0000/Ool01000FUIJEP000UYF00<007ooOol0EWoo000oOol=0014Ool00`00
FUH0000YOol20004FUH2001IOol0091oo`04001JEUYF000WOol00`00FUIJEP04FUH00`00Oomoo`1H
Ool0095oo`03001JEP00008002=oo`<000EJEP03001oogoo05Uoo`00TWoo0P000UYF00<007ooOol0
7Woo0P000UYF00<005YFFUH00UYF00<007ooOol0FWoo002BOol00`00FUH00002FUH2000LOol20005
FUH01000FUH00000GGoo002COol20004FUH4000BOol60007FUH2001OOol009Aoo`03001JEUYF009J
EP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH2001POol009Eoo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Ugoo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P00I7oo002IOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH4001WOol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@006]oo`00
X7oo3P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5924 .74269 m .59366 .68636 L .56249 .68418 L p .707 .577 .707 r
F P
0 g
s
.59366 .68636 m .5924 .74269 L .62423 .74274 L p .707 .577 .707 r
F P
0 g
s
.62423 .74274 m .62548 .68641 L .59366 .68636 L p .707 .577 .707 r
F P
0 g
s
.62548 .68641 m .62423 .74274 L .6536 .74064 L p .707 .577 .707 r
F P
0 g
s
.6536 .74064 m .65485 .68431 L .62548 .68641 L p .707 .577 .707 r
F P
0 g
s
.56123 .74051 m .56249 .68418 L .53503 .68007 L p .707 .577 .707 r
F P
0 g
s
.56249 .68418 m .56123 .74051 L .5924 .74269 L p .707 .577 .707 r
F P
0 g
s
.65485 .68431 m .6536 .74064 L .67763 .73661 L p .707 .577 .707 r
F P
0 g
s
.67763 .73661 m .67889 .68028 L .65485 .68431 L p .707 .577 .707 r
F P
0 g
s
.53503 .68007 m .53377 .7364 L .56123 .74051 L p .707 .577 .707 r
F P
0 g
s
.53377 .7364 m .53503 .68007 L .51396 .67444 L p .707 .577 .707 r
F P
0 g
s
.59474 .8224 m .59211 .78775 L .56097 .78671 L p .707 .577 .707 r
F P
0 g
s
.59211 .78775 m .59474 .8224 L .62649 .81911 L p .707 .577 .707 r
F P
0 g
s
.62649 .81911 m .62385 .78446 L .59211 .78775 L p .707 .577 .707 r
F P
0 g
s
.62385 .78446 m .62649 .81911 L .65572 .81181 L p .707 .577 .707 r
F P
0 g
s
.65572 .81181 m .65309 .77716 L .62385 .78446 L p .707 .577 .707 r
F P
0 g
s
.5636 .82137 m .56097 .78671 L .53348 .78146 L p .707 .577 .707 r
F P
0 g
s
.56097 .78671 m .5636 .82137 L .59474 .8224 L p .707 .577 .707 r
F P
0 g
s
.51396 .67444 m .51271 .73077 L .53377 .7364 L p .707 .577 .707 r
F P
0 g
s
.67889 .68028 m .67763 .73661 L .69398 .73104 L p .707 .577 .707 r
F P
0 g
s
.69398 .73104 m .69523 .67471 L .67889 .68028 L p .707 .577 .707 r
F P
0 g
s
.65309 .77716 m .65572 .81181 L .6796 .80123 L p .707 .577 .707 r
F P
0 g
s
.6796 .80123 m .67696 .76658 L .65309 .77716 L p .707 .577 .707 r
F P
0 g
s
.51271 .73077 m .51396 .67444 L .50136 .66784 L p .707 .577 .707 r
F P
0 g
s
.53611 .81611 m .53348 .78146 L .51233 .77249 L p .707 .577 .707 r
F P
0 g
s
.53348 .78146 m .53611 .81611 L .5636 .82137 L p .707 .577 .707 r
F P
0 g
s
.67696 .76658 m .6796 .80123 L .69576 .78839 L p .707 .577 .707 r
F P
0 g
s
.69576 .78839 m .69313 .75374 L .67696 .76658 L p .707 .577 .707 r
F P
0 g
s
.50136 .66784 m .5001 .72417 L .51271 .73077 L p .707 .577 .707 r
F P
0 g
s
.69523 .67471 m .69398 .73104 L .70104 .72447 L p .707 .577 .707 r
F P
0 g
s
.70104 .72447 m .7023 .66814 L .69523 .67471 L p .707 .577 .707 r
F P
0 g
s
.51233 .77249 m .51497 .80714 L .53611 .81611 L p .707 .577 .707 r
F P
0 g
s
.60213 .88357 m .59918 .86868 L .56817 .86866 L p .707 .577 .707 r
F P
0 g
s
.59918 .86868 m .60213 .88357 L .63349 .87734 L p .707 .577 .707 r
F P
0 g
s
.63349 .87734 m .63053 .86245 L .59918 .86868 L p .707 .577 .707 r
F P
0 g
s
.63053 .86245 m .63349 .87734 L .66212 .86546 L p .707 .577 .707 r
F P
0 g
s
.66212 .86546 m .65916 .85057 L .63053 .86245 L p .707 .577 .707 r
F P
0 g
s
.51497 .80714 m .51233 .77249 L .4996 .76069 L p .707 .577 .707 r
F P
0 g
s
.57113 .88355 m .56817 .86866 L .54055 .86239 L p .707 .577 .707 r
F P
0 g
s
.56817 .86866 m .57113 .88355 L .60213 .88357 L p .707 .577 .707 r
F P
0 g
s
.65916 .85057 m .66212 .86546 L .68522 .8491 L p .707 .577 .707 r
F P
0 g
s
.68522 .8491 m .68227 .83422 L .65916 .85057 L p .707 .577 .707 r
F P
0 g
s
.5001 .72417 m .50136 .66784 L .49844 .66092 L p .707 .577 .707 r
F P
0 g
s
.69313 .75374 m .69576 .78839 L .70265 .77455 L p .707 .577 .707 r
F P
0 g
s
.70265 .77455 m .70001 .7399 L .69313 .75374 L p .707 .577 .707 r
F P
0 g
s
.54055 .86239 m .5435 .87728 L .57113 .88355 L p .707 .577 .707 r
F P
0 g
s
.4996 .76069 m .50223 .79534 L .51497 .80714 L p .707 .577 .707 r
F P
0 g
s
.49844 .66092 m .49719 .71724 L .5001 .72417 L p .707 .577 .707 r
F P
0 g
s
.5435 .87728 m .54055 .86239 L .51901 .85048 L p .707 .577 .707 r
F P
0 g
s
.68227 .83422 m .68522 .8491 L .70054 .82987 L p .707 .577 .707 r
F P
0 g
s
.70054 .82987 m .69759 .81498 L .68227 .83422 L p .707 .577 .707 r
F P
0 g
s
.7023 .66814 m .70104 .72447 L .69813 .71754 L p .707 .577 .707 r
F P
0 g
s
.69813 .71754 m .69938 .66121 L .7023 .66814 L p .707 .577 .707 r
F P
0 g
s
.50223 .79534 m .4996 .76069 L .49652 .74721 L p .707 .577 .707 r
F P
0 g
s
.51901 .85048 m .52196 .86537 L .5435 .87728 L p .707 .577 .707 r
F P
0 g
s
.49724 .8244 m .48621 .33072 L .44221 .32842 L p .707 .577 .707 r
F P
0 g
s
.49719 .71724 m .49844 .66092 L .5055 .65435 L p .707 .577 .707 r
F P
0 g
s
.49652 .74721 m .49915 .78186 L .50223 .79534 L p .707 .577 .707 r
F P
0 g
s
.5055 .65435 m .50425 .71067 L .49719 .71724 L p .707 .577 .707 r
F P
0 g
s
.49915 .78186 m .49652 .74721 L .5034 .73337 L p .707 .577 .707 r
F P
0 g
s
.50862 .84899 m .50567 .8341 L .50183 .81485 L p .717 .584 .705 r
F P
0 g
s
.50425 .71067 m .5055 .65435 L .52185 .64877 L p .707 .577 .707 r
F P
0 g
s
.5034 .73337 m .50603 .76803 L .49915 .78186 L p .707 .577 .707 r
F P
0 g
s
.50183 .81485 m .50478 .82974 L .50862 .84899 L p .717 .584 .705 r
F P
0 g
s
.52185 .64877 m .5206 .7051 L .50425 .71067 L p .707 .577 .707 r
F P
0 g
s
.50603 .76803 m .5034 .73337 L .51957 .72053 L p .707 .577 .707 r
F P
0 g
s
.50478 .82974 m .50183 .81485 L .50786 .79461 L p .707 .577 .707 r
F P
0 g
s
.5206 .7051 m .52185 .64877 L .54589 .64474 L p .707 .577 .707 r
F P
0 g
s
.50786 .79461 m .51081 .8095 L .50478 .82974 L p .707 .577 .707 r
F P
0 g
s
.51957 .72053 m .5222 .75519 L .50603 .76803 L p .707 .577 .707 r
F P
0 g
s
.54589 .64474 m .54463 .70107 L .5206 .7051 L p .707 .577 .707 r
F P
0 g
s
.5222 .75519 m .51957 .72053 L .54344 .70995 L p .707 .577 .707 r
F P
0 g
s
.51081 .8095 m .50786 .79461 L .52318 .77538 L p .707 .577 .707 r
F P
0 g
s
.52318 .77538 m .52613 .79027 L .51081 .8095 L p .707 .577 .707 r
F P
0 g
s
.54344 .70995 m .54607 .7446 L .5222 .75519 L p .707 .577 .707 r
F P
0 g
s
.52613 .79027 m .52318 .77538 L .54629 .75902 L p .707 .577 .707 r
F P
0 g
s
.54629 .75902 m .54924 .77391 L .52613 .79027 L p .707 .577 .707 r
F P
0 g
s
.48621 .33072 m .49724 .8244 L .54217 .82218 L p .707 .577 .707 r
F P
0 g
s
.54217 .82218 m .53115 .32851 L .48621 .33072 L p .707 .577 .707 r
F P
0 g
s
.54463 .70107 m .54589 .64474 L .57526 .64264 L p .707 .577 .707 r
F P
0 g
s
.54607 .7446 m .54344 .70995 L .57268 .70265 L p .707 .577 .707 r
F P
0 g
s
.57526 .64264 m .574 .69897 L .54463 .70107 L p .707 .577 .707 r
F P
0 g
s
.57268 .70265 m .57531 .73731 L .54607 .7446 L p .707 .577 .707 r
F P
0 g
s
.54924 .77391 m .54629 .75902 L .57492 .74714 L p .707 .577 .707 r
F P
0 g
s
.57787 .76203 m .57492 .74714 L .60627 .74091 L p .707 .577 .707 r
F P
0 g
s
.57492 .74714 m .57787 .76203 L .54924 .77391 L p .707 .577 .707 r
F P
0 g
s
.53115 .32851 m .54217 .82218 L .58363 .81567 L p .707 .577 .707 r
F P
0 g
s
.574 .69897 m .57526 .64264 L .60708 .64269 L p .707 .577 .707 r
F P
0 g
s
.60708 .64269 m .60583 .69902 L .574 .69897 L p .707 .577 .707 r
F P
0 g
s
.57531 .73731 m .57268 .70265 L .60442 .69936 L p .707 .577 .707 r
F P
0 g
s
.60442 .69936 m .60705 .73401 L .57531 .73731 L p .707 .577 .707 r
F P
0 g
s
.60627 .74091 m .60922 .7558 L .57787 .76203 L p .707 .577 .707 r
F P
0 g
s
.58363 .81567 m .57261 .322 L .53115 .32851 L p .707 .577 .707 r
F P
0 g
s
.70001 .7399 m .70265 .77455 L .69957 .76108 L p .707 .577 .707 r
F P
0 g
s
.69957 .76108 m .69694 .72642 L .70001 .7399 L p .707 .577 .707 r
F P
0 g
s
.52196 .86537 m .51901 .85048 L .50567 .8341 L p .707 .577 .707 r
F P
0 g
s
.69759 .81498 m .70054 .82987 L .70658 .80963 L p .707 .577 .707 r
F P
0 g
s
.70658 .80963 m .70363 .79474 L .69759 .81498 L p .707 .577 .707 r
F P
0 g
s
.45323 .8221 m .44221 .32842 L .40344 .32184 L p .707 .577 .707 r
F P
0 g
s
.44221 .32842 m .45323 .8221 L .49724 .8244 L p .707 .577 .707 r
F P
0 g
s
.50567 .8341 m .50862 .84899 L .52196 .86537 L p .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .66305 .70565 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63669 .71517 m .63556 .70039 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .6382 .73505 L .60705 .73401 L p .707 .577 .707 r
F P
0 g
s
.60705 .73401 m .60442 .69936 L .63556 .70039 L p .707 .577 .707 r
F P
0 g
s
.63825 .64488 m .637 .70121 L .62607 .70044 L p .707 .577 .707 r
F P
0 g
s
.62607 .70044 m .60583 .69902 L p .61455 .68446 L .707 .577 .707 r
F P
0 g
s
.61455 .68446 m .63825 .64488 L .62607 .70044 L .707 .577 .707 r
F
.6382 .73505 m .63669 .71517 L p .64511 .72687 L F P
0 g
s
.60583 .69902 m .60708 .64269 L .63825 .64488 L p .707 .577 .707 r
F P
0 g
s
.63728 .74093 m .64023 .75582 L .60922 .7558 L p .707 .577 .707 r
F P
0 g
s
.60922 .7558 m .60627 .74091 L .63728 .74093 L p .707 .577 .707 r
F P
0 g
s
.57261 .322 m .58363 .81567 L .61756 .80551 L p .707 .577 .707 r
F P
0 g
s
.61756 .80551 m .60654 .31183 L .57261 .322 L p .707 .577 .707 r
F P
0 g
s
.69938 .66121 m .69813 .71754 L .68552 .71094 L p .707 .577 .707 r
F P
0 g
s
.68552 .71094 m .68678 .65461 L .69938 .66121 L p .707 .577 .707 r
F P
0 g
s
.24939 .70588 m .25065 .64955 L .21948 .64736 L p .707 .577 .707 r
F P
0 g
s
.25065 .64955 m .24939 .70588 L .28122 .70592 L p .707 .577 .707 r
F P
0 g
s
.28122 .70592 m .28247 .64959 L .25065 .64955 L p .707 .577 .707 r
F P
0 g
s
.70363 .79474 m .70658 .80963 L .70274 .79038 L p .717 .584 .705 r
F P
0 g
s
.70274 .79038 m .69978 .77549 L .70363 .79474 L p .717 .584 .705 r
F P
0 g
s
.41447 .81551 m .40344 .32184 L .3737 .31161 L p .707 .577 .707 r
F P
0 g
s
.40344 .32184 m .41447 .81551 L .45323 .8221 L p .707 .577 .707 r
F P
0 g
s
.28247 .64959 m .28122 .70592 L .31059 .70383 L p .707 .577 .707 r
F P
0 g
s
.31059 .70383 m .31184 .6475 L .28247 .64959 L p .707 .577 .707 r
F P
0 g
s
.69694 .72642 m .69957 .76108 L .68683 .74928 L p .707 .577 .707 r
F P
0 g
s
.68683 .74928 m .6842 .71462 L .69694 .72642 L p .707 .577 .707 r
F P
0 g
s
.21822 .70369 m .21948 .64736 L .19202 .64325 L p .707 .577 .707 r
F P
0 g
s
.21948 .64736 m .21822 .70369 L .24939 .70588 L p .707 .577 .707 r
F P
0 g
s
.31184 .6475 m .31059 .70383 L .33462 .6998 L p .707 .577 .707 r
F P
0 g
s
.33462 .6998 m .33588 .64347 L .31184 .6475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60654 .31183 m .61756 .80551 L .64065 .79268 L p .707 .577 .707 r
F P
0 g
s
.66571 .64899 m .66446 .70531 L .637 .70121 L p .707 .577 .707 r
F P
0 g
s
.637 .70121 m .63825 .64488 L .66571 .64899 L p .707 .577 .707 r
F P
0 g
s
.66305 .70565 m .66569 .74031 L .6382 .73505 L p .707 .577 .707 r
F P
0 g
s
.64023 .75582 m .63728 .74093 L .6649 .7472 L p .707 .577 .707 r
F P
0 g
s
.64065 .79268 m .62962 .299 L .60654 .31183 L p .707 .577 .707 r
F P
0 g
s
.19202 .64325 m .19076 .69958 L .21822 .70369 L p .707 .577 .707 r
F P
0 g
s
.68678 .65461 m .68552 .71094 L .66446 .70531 L p .707 .577 .707 r
F P
0 g
s
.66446 .70531 m .66571 .64899 L .68678 .65461 L p .707 .577 .707 r
F P
0 g
s
.19076 .69958 m .19202 .64325 L .17095 .63762 L p .707 .577 .707 r
F P
0 g
s
.25173 .78559 m .2491 .75093 L .21796 .7499 L p .707 .577 .707 r
F P
0 g
s
.2491 .75093 m .25173 .78559 L .28348 .78229 L p .707 .577 .707 r
F P
0 g
s
.28348 .78229 m .28084 .74764 L .2491 .75093 L p .707 .577 .707 r
F P
0 g
s
.69978 .77549 m .70274 .79038 L .68939 .774 L p .707 .577 .707 r
F P
0 g
s
.68939 .774 m .68644 .75911 L .69978 .77549 L p .707 .577 .707 r
F P
0 g
s
.28084 .74764 m .28348 .78229 L .31272 .775 L p .707 .577 .707 r
F P
0 g
s
.31272 .775 m .31008 .74035 L .28084 .74764 L p .707 .577 .707 r
F P
0 g
s
.6842 .71462 m .68683 .74928 L .66569 .74031 L p .707 .577 .707 r
F P
0 g
s
.66569 .74031 m .66305 .70565 L .6842 .71462 L p .707 .577 .707 r
F P
0 g
s
.22059 .78455 m .21796 .7499 L .19047 .74464 L p .707 .577 .707 r
F P
0 g
s
.21796 .7499 m .22059 .78455 L .25173 .78559 L p .707 .577 .707 r
F P
0 g
s
.38473 .80528 m .3737 .31161 L .35591 .29874 L p .707 .577 .707 r
F P
0 g
s
.3737 .31161 m .38473 .80528 L .41447 .81551 L p .707 .577 .707 r
F P
0 g
s
.17095 .63762 m .1697 .69395 L .19076 .69958 L p .707 .577 .707 r
F P
0 g
s
.33588 .64347 m .33462 .6998 L .35097 .69422 L p .707 .577 .707 r
F P
0 g
s
.35097 .69422 m .35223 .63789 L .33588 .64347 L p .707 .577 .707 r
F P
0 g
s
.31008 .74035 m .31272 .775 L .33659 .76441 L p .707 .577 .707 r
F P
0 g
s
.33659 .76441 m .33395 .72976 L .31008 .74035 L p .707 .577 .707 r
F P
0 g
s
.1697 .69395 m .17095 .63762 L .15835 .63102 L p .707 .577 .707 r
F P
0 g
s
.1931 .77929 m .19047 .74464 L .16932 .73567 L p .707 .577 .707 r
F P
0 g
s
.19047 .74464 m .1931 .77929 L .22059 .78455 L p .707 .577 .707 r
F P
0 g
s
.68644 .75911 m .68939 .774 L .66786 .76209 L p .707 .577 .707 r
F P
0 g
s
.66786 .76209 m .6649 .7472 L .68644 .75911 L p .707 .577 .707 r
F P
0 g
s
.6649 .7472 m .66786 .76209 L .64023 .75582 L p .707 .577 .707 r
F P
0 g
s
.62962 .299 m .64065 .79268 L .65062 .77844 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .63959 .28476 L .62962 .299 L p .707 .577 .707 r
F P
0 g
s
.33395 .72976 m .33659 .76441 L .35276 .75157 L p .707 .577 .707 r
F P
0 g
s
.35276 .75157 m .35012 .71692 L .33395 .72976 L p .707 .577 .707 r
F P
0 g
s
.15835 .63102 m .15709 .68735 L .1697 .69395 L p .707 .577 .707 r
F P
0 g
s
.35223 .63789 m .35097 .69422 L .35803 .68765 L p .707 .577 .707 r
F P
0 g
s
.35803 .68765 m .35929 .63132 L .35223 .63789 L p .707 .577 .707 r
F P
0 g
s
.16932 .73567 m .17196 .77033 L .1931 .77929 L p .707 .577 .707 r
F P
0 g
s
.25912 .84676 m .25617 .83187 L .22516 .83185 L p .707 .577 .707 r
F P
0 g
s
.25617 .83187 m .25912 .84676 L .29048 .84052 L p .707 .577 .707 r
F P
0 g
s
.29048 .84052 m .28752 .82563 L .25617 .83187 L p .707 .577 .707 r
F P
0 g
s
.28752 .82563 m .29048 .84052 L .31911 .82865 L p .707 .577 .707 r
F P
0 g
s
.31911 .82865 m .31616 .81376 L .28752 .82563 L p .707 .577 .707 r
F P
0 g
s
.17196 .77033 m .16932 .73567 L .15659 .72387 L p .707 .577 .707 r
F P
0 g
s
.22812 .84674 m .22516 .83185 L .19754 .82558 L p .707 .577 .707 r
F P
0 g
s
.22516 .83185 m .22812 .84674 L .25912 .84676 L p .707 .577 .707 r
F P
0 g
s
.31616 .81376 m .31911 .82865 L .34222 .81229 L p .707 .577 .707 r
F P
0 g
s
.34222 .81229 m .33926 .7974 L .31616 .81376 L p .707 .577 .707 r
F P
0 g
s
.36693 .79242 m .35591 .29874 L .35179 .28449 L p .707 .577 .707 r
F P
0 g
s
.35591 .29874 m .36693 .79242 L .38473 .80528 L p .707 .577 .707 r
F P
0 g
s
.15709 .68735 m .15835 .63102 L .15543 .6241 L p .707 .577 .707 r
F P
0 g
s
.35012 .71692 m .35276 .75157 L .35964 .73774 L p .707 .577 .707 r
F P
0 g
s
.35964 .73774 m .357 .70309 L .35012 .71692 L p .707 .577 .707 r
F P
0 g
s
.19754 .82558 m .20049 .84046 L .22812 .84674 L p .707 .577 .707 r
F P
0 g
s
.15659 .72387 m .15922 .75852 L .17196 .77033 L p .707 .577 .707 r
F P
0 g
s
.15543 .6241 m .15418 .68043 L .15709 .68735 L p .707 .577 .707 r
F P
0 g
s
.20049 .84046 m .19754 .82558 L .176 .81367 L p .707 .577 .707 r
F P
0 g
s
.33926 .7974 m .34222 .81229 L .35754 .79305 L p .707 .577 .707 r
F P
0 g
s
.35754 .79305 m .35458 .77816 L .33926 .7974 L p .707 .577 .707 r
F P
0 g
s
.35929 .63132 m .35803 .68765 L .35512 .68073 L p .707 .577 .707 r
F P
0 g
s
.35512 .68073 m .35637 .6244 L .35929 .63132 L p .707 .577 .707 r
F P
0 g
s
.15922 .75852 m .15659 .72387 L .15351 .71039 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .64865 .77161 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.63959 .28476 m .64558 .55265 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64558 .55265 m .65062 .77844 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64563 .70311 m .63959 .28476 L .64865 .77161 L .707 .577 .707 r
F
.63548 .27051 m .63959 .28476 L p .64563 .70311 L F P
0 g
s
.63548 .27051 m .64651 .76419 L .62871 .75132 L p .707 .577 .707 r
F P
0 g
s
.6368 .67929 m .63943 .71394 L .64441 .71856 L p .707 .577 .707 r
F P
0 g
s
.64651 .76419 m .64467 .68193 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64865 .77161 m .64651 .76419 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64441 .71856 m .65217 .72574 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.64452 .70264 m .6368 .67929 L .64441 .71856 L .707 .577 .707 r
F
.64467 .68193 m .64465 .68093 L p .64467 .68151 L F P
0 g
s
.64467 .68193 m .64467 .68151 L .64563 .70311 L .707 .577 .707 r
F
.64465 .68093 m .63548 .27051 L p .64563 .70311 L F P
0 g
s
.63856 .58336 m .6373 .63968 L .64296 .64264 L p .707 .577 .707 r
F P
0 g
s
.64296 .64264 m .64991 .64628 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64092 .59643 m .63856 .58336 L .64296 .64264 L .707 .577 .707 r
F
.65217 .72574 m .64954 .69109 L .64464 .68655 L p F P
0 g
s
.64464 .68655 m .6368 .67929 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.65217 .72574 m .64464 .68655 L .64452 .70264 L .707 .577 .707 r
F
.64991 .64628 m .65117 .58996 L .64038 .58431 L p F P
0 g
s
.64038 .58431 m .63856 .58336 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64991 .64628 m .64038 .58431 L .64092 .59643 L .707 .577 .707 r
F
.176 .81367 m .17896 .82855 L .20049 .84046 L p F P
0 g
s
.15418 .68043 m .15543 .6241 L .16249 .61753 L p .707 .577 .707 r
F P
0 g
s
.357 .70309 m .35964 .73774 L .35656 .72426 L p .707 .577 .707 r
F P
0 g
s
.35656 .72426 m .35393 .68961 L .357 .70309 L p .707 .577 .707 r
F P
0 g
s
.17896 .82855 m .176 .81367 L .16266 .79728 L p .707 .577 .707 r
F P
0 g
s
.35458 .77816 m .35754 .79305 L .36357 .77282 L p .707 .577 .707 r
F P
0 g
s
.36357 .77282 m .36062 .75793 L .35458 .77816 L p .707 .577 .707 r
F P
0 g
s
.15351 .71039 m .15614 .74505 L .15922 .75852 L p .707 .577 .707 r
F P
0 g
s
.36062 .75793 m .36357 .77282 L .35973 .75357 L p .717 .584 .705 r
F P
0 g
s
.35179 .28449 m .36282 .77817 L .36693 .79242 L p .707 .577 .707 r
F P
0 g
s
.36282 .77817 m .35179 .28449 L .36177 .27025 L p .707 .577 .707 r
F P
0 g
s
.16249 .61753 m .16124 .67386 L .15418 .68043 L p .707 .577 .707 r
F P
0 g
s
.16266 .79728 m .16561 .81217 L .17896 .82855 L p .707 .577 .707 r
F P
0 g
s
.35637 .6244 m .35512 .68073 L .34251 .67413 L p .707 .577 .707 r
F P
0 g
s
.34251 .67413 m .34377 .6178 L .35637 .6244 L p .707 .577 .707 r
F P
0 g
s
.15614 .74505 m .15351 .71039 L .16039 .69656 L p .707 .577 .707 r
F P
0 g
s
.16561 .81217 m .16266 .79728 L .15882 .77803 L p .717 .584 .705 r
F P
0 g
s
.35973 .75357 m .35677 .73868 L .36062 .75793 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16124 .67386 m .16249 .61753 L .17884 .61196 L p .707 .577 .707 r
F P
0 g
s
.35393 .68961 m .35656 .72426 L .34382 .71246 L p .707 .577 .707 r
F P
0 g
s
.34382 .71246 m .34119 .67781 L .35393 .68961 L p .707 .577 .707 r
F P
0 g
s
.62871 .75132 m .61768 .25764 L .63548 .27051 L p .707 .577 .707 r
F P
0 g
s
.16039 .69656 m .16302 .73121 L .15614 .74505 L p .707 .577 .707 r
F P
0 g
s
.15882 .77803 m .16177 .79292 L .16561 .81217 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17884 .61196 m .17759 .66828 L .16124 .67386 L p .707 .577 .707 r
F P
0 g
s
.16302 .73121 m .16039 .69656 L .17656 .68372 L p .707 .577 .707 r
F P
0 g
s
.34377 .6178 m .34251 .67413 L .32145 .6685 L p .707 .577 .707 r
F P
0 g
s
.32145 .6685 m .3227 .61217 L .34377 .6178 L p .707 .577 .707 r
F P
0 g
s
.16177 .79292 m .15882 .77803 L .16485 .7578 L p .707 .577 .707 r
F P
0 g
s
.35677 .73868 m .35973 .75357 L .34638 .73718 L p .707 .577 .707 r
F P
0 g
s
.34638 .73718 m .34343 .7223 L .35677 .73868 L p .707 .577 .707 r
F P
0 g
s
.37279 .76393 m .36177 .27025 L .38485 .25742 L p .707 .577 .707 r
F P
0 g
s
.36177 .27025 m .37279 .76393 L .36282 .77817 L p .707 .577 .707 r
F P
0 g
s
.17759 .66828 m .17884 .61196 L .20288 .60792 L p .707 .577 .707 r
F P
0 g
s
.34119 .67781 m .34382 .71246 L .32268 .70349 L p .707 .577 .707 r
F P
0 g
s
.32268 .70349 m .32004 .66884 L .34119 .67781 L p .707 .577 .707 r
F P
0 g
s
.16485 .7578 m .1678 .77269 L .16177 .79292 L p .707 .577 .707 r
F P
0 g
s
.17656 .68372 m .17919 .71837 L .16302 .73121 L p .707 .577 .707 r
F P
0 g
s
.20288 .60792 m .20162 .66425 L .17759 .66828 L p .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .32004 .66884 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29519 .69823 m .29368 .67836 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29368 .67836 m .29255 .66358 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .29519 .69823 L .26405 .6972 L p .707 .577 .707 r
F P
0 g
s
.26405 .6972 m .26141 .66254 L .29255 .66358 L p .707 .577 .707 r
F P
0 g
s
.29524 .60806 m .29399 .66439 L .28306 .66362 L p .707 .577 .707 r
F P
0 g
s
.28306 .66362 m .26282 .66221 L p .27154 .64764 L .707 .577 .707 r
F P
0 g
s
.27154 .64764 m .29524 .60806 L .28306 .66362 L .707 .577 .707 r
F
.3227 .61217 m .32145 .6685 L .29399 .66439 L p F P
0 g
s
.29399 .66439 m .29524 .60806 L .3227 .61217 L p .707 .577 .707 r
F P
0 g
s
.17919 .71837 m .17656 .68372 L .20043 .67313 L p .707 .577 .707 r
F P
0 g
s
.61768 .25764 m .62871 .75132 L .59897 .74109 L p .707 .577 .707 r
F P
0 g
s
.59897 .74109 m .58795 .24741 L .61768 .25764 L p .707 .577 .707 r
F P
0 g
s
.1678 .77269 m .16485 .7578 L .18017 .73856 L p .707 .577 .707 r
F P
0 g
s
.34343 .7223 m .34638 .73718 L .32485 .72527 L p .707 .577 .707 r
F P
0 g
s
.32485 .72527 m .32189 .71039 L .34343 .7223 L p .707 .577 .707 r
F P
0 g
s
.20162 .66425 m .20288 .60792 L .23225 .60583 L p .707 .577 .707 r
F P
0 g
s
.32004 .66884 m .32268 .70349 L .29519 .69823 L p .707 .577 .707 r
F P
0 g
s
.26282 .66221 m .26407 .60588 L .29524 .60806 L p .707 .577 .707 r
F P
0 g
s
.18017 .73856 m .18312 .75345 L .1678 .77269 L p .707 .577 .707 r
F P
0 g
s
.20043 .67313 m .20306 .70779 L .17919 .71837 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .37279 .76393 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.38981 .47983 m .39587 .7511 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .38485 .25742 L .41878 .24725 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .40399 .57256 L .4278 .65808 L .707 .577 .707 r
F
.42981 .74093 m .41213 .74623 L p .42785 .65823 L F P
0 g
s
.42795 .65767 m .42797 .65868 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42797 .65868 m .42981 .74093 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42981 .74093 m .41878 .24725 L .46024 .24074 L p .707 .577 .707 r
F P
0 g
s
.46024 .24074 m .47127 .73442 L .42981 .74093 L p .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .44729 .65895 L .42929 .66344 L p .707 .577 .707 r
F P
0 g
s
.41213 .74623 m .39587 .7511 L p .42795 .65767 L .707 .577 .707 r
F P
0 g
s
.42929 .66344 m .41805 .66624 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .42929 .66344 L .43385 .67981 L .707 .577 .707 r
F
.41805 .66624 m .42068 .7009 L .43849 .69645 L p F P
0 g
s
.43849 .69645 m .44992 .6936 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.43385 .67981 m .41805 .66624 L .43849 .69645 L .707 .577 .707 r
F
.41878 .24725 m .42795 .65767 L p .4278 .65808 L F P
0 g
s
.40399 .57256 m .41878 .24725 L .4278 .65808 L .707 .577 .707 r
F
.41968 .56511 m .41842 .62144 L .43462 .62028 L p F P
0 g
s
.43462 .62028 m .44779 .61934 L p .43812 .60069 L .707 .577 .707 r
F P
0 g
s
.43812 .60069 m .41968 .56511 L .43462 .62028 L .707 .577 .707 r
F
.3863 .66954 m .38894 .70419 L .41279 .70172 L p F P
0 g
s
.41279 .70172 m .42068 .7009 L p .41187 .69286 L .707 .577 .707 r
F P
0 g
s
.41187 .69286 m .3863 .66954 L .41279 .70172 L .707 .577 .707 r
F
.38485 .25742 m .38981 .47983 L p .38147 .39925 L F P
0 g
s
.20306 .70779 m .20043 .67313 L .22967 .66584 L p .707 .577 .707 r
F P
0 g
s
.23225 .60583 m .23099 .66216 L .20162 .66425 L p .707 .577 .707 r
F P
0 g
s
.23099 .66216 m .23225 .60583 L .26407 .60588 L p .707 .577 .707 r
F P
0 g
s
.26407 .60588 m .26282 .66221 L .23099 .66216 L p .707 .577 .707 r
F P
0 g
s
.72961 .65821 m .73086 .60188 L .69969 .59969 L p .707 .577 .707 r
F P
0 g
s
.73086 .60188 m .72961 .65821 L .76143 .65825 L p .707 .577 .707 r
F P
0 g
s
.76143 .65825 m .76269 .60193 L .73086 .60188 L p .707 .577 .707 r
F P
0 g
s
.18312 .75345 m .18017 .73856 L .20328 .7222 L p .707 .577 .707 r
F P
0 g
s
.32189 .71039 m .32485 .72527 L .29722 .719 L p .707 .577 .707 r
F P
0 g
s
.29722 .719 m .29427 .70411 L .32189 .71039 L p .707 .577 .707 r
F P
0 g
s
.76269 .60193 m .76143 .65825 L .7908 .65616 L p .707 .577 .707 r
F P
0 g
s
.7908 .65616 m .79206 .59983 L .76269 .60193 L p .707 .577 .707 r
F P
0 g
s
.2323 .70049 m .22967 .66584 L .26141 .66254 L p .707 .577 .707 r
F P
0 g
s
.22967 .66584 m .2323 .70049 L .20306 .70779 L p .707 .577 .707 r
F P
0 g
s
.69844 .65602 m .69969 .59969 L .67223 .59559 L p .707 .577 .707 r
F P
0 g
s
.69969 .59969 m .69844 .65602 L .72961 .65821 L p .707 .577 .707 r
F P
0 g
s
.26141 .66254 m .26405 .6972 L .2323 .70049 L p .707 .577 .707 r
F P
0 g
s
.58795 .24741 m .59897 .74109 L .5602 .73451 L p .707 .577 .707 r
F P
0 g
s
.5602 .73451 m .54918 .24083 L .58795 .24741 L p .707 .577 .707 r
F P
0 g
s
.20328 .7222 m .20623 .73709 L .18312 .75345 L p .707 .577 .707 r
F P
0 g
s
.79206 .59983 m .7908 .65616 L .81484 .65213 L p .707 .577 .707 r
F P
0 g
s
.81484 .65213 m .81609 .5958 L .79206 .59983 L p .707 .577 .707 r
F P
0 g
s
.20623 .73709 m .20328 .7222 L .23191 .71033 L p .707 .577 .707 r
F P
0 g
s
.29427 .70411 m .29722 .719 L .26622 .71898 L p .707 .577 .707 r
F P
0 g
s
.26622 .71898 m .26326 .70409 L .29427 .70411 L p .707 .577 .707 r
F P
0 g
s
.67223 .59559 m .67098 .65191 L .69844 .65602 L p .707 .577 .707 r
F P
0 g
s
.67098 .65191 m .67223 .59559 L .65117 .58996 L p .707 .577 .707 r
F P
0 g
s
.23486 .72522 m .23191 .71033 L .26326 .70409 L p .707 .577 .707 r
F P
0 g
s
.23191 .71033 m .23486 .72522 L .20623 .73709 L p .707 .577 .707 r
F P
0 g
s
.26326 .70409 m .26622 .71898 L .23486 .72522 L p .707 .577 .707 r
F P
0 g
s
.73195 .741 m .72931 .70635 L .69817 .70532 L p .707 .577 .707 r
F P
0 g
s
.72931 .70635 m .73195 .741 L .76369 .73771 L p .707 .577 .707 r
F P
0 g
s
.76369 .73771 m .76106 .70306 L .72931 .70635 L p .707 .577 .707 r
F P
0 g
s
.76106 .70306 m .76369 .73771 L .79293 .73042 L p .707 .577 .707 r
F P
0 g
s
.79293 .73042 m .7903 .69576 L .76106 .70306 L p .707 .577 .707 r
F P
0 g
s
.70081 .73997 m .69817 .70532 L .67068 .70006 L p .707 .577 .707 r
F P
0 g
s
.69817 .70532 m .70081 .73997 L .73195 .741 L p .707 .577 .707 r
F P
0 g
s
.54918 .24083 m .5602 .73451 L .5162 .73221 L p .707 .577 .707 r
F P
0 g
s
.5162 .73221 m .50517 .23853 L .54918 .24083 L p .707 .577 .707 r
F P
0 g
s
.65117 .58996 m .64991 .64628 L .67098 .65191 L p .707 .577 .707 r
F P
0 g
s
.81609 .5958 m .81484 .65213 L .83119 .64655 L p .707 .577 .707 r
F P
0 g
s
.83119 .64655 m .83244 .59023 L .81609 .5958 L p .707 .577 .707 r
F P
0 g
s
.7903 .69576 m .79293 .73042 L .8168 .71983 L p .707 .577 .707 r
F P
0 g
s
.8168 .71983 m .81417 .68518 L .7903 .69576 L p .707 .577 .707 r
F P
0 g
s
.44729 .65895 m .44992 .6936 L .4533 .6921 L p .707 .577 .707 r
F P
0 g
s
.47127 .73442 m .46664 .52717 L p .50517 .23853 L .707 .577 .707 r
F P
0 g
s
.4533 .6921 m .47379 .68302 L p .45539 .66631 L .707 .577 .707 r
F P
0 g
s
.45539 .66631 m .44729 .65895 L .4533 .6921 L .707 .577 .707 r
F
.46664 .52717 m .46024 .24074 L .48991 .23928 L p F P
0 g
s
.48991 .23928 m .50517 .23853 L p .46664 .52717 L .707 .577 .707 r
F P
0 g
s
.50517 .23853 m .5162 .73221 L .47127 .73442 L p .707 .577 .707 r
F P
0 g
s
.67332 .73471 m .67068 .70006 L .64954 .69109 L p .707 .577 .707 r
F P
0 g
s
.67068 .70006 m .67332 .73471 L .70081 .73997 L p .707 .577 .707 r
F P
0 g
s
.81417 .68518 m .8168 .71983 L .83297 .70699 L p .707 .577 .707 r
F P
0 g
s
.83297 .70699 m .83034 .67234 L .81417 .68518 L p .707 .577 .707 r
F P
0 g
s
.83244 .59023 m .83119 .64655 L .83825 .63998 L p .707 .577 .707 r
F P
0 g
s
.83825 .63998 m .8395 .58365 L .83244 .59023 L p .707 .577 .707 r
F P
0 g
s
.73934 .79546 m .73638 .78057 L .70538 .78055 L p .707 .577 .707 r
F P
0 g
s
.73638 .78057 m .73934 .79546 L .77069 .78922 L p .707 .577 .707 r
F P
0 g
s
.77069 .78922 m .76774 .77433 L .73638 .78057 L p .707 .577 .707 r
F P
0 g
s
.76774 .77433 m .77069 .78922 L .79932 .77735 L p .707 .577 .707 r
F P
0 g
s
.79932 .77735 m .79637 .76246 L .76774 .77433 L p .707 .577 .707 r
F P
0 g
s
.64954 .69109 m .65217 .72574 L .67332 .73471 L p .707 .577 .707 r
F P
0 g
s
.70833 .79544 m .70538 .78055 L .67775 .77427 L p .707 .577 .707 r
F P
0 g
s
.70538 .78055 m .70833 .79544 L .73934 .79546 L p .707 .577 .707 r
F P
0 g
s
.79637 .76246 m .79932 .77735 L .82243 .76099 L p .707 .577 .707 r
F P
0 g
s
.82243 .76099 m .81948 .7461 L .79637 .76246 L p .707 .577 .707 r
F P
0 g
s
.6373 .63968 m .63856 .58336 L .63564 .57643 L p .707 .577 .707 r
F P
0 g
s
.83034 .67234 m .83297 .70699 L .83985 .69316 L p .707 .577 .707 r
F P
0 g
s
.83985 .69316 m .83722 .6585 L .83034 .67234 L p .707 .577 .707 r
F P
0 g
s
.67775 .77427 m .68071 .78916 L .70833 .79544 L p .707 .577 .707 r
F P
0 g
s
.68071 .78916 m .67775 .77427 L .65622 .76236 L p .707 .577 .707 r
F P
0 g
s
.81948 .7461 m .82243 .76099 L .83775 .74175 L p .707 .577 .707 r
F P
0 g
s
.83775 .74175 m .8348 .72686 L .81948 .7461 L p .707 .577 .707 r
F P
0 g
s
.63564 .57643 m .63439 .63276 L .6373 .63968 L p .707 .577 .707 r
F P
0 g
s
.8395 .58365 m .83825 .63998 L .83533 .63306 L p .707 .577 .707 r
F P
0 g
s
.83533 .63306 m .83659 .57673 L .8395 .58365 L p .707 .577 .707 r
F P
0 g
s
.63943 .71394 m .6368 .67929 L .63372 .66581 L p .707 .577 .707 r
F P
0 g
s
.65622 .76236 m .65917 .77725 L .68071 .78916 L p .707 .577 .707 r
F P
0 g
s
.63439 .63276 m .63564 .57643 L .64271 .56986 L p .707 .577 .707 r
F P
0 g
s
.65917 .77725 m .65622 .76236 L .64287 .74598 L p .707 .577 .707 r
F P
0 g
s
.8348 .72686 m .83775 .74175 L .84378 .72152 L p .707 .577 .707 r
F P
0 g
s
.84378 .72152 m .84083 .70663 L .8348 .72686 L p .707 .577 .707 r
F P
0 g
s
.83722 .6585 m .83985 .69316 L .83677 .67968 L p .707 .577 .707 r
F P
0 g
s
.83677 .67968 m .83414 .64502 L .83722 .6585 L p .707 .577 .707 r
F P
0 g
s
.63372 .66581 m .63636 .70046 L .63943 .71394 L p .707 .577 .707 r
F P
0 g
s
.64271 .56986 m .64145 .62619 L .63439 .63276 L p .707 .577 .707 r
F P
0 g
s
.64287 .74598 m .64583 .76087 L .65917 .77725 L p .707 .577 .707 r
F P
0 g
s
.83659 .57673 m .83533 .63306 L .82273 .62646 L p .707 .577 .707 r
F P
0 g
s
.82273 .62646 m .82398 .57013 L .83659 .57673 L p .707 .577 .707 r
F P
0 g
s
.63636 .70046 m .63372 .66581 L .6406 .65197 L p .707 .577 .707 r
F P
0 g
s
.64583 .76087 m .64287 .74598 L .63903 .72673 L p .717 .584 .705 r
F P
0 g
s
.84083 .70663 m .84378 .72152 L .83994 .70227 L p .717 .584 .705 r
F P
0 g
s
.83994 .70227 m .83699 .68738 L .84083 .70663 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3866 .62139 m .38785 .56506 L .35668 .56288 L p .707 .577 .707 r
F P
0 g
s
.38785 .56506 m .3866 .62139 L .41842 .62144 L p .707 .577 .707 r
F P
0 g
s
.41842 .62144 m .41968 .56511 L .38785 .56506 L p .707 .577 .707 r
F P
0 g
s
.44779 .61934 m .44905 .56302 L .41968 .56511 L p .707 .577 .707 r
F P
0 g
s
.64145 .62619 m .64271 .56986 L .65906 .56429 L p .707 .577 .707 r
F P
0 g
s
.83414 .64502 m .83677 .67968 L .82404 .66788 L p .707 .577 .707 r
F P
0 g
s
.82404 .66788 m .8214 .63322 L .83414 .64502 L p .707 .577 .707 r
F P
0 g
s
.35543 .61921 m .35668 .56288 L .32922 .55877 L p .707 .577 .707 r
F P
0 g
s
.35668 .56288 m .35543 .61921 L .3866 .62139 L p .707 .577 .707 r
F P
0 g
s
.6406 .65197 m .64324 .68663 L .63636 .70046 L p .707 .577 .707 r
F P
0 g
s
.63903 .72673 m .64198 .74162 L .64583 .76087 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44905 .56302 m .44779 .61934 L .47183 .61531 L p .707 .577 .707 r
F P
0 g
s
.47183 .61531 m .47308 .55898 L .44905 .56302 L p .707 .577 .707 r
F P
0 g
s
.65906 .56429 m .6578 .62062 L .64145 .62619 L p .707 .577 .707 r
F P
0 g
s
.32922 .55877 m .32797 .6151 L .35543 .61921 L p .707 .577 .707 r
F P
0 g
s
.82398 .57013 m .82273 .62646 L .80166 .62083 L p .707 .577 .707 r
F P
0 g
s
.80166 .62083 m .80292 .5645 L .82398 .57013 L p .707 .577 .707 r
F P
0 g
s
.64324 .68663 m .6406 .65197 L .65677 .63914 L p .707 .577 .707 r
F P
0 g
s
.32797 .6151 m .32922 .55877 L .30816 .55314 L p .707 .577 .707 r
F P
0 g
s
.64198 .74162 m .63903 .72673 L .64506 .7065 L p .707 .577 .707 r
F P
0 g
s
.83699 .68738 m .83994 .70227 L .8266 .68588 L p .707 .577 .707 r
F P
0 g
s
.8266 .68588 m .82364 .67099 L .83699 .68738 L p .707 .577 .707 r
F P
0 g
s
.38894 .70419 m .3863 .66954 L .35516 .6685 L p .707 .577 .707 r
F P
0 g
s
.42068 .7009 m .41805 .66624 L .3863 .66954 L p .707 .577 .707 r
F P
0 g
s
.6578 .62062 m .65906 .56429 L .68309 .56026 L p .707 .577 .707 r
F P
0 g
s
.8214 .63322 m .82404 .66788 L .80289 .65891 L p .707 .577 .707 r
F P
0 g
s
.80289 .65891 m .80026 .62425 L .8214 .63322 L p .707 .577 .707 r
F P
0 g
s
.3578 .70316 m .35516 .6685 L .32767 .66324 L p .707 .577 .707 r
F P
0 g
s
.35516 .6685 m .3578 .70316 L .38894 .70419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55314 m .3069 .60947 L .32797 .6151 L p .707 .577 .707 r
F P
0 g
s
.64506 .7065 m .64802 .72139 L .64198 .74162 L p .707 .577 .707 r
F P
0 g
s
.47308 .55898 m .47183 .61531 L .48818 .60974 L p .707 .577 .707 r
F P
0 g
s
.48818 .60974 m .48943 .55341 L .47308 .55898 L p .707 .577 .707 r
F P
0 g
s
.47379 .68302 m .47116 .64836 L .44729 .65895 L p .707 .577 .707 r
F P
0 g
s
.65677 .63914 m .65941 .67379 L .64324 .68663 L p .707 .577 .707 r
F P
0 g
s
.68309 .56026 m .68184 .61658 L .6578 .62062 L p .707 .577 .707 r
F P
0 g
s
.80292 .5645 m .80166 .62083 L .7742 .61672 L p .707 .577 .707 r
F P
0 g
s
.7742 .61672 m .77546 .56039 L .80292 .5645 L p .707 .577 .707 r
F P
0 g
s
.65941 .67379 m .65677 .63914 L .68064 .62855 L p .707 .577 .707 r
F P
0 g
s
.3069 .60947 m .30816 .55314 L .29555 .54654 L p .707 .577 .707 r
F P
0 g
s
.33031 .6979 m .32767 .66324 L .30653 .65427 L p .707 .577 .707 r
F P
0 g
s
.32767 .66324 m .33031 .6979 L .3578 .70316 L p .707 .577 .707 r
F P
0 g
s
.64802 .72139 m .64506 .7065 L .66038 .68726 L p .707 .577 .707 r
F P
0 g
s
.82364 .67099 m .8266 .68588 L .80506 .67397 L p .707 .577 .707 r
F P
0 g
s
.80506 .67397 m .80211 .65908 L .82364 .67099 L p .707 .577 .707 r
F P
0 g
s
.68184 .61658 m .68309 .56026 L .71246 .55816 L p .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .80211 .65908 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77744 .6677 m .77587 .65979 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77587 .65979 m .77448 .65281 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .77744 .6677 L .74643 .66768 L p .707 .577 .707 r
F P
0 g
s
.74643 .66768 m .74348 .65279 L .77448 .65281 L p .707 .577 .707 r
F P
0 g
s
.77277 .619 m .7754 .65365 L .77027 .65348 L p .707 .577 .707 r
F P
0 g
s
.77027 .65348 m .74426 .65262 L p .75659 .63807 L .707 .577 .707 r
F P
0 g
s
.75659 .63807 m .77277 .619 L .77027 .65348 L .707 .577 .707 r
F
.80026 .62425 m .80289 .65891 L .7754 .65365 L p F P
0 g
s
.7754 .65365 m .77277 .619 L .80026 .62425 L p .707 .577 .707 r
F P
0 g
s
.47116 .64836 m .47379 .68302 L .48996 .67018 L p .707 .577 .707 r
F P
0 g
s
.48996 .67018 m .48733 .63552 L .47116 .64836 L p .707 .577 .707 r
F P
0 g
s
.29555 .54654 m .29429 .60287 L .3069 .60947 L p .707 .577 .707 r
F P
0 g
s
.66038 .68726 m .66334 .70215 L .64802 .72139 L p .707 .577 .707 r
F P
0 g
s
.77546 .56039 m .7742 .61672 L .74303 .61454 L p .707 .577 .707 r
F P
0 g
s
.74303 .61454 m .74429 .55821 L .77546 .56039 L p .707 .577 .707 r
F P
0 g
s
.68064 .62855 m .68328 .6632 L .65941 .67379 L p .707 .577 .707 r
F P
0 g
s
.48943 .55341 m .48818 .60974 L .49524 .60317 L p .707 .577 .707 r
F P
0 g
s
.49524 .60317 m .49649 .54684 L .48943 .55341 L p .707 .577 .707 r
F P
0 g
s
.71246 .55816 m .71121 .61449 L .68184 .61658 L p .707 .577 .707 r
F P
0 g
s
.71121 .61449 m .71246 .55816 L .74429 .55821 L p .707 .577 .707 r
F P
0 g
s
.39633 .75864 m .39337 .74375 L .36237 .74373 L p .707 .577 .707 r
F P
0 g
s
.39337 .74375 m .39633 .75864 L .42768 .75241 L p .707 .577 .707 r
F P
0 g
s
.42768 .75241 m .42473 .73752 L .39337 .74375 L p .707 .577 .707 r
F P
0 g
s
.42473 .73752 m .42768 .75241 L .45631 .74053 L p .707 .577 .707 r
F P
0 g
s
.45631 .74053 m .45336 .72564 L .42473 .73752 L p .707 .577 .707 r
F P
0 g
s
.30653 .65427 m .30916 .68893 L .33031 .6979 L p .707 .577 .707 r
F P
0 g
s
.68328 .6632 m .68064 .62855 L .70988 .62125 L p .707 .577 .707 r
F P
0 g
s
.74429 .55821 m .74303 .61454 L .71121 .61449 L p .707 .577 .707 r
F P
0 g
s
.66334 .70215 m .66038 .68726 L .68349 .6709 L p .707 .577 .707 r
F P
0 g
s
.80211 .65908 m .80506 .67397 L .77744 .6677 L p .707 .577 .707 r
F P
0 g
s
.74426 .65262 m .74163 .61796 L .77277 .619 L p .707 .577 .707 r
F P
0 g
s
.30916 .68893 m .30653 .65427 L .29379 .64247 L p .707 .577 .707 r
F P
0 g
s
.36532 .75862 m .36237 .74373 L .33474 .73746 L p .707 .577 .707 r
F P
0 g
s
.36237 .74373 m .36532 .75862 L .39633 .75864 L p .707 .577 .707 r
F P
0 g
s
.45336 .72564 m .45631 .74053 L .47942 .72417 L p .707 .577 .707 r
F P
0 g
s
.47942 .72417 m .47647 .70928 L .45336 .72564 L p .707 .577 .707 r
F P
0 g
s
.29429 .60287 m .29555 .54654 L .29263 .53962 L p .707 .577 .707 r
F P
0 g
s
.71252 .65591 m .70988 .62125 L .74163 .61796 L p .707 .577 .707 r
F P
0 g
s
.70988 .62125 m .71252 .65591 L .68328 .6632 L p .707 .577 .707 r
F P
0 g
s
.74163 .61796 m .74426 .65262 L .71252 .65591 L p .707 .577 .707 r
F P
0 g
s
.68349 .6709 m .68644 .68579 L .66334 .70215 L p .707 .577 .707 r
F P
0 g
s
.48733 .63552 m .48996 .67018 L .49684 .65634 L p .707 .577 .707 r
F P
0 g
s
.49684 .65634 m .49421 .62169 L .48733 .63552 L p .707 .577 .707 r
F P
0 g
s
.68644 .68579 m .68349 .6709 L .71212 .65902 L p .707 .577 .707 r
F P
0 g
s
.33474 .73746 m .3377 .75235 L .36532 .75862 L p .707 .577 .707 r
F P
0 g
s
.29379 .64247 m .29642 .67713 L .30916 .68893 L p .707 .577 .707 r
F P
0 g
s
.3377 .75235 m .33474 .73746 L .31321 .72555 L p .707 .577 .707 r
F P
0 g
s
.47647 .70928 m .47942 .72417 L .49474 .70493 L p .707 .577 .707 r
F P
0 g
s
.49474 .70493 m .49179 .69005 L .47647 .70928 L p .707 .577 .707 r
F P
0 g
s
.29263 .53962 m .29138 .59594 L .29429 .60287 L p .707 .577 .707 r
F P
0 g
s
.71508 .67391 m .71212 .65902 L .74348 .65279 L p .707 .577 .707 r
F P
0 g
s
.71212 .65902 m .71508 .67391 L .68644 .68579 L p .707 .577 .707 r
F P
0 g
s
.74348 .65279 m .74643 .66768 L .71508 .67391 L p .707 .577 .707 r
F P
0 g
s
.49649 .54684 m .49524 .60317 L .49232 .59624 L p .707 .577 .707 r
F P
0 g
s
.49232 .59624 m .49358 .53991 L .49649 .54684 L p .707 .577 .707 r
F P
0 g
s
.29642 .67713 m .29379 .64247 L .29071 .62899 L p .707 .577 .707 r
F P
0 g
s
.31321 .72555 m .31616 .74044 L .3377 .75235 L p .707 .577 .707 r
F P
0 g
s
.29138 .59594 m .29263 .53962 L .2997 .53305 L p .707 .577 .707 r
F P
0 g
s
.31616 .74044 m .31321 .72555 L .29986 .70917 L p .707 .577 .707 r
F P
0 g
s
.49179 .69005 m .49474 .70493 L .50077 .6847 L p .707 .577 .707 r
F P
0 g
s
.50077 .6847 m .49782 .66981 L .49179 .69005 L p .707 .577 .707 r
F P
0 g
s
.49421 .62169 m .49684 .65634 L .49376 .64286 L p .707 .577 .707 r
F P
0 g
s
.49376 .64286 m .49113 .60821 L .49421 .62169 L p .707 .577 .707 r
F P
0 g
s
.29071 .62899 m .29334 .66365 L .29642 .67713 L p .707 .577 .707 r
F P
0 g
s
.2997 .53305 m .29844 .58937 L .29138 .59594 L p .707 .577 .707 r
F P
0 g
s
.29986 .70917 m .30282 .72406 L .31616 .74044 L p .707 .577 .707 r
F P
0 g
s
.49358 .53991 m .49232 .59624 L .47972 .58964 L p .707 .577 .707 r
F P
0 g
s
.47972 .58964 m .48097 .53331 L .49358 .53991 L p .707 .577 .707 r
F P
0 g
s
.29334 .66365 m .29071 .62899 L .29759 .61516 L p .707 .577 .707 r
F P
0 g
s
.30282 .72406 m .29986 .70917 L .29602 .68992 L p .717 .584 .705 r
F P
0 g
s
.49782 .66981 m .50077 .6847 L .49693 .66545 L p .717 .584 .705 r
F P
0 g
s
.49693 .66545 m .49398 .65056 L .49782 .66981 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29844 .58937 m .2997 .53305 L .31605 .52747 L p .707 .577 .707 r
F P
0 g
s
.49113 .60821 m .49376 .64286 L .48103 .63106 L p .707 .577 .707 r
F P
0 g
s
.48103 .63106 m .47839 .59641 L .49113 .60821 L p .707 .577 .707 r
F P
0 g
s
.29759 .61516 m .30023 .64981 L .29334 .66365 L p .707 .577 .707 r
F P
0 g
s
.29602 .68992 m .29897 .70481 L .30282 .72406 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31605 .52747 m .31479 .5838 L .29844 .58937 L p .707 .577 .707 r
F P
0 g
s
.48097 .53331 m .47972 .58964 L .45865 .58401 L p .707 .577 .707 r
F P
0 g
s
.45865 .58401 m .45991 .52769 L .48097 .53331 L p .707 .577 .707 r
F P
0 g
s
.30023 .64981 m .29759 .61516 L .31376 .60232 L p .707 .577 .707 r
F P
0 g
s
.29897 .70481 m .29602 .68992 L .30205 .66968 L p .707 .577 .707 r
F P
0 g
s
.49398 .65056 m .49693 .66545 L .48359 .64907 L p .707 .577 .707 r
F P
0 g
s
.48359 .64907 m .48063 .63418 L .49398 .65056 L p .707 .577 .707 r
F P
0 g
s
.31479 .5838 m .31605 .52747 L .34008 .52344 L p .707 .577 .707 r
F P
0 g
s
.47839 .59641 m .48103 .63106 L .45988 .62209 L p .707 .577 .707 r
F P
0 g
s
.45988 .62209 m .45725 .58744 L .47839 .59641 L p .707 .577 .707 r
F P
0 g
s
.30205 .66968 m .30501 .68457 L .29897 .70481 L p .707 .577 .707 r
F P
0 g
s
.31376 .60232 m .3164 .63697 L .30023 .64981 L p .707 .577 .707 r
F P
0 g
s
.34008 .52344 m .33883 .57977 L .31479 .5838 L p .707 .577 .707 r
F P
0 g
s
.45991 .52769 m .45865 .58401 L .43119 .57991 L p .707 .577 .707 r
F P
0 g
s
.43119 .57991 m .43244 .52358 L .45991 .52769 L p .707 .577 .707 r
F P
0 g
s
.3164 .63697 m .31376 .60232 L .33763 .59173 L p .707 .577 .707 r
F P
0 g
s
.30501 .68457 m .30205 .66968 L .31737 .65044 L p .707 .577 .707 r
F P
0 g
s
.48063 .63418 m .48359 .64907 L .46205 .63716 L p .707 .577 .707 r
F P
0 g
s
.46205 .63716 m .4591 .62227 L .48063 .63418 L p .707 .577 .707 r
F P
0 g
s
.33883 .57977 m .34008 .52344 L .36945 .52135 L p .707 .577 .707 r
F P
0 g
s
.43147 .616 m .4591 .62227 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43443 .63089 m .43286 .62297 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43286 .62297 m .43147 .616 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43147 .616 m .43443 .63089 L .40342 .63086 L p .707 .577 .707 r
F P
0 g
s
.40342 .63086 m .40047 .61598 L .43147 .616 L p .707 .577 .707 r
F P
0 g
s
.42976 .58218 m .43239 .61683 L .42726 .61666 L p .707 .577 .707 r
F P
0 g
s
.42726 .61666 m .40125 .6158 L p .41358 .60126 L .707 .577 .707 r
F P
0 g
s
.41358 .60126 m .42976 .58218 L .42726 .61666 L .707 .577 .707 r
F
.45725 .58744 m .45988 .62209 L .43239 .61683 L p F P
0 g
s
.43239 .61683 m .42976 .58218 L .45725 .58744 L p .707 .577 .707 r
F P
0 g
s
.31737 .65044 m .32033 .66533 L .30501 .68457 L p .707 .577 .707 r
F P
0 g
s
.43244 .52358 m .43119 .57991 L .40002 .57772 L p .707 .577 .707 r
F P
0 g
s
.40002 .57772 m .40128 .52139 L .43244 .52358 L p .707 .577 .707 r
F P
0 g
s
.33763 .59173 m .34027 .62639 L .3164 .63697 L p .707 .577 .707 r
F P
0 g
s
.36945 .52135 m .36819 .57767 L .33883 .57977 L p .707 .577 .707 r
F P
0 g
s
.36819 .57767 m .36945 .52135 L .40128 .52139 L p .707 .577 .707 r
F P
0 g
s
.34027 .62639 m .33763 .59173 L .36687 .58444 L p .707 .577 .707 r
F P
0 g
s
.40128 .52139 m .40002 .57772 L .36819 .57767 L p .707 .577 .707 r
F P
0 g
s
.32033 .66533 m .31737 .65044 L .34048 .63409 L p .707 .577 .707 r
F P
0 g
s
.4591 .62227 m .46205 .63716 L .43443 .63089 L p .707 .577 .707 r
F P
0 g
s
.40125 .6158 m .39862 .58115 L .42976 .58218 L p .707 .577 .707 r
F P
0 g
s
.36951 .61909 m .36687 .58444 L .39862 .58115 L p .707 .577 .707 r
F P
0 g
s
.36687 .58444 m .36951 .61909 L .34027 .62639 L p .707 .577 .707 r
F P
0 g
s
.39862 .58115 m .40125 .6158 L .36951 .61909 L p .707 .577 .707 r
F P
0 g
s
.34048 .63409 m .34343 .64898 L .32033 .66533 L p .707 .577 .707 r
F P
0 g
s
.34343 .64898 m .34048 .63409 L .36911 .62221 L p .707 .577 .707 r
F P
0 g
s
.37207 .6371 m .36911 .62221 L .40047 .61598 L p .707 .577 .707 r
F P
0 g
s
.36911 .62221 m .37207 .6371 L .34343 .64898 L p .707 .577 .707 r
F P
0 g
s
.40047 .61598 m .40342 .63086 L .37207 .6371 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002>Ool80027Ool0081oo`h0
0003FUH005YF00EJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001d
Ool007=oo`<000aJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001b
Ool006moo`@000mJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3
001_Ool006aoo`<001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP8006eoo`00JWoo0P0000=JEP00FUH04eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF0P00K7oo001XOol20003FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000JWoo001VOol20005FUH0
0`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000JGoo001UOol20006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJ
EP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001T
Ool00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo
001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001TOol00`00FUH0
0006FUH00`00FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF01=JEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF
00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00@005YFFUH0
00EJEP8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001WOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP8000UJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YF
FUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF
00000eYF00<005YFFUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF00000eYF00<005YF
FUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0009JEP03001JEUYF008000UJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH3001UOol005mooad000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Fgoo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001HOol30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000?OolA0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool80003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH8000mOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0031oo`00DWoo00<005YF000015YF00<005YF
FUH00eYF7@001UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001B
Ool00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUHC0002FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00<005YF00000UYF10000UYF00<0
05YFFUH01EYF200015YF00<005YFFUH01UYF00<005YF000020000eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP0000<000EJEP03001JEUYF009JEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@0009JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030002FUH40004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF0080
02ioo`00DWoo0P000eYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool0059oo`80
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF0000000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001C
Ool01P00FUIJEUYF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001JEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000hOolN000015YF000000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
=7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUHA0004FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP04001JEUYFFUH90007FUH900000eYF000000060003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@001EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP05FUH00`00FUH000050004FUH00`00FUIJ
EP02FUH800000eYF000000030004FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP060008FUH00`00FUIJEP06FUH20006FUH30003FUH00`00FUIJEP020004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJ
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH500001UYF0000
0000FUH000=JEP8002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF100000=JEP0000000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00UYF
00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF
00<000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
0004FUH000000003FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH20002FUH30005FUH0
0`00FUIJEP04FUH=0006FUH00`00FUIJEP030003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH200000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH200000eYF
0000000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH01000FUH000000eYF0P001eYF00<005YFFUH01`001UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH3
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05
001JEUYFFUIoo`03FUH01000FUIJEP000eYF0`000UYF0`001eYF10000UYF1@001UYF00<005YFFUH0
1EYF0`0015YF1@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP00009JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF00000000;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YF
FUH005YF0002FUH00`00FUIJEP03FUH30006FUH30007FUH00`00FUIJEP08FUH20002FUH01000FUH0
05YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00H005YF000005YF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP04001JEUYFOol4FUH00`00FUIJEP030003FUH20004FUH00`00FUH00003
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000015YF000005YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH01EYF
00<005YFFUH01eYF00<005YFFUH025YF0P000UYF0P0000AJEP00000000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP800004FUH005YFFUH20005FUH20002FUH01@00FUH005YF00001UYF00<005YF
FUH01eYF00<005YFFUH01eYF0`0015YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP03
FUH00`00FUH00002FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF00IJEP03001JEP00
00<0009JEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUH0
00000UYF00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01eYF0P000UYF100015YF00<005YF
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP03001JEUYF00P000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJ
EP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEQd0009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP0300000eYF001JEP05FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00=JEP@00006FUH00000001JEP002EYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YF00000`0000EJEP00FUIJEP0002moo`00:goo00<005YF000015YF00<005YF0000
0`001UYF200015YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00@005YF001JEP@00006FUH00000
001JEP001UYF00<005YFFUH01`001UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00H005YFFUH005YF0004FUH01000FUIJ
EUYF0P000UYF10000eYF00<005YFFUH01EYF30001EYF00@005YFFUIJEP@0009JEP03001oogoo02eo
o`00:goo00<005YF00000UYF10000UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0015YF00@005YFFUH000EJEPl000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00004FUH01000FUH000000eYF0P001eYF00<005YFFUH01`002Goo10000UYF00<005YFFUH0
0UYF0`0000=JEP00Ool0;Woo000[Ool00`00FUH000030005FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH30002FUH30008FUH3
0002Ool5000=Ool30005FUH200000eYF001oo`0^Ool002]oo`8000=JEP03001JEUYF00=JEP<000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH30003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YF
00000UYF00@005YFFUH000IJEP8000Eoo`D0011oo`8000=JEP@002moo`00:goo0P000eYF00@005YF
FUIJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0000000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEP00FUH005YF0P000UYF00<005YF000015YF00@005YFFUIJEP8000Qoo`<001=oo`05001JEUYF
001JEP03000^Ool002]oo`8000=JEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH005YF0`000eYF0P001EYF00<005YF00000P007Woo1@0000AJEP00
000002ioo`00;7oo00@005YFFUIJEP<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJ
EP03001JEUYF00@000EJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH005YF0`000UYF00<005YFFUH01EYF0P0000=JEP00000077oo0P0000EJEP00FUIJ
EP00009JEP8002ioo`00;Goo100000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`000UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF0`000eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP04001JEP000005FUH20003FUH2000JOol20003FUH01P00FUIJ
EUYF001JEP8002ioo`00;Woo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP<000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000002FUH200000eYF001JEP02FUH200000eYF001JEP02FUH2000GOol3
0005FUH00`00FUIJEP02FUH3000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPl000EJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00@000MJEP09001JEUYFFUH005YF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000002FUH20002FUH30003FUH01000FUIJEUYF0P004goo100000=JEP00FUH0
1EYF00<005YFFUH00UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008
FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH90004FUH01000FUIJEUYF2@002UYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEP000002FUH01000FUIJEUYF1`000eYF0P0037oo1`001EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP0Q0004FUH00`00FUIJEP020000
0gooFUIJEP090008FUH00`00FUIJEP08FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF000005YF0003FUH01000FUIJEP000eYF4P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00=JEP@000Eoo`D000AJEP03001JEUYF00IJEP800004FUH000000004Ool30000
0eYF001JEP02FUH01@00OomJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF0000
05YF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP0000AJEP04001JEUYFFUH20007
Ool30008FUH00`00FUIJEP06FUH01000FUH000000UYF0`0017oo0P000eYF00D007ooFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP<0009JEP03001JEUYF00EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00<0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP000Woo00<007ooOol0
;7oo000[Ool01000FUIJEP000eYF00@005YF000000Moo`80009JEP03001JEUYF00MJEP03001JEUYF
00IJEP800003FUH005YF009JEP<000Aoo`05001JEUYF001oo`02FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo00<005YF0000
;Goo000[Ool01000FUIJEP000eYF0P001goo0P001EYF00<005YFFUH015YF3`000eYF00<005YFFUH0
0P000Woo100000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo
00<005YF0000;Goo000[Ool01000FUIJEP000UYF00<007ooOol01Goo0P001eYF00<005YFFUH01P00
2goo00@005YF0000009JEP04001JEUYFFUH200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH01EYF00@005YFFUIJEP8000Ioo`03001JEP0002eoo`00:goo00<005YFFUH00`00
1goo0P001eYF10000Woo1@002goo00<005YF00000`0015YF0`0000=JEP0000000UYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00UYF0P001EYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP04001JEP000008Ool00`00FUH0000]Ool002aoo`03001JEP0000Qoo`03
001JEP0000EJEP8000Ioo`D000]oo`03001JEP0000800003Ool00000009JEP04001JEP00FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF0`002Goo0P0000=JEP00Ool0
;7oo000/Ool200000eYF001oo`04Ool20003FUH00`00FUH000020008Ool5000<Ool20002FUH50000
0eYF00000002FUH01000FUIJEP001UYF00<005YFFUH01eYF0`000eYF00@005YFFUIJEQh000QJEP03
001JEUYF00EJEP05001JEUYF001JEP020004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000;Ool01000FUH00000;Woo000/Ool20002FUH20002Ool00`00FUIJEP03FUH2000<
Ool3000=Ool20004FUH5000015YF001JEP000UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF
0`0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000ioo`05
001JEUYFFUH0000^Ool002aoo`06001JEUYFFUH005YF0P001EYF00<007ooOol06Woo1@0015YF00<0
05YF0000100000AooeYFFUH000IJEP03001JEP0000<0009JEP03001JEUYF00EJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00@000IJEP06001JEUYFFUH005YF1P001EYF00<005YF
00003`005Goo00D005YFFUIJEP0002ioo`00;7oo0P000UYF00@005YF000000AJEP03001oogoo01Mo
o`@0009JEP03001JEUYF0080009JEP03001JEUYF00=JEPd000IJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP06001JEUYFFUH005YF0`000goo
0P000eYF00@005YFFUH0029oo`05001JEUYFFUH0000_Ool002aoo`80009JEP800004FUH005YFFUH6
000?Ool70006FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH300000eYF001JEP02FUH00`00FUH00002FUH30002Ool200001EYF001JEUYF00008Goo00D0
05YFFUIJEP00031oo`00;7oo0P000UYF00@005YFFUIJEP<000EJEPl000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000003FUH30003FUH01000FUH0
00000Woo0P000UYF00<007ooOol07Goo0`000UYF00<007ooOol0;goo000]Ool00`00FUH00004FUH0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP040009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000UYF0`000eYF00@005YFFUIJEP80
009oo`03001JEP0001ioo`04001JEUYF0002FUH00`00Oomoo`0_Ool002eoo`8000AJEP04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0
00000goo3@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00P000UYF00<005YFFUH00UYF1@0077oo
0P0015YF0P00<Woo000^Ool01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo00<005YFFUH00`0000=JEP00FUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P000UYF10001EYF1@006Woo00<005YFFUH015YF00<007ooOol0<Goo000^
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P001Goo0P000UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00005
FUH00000001oo`020003FUH5000HOol30005FUH00`00Oomoo`0bOol002eoo`04001JEP000005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
1goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD0009JEP800006FUH005YFFUH0
05YF0`005Woo0P000UYF00<005YFFUH00UYF00<007ooOol0<goo000]Ool00`00FUH000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUH000002Goo00@005YF
FUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP000UYF1P0000AJEP00FUH0
01Aoo`8000EJEP04001JEP00000fOol002eoo`03001JEP00009oo`<00003FUH005YF00IJEP03001J
EUYF00IJEPD000AJEP03001JEUYF00AJEP<000Yoo`03001JEUYF008000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<000AJEP@0009JEP8000ioo`H000MJEP8003Qoo`00;Goo00<005YF
00001Goo0`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00<005YF00000P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0004FUH01000FUIJEUYF4P0015YF00<0
05YFFUH01EYF0P00>Goo000]Ool20009Ool40002FUH00`00FUIJEP06FUH<000@Ool2000015YF0000
000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUIJEP80009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003]oo`00;Goo0P003Goo40005Woo
00@005YF001JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP800003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003eoo`00;Woo00<007oo
Ool0<Goo00@005YFFUH0009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0006FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40010Ool002ioo`03001oogoo031o
o`05001JEUYFFUH00002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001eYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01000A7oo000^Ool00`00Oomo
o`0_Ool01@00FUIJEUYF000017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH015YF0`000goo3P00B7oo000^Ool2000^Ool30002FUH00`00Oomoo`05Ool30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP020006FUH00`00FUIJEP03FUH20005Ool00`00Oomoo`1COol002ioo`<002aoo`04001JEUYF
0002FUH00`00Oomoo`07Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH40007FUH01000FUIJEUYF0P001Woo00<005YF0000E7oo000_
Ool2000[Ool00`00FUIJEP02FUH2000<Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH01000FUH00000
27oo00<005YF0000E7oo000_Ool00`00FUH0000XOol20005FUH00`00Oomoo`0=Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050005FUH00`00
FUIJEP04FUH3000:Ool00`00FUH0001DOol0031oo`03001JEP0002Eoo`8000EJEP8001=oo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD00003FUH0000000<000AJEP03001J
EUYF00@000eoo`03001JEP0005Aoo`00<7oo00<005YF00000P008Goo0P0000=JEP00FUH00eYF00<0
07ooOol05goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P001UYF300047oo
0P0000=JEP00Ool0Dgoo000aOol20002FUH2000LOol30003FUH01@00FUIJEUYF000087oo2@001UYF
00<005YFFUH015YF6P005Woo00@005YF000005Eoo`00<Goo0P0015YF0`005Goo10001eYF0`00:Woo
3@005Woo0`005Woo00D005YFFUIJEP0005Eoo`00<Woo0P0015YF00<005YF00000`003Goo10000UYF
00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo00D005YFFUIJEP0005Eoo`00=7oo0P000UYF00<0
05YFFUH00eYF3@001UYF00<005YFFUH00eYF0P00=Woo00<007ooOol0<7oo00D005YFFUIJEP0005Io
o`00=Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00>7oo
00<007ooOol0;goo00D005YFFUIJEP0005Moo`00>7oo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF1000>goo0P00;Woo0`000UYF00<007ooOol0EWoo000kOol400000eYF001JEP07FUH00`00FUIJ
EP04000oOol00`00FUH0000/Ool01000FUIJEP000UYF00<007ooOol0EWoo000oOol=0014Ool00`00
FUH0000YOol20004FUH2001IOol0091oo`04001JEUYF000WOol00`00FUIJEP04FUH00`00Oomoo`1H
Ool0095oo`03001JEP00008002=oo`<000EJEP03001oogoo05Uoo`00TWoo0P000UYF00<007ooOol0
7Woo0P000UYF00<005YFFUH00UYF00<007ooOol0FWoo002BOol00`00FUH00002FUH2000LOol20005
FUH01000FUH00000GGoo002COol20004FUH4000BOol60007FUH2001OOol009Aoo`03001JEUYF009J
EP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH2001POol009Eoo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Ugoo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P00I7oo002IOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH4001WOol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@006]oo`00
X7oo3P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59381 .74531 m .59459 .68924 L .56341 .68717 L p .707 .577 .707 r
F P
0 g
s
.59459 .68924 m .59381 .74531 L .62564 .74504 L p .707 .577 .707 r
F P
0 g
s
.62564 .74504 m .62642 .68897 L .59459 .68924 L p .707 .577 .707 r
F P
0 g
s
.62642 .68897 m .62564 .74504 L .65502 .74245 L p .707 .577 .707 r
F P
0 g
s
.65502 .74245 m .65579 .68639 L .62642 .68897 L p .707 .577 .707 r
F P
0 g
s
.56264 .74323 m .56341 .68717 L .53596 .68295 L p .707 .577 .707 r
F P
0 g
s
.56341 .68717 m .56264 .74323 L .59381 .74531 L p .707 .577 .707 r
F P
0 g
s
.65579 .68639 m .65502 .74245 L .67907 .7378 L p .707 .577 .707 r
F P
0 g
s
.67907 .7378 m .67984 .68174 L .65579 .68639 L p .707 .577 .707 r
F P
0 g
s
.53596 .68295 m .53518 .73902 L .56264 .74323 L p .707 .577 .707 r
F P
0 g
s
.53518 .73902 m .53596 .68295 L .5149 .67701 L p .707 .577 .707 r
F P
0 g
s
.59513 .81782 m .5935 .7821 L .56234 .78074 L p .707 .577 .707 r
F P
0 g
s
.5935 .7821 m .59513 .81782 L .62693 .81547 L p .707 .577 .707 r
F P
0 g
s
.62693 .81547 m .6253 .77975 L .5935 .7821 L p .707 .577 .707 r
F P
0 g
s
.6253 .77975 m .62693 .81547 L .65626 .80964 L p .707 .577 .707 r
F P
0 g
s
.65626 .80964 m .65462 .77392 L .6253 .77975 L p .707 .577 .707 r
F P
0 g
s
.56397 .81646 m .56234 .78074 L .53487 .77581 L p .707 .577 .707 r
F P
0 g
s
.56234 .78074 m .56397 .81646 L .59513 .81782 L p .707 .577 .707 r
F P
0 g
s
.67984 .68174 m .67907 .7378 L .69543 .73154 L p .707 .577 .707 r
F P
0 g
s
.69543 .73154 m .6962 .67547 L .67984 .68174 L p .707 .577 .707 r
F P
0 g
s
.5149 .67701 m .51412 .73307 L .53518 .73902 L p .707 .577 .707 r
F P
0 g
s
.65462 .77392 m .65626 .80964 L .68024 .8009 L p .707 .577 .707 r
F P
0 g
s
.68024 .8009 m .67861 .76518 L .65462 .77392 L p .707 .577 .707 r
F P
0 g
s
.53487 .77581 m .5365 .81153 L .56397 .81646 L p .707 .577 .707 r
F P
0 g
s
.5365 .81153 m .53487 .77581 L .51378 .76778 L p .707 .577 .707 r
F P
0 g
s
.51412 .73307 m .5149 .67701 L .5023 .66991 L p .707 .577 .707 r
F P
0 g
s
.59911 .87254 m .59725 .85589 L .56614 .85521 L p .707 .577 .707 r
F P
0 g
s
.59725 .85589 m .59911 .87254 L .63076 .86824 L p .707 .577 .707 r
F P
0 g
s
.63076 .86824 m .6289 .8516 L .59725 .85589 L p .707 .577 .707 r
F P
0 g
s
.6289 .8516 m .63076 .86824 L .65985 .85939 L p .707 .577 .707 r
F P
0 g
s
.65985 .85939 m .65799 .84275 L .6289 .8516 L p .707 .577 .707 r
F P
0 g
s
.67861 .76518 m .68024 .8009 L .69653 .7901 L p .707 .577 .707 r
F P
0 g
s
.69653 .7901 m .6949 .75439 L .67861 .76518 L p .707 .577 .707 r
F P
0 g
s
.5023 .66991 m .50152 .72598 L .51412 .73307 L p .707 .577 .707 r
F P
0 g
s
.51378 .76778 m .51541 .8035 L .5365 .81153 L p .707 .577 .707 r
F P
0 g
s
.568 .87185 m .56614 .85521 L .53862 .8496 L p .707 .577 .707 r
F P
0 g
s
.56614 .85521 m .568 .87185 L .59911 .87254 L p .707 .577 .707 r
F P
0 g
s
.6962 .67547 m .69543 .73154 L .7025 .72428 L p .707 .577 .707 r
F P
0 g
s
.7025 .72428 m .70328 .66822 L .6962 .67547 L p .707 .577 .707 r
F P
0 g
s
.65799 .84275 m .65985 .85939 L .68354 .84684 L p .707 .577 .707 r
F P
0 g
s
.68354 .84684 m .68168 .8302 L .65799 .84275 L p .707 .577 .707 r
F P
0 g
s
.51541 .8035 m .51378 .76778 L .50113 .75744 L p .707 .577 .707 r
F P
0 g
s
.53862 .8496 m .54048 .86624 L .568 .87185 L p .707 .577 .707 r
F P
0 g
s
.50152 .72598 m .5023 .66991 L .4994 .66237 L p .707 .577 .707 r
F P
0 g
s
.54048 .86624 m .53862 .8496 L .51737 .83963 L p .707 .577 .707 r
F P
0 g
s
.6949 .75439 m .69653 .7901 L .70354 .77831 L p .707 .577 .707 r
F P
0 g
s
.70354 .77831 m .70191 .7426 L .6949 .75439 L p .707 .577 .707 r
F P
0 g
s
.68168 .8302 m .68354 .84684 L .6995 .83182 L p .707 .577 .707 r
F P
0 g
s
.6995 .83182 m .69764 .81518 L .68168 .8302 L p .707 .577 .707 r
F P
0 g
s
.50113 .75744 m .50276 .79316 L .51541 .8035 L p .707 .577 .707 r
F P
0 g
s
.51737 .83963 m .51923 .85627 L .54048 .86624 L p .707 .577 .707 r
F P
0 g
s
.4994 .66237 m .49862 .71843 L .50152 .72598 L p .707 .577 .707 r
F P
0 g
s
.70328 .66822 m .7025 .72428 L .6996 .71674 L p .707 .577 .707 r
F P
0 g
s
.6996 .71674 m .70037 .66067 L .70328 .66822 L p .707 .577 .707 r
F P
0 g
s
.50276 .79316 m .50113 .75744 L .49816 .74581 L p .707 .577 .707 r
F P
0 g
s
.51923 .85627 m .51737 .83963 L .50449 .82627 L p .707 .577 .707 r
F P
0 g
s
.49462 .82353 m .48781 .32652 L .4438 .32408 L p .707 .577 .707 r
F P
0 g
s
.49862 .71843 m .4994 .66237 L .50647 .65511 L p .707 .577 .707 r
F P
0 g
s
.49816 .74581 m .49979 .78153 L .50276 .79316 L p .707 .577 .707 r
F P
0 g
s
.50647 .65511 m .5057 .71118 L .49862 .71843 L p .707 .577 .707 r
F P
0 g
s
.50635 .84291 m .50449 .82627 L .50123 .81083 L p .707 .577 .707 r
F P
0 g
s
.49979 .78153 m .49816 .74581 L .50517 .73402 L p .707 .577 .707 r
F P
0 g
s
.50123 .81083 m .50309 .82747 L .50635 .84291 L p .707 .577 .707 r
F P
0 g
s
.5057 .71118 m .50647 .65511 L .52283 .64885 L p .707 .577 .707 r
F P
0 g
s
.50517 .73402 m .5068 .76974 L .49979 .78153 L p .707 .577 .707 r
F P
0 g
s
.52283 .64885 m .52206 .70491 L .5057 .71118 L p .707 .577 .707 r
F P
0 g
s
.50309 .82747 m .50123 .81083 L .50791 .79482 L p .707 .577 .707 r
F P
0 g
s
.5068 .76974 m .50517 .73402 L .52146 .72323 L p .707 .577 .707 r
F P
0 g
s
.50791 .79482 m .50977 .81146 L .50309 .82747 L p .707 .577 .707 r
F P
0 g
s
.52206 .70491 m .52283 .64885 L .54688 .6442 L p .707 .577 .707 r
F P
0 g
s
.52146 .72323 m .52309 .75895 L .5068 .76974 L p .707 .577 .707 r
F P
0 g
s
.54688 .6442 m .5461 .70026 L .52206 .70491 L p .707 .577 .707 r
F P
0 g
s
.50977 .81146 m .50791 .79482 L .52387 .7798 L p .707 .577 .707 r
F P
0 g
s
.52309 .75895 m .52146 .72323 L .54544 .71449 L p .707 .577 .707 r
F P
0 g
s
.52387 .7798 m .52573 .79645 L .50977 .81146 L p .707 .577 .707 r
F P
0 g
s
.54544 .71449 m .54708 .75021 L .52309 .75895 L p .707 .577 .707 r
F P
0 g
s
.52573 .79645 m .52387 .7798 L .54756 .76726 L p .707 .577 .707 r
F P
0 g
s
.54756 .76726 m .54942 .7839 L .52573 .79645 L p .707 .577 .707 r
F P
0 g
s
.48781 .32652 m .49462 .82353 L .53956 .82174 L p .707 .577 .707 r
F P
0 g
s
.53956 .82174 m .53274 .32474 L .48781 .32652 L p .707 .577 .707 r
F P
0 g
s
.69764 .81518 m .6995 .83182 L .70618 .81581 L p .707 .577 .707 r
F P
0 g
s
.70618 .81581 m .70432 .79917 L .69764 .81518 L p .707 .577 .707 r
F P
0 g
s
.5461 .70026 m .54688 .6442 L .57625 .64161 L p .707 .577 .707 r
F P
0 g
s
.57625 .64161 m .57548 .69767 L .5461 .70026 L p .707 .577 .707 r
F P
0 g
s
.54708 .75021 m .54544 .71449 L .57477 .70866 L p .707 .577 .707 r
F P
0 g
s
.57477 .70866 m .5764 .74437 L .54708 .75021 L p .707 .577 .707 r
F P
0 g
s
.54942 .7839 m .54756 .76726 L .57666 .7584 L p .707 .577 .707 r
F P
0 g
s
.57666 .7584 m .57852 .77504 L .54942 .7839 L p .707 .577 .707 r
F P
0 g
s
.53274 .32474 m .53956 .82174 L .58103 .81589 L p .707 .577 .707 r
F P
0 g
s
.57548 .69767 m .57625 .64161 L .60809 .64134 L p .707 .577 .707 r
F P
0 g
s
.60809 .64134 m .60731 .69741 L .57548 .69767 L p .707 .577 .707 r
F P
0 g
s
.5764 .74437 m .57477 .70866 L .60657 .70631 L p .707 .577 .707 r
F P
0 g
s
.60657 .70631 m .6082 .74202 L .5764 .74437 L p .707 .577 .707 r
F P
0 g
s
.57852 .77504 m .57666 .7584 L .60831 .75411 L p .707 .577 .707 r
F P
0 g
s
.60831 .75411 m .61016 .77075 L .57852 .77504 L p .707 .577 .707 r
F P
0 g
s
.58103 .81589 m .57422 .31889 L .53274 .32474 L p .707 .577 .707 r
F P
0 g
s
.50449 .82627 m .50635 .84291 L .51923 .85627 L p .707 .577 .707 r
F P
0 g
s
.70191 .7426 m .70354 .77831 L .70057 .76668 L p .707 .577 .707 r
F P
0 g
s
.70057 .76668 m .69894 .73096 L .70191 .7426 L p .707 .577 .707 r
F P
0 g
s
.45061 .82108 m .4438 .32408 L .40503 .31764 L p .707 .577 .707 r
F P
0 g
s
.4438 .32408 m .45061 .82108 L .49462 .82353 L p .707 .577 .707 r
F P
0 g
s
.63773 .70766 m .63936 .74338 L .6082 .74202 L p .707 .577 .707 r
F P
0 g
s
.6082 .74202 m .60657 .70631 L .63773 .70766 L p .707 .577 .707 r
F P
0 g
s
.63941 .7548 m .64127 .77144 L .61016 .77075 L p .707 .577 .707 r
F P
0 g
s
.61016 .77075 m .60831 .75411 L .63941 .7548 L p .707 .577 .707 r
F P
0 g
s
.57422 .31889 m .58103 .81589 L .61498 .80656 L p .707 .577 .707 r
F P
0 g
s
.63926 .64342 m .63848 .69948 L .60731 .69741 L p .707 .577 .707 r
F P
0 g
s
.60731 .69741 m .60809 .64134 L .63926 .64342 L p .707 .577 .707 r
F P
0 g
s
.61498 .80656 m .60817 .30955 L .57422 .31889 L p .707 .577 .707 r
F P
0 g
s
.70037 .66067 m .6996 .71674 L .687 .70964 L p .707 .577 .707 r
F P
0 g
s
.687 .70964 m .68778 .65358 L .70037 .66067 L p .707 .577 .707 r
F P
0 g
s
.70432 .79917 m .70618 .81581 L .70292 .80037 L p .707 .577 .707 r
F P
0 g
s
.70292 .80037 m .70106 .78373 L .70432 .79917 L p .707 .577 .707 r
F P
0 g
s
.2508 .70849 m .25158 .65243 L .22041 .65035 L p .707 .577 .707 r
F P
0 g
s
.25158 .65243 m .2508 .70849 L .28263 .70823 L p .707 .577 .707 r
F P
0 g
s
.28263 .70823 m .28341 .65216 L .25158 .65243 L p .707 .577 .707 r
F P
0 g
s
.41185 .81465 m .40503 .31764 L .3753 .30784 L p .707 .577 .707 r
F P
0 g
s
.40503 .31764 m .41185 .81465 L .45061 .82108 L p .707 .577 .707 r
F P
0 g
s
.28341 .65216 m .28263 .70823 L .31201 .70564 L p .707 .577 .707 r
F P
0 g
s
.31201 .70564 m .31279 .64957 L .28341 .65216 L p .707 .577 .707 r
F P
0 g
s
.21963 .70642 m .22041 .65035 L .19295 .64614 L p .707 .577 .707 r
F P
0 g
s
.22041 .65035 m .21963 .70642 L .2508 .70849 L p .707 .577 .707 r
F P
0 g
s
.69894 .73096 m .70057 .76668 L .68793 .75634 L p .707 .577 .707 r
F P
0 g
s
.68793 .75634 m .68629 .72063 L .69894 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31279 .64957 m .31201 .70564 L .33606 .70099 L p .707 .577 .707 r
F P
0 g
s
.33606 .70099 m .33683 .64492 L .31279 .64957 L p .707 .577 .707 r
F P
0 g
s
.60817 .30955 m .61498 .80656 L .63808 .79465 L p .707 .577 .707 r
F P
0 g
s
.63808 .79465 m .63127 .29765 L .60817 .30955 L p .707 .577 .707 r
F P
0 g
s
.68778 .65358 m .687 .70964 L .66594 .7037 L p .707 .577 .707 r
F P
0 g
s
.66594 .7037 m .66672 .64763 L .68778 .65358 L p .707 .577 .707 r
F P
0 g
s
.19295 .64614 m .19217 .7022 L .21963 .70642 L p .707 .577 .707 r
F P
0 g
s
.19217 .7022 m .19295 .64614 L .17189 .64019 L p .707 .577 .707 r
F P
0 g
s
.25212 .781 m .25049 .74529 L .21933 .74393 L p .707 .577 .707 r
F P
0 g
s
.25049 .74529 m .25212 .781 L .28392 .77865 L p .707 .577 .707 r
F P
0 g
s
.28392 .77865 m .28229 .74294 L .25049 .74529 L p .707 .577 .707 r
F P
0 g
s
.28229 .74294 m .28392 .77865 L .31325 .77282 L p .707 .577 .707 r
F P
0 g
s
.31325 .77282 m .31161 .7371 L .28229 .74294 L p .707 .577 .707 r
F P
0 g
s
.70106 .78373 m .70292 .80037 L .69004 .78701 L p .707 .577 .707 r
F P
0 g
s
.69004 .78701 m .68818 .77037 L .70106 .78373 L p .707 .577 .707 r
F P
0 g
s
.22096 .77965 m .21933 .74393 L .19186 .73899 L p .707 .577 .707 r
F P
0 g
s
.21933 .74393 m .22096 .77965 L .25212 .781 L p .707 .577 .707 r
F P
0 g
s
.38212 .80484 m .3753 .30784 L .35752 .29563 L p .707 .577 .707 r
F P
0 g
s
.3753 .30784 m .38212 .80484 L .41185 .81465 L p .707 .577 .707 r
F P
0 g
s
.68629 .72063 m .68793 .75634 L .66683 .74832 L p .707 .577 .707 r
F P
0 g
s
.66683 .74832 m .6652 .7126 L .68629 .72063 L p .707 .577 .707 r
F P
0 g
s
.33683 .64492 m .33606 .70099 L .35242 .69472 L p .707 .577 .707 r
F P
0 g
s
.35242 .69472 m .35319 .63866 L .33683 .64492 L p .707 .577 .707 r
F P
0 g
s
.17189 .64019 m .17111 .69626 L .19217 .7022 L p .707 .577 .707 r
F P
0 g
s
.31161 .7371 m .31325 .77282 L .33723 .76408 L p .707 .577 .707 r
F P
0 g
s
.33723 .76408 m .3356 .72836 L .31161 .7371 L p .707 .577 .707 r
F P
0 g
s
.66672 .64763 m .66594 .7037 L .63848 .69948 L p .707 .577 .707 r
F P
0 g
s
.63848 .69948 m .63926 .64342 L .66672 .64763 L p .707 .577 .707 r
F P
0 g
s
.19186 .73899 m .19349 .77471 L .22096 .77965 L p .707 .577 .707 r
F P
0 g
s
.19349 .77471 m .19186 .73899 L .17077 .73097 L p .707 .577 .707 r
F P
0 g
s
.17111 .69626 m .17189 .64019 L .15929 .6331 L p .707 .577 .707 r
F P
0 g
s
.2561 .83572 m .25424 .81908 L .22313 .81839 L p .707 .577 .707 r
F P
0 g
s
.25424 .81908 m .2561 .83572 L .28775 .83143 L p .707 .577 .707 r
F P
0 g
s
.28775 .83143 m .28589 .81479 L .25424 .81908 L p .707 .577 .707 r
F P
0 g
s
.68818 .77037 m .69004 .78701 L .6688 .77704 L p .707 .577 .707 r
F P
0 g
s
.6688 .77704 m .66694 .7604 L .68818 .77037 L p .707 .577 .707 r
F P
0 g
s
.28589 .81479 m .28775 .83143 L .31684 .82257 L p .707 .577 .707 r
F P
0 g
s
.31684 .82257 m .31498 .80593 L .28589 .81479 L p .707 .577 .707 r
F P
0 g
s
.6652 .7126 m .66683 .74832 L .63936 .74338 L p .707 .577 .707 r
F P
0 g
s
.63936 .74338 m .63773 .70766 L .6652 .7126 L p .707 .577 .707 r
F P
0 g
s
.66694 .7604 m .6688 .77704 L .64127 .77144 L p .707 .577 .707 r
F P
0 g
s
.64127 .77144 m .63941 .7548 L .66694 .7604 L p .707 .577 .707 r
F P
0 g
s
.63127 .29765 m .63808 .79465 L .64807 .78134 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64125 .28433 L .63127 .29765 L p .707 .577 .707 r
F P
0 g
s
.3356 .72836 m .33723 .76408 L .35352 .75329 L p .707 .577 .707 r
F P
0 g
s
.35352 .75329 m .35189 .71757 L .3356 .72836 L p .707 .577 .707 r
F P
0 g
s
.15929 .6331 m .15851 .68916 L .17111 .69626 L p .707 .577 .707 r
F P
0 g
s
.17077 .73097 m .1724 .76668 L .19349 .77471 L p .707 .577 .707 r
F P
0 g
s
.22499 .83503 m .22313 .81839 L .19561 .81279 L p .707 .577 .707 r
F P
0 g
s
.22313 .81839 m .22499 .83503 L .2561 .83572 L p .707 .577 .707 r
F P
0 g
s
.35319 .63866 m .35242 .69472 L .35949 .68747 L p .707 .577 .707 r
F P
0 g
s
.35949 .68747 m .36027 .6314 L .35319 .63866 L p .707 .577 .707 r
F P
0 g
s
.31498 .80593 m .31684 .82257 L .34053 .81002 L p .707 .577 .707 r
F P
0 g
s
.34053 .81002 m .33867 .79338 L .31498 .80593 L p .707 .577 .707 r
F P
0 g
s
.1724 .76668 m .17077 .73097 L .15812 .72063 L p .707 .577 .707 r
F P
0 g
s
.19561 .81279 m .19747 .82943 L .22499 .83503 L p .707 .577 .707 r
F P
0 g
s
.36433 .79263 m .35752 .29563 L .35342 .28221 L p .707 .577 .707 r
F P
0 g
s
.35752 .29563 m .36433 .79263 L .38212 .80484 L p .707 .577 .707 r
F P
0 g
s
.15851 .68916 m .15929 .6331 L .15639 .62555 L p .707 .577 .707 r
F P
0 g
s
.19747 .82943 m .19561 .81279 L .17437 .80282 L p .707 .577 .707 r
F P
0 g
s
.35189 .71757 m .35352 .75329 L .36053 .7415 L p .707 .577 .707 r
F P
0 g
s
.36053 .7415 m .3589 .70578 L .35189 .71757 L p .707 .577 .707 r
F P
0 g
s
.33867 .79338 m .34053 .81002 L .35649 .79501 L p .707 .577 .707 r
F P
0 g
s
.35649 .79501 m .35463 .77837 L .33867 .79338 L p .707 .577 .707 r
F P
0 g
s
.15812 .72063 m .15975 .75635 L .1724 .76668 L p .707 .577 .707 r
F P
0 g
s
.17437 .80282 m .17622 .81946 L .19747 .82943 L p .707 .577 .707 r
F P
0 g
s
.15639 .62555 m .15561 .68162 L .15851 .68916 L p .707 .577 .707 r
F P
0 g
s
.36027 .6314 m .35949 .68747 L .35659 .67992 L p .707 .577 .707 r
F P
0 g
s
.35659 .67992 m .35737 .62385 L .36027 .6314 L p .707 .577 .707 r
F P
0 g
s
.15975 .75635 m .15812 .72063 L .15515 .709 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64397 .76792 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64199 .33829 m .64807 .78134 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64125 .28433 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64397 .76792 m .64113 .56075 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64113 .56075 m .63716 .27091 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64397 .76792 L .62619 .75571 L p .707 .577 .707 r
F P
0 g
s
.63833 .67198 m .63996 .7077 L .64056 .70819 L p .707 .577 .707 r
F P
0 g
s
.64056 .70819 m .65261 .71804 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.64067 .67952 m .63833 .67198 L .64056 .70819 L .707 .577 .707 r
F
.65261 .71804 m .65098 .68232 L .64069 .67391 L p F P
0 g
s
.64069 .67391 m .63833 .67198 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.65261 .71804 m .64069 .67391 L .64067 .67952 L .707 .577 .707 r
F
.64125 .28433 m .64199 .33829 L p .64182 .38426 L F P
0 g
s
.17622 .81946 m .17437 .80282 L .16148 .78946 L p .707 .577 .707 r
F P
0 g
s
.35463 .77837 m .35649 .79501 L .36317 .779 L p .707 .577 .707 r
F P
0 g
s
.36317 .779 m .36131 .76236 L .35463 .77837 L p .707 .577 .707 r
F P
0 g
s
.15561 .68162 m .15639 .62555 L .16346 .61829 L p .707 .577 .707 r
F P
0 g
s
.16148 .78946 m .16334 .8061 L .17622 .81946 L p .707 .577 .707 r
F P
0 g
s
.15515 .709 m .15679 .74471 L .15975 .75635 L p .707 .577 .707 r
F P
0 g
s
.3589 .70578 m .36053 .7415 L .35756 .72987 L p .707 .577 .707 r
F P
0 g
s
.35756 .72987 m .35593 .69415 L .3589 .70578 L p .707 .577 .707 r
F P
0 g
s
.36131 .76236 m .36317 .779 L .35991 .76356 L p .707 .577 .707 r
F P
0 g
s
.35991 .76356 m .35805 .74692 L .36131 .76236 L p .707 .577 .707 r
F P
0 g
s
.35342 .28221 m .36024 .77922 L .36433 .79263 L p .707 .577 .707 r
F P
0 g
s
.36024 .77922 m .35342 .28221 L .36341 .2689 L p .707 .577 .707 r
F P
0 g
s
.16346 .61829 m .16269 .67436 L .15561 .68162 L p .707 .577 .707 r
F P
0 g
s
.16334 .8061 m .16148 .78946 L .15822 .77402 L p .707 .577 .707 r
F P
0 g
s
.35737 .62385 m .35659 .67992 L .34399 .67283 L p .707 .577 .707 r
F P
0 g
s
.34399 .67283 m .34477 .61676 L .35737 .62385 L p .707 .577 .707 r
F P
0 g
s
.15679 .74471 m .15515 .709 L .16216 .69721 L p .707 .577 .707 r
F P
0 g
s
.15822 .77402 m .16008 .79066 L .16334 .8061 L p .707 .577 .707 r
F P
0 g
s
.16269 .67436 m .16346 .61829 L .17982 .61203 L p .707 .577 .707 r
F P
0 g
s
.16216 .69721 m .16379 .73292 L .15679 .74471 L p .707 .577 .707 r
F P
0 g
s
.35593 .69415 m .35756 .72987 L .34492 .71953 L p .707 .577 .707 r
F P
0 g
s
.34492 .71953 m .34328 .68381 L .35593 .69415 L p .707 .577 .707 r
F P
0 g
s
.62619 .75571 m .61937 .2587 L .63716 .27091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17982 .61203 m .17905 .6681 L .16269 .67436 L p .707 .577 .707 r
F P
0 g
s
.16008 .79066 m .15822 .77402 L .1649 .758 L p .707 .577 .707 r
F P
0 g
s
.34477 .61676 m .34399 .67283 L .32293 .66688 L p .707 .577 .707 r
F P
0 g
s
.32293 .66688 m .32371 .61082 L .34477 .61676 L p .707 .577 .707 r
F P
0 g
s
.16379 .73292 m .16216 .69721 L .17845 .68641 L p .707 .577 .707 r
F P
0 g
s
.37022 .7659 m .36341 .2689 L .38651 .25699 L p .707 .577 .707 r
F P
0 g
s
.36341 .2689 m .37022 .7659 L .36024 .77922 L p .707 .577 .707 r
F P
0 g
s
.35805 .74692 m .35991 .76356 L .34703 .7502 L p .707 .577 .707 r
F P
0 g
s
.34703 .7502 m .34517 .73356 L .35805 .74692 L p .707 .577 .707 r
F P
0 g
s
.1649 .758 m .16676 .77465 L .16008 .79066 L p .707 .577 .707 r
F P
0 g
s
.17905 .6681 m .17982 .61203 L .20387 .60738 L p .707 .577 .707 r
F P
0 g
s
.34328 .68381 m .34492 .71953 L .32383 .7115 L p .707 .577 .707 r
F P
0 g
s
.32383 .7115 m .32219 .67578 L .34328 .68381 L p .707 .577 .707 r
F P
0 g
s
.17845 .68641 m .18008 .72213 L .16379 .73292 L p .707 .577 .707 r
F P
0 g
s
.32371 .61082 m .32293 .66688 L .29547 .66267 L p .707 .577 .707 r
F P
0 g
s
.29547 .66267 m .29625 .6066 L .32371 .61082 L p .707 .577 .707 r
F P
0 g
s
.20387 .60738 m .20309 .66345 L .17905 .6681 L p .707 .577 .707 r
F P
0 g
s
.16676 .77465 m .1649 .758 L .18087 .74299 L p .707 .577 .707 r
F P
0 g
s
.18008 .72213 m .17845 .68641 L .20243 .67767 L p .707 .577 .707 r
F P
0 g
s
.61937 .2587 m .62619 .75571 L .59646 .74591 L p .707 .577 .707 r
F P
0 g
s
.59646 .74591 m .58964 .2489 L .61937 .2587 L p .707 .577 .707 r
F P
0 g
s
.20309 .66345 m .20387 .60738 L .23325 .60479 L p .707 .577 .707 r
F P
0 g
s
.34517 .73356 m .34703 .7502 L .32579 .74023 L p .707 .577 .707 r
F P
0 g
s
.32579 .74023 m .32393 .72359 L .34517 .73356 L p .707 .577 .707 r
F P
0 g
s
.18087 .74299 m .18272 .75963 L .16676 .77465 L p .707 .577 .707 r
F P
0 g
s
.32219 .67578 m .32383 .7115 L .29636 .70657 L p .707 .577 .707 r
F P
0 g
s
.29636 .70657 m .29472 .67085 L .32219 .67578 L p .707 .577 .707 r
F P
0 g
s
.29625 .6066 m .29547 .66267 L .2643 .66059 L p .707 .577 .707 r
F P
0 g
s
.2643 .66059 m .26508 .60452 L .29625 .6066 L p .707 .577 .707 r
F P
0 g
s
.20243 .67767 m .20407 .71339 L .18008 .72213 L p .707 .577 .707 r
F P
0 g
s
.23247 .66086 m .23325 .60479 L .26508 .60452 L p .707 .577 .707 r
F P
0 g
s
.23325 .60479 m .23247 .66086 L .20309 .66345 L p .707 .577 .707 r
F P
0 g
s
.38651 .25699 m .39332 .75399 L .37022 .7659 L p .707 .577 .707 r
F P
0 g
s
.39332 .75399 m .38651 .25699 L .42046 .24765 L p .707 .577 .707 r
F P
0 g
s
.26508 .60452 m .2643 .66059 L .23247 .66086 L p .707 .577 .707 r
F P
0 g
s
.20407 .71339 m .20243 .67767 L .23176 .67184 L p .707 .577 .707 r
F P
0 g
s
.73101 .65794 m .73179 .60187 L .70062 .5998 L p .707 .577 .707 r
F P
0 g
s
.73179 .60187 m .73101 .65794 L .76285 .65767 L p .707 .577 .707 r
F P
0 g
s
.76285 .65767 m .76362 .60161 L .73179 .60187 L p .707 .577 .707 r
F P
0 g
s
.18272 .75963 m .18087 .74299 L .20455 .73044 L p .707 .577 .707 r
F P
0 g
s
.76362 .60161 m .76285 .65767 L .79222 .65508 L p .707 .577 .707 r
F P
0 g
s
.79222 .65508 m .793 .59902 L .76362 .60161 L p .707 .577 .707 r
F P
0 g
s
.29472 .67085 m .29636 .70657 L .26519 .70521 L p .707 .577 .707 r
F P
0 g
s
.26519 .70521 m .26356 .66949 L .29472 .67085 L p .707 .577 .707 r
F P
0 g
s
.69984 .65586 m .70062 .5998 L .67316 .59558 L p .707 .577 .707 r
F P
0 g
s
.70062 .5998 m .69984 .65586 L .73101 .65794 L p .707 .577 .707 r
F P
0 g
s
.32393 .72359 m .32579 .74023 L .29826 .73462 L p .707 .577 .707 r
F P
0 g
s
.29826 .73462 m .2964 .71798 L .32393 .72359 L p .707 .577 .707 r
F P
0 g
s
.23339 .70756 m .23176 .67184 L .26356 .66949 L p .707 .577 .707 r
F P
0 g
s
.23176 .67184 m .23339 .70756 L .20407 .71339 L p .707 .577 .707 r
F P
0 g
s
.20455 .73044 m .20641 .74708 L .18272 .75963 L p .707 .577 .707 r
F P
0 g
s
.58964 .2489 m .59646 .74591 L .55769 .73947 L p .707 .577 .707 r
F P
0 g
s
.55769 .73947 m .55088 .24246 L .58964 .2489 L p .707 .577 .707 r
F P
0 g
s
.26356 .66949 m .26519 .70521 L .23339 .70756 L p .707 .577 .707 r
F P
0 g
s
.793 .59902 m .79222 .65508 L .81627 .65043 L p .707 .577 .707 r
F P
0 g
s
.81627 .65043 m .81705 .59437 L .793 .59902 L p .707 .577 .707 r
F P
0 g
s
.20641 .74708 m .20455 .73044 L .23365 .72159 L p .707 .577 .707 r
F P
0 g
s
.67316 .59558 m .67238 .65165 L .69984 .65586 L p .707 .577 .707 r
F P
0 g
s
.67238 .65165 m .67316 .59558 L .6521 .58964 L p .707 .577 .707 r
F P
0 g
s
.2964 .71798 m .29826 .73462 L .26716 .73394 L p .707 .577 .707 r
F P
0 g
s
.26716 .73394 m .2653 .71729 L .2964 .71798 L p .707 .577 .707 r
F P
0 g
s
.73233 .73236 m .7307 .69664 L .69954 .69528 L p .707 .577 .707 r
F P
0 g
s
.7307 .69664 m .73233 .73236 L .76413 .73001 L p .707 .577 .707 r
F P
0 g
s
.76413 .73001 m .7625 .69429 L .7307 .69664 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .42046 .24765 L .46193 .24181 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .39332 .75399 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.42443 .53749 m .42727 .74466 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.46193 .24181 m .46875 .73881 L .42727 .74466 L p .707 .577 .707 r
F P
0 g
s
.41949 .65747 m .42112 .69319 L .44907 .68763 L p .707 .577 .707 r
F P
0 g
s
.44907 .68763 m .45045 .68736 L p .44876 .68573 L .707 .577 .707 r
F P
0 g
s
.44876 .68573 m .41949 .65747 L .44907 .68763 L .707 .577 .707 r
F
.42046 .24765 m .42443 .53749 L p .40973 .4479 L F P
0 g
s
.7625 .69429 m .76413 .73001 L .79346 .72417 L p .707 .577 .707 r
F P
0 g
s
.79346 .72417 m .79183 .68846 L .7625 .69429 L p .707 .577 .707 r
F P
0 g
s
.23365 .72159 m .23551 .73823 L .20641 .74708 L p .707 .577 .707 r
F P
0 g
s
.23551 .73823 m .23365 .72159 L .2653 .71729 L p .707 .577 .707 r
F P
0 g
s
.70117 .731 m .69954 .69528 L .67207 .69035 L p .707 .577 .707 r
F P
0 g
s
.69954 .69528 m .70117 .731 L .73233 .73236 L p .707 .577 .707 r
F P
0 g
s
.2653 .71729 m .26716 .73394 L .23551 .73823 L p .707 .577 .707 r
F P
0 g
s
.55088 .24246 m .55769 .73947 L .51368 .73702 L p .707 .577 .707 r
F P
0 g
s
.51368 .73702 m .50687 .24002 L .55088 .24246 L p .707 .577 .707 r
F P
0 g
s
.81705 .59437 m .81627 .65043 L .83263 .64417 L p .707 .577 .707 r
F P
0 g
s
.83263 .64417 m .83341 .5881 L .81705 .59437 L p .707 .577 .707 r
F P
0 g
s
.6521 .58964 m .65133 .6457 L .67238 .65165 L p .707 .577 .707 r
F P
0 g
s
.79183 .68846 m .79346 .72417 L .81744 .71543 L p .707 .577 .707 r
F P
0 g
s
.81744 .71543 m .81581 .67972 L .79183 .68846 L p .707 .577 .707 r
F P
0 g
s
.46875 .73881 m .46193 .24181 L .50687 .24002 L p .707 .577 .707 r
F P
0 g
s
.50687 .24002 m .51368 .73702 L .46875 .73881 L p .707 .577 .707 r
F P
0 g
s
.67207 .69035 m .6737 .72606 L .70117 .731 L p .707 .577 .707 r
F P
0 g
s
.65133 .6457 m .6521 .58964 L .6395 .58254 L p .707 .577 .707 r
F P
0 g
s
.6737 .72606 m .67207 .69035 L .65098 .68232 L p .707 .577 .707 r
F P
0 g
s
.73631 .78292 m .73445 .76628 L .70334 .76559 L p .707 .577 .707 r
F P
0 g
s
.73445 .76628 m .73631 .78292 L .76796 .77863 L p .707 .577 .707 r
F P
0 g
s
.76796 .77863 m .7661 .76199 L .73445 .76628 L p .707 .577 .707 r
F P
0 g
s
.7661 .76199 m .76796 .77863 L .79705 .76977 L p .707 .577 .707 r
F P
0 g
s
.79705 .76977 m .79519 .75313 L .7661 .76199 L p .707 .577 .707 r
F P
0 g
s
.81581 .67972 m .81744 .71543 L .83374 .70464 L p .707 .577 .707 r
F P
0 g
s
.83374 .70464 m .8321 .66892 L .81581 .67972 L p .707 .577 .707 r
F P
0 g
s
.6395 .58254 m .63873 .63861 L .65133 .6457 L p .707 .577 .707 r
F P
0 g
s
.7052 .78223 m .70334 .76559 L .67582 .75999 L p .707 .577 .707 r
F P
0 g
s
.70334 .76559 m .7052 .78223 L .73631 .78292 L p .707 .577 .707 r
F P
0 g
s
.65098 .68232 m .65261 .71804 L .6737 .72606 L p .707 .577 .707 r
F P
0 g
s
.83341 .5881 m .83263 .64417 L .83971 .63691 L p .707 .577 .707 r
F P
0 g
s
.83971 .63691 m .84048 .58085 L .83341 .5881 L p .707 .577 .707 r
F P
0 g
s
.79519 .75313 m .79705 .76977 L .82074 .75723 L p .707 .577 .707 r
F P
0 g
s
.82074 .75723 m .81888 .74058 L .79519 .75313 L p .707 .577 .707 r
F P
0 g
s
.67582 .75999 m .67768 .77663 L .7052 .78223 L p .707 .577 .707 r
F P
0 g
s
.63873 .63861 m .6395 .58254 L .6366 .575 L p .707 .577 .707 r
F P
0 g
s
.67768 .77663 m .67582 .75999 L .65458 .75002 L p .707 .577 .707 r
F P
0 g
s
.81888 .74058 m .82074 .75723 L .83671 .74221 L p .707 .577 .707 r
F P
0 g
s
.83671 .74221 m .83485 .72557 L .81888 .74058 L p .707 .577 .707 r
F P
0 g
s
.8321 .66892 m .83374 .70464 L .84074 .69285 L p .707 .577 .707 r
F P
0 g
s
.84074 .69285 m .83911 .65713 L .8321 .66892 L p .707 .577 .707 r
F P
0 g
s
.65458 .75002 m .65644 .76666 L .67768 .77663 L p .707 .577 .707 r
F P
0 g
s
.6366 .575 m .63582 .63106 L .63873 .63861 L p .707 .577 .707 r
F P
0 g
s
.84048 .58085 m .83971 .63691 L .8368 .62937 L p .707 .577 .707 r
F P
0 g
s
.8368 .62937 m .83758 .5733 L .84048 .58085 L p .707 .577 .707 r
F P
0 g
s
.63996 .7077 m .63833 .67198 L .63537 .66035 L p .707 .577 .707 r
F P
0 g
s
.65644 .76666 m .65458 .75002 L .6417 .73666 L p .707 .577 .707 r
F P
0 g
s
.83485 .72557 m .83671 .74221 L .84338 .7262 L p .707 .577 .707 r
F P
0 g
s
.84338 .7262 m .84152 .70956 L .83485 .72557 L p .707 .577 .707 r
F P
0 g
s
.63582 .63106 m .6366 .575 L .64367 .56774 L p .707 .577 .707 r
F P
0 g
s
.6417 .73666 m .64356 .7533 L .65644 .76666 L p .707 .577 .707 r
F P
0 g
s
.63537 .66035 m .637 .69607 L .63996 .7077 L p .707 .577 .707 r
F P
0 g
s
.83911 .65713 m .84074 .69285 L .83778 .68122 L p .707 .577 .707 r
F P
0 g
s
.83778 .68122 m .83614 .6455 L .83911 .65713 L p .707 .577 .707 r
F P
0 g
s
.64367 .56774 m .6429 .62381 L .63582 .63106 L p .707 .577 .707 r
F P
0 g
s
.64356 .7533 m .6417 .73666 L .63844 .72122 L p .707 .577 .707 r
F P
0 g
s
.83758 .5733 m .8368 .62937 L .82421 .62227 L p .707 .577 .707 r
F P
0 g
s
.82421 .62227 m .82498 .56621 L .83758 .5733 L p .707 .577 .707 r
F P
0 g
s
.637 .69607 m .63537 .66035 L .64237 .64856 L p .707 .577 .707 r
F P
0 g
s
.84152 .70956 m .84338 .7262 L .84012 .71076 L p .707 .577 .707 r
F P
0 g
s
.84012 .71076 m .83826 .69412 L .84152 .70956 L p .707 .577 .707 r
F P
0 g
s
.38801 .62113 m .38878 .56506 L .35761 .56298 L p .707 .577 .707 r
F P
0 g
s
.38878 .56506 m .38801 .62113 L .41984 .62086 L p .707 .577 .707 r
F P
0 g
s
.41984 .62086 m .42061 .56479 L .38878 .56506 L p .707 .577 .707 r
F P
0 g
s
.63844 .72122 m .6403 .73786 L .64356 .7533 L p .707 .577 .707 r
F P
0 g
s
.42061 .56479 m .41984 .62086 L .44921 .61827 L p .707 .577 .707 r
F P
0 g
s
.44921 .61827 m .44999 .5622 L .42061 .56479 L p .707 .577 .707 r
F P
0 g
s
.6429 .62381 m .64367 .56774 L .66004 .56148 L p .707 .577 .707 r
F P
0 g
s
.35683 .61905 m .35761 .56298 L .33015 .55877 L p .707 .577 .707 r
F P
0 g
s
.35761 .56298 m .35683 .61905 L .38801 .62113 L p .707 .577 .707 r
F P
0 g
s
.64237 .64856 m .64401 .68428 L .637 .69607 L p .707 .577 .707 r
F P
0 g
s
.83614 .6455 m .83778 .68122 L .82513 .67088 L p .707 .577 .707 r
F P
0 g
s
.82513 .67088 m .8235 .63517 L .83614 .6455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44999 .5622 m .44921 .61827 L .47326 .61362 L p .707 .577 .707 r
F P
0 g
s
.47326 .61362 m .47404 .55755 L .44999 .5622 L p .707 .577 .707 r
F P
0 g
s
.66004 .56148 m .65926 .61754 L .6429 .62381 L p .707 .577 .707 r
F P
0 g
s
.6403 .73786 m .63844 .72122 L .64511 .70521 L p .707 .577 .707 r
F P
0 g
s
.82498 .56621 m .82421 .62227 L .80315 .61633 L p .707 .577 .707 r
F P
0 g
s
.80315 .61633 m .80392 .56026 L .82498 .56621 L p .707 .577 .707 r
F P
0 g
s
.33015 .55877 m .32937 .61483 L .35683 .61905 L p .707 .577 .707 r
F P
0 g
s
.32937 .61483 m .33015 .55877 L .30909 .55282 L p .707 .577 .707 r
F P
0 g
s
.64401 .68428 m .64237 .64856 L .65866 .63777 L p .707 .577 .707 r
F P
0 g
s
.38932 .69554 m .38769 .65983 L .35653 .65847 L p .707 .577 .707 r
F P
0 g
s
.38769 .65983 m .38932 .69554 L .42112 .69319 L p .707 .577 .707 r
F P
0 g
s
.42112 .69319 m .41949 .65747 L .38769 .65983 L p .707 .577 .707 r
F P
0 g
s
.45045 .68736 m .44882 .65164 L .41949 .65747 L p .707 .577 .707 r
F P
0 g
s
.83826 .69412 m .84012 .71076 L .82724 .6974 L p .707 .577 .707 r
F P
0 g
s
.82724 .6974 m .82538 .68076 L .83826 .69412 L p .707 .577 .707 r
F P
0 g
s
.64511 .70521 m .64697 .72185 L .6403 .73786 L p .707 .577 .707 r
F P
0 g
s
.65926 .61754 m .66004 .56148 L .68408 .55683 L p .707 .577 .707 r
F P
0 g
s
.35816 .69418 m .35653 .65847 L .32906 .65353 L p .707 .577 .707 r
F P
0 g
s
.35653 .65847 m .35816 .69418 L .38932 .69554 L p .707 .577 .707 r
F P
0 g
s
.8235 .63517 m .82513 .67088 L .80404 .66285 L p .707 .577 .707 r
F P
0 g
s
.80404 .66285 m .80241 .62714 L .8235 .63517 L p .707 .577 .707 r
F P
0 g
s
.47404 .55755 m .47326 .61362 L .48962 .60735 L p .707 .577 .707 r
F P
0 g
s
.48962 .60735 m .4904 .55129 L .47404 .55755 L p .707 .577 .707 r
F P
0 g
s
.30909 .55282 m .30832 .60889 L .32937 .61483 L p .707 .577 .707 r
F P
0 g
s
.65866 .63777 m .6603 .67348 L .64401 .68428 L p .707 .577 .707 r
F P
0 g
s
.44882 .65164 m .45045 .68736 L .47443 .67862 L p .707 .577 .707 r
F P
0 g
s
.47443 .67862 m .4728 .6429 L .44882 .65164 L p .707 .577 .707 r
F P
0 g
s
.80392 .56026 m .80315 .61633 L .77569 .61211 L p .707 .577 .707 r
F P
0 g
s
.77569 .61211 m .77646 .55605 L .80392 .56026 L p .707 .577 .707 r
F P
0 g
s
.68408 .55683 m .68331 .61289 L .65926 .61754 L p .707 .577 .707 r
F P
0 g
s
.32906 .65353 m .33069 .68925 L .35816 .69418 L p .707 .577 .707 r
F P
0 g
s
.64697 .72185 m .64511 .70521 L .66108 .69019 L p .707 .577 .707 r
F P
0 g
s
.30832 .60889 m .30909 .55282 L .29649 .54573 L p .707 .577 .707 r
F P
0 g
s
.33069 .68925 m .32906 .65353 L .30797 .6455 L p .707 .577 .707 r
F P
0 g
s
.6603 .67348 m .65866 .63777 L .68265 .62903 L p .707 .577 .707 r
F P
0 g
s
.68331 .61289 m .68408 .55683 L .71346 .55424 L p .707 .577 .707 r
F P
0 g
s
.3933 .74611 m .39144 .72946 L .36033 .72878 L p .707 .577 .707 r
F P
0 g
s
.39144 .72946 m .3933 .74611 L .42495 .74181 L p .707 .577 .707 r
F P
0 g
s
.42495 .74181 m .42309 .72517 L .39144 .72946 L p .707 .577 .707 r
F P
0 g
s
.82538 .68076 m .82724 .6974 L .806 .68743 L p .707 .577 .707 r
F P
0 g
s
.806 .68743 m .80414 .67079 L .82538 .68076 L p .707 .577 .707 r
F P
0 g
s
.42309 .72517 m .42495 .74181 L .45404 .73296 L p .707 .577 .707 r
F P
0 g
s
.45404 .73296 m .45218 .71632 L .42309 .72517 L p .707 .577 .707 r
F P
0 g
s
.66108 .69019 m .66294 .70683 L .64697 .72185 L p .707 .577 .707 r
F P
0 g
s
.4728 .6429 m .47443 .67862 L .49073 .66783 L p .707 .577 .707 r
F P
0 g
s
.49073 .66783 m .48909 .63211 L .4728 .6429 L p .707 .577 .707 r
F P
0 g
s
.80241 .62714 m .80404 .66285 L .77657 .65792 L p .707 .577 .707 r
F P
0 g
s
.77657 .65792 m .77494 .6222 L .80241 .62714 L p .707 .577 .707 r
F P
0 g
s
.77646 .55605 m .77569 .61211 L .74452 .61004 L p .707 .577 .707 r
F P
0 g
s
.74452 .61004 m .74529 .55397 L .77646 .55605 L p .707 .577 .707 r
F P
0 g
s
.29649 .54573 m .29572 .60179 L .30832 .60889 L p .707 .577 .707 r
F P
0 g
s
.36219 .74542 m .36033 .72878 L .33281 .72317 L p .707 .577 .707 r
F P
0 g
s
.36033 .72878 m .36219 .74542 L .3933 .74611 L p .707 .577 .707 r
F P
0 g
s
.30797 .6455 m .3096 .68122 L .33069 .68925 L p .707 .577 .707 r
F P
0 g
s
.68265 .62903 m .68428 .66474 L .6603 .67348 L p .707 .577 .707 r
F P
0 g
s
.4904 .55129 m .48962 .60735 L .4967 .6001 L p .707 .577 .707 r
F P
0 g
s
.4967 .6001 m .49747 .54403 L .4904 .55129 L p .707 .577 .707 r
F P
0 g
s
.71268 .6103 m .71346 .55424 L .74529 .55397 L p .707 .577 .707 r
F P
0 g
s
.71346 .55424 m .71268 .6103 L .68331 .61289 L p .707 .577 .707 r
F P
0 g
s
.45218 .71632 m .45404 .73296 L .47773 .72041 L p .707 .577 .707 r
F P
0 g
s
.47773 .72041 m .47587 .70377 L .45218 .71632 L p .707 .577 .707 r
F P
0 g
s
.74529 .55397 m .74452 .61004 L .71268 .6103 L p .707 .577 .707 r
F P
0 g
s
.68428 .66474 m .68265 .62903 L .71198 .6232 L p .707 .577 .707 r
F P
0 g
s
.66294 .70683 m .66108 .69019 L .68477 .67764 L p .707 .577 .707 r
F P
0 g
s
.3096 .68122 m .30797 .6455 L .29532 .63517 L p .707 .577 .707 r
F P
0 g
s
.33281 .72317 m .33467 .73981 L .36219 .74542 L p .707 .577 .707 r
F P
0 g
s
.77494 .6222 m .77657 .65792 L .74541 .65656 L p .707 .577 .707 r
F P
0 g
s
.74541 .65656 m .74378 .62084 L .77494 .6222 L p .707 .577 .707 r
F P
0 g
s
.29572 .60179 m .29649 .54573 L .29359 .53818 L p .707 .577 .707 r
F P
0 g
s
.80414 .67079 m .806 .68743 L .77848 .68183 L p .707 .577 .707 r
F P
0 g
s
.77848 .68183 m .77662 .66518 L .80414 .67079 L p .707 .577 .707 r
F P
0 g
s
.33467 .73981 m .33281 .72317 L .31157 .7132 L p .707 .577 .707 r
F P
0 g
s
.68477 .67764 m .68663 .69428 L .66294 .70683 L p .707 .577 .707 r
F P
0 g
s
.71361 .65891 m .71198 .6232 L .74378 .62084 L p .707 .577 .707 r
F P
0 g
s
.71198 .6232 m .71361 .65891 L .68428 .66474 L p .707 .577 .707 r
F P
0 g
s
.74378 .62084 m .74541 .65656 L .71361 .65891 L p .707 .577 .707 r
F P
0 g
s
.47587 .70377 m .47773 .72041 L .4937 .7054 L p .707 .577 .707 r
F P
0 g
s
.4937 .7054 m .49184 .68875 L .47587 .70377 L p .707 .577 .707 r
F P
0 g
s
.48909 .63211 m .49073 .66783 L .49773 .65604 L p .707 .577 .707 r
F P
0 g
s
.49773 .65604 m .4961 .62032 L .48909 .63211 L p .707 .577 .707 r
F P
0 g
s
.29532 .63517 m .29695 .67088 L .3096 .68122 L p .707 .577 .707 r
F P
0 g
s
.31157 .7132 m .31343 .72984 L .33467 .73981 L p .707 .577 .707 r
F P
0 g
s
.68663 .69428 m .68477 .67764 L .71386 .66879 L p .707 .577 .707 r
F P
0 g
s
.29359 .53818 m .29281 .59425 L .29572 .60179 L p .707 .577 .707 r
F P
0 g
s
.77662 .66518 m .77848 .68183 L .74737 .68114 L p .707 .577 .707 r
F P
0 g
s
.74737 .68114 m .74551 .66449 L .77662 .66518 L p .707 .577 .707 r
F P
0 g
s
.49747 .54403 m .4967 .6001 L .49379 .59255 L p .707 .577 .707 r
F P
0 g
s
.49379 .59255 m .49457 .53649 L .49747 .54403 L p .707 .577 .707 r
F P
0 g
s
.71386 .66879 m .71572 .68543 L .68663 .69428 L p .707 .577 .707 r
F P
0 g
s
.71572 .68543 m .71386 .66879 L .74551 .66449 L p .707 .577 .707 r
F P
0 g
s
.29695 .67088 m .29532 .63517 L .29236 .62354 L p .707 .577 .707 r
F P
0 g
s
.31343 .72984 m .31157 .7132 L .29869 .69984 L p .707 .577 .707 r
F P
0 g
s
.74551 .66449 m .74737 .68114 L .71572 .68543 L p .707 .577 .707 r
F P
0 g
s
.49184 .68875 m .4937 .7054 L .50037 .68938 L p .707 .577 .707 r
F P
0 g
s
.50037 .68938 m .49851 .67274 L .49184 .68875 L p .707 .577 .707 r
F P
0 g
s
.29281 .59425 m .29359 .53818 L .30066 .53092 L p .707 .577 .707 r
F P
0 g
s
.29869 .69984 m .30055 .71648 L .31343 .72984 L p .707 .577 .707 r
F P
0 g
s
.29236 .62354 m .29399 .65925 L .29695 .67088 L p .707 .577 .707 r
F P
0 g
s
.4961 .62032 m .49773 .65604 L .49477 .6444 L p .707 .577 .707 r
F P
0 g
s
.49477 .6444 m .49313 .60869 L .4961 .62032 L p .707 .577 .707 r
F P
0 g
s
.30066 .53092 m .29989 .58699 L .29281 .59425 L p .707 .577 .707 r
F P
0 g
s
.30055 .71648 m .29869 .69984 L .29542 .6844 L p .707 .577 .707 r
F P
0 g
s
.49457 .53649 m .49379 .59255 L .4812 .58546 L p .707 .577 .707 r
F P
0 g
s
.4812 .58546 m .48197 .52939 L .49457 .53649 L p .707 .577 .707 r
F P
0 g
s
.29399 .65925 m .29236 .62354 L .29936 .61175 L p .707 .577 .707 r
F P
0 g
s
.49851 .67274 m .50037 .68938 L .49711 .67394 L p .707 .577 .707 r
F P
0 g
s
.49711 .67394 m .49525 .6573 L .49851 .67274 L p .707 .577 .707 r
F P
0 g
s
.29542 .6844 m .29728 .70104 L .30055 .71648 L p .707 .577 .707 r
F P
0 g
s
.29989 .58699 m .30066 .53092 L .31703 .52466 L p .707 .577 .707 r
F P
0 g
s
.29936 .61175 m .30099 .64746 L .29399 .65925 L p .707 .577 .707 r
F P
0 g
s
.49313 .60869 m .49477 .6444 L .48212 .63407 L p .707 .577 .707 r
F P
0 g
s
.48212 .63407 m .48049 .59835 L .49313 .60869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31703 .52466 m .31625 .58073 L .29989 .58699 L p .707 .577 .707 r
F P
0 g
s
.29728 .70104 m .29542 .6844 L .3021 .66839 L p .707 .577 .707 r
F P
0 g
s
.48197 .52939 m .4812 .58546 L .46014 .57951 L p .707 .577 .707 r
F P
0 g
s
.46014 .57951 m .46091 .52345 L .48197 .52939 L p .707 .577 .707 r
F P
0 g
s
.30099 .64746 m .29936 .61175 L .31565 .60095 L p .707 .577 .707 r
F P
0 g
s
.49525 .6573 m .49711 .67394 L .48423 .66058 L p .707 .577 .707 r
F P
0 g
s
.48423 .66058 m .48237 .64394 L .49525 .6573 L p .707 .577 .707 r
F P
0 g
s
.3021 .66839 m .30396 .68503 L .29728 .70104 L p .707 .577 .707 r
F P
0 g
s
.31625 .58073 m .31703 .52466 L .34107 .52001 L p .707 .577 .707 r
F P
0 g
s
.48049 .59835 m .48212 .63407 L .46103 .62604 L p .707 .577 .707 r
F P
0 g
s
.46103 .62604 m .4594 .59032 L .48049 .59835 L p .707 .577 .707 r
F P
0 g
s
.31565 .60095 m .31729 .63667 L .30099 .64746 L p .707 .577 .707 r
F P
0 g
s
.46091 .52345 m .46014 .57951 L .43268 .5753 L p .707 .577 .707 r
F P
0 g
s
.43268 .5753 m .43345 .51923 L .46091 .52345 L p .707 .577 .707 r
F P
0 g
s
.34107 .52001 m .3403 .57608 L .31625 .58073 L p .707 .577 .707 r
F P
0 g
s
.30396 .68503 m .3021 .66839 L .31807 .65337 L p .707 .577 .707 r
F P
0 g
s
.31729 .63667 m .31565 .60095 L .33964 .59221 L p .707 .577 .707 r
F P
0 g
s
.3403 .57608 m .34107 .52001 L .37045 .51742 L p .707 .577 .707 r
F P
0 g
s
.48237 .64394 m .48423 .66058 L .46299 .65061 L p .707 .577 .707 r
F P
0 g
s
.46299 .65061 m .46113 .63397 L .48237 .64394 L p .707 .577 .707 r
F P
0 g
s
.31807 .65337 m .31993 .67002 L .30396 .68503 L p .707 .577 .707 r
F P
0 g
s
.4594 .59032 m .46103 .62604 L .43356 .6211 L p .707 .577 .707 r
F P
0 g
s
.43356 .6211 m .43193 .58539 L .4594 .59032 L p .707 .577 .707 r
F P
0 g
s
.43345 .51923 m .43268 .5753 L .40151 .57322 L p .707 .577 .707 r
F P
0 g
s
.40151 .57322 m .40228 .51715 L .43345 .51923 L p .707 .577 .707 r
F P
0 g
s
.33964 .59221 m .34127 .62793 L .31729 .63667 L p .707 .577 .707 r
F P
0 g
s
.36967 .57349 m .37045 .51742 L .40228 .51715 L p .707 .577 .707 r
F P
0 g
s
.37045 .51742 m .36967 .57349 L .3403 .57608 L p .707 .577 .707 r
F P
0 g
s
.40228 .51715 m .40151 .57322 L .36967 .57349 L p .707 .577 .707 r
F P
0 g
s
.34127 .62793 m .33964 .59221 L .36896 .58638 L p .707 .577 .707 r
F P
0 g
s
.31993 .67002 m .31807 .65337 L .34176 .64083 L p .707 .577 .707 r
F P
0 g
s
.43193 .58539 m .43356 .6211 L .4024 .61975 L p .707 .577 .707 r
F P
0 g
s
.4024 .61975 m .40077 .58403 L .43193 .58539 L p .707 .577 .707 r
F P
0 g
s
.46113 .63397 m .46299 .65061 L .43547 .64501 L p .707 .577 .707 r
F P
0 g
s
.43547 .64501 m .43361 .62837 L .46113 .63397 L p .707 .577 .707 r
F P
0 g
s
.34176 .64083 m .34362 .65747 L .31993 .67002 L p .707 .577 .707 r
F P
0 g
s
.3706 .6221 m .36896 .58638 L .40077 .58403 L p .707 .577 .707 r
F P
0 g
s
.36896 .58638 m .3706 .6221 L .34127 .62793 L p .707 .577 .707 r
F P
0 g
s
.40077 .58403 m .4024 .61975 L .3706 .6221 L p .707 .577 .707 r
F P
0 g
s
.34362 .65747 m .34176 .64083 L .37085 .63197 L p .707 .577 .707 r
F P
0 g
s
.43361 .62837 m .43547 .64501 L .40436 .64432 L p .707 .577 .707 r
F P
0 g
s
.40436 .64432 m .4025 .62768 L .43361 .62837 L p .707 .577 .707 r
F P
0 g
s
.37085 .63197 m .37271 .64861 L .34362 .65747 L p .707 .577 .707 r
F P
0 g
s
.37271 .64861 m .37085 .63197 L .4025 .62768 L p .707 .577 .707 r
F P
0 g
s
.4025 .62768 m .40436 .64432 L .37271 .64861 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00Kgoo100015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qoo`00IWoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YFFUIJ
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005moob0000EJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00G7oo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00FGoo0`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001GOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P003goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo20000eYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH003Moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00
Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool005=oo`03001J
EP0000=JEP03001JEUYF00=JEQl000AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00Dgoo00<005YF00000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUH0000F00000eYF001J
EP05FUH30003FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF00=J
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00
FUIJEP0200000eYF00000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF
00=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00=JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YFFUIJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080
00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YF000000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Agoo2@0017oo00<005YFFUH00`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`l000AJEP03001JEUYF009JEPP0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF200015YF00<005YF
FUH00eYF00<005YFFUH00P00;Woo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEQD000IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF3`000eYF00<005YFFUH00eYF10000UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH00`00FUIJEP07FUH20003FUH40002FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEP00FUH00P0000=JEP00FUH015YF00<005YFFUH01EYF200015YF00<005YFFUH01UYF
00<005YF00000`001UYF00<005YFFUH01000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH4
00001EYF001JEUYF00001EYF3`0015YF100015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF00001@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@005YFFUIJEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00@005YFFUIJEP80009JEP04001JEUYF0002FUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030004FUH3000015YF001JEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0`00;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH01000FUH0000015YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000AJEP00FUIJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH20006FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300001UYF000005YF001JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0002FUH200000eYF001JEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000UYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJ
EP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00FUH005YF1@000eYF00<005YF
FUH015YF1P0000=JEP00FUH025YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF008000EJEP03001JEUYF00@00003
FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00T000AJEP05001JEP00FUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH01000FUH000001UYF0`0000=JEP0000000UYF00<005YFFUH0
0eYF00@005YFFUIJEPT000=JEP03001JEUYF00=JEP<00004FUH005YFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0003FUH20002FUH20000
0eYF001JEP03FUH20002FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF
00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH50002FUH01000FUIJ
EP000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00@000Qoo`L000Qoo`H000AJEP03001JEUYF
008002ioo`00;7oo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP@0009JEP03001oogoo00=oo`@0009J
EP03001JEUYF009JEPP000Ioo`<00003FUH005YF009JEP03001oogoo02aoo`00;7oo00@005YF001J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEQ0000AJEP04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF00000004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YFFUIJ
EP00FUH40002FUH01P00FUIJEUYF001oo`@000IJEP03001JEUYF00IJEP04001JEUYFFUH50004Ool2
0003FUH00`00Oomoo`0/Ool002aoo`03001JEP00008000EJEP03001JEUYF00EJEPP000AJEP03001J
EUYF00IJEP<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF0`000goo0P000UYF00<007ooOol0;7oo
000/Ool20002FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUH0009JEP03001JEUYF009JEP<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0009JEP<002ioo`00;7oo
0P000UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00@005YF
FUIJEP8000IJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF0`000eYF00<005YFFUH00`0025YF00<005YFFUH00UYF3`001UYF00@005YFFUIJEP800004
FUH005YF000^Ool002aoo`80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF1@00
15YF00<005YFFUH01UYF00H005YF000005YF0005FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P000UYF0`000UYF00<005YFFUH0
1EYF1P003goo10000UYF00<005YFFUH00UYF0`0000=JEP00Ool0;Goo000]Ool01@00FUIJEP00FUH0
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP800003
FUH005YF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00AJEP@000=JEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YF00000P001EYF00<005YFFUH00UYF0P005Goo1`0015YF00D005YF001JEP0002ioo`00
;Woo1@001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YF000010000eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010001eYF00<005YFFUH00UYF0P00
0UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH0
0`00FUH00007FUH00`00FUH00002000COol40002FUH00`00FUIJEP02FUH20003FUH01000FUH00000
;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0005FUH00`00FUIJEP03FUHI000;FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001eYF20002Goo1`001UYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0002ioo`00;Woo00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP0000EJEP8000=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001oogoo02aoo`00;Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YF
FUIJEP00009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHF00000eYF000000020002FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP05001JEUYF001oo`03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPH0
01Ioo`05001JEUYF001oo`040004FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH20003FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=oo`8002eoo`00;7oo00<005YF000015YF
00@005YFFUIJEP80011oo`L000Eoo`03001JEUYF00<000=oo`<00004FUH005YFFUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool2000]
Ool002aoo`03001JEP0000AJEP04001JEP00000>Ool40002FUH00`00FUIJEP02FUH7000015YF001J
EUYF0P0017oo0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEP800003
FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YF100015YF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF
00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00004FUH2000<Ool40006FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP<0009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00MJEP@000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF1@0015YF00<0
05YFFUH015YF0`002Woo00<005YF0000;Goo000/Ool00`00FUH00002FUH2000:Ool400000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF00001P000UYF00<005YFFUH00eYF
00<005YFFUH00UYF1P001eYF00<005YFFUH00P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP@000AJEPH000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00@0
00eoo`03001JEP0002eoo`00;7oo00<005YF00000P002Goo0`001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
0`0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP@000AJEP03001JEUYF00=JEPT000AJEP@00003FUH0000000D0011oo`800003FUH007oo02aoo`00
;7oo00@005YF001JEP<000Eoo`<000MJEP03001JEUYF009JEPl000AJEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH40004FUH00`00FUIJEP03FUH0
1000FUIJEP001Goo2@005Goo0P0000=JEP000000;Woo000/Ool20002FUH00`00FUIJEP0200000goo
00000002FUH00`00FUIJEP04FUH6000?Ool40002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00@005YFFUH0029oo`04001JEUYFFUH2
000^Ool002aoo`80009JEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH2000BOol400000eYF001J
EP0300000eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005FUH=000;FUH90008
FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH00P0087oo00<0
05YFFUH00UYF00<007ooOol0;Goo000/Ool20002FUH01000FUIJEP001UYF00<005YF00005P001EYF
00<005YFFUH00UYF0P000eYF2@0015YF00<005YFFUH010000UYF2@002eYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF008001ioo`<000AJEP03001oogoo02eoo`00;7oo0P000UYF00@005YF000000IJ
EP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800004
FUH005YFFUH20002FUH00`00FUH000060003FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUIJEP050005FUH00`00FUIJ
EP02000MOol01000FUIJEP000eYF00<007ooOol0;Woo000/Ool20002FUH200000eYF001JEP03FUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
00000UYF0P000UYF00<005YFFUH00eYF00<005YF000010002UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00D005YFFUIJEP0000=o
o`8000=JEP05001JEUYFFUH0000KOol20004FUH00`00FUH0000aOol002eoo`03001JEP0000=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP06001JEUYFFUH005YF0P000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF100015YF00@005YFFUIJEP<000=o
o`800003FUH005YF009JEP03001oogoo01Ioo`<000IJEP80039oo`00;Goo0P0015YF10001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00`0000EJ
EP00FUIJEP0000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEP0000QJEP04001JEUYFFUH20003FUH01000FUIJEP000UYF0P000goo0P000eYF
00<007ooOol04Woo10000UYF00<005YFFUH00eYF0P00<goo000^Ool00`00FUIJEP02FUH01@00FUIJ
EUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
0goo0P000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00=JEPH0
009JEP03001oogoo00]oo`L000IJEP04001JEUYFFUH2000eOol002eoo`8000=JEP03001JEUYF009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Ioo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00AJEPH000EJEP04001JEUYFFUHA
0004FUH00`00FUIJEP06FUH01000FUH00000=goo000]Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001goo0P0000=J
EP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF008000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00<005YFFUH0
0P000Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF10002Woo0`00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P000UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?7oo000/Ool01000FUIJEP001Woo1@00
0eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000X000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008003ioo`00;7oo00<005YF000037oo200015YF30004Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF0P0000=JEP0000000P000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P00@Goo000/Ool00`00FUH0000DOol9000GOol200000eYF00000004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP<00003FUH005YF010004Moo`00;Goo
00<007ooOol067oo0`005goo00@005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00009JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomoo`1COol002eoo`03001oogoo
035oo`04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0005Eoo`00;Goo0P00<Goo00<005YFFUH00UYF00<007oo000015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo000]Ool00`00FUH0000^Ool30004FUH00`00Oomoo`020002FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH30002Ool3001DOol002ioo`03001JEP0002]oo`80
009JEP05001JEUYFFUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH20005Ool2
001DOol002ioo`04001JEUYF000XOol20004FUH01000FUH0000027oo0P001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
1UYF00@005YFFUIJEP8000Moo`8005Aoo`00;Woo00<005YFFUH00`0097oo0P001UYF0P0037oo0`00
15YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0`000eYF00<005YFFUH01EYF00@005YF000000Uoo`8005Aoo`00;goo00<005YF00000UYF0P00
7Woo100000=JEP00FUH01EYF00<007ooOol03Woo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001EYF00<005YFFUH00UYF1@002Woo00<005YF
0000E7oo000`Ool00`00FUH00003FUH5000BOol70005FUH00`00FUIJEP02FUH2000DOol40008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH500000eYF0000000<000?Ool00`00FUH0
001DOol0035oo`8000AJEP04001JEUYFFUHB0004FUH00`00FUIJEP06FUH01000FUH000006Woo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEQ4001Moo`800003FUH007oo05=oo`00
<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
8Woo20001UYF00<005YFFUH015YF2P0037oo1@005Woo00@005YF000005Eoo`00=7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo3@005goo0`005Woo
00<005YFFUH00P00EGoo000gOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002
000iOol2000aOol01@00FUIJEUYF0000EWoo000jOol400000eYF001JEP07FUH00`00FUIJEP02FUH6
000lOol00`00FUH0000_Ool00`00FUIJEP02FUH00`00Oomoo`1DOol003ioo`l0049oo`04001JEUYF
000/Ool30003FUH00`00Oomoo`1EOol008moo`05001JEUYFFUH0000YOol20002FUH01000FUIJEP00
F7oo002?Ool01000FUIJEUYF0`0097oo0`001EYF0P00FGoo002@Ool01000FUIJEP000UYF0P007goo
0`0000=JEP00FUH01EYF00<007ooOol0F7oo002AOol00`00FUH00004FUH3000IOol30004FUH00`00
FUIJEP02FUH2001KOol0099oo`8000EJEP03001JEP0000<000moo`H000MJEP03001JEUYF008005eo
o`00Tgoo00<005YFFUH00eYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF0`00Ggoo002DOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2001QOol0
09Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00
V7oo1@0015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Igoo002MOol90004FUH00`00FUIJEP04
001/Ool00:Ioo`L0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59849 .75361 m .59772 .69859 L .56654 .69686 L p .707 .577 .707 r
F P
0 g
s
.59772 .69859 m .59849 .75361 L .63032 .75233 L p .707 .577 .707 r
F P
0 g
s
.63032 .75233 m .62955 .69731 L .59772 .69859 L p .707 .577 .707 r
F P
0 g
s
.62955 .69731 m .63032 .75233 L .6597 .74817 L p .707 .577 .707 r
F P
0 g
s
.6597 .74817 m .65892 .69314 L .62955 .69731 L p .707 .577 .707 r
F P
0 g
s
.56732 .75189 m .56654 .69686 L .53909 .6923 L p .707 .577 .707 r
F P
0 g
s
.56654 .69686 m .56732 .75189 L .59849 .75361 L p .707 .577 .707 r
F P
0 g
s
.65892 .69314 m .6597 .74817 L .68375 .74153 L p .707 .577 .707 r
F P
0 g
s
.68375 .74153 m .68297 .68651 L .65892 .69314 L p .707 .577 .707 r
F P
0 g
s
.5976 .80134 m .59923 .76343 L .56807 .76097 L p .707 .577 .707 r
F P
0 g
s
.59923 .76343 m .5976 .80134 L .6294 .80218 L p .707 .577 .707 r
F P
0 g
s
.6294 .80218 m .63103 .76427 L .59923 .76343 L p .707 .577 .707 r
F P
0 g
s
.53986 .74732 m .53909 .6923 L .51803 .68534 L p .707 .577 .707 r
F P
0 g
s
.53909 .6923 m .53986 .74732 L .56732 .75189 L p .707 .577 .707 r
F P
0 g
s
.63103 .76427 m .6294 .80218 L .65873 .80133 L p .707 .577 .707 r
F P
0 g
s
.65873 .80133 m .66036 .76342 L .63103 .76427 L p .707 .577 .707 r
F P
0 g
s
.56807 .76097 m .56644 .79888 L .5976 .80134 L p .707 .577 .707 r
F P
0 g
s
.56644 .79888 m .56807 .76097 L .5406 .75714 L p .707 .577 .707 r
F P
0 g
s
.59564 .82854 m .5975 .80941 L .56639 .80621 L p .707 .577 .707 r
F P
0 g
s
.5975 .80941 m .59564 .82854 L .62729 .83153 L p .707 .577 .707 r
F P
0 g
s
.62729 .83153 m .62915 .81239 L .5975 .80941 L p .707 .577 .707 r
F P
0 g
s
.56639 .80621 m .56453 .82534 L .59564 .82854 L p .707 .577 .707 r
F P
0 g
s
.62915 .81239 m .62729 .83153 L .65638 .83401 L p .707 .577 .707 r
F P
0 g
s
.65638 .83401 m .65824 .81488 L .62915 .81239 L p .707 .577 .707 r
F P
0 g
s
.68297 .68651 m .68375 .74153 L .70011 .73307 L p .707 .577 .707 r
F P
0 g
s
.70011 .73307 m .69933 .67804 L .68297 .68651 L p .707 .577 .707 r
F P
0 g
s
.5406 .75714 m .53897 .79504 L .56644 .79888 L p .707 .577 .707 r
F P
0 g
s
.56453 .82534 m .56639 .80621 L .53887 .80311 L p .707 .577 .707 r
F P
0 g
s
.53887 .80311 m .53701 .82225 L .56453 .82534 L p .707 .577 .707 r
F P
0 g
s
.66036 .76342 m .65873 .80133 L .68271 .79886 L p .707 .577 .707 r
F P
0 g
s
.68271 .79886 m .68434 .76095 L .66036 .76342 L p .707 .577 .707 r
F P
0 g
s
.51803 .68534 m .5188 .74036 L .53986 .74732 L p .707 .577 .707 r
F P
0 g
s
.53897 .79504 m .5406 .75714 L .51951 .7523 L p .707 .577 .707 r
F P
0 g
s
.5188 .74036 m .51803 .68534 L .50543 .67667 L p .707 .577 .707 r
F P
0 g
s
.65824 .81488 m .65638 .83401 L .68007 .83575 L p .707 .577 .707 r
F P
0 g
s
.68007 .83575 m .68193 .81662 L .65824 .81488 L p .707 .577 .707 r
F P
0 g
s
.51951 .7523 m .51788 .79021 L .53897 .79504 L p .707 .577 .707 r
F P
0 g
s
.53701 .82225 m .53887 .80311 L .51763 .80042 L p .707 .577 .707 r
F P
0 g
s
.51763 .80042 m .51577 .81956 L .53701 .82225 L p .707 .577 .707 r
F P
0 g
s
.68434 .76095 m .68271 .79886 L .699 .79502 L p .707 .577 .707 r
F P
0 g
s
.699 .79502 m .70063 .75712 L .68434 .76095 L p .707 .577 .707 r
F P
0 g
s
.69933 .67804 m .70011 .73307 L .70718 .72361 L p .707 .577 .707 r
F P
0 g
s
.70718 .72361 m .70641 .66858 L .69933 .67804 L p .707 .577 .707 r
F P
0 g
s
.50543 .67667 m .5062 .7317 L .5188 .74036 L p .707 .577 .707 r
F P
0 g
s
.68193 .81662 m .68007 .83575 L .69603 .83657 L p .707 .577 .707 r
F P
0 g
s
.69603 .83657 m .69789 .81744 L .68193 .81662 L p .707 .577 .707 r
F P
0 g
s
.51788 .79021 m .51951 .7523 L .50686 .74695 L p .707 .577 .707 r
F P
0 g
s
.5062 .7317 m .50543 .67667 L .50253 .66714 L p .707 .577 .707 r
F P
0 g
s
.50686 .74695 m .50523 .78485 L .51788 .79021 L p .707 .577 .707 r
F P
0 g
s
.51577 .81956 m .51763 .80042 L .50474 .7984 L p .707 .577 .707 r
F P
0 g
s
.50474 .7984 m .50288 .81754 L .51577 .81956 L p .707 .577 .707 r
F P
0 g
s
.70063 .75712 m .699 .79502 L .70601 .79019 L p .707 .577 .707 r
F P
0 g
s
.70601 .79019 m .70764 .75228 L .70063 .75712 L p .707 .577 .707 r
F P
0 g
s
.70641 .66858 m .70718 .72361 L .70428 .71408 L p .707 .577 .707 r
F P
0 g
s
.70428 .71408 m .7035 .65905 L .70641 .66858 L p .707 .577 .707 r
F P
0 g
s
.50253 .66714 m .5033 .72216 L .5062 .7317 L p .707 .577 .707 r
F P
0 g
s
.69789 .81744 m .69603 .83657 L .70271 .8364 L p .707 .577 .707 r
F P
0 g
s
.70271 .8364 m .70457 .81726 L .69789 .81744 L p .707 .577 .707 r
F P
0 g
s
.50523 .78485 m .50686 .74695 L .5039 .74159 L p .707 .577 .707 r
F P
0 g
s
.48631 .81979 m .49313 .31364 L .44912 .31072 L p .707 .577 .707 r
F P
0 g
s
.5039 .74159 m .50226 .77949 L .50523 .78485 L p .707 .577 .707 r
F P
0 g
s
.5033 .72216 m .50253 .66714 L .5096 .65768 L p .707 .577 .707 r
F P
0 g
s
.50288 .81754 m .50474 .7984 L .50148 .79725 L p .707 .577 .707 r
F P
0 g
s
.50148 .79725 m .49962 .81638 L .50288 .81754 L p .707 .577 .707 r
F P
0 g
s
.5096 .65768 m .51038 .7127 L .5033 .72216 L p .707 .577 .707 r
F P
0 g
s
.50226 .77949 m .5039 .74159 L .5109 .73675 L p .707 .577 .707 r
F P
0 g
s
.51038 .7127 m .5096 .65768 L .52596 .64922 L p .707 .577 .707 r
F P
0 g
s
.5109 .73675 m .50927 .77466 L .50226 .77949 L p .707 .577 .707 r
F P
0 g
s
.49962 .81638 m .50148 .79725 L .50816 .79707 L p .707 .577 .707 r
F P
0 g
s
.50816 .79707 m .5063 .81621 L .49962 .81638 L p .707 .577 .707 r
F P
0 g
s
.52596 .64922 m .52674 .70424 L .51038 .7127 L p .707 .577 .707 r
F P
0 g
s
.50927 .77466 m .5109 .73675 L .5272 .73291 L p .707 .577 .707 r
F P
0 g
s
.5272 .73291 m .52556 .77082 L .50927 .77466 L p .707 .577 .707 r
F P
0 g
s
.5063 .81621 m .50816 .79707 L .52413 .7979 L p .707 .577 .707 r
F P
0 g
s
.52413 .7979 m .52227 .81703 L .5063 .81621 L p .707 .577 .707 r
F P
0 g
s
.52556 .77082 m .5272 .73291 L .55118 .73045 L p .707 .577 .707 r
F P
0 g
s
.55118 .73045 m .54955 .76835 L .52556 .77082 L p .707 .577 .707 r
F P
0 g
s
.52227 .81703 m .52413 .7979 L .54781 .79964 L p .707 .577 .707 r
F P
0 g
s
.54781 .79964 m .54595 .81877 L .52227 .81703 L p .707 .577 .707 r
F P
0 g
s
.49313 .31364 m .48631 .81979 L .53125 .81939 L p .707 .577 .707 r
F P
0 g
s
.52674 .70424 m .52596 .64922 L .55001 .64258 L p .707 .577 .707 r
F P
0 g
s
.55001 .64258 m .55078 .6976 L .52674 .70424 L p .707 .577 .707 r
F P
0 g
s
.53125 .81939 m .53807 .31324 L .49313 .31364 L p .707 .577 .707 r
F P
0 g
s
.55078 .6976 m .55001 .64258 L .57938 .63841 L p .707 .577 .707 r
F P
0 g
s
.57938 .63841 m .58016 .69344 L .55078 .6976 L p .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55118 .73045 L .55665 .73029 L p .707 .577 .707 r
F P
0 g
s
.55665 .73029 m .58051 .72959 L p .55124 .76624 L .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55665 .73029 L .55124 .76624 L .707 .577 .707 r
F
.58016 .69344 m .57938 .63841 L .61122 .63713 L p F P
0 g
s
.61122 .63713 m .61199 .69216 L .58016 .69344 L p .707 .577 .707 r
F P
0 g
s
.58051 .72959 m .57887 .7675 L .54955 .76835 L p .707 .577 .707 r
F P
0 g
s
.54595 .81877 m .54781 .79964 L .57691 .80212 L p .707 .577 .707 r
F P
0 g
s
.57691 .80212 m .57505 .82126 L .54595 .81877 L p .707 .577 .707 r
F P
0 g
s
.57887 .7675 m .58051 .72959 L .61231 .73044 L p .707 .577 .707 r
F P
0 g
s
.61231 .73044 m .61067 .76835 L .57887 .7675 L p .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .57691 .80212 L .58257 .80265 L p .707 .577 .707 r
F P
0 g
s
.58257 .80265 m .60856 .80511 L p .5803 .81873 L .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .58257 .80265 L .5803 .81873 L .707 .577 .707 r
F
.64239 .63886 m .64316 .69389 L .61199 .69216 L p F P
0 g
s
.61199 .69216 m .61122 .63713 L .64239 .63886 L p .707 .577 .707 r
F P
0 g
s
.64347 .7329 m .64183 .7708 L .61067 .76835 L p .707 .577 .707 r
F P
0 g
s
.61067 .76835 m .61231 .73044 L .64347 .7329 L p .707 .577 .707 r
F P
0 g
s
.6067 .82424 m .60856 .80511 L .63967 .80831 L p .707 .577 .707 r
F P
0 g
s
.60856 .80511 m .6067 .82424 L .57505 .82126 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .62977 .80022 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.61349 .30296 m .60931 .61321 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.60931 .61321 m .60667 .80911 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .60667 .80911 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57954 .30956 m .57557 .60473 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57557 .60473 m .57273 .81571 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.53807 .31324 m .53125 .81939 L .57273 .81571 L p .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .57954 .30956 L .53807 .31324 L p .707 .577 .707 r
F P
0 g
s
.44231 .81687 m .44912 .31072 L .41036 .30476 L p .707 .577 .707 r
F P
0 g
s
.44912 .31072 m .44231 .81687 L .48631 .81979 L p .707 .577 .707 r
F P
0 g
s
.70764 .75228 m .70601 .79019 L .70304 .78483 L p .707 .577 .707 r
F P
0 g
s
.70304 .78483 m .70468 .74692 L .70764 .75228 L p .707 .577 .707 r
F P
0 g
s
.7035 .65905 m .70428 .71408 L .69168 .70541 L p .707 .577 .707 r
F P
0 g
s
.69168 .70541 m .69091 .65038 L .7035 .65905 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .61349 .30296 L .57954 .30956 L p .707 .577 .707 r
F P
0 g
s
.70457 .81726 m .70271 .8364 L .69945 .83525 L p .707 .577 .707 r
F P
0 g
s
.69945 .83525 m .70131 .81611 L .70457 .81726 L p .707 .577 .707 r
F P
0 g
s
.25548 .7168 m .25471 .66177 L .22354 .66005 L p .707 .577 .707 r
F P
0 g
s
.25471 .66177 m .25548 .7168 L .28731 .71552 L p .707 .577 .707 r
F P
0 g
s
.28731 .71552 m .28654 .66049 L .25471 .66177 L p .707 .577 .707 r
F P
0 g
s
.40354 .81091 m .41036 .30476 L .38063 .29635 L p .707 .577 .707 r
F P
0 g
s
.41036 .30476 m .40354 .81091 L .44231 .81687 L p .707 .577 .707 r
F P
0 g
s
.28654 .66049 m .28731 .71552 L .31669 .71135 L p .707 .577 .707 r
F P
0 g
s
.31669 .71135 m .31592 .65633 L .28654 .66049 L p .707 .577 .707 r
F P
0 g
s
.22431 .71507 m .22354 .66005 L .19608 .65548 L p .707 .577 .707 r
F P
0 g
s
.22354 .66005 m .22431 .71507 L .25548 .7168 L p .707 .577 .707 r
F P
0 g
s
.31592 .65633 m .31669 .71135 L .34074 .70472 L p .707 .577 .707 r
F P
0 g
s
.34074 .70472 m .33996 .64969 L .31592 .65633 L p .707 .577 .707 r
F P
0 g
s
.70468 .74692 m .70304 .78483 L .69039 .77947 L p .707 .577 .707 r
F P
0 g
s
.69039 .77947 m .69203 .74156 L .70468 .74692 L p .707 .577 .707 r
F P
0 g
s
.69091 .65038 m .69168 .70541 L .67062 .69845 L p .707 .577 .707 r
F P
0 g
s
.67062 .69845 m .66985 .64343 L .69091 .65038 L p .707 .577 .707 r
F P
0 g
s
.62977 .80022 m .63659 .29407 L .61349 .30296 L p .707 .577 .707 r
F P
0 g
s
.25459 .76452 m .25622 .72661 L .22506 .72415 L p .707 .577 .707 r
F P
0 g
s
.25622 .72661 m .25459 .76452 L .28639 .76537 L p .707 .577 .707 r
F P
0 g
s
.28639 .76537 m .28802 .72746 L .25622 .72661 L p .707 .577 .707 r
F P
0 g
s
.19685 .71051 m .19608 .65548 L .17502 .64852 L p .707 .577 .707 r
F P
0 g
s
.19608 .65548 m .19685 .71051 L .22431 .71507 L p .707 .577 .707 r
F P
0 g
s
.28802 .72746 m .28639 .76537 L .31572 .76451 L p .707 .577 .707 r
F P
0 g
s
.31572 .76451 m .31735 .72661 L .28802 .72746 L p .707 .577 .707 r
F P
0 g
s
.70131 .81611 m .69945 .83525 L .68657 .83323 L p .707 .577 .707 r
F P
0 g
s
.68657 .83323 m .68843 .81409 L .70131 .81611 L p .707 .577 .707 r
F P
0 g
s
.22506 .72415 m .22343 .76206 L .25459 .76452 L p .707 .577 .707 r
F P
0 g
s
.22343 .76206 m .22506 .72415 L .19759 .72032 L p .707 .577 .707 r
F P
0 g
s
.25263 .79173 m .25449 .77259 L .22338 .76939 L p .707 .577 .707 r
F P
0 g
s
.25449 .77259 m .25263 .79173 L .28428 .79471 L p .707 .577 .707 r
F P
0 g
s
.28428 .79471 m .28614 .77558 L .25449 .77259 L p .707 .577 .707 r
F P
0 g
s
.22338 .76939 m .22152 .78853 L .25263 .79173 L p .707 .577 .707 r
F P
0 g
s
.28614 .77558 m .28428 .79471 L .31337 .7972 L p .707 .577 .707 r
F P
0 g
s
.31337 .7972 m .31523 .77806 L .28614 .77558 L p .707 .577 .707 r
F P
0 g
s
.37381 .8025 m .38063 .29635 L .36284 .2863 L p .707 .577 .707 r
F P
0 g
s
.38063 .29635 m .37381 .8025 L .40354 .81091 L p .707 .577 .707 r
F P
0 g
s
.33996 .64969 m .34074 .70472 L .3571 .69625 L p .707 .577 .707 r
F P
0 g
s
.3571 .69625 m .35632 .64123 L .33996 .64969 L p .707 .577 .707 r
F P
0 g
s
.19759 .72032 m .19596 .75823 L .22343 .76206 L p .707 .577 .707 r
F P
0 g
s
.22152 .78853 m .22338 .76939 L .19586 .7663 L p .707 .577 .707 r
F P
0 g
s
.19586 .7663 m .194 .78543 L .22152 .78853 L p .707 .577 .707 r
F P
0 g
s
.31735 .72661 m .31572 .76451 L .3397 .76205 L p .707 .577 .707 r
F P
0 g
s
.3397 .76205 m .34133 .72414 L .31735 .72661 L p .707 .577 .707 r
F P
0 g
s
.66985 .64343 m .67062 .69845 L .64316 .69389 L p .707 .577 .707 r
F P
0 g
s
.64316 .69389 m .64239 .63886 L .66985 .64343 L p .707 .577 .707 r
F P
0 g
s
.17502 .64852 m .17579 .70355 L .19685 .71051 L p .707 .577 .707 r
F P
0 g
s
.19596 .75823 m .19759 .72032 L .1765 .71549 L p .707 .577 .707 r
F P
0 g
s
.69203 .74156 m .69039 .77947 L .6693 .77464 L p .707 .577 .707 r
F P
0 g
s
.6693 .77464 m .67094 .73673 L .69203 .74156 L p .707 .577 .707 r
F P
0 g
s
.17579 .70355 m .17502 .64852 L .16242 .63985 L p .707 .577 .707 r
F P
0 g
s
.31523 .77806 m .31337 .7972 L .33706 .79894 L p .707 .577 .707 r
F P
0 g
s
.33706 .79894 m .33892 .7798 L .31523 .77806 L p .707 .577 .707 r
F P
0 g
s
.1765 .71549 m .17487 .7534 L .19596 .75823 L p .707 .577 .707 r
F P
0 g
s
.194 .78543 m .19586 .7663 L .17462 .76361 L p .707 .577 .707 r
F P
0 g
s
.17462 .76361 m .17276 .78274 L .194 .78543 L p .707 .577 .707 r
F P
0 g
s
.68843 .81409 m .68657 .83323 L .66533 .83054 L p .707 .577 .707 r
F P
0 g
s
.66533 .83054 m .66719 .8114 L .68843 .81409 L p .707 .577 .707 r
F P
0 g
s
.63659 .29407 m .62977 .80022 L .63976 .78993 L p .707 .577 .707 r
F P
0 g
s
.63976 .78993 m .64658 .28379 L .63659 .29407 L p .707 .577 .707 r
F P
0 g
s
.34133 .72414 m .3397 .76205 L .35599 .75821 L p .707 .577 .707 r
F P
0 g
s
.35599 .75821 m .35763 .7203 L .34133 .72414 L p .707 .577 .707 r
F P
0 g
s
.35632 .64123 m .3571 .69625 L .36417 .68679 L p .707 .577 .707 r
F P
0 g
s
.36417 .68679 m .3634 .63177 L .35632 .64123 L p .707 .577 .707 r
F P
0 g
s
.16242 .63985 m .16319 .69488 L .17579 .70355 L p .707 .577 .707 r
F P
0 g
s
.33892 .7798 m .33706 .79894 L .35302 .79976 L p .707 .577 .707 r
F P
0 g
s
.35302 .79976 m .35488 .78062 L .33892 .7798 L p .707 .577 .707 r
F P
0 g
s
.17487 .7534 m .1765 .71549 L .16385 .71013 L p .707 .577 .707 r
F P
0 g
s
.67094 .73673 m .6693 .77464 L .64183 .7708 L p .707 .577 .707 r
F P
0 g
s
.64183 .7708 m .64347 .7329 L .67094 .73673 L p .707 .577 .707 r
F P
0 g
s
.16319 .69488 m .16242 .63985 L .15952 .63032 L p .707 .577 .707 r
F P
0 g
s
.35763 .7203 m .35599 .75821 L .363 .75337 L p .707 .577 .707 r
F P
0 g
s
.35488 .78062 m .35302 .79976 L .3597 .79959 L p .707 .577 .707 r
F P
0 g
s
.3597 .79959 m .36156 .78045 L .35488 .78062 L p .707 .577 .707 r
F P
0 g
s
.3605 .62224 m .36127 .67726 L .34867 .66859 L p .707 .577 .707 r
F P
0 g
s
.34867 .66859 m .3479 .61357 L .3605 .62224 L p .707 .577 .707 r
F P
0 g
s
.363 .75337 m .36463 .71546 L .35763 .7203 L p .707 .577 .707 r
F P
0 g
s
.36167 .71011 m .36003 .74801 L .35944 .74776 L p .707 .577 .707 r
F P
0 g
s
.35944 .74776 m .34739 .74266 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.35933 .71544 m .36167 .71011 L .35944 .74776 L .707 .577 .707 r
F
.36284 .2863 m .35874 .27561 L p .35818 .38242 L F P
0 g
s
.34739 .74266 m .34902 .70475 L .35931 .70911 L p .707 .577 .707 r
F P
0 g
s
.35931 .70911 m .36167 .71011 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.34739 .74266 m .35931 .70911 L .35933 .71544 L .707 .577 .707 r
F
.3583 .7793 m .35644 .79843 L .34356 .79641 L p F P
0 g
s
.34356 .79641 m .34542 .77728 L .3583 .7793 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35603 .79245 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35874 .27561 m .358 .33057 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.358 .33057 m .35193 .78176 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35603 .79245 m .35887 .58147 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35887 .58147 m .36284 .2863 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.3634 .63177 m .36417 .68679 L .36127 .67726 L p .707 .577 .707 r
F P
0 g
s
.36127 .67726 m .3605 .62224 L .3634 .63177 L p .707 .577 .707 r
F P
0 g
s
.36463 .71546 m .363 .75337 L .36003 .74801 L p .707 .577 .707 r
F P
0 g
s
.36003 .74801 m .36167 .71011 L .36463 .71546 L p .707 .577 .707 r
F P
0 g
s
.36156 .78045 m .3597 .79959 L .35644 .79843 L p .707 .577 .707 r
F P
0 g
s
.35644 .79843 m .3583 .7793 L .36156 .78045 L p .707 .577 .707 r
F P
0 g
s
.36284 .2863 m .35603 .79245 L .37381 .8025 L p .707 .577 .707 r
F P
0 g
s
.16385 .71013 m .16222 .74804 L .17487 .7534 L p .707 .577 .707 r
F P
0 g
s
.17276 .78274 m .17462 .76361 L .16173 .76159 L p .707 .577 .707 r
F P
0 g
s
.16173 .76159 m .15988 .78072 L .17276 .78274 L p .707 .577 .707 r
F P
0 g
s
.66719 .8114 m .66533 .83054 L .63781 .82744 L p .707 .577 .707 r
F P
0 g
s
.63781 .82744 m .63967 .80831 L .66719 .8114 L p .707 .577 .707 r
F P
0 g
s
.15952 .63032 m .16029 .68535 L .16319 .69488 L p .707 .577 .707 r
F P
0 g
s
.63967 .80831 m .63781 .82744 L .6067 .82424 L p .707 .577 .707 r
F P
0 g
s
.16222 .74804 m .16385 .71013 L .16089 .70477 L p .707 .577 .707 r
F P
0 g
s
.64658 .28379 m .63976 .78993 L .63566 .77925 L p .707 .577 .707 r
F P
0 g
s
.63566 .77925 m .64248 .2731 L .64658 .28379 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16089 .70477 m .15925 .74268 L .16222 .74804 L p .707 .577 .707 r
F P
0 g
s
.16029 .68535 m .15952 .63032 L .16659 .62086 L p .707 .577 .707 r
F P
0 g
s
.15988 .78072 m .16173 .76159 L .15847 .76043 L p .707 .577 .707 r
F P
0 g
s
.15847 .76043 m .15661 .77957 L .15988 .78072 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35874 .27561 L .36873 .26532 L p .707 .577 .707 r
F P
0 g
s
.16659 .62086 m .16737 .67589 L .16029 .68535 L p .707 .577 .707 r
F P
0 g
s
.15925 .74268 m .16089 .70477 L .16789 .69994 L p .707 .577 .707 r
F P
0 g
s
.16737 .67589 m .16659 .62086 L .18295 .6124 L p .707 .577 .707 r
F P
0 g
s
.16789 .69994 m .16626 .73784 L .15925 .74268 L p .707 .577 .707 r
F P
0 g
s
.15661 .77957 m .15847 .76043 L .16515 .76026 L p .707 .577 .707 r
F P
0 g
s
.16515 .76026 m .16329 .7794 L .15661 .77957 L p .707 .577 .707 r
F P
0 g
s
.64248 .2731 m .63566 .77925 L .61788 .7692 L p .707 .577 .707 r
F P
0 g
s
.61788 .7692 m .62469 .26305 L .64248 .2731 L p .707 .577 .707 r
F P
0 g
s
.3479 .61357 m .34867 .66859 L .32761 .66164 L p .707 .577 .707 r
F P
0 g
s
.32761 .66164 m .32684 .60661 L .3479 .61357 L p .707 .577 .707 r
F P
0 g
s
.18295 .6124 m .18373 .66743 L .16737 .67589 L p .707 .577 .707 r
F P
0 g
s
.16626 .73784 m .16789 .69994 L .18419 .6961 L p .707 .577 .707 r
F P
0 g
s
.18373 .66743 m .18295 .6124 L .207 .60576 L p .707 .577 .707 r
F P
0 g
s
.36192 .77147 m .36873 .26532 L .39183 .25644 L p .707 .577 .707 r
F P
0 g
s
.36873 .26532 m .36192 .77147 L .35193 .78176 L p .707 .577 .707 r
F P
0 g
s
.18419 .6961 m .18255 .734 L .16626 .73784 L p .707 .577 .707 r
F P
0 g
s
.16329 .7794 m .16515 .76026 L .18112 .76108 L p .707 .577 .707 r
F P
0 g
s
.18112 .76108 m .17926 .78022 L .16329 .7794 L p .707 .577 .707 r
F P
0 g
s
.32684 .60661 m .32761 .66164 L .30015 .65707 L p .707 .577 .707 r
F P
0 g
s
.30015 .65707 m .29938 .60205 L .32684 .60661 L p .707 .577 .707 r
F P
0 g
s
.34902 .70475 m .34739 .74266 L .32629 .73782 L p .707 .577 .707 r
F P
0 g
s
.32629 .73782 m .32793 .69992 L .34902 .70475 L p .707 .577 .707 r
F P
0 g
s
.207 .60576 m .20777 .66079 L .18373 .66743 L p .707 .577 .707 r
F P
0 g
s
.20777 .66079 m .207 .60576 L .23638 .6016 L p .707 .577 .707 r
F P
0 g
s
.62469 .26305 m .61788 .7692 L .58815 .76079 L p .707 .577 .707 r
F P
0 g
s
.58815 .76079 m .59496 .25464 L .62469 .26305 L p .707 .577 .707 r
F P
0 g
s
.18255 .734 m .18419 .6961 L .20817 .69363 L p .707 .577 .707 r
F P
0 g
s
.29938 .60205 m .30015 .65707 L .26898 .65534 L p .707 .577 .707 r
F P
0 g
s
.26898 .65534 m .26821 .60032 L .29938 .60205 L p .707 .577 .707 r
F P
0 g
s
.34542 .77728 m .34356 .79641 L .32232 .79372 L p .707 .577 .707 r
F P
0 g
s
.32232 .79372 m .32418 .77459 L .34542 .77728 L p .707 .577 .707 r
F P
0 g
s
.23715 .65662 m .23638 .6016 L .26821 .60032 L p .707 .577 .707 r
F P
0 g
s
.23638 .6016 m .23715 .65662 L .20777 .66079 L p .707 .577 .707 r
F P
0 g
s
.20817 .69363 m .20654 .73154 L .18255 .734 L p .707 .577 .707 r
F P
0 g
s
.26821 .60032 m .26898 .65534 L .23715 .65662 L p .707 .577 .707 r
F P
0 g
s
.17926 .78022 m .18112 .76108 L .2048 .76282 L p .707 .577 .707 r
F P
0 g
s
.7357 .65691 m .73492 .60188 L .70375 .60015 L p .707 .577 .707 r
F P
0 g
s
.73492 .60188 m .7357 .65691 L .76753 .65563 L p .707 .577 .707 r
F P
0 g
s
.76753 .65563 m .76675 .6006 L .73492 .60188 L p .707 .577 .707 r
F P
0 g
s
.2048 .76282 m .20295 .78196 L .17926 .78022 L p .707 .577 .707 r
F P
0 g
s
.39183 .25644 m .38502 .76259 L .36192 .77147 L p .707 .577 .707 r
F P
0 g
s
.38502 .76259 m .39183 .25644 L .42578 .24984 L p .707 .577 .707 r
F P
0 g
s
.76675 .6006 m .76753 .65563 L .7969 .65146 L p .707 .577 .707 r
F P
0 g
s
.7969 .65146 m .79613 .59644 L .76675 .6006 L p .707 .577 .707 r
F P
0 g
s
.32793 .69992 m .32629 .73782 L .29882 .73399 L p .707 .577 .707 r
F P
0 g
s
.29882 .73399 m .30046 .69608 L .32793 .69992 L p .707 .577 .707 r
F P
0 g
s
.70452 .65518 m .70375 .60015 L .67629 .59559 L p .707 .577 .707 r
F P
0 g
s
.70375 .60015 m .70452 .65518 L .7357 .65691 L p .707 .577 .707 r
F P
0 g
s
.20654 .73154 m .20817 .69363 L .2375 .69278 L p .707 .577 .707 r
F P
0 g
s
.79613 .59644 m .7969 .65146 L .82095 .64482 L p .707 .577 .707 r
F P
0 g
s
.82095 .64482 m .82018 .5898 L .79613 .59644 L p .707 .577 .707 r
F P
0 g
s
.32418 .77459 m .32232 .79372 L .2948 .79063 L p .707 .577 .707 r
F P
0 g
s
.2948 .79063 m .29666 .77149 L .32418 .77459 L p .707 .577 .707 r
F P
0 g
s
.2375 .69278 m .23586 .73069 L .20654 .73154 L p .707 .577 .707 r
F P
0 g
s
.30046 .69608 m .29882 .73399 L .26766 .73153 L p .707 .577 .707 r
F P
0 g
s
.26766 .73153 m .2693 .69362 L .30046 .69608 L p .707 .577 .707 r
F P
0 g
s
.59496 .25464 m .58815 .76079 L .54938 .75483 L p .707 .577 .707 r
F P
0 g
s
.54938 .75483 m .5562 .24868 L .59496 .25464 L p .707 .577 .707 r
F P
0 g
s
.20295 .78196 m .2048 .76282 L .2339 .76531 L p .707 .577 .707 r
F P
0 g
s
.7348 .70272 m .73644 .66481 L .70528 .66236 L p .707 .577 .707 r
F P
0 g
s
.73644 .66481 m .7348 .70272 L .7666 .70357 L p .707 .577 .707 r
F P
0 g
s
.7666 .70357 m .76824 .66566 L .73644 .66481 L p .707 .577 .707 r
F P
0 g
s
.2339 .76531 m .23204 .78444 L .20295 .78196 L p .707 .577 .707 r
F P
0 g
s
.67707 .65061 m .67629 .59559 L .65523 .58863 L p .707 .577 .707 r
F P
0 g
s
.67629 .59559 m .67707 .65061 L .70452 .65518 L p .707 .577 .707 r
F P
0 g
s
.23586 .73069 m .2375 .69278 L .2693 .69362 L p .707 .577 .707 r
F P
0 g
s
.76824 .66566 m .7666 .70357 L .79593 .70271 L p .707 .577 .707 r
F P
0 g
s
.79593 .70271 m .79756 .66481 L .76824 .66566 L p .707 .577 .707 r
F P
0 g
s
.2693 .69362 m .26766 .73153 L .23586 .73069 L p .707 .577 .707 r
F P
0 g
s
.70528 .66236 m .70364 .70026 L .7348 .70272 L p .707 .577 .707 r
F P
0 g
s
.70364 .70026 m .70528 .66236 L .67781 .65852 L p .707 .577 .707 r
F P
0 g
s
.41896 .75599 m .42578 .24984 L .46725 .24615 L p .707 .577 .707 r
F P
0 g
s
.42578 .24984 m .41896 .75599 L .38502 .76259 L p .707 .577 .707 r
F P
0 g
s
.29666 .77149 m .2948 .79063 L .26369 .78743 L p .707 .577 .707 r
F P
0 g
s
.26369 .78743 m .26555 .76829 L .29666 .77149 L p .707 .577 .707 r
F P
0 g
s
.73284 .73408 m .7347 .71494 L .70359 .71175 L p .707 .577 .707 r
F P
0 g
s
.7347 .71494 m .73284 .73408 L .76449 .73707 L p .707 .577 .707 r
F P
0 g
s
.76449 .73707 m .76635 .71793 L .7347 .71494 L p .707 .577 .707 r
F P
0 g
s
.70359 .71175 m .70173 .73088 L .73284 .73408 L p .707 .577 .707 r
F P
0 g
s
.23204 .78444 m .2339 .76531 L .26555 .76829 L p .707 .577 .707 r
F P
0 g
s
.76635 .71793 m .76449 .73707 L .79358 .73955 L p .707 .577 .707 r
F P
0 g
s
.79358 .73955 m .79544 .72042 L .76635 .71793 L p .707 .577 .707 r
F P
0 g
s
.67781 .65852 m .67617 .69643 L .70364 .70026 L p .707 .577 .707 r
F P
0 g
s
.26555 .76829 m .26369 .78743 L .23204 .78444 L p .707 .577 .707 r
F P
0 g
s
.82018 .5898 m .82095 .64482 L .83731 .63636 L p .707 .577 .707 r
F P
0 g
s
.83731 .63636 m .83654 .58134 L .82018 .5898 L p .707 .577 .707 r
F P
0 g
s
.79756 .66481 m .79593 .70271 L .81991 .70025 L p .707 .577 .707 r
F P
0 g
s
.81991 .70025 m .82155 .66234 L .79756 .66481 L p .707 .577 .707 r
F P
0 g
s
.70173 .73088 m .70359 .71175 L .67607 .70865 L p .707 .577 .707 r
F P
0 g
s
.67607 .70865 m .67421 .72779 L .70173 .73088 L p .707 .577 .707 r
F P
0 g
s
.65523 .58863 m .65601 .64366 L .67707 .65061 L p .707 .577 .707 r
F P
0 g
s
.5562 .24868 m .54938 .75483 L .50538 .75191 L p .707 .577 .707 r
F P
0 g
s
.50538 .75191 m .51219 .24576 L .5562 .24868 L p .707 .577 .707 r
F P
0 g
s
.67617 .69643 m .67781 .65852 L .65671 .65369 L p .707 .577 .707 r
F P
0 g
s
.65601 .64366 m .65523 .58863 L .64263 .57996 L p .707 .577 .707 r
F P
0 g
s
.79544 .72042 m .79358 .73955 L .81727 .74129 L p .707 .577 .707 r
F P
0 g
s
.81727 .74129 m .81913 .72215 L .79544 .72042 L p .707 .577 .707 r
F P
0 g
s
.46044 .7523 m .46725 .24615 L .51219 .24576 L p .707 .577 .707 r
F P
0 g
s
.46725 .24615 m .46044 .7523 L .41896 .75599 L p .707 .577 .707 r
F P
0 g
s
.65671 .65369 m .65508 .6916 L .67617 .69643 L p .707 .577 .707 r
F P
0 g
s
.51219 .24576 m .50538 .75191 L .46044 .7523 L p .707 .577 .707 r
F P
0 g
s
.67421 .72779 m .67607 .70865 L .65483 .70596 L p .707 .577 .707 r
F P
0 g
s
.65483 .70596 m .65297 .7251 L .67421 .72779 L p .707 .577 .707 r
F P
0 g
s
.82155 .66234 m .81991 .70025 L .83621 .69641 L p .707 .577 .707 r
F P
0 g
s
.83621 .69641 m .83784 .6585 L .82155 .66234 L p .707 .577 .707 r
F P
0 g
s
.83654 .58134 m .83731 .63636 L .84439 .6269 L p .707 .577 .707 r
F P
0 g
s
.84439 .6269 m .84361 .57188 L .83654 .58134 L p .707 .577 .707 r
F P
0 g
s
.64263 .57996 m .64341 .63499 L .65601 .64366 L p .707 .577 .707 r
F P
0 g
s
.65508 .6916 m .65671 .65369 L .64407 .64833 L p .707 .577 .707 r
F P
0 g
s
.81913 .72215 m .81727 .74129 L .83324 .74211 L p .707 .577 .707 r
F P
0 g
s
.83324 .74211 m .8351 .72298 L .81913 .72215 L p .707 .577 .707 r
F P
0 g
s
.64341 .63499 m .64263 .57996 L .63973 .57043 L p .707 .577 .707 r
F P
0 g
s
.64407 .64833 m .64243 .68624 L .65508 .6916 L p .707 .577 .707 r
F P
0 g
s
.65297 .7251 m .65483 .70596 L .64195 .70394 L p .707 .577 .707 r
F P
0 g
s
.64195 .70394 m .64009 .72308 L .65297 .7251 L p .707 .577 .707 r
F P
0 g
s
.83784 .6585 m .83621 .69641 L .84321 .69157 L p .707 .577 .707 r
F P
0 g
s
.84321 .69157 m .84485 .65367 L .83784 .6585 L p .707 .577 .707 r
F P
0 g
s
.84361 .57188 m .84439 .6269 L .84148 .61737 L p .707 .577 .707 r
F P
0 g
s
.84148 .61737 m .84071 .56234 L .84361 .57188 L p .707 .577 .707 r
F P
0 g
s
.63973 .57043 m .6405 .62546 L .64341 .63499 L p .707 .577 .707 r
F P
0 g
s
.8351 .72298 m .83324 .74211 L .83992 .74194 L p .707 .577 .707 r
F P
0 g
s
.83992 .74194 m .84178 .7228 L .8351 .72298 L p .707 .577 .707 r
F P
0 g
s
.64243 .68624 m .64407 .64833 L .6411 .64297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6411 .64297 m .63947 .68088 L .64243 .68624 L p .707 .577 .707 r
F P
0 g
s
.6405 .62546 m .63973 .57043 L .6468 .56097 L p .707 .577 .707 r
F P
0 g
s
.64009 .72308 m .64195 .70394 L .63869 .70279 L p .707 .577 .707 r
F P
0 g
s
.63869 .70279 m .63683 .72192 L .64009 .72308 L p .707 .577 .707 r
F P
0 g
s
.84485 .65367 m .84321 .69157 L .84025 .68621 L p .707 .577 .707 r
F P
0 g
s
.84025 .68621 m .84188 .64831 L .84485 .65367 L p .707 .577 .707 r
F P
0 g
s
.84071 .56234 m .84148 .61737 L .82889 .6087 L p .707 .577 .707 r
F P
0 g
s
.82889 .6087 m .82811 .55368 L .84071 .56234 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6468 .56097 m .64758 .616 L .6405 .62546 L p .707 .577 .707 r
F P
0 g
s
.84178 .7228 m .83992 .74194 L .83666 .74079 L p .707 .577 .707 r
F P
0 g
s
.83666 .74079 m .83852 .72165 L .84178 .7228 L p .707 .577 .707 r
F P
0 g
s
.63947 .68088 m .6411 .64297 L .64811 .63814 L p .707 .577 .707 r
F P
0 g
s
.39269 .62009 m .39191 .56507 L .36074 .56334 L p .707 .577 .707 r
F P
0 g
s
.39191 .56507 m .39269 .62009 L .42452 .61881 L p .707 .577 .707 r
F P
0 g
s
.42452 .61881 m .42374 .56378 L .39191 .56507 L p .707 .577 .707 r
F P
0 g
s
.64758 .616 m .6468 .56097 L .66317 .55251 L p .707 .577 .707 r
F P
0 g
s
.64811 .63814 m .64647 .67604 L .63947 .68088 L p .707 .577 .707 r
F P
0 g
s
.42374 .56378 m .42452 .61881 L .45389 .61465 L p .707 .577 .707 r
F P
0 g
s
.45389 .61465 m .45312 .55962 L .42374 .56378 L p .707 .577 .707 r
F P
0 g
s
.63683 .72192 m .63869 .70279 L .64537 .70261 L p .707 .577 .707 r
F P
0 g
s
.64537 .70261 m .64351 .72175 L .63683 .72192 L p .707 .577 .707 r
F P
0 g
s
.36151 .61836 m .36074 .56334 L .33328 .55877 L p .707 .577 .707 r
F P
0 g
s
.36074 .56334 m .36151 .61836 L .39269 .62009 L p .707 .577 .707 r
F P
0 g
s
.45312 .55962 m .45389 .61465 L .47794 .60801 L p .707 .577 .707 r
F P
0 g
s
.47794 .60801 m .47717 .55298 L .45312 .55962 L p .707 .577 .707 r
F P
0 g
s
.84188 .64831 m .84025 .68621 L .8276 .68086 L p .707 .577 .707 r
F P
0 g
s
.8276 .68086 m .82923 .64295 L .84188 .64831 L p .707 .577 .707 r
F P
0 g
s
.82811 .55368 m .82889 .6087 L .80783 .60174 L p .707 .577 .707 r
F P
0 g
s
.80783 .60174 m .80705 .54672 L .82811 .55368 L p .707 .577 .707 r
F P
0 g
s
.66317 .55251 m .66394 .60753 L .64758 .616 L p .707 .577 .707 r
F P
0 g
s
.39179 .66591 m .39343 .628 L .36227 .62554 L p .707 .577 .707 r
F P
0 g
s
.39343 .628 m .39179 .66591 L .42359 .66675 L p .707 .577 .707 r
F P
0 g
s
.42359 .66675 m .42523 .62884 L .39343 .628 L p .707 .577 .707 r
F P
0 g
s
.33406 .6138 m .33328 .55877 L .31222 .55181 L p .707 .577 .707 r
F P
0 g
s
.33328 .55877 m .33406 .6138 L .36151 .61836 L p .707 .577 .707 r
F P
0 g
s
.42523 .62884 m .42359 .66675 L .45292 .6659 L p .707 .577 .707 r
F P
0 g
s
.45292 .6659 m .45455 .62799 L .42523 .62884 L p .707 .577 .707 r
F P
0 g
s
.64647 .67604 m .64811 .63814 L .6644 .6343 L p .707 .577 .707 r
F P
0 g
s
.83852 .72165 m .83666 .74079 L .82377 .73876 L p .707 .577 .707 r
F P
0 g
s
.82377 .73876 m .82563 .71963 L .83852 .72165 L p .707 .577 .707 r
F P
0 g
s
.66394 .60753 m .66317 .55251 L .68721 .54587 L p .707 .577 .707 r
F P
0 g
s
.36227 .62554 m .36063 .66345 L .39179 .66591 L p .707 .577 .707 r
F P
0 g
s
.36063 .66345 m .36227 .62554 L .3348 .62171 L p .707 .577 .707 r
F P
0 g
s
.38983 .69726 m .39169 .67813 L .36058 .67493 L p .707 .577 .707 r
F P
0 g
s
.39169 .67813 m .38983 .69726 L .42148 .70025 L p .707 .577 .707 r
F P
0 g
s
.42148 .70025 m .42334 .68112 L .39169 .67813 L p .707 .577 .707 r
F P
0 g
s
.36058 .67493 m .35872 .69407 L .38983 .69726 L p .707 .577 .707 r
F P
0 g
s
.6644 .6343 m .66277 .67221 L .64647 .67604 L p .707 .577 .707 r
F P
0 g
s
.42334 .68112 m .42148 .70025 L .45058 .70274 L p .707 .577 .707 r
F P
0 g
s
.45058 .70274 m .45243 .6836 L .42334 .68112 L p .707 .577 .707 r
F P
0 g
s
.3348 .62171 m .33316 .65961 L .36063 .66345 L p .707 .577 .707 r
F P
0 g
s
.47717 .55298 m .47794 .60801 L .4943 .59955 L p .707 .577 .707 r
F P
0 g
s
.4943 .59955 m .49353 .54452 L .47717 .55298 L p .707 .577 .707 r
F P
0 g
s
.45455 .62799 m .45292 .6659 L .4769 .66343 L p .707 .577 .707 r
F P
0 g
s
.4769 .66343 m .47854 .62552 L .45455 .62799 L p .707 .577 .707 r
F P
0 g
s
.64351 .72175 m .64537 .70261 L .66133 .70344 L p .707 .577 .707 r
F P
0 g
s
.35872 .69407 m .36058 .67493 L .33306 .67184 L p .707 .577 .707 r
F P
0 g
s
.66133 .70344 m .65947 .72257 L .64351 .72175 L p .707 .577 .707 r
F P
0 g
s
.33306 .67184 m .3312 .69097 L .35872 .69407 L p .707 .577 .707 r
F P
0 g
s
.80705 .54672 m .80783 .60174 L .78037 .59718 L p .707 .577 .707 r
F P
0 g
s
.78037 .59718 m .77959 .54215 L .80705 .54672 L p .707 .577 .707 r
F P
0 g
s
.31222 .55181 m .313 .60684 L .33406 .6138 L p .707 .577 .707 r
F P
0 g
s
.33316 .65961 m .3348 .62171 L .3137 .61687 L p .707 .577 .707 r
F P
0 g
s
.82923 .64295 m .8276 .68086 L .80651 .67602 L p .707 .577 .707 r
F P
0 g
s
.80651 .67602 m .80814 .63812 L .82923 .64295 L p .707 .577 .707 r
F P
0 g
s
.68721 .54587 m .68799 .6009 L .66394 .60753 L p .707 .577 .707 r
F P
0 g
s
.313 .60684 m .31222 .55181 L .29962 .54315 L p .707 .577 .707 r
F P
0 g
s
.45243 .6836 m .45058 .70274 L .47426 .70448 L p .707 .577 .707 r
F P
0 g
s
.47426 .70448 m .47612 .68534 L .45243 .6836 L p .707 .577 .707 r
F P
0 g
s
.68799 .6009 m .68721 .54587 L .71659 .54171 L p .707 .577 .707 r
F P
0 g
s
.3137 .61687 m .31207 .65478 L .33316 .65961 L p .707 .577 .707 r
F P
0 g
s
.3312 .69097 m .33306 .67184 L .31182 .66915 L p .707 .577 .707 r
F P
0 g
s
.66277 .67221 m .6644 .6343 L .68838 .63183 L p .707 .577 .707 r
F P
0 g
s
.31182 .66915 m .30996 .68828 L .3312 .69097 L p .707 .577 .707 r
F P
0 g
s
.77959 .54215 m .78037 .59718 L .7492 .59545 L p .707 .577 .707 r
F P
0 g
s
.7492 .59545 m .74842 .54043 L .77959 .54215 L p .707 .577 .707 r
F P
0 g
s
.82563 .71963 m .82377 .73876 L .80253 .73608 L p .707 .577 .707 r
F P
0 g
s
.80253 .73608 m .80439 .71694 L .82563 .71963 L p .707 .577 .707 r
F P
0 g
s
.47854 .62552 m .4769 .66343 L .4932 .65959 L p .707 .577 .707 r
F P
0 g
s
.4932 .65959 m .49483 .62169 L .47854 .62552 L p .707 .577 .707 r
F P
0 g
s
.71736 .59673 m .71659 .54171 L .74842 .54043 L p .707 .577 .707 r
F P
0 g
s
.71659 .54171 m .71736 .59673 L .68799 .6009 L p .707 .577 .707 r
F P
0 g
s
.68838 .63183 m .68675 .66974 L .66277 .67221 L p .707 .577 .707 r
F P
0 g
s
.49353 .54452 m .4943 .59955 L .50138 .59009 L p .707 .577 .707 r
F P
0 g
s
.50138 .59009 m .5006 .53506 L .49353 .54452 L p .707 .577 .707 r
F P
0 g
s
.74842 .54043 m .7492 .59545 L .71736 .59673 L p .707 .577 .707 r
F P
0 g
s
.29962 .54315 m .3004 .59817 L .313 .60684 L p .707 .577 .707 r
F P
0 g
s
.65947 .72257 m .66133 .70344 L .68502 .70517 L p .707 .577 .707 r
F P
0 g
s
.68502 .70517 m .68316 .72431 L .65947 .72257 L p .707 .577 .707 r
F P
0 g
s
.31207 .65478 m .3137 .61687 L .30106 .61152 L p .707 .577 .707 r
F P
0 g
s
.80814 .63812 m .80651 .67602 L .77904 .67219 L p .707 .577 .707 r
F P
0 g
s
.77904 .67219 m .78067 .63428 L .80814 .63812 L p .707 .577 .707 r
F P
0 g
s
.47612 .68534 m .47426 .70448 L .49023 .7053 L p .707 .577 .707 r
F P
0 g
s
.49023 .7053 m .49209 .68616 L .47612 .68534 L p .707 .577 .707 r
F P
0 g
s
.3004 .59817 m .29962 .54315 L .29672 .53362 L p .707 .577 .707 r
F P
0 g
s
.30106 .61152 m .29942 .64942 L .31207 .65478 L p .707 .577 .707 r
F P
0 g
s
.68675 .66974 m .68838 .63183 L .71771 .63098 L p .707 .577 .707 r
F P
0 g
s
.30996 .68828 m .31182 .66915 L .29894 .66713 L p .707 .577 .707 r
F P
0 g
s
.29894 .66713 m .29708 .68626 L .30996 .68828 L p .707 .577 .707 r
F P
0 g
s
.80439 .71694 m .80253 .73608 L .77501 .73298 L p .707 .577 .707 r
F P
0 g
s
.77501 .73298 m .77687 .71384 L .80439 .71694 L p .707 .577 .707 r
F P
0 g
s
.71771 .63098 m .71608 .66889 L .68675 .66974 L p .707 .577 .707 r
F P
0 g
s
.78067 .63428 m .77904 .67219 L .74788 .66973 L p .707 .577 .707 r
F P
0 g
s
.74788 .66973 m .74951 .63182 L .78067 .63428 L p .707 .577 .707 r
F P
0 g
s
.49483 .62169 m .4932 .65959 L .5002 .65476 L p .707 .577 .707 r
F P
0 g
s
.5002 .65476 m .50184 .61685 L .49483 .62169 L p .707 .577 .707 r
F P
0 g
s
.68316 .72431 m .68502 .70517 L .71411 .70766 L p .707 .577 .707 r
F P
0 g
s
.71411 .70766 m .71225 .72679 L .68316 .72431 L p .707 .577 .707 r
F P
0 g
s
.71608 .66889 m .71771 .63098 L .74951 .63182 L p .707 .577 .707 r
F P
0 g
s
.5006 .53506 m .50138 .59009 L .49847 .58056 L p .707 .577 .707 r
F P
0 g
s
.49847 .58056 m .4977 .52553 L .5006 .53506 L p .707 .577 .707 r
F P
0 g
s
.74951 .63182 m .74788 .66973 L .71608 .66889 L p .707 .577 .707 r
F P
0 g
s
.29672 .53362 m .29749 .58864 L .3004 .59817 L p .707 .577 .707 r
F P
0 g
s
.77687 .71384 m .77501 .73298 L .7439 .72978 L p .707 .577 .707 r
F P
0 g
s
.7439 .72978 m .74576 .71065 L .77687 .71384 L p .707 .577 .707 r
F P
0 g
s
.49209 .68616 m .49023 .7053 L .49691 .70512 L p .707 .577 .707 r
F P
0 g
s
.49691 .70512 m .49877 .68599 L .49209 .68616 L p .707 .577 .707 r
F P
0 g
s
.29942 .64942 m .30106 .61152 L .29809 .60616 L p .707 .577 .707 r
F P
0 g
s
.71225 .72679 m .71411 .70766 L .74576 .71065 L p .707 .577 .707 r
F P
0 g
s
.74576 .71065 m .7439 .72978 L .71225 .72679 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29809 .60616 m .29646 .64406 L .29942 .64942 L p .707 .577 .707 r
F P
0 g
s
.29749 .58864 m .29672 .53362 L .30379 .52416 L p .707 .577 .707 r
F P
0 g
s
.29708 .68626 m .29894 .66713 L .29568 .66597 L p .707 .577 .707 r
F P
0 g
s
.29568 .66597 m .29382 .68511 L .29708 .68626 L p .707 .577 .707 r
F P
0 g
s
.50184 .61685 m .5002 .65476 L .49724 .6494 L p .707 .577 .707 r
F P
0 g
s
.49724 .6494 m .49887 .61149 L .50184 .61685 L p .707 .577 .707 r
F P
0 g
s
.4977 .52553 m .49847 .58056 L .48588 .57189 L p .707 .577 .707 r
F P
0 g
s
.48588 .57189 m .4851 .51686 L .4977 .52553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30379 .52416 m .30457 .57918 L .29749 .58864 L p .707 .577 .707 r
F P
0 g
s
.49877 .68599 m .49691 .70512 L .49365 .70397 L p .707 .577 .707 r
F P
0 g
s
.49365 .70397 m .49551 .68483 L .49877 .68599 L p .707 .577 .707 r
F P
0 g
s
.29646 .64406 m .29809 .60616 L .3051 .60132 L p .707 .577 .707 r
F P
0 g
s
.30457 .57918 m .30379 .52416 L .32016 .51569 L p .707 .577 .707 r
F P
0 g
s
.3051 .60132 m .30346 .63923 L .29646 .64406 L p .707 .577 .707 r
F P
0 g
s
.29382 .68511 m .29568 .66597 L .30236 .6658 L p .707 .577 .707 r
F P
0 g
s
.30236 .6658 m .3005 .68493 L .29382 .68511 L p .707 .577 .707 r
F P
0 g
s
.49887 .61149 m .49724 .6494 L .48459 .64404 L p .707 .577 .707 r
F P
0 g
s
.48459 .64404 m .48622 .60613 L .49887 .61149 L p .707 .577 .707 r
F P
0 g
s
.4851 .51686 m .48588 .57189 L .46482 .56493 L p .707 .577 .707 r
F P
0 g
s
.46482 .56493 m .46404 .5099 L .4851 .51686 L p .707 .577 .707 r
F P
0 g
s
.32016 .51569 m .32093 .57072 L .30457 .57918 L p .707 .577 .707 r
F P
0 g
s
.30346 .63923 m .3051 .60132 L .32139 .59748 L p .707 .577 .707 r
F P
0 g
s
.49551 .68483 m .49365 .70397 L .48076 .70195 L p .707 .577 .707 r
F P
0 g
s
.48076 .70195 m .48262 .68281 L .49551 .68483 L p .707 .577 .707 r
F P
0 g
s
.32093 .57072 m .32016 .51569 L .3442 .50905 L p .707 .577 .707 r
F P
0 g
s
.32139 .59748 m .31976 .63539 L .30346 .63923 L p .707 .577 .707 r
F P
0 g
s
.3005 .68493 m .30236 .6658 L .31832 .66662 L p .707 .577 .707 r
F P
0 g
s
.31832 .66662 m .31646 .68576 L .3005 .68493 L p .707 .577 .707 r
F P
0 g
s
.46404 .5099 m .46482 .56493 L .43736 .56036 L p .707 .577 .707 r
F P
0 g
s
.43736 .56036 m .43658 .50534 L .46404 .5099 L p .707 .577 .707 r
F P
0 g
s
.48622 .60613 m .48459 .64404 L .4635 .63921 L p .707 .577 .707 r
F P
0 g
s
.4635 .63921 m .46513 .6013 L .48622 .60613 L p .707 .577 .707 r
F P
0 g
s
.3442 .50905 m .34498 .56408 L .32093 .57072 L p .707 .577 .707 r
F P
0 g
s
.34498 .56408 m .3442 .50905 L .37358 .50489 L p .707 .577 .707 r
F P
0 g
s
.31976 .63539 m .32139 .59748 L .34537 .59502 L p .707 .577 .707 r
F P
0 g
s
.43658 .50534 m .43736 .56036 L .40619 .55864 L p .707 .577 .707 r
F P
0 g
s
.40619 .55864 m .40541 .50361 L .43658 .50534 L p .707 .577 .707 r
F P
0 g
s
.48262 .68281 m .48076 .70195 L .45952 .69926 L p .707 .577 .707 r
F P
0 g
s
.45952 .69926 m .46138 .68012 L .48262 .68281 L p .707 .577 .707 r
F P
0 g
s
.37435 .55992 m .37358 .50489 L .40541 .50361 L p .707 .577 .707 r
F P
0 g
s
.37358 .50489 m .37435 .55992 L .34498 .56408 L p .707 .577 .707 r
F P
0 g
s
.34537 .59502 m .34374 .63292 L .31976 .63539 L p .707 .577 .707 r
F P
0 g
s
.40541 .50361 m .40619 .55864 L .37435 .55992 L p .707 .577 .707 r
F P
0 g
s
.31646 .68576 m .31832 .66662 L .34201 .66836 L p .707 .577 .707 r
F P
0 g
s
.34201 .66836 m .34015 .68749 L .31646 .68576 L p .707 .577 .707 r
F P
0 g
s
.46513 .6013 m .4635 .63921 L .43603 .63537 L p .707 .577 .707 r
F P
0 g
s
.43603 .63537 m .43766 .59747 L .46513 .6013 L p .707 .577 .707 r
F P
0 g
s
.34374 .63292 m .34537 .59502 L .3747 .59416 L p .707 .577 .707 r
F P
0 g
s
.46138 .68012 m .45952 .69926 L .432 .69616 L p .707 .577 .707 r
F P
0 g
s
.432 .69616 m .43386 .67703 L .46138 .68012 L p .707 .577 .707 r
F P
0 g
s
.3747 .59416 m .37307 .63207 L .34374 .63292 L p .707 .577 .707 r
F P
0 g
s
.43766 .59747 m .43603 .63537 L .40487 .63292 L p .707 .577 .707 r
F P
0 g
s
.40487 .63292 m .4065 .59501 L .43766 .59747 L p .707 .577 .707 r
F P
0 g
s
.34015 .68749 m .34201 .66836 L .3711 .67084 L p .707 .577 .707 r
F P
0 g
s
.3711 .67084 m .36924 .68998 L .34015 .68749 L p .707 .577 .707 r
F P
0 g
s
.37307 .63207 m .3747 .59416 L .4065 .59501 L p .707 .577 .707 r
F P
0 g
s
.4065 .59501 m .40487 .63292 L .37307 .63207 L p .707 .577 .707 r
F P
0 g
s
.43386 .67703 m .432 .69616 L .40089 .69297 L p .707 .577 .707 r
F P
0 g
s
.40089 .69297 m .40275 .67383 L .43386 .67703 L p .707 .577 .707 r
F P
0 g
s
.36924 .68998 m .3711 .67084 L .40275 .67383 L p .707 .577 .707 r
F P
0 g
s
.40275 .67383 m .40089 .69297 L .36924 .68998 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3@00QGoo001oOol<0006FUH00`00FUIJEP04FUH9001lOol007Moo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Ioo`00LWoo1@000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1000LWoo001^Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001^Ool006Yoo`@00003FUH0
05YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<006]oo`00J7oo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JGoo001WOol20006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006EooaT000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00H7oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001MOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol005]oo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00FGoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001GOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
05Ioo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00EGoo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Uoo`T0
04Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF009JEPP0
03aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH003Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<002moo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF2`001UYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF70000eYF1P0015YF
00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YF00000`00
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00E7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo001DOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000]Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH:0008FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00D005YFFUH005YF00d000=JEP03001JEUYF
009JEPl000=JEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo0018Ool90004Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF2P0017oo3P0000=JEP0000000P000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?goo2@0015YF00<005YFFUH00UYF1`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P00
00=JEP0000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YF00000`001UYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEPD0
00AJEP04001JEUYFFUH2000/Ool003Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP8002aoo`00=Woo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH005YF
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH30003FUH2000/Ool003=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000;7oo000aOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00
;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000/Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000eJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEQT00003FUH005YF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEPD00003FUH005YF00EJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YFFUIJ
EP0002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF00<0
05YFFUH015YF1P0015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH700001EYF001JEUYF0000<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000<Goo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF5`0000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002aoo`00;Goo00<005YF000015YF00<005YFFUH00eYF2P000goo1@0000=oo`0000001`0000=J
EP0000002@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002eoo`03001JEP0000AJEP03
001JEP0000<000EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEP0000<000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;7oo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP0:00001EYF00000000FUH00P0000=JEP00FUH00eYF6@002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00@005YFFUIJEQ0000UJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00FUIJEPL000MJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00;Goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000]Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
1`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000UYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP070002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP04000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF010000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002ioo`04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80002FUH90004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF000000020004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Woo00D005YFFUH005YF02@000=JEP03001JEUYF00=JEP03001JEP00
00L000=JEQ4000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH300000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000_Ool01P00
FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
00EJEP03001JEUYF00800003FUH005YF009JEPT000AJEP03001JEUYF00AJEPL000=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02000_Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPP00004Ool005YF0006FUH00`00FUIJEP03FUH@0002FUH50002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH300000eYF0000000?0004FUH00`00FUIJEP02FUH>000aOol002eoo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP`00003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00d0009JEP8000]oo`T0
03moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00@005YFFUIJEPT004ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@00?Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<002eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH0000000X000=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH:0003FUH90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00002FUH>0008FUH@0004
FUH00`00FUIJEP03FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=J
EP00FUH01EYF00D005YFFUIJEP0000Eoo`T000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00;Goo00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF1P0015YF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00=JEPL00003FUH005YF008000moo`P000=JEPL000=JEP03001JEUYF008002ioo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP<00006FUH005YF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF
00<005YFFUH0100067oo4P00;Woo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH500000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP03FUH3000SOol4000_Ool002ioo`04
001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJ
EP03001JEUYF00=JEP03001JEUYF008005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHI0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000aOol30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00EJEPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol003Aoo`L000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0
009JEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001C
Ool002eooaL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000017oo001JEP00
1EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH010001UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00
;Goo0P0015YF00<005YFFUH015YF00@005YFFUIJEQl000Moo`03001JEP0000=JEP8000IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT001Aoo`04001JEP00FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004
FUH30007FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005=oo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200037oo00@005YF0000009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEUYFFUH20002FUH60004FUH00`00FUIJEP03FUH00`00FUIJEP02001D
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEUYFFUH70005Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40004FUH7
0003FUH00`00FUIJEP02001DOol002aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<0
00EJEP03001JEUYF00=JEP@0009JEP8005Aoo`00;Goo1`000UYF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00AJEP03001JEUYF00@005Aoo`00=7oo1`000UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003]oo`P000AJEP03001JEUYF
00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Aoo`00@goo4P000UYF1`00
0eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJ
EP04001JEUYFFUH2001EOol005Eoo`L0009JEPD0009JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF008005Ioo`00G7oo2`0000Aoo`00000000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000=JEPh005Qoo`00JWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEPL006Ioo`00K7oo10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YF000005YF00P006Aoo`00L7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF1P001eYF00@005YFFUIJEPL005eoo`00MGoo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH00eYF2`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01@00F7oo001kOol90006FUH00`00FUIJEP04FUH>0004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001DOol008AooaP000=JEPT000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol009aoo`T0
00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol00:Eoo`T000=J
EPP000AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00[Woo20000eYF300000=JEP000000EGoo
002fOolB001EOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59998 .75612 m .59872 .70148 L .56755 .69986 L p .707 .577 .707 r
F P
0 g
s
.59872 .70148 m .59998 .75612 L .6318 .75453 L p .707 .577 .707 r
F P
0 g
s
.6318 .75453 m .63055 .69989 L .59872 .70148 L p .707 .577 .707 r
F P
0 g
s
.63055 .69989 m .6318 .75453 L .66117 .74989 L p .707 .577 .707 r
F P
0 g
s
.66117 .74989 m .65992 .69524 L .63055 .69989 L p .707 .577 .707 r
F P
0 g
s
.56881 .7545 m .56755 .69986 L .54009 .69518 L p .707 .577 .707 r
F P
0 g
s
.56755 .69986 m .56881 .7545 L .59998 .75612 L p .707 .577 .707 r
F P
0 g
s
.65992 .69524 m .66117 .74989 L .6852 .74265 L p .707 .577 .707 r
F P
0 g
s
.6852 .74265 m .68395 .688 L .65992 .69524 L p .707 .577 .707 r
F P
0 g
s
.59875 .79585 m .60138 .75766 L .57024 .75485 L p .707 .577 .707 r
F P
0 g
s
.60138 .75766 m .59875 .79585 L .60461 .79619 L p .707 .577 .707 r
F P
0 g
s
.57024 .75485 m .56761 .79304 L .57274 .7935 L p .707 .577 .707 r
F P
0 g
s
.57274 .7935 m .59875 .79585 L p .58642 .77812 L .707 .577 .707 r
F P
0 g
s
.58642 .77812 m .57024 .75485 L .57274 .7935 L .707 .577 .707 r
F
.56761 .79304 m .57024 .75485 L .54275 .75137 L p F P
0 g
s
.54275 .75137 m .54012 .78956 L .54445 .79011 L p .707 .577 .707 r
F P
0 g
s
.54445 .79011 m .56761 .79304 L p .55608 .77372 L .707 .577 .707 r
F P
0 g
s
.55608 .77372 m .54275 .75137 L .54445 .79011 L .707 .577 .707 r
F
.54012 .78956 m .54275 .75137 L .5216 .74755 L p F P
0 g
s
.5216 .74755 m .51897 .78574 L .54012 .78956 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .51936 .78833 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53795 .80753 m .53961 .79692 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53961 .79692 m .5409 .78868 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .5409 .78868 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56557 .80982 m .56714 .7998 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56714 .7998 m .56852 .79097 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .56852 .79097 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59658 .81382 m .59824 .80322 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59824 .80322 m .59953 .79497 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.60461 .79619 m .63049 .79771 L p .61836 .78103 L .707 .577 .707 r
F P
0 g
s
.61836 .78103 m .60138 .75766 L .60461 .79619 L .707 .577 .707 r
F
.63049 .79771 m .63312 .75952 L .60138 .75766 L p F P
0 g
s
.54135 .74983 m .54009 .69518 L .51903 .68792 L p .707 .577 .707 r
F P
0 g
s
.54009 .69518 m .54135 .74983 L .56881 .7545 L p .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .56557 .80982 L .59658 .81382 L p .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .59658 .81382 L .62793 .81915 L p .707 .577 .707 r
F P
0 g
s
.63312 .75952 m .63049 .79771 L .65973 .79844 L p .707 .577 .707 r
F P
0 g
s
.65973 .79844 m .66236 .76026 L .63312 .75952 L p .707 .577 .707 r
F P
0 g
s
.62793 .81915 m .63088 .8003 L .59953 .79497 L p .707 .577 .707 r
F P
0 g
s
.63088 .8003 m .62793 .81915 L .65656 .82528 L p .707 .577 .707 r
F P
0 g
s
.65656 .82528 m .65952 .80643 L .63088 .8003 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .53795 .80753 L .56557 .80982 L p .707 .577 .707 r
F P
0 g
s
.68395 .688 m .6852 .74265 L .70155 .73351 L p .707 .577 .707 r
F P
0 g
s
.70155 .73351 m .7003 .67887 L .68395 .688 L p .707 .577 .707 r
F P
0 g
s
.66236 .76026 m .65973 .79844 L .6836 .79797 L p .707 .577 .707 r
F P
0 g
s
.6836 .79797 m .68623 .75978 L .66236 .76026 L p .707 .577 .707 r
F P
0 g
s
.51903 .68792 m .52028 .74256 L .54135 .74983 L p .707 .577 .707 r
F P
0 g
s
.65952 .80643 m .65656 .82528 L .67967 .8316 L p .707 .577 .707 r
F P
0 g
s
.67967 .8316 m .68262 .81275 L .65952 .80643 L p .707 .577 .707 r
F P
0 g
s
.52028 .74256 m .51903 .68792 L .50642 .67877 L p .707 .577 .707 r
F P
0 g
s
.51936 .78833 m .51641 .80718 L .53795 .80753 L p .707 .577 .707 r
F P
0 g
s
.7003 .67887 m .70155 .73351 L .70862 .72338 L p .707 .577 .707 r
F P
0 g
s
.70862 .72338 m .70736 .66874 L .7003 .67887 L p .707 .577 .707 r
F P
0 g
s
.68623 .75978 m .6836 .79797 L .69977 .79634 L p .707 .577 .707 r
F P
0 g
s
.69977 .79634 m .7024 .75816 L .68623 .75978 L p .707 .577 .707 r
F P
0 g
s
.68262 .81275 m .67967 .8316 L .69499 .83751 L p .707 .577 .707 r
F P
0 g
s
.50642 .67877 m .50767 .73342 L .52028 .74256 L p .707 .577 .707 r
F P
0 g
s
.69499 .83751 m .69794 .81866 L .68262 .81275 L p .707 .577 .707 r
F P
0 g
s
.51897 .78574 m .5216 .74755 L .50887 .74378 L p .707 .577 .707 r
F P
0 g
s
.50602 .78995 m .50307 .8088 L .51641 .80718 L p .707 .577 .707 r
F P
0 g
s
.51641 .80718 m .51936 .78833 L .50602 .78995 L p .707 .577 .707 r
F P
0 g
s
.50887 .74378 m .50623 .78197 L .51897 .78574 L p .707 .577 .707 r
F P
0 g
s
.50767 .73342 m .50642 .67877 L .50351 .66863 L p .707 .577 .707 r
F P
0 g
s
.7024 .75816 m .69977 .79634 L .70665 .79372 L p .707 .577 .707 r
F P
0 g
s
.70665 .79372 m .70928 .75553 L .7024 .75816 L p .707 .577 .707 r
F P
0 g
s
.70736 .66874 m .70862 .72338 L .7057 .71324 L p .707 .577 .707 r
F P
0 g
s
.7057 .71324 m .70445 .6586 L .70736 .66874 L p .707 .577 .707 r
F P
0 g
s
.69794 .81866 m .69499 .83751 L .70102 .84243 L p .707 .577 .707 r
F P
0 g
s
.50351 .66863 m .50476 .72328 L .50767 .73342 L p .707 .577 .707 r
F P
0 g
s
.70102 .84243 m .70398 .82358 L .69794 .81866 L p .707 .577 .707 r
F P
0 g
s
.50623 .78197 m .50887 .74378 L .50579 .74042 L p .707 .577 .707 r
F P
0 g
s
.50218 .79339 m .49922 .81224 L .50307 .8088 L p .707 .577 .707 r
F P
0 g
s
.50307 .8088 m .50602 .78995 L .50218 .79339 L p .707 .577 .707 r
F P
0 g
s
.4838 .81835 m .49482 .30988 L .45082 .30681 L p .707 .577 .707 r
F P
0 g
s
.50579 .74042 m .50316 .7786 L .50623 .78197 L p .707 .577 .707 r
F P
0 g
s
.50476 .72328 m .50351 .66863 L .51057 .6585 L p .707 .577 .707 r
F P
0 g
s
.51057 .6585 m .51182 .71315 L .50476 .72328 L p .707 .577 .707 r
F P
0 g
s
.50316 .7786 m .50579 .74042 L .51267 .73779 L p .707 .577 .707 r
F P
0 g
s
.50821 .7983 m .50526 .81715 L .49922 .81224 L p .707 .577 .707 r
F P
0 g
s
.49922 .81224 m .50218 .79339 L .50821 .7983 L p .707 .577 .707 r
F P
0 g
s
.51182 .71315 m .51057 .6585 L .52692 .64937 L p .707 .577 .707 r
F P
0 g
s
.51267 .73779 m .51004 .77598 L .50316 .7786 L p .707 .577 .707 r
F P
0 g
s
.52692 .64937 m .52817 .70401 L .51182 .71315 L p .707 .577 .707 r
F P
0 g
s
.51004 .77598 m .51267 .73779 L .52884 .73617 L p .707 .577 .707 r
F P
0 g
s
.52353 .80421 m .52058 .82306 L .50526 .81715 L p .707 .577 .707 r
F P
0 g
s
.50526 .81715 m .50821 .7983 L .52353 .80421 L p .707 .577 .707 r
F P
0 g
s
.52884 .73617 m .52621 .77435 L .51004 .77598 L p .707 .577 .707 r
F P
0 g
s
.52058 .82306 m .52353 .80421 L .54664 .81054 L p .707 .577 .707 r
F P
0 g
s
.49482 .30988 m .4838 .81835 L .52873 .81839 L p .707 .577 .707 r
F P
0 g
s
.52817 .70401 m .52692 .64937 L .55095 .64212 L p .707 .577 .707 r
F P
0 g
s
.55095 .64212 m .55221 .69677 L .52817 .70401 L p .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .52884 .73617 L .54369 .73587 L p .707 .577 .707 r
F P
0 g
s
.54369 .73587 m .55271 .7357 L p .54461 .74752 L .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .54369 .73587 L .54461 .74752 L .707 .577 .707 r
F
.55271 .7357 m .55008 .77388 L .52621 .77435 L p F P
0 g
s
.52873 .81839 m .53336 .60492 L p .49482 .30988 L .707 .577 .707 r
F P
0 g
s
.53336 .60492 m .53976 .30992 L .51008 .3099 L p .707 .577 .707 r
F P
0 g
s
.51008 .3099 m .49482 .30988 L p .53336 .60492 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .55095 .64212 L .5552 .64145 L p .707 .577 .707 r
F P
0 g
s
.5552 .64145 m .58032 .63748 L p .56188 .67638 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .5552 .64145 L .56188 .67638 L .707 .577 .707 r
F
.58157 .69213 m .58032 .63748 L .61215 .63589 L p F P
0 g
s
.58032 .63748 m .58157 .69213 L .55221 .69677 L p .707 .577 .707 r
F P
0 g
s
.61215 .63589 m .6134 .69054 L .58157 .69213 L p .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .55271 .7357 L .5707 .73615 L p .707 .577 .707 r
F P
0 g
s
.5707 .73615 m .58195 .73643 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .5707 .73615 L .56614 .755 L .707 .577 .707 r
F
.58122 .30691 m .57205 .72963 L p .57219 .72998 L F P
0 g
s
.58195 .73643 m .57932 .77461 L .56151 .77417 L p .707 .577 .707 r
F P
0 g
s
.56151 .77417 m .55008 .77388 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.56614 .755 m .58195 .73643 L .56151 .77417 L .707 .577 .707 r
F
.57932 .77461 m .58195 .73643 L .59079 .73695 L p F P
0 g
s
.59079 .73695 m .61369 .73829 L p .58813 .76531 L .707 .577 .707 r
F P
0 g
s
.57932 .77461 m .59079 .73695 L .58813 .76531 L .707 .577 .707 r
F
.64332 .63751 m .64457 .69216 L .6134 .69054 L p F P
0 g
s
.6134 .69054 m .61215 .63589 L .64332 .63751 L p .707 .577 .707 r
F P
0 g
s
.64483 .7411 m .6422 .77929 L .61106 .77648 L p .707 .577 .707 r
F P
0 g
s
.61106 .77648 m .61369 .73829 L .64483 .7411 L p .707 .577 .707 r
F P
0 g
s
.61369 .73829 m .61106 .77648 L .57932 .77461 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .62721 .80169 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61515 .30116 m .61018 .53024 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61018 .53024 m .60412 .80963 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58787 .81239 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57205 .72963 m .57203 .73066 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57203 .73066 m .57019 .81538 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .59601 .6315 L .57219 .72998 L .707 .577 .707 r
F
.59601 .6315 m .58122 .30691 L .57219 .72998 L F
.58787 .81239 m .60412 .80963 L p .57205 .72963 L F P
0 g
s
.54664 .81054 m .54369 .82939 L .52058 .82306 L p .707 .577 .707 r
F P
0 g
s
.54369 .82939 m .54664 .81054 L .57527 .81666 L p .707 .577 .707 r
F P
0 g
s
.53976 .30992 m .52873 .81839 L .57019 .81538 L p .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58122 .30691 L .53976 .30992 L p .707 .577 .707 r
F P
0 g
s
.43979 .81528 m .45082 .30681 L .41205 .301 L p .707 .577 .707 r
F P
0 g
s
.45082 .30681 m .43979 .81528 L .4838 .81835 L p .707 .577 .707 r
F P
0 g
s
.70928 .75553 m .70665 .79372 L .70357 .79036 L p .707 .577 .707 r
F P
0 g
s
.70357 .79036 m .70621 .75217 L .70928 .75553 L p .707 .577 .707 r
F P
0 g
s
.70445 .6586 m .7057 .71324 L .6931 .7041 L p .707 .577 .707 r
F P
0 g
s
.6931 .7041 m .69184 .64945 L .70445 .6586 L p .707 .577 .707 r
F P
0 g
s
.70398 .82358 m .70102 .84243 L .69718 .84586 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .61515 .30116 L .58122 .30691 L p .707 .577 .707 r
F P
0 g
s
.69718 .84586 m .70013 .82701 L .70398 .82358 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25697 .71931 m .25571 .66466 L .22454 .66304 L p .707 .577 .707 r
F P
0 g
s
.25571 .66466 m .25697 .71931 L .28879 .71772 L p .707 .577 .707 r
F P
0 g
s
.28879 .71772 m .28754 .66307 L .25571 .66466 L p .707 .577 .707 r
F P
0 g
s
.40103 .80947 m .41205 .301 L .38231 .29302 L p .707 .577 .707 r
F P
0 g
s
.41205 .301 m .40103 .80947 L .43979 .81528 L p .707 .577 .707 r
F P
0 g
s
.28754 .66307 m .28879 .71772 L .31816 .71307 L p .707 .577 .707 r
F P
0 g
s
.31816 .71307 m .31691 .65843 L .28754 .66307 L p .707 .577 .707 r
F P
0 g
s
.2258 .71769 m .22454 .66304 L .19708 .65837 L p .707 .577 .707 r
F P
0 g
s
.22454 .66304 m .2258 .71769 L .25697 .71931 L p .707 .577 .707 r
F P
0 g
s
.31691 .65843 m .31816 .71307 L .3422 .70583 L p .707 .577 .707 r
F P
0 g
s
.3422 .70583 m .34094 .65119 L .31691 .65843 L p .707 .577 .707 r
F P
0 g
s
.69184 .64945 m .6931 .7041 L .67203 .69683 L p .707 .577 .707 r
F P
0 g
s
.67203 .69683 m .67078 .64218 L .69184 .64945 L p .707 .577 .707 r
F P
0 g
s
.70621 .75217 m .70357 .79036 L .69084 .78658 L p .707 .577 .707 r
F P
0 g
s
.69084 .78658 m .69347 .7484 L .70621 .75217 L p .707 .577 .707 r
F P
0 g
s
.62721 .80169 m .63823 .29322 L .61515 .30116 L p .707 .577 .707 r
F P
0 g
s
.70013 .82701 m .69718 .84586 L .68384 .84748 L p .707 .577 .707 r
F P
0 g
s
.25574 .75903 m .25837 .72085 L .22723 .71804 L p .707 .577 .707 r
F P
0 g
s
.25837 .72085 m .25574 .75903 L .2616 .75938 L p .707 .577 .707 r
F P
0 g
s
.22723 .71804 m .2246 .75622 L .22973 .75669 L p .707 .577 .707 r
F P
0 g
s
.22973 .75669 m .25574 .75903 L p .24341 .7413 L .707 .577 .707 r
F P
0 g
s
.24341 .7413 m .22723 .71804 L .22973 .75669 L .707 .577 .707 r
F
.2246 .75622 m .22723 .71804 L .19974 .71455 L p F P
0 g
s
.19974 .71455 m .19711 .75274 L .20144 .75329 L p .707 .577 .707 r
F P
0 g
s
.20144 .75329 m .2246 .75622 L p .21307 .7369 L .707 .577 .707 r
F P
0 g
s
.21307 .7369 m .19974 .71455 L .20144 .75329 L .707 .577 .707 r
F
.19711 .75274 m .19974 .71455 L .17859 .71074 L p F P
0 g
s
.17859 .71074 m .17596 .74893 L .19711 .75274 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .17635 .75151 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.19494 .77072 m .1966 .76011 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.1966 .76011 m .19789 .75187 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .19789 .75187 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22256 .77301 m .22413 .76299 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22413 .76299 m .22552 .75416 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .22552 .75416 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25357 .77701 m .25523 .7664 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25523 .7664 m .25652 .75816 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.2616 .75938 m .28748 .7609 L p .27536 .74421 L .707 .577 .707 r
F P
0 g
s
.27536 .74421 m .25837 .72085 L .2616 .75938 L .707 .577 .707 r
F
.28748 .7609 m .29012 .72271 L .25837 .72085 L p F P
0 g
s
.19834 .71301 m .19708 .65837 L .17602 .6511 L p .707 .577 .707 r
F P
0 g
s
.19708 .65837 m .19834 .71301 L .2258 .71769 L p .707 .577 .707 r
F P
0 g
s
.68384 .84748 m .68679 .82863 L .70013 .82701 L p .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .22256 .77301 L .25357 .77701 L p .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .25357 .77701 L .28492 .78234 L p .707 .577 .707 r
F P
0 g
s
.29012 .72271 m .28748 .7609 L .31672 .76163 L p .707 .577 .707 r
F P
0 g
s
.31672 .76163 m .31935 .72344 L .29012 .72271 L p .707 .577 .707 r
F P
0 g
s
.28492 .78234 m .28788 .76348 L .25652 .75816 L p .707 .577 .707 r
F P
0 g
s
.28788 .76348 m .28492 .78234 L .31355 .78846 L p .707 .577 .707 r
F P
0 g
s
.31355 .78846 m .31651 .76961 L .28788 .76348 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .19494 .77072 L .22256 .77301 L p .707 .577 .707 r
F P
0 g
s
.37129 .80149 m .38231 .29302 L .36452 .28365 L p .707 .577 .707 r
F P
0 g
s
.38231 .29302 m .37129 .80149 L .40103 .80947 L p .707 .577 .707 r
F P
0 g
s
.34094 .65119 m .3422 .70583 L .35854 .6967 L p .707 .577 .707 r
F P
0 g
s
.35854 .6967 m .35729 .64205 L .34094 .65119 L p .707 .577 .707 r
F P
0 g
s
.67078 .64218 m .67203 .69683 L .64457 .69216 L p .707 .577 .707 r
F P
0 g
s
.64457 .69216 m .64332 .63751 L .67078 .64218 L p .707 .577 .707 r
F P
0 g
s
.31935 .72344 m .31672 .76163 L .34059 .76116 L p .707 .577 .707 r
F P
0 g
s
.34059 .76116 m .34323 .72297 L .31935 .72344 L p .707 .577 .707 r
F P
0 g
s
.17602 .6511 m .17727 .70575 L .19834 .71301 L p .707 .577 .707 r
F P
0 g
s
.31651 .76961 m .31355 .78846 L .33666 .79479 L p .707 .577 .707 r
F P
0 g
s
.33666 .79479 m .33961 .77594 L .31651 .76961 L p .707 .577 .707 r
F P
0 g
s
.17727 .70575 m .17602 .6511 L .16341 .64195 L p .707 .577 .707 r
F P
0 g
s
.69347 .7484 m .69084 .78658 L .66969 .78277 L p .707 .577 .707 r
F P
0 g
s
.66969 .78277 m .67232 .74458 L .69347 .7484 L p .707 .577 .707 r
F P
0 g
s
.17635 .75151 m .1734 .77037 L .19494 .77072 L p .707 .577 .707 r
F P
0 g
s
.68679 .82863 m .68384 .84748 L .6623 .84713 L p .707 .577 .707 r
F P
0 g
s
.6623 .84713 m .66525 .82828 L .68679 .82863 L p .707 .577 .707 r
F P
0 g
s
.63823 .29322 m .62721 .80169 L .63718 .79235 L p .707 .577 .707 r
F P
0 g
s
.63718 .79235 m .6482 .28388 L .63823 .29322 L p .707 .577 .707 r
F P
0 g
s
.35729 .64205 m .35854 .6967 L .36561 .68657 L p .707 .577 .707 r
F P
0 g
s
.36561 .68657 m .36435 .63192 L .35729 .64205 L p .707 .577 .707 r
F P
0 g
s
.34323 .72297 m .34059 .76116 L .35676 .75953 L p .707 .577 .707 r
F P
0 g
s
.35676 .75953 m .35939 .72134 L .34323 .72297 L p .707 .577 .707 r
F P
0 g
s
.33961 .77594 m .33666 .79479 L .35198 .8007 L p .707 .577 .707 r
F P
0 g
s
.16341 .64195 m .16466 .6966 L .17727 .70575 L p .707 .577 .707 r
F P
0 g
s
.35198 .8007 m .35493 .78185 L .33961 .77594 L p .707 .577 .707 r
F P
0 g
s
.17596 .74893 m .17859 .71074 L .16586 .70697 L p .707 .577 .707 r
F P
0 g
s
.67232 .74458 m .66969 .78277 L .6422 .77929 L p .707 .577 .707 r
F P
0 g
s
.6422 .77929 m .64483 .7411 L .67232 .74458 L p .707 .577 .707 r
F P
0 g
s
.16301 .75314 m .16006 .77199 L .1734 .77037 L p .707 .577 .707 r
F P
0 g
s
.1734 .77037 m .17635 .75151 L .16301 .75314 L p .707 .577 .707 r
F P
0 g
s
.16586 .70697 m .16322 .74515 L .17596 .74893 L p .707 .577 .707 r
F P
0 g
s
.66525 .82828 m .6623 .84713 L .63468 .84484 L p .707 .577 .707 r
F P
0 g
s
.16466 .6966 m .16341 .64195 L .1605 .63182 L p .707 .577 .707 r
F P
0 g
s
.35493 .78185 m .35198 .8007 L .35801 .80561 L p .707 .577 .707 r
F P
0 g
s
.36144 .62178 m .36269 .67643 L .35704 .67233 L p .707 .577 .707 r
F P
0 g
s
.35704 .67233 m .35009 .66728 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35908 .63124 m .36144 .62178 L .35704 .67233 L .707 .577 .707 r
F
.35009 .66728 m .34883 .61263 L .35961 .62046 L p F P
0 g
s
.35961 .62046 m .36144 .62178 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35009 .66728 m .35961 .62046 L .35908 .63124 L .707 .577 .707 r
F
.35939 .72134 m .35676 .75953 L .36364 .75691 L p F P
0 g
s
.36364 .75691 m .36628 .71872 L .35939 .72134 L p .707 .577 .707 r
F P
0 g
s
.3632 .71536 m .36056 .75354 L .35559 .75207 L p .707 .577 .707 r
F P
0 g
s
.35559 .75207 m .34783 .74977 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.35547 .73265 m .3632 .71536 L .35559 .75207 L .707 .577 .707 r
F
.34783 .74977 m .35046 .71158 L .35536 .71303 L p F P
0 g
s
.35536 .71303 m .3632 .71536 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.34783 .74977 m .35536 .71303 L .35547 .73265 L .707 .577 .707 r
F
.35437 .72609 m .35511 .67036 L .35135 .787 L F
.35511 .67036 m .3604 .27382 L .35469 .59736 L F
.35511 .67036 m .35469 .59736 L .35135 .787 L F
.34938 .78229 m .35135 .787 L p .35469 .59736 L F P
0 g
s
.3604 .27382 m .35442 .54973 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35442 .54973 m .34938 .78229 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35801 .80561 m .36097 .78676 L .35493 .78185 L p .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .34378 .79182 L .35634 .79029 L p .707 .577 .707 r
F P
0 g
s
.35634 .79029 m .35713 .7902 L p .35639 .79112 L .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .35634 .79029 L .35639 .79112 L .707 .577 .707 r
F
.35135 .787 m .35349 .79212 L p .35406 .74939 L F P
0 g
s
.35406 .74939 m .35437 .72609 L .35361 .74137 L .707 .577 .707 r
F
.35406 .74939 m .35361 .74137 L .35135 .787 L F
.36452 .28365 m .3604 .27382 L p .35437 .72609 L F P
0 g
s
.35349 .79212 m .35535 .70637 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.35535 .70637 m .36452 .28365 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.36435 .63192 m .36561 .68657 L .36269 .67643 L p .707 .577 .707 r
F P
0 g
s
.36269 .67643 m .36144 .62178 L .36435 .63192 L p .707 .577 .707 r
F P
0 g
s
.36628 .71872 m .36364 .75691 L .36056 .75354 L p .707 .577 .707 r
F P
0 g
s
.36056 .75354 m .3632 .71536 L .36628 .71872 L p .707 .577 .707 r
F P
0 g
s
.36097 .78676 m .35801 .80561 L .35417 .80905 L p .707 .577 .707 r
F P
0 g
s
.35417 .80905 m .35713 .7902 L .36097 .78676 L p .707 .577 .707 r
F P
0 g
s
.35713 .7902 m .35417 .80905 L .34083 .81067 L p .707 .577 .707 r
F P
0 g
s
.36452 .28365 m .35349 .79212 L .37129 .80149 L p .707 .577 .707 r
F P
0 g
s
.63468 .84484 m .63763 .82599 L .66525 .82828 L p .707 .577 .707 r
F P
0 g
s
.57527 .81666 m .57232 .83551 L .54369 .82939 L p .707 .577 .707 r
F P
0 g
s
.63763 .82599 m .63468 .84484 L .60367 .84084 L p .707 .577 .707 r
F P
0 g
s
.60367 .84084 m .60662 .82199 L .63763 .82599 L p .707 .577 .707 r
F P
0 g
s
.1605 .63182 m .16175 .68646 L .16466 .6966 L p .707 .577 .707 r
F P
0 g
s
.60662 .82199 m .60367 .84084 L .57232 .83551 L p .707 .577 .707 r
F P
0 g
s
.57232 .83551 m .57527 .81666 L .60662 .82199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16322 .74515 m .16586 .70697 L .16278 .7036 L p .707 .577 .707 r
F P
0 g
s
.15917 .75657 m .15621 .77542 L .16006 .77199 L p .707 .577 .707 r
F P
0 g
s
.16006 .77199 m .16301 .75314 L .15917 .75657 L p .707 .577 .707 r
F P
0 g
s
.6482 .28388 m .63718 .79235 L .63307 .78251 L p .707 .577 .707 r
F P
0 g
s
.63307 .78251 m .64409 .27404 L .6482 .28388 L p .707 .577 .707 r
F P
0 g
s
.16278 .7036 m .16015 .74179 L .16322 .74515 L p .707 .577 .707 r
F P
0 g
s
.16175 .68646 m .1605 .63182 L .16756 .62169 L p .707 .577 .707 r
F P
0 g
s
.34938 .78229 m .3604 .27382 L .37038 .26447 L p .707 .577 .707 r
F P
0 g
s
.16756 .62169 m .16881 .67633 L .16175 .68646 L p .707 .577 .707 r
F P
0 g
s
.16015 .74179 m .16278 .7036 L .16966 .70098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1652 .76148 m .16225 .78034 L .15621 .77542 L p .707 .577 .707 r
F P
0 g
s
.15621 .77542 m .15917 .75657 L .1652 .76148 L p .707 .577 .707 r
F P
0 g
s
.16881 .67633 m .16756 .62169 L .18391 .61255 L p .707 .577 .707 r
F P
0 g
s
.16966 .70098 m .16703 .73917 L .16015 .74179 L p .707 .577 .707 r
F P
0 g
s
.64409 .27404 m .63307 .78251 L .61527 .77315 L p .707 .577 .707 r
F P
0 g
s
.61527 .77315 m .62629 .26468 L .64409 .27404 L p .707 .577 .707 r
F P
0 g
s
.34883 .61263 m .35009 .66728 L .32902 .66001 L p .707 .577 .707 r
F P
0 g
s
.32902 .66001 m .32777 .60537 L .34883 .61263 L p .707 .577 .707 r
F P
0 g
s
.18391 .61255 m .18516 .6672 L .16881 .67633 L p .707 .577 .707 r
F P
0 g
s
.18516 .6672 m .18391 .61255 L .20794 .60531 L p .707 .577 .707 r
F P
0 g
s
.16703 .73917 m .16966 .70098 L .18583 .69935 L p .707 .577 .707 r
F P
0 g
s
.35935 .77294 m .37038 .26447 L .39346 .25654 L p .707 .577 .707 r
F P
0 g
s
.37038 .26447 m .35935 .77294 L .34938 .78229 L p .707 .577 .707 r
F P
0 g
s
.18052 .76739 m .17757 .78624 L .16225 .78034 L p .707 .577 .707 r
F P
0 g
s
.16225 .78034 m .1652 .76148 L .18052 .76739 L p .707 .577 .707 r
F P
0 g
s
.18583 .69935 m .1832 .73754 L .16703 .73917 L p .707 .577 .707 r
F P
0 g
s
.32777 .60537 m .32902 .66001 L .30156 .65534 L p .707 .577 .707 r
F P
0 g
s
.30156 .65534 m .30031 .6007 L .32777 .60537 L p .707 .577 .707 r
F P
0 g
s
.20794 .60531 m .2092 .65995 L .18516 .6672 L p .707 .577 .707 r
F P
0 g
s
.2092 .65995 m .20794 .60531 L .23731 .60067 L p .707 .577 .707 r
F P
0 g
s
.35046 .71158 m .34783 .74977 L .32668 .74595 L p .707 .577 .707 r
F P
0 g
s
.32668 .74595 m .32931 .70777 L .35046 .71158 L p .707 .577 .707 r
F P
0 g
s
.34378 .79182 m .34083 .81067 L .31929 .81032 L p .707 .577 .707 r
F P
0 g
s
.31929 .81032 m .32224 .79147 L .34378 .79182 L p .707 .577 .707 r
F P
0 g
s
.62629 .26468 m .61527 .77315 L .58553 .76517 L p .707 .577 .707 r
F P
0 g
s
.58553 .76517 m .59656 .2567 L .62629 .26468 L p .707 .577 .707 r
F P
0 g
s
.30031 .6007 m .30156 .65534 L .27039 .65372 L p .707 .577 .707 r
F P
0 g
s
.27039 .65372 m .26914 .59908 L .30031 .6007 L p .707 .577 .707 r
F P
0 g
s
.1832 .73754 m .18583 .69935 L .2097 .69888 L p .707 .577 .707 r
F P
0 g
s
.23856 .65531 m .23731 .60067 L .26914 .59908 L p .707 .577 .707 r
F P
0 g
s
.23731 .60067 m .23856 .65531 L .2092 .65995 L p .707 .577 .707 r
F P
0 g
s
.20363 .77372 m .20068 .79257 L .17757 .78624 L p .707 .577 .707 r
F P
0 g
s
.17757 .78624 m .18052 .76739 L .20363 .77372 L p .707 .577 .707 r
F P
0 g
s
.2097 .69888 m .20707 .73707 L .1832 .73754 L p .707 .577 .707 r
F P
0 g
s
.26914 .59908 m .27039 .65372 L .23856 .65531 L p .707 .577 .707 r
F P
0 g
s
.73718 .65653 m .73593 .60188 L .70476 .60026 L p .707 .577 .707 r
F P
0 g
s
.73593 .60188 m .73718 .65653 L .76901 .65494 L p .707 .577 .707 r
F P
0 g
s
.76901 .65494 m .76775 .6003 L .73593 .60188 L p .707 .577 .707 r
F P
0 g
s
.76775 .6003 m .76901 .65494 L .79837 .6503 L p .707 .577 .707 r
F P
0 g
s
.79837 .6503 m .79712 .59565 L .76775 .6003 L p .707 .577 .707 r
F P
0 g
s
.39346 .25654 m .38243 .76501 L .35935 .77294 L p .707 .577 .707 r
F P
0 g
s
.38243 .76501 m .39346 .25654 L .42739 .25078 L p .707 .577 .707 r
F P
0 g
s
.32931 .70777 m .32668 .74595 L .29919 .74247 L p .707 .577 .707 r
F P
0 g
s
.29919 .74247 m .30182 .70428 L .32931 .70777 L p .707 .577 .707 r
F P
0 g
s
.70601 .65491 m .70476 .60026 L .6773 .59559 L p .707 .577 .707 r
F P
0 g
s
.70476 .60026 m .70601 .65491 L .73718 .65653 L p .707 .577 .707 r
F P
0 g
s
.32224 .79147 m .31929 .81032 L .29167 .80803 L p .707 .577 .707 r
F P
0 g
s
.29167 .80803 m .29462 .78918 L .32224 .79147 L p .707 .577 .707 r
F P
0 g
s
.20707 .73707 m .2097 .69888 L .23894 .69961 L p .707 .577 .707 r
F P
0 g
s
.79712 .59565 m .79837 .6503 L .82241 .64305 L p .707 .577 .707 r
F P
0 g
s
.82241 .64305 m .82116 .58841 L .79712 .59565 L p .707 .577 .707 r
F P
0 g
s
.23226 .77985 m .22931 .7987 L .20068 .79257 L p .707 .577 .707 r
F P
0 g
s
.20068 .79257 m .20363 .77372 L .23226 .77985 L p .707 .577 .707 r
F P
0 g
s
.23894 .69961 m .23631 .7378 L .20707 .73707 L p .707 .577 .707 r
F P
0 g
s
.73595 .69317 m .73859 .65498 L .70744 .65217 L p .707 .577 .707 r
F P
0 g
s
.73859 .65498 m .73595 .69317 L .7677 .69503 L p .707 .577 .707 r
F P
0 g
s
.7677 .69503 m .77033 .65685 L .73859 .65498 L p .707 .577 .707 r
F P
0 g
s
.59656 .2567 m .58553 .76517 L .54676 .75936 L p .707 .577 .707 r
F P
0 g
s
.54676 .75936 m .55779 .25089 L .59656 .2567 L p .707 .577 .707 r
F P
0 g
s
.67855 .65024 m .6773 .59559 L .65623 .58833 L p .707 .577 .707 r
F P
0 g
s
.6773 .59559 m .67855 .65024 L .70601 .65491 L p .707 .577 .707 r
F P
0 g
s
.30182 .70428 m .29919 .74247 L .26805 .73966 L p .707 .577 .707 r
F P
0 g
s
.26805 .73966 m .27068 .70147 L .30182 .70428 L p .707 .577 .707 r
F P
0 g
s
.77033 .65685 m .7677 .69503 L .79693 .69576 L p .707 .577 .707 r
F P
0 g
s
.79693 .69576 m .79957 .65758 L .77033 .65685 L p .707 .577 .707 r
F P
0 g
s
.29462 .78918 m .29167 .80803 L .26066 .80402 L p .707 .577 .707 r
F P
0 g
s
.70744 .65217 m .70481 .69036 L .73595 .69317 L p .707 .577 .707 r
F P
0 g
s
.23631 .7378 m .23894 .69961 L .27068 .70147 L p .707 .577 .707 r
F P
0 g
s
.70573 .69501 m .70278 .71386 L .73378 .71787 L p .707 .577 .707 r
F P
0 g
s
.73378 .71787 m .73674 .69901 L .70573 .69501 L p .707 .577 .707 r
F P
0 g
s
.73674 .69901 m .73378 .71787 L .76514 .72319 L p .707 .577 .707 r
F P
0 g
s
.26066 .80402 m .26361 .78517 L .29462 .78918 L p .707 .577 .707 r
F P
0 g
s
.70481 .69036 m .70744 .65217 L .67995 .64869 L p .707 .577 .707 r
F P
0 g
s
.26361 .78517 m .26066 .80402 L .22931 .7987 L p .707 .577 .707 r
F P
0 g
s
.22931 .7987 m .23226 .77985 L .26361 .78517 L p .707 .577 .707 r
F P
0 g
s
.76514 .72319 m .76809 .70434 L .73674 .69901 L p .707 .577 .707 r
F P
0 g
s
.27068 .70147 m .26805 .73966 L .23631 .7378 L p .707 .577 .707 r
F P
0 g
s
.76809 .70434 m .76514 .72319 L .79377 .72932 L p .707 .577 .707 r
F P
0 g
s
.67995 .64869 m .67732 .68688 L .70481 .69036 L p .707 .577 .707 r
F P
0 g
s
.41637 .75925 m .42739 .25078 L .46885 .24778 L p .707 .577 .707 r
F P
0 g
s
.42739 .25078 m .41637 .75925 L .38243 .76501 L p .707 .577 .707 r
F P
0 g
s
.79377 .72932 m .79672 .71047 L .76809 .70434 L p .707 .577 .707 r
F P
0 g
s
.6781 .69272 m .67515 .71157 L .70278 .71386 L p .707 .577 .707 r
F P
0 g
s
.70278 .71386 m .70573 .69501 L .6781 .69272 L p .707 .577 .707 r
F P
0 g
s
.82116 .58841 m .82241 .64305 L .83876 .63392 L p .707 .577 .707 r
F P
0 g
s
.83876 .63392 m .8375 .57927 L .82116 .58841 L p .707 .577 .707 r
F P
0 g
s
.79957 .65758 m .79693 .69576 L .82081 .69529 L p .707 .577 .707 r
F P
0 g
s
.82081 .69529 m .82344 .65711 L .79957 .65758 L p .707 .577 .707 r
F P
0 g
s
.65623 .58833 m .65748 .64297 L .67855 .65024 L p .707 .577 .707 r
F P
0 g
s
.79672 .71047 m .79377 .72932 L .81687 .73565 L p .707 .577 .707 r
F P
0 g
s
.67732 .68688 m .67995 .64869 L .65881 .64488 L p .707 .577 .707 r
F P
0 g
s
.55779 .25089 m .54676 .75936 L .50276 .75628 L p .707 .577 .707 r
F P
0 g
s
.50276 .75628 m .51378 .24781 L .55779 .25089 L p .707 .577 .707 r
F P
0 g
s
.81687 .73565 m .81983 .71679 L .79672 .71047 L p .707 .577 .707 r
F P
0 g
s
.65748 .64297 m .65623 .58833 L .64362 .57918 L p .707 .577 .707 r
F P
0 g
s
.65881 .64488 m .65617 .68306 L .67732 .68688 L p .707 .577 .707 r
F P
0 g
s
.65657 .69237 m .65361 .71122 L .67515 .71157 L p .707 .577 .707 r
F P
0 g
s
.67515 .71157 m .6781 .69272 L .65657 .69237 L p .707 .577 .707 r
F P
0 g
s
.45783 .75625 m .46885 .24778 L .51378 .24781 L p .707 .577 .707 r
F P
0 g
s
.46885 .24778 m .45783 .75625 L .41637 .75925 L p .707 .577 .707 r
F P
0 g
s
.51378 .24781 m .50276 .75628 L .45783 .75625 L p .707 .577 .707 r
F P
0 g
s
.82344 .65711 m .82081 .69529 L .83697 .69367 L p .707 .577 .707 r
F P
0 g
s
.83697 .69367 m .83961 .65548 L .82344 .65711 L p .707 .577 .707 r
F P
0 g
s
.8375 .57927 m .83876 .63392 L .84582 .62379 L p .707 .577 .707 r
F P
0 g
s
.84582 .62379 m .84457 .56914 L .8375 .57927 L p .707 .577 .707 r
F P
0 g
s
.81983 .71679 m .81687 .73565 L .83219 .74155 L p .707 .577 .707 r
F P
0 g
s
.64362 .57918 m .64488 .63382 L .65748 .64297 L p .707 .577 .707 r
F P
0 g
s
.83219 .74155 m .83515 .7227 L .81983 .71679 L p .707 .577 .707 r
F P
0 g
s
.65617 .68306 m .65881 .64488 L .64607 .6411 L p .707 .577 .707 r
F P
0 g
s
.64607 .6411 m .64344 .67929 L .65617 .68306 L p .707 .577 .707 r
F P
0 g
s
.64322 .69399 m .64027 .71284 L .65361 .71122 L p .707 .577 .707 r
F P
0 g
s
.65361 .71122 m .65657 .69237 L .64322 .69399 L p .707 .577 .707 r
F P
0 g
s
.64488 .63382 m .64362 .57918 L .64071 .56904 L p .707 .577 .707 r
F P
0 g
s
.83961 .65548 m .83697 .69367 L .84386 .69104 L p .707 .577 .707 r
F P
0 g
s
.84386 .69104 m .84649 .65286 L .83961 .65548 L p .707 .577 .707 r
F P
0 g
s
.84457 .56914 m .84582 .62379 L .84291 .61365 L p .707 .577 .707 r
F P
0 g
s
.84291 .61365 m .84165 .55901 L .84457 .56914 L p .707 .577 .707 r
F P
0 g
s
.83515 .7227 m .83219 .74155 L .83823 .74647 L p .707 .577 .707 r
F P
0 g
s
.64071 .56904 m .64196 .62369 L .64488 .63382 L p .707 .577 .707 r
F P
0 g
s
.83823 .74647 m .84118 .72762 L .83515 .7227 L p .707 .577 .707 r
F P
0 g
s
.64344 .67929 m .64607 .6411 L .64299 .63774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64299 .63774 m .64036 .67592 L .64344 .67929 L p .707 .577 .707 r
F P
0 g
s
.63938 .69743 m .63643 .71628 L .64027 .71284 L p .707 .577 .707 r
F P
0 g
s
.64027 .71284 m .64322 .69399 L .63938 .69743 L p .707 .577 .707 r
F P
0 g
s
.64196 .62369 m .64071 .56904 L .64777 .55891 L p .707 .577 .707 r
F P
0 g
s
.84649 .65286 m .84386 .69104 L .84078 .68768 L p .707 .577 .707 r
F P
0 g
s
.84078 .68768 m .84341 .64949 L .84649 .65286 L p .707 .577 .707 r
F P
0 g
s
.84165 .55901 m .84291 .61365 L .8303 .6045 L p .707 .577 .707 r
F P
0 g
s
.8303 .6045 m .82905 .54986 L .84165 .55901 L p .707 .577 .707 r
F P
0 g
s
.64777 .55891 m .64903 .61355 L .64196 .62369 L p .707 .577 .707 r
F P
0 g
s
.84118 .72762 m .83823 .74647 L .83439 .7499 L p .707 .577 .707 r
F P
0 g
s
.83439 .7499 m .83734 .73105 L .84118 .72762 L p .707 .577 .707 r
F P
0 g
s
.64036 .67592 m .64299 .63774 L .64988 .63511 L p .707 .577 .707 r
F P
0 g
s
.39417 .61971 m .39292 .56507 L .36175 .56345 L p .707 .577 .707 r
F P
0 g
s
.39292 .56507 m .39417 .61971 L .426 .61813 L p .707 .577 .707 r
F P
0 g
s
.426 .61813 m .42474 .56348 L .39292 .56507 L p .707 .577 .707 r
F P
0 g
s
.64988 .63511 m .64724 .6733 L .64036 .67592 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64903 .61355 m .64777 .55891 L .66412 .54977 L p .707 .577 .707 r
F P
0 g
s
.64542 .70234 m .64246 .72119 L .63643 .71628 L p .707 .577 .707 r
F P
0 g
s
.63643 .71628 m .63938 .69743 L .64542 .70234 L p .707 .577 .707 r
F P
0 g
s
.42474 .56348 m .426 .61813 L .45536 .61348 L p .707 .577 .707 r
F P
0 g
s
.45536 .61348 m .45411 .55884 L .42474 .56348 L p .707 .577 .707 r
F P
0 g
s
.363 .61809 m .36175 .56345 L .33429 .55878 L p .707 .577 .707 r
F P
0 g
s
.36175 .56345 m .363 .61809 L .39417 .61971 L p .707 .577 .707 r
F P
0 g
s
.45411 .55884 m .45536 .61348 L .4794 .60624 L p .707 .577 .707 r
F P
0 g
s
.4794 .60624 m .47815 .55159 L .45411 .55884 L p .707 .577 .707 r
F P
0 g
s
.82905 .54986 m .8303 .6045 L .80924 .59724 L p .707 .577 .707 r
F P
0 g
s
.80924 .59724 m .80798 .54259 L .82905 .54986 L p .707 .577 .707 r
F P
0 g
s
.84341 .64949 m .84078 .68768 L .82804 .6839 L p .707 .577 .707 r
F P
0 g
s
.82804 .6839 m .83068 .64572 L .84341 .64949 L p .707 .577 .707 r
F P
0 g
s
.66412 .54977 m .66538 .60442 L .64903 .61355 L p .707 .577 .707 r
F P
0 g
s
.39294 .65635 m .39558 .61817 L .36443 .61536 L p .707 .577 .707 r
F P
0 g
s
.39558 .61817 m .39294 .65635 L .42469 .65822 L p .707 .577 .707 r
F P
0 g
s
.42469 .65822 m .42732 .62003 L .39558 .61817 L p .707 .577 .707 r
F P
0 g
s
.83734 .73105 m .83439 .7499 L .82104 .75152 L p .707 .577 .707 r
F P
0 g
s
.33554 .61342 m .33429 .55878 L .31322 .55151 L p .707 .577 .707 r
F P
0 g
s
.33429 .55878 m .33554 .61342 L .363 .61809 L p .707 .577 .707 r
F P
0 g
s
.82104 .75152 m .824 .73267 L .83734 .73105 L p .707 .577 .707 r
F P
0 g
s
.42732 .62003 m .42469 .65822 L .45392 .65895 L p .707 .577 .707 r
F P
0 g
s
.45392 .65895 m .45656 .62076 L .42732 .62003 L p .707 .577 .707 r
F P
0 g
s
.36443 .61536 m .3618 .65355 L .39294 .65635 L p .707 .577 .707 r
F P
0 g
s
.36272 .6582 m .35977 .67705 L .39077 .68105 L p .707 .577 .707 r
F P
0 g
s
.39077 .68105 m .39373 .6622 L .36272 .6582 L p .707 .577 .707 r
F P
0 g
s
.39373 .6622 m .39077 .68105 L .42213 .68638 L p .707 .577 .707 r
F P
0 g
s
.66538 .60442 m .66412 .54977 L .68816 .54253 L p .707 .577 .707 r
F P
0 g
s
.64724 .6733 m .64988 .63511 L .66604 .63349 L p .707 .577 .707 r
F P
0 g
s
.3618 .65355 m .36443 .61536 L .33694 .61188 L p .707 .577 .707 r
F P
0 g
s
.42213 .68638 m .42508 .66752 L .39373 .6622 L p .707 .577 .707 r
F P
0 g
s
.42508 .66752 m .42213 .68638 L .45076 .6925 L p .707 .577 .707 r
F P
0 g
s
.66604 .63349 m .66341 .67167 L .64724 .6733 L p .707 .577 .707 r
F P
0 g
s
.33694 .61188 m .33431 .65006 L .3618 .65355 L p .707 .577 .707 r
F P
0 g
s
.66074 .70825 m .65778 .7271 L .64246 .72119 L p .707 .577 .707 r
F P
0 g
s
.64246 .72119 m .64542 .70234 L .66074 .70825 L p .707 .577 .707 r
F P
0 g
s
.45076 .6925 m .45371 .67365 L .42508 .66752 L p .707 .577 .707 r
F P
0 g
s
.33509 .65591 m .33214 .67476 L .35977 .67705 L p .707 .577 .707 r
F P
0 g
s
.35977 .67705 m .36272 .6582 L .33509 .65591 L p .707 .577 .707 r
F P
0 g
s
.47815 .55159 m .4794 .60624 L .49575 .5971 L p .707 .577 .707 r
F P
0 g
s
.49575 .5971 m .49449 .54246 L .47815 .55159 L p .707 .577 .707 r
F P
0 g
s
.45656 .62076 m .45392 .65895 L .4778 .65848 L p .707 .577 .707 r
F P
0 g
s
.4778 .65848 m .48043 .62029 L .45656 .62076 L p .707 .577 .707 r
F P
0 g
s
.80798 .54259 m .80924 .59724 L .78177 .59256 L p .707 .577 .707 r
F P
0 g
s
.78177 .59256 m .78052 .53792 L .80798 .54259 L p .707 .577 .707 r
F P
0 g
s
.31322 .55151 m .31447 .60616 L .33554 .61342 L p .707 .577 .707 r
F P
0 g
s
.45371 .67365 m .45076 .6925 L .47386 .69883 L p .707 .577 .707 r
F P
0 g
s
.33431 .65006 m .33694 .61188 L .3158 .60806 L p .707 .577 .707 r
F P
0 g
s
.47386 .69883 m .47682 .67998 L .45371 .67365 L p .707 .577 .707 r
F P
0 g
s
.68816 .54253 m .68941 .59718 L .66538 .60442 L p .707 .577 .707 r
F P
0 g
s
.31447 .60616 m .31322 .55151 L .30061 .54236 L p .707 .577 .707 r
F P
0 g
s
.83068 .64572 m .82804 .6839 L .80689 .68009 L p .707 .577 .707 r
F P
0 g
s
.80689 .68009 m .80953 .6419 L .83068 .64572 L p .707 .577 .707 r
F P
0 g
s
.68941 .59718 m .68816 .54253 L .71752 .53789 L p .707 .577 .707 r
F P
0 g
s
.3158 .60806 m .31316 .64625 L .33431 .65006 L p .707 .577 .707 r
F P
0 g
s
.31356 .65556 m .3106 .67441 L .33214 .67476 L p .707 .577 .707 r
F P
0 g
s
.33214 .67476 m .33509 .65591 L .31356 .65556 L p .707 .577 .707 r
F P
0 g
s
.824 .73267 m .82104 .75152 L .79951 .75117 L p .707 .577 .707 r
F P
0 g
s
.79951 .75117 m .80246 .73232 L .824 .73267 L p .707 .577 .707 r
F P
0 g
s
.78052 .53792 m .78177 .59256 L .7506 .59094 L p .707 .577 .707 r
F P
0 g
s
.7506 .59094 m .74935 .5363 L .78052 .53792 L p .707 .577 .707 r
F P
0 g
s
.66341 .67167 m .66604 .63349 L .68992 .63302 L p .707 .577 .707 r
F P
0 g
s
.71878 .59253 m .71752 .53789 L .74935 .5363 L p .707 .577 .707 r
F P
0 g
s
.71752 .53789 m .71878 .59253 L .68941 .59718 L p .707 .577 .707 r
F P
0 g
s
.68992 .63302 m .68728 .6712 L .66341 .67167 L p .707 .577 .707 r
F P
0 g
s
.48043 .62029 m .4778 .65848 L .49396 .65685 L p .707 .577 .707 r
F P
0 g
s
.49396 .65685 m .4966 .61866 L .48043 .62029 L p .707 .577 .707 r
F P
0 g
s
.68384 .71458 m .68089 .73343 L .65778 .7271 L p .707 .577 .707 r
F P
0 g
s
.65778 .7271 m .66074 .70825 L .68384 .71458 L p .707 .577 .707 r
F P
0 g
s
.49449 .54246 m .49575 .5971 L .50281 .58697 L p .707 .577 .707 r
F P
0 g
s
.50281 .58697 m .50156 .53233 L .49449 .54246 L p .707 .577 .707 r
F P
0 g
s
.74935 .5363 m .7506 .59094 L .71878 .59253 L p .707 .577 .707 r
F P
0 g
s
.47682 .67998 m .47386 .69883 L .48918 .70474 L p .707 .577 .707 r
F P
0 g
s
.30061 .54236 m .30187 .59701 L .31447 .60616 L p .707 .577 .707 r
F P
0 g
s
.48918 .70474 m .49214 .68589 L .47682 .67998 L p .707 .577 .707 r
F P
0 g
s
.31316 .64625 m .3158 .60806 L .30306 .60429 L p .707 .577 .707 r
F P
0 g
s
.80953 .6419 m .80689 .68009 L .7794 .67661 L p .707 .577 .707 r
F P
0 g
s
.7794 .67661 m .78204 .63842 L .80953 .6419 L p .707 .577 .707 r
F P
0 g
s
.30306 .60429 m .30043 .64247 L .31316 .64625 L p .707 .577 .707 r
F P
0 g
s
.30021 .65718 m .29726 .67603 L .3106 .67441 L p .707 .577 .707 r
F P
0 g
s
.3106 .67441 m .31356 .65556 L .30021 .65718 L p .707 .577 .707 r
F P
0 g
s
.30187 .59701 m .30061 .54236 L .2977 .53222 L p .707 .577 .707 r
F P
0 g
s
.80246 .73232 m .79951 .75117 L .77188 .74888 L p .707 .577 .707 r
F P
0 g
s
.68728 .6712 m .68992 .63302 L .71915 .63375 L p .707 .577 .707 r
F P
0 g
s
.77188 .74888 m .77483 .73003 L .80246 .73232 L p .707 .577 .707 r
F P
0 g
s
.71915 .63375 m .71652 .67193 L .68728 .6712 L p .707 .577 .707 r
F P
0 g
s
.71247 .7207 m .70952 .73955 L .68089 .73343 L p .707 .577 .707 r
F P
0 g
s
.68089 .73343 m .68384 .71458 L .71247 .7207 L p .707 .577 .707 r
F P
0 g
s
.78204 .63842 m .7794 .67661 L .74826 .6738 L p .707 .577 .707 r
F P
0 g
s
.74826 .6738 m .7509 .63561 L .78204 .63842 L p .707 .577 .707 r
F P
0 g
s
.4966 .61866 m .49396 .65685 L .50085 .65423 L p .707 .577 .707 r
F P
0 g
s
.50085 .65423 m .50348 .61604 L .4966 .61866 L p .707 .577 .707 r
F P
0 g
s
.71652 .67193 m .71915 .63375 L .7509 .63561 L p .707 .577 .707 r
F P
0 g
s
.50156 .53233 m .50281 .58697 L .4999 .57684 L p .707 .577 .707 r
F P
0 g
s
.4999 .57684 m .49864 .52219 L .50156 .53233 L p .707 .577 .707 r
F P
0 g
s
.77483 .73003 m .77188 .74888 L .74087 .74488 L p .707 .577 .707 r
F P
0 g
s
.49214 .68589 m .48918 .70474 L .49522 .70965 L p .707 .577 .707 r
F P
0 g
s
.2977 .53222 m .29895 .58687 L .30187 .59701 L p .707 .577 .707 r
F P
0 g
s
.7509 .63561 m .74826 .6738 L .71652 .67193 L p .707 .577 .707 r
F P
0 g
s
.74087 .74488 m .74383 .72603 L .77483 .73003 L p .707 .577 .707 r
F P
0 g
s
.74383 .72603 m .74087 .74488 L .70952 .73955 L p .707 .577 .707 r
F P
0 g
s
.70952 .73955 m .71247 .7207 L .74383 .72603 L p .707 .577 .707 r
F P
0 g
s
.49522 .70965 m .49817 .6908 L .49214 .68589 L p .707 .577 .707 r
F P
0 g
s
.30043 .64247 m .30306 .60429 L .29998 .60092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29998 .60092 m .29735 .63911 L .30043 .64247 L p .707 .577 .707 r
F P
0 g
s
.29637 .66061 m .29342 .67946 L .29726 .67603 L p .707 .577 .707 r
F P
0 g
s
.29726 .67603 m .30021 .65718 L .29637 .66061 L p .707 .577 .707 r
F P
0 g
s
.29895 .58687 m .2977 .53222 L .30476 .52209 L p .707 .577 .707 r
F P
0 g
s
.50348 .61604 m .50085 .65423 L .49777 .65086 L p .707 .577 .707 r
F P
0 g
s
.49777 .65086 m .5004 .61268 L .50348 .61604 L p .707 .577 .707 r
F P
0 g
s
.49864 .52219 m .4999 .57684 L .48729 .56769 L p .707 .577 .707 r
F P
0 g
s
.48729 .56769 m .48604 .51304 L .49864 .52219 L p .707 .577 .707 r
F P
0 g
s
.30476 .52209 m .30602 .57674 L .29895 .58687 L p .707 .577 .707 r
F P
0 g
s
.49817 .6908 m .49522 .70965 L .49138 .71309 L p .707 .577 .707 r
F P
0 g
s
.49138 .71309 m .49433 .69424 L .49817 .6908 L p .707 .577 .707 r
F P
0 g
s
.29735 .63911 m .29998 .60092 L .30686 .5983 L p .707 .577 .707 r
F P
0 g
s
.30686 .5983 m .30423 .63649 L .29735 .63911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30602 .57674 m .30476 .52209 L .32111 .51296 L p .707 .577 .707 r
F P
0 g
s
.3024 .66552 m .29945 .68438 L .29342 .67946 L p .707 .577 .707 r
F P
0 g
s
.29342 .67946 m .29637 .66061 L .3024 .66552 L p .707 .577 .707 r
F P
0 g
s
.48604 .51304 m .48729 .56769 L .46622 .56042 L p .707 .577 .707 r
F P
0 g
s
.46622 .56042 m .46497 .50577 L .48604 .51304 L p .707 .577 .707 r
F P
0 g
s
.5004 .61268 m .49777 .65086 L .48503 .64709 L p .707 .577 .707 r
F P
0 g
s
.48503 .64709 m .48767 .6089 L .5004 .61268 L p .707 .577 .707 r
F P
0 g
s
.32111 .51296 m .32236 .5676 L .30602 .57674 L p .707 .577 .707 r
F P
0 g
s
.49433 .69424 m .49138 .71309 L .47803 .71471 L p .707 .577 .707 r
F P
0 g
s
.47803 .71471 m .48099 .69586 L .49433 .69424 L p .707 .577 .707 r
F P
0 g
s
.32236 .5676 m .32111 .51296 L .34515 .50572 L p .707 .577 .707 r
F P
0 g
s
.30423 .63649 m .30686 .5983 L .32303 .59667 L p .707 .577 .707 r
F P
0 g
s
.32303 .59667 m .3204 .63486 L .30423 .63649 L p .707 .577 .707 r
F P
0 g
s
.31772 .67143 m .31477 .69028 L .29945 .68438 L p .707 .577 .707 r
F P
0 g
s
.29945 .68438 m .3024 .66552 L .31772 .67143 L p .707 .577 .707 r
F P
0 g
s
.46497 .50577 m .46622 .56042 L .43876 .55575 L p .707 .577 .707 r
F P
0 g
s
.43876 .55575 m .43751 .5011 L .46497 .50577 L p .707 .577 .707 r
F P
0 g
s
.34515 .50572 m .3464 .56036 L .32236 .5676 L p .707 .577 .707 r
F P
0 g
s
.48767 .6089 m .48503 .64709 L .46388 .64327 L p .707 .577 .707 r
F P
0 g
s
.46388 .64327 m .46652 .60509 L .48767 .6089 L p .707 .577 .707 r
F P
0 g
s
.3464 .56036 m .34515 .50572 L .37451 .50107 L p .707 .577 .707 r
F P
0 g
s
.48099 .69586 m .47803 .71471 L .45649 .71436 L p .707 .577 .707 r
F P
0 g
s
.45649 .71436 m .45945 .69551 L .48099 .69586 L p .707 .577 .707 r
F P
0 g
s
.43751 .5011 m .43876 .55575 L .40759 .55413 L p .707 .577 .707 r
F P
0 g
s
.40759 .55413 m .40634 .49948 L .43751 .5011 L p .707 .577 .707 r
F P
0 g
s
.3204 .63486 m .32303 .59667 L .3469 .5962 L p .707 .577 .707 r
F P
0 g
s
.37577 .55572 m .37451 .50107 L .40634 .49948 L p .707 .577 .707 r
F P
0 g
s
.37451 .50107 m .37577 .55572 L .3464 .56036 L p .707 .577 .707 r
F P
0 g
s
.3469 .5962 m .34427 .63439 L .3204 .63486 L p .707 .577 .707 r
F P
0 g
s
.34083 .67776 m .33788 .69661 L .31477 .69028 L p .707 .577 .707 r
F P
0 g
s
.31477 .69028 m .31772 .67143 L .34083 .67776 L p .707 .577 .707 r
F P
0 g
s
.40634 .49948 m .40759 .55413 L .37577 .55572 L p .707 .577 .707 r
F P
0 g
s
.46652 .60509 m .46388 .64327 L .43639 .63979 L p .707 .577 .707 r
F P
0 g
s
.43639 .63979 m .43903 .6016 L .46652 .60509 L p .707 .577 .707 r
F P
0 g
s
.45945 .69551 m .45649 .71436 L .42887 .71207 L p .707 .577 .707 r
F P
0 g
s
.34427 .63439 m .3469 .5962 L .37614 .59693 L p .707 .577 .707 r
F P
0 g
s
.42887 .71207 m .43182 .69322 L .45945 .69551 L p .707 .577 .707 r
F P
0 g
s
.37614 .59693 m .37351 .63512 L .34427 .63439 L p .707 .577 .707 r
F P
0 g
s
.36946 .68389 m .36651 .70274 L .33788 .69661 L p .707 .577 .707 r
F P
0 g
s
.33788 .69661 m .34083 .67776 L .36946 .68389 L p .707 .577 .707 r
F P
0 g
s
.43903 .6016 m .43639 .63979 L .40525 .63698 L p .707 .577 .707 r
F P
0 g
s
.40525 .63698 m .40789 .59879 L .43903 .6016 L p .707 .577 .707 r
F P
0 g
s
.37351 .63512 m .37614 .59693 L .40789 .59879 L p .707 .577 .707 r
F P
0 g
s
.43182 .69322 m .42887 .71207 L .39786 .70806 L p .707 .577 .707 r
F P
0 g
s
.40789 .59879 m .40525 .63698 L .37351 .63512 L p .707 .577 .707 r
F P
0 g
s
.39786 .70806 m .40082 .68921 L .43182 .69322 L p .707 .577 .707 r
F P
0 g
s
.40082 .68921 m .39786 .70806 L .36651 .70274 L p .707 .577 .707 r
F P
0 g
s
.36651 .70274 m .36946 .68389 L .40082 .68921 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001aOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00JWoo001W
Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`80009JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP0000005`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001QOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000BOolE000nOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000moo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo10001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000c
Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEPT000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH70005FUH00`00FUH000020005FUH0
1000FUIJEUYF100000=JEP000000100015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001D
Ool00`00FUH00004FUH00`00FUH000030004FUHF0006FUH00`00FUIJEP02FUH300000eYF001JEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001DOol00`00FUH00004FUH20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002aoo`00E7oo00<005YF00000UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000/Ool005Aoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;7oo001DOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000/Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP8002aoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Eoo`04001JEUYFFUHF00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000AJEP03001JEUYF009JEPH000Uoo`<000]oo`T000=JEP04001JEUYF
FUH2000/Ool0049ooaP00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH0
05YF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YF00000P000UYF2@000goo1@00
00=oo`0000001`000eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P00;7oo000nOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF0P0000=JEP00FUH01UYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;7oo000jOol4
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002
FUH2000/Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;7oo000cOol30005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009JEQH000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000090001eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF1P001EYF00<005YFFUH015YF00<005YFFUH01UYF4@000eYF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP04001JEP00
000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT0039oo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH0
05YF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05000_Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH01EYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH<0005OolD0002FUH01000FUIJEUYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH01P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000Moo`D000Qoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH80002
FUH00`00FUIJEP04FUHF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000]Ool01000FUIJ
EP000eYF00<005YF00000`000UYF20000goo1@0000=oo`0000001`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00@005YFFUIJEPT000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP050005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH60009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00@005YF
FUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001J
EP00FUH00002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;7oo000]Ool00`00FUIJEP030005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
00001@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0035YF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002P001UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01P00FUIJEP00FUH000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJ
EP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000030009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP050003FUH7
0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P00;Goo000]
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH600000eYF000000050002FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF0000000]Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF000000050004FUH00`00FUIJEP04FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH0100015YF1P0015YF00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005P0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002ioo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH500000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUHG000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH01000FUIJEUYF:`00;Woo000^Ool01000
FUIJEUYF5P0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL004Uoo`00;goo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YF00001`001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00AJEP@0009JEP03001JEUYF009JEP@0009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF1000@Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000goo00@005YFFUH000EJEP03
001JEUYF00H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00?Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03
FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00004FUH00`00FUH0000<0006FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000g
Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH=0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH500000eYF000000050002FUH40005FUH00`00FUIJEP06
FUH01000FUIJEUYF1000<goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJEP04001JEUYFFUH7
00000goo000000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000aOol002eoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0>0006FUH00`00FUIJEP05FUH0
0`00FUIJEP02000_Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH;0005FUH01000FUIJEUYF1000
;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUIJEUYF300000AJEP00FUH002eoo`00;Goo00<005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00;Goo1P001EYF
00<005YFFUH015YF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P001UYF0`000Woo1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH0
05YF00000eYF20002goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002io
o`00<7oo100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1P000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00MJEP03001JEUYF00D0011oo`P000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`/0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03
FUH01000FUH000005Woo3`00;goo000^Ool300000eYF001JEP04FUH01000FUIJEUYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03FUH00`00FUIJEP02
001COol002eoo`8000=JEP03001JEUYF009JEP8000IJEP8000=JEPX000=JEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHZ0008FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00001eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo
000]Ool300000eYF001JEP04FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP0I0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000025YF00<005YFFUH00eYF00<005YFFUH0
0P00Dgoo000]Ool200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH6000>Ool01000FUIJEP0015YF10000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF00@005YF000000MJEP03001J
EUYF00AJEP03001JEUYF008005=oo`00;7oo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`05001JEUYF001JEP030007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP02FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00;7oo00<005YF
000015YF00<005YF00003P0015YF0`001UYF00<005YFFUH01EYF00<005YF00000`0017oo00<005YF
FUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF
00<005YFFUH01UYF100015YF00@005YF000000MJEP03001JEUYF00=JEP06001JEUYF001JEP00Dgoo
000/Ool00`00FUH00004FUH00`00FUIJEP02FUH60006Ool80005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20002Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00@005YF000000MJEP03
001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF
1P000goo20000UYF00<005YFFUH01EYF00<005YFFUH015YF1@0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0000=JEP0000000`0015YF00<005YFFUH00eYF00<005YFFUH00P00E7oo000_Ool20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070003Ool40006FUH00`00FUIJEP04FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH70003FUH00`00
FUIJEP02001DOol0035oo`<000EJEP03001JEUYF00IJEP03001JEUYF00=JEPL000Aoo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF1@0000=JEP000000E7oo000dOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH=0003FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF000000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003Qoo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH?0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001DOol003]oo`@0009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001J
EP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF2@00EGoo000oOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002Ool8001NOol004Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005
Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YF00000`00I7oo001>Ool80004FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0027oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00=JEP@0061oo`00EWoo3`00
37oo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF0`00
1EYF00<005YFFUH01UYF00<005YF00000`00G7oo001hOol;0006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3001IOol008=ooaX000AJEPL00003Ool0
000000T000IJEP03001JEUYF00EJEP03001JEP00008005Ioo`00T7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF2@000goo10000UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00TWoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2`001EYF00<005YF
FUH00UYF00<005YF0000E7oo002GOol50006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF4000E7oo002LOol40002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002POol50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000EGoo002UOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo002YOol70004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00EGoo002`OolG001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59998 .75612 m .59872 .70148 L .56755 .69986 L p .707 .577 .707 r
F P
0 g
s
.59872 .70148 m .59998 .75612 L .6318 .75453 L p .707 .577 .707 r
F P
0 g
s
.6318 .75453 m .63055 .69989 L .59872 .70148 L p .707 .577 .707 r
F P
0 g
s
.63055 .69989 m .6318 .75453 L .66117 .74989 L p .707 .577 .707 r
F P
0 g
s
.66117 .74989 m .65992 .69524 L .63055 .69989 L p .707 .577 .707 r
F P
0 g
s
.56881 .7545 m .56755 .69986 L .54009 .69518 L p .707 .577 .707 r
F P
0 g
s
.56755 .69986 m .56881 .7545 L .59998 .75612 L p .707 .577 .707 r
F P
0 g
s
.65992 .69524 m .66117 .74989 L .6852 .74265 L p .707 .577 .707 r
F P
0 g
s
.6852 .74265 m .68395 .688 L .65992 .69524 L p .707 .577 .707 r
F P
0 g
s
.59875 .79585 m .60138 .75766 L .57024 .75485 L p .707 .577 .707 r
F P
0 g
s
.60138 .75766 m .59875 .79585 L .60461 .79619 L p .707 .577 .707 r
F P
0 g
s
.57024 .75485 m .56761 .79304 L .57274 .7935 L p .707 .577 .707 r
F P
0 g
s
.57274 .7935 m .59875 .79585 L p .58642 .77812 L .707 .577 .707 r
F P
0 g
s
.58642 .77812 m .57024 .75485 L .57274 .7935 L .707 .577 .707 r
F
.56761 .79304 m .57024 .75485 L .54275 .75137 L p F P
0 g
s
.54275 .75137 m .54012 .78956 L .54445 .79011 L p .707 .577 .707 r
F P
0 g
s
.54445 .79011 m .56761 .79304 L p .55608 .77372 L .707 .577 .707 r
F P
0 g
s
.55608 .77372 m .54275 .75137 L .54445 .79011 L .707 .577 .707 r
F
.54012 .78956 m .54275 .75137 L .5216 .74755 L p F P
0 g
s
.5216 .74755 m .51897 .78574 L .54012 .78956 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .51936 .78833 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53795 .80753 m .53961 .79692 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.53961 .79692 m .5409 .78868 L p .53456 .80403 L .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .5409 .78868 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56557 .80982 m .56714 .7998 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.56714 .7998 m .56852 .79097 L p .56141 .80625 L .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .56852 .79097 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59658 .81382 m .59824 .80322 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.59824 .80322 m .59953 .79497 L p .592 .81009 L .707 .577 .707 r
F P
0 g
s
.60461 .79619 m .63049 .79771 L p .61836 .78103 L .707 .577 .707 r
F P
0 g
s
.61836 .78103 m .60138 .75766 L .60461 .79619 L .707 .577 .707 r
F
.63049 .79771 m .63312 .75952 L .60138 .75766 L p F P
0 g
s
.54135 .74983 m .54009 .69518 L .51903 .68792 L p .707 .577 .707 r
F P
0 g
s
.54009 .69518 m .54135 .74983 L .56881 .7545 L p .707 .577 .707 r
F P
0 g
s
.56852 .79097 m .56557 .80982 L .59658 .81382 L p .707 .577 .707 r
F P
0 g
s
.59953 .79497 m .59658 .81382 L .62793 .81915 L p .707 .577 .707 r
F P
0 g
s
.63312 .75952 m .63049 .79771 L .65973 .79844 L p .707 .577 .707 r
F P
0 g
s
.65973 .79844 m .66236 .76026 L .63312 .75952 L p .707 .577 .707 r
F P
0 g
s
.62793 .81915 m .63088 .8003 L .59953 .79497 L p .707 .577 .707 r
F P
0 g
s
.63088 .8003 m .62793 .81915 L .65656 .82528 L p .707 .577 .707 r
F P
0 g
s
.65656 .82528 m .65952 .80643 L .63088 .8003 L p .707 .577 .707 r
F P
0 g
s
.5409 .78868 m .53795 .80753 L .56557 .80982 L p .707 .577 .707 r
F P
0 g
s
.68395 .688 m .6852 .74265 L .70155 .73351 L p .707 .577 .707 r
F P
0 g
s
.70155 .73351 m .7003 .67887 L .68395 .688 L p .707 .577 .707 r
F P
0 g
s
.66236 .76026 m .65973 .79844 L .6836 .79797 L p .707 .577 .707 r
F P
0 g
s
.6836 .79797 m .68623 .75978 L .66236 .76026 L p .707 .577 .707 r
F P
0 g
s
.51903 .68792 m .52028 .74256 L .54135 .74983 L p .707 .577 .707 r
F P
0 g
s
.65952 .80643 m .65656 .82528 L .67967 .8316 L p .707 .577 .707 r
F P
0 g
s
.67967 .8316 m .68262 .81275 L .65952 .80643 L p .707 .577 .707 r
F P
0 g
s
.52028 .74256 m .51903 .68792 L .50642 .67877 L p .707 .577 .707 r
F P
0 g
s
.51936 .78833 m .51641 .80718 L .53795 .80753 L p .707 .577 .707 r
F P
0 g
s
.7003 .67887 m .70155 .73351 L .70862 .72338 L p .707 .577 .707 r
F P
0 g
s
.70862 .72338 m .70736 .66874 L .7003 .67887 L p .707 .577 .707 r
F P
0 g
s
.68623 .75978 m .6836 .79797 L .69977 .79634 L p .707 .577 .707 r
F P
0 g
s
.69977 .79634 m .7024 .75816 L .68623 .75978 L p .707 .577 .707 r
F P
0 g
s
.68262 .81275 m .67967 .8316 L .69499 .83751 L p .707 .577 .707 r
F P
0 g
s
.50642 .67877 m .50767 .73342 L .52028 .74256 L p .707 .577 .707 r
F P
0 g
s
.69499 .83751 m .69794 .81866 L .68262 .81275 L p .707 .577 .707 r
F P
0 g
s
.51897 .78574 m .5216 .74755 L .50887 .74378 L p .707 .577 .707 r
F P
0 g
s
.50602 .78995 m .50307 .8088 L .51641 .80718 L p .707 .577 .707 r
F P
0 g
s
.51641 .80718 m .51936 .78833 L .50602 .78995 L p .707 .577 .707 r
F P
0 g
s
.50887 .74378 m .50623 .78197 L .51897 .78574 L p .707 .577 .707 r
F P
0 g
s
.50767 .73342 m .50642 .67877 L .50351 .66863 L p .707 .577 .707 r
F P
0 g
s
.7024 .75816 m .69977 .79634 L .70665 .79372 L p .707 .577 .707 r
F P
0 g
s
.70665 .79372 m .70928 .75553 L .7024 .75816 L p .707 .577 .707 r
F P
0 g
s
.70736 .66874 m .70862 .72338 L .7057 .71324 L p .707 .577 .707 r
F P
0 g
s
.7057 .71324 m .70445 .6586 L .70736 .66874 L p .707 .577 .707 r
F P
0 g
s
.69794 .81866 m .69499 .83751 L .70102 .84243 L p .707 .577 .707 r
F P
0 g
s
.50351 .66863 m .50476 .72328 L .50767 .73342 L p .707 .577 .707 r
F P
0 g
s
.70102 .84243 m .70398 .82358 L .69794 .81866 L p .707 .577 .707 r
F P
0 g
s
.50623 .78197 m .50887 .74378 L .50579 .74042 L p .707 .577 .707 r
F P
0 g
s
.50218 .79339 m .49922 .81224 L .50307 .8088 L p .707 .577 .707 r
F P
0 g
s
.50307 .8088 m .50602 .78995 L .50218 .79339 L p .707 .577 .707 r
F P
0 g
s
.4838 .81835 m .49482 .30988 L .45082 .30681 L p .707 .577 .707 r
F P
0 g
s
.50579 .74042 m .50316 .7786 L .50623 .78197 L p .707 .577 .707 r
F P
0 g
s
.50476 .72328 m .50351 .66863 L .51057 .6585 L p .707 .577 .707 r
F P
0 g
s
.51057 .6585 m .51182 .71315 L .50476 .72328 L p .707 .577 .707 r
F P
0 g
s
.50316 .7786 m .50579 .74042 L .51267 .73779 L p .707 .577 .707 r
F P
0 g
s
.50821 .7983 m .50526 .81715 L .49922 .81224 L p .707 .577 .707 r
F P
0 g
s
.49922 .81224 m .50218 .79339 L .50821 .7983 L p .707 .577 .707 r
F P
0 g
s
.51182 .71315 m .51057 .6585 L .52692 .64937 L p .707 .577 .707 r
F P
0 g
s
.51267 .73779 m .51004 .77598 L .50316 .7786 L p .707 .577 .707 r
F P
0 g
s
.52692 .64937 m .52817 .70401 L .51182 .71315 L p .707 .577 .707 r
F P
0 g
s
.51004 .77598 m .51267 .73779 L .52884 .73617 L p .707 .577 .707 r
F P
0 g
s
.52353 .80421 m .52058 .82306 L .50526 .81715 L p .707 .577 .707 r
F P
0 g
s
.50526 .81715 m .50821 .7983 L .52353 .80421 L p .707 .577 .707 r
F P
0 g
s
.52884 .73617 m .52621 .77435 L .51004 .77598 L p .707 .577 .707 r
F P
0 g
s
.52058 .82306 m .52353 .80421 L .54664 .81054 L p .707 .577 .707 r
F P
0 g
s
.49482 .30988 m .4838 .81835 L .52873 .81839 L p .707 .577 .707 r
F P
0 g
s
.52817 .70401 m .52692 .64937 L .55095 .64212 L p .707 .577 .707 r
F P
0 g
s
.55095 .64212 m .55221 .69677 L .52817 .70401 L p .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .52884 .73617 L .54369 .73587 L p .707 .577 .707 r
F P
0 g
s
.54369 .73587 m .55271 .7357 L p .54461 .74752 L .707 .577 .707 r
F P
0 g
s
.52621 .77435 m .54369 .73587 L .54461 .74752 L .707 .577 .707 r
F
.55271 .7357 m .55008 .77388 L .52621 .77435 L p F P
0 g
s
.52873 .81839 m .53336 .60492 L p .49482 .30988 L .707 .577 .707 r
F P
0 g
s
.53336 .60492 m .53976 .30992 L .51008 .3099 L p .707 .577 .707 r
F P
0 g
s
.51008 .3099 m .49482 .30988 L p .53336 .60492 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .55095 .64212 L .5552 .64145 L p .707 .577 .707 r
F P
0 g
s
.5552 .64145 m .58032 .63748 L p .56188 .67638 L .707 .577 .707 r
F P
0 g
s
.55221 .69677 m .5552 .64145 L .56188 .67638 L .707 .577 .707 r
F
.58157 .69213 m .58032 .63748 L .61215 .63589 L p F P
0 g
s
.58032 .63748 m .58157 .69213 L .55221 .69677 L p .707 .577 .707 r
F P
0 g
s
.61215 .63589 m .6134 .69054 L .58157 .69213 L p .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .55271 .7357 L .5707 .73615 L p .707 .577 .707 r
F P
0 g
s
.5707 .73615 m .58195 .73643 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.55008 .77388 m .5707 .73615 L .56614 .755 L .707 .577 .707 r
F
.58122 .30691 m .57205 .72963 L p .57219 .72998 L F P
0 g
s
.58195 .73643 m .57932 .77461 L .56151 .77417 L p .707 .577 .707 r
F P
0 g
s
.56151 .77417 m .55008 .77388 L p .56614 .755 L .707 .577 .707 r
F P
0 g
s
.56614 .755 m .58195 .73643 L .56151 .77417 L .707 .577 .707 r
F
.57932 .77461 m .58195 .73643 L .59079 .73695 L p F P
0 g
s
.59079 .73695 m .61369 .73829 L p .58813 .76531 L .707 .577 .707 r
F P
0 g
s
.57932 .77461 m .59079 .73695 L .58813 .76531 L .707 .577 .707 r
F
.64332 .63751 m .64457 .69216 L .6134 .69054 L p F P
0 g
s
.6134 .69054 m .61215 .63589 L .64332 .63751 L p .707 .577 .707 r
F P
0 g
s
.64483 .7411 m .6422 .77929 L .61106 .77648 L p .707 .577 .707 r
F P
0 g
s
.61106 .77648 m .61369 .73829 L .64483 .7411 L p .707 .577 .707 r
F P
0 g
s
.61369 .73829 m .61106 .77648 L .57932 .77461 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .62721 .80169 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61515 .30116 m .61018 .53024 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.61018 .53024 m .60412 .80963 L p .61853 .44132 L .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58787 .81239 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57205 .72963 m .57203 .73066 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.57203 .73066 m .57019 .81538 L p .57215 .73015 L .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .59601 .6315 L .57219 .72998 L .707 .577 .707 r
F
.59601 .6315 m .58122 .30691 L .57219 .72998 L F
.58787 .81239 m .60412 .80963 L p .57205 .72963 L F P
0 g
s
.54664 .81054 m .54369 .82939 L .52058 .82306 L p .707 .577 .707 r
F P
0 g
s
.54369 .82939 m .54664 .81054 L .57527 .81666 L p .707 .577 .707 r
F P
0 g
s
.53976 .30992 m .52873 .81839 L .57019 .81538 L p .707 .577 .707 r
F P
0 g
s
.57019 .81538 m .58122 .30691 L .53976 .30992 L p .707 .577 .707 r
F P
0 g
s
.43979 .81528 m .45082 .30681 L .41205 .301 L p .707 .577 .707 r
F P
0 g
s
.45082 .30681 m .43979 .81528 L .4838 .81835 L p .707 .577 .707 r
F P
0 g
s
.70928 .75553 m .70665 .79372 L .70357 .79036 L p .707 .577 .707 r
F P
0 g
s
.70357 .79036 m .70621 .75217 L .70928 .75553 L p .707 .577 .707 r
F P
0 g
s
.70445 .6586 m .7057 .71324 L .6931 .7041 L p .707 .577 .707 r
F P
0 g
s
.6931 .7041 m .69184 .64945 L .70445 .6586 L p .707 .577 .707 r
F P
0 g
s
.70398 .82358 m .70102 .84243 L .69718 .84586 L p .707 .577 .707 r
F P
0 g
s
.60412 .80963 m .61515 .30116 L .58122 .30691 L p .707 .577 .707 r
F P
0 g
s
.69718 .84586 m .70013 .82701 L .70398 .82358 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25697 .71931 m .25571 .66466 L .22454 .66304 L p .707 .577 .707 r
F P
0 g
s
.25571 .66466 m .25697 .71931 L .28879 .71772 L p .707 .577 .707 r
F P
0 g
s
.28879 .71772 m .28754 .66307 L .25571 .66466 L p .707 .577 .707 r
F P
0 g
s
.40103 .80947 m .41205 .301 L .38231 .29302 L p .707 .577 .707 r
F P
0 g
s
.41205 .301 m .40103 .80947 L .43979 .81528 L p .707 .577 .707 r
F P
0 g
s
.28754 .66307 m .28879 .71772 L .31816 .71307 L p .707 .577 .707 r
F P
0 g
s
.31816 .71307 m .31691 .65843 L .28754 .66307 L p .707 .577 .707 r
F P
0 g
s
.2258 .71769 m .22454 .66304 L .19708 .65837 L p .707 .577 .707 r
F P
0 g
s
.22454 .66304 m .2258 .71769 L .25697 .71931 L p .707 .577 .707 r
F P
0 g
s
.31691 .65843 m .31816 .71307 L .3422 .70583 L p .707 .577 .707 r
F P
0 g
s
.3422 .70583 m .34094 .65119 L .31691 .65843 L p .707 .577 .707 r
F P
0 g
s
.69184 .64945 m .6931 .7041 L .67203 .69683 L p .707 .577 .707 r
F P
0 g
s
.67203 .69683 m .67078 .64218 L .69184 .64945 L p .707 .577 .707 r
F P
0 g
s
.70621 .75217 m .70357 .79036 L .69084 .78658 L p .707 .577 .707 r
F P
0 g
s
.69084 .78658 m .69347 .7484 L .70621 .75217 L p .707 .577 .707 r
F P
0 g
s
.62721 .80169 m .63823 .29322 L .61515 .30116 L p .707 .577 .707 r
F P
0 g
s
.70013 .82701 m .69718 .84586 L .68384 .84748 L p .707 .577 .707 r
F P
0 g
s
.25574 .75903 m .25837 .72085 L .22723 .71804 L p .707 .577 .707 r
F P
0 g
s
.25837 .72085 m .25574 .75903 L .2616 .75938 L p .707 .577 .707 r
F P
0 g
s
.22723 .71804 m .2246 .75622 L .22973 .75669 L p .707 .577 .707 r
F P
0 g
s
.22973 .75669 m .25574 .75903 L p .24341 .7413 L .707 .577 .707 r
F P
0 g
s
.24341 .7413 m .22723 .71804 L .22973 .75669 L .707 .577 .707 r
F
.2246 .75622 m .22723 .71804 L .19974 .71455 L p F P
0 g
s
.19974 .71455 m .19711 .75274 L .20144 .75329 L p .707 .577 .707 r
F P
0 g
s
.20144 .75329 m .2246 .75622 L p .21307 .7369 L .707 .577 .707 r
F P
0 g
s
.21307 .7369 m .19974 .71455 L .20144 .75329 L .707 .577 .707 r
F
.19711 .75274 m .19974 .71455 L .17859 .71074 L p F P
0 g
s
.17859 .71074 m .17596 .74893 L .19711 .75274 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .17635 .75151 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.19494 .77072 m .1966 .76011 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.1966 .76011 m .19789 .75187 L p .19155 .76722 L .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .19789 .75187 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22256 .77301 m .22413 .76299 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.22413 .76299 m .22552 .75416 L p .2184 .76944 L .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .22552 .75416 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25357 .77701 m .25523 .7664 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.25523 .7664 m .25652 .75816 L p .24899 .77328 L .707 .577 .707 r
F P
0 g
s
.2616 .75938 m .28748 .7609 L p .27536 .74421 L .707 .577 .707 r
F P
0 g
s
.27536 .74421 m .25837 .72085 L .2616 .75938 L .707 .577 .707 r
F
.28748 .7609 m .29012 .72271 L .25837 .72085 L p F P
0 g
s
.19834 .71301 m .19708 .65837 L .17602 .6511 L p .707 .577 .707 r
F P
0 g
s
.19708 .65837 m .19834 .71301 L .2258 .71769 L p .707 .577 .707 r
F P
0 g
s
.68384 .84748 m .68679 .82863 L .70013 .82701 L p .707 .577 .707 r
F P
0 g
s
.22552 .75416 m .22256 .77301 L .25357 .77701 L p .707 .577 .707 r
F P
0 g
s
.25652 .75816 m .25357 .77701 L .28492 .78234 L p .707 .577 .707 r
F P
0 g
s
.29012 .72271 m .28748 .7609 L .31672 .76163 L p .707 .577 .707 r
F P
0 g
s
.31672 .76163 m .31935 .72344 L .29012 .72271 L p .707 .577 .707 r
F P
0 g
s
.28492 .78234 m .28788 .76348 L .25652 .75816 L p .707 .577 .707 r
F P
0 g
s
.28788 .76348 m .28492 .78234 L .31355 .78846 L p .707 .577 .707 r
F P
0 g
s
.31355 .78846 m .31651 .76961 L .28788 .76348 L p .707 .577 .707 r
F P
0 g
s
.19789 .75187 m .19494 .77072 L .22256 .77301 L p .707 .577 .707 r
F P
0 g
s
.37129 .80149 m .38231 .29302 L .36452 .28365 L p .707 .577 .707 r
F P
0 g
s
.38231 .29302 m .37129 .80149 L .40103 .80947 L p .707 .577 .707 r
F P
0 g
s
.34094 .65119 m .3422 .70583 L .35854 .6967 L p .707 .577 .707 r
F P
0 g
s
.35854 .6967 m .35729 .64205 L .34094 .65119 L p .707 .577 .707 r
F P
0 g
s
.67078 .64218 m .67203 .69683 L .64457 .69216 L p .707 .577 .707 r
F P
0 g
s
.64457 .69216 m .64332 .63751 L .67078 .64218 L p .707 .577 .707 r
F P
0 g
s
.31935 .72344 m .31672 .76163 L .34059 .76116 L p .707 .577 .707 r
F P
0 g
s
.34059 .76116 m .34323 .72297 L .31935 .72344 L p .707 .577 .707 r
F P
0 g
s
.17602 .6511 m .17727 .70575 L .19834 .71301 L p .707 .577 .707 r
F P
0 g
s
.31651 .76961 m .31355 .78846 L .33666 .79479 L p .707 .577 .707 r
F P
0 g
s
.33666 .79479 m .33961 .77594 L .31651 .76961 L p .707 .577 .707 r
F P
0 g
s
.17727 .70575 m .17602 .6511 L .16341 .64195 L p .707 .577 .707 r
F P
0 g
s
.69347 .7484 m .69084 .78658 L .66969 .78277 L p .707 .577 .707 r
F P
0 g
s
.66969 .78277 m .67232 .74458 L .69347 .7484 L p .707 .577 .707 r
F P
0 g
s
.17635 .75151 m .1734 .77037 L .19494 .77072 L p .707 .577 .707 r
F P
0 g
s
.68679 .82863 m .68384 .84748 L .6623 .84713 L p .707 .577 .707 r
F P
0 g
s
.6623 .84713 m .66525 .82828 L .68679 .82863 L p .707 .577 .707 r
F P
0 g
s
.63823 .29322 m .62721 .80169 L .63718 .79235 L p .707 .577 .707 r
F P
0 g
s
.63718 .79235 m .6482 .28388 L .63823 .29322 L p .707 .577 .707 r
F P
0 g
s
.35729 .64205 m .35854 .6967 L .36561 .68657 L p .707 .577 .707 r
F P
0 g
s
.36561 .68657 m .36435 .63192 L .35729 .64205 L p .707 .577 .707 r
F P
0 g
s
.34323 .72297 m .34059 .76116 L .35676 .75953 L p .707 .577 .707 r
F P
0 g
s
.35676 .75953 m .35939 .72134 L .34323 .72297 L p .707 .577 .707 r
F P
0 g
s
.33961 .77594 m .33666 .79479 L .35198 .8007 L p .707 .577 .707 r
F P
0 g
s
.16341 .64195 m .16466 .6966 L .17727 .70575 L p .707 .577 .707 r
F P
0 g
s
.35198 .8007 m .35493 .78185 L .33961 .77594 L p .707 .577 .707 r
F P
0 g
s
.17596 .74893 m .17859 .71074 L .16586 .70697 L p .707 .577 .707 r
F P
0 g
s
.67232 .74458 m .66969 .78277 L .6422 .77929 L p .707 .577 .707 r
F P
0 g
s
.6422 .77929 m .64483 .7411 L .67232 .74458 L p .707 .577 .707 r
F P
0 g
s
.16301 .75314 m .16006 .77199 L .1734 .77037 L p .707 .577 .707 r
F P
0 g
s
.1734 .77037 m .17635 .75151 L .16301 .75314 L p .707 .577 .707 r
F P
0 g
s
.16586 .70697 m .16322 .74515 L .17596 .74893 L p .707 .577 .707 r
F P
0 g
s
.66525 .82828 m .6623 .84713 L .63468 .84484 L p .707 .577 .707 r
F P
0 g
s
.16466 .6966 m .16341 .64195 L .1605 .63182 L p .707 .577 .707 r
F P
0 g
s
.35493 .78185 m .35198 .8007 L .35801 .80561 L p .707 .577 .707 r
F P
0 g
s
.36144 .62178 m .36269 .67643 L .35704 .67233 L p .707 .577 .707 r
F P
0 g
s
.35704 .67233 m .35009 .66728 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35908 .63124 m .36144 .62178 L .35704 .67233 L .707 .577 .707 r
F
.35009 .66728 m .34883 .61263 L .35961 .62046 L p F P
0 g
s
.35961 .62046 m .36144 .62178 L p .35908 .63124 L .707 .577 .707 r
F P
0 g
s
.35009 .66728 m .35961 .62046 L .35908 .63124 L .707 .577 .707 r
F
.35939 .72134 m .35676 .75953 L .36364 .75691 L p F P
0 g
s
.36364 .75691 m .36628 .71872 L .35939 .72134 L p .707 .577 .707 r
F P
0 g
s
.3632 .71536 m .36056 .75354 L .35559 .75207 L p .707 .577 .707 r
F P
0 g
s
.35559 .75207 m .34783 .74977 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.35547 .73265 m .3632 .71536 L .35559 .75207 L .707 .577 .707 r
F
.34783 .74977 m .35046 .71158 L .35536 .71303 L p F P
0 g
s
.35536 .71303 m .3632 .71536 L p .35547 .73265 L .707 .577 .707 r
F P
0 g
s
.34783 .74977 m .35536 .71303 L .35547 .73265 L .707 .577 .707 r
F
.35437 .72609 m .35511 .67036 L .35135 .787 L F
.35511 .67036 m .3604 .27382 L .35469 .59736 L F
.35511 .67036 m .35469 .59736 L .35135 .787 L F
.34938 .78229 m .35135 .787 L p .35469 .59736 L F P
0 g
s
.3604 .27382 m .35442 .54973 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35442 .54973 m .34938 .78229 L p .35469 .59736 L .707 .577 .707 r
F P
0 g
s
.35801 .80561 m .36097 .78676 L .35493 .78185 L p .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .34378 .79182 L .35634 .79029 L p .707 .577 .707 r
F P
0 g
s
.35634 .79029 m .35713 .7902 L p .35639 .79112 L .707 .577 .707 r
F P
0 g
s
.34083 .81067 m .35634 .79029 L .35639 .79112 L .707 .577 .707 r
F
.35135 .787 m .35349 .79212 L p .35406 .74939 L F P
0 g
s
.35406 .74939 m .35437 .72609 L .35361 .74137 L .707 .577 .707 r
F
.35406 .74939 m .35361 .74137 L .35135 .787 L F
.36452 .28365 m .3604 .27382 L p .35437 .72609 L F P
0 g
s
.35349 .79212 m .35535 .70637 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.35535 .70637 m .36452 .28365 L p .35437 .72609 L .707 .577 .707 r
F P
0 g
s
.36435 .63192 m .36561 .68657 L .36269 .67643 L p .707 .577 .707 r
F P
0 g
s
.36269 .67643 m .36144 .62178 L .36435 .63192 L p .707 .577 .707 r
F P
0 g
s
.36628 .71872 m .36364 .75691 L .36056 .75354 L p .707 .577 .707 r
F P
0 g
s
.36056 .75354 m .3632 .71536 L .36628 .71872 L p .707 .577 .707 r
F P
0 g
s
.36097 .78676 m .35801 .80561 L .35417 .80905 L p .707 .577 .707 r
F P
0 g
s
.35417 .80905 m .35713 .7902 L .36097 .78676 L p .707 .577 .707 r
F P
0 g
s
.35713 .7902 m .35417 .80905 L .34083 .81067 L p .707 .577 .707 r
F P
0 g
s
.36452 .28365 m .35349 .79212 L .37129 .80149 L p .707 .577 .707 r
F P
0 g
s
.63468 .84484 m .63763 .82599 L .66525 .82828 L p .707 .577 .707 r
F P
0 g
s
.57527 .81666 m .57232 .83551 L .54369 .82939 L p .707 .577 .707 r
F P
0 g
s
.63763 .82599 m .63468 .84484 L .60367 .84084 L p .707 .577 .707 r
F P
0 g
s
.60367 .84084 m .60662 .82199 L .63763 .82599 L p .707 .577 .707 r
F P
0 g
s
.1605 .63182 m .16175 .68646 L .16466 .6966 L p .707 .577 .707 r
F P
0 g
s
.60662 .82199 m .60367 .84084 L .57232 .83551 L p .707 .577 .707 r
F P
0 g
s
.57232 .83551 m .57527 .81666 L .60662 .82199 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16322 .74515 m .16586 .70697 L .16278 .7036 L p .707 .577 .707 r
F P
0 g
s
.15917 .75657 m .15621 .77542 L .16006 .77199 L p .707 .577 .707 r
F P
0 g
s
.16006 .77199 m .16301 .75314 L .15917 .75657 L p .707 .577 .707 r
F P
0 g
s
.6482 .28388 m .63718 .79235 L .63307 .78251 L p .707 .577 .707 r
F P
0 g
s
.63307 .78251 m .64409 .27404 L .6482 .28388 L p .707 .577 .707 r
F P
0 g
s
.16278 .7036 m .16015 .74179 L .16322 .74515 L p .707 .577 .707 r
F P
0 g
s
.16175 .68646 m .1605 .63182 L .16756 .62169 L p .707 .577 .707 r
F P
0 g
s
.34938 .78229 m .3604 .27382 L .37038 .26447 L p .707 .577 .707 r
F P
0 g
s
.16756 .62169 m .16881 .67633 L .16175 .68646 L p .707 .577 .707 r
F P
0 g
s
.16015 .74179 m .16278 .7036 L .16966 .70098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1652 .76148 m .16225 .78034 L .15621 .77542 L p .707 .577 .707 r
F P
0 g
s
.15621 .77542 m .15917 .75657 L .1652 .76148 L p .707 .577 .707 r
F P
0 g
s
.16881 .67633 m .16756 .62169 L .18391 .61255 L p .707 .577 .707 r
F P
0 g
s
.16966 .70098 m .16703 .73917 L .16015 .74179 L p .707 .577 .707 r
F P
0 g
s
.64409 .27404 m .63307 .78251 L .61527 .77315 L p .707 .577 .707 r
F P
0 g
s
.61527 .77315 m .62629 .26468 L .64409 .27404 L p .707 .577 .707 r
F P
0 g
s
.34883 .61263 m .35009 .66728 L .32902 .66001 L p .707 .577 .707 r
F P
0 g
s
.32902 .66001 m .32777 .60537 L .34883 .61263 L p .707 .577 .707 r
F P
0 g
s
.18391 .61255 m .18516 .6672 L .16881 .67633 L p .707 .577 .707 r
F P
0 g
s
.18516 .6672 m .18391 .61255 L .20794 .60531 L p .707 .577 .707 r
F P
0 g
s
.16703 .73917 m .16966 .70098 L .18583 .69935 L p .707 .577 .707 r
F P
0 g
s
.35935 .77294 m .37038 .26447 L .39346 .25654 L p .707 .577 .707 r
F P
0 g
s
.37038 .26447 m .35935 .77294 L .34938 .78229 L p .707 .577 .707 r
F P
0 g
s
.18052 .76739 m .17757 .78624 L .16225 .78034 L p .707 .577 .707 r
F P
0 g
s
.16225 .78034 m .1652 .76148 L .18052 .76739 L p .707 .577 .707 r
F P
0 g
s
.18583 .69935 m .1832 .73754 L .16703 .73917 L p .707 .577 .707 r
F P
0 g
s
.32777 .60537 m .32902 .66001 L .30156 .65534 L p .707 .577 .707 r
F P
0 g
s
.30156 .65534 m .30031 .6007 L .32777 .60537 L p .707 .577 .707 r
F P
0 g
s
.20794 .60531 m .2092 .65995 L .18516 .6672 L p .707 .577 .707 r
F P
0 g
s
.2092 .65995 m .20794 .60531 L .23731 .60067 L p .707 .577 .707 r
F P
0 g
s
.35046 .71158 m .34783 .74977 L .32668 .74595 L p .707 .577 .707 r
F P
0 g
s
.32668 .74595 m .32931 .70777 L .35046 .71158 L p .707 .577 .707 r
F P
0 g
s
.34378 .79182 m .34083 .81067 L .31929 .81032 L p .707 .577 .707 r
F P
0 g
s
.31929 .81032 m .32224 .79147 L .34378 .79182 L p .707 .577 .707 r
F P
0 g
s
.62629 .26468 m .61527 .77315 L .58553 .76517 L p .707 .577 .707 r
F P
0 g
s
.58553 .76517 m .59656 .2567 L .62629 .26468 L p .707 .577 .707 r
F P
0 g
s
.30031 .6007 m .30156 .65534 L .27039 .65372 L p .707 .577 .707 r
F P
0 g
s
.27039 .65372 m .26914 .59908 L .30031 .6007 L p .707 .577 .707 r
F P
0 g
s
.1832 .73754 m .18583 .69935 L .2097 .69888 L p .707 .577 .707 r
F P
0 g
s
.23856 .65531 m .23731 .60067 L .26914 .59908 L p .707 .577 .707 r
F P
0 g
s
.23731 .60067 m .23856 .65531 L .2092 .65995 L p .707 .577 .707 r
F P
0 g
s
.20363 .77372 m .20068 .79257 L .17757 .78624 L p .707 .577 .707 r
F P
0 g
s
.17757 .78624 m .18052 .76739 L .20363 .77372 L p .707 .577 .707 r
F P
0 g
s
.2097 .69888 m .20707 .73707 L .1832 .73754 L p .707 .577 .707 r
F P
0 g
s
.26914 .59908 m .27039 .65372 L .23856 .65531 L p .707 .577 .707 r
F P
0 g
s
.73718 .65653 m .73593 .60188 L .70476 .60026 L p .707 .577 .707 r
F P
0 g
s
.73593 .60188 m .73718 .65653 L .76901 .65494 L p .707 .577 .707 r
F P
0 g
s
.76901 .65494 m .76775 .6003 L .73593 .60188 L p .707 .577 .707 r
F P
0 g
s
.76775 .6003 m .76901 .65494 L .79837 .6503 L p .707 .577 .707 r
F P
0 g
s
.79837 .6503 m .79712 .59565 L .76775 .6003 L p .707 .577 .707 r
F P
0 g
s
.39346 .25654 m .38243 .76501 L .35935 .77294 L p .707 .577 .707 r
F P
0 g
s
.38243 .76501 m .39346 .25654 L .42739 .25078 L p .707 .577 .707 r
F P
0 g
s
.32931 .70777 m .32668 .74595 L .29919 .74247 L p .707 .577 .707 r
F P
0 g
s
.29919 .74247 m .30182 .70428 L .32931 .70777 L p .707 .577 .707 r
F P
0 g
s
.70601 .65491 m .70476 .60026 L .6773 .59559 L p .707 .577 .707 r
F P
0 g
s
.70476 .60026 m .70601 .65491 L .73718 .65653 L p .707 .577 .707 r
F P
0 g
s
.32224 .79147 m .31929 .81032 L .29167 .80803 L p .707 .577 .707 r
F P
0 g
s
.29167 .80803 m .29462 .78918 L .32224 .79147 L p .707 .577 .707 r
F P
0 g
s
.20707 .73707 m .2097 .69888 L .23894 .69961 L p .707 .577 .707 r
F P
0 g
s
.79712 .59565 m .79837 .6503 L .82241 .64305 L p .707 .577 .707 r
F P
0 g
s
.82241 .64305 m .82116 .58841 L .79712 .59565 L p .707 .577 .707 r
F P
0 g
s
.23226 .77985 m .22931 .7987 L .20068 .79257 L p .707 .577 .707 r
F P
0 g
s
.20068 .79257 m .20363 .77372 L .23226 .77985 L p .707 .577 .707 r
F P
0 g
s
.23894 .69961 m .23631 .7378 L .20707 .73707 L p .707 .577 .707 r
F P
0 g
s
.73595 .69317 m .73859 .65498 L .70744 .65217 L p .707 .577 .707 r
F P
0 g
s
.73859 .65498 m .73595 .69317 L .7677 .69503 L p .707 .577 .707 r
F P
0 g
s
.7677 .69503 m .77033 .65685 L .73859 .65498 L p .707 .577 .707 r
F P
0 g
s
.59656 .2567 m .58553 .76517 L .54676 .75936 L p .707 .577 .707 r
F P
0 g
s
.54676 .75936 m .55779 .25089 L .59656 .2567 L p .707 .577 .707 r
F P
0 g
s
.67855 .65024 m .6773 .59559 L .65623 .58833 L p .707 .577 .707 r
F P
0 g
s
.6773 .59559 m .67855 .65024 L .70601 .65491 L p .707 .577 .707 r
F P
0 g
s
.30182 .70428 m .29919 .74247 L .26805 .73966 L p .707 .577 .707 r
F P
0 g
s
.26805 .73966 m .27068 .70147 L .30182 .70428 L p .707 .577 .707 r
F P
0 g
s
.77033 .65685 m .7677 .69503 L .79693 .69576 L p .707 .577 .707 r
F P
0 g
s
.79693 .69576 m .79957 .65758 L .77033 .65685 L p .707 .577 .707 r
F P
0 g
s
.29462 .78918 m .29167 .80803 L .26066 .80402 L p .707 .577 .707 r
F P
0 g
s
.70744 .65217 m .70481 .69036 L .73595 .69317 L p .707 .577 .707 r
F P
0 g
s
.23631 .7378 m .23894 .69961 L .27068 .70147 L p .707 .577 .707 r
F P
0 g
s
.70573 .69501 m .70278 .71386 L .73378 .71787 L p .707 .577 .707 r
F P
0 g
s
.73378 .71787 m .73674 .69901 L .70573 .69501 L p .707 .577 .707 r
F P
0 g
s
.73674 .69901 m .73378 .71787 L .76514 .72319 L p .707 .577 .707 r
F P
0 g
s
.26066 .80402 m .26361 .78517 L .29462 .78918 L p .707 .577 .707 r
F P
0 g
s
.70481 .69036 m .70744 .65217 L .67995 .64869 L p .707 .577 .707 r
F P
0 g
s
.26361 .78517 m .26066 .80402 L .22931 .7987 L p .707 .577 .707 r
F P
0 g
s
.22931 .7987 m .23226 .77985 L .26361 .78517 L p .707 .577 .707 r
F P
0 g
s
.76514 .72319 m .76809 .70434 L .73674 .69901 L p .707 .577 .707 r
F P
0 g
s
.27068 .70147 m .26805 .73966 L .23631 .7378 L p .707 .577 .707 r
F P
0 g
s
.76809 .70434 m .76514 .72319 L .79377 .72932 L p .707 .577 .707 r
F P
0 g
s
.67995 .64869 m .67732 .68688 L .70481 .69036 L p .707 .577 .707 r
F P
0 g
s
.41637 .75925 m .42739 .25078 L .46885 .24778 L p .707 .577 .707 r
F P
0 g
s
.42739 .25078 m .41637 .75925 L .38243 .76501 L p .707 .577 .707 r
F P
0 g
s
.79377 .72932 m .79672 .71047 L .76809 .70434 L p .707 .577 .707 r
F P
0 g
s
.6781 .69272 m .67515 .71157 L .70278 .71386 L p .707 .577 .707 r
F P
0 g
s
.70278 .71386 m .70573 .69501 L .6781 .69272 L p .707 .577 .707 r
F P
0 g
s
.82116 .58841 m .82241 .64305 L .83876 .63392 L p .707 .577 .707 r
F P
0 g
s
.83876 .63392 m .8375 .57927 L .82116 .58841 L p .707 .577 .707 r
F P
0 g
s
.79957 .65758 m .79693 .69576 L .82081 .69529 L p .707 .577 .707 r
F P
0 g
s
.82081 .69529 m .82344 .65711 L .79957 .65758 L p .707 .577 .707 r
F P
0 g
s
.65623 .58833 m .65748 .64297 L .67855 .65024 L p .707 .577 .707 r
F P
0 g
s
.79672 .71047 m .79377 .72932 L .81687 .73565 L p .707 .577 .707 r
F P
0 g
s
.67732 .68688 m .67995 .64869 L .65881 .64488 L p .707 .577 .707 r
F P
0 g
s
.55779 .25089 m .54676 .75936 L .50276 .75628 L p .707 .577 .707 r
F P
0 g
s
.50276 .75628 m .51378 .24781 L .55779 .25089 L p .707 .577 .707 r
F P
0 g
s
.81687 .73565 m .81983 .71679 L .79672 .71047 L p .707 .577 .707 r
F P
0 g
s
.65748 .64297 m .65623 .58833 L .64362 .57918 L p .707 .577 .707 r
F P
0 g
s
.65881 .64488 m .65617 .68306 L .67732 .68688 L p .707 .577 .707 r
F P
0 g
s
.65657 .69237 m .65361 .71122 L .67515 .71157 L p .707 .577 .707 r
F P
0 g
s
.67515 .71157 m .6781 .69272 L .65657 .69237 L p .707 .577 .707 r
F P
0 g
s
.45783 .75625 m .46885 .24778 L .51378 .24781 L p .707 .577 .707 r
F P
0 g
s
.46885 .24778 m .45783 .75625 L .41637 .75925 L p .707 .577 .707 r
F P
0 g
s
.51378 .24781 m .50276 .75628 L .45783 .75625 L p .707 .577 .707 r
F P
0 g
s
.82344 .65711 m .82081 .69529 L .83697 .69367 L p .707 .577 .707 r
F P
0 g
s
.83697 .69367 m .83961 .65548 L .82344 .65711 L p .707 .577 .707 r
F P
0 g
s
.8375 .57927 m .83876 .63392 L .84582 .62379 L p .707 .577 .707 r
F P
0 g
s
.84582 .62379 m .84457 .56914 L .8375 .57927 L p .707 .577 .707 r
F P
0 g
s
.81983 .71679 m .81687 .73565 L .83219 .74155 L p .707 .577 .707 r
F P
0 g
s
.64362 .57918 m .64488 .63382 L .65748 .64297 L p .707 .577 .707 r
F P
0 g
s
.83219 .74155 m .83515 .7227 L .81983 .71679 L p .707 .577 .707 r
F P
0 g
s
.65617 .68306 m .65881 .64488 L .64607 .6411 L p .707 .577 .707 r
F P
0 g
s
.64607 .6411 m .64344 .67929 L .65617 .68306 L p .707 .577 .707 r
F P
0 g
s
.64322 .69399 m .64027 .71284 L .65361 .71122 L p .707 .577 .707 r
F P
0 g
s
.65361 .71122 m .65657 .69237 L .64322 .69399 L p .707 .577 .707 r
F P
0 g
s
.64488 .63382 m .64362 .57918 L .64071 .56904 L p .707 .577 .707 r
F P
0 g
s
.83961 .65548 m .83697 .69367 L .84386 .69104 L p .707 .577 .707 r
F P
0 g
s
.84386 .69104 m .84649 .65286 L .83961 .65548 L p .707 .577 .707 r
F P
0 g
s
.84457 .56914 m .84582 .62379 L .84291 .61365 L p .707 .577 .707 r
F P
0 g
s
.84291 .61365 m .84165 .55901 L .84457 .56914 L p .707 .577 .707 r
F P
0 g
s
.83515 .7227 m .83219 .74155 L .83823 .74647 L p .707 .577 .707 r
F P
0 g
s
.64071 .56904 m .64196 .62369 L .64488 .63382 L p .707 .577 .707 r
F P
0 g
s
.83823 .74647 m .84118 .72762 L .83515 .7227 L p .707 .577 .707 r
F P
0 g
s
.64344 .67929 m .64607 .6411 L .64299 .63774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64299 .63774 m .64036 .67592 L .64344 .67929 L p .707 .577 .707 r
F P
0 g
s
.63938 .69743 m .63643 .71628 L .64027 .71284 L p .707 .577 .707 r
F P
0 g
s
.64027 .71284 m .64322 .69399 L .63938 .69743 L p .707 .577 .707 r
F P
0 g
s
.64196 .62369 m .64071 .56904 L .64777 .55891 L p .707 .577 .707 r
F P
0 g
s
.84649 .65286 m .84386 .69104 L .84078 .68768 L p .707 .577 .707 r
F P
0 g
s
.84078 .68768 m .84341 .64949 L .84649 .65286 L p .707 .577 .707 r
F P
0 g
s
.84165 .55901 m .84291 .61365 L .8303 .6045 L p .707 .577 .707 r
F P
0 g
s
.8303 .6045 m .82905 .54986 L .84165 .55901 L p .707 .577 .707 r
F P
0 g
s
.64777 .55891 m .64903 .61355 L .64196 .62369 L p .707 .577 .707 r
F P
0 g
s
.84118 .72762 m .83823 .74647 L .83439 .7499 L p .707 .577 .707 r
F P
0 g
s
.83439 .7499 m .83734 .73105 L .84118 .72762 L p .707 .577 .707 r
F P
0 g
s
.64036 .67592 m .64299 .63774 L .64988 .63511 L p .707 .577 .707 r
F P
0 g
s
.39417 .61971 m .39292 .56507 L .36175 .56345 L p .707 .577 .707 r
F P
0 g
s
.39292 .56507 m .39417 .61971 L .426 .61813 L p .707 .577 .707 r
F P
0 g
s
.426 .61813 m .42474 .56348 L .39292 .56507 L p .707 .577 .707 r
F P
0 g
s
.64988 .63511 m .64724 .6733 L .64036 .67592 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64903 .61355 m .64777 .55891 L .66412 .54977 L p .707 .577 .707 r
F P
0 g
s
.64542 .70234 m .64246 .72119 L .63643 .71628 L p .707 .577 .707 r
F P
0 g
s
.63643 .71628 m .63938 .69743 L .64542 .70234 L p .707 .577 .707 r
F P
0 g
s
.42474 .56348 m .426 .61813 L .45536 .61348 L p .707 .577 .707 r
F P
0 g
s
.45536 .61348 m .45411 .55884 L .42474 .56348 L p .707 .577 .707 r
F P
0 g
s
.363 .61809 m .36175 .56345 L .33429 .55878 L p .707 .577 .707 r
F P
0 g
s
.36175 .56345 m .363 .61809 L .39417 .61971 L p .707 .577 .707 r
F P
0 g
s
.45411 .55884 m .45536 .61348 L .4794 .60624 L p .707 .577 .707 r
F P
0 g
s
.4794 .60624 m .47815 .55159 L .45411 .55884 L p .707 .577 .707 r
F P
0 g
s
.82905 .54986 m .8303 .6045 L .80924 .59724 L p .707 .577 .707 r
F P
0 g
s
.80924 .59724 m .80798 .54259 L .82905 .54986 L p .707 .577 .707 r
F P
0 g
s
.84341 .64949 m .84078 .68768 L .82804 .6839 L p .707 .577 .707 r
F P
0 g
s
.82804 .6839 m .83068 .64572 L .84341 .64949 L p .707 .577 .707 r
F P
0 g
s
.66412 .54977 m .66538 .60442 L .64903 .61355 L p .707 .577 .707 r
F P
0 g
s
.39294 .65635 m .39558 .61817 L .36443 .61536 L p .707 .577 .707 r
F P
0 g
s
.39558 .61817 m .39294 .65635 L .42469 .65822 L p .707 .577 .707 r
F P
0 g
s
.42469 .65822 m .42732 .62003 L .39558 .61817 L p .707 .577 .707 r
F P
0 g
s
.83734 .73105 m .83439 .7499 L .82104 .75152 L p .707 .577 .707 r
F P
0 g
s
.33554 .61342 m .33429 .55878 L .31322 .55151 L p .707 .577 .707 r
F P
0 g
s
.33429 .55878 m .33554 .61342 L .363 .61809 L p .707 .577 .707 r
F P
0 g
s
.82104 .75152 m .824 .73267 L .83734 .73105 L p .707 .577 .707 r
F P
0 g
s
.42732 .62003 m .42469 .65822 L .45392 .65895 L p .707 .577 .707 r
F P
0 g
s
.45392 .65895 m .45656 .62076 L .42732 .62003 L p .707 .577 .707 r
F P
0 g
s
.36443 .61536 m .3618 .65355 L .39294 .65635 L p .707 .577 .707 r
F P
0 g
s
.36272 .6582 m .35977 .67705 L .39077 .68105 L p .707 .577 .707 r
F P
0 g
s
.39077 .68105 m .39373 .6622 L .36272 .6582 L p .707 .577 .707 r
F P
0 g
s
.39373 .6622 m .39077 .68105 L .42213 .68638 L p .707 .577 .707 r
F P
0 g
s
.66538 .60442 m .66412 .54977 L .68816 .54253 L p .707 .577 .707 r
F P
0 g
s
.64724 .6733 m .64988 .63511 L .66604 .63349 L p .707 .577 .707 r
F P
0 g
s
.3618 .65355 m .36443 .61536 L .33694 .61188 L p .707 .577 .707 r
F P
0 g
s
.42213 .68638 m .42508 .66752 L .39373 .6622 L p .707 .577 .707 r
F P
0 g
s
.42508 .66752 m .42213 .68638 L .45076 .6925 L p .707 .577 .707 r
F P
0 g
s
.66604 .63349 m .66341 .67167 L .64724 .6733 L p .707 .577 .707 r
F P
0 g
s
.33694 .61188 m .33431 .65006 L .3618 .65355 L p .707 .577 .707 r
F P
0 g
s
.66074 .70825 m .65778 .7271 L .64246 .72119 L p .707 .577 .707 r
F P
0 g
s
.64246 .72119 m .64542 .70234 L .66074 .70825 L p .707 .577 .707 r
F P
0 g
s
.45076 .6925 m .45371 .67365 L .42508 .66752 L p .707 .577 .707 r
F P
0 g
s
.33509 .65591 m .33214 .67476 L .35977 .67705 L p .707 .577 .707 r
F P
0 g
s
.35977 .67705 m .36272 .6582 L .33509 .65591 L p .707 .577 .707 r
F P
0 g
s
.47815 .55159 m .4794 .60624 L .49575 .5971 L p .707 .577 .707 r
F P
0 g
s
.49575 .5971 m .49449 .54246 L .47815 .55159 L p .707 .577 .707 r
F P
0 g
s
.45656 .62076 m .45392 .65895 L .4778 .65848 L p .707 .577 .707 r
F P
0 g
s
.4778 .65848 m .48043 .62029 L .45656 .62076 L p .707 .577 .707 r
F P
0 g
s
.80798 .54259 m .80924 .59724 L .78177 .59256 L p .707 .577 .707 r
F P
0 g
s
.78177 .59256 m .78052 .53792 L .80798 .54259 L p .707 .577 .707 r
F P
0 g
s
.31322 .55151 m .31447 .60616 L .33554 .61342 L p .707 .577 .707 r
F P
0 g
s
.45371 .67365 m .45076 .6925 L .47386 .69883 L p .707 .577 .707 r
F P
0 g
s
.33431 .65006 m .33694 .61188 L .3158 .60806 L p .707 .577 .707 r
F P
0 g
s
.47386 .69883 m .47682 .67998 L .45371 .67365 L p .707 .577 .707 r
F P
0 g
s
.68816 .54253 m .68941 .59718 L .66538 .60442 L p .707 .577 .707 r
F P
0 g
s
.31447 .60616 m .31322 .55151 L .30061 .54236 L p .707 .577 .707 r
F P
0 g
s
.83068 .64572 m .82804 .6839 L .80689 .68009 L p .707 .577 .707 r
F P
0 g
s
.80689 .68009 m .80953 .6419 L .83068 .64572 L p .707 .577 .707 r
F P
0 g
s
.68941 .59718 m .68816 .54253 L .71752 .53789 L p .707 .577 .707 r
F P
0 g
s
.3158 .60806 m .31316 .64625 L .33431 .65006 L p .707 .577 .707 r
F P
0 g
s
.31356 .65556 m .3106 .67441 L .33214 .67476 L p .707 .577 .707 r
F P
0 g
s
.33214 .67476 m .33509 .65591 L .31356 .65556 L p .707 .577 .707 r
F P
0 g
s
.824 .73267 m .82104 .75152 L .79951 .75117 L p .707 .577 .707 r
F P
0 g
s
.79951 .75117 m .80246 .73232 L .824 .73267 L p .707 .577 .707 r
F P
0 g
s
.78052 .53792 m .78177 .59256 L .7506 .59094 L p .707 .577 .707 r
F P
0 g
s
.7506 .59094 m .74935 .5363 L .78052 .53792 L p .707 .577 .707 r
F P
0 g
s
.66341 .67167 m .66604 .63349 L .68992 .63302 L p .707 .577 .707 r
F P
0 g
s
.71878 .59253 m .71752 .53789 L .74935 .5363 L p .707 .577 .707 r
F P
0 g
s
.71752 .53789 m .71878 .59253 L .68941 .59718 L p .707 .577 .707 r
F P
0 g
s
.68992 .63302 m .68728 .6712 L .66341 .67167 L p .707 .577 .707 r
F P
0 g
s
.48043 .62029 m .4778 .65848 L .49396 .65685 L p .707 .577 .707 r
F P
0 g
s
.49396 .65685 m .4966 .61866 L .48043 .62029 L p .707 .577 .707 r
F P
0 g
s
.68384 .71458 m .68089 .73343 L .65778 .7271 L p .707 .577 .707 r
F P
0 g
s
.65778 .7271 m .66074 .70825 L .68384 .71458 L p .707 .577 .707 r
F P
0 g
s
.49449 .54246 m .49575 .5971 L .50281 .58697 L p .707 .577 .707 r
F P
0 g
s
.50281 .58697 m .50156 .53233 L .49449 .54246 L p .707 .577 .707 r
F P
0 g
s
.74935 .5363 m .7506 .59094 L .71878 .59253 L p .707 .577 .707 r
F P
0 g
s
.47682 .67998 m .47386 .69883 L .48918 .70474 L p .707 .577 .707 r
F P
0 g
s
.30061 .54236 m .30187 .59701 L .31447 .60616 L p .707 .577 .707 r
F P
0 g
s
.48918 .70474 m .49214 .68589 L .47682 .67998 L p .707 .577 .707 r
F P
0 g
s
.31316 .64625 m .3158 .60806 L .30306 .60429 L p .707 .577 .707 r
F P
0 g
s
.80953 .6419 m .80689 .68009 L .7794 .67661 L p .707 .577 .707 r
F P
0 g
s
.7794 .67661 m .78204 .63842 L .80953 .6419 L p .707 .577 .707 r
F P
0 g
s
.30306 .60429 m .30043 .64247 L .31316 .64625 L p .707 .577 .707 r
F P
0 g
s
.30021 .65718 m .29726 .67603 L .3106 .67441 L p .707 .577 .707 r
F P
0 g
s
.3106 .67441 m .31356 .65556 L .30021 .65718 L p .707 .577 .707 r
F P
0 g
s
.30187 .59701 m .30061 .54236 L .2977 .53222 L p .707 .577 .707 r
F P
0 g
s
.80246 .73232 m .79951 .75117 L .77188 .74888 L p .707 .577 .707 r
F P
0 g
s
.68728 .6712 m .68992 .63302 L .71915 .63375 L p .707 .577 .707 r
F P
0 g
s
.77188 .74888 m .77483 .73003 L .80246 .73232 L p .707 .577 .707 r
F P
0 g
s
.71915 .63375 m .71652 .67193 L .68728 .6712 L p .707 .577 .707 r
F P
0 g
s
.71247 .7207 m .70952 .73955 L .68089 .73343 L p .707 .577 .707 r
F P
0 g
s
.68089 .73343 m .68384 .71458 L .71247 .7207 L p .707 .577 .707 r
F P
0 g
s
.78204 .63842 m .7794 .67661 L .74826 .6738 L p .707 .577 .707 r
F P
0 g
s
.74826 .6738 m .7509 .63561 L .78204 .63842 L p .707 .577 .707 r
F P
0 g
s
.4966 .61866 m .49396 .65685 L .50085 .65423 L p .707 .577 .707 r
F P
0 g
s
.50085 .65423 m .50348 .61604 L .4966 .61866 L p .707 .577 .707 r
F P
0 g
s
.71652 .67193 m .71915 .63375 L .7509 .63561 L p .707 .577 .707 r
F P
0 g
s
.50156 .53233 m .50281 .58697 L .4999 .57684 L p .707 .577 .707 r
F P
0 g
s
.4999 .57684 m .49864 .52219 L .50156 .53233 L p .707 .577 .707 r
F P
0 g
s
.77483 .73003 m .77188 .74888 L .74087 .74488 L p .707 .577 .707 r
F P
0 g
s
.49214 .68589 m .48918 .70474 L .49522 .70965 L p .707 .577 .707 r
F P
0 g
s
.2977 .53222 m .29895 .58687 L .30187 .59701 L p .707 .577 .707 r
F P
0 g
s
.7509 .63561 m .74826 .6738 L .71652 .67193 L p .707 .577 .707 r
F P
0 g
s
.74087 .74488 m .74383 .72603 L .77483 .73003 L p .707 .577 .707 r
F P
0 g
s
.74383 .72603 m .74087 .74488 L .70952 .73955 L p .707 .577 .707 r
F P
0 g
s
.70952 .73955 m .71247 .7207 L .74383 .72603 L p .707 .577 .707 r
F P
0 g
s
.49522 .70965 m .49817 .6908 L .49214 .68589 L p .707 .577 .707 r
F P
0 g
s
.30043 .64247 m .30306 .60429 L .29998 .60092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29998 .60092 m .29735 .63911 L .30043 .64247 L p .707 .577 .707 r
F P
0 g
s
.29637 .66061 m .29342 .67946 L .29726 .67603 L p .707 .577 .707 r
F P
0 g
s
.29726 .67603 m .30021 .65718 L .29637 .66061 L p .707 .577 .707 r
F P
0 g
s
.29895 .58687 m .2977 .53222 L .30476 .52209 L p .707 .577 .707 r
F P
0 g
s
.50348 .61604 m .50085 .65423 L .49777 .65086 L p .707 .577 .707 r
F P
0 g
s
.49777 .65086 m .5004 .61268 L .50348 .61604 L p .707 .577 .707 r
F P
0 g
s
.49864 .52219 m .4999 .57684 L .48729 .56769 L p .707 .577 .707 r
F P
0 g
s
.48729 .56769 m .48604 .51304 L .49864 .52219 L p .707 .577 .707 r
F P
0 g
s
.30476 .52209 m .30602 .57674 L .29895 .58687 L p .707 .577 .707 r
F P
0 g
s
.49817 .6908 m .49522 .70965 L .49138 .71309 L p .707 .577 .707 r
F P
0 g
s
.49138 .71309 m .49433 .69424 L .49817 .6908 L p .707 .577 .707 r
F P
0 g
s
.29735 .63911 m .29998 .60092 L .30686 .5983 L p .707 .577 .707 r
F P
0 g
s
.30686 .5983 m .30423 .63649 L .29735 .63911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30602 .57674 m .30476 .52209 L .32111 .51296 L p .707 .577 .707 r
F P
0 g
s
.3024 .66552 m .29945 .68438 L .29342 .67946 L p .707 .577 .707 r
F P
0 g
s
.29342 .67946 m .29637 .66061 L .3024 .66552 L p .707 .577 .707 r
F P
0 g
s
.48604 .51304 m .48729 .56769 L .46622 .56042 L p .707 .577 .707 r
F P
0 g
s
.46622 .56042 m .46497 .50577 L .48604 .51304 L p .707 .577 .707 r
F P
0 g
s
.5004 .61268 m .49777 .65086 L .48503 .64709 L p .707 .577 .707 r
F P
0 g
s
.48503 .64709 m .48767 .6089 L .5004 .61268 L p .707 .577 .707 r
F P
0 g
s
.32111 .51296 m .32236 .5676 L .30602 .57674 L p .707 .577 .707 r
F P
0 g
s
.49433 .69424 m .49138 .71309 L .47803 .71471 L p .707 .577 .707 r
F P
0 g
s
.47803 .71471 m .48099 .69586 L .49433 .69424 L p .707 .577 .707 r
F P
0 g
s
.32236 .5676 m .32111 .51296 L .34515 .50572 L p .707 .577 .707 r
F P
0 g
s
.30423 .63649 m .30686 .5983 L .32303 .59667 L p .707 .577 .707 r
F P
0 g
s
.32303 .59667 m .3204 .63486 L .30423 .63649 L p .707 .577 .707 r
F P
0 g
s
.31772 .67143 m .31477 .69028 L .29945 .68438 L p .707 .577 .707 r
F P
0 g
s
.29945 .68438 m .3024 .66552 L .31772 .67143 L p .707 .577 .707 r
F P
0 g
s
.46497 .50577 m .46622 .56042 L .43876 .55575 L p .707 .577 .707 r
F P
0 g
s
.43876 .55575 m .43751 .5011 L .46497 .50577 L p .707 .577 .707 r
F P
0 g
s
.34515 .50572 m .3464 .56036 L .32236 .5676 L p .707 .577 .707 r
F P
0 g
s
.48767 .6089 m .48503 .64709 L .46388 .64327 L p .707 .577 .707 r
F P
0 g
s
.46388 .64327 m .46652 .60509 L .48767 .6089 L p .707 .577 .707 r
F P
0 g
s
.3464 .56036 m .34515 .50572 L .37451 .50107 L p .707 .577 .707 r
F P
0 g
s
.48099 .69586 m .47803 .71471 L .45649 .71436 L p .707 .577 .707 r
F P
0 g
s
.45649 .71436 m .45945 .69551 L .48099 .69586 L p .707 .577 .707 r
F P
0 g
s
.43751 .5011 m .43876 .55575 L .40759 .55413 L p .707 .577 .707 r
F P
0 g
s
.40759 .55413 m .40634 .49948 L .43751 .5011 L p .707 .577 .707 r
F P
0 g
s
.3204 .63486 m .32303 .59667 L .3469 .5962 L p .707 .577 .707 r
F P
0 g
s
.37577 .55572 m .37451 .50107 L .40634 .49948 L p .707 .577 .707 r
F P
0 g
s
.37451 .50107 m .37577 .55572 L .3464 .56036 L p .707 .577 .707 r
F P
0 g
s
.3469 .5962 m .34427 .63439 L .3204 .63486 L p .707 .577 .707 r
F P
0 g
s
.34083 .67776 m .33788 .69661 L .31477 .69028 L p .707 .577 .707 r
F P
0 g
s
.31477 .69028 m .31772 .67143 L .34083 .67776 L p .707 .577 .707 r
F P
0 g
s
.40634 .49948 m .40759 .55413 L .37577 .55572 L p .707 .577 .707 r
F P
0 g
s
.46652 .60509 m .46388 .64327 L .43639 .63979 L p .707 .577 .707 r
F P
0 g
s
.43639 .63979 m .43903 .6016 L .46652 .60509 L p .707 .577 .707 r
F P
0 g
s
.45945 .69551 m .45649 .71436 L .42887 .71207 L p .707 .577 .707 r
F P
0 g
s
.34427 .63439 m .3469 .5962 L .37614 .59693 L p .707 .577 .707 r
F P
0 g
s
.42887 .71207 m .43182 .69322 L .45945 .69551 L p .707 .577 .707 r
F P
0 g
s
.37614 .59693 m .37351 .63512 L .34427 .63439 L p .707 .577 .707 r
F P
0 g
s
.36946 .68389 m .36651 .70274 L .33788 .69661 L p .707 .577 .707 r
F P
0 g
s
.33788 .69661 m .34083 .67776 L .36946 .68389 L p .707 .577 .707 r
F P
0 g
s
.43903 .6016 m .43639 .63979 L .40525 .63698 L p .707 .577 .707 r
F P
0 g
s
.40525 .63698 m .40789 .59879 L .43903 .6016 L p .707 .577 .707 r
F P
0 g
s
.37351 .63512 m .37614 .59693 L .40789 .59879 L p .707 .577 .707 r
F P
0 g
s
.43182 .69322 m .42887 .71207 L .39786 .70806 L p .707 .577 .707 r
F P
0 g
s
.40789 .59879 m .40525 .63698 L .37351 .63512 L p .707 .577 .707 r
F P
0 g
s
.39786 .70806 m .40082 .68921 L .43182 .69322 L p .707 .577 .707 r
F P
0 g
s
.40082 .68921 m .39786 .70806 L .36651 .70274 L p .707 .577 .707 r
F P
0 g
s
.36651 .70274 m .36946 .68389 L .40082 .68921 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001aOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00JWoo001W
Ool30005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`80009JEP03001JEUYF
009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP0000005`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001QOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000BOolE000nOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000moo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo10001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000c
Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEPT000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH70005FUH00`00FUH000020005FUH0
1000FUIJEUYF100000=JEP000000100015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001D
Ool00`00FUH00004FUH00`00FUH000030004FUHF0006FUH00`00FUIJEP02FUH300000eYF001JEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001DOol00`00FUH00004FUH20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002aoo`00E7oo00<005YF00000UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP8000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000/Ool005Aoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;7oo001DOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000/Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP8002aoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYF
FUH2000/Ool005Eoo`04001JEUYFFUHF00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000AJEP03001JEUYF009JEPH000Uoo`<000]oo`T000=JEP04001JEUYF
FUH2000/Ool0049ooaP00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH0
05YF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YF00000P000UYF2@000goo1@00
00=oo`0000001`000eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P00;7oo000nOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF0P0000=JEP00FUH01UYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;7oo000jOol4
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2@001UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002
FUH2000/Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;7oo000cOol30005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000/Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00009JEQH000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF000090001eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF1P001EYF00<005YFFUH015YF00<005YFFUH01UYF4@000eYF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP04001JEP00
000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT0039oo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH0
05YF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05000_Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo
000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH01EYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH<0005OolD0002FUH01000FUIJEUYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH01P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00@005YFFUH0
00=JEP03001JEUYF00=JEPH000Moo`D000Qoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH80002
FUH00`00FUIJEP04FUHF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000]Ool01000FUIJ
EP000eYF00<005YF00000`000UYF20000goo1@0000=oo`0000001`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00@005YFFUIJEPT000=JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF0003FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP050005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH60009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00@005YF
FUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001J
EP00FUH00002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;7oo000]Ool00`00FUIJEP030005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
00001@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0035YF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002P001UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01P00FUIJEP00FUH000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJ
EP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000030009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP050003FUH7
0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P00;Goo000]
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH600000eYF000000050002FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF0000000]Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF000000050004FUH00`00FUIJEP04FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH0100015YF1P0015YF00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00005P0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool002ioo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH500000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUHG000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH01000FUIJEUYF:`00;Woo000^Ool01000
FUIJEUYF5P0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL004Uoo`00;goo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YF00001`001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEPP00003FUH005YF00AJEP@0009JEP03001JEUYF009JEP@0009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF1000@Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000goo00@005YFFUH000EJEP03
001JEUYF00H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`00?Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03
FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00004FUH00`00FUH0000<0006FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000g
Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH=0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH00004FUH00`00FUIJEP03FUH500000eYF000000050002FUH40005FUH00`00FUIJEP06
FUH01000FUIJEUYF1000<goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJEP04001JEUYFFUH7
00000goo000000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000aOol002eoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0>0006FUH00`00FUIJEP05FUH0
0`00FUIJEP02000_Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH;0005FUH01000FUIJEUYF1000
;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUIJEUYF300000AJEP00FUH002eoo`00;Goo00<005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00;Goo1P001EYF
00<005YFFUH015YF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P001UYF0`000Woo1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000^Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH0
05YF00000eYF20002goo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002io
o`00<7oo100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1P000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00MJEP03001JEUYF00D0011oo`P000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`/0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03
FUH01000FUH000005Woo3`00;goo000^Ool300000eYF001JEP04FUH01000FUIJEUYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03FUH00`00FUIJEP02
001COol002eoo`8000=JEP03001JEUYF009JEP8000IJEP8000=JEPX000=JEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHZ0008FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00001eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo
000]Ool300000eYF001JEP04FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP0I0002FUH00`00FUIJ
EP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000025YF00<005YFFUH00eYF00<005YFFUH0
0P00Dgoo000]Ool200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH6000>Ool01000FUIJEP0015YF10000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF00@005YF000000MJEP03001J
EUYF00AJEP03001JEUYF008005=oo`00;7oo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`05001JEUYF001JEP030007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP02FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00;7oo00<005YF
000015YF00<005YF00003P0015YF0`001UYF00<005YFFUH01EYF00<005YF00000`0017oo00<005YF
FUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF
00<005YFFUH01UYF100015YF00@005YF000000MJEP03001JEUYF00=JEP06001JEUYF001JEP00Dgoo
000/Ool00`00FUH00004FUH00`00FUIJEP02FUH60006Ool80005FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20002Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH2000;FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00@005YF000000MJEP03
001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF
1P000goo20000UYF00<005YFFUH01EYF00<005YFFUH015YF1@0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0000=JEP0000000`0015YF00<005YFFUH00eYF00<005YFFUH00P00E7oo000_Ool20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070003Ool40006FUH00`00FUIJEP04FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH70003FUH00`00
FUIJEP02001DOol0035oo`<000EJEP03001JEUYF00IJEP03001JEUYF00=JEPL000Aoo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF1@0000=JEP000000E7oo000dOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH=0003FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF000000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003Qoo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH?0003FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001DOol003]oo`@0009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001J
EP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF2@00EGoo000oOol70004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002Ool8001NOol004Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005
Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YF00000`00I7oo001>Ool80004FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0027oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00=JEP@0061oo`00EWoo3`00
37oo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF0`00
1EYF00<005YFFUH01UYF00<005YF00000`00G7oo001hOol;0006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3001IOol008=ooaX000AJEPL00003Ool0
000000T000IJEP03001JEUYF00EJEP03001JEP00008005Ioo`00T7oo0P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF2@000goo10000UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00TWoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2`001EYF00<005YF
FUH00UYF00<005YF0000E7oo002GOol50006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF4000E7oo002LOol40002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002POol50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000EGoo002UOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo002YOol70004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00EGoo002`OolG001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59849 .75361 m .59772 .69859 L .56654 .69686 L p .707 .577 .707 r
F P
0 g
s
.59772 .69859 m .59849 .75361 L .63032 .75233 L p .707 .577 .707 r
F P
0 g
s
.63032 .75233 m .62955 .69731 L .59772 .69859 L p .707 .577 .707 r
F P
0 g
s
.62955 .69731 m .63032 .75233 L .6597 .74817 L p .707 .577 .707 r
F P
0 g
s
.6597 .74817 m .65892 .69314 L .62955 .69731 L p .707 .577 .707 r
F P
0 g
s
.56732 .75189 m .56654 .69686 L .53909 .6923 L p .707 .577 .707 r
F P
0 g
s
.56654 .69686 m .56732 .75189 L .59849 .75361 L p .707 .577 .707 r
F P
0 g
s
.65892 .69314 m .6597 .74817 L .68375 .74153 L p .707 .577 .707 r
F P
0 g
s
.68375 .74153 m .68297 .68651 L .65892 .69314 L p .707 .577 .707 r
F P
0 g
s
.5976 .80134 m .59923 .76343 L .56807 .76097 L p .707 .577 .707 r
F P
0 g
s
.59923 .76343 m .5976 .80134 L .6294 .80218 L p .707 .577 .707 r
F P
0 g
s
.6294 .80218 m .63103 .76427 L .59923 .76343 L p .707 .577 .707 r
F P
0 g
s
.53986 .74732 m .53909 .6923 L .51803 .68534 L p .707 .577 .707 r
F P
0 g
s
.53909 .6923 m .53986 .74732 L .56732 .75189 L p .707 .577 .707 r
F P
0 g
s
.63103 .76427 m .6294 .80218 L .65873 .80133 L p .707 .577 .707 r
F P
0 g
s
.65873 .80133 m .66036 .76342 L .63103 .76427 L p .707 .577 .707 r
F P
0 g
s
.56807 .76097 m .56644 .79888 L .5976 .80134 L p .707 .577 .707 r
F P
0 g
s
.56644 .79888 m .56807 .76097 L .5406 .75714 L p .707 .577 .707 r
F P
0 g
s
.59564 .82854 m .5975 .80941 L .56639 .80621 L p .707 .577 .707 r
F P
0 g
s
.5975 .80941 m .59564 .82854 L .62729 .83153 L p .707 .577 .707 r
F P
0 g
s
.62729 .83153 m .62915 .81239 L .5975 .80941 L p .707 .577 .707 r
F P
0 g
s
.56639 .80621 m .56453 .82534 L .59564 .82854 L p .707 .577 .707 r
F P
0 g
s
.62915 .81239 m .62729 .83153 L .65638 .83401 L p .707 .577 .707 r
F P
0 g
s
.65638 .83401 m .65824 .81488 L .62915 .81239 L p .707 .577 .707 r
F P
0 g
s
.68297 .68651 m .68375 .74153 L .70011 .73307 L p .707 .577 .707 r
F P
0 g
s
.70011 .73307 m .69933 .67804 L .68297 .68651 L p .707 .577 .707 r
F P
0 g
s
.5406 .75714 m .53897 .79504 L .56644 .79888 L p .707 .577 .707 r
F P
0 g
s
.56453 .82534 m .56639 .80621 L .53887 .80311 L p .707 .577 .707 r
F P
0 g
s
.53887 .80311 m .53701 .82225 L .56453 .82534 L p .707 .577 .707 r
F P
0 g
s
.66036 .76342 m .65873 .80133 L .68271 .79886 L p .707 .577 .707 r
F P
0 g
s
.68271 .79886 m .68434 .76095 L .66036 .76342 L p .707 .577 .707 r
F P
0 g
s
.51803 .68534 m .5188 .74036 L .53986 .74732 L p .707 .577 .707 r
F P
0 g
s
.53897 .79504 m .5406 .75714 L .51951 .7523 L p .707 .577 .707 r
F P
0 g
s
.5188 .74036 m .51803 .68534 L .50543 .67667 L p .707 .577 .707 r
F P
0 g
s
.65824 .81488 m .65638 .83401 L .68007 .83575 L p .707 .577 .707 r
F P
0 g
s
.68007 .83575 m .68193 .81662 L .65824 .81488 L p .707 .577 .707 r
F P
0 g
s
.51951 .7523 m .51788 .79021 L .53897 .79504 L p .707 .577 .707 r
F P
0 g
s
.53701 .82225 m .53887 .80311 L .51763 .80042 L p .707 .577 .707 r
F P
0 g
s
.51763 .80042 m .51577 .81956 L .53701 .82225 L p .707 .577 .707 r
F P
0 g
s
.68434 .76095 m .68271 .79886 L .699 .79502 L p .707 .577 .707 r
F P
0 g
s
.699 .79502 m .70063 .75712 L .68434 .76095 L p .707 .577 .707 r
F P
0 g
s
.69933 .67804 m .70011 .73307 L .70718 .72361 L p .707 .577 .707 r
F P
0 g
s
.70718 .72361 m .70641 .66858 L .69933 .67804 L p .707 .577 .707 r
F P
0 g
s
.50543 .67667 m .5062 .7317 L .5188 .74036 L p .707 .577 .707 r
F P
0 g
s
.68193 .81662 m .68007 .83575 L .69603 .83657 L p .707 .577 .707 r
F P
0 g
s
.69603 .83657 m .69789 .81744 L .68193 .81662 L p .707 .577 .707 r
F P
0 g
s
.51788 .79021 m .51951 .7523 L .50686 .74695 L p .707 .577 .707 r
F P
0 g
s
.5062 .7317 m .50543 .67667 L .50253 .66714 L p .707 .577 .707 r
F P
0 g
s
.50686 .74695 m .50523 .78485 L .51788 .79021 L p .707 .577 .707 r
F P
0 g
s
.51577 .81956 m .51763 .80042 L .50474 .7984 L p .707 .577 .707 r
F P
0 g
s
.50474 .7984 m .50288 .81754 L .51577 .81956 L p .707 .577 .707 r
F P
0 g
s
.70063 .75712 m .699 .79502 L .70601 .79019 L p .707 .577 .707 r
F P
0 g
s
.70601 .79019 m .70764 .75228 L .70063 .75712 L p .707 .577 .707 r
F P
0 g
s
.70641 .66858 m .70718 .72361 L .70428 .71408 L p .707 .577 .707 r
F P
0 g
s
.70428 .71408 m .7035 .65905 L .70641 .66858 L p .707 .577 .707 r
F P
0 g
s
.50253 .66714 m .5033 .72216 L .5062 .7317 L p .707 .577 .707 r
F P
0 g
s
.69789 .81744 m .69603 .83657 L .70271 .8364 L p .707 .577 .707 r
F P
0 g
s
.70271 .8364 m .70457 .81726 L .69789 .81744 L p .707 .577 .707 r
F P
0 g
s
.50523 .78485 m .50686 .74695 L .5039 .74159 L p .707 .577 .707 r
F P
0 g
s
.48631 .81979 m .49313 .31364 L .44912 .31072 L p .707 .577 .707 r
F P
0 g
s
.5039 .74159 m .50226 .77949 L .50523 .78485 L p .707 .577 .707 r
F P
0 g
s
.5033 .72216 m .50253 .66714 L .5096 .65768 L p .707 .577 .707 r
F P
0 g
s
.50288 .81754 m .50474 .7984 L .50148 .79725 L p .707 .577 .707 r
F P
0 g
s
.50148 .79725 m .49962 .81638 L .50288 .81754 L p .707 .577 .707 r
F P
0 g
s
.5096 .65768 m .51038 .7127 L .5033 .72216 L p .707 .577 .707 r
F P
0 g
s
.50226 .77949 m .5039 .74159 L .5109 .73675 L p .707 .577 .707 r
F P
0 g
s
.51038 .7127 m .5096 .65768 L .52596 .64922 L p .707 .577 .707 r
F P
0 g
s
.5109 .73675 m .50927 .77466 L .50226 .77949 L p .707 .577 .707 r
F P
0 g
s
.49962 .81638 m .50148 .79725 L .50816 .79707 L p .707 .577 .707 r
F P
0 g
s
.50816 .79707 m .5063 .81621 L .49962 .81638 L p .707 .577 .707 r
F P
0 g
s
.52596 .64922 m .52674 .70424 L .51038 .7127 L p .707 .577 .707 r
F P
0 g
s
.50927 .77466 m .5109 .73675 L .5272 .73291 L p .707 .577 .707 r
F P
0 g
s
.5272 .73291 m .52556 .77082 L .50927 .77466 L p .707 .577 .707 r
F P
0 g
s
.5063 .81621 m .50816 .79707 L .52413 .7979 L p .707 .577 .707 r
F P
0 g
s
.52413 .7979 m .52227 .81703 L .5063 .81621 L p .707 .577 .707 r
F P
0 g
s
.52556 .77082 m .5272 .73291 L .55118 .73045 L p .707 .577 .707 r
F P
0 g
s
.55118 .73045 m .54955 .76835 L .52556 .77082 L p .707 .577 .707 r
F P
0 g
s
.52227 .81703 m .52413 .7979 L .54781 .79964 L p .707 .577 .707 r
F P
0 g
s
.54781 .79964 m .54595 .81877 L .52227 .81703 L p .707 .577 .707 r
F P
0 g
s
.49313 .31364 m .48631 .81979 L .53125 .81939 L p .707 .577 .707 r
F P
0 g
s
.52674 .70424 m .52596 .64922 L .55001 .64258 L p .707 .577 .707 r
F P
0 g
s
.55001 .64258 m .55078 .6976 L .52674 .70424 L p .707 .577 .707 r
F P
0 g
s
.53125 .81939 m .53807 .31324 L .49313 .31364 L p .707 .577 .707 r
F P
0 g
s
.55078 .6976 m .55001 .64258 L .57938 .63841 L p .707 .577 .707 r
F P
0 g
s
.57938 .63841 m .58016 .69344 L .55078 .6976 L p .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55118 .73045 L .55665 .73029 L p .707 .577 .707 r
F P
0 g
s
.55665 .73029 m .58051 .72959 L p .55124 .76624 L .707 .577 .707 r
F P
0 g
s
.54955 .76835 m .55665 .73029 L .55124 .76624 L .707 .577 .707 r
F
.58016 .69344 m .57938 .63841 L .61122 .63713 L p F P
0 g
s
.61122 .63713 m .61199 .69216 L .58016 .69344 L p .707 .577 .707 r
F P
0 g
s
.58051 .72959 m .57887 .7675 L .54955 .76835 L p .707 .577 .707 r
F P
0 g
s
.54595 .81877 m .54781 .79964 L .57691 .80212 L p .707 .577 .707 r
F P
0 g
s
.57691 .80212 m .57505 .82126 L .54595 .81877 L p .707 .577 .707 r
F P
0 g
s
.57887 .7675 m .58051 .72959 L .61231 .73044 L p .707 .577 .707 r
F P
0 g
s
.61231 .73044 m .61067 .76835 L .57887 .7675 L p .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .57691 .80212 L .58257 .80265 L p .707 .577 .707 r
F P
0 g
s
.58257 .80265 m .60856 .80511 L p .5803 .81873 L .707 .577 .707 r
F P
0 g
s
.57505 .82126 m .58257 .80265 L .5803 .81873 L .707 .577 .707 r
F
.64239 .63886 m .64316 .69389 L .61199 .69216 L p F P
0 g
s
.61199 .69216 m .61122 .63713 L .64239 .63886 L p .707 .577 .707 r
F P
0 g
s
.64347 .7329 m .64183 .7708 L .61067 .76835 L p .707 .577 .707 r
F P
0 g
s
.61067 .76835 m .61231 .73044 L .64347 .7329 L p .707 .577 .707 r
F P
0 g
s
.6067 .82424 m .60856 .80511 L .63967 .80831 L p .707 .577 .707 r
F P
0 g
s
.60856 .80511 m .6067 .82424 L .57505 .82126 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .62977 .80022 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.61349 .30296 m .60931 .61321 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.60931 .61321 m .60667 .80911 L p .62095 .53078 L .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .60667 .80911 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57954 .30956 m .57557 .60473 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.57557 .60473 m .57273 .81571 L p .59027 .50712 L .707 .577 .707 r
F P
0 g
s
.53807 .31324 m .53125 .81939 L .57273 .81571 L p .707 .577 .707 r
F P
0 g
s
.57273 .81571 m .57954 .30956 L .53807 .31324 L p .707 .577 .707 r
F P
0 g
s
.44231 .81687 m .44912 .31072 L .41036 .30476 L p .707 .577 .707 r
F P
0 g
s
.44912 .31072 m .44231 .81687 L .48631 .81979 L p .707 .577 .707 r
F P
0 g
s
.70764 .75228 m .70601 .79019 L .70304 .78483 L p .707 .577 .707 r
F P
0 g
s
.70304 .78483 m .70468 .74692 L .70764 .75228 L p .707 .577 .707 r
F P
0 g
s
.7035 .65905 m .70428 .71408 L .69168 .70541 L p .707 .577 .707 r
F P
0 g
s
.69168 .70541 m .69091 .65038 L .7035 .65905 L p .707 .577 .707 r
F P
0 g
s
.60667 .80911 m .61349 .30296 L .57954 .30956 L p .707 .577 .707 r
F P
0 g
s
.70457 .81726 m .70271 .8364 L .69945 .83525 L p .707 .577 .707 r
F P
0 g
s
.69945 .83525 m .70131 .81611 L .70457 .81726 L p .707 .577 .707 r
F P
0 g
s
.25548 .7168 m .25471 .66177 L .22354 .66005 L p .707 .577 .707 r
F P
0 g
s
.25471 .66177 m .25548 .7168 L .28731 .71552 L p .707 .577 .707 r
F P
0 g
s
.28731 .71552 m .28654 .66049 L .25471 .66177 L p .707 .577 .707 r
F P
0 g
s
.40354 .81091 m .41036 .30476 L .38063 .29635 L p .707 .577 .707 r
F P
0 g
s
.41036 .30476 m .40354 .81091 L .44231 .81687 L p .707 .577 .707 r
F P
0 g
s
.28654 .66049 m .28731 .71552 L .31669 .71135 L p .707 .577 .707 r
F P
0 g
s
.31669 .71135 m .31592 .65633 L .28654 .66049 L p .707 .577 .707 r
F P
0 g
s
.22431 .71507 m .22354 .66005 L .19608 .65548 L p .707 .577 .707 r
F P
0 g
s
.22354 .66005 m .22431 .71507 L .25548 .7168 L p .707 .577 .707 r
F P
0 g
s
.31592 .65633 m .31669 .71135 L .34074 .70472 L p .707 .577 .707 r
F P
0 g
s
.34074 .70472 m .33996 .64969 L .31592 .65633 L p .707 .577 .707 r
F P
0 g
s
.70468 .74692 m .70304 .78483 L .69039 .77947 L p .707 .577 .707 r
F P
0 g
s
.69039 .77947 m .69203 .74156 L .70468 .74692 L p .707 .577 .707 r
F P
0 g
s
.69091 .65038 m .69168 .70541 L .67062 .69845 L p .707 .577 .707 r
F P
0 g
s
.67062 .69845 m .66985 .64343 L .69091 .65038 L p .707 .577 .707 r
F P
0 g
s
.62977 .80022 m .63659 .29407 L .61349 .30296 L p .707 .577 .707 r
F P
0 g
s
.25459 .76452 m .25622 .72661 L .22506 .72415 L p .707 .577 .707 r
F P
0 g
s
.25622 .72661 m .25459 .76452 L .28639 .76537 L p .707 .577 .707 r
F P
0 g
s
.28639 .76537 m .28802 .72746 L .25622 .72661 L p .707 .577 .707 r
F P
0 g
s
.19685 .71051 m .19608 .65548 L .17502 .64852 L p .707 .577 .707 r
F P
0 g
s
.19608 .65548 m .19685 .71051 L .22431 .71507 L p .707 .577 .707 r
F P
0 g
s
.28802 .72746 m .28639 .76537 L .31572 .76451 L p .707 .577 .707 r
F P
0 g
s
.31572 .76451 m .31735 .72661 L .28802 .72746 L p .707 .577 .707 r
F P
0 g
s
.70131 .81611 m .69945 .83525 L .68657 .83323 L p .707 .577 .707 r
F P
0 g
s
.68657 .83323 m .68843 .81409 L .70131 .81611 L p .707 .577 .707 r
F P
0 g
s
.22506 .72415 m .22343 .76206 L .25459 .76452 L p .707 .577 .707 r
F P
0 g
s
.22343 .76206 m .22506 .72415 L .19759 .72032 L p .707 .577 .707 r
F P
0 g
s
.25263 .79173 m .25449 .77259 L .22338 .76939 L p .707 .577 .707 r
F P
0 g
s
.25449 .77259 m .25263 .79173 L .28428 .79471 L p .707 .577 .707 r
F P
0 g
s
.28428 .79471 m .28614 .77558 L .25449 .77259 L p .707 .577 .707 r
F P
0 g
s
.22338 .76939 m .22152 .78853 L .25263 .79173 L p .707 .577 .707 r
F P
0 g
s
.28614 .77558 m .28428 .79471 L .31337 .7972 L p .707 .577 .707 r
F P
0 g
s
.31337 .7972 m .31523 .77806 L .28614 .77558 L p .707 .577 .707 r
F P
0 g
s
.37381 .8025 m .38063 .29635 L .36284 .2863 L p .707 .577 .707 r
F P
0 g
s
.38063 .29635 m .37381 .8025 L .40354 .81091 L p .707 .577 .707 r
F P
0 g
s
.33996 .64969 m .34074 .70472 L .3571 .69625 L p .707 .577 .707 r
F P
0 g
s
.3571 .69625 m .35632 .64123 L .33996 .64969 L p .707 .577 .707 r
F P
0 g
s
.19759 .72032 m .19596 .75823 L .22343 .76206 L p .707 .577 .707 r
F P
0 g
s
.22152 .78853 m .22338 .76939 L .19586 .7663 L p .707 .577 .707 r
F P
0 g
s
.19586 .7663 m .194 .78543 L .22152 .78853 L p .707 .577 .707 r
F P
0 g
s
.31735 .72661 m .31572 .76451 L .3397 .76205 L p .707 .577 .707 r
F P
0 g
s
.3397 .76205 m .34133 .72414 L .31735 .72661 L p .707 .577 .707 r
F P
0 g
s
.66985 .64343 m .67062 .69845 L .64316 .69389 L p .707 .577 .707 r
F P
0 g
s
.64316 .69389 m .64239 .63886 L .66985 .64343 L p .707 .577 .707 r
F P
0 g
s
.17502 .64852 m .17579 .70355 L .19685 .71051 L p .707 .577 .707 r
F P
0 g
s
.19596 .75823 m .19759 .72032 L .1765 .71549 L p .707 .577 .707 r
F P
0 g
s
.69203 .74156 m .69039 .77947 L .6693 .77464 L p .707 .577 .707 r
F P
0 g
s
.6693 .77464 m .67094 .73673 L .69203 .74156 L p .707 .577 .707 r
F P
0 g
s
.17579 .70355 m .17502 .64852 L .16242 .63985 L p .707 .577 .707 r
F P
0 g
s
.31523 .77806 m .31337 .7972 L .33706 .79894 L p .707 .577 .707 r
F P
0 g
s
.33706 .79894 m .33892 .7798 L .31523 .77806 L p .707 .577 .707 r
F P
0 g
s
.1765 .71549 m .17487 .7534 L .19596 .75823 L p .707 .577 .707 r
F P
0 g
s
.194 .78543 m .19586 .7663 L .17462 .76361 L p .707 .577 .707 r
F P
0 g
s
.17462 .76361 m .17276 .78274 L .194 .78543 L p .707 .577 .707 r
F P
0 g
s
.68843 .81409 m .68657 .83323 L .66533 .83054 L p .707 .577 .707 r
F P
0 g
s
.66533 .83054 m .66719 .8114 L .68843 .81409 L p .707 .577 .707 r
F P
0 g
s
.63659 .29407 m .62977 .80022 L .63976 .78993 L p .707 .577 .707 r
F P
0 g
s
.63976 .78993 m .64658 .28379 L .63659 .29407 L p .707 .577 .707 r
F P
0 g
s
.34133 .72414 m .3397 .76205 L .35599 .75821 L p .707 .577 .707 r
F P
0 g
s
.35599 .75821 m .35763 .7203 L .34133 .72414 L p .707 .577 .707 r
F P
0 g
s
.35632 .64123 m .3571 .69625 L .36417 .68679 L p .707 .577 .707 r
F P
0 g
s
.36417 .68679 m .3634 .63177 L .35632 .64123 L p .707 .577 .707 r
F P
0 g
s
.16242 .63985 m .16319 .69488 L .17579 .70355 L p .707 .577 .707 r
F P
0 g
s
.33892 .7798 m .33706 .79894 L .35302 .79976 L p .707 .577 .707 r
F P
0 g
s
.35302 .79976 m .35488 .78062 L .33892 .7798 L p .707 .577 .707 r
F P
0 g
s
.17487 .7534 m .1765 .71549 L .16385 .71013 L p .707 .577 .707 r
F P
0 g
s
.67094 .73673 m .6693 .77464 L .64183 .7708 L p .707 .577 .707 r
F P
0 g
s
.64183 .7708 m .64347 .7329 L .67094 .73673 L p .707 .577 .707 r
F P
0 g
s
.16319 .69488 m .16242 .63985 L .15952 .63032 L p .707 .577 .707 r
F P
0 g
s
.35763 .7203 m .35599 .75821 L .363 .75337 L p .707 .577 .707 r
F P
0 g
s
.35488 .78062 m .35302 .79976 L .3597 .79959 L p .707 .577 .707 r
F P
0 g
s
.3597 .79959 m .36156 .78045 L .35488 .78062 L p .707 .577 .707 r
F P
0 g
s
.3605 .62224 m .36127 .67726 L .34867 .66859 L p .707 .577 .707 r
F P
0 g
s
.34867 .66859 m .3479 .61357 L .3605 .62224 L p .707 .577 .707 r
F P
0 g
s
.363 .75337 m .36463 .71546 L .35763 .7203 L p .707 .577 .707 r
F P
0 g
s
.36167 .71011 m .36003 .74801 L .35944 .74776 L p .707 .577 .707 r
F P
0 g
s
.35944 .74776 m .34739 .74266 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.35933 .71544 m .36167 .71011 L .35944 .74776 L .707 .577 .707 r
F
.36284 .2863 m .35874 .27561 L p .35818 .38242 L F P
0 g
s
.34739 .74266 m .34902 .70475 L .35931 .70911 L p .707 .577 .707 r
F P
0 g
s
.35931 .70911 m .36167 .71011 L p .35933 .71544 L .707 .577 .707 r
F P
0 g
s
.34739 .74266 m .35931 .70911 L .35933 .71544 L .707 .577 .707 r
F
.3583 .7793 m .35644 .79843 L .34356 .79641 L p F P
0 g
s
.34356 .79641 m .34542 .77728 L .3583 .7793 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35603 .79245 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35874 .27561 m .358 .33057 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.358 .33057 m .35193 .78176 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35603 .79245 m .35887 .58147 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.35887 .58147 m .36284 .2863 L p .35818 .38242 L .707 .577 .707 r
F P
0 g
s
.3634 .63177 m .36417 .68679 L .36127 .67726 L p .707 .577 .707 r
F P
0 g
s
.36127 .67726 m .3605 .62224 L .3634 .63177 L p .707 .577 .707 r
F P
0 g
s
.36463 .71546 m .363 .75337 L .36003 .74801 L p .707 .577 .707 r
F P
0 g
s
.36003 .74801 m .36167 .71011 L .36463 .71546 L p .707 .577 .707 r
F P
0 g
s
.36156 .78045 m .3597 .79959 L .35644 .79843 L p .707 .577 .707 r
F P
0 g
s
.35644 .79843 m .3583 .7793 L .36156 .78045 L p .707 .577 .707 r
F P
0 g
s
.36284 .2863 m .35603 .79245 L .37381 .8025 L p .707 .577 .707 r
F P
0 g
s
.16385 .71013 m .16222 .74804 L .17487 .7534 L p .707 .577 .707 r
F P
0 g
s
.17276 .78274 m .17462 .76361 L .16173 .76159 L p .707 .577 .707 r
F P
0 g
s
.16173 .76159 m .15988 .78072 L .17276 .78274 L p .707 .577 .707 r
F P
0 g
s
.66719 .8114 m .66533 .83054 L .63781 .82744 L p .707 .577 .707 r
F P
0 g
s
.63781 .82744 m .63967 .80831 L .66719 .8114 L p .707 .577 .707 r
F P
0 g
s
.15952 .63032 m .16029 .68535 L .16319 .69488 L p .707 .577 .707 r
F P
0 g
s
.63967 .80831 m .63781 .82744 L .6067 .82424 L p .707 .577 .707 r
F P
0 g
s
.16222 .74804 m .16385 .71013 L .16089 .70477 L p .707 .577 .707 r
F P
0 g
s
.64658 .28379 m .63976 .78993 L .63566 .77925 L p .707 .577 .707 r
F P
0 g
s
.63566 .77925 m .64248 .2731 L .64658 .28379 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16089 .70477 m .15925 .74268 L .16222 .74804 L p .707 .577 .707 r
F P
0 g
s
.16029 .68535 m .15952 .63032 L .16659 .62086 L p .707 .577 .707 r
F P
0 g
s
.15988 .78072 m .16173 .76159 L .15847 .76043 L p .707 .577 .707 r
F P
0 g
s
.15847 .76043 m .15661 .77957 L .15988 .78072 L p .707 .577 .707 r
F P
0 g
s
.35193 .78176 m .35874 .27561 L .36873 .26532 L p .707 .577 .707 r
F P
0 g
s
.16659 .62086 m .16737 .67589 L .16029 .68535 L p .707 .577 .707 r
F P
0 g
s
.15925 .74268 m .16089 .70477 L .16789 .69994 L p .707 .577 .707 r
F P
0 g
s
.16737 .67589 m .16659 .62086 L .18295 .6124 L p .707 .577 .707 r
F P
0 g
s
.16789 .69994 m .16626 .73784 L .15925 .74268 L p .707 .577 .707 r
F P
0 g
s
.15661 .77957 m .15847 .76043 L .16515 .76026 L p .707 .577 .707 r
F P
0 g
s
.16515 .76026 m .16329 .7794 L .15661 .77957 L p .707 .577 .707 r
F P
0 g
s
.64248 .2731 m .63566 .77925 L .61788 .7692 L p .707 .577 .707 r
F P
0 g
s
.61788 .7692 m .62469 .26305 L .64248 .2731 L p .707 .577 .707 r
F P
0 g
s
.3479 .61357 m .34867 .66859 L .32761 .66164 L p .707 .577 .707 r
F P
0 g
s
.32761 .66164 m .32684 .60661 L .3479 .61357 L p .707 .577 .707 r
F P
0 g
s
.18295 .6124 m .18373 .66743 L .16737 .67589 L p .707 .577 .707 r
F P
0 g
s
.16626 .73784 m .16789 .69994 L .18419 .6961 L p .707 .577 .707 r
F P
0 g
s
.18373 .66743 m .18295 .6124 L .207 .60576 L p .707 .577 .707 r
F P
0 g
s
.36192 .77147 m .36873 .26532 L .39183 .25644 L p .707 .577 .707 r
F P
0 g
s
.36873 .26532 m .36192 .77147 L .35193 .78176 L p .707 .577 .707 r
F P
0 g
s
.18419 .6961 m .18255 .734 L .16626 .73784 L p .707 .577 .707 r
F P
0 g
s
.16329 .7794 m .16515 .76026 L .18112 .76108 L p .707 .577 .707 r
F P
0 g
s
.18112 .76108 m .17926 .78022 L .16329 .7794 L p .707 .577 .707 r
F P
0 g
s
.32684 .60661 m .32761 .66164 L .30015 .65707 L p .707 .577 .707 r
F P
0 g
s
.30015 .65707 m .29938 .60205 L .32684 .60661 L p .707 .577 .707 r
F P
0 g
s
.34902 .70475 m .34739 .74266 L .32629 .73782 L p .707 .577 .707 r
F P
0 g
s
.32629 .73782 m .32793 .69992 L .34902 .70475 L p .707 .577 .707 r
F P
0 g
s
.207 .60576 m .20777 .66079 L .18373 .66743 L p .707 .577 .707 r
F P
0 g
s
.20777 .66079 m .207 .60576 L .23638 .6016 L p .707 .577 .707 r
F P
0 g
s
.62469 .26305 m .61788 .7692 L .58815 .76079 L p .707 .577 .707 r
F P
0 g
s
.58815 .76079 m .59496 .25464 L .62469 .26305 L p .707 .577 .707 r
F P
0 g
s
.18255 .734 m .18419 .6961 L .20817 .69363 L p .707 .577 .707 r
F P
0 g
s
.29938 .60205 m .30015 .65707 L .26898 .65534 L p .707 .577 .707 r
F P
0 g
s
.26898 .65534 m .26821 .60032 L .29938 .60205 L p .707 .577 .707 r
F P
0 g
s
.34542 .77728 m .34356 .79641 L .32232 .79372 L p .707 .577 .707 r
F P
0 g
s
.32232 .79372 m .32418 .77459 L .34542 .77728 L p .707 .577 .707 r
F P
0 g
s
.23715 .65662 m .23638 .6016 L .26821 .60032 L p .707 .577 .707 r
F P
0 g
s
.23638 .6016 m .23715 .65662 L .20777 .66079 L p .707 .577 .707 r
F P
0 g
s
.20817 .69363 m .20654 .73154 L .18255 .734 L p .707 .577 .707 r
F P
0 g
s
.26821 .60032 m .26898 .65534 L .23715 .65662 L p .707 .577 .707 r
F P
0 g
s
.17926 .78022 m .18112 .76108 L .2048 .76282 L p .707 .577 .707 r
F P
0 g
s
.7357 .65691 m .73492 .60188 L .70375 .60015 L p .707 .577 .707 r
F P
0 g
s
.73492 .60188 m .7357 .65691 L .76753 .65563 L p .707 .577 .707 r
F P
0 g
s
.76753 .65563 m .76675 .6006 L .73492 .60188 L p .707 .577 .707 r
F P
0 g
s
.2048 .76282 m .20295 .78196 L .17926 .78022 L p .707 .577 .707 r
F P
0 g
s
.39183 .25644 m .38502 .76259 L .36192 .77147 L p .707 .577 .707 r
F P
0 g
s
.38502 .76259 m .39183 .25644 L .42578 .24984 L p .707 .577 .707 r
F P
0 g
s
.76675 .6006 m .76753 .65563 L .7969 .65146 L p .707 .577 .707 r
F P
0 g
s
.7969 .65146 m .79613 .59644 L .76675 .6006 L p .707 .577 .707 r
F P
0 g
s
.32793 .69992 m .32629 .73782 L .29882 .73399 L p .707 .577 .707 r
F P
0 g
s
.29882 .73399 m .30046 .69608 L .32793 .69992 L p .707 .577 .707 r
F P
0 g
s
.70452 .65518 m .70375 .60015 L .67629 .59559 L p .707 .577 .707 r
F P
0 g
s
.70375 .60015 m .70452 .65518 L .7357 .65691 L p .707 .577 .707 r
F P
0 g
s
.20654 .73154 m .20817 .69363 L .2375 .69278 L p .707 .577 .707 r
F P
0 g
s
.79613 .59644 m .7969 .65146 L .82095 .64482 L p .707 .577 .707 r
F P
0 g
s
.82095 .64482 m .82018 .5898 L .79613 .59644 L p .707 .577 .707 r
F P
0 g
s
.32418 .77459 m .32232 .79372 L .2948 .79063 L p .707 .577 .707 r
F P
0 g
s
.2948 .79063 m .29666 .77149 L .32418 .77459 L p .707 .577 .707 r
F P
0 g
s
.2375 .69278 m .23586 .73069 L .20654 .73154 L p .707 .577 .707 r
F P
0 g
s
.30046 .69608 m .29882 .73399 L .26766 .73153 L p .707 .577 .707 r
F P
0 g
s
.26766 .73153 m .2693 .69362 L .30046 .69608 L p .707 .577 .707 r
F P
0 g
s
.59496 .25464 m .58815 .76079 L .54938 .75483 L p .707 .577 .707 r
F P
0 g
s
.54938 .75483 m .5562 .24868 L .59496 .25464 L p .707 .577 .707 r
F P
0 g
s
.20295 .78196 m .2048 .76282 L .2339 .76531 L p .707 .577 .707 r
F P
0 g
s
.7348 .70272 m .73644 .66481 L .70528 .66236 L p .707 .577 .707 r
F P
0 g
s
.73644 .66481 m .7348 .70272 L .7666 .70357 L p .707 .577 .707 r
F P
0 g
s
.7666 .70357 m .76824 .66566 L .73644 .66481 L p .707 .577 .707 r
F P
0 g
s
.2339 .76531 m .23204 .78444 L .20295 .78196 L p .707 .577 .707 r
F P
0 g
s
.67707 .65061 m .67629 .59559 L .65523 .58863 L p .707 .577 .707 r
F P
0 g
s
.67629 .59559 m .67707 .65061 L .70452 .65518 L p .707 .577 .707 r
F P
0 g
s
.23586 .73069 m .2375 .69278 L .2693 .69362 L p .707 .577 .707 r
F P
0 g
s
.76824 .66566 m .7666 .70357 L .79593 .70271 L p .707 .577 .707 r
F P
0 g
s
.79593 .70271 m .79756 .66481 L .76824 .66566 L p .707 .577 .707 r
F P
0 g
s
.2693 .69362 m .26766 .73153 L .23586 .73069 L p .707 .577 .707 r
F P
0 g
s
.70528 .66236 m .70364 .70026 L .7348 .70272 L p .707 .577 .707 r
F P
0 g
s
.70364 .70026 m .70528 .66236 L .67781 .65852 L p .707 .577 .707 r
F P
0 g
s
.41896 .75599 m .42578 .24984 L .46725 .24615 L p .707 .577 .707 r
F P
0 g
s
.42578 .24984 m .41896 .75599 L .38502 .76259 L p .707 .577 .707 r
F P
0 g
s
.29666 .77149 m .2948 .79063 L .26369 .78743 L p .707 .577 .707 r
F P
0 g
s
.26369 .78743 m .26555 .76829 L .29666 .77149 L p .707 .577 .707 r
F P
0 g
s
.73284 .73408 m .7347 .71494 L .70359 .71175 L p .707 .577 .707 r
F P
0 g
s
.7347 .71494 m .73284 .73408 L .76449 .73707 L p .707 .577 .707 r
F P
0 g
s
.76449 .73707 m .76635 .71793 L .7347 .71494 L p .707 .577 .707 r
F P
0 g
s
.70359 .71175 m .70173 .73088 L .73284 .73408 L p .707 .577 .707 r
F P
0 g
s
.23204 .78444 m .2339 .76531 L .26555 .76829 L p .707 .577 .707 r
F P
0 g
s
.76635 .71793 m .76449 .73707 L .79358 .73955 L p .707 .577 .707 r
F P
0 g
s
.79358 .73955 m .79544 .72042 L .76635 .71793 L p .707 .577 .707 r
F P
0 g
s
.67781 .65852 m .67617 .69643 L .70364 .70026 L p .707 .577 .707 r
F P
0 g
s
.26555 .76829 m .26369 .78743 L .23204 .78444 L p .707 .577 .707 r
F P
0 g
s
.82018 .5898 m .82095 .64482 L .83731 .63636 L p .707 .577 .707 r
F P
0 g
s
.83731 .63636 m .83654 .58134 L .82018 .5898 L p .707 .577 .707 r
F P
0 g
s
.79756 .66481 m .79593 .70271 L .81991 .70025 L p .707 .577 .707 r
F P
0 g
s
.81991 .70025 m .82155 .66234 L .79756 .66481 L p .707 .577 .707 r
F P
0 g
s
.70173 .73088 m .70359 .71175 L .67607 .70865 L p .707 .577 .707 r
F P
0 g
s
.67607 .70865 m .67421 .72779 L .70173 .73088 L p .707 .577 .707 r
F P
0 g
s
.65523 .58863 m .65601 .64366 L .67707 .65061 L p .707 .577 .707 r
F P
0 g
s
.5562 .24868 m .54938 .75483 L .50538 .75191 L p .707 .577 .707 r
F P
0 g
s
.50538 .75191 m .51219 .24576 L .5562 .24868 L p .707 .577 .707 r
F P
0 g
s
.67617 .69643 m .67781 .65852 L .65671 .65369 L p .707 .577 .707 r
F P
0 g
s
.65601 .64366 m .65523 .58863 L .64263 .57996 L p .707 .577 .707 r
F P
0 g
s
.79544 .72042 m .79358 .73955 L .81727 .74129 L p .707 .577 .707 r
F P
0 g
s
.81727 .74129 m .81913 .72215 L .79544 .72042 L p .707 .577 .707 r
F P
0 g
s
.46044 .7523 m .46725 .24615 L .51219 .24576 L p .707 .577 .707 r
F P
0 g
s
.46725 .24615 m .46044 .7523 L .41896 .75599 L p .707 .577 .707 r
F P
0 g
s
.65671 .65369 m .65508 .6916 L .67617 .69643 L p .707 .577 .707 r
F P
0 g
s
.51219 .24576 m .50538 .75191 L .46044 .7523 L p .707 .577 .707 r
F P
0 g
s
.67421 .72779 m .67607 .70865 L .65483 .70596 L p .707 .577 .707 r
F P
0 g
s
.65483 .70596 m .65297 .7251 L .67421 .72779 L p .707 .577 .707 r
F P
0 g
s
.82155 .66234 m .81991 .70025 L .83621 .69641 L p .707 .577 .707 r
F P
0 g
s
.83621 .69641 m .83784 .6585 L .82155 .66234 L p .707 .577 .707 r
F P
0 g
s
.83654 .58134 m .83731 .63636 L .84439 .6269 L p .707 .577 .707 r
F P
0 g
s
.84439 .6269 m .84361 .57188 L .83654 .58134 L p .707 .577 .707 r
F P
0 g
s
.64263 .57996 m .64341 .63499 L .65601 .64366 L p .707 .577 .707 r
F P
0 g
s
.65508 .6916 m .65671 .65369 L .64407 .64833 L p .707 .577 .707 r
F P
0 g
s
.81913 .72215 m .81727 .74129 L .83324 .74211 L p .707 .577 .707 r
F P
0 g
s
.83324 .74211 m .8351 .72298 L .81913 .72215 L p .707 .577 .707 r
F P
0 g
s
.64341 .63499 m .64263 .57996 L .63973 .57043 L p .707 .577 .707 r
F P
0 g
s
.64407 .64833 m .64243 .68624 L .65508 .6916 L p .707 .577 .707 r
F P
0 g
s
.65297 .7251 m .65483 .70596 L .64195 .70394 L p .707 .577 .707 r
F P
0 g
s
.64195 .70394 m .64009 .72308 L .65297 .7251 L p .707 .577 .707 r
F P
0 g
s
.83784 .6585 m .83621 .69641 L .84321 .69157 L p .707 .577 .707 r
F P
0 g
s
.84321 .69157 m .84485 .65367 L .83784 .6585 L p .707 .577 .707 r
F P
0 g
s
.84361 .57188 m .84439 .6269 L .84148 .61737 L p .707 .577 .707 r
F P
0 g
s
.84148 .61737 m .84071 .56234 L .84361 .57188 L p .707 .577 .707 r
F P
0 g
s
.63973 .57043 m .6405 .62546 L .64341 .63499 L p .707 .577 .707 r
F P
0 g
s
.8351 .72298 m .83324 .74211 L .83992 .74194 L p .707 .577 .707 r
F P
0 g
s
.83992 .74194 m .84178 .7228 L .8351 .72298 L p .707 .577 .707 r
F P
0 g
s
.64243 .68624 m .64407 .64833 L .6411 .64297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6411 .64297 m .63947 .68088 L .64243 .68624 L p .707 .577 .707 r
F P
0 g
s
.6405 .62546 m .63973 .57043 L .6468 .56097 L p .707 .577 .707 r
F P
0 g
s
.64009 .72308 m .64195 .70394 L .63869 .70279 L p .707 .577 .707 r
F P
0 g
s
.63869 .70279 m .63683 .72192 L .64009 .72308 L p .707 .577 .707 r
F P
0 g
s
.84485 .65367 m .84321 .69157 L .84025 .68621 L p .707 .577 .707 r
F P
0 g
s
.84025 .68621 m .84188 .64831 L .84485 .65367 L p .707 .577 .707 r
F P
0 g
s
.84071 .56234 m .84148 .61737 L .82889 .6087 L p .707 .577 .707 r
F P
0 g
s
.82889 .6087 m .82811 .55368 L .84071 .56234 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6468 .56097 m .64758 .616 L .6405 .62546 L p .707 .577 .707 r
F P
0 g
s
.84178 .7228 m .83992 .74194 L .83666 .74079 L p .707 .577 .707 r
F P
0 g
s
.83666 .74079 m .83852 .72165 L .84178 .7228 L p .707 .577 .707 r
F P
0 g
s
.63947 .68088 m .6411 .64297 L .64811 .63814 L p .707 .577 .707 r
F P
0 g
s
.39269 .62009 m .39191 .56507 L .36074 .56334 L p .707 .577 .707 r
F P
0 g
s
.39191 .56507 m .39269 .62009 L .42452 .61881 L p .707 .577 .707 r
F P
0 g
s
.42452 .61881 m .42374 .56378 L .39191 .56507 L p .707 .577 .707 r
F P
0 g
s
.64758 .616 m .6468 .56097 L .66317 .55251 L p .707 .577 .707 r
F P
0 g
s
.64811 .63814 m .64647 .67604 L .63947 .68088 L p .707 .577 .707 r
F P
0 g
s
.42374 .56378 m .42452 .61881 L .45389 .61465 L p .707 .577 .707 r
F P
0 g
s
.45389 .61465 m .45312 .55962 L .42374 .56378 L p .707 .577 .707 r
F P
0 g
s
.63683 .72192 m .63869 .70279 L .64537 .70261 L p .707 .577 .707 r
F P
0 g
s
.64537 .70261 m .64351 .72175 L .63683 .72192 L p .707 .577 .707 r
F P
0 g
s
.36151 .61836 m .36074 .56334 L .33328 .55877 L p .707 .577 .707 r
F P
0 g
s
.36074 .56334 m .36151 .61836 L .39269 .62009 L p .707 .577 .707 r
F P
0 g
s
.45312 .55962 m .45389 .61465 L .47794 .60801 L p .707 .577 .707 r
F P
0 g
s
.47794 .60801 m .47717 .55298 L .45312 .55962 L p .707 .577 .707 r
F P
0 g
s
.84188 .64831 m .84025 .68621 L .8276 .68086 L p .707 .577 .707 r
F P
0 g
s
.8276 .68086 m .82923 .64295 L .84188 .64831 L p .707 .577 .707 r
F P
0 g
s
.82811 .55368 m .82889 .6087 L .80783 .60174 L p .707 .577 .707 r
F P
0 g
s
.80783 .60174 m .80705 .54672 L .82811 .55368 L p .707 .577 .707 r
F P
0 g
s
.66317 .55251 m .66394 .60753 L .64758 .616 L p .707 .577 .707 r
F P
0 g
s
.39179 .66591 m .39343 .628 L .36227 .62554 L p .707 .577 .707 r
F P
0 g
s
.39343 .628 m .39179 .66591 L .42359 .66675 L p .707 .577 .707 r
F P
0 g
s
.42359 .66675 m .42523 .62884 L .39343 .628 L p .707 .577 .707 r
F P
0 g
s
.33406 .6138 m .33328 .55877 L .31222 .55181 L p .707 .577 .707 r
F P
0 g
s
.33328 .55877 m .33406 .6138 L .36151 .61836 L p .707 .577 .707 r
F P
0 g
s
.42523 .62884 m .42359 .66675 L .45292 .6659 L p .707 .577 .707 r
F P
0 g
s
.45292 .6659 m .45455 .62799 L .42523 .62884 L p .707 .577 .707 r
F P
0 g
s
.64647 .67604 m .64811 .63814 L .6644 .6343 L p .707 .577 .707 r
F P
0 g
s
.83852 .72165 m .83666 .74079 L .82377 .73876 L p .707 .577 .707 r
F P
0 g
s
.82377 .73876 m .82563 .71963 L .83852 .72165 L p .707 .577 .707 r
F P
0 g
s
.66394 .60753 m .66317 .55251 L .68721 .54587 L p .707 .577 .707 r
F P
0 g
s
.36227 .62554 m .36063 .66345 L .39179 .66591 L p .707 .577 .707 r
F P
0 g
s
.36063 .66345 m .36227 .62554 L .3348 .62171 L p .707 .577 .707 r
F P
0 g
s
.38983 .69726 m .39169 .67813 L .36058 .67493 L p .707 .577 .707 r
F P
0 g
s
.39169 .67813 m .38983 .69726 L .42148 .70025 L p .707 .577 .707 r
F P
0 g
s
.42148 .70025 m .42334 .68112 L .39169 .67813 L p .707 .577 .707 r
F P
0 g
s
.36058 .67493 m .35872 .69407 L .38983 .69726 L p .707 .577 .707 r
F P
0 g
s
.6644 .6343 m .66277 .67221 L .64647 .67604 L p .707 .577 .707 r
F P
0 g
s
.42334 .68112 m .42148 .70025 L .45058 .70274 L p .707 .577 .707 r
F P
0 g
s
.45058 .70274 m .45243 .6836 L .42334 .68112 L p .707 .577 .707 r
F P
0 g
s
.3348 .62171 m .33316 .65961 L .36063 .66345 L p .707 .577 .707 r
F P
0 g
s
.47717 .55298 m .47794 .60801 L .4943 .59955 L p .707 .577 .707 r
F P
0 g
s
.4943 .59955 m .49353 .54452 L .47717 .55298 L p .707 .577 .707 r
F P
0 g
s
.45455 .62799 m .45292 .6659 L .4769 .66343 L p .707 .577 .707 r
F P
0 g
s
.4769 .66343 m .47854 .62552 L .45455 .62799 L p .707 .577 .707 r
F P
0 g
s
.64351 .72175 m .64537 .70261 L .66133 .70344 L p .707 .577 .707 r
F P
0 g
s
.35872 .69407 m .36058 .67493 L .33306 .67184 L p .707 .577 .707 r
F P
0 g
s
.66133 .70344 m .65947 .72257 L .64351 .72175 L p .707 .577 .707 r
F P
0 g
s
.33306 .67184 m .3312 .69097 L .35872 .69407 L p .707 .577 .707 r
F P
0 g
s
.80705 .54672 m .80783 .60174 L .78037 .59718 L p .707 .577 .707 r
F P
0 g
s
.78037 .59718 m .77959 .54215 L .80705 .54672 L p .707 .577 .707 r
F P
0 g
s
.31222 .55181 m .313 .60684 L .33406 .6138 L p .707 .577 .707 r
F P
0 g
s
.33316 .65961 m .3348 .62171 L .3137 .61687 L p .707 .577 .707 r
F P
0 g
s
.82923 .64295 m .8276 .68086 L .80651 .67602 L p .707 .577 .707 r
F P
0 g
s
.80651 .67602 m .80814 .63812 L .82923 .64295 L p .707 .577 .707 r
F P
0 g
s
.68721 .54587 m .68799 .6009 L .66394 .60753 L p .707 .577 .707 r
F P
0 g
s
.313 .60684 m .31222 .55181 L .29962 .54315 L p .707 .577 .707 r
F P
0 g
s
.45243 .6836 m .45058 .70274 L .47426 .70448 L p .707 .577 .707 r
F P
0 g
s
.47426 .70448 m .47612 .68534 L .45243 .6836 L p .707 .577 .707 r
F P
0 g
s
.68799 .6009 m .68721 .54587 L .71659 .54171 L p .707 .577 .707 r
F P
0 g
s
.3137 .61687 m .31207 .65478 L .33316 .65961 L p .707 .577 .707 r
F P
0 g
s
.3312 .69097 m .33306 .67184 L .31182 .66915 L p .707 .577 .707 r
F P
0 g
s
.66277 .67221 m .6644 .6343 L .68838 .63183 L p .707 .577 .707 r
F P
0 g
s
.31182 .66915 m .30996 .68828 L .3312 .69097 L p .707 .577 .707 r
F P
0 g
s
.77959 .54215 m .78037 .59718 L .7492 .59545 L p .707 .577 .707 r
F P
0 g
s
.7492 .59545 m .74842 .54043 L .77959 .54215 L p .707 .577 .707 r
F P
0 g
s
.82563 .71963 m .82377 .73876 L .80253 .73608 L p .707 .577 .707 r
F P
0 g
s
.80253 .73608 m .80439 .71694 L .82563 .71963 L p .707 .577 .707 r
F P
0 g
s
.47854 .62552 m .4769 .66343 L .4932 .65959 L p .707 .577 .707 r
F P
0 g
s
.4932 .65959 m .49483 .62169 L .47854 .62552 L p .707 .577 .707 r
F P
0 g
s
.71736 .59673 m .71659 .54171 L .74842 .54043 L p .707 .577 .707 r
F P
0 g
s
.71659 .54171 m .71736 .59673 L .68799 .6009 L p .707 .577 .707 r
F P
0 g
s
.68838 .63183 m .68675 .66974 L .66277 .67221 L p .707 .577 .707 r
F P
0 g
s
.49353 .54452 m .4943 .59955 L .50138 .59009 L p .707 .577 .707 r
F P
0 g
s
.50138 .59009 m .5006 .53506 L .49353 .54452 L p .707 .577 .707 r
F P
0 g
s
.74842 .54043 m .7492 .59545 L .71736 .59673 L p .707 .577 .707 r
F P
0 g
s
.29962 .54315 m .3004 .59817 L .313 .60684 L p .707 .577 .707 r
F P
0 g
s
.65947 .72257 m .66133 .70344 L .68502 .70517 L p .707 .577 .707 r
F P
0 g
s
.68502 .70517 m .68316 .72431 L .65947 .72257 L p .707 .577 .707 r
F P
0 g
s
.31207 .65478 m .3137 .61687 L .30106 .61152 L p .707 .577 .707 r
F P
0 g
s
.80814 .63812 m .80651 .67602 L .77904 .67219 L p .707 .577 .707 r
F P
0 g
s
.77904 .67219 m .78067 .63428 L .80814 .63812 L p .707 .577 .707 r
F P
0 g
s
.47612 .68534 m .47426 .70448 L .49023 .7053 L p .707 .577 .707 r
F P
0 g
s
.49023 .7053 m .49209 .68616 L .47612 .68534 L p .707 .577 .707 r
F P
0 g
s
.3004 .59817 m .29962 .54315 L .29672 .53362 L p .707 .577 .707 r
F P
0 g
s
.30106 .61152 m .29942 .64942 L .31207 .65478 L p .707 .577 .707 r
F P
0 g
s
.68675 .66974 m .68838 .63183 L .71771 .63098 L p .707 .577 .707 r
F P
0 g
s
.30996 .68828 m .31182 .66915 L .29894 .66713 L p .707 .577 .707 r
F P
0 g
s
.29894 .66713 m .29708 .68626 L .30996 .68828 L p .707 .577 .707 r
F P
0 g
s
.80439 .71694 m .80253 .73608 L .77501 .73298 L p .707 .577 .707 r
F P
0 g
s
.77501 .73298 m .77687 .71384 L .80439 .71694 L p .707 .577 .707 r
F P
0 g
s
.71771 .63098 m .71608 .66889 L .68675 .66974 L p .707 .577 .707 r
F P
0 g
s
.78067 .63428 m .77904 .67219 L .74788 .66973 L p .707 .577 .707 r
F P
0 g
s
.74788 .66973 m .74951 .63182 L .78067 .63428 L p .707 .577 .707 r
F P
0 g
s
.49483 .62169 m .4932 .65959 L .5002 .65476 L p .707 .577 .707 r
F P
0 g
s
.5002 .65476 m .50184 .61685 L .49483 .62169 L p .707 .577 .707 r
F P
0 g
s
.68316 .72431 m .68502 .70517 L .71411 .70766 L p .707 .577 .707 r
F P
0 g
s
.71411 .70766 m .71225 .72679 L .68316 .72431 L p .707 .577 .707 r
F P
0 g
s
.71608 .66889 m .71771 .63098 L .74951 .63182 L p .707 .577 .707 r
F P
0 g
s
.5006 .53506 m .50138 .59009 L .49847 .58056 L p .707 .577 .707 r
F P
0 g
s
.49847 .58056 m .4977 .52553 L .5006 .53506 L p .707 .577 .707 r
F P
0 g
s
.74951 .63182 m .74788 .66973 L .71608 .66889 L p .707 .577 .707 r
F P
0 g
s
.29672 .53362 m .29749 .58864 L .3004 .59817 L p .707 .577 .707 r
F P
0 g
s
.77687 .71384 m .77501 .73298 L .7439 .72978 L p .707 .577 .707 r
F P
0 g
s
.7439 .72978 m .74576 .71065 L .77687 .71384 L p .707 .577 .707 r
F P
0 g
s
.49209 .68616 m .49023 .7053 L .49691 .70512 L p .707 .577 .707 r
F P
0 g
s
.49691 .70512 m .49877 .68599 L .49209 .68616 L p .707 .577 .707 r
F P
0 g
s
.29942 .64942 m .30106 .61152 L .29809 .60616 L p .707 .577 .707 r
F P
0 g
s
.71225 .72679 m .71411 .70766 L .74576 .71065 L p .707 .577 .707 r
F P
0 g
s
.74576 .71065 m .7439 .72978 L .71225 .72679 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29809 .60616 m .29646 .64406 L .29942 .64942 L p .707 .577 .707 r
F P
0 g
s
.29749 .58864 m .29672 .53362 L .30379 .52416 L p .707 .577 .707 r
F P
0 g
s
.29708 .68626 m .29894 .66713 L .29568 .66597 L p .707 .577 .707 r
F P
0 g
s
.29568 .66597 m .29382 .68511 L .29708 .68626 L p .707 .577 .707 r
F P
0 g
s
.50184 .61685 m .5002 .65476 L .49724 .6494 L p .707 .577 .707 r
F P
0 g
s
.49724 .6494 m .49887 .61149 L .50184 .61685 L p .707 .577 .707 r
F P
0 g
s
.4977 .52553 m .49847 .58056 L .48588 .57189 L p .707 .577 .707 r
F P
0 g
s
.48588 .57189 m .4851 .51686 L .4977 .52553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30379 .52416 m .30457 .57918 L .29749 .58864 L p .707 .577 .707 r
F P
0 g
s
.49877 .68599 m .49691 .70512 L .49365 .70397 L p .707 .577 .707 r
F P
0 g
s
.49365 .70397 m .49551 .68483 L .49877 .68599 L p .707 .577 .707 r
F P
0 g
s
.29646 .64406 m .29809 .60616 L .3051 .60132 L p .707 .577 .707 r
F P
0 g
s
.30457 .57918 m .30379 .52416 L .32016 .51569 L p .707 .577 .707 r
F P
0 g
s
.3051 .60132 m .30346 .63923 L .29646 .64406 L p .707 .577 .707 r
F P
0 g
s
.29382 .68511 m .29568 .66597 L .30236 .6658 L p .707 .577 .707 r
F P
0 g
s
.30236 .6658 m .3005 .68493 L .29382 .68511 L p .707 .577 .707 r
F P
0 g
s
.49887 .61149 m .49724 .6494 L .48459 .64404 L p .707 .577 .707 r
F P
0 g
s
.48459 .64404 m .48622 .60613 L .49887 .61149 L p .707 .577 .707 r
F P
0 g
s
.4851 .51686 m .48588 .57189 L .46482 .56493 L p .707 .577 .707 r
F P
0 g
s
.46482 .56493 m .46404 .5099 L .4851 .51686 L p .707 .577 .707 r
F P
0 g
s
.32016 .51569 m .32093 .57072 L .30457 .57918 L p .707 .577 .707 r
F P
0 g
s
.30346 .63923 m .3051 .60132 L .32139 .59748 L p .707 .577 .707 r
F P
0 g
s
.49551 .68483 m .49365 .70397 L .48076 .70195 L p .707 .577 .707 r
F P
0 g
s
.48076 .70195 m .48262 .68281 L .49551 .68483 L p .707 .577 .707 r
F P
0 g
s
.32093 .57072 m .32016 .51569 L .3442 .50905 L p .707 .577 .707 r
F P
0 g
s
.32139 .59748 m .31976 .63539 L .30346 .63923 L p .707 .577 .707 r
F P
0 g
s
.3005 .68493 m .30236 .6658 L .31832 .66662 L p .707 .577 .707 r
F P
0 g
s
.31832 .66662 m .31646 .68576 L .3005 .68493 L p .707 .577 .707 r
F P
0 g
s
.46404 .5099 m .46482 .56493 L .43736 .56036 L p .707 .577 .707 r
F P
0 g
s
.43736 .56036 m .43658 .50534 L .46404 .5099 L p .707 .577 .707 r
F P
0 g
s
.48622 .60613 m .48459 .64404 L .4635 .63921 L p .707 .577 .707 r
F P
0 g
s
.4635 .63921 m .46513 .6013 L .48622 .60613 L p .707 .577 .707 r
F P
0 g
s
.3442 .50905 m .34498 .56408 L .32093 .57072 L p .707 .577 .707 r
F P
0 g
s
.34498 .56408 m .3442 .50905 L .37358 .50489 L p .707 .577 .707 r
F P
0 g
s
.31976 .63539 m .32139 .59748 L .34537 .59502 L p .707 .577 .707 r
F P
0 g
s
.43658 .50534 m .43736 .56036 L .40619 .55864 L p .707 .577 .707 r
F P
0 g
s
.40619 .55864 m .40541 .50361 L .43658 .50534 L p .707 .577 .707 r
F P
0 g
s
.48262 .68281 m .48076 .70195 L .45952 .69926 L p .707 .577 .707 r
F P
0 g
s
.45952 .69926 m .46138 .68012 L .48262 .68281 L p .707 .577 .707 r
F P
0 g
s
.37435 .55992 m .37358 .50489 L .40541 .50361 L p .707 .577 .707 r
F P
0 g
s
.37358 .50489 m .37435 .55992 L .34498 .56408 L p .707 .577 .707 r
F P
0 g
s
.34537 .59502 m .34374 .63292 L .31976 .63539 L p .707 .577 .707 r
F P
0 g
s
.40541 .50361 m .40619 .55864 L .37435 .55992 L p .707 .577 .707 r
F P
0 g
s
.31646 .68576 m .31832 .66662 L .34201 .66836 L p .707 .577 .707 r
F P
0 g
s
.34201 .66836 m .34015 .68749 L .31646 .68576 L p .707 .577 .707 r
F P
0 g
s
.46513 .6013 m .4635 .63921 L .43603 .63537 L p .707 .577 .707 r
F P
0 g
s
.43603 .63537 m .43766 .59747 L .46513 .6013 L p .707 .577 .707 r
F P
0 g
s
.34374 .63292 m .34537 .59502 L .3747 .59416 L p .707 .577 .707 r
F P
0 g
s
.46138 .68012 m .45952 .69926 L .432 .69616 L p .707 .577 .707 r
F P
0 g
s
.432 .69616 m .43386 .67703 L .46138 .68012 L p .707 .577 .707 r
F P
0 g
s
.3747 .59416 m .37307 .63207 L .34374 .63292 L p .707 .577 .707 r
F P
0 g
s
.43766 .59747 m .43603 .63537 L .40487 .63292 L p .707 .577 .707 r
F P
0 g
s
.40487 .63292 m .4065 .59501 L .43766 .59747 L p .707 .577 .707 r
F P
0 g
s
.34015 .68749 m .34201 .66836 L .3711 .67084 L p .707 .577 .707 r
F P
0 g
s
.3711 .67084 m .36924 .68998 L .34015 .68749 L p .707 .577 .707 r
F P
0 g
s
.37307 .63207 m .3747 .59416 L .4065 .59501 L p .707 .577 .707 r
F P
0 g
s
.4065 .59501 m .40487 .63292 L .37307 .63207 L p .707 .577 .707 r
F P
0 g
s
.43386 .67703 m .432 .69616 L .40089 .69297 L p .707 .577 .707 r
F P
0 g
s
.40089 .69297 m .40275 .67383 L .43386 .67703 L p .707 .577 .707 r
F P
0 g
s
.36924 .68998 m .3711 .67084 L .40275 .67383 L p .707 .577 .707 r
F P
0 g
s
.40275 .67383 m .40089 .69297 L .36924 .68998 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3@00QGoo001oOol<0006FUH00`00FUIJEP04FUH9001lOol007Moo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00H007Ioo`00LWoo1@000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1000LWoo001^Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001^Ool006Yoo`@00003FUH0
05YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00=JEP<006]oo`00J7oo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JGoo001WOol20006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006EooaT000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00H7oo1P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001MOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol005]oo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00FGoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001GOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
05Ioo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00EGoo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001Uoo`T0
04Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF009JEPP0
03aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH003Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<goo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<002moo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF2`001UYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF70000eYF1P0015YF
00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo00<005YF000015YF00<005YF00000`00
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00E7oo00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00E7oo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo001DOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000]Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH:0008FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00D005YFFUH005YF00d000=JEP03001JEUYF
009JEPl000=JEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo0018Ool90004Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF2P0017oo3P0000=JEP0000000P000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?goo2@0015YF00<005YFFUH00UYF1`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1P00
00=JEP0000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YF00000`001UYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEPD0
00AJEP04001JEUYFFUH2000/Ool003Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00D000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF009JEP80009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP8002aoo`00=Woo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH005YF
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH30003FUH2000/Ool003=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
0000;7oo000aOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00
;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000/Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000eJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00Oomoo`0ZOol0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo
000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEQT00003FUH005YF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00009JEPD00003FUH005YF00EJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF200000=JEP00FUH01EYF00D005YFFUIJ
EP0002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF00<0
05YFFUH015YF1P0015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH700001EYF001JEUYF0000<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000<Goo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF5`0000AJEP00000000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002aoo`00;Goo00<005YF000015YF00<005YFFUH00eYF2P000goo1@0000=oo`0000001`0000=J
EP0000002@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002eoo`03001JEP0000AJEP03
001JEP0000<000EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEP0000<000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;7oo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP0:00001EYF00000000FUH00P0000=JEP00FUH00eYF6@002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00;Goo00<005YF00000UYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00@005YFFUIJEQ0000UJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000AJEP00FUIJEPL000MJEP03001JEUYF00EJEPD000AJEPP000AJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00;Goo00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF000000020005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000]Ool002eoo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
1`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000UYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP070002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP04000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF010000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002ioo`04001JEUYF0005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80002FUH90004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF000000020004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002eoo`00;Woo00D005YFFUH005YF02@000=JEP03001JEUYF00=JEP03001JEP00
00L000=JEQ4000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60002FUH300000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000_Ool01P00
FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
00EJEP03001JEUYF00800003FUH005YF009JEPT000AJEP03001JEUYF00AJEPL000=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH:
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02000_Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPP00004Ool005YF0006FUH00`00FUIJEP03FUH@0002FUH50002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP02FUH300000eYF0000000?0004FUH00`00FUIJEP02FUH>000aOol002eoo`<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00D00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP`00003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00d0009JEP8000]oo`T0
03moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00@005YFFUIJEPT004ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@00?Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<002eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH0000000X000=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009J
EPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH:0003FUH90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00002FUH>0008FUH@0004
FUH00`00FUIJEP03FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P0000=J
EP00FUH01EYF00D005YFFUIJEP0000Eoo`T000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00;Goo00<005YF00000P001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF1P0015YF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00=JEPL00003FUH005YF008000moo`P000=JEPL000=JEP03001JEUYF008002ioo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEP<00006FUH005YF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF
00<005YFFUH0100067oo4P00;Woo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH500000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP03FUH3000SOol4000_Ool002ioo`04
001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJ
EP03001JEUYF00=JEP03001JEUYF008005Aoo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHI0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000aOol30003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00EJEPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol003Aoo`L000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0
009JEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001C
Ool002eooaL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000017oo001JEP00
1EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH010001UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00
;Goo0P0015YF00<005YFFUH015YF00@005YFFUIJEQl000Moo`03001JEP0000=JEP8000IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2001COol002eoo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT001Aoo`04001JEP00FUH30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40004
FUH30007FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005=oo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200037oo00@005YF0000009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEUYFFUH20002FUH60004FUH00`00FUIJEP03FUH00`00FUIJEP02001D
Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEUYFFUH70005Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40004FUH7
0003FUH00`00FUIJEP02001DOol002aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<0
00EJEP03001JEUYF00=JEP@0009JEP8005Aoo`00;Goo1`000UYF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00AJEP03001JEUYF00@005Aoo`00=7oo1`000UYF4P0015YF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003]oo`P000AJEP03001JEUYF
00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00005FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Aoo`00@goo4P000UYF1`00
0eYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00AJ
EP04001JEUYFFUH2001EOol005Eoo`L0009JEPD0009JEP<0009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP8000IJEP03001JEUYF00AJEP03001JEUYF008005Ioo`00G7oo2`0000Aoo`00000000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000=JEPh005Qoo`00JWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEPL006Ioo`00K7oo10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00D005YF000005YF00P006Aoo`00L7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF1P001eYF00@005YFFUIJEPL005eoo`00MGoo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH00eYF2`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01@00F7oo001kOol90006FUH00`00FUIJEP04FUH>0004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003001DOol008AooaP000=JEPT000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol009aoo`T0
00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol00:Eoo`T000=J
EPP000AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00[Woo20000eYF300000=JEP000000EGoo
002fOolB001EOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59381 .74531 m .59459 .68924 L .56341 .68717 L p .707 .577 .707 r
F P
0 g
s
.59459 .68924 m .59381 .74531 L .62564 .74504 L p .707 .577 .707 r
F P
0 g
s
.62564 .74504 m .62642 .68897 L .59459 .68924 L p .707 .577 .707 r
F P
0 g
s
.62642 .68897 m .62564 .74504 L .65502 .74245 L p .707 .577 .707 r
F P
0 g
s
.65502 .74245 m .65579 .68639 L .62642 .68897 L p .707 .577 .707 r
F P
0 g
s
.56264 .74323 m .56341 .68717 L .53596 .68295 L p .707 .577 .707 r
F P
0 g
s
.56341 .68717 m .56264 .74323 L .59381 .74531 L p .707 .577 .707 r
F P
0 g
s
.65579 .68639 m .65502 .74245 L .67907 .7378 L p .707 .577 .707 r
F P
0 g
s
.67907 .7378 m .67984 .68174 L .65579 .68639 L p .707 .577 .707 r
F P
0 g
s
.53596 .68295 m .53518 .73902 L .56264 .74323 L p .707 .577 .707 r
F P
0 g
s
.53518 .73902 m .53596 .68295 L .5149 .67701 L p .707 .577 .707 r
F P
0 g
s
.59513 .81782 m .5935 .7821 L .56234 .78074 L p .707 .577 .707 r
F P
0 g
s
.5935 .7821 m .59513 .81782 L .62693 .81547 L p .707 .577 .707 r
F P
0 g
s
.62693 .81547 m .6253 .77975 L .5935 .7821 L p .707 .577 .707 r
F P
0 g
s
.6253 .77975 m .62693 .81547 L .65626 .80964 L p .707 .577 .707 r
F P
0 g
s
.65626 .80964 m .65462 .77392 L .6253 .77975 L p .707 .577 .707 r
F P
0 g
s
.56397 .81646 m .56234 .78074 L .53487 .77581 L p .707 .577 .707 r
F P
0 g
s
.56234 .78074 m .56397 .81646 L .59513 .81782 L p .707 .577 .707 r
F P
0 g
s
.67984 .68174 m .67907 .7378 L .69543 .73154 L p .707 .577 .707 r
F P
0 g
s
.69543 .73154 m .6962 .67547 L .67984 .68174 L p .707 .577 .707 r
F P
0 g
s
.5149 .67701 m .51412 .73307 L .53518 .73902 L p .707 .577 .707 r
F P
0 g
s
.65462 .77392 m .65626 .80964 L .68024 .8009 L p .707 .577 .707 r
F P
0 g
s
.68024 .8009 m .67861 .76518 L .65462 .77392 L p .707 .577 .707 r
F P
0 g
s
.53487 .77581 m .5365 .81153 L .56397 .81646 L p .707 .577 .707 r
F P
0 g
s
.5365 .81153 m .53487 .77581 L .51378 .76778 L p .707 .577 .707 r
F P
0 g
s
.51412 .73307 m .5149 .67701 L .5023 .66991 L p .707 .577 .707 r
F P
0 g
s
.59911 .87254 m .59725 .85589 L .56614 .85521 L p .707 .577 .707 r
F P
0 g
s
.59725 .85589 m .59911 .87254 L .63076 .86824 L p .707 .577 .707 r
F P
0 g
s
.63076 .86824 m .6289 .8516 L .59725 .85589 L p .707 .577 .707 r
F P
0 g
s
.6289 .8516 m .63076 .86824 L .65985 .85939 L p .707 .577 .707 r
F P
0 g
s
.65985 .85939 m .65799 .84275 L .6289 .8516 L p .707 .577 .707 r
F P
0 g
s
.67861 .76518 m .68024 .8009 L .69653 .7901 L p .707 .577 .707 r
F P
0 g
s
.69653 .7901 m .6949 .75439 L .67861 .76518 L p .707 .577 .707 r
F P
0 g
s
.5023 .66991 m .50152 .72598 L .51412 .73307 L p .707 .577 .707 r
F P
0 g
s
.51378 .76778 m .51541 .8035 L .5365 .81153 L p .707 .577 .707 r
F P
0 g
s
.568 .87185 m .56614 .85521 L .53862 .8496 L p .707 .577 .707 r
F P
0 g
s
.56614 .85521 m .568 .87185 L .59911 .87254 L p .707 .577 .707 r
F P
0 g
s
.6962 .67547 m .69543 .73154 L .7025 .72428 L p .707 .577 .707 r
F P
0 g
s
.7025 .72428 m .70328 .66822 L .6962 .67547 L p .707 .577 .707 r
F P
0 g
s
.65799 .84275 m .65985 .85939 L .68354 .84684 L p .707 .577 .707 r
F P
0 g
s
.68354 .84684 m .68168 .8302 L .65799 .84275 L p .707 .577 .707 r
F P
0 g
s
.51541 .8035 m .51378 .76778 L .50113 .75744 L p .707 .577 .707 r
F P
0 g
s
.53862 .8496 m .54048 .86624 L .568 .87185 L p .707 .577 .707 r
F P
0 g
s
.50152 .72598 m .5023 .66991 L .4994 .66237 L p .707 .577 .707 r
F P
0 g
s
.54048 .86624 m .53862 .8496 L .51737 .83963 L p .707 .577 .707 r
F P
0 g
s
.6949 .75439 m .69653 .7901 L .70354 .77831 L p .707 .577 .707 r
F P
0 g
s
.70354 .77831 m .70191 .7426 L .6949 .75439 L p .707 .577 .707 r
F P
0 g
s
.68168 .8302 m .68354 .84684 L .6995 .83182 L p .707 .577 .707 r
F P
0 g
s
.6995 .83182 m .69764 .81518 L .68168 .8302 L p .707 .577 .707 r
F P
0 g
s
.50113 .75744 m .50276 .79316 L .51541 .8035 L p .707 .577 .707 r
F P
0 g
s
.51737 .83963 m .51923 .85627 L .54048 .86624 L p .707 .577 .707 r
F P
0 g
s
.4994 .66237 m .49862 .71843 L .50152 .72598 L p .707 .577 .707 r
F P
0 g
s
.70328 .66822 m .7025 .72428 L .6996 .71674 L p .707 .577 .707 r
F P
0 g
s
.6996 .71674 m .70037 .66067 L .70328 .66822 L p .707 .577 .707 r
F P
0 g
s
.50276 .79316 m .50113 .75744 L .49816 .74581 L p .707 .577 .707 r
F P
0 g
s
.51923 .85627 m .51737 .83963 L .50449 .82627 L p .707 .577 .707 r
F P
0 g
s
.49462 .82353 m .48781 .32652 L .4438 .32408 L p .707 .577 .707 r
F P
0 g
s
.49862 .71843 m .4994 .66237 L .50647 .65511 L p .707 .577 .707 r
F P
0 g
s
.49816 .74581 m .49979 .78153 L .50276 .79316 L p .707 .577 .707 r
F P
0 g
s
.50647 .65511 m .5057 .71118 L .49862 .71843 L p .707 .577 .707 r
F P
0 g
s
.50635 .84291 m .50449 .82627 L .50123 .81083 L p .707 .577 .707 r
F P
0 g
s
.49979 .78153 m .49816 .74581 L .50517 .73402 L p .707 .577 .707 r
F P
0 g
s
.50123 .81083 m .50309 .82747 L .50635 .84291 L p .707 .577 .707 r
F P
0 g
s
.5057 .71118 m .50647 .65511 L .52283 .64885 L p .707 .577 .707 r
F P
0 g
s
.50517 .73402 m .5068 .76974 L .49979 .78153 L p .707 .577 .707 r
F P
0 g
s
.52283 .64885 m .52206 .70491 L .5057 .71118 L p .707 .577 .707 r
F P
0 g
s
.50309 .82747 m .50123 .81083 L .50791 .79482 L p .707 .577 .707 r
F P
0 g
s
.5068 .76974 m .50517 .73402 L .52146 .72323 L p .707 .577 .707 r
F P
0 g
s
.50791 .79482 m .50977 .81146 L .50309 .82747 L p .707 .577 .707 r
F P
0 g
s
.52206 .70491 m .52283 .64885 L .54688 .6442 L p .707 .577 .707 r
F P
0 g
s
.52146 .72323 m .52309 .75895 L .5068 .76974 L p .707 .577 .707 r
F P
0 g
s
.54688 .6442 m .5461 .70026 L .52206 .70491 L p .707 .577 .707 r
F P
0 g
s
.50977 .81146 m .50791 .79482 L .52387 .7798 L p .707 .577 .707 r
F P
0 g
s
.52309 .75895 m .52146 .72323 L .54544 .71449 L p .707 .577 .707 r
F P
0 g
s
.52387 .7798 m .52573 .79645 L .50977 .81146 L p .707 .577 .707 r
F P
0 g
s
.54544 .71449 m .54708 .75021 L .52309 .75895 L p .707 .577 .707 r
F P
0 g
s
.52573 .79645 m .52387 .7798 L .54756 .76726 L p .707 .577 .707 r
F P
0 g
s
.54756 .76726 m .54942 .7839 L .52573 .79645 L p .707 .577 .707 r
F P
0 g
s
.48781 .32652 m .49462 .82353 L .53956 .82174 L p .707 .577 .707 r
F P
0 g
s
.53956 .82174 m .53274 .32474 L .48781 .32652 L p .707 .577 .707 r
F P
0 g
s
.69764 .81518 m .6995 .83182 L .70618 .81581 L p .707 .577 .707 r
F P
0 g
s
.70618 .81581 m .70432 .79917 L .69764 .81518 L p .707 .577 .707 r
F P
0 g
s
.5461 .70026 m .54688 .6442 L .57625 .64161 L p .707 .577 .707 r
F P
0 g
s
.57625 .64161 m .57548 .69767 L .5461 .70026 L p .707 .577 .707 r
F P
0 g
s
.54708 .75021 m .54544 .71449 L .57477 .70866 L p .707 .577 .707 r
F P
0 g
s
.57477 .70866 m .5764 .74437 L .54708 .75021 L p .707 .577 .707 r
F P
0 g
s
.54942 .7839 m .54756 .76726 L .57666 .7584 L p .707 .577 .707 r
F P
0 g
s
.57666 .7584 m .57852 .77504 L .54942 .7839 L p .707 .577 .707 r
F P
0 g
s
.53274 .32474 m .53956 .82174 L .58103 .81589 L p .707 .577 .707 r
F P
0 g
s
.57548 .69767 m .57625 .64161 L .60809 .64134 L p .707 .577 .707 r
F P
0 g
s
.60809 .64134 m .60731 .69741 L .57548 .69767 L p .707 .577 .707 r
F P
0 g
s
.5764 .74437 m .57477 .70866 L .60657 .70631 L p .707 .577 .707 r
F P
0 g
s
.60657 .70631 m .6082 .74202 L .5764 .74437 L p .707 .577 .707 r
F P
0 g
s
.57852 .77504 m .57666 .7584 L .60831 .75411 L p .707 .577 .707 r
F P
0 g
s
.60831 .75411 m .61016 .77075 L .57852 .77504 L p .707 .577 .707 r
F P
0 g
s
.58103 .81589 m .57422 .31889 L .53274 .32474 L p .707 .577 .707 r
F P
0 g
s
.50449 .82627 m .50635 .84291 L .51923 .85627 L p .707 .577 .707 r
F P
0 g
s
.70191 .7426 m .70354 .77831 L .70057 .76668 L p .707 .577 .707 r
F P
0 g
s
.70057 .76668 m .69894 .73096 L .70191 .7426 L p .707 .577 .707 r
F P
0 g
s
.45061 .82108 m .4438 .32408 L .40503 .31764 L p .707 .577 .707 r
F P
0 g
s
.4438 .32408 m .45061 .82108 L .49462 .82353 L p .707 .577 .707 r
F P
0 g
s
.63773 .70766 m .63936 .74338 L .6082 .74202 L p .707 .577 .707 r
F P
0 g
s
.6082 .74202 m .60657 .70631 L .63773 .70766 L p .707 .577 .707 r
F P
0 g
s
.63941 .7548 m .64127 .77144 L .61016 .77075 L p .707 .577 .707 r
F P
0 g
s
.61016 .77075 m .60831 .75411 L .63941 .7548 L p .707 .577 .707 r
F P
0 g
s
.57422 .31889 m .58103 .81589 L .61498 .80656 L p .707 .577 .707 r
F P
0 g
s
.63926 .64342 m .63848 .69948 L .60731 .69741 L p .707 .577 .707 r
F P
0 g
s
.60731 .69741 m .60809 .64134 L .63926 .64342 L p .707 .577 .707 r
F P
0 g
s
.61498 .80656 m .60817 .30955 L .57422 .31889 L p .707 .577 .707 r
F P
0 g
s
.70037 .66067 m .6996 .71674 L .687 .70964 L p .707 .577 .707 r
F P
0 g
s
.687 .70964 m .68778 .65358 L .70037 .66067 L p .707 .577 .707 r
F P
0 g
s
.70432 .79917 m .70618 .81581 L .70292 .80037 L p .707 .577 .707 r
F P
0 g
s
.70292 .80037 m .70106 .78373 L .70432 .79917 L p .707 .577 .707 r
F P
0 g
s
.2508 .70849 m .25158 .65243 L .22041 .65035 L p .707 .577 .707 r
F P
0 g
s
.25158 .65243 m .2508 .70849 L .28263 .70823 L p .707 .577 .707 r
F P
0 g
s
.28263 .70823 m .28341 .65216 L .25158 .65243 L p .707 .577 .707 r
F P
0 g
s
.41185 .81465 m .40503 .31764 L .3753 .30784 L p .707 .577 .707 r
F P
0 g
s
.40503 .31764 m .41185 .81465 L .45061 .82108 L p .707 .577 .707 r
F P
0 g
s
.28341 .65216 m .28263 .70823 L .31201 .70564 L p .707 .577 .707 r
F P
0 g
s
.31201 .70564 m .31279 .64957 L .28341 .65216 L p .707 .577 .707 r
F P
0 g
s
.21963 .70642 m .22041 .65035 L .19295 .64614 L p .707 .577 .707 r
F P
0 g
s
.22041 .65035 m .21963 .70642 L .2508 .70849 L p .707 .577 .707 r
F P
0 g
s
.69894 .73096 m .70057 .76668 L .68793 .75634 L p .707 .577 .707 r
F P
0 g
s
.68793 .75634 m .68629 .72063 L .69894 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31279 .64957 m .31201 .70564 L .33606 .70099 L p .707 .577 .707 r
F P
0 g
s
.33606 .70099 m .33683 .64492 L .31279 .64957 L p .707 .577 .707 r
F P
0 g
s
.60817 .30955 m .61498 .80656 L .63808 .79465 L p .707 .577 .707 r
F P
0 g
s
.63808 .79465 m .63127 .29765 L .60817 .30955 L p .707 .577 .707 r
F P
0 g
s
.68778 .65358 m .687 .70964 L .66594 .7037 L p .707 .577 .707 r
F P
0 g
s
.66594 .7037 m .66672 .64763 L .68778 .65358 L p .707 .577 .707 r
F P
0 g
s
.19295 .64614 m .19217 .7022 L .21963 .70642 L p .707 .577 .707 r
F P
0 g
s
.19217 .7022 m .19295 .64614 L .17189 .64019 L p .707 .577 .707 r
F P
0 g
s
.25212 .781 m .25049 .74529 L .21933 .74393 L p .707 .577 .707 r
F P
0 g
s
.25049 .74529 m .25212 .781 L .28392 .77865 L p .707 .577 .707 r
F P
0 g
s
.28392 .77865 m .28229 .74294 L .25049 .74529 L p .707 .577 .707 r
F P
0 g
s
.28229 .74294 m .28392 .77865 L .31325 .77282 L p .707 .577 .707 r
F P
0 g
s
.31325 .77282 m .31161 .7371 L .28229 .74294 L p .707 .577 .707 r
F P
0 g
s
.70106 .78373 m .70292 .80037 L .69004 .78701 L p .707 .577 .707 r
F P
0 g
s
.69004 .78701 m .68818 .77037 L .70106 .78373 L p .707 .577 .707 r
F P
0 g
s
.22096 .77965 m .21933 .74393 L .19186 .73899 L p .707 .577 .707 r
F P
0 g
s
.21933 .74393 m .22096 .77965 L .25212 .781 L p .707 .577 .707 r
F P
0 g
s
.38212 .80484 m .3753 .30784 L .35752 .29563 L p .707 .577 .707 r
F P
0 g
s
.3753 .30784 m .38212 .80484 L .41185 .81465 L p .707 .577 .707 r
F P
0 g
s
.68629 .72063 m .68793 .75634 L .66683 .74832 L p .707 .577 .707 r
F P
0 g
s
.66683 .74832 m .6652 .7126 L .68629 .72063 L p .707 .577 .707 r
F P
0 g
s
.33683 .64492 m .33606 .70099 L .35242 .69472 L p .707 .577 .707 r
F P
0 g
s
.35242 .69472 m .35319 .63866 L .33683 .64492 L p .707 .577 .707 r
F P
0 g
s
.17189 .64019 m .17111 .69626 L .19217 .7022 L p .707 .577 .707 r
F P
0 g
s
.31161 .7371 m .31325 .77282 L .33723 .76408 L p .707 .577 .707 r
F P
0 g
s
.33723 .76408 m .3356 .72836 L .31161 .7371 L p .707 .577 .707 r
F P
0 g
s
.66672 .64763 m .66594 .7037 L .63848 .69948 L p .707 .577 .707 r
F P
0 g
s
.63848 .69948 m .63926 .64342 L .66672 .64763 L p .707 .577 .707 r
F P
0 g
s
.19186 .73899 m .19349 .77471 L .22096 .77965 L p .707 .577 .707 r
F P
0 g
s
.19349 .77471 m .19186 .73899 L .17077 .73097 L p .707 .577 .707 r
F P
0 g
s
.17111 .69626 m .17189 .64019 L .15929 .6331 L p .707 .577 .707 r
F P
0 g
s
.2561 .83572 m .25424 .81908 L .22313 .81839 L p .707 .577 .707 r
F P
0 g
s
.25424 .81908 m .2561 .83572 L .28775 .83143 L p .707 .577 .707 r
F P
0 g
s
.28775 .83143 m .28589 .81479 L .25424 .81908 L p .707 .577 .707 r
F P
0 g
s
.68818 .77037 m .69004 .78701 L .6688 .77704 L p .707 .577 .707 r
F P
0 g
s
.6688 .77704 m .66694 .7604 L .68818 .77037 L p .707 .577 .707 r
F P
0 g
s
.28589 .81479 m .28775 .83143 L .31684 .82257 L p .707 .577 .707 r
F P
0 g
s
.31684 .82257 m .31498 .80593 L .28589 .81479 L p .707 .577 .707 r
F P
0 g
s
.6652 .7126 m .66683 .74832 L .63936 .74338 L p .707 .577 .707 r
F P
0 g
s
.63936 .74338 m .63773 .70766 L .6652 .7126 L p .707 .577 .707 r
F P
0 g
s
.66694 .7604 m .6688 .77704 L .64127 .77144 L p .707 .577 .707 r
F P
0 g
s
.64127 .77144 m .63941 .7548 L .66694 .7604 L p .707 .577 .707 r
F P
0 g
s
.63127 .29765 m .63808 .79465 L .64807 .78134 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64125 .28433 L .63127 .29765 L p .707 .577 .707 r
F P
0 g
s
.3356 .72836 m .33723 .76408 L .35352 .75329 L p .707 .577 .707 r
F P
0 g
s
.35352 .75329 m .35189 .71757 L .3356 .72836 L p .707 .577 .707 r
F P
0 g
s
.15929 .6331 m .15851 .68916 L .17111 .69626 L p .707 .577 .707 r
F P
0 g
s
.17077 .73097 m .1724 .76668 L .19349 .77471 L p .707 .577 .707 r
F P
0 g
s
.22499 .83503 m .22313 .81839 L .19561 .81279 L p .707 .577 .707 r
F P
0 g
s
.22313 .81839 m .22499 .83503 L .2561 .83572 L p .707 .577 .707 r
F P
0 g
s
.35319 .63866 m .35242 .69472 L .35949 .68747 L p .707 .577 .707 r
F P
0 g
s
.35949 .68747 m .36027 .6314 L .35319 .63866 L p .707 .577 .707 r
F P
0 g
s
.31498 .80593 m .31684 .82257 L .34053 .81002 L p .707 .577 .707 r
F P
0 g
s
.34053 .81002 m .33867 .79338 L .31498 .80593 L p .707 .577 .707 r
F P
0 g
s
.1724 .76668 m .17077 .73097 L .15812 .72063 L p .707 .577 .707 r
F P
0 g
s
.19561 .81279 m .19747 .82943 L .22499 .83503 L p .707 .577 .707 r
F P
0 g
s
.36433 .79263 m .35752 .29563 L .35342 .28221 L p .707 .577 .707 r
F P
0 g
s
.35752 .29563 m .36433 .79263 L .38212 .80484 L p .707 .577 .707 r
F P
0 g
s
.15851 .68916 m .15929 .6331 L .15639 .62555 L p .707 .577 .707 r
F P
0 g
s
.19747 .82943 m .19561 .81279 L .17437 .80282 L p .707 .577 .707 r
F P
0 g
s
.35189 .71757 m .35352 .75329 L .36053 .7415 L p .707 .577 .707 r
F P
0 g
s
.36053 .7415 m .3589 .70578 L .35189 .71757 L p .707 .577 .707 r
F P
0 g
s
.33867 .79338 m .34053 .81002 L .35649 .79501 L p .707 .577 .707 r
F P
0 g
s
.35649 .79501 m .35463 .77837 L .33867 .79338 L p .707 .577 .707 r
F P
0 g
s
.15812 .72063 m .15975 .75635 L .1724 .76668 L p .707 .577 .707 r
F P
0 g
s
.17437 .80282 m .17622 .81946 L .19747 .82943 L p .707 .577 .707 r
F P
0 g
s
.15639 .62555 m .15561 .68162 L .15851 .68916 L p .707 .577 .707 r
F P
0 g
s
.36027 .6314 m .35949 .68747 L .35659 .67992 L p .707 .577 .707 r
F P
0 g
s
.35659 .67992 m .35737 .62385 L .36027 .6314 L p .707 .577 .707 r
F P
0 g
s
.15975 .75635 m .15812 .72063 L .15515 .709 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64397 .76792 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64199 .33829 m .64807 .78134 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64125 .28433 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64397 .76792 m .64113 .56075 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64113 .56075 m .63716 .27091 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64397 .76792 L .62619 .75571 L p .707 .577 .707 r
F P
0 g
s
.63833 .67198 m .63996 .7077 L .64056 .70819 L p .707 .577 .707 r
F P
0 g
s
.64056 .70819 m .65261 .71804 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.64067 .67952 m .63833 .67198 L .64056 .70819 L .707 .577 .707 r
F
.65261 .71804 m .65098 .68232 L .64069 .67391 L p F P
0 g
s
.64069 .67391 m .63833 .67198 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.65261 .71804 m .64069 .67391 L .64067 .67952 L .707 .577 .707 r
F
.64125 .28433 m .64199 .33829 L p .64182 .38426 L F P
0 g
s
.17622 .81946 m .17437 .80282 L .16148 .78946 L p .707 .577 .707 r
F P
0 g
s
.35463 .77837 m .35649 .79501 L .36317 .779 L p .707 .577 .707 r
F P
0 g
s
.36317 .779 m .36131 .76236 L .35463 .77837 L p .707 .577 .707 r
F P
0 g
s
.15561 .68162 m .15639 .62555 L .16346 .61829 L p .707 .577 .707 r
F P
0 g
s
.16148 .78946 m .16334 .8061 L .17622 .81946 L p .707 .577 .707 r
F P
0 g
s
.15515 .709 m .15679 .74471 L .15975 .75635 L p .707 .577 .707 r
F P
0 g
s
.3589 .70578 m .36053 .7415 L .35756 .72987 L p .707 .577 .707 r
F P
0 g
s
.35756 .72987 m .35593 .69415 L .3589 .70578 L p .707 .577 .707 r
F P
0 g
s
.36131 .76236 m .36317 .779 L .35991 .76356 L p .707 .577 .707 r
F P
0 g
s
.35991 .76356 m .35805 .74692 L .36131 .76236 L p .707 .577 .707 r
F P
0 g
s
.35342 .28221 m .36024 .77922 L .36433 .79263 L p .707 .577 .707 r
F P
0 g
s
.36024 .77922 m .35342 .28221 L .36341 .2689 L p .707 .577 .707 r
F P
0 g
s
.16346 .61829 m .16269 .67436 L .15561 .68162 L p .707 .577 .707 r
F P
0 g
s
.16334 .8061 m .16148 .78946 L .15822 .77402 L p .707 .577 .707 r
F P
0 g
s
.35737 .62385 m .35659 .67992 L .34399 .67283 L p .707 .577 .707 r
F P
0 g
s
.34399 .67283 m .34477 .61676 L .35737 .62385 L p .707 .577 .707 r
F P
0 g
s
.15679 .74471 m .15515 .709 L .16216 .69721 L p .707 .577 .707 r
F P
0 g
s
.15822 .77402 m .16008 .79066 L .16334 .8061 L p .707 .577 .707 r
F P
0 g
s
.16269 .67436 m .16346 .61829 L .17982 .61203 L p .707 .577 .707 r
F P
0 g
s
.16216 .69721 m .16379 .73292 L .15679 .74471 L p .707 .577 .707 r
F P
0 g
s
.35593 .69415 m .35756 .72987 L .34492 .71953 L p .707 .577 .707 r
F P
0 g
s
.34492 .71953 m .34328 .68381 L .35593 .69415 L p .707 .577 .707 r
F P
0 g
s
.62619 .75571 m .61937 .2587 L .63716 .27091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17982 .61203 m .17905 .6681 L .16269 .67436 L p .707 .577 .707 r
F P
0 g
s
.16008 .79066 m .15822 .77402 L .1649 .758 L p .707 .577 .707 r
F P
0 g
s
.34477 .61676 m .34399 .67283 L .32293 .66688 L p .707 .577 .707 r
F P
0 g
s
.32293 .66688 m .32371 .61082 L .34477 .61676 L p .707 .577 .707 r
F P
0 g
s
.16379 .73292 m .16216 .69721 L .17845 .68641 L p .707 .577 .707 r
F P
0 g
s
.37022 .7659 m .36341 .2689 L .38651 .25699 L p .707 .577 .707 r
F P
0 g
s
.36341 .2689 m .37022 .7659 L .36024 .77922 L p .707 .577 .707 r
F P
0 g
s
.35805 .74692 m .35991 .76356 L .34703 .7502 L p .707 .577 .707 r
F P
0 g
s
.34703 .7502 m .34517 .73356 L .35805 .74692 L p .707 .577 .707 r
F P
0 g
s
.1649 .758 m .16676 .77465 L .16008 .79066 L p .707 .577 .707 r
F P
0 g
s
.17905 .6681 m .17982 .61203 L .20387 .60738 L p .707 .577 .707 r
F P
0 g
s
.34328 .68381 m .34492 .71953 L .32383 .7115 L p .707 .577 .707 r
F P
0 g
s
.32383 .7115 m .32219 .67578 L .34328 .68381 L p .707 .577 .707 r
F P
0 g
s
.17845 .68641 m .18008 .72213 L .16379 .73292 L p .707 .577 .707 r
F P
0 g
s
.32371 .61082 m .32293 .66688 L .29547 .66267 L p .707 .577 .707 r
F P
0 g
s
.29547 .66267 m .29625 .6066 L .32371 .61082 L p .707 .577 .707 r
F P
0 g
s
.20387 .60738 m .20309 .66345 L .17905 .6681 L p .707 .577 .707 r
F P
0 g
s
.16676 .77465 m .1649 .758 L .18087 .74299 L p .707 .577 .707 r
F P
0 g
s
.18008 .72213 m .17845 .68641 L .20243 .67767 L p .707 .577 .707 r
F P
0 g
s
.61937 .2587 m .62619 .75571 L .59646 .74591 L p .707 .577 .707 r
F P
0 g
s
.59646 .74591 m .58964 .2489 L .61937 .2587 L p .707 .577 .707 r
F P
0 g
s
.20309 .66345 m .20387 .60738 L .23325 .60479 L p .707 .577 .707 r
F P
0 g
s
.34517 .73356 m .34703 .7502 L .32579 .74023 L p .707 .577 .707 r
F P
0 g
s
.32579 .74023 m .32393 .72359 L .34517 .73356 L p .707 .577 .707 r
F P
0 g
s
.18087 .74299 m .18272 .75963 L .16676 .77465 L p .707 .577 .707 r
F P
0 g
s
.32219 .67578 m .32383 .7115 L .29636 .70657 L p .707 .577 .707 r
F P
0 g
s
.29636 .70657 m .29472 .67085 L .32219 .67578 L p .707 .577 .707 r
F P
0 g
s
.29625 .6066 m .29547 .66267 L .2643 .66059 L p .707 .577 .707 r
F P
0 g
s
.2643 .66059 m .26508 .60452 L .29625 .6066 L p .707 .577 .707 r
F P
0 g
s
.20243 .67767 m .20407 .71339 L .18008 .72213 L p .707 .577 .707 r
F P
0 g
s
.23247 .66086 m .23325 .60479 L .26508 .60452 L p .707 .577 .707 r
F P
0 g
s
.23325 .60479 m .23247 .66086 L .20309 .66345 L p .707 .577 .707 r
F P
0 g
s
.38651 .25699 m .39332 .75399 L .37022 .7659 L p .707 .577 .707 r
F P
0 g
s
.39332 .75399 m .38651 .25699 L .42046 .24765 L p .707 .577 .707 r
F P
0 g
s
.26508 .60452 m .2643 .66059 L .23247 .66086 L p .707 .577 .707 r
F P
0 g
s
.20407 .71339 m .20243 .67767 L .23176 .67184 L p .707 .577 .707 r
F P
0 g
s
.73101 .65794 m .73179 .60187 L .70062 .5998 L p .707 .577 .707 r
F P
0 g
s
.73179 .60187 m .73101 .65794 L .76285 .65767 L p .707 .577 .707 r
F P
0 g
s
.76285 .65767 m .76362 .60161 L .73179 .60187 L p .707 .577 .707 r
F P
0 g
s
.18272 .75963 m .18087 .74299 L .20455 .73044 L p .707 .577 .707 r
F P
0 g
s
.76362 .60161 m .76285 .65767 L .79222 .65508 L p .707 .577 .707 r
F P
0 g
s
.79222 .65508 m .793 .59902 L .76362 .60161 L p .707 .577 .707 r
F P
0 g
s
.29472 .67085 m .29636 .70657 L .26519 .70521 L p .707 .577 .707 r
F P
0 g
s
.26519 .70521 m .26356 .66949 L .29472 .67085 L p .707 .577 .707 r
F P
0 g
s
.69984 .65586 m .70062 .5998 L .67316 .59558 L p .707 .577 .707 r
F P
0 g
s
.70062 .5998 m .69984 .65586 L .73101 .65794 L p .707 .577 .707 r
F P
0 g
s
.32393 .72359 m .32579 .74023 L .29826 .73462 L p .707 .577 .707 r
F P
0 g
s
.29826 .73462 m .2964 .71798 L .32393 .72359 L p .707 .577 .707 r
F P
0 g
s
.23339 .70756 m .23176 .67184 L .26356 .66949 L p .707 .577 .707 r
F P
0 g
s
.23176 .67184 m .23339 .70756 L .20407 .71339 L p .707 .577 .707 r
F P
0 g
s
.20455 .73044 m .20641 .74708 L .18272 .75963 L p .707 .577 .707 r
F P
0 g
s
.58964 .2489 m .59646 .74591 L .55769 .73947 L p .707 .577 .707 r
F P
0 g
s
.55769 .73947 m .55088 .24246 L .58964 .2489 L p .707 .577 .707 r
F P
0 g
s
.26356 .66949 m .26519 .70521 L .23339 .70756 L p .707 .577 .707 r
F P
0 g
s
.793 .59902 m .79222 .65508 L .81627 .65043 L p .707 .577 .707 r
F P
0 g
s
.81627 .65043 m .81705 .59437 L .793 .59902 L p .707 .577 .707 r
F P
0 g
s
.20641 .74708 m .20455 .73044 L .23365 .72159 L p .707 .577 .707 r
F P
0 g
s
.67316 .59558 m .67238 .65165 L .69984 .65586 L p .707 .577 .707 r
F P
0 g
s
.67238 .65165 m .67316 .59558 L .6521 .58964 L p .707 .577 .707 r
F P
0 g
s
.2964 .71798 m .29826 .73462 L .26716 .73394 L p .707 .577 .707 r
F P
0 g
s
.26716 .73394 m .2653 .71729 L .2964 .71798 L p .707 .577 .707 r
F P
0 g
s
.73233 .73236 m .7307 .69664 L .69954 .69528 L p .707 .577 .707 r
F P
0 g
s
.7307 .69664 m .73233 .73236 L .76413 .73001 L p .707 .577 .707 r
F P
0 g
s
.76413 .73001 m .7625 .69429 L .7307 .69664 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .42046 .24765 L .46193 .24181 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .39332 .75399 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.42443 .53749 m .42727 .74466 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.46193 .24181 m .46875 .73881 L .42727 .74466 L p .707 .577 .707 r
F P
0 g
s
.41949 .65747 m .42112 .69319 L .44907 .68763 L p .707 .577 .707 r
F P
0 g
s
.44907 .68763 m .45045 .68736 L p .44876 .68573 L .707 .577 .707 r
F P
0 g
s
.44876 .68573 m .41949 .65747 L .44907 .68763 L .707 .577 .707 r
F
.42046 .24765 m .42443 .53749 L p .40973 .4479 L F P
0 g
s
.7625 .69429 m .76413 .73001 L .79346 .72417 L p .707 .577 .707 r
F P
0 g
s
.79346 .72417 m .79183 .68846 L .7625 .69429 L p .707 .577 .707 r
F P
0 g
s
.23365 .72159 m .23551 .73823 L .20641 .74708 L p .707 .577 .707 r
F P
0 g
s
.23551 .73823 m .23365 .72159 L .2653 .71729 L p .707 .577 .707 r
F P
0 g
s
.70117 .731 m .69954 .69528 L .67207 .69035 L p .707 .577 .707 r
F P
0 g
s
.69954 .69528 m .70117 .731 L .73233 .73236 L p .707 .577 .707 r
F P
0 g
s
.2653 .71729 m .26716 .73394 L .23551 .73823 L p .707 .577 .707 r
F P
0 g
s
.55088 .24246 m .55769 .73947 L .51368 .73702 L p .707 .577 .707 r
F P
0 g
s
.51368 .73702 m .50687 .24002 L .55088 .24246 L p .707 .577 .707 r
F P
0 g
s
.81705 .59437 m .81627 .65043 L .83263 .64417 L p .707 .577 .707 r
F P
0 g
s
.83263 .64417 m .83341 .5881 L .81705 .59437 L p .707 .577 .707 r
F P
0 g
s
.6521 .58964 m .65133 .6457 L .67238 .65165 L p .707 .577 .707 r
F P
0 g
s
.79183 .68846 m .79346 .72417 L .81744 .71543 L p .707 .577 .707 r
F P
0 g
s
.81744 .71543 m .81581 .67972 L .79183 .68846 L p .707 .577 .707 r
F P
0 g
s
.46875 .73881 m .46193 .24181 L .50687 .24002 L p .707 .577 .707 r
F P
0 g
s
.50687 .24002 m .51368 .73702 L .46875 .73881 L p .707 .577 .707 r
F P
0 g
s
.67207 .69035 m .6737 .72606 L .70117 .731 L p .707 .577 .707 r
F P
0 g
s
.65133 .6457 m .6521 .58964 L .6395 .58254 L p .707 .577 .707 r
F P
0 g
s
.6737 .72606 m .67207 .69035 L .65098 .68232 L p .707 .577 .707 r
F P
0 g
s
.73631 .78292 m .73445 .76628 L .70334 .76559 L p .707 .577 .707 r
F P
0 g
s
.73445 .76628 m .73631 .78292 L .76796 .77863 L p .707 .577 .707 r
F P
0 g
s
.76796 .77863 m .7661 .76199 L .73445 .76628 L p .707 .577 .707 r
F P
0 g
s
.7661 .76199 m .76796 .77863 L .79705 .76977 L p .707 .577 .707 r
F P
0 g
s
.79705 .76977 m .79519 .75313 L .7661 .76199 L p .707 .577 .707 r
F P
0 g
s
.81581 .67972 m .81744 .71543 L .83374 .70464 L p .707 .577 .707 r
F P
0 g
s
.83374 .70464 m .8321 .66892 L .81581 .67972 L p .707 .577 .707 r
F P
0 g
s
.6395 .58254 m .63873 .63861 L .65133 .6457 L p .707 .577 .707 r
F P
0 g
s
.7052 .78223 m .70334 .76559 L .67582 .75999 L p .707 .577 .707 r
F P
0 g
s
.70334 .76559 m .7052 .78223 L .73631 .78292 L p .707 .577 .707 r
F P
0 g
s
.65098 .68232 m .65261 .71804 L .6737 .72606 L p .707 .577 .707 r
F P
0 g
s
.83341 .5881 m .83263 .64417 L .83971 .63691 L p .707 .577 .707 r
F P
0 g
s
.83971 .63691 m .84048 .58085 L .83341 .5881 L p .707 .577 .707 r
F P
0 g
s
.79519 .75313 m .79705 .76977 L .82074 .75723 L p .707 .577 .707 r
F P
0 g
s
.82074 .75723 m .81888 .74058 L .79519 .75313 L p .707 .577 .707 r
F P
0 g
s
.67582 .75999 m .67768 .77663 L .7052 .78223 L p .707 .577 .707 r
F P
0 g
s
.63873 .63861 m .6395 .58254 L .6366 .575 L p .707 .577 .707 r
F P
0 g
s
.67768 .77663 m .67582 .75999 L .65458 .75002 L p .707 .577 .707 r
F P
0 g
s
.81888 .74058 m .82074 .75723 L .83671 .74221 L p .707 .577 .707 r
F P
0 g
s
.83671 .74221 m .83485 .72557 L .81888 .74058 L p .707 .577 .707 r
F P
0 g
s
.8321 .66892 m .83374 .70464 L .84074 .69285 L p .707 .577 .707 r
F P
0 g
s
.84074 .69285 m .83911 .65713 L .8321 .66892 L p .707 .577 .707 r
F P
0 g
s
.65458 .75002 m .65644 .76666 L .67768 .77663 L p .707 .577 .707 r
F P
0 g
s
.6366 .575 m .63582 .63106 L .63873 .63861 L p .707 .577 .707 r
F P
0 g
s
.84048 .58085 m .83971 .63691 L .8368 .62937 L p .707 .577 .707 r
F P
0 g
s
.8368 .62937 m .83758 .5733 L .84048 .58085 L p .707 .577 .707 r
F P
0 g
s
.63996 .7077 m .63833 .67198 L .63537 .66035 L p .707 .577 .707 r
F P
0 g
s
.65644 .76666 m .65458 .75002 L .6417 .73666 L p .707 .577 .707 r
F P
0 g
s
.83485 .72557 m .83671 .74221 L .84338 .7262 L p .707 .577 .707 r
F P
0 g
s
.84338 .7262 m .84152 .70956 L .83485 .72557 L p .707 .577 .707 r
F P
0 g
s
.63582 .63106 m .6366 .575 L .64367 .56774 L p .707 .577 .707 r
F P
0 g
s
.6417 .73666 m .64356 .7533 L .65644 .76666 L p .707 .577 .707 r
F P
0 g
s
.63537 .66035 m .637 .69607 L .63996 .7077 L p .707 .577 .707 r
F P
0 g
s
.83911 .65713 m .84074 .69285 L .83778 .68122 L p .707 .577 .707 r
F P
0 g
s
.83778 .68122 m .83614 .6455 L .83911 .65713 L p .707 .577 .707 r
F P
0 g
s
.64367 .56774 m .6429 .62381 L .63582 .63106 L p .707 .577 .707 r
F P
0 g
s
.64356 .7533 m .6417 .73666 L .63844 .72122 L p .707 .577 .707 r
F P
0 g
s
.83758 .5733 m .8368 .62937 L .82421 .62227 L p .707 .577 .707 r
F P
0 g
s
.82421 .62227 m .82498 .56621 L .83758 .5733 L p .707 .577 .707 r
F P
0 g
s
.637 .69607 m .63537 .66035 L .64237 .64856 L p .707 .577 .707 r
F P
0 g
s
.84152 .70956 m .84338 .7262 L .84012 .71076 L p .707 .577 .707 r
F P
0 g
s
.84012 .71076 m .83826 .69412 L .84152 .70956 L p .707 .577 .707 r
F P
0 g
s
.38801 .62113 m .38878 .56506 L .35761 .56298 L p .707 .577 .707 r
F P
0 g
s
.38878 .56506 m .38801 .62113 L .41984 .62086 L p .707 .577 .707 r
F P
0 g
s
.41984 .62086 m .42061 .56479 L .38878 .56506 L p .707 .577 .707 r
F P
0 g
s
.63844 .72122 m .6403 .73786 L .64356 .7533 L p .707 .577 .707 r
F P
0 g
s
.42061 .56479 m .41984 .62086 L .44921 .61827 L p .707 .577 .707 r
F P
0 g
s
.44921 .61827 m .44999 .5622 L .42061 .56479 L p .707 .577 .707 r
F P
0 g
s
.6429 .62381 m .64367 .56774 L .66004 .56148 L p .707 .577 .707 r
F P
0 g
s
.35683 .61905 m .35761 .56298 L .33015 .55877 L p .707 .577 .707 r
F P
0 g
s
.35761 .56298 m .35683 .61905 L .38801 .62113 L p .707 .577 .707 r
F P
0 g
s
.64237 .64856 m .64401 .68428 L .637 .69607 L p .707 .577 .707 r
F P
0 g
s
.83614 .6455 m .83778 .68122 L .82513 .67088 L p .707 .577 .707 r
F P
0 g
s
.82513 .67088 m .8235 .63517 L .83614 .6455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44999 .5622 m .44921 .61827 L .47326 .61362 L p .707 .577 .707 r
F P
0 g
s
.47326 .61362 m .47404 .55755 L .44999 .5622 L p .707 .577 .707 r
F P
0 g
s
.66004 .56148 m .65926 .61754 L .6429 .62381 L p .707 .577 .707 r
F P
0 g
s
.6403 .73786 m .63844 .72122 L .64511 .70521 L p .707 .577 .707 r
F P
0 g
s
.82498 .56621 m .82421 .62227 L .80315 .61633 L p .707 .577 .707 r
F P
0 g
s
.80315 .61633 m .80392 .56026 L .82498 .56621 L p .707 .577 .707 r
F P
0 g
s
.33015 .55877 m .32937 .61483 L .35683 .61905 L p .707 .577 .707 r
F P
0 g
s
.32937 .61483 m .33015 .55877 L .30909 .55282 L p .707 .577 .707 r
F P
0 g
s
.64401 .68428 m .64237 .64856 L .65866 .63777 L p .707 .577 .707 r
F P
0 g
s
.38932 .69554 m .38769 .65983 L .35653 .65847 L p .707 .577 .707 r
F P
0 g
s
.38769 .65983 m .38932 .69554 L .42112 .69319 L p .707 .577 .707 r
F P
0 g
s
.42112 .69319 m .41949 .65747 L .38769 .65983 L p .707 .577 .707 r
F P
0 g
s
.45045 .68736 m .44882 .65164 L .41949 .65747 L p .707 .577 .707 r
F P
0 g
s
.83826 .69412 m .84012 .71076 L .82724 .6974 L p .707 .577 .707 r
F P
0 g
s
.82724 .6974 m .82538 .68076 L .83826 .69412 L p .707 .577 .707 r
F P
0 g
s
.64511 .70521 m .64697 .72185 L .6403 .73786 L p .707 .577 .707 r
F P
0 g
s
.65926 .61754 m .66004 .56148 L .68408 .55683 L p .707 .577 .707 r
F P
0 g
s
.35816 .69418 m .35653 .65847 L .32906 .65353 L p .707 .577 .707 r
F P
0 g
s
.35653 .65847 m .35816 .69418 L .38932 .69554 L p .707 .577 .707 r
F P
0 g
s
.8235 .63517 m .82513 .67088 L .80404 .66285 L p .707 .577 .707 r
F P
0 g
s
.80404 .66285 m .80241 .62714 L .8235 .63517 L p .707 .577 .707 r
F P
0 g
s
.47404 .55755 m .47326 .61362 L .48962 .60735 L p .707 .577 .707 r
F P
0 g
s
.48962 .60735 m .4904 .55129 L .47404 .55755 L p .707 .577 .707 r
F P
0 g
s
.30909 .55282 m .30832 .60889 L .32937 .61483 L p .707 .577 .707 r
F P
0 g
s
.65866 .63777 m .6603 .67348 L .64401 .68428 L p .707 .577 .707 r
F P
0 g
s
.44882 .65164 m .45045 .68736 L .47443 .67862 L p .707 .577 .707 r
F P
0 g
s
.47443 .67862 m .4728 .6429 L .44882 .65164 L p .707 .577 .707 r
F P
0 g
s
.80392 .56026 m .80315 .61633 L .77569 .61211 L p .707 .577 .707 r
F P
0 g
s
.77569 .61211 m .77646 .55605 L .80392 .56026 L p .707 .577 .707 r
F P
0 g
s
.68408 .55683 m .68331 .61289 L .65926 .61754 L p .707 .577 .707 r
F P
0 g
s
.32906 .65353 m .33069 .68925 L .35816 .69418 L p .707 .577 .707 r
F P
0 g
s
.64697 .72185 m .64511 .70521 L .66108 .69019 L p .707 .577 .707 r
F P
0 g
s
.30832 .60889 m .30909 .55282 L .29649 .54573 L p .707 .577 .707 r
F P
0 g
s
.33069 .68925 m .32906 .65353 L .30797 .6455 L p .707 .577 .707 r
F P
0 g
s
.6603 .67348 m .65866 .63777 L .68265 .62903 L p .707 .577 .707 r
F P
0 g
s
.68331 .61289 m .68408 .55683 L .71346 .55424 L p .707 .577 .707 r
F P
0 g
s
.3933 .74611 m .39144 .72946 L .36033 .72878 L p .707 .577 .707 r
F P
0 g
s
.39144 .72946 m .3933 .74611 L .42495 .74181 L p .707 .577 .707 r
F P
0 g
s
.42495 .74181 m .42309 .72517 L .39144 .72946 L p .707 .577 .707 r
F P
0 g
s
.82538 .68076 m .82724 .6974 L .806 .68743 L p .707 .577 .707 r
F P
0 g
s
.806 .68743 m .80414 .67079 L .82538 .68076 L p .707 .577 .707 r
F P
0 g
s
.42309 .72517 m .42495 .74181 L .45404 .73296 L p .707 .577 .707 r
F P
0 g
s
.45404 .73296 m .45218 .71632 L .42309 .72517 L p .707 .577 .707 r
F P
0 g
s
.66108 .69019 m .66294 .70683 L .64697 .72185 L p .707 .577 .707 r
F P
0 g
s
.4728 .6429 m .47443 .67862 L .49073 .66783 L p .707 .577 .707 r
F P
0 g
s
.49073 .66783 m .48909 .63211 L .4728 .6429 L p .707 .577 .707 r
F P
0 g
s
.80241 .62714 m .80404 .66285 L .77657 .65792 L p .707 .577 .707 r
F P
0 g
s
.77657 .65792 m .77494 .6222 L .80241 .62714 L p .707 .577 .707 r
F P
0 g
s
.77646 .55605 m .77569 .61211 L .74452 .61004 L p .707 .577 .707 r
F P
0 g
s
.74452 .61004 m .74529 .55397 L .77646 .55605 L p .707 .577 .707 r
F P
0 g
s
.29649 .54573 m .29572 .60179 L .30832 .60889 L p .707 .577 .707 r
F P
0 g
s
.36219 .74542 m .36033 .72878 L .33281 .72317 L p .707 .577 .707 r
F P
0 g
s
.36033 .72878 m .36219 .74542 L .3933 .74611 L p .707 .577 .707 r
F P
0 g
s
.30797 .6455 m .3096 .68122 L .33069 .68925 L p .707 .577 .707 r
F P
0 g
s
.68265 .62903 m .68428 .66474 L .6603 .67348 L p .707 .577 .707 r
F P
0 g
s
.4904 .55129 m .48962 .60735 L .4967 .6001 L p .707 .577 .707 r
F P
0 g
s
.4967 .6001 m .49747 .54403 L .4904 .55129 L p .707 .577 .707 r
F P
0 g
s
.71268 .6103 m .71346 .55424 L .74529 .55397 L p .707 .577 .707 r
F P
0 g
s
.71346 .55424 m .71268 .6103 L .68331 .61289 L p .707 .577 .707 r
F P
0 g
s
.45218 .71632 m .45404 .73296 L .47773 .72041 L p .707 .577 .707 r
F P
0 g
s
.47773 .72041 m .47587 .70377 L .45218 .71632 L p .707 .577 .707 r
F P
0 g
s
.74529 .55397 m .74452 .61004 L .71268 .6103 L p .707 .577 .707 r
F P
0 g
s
.68428 .66474 m .68265 .62903 L .71198 .6232 L p .707 .577 .707 r
F P
0 g
s
.66294 .70683 m .66108 .69019 L .68477 .67764 L p .707 .577 .707 r
F P
0 g
s
.3096 .68122 m .30797 .6455 L .29532 .63517 L p .707 .577 .707 r
F P
0 g
s
.33281 .72317 m .33467 .73981 L .36219 .74542 L p .707 .577 .707 r
F P
0 g
s
.77494 .6222 m .77657 .65792 L .74541 .65656 L p .707 .577 .707 r
F P
0 g
s
.74541 .65656 m .74378 .62084 L .77494 .6222 L p .707 .577 .707 r
F P
0 g
s
.29572 .60179 m .29649 .54573 L .29359 .53818 L p .707 .577 .707 r
F P
0 g
s
.80414 .67079 m .806 .68743 L .77848 .68183 L p .707 .577 .707 r
F P
0 g
s
.77848 .68183 m .77662 .66518 L .80414 .67079 L p .707 .577 .707 r
F P
0 g
s
.33467 .73981 m .33281 .72317 L .31157 .7132 L p .707 .577 .707 r
F P
0 g
s
.68477 .67764 m .68663 .69428 L .66294 .70683 L p .707 .577 .707 r
F P
0 g
s
.71361 .65891 m .71198 .6232 L .74378 .62084 L p .707 .577 .707 r
F P
0 g
s
.71198 .6232 m .71361 .65891 L .68428 .66474 L p .707 .577 .707 r
F P
0 g
s
.74378 .62084 m .74541 .65656 L .71361 .65891 L p .707 .577 .707 r
F P
0 g
s
.47587 .70377 m .47773 .72041 L .4937 .7054 L p .707 .577 .707 r
F P
0 g
s
.4937 .7054 m .49184 .68875 L .47587 .70377 L p .707 .577 .707 r
F P
0 g
s
.48909 .63211 m .49073 .66783 L .49773 .65604 L p .707 .577 .707 r
F P
0 g
s
.49773 .65604 m .4961 .62032 L .48909 .63211 L p .707 .577 .707 r
F P
0 g
s
.29532 .63517 m .29695 .67088 L .3096 .68122 L p .707 .577 .707 r
F P
0 g
s
.31157 .7132 m .31343 .72984 L .33467 .73981 L p .707 .577 .707 r
F P
0 g
s
.68663 .69428 m .68477 .67764 L .71386 .66879 L p .707 .577 .707 r
F P
0 g
s
.29359 .53818 m .29281 .59425 L .29572 .60179 L p .707 .577 .707 r
F P
0 g
s
.77662 .66518 m .77848 .68183 L .74737 .68114 L p .707 .577 .707 r
F P
0 g
s
.74737 .68114 m .74551 .66449 L .77662 .66518 L p .707 .577 .707 r
F P
0 g
s
.49747 .54403 m .4967 .6001 L .49379 .59255 L p .707 .577 .707 r
F P
0 g
s
.49379 .59255 m .49457 .53649 L .49747 .54403 L p .707 .577 .707 r
F P
0 g
s
.71386 .66879 m .71572 .68543 L .68663 .69428 L p .707 .577 .707 r
F P
0 g
s
.71572 .68543 m .71386 .66879 L .74551 .66449 L p .707 .577 .707 r
F P
0 g
s
.29695 .67088 m .29532 .63517 L .29236 .62354 L p .707 .577 .707 r
F P
0 g
s
.31343 .72984 m .31157 .7132 L .29869 .69984 L p .707 .577 .707 r
F P
0 g
s
.74551 .66449 m .74737 .68114 L .71572 .68543 L p .707 .577 .707 r
F P
0 g
s
.49184 .68875 m .4937 .7054 L .50037 .68938 L p .707 .577 .707 r
F P
0 g
s
.50037 .68938 m .49851 .67274 L .49184 .68875 L p .707 .577 .707 r
F P
0 g
s
.29281 .59425 m .29359 .53818 L .30066 .53092 L p .707 .577 .707 r
F P
0 g
s
.29869 .69984 m .30055 .71648 L .31343 .72984 L p .707 .577 .707 r
F P
0 g
s
.29236 .62354 m .29399 .65925 L .29695 .67088 L p .707 .577 .707 r
F P
0 g
s
.4961 .62032 m .49773 .65604 L .49477 .6444 L p .707 .577 .707 r
F P
0 g
s
.49477 .6444 m .49313 .60869 L .4961 .62032 L p .707 .577 .707 r
F P
0 g
s
.30066 .53092 m .29989 .58699 L .29281 .59425 L p .707 .577 .707 r
F P
0 g
s
.30055 .71648 m .29869 .69984 L .29542 .6844 L p .707 .577 .707 r
F P
0 g
s
.49457 .53649 m .49379 .59255 L .4812 .58546 L p .707 .577 .707 r
F P
0 g
s
.4812 .58546 m .48197 .52939 L .49457 .53649 L p .707 .577 .707 r
F P
0 g
s
.29399 .65925 m .29236 .62354 L .29936 .61175 L p .707 .577 .707 r
F P
0 g
s
.49851 .67274 m .50037 .68938 L .49711 .67394 L p .707 .577 .707 r
F P
0 g
s
.49711 .67394 m .49525 .6573 L .49851 .67274 L p .707 .577 .707 r
F P
0 g
s
.29542 .6844 m .29728 .70104 L .30055 .71648 L p .707 .577 .707 r
F P
0 g
s
.29989 .58699 m .30066 .53092 L .31703 .52466 L p .707 .577 .707 r
F P
0 g
s
.29936 .61175 m .30099 .64746 L .29399 .65925 L p .707 .577 .707 r
F P
0 g
s
.49313 .60869 m .49477 .6444 L .48212 .63407 L p .707 .577 .707 r
F P
0 g
s
.48212 .63407 m .48049 .59835 L .49313 .60869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31703 .52466 m .31625 .58073 L .29989 .58699 L p .707 .577 .707 r
F P
0 g
s
.29728 .70104 m .29542 .6844 L .3021 .66839 L p .707 .577 .707 r
F P
0 g
s
.48197 .52939 m .4812 .58546 L .46014 .57951 L p .707 .577 .707 r
F P
0 g
s
.46014 .57951 m .46091 .52345 L .48197 .52939 L p .707 .577 .707 r
F P
0 g
s
.30099 .64746 m .29936 .61175 L .31565 .60095 L p .707 .577 .707 r
F P
0 g
s
.49525 .6573 m .49711 .67394 L .48423 .66058 L p .707 .577 .707 r
F P
0 g
s
.48423 .66058 m .48237 .64394 L .49525 .6573 L p .707 .577 .707 r
F P
0 g
s
.3021 .66839 m .30396 .68503 L .29728 .70104 L p .707 .577 .707 r
F P
0 g
s
.31625 .58073 m .31703 .52466 L .34107 .52001 L p .707 .577 .707 r
F P
0 g
s
.48049 .59835 m .48212 .63407 L .46103 .62604 L p .707 .577 .707 r
F P
0 g
s
.46103 .62604 m .4594 .59032 L .48049 .59835 L p .707 .577 .707 r
F P
0 g
s
.31565 .60095 m .31729 .63667 L .30099 .64746 L p .707 .577 .707 r
F P
0 g
s
.46091 .52345 m .46014 .57951 L .43268 .5753 L p .707 .577 .707 r
F P
0 g
s
.43268 .5753 m .43345 .51923 L .46091 .52345 L p .707 .577 .707 r
F P
0 g
s
.34107 .52001 m .3403 .57608 L .31625 .58073 L p .707 .577 .707 r
F P
0 g
s
.30396 .68503 m .3021 .66839 L .31807 .65337 L p .707 .577 .707 r
F P
0 g
s
.31729 .63667 m .31565 .60095 L .33964 .59221 L p .707 .577 .707 r
F P
0 g
s
.3403 .57608 m .34107 .52001 L .37045 .51742 L p .707 .577 .707 r
F P
0 g
s
.48237 .64394 m .48423 .66058 L .46299 .65061 L p .707 .577 .707 r
F P
0 g
s
.46299 .65061 m .46113 .63397 L .48237 .64394 L p .707 .577 .707 r
F P
0 g
s
.31807 .65337 m .31993 .67002 L .30396 .68503 L p .707 .577 .707 r
F P
0 g
s
.4594 .59032 m .46103 .62604 L .43356 .6211 L p .707 .577 .707 r
F P
0 g
s
.43356 .6211 m .43193 .58539 L .4594 .59032 L p .707 .577 .707 r
F P
0 g
s
.43345 .51923 m .43268 .5753 L .40151 .57322 L p .707 .577 .707 r
F P
0 g
s
.40151 .57322 m .40228 .51715 L .43345 .51923 L p .707 .577 .707 r
F P
0 g
s
.33964 .59221 m .34127 .62793 L .31729 .63667 L p .707 .577 .707 r
F P
0 g
s
.36967 .57349 m .37045 .51742 L .40228 .51715 L p .707 .577 .707 r
F P
0 g
s
.37045 .51742 m .36967 .57349 L .3403 .57608 L p .707 .577 .707 r
F P
0 g
s
.40228 .51715 m .40151 .57322 L .36967 .57349 L p .707 .577 .707 r
F P
0 g
s
.34127 .62793 m .33964 .59221 L .36896 .58638 L p .707 .577 .707 r
F P
0 g
s
.31993 .67002 m .31807 .65337 L .34176 .64083 L p .707 .577 .707 r
F P
0 g
s
.43193 .58539 m .43356 .6211 L .4024 .61975 L p .707 .577 .707 r
F P
0 g
s
.4024 .61975 m .40077 .58403 L .43193 .58539 L p .707 .577 .707 r
F P
0 g
s
.46113 .63397 m .46299 .65061 L .43547 .64501 L p .707 .577 .707 r
F P
0 g
s
.43547 .64501 m .43361 .62837 L .46113 .63397 L p .707 .577 .707 r
F P
0 g
s
.34176 .64083 m .34362 .65747 L .31993 .67002 L p .707 .577 .707 r
F P
0 g
s
.3706 .6221 m .36896 .58638 L .40077 .58403 L p .707 .577 .707 r
F P
0 g
s
.36896 .58638 m .3706 .6221 L .34127 .62793 L p .707 .577 .707 r
F P
0 g
s
.40077 .58403 m .4024 .61975 L .3706 .6221 L p .707 .577 .707 r
F P
0 g
s
.34362 .65747 m .34176 .64083 L .37085 .63197 L p .707 .577 .707 r
F P
0 g
s
.43361 .62837 m .43547 .64501 L .40436 .64432 L p .707 .577 .707 r
F P
0 g
s
.40436 .64432 m .4025 .62768 L .43361 .62837 L p .707 .577 .707 r
F P
0 g
s
.37085 .63197 m .37271 .64861 L .34362 .65747 L p .707 .577 .707 r
F P
0 g
s
.37271 .64861 m .37085 .63197 L .4025 .62768 L p .707 .577 .707 r
F P
0 g
s
.4025 .62768 m .40436 .64432 L .37271 .64861 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00Kgoo100015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qoo`00IWoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YFFUIJ
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005moob0000EJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00G7oo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00FGoo0`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001GOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P003goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo20000eYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH003Moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00
Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool005=oo`03001J
EP0000=JEP03001JEUYF00=JEQl000AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00Dgoo00<005YF00000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUH0000F00000eYF001J
EP05FUH30003FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF00=J
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00
FUIJEP0200000eYF00000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF
00=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00=JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YFFUIJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080
00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YF000000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Agoo2@0017oo00<005YFFUH00`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`l000AJEP03001JEUYF009JEPP0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF200015YF00<005YF
FUH00eYF00<005YFFUH00P00;Woo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEQD000IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF3`000eYF00<005YFFUH00eYF10000UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH00`00FUIJEP07FUH20003FUH40002FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEP00FUH00P0000=JEP00FUH015YF00<005YFFUH01EYF200015YF00<005YFFUH01UYF
00<005YF00000`001UYF00<005YFFUH01000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH4
00001EYF001JEUYF00001EYF3`0015YF100015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF00001@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@005YFFUIJEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00@005YFFUIJEP80009JEP04001JEUYF0002FUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030004FUH3000015YF001JEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0`00;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH01000FUH0000015YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000AJEP00FUIJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH20006FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300001UYF000005YF001JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0002FUH200000eYF001JEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000UYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJ
EP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00FUH005YF1@000eYF00<005YF
FUH015YF1P0000=JEP00FUH025YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF008000EJEP03001JEUYF00@00003
FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00T000AJEP05001JEP00FUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH01000FUH000001UYF0`0000=JEP0000000UYF00<005YFFUH0
0eYF00@005YFFUIJEPT000=JEP03001JEUYF00=JEP<00004FUH005YFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0003FUH20002FUH20000
0eYF001JEP03FUH20002FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF
00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH50002FUH01000FUIJ
EP000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00@000Qoo`L000Qoo`H000AJEP03001JEUYF
008002ioo`00;7oo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP@0009JEP03001oogoo00=oo`@0009J
EP03001JEUYF009JEPP000Ioo`<00003FUH005YF009JEP03001oogoo02aoo`00;7oo00@005YF001J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEQ0000AJEP04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF00000004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YFFUIJ
EP00FUH40002FUH01P00FUIJEUYF001oo`@000IJEP03001JEUYF00IJEP04001JEUYFFUH50004Ool2
0003FUH00`00Oomoo`0/Ool002aoo`03001JEP00008000EJEP03001JEUYF00EJEPP000AJEP03001J
EUYF00IJEP<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF0`000goo0P000UYF00<007ooOol0;7oo
000/Ool20002FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUH0009JEP03001JEUYF009JEP<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0009JEP<002ioo`00;7oo
0P000UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00@005YF
FUIJEP8000IJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF0`000eYF00<005YFFUH00`0025YF00<005YFFUH00UYF3`001UYF00@005YFFUIJEP800004
FUH005YF000^Ool002aoo`80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF1@00
15YF00<005YFFUH01UYF00H005YF000005YF0005FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P000UYF0`000UYF00<005YFFUH0
1EYF1P003goo10000UYF00<005YFFUH00UYF0`0000=JEP00Ool0;Goo000]Ool01@00FUIJEP00FUH0
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP800003
FUH005YF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00AJEP@000=JEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YF00000P001EYF00<005YFFUH00UYF0P005Goo1`0015YF00D005YF001JEP0002ioo`00
;Woo1@001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YF000010000eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010001eYF00<005YFFUH00UYF0P00
0UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH0
0`00FUH00007FUH00`00FUH00002000COol40002FUH00`00FUIJEP02FUH20003FUH01000FUH00000
;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0005FUH00`00FUIJEP03FUHI000;FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001eYF20002Goo1`001UYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0002ioo`00;Woo00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP0000EJEP8000=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001oogoo02aoo`00;Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YF
FUIJEP00009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHF00000eYF000000020002FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP05001JEUYF001oo`03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPH0
01Ioo`05001JEUYF001oo`040004FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH20003FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=oo`8002eoo`00;7oo00<005YF000015YF
00@005YFFUIJEP80011oo`L000Eoo`03001JEUYF00<000=oo`<00004FUH005YFFUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool2000]
Ool002aoo`03001JEP0000AJEP04001JEP00000>Ool40002FUH00`00FUIJEP02FUH7000015YF001J
EUYF0P0017oo0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEP800003
FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YF100015YF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF
00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00004FUH2000<Ool40006FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP<0009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00MJEP@000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF1@0015YF00<0
05YFFUH015YF0`002Woo00<005YF0000;Goo000/Ool00`00FUH00002FUH2000:Ool400000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF00001P000UYF00<005YFFUH00eYF
00<005YFFUH00UYF1P001eYF00<005YFFUH00P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP@000AJEPH000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00@0
00eoo`03001JEP0002eoo`00;7oo00<005YF00000P002Goo0`001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
0`0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP@000AJEP03001JEUYF00=JEPT000AJEP@00003FUH0000000D0011oo`800003FUH007oo02aoo`00
;7oo00@005YF001JEP<000Eoo`<000MJEP03001JEUYF009JEPl000AJEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH40004FUH00`00FUIJEP03FUH0
1000FUIJEP001Goo2@005Goo0P0000=JEP000000;Woo000/Ool20002FUH00`00FUIJEP0200000goo
00000002FUH00`00FUIJEP04FUH6000?Ool40002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00@005YFFUH0029oo`04001JEUYFFUH2
000^Ool002aoo`80009JEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH2000BOol400000eYF001J
EP0300000eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005FUH=000;FUH90008
FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH00P0087oo00<0
05YFFUH00UYF00<007ooOol0;Goo000/Ool20002FUH01000FUIJEP001UYF00<005YF00005P001EYF
00<005YFFUH00UYF0P000eYF2@0015YF00<005YFFUH010000UYF2@002eYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF008001ioo`<000AJEP03001oogoo02eoo`00;7oo0P000UYF00@005YF000000IJ
EP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800004
FUH005YFFUH20002FUH00`00FUH000060003FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUIJEP050005FUH00`00FUIJ
EP02000MOol01000FUIJEP000eYF00<007ooOol0;Woo000/Ool20002FUH200000eYF001JEP03FUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
00000UYF0P000UYF00<005YFFUH00eYF00<005YF000010002UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00D005YFFUIJEP0000=o
o`8000=JEP05001JEUYFFUH0000KOol20004FUH00`00FUH0000aOol002eoo`03001JEP0000=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP06001JEUYFFUH005YF0P000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF100015YF00@005YFFUIJEP<000=o
o`800003FUH005YF009JEP03001oogoo01Ioo`<000IJEP80039oo`00;Goo0P0015YF10001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00`0000EJ
EP00FUIJEP0000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEP0000QJEP04001JEUYFFUH20003FUH01000FUIJEP000UYF0P000goo0P000eYF
00<007ooOol04Woo10000UYF00<005YFFUH00eYF0P00<goo000^Ool00`00FUIJEP02FUH01@00FUIJ
EUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
0goo0P000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00=JEPH0
009JEP03001oogoo00]oo`L000IJEP04001JEUYFFUH2000eOol002eoo`8000=JEP03001JEUYF009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Ioo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00AJEPH000EJEP04001JEUYFFUHA
0004FUH00`00FUIJEP06FUH01000FUH00000=goo000]Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001goo0P0000=J
EP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF008000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00<005YFFUH0
0P000Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF10002Woo0`00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P000UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?7oo000/Ool01000FUIJEP001Woo1@00
0eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000X000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008003ioo`00;7oo00<005YF000037oo200015YF30004Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF0P0000=JEP0000000P000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P00@Goo000/Ool00`00FUH0000DOol9000GOol200000eYF00000004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP<00003FUH005YF010004Moo`00;Goo
00<007ooOol067oo0`005goo00@005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00009JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomoo`1COol002eoo`03001oogoo
035oo`04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0005Eoo`00;Goo0P00<Goo00<005YFFUH00UYF00<007oo000015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo000]Ool00`00FUH0000^Ool30004FUH00`00Oomoo`020002FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH30002Ool3001DOol002ioo`03001JEP0002]oo`80
009JEP05001JEUYFFUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH20005Ool2
001DOol002ioo`04001JEUYF000XOol20004FUH01000FUH0000027oo0P001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
1UYF00@005YFFUIJEP8000Moo`8005Aoo`00;Woo00<005YFFUH00`0097oo0P001UYF0P0037oo0`00
15YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0`000eYF00<005YFFUH01EYF00@005YF000000Uoo`8005Aoo`00;goo00<005YF00000UYF0P00
7Woo100000=JEP00FUH01EYF00<007ooOol03Woo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001EYF00<005YFFUH00UYF1@002Woo00<005YF
0000E7oo000`Ool00`00FUH00003FUH5000BOol70005FUH00`00FUIJEP02FUH2000DOol40008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH500000eYF0000000<000?Ool00`00FUH0
001DOol0035oo`8000AJEP04001JEUYFFUHB0004FUH00`00FUIJEP06FUH01000FUH000006Woo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEQ4001Moo`800003FUH007oo05=oo`00
<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
8Woo20001UYF00<005YFFUH015YF2P0037oo1@005Woo00@005YF000005Eoo`00=7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo3@005goo0`005Woo
00<005YFFUH00P00EGoo000gOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002
000iOol2000aOol01@00FUIJEUYF0000EWoo000jOol400000eYF001JEP07FUH00`00FUIJEP02FUH6
000lOol00`00FUH0000_Ool00`00FUIJEP02FUH00`00Oomoo`1DOol003ioo`l0049oo`04001JEUYF
000/Ool30003FUH00`00Oomoo`1EOol008moo`05001JEUYFFUH0000YOol20002FUH01000FUIJEP00
F7oo002?Ool01000FUIJEUYF0`0097oo0`001EYF0P00FGoo002@Ool01000FUIJEP000UYF0P007goo
0`0000=JEP00FUH01EYF00<007ooOol0F7oo002AOol00`00FUH00004FUH3000IOol30004FUH00`00
FUIJEP02FUH2001KOol0099oo`8000EJEP03001JEP0000<000moo`H000MJEP03001JEUYF008005eo
o`00Tgoo00<005YFFUH00eYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF0`00Ggoo002DOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2001QOol0
09Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00
V7oo1@0015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Igoo002MOol90004FUH00`00FUIJEP04
001/Ool00:Ioo`L0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5924 .74269 m .59366 .68636 L .56249 .68418 L p .707 .577 .707 r
F P
0 g
s
.59366 .68636 m .5924 .74269 L .62423 .74274 L p .707 .577 .707 r
F P
0 g
s
.62423 .74274 m .62548 .68641 L .59366 .68636 L p .707 .577 .707 r
F P
0 g
s
.62548 .68641 m .62423 .74274 L .6536 .74064 L p .707 .577 .707 r
F P
0 g
s
.6536 .74064 m .65485 .68431 L .62548 .68641 L p .707 .577 .707 r
F P
0 g
s
.56123 .74051 m .56249 .68418 L .53503 .68007 L p .707 .577 .707 r
F P
0 g
s
.56249 .68418 m .56123 .74051 L .5924 .74269 L p .707 .577 .707 r
F P
0 g
s
.65485 .68431 m .6536 .74064 L .67763 .73661 L p .707 .577 .707 r
F P
0 g
s
.67763 .73661 m .67889 .68028 L .65485 .68431 L p .707 .577 .707 r
F P
0 g
s
.53503 .68007 m .53377 .7364 L .56123 .74051 L p .707 .577 .707 r
F P
0 g
s
.53377 .7364 m .53503 .68007 L .51396 .67444 L p .707 .577 .707 r
F P
0 g
s
.59474 .8224 m .59211 .78775 L .56097 .78671 L p .707 .577 .707 r
F P
0 g
s
.59211 .78775 m .59474 .8224 L .62649 .81911 L p .707 .577 .707 r
F P
0 g
s
.62649 .81911 m .62385 .78446 L .59211 .78775 L p .707 .577 .707 r
F P
0 g
s
.62385 .78446 m .62649 .81911 L .65572 .81181 L p .707 .577 .707 r
F P
0 g
s
.65572 .81181 m .65309 .77716 L .62385 .78446 L p .707 .577 .707 r
F P
0 g
s
.5636 .82137 m .56097 .78671 L .53348 .78146 L p .707 .577 .707 r
F P
0 g
s
.56097 .78671 m .5636 .82137 L .59474 .8224 L p .707 .577 .707 r
F P
0 g
s
.51396 .67444 m .51271 .73077 L .53377 .7364 L p .707 .577 .707 r
F P
0 g
s
.67889 .68028 m .67763 .73661 L .69398 .73104 L p .707 .577 .707 r
F P
0 g
s
.69398 .73104 m .69523 .67471 L .67889 .68028 L p .707 .577 .707 r
F P
0 g
s
.65309 .77716 m .65572 .81181 L .6796 .80123 L p .707 .577 .707 r
F P
0 g
s
.6796 .80123 m .67696 .76658 L .65309 .77716 L p .707 .577 .707 r
F P
0 g
s
.51271 .73077 m .51396 .67444 L .50136 .66784 L p .707 .577 .707 r
F P
0 g
s
.53611 .81611 m .53348 .78146 L .51233 .77249 L p .707 .577 .707 r
F P
0 g
s
.53348 .78146 m .53611 .81611 L .5636 .82137 L p .707 .577 .707 r
F P
0 g
s
.67696 .76658 m .6796 .80123 L .69576 .78839 L p .707 .577 .707 r
F P
0 g
s
.69576 .78839 m .69313 .75374 L .67696 .76658 L p .707 .577 .707 r
F P
0 g
s
.50136 .66784 m .5001 .72417 L .51271 .73077 L p .707 .577 .707 r
F P
0 g
s
.69523 .67471 m .69398 .73104 L .70104 .72447 L p .707 .577 .707 r
F P
0 g
s
.70104 .72447 m .7023 .66814 L .69523 .67471 L p .707 .577 .707 r
F P
0 g
s
.51233 .77249 m .51497 .80714 L .53611 .81611 L p .707 .577 .707 r
F P
0 g
s
.60213 .88357 m .59918 .86868 L .56817 .86866 L p .707 .577 .707 r
F P
0 g
s
.59918 .86868 m .60213 .88357 L .63349 .87734 L p .707 .577 .707 r
F P
0 g
s
.63349 .87734 m .63053 .86245 L .59918 .86868 L p .707 .577 .707 r
F P
0 g
s
.63053 .86245 m .63349 .87734 L .66212 .86546 L p .707 .577 .707 r
F P
0 g
s
.66212 .86546 m .65916 .85057 L .63053 .86245 L p .707 .577 .707 r
F P
0 g
s
.51497 .80714 m .51233 .77249 L .4996 .76069 L p .707 .577 .707 r
F P
0 g
s
.57113 .88355 m .56817 .86866 L .54055 .86239 L p .707 .577 .707 r
F P
0 g
s
.56817 .86866 m .57113 .88355 L .60213 .88357 L p .707 .577 .707 r
F P
0 g
s
.65916 .85057 m .66212 .86546 L .68522 .8491 L p .707 .577 .707 r
F P
0 g
s
.68522 .8491 m .68227 .83422 L .65916 .85057 L p .707 .577 .707 r
F P
0 g
s
.5001 .72417 m .50136 .66784 L .49844 .66092 L p .707 .577 .707 r
F P
0 g
s
.69313 .75374 m .69576 .78839 L .70265 .77455 L p .707 .577 .707 r
F P
0 g
s
.70265 .77455 m .70001 .7399 L .69313 .75374 L p .707 .577 .707 r
F P
0 g
s
.54055 .86239 m .5435 .87728 L .57113 .88355 L p .707 .577 .707 r
F P
0 g
s
.4996 .76069 m .50223 .79534 L .51497 .80714 L p .707 .577 .707 r
F P
0 g
s
.49844 .66092 m .49719 .71724 L .5001 .72417 L p .707 .577 .707 r
F P
0 g
s
.5435 .87728 m .54055 .86239 L .51901 .85048 L p .707 .577 .707 r
F P
0 g
s
.68227 .83422 m .68522 .8491 L .70054 .82987 L p .707 .577 .707 r
F P
0 g
s
.70054 .82987 m .69759 .81498 L .68227 .83422 L p .707 .577 .707 r
F P
0 g
s
.7023 .66814 m .70104 .72447 L .69813 .71754 L p .707 .577 .707 r
F P
0 g
s
.69813 .71754 m .69938 .66121 L .7023 .66814 L p .707 .577 .707 r
F P
0 g
s
.50223 .79534 m .4996 .76069 L .49652 .74721 L p .707 .577 .707 r
F P
0 g
s
.51901 .85048 m .52196 .86537 L .5435 .87728 L p .707 .577 .707 r
F P
0 g
s
.49724 .8244 m .48621 .33072 L .44221 .32842 L p .707 .577 .707 r
F P
0 g
s
.49719 .71724 m .49844 .66092 L .5055 .65435 L p .707 .577 .707 r
F P
0 g
s
.49652 .74721 m .49915 .78186 L .50223 .79534 L p .707 .577 .707 r
F P
0 g
s
.5055 .65435 m .50425 .71067 L .49719 .71724 L p .707 .577 .707 r
F P
0 g
s
.49915 .78186 m .49652 .74721 L .5034 .73337 L p .707 .577 .707 r
F P
0 g
s
.50862 .84899 m .50567 .8341 L .50183 .81485 L p .717 .584 .705 r
F P
0 g
s
.50425 .71067 m .5055 .65435 L .52185 .64877 L p .707 .577 .707 r
F P
0 g
s
.5034 .73337 m .50603 .76803 L .49915 .78186 L p .707 .577 .707 r
F P
0 g
s
.50183 .81485 m .50478 .82974 L .50862 .84899 L p .717 .584 .705 r
F P
0 g
s
.52185 .64877 m .5206 .7051 L .50425 .71067 L p .707 .577 .707 r
F P
0 g
s
.50603 .76803 m .5034 .73337 L .51957 .72053 L p .707 .577 .707 r
F P
0 g
s
.50478 .82974 m .50183 .81485 L .50786 .79461 L p .707 .577 .707 r
F P
0 g
s
.5206 .7051 m .52185 .64877 L .54589 .64474 L p .707 .577 .707 r
F P
0 g
s
.50786 .79461 m .51081 .8095 L .50478 .82974 L p .707 .577 .707 r
F P
0 g
s
.51957 .72053 m .5222 .75519 L .50603 .76803 L p .707 .577 .707 r
F P
0 g
s
.54589 .64474 m .54463 .70107 L .5206 .7051 L p .707 .577 .707 r
F P
0 g
s
.5222 .75519 m .51957 .72053 L .54344 .70995 L p .707 .577 .707 r
F P
0 g
s
.51081 .8095 m .50786 .79461 L .52318 .77538 L p .707 .577 .707 r
F P
0 g
s
.52318 .77538 m .52613 .79027 L .51081 .8095 L p .707 .577 .707 r
F P
0 g
s
.54344 .70995 m .54607 .7446 L .5222 .75519 L p .707 .577 .707 r
F P
0 g
s
.52613 .79027 m .52318 .77538 L .54629 .75902 L p .707 .577 .707 r
F P
0 g
s
.54629 .75902 m .54924 .77391 L .52613 .79027 L p .707 .577 .707 r
F P
0 g
s
.48621 .33072 m .49724 .8244 L .54217 .82218 L p .707 .577 .707 r
F P
0 g
s
.54217 .82218 m .53115 .32851 L .48621 .33072 L p .707 .577 .707 r
F P
0 g
s
.54463 .70107 m .54589 .64474 L .57526 .64264 L p .707 .577 .707 r
F P
0 g
s
.54607 .7446 m .54344 .70995 L .57268 .70265 L p .707 .577 .707 r
F P
0 g
s
.57526 .64264 m .574 .69897 L .54463 .70107 L p .707 .577 .707 r
F P
0 g
s
.57268 .70265 m .57531 .73731 L .54607 .7446 L p .707 .577 .707 r
F P
0 g
s
.54924 .77391 m .54629 .75902 L .57492 .74714 L p .707 .577 .707 r
F P
0 g
s
.57787 .76203 m .57492 .74714 L .60627 .74091 L p .707 .577 .707 r
F P
0 g
s
.57492 .74714 m .57787 .76203 L .54924 .77391 L p .707 .577 .707 r
F P
0 g
s
.53115 .32851 m .54217 .82218 L .58363 .81567 L p .707 .577 .707 r
F P
0 g
s
.574 .69897 m .57526 .64264 L .60708 .64269 L p .707 .577 .707 r
F P
0 g
s
.60708 .64269 m .60583 .69902 L .574 .69897 L p .707 .577 .707 r
F P
0 g
s
.57531 .73731 m .57268 .70265 L .60442 .69936 L p .707 .577 .707 r
F P
0 g
s
.60442 .69936 m .60705 .73401 L .57531 .73731 L p .707 .577 .707 r
F P
0 g
s
.60627 .74091 m .60922 .7558 L .57787 .76203 L p .707 .577 .707 r
F P
0 g
s
.58363 .81567 m .57261 .322 L .53115 .32851 L p .707 .577 .707 r
F P
0 g
s
.70001 .7399 m .70265 .77455 L .69957 .76108 L p .707 .577 .707 r
F P
0 g
s
.69957 .76108 m .69694 .72642 L .70001 .7399 L p .707 .577 .707 r
F P
0 g
s
.52196 .86537 m .51901 .85048 L .50567 .8341 L p .707 .577 .707 r
F P
0 g
s
.69759 .81498 m .70054 .82987 L .70658 .80963 L p .707 .577 .707 r
F P
0 g
s
.70658 .80963 m .70363 .79474 L .69759 .81498 L p .707 .577 .707 r
F P
0 g
s
.45323 .8221 m .44221 .32842 L .40344 .32184 L p .707 .577 .707 r
F P
0 g
s
.44221 .32842 m .45323 .8221 L .49724 .8244 L p .707 .577 .707 r
F P
0 g
s
.50567 .8341 m .50862 .84899 L .52196 .86537 L p .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .66305 .70565 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63669 .71517 m .63556 .70039 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .6382 .73505 L .60705 .73401 L p .707 .577 .707 r
F P
0 g
s
.60705 .73401 m .60442 .69936 L .63556 .70039 L p .707 .577 .707 r
F P
0 g
s
.63825 .64488 m .637 .70121 L .62607 .70044 L p .707 .577 .707 r
F P
0 g
s
.62607 .70044 m .60583 .69902 L p .61455 .68446 L .707 .577 .707 r
F P
0 g
s
.61455 .68446 m .63825 .64488 L .62607 .70044 L .707 .577 .707 r
F
.6382 .73505 m .63669 .71517 L p .64511 .72687 L F P
0 g
s
.60583 .69902 m .60708 .64269 L .63825 .64488 L p .707 .577 .707 r
F P
0 g
s
.63728 .74093 m .64023 .75582 L .60922 .7558 L p .707 .577 .707 r
F P
0 g
s
.60922 .7558 m .60627 .74091 L .63728 .74093 L p .707 .577 .707 r
F P
0 g
s
.57261 .322 m .58363 .81567 L .61756 .80551 L p .707 .577 .707 r
F P
0 g
s
.61756 .80551 m .60654 .31183 L .57261 .322 L p .707 .577 .707 r
F P
0 g
s
.69938 .66121 m .69813 .71754 L .68552 .71094 L p .707 .577 .707 r
F P
0 g
s
.68552 .71094 m .68678 .65461 L .69938 .66121 L p .707 .577 .707 r
F P
0 g
s
.24939 .70588 m .25065 .64955 L .21948 .64736 L p .707 .577 .707 r
F P
0 g
s
.25065 .64955 m .24939 .70588 L .28122 .70592 L p .707 .577 .707 r
F P
0 g
s
.28122 .70592 m .28247 .64959 L .25065 .64955 L p .707 .577 .707 r
F P
0 g
s
.70363 .79474 m .70658 .80963 L .70274 .79038 L p .717 .584 .705 r
F P
0 g
s
.70274 .79038 m .69978 .77549 L .70363 .79474 L p .717 .584 .705 r
F P
0 g
s
.41447 .81551 m .40344 .32184 L .3737 .31161 L p .707 .577 .707 r
F P
0 g
s
.40344 .32184 m .41447 .81551 L .45323 .8221 L p .707 .577 .707 r
F P
0 g
s
.28247 .64959 m .28122 .70592 L .31059 .70383 L p .707 .577 .707 r
F P
0 g
s
.31059 .70383 m .31184 .6475 L .28247 .64959 L p .707 .577 .707 r
F P
0 g
s
.69694 .72642 m .69957 .76108 L .68683 .74928 L p .707 .577 .707 r
F P
0 g
s
.68683 .74928 m .6842 .71462 L .69694 .72642 L p .707 .577 .707 r
F P
0 g
s
.21822 .70369 m .21948 .64736 L .19202 .64325 L p .707 .577 .707 r
F P
0 g
s
.21948 .64736 m .21822 .70369 L .24939 .70588 L p .707 .577 .707 r
F P
0 g
s
.31184 .6475 m .31059 .70383 L .33462 .6998 L p .707 .577 .707 r
F P
0 g
s
.33462 .6998 m .33588 .64347 L .31184 .6475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60654 .31183 m .61756 .80551 L .64065 .79268 L p .707 .577 .707 r
F P
0 g
s
.66571 .64899 m .66446 .70531 L .637 .70121 L p .707 .577 .707 r
F P
0 g
s
.637 .70121 m .63825 .64488 L .66571 .64899 L p .707 .577 .707 r
F P
0 g
s
.66305 .70565 m .66569 .74031 L .6382 .73505 L p .707 .577 .707 r
F P
0 g
s
.64023 .75582 m .63728 .74093 L .6649 .7472 L p .707 .577 .707 r
F P
0 g
s
.64065 .79268 m .62962 .299 L .60654 .31183 L p .707 .577 .707 r
F P
0 g
s
.19202 .64325 m .19076 .69958 L .21822 .70369 L p .707 .577 .707 r
F P
0 g
s
.68678 .65461 m .68552 .71094 L .66446 .70531 L p .707 .577 .707 r
F P
0 g
s
.66446 .70531 m .66571 .64899 L .68678 .65461 L p .707 .577 .707 r
F P
0 g
s
.19076 .69958 m .19202 .64325 L .17095 .63762 L p .707 .577 .707 r
F P
0 g
s
.25173 .78559 m .2491 .75093 L .21796 .7499 L p .707 .577 .707 r
F P
0 g
s
.2491 .75093 m .25173 .78559 L .28348 .78229 L p .707 .577 .707 r
F P
0 g
s
.28348 .78229 m .28084 .74764 L .2491 .75093 L p .707 .577 .707 r
F P
0 g
s
.69978 .77549 m .70274 .79038 L .68939 .774 L p .707 .577 .707 r
F P
0 g
s
.68939 .774 m .68644 .75911 L .69978 .77549 L p .707 .577 .707 r
F P
0 g
s
.28084 .74764 m .28348 .78229 L .31272 .775 L p .707 .577 .707 r
F P
0 g
s
.31272 .775 m .31008 .74035 L .28084 .74764 L p .707 .577 .707 r
F P
0 g
s
.6842 .71462 m .68683 .74928 L .66569 .74031 L p .707 .577 .707 r
F P
0 g
s
.66569 .74031 m .66305 .70565 L .6842 .71462 L p .707 .577 .707 r
F P
0 g
s
.22059 .78455 m .21796 .7499 L .19047 .74464 L p .707 .577 .707 r
F P
0 g
s
.21796 .7499 m .22059 .78455 L .25173 .78559 L p .707 .577 .707 r
F P
0 g
s
.38473 .80528 m .3737 .31161 L .35591 .29874 L p .707 .577 .707 r
F P
0 g
s
.3737 .31161 m .38473 .80528 L .41447 .81551 L p .707 .577 .707 r
F P
0 g
s
.17095 .63762 m .1697 .69395 L .19076 .69958 L p .707 .577 .707 r
F P
0 g
s
.33588 .64347 m .33462 .6998 L .35097 .69422 L p .707 .577 .707 r
F P
0 g
s
.35097 .69422 m .35223 .63789 L .33588 .64347 L p .707 .577 .707 r
F P
0 g
s
.31008 .74035 m .31272 .775 L .33659 .76441 L p .707 .577 .707 r
F P
0 g
s
.33659 .76441 m .33395 .72976 L .31008 .74035 L p .707 .577 .707 r
F P
0 g
s
.1697 .69395 m .17095 .63762 L .15835 .63102 L p .707 .577 .707 r
F P
0 g
s
.1931 .77929 m .19047 .74464 L .16932 .73567 L p .707 .577 .707 r
F P
0 g
s
.19047 .74464 m .1931 .77929 L .22059 .78455 L p .707 .577 .707 r
F P
0 g
s
.68644 .75911 m .68939 .774 L .66786 .76209 L p .707 .577 .707 r
F P
0 g
s
.66786 .76209 m .6649 .7472 L .68644 .75911 L p .707 .577 .707 r
F P
0 g
s
.6649 .7472 m .66786 .76209 L .64023 .75582 L p .707 .577 .707 r
F P
0 g
s
.62962 .299 m .64065 .79268 L .65062 .77844 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .63959 .28476 L .62962 .299 L p .707 .577 .707 r
F P
0 g
s
.33395 .72976 m .33659 .76441 L .35276 .75157 L p .707 .577 .707 r
F P
0 g
s
.35276 .75157 m .35012 .71692 L .33395 .72976 L p .707 .577 .707 r
F P
0 g
s
.15835 .63102 m .15709 .68735 L .1697 .69395 L p .707 .577 .707 r
F P
0 g
s
.35223 .63789 m .35097 .69422 L .35803 .68765 L p .707 .577 .707 r
F P
0 g
s
.35803 .68765 m .35929 .63132 L .35223 .63789 L p .707 .577 .707 r
F P
0 g
s
.16932 .73567 m .17196 .77033 L .1931 .77929 L p .707 .577 .707 r
F P
0 g
s
.25912 .84676 m .25617 .83187 L .22516 .83185 L p .707 .577 .707 r
F P
0 g
s
.25617 .83187 m .25912 .84676 L .29048 .84052 L p .707 .577 .707 r
F P
0 g
s
.29048 .84052 m .28752 .82563 L .25617 .83187 L p .707 .577 .707 r
F P
0 g
s
.28752 .82563 m .29048 .84052 L .31911 .82865 L p .707 .577 .707 r
F P
0 g
s
.31911 .82865 m .31616 .81376 L .28752 .82563 L p .707 .577 .707 r
F P
0 g
s
.17196 .77033 m .16932 .73567 L .15659 .72387 L p .707 .577 .707 r
F P
0 g
s
.22812 .84674 m .22516 .83185 L .19754 .82558 L p .707 .577 .707 r
F P
0 g
s
.22516 .83185 m .22812 .84674 L .25912 .84676 L p .707 .577 .707 r
F P
0 g
s
.31616 .81376 m .31911 .82865 L .34222 .81229 L p .707 .577 .707 r
F P
0 g
s
.34222 .81229 m .33926 .7974 L .31616 .81376 L p .707 .577 .707 r
F P
0 g
s
.36693 .79242 m .35591 .29874 L .35179 .28449 L p .707 .577 .707 r
F P
0 g
s
.35591 .29874 m .36693 .79242 L .38473 .80528 L p .707 .577 .707 r
F P
0 g
s
.15709 .68735 m .15835 .63102 L .15543 .6241 L p .707 .577 .707 r
F P
0 g
s
.35012 .71692 m .35276 .75157 L .35964 .73774 L p .707 .577 .707 r
F P
0 g
s
.35964 .73774 m .357 .70309 L .35012 .71692 L p .707 .577 .707 r
F P
0 g
s
.19754 .82558 m .20049 .84046 L .22812 .84674 L p .707 .577 .707 r
F P
0 g
s
.15659 .72387 m .15922 .75852 L .17196 .77033 L p .707 .577 .707 r
F P
0 g
s
.15543 .6241 m .15418 .68043 L .15709 .68735 L p .707 .577 .707 r
F P
0 g
s
.20049 .84046 m .19754 .82558 L .176 .81367 L p .707 .577 .707 r
F P
0 g
s
.33926 .7974 m .34222 .81229 L .35754 .79305 L p .707 .577 .707 r
F P
0 g
s
.35754 .79305 m .35458 .77816 L .33926 .7974 L p .707 .577 .707 r
F P
0 g
s
.35929 .63132 m .35803 .68765 L .35512 .68073 L p .707 .577 .707 r
F P
0 g
s
.35512 .68073 m .35637 .6244 L .35929 .63132 L p .707 .577 .707 r
F P
0 g
s
.15922 .75852 m .15659 .72387 L .15351 .71039 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .64865 .77161 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.63959 .28476 m .64558 .55265 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64558 .55265 m .65062 .77844 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64563 .70311 m .63959 .28476 L .64865 .77161 L .707 .577 .707 r
F
.63548 .27051 m .63959 .28476 L p .64563 .70311 L F P
0 g
s
.63548 .27051 m .64651 .76419 L .62871 .75132 L p .707 .577 .707 r
F P
0 g
s
.6368 .67929 m .63943 .71394 L .64441 .71856 L p .707 .577 .707 r
F P
0 g
s
.64651 .76419 m .64467 .68193 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64865 .77161 m .64651 .76419 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64441 .71856 m .65217 .72574 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.64452 .70264 m .6368 .67929 L .64441 .71856 L .707 .577 .707 r
F
.64467 .68193 m .64465 .68093 L p .64467 .68151 L F P
0 g
s
.64467 .68193 m .64467 .68151 L .64563 .70311 L .707 .577 .707 r
F
.64465 .68093 m .63548 .27051 L p .64563 .70311 L F P
0 g
s
.63856 .58336 m .6373 .63968 L .64296 .64264 L p .707 .577 .707 r
F P
0 g
s
.64296 .64264 m .64991 .64628 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64092 .59643 m .63856 .58336 L .64296 .64264 L .707 .577 .707 r
F
.65217 .72574 m .64954 .69109 L .64464 .68655 L p F P
0 g
s
.64464 .68655 m .6368 .67929 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.65217 .72574 m .64464 .68655 L .64452 .70264 L .707 .577 .707 r
F
.64991 .64628 m .65117 .58996 L .64038 .58431 L p F P
0 g
s
.64038 .58431 m .63856 .58336 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64991 .64628 m .64038 .58431 L .64092 .59643 L .707 .577 .707 r
F
.176 .81367 m .17896 .82855 L .20049 .84046 L p F P
0 g
s
.15418 .68043 m .15543 .6241 L .16249 .61753 L p .707 .577 .707 r
F P
0 g
s
.357 .70309 m .35964 .73774 L .35656 .72426 L p .707 .577 .707 r
F P
0 g
s
.35656 .72426 m .35393 .68961 L .357 .70309 L p .707 .577 .707 r
F P
0 g
s
.17896 .82855 m .176 .81367 L .16266 .79728 L p .707 .577 .707 r
F P
0 g
s
.35458 .77816 m .35754 .79305 L .36357 .77282 L p .707 .577 .707 r
F P
0 g
s
.36357 .77282 m .36062 .75793 L .35458 .77816 L p .707 .577 .707 r
F P
0 g
s
.15351 .71039 m .15614 .74505 L .15922 .75852 L p .707 .577 .707 r
F P
0 g
s
.36062 .75793 m .36357 .77282 L .35973 .75357 L p .717 .584 .705 r
F P
0 g
s
.35179 .28449 m .36282 .77817 L .36693 .79242 L p .707 .577 .707 r
F P
0 g
s
.36282 .77817 m .35179 .28449 L .36177 .27025 L p .707 .577 .707 r
F P
0 g
s
.16249 .61753 m .16124 .67386 L .15418 .68043 L p .707 .577 .707 r
F P
0 g
s
.16266 .79728 m .16561 .81217 L .17896 .82855 L p .707 .577 .707 r
F P
0 g
s
.35637 .6244 m .35512 .68073 L .34251 .67413 L p .707 .577 .707 r
F P
0 g
s
.34251 .67413 m .34377 .6178 L .35637 .6244 L p .707 .577 .707 r
F P
0 g
s
.15614 .74505 m .15351 .71039 L .16039 .69656 L p .707 .577 .707 r
F P
0 g
s
.16561 .81217 m .16266 .79728 L .15882 .77803 L p .717 .584 .705 r
F P
0 g
s
.35973 .75357 m .35677 .73868 L .36062 .75793 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16124 .67386 m .16249 .61753 L .17884 .61196 L p .707 .577 .707 r
F P
0 g
s
.35393 .68961 m .35656 .72426 L .34382 .71246 L p .707 .577 .707 r
F P
0 g
s
.34382 .71246 m .34119 .67781 L .35393 .68961 L p .707 .577 .707 r
F P
0 g
s
.62871 .75132 m .61768 .25764 L .63548 .27051 L p .707 .577 .707 r
F P
0 g
s
.16039 .69656 m .16302 .73121 L .15614 .74505 L p .707 .577 .707 r
F P
0 g
s
.15882 .77803 m .16177 .79292 L .16561 .81217 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17884 .61196 m .17759 .66828 L .16124 .67386 L p .707 .577 .707 r
F P
0 g
s
.16302 .73121 m .16039 .69656 L .17656 .68372 L p .707 .577 .707 r
F P
0 g
s
.34377 .6178 m .34251 .67413 L .32145 .6685 L p .707 .577 .707 r
F P
0 g
s
.32145 .6685 m .3227 .61217 L .34377 .6178 L p .707 .577 .707 r
F P
0 g
s
.16177 .79292 m .15882 .77803 L .16485 .7578 L p .707 .577 .707 r
F P
0 g
s
.35677 .73868 m .35973 .75357 L .34638 .73718 L p .707 .577 .707 r
F P
0 g
s
.34638 .73718 m .34343 .7223 L .35677 .73868 L p .707 .577 .707 r
F P
0 g
s
.37279 .76393 m .36177 .27025 L .38485 .25742 L p .707 .577 .707 r
F P
0 g
s
.36177 .27025 m .37279 .76393 L .36282 .77817 L p .707 .577 .707 r
F P
0 g
s
.17759 .66828 m .17884 .61196 L .20288 .60792 L p .707 .577 .707 r
F P
0 g
s
.34119 .67781 m .34382 .71246 L .32268 .70349 L p .707 .577 .707 r
F P
0 g
s
.32268 .70349 m .32004 .66884 L .34119 .67781 L p .707 .577 .707 r
F P
0 g
s
.16485 .7578 m .1678 .77269 L .16177 .79292 L p .707 .577 .707 r
F P
0 g
s
.17656 .68372 m .17919 .71837 L .16302 .73121 L p .707 .577 .707 r
F P
0 g
s
.20288 .60792 m .20162 .66425 L .17759 .66828 L p .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .32004 .66884 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29519 .69823 m .29368 .67836 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29368 .67836 m .29255 .66358 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .29519 .69823 L .26405 .6972 L p .707 .577 .707 r
F P
0 g
s
.26405 .6972 m .26141 .66254 L .29255 .66358 L p .707 .577 .707 r
F P
0 g
s
.29524 .60806 m .29399 .66439 L .28306 .66362 L p .707 .577 .707 r
F P
0 g
s
.28306 .66362 m .26282 .66221 L p .27154 .64764 L .707 .577 .707 r
F P
0 g
s
.27154 .64764 m .29524 .60806 L .28306 .66362 L .707 .577 .707 r
F
.3227 .61217 m .32145 .6685 L .29399 .66439 L p F P
0 g
s
.29399 .66439 m .29524 .60806 L .3227 .61217 L p .707 .577 .707 r
F P
0 g
s
.17919 .71837 m .17656 .68372 L .20043 .67313 L p .707 .577 .707 r
F P
0 g
s
.61768 .25764 m .62871 .75132 L .59897 .74109 L p .707 .577 .707 r
F P
0 g
s
.59897 .74109 m .58795 .24741 L .61768 .25764 L p .707 .577 .707 r
F P
0 g
s
.1678 .77269 m .16485 .7578 L .18017 .73856 L p .707 .577 .707 r
F P
0 g
s
.34343 .7223 m .34638 .73718 L .32485 .72527 L p .707 .577 .707 r
F P
0 g
s
.32485 .72527 m .32189 .71039 L .34343 .7223 L p .707 .577 .707 r
F P
0 g
s
.20162 .66425 m .20288 .60792 L .23225 .60583 L p .707 .577 .707 r
F P
0 g
s
.32004 .66884 m .32268 .70349 L .29519 .69823 L p .707 .577 .707 r
F P
0 g
s
.26282 .66221 m .26407 .60588 L .29524 .60806 L p .707 .577 .707 r
F P
0 g
s
.18017 .73856 m .18312 .75345 L .1678 .77269 L p .707 .577 .707 r
F P
0 g
s
.20043 .67313 m .20306 .70779 L .17919 .71837 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .37279 .76393 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.38981 .47983 m .39587 .7511 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .38485 .25742 L .41878 .24725 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .40399 .57256 L .4278 .65808 L .707 .577 .707 r
F
.42981 .74093 m .41213 .74623 L p .42785 .65823 L F P
0 g
s
.42795 .65767 m .42797 .65868 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42797 .65868 m .42981 .74093 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42981 .74093 m .41878 .24725 L .46024 .24074 L p .707 .577 .707 r
F P
0 g
s
.46024 .24074 m .47127 .73442 L .42981 .74093 L p .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .44729 .65895 L .42929 .66344 L p .707 .577 .707 r
F P
0 g
s
.41213 .74623 m .39587 .7511 L p .42795 .65767 L .707 .577 .707 r
F P
0 g
s
.42929 .66344 m .41805 .66624 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .42929 .66344 L .43385 .67981 L .707 .577 .707 r
F
.41805 .66624 m .42068 .7009 L .43849 .69645 L p F P
0 g
s
.43849 .69645 m .44992 .6936 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.43385 .67981 m .41805 .66624 L .43849 .69645 L .707 .577 .707 r
F
.41878 .24725 m .42795 .65767 L p .4278 .65808 L F P
0 g
s
.40399 .57256 m .41878 .24725 L .4278 .65808 L .707 .577 .707 r
F
.41968 .56511 m .41842 .62144 L .43462 .62028 L p F P
0 g
s
.43462 .62028 m .44779 .61934 L p .43812 .60069 L .707 .577 .707 r
F P
0 g
s
.43812 .60069 m .41968 .56511 L .43462 .62028 L .707 .577 .707 r
F
.3863 .66954 m .38894 .70419 L .41279 .70172 L p F P
0 g
s
.41279 .70172 m .42068 .7009 L p .41187 .69286 L .707 .577 .707 r
F P
0 g
s
.41187 .69286 m .3863 .66954 L .41279 .70172 L .707 .577 .707 r
F
.38485 .25742 m .38981 .47983 L p .38147 .39925 L F P
0 g
s
.20306 .70779 m .20043 .67313 L .22967 .66584 L p .707 .577 .707 r
F P
0 g
s
.23225 .60583 m .23099 .66216 L .20162 .66425 L p .707 .577 .707 r
F P
0 g
s
.23099 .66216 m .23225 .60583 L .26407 .60588 L p .707 .577 .707 r
F P
0 g
s
.26407 .60588 m .26282 .66221 L .23099 .66216 L p .707 .577 .707 r
F P
0 g
s
.72961 .65821 m .73086 .60188 L .69969 .59969 L p .707 .577 .707 r
F P
0 g
s
.73086 .60188 m .72961 .65821 L .76143 .65825 L p .707 .577 .707 r
F P
0 g
s
.76143 .65825 m .76269 .60193 L .73086 .60188 L p .707 .577 .707 r
F P
0 g
s
.18312 .75345 m .18017 .73856 L .20328 .7222 L p .707 .577 .707 r
F P
0 g
s
.32189 .71039 m .32485 .72527 L .29722 .719 L p .707 .577 .707 r
F P
0 g
s
.29722 .719 m .29427 .70411 L .32189 .71039 L p .707 .577 .707 r
F P
0 g
s
.76269 .60193 m .76143 .65825 L .7908 .65616 L p .707 .577 .707 r
F P
0 g
s
.7908 .65616 m .79206 .59983 L .76269 .60193 L p .707 .577 .707 r
F P
0 g
s
.2323 .70049 m .22967 .66584 L .26141 .66254 L p .707 .577 .707 r
F P
0 g
s
.22967 .66584 m .2323 .70049 L .20306 .70779 L p .707 .577 .707 r
F P
0 g
s
.69844 .65602 m .69969 .59969 L .67223 .59559 L p .707 .577 .707 r
F P
0 g
s
.69969 .59969 m .69844 .65602 L .72961 .65821 L p .707 .577 .707 r
F P
0 g
s
.26141 .66254 m .26405 .6972 L .2323 .70049 L p .707 .577 .707 r
F P
0 g
s
.58795 .24741 m .59897 .74109 L .5602 .73451 L p .707 .577 .707 r
F P
0 g
s
.5602 .73451 m .54918 .24083 L .58795 .24741 L p .707 .577 .707 r
F P
0 g
s
.20328 .7222 m .20623 .73709 L .18312 .75345 L p .707 .577 .707 r
F P
0 g
s
.79206 .59983 m .7908 .65616 L .81484 .65213 L p .707 .577 .707 r
F P
0 g
s
.81484 .65213 m .81609 .5958 L .79206 .59983 L p .707 .577 .707 r
F P
0 g
s
.20623 .73709 m .20328 .7222 L .23191 .71033 L p .707 .577 .707 r
F P
0 g
s
.29427 .70411 m .29722 .719 L .26622 .71898 L p .707 .577 .707 r
F P
0 g
s
.26622 .71898 m .26326 .70409 L .29427 .70411 L p .707 .577 .707 r
F P
0 g
s
.67223 .59559 m .67098 .65191 L .69844 .65602 L p .707 .577 .707 r
F P
0 g
s
.67098 .65191 m .67223 .59559 L .65117 .58996 L p .707 .577 .707 r
F P
0 g
s
.23486 .72522 m .23191 .71033 L .26326 .70409 L p .707 .577 .707 r
F P
0 g
s
.23191 .71033 m .23486 .72522 L .20623 .73709 L p .707 .577 .707 r
F P
0 g
s
.26326 .70409 m .26622 .71898 L .23486 .72522 L p .707 .577 .707 r
F P
0 g
s
.73195 .741 m .72931 .70635 L .69817 .70532 L p .707 .577 .707 r
F P
0 g
s
.72931 .70635 m .73195 .741 L .76369 .73771 L p .707 .577 .707 r
F P
0 g
s
.76369 .73771 m .76106 .70306 L .72931 .70635 L p .707 .577 .707 r
F P
0 g
s
.76106 .70306 m .76369 .73771 L .79293 .73042 L p .707 .577 .707 r
F P
0 g
s
.79293 .73042 m .7903 .69576 L .76106 .70306 L p .707 .577 .707 r
F P
0 g
s
.70081 .73997 m .69817 .70532 L .67068 .70006 L p .707 .577 .707 r
F P
0 g
s
.69817 .70532 m .70081 .73997 L .73195 .741 L p .707 .577 .707 r
F P
0 g
s
.54918 .24083 m .5602 .73451 L .5162 .73221 L p .707 .577 .707 r
F P
0 g
s
.5162 .73221 m .50517 .23853 L .54918 .24083 L p .707 .577 .707 r
F P
0 g
s
.65117 .58996 m .64991 .64628 L .67098 .65191 L p .707 .577 .707 r
F P
0 g
s
.81609 .5958 m .81484 .65213 L .83119 .64655 L p .707 .577 .707 r
F P
0 g
s
.83119 .64655 m .83244 .59023 L .81609 .5958 L p .707 .577 .707 r
F P
0 g
s
.7903 .69576 m .79293 .73042 L .8168 .71983 L p .707 .577 .707 r
F P
0 g
s
.8168 .71983 m .81417 .68518 L .7903 .69576 L p .707 .577 .707 r
F P
0 g
s
.44729 .65895 m .44992 .6936 L .4533 .6921 L p .707 .577 .707 r
F P
0 g
s
.47127 .73442 m .46664 .52717 L p .50517 .23853 L .707 .577 .707 r
F P
0 g
s
.4533 .6921 m .47379 .68302 L p .45539 .66631 L .707 .577 .707 r
F P
0 g
s
.45539 .66631 m .44729 .65895 L .4533 .6921 L .707 .577 .707 r
F
.46664 .52717 m .46024 .24074 L .48991 .23928 L p F P
0 g
s
.48991 .23928 m .50517 .23853 L p .46664 .52717 L .707 .577 .707 r
F P
0 g
s
.50517 .23853 m .5162 .73221 L .47127 .73442 L p .707 .577 .707 r
F P
0 g
s
.67332 .73471 m .67068 .70006 L .64954 .69109 L p .707 .577 .707 r
F P
0 g
s
.67068 .70006 m .67332 .73471 L .70081 .73997 L p .707 .577 .707 r
F P
0 g
s
.81417 .68518 m .8168 .71983 L .83297 .70699 L p .707 .577 .707 r
F P
0 g
s
.83297 .70699 m .83034 .67234 L .81417 .68518 L p .707 .577 .707 r
F P
0 g
s
.83244 .59023 m .83119 .64655 L .83825 .63998 L p .707 .577 .707 r
F P
0 g
s
.83825 .63998 m .8395 .58365 L .83244 .59023 L p .707 .577 .707 r
F P
0 g
s
.73934 .79546 m .73638 .78057 L .70538 .78055 L p .707 .577 .707 r
F P
0 g
s
.73638 .78057 m .73934 .79546 L .77069 .78922 L p .707 .577 .707 r
F P
0 g
s
.77069 .78922 m .76774 .77433 L .73638 .78057 L p .707 .577 .707 r
F P
0 g
s
.76774 .77433 m .77069 .78922 L .79932 .77735 L p .707 .577 .707 r
F P
0 g
s
.79932 .77735 m .79637 .76246 L .76774 .77433 L p .707 .577 .707 r
F P
0 g
s
.64954 .69109 m .65217 .72574 L .67332 .73471 L p .707 .577 .707 r
F P
0 g
s
.70833 .79544 m .70538 .78055 L .67775 .77427 L p .707 .577 .707 r
F P
0 g
s
.70538 .78055 m .70833 .79544 L .73934 .79546 L p .707 .577 .707 r
F P
0 g
s
.79637 .76246 m .79932 .77735 L .82243 .76099 L p .707 .577 .707 r
F P
0 g
s
.82243 .76099 m .81948 .7461 L .79637 .76246 L p .707 .577 .707 r
F P
0 g
s
.6373 .63968 m .63856 .58336 L .63564 .57643 L p .707 .577 .707 r
F P
0 g
s
.83034 .67234 m .83297 .70699 L .83985 .69316 L p .707 .577 .707 r
F P
0 g
s
.83985 .69316 m .83722 .6585 L .83034 .67234 L p .707 .577 .707 r
F P
0 g
s
.67775 .77427 m .68071 .78916 L .70833 .79544 L p .707 .577 .707 r
F P
0 g
s
.68071 .78916 m .67775 .77427 L .65622 .76236 L p .707 .577 .707 r
F P
0 g
s
.81948 .7461 m .82243 .76099 L .83775 .74175 L p .707 .577 .707 r
F P
0 g
s
.83775 .74175 m .8348 .72686 L .81948 .7461 L p .707 .577 .707 r
F P
0 g
s
.63564 .57643 m .63439 .63276 L .6373 .63968 L p .707 .577 .707 r
F P
0 g
s
.8395 .58365 m .83825 .63998 L .83533 .63306 L p .707 .577 .707 r
F P
0 g
s
.83533 .63306 m .83659 .57673 L .8395 .58365 L p .707 .577 .707 r
F P
0 g
s
.63943 .71394 m .6368 .67929 L .63372 .66581 L p .707 .577 .707 r
F P
0 g
s
.65622 .76236 m .65917 .77725 L .68071 .78916 L p .707 .577 .707 r
F P
0 g
s
.63439 .63276 m .63564 .57643 L .64271 .56986 L p .707 .577 .707 r
F P
0 g
s
.65917 .77725 m .65622 .76236 L .64287 .74598 L p .707 .577 .707 r
F P
0 g
s
.8348 .72686 m .83775 .74175 L .84378 .72152 L p .707 .577 .707 r
F P
0 g
s
.84378 .72152 m .84083 .70663 L .8348 .72686 L p .707 .577 .707 r
F P
0 g
s
.83722 .6585 m .83985 .69316 L .83677 .67968 L p .707 .577 .707 r
F P
0 g
s
.83677 .67968 m .83414 .64502 L .83722 .6585 L p .707 .577 .707 r
F P
0 g
s
.63372 .66581 m .63636 .70046 L .63943 .71394 L p .707 .577 .707 r
F P
0 g
s
.64271 .56986 m .64145 .62619 L .63439 .63276 L p .707 .577 .707 r
F P
0 g
s
.64287 .74598 m .64583 .76087 L .65917 .77725 L p .707 .577 .707 r
F P
0 g
s
.83659 .57673 m .83533 .63306 L .82273 .62646 L p .707 .577 .707 r
F P
0 g
s
.82273 .62646 m .82398 .57013 L .83659 .57673 L p .707 .577 .707 r
F P
0 g
s
.63636 .70046 m .63372 .66581 L .6406 .65197 L p .707 .577 .707 r
F P
0 g
s
.64583 .76087 m .64287 .74598 L .63903 .72673 L p .717 .584 .705 r
F P
0 g
s
.84083 .70663 m .84378 .72152 L .83994 .70227 L p .717 .584 .705 r
F P
0 g
s
.83994 .70227 m .83699 .68738 L .84083 .70663 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3866 .62139 m .38785 .56506 L .35668 .56288 L p .707 .577 .707 r
F P
0 g
s
.38785 .56506 m .3866 .62139 L .41842 .62144 L p .707 .577 .707 r
F P
0 g
s
.41842 .62144 m .41968 .56511 L .38785 .56506 L p .707 .577 .707 r
F P
0 g
s
.44779 .61934 m .44905 .56302 L .41968 .56511 L p .707 .577 .707 r
F P
0 g
s
.64145 .62619 m .64271 .56986 L .65906 .56429 L p .707 .577 .707 r
F P
0 g
s
.83414 .64502 m .83677 .67968 L .82404 .66788 L p .707 .577 .707 r
F P
0 g
s
.82404 .66788 m .8214 .63322 L .83414 .64502 L p .707 .577 .707 r
F P
0 g
s
.35543 .61921 m .35668 .56288 L .32922 .55877 L p .707 .577 .707 r
F P
0 g
s
.35668 .56288 m .35543 .61921 L .3866 .62139 L p .707 .577 .707 r
F P
0 g
s
.6406 .65197 m .64324 .68663 L .63636 .70046 L p .707 .577 .707 r
F P
0 g
s
.63903 .72673 m .64198 .74162 L .64583 .76087 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44905 .56302 m .44779 .61934 L .47183 .61531 L p .707 .577 .707 r
F P
0 g
s
.47183 .61531 m .47308 .55898 L .44905 .56302 L p .707 .577 .707 r
F P
0 g
s
.65906 .56429 m .6578 .62062 L .64145 .62619 L p .707 .577 .707 r
F P
0 g
s
.32922 .55877 m .32797 .6151 L .35543 .61921 L p .707 .577 .707 r
F P
0 g
s
.82398 .57013 m .82273 .62646 L .80166 .62083 L p .707 .577 .707 r
F P
0 g
s
.80166 .62083 m .80292 .5645 L .82398 .57013 L p .707 .577 .707 r
F P
0 g
s
.64324 .68663 m .6406 .65197 L .65677 .63914 L p .707 .577 .707 r
F P
0 g
s
.32797 .6151 m .32922 .55877 L .30816 .55314 L p .707 .577 .707 r
F P
0 g
s
.64198 .74162 m .63903 .72673 L .64506 .7065 L p .707 .577 .707 r
F P
0 g
s
.83699 .68738 m .83994 .70227 L .8266 .68588 L p .707 .577 .707 r
F P
0 g
s
.8266 .68588 m .82364 .67099 L .83699 .68738 L p .707 .577 .707 r
F P
0 g
s
.38894 .70419 m .3863 .66954 L .35516 .6685 L p .707 .577 .707 r
F P
0 g
s
.42068 .7009 m .41805 .66624 L .3863 .66954 L p .707 .577 .707 r
F P
0 g
s
.6578 .62062 m .65906 .56429 L .68309 .56026 L p .707 .577 .707 r
F P
0 g
s
.8214 .63322 m .82404 .66788 L .80289 .65891 L p .707 .577 .707 r
F P
0 g
s
.80289 .65891 m .80026 .62425 L .8214 .63322 L p .707 .577 .707 r
F P
0 g
s
.3578 .70316 m .35516 .6685 L .32767 .66324 L p .707 .577 .707 r
F P
0 g
s
.35516 .6685 m .3578 .70316 L .38894 .70419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55314 m .3069 .60947 L .32797 .6151 L p .707 .577 .707 r
F P
0 g
s
.64506 .7065 m .64802 .72139 L .64198 .74162 L p .707 .577 .707 r
F P
0 g
s
.47308 .55898 m .47183 .61531 L .48818 .60974 L p .707 .577 .707 r
F P
0 g
s
.48818 .60974 m .48943 .55341 L .47308 .55898 L p .707 .577 .707 r
F P
0 g
s
.47379 .68302 m .47116 .64836 L .44729 .65895 L p .707 .577 .707 r
F P
0 g
s
.65677 .63914 m .65941 .67379 L .64324 .68663 L p .707 .577 .707 r
F P
0 g
s
.68309 .56026 m .68184 .61658 L .6578 .62062 L p .707 .577 .707 r
F P
0 g
s
.80292 .5645 m .80166 .62083 L .7742 .61672 L p .707 .577 .707 r
F P
0 g
s
.7742 .61672 m .77546 .56039 L .80292 .5645 L p .707 .577 .707 r
F P
0 g
s
.65941 .67379 m .65677 .63914 L .68064 .62855 L p .707 .577 .707 r
F P
0 g
s
.3069 .60947 m .30816 .55314 L .29555 .54654 L p .707 .577 .707 r
F P
0 g
s
.33031 .6979 m .32767 .66324 L .30653 .65427 L p .707 .577 .707 r
F P
0 g
s
.32767 .66324 m .33031 .6979 L .3578 .70316 L p .707 .577 .707 r
F P
0 g
s
.64802 .72139 m .64506 .7065 L .66038 .68726 L p .707 .577 .707 r
F P
0 g
s
.82364 .67099 m .8266 .68588 L .80506 .67397 L p .707 .577 .707 r
F P
0 g
s
.80506 .67397 m .80211 .65908 L .82364 .67099 L p .707 .577 .707 r
F P
0 g
s
.68184 .61658 m .68309 .56026 L .71246 .55816 L p .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .80211 .65908 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77744 .6677 m .77587 .65979 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77587 .65979 m .77448 .65281 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .77744 .6677 L .74643 .66768 L p .707 .577 .707 r
F P
0 g
s
.74643 .66768 m .74348 .65279 L .77448 .65281 L p .707 .577 .707 r
F P
0 g
s
.77277 .619 m .7754 .65365 L .77027 .65348 L p .707 .577 .707 r
F P
0 g
s
.77027 .65348 m .74426 .65262 L p .75659 .63807 L .707 .577 .707 r
F P
0 g
s
.75659 .63807 m .77277 .619 L .77027 .65348 L .707 .577 .707 r
F
.80026 .62425 m .80289 .65891 L .7754 .65365 L p F P
0 g
s
.7754 .65365 m .77277 .619 L .80026 .62425 L p .707 .577 .707 r
F P
0 g
s
.47116 .64836 m .47379 .68302 L .48996 .67018 L p .707 .577 .707 r
F P
0 g
s
.48996 .67018 m .48733 .63552 L .47116 .64836 L p .707 .577 .707 r
F P
0 g
s
.29555 .54654 m .29429 .60287 L .3069 .60947 L p .707 .577 .707 r
F P
0 g
s
.66038 .68726 m .66334 .70215 L .64802 .72139 L p .707 .577 .707 r
F P
0 g
s
.77546 .56039 m .7742 .61672 L .74303 .61454 L p .707 .577 .707 r
F P
0 g
s
.74303 .61454 m .74429 .55821 L .77546 .56039 L p .707 .577 .707 r
F P
0 g
s
.68064 .62855 m .68328 .6632 L .65941 .67379 L p .707 .577 .707 r
F P
0 g
s
.48943 .55341 m .48818 .60974 L .49524 .60317 L p .707 .577 .707 r
F P
0 g
s
.49524 .60317 m .49649 .54684 L .48943 .55341 L p .707 .577 .707 r
F P
0 g
s
.71246 .55816 m .71121 .61449 L .68184 .61658 L p .707 .577 .707 r
F P
0 g
s
.71121 .61449 m .71246 .55816 L .74429 .55821 L p .707 .577 .707 r
F P
0 g
s
.39633 .75864 m .39337 .74375 L .36237 .74373 L p .707 .577 .707 r
F P
0 g
s
.39337 .74375 m .39633 .75864 L .42768 .75241 L p .707 .577 .707 r
F P
0 g
s
.42768 .75241 m .42473 .73752 L .39337 .74375 L p .707 .577 .707 r
F P
0 g
s
.42473 .73752 m .42768 .75241 L .45631 .74053 L p .707 .577 .707 r
F P
0 g
s
.45631 .74053 m .45336 .72564 L .42473 .73752 L p .707 .577 .707 r
F P
0 g
s
.30653 .65427 m .30916 .68893 L .33031 .6979 L p .707 .577 .707 r
F P
0 g
s
.68328 .6632 m .68064 .62855 L .70988 .62125 L p .707 .577 .707 r
F P
0 g
s
.74429 .55821 m .74303 .61454 L .71121 .61449 L p .707 .577 .707 r
F P
0 g
s
.66334 .70215 m .66038 .68726 L .68349 .6709 L p .707 .577 .707 r
F P
0 g
s
.80211 .65908 m .80506 .67397 L .77744 .6677 L p .707 .577 .707 r
F P
0 g
s
.74426 .65262 m .74163 .61796 L .77277 .619 L p .707 .577 .707 r
F P
0 g
s
.30916 .68893 m .30653 .65427 L .29379 .64247 L p .707 .577 .707 r
F P
0 g
s
.36532 .75862 m .36237 .74373 L .33474 .73746 L p .707 .577 .707 r
F P
0 g
s
.36237 .74373 m .36532 .75862 L .39633 .75864 L p .707 .577 .707 r
F P
0 g
s
.45336 .72564 m .45631 .74053 L .47942 .72417 L p .707 .577 .707 r
F P
0 g
s
.47942 .72417 m .47647 .70928 L .45336 .72564 L p .707 .577 .707 r
F P
0 g
s
.29429 .60287 m .29555 .54654 L .29263 .53962 L p .707 .577 .707 r
F P
0 g
s
.71252 .65591 m .70988 .62125 L .74163 .61796 L p .707 .577 .707 r
F P
0 g
s
.70988 .62125 m .71252 .65591 L .68328 .6632 L p .707 .577 .707 r
F P
0 g
s
.74163 .61796 m .74426 .65262 L .71252 .65591 L p .707 .577 .707 r
F P
0 g
s
.68349 .6709 m .68644 .68579 L .66334 .70215 L p .707 .577 .707 r
F P
0 g
s
.48733 .63552 m .48996 .67018 L .49684 .65634 L p .707 .577 .707 r
F P
0 g
s
.49684 .65634 m .49421 .62169 L .48733 .63552 L p .707 .577 .707 r
F P
0 g
s
.68644 .68579 m .68349 .6709 L .71212 .65902 L p .707 .577 .707 r
F P
0 g
s
.33474 .73746 m .3377 .75235 L .36532 .75862 L p .707 .577 .707 r
F P
0 g
s
.29379 .64247 m .29642 .67713 L .30916 .68893 L p .707 .577 .707 r
F P
0 g
s
.3377 .75235 m .33474 .73746 L .31321 .72555 L p .707 .577 .707 r
F P
0 g
s
.47647 .70928 m .47942 .72417 L .49474 .70493 L p .707 .577 .707 r
F P
0 g
s
.49474 .70493 m .49179 .69005 L .47647 .70928 L p .707 .577 .707 r
F P
0 g
s
.29263 .53962 m .29138 .59594 L .29429 .60287 L p .707 .577 .707 r
F P
0 g
s
.71508 .67391 m .71212 .65902 L .74348 .65279 L p .707 .577 .707 r
F P
0 g
s
.71212 .65902 m .71508 .67391 L .68644 .68579 L p .707 .577 .707 r
F P
0 g
s
.74348 .65279 m .74643 .66768 L .71508 .67391 L p .707 .577 .707 r
F P
0 g
s
.49649 .54684 m .49524 .60317 L .49232 .59624 L p .707 .577 .707 r
F P
0 g
s
.49232 .59624 m .49358 .53991 L .49649 .54684 L p .707 .577 .707 r
F P
0 g
s
.29642 .67713 m .29379 .64247 L .29071 .62899 L p .707 .577 .707 r
F P
0 g
s
.31321 .72555 m .31616 .74044 L .3377 .75235 L p .707 .577 .707 r
F P
0 g
s
.29138 .59594 m .29263 .53962 L .2997 .53305 L p .707 .577 .707 r
F P
0 g
s
.31616 .74044 m .31321 .72555 L .29986 .70917 L p .707 .577 .707 r
F P
0 g
s
.49179 .69005 m .49474 .70493 L .50077 .6847 L p .707 .577 .707 r
F P
0 g
s
.50077 .6847 m .49782 .66981 L .49179 .69005 L p .707 .577 .707 r
F P
0 g
s
.49421 .62169 m .49684 .65634 L .49376 .64286 L p .707 .577 .707 r
F P
0 g
s
.49376 .64286 m .49113 .60821 L .49421 .62169 L p .707 .577 .707 r
F P
0 g
s
.29071 .62899 m .29334 .66365 L .29642 .67713 L p .707 .577 .707 r
F P
0 g
s
.2997 .53305 m .29844 .58937 L .29138 .59594 L p .707 .577 .707 r
F P
0 g
s
.29986 .70917 m .30282 .72406 L .31616 .74044 L p .707 .577 .707 r
F P
0 g
s
.49358 .53991 m .49232 .59624 L .47972 .58964 L p .707 .577 .707 r
F P
0 g
s
.47972 .58964 m .48097 .53331 L .49358 .53991 L p .707 .577 .707 r
F P
0 g
s
.29334 .66365 m .29071 .62899 L .29759 .61516 L p .707 .577 .707 r
F P
0 g
s
.30282 .72406 m .29986 .70917 L .29602 .68992 L p .717 .584 .705 r
F P
0 g
s
.49782 .66981 m .50077 .6847 L .49693 .66545 L p .717 .584 .705 r
F P
0 g
s
.49693 .66545 m .49398 .65056 L .49782 .66981 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29844 .58937 m .2997 .53305 L .31605 .52747 L p .707 .577 .707 r
F P
0 g
s
.49113 .60821 m .49376 .64286 L .48103 .63106 L p .707 .577 .707 r
F P
0 g
s
.48103 .63106 m .47839 .59641 L .49113 .60821 L p .707 .577 .707 r
F P
0 g
s
.29759 .61516 m .30023 .64981 L .29334 .66365 L p .707 .577 .707 r
F P
0 g
s
.29602 .68992 m .29897 .70481 L .30282 .72406 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31605 .52747 m .31479 .5838 L .29844 .58937 L p .707 .577 .707 r
F P
0 g
s
.48097 .53331 m .47972 .58964 L .45865 .58401 L p .707 .577 .707 r
F P
0 g
s
.45865 .58401 m .45991 .52769 L .48097 .53331 L p .707 .577 .707 r
F P
0 g
s
.30023 .64981 m .29759 .61516 L .31376 .60232 L p .707 .577 .707 r
F P
0 g
s
.29897 .70481 m .29602 .68992 L .30205 .66968 L p .707 .577 .707 r
F P
0 g
s
.49398 .65056 m .49693 .66545 L .48359 .64907 L p .707 .577 .707 r
F P
0 g
s
.48359 .64907 m .48063 .63418 L .49398 .65056 L p .707 .577 .707 r
F P
0 g
s
.31479 .5838 m .31605 .52747 L .34008 .52344 L p .707 .577 .707 r
F P
0 g
s
.47839 .59641 m .48103 .63106 L .45988 .62209 L p .707 .577 .707 r
F P
0 g
s
.45988 .62209 m .45725 .58744 L .47839 .59641 L p .707 .577 .707 r
F P
0 g
s
.30205 .66968 m .30501 .68457 L .29897 .70481 L p .707 .577 .707 r
F P
0 g
s
.31376 .60232 m .3164 .63697 L .30023 .64981 L p .707 .577 .707 r
F P
0 g
s
.34008 .52344 m .33883 .57977 L .31479 .5838 L p .707 .577 .707 r
F P
0 g
s
.45991 .52769 m .45865 .58401 L .43119 .57991 L p .707 .577 .707 r
F P
0 g
s
.43119 .57991 m .43244 .52358 L .45991 .52769 L p .707 .577 .707 r
F P
0 g
s
.3164 .63697 m .31376 .60232 L .33763 .59173 L p .707 .577 .707 r
F P
0 g
s
.30501 .68457 m .30205 .66968 L .31737 .65044 L p .707 .577 .707 r
F P
0 g
s
.48063 .63418 m .48359 .64907 L .46205 .63716 L p .707 .577 .707 r
F P
0 g
s
.46205 .63716 m .4591 .62227 L .48063 .63418 L p .707 .577 .707 r
F P
0 g
s
.33883 .57977 m .34008 .52344 L .36945 .52135 L p .707 .577 .707 r
F P
0 g
s
.43147 .616 m .4591 .62227 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43443 .63089 m .43286 .62297 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43286 .62297 m .43147 .616 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43147 .616 m .43443 .63089 L .40342 .63086 L p .707 .577 .707 r
F P
0 g
s
.40342 .63086 m .40047 .61598 L .43147 .616 L p .707 .577 .707 r
F P
0 g
s
.42976 .58218 m .43239 .61683 L .42726 .61666 L p .707 .577 .707 r
F P
0 g
s
.42726 .61666 m .40125 .6158 L p .41358 .60126 L .707 .577 .707 r
F P
0 g
s
.41358 .60126 m .42976 .58218 L .42726 .61666 L .707 .577 .707 r
F
.45725 .58744 m .45988 .62209 L .43239 .61683 L p F P
0 g
s
.43239 .61683 m .42976 .58218 L .45725 .58744 L p .707 .577 .707 r
F P
0 g
s
.31737 .65044 m .32033 .66533 L .30501 .68457 L p .707 .577 .707 r
F P
0 g
s
.43244 .52358 m .43119 .57991 L .40002 .57772 L p .707 .577 .707 r
F P
0 g
s
.40002 .57772 m .40128 .52139 L .43244 .52358 L p .707 .577 .707 r
F P
0 g
s
.33763 .59173 m .34027 .62639 L .3164 .63697 L p .707 .577 .707 r
F P
0 g
s
.36945 .52135 m .36819 .57767 L .33883 .57977 L p .707 .577 .707 r
F P
0 g
s
.36819 .57767 m .36945 .52135 L .40128 .52139 L p .707 .577 .707 r
F P
0 g
s
.34027 .62639 m .33763 .59173 L .36687 .58444 L p .707 .577 .707 r
F P
0 g
s
.40128 .52139 m .40002 .57772 L .36819 .57767 L p .707 .577 .707 r
F P
0 g
s
.32033 .66533 m .31737 .65044 L .34048 .63409 L p .707 .577 .707 r
F P
0 g
s
.4591 .62227 m .46205 .63716 L .43443 .63089 L p .707 .577 .707 r
F P
0 g
s
.40125 .6158 m .39862 .58115 L .42976 .58218 L p .707 .577 .707 r
F P
0 g
s
.36951 .61909 m .36687 .58444 L .39862 .58115 L p .707 .577 .707 r
F P
0 g
s
.36687 .58444 m .36951 .61909 L .34027 .62639 L p .707 .577 .707 r
F P
0 g
s
.39862 .58115 m .40125 .6158 L .36951 .61909 L p .707 .577 .707 r
F P
0 g
s
.34048 .63409 m .34343 .64898 L .32033 .66533 L p .707 .577 .707 r
F P
0 g
s
.34343 .64898 m .34048 .63409 L .36911 .62221 L p .707 .577 .707 r
F P
0 g
s
.37207 .6371 m .36911 .62221 L .40047 .61598 L p .707 .577 .707 r
F P
0 g
s
.36911 .62221 m .37207 .6371 L .34343 .64898 L p .707 .577 .707 r
F P
0 g
s
.40047 .61598 m .40342 .63086 L .37207 .6371 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002>Ool80027Ool0081oo`h0
0003FUH005YF00EJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001d
Ool007=oo`<000aJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001b
Ool006moo`@000mJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3
001_Ool006aoo`<001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP8006eoo`00JWoo0P0000=JEP00FUH04eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF0P00K7oo001XOol20003FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000JWoo001VOol20005FUH0
0`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000JGoo001UOol20006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJ
EP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001T
Ool00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo
001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001TOol00`00FUH0
0006FUH00`00FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF01=JEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF
00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00@005YFFUH0
00EJEP8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001WOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP8000UJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YF
FUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF
00000eYF00<005YFFUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF00000eYF00<005YF
FUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0009JEP03001JEUYF008000UJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH3001UOol005mooad000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Fgoo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001HOol30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000?OolA0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool80003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH8000mOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0031oo`00DWoo00<005YF000015YF00<005YF
FUH00eYF7@001UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001B
Ool00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUHC0002FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00<005YF00000UYF10000UYF00<0
05YFFUH01EYF200015YF00<005YFFUH01UYF00<005YF000020000eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP0000<000EJEP03001JEUYF009JEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@0009JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030002FUH40004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF0080
02ioo`00DWoo0P000eYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool0059oo`80
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF0000000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001C
Ool01P00FUIJEUYF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001JEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000hOolN000015YF000000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
=7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUHA0004FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP04001JEUYFFUH90007FUH900000eYF000000060003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@001EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP05FUH00`00FUH000050004FUH00`00FUIJ
EP02FUH800000eYF000000030004FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP060008FUH00`00FUIJEP06FUH20006FUH30003FUH00`00FUIJEP020004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJ
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH500001UYF0000
0000FUH000=JEP8002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF100000=JEP0000000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00UYF
00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF
00<000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
0004FUH000000003FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH20002FUH30005FUH0
0`00FUIJEP04FUH=0006FUH00`00FUIJEP030003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH200000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH200000eYF
0000000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH01000FUH000000eYF0P001eYF00<005YFFUH01`001UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH3
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05
001JEUYFFUIoo`03FUH01000FUIJEP000eYF0`000UYF0`001eYF10000UYF1@001UYF00<005YFFUH0
1EYF0`0015YF1@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP00009JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF00000000;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YF
FUH005YF0002FUH00`00FUIJEP03FUH30006FUH30007FUH00`00FUIJEP08FUH20002FUH01000FUH0
05YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00H005YF000005YF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP04001JEUYFOol4FUH00`00FUIJEP030003FUH20004FUH00`00FUH00003
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000015YF000005YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH01EYF
00<005YFFUH01eYF00<005YFFUH025YF0P000UYF0P0000AJEP00000000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP800004FUH005YFFUH20005FUH20002FUH01@00FUH005YF00001UYF00<005YF
FUH01eYF00<005YFFUH01eYF0`0015YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP03
FUH00`00FUH00002FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF00IJEP03001JEP00
00<0009JEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUH0
00000UYF00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01eYF0P000UYF100015YF00<005YF
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP03001JEUYF00P000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJ
EP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEQd0009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP0300000eYF001JEP05FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00=JEP@00006FUH00000001JEP002EYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YF00000`0000EJEP00FUIJEP0002moo`00:goo00<005YF000015YF00<005YF0000
0`001UYF200015YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00@005YF001JEP@00006FUH00000
001JEP001UYF00<005YFFUH01`001UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00H005YFFUH005YF0004FUH01000FUIJ
EUYF0P000UYF10000eYF00<005YFFUH01EYF30001EYF00@005YFFUIJEP@0009JEP03001oogoo02eo
o`00:goo00<005YF00000UYF10000UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0015YF00@005YFFUH000EJEPl000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00004FUH01000FUH000000eYF0P001eYF00<005YFFUH01`002Goo10000UYF00<005YFFUH0
0UYF0`0000=JEP00Ool0;Woo000[Ool00`00FUH000030005FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH30002FUH30008FUH3
0002Ool5000=Ool30005FUH200000eYF001oo`0^Ool002]oo`8000=JEP03001JEUYF00=JEP<000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH30003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YF
00000UYF00@005YFFUH000IJEP8000Eoo`D0011oo`8000=JEP@002moo`00:goo0P000eYF00@005YF
FUIJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0000000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEP00FUH005YF0P000UYF00<005YF000015YF00@005YFFUIJEP8000Qoo`<001=oo`05001JEUYF
001JEP03000^Ool002]oo`8000=JEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH005YF0`000eYF0P001EYF00<005YF00000P007Woo1@0000AJEP00
000002ioo`00;7oo00@005YFFUIJEP<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJ
EP03001JEUYF00@000EJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH005YF0`000UYF00<005YFFUH01EYF0P0000=JEP00000077oo0P0000EJEP00FUIJ
EP00009JEP8002ioo`00;Goo100000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`000UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF0`000eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP04001JEP000005FUH20003FUH2000JOol20003FUH01P00FUIJ
EUYF001JEP8002ioo`00;Woo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP<000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000002FUH200000eYF001JEP02FUH200000eYF001JEP02FUH2000GOol3
0005FUH00`00FUIJEP02FUH3000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPl000EJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00@000MJEP09001JEUYFFUH005YF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000002FUH20002FUH30003FUH01000FUIJEUYF0P004goo100000=JEP00FUH0
1EYF00<005YFFUH00UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008
FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH90004FUH01000FUIJEUYF2@002UYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEP000002FUH01000FUIJEUYF1`000eYF0P0037oo1`001EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP0Q0004FUH00`00FUIJEP020000
0gooFUIJEP090008FUH00`00FUIJEP08FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF000005YF0003FUH01000FUIJEP000eYF4P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00=JEP@000Eoo`D000AJEP03001JEUYF00IJEP800004FUH000000004Ool30000
0eYF001JEP02FUH01@00OomJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF0000
05YF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP0000AJEP04001JEUYFFUH20007
Ool30008FUH00`00FUIJEP06FUH01000FUH000000UYF0`0017oo0P000eYF00D007ooFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP<0009JEP03001JEUYF00EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00<0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP000Woo00<007ooOol0
;7oo000[Ool01000FUIJEP000eYF00@005YF000000Moo`80009JEP03001JEUYF00MJEP03001JEUYF
00IJEP800003FUH005YF009JEP<000Aoo`05001JEUYF001oo`02FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo00<005YF0000
;Goo000[Ool01000FUIJEP000eYF0P001goo0P001EYF00<005YFFUH015YF3`000eYF00<005YFFUH0
0P000Woo100000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo
00<005YF0000;Goo000[Ool01000FUIJEP000UYF00<007ooOol01Goo0P001eYF00<005YFFUH01P00
2goo00@005YF0000009JEP04001JEUYFFUH200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH01EYF00@005YFFUIJEP8000Ioo`03001JEP0002eoo`00:goo00<005YFFUH00`00
1goo0P001eYF10000Woo1@002goo00<005YF00000`0015YF0`0000=JEP0000000UYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00UYF0P001EYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP04001JEP000008Ool00`00FUH0000]Ool002aoo`03001JEP0000Qoo`03
001JEP0000EJEP8000Ioo`D000]oo`03001JEP0000800003Ool00000009JEP04001JEP00FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF0`002Goo0P0000=JEP00Ool0
;7oo000/Ool200000eYF001oo`04Ool20003FUH00`00FUH000020008Ool5000<Ool20002FUH50000
0eYF00000002FUH01000FUIJEP001UYF00<005YFFUH01eYF0`000eYF00@005YFFUIJEQh000QJEP03
001JEUYF00EJEP05001JEUYF001JEP020004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000;Ool01000FUH00000;Woo000/Ool20002FUH20002Ool00`00FUIJEP03FUH2000<
Ool3000=Ool20004FUH5000015YF001JEP000UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF
0`0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000ioo`05
001JEUYFFUH0000^Ool002aoo`06001JEUYFFUH005YF0P001EYF00<007ooOol06Woo1@0015YF00<0
05YF0000100000AooeYFFUH000IJEP03001JEP0000<0009JEP03001JEUYF00EJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00@000IJEP06001JEUYFFUH005YF1P001EYF00<005YF
00003`005Goo00D005YFFUIJEP0002ioo`00;7oo0P000UYF00@005YF000000AJEP03001oogoo01Mo
o`@0009JEP03001JEUYF0080009JEP03001JEUYF00=JEPd000IJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP06001JEUYFFUH005YF0`000goo
0P000eYF00@005YFFUH0029oo`05001JEUYFFUH0000_Ool002aoo`80009JEP800004FUH005YFFUH6
000?Ool70006FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH300000eYF001JEP02FUH00`00FUH00002FUH30002Ool200001EYF001JEUYF00008Goo00D0
05YFFUIJEP00031oo`00;7oo0P000UYF00@005YFFUIJEP<000EJEPl000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000003FUH30003FUH01000FUH0
00000Woo0P000UYF00<007ooOol07Goo0`000UYF00<007ooOol0;goo000]Ool00`00FUH00004FUH0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP040009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000UYF0`000eYF00@005YFFUIJEP80
009oo`03001JEP0001ioo`04001JEUYF0002FUH00`00Oomoo`0_Ool002eoo`8000AJEP04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0
00000goo3@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00P000UYF00<005YFFUH00UYF1@0077oo
0P0015YF0P00<Woo000^Ool01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo00<005YFFUH00`0000=JEP00FUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P000UYF10001EYF1@006Woo00<005YFFUH015YF00<007ooOol0<Goo000^
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P001Goo0P000UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00005
FUH00000001oo`020003FUH5000HOol30005FUH00`00Oomoo`0bOol002eoo`04001JEP000005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
1goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD0009JEP800006FUH005YFFUH0
05YF0`005Woo0P000UYF00<005YFFUH00UYF00<007ooOol0<goo000]Ool00`00FUH000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUH000002Goo00@005YF
FUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP000UYF1P0000AJEP00FUH0
01Aoo`8000EJEP04001JEP00000fOol002eoo`03001JEP00009oo`<00003FUH005YF00IJEP03001J
EUYF00IJEPD000AJEP03001JEUYF00AJEP<000Yoo`03001JEUYF008000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<000AJEP@0009JEP8000ioo`H000MJEP8003Qoo`00;Goo00<005YF
00001Goo0`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00<005YF00000P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0004FUH01000FUIJEUYF4P0015YF00<0
05YFFUH01EYF0P00>Goo000]Ool20009Ool40002FUH00`00FUIJEP06FUH<000@Ool2000015YF0000
000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUIJEP80009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003]oo`00;Goo0P003Goo40005Woo
00@005YF001JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP800003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003eoo`00;Woo00<007oo
Ool0<Goo00@005YFFUH0009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0006FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40010Ool002ioo`03001oogoo031o
o`05001JEUYFFUH00002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001eYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01000A7oo000^Ool00`00Oomo
o`0_Ool01@00FUIJEUYF000017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH015YF0`000goo3P00B7oo000^Ool2000^Ool30002FUH00`00Oomoo`05Ool30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP020006FUH00`00FUIJEP03FUH20005Ool00`00Oomoo`1COol002ioo`<002aoo`04001JEUYF
0002FUH00`00Oomoo`07Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH40007FUH01000FUIJEUYF0P001Woo00<005YF0000E7oo000_
Ool2000[Ool00`00FUIJEP02FUH2000<Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH01000FUH00000
27oo00<005YF0000E7oo000_Ool00`00FUH0000XOol20005FUH00`00Oomoo`0=Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050005FUH00`00
FUIJEP04FUH3000:Ool00`00FUH0001DOol0031oo`03001JEP0002Eoo`8000EJEP8001=oo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD00003FUH0000000<000AJEP03001J
EUYF00@000eoo`03001JEP0005Aoo`00<7oo00<005YF00000P008Goo0P0000=JEP00FUH00eYF00<0
07ooOol05goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P001UYF300047oo
0P0000=JEP00Ool0Dgoo000aOol20002FUH2000LOol30003FUH01@00FUIJEUYF000087oo2@001UYF
00<005YFFUH015YF6P005Woo00@005YF000005Eoo`00<Goo0P0015YF0`005Goo10001eYF0`00:Woo
3@005Woo0`005Woo00D005YFFUIJEP0005Eoo`00<Woo0P0015YF00<005YF00000`003Goo10000UYF
00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo00D005YFFUIJEP0005Eoo`00=7oo0P000UYF00<0
05YFFUH00eYF3@001UYF00<005YFFUH00eYF0P00=Woo00<007ooOol0<7oo00D005YFFUIJEP0005Io
o`00=Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00>7oo
00<007ooOol0;goo00D005YFFUIJEP0005Moo`00>7oo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF1000>goo0P00;Woo0`000UYF00<007ooOol0EWoo000kOol400000eYF001JEP07FUH00`00FUIJ
EP04000oOol00`00FUH0000/Ool01000FUIJEP000UYF00<007ooOol0EWoo000oOol=0014Ool00`00
FUH0000YOol20004FUH2001IOol0091oo`04001JEUYF000WOol00`00FUIJEP04FUH00`00Oomoo`1H
Ool0095oo`03001JEP00008002=oo`<000EJEP03001oogoo05Uoo`00TWoo0P000UYF00<007ooOol0
7Woo0P000UYF00<005YFFUH00UYF00<007ooOol0FWoo002BOol00`00FUH00002FUH2000LOol20005
FUH01000FUH00000GGoo002COol20004FUH4000BOol60007FUH2001OOol009Aoo`03001JEUYF009J
EP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH2001POol009Eoo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Ugoo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P00I7oo002IOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH4001WOol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@006]oo`00
X7oo3P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5924 .74269 m .59366 .68636 L .56249 .68418 L p .707 .577 .707 r
F P
0 g
s
.59366 .68636 m .5924 .74269 L .62423 .74274 L p .707 .577 .707 r
F P
0 g
s
.62423 .74274 m .62548 .68641 L .59366 .68636 L p .707 .577 .707 r
F P
0 g
s
.62548 .68641 m .62423 .74274 L .6536 .74064 L p .707 .577 .707 r
F P
0 g
s
.6536 .74064 m .65485 .68431 L .62548 .68641 L p .707 .577 .707 r
F P
0 g
s
.56123 .74051 m .56249 .68418 L .53503 .68007 L p .707 .577 .707 r
F P
0 g
s
.56249 .68418 m .56123 .74051 L .5924 .74269 L p .707 .577 .707 r
F P
0 g
s
.65485 .68431 m .6536 .74064 L .67763 .73661 L p .707 .577 .707 r
F P
0 g
s
.67763 .73661 m .67889 .68028 L .65485 .68431 L p .707 .577 .707 r
F P
0 g
s
.53503 .68007 m .53377 .7364 L .56123 .74051 L p .707 .577 .707 r
F P
0 g
s
.53377 .7364 m .53503 .68007 L .51396 .67444 L p .707 .577 .707 r
F P
0 g
s
.59474 .8224 m .59211 .78775 L .56097 .78671 L p .707 .577 .707 r
F P
0 g
s
.59211 .78775 m .59474 .8224 L .62649 .81911 L p .707 .577 .707 r
F P
0 g
s
.62649 .81911 m .62385 .78446 L .59211 .78775 L p .707 .577 .707 r
F P
0 g
s
.62385 .78446 m .62649 .81911 L .65572 .81181 L p .707 .577 .707 r
F P
0 g
s
.65572 .81181 m .65309 .77716 L .62385 .78446 L p .707 .577 .707 r
F P
0 g
s
.5636 .82137 m .56097 .78671 L .53348 .78146 L p .707 .577 .707 r
F P
0 g
s
.56097 .78671 m .5636 .82137 L .59474 .8224 L p .707 .577 .707 r
F P
0 g
s
.51396 .67444 m .51271 .73077 L .53377 .7364 L p .707 .577 .707 r
F P
0 g
s
.67889 .68028 m .67763 .73661 L .69398 .73104 L p .707 .577 .707 r
F P
0 g
s
.69398 .73104 m .69523 .67471 L .67889 .68028 L p .707 .577 .707 r
F P
0 g
s
.65309 .77716 m .65572 .81181 L .6796 .80123 L p .707 .577 .707 r
F P
0 g
s
.6796 .80123 m .67696 .76658 L .65309 .77716 L p .707 .577 .707 r
F P
0 g
s
.51271 .73077 m .51396 .67444 L .50136 .66784 L p .707 .577 .707 r
F P
0 g
s
.53611 .81611 m .53348 .78146 L .51233 .77249 L p .707 .577 .707 r
F P
0 g
s
.53348 .78146 m .53611 .81611 L .5636 .82137 L p .707 .577 .707 r
F P
0 g
s
.67696 .76658 m .6796 .80123 L .69576 .78839 L p .707 .577 .707 r
F P
0 g
s
.69576 .78839 m .69313 .75374 L .67696 .76658 L p .707 .577 .707 r
F P
0 g
s
.50136 .66784 m .5001 .72417 L .51271 .73077 L p .707 .577 .707 r
F P
0 g
s
.69523 .67471 m .69398 .73104 L .70104 .72447 L p .707 .577 .707 r
F P
0 g
s
.70104 .72447 m .7023 .66814 L .69523 .67471 L p .707 .577 .707 r
F P
0 g
s
.51233 .77249 m .51497 .80714 L .53611 .81611 L p .707 .577 .707 r
F P
0 g
s
.60213 .88357 m .59918 .86868 L .56817 .86866 L p .707 .577 .707 r
F P
0 g
s
.59918 .86868 m .60213 .88357 L .63349 .87734 L p .707 .577 .707 r
F P
0 g
s
.63349 .87734 m .63053 .86245 L .59918 .86868 L p .707 .577 .707 r
F P
0 g
s
.63053 .86245 m .63349 .87734 L .66212 .86546 L p .707 .577 .707 r
F P
0 g
s
.66212 .86546 m .65916 .85057 L .63053 .86245 L p .707 .577 .707 r
F P
0 g
s
.51497 .80714 m .51233 .77249 L .4996 .76069 L p .707 .577 .707 r
F P
0 g
s
.57113 .88355 m .56817 .86866 L .54055 .86239 L p .707 .577 .707 r
F P
0 g
s
.56817 .86866 m .57113 .88355 L .60213 .88357 L p .707 .577 .707 r
F P
0 g
s
.65916 .85057 m .66212 .86546 L .68522 .8491 L p .707 .577 .707 r
F P
0 g
s
.68522 .8491 m .68227 .83422 L .65916 .85057 L p .707 .577 .707 r
F P
0 g
s
.5001 .72417 m .50136 .66784 L .49844 .66092 L p .707 .577 .707 r
F P
0 g
s
.69313 .75374 m .69576 .78839 L .70265 .77455 L p .707 .577 .707 r
F P
0 g
s
.70265 .77455 m .70001 .7399 L .69313 .75374 L p .707 .577 .707 r
F P
0 g
s
.54055 .86239 m .5435 .87728 L .57113 .88355 L p .707 .577 .707 r
F P
0 g
s
.4996 .76069 m .50223 .79534 L .51497 .80714 L p .707 .577 .707 r
F P
0 g
s
.49844 .66092 m .49719 .71724 L .5001 .72417 L p .707 .577 .707 r
F P
0 g
s
.5435 .87728 m .54055 .86239 L .51901 .85048 L p .707 .577 .707 r
F P
0 g
s
.68227 .83422 m .68522 .8491 L .70054 .82987 L p .707 .577 .707 r
F P
0 g
s
.70054 .82987 m .69759 .81498 L .68227 .83422 L p .707 .577 .707 r
F P
0 g
s
.7023 .66814 m .70104 .72447 L .69813 .71754 L p .707 .577 .707 r
F P
0 g
s
.69813 .71754 m .69938 .66121 L .7023 .66814 L p .707 .577 .707 r
F P
0 g
s
.50223 .79534 m .4996 .76069 L .49652 .74721 L p .707 .577 .707 r
F P
0 g
s
.51901 .85048 m .52196 .86537 L .5435 .87728 L p .707 .577 .707 r
F P
0 g
s
.49724 .8244 m .48621 .33072 L .44221 .32842 L p .707 .577 .707 r
F P
0 g
s
.49719 .71724 m .49844 .66092 L .5055 .65435 L p .707 .577 .707 r
F P
0 g
s
.49652 .74721 m .49915 .78186 L .50223 .79534 L p .707 .577 .707 r
F P
0 g
s
.5055 .65435 m .50425 .71067 L .49719 .71724 L p .707 .577 .707 r
F P
0 g
s
.49915 .78186 m .49652 .74721 L .5034 .73337 L p .707 .577 .707 r
F P
0 g
s
.50862 .84899 m .50567 .8341 L .50183 .81485 L p .717 .584 .705 r
F P
0 g
s
.50425 .71067 m .5055 .65435 L .52185 .64877 L p .707 .577 .707 r
F P
0 g
s
.5034 .73337 m .50603 .76803 L .49915 .78186 L p .707 .577 .707 r
F P
0 g
s
.50183 .81485 m .50478 .82974 L .50862 .84899 L p .717 .584 .705 r
F P
0 g
s
.52185 .64877 m .5206 .7051 L .50425 .71067 L p .707 .577 .707 r
F P
0 g
s
.50603 .76803 m .5034 .73337 L .51957 .72053 L p .707 .577 .707 r
F P
0 g
s
.50478 .82974 m .50183 .81485 L .50786 .79461 L p .707 .577 .707 r
F P
0 g
s
.5206 .7051 m .52185 .64877 L .54589 .64474 L p .707 .577 .707 r
F P
0 g
s
.50786 .79461 m .51081 .8095 L .50478 .82974 L p .707 .577 .707 r
F P
0 g
s
.51957 .72053 m .5222 .75519 L .50603 .76803 L p .707 .577 .707 r
F P
0 g
s
.54589 .64474 m .54463 .70107 L .5206 .7051 L p .707 .577 .707 r
F P
0 g
s
.5222 .75519 m .51957 .72053 L .54344 .70995 L p .707 .577 .707 r
F P
0 g
s
.51081 .8095 m .50786 .79461 L .52318 .77538 L p .707 .577 .707 r
F P
0 g
s
.52318 .77538 m .52613 .79027 L .51081 .8095 L p .707 .577 .707 r
F P
0 g
s
.54344 .70995 m .54607 .7446 L .5222 .75519 L p .707 .577 .707 r
F P
0 g
s
.52613 .79027 m .52318 .77538 L .54629 .75902 L p .707 .577 .707 r
F P
0 g
s
.54629 .75902 m .54924 .77391 L .52613 .79027 L p .707 .577 .707 r
F P
0 g
s
.48621 .33072 m .49724 .8244 L .54217 .82218 L p .707 .577 .707 r
F P
0 g
s
.54217 .82218 m .53115 .32851 L .48621 .33072 L p .707 .577 .707 r
F P
0 g
s
.54463 .70107 m .54589 .64474 L .57526 .64264 L p .707 .577 .707 r
F P
0 g
s
.54607 .7446 m .54344 .70995 L .57268 .70265 L p .707 .577 .707 r
F P
0 g
s
.57526 .64264 m .574 .69897 L .54463 .70107 L p .707 .577 .707 r
F P
0 g
s
.57268 .70265 m .57531 .73731 L .54607 .7446 L p .707 .577 .707 r
F P
0 g
s
.54924 .77391 m .54629 .75902 L .57492 .74714 L p .707 .577 .707 r
F P
0 g
s
.57787 .76203 m .57492 .74714 L .60627 .74091 L p .707 .577 .707 r
F P
0 g
s
.57492 .74714 m .57787 .76203 L .54924 .77391 L p .707 .577 .707 r
F P
0 g
s
.53115 .32851 m .54217 .82218 L .58363 .81567 L p .707 .577 .707 r
F P
0 g
s
.574 .69897 m .57526 .64264 L .60708 .64269 L p .707 .577 .707 r
F P
0 g
s
.60708 .64269 m .60583 .69902 L .574 .69897 L p .707 .577 .707 r
F P
0 g
s
.57531 .73731 m .57268 .70265 L .60442 .69936 L p .707 .577 .707 r
F P
0 g
s
.60442 .69936 m .60705 .73401 L .57531 .73731 L p .707 .577 .707 r
F P
0 g
s
.60627 .74091 m .60922 .7558 L .57787 .76203 L p .707 .577 .707 r
F P
0 g
s
.58363 .81567 m .57261 .322 L .53115 .32851 L p .707 .577 .707 r
F P
0 g
s
.70001 .7399 m .70265 .77455 L .69957 .76108 L p .707 .577 .707 r
F P
0 g
s
.69957 .76108 m .69694 .72642 L .70001 .7399 L p .707 .577 .707 r
F P
0 g
s
.52196 .86537 m .51901 .85048 L .50567 .8341 L p .707 .577 .707 r
F P
0 g
s
.69759 .81498 m .70054 .82987 L .70658 .80963 L p .707 .577 .707 r
F P
0 g
s
.70658 .80963 m .70363 .79474 L .69759 .81498 L p .707 .577 .707 r
F P
0 g
s
.45323 .8221 m .44221 .32842 L .40344 .32184 L p .707 .577 .707 r
F P
0 g
s
.44221 .32842 m .45323 .8221 L .49724 .8244 L p .707 .577 .707 r
F P
0 g
s
.50567 .8341 m .50862 .84899 L .52196 .86537 L p .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .66305 .70565 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63669 .71517 m .63556 .70039 L p .64511 .72687 L .707 .577 .707 r
F P
0 g
s
.63556 .70039 m .6382 .73505 L .60705 .73401 L p .707 .577 .707 r
F P
0 g
s
.60705 .73401 m .60442 .69936 L .63556 .70039 L p .707 .577 .707 r
F P
0 g
s
.63825 .64488 m .637 .70121 L .62607 .70044 L p .707 .577 .707 r
F P
0 g
s
.62607 .70044 m .60583 .69902 L p .61455 .68446 L .707 .577 .707 r
F P
0 g
s
.61455 .68446 m .63825 .64488 L .62607 .70044 L .707 .577 .707 r
F
.6382 .73505 m .63669 .71517 L p .64511 .72687 L F P
0 g
s
.60583 .69902 m .60708 .64269 L .63825 .64488 L p .707 .577 .707 r
F P
0 g
s
.63728 .74093 m .64023 .75582 L .60922 .7558 L p .707 .577 .707 r
F P
0 g
s
.60922 .7558 m .60627 .74091 L .63728 .74093 L p .707 .577 .707 r
F P
0 g
s
.57261 .322 m .58363 .81567 L .61756 .80551 L p .707 .577 .707 r
F P
0 g
s
.61756 .80551 m .60654 .31183 L .57261 .322 L p .707 .577 .707 r
F P
0 g
s
.69938 .66121 m .69813 .71754 L .68552 .71094 L p .707 .577 .707 r
F P
0 g
s
.68552 .71094 m .68678 .65461 L .69938 .66121 L p .707 .577 .707 r
F P
0 g
s
.24939 .70588 m .25065 .64955 L .21948 .64736 L p .707 .577 .707 r
F P
0 g
s
.25065 .64955 m .24939 .70588 L .28122 .70592 L p .707 .577 .707 r
F P
0 g
s
.28122 .70592 m .28247 .64959 L .25065 .64955 L p .707 .577 .707 r
F P
0 g
s
.70363 .79474 m .70658 .80963 L .70274 .79038 L p .717 .584 .705 r
F P
0 g
s
.70274 .79038 m .69978 .77549 L .70363 .79474 L p .717 .584 .705 r
F P
0 g
s
.41447 .81551 m .40344 .32184 L .3737 .31161 L p .707 .577 .707 r
F P
0 g
s
.40344 .32184 m .41447 .81551 L .45323 .8221 L p .707 .577 .707 r
F P
0 g
s
.28247 .64959 m .28122 .70592 L .31059 .70383 L p .707 .577 .707 r
F P
0 g
s
.31059 .70383 m .31184 .6475 L .28247 .64959 L p .707 .577 .707 r
F P
0 g
s
.69694 .72642 m .69957 .76108 L .68683 .74928 L p .707 .577 .707 r
F P
0 g
s
.68683 .74928 m .6842 .71462 L .69694 .72642 L p .707 .577 .707 r
F P
0 g
s
.21822 .70369 m .21948 .64736 L .19202 .64325 L p .707 .577 .707 r
F P
0 g
s
.21948 .64736 m .21822 .70369 L .24939 .70588 L p .707 .577 .707 r
F P
0 g
s
.31184 .6475 m .31059 .70383 L .33462 .6998 L p .707 .577 .707 r
F P
0 g
s
.33462 .6998 m .33588 .64347 L .31184 .6475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.60654 .31183 m .61756 .80551 L .64065 .79268 L p .707 .577 .707 r
F P
0 g
s
.66571 .64899 m .66446 .70531 L .637 .70121 L p .707 .577 .707 r
F P
0 g
s
.637 .70121 m .63825 .64488 L .66571 .64899 L p .707 .577 .707 r
F P
0 g
s
.66305 .70565 m .66569 .74031 L .6382 .73505 L p .707 .577 .707 r
F P
0 g
s
.64023 .75582 m .63728 .74093 L .6649 .7472 L p .707 .577 .707 r
F P
0 g
s
.64065 .79268 m .62962 .299 L .60654 .31183 L p .707 .577 .707 r
F P
0 g
s
.19202 .64325 m .19076 .69958 L .21822 .70369 L p .707 .577 .707 r
F P
0 g
s
.68678 .65461 m .68552 .71094 L .66446 .70531 L p .707 .577 .707 r
F P
0 g
s
.66446 .70531 m .66571 .64899 L .68678 .65461 L p .707 .577 .707 r
F P
0 g
s
.19076 .69958 m .19202 .64325 L .17095 .63762 L p .707 .577 .707 r
F P
0 g
s
.25173 .78559 m .2491 .75093 L .21796 .7499 L p .707 .577 .707 r
F P
0 g
s
.2491 .75093 m .25173 .78559 L .28348 .78229 L p .707 .577 .707 r
F P
0 g
s
.28348 .78229 m .28084 .74764 L .2491 .75093 L p .707 .577 .707 r
F P
0 g
s
.69978 .77549 m .70274 .79038 L .68939 .774 L p .707 .577 .707 r
F P
0 g
s
.68939 .774 m .68644 .75911 L .69978 .77549 L p .707 .577 .707 r
F P
0 g
s
.28084 .74764 m .28348 .78229 L .31272 .775 L p .707 .577 .707 r
F P
0 g
s
.31272 .775 m .31008 .74035 L .28084 .74764 L p .707 .577 .707 r
F P
0 g
s
.6842 .71462 m .68683 .74928 L .66569 .74031 L p .707 .577 .707 r
F P
0 g
s
.66569 .74031 m .66305 .70565 L .6842 .71462 L p .707 .577 .707 r
F P
0 g
s
.22059 .78455 m .21796 .7499 L .19047 .74464 L p .707 .577 .707 r
F P
0 g
s
.21796 .7499 m .22059 .78455 L .25173 .78559 L p .707 .577 .707 r
F P
0 g
s
.38473 .80528 m .3737 .31161 L .35591 .29874 L p .707 .577 .707 r
F P
0 g
s
.3737 .31161 m .38473 .80528 L .41447 .81551 L p .707 .577 .707 r
F P
0 g
s
.17095 .63762 m .1697 .69395 L .19076 .69958 L p .707 .577 .707 r
F P
0 g
s
.33588 .64347 m .33462 .6998 L .35097 .69422 L p .707 .577 .707 r
F P
0 g
s
.35097 .69422 m .35223 .63789 L .33588 .64347 L p .707 .577 .707 r
F P
0 g
s
.31008 .74035 m .31272 .775 L .33659 .76441 L p .707 .577 .707 r
F P
0 g
s
.33659 .76441 m .33395 .72976 L .31008 .74035 L p .707 .577 .707 r
F P
0 g
s
.1697 .69395 m .17095 .63762 L .15835 .63102 L p .707 .577 .707 r
F P
0 g
s
.1931 .77929 m .19047 .74464 L .16932 .73567 L p .707 .577 .707 r
F P
0 g
s
.19047 .74464 m .1931 .77929 L .22059 .78455 L p .707 .577 .707 r
F P
0 g
s
.68644 .75911 m .68939 .774 L .66786 .76209 L p .707 .577 .707 r
F P
0 g
s
.66786 .76209 m .6649 .7472 L .68644 .75911 L p .707 .577 .707 r
F P
0 g
s
.6649 .7472 m .66786 .76209 L .64023 .75582 L p .707 .577 .707 r
F P
0 g
s
.62962 .299 m .64065 .79268 L .65062 .77844 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .63959 .28476 L .62962 .299 L p .707 .577 .707 r
F P
0 g
s
.33395 .72976 m .33659 .76441 L .35276 .75157 L p .707 .577 .707 r
F P
0 g
s
.35276 .75157 m .35012 .71692 L .33395 .72976 L p .707 .577 .707 r
F P
0 g
s
.15835 .63102 m .15709 .68735 L .1697 .69395 L p .707 .577 .707 r
F P
0 g
s
.35223 .63789 m .35097 .69422 L .35803 .68765 L p .707 .577 .707 r
F P
0 g
s
.35803 .68765 m .35929 .63132 L .35223 .63789 L p .707 .577 .707 r
F P
0 g
s
.16932 .73567 m .17196 .77033 L .1931 .77929 L p .707 .577 .707 r
F P
0 g
s
.25912 .84676 m .25617 .83187 L .22516 .83185 L p .707 .577 .707 r
F P
0 g
s
.25617 .83187 m .25912 .84676 L .29048 .84052 L p .707 .577 .707 r
F P
0 g
s
.29048 .84052 m .28752 .82563 L .25617 .83187 L p .707 .577 .707 r
F P
0 g
s
.28752 .82563 m .29048 .84052 L .31911 .82865 L p .707 .577 .707 r
F P
0 g
s
.31911 .82865 m .31616 .81376 L .28752 .82563 L p .707 .577 .707 r
F P
0 g
s
.17196 .77033 m .16932 .73567 L .15659 .72387 L p .707 .577 .707 r
F P
0 g
s
.22812 .84674 m .22516 .83185 L .19754 .82558 L p .707 .577 .707 r
F P
0 g
s
.22516 .83185 m .22812 .84674 L .25912 .84676 L p .707 .577 .707 r
F P
0 g
s
.31616 .81376 m .31911 .82865 L .34222 .81229 L p .707 .577 .707 r
F P
0 g
s
.34222 .81229 m .33926 .7974 L .31616 .81376 L p .707 .577 .707 r
F P
0 g
s
.36693 .79242 m .35591 .29874 L .35179 .28449 L p .707 .577 .707 r
F P
0 g
s
.35591 .29874 m .36693 .79242 L .38473 .80528 L p .707 .577 .707 r
F P
0 g
s
.15709 .68735 m .15835 .63102 L .15543 .6241 L p .707 .577 .707 r
F P
0 g
s
.35012 .71692 m .35276 .75157 L .35964 .73774 L p .707 .577 .707 r
F P
0 g
s
.35964 .73774 m .357 .70309 L .35012 .71692 L p .707 .577 .707 r
F P
0 g
s
.19754 .82558 m .20049 .84046 L .22812 .84674 L p .707 .577 .707 r
F P
0 g
s
.15659 .72387 m .15922 .75852 L .17196 .77033 L p .707 .577 .707 r
F P
0 g
s
.15543 .6241 m .15418 .68043 L .15709 .68735 L p .707 .577 .707 r
F P
0 g
s
.20049 .84046 m .19754 .82558 L .176 .81367 L p .707 .577 .707 r
F P
0 g
s
.33926 .7974 m .34222 .81229 L .35754 .79305 L p .707 .577 .707 r
F P
0 g
s
.35754 .79305 m .35458 .77816 L .33926 .7974 L p .707 .577 .707 r
F P
0 g
s
.35929 .63132 m .35803 .68765 L .35512 .68073 L p .707 .577 .707 r
F P
0 g
s
.35512 .68073 m .35637 .6244 L .35929 .63132 L p .707 .577 .707 r
F P
0 g
s
.15922 .75852 m .15659 .72387 L .15351 .71039 L p .707 .577 .707 r
F P
0 g
s
.65062 .77844 m .64865 .77161 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.63959 .28476 m .64558 .55265 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64558 .55265 m .65062 .77844 L p .6453 .5917 L .707 .577 .707 r
F P
0 g
s
.64563 .70311 m .63959 .28476 L .64865 .77161 L .707 .577 .707 r
F
.63548 .27051 m .63959 .28476 L p .64563 .70311 L F P
0 g
s
.63548 .27051 m .64651 .76419 L .62871 .75132 L p .707 .577 .707 r
F P
0 g
s
.6368 .67929 m .63943 .71394 L .64441 .71856 L p .707 .577 .707 r
F P
0 g
s
.64651 .76419 m .64467 .68193 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64865 .77161 m .64651 .76419 L p .64563 .70311 L .707 .577 .707 r
F P
0 g
s
.64441 .71856 m .65217 .72574 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.64452 .70264 m .6368 .67929 L .64441 .71856 L .707 .577 .707 r
F
.64467 .68193 m .64465 .68093 L p .64467 .68151 L F P
0 g
s
.64467 .68193 m .64467 .68151 L .64563 .70311 L .707 .577 .707 r
F
.64465 .68093 m .63548 .27051 L p .64563 .70311 L F P
0 g
s
.63856 .58336 m .6373 .63968 L .64296 .64264 L p .707 .577 .707 r
F P
0 g
s
.64296 .64264 m .64991 .64628 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64092 .59643 m .63856 .58336 L .64296 .64264 L .707 .577 .707 r
F
.65217 .72574 m .64954 .69109 L .64464 .68655 L p F P
0 g
s
.64464 .68655 m .6368 .67929 L p .64452 .70264 L .707 .577 .707 r
F P
0 g
s
.65217 .72574 m .64464 .68655 L .64452 .70264 L .707 .577 .707 r
F
.64991 .64628 m .65117 .58996 L .64038 .58431 L p F P
0 g
s
.64038 .58431 m .63856 .58336 L p .64092 .59643 L .707 .577 .707 r
F P
0 g
s
.64991 .64628 m .64038 .58431 L .64092 .59643 L .707 .577 .707 r
F
.176 .81367 m .17896 .82855 L .20049 .84046 L p F P
0 g
s
.15418 .68043 m .15543 .6241 L .16249 .61753 L p .707 .577 .707 r
F P
0 g
s
.357 .70309 m .35964 .73774 L .35656 .72426 L p .707 .577 .707 r
F P
0 g
s
.35656 .72426 m .35393 .68961 L .357 .70309 L p .707 .577 .707 r
F P
0 g
s
.17896 .82855 m .176 .81367 L .16266 .79728 L p .707 .577 .707 r
F P
0 g
s
.35458 .77816 m .35754 .79305 L .36357 .77282 L p .707 .577 .707 r
F P
0 g
s
.36357 .77282 m .36062 .75793 L .35458 .77816 L p .707 .577 .707 r
F P
0 g
s
.15351 .71039 m .15614 .74505 L .15922 .75852 L p .707 .577 .707 r
F P
0 g
s
.36062 .75793 m .36357 .77282 L .35973 .75357 L p .717 .584 .705 r
F P
0 g
s
.35179 .28449 m .36282 .77817 L .36693 .79242 L p .707 .577 .707 r
F P
0 g
s
.36282 .77817 m .35179 .28449 L .36177 .27025 L p .707 .577 .707 r
F P
0 g
s
.16249 .61753 m .16124 .67386 L .15418 .68043 L p .707 .577 .707 r
F P
0 g
s
.16266 .79728 m .16561 .81217 L .17896 .82855 L p .707 .577 .707 r
F P
0 g
s
.35637 .6244 m .35512 .68073 L .34251 .67413 L p .707 .577 .707 r
F P
0 g
s
.34251 .67413 m .34377 .6178 L .35637 .6244 L p .707 .577 .707 r
F P
0 g
s
.15614 .74505 m .15351 .71039 L .16039 .69656 L p .707 .577 .707 r
F P
0 g
s
.16561 .81217 m .16266 .79728 L .15882 .77803 L p .717 .584 .705 r
F P
0 g
s
.35973 .75357 m .35677 .73868 L .36062 .75793 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16124 .67386 m .16249 .61753 L .17884 .61196 L p .707 .577 .707 r
F P
0 g
s
.35393 .68961 m .35656 .72426 L .34382 .71246 L p .707 .577 .707 r
F P
0 g
s
.34382 .71246 m .34119 .67781 L .35393 .68961 L p .707 .577 .707 r
F P
0 g
s
.62871 .75132 m .61768 .25764 L .63548 .27051 L p .707 .577 .707 r
F P
0 g
s
.16039 .69656 m .16302 .73121 L .15614 .74505 L p .707 .577 .707 r
F P
0 g
s
.15882 .77803 m .16177 .79292 L .16561 .81217 L p .717 .584 .705 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17884 .61196 m .17759 .66828 L .16124 .67386 L p .707 .577 .707 r
F P
0 g
s
.16302 .73121 m .16039 .69656 L .17656 .68372 L p .707 .577 .707 r
F P
0 g
s
.34377 .6178 m .34251 .67413 L .32145 .6685 L p .707 .577 .707 r
F P
0 g
s
.32145 .6685 m .3227 .61217 L .34377 .6178 L p .707 .577 .707 r
F P
0 g
s
.16177 .79292 m .15882 .77803 L .16485 .7578 L p .707 .577 .707 r
F P
0 g
s
.35677 .73868 m .35973 .75357 L .34638 .73718 L p .707 .577 .707 r
F P
0 g
s
.34638 .73718 m .34343 .7223 L .35677 .73868 L p .707 .577 .707 r
F P
0 g
s
.37279 .76393 m .36177 .27025 L .38485 .25742 L p .707 .577 .707 r
F P
0 g
s
.36177 .27025 m .37279 .76393 L .36282 .77817 L p .707 .577 .707 r
F P
0 g
s
.17759 .66828 m .17884 .61196 L .20288 .60792 L p .707 .577 .707 r
F P
0 g
s
.34119 .67781 m .34382 .71246 L .32268 .70349 L p .707 .577 .707 r
F P
0 g
s
.32268 .70349 m .32004 .66884 L .34119 .67781 L p .707 .577 .707 r
F P
0 g
s
.16485 .7578 m .1678 .77269 L .16177 .79292 L p .707 .577 .707 r
F P
0 g
s
.17656 .68372 m .17919 .71837 L .16302 .73121 L p .707 .577 .707 r
F P
0 g
s
.20288 .60792 m .20162 .66425 L .17759 .66828 L p .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .32004 .66884 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29519 .69823 m .29368 .67836 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29368 .67836 m .29255 .66358 L p .3021 .69005 L .707 .577 .707 r
F P
0 g
s
.29255 .66358 m .29519 .69823 L .26405 .6972 L p .707 .577 .707 r
F P
0 g
s
.26405 .6972 m .26141 .66254 L .29255 .66358 L p .707 .577 .707 r
F P
0 g
s
.29524 .60806 m .29399 .66439 L .28306 .66362 L p .707 .577 .707 r
F P
0 g
s
.28306 .66362 m .26282 .66221 L p .27154 .64764 L .707 .577 .707 r
F P
0 g
s
.27154 .64764 m .29524 .60806 L .28306 .66362 L .707 .577 .707 r
F
.3227 .61217 m .32145 .6685 L .29399 .66439 L p F P
0 g
s
.29399 .66439 m .29524 .60806 L .3227 .61217 L p .707 .577 .707 r
F P
0 g
s
.17919 .71837 m .17656 .68372 L .20043 .67313 L p .707 .577 .707 r
F P
0 g
s
.61768 .25764 m .62871 .75132 L .59897 .74109 L p .707 .577 .707 r
F P
0 g
s
.59897 .74109 m .58795 .24741 L .61768 .25764 L p .707 .577 .707 r
F P
0 g
s
.1678 .77269 m .16485 .7578 L .18017 .73856 L p .707 .577 .707 r
F P
0 g
s
.34343 .7223 m .34638 .73718 L .32485 .72527 L p .707 .577 .707 r
F P
0 g
s
.32485 .72527 m .32189 .71039 L .34343 .7223 L p .707 .577 .707 r
F P
0 g
s
.20162 .66425 m .20288 .60792 L .23225 .60583 L p .707 .577 .707 r
F P
0 g
s
.32004 .66884 m .32268 .70349 L .29519 .69823 L p .707 .577 .707 r
F P
0 g
s
.26282 .66221 m .26407 .60588 L .29524 .60806 L p .707 .577 .707 r
F P
0 g
s
.18017 .73856 m .18312 .75345 L .1678 .77269 L p .707 .577 .707 r
F P
0 g
s
.20043 .67313 m .20306 .70779 L .17919 .71837 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .37279 .76393 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.38981 .47983 m .39587 .7511 L p .38147 .39925 L .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .38485 .25742 L .41878 .24725 L p .707 .577 .707 r
F P
0 g
s
.39587 .7511 m .40399 .57256 L .4278 .65808 L .707 .577 .707 r
F
.42981 .74093 m .41213 .74623 L p .42785 .65823 L F P
0 g
s
.42795 .65767 m .42797 .65868 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42797 .65868 m .42981 .74093 L p .42785 .65823 L .707 .577 .707 r
F P
0 g
s
.42981 .74093 m .41878 .24725 L .46024 .24074 L p .707 .577 .707 r
F P
0 g
s
.46024 .24074 m .47127 .73442 L .42981 .74093 L p .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .44729 .65895 L .42929 .66344 L p .707 .577 .707 r
F P
0 g
s
.41213 .74623 m .39587 .7511 L p .42795 .65767 L .707 .577 .707 r
F P
0 g
s
.42929 .66344 m .41805 .66624 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.44992 .6936 m .42929 .66344 L .43385 .67981 L .707 .577 .707 r
F
.41805 .66624 m .42068 .7009 L .43849 .69645 L p F P
0 g
s
.43849 .69645 m .44992 .6936 L p .43385 .67981 L .707 .577 .707 r
F P
0 g
s
.43385 .67981 m .41805 .66624 L .43849 .69645 L .707 .577 .707 r
F
.41878 .24725 m .42795 .65767 L p .4278 .65808 L F P
0 g
s
.40399 .57256 m .41878 .24725 L .4278 .65808 L .707 .577 .707 r
F
.41968 .56511 m .41842 .62144 L .43462 .62028 L p F P
0 g
s
.43462 .62028 m .44779 .61934 L p .43812 .60069 L .707 .577 .707 r
F P
0 g
s
.43812 .60069 m .41968 .56511 L .43462 .62028 L .707 .577 .707 r
F
.3863 .66954 m .38894 .70419 L .41279 .70172 L p F P
0 g
s
.41279 .70172 m .42068 .7009 L p .41187 .69286 L .707 .577 .707 r
F P
0 g
s
.41187 .69286 m .3863 .66954 L .41279 .70172 L .707 .577 .707 r
F
.38485 .25742 m .38981 .47983 L p .38147 .39925 L F P
0 g
s
.20306 .70779 m .20043 .67313 L .22967 .66584 L p .707 .577 .707 r
F P
0 g
s
.23225 .60583 m .23099 .66216 L .20162 .66425 L p .707 .577 .707 r
F P
0 g
s
.23099 .66216 m .23225 .60583 L .26407 .60588 L p .707 .577 .707 r
F P
0 g
s
.26407 .60588 m .26282 .66221 L .23099 .66216 L p .707 .577 .707 r
F P
0 g
s
.72961 .65821 m .73086 .60188 L .69969 .59969 L p .707 .577 .707 r
F P
0 g
s
.73086 .60188 m .72961 .65821 L .76143 .65825 L p .707 .577 .707 r
F P
0 g
s
.76143 .65825 m .76269 .60193 L .73086 .60188 L p .707 .577 .707 r
F P
0 g
s
.18312 .75345 m .18017 .73856 L .20328 .7222 L p .707 .577 .707 r
F P
0 g
s
.32189 .71039 m .32485 .72527 L .29722 .719 L p .707 .577 .707 r
F P
0 g
s
.29722 .719 m .29427 .70411 L .32189 .71039 L p .707 .577 .707 r
F P
0 g
s
.76269 .60193 m .76143 .65825 L .7908 .65616 L p .707 .577 .707 r
F P
0 g
s
.7908 .65616 m .79206 .59983 L .76269 .60193 L p .707 .577 .707 r
F P
0 g
s
.2323 .70049 m .22967 .66584 L .26141 .66254 L p .707 .577 .707 r
F P
0 g
s
.22967 .66584 m .2323 .70049 L .20306 .70779 L p .707 .577 .707 r
F P
0 g
s
.69844 .65602 m .69969 .59969 L .67223 .59559 L p .707 .577 .707 r
F P
0 g
s
.69969 .59969 m .69844 .65602 L .72961 .65821 L p .707 .577 .707 r
F P
0 g
s
.26141 .66254 m .26405 .6972 L .2323 .70049 L p .707 .577 .707 r
F P
0 g
s
.58795 .24741 m .59897 .74109 L .5602 .73451 L p .707 .577 .707 r
F P
0 g
s
.5602 .73451 m .54918 .24083 L .58795 .24741 L p .707 .577 .707 r
F P
0 g
s
.20328 .7222 m .20623 .73709 L .18312 .75345 L p .707 .577 .707 r
F P
0 g
s
.79206 .59983 m .7908 .65616 L .81484 .65213 L p .707 .577 .707 r
F P
0 g
s
.81484 .65213 m .81609 .5958 L .79206 .59983 L p .707 .577 .707 r
F P
0 g
s
.20623 .73709 m .20328 .7222 L .23191 .71033 L p .707 .577 .707 r
F P
0 g
s
.29427 .70411 m .29722 .719 L .26622 .71898 L p .707 .577 .707 r
F P
0 g
s
.26622 .71898 m .26326 .70409 L .29427 .70411 L p .707 .577 .707 r
F P
0 g
s
.67223 .59559 m .67098 .65191 L .69844 .65602 L p .707 .577 .707 r
F P
0 g
s
.67098 .65191 m .67223 .59559 L .65117 .58996 L p .707 .577 .707 r
F P
0 g
s
.23486 .72522 m .23191 .71033 L .26326 .70409 L p .707 .577 .707 r
F P
0 g
s
.23191 .71033 m .23486 .72522 L .20623 .73709 L p .707 .577 .707 r
F P
0 g
s
.26326 .70409 m .26622 .71898 L .23486 .72522 L p .707 .577 .707 r
F P
0 g
s
.73195 .741 m .72931 .70635 L .69817 .70532 L p .707 .577 .707 r
F P
0 g
s
.72931 .70635 m .73195 .741 L .76369 .73771 L p .707 .577 .707 r
F P
0 g
s
.76369 .73771 m .76106 .70306 L .72931 .70635 L p .707 .577 .707 r
F P
0 g
s
.76106 .70306 m .76369 .73771 L .79293 .73042 L p .707 .577 .707 r
F P
0 g
s
.79293 .73042 m .7903 .69576 L .76106 .70306 L p .707 .577 .707 r
F P
0 g
s
.70081 .73997 m .69817 .70532 L .67068 .70006 L p .707 .577 .707 r
F P
0 g
s
.69817 .70532 m .70081 .73997 L .73195 .741 L p .707 .577 .707 r
F P
0 g
s
.54918 .24083 m .5602 .73451 L .5162 .73221 L p .707 .577 .707 r
F P
0 g
s
.5162 .73221 m .50517 .23853 L .54918 .24083 L p .707 .577 .707 r
F P
0 g
s
.65117 .58996 m .64991 .64628 L .67098 .65191 L p .707 .577 .707 r
F P
0 g
s
.81609 .5958 m .81484 .65213 L .83119 .64655 L p .707 .577 .707 r
F P
0 g
s
.83119 .64655 m .83244 .59023 L .81609 .5958 L p .707 .577 .707 r
F P
0 g
s
.7903 .69576 m .79293 .73042 L .8168 .71983 L p .707 .577 .707 r
F P
0 g
s
.8168 .71983 m .81417 .68518 L .7903 .69576 L p .707 .577 .707 r
F P
0 g
s
.44729 .65895 m .44992 .6936 L .4533 .6921 L p .707 .577 .707 r
F P
0 g
s
.47127 .73442 m .46664 .52717 L p .50517 .23853 L .707 .577 .707 r
F P
0 g
s
.4533 .6921 m .47379 .68302 L p .45539 .66631 L .707 .577 .707 r
F P
0 g
s
.45539 .66631 m .44729 .65895 L .4533 .6921 L .707 .577 .707 r
F
.46664 .52717 m .46024 .24074 L .48991 .23928 L p F P
0 g
s
.48991 .23928 m .50517 .23853 L p .46664 .52717 L .707 .577 .707 r
F P
0 g
s
.50517 .23853 m .5162 .73221 L .47127 .73442 L p .707 .577 .707 r
F P
0 g
s
.67332 .73471 m .67068 .70006 L .64954 .69109 L p .707 .577 .707 r
F P
0 g
s
.67068 .70006 m .67332 .73471 L .70081 .73997 L p .707 .577 .707 r
F P
0 g
s
.81417 .68518 m .8168 .71983 L .83297 .70699 L p .707 .577 .707 r
F P
0 g
s
.83297 .70699 m .83034 .67234 L .81417 .68518 L p .707 .577 .707 r
F P
0 g
s
.83244 .59023 m .83119 .64655 L .83825 .63998 L p .707 .577 .707 r
F P
0 g
s
.83825 .63998 m .8395 .58365 L .83244 .59023 L p .707 .577 .707 r
F P
0 g
s
.73934 .79546 m .73638 .78057 L .70538 .78055 L p .707 .577 .707 r
F P
0 g
s
.73638 .78057 m .73934 .79546 L .77069 .78922 L p .707 .577 .707 r
F P
0 g
s
.77069 .78922 m .76774 .77433 L .73638 .78057 L p .707 .577 .707 r
F P
0 g
s
.76774 .77433 m .77069 .78922 L .79932 .77735 L p .707 .577 .707 r
F P
0 g
s
.79932 .77735 m .79637 .76246 L .76774 .77433 L p .707 .577 .707 r
F P
0 g
s
.64954 .69109 m .65217 .72574 L .67332 .73471 L p .707 .577 .707 r
F P
0 g
s
.70833 .79544 m .70538 .78055 L .67775 .77427 L p .707 .577 .707 r
F P
0 g
s
.70538 .78055 m .70833 .79544 L .73934 .79546 L p .707 .577 .707 r
F P
0 g
s
.79637 .76246 m .79932 .77735 L .82243 .76099 L p .707 .577 .707 r
F P
0 g
s
.82243 .76099 m .81948 .7461 L .79637 .76246 L p .707 .577 .707 r
F P
0 g
s
.6373 .63968 m .63856 .58336 L .63564 .57643 L p .707 .577 .707 r
F P
0 g
s
.83034 .67234 m .83297 .70699 L .83985 .69316 L p .707 .577 .707 r
F P
0 g
s
.83985 .69316 m .83722 .6585 L .83034 .67234 L p .707 .577 .707 r
F P
0 g
s
.67775 .77427 m .68071 .78916 L .70833 .79544 L p .707 .577 .707 r
F P
0 g
s
.68071 .78916 m .67775 .77427 L .65622 .76236 L p .707 .577 .707 r
F P
0 g
s
.81948 .7461 m .82243 .76099 L .83775 .74175 L p .707 .577 .707 r
F P
0 g
s
.83775 .74175 m .8348 .72686 L .81948 .7461 L p .707 .577 .707 r
F P
0 g
s
.63564 .57643 m .63439 .63276 L .6373 .63968 L p .707 .577 .707 r
F P
0 g
s
.8395 .58365 m .83825 .63998 L .83533 .63306 L p .707 .577 .707 r
F P
0 g
s
.83533 .63306 m .83659 .57673 L .8395 .58365 L p .707 .577 .707 r
F P
0 g
s
.63943 .71394 m .6368 .67929 L .63372 .66581 L p .707 .577 .707 r
F P
0 g
s
.65622 .76236 m .65917 .77725 L .68071 .78916 L p .707 .577 .707 r
F P
0 g
s
.63439 .63276 m .63564 .57643 L .64271 .56986 L p .707 .577 .707 r
F P
0 g
s
.65917 .77725 m .65622 .76236 L .64287 .74598 L p .707 .577 .707 r
F P
0 g
s
.8348 .72686 m .83775 .74175 L .84378 .72152 L p .707 .577 .707 r
F P
0 g
s
.84378 .72152 m .84083 .70663 L .8348 .72686 L p .707 .577 .707 r
F P
0 g
s
.83722 .6585 m .83985 .69316 L .83677 .67968 L p .707 .577 .707 r
F P
0 g
s
.83677 .67968 m .83414 .64502 L .83722 .6585 L p .707 .577 .707 r
F P
0 g
s
.63372 .66581 m .63636 .70046 L .63943 .71394 L p .707 .577 .707 r
F P
0 g
s
.64271 .56986 m .64145 .62619 L .63439 .63276 L p .707 .577 .707 r
F P
0 g
s
.64287 .74598 m .64583 .76087 L .65917 .77725 L p .707 .577 .707 r
F P
0 g
s
.83659 .57673 m .83533 .63306 L .82273 .62646 L p .707 .577 .707 r
F P
0 g
s
.82273 .62646 m .82398 .57013 L .83659 .57673 L p .707 .577 .707 r
F P
0 g
s
.63636 .70046 m .63372 .66581 L .6406 .65197 L p .707 .577 .707 r
F P
0 g
s
.64583 .76087 m .64287 .74598 L .63903 .72673 L p .717 .584 .705 r
F P
0 g
s
.84083 .70663 m .84378 .72152 L .83994 .70227 L p .717 .584 .705 r
F P
0 g
s
.83994 .70227 m .83699 .68738 L .84083 .70663 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3866 .62139 m .38785 .56506 L .35668 .56288 L p .707 .577 .707 r
F P
0 g
s
.38785 .56506 m .3866 .62139 L .41842 .62144 L p .707 .577 .707 r
F P
0 g
s
.41842 .62144 m .41968 .56511 L .38785 .56506 L p .707 .577 .707 r
F P
0 g
s
.44779 .61934 m .44905 .56302 L .41968 .56511 L p .707 .577 .707 r
F P
0 g
s
.64145 .62619 m .64271 .56986 L .65906 .56429 L p .707 .577 .707 r
F P
0 g
s
.83414 .64502 m .83677 .67968 L .82404 .66788 L p .707 .577 .707 r
F P
0 g
s
.82404 .66788 m .8214 .63322 L .83414 .64502 L p .707 .577 .707 r
F P
0 g
s
.35543 .61921 m .35668 .56288 L .32922 .55877 L p .707 .577 .707 r
F P
0 g
s
.35668 .56288 m .35543 .61921 L .3866 .62139 L p .707 .577 .707 r
F P
0 g
s
.6406 .65197 m .64324 .68663 L .63636 .70046 L p .707 .577 .707 r
F P
0 g
s
.63903 .72673 m .64198 .74162 L .64583 .76087 L p .717 .584 .705 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44905 .56302 m .44779 .61934 L .47183 .61531 L p .707 .577 .707 r
F P
0 g
s
.47183 .61531 m .47308 .55898 L .44905 .56302 L p .707 .577 .707 r
F P
0 g
s
.65906 .56429 m .6578 .62062 L .64145 .62619 L p .707 .577 .707 r
F P
0 g
s
.32922 .55877 m .32797 .6151 L .35543 .61921 L p .707 .577 .707 r
F P
0 g
s
.82398 .57013 m .82273 .62646 L .80166 .62083 L p .707 .577 .707 r
F P
0 g
s
.80166 .62083 m .80292 .5645 L .82398 .57013 L p .707 .577 .707 r
F P
0 g
s
.64324 .68663 m .6406 .65197 L .65677 .63914 L p .707 .577 .707 r
F P
0 g
s
.32797 .6151 m .32922 .55877 L .30816 .55314 L p .707 .577 .707 r
F P
0 g
s
.64198 .74162 m .63903 .72673 L .64506 .7065 L p .707 .577 .707 r
F P
0 g
s
.83699 .68738 m .83994 .70227 L .8266 .68588 L p .707 .577 .707 r
F P
0 g
s
.8266 .68588 m .82364 .67099 L .83699 .68738 L p .707 .577 .707 r
F P
0 g
s
.38894 .70419 m .3863 .66954 L .35516 .6685 L p .707 .577 .707 r
F P
0 g
s
.42068 .7009 m .41805 .66624 L .3863 .66954 L p .707 .577 .707 r
F P
0 g
s
.6578 .62062 m .65906 .56429 L .68309 .56026 L p .707 .577 .707 r
F P
0 g
s
.8214 .63322 m .82404 .66788 L .80289 .65891 L p .707 .577 .707 r
F P
0 g
s
.80289 .65891 m .80026 .62425 L .8214 .63322 L p .707 .577 .707 r
F P
0 g
s
.3578 .70316 m .35516 .6685 L .32767 .66324 L p .707 .577 .707 r
F P
0 g
s
.35516 .6685 m .3578 .70316 L .38894 .70419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55314 m .3069 .60947 L .32797 .6151 L p .707 .577 .707 r
F P
0 g
s
.64506 .7065 m .64802 .72139 L .64198 .74162 L p .707 .577 .707 r
F P
0 g
s
.47308 .55898 m .47183 .61531 L .48818 .60974 L p .707 .577 .707 r
F P
0 g
s
.48818 .60974 m .48943 .55341 L .47308 .55898 L p .707 .577 .707 r
F P
0 g
s
.47379 .68302 m .47116 .64836 L .44729 .65895 L p .707 .577 .707 r
F P
0 g
s
.65677 .63914 m .65941 .67379 L .64324 .68663 L p .707 .577 .707 r
F P
0 g
s
.68309 .56026 m .68184 .61658 L .6578 .62062 L p .707 .577 .707 r
F P
0 g
s
.80292 .5645 m .80166 .62083 L .7742 .61672 L p .707 .577 .707 r
F P
0 g
s
.7742 .61672 m .77546 .56039 L .80292 .5645 L p .707 .577 .707 r
F P
0 g
s
.65941 .67379 m .65677 .63914 L .68064 .62855 L p .707 .577 .707 r
F P
0 g
s
.3069 .60947 m .30816 .55314 L .29555 .54654 L p .707 .577 .707 r
F P
0 g
s
.33031 .6979 m .32767 .66324 L .30653 .65427 L p .707 .577 .707 r
F P
0 g
s
.32767 .66324 m .33031 .6979 L .3578 .70316 L p .707 .577 .707 r
F P
0 g
s
.64802 .72139 m .64506 .7065 L .66038 .68726 L p .707 .577 .707 r
F P
0 g
s
.82364 .67099 m .8266 .68588 L .80506 .67397 L p .707 .577 .707 r
F P
0 g
s
.80506 .67397 m .80211 .65908 L .82364 .67099 L p .707 .577 .707 r
F P
0 g
s
.68184 .61658 m .68309 .56026 L .71246 .55816 L p .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .80211 .65908 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77744 .6677 m .77587 .65979 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77587 .65979 m .77448 .65281 L p .7816 .66625 L .707 .577 .707 r
F P
0 g
s
.77448 .65281 m .77744 .6677 L .74643 .66768 L p .707 .577 .707 r
F P
0 g
s
.74643 .66768 m .74348 .65279 L .77448 .65281 L p .707 .577 .707 r
F P
0 g
s
.77277 .619 m .7754 .65365 L .77027 .65348 L p .707 .577 .707 r
F P
0 g
s
.77027 .65348 m .74426 .65262 L p .75659 .63807 L .707 .577 .707 r
F P
0 g
s
.75659 .63807 m .77277 .619 L .77027 .65348 L .707 .577 .707 r
F
.80026 .62425 m .80289 .65891 L .7754 .65365 L p F P
0 g
s
.7754 .65365 m .77277 .619 L .80026 .62425 L p .707 .577 .707 r
F P
0 g
s
.47116 .64836 m .47379 .68302 L .48996 .67018 L p .707 .577 .707 r
F P
0 g
s
.48996 .67018 m .48733 .63552 L .47116 .64836 L p .707 .577 .707 r
F P
0 g
s
.29555 .54654 m .29429 .60287 L .3069 .60947 L p .707 .577 .707 r
F P
0 g
s
.66038 .68726 m .66334 .70215 L .64802 .72139 L p .707 .577 .707 r
F P
0 g
s
.77546 .56039 m .7742 .61672 L .74303 .61454 L p .707 .577 .707 r
F P
0 g
s
.74303 .61454 m .74429 .55821 L .77546 .56039 L p .707 .577 .707 r
F P
0 g
s
.68064 .62855 m .68328 .6632 L .65941 .67379 L p .707 .577 .707 r
F P
0 g
s
.48943 .55341 m .48818 .60974 L .49524 .60317 L p .707 .577 .707 r
F P
0 g
s
.49524 .60317 m .49649 .54684 L .48943 .55341 L p .707 .577 .707 r
F P
0 g
s
.71246 .55816 m .71121 .61449 L .68184 .61658 L p .707 .577 .707 r
F P
0 g
s
.71121 .61449 m .71246 .55816 L .74429 .55821 L p .707 .577 .707 r
F P
0 g
s
.39633 .75864 m .39337 .74375 L .36237 .74373 L p .707 .577 .707 r
F P
0 g
s
.39337 .74375 m .39633 .75864 L .42768 .75241 L p .707 .577 .707 r
F P
0 g
s
.42768 .75241 m .42473 .73752 L .39337 .74375 L p .707 .577 .707 r
F P
0 g
s
.42473 .73752 m .42768 .75241 L .45631 .74053 L p .707 .577 .707 r
F P
0 g
s
.45631 .74053 m .45336 .72564 L .42473 .73752 L p .707 .577 .707 r
F P
0 g
s
.30653 .65427 m .30916 .68893 L .33031 .6979 L p .707 .577 .707 r
F P
0 g
s
.68328 .6632 m .68064 .62855 L .70988 .62125 L p .707 .577 .707 r
F P
0 g
s
.74429 .55821 m .74303 .61454 L .71121 .61449 L p .707 .577 .707 r
F P
0 g
s
.66334 .70215 m .66038 .68726 L .68349 .6709 L p .707 .577 .707 r
F P
0 g
s
.80211 .65908 m .80506 .67397 L .77744 .6677 L p .707 .577 .707 r
F P
0 g
s
.74426 .65262 m .74163 .61796 L .77277 .619 L p .707 .577 .707 r
F P
0 g
s
.30916 .68893 m .30653 .65427 L .29379 .64247 L p .707 .577 .707 r
F P
0 g
s
.36532 .75862 m .36237 .74373 L .33474 .73746 L p .707 .577 .707 r
F P
0 g
s
.36237 .74373 m .36532 .75862 L .39633 .75864 L p .707 .577 .707 r
F P
0 g
s
.45336 .72564 m .45631 .74053 L .47942 .72417 L p .707 .577 .707 r
F P
0 g
s
.47942 .72417 m .47647 .70928 L .45336 .72564 L p .707 .577 .707 r
F P
0 g
s
.29429 .60287 m .29555 .54654 L .29263 .53962 L p .707 .577 .707 r
F P
0 g
s
.71252 .65591 m .70988 .62125 L .74163 .61796 L p .707 .577 .707 r
F P
0 g
s
.70988 .62125 m .71252 .65591 L .68328 .6632 L p .707 .577 .707 r
F P
0 g
s
.74163 .61796 m .74426 .65262 L .71252 .65591 L p .707 .577 .707 r
F P
0 g
s
.68349 .6709 m .68644 .68579 L .66334 .70215 L p .707 .577 .707 r
F P
0 g
s
.48733 .63552 m .48996 .67018 L .49684 .65634 L p .707 .577 .707 r
F P
0 g
s
.49684 .65634 m .49421 .62169 L .48733 .63552 L p .707 .577 .707 r
F P
0 g
s
.68644 .68579 m .68349 .6709 L .71212 .65902 L p .707 .577 .707 r
F P
0 g
s
.33474 .73746 m .3377 .75235 L .36532 .75862 L p .707 .577 .707 r
F P
0 g
s
.29379 .64247 m .29642 .67713 L .30916 .68893 L p .707 .577 .707 r
F P
0 g
s
.3377 .75235 m .33474 .73746 L .31321 .72555 L p .707 .577 .707 r
F P
0 g
s
.47647 .70928 m .47942 .72417 L .49474 .70493 L p .707 .577 .707 r
F P
0 g
s
.49474 .70493 m .49179 .69005 L .47647 .70928 L p .707 .577 .707 r
F P
0 g
s
.29263 .53962 m .29138 .59594 L .29429 .60287 L p .707 .577 .707 r
F P
0 g
s
.71508 .67391 m .71212 .65902 L .74348 .65279 L p .707 .577 .707 r
F P
0 g
s
.71212 .65902 m .71508 .67391 L .68644 .68579 L p .707 .577 .707 r
F P
0 g
s
.74348 .65279 m .74643 .66768 L .71508 .67391 L p .707 .577 .707 r
F P
0 g
s
.49649 .54684 m .49524 .60317 L .49232 .59624 L p .707 .577 .707 r
F P
0 g
s
.49232 .59624 m .49358 .53991 L .49649 .54684 L p .707 .577 .707 r
F P
0 g
s
.29642 .67713 m .29379 .64247 L .29071 .62899 L p .707 .577 .707 r
F P
0 g
s
.31321 .72555 m .31616 .74044 L .3377 .75235 L p .707 .577 .707 r
F P
0 g
s
.29138 .59594 m .29263 .53962 L .2997 .53305 L p .707 .577 .707 r
F P
0 g
s
.31616 .74044 m .31321 .72555 L .29986 .70917 L p .707 .577 .707 r
F P
0 g
s
.49179 .69005 m .49474 .70493 L .50077 .6847 L p .707 .577 .707 r
F P
0 g
s
.50077 .6847 m .49782 .66981 L .49179 .69005 L p .707 .577 .707 r
F P
0 g
s
.49421 .62169 m .49684 .65634 L .49376 .64286 L p .707 .577 .707 r
F P
0 g
s
.49376 .64286 m .49113 .60821 L .49421 .62169 L p .707 .577 .707 r
F P
0 g
s
.29071 .62899 m .29334 .66365 L .29642 .67713 L p .707 .577 .707 r
F P
0 g
s
.2997 .53305 m .29844 .58937 L .29138 .59594 L p .707 .577 .707 r
F P
0 g
s
.29986 .70917 m .30282 .72406 L .31616 .74044 L p .707 .577 .707 r
F P
0 g
s
.49358 .53991 m .49232 .59624 L .47972 .58964 L p .707 .577 .707 r
F P
0 g
s
.47972 .58964 m .48097 .53331 L .49358 .53991 L p .707 .577 .707 r
F P
0 g
s
.29334 .66365 m .29071 .62899 L .29759 .61516 L p .707 .577 .707 r
F P
0 g
s
.30282 .72406 m .29986 .70917 L .29602 .68992 L p .717 .584 .705 r
F P
0 g
s
.49782 .66981 m .50077 .6847 L .49693 .66545 L p .717 .584 .705 r
F P
0 g
s
.49693 .66545 m .49398 .65056 L .49782 .66981 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29844 .58937 m .2997 .53305 L .31605 .52747 L p .707 .577 .707 r
F P
0 g
s
.49113 .60821 m .49376 .64286 L .48103 .63106 L p .707 .577 .707 r
F P
0 g
s
.48103 .63106 m .47839 .59641 L .49113 .60821 L p .707 .577 .707 r
F P
0 g
s
.29759 .61516 m .30023 .64981 L .29334 .66365 L p .707 .577 .707 r
F P
0 g
s
.29602 .68992 m .29897 .70481 L .30282 .72406 L p .717 .584 .705 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31605 .52747 m .31479 .5838 L .29844 .58937 L p .707 .577 .707 r
F P
0 g
s
.48097 .53331 m .47972 .58964 L .45865 .58401 L p .707 .577 .707 r
F P
0 g
s
.45865 .58401 m .45991 .52769 L .48097 .53331 L p .707 .577 .707 r
F P
0 g
s
.30023 .64981 m .29759 .61516 L .31376 .60232 L p .707 .577 .707 r
F P
0 g
s
.29897 .70481 m .29602 .68992 L .30205 .66968 L p .707 .577 .707 r
F P
0 g
s
.49398 .65056 m .49693 .66545 L .48359 .64907 L p .707 .577 .707 r
F P
0 g
s
.48359 .64907 m .48063 .63418 L .49398 .65056 L p .707 .577 .707 r
F P
0 g
s
.31479 .5838 m .31605 .52747 L .34008 .52344 L p .707 .577 .707 r
F P
0 g
s
.47839 .59641 m .48103 .63106 L .45988 .62209 L p .707 .577 .707 r
F P
0 g
s
.45988 .62209 m .45725 .58744 L .47839 .59641 L p .707 .577 .707 r
F P
0 g
s
.30205 .66968 m .30501 .68457 L .29897 .70481 L p .707 .577 .707 r
F P
0 g
s
.31376 .60232 m .3164 .63697 L .30023 .64981 L p .707 .577 .707 r
F P
0 g
s
.34008 .52344 m .33883 .57977 L .31479 .5838 L p .707 .577 .707 r
F P
0 g
s
.45991 .52769 m .45865 .58401 L .43119 .57991 L p .707 .577 .707 r
F P
0 g
s
.43119 .57991 m .43244 .52358 L .45991 .52769 L p .707 .577 .707 r
F P
0 g
s
.3164 .63697 m .31376 .60232 L .33763 .59173 L p .707 .577 .707 r
F P
0 g
s
.30501 .68457 m .30205 .66968 L .31737 .65044 L p .707 .577 .707 r
F P
0 g
s
.48063 .63418 m .48359 .64907 L .46205 .63716 L p .707 .577 .707 r
F P
0 g
s
.46205 .63716 m .4591 .62227 L .48063 .63418 L p .707 .577 .707 r
F P
0 g
s
.33883 .57977 m .34008 .52344 L .36945 .52135 L p .707 .577 .707 r
F P
0 g
s
.43147 .616 m .4591 .62227 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43443 .63089 m .43286 .62297 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43286 .62297 m .43147 .616 L p .43859 .62943 L .707 .577 .707 r
F P
0 g
s
.43147 .616 m .43443 .63089 L .40342 .63086 L p .707 .577 .707 r
F P
0 g
s
.40342 .63086 m .40047 .61598 L .43147 .616 L p .707 .577 .707 r
F P
0 g
s
.42976 .58218 m .43239 .61683 L .42726 .61666 L p .707 .577 .707 r
F P
0 g
s
.42726 .61666 m .40125 .6158 L p .41358 .60126 L .707 .577 .707 r
F P
0 g
s
.41358 .60126 m .42976 .58218 L .42726 .61666 L .707 .577 .707 r
F
.45725 .58744 m .45988 .62209 L .43239 .61683 L p F P
0 g
s
.43239 .61683 m .42976 .58218 L .45725 .58744 L p .707 .577 .707 r
F P
0 g
s
.31737 .65044 m .32033 .66533 L .30501 .68457 L p .707 .577 .707 r
F P
0 g
s
.43244 .52358 m .43119 .57991 L .40002 .57772 L p .707 .577 .707 r
F P
0 g
s
.40002 .57772 m .40128 .52139 L .43244 .52358 L p .707 .577 .707 r
F P
0 g
s
.33763 .59173 m .34027 .62639 L .3164 .63697 L p .707 .577 .707 r
F P
0 g
s
.36945 .52135 m .36819 .57767 L .33883 .57977 L p .707 .577 .707 r
F P
0 g
s
.36819 .57767 m .36945 .52135 L .40128 .52139 L p .707 .577 .707 r
F P
0 g
s
.34027 .62639 m .33763 .59173 L .36687 .58444 L p .707 .577 .707 r
F P
0 g
s
.40128 .52139 m .40002 .57772 L .36819 .57767 L p .707 .577 .707 r
F P
0 g
s
.32033 .66533 m .31737 .65044 L .34048 .63409 L p .707 .577 .707 r
F P
0 g
s
.4591 .62227 m .46205 .63716 L .43443 .63089 L p .707 .577 .707 r
F P
0 g
s
.40125 .6158 m .39862 .58115 L .42976 .58218 L p .707 .577 .707 r
F P
0 g
s
.36951 .61909 m .36687 .58444 L .39862 .58115 L p .707 .577 .707 r
F P
0 g
s
.36687 .58444 m .36951 .61909 L .34027 .62639 L p .707 .577 .707 r
F P
0 g
s
.39862 .58115 m .40125 .6158 L .36951 .61909 L p .707 .577 .707 r
F P
0 g
s
.34048 .63409 m .34343 .64898 L .32033 .66533 L p .707 .577 .707 r
F P
0 g
s
.34343 .64898 m .34048 .63409 L .36911 .62221 L p .707 .577 .707 r
F P
0 g
s
.37207 .6371 m .36911 .62221 L .40047 .61598 L p .707 .577 .707 r
F P
0 g
s
.36911 .62221 m .37207 .6371 L .34343 .64898 L p .707 .577 .707 r
F P
0 g
s
.40047 .61598 m .40342 .63086 L .37207 .6371 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002>Ool80027Ool0081oo`h0
0003FUH005YF00EJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001d
Ool007=oo`<000aJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001b
Ool006moo`@000mJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3
001_Ool006aoo`<001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP8006eoo`00JWoo0P0000=JEP00FUH04eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF0P00K7oo001XOol20003FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000JWoo001VOol20005FUH0
0`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000JGoo001UOol20006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJ
EP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001T
Ool00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo
001TOol00`00FUH00006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03
001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001J
EUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001TOol00`00FUH0
0006FUH00`00FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF01=JEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFOol0
IWoo001TOol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Ioo`00I7oo00<005YF
00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Moo`00I7oo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Moo`00I7oo00@005YFFUH0
00EJEP8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001WOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0005FUH20009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP8000UJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Eoo`03001JEP0000IJEP03001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YF
FUH04UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP0BFUH2000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF019JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH04UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP0CFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF01=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF
00000eYF00<005YFFUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00<005YF00000eYF00<005YF
FUH00P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0009JEP03001JEUYF008000UJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH3001UOol005mooad000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Fgoo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001HOol30005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000?OolA0015Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool80003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH8000mOol005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001BOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0031oo`00DWoo00<005YF000015YF00<005YF
FUH00eYF7@001UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001B
Ool00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUHC0002FUH00`00FUIJEP03FUH0
0`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00<005YF00000UYF10000UYF00<0
05YFFUH01EYF200015YF00<005YFFUH01UYF00<005YF000020000eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool0059oo`03001JEP0000<000EJEP03001JEUYF009JEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@0009JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030002FUH40004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF0080
02ioo`00DWoo0P000eYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool0059oo`80
00=JEP04001JEUYFFUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF0000000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001C
Ool01P00FUIJEUYF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001JEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000hOolN000015YF000000001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
=7oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0035oo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUHA0004FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP04001JEUYFFUH90007FUH900000eYF000000060003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@001EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP05FUH00`00FUH000050004FUH00`00FUIJ
EP02FUH800000eYF000000030004FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP060008FUH00`00FUIJEP06FUH20006FUH30003FUH00`00FUIJEP020004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJ
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH500001UYF0000
0000FUH000=JEP8002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF100000=JEP0000000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00UYF
00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF
00<000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
0004FUH000000003FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH20002FUH30005FUH0
0`00FUIJEP04FUH=0006FUH00`00FUIJEP030003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH200000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH200000eYF
0000000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH01000FUH000000eYF0P001eYF00<005YFFUH01`001UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH3
000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05
001JEUYFFUIoo`03FUH01000FUIJEP000eYF0`000UYF0`001eYF10000UYF1@001UYF00<005YFFUH0
1EYF0`0015YF1@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP00009JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH2000015YF00000000;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YF
FUH005YF0002FUH00`00FUIJEP03FUH30006FUH30007FUH00`00FUIJEP08FUH20002FUH01000FUH0
05YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00H005YF000005YF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP04001JEUYFOol4FUH00`00FUIJEP030003FUH20004FUH00`00FUH00003
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000015YF000005YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH01EYF
00<005YFFUH01eYF00<005YFFUH025YF0P000UYF0P0000AJEP00000000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP800004FUH005YFFUH20005FUH20002FUH01@00FUH005YF00001UYF00<005YF
FUH01eYF00<005YFFUH01eYF0`0015YF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP00;goo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH200000eYF001JEP03
FUH00`00FUH00002FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF00IJEP03001JEP00
00<0009JEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUH0
00000UYF00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01eYF0P000UYF100015YF00<005YF
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUIJEP80
00AJEP03001JEUYF00AJEP03001JEUYF00P000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJ
EP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03001JEUYF00=JEQd0009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP0300000eYF001JEP05FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00=JEP@00006FUH00000001JEP002EYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YF00000`0000EJEP00FUIJEP0002moo`00:goo00<005YF000015YF00<005YF0000
0`001UYF200015YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00@005YF001JEP@00006FUH00000
001JEP001UYF00<005YFFUH01`001UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00H005YFFUH005YF0004FUH01000FUIJ
EUYF0P000UYF10000eYF00<005YFFUH01EYF30001EYF00@005YFFUIJEP@0009JEP03001oogoo02eo
o`00:goo00<005YF00000UYF10000UYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0015YF00@005YFFUH000EJEPl000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00004FUH01000FUH000000eYF0P001eYF00<005YFFUH01`002Goo10000UYF00<005YFFUH0
0UYF0`0000=JEP00Ool0;Woo000[Ool00`00FUH000030005FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30003FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH30002FUH30008FUH3
0002Ool5000=Ool30005FUH200000eYF001oo`0^Ool002]oo`8000=JEP03001JEUYF00=JEP<000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH30003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YF
00000UYF00@005YFFUH000IJEP8000Eoo`D0011oo`8000=JEP@002moo`00:goo0P000eYF00@005YF
FUIJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0000000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEP00FUH005YF0P000UYF00<005YF000015YF00@005YFFUIJEP8000Qoo`<001=oo`05001JEUYF
001JEP03000^Ool002]oo`8000=JEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH005YF0`000eYF0P001EYF00<005YF00000P007Woo1@0000AJEP00
000002ioo`00;7oo00@005YFFUIJEP<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJ
EP03001JEUYF00@000EJEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH005YF0`000UYF00<005YFFUH01EYF0P0000=JEP00000077oo0P0000EJEP00FUIJ
EP00009JEP8002ioo`00;Goo100000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`000UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF0`000eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP04001JEP000005FUH20003FUH2000JOol20003FUH01P00FUIJ
EUYF001JEP8002ioo`00;Woo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP<000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000002FUH200000eYF001JEP02FUH200000eYF001JEP02FUH2000GOol3
0005FUH00`00FUIJEP02FUH3000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPl000EJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00@000MJEP09001JEUYFFUH005YF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000002FUH20002FUH30003FUH01000FUIJEUYF0P004goo100000=JEP00FUH0
1EYF00<005YFFUH00UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008
FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03FUH90004FUH01000FUIJEUYF2@002UYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEP000002FUH01000FUIJEUYF1`000eYF0P0037oo1`001EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP0Q0004FUH00`00FUIJEP020000
0gooFUIJEP090008FUH00`00FUIJEP08FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF000005YF0003FUH01000FUIJEP000eYF4P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00=JEP@000Eoo`D000AJEP03001JEUYF00IJEP800004FUH000000004Ool30000
0eYF001JEP02FUH01@00OomJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF0000
05YF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP0000AJEP04001JEUYFFUH20007
Ool30008FUH00`00FUIJEP06FUH01000FUH000000UYF0`0017oo0P000eYF00D007ooFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP<0009JEP03001JEUYF00EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00<0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP000Woo00<007ooOol0
;7oo000[Ool01000FUIJEP000eYF00@005YF000000Moo`80009JEP03001JEUYF00MJEP03001JEUYF
00IJEP800003FUH005YF009JEP<000Aoo`05001JEUYF001oo`02FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo00<005YF0000
;Goo000[Ool01000FUIJEP000eYF0P001goo0P001EYF00<005YFFUH015YF3`000eYF00<005YFFUH0
0P000Woo100000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P001EYF
00<005YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0017oo
00<005YF0000;Goo000[Ool01000FUIJEP000UYF00<007ooOol01Goo0P001eYF00<005YFFUH01P00
2goo00@005YF0000009JEP04001JEUYFFUH200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH01EYF00@005YFFUIJEP8000Ioo`03001JEP0002eoo`00:goo00<005YFFUH00`00
1goo0P001eYF10000Woo1@002goo00<005YF00000`0015YF0`0000=JEP0000000UYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00UYF0P001EYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP04001JEP000008Ool00`00FUH0000]Ool002aoo`03001JEP0000Qoo`03
001JEP0000EJEP8000Ioo`D000]oo`03001JEP0000800003Ool00000009JEP04001JEP00FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF0`002Goo0P0000=JEP00Ool0
;7oo000/Ool200000eYF001oo`04Ool20003FUH00`00FUH000020008Ool5000<Ool20002FUH50000
0eYF00000002FUH01000FUIJEP001UYF00<005YFFUH01eYF0`000eYF00@005YFFUIJEQh000QJEP03
001JEUYF00EJEP05001JEUYF001JEP020004FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04000;Ool01000FUH00000;Woo000/Ool20002FUH20002Ool00`00FUIJEP03FUH2000<
Ool3000=Ool20004FUH5000015YF001JEP000UYF00<005YFFUH015YF00<005YFFUH00eYF10001eYF
0`0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000ioo`05
001JEUYFFUH0000^Ool002aoo`06001JEUYFFUH005YF0P001EYF00<007ooOol06Woo1@0015YF00<0
05YF0000100000AooeYFFUH000IJEP03001JEP0000<0009JEP03001JEUYF00EJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00@000IJEP06001JEUYFFUH005YF1P001EYF00<005YF
00003`005Goo00D005YFFUIJEP0002ioo`00;7oo0P000UYF00@005YF000000AJEP03001oogoo01Mo
o`@0009JEP03001JEUYF0080009JEP03001JEUYF00=JEPd000IJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP06001JEUYFFUH005YF0`000goo
0P000eYF00@005YFFUH0029oo`05001JEUYFFUH0000_Ool002aoo`80009JEP800004FUH005YFFUH6
000?Ool70006FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH300000eYF001JEP02FUH00`00FUH00002FUH30002Ool200001EYF001JEUYF00008Goo00D0
05YFFUIJEP00031oo`00;7oo0P000UYF00@005YFFUIJEP<000EJEPl000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000003FUH30003FUH01000FUH0
00000Woo0P000UYF00<007ooOol07Goo0`000UYF00<007ooOol0;goo000]Ool00`00FUH00004FUH0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP040009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000UYF0`000eYF00@005YFFUIJEP80
009oo`03001JEP0001ioo`04001JEUYF0002FUH00`00Oomoo`0_Ool002eoo`8000AJEP04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0
00000goo3@000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH00P000UYF00<005YFFUH00UYF1@0077oo
0P0015YF0P00<Woo000^Ool01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo00<005YFFUH00`0000=JEP00FUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P000UYF10001EYF1@006Woo00<005YFFUH015YF00<007ooOol0<Goo000^
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P001Goo0P000UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00005
FUH00000001oo`020003FUH5000HOol30005FUH00`00Oomoo`0bOol002eoo`04001JEP000005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
1goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD0009JEP800006FUH005YFFUH0
05YF0`005Woo0P000UYF00<005YFFUH00UYF00<007ooOol0<goo000]Ool00`00FUH000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUH000002Goo00@005YF
FUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP000UYF1P0000AJEP00FUH0
01Aoo`8000EJEP04001JEP00000fOol002eoo`03001JEP00009oo`<00003FUH005YF00IJEP03001J
EUYF00IJEPD000AJEP03001JEUYF00AJEP<000Yoo`03001JEUYF008000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<000AJEP@0009JEP8000ioo`H000MJEP8003Qoo`00;Goo00<005YF
00001Goo0`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00<005YF00000P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0004FUH01000FUIJEUYF4P0015YF00<0
05YFFUH01EYF0P00>Goo000]Ool20009Ool40002FUH00`00FUIJEP06FUH<000@Ool2000015YF0000
000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00FUIJEP80009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003]oo`00;Goo0P003Goo40005Woo
00@005YF001JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP800003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003eoo`00;Woo00<007oo
Ool0<Goo00@005YFFUH0009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0006FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40010Ool002ioo`03001oogoo031o
o`05001JEUYFFUH00002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EP001eYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01000A7oo000^Ool00`00Oomo
o`0_Ool01@00FUIJEUYF000017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0015YF00<0
05YFFUH015YF0`000goo3P00B7oo000^Ool2000^Ool30002FUH00`00Oomoo`05Ool30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP020006FUH00`00FUIJEP03FUH20005Ool00`00Oomoo`1COol002ioo`<002aoo`04001JEUYF
0002FUH00`00Oomoo`07Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH40007FUH01000FUIJEUYF0P001Woo00<005YF0000E7oo000_
Ool2000[Ool00`00FUIJEP02FUH2000<Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP05FUH01000FUH00000
27oo00<005YF0000E7oo000_Ool00`00FUH0000XOol20005FUH00`00Oomoo`0=Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050005FUH00`00
FUIJEP04FUH3000:Ool00`00FUH0001DOol0031oo`03001JEP0002Eoo`8000EJEP8001=oo`@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD00003FUH0000000<000AJEP03001J
EUYF00@000eoo`03001JEP0005Aoo`00<7oo00<005YF00000P008Goo0P0000=JEP00FUH00eYF00<0
07ooOol05goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P001UYF300047oo
0P0000=JEP00Ool0Dgoo000aOol20002FUH2000LOol30003FUH01@00FUIJEUYF000087oo2@001UYF
00<005YFFUH015YF6P005Woo00@005YF000005Eoo`00<Goo0P0015YF0`005Goo10001eYF0`00:Woo
3@005Woo0`005Woo00D005YFFUIJEP0005Eoo`00<Woo0P0015YF00<005YF00000`003Goo10000UYF
00<005YFFUH01EYF0P00=7oo00<007ooOol0<Goo00D005YFFUIJEP0005Eoo`00=7oo0P000UYF00<0
05YFFUH00eYF3@001UYF00<005YFFUH00eYF0P00=Woo00<007ooOol0<7oo00D005YFFUIJEP0005Io
o`00=Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00>7oo
00<007ooOol0;goo00D005YFFUIJEP0005Moo`00>7oo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF1000>goo0P00;Woo0`000UYF00<007ooOol0EWoo000kOol400000eYF001JEP07FUH00`00FUIJ
EP04000oOol00`00FUH0000/Ool01000FUIJEP000UYF00<007ooOol0EWoo000oOol=0014Ool00`00
FUH0000YOol20004FUH2001IOol0091oo`04001JEUYF000WOol00`00FUIJEP04FUH00`00Oomoo`1H
Ool0095oo`03001JEP00008002=oo`<000EJEP03001oogoo05Uoo`00TWoo0P000UYF00<007ooOol0
7Woo0P000UYF00<005YFFUH00UYF00<007ooOol0FWoo002BOol00`00FUH00002FUH2000LOol20005
FUH01000FUH00000GGoo002COol20004FUH4000BOol60007FUH2001OOol009Aoo`03001JEUYF009J
EP04001JEUYFFUHB0004FUH00`00FUIJEP05FUH2001POol009Eoo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Ugoo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P00I7oo002IOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH4001WOol009aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@006]oo`00
X7oo3P00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59381 .74531 m .59459 .68924 L .56341 .68717 L p .707 .577 .707 r
F P
0 g
s
.59459 .68924 m .59381 .74531 L .62564 .74504 L p .707 .577 .707 r
F P
0 g
s
.62564 .74504 m .62642 .68897 L .59459 .68924 L p .707 .577 .707 r
F P
0 g
s
.62642 .68897 m .62564 .74504 L .65502 .74245 L p .707 .577 .707 r
F P
0 g
s
.65502 .74245 m .65579 .68639 L .62642 .68897 L p .707 .577 .707 r
F P
0 g
s
.56264 .74323 m .56341 .68717 L .53596 .68295 L p .707 .577 .707 r
F P
0 g
s
.56341 .68717 m .56264 .74323 L .59381 .74531 L p .707 .577 .707 r
F P
0 g
s
.65579 .68639 m .65502 .74245 L .67907 .7378 L p .707 .577 .707 r
F P
0 g
s
.67907 .7378 m .67984 .68174 L .65579 .68639 L p .707 .577 .707 r
F P
0 g
s
.53596 .68295 m .53518 .73902 L .56264 .74323 L p .707 .577 .707 r
F P
0 g
s
.53518 .73902 m .53596 .68295 L .5149 .67701 L p .707 .577 .707 r
F P
0 g
s
.59513 .81782 m .5935 .7821 L .56234 .78074 L p .707 .577 .707 r
F P
0 g
s
.5935 .7821 m .59513 .81782 L .62693 .81547 L p .707 .577 .707 r
F P
0 g
s
.62693 .81547 m .6253 .77975 L .5935 .7821 L p .707 .577 .707 r
F P
0 g
s
.6253 .77975 m .62693 .81547 L .65626 .80964 L p .707 .577 .707 r
F P
0 g
s
.65626 .80964 m .65462 .77392 L .6253 .77975 L p .707 .577 .707 r
F P
0 g
s
.56397 .81646 m .56234 .78074 L .53487 .77581 L p .707 .577 .707 r
F P
0 g
s
.56234 .78074 m .56397 .81646 L .59513 .81782 L p .707 .577 .707 r
F P
0 g
s
.67984 .68174 m .67907 .7378 L .69543 .73154 L p .707 .577 .707 r
F P
0 g
s
.69543 .73154 m .6962 .67547 L .67984 .68174 L p .707 .577 .707 r
F P
0 g
s
.5149 .67701 m .51412 .73307 L .53518 .73902 L p .707 .577 .707 r
F P
0 g
s
.65462 .77392 m .65626 .80964 L .68024 .8009 L p .707 .577 .707 r
F P
0 g
s
.68024 .8009 m .67861 .76518 L .65462 .77392 L p .707 .577 .707 r
F P
0 g
s
.53487 .77581 m .5365 .81153 L .56397 .81646 L p .707 .577 .707 r
F P
0 g
s
.5365 .81153 m .53487 .77581 L .51378 .76778 L p .707 .577 .707 r
F P
0 g
s
.51412 .73307 m .5149 .67701 L .5023 .66991 L p .707 .577 .707 r
F P
0 g
s
.59911 .87254 m .59725 .85589 L .56614 .85521 L p .707 .577 .707 r
F P
0 g
s
.59725 .85589 m .59911 .87254 L .63076 .86824 L p .707 .577 .707 r
F P
0 g
s
.63076 .86824 m .6289 .8516 L .59725 .85589 L p .707 .577 .707 r
F P
0 g
s
.6289 .8516 m .63076 .86824 L .65985 .85939 L p .707 .577 .707 r
F P
0 g
s
.65985 .85939 m .65799 .84275 L .6289 .8516 L p .707 .577 .707 r
F P
0 g
s
.67861 .76518 m .68024 .8009 L .69653 .7901 L p .707 .577 .707 r
F P
0 g
s
.69653 .7901 m .6949 .75439 L .67861 .76518 L p .707 .577 .707 r
F P
0 g
s
.5023 .66991 m .50152 .72598 L .51412 .73307 L p .707 .577 .707 r
F P
0 g
s
.51378 .76778 m .51541 .8035 L .5365 .81153 L p .707 .577 .707 r
F P
0 g
s
.568 .87185 m .56614 .85521 L .53862 .8496 L p .707 .577 .707 r
F P
0 g
s
.56614 .85521 m .568 .87185 L .59911 .87254 L p .707 .577 .707 r
F P
0 g
s
.6962 .67547 m .69543 .73154 L .7025 .72428 L p .707 .577 .707 r
F P
0 g
s
.7025 .72428 m .70328 .66822 L .6962 .67547 L p .707 .577 .707 r
F P
0 g
s
.65799 .84275 m .65985 .85939 L .68354 .84684 L p .707 .577 .707 r
F P
0 g
s
.68354 .84684 m .68168 .8302 L .65799 .84275 L p .707 .577 .707 r
F P
0 g
s
.51541 .8035 m .51378 .76778 L .50113 .75744 L p .707 .577 .707 r
F P
0 g
s
.53862 .8496 m .54048 .86624 L .568 .87185 L p .707 .577 .707 r
F P
0 g
s
.50152 .72598 m .5023 .66991 L .4994 .66237 L p .707 .577 .707 r
F P
0 g
s
.54048 .86624 m .53862 .8496 L .51737 .83963 L p .707 .577 .707 r
F P
0 g
s
.6949 .75439 m .69653 .7901 L .70354 .77831 L p .707 .577 .707 r
F P
0 g
s
.70354 .77831 m .70191 .7426 L .6949 .75439 L p .707 .577 .707 r
F P
0 g
s
.68168 .8302 m .68354 .84684 L .6995 .83182 L p .707 .577 .707 r
F P
0 g
s
.6995 .83182 m .69764 .81518 L .68168 .8302 L p .707 .577 .707 r
F P
0 g
s
.50113 .75744 m .50276 .79316 L .51541 .8035 L p .707 .577 .707 r
F P
0 g
s
.51737 .83963 m .51923 .85627 L .54048 .86624 L p .707 .577 .707 r
F P
0 g
s
.4994 .66237 m .49862 .71843 L .50152 .72598 L p .707 .577 .707 r
F P
0 g
s
.70328 .66822 m .7025 .72428 L .6996 .71674 L p .707 .577 .707 r
F P
0 g
s
.6996 .71674 m .70037 .66067 L .70328 .66822 L p .707 .577 .707 r
F P
0 g
s
.50276 .79316 m .50113 .75744 L .49816 .74581 L p .707 .577 .707 r
F P
0 g
s
.51923 .85627 m .51737 .83963 L .50449 .82627 L p .707 .577 .707 r
F P
0 g
s
.49462 .82353 m .48781 .32652 L .4438 .32408 L p .707 .577 .707 r
F P
0 g
s
.49862 .71843 m .4994 .66237 L .50647 .65511 L p .707 .577 .707 r
F P
0 g
s
.49816 .74581 m .49979 .78153 L .50276 .79316 L p .707 .577 .707 r
F P
0 g
s
.50647 .65511 m .5057 .71118 L .49862 .71843 L p .707 .577 .707 r
F P
0 g
s
.50635 .84291 m .50449 .82627 L .50123 .81083 L p .707 .577 .707 r
F P
0 g
s
.49979 .78153 m .49816 .74581 L .50517 .73402 L p .707 .577 .707 r
F P
0 g
s
.50123 .81083 m .50309 .82747 L .50635 .84291 L p .707 .577 .707 r
F P
0 g
s
.5057 .71118 m .50647 .65511 L .52283 .64885 L p .707 .577 .707 r
F P
0 g
s
.50517 .73402 m .5068 .76974 L .49979 .78153 L p .707 .577 .707 r
F P
0 g
s
.52283 .64885 m .52206 .70491 L .5057 .71118 L p .707 .577 .707 r
F P
0 g
s
.50309 .82747 m .50123 .81083 L .50791 .79482 L p .707 .577 .707 r
F P
0 g
s
.5068 .76974 m .50517 .73402 L .52146 .72323 L p .707 .577 .707 r
F P
0 g
s
.50791 .79482 m .50977 .81146 L .50309 .82747 L p .707 .577 .707 r
F P
0 g
s
.52206 .70491 m .52283 .64885 L .54688 .6442 L p .707 .577 .707 r
F P
0 g
s
.52146 .72323 m .52309 .75895 L .5068 .76974 L p .707 .577 .707 r
F P
0 g
s
.54688 .6442 m .5461 .70026 L .52206 .70491 L p .707 .577 .707 r
F P
0 g
s
.50977 .81146 m .50791 .79482 L .52387 .7798 L p .707 .577 .707 r
F P
0 g
s
.52309 .75895 m .52146 .72323 L .54544 .71449 L p .707 .577 .707 r
F P
0 g
s
.52387 .7798 m .52573 .79645 L .50977 .81146 L p .707 .577 .707 r
F P
0 g
s
.54544 .71449 m .54708 .75021 L .52309 .75895 L p .707 .577 .707 r
F P
0 g
s
.52573 .79645 m .52387 .7798 L .54756 .76726 L p .707 .577 .707 r
F P
0 g
s
.54756 .76726 m .54942 .7839 L .52573 .79645 L p .707 .577 .707 r
F P
0 g
s
.48781 .32652 m .49462 .82353 L .53956 .82174 L p .707 .577 .707 r
F P
0 g
s
.53956 .82174 m .53274 .32474 L .48781 .32652 L p .707 .577 .707 r
F P
0 g
s
.69764 .81518 m .6995 .83182 L .70618 .81581 L p .707 .577 .707 r
F P
0 g
s
.70618 .81581 m .70432 .79917 L .69764 .81518 L p .707 .577 .707 r
F P
0 g
s
.5461 .70026 m .54688 .6442 L .57625 .64161 L p .707 .577 .707 r
F P
0 g
s
.57625 .64161 m .57548 .69767 L .5461 .70026 L p .707 .577 .707 r
F P
0 g
s
.54708 .75021 m .54544 .71449 L .57477 .70866 L p .707 .577 .707 r
F P
0 g
s
.57477 .70866 m .5764 .74437 L .54708 .75021 L p .707 .577 .707 r
F P
0 g
s
.54942 .7839 m .54756 .76726 L .57666 .7584 L p .707 .577 .707 r
F P
0 g
s
.57666 .7584 m .57852 .77504 L .54942 .7839 L p .707 .577 .707 r
F P
0 g
s
.53274 .32474 m .53956 .82174 L .58103 .81589 L p .707 .577 .707 r
F P
0 g
s
.57548 .69767 m .57625 .64161 L .60809 .64134 L p .707 .577 .707 r
F P
0 g
s
.60809 .64134 m .60731 .69741 L .57548 .69767 L p .707 .577 .707 r
F P
0 g
s
.5764 .74437 m .57477 .70866 L .60657 .70631 L p .707 .577 .707 r
F P
0 g
s
.60657 .70631 m .6082 .74202 L .5764 .74437 L p .707 .577 .707 r
F P
0 g
s
.57852 .77504 m .57666 .7584 L .60831 .75411 L p .707 .577 .707 r
F P
0 g
s
.60831 .75411 m .61016 .77075 L .57852 .77504 L p .707 .577 .707 r
F P
0 g
s
.58103 .81589 m .57422 .31889 L .53274 .32474 L p .707 .577 .707 r
F P
0 g
s
.50449 .82627 m .50635 .84291 L .51923 .85627 L p .707 .577 .707 r
F P
0 g
s
.70191 .7426 m .70354 .77831 L .70057 .76668 L p .707 .577 .707 r
F P
0 g
s
.70057 .76668 m .69894 .73096 L .70191 .7426 L p .707 .577 .707 r
F P
0 g
s
.45061 .82108 m .4438 .32408 L .40503 .31764 L p .707 .577 .707 r
F P
0 g
s
.4438 .32408 m .45061 .82108 L .49462 .82353 L p .707 .577 .707 r
F P
0 g
s
.63773 .70766 m .63936 .74338 L .6082 .74202 L p .707 .577 .707 r
F P
0 g
s
.6082 .74202 m .60657 .70631 L .63773 .70766 L p .707 .577 .707 r
F P
0 g
s
.63941 .7548 m .64127 .77144 L .61016 .77075 L p .707 .577 .707 r
F P
0 g
s
.61016 .77075 m .60831 .75411 L .63941 .7548 L p .707 .577 .707 r
F P
0 g
s
.57422 .31889 m .58103 .81589 L .61498 .80656 L p .707 .577 .707 r
F P
0 g
s
.63926 .64342 m .63848 .69948 L .60731 .69741 L p .707 .577 .707 r
F P
0 g
s
.60731 .69741 m .60809 .64134 L .63926 .64342 L p .707 .577 .707 r
F P
0 g
s
.61498 .80656 m .60817 .30955 L .57422 .31889 L p .707 .577 .707 r
F P
0 g
s
.70037 .66067 m .6996 .71674 L .687 .70964 L p .707 .577 .707 r
F P
0 g
s
.687 .70964 m .68778 .65358 L .70037 .66067 L p .707 .577 .707 r
F P
0 g
s
.70432 .79917 m .70618 .81581 L .70292 .80037 L p .707 .577 .707 r
F P
0 g
s
.70292 .80037 m .70106 .78373 L .70432 .79917 L p .707 .577 .707 r
F P
0 g
s
.2508 .70849 m .25158 .65243 L .22041 .65035 L p .707 .577 .707 r
F P
0 g
s
.25158 .65243 m .2508 .70849 L .28263 .70823 L p .707 .577 .707 r
F P
0 g
s
.28263 .70823 m .28341 .65216 L .25158 .65243 L p .707 .577 .707 r
F P
0 g
s
.41185 .81465 m .40503 .31764 L .3753 .30784 L p .707 .577 .707 r
F P
0 g
s
.40503 .31764 m .41185 .81465 L .45061 .82108 L p .707 .577 .707 r
F P
0 g
s
.28341 .65216 m .28263 .70823 L .31201 .70564 L p .707 .577 .707 r
F P
0 g
s
.31201 .70564 m .31279 .64957 L .28341 .65216 L p .707 .577 .707 r
F P
0 g
s
.21963 .70642 m .22041 .65035 L .19295 .64614 L p .707 .577 .707 r
F P
0 g
s
.22041 .65035 m .21963 .70642 L .2508 .70849 L p .707 .577 .707 r
F P
0 g
s
.69894 .73096 m .70057 .76668 L .68793 .75634 L p .707 .577 .707 r
F P
0 g
s
.68793 .75634 m .68629 .72063 L .69894 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31279 .64957 m .31201 .70564 L .33606 .70099 L p .707 .577 .707 r
F P
0 g
s
.33606 .70099 m .33683 .64492 L .31279 .64957 L p .707 .577 .707 r
F P
0 g
s
.60817 .30955 m .61498 .80656 L .63808 .79465 L p .707 .577 .707 r
F P
0 g
s
.63808 .79465 m .63127 .29765 L .60817 .30955 L p .707 .577 .707 r
F P
0 g
s
.68778 .65358 m .687 .70964 L .66594 .7037 L p .707 .577 .707 r
F P
0 g
s
.66594 .7037 m .66672 .64763 L .68778 .65358 L p .707 .577 .707 r
F P
0 g
s
.19295 .64614 m .19217 .7022 L .21963 .70642 L p .707 .577 .707 r
F P
0 g
s
.19217 .7022 m .19295 .64614 L .17189 .64019 L p .707 .577 .707 r
F P
0 g
s
.25212 .781 m .25049 .74529 L .21933 .74393 L p .707 .577 .707 r
F P
0 g
s
.25049 .74529 m .25212 .781 L .28392 .77865 L p .707 .577 .707 r
F P
0 g
s
.28392 .77865 m .28229 .74294 L .25049 .74529 L p .707 .577 .707 r
F P
0 g
s
.28229 .74294 m .28392 .77865 L .31325 .77282 L p .707 .577 .707 r
F P
0 g
s
.31325 .77282 m .31161 .7371 L .28229 .74294 L p .707 .577 .707 r
F P
0 g
s
.70106 .78373 m .70292 .80037 L .69004 .78701 L p .707 .577 .707 r
F P
0 g
s
.69004 .78701 m .68818 .77037 L .70106 .78373 L p .707 .577 .707 r
F P
0 g
s
.22096 .77965 m .21933 .74393 L .19186 .73899 L p .707 .577 .707 r
F P
0 g
s
.21933 .74393 m .22096 .77965 L .25212 .781 L p .707 .577 .707 r
F P
0 g
s
.38212 .80484 m .3753 .30784 L .35752 .29563 L p .707 .577 .707 r
F P
0 g
s
.3753 .30784 m .38212 .80484 L .41185 .81465 L p .707 .577 .707 r
F P
0 g
s
.68629 .72063 m .68793 .75634 L .66683 .74832 L p .707 .577 .707 r
F P
0 g
s
.66683 .74832 m .6652 .7126 L .68629 .72063 L p .707 .577 .707 r
F P
0 g
s
.33683 .64492 m .33606 .70099 L .35242 .69472 L p .707 .577 .707 r
F P
0 g
s
.35242 .69472 m .35319 .63866 L .33683 .64492 L p .707 .577 .707 r
F P
0 g
s
.17189 .64019 m .17111 .69626 L .19217 .7022 L p .707 .577 .707 r
F P
0 g
s
.31161 .7371 m .31325 .77282 L .33723 .76408 L p .707 .577 .707 r
F P
0 g
s
.33723 .76408 m .3356 .72836 L .31161 .7371 L p .707 .577 .707 r
F P
0 g
s
.66672 .64763 m .66594 .7037 L .63848 .69948 L p .707 .577 .707 r
F P
0 g
s
.63848 .69948 m .63926 .64342 L .66672 .64763 L p .707 .577 .707 r
F P
0 g
s
.19186 .73899 m .19349 .77471 L .22096 .77965 L p .707 .577 .707 r
F P
0 g
s
.19349 .77471 m .19186 .73899 L .17077 .73097 L p .707 .577 .707 r
F P
0 g
s
.17111 .69626 m .17189 .64019 L .15929 .6331 L p .707 .577 .707 r
F P
0 g
s
.2561 .83572 m .25424 .81908 L .22313 .81839 L p .707 .577 .707 r
F P
0 g
s
.25424 .81908 m .2561 .83572 L .28775 .83143 L p .707 .577 .707 r
F P
0 g
s
.28775 .83143 m .28589 .81479 L .25424 .81908 L p .707 .577 .707 r
F P
0 g
s
.68818 .77037 m .69004 .78701 L .6688 .77704 L p .707 .577 .707 r
F P
0 g
s
.6688 .77704 m .66694 .7604 L .68818 .77037 L p .707 .577 .707 r
F P
0 g
s
.28589 .81479 m .28775 .83143 L .31684 .82257 L p .707 .577 .707 r
F P
0 g
s
.31684 .82257 m .31498 .80593 L .28589 .81479 L p .707 .577 .707 r
F P
0 g
s
.6652 .7126 m .66683 .74832 L .63936 .74338 L p .707 .577 .707 r
F P
0 g
s
.63936 .74338 m .63773 .70766 L .6652 .7126 L p .707 .577 .707 r
F P
0 g
s
.66694 .7604 m .6688 .77704 L .64127 .77144 L p .707 .577 .707 r
F P
0 g
s
.64127 .77144 m .63941 .7548 L .66694 .7604 L p .707 .577 .707 r
F P
0 g
s
.63127 .29765 m .63808 .79465 L .64807 .78134 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64125 .28433 L .63127 .29765 L p .707 .577 .707 r
F P
0 g
s
.3356 .72836 m .33723 .76408 L .35352 .75329 L p .707 .577 .707 r
F P
0 g
s
.35352 .75329 m .35189 .71757 L .3356 .72836 L p .707 .577 .707 r
F P
0 g
s
.15929 .6331 m .15851 .68916 L .17111 .69626 L p .707 .577 .707 r
F P
0 g
s
.17077 .73097 m .1724 .76668 L .19349 .77471 L p .707 .577 .707 r
F P
0 g
s
.22499 .83503 m .22313 .81839 L .19561 .81279 L p .707 .577 .707 r
F P
0 g
s
.22313 .81839 m .22499 .83503 L .2561 .83572 L p .707 .577 .707 r
F P
0 g
s
.35319 .63866 m .35242 .69472 L .35949 .68747 L p .707 .577 .707 r
F P
0 g
s
.35949 .68747 m .36027 .6314 L .35319 .63866 L p .707 .577 .707 r
F P
0 g
s
.31498 .80593 m .31684 .82257 L .34053 .81002 L p .707 .577 .707 r
F P
0 g
s
.34053 .81002 m .33867 .79338 L .31498 .80593 L p .707 .577 .707 r
F P
0 g
s
.1724 .76668 m .17077 .73097 L .15812 .72063 L p .707 .577 .707 r
F P
0 g
s
.19561 .81279 m .19747 .82943 L .22499 .83503 L p .707 .577 .707 r
F P
0 g
s
.36433 .79263 m .35752 .29563 L .35342 .28221 L p .707 .577 .707 r
F P
0 g
s
.35752 .29563 m .36433 .79263 L .38212 .80484 L p .707 .577 .707 r
F P
0 g
s
.15851 .68916 m .15929 .6331 L .15639 .62555 L p .707 .577 .707 r
F P
0 g
s
.19747 .82943 m .19561 .81279 L .17437 .80282 L p .707 .577 .707 r
F P
0 g
s
.35189 .71757 m .35352 .75329 L .36053 .7415 L p .707 .577 .707 r
F P
0 g
s
.36053 .7415 m .3589 .70578 L .35189 .71757 L p .707 .577 .707 r
F P
0 g
s
.33867 .79338 m .34053 .81002 L .35649 .79501 L p .707 .577 .707 r
F P
0 g
s
.35649 .79501 m .35463 .77837 L .33867 .79338 L p .707 .577 .707 r
F P
0 g
s
.15812 .72063 m .15975 .75635 L .1724 .76668 L p .707 .577 .707 r
F P
0 g
s
.17437 .80282 m .17622 .81946 L .19747 .82943 L p .707 .577 .707 r
F P
0 g
s
.15639 .62555 m .15561 .68162 L .15851 .68916 L p .707 .577 .707 r
F P
0 g
s
.36027 .6314 m .35949 .68747 L .35659 .67992 L p .707 .577 .707 r
F P
0 g
s
.35659 .67992 m .35737 .62385 L .36027 .6314 L p .707 .577 .707 r
F P
0 g
s
.15975 .75635 m .15812 .72063 L .15515 .709 L p .707 .577 .707 r
F P
0 g
s
.64807 .78134 m .64397 .76792 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64199 .33829 m .64807 .78134 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64125 .28433 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64397 .76792 m .64113 .56075 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.64113 .56075 m .63716 .27091 L p .64182 .38426 L .707 .577 .707 r
F P
0 g
s
.63716 .27091 m .64397 .76792 L .62619 .75571 L p .707 .577 .707 r
F P
0 g
s
.63833 .67198 m .63996 .7077 L .64056 .70819 L p .707 .577 .707 r
F P
0 g
s
.64056 .70819 m .65261 .71804 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.64067 .67952 m .63833 .67198 L .64056 .70819 L .707 .577 .707 r
F
.65261 .71804 m .65098 .68232 L .64069 .67391 L p F P
0 g
s
.64069 .67391 m .63833 .67198 L p .64067 .67952 L .707 .577 .707 r
F P
0 g
s
.65261 .71804 m .64069 .67391 L .64067 .67952 L .707 .577 .707 r
F
.64125 .28433 m .64199 .33829 L p .64182 .38426 L F P
0 g
s
.17622 .81946 m .17437 .80282 L .16148 .78946 L p .707 .577 .707 r
F P
0 g
s
.35463 .77837 m .35649 .79501 L .36317 .779 L p .707 .577 .707 r
F P
0 g
s
.36317 .779 m .36131 .76236 L .35463 .77837 L p .707 .577 .707 r
F P
0 g
s
.15561 .68162 m .15639 .62555 L .16346 .61829 L p .707 .577 .707 r
F P
0 g
s
.16148 .78946 m .16334 .8061 L .17622 .81946 L p .707 .577 .707 r
F P
0 g
s
.15515 .709 m .15679 .74471 L .15975 .75635 L p .707 .577 .707 r
F P
0 g
s
.3589 .70578 m .36053 .7415 L .35756 .72987 L p .707 .577 .707 r
F P
0 g
s
.35756 .72987 m .35593 .69415 L .3589 .70578 L p .707 .577 .707 r
F P
0 g
s
.36131 .76236 m .36317 .779 L .35991 .76356 L p .707 .577 .707 r
F P
0 g
s
.35991 .76356 m .35805 .74692 L .36131 .76236 L p .707 .577 .707 r
F P
0 g
s
.35342 .28221 m .36024 .77922 L .36433 .79263 L p .707 .577 .707 r
F P
0 g
s
.36024 .77922 m .35342 .28221 L .36341 .2689 L p .707 .577 .707 r
F P
0 g
s
.16346 .61829 m .16269 .67436 L .15561 .68162 L p .707 .577 .707 r
F P
0 g
s
.16334 .8061 m .16148 .78946 L .15822 .77402 L p .707 .577 .707 r
F P
0 g
s
.35737 .62385 m .35659 .67992 L .34399 .67283 L p .707 .577 .707 r
F P
0 g
s
.34399 .67283 m .34477 .61676 L .35737 .62385 L p .707 .577 .707 r
F P
0 g
s
.15679 .74471 m .15515 .709 L .16216 .69721 L p .707 .577 .707 r
F P
0 g
s
.15822 .77402 m .16008 .79066 L .16334 .8061 L p .707 .577 .707 r
F P
0 g
s
.16269 .67436 m .16346 .61829 L .17982 .61203 L p .707 .577 .707 r
F P
0 g
s
.16216 .69721 m .16379 .73292 L .15679 .74471 L p .707 .577 .707 r
F P
0 g
s
.35593 .69415 m .35756 .72987 L .34492 .71953 L p .707 .577 .707 r
F P
0 g
s
.34492 .71953 m .34328 .68381 L .35593 .69415 L p .707 .577 .707 r
F P
0 g
s
.62619 .75571 m .61937 .2587 L .63716 .27091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17982 .61203 m .17905 .6681 L .16269 .67436 L p .707 .577 .707 r
F P
0 g
s
.16008 .79066 m .15822 .77402 L .1649 .758 L p .707 .577 .707 r
F P
0 g
s
.34477 .61676 m .34399 .67283 L .32293 .66688 L p .707 .577 .707 r
F P
0 g
s
.32293 .66688 m .32371 .61082 L .34477 .61676 L p .707 .577 .707 r
F P
0 g
s
.16379 .73292 m .16216 .69721 L .17845 .68641 L p .707 .577 .707 r
F P
0 g
s
.37022 .7659 m .36341 .2689 L .38651 .25699 L p .707 .577 .707 r
F P
0 g
s
.36341 .2689 m .37022 .7659 L .36024 .77922 L p .707 .577 .707 r
F P
0 g
s
.35805 .74692 m .35991 .76356 L .34703 .7502 L p .707 .577 .707 r
F P
0 g
s
.34703 .7502 m .34517 .73356 L .35805 .74692 L p .707 .577 .707 r
F P
0 g
s
.1649 .758 m .16676 .77465 L .16008 .79066 L p .707 .577 .707 r
F P
0 g
s
.17905 .6681 m .17982 .61203 L .20387 .60738 L p .707 .577 .707 r
F P
0 g
s
.34328 .68381 m .34492 .71953 L .32383 .7115 L p .707 .577 .707 r
F P
0 g
s
.32383 .7115 m .32219 .67578 L .34328 .68381 L p .707 .577 .707 r
F P
0 g
s
.17845 .68641 m .18008 .72213 L .16379 .73292 L p .707 .577 .707 r
F P
0 g
s
.32371 .61082 m .32293 .66688 L .29547 .66267 L p .707 .577 .707 r
F P
0 g
s
.29547 .66267 m .29625 .6066 L .32371 .61082 L p .707 .577 .707 r
F P
0 g
s
.20387 .60738 m .20309 .66345 L .17905 .6681 L p .707 .577 .707 r
F P
0 g
s
.16676 .77465 m .1649 .758 L .18087 .74299 L p .707 .577 .707 r
F P
0 g
s
.18008 .72213 m .17845 .68641 L .20243 .67767 L p .707 .577 .707 r
F P
0 g
s
.61937 .2587 m .62619 .75571 L .59646 .74591 L p .707 .577 .707 r
F P
0 g
s
.59646 .74591 m .58964 .2489 L .61937 .2587 L p .707 .577 .707 r
F P
0 g
s
.20309 .66345 m .20387 .60738 L .23325 .60479 L p .707 .577 .707 r
F P
0 g
s
.34517 .73356 m .34703 .7502 L .32579 .74023 L p .707 .577 .707 r
F P
0 g
s
.32579 .74023 m .32393 .72359 L .34517 .73356 L p .707 .577 .707 r
F P
0 g
s
.18087 .74299 m .18272 .75963 L .16676 .77465 L p .707 .577 .707 r
F P
0 g
s
.32219 .67578 m .32383 .7115 L .29636 .70657 L p .707 .577 .707 r
F P
0 g
s
.29636 .70657 m .29472 .67085 L .32219 .67578 L p .707 .577 .707 r
F P
0 g
s
.29625 .6066 m .29547 .66267 L .2643 .66059 L p .707 .577 .707 r
F P
0 g
s
.2643 .66059 m .26508 .60452 L .29625 .6066 L p .707 .577 .707 r
F P
0 g
s
.20243 .67767 m .20407 .71339 L .18008 .72213 L p .707 .577 .707 r
F P
0 g
s
.23247 .66086 m .23325 .60479 L .26508 .60452 L p .707 .577 .707 r
F P
0 g
s
.23325 .60479 m .23247 .66086 L .20309 .66345 L p .707 .577 .707 r
F P
0 g
s
.38651 .25699 m .39332 .75399 L .37022 .7659 L p .707 .577 .707 r
F P
0 g
s
.39332 .75399 m .38651 .25699 L .42046 .24765 L p .707 .577 .707 r
F P
0 g
s
.26508 .60452 m .2643 .66059 L .23247 .66086 L p .707 .577 .707 r
F P
0 g
s
.20407 .71339 m .20243 .67767 L .23176 .67184 L p .707 .577 .707 r
F P
0 g
s
.73101 .65794 m .73179 .60187 L .70062 .5998 L p .707 .577 .707 r
F P
0 g
s
.73179 .60187 m .73101 .65794 L .76285 .65767 L p .707 .577 .707 r
F P
0 g
s
.76285 .65767 m .76362 .60161 L .73179 .60187 L p .707 .577 .707 r
F P
0 g
s
.18272 .75963 m .18087 .74299 L .20455 .73044 L p .707 .577 .707 r
F P
0 g
s
.76362 .60161 m .76285 .65767 L .79222 .65508 L p .707 .577 .707 r
F P
0 g
s
.79222 .65508 m .793 .59902 L .76362 .60161 L p .707 .577 .707 r
F P
0 g
s
.29472 .67085 m .29636 .70657 L .26519 .70521 L p .707 .577 .707 r
F P
0 g
s
.26519 .70521 m .26356 .66949 L .29472 .67085 L p .707 .577 .707 r
F P
0 g
s
.69984 .65586 m .70062 .5998 L .67316 .59558 L p .707 .577 .707 r
F P
0 g
s
.70062 .5998 m .69984 .65586 L .73101 .65794 L p .707 .577 .707 r
F P
0 g
s
.32393 .72359 m .32579 .74023 L .29826 .73462 L p .707 .577 .707 r
F P
0 g
s
.29826 .73462 m .2964 .71798 L .32393 .72359 L p .707 .577 .707 r
F P
0 g
s
.23339 .70756 m .23176 .67184 L .26356 .66949 L p .707 .577 .707 r
F P
0 g
s
.23176 .67184 m .23339 .70756 L .20407 .71339 L p .707 .577 .707 r
F P
0 g
s
.20455 .73044 m .20641 .74708 L .18272 .75963 L p .707 .577 .707 r
F P
0 g
s
.58964 .2489 m .59646 .74591 L .55769 .73947 L p .707 .577 .707 r
F P
0 g
s
.55769 .73947 m .55088 .24246 L .58964 .2489 L p .707 .577 .707 r
F P
0 g
s
.26356 .66949 m .26519 .70521 L .23339 .70756 L p .707 .577 .707 r
F P
0 g
s
.793 .59902 m .79222 .65508 L .81627 .65043 L p .707 .577 .707 r
F P
0 g
s
.81627 .65043 m .81705 .59437 L .793 .59902 L p .707 .577 .707 r
F P
0 g
s
.20641 .74708 m .20455 .73044 L .23365 .72159 L p .707 .577 .707 r
F P
0 g
s
.67316 .59558 m .67238 .65165 L .69984 .65586 L p .707 .577 .707 r
F P
0 g
s
.67238 .65165 m .67316 .59558 L .6521 .58964 L p .707 .577 .707 r
F P
0 g
s
.2964 .71798 m .29826 .73462 L .26716 .73394 L p .707 .577 .707 r
F P
0 g
s
.26716 .73394 m .2653 .71729 L .2964 .71798 L p .707 .577 .707 r
F P
0 g
s
.73233 .73236 m .7307 .69664 L .69954 .69528 L p .707 .577 .707 r
F P
0 g
s
.7307 .69664 m .73233 .73236 L .76413 .73001 L p .707 .577 .707 r
F P
0 g
s
.76413 .73001 m .7625 .69429 L .7307 .69664 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .42046 .24765 L .46193 .24181 L p .707 .577 .707 r
F P
0 g
s
.42727 .74466 m .39332 .75399 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.42443 .53749 m .42727 .74466 L p .40973 .4479 L .707 .577 .707 r
F P
0 g
s
.46193 .24181 m .46875 .73881 L .42727 .74466 L p .707 .577 .707 r
F P
0 g
s
.41949 .65747 m .42112 .69319 L .44907 .68763 L p .707 .577 .707 r
F P
0 g
s
.44907 .68763 m .45045 .68736 L p .44876 .68573 L .707 .577 .707 r
F P
0 g
s
.44876 .68573 m .41949 .65747 L .44907 .68763 L .707 .577 .707 r
F
.42046 .24765 m .42443 .53749 L p .40973 .4479 L F P
0 g
s
.7625 .69429 m .76413 .73001 L .79346 .72417 L p .707 .577 .707 r
F P
0 g
s
.79346 .72417 m .79183 .68846 L .7625 .69429 L p .707 .577 .707 r
F P
0 g
s
.23365 .72159 m .23551 .73823 L .20641 .74708 L p .707 .577 .707 r
F P
0 g
s
.23551 .73823 m .23365 .72159 L .2653 .71729 L p .707 .577 .707 r
F P
0 g
s
.70117 .731 m .69954 .69528 L .67207 .69035 L p .707 .577 .707 r
F P
0 g
s
.69954 .69528 m .70117 .731 L .73233 .73236 L p .707 .577 .707 r
F P
0 g
s
.2653 .71729 m .26716 .73394 L .23551 .73823 L p .707 .577 .707 r
F P
0 g
s
.55088 .24246 m .55769 .73947 L .51368 .73702 L p .707 .577 .707 r
F P
0 g
s
.51368 .73702 m .50687 .24002 L .55088 .24246 L p .707 .577 .707 r
F P
0 g
s
.81705 .59437 m .81627 .65043 L .83263 .64417 L p .707 .577 .707 r
F P
0 g
s
.83263 .64417 m .83341 .5881 L .81705 .59437 L p .707 .577 .707 r
F P
0 g
s
.6521 .58964 m .65133 .6457 L .67238 .65165 L p .707 .577 .707 r
F P
0 g
s
.79183 .68846 m .79346 .72417 L .81744 .71543 L p .707 .577 .707 r
F P
0 g
s
.81744 .71543 m .81581 .67972 L .79183 .68846 L p .707 .577 .707 r
F P
0 g
s
.46875 .73881 m .46193 .24181 L .50687 .24002 L p .707 .577 .707 r
F P
0 g
s
.50687 .24002 m .51368 .73702 L .46875 .73881 L p .707 .577 .707 r
F P
0 g
s
.67207 .69035 m .6737 .72606 L .70117 .731 L p .707 .577 .707 r
F P
0 g
s
.65133 .6457 m .6521 .58964 L .6395 .58254 L p .707 .577 .707 r
F P
0 g
s
.6737 .72606 m .67207 .69035 L .65098 .68232 L p .707 .577 .707 r
F P
0 g
s
.73631 .78292 m .73445 .76628 L .70334 .76559 L p .707 .577 .707 r
F P
0 g
s
.73445 .76628 m .73631 .78292 L .76796 .77863 L p .707 .577 .707 r
F P
0 g
s
.76796 .77863 m .7661 .76199 L .73445 .76628 L p .707 .577 .707 r
F P
0 g
s
.7661 .76199 m .76796 .77863 L .79705 .76977 L p .707 .577 .707 r
F P
0 g
s
.79705 .76977 m .79519 .75313 L .7661 .76199 L p .707 .577 .707 r
F P
0 g
s
.81581 .67972 m .81744 .71543 L .83374 .70464 L p .707 .577 .707 r
F P
0 g
s
.83374 .70464 m .8321 .66892 L .81581 .67972 L p .707 .577 .707 r
F P
0 g
s
.6395 .58254 m .63873 .63861 L .65133 .6457 L p .707 .577 .707 r
F P
0 g
s
.7052 .78223 m .70334 .76559 L .67582 .75999 L p .707 .577 .707 r
F P
0 g
s
.70334 .76559 m .7052 .78223 L .73631 .78292 L p .707 .577 .707 r
F P
0 g
s
.65098 .68232 m .65261 .71804 L .6737 .72606 L p .707 .577 .707 r
F P
0 g
s
.83341 .5881 m .83263 .64417 L .83971 .63691 L p .707 .577 .707 r
F P
0 g
s
.83971 .63691 m .84048 .58085 L .83341 .5881 L p .707 .577 .707 r
F P
0 g
s
.79519 .75313 m .79705 .76977 L .82074 .75723 L p .707 .577 .707 r
F P
0 g
s
.82074 .75723 m .81888 .74058 L .79519 .75313 L p .707 .577 .707 r
F P
0 g
s
.67582 .75999 m .67768 .77663 L .7052 .78223 L p .707 .577 .707 r
F P
0 g
s
.63873 .63861 m .6395 .58254 L .6366 .575 L p .707 .577 .707 r
F P
0 g
s
.67768 .77663 m .67582 .75999 L .65458 .75002 L p .707 .577 .707 r
F P
0 g
s
.81888 .74058 m .82074 .75723 L .83671 .74221 L p .707 .577 .707 r
F P
0 g
s
.83671 .74221 m .83485 .72557 L .81888 .74058 L p .707 .577 .707 r
F P
0 g
s
.8321 .66892 m .83374 .70464 L .84074 .69285 L p .707 .577 .707 r
F P
0 g
s
.84074 .69285 m .83911 .65713 L .8321 .66892 L p .707 .577 .707 r
F P
0 g
s
.65458 .75002 m .65644 .76666 L .67768 .77663 L p .707 .577 .707 r
F P
0 g
s
.6366 .575 m .63582 .63106 L .63873 .63861 L p .707 .577 .707 r
F P
0 g
s
.84048 .58085 m .83971 .63691 L .8368 .62937 L p .707 .577 .707 r
F P
0 g
s
.8368 .62937 m .83758 .5733 L .84048 .58085 L p .707 .577 .707 r
F P
0 g
s
.63996 .7077 m .63833 .67198 L .63537 .66035 L p .707 .577 .707 r
F P
0 g
s
.65644 .76666 m .65458 .75002 L .6417 .73666 L p .707 .577 .707 r
F P
0 g
s
.83485 .72557 m .83671 .74221 L .84338 .7262 L p .707 .577 .707 r
F P
0 g
s
.84338 .7262 m .84152 .70956 L .83485 .72557 L p .707 .577 .707 r
F P
0 g
s
.63582 .63106 m .6366 .575 L .64367 .56774 L p .707 .577 .707 r
F P
0 g
s
.6417 .73666 m .64356 .7533 L .65644 .76666 L p .707 .577 .707 r
F P
0 g
s
.63537 .66035 m .637 .69607 L .63996 .7077 L p .707 .577 .707 r
F P
0 g
s
.83911 .65713 m .84074 .69285 L .83778 .68122 L p .707 .577 .707 r
F P
0 g
s
.83778 .68122 m .83614 .6455 L .83911 .65713 L p .707 .577 .707 r
F P
0 g
s
.64367 .56774 m .6429 .62381 L .63582 .63106 L p .707 .577 .707 r
F P
0 g
s
.64356 .7533 m .6417 .73666 L .63844 .72122 L p .707 .577 .707 r
F P
0 g
s
.83758 .5733 m .8368 .62937 L .82421 .62227 L p .707 .577 .707 r
F P
0 g
s
.82421 .62227 m .82498 .56621 L .83758 .5733 L p .707 .577 .707 r
F P
0 g
s
.637 .69607 m .63537 .66035 L .64237 .64856 L p .707 .577 .707 r
F P
0 g
s
.84152 .70956 m .84338 .7262 L .84012 .71076 L p .707 .577 .707 r
F P
0 g
s
.84012 .71076 m .83826 .69412 L .84152 .70956 L p .707 .577 .707 r
F P
0 g
s
.38801 .62113 m .38878 .56506 L .35761 .56298 L p .707 .577 .707 r
F P
0 g
s
.38878 .56506 m .38801 .62113 L .41984 .62086 L p .707 .577 .707 r
F P
0 g
s
.41984 .62086 m .42061 .56479 L .38878 .56506 L p .707 .577 .707 r
F P
0 g
s
.63844 .72122 m .6403 .73786 L .64356 .7533 L p .707 .577 .707 r
F P
0 g
s
.42061 .56479 m .41984 .62086 L .44921 .61827 L p .707 .577 .707 r
F P
0 g
s
.44921 .61827 m .44999 .5622 L .42061 .56479 L p .707 .577 .707 r
F P
0 g
s
.6429 .62381 m .64367 .56774 L .66004 .56148 L p .707 .577 .707 r
F P
0 g
s
.35683 .61905 m .35761 .56298 L .33015 .55877 L p .707 .577 .707 r
F P
0 g
s
.35761 .56298 m .35683 .61905 L .38801 .62113 L p .707 .577 .707 r
F P
0 g
s
.64237 .64856 m .64401 .68428 L .637 .69607 L p .707 .577 .707 r
F P
0 g
s
.83614 .6455 m .83778 .68122 L .82513 .67088 L p .707 .577 .707 r
F P
0 g
s
.82513 .67088 m .8235 .63517 L .83614 .6455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44999 .5622 m .44921 .61827 L .47326 .61362 L p .707 .577 .707 r
F P
0 g
s
.47326 .61362 m .47404 .55755 L .44999 .5622 L p .707 .577 .707 r
F P
0 g
s
.66004 .56148 m .65926 .61754 L .6429 .62381 L p .707 .577 .707 r
F P
0 g
s
.6403 .73786 m .63844 .72122 L .64511 .70521 L p .707 .577 .707 r
F P
0 g
s
.82498 .56621 m .82421 .62227 L .80315 .61633 L p .707 .577 .707 r
F P
0 g
s
.80315 .61633 m .80392 .56026 L .82498 .56621 L p .707 .577 .707 r
F P
0 g
s
.33015 .55877 m .32937 .61483 L .35683 .61905 L p .707 .577 .707 r
F P
0 g
s
.32937 .61483 m .33015 .55877 L .30909 .55282 L p .707 .577 .707 r
F P
0 g
s
.64401 .68428 m .64237 .64856 L .65866 .63777 L p .707 .577 .707 r
F P
0 g
s
.38932 .69554 m .38769 .65983 L .35653 .65847 L p .707 .577 .707 r
F P
0 g
s
.38769 .65983 m .38932 .69554 L .42112 .69319 L p .707 .577 .707 r
F P
0 g
s
.42112 .69319 m .41949 .65747 L .38769 .65983 L p .707 .577 .707 r
F P
0 g
s
.45045 .68736 m .44882 .65164 L .41949 .65747 L p .707 .577 .707 r
F P
0 g
s
.83826 .69412 m .84012 .71076 L .82724 .6974 L p .707 .577 .707 r
F P
0 g
s
.82724 .6974 m .82538 .68076 L .83826 .69412 L p .707 .577 .707 r
F P
0 g
s
.64511 .70521 m .64697 .72185 L .6403 .73786 L p .707 .577 .707 r
F P
0 g
s
.65926 .61754 m .66004 .56148 L .68408 .55683 L p .707 .577 .707 r
F P
0 g
s
.35816 .69418 m .35653 .65847 L .32906 .65353 L p .707 .577 .707 r
F P
0 g
s
.35653 .65847 m .35816 .69418 L .38932 .69554 L p .707 .577 .707 r
F P
0 g
s
.8235 .63517 m .82513 .67088 L .80404 .66285 L p .707 .577 .707 r
F P
0 g
s
.80404 .66285 m .80241 .62714 L .8235 .63517 L p .707 .577 .707 r
F P
0 g
s
.47404 .55755 m .47326 .61362 L .48962 .60735 L p .707 .577 .707 r
F P
0 g
s
.48962 .60735 m .4904 .55129 L .47404 .55755 L p .707 .577 .707 r
F P
0 g
s
.30909 .55282 m .30832 .60889 L .32937 .61483 L p .707 .577 .707 r
F P
0 g
s
.65866 .63777 m .6603 .67348 L .64401 .68428 L p .707 .577 .707 r
F P
0 g
s
.44882 .65164 m .45045 .68736 L .47443 .67862 L p .707 .577 .707 r
F P
0 g
s
.47443 .67862 m .4728 .6429 L .44882 .65164 L p .707 .577 .707 r
F P
0 g
s
.80392 .56026 m .80315 .61633 L .77569 .61211 L p .707 .577 .707 r
F P
0 g
s
.77569 .61211 m .77646 .55605 L .80392 .56026 L p .707 .577 .707 r
F P
0 g
s
.68408 .55683 m .68331 .61289 L .65926 .61754 L p .707 .577 .707 r
F P
0 g
s
.32906 .65353 m .33069 .68925 L .35816 .69418 L p .707 .577 .707 r
F P
0 g
s
.64697 .72185 m .64511 .70521 L .66108 .69019 L p .707 .577 .707 r
F P
0 g
s
.30832 .60889 m .30909 .55282 L .29649 .54573 L p .707 .577 .707 r
F P
0 g
s
.33069 .68925 m .32906 .65353 L .30797 .6455 L p .707 .577 .707 r
F P
0 g
s
.6603 .67348 m .65866 .63777 L .68265 .62903 L p .707 .577 .707 r
F P
0 g
s
.68331 .61289 m .68408 .55683 L .71346 .55424 L p .707 .577 .707 r
F P
0 g
s
.3933 .74611 m .39144 .72946 L .36033 .72878 L p .707 .577 .707 r
F P
0 g
s
.39144 .72946 m .3933 .74611 L .42495 .74181 L p .707 .577 .707 r
F P
0 g
s
.42495 .74181 m .42309 .72517 L .39144 .72946 L p .707 .577 .707 r
F P
0 g
s
.82538 .68076 m .82724 .6974 L .806 .68743 L p .707 .577 .707 r
F P
0 g
s
.806 .68743 m .80414 .67079 L .82538 .68076 L p .707 .577 .707 r
F P
0 g
s
.42309 .72517 m .42495 .74181 L .45404 .73296 L p .707 .577 .707 r
F P
0 g
s
.45404 .73296 m .45218 .71632 L .42309 .72517 L p .707 .577 .707 r
F P
0 g
s
.66108 .69019 m .66294 .70683 L .64697 .72185 L p .707 .577 .707 r
F P
0 g
s
.4728 .6429 m .47443 .67862 L .49073 .66783 L p .707 .577 .707 r
F P
0 g
s
.49073 .66783 m .48909 .63211 L .4728 .6429 L p .707 .577 .707 r
F P
0 g
s
.80241 .62714 m .80404 .66285 L .77657 .65792 L p .707 .577 .707 r
F P
0 g
s
.77657 .65792 m .77494 .6222 L .80241 .62714 L p .707 .577 .707 r
F P
0 g
s
.77646 .55605 m .77569 .61211 L .74452 .61004 L p .707 .577 .707 r
F P
0 g
s
.74452 .61004 m .74529 .55397 L .77646 .55605 L p .707 .577 .707 r
F P
0 g
s
.29649 .54573 m .29572 .60179 L .30832 .60889 L p .707 .577 .707 r
F P
0 g
s
.36219 .74542 m .36033 .72878 L .33281 .72317 L p .707 .577 .707 r
F P
0 g
s
.36033 .72878 m .36219 .74542 L .3933 .74611 L p .707 .577 .707 r
F P
0 g
s
.30797 .6455 m .3096 .68122 L .33069 .68925 L p .707 .577 .707 r
F P
0 g
s
.68265 .62903 m .68428 .66474 L .6603 .67348 L p .707 .577 .707 r
F P
0 g
s
.4904 .55129 m .48962 .60735 L .4967 .6001 L p .707 .577 .707 r
F P
0 g
s
.4967 .6001 m .49747 .54403 L .4904 .55129 L p .707 .577 .707 r
F P
0 g
s
.71268 .6103 m .71346 .55424 L .74529 .55397 L p .707 .577 .707 r
F P
0 g
s
.71346 .55424 m .71268 .6103 L .68331 .61289 L p .707 .577 .707 r
F P
0 g
s
.45218 .71632 m .45404 .73296 L .47773 .72041 L p .707 .577 .707 r
F P
0 g
s
.47773 .72041 m .47587 .70377 L .45218 .71632 L p .707 .577 .707 r
F P
0 g
s
.74529 .55397 m .74452 .61004 L .71268 .6103 L p .707 .577 .707 r
F P
0 g
s
.68428 .66474 m .68265 .62903 L .71198 .6232 L p .707 .577 .707 r
F P
0 g
s
.66294 .70683 m .66108 .69019 L .68477 .67764 L p .707 .577 .707 r
F P
0 g
s
.3096 .68122 m .30797 .6455 L .29532 .63517 L p .707 .577 .707 r
F P
0 g
s
.33281 .72317 m .33467 .73981 L .36219 .74542 L p .707 .577 .707 r
F P
0 g
s
.77494 .6222 m .77657 .65792 L .74541 .65656 L p .707 .577 .707 r
F P
0 g
s
.74541 .65656 m .74378 .62084 L .77494 .6222 L p .707 .577 .707 r
F P
0 g
s
.29572 .60179 m .29649 .54573 L .29359 .53818 L p .707 .577 .707 r
F P
0 g
s
.80414 .67079 m .806 .68743 L .77848 .68183 L p .707 .577 .707 r
F P
0 g
s
.77848 .68183 m .77662 .66518 L .80414 .67079 L p .707 .577 .707 r
F P
0 g
s
.33467 .73981 m .33281 .72317 L .31157 .7132 L p .707 .577 .707 r
F P
0 g
s
.68477 .67764 m .68663 .69428 L .66294 .70683 L p .707 .577 .707 r
F P
0 g
s
.71361 .65891 m .71198 .6232 L .74378 .62084 L p .707 .577 .707 r
F P
0 g
s
.71198 .6232 m .71361 .65891 L .68428 .66474 L p .707 .577 .707 r
F P
0 g
s
.74378 .62084 m .74541 .65656 L .71361 .65891 L p .707 .577 .707 r
F P
0 g
s
.47587 .70377 m .47773 .72041 L .4937 .7054 L p .707 .577 .707 r
F P
0 g
s
.4937 .7054 m .49184 .68875 L .47587 .70377 L p .707 .577 .707 r
F P
0 g
s
.48909 .63211 m .49073 .66783 L .49773 .65604 L p .707 .577 .707 r
F P
0 g
s
.49773 .65604 m .4961 .62032 L .48909 .63211 L p .707 .577 .707 r
F P
0 g
s
.29532 .63517 m .29695 .67088 L .3096 .68122 L p .707 .577 .707 r
F P
0 g
s
.31157 .7132 m .31343 .72984 L .33467 .73981 L p .707 .577 .707 r
F P
0 g
s
.68663 .69428 m .68477 .67764 L .71386 .66879 L p .707 .577 .707 r
F P
0 g
s
.29359 .53818 m .29281 .59425 L .29572 .60179 L p .707 .577 .707 r
F P
0 g
s
.77662 .66518 m .77848 .68183 L .74737 .68114 L p .707 .577 .707 r
F P
0 g
s
.74737 .68114 m .74551 .66449 L .77662 .66518 L p .707 .577 .707 r
F P
0 g
s
.49747 .54403 m .4967 .6001 L .49379 .59255 L p .707 .577 .707 r
F P
0 g
s
.49379 .59255 m .49457 .53649 L .49747 .54403 L p .707 .577 .707 r
F P
0 g
s
.71386 .66879 m .71572 .68543 L .68663 .69428 L p .707 .577 .707 r
F P
0 g
s
.71572 .68543 m .71386 .66879 L .74551 .66449 L p .707 .577 .707 r
F P
0 g
s
.29695 .67088 m .29532 .63517 L .29236 .62354 L p .707 .577 .707 r
F P
0 g
s
.31343 .72984 m .31157 .7132 L .29869 .69984 L p .707 .577 .707 r
F P
0 g
s
.74551 .66449 m .74737 .68114 L .71572 .68543 L p .707 .577 .707 r
F P
0 g
s
.49184 .68875 m .4937 .7054 L .50037 .68938 L p .707 .577 .707 r
F P
0 g
s
.50037 .68938 m .49851 .67274 L .49184 .68875 L p .707 .577 .707 r
F P
0 g
s
.29281 .59425 m .29359 .53818 L .30066 .53092 L p .707 .577 .707 r
F P
0 g
s
.29869 .69984 m .30055 .71648 L .31343 .72984 L p .707 .577 .707 r
F P
0 g
s
.29236 .62354 m .29399 .65925 L .29695 .67088 L p .707 .577 .707 r
F P
0 g
s
.4961 .62032 m .49773 .65604 L .49477 .6444 L p .707 .577 .707 r
F P
0 g
s
.49477 .6444 m .49313 .60869 L .4961 .62032 L p .707 .577 .707 r
F P
0 g
s
.30066 .53092 m .29989 .58699 L .29281 .59425 L p .707 .577 .707 r
F P
0 g
s
.30055 .71648 m .29869 .69984 L .29542 .6844 L p .707 .577 .707 r
F P
0 g
s
.49457 .53649 m .49379 .59255 L .4812 .58546 L p .707 .577 .707 r
F P
0 g
s
.4812 .58546 m .48197 .52939 L .49457 .53649 L p .707 .577 .707 r
F P
0 g
s
.29399 .65925 m .29236 .62354 L .29936 .61175 L p .707 .577 .707 r
F P
0 g
s
.49851 .67274 m .50037 .68938 L .49711 .67394 L p .707 .577 .707 r
F P
0 g
s
.49711 .67394 m .49525 .6573 L .49851 .67274 L p .707 .577 .707 r
F P
0 g
s
.29542 .6844 m .29728 .70104 L .30055 .71648 L p .707 .577 .707 r
F P
0 g
s
.29989 .58699 m .30066 .53092 L .31703 .52466 L p .707 .577 .707 r
F P
0 g
s
.29936 .61175 m .30099 .64746 L .29399 .65925 L p .707 .577 .707 r
F P
0 g
s
.49313 .60869 m .49477 .6444 L .48212 .63407 L p .707 .577 .707 r
F P
0 g
s
.48212 .63407 m .48049 .59835 L .49313 .60869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31703 .52466 m .31625 .58073 L .29989 .58699 L p .707 .577 .707 r
F P
0 g
s
.29728 .70104 m .29542 .6844 L .3021 .66839 L p .707 .577 .707 r
F P
0 g
s
.48197 .52939 m .4812 .58546 L .46014 .57951 L p .707 .577 .707 r
F P
0 g
s
.46014 .57951 m .46091 .52345 L .48197 .52939 L p .707 .577 .707 r
F P
0 g
s
.30099 .64746 m .29936 .61175 L .31565 .60095 L p .707 .577 .707 r
F P
0 g
s
.49525 .6573 m .49711 .67394 L .48423 .66058 L p .707 .577 .707 r
F P
0 g
s
.48423 .66058 m .48237 .64394 L .49525 .6573 L p .707 .577 .707 r
F P
0 g
s
.3021 .66839 m .30396 .68503 L .29728 .70104 L p .707 .577 .707 r
F P
0 g
s
.31625 .58073 m .31703 .52466 L .34107 .52001 L p .707 .577 .707 r
F P
0 g
s
.48049 .59835 m .48212 .63407 L .46103 .62604 L p .707 .577 .707 r
F P
0 g
s
.46103 .62604 m .4594 .59032 L .48049 .59835 L p .707 .577 .707 r
F P
0 g
s
.31565 .60095 m .31729 .63667 L .30099 .64746 L p .707 .577 .707 r
F P
0 g
s
.46091 .52345 m .46014 .57951 L .43268 .5753 L p .707 .577 .707 r
F P
0 g
s
.43268 .5753 m .43345 .51923 L .46091 .52345 L p .707 .577 .707 r
F P
0 g
s
.34107 .52001 m .3403 .57608 L .31625 .58073 L p .707 .577 .707 r
F P
0 g
s
.30396 .68503 m .3021 .66839 L .31807 .65337 L p .707 .577 .707 r
F P
0 g
s
.31729 .63667 m .31565 .60095 L .33964 .59221 L p .707 .577 .707 r
F P
0 g
s
.3403 .57608 m .34107 .52001 L .37045 .51742 L p .707 .577 .707 r
F P
0 g
s
.48237 .64394 m .48423 .66058 L .46299 .65061 L p .707 .577 .707 r
F P
0 g
s
.46299 .65061 m .46113 .63397 L .48237 .64394 L p .707 .577 .707 r
F P
0 g
s
.31807 .65337 m .31993 .67002 L .30396 .68503 L p .707 .577 .707 r
F P
0 g
s
.4594 .59032 m .46103 .62604 L .43356 .6211 L p .707 .577 .707 r
F P
0 g
s
.43356 .6211 m .43193 .58539 L .4594 .59032 L p .707 .577 .707 r
F P
0 g
s
.43345 .51923 m .43268 .5753 L .40151 .57322 L p .707 .577 .707 r
F P
0 g
s
.40151 .57322 m .40228 .51715 L .43345 .51923 L p .707 .577 .707 r
F P
0 g
s
.33964 .59221 m .34127 .62793 L .31729 .63667 L p .707 .577 .707 r
F P
0 g
s
.36967 .57349 m .37045 .51742 L .40228 .51715 L p .707 .577 .707 r
F P
0 g
s
.37045 .51742 m .36967 .57349 L .3403 .57608 L p .707 .577 .707 r
F P
0 g
s
.40228 .51715 m .40151 .57322 L .36967 .57349 L p .707 .577 .707 r
F P
0 g
s
.34127 .62793 m .33964 .59221 L .36896 .58638 L p .707 .577 .707 r
F P
0 g
s
.31993 .67002 m .31807 .65337 L .34176 .64083 L p .707 .577 .707 r
F P
0 g
s
.43193 .58539 m .43356 .6211 L .4024 .61975 L p .707 .577 .707 r
F P
0 g
s
.4024 .61975 m .40077 .58403 L .43193 .58539 L p .707 .577 .707 r
F P
0 g
s
.46113 .63397 m .46299 .65061 L .43547 .64501 L p .707 .577 .707 r
F P
0 g
s
.43547 .64501 m .43361 .62837 L .46113 .63397 L p .707 .577 .707 r
F P
0 g
s
.34176 .64083 m .34362 .65747 L .31993 .67002 L p .707 .577 .707 r
F P
0 g
s
.3706 .6221 m .36896 .58638 L .40077 .58403 L p .707 .577 .707 r
F P
0 g
s
.36896 .58638 m .3706 .6221 L .34127 .62793 L p .707 .577 .707 r
F P
0 g
s
.40077 .58403 m .4024 .61975 L .3706 .6221 L p .707 .577 .707 r
F P
0 g
s
.34362 .65747 m .34176 .64083 L .37085 .63197 L p .707 .577 .707 r
F P
0 g
s
.43361 .62837 m .43547 .64501 L .40436 .64432 L p .707 .577 .707 r
F P
0 g
s
.40436 .64432 m .4025 .62768 L .43361 .62837 L p .707 .577 .707 r
F P
0 g
s
.37085 .63197 m .37271 .64861 L .34362 .65747 L p .707 .577 .707 r
F P
0 g
s
.37271 .64861 m .37085 .63197 L .4025 .62768 L p .707 .577 .707 r
F P
0 g
s
.4025 .62768 m .40436 .64432 L .37271 .64861 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00Kgoo100015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qoo`00IWoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D005YFFUIJ
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005moob0000EJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00G7oo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000aJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00FGoo0`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001GOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P003goo4@00AGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo20000eYF
00<005YFFUH01UYF00<005YFFUH00UYF2000?Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000Woo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH003Moo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00
Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000`Ool005=oo`03001J
EP0000=JEP03001JEUYF00=JEQl000AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00Dgoo00<005YF00000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo001COol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUH0000F00000eYF001J
EP05FUH30003FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF00=J
EP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00
FUIJEP0200000eYF00000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`80009JEP03001JEUYF
00=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00=JEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YFFUIJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080
00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo0P000UYF00@005YF000000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Agoo2@0017oo00<005YFFUH00`001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000=JEP00000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`l000AJEP03001JEUYF009JEPP0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo000aOol40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF200015YF00<005YF
FUH00eYF00<005YFFUH00P00;Woo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00AJEQD000IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF3`000eYF00<005YFFUH00eYF10000UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH00`00FUIJEP07FUH20003FUH40002FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEP00FUH00P0000=JEP00FUH015YF00<005YFFUH01EYF200015YF00<005YFFUH01UYF
00<005YF00000`001UYF00<005YFFUH01000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH4
00001EYF001JEUYF00001EYF3`0015YF100015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF00001@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@005YFFUIJEP<002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00@005YFFUIJEP80009JEP04001JEUYF0002FUH60004FUH00`00FUIJ
EP06FUH00`00FUH000030004FUH3000015YF001JEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0`00;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00004FUH01000FUH0000015YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000AJEP00FUIJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00004FUH20006FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300001UYF000005YF001JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00003FUH01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0002FUH200000eYF001JEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000UYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P0000AJ
EP00000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00FUH005YF1@000eYF00<005YF
FUH015YF1P0000=JEP00FUH025YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF008000EJEP03001JEUYF00@00003
FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00T000AJEP05001JEP00FUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH01000FUH000001UYF0`0000=JEP0000000UYF00<005YFFUH0
0eYF00@005YFFUIJEPT000=JEP03001JEUYF00=JEP<00004FUH005YFFUH20004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0003FUH20002FUH20000
0eYF001JEP03FUH20002FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000000UYF
00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH50002FUH01000FUIJ
EP000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00@000Qoo`L000Qoo`H000AJEP03001JEUYF
008002ioo`00;7oo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP@0009JEP03001oogoo00=oo`@0009J
EP03001JEUYF009JEPP000Ioo`<00003FUH005YF009JEP03001oogoo02aoo`00;7oo00@005YF001J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEQ0000AJEP04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF00000004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YFFUIJ
EP00FUH40002FUH01P00FUIJEUYF001oo`@000IJEP03001JEUYF00IJEP04001JEUYFFUH50004Ool2
0003FUH00`00Oomoo`0/Ool002aoo`03001JEP00008000EJEP03001JEUYF00EJEPP000AJEP03001J
EUYF00IJEP<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF0`001EYF00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF0`000goo0P000UYF00<007ooOol0;7oo
000/Ool20002FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUH0009JEP03001JEUYF009JEP<000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0009JEP<002ioo`00;7oo
0P000UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00@005YF
FUIJEP8000IJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF0`000eYF00<005YFFUH00`0025YF00<005YFFUH00UYF3`001UYF00@005YFFUIJEP800004
FUH005YF000^Ool002aoo`80009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF1@00
15YF00<005YFFUH01UYF00H005YF000005YF0005FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF0P000UYF0`000UYF00<005YFFUH0
1EYF1P003goo10000UYF00<005YFFUH00UYF0`0000=JEP00Ool0;Goo000]Ool01@00FUIJEP00FUH0
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP800003
FUH005YF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00AJEP@000=JEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YF00000P001EYF00<005YFFUH00UYF0P005Goo1`0015YF00D005YF001JEP0002ioo`00
;Woo1@001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001EYF00<0
05YF000010000eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010001eYF00<005YFFUH00UYF0P00
0UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH0
0`00FUH00007FUH00`00FUH00002000COol40002FUH00`00FUIJEP02FUH20003FUH01000FUH00000
;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0005FUH00`00FUIJEP03FUHI000;FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`001eYF20002Goo1`001UYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0002ioo`00;Woo00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP0000EJEP8000=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001oogoo02aoo`00;Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYF0003FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YF
FUIJEP00009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHF00000eYF000000020002FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP05001JEUYF001oo`03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPH0
01Ioo`05001JEUYF001oo`040004FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH20003FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=oo`8002eoo`00;7oo00<005YF000015YF
00@005YFFUIJEP80011oo`L000Eoo`03001JEUYF00<000=oo`<00004FUH005YFFUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH20009FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool2000]
Ool002aoo`03001JEP0000AJEP04001JEP00000>Ool40002FUH00`00FUIJEP02FUH7000015YF001J
EUYF0P0017oo0P000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEP800003
FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YF100015YF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF
00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00004FUH2000<Ool40006FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000=JEP<0009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF
00MJEP@000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYFFUH005YF0P000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF1@0015YF00<0
05YFFUH015YF0`002Woo00<005YF0000;Goo000/Ool00`00FUH00002FUH2000:Ool400000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF00001P000UYF00<005YFFUH00eYF
00<005YFFUH00UYF1P001eYF00<005YFFUH00P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP@000AJEPH000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00@0
00eoo`03001JEP0002eoo`00;7oo00<005YF00000P002Goo0`001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF400015YF00<005YFFUH01UYF
0`0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP@000AJEP03001JEUYF00=JEPT000AJEP@00003FUH0000000D0011oo`800003FUH007oo02aoo`00
;7oo00@005YF001JEP<000Eoo`<000MJEP03001JEUYF009JEPl000AJEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH40004FUH00`00FUIJEP03FUH0
1000FUIJEP001Goo2@005Goo0P0000=JEP000000;Woo000/Ool20002FUH00`00FUIJEP0200000goo
00000002FUH00`00FUIJEP04FUH6000?Ool40002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00@005YFFUH0029oo`04001JEUYFFUH2
000^Ool002aoo`80009JEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH2000BOol400000eYF001J
EP0300000eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005FUH=000;FUH90008
FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH00P0087oo00<0
05YFFUH00UYF00<007ooOol0;Goo000/Ool20002FUH01000FUIJEP001UYF00<005YF00005P001EYF
00<005YFFUH00UYF0P000eYF2@0015YF00<005YFFUH010000UYF2@002eYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF
00=JEP03001JEUYF008001ioo`<000AJEP03001oogoo02eoo`00;7oo0P000UYF00@005YF000000IJ
EP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800004
FUH005YFFUH20002FUH00`00FUH000060003FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUIJEP050005FUH00`00FUIJ
EP02000MOol01000FUIJEP000eYF00<007ooOol0;Woo000/Ool20002FUH200000eYF001JEP03FUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
00000UYF0P000UYF00<005YFFUH00eYF00<005YF000010002UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF00D005YFFUIJEP0000=o
o`8000=JEP05001JEUYFFUH0000KOol20004FUH00`00FUH0000aOol002eoo`03001JEP0000=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP06001JEUYFFUH005YF0P000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF100015YF00@005YFFUIJEP<000=o
o`800003FUH005YF009JEP03001oogoo01Ioo`<000IJEP80039oo`00;Goo0P0015YF10001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00`0000EJ
EP00FUIJEP0000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEP0000QJEP04001JEUYFFUH20003FUH01000FUIJEP000UYF0P000goo0P000eYF
00<007ooOol04Woo10000UYF00<005YFFUH00eYF0P00<goo000^Ool00`00FUIJEP02FUH01@00FUIJ
EUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
0goo0P000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00=JEPH0
009JEP03001oogoo00]oo`L000IJEP04001JEUYFFUH2000eOol002eoo`8000=JEP03001JEUYF009J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Ioo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEP0000QJEP03001JEUYF00AJEPH000EJEP04001JEUYFFUHA
0004FUH00`00FUIJEP06FUH01000FUH00000=goo000]Ool01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001goo0P0000=J
EP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF008000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00<005YFFUH0
0P000Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH015YF10002Woo0`00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P000UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00?7oo000/Ool01000FUIJEP001Woo1@00
0eYF00<005YFFUH01UYF1@0015YF00<005YFFUH010003Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000X000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
008003ioo`00;7oo00<005YF000037oo200015YF30004Goo00@005YF000000AJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF0P0000=JEP0000000P000UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P00@Goo000/Ool00`00FUH0000DOol9000GOol200000eYF00000004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP<00003FUH005YF010004Moo`00;Goo
00<007ooOol067oo0`005goo00@005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP00009JEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomoo`1COol002eoo`03001oogoo
035oo`04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0005Eoo`00;Goo0P00<Goo00<005YFFUH00UYF00<007oo000015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo000]Ool00`00FUH0000^Ool30004FUH00`00Oomoo`020002FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP04FUH30002Ool3001DOol002ioo`03001JEP0002]oo`80
009JEP05001JEUYFFUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020007FUH00`00FUIJEP03FUH20005Ool2
001DOol002ioo`04001JEUYF000XOol20004FUH01000FUH0000027oo0P001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
1UYF00@005YFFUIJEP8000Moo`8005Aoo`00;Woo00<005YFFUH00`0097oo0P001UYF0P0037oo0`00
15YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
15YF0`000eYF00<005YFFUH01EYF00@005YF000000Uoo`8005Aoo`00;goo00<005YF00000UYF0P00
7Woo100000=JEP00FUH01EYF00<007ooOol03Woo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001EYF00<005YFFUH00UYF1@002Woo00<005YF
0000E7oo000`Ool00`00FUH00003FUH5000BOol70005FUH00`00FUIJEP02FUH2000DOol40008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH500000eYF0000000<000?Ool00`00FUH0
001DOol0035oo`8000AJEP04001JEUYFFUHB0004FUH00`00FUIJEP06FUH01000FUH000006Woo1P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEQ4001Moo`800003FUH007oo05=oo`00
<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
8Woo20001UYF00<005YFFUH015YF2P0037oo1@005Woo00@005YF000005Eoo`00=7oo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo3@005goo0`005Woo
00<005YFFUH00P00EGoo000gOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002
000iOol2000aOol01@00FUIJEUYF0000EWoo000jOol400000eYF001JEP07FUH00`00FUIJEP02FUH6
000lOol00`00FUH0000_Ool00`00FUIJEP02FUH00`00Oomoo`1DOol003ioo`l0049oo`04001JEUYF
000/Ool30003FUH00`00Oomoo`1EOol008moo`05001JEUYFFUH0000YOol20002FUH01000FUIJEP00
F7oo002?Ool01000FUIJEUYF0`0097oo0`001EYF0P00FGoo002@Ool01000FUIJEP000UYF0P007goo
0`0000=JEP00FUH01EYF00<007ooOol0F7oo002AOol00`00FUH00004FUH3000IOol30004FUH00`00
FUIJEP02FUH2001KOol0099oo`8000EJEP03001JEP0000<000moo`H000MJEP03001JEUYF008005eo
o`00Tgoo00<005YFFUH00eYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF0`00Ggoo002DOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2001QOol0
09Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00
V7oo1@0015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Igoo002MOol90004FUH00`00FUIJEP04
001/Ool00:Ioo`L0071oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]20\[InvisibleSpace]"     "\
\[InvisibleSpace]6.435172469202728`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 20, "     ", 6.4351724692027279, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60198 .74661 m .59955 .69082 L .56841 .69031 L p .707 .577 .707 r
F P
0 g
s
.59955 .69082 m .60198 .74661 L .63379 .74458 L p .707 .577 .707 r
F P
0 g
s
.63379 .74458 m .63136 .6888 L .59955 .69082 L p .707 .577 .707 r
F P
0 g
s
.63136 .6888 m .63379 .74458 L .66315 .74021 L p .707 .577 .707 r
F P
0 g
s
.66315 .74021 m .66072 .68443 L .63136 .6888 L p .707 .577 .707 r
F P
0 g
s
.57084 .74609 m .56841 .69031 L .54098 .6873 L p .707 .577 .707 r
F P
0 g
s
.56841 .69031 m .57084 .74609 L .60198 .74661 L p .707 .577 .707 r
F P
0 g
s
.66072 .68443 m .66315 .74021 L .68719 .73393 L p .707 .577 .707 r
F P
0 g
s
.68719 .73393 m .68476 .67814 L .66072 .68443 L p .707 .577 .707 r
F P
0 g
s
.59942 .8105 m .60324 .77406 L .57223 .76893 L p .707 .577 .707 r
F P
0 g
s
.60324 .77406 m .59942 .8105 L .6311 .81264 L p .707 .577 .707 r
F P
0 g
s
.6311 .81264 m .63492 .77621 L .60324 .77406 L p .707 .577 .707 r
F P
0 g
s
.54098 .6873 m .54341 .74309 L .57084 .74609 L p .707 .577 .707 r
F P
0 g
s
.54341 .74309 m .54098 .6873 L .51995 .68209 L p .707 .577 .707 r
F P
0 g
s
.63492 .77621 m .6311 .81264 L .66036 .81158 L p .707 .577 .707 r
F P
0 g
s
.66036 .81158 m .66418 .77514 L .63492 .77621 L p .707 .577 .707 r
F P
0 g
s
.56841 .80536 m .57223 .76893 L .54494 .7613 L p .707 .577 .707 r
F P
0 g
s
.57223 .76893 m .56841 .80536 L .59942 .8105 L p .707 .577 .707 r
F P
0 g
s
.68476 .67814 m .68719 .73393 L .70356 .72634 L p .707 .577 .707 r
F P
0 g
s
.70356 .72634 m .70112 .67055 L .68476 .67814 L p .707 .577 .707 r
F P
0 g
s
.51995 .68209 m .52239 .73788 L .54341 .74309 L p .707 .577 .707 r
F P
0 g
s
.66418 .77514 m .66036 .81158 L .68434 .80741 L p .707 .577 .707 r
F P
0 g
s
.68434 .80741 m .68816 .77098 L .66418 .77514 L p .707 .577 .707 r
F P
0 g
s
.54494 .7613 m .54112 .79773 L .56841 .80536 L p .707 .577 .707 r
F P
0 g
s
.54112 .79773 m .54494 .7613 L .52404 .75193 L p .707 .577 .707 r
F P
0 g
s
.59097 .85797 m .59565 .8406 L .5655 .83083 L p .707 .577 .707 r
F P
0 g
s
.59565 .8406 m .59097 .85797 L .62188 .86429 L p .707 .577 .707 r
F P
0 g
s
.62188 .86429 m .62656 .84692 L .59565 .8406 L p .707 .577 .707 r
F P
0 g
s
.52239 .73788 m .51995 .68209 L .50738 .6752 L p .707 .577 .707 r
F P
0 g
s
.56082 .84821 m .5655 .83083 L .53907 .81857 L p .707 .577 .707 r
F P
0 g
s
.5655 .83083 m .56082 .84821 L .59097 .85797 L p .707 .577 .707 r
F P
0 g
s
.62656 .84692 m .62188 .86429 L .65053 .86655 L p .707 .577 .707 r
F P
0 g
s
.65053 .86655 m .65521 .84917 L .62656 .84692 L p .707 .577 .707 r
F P
0 g
s
.52404 .75193 m .52022 .78836 L .54112 .79773 L p .707 .577 .707 r
F P
0 g
s
.53907 .81857 m .53439 .83595 L .56082 .84821 L p .707 .577 .707 r
F P
0 g
s
.68816 .77098 m .68434 .80741 L .70068 .80056 L p .707 .577 .707 r
F P
0 g
s
.70068 .80056 m .7045 .76413 L .68816 .77098 L p .707 .577 .707 r
F P
0 g
s
.53439 .83595 m .53907 .81857 L .51894 .80502 L p .707 .577 .707 r
F P
0 g
s
.70112 .67055 m .70356 .72634 L .71064 .71819 L p .707 .577 .707 r
F P
0 g
s
.71064 .71819 m .70821 .66241 L .70112 .67055 L p .707 .577 .707 r
F P
0 g
s
.50738 .6752 m .50982 .73099 L .52239 .73788 L p .707 .577 .707 r
F P
0 g
s
.65521 .84917 m .65053 .86655 L .67411 .86451 L p .707 .577 .707 r
F P
0 g
s
.67411 .86451 m .67879 .84714 L .65521 .84917 L p .707 .577 .707 r
F P
0 g
s
.52022 .78836 m .52404 .75193 L .51157 .74173 L p .707 .577 .707 r
F P
0 g
s
.51894 .80502 m .51426 .8224 L .53439 .83595 L p .707 .577 .707 r
F P
0 g
s
.50982 .73099 m .50738 .6752 L .5045 .6673 L p .707 .577 .707 r
F P
0 g
s
.51157 .74173 m .50775 .77816 L .52022 .78836 L p .707 .577 .707 r
F P
0 g
s
.51426 .8224 m .51894 .80502 L .50709 .79151 L p .707 .577 .707 r
F P
0 g
s
.67879 .84714 m .67411 .86451 L .69031 .85839 L p .707 .577 .707 r
F P
0 g
s
.69031 .85839 m .695 .84101 L .67879 .84714 L p .707 .577 .707 r
F P
0 g
s
.7045 .76413 m .70068 .80056 L .70779 .79168 L p .707 .577 .707 r
F P
0 g
s
.70779 .79168 m .71161 .75525 L .7045 .76413 L p .707 .577 .707 r
F P
0 g
s
.50709 .79151 m .5024 .80888 L .51426 .8224 L p .707 .577 .707 r
F P
0 g
s
.5045 .6673 m .50693 .72308 L .50982 .73099 L p .707 .577 .707 r
F P
0 g
s
.70821 .66241 m .71064 .71819 L .70776 .71029 L p .707 .577 .707 r
F P
0 g
s
.70776 .71029 m .70533 .6545 L .70821 .66241 L p .707 .577 .707 r
F P
0 g
s
.50775 .77816 m .51157 .74173 L .50875 .7317 L p .707 .577 .707 r
F P
0 g
s
.47998 .82206 m .4968 .32228 L .45281 .3181 L p .707 .577 .707 r
F P
0 g
s
.50875 .7317 m .50493 .76813 L .50775 .77816 L p .707 .577 .707 r
F P
0 g
s
.50693 .72308 m .5045 .6673 L .51159 .65915 L p .707 .577 .707 r
F P
0 g
s
.5024 .80888 m .50709 .79151 L .50466 .77935 L p .707 .577 .707 r
F P
0 g
s
.50466 .77935 m .49998 .79672 L .5024 .80888 L p .707 .577 .707 r
F P
0 g
s
.51159 .65915 m .51402 .71494 L .50693 .72308 L p .707 .577 .707 r
F P
0 g
s
.50493 .76813 m .50875 .7317 L .51586 .72282 L p .707 .577 .707 r
F P
0 g
s
.51586 .72282 m .51204 .75925 L .50493 .76813 L p .707 .577 .707 r
F P
0 g
s
.51402 .71494 m .51159 .65915 L .52795 .65156 L p .707 .577 .707 r
F P
0 g
s
.49998 .79672 m .50466 .77935 L .51191 .76974 L p .707 .577 .707 r
F P
0 g
s
.51191 .76974 m .50722 .78711 L .49998 .79672 L p .707 .577 .707 r
F P
0 g
s
.52795 .65156 m .53039 .70735 L .51402 .71494 L p .707 .577 .707 r
F P
0 g
s
.51204 .75925 m .51586 .72282 L .5322 .71597 L p .707 .577 .707 r
F P
0 g
s
.5322 .71597 m .52838 .7524 L .51204 .75925 L p .707 .577 .707 r
F P
0 g
s
.50722 .78711 m .51191 .76974 L .52811 .76362 L p .707 .577 .707 r
F P
0 g
s
.52811 .76362 m .52343 .78099 L .50722 .78711 L p .707 .577 .707 r
F P
0 g
s
.4968 .32228 m .47998 .82206 L .5249 .8223 L p .707 .577 .707 r
F P
0 g
s
.53039 .70735 m .52795 .65156 L .55199 .64528 L p .707 .577 .707 r
F P
0 g
s
.52343 .78099 m .52811 .76362 L .55169 .76158 L p .707 .577 .707 r
F P
0 g
s
.55169 .76158 m .54701 .77896 L .52343 .78099 L p .707 .577 .707 r
F P
0 g
s
.5249 .8223 m .54172 .32252 L .4968 .32228 L p .707 .577 .707 r
F P
0 g
s
.55199 .64528 m .55442 .70106 L .53039 .70735 L p .707 .577 .707 r
F P
0 g
s
.52838 .7524 m .5322 .71597 L .55618 .7118 L p .707 .577 .707 r
F P
0 g
s
.55442 .70106 m .55199 .64528 L .58135 .64091 L p .707 .577 .707 r
F P
0 g
s
.55618 .7118 m .55236 .74824 L .52838 .7524 L p .707 .577 .707 r
F P
0 g
s
.58135 .64091 m .58378 .69669 L .55442 .70106 L p .707 .577 .707 r
F P
0 g
s
.55236 .74824 m .55618 .7118 L .58544 .71074 L p .707 .577 .707 r
F P
0 g
s
.58544 .71074 m .58162 .74717 L .55236 .74824 L p .707 .577 .707 r
F P
0 g
s
.54701 .77896 m .55169 .76158 L .58034 .76383 L p .707 .577 .707 r
F P
0 g
s
.58034 .76383 m .57566 .78121 L .54701 .77896 L p .707 .577 .707 r
F P
0 g
s
.54172 .32252 m .5249 .8223 L .56636 .8186 L p .707 .577 .707 r
F P
0 g
s
.56636 .8186 m .58318 .31882 L .54172 .32252 L p .707 .577 .707 r
F P
0 g
s
.695 .84101 m .69031 .85839 L .69756 .84878 L p .707 .577 .707 r
F P
0 g
s
.69756 .84878 m .70224 .8314 L .695 .84101 L p .707 .577 .707 r
F P
0 g
s
.43599 .81788 m .45281 .3181 L .41407 .31041 L p .707 .577 .707 r
F P
0 g
s
.45281 .3181 m .43599 .81788 L .47998 .82206 L p .707 .577 .707 r
F P
0 g
s
.71161 .75525 m .70779 .79168 L .70497 .78165 L p .707 .577 .707 r
F P
0 g
s
.70497 .78165 m .70879 .74522 L .71161 .75525 L p .707 .577 .707 r
F P
0 g
s
.70533 .6545 m .70776 .71029 L .69519 .70339 L p .707 .577 .707 r
F P
0 g
s
.69519 .70339 m .69276 .64761 L .70533 .6545 L p .707 .577 .707 r
F P
0 g
s
.58378 .69669 m .58135 .64091 L .61316 .63888 L p .707 .577 .707 r
F P
0 g
s
.61316 .63888 m .61559 .69467 L .58378 .69669 L p .707 .577 .707 r
F P
0 g
s
.58162 .74717 m .58544 .71074 L .61712 .71288 L p .707 .577 .707 r
F P
0 g
s
.61712 .71288 m .6133 .74932 L .58162 .74717 L p .707 .577 .707 r
F P
0 g
s
.57566 .78121 m .58034 .76383 L .61125 .77015 L p .707 .577 .707 r
F P
0 g
s
.61125 .77015 m .60657 .78753 L .57566 .78121 L p .707 .577 .707 r
F P
0 g
s
.58318 .31882 m .56636 .8186 L .60031 .81131 L p .707 .577 .707 r
F P
0 g
s
.60031 .81131 m .61713 .31153 L .58318 .31882 L p .707 .577 .707 r
F P
0 g
s
.39725 .81019 m .41407 .31041 L .38437 .29996 L p .707 .577 .707 r
F P
0 g
s
.41407 .31041 m .39725 .81019 L .43599 .81788 L p .707 .577 .707 r
F P
0 g
s
.25898 .714 m .25654 .65822 L .2254 .6577 L p .707 .577 .707 r
F P
0 g
s
.25654 .65822 m .25898 .714 L .29078 .71198 L p .707 .577 .707 r
F P
0 g
s
.29078 .71198 m .28835 .65619 L .25654 .65822 L p .707 .577 .707 r
F P
0 g
s
.28835 .65619 m .29078 .71198 L .32014 .70761 L p .707 .577 .707 r
F P
0 g
s
.32014 .70761 m .31771 .65182 L .28835 .65619 L p .707 .577 .707 r
F P
0 g
s
.70224 .8314 m .69756 .84878 L .69513 .83662 L p .707 .577 .707 r
F P
0 g
s
.69513 .83662 m .69982 .81925 L .70224 .8314 L p .707 .577 .707 r
F P
0 g
s
.22783 .71349 m .2254 .6577 L .19797 .6547 L p .707 .577 .707 r
F P
0 g
s
.2254 .6577 m .22783 .71349 L .25898 .714 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70879 .74522 m .70497 .78165 L .6925 .77145 L p .707 .577 .707 r
F P
0 g
s
.6925 .77145 m .69632 .73502 L .70879 .74522 L p .707 .577 .707 r
F P
0 g
s
.31771 .65182 m .32014 .70761 L .34418 .70132 L p .707 .577 .707 r
F P
0 g
s
.34418 .70132 m .34175 .64554 L .31771 .65182 L p .707 .577 .707 r
F P
0 g
s
.69276 .64761 m .69519 .70339 L .67416 .69819 L p .707 .577 .707 r
F P
0 g
s
.67416 .69819 m .67173 .6424 L .69276 .64761 L p .707 .577 .707 r
F P
0 g
s
.6443 .6394 m .64674 .69518 L .61559 .69467 L p .707 .577 .707 r
F P
0 g
s
.61559 .69467 m .61316 .63888 L .6443 .6394 L p .707 .577 .707 r
F P
0 g
s
.64813 .71802 m .64431 .75445 L .6133 .74932 L p .707 .577 .707 r
F P
0 g
s
.6133 .74932 m .61712 .71288 L .64813 .71802 L p .707 .577 .707 r
F P
0 g
s
.6414 .77992 m .63671 .7973 L .60657 .78753 L p .707 .577 .707 r
F P
0 g
s
.60657 .78753 m .61125 .77015 L .6414 .77992 L p .707 .577 .707 r
F P
0 g
s
.61713 .31153 m .60031 .81131 L .62341 .80114 L p .707 .577 .707 r
F P
0 g
s
.62341 .80114 m .64023 .30136 L .61713 .31153 L p .707 .577 .707 r
F P
0 g
s
.19797 .6547 m .20041 .71048 L .22783 .71349 L p .707 .577 .707 r
F P
0 g
s
.25641 .7794 m .26023 .74297 L .22922 .73784 L p .707 .577 .707 r
F P
0 g
s
.26023 .74297 m .25641 .7794 L .28809 .78155 L p .707 .577 .707 r
F P
0 g
s
.28809 .78155 m .29191 .74511 L .26023 .74297 L p .707 .577 .707 r
F P
0 g
s
.20041 .71048 m .19797 .6547 L .17694 .64949 L p .707 .577 .707 r
F P
0 g
s
.29191 .74511 m .28809 .78155 L .31735 .78048 L p .707 .577 .707 r
F P
0 g
s
.31735 .78048 m .32117 .74405 L .29191 .74511 L p .707 .577 .707 r
F P
0 g
s
.2254 .77427 m .22922 .73784 L .20193 .73021 L p .707 .577 .707 r
F P
0 g
s
.22922 .73784 m .2254 .77427 L .25641 .7794 L p .707 .577 .707 r
F P
0 g
s
.35811 .63795 m .36055 .69373 L .36764 .68559 L p .707 .577 .707 r
F P
0 g
s
.36764 .68559 m .3652 .6298 L .35811 .63795 L p .707 .577 .707 r
F P
0 g
s
.36478 .76059 m .3686 .72416 L .36149 .73303 L p .707 .577 .707 r
F P
0 g
s
.3652 .6298 m .36764 .68559 L .36475 .67768 L p .707 .577 .707 r
F P
0 g
s
.36149 .73303 m .35767 .76947 L .36478 .76059 L p .707 .577 .707 r
F P
0 g
s
.3686 .72416 m .36478 .76059 L .36196 .75056 L p .707 .577 .707 r
F P
0 g
s
.36196 .75056 m .36578 .71413 L .3686 .72416 L p .707 .577 .707 r
F P
0 g
s
.36755 .79974 m .38437 .29996 L .36661 .28776 L p .707 .577 .707 r
F P
0 g
s
.38437 .29996 m .36755 .79974 L .39725 .81019 L p .707 .577 .707 r
F P
0 g
s
.34175 .64554 m .34418 .70132 L .36055 .69373 L p .707 .577 .707 r
F P
0 g
s
.36055 .69373 m .35811 .63795 L .34175 .64554 L p .707 .577 .707 r
F P
0 g
s
.69982 .81925 m .69513 .83662 L .68328 .82311 L p .707 .577 .707 r
F P
0 g
s
.68328 .82311 m .68796 .80573 L .69982 .81925 L p .707 .577 .707 r
F P
0 g
s
.17694 .64949 m .17938 .70528 L .20041 .71048 L p .707 .577 .707 r
F P
0 g
s
.32117 .74405 m .31735 .78048 L .34133 .77632 L p .707 .577 .707 r
F P
0 g
s
.34133 .77632 m .34515 .73989 L .32117 .74405 L p .707 .577 .707 r
F P
0 g
s
.20193 .73021 m .19811 .76664 L .2254 .77427 L p .707 .577 .707 r
F P
0 g
s
.69632 .73502 m .6925 .77145 L .67159 .76208 L p .707 .577 .707 r
F P
0 g
s
.67159 .76208 m .67542 .72565 L .69632 .73502 L p .707 .577 .707 r
F P
0 g
s
.67173 .6424 m .67416 .69819 L .64674 .69518 L p .707 .577 .707 r
F P
0 g
s
.64674 .69518 m .6443 .6394 L .67173 .6424 L p .707 .577 .707 r
F P
0 g
s
.24796 .82279 m .25264 .80542 L .2225 .79565 L p .707 .577 .707 r
F P
0 g
s
.25264 .80542 m .24796 .82279 L .27887 .82911 L p .707 .577 .707 r
F P
0 g
s
.27887 .82911 m .28355 .81174 L .25264 .80542 L p .707 .577 .707 r
F P
0 g
s
.19811 .76664 m .20193 .73021 L .18103 .72084 L p .707 .577 .707 r
F P
0 g
s
.21781 .81303 m .2225 .79565 L .19606 .78339 L p .707 .577 .707 r
F P
0 g
s
.2225 .79565 m .21781 .81303 L .24796 .82279 L p .707 .577 .707 r
F P
0 g
s
.17938 .70528 m .17694 .64949 L .16437 .6426 L p .707 .577 .707 r
F P
0 g
s
.28355 .81174 m .27887 .82911 L .30752 .83137 L p .707 .577 .707 r
F P
0 g
s
.30752 .83137 m .3122 .81399 L .28355 .81174 L p .707 .577 .707 r
F P
0 g
s
.19606 .78339 m .19138 .80077 L .21781 .81303 L p .707 .577 .707 r
F P
0 g
s
.18103 .72084 m .17721 .75727 L .19811 .76664 L p .707 .577 .707 r
F P
0 g
s
.64023 .30136 m .62341 .80114 L .63342 .7891 L p .707 .577 .707 r
F P
0 g
s
.63342 .7891 m .65023 .28932 L .64023 .30136 L p .707 .577 .707 r
F P
0 g
s
.34515 .73989 m .34133 .77632 L .35767 .76947 L p .707 .577 .707 r
F P
0 g
s
.35767 .76947 m .36149 .73303 L .34515 .73989 L p .707 .577 .707 r
F P
0 g
s
.19138 .80077 m .19606 .78339 L .17593 .76984 L p .707 .577 .707 r
F P
0 g
s
.16437 .6426 m .16681 .69838 L .17938 .70528 L p .707 .577 .707 r
F P
0 g
s
.3122 .81399 m .30752 .83137 L .3311 .82933 L p .707 .577 .707 r
F P
0 g
s
.3311 .82933 m .33578 .81196 L .3122 .81399 L p .707 .577 .707 r
F P
0 g
s
.67542 .72565 m .67159 .76208 L .64431 .75445 L p .707 .577 .707 r
F P
0 g
s
.64431 .75445 m .64813 .71802 L .67542 .72565 L p .707 .577 .707 r
F P
0 g
s
.68796 .80573 m .68328 .82311 L .66315 .80956 L p .707 .577 .707 r
F P
0 g
s
.66315 .80956 m .66783 .79218 L .68796 .80573 L p .707 .577 .707 r
F P
0 g
s
.17721 .75727 m .18103 .72084 L .16856 .71064 L p .707 .577 .707 r
F P
0 g
s
.17593 .76984 m .17125 .78722 L .19138 .80077 L p .707 .577 .707 r
F P
0 g
s
.36232 .6219 m .36475 .67768 L .35218 .67079 L p .707 .577 .707 r
F P
0 g
s
.35218 .67079 m .34975 .61501 L .36232 .6219 L p .707 .577 .707 r
F P
0 g
s
.36578 .71413 m .36196 .75056 L .35413 .74415 L p .707 .577 .707 r
F P
0 g
s
.35413 .74415 m .34949 .74036 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.35433 .73257 m .36578 .71413 L .35413 .74415 L .707 .577 .707 r
F
.36661 .28776 m .36253 .27501 L p .36154 .31489 L F P
0 g
s
.34949 .74036 m .35331 .70393 L .3548 .70515 L p .707 .577 .707 r
F P
0 g
s
.3548 .70515 m .36578 .71413 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.34949 .74036 m .3548 .70515 L .35433 .73257 L .707 .577 .707 r
F
.34975 .61501 m .35218 .67079 L .33115 .66559 L p F P
0 g
s
.35213 .80144 m .34027 .78793 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35681 .78407 m .35403 .79437 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35403 .79437 m .35213 .80144 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .34495 .77055 L .35386 .7807 L p .707 .577 .707 r
F P
0 g
s
.35386 .7807 m .35681 .78407 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .35386 .7807 L .35391 .78474 L .707 .577 .707 r
F
.36191 .29349 m .35161 .59958 L p .36154 .31489 L F P
0 g
s
.35331 .70393 m .34949 .74036 L .32859 .73099 L p .707 .577 .707 r
F P
0 g
s
.32859 .73099 m .33241 .69455 L .35331 .70393 L p .707 .577 .707 r
F P
0 g
s
.35161 .59958 m .34571 .77479 L p .35165 .60243 L .707 .577 .707 r
F P
0 g
s
.36154 .31489 m .35161 .59958 L .35165 .60243 L .707 .577 .707 r
F
.34571 .77479 m .34979 .78754 L p .35256 .67613 L F P
0 g
s
.35256 .67613 m .36154 .31489 L .35165 .60243 L .707 .577 .707 r
F
.35256 .67613 m .35165 .60243 L .34571 .77479 L F
.36253 .27501 m .36191 .29349 L p .36154 .31489 L F P
0 g
s
.34979 .78754 m .35716 .56852 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.35716 .56852 m .36661 .28776 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.36475 .67768 m .36232 .6219 L .3652 .6298 L p .707 .577 .707 r
F P
0 g
s
.35213 .80144 m .35681 .78407 L .35923 .79622 L p .707 .577 .707 r
F P
0 g
s
.36661 .28776 m .34979 .78754 L .36755 .79974 L p .707 .577 .707 r
F P
0 g
s
.16681 .69838 m .16437 .6426 L .16149 .63469 L p .707 .577 .707 r
F P
0 g
s
.16856 .71064 m .16474 .74707 L .17721 .75727 L p .707 .577 .707 r
F P
0 g
s
.17125 .78722 m .17593 .76984 L .16408 .75633 L p .707 .577 .707 r
F P
0 g
s
.33578 .81196 m .3311 .82933 L .3473 .82321 L p .707 .577 .707 r
F P
0 g
s
.3473 .82321 m .35199 .80583 L .33578 .81196 L p .707 .577 .707 r
F P
0 g
s
.66783 .79218 m .66315 .80956 L .63671 .7973 L p .707 .577 .707 r
F P
0 g
s
.63671 .7973 m .6414 .77992 L .66783 .79218 L p .707 .577 .707 r
F P
0 g
s
.16408 .75633 m .15939 .7737 L .17125 .78722 L p .707 .577 .707 r
F P
0 g
s
.16149 .63469 m .16392 .69048 L .16681 .69838 L p .707 .577 .707 r
F P
0 g
s
.16474 .74707 m .16856 .71064 L .16574 .70061 L p .707 .577 .707 r
F P
0 g
s
.65023 .28932 m .63342 .7891 L .62934 .77635 L p .707 .577 .707 r
F P
0 g
s
.62934 .77635 m .64616 .27657 L .65023 .28932 L p .707 .577 .707 r
F P
0 g
s
.16574 .70061 m .16192 .73704 L .16474 .74707 L p .707 .577 .707 r
F P
0 g
s
.16392 .69048 m .16149 .63469 L .16858 .62655 L p .707 .577 .707 r
F P
0 g
s
.15939 .7737 m .16408 .75633 L .16165 .74417 L p .707 .577 .707 r
F P
0 g
s
.35199 .80583 m .3473 .82321 L .35455 .8136 L p .707 .577 .707 r
F P
0 g
s
.35455 .8136 m .35923 .79622 L .35199 .80583 L p .707 .577 .707 r
F P
0 g
s
.16165 .74417 m .15697 .76154 L .15939 .7737 L p .707 .577 .707 r
F P
0 g
s
.34571 .77479 m .36253 .27501 L .37254 .26297 L p .707 .577 .707 r
F P
0 g
s
.16858 .62655 m .17101 .68233 L .16392 .69048 L p .707 .577 .707 r
F P
0 g
s
.16192 .73704 m .16574 .70061 L .17285 .69173 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17285 .69173 m .16903 .72816 L .16192 .73704 L p .707 .577 .707 r
F P
0 g
s
.17101 .68233 m .16858 .62655 L .18494 .61896 L p .707 .577 .707 r
F P
0 g
s
.15697 .76154 m .16165 .74417 L .1689 .73456 L p .707 .577 .707 r
F P
0 g
s
.35923 .79622 m .35455 .8136 L .35213 .80144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64616 .27657 m .62934 .77635 L .61158 .76416 L p .707 .577 .707 r
F P
0 g
s
.61158 .76416 m .6284 .26438 L .64616 .27657 L p .707 .577 .707 r
F P
0 g
s
.1689 .73456 m .16421 .75193 L .15697 .76154 L p .707 .577 .707 r
F P
0 g
s
.33115 .66559 m .32872 .6098 L .34975 .61501 L p .707 .577 .707 r
F P
0 g
s
.18494 .61896 m .18738 .67475 L .17101 .68233 L p .707 .577 .707 r
F P
0 g
s
.16903 .72816 m .17285 .69173 L .18919 .68487 L p .707 .577 .707 r
F P
0 g
s
.35572 .76275 m .37254 .26297 L .39564 .2528 L p .707 .577 .707 r
F P
0 g
s
.37254 .26297 m .35572 .76275 L .34571 .77479 L p .707 .577 .707 r
F P
0 g
s
.18738 .67475 m .18494 .61896 L .20898 .61267 L p .707 .577 .707 r
F P
0 g
s
.18919 .68487 m .18537 .72131 L .16903 .72816 L p .707 .577 .707 r
F P
0 g
s
.16421 .75193 m .1689 .73456 L .1851 .72844 L p .707 .577 .707 r
F P
0 g
s
.1851 .72844 m .18042 .74581 L .16421 .75193 L p .707 .577 .707 r
F P
0 g
s
.32872 .6098 m .33115 .66559 L .30373 .66258 L p .707 .577 .707 r
F P
0 g
s
.30373 .66258 m .30129 .60679 L .32872 .6098 L p .707 .577 .707 r
F P
0 g
s
.20898 .61267 m .21141 .66846 L .18738 .67475 L p .707 .577 .707 r
F P
0 g
s
.18537 .72131 m .18919 .68487 L .21317 .68071 L p .707 .577 .707 r
F P
0 g
s
.6284 .26438 m .61158 .76416 L .58188 .7537 L p .707 .577 .707 r
F P
0 g
s
.58188 .7537 m .59869 .25392 L .6284 .26438 L p .707 .577 .707 r
F P
0 g
s
.21141 .66846 m .20898 .61267 L .23834 .6083 L p .707 .577 .707 r
F P
0 g
s
.30129 .60679 m .30373 .66258 L .27258 .66206 L p .707 .577 .707 r
F P
0 g
s
.27258 .66206 m .27015 .60628 L .30129 .60679 L p .707 .577 .707 r
F P
0 g
s
.21317 .68071 m .20935 .71714 L .18537 .72131 L p .707 .577 .707 r
F P
0 g
s
.18042 .74581 m .1851 .72844 L .20868 .7264 L p .707 .577 .707 r
F P
0 g
s
.39564 .2528 m .37882 .75258 L .35572 .76275 L p .707 .577 .707 r
F P
0 g
s
.37882 .75258 m .39564 .2528 L .42959 .24551 L p .707 .577 .707 r
F P
0 g
s
.24078 .66409 m .23834 .6083 L .27015 .60628 L p .707 .577 .707 r
F P
0 g
s
.23834 .6083 m .24078 .66409 L .21141 .66846 L p .707 .577 .707 r
F P
0 g
s
.34495 .77055 m .34027 .78793 L .32014 .77438 L p .707 .577 .707 r
F P
0 g
s
.32014 .77438 m .32482 .757 L .34495 .77055 L p .707 .577 .707 r
F P
0 g
s
.33241 .69455 m .32859 .73099 L .3013 .72336 L p .707 .577 .707 r
F P
0 g
s
.3013 .72336 m .30512 .68693 L .33241 .69455 L p .707 .577 .707 r
F P
0 g
s
.73919 .65457 m .73676 .59878 L .70561 .59827 L p .707 .577 .707 r
F P
0 g
s
.73676 .59878 m .73919 .65457 L .771 .65254 L p .707 .577 .707 r
F P
0 g
s
.771 .65254 m .76856 .59676 L .73676 .59878 L p .707 .577 .707 r
F P
0 g
s
.27015 .60628 m .27258 .66206 L .24078 .66409 L p .707 .577 .707 r
F P
0 g
s
.76856 .59676 m .771 .65254 L .80036 .64817 L p .707 .577 .707 r
F P
0 g
s
.80036 .64817 m .79792 .59239 L .76856 .59676 L p .707 .577 .707 r
F P
0 g
s
.20868 .7264 m .204 .74378 L .18042 .74581 L p .707 .577 .707 r
F P
0 g
s
.20935 .71714 m .21317 .68071 L .24243 .67965 L p .707 .577 .707 r
F P
0 g
s
.70805 .65405 m .70561 .59827 L .67819 .59526 L p .707 .577 .707 r
F P
0 g
s
.70561 .59827 m .70805 .65405 L .73919 .65457 L p .707 .577 .707 r
F P
0 g
s
.30512 .68693 m .3013 .72336 L .27029 .71822 L p .707 .577 .707 r
F P
0 g
s
.27029 .71822 m .27411 .68179 L .30512 .68693 L p .707 .577 .707 r
F P
0 g
s
.79792 .59239 m .80036 .64817 L .8244 .64189 L p .707 .577 .707 r
F P
0 g
s
.8244 .64189 m .82196 .5861 L .79792 .59239 L p .707 .577 .707 r
F P
0 g
s
.24243 .67965 m .23861 .71608 L .20935 .71714 L p .707 .577 .707 r
F P
0 g
s
.23861 .71608 m .24243 .67965 L .27411 .68179 L p .707 .577 .707 r
F P
0 g
s
.59869 .25392 m .58188 .7537 L .54314 .74601 L p .707 .577 .707 r
F P
0 g
s
.54314 .74601 m .55996 .24623 L .59869 .25392 L p .707 .577 .707 r
F P
0 g
s
.204 .74378 m .20868 .7264 L .23733 .72865 L p .707 .577 .707 r
F P
0 g
s
.32482 .757 m .32014 .77438 L .29371 .76212 L p .707 .577 .707 r
F P
0 g
s
.29371 .76212 m .29839 .74474 L .32482 .757 L p .707 .577 .707 r
F P
0 g
s
.27411 .68179 m .27029 .71822 L .23861 .71608 L p .707 .577 .707 r
F P
0 g
s
.73662 .71846 m .74044 .68203 L .70944 .67689 L p .707 .577 .707 r
F P
0 g
s
.74044 .68203 m .73662 .71846 L .7683 .7206 L p .707 .577 .707 r
F P
0 g
s
.7683 .7206 m .77212 .68417 L .74044 .68203 L p .707 .577 .707 r
F P
0 g
s
.67819 .59526 m .68062 .65105 L .70805 .65405 L p .707 .577 .707 r
F P
0 g
s
.68062 .65105 m .67819 .59526 L .65716 .59006 L p .707 .577 .707 r
F P
0 g
s
.23733 .72865 m .23265 .74603 L .204 .74378 L p .707 .577 .707 r
F P
0 g
s
.77212 .68417 m .7683 .7206 L .79757 .71954 L p .707 .577 .707 r
F P
0 g
s
.79757 .71954 m .80139 .68311 L .77212 .68417 L p .707 .577 .707 r
F P
0 g
s
.41277 .74529 m .42959 .24551 L .47105 .24181 L p .707 .577 .707 r
F P
0 g
s
.42959 .24551 m .41277 .74529 L .37882 .75258 L p .707 .577 .707 r
F P
0 g
s
.70562 .71332 m .70944 .67689 L .68215 .66926 L p .707 .577 .707 r
F P
0 g
s
.70944 .67689 m .70562 .71332 L .73662 .71846 L p .707 .577 .707 r
F P
0 g
s
.23265 .74603 m .23733 .72865 L .26824 .73497 L p .707 .577 .707 r
F P
0 g
s
.29839 .74474 m .29371 .76212 L .26356 .75235 L p .707 .577 .707 r
F P
0 g
s
.26356 .75235 m .26824 .73497 L .29839 .74474 L p .707 .577 .707 r
F P
0 g
s
.82196 .5861 m .8244 .64189 L .84076 .6343 L p .707 .577 .707 r
F P
0 g
s
.84076 .6343 m .83833 .57851 L .82196 .5861 L p .707 .577 .707 r
F P
0 g
s
.26824 .73497 m .26356 .75235 L .23265 .74603 L p .707 .577 .707 r
F P
0 g
s
.65716 .59006 m .65959 .64584 L .68062 .65105 L p .707 .577 .707 r
F P
0 g
s
.80139 .68311 m .79757 .71954 L .82154 .71537 L p .707 .577 .707 r
F P
0 g
s
.82154 .71537 m .82536 .67894 L .80139 .68311 L p .707 .577 .707 r
F P
0 g
s
.55996 .24623 m .54314 .74601 L .49915 .74184 L p .707 .577 .707 r
F P
0 g
s
.49915 .74184 m .51597 .24206 L .55996 .24623 L p .707 .577 .707 r
F P
0 g
s
.68215 .66926 m .67833 .7057 L .70562 .71332 L p .707 .577 .707 r
F P
0 g
s
.67833 .7057 m .68215 .66926 L .66124 .65989 L p .707 .577 .707 r
F P
0 g
s
.72817 .76594 m .73286 .74856 L .70271 .73879 L p .707 .577 .707 r
F P
0 g
s
.73286 .74856 m .72817 .76594 L .75908 .77225 L p .707 .577 .707 r
F P
0 g
s
.75908 .77225 m .76377 .75488 L .73286 .74856 L p .707 .577 .707 r
F P
0 g
s
.45423 .74159 m .46156 .52368 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.47105 .24181 m .45423 .74159 L .41277 .74529 L p .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .45838 .65201 L .43489 .65287 L p .707 .577 .707 r
F P
0 g
s
.43489 .65287 m .42911 .65307 L p .43356 .65926 L .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .43489 .65287 L .43356 .65926 L .707 .577 .707 r
F
.47105 .24181 m .51597 .24206 L p .51038 .28729 L F P
0 g
s
.46156 .52368 m .47105 .24181 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.65959 .64584 m .65716 .59006 L .64459 .58316 L p .707 .577 .707 r
F P
0 g
s
.69803 .75617 m .70271 .73879 L .67628 .72653 L p .707 .577 .707 r
F P
0 g
s
.70271 .73879 m .69803 .75617 L .72817 .76594 L p .707 .577 .707 r
F P
0 g
s
.51597 .24206 m .49915 .74184 L .45423 .74159 L p .707 .577 .707 r
F P
0 g
s
.76377 .75488 m .75908 .77225 L .78773 .77451 L p .707 .577 .707 r
F P
0 g
s
.78773 .77451 m .79241 .75713 L .76377 .75488 L p .707 .577 .707 r
F P
0 g
s
.66124 .65989 m .65742 .69632 L .67833 .7057 L p .707 .577 .707 r
F P
0 g
s
.67628 .72653 m .67159 .74391 L .69803 .75617 L p .707 .577 .707 r
F P
0 g
s
.82536 .67894 m .82154 .71537 L .83788 .70852 L p .707 .577 .707 r
F P
0 g
s
.83788 .70852 m .84171 .67209 L .82536 .67894 L p .707 .577 .707 r
F P
0 g
s
.67159 .74391 m .67628 .72653 L .65615 .71298 L p .707 .577 .707 r
F P
0 g
s
.83833 .57851 m .84076 .6343 L .84785 .62615 L p .707 .577 .707 r
F P
0 g
s
.84785 .62615 m .84542 .57037 L .83833 .57851 L p .707 .577 .707 r
F P
0 g
s
.64459 .58316 m .64702 .63895 L .65959 .64584 L p .707 .577 .707 r
F P
0 g
s
.79241 .75713 m .78773 .77451 L .81131 .77247 L p .707 .577 .707 r
F P
0 g
s
.81131 .77247 m .81599 .7551 L .79241 .75713 L p .707 .577 .707 r
F P
0 g
s
.65742 .69632 m .66124 .65989 L .64877 .64969 L p .707 .577 .707 r
F P
0 g
s
.65615 .71298 m .65146 .73036 L .67159 .74391 L p .707 .577 .707 r
F P
0 g
s
.64702 .63895 m .64459 .58316 L .6417 .57526 L p .707 .577 .707 r
F P
0 g
s
.64877 .64969 m .64495 .68612 L .65742 .69632 L p .707 .577 .707 r
F P
0 g
s
.65146 .73036 m .65615 .71298 L .64429 .69947 L p .707 .577 .707 r
F P
0 g
s
.81599 .7551 m .81131 .77247 L .82752 .76635 L p .707 .577 .707 r
F P
0 g
s
.82752 .76635 m .8322 .74898 L .81599 .7551 L p .707 .577 .707 r
F P
0 g
s
.84171 .67209 m .83788 .70852 L .84499 .69964 L p .707 .577 .707 r
F P
0 g
s
.84499 .69964 m .84881 .66321 L .84171 .67209 L p .707 .577 .707 r
F P
0 g
s
.64429 .69947 m .63961 .71684 L .65146 .73036 L p .707 .577 .707 r
F P
0 g
s
.6417 .57526 m .64414 .63104 L .64702 .63895 L p .707 .577 .707 r
F P
0 g
s
.84542 .57037 m .84785 .62615 L .84497 .61825 L p .707 .577 .707 r
F P
0 g
s
.84497 .61825 m .84253 .56246 L .84542 .57037 L p .707 .577 .707 r
F P
0 g
s
.64495 .68612 m .64877 .64969 L .64595 .63966 L p .707 .577 .707 r
F P
0 g
s
.64595 .63966 m .64213 .67609 L .64495 .68612 L p .707 .577 .707 r
F P
0 g
s
.64414 .63104 m .6417 .57526 L .64879 .56711 L p .707 .577 .707 r
F P
0 g
s
.63961 .71684 m .64429 .69947 L .64186 .68731 L p .707 .577 .707 r
F P
0 g
s
.8322 .74898 m .82752 .76635 L .83476 .75674 L p .707 .577 .707 r
F P
0 g
s
.83476 .75674 m .83945 .73937 L .8322 .74898 L p .707 .577 .707 r
F P
0 g
s
.64186 .68731 m .63718 .70469 L .63961 .71684 L p .707 .577 .707 r
F P
0 g
s
.84881 .66321 m .84499 .69964 L .84218 .68961 L p .707 .577 .707 r
F P
0 g
s
.84218 .68961 m .846 .65318 L .84881 .66321 L p .707 .577 .707 r
F P
0 g
s
.64879 .56711 m .65122 .6229 L .64414 .63104 L p .707 .577 .707 r
F P
0 g
s
.84253 .56246 m .84497 .61825 L .8324 .61136 L p .707 .577 .707 r
F P
0 g
s
.8324 .61136 m .82996 .55557 L .84253 .56246 L p .707 .577 .707 r
F P
0 g
s
.64213 .67609 m .64595 .63966 L .65306 .63078 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39618 .62197 m .39375 .56618 L .3626 .56566 L p .707 .577 .707 r
F P
0 g
s
.39375 .56618 m .39618 .62197 L .42799 .61994 L p .707 .577 .707 r
F P
0 g
s
.42799 .61994 m .42555 .56415 L .39375 .56618 L p .707 .577 .707 r
F P
0 g
s
.65306 .63078 m .64924 .66722 L .64213 .67609 L p .707 .577 .707 r
F P
0 g
s
.42555 .56415 m .42799 .61994 L .45735 .61557 L p .707 .577 .707 r
F P
0 g
s
.45735 .61557 m .45491 .55978 L .42555 .56415 L p .707 .577 .707 r
F P
0 g
s
.65122 .6229 m .64879 .56711 L .66516 .55953 L p .707 .577 .707 r
F P
0 g
s
.63718 .70469 m .64186 .68731 L .64911 .6777 L p .707 .577 .707 r
F P
0 g
s
.83945 .73937 m .83476 .75674 L .83234 .74458 L p .707 .577 .707 r
F P
0 g
s
.83234 .74458 m .83702 .72721 L .83945 .73937 L p .707 .577 .707 r
F P
0 g
s
.36504 .62145 m .3626 .56566 L .33518 .56266 L p .707 .577 .707 r
F P
0 g
s
.3626 .56566 m .36504 .62145 L .39618 .62197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64911 .6777 m .64443 .69508 L .63718 .70469 L p .707 .577 .707 r
F P
0 g
s
.846 .65318 m .84218 .68961 L .8297 .67941 L p .707 .577 .707 r
F P
0 g
s
.8297 .67941 m .83352 .64298 L .846 .65318 L p .707 .577 .707 r
F P
0 g
s
.45491 .55978 m .45735 .61557 L .48139 .60928 L p .707 .577 .707 r
F P
0 g
s
.48139 .60928 m .47895 .5535 L .45491 .55978 L p .707 .577 .707 r
F P
0 g
s
.82996 .55557 m .8324 .61136 L .81137 .60615 L p .707 .577 .707 r
F P
0 g
s
.81137 .60615 m .80893 .55037 L .82996 .55557 L p .707 .577 .707 r
F P
0 g
s
.66516 .55953 m .66759 .61531 L .65122 .6229 L p .707 .577 .707 r
F P
0 g
s
.64924 .66722 m .65306 .63078 L .6694 .62393 L p .707 .577 .707 r
F P
0 g
s
.33518 .56266 m .33761 .61844 L .36504 .62145 L p .707 .577 .707 r
F P
0 g
s
.39361 .68737 m .39743 .65093 L .36643 .6458 L p .707 .577 .707 r
F P
0 g
s
.39743 .65093 m .39361 .68737 L .42529 .68951 L p .707 .577 .707 r
F P
0 g
s
.42529 .68951 m .42911 .65307 L .39743 .65093 L p .707 .577 .707 r
F P
0 g
s
.33761 .61844 m .33518 .56266 L .31415 .55745 L p .707 .577 .707 r
F P
0 g
s
.42911 .65307 m .42529 .68951 L .45456 .68844 L p .707 .577 .707 r
F P
0 g
s
.36261 .68223 m .36643 .6458 L .33914 .63817 L p .707 .577 .707 r
F P
0 g
s
.36643 .6458 m .36261 .68223 L .39361 .68737 L p .707 .577 .707 r
F P
0 g
s
.66759 .61531 m .66516 .55953 L .6892 .55324 L p .707 .577 .707 r
F P
0 g
s
.6694 .62393 m .66558 .66036 L .64924 .66722 L p .707 .577 .707 r
F P
0 g
s
.64443 .69508 m .64911 .6777 L .66532 .67158 L p .707 .577 .707 r
F P
0 g
s
.47895 .5535 m .48139 .60928 L .49775 .6017 L p .707 .577 .707 r
F P
0 g
s
.49775 .6017 m .49532 .54591 L .47895 .5535 L p .707 .577 .707 r
F P
0 g
s
.83702 .72721 m .83234 .74458 L .82048 .73107 L p .707 .577 .707 r
F P
0 g
s
.82048 .73107 m .82516 .71369 L .83702 .72721 L p .707 .577 .707 r
F P
0 g
s
.31415 .55745 m .31658 .61324 L .33761 .61844 L p .707 .577 .707 r
F P
0 g
s
.45838 .65201 m .45456 .68844 L .47853 .68428 L p .707 .577 .707 r
F P
0 g
s
.47853 .68428 m .48235 .64785 L .45838 .65201 L p .707 .577 .707 r
F P
0 g
s
.33914 .63817 m .33532 .6746 L .36261 .68223 L p .707 .577 .707 r
F P
0 g
s
.83352 .64298 m .8297 .67941 L .8088 .67004 L p .707 .577 .707 r
F P
0 g
s
.8088 .67004 m .81262 .63361 L .83352 .64298 L p .707 .577 .707 r
F P
0 g
s
.66532 .67158 m .66063 .68895 L .64443 .69508 L p .707 .577 .707 r
F P
0 g
s
.80893 .55037 m .81137 .60615 L .78394 .60314 L p .707 .577 .707 r
F P
0 g
s
.78394 .60314 m .78151 .54736 L .80893 .55037 L p .707 .577 .707 r
F P
0 g
s
.38516 .73076 m .38985 .71338 L .3597 .70361 L p .707 .577 .707 r
F P
0 g
s
.38985 .71338 m .38516 .73076 L .41607 .73707 L p .707 .577 .707 r
F P
0 g
s
.41607 .73707 m .42076 .7197 L .38985 .71338 L p .707 .577 .707 r
F P
0 g
s
.33532 .6746 m .33914 .63817 L .31823 .6288 L p .707 .577 .707 r
F P
0 g
s
.6892 .55324 m .69163 .60903 L .66759 .61531 L p .707 .577 .707 r
F P
0 g
s
.66558 .66036 m .6694 .62393 L .69338 .61977 L p .707 .577 .707 r
F P
0 g
s
.35502 .72099 m .3597 .70361 L .33327 .69135 L p .707 .577 .707 r
F P
0 g
s
.3597 .70361 m .35502 .72099 L .38516 .73076 L p .707 .577 .707 r
F P
0 g
s
.31658 .61324 m .31415 .55745 L .30158 .55056 L p .707 .577 .707 r
F P
0 g
s
.42076 .7197 m .41607 .73707 L .44472 .73933 L p .707 .577 .707 r
F P
0 g
s
.44472 .73933 m .4494 .72195 L .42076 .7197 L p .707 .577 .707 r
F P
0 g
s
.69163 .60903 m .6892 .55324 L .71856 .54887 L p .707 .577 .707 r
F P
0 g
s
.33327 .69135 m .32858 .70873 L .35502 .72099 L p .707 .577 .707 r
F P
0 g
s
.31823 .6288 m .31441 .66523 L .33532 .6746 L p .707 .577 .707 r
F P
0 g
s
.78151 .54736 m .78394 .60314 L .7528 .60263 L p .707 .577 .707 r
F P
0 g
s
.7528 .60263 m .75036 .54684 L .78151 .54736 L p .707 .577 .707 r
F P
0 g
s
.69338 .61977 m .68956 .6562 L .66558 .66036 L p .707 .577 .707 r
F P
0 g
s
.48235 .64785 m .47853 .68428 L .49487 .67743 L p .707 .577 .707 r
F P
0 g
s
.49487 .67743 m .4987 .64099 L .48235 .64785 L p .707 .577 .707 r
F P
0 g
s
.32858 .70873 m .33327 .69135 L .31314 .6778 L p .707 .577 .707 r
F P
0 g
s
.66063 .68895 m .66532 .67158 L .6889 .66954 L p .707 .577 .707 r
F P
0 g
s
.49532 .54591 m .49775 .6017 L .50484 .59355 L p .707 .577 .707 r
F P
0 g
s
.50484 .59355 m .50241 .53776 L .49532 .54591 L p .707 .577 .707 r
F P
0 g
s
.72099 .60465 m .71856 .54887 L .75036 .54684 L p .707 .577 .707 r
F P
0 g
s
.71856 .54887 m .72099 .60465 L .69163 .60903 L p .707 .577 .707 r
F P
0 g
s
.30158 .55056 m .30401 .60635 L .31658 .61324 L p .707 .577 .707 r
F P
0 g
s
.4494 .72195 m .44472 .73933 L .4683 .73729 L p .707 .577 .707 r
F P
0 g
s
.4683 .73729 m .47298 .71992 L .4494 .72195 L p .707 .577 .707 r
F P
0 g
s
.81262 .63361 m .8088 .67004 L .78151 .66241 L p .707 .577 .707 r
F P
0 g
s
.78151 .66241 m .78533 .62598 L .81262 .63361 L p .707 .577 .707 r
F P
0 g
s
.82516 .71369 m .82048 .73107 L .80035 .71752 L p .707 .577 .707 r
F P
0 g
s
.80035 .71752 m .80503 .70014 L .82516 .71369 L p .707 .577 .707 r
F P
0 g
s
.75036 .54684 m .7528 .60263 L .72099 .60465 L p .707 .577 .707 r
F P
0 g
s
.31441 .66523 m .31823 .6288 L .30576 .6186 L p .707 .577 .707 r
F P
0 g
s
.68956 .6562 m .69338 .61977 L .72264 .6187 L p .707 .577 .707 r
F P
0 g
s
.31314 .6778 m .30845 .69518 L .32858 .70873 L p .707 .577 .707 r
F P
0 g
s
.6889 .66954 m .68422 .68692 L .66063 .68895 L p .707 .577 .707 r
F P
0 g
s
.30401 .60635 m .30158 .55056 L .29869 .54265 L p .707 .577 .707 r
F P
0 g
s
.30576 .6186 m .30194 .65503 L .31441 .66523 L p .707 .577 .707 r
F P
0 g
s
.78533 .62598 m .78151 .66241 L .75051 .65728 L p .707 .577 .707 r
F P
0 g
s
.75051 .65728 m .75433 .62084 L .78533 .62598 L p .707 .577 .707 r
F P
0 g
s
.72264 .6187 m .71882 .65514 L .68956 .6562 L p .707 .577 .707 r
F P
0 g
s
.71882 .65514 m .72264 .6187 L .75433 .62084 L p .707 .577 .707 r
F P
0 g
s
.30845 .69518 m .31314 .6778 L .30128 .66429 L p .707 .577 .707 r
F P
0 g
s
.68422 .68692 m .6889 .66954 L .71755 .6718 L p .707 .577 .707 r
F P
0 g
s
.75433 .62084 m .75051 .65728 L .71882 .65514 L p .707 .577 .707 r
F P
0 g
s
.47298 .71992 m .4683 .73729 L .48451 .73117 L p .707 .577 .707 r
F P
0 g
s
.48451 .73117 m .48919 .7138 L .47298 .71992 L p .707 .577 .707 r
F P
0 g
s
.80503 .70014 m .80035 .71752 L .77392 .70526 L p .707 .577 .707 r
F P
0 g
s
.77392 .70526 m .7786 .68788 L .80503 .70014 L p .707 .577 .707 r
F P
0 g
s
.4987 .64099 m .49487 .67743 L .50198 .66855 L p .707 .577 .707 r
F P
0 g
s
.50198 .66855 m .5058 .63212 L .4987 .64099 L p .707 .577 .707 r
F P
0 g
s
.30128 .66429 m .2966 .68166 L .30845 .69518 L p .707 .577 .707 r
F P
0 g
s
.71755 .6718 m .71286 .68917 L .68422 .68692 L p .707 .577 .707 r
F P
0 g
s
.29869 .54265 m .30113 .59844 L .30401 .60635 L p .707 .577 .707 r
F P
0 g
s
.50241 .53776 m .50484 .59355 L .50196 .58564 L p .707 .577 .707 r
F P
0 g
s
.50196 .58564 m .49952 .52986 L .50241 .53776 L p .707 .577 .707 r
F P
0 g
s
.30194 .65503 m .30576 .6186 L .30294 .60857 L p .707 .577 .707 r
F P
0 g
s
.71286 .68917 m .71755 .6718 L .74846 .67812 L p .707 .577 .707 r
F P
0 g
s
.7786 .68788 m .77392 .70526 L .74377 .69549 L p .707 .577 .707 r
F P
0 g
s
.74377 .69549 m .74846 .67812 L .7786 .68788 L p .707 .577 .707 r
F P
0 g
s
.74846 .67812 m .74377 .69549 L .71286 .68917 L p .707 .577 .707 r
F P
0 g
s
.30294 .60857 m .29912 .645 L .30194 .65503 L p .707 .577 .707 r
F P
0 g
s
.30113 .59844 m .29869 .54265 L .30578 .53451 L p .707 .577 .707 r
F P
0 g
s
.2966 .68166 m .30128 .66429 L .29885 .65213 L p .707 .577 .707 r
F P
0 g
s
.48919 .7138 m .48451 .73117 L .49175 .72156 L p .707 .577 .707 r
F P
0 g
s
.49175 .72156 m .49644 .70418 L .48919 .7138 L p .707 .577 .707 r
F P
0 g
s
.29885 .65213 m .29417 .66951 L .2966 .68166 L p .707 .577 .707 r
F P
0 g
s
.5058 .63212 m .50198 .66855 L .49917 .65852 L p .707 .577 .707 r
F P
0 g
s
.49917 .65852 m .50299 .62209 L .5058 .63212 L p .707 .577 .707 r
F P
0 g
s
.30578 .53451 m .30821 .59029 L .30113 .59844 L p .707 .577 .707 r
F P
0 g
s
.49952 .52986 m .50196 .58564 L .48939 .57875 L p .707 .577 .707 r
F P
0 g
s
.48939 .57875 m .48695 .52297 L .49952 .52986 L p .707 .577 .707 r
F P
0 g
s
.29912 .645 m .30294 .60857 L .31005 .59969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31005 .59969 m .30623 .63612 L .29912 .645 L p .707 .577 .707 r
F P
0 g
s
.30821 .59029 m .30578 .53451 L .32215 .52692 L p .707 .577 .707 r
F P
0 g
s
.29417 .66951 m .29885 .65213 L .3061 .64252 L p .707 .577 .707 r
F P
0 g
s
.49644 .70418 m .49175 .72156 L .48933 .7094 L p .707 .577 .707 r
F P
0 g
s
.48933 .7094 m .49401 .69203 L .49644 .70418 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3061 .64252 m .30142 .6599 L .29417 .66951 L p .707 .577 .707 r
F P
0 g
s
.50299 .62209 m .49917 .65852 L .48669 .64832 L p .707 .577 .707 r
F P
0 g
s
.48669 .64832 m .49051 .61189 L .50299 .62209 L p .707 .577 .707 r
F P
0 g
s
.48695 .52297 m .48939 .57875 L .46836 .57355 L p .707 .577 .707 r
F P
0 g
s
.46836 .57355 m .46592 .51776 L .48695 .52297 L p .707 .577 .707 r
F P
0 g
s
.32215 .52692 m .32458 .58271 L .30821 .59029 L p .707 .577 .707 r
F P
0 g
s
.30623 .63612 m .31005 .59969 L .32639 .59284 L p .707 .577 .707 r
F P
0 g
s
.32458 .58271 m .32215 .52692 L .34618 .52063 L p .707 .577 .707 r
F P
0 g
s
.32639 .59284 m .32257 .62927 L .30623 .63612 L p .707 .577 .707 r
F P
0 g
s
.30142 .6599 m .3061 .64252 L .32231 .6364 L p .707 .577 .707 r
F P
0 g
s
.49401 .69203 m .48933 .7094 L .47747 .69589 L p .707 .577 .707 r
F P
0 g
s
.47747 .69589 m .48215 .67851 L .49401 .69203 L p .707 .577 .707 r
F P
0 g
s
.32231 .6364 m .31762 .65377 L .30142 .6599 L p .707 .577 .707 r
F P
0 g
s
.49051 .61189 m .48669 .64832 L .46579 .63895 L p .707 .577 .707 r
F P
0 g
s
.46579 .63895 m .46961 .60251 L .49051 .61189 L p .707 .577 .707 r
F P
0 g
s
.46592 .51776 m .46836 .57355 L .44093 .57054 L p .707 .577 .707 r
F P
0 g
s
.44093 .57054 m .4385 .51475 L .46592 .51776 L p .707 .577 .707 r
F P
0 g
s
.34618 .52063 m .34862 .57642 L .32458 .58271 L p .707 .577 .707 r
F P
0 g
s
.32257 .62927 m .32639 .59284 L .35037 .58867 L p .707 .577 .707 r
F P
0 g
s
.34862 .57642 m .34618 .52063 L .37555 .51626 L p .707 .577 .707 r
F P
0 g
s
.4385 .51475 m .44093 .57054 L .40979 .57002 L p .707 .577 .707 r
F P
0 g
s
.40979 .57002 m .40735 .51424 L .4385 .51475 L p .707 .577 .707 r
F P
0 g
s
.35037 .58867 m .34655 .6251 L .32257 .62927 L p .707 .577 .707 r
F P
0 g
s
.31762 .65377 m .32231 .6364 L .34589 .63436 L p .707 .577 .707 r
F P
0 g
s
.37798 .57205 m .37555 .51626 L .40735 .51424 L p .707 .577 .707 r
F P
0 g
s
.37555 .51626 m .37798 .57205 L .34862 .57642 L p .707 .577 .707 r
F P
0 g
s
.48215 .67851 m .47747 .69589 L .45734 .68234 L p .707 .577 .707 r
F P
0 g
s
.45734 .68234 m .46202 .66496 L .48215 .67851 L p .707 .577 .707 r
F P
0 g
s
.46961 .60251 m .46579 .63895 L .4385 .63132 L p .707 .577 .707 r
F P
0 g
s
.4385 .63132 m .44232 .59489 L .46961 .60251 L p .707 .577 .707 r
F P
0 g
s
.40735 .51424 m .40979 .57002 L .37798 .57205 L p .707 .577 .707 r
F P
0 g
s
.34589 .63436 m .3412 .65174 L .31762 .65377 L p .707 .577 .707 r
F P
0 g
s
.34655 .6251 m .35037 .58867 L .37963 .58761 L p .707 .577 .707 r
F P
0 g
s
.44232 .59489 m .4385 .63132 L .4075 .62618 L p .707 .577 .707 r
F P
0 g
s
.4075 .62618 m .41132 .58975 L .44232 .59489 L p .707 .577 .707 r
F P
0 g
s
.37963 .58761 m .37581 .62404 L .34655 .6251 L p .707 .577 .707 r
F P
0 g
s
.37581 .62404 m .37963 .58761 L .41132 .58975 L p .707 .577 .707 r
F P
0 g
s
.3412 .65174 m .34589 .63436 L .37454 .63662 L p .707 .577 .707 r
F P
0 g
s
.46202 .66496 m .45734 .68234 L .43091 .67008 L p .707 .577 .707 r
F P
0 g
s
.43091 .67008 m .43559 .6527 L .46202 .66496 L p .707 .577 .707 r
F P
0 g
s
.41132 .58975 m .4075 .62618 L .37581 .62404 L p .707 .577 .707 r
F P
0 g
s
.37454 .63662 m .36985 .65399 L .3412 .65174 L p .707 .577 .707 r
F P
0 g
s
.36985 .65399 m .37454 .63662 L .40545 .64294 L p .707 .577 .707 r
F P
0 g
s
.43559 .6527 m .43091 .67008 L .40076 .66031 L p .707 .577 .707 r
F P
0 g
s
.40076 .66031 m .40545 .64294 L .43559 .6527 L p .707 .577 .707 r
F P
0 g
s
.40545 .64294 m .40076 .66031 L .36985 .65399 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0081ooaH008Mo
o`00N7oo20001EYF00<005YFFUH02UYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH01eYF1P00Ngoo001_Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006eoo`800003FUH005YF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00Jgoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF000006moo`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00J7oo0P001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00JWoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Moo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008006Ioo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00IWoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol006Ioo`800003FUH005YF00EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo
00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00=JEP0000001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`800003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH025YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01EYF001JEP00FUH05`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol00eYF0000000200000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IWoo001OOol60005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005]oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00FGoo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000JOolA000kOol005Aoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
015oo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH5000fOol005Aoo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003=oo`00E7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool005Aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP02
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00FUH00004FUH00`00FUIJEP03FUH60007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00EGoo00<005YF000015YF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF10000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Eo
o`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002aoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP00008000EJEQP00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000/Ool005Eoo`80009JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00@000MJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo001EOol20002FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02aoo`00EGoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool005Eoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF5`0015YF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00B7oo4@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0
000/Ool0041oo`P000AJEP03001JEUYF00IJEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000=J
EP03001oogoo02Yoo`00>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00FUIJ
EP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800004Ool005YF0003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00Ool0:goo000fOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000UYF00D005YFFUIJEP0000MJEP03001JEP00
00L000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000/Ool003=oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo001JEP030004FUH0
0`00FUH000070003FUH00`00FUIJEP02FUH700000eYF001JEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20000
1goo001JEP00FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH40004FUH01000FUIJEP00
1EYF00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP07
001JEUYFFUH005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH005YF1@001EYF00@005YFFUH000EJEP03001JEP0000@000=J
EP03001JEP0000D000IJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01P00FUH007oo001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00001JEP0=0005FUH00`00FUH000040003FUH00`00FUIJEP05FUH40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP05001JEUYFFUH0000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<000IJEP04001J
EUYFFUH=0003FUH00`00FUIJEP09FUH30005FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=J
EP000000;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60000
0eYF001JEP0:FUH00`00FUIJEP020003FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP07001JEP00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0P00<7oo000]
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000002eYF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YFFUIJ
EPD0009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUHB0007FUH0
0`00FUIJEP05FUH<0003FUH01000FUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000/Ool002eoo`03
001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
0004FUH000000005FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH0
0`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPD000=JEP05001JEUYFFUH0
000?Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00:goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF5`001EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH00`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF000005YF001JEP050005FUH01000FUIJEUYF
0P004Woo10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:goo000^Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUH000030002FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH01`00
FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00
001JEP02000015YF001JEUYF0P0015YF00@005YFFUIJEP8000Moo`<000aoo`@00003FUH005YF00AJ
EP03001JEUYF009JEP8002]oo`00;Woo00<005YF000015YF00@005YFFUIJEPH00003FUH005YF00IJ
EP03001JEUYF00IJEP07001JEP00FUH005YF00000UYF100000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF0P0025YF0`000UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH<00000eYF00000006Ool5000?Ool20005
FUH00`00FUIJEP02FUH2000[Ool002ioo`03001JEP0000AJEP@000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUH00003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020006FUH00`00FUIJEP030003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020002FUH200000eYF001JEP04FUH01000FUIJEUYF3P004Goo
0P000eYF00L005YFFUIJEP00FUH0000[Ool002ioo`03001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEUYF0004FUH20006FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20002FUH00`00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000BOol200000eYF001JEP02FUH00`00FUH0000[
Ool002ioo`03001JEP0000<000AJEQP00005FUH005YFFUH00004FUH20006FUH00`00FUH000020000
0eYF001JEP06FUH30006FUH00`00FUIJEP04FUH200000eYF001JEP05FUH30002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00002000>Ool50003FUH2000/Ool002io
o`03001JEP00009JEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00@00005FUH005YFFUH00002FUH20004FUH00`00FUH00002FUH50003FUH50005FUH00`00FUIJEP06
FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF3P000eYF00<005YF00000UYF0P00;7oo000^Ool20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH01000FUIJEUYF0`00
0UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF20000eYF00@005YFFUH0009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEQ8000IJ
EP03001JEUYF00IJEP8000EJEP03001JEUYF00AJEP03001JEUYF00@002aoo`00;Woo0P0000=JEP00
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF
00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF0000100000=JEP0000001`0015YF00@005YF
FUIJEP<000AJEP8000eJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH0000000EJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH30003
FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;7oo000^Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000050005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<002aoo`00;goo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF0000
00AJEP03001JEUYF00<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP02FUH00`00FUH0000/Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<0
05YFFUH00UYF00<005YFFUH00UYF0P00;Goo000_Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007FUH30003FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20008FUH30002FUH00`00FUIJEP02FUH2000]Ool002moo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YF
FUH00`000eYF0P00;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH20007FUH00`00FUIJEP050006FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH00eYF1000<7oo000_Ool20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH00`00FUIJEP05000;FUH00`00FUIJEP04
FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
000015YF0`001UYF00P005YFFUIJEP00FUH007oo10000UYF0`001UYF00<005YFFUH00eYF0P0000=J
EP00FUH01EYF0P00<Goo000^Ool00`00FUH00003FUH00`00FUH00003000>Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP04FUH60006FUH00`00FUH000040002FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF
00@005YFFUH000EJEP07001JEUYFFUH005YF00001Goo5@001UYF0P00<Goo000^Ool00`00FUH00003
FUH2000BOol30006Ool60006FUH00`00FUIJEP02FUH00`00FUH000020006FUH00`00FUIJEP07FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEP00FUH005YF000015YF0P000eYF00@005YFFUIJEP8000Moo`D0
00moo`8000=JEP04001JEUYF000`Ool002ioo`04001JEP00FUH20002FUH90008Ool5000;Ool40002
FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH0009JEP8000IJEP04001JEUYF0003FUH00`00Oomoo`06Ool5000A
Ool200000eYF001JEP02FUH00`00Oomoo`0]Ool002ioo`05001JEP00001JEP050003FUH01000FUIJ
EUYF3@003goo0`0015YF00@005YFFUH000EJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH20006FUH400000eYF0000000:Ool3000DOol20003FUH00`00Oomoo`0]Ool0
02ioo`D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPH0011oo`80009JEP04001J
EUYF0005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF000015YF00@005YFFUIJEP8002Eoo`04001JEUYF000_Ool002ioo`<000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000@Ool30002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH60004FUH01000FUIJEUYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP8002=oo`05001JEP00FUH0000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000aoo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEQL000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP03001JEUYF00=JEP8000QJEP<0025oo`800003FUH007oo02eoo`00;Goo00<005YF0000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP`000=JEP04001JEUYF0005
FUH00`00FUIJEP06FUH9000<FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
000NOol00`00FUH0000^Ool002eoo`80009JEPH00003FUH005YF00AJEPP000AJEP03001JEUYF00MJ
EP<000AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP04FUH5000HOol200000eYF001oo`0]Ool002eoo`@00003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000QJEP03001JEUYF0080009JEP03001JEUYF
00AJEP04001JEUYF0005FUH00`00FUH00004000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP04FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP020003FUH00`00FUIJEP07FUH00`00FUIJEP04000BOol200000eYF0000000_Ool0
02aoo`<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH0
0`00FUIJEP03FUH30006FUH01000FUIJEP0015YF0`0015YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF0000
10001EYF00<005YFFUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH01EYF1P0027oo10000eYF0P00
;goo000/Ool30003Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30000
0eYF001JEP06FUH20004FUH20002FUH00`00FUH000020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH00`00
FUH00004Ool400000eYF001JEP04FUH40007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00L0
05YFFUIJEP00FUH0000_Ool002aoo`04001JEP000004Ool300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH20008FUH30002FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03
FUH00`00FUH00008Ool20005FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80031oo`00;7oo00@005YF001JEP8000Eoo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF008000IJEP05001JEUYF001JEP0200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YF00002Woo0P000eYF00P005YFFUIJEP00FUH0
07oo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80035oo`00;7oo0P0015YF
00<007ooOol01Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP03001JEP0000aoo`80
0003FUH005YF009JEP03001JEP0000Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP00000cOol002eoo`03001JEUYF009JEP8000Qoo`<00003FUH005YF00IJEP<000IJEP03001JEUYF
00AJEP800003FUH005YF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo
00Yoo`D000=JEP03001JEP0000Yoo`H000AJEP04001JEUYFFUH5000eOol002eoo`05001JEUYFFUH0
0002FUH20009Ool50003FUH50005FUH00`00FUIJEP06FUH20006FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH200000eYF0000000:0003FUH00`00FUH00002FUH2000AOol8000jOol002ioo`04
001JEUYF0004FUH00`00Oomoo`0;Ool90004FUH00`00FUIJEP02FUH70004FUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01000Dgoo000_Ool2
0006FUH00`00Oomoo`0=Ool500000goo000000070007Ool20002FUH00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUH00000FUH00`000eYF00<005YFFUH015YF00@005YFFUIJEP<005=oo`00
<7oo00<005YFFUH015YF0`003Woo0`0057oo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<005=oo`00<Goo
0P0015YF00<005YFFUH00P0097oo00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF008000EJEP8000EJEP03001JEUYF009JEP03001JEP0005=oo`00<goo00@005YFFUH0
00EJEP8002=oo`03001JEUYF00<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000008FUH0
0`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0001COol003Aoo`<000MJEP<0025oo`<00004FUH0
00000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40008FUH30002FUH00`00FUIJEP02FUH2001DOol003Ioo`03001J
EUYF00IJEP04001JEP00000QOol01000FUH007oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH0
0P001UYF00H005YFFUH005YF0003FUH2001EOol003Moo`8000EJEP03001JEUYF009JEP<001ioo`80
00Aoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20003FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P0000=J
EP000000Egoo000iOol20003FUH00`00FUIJEP05FUH6000FOol40006Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001EYF
00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<007ooOol0Egoo000kOol30009FUH00`00FUIJEP02
FUH80008Ool60002FUH00`00Oomoo`08Ool40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP02FUH50006FUH2001HOol003eoo`<000IJ
EP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P003Woo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@0000=oo`0000000`0000=oo`000000
1`001Goo0P0015YF00<005YF0000Egoo0010Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00005Goo2@001UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
1Woo1@004Goo00@005YFFUH000=JEP03001oogoo05Aoo`00A7oo1@001UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP8001iooaX000eoo`D0019oo`<000=JEP03001oogoo05Aoo`00BGoo
10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo00<005YFFUH00UYF00@0
05YFFUIJEP8000aoo`<001Eoo`05001JEUYFFUH0001FOol004eoo`H000AJEP04001JEUYFFUH6000c
Ool20002FUH00`00FUIJEP03FUH2000SOol01@00FUH005YF0000EGoo001COol8000kOol20008FUH2
000ROol200000eYF001oo`1DOol009Moo`03001JEUYF00IJEP03001JEP000080021oo`03001JEP00
05Eoo`00V7oo0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000EGoo002JOol20003FUH00`00
FUIJEP06FUH6000EOol4001FOol009aoo`800003FUH005YF00MJEP03001JEUYF00=JEPP000Qoo`D0
009JEP8005Ioo`00WWoo0`001eYF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF009J
EP8005Ioo`00XGoo10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8005Moo`00YGoo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00
Egoo002ZOol40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001HOol00:ioo`H0
00AJEP04001JEUYFFUH6001KOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60557 .74479 m .60164 .68894 L .57054 .68928 L p .707 .577 .707 r
F P
0 g
s
.60164 .68894 m .60557 .74479 L .63734 .74199 L p .707 .577 .707 r
F P
0 g
s
.63734 .74199 m .6334 .68614 L .60164 .68894 L p .707 .577 .707 r
F P
0 g
s
.6334 .68614 m .63734 .74199 L .66666 .73701 L p .707 .577 .707 r
F P
0 g
s
.66666 .73701 m .66273 .68115 L .6334 .68614 L p .707 .577 .707 r
F P
0 g
s
.57448 .74514 m .57054 .68928 L .54317 .68713 L p .707 .577 .707 r
F P
0 g
s
.57054 .68928 m .57448 .74514 L .60557 .74479 L p .707 .577 .707 r
F P
0 g
s
.66273 .68115 m .66666 .73701 L .69068 .73033 L p .707 .577 .707 r
F P
0 g
s
.69068 .73033 m .68674 .67447 L .66273 .68115 L p .707 .577 .707 r
F P
0 g
s
.54317 .68713 m .5471 .74299 L .57448 .74514 L p .707 .577 .707 r
F P
0 g
s
.60129 .81075 m .60745 .77491 L .57672 .76781 L p .707 .577 .707 r
F P
0 g
s
.60745 .77491 m .60129 .81075 L .63273 .81467 L p .707 .577 .707 r
F P
0 g
s
.63273 .81467 m .63889 .77883 L .60745 .77491 L p .707 .577 .707 r
F P
0 g
s
.5471 .74299 m .54317 .68713 L .52218 .6827 L p .707 .577 .707 r
F P
0 g
s
.63889 .77883 m .63273 .81467 L .6618 .81501 L p .707 .577 .707 r
F P
0 g
s
.6618 .81501 m .66796 .77917 L .63889 .77883 L p .707 .577 .707 r
F P
0 g
s
.57056 .80365 m .57672 .76781 L .5497 .75822 L p .707 .577 .707 r
F P
0 g
s
.57672 .76781 m .57056 .80365 L .60129 .81075 L p .707 .577 .707 r
F P
0 g
s
.68674 .67447 m .69068 .73033 L .70704 .7226 L p .707 .577 .707 r
F P
0 g
s
.70704 .7226 m .7031 .66675 L .68674 .67447 L p .707 .577 .707 r
F P
0 g
s
.52218 .6827 m .52612 .73855 L .5471 .74299 L p .707 .577 .707 r
F P
0 g
s
.66796 .77917 m .6618 .81501 L .68565 .81175 L p .707 .577 .707 r
F P
0 g
s
.68565 .81175 m .69181 .77591 L .66796 .77917 L p .707 .577 .707 r
F P
0 g
s
.5497 .75822 m .54354 .79406 L .57056 .80365 L p .707 .577 .707 r
F P
0 g
s
.54354 .79406 m .5497 .75822 L .52904 .74708 L p .707 .577 .707 r
F P
0 g
s
.58685 .86119 m .59428 .84515 L .56577 .83087 L p .707 .577 .707 r
F P
0 g
s
.59428 .84515 m .58685 .86119 L .61629 .87158 L p .707 .577 .707 r
F P
0 g
s
.61629 .87158 m .62372 .85553 L .59428 .84515 L p .707 .577 .707 r
F P
0 g
s
.52612 .73855 m .52218 .6827 L .50965 .67642 L p .707 .577 .707 r
F P
0 g
s
.55834 .84692 m .56577 .83087 L .54098 .8141 L p .707 .577 .707 r
F P
0 g
s
.56577 .83087 m .55834 .84692 L .58685 .86119 L p .707 .577 .707 r
F P
0 g
s
.52904 .74708 m .52288 .78291 L .54354 .79406 L p .707 .577 .707 r
F P
0 g
s
.62372 .85553 m .61629 .87158 L .64376 .87706 L p .707 .577 .707 r
F P
0 g
s
.64376 .87706 m .6512 .86101 L .62372 .85553 L p .707 .577 .707 r
F P
0 g
s
.54098 .8141 m .53354 .83015 L .55834 .84692 L p .707 .577 .707 r
F P
0 g
s
.53354 .83015 m .54098 .8141 L .52232 .79648 L p .707 .577 .707 r
F P
0 g
s
.69181 .77591 m .68565 .81175 L .70195 .80521 L p .707 .577 .707 r
F P
0 g
s
.70195 .80521 m .70811 .76937 L .69181 .77591 L p .707 .577 .707 r
F P
0 g
s
.7031 .66675 m .70704 .7226 L .71413 .7146 L p .707 .577 .707 r
F P
0 g
s
.71413 .7146 m .7102 .65874 L .7031 .66675 L p .707 .577 .707 r
F P
0 g
s
.50965 .67642 m .51358 .73228 L .51827 .73462 L p .707 .577 .707 r
F P
0 g
s
.51358 .73228 m .50965 .67642 L .50679 .66891 L p .707 .577 .707 r
F P
0 g
s
.50679 .66891 m .51072 .72477 L .51175 .72747 L p .707 .577 .707 r
F P
0 g
s
.51175 .72747 m .51358 .73228 L p .51183 .71591 L .707 .577 .707 r
F P
0 g
s
.51183 .71591 m .50679 .66891 L .51175 .72747 L .707 .577 .707 r
F
.51677 .73547 m .51407 .72454 L p .51151 .75913 L F P
0 g
s
.52174 .72204 m .50965 .67642 L .51827 .73462 L .707 .577 .707 r
F
.51407 .72454 m .50791 .76037 L .5106 .77131 L p F P
0 g
s
.51407 .72454 m .52122 .71535 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.50791 .76037 m .51168 .73842 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.51168 .73842 m .51407 .72454 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.5106 .77131 m .51467 .74768 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51467 .74768 m .51677 .73547 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51827 .73462 m .52612 .73855 L p .52174 .72204 L .707 .577 .707 r
F P
0 g
s
.52288 .78291 m .52904 .74708 L .51677 .73547 L p .707 .577 .707 r
F P
0 g
s
.52232 .79648 m .51489 .81253 L .53354 .83015 L p .707 .577 .707 r
F P
0 g
s
.6512 .86101 m .64376 .87706 L .66659 .8771 L p .707 .577 .707 r
F P
0 g
s
.66659 .8771 m .67403 .86105 L .6512 .86101 L p .707 .577 .707 r
F P
0 g
s
.51677 .73547 m .5106 .77131 L .52288 .78291 L p .707 .577 .707 r
F P
0 g
s
.51489 .81253 m .52232 .79648 L .51163 .77974 L p .707 .577 .707 r
F P
0 g
s
.51163 .77974 m .5042 .79579 L .51489 .81253 L p .707 .577 .707 r
F P
0 g
s
.70811 .76937 m .70195 .80521 L .7091 .79602 L p .707 .577 .707 r
F P
0 g
s
.7091 .79602 m .71526 .76018 L .70811 .76937 L p .707 .577 .707 r
F P
0 g
s
.7102 .65874 m .71413 .7146 L .71127 .70708 L p .707 .577 .707 r
F P
0 g
s
.71127 .70708 m .70734 .65123 L .7102 .65874 L p .707 .577 .707 r
F P
0 g
s
.67403 .86105 m .66659 .8771 L .68254 .87169 L p .707 .577 .707 r
F P
0 g
s
.68254 .87169 m .68997 .85565 L .67403 .86105 L p .707 .577 .707 r
F P
0 g
s
.47349 .82204 m .5007 .32386 L .45675 .31877 L p .707 .577 .707 r
F P
0 g
s
.5042 .79579 m .51163 .77974 L .50996 .76551 L p .707 .577 .707 r
F P
0 g
s
.51072 .72477 m .50679 .66891 L .51388 .6609 L p .707 .577 .707 r
F P
0 g
s
.50996 .76551 m .50253 .78156 L .5042 .79579 L p .707 .577 .707 r
F P
0 g
s
.51388 .6609 m .51782 .71676 L .51072 .72477 L p .707 .577 .707 r
F P
0 g
s
.52122 .71535 m .51506 .75118 L .50791 .76037 L p .707 .577 .707 r
F P
0 g
s
.50253 .78156 m .50996 .76551 L .51746 .75519 L p .707 .577 .707 r
F P
0 g
s
.51746 .75519 m .51003 .77123 L .50253 .78156 L p .707 .577 .707 r
F P
0 g
s
.51506 .75118 m .52122 .71535 L .53752 .7088 L p .707 .577 .707 r
F P
0 g
s
.53752 .7088 m .53136 .74464 L .51506 .75118 L p .707 .577 .707 r
F P
0 g
s
.51003 .77123 m .51746 .75519 L .53341 .74978 L p .707 .577 .707 r
F P
0 g
s
.53341 .74978 m .52598 .76583 L .51003 .77123 L p .707 .577 .707 r
F P
0 g
s
.5007 .32386 m .47349 .82204 L .51838 .82311 L p .707 .577 .707 r
F P
0 g
s
.51782 .71676 m .51388 .6609 L .53024 .65318 L p .707 .577 .707 r
F P
0 g
s
.53024 .65318 m .53417 .70903 L .51782 .71676 L p .707 .577 .707 r
F P
0 g
s
.51838 .82311 m .54558 .32494 L .5007 .32386 L p .707 .577 .707 r
F P
0 g
s
.53417 .70903 m .53024 .65318 L .55425 .6465 L p .707 .577 .707 r
F P
0 g
s
.53136 .74464 m .53752 .7088 L .56137 .70554 L p .707 .577 .707 r
F P
0 g
s
.55425 .6465 m .55819 .70235 L .53417 .70903 L p .707 .577 .707 r
F P
0 g
s
.55819 .70235 m .55425 .6465 L .58358 .64151 L p .707 .577 .707 r
F P
0 g
s
.56137 .70554 m .55521 .74138 L .53136 .74464 L p .707 .577 .707 r
F P
0 g
s
.52598 .76583 m .53341 .74978 L .55624 .74982 L p .707 .577 .707 r
F P
0 g
s
.55624 .74982 m .54881 .76586 L .52598 .76583 L p .707 .577 .707 r
F P
0 g
s
.55521 .74138 m .56137 .70554 L .59044 .70589 L p .707 .577 .707 r
F P
0 g
s
.59044 .70589 m .58428 .74173 L .55521 .74138 L p .707 .577 .707 r
F P
0 g
s
.54881 .76586 m .55624 .74982 L .58372 .7553 L p .707 .577 .707 r
F P
0 g
s
.58372 .7553 m .57629 .77135 L .54881 .76586 L p .707 .577 .707 r
F P
0 g
s
.54558 .32494 m .51838 .82311 L .55981 .82007 L p .707 .577 .707 r
F P
0 g
s
.58358 .64151 m .58752 .69737 L .55819 .70235 L p .707 .577 .707 r
F P
0 g
s
.55981 .82007 m .58702 .32189 L .54558 .32494 L p .707 .577 .707 r
F P
0 g
s
.42955 .81695 m .45675 .31877 L .41806 .31016 L p .707 .577 .707 r
F P
0 g
s
.45675 .31877 m .42955 .81695 L .47349 .82204 L p .707 .577 .707 r
F P
0 g
s
.71526 .76018 m .7091 .79602 L .70641 .78509 L p .707 .577 .707 r
F P
0 g
s
.70641 .78509 m .71257 .74925 L .71526 .76018 L p .707 .577 .707 r
F P
0 g
s
.68997 .85565 m .68254 .87169 L .69005 .86137 L p .707 .577 .707 r
F P
0 g
s
.69005 .86137 m .69748 .84532 L .68997 .85565 L p .707 .577 .707 r
F P
0 g
s
.70734 .65123 m .71127 .70708 L .69874 .70081 L p .707 .577 .707 r
F P
0 g
s
.69874 .70081 m .6948 .64495 L .70734 .65123 L p .707 .577 .707 r
F P
0 g
s
.58752 .69737 m .58358 .64151 L .61534 .63871 L p .707 .577 .707 r
F P
0 g
s
.61534 .63871 m .61928 .69457 L .58752 .69737 L p .707 .577 .707 r
F P
0 g
s
.58428 .74173 m .59044 .70589 L .62188 .7098 L p .707 .577 .707 r
F P
0 g
s
.62188 .7098 m .61572 .74564 L .58428 .74173 L p .707 .577 .707 r
F P
0 g
s
.57629 .77135 m .58372 .7553 L .61315 .76568 L p .707 .577 .707 r
F P
0 g
s
.61315 .76568 m .60572 .78173 L .57629 .77135 L p .707 .577 .707 r
F P
0 g
s
.58702 .32189 m .55981 .82007 L .59374 .8132 L p .707 .577 .707 r
F P
0 g
s
.59374 .8132 m .62094 .31502 L .58702 .32189 L p .707 .577 .707 r
F P
0 g
s
.39085 .80834 m .41806 .31016 L .38839 .29888 L p .707 .577 .707 r
F P
0 g
s
.41806 .31016 m .39085 .80834 L .42955 .81695 L p .707 .577 .707 r
F P
0 g
s
.26256 .71479 m .25863 .65894 L .22754 .65928 L p .707 .577 .707 r
F P
0 g
s
.25863 .65894 m .26256 .71479 L .29433 .71199 L p .707 .577 .707 r
F P
0 g
s
.29433 .71199 m .29039 .65614 L .25863 .65894 L p .707 .577 .707 r
F P
0 g
s
.29039 .65614 m .29433 .71199 L .32365 .70701 L p .707 .577 .707 r
F P
0 g
s
.32365 .70701 m .31972 .65115 L .29039 .65614 L p .707 .577 .707 r
F P
0 g
s
.23147 .71513 m .22754 .65928 L .20016 .65713 L p .707 .577 .707 r
F P
0 g
s
.22754 .65928 m .23147 .71513 L .26256 .71479 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71257 .74925 m .70641 .78509 L .69413 .77348 L p .707 .577 .707 r
F P
0 g
s
.69413 .77348 m .70029 .73764 L .71257 .74925 L p .707 .577 .707 r
F P
0 g
s
.69748 .84532 m .69005 .86137 L .68837 .84714 L p .707 .577 .707 r
F P
0 g
s
.68837 .84714 m .69581 .83109 L .69748 .84532 L p .707 .577 .707 r
F P
0 g
s
.31972 .65115 m .32365 .70701 L .34767 .70033 L p .707 .577 .707 r
F P
0 g
s
.34767 .70033 m .34373 .64447 L .31972 .65115 L p .707 .577 .707 r
F P
0 g
s
.6948 .64495 m .69874 .70081 L .67775 .69637 L p .707 .577 .707 r
F P
0 g
s
.67775 .69637 m .67382 .64052 L .6948 .64495 L p .707 .577 .707 r
F P
0 g
s
.61928 .69457 m .61534 .63871 L .64644 .63837 L p .707 .577 .707 r
F P
0 g
s
.65261 .7169 m .64645 .75274 L .61572 .74564 L p .707 .577 .707 r
F P
0 g
s
.61572 .74564 m .62188 .7098 L .65261 .7169 L p .707 .577 .707 r
F P
0 g
s
.64167 .77996 m .63423 .79601 L .60572 .78173 L p .707 .577 .707 r
F P
0 g
s
.60572 .78173 m .61315 .76568 L .64167 .77996 L p .707 .577 .707 r
F P
0 g
s
.62094 .31502 m .59374 .8132 L .61684 .80318 L p .707 .577 .707 r
F P
0 g
s
.64644 .63837 m .65037 .69423 L .61928 .69457 L p .707 .577 .707 r
F P
0 g
s
.61684 .80318 m .64404 .305 L .62094 .31502 L p .707 .577 .707 r
F P
0 g
s
.20016 .65713 m .20409 .71298 L .23147 .71513 L p .707 .577 .707 r
F P
0 g
s
.25828 .7832 m .26444 .74736 L .23371 .74026 L p .707 .577 .707 r
F P
0 g
s
.26444 .74736 m .25828 .7832 L .28972 .78711 L p .707 .577 .707 r
F P
0 g
s
.28972 .78711 m .29588 .75127 L .26444 .74736 L p .707 .577 .707 r
F P
0 g
s
.20409 .71298 m .20016 .65713 L .17917 .6527 L p .707 .577 .707 r
F P
0 g
s
.29588 .75127 m .28972 .78711 L .31879 .78746 L p .707 .577 .707 r
F P
0 g
s
.31879 .78746 m .32495 .75162 L .29588 .75127 L p .707 .577 .707 r
F P
0 g
s
.22755 .7761 m .23371 .74026 L .20669 .73066 L p .707 .577 .707 r
F P
0 g
s
.23371 .74026 m .22755 .7761 L .25828 .7832 L p .707 .577 .707 r
F P
0 g
s
.34373 .64447 m .34767 .70033 L .36403 .6926 L p .707 .577 .707 r
F P
0 g
s
.36403 .6926 m .36009 .63675 L .34373 .64447 L p .707 .577 .707 r
F P
0 g
s
.36009 .63675 m .36403 .6926 L .37112 .68459 L p .707 .577 .707 r
F P
0 g
s
.37112 .68459 m .36719 .62874 L .36009 .63675 L p .707 .577 .707 r
F P
0 g
s
.35894 .77765 m .3651 .74181 L .3488 .74836 L p .707 .577 .707 r
F P
0 g
s
.3651 .74181 m .35894 .77765 L .36609 .76846 L p .707 .577 .707 r
F P
0 g
s
.36719 .62874 m .37112 .68459 L .36826 .67708 L p .707 .577 .707 r
F P
0 g
s
.36826 .67708 m .36433 .62123 L .36719 .62874 L p .707 .577 .707 r
F P
0 g
s
.36433 .62123 m .36826 .67708 L .3614 .67365 L p .707 .577 .707 r
F P
0 g
s
.3614 .67365 m .35573 .6708 L p .35863 .65407 L .707 .577 .707 r
F P
0 g
s
.35863 .65407 m .36433 .62123 L .3614 .67365 L .707 .577 .707 r
F
.38839 .29888 m .3661 .70694 L p .39085 .80834 L F P
0 g
s
.36609 .76846 m .37225 .73263 L .3651 .74181 L p .707 .577 .707 r
F P
0 g
s
.37225 .73263 m .36609 .76846 L .3634 .75753 L p .707 .577 .707 r
F P
0 g
s
.3634 .75753 m .36956 .72169 L .37225 .73263 L p .707 .577 .707 r
F P
0 g
s
.36956 .72169 m .3634 .75753 L .35638 .7509 L p .707 .577 .707 r
F P
0 g
s
.35638 .7509 m .35112 .74592 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.36106 .73286 m .36956 .72169 L .35638 .7509 L .707 .577 .707 r
F
.35112 .74592 m .35728 .71009 L .36506 .71744 L p F P
0 g
s
.36506 .71744 m .36956 .72169 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.35112 .74592 m .36506 .71744 L .36106 .73286 L .707 .577 .707 r
F
.37985 .80415 m .39085 .80834 L p .36692 .71028 L F P
0 g
s
.36692 .71028 m .3661 .70694 L .3667 .71113 L .707 .577 .707 r
F
.36692 .71028 m .3667 .71113 L .37985 .80415 L F
.36118 .79705 m .37985 .80415 L p .3667 .71113 L F P
0 g
s
.3661 .70694 m .36566 .71515 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36566 .71515 m .36118 .79705 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36118 .79705 m .38839 .29888 L .37066 .28602 L p .707 .577 .707 r
F P
0 g
s
.17917 .6527 m .18311 .70855 L .20409 .71298 L p .707 .577 .707 r
F P
0 g
s
.70029 .73764 m .69413 .77348 L .67347 .76233 L p .707 .577 .707 r
F P
0 g
s
.67347 .76233 m .67963 .7265 L .70029 .73764 L p .707 .577 .707 r
F P
0 g
s
.67382 .64052 m .67775 .69637 L .65037 .69423 L p .707 .577 .707 r
F P
0 g
s
.65037 .69423 m .64644 .63837 L .67382 .64052 L p .707 .577 .707 r
F P
0 g
s
.32495 .75162 m .31879 .78746 L .34264 .7842 L p .707 .577 .707 r
F P
0 g
s
.34264 .7842 m .3488 .74836 L .32495 .75162 L p .707 .577 .707 r
F P
0 g
s
.20669 .73066 m .20053 .7665 L .22755 .7761 L p .707 .577 .707 r
F P
0 g
s
.20053 .7665 m .20669 .73066 L .18603 .71952 L p .707 .577 .707 r
F P
0 g
s
.69581 .83109 m .68837 .84714 L .67768 .8304 L p .707 .577 .707 r
F P
0 g
s
.67768 .8304 m .68512 .81435 L .69581 .83109 L p .707 .577 .707 r
F P
0 g
s
.24384 .82703 m .25128 .81098 L .22276 .7967 L p .707 .577 .707 r
F P
0 g
s
.25128 .81098 m .24384 .82703 L .27328 .83741 L p .707 .577 .707 r
F P
0 g
s
.27328 .83741 m .28071 .82136 L .25128 .81098 L p .707 .577 .707 r
F P
0 g
s
.18311 .70855 m .17917 .6527 L .16664 .64642 L p .707 .577 .707 r
F P
0 g
s
.21533 .81275 m .22276 .7967 L .19797 .77993 L p .707 .577 .707 r
F P
0 g
s
.22276 .7967 m .21533 .81275 L .24384 .82703 L p .707 .577 .707 r
F P
0 g
s
.28071 .82136 m .27328 .83741 L .30075 .84289 L p .707 .577 .707 r
F P
0 g
s
.30075 .84289 m .30819 .82685 L .28071 .82136 L p .707 .577 .707 r
F P
0 g
s
.18603 .71952 m .17987 .75536 L .20053 .7665 L p .707 .577 .707 r
F P
0 g
s
.19797 .77993 m .19053 .79598 L .21533 .81275 L p .707 .577 .707 r
F P
0 g
s
.64404 .305 m .61684 .80318 L .62685 .79099 L p .707 .577 .707 r
F P
0 g
s
.62685 .79099 m .65405 .29281 L .64404 .305 L p .707 .577 .707 r
F P
0 g
s
.19053 .79598 m .19797 .77993 L .17931 .76231 L p .707 .577 .707 r
F P
0 g
s
.3488 .74836 m .34264 .7842 L .35894 .77765 L p .707 .577 .707 r
F P
0 g
s
.67963 .7265 m .67347 .76233 L .64645 .75274 L p .707 .577 .707 r
F P
0 g
s
.64645 .75274 m .65261 .7169 L .67963 .7265 L p .707 .577 .707 r
F P
0 g
s
.16664 .64642 m .17057 .70228 L .18311 .70855 L p .707 .577 .707 r
F P
0 g
s
.17987 .75536 m .18603 .71952 L .17376 .70791 L p .707 .577 .707 r
F P
0 g
s
.17931 .76231 m .17188 .77836 L .19053 .79598 L p .707 .577 .707 r
F P
0 g
s
.68512 .81435 m .67768 .8304 L .65903 .81278 L p .707 .577 .707 r
F P
0 g
s
.65903 .81278 m .66646 .79673 L .68512 .81435 L p .707 .577 .707 r
F P
0 g
s
.30819 .82685 m .30075 .84289 L .32358 .84293 L p .707 .577 .707 r
F P
0 g
s
.32358 .84293 m .33102 .82688 L .30819 .82685 L p .707 .577 .707 r
F P
0 g
s
.35573 .6708 m .35346 .63859 L p .36433 .62123 L .707 .577 .707 r
F P
0 g
s
.35346 .63859 m .35179 .61495 L .35543 .61677 L p .707 .577 .707 r
F P
0 g
s
.35543 .61677 m .36433 .62123 L p .35346 .63859 L .707 .577 .707 r
F P
0 g
s
.35179 .61495 m .35573 .6708 L .33474 .66637 L p .707 .577 .707 r
F P
0 g
s
.33474 .66637 m .33081 .61052 L .35179 .61495 L p .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .33662 .69894 L .34911 .70568 L p .707 .577 .707 r
F P
0 g
s
.34911 .70568 m .35728 .71009 L p .34855 .71812 L .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .34911 .70568 L .34855 .71812 L .707 .577 .707 r
F
.34661 .71435 m .35715 .52669 L .3666 .27286 L F
.37066 .28602 m .3683 .27837 L p .35715 .52669 L F P
0 g
s
.3683 .27837 m .3666 .27286 L p .35715 .52669 L .707 .577 .707 r
F P
0 g
s
.35728 .71009 m .35112 .74592 L .33046 .73478 L p .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34211 .78018 L .34644 .78697 L p .707 .577 .707 r
F P
0 g
s
.34644 .78697 m .3528 .79692 L p .34659 .79668 L .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34644 .78697 L .34659 .79668 L .707 .577 .707 r
F
.34567 .7353 m .34827 .69607 L .34661 .71435 L F
.34345 .7842 m .34576 .74186 L p .34567 .7353 L F P
0 g
s
.34576 .74186 m .34827 .69607 L p .34567 .7353 L .707 .577 .707 r
F P
0 g
s
.34827 .69607 m .37066 .28602 L p .34661 .71435 L .707 .577 .707 r
F P
0 g
s
.37066 .28602 m .34345 .7842 L .36118 .79705 L p .707 .577 .707 r
F P
0 g
s
.17376 .70791 m .16759 .74375 L .17987 .75536 L p .707 .577 .707 r
F P
0 g
s
.17057 .70228 m .16664 .64642 L .16378 .63891 L p .707 .577 .707 r
F P
0 g
s
.17188 .77836 m .17931 .76231 L .16862 .74557 L p .707 .577 .707 r
F P
0 g
s
.16862 .74557 m .16119 .76162 L .17188 .77836 L p .707 .577 .707 r
F P
0 g
s
.66646 .79673 m .65903 .81278 L .63423 .79601 L p .707 .577 .707 r
F P
0 g
s
.63423 .79601 m .64167 .77996 L .66646 .79673 L p .707 .577 .707 r
F P
0 g
s
.33102 .82688 m .32358 .84293 L .33953 .83752 L p .707 .577 .707 r
F P
0 g
s
.33953 .83752 m .34697 .82148 L .33102 .82688 L p .707 .577 .707 r
F P
0 g
s
.16887 .69782 m .17057 .70228 L p .16894 .68708 L .707 .577 .707 r
F P
0 g
s
.16759 .74375 m .17376 .70791 L .17106 .69698 L p .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .1649 .73282 L .16526 .73428 L p .707 .577 .707 r
F P
0 g
s
.16526 .73428 m .16759 .74375 L p .16908 .72371 L .707 .577 .707 r
F P
0 g
s
.16908 .72371 m .17106 .69698 L .16526 .73428 L .707 .577 .707 r
F
.16119 .76162 m .16862 .74557 L .16695 .73134 L p F P
0 g
s
.16695 .73134 m .15952 .74739 L .16119 .76162 L p .707 .577 .707 r
F P
0 g
s
.16695 .73134 m .17445 .72102 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.15952 .74739 m .16409 .73751 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.16409 .73751 m .16695 .73134 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .17821 .68779 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1649 .73282 m .1688 .71016 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1688 .71016 m .17106 .69698 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.16378 .63891 m .16771 .69476 L .16887 .69782 L p .707 .577 .707 r
F P
0 g
s
.16894 .68708 m .16378 .63891 L .16887 .69782 L .707 .577 .707 r
F
.65405 .29281 m .62685 .79099 L .62279 .77782 L p F P
0 g
s
.62279 .77782 m .64999 .27965 L .65405 .29281 L p .707 .577 .707 r
F P
0 g
s
.16771 .69476 m .16378 .63891 L .17087 .6309 L p .707 .577 .707 r
F P
0 g
s
.3666 .27286 m .33939 .77103 L .34345 .7842 L p .707 .577 .707 r
F P
0 g
s
.33939 .77103 m .3666 .27286 L .37661 .26067 L p .707 .577 .707 r
F P
0 g
s
.34697 .82148 m .33953 .83752 L .34704 .8272 L p .707 .577 .707 r
F P
0 g
s
.34704 .8272 m .35447 .81115 L .34697 .82148 L p .707 .577 .707 r
F P
0 g
s
.17087 .6309 m .17481 .68675 L .16771 .69476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17821 .68779 m .17205 .72363 L .1649 .73282 L p .707 .577 .707 r
F P
0 g
s
.17481 .68675 m .17087 .6309 L .18723 .62318 L p .707 .577 .707 r
F P
0 g
s
.19451 .68125 m .19387 .68497 L p .17205 .72363 L .707 .577 .707 r
F P
0 g
s
.16702 .73706 m .17445 .72102 L .1904 .71561 L p .707 .577 .707 r
F P
0 g
s
.19387 .68497 m .18835 .71708 L .17389 .72289 L p .707 .577 .707 r
F P
0 g
s
.17445 .72102 m .17135 .72772 L p .15952 .74739 L .707 .577 .707 r
F P
0 g
s
.17389 .72289 m .17205 .72363 L p .19387 .68497 L .707 .577 .707 r
F P
0 g
s
.17135 .72772 m .16702 .73706 L .16486 .74004 L p .707 .577 .707 r
F P
0 g
s
.16486 .74004 m .15952 .74739 L p .17135 .72772 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64999 .27965 m .62279 .77782 L .60506 .76497 L p .707 .577 .707 r
F P
0 g
s
.60506 .76497 m .63226 .26679 L .64999 .27965 L p .707 .577 .707 r
F P
0 g
s
.35447 .81115 m .34704 .8272 L .34536 .81297 L p .707 .577 .707 r
F P
0 g
s
.34536 .81297 m .3528 .79692 L .35447 .81115 L p .707 .577 .707 r
F P
0 g
s
.17205 .72363 m .17821 .68779 L .19451 .68125 L p .707 .577 .707 r
F P
0 g
s
.18723 .62318 m .19116 .67903 L .17481 .68675 L p .707 .577 .707 r
F P
0 g
s
.3494 .75884 m .37661 .26067 L .39971 .25065 L p .707 .577 .707 r
F P
0 g
s
.37661 .26067 m .3494 .75884 L .33939 .77103 L p .707 .577 .707 r
F P
0 g
s
.19116 .67903 m .18723 .62318 L .21125 .6165 L p .707 .577 .707 r
F P
0 g
s
.21836 .67799 m .21743 .68345 L p .18835 .71708 L .707 .577 .707 r
F P
0 g
s
.18297 .73166 m .1904 .71561 L .21323 .71565 L p .707 .577 .707 r
F P
0 g
s
.21743 .68345 m .2122 .71383 L .19154 .71665 L p .707 .577 .707 r
F P
0 g
s
.1904 .71561 m .18755 .72177 L p .16702 .73706 L .707 .577 .707 r
F P
0 g
s
.19154 .71665 m .18835 .71708 L p .21743 .68345 L .707 .577 .707 r
F P
0 g
s
.18755 .72177 m .18297 .73166 L .17872 .7331 L p .707 .577 .707 r
F P
0 g
s
.17872 .7331 m .16702 .73706 L p .18755 .72177 L .707 .577 .707 r
F P
0 g
s
.33081 .61052 m .33474 .66637 L .30736 .66422 L p .707 .577 .707 r
F P
0 g
s
.30736 .66422 m .30343 .60837 L .33081 .61052 L p .707 .577 .707 r
F P
0 g
s
.3528 .79692 m .34536 .81297 L .33468 .79623 L p .707 .577 .707 r
F P
0 g
s
.18835 .71708 m .19451 .68125 L .21836 .67799 L p .707 .577 .707 r
F P
0 g
s
.21125 .6165 m .21518 .67235 L .19116 .67903 L p .707 .577 .707 r
F P
0 g
s
.63226 .26679 m .60506 .76497 L .57539 .75368 L p .707 .577 .707 r
F P
0 g
s
.57539 .75368 m .6026 .25551 L .63226 .26679 L p .707 .577 .707 r
F P
0 g
s
.21518 .67235 m .21125 .6165 L .24057 .61151 L p .707 .577 .707 r
F P
0 g
s
.30343 .60837 m .30736 .66422 L .27627 .66457 L p .707 .577 .707 r
F P
0 g
s
.27627 .66457 m .27233 .60871 L .30343 .60837 L p .707 .577 .707 r
F P
0 g
s
.39971 .25065 m .3725 .74882 L .3494 .75884 L p .707 .577 .707 r
F P
0 g
s
.3725 .74882 m .39971 .25065 L .43363 .24378 L p .707 .577 .707 r
F P
0 g
s
.24451 .66737 m .24057 .61151 L .27233 .60871 L p .707 .577 .707 r
F P
0 g
s
.24057 .61151 m .24451 .66737 L .21518 .67235 L p .707 .577 .707 r
F P
0 g
s
.21323 .71565 m .2058 .73169 L .18297 .73166 L p .707 .577 .707 r
F P
0 g
s
.33662 .69894 m .33046 .73478 L .30344 .72519 L p .707 .577 .707 r
F P
0 g
s
.30344 .72519 m .3096 .68935 L .33662 .69894 L p .707 .577 .707 r
F P
0 g
s
.74278 .65275 m .73884 .5969 L .70775 .59724 L p .707 .577 .707 r
F P
0 g
s
.73884 .5969 m .74278 .65275 L .77454 .64995 L p .707 .577 .707 r
F P
0 g
s
.77454 .64995 m .77061 .5941 L .73884 .5969 L p .707 .577 .707 r
F P
0 g
s
.27233 .60871 m .27627 .66457 L .24451 .66737 L p .707 .577 .707 r
F P
0 g
s
.2122 .71383 m .21836 .67799 L .24743 .67833 L p .707 .577 .707 r
F P
0 g
s
.77061 .5941 m .77454 .64995 L .80387 .64497 L p .707 .577 .707 r
F P
0 g
s
.80387 .64497 m .79993 .58912 L .77061 .5941 L p .707 .577 .707 r
F P
0 g
s
.34211 .78018 m .33468 .79623 L .31602 .77861 L p .707 .577 .707 r
F P
0 g
s
.31602 .77861 m .32345 .76256 L .34211 .78018 L p .707 .577 .707 r
F P
0 g
s
.71168 .6531 m .70775 .59724 L .68037 .59509 L p .707 .577 .707 r
F P
0 g
s
.70775 .59724 m .71168 .6531 L .74278 .65275 L p .707 .577 .707 r
F P
0 g
s
.3096 .68935 m .30344 .72519 L .27271 .71808 L p .707 .577 .707 r
F P
0 g
s
.27271 .71808 m .27887 .68225 L .3096 .68935 L p .707 .577 .707 r
F P
0 g
s
.79993 .58912 m .80387 .64497 L .82788 .63829 L p .707 .577 .707 r
F P
0 g
s
.82788 .63829 m .82395 .58243 L .79993 .58912 L p .707 .577 .707 r
F P
0 g
s
.24743 .67833 m .24127 .71417 L .2122 .71383 L p .707 .577 .707 r
F P
0 g
s
.2058 .73169 m .21323 .71565 L .24071 .72113 L p .707 .577 .707 r
F P
0 g
s
.24127 .71417 m .24743 .67833 L .27887 .68225 L p .707 .577 .707 r
F P
0 g
s
.6026 .25551 m .57539 .75368 L .53669 .74507 L p .707 .577 .707 r
F P
0 g
s
.53669 .74507 m .5639 .2469 L .6026 .25551 L p .707 .577 .707 r
F P
0 g
s
.27887 .68225 m .27271 .71808 L .24127 .71417 L p .707 .577 .707 r
F P
0 g
s
.68037 .59509 m .68431 .65095 L .71168 .6531 L p .707 .577 .707 r
F P
0 g
s
.7385 .71871 m .74466 .68288 L .71392 .67578 L p .707 .577 .707 r
F P
0 g
s
.74466 .68288 m .7385 .71871 L .76993 .72263 L p .707 .577 .707 r
F P
0 g
s
.76993 .72263 m .7761 .68679 L .74466 .68288 L p .707 .577 .707 r
F P
0 g
s
.24071 .72113 m .23328 .73718 L .2058 .73169 L p .707 .577 .707 r
F P
0 g
s
.32345 .76256 m .31602 .77861 L .29122 .76184 L p .707 .577 .707 r
F P
0 g
s
.29122 .76184 m .29866 .74579 L .32345 .76256 L p .707 .577 .707 r
F P
0 g
s
.68431 .65095 m .68037 .59509 L .65939 .59066 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .43363 .24378 L .47507 .24073 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .3725 .74882 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.41843 .52224 m .40643 .74195 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .44786 .73891 L .40643 .74195 L p .707 .577 .707 r
F P
0 g
s
.40165 .65532 m .39549 .69116 L .42126 .69437 L p .707 .577 .707 r
F P
0 g
s
.42126 .69437 m .42692 .69507 L p .42112 .68594 L .707 .577 .707 r
F P
0 g
s
.42112 .68594 m .40165 .65532 L .42126 .69437 L .707 .577 .707 r
F
.43363 .24378 m .41843 .52224 L p .41622 .38766 L F P
0 g
s
.7761 .68679 m .76993 .72263 L .799 .72297 L p .707 .577 .707 r
F P
0 g
s
.799 .72297 m .80516 .68714 L .7761 .68679 L p .707 .577 .707 r
F P
0 g
s
.70776 .71161 m .71392 .67578 L .68691 .66618 L p .707 .577 .707 r
F P
0 g
s
.71392 .67578 m .70776 .71161 L .7385 .71871 L p .707 .577 .707 r
F P
0 g
s
.23328 .73718 m .24071 .72113 L .27014 .73151 L p .707 .577 .707 r
F P
0 g
s
.82395 .58243 m .82788 .63829 L .84424 .63057 L p .707 .577 .707 r
F P
0 g
s
.84424 .63057 m .8403 .57471 L .82395 .58243 L p .707 .577 .707 r
F P
0 g
s
.29866 .74579 m .29122 .76184 L .26271 .74756 L p .707 .577 .707 r
F P
0 g
s
.26271 .74756 m .27014 .73151 L .29866 .74579 L p .707 .577 .707 r
F P
0 g
s
.27014 .73151 m .26271 .74756 L .23328 .73718 L p .707 .577 .707 r
F P
0 g
s
.65939 .59066 m .66332 .64652 L .68431 .65095 L p .707 .577 .707 r
F P
0 g
s
.5639 .2469 m .53669 .74507 L .49275 .73998 L p .707 .577 .707 r
F P
0 g
s
.49275 .73998 m .51995 .24181 L .5639 .2469 L p .707 .577 .707 r
F P
0 g
s
.80516 .68714 m .799 .72297 L .82285 .71971 L p .707 .577 .707 r
F P
0 g
s
.82285 .71971 m .82902 .68388 L .80516 .68714 L p .707 .577 .707 r
F P
0 g
s
.68691 .66618 m .68074 .70202 L .70776 .71161 L p .707 .577 .707 r
F P
0 g
s
.68074 .70202 m .68691 .66618 L .66625 .65504 L p .707 .577 .707 r
F P
0 g
s
.4276 .5641 m .43153 .61995 L .4448 .6177 L p .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .51995 .24181 L p .46528 .61883 L .707 .577 .707 r
F P
0 g
s
.45799 .66906 m .45929 .63649 L .46528 .61883 L .707 .577 .707 r
F
.45929 .63649 m .47507 .24073 L .46528 .61883 L F
.44786 .73891 m .45234 .657 L p .45799 .66906 L F P
0 g
s
.45234 .657 m .45279 .64879 L p .45379 .65271 L .707 .577 .707 r
F P
0 g
s
.45234 .657 m .45379 .65271 L .45799 .66906 L .707 .577 .707 r
F
.43309 .65923 m .42692 .69507 L .43938 .69522 L p F P
0 g
s
.51995 .24181 m .49275 .73998 L .44786 .73891 L p .707 .577 .707 r
F P
0 g
s
.43938 .69522 m .45599 .69542 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.44513 .67826 m .43309 .65923 L .43938 .69522 L .707 .577 .707 r
F
.45279 .64879 m .47507 .24073 L p .45799 .66906 L F P
0 g
s
.45599 .69542 m .46215 .65958 L .45151 .65945 L p .707 .577 .707 r
F P
0 g
s
.45151 .65945 m .43309 .65923 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.45599 .69542 m .45151 .65945 L .44513 .67826 L .707 .577 .707 r
F
.4448 .6177 m .46086 .61497 L p .43325 .57275 L F P
0 g
s
.43325 .57275 m .4276 .5641 L .4448 .6177 L .707 .577 .707 r
F
.72406 .76916 m .73149 .75311 L .70298 .73883 L p F P
0 g
s
.73149 .75311 m .72406 .76916 L .75349 .77954 L p .707 .577 .707 r
F P
0 g
s
.75349 .77954 m .76092 .7635 L .73149 .75311 L p .707 .577 .707 r
F P
0 g
s
.66332 .64652 m .65939 .59066 L .64685 .58438 L p .707 .577 .707 r
F P
0 g
s
.69554 .75488 m .70298 .73883 L .67818 .72206 L p .707 .577 .707 r
F P
0 g
s
.70298 .73883 m .69554 .75488 L .72406 .76916 L p .707 .577 .707 r
F P
0 g
s
.66625 .65504 m .66009 .69087 L .68074 .70202 L p .707 .577 .707 r
F P
0 g
s
.76092 .7635 m .75349 .77954 L .78097 .78503 L p .707 .577 .707 r
F P
0 g
s
.78097 .78503 m .7884 .76898 L .76092 .7635 L p .707 .577 .707 r
F P
0 g
s
.67818 .72206 m .67075 .73811 L .69554 .75488 L p .707 .577 .707 r
F P
0 g
s
.67075 .73811 m .67818 .72206 L .65952 .70445 L p .707 .577 .707 r
F P
0 g
s
.82902 .68388 m .82285 .71971 L .83915 .71317 L p .707 .577 .707 r
F P
0 g
s
.83915 .71317 m .84531 .67733 L .82902 .68388 L p .707 .577 .707 r
F P
0 g
s
.8403 .57471 m .84424 .63057 L .85134 .62256 L p .707 .577 .707 r
F P
0 g
s
.85134 .62256 m .8474 .5667 L .8403 .57471 L p .707 .577 .707 r
F P
0 g
s
.64685 .58438 m .65079 .64024 L .65547 .64259 L p .707 .577 .707 r
F P
0 g
s
.65079 .64024 m .64685 .58438 L .64399 .57687 L p .707 .577 .707 r
F P
0 g
s
.64399 .57687 m .64793 .63273 L .64896 .63544 L p .707 .577 .707 r
F P
0 g
s
.64896 .63544 m .65079 .64024 L p .64903 .62387 L .707 .577 .707 r
F P
0 g
s
.64903 .62387 m .64399 .57687 L .64896 .63544 L .707 .577 .707 r
F
.65397 .64343 m .65128 .6325 L p .64871 .66709 L F P
0 g
s
.65894 .63 m .64685 .58438 L .65547 .64259 L .707 .577 .707 r
F
.65128 .6325 m .64511 .66833 L .64781 .67927 L p F P
0 g
s
.65128 .6325 m .65843 .62331 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64511 .66833 m .64889 .64639 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64889 .64639 m .65128 .6325 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64781 .67927 m .65187 .65564 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65187 .65564 m .65397 .64343 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65547 .64259 m .66332 .64652 L p .65894 .63 L .707 .577 .707 r
F P
0 g
s
.66009 .69087 m .66625 .65504 L .65397 .64343 L p .707 .577 .707 r
F P
0 g
s
.65952 .70445 m .65209 .72049 L .67075 .73811 L p .707 .577 .707 r
F P
0 g
s
.7884 .76898 m .78097 .78503 L .8038 .78506 L p .707 .577 .707 r
F P
0 g
s
.8038 .78506 m .81123 .76902 L .7884 .76898 L p .707 .577 .707 r
F P
0 g
s
.65397 .64343 m .64781 .67927 L .66009 .69087 L p .707 .577 .707 r
F P
0 g
s
.65209 .72049 m .65952 .70445 L .64884 .6877 L p .707 .577 .707 r
F P
0 g
s
.64884 .6877 m .6414 .70375 L .65209 .72049 L p .707 .577 .707 r
F P
0 g
s
.84531 .67733 m .83915 .71317 L .84631 .70398 L p .707 .577 .707 r
F P
0 g
s
.84631 .70398 m .85247 .66814 L .84531 .67733 L p .707 .577 .707 r
F P
0 g
s
.8474 .5667 m .85134 .62256 L .84848 .61505 L p .707 .577 .707 r
F P
0 g
s
.84848 .61505 m .84454 .55919 L .8474 .5667 L p .707 .577 .707 r
F P
0 g
s
.81123 .76902 m .8038 .78506 L .81975 .77966 L p .707 .577 .707 r
F P
0 g
s
.81975 .77966 m .82718 .76361 L .81123 .76902 L p .707 .577 .707 r
F P
0 g
s
.6414 .70375 m .64884 .6877 L .64716 .67347 L p .707 .577 .707 r
F P
0 g
s
.64793 .63273 m .64399 .57687 L .65109 .56886 L p .707 .577 .707 r
F P
0 g
s
.64716 .67347 m .63973 .68952 L .6414 .70375 L p .707 .577 .707 r
F P
0 g
s
.85247 .66814 m .84631 .70398 L .84361 .69305 L p .707 .577 .707 r
F P
0 g
s
.84361 .69305 m .84977 .65721 L .85247 .66814 L p .707 .577 .707 r
F P
0 g
s
.82718 .76361 m .81975 .77966 L .82725 .76933 L p .707 .577 .707 r
F P
0 g
s
.82725 .76933 m .83468 .75328 L .82718 .76361 L p .707 .577 .707 r
F P
0 g
s
.65109 .56886 m .65502 .62472 L .64793 .63273 L p .707 .577 .707 r
F P
0 g
s
.84454 .55919 m .84848 .61505 L .83594 .60877 L p .707 .577 .707 r
F P
0 g
s
.83594 .60877 m .83201 .55291 L .84454 .55919 L p .707 .577 .707 r
F P
0 g
s
.65843 .62331 m .65227 .65915 L .64511 .66833 L p .707 .577 .707 r
F P
0 g
s
.63973 .68952 m .64716 .67347 L .65467 .66315 L p .707 .577 .707 r
F P
0 g
s
.39977 .62275 m .39583 .5669 L .36474 .56724 L p .707 .577 .707 r
F P
0 g
s
.39583 .5669 m .39977 .62275 L .43153 .61995 L p .707 .577 .707 r
F P
0 g
s
.43153 .61995 m .4276 .5641 L .39583 .5669 L p .707 .577 .707 r
F P
0 g
s
.46086 .61497 m .45692 .55911 L .4276 .5641 L p .707 .577 .707 r
F P
0 g
s
.65502 .62472 m .65109 .56886 L .66744 .56114 L p .707 .577 .707 r
F P
0 g
s
.65467 .66315 m .64723 .67919 L .63973 .68952 L p .707 .577 .707 r
F P
0 g
s
.36867 .6231 m .36474 .56724 L .33736 .56509 L p .707 .577 .707 r
F P
0 g
s
.36474 .56724 m .36867 .6231 L .39977 .62275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84977 .65721 m .84361 .69305 L .83133 .68144 L p .707 .577 .707 r
F P
0 g
s
.83133 .68144 m .8375 .6456 L .84977 .65721 L p .707 .577 .707 r
F P
0 g
s
.83468 .75328 m .82725 .76933 L .82558 .7551 L p .707 .577 .707 r
F P
0 g
s
.82558 .7551 m .83301 .73905 L .83468 .75328 L p .707 .577 .707 r
F P
0 g
s
.45692 .55911 m .46086 .61497 L .48487 .60829 L p .707 .577 .707 r
F P
0 g
s
.48487 .60829 m .48094 .55243 L .45692 .55911 L p .707 .577 .707 r
F P
0 g
s
.65227 .65915 m .65843 .62331 L .67473 .61676 L p .707 .577 .707 r
F P
0 g
s
.83201 .55291 m .83594 .60877 L .81496 .60434 L p .707 .577 .707 r
F P
0 g
s
.81496 .60434 m .81102 .54848 L .83201 .55291 L p .707 .577 .707 r
F P
0 g
s
.66744 .56114 m .67138 .61699 L .65502 .62472 L p .707 .577 .707 r
F P
0 g
s
.33736 .56509 m .3413 .62095 L .36867 .6231 L p .707 .577 .707 r
F P
0 g
s
.39549 .69116 m .40165 .65532 L .37091 .64822 L p .707 .577 .707 r
F P
0 g
s
.42692 .69507 m .43309 .65923 L .40165 .65532 L p .707 .577 .707 r
F P
0 g
s
.3413 .62095 m .33736 .56509 L .31638 .56066 L p .707 .577 .707 r
F P
0 g
s
.36475 .68406 m .37091 .64822 L .3439 .63863 L p .707 .577 .707 r
F P
0 g
s
.37091 .64822 m .36475 .68406 L .39549 .69116 L p .707 .577 .707 r
F P
0 g
s
.67473 .61676 m .66857 .6526 L .65227 .65915 L p .707 .577 .707 r
F P
0 g
s
.64723 .67919 m .65467 .66315 L .67062 .65774 L p .707 .577 .707 r
F P
0 g
s
.67138 .61699 m .66744 .56114 L .69146 .55446 L p .707 .577 .707 r
F P
0 g
s
.48094 .55243 m .48487 .60829 L .50123 .60057 L p .707 .577 .707 r
F P
0 g
s
.50123 .60057 m .4973 .54471 L .48094 .55243 L p .707 .577 .707 r
F P
0 g
s
.67062 .65774 m .66318 .67379 L .64723 .67919 L p .707 .577 .707 r
F P
0 g
s
.31638 .56066 m .32031 .61652 L .3413 .62095 L p .707 .577 .707 r
F P
0 g
s
.8375 .6456 m .83133 .68144 L .81067 .6703 L p .707 .577 .707 r
F P
0 g
s
.81067 .6703 m .81684 .63446 L .8375 .6456 L p .707 .577 .707 r
F P
0 g
s
.81102 .54848 m .81496 .60434 L .78758 .60219 L p .707 .577 .707 r
F P
0 g
s
.78758 .60219 m .78364 .54633 L .81102 .54848 L p .707 .577 .707 r
F P
0 g
s
.46215 .65958 m .45599 .69542 L .47984 .69216 L p .707 .577 .707 r
F P
0 g
s
.47984 .69216 m .48601 .65632 L .46215 .65958 L p .707 .577 .707 r
F P
0 g
s
.3439 .63863 m .33773 .67446 L .36475 .68406 L p .707 .577 .707 r
F P
0 g
s
.33773 .67446 m .3439 .63863 L .32324 .62748 L p .707 .577 .707 r
F P
0 g
s
.66857 .6526 m .67473 .61676 L .69858 .61351 L p .707 .577 .707 r
F P
0 g
s
.83301 .73905 m .82558 .7551 L .81489 .73836 L p .707 .577 .707 r
F P
0 g
s
.81489 .73836 m .82232 .72231 L .83301 .73905 L p .707 .577 .707 r
F P
0 g
s
.69146 .55446 m .69539 .61031 L .67138 .61699 L p .707 .577 .707 r
F P
0 g
s
.38105 .73499 m .38848 .71894 L .35997 .70466 L p .707 .577 .707 r
F P
0 g
s
.38848 .71894 m .38105 .73499 L .41048 .74537 L p .707 .577 .707 r
F P
0 g
s
.41048 .74537 m .41791 .72933 L .38848 .71894 L p .707 .577 .707 r
F P
0 g
s
.32031 .61652 m .31638 .56066 L .30384 .55438 L p .707 .577 .707 r
F P
0 g
s
.35253 .72071 m .35997 .70466 L .33517 .68789 L p .707 .577 .707 r
F P
0 g
s
.35997 .70466 m .35253 .72071 L .38105 .73499 L p .707 .577 .707 r
F P
0 g
s
.69539 .61031 m .69146 .55446 L .72078 .54947 L p .707 .577 .707 r
F P
0 g
s
.41791 .72933 m .41048 .74537 L .43796 .75086 L p .707 .577 .707 r
F P
0 g
s
.43796 .75086 m .44539 .73481 L .41791 .72933 L p .707 .577 .707 r
F P
0 g
s
.32324 .62748 m .31708 .66332 L .33773 .67446 L p .707 .577 .707 r
F P
0 g
s
.69858 .61351 m .69242 .64934 L .66857 .6526 L p .707 .577 .707 r
F P
0 g
s
.66318 .67379 m .67062 .65774 L .69345 .65778 L p .707 .577 .707 r
F P
0 g
s
.33517 .68789 m .32774 .70394 L .35253 .72071 L p .707 .577 .707 r
F P
0 g
s
.78364 .54633 m .78758 .60219 L .75648 .60253 L p .707 .577 .707 r
F P
0 g
s
.75648 .60253 m .75255 .54667 L .78364 .54633 L p .707 .577 .707 r
F P
0 g
s
.32774 .70394 m .33517 .68789 L .31651 .67028 L p .707 .577 .707 r
F P
0 g
s
.4973 .54471 m .50123 .60057 L .50833 .59256 L p .707 .577 .707 r
F P
0 g
s
.50833 .59256 m .50439 .5367 L .4973 .54471 L p .707 .577 .707 r
F P
0 g
s
.48601 .65632 m .47984 .69216 L .49614 .68561 L p .707 .577 .707 r
F P
0 g
s
.49614 .68561 m .5023 .64978 L .48601 .65632 L p .707 .577 .707 r
F P
0 g
s
.72472 .60533 m .72078 .54947 L .75255 .54667 L p .707 .577 .707 r
F P
0 g
s
.72078 .54947 m .72472 .60533 L .69539 .61031 L p .707 .577 .707 r
F P
0 g
s
.81684 .63446 m .81067 .6703 L .78366 .6607 L p .707 .577 .707 r
F P
0 g
s
.78366 .6607 m .78982 .62487 L .81684 .63446 L p .707 .577 .707 r
F P
0 g
s
.30384 .55438 m .30777 .61024 L .32031 .61652 L p .707 .577 .707 r
F P
0 g
s
.69345 .65778 m .68601 .67383 L .66318 .67379 L p .707 .577 .707 r
F P
0 g
s
.69242 .64934 m .69858 .61351 L .72765 .61385 L p .707 .577 .707 r
F P
0 g
s
.31708 .66332 m .32324 .62748 L .31096 .61587 L p .707 .577 .707 r
F P
0 g
s
.75255 .54667 m .75648 .60253 L .72472 .60533 L p .707 .577 .707 r
F P
0 g
s
.31651 .67028 m .30908 .68632 L .32774 .70394 L p .707 .577 .707 r
F P
0 g
s
.82232 .72231 m .81489 .73836 L .79623 .72074 L p .707 .577 .707 r
F P
0 g
s
.79623 .72074 m .80367 .70469 L .82232 .72231 L p .707 .577 .707 r
F P
0 g
s
.44539 .73481 m .43796 .75086 L .46079 .75089 L p .707 .577 .707 r
F P
0 g
s
.46079 .75089 m .46822 .73485 L .44539 .73481 L p .707 .577 .707 r
F P
0 g
s
.78982 .62487 m .78366 .6607 L .75292 .6536 L p .707 .577 .707 r
F P
0 g
s
.75292 .6536 m .75909 .61776 L .78982 .62487 L p .707 .577 .707 r
F P
0 g
s
.72765 .61385 m .72148 .64969 L .69242 .64934 L p .707 .577 .707 r
F P
0 g
s
.31096 .61587 m .3048 .65171 L .31708 .66332 L p .707 .577 .707 r
F P
0 g
s
.30777 .61024 m .30384 .55438 L .30098 .54687 L p .707 .577 .707 r
F P
0 g
s
.72148 .64969 m .72765 .61385 L .75909 .61776 L p .707 .577 .707 r
F P
0 g
s
.68601 .67383 m .69345 .65778 L .72092 .66326 L p .707 .577 .707 r
F P
0 g
s
.30908 .68632 m .31651 .67028 L .30583 .65353 L p .707 .577 .707 r
F P
0 g
s
.75909 .61776 m .75292 .6536 L .72148 .64969 L p .707 .577 .707 r
F P
0 g
s
.72092 .66326 m .71349 .67931 L .68601 .67383 L p .707 .577 .707 r
F P
0 g
s
.30583 .65353 m .29839 .66958 L .30908 .68632 L p .707 .577 .707 r
F P
0 g
s
.80367 .70469 m .79623 .72074 L .77144 .70397 L p .707 .577 .707 r
F P
0 g
s
.77144 .70397 m .77887 .68792 L .80367 .70469 L p .707 .577 .707 r
F P
0 g
s
.5023 .64978 m .49614 .68561 L .5033 .67643 L p .707 .577 .707 r
F P
0 g
s
.5033 .67643 m .50946 .64059 L .5023 .64978 L p .707 .577 .707 r
F P
0 g
s
.46822 .73485 m .46079 .75089 L .47674 .74549 L p .707 .577 .707 r
F P
0 g
s
.47674 .74549 m .48417 .72944 L .46822 .73485 L p .707 .577 .707 r
F P
0 g
s
.30608 .60578 m .30777 .61024 L p .30615 .59504 L .707 .577 .707 r
F P
0 g
s
.3048 .65171 m .31096 .61587 L .30827 .60494 L p .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .3021 .64078 L .30246 .64224 L p .707 .577 .707 r
F P
0 g
s
.30246 .64224 m .3048 .65171 L p .30628 .63167 L .707 .577 .707 r
F P
0 g
s
.30628 .63167 m .30827 .60494 L .30246 .64224 L .707 .577 .707 r
F
.29839 .66958 m .30583 .65353 L .30415 .6393 L p F P
0 g
s
.30415 .6393 m .29672 .65535 L .29839 .66958 L p .707 .577 .707 r
F P
0 g
s
.30415 .6393 m .31166 .62898 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.29672 .65535 m .3013 .64547 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.3013 .64547 m .30415 .6393 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .31542 .59575 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.3021 .64078 m .306 .61812 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.306 .61812 m .30827 .60494 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.30098 .54687 m .30491 .60273 L .30608 .60578 L p .707 .577 .707 r
F P
0 g
s
.30615 .59504 m .30098 .54687 L .30608 .60578 L .707 .577 .707 r
F
.50439 .5367 m .50833 .59256 L .50547 .58504 L p F P
0 g
s
.50547 .58504 m .50153 .52919 L .50439 .5367 L p .707 .577 .707 r
F P
0 g
s
.71349 .67931 m .72092 .66326 L .75036 .67365 L p .707 .577 .707 r
F P
0 g
s
.77887 .68792 m .77144 .70397 L .74293 .68969 L p .707 .577 .707 r
F P
0 g
s
.74293 .68969 m .75036 .67365 L .77887 .68792 L p .707 .577 .707 r
F P
0 g
s
.75036 .67365 m .74293 .68969 L .71349 .67931 L p .707 .577 .707 r
F P
0 g
s
.30491 .60273 m .30098 .54687 L .30808 .53886 L p .707 .577 .707 r
F P
0 g
s
.48417 .72944 m .47674 .74549 L .48424 .73516 L p .707 .577 .707 r
F P
0 g
s
.48424 .73516 m .49167 .71911 L .48417 .72944 L p .707 .577 .707 r
F P
0 g
s
.50946 .64059 m .5033 .67643 L .5006 .66549 L p .707 .577 .707 r
F P
0 g
s
.5006 .66549 m .50676 .62965 L .50946 .64059 L p .707 .577 .707 r
F P
0 g
s
.30808 .53886 m .31201 .59472 L .30491 .60273 L p .707 .577 .707 r
F P
0 g
s
.50153 .52919 m .50547 .58504 L .49293 .57877 L p .707 .577 .707 r
F P
0 g
s
.49293 .57877 m .48899 .52291 L .50153 .52919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31542 .59575 m .30926 .63159 L .3021 .64078 L p .707 .577 .707 r
F P
0 g
s
.31201 .59472 m .30808 .53886 L .32443 .53114 L p .707 .577 .707 r
F P
0 g
s
.33172 .58921 m .33108 .59293 L p .30926 .63159 L .707 .577 .707 r
F P
0 g
s
.30422 .64502 m .31166 .62898 L .32761 .62357 L p .707 .577 .707 r
F P
0 g
s
.33108 .59293 m .32556 .62505 L .3111 .63085 L p .707 .577 .707 r
F P
0 g
s
.31166 .62898 m .30855 .63568 L p .29672 .65535 L .707 .577 .707 r
F P
0 g
s
.3111 .63085 m .30926 .63159 L p .33108 .59293 L .707 .577 .707 r
F P
0 g
s
.30855 .63568 m .30422 .64502 L .30206 .648 L p .707 .577 .707 r
F P
0 g
s
.30206 .648 m .29672 .65535 L p .30855 .63568 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49167 .71911 m .48424 .73516 L .48257 .72093 L p .707 .577 .707 r
F P
0 g
s
.48257 .72093 m .49 .70488 L .49167 .71911 L p .707 .577 .707 r
F P
0 g
s
.50676 .62965 m .5006 .66549 L .48832 .65389 L p .707 .577 .707 r
F P
0 g
s
.48832 .65389 m .49449 .61805 L .50676 .62965 L p .707 .577 .707 r
F P
0 g
s
.30926 .63159 m .31542 .59575 L .33172 .58921 L p .707 .577 .707 r
F P
0 g
s
.48899 .52291 m .49293 .57877 L .47195 .57433 L p .707 .577 .707 r
F P
0 g
s
.47195 .57433 m .46801 .51848 L .48899 .52291 L p .707 .577 .707 r
F P
0 g
s
.32443 .53114 m .32837 .58699 L .31201 .59472 L p .707 .577 .707 r
F P
0 g
s
.32837 .58699 m .32443 .53114 L .34845 .52446 L p .707 .577 .707 r
F P
0 g
s
.35557 .58595 m .35463 .59141 L p .32556 .62505 L .707 .577 .707 r
F P
0 g
s
.32017 .63962 m .32761 .62357 L .35044 .62361 L p .707 .577 .707 r
F P
0 g
s
.35463 .59141 m .34941 .62179 L .32874 .62461 L p .707 .577 .707 r
F P
0 g
s
.32761 .62357 m .32475 .62974 L p .30422 .64502 L .707 .577 .707 r
F P
0 g
s
.32874 .62461 m .32556 .62505 L p .35463 .59141 L .707 .577 .707 r
F P
0 g
s
.32475 .62974 m .32017 .63962 L .31592 .64106 L p .707 .577 .707 r
F P
0 g
s
.31592 .64106 m .30422 .64502 L p .32475 .62974 L .707 .577 .707 r
F P
0 g
s
.46801 .51848 m .47195 .57433 L .44457 .57219 L p .707 .577 .707 r
F P
0 g
s
.44457 .57219 m .44063 .51633 L .46801 .51848 L p .707 .577 .707 r
F P
0 g
s
.49449 .61805 m .48832 .65389 L .46766 .64274 L p .707 .577 .707 r
F P
0 g
s
.46766 .64274 m .47383 .6069 L .49449 .61805 L p .707 .577 .707 r
F P
0 g
s
.49 .70488 m .48257 .72093 L .47188 .70419 L p .707 .577 .707 r
F P
0 g
s
.47188 .70419 m .47931 .68814 L .49 .70488 L p .707 .577 .707 r
F P
0 g
s
.32556 .62505 m .33172 .58921 L .35557 .58595 L p .707 .577 .707 r
F P
0 g
s
.34845 .52446 m .35238 .58031 L .32837 .58699 L p .707 .577 .707 r
F P
0 g
s
.35238 .58031 m .34845 .52446 L .37777 .51947 L p .707 .577 .707 r
F P
0 g
s
.44063 .51633 m .44457 .57219 L .41347 .57253 L p .707 .577 .707 r
F P
0 g
s
.41347 .57253 m .40954 .51667 L .44063 .51633 L p .707 .577 .707 r
F P
0 g
s
.38171 .57533 m .37777 .51947 L .40954 .51667 L p .707 .577 .707 r
F P
0 g
s
.37777 .51947 m .38171 .57533 L .35238 .58031 L p .707 .577 .707 r
F P
0 g
s
.35044 .62361 m .343 .63966 L .32017 .63962 L p .707 .577 .707 r
F P
0 g
s
.47383 .6069 m .46766 .64274 L .44065 .63315 L p .707 .577 .707 r
F P
0 g
s
.44065 .63315 m .44681 .59731 L .47383 .6069 L p .707 .577 .707 r
F P
0 g
s
.40954 .51667 m .41347 .57253 L .38171 .57533 L p .707 .577 .707 r
F P
0 g
s
.34941 .62179 m .35557 .58595 L .38464 .58629 L p .707 .577 .707 r
F P
0 g
s
.47931 .68814 m .47188 .70419 L .45322 .68657 L p .707 .577 .707 r
F P
0 g
s
.45322 .68657 m .46066 .67052 L .47931 .68814 L p .707 .577 .707 r
F P
0 g
s
.44681 .59731 m .44065 .63315 L .40991 .62605 L p .707 .577 .707 r
F P
0 g
s
.40991 .62605 m .41607 .59021 L .44681 .59731 L p .707 .577 .707 r
F P
0 g
s
.38464 .58629 m .37847 .62213 L .34941 .62179 L p .707 .577 .707 r
F P
0 g
s
.343 .63966 m .35044 .62361 L .37791 .62909 L p .707 .577 .707 r
F P
0 g
s
.37847 .62213 m .38464 .58629 L .41607 .59021 L p .707 .577 .707 r
F P
0 g
s
.41607 .59021 m .40991 .62605 L .37847 .62213 L p .707 .577 .707 r
F P
0 g
s
.37791 .62909 m .37048 .64514 L .343 .63966 L p .707 .577 .707 r
F P
0 g
s
.46066 .67052 m .45322 .68657 L .42843 .6698 L p .707 .577 .707 r
F P
0 g
s
.42843 .6698 m .43586 .65375 L .46066 .67052 L p .707 .577 .707 r
F P
0 g
s
.37048 .64514 m .37791 .62909 L .40735 .63948 L p .707 .577 .707 r
F P
0 g
s
.43586 .65375 m .42843 .6698 L .39991 .65552 L p .707 .577 .707 r
F P
0 g
s
.39991 .65552 m .40735 .63948 L .43586 .65375 L p .707 .577 .707 r
F P
0 g
s
.40735 .63948 m .39991 .65552 L .37048 .64514 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0081oo`00M7oo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00NWoo001aOol30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001dOol006moo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0071oo`00KGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06ioo`00Jgoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006]oo`00JWoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JGoo
001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001XOol006Qoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUH00000IWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Eoo`00
J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH0
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001S
Ool006Qoo`03001JEP0000EJEP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo
00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03001JEUYF
00AJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF01400003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH0009JEPH000AJEP03001JEUYF00IJEP04001JEUYFFUH70007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000<00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00HWoo10001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001NOol400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Uoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00
EWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000KOolG000eOol005Eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8001=oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080039o
o`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P003Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009Ool400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000^
Ool005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<005YFFUH0
0P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPH000QJEP03001JEUYF00IJEPL000=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP80009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
05Ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD0009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00
FUH00004FUH01000FUIJEUYF1`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP@000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00FUH00004FUH400000eYF
0000000>0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000UYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000[Ool005Ioo`03
001JEP0000@00003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000:goo001FOol00`00
FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
00000eYF001JEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2000017oo001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000
00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
1Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo00@005YF000000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00Ool00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00eYF5P0015YF
00D005YFFUIJEP0002]oo`00Egoo0P0015YF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH0
0`00Oomoo`0YOol004=ooaH000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP03FUH60008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000020002FUH00`00Oomoo`0YOol003mo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`800003FUH005YF
009JEP03001JEP00018000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000[Ool0
03]oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001J
EP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00IJEP03001JEUYF
00EJEP07001JEUYFFUH005YF0000:goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH01@00FUIJEUYF000015YF3@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000goo00@005YF
001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000:goo000dOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP02FUHF0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00
FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00<Woo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`001EYF00<005YFFUH00UYF1P00
0UYF20001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`@000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP04001JEUYFFUH2000/Ool0031o
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000D00004FUH00000FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP02FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00D005YFFUIJ
EP0002eoo`00;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP000000
1EYF10001EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00@005YF000002ioo`00;Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
0eYF20001eYF00<005YFFUH01EYF10002EYF100000=JEP00FUH01EYF00<005YFFUH00UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH200000eYF000000020005FUH00`00FUH000030002FUH00`00FUIJEP07FUH3000:FUH0
0`00FUIJEP020006FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF10000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP04FUH01000
FUIJEUYF1P001eYF00@005YFFUIJEP8000QJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP80
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8002ioo`00;Woo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH015YF1@001EYF00<005YFFUH0
0eYF0P001UYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00MJEP8000AJEP03001JEUYF00IJEP80
00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP00
00=JEQ/000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0002aoo`00;Woo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP8000UJEP<000UJEPD000=JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP<00006FUH00000001J
EP001EYF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJ
EP04001JEUYFFUH90003FUH01000FUH005YF0P002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000UYF00@005YF0000009JEPd0019oo`@000MJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH<0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80009JEP800003FUH00000008000IJEP03001JEUYF009JEPD0019oo`8000AJEP03
001JEUYF00AJEP05001JEUYFFUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUH00003FUH00`00FUH000020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH200000eYF001JEP04FUH01000FUIJEUYF0`00
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P004Goo0`0000=JEP00FUH01EYF00H005YFFUH005YF000Z
Ool002moo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03
001JEP0000AJEP04001JEP00FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0008FUH00`00FUIJEP04FUH01000FUIJEUYF0`002EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF0`00
4Goo0P001UYF00H005YFFUH005YF000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPD000QJ
EP03001JEUYF00IJEP04001JEUYF0003FUH30003FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH20005FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00009JEP80009JEPT000MJEP03001JEUYF00IJEP80015oo`8000=JEP07
001JEUYFFUH005YF0000:Woo000_Ool00`00FUH00004FUH00`00FUH0000A0008FUH01000FUIJEP00
0UYF00@005YFFUH000IJEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000AJEP04
001JEUYF0004FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP@00003FUH005YF00AJEP03001JEP0000<0009JEP03001JEUYF00QJ
EP<0015oo`800003FUH005YF009JEP03001JEP0002Yoo`00;goo00<005YF00000eYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH010001EYF00L005YFFUIJEP00FUH00003FUH20003FUH00`00FUIJEP02
00000eYF001JEP06FUH30008FUH01000FUIJEP000eYF00@005YFFUIJEP80009JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF0`000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF100025YF00@005YFFUIJEP80015oo`8000=JEP8002]oo`00;goo
00@005YF001JEP<00003FUH005YF00AJEP8000MJEP03001JEUYF00AJEPH000=JEP8000IJEP04001J
EUYF0002FUH00`00FUH000030004FUH50007FUH01000FUIJEUYF0`001UYF0P000eYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00H005YF000005YF0006FUH00`00
FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP03FUH2000<Ool60002FUH2000[Ool002moo`03
001JEP00008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEP00009JEP03001JEUYF00=JEPT000IJEP03001JEUYF00AJEP03001J
EUYF00EJEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000IJEP00001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP07
FUH<0003FUH01`00FUH005YF001JEP0002]oo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJ
EPH000EJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH20009FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001o
o`0ZOol002moo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH20004FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF009JEP<0009JEPl000AJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP@00003FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01@00
FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000:goo000`Ool20004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YF
FUH00UYF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00@005YFFUIJEP80009JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400001UYF
001JEUYF001JEP@00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF00<005YFFUH00UYF0P00;7oo000`Ool20004FUH00`00FUIJEP03FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH20004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YF00000eYF0`001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF0`001EYF00<005YFFUH00UYF0P00;7oo
000`Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH01@00FUIJEUYF000025YF0P002UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF0P001UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF00<005YFFUH00eYF
00L005YFFUIJEP00FUH0000/Ool002moo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP06001JEP00001JEP0025YF0P002UYF
00<005YFFUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<0009JEP06001JEUYF001JEP001eYF100000=JEP00FUH01eYF00<005YFFUH01UYF0`001EYF
00<005YF000015YF00@005YFFUIJEP8002eoo`00;goo00<005YF00000eYF00<005YFFUH00UYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000=JEP04001JEUYF
FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH60002FUH01000FUIJEP001UYF00@005YFFUIJEP<000IJEP03
001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH01000FUIJEUYF0P00;Woo000_Ool2
0004FUHD0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH20006FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUH00002000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH30004FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPD0009JEP<000IJ
EP03001JEUYF00=JEP<000AJEP04001JEP00FUH2000`Ool002moo`80009JEP@000EJEP03001JEP00
00<000Moo`L000IJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH01000FUIJEUYF0P001Goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF0`00<Woo000_Ool015YF000000000UYF00<005YFFUH0
0eYF00<005YFFUH015YF10000Woo0`001Goo10000UYF00<005YFFUH01EYF00@005YFFUH000=JEP80
00MJEP06001JEP00001JEP002eYF00<005YFFUH01eYF00@005YF000000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000EJEP8000EJEP05001JEUYFFUH00003FUH00`00Oomoo`05
Ool500000goo0000000<0005FUH00`00Oomoo`0aOol002ioo`<000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00H000Qoo`@000EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF
009JEP<000YJEP03001JEUYF00MJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000AJEP04001JEUYF0003FUH01`00FUH00000FUH005YF008000Qoo`D000mo
o`07001JEUYFFUH005YF0000<Woo000^Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH4000<Ool400000eYF001JEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP06FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20004FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000]oo`<0015oo`06001JEUYF
001JEP00<Woo000^Ool200000eYF0000000;0004FUH00`00FUIJEP06FUH2000?Ool20005FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP02FUH@0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20005FUH2000POol20003FUH00`00
Oomoo`0_Ool002ioo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH60007FUH01000FUH000003goo
0P000eYF00<005YFFUH00eYF00<005YFFUH00P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP<001moo`05001JEUYFFUH0000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEPD000EJEP04001JEUYFFUH2000?Ool01000FUIJEP00
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02`001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P001UYF
0P007goo00D005YFFUIJEP00031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH0100000=JEP00FUH01EYF0P003Goo00@005YFFUH000EJEP03001JEUYF00D00003
FUH00000008000MJEP03001JEUYF00=JEP03001JEUYF008000YJEPP000UJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP8000AJEP04001JEP00000NOol00`00FUIJ
EP02000`Ool002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20008FUH2000;Ool01000FUIJEP001EYF0`0015YF00<005YFFUH00eYF10000UYF00<005YFFUH0
15YF0`0000=JEP00FUH02eYF00<005YFFUH00eYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000eYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEP8001eoo`04001JEP00
000`Ool002eoo`800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJEP03
001JEP0000/0009JEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH:0003FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH0
1UYF00<005YFFUH00`001UYF0P006goo0P000UYF00<007ooOol0;Goo000]Ool200001EYF001oogoo
00001EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEP04001JEUYFFUH20003FUH0
1@00FUIJEUYF00000UYF00<005YF00000P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P001UYF00<005YFFUH00eYF0P000Woo10001UYF00<0
05YFFUH00eYF00<005YFFUH01UYF0`006Goo00@005YFFUH002moo`00;Goo00D005YFFUIJEP00009o
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP80
0003FUH005YF009JEP03001JEUYF0080009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP80
00Ioo`@0009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00<001Ioo`03001JEP00031oo`00;Goo
00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP<00003FUH005YF00AJEP80
00Yoo`<000IJEP04001JEP000004FUH00`00FUIJEP03FUH3000COol00`00FUH0000`Ool002ioo`04
001JEUYFFUH20004Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH20003FUH20005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH30005FUH2000=Ool20003FUH01000FUIJEUYF0`0000=JEP00FUH025YF1@00
3Goo0`00<Goo000^Ool01000FUIJEP000UYF00<007ooOol017oo0P000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YF000015YF00@005YFFUH0009JEP8000iJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000=JEP8000mo
o`800003FUH005YF009JEP03001JEP0000<000QJEP03001JEUYF009JEPd00003FUH00000035oo`00
;goo00<005YF00000eYF0P001Woo0P0000=JEP00FUH01UYF0`0025YF00@005YFFUH000=JEP04001J
EUYFFUH3000>FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000AOol20003FUH20004Ool30005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000IJEP03001oogoo00Eoo`@0
00AJEPD000MJEP04001JEUYFFUH30006FUH00`00FUIJEP0<FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000<Ool60002
FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<goo000`Ool00`00
FUIJEP05FUH00`00Oomoo`08Ool90006FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF30000eYF00L005YF001JEP00FUH0000:Ool30006FUH0
0`00FUIJEP04FUH01000FUIJEP00=7oo000aOol00`00FUIJEP04FUH3000<Ool70004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0`0015YF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool037oo10000UYF00<005YFFUH00eYF00@005YF
000003Eoo`00<Woo00<005YFFUH00UYF00D005YFFUIJEP0000aoo`<000=oo`h000AJEP03001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00004Goo2P00=goo000cOol20002FUH00`00FUIJEP02FUH00`00Oomoo`0M
Ool20002FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF009JEP8005=oo`00=Goo0P001UYF0P007goo0P000eYF00<007oo
00002EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH30005FUH00`00FUIJEP02FUH2001COol0
03Ioo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF009JEP04001oo`000007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20002FUH20008FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005=oo`00=goo0P001UYF
0`007Woo00D005YFFUIJEP0000=oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<000IJEP8000AJEP04
001JEUYFFUH2001DOol003Uoo`03001JEUYF009JEP04001JEUYFFUH2000LOol00`00FUIJEP020005
Ool30002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEP0015YF00@005YFFUH0009JEP04001JEUYF
FUH2001EOol003Yoo`05001JEUYFFUH00005FUH2000KOol01000FUH0000027oo10002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP05001JEUYFFUH00003FUH01000FUH005YF0P00Egoo000kOol30008FUH3000HOol2
00000eYF001oo`0;Ool40005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUH000040004FUH00`00FUIJEP03FUH30005FUH3001IOol003eoo`03001JEUYF
00MJEP04001JEP00000GOol00`00FUH0000@Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH800000goo0000000;0006FUH00`00Oomoo`1HOol003ioo`8000IJ
EP03001JEUYF009JEP<001Aoo`8001Eoo`L000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@000=oo`D000ioo`03001JEUYF00=JEP8005Uoo`00@7oo0P0015YF00<005YFFUH01EYF0`00
4Goo0P0077oo3@001UYF00<005YFFUH015YF20001goo1@003goo00L005YFFUIJEP00FUH0001IOol0
049oo`800003FUH005YF00QJEP03001JEP0000<000]oo`<002Yoo`d000=JEP03001oogoo00Yoo`<0
015oo`04001JEUYF0002FUH00`00Oomoo`1FOol004Aoo`<000MJEP03001JEUYF00AJEP/00003FUH0
000003=oo`8000IJEP8001moo`8000=JEP03001oogoo05Ioo`00Agoo0P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUIJEP0003Eoo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF
009JEP03001oogoo05Eoo`00BGoo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP80
03Ioo`8000EJEP04001JEP00000NOol00`00FUIJEP02001GOol004aoo`D000AJEP03001JEUYF00AJ
EP03001JEP00008003Uoo`8000=JEP04001JEUYFFUH2000LOol00`00FUIJEP02001GOol0055oo`d0
03ioo`<000IJEP8001]oo`80009JEP03001oogoo05Aoo`00WWoo00<005YFFUH01UYF0`006Goo00@0
05YFFUH005Ioo`00Wgoo0P001UYF00<005YFFUH00`005Woo00<005YF0000Egoo002QOol20004FUH0
0`00FUIJEP03FUH3000COol00`00FUH0001GOol00:=oo`800003FUH005YF00QJEPD000eoo`<005Qo
o`00YGoo0`0025YF00<005YFFUH00UYF3@0000=JEP000000F7oo002XOol30005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000FGoo002[Ool300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00FGoo002^Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP02001JOol00;5o
o`@0009JEP03001JEUYF00=JEP04001JEP00001LOol00;Eoo`X005ioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60557 .74479 m .60164 .68894 L .57054 .68928 L p .707 .577 .707 r
F P
0 g
s
.60164 .68894 m .60557 .74479 L .63734 .74199 L p .707 .577 .707 r
F P
0 g
s
.63734 .74199 m .6334 .68614 L .60164 .68894 L p .707 .577 .707 r
F P
0 g
s
.6334 .68614 m .63734 .74199 L .66666 .73701 L p .707 .577 .707 r
F P
0 g
s
.66666 .73701 m .66273 .68115 L .6334 .68614 L p .707 .577 .707 r
F P
0 g
s
.57448 .74514 m .57054 .68928 L .54317 .68713 L p .707 .577 .707 r
F P
0 g
s
.57054 .68928 m .57448 .74514 L .60557 .74479 L p .707 .577 .707 r
F P
0 g
s
.66273 .68115 m .66666 .73701 L .69068 .73033 L p .707 .577 .707 r
F P
0 g
s
.69068 .73033 m .68674 .67447 L .66273 .68115 L p .707 .577 .707 r
F P
0 g
s
.54317 .68713 m .5471 .74299 L .57448 .74514 L p .707 .577 .707 r
F P
0 g
s
.60129 .81075 m .60745 .77491 L .57672 .76781 L p .707 .577 .707 r
F P
0 g
s
.60745 .77491 m .60129 .81075 L .63273 .81467 L p .707 .577 .707 r
F P
0 g
s
.63273 .81467 m .63889 .77883 L .60745 .77491 L p .707 .577 .707 r
F P
0 g
s
.5471 .74299 m .54317 .68713 L .52218 .6827 L p .707 .577 .707 r
F P
0 g
s
.63889 .77883 m .63273 .81467 L .6618 .81501 L p .707 .577 .707 r
F P
0 g
s
.6618 .81501 m .66796 .77917 L .63889 .77883 L p .707 .577 .707 r
F P
0 g
s
.57056 .80365 m .57672 .76781 L .5497 .75822 L p .707 .577 .707 r
F P
0 g
s
.57672 .76781 m .57056 .80365 L .60129 .81075 L p .707 .577 .707 r
F P
0 g
s
.68674 .67447 m .69068 .73033 L .70704 .7226 L p .707 .577 .707 r
F P
0 g
s
.70704 .7226 m .7031 .66675 L .68674 .67447 L p .707 .577 .707 r
F P
0 g
s
.52218 .6827 m .52612 .73855 L .5471 .74299 L p .707 .577 .707 r
F P
0 g
s
.66796 .77917 m .6618 .81501 L .68565 .81175 L p .707 .577 .707 r
F P
0 g
s
.68565 .81175 m .69181 .77591 L .66796 .77917 L p .707 .577 .707 r
F P
0 g
s
.5497 .75822 m .54354 .79406 L .57056 .80365 L p .707 .577 .707 r
F P
0 g
s
.54354 .79406 m .5497 .75822 L .52904 .74708 L p .707 .577 .707 r
F P
0 g
s
.58685 .86119 m .59428 .84515 L .56577 .83087 L p .707 .577 .707 r
F P
0 g
s
.59428 .84515 m .58685 .86119 L .61629 .87158 L p .707 .577 .707 r
F P
0 g
s
.61629 .87158 m .62372 .85553 L .59428 .84515 L p .707 .577 .707 r
F P
0 g
s
.52612 .73855 m .52218 .6827 L .50965 .67642 L p .707 .577 .707 r
F P
0 g
s
.55834 .84692 m .56577 .83087 L .54098 .8141 L p .707 .577 .707 r
F P
0 g
s
.56577 .83087 m .55834 .84692 L .58685 .86119 L p .707 .577 .707 r
F P
0 g
s
.52904 .74708 m .52288 .78291 L .54354 .79406 L p .707 .577 .707 r
F P
0 g
s
.62372 .85553 m .61629 .87158 L .64376 .87706 L p .707 .577 .707 r
F P
0 g
s
.64376 .87706 m .6512 .86101 L .62372 .85553 L p .707 .577 .707 r
F P
0 g
s
.54098 .8141 m .53354 .83015 L .55834 .84692 L p .707 .577 .707 r
F P
0 g
s
.53354 .83015 m .54098 .8141 L .52232 .79648 L p .707 .577 .707 r
F P
0 g
s
.69181 .77591 m .68565 .81175 L .70195 .80521 L p .707 .577 .707 r
F P
0 g
s
.70195 .80521 m .70811 .76937 L .69181 .77591 L p .707 .577 .707 r
F P
0 g
s
.7031 .66675 m .70704 .7226 L .71413 .7146 L p .707 .577 .707 r
F P
0 g
s
.71413 .7146 m .7102 .65874 L .7031 .66675 L p .707 .577 .707 r
F P
0 g
s
.50965 .67642 m .51358 .73228 L .51827 .73462 L p .707 .577 .707 r
F P
0 g
s
.51358 .73228 m .50965 .67642 L .50679 .66891 L p .707 .577 .707 r
F P
0 g
s
.50679 .66891 m .51072 .72477 L .51175 .72747 L p .707 .577 .707 r
F P
0 g
s
.51175 .72747 m .51358 .73228 L p .51183 .71591 L .707 .577 .707 r
F P
0 g
s
.51183 .71591 m .50679 .66891 L .51175 .72747 L .707 .577 .707 r
F
.51677 .73547 m .51407 .72454 L p .51151 .75913 L F P
0 g
s
.52174 .72204 m .50965 .67642 L .51827 .73462 L .707 .577 .707 r
F
.51407 .72454 m .50791 .76037 L .5106 .77131 L p F P
0 g
s
.51407 .72454 m .52122 .71535 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.50791 .76037 m .51168 .73842 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.51168 .73842 m .51407 .72454 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.5106 .77131 m .51467 .74768 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51467 .74768 m .51677 .73547 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51827 .73462 m .52612 .73855 L p .52174 .72204 L .707 .577 .707 r
F P
0 g
s
.52288 .78291 m .52904 .74708 L .51677 .73547 L p .707 .577 .707 r
F P
0 g
s
.52232 .79648 m .51489 .81253 L .53354 .83015 L p .707 .577 .707 r
F P
0 g
s
.6512 .86101 m .64376 .87706 L .66659 .8771 L p .707 .577 .707 r
F P
0 g
s
.66659 .8771 m .67403 .86105 L .6512 .86101 L p .707 .577 .707 r
F P
0 g
s
.51677 .73547 m .5106 .77131 L .52288 .78291 L p .707 .577 .707 r
F P
0 g
s
.51489 .81253 m .52232 .79648 L .51163 .77974 L p .707 .577 .707 r
F P
0 g
s
.51163 .77974 m .5042 .79579 L .51489 .81253 L p .707 .577 .707 r
F P
0 g
s
.70811 .76937 m .70195 .80521 L .7091 .79602 L p .707 .577 .707 r
F P
0 g
s
.7091 .79602 m .71526 .76018 L .70811 .76937 L p .707 .577 .707 r
F P
0 g
s
.7102 .65874 m .71413 .7146 L .71127 .70708 L p .707 .577 .707 r
F P
0 g
s
.71127 .70708 m .70734 .65123 L .7102 .65874 L p .707 .577 .707 r
F P
0 g
s
.67403 .86105 m .66659 .8771 L .68254 .87169 L p .707 .577 .707 r
F P
0 g
s
.68254 .87169 m .68997 .85565 L .67403 .86105 L p .707 .577 .707 r
F P
0 g
s
.47349 .82204 m .5007 .32386 L .45675 .31877 L p .707 .577 .707 r
F P
0 g
s
.5042 .79579 m .51163 .77974 L .50996 .76551 L p .707 .577 .707 r
F P
0 g
s
.51072 .72477 m .50679 .66891 L .51388 .6609 L p .707 .577 .707 r
F P
0 g
s
.50996 .76551 m .50253 .78156 L .5042 .79579 L p .707 .577 .707 r
F P
0 g
s
.51388 .6609 m .51782 .71676 L .51072 .72477 L p .707 .577 .707 r
F P
0 g
s
.52122 .71535 m .51506 .75118 L .50791 .76037 L p .707 .577 .707 r
F P
0 g
s
.50253 .78156 m .50996 .76551 L .51746 .75519 L p .707 .577 .707 r
F P
0 g
s
.51746 .75519 m .51003 .77123 L .50253 .78156 L p .707 .577 .707 r
F P
0 g
s
.51506 .75118 m .52122 .71535 L .53752 .7088 L p .707 .577 .707 r
F P
0 g
s
.53752 .7088 m .53136 .74464 L .51506 .75118 L p .707 .577 .707 r
F P
0 g
s
.51003 .77123 m .51746 .75519 L .53341 .74978 L p .707 .577 .707 r
F P
0 g
s
.53341 .74978 m .52598 .76583 L .51003 .77123 L p .707 .577 .707 r
F P
0 g
s
.5007 .32386 m .47349 .82204 L .51838 .82311 L p .707 .577 .707 r
F P
0 g
s
.51782 .71676 m .51388 .6609 L .53024 .65318 L p .707 .577 .707 r
F P
0 g
s
.53024 .65318 m .53417 .70903 L .51782 .71676 L p .707 .577 .707 r
F P
0 g
s
.51838 .82311 m .54558 .32494 L .5007 .32386 L p .707 .577 .707 r
F P
0 g
s
.53417 .70903 m .53024 .65318 L .55425 .6465 L p .707 .577 .707 r
F P
0 g
s
.53136 .74464 m .53752 .7088 L .56137 .70554 L p .707 .577 .707 r
F P
0 g
s
.55425 .6465 m .55819 .70235 L .53417 .70903 L p .707 .577 .707 r
F P
0 g
s
.55819 .70235 m .55425 .6465 L .58358 .64151 L p .707 .577 .707 r
F P
0 g
s
.56137 .70554 m .55521 .74138 L .53136 .74464 L p .707 .577 .707 r
F P
0 g
s
.52598 .76583 m .53341 .74978 L .55624 .74982 L p .707 .577 .707 r
F P
0 g
s
.55624 .74982 m .54881 .76586 L .52598 .76583 L p .707 .577 .707 r
F P
0 g
s
.55521 .74138 m .56137 .70554 L .59044 .70589 L p .707 .577 .707 r
F P
0 g
s
.59044 .70589 m .58428 .74173 L .55521 .74138 L p .707 .577 .707 r
F P
0 g
s
.54881 .76586 m .55624 .74982 L .58372 .7553 L p .707 .577 .707 r
F P
0 g
s
.58372 .7553 m .57629 .77135 L .54881 .76586 L p .707 .577 .707 r
F P
0 g
s
.54558 .32494 m .51838 .82311 L .55981 .82007 L p .707 .577 .707 r
F P
0 g
s
.58358 .64151 m .58752 .69737 L .55819 .70235 L p .707 .577 .707 r
F P
0 g
s
.55981 .82007 m .58702 .32189 L .54558 .32494 L p .707 .577 .707 r
F P
0 g
s
.42955 .81695 m .45675 .31877 L .41806 .31016 L p .707 .577 .707 r
F P
0 g
s
.45675 .31877 m .42955 .81695 L .47349 .82204 L p .707 .577 .707 r
F P
0 g
s
.71526 .76018 m .7091 .79602 L .70641 .78509 L p .707 .577 .707 r
F P
0 g
s
.70641 .78509 m .71257 .74925 L .71526 .76018 L p .707 .577 .707 r
F P
0 g
s
.68997 .85565 m .68254 .87169 L .69005 .86137 L p .707 .577 .707 r
F P
0 g
s
.69005 .86137 m .69748 .84532 L .68997 .85565 L p .707 .577 .707 r
F P
0 g
s
.70734 .65123 m .71127 .70708 L .69874 .70081 L p .707 .577 .707 r
F P
0 g
s
.69874 .70081 m .6948 .64495 L .70734 .65123 L p .707 .577 .707 r
F P
0 g
s
.58752 .69737 m .58358 .64151 L .61534 .63871 L p .707 .577 .707 r
F P
0 g
s
.61534 .63871 m .61928 .69457 L .58752 .69737 L p .707 .577 .707 r
F P
0 g
s
.58428 .74173 m .59044 .70589 L .62188 .7098 L p .707 .577 .707 r
F P
0 g
s
.62188 .7098 m .61572 .74564 L .58428 .74173 L p .707 .577 .707 r
F P
0 g
s
.57629 .77135 m .58372 .7553 L .61315 .76568 L p .707 .577 .707 r
F P
0 g
s
.61315 .76568 m .60572 .78173 L .57629 .77135 L p .707 .577 .707 r
F P
0 g
s
.58702 .32189 m .55981 .82007 L .59374 .8132 L p .707 .577 .707 r
F P
0 g
s
.59374 .8132 m .62094 .31502 L .58702 .32189 L p .707 .577 .707 r
F P
0 g
s
.39085 .80834 m .41806 .31016 L .38839 .29888 L p .707 .577 .707 r
F P
0 g
s
.41806 .31016 m .39085 .80834 L .42955 .81695 L p .707 .577 .707 r
F P
0 g
s
.26256 .71479 m .25863 .65894 L .22754 .65928 L p .707 .577 .707 r
F P
0 g
s
.25863 .65894 m .26256 .71479 L .29433 .71199 L p .707 .577 .707 r
F P
0 g
s
.29433 .71199 m .29039 .65614 L .25863 .65894 L p .707 .577 .707 r
F P
0 g
s
.29039 .65614 m .29433 .71199 L .32365 .70701 L p .707 .577 .707 r
F P
0 g
s
.32365 .70701 m .31972 .65115 L .29039 .65614 L p .707 .577 .707 r
F P
0 g
s
.23147 .71513 m .22754 .65928 L .20016 .65713 L p .707 .577 .707 r
F P
0 g
s
.22754 .65928 m .23147 .71513 L .26256 .71479 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71257 .74925 m .70641 .78509 L .69413 .77348 L p .707 .577 .707 r
F P
0 g
s
.69413 .77348 m .70029 .73764 L .71257 .74925 L p .707 .577 .707 r
F P
0 g
s
.69748 .84532 m .69005 .86137 L .68837 .84714 L p .707 .577 .707 r
F P
0 g
s
.68837 .84714 m .69581 .83109 L .69748 .84532 L p .707 .577 .707 r
F P
0 g
s
.31972 .65115 m .32365 .70701 L .34767 .70033 L p .707 .577 .707 r
F P
0 g
s
.34767 .70033 m .34373 .64447 L .31972 .65115 L p .707 .577 .707 r
F P
0 g
s
.6948 .64495 m .69874 .70081 L .67775 .69637 L p .707 .577 .707 r
F P
0 g
s
.67775 .69637 m .67382 .64052 L .6948 .64495 L p .707 .577 .707 r
F P
0 g
s
.61928 .69457 m .61534 .63871 L .64644 .63837 L p .707 .577 .707 r
F P
0 g
s
.65261 .7169 m .64645 .75274 L .61572 .74564 L p .707 .577 .707 r
F P
0 g
s
.61572 .74564 m .62188 .7098 L .65261 .7169 L p .707 .577 .707 r
F P
0 g
s
.64167 .77996 m .63423 .79601 L .60572 .78173 L p .707 .577 .707 r
F P
0 g
s
.60572 .78173 m .61315 .76568 L .64167 .77996 L p .707 .577 .707 r
F P
0 g
s
.62094 .31502 m .59374 .8132 L .61684 .80318 L p .707 .577 .707 r
F P
0 g
s
.64644 .63837 m .65037 .69423 L .61928 .69457 L p .707 .577 .707 r
F P
0 g
s
.61684 .80318 m .64404 .305 L .62094 .31502 L p .707 .577 .707 r
F P
0 g
s
.20016 .65713 m .20409 .71298 L .23147 .71513 L p .707 .577 .707 r
F P
0 g
s
.25828 .7832 m .26444 .74736 L .23371 .74026 L p .707 .577 .707 r
F P
0 g
s
.26444 .74736 m .25828 .7832 L .28972 .78711 L p .707 .577 .707 r
F P
0 g
s
.28972 .78711 m .29588 .75127 L .26444 .74736 L p .707 .577 .707 r
F P
0 g
s
.20409 .71298 m .20016 .65713 L .17917 .6527 L p .707 .577 .707 r
F P
0 g
s
.29588 .75127 m .28972 .78711 L .31879 .78746 L p .707 .577 .707 r
F P
0 g
s
.31879 .78746 m .32495 .75162 L .29588 .75127 L p .707 .577 .707 r
F P
0 g
s
.22755 .7761 m .23371 .74026 L .20669 .73066 L p .707 .577 .707 r
F P
0 g
s
.23371 .74026 m .22755 .7761 L .25828 .7832 L p .707 .577 .707 r
F P
0 g
s
.34373 .64447 m .34767 .70033 L .36403 .6926 L p .707 .577 .707 r
F P
0 g
s
.36403 .6926 m .36009 .63675 L .34373 .64447 L p .707 .577 .707 r
F P
0 g
s
.36009 .63675 m .36403 .6926 L .37112 .68459 L p .707 .577 .707 r
F P
0 g
s
.37112 .68459 m .36719 .62874 L .36009 .63675 L p .707 .577 .707 r
F P
0 g
s
.35894 .77765 m .3651 .74181 L .3488 .74836 L p .707 .577 .707 r
F P
0 g
s
.3651 .74181 m .35894 .77765 L .36609 .76846 L p .707 .577 .707 r
F P
0 g
s
.36719 .62874 m .37112 .68459 L .36826 .67708 L p .707 .577 .707 r
F P
0 g
s
.36826 .67708 m .36433 .62123 L .36719 .62874 L p .707 .577 .707 r
F P
0 g
s
.36433 .62123 m .36826 .67708 L .3614 .67365 L p .707 .577 .707 r
F P
0 g
s
.3614 .67365 m .35573 .6708 L p .35863 .65407 L .707 .577 .707 r
F P
0 g
s
.35863 .65407 m .36433 .62123 L .3614 .67365 L .707 .577 .707 r
F
.38839 .29888 m .3661 .70694 L p .39085 .80834 L F P
0 g
s
.36609 .76846 m .37225 .73263 L .3651 .74181 L p .707 .577 .707 r
F P
0 g
s
.37225 .73263 m .36609 .76846 L .3634 .75753 L p .707 .577 .707 r
F P
0 g
s
.3634 .75753 m .36956 .72169 L .37225 .73263 L p .707 .577 .707 r
F P
0 g
s
.36956 .72169 m .3634 .75753 L .35638 .7509 L p .707 .577 .707 r
F P
0 g
s
.35638 .7509 m .35112 .74592 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.36106 .73286 m .36956 .72169 L .35638 .7509 L .707 .577 .707 r
F
.35112 .74592 m .35728 .71009 L .36506 .71744 L p F P
0 g
s
.36506 .71744 m .36956 .72169 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.35112 .74592 m .36506 .71744 L .36106 .73286 L .707 .577 .707 r
F
.37985 .80415 m .39085 .80834 L p .36692 .71028 L F P
0 g
s
.36692 .71028 m .3661 .70694 L .3667 .71113 L .707 .577 .707 r
F
.36692 .71028 m .3667 .71113 L .37985 .80415 L F
.36118 .79705 m .37985 .80415 L p .3667 .71113 L F P
0 g
s
.3661 .70694 m .36566 .71515 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36566 .71515 m .36118 .79705 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36118 .79705 m .38839 .29888 L .37066 .28602 L p .707 .577 .707 r
F P
0 g
s
.17917 .6527 m .18311 .70855 L .20409 .71298 L p .707 .577 .707 r
F P
0 g
s
.70029 .73764 m .69413 .77348 L .67347 .76233 L p .707 .577 .707 r
F P
0 g
s
.67347 .76233 m .67963 .7265 L .70029 .73764 L p .707 .577 .707 r
F P
0 g
s
.67382 .64052 m .67775 .69637 L .65037 .69423 L p .707 .577 .707 r
F P
0 g
s
.65037 .69423 m .64644 .63837 L .67382 .64052 L p .707 .577 .707 r
F P
0 g
s
.32495 .75162 m .31879 .78746 L .34264 .7842 L p .707 .577 .707 r
F P
0 g
s
.34264 .7842 m .3488 .74836 L .32495 .75162 L p .707 .577 .707 r
F P
0 g
s
.20669 .73066 m .20053 .7665 L .22755 .7761 L p .707 .577 .707 r
F P
0 g
s
.20053 .7665 m .20669 .73066 L .18603 .71952 L p .707 .577 .707 r
F P
0 g
s
.69581 .83109 m .68837 .84714 L .67768 .8304 L p .707 .577 .707 r
F P
0 g
s
.67768 .8304 m .68512 .81435 L .69581 .83109 L p .707 .577 .707 r
F P
0 g
s
.24384 .82703 m .25128 .81098 L .22276 .7967 L p .707 .577 .707 r
F P
0 g
s
.25128 .81098 m .24384 .82703 L .27328 .83741 L p .707 .577 .707 r
F P
0 g
s
.27328 .83741 m .28071 .82136 L .25128 .81098 L p .707 .577 .707 r
F P
0 g
s
.18311 .70855 m .17917 .6527 L .16664 .64642 L p .707 .577 .707 r
F P
0 g
s
.21533 .81275 m .22276 .7967 L .19797 .77993 L p .707 .577 .707 r
F P
0 g
s
.22276 .7967 m .21533 .81275 L .24384 .82703 L p .707 .577 .707 r
F P
0 g
s
.28071 .82136 m .27328 .83741 L .30075 .84289 L p .707 .577 .707 r
F P
0 g
s
.30075 .84289 m .30819 .82685 L .28071 .82136 L p .707 .577 .707 r
F P
0 g
s
.18603 .71952 m .17987 .75536 L .20053 .7665 L p .707 .577 .707 r
F P
0 g
s
.19797 .77993 m .19053 .79598 L .21533 .81275 L p .707 .577 .707 r
F P
0 g
s
.64404 .305 m .61684 .80318 L .62685 .79099 L p .707 .577 .707 r
F P
0 g
s
.62685 .79099 m .65405 .29281 L .64404 .305 L p .707 .577 .707 r
F P
0 g
s
.19053 .79598 m .19797 .77993 L .17931 .76231 L p .707 .577 .707 r
F P
0 g
s
.3488 .74836 m .34264 .7842 L .35894 .77765 L p .707 .577 .707 r
F P
0 g
s
.67963 .7265 m .67347 .76233 L .64645 .75274 L p .707 .577 .707 r
F P
0 g
s
.64645 .75274 m .65261 .7169 L .67963 .7265 L p .707 .577 .707 r
F P
0 g
s
.16664 .64642 m .17057 .70228 L .18311 .70855 L p .707 .577 .707 r
F P
0 g
s
.17987 .75536 m .18603 .71952 L .17376 .70791 L p .707 .577 .707 r
F P
0 g
s
.17931 .76231 m .17188 .77836 L .19053 .79598 L p .707 .577 .707 r
F P
0 g
s
.68512 .81435 m .67768 .8304 L .65903 .81278 L p .707 .577 .707 r
F P
0 g
s
.65903 .81278 m .66646 .79673 L .68512 .81435 L p .707 .577 .707 r
F P
0 g
s
.30819 .82685 m .30075 .84289 L .32358 .84293 L p .707 .577 .707 r
F P
0 g
s
.32358 .84293 m .33102 .82688 L .30819 .82685 L p .707 .577 .707 r
F P
0 g
s
.35573 .6708 m .35346 .63859 L p .36433 .62123 L .707 .577 .707 r
F P
0 g
s
.35346 .63859 m .35179 .61495 L .35543 .61677 L p .707 .577 .707 r
F P
0 g
s
.35543 .61677 m .36433 .62123 L p .35346 .63859 L .707 .577 .707 r
F P
0 g
s
.35179 .61495 m .35573 .6708 L .33474 .66637 L p .707 .577 .707 r
F P
0 g
s
.33474 .66637 m .33081 .61052 L .35179 .61495 L p .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .33662 .69894 L .34911 .70568 L p .707 .577 .707 r
F P
0 g
s
.34911 .70568 m .35728 .71009 L p .34855 .71812 L .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .34911 .70568 L .34855 .71812 L .707 .577 .707 r
F
.34661 .71435 m .35715 .52669 L .3666 .27286 L F
.37066 .28602 m .3683 .27837 L p .35715 .52669 L F P
0 g
s
.3683 .27837 m .3666 .27286 L p .35715 .52669 L .707 .577 .707 r
F P
0 g
s
.35728 .71009 m .35112 .74592 L .33046 .73478 L p .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34211 .78018 L .34644 .78697 L p .707 .577 .707 r
F P
0 g
s
.34644 .78697 m .3528 .79692 L p .34659 .79668 L .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34644 .78697 L .34659 .79668 L .707 .577 .707 r
F
.34567 .7353 m .34827 .69607 L .34661 .71435 L F
.34345 .7842 m .34576 .74186 L p .34567 .7353 L F P
0 g
s
.34576 .74186 m .34827 .69607 L p .34567 .7353 L .707 .577 .707 r
F P
0 g
s
.34827 .69607 m .37066 .28602 L p .34661 .71435 L .707 .577 .707 r
F P
0 g
s
.37066 .28602 m .34345 .7842 L .36118 .79705 L p .707 .577 .707 r
F P
0 g
s
.17376 .70791 m .16759 .74375 L .17987 .75536 L p .707 .577 .707 r
F P
0 g
s
.17057 .70228 m .16664 .64642 L .16378 .63891 L p .707 .577 .707 r
F P
0 g
s
.17188 .77836 m .17931 .76231 L .16862 .74557 L p .707 .577 .707 r
F P
0 g
s
.16862 .74557 m .16119 .76162 L .17188 .77836 L p .707 .577 .707 r
F P
0 g
s
.66646 .79673 m .65903 .81278 L .63423 .79601 L p .707 .577 .707 r
F P
0 g
s
.63423 .79601 m .64167 .77996 L .66646 .79673 L p .707 .577 .707 r
F P
0 g
s
.33102 .82688 m .32358 .84293 L .33953 .83752 L p .707 .577 .707 r
F P
0 g
s
.33953 .83752 m .34697 .82148 L .33102 .82688 L p .707 .577 .707 r
F P
0 g
s
.16887 .69782 m .17057 .70228 L p .16894 .68708 L .707 .577 .707 r
F P
0 g
s
.16759 .74375 m .17376 .70791 L .17106 .69698 L p .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .1649 .73282 L .16526 .73428 L p .707 .577 .707 r
F P
0 g
s
.16526 .73428 m .16759 .74375 L p .16908 .72371 L .707 .577 .707 r
F P
0 g
s
.16908 .72371 m .17106 .69698 L .16526 .73428 L .707 .577 .707 r
F
.16119 .76162 m .16862 .74557 L .16695 .73134 L p F P
0 g
s
.16695 .73134 m .15952 .74739 L .16119 .76162 L p .707 .577 .707 r
F P
0 g
s
.16695 .73134 m .17445 .72102 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.15952 .74739 m .16409 .73751 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.16409 .73751 m .16695 .73134 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .17821 .68779 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1649 .73282 m .1688 .71016 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1688 .71016 m .17106 .69698 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.16378 .63891 m .16771 .69476 L .16887 .69782 L p .707 .577 .707 r
F P
0 g
s
.16894 .68708 m .16378 .63891 L .16887 .69782 L .707 .577 .707 r
F
.65405 .29281 m .62685 .79099 L .62279 .77782 L p F P
0 g
s
.62279 .77782 m .64999 .27965 L .65405 .29281 L p .707 .577 .707 r
F P
0 g
s
.16771 .69476 m .16378 .63891 L .17087 .6309 L p .707 .577 .707 r
F P
0 g
s
.3666 .27286 m .33939 .77103 L .34345 .7842 L p .707 .577 .707 r
F P
0 g
s
.33939 .77103 m .3666 .27286 L .37661 .26067 L p .707 .577 .707 r
F P
0 g
s
.34697 .82148 m .33953 .83752 L .34704 .8272 L p .707 .577 .707 r
F P
0 g
s
.34704 .8272 m .35447 .81115 L .34697 .82148 L p .707 .577 .707 r
F P
0 g
s
.17087 .6309 m .17481 .68675 L .16771 .69476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17821 .68779 m .17205 .72363 L .1649 .73282 L p .707 .577 .707 r
F P
0 g
s
.17481 .68675 m .17087 .6309 L .18723 .62318 L p .707 .577 .707 r
F P
0 g
s
.19451 .68125 m .19387 .68497 L p .17205 .72363 L .707 .577 .707 r
F P
0 g
s
.16702 .73706 m .17445 .72102 L .1904 .71561 L p .707 .577 .707 r
F P
0 g
s
.19387 .68497 m .18835 .71708 L .17389 .72289 L p .707 .577 .707 r
F P
0 g
s
.17445 .72102 m .17135 .72772 L p .15952 .74739 L .707 .577 .707 r
F P
0 g
s
.17389 .72289 m .17205 .72363 L p .19387 .68497 L .707 .577 .707 r
F P
0 g
s
.17135 .72772 m .16702 .73706 L .16486 .74004 L p .707 .577 .707 r
F P
0 g
s
.16486 .74004 m .15952 .74739 L p .17135 .72772 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64999 .27965 m .62279 .77782 L .60506 .76497 L p .707 .577 .707 r
F P
0 g
s
.60506 .76497 m .63226 .26679 L .64999 .27965 L p .707 .577 .707 r
F P
0 g
s
.35447 .81115 m .34704 .8272 L .34536 .81297 L p .707 .577 .707 r
F P
0 g
s
.34536 .81297 m .3528 .79692 L .35447 .81115 L p .707 .577 .707 r
F P
0 g
s
.17205 .72363 m .17821 .68779 L .19451 .68125 L p .707 .577 .707 r
F P
0 g
s
.18723 .62318 m .19116 .67903 L .17481 .68675 L p .707 .577 .707 r
F P
0 g
s
.3494 .75884 m .37661 .26067 L .39971 .25065 L p .707 .577 .707 r
F P
0 g
s
.37661 .26067 m .3494 .75884 L .33939 .77103 L p .707 .577 .707 r
F P
0 g
s
.19116 .67903 m .18723 .62318 L .21125 .6165 L p .707 .577 .707 r
F P
0 g
s
.21836 .67799 m .21743 .68345 L p .18835 .71708 L .707 .577 .707 r
F P
0 g
s
.18297 .73166 m .1904 .71561 L .21323 .71565 L p .707 .577 .707 r
F P
0 g
s
.21743 .68345 m .2122 .71383 L .19154 .71665 L p .707 .577 .707 r
F P
0 g
s
.1904 .71561 m .18755 .72177 L p .16702 .73706 L .707 .577 .707 r
F P
0 g
s
.19154 .71665 m .18835 .71708 L p .21743 .68345 L .707 .577 .707 r
F P
0 g
s
.18755 .72177 m .18297 .73166 L .17872 .7331 L p .707 .577 .707 r
F P
0 g
s
.17872 .7331 m .16702 .73706 L p .18755 .72177 L .707 .577 .707 r
F P
0 g
s
.33081 .61052 m .33474 .66637 L .30736 .66422 L p .707 .577 .707 r
F P
0 g
s
.30736 .66422 m .30343 .60837 L .33081 .61052 L p .707 .577 .707 r
F P
0 g
s
.3528 .79692 m .34536 .81297 L .33468 .79623 L p .707 .577 .707 r
F P
0 g
s
.18835 .71708 m .19451 .68125 L .21836 .67799 L p .707 .577 .707 r
F P
0 g
s
.21125 .6165 m .21518 .67235 L .19116 .67903 L p .707 .577 .707 r
F P
0 g
s
.63226 .26679 m .60506 .76497 L .57539 .75368 L p .707 .577 .707 r
F P
0 g
s
.57539 .75368 m .6026 .25551 L .63226 .26679 L p .707 .577 .707 r
F P
0 g
s
.21518 .67235 m .21125 .6165 L .24057 .61151 L p .707 .577 .707 r
F P
0 g
s
.30343 .60837 m .30736 .66422 L .27627 .66457 L p .707 .577 .707 r
F P
0 g
s
.27627 .66457 m .27233 .60871 L .30343 .60837 L p .707 .577 .707 r
F P
0 g
s
.39971 .25065 m .3725 .74882 L .3494 .75884 L p .707 .577 .707 r
F P
0 g
s
.3725 .74882 m .39971 .25065 L .43363 .24378 L p .707 .577 .707 r
F P
0 g
s
.24451 .66737 m .24057 .61151 L .27233 .60871 L p .707 .577 .707 r
F P
0 g
s
.24057 .61151 m .24451 .66737 L .21518 .67235 L p .707 .577 .707 r
F P
0 g
s
.21323 .71565 m .2058 .73169 L .18297 .73166 L p .707 .577 .707 r
F P
0 g
s
.33662 .69894 m .33046 .73478 L .30344 .72519 L p .707 .577 .707 r
F P
0 g
s
.30344 .72519 m .3096 .68935 L .33662 .69894 L p .707 .577 .707 r
F P
0 g
s
.74278 .65275 m .73884 .5969 L .70775 .59724 L p .707 .577 .707 r
F P
0 g
s
.73884 .5969 m .74278 .65275 L .77454 .64995 L p .707 .577 .707 r
F P
0 g
s
.77454 .64995 m .77061 .5941 L .73884 .5969 L p .707 .577 .707 r
F P
0 g
s
.27233 .60871 m .27627 .66457 L .24451 .66737 L p .707 .577 .707 r
F P
0 g
s
.2122 .71383 m .21836 .67799 L .24743 .67833 L p .707 .577 .707 r
F P
0 g
s
.77061 .5941 m .77454 .64995 L .80387 .64497 L p .707 .577 .707 r
F P
0 g
s
.80387 .64497 m .79993 .58912 L .77061 .5941 L p .707 .577 .707 r
F P
0 g
s
.34211 .78018 m .33468 .79623 L .31602 .77861 L p .707 .577 .707 r
F P
0 g
s
.31602 .77861 m .32345 .76256 L .34211 .78018 L p .707 .577 .707 r
F P
0 g
s
.71168 .6531 m .70775 .59724 L .68037 .59509 L p .707 .577 .707 r
F P
0 g
s
.70775 .59724 m .71168 .6531 L .74278 .65275 L p .707 .577 .707 r
F P
0 g
s
.3096 .68935 m .30344 .72519 L .27271 .71808 L p .707 .577 .707 r
F P
0 g
s
.27271 .71808 m .27887 .68225 L .3096 .68935 L p .707 .577 .707 r
F P
0 g
s
.79993 .58912 m .80387 .64497 L .82788 .63829 L p .707 .577 .707 r
F P
0 g
s
.82788 .63829 m .82395 .58243 L .79993 .58912 L p .707 .577 .707 r
F P
0 g
s
.24743 .67833 m .24127 .71417 L .2122 .71383 L p .707 .577 .707 r
F P
0 g
s
.2058 .73169 m .21323 .71565 L .24071 .72113 L p .707 .577 .707 r
F P
0 g
s
.24127 .71417 m .24743 .67833 L .27887 .68225 L p .707 .577 .707 r
F P
0 g
s
.6026 .25551 m .57539 .75368 L .53669 .74507 L p .707 .577 .707 r
F P
0 g
s
.53669 .74507 m .5639 .2469 L .6026 .25551 L p .707 .577 .707 r
F P
0 g
s
.27887 .68225 m .27271 .71808 L .24127 .71417 L p .707 .577 .707 r
F P
0 g
s
.68037 .59509 m .68431 .65095 L .71168 .6531 L p .707 .577 .707 r
F P
0 g
s
.7385 .71871 m .74466 .68288 L .71392 .67578 L p .707 .577 .707 r
F P
0 g
s
.74466 .68288 m .7385 .71871 L .76993 .72263 L p .707 .577 .707 r
F P
0 g
s
.76993 .72263 m .7761 .68679 L .74466 .68288 L p .707 .577 .707 r
F P
0 g
s
.24071 .72113 m .23328 .73718 L .2058 .73169 L p .707 .577 .707 r
F P
0 g
s
.32345 .76256 m .31602 .77861 L .29122 .76184 L p .707 .577 .707 r
F P
0 g
s
.29122 .76184 m .29866 .74579 L .32345 .76256 L p .707 .577 .707 r
F P
0 g
s
.68431 .65095 m .68037 .59509 L .65939 .59066 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .43363 .24378 L .47507 .24073 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .3725 .74882 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.41843 .52224 m .40643 .74195 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .44786 .73891 L .40643 .74195 L p .707 .577 .707 r
F P
0 g
s
.40165 .65532 m .39549 .69116 L .42126 .69437 L p .707 .577 .707 r
F P
0 g
s
.42126 .69437 m .42692 .69507 L p .42112 .68594 L .707 .577 .707 r
F P
0 g
s
.42112 .68594 m .40165 .65532 L .42126 .69437 L .707 .577 .707 r
F
.43363 .24378 m .41843 .52224 L p .41622 .38766 L F P
0 g
s
.7761 .68679 m .76993 .72263 L .799 .72297 L p .707 .577 .707 r
F P
0 g
s
.799 .72297 m .80516 .68714 L .7761 .68679 L p .707 .577 .707 r
F P
0 g
s
.70776 .71161 m .71392 .67578 L .68691 .66618 L p .707 .577 .707 r
F P
0 g
s
.71392 .67578 m .70776 .71161 L .7385 .71871 L p .707 .577 .707 r
F P
0 g
s
.23328 .73718 m .24071 .72113 L .27014 .73151 L p .707 .577 .707 r
F P
0 g
s
.82395 .58243 m .82788 .63829 L .84424 .63057 L p .707 .577 .707 r
F P
0 g
s
.84424 .63057 m .8403 .57471 L .82395 .58243 L p .707 .577 .707 r
F P
0 g
s
.29866 .74579 m .29122 .76184 L .26271 .74756 L p .707 .577 .707 r
F P
0 g
s
.26271 .74756 m .27014 .73151 L .29866 .74579 L p .707 .577 .707 r
F P
0 g
s
.27014 .73151 m .26271 .74756 L .23328 .73718 L p .707 .577 .707 r
F P
0 g
s
.65939 .59066 m .66332 .64652 L .68431 .65095 L p .707 .577 .707 r
F P
0 g
s
.5639 .2469 m .53669 .74507 L .49275 .73998 L p .707 .577 .707 r
F P
0 g
s
.49275 .73998 m .51995 .24181 L .5639 .2469 L p .707 .577 .707 r
F P
0 g
s
.80516 .68714 m .799 .72297 L .82285 .71971 L p .707 .577 .707 r
F P
0 g
s
.82285 .71971 m .82902 .68388 L .80516 .68714 L p .707 .577 .707 r
F P
0 g
s
.68691 .66618 m .68074 .70202 L .70776 .71161 L p .707 .577 .707 r
F P
0 g
s
.68074 .70202 m .68691 .66618 L .66625 .65504 L p .707 .577 .707 r
F P
0 g
s
.4276 .5641 m .43153 .61995 L .4448 .6177 L p .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .51995 .24181 L p .46528 .61883 L .707 .577 .707 r
F P
0 g
s
.45799 .66906 m .45929 .63649 L .46528 .61883 L .707 .577 .707 r
F
.45929 .63649 m .47507 .24073 L .46528 .61883 L F
.44786 .73891 m .45234 .657 L p .45799 .66906 L F P
0 g
s
.45234 .657 m .45279 .64879 L p .45379 .65271 L .707 .577 .707 r
F P
0 g
s
.45234 .657 m .45379 .65271 L .45799 .66906 L .707 .577 .707 r
F
.43309 .65923 m .42692 .69507 L .43938 .69522 L p F P
0 g
s
.51995 .24181 m .49275 .73998 L .44786 .73891 L p .707 .577 .707 r
F P
0 g
s
.43938 .69522 m .45599 .69542 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.44513 .67826 m .43309 .65923 L .43938 .69522 L .707 .577 .707 r
F
.45279 .64879 m .47507 .24073 L p .45799 .66906 L F P
0 g
s
.45599 .69542 m .46215 .65958 L .45151 .65945 L p .707 .577 .707 r
F P
0 g
s
.45151 .65945 m .43309 .65923 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.45599 .69542 m .45151 .65945 L .44513 .67826 L .707 .577 .707 r
F
.4448 .6177 m .46086 .61497 L p .43325 .57275 L F P
0 g
s
.43325 .57275 m .4276 .5641 L .4448 .6177 L .707 .577 .707 r
F
.72406 .76916 m .73149 .75311 L .70298 .73883 L p F P
0 g
s
.73149 .75311 m .72406 .76916 L .75349 .77954 L p .707 .577 .707 r
F P
0 g
s
.75349 .77954 m .76092 .7635 L .73149 .75311 L p .707 .577 .707 r
F P
0 g
s
.66332 .64652 m .65939 .59066 L .64685 .58438 L p .707 .577 .707 r
F P
0 g
s
.69554 .75488 m .70298 .73883 L .67818 .72206 L p .707 .577 .707 r
F P
0 g
s
.70298 .73883 m .69554 .75488 L .72406 .76916 L p .707 .577 .707 r
F P
0 g
s
.66625 .65504 m .66009 .69087 L .68074 .70202 L p .707 .577 .707 r
F P
0 g
s
.76092 .7635 m .75349 .77954 L .78097 .78503 L p .707 .577 .707 r
F P
0 g
s
.78097 .78503 m .7884 .76898 L .76092 .7635 L p .707 .577 .707 r
F P
0 g
s
.67818 .72206 m .67075 .73811 L .69554 .75488 L p .707 .577 .707 r
F P
0 g
s
.67075 .73811 m .67818 .72206 L .65952 .70445 L p .707 .577 .707 r
F P
0 g
s
.82902 .68388 m .82285 .71971 L .83915 .71317 L p .707 .577 .707 r
F P
0 g
s
.83915 .71317 m .84531 .67733 L .82902 .68388 L p .707 .577 .707 r
F P
0 g
s
.8403 .57471 m .84424 .63057 L .85134 .62256 L p .707 .577 .707 r
F P
0 g
s
.85134 .62256 m .8474 .5667 L .8403 .57471 L p .707 .577 .707 r
F P
0 g
s
.64685 .58438 m .65079 .64024 L .65547 .64259 L p .707 .577 .707 r
F P
0 g
s
.65079 .64024 m .64685 .58438 L .64399 .57687 L p .707 .577 .707 r
F P
0 g
s
.64399 .57687 m .64793 .63273 L .64896 .63544 L p .707 .577 .707 r
F P
0 g
s
.64896 .63544 m .65079 .64024 L p .64903 .62387 L .707 .577 .707 r
F P
0 g
s
.64903 .62387 m .64399 .57687 L .64896 .63544 L .707 .577 .707 r
F
.65397 .64343 m .65128 .6325 L p .64871 .66709 L F P
0 g
s
.65894 .63 m .64685 .58438 L .65547 .64259 L .707 .577 .707 r
F
.65128 .6325 m .64511 .66833 L .64781 .67927 L p F P
0 g
s
.65128 .6325 m .65843 .62331 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64511 .66833 m .64889 .64639 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64889 .64639 m .65128 .6325 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64781 .67927 m .65187 .65564 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65187 .65564 m .65397 .64343 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65547 .64259 m .66332 .64652 L p .65894 .63 L .707 .577 .707 r
F P
0 g
s
.66009 .69087 m .66625 .65504 L .65397 .64343 L p .707 .577 .707 r
F P
0 g
s
.65952 .70445 m .65209 .72049 L .67075 .73811 L p .707 .577 .707 r
F P
0 g
s
.7884 .76898 m .78097 .78503 L .8038 .78506 L p .707 .577 .707 r
F P
0 g
s
.8038 .78506 m .81123 .76902 L .7884 .76898 L p .707 .577 .707 r
F P
0 g
s
.65397 .64343 m .64781 .67927 L .66009 .69087 L p .707 .577 .707 r
F P
0 g
s
.65209 .72049 m .65952 .70445 L .64884 .6877 L p .707 .577 .707 r
F P
0 g
s
.64884 .6877 m .6414 .70375 L .65209 .72049 L p .707 .577 .707 r
F P
0 g
s
.84531 .67733 m .83915 .71317 L .84631 .70398 L p .707 .577 .707 r
F P
0 g
s
.84631 .70398 m .85247 .66814 L .84531 .67733 L p .707 .577 .707 r
F P
0 g
s
.8474 .5667 m .85134 .62256 L .84848 .61505 L p .707 .577 .707 r
F P
0 g
s
.84848 .61505 m .84454 .55919 L .8474 .5667 L p .707 .577 .707 r
F P
0 g
s
.81123 .76902 m .8038 .78506 L .81975 .77966 L p .707 .577 .707 r
F P
0 g
s
.81975 .77966 m .82718 .76361 L .81123 .76902 L p .707 .577 .707 r
F P
0 g
s
.6414 .70375 m .64884 .6877 L .64716 .67347 L p .707 .577 .707 r
F P
0 g
s
.64793 .63273 m .64399 .57687 L .65109 .56886 L p .707 .577 .707 r
F P
0 g
s
.64716 .67347 m .63973 .68952 L .6414 .70375 L p .707 .577 .707 r
F P
0 g
s
.85247 .66814 m .84631 .70398 L .84361 .69305 L p .707 .577 .707 r
F P
0 g
s
.84361 .69305 m .84977 .65721 L .85247 .66814 L p .707 .577 .707 r
F P
0 g
s
.82718 .76361 m .81975 .77966 L .82725 .76933 L p .707 .577 .707 r
F P
0 g
s
.82725 .76933 m .83468 .75328 L .82718 .76361 L p .707 .577 .707 r
F P
0 g
s
.65109 .56886 m .65502 .62472 L .64793 .63273 L p .707 .577 .707 r
F P
0 g
s
.84454 .55919 m .84848 .61505 L .83594 .60877 L p .707 .577 .707 r
F P
0 g
s
.83594 .60877 m .83201 .55291 L .84454 .55919 L p .707 .577 .707 r
F P
0 g
s
.65843 .62331 m .65227 .65915 L .64511 .66833 L p .707 .577 .707 r
F P
0 g
s
.63973 .68952 m .64716 .67347 L .65467 .66315 L p .707 .577 .707 r
F P
0 g
s
.39977 .62275 m .39583 .5669 L .36474 .56724 L p .707 .577 .707 r
F P
0 g
s
.39583 .5669 m .39977 .62275 L .43153 .61995 L p .707 .577 .707 r
F P
0 g
s
.43153 .61995 m .4276 .5641 L .39583 .5669 L p .707 .577 .707 r
F P
0 g
s
.46086 .61497 m .45692 .55911 L .4276 .5641 L p .707 .577 .707 r
F P
0 g
s
.65502 .62472 m .65109 .56886 L .66744 .56114 L p .707 .577 .707 r
F P
0 g
s
.65467 .66315 m .64723 .67919 L .63973 .68952 L p .707 .577 .707 r
F P
0 g
s
.36867 .6231 m .36474 .56724 L .33736 .56509 L p .707 .577 .707 r
F P
0 g
s
.36474 .56724 m .36867 .6231 L .39977 .62275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84977 .65721 m .84361 .69305 L .83133 .68144 L p .707 .577 .707 r
F P
0 g
s
.83133 .68144 m .8375 .6456 L .84977 .65721 L p .707 .577 .707 r
F P
0 g
s
.83468 .75328 m .82725 .76933 L .82558 .7551 L p .707 .577 .707 r
F P
0 g
s
.82558 .7551 m .83301 .73905 L .83468 .75328 L p .707 .577 .707 r
F P
0 g
s
.45692 .55911 m .46086 .61497 L .48487 .60829 L p .707 .577 .707 r
F P
0 g
s
.48487 .60829 m .48094 .55243 L .45692 .55911 L p .707 .577 .707 r
F P
0 g
s
.65227 .65915 m .65843 .62331 L .67473 .61676 L p .707 .577 .707 r
F P
0 g
s
.83201 .55291 m .83594 .60877 L .81496 .60434 L p .707 .577 .707 r
F P
0 g
s
.81496 .60434 m .81102 .54848 L .83201 .55291 L p .707 .577 .707 r
F P
0 g
s
.66744 .56114 m .67138 .61699 L .65502 .62472 L p .707 .577 .707 r
F P
0 g
s
.33736 .56509 m .3413 .62095 L .36867 .6231 L p .707 .577 .707 r
F P
0 g
s
.39549 .69116 m .40165 .65532 L .37091 .64822 L p .707 .577 .707 r
F P
0 g
s
.42692 .69507 m .43309 .65923 L .40165 .65532 L p .707 .577 .707 r
F P
0 g
s
.3413 .62095 m .33736 .56509 L .31638 .56066 L p .707 .577 .707 r
F P
0 g
s
.36475 .68406 m .37091 .64822 L .3439 .63863 L p .707 .577 .707 r
F P
0 g
s
.37091 .64822 m .36475 .68406 L .39549 .69116 L p .707 .577 .707 r
F P
0 g
s
.67473 .61676 m .66857 .6526 L .65227 .65915 L p .707 .577 .707 r
F P
0 g
s
.64723 .67919 m .65467 .66315 L .67062 .65774 L p .707 .577 .707 r
F P
0 g
s
.67138 .61699 m .66744 .56114 L .69146 .55446 L p .707 .577 .707 r
F P
0 g
s
.48094 .55243 m .48487 .60829 L .50123 .60057 L p .707 .577 .707 r
F P
0 g
s
.50123 .60057 m .4973 .54471 L .48094 .55243 L p .707 .577 .707 r
F P
0 g
s
.67062 .65774 m .66318 .67379 L .64723 .67919 L p .707 .577 .707 r
F P
0 g
s
.31638 .56066 m .32031 .61652 L .3413 .62095 L p .707 .577 .707 r
F P
0 g
s
.8375 .6456 m .83133 .68144 L .81067 .6703 L p .707 .577 .707 r
F P
0 g
s
.81067 .6703 m .81684 .63446 L .8375 .6456 L p .707 .577 .707 r
F P
0 g
s
.81102 .54848 m .81496 .60434 L .78758 .60219 L p .707 .577 .707 r
F P
0 g
s
.78758 .60219 m .78364 .54633 L .81102 .54848 L p .707 .577 .707 r
F P
0 g
s
.46215 .65958 m .45599 .69542 L .47984 .69216 L p .707 .577 .707 r
F P
0 g
s
.47984 .69216 m .48601 .65632 L .46215 .65958 L p .707 .577 .707 r
F P
0 g
s
.3439 .63863 m .33773 .67446 L .36475 .68406 L p .707 .577 .707 r
F P
0 g
s
.33773 .67446 m .3439 .63863 L .32324 .62748 L p .707 .577 .707 r
F P
0 g
s
.66857 .6526 m .67473 .61676 L .69858 .61351 L p .707 .577 .707 r
F P
0 g
s
.83301 .73905 m .82558 .7551 L .81489 .73836 L p .707 .577 .707 r
F P
0 g
s
.81489 .73836 m .82232 .72231 L .83301 .73905 L p .707 .577 .707 r
F P
0 g
s
.69146 .55446 m .69539 .61031 L .67138 .61699 L p .707 .577 .707 r
F P
0 g
s
.38105 .73499 m .38848 .71894 L .35997 .70466 L p .707 .577 .707 r
F P
0 g
s
.38848 .71894 m .38105 .73499 L .41048 .74537 L p .707 .577 .707 r
F P
0 g
s
.41048 .74537 m .41791 .72933 L .38848 .71894 L p .707 .577 .707 r
F P
0 g
s
.32031 .61652 m .31638 .56066 L .30384 .55438 L p .707 .577 .707 r
F P
0 g
s
.35253 .72071 m .35997 .70466 L .33517 .68789 L p .707 .577 .707 r
F P
0 g
s
.35997 .70466 m .35253 .72071 L .38105 .73499 L p .707 .577 .707 r
F P
0 g
s
.69539 .61031 m .69146 .55446 L .72078 .54947 L p .707 .577 .707 r
F P
0 g
s
.41791 .72933 m .41048 .74537 L .43796 .75086 L p .707 .577 .707 r
F P
0 g
s
.43796 .75086 m .44539 .73481 L .41791 .72933 L p .707 .577 .707 r
F P
0 g
s
.32324 .62748 m .31708 .66332 L .33773 .67446 L p .707 .577 .707 r
F P
0 g
s
.69858 .61351 m .69242 .64934 L .66857 .6526 L p .707 .577 .707 r
F P
0 g
s
.66318 .67379 m .67062 .65774 L .69345 .65778 L p .707 .577 .707 r
F P
0 g
s
.33517 .68789 m .32774 .70394 L .35253 .72071 L p .707 .577 .707 r
F P
0 g
s
.78364 .54633 m .78758 .60219 L .75648 .60253 L p .707 .577 .707 r
F P
0 g
s
.75648 .60253 m .75255 .54667 L .78364 .54633 L p .707 .577 .707 r
F P
0 g
s
.32774 .70394 m .33517 .68789 L .31651 .67028 L p .707 .577 .707 r
F P
0 g
s
.4973 .54471 m .50123 .60057 L .50833 .59256 L p .707 .577 .707 r
F P
0 g
s
.50833 .59256 m .50439 .5367 L .4973 .54471 L p .707 .577 .707 r
F P
0 g
s
.48601 .65632 m .47984 .69216 L .49614 .68561 L p .707 .577 .707 r
F P
0 g
s
.49614 .68561 m .5023 .64978 L .48601 .65632 L p .707 .577 .707 r
F P
0 g
s
.72472 .60533 m .72078 .54947 L .75255 .54667 L p .707 .577 .707 r
F P
0 g
s
.72078 .54947 m .72472 .60533 L .69539 .61031 L p .707 .577 .707 r
F P
0 g
s
.81684 .63446 m .81067 .6703 L .78366 .6607 L p .707 .577 .707 r
F P
0 g
s
.78366 .6607 m .78982 .62487 L .81684 .63446 L p .707 .577 .707 r
F P
0 g
s
.30384 .55438 m .30777 .61024 L .32031 .61652 L p .707 .577 .707 r
F P
0 g
s
.69345 .65778 m .68601 .67383 L .66318 .67379 L p .707 .577 .707 r
F P
0 g
s
.69242 .64934 m .69858 .61351 L .72765 .61385 L p .707 .577 .707 r
F P
0 g
s
.31708 .66332 m .32324 .62748 L .31096 .61587 L p .707 .577 .707 r
F P
0 g
s
.75255 .54667 m .75648 .60253 L .72472 .60533 L p .707 .577 .707 r
F P
0 g
s
.31651 .67028 m .30908 .68632 L .32774 .70394 L p .707 .577 .707 r
F P
0 g
s
.82232 .72231 m .81489 .73836 L .79623 .72074 L p .707 .577 .707 r
F P
0 g
s
.79623 .72074 m .80367 .70469 L .82232 .72231 L p .707 .577 .707 r
F P
0 g
s
.44539 .73481 m .43796 .75086 L .46079 .75089 L p .707 .577 .707 r
F P
0 g
s
.46079 .75089 m .46822 .73485 L .44539 .73481 L p .707 .577 .707 r
F P
0 g
s
.78982 .62487 m .78366 .6607 L .75292 .6536 L p .707 .577 .707 r
F P
0 g
s
.75292 .6536 m .75909 .61776 L .78982 .62487 L p .707 .577 .707 r
F P
0 g
s
.72765 .61385 m .72148 .64969 L .69242 .64934 L p .707 .577 .707 r
F P
0 g
s
.31096 .61587 m .3048 .65171 L .31708 .66332 L p .707 .577 .707 r
F P
0 g
s
.30777 .61024 m .30384 .55438 L .30098 .54687 L p .707 .577 .707 r
F P
0 g
s
.72148 .64969 m .72765 .61385 L .75909 .61776 L p .707 .577 .707 r
F P
0 g
s
.68601 .67383 m .69345 .65778 L .72092 .66326 L p .707 .577 .707 r
F P
0 g
s
.30908 .68632 m .31651 .67028 L .30583 .65353 L p .707 .577 .707 r
F P
0 g
s
.75909 .61776 m .75292 .6536 L .72148 .64969 L p .707 .577 .707 r
F P
0 g
s
.72092 .66326 m .71349 .67931 L .68601 .67383 L p .707 .577 .707 r
F P
0 g
s
.30583 .65353 m .29839 .66958 L .30908 .68632 L p .707 .577 .707 r
F P
0 g
s
.80367 .70469 m .79623 .72074 L .77144 .70397 L p .707 .577 .707 r
F P
0 g
s
.77144 .70397 m .77887 .68792 L .80367 .70469 L p .707 .577 .707 r
F P
0 g
s
.5023 .64978 m .49614 .68561 L .5033 .67643 L p .707 .577 .707 r
F P
0 g
s
.5033 .67643 m .50946 .64059 L .5023 .64978 L p .707 .577 .707 r
F P
0 g
s
.46822 .73485 m .46079 .75089 L .47674 .74549 L p .707 .577 .707 r
F P
0 g
s
.47674 .74549 m .48417 .72944 L .46822 .73485 L p .707 .577 .707 r
F P
0 g
s
.30608 .60578 m .30777 .61024 L p .30615 .59504 L .707 .577 .707 r
F P
0 g
s
.3048 .65171 m .31096 .61587 L .30827 .60494 L p .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .3021 .64078 L .30246 .64224 L p .707 .577 .707 r
F P
0 g
s
.30246 .64224 m .3048 .65171 L p .30628 .63167 L .707 .577 .707 r
F P
0 g
s
.30628 .63167 m .30827 .60494 L .30246 .64224 L .707 .577 .707 r
F
.29839 .66958 m .30583 .65353 L .30415 .6393 L p F P
0 g
s
.30415 .6393 m .29672 .65535 L .29839 .66958 L p .707 .577 .707 r
F P
0 g
s
.30415 .6393 m .31166 .62898 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.29672 .65535 m .3013 .64547 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.3013 .64547 m .30415 .6393 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .31542 .59575 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.3021 .64078 m .306 .61812 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.306 .61812 m .30827 .60494 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.30098 .54687 m .30491 .60273 L .30608 .60578 L p .707 .577 .707 r
F P
0 g
s
.30615 .59504 m .30098 .54687 L .30608 .60578 L .707 .577 .707 r
F
.50439 .5367 m .50833 .59256 L .50547 .58504 L p F P
0 g
s
.50547 .58504 m .50153 .52919 L .50439 .5367 L p .707 .577 .707 r
F P
0 g
s
.71349 .67931 m .72092 .66326 L .75036 .67365 L p .707 .577 .707 r
F P
0 g
s
.77887 .68792 m .77144 .70397 L .74293 .68969 L p .707 .577 .707 r
F P
0 g
s
.74293 .68969 m .75036 .67365 L .77887 .68792 L p .707 .577 .707 r
F P
0 g
s
.75036 .67365 m .74293 .68969 L .71349 .67931 L p .707 .577 .707 r
F P
0 g
s
.30491 .60273 m .30098 .54687 L .30808 .53886 L p .707 .577 .707 r
F P
0 g
s
.48417 .72944 m .47674 .74549 L .48424 .73516 L p .707 .577 .707 r
F P
0 g
s
.48424 .73516 m .49167 .71911 L .48417 .72944 L p .707 .577 .707 r
F P
0 g
s
.50946 .64059 m .5033 .67643 L .5006 .66549 L p .707 .577 .707 r
F P
0 g
s
.5006 .66549 m .50676 .62965 L .50946 .64059 L p .707 .577 .707 r
F P
0 g
s
.30808 .53886 m .31201 .59472 L .30491 .60273 L p .707 .577 .707 r
F P
0 g
s
.50153 .52919 m .50547 .58504 L .49293 .57877 L p .707 .577 .707 r
F P
0 g
s
.49293 .57877 m .48899 .52291 L .50153 .52919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31542 .59575 m .30926 .63159 L .3021 .64078 L p .707 .577 .707 r
F P
0 g
s
.31201 .59472 m .30808 .53886 L .32443 .53114 L p .707 .577 .707 r
F P
0 g
s
.33172 .58921 m .33108 .59293 L p .30926 .63159 L .707 .577 .707 r
F P
0 g
s
.30422 .64502 m .31166 .62898 L .32761 .62357 L p .707 .577 .707 r
F P
0 g
s
.33108 .59293 m .32556 .62505 L .3111 .63085 L p .707 .577 .707 r
F P
0 g
s
.31166 .62898 m .30855 .63568 L p .29672 .65535 L .707 .577 .707 r
F P
0 g
s
.3111 .63085 m .30926 .63159 L p .33108 .59293 L .707 .577 .707 r
F P
0 g
s
.30855 .63568 m .30422 .64502 L .30206 .648 L p .707 .577 .707 r
F P
0 g
s
.30206 .648 m .29672 .65535 L p .30855 .63568 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49167 .71911 m .48424 .73516 L .48257 .72093 L p .707 .577 .707 r
F P
0 g
s
.48257 .72093 m .49 .70488 L .49167 .71911 L p .707 .577 .707 r
F P
0 g
s
.50676 .62965 m .5006 .66549 L .48832 .65389 L p .707 .577 .707 r
F P
0 g
s
.48832 .65389 m .49449 .61805 L .50676 .62965 L p .707 .577 .707 r
F P
0 g
s
.30926 .63159 m .31542 .59575 L .33172 .58921 L p .707 .577 .707 r
F P
0 g
s
.48899 .52291 m .49293 .57877 L .47195 .57433 L p .707 .577 .707 r
F P
0 g
s
.47195 .57433 m .46801 .51848 L .48899 .52291 L p .707 .577 .707 r
F P
0 g
s
.32443 .53114 m .32837 .58699 L .31201 .59472 L p .707 .577 .707 r
F P
0 g
s
.32837 .58699 m .32443 .53114 L .34845 .52446 L p .707 .577 .707 r
F P
0 g
s
.35557 .58595 m .35463 .59141 L p .32556 .62505 L .707 .577 .707 r
F P
0 g
s
.32017 .63962 m .32761 .62357 L .35044 .62361 L p .707 .577 .707 r
F P
0 g
s
.35463 .59141 m .34941 .62179 L .32874 .62461 L p .707 .577 .707 r
F P
0 g
s
.32761 .62357 m .32475 .62974 L p .30422 .64502 L .707 .577 .707 r
F P
0 g
s
.32874 .62461 m .32556 .62505 L p .35463 .59141 L .707 .577 .707 r
F P
0 g
s
.32475 .62974 m .32017 .63962 L .31592 .64106 L p .707 .577 .707 r
F P
0 g
s
.31592 .64106 m .30422 .64502 L p .32475 .62974 L .707 .577 .707 r
F P
0 g
s
.46801 .51848 m .47195 .57433 L .44457 .57219 L p .707 .577 .707 r
F P
0 g
s
.44457 .57219 m .44063 .51633 L .46801 .51848 L p .707 .577 .707 r
F P
0 g
s
.49449 .61805 m .48832 .65389 L .46766 .64274 L p .707 .577 .707 r
F P
0 g
s
.46766 .64274 m .47383 .6069 L .49449 .61805 L p .707 .577 .707 r
F P
0 g
s
.49 .70488 m .48257 .72093 L .47188 .70419 L p .707 .577 .707 r
F P
0 g
s
.47188 .70419 m .47931 .68814 L .49 .70488 L p .707 .577 .707 r
F P
0 g
s
.32556 .62505 m .33172 .58921 L .35557 .58595 L p .707 .577 .707 r
F P
0 g
s
.34845 .52446 m .35238 .58031 L .32837 .58699 L p .707 .577 .707 r
F P
0 g
s
.35238 .58031 m .34845 .52446 L .37777 .51947 L p .707 .577 .707 r
F P
0 g
s
.44063 .51633 m .44457 .57219 L .41347 .57253 L p .707 .577 .707 r
F P
0 g
s
.41347 .57253 m .40954 .51667 L .44063 .51633 L p .707 .577 .707 r
F P
0 g
s
.38171 .57533 m .37777 .51947 L .40954 .51667 L p .707 .577 .707 r
F P
0 g
s
.37777 .51947 m .38171 .57533 L .35238 .58031 L p .707 .577 .707 r
F P
0 g
s
.35044 .62361 m .343 .63966 L .32017 .63962 L p .707 .577 .707 r
F P
0 g
s
.47383 .6069 m .46766 .64274 L .44065 .63315 L p .707 .577 .707 r
F P
0 g
s
.44065 .63315 m .44681 .59731 L .47383 .6069 L p .707 .577 .707 r
F P
0 g
s
.40954 .51667 m .41347 .57253 L .38171 .57533 L p .707 .577 .707 r
F P
0 g
s
.34941 .62179 m .35557 .58595 L .38464 .58629 L p .707 .577 .707 r
F P
0 g
s
.47931 .68814 m .47188 .70419 L .45322 .68657 L p .707 .577 .707 r
F P
0 g
s
.45322 .68657 m .46066 .67052 L .47931 .68814 L p .707 .577 .707 r
F P
0 g
s
.44681 .59731 m .44065 .63315 L .40991 .62605 L p .707 .577 .707 r
F P
0 g
s
.40991 .62605 m .41607 .59021 L .44681 .59731 L p .707 .577 .707 r
F P
0 g
s
.38464 .58629 m .37847 .62213 L .34941 .62179 L p .707 .577 .707 r
F P
0 g
s
.343 .63966 m .35044 .62361 L .37791 .62909 L p .707 .577 .707 r
F P
0 g
s
.37847 .62213 m .38464 .58629 L .41607 .59021 L p .707 .577 .707 r
F P
0 g
s
.41607 .59021 m .40991 .62605 L .37847 .62213 L p .707 .577 .707 r
F P
0 g
s
.37791 .62909 m .37048 .64514 L .343 .63966 L p .707 .577 .707 r
F P
0 g
s
.46066 .67052 m .45322 .68657 L .42843 .6698 L p .707 .577 .707 r
F P
0 g
s
.42843 .6698 m .43586 .65375 L .46066 .67052 L p .707 .577 .707 r
F P
0 g
s
.37048 .64514 m .37791 .62909 L .40735 .63948 L p .707 .577 .707 r
F P
0 g
s
.43586 .65375 m .42843 .6698 L .39991 .65552 L p .707 .577 .707 r
F P
0 g
s
.39991 .65552 m .40735 .63948 L .43586 .65375 L p .707 .577 .707 r
F P
0 g
s
.40735 .63948 m .39991 .65552 L .37048 .64514 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0081oo`00M7oo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00NWoo001aOol30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001dOol006moo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0071oo`00KGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06ioo`00Jgoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006]oo`00JWoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JGoo
001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001XOol006Qoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUH00000IWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Eoo`00
J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH0
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001S
Ool006Qoo`03001JEP0000EJEP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo
00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03001JEUYF
00AJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF01400003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH0009JEPH000AJEP03001JEUYF00IJEP04001JEUYFFUH70007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000<00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00HWoo10001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001NOol400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Uoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00
EWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000KOolG000eOol005Eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8001=oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080039o
o`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P003Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009Ool400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000^
Ool005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<005YFFUH0
0P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPH000QJEP03001JEUYF00IJEPL000=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP80009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
05Ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD0009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00
FUH00004FUH01000FUIJEUYF1`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP@000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00FUH00004FUH400000eYF
0000000>0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000UYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000[Ool005Ioo`03
001JEP0000@00003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000:goo001FOol00`00
FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
00000eYF001JEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2000017oo001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000
00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
1Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo00@005YF000000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00Ool00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00eYF5P0015YF
00D005YFFUIJEP0002]oo`00Egoo0P0015YF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH0
0`00Oomoo`0YOol004=ooaH000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP03FUH60008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000020002FUH00`00Oomoo`0YOol003mo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`800003FUH005YF
009JEP03001JEP00018000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000[Ool0
03]oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001J
EP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00IJEP03001JEUYF
00EJEP07001JEUYFFUH005YF0000:goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH01@00FUIJEUYF000015YF3@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000goo00@005YF
001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000:goo000dOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP02FUHF0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00
FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00<Woo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`001EYF00<005YFFUH00UYF1P00
0UYF20001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`@000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP04001JEUYFFUH2000/Ool0031o
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000D00004FUH00000FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP02FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00D005YFFUIJ
EP0002eoo`00;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP000000
1EYF10001EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00@005YF000002ioo`00;Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
0eYF20001eYF00<005YFFUH01EYF10002EYF100000=JEP00FUH01EYF00<005YFFUH00UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH200000eYF000000020005FUH00`00FUH000030002FUH00`00FUIJEP07FUH3000:FUH0
0`00FUIJEP020006FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF10000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP04FUH01000
FUIJEUYF1P001eYF00@005YFFUIJEP8000QJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP80
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8002ioo`00;Woo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH015YF1@001EYF00<005YFFUH0
0eYF0P001UYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00MJEP8000AJEP03001JEUYF00IJEP80
00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP00
00=JEQ/000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0002aoo`00;Woo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP8000UJEP<000UJEPD000=JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP<00006FUH00000001J
EP001EYF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJ
EP04001JEUYFFUH90003FUH01000FUH005YF0P002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000UYF00@005YF0000009JEPd0019oo`@000MJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH<0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80009JEP800003FUH00000008000IJEP03001JEUYF009JEPD0019oo`8000AJEP03
001JEUYF00AJEP05001JEUYFFUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUH00003FUH00`00FUH000020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH200000eYF001JEP04FUH01000FUIJEUYF0`00
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P004Goo0`0000=JEP00FUH01EYF00H005YFFUH005YF000Z
Ool002moo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03
001JEP0000AJEP04001JEP00FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0008FUH00`00FUIJEP04FUH01000FUIJEUYF0`002EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF0`00
4Goo0P001UYF00H005YFFUH005YF000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPD000QJ
EP03001JEUYF00IJEP04001JEUYF0003FUH30003FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH20005FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00009JEP80009JEPT000MJEP03001JEUYF00IJEP80015oo`8000=JEP07
001JEUYFFUH005YF0000:Woo000_Ool00`00FUH00004FUH00`00FUH0000A0008FUH01000FUIJEP00
0UYF00@005YFFUH000IJEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000AJEP04
001JEUYF0004FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP@00003FUH005YF00AJEP03001JEP0000<0009JEP03001JEUYF00QJ
EP<0015oo`800003FUH005YF009JEP03001JEP0002Yoo`00;goo00<005YF00000eYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH010001EYF00L005YFFUIJEP00FUH00003FUH20003FUH00`00FUIJEP02
00000eYF001JEP06FUH30008FUH01000FUIJEP000eYF00@005YFFUIJEP80009JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF0`000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF100025YF00@005YFFUIJEP80015oo`8000=JEP8002]oo`00;goo
00@005YF001JEP<00003FUH005YF00AJEP8000MJEP03001JEUYF00AJEPH000=JEP8000IJEP04001J
EUYF0002FUH00`00FUH000030004FUH50007FUH01000FUIJEUYF0`001UYF0P000eYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00H005YF000005YF0006FUH00`00
FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP03FUH2000<Ool60002FUH2000[Ool002moo`03
001JEP00008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEP00009JEP03001JEUYF00=JEPT000IJEP03001JEUYF00AJEP03001J
EUYF00EJEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000IJEP00001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP07
FUH<0003FUH01`00FUH005YF001JEP0002]oo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJ
EPH000EJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH20009FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001o
o`0ZOol002moo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH20004FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF009JEP<0009JEPl000AJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP@00003FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01@00
FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000:goo000`Ool20004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YF
FUH00UYF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00@005YFFUIJEP80009JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400001UYF
001JEUYF001JEP@00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF00<005YFFUH00UYF0P00;7oo000`Ool20004FUH00`00FUIJEP03FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH20004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YF00000eYF0`001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF0`001EYF00<005YFFUH00UYF0P00;7oo
000`Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH01@00FUIJEUYF000025YF0P002UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF0P001UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF00<005YFFUH00eYF
00L005YFFUIJEP00FUH0000/Ool002moo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP06001JEP00001JEP0025YF0P002UYF
00<005YFFUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<0009JEP06001JEUYF001JEP001eYF100000=JEP00FUH01eYF00<005YFFUH01UYF0`001EYF
00<005YF000015YF00@005YFFUIJEP8002eoo`00;goo00<005YF00000eYF00<005YFFUH00UYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000=JEP04001JEUYF
FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH60002FUH01000FUIJEP001UYF00@005YFFUIJEP<000IJEP03
001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH01000FUIJEUYF0P00;Woo000_Ool2
0004FUHD0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH20006FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUH00002000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH30004FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPD0009JEP<000IJ
EP03001JEUYF00=JEP<000AJEP04001JEP00FUH2000`Ool002moo`80009JEP@000EJEP03001JEP00
00<000Moo`L000IJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH01000FUIJEUYF0P001Goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF0`00<Woo000_Ool015YF000000000UYF00<005YFFUH0
0eYF00<005YFFUH015YF10000Woo0`001Goo10000UYF00<005YFFUH01EYF00@005YFFUH000=JEP80
00MJEP06001JEP00001JEP002eYF00<005YFFUH01eYF00@005YF000000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000EJEP8000EJEP05001JEUYFFUH00003FUH00`00Oomoo`05
Ool500000goo0000000<0005FUH00`00Oomoo`0aOol002ioo`<000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00H000Qoo`@000EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF
009JEP<000YJEP03001JEUYF00MJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000AJEP04001JEUYF0003FUH01`00FUH00000FUH005YF008000Qoo`D000mo
o`07001JEUYFFUH005YF0000<Woo000^Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH4000<Ool400000eYF001JEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP06FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20004FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000]oo`<0015oo`06001JEUYF
001JEP00<Woo000^Ool200000eYF0000000;0004FUH00`00FUIJEP06FUH2000?Ool20005FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP02FUH@0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20005FUH2000POol20003FUH00`00
Oomoo`0_Ool002ioo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH60007FUH01000FUH000003goo
0P000eYF00<005YFFUH00eYF00<005YFFUH00P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP<001moo`05001JEUYFFUH0000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEPD000EJEP04001JEUYFFUH2000?Ool01000FUIJEP00
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02`001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P001UYF
0P007goo00D005YFFUIJEP00031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH0100000=JEP00FUH01EYF0P003Goo00@005YFFUH000EJEP03001JEUYF00D00003
FUH00000008000MJEP03001JEUYF00=JEP03001JEUYF008000YJEPP000UJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP8000AJEP04001JEP00000NOol00`00FUIJ
EP02000`Ool002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20008FUH2000;Ool01000FUIJEP001EYF0`0015YF00<005YFFUH00eYF10000UYF00<005YFFUH0
15YF0`0000=JEP00FUH02eYF00<005YFFUH00eYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000eYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEP8001eoo`04001JEP00
000`Ool002eoo`800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJEP03
001JEP0000/0009JEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH:0003FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH0
1UYF00<005YFFUH00`001UYF0P006goo0P000UYF00<007ooOol0;Goo000]Ool200001EYF001oogoo
00001EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEP04001JEUYFFUH20003FUH0
1@00FUIJEUYF00000UYF00<005YF00000P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P001UYF00<005YFFUH00eYF0P000Woo10001UYF00<0
05YFFUH00eYF00<005YFFUH01UYF0`006Goo00@005YFFUH002moo`00;Goo00D005YFFUIJEP00009o
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP80
0003FUH005YF009JEP03001JEUYF0080009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP80
00Ioo`@0009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00<001Ioo`03001JEP00031oo`00;Goo
00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP<00003FUH005YF00AJEP80
00Yoo`<000IJEP04001JEP000004FUH00`00FUIJEP03FUH3000COol00`00FUH0000`Ool002ioo`04
001JEUYFFUH20004Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH20003FUH20005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH30005FUH2000=Ool20003FUH01000FUIJEUYF0`0000=JEP00FUH025YF1@00
3Goo0`00<Goo000^Ool01000FUIJEP000UYF00<007ooOol017oo0P000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YF000015YF00@005YFFUH0009JEP8000iJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000=JEP8000mo
o`800003FUH005YF009JEP03001JEP0000<000QJEP03001JEUYF009JEPd00003FUH00000035oo`00
;goo00<005YF00000eYF0P001Woo0P0000=JEP00FUH01UYF0`0025YF00@005YFFUH000=JEP04001J
EUYFFUH3000>FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000AOol20003FUH20004Ool30005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000IJEP03001oogoo00Eoo`@0
00AJEPD000MJEP04001JEUYFFUH30006FUH00`00FUIJEP0<FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000<Ool60002
FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<goo000`Ool00`00
FUIJEP05FUH00`00Oomoo`08Ool90006FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF30000eYF00L005YF001JEP00FUH0000:Ool30006FUH0
0`00FUIJEP04FUH01000FUIJEP00=7oo000aOol00`00FUIJEP04FUH3000<Ool70004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0`0015YF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool037oo10000UYF00<005YFFUH00eYF00@005YF
000003Eoo`00<Woo00<005YFFUH00UYF00D005YFFUIJEP0000aoo`<000=oo`h000AJEP03001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00004Goo2P00=goo000cOol20002FUH00`00FUIJEP02FUH00`00Oomoo`0M
Ool20002FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF009JEP8005=oo`00=Goo0P001UYF0P007goo0P000eYF00<007oo
00002EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH30005FUH00`00FUIJEP02FUH2001COol0
03Ioo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF009JEP04001oo`000007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20002FUH20008FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005=oo`00=goo0P001UYF
0`007Woo00D005YFFUIJEP0000=oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<000IJEP8000AJEP04
001JEUYFFUH2001DOol003Uoo`03001JEUYF009JEP04001JEUYFFUH2000LOol00`00FUIJEP020005
Ool30002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEP0015YF00@005YFFUH0009JEP04001JEUYF
FUH2001EOol003Yoo`05001JEUYFFUH00005FUH2000KOol01000FUH0000027oo10002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP05001JEUYFFUH00003FUH01000FUH005YF0P00Egoo000kOol30008FUH3000HOol2
00000eYF001oo`0;Ool40005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUH000040004FUH00`00FUIJEP03FUH30005FUH3001IOol003eoo`03001JEUYF
00MJEP04001JEP00000GOol00`00FUH0000@Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH800000goo0000000;0006FUH00`00Oomoo`1HOol003ioo`8000IJ
EP03001JEUYF009JEP<001Aoo`8001Eoo`L000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@000=oo`D000ioo`03001JEUYF00=JEP8005Uoo`00@7oo0P0015YF00<005YFFUH01EYF0`00
4Goo0P0077oo3@001UYF00<005YFFUH015YF20001goo1@003goo00L005YFFUIJEP00FUH0001IOol0
049oo`800003FUH005YF00QJEP03001JEP0000<000]oo`<002Yoo`d000=JEP03001oogoo00Yoo`<0
015oo`04001JEUYF0002FUH00`00Oomoo`1FOol004Aoo`<000MJEP03001JEUYF00AJEP/00003FUH0
000003=oo`8000IJEP8001moo`8000=JEP03001oogoo05Ioo`00Agoo0P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUIJEP0003Eoo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF
009JEP03001oogoo05Eoo`00BGoo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP80
03Ioo`8000EJEP04001JEP00000NOol00`00FUIJEP02001GOol004aoo`D000AJEP03001JEUYF00AJ
EP03001JEP00008003Uoo`8000=JEP04001JEUYFFUH2000LOol00`00FUIJEP02001GOol0055oo`d0
03ioo`<000IJEP8001]oo`80009JEP03001oogoo05Aoo`00WWoo00<005YFFUH01UYF0`006Goo00@0
05YFFUH005Ioo`00Wgoo0P001UYF00<005YFFUH00`005Woo00<005YF0000Egoo002QOol20004FUH0
0`00FUIJEP03FUH3000COol00`00FUH0001GOol00:=oo`800003FUH005YF00QJEPD000eoo`<005Qo
o`00YGoo0`0025YF00<005YFFUH00UYF3@0000=JEP000000F7oo002XOol30005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000FGoo002[Ool300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00FGoo002^Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP02001JOol00;5o
o`@0009JEP03001JEUYF00=JEP04001JEP00001LOol00;Eoo`X005ioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60198 .74661 m .59955 .69082 L .56841 .69031 L p .707 .577 .707 r
F P
0 g
s
.59955 .69082 m .60198 .74661 L .63379 .74458 L p .707 .577 .707 r
F P
0 g
s
.63379 .74458 m .63136 .6888 L .59955 .69082 L p .707 .577 .707 r
F P
0 g
s
.63136 .6888 m .63379 .74458 L .66315 .74021 L p .707 .577 .707 r
F P
0 g
s
.66315 .74021 m .66072 .68443 L .63136 .6888 L p .707 .577 .707 r
F P
0 g
s
.57084 .74609 m .56841 .69031 L .54098 .6873 L p .707 .577 .707 r
F P
0 g
s
.56841 .69031 m .57084 .74609 L .60198 .74661 L p .707 .577 .707 r
F P
0 g
s
.66072 .68443 m .66315 .74021 L .68719 .73393 L p .707 .577 .707 r
F P
0 g
s
.68719 .73393 m .68476 .67814 L .66072 .68443 L p .707 .577 .707 r
F P
0 g
s
.59942 .8105 m .60324 .77406 L .57223 .76893 L p .707 .577 .707 r
F P
0 g
s
.60324 .77406 m .59942 .8105 L .6311 .81264 L p .707 .577 .707 r
F P
0 g
s
.6311 .81264 m .63492 .77621 L .60324 .77406 L p .707 .577 .707 r
F P
0 g
s
.54098 .6873 m .54341 .74309 L .57084 .74609 L p .707 .577 .707 r
F P
0 g
s
.54341 .74309 m .54098 .6873 L .51995 .68209 L p .707 .577 .707 r
F P
0 g
s
.63492 .77621 m .6311 .81264 L .66036 .81158 L p .707 .577 .707 r
F P
0 g
s
.66036 .81158 m .66418 .77514 L .63492 .77621 L p .707 .577 .707 r
F P
0 g
s
.56841 .80536 m .57223 .76893 L .54494 .7613 L p .707 .577 .707 r
F P
0 g
s
.57223 .76893 m .56841 .80536 L .59942 .8105 L p .707 .577 .707 r
F P
0 g
s
.68476 .67814 m .68719 .73393 L .70356 .72634 L p .707 .577 .707 r
F P
0 g
s
.70356 .72634 m .70112 .67055 L .68476 .67814 L p .707 .577 .707 r
F P
0 g
s
.51995 .68209 m .52239 .73788 L .54341 .74309 L p .707 .577 .707 r
F P
0 g
s
.66418 .77514 m .66036 .81158 L .68434 .80741 L p .707 .577 .707 r
F P
0 g
s
.68434 .80741 m .68816 .77098 L .66418 .77514 L p .707 .577 .707 r
F P
0 g
s
.54494 .7613 m .54112 .79773 L .56841 .80536 L p .707 .577 .707 r
F P
0 g
s
.54112 .79773 m .54494 .7613 L .52404 .75193 L p .707 .577 .707 r
F P
0 g
s
.59097 .85797 m .59565 .8406 L .5655 .83083 L p .707 .577 .707 r
F P
0 g
s
.59565 .8406 m .59097 .85797 L .62188 .86429 L p .707 .577 .707 r
F P
0 g
s
.62188 .86429 m .62656 .84692 L .59565 .8406 L p .707 .577 .707 r
F P
0 g
s
.52239 .73788 m .51995 .68209 L .50738 .6752 L p .707 .577 .707 r
F P
0 g
s
.56082 .84821 m .5655 .83083 L .53907 .81857 L p .707 .577 .707 r
F P
0 g
s
.5655 .83083 m .56082 .84821 L .59097 .85797 L p .707 .577 .707 r
F P
0 g
s
.62656 .84692 m .62188 .86429 L .65053 .86655 L p .707 .577 .707 r
F P
0 g
s
.65053 .86655 m .65521 .84917 L .62656 .84692 L p .707 .577 .707 r
F P
0 g
s
.52404 .75193 m .52022 .78836 L .54112 .79773 L p .707 .577 .707 r
F P
0 g
s
.53907 .81857 m .53439 .83595 L .56082 .84821 L p .707 .577 .707 r
F P
0 g
s
.68816 .77098 m .68434 .80741 L .70068 .80056 L p .707 .577 .707 r
F P
0 g
s
.70068 .80056 m .7045 .76413 L .68816 .77098 L p .707 .577 .707 r
F P
0 g
s
.53439 .83595 m .53907 .81857 L .51894 .80502 L p .707 .577 .707 r
F P
0 g
s
.70112 .67055 m .70356 .72634 L .71064 .71819 L p .707 .577 .707 r
F P
0 g
s
.71064 .71819 m .70821 .66241 L .70112 .67055 L p .707 .577 .707 r
F P
0 g
s
.50738 .6752 m .50982 .73099 L .52239 .73788 L p .707 .577 .707 r
F P
0 g
s
.65521 .84917 m .65053 .86655 L .67411 .86451 L p .707 .577 .707 r
F P
0 g
s
.67411 .86451 m .67879 .84714 L .65521 .84917 L p .707 .577 .707 r
F P
0 g
s
.52022 .78836 m .52404 .75193 L .51157 .74173 L p .707 .577 .707 r
F P
0 g
s
.51894 .80502 m .51426 .8224 L .53439 .83595 L p .707 .577 .707 r
F P
0 g
s
.50982 .73099 m .50738 .6752 L .5045 .6673 L p .707 .577 .707 r
F P
0 g
s
.51157 .74173 m .50775 .77816 L .52022 .78836 L p .707 .577 .707 r
F P
0 g
s
.51426 .8224 m .51894 .80502 L .50709 .79151 L p .707 .577 .707 r
F P
0 g
s
.67879 .84714 m .67411 .86451 L .69031 .85839 L p .707 .577 .707 r
F P
0 g
s
.69031 .85839 m .695 .84101 L .67879 .84714 L p .707 .577 .707 r
F P
0 g
s
.7045 .76413 m .70068 .80056 L .70779 .79168 L p .707 .577 .707 r
F P
0 g
s
.70779 .79168 m .71161 .75525 L .7045 .76413 L p .707 .577 .707 r
F P
0 g
s
.50709 .79151 m .5024 .80888 L .51426 .8224 L p .707 .577 .707 r
F P
0 g
s
.5045 .6673 m .50693 .72308 L .50982 .73099 L p .707 .577 .707 r
F P
0 g
s
.70821 .66241 m .71064 .71819 L .70776 .71029 L p .707 .577 .707 r
F P
0 g
s
.70776 .71029 m .70533 .6545 L .70821 .66241 L p .707 .577 .707 r
F P
0 g
s
.50775 .77816 m .51157 .74173 L .50875 .7317 L p .707 .577 .707 r
F P
0 g
s
.47998 .82206 m .4968 .32228 L .45281 .3181 L p .707 .577 .707 r
F P
0 g
s
.50875 .7317 m .50493 .76813 L .50775 .77816 L p .707 .577 .707 r
F P
0 g
s
.50693 .72308 m .5045 .6673 L .51159 .65915 L p .707 .577 .707 r
F P
0 g
s
.5024 .80888 m .50709 .79151 L .50466 .77935 L p .707 .577 .707 r
F P
0 g
s
.50466 .77935 m .49998 .79672 L .5024 .80888 L p .707 .577 .707 r
F P
0 g
s
.51159 .65915 m .51402 .71494 L .50693 .72308 L p .707 .577 .707 r
F P
0 g
s
.50493 .76813 m .50875 .7317 L .51586 .72282 L p .707 .577 .707 r
F P
0 g
s
.51586 .72282 m .51204 .75925 L .50493 .76813 L p .707 .577 .707 r
F P
0 g
s
.51402 .71494 m .51159 .65915 L .52795 .65156 L p .707 .577 .707 r
F P
0 g
s
.49998 .79672 m .50466 .77935 L .51191 .76974 L p .707 .577 .707 r
F P
0 g
s
.51191 .76974 m .50722 .78711 L .49998 .79672 L p .707 .577 .707 r
F P
0 g
s
.52795 .65156 m .53039 .70735 L .51402 .71494 L p .707 .577 .707 r
F P
0 g
s
.51204 .75925 m .51586 .72282 L .5322 .71597 L p .707 .577 .707 r
F P
0 g
s
.5322 .71597 m .52838 .7524 L .51204 .75925 L p .707 .577 .707 r
F P
0 g
s
.50722 .78711 m .51191 .76974 L .52811 .76362 L p .707 .577 .707 r
F P
0 g
s
.52811 .76362 m .52343 .78099 L .50722 .78711 L p .707 .577 .707 r
F P
0 g
s
.4968 .32228 m .47998 .82206 L .5249 .8223 L p .707 .577 .707 r
F P
0 g
s
.53039 .70735 m .52795 .65156 L .55199 .64528 L p .707 .577 .707 r
F P
0 g
s
.52343 .78099 m .52811 .76362 L .55169 .76158 L p .707 .577 .707 r
F P
0 g
s
.55169 .76158 m .54701 .77896 L .52343 .78099 L p .707 .577 .707 r
F P
0 g
s
.5249 .8223 m .54172 .32252 L .4968 .32228 L p .707 .577 .707 r
F P
0 g
s
.55199 .64528 m .55442 .70106 L .53039 .70735 L p .707 .577 .707 r
F P
0 g
s
.52838 .7524 m .5322 .71597 L .55618 .7118 L p .707 .577 .707 r
F P
0 g
s
.55442 .70106 m .55199 .64528 L .58135 .64091 L p .707 .577 .707 r
F P
0 g
s
.55618 .7118 m .55236 .74824 L .52838 .7524 L p .707 .577 .707 r
F P
0 g
s
.58135 .64091 m .58378 .69669 L .55442 .70106 L p .707 .577 .707 r
F P
0 g
s
.55236 .74824 m .55618 .7118 L .58544 .71074 L p .707 .577 .707 r
F P
0 g
s
.58544 .71074 m .58162 .74717 L .55236 .74824 L p .707 .577 .707 r
F P
0 g
s
.54701 .77896 m .55169 .76158 L .58034 .76383 L p .707 .577 .707 r
F P
0 g
s
.58034 .76383 m .57566 .78121 L .54701 .77896 L p .707 .577 .707 r
F P
0 g
s
.54172 .32252 m .5249 .8223 L .56636 .8186 L p .707 .577 .707 r
F P
0 g
s
.56636 .8186 m .58318 .31882 L .54172 .32252 L p .707 .577 .707 r
F P
0 g
s
.695 .84101 m .69031 .85839 L .69756 .84878 L p .707 .577 .707 r
F P
0 g
s
.69756 .84878 m .70224 .8314 L .695 .84101 L p .707 .577 .707 r
F P
0 g
s
.43599 .81788 m .45281 .3181 L .41407 .31041 L p .707 .577 .707 r
F P
0 g
s
.45281 .3181 m .43599 .81788 L .47998 .82206 L p .707 .577 .707 r
F P
0 g
s
.71161 .75525 m .70779 .79168 L .70497 .78165 L p .707 .577 .707 r
F P
0 g
s
.70497 .78165 m .70879 .74522 L .71161 .75525 L p .707 .577 .707 r
F P
0 g
s
.70533 .6545 m .70776 .71029 L .69519 .70339 L p .707 .577 .707 r
F P
0 g
s
.69519 .70339 m .69276 .64761 L .70533 .6545 L p .707 .577 .707 r
F P
0 g
s
.58378 .69669 m .58135 .64091 L .61316 .63888 L p .707 .577 .707 r
F P
0 g
s
.61316 .63888 m .61559 .69467 L .58378 .69669 L p .707 .577 .707 r
F P
0 g
s
.58162 .74717 m .58544 .71074 L .61712 .71288 L p .707 .577 .707 r
F P
0 g
s
.61712 .71288 m .6133 .74932 L .58162 .74717 L p .707 .577 .707 r
F P
0 g
s
.57566 .78121 m .58034 .76383 L .61125 .77015 L p .707 .577 .707 r
F P
0 g
s
.61125 .77015 m .60657 .78753 L .57566 .78121 L p .707 .577 .707 r
F P
0 g
s
.58318 .31882 m .56636 .8186 L .60031 .81131 L p .707 .577 .707 r
F P
0 g
s
.60031 .81131 m .61713 .31153 L .58318 .31882 L p .707 .577 .707 r
F P
0 g
s
.39725 .81019 m .41407 .31041 L .38437 .29996 L p .707 .577 .707 r
F P
0 g
s
.41407 .31041 m .39725 .81019 L .43599 .81788 L p .707 .577 .707 r
F P
0 g
s
.25898 .714 m .25654 .65822 L .2254 .6577 L p .707 .577 .707 r
F P
0 g
s
.25654 .65822 m .25898 .714 L .29078 .71198 L p .707 .577 .707 r
F P
0 g
s
.29078 .71198 m .28835 .65619 L .25654 .65822 L p .707 .577 .707 r
F P
0 g
s
.28835 .65619 m .29078 .71198 L .32014 .70761 L p .707 .577 .707 r
F P
0 g
s
.32014 .70761 m .31771 .65182 L .28835 .65619 L p .707 .577 .707 r
F P
0 g
s
.70224 .8314 m .69756 .84878 L .69513 .83662 L p .707 .577 .707 r
F P
0 g
s
.69513 .83662 m .69982 .81925 L .70224 .8314 L p .707 .577 .707 r
F P
0 g
s
.22783 .71349 m .2254 .6577 L .19797 .6547 L p .707 .577 .707 r
F P
0 g
s
.2254 .6577 m .22783 .71349 L .25898 .714 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70879 .74522 m .70497 .78165 L .6925 .77145 L p .707 .577 .707 r
F P
0 g
s
.6925 .77145 m .69632 .73502 L .70879 .74522 L p .707 .577 .707 r
F P
0 g
s
.31771 .65182 m .32014 .70761 L .34418 .70132 L p .707 .577 .707 r
F P
0 g
s
.34418 .70132 m .34175 .64554 L .31771 .65182 L p .707 .577 .707 r
F P
0 g
s
.69276 .64761 m .69519 .70339 L .67416 .69819 L p .707 .577 .707 r
F P
0 g
s
.67416 .69819 m .67173 .6424 L .69276 .64761 L p .707 .577 .707 r
F P
0 g
s
.6443 .6394 m .64674 .69518 L .61559 .69467 L p .707 .577 .707 r
F P
0 g
s
.61559 .69467 m .61316 .63888 L .6443 .6394 L p .707 .577 .707 r
F P
0 g
s
.64813 .71802 m .64431 .75445 L .6133 .74932 L p .707 .577 .707 r
F P
0 g
s
.6133 .74932 m .61712 .71288 L .64813 .71802 L p .707 .577 .707 r
F P
0 g
s
.6414 .77992 m .63671 .7973 L .60657 .78753 L p .707 .577 .707 r
F P
0 g
s
.60657 .78753 m .61125 .77015 L .6414 .77992 L p .707 .577 .707 r
F P
0 g
s
.61713 .31153 m .60031 .81131 L .62341 .80114 L p .707 .577 .707 r
F P
0 g
s
.62341 .80114 m .64023 .30136 L .61713 .31153 L p .707 .577 .707 r
F P
0 g
s
.19797 .6547 m .20041 .71048 L .22783 .71349 L p .707 .577 .707 r
F P
0 g
s
.25641 .7794 m .26023 .74297 L .22922 .73784 L p .707 .577 .707 r
F P
0 g
s
.26023 .74297 m .25641 .7794 L .28809 .78155 L p .707 .577 .707 r
F P
0 g
s
.28809 .78155 m .29191 .74511 L .26023 .74297 L p .707 .577 .707 r
F P
0 g
s
.20041 .71048 m .19797 .6547 L .17694 .64949 L p .707 .577 .707 r
F P
0 g
s
.29191 .74511 m .28809 .78155 L .31735 .78048 L p .707 .577 .707 r
F P
0 g
s
.31735 .78048 m .32117 .74405 L .29191 .74511 L p .707 .577 .707 r
F P
0 g
s
.2254 .77427 m .22922 .73784 L .20193 .73021 L p .707 .577 .707 r
F P
0 g
s
.22922 .73784 m .2254 .77427 L .25641 .7794 L p .707 .577 .707 r
F P
0 g
s
.35811 .63795 m .36055 .69373 L .36764 .68559 L p .707 .577 .707 r
F P
0 g
s
.36764 .68559 m .3652 .6298 L .35811 .63795 L p .707 .577 .707 r
F P
0 g
s
.36478 .76059 m .3686 .72416 L .36149 .73303 L p .707 .577 .707 r
F P
0 g
s
.3652 .6298 m .36764 .68559 L .36475 .67768 L p .707 .577 .707 r
F P
0 g
s
.36149 .73303 m .35767 .76947 L .36478 .76059 L p .707 .577 .707 r
F P
0 g
s
.3686 .72416 m .36478 .76059 L .36196 .75056 L p .707 .577 .707 r
F P
0 g
s
.36196 .75056 m .36578 .71413 L .3686 .72416 L p .707 .577 .707 r
F P
0 g
s
.36755 .79974 m .38437 .29996 L .36661 .28776 L p .707 .577 .707 r
F P
0 g
s
.38437 .29996 m .36755 .79974 L .39725 .81019 L p .707 .577 .707 r
F P
0 g
s
.34175 .64554 m .34418 .70132 L .36055 .69373 L p .707 .577 .707 r
F P
0 g
s
.36055 .69373 m .35811 .63795 L .34175 .64554 L p .707 .577 .707 r
F P
0 g
s
.69982 .81925 m .69513 .83662 L .68328 .82311 L p .707 .577 .707 r
F P
0 g
s
.68328 .82311 m .68796 .80573 L .69982 .81925 L p .707 .577 .707 r
F P
0 g
s
.17694 .64949 m .17938 .70528 L .20041 .71048 L p .707 .577 .707 r
F P
0 g
s
.32117 .74405 m .31735 .78048 L .34133 .77632 L p .707 .577 .707 r
F P
0 g
s
.34133 .77632 m .34515 .73989 L .32117 .74405 L p .707 .577 .707 r
F P
0 g
s
.20193 .73021 m .19811 .76664 L .2254 .77427 L p .707 .577 .707 r
F P
0 g
s
.69632 .73502 m .6925 .77145 L .67159 .76208 L p .707 .577 .707 r
F P
0 g
s
.67159 .76208 m .67542 .72565 L .69632 .73502 L p .707 .577 .707 r
F P
0 g
s
.67173 .6424 m .67416 .69819 L .64674 .69518 L p .707 .577 .707 r
F P
0 g
s
.64674 .69518 m .6443 .6394 L .67173 .6424 L p .707 .577 .707 r
F P
0 g
s
.24796 .82279 m .25264 .80542 L .2225 .79565 L p .707 .577 .707 r
F P
0 g
s
.25264 .80542 m .24796 .82279 L .27887 .82911 L p .707 .577 .707 r
F P
0 g
s
.27887 .82911 m .28355 .81174 L .25264 .80542 L p .707 .577 .707 r
F P
0 g
s
.19811 .76664 m .20193 .73021 L .18103 .72084 L p .707 .577 .707 r
F P
0 g
s
.21781 .81303 m .2225 .79565 L .19606 .78339 L p .707 .577 .707 r
F P
0 g
s
.2225 .79565 m .21781 .81303 L .24796 .82279 L p .707 .577 .707 r
F P
0 g
s
.17938 .70528 m .17694 .64949 L .16437 .6426 L p .707 .577 .707 r
F P
0 g
s
.28355 .81174 m .27887 .82911 L .30752 .83137 L p .707 .577 .707 r
F P
0 g
s
.30752 .83137 m .3122 .81399 L .28355 .81174 L p .707 .577 .707 r
F P
0 g
s
.19606 .78339 m .19138 .80077 L .21781 .81303 L p .707 .577 .707 r
F P
0 g
s
.18103 .72084 m .17721 .75727 L .19811 .76664 L p .707 .577 .707 r
F P
0 g
s
.64023 .30136 m .62341 .80114 L .63342 .7891 L p .707 .577 .707 r
F P
0 g
s
.63342 .7891 m .65023 .28932 L .64023 .30136 L p .707 .577 .707 r
F P
0 g
s
.34515 .73989 m .34133 .77632 L .35767 .76947 L p .707 .577 .707 r
F P
0 g
s
.35767 .76947 m .36149 .73303 L .34515 .73989 L p .707 .577 .707 r
F P
0 g
s
.19138 .80077 m .19606 .78339 L .17593 .76984 L p .707 .577 .707 r
F P
0 g
s
.16437 .6426 m .16681 .69838 L .17938 .70528 L p .707 .577 .707 r
F P
0 g
s
.3122 .81399 m .30752 .83137 L .3311 .82933 L p .707 .577 .707 r
F P
0 g
s
.3311 .82933 m .33578 .81196 L .3122 .81399 L p .707 .577 .707 r
F P
0 g
s
.67542 .72565 m .67159 .76208 L .64431 .75445 L p .707 .577 .707 r
F P
0 g
s
.64431 .75445 m .64813 .71802 L .67542 .72565 L p .707 .577 .707 r
F P
0 g
s
.68796 .80573 m .68328 .82311 L .66315 .80956 L p .707 .577 .707 r
F P
0 g
s
.66315 .80956 m .66783 .79218 L .68796 .80573 L p .707 .577 .707 r
F P
0 g
s
.17721 .75727 m .18103 .72084 L .16856 .71064 L p .707 .577 .707 r
F P
0 g
s
.17593 .76984 m .17125 .78722 L .19138 .80077 L p .707 .577 .707 r
F P
0 g
s
.36232 .6219 m .36475 .67768 L .35218 .67079 L p .707 .577 .707 r
F P
0 g
s
.35218 .67079 m .34975 .61501 L .36232 .6219 L p .707 .577 .707 r
F P
0 g
s
.36578 .71413 m .36196 .75056 L .35413 .74415 L p .707 .577 .707 r
F P
0 g
s
.35413 .74415 m .34949 .74036 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.35433 .73257 m .36578 .71413 L .35413 .74415 L .707 .577 .707 r
F
.36661 .28776 m .36253 .27501 L p .36154 .31489 L F P
0 g
s
.34949 .74036 m .35331 .70393 L .3548 .70515 L p .707 .577 .707 r
F P
0 g
s
.3548 .70515 m .36578 .71413 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.34949 .74036 m .3548 .70515 L .35433 .73257 L .707 .577 .707 r
F
.34975 .61501 m .35218 .67079 L .33115 .66559 L p F P
0 g
s
.35213 .80144 m .34027 .78793 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35681 .78407 m .35403 .79437 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35403 .79437 m .35213 .80144 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .34495 .77055 L .35386 .7807 L p .707 .577 .707 r
F P
0 g
s
.35386 .7807 m .35681 .78407 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .35386 .7807 L .35391 .78474 L .707 .577 .707 r
F
.36191 .29349 m .35161 .59958 L p .36154 .31489 L F P
0 g
s
.35331 .70393 m .34949 .74036 L .32859 .73099 L p .707 .577 .707 r
F P
0 g
s
.32859 .73099 m .33241 .69455 L .35331 .70393 L p .707 .577 .707 r
F P
0 g
s
.35161 .59958 m .34571 .77479 L p .35165 .60243 L .707 .577 .707 r
F P
0 g
s
.36154 .31489 m .35161 .59958 L .35165 .60243 L .707 .577 .707 r
F
.34571 .77479 m .34979 .78754 L p .35256 .67613 L F P
0 g
s
.35256 .67613 m .36154 .31489 L .35165 .60243 L .707 .577 .707 r
F
.35256 .67613 m .35165 .60243 L .34571 .77479 L F
.36253 .27501 m .36191 .29349 L p .36154 .31489 L F P
0 g
s
.34979 .78754 m .35716 .56852 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.35716 .56852 m .36661 .28776 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.36475 .67768 m .36232 .6219 L .3652 .6298 L p .707 .577 .707 r
F P
0 g
s
.35213 .80144 m .35681 .78407 L .35923 .79622 L p .707 .577 .707 r
F P
0 g
s
.36661 .28776 m .34979 .78754 L .36755 .79974 L p .707 .577 .707 r
F P
0 g
s
.16681 .69838 m .16437 .6426 L .16149 .63469 L p .707 .577 .707 r
F P
0 g
s
.16856 .71064 m .16474 .74707 L .17721 .75727 L p .707 .577 .707 r
F P
0 g
s
.17125 .78722 m .17593 .76984 L .16408 .75633 L p .707 .577 .707 r
F P
0 g
s
.33578 .81196 m .3311 .82933 L .3473 .82321 L p .707 .577 .707 r
F P
0 g
s
.3473 .82321 m .35199 .80583 L .33578 .81196 L p .707 .577 .707 r
F P
0 g
s
.66783 .79218 m .66315 .80956 L .63671 .7973 L p .707 .577 .707 r
F P
0 g
s
.63671 .7973 m .6414 .77992 L .66783 .79218 L p .707 .577 .707 r
F P
0 g
s
.16408 .75633 m .15939 .7737 L .17125 .78722 L p .707 .577 .707 r
F P
0 g
s
.16149 .63469 m .16392 .69048 L .16681 .69838 L p .707 .577 .707 r
F P
0 g
s
.16474 .74707 m .16856 .71064 L .16574 .70061 L p .707 .577 .707 r
F P
0 g
s
.65023 .28932 m .63342 .7891 L .62934 .77635 L p .707 .577 .707 r
F P
0 g
s
.62934 .77635 m .64616 .27657 L .65023 .28932 L p .707 .577 .707 r
F P
0 g
s
.16574 .70061 m .16192 .73704 L .16474 .74707 L p .707 .577 .707 r
F P
0 g
s
.16392 .69048 m .16149 .63469 L .16858 .62655 L p .707 .577 .707 r
F P
0 g
s
.15939 .7737 m .16408 .75633 L .16165 .74417 L p .707 .577 .707 r
F P
0 g
s
.35199 .80583 m .3473 .82321 L .35455 .8136 L p .707 .577 .707 r
F P
0 g
s
.35455 .8136 m .35923 .79622 L .35199 .80583 L p .707 .577 .707 r
F P
0 g
s
.16165 .74417 m .15697 .76154 L .15939 .7737 L p .707 .577 .707 r
F P
0 g
s
.34571 .77479 m .36253 .27501 L .37254 .26297 L p .707 .577 .707 r
F P
0 g
s
.16858 .62655 m .17101 .68233 L .16392 .69048 L p .707 .577 .707 r
F P
0 g
s
.16192 .73704 m .16574 .70061 L .17285 .69173 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17285 .69173 m .16903 .72816 L .16192 .73704 L p .707 .577 .707 r
F P
0 g
s
.17101 .68233 m .16858 .62655 L .18494 .61896 L p .707 .577 .707 r
F P
0 g
s
.15697 .76154 m .16165 .74417 L .1689 .73456 L p .707 .577 .707 r
F P
0 g
s
.35923 .79622 m .35455 .8136 L .35213 .80144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64616 .27657 m .62934 .77635 L .61158 .76416 L p .707 .577 .707 r
F P
0 g
s
.61158 .76416 m .6284 .26438 L .64616 .27657 L p .707 .577 .707 r
F P
0 g
s
.1689 .73456 m .16421 .75193 L .15697 .76154 L p .707 .577 .707 r
F P
0 g
s
.33115 .66559 m .32872 .6098 L .34975 .61501 L p .707 .577 .707 r
F P
0 g
s
.18494 .61896 m .18738 .67475 L .17101 .68233 L p .707 .577 .707 r
F P
0 g
s
.16903 .72816 m .17285 .69173 L .18919 .68487 L p .707 .577 .707 r
F P
0 g
s
.35572 .76275 m .37254 .26297 L .39564 .2528 L p .707 .577 .707 r
F P
0 g
s
.37254 .26297 m .35572 .76275 L .34571 .77479 L p .707 .577 .707 r
F P
0 g
s
.18738 .67475 m .18494 .61896 L .20898 .61267 L p .707 .577 .707 r
F P
0 g
s
.18919 .68487 m .18537 .72131 L .16903 .72816 L p .707 .577 .707 r
F P
0 g
s
.16421 .75193 m .1689 .73456 L .1851 .72844 L p .707 .577 .707 r
F P
0 g
s
.1851 .72844 m .18042 .74581 L .16421 .75193 L p .707 .577 .707 r
F P
0 g
s
.32872 .6098 m .33115 .66559 L .30373 .66258 L p .707 .577 .707 r
F P
0 g
s
.30373 .66258 m .30129 .60679 L .32872 .6098 L p .707 .577 .707 r
F P
0 g
s
.20898 .61267 m .21141 .66846 L .18738 .67475 L p .707 .577 .707 r
F P
0 g
s
.18537 .72131 m .18919 .68487 L .21317 .68071 L p .707 .577 .707 r
F P
0 g
s
.6284 .26438 m .61158 .76416 L .58188 .7537 L p .707 .577 .707 r
F P
0 g
s
.58188 .7537 m .59869 .25392 L .6284 .26438 L p .707 .577 .707 r
F P
0 g
s
.21141 .66846 m .20898 .61267 L .23834 .6083 L p .707 .577 .707 r
F P
0 g
s
.30129 .60679 m .30373 .66258 L .27258 .66206 L p .707 .577 .707 r
F P
0 g
s
.27258 .66206 m .27015 .60628 L .30129 .60679 L p .707 .577 .707 r
F P
0 g
s
.21317 .68071 m .20935 .71714 L .18537 .72131 L p .707 .577 .707 r
F P
0 g
s
.18042 .74581 m .1851 .72844 L .20868 .7264 L p .707 .577 .707 r
F P
0 g
s
.39564 .2528 m .37882 .75258 L .35572 .76275 L p .707 .577 .707 r
F P
0 g
s
.37882 .75258 m .39564 .2528 L .42959 .24551 L p .707 .577 .707 r
F P
0 g
s
.24078 .66409 m .23834 .6083 L .27015 .60628 L p .707 .577 .707 r
F P
0 g
s
.23834 .6083 m .24078 .66409 L .21141 .66846 L p .707 .577 .707 r
F P
0 g
s
.34495 .77055 m .34027 .78793 L .32014 .77438 L p .707 .577 .707 r
F P
0 g
s
.32014 .77438 m .32482 .757 L .34495 .77055 L p .707 .577 .707 r
F P
0 g
s
.33241 .69455 m .32859 .73099 L .3013 .72336 L p .707 .577 .707 r
F P
0 g
s
.3013 .72336 m .30512 .68693 L .33241 .69455 L p .707 .577 .707 r
F P
0 g
s
.73919 .65457 m .73676 .59878 L .70561 .59827 L p .707 .577 .707 r
F P
0 g
s
.73676 .59878 m .73919 .65457 L .771 .65254 L p .707 .577 .707 r
F P
0 g
s
.771 .65254 m .76856 .59676 L .73676 .59878 L p .707 .577 .707 r
F P
0 g
s
.27015 .60628 m .27258 .66206 L .24078 .66409 L p .707 .577 .707 r
F P
0 g
s
.76856 .59676 m .771 .65254 L .80036 .64817 L p .707 .577 .707 r
F P
0 g
s
.80036 .64817 m .79792 .59239 L .76856 .59676 L p .707 .577 .707 r
F P
0 g
s
.20868 .7264 m .204 .74378 L .18042 .74581 L p .707 .577 .707 r
F P
0 g
s
.20935 .71714 m .21317 .68071 L .24243 .67965 L p .707 .577 .707 r
F P
0 g
s
.70805 .65405 m .70561 .59827 L .67819 .59526 L p .707 .577 .707 r
F P
0 g
s
.70561 .59827 m .70805 .65405 L .73919 .65457 L p .707 .577 .707 r
F P
0 g
s
.30512 .68693 m .3013 .72336 L .27029 .71822 L p .707 .577 .707 r
F P
0 g
s
.27029 .71822 m .27411 .68179 L .30512 .68693 L p .707 .577 .707 r
F P
0 g
s
.79792 .59239 m .80036 .64817 L .8244 .64189 L p .707 .577 .707 r
F P
0 g
s
.8244 .64189 m .82196 .5861 L .79792 .59239 L p .707 .577 .707 r
F P
0 g
s
.24243 .67965 m .23861 .71608 L .20935 .71714 L p .707 .577 .707 r
F P
0 g
s
.23861 .71608 m .24243 .67965 L .27411 .68179 L p .707 .577 .707 r
F P
0 g
s
.59869 .25392 m .58188 .7537 L .54314 .74601 L p .707 .577 .707 r
F P
0 g
s
.54314 .74601 m .55996 .24623 L .59869 .25392 L p .707 .577 .707 r
F P
0 g
s
.204 .74378 m .20868 .7264 L .23733 .72865 L p .707 .577 .707 r
F P
0 g
s
.32482 .757 m .32014 .77438 L .29371 .76212 L p .707 .577 .707 r
F P
0 g
s
.29371 .76212 m .29839 .74474 L .32482 .757 L p .707 .577 .707 r
F P
0 g
s
.27411 .68179 m .27029 .71822 L .23861 .71608 L p .707 .577 .707 r
F P
0 g
s
.73662 .71846 m .74044 .68203 L .70944 .67689 L p .707 .577 .707 r
F P
0 g
s
.74044 .68203 m .73662 .71846 L .7683 .7206 L p .707 .577 .707 r
F P
0 g
s
.7683 .7206 m .77212 .68417 L .74044 .68203 L p .707 .577 .707 r
F P
0 g
s
.67819 .59526 m .68062 .65105 L .70805 .65405 L p .707 .577 .707 r
F P
0 g
s
.68062 .65105 m .67819 .59526 L .65716 .59006 L p .707 .577 .707 r
F P
0 g
s
.23733 .72865 m .23265 .74603 L .204 .74378 L p .707 .577 .707 r
F P
0 g
s
.77212 .68417 m .7683 .7206 L .79757 .71954 L p .707 .577 .707 r
F P
0 g
s
.79757 .71954 m .80139 .68311 L .77212 .68417 L p .707 .577 .707 r
F P
0 g
s
.41277 .74529 m .42959 .24551 L .47105 .24181 L p .707 .577 .707 r
F P
0 g
s
.42959 .24551 m .41277 .74529 L .37882 .75258 L p .707 .577 .707 r
F P
0 g
s
.70562 .71332 m .70944 .67689 L .68215 .66926 L p .707 .577 .707 r
F P
0 g
s
.70944 .67689 m .70562 .71332 L .73662 .71846 L p .707 .577 .707 r
F P
0 g
s
.23265 .74603 m .23733 .72865 L .26824 .73497 L p .707 .577 .707 r
F P
0 g
s
.29839 .74474 m .29371 .76212 L .26356 .75235 L p .707 .577 .707 r
F P
0 g
s
.26356 .75235 m .26824 .73497 L .29839 .74474 L p .707 .577 .707 r
F P
0 g
s
.82196 .5861 m .8244 .64189 L .84076 .6343 L p .707 .577 .707 r
F P
0 g
s
.84076 .6343 m .83833 .57851 L .82196 .5861 L p .707 .577 .707 r
F P
0 g
s
.26824 .73497 m .26356 .75235 L .23265 .74603 L p .707 .577 .707 r
F P
0 g
s
.65716 .59006 m .65959 .64584 L .68062 .65105 L p .707 .577 .707 r
F P
0 g
s
.80139 .68311 m .79757 .71954 L .82154 .71537 L p .707 .577 .707 r
F P
0 g
s
.82154 .71537 m .82536 .67894 L .80139 .68311 L p .707 .577 .707 r
F P
0 g
s
.55996 .24623 m .54314 .74601 L .49915 .74184 L p .707 .577 .707 r
F P
0 g
s
.49915 .74184 m .51597 .24206 L .55996 .24623 L p .707 .577 .707 r
F P
0 g
s
.68215 .66926 m .67833 .7057 L .70562 .71332 L p .707 .577 .707 r
F P
0 g
s
.67833 .7057 m .68215 .66926 L .66124 .65989 L p .707 .577 .707 r
F P
0 g
s
.72817 .76594 m .73286 .74856 L .70271 .73879 L p .707 .577 .707 r
F P
0 g
s
.73286 .74856 m .72817 .76594 L .75908 .77225 L p .707 .577 .707 r
F P
0 g
s
.75908 .77225 m .76377 .75488 L .73286 .74856 L p .707 .577 .707 r
F P
0 g
s
.45423 .74159 m .46156 .52368 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.47105 .24181 m .45423 .74159 L .41277 .74529 L p .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .45838 .65201 L .43489 .65287 L p .707 .577 .707 r
F P
0 g
s
.43489 .65287 m .42911 .65307 L p .43356 .65926 L .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .43489 .65287 L .43356 .65926 L .707 .577 .707 r
F
.47105 .24181 m .51597 .24206 L p .51038 .28729 L F P
0 g
s
.46156 .52368 m .47105 .24181 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.65959 .64584 m .65716 .59006 L .64459 .58316 L p .707 .577 .707 r
F P
0 g
s
.69803 .75617 m .70271 .73879 L .67628 .72653 L p .707 .577 .707 r
F P
0 g
s
.70271 .73879 m .69803 .75617 L .72817 .76594 L p .707 .577 .707 r
F P
0 g
s
.51597 .24206 m .49915 .74184 L .45423 .74159 L p .707 .577 .707 r
F P
0 g
s
.76377 .75488 m .75908 .77225 L .78773 .77451 L p .707 .577 .707 r
F P
0 g
s
.78773 .77451 m .79241 .75713 L .76377 .75488 L p .707 .577 .707 r
F P
0 g
s
.66124 .65989 m .65742 .69632 L .67833 .7057 L p .707 .577 .707 r
F P
0 g
s
.67628 .72653 m .67159 .74391 L .69803 .75617 L p .707 .577 .707 r
F P
0 g
s
.82536 .67894 m .82154 .71537 L .83788 .70852 L p .707 .577 .707 r
F P
0 g
s
.83788 .70852 m .84171 .67209 L .82536 .67894 L p .707 .577 .707 r
F P
0 g
s
.67159 .74391 m .67628 .72653 L .65615 .71298 L p .707 .577 .707 r
F P
0 g
s
.83833 .57851 m .84076 .6343 L .84785 .62615 L p .707 .577 .707 r
F P
0 g
s
.84785 .62615 m .84542 .57037 L .83833 .57851 L p .707 .577 .707 r
F P
0 g
s
.64459 .58316 m .64702 .63895 L .65959 .64584 L p .707 .577 .707 r
F P
0 g
s
.79241 .75713 m .78773 .77451 L .81131 .77247 L p .707 .577 .707 r
F P
0 g
s
.81131 .77247 m .81599 .7551 L .79241 .75713 L p .707 .577 .707 r
F P
0 g
s
.65742 .69632 m .66124 .65989 L .64877 .64969 L p .707 .577 .707 r
F P
0 g
s
.65615 .71298 m .65146 .73036 L .67159 .74391 L p .707 .577 .707 r
F P
0 g
s
.64702 .63895 m .64459 .58316 L .6417 .57526 L p .707 .577 .707 r
F P
0 g
s
.64877 .64969 m .64495 .68612 L .65742 .69632 L p .707 .577 .707 r
F P
0 g
s
.65146 .73036 m .65615 .71298 L .64429 .69947 L p .707 .577 .707 r
F P
0 g
s
.81599 .7551 m .81131 .77247 L .82752 .76635 L p .707 .577 .707 r
F P
0 g
s
.82752 .76635 m .8322 .74898 L .81599 .7551 L p .707 .577 .707 r
F P
0 g
s
.84171 .67209 m .83788 .70852 L .84499 .69964 L p .707 .577 .707 r
F P
0 g
s
.84499 .69964 m .84881 .66321 L .84171 .67209 L p .707 .577 .707 r
F P
0 g
s
.64429 .69947 m .63961 .71684 L .65146 .73036 L p .707 .577 .707 r
F P
0 g
s
.6417 .57526 m .64414 .63104 L .64702 .63895 L p .707 .577 .707 r
F P
0 g
s
.84542 .57037 m .84785 .62615 L .84497 .61825 L p .707 .577 .707 r
F P
0 g
s
.84497 .61825 m .84253 .56246 L .84542 .57037 L p .707 .577 .707 r
F P
0 g
s
.64495 .68612 m .64877 .64969 L .64595 .63966 L p .707 .577 .707 r
F P
0 g
s
.64595 .63966 m .64213 .67609 L .64495 .68612 L p .707 .577 .707 r
F P
0 g
s
.64414 .63104 m .6417 .57526 L .64879 .56711 L p .707 .577 .707 r
F P
0 g
s
.63961 .71684 m .64429 .69947 L .64186 .68731 L p .707 .577 .707 r
F P
0 g
s
.8322 .74898 m .82752 .76635 L .83476 .75674 L p .707 .577 .707 r
F P
0 g
s
.83476 .75674 m .83945 .73937 L .8322 .74898 L p .707 .577 .707 r
F P
0 g
s
.64186 .68731 m .63718 .70469 L .63961 .71684 L p .707 .577 .707 r
F P
0 g
s
.84881 .66321 m .84499 .69964 L .84218 .68961 L p .707 .577 .707 r
F P
0 g
s
.84218 .68961 m .846 .65318 L .84881 .66321 L p .707 .577 .707 r
F P
0 g
s
.64879 .56711 m .65122 .6229 L .64414 .63104 L p .707 .577 .707 r
F P
0 g
s
.84253 .56246 m .84497 .61825 L .8324 .61136 L p .707 .577 .707 r
F P
0 g
s
.8324 .61136 m .82996 .55557 L .84253 .56246 L p .707 .577 .707 r
F P
0 g
s
.64213 .67609 m .64595 .63966 L .65306 .63078 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39618 .62197 m .39375 .56618 L .3626 .56566 L p .707 .577 .707 r
F P
0 g
s
.39375 .56618 m .39618 .62197 L .42799 .61994 L p .707 .577 .707 r
F P
0 g
s
.42799 .61994 m .42555 .56415 L .39375 .56618 L p .707 .577 .707 r
F P
0 g
s
.65306 .63078 m .64924 .66722 L .64213 .67609 L p .707 .577 .707 r
F P
0 g
s
.42555 .56415 m .42799 .61994 L .45735 .61557 L p .707 .577 .707 r
F P
0 g
s
.45735 .61557 m .45491 .55978 L .42555 .56415 L p .707 .577 .707 r
F P
0 g
s
.65122 .6229 m .64879 .56711 L .66516 .55953 L p .707 .577 .707 r
F P
0 g
s
.63718 .70469 m .64186 .68731 L .64911 .6777 L p .707 .577 .707 r
F P
0 g
s
.83945 .73937 m .83476 .75674 L .83234 .74458 L p .707 .577 .707 r
F P
0 g
s
.83234 .74458 m .83702 .72721 L .83945 .73937 L p .707 .577 .707 r
F P
0 g
s
.36504 .62145 m .3626 .56566 L .33518 .56266 L p .707 .577 .707 r
F P
0 g
s
.3626 .56566 m .36504 .62145 L .39618 .62197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64911 .6777 m .64443 .69508 L .63718 .70469 L p .707 .577 .707 r
F P
0 g
s
.846 .65318 m .84218 .68961 L .8297 .67941 L p .707 .577 .707 r
F P
0 g
s
.8297 .67941 m .83352 .64298 L .846 .65318 L p .707 .577 .707 r
F P
0 g
s
.45491 .55978 m .45735 .61557 L .48139 .60928 L p .707 .577 .707 r
F P
0 g
s
.48139 .60928 m .47895 .5535 L .45491 .55978 L p .707 .577 .707 r
F P
0 g
s
.82996 .55557 m .8324 .61136 L .81137 .60615 L p .707 .577 .707 r
F P
0 g
s
.81137 .60615 m .80893 .55037 L .82996 .55557 L p .707 .577 .707 r
F P
0 g
s
.66516 .55953 m .66759 .61531 L .65122 .6229 L p .707 .577 .707 r
F P
0 g
s
.64924 .66722 m .65306 .63078 L .6694 .62393 L p .707 .577 .707 r
F P
0 g
s
.33518 .56266 m .33761 .61844 L .36504 .62145 L p .707 .577 .707 r
F P
0 g
s
.39361 .68737 m .39743 .65093 L .36643 .6458 L p .707 .577 .707 r
F P
0 g
s
.39743 .65093 m .39361 .68737 L .42529 .68951 L p .707 .577 .707 r
F P
0 g
s
.42529 .68951 m .42911 .65307 L .39743 .65093 L p .707 .577 .707 r
F P
0 g
s
.33761 .61844 m .33518 .56266 L .31415 .55745 L p .707 .577 .707 r
F P
0 g
s
.42911 .65307 m .42529 .68951 L .45456 .68844 L p .707 .577 .707 r
F P
0 g
s
.36261 .68223 m .36643 .6458 L .33914 .63817 L p .707 .577 .707 r
F P
0 g
s
.36643 .6458 m .36261 .68223 L .39361 .68737 L p .707 .577 .707 r
F P
0 g
s
.66759 .61531 m .66516 .55953 L .6892 .55324 L p .707 .577 .707 r
F P
0 g
s
.6694 .62393 m .66558 .66036 L .64924 .66722 L p .707 .577 .707 r
F P
0 g
s
.64443 .69508 m .64911 .6777 L .66532 .67158 L p .707 .577 .707 r
F P
0 g
s
.47895 .5535 m .48139 .60928 L .49775 .6017 L p .707 .577 .707 r
F P
0 g
s
.49775 .6017 m .49532 .54591 L .47895 .5535 L p .707 .577 .707 r
F P
0 g
s
.83702 .72721 m .83234 .74458 L .82048 .73107 L p .707 .577 .707 r
F P
0 g
s
.82048 .73107 m .82516 .71369 L .83702 .72721 L p .707 .577 .707 r
F P
0 g
s
.31415 .55745 m .31658 .61324 L .33761 .61844 L p .707 .577 .707 r
F P
0 g
s
.45838 .65201 m .45456 .68844 L .47853 .68428 L p .707 .577 .707 r
F P
0 g
s
.47853 .68428 m .48235 .64785 L .45838 .65201 L p .707 .577 .707 r
F P
0 g
s
.33914 .63817 m .33532 .6746 L .36261 .68223 L p .707 .577 .707 r
F P
0 g
s
.83352 .64298 m .8297 .67941 L .8088 .67004 L p .707 .577 .707 r
F P
0 g
s
.8088 .67004 m .81262 .63361 L .83352 .64298 L p .707 .577 .707 r
F P
0 g
s
.66532 .67158 m .66063 .68895 L .64443 .69508 L p .707 .577 .707 r
F P
0 g
s
.80893 .55037 m .81137 .60615 L .78394 .60314 L p .707 .577 .707 r
F P
0 g
s
.78394 .60314 m .78151 .54736 L .80893 .55037 L p .707 .577 .707 r
F P
0 g
s
.38516 .73076 m .38985 .71338 L .3597 .70361 L p .707 .577 .707 r
F P
0 g
s
.38985 .71338 m .38516 .73076 L .41607 .73707 L p .707 .577 .707 r
F P
0 g
s
.41607 .73707 m .42076 .7197 L .38985 .71338 L p .707 .577 .707 r
F P
0 g
s
.33532 .6746 m .33914 .63817 L .31823 .6288 L p .707 .577 .707 r
F P
0 g
s
.6892 .55324 m .69163 .60903 L .66759 .61531 L p .707 .577 .707 r
F P
0 g
s
.66558 .66036 m .6694 .62393 L .69338 .61977 L p .707 .577 .707 r
F P
0 g
s
.35502 .72099 m .3597 .70361 L .33327 .69135 L p .707 .577 .707 r
F P
0 g
s
.3597 .70361 m .35502 .72099 L .38516 .73076 L p .707 .577 .707 r
F P
0 g
s
.31658 .61324 m .31415 .55745 L .30158 .55056 L p .707 .577 .707 r
F P
0 g
s
.42076 .7197 m .41607 .73707 L .44472 .73933 L p .707 .577 .707 r
F P
0 g
s
.44472 .73933 m .4494 .72195 L .42076 .7197 L p .707 .577 .707 r
F P
0 g
s
.69163 .60903 m .6892 .55324 L .71856 .54887 L p .707 .577 .707 r
F P
0 g
s
.33327 .69135 m .32858 .70873 L .35502 .72099 L p .707 .577 .707 r
F P
0 g
s
.31823 .6288 m .31441 .66523 L .33532 .6746 L p .707 .577 .707 r
F P
0 g
s
.78151 .54736 m .78394 .60314 L .7528 .60263 L p .707 .577 .707 r
F P
0 g
s
.7528 .60263 m .75036 .54684 L .78151 .54736 L p .707 .577 .707 r
F P
0 g
s
.69338 .61977 m .68956 .6562 L .66558 .66036 L p .707 .577 .707 r
F P
0 g
s
.48235 .64785 m .47853 .68428 L .49487 .67743 L p .707 .577 .707 r
F P
0 g
s
.49487 .67743 m .4987 .64099 L .48235 .64785 L p .707 .577 .707 r
F P
0 g
s
.32858 .70873 m .33327 .69135 L .31314 .6778 L p .707 .577 .707 r
F P
0 g
s
.66063 .68895 m .66532 .67158 L .6889 .66954 L p .707 .577 .707 r
F P
0 g
s
.49532 .54591 m .49775 .6017 L .50484 .59355 L p .707 .577 .707 r
F P
0 g
s
.50484 .59355 m .50241 .53776 L .49532 .54591 L p .707 .577 .707 r
F P
0 g
s
.72099 .60465 m .71856 .54887 L .75036 .54684 L p .707 .577 .707 r
F P
0 g
s
.71856 .54887 m .72099 .60465 L .69163 .60903 L p .707 .577 .707 r
F P
0 g
s
.30158 .55056 m .30401 .60635 L .31658 .61324 L p .707 .577 .707 r
F P
0 g
s
.4494 .72195 m .44472 .73933 L .4683 .73729 L p .707 .577 .707 r
F P
0 g
s
.4683 .73729 m .47298 .71992 L .4494 .72195 L p .707 .577 .707 r
F P
0 g
s
.81262 .63361 m .8088 .67004 L .78151 .66241 L p .707 .577 .707 r
F P
0 g
s
.78151 .66241 m .78533 .62598 L .81262 .63361 L p .707 .577 .707 r
F P
0 g
s
.82516 .71369 m .82048 .73107 L .80035 .71752 L p .707 .577 .707 r
F P
0 g
s
.80035 .71752 m .80503 .70014 L .82516 .71369 L p .707 .577 .707 r
F P
0 g
s
.75036 .54684 m .7528 .60263 L .72099 .60465 L p .707 .577 .707 r
F P
0 g
s
.31441 .66523 m .31823 .6288 L .30576 .6186 L p .707 .577 .707 r
F P
0 g
s
.68956 .6562 m .69338 .61977 L .72264 .6187 L p .707 .577 .707 r
F P
0 g
s
.31314 .6778 m .30845 .69518 L .32858 .70873 L p .707 .577 .707 r
F P
0 g
s
.6889 .66954 m .68422 .68692 L .66063 .68895 L p .707 .577 .707 r
F P
0 g
s
.30401 .60635 m .30158 .55056 L .29869 .54265 L p .707 .577 .707 r
F P
0 g
s
.30576 .6186 m .30194 .65503 L .31441 .66523 L p .707 .577 .707 r
F P
0 g
s
.78533 .62598 m .78151 .66241 L .75051 .65728 L p .707 .577 .707 r
F P
0 g
s
.75051 .65728 m .75433 .62084 L .78533 .62598 L p .707 .577 .707 r
F P
0 g
s
.72264 .6187 m .71882 .65514 L .68956 .6562 L p .707 .577 .707 r
F P
0 g
s
.71882 .65514 m .72264 .6187 L .75433 .62084 L p .707 .577 .707 r
F P
0 g
s
.30845 .69518 m .31314 .6778 L .30128 .66429 L p .707 .577 .707 r
F P
0 g
s
.68422 .68692 m .6889 .66954 L .71755 .6718 L p .707 .577 .707 r
F P
0 g
s
.75433 .62084 m .75051 .65728 L .71882 .65514 L p .707 .577 .707 r
F P
0 g
s
.47298 .71992 m .4683 .73729 L .48451 .73117 L p .707 .577 .707 r
F P
0 g
s
.48451 .73117 m .48919 .7138 L .47298 .71992 L p .707 .577 .707 r
F P
0 g
s
.80503 .70014 m .80035 .71752 L .77392 .70526 L p .707 .577 .707 r
F P
0 g
s
.77392 .70526 m .7786 .68788 L .80503 .70014 L p .707 .577 .707 r
F P
0 g
s
.4987 .64099 m .49487 .67743 L .50198 .66855 L p .707 .577 .707 r
F P
0 g
s
.50198 .66855 m .5058 .63212 L .4987 .64099 L p .707 .577 .707 r
F P
0 g
s
.30128 .66429 m .2966 .68166 L .30845 .69518 L p .707 .577 .707 r
F P
0 g
s
.71755 .6718 m .71286 .68917 L .68422 .68692 L p .707 .577 .707 r
F P
0 g
s
.29869 .54265 m .30113 .59844 L .30401 .60635 L p .707 .577 .707 r
F P
0 g
s
.50241 .53776 m .50484 .59355 L .50196 .58564 L p .707 .577 .707 r
F P
0 g
s
.50196 .58564 m .49952 .52986 L .50241 .53776 L p .707 .577 .707 r
F P
0 g
s
.30194 .65503 m .30576 .6186 L .30294 .60857 L p .707 .577 .707 r
F P
0 g
s
.71286 .68917 m .71755 .6718 L .74846 .67812 L p .707 .577 .707 r
F P
0 g
s
.7786 .68788 m .77392 .70526 L .74377 .69549 L p .707 .577 .707 r
F P
0 g
s
.74377 .69549 m .74846 .67812 L .7786 .68788 L p .707 .577 .707 r
F P
0 g
s
.74846 .67812 m .74377 .69549 L .71286 .68917 L p .707 .577 .707 r
F P
0 g
s
.30294 .60857 m .29912 .645 L .30194 .65503 L p .707 .577 .707 r
F P
0 g
s
.30113 .59844 m .29869 .54265 L .30578 .53451 L p .707 .577 .707 r
F P
0 g
s
.2966 .68166 m .30128 .66429 L .29885 .65213 L p .707 .577 .707 r
F P
0 g
s
.48919 .7138 m .48451 .73117 L .49175 .72156 L p .707 .577 .707 r
F P
0 g
s
.49175 .72156 m .49644 .70418 L .48919 .7138 L p .707 .577 .707 r
F P
0 g
s
.29885 .65213 m .29417 .66951 L .2966 .68166 L p .707 .577 .707 r
F P
0 g
s
.5058 .63212 m .50198 .66855 L .49917 .65852 L p .707 .577 .707 r
F P
0 g
s
.49917 .65852 m .50299 .62209 L .5058 .63212 L p .707 .577 .707 r
F P
0 g
s
.30578 .53451 m .30821 .59029 L .30113 .59844 L p .707 .577 .707 r
F P
0 g
s
.49952 .52986 m .50196 .58564 L .48939 .57875 L p .707 .577 .707 r
F P
0 g
s
.48939 .57875 m .48695 .52297 L .49952 .52986 L p .707 .577 .707 r
F P
0 g
s
.29912 .645 m .30294 .60857 L .31005 .59969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31005 .59969 m .30623 .63612 L .29912 .645 L p .707 .577 .707 r
F P
0 g
s
.30821 .59029 m .30578 .53451 L .32215 .52692 L p .707 .577 .707 r
F P
0 g
s
.29417 .66951 m .29885 .65213 L .3061 .64252 L p .707 .577 .707 r
F P
0 g
s
.49644 .70418 m .49175 .72156 L .48933 .7094 L p .707 .577 .707 r
F P
0 g
s
.48933 .7094 m .49401 .69203 L .49644 .70418 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3061 .64252 m .30142 .6599 L .29417 .66951 L p .707 .577 .707 r
F P
0 g
s
.50299 .62209 m .49917 .65852 L .48669 .64832 L p .707 .577 .707 r
F P
0 g
s
.48669 .64832 m .49051 .61189 L .50299 .62209 L p .707 .577 .707 r
F P
0 g
s
.48695 .52297 m .48939 .57875 L .46836 .57355 L p .707 .577 .707 r
F P
0 g
s
.46836 .57355 m .46592 .51776 L .48695 .52297 L p .707 .577 .707 r
F P
0 g
s
.32215 .52692 m .32458 .58271 L .30821 .59029 L p .707 .577 .707 r
F P
0 g
s
.30623 .63612 m .31005 .59969 L .32639 .59284 L p .707 .577 .707 r
F P
0 g
s
.32458 .58271 m .32215 .52692 L .34618 .52063 L p .707 .577 .707 r
F P
0 g
s
.32639 .59284 m .32257 .62927 L .30623 .63612 L p .707 .577 .707 r
F P
0 g
s
.30142 .6599 m .3061 .64252 L .32231 .6364 L p .707 .577 .707 r
F P
0 g
s
.49401 .69203 m .48933 .7094 L .47747 .69589 L p .707 .577 .707 r
F P
0 g
s
.47747 .69589 m .48215 .67851 L .49401 .69203 L p .707 .577 .707 r
F P
0 g
s
.32231 .6364 m .31762 .65377 L .30142 .6599 L p .707 .577 .707 r
F P
0 g
s
.49051 .61189 m .48669 .64832 L .46579 .63895 L p .707 .577 .707 r
F P
0 g
s
.46579 .63895 m .46961 .60251 L .49051 .61189 L p .707 .577 .707 r
F P
0 g
s
.46592 .51776 m .46836 .57355 L .44093 .57054 L p .707 .577 .707 r
F P
0 g
s
.44093 .57054 m .4385 .51475 L .46592 .51776 L p .707 .577 .707 r
F P
0 g
s
.34618 .52063 m .34862 .57642 L .32458 .58271 L p .707 .577 .707 r
F P
0 g
s
.32257 .62927 m .32639 .59284 L .35037 .58867 L p .707 .577 .707 r
F P
0 g
s
.34862 .57642 m .34618 .52063 L .37555 .51626 L p .707 .577 .707 r
F P
0 g
s
.4385 .51475 m .44093 .57054 L .40979 .57002 L p .707 .577 .707 r
F P
0 g
s
.40979 .57002 m .40735 .51424 L .4385 .51475 L p .707 .577 .707 r
F P
0 g
s
.35037 .58867 m .34655 .6251 L .32257 .62927 L p .707 .577 .707 r
F P
0 g
s
.31762 .65377 m .32231 .6364 L .34589 .63436 L p .707 .577 .707 r
F P
0 g
s
.37798 .57205 m .37555 .51626 L .40735 .51424 L p .707 .577 .707 r
F P
0 g
s
.37555 .51626 m .37798 .57205 L .34862 .57642 L p .707 .577 .707 r
F P
0 g
s
.48215 .67851 m .47747 .69589 L .45734 .68234 L p .707 .577 .707 r
F P
0 g
s
.45734 .68234 m .46202 .66496 L .48215 .67851 L p .707 .577 .707 r
F P
0 g
s
.46961 .60251 m .46579 .63895 L .4385 .63132 L p .707 .577 .707 r
F P
0 g
s
.4385 .63132 m .44232 .59489 L .46961 .60251 L p .707 .577 .707 r
F P
0 g
s
.40735 .51424 m .40979 .57002 L .37798 .57205 L p .707 .577 .707 r
F P
0 g
s
.34589 .63436 m .3412 .65174 L .31762 .65377 L p .707 .577 .707 r
F P
0 g
s
.34655 .6251 m .35037 .58867 L .37963 .58761 L p .707 .577 .707 r
F P
0 g
s
.44232 .59489 m .4385 .63132 L .4075 .62618 L p .707 .577 .707 r
F P
0 g
s
.4075 .62618 m .41132 .58975 L .44232 .59489 L p .707 .577 .707 r
F P
0 g
s
.37963 .58761 m .37581 .62404 L .34655 .6251 L p .707 .577 .707 r
F P
0 g
s
.37581 .62404 m .37963 .58761 L .41132 .58975 L p .707 .577 .707 r
F P
0 g
s
.3412 .65174 m .34589 .63436 L .37454 .63662 L p .707 .577 .707 r
F P
0 g
s
.46202 .66496 m .45734 .68234 L .43091 .67008 L p .707 .577 .707 r
F P
0 g
s
.43091 .67008 m .43559 .6527 L .46202 .66496 L p .707 .577 .707 r
F P
0 g
s
.41132 .58975 m .4075 .62618 L .37581 .62404 L p .707 .577 .707 r
F P
0 g
s
.37454 .63662 m .36985 .65399 L .3412 .65174 L p .707 .577 .707 r
F P
0 g
s
.36985 .65399 m .37454 .63662 L .40545 .64294 L p .707 .577 .707 r
F P
0 g
s
.43559 .6527 m .43091 .67008 L .40076 .66031 L p .707 .577 .707 r
F P
0 g
s
.40076 .66031 m .40545 .64294 L .43559 .6527 L p .707 .577 .707 r
F P
0 g
s
.40545 .64294 m .40076 .66031 L .36985 .65399 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0081ooaH008Mo
o`00N7oo20001EYF00<005YFFUH02UYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH01eYF1P00Ngoo001_Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006eoo`800003FUH005YF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00Jgoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF000006moo`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00J7oo0P001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00JWoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Moo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008006Ioo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00IWoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol006Ioo`800003FUH005YF00EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo
00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00=JEP0000001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`800003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH025YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01EYF001JEP00FUH05`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol00eYF0000000200000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IWoo001OOol60005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005]oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00FGoo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000JOolA000kOol005Aoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
015oo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH5000fOol005Aoo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003=oo`00E7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool005Aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP02
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00FUH00004FUH00`00FUIJEP03FUH60007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00EGoo00<005YF000015YF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF10000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Eo
o`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002aoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP00008000EJEQP00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000/Ool005Eoo`80009JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00@000MJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo001EOol20002FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02aoo`00EGoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool005Eoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF5`0015YF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00B7oo4@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0
000/Ool0041oo`P000AJEP03001JEUYF00IJEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000=J
EP03001oogoo02Yoo`00>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00FUIJ
EP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800004Ool005YF0003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00Ool0:goo000fOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000UYF00D005YFFUIJEP0000MJEP03001JEP00
00L000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000/Ool003=oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo001JEP030004FUH0
0`00FUH000070003FUH00`00FUIJEP02FUH700000eYF001JEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20000
1goo001JEP00FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH40004FUH01000FUIJEP00
1EYF00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP07
001JEUYFFUH005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH005YF1@001EYF00@005YFFUH000EJEP03001JEP0000@000=J
EP03001JEP0000D000IJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01P00FUH007oo001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00001JEP0=0005FUH00`00FUH000040003FUH00`00FUIJEP05FUH40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP05001JEUYFFUH0000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<000IJEP04001J
EUYFFUH=0003FUH00`00FUIJEP09FUH30005FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=J
EP000000;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60000
0eYF001JEP0:FUH00`00FUIJEP020003FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP07001JEP00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0P00<7oo000]
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000002eYF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YFFUIJ
EPD0009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUHB0007FUH0
0`00FUIJEP05FUH<0003FUH01000FUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000/Ool002eoo`03
001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
0004FUH000000005FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH0
0`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPD000=JEP05001JEUYFFUH0
000?Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00:goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF5`001EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH00`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF000005YF001JEP050005FUH01000FUIJEUYF
0P004Woo10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:goo000^Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUH000030002FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH01`00
FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00
001JEP02000015YF001JEUYF0P0015YF00@005YFFUIJEP8000Moo`<000aoo`@00003FUH005YF00AJ
EP03001JEUYF009JEP8002]oo`00;Woo00<005YF000015YF00@005YFFUIJEPH00003FUH005YF00IJ
EP03001JEUYF00IJEP07001JEP00FUH005YF00000UYF100000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF0P0025YF0`000UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH<00000eYF00000006Ool5000?Ool20005
FUH00`00FUIJEP02FUH2000[Ool002ioo`03001JEP0000AJEP@000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUH00003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020006FUH00`00FUIJEP030003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020002FUH200000eYF001JEP04FUH01000FUIJEUYF3P004Goo
0P000eYF00L005YFFUIJEP00FUH0000[Ool002ioo`03001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEUYF0004FUH20006FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20002FUH00`00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000BOol200000eYF001JEP02FUH00`00FUH0000[
Ool002ioo`03001JEP0000<000AJEQP00005FUH005YFFUH00004FUH20006FUH00`00FUH000020000
0eYF001JEP06FUH30006FUH00`00FUIJEP04FUH200000eYF001JEP05FUH30002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00002000>Ool50003FUH2000/Ool002io
o`03001JEP00009JEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00@00005FUH005YFFUH00002FUH20004FUH00`00FUH00002FUH50003FUH50005FUH00`00FUIJEP06
FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF3P000eYF00<005YF00000UYF0P00;7oo000^Ool20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH01000FUIJEUYF0`00
0UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF20000eYF00@005YFFUH0009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEQ8000IJ
EP03001JEUYF00IJEP8000EJEP03001JEUYF00AJEP03001JEUYF00@002aoo`00;Woo0P0000=JEP00
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF
00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF0000100000=JEP0000001`0015YF00@005YF
FUIJEP<000AJEP8000eJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH0000000EJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH30003
FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;7oo000^Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000050005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<002aoo`00;goo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF0000
00AJEP03001JEUYF00<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP02FUH00`00FUH0000/Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<0
05YFFUH00UYF00<005YFFUH00UYF0P00;Goo000_Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007FUH30003FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20008FUH30002FUH00`00FUIJEP02FUH2000]Ool002moo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YF
FUH00`000eYF0P00;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH20007FUH00`00FUIJEP050006FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH00eYF1000<7oo000_Ool20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH00`00FUIJEP05000;FUH00`00FUIJEP04
FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
000015YF0`001UYF00P005YFFUIJEP00FUH007oo10000UYF0`001UYF00<005YFFUH00eYF0P0000=J
EP00FUH01EYF0P00<Goo000^Ool00`00FUH00003FUH00`00FUH00003000>Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP04FUH60006FUH00`00FUH000040002FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF
00@005YFFUH000EJEP07001JEUYFFUH005YF00001Goo5@001UYF0P00<Goo000^Ool00`00FUH00003
FUH2000BOol30006Ool60006FUH00`00FUIJEP02FUH00`00FUH000020006FUH00`00FUIJEP07FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEP00FUH005YF000015YF0P000eYF00@005YFFUIJEP8000Moo`D0
00moo`8000=JEP04001JEUYF000`Ool002ioo`04001JEP00FUH20002FUH90008Ool5000;Ool40002
FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH0009JEP8000IJEP04001JEUYF0003FUH00`00Oomoo`06Ool5000A
Ool200000eYF001JEP02FUH00`00Oomoo`0]Ool002ioo`05001JEP00001JEP050003FUH01000FUIJ
EUYF3@003goo0`0015YF00@005YFFUH000EJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH20006FUH400000eYF0000000:Ool3000DOol20003FUH00`00Oomoo`0]Ool0
02ioo`D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPH0011oo`80009JEP04001J
EUYF0005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF000015YF00@005YFFUIJEP8002Eoo`04001JEUYF000_Ool002ioo`<000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000@Ool30002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH60004FUH01000FUIJEUYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP8002=oo`05001JEP00FUH0000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000aoo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEQL000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP03001JEUYF00=JEP8000QJEP<0025oo`800003FUH007oo02eoo`00;Goo00<005YF0000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP`000=JEP04001JEUYF0005
FUH00`00FUIJEP06FUH9000<FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
000NOol00`00FUH0000^Ool002eoo`80009JEPH00003FUH005YF00AJEPP000AJEP03001JEUYF00MJ
EP<000AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP04FUH5000HOol200000eYF001oo`0]Ool002eoo`@00003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000QJEP03001JEUYF0080009JEP03001JEUYF
00AJEP04001JEUYF0005FUH00`00FUH00004000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP04FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP020003FUH00`00FUIJEP07FUH00`00FUIJEP04000BOol200000eYF0000000_Ool0
02aoo`<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH0
0`00FUIJEP03FUH30006FUH01000FUIJEP0015YF0`0015YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF0000
10001EYF00<005YFFUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH01EYF1P0027oo10000eYF0P00
;goo000/Ool30003Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30000
0eYF001JEP06FUH20004FUH20002FUH00`00FUH000020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH00`00
FUH00004Ool400000eYF001JEP04FUH40007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00L0
05YFFUIJEP00FUH0000_Ool002aoo`04001JEP000004Ool300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH20008FUH30002FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03
FUH00`00FUH00008Ool20005FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80031oo`00;7oo00@005YF001JEP8000Eoo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF008000IJEP05001JEUYF001JEP0200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YF00002Woo0P000eYF00P005YFFUIJEP00FUH0
07oo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80035oo`00;7oo0P0015YF
00<007ooOol01Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP03001JEP0000aoo`80
0003FUH005YF009JEP03001JEP0000Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP00000cOol002eoo`03001JEUYF009JEP8000Qoo`<00003FUH005YF00IJEP<000IJEP03001JEUYF
00AJEP800003FUH005YF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo
00Yoo`D000=JEP03001JEP0000Yoo`H000AJEP04001JEUYFFUH5000eOol002eoo`05001JEUYFFUH0
0002FUH20009Ool50003FUH50005FUH00`00FUIJEP06FUH20006FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH200000eYF0000000:0003FUH00`00FUH00002FUH2000AOol8000jOol002ioo`04
001JEUYF0004FUH00`00Oomoo`0;Ool90004FUH00`00FUIJEP02FUH70004FUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01000Dgoo000_Ool2
0006FUH00`00Oomoo`0=Ool500000goo000000070007Ool20002FUH00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUH00000FUH00`000eYF00<005YFFUH015YF00@005YFFUIJEP<005=oo`00
<7oo00<005YFFUH015YF0`003Woo0`0057oo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<005=oo`00<Goo
0P0015YF00<005YFFUH00P0097oo00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF008000EJEP8000EJEP03001JEUYF009JEP03001JEP0005=oo`00<goo00@005YFFUH0
00EJEP8002=oo`03001JEUYF00<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000008FUH0
0`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0001COol003Aoo`<000MJEP<0025oo`<00004FUH0
00000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40008FUH30002FUH00`00FUIJEP02FUH2001DOol003Ioo`03001J
EUYF00IJEP04001JEP00000QOol01000FUH007oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH0
0P001UYF00H005YFFUH005YF0003FUH2001EOol003Moo`8000EJEP03001JEUYF009JEP<001ioo`80
00Aoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20003FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P0000=J
EP000000Egoo000iOol20003FUH00`00FUIJEP05FUH6000FOol40006Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001EYF
00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<007ooOol0Egoo000kOol30009FUH00`00FUIJEP02
FUH80008Ool60002FUH00`00Oomoo`08Ool40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP02FUH50006FUH2001HOol003eoo`<000IJ
EP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P003Woo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@0000=oo`0000000`0000=oo`000000
1`001Goo0P0015YF00<005YF0000Egoo0010Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00005Goo2@001UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
1Woo1@004Goo00@005YFFUH000=JEP03001oogoo05Aoo`00A7oo1@001UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP8001iooaX000eoo`D0019oo`<000=JEP03001oogoo05Aoo`00BGoo
10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo00<005YFFUH00UYF00@0
05YFFUIJEP8000aoo`<001Eoo`05001JEUYFFUH0001FOol004eoo`H000AJEP04001JEUYFFUH6000c
Ool20002FUH00`00FUIJEP03FUH2000SOol01@00FUH005YF0000EGoo001COol8000kOol20008FUH2
000ROol200000eYF001oo`1DOol009Moo`03001JEUYF00IJEP03001JEP000080021oo`03001JEP00
05Eoo`00V7oo0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000EGoo002JOol20003FUH00`00
FUIJEP06FUH6000EOol4001FOol009aoo`800003FUH005YF00MJEP03001JEUYF00=JEPP000Qoo`D0
009JEP8005Ioo`00WWoo0`001eYF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF009J
EP8005Ioo`00XGoo10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8005Moo`00YGoo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00
Egoo002ZOol40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001HOol00:ioo`H0
00AJEP04001JEUYFFUH6001KOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59021 .75232 m .59264 .69706 L .5615 .69378 L p .707 .577 .707 r
F P
0 g
s
.59264 .69706 m .59021 .75232 L .62202 .75279 L p .707 .577 .707 r
F P
0 g
s
.62202 .75279 m .62445 .69752 L .59264 .69706 L p .707 .577 .707 r
F P
0 g
s
.62445 .69752 m .62202 .75279 L .65138 .75039 L p .707 .577 .707 r
F P
0 g
s
.65138 .75039 m .65381 .69513 L .62445 .69752 L p .707 .577 .707 r
F P
0 g
s
.55907 .74904 m .5615 .69378 L .53407 .68801 L p .707 .577 .707 r
F P
0 g
s
.5615 .69378 m .55907 .74904 L .59021 .75232 L p .707 .577 .707 r
F P
0 g
s
.65381 .69513 m .65138 .75039 L .67542 .74538 L p .707 .577 .707 r
F P
0 g
s
.67542 .74538 m .67785 .69011 L .65381 .69513 L p .707 .577 .707 r
F P
0 g
s
.53164 .74327 m .53407 .68801 L .51305 .68031 L p .707 .577 .707 r
F P
0 g
s
.53407 .68801 m .53164 .74327 L .55907 .74904 L p .707 .577 .707 r
F P
0 g
s
.5925 .80897 m .58868 .77172 L .55768 .77309 L p .707 .577 .707 r
F P
0 g
s
.58868 .77172 m .5925 .80897 L .62419 .80524 L p .707 .577 .707 r
F P
0 g
s
.62419 .80524 m .62037 .76799 L .58868 .77172 L p .707 .577 .707 r
F P
0 g
s
.62037 .76799 m .62419 .80524 L .65345 .79952 L p .707 .577 .707 r
F P
0 g
s
.65345 .79952 m .64963 .76227 L .62037 .76799 L p .707 .577 .707 r
F P
0 g
s
.5615 .81034 m .55768 .77309 L .53039 .77197 L p .707 .577 .707 r
F P
0 g
s
.55768 .77309 m .5615 .81034 L .5925 .80897 L p .707 .577 .707 r
F P
0 g
s
.59923 .84454 m .59455 .82616 L .56441 .83235 L p .707 .577 .707 r
F P
0 g
s
.59455 .82616 m .59923 .84454 L .63014 .83647 L p .707 .577 .707 r
F P
0 g
s
.63014 .83647 m .62546 .81809 L .59455 .82616 L p .707 .577 .707 r
F P
0 g
s
.64963 .76227 m .65345 .79952 L .67742 .79237 L p .707 .577 .707 r
F P
0 g
s
.67742 .79237 m .6736 .75512 L .64963 .76227 L p .707 .577 .707 r
F P
0 g
s
.67785 .69011 m .67542 .74538 L .69178 .73823 L p .707 .577 .707 r
F P
0 g
s
.69178 .73823 m .69422 .68296 L .67785 .69011 L p .707 .577 .707 r
F P
0 g
s
.62546 .81809 m .63014 .83647 L .65879 .8273 L p .707 .577 .707 r
F P
0 g
s
.65879 .8273 m .65411 .80892 L .62546 .81809 L p .707 .577 .707 r
F P
0 g
s
.51305 .68031 m .51061 .73557 L .53164 .74327 L p .707 .577 .707 r
F P
0 g
s
.56441 .83235 m .56909 .85073 L .59923 .84454 L p .707 .577 .707 r
F P
0 g
s
.53039 .77197 m .53421 .80922 L .5615 .81034 L p .707 .577 .707 r
F P
0 g
s
.56909 .85073 m .56441 .83235 L .53797 .83604 L p .707 .577 .707 r
F P
0 g
s
.51061 .73557 m .51305 .68031 L .50047 .67144 L p .707 .577 .707 r
F P
0 g
s
.53421 .80922 m .53039 .77197 L .50948 .76847 L p .707 .577 .707 r
F P
0 g
s
.53797 .83604 m .54266 .85442 L .56909 .85073 L p .707 .577 .707 r
F P
0 g
s
.65411 .80892 m .65879 .8273 L .68237 .81794 L p .707 .577 .707 r
F P
0 g
s
.68237 .81794 m .67769 .79955 L .65411 .80892 L p .707 .577 .707 r
F P
0 g
s
.50948 .76847 m .5133 .80572 L .53421 .80922 L p .707 .577 .707 r
F P
0 g
s
.6736 .75512 m .67742 .79237 L .69377 .78448 L p .707 .577 .707 r
F P
0 g
s
.69377 .78448 m .68995 .74723 L .6736 .75512 L p .707 .577 .707 r
F P
0 g
s
.50047 .67144 m .49804 .7267 L .51061 .73557 L p .707 .577 .707 r
F P
0 g
s
.54266 .85442 m .53797 .83604 L .51784 .83688 L p .707 .577 .707 r
F P
0 g
s
.69422 .68296 m .69178 .73823 L .69887 .72965 L p .707 .577 .707 r
F P
0 g
s
.69887 .72965 m .7013 .67438 L .69422 .68296 L p .707 .577 .707 r
F P
0 g
s
.51784 .83688 m .52253 .85526 L .54266 .85442 L p .707 .577 .707 r
F P
0 g
s
.67769 .79955 m .68237 .81794 L .69858 .80929 L p .707 .577 .707 r
F P
0 g
s
.69858 .80929 m .6939 .79091 L .67769 .79955 L p .707 .577 .707 r
F P
0 g
s
.5133 .80572 m .50948 .76847 L .49701 .76292 L p .707 .577 .707 r
F P
0 g
s
.49804 .7267 m .50047 .67144 L .49759 .66226 L p .707 .577 .707 r
F P
0 g
s
.49701 .76292 m .50083 .80018 L .5133 .80572 L p .707 .577 .707 r
F P
0 g
s
.68995 .74723 m .69377 .78448 L .70088 .77664 L p .707 .577 .707 r
F P
0 g
s
.70088 .77664 m .69706 .73938 L .68995 .74723 L p .707 .577 .707 r
F P
0 g
s
.52253 .85526 m .51784 .83688 L .50599 .83479 L p .707 .577 .707 r
F P
0 g
s
.49759 .66226 m .49516 .71753 L .49804 .7267 L p .707 .577 .707 r
F P
0 g
s
.50599 .83479 m .51067 .85317 L .52253 .85526 L p .707 .577 .707 r
F P
0 g
s
.7013 .67438 m .69887 .72965 L .69599 .72047 L p .707 .577 .707 r
F P
0 g
s
.69599 .72047 m .69842 .66521 L .7013 .67438 L p .707 .577 .707 r
F P
0 g
s
.6939 .79091 m .69858 .80929 L .70583 .8022 L p .707 .577 .707 r
F P
0 g
s
.70583 .8022 m .70114 .78382 L .6939 .79091 L p .707 .577 .707 r
F P
0 g
s
.50083 .80018 m .49701 .76292 L .49419 .75588 L p .707 .577 .707 r
F P
0 g
s
.49516 .71753 m .49759 .66226 L .50468 .65368 L p .707 .577 .707 r
F P
0 g
s
.49419 .75588 m .49801 .79314 L .50083 .80018 L p .707 .577 .707 r
F P
0 g
s
.50468 .65368 m .50225 .70894 L .49516 .71753 L p .707 .577 .707 r
F P
0 g
s
.49801 .79314 m .49419 .75588 L .5013 .74804 L p .707 .577 .707 r
F P
0 g
s
.5013 .74804 m .50512 .78529 L .49801 .79314 L p .707 .577 .707 r
F P
0 g
s
.50084 .82131 m .48403 .31792 L .44004 .31673 L p .707 .577 .707 r
F P
0 g
s
.50225 .70894 m .50468 .65368 L .52104 .64653 L p .707 .577 .707 r
F P
0 g
s
.52104 .64653 m .51861 .70179 L .50225 .70894 L p .707 .577 .707 r
F P
0 g
s
.51861 .70179 m .52104 .64653 L .54508 .64151 L p .707 .577 .707 r
F P
0 g
s
.50512 .78529 m .5013 .74804 L .51764 .74015 L p .707 .577 .707 r
F P
0 g
s
.51764 .74015 m .52147 .77741 L .50512 .78529 L p .707 .577 .707 r
F P
0 g
s
.54508 .64151 m .54265 .69678 L .51861 .70179 L p .707 .577 .707 r
F P
0 g
s
.51549 .84126 m .51081 .82288 L .52701 .81423 L p .707 .577 .707 r
F P
0 g
s
.52701 .81423 m .5317 .83261 L .51549 .84126 L p .707 .577 .707 r
F P
0 g
s
.52147 .77741 m .51764 .74015 L .54162 .733 L p .707 .577 .707 r
F P
0 g
s
.54162 .733 m .54544 .77025 L .52147 .77741 L p .707 .577 .707 r
F P
0 g
s
.5317 .83261 m .52701 .81423 L .55059 .80486 L p .707 .577 .707 r
F P
0 g
s
.55059 .80486 m .55528 .82325 L .5317 .83261 L p .707 .577 .707 r
F P
0 g
s
.48403 .31792 m .50084 .82131 L .54577 .81886 L p .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .54162 .733 L .56511 .72841 L p .707 .577 .707 r
F P
0 g
s
.56511 .72841 m .57088 .72728 L p .56643 .73479 L .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .56511 .72841 L .56643 .73479 L .707 .577 .707 r
F
.52895 .31547 m .48403 .31792 L p .48962 .36328 L F P
0 g
s
.54577 .81886 m .53843 .59938 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.53843 .59938 m .52895 .31547 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.54265 .69678 m .54508 .64151 L .57444 .63912 L p .707 .577 .707 r
F P
0 g
s
.57201 .69439 m .57444 .63912 L .60625 .63959 L p .707 .577 .707 r
F P
0 g
s
.57444 .63912 m .57201 .69439 L .54265 .69678 L p .707 .577 .707 r
F P
0 g
s
.60625 .63959 m .60382 .69485 L .57201 .69439 L p .707 .577 .707 r
F P
0 g
s
.57088 .72728 m .5747 .76453 L .54544 .77025 L p .707 .577 .707 r
F P
0 g
s
.5747 .76453 m .57088 .72728 L .60257 .72355 L p .707 .577 .707 r
F P
0 g
s
.60257 .72355 m .60639 .7608 L .5747 .76453 L p .707 .577 .707 r
F P
0 g
s
.55528 .82325 m .55059 .80486 L .57924 .7957 L p .707 .577 .707 r
F P
0 g
s
.57924 .7957 m .58392 .81408 L .55528 .82325 L p .707 .577 .707 r
F P
0 g
s
.58392 .81408 m .57924 .7957 L .61015 .78762 L p .707 .577 .707 r
F P
0 g
s
.61015 .78762 m .61483 .80601 L .58392 .81408 L p .707 .577 .707 r
F P
0 g
s
.52895 .31547 m .54577 .81886 L .58723 .81302 L p .707 .577 .707 r
F P
0 g
s
.58723 .81302 m .57041 .30963 L .52895 .31547 L p .707 .577 .707 r
F P
0 g
s
.45686 .82012 m .44004 .31673 L .4013 .31203 L p .707 .577 .707 r
F P
0 g
s
.44004 .31673 m .45686 .82012 L .50084 .82131 L p .707 .577 .707 r
F P
0 g
s
.69706 .73938 m .70088 .77664 L .69806 .7696 L p .707 .577 .707 r
F P
0 g
s
.69806 .7696 m .69424 .73234 L .69706 .73938 L p .707 .577 .707 r
F P
0 g
s
.51067 .85317 m .50599 .83479 L .50356 .82996 L p .707 .577 .707 r
F P
0 g
s
.50356 .82996 m .50824 .84834 L .51067 .85317 L p .707 .577 .707 r
F P
0 g
s
.63739 .64287 m .63496 .69813 L .60382 .69485 L p .707 .577 .707 r
F P
0 g
s
.60382 .69485 m .60625 .63959 L .63739 .64287 L p .707 .577 .707 r
F P
0 g
s
.63357 .72218 m .63739 .75943 L .60639 .7608 L p .707 .577 .707 r
F P
0 g
s
.60639 .7608 m .60257 .72355 L .63357 .72218 L p .707 .577 .707 r
F P
0 g
s
.6403 .78144 m .64498 .79982 L .61483 .80601 L p .707 .577 .707 r
F P
0 g
s
.61483 .80601 m .61015 .78762 L .6403 .78144 L p .707 .577 .707 r
F P
0 g
s
.57041 .30963 m .58723 .81302 L .62117 .80436 L p .707 .577 .707 r
F P
0 g
s
.62117 .80436 m .60436 .30097 L .57041 .30963 L p .707 .577 .707 r
F P
0 g
s
.69842 .66521 m .69599 .72047 L .68342 .7116 L p .707 .577 .707 r
F P
0 g
s
.68342 .7116 m .68585 .65633 L .69842 .66521 L p .707 .577 .707 r
F P
0 g
s
.70114 .78382 m .70583 .8022 L .7034 .79738 L p .707 .577 .707 r
F P
0 g
s
.7034 .79738 m .69872 .779 L .70114 .78382 L p .707 .577 .707 r
F P
0 g
s
.2472 .71129 m .24963 .65603 L .21849 .65275 L p .707 .577 .707 r
F P
0 g
s
.24963 .65603 m .2472 .71129 L .27901 .71176 L p .707 .577 .707 r
F P
0 g
s
.27901 .71176 m .28144 .6565 L .24963 .65603 L p .707 .577 .707 r
F P
0 g
s
.41812 .81542 m .4013 .31203 L .3716 .30427 L p .707 .577 .707 r
F P
0 g
s
.4013 .31203 m .41812 .81542 L .45686 .82012 L p .707 .577 .707 r
F P
0 g
s
.28144 .6565 m .27901 .71176 L .30837 .70937 L p .707 .577 .707 r
F P
0 g
s
.30837 .70937 m .3108 .6541 L .28144 .6565 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21606 .70801 m .21849 .65275 L .19106 .64698 L p .707 .577 .707 r
F P
0 g
s
.21849 .65275 m .21606 .70801 L .2472 .71129 L p .707 .577 .707 r
F P
0 g
s
.69424 .73234 m .69806 .7696 L .68558 .76405 L p .707 .577 .707 r
F P
0 g
s
.68558 .76405 m .68176 .7268 L .69424 .73234 L p .707 .577 .707 r
F P
0 g
s
.3108 .6541 m .30837 .70937 L .33241 .70435 L p .707 .577 .707 r
F P
0 g
s
.33241 .70435 m .33484 .64909 L .3108 .6541 L p .707 .577 .707 r
F P
0 g
s
.50824 .84834 m .50356 .82996 L .51081 .82288 L p .707 .577 .707 r
F P
0 g
s
.66482 .64864 m .66239 .7039 L .63496 .69813 L p .707 .577 .707 r
F P
0 g
s
.63496 .69813 m .63739 .64287 L .66482 .64864 L p .707 .577 .707 r
F P
0 g
s
.66086 .7233 m .66468 .76055 L .63739 .75943 L p .707 .577 .707 r
F P
0 g
s
.63739 .75943 m .63357 .72218 L .66086 .7233 L p .707 .577 .707 r
F P
0 g
s
.64498 .79982 m .6403 .78144 L .66673 .77774 L p .707 .577 .707 r
F P
0 g
s
.60436 .30097 m .62117 .80436 L .64428 .79372 L p .707 .577 .707 r
F P
0 g
s
.64428 .79372 m .62746 .29033 L .60436 .30097 L p .707 .577 .707 r
F P
0 g
s
.51081 .82288 m .51549 .84126 L .50824 .84834 L p .707 .577 .707 r
F P
0 g
s
.68585 .65633 m .68342 .7116 L .66239 .7039 L p .707 .577 .707 r
F P
0 g
s
.66239 .7039 m .66482 .64864 L .68585 .65633 L p .707 .577 .707 r
F P
0 g
s
.18863 .70224 m .19106 .64698 L .17004 .63928 L p .707 .577 .707 r
F P
0 g
s
.19106 .64698 m .18863 .70224 L .21606 .70801 L p .707 .577 .707 r
F P
0 g
s
.24949 .76643 m .24567 .72918 L .21467 .73055 L p .707 .577 .707 r
F P
0 g
s
.24567 .72918 m .24949 .76643 L .28118 .7627 L p .707 .577 .707 r
F P
0 g
s
.28118 .7627 m .27736 .72545 L .24567 .72918 L p .707 .577 .707 r
F P
0 g
s
.69872 .779 m .7034 .79738 L .69154 .79528 L p .707 .577 .707 r
F P
0 g
s
.69154 .79528 m .68686 .7769 L .69872 .779 L p .707 .577 .707 r
F P
0 g
s
.27736 .72545 m .28118 .7627 L .31044 .75698 L p .707 .577 .707 r
F P
0 g
s
.31044 .75698 m .30662 .71973 L .27736 .72545 L p .707 .577 .707 r
F P
0 g
s
.21849 .7678 m .21467 .73055 L .18738 .72943 L p .707 .577 .707 r
F P
0 g
s
.21467 .73055 m .21849 .7678 L .24949 .76643 L p .707 .577 .707 r
F P
0 g
s
.30662 .71973 m .31044 .75698 L .33441 .74983 L p .707 .577 .707 r
F P
0 g
s
.33441 .74983 m .33059 .71258 L .30662 .71973 L p .707 .577 .707 r
F P
0 g
s
.25623 .80609 m .25154 .78771 L .2214 .7939 L p .707 .577 .707 r
F P
0 g
s
.25154 .78771 m .25623 .80609 L .28714 .79802 L p .707 .577 .707 r
F P
0 g
s
.28714 .79802 m .28245 .77964 L .25154 .78771 L p .707 .577 .707 r
F P
0 g
s
.33484 .64909 m .33241 .70435 L .34877 .6972 L p .707 .577 .707 r
F P
0 g
s
.34877 .6972 m .35121 .64194 L .33484 .64909 L p .707 .577 .707 r
F P
0 g
s
.38842 .80766 m .3716 .30427 L .35384 .29421 L p .707 .577 .707 r
F P
0 g
s
.3716 .30427 m .38842 .80766 L .41812 .81542 L p .707 .577 .707 r
F P
0 g
s
.28245 .77964 m .28714 .79802 L .31578 .78885 L p .707 .577 .707 r
F P
0 g
s
.31578 .78885 m .3111 .77047 L .28245 .77964 L p .707 .577 .707 r
F P
0 g
s
.17004 .63928 m .1676 .69455 L .18863 .70224 L p .707 .577 .707 r
F P
0 g
s
.18738 .72943 m .1912 .76668 L .21849 .7678 L p .707 .577 .707 r
F P
0 g
s
.2214 .7939 m .22608 .81228 L .25623 .80609 L p .707 .577 .707 r
F P
0 g
s
.68176 .7268 m .68558 .76405 L .66468 .76055 L p .707 .577 .707 r
F P
0 g
s
.66468 .76055 m .66086 .7233 L .68176 .7268 L p .707 .577 .707 r
F P
0 g
s
.22608 .81228 m .2214 .7939 L .19496 .79759 L p .707 .577 .707 r
F P
0 g
s
.1676 .69455 m .17004 .63928 L .15747 .63041 L p .707 .577 .707 r
F P
0 g
s
.1912 .76668 m .18738 .72943 L .16647 .72593 L p .707 .577 .707 r
F P
0 g
s
.19496 .79759 m .19965 .81597 L .22608 .81228 L p .707 .577 .707 r
F P
0 g
s
.3111 .77047 m .31578 .78885 L .33936 .77949 L p .707 .577 .707 r
F P
0 g
s
.33936 .77949 m .33468 .7611 L .3111 .77047 L p .707 .577 .707 r
F P
0 g
s
.68686 .7769 m .69154 .79528 L .67141 .79613 L p .707 .577 .707 r
F P
0 g
s
.67141 .79613 m .66673 .77774 L .68686 .7769 L p .707 .577 .707 r
F P
0 g
s
.16647 .72593 m .17029 .76318 L .1912 .76668 L p .707 .577 .707 r
F P
0 g
s
.33059 .71258 m .33441 .74983 L .35076 .74194 L p .707 .577 .707 r
F P
0 g
s
.35076 .74194 m .34694 .70469 L .33059 .71258 L p .707 .577 .707 r
F P
0 g
s
.62746 .29033 m .64428 .79372 L .65428 .78215 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .63746 .27876 L .62746 .29033 L p .707 .577 .707 r
F P
0 g
s
.15747 .63041 m .15503 .68567 L .1676 .69455 L p .707 .577 .707 r
F P
0 g
s
.19965 .81597 m .19496 .79759 L .17483 .79843 L p .707 .577 .707 r
F P
0 g
s
.35121 .64194 m .34877 .6972 L .35586 .68862 L p .707 .577 .707 r
F P
0 g
s
.35586 .68862 m .35829 .63335 L .35121 .64194 L p .707 .577 .707 r
F P
0 g
s
.17483 .79843 m .17952 .81681 L .19965 .81597 L p .707 .577 .707 r
F P
0 g
s
.33468 .7611 m .33936 .77949 L .35557 .77084 L p .707 .577 .707 r
F P
0 g
s
.35557 .77084 m .35089 .75246 L .33468 .7611 L p .707 .577 .707 r
F P
0 g
s
.17029 .76318 m .16647 .72593 L .154 .72039 L p .707 .577 .707 r
F P
0 g
s
.15503 .68567 m .15747 .63041 L .15458 .62124 L p .707 .577 .707 r
F P
0 g
s
.37066 .7976 m .35384 .29421 L .34976 .28283 L p .707 .577 .707 r
F P
0 g
s
.35384 .29421 m .37066 .7976 L .38842 .80766 L p .707 .577 .707 r
F P
0 g
s
.66673 .77774 m .67141 .79613 L .64498 .79982 L p .707 .577 .707 r
F P
0 g
s
.154 .72039 m .15782 .75764 L .17029 .76318 L p .707 .577 .707 r
F P
0 g
s
.34694 .70469 m .35076 .74194 L .35787 .7341 L p .707 .577 .707 r
F P
0 g
s
.35787 .7341 m .35405 .69685 L .34694 .70469 L p .707 .577 .707 r
F P
0 g
s
.17952 .81681 m .17483 .79843 L .16298 .79634 L p .707 .577 .707 r
F P
0 g
s
.15458 .62124 m .15215 .6765 L .15503 .68567 L p .707 .577 .707 r
F P
0 g
s
.16298 .79634 m .16766 .81472 L .17952 .81681 L p .707 .577 .707 r
F P
0 g
s
.35829 .63335 m .35586 .68862 L .35298 .67944 L p .707 .577 .707 r
F P
0 g
s
.35298 .67944 m .35541 .62418 L .35829 .63335 L p .707 .577 .707 r
F P
0 g
s
.35089 .75246 m .35557 .77084 L .36282 .76375 L p .707 .577 .707 r
F P
0 g
s
.36282 .76375 m .35813 .74537 L .35089 .75246 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .65021 .77078 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.65021 .77078 m .63339 .26739 L .63746 .27876 L p .707 .577 .707 r
F P
0 g
s
.63339 .26739 m .65021 .77078 L .63245 .76072 L p .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64669 .67643 L .64519 .67576 L p .707 .577 .707 r
F P
0 g
s
.64519 .67576 m .63422 .67089 L p .64567 .70097 L .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64519 .67576 L .64567 .70097 L .707 .577 .707 r
F
.63746 .27876 m .63809 .29737 L p .63846 .31704 L F P
0 g
s
.63809 .29737 m .65428 .78215 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.15782 .75764 m .154 .72039 L .15118 .71335 L p .707 .577 .707 r
F P
0 g
s
.15215 .6765 m .15458 .62124 L .16167 .61265 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15118 .71335 m .155 .7506 L .15782 .75764 L p .707 .577 .707 r
F P
0 g
s
.35405 .69685 m .35787 .7341 L .35505 .72706 L p .707 .577 .707 r
F P
0 g
s
.35505 .72706 m .35123 .68981 L .35405 .69685 L p .707 .577 .707 r
F P
0 g
s
.16766 .81472 m .16298 .79634 L .16055 .79151 L p .707 .577 .707 r
F P
0 g
s
.16167 .61265 m .15924 .66792 L .15215 .6765 L p .707 .577 .707 r
F P
0 g
s
.16055 .79151 m .16523 .80989 L .16766 .81472 L p .707 .577 .707 r
F P
0 g
s
.34976 .28283 m .36658 .78622 L .37066 .7976 L p .707 .577 .707 r
F P
0 g
s
.36658 .78622 m .34976 .28283 L .35977 .27126 L p .707 .577 .707 r
F P
0 g
s
.35541 .62418 m .35298 .67944 L .34041 .67057 L p .707 .577 .707 r
F P
0 g
s
.34041 .67057 m .34284 .61531 L .35541 .62418 L p .707 .577 .707 r
F P
0 g
s
.35813 .74537 m .36282 .76375 L .36039 .75893 L p .707 .577 .707 r
F P
0 g
s
.36039 .75893 m .35571 .74055 L .35813 .74537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.155 .7506 m .15118 .71335 L .15829 .7055 L p .707 .577 .707 r
F P
0 g
s
.15924 .66792 m .16167 .61265 L .17803 .6055 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15829 .7055 m .16211 .74275 L .155 .7506 L p .707 .577 .707 r
F P
0 g
s
.63245 .76072 m .61563 .25733 L .63339 .26739 L p .707 .577 .707 r
F P
0 g
s
.35123 .68981 m .35505 .72706 L .34257 .72152 L p .707 .577 .707 r
F P
0 g
s
.34257 .72152 m .33875 .68427 L .35123 .68981 L p .707 .577 .707 r
F P
0 g
s
.16523 .80989 m .16055 .79151 L .1678 .78443 L p .707 .577 .707 r
F P
0 g
s
.17803 .6055 m .1756 .66077 L .15924 .66792 L p .707 .577 .707 r
F P
0 g
s
.34284 .61531 m .34041 .67057 L .31938 .66287 L p .707 .577 .707 r
F P
0 g
s
.31938 .66287 m .32181 .60761 L .34284 .61531 L p .707 .577 .707 r
F P
0 g
s
.1678 .78443 m .17248 .80281 L .16523 .80989 L p .707 .577 .707 r
F P
0 g
s
.35571 .74055 m .36039 .75893 L .34853 .75683 L p .707 .577 .707 r
F P
0 g
s
.34853 .75683 m .34385 .73845 L .35571 .74055 L p .707 .577 .707 r
F P
0 g
s
.1756 .66077 m .17803 .6055 L .20207 .60049 L p .707 .577 .707 r
F P
0 g
s
.16211 .74275 m .15829 .7055 L .17464 .69762 L p .707 .577 .707 r
F P
0 g
s
.37659 .77465 m .35977 .27126 L .38287 .26062 L p .707 .577 .707 r
F P
0 g
s
.35977 .27126 m .37659 .77465 L .36658 .78622 L p .707 .577 .707 r
F P
0 g
s
.17464 .69762 m .17846 .73487 L .16211 .74275 L p .707 .577 .707 r
F P
0 g
s
.33875 .68427 m .34257 .72152 L .32167 .71801 L p .707 .577 .707 r
F P
0 g
s
.32167 .71801 m .31785 .68076 L .33875 .68427 L p .707 .577 .707 r
F P
0 g
s
.32181 .60761 m .31938 .66287 L .29195 .6571 L p .707 .577 .707 r
F P
0 g
s
.29195 .6571 m .29438 .60184 L .32181 .60761 L p .707 .577 .707 r
F P
0 g
s
.20207 .60049 m .19964 .65575 L .1756 .66077 L p .707 .577 .707 r
F P
0 g
s
.17248 .80281 m .1678 .78443 L .184 .77578 L p .707 .577 .707 r
F P
0 g
s
.19964 .65575 m .20207 .60049 L .23143 .59809 L p .707 .577 .707 r
F P
0 g
s
.184 .77578 m .18869 .79416 L .17248 .80281 L p .707 .577 .707 r
F P
0 g
s
.61563 .25733 m .63245 .76072 L .60274 .75296 L p .707 .577 .707 r
F P
0 g
s
.60274 .75296 m .58592 .24956 L .61563 .25733 L p .707 .577 .707 r
F P
0 g
s
.34385 .73845 m .34853 .75683 L .3284 .75767 L p .707 .577 .707 r
F P
0 g
s
.3284 .75767 m .32372 .73929 L .34385 .73845 L p .707 .577 .707 r
F P
0 g
s
.17846 .73487 m .17464 .69762 L .19861 .69046 L p .707 .577 .707 r
F P
0 g
s
.29438 .60184 m .29195 .6571 L .26081 .65382 L p .707 .577 .707 r
F P
0 g
s
.26081 .65382 m .26324 .59856 L .29438 .60184 L p .707 .577 .707 r
F P
0 g
s
.229 .65336 m .23143 .59809 L .26324 .59856 L p .707 .577 .707 r
F P
0 g
s
.23143 .59809 m .229 .65336 L .19964 .65575 L p .707 .577 .707 r
F P
0 g
s
.19861 .69046 m .20243 .72771 L .17846 .73487 L p .707 .577 .707 r
F P
0 g
s
.26324 .59856 m .26081 .65382 L .229 .65336 L p .707 .577 .707 r
F P
0 g
s
.31785 .68076 m .32167 .71801 L .29438 .71689 L p .707 .577 .707 r
F P
0 g
s
.29438 .71689 m .29056 .67964 L .31785 .68076 L p .707 .577 .707 r
F P
0 g
s
.72741 .66028 m .72985 .60502 L .69871 .60174 L p .707 .577 .707 r
F P
0 g
s
.72985 .60502 m .72741 .66028 L .75922 .66075 L p .707 .577 .707 r
F P
0 g
s
.75922 .66075 m .76166 .60548 L .72985 .60502 L p .707 .577 .707 r
F P
0 g
s
.38287 .26062 m .39969 .76401 L .37659 .77465 L p .707 .577 .707 r
F P
0 g
s
.39969 .76401 m .38287 .26062 L .41682 .25196 L p .707 .577 .707 r
F P
0 g
s
.76166 .60548 m .75922 .66075 L .78858 .65836 L p .707 .577 .707 r
F P
0 g
s
.78858 .65836 m .79102 .60309 L .76166 .60548 L p .707 .577 .707 r
F P
0 g
s
.18869 .79416 m .184 .77578 L .20758 .76641 L p .707 .577 .707 r
F P
0 g
s
.69627 .657 m .69871 .60174 L .67128 .59597 L p .707 .577 .707 r
F P
0 g
s
.69871 .60174 m .69627 .657 L .72741 .66028 L p .707 .577 .707 r
F P
0 g
s
.20243 .72771 m .19861 .69046 L .22787 .68474 L p .707 .577 .707 r
F P
0 g
s
.20758 .76641 m .21227 .7848 L .18869 .79416 L p .707 .577 .707 r
F P
0 g
s
.32372 .73929 m .3284 .75767 L .30197 .76137 L p .707 .577 .707 r
F P
0 g
s
.30197 .76137 m .29729 .74299 L .32372 .73929 L p .707 .577 .707 r
F P
0 g
s
.29056 .67964 m .29438 .71689 L .26338 .71826 L p .707 .577 .707 r
F P
0 g
s
.26338 .71826 m .25956 .68101 L .29056 .67964 L p .707 .577 .707 r
F P
0 g
s
.79102 .60309 m .78858 .65836 L .81262 .65334 L p .707 .577 .707 r
F P
0 g
s
.81262 .65334 m .81506 .59808 L .79102 .60309 L p .707 .577 .707 r
F P
0 g
s
.22787 .68474 m .23169 .72199 L .20243 .72771 L p .707 .577 .707 r
F P
0 g
s
.58592 .24956 m .60274 .75296 L .564 .74825 L p .707 .577 .707 r
F P
0 g
s
.564 .74825 m .54719 .24486 L .58592 .24956 L p .707 .577 .707 r
F P
0 g
s
.23169 .72199 m .22787 .68474 L .25956 .68101 L p .707 .577 .707 r
F P
0 g
s
.25956 .68101 m .26338 .71826 L .23169 .72199 L p .707 .577 .707 r
F P
0 g
s
.66884 .65123 m .67128 .59597 L .65025 .58827 L p .707 .577 .707 r
F P
0 g
s
.67128 .59597 m .66884 .65123 L .69627 .657 L p .707 .577 .707 r
F P
0 g
s
.72971 .71693 m .72589 .67968 L .69488 .68105 L p .707 .577 .707 r
F P
0 g
s
.72589 .67968 m .72971 .71693 L .76139 .7132 L p .707 .577 .707 r
F P
0 g
s
.76139 .7132 m .75757 .67595 L .72589 .67968 L p .707 .577 .707 r
F P
0 g
s
.75757 .67595 m .76139 .7132 L .79065 .70748 L p .707 .577 .707 r
F P
0 g
s
.79065 .70748 m .78683 .67023 L .75757 .67595 L p .707 .577 .707 r
F P
0 g
s
.21227 .7848 m .20758 .76641 L .23623 .75725 L p .707 .577 .707 r
F P
0 g
s
.23623 .75725 m .24092 .77563 L .21227 .7848 L p .707 .577 .707 r
F P
0 g
s
.29729 .74299 m .30197 .76137 L .27183 .76756 L p .707 .577 .707 r
F P
0 g
s
.27183 .76756 m .26714 .74917 L .29729 .74299 L p .707 .577 .707 r
F P
0 g
s
.43364 .75535 m .41682 .25196 L .45828 .24612 L p .707 .577 .707 r
F P
0 g
s
.41682 .25196 m .43364 .75535 L .39969 .76401 L p .707 .577 .707 r
F P
0 g
s
.6987 .7183 m .69488 .68105 L .66759 .67993 L p .707 .577 .707 r
F P
0 g
s
.69488 .68105 m .6987 .7183 L .72971 .71693 L p .707 .577 .707 r
F P
0 g
s
.73644 .75251 m .73176 .73412 L .70161 .74031 L p .707 .577 .707 r
F P
0 g
s
.73176 .73412 m .73644 .75251 L .76735 .74443 L p .707 .577 .707 r
F P
0 g
s
.76735 .74443 m .76267 .72605 L .73176 .73412 L p .707 .577 .707 r
F P
0 g
s
.24092 .77563 m .23623 .75725 L .26714 .74917 L p .707 .577 .707 r
F P
0 g
s
.78683 .67023 m .79065 .70748 L .81463 .70033 L p .707 .577 .707 r
F P
0 g
s
.81463 .70033 m .81081 .66308 L .78683 .67023 L p .707 .577 .707 r
F P
0 g
s
.81506 .59808 m .81262 .65334 L .82899 .64619 L p .707 .577 .707 r
F P
0 g
s
.82899 .64619 m .83142 .59093 L .81506 .59808 L p .707 .577 .707 r
F P
0 g
s
.76267 .72605 m .76735 .74443 L .796 .73526 L p .707 .577 .707 r
F P
0 g
s
.796 .73526 m .79131 .71688 L .76267 .72605 L p .707 .577 .707 r
F P
0 g
s
.26714 .74917 m .27183 .76756 L .24092 .77563 L p .707 .577 .707 r
F P
0 g
s
.65025 .58827 m .64782 .64353 L .66884 .65123 L p .707 .577 .707 r
F P
0 g
s
.70161 .74031 m .70629 .75869 L .73644 .75251 L p .707 .577 .707 r
F P
0 g
s
.66759 .67993 m .67141 .71718 L .6987 .7183 L p .707 .577 .707 r
F P
0 g
s
.54719 .24486 m .564 .74825 L .52002 .74706 L p .707 .577 .707 r
F P
0 g
s
.52002 .74706 m .5032 .24367 L .54719 .24486 L p .707 .577 .707 r
F P
0 g
s
.70629 .75869 m .70161 .74031 L .67518 .744 L p .707 .577 .707 r
F P
0 g
s
.64782 .64353 m .65025 .58827 L .63768 .5794 L p .707 .577 .707 r
F P
0 g
s
.4751 .74951 m .45828 .24612 L .5032 .24367 L p .707 .577 .707 r
F P
0 g
s
.45828 .24612 m .4751 .74951 L .43364 .75535 L p .707 .577 .707 r
F P
0 g
s
.67141 .71718 m .66759 .67993 L .64669 .67643 L p .707 .577 .707 r
F P
0 g
s
.67518 .744 m .67986 .76239 L .70629 .75869 L p .707 .577 .707 r
F P
0 g
s
.79131 .71688 m .796 .73526 L .81958 .7259 L p .707 .577 .707 r
F P
0 g
s
.81958 .7259 m .81489 .70752 L .79131 .71688 L p .707 .577 .707 r
F P
0 g
s
.5032 .24367 m .52002 .74706 L .4751 .74951 L p .707 .577 .707 r
F P
0 g
s
.64669 .67643 m .65051 .71368 L .67141 .71718 L p .707 .577 .707 r
F P
0 g
s
.81081 .66308 m .81463 .70033 L .83097 .69244 L p .707 .577 .707 r
F P
0 g
s
.83097 .69244 m .82715 .65519 L .81081 .66308 L p .707 .577 .707 r
F P
0 g
s
.63768 .5794 m .63525 .63466 L .64782 .64353 L p .707 .577 .707 r
F P
0 g
s
.67986 .76239 m .67518 .744 L .65505 .74484 L p .707 .577 .707 r
F P
0 g
s
.83142 .59093 m .82899 .64619 L .83607 .63761 L p .707 .577 .707 r
F P
0 g
s
.83607 .63761 m .83851 .58234 L .83142 .59093 L p .707 .577 .707 r
F P
0 g
s
.65505 .74484 m .65973 .76323 L .67986 .76239 L p .707 .577 .707 r
F P
0 g
s
.81489 .70752 m .81958 .7259 L .83578 .71725 L p .707 .577 .707 r
F P
0 g
s
.83578 .71725 m .8311 .69887 L .81489 .70752 L p .707 .577 .707 r
F P
0 g
s
.63525 .63466 m .63768 .5794 L .6348 .57022 L p .707 .577 .707 r
F P
0 g
s
.63422 .67089 m .63804 .70814 L .65051 .71368 L p .707 .577 .707 r
F P
0 g
s
.82715 .65519 m .83097 .69244 L .83808 .6846 L p .707 .577 .707 r
F P
0 g
s
.83808 .6846 m .83426 .64734 L .82715 .65519 L p .707 .577 .707 r
F P
0 g
s
.65973 .76323 m .65505 .74484 L .64319 .74275 L p .707 .577 .707 r
F P
0 g
s
.6348 .57022 m .63236 .62549 L .63525 .63466 L p .707 .577 .707 r
F P
0 g
s
.64319 .74275 m .64787 .76113 L .65973 .76323 L p .707 .577 .707 r
F P
0 g
s
.83851 .58234 m .83607 .63761 L .83319 .62843 L p .707 .577 .707 r
F P
0 g
s
.83319 .62843 m .83563 .57317 L .83851 .58234 L p .707 .577 .707 r
F P
0 g
s
.8311 .69887 m .83578 .71725 L .84303 .71017 L p .707 .577 .707 r
F P
0 g
s
.84303 .71017 m .83835 .69178 L .8311 .69887 L p .707 .577 .707 r
F P
0 g
s
.63804 .70814 m .63422 .67089 L .6314 .66385 L p .707 .577 .707 r
F P
0 g
s
.63236 .62549 m .6348 .57022 L .64188 .56164 L p .707 .577 .707 r
F P
0 g
s
.6314 .66385 m .63522 .7011 L .63804 .70814 L p .707 .577 .707 r
F P
0 g
s
.83426 .64734 m .83808 .6846 L .83526 .67756 L p .707 .577 .707 r
F P
0 g
s
.83526 .67756 m .83144 .64031 L .83426 .64734 L p .707 .577 .707 r
F P
0 g
s
.64787 .76113 m .64319 .74275 L .64076 .73792 L p .707 .577 .707 r
F P
0 g
s
.64076 .73792 m .64545 .75631 L .64787 .76113 L p .707 .577 .707 r
F P
0 g
s
.64188 .56164 m .63945 .6169 L .63236 .62549 L p .707 .577 .707 r
F P
0 g
s
.83563 .57317 m .83319 .62843 L .82062 .61956 L p .707 .577 .707 r
F P
0 g
s
.82062 .61956 m .82305 .5643 L .83563 .57317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83835 .69178 m .84303 .71017 L .84061 .70534 L p .707 .577 .707 r
F P
0 g
s
.84061 .70534 m .83592 .68696 L .83835 .69178 L p .707 .577 .707 r
F P
0 g
s
.63522 .7011 m .6314 .66385 L .63851 .656 L p .707 .577 .707 r
F P
0 g
s
.3844 .61925 m .38684 .56399 L .3557 .56071 L p .707 .577 .707 r
F P
0 g
s
.38684 .56399 m .3844 .61925 L .41621 .61972 L p .707 .577 .707 r
F P
0 g
s
.41621 .61972 m .41865 .56446 L .38684 .56399 L p .707 .577 .707 r
F P
0 g
s
.63945 .6169 m .64188 .56164 L .65825 .55449 L p .707 .577 .707 r
F P
0 g
s
.41865 .56446 m .41621 .61972 L .44557 .61733 L p .707 .577 .707 r
F P
0 g
s
.44557 .61733 m .44801 .56206 L .41865 .56446 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35326 .61598 m .3557 .56071 L .32827 .55494 L p .707 .577 .707 r
F P
0 g
s
.3557 .56071 m .35326 .61598 L .3844 .61925 L p .707 .577 .707 r
F P
0 g
s
.63851 .656 m .64233 .69325 L .63522 .7011 L p .707 .577 .707 r
F P
0 g
s
.83144 .64031 m .83526 .67756 L .82279 .67202 L p .707 .577 .707 r
F P
0 g
s
.82279 .67202 m .81897 .63476 L .83144 .64031 L p .707 .577 .707 r
F P
0 g
s
.44801 .56206 m .44557 .61733 L .46961 .61231 L p .707 .577 .707 r
F P
0 g
s
.46961 .61231 m .47205 .55705 L .44801 .56206 L p .707 .577 .707 r
F P
0 g
s
.64545 .75631 m .64076 .73792 L .64801 .73084 L p .707 .577 .707 r
F P
0 g
s
.65825 .55449 m .65581 .60976 L .63945 .6169 L p .707 .577 .707 r
F P
0 g
s
.64801 .73084 m .65269 .74922 L .64545 .75631 L p .707 .577 .707 r
F P
0 g
s
.82305 .5643 m .82062 .61956 L .79959 .61186 L p .707 .577 .707 r
F P
0 g
s
.79959 .61186 m .80203 .5566 L .82305 .5643 L p .707 .577 .707 r
F P
0 g
s
.32583 .6102 m .32827 .55494 L .30724 .54724 L p .707 .577 .707 r
F P
0 g
s
.32827 .55494 m .32583 .6102 L .35326 .61598 L p .707 .577 .707 r
F P
0 g
s
.3867 .67439 m .38288 .63714 L .35187 .63851 L p .707 .577 .707 r
F P
0 g
s
.38288 .63714 m .3867 .67439 L .41838 .67067 L p .707 .577 .707 r
F P
0 g
s
.41838 .67067 m .41456 .63341 L .38288 .63714 L p .707 .577 .707 r
F P
0 g
s
.83592 .68696 m .84061 .70534 L .82875 .70325 L p .707 .577 .707 r
F P
0 g
s
.82875 .70325 m .82406 .68486 L .83592 .68696 L p .707 .577 .707 r
F P
0 g
s
.41456 .63341 m .41838 .67067 L .44764 .66494 L p .707 .577 .707 r
F P
0 g
s
.44764 .66494 m .44382 .62769 L .41456 .63341 L p .707 .577 .707 r
F P
0 g
s
.65581 .60976 m .65825 .55449 L .68229 .54948 L p .707 .577 .707 r
F P
0 g
s
.35569 .67577 m .35187 .63851 L .32458 .63739 L p .707 .577 .707 r
F P
0 g
s
.35187 .63851 m .35569 .67577 L .3867 .67439 L p .707 .577 .707 r
F P
0 g
s
.64233 .69325 m .63851 .656 L .65485 .64811 L p .707 .577 .707 r
F P
0 g
s
.44382 .62769 m .44764 .66494 L .47162 .65779 L p .707 .577 .707 r
F P
0 g
s
.47162 .65779 m .4678 .62054 L .44382 .62769 L p .707 .577 .707 r
F P
0 g
s
.39343 .71405 m .38875 .69567 L .3586 .70186 L p .707 .577 .707 r
F P
0 g
s
.38875 .69567 m .39343 .71405 L .42434 .70598 L p .707 .577 .707 r
F P
0 g
s
.42434 .70598 m .41966 .6876 L .38875 .69567 L p .707 .577 .707 r
F P
0 g
s
.47205 .55705 m .46961 .61231 L .48598 .60516 L p .707 .577 .707 r
F P
0 g
s
.48598 .60516 m .48841 .5499 L .47205 .55705 L p .707 .577 .707 r
F P
0 g
s
.41966 .6876 m .42434 .70598 L .45299 .69681 L p .707 .577 .707 r
F P
0 g
s
.45299 .69681 m .4483 .67843 L .41966 .6876 L p .707 .577 .707 r
F P
0 g
s
.30724 .54724 m .30481 .60251 L .32583 .6102 L p .707 .577 .707 r
F P
0 g
s
.32458 .63739 m .3284 .67464 L .35569 .67577 L p .707 .577 .707 r
F P
0 g
s
.65485 .64811 m .65867 .68537 L .64233 .69325 L p .707 .577 .707 r
F P
0 g
s
.3586 .70186 m .36328 .72024 L .39343 .71405 L p .707 .577 .707 r
F P
0 g
s
.81897 .63476 m .82279 .67202 L .80189 .66851 L p .707 .577 .707 r
F P
0 g
s
.80189 .66851 m .79806 .63126 L .81897 .63476 L p .707 .577 .707 r
F P
0 g
s
.80203 .5566 m .79959 .61186 L .77217 .60609 L p .707 .577 .707 r
F P
0 g
s
.77217 .60609 m .7746 .55083 L .80203 .5566 L p .707 .577 .707 r
F P
0 g
s
.36328 .72024 m .3586 .70186 L .33217 .70555 L p .707 .577 .707 r
F P
0 g
s
.30481 .60251 m .30724 .54724 L .29467 .53837 L p .707 .577 .707 r
F P
0 g
s
.68229 .54948 m .67985 .60474 L .65581 .60976 L p .707 .577 .707 r
F P
0 g
s
.3284 .67464 m .32458 .63739 L .30368 .63389 L p .707 .577 .707 r
F P
0 g
s
.65269 .74922 m .64801 .73084 L .66422 .72219 L p .707 .577 .707 r
F P
0 g
s
.33217 .70555 m .33685 .72393 L .36328 .72024 L p .707 .577 .707 r
F P
0 g
s
.4483 .67843 m .45299 .69681 L .47657 .68745 L p .707 .577 .707 r
F P
0 g
s
.47657 .68745 m .47189 .66907 L .4483 .67843 L p .707 .577 .707 r
F P
0 g
s
.67985 .60474 m .68229 .54948 L .71165 .54708 L p .707 .577 .707 r
F P
0 g
s
.66422 .72219 m .6689 .74057 L .65269 .74922 L p .707 .577 .707 r
F P
0 g
s
.82406 .68486 m .82875 .70325 L .80862 .70409 L p .707 .577 .707 r
F P
0 g
s
.80862 .70409 m .80393 .68571 L .82406 .68486 L p .707 .577 .707 r
F P
0 g
s
.30368 .63389 m .3075 .67114 L .3284 .67464 L p .707 .577 .707 r
F P
0 g
s
.4678 .62054 m .47162 .65779 L .48796 .64991 L p .707 .577 .707 r
F P
0 g
s
.48796 .64991 m .48414 .61265 L .4678 .62054 L p .707 .577 .707 r
F P
0 g
s
.65867 .68537 m .65485 .64811 L .67882 .64096 L p .707 .577 .707 r
F P
0 g
s
.7746 .55083 m .77217 .60609 L .74102 .60281 L p .707 .577 .707 r
F P
0 g
s
.74102 .60281 m .74346 .54755 L .7746 .55083 L p .707 .577 .707 r
F P
0 g
s
.29467 .53837 m .29223 .59364 L .30481 .60251 L p .707 .577 .707 r
F P
0 g
s
.70921 .60235 m .71165 .54708 L .74346 .54755 L p .707 .577 .707 r
F P
0 g
s
.71165 .54708 m .70921 .60235 L .67985 .60474 L p .707 .577 .707 r
F P
0 g
s
.33685 .72393 m .33217 .70555 L .31204 .70639 L p .707 .577 .707 r
F P
0 g
s
.48841 .5499 m .48598 .60516 L .49306 .59658 L p .707 .577 .707 r
F P
0 g
s
.49306 .59658 m .4955 .54132 L .48841 .5499 L p .707 .577 .707 r
F P
0 g
s
.74346 .54755 m .74102 .60281 L .70921 .60235 L p .707 .577 .707 r
F P
0 g
s
.67882 .64096 m .68265 .67821 L .65867 .68537 L p .707 .577 .707 r
F P
0 g
s
.79806 .63126 m .80189 .66851 L .7746 .66739 L p .707 .577 .707 r
F P
0 g
s
.7746 .66739 m .77078 .63014 L .79806 .63126 L p .707 .577 .707 r
F P
0 g
s
.31204 .70639 m .31672 .72478 L .33685 .72393 L p .707 .577 .707 r
F P
0 g
s
.47189 .66907 m .47657 .68745 L .49277 .6788 L p .707 .577 .707 r
F P
0 g
s
.49277 .6788 m .48809 .66042 L .47189 .66907 L p .707 .577 .707 r
F P
0 g
s
.3075 .67114 m .30368 .63389 L .29121 .62835 L p .707 .577 .707 r
F P
0 g
s
.29223 .59364 m .29467 .53837 L .29179 .5292 L p .707 .577 .707 r
F P
0 g
s
.6689 .74057 m .66422 .72219 L .6878 .71283 L p .707 .577 .707 r
F P
0 g
s
.68265 .67821 m .67882 .64096 L .70809 .63524 L p .707 .577 .707 r
F P
0 g
s
.6878 .71283 m .69248 .73121 L .6689 .74057 L p .707 .577 .707 r
F P
0 g
s
.80393 .68571 m .80862 .70409 L .78219 .70778 L p .707 .577 .707 r
F P
0 g
s
.78219 .70778 m .7775 .6894 L .80393 .68571 L p .707 .577 .707 r
F P
0 g
s
.29121 .62835 m .29503 .6656 L .3075 .67114 L p .707 .577 .707 r
F P
0 g
s
.48414 .61265 m .48796 .64991 L .49507 .64206 L p .707 .577 .707 r
F P
0 g
s
.49507 .64206 m .49125 .60481 L .48414 .61265 L p .707 .577 .707 r
F P
0 g
s
.77078 .63014 m .7746 .66739 L .74359 .66876 L p .707 .577 .707 r
F P
0 g
s
.74359 .66876 m .73977 .63151 L .77078 .63014 L p .707 .577 .707 r
F P
0 g
s
.70809 .63524 m .71191 .67249 L .68265 .67821 L p .707 .577 .707 r
F P
0 g
s
.31672 .72478 m .31204 .70639 L .30018 .7043 L p .707 .577 .707 r
F P
0 g
s
.71191 .67249 m .70809 .63524 L .73977 .63151 L p .707 .577 .707 r
F P
0 g
s
.29179 .5292 m .28935 .58446 L .29223 .59364 L p .707 .577 .707 r
F P
0 g
s
.73977 .63151 m .74359 .66876 L .71191 .67249 L p .707 .577 .707 r
F P
0 g
s
.30018 .7043 m .30486 .72268 L .31672 .72478 L p .707 .577 .707 r
F P
0 g
s
.69248 .73121 m .6878 .71283 L .71645 .70366 L p .707 .577 .707 r
F P
0 g
s
.4955 .54132 m .49306 .59658 L .49018 .5874 L p .707 .577 .707 r
F P
0 g
s
.49018 .5874 m .49262 .53214 L .4955 .54132 L p .707 .577 .707 r
F P
0 g
s
.48809 .66042 m .49277 .6788 L .50002 .67172 L p .707 .577 .707 r
F P
0 g
s
.50002 .67172 m .49534 .65333 L .48809 .66042 L p .707 .577 .707 r
F P
0 g
s
.71645 .70366 m .72113 .72204 L .69248 .73121 L p .707 .577 .707 r
F P
0 g
s
.7775 .6894 m .78219 .70778 L .75204 .71397 L p .707 .577 .707 r
F P
0 g
s
.75204 .71397 m .74736 .69559 L .7775 .6894 L p .707 .577 .707 r
F P
0 g
s
.29503 .6656 m .29121 .62835 L .28839 .62131 L p .707 .577 .707 r
F P
0 g
s
.72113 .72204 m .71645 .70366 L .74736 .69559 L p .707 .577 .707 r
F P
0 g
s
.28935 .58446 m .29179 .5292 L .29887 .52061 L p .707 .577 .707 r
F P
0 g
s
.74736 .69559 m .75204 .71397 L .72113 .72204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28839 .62131 m .29221 .65856 L .29503 .6656 L p .707 .577 .707 r
F P
0 g
s
.49125 .60481 m .49507 .64206 L .49225 .63502 L p .707 .577 .707 r
F P
0 g
s
.49225 .63502 m .48843 .59777 L .49125 .60481 L p .707 .577 .707 r
F P
0 g
s
.30486 .72268 m .30018 .7043 L .29775 .69947 L p .707 .577 .707 r
F P
0 g
s
.29887 .52061 m .29644 .57588 L .28935 .58446 L p .707 .577 .707 r
F P
0 g
s
.29775 .69947 m .30244 .71786 L .30486 .72268 L p .707 .577 .707 r
F P
0 g
s
.49262 .53214 m .49018 .5874 L .47761 .57853 L p .707 .577 .707 r
F P
0 g
s
.47761 .57853 m .48004 .52327 L .49262 .53214 L p .707 .577 .707 r
F P
0 g
s
.49534 .65333 m .50002 .67172 L .4976 .66689 L p .707 .577 .707 r
F P
0 g
s
.4976 .66689 m .49291 .64851 L .49534 .65333 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29221 .65856 m .28839 .62131 L .2955 .61346 L p .707 .577 .707 r
F P
0 g
s
.29644 .57588 m .29887 .52061 L .31524 .51346 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2955 .61346 m .29932 .65071 L .29221 .65856 L p .707 .577 .707 r
F P
0 g
s
.48843 .59777 m .49225 .63502 L .47978 .62948 L p .707 .577 .707 r
F P
0 g
s
.47978 .62948 m .47596 .59223 L .48843 .59777 L p .707 .577 .707 r
F P
0 g
s
.30244 .71786 m .29775 .69947 L .305 .69239 L p .707 .577 .707 r
F P
0 g
s
.31524 .51346 m .3128 .56873 L .29644 .57588 L p .707 .577 .707 r
F P
0 g
s
.48004 .52327 m .47761 .57853 L .45658 .57084 L p .707 .577 .707 r
F P
0 g
s
.45658 .57084 m .45902 .51557 L .48004 .52327 L p .707 .577 .707 r
F P
0 g
s
.305 .69239 m .30968 .71077 L .30244 .71786 L p .707 .577 .707 r
F P
0 g
s
.49291 .64851 m .4976 .66689 L .48574 .6648 L p .707 .577 .707 r
F P
0 g
s
.48574 .6648 m .48105 .64641 L .49291 .64851 L p .707 .577 .707 r
F P
0 g
s
.3128 .56873 m .31524 .51346 L .33928 .50845 L p .707 .577 .707 r
F P
0 g
s
.29932 .65071 m .2955 .61346 L .31184 .60558 L p .707 .577 .707 r
F P
0 g
s
.31184 .60558 m .31566 .64283 L .29932 .65071 L p .707 .577 .707 r
F P
0 g
s
.47596 .59223 m .47978 .62948 L .45887 .62598 L p .707 .577 .707 r
F P
0 g
s
.45887 .62598 m .45505 .58872 L .47596 .59223 L p .707 .577 .707 r
F P
0 g
s
.45902 .51557 m .45658 .57084 L .42915 .56506 L p .707 .577 .707 r
F P
0 g
s
.42915 .56506 m .43159 .5098 L .45902 .51557 L p .707 .577 .707 r
F P
0 g
s
.33928 .50845 m .33684 .56371 L .3128 .56873 L p .707 .577 .707 r
F P
0 g
s
.30968 .71077 m .305 .69239 L .32121 .68374 L p .707 .577 .707 r
F P
0 g
s
.33684 .56371 m .33928 .50845 L .36864 .50606 L p .707 .577 .707 r
F P
0 g
s
.32121 .68374 m .32589 .70212 L .30968 .71077 L p .707 .577 .707 r
F P
0 g
s
.48105 .64641 m .48574 .6648 L .46561 .66564 L p .707 .577 .707 r
F P
0 g
s
.46561 .66564 m .46092 .64725 L .48105 .64641 L p .707 .577 .707 r
F P
0 g
s
.31566 .64283 m .31184 .60558 L .33581 .59842 L p .707 .577 .707 r
F P
0 g
s
.43159 .5098 m .42915 .56506 L .39801 .56179 L p .707 .577 .707 r
F P
0 g
s
.39801 .56179 m .40045 .50652 L .43159 .5098 L p .707 .577 .707 r
F P
0 g
s
.3662 .56132 m .36864 .50606 L .40045 .50652 L p .707 .577 .707 r
F P
0 g
s
.36864 .50606 m .3662 .56132 L .33684 .56371 L p .707 .577 .707 r
F P
0 g
s
.33581 .59842 m .33963 .63568 L .31566 .64283 L p .707 .577 .707 r
F P
0 g
s
.40045 .50652 m .39801 .56179 L .3662 .56132 L p .707 .577 .707 r
F P
0 g
s
.45505 .58872 m .45887 .62598 L .43158 .62485 L p .707 .577 .707 r
F P
0 g
s
.43158 .62485 m .42776 .5876 L .45505 .58872 L p .707 .577 .707 r
F P
0 g
s
.32589 .70212 m .32121 .68374 L .34479 .67438 L p .707 .577 .707 r
F P
0 g
s
.33963 .63568 m .33581 .59842 L .36508 .5927 L p .707 .577 .707 r
F P
0 g
s
.34479 .67438 m .34947 .69276 L .32589 .70212 L p .707 .577 .707 r
F P
0 g
s
.46092 .64725 m .46561 .66564 L .43918 .66933 L p .707 .577 .707 r
F P
0 g
s
.43918 .66933 m .43449 .65095 L .46092 .64725 L p .707 .577 .707 r
F P
0 g
s
.42776 .5876 m .43158 .62485 L .40058 .62623 L p .707 .577 .707 r
F P
0 g
s
.40058 .62623 m .39676 .58897 L .42776 .5876 L p .707 .577 .707 r
F P
0 g
s
.36508 .5927 m .3689 .62995 L .33963 .63568 L p .707 .577 .707 r
F P
0 g
s
.3689 .62995 m .36508 .5927 L .39676 .58897 L p .707 .577 .707 r
F P
0 g
s
.39676 .58897 m .40058 .62623 L .3689 .62995 L p .707 .577 .707 r
F P
0 g
s
.34947 .69276 m .34479 .67438 L .37344 .66521 L p .707 .577 .707 r
F P
0 g
s
.37344 .66521 m .37812 .68359 L .34947 .69276 L p .707 .577 .707 r
F P
0 g
s
.43449 .65095 m .43918 .66933 L .40903 .67552 L p .707 .577 .707 r
F P
0 g
s
.40903 .67552 m .40435 .65713 L .43449 .65095 L p .707 .577 .707 r
F P
0 g
s
.37812 .68359 m .37344 .66521 L .40435 .65713 L p .707 .577 .707 r
F P
0 g
s
.40435 .65713 m .40903 .67552 L .37812 .68359 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo5@00Ogoo001mOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol007Eoo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Eoo`00LWoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`00LGoo001^Ool40004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001^Ool006aoo`8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP<006aoo`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00JWoo001XOol20002
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006Ioo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo
001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol0
06=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`P00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Eoo`00Ggoo1P000eYF00<005YF
FUH00UYF2@000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00eYF0P00IGoo001KOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH600000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000>OolB0015Ool0059oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Moo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPH003moo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo1@000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>goo001BOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000hOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002
000eOol0059oo`03001JEP0000=JEP04001JEUYFFUH800000eYF001JEP02FUHB0006FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF1P0015YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Woo001BOol01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
1P0015YF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000031oo`00
DWoo00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002mo
o`00DWoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001B
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=J
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH30005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo001DOol00`00FUH00005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000hOolG0006Ool20005FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
;Woo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00D0
05YF001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00P00;goo
000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF1@0015YF00<005YFFUH00P00;goo000/Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000EJEP00001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEP00
00P000=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<002moo`00:goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF200000=JEP0000000`001EYF10000UYF00<005YFFUH015YF1@0000=JEP00
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF5`0000=JEP00FUH00eYF0`00;goo000[Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000eYF00<005YFFUH00eYF20000eYF00@005YFFUIJEPX000IJEP03001JEUYF00AJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0009JEP03001JEP0002moo`00:goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0001L0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF
001oo`0^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`001EYF1@001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00<7oo000[
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEPL0009JEP03001JEP00
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ80
00AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
00080003FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002moo`00:goo00<0
05YF00000eYF00@005YFFUIJEPP00003FUH005YF009JEQ<0009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool002]oo`03001JEP0000=JEP@00003FUH005YF00IJ
EP03001JEUYF00EJEPH000AJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo000[Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF1P0015YF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo000[Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`001eYF00<005YFFUH01UYF00<005YFFUH00UYF3@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00:goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0UYF1@000eYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01EYF1P0015YF0P0015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000Ioo`P000=JEP04001JEUYF
FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP0000X000EJEP03001JEUYF00MJEP03001JEUYF00@000IJ
EP@00003FUH005YF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000goo000000030005
Ool400000eYF001JEP05FUH50002FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00MJEP03001JEUYF00AJEPD000=JEP04001JEUYFFUH30005FUH00`00FUIJEP03FUH20004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH70008Ool:0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000^Ool002]oo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQX000=JEP03001JEUYF00IJEP03001JEUYF
00@000QJEP06001JEP00001JEP001eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP03001JEP0001H000=JEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<002ioo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEPT0
00IJEP<000=JEP03001JEUYF00EJEP04001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPX00003FUH007oo02eoo`00;Goo00<005YF00001EYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH00UYF0`000eYF1@000UYF10001UYF00<005YFFUH015YF0`002UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00AJEP04001JEP00000_Ool0
02ioo`8000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEUYF1`000UYF00<005YFFUH01UYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050005FUH0
0`00FUIJEP03FUH00`00FUIJEP02000^Ool002moo`80009JEP@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00=JEP<0009oo`05001JEUYF001J
EP060005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000^Ool0035o
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001J
EUYF009JEP03001JEP0000<00003FUH00000009oo`D0009JEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000_Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00
FUH000050006FUH00`00FUIJEP07FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003
FUH0000002eoo`00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000UYF00@005YFFUIJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEPD000]J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01eYF00@005YF
FUIJEPP0009JEP@002eoo`00:goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF100000=JEP00FUH025YF
00<005YFFUH015YF1P0017oo0P001EYF00<005YF0000;Goo000ZOol01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP04001J
EUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP050005Ool400000eYF001JEP04FUH2000^Ool0
02Yoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH900000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF0000000500000eYF001JEP07FUH00`00FUIJEP04FUH50007Ool30005FUH00`00FUIJ
EP03FUH00`00Oomoo`0]Ool002Yoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90006Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP060008Ool20000
0eYF001JEP06FUH00`00FUIJEP02000`Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP0009oo`<000Ioo`@00003FUH00000009JEP03001JEUYF00T00005Ool005YFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH400000goo000000030005
Ool30004FUH00`00FUIJEP04FUH3000bOol002]oo`04001JEUYF0003FUH00`00FUIJEP03FUH60009
Ool:0006FUH600000eYF001JEP03FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP040005Ool500000goo000000020007FUH00`00FUIJ
EP04FUH00`00Oomoo`0bOol002]oo`04001JEUYF0003FUH00`00FUH0000G0002FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH3000:Ool50002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000eOol002]oo`04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH0
07oo00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF009J
EP@000Qoo`@000MJEP03001JEUYF00IJEP04001JEP00000gOol002]oo`04001JEUYF0002FUH01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH0
15YF1`000goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0005FUH01000FUH0
00000eYF00<007ooOol00Woo100000=JEP00FUH025YF00<005YFFUH01EYF0`00>Goo000[Ool00`00
FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH7
0002FUH00`00FUH000020002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00EJEP800004FUH005YFFUH60006FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol002aoo`04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF
00<005YFFUH00eYF00@005YFFUH0009oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP080003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50010Ool002aoo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000AGoo000/Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEUYFFUH007oo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3000
35YF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50019Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00Ool0
0eYF00<005YFFUH00eYF00<005YFFUH01UYF20002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH010001UYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@0
04ioo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=00001GooFUIJEUYF00001EYF00<005YFFUH00eYF0`001UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUIJEP80
009JEP03001JEUYF00=JEP04001JEUYFFUH6001BOol002eoo`800003FUH005YF00AJEP03001JEUYF
00EJEP@00003FUH005YF00MJEP03001JEUYF00EJEPH000Aoo`8000AJEP04001JEP000003FUH00`00
FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH40004FUH200000eYF001JEP02FUH600000eYF0000001EOol002moo`@000=JEP04
001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool200000eYF001JEP03FUH01000
FUIJEP000eYF00<005YFFUH00eYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009JEP`0009JEP8005Eoo`00<goo
1`0000=JEP00FUH01eYF00<005YFFUH015YF1@002Woo0P000eYF00<005YFFUH00eYF0P0000EooeYF
FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000EJEP03001JEUYF009JEP@005Eoo`00=Woo0P00
0eYF00<005YFFUH01UYF00<005YFFUH0100037oo0`001UYF00@005YFFUIJEP80009oo`=JEP04001J
EP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP03FUH3001EOol003Aoo`8000EJEP03001J
EUYF00EJEPT000Moo`@00003FUH005YF00IJEP04001JEP000004Ool3FUH200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30006FUH600000eYF001oo`1DOol0039oo`<000MJEP03001JEUYF009JEP8000Ao
o`D0009oo`D000EJEP03001JEUYF00AJEP<000Ioo`9JEP05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH000070002FUH01000FUH00000EWoo000`Ool20002FUH00`00FUIJEP05FUH00`00FUH0
00020006Ool70002FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo00=JEP00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000_
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH30007Ool60005FUH00`00FUIJEP06FUH01000FUH00000
2goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
0P00EGoo000^Ool20005FUH00`00FUH000030006Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000=Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH01000
FUIJEP00EGoo000]Ool01000FUIJEP0015YF0P0017oo1P001UYF00<005YFFUH01eYF00<005YFFUH0
10004Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH00eYF
00@005YFFUH005Eoo`00;Goo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP@001Eoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP02FUH>001D
Ool002eoo`04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000JOol20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUH00000FUH01P0017oo0P0015YF00@005YF000005Ao
o`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008001moo`<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEPL000Moo`800003FUH005YF00AJEP03001JEP0005Aoo`00;Woo0`0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH00UYF1@0097oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF1@002Woo0P000eYF00<005YFFUH00eYF0P00
EGoo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH6000[Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00004000;Ool30006FUH0
1000FUIJEUYF0P00EWoo000_Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04000eOol50008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH700000goo000000030006Ool400000eYF
001JEP06FUH01000FUH00000F7oo000aOol:000nOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04
FUH<00000eYF00000005Ool500000goo000000030006FUH00`00FUIJEP04FUH2001JOol007mooaH0
0003FUH005YF00EJEP03001JEP00008000Moo`H0009JEP03001JEUYF00IJEP03001JEUYF009JEP80
05aoo`00T7oo0P0015YF00<005YFFUH00eYF0`0027oo1P001EYF00<005YFFUH01UYF00@005YF0000
05ioo`00Sgoo00<005YF00001EYF00<005YF00000P001goo100000=JEP00FUH025YF00<005YFFUH0
1EYF0`00H7oo002?Ool00`00FUH00005FUH20004Ool60006FUH00`00FUIJEP07FUH00`00FUIJEP04
001SOol008moo`04001JEUYF0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4001WOol0
08moo`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<006]o
o`00T7oo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006ioo`00
T7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P00LGoo002@Ool20002FUH0
0`00FUIJEP03FUH01000FUIJEUYF2000Mgoo002AOol200000eYF001JEP02FUH6001oOol009=oo`D0
08Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58652 .75403 m .59046 .69902 L .55937 .6949 L p .707 .577 .707 r
F P
0 g
s
.59046 .69902 m .58652 .75403 L .61829 .75526 L p .707 .577 .707 r
F P
0 g
s
.61829 .75526 m .62222 .70025 L .59046 .69902 L p .707 .577 .707 r
F P
0 g
s
.62222 .70025 m .61829 .75526 L .64761 .75348 L p .707 .577 .707 r
F P
0 g
s
.64761 .75348 m .65155 .69847 L .62222 .70025 L p .707 .577 .707 r
F P
0 g
s
.55543 .7499 m .55937 .6949 L .53199 .68828 L p .707 .577 .707 r
F P
0 g
s
.55937 .6949 m .55543 .7499 L .58652 .75403 L p .707 .577 .707 r
F P
0 g
s
.65155 .69847 m .64761 .75348 L .67163 .74885 L p .707 .577 .707 r
F P
0 g
s
.67163 .74885 m .67556 .69384 L .65155 .69847 L p .707 .577 .707 r
F P
0 g
s
.52805 .74329 m .53199 .68828 L .511 .67982 L p .707 .577 .707 r
F P
0 g
s
.53199 .68828 m .52805 .74329 L .55543 .7499 L p .707 .577 .707 r
F P
0 g
s
.59008 .80831 m .58392 .77115 L .55319 .77455 L p .707 .577 .707 r
F P
0 g
s
.58392 .77115 m .59008 .80831 L .62152 .80276 L p .707 .577 .707 r
F P
0 g
s
.62152 .80276 m .61536 .7656 L .58392 .77115 L p .707 .577 .707 r
F P
0 g
s
.61536 .7656 m .62152 .80276 L .65059 .79559 L p .707 .577 .707 r
F P
0 g
s
.65059 .79559 m .64443 .75843 L .61536 .7656 L p .707 .577 .707 r
F P
0 g
s
.55319 .77455 m .55935 .81171 L .59008 .80831 L p .707 .577 .707 r
F P
0 g
s
.55935 .81171 m .55319 .77455 L .52617 .77545 L p .707 .577 .707 r
F P
0 g
s
.60008 .83994 m .59265 .82229 L .56414 .83334 L p .707 .577 .707 r
F P
0 g
s
.59265 .82229 m .60008 .83994 L .62952 .82748 L p .707 .577 .707 r
F P
0 g
s
.62952 .82748 m .62208 .80984 L .59265 .82229 L p .707 .577 .707 r
F P
0 g
s
.62208 .80984 m .62952 .82748 L .65699 .81483 L p .707 .577 .707 r
F P
0 g
s
.65699 .81483 m .64956 .79719 L .62208 .80984 L p .707 .577 .707 r
F P
0 g
s
.56414 .83334 m .57157 .85098 L .60008 .83994 L p .707 .577 .707 r
F P
0 g
s
.64443 .75843 m .65059 .79559 L .67444 .78751 L p .707 .577 .707 r
F P
0 g
s
.67444 .78751 m .66828 .75035 L .64443 .75843 L p .707 .577 .707 r
F P
0 g
s
.67556 .69384 m .67163 .74885 L .68799 .74183 L p .707 .577 .707 r
F P
0 g
s
.68799 .74183 m .69192 .68682 L .67556 .69384 L p .707 .577 .707 r
F P
0 g
s
.511 .67982 m .50707 .73483 L .52805 .74329 L p .707 .577 .707 r
F P
0 g
s
.52617 .77545 m .53233 .81261 L .55935 .81171 L p .707 .577 .707 r
F P
0 g
s
.57157 .85098 m .56414 .83334 L .53934 .8419 L p .707 .577 .707 r
F P
0 g
s
.50707 .73483 m .511 .67982 L .49847 .67034 L p .707 .577 .707 r
F P
0 g
s
.64956 .79719 m .65699 .81483 L .67982 .80323 L p .707 .577 .707 r
F P
0 g
s
.67982 .80323 m .67239 .78559 L .64956 .79719 L p .707 .577 .707 r
F P
0 g
s
.53934 .8419 m .54677 .85954 L .57157 .85098 L p .707 .577 .707 r
F P
0 g
s
.53233 .81261 m .52617 .77545 L .50551 .77377 L p .707 .577 .707 r
F P
0 g
s
.66828 .75035 m .67444 .78751 L .69074 .7793 L p .707 .577 .707 r
F P
0 g
s
.69074 .7793 m .68458 .74214 L .66828 .75035 L p .707 .577 .707 r
F P
0 g
s
.50551 .77377 m .51167 .81093 L .53233 .81261 L p .707 .577 .707 r
F P
0 g
s
.49847 .67034 m .49453 .72535 L .50707 .73483 L p .707 .577 .707 r
F P
0 g
s
.54677 .85954 m .53934 .8419 L .52068 .84712 L p .707 .577 .707 r
F P
0 g
s
.52068 .84712 m .52812 .86476 L .54677 .85954 L p .707 .577 .707 r
F P
0 g
s
.69192 .68682 m .68799 .74183 L .69508 .73312 L p .707 .577 .707 r
F P
0 g
s
.69508 .73312 m .69902 .67811 L .69192 .68682 L p .707 .577 .707 r
F P
0 g
s
.67239 .78559 m .67982 .80323 L .69577 .79381 L p .707 .577 .707 r
F P
0 g
s
.69577 .79381 m .68834 .77617 L .67239 .78559 L p .707 .577 .707 r
F P
0 g
s
.49453 .72535 m .49847 .67034 L .49561 .66077 L p .707 .577 .707 r
F P
0 g
s
.51167 .81093 m .50551 .77377 L .49323 .76968 L p .707 .577 .707 r
F P
0 g
s
.49323 .76968 m .4994 .80684 L .51167 .81093 L p .707 .577 .707 r
F P
0 g
s
.68458 .74214 m .69074 .7793 L .69789 .77177 L p .707 .577 .707 r
F P
0 g
s
.69789 .77177 m .69173 .73461 L .68458 .74214 L p .707 .577 .707 r
F P
0 g
s
.52812 .86476 m .52068 .84712 L .51 .84851 L p .707 .577 .707 r
F P
0 g
s
.51 .84851 m .51743 .86615 L .52812 .86476 L p .707 .577 .707 r
F P
0 g
s
.49561 .66077 m .49167 .71578 L .49453 .72535 L p .707 .577 .707 r
F P
0 g
s
.68834 .77617 m .69577 .79381 L .70328 .7875 L p .707 .577 .707 r
F P
0 g
s
.70328 .7875 m .69584 .76986 L .68834 .77617 L p .707 .577 .707 r
F P
0 g
s
.69902 .67811 m .69508 .73312 L .69222 .72355 L p .707 .577 .707 r
F P
0 g
s
.69222 .72355 m .69616 .66854 L .69902 .67811 L p .707 .577 .707 r
F P
0 g
s
.49167 .71578 m .49561 .66077 L .5027 .65206 L p .707 .577 .707 r
F P
0 g
s
.5027 .65206 m .49877 .70707 L .49167 .71578 L p .707 .577 .707 r
F P
0 g
s
.49877 .70707 m .5027 .65206 L .51906 .64504 L p .707 .577 .707 r
F P
0 g
s
.4994 .80684 m .49323 .76968 L .49054 .76357 L p .707 .577 .707 r
F P
0 g
s
.49054 .76357 m .4967 .80073 L .4994 .80684 L p .707 .577 .707 r
F P
0 g
s
.49769 .75605 m .50385 .79321 L .4967 .80073 L p .707 .577 .707 r
F P
0 g
s
.51906 .64504 m .51512 .70005 L .49877 .70707 L p .707 .577 .707 r
F P
0 g
s
.50385 .79321 m .49769 .75605 L .51399 .74784 L p .707 .577 .707 r
F P
0 g
s
.51399 .74784 m .52015 .785 L .50385 .79321 L p .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .48004 .31682 L .4361 .31656 L p .707 .577 .707 r
F P
0 g
s
.51512 .70005 m .51906 .64504 L .54308 .64041 L p .707 .577 .707 r
F P
0 g
s
.54308 .64041 m .53914 .69542 L .51512 .70005 L p .707 .577 .707 r
F P
0 g
s
.52015 .785 m .51399 .74784 L .53784 .73976 L p .707 .577 .707 r
F P
0 g
s
.53784 .73976 m .54401 .77692 L .52015 .785 L p .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .53784 .73976 L .54849 .73713 L p .707 .577 .707 r
F P
0 g
s
.54849 .73713 m .56691 .73259 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .54849 .73713 L .55487 .75589 L .707 .577 .707 r
F
.56691 .73259 m .57307 .76975 L .56062 .77282 L p F P
0 g
s
.56062 .77282 m .54401 .77692 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.55487 .75589 m .56691 .73259 L .56062 .77282 L .707 .577 .707 r
F
.52493 .31353 m .48004 .31682 L p .53472 .69659 L F P
0 g
s
.55213 .81755 m .54766 .73468 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .54308 .64041 L .56911 .63883 L p .707 .577 .707 r
F P
0 g
s
.56911 .63883 m .5724 .63863 L p .56675 .64828 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .56911 .63883 L .56675 .64828 L .707 .577 .707 r
F
.5724 .63863 m .56847 .69364 L .53914 .69542 L p F P
0 g
s
.54621 .7304 m .52493 .31353 L .53472 .69659 L .707 .577 .707 r
F
.54766 .73468 m .54721 .72638 L p .54621 .7304 L F P
0 g
s
.54721 .72638 m .52493 .31353 L p .54621 .7304 L .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .55213 .81755 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.48004 .31682 m .49409 .57699 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.49409 .57699 m .50725 .82083 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.56847 .69364 m .5724 .63863 L .60417 .63986 L p .707 .577 .707 r
F P
0 g
s
.60417 .63986 m .60023 .69487 L .56847 .69364 L p .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .56691 .73259 L .57934 .73039 L p .707 .577 .707 r
F P
0 g
s
.57934 .73039 m .59835 .72703 L p .57888 .75993 L .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .57934 .73039 L .57888 .75993 L .707 .577 .707 r
F
.63526 .64399 m .63132 .699 L .60023 .69487 L p F P
0 g
s
.60023 .69487 m .60417 .63986 L .63526 .64399 L p .707 .577 .707 r
F P
0 g
s
.62908 .72364 m .63524 .7608 L .60451 .76419 L p .707 .577 .707 r
F P
0 g
s
.60451 .76419 m .59835 .72703 L .62908 .72364 L p .707 .577 .707 r
F P
0 g
s
.59835 .72703 m .60451 .76419 L .57307 .76975 L p .707 .577 .707 r
F P
0 g
s
.64003 .78243 m .64746 .80007 L .61895 .81112 L p .707 .577 .707 r
F P
0 g
s
.61895 .81112 m .61152 .79348 L .64003 .78243 L p .707 .577 .707 r
F P
0 g
s
.58952 .82358 m .58208 .80593 L .61152 .79348 L p .707 .577 .707 r
F P
0 g
s
.61152 .79348 m .61895 .81112 L .58952 .82358 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .62749 .80195 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56636 .30703 m .58157 .58875 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.58157 .58875 m .59357 .81104 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56204 .83623 m .55461 .81858 L .58208 .80593 L p .707 .577 .707 r
F P
0 g
s
.58208 .80593 m .58952 .82358 L .56204 .83623 L p .707 .577 .707 r
F P
0 g
s
.52493 .31353 m .55213 .81755 L .59357 .81104 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .56636 .30703 L .52493 .31353 L p .707 .577 .707 r
F P
0 g
s
.46331 .82057 m .4361 .31656 L .3974 .31278 L p .707 .577 .707 r
F P
0 g
s
.4967 .80073 m .49054 .76357 L .49769 .75605 L p .707 .577 .707 r
F P
0 g
s
.4361 .31656 m .46331 .82057 L .50725 .82083 L p .707 .577 .707 r
F P
0 g
s
.69173 .73461 m .69789 .77177 L .6952 .76567 L p .707 .577 .707 r
F P
0 g
s
.6952 .76567 m .68904 .72851 L .69173 .73461 L p .707 .577 .707 r
F P
0 g
s
.51743 .86615 m .51 .84851 L .50832 .84591 L p .707 .578 .707 r
F P
0 g
s
.50832 .84591 m .51576 .86356 L .51743 .86615 L p .707 .578 .707 r
F P
0 g
s
.69584 .76986 m .70328 .7875 L .7016 .78491 L p .707 .578 .707 r
F P
0 g
s
.7016 .78491 m .69417 .76727 L .69584 .76986 L p .707 .578 .707 r
F P
0 g
s
.62749 .80195 m .60029 .29794 L .56636 .30703 L p .707 .577 .707 r
F P
0 g
s
.69616 .66854 m .69222 .72355 L .67969 .71407 L p .707 .577 .707 r
F P
0 g
s
.67969 .71407 m .68362 .65907 L .69616 .66854 L p .707 .577 .707 r
F P
0 g
s
.24351 .7104 m .24745 .65539 L .21636 .65127 L p .707 .577 .707 r
F P
0 g
s
.24745 .65539 m .24351 .7104 L .27528 .71163 L p .707 .577 .707 r
F P
0 g
s
.27528 .71163 m .27921 .65662 L .24745 .65539 L p .707 .577 .707 r
F P
0 g
s
.27921 .65662 m .27528 .71163 L .3046 .70985 L p .707 .577 .707 r
F P
0 g
s
.3046 .70985 m .30854 .65484 L .27921 .65662 L p .707 .577 .707 r
F P
0 g
s
.42461 .81679 m .3974 .31278 L .36774 .30585 L p .707 .577 .707 r
F P
0 g
s
.3974 .31278 m .42461 .81679 L .46331 .82057 L p .707 .577 .707 r
F P
0 g
s
.21242 .70628 m .21636 .65127 L .18898 .64465 L p .707 .577 .707 r
F P
0 g
s
.21636 .65127 m .21242 .70628 L .24351 .7104 L p .707 .577 .707 r
F P
0 g
s
.68904 .72851 m .6952 .76567 L .68292 .76157 L p .707 .577 .707 r
F P
0 g
s
.68292 .76157 m .67676 .72441 L .68904 .72851 L p .707 .577 .707 r
F P
0 g
s
.30854 .65484 m .3046 .70985 L .32862 .70522 L p .707 .577 .707 r
F P
0 g
s
.32862 .70522 m .33256 .65021 L .30854 .65484 L p .707 .577 .707 r
F P
0 g
s
.51576 .86356 m .50832 .84591 L .51583 .8396 L p .707 .577 .707 r
F P
0 g
s
.66264 .6506 m .6587 .70561 L .63132 .699 L p .707 .577 .707 r
F P
0 g
s
.63132 .699 m .63526 .64399 L .66264 .6506 L p .707 .577 .707 r
F P
0 g
s
.6561 .72273 m .66226 .7599 L .63524 .7608 L p .707 .577 .707 r
F P
0 g
s
.63524 .7608 m .62908 .72364 L .6561 .72273 L p .707 .577 .707 r
F P
0 g
s
.64746 .80007 m .64003 .78243 L .66483 .77388 L p .707 .577 .707 r
F P
0 g
s
.60029 .29794 m .62749 .80195 L .65059 .79117 L p .707 .577 .707 r
F P
0 g
s
.65059 .79117 m .62339 .28716 L .60029 .29794 L p .707 .577 .707 r
F P
0 g
s
.51583 .8396 m .52326 .85724 L .51576 .86356 L p .707 .577 .707 r
F P
0 g
s
.68362 .65907 m .67969 .71407 L .6587 .70561 L p .707 .577 .707 r
F P
0 g
s
.6587 .70561 m .66264 .6506 L .68362 .65907 L p .707 .577 .707 r
F P
0 g
s
.18504 .69966 m .18898 .64465 L .16799 .63619 L p .707 .577 .707 r
F P
0 g
s
.18898 .64465 m .18504 .69966 L .21242 .70628 L p .707 .577 .707 r
F P
0 g
s
.69417 .76727 m .7016 .78491 L .69092 .78629 L p .707 .577 .707 r
F P
0 g
s
.69092 .78629 m .68348 .76865 L .69417 .76727 L p .707 .577 .707 r
F P
0 g
s
.24708 .76224 m .24091 .72508 L .21018 .72847 L p .707 .577 .707 r
F P
0 g
s
.24091 .72508 m .24708 .76224 L .27851 .75668 L p .707 .577 .707 r
F P
0 g
s
.27851 .75668 m .27235 .71952 L .24091 .72508 L p .707 .577 .707 r
F P
0 g
s
.27235 .71952 m .27851 .75668 L .30758 .74952 L p .707 .577 .707 r
F P
0 g
s
.30758 .74952 m .30142 .71235 L .27235 .71952 L p .707 .577 .707 r
F P
0 g
s
.21018 .72847 m .21634 .76563 L .24708 .76224 L p .707 .577 .707 r
F P
0 g
s
.21634 .76563 m .21018 .72847 L .18316 .72938 L p .707 .577 .707 r
F P
0 g
s
.25707 .80048 m .24964 .78283 L .22113 .79388 L p .707 .577 .707 r
F P
0 g
s
.24964 .78283 m .25707 .80048 L .28651 .78802 L p .707 .577 .707 r
F P
0 g
s
.28651 .78802 m .27908 .77038 L .24964 .78283 L p .707 .577 .707 r
F P
0 g
s
.30142 .71235 m .30758 .74952 L .33143 .74143 L p .707 .577 .707 r
F P
0 g
s
.33143 .74143 m .32527 .70427 L .30142 .71235 L p .707 .577 .707 r
F P
0 g
s
.27908 .77038 m .28651 .78802 L .31399 .77537 L p .707 .577 .707 r
F P
0 g
s
.31399 .77537 m .30655 .75773 L .27908 .77038 L p .707 .577 .707 r
F P
0 g
s
.22113 .79388 m .22856 .81152 L .25707 .80048 L p .707 .577 .707 r
F P
0 g
s
.33256 .65021 m .32862 .70522 L .34498 .6982 L p .707 .577 .707 r
F P
0 g
s
.34498 .6982 m .34891 .6432 L .33256 .65021 L p .707 .577 .707 r
F P
0 g
s
.39494 .80986 m .36774 .30585 L .35001 .29645 L p .707 .577 .707 r
F P
0 g
s
.36774 .30585 m .39494 .80986 L .42461 .81679 L p .707 .577 .707 r
F P
0 g
s
.18316 .72938 m .18932 .76654 L .21634 .76563 L p .707 .577 .707 r
F P
0 g
s
.16799 .63619 m .16406 .6912 L .18504 .69966 L p .707 .577 .707 r
F P
0 g
s
.67676 .72441 m .68292 .76157 L .66226 .7599 L p .707 .577 .707 r
F P
0 g
s
.66226 .7599 m .6561 .72273 L .67676 .72441 L p .707 .577 .707 r
F P
0 g
s
.16406 .6912 m .16799 .63619 L .15546 .62671 L p .707 .577 .707 r
F P
0 g
s
.22856 .81152 m .22113 .79388 L .19633 .80243 L p .707 .577 .707 r
F P
0 g
s
.30655 .75773 m .31399 .77537 L .33682 .76377 L p .707 .577 .707 r
F P
0 g
s
.33682 .76377 m .32938 .74613 L .30655 .75773 L p .707 .577 .707 r
F P
0 g
s
.19633 .80243 m .20376 .82008 L .22856 .81152 L p .707 .577 .707 r
F P
0 g
s
.18932 .76654 m .18316 .72938 L .1625 .7277 L p .707 .577 .707 r
F P
0 g
s
.52326 .85724 m .51583 .8396 L .53178 .83018 L p .707 .577 .707 r
F P
0 g
s
.53178 .83018 m .53921 .84783 L .52326 .85724 L p .707 .577 .707 r
F P
0 g
s
.68348 .76865 m .69092 .78629 L .67226 .79152 L p .707 .577 .707 r
F P
0 g
s
.67226 .79152 m .66483 .77388 L .68348 .76865 L p .707 .577 .707 r
F P
0 g
s
.32527 .70427 m .33143 .74143 L .34773 .73323 L p .707 .577 .707 r
F P
0 g
s
.34773 .73323 m .34157 .69606 L .32527 .70427 L p .707 .577 .707 r
F P
0 g
s
.1625 .7277 m .16866 .76486 L .18932 .76654 L p .707 .577 .707 r
F P
0 g
s
.62339 .28716 m .65059 .79117 L .6606 .77974 L p .707 .577 .707 r
F P
0 g
s
.6606 .77974 m .6334 .27573 L .62339 .28716 L p .707 .577 .707 r
F P
0 g
s
.15546 .62671 m .15152 .68172 L .16406 .6912 L p .707 .577 .707 r
F P
0 g
s
.20376 .82008 m .19633 .80243 L .17768 .80766 L p .707 .577 .707 r
F P
0 g
s
.34891 .6432 m .34498 .6982 L .35207 .68949 L p .707 .577 .707 r
F P
0 g
s
.35207 .68949 m .35601 .63448 L .34891 .6432 L p .707 .577 .707 r
F P
0 g
s
.17768 .80766 m .18511 .8253 L .20376 .82008 L p .707 .577 .707 r
F P
0 g
s
.32938 .74613 m .33682 .76377 L .35276 .75435 L p .707 .577 .707 r
F P
0 g
s
.35276 .75435 m .34533 .73671 L .32938 .74613 L p .707 .577 .707 r
F P
0 g
s
.16866 .76486 m .1625 .7277 L .15023 .72361 L p .707 .577 .707 r
F P
0 g
s
.15152 .68172 m .15546 .62671 L .1526 .61714 L p .707 .577 .707 r
F P
0 g
s
.53921 .84783 m .53178 .83018 L .55461 .81858 L p .707 .577 .707 r
F P
0 g
s
.55461 .81858 m .56204 .83623 L .53921 .84783 L p .707 .577 .707 r
F P
0 g
s
.66483 .77388 m .67226 .79152 L .64746 .80007 L p .707 .577 .707 r
F P
0 g
s
.37721 .80047 m .35001 .29645 L .34595 .28551 L p .707 .577 .707 r
F P
0 g
s
.35001 .29645 m .37721 .80047 L .39494 .80986 L p .707 .577 .707 r
F P
0 g
s
.15023 .72361 m .15639 .76077 L .16866 .76486 L p .707 .577 .707 r
F P
0 g
s
.34157 .69606 m .34773 .73323 L .35488 .7257 L p .707 .577 .707 r
F P
0 g
s
.35488 .7257 m .34872 .68854 L .34157 .69606 L p .707 .577 .707 r
F P
0 g
s
.18511 .8253 m .17768 .80766 L .16699 .80904 L p .707 .577 .707 r
F P
0 g
s
.1526 .61714 m .14866 .67215 L .15152 .68172 L p .707 .577 .707 r
F P
0 g
s
.16699 .80904 m .17442 .82669 L .18511 .8253 L p .707 .577 .707 r
F P
0 g
s
.34533 .73671 m .35276 .75435 L .36027 .74804 L p .707 .577 .707 r
F P
0 g
s
.36027 .74804 m .35283 .7304 L .34533 .73671 L p .707 .577 .707 r
F P
0 g
s
.35601 .63448 m .35207 .68949 L .34921 .67992 L p .707 .577 .707 r
F P
0 g
s
.34921 .67992 m .35315 .62491 L .35601 .63448 L p .707 .577 .707 r
F P
0 g
s
.62934 .26478 m .65654 .7688 L .63881 .7594 L p .707 .577 .707 r
F P
0 g
s
.64427 .64279 m .64654 .61106 L p .63567 .5783 L .707 .577 .707 r
F P
0 g
s
.65338 .70144 m .6334 .27573 L .65898 .77536 L .707 .577 .707 r
F
.65654 .7688 m .64455 .5465 L p .6334 .27573 L F P
0 g
s
.64455 .5465 m .62934 .26478 L .6317 .27114 L p .707 .577 .707 r
F P
0 g
s
.6317 .27114 m .6334 .27573 L p .64455 .5465 L .707 .577 .707 r
F P
0 g
s
.6334 .27573 m .6606 .77974 L .65898 .77536 L p .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .66338 .68341 L .65089 .6824 L p .707 .577 .707 r
F P
0 g
s
.65089 .6824 m .64272 .68173 L p .65145 .69437 L .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .65089 .6824 L .65145 .69437 L .707 .577 .707 r
F
.64654 .61106 m .64821 .58778 L .64457 .58503 L p F P
0 g
s
.64457 .58503 m .63567 .5783 L p .64654 .61106 L .707 .577 .707 r
F P
0 g
s
.65898 .77536 m .65654 .7688 L p .65338 .70144 L .707 .577 .707 r
F P
0 g
s
.15639 .76077 m .15023 .72361 L .14753 .7175 L p .707 .577 .707 r
F P
0 g
s
.14866 .67215 m .1526 .61714 L .15969 .60843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.14753 .7175 m .15369 .75466 L .15639 .76077 L p .707 .577 .707 r
F P
0 g
s
.34872 .68854 m .35488 .7257 L .35219 .71959 L p .707 .577 .707 r
F P
0 g
s
.35219 .71959 m .34603 .68243 L .34872 .68854 L p .707 .577 .707 r
F P
0 g
s
.17442 .82669 m .16699 .80904 L .16531 .80645 L p .707 .578 .707 r
F P
0 g
s
.15969 .60843 m .15576 .66344 L .14866 .67215 L p .707 .577 .707 r
F P
0 g
s
.16531 .80645 m .17275 .8241 L .17442 .82669 L p .707 .578 .707 r
F P
0 g
s
.35283 .7304 m .36027 .74804 L .35859 .74545 L p .707 .578 .707 r
F P
0 g
s
.35859 .74545 m .35116 .7278 L .35283 .7304 L p .707 .578 .707 r
F P
0 g
s
.34595 .28551 m .37315 .78952 L .37721 .80047 L p .707 .577 .707 r
F P
0 g
s
.37315 .78952 m .34595 .28551 L .35596 .27408 L p .707 .577 .707 r
F P
0 g
s
.35315 .62491 m .34921 .67992 L .33668 .67045 L p .707 .577 .707 r
F P
0 g
s
.33668 .67045 m .34061 .61544 L .35315 .62491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15576 .66344 m .15969 .60843 L .17605 .60141 L p .707 .577 .707 r
F P
0 g
s
.15369 .75466 m .14753 .7175 L .15468 .70997 L p .707 .577 .707 r
F P
0 g
s
.15468 .70997 m .16085 .74713 L .15369 .75466 L p .707 .577 .707 r
F P
0 g
s
.34603 .68243 m .35219 .71959 L .33991 .7155 L p .707 .577 .707 r
F P
0 g
s
.33991 .7155 m .33375 .67834 L .34603 .68243 L p .707 .577 .707 r
F P
0 g
s
.63881 .7594 m .61161 .25539 L .62934 .26478 L p .707 .577 .707 r
F P
0 g
s
.17605 .60141 m .17211 .65642 L .15576 .66344 L p .707 .577 .707 r
F P
0 g
s
.17275 .8241 m .16531 .80645 L .17282 .80014 L p .707 .577 .707 r
F P
0 g
s
.34061 .61544 m .33668 .67045 L .31569 .66198 L p .707 .577 .707 r
F P
0 g
s
.31569 .66198 m .31963 .60697 L .34061 .61544 L p .707 .577 .707 r
F P
0 g
s
.17282 .80014 m .18025 .81778 L .17275 .8241 L p .707 .577 .707 r
F P
0 g
s
.35116 .7278 m .35859 .74545 L .34791 .74683 L p .707 .577 .707 r
F P
0 g
s
.34791 .74683 m .34047 .72919 L .35116 .7278 L p .707 .577 .707 r
F P
0 g
s
.17211 .65642 m .17605 .60141 L .20007 .59678 L p .707 .577 .707 r
F P
0 g
s
.16085 .74713 m .15468 .70997 L .17098 .70176 L p .707 .577 .707 r
F P
0 g
s
.38316 .7781 m .35596 .27408 L .37905 .2633 L p .707 .577 .707 r
F P
0 g
s
.35596 .27408 m .38316 .7781 L .37315 .78952 L p .707 .577 .707 r
F P
0 g
s
.17098 .70176 m .17714 .73893 L .16085 .74713 L p .707 .577 .707 r
F P
0 g
s
.33375 .67834 m .33991 .7155 L .31925 .71382 L p .707 .577 .707 r
F P
0 g
s
.31925 .71382 m .31309 .67666 L .33375 .67834 L p .707 .577 .707 r
F P
0 g
s
.31963 .60697 m .31569 .66198 L .28831 .65537 L p .707 .577 .707 r
F P
0 g
s
.28831 .65537 m .29225 .60036 L .31963 .60697 L p .707 .577 .707 r
F P
0 g
s
.20007 .59678 m .19613 .65179 L .17211 .65642 L p .707 .577 .707 r
F P
0 g
s
.19613 .65179 m .20007 .59678 L .22939 .595 L p .707 .577 .707 r
F P
0 g
s
.18025 .81778 m .17282 .80014 L .18877 .79072 L p .707 .577 .707 r
F P
0 g
s
.18877 .79072 m .1962 .80837 L .18025 .81778 L p .707 .577 .707 r
F P
0 g
s
.34047 .72919 m .34791 .74683 L .32925 .75206 L p .707 .577 .707 r
F P
0 g
s
.32925 .75206 m .32182 .73442 L .34047 .72919 L p .707 .577 .707 r
F P
0 g
s
.61161 .25539 m .63389 .66823 L p .63308 .671 L .707 .577 .707 r
F P
0 g
s
.60915 .75248 m .61005 .5702 L .63308 .671 L .707 .577 .707 r
F
.61005 .5702 m .61161 .25539 L .63308 .671 L F
.64888 .71889 m .64272 .68173 L .63494 .67914 L p F P
0 g
s
.63881 .7594 m .62015 .75504 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63389 .66823 m .63434 .67654 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63434 .67654 m .63881 .7594 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.62015 .75504 m .60915 .75248 L p .63389 .66823 L .707 .577 .707 r
F P
0 g
s
.63044 .67764 m .6366 .7148 L .64362 .71714 L p .707 .577 .707 r
F P
0 g
s
.64362 .71714 m .64888 .71889 L p .63894 .69665 L .707 .577 .707 r
F P
0 g
s
.63894 .69665 m .63044 .67764 L .64362 .71714 L .707 .577 .707 r
F
.63494 .67914 m .63044 .67764 L p .63894 .69665 L F P
0 g
s
.64888 .71889 m .63494 .67914 L .63894 .69665 L .707 .577 .707 r
F
.63567 .5783 m .63174 .63331 L .6386 .6385 L p F P
0 g
s
.6386 .6385 m .64427 .64279 L p .64137 .62102 L .707 .577 .707 r
F P
0 g
s
.64137 .62102 m .63567 .5783 L .6386 .6385 L .707 .577 .707 r
F
.60915 .75248 m .58194 .24846 L .61161 .25539 L p F P
0 g
s
.17714 .73893 m .17098 .70176 L .19483 .69368 L p .707 .577 .707 r
F P
0 g
s
.29225 .60036 m .28831 .65537 L .25722 .65124 L p .707 .577 .707 r
F P
0 g
s
.25722 .65124 m .26116 .59623 L .29225 .60036 L p .707 .577 .707 r
F P
0 g
s
.22546 .65001 m .22939 .595 L .26116 .59623 L p .707 .577 .707 r
F P
0 g
s
.22939 .595 m .22546 .65001 L .19613 .65179 L p .707 .577 .707 r
F P
0 g
s
.26116 .59623 m .25722 .65124 L .22546 .65001 L p .707 .577 .707 r
F P
0 g
s
.31309 .67666 m .31925 .71382 L .29223 .71472 L p .707 .577 .707 r
F P
0 g
s
.29223 .71472 m .28607 .67756 L .31309 .67666 L p .707 .577 .707 r
F P
0 g
s
.19483 .69368 m .201 .73084 L .17714 .73893 L p .707 .577 .707 r
F P
0 g
s
.72373 .66199 m .72766 .60698 L .69657 .60286 L p .707 .577 .707 r
F P
0 g
s
.72766 .60698 m .72373 .66199 L .75549 .66322 L p .707 .577 .707 r
F P
0 g
s
.75549 .66322 m .75943 .60821 L .72766 .60698 L p .707 .577 .707 r
F P
0 g
s
.37905 .2633 m .40626 .76731 L .38316 .7781 L p .707 .577 .707 r
F P
0 g
s
.40626 .76731 m .37905 .2633 L .41298 .25421 L p .707 .577 .707 r
F P
0 g
s
.75943 .60821 m .75549 .66322 L .78482 .66144 L p .707 .577 .707 r
F P
0 g
s
.78482 .66144 m .78875 .60643 L .75943 .60821 L p .707 .577 .707 r
F P
0 g
s
.1962 .80837 m .18877 .79072 L .2116 .77912 L p .707 .577 .707 r
F P
0 g
s
.69263 .65787 m .69657 .60286 L .66919 .59624 L p .707 .577 .707 r
F P
0 g
s
.69657 .60286 m .69263 .65787 L .72373 .66199 L p .707 .577 .707 r
F P
0 g
s
.2116 .77912 m .21903 .79676 L .1962 .80837 L p .707 .577 .707 r
F P
0 g
s
.201 .73084 m .19483 .69368 L .2239 .68651 L p .707 .577 .707 r
F P
0 g
s
.32182 .73442 m .32925 .75206 L .30445 .76061 L p .707 .577 .707 r
F P
0 g
s
.30445 .76061 m .29702 .74297 L .32182 .73442 L p .707 .577 .707 r
F P
0 g
s
.28607 .67756 m .29223 .71472 L .2615 .71812 L p .707 .577 .707 r
F P
0 g
s
.2615 .71812 m .25534 .68096 L .28607 .67756 L p .707 .577 .707 r
F P
0 g
s
.2239 .68651 m .23006 .72367 L .201 .73084 L p .707 .577 .707 r
F P
0 g
s
.78875 .60643 m .78482 .66144 L .80883 .65681 L p .707 .577 .707 r
F P
0 g
s
.80883 .65681 m .81277 .6018 L .78875 .60643 L p .707 .577 .707 r
F P
0 g
s
.58194 .24846 m .60915 .75248 L .57045 .7487 L p .707 .577 .707 r
F P
0 g
s
.57045 .7487 m .54324 .24468 L .58194 .24846 L p .707 .577 .707 r
F P
0 g
s
.23006 .72367 m .2239 .68651 L .25534 .68096 L p .707 .577 .707 r
F P
0 g
s
.25534 .68096 m .2615 .71812 L .23006 .72367 L p .707 .577 .707 r
F P
0 g
s
.66526 .65125 m .66919 .59624 L .64821 .58778 L p .707 .577 .707 r
F P
0 g
s
.66919 .59624 m .66526 .65125 L .69263 .65787 L p .707 .577 .707 r
F P
0 g
s
.72729 .71628 m .72113 .67911 L .69039 .68251 L p .707 .577 .707 r
F P
0 g
s
.72113 .67911 m .72729 .71628 L .75873 .71072 L p .707 .577 .707 r
F P
0 g
s
.75873 .71072 m .75257 .67356 L .72113 .67911 L p .707 .577 .707 r
F P
0 g
s
.75257 .67356 m .75873 .71072 L .78779 .70355 L p .707 .577 .707 r
F P
0 g
s
.78779 .70355 m .78163 .66639 L .75257 .67356 L p .707 .577 .707 r
F P
0 g
s
.21903 .79676 m .2116 .77912 L .23907 .76647 L p .707 .577 .707 r
F P
0 g
s
.29702 .74297 m .30445 .76061 L .27594 .77166 L p .707 .577 .707 r
F P
0 g
s
.27594 .77166 m .26851 .75402 L .29702 .74297 L p .707 .577 .707 r
F P
0 g
s
.23907 .76647 m .24651 .78412 L .21903 .79676 L p .707 .577 .707 r
F P
0 g
s
.44019 .75822 m .41298 .25421 L .45442 .2477 L p .707 .577 .707 r
F P
0 g
s
.41298 .25421 m .44019 .75822 L .40626 .76731 L p .707 .577 .707 r
F P
0 g
s
.69039 .68251 m .69656 .71967 L .72729 .71628 L p .707 .577 .707 r
F P
0 g
s
.69656 .71967 m .69039 .68251 L .66338 .68341 L p .707 .577 .707 r
F P
0 g
s
.73729 .7479 m .72985 .73026 L .70134 .7413 L p .707 .577 .707 r
F P
0 g
s
.72985 .73026 m .73729 .7479 L .76672 .73544 L p .707 .577 .707 r
F P
0 g
s
.76672 .73544 m .75929 .7178 L .72985 .73026 L p .707 .577 .707 r
F P
0 g
s
.75929 .7178 m .76672 .73544 L .7942 .7228 L p .707 .577 .707 r
F P
0 g
s
.7942 .7228 m .78677 .70515 L .75929 .7178 L p .707 .577 .707 r
F P
0 g
s
.70134 .7413 m .70877 .75895 L .73729 .7479 L p .707 .577 .707 r
F P
0 g
s
.24651 .78412 m .23907 .76647 L .26851 .75402 L p .707 .577 .707 r
F P
0 g
s
.78163 .66639 m .78779 .70355 L .81165 .69547 L p .707 .577 .707 r
F P
0 g
s
.81165 .69547 m .80548 .65831 L .78163 .66639 L p .707 .577 .707 r
F P
0 g
s
.26851 .75402 m .27594 .77166 L .24651 .78412 L p .707 .577 .707 r
F P
0 g
s
.81277 .6018 m .80883 .65681 L .82519 .6498 L p .707 .577 .707 r
F P
0 g
s
.82519 .6498 m .82913 .59479 L .81277 .6018 L p .707 .577 .707 r
F P
0 g
s
.64821 .58778 m .64427 .64279 L .66526 .65125 L p .707 .577 .707 r
F P
0 g
s
.66338 .68341 m .66954 .72057 L .69656 .71967 L p .707 .577 .707 r
F P
0 g
s
.54324 .24468 m .57045 .7487 L .52651 .74843 L p .707 .577 .707 r
F P
0 g
s
.52651 .74843 m .4993 .24442 L .54324 .24468 L p .707 .577 .707 r
F P
0 g
s
.70877 .75895 m .70134 .7413 L .67654 .74986 L p .707 .577 .707 r
F P
0 g
s
.78677 .70515 m .7942 .7228 L .81703 .71119 L p .707 .577 .707 r
F P
0 g
s
.81703 .71119 m .8096 .69355 L .78677 .70515 L p .707 .577 .707 r
F P
0 g
s
.67654 .74986 m .68398 .7675 L .70877 .75895 L p .707 .577 .707 r
F P
0 g
s
.48162 .75172 m .45442 .2477 L .4993 .24442 L p .707 .577 .707 r
F P
0 g
s
.45442 .2477 m .48162 .75172 L .44019 .75822 L p .707 .577 .707 r
F P
0 g
s
.4993 .24442 m .52651 .74843 L .48162 .75172 L p .707 .577 .707 r
F P
0 g
s
.80548 .65831 m .81165 .69547 L .82795 .68726 L p .707 .577 .707 r
F P
0 g
s
.82795 .68726 m .82178 .6501 L .80548 .65831 L p .707 .577 .707 r
F P
0 g
s
.64272 .68173 m .64888 .71889 L .66954 .72057 L p .707 .577 .707 r
F P
0 g
s
.68398 .7675 m .67654 .74986 L .65789 .75508 L p .707 .577 .707 r
F P
0 g
s
.65789 .75508 m .66532 .77273 L .68398 .7675 L p .707 .577 .707 r
F P
0 g
s
.82913 .59479 m .82519 .6498 L .83229 .64108 L p .707 .577 .707 r
F P
0 g
s
.83229 .64108 m .83622 .58607 L .82913 .59479 L p .707 .577 .707 r
F P
0 g
s
.8096 .69355 m .81703 .71119 L .83298 .70178 L p .707 .577 .707 r
F P
0 g
s
.83298 .70178 m .82554 .68413 L .8096 .69355 L p .707 .577 .707 r
F P
0 g
s
.63174 .63331 m .63567 .5783 L .63281 .56873 L p .707 .577 .707 r
F P
0 g
s
.82178 .6501 m .82795 .68726 L .8351 .67974 L p .707 .577 .707 r
F P
0 g
s
.8351 .67974 m .82894 .64258 L .82178 .6501 L p .707 .577 .707 r
F P
0 g
s
.66532 .77273 m .65789 .75508 L .6472 .75647 L p .707 .577 .707 r
F P
0 g
s
.6472 .75647 m .65463 .77411 L .66532 .77273 L p .707 .577 .707 r
F P
0 g
s
.63281 .56873 m .62888 .62374 L .63174 .63331 L p .707 .577 .707 r
F P
0 g
s
.82554 .68413 m .83298 .70178 L .84048 .69546 L p .707 .577 .707 r
F P
0 g
s
.84048 .69546 m .83305 .67782 L .82554 .68413 L p .707 .577 .707 r
F P
0 g
s
.83622 .58607 m .83229 .64108 L .82943 .63151 L p .707 .577 .707 r
F P
0 g
s
.82943 .63151 m .83336 .5765 L .83622 .58607 L p .707 .577 .707 r
F P
0 g
s
.6366 .7148 m .63044 .67764 L .62774 .67153 L p .707 .577 .707 r
F P
0 g
s
.62888 .62374 m .63281 .56873 L .63991 .56002 L p .707 .577 .707 r
F P
0 g
s
.62774 .67153 m .63391 .70869 L .6366 .7148 L p .707 .577 .707 r
F P
0 g
s
.82894 .64258 m .8351 .67974 L .8324 .67363 L p .707 .577 .707 r
F P
0 g
s
.8324 .67363 m .82624 .63647 L .82894 .64258 L p .707 .577 .707 r
F P
0 g
s
.65463 .77411 m .6472 .75647 L .64553 .75388 L p .707 .578 .707 r
F P
0 g
s
.64553 .75388 m .65296 .77152 L .65463 .77411 L p .707 .578 .707 r
F P
0 g
s
.63991 .56002 m .63597 .61503 L .62888 .62374 L p .707 .577 .707 r
F P
0 g
s
.83305 .67782 m .84048 .69546 L .83881 .69287 L p .707 .578 .707 r
F P
0 g
s
.83881 .69287 m .83137 .67523 L .83305 .67782 L p .707 .578 .707 r
F P
0 g
s
.83336 .5765 m .82943 .63151 L .81689 .62204 L p .707 .577 .707 r
F P
0 g
s
.81689 .62204 m .82083 .56703 L .83336 .5765 L p .707 .577 .707 r
F P
0 g
s
.38072 .61836 m .38465 .56335 L .35356 .55923 L p .707 .577 .707 r
F P
0 g
s
.38465 .56335 m .38072 .61836 L .41248 .61959 L p .707 .577 .707 r
F P
0 g
s
.41248 .61959 m .41642 .56458 L .38465 .56335 L p .707 .577 .707 r
F P
0 g
s
.63597 .61503 m .63991 .56002 L .65626 .553 L p .707 .577 .707 r
F P
0 g
s
.63391 .70869 m .62774 .67153 L .6349 .66401 L p .707 .577 .707 r
F P
0 g
s
.41642 .56458 m .41248 .61959 L .44181 .61781 L p .707 .577 .707 r
F P
0 g
s
.44181 .61781 m .44574 .5628 L .41642 .56458 L p .707 .577 .707 r
F P
0 g
s
.34962 .61424 m .35356 .55923 L .32618 .55261 L p .707 .577 .707 r
F P
0 g
s
.35356 .55923 m .34962 .61424 L .38072 .61836 L p .707 .577 .707 r
F P
0 g
s
.6349 .66401 m .64106 .70117 L .63391 .70869 L p .707 .577 .707 r
F P
0 g
s
.82624 .63647 m .8324 .67363 L .82013 .66953 L p .707 .577 .707 r
F P
0 g
s
.82013 .66953 m .81396 .63237 L .82624 .63647 L p .707 .577 .707 r
F P
0 g
s
.44574 .5628 m .44181 .61781 L .46582 .61318 L p .707 .577 .707 r
F P
0 g
s
.46582 .61318 m .46976 .55817 L .44574 .5628 L p .707 .577 .707 r
F P
0 g
s
.65296 .77152 m .64553 .75388 L .65303 .74756 L p .707 .577 .707 r
F P
0 g
s
.65626 .553 m .65233 .60801 L .63597 .61503 L p .707 .577 .707 r
F P
0 g
s
.65303 .74756 m .66047 .76521 L .65296 .77152 L p .707 .577 .707 r
F P
0 g
s
.82083 .56703 m .81689 .62204 L .79591 .61357 L p .707 .577 .707 r
F P
0 g
s
.79591 .61357 m .79984 .55856 L .82083 .56703 L p .707 .577 .707 r
F P
0 g
s
.32225 .60762 m .32618 .55261 L .3052 .54415 L p .707 .577 .707 r
F P
0 g
s
.32618 .55261 m .32225 .60762 L .34962 .61424 L p .707 .577 .707 r
F P
0 g
s
.83137 .67523 m .83881 .69287 L .82812 .69426 L p .707 .577 .707 r
F P
0 g
s
.82812 .69426 m .82069 .67661 L .83137 .67523 L p .707 .577 .707 r
F P
0 g
s
.38428 .6702 m .37812 .63304 L .34738 .63643 L p .707 .577 .707 r
F P
0 g
s
.37812 .63304 m .38428 .6702 L .41572 .66465 L p .707 .577 .707 r
F P
0 g
s
.41572 .66465 m .40956 .62749 L .37812 .63304 L p .707 .577 .707 r
F P
0 g
s
.40956 .62749 m .41572 .66465 L .44479 .65748 L p .707 .577 .707 r
F P
0 g
s
.44479 .65748 m .43862 .62032 L .40956 .62749 L p .707 .577 .707 r
F P
0 g
s
.65233 .60801 m .65626 .553 L .68028 .54838 L p .707 .577 .707 r
F P
0 g
s
.34738 .63643 m .35355 .67359 L .38428 .6702 L p .707 .577 .707 r
F P
0 g
s
.35355 .67359 m .34738 .63643 L .32037 .63734 L p .707 .577 .707 r
F P
0 g
s
.64106 .70117 m .6349 .66401 L .6512 .6558 L p .707 .577 .707 r
F P
0 g
s
.39428 .70844 m .38684 .6908 L .35833 .70184 L p .707 .577 .707 r
F P
0 g
s
.38684 .6908 m .39428 .70844 L .42371 .69598 L p .707 .577 .707 r
F P
0 g
s
.42371 .69598 m .41628 .67834 L .38684 .6908 L p .707 .577 .707 r
F P
0 g
s
.43862 .62032 m .44479 .65748 L .46864 .64939 L p .707 .577 .707 r
F P
0 g
s
.46864 .64939 m .46247 .61223 L .43862 .62032 L p .707 .577 .707 r
F P
0 g
s
.41628 .67834 m .42371 .69598 L .45119 .68333 L p .707 .577 .707 r
F P
0 g
s
.45119 .68333 m .44376 .66569 L .41628 .67834 L p .707 .577 .707 r
F P
0 g
s
.35833 .70184 m .36576 .71949 L .39428 .70844 L p .707 .577 .707 r
F P
0 g
s
.46976 .55817 m .46582 .61318 L .48218 .60617 L p .707 .577 .707 r
F P
0 g
s
.48218 .60617 m .48612 .55116 L .46976 .55817 L p .707 .577 .707 r
F P
0 g
s
.32037 .63734 m .32653 .6745 L .35355 .67359 L p .707 .577 .707 r
F P
0 g
s
.3052 .54415 m .30126 .59916 L .32225 .60762 L p .707 .577 .707 r
F P
0 g
s
.6512 .6558 m .65736 .69296 L .64106 .70117 L p .707 .577 .707 r
F P
0 g
s
.81396 .63237 m .82013 .66953 L .79947 .66786 L p .707 .577 .707 r
F P
0 g
s
.79947 .66786 m .79331 .6307 L .81396 .63237 L p .707 .577 .707 r
F P
0 g
s
.79984 .55856 m .79591 .61357 L .76853 .60696 L p .707 .577 .707 r
F P
0 g
s
.76853 .60696 m .77246 .55195 L .79984 .55856 L p .707 .577 .707 r
F P
0 g
s
.30126 .59916 m .3052 .54415 L .29266 .53467 L p .707 .577 .707 r
F P
0 g
s
.36576 .71949 m .35833 .70184 L .33353 .7104 L p .707 .577 .707 r
F P
0 g
s
.68028 .54838 m .67634 .60339 L .65233 .60801 L p .707 .577 .707 r
F P
0 g
s
.44376 .66569 m .45119 .68333 L .47402 .67173 L p .707 .577 .707 r
F P
0 g
s
.47402 .67173 m .46659 .65409 L .44376 .66569 L p .707 .577 .707 r
F P
0 g
s
.33353 .7104 m .34097 .72804 L .36576 .71949 L p .707 .577 .707 r
F P
0 g
s
.32653 .6745 m .32037 .63734 L .29971 .63566 L p .707 .577 .707 r
F P
0 g
s
.66047 .76521 m .65303 .74756 L .66898 .73814 L p .707 .577 .707 r
F P
0 g
s
.67634 .60339 m .68028 .54838 L .70961 .54659 L p .707 .577 .707 r
F P
0 g
s
.66898 .73814 m .67641 .75579 L .66047 .76521 L p .707 .577 .707 r
F P
0 g
s
.82069 .67661 m .82812 .69426 L .80947 .69948 L p .707 .577 .707 r
F P
0 g
s
.80947 .69948 m .80203 .68184 L .82069 .67661 L p .707 .577 .707 r
F P
0 g
s
.46247 .61223 m .46864 .64939 L .48494 .64119 L p .707 .577 .707 r
F P
0 g
s
.48494 .64119 m .47877 .60403 L .46247 .61223 L p .707 .577 .707 r
F P
0 g
s
.29971 .63566 m .30587 .67282 L .32653 .6745 L p .707 .577 .707 r
F P
0 g
s
.77246 .55195 m .76853 .60696 L .73743 .60283 L p .707 .577 .707 r
F P
0 g
s
.73743 .60283 m .74137 .54782 L .77246 .55195 L p .707 .577 .707 r
F P
0 g
s
.65736 .69296 m .6512 .6558 L .67505 .64772 L p .707 .577 .707 r
F P
0 g
s
.29266 .53467 m .28873 .58968 L .30126 .59916 L p .707 .577 .707 r
F P
0 g
s
.70567 .6016 m .70961 .54659 L .74137 .54782 L p .707 .577 .707 r
F P
0 g
s
.70961 .54659 m .70567 .6016 L .67634 .60339 L p .707 .577 .707 r
F P
0 g
s
.34097 .72804 m .33353 .7104 L .31488 .71562 L p .707 .577 .707 r
F P
0 g
s
.48612 .55116 m .48218 .60617 L .48928 .59745 L p .707 .577 .707 r
F P
0 g
s
.48928 .59745 m .49321 .54244 L .48612 .55116 L p .707 .577 .707 r
F P
0 g
s
.31488 .71562 m .32231 .73327 L .34097 .72804 L p .707 .577 .707 r
F P
0 g
s
.46659 .65409 m .47402 .67173 L .48997 .66232 L p .707 .577 .707 r
F P
0 g
s
.48997 .66232 m .48253 .64467 L .46659 .65409 L p .707 .577 .707 r
F P
0 g
s
.74137 .54782 m .73743 .60283 L .70567 .6016 L p .707 .577 .707 r
F P
0 g
s
.79331 .6307 m .79947 .66786 L .77245 .66876 L p .707 .577 .707 r
F P
0 g
s
.77245 .66876 m .76629 .6316 L .79331 .6307 L p .707 .577 .707 r
F P
0 g
s
.67505 .64772 m .68121 .68488 L .65736 .69296 L p .707 .577 .707 r
F P
0 g
s
.30587 .67282 m .29971 .63566 L .28743 .63157 L p .707 .577 .707 r
F P
0 g
s
.28873 .58968 m .29266 .53467 L .2898 .5251 L p .707 .577 .707 r
F P
0 g
s
.67641 .75579 m .66898 .73814 L .69181 .72654 L p .707 .577 .707 r
F P
0 g
s
.69181 .72654 m .69924 .74419 L .67641 .75579 L p .707 .577 .707 r
F P
0 g
s
.80203 .68184 m .80947 .69948 L .78467 .70804 L p .707 .577 .707 r
F P
0 g
s
.78467 .70804 m .77723 .69039 L .80203 .68184 L p .707 .577 .707 r
F P
0 g
s
.68121 .68488 m .67505 .64772 L .70412 .64055 L p .707 .577 .707 r
F P
0 g
s
.28743 .63157 m .29359 .66873 L .30587 .67282 L p .707 .577 .707 r
F P
0 g
s
.47877 .60403 m .48494 .64119 L .49209 .63366 L p .707 .577 .707 r
F P
0 g
s
.49209 .63366 m .48593 .5965 L .47877 .60403 L p .707 .577 .707 r
F P
0 g
s
.76629 .6316 m .77245 .66876 L .74172 .67215 L p .707 .577 .707 r
F P
0 g
s
.74172 .67215 m .73555 .63499 L .76629 .6316 L p .707 .577 .707 r
F P
0 g
s
.70412 .64055 m .71028 .67771 L .68121 .68488 L p .707 .577 .707 r
F P
0 g
s
.32231 .73327 m .31488 .71562 L .30419 .71701 L p .707 .577 .707 r
F P
0 g
s
.2898 .5251 m .28587 .58011 L .28873 .58968 L p .707 .577 .707 r
F P
0 g
s
.30419 .71701 m .31162 .73465 L .32231 .73327 L p .707 .577 .707 r
F P
0 g
s
.71028 .67771 m .70412 .64055 L .73555 .63499 L p .707 .577 .707 r
F P
0 g
s
.48253 .64467 m .48997 .66232 L .49747 .656 L p .707 .577 .707 r
F P
0 g
s
.49747 .656 m .49004 .63836 L .48253 .64467 L p .707 .577 .707 r
F P
0 g
s
.73555 .63499 m .74172 .67215 L .71028 .67771 L p .707 .577 .707 r
F P
0 g
s
.49321 .54244 m .48928 .59745 L .48642 .58788 L p .707 .577 .707 r
F P
0 g
s
.48642 .58788 m .49035 .53287 L .49321 .54244 L p .707 .577 .707 r
F P
0 g
s
.69924 .74419 m .69181 .72654 L .71929 .7139 L p .707 .577 .707 r
F P
0 g
s
.77723 .69039 m .78467 .70804 L .75616 .71908 L p .707 .577 .707 r
F P
0 g
s
.75616 .71908 m .74872 .70144 L .77723 .69039 L p .707 .577 .707 r
F P
0 g
s
.71929 .7139 m .72672 .73154 L .69924 .74419 L p .707 .577 .707 r
F P
0 g
s
.29359 .66873 m .28743 .63157 L .28473 .62546 L p .707 .577 .707 r
F P
0 g
s
.28587 .58011 m .2898 .5251 L .2969 .51639 L p .707 .577 .707 r
F P
0 g
s
.72672 .73154 m .71929 .7139 L .74872 .70144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74872 .70144 m .75616 .71908 L .72672 .73154 L p .707 .577 .707 r
F P
0 g
s
.28473 .62546 m .2909 .66262 L .29359 .66873 L p .707 .577 .707 r
F P
0 g
s
.48593 .5965 m .49209 .63366 L .48939 .62755 L p .707 .577 .707 r
F P
0 g
s
.48939 .62755 m .48323 .59039 L .48593 .5965 L p .707 .577 .707 r
F P
0 g
s
.31162 .73465 m .30419 .71701 L .30252 .71442 L p .707 .578 .707 r
F P
0 g
s
.2969 .51639 m .29296 .5714 L .28587 .58011 L p .707 .577 .707 r
F P
0 g
s
.30252 .71442 m .30995 .73206 L .31162 .73465 L p .707 .578 .707 r
F P
0 g
s
.49004 .63836 m .49747 .656 L .4958 .65341 L p .707 .578 .707 r
F P
0 g
s
.4958 .65341 m .48836 .63577 L .49004 .63836 L p .707 .578 .707 r
F P
0 g
s
.49035 .53287 m .48642 .58788 L .47388 .57841 L p .707 .577 .707 r
F P
0 g
s
.47388 .57841 m .47782 .5234 L .49035 .53287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29296 .5714 m .2969 .51639 L .31325 .50937 L p .707 .577 .707 r
F P
0 g
s
.2909 .66262 m .28473 .62546 L .29189 .61793 L p .707 .577 .707 r
F P
0 g
s
.29189 .61793 m .29805 .65509 L .2909 .66262 L p .707 .577 .707 r
F P
0 g
s
.48323 .59039 m .48939 .62755 L .47712 .62346 L p .707 .577 .707 r
F P
0 g
s
.47712 .62346 m .47095 .5863 L .48323 .59039 L p .707 .577 .707 r
F P
0 g
s
.31325 .50937 m .30932 .56438 L .29296 .5714 L p .707 .577 .707 r
F P
0 g
s
.30995 .73206 m .30252 .71442 L .31002 .7081 L p .707 .577 .707 r
F P
0 g
s
.47782 .5234 m .47388 .57841 L .4529 .56994 L p .707 .577 .707 r
F P
0 g
s
.4529 .56994 m .45683 .51493 L .47782 .5234 L p .707 .577 .707 r
F P
0 g
s
.31002 .7081 m .31746 .72575 L .30995 .73206 L p .707 .577 .707 r
F P
0 g
s
.48836 .63577 m .4958 .65341 L .48511 .65479 L p .707 .577 .707 r
F P
0 g
s
.48511 .65479 m .47768 .63715 L .48836 .63577 L p .707 .577 .707 r
F P
0 g
s
.30932 .56438 m .31325 .50937 L .33727 .50475 L p .707 .577 .707 r
F P
0 g
s
.29805 .65509 m .29189 .61793 L .30819 .60973 L p .707 .577 .707 r
F P
0 g
s
.30819 .60973 m .31435 .64689 L .29805 .65509 L p .707 .577 .707 r
F P
0 g
s
.47095 .5863 m .47712 .62346 L .45646 .62178 L p .707 .577 .707 r
F P
0 g
s
.45646 .62178 m .45029 .58462 L .47095 .5863 L p .707 .577 .707 r
F P
0 g
s
.45683 .51493 m .4529 .56994 L .42552 .56333 L p .707 .577 .707 r
F P
0 g
s
.42552 .56333 m .42945 .50832 L .45683 .51493 L p .707 .577 .707 r
F P
0 g
s
.33727 .50475 m .33333 .55976 L .30932 .56438 L p .707 .577 .707 r
F P
0 g
s
.33333 .55976 m .33727 .50475 L .3666 .50296 L p .707 .577 .707 r
F P
0 g
s
.31746 .72575 m .31002 .7081 L .32597 .69868 L p .707 .577 .707 r
F P
0 g
s
.32597 .69868 m .3334 .71633 L .31746 .72575 L p .707 .577 .707 r
F P
0 g
s
.47768 .63715 m .48511 .65479 L .46646 .66002 L p .707 .577 .707 r
F P
0 g
s
.46646 .66002 m .45902 .64238 L .47768 .63715 L p .707 .577 .707 r
F P
0 g
s
.31435 .64689 m .30819 .60973 L .33204 .60164 L p .707 .577 .707 r
F P
0 g
s
.42945 .50832 m .42552 .56333 L .39442 .5592 L p .707 .577 .707 r
F P
0 g
s
.39442 .5592 m .39836 .50419 L .42945 .50832 L p .707 .577 .707 r
F P
0 g
s
.36266 .55797 m .3666 .50296 L .39836 .50419 L p .707 .577 .707 r
F P
0 g
s
.3666 .50296 m .36266 .55797 L .33333 .55976 L p .707 .577 .707 r
F P
0 g
s
.39836 .50419 m .39442 .5592 L .36266 .55797 L p .707 .577 .707 r
F P
0 g
s
.45029 .58462 m .45646 .62178 L .42944 .62268 L p .707 .577 .707 r
F P
0 g
s
.42944 .62268 m .42328 .58552 L .45029 .58462 L p .707 .577 .707 r
F P
0 g
s
.33204 .60164 m .3382 .6388 L .31435 .64689 L p .707 .577 .707 r
F P
0 g
s
.3334 .71633 m .32597 .69868 L .3488 .68708 L p .707 .577 .707 r
F P
0 g
s
.3488 .68708 m .35623 .70473 L .3334 .71633 L p .707 .577 .707 r
F P
0 g
s
.3382 .6388 m .33204 .60164 L .3611 .59447 L p .707 .577 .707 r
F P
0 g
s
.45902 .64238 m .46646 .66002 L .44166 .66858 L p .707 .577 .707 r
F P
0 g
s
.44166 .66858 m .43422 .65093 L .45902 .64238 L p .707 .577 .707 r
F P
0 g
s
.42328 .58552 m .42944 .62268 L .39871 .62608 L p .707 .577 .707 r
F P
0 g
s
.39871 .62608 m .39254 .58892 L .42328 .58552 L p .707 .577 .707 r
F P
0 g
s
.3611 .59447 m .36727 .63163 L .3382 .6388 L p .707 .577 .707 r
F P
0 g
s
.36727 .63163 m .3611 .59447 L .39254 .58892 L p .707 .577 .707 r
F P
0 g
s
.39254 .58892 m .39871 .62608 L .36727 .63163 L p .707 .577 .707 r
F P
0 g
s
.35623 .70473 m .3488 .68708 L .37628 .67443 L p .707 .577 .707 r
F P
0 g
s
.43422 .65093 m .44166 .66858 L .41315 .67962 L p .707 .577 .707 r
F P
0 g
s
.41315 .67962 m .40571 .66198 L .43422 .65093 L p .707 .577 .707 r
F P
0 g
s
.37628 .67443 m .38371 .69208 L .35623 .70473 L p .707 .577 .707 r
F P
0 g
s
.38371 .69208 m .37628 .67443 L .40571 .66198 L p .707 .577 .707 r
F P
0 g
s
.40571 .66198 m .41315 .67962 L .38371 .69208 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6000OGoo001oOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Uoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00Lgoo1P00
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001^
Ool50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH2001]Ool006]oo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00QJEP8006]oo`00JGoo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF00<007ooOol0J7oo001XOol0
1000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH02eYFJWoo001VOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1WOol006Eoo`03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00aJEP03001oogoo06Ioo`00I7oo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02eYF00<007oo
Ool0IWoo001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1VOol0069oo`04001JEUYF
0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001W
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
0000Igoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IWoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005eooaT000=JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00F7oo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P002EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP<006Aoo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001T
Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`00I7oo001BOol00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP<006Aoo`00DWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001TOol0059oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`001goo5`00AWoo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60010Ool0055oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPD000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003aoo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Goo001AOol0
0`00FUH00003FUH01000FUIJEUYF3`000UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00L0
05YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH3000gOol0055oo`03001JEP0000=JEP@00003FUH005YF00IJEP03001JEUYF009JEQ40
00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003Eoo`00DGoo00@005YF001JEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH0
1`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DGoo00<005YF00000P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035o
o`00DGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`
Ool0055oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000`Ool0055oo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEQ<00003FUH00000008000IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002moo`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000@000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00Dgoo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP<000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00=goo60001Goo0P001EYF00<0
05YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00=7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035o
o`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@00003FUH0
05YF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004
FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000_Ool0
02moo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUH00003FUH500000eYF001JEP05FUH00`00FUIJEP02FUHB0006FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP04001JEP00FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002mo
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF0080031oo`00:goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP<00004FUH005YFFUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH01@00FUIJEUYF00001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P00
<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80006FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00<7oo000[Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP<0031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001J
EUYF00AJEPH00003FUH0000000<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUHB0002FUH3000`Ool002]oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF01000003FUH005YF00MJEP03001JEUYF00AJEP03001J
EUYF009JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH6000`Ool002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00D0009JEP03
001JEUYF00EJEP03001JEUYF00AJEPD00003FUH0000000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00<7oo000[Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005
FUH00`00FUH000030003FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YF000010001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00<7oo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH005YF<Goo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH400000eYF000000030006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<Goo000ZOol00`00FUH00003FUH01000FUIJEUYF3P000goo200015YF00<005YFFUH00`0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080031oo`00:Woo00<005YF00000eYF100000=JEP00FUH01UYF00<005YF
FUH00UYF40000UYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH015YF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080031oo`00
:Woo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH0
0`00FUIJEP04FUH40004FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF0080031oo`00:Woo00<005YF00000P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF1P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF0000031oo`00:Woo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH025YF00@005YF000000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH01000FUIJ
EP00<7oo000ZOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P001EYF
00<005YFFUH01EYF0`001eYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2@001EYF1P0000=JEP00Ool0;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUHD00000eYF00000008FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001UYF00<005YF
FUH015YF00<005YFFUH00UYF1000;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUHB0002FUH40003Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=oo`0000000P00
0UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001P00;goo000[Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01eYF1`0015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJ
EP00000007oo008000=JEP03001JEUYF00IJEP<000UJEP04001JEP000003FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000goo000000040006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000UYF00<005YF
FUH00P00;goo000/Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP050006FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P001EYF00<005YF
FUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P0025YF00<005YFFUH00`001EYF00<005YFFUH00eYF0P0025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP04001J
EUYF000_Ool002ioo`8000AJEP03001JEUYF00=JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00QJEP8000UJEP03001JEP00008000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000AJEP04
001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool300000eYF001JEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH20002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH01EYF00@005YFFUIJEPH002ioo`00<Woo100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00EJEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP05FUH40003FUH2000_Ool002moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000QJEP04
001JEP000006FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20008FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0^Ool0
02eoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP80009JEP03001JEUYF00AJEP<000QJEP03001JEUYF008000QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<000UJEP03001JEUYF008000AJEP05001J
EUYFFUH0000aOol002]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP@000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000000eYF
00<005YFFUH01UYF0`001eYF0`00<Woo000ZOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00@005YF000000AJEP03001JEUYF
00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH2000dOol002Yoo`8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF009J
EP8000MJEP03001JEP00008000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000QJEP03001JEP00008000EJEP03001JEUYF009JEP8003Ioo`00:Goo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPX000EJEP80009JEP07
001JEUYFFUH005YF00001UYF100000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00004`0000=J
EP00FUH025YF0`0025YF00@005YF000003Qoo`00:Goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00AJEPH00003Ool000000080009JEP03001JEUYF00IJEP80009JEP<0009JEP03001JEUYF
009JEP8000=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH80002FUH60004FUH00`00
FUIJEP04FUH200000eYF001JEP08FUH2000jOol002Uoo`04001JEUYF0004FUH00`00FUIJEP05FUH0
0`00FUIJEP0@00000eYF001JEP07FUH20002FUH00`00FUIJEP03FUH00`00FUH000020004Ool00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF1P001eYF00<005YFFUH00UYF0P0015YF
00<005YFFUH015YF0P00?7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH80004FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEP@00003FUH0000000Aoo`03001JEP00
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUH000020009FUH01000FUH000001UYF
00<005YFFUH00UYF0P00?Woo000ZOol00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH0
1UYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YF00001@000UYF00D005YFFUIJEP0000Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP05001JEUYFFUH00003FUH01000FUIJEUYF0`0015YF0P000eYF00<005YFFUH0
1EYF0`002EYF00@005YF0000041oo`00:Woo00<005YF00001EYF00@005YF000000EJEP03001JEUYF
00MJEP03001JEUYF00<000=JEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH00P00
0goo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP8000EJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00EJEP<0049oo`00:Woo00@005YFFUH000=JEP@000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF009JEP05001JEUYFFUH00003Ool0
0`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40007FUH00`00FUH000020005FUH00`00
FUIJEP03FUH20015Ool002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP03FUH00`00FUH000020002Ool0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH20009FUH0
0`00FUH000020017Ool002]oo`9JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00MJEP03001JEUYF00@0009JEP04001oogoo0009FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP04FUHI0005FUH00`00FUIJEP05FUH01@00FUIJEUYF
00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01EYF0`00BWoo000[Ool01EYF001JEUYF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH015YF1000
15YF0P000goo00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF2P002eYF00<005YFFUH0
2EYF20001UYF00<005YFFUH00P001UYF00@005YF000000AJEP03001JEUYF00=JEP8004eoo`00:goo
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<007ooOol00Woo00<005YFFUH01eYF00<005YF
FUH01eYF00<005YFFUH01P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF0P001eYF00<005YF00000P00Cgoo000[Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP08FUH0
1000FUH0000015YF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000800005
FUH005YFFUH00003FUH200000eYF001JEP05FUH3001BOol002aoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPH000EJEP03001JEUYF00EJEP<000MJEP<000Qoo`UJEP03001JEUYF
00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF009JEP<0009JEP<000=JEP03001JEUYF009JEP8005Eoo`00;Woo500000=oo`00000025YF
00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<007ooOol027oo2EYF00<005YF00000`002EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YF00000P00EWoo0011Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH2000;Ool8FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF
1`00EWoo000oOol20003FUH00`00FUIJEP06FUH40008FUH01000FUH000003Goo1UYF0P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF0P000UYF1@0000AJEP00FUIJEP8005Ioo`00?Goo0P001UYF00<005YFFUH00eYF0`00
00=JEP00FUH025YF0P003goo15YF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF00<005YF00000`001EYF00@005YFFUH005Io
o`00>goo0P0025YF00<005YFFUH00`001EYF00<005YFFUH015YF0P004Goo0UYF0P002EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF
00H005YFFUH005YF0005FUH01000FUIJEP00EWoo000iOol200000eYF001JEP08FUH20008FUH00`00
FUIJEP02FUH2000COol00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH01000FUIJEP00EGoo000gOol20004FUH00`00FUIJEP04FUH200000eYF001J
EP08FUH01000FUH000005Goo00=JEP00FUH00eYF00<005YFFUH03eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF
1@00EGoo000eOol20006FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH3000GOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH2001FOol003Ao
o`8000QJEP04001JEP000006FUH00`00FUIJEP03FUH2000JOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUIJEUYF0P001UYF0`0015YF00<007ooOol0EGoo000bOol20002FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP03000MOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUIJEP00FUH0009JEP@0009J
EP05001JEUYFFUH0001HOol0035oo`03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP<0021oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0009JEP<000MJEP<005Uoo`00<7oo0P00
1EYF00@005YF000000AJEP03001JEUYF00=JEP<002Aoo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00004FUH0
00000002FUH00`00FUIJEP04FUH2001KOol002moo`04001JEUYF0004FUH20007FUH00`00FUH00002
000YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05000015YF000000001EYF00<005YFFUH00UYF0P00GGoo000_Ool01000FUIJEP000eYF
00<005YF00001UYF0`00;Woo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF1@0015YF0`0025YF00@005YF000005moo`00;goo0P000UYF0`000UYF00<005YF
FUH00UYF0P00<goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPL000IJEP800003FUH005YF00QJEP80065oo`00<7oo00@005YFFUH000EJEP04001JEP00000i
Ool80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH90006FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH2001SOol0031oo`05001JEP00FUH00002FUH40013OolI0004Ool30009FUH01000FUH0
00001UYF00<005YFFUH00UYF0P00IGoo000aOol00`00FUH00003001SOol01@00FUIJEUYF00001eYF
0`002EYF00@005YF000006Moo`00<Goo0P00IGoo0P0015YF00<005YFFUH00eYF0P000eYF00<005YF
FUH01EYF0`00JGoo002FOol20007FUH00`00FUH000020005FUH00`00FUIJEP03FUH2001/Ool009Ao
o`800003FUH005YF00IJEP8000UJEP03001JEP00008006ioo`00TWoo0P0015YF00<005YFFUH00UYF
0P000UYF00<005YFFUH01EYF0`00LGoo002AOol20005FUH01@00FUIJEUYF000015YF00<005YFFUH0
0eYF0P00M7oo002@Ool01000FUIJEP001EYF0`001UYF00<005YF00000P00MWoo002@Ool01000FUIJ
EP0015YF0`001UYF0`00NGoo002AOol01@00FUIJEP00FUH00P000UYF00<005YFFUH00UYF0P00O7oo
002AOol00`00FUIJEP020005FUH01000FUH00000OWoo002BOol01EYF001JEUYF00000UYF1000P7oo
002BOol00`00FUIJEP040024Ool009=oo`8008Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58652 .75403 m .59046 .69902 L .55937 .6949 L p .707 .577 .707 r
F P
0 g
s
.59046 .69902 m .58652 .75403 L .61829 .75526 L p .707 .577 .707 r
F P
0 g
s
.61829 .75526 m .62222 .70025 L .59046 .69902 L p .707 .577 .707 r
F P
0 g
s
.62222 .70025 m .61829 .75526 L .64761 .75348 L p .707 .577 .707 r
F P
0 g
s
.64761 .75348 m .65155 .69847 L .62222 .70025 L p .707 .577 .707 r
F P
0 g
s
.55543 .7499 m .55937 .6949 L .53199 .68828 L p .707 .577 .707 r
F P
0 g
s
.55937 .6949 m .55543 .7499 L .58652 .75403 L p .707 .577 .707 r
F P
0 g
s
.65155 .69847 m .64761 .75348 L .67163 .74885 L p .707 .577 .707 r
F P
0 g
s
.67163 .74885 m .67556 .69384 L .65155 .69847 L p .707 .577 .707 r
F P
0 g
s
.52805 .74329 m .53199 .68828 L .511 .67982 L p .707 .577 .707 r
F P
0 g
s
.53199 .68828 m .52805 .74329 L .55543 .7499 L p .707 .577 .707 r
F P
0 g
s
.59008 .80831 m .58392 .77115 L .55319 .77455 L p .707 .577 .707 r
F P
0 g
s
.58392 .77115 m .59008 .80831 L .62152 .80276 L p .707 .577 .707 r
F P
0 g
s
.62152 .80276 m .61536 .7656 L .58392 .77115 L p .707 .577 .707 r
F P
0 g
s
.61536 .7656 m .62152 .80276 L .65059 .79559 L p .707 .577 .707 r
F P
0 g
s
.65059 .79559 m .64443 .75843 L .61536 .7656 L p .707 .577 .707 r
F P
0 g
s
.55319 .77455 m .55935 .81171 L .59008 .80831 L p .707 .577 .707 r
F P
0 g
s
.55935 .81171 m .55319 .77455 L .52617 .77545 L p .707 .577 .707 r
F P
0 g
s
.60008 .83994 m .59265 .82229 L .56414 .83334 L p .707 .577 .707 r
F P
0 g
s
.59265 .82229 m .60008 .83994 L .62952 .82748 L p .707 .577 .707 r
F P
0 g
s
.62952 .82748 m .62208 .80984 L .59265 .82229 L p .707 .577 .707 r
F P
0 g
s
.62208 .80984 m .62952 .82748 L .65699 .81483 L p .707 .577 .707 r
F P
0 g
s
.65699 .81483 m .64956 .79719 L .62208 .80984 L p .707 .577 .707 r
F P
0 g
s
.56414 .83334 m .57157 .85098 L .60008 .83994 L p .707 .577 .707 r
F P
0 g
s
.64443 .75843 m .65059 .79559 L .67444 .78751 L p .707 .577 .707 r
F P
0 g
s
.67444 .78751 m .66828 .75035 L .64443 .75843 L p .707 .577 .707 r
F P
0 g
s
.67556 .69384 m .67163 .74885 L .68799 .74183 L p .707 .577 .707 r
F P
0 g
s
.68799 .74183 m .69192 .68682 L .67556 .69384 L p .707 .577 .707 r
F P
0 g
s
.511 .67982 m .50707 .73483 L .52805 .74329 L p .707 .577 .707 r
F P
0 g
s
.52617 .77545 m .53233 .81261 L .55935 .81171 L p .707 .577 .707 r
F P
0 g
s
.57157 .85098 m .56414 .83334 L .53934 .8419 L p .707 .577 .707 r
F P
0 g
s
.50707 .73483 m .511 .67982 L .49847 .67034 L p .707 .577 .707 r
F P
0 g
s
.64956 .79719 m .65699 .81483 L .67982 .80323 L p .707 .577 .707 r
F P
0 g
s
.67982 .80323 m .67239 .78559 L .64956 .79719 L p .707 .577 .707 r
F P
0 g
s
.53934 .8419 m .54677 .85954 L .57157 .85098 L p .707 .577 .707 r
F P
0 g
s
.53233 .81261 m .52617 .77545 L .50551 .77377 L p .707 .577 .707 r
F P
0 g
s
.66828 .75035 m .67444 .78751 L .69074 .7793 L p .707 .577 .707 r
F P
0 g
s
.69074 .7793 m .68458 .74214 L .66828 .75035 L p .707 .577 .707 r
F P
0 g
s
.50551 .77377 m .51167 .81093 L .53233 .81261 L p .707 .577 .707 r
F P
0 g
s
.49847 .67034 m .49453 .72535 L .50707 .73483 L p .707 .577 .707 r
F P
0 g
s
.54677 .85954 m .53934 .8419 L .52068 .84712 L p .707 .577 .707 r
F P
0 g
s
.52068 .84712 m .52812 .86476 L .54677 .85954 L p .707 .577 .707 r
F P
0 g
s
.69192 .68682 m .68799 .74183 L .69508 .73312 L p .707 .577 .707 r
F P
0 g
s
.69508 .73312 m .69902 .67811 L .69192 .68682 L p .707 .577 .707 r
F P
0 g
s
.67239 .78559 m .67982 .80323 L .69577 .79381 L p .707 .577 .707 r
F P
0 g
s
.69577 .79381 m .68834 .77617 L .67239 .78559 L p .707 .577 .707 r
F P
0 g
s
.49453 .72535 m .49847 .67034 L .49561 .66077 L p .707 .577 .707 r
F P
0 g
s
.51167 .81093 m .50551 .77377 L .49323 .76968 L p .707 .577 .707 r
F P
0 g
s
.49323 .76968 m .4994 .80684 L .51167 .81093 L p .707 .577 .707 r
F P
0 g
s
.68458 .74214 m .69074 .7793 L .69789 .77177 L p .707 .577 .707 r
F P
0 g
s
.69789 .77177 m .69173 .73461 L .68458 .74214 L p .707 .577 .707 r
F P
0 g
s
.52812 .86476 m .52068 .84712 L .51 .84851 L p .707 .577 .707 r
F P
0 g
s
.51 .84851 m .51743 .86615 L .52812 .86476 L p .707 .577 .707 r
F P
0 g
s
.49561 .66077 m .49167 .71578 L .49453 .72535 L p .707 .577 .707 r
F P
0 g
s
.68834 .77617 m .69577 .79381 L .70328 .7875 L p .707 .577 .707 r
F P
0 g
s
.70328 .7875 m .69584 .76986 L .68834 .77617 L p .707 .577 .707 r
F P
0 g
s
.69902 .67811 m .69508 .73312 L .69222 .72355 L p .707 .577 .707 r
F P
0 g
s
.69222 .72355 m .69616 .66854 L .69902 .67811 L p .707 .577 .707 r
F P
0 g
s
.49167 .71578 m .49561 .66077 L .5027 .65206 L p .707 .577 .707 r
F P
0 g
s
.5027 .65206 m .49877 .70707 L .49167 .71578 L p .707 .577 .707 r
F P
0 g
s
.49877 .70707 m .5027 .65206 L .51906 .64504 L p .707 .577 .707 r
F P
0 g
s
.4994 .80684 m .49323 .76968 L .49054 .76357 L p .707 .577 .707 r
F P
0 g
s
.49054 .76357 m .4967 .80073 L .4994 .80684 L p .707 .577 .707 r
F P
0 g
s
.49769 .75605 m .50385 .79321 L .4967 .80073 L p .707 .577 .707 r
F P
0 g
s
.51906 .64504 m .51512 .70005 L .49877 .70707 L p .707 .577 .707 r
F P
0 g
s
.50385 .79321 m .49769 .75605 L .51399 .74784 L p .707 .577 .707 r
F P
0 g
s
.51399 .74784 m .52015 .785 L .50385 .79321 L p .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .48004 .31682 L .4361 .31656 L p .707 .577 .707 r
F P
0 g
s
.51512 .70005 m .51906 .64504 L .54308 .64041 L p .707 .577 .707 r
F P
0 g
s
.54308 .64041 m .53914 .69542 L .51512 .70005 L p .707 .577 .707 r
F P
0 g
s
.52015 .785 m .51399 .74784 L .53784 .73976 L p .707 .577 .707 r
F P
0 g
s
.53784 .73976 m .54401 .77692 L .52015 .785 L p .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .53784 .73976 L .54849 .73713 L p .707 .577 .707 r
F P
0 g
s
.54849 .73713 m .56691 .73259 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .54849 .73713 L .55487 .75589 L .707 .577 .707 r
F
.56691 .73259 m .57307 .76975 L .56062 .77282 L p F P
0 g
s
.56062 .77282 m .54401 .77692 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.55487 .75589 m .56691 .73259 L .56062 .77282 L .707 .577 .707 r
F
.52493 .31353 m .48004 .31682 L p .53472 .69659 L F P
0 g
s
.55213 .81755 m .54766 .73468 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .54308 .64041 L .56911 .63883 L p .707 .577 .707 r
F P
0 g
s
.56911 .63883 m .5724 .63863 L p .56675 .64828 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .56911 .63883 L .56675 .64828 L .707 .577 .707 r
F
.5724 .63863 m .56847 .69364 L .53914 .69542 L p F P
0 g
s
.54621 .7304 m .52493 .31353 L .53472 .69659 L .707 .577 .707 r
F
.54766 .73468 m .54721 .72638 L p .54621 .7304 L F P
0 g
s
.54721 .72638 m .52493 .31353 L p .54621 .7304 L .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .55213 .81755 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.48004 .31682 m .49409 .57699 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.49409 .57699 m .50725 .82083 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.56847 .69364 m .5724 .63863 L .60417 .63986 L p .707 .577 .707 r
F P
0 g
s
.60417 .63986 m .60023 .69487 L .56847 .69364 L p .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .56691 .73259 L .57934 .73039 L p .707 .577 .707 r
F P
0 g
s
.57934 .73039 m .59835 .72703 L p .57888 .75993 L .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .57934 .73039 L .57888 .75993 L .707 .577 .707 r
F
.63526 .64399 m .63132 .699 L .60023 .69487 L p F P
0 g
s
.60023 .69487 m .60417 .63986 L .63526 .64399 L p .707 .577 .707 r
F P
0 g
s
.62908 .72364 m .63524 .7608 L .60451 .76419 L p .707 .577 .707 r
F P
0 g
s
.60451 .76419 m .59835 .72703 L .62908 .72364 L p .707 .577 .707 r
F P
0 g
s
.59835 .72703 m .60451 .76419 L .57307 .76975 L p .707 .577 .707 r
F P
0 g
s
.64003 .78243 m .64746 .80007 L .61895 .81112 L p .707 .577 .707 r
F P
0 g
s
.61895 .81112 m .61152 .79348 L .64003 .78243 L p .707 .577 .707 r
F P
0 g
s
.58952 .82358 m .58208 .80593 L .61152 .79348 L p .707 .577 .707 r
F P
0 g
s
.61152 .79348 m .61895 .81112 L .58952 .82358 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .62749 .80195 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56636 .30703 m .58157 .58875 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.58157 .58875 m .59357 .81104 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56204 .83623 m .55461 .81858 L .58208 .80593 L p .707 .577 .707 r
F P
0 g
s
.58208 .80593 m .58952 .82358 L .56204 .83623 L p .707 .577 .707 r
F P
0 g
s
.52493 .31353 m .55213 .81755 L .59357 .81104 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .56636 .30703 L .52493 .31353 L p .707 .577 .707 r
F P
0 g
s
.46331 .82057 m .4361 .31656 L .3974 .31278 L p .707 .577 .707 r
F P
0 g
s
.4967 .80073 m .49054 .76357 L .49769 .75605 L p .707 .577 .707 r
F P
0 g
s
.4361 .31656 m .46331 .82057 L .50725 .82083 L p .707 .577 .707 r
F P
0 g
s
.69173 .73461 m .69789 .77177 L .6952 .76567 L p .707 .577 .707 r
F P
0 g
s
.6952 .76567 m .68904 .72851 L .69173 .73461 L p .707 .577 .707 r
F P
0 g
s
.51743 .86615 m .51 .84851 L .50832 .84591 L p .707 .578 .707 r
F P
0 g
s
.50832 .84591 m .51576 .86356 L .51743 .86615 L p .707 .578 .707 r
F P
0 g
s
.69584 .76986 m .70328 .7875 L .7016 .78491 L p .707 .578 .707 r
F P
0 g
s
.7016 .78491 m .69417 .76727 L .69584 .76986 L p .707 .578 .707 r
F P
0 g
s
.62749 .80195 m .60029 .29794 L .56636 .30703 L p .707 .577 .707 r
F P
0 g
s
.69616 .66854 m .69222 .72355 L .67969 .71407 L p .707 .577 .707 r
F P
0 g
s
.67969 .71407 m .68362 .65907 L .69616 .66854 L p .707 .577 .707 r
F P
0 g
s
.24351 .7104 m .24745 .65539 L .21636 .65127 L p .707 .577 .707 r
F P
0 g
s
.24745 .65539 m .24351 .7104 L .27528 .71163 L p .707 .577 .707 r
F P
0 g
s
.27528 .71163 m .27921 .65662 L .24745 .65539 L p .707 .577 .707 r
F P
0 g
s
.27921 .65662 m .27528 .71163 L .3046 .70985 L p .707 .577 .707 r
F P
0 g
s
.3046 .70985 m .30854 .65484 L .27921 .65662 L p .707 .577 .707 r
F P
0 g
s
.42461 .81679 m .3974 .31278 L .36774 .30585 L p .707 .577 .707 r
F P
0 g
s
.3974 .31278 m .42461 .81679 L .46331 .82057 L p .707 .577 .707 r
F P
0 g
s
.21242 .70628 m .21636 .65127 L .18898 .64465 L p .707 .577 .707 r
F P
0 g
s
.21636 .65127 m .21242 .70628 L .24351 .7104 L p .707 .577 .707 r
F P
0 g
s
.68904 .72851 m .6952 .76567 L .68292 .76157 L p .707 .577 .707 r
F P
0 g
s
.68292 .76157 m .67676 .72441 L .68904 .72851 L p .707 .577 .707 r
F P
0 g
s
.30854 .65484 m .3046 .70985 L .32862 .70522 L p .707 .577 .707 r
F P
0 g
s
.32862 .70522 m .33256 .65021 L .30854 .65484 L p .707 .577 .707 r
F P
0 g
s
.51576 .86356 m .50832 .84591 L .51583 .8396 L p .707 .577 .707 r
F P
0 g
s
.66264 .6506 m .6587 .70561 L .63132 .699 L p .707 .577 .707 r
F P
0 g
s
.63132 .699 m .63526 .64399 L .66264 .6506 L p .707 .577 .707 r
F P
0 g
s
.6561 .72273 m .66226 .7599 L .63524 .7608 L p .707 .577 .707 r
F P
0 g
s
.63524 .7608 m .62908 .72364 L .6561 .72273 L p .707 .577 .707 r
F P
0 g
s
.64746 .80007 m .64003 .78243 L .66483 .77388 L p .707 .577 .707 r
F P
0 g
s
.60029 .29794 m .62749 .80195 L .65059 .79117 L p .707 .577 .707 r
F P
0 g
s
.65059 .79117 m .62339 .28716 L .60029 .29794 L p .707 .577 .707 r
F P
0 g
s
.51583 .8396 m .52326 .85724 L .51576 .86356 L p .707 .577 .707 r
F P
0 g
s
.68362 .65907 m .67969 .71407 L .6587 .70561 L p .707 .577 .707 r
F P
0 g
s
.6587 .70561 m .66264 .6506 L .68362 .65907 L p .707 .577 .707 r
F P
0 g
s
.18504 .69966 m .18898 .64465 L .16799 .63619 L p .707 .577 .707 r
F P
0 g
s
.18898 .64465 m .18504 .69966 L .21242 .70628 L p .707 .577 .707 r
F P
0 g
s
.69417 .76727 m .7016 .78491 L .69092 .78629 L p .707 .577 .707 r
F P
0 g
s
.69092 .78629 m .68348 .76865 L .69417 .76727 L p .707 .577 .707 r
F P
0 g
s
.24708 .76224 m .24091 .72508 L .21018 .72847 L p .707 .577 .707 r
F P
0 g
s
.24091 .72508 m .24708 .76224 L .27851 .75668 L p .707 .577 .707 r
F P
0 g
s
.27851 .75668 m .27235 .71952 L .24091 .72508 L p .707 .577 .707 r
F P
0 g
s
.27235 .71952 m .27851 .75668 L .30758 .74952 L p .707 .577 .707 r
F P
0 g
s
.30758 .74952 m .30142 .71235 L .27235 .71952 L p .707 .577 .707 r
F P
0 g
s
.21018 .72847 m .21634 .76563 L .24708 .76224 L p .707 .577 .707 r
F P
0 g
s
.21634 .76563 m .21018 .72847 L .18316 .72938 L p .707 .577 .707 r
F P
0 g
s
.25707 .80048 m .24964 .78283 L .22113 .79388 L p .707 .577 .707 r
F P
0 g
s
.24964 .78283 m .25707 .80048 L .28651 .78802 L p .707 .577 .707 r
F P
0 g
s
.28651 .78802 m .27908 .77038 L .24964 .78283 L p .707 .577 .707 r
F P
0 g
s
.30142 .71235 m .30758 .74952 L .33143 .74143 L p .707 .577 .707 r
F P
0 g
s
.33143 .74143 m .32527 .70427 L .30142 .71235 L p .707 .577 .707 r
F P
0 g
s
.27908 .77038 m .28651 .78802 L .31399 .77537 L p .707 .577 .707 r
F P
0 g
s
.31399 .77537 m .30655 .75773 L .27908 .77038 L p .707 .577 .707 r
F P
0 g
s
.22113 .79388 m .22856 .81152 L .25707 .80048 L p .707 .577 .707 r
F P
0 g
s
.33256 .65021 m .32862 .70522 L .34498 .6982 L p .707 .577 .707 r
F P
0 g
s
.34498 .6982 m .34891 .6432 L .33256 .65021 L p .707 .577 .707 r
F P
0 g
s
.39494 .80986 m .36774 .30585 L .35001 .29645 L p .707 .577 .707 r
F P
0 g
s
.36774 .30585 m .39494 .80986 L .42461 .81679 L p .707 .577 .707 r
F P
0 g
s
.18316 .72938 m .18932 .76654 L .21634 .76563 L p .707 .577 .707 r
F P
0 g
s
.16799 .63619 m .16406 .6912 L .18504 .69966 L p .707 .577 .707 r
F P
0 g
s
.67676 .72441 m .68292 .76157 L .66226 .7599 L p .707 .577 .707 r
F P
0 g
s
.66226 .7599 m .6561 .72273 L .67676 .72441 L p .707 .577 .707 r
F P
0 g
s
.16406 .6912 m .16799 .63619 L .15546 .62671 L p .707 .577 .707 r
F P
0 g
s
.22856 .81152 m .22113 .79388 L .19633 .80243 L p .707 .577 .707 r
F P
0 g
s
.30655 .75773 m .31399 .77537 L .33682 .76377 L p .707 .577 .707 r
F P
0 g
s
.33682 .76377 m .32938 .74613 L .30655 .75773 L p .707 .577 .707 r
F P
0 g
s
.19633 .80243 m .20376 .82008 L .22856 .81152 L p .707 .577 .707 r
F P
0 g
s
.18932 .76654 m .18316 .72938 L .1625 .7277 L p .707 .577 .707 r
F P
0 g
s
.52326 .85724 m .51583 .8396 L .53178 .83018 L p .707 .577 .707 r
F P
0 g
s
.53178 .83018 m .53921 .84783 L .52326 .85724 L p .707 .577 .707 r
F P
0 g
s
.68348 .76865 m .69092 .78629 L .67226 .79152 L p .707 .577 .707 r
F P
0 g
s
.67226 .79152 m .66483 .77388 L .68348 .76865 L p .707 .577 .707 r
F P
0 g
s
.32527 .70427 m .33143 .74143 L .34773 .73323 L p .707 .577 .707 r
F P
0 g
s
.34773 .73323 m .34157 .69606 L .32527 .70427 L p .707 .577 .707 r
F P
0 g
s
.1625 .7277 m .16866 .76486 L .18932 .76654 L p .707 .577 .707 r
F P
0 g
s
.62339 .28716 m .65059 .79117 L .6606 .77974 L p .707 .577 .707 r
F P
0 g
s
.6606 .77974 m .6334 .27573 L .62339 .28716 L p .707 .577 .707 r
F P
0 g
s
.15546 .62671 m .15152 .68172 L .16406 .6912 L p .707 .577 .707 r
F P
0 g
s
.20376 .82008 m .19633 .80243 L .17768 .80766 L p .707 .577 .707 r
F P
0 g
s
.34891 .6432 m .34498 .6982 L .35207 .68949 L p .707 .577 .707 r
F P
0 g
s
.35207 .68949 m .35601 .63448 L .34891 .6432 L p .707 .577 .707 r
F P
0 g
s
.17768 .80766 m .18511 .8253 L .20376 .82008 L p .707 .577 .707 r
F P
0 g
s
.32938 .74613 m .33682 .76377 L .35276 .75435 L p .707 .577 .707 r
F P
0 g
s
.35276 .75435 m .34533 .73671 L .32938 .74613 L p .707 .577 .707 r
F P
0 g
s
.16866 .76486 m .1625 .7277 L .15023 .72361 L p .707 .577 .707 r
F P
0 g
s
.15152 .68172 m .15546 .62671 L .1526 .61714 L p .707 .577 .707 r
F P
0 g
s
.53921 .84783 m .53178 .83018 L .55461 .81858 L p .707 .577 .707 r
F P
0 g
s
.55461 .81858 m .56204 .83623 L .53921 .84783 L p .707 .577 .707 r
F P
0 g
s
.66483 .77388 m .67226 .79152 L .64746 .80007 L p .707 .577 .707 r
F P
0 g
s
.37721 .80047 m .35001 .29645 L .34595 .28551 L p .707 .577 .707 r
F P
0 g
s
.35001 .29645 m .37721 .80047 L .39494 .80986 L p .707 .577 .707 r
F P
0 g
s
.15023 .72361 m .15639 .76077 L .16866 .76486 L p .707 .577 .707 r
F P
0 g
s
.34157 .69606 m .34773 .73323 L .35488 .7257 L p .707 .577 .707 r
F P
0 g
s
.35488 .7257 m .34872 .68854 L .34157 .69606 L p .707 .577 .707 r
F P
0 g
s
.18511 .8253 m .17768 .80766 L .16699 .80904 L p .707 .577 .707 r
F P
0 g
s
.1526 .61714 m .14866 .67215 L .15152 .68172 L p .707 .577 .707 r
F P
0 g
s
.16699 .80904 m .17442 .82669 L .18511 .8253 L p .707 .577 .707 r
F P
0 g
s
.34533 .73671 m .35276 .75435 L .36027 .74804 L p .707 .577 .707 r
F P
0 g
s
.36027 .74804 m .35283 .7304 L .34533 .73671 L p .707 .577 .707 r
F P
0 g
s
.35601 .63448 m .35207 .68949 L .34921 .67992 L p .707 .577 .707 r
F P
0 g
s
.34921 .67992 m .35315 .62491 L .35601 .63448 L p .707 .577 .707 r
F P
0 g
s
.62934 .26478 m .65654 .7688 L .63881 .7594 L p .707 .577 .707 r
F P
0 g
s
.64427 .64279 m .64654 .61106 L p .63567 .5783 L .707 .577 .707 r
F P
0 g
s
.65338 .70144 m .6334 .27573 L .65898 .77536 L .707 .577 .707 r
F
.65654 .7688 m .64455 .5465 L p .6334 .27573 L F P
0 g
s
.64455 .5465 m .62934 .26478 L .6317 .27114 L p .707 .577 .707 r
F P
0 g
s
.6317 .27114 m .6334 .27573 L p .64455 .5465 L .707 .577 .707 r
F P
0 g
s
.6334 .27573 m .6606 .77974 L .65898 .77536 L p .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .66338 .68341 L .65089 .6824 L p .707 .577 .707 r
F P
0 g
s
.65089 .6824 m .64272 .68173 L p .65145 .69437 L .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .65089 .6824 L .65145 .69437 L .707 .577 .707 r
F
.64654 .61106 m .64821 .58778 L .64457 .58503 L p F P
0 g
s
.64457 .58503 m .63567 .5783 L p .64654 .61106 L .707 .577 .707 r
F P
0 g
s
.65898 .77536 m .65654 .7688 L p .65338 .70144 L .707 .577 .707 r
F P
0 g
s
.15639 .76077 m .15023 .72361 L .14753 .7175 L p .707 .577 .707 r
F P
0 g
s
.14866 .67215 m .1526 .61714 L .15969 .60843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.14753 .7175 m .15369 .75466 L .15639 .76077 L p .707 .577 .707 r
F P
0 g
s
.34872 .68854 m .35488 .7257 L .35219 .71959 L p .707 .577 .707 r
F P
0 g
s
.35219 .71959 m .34603 .68243 L .34872 .68854 L p .707 .577 .707 r
F P
0 g
s
.17442 .82669 m .16699 .80904 L .16531 .80645 L p .707 .578 .707 r
F P
0 g
s
.15969 .60843 m .15576 .66344 L .14866 .67215 L p .707 .577 .707 r
F P
0 g
s
.16531 .80645 m .17275 .8241 L .17442 .82669 L p .707 .578 .707 r
F P
0 g
s
.35283 .7304 m .36027 .74804 L .35859 .74545 L p .707 .578 .707 r
F P
0 g
s
.35859 .74545 m .35116 .7278 L .35283 .7304 L p .707 .578 .707 r
F P
0 g
s
.34595 .28551 m .37315 .78952 L .37721 .80047 L p .707 .577 .707 r
F P
0 g
s
.37315 .78952 m .34595 .28551 L .35596 .27408 L p .707 .577 .707 r
F P
0 g
s
.35315 .62491 m .34921 .67992 L .33668 .67045 L p .707 .577 .707 r
F P
0 g
s
.33668 .67045 m .34061 .61544 L .35315 .62491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15576 .66344 m .15969 .60843 L .17605 .60141 L p .707 .577 .707 r
F P
0 g
s
.15369 .75466 m .14753 .7175 L .15468 .70997 L p .707 .577 .707 r
F P
0 g
s
.15468 .70997 m .16085 .74713 L .15369 .75466 L p .707 .577 .707 r
F P
0 g
s
.34603 .68243 m .35219 .71959 L .33991 .7155 L p .707 .577 .707 r
F P
0 g
s
.33991 .7155 m .33375 .67834 L .34603 .68243 L p .707 .577 .707 r
F P
0 g
s
.63881 .7594 m .61161 .25539 L .62934 .26478 L p .707 .577 .707 r
F P
0 g
s
.17605 .60141 m .17211 .65642 L .15576 .66344 L p .707 .577 .707 r
F P
0 g
s
.17275 .8241 m .16531 .80645 L .17282 .80014 L p .707 .577 .707 r
F P
0 g
s
.34061 .61544 m .33668 .67045 L .31569 .66198 L p .707 .577 .707 r
F P
0 g
s
.31569 .66198 m .31963 .60697 L .34061 .61544 L p .707 .577 .707 r
F P
0 g
s
.17282 .80014 m .18025 .81778 L .17275 .8241 L p .707 .577 .707 r
F P
0 g
s
.35116 .7278 m .35859 .74545 L .34791 .74683 L p .707 .577 .707 r
F P
0 g
s
.34791 .74683 m .34047 .72919 L .35116 .7278 L p .707 .577 .707 r
F P
0 g
s
.17211 .65642 m .17605 .60141 L .20007 .59678 L p .707 .577 .707 r
F P
0 g
s
.16085 .74713 m .15468 .70997 L .17098 .70176 L p .707 .577 .707 r
F P
0 g
s
.38316 .7781 m .35596 .27408 L .37905 .2633 L p .707 .577 .707 r
F P
0 g
s
.35596 .27408 m .38316 .7781 L .37315 .78952 L p .707 .577 .707 r
F P
0 g
s
.17098 .70176 m .17714 .73893 L .16085 .74713 L p .707 .577 .707 r
F P
0 g
s
.33375 .67834 m .33991 .7155 L .31925 .71382 L p .707 .577 .707 r
F P
0 g
s
.31925 .71382 m .31309 .67666 L .33375 .67834 L p .707 .577 .707 r
F P
0 g
s
.31963 .60697 m .31569 .66198 L .28831 .65537 L p .707 .577 .707 r
F P
0 g
s
.28831 .65537 m .29225 .60036 L .31963 .60697 L p .707 .577 .707 r
F P
0 g
s
.20007 .59678 m .19613 .65179 L .17211 .65642 L p .707 .577 .707 r
F P
0 g
s
.19613 .65179 m .20007 .59678 L .22939 .595 L p .707 .577 .707 r
F P
0 g
s
.18025 .81778 m .17282 .80014 L .18877 .79072 L p .707 .577 .707 r
F P
0 g
s
.18877 .79072 m .1962 .80837 L .18025 .81778 L p .707 .577 .707 r
F P
0 g
s
.34047 .72919 m .34791 .74683 L .32925 .75206 L p .707 .577 .707 r
F P
0 g
s
.32925 .75206 m .32182 .73442 L .34047 .72919 L p .707 .577 .707 r
F P
0 g
s
.61161 .25539 m .63389 .66823 L p .63308 .671 L .707 .577 .707 r
F P
0 g
s
.60915 .75248 m .61005 .5702 L .63308 .671 L .707 .577 .707 r
F
.61005 .5702 m .61161 .25539 L .63308 .671 L F
.64888 .71889 m .64272 .68173 L .63494 .67914 L p F P
0 g
s
.63881 .7594 m .62015 .75504 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63389 .66823 m .63434 .67654 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63434 .67654 m .63881 .7594 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.62015 .75504 m .60915 .75248 L p .63389 .66823 L .707 .577 .707 r
F P
0 g
s
.63044 .67764 m .6366 .7148 L .64362 .71714 L p .707 .577 .707 r
F P
0 g
s
.64362 .71714 m .64888 .71889 L p .63894 .69665 L .707 .577 .707 r
F P
0 g
s
.63894 .69665 m .63044 .67764 L .64362 .71714 L .707 .577 .707 r
F
.63494 .67914 m .63044 .67764 L p .63894 .69665 L F P
0 g
s
.64888 .71889 m .63494 .67914 L .63894 .69665 L .707 .577 .707 r
F
.63567 .5783 m .63174 .63331 L .6386 .6385 L p F P
0 g
s
.6386 .6385 m .64427 .64279 L p .64137 .62102 L .707 .577 .707 r
F P
0 g
s
.64137 .62102 m .63567 .5783 L .6386 .6385 L .707 .577 .707 r
F
.60915 .75248 m .58194 .24846 L .61161 .25539 L p F P
0 g
s
.17714 .73893 m .17098 .70176 L .19483 .69368 L p .707 .577 .707 r
F P
0 g
s
.29225 .60036 m .28831 .65537 L .25722 .65124 L p .707 .577 .707 r
F P
0 g
s
.25722 .65124 m .26116 .59623 L .29225 .60036 L p .707 .577 .707 r
F P
0 g
s
.22546 .65001 m .22939 .595 L .26116 .59623 L p .707 .577 .707 r
F P
0 g
s
.22939 .595 m .22546 .65001 L .19613 .65179 L p .707 .577 .707 r
F P
0 g
s
.26116 .59623 m .25722 .65124 L .22546 .65001 L p .707 .577 .707 r
F P
0 g
s
.31309 .67666 m .31925 .71382 L .29223 .71472 L p .707 .577 .707 r
F P
0 g
s
.29223 .71472 m .28607 .67756 L .31309 .67666 L p .707 .577 .707 r
F P
0 g
s
.19483 .69368 m .201 .73084 L .17714 .73893 L p .707 .577 .707 r
F P
0 g
s
.72373 .66199 m .72766 .60698 L .69657 .60286 L p .707 .577 .707 r
F P
0 g
s
.72766 .60698 m .72373 .66199 L .75549 .66322 L p .707 .577 .707 r
F P
0 g
s
.75549 .66322 m .75943 .60821 L .72766 .60698 L p .707 .577 .707 r
F P
0 g
s
.37905 .2633 m .40626 .76731 L .38316 .7781 L p .707 .577 .707 r
F P
0 g
s
.40626 .76731 m .37905 .2633 L .41298 .25421 L p .707 .577 .707 r
F P
0 g
s
.75943 .60821 m .75549 .66322 L .78482 .66144 L p .707 .577 .707 r
F P
0 g
s
.78482 .66144 m .78875 .60643 L .75943 .60821 L p .707 .577 .707 r
F P
0 g
s
.1962 .80837 m .18877 .79072 L .2116 .77912 L p .707 .577 .707 r
F P
0 g
s
.69263 .65787 m .69657 .60286 L .66919 .59624 L p .707 .577 .707 r
F P
0 g
s
.69657 .60286 m .69263 .65787 L .72373 .66199 L p .707 .577 .707 r
F P
0 g
s
.2116 .77912 m .21903 .79676 L .1962 .80837 L p .707 .577 .707 r
F P
0 g
s
.201 .73084 m .19483 .69368 L .2239 .68651 L p .707 .577 .707 r
F P
0 g
s
.32182 .73442 m .32925 .75206 L .30445 .76061 L p .707 .577 .707 r
F P
0 g
s
.30445 .76061 m .29702 .74297 L .32182 .73442 L p .707 .577 .707 r
F P
0 g
s
.28607 .67756 m .29223 .71472 L .2615 .71812 L p .707 .577 .707 r
F P
0 g
s
.2615 .71812 m .25534 .68096 L .28607 .67756 L p .707 .577 .707 r
F P
0 g
s
.2239 .68651 m .23006 .72367 L .201 .73084 L p .707 .577 .707 r
F P
0 g
s
.78875 .60643 m .78482 .66144 L .80883 .65681 L p .707 .577 .707 r
F P
0 g
s
.80883 .65681 m .81277 .6018 L .78875 .60643 L p .707 .577 .707 r
F P
0 g
s
.58194 .24846 m .60915 .75248 L .57045 .7487 L p .707 .577 .707 r
F P
0 g
s
.57045 .7487 m .54324 .24468 L .58194 .24846 L p .707 .577 .707 r
F P
0 g
s
.23006 .72367 m .2239 .68651 L .25534 .68096 L p .707 .577 .707 r
F P
0 g
s
.25534 .68096 m .2615 .71812 L .23006 .72367 L p .707 .577 .707 r
F P
0 g
s
.66526 .65125 m .66919 .59624 L .64821 .58778 L p .707 .577 .707 r
F P
0 g
s
.66919 .59624 m .66526 .65125 L .69263 .65787 L p .707 .577 .707 r
F P
0 g
s
.72729 .71628 m .72113 .67911 L .69039 .68251 L p .707 .577 .707 r
F P
0 g
s
.72113 .67911 m .72729 .71628 L .75873 .71072 L p .707 .577 .707 r
F P
0 g
s
.75873 .71072 m .75257 .67356 L .72113 .67911 L p .707 .577 .707 r
F P
0 g
s
.75257 .67356 m .75873 .71072 L .78779 .70355 L p .707 .577 .707 r
F P
0 g
s
.78779 .70355 m .78163 .66639 L .75257 .67356 L p .707 .577 .707 r
F P
0 g
s
.21903 .79676 m .2116 .77912 L .23907 .76647 L p .707 .577 .707 r
F P
0 g
s
.29702 .74297 m .30445 .76061 L .27594 .77166 L p .707 .577 .707 r
F P
0 g
s
.27594 .77166 m .26851 .75402 L .29702 .74297 L p .707 .577 .707 r
F P
0 g
s
.23907 .76647 m .24651 .78412 L .21903 .79676 L p .707 .577 .707 r
F P
0 g
s
.44019 .75822 m .41298 .25421 L .45442 .2477 L p .707 .577 .707 r
F P
0 g
s
.41298 .25421 m .44019 .75822 L .40626 .76731 L p .707 .577 .707 r
F P
0 g
s
.69039 .68251 m .69656 .71967 L .72729 .71628 L p .707 .577 .707 r
F P
0 g
s
.69656 .71967 m .69039 .68251 L .66338 .68341 L p .707 .577 .707 r
F P
0 g
s
.73729 .7479 m .72985 .73026 L .70134 .7413 L p .707 .577 .707 r
F P
0 g
s
.72985 .73026 m .73729 .7479 L .76672 .73544 L p .707 .577 .707 r
F P
0 g
s
.76672 .73544 m .75929 .7178 L .72985 .73026 L p .707 .577 .707 r
F P
0 g
s
.75929 .7178 m .76672 .73544 L .7942 .7228 L p .707 .577 .707 r
F P
0 g
s
.7942 .7228 m .78677 .70515 L .75929 .7178 L p .707 .577 .707 r
F P
0 g
s
.70134 .7413 m .70877 .75895 L .73729 .7479 L p .707 .577 .707 r
F P
0 g
s
.24651 .78412 m .23907 .76647 L .26851 .75402 L p .707 .577 .707 r
F P
0 g
s
.78163 .66639 m .78779 .70355 L .81165 .69547 L p .707 .577 .707 r
F P
0 g
s
.81165 .69547 m .80548 .65831 L .78163 .66639 L p .707 .577 .707 r
F P
0 g
s
.26851 .75402 m .27594 .77166 L .24651 .78412 L p .707 .577 .707 r
F P
0 g
s
.81277 .6018 m .80883 .65681 L .82519 .6498 L p .707 .577 .707 r
F P
0 g
s
.82519 .6498 m .82913 .59479 L .81277 .6018 L p .707 .577 .707 r
F P
0 g
s
.64821 .58778 m .64427 .64279 L .66526 .65125 L p .707 .577 .707 r
F P
0 g
s
.66338 .68341 m .66954 .72057 L .69656 .71967 L p .707 .577 .707 r
F P
0 g
s
.54324 .24468 m .57045 .7487 L .52651 .74843 L p .707 .577 .707 r
F P
0 g
s
.52651 .74843 m .4993 .24442 L .54324 .24468 L p .707 .577 .707 r
F P
0 g
s
.70877 .75895 m .70134 .7413 L .67654 .74986 L p .707 .577 .707 r
F P
0 g
s
.78677 .70515 m .7942 .7228 L .81703 .71119 L p .707 .577 .707 r
F P
0 g
s
.81703 .71119 m .8096 .69355 L .78677 .70515 L p .707 .577 .707 r
F P
0 g
s
.67654 .74986 m .68398 .7675 L .70877 .75895 L p .707 .577 .707 r
F P
0 g
s
.48162 .75172 m .45442 .2477 L .4993 .24442 L p .707 .577 .707 r
F P
0 g
s
.45442 .2477 m .48162 .75172 L .44019 .75822 L p .707 .577 .707 r
F P
0 g
s
.4993 .24442 m .52651 .74843 L .48162 .75172 L p .707 .577 .707 r
F P
0 g
s
.80548 .65831 m .81165 .69547 L .82795 .68726 L p .707 .577 .707 r
F P
0 g
s
.82795 .68726 m .82178 .6501 L .80548 .65831 L p .707 .577 .707 r
F P
0 g
s
.64272 .68173 m .64888 .71889 L .66954 .72057 L p .707 .577 .707 r
F P
0 g
s
.68398 .7675 m .67654 .74986 L .65789 .75508 L p .707 .577 .707 r
F P
0 g
s
.65789 .75508 m .66532 .77273 L .68398 .7675 L p .707 .577 .707 r
F P
0 g
s
.82913 .59479 m .82519 .6498 L .83229 .64108 L p .707 .577 .707 r
F P
0 g
s
.83229 .64108 m .83622 .58607 L .82913 .59479 L p .707 .577 .707 r
F P
0 g
s
.8096 .69355 m .81703 .71119 L .83298 .70178 L p .707 .577 .707 r
F P
0 g
s
.83298 .70178 m .82554 .68413 L .8096 .69355 L p .707 .577 .707 r
F P
0 g
s
.63174 .63331 m .63567 .5783 L .63281 .56873 L p .707 .577 .707 r
F P
0 g
s
.82178 .6501 m .82795 .68726 L .8351 .67974 L p .707 .577 .707 r
F P
0 g
s
.8351 .67974 m .82894 .64258 L .82178 .6501 L p .707 .577 .707 r
F P
0 g
s
.66532 .77273 m .65789 .75508 L .6472 .75647 L p .707 .577 .707 r
F P
0 g
s
.6472 .75647 m .65463 .77411 L .66532 .77273 L p .707 .577 .707 r
F P
0 g
s
.63281 .56873 m .62888 .62374 L .63174 .63331 L p .707 .577 .707 r
F P
0 g
s
.82554 .68413 m .83298 .70178 L .84048 .69546 L p .707 .577 .707 r
F P
0 g
s
.84048 .69546 m .83305 .67782 L .82554 .68413 L p .707 .577 .707 r
F P
0 g
s
.83622 .58607 m .83229 .64108 L .82943 .63151 L p .707 .577 .707 r
F P
0 g
s
.82943 .63151 m .83336 .5765 L .83622 .58607 L p .707 .577 .707 r
F P
0 g
s
.6366 .7148 m .63044 .67764 L .62774 .67153 L p .707 .577 .707 r
F P
0 g
s
.62888 .62374 m .63281 .56873 L .63991 .56002 L p .707 .577 .707 r
F P
0 g
s
.62774 .67153 m .63391 .70869 L .6366 .7148 L p .707 .577 .707 r
F P
0 g
s
.82894 .64258 m .8351 .67974 L .8324 .67363 L p .707 .577 .707 r
F P
0 g
s
.8324 .67363 m .82624 .63647 L .82894 .64258 L p .707 .577 .707 r
F P
0 g
s
.65463 .77411 m .6472 .75647 L .64553 .75388 L p .707 .578 .707 r
F P
0 g
s
.64553 .75388 m .65296 .77152 L .65463 .77411 L p .707 .578 .707 r
F P
0 g
s
.63991 .56002 m .63597 .61503 L .62888 .62374 L p .707 .577 .707 r
F P
0 g
s
.83305 .67782 m .84048 .69546 L .83881 .69287 L p .707 .578 .707 r
F P
0 g
s
.83881 .69287 m .83137 .67523 L .83305 .67782 L p .707 .578 .707 r
F P
0 g
s
.83336 .5765 m .82943 .63151 L .81689 .62204 L p .707 .577 .707 r
F P
0 g
s
.81689 .62204 m .82083 .56703 L .83336 .5765 L p .707 .577 .707 r
F P
0 g
s
.38072 .61836 m .38465 .56335 L .35356 .55923 L p .707 .577 .707 r
F P
0 g
s
.38465 .56335 m .38072 .61836 L .41248 .61959 L p .707 .577 .707 r
F P
0 g
s
.41248 .61959 m .41642 .56458 L .38465 .56335 L p .707 .577 .707 r
F P
0 g
s
.63597 .61503 m .63991 .56002 L .65626 .553 L p .707 .577 .707 r
F P
0 g
s
.63391 .70869 m .62774 .67153 L .6349 .66401 L p .707 .577 .707 r
F P
0 g
s
.41642 .56458 m .41248 .61959 L .44181 .61781 L p .707 .577 .707 r
F P
0 g
s
.44181 .61781 m .44574 .5628 L .41642 .56458 L p .707 .577 .707 r
F P
0 g
s
.34962 .61424 m .35356 .55923 L .32618 .55261 L p .707 .577 .707 r
F P
0 g
s
.35356 .55923 m .34962 .61424 L .38072 .61836 L p .707 .577 .707 r
F P
0 g
s
.6349 .66401 m .64106 .70117 L .63391 .70869 L p .707 .577 .707 r
F P
0 g
s
.82624 .63647 m .8324 .67363 L .82013 .66953 L p .707 .577 .707 r
F P
0 g
s
.82013 .66953 m .81396 .63237 L .82624 .63647 L p .707 .577 .707 r
F P
0 g
s
.44574 .5628 m .44181 .61781 L .46582 .61318 L p .707 .577 .707 r
F P
0 g
s
.46582 .61318 m .46976 .55817 L .44574 .5628 L p .707 .577 .707 r
F P
0 g
s
.65296 .77152 m .64553 .75388 L .65303 .74756 L p .707 .577 .707 r
F P
0 g
s
.65626 .553 m .65233 .60801 L .63597 .61503 L p .707 .577 .707 r
F P
0 g
s
.65303 .74756 m .66047 .76521 L .65296 .77152 L p .707 .577 .707 r
F P
0 g
s
.82083 .56703 m .81689 .62204 L .79591 .61357 L p .707 .577 .707 r
F P
0 g
s
.79591 .61357 m .79984 .55856 L .82083 .56703 L p .707 .577 .707 r
F P
0 g
s
.32225 .60762 m .32618 .55261 L .3052 .54415 L p .707 .577 .707 r
F P
0 g
s
.32618 .55261 m .32225 .60762 L .34962 .61424 L p .707 .577 .707 r
F P
0 g
s
.83137 .67523 m .83881 .69287 L .82812 .69426 L p .707 .577 .707 r
F P
0 g
s
.82812 .69426 m .82069 .67661 L .83137 .67523 L p .707 .577 .707 r
F P
0 g
s
.38428 .6702 m .37812 .63304 L .34738 .63643 L p .707 .577 .707 r
F P
0 g
s
.37812 .63304 m .38428 .6702 L .41572 .66465 L p .707 .577 .707 r
F P
0 g
s
.41572 .66465 m .40956 .62749 L .37812 .63304 L p .707 .577 .707 r
F P
0 g
s
.40956 .62749 m .41572 .66465 L .44479 .65748 L p .707 .577 .707 r
F P
0 g
s
.44479 .65748 m .43862 .62032 L .40956 .62749 L p .707 .577 .707 r
F P
0 g
s
.65233 .60801 m .65626 .553 L .68028 .54838 L p .707 .577 .707 r
F P
0 g
s
.34738 .63643 m .35355 .67359 L .38428 .6702 L p .707 .577 .707 r
F P
0 g
s
.35355 .67359 m .34738 .63643 L .32037 .63734 L p .707 .577 .707 r
F P
0 g
s
.64106 .70117 m .6349 .66401 L .6512 .6558 L p .707 .577 .707 r
F P
0 g
s
.39428 .70844 m .38684 .6908 L .35833 .70184 L p .707 .577 .707 r
F P
0 g
s
.38684 .6908 m .39428 .70844 L .42371 .69598 L p .707 .577 .707 r
F P
0 g
s
.42371 .69598 m .41628 .67834 L .38684 .6908 L p .707 .577 .707 r
F P
0 g
s
.43862 .62032 m .44479 .65748 L .46864 .64939 L p .707 .577 .707 r
F P
0 g
s
.46864 .64939 m .46247 .61223 L .43862 .62032 L p .707 .577 .707 r
F P
0 g
s
.41628 .67834 m .42371 .69598 L .45119 .68333 L p .707 .577 .707 r
F P
0 g
s
.45119 .68333 m .44376 .66569 L .41628 .67834 L p .707 .577 .707 r
F P
0 g
s
.35833 .70184 m .36576 .71949 L .39428 .70844 L p .707 .577 .707 r
F P
0 g
s
.46976 .55817 m .46582 .61318 L .48218 .60617 L p .707 .577 .707 r
F P
0 g
s
.48218 .60617 m .48612 .55116 L .46976 .55817 L p .707 .577 .707 r
F P
0 g
s
.32037 .63734 m .32653 .6745 L .35355 .67359 L p .707 .577 .707 r
F P
0 g
s
.3052 .54415 m .30126 .59916 L .32225 .60762 L p .707 .577 .707 r
F P
0 g
s
.6512 .6558 m .65736 .69296 L .64106 .70117 L p .707 .577 .707 r
F P
0 g
s
.81396 .63237 m .82013 .66953 L .79947 .66786 L p .707 .577 .707 r
F P
0 g
s
.79947 .66786 m .79331 .6307 L .81396 .63237 L p .707 .577 .707 r
F P
0 g
s
.79984 .55856 m .79591 .61357 L .76853 .60696 L p .707 .577 .707 r
F P
0 g
s
.76853 .60696 m .77246 .55195 L .79984 .55856 L p .707 .577 .707 r
F P
0 g
s
.30126 .59916 m .3052 .54415 L .29266 .53467 L p .707 .577 .707 r
F P
0 g
s
.36576 .71949 m .35833 .70184 L .33353 .7104 L p .707 .577 .707 r
F P
0 g
s
.68028 .54838 m .67634 .60339 L .65233 .60801 L p .707 .577 .707 r
F P
0 g
s
.44376 .66569 m .45119 .68333 L .47402 .67173 L p .707 .577 .707 r
F P
0 g
s
.47402 .67173 m .46659 .65409 L .44376 .66569 L p .707 .577 .707 r
F P
0 g
s
.33353 .7104 m .34097 .72804 L .36576 .71949 L p .707 .577 .707 r
F P
0 g
s
.32653 .6745 m .32037 .63734 L .29971 .63566 L p .707 .577 .707 r
F P
0 g
s
.66047 .76521 m .65303 .74756 L .66898 .73814 L p .707 .577 .707 r
F P
0 g
s
.67634 .60339 m .68028 .54838 L .70961 .54659 L p .707 .577 .707 r
F P
0 g
s
.66898 .73814 m .67641 .75579 L .66047 .76521 L p .707 .577 .707 r
F P
0 g
s
.82069 .67661 m .82812 .69426 L .80947 .69948 L p .707 .577 .707 r
F P
0 g
s
.80947 .69948 m .80203 .68184 L .82069 .67661 L p .707 .577 .707 r
F P
0 g
s
.46247 .61223 m .46864 .64939 L .48494 .64119 L p .707 .577 .707 r
F P
0 g
s
.48494 .64119 m .47877 .60403 L .46247 .61223 L p .707 .577 .707 r
F P
0 g
s
.29971 .63566 m .30587 .67282 L .32653 .6745 L p .707 .577 .707 r
F P
0 g
s
.77246 .55195 m .76853 .60696 L .73743 .60283 L p .707 .577 .707 r
F P
0 g
s
.73743 .60283 m .74137 .54782 L .77246 .55195 L p .707 .577 .707 r
F P
0 g
s
.65736 .69296 m .6512 .6558 L .67505 .64772 L p .707 .577 .707 r
F P
0 g
s
.29266 .53467 m .28873 .58968 L .30126 .59916 L p .707 .577 .707 r
F P
0 g
s
.70567 .6016 m .70961 .54659 L .74137 .54782 L p .707 .577 .707 r
F P
0 g
s
.70961 .54659 m .70567 .6016 L .67634 .60339 L p .707 .577 .707 r
F P
0 g
s
.34097 .72804 m .33353 .7104 L .31488 .71562 L p .707 .577 .707 r
F P
0 g
s
.48612 .55116 m .48218 .60617 L .48928 .59745 L p .707 .577 .707 r
F P
0 g
s
.48928 .59745 m .49321 .54244 L .48612 .55116 L p .707 .577 .707 r
F P
0 g
s
.31488 .71562 m .32231 .73327 L .34097 .72804 L p .707 .577 .707 r
F P
0 g
s
.46659 .65409 m .47402 .67173 L .48997 .66232 L p .707 .577 .707 r
F P
0 g
s
.48997 .66232 m .48253 .64467 L .46659 .65409 L p .707 .577 .707 r
F P
0 g
s
.74137 .54782 m .73743 .60283 L .70567 .6016 L p .707 .577 .707 r
F P
0 g
s
.79331 .6307 m .79947 .66786 L .77245 .66876 L p .707 .577 .707 r
F P
0 g
s
.77245 .66876 m .76629 .6316 L .79331 .6307 L p .707 .577 .707 r
F P
0 g
s
.67505 .64772 m .68121 .68488 L .65736 .69296 L p .707 .577 .707 r
F P
0 g
s
.30587 .67282 m .29971 .63566 L .28743 .63157 L p .707 .577 .707 r
F P
0 g
s
.28873 .58968 m .29266 .53467 L .2898 .5251 L p .707 .577 .707 r
F P
0 g
s
.67641 .75579 m .66898 .73814 L .69181 .72654 L p .707 .577 .707 r
F P
0 g
s
.69181 .72654 m .69924 .74419 L .67641 .75579 L p .707 .577 .707 r
F P
0 g
s
.80203 .68184 m .80947 .69948 L .78467 .70804 L p .707 .577 .707 r
F P
0 g
s
.78467 .70804 m .77723 .69039 L .80203 .68184 L p .707 .577 .707 r
F P
0 g
s
.68121 .68488 m .67505 .64772 L .70412 .64055 L p .707 .577 .707 r
F P
0 g
s
.28743 .63157 m .29359 .66873 L .30587 .67282 L p .707 .577 .707 r
F P
0 g
s
.47877 .60403 m .48494 .64119 L .49209 .63366 L p .707 .577 .707 r
F P
0 g
s
.49209 .63366 m .48593 .5965 L .47877 .60403 L p .707 .577 .707 r
F P
0 g
s
.76629 .6316 m .77245 .66876 L .74172 .67215 L p .707 .577 .707 r
F P
0 g
s
.74172 .67215 m .73555 .63499 L .76629 .6316 L p .707 .577 .707 r
F P
0 g
s
.70412 .64055 m .71028 .67771 L .68121 .68488 L p .707 .577 .707 r
F P
0 g
s
.32231 .73327 m .31488 .71562 L .30419 .71701 L p .707 .577 .707 r
F P
0 g
s
.2898 .5251 m .28587 .58011 L .28873 .58968 L p .707 .577 .707 r
F P
0 g
s
.30419 .71701 m .31162 .73465 L .32231 .73327 L p .707 .577 .707 r
F P
0 g
s
.71028 .67771 m .70412 .64055 L .73555 .63499 L p .707 .577 .707 r
F P
0 g
s
.48253 .64467 m .48997 .66232 L .49747 .656 L p .707 .577 .707 r
F P
0 g
s
.49747 .656 m .49004 .63836 L .48253 .64467 L p .707 .577 .707 r
F P
0 g
s
.73555 .63499 m .74172 .67215 L .71028 .67771 L p .707 .577 .707 r
F P
0 g
s
.49321 .54244 m .48928 .59745 L .48642 .58788 L p .707 .577 .707 r
F P
0 g
s
.48642 .58788 m .49035 .53287 L .49321 .54244 L p .707 .577 .707 r
F P
0 g
s
.69924 .74419 m .69181 .72654 L .71929 .7139 L p .707 .577 .707 r
F P
0 g
s
.77723 .69039 m .78467 .70804 L .75616 .71908 L p .707 .577 .707 r
F P
0 g
s
.75616 .71908 m .74872 .70144 L .77723 .69039 L p .707 .577 .707 r
F P
0 g
s
.71929 .7139 m .72672 .73154 L .69924 .74419 L p .707 .577 .707 r
F P
0 g
s
.29359 .66873 m .28743 .63157 L .28473 .62546 L p .707 .577 .707 r
F P
0 g
s
.28587 .58011 m .2898 .5251 L .2969 .51639 L p .707 .577 .707 r
F P
0 g
s
.72672 .73154 m .71929 .7139 L .74872 .70144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74872 .70144 m .75616 .71908 L .72672 .73154 L p .707 .577 .707 r
F P
0 g
s
.28473 .62546 m .2909 .66262 L .29359 .66873 L p .707 .577 .707 r
F P
0 g
s
.48593 .5965 m .49209 .63366 L .48939 .62755 L p .707 .577 .707 r
F P
0 g
s
.48939 .62755 m .48323 .59039 L .48593 .5965 L p .707 .577 .707 r
F P
0 g
s
.31162 .73465 m .30419 .71701 L .30252 .71442 L p .707 .578 .707 r
F P
0 g
s
.2969 .51639 m .29296 .5714 L .28587 .58011 L p .707 .577 .707 r
F P
0 g
s
.30252 .71442 m .30995 .73206 L .31162 .73465 L p .707 .578 .707 r
F P
0 g
s
.49004 .63836 m .49747 .656 L .4958 .65341 L p .707 .578 .707 r
F P
0 g
s
.4958 .65341 m .48836 .63577 L .49004 .63836 L p .707 .578 .707 r
F P
0 g
s
.49035 .53287 m .48642 .58788 L .47388 .57841 L p .707 .577 .707 r
F P
0 g
s
.47388 .57841 m .47782 .5234 L .49035 .53287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29296 .5714 m .2969 .51639 L .31325 .50937 L p .707 .577 .707 r
F P
0 g
s
.2909 .66262 m .28473 .62546 L .29189 .61793 L p .707 .577 .707 r
F P
0 g
s
.29189 .61793 m .29805 .65509 L .2909 .66262 L p .707 .577 .707 r
F P
0 g
s
.48323 .59039 m .48939 .62755 L .47712 .62346 L p .707 .577 .707 r
F P
0 g
s
.47712 .62346 m .47095 .5863 L .48323 .59039 L p .707 .577 .707 r
F P
0 g
s
.31325 .50937 m .30932 .56438 L .29296 .5714 L p .707 .577 .707 r
F P
0 g
s
.30995 .73206 m .30252 .71442 L .31002 .7081 L p .707 .577 .707 r
F P
0 g
s
.47782 .5234 m .47388 .57841 L .4529 .56994 L p .707 .577 .707 r
F P
0 g
s
.4529 .56994 m .45683 .51493 L .47782 .5234 L p .707 .577 .707 r
F P
0 g
s
.31002 .7081 m .31746 .72575 L .30995 .73206 L p .707 .577 .707 r
F P
0 g
s
.48836 .63577 m .4958 .65341 L .48511 .65479 L p .707 .577 .707 r
F P
0 g
s
.48511 .65479 m .47768 .63715 L .48836 .63577 L p .707 .577 .707 r
F P
0 g
s
.30932 .56438 m .31325 .50937 L .33727 .50475 L p .707 .577 .707 r
F P
0 g
s
.29805 .65509 m .29189 .61793 L .30819 .60973 L p .707 .577 .707 r
F P
0 g
s
.30819 .60973 m .31435 .64689 L .29805 .65509 L p .707 .577 .707 r
F P
0 g
s
.47095 .5863 m .47712 .62346 L .45646 .62178 L p .707 .577 .707 r
F P
0 g
s
.45646 .62178 m .45029 .58462 L .47095 .5863 L p .707 .577 .707 r
F P
0 g
s
.45683 .51493 m .4529 .56994 L .42552 .56333 L p .707 .577 .707 r
F P
0 g
s
.42552 .56333 m .42945 .50832 L .45683 .51493 L p .707 .577 .707 r
F P
0 g
s
.33727 .50475 m .33333 .55976 L .30932 .56438 L p .707 .577 .707 r
F P
0 g
s
.33333 .55976 m .33727 .50475 L .3666 .50296 L p .707 .577 .707 r
F P
0 g
s
.31746 .72575 m .31002 .7081 L .32597 .69868 L p .707 .577 .707 r
F P
0 g
s
.32597 .69868 m .3334 .71633 L .31746 .72575 L p .707 .577 .707 r
F P
0 g
s
.47768 .63715 m .48511 .65479 L .46646 .66002 L p .707 .577 .707 r
F P
0 g
s
.46646 .66002 m .45902 .64238 L .47768 .63715 L p .707 .577 .707 r
F P
0 g
s
.31435 .64689 m .30819 .60973 L .33204 .60164 L p .707 .577 .707 r
F P
0 g
s
.42945 .50832 m .42552 .56333 L .39442 .5592 L p .707 .577 .707 r
F P
0 g
s
.39442 .5592 m .39836 .50419 L .42945 .50832 L p .707 .577 .707 r
F P
0 g
s
.36266 .55797 m .3666 .50296 L .39836 .50419 L p .707 .577 .707 r
F P
0 g
s
.3666 .50296 m .36266 .55797 L .33333 .55976 L p .707 .577 .707 r
F P
0 g
s
.39836 .50419 m .39442 .5592 L .36266 .55797 L p .707 .577 .707 r
F P
0 g
s
.45029 .58462 m .45646 .62178 L .42944 .62268 L p .707 .577 .707 r
F P
0 g
s
.42944 .62268 m .42328 .58552 L .45029 .58462 L p .707 .577 .707 r
F P
0 g
s
.33204 .60164 m .3382 .6388 L .31435 .64689 L p .707 .577 .707 r
F P
0 g
s
.3334 .71633 m .32597 .69868 L .3488 .68708 L p .707 .577 .707 r
F P
0 g
s
.3488 .68708 m .35623 .70473 L .3334 .71633 L p .707 .577 .707 r
F P
0 g
s
.3382 .6388 m .33204 .60164 L .3611 .59447 L p .707 .577 .707 r
F P
0 g
s
.45902 .64238 m .46646 .66002 L .44166 .66858 L p .707 .577 .707 r
F P
0 g
s
.44166 .66858 m .43422 .65093 L .45902 .64238 L p .707 .577 .707 r
F P
0 g
s
.42328 .58552 m .42944 .62268 L .39871 .62608 L p .707 .577 .707 r
F P
0 g
s
.39871 .62608 m .39254 .58892 L .42328 .58552 L p .707 .577 .707 r
F P
0 g
s
.3611 .59447 m .36727 .63163 L .3382 .6388 L p .707 .577 .707 r
F P
0 g
s
.36727 .63163 m .3611 .59447 L .39254 .58892 L p .707 .577 .707 r
F P
0 g
s
.39254 .58892 m .39871 .62608 L .36727 .63163 L p .707 .577 .707 r
F P
0 g
s
.35623 .70473 m .3488 .68708 L .37628 .67443 L p .707 .577 .707 r
F P
0 g
s
.43422 .65093 m .44166 .66858 L .41315 .67962 L p .707 .577 .707 r
F P
0 g
s
.41315 .67962 m .40571 .66198 L .43422 .65093 L p .707 .577 .707 r
F P
0 g
s
.37628 .67443 m .38371 .69208 L .35623 .70473 L p .707 .577 .707 r
F P
0 g
s
.38371 .69208 m .37628 .67443 L .40571 .66198 L p .707 .577 .707 r
F P
0 g
s
.40571 .66198 m .41315 .67962 L .38371 .69208 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6000OGoo001oOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Uoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00Lgoo1P00
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001^
Ool50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH2001]Ool006]oo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00QJEP8006]oo`00JGoo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF00<007ooOol0J7oo001XOol0
1000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH02eYFJWoo001VOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1WOol006Eoo`03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00aJEP03001oogoo06Ioo`00I7oo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02eYF00<007oo
Ool0IWoo001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1VOol0069oo`04001JEUYF
0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001W
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
0000Igoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IWoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005eooaT000=JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00F7oo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P002EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP<006Aoo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001T
Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`00I7oo001BOol00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP<006Aoo`00DWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001TOol0059oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`001goo5`00AWoo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60010Ool0055oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPD000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003aoo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Goo001AOol0
0`00FUH00003FUH01000FUIJEUYF3`000UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00L0
05YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH3000gOol0055oo`03001JEP0000=JEP@00003FUH005YF00IJEP03001JEUYF009JEQ40
00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003Eoo`00DGoo00@005YF001JEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH0
1`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DGoo00<005YF00000P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035o
o`00DGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`
Ool0055oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000`Ool0055oo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEQ<00003FUH00000008000IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002moo`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000@000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00Dgoo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP<000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00=goo60001Goo0P001EYF00<0
05YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00=7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035o
o`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@00003FUH0
05YF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004
FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000_Ool0
02moo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUH00003FUH500000eYF001JEP05FUH00`00FUIJEP02FUHB0006FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP04001JEP00FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002mo
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF0080031oo`00:goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP<00004FUH005YFFUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH01@00FUIJEUYF00001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P00
<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80006FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00<7oo000[Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP<0031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001J
EUYF00AJEPH00003FUH0000000<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUHB0002FUH3000`Ool002]oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF01000003FUH005YF00MJEP03001JEUYF00AJEP03001J
EUYF009JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH6000`Ool002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00D0009JEP03
001JEUYF00EJEP03001JEUYF00AJEPD00003FUH0000000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00<7oo000[Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005
FUH00`00FUH000030003FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YF000010001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00<7oo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH005YF<Goo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH400000eYF000000030006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<Goo000ZOol00`00FUH00003FUH01000FUIJEUYF3P000goo200015YF00<005YFFUH00`0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080031oo`00:Woo00<005YF00000eYF100000=JEP00FUH01UYF00<005YF
FUH00UYF40000UYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH015YF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080031oo`00
:Woo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH0
0`00FUIJEP04FUH40004FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF0080031oo`00:Woo00<005YF00000P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF1P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF0000031oo`00:Woo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH025YF00@005YF000000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH01000FUIJ
EP00<7oo000ZOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P001EYF
00<005YFFUH01EYF0`001eYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2@001EYF1P0000=JEP00Ool0;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUHD00000eYF00000008FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001UYF00<005YF
FUH015YF00<005YFFUH00UYF1000;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUHB0002FUH40003Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=oo`0000000P00
0UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001P00;goo000[Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01eYF1`0015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJ
EP00000007oo008000=JEP03001JEUYF00IJEP<000UJEP04001JEP000003FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000goo000000040006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000UYF00<005YF
FUH00P00;goo000/Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP050006FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P001EYF00<005YF
FUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P0025YF00<005YFFUH00`001EYF00<005YFFUH00eYF0P0025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP04001J
EUYF000_Ool002ioo`8000AJEP03001JEUYF00=JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00QJEP8000UJEP03001JEP00008000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000AJEP04
001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool300000eYF001JEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH20002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH01EYF00@005YFFUIJEPH002ioo`00<Woo100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00EJEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP05FUH40003FUH2000_Ool002moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000QJEP04
001JEP000006FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20008FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0^Ool0
02eoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP80009JEP03001JEUYF00AJEP<000QJEP03001JEUYF008000QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<000UJEP03001JEUYF008000AJEP05001J
EUYFFUH0000aOol002]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP@000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000000eYF
00<005YFFUH01UYF0`001eYF0`00<Woo000ZOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00@005YF000000AJEP03001JEUYF
00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH2000dOol002Yoo`8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF009J
EP8000MJEP03001JEP00008000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000QJEP03001JEP00008000EJEP03001JEUYF009JEP8003Ioo`00:Goo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPX000EJEP80009JEP07
001JEUYFFUH005YF00001UYF100000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00004`0000=J
EP00FUH025YF0`0025YF00@005YF000003Qoo`00:Goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00AJEPH00003Ool000000080009JEP03001JEUYF00IJEP80009JEP<0009JEP03001JEUYF
009JEP8000=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH80002FUH60004FUH00`00
FUIJEP04FUH200000eYF001JEP08FUH2000jOol002Uoo`04001JEUYF0004FUH00`00FUIJEP05FUH0
0`00FUIJEP0@00000eYF001JEP07FUH20002FUH00`00FUIJEP03FUH00`00FUH000020004Ool00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF1P001eYF00<005YFFUH00UYF0P0015YF
00<005YFFUH015YF0P00?7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH80004FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEP@00003FUH0000000Aoo`03001JEP00
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUH000020009FUH01000FUH000001UYF
00<005YFFUH00UYF0P00?Woo000ZOol00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH0
1UYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YF00001@000UYF00D005YFFUIJEP0000Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP05001JEUYFFUH00003FUH01000FUIJEUYF0`0015YF0P000eYF00<005YFFUH0
1EYF0`002EYF00@005YF0000041oo`00:Woo00<005YF00001EYF00@005YF000000EJEP03001JEUYF
00MJEP03001JEUYF00<000=JEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH00P00
0goo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP8000EJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00EJEP<0049oo`00:Woo00@005YFFUH000=JEP@000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF009JEP05001JEUYFFUH00003Ool0
0`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40007FUH00`00FUH000020005FUH00`00
FUIJEP03FUH20015Ool002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP03FUH00`00FUH000020002Ool0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH20009FUH0
0`00FUH000020017Ool002]oo`9JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00MJEP03001JEUYF00@0009JEP04001oogoo0009FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP04FUHI0005FUH00`00FUIJEP05FUH01@00FUIJEUYF
00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01EYF0`00BWoo000[Ool01EYF001JEUYF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH015YF1000
15YF0P000goo00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF2P002eYF00<005YFFUH0
2EYF20001UYF00<005YFFUH00P001UYF00@005YF000000AJEP03001JEUYF00=JEP8004eoo`00:goo
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<007ooOol00Woo00<005YFFUH01eYF00<005YF
FUH01eYF00<005YFFUH01P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF0P001eYF00<005YF00000P00Cgoo000[Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP08FUH0
1000FUH0000015YF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000800005
FUH005YFFUH00003FUH200000eYF001JEP05FUH3001BOol002aoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPH000EJEP03001JEUYF00EJEP<000MJEP<000Qoo`UJEP03001JEUYF
00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF009JEP<0009JEP<000=JEP03001JEUYF009JEP8005Eoo`00;Woo500000=oo`00000025YF
00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<007ooOol027oo2EYF00<005YF00000`002EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YF00000P00EWoo0011Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH2000;Ool8FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF
1`00EWoo000oOol20003FUH00`00FUIJEP06FUH40008FUH01000FUH000003Goo1UYF0P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF0P000UYF1@0000AJEP00FUIJEP8005Ioo`00?Goo0P001UYF00<005YFFUH00eYF0`00
00=JEP00FUH025YF0P003goo15YF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF00<005YF00000`001EYF00@005YFFUH005Io
o`00>goo0P0025YF00<005YFFUH00`001EYF00<005YFFUH015YF0P004Goo0UYF0P002EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF
00H005YFFUH005YF0005FUH01000FUIJEP00EWoo000iOol200000eYF001JEP08FUH20008FUH00`00
FUIJEP02FUH2000COol00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH01000FUIJEP00EGoo000gOol20004FUH00`00FUIJEP04FUH200000eYF001J
EP08FUH01000FUH000005Goo00=JEP00FUH00eYF00<005YFFUH03eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF
1@00EGoo000eOol20006FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH3000GOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH2001FOol003Ao
o`8000QJEP04001JEP000006FUH00`00FUIJEP03FUH2000JOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUIJEUYF0P001UYF0`0015YF00<007ooOol0EGoo000bOol20002FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP03000MOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUIJEP00FUH0009JEP@0009J
EP05001JEUYFFUH0001HOol0035oo`03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP<0021oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0009JEP<000MJEP<005Uoo`00<7oo0P00
1EYF00@005YF000000AJEP03001JEUYF00=JEP<002Aoo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00004FUH0
00000002FUH00`00FUIJEP04FUH2001KOol002moo`04001JEUYF0004FUH20007FUH00`00FUH00002
000YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05000015YF000000001EYF00<005YFFUH00UYF0P00GGoo000_Ool01000FUIJEP000eYF
00<005YF00001UYF0`00;Woo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF1@0015YF0`0025YF00@005YF000005moo`00;goo0P000UYF0`000UYF00<005YF
FUH00UYF0P00<goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPL000IJEP800003FUH005YF00QJEP80065oo`00<7oo00@005YFFUH000EJEP04001JEP00000i
Ool80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH90006FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH2001SOol0031oo`05001JEP00FUH00002FUH40013OolI0004Ool30009FUH01000FUH0
00001UYF00<005YFFUH00UYF0P00IGoo000aOol00`00FUH00003001SOol01@00FUIJEUYF00001eYF
0`002EYF00@005YF000006Moo`00<Goo0P00IGoo0P0015YF00<005YFFUH00eYF0P000eYF00<005YF
FUH01EYF0`00JGoo002FOol20007FUH00`00FUH000020005FUH00`00FUIJEP03FUH2001/Ool009Ao
o`800003FUH005YF00IJEP8000UJEP03001JEP00008006ioo`00TWoo0P0015YF00<005YFFUH00UYF
0P000UYF00<005YFFUH01EYF0`00LGoo002AOol20005FUH01@00FUIJEUYF000015YF00<005YFFUH0
0eYF0P00M7oo002@Ool01000FUIJEP001EYF0`001UYF00<005YF00000P00MWoo002@Ool01000FUIJ
EP0015YF0`001UYF0`00NGoo002AOol01@00FUIJEP00FUH00P000UYF00<005YFFUH00UYF0P00O7oo
002AOol00`00FUIJEP020005FUH01000FUH00000OWoo002BOol01EYF001JEUYF00000UYF1000P7oo
002BOol00`00FUIJEP040024Ool009=oo`8008Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59021 .75232 m .59264 .69706 L .5615 .69378 L p .707 .577 .707 r
F P
0 g
s
.59264 .69706 m .59021 .75232 L .62202 .75279 L p .707 .577 .707 r
F P
0 g
s
.62202 .75279 m .62445 .69752 L .59264 .69706 L p .707 .577 .707 r
F P
0 g
s
.62445 .69752 m .62202 .75279 L .65138 .75039 L p .707 .577 .707 r
F P
0 g
s
.65138 .75039 m .65381 .69513 L .62445 .69752 L p .707 .577 .707 r
F P
0 g
s
.55907 .74904 m .5615 .69378 L .53407 .68801 L p .707 .577 .707 r
F P
0 g
s
.5615 .69378 m .55907 .74904 L .59021 .75232 L p .707 .577 .707 r
F P
0 g
s
.65381 .69513 m .65138 .75039 L .67542 .74538 L p .707 .577 .707 r
F P
0 g
s
.67542 .74538 m .67785 .69011 L .65381 .69513 L p .707 .577 .707 r
F P
0 g
s
.53164 .74327 m .53407 .68801 L .51305 .68031 L p .707 .577 .707 r
F P
0 g
s
.53407 .68801 m .53164 .74327 L .55907 .74904 L p .707 .577 .707 r
F P
0 g
s
.5925 .80897 m .58868 .77172 L .55768 .77309 L p .707 .577 .707 r
F P
0 g
s
.58868 .77172 m .5925 .80897 L .62419 .80524 L p .707 .577 .707 r
F P
0 g
s
.62419 .80524 m .62037 .76799 L .58868 .77172 L p .707 .577 .707 r
F P
0 g
s
.62037 .76799 m .62419 .80524 L .65345 .79952 L p .707 .577 .707 r
F P
0 g
s
.65345 .79952 m .64963 .76227 L .62037 .76799 L p .707 .577 .707 r
F P
0 g
s
.5615 .81034 m .55768 .77309 L .53039 .77197 L p .707 .577 .707 r
F P
0 g
s
.55768 .77309 m .5615 .81034 L .5925 .80897 L p .707 .577 .707 r
F P
0 g
s
.59923 .84454 m .59455 .82616 L .56441 .83235 L p .707 .577 .707 r
F P
0 g
s
.59455 .82616 m .59923 .84454 L .63014 .83647 L p .707 .577 .707 r
F P
0 g
s
.63014 .83647 m .62546 .81809 L .59455 .82616 L p .707 .577 .707 r
F P
0 g
s
.64963 .76227 m .65345 .79952 L .67742 .79237 L p .707 .577 .707 r
F P
0 g
s
.67742 .79237 m .6736 .75512 L .64963 .76227 L p .707 .577 .707 r
F P
0 g
s
.67785 .69011 m .67542 .74538 L .69178 .73823 L p .707 .577 .707 r
F P
0 g
s
.69178 .73823 m .69422 .68296 L .67785 .69011 L p .707 .577 .707 r
F P
0 g
s
.62546 .81809 m .63014 .83647 L .65879 .8273 L p .707 .577 .707 r
F P
0 g
s
.65879 .8273 m .65411 .80892 L .62546 .81809 L p .707 .577 .707 r
F P
0 g
s
.51305 .68031 m .51061 .73557 L .53164 .74327 L p .707 .577 .707 r
F P
0 g
s
.56441 .83235 m .56909 .85073 L .59923 .84454 L p .707 .577 .707 r
F P
0 g
s
.53039 .77197 m .53421 .80922 L .5615 .81034 L p .707 .577 .707 r
F P
0 g
s
.56909 .85073 m .56441 .83235 L .53797 .83604 L p .707 .577 .707 r
F P
0 g
s
.51061 .73557 m .51305 .68031 L .50047 .67144 L p .707 .577 .707 r
F P
0 g
s
.53421 .80922 m .53039 .77197 L .50948 .76847 L p .707 .577 .707 r
F P
0 g
s
.53797 .83604 m .54266 .85442 L .56909 .85073 L p .707 .577 .707 r
F P
0 g
s
.65411 .80892 m .65879 .8273 L .68237 .81794 L p .707 .577 .707 r
F P
0 g
s
.68237 .81794 m .67769 .79955 L .65411 .80892 L p .707 .577 .707 r
F P
0 g
s
.50948 .76847 m .5133 .80572 L .53421 .80922 L p .707 .577 .707 r
F P
0 g
s
.6736 .75512 m .67742 .79237 L .69377 .78448 L p .707 .577 .707 r
F P
0 g
s
.69377 .78448 m .68995 .74723 L .6736 .75512 L p .707 .577 .707 r
F P
0 g
s
.50047 .67144 m .49804 .7267 L .51061 .73557 L p .707 .577 .707 r
F P
0 g
s
.54266 .85442 m .53797 .83604 L .51784 .83688 L p .707 .577 .707 r
F P
0 g
s
.69422 .68296 m .69178 .73823 L .69887 .72965 L p .707 .577 .707 r
F P
0 g
s
.69887 .72965 m .7013 .67438 L .69422 .68296 L p .707 .577 .707 r
F P
0 g
s
.51784 .83688 m .52253 .85526 L .54266 .85442 L p .707 .577 .707 r
F P
0 g
s
.67769 .79955 m .68237 .81794 L .69858 .80929 L p .707 .577 .707 r
F P
0 g
s
.69858 .80929 m .6939 .79091 L .67769 .79955 L p .707 .577 .707 r
F P
0 g
s
.5133 .80572 m .50948 .76847 L .49701 .76292 L p .707 .577 .707 r
F P
0 g
s
.49804 .7267 m .50047 .67144 L .49759 .66226 L p .707 .577 .707 r
F P
0 g
s
.49701 .76292 m .50083 .80018 L .5133 .80572 L p .707 .577 .707 r
F P
0 g
s
.68995 .74723 m .69377 .78448 L .70088 .77664 L p .707 .577 .707 r
F P
0 g
s
.70088 .77664 m .69706 .73938 L .68995 .74723 L p .707 .577 .707 r
F P
0 g
s
.52253 .85526 m .51784 .83688 L .50599 .83479 L p .707 .577 .707 r
F P
0 g
s
.49759 .66226 m .49516 .71753 L .49804 .7267 L p .707 .577 .707 r
F P
0 g
s
.50599 .83479 m .51067 .85317 L .52253 .85526 L p .707 .577 .707 r
F P
0 g
s
.7013 .67438 m .69887 .72965 L .69599 .72047 L p .707 .577 .707 r
F P
0 g
s
.69599 .72047 m .69842 .66521 L .7013 .67438 L p .707 .577 .707 r
F P
0 g
s
.6939 .79091 m .69858 .80929 L .70583 .8022 L p .707 .577 .707 r
F P
0 g
s
.70583 .8022 m .70114 .78382 L .6939 .79091 L p .707 .577 .707 r
F P
0 g
s
.50083 .80018 m .49701 .76292 L .49419 .75588 L p .707 .577 .707 r
F P
0 g
s
.49516 .71753 m .49759 .66226 L .50468 .65368 L p .707 .577 .707 r
F P
0 g
s
.49419 .75588 m .49801 .79314 L .50083 .80018 L p .707 .577 .707 r
F P
0 g
s
.50468 .65368 m .50225 .70894 L .49516 .71753 L p .707 .577 .707 r
F P
0 g
s
.49801 .79314 m .49419 .75588 L .5013 .74804 L p .707 .577 .707 r
F P
0 g
s
.5013 .74804 m .50512 .78529 L .49801 .79314 L p .707 .577 .707 r
F P
0 g
s
.50084 .82131 m .48403 .31792 L .44004 .31673 L p .707 .577 .707 r
F P
0 g
s
.50225 .70894 m .50468 .65368 L .52104 .64653 L p .707 .577 .707 r
F P
0 g
s
.52104 .64653 m .51861 .70179 L .50225 .70894 L p .707 .577 .707 r
F P
0 g
s
.51861 .70179 m .52104 .64653 L .54508 .64151 L p .707 .577 .707 r
F P
0 g
s
.50512 .78529 m .5013 .74804 L .51764 .74015 L p .707 .577 .707 r
F P
0 g
s
.51764 .74015 m .52147 .77741 L .50512 .78529 L p .707 .577 .707 r
F P
0 g
s
.54508 .64151 m .54265 .69678 L .51861 .70179 L p .707 .577 .707 r
F P
0 g
s
.51549 .84126 m .51081 .82288 L .52701 .81423 L p .707 .577 .707 r
F P
0 g
s
.52701 .81423 m .5317 .83261 L .51549 .84126 L p .707 .577 .707 r
F P
0 g
s
.52147 .77741 m .51764 .74015 L .54162 .733 L p .707 .577 .707 r
F P
0 g
s
.54162 .733 m .54544 .77025 L .52147 .77741 L p .707 .577 .707 r
F P
0 g
s
.5317 .83261 m .52701 .81423 L .55059 .80486 L p .707 .577 .707 r
F P
0 g
s
.55059 .80486 m .55528 .82325 L .5317 .83261 L p .707 .577 .707 r
F P
0 g
s
.48403 .31792 m .50084 .82131 L .54577 .81886 L p .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .54162 .733 L .56511 .72841 L p .707 .577 .707 r
F P
0 g
s
.56511 .72841 m .57088 .72728 L p .56643 .73479 L .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .56511 .72841 L .56643 .73479 L .707 .577 .707 r
F
.52895 .31547 m .48403 .31792 L p .48962 .36328 L F P
0 g
s
.54577 .81886 m .53843 .59938 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.53843 .59938 m .52895 .31547 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.54265 .69678 m .54508 .64151 L .57444 .63912 L p .707 .577 .707 r
F P
0 g
s
.57201 .69439 m .57444 .63912 L .60625 .63959 L p .707 .577 .707 r
F P
0 g
s
.57444 .63912 m .57201 .69439 L .54265 .69678 L p .707 .577 .707 r
F P
0 g
s
.60625 .63959 m .60382 .69485 L .57201 .69439 L p .707 .577 .707 r
F P
0 g
s
.57088 .72728 m .5747 .76453 L .54544 .77025 L p .707 .577 .707 r
F P
0 g
s
.5747 .76453 m .57088 .72728 L .60257 .72355 L p .707 .577 .707 r
F P
0 g
s
.60257 .72355 m .60639 .7608 L .5747 .76453 L p .707 .577 .707 r
F P
0 g
s
.55528 .82325 m .55059 .80486 L .57924 .7957 L p .707 .577 .707 r
F P
0 g
s
.57924 .7957 m .58392 .81408 L .55528 .82325 L p .707 .577 .707 r
F P
0 g
s
.58392 .81408 m .57924 .7957 L .61015 .78762 L p .707 .577 .707 r
F P
0 g
s
.61015 .78762 m .61483 .80601 L .58392 .81408 L p .707 .577 .707 r
F P
0 g
s
.52895 .31547 m .54577 .81886 L .58723 .81302 L p .707 .577 .707 r
F P
0 g
s
.58723 .81302 m .57041 .30963 L .52895 .31547 L p .707 .577 .707 r
F P
0 g
s
.45686 .82012 m .44004 .31673 L .4013 .31203 L p .707 .577 .707 r
F P
0 g
s
.44004 .31673 m .45686 .82012 L .50084 .82131 L p .707 .577 .707 r
F P
0 g
s
.69706 .73938 m .70088 .77664 L .69806 .7696 L p .707 .577 .707 r
F P
0 g
s
.69806 .7696 m .69424 .73234 L .69706 .73938 L p .707 .577 .707 r
F P
0 g
s
.51067 .85317 m .50599 .83479 L .50356 .82996 L p .707 .577 .707 r
F P
0 g
s
.50356 .82996 m .50824 .84834 L .51067 .85317 L p .707 .577 .707 r
F P
0 g
s
.63739 .64287 m .63496 .69813 L .60382 .69485 L p .707 .577 .707 r
F P
0 g
s
.60382 .69485 m .60625 .63959 L .63739 .64287 L p .707 .577 .707 r
F P
0 g
s
.63357 .72218 m .63739 .75943 L .60639 .7608 L p .707 .577 .707 r
F P
0 g
s
.60639 .7608 m .60257 .72355 L .63357 .72218 L p .707 .577 .707 r
F P
0 g
s
.6403 .78144 m .64498 .79982 L .61483 .80601 L p .707 .577 .707 r
F P
0 g
s
.61483 .80601 m .61015 .78762 L .6403 .78144 L p .707 .577 .707 r
F P
0 g
s
.57041 .30963 m .58723 .81302 L .62117 .80436 L p .707 .577 .707 r
F P
0 g
s
.62117 .80436 m .60436 .30097 L .57041 .30963 L p .707 .577 .707 r
F P
0 g
s
.69842 .66521 m .69599 .72047 L .68342 .7116 L p .707 .577 .707 r
F P
0 g
s
.68342 .7116 m .68585 .65633 L .69842 .66521 L p .707 .577 .707 r
F P
0 g
s
.70114 .78382 m .70583 .8022 L .7034 .79738 L p .707 .577 .707 r
F P
0 g
s
.7034 .79738 m .69872 .779 L .70114 .78382 L p .707 .577 .707 r
F P
0 g
s
.2472 .71129 m .24963 .65603 L .21849 .65275 L p .707 .577 .707 r
F P
0 g
s
.24963 .65603 m .2472 .71129 L .27901 .71176 L p .707 .577 .707 r
F P
0 g
s
.27901 .71176 m .28144 .6565 L .24963 .65603 L p .707 .577 .707 r
F P
0 g
s
.41812 .81542 m .4013 .31203 L .3716 .30427 L p .707 .577 .707 r
F P
0 g
s
.4013 .31203 m .41812 .81542 L .45686 .82012 L p .707 .577 .707 r
F P
0 g
s
.28144 .6565 m .27901 .71176 L .30837 .70937 L p .707 .577 .707 r
F P
0 g
s
.30837 .70937 m .3108 .6541 L .28144 .6565 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21606 .70801 m .21849 .65275 L .19106 .64698 L p .707 .577 .707 r
F P
0 g
s
.21849 .65275 m .21606 .70801 L .2472 .71129 L p .707 .577 .707 r
F P
0 g
s
.69424 .73234 m .69806 .7696 L .68558 .76405 L p .707 .577 .707 r
F P
0 g
s
.68558 .76405 m .68176 .7268 L .69424 .73234 L p .707 .577 .707 r
F P
0 g
s
.3108 .6541 m .30837 .70937 L .33241 .70435 L p .707 .577 .707 r
F P
0 g
s
.33241 .70435 m .33484 .64909 L .3108 .6541 L p .707 .577 .707 r
F P
0 g
s
.50824 .84834 m .50356 .82996 L .51081 .82288 L p .707 .577 .707 r
F P
0 g
s
.66482 .64864 m .66239 .7039 L .63496 .69813 L p .707 .577 .707 r
F P
0 g
s
.63496 .69813 m .63739 .64287 L .66482 .64864 L p .707 .577 .707 r
F P
0 g
s
.66086 .7233 m .66468 .76055 L .63739 .75943 L p .707 .577 .707 r
F P
0 g
s
.63739 .75943 m .63357 .72218 L .66086 .7233 L p .707 .577 .707 r
F P
0 g
s
.64498 .79982 m .6403 .78144 L .66673 .77774 L p .707 .577 .707 r
F P
0 g
s
.60436 .30097 m .62117 .80436 L .64428 .79372 L p .707 .577 .707 r
F P
0 g
s
.64428 .79372 m .62746 .29033 L .60436 .30097 L p .707 .577 .707 r
F P
0 g
s
.51081 .82288 m .51549 .84126 L .50824 .84834 L p .707 .577 .707 r
F P
0 g
s
.68585 .65633 m .68342 .7116 L .66239 .7039 L p .707 .577 .707 r
F P
0 g
s
.66239 .7039 m .66482 .64864 L .68585 .65633 L p .707 .577 .707 r
F P
0 g
s
.18863 .70224 m .19106 .64698 L .17004 .63928 L p .707 .577 .707 r
F P
0 g
s
.19106 .64698 m .18863 .70224 L .21606 .70801 L p .707 .577 .707 r
F P
0 g
s
.24949 .76643 m .24567 .72918 L .21467 .73055 L p .707 .577 .707 r
F P
0 g
s
.24567 .72918 m .24949 .76643 L .28118 .7627 L p .707 .577 .707 r
F P
0 g
s
.28118 .7627 m .27736 .72545 L .24567 .72918 L p .707 .577 .707 r
F P
0 g
s
.69872 .779 m .7034 .79738 L .69154 .79528 L p .707 .577 .707 r
F P
0 g
s
.69154 .79528 m .68686 .7769 L .69872 .779 L p .707 .577 .707 r
F P
0 g
s
.27736 .72545 m .28118 .7627 L .31044 .75698 L p .707 .577 .707 r
F P
0 g
s
.31044 .75698 m .30662 .71973 L .27736 .72545 L p .707 .577 .707 r
F P
0 g
s
.21849 .7678 m .21467 .73055 L .18738 .72943 L p .707 .577 .707 r
F P
0 g
s
.21467 .73055 m .21849 .7678 L .24949 .76643 L p .707 .577 .707 r
F P
0 g
s
.30662 .71973 m .31044 .75698 L .33441 .74983 L p .707 .577 .707 r
F P
0 g
s
.33441 .74983 m .33059 .71258 L .30662 .71973 L p .707 .577 .707 r
F P
0 g
s
.25623 .80609 m .25154 .78771 L .2214 .7939 L p .707 .577 .707 r
F P
0 g
s
.25154 .78771 m .25623 .80609 L .28714 .79802 L p .707 .577 .707 r
F P
0 g
s
.28714 .79802 m .28245 .77964 L .25154 .78771 L p .707 .577 .707 r
F P
0 g
s
.33484 .64909 m .33241 .70435 L .34877 .6972 L p .707 .577 .707 r
F P
0 g
s
.34877 .6972 m .35121 .64194 L .33484 .64909 L p .707 .577 .707 r
F P
0 g
s
.38842 .80766 m .3716 .30427 L .35384 .29421 L p .707 .577 .707 r
F P
0 g
s
.3716 .30427 m .38842 .80766 L .41812 .81542 L p .707 .577 .707 r
F P
0 g
s
.28245 .77964 m .28714 .79802 L .31578 .78885 L p .707 .577 .707 r
F P
0 g
s
.31578 .78885 m .3111 .77047 L .28245 .77964 L p .707 .577 .707 r
F P
0 g
s
.17004 .63928 m .1676 .69455 L .18863 .70224 L p .707 .577 .707 r
F P
0 g
s
.18738 .72943 m .1912 .76668 L .21849 .7678 L p .707 .577 .707 r
F P
0 g
s
.2214 .7939 m .22608 .81228 L .25623 .80609 L p .707 .577 .707 r
F P
0 g
s
.68176 .7268 m .68558 .76405 L .66468 .76055 L p .707 .577 .707 r
F P
0 g
s
.66468 .76055 m .66086 .7233 L .68176 .7268 L p .707 .577 .707 r
F P
0 g
s
.22608 .81228 m .2214 .7939 L .19496 .79759 L p .707 .577 .707 r
F P
0 g
s
.1676 .69455 m .17004 .63928 L .15747 .63041 L p .707 .577 .707 r
F P
0 g
s
.1912 .76668 m .18738 .72943 L .16647 .72593 L p .707 .577 .707 r
F P
0 g
s
.19496 .79759 m .19965 .81597 L .22608 .81228 L p .707 .577 .707 r
F P
0 g
s
.3111 .77047 m .31578 .78885 L .33936 .77949 L p .707 .577 .707 r
F P
0 g
s
.33936 .77949 m .33468 .7611 L .3111 .77047 L p .707 .577 .707 r
F P
0 g
s
.68686 .7769 m .69154 .79528 L .67141 .79613 L p .707 .577 .707 r
F P
0 g
s
.67141 .79613 m .66673 .77774 L .68686 .7769 L p .707 .577 .707 r
F P
0 g
s
.16647 .72593 m .17029 .76318 L .1912 .76668 L p .707 .577 .707 r
F P
0 g
s
.33059 .71258 m .33441 .74983 L .35076 .74194 L p .707 .577 .707 r
F P
0 g
s
.35076 .74194 m .34694 .70469 L .33059 .71258 L p .707 .577 .707 r
F P
0 g
s
.62746 .29033 m .64428 .79372 L .65428 .78215 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .63746 .27876 L .62746 .29033 L p .707 .577 .707 r
F P
0 g
s
.15747 .63041 m .15503 .68567 L .1676 .69455 L p .707 .577 .707 r
F P
0 g
s
.19965 .81597 m .19496 .79759 L .17483 .79843 L p .707 .577 .707 r
F P
0 g
s
.35121 .64194 m .34877 .6972 L .35586 .68862 L p .707 .577 .707 r
F P
0 g
s
.35586 .68862 m .35829 .63335 L .35121 .64194 L p .707 .577 .707 r
F P
0 g
s
.17483 .79843 m .17952 .81681 L .19965 .81597 L p .707 .577 .707 r
F P
0 g
s
.33468 .7611 m .33936 .77949 L .35557 .77084 L p .707 .577 .707 r
F P
0 g
s
.35557 .77084 m .35089 .75246 L .33468 .7611 L p .707 .577 .707 r
F P
0 g
s
.17029 .76318 m .16647 .72593 L .154 .72039 L p .707 .577 .707 r
F P
0 g
s
.15503 .68567 m .15747 .63041 L .15458 .62124 L p .707 .577 .707 r
F P
0 g
s
.37066 .7976 m .35384 .29421 L .34976 .28283 L p .707 .577 .707 r
F P
0 g
s
.35384 .29421 m .37066 .7976 L .38842 .80766 L p .707 .577 .707 r
F P
0 g
s
.66673 .77774 m .67141 .79613 L .64498 .79982 L p .707 .577 .707 r
F P
0 g
s
.154 .72039 m .15782 .75764 L .17029 .76318 L p .707 .577 .707 r
F P
0 g
s
.34694 .70469 m .35076 .74194 L .35787 .7341 L p .707 .577 .707 r
F P
0 g
s
.35787 .7341 m .35405 .69685 L .34694 .70469 L p .707 .577 .707 r
F P
0 g
s
.17952 .81681 m .17483 .79843 L .16298 .79634 L p .707 .577 .707 r
F P
0 g
s
.15458 .62124 m .15215 .6765 L .15503 .68567 L p .707 .577 .707 r
F P
0 g
s
.16298 .79634 m .16766 .81472 L .17952 .81681 L p .707 .577 .707 r
F P
0 g
s
.35829 .63335 m .35586 .68862 L .35298 .67944 L p .707 .577 .707 r
F P
0 g
s
.35298 .67944 m .35541 .62418 L .35829 .63335 L p .707 .577 .707 r
F P
0 g
s
.35089 .75246 m .35557 .77084 L .36282 .76375 L p .707 .577 .707 r
F P
0 g
s
.36282 .76375 m .35813 .74537 L .35089 .75246 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .65021 .77078 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.65021 .77078 m .63339 .26739 L .63746 .27876 L p .707 .577 .707 r
F P
0 g
s
.63339 .26739 m .65021 .77078 L .63245 .76072 L p .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64669 .67643 L .64519 .67576 L p .707 .577 .707 r
F P
0 g
s
.64519 .67576 m .63422 .67089 L p .64567 .70097 L .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64519 .67576 L .64567 .70097 L .707 .577 .707 r
F
.63746 .27876 m .63809 .29737 L p .63846 .31704 L F P
0 g
s
.63809 .29737 m .65428 .78215 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.15782 .75764 m .154 .72039 L .15118 .71335 L p .707 .577 .707 r
F P
0 g
s
.15215 .6765 m .15458 .62124 L .16167 .61265 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15118 .71335 m .155 .7506 L .15782 .75764 L p .707 .577 .707 r
F P
0 g
s
.35405 .69685 m .35787 .7341 L .35505 .72706 L p .707 .577 .707 r
F P
0 g
s
.35505 .72706 m .35123 .68981 L .35405 .69685 L p .707 .577 .707 r
F P
0 g
s
.16766 .81472 m .16298 .79634 L .16055 .79151 L p .707 .577 .707 r
F P
0 g
s
.16167 .61265 m .15924 .66792 L .15215 .6765 L p .707 .577 .707 r
F P
0 g
s
.16055 .79151 m .16523 .80989 L .16766 .81472 L p .707 .577 .707 r
F P
0 g
s
.34976 .28283 m .36658 .78622 L .37066 .7976 L p .707 .577 .707 r
F P
0 g
s
.36658 .78622 m .34976 .28283 L .35977 .27126 L p .707 .577 .707 r
F P
0 g
s
.35541 .62418 m .35298 .67944 L .34041 .67057 L p .707 .577 .707 r
F P
0 g
s
.34041 .67057 m .34284 .61531 L .35541 .62418 L p .707 .577 .707 r
F P
0 g
s
.35813 .74537 m .36282 .76375 L .36039 .75893 L p .707 .577 .707 r
F P
0 g
s
.36039 .75893 m .35571 .74055 L .35813 .74537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.155 .7506 m .15118 .71335 L .15829 .7055 L p .707 .577 .707 r
F P
0 g
s
.15924 .66792 m .16167 .61265 L .17803 .6055 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15829 .7055 m .16211 .74275 L .155 .7506 L p .707 .577 .707 r
F P
0 g
s
.63245 .76072 m .61563 .25733 L .63339 .26739 L p .707 .577 .707 r
F P
0 g
s
.35123 .68981 m .35505 .72706 L .34257 .72152 L p .707 .577 .707 r
F P
0 g
s
.34257 .72152 m .33875 .68427 L .35123 .68981 L p .707 .577 .707 r
F P
0 g
s
.16523 .80989 m .16055 .79151 L .1678 .78443 L p .707 .577 .707 r
F P
0 g
s
.17803 .6055 m .1756 .66077 L .15924 .66792 L p .707 .577 .707 r
F P
0 g
s
.34284 .61531 m .34041 .67057 L .31938 .66287 L p .707 .577 .707 r
F P
0 g
s
.31938 .66287 m .32181 .60761 L .34284 .61531 L p .707 .577 .707 r
F P
0 g
s
.1678 .78443 m .17248 .80281 L .16523 .80989 L p .707 .577 .707 r
F P
0 g
s
.35571 .74055 m .36039 .75893 L .34853 .75683 L p .707 .577 .707 r
F P
0 g
s
.34853 .75683 m .34385 .73845 L .35571 .74055 L p .707 .577 .707 r
F P
0 g
s
.1756 .66077 m .17803 .6055 L .20207 .60049 L p .707 .577 .707 r
F P
0 g
s
.16211 .74275 m .15829 .7055 L .17464 .69762 L p .707 .577 .707 r
F P
0 g
s
.37659 .77465 m .35977 .27126 L .38287 .26062 L p .707 .577 .707 r
F P
0 g
s
.35977 .27126 m .37659 .77465 L .36658 .78622 L p .707 .577 .707 r
F P
0 g
s
.17464 .69762 m .17846 .73487 L .16211 .74275 L p .707 .577 .707 r
F P
0 g
s
.33875 .68427 m .34257 .72152 L .32167 .71801 L p .707 .577 .707 r
F P
0 g
s
.32167 .71801 m .31785 .68076 L .33875 .68427 L p .707 .577 .707 r
F P
0 g
s
.32181 .60761 m .31938 .66287 L .29195 .6571 L p .707 .577 .707 r
F P
0 g
s
.29195 .6571 m .29438 .60184 L .32181 .60761 L p .707 .577 .707 r
F P
0 g
s
.20207 .60049 m .19964 .65575 L .1756 .66077 L p .707 .577 .707 r
F P
0 g
s
.17248 .80281 m .1678 .78443 L .184 .77578 L p .707 .577 .707 r
F P
0 g
s
.19964 .65575 m .20207 .60049 L .23143 .59809 L p .707 .577 .707 r
F P
0 g
s
.184 .77578 m .18869 .79416 L .17248 .80281 L p .707 .577 .707 r
F P
0 g
s
.61563 .25733 m .63245 .76072 L .60274 .75296 L p .707 .577 .707 r
F P
0 g
s
.60274 .75296 m .58592 .24956 L .61563 .25733 L p .707 .577 .707 r
F P
0 g
s
.34385 .73845 m .34853 .75683 L .3284 .75767 L p .707 .577 .707 r
F P
0 g
s
.3284 .75767 m .32372 .73929 L .34385 .73845 L p .707 .577 .707 r
F P
0 g
s
.17846 .73487 m .17464 .69762 L .19861 .69046 L p .707 .577 .707 r
F P
0 g
s
.29438 .60184 m .29195 .6571 L .26081 .65382 L p .707 .577 .707 r
F P
0 g
s
.26081 .65382 m .26324 .59856 L .29438 .60184 L p .707 .577 .707 r
F P
0 g
s
.229 .65336 m .23143 .59809 L .26324 .59856 L p .707 .577 .707 r
F P
0 g
s
.23143 .59809 m .229 .65336 L .19964 .65575 L p .707 .577 .707 r
F P
0 g
s
.19861 .69046 m .20243 .72771 L .17846 .73487 L p .707 .577 .707 r
F P
0 g
s
.26324 .59856 m .26081 .65382 L .229 .65336 L p .707 .577 .707 r
F P
0 g
s
.31785 .68076 m .32167 .71801 L .29438 .71689 L p .707 .577 .707 r
F P
0 g
s
.29438 .71689 m .29056 .67964 L .31785 .68076 L p .707 .577 .707 r
F P
0 g
s
.72741 .66028 m .72985 .60502 L .69871 .60174 L p .707 .577 .707 r
F P
0 g
s
.72985 .60502 m .72741 .66028 L .75922 .66075 L p .707 .577 .707 r
F P
0 g
s
.75922 .66075 m .76166 .60548 L .72985 .60502 L p .707 .577 .707 r
F P
0 g
s
.38287 .26062 m .39969 .76401 L .37659 .77465 L p .707 .577 .707 r
F P
0 g
s
.39969 .76401 m .38287 .26062 L .41682 .25196 L p .707 .577 .707 r
F P
0 g
s
.76166 .60548 m .75922 .66075 L .78858 .65836 L p .707 .577 .707 r
F P
0 g
s
.78858 .65836 m .79102 .60309 L .76166 .60548 L p .707 .577 .707 r
F P
0 g
s
.18869 .79416 m .184 .77578 L .20758 .76641 L p .707 .577 .707 r
F P
0 g
s
.69627 .657 m .69871 .60174 L .67128 .59597 L p .707 .577 .707 r
F P
0 g
s
.69871 .60174 m .69627 .657 L .72741 .66028 L p .707 .577 .707 r
F P
0 g
s
.20243 .72771 m .19861 .69046 L .22787 .68474 L p .707 .577 .707 r
F P
0 g
s
.20758 .76641 m .21227 .7848 L .18869 .79416 L p .707 .577 .707 r
F P
0 g
s
.32372 .73929 m .3284 .75767 L .30197 .76137 L p .707 .577 .707 r
F P
0 g
s
.30197 .76137 m .29729 .74299 L .32372 .73929 L p .707 .577 .707 r
F P
0 g
s
.29056 .67964 m .29438 .71689 L .26338 .71826 L p .707 .577 .707 r
F P
0 g
s
.26338 .71826 m .25956 .68101 L .29056 .67964 L p .707 .577 .707 r
F P
0 g
s
.79102 .60309 m .78858 .65836 L .81262 .65334 L p .707 .577 .707 r
F P
0 g
s
.81262 .65334 m .81506 .59808 L .79102 .60309 L p .707 .577 .707 r
F P
0 g
s
.22787 .68474 m .23169 .72199 L .20243 .72771 L p .707 .577 .707 r
F P
0 g
s
.58592 .24956 m .60274 .75296 L .564 .74825 L p .707 .577 .707 r
F P
0 g
s
.564 .74825 m .54719 .24486 L .58592 .24956 L p .707 .577 .707 r
F P
0 g
s
.23169 .72199 m .22787 .68474 L .25956 .68101 L p .707 .577 .707 r
F P
0 g
s
.25956 .68101 m .26338 .71826 L .23169 .72199 L p .707 .577 .707 r
F P
0 g
s
.66884 .65123 m .67128 .59597 L .65025 .58827 L p .707 .577 .707 r
F P
0 g
s
.67128 .59597 m .66884 .65123 L .69627 .657 L p .707 .577 .707 r
F P
0 g
s
.72971 .71693 m .72589 .67968 L .69488 .68105 L p .707 .577 .707 r
F P
0 g
s
.72589 .67968 m .72971 .71693 L .76139 .7132 L p .707 .577 .707 r
F P
0 g
s
.76139 .7132 m .75757 .67595 L .72589 .67968 L p .707 .577 .707 r
F P
0 g
s
.75757 .67595 m .76139 .7132 L .79065 .70748 L p .707 .577 .707 r
F P
0 g
s
.79065 .70748 m .78683 .67023 L .75757 .67595 L p .707 .577 .707 r
F P
0 g
s
.21227 .7848 m .20758 .76641 L .23623 .75725 L p .707 .577 .707 r
F P
0 g
s
.23623 .75725 m .24092 .77563 L .21227 .7848 L p .707 .577 .707 r
F P
0 g
s
.29729 .74299 m .30197 .76137 L .27183 .76756 L p .707 .577 .707 r
F P
0 g
s
.27183 .76756 m .26714 .74917 L .29729 .74299 L p .707 .577 .707 r
F P
0 g
s
.43364 .75535 m .41682 .25196 L .45828 .24612 L p .707 .577 .707 r
F P
0 g
s
.41682 .25196 m .43364 .75535 L .39969 .76401 L p .707 .577 .707 r
F P
0 g
s
.6987 .7183 m .69488 .68105 L .66759 .67993 L p .707 .577 .707 r
F P
0 g
s
.69488 .68105 m .6987 .7183 L .72971 .71693 L p .707 .577 .707 r
F P
0 g
s
.73644 .75251 m .73176 .73412 L .70161 .74031 L p .707 .577 .707 r
F P
0 g
s
.73176 .73412 m .73644 .75251 L .76735 .74443 L p .707 .577 .707 r
F P
0 g
s
.76735 .74443 m .76267 .72605 L .73176 .73412 L p .707 .577 .707 r
F P
0 g
s
.24092 .77563 m .23623 .75725 L .26714 .74917 L p .707 .577 .707 r
F P
0 g
s
.78683 .67023 m .79065 .70748 L .81463 .70033 L p .707 .577 .707 r
F P
0 g
s
.81463 .70033 m .81081 .66308 L .78683 .67023 L p .707 .577 .707 r
F P
0 g
s
.81506 .59808 m .81262 .65334 L .82899 .64619 L p .707 .577 .707 r
F P
0 g
s
.82899 .64619 m .83142 .59093 L .81506 .59808 L p .707 .577 .707 r
F P
0 g
s
.76267 .72605 m .76735 .74443 L .796 .73526 L p .707 .577 .707 r
F P
0 g
s
.796 .73526 m .79131 .71688 L .76267 .72605 L p .707 .577 .707 r
F P
0 g
s
.26714 .74917 m .27183 .76756 L .24092 .77563 L p .707 .577 .707 r
F P
0 g
s
.65025 .58827 m .64782 .64353 L .66884 .65123 L p .707 .577 .707 r
F P
0 g
s
.70161 .74031 m .70629 .75869 L .73644 .75251 L p .707 .577 .707 r
F P
0 g
s
.66759 .67993 m .67141 .71718 L .6987 .7183 L p .707 .577 .707 r
F P
0 g
s
.54719 .24486 m .564 .74825 L .52002 .74706 L p .707 .577 .707 r
F P
0 g
s
.52002 .74706 m .5032 .24367 L .54719 .24486 L p .707 .577 .707 r
F P
0 g
s
.70629 .75869 m .70161 .74031 L .67518 .744 L p .707 .577 .707 r
F P
0 g
s
.64782 .64353 m .65025 .58827 L .63768 .5794 L p .707 .577 .707 r
F P
0 g
s
.4751 .74951 m .45828 .24612 L .5032 .24367 L p .707 .577 .707 r
F P
0 g
s
.45828 .24612 m .4751 .74951 L .43364 .75535 L p .707 .577 .707 r
F P
0 g
s
.67141 .71718 m .66759 .67993 L .64669 .67643 L p .707 .577 .707 r
F P
0 g
s
.67518 .744 m .67986 .76239 L .70629 .75869 L p .707 .577 .707 r
F P
0 g
s
.79131 .71688 m .796 .73526 L .81958 .7259 L p .707 .577 .707 r
F P
0 g
s
.81958 .7259 m .81489 .70752 L .79131 .71688 L p .707 .577 .707 r
F P
0 g
s
.5032 .24367 m .52002 .74706 L .4751 .74951 L p .707 .577 .707 r
F P
0 g
s
.64669 .67643 m .65051 .71368 L .67141 .71718 L p .707 .577 .707 r
F P
0 g
s
.81081 .66308 m .81463 .70033 L .83097 .69244 L p .707 .577 .707 r
F P
0 g
s
.83097 .69244 m .82715 .65519 L .81081 .66308 L p .707 .577 .707 r
F P
0 g
s
.63768 .5794 m .63525 .63466 L .64782 .64353 L p .707 .577 .707 r
F P
0 g
s
.67986 .76239 m .67518 .744 L .65505 .74484 L p .707 .577 .707 r
F P
0 g
s
.83142 .59093 m .82899 .64619 L .83607 .63761 L p .707 .577 .707 r
F P
0 g
s
.83607 .63761 m .83851 .58234 L .83142 .59093 L p .707 .577 .707 r
F P
0 g
s
.65505 .74484 m .65973 .76323 L .67986 .76239 L p .707 .577 .707 r
F P
0 g
s
.81489 .70752 m .81958 .7259 L .83578 .71725 L p .707 .577 .707 r
F P
0 g
s
.83578 .71725 m .8311 .69887 L .81489 .70752 L p .707 .577 .707 r
F P
0 g
s
.63525 .63466 m .63768 .5794 L .6348 .57022 L p .707 .577 .707 r
F P
0 g
s
.63422 .67089 m .63804 .70814 L .65051 .71368 L p .707 .577 .707 r
F P
0 g
s
.82715 .65519 m .83097 .69244 L .83808 .6846 L p .707 .577 .707 r
F P
0 g
s
.83808 .6846 m .83426 .64734 L .82715 .65519 L p .707 .577 .707 r
F P
0 g
s
.65973 .76323 m .65505 .74484 L .64319 .74275 L p .707 .577 .707 r
F P
0 g
s
.6348 .57022 m .63236 .62549 L .63525 .63466 L p .707 .577 .707 r
F P
0 g
s
.64319 .74275 m .64787 .76113 L .65973 .76323 L p .707 .577 .707 r
F P
0 g
s
.83851 .58234 m .83607 .63761 L .83319 .62843 L p .707 .577 .707 r
F P
0 g
s
.83319 .62843 m .83563 .57317 L .83851 .58234 L p .707 .577 .707 r
F P
0 g
s
.8311 .69887 m .83578 .71725 L .84303 .71017 L p .707 .577 .707 r
F P
0 g
s
.84303 .71017 m .83835 .69178 L .8311 .69887 L p .707 .577 .707 r
F P
0 g
s
.63804 .70814 m .63422 .67089 L .6314 .66385 L p .707 .577 .707 r
F P
0 g
s
.63236 .62549 m .6348 .57022 L .64188 .56164 L p .707 .577 .707 r
F P
0 g
s
.6314 .66385 m .63522 .7011 L .63804 .70814 L p .707 .577 .707 r
F P
0 g
s
.83426 .64734 m .83808 .6846 L .83526 .67756 L p .707 .577 .707 r
F P
0 g
s
.83526 .67756 m .83144 .64031 L .83426 .64734 L p .707 .577 .707 r
F P
0 g
s
.64787 .76113 m .64319 .74275 L .64076 .73792 L p .707 .577 .707 r
F P
0 g
s
.64076 .73792 m .64545 .75631 L .64787 .76113 L p .707 .577 .707 r
F P
0 g
s
.64188 .56164 m .63945 .6169 L .63236 .62549 L p .707 .577 .707 r
F P
0 g
s
.83563 .57317 m .83319 .62843 L .82062 .61956 L p .707 .577 .707 r
F P
0 g
s
.82062 .61956 m .82305 .5643 L .83563 .57317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83835 .69178 m .84303 .71017 L .84061 .70534 L p .707 .577 .707 r
F P
0 g
s
.84061 .70534 m .83592 .68696 L .83835 .69178 L p .707 .577 .707 r
F P
0 g
s
.63522 .7011 m .6314 .66385 L .63851 .656 L p .707 .577 .707 r
F P
0 g
s
.3844 .61925 m .38684 .56399 L .3557 .56071 L p .707 .577 .707 r
F P
0 g
s
.38684 .56399 m .3844 .61925 L .41621 .61972 L p .707 .577 .707 r
F P
0 g
s
.41621 .61972 m .41865 .56446 L .38684 .56399 L p .707 .577 .707 r
F P
0 g
s
.63945 .6169 m .64188 .56164 L .65825 .55449 L p .707 .577 .707 r
F P
0 g
s
.41865 .56446 m .41621 .61972 L .44557 .61733 L p .707 .577 .707 r
F P
0 g
s
.44557 .61733 m .44801 .56206 L .41865 .56446 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35326 .61598 m .3557 .56071 L .32827 .55494 L p .707 .577 .707 r
F P
0 g
s
.3557 .56071 m .35326 .61598 L .3844 .61925 L p .707 .577 .707 r
F P
0 g
s
.63851 .656 m .64233 .69325 L .63522 .7011 L p .707 .577 .707 r
F P
0 g
s
.83144 .64031 m .83526 .67756 L .82279 .67202 L p .707 .577 .707 r
F P
0 g
s
.82279 .67202 m .81897 .63476 L .83144 .64031 L p .707 .577 .707 r
F P
0 g
s
.44801 .56206 m .44557 .61733 L .46961 .61231 L p .707 .577 .707 r
F P
0 g
s
.46961 .61231 m .47205 .55705 L .44801 .56206 L p .707 .577 .707 r
F P
0 g
s
.64545 .75631 m .64076 .73792 L .64801 .73084 L p .707 .577 .707 r
F P
0 g
s
.65825 .55449 m .65581 .60976 L .63945 .6169 L p .707 .577 .707 r
F P
0 g
s
.64801 .73084 m .65269 .74922 L .64545 .75631 L p .707 .577 .707 r
F P
0 g
s
.82305 .5643 m .82062 .61956 L .79959 .61186 L p .707 .577 .707 r
F P
0 g
s
.79959 .61186 m .80203 .5566 L .82305 .5643 L p .707 .577 .707 r
F P
0 g
s
.32583 .6102 m .32827 .55494 L .30724 .54724 L p .707 .577 .707 r
F P
0 g
s
.32827 .55494 m .32583 .6102 L .35326 .61598 L p .707 .577 .707 r
F P
0 g
s
.3867 .67439 m .38288 .63714 L .35187 .63851 L p .707 .577 .707 r
F P
0 g
s
.38288 .63714 m .3867 .67439 L .41838 .67067 L p .707 .577 .707 r
F P
0 g
s
.41838 .67067 m .41456 .63341 L .38288 .63714 L p .707 .577 .707 r
F P
0 g
s
.83592 .68696 m .84061 .70534 L .82875 .70325 L p .707 .577 .707 r
F P
0 g
s
.82875 .70325 m .82406 .68486 L .83592 .68696 L p .707 .577 .707 r
F P
0 g
s
.41456 .63341 m .41838 .67067 L .44764 .66494 L p .707 .577 .707 r
F P
0 g
s
.44764 .66494 m .44382 .62769 L .41456 .63341 L p .707 .577 .707 r
F P
0 g
s
.65581 .60976 m .65825 .55449 L .68229 .54948 L p .707 .577 .707 r
F P
0 g
s
.35569 .67577 m .35187 .63851 L .32458 .63739 L p .707 .577 .707 r
F P
0 g
s
.35187 .63851 m .35569 .67577 L .3867 .67439 L p .707 .577 .707 r
F P
0 g
s
.64233 .69325 m .63851 .656 L .65485 .64811 L p .707 .577 .707 r
F P
0 g
s
.44382 .62769 m .44764 .66494 L .47162 .65779 L p .707 .577 .707 r
F P
0 g
s
.47162 .65779 m .4678 .62054 L .44382 .62769 L p .707 .577 .707 r
F P
0 g
s
.39343 .71405 m .38875 .69567 L .3586 .70186 L p .707 .577 .707 r
F P
0 g
s
.38875 .69567 m .39343 .71405 L .42434 .70598 L p .707 .577 .707 r
F P
0 g
s
.42434 .70598 m .41966 .6876 L .38875 .69567 L p .707 .577 .707 r
F P
0 g
s
.47205 .55705 m .46961 .61231 L .48598 .60516 L p .707 .577 .707 r
F P
0 g
s
.48598 .60516 m .48841 .5499 L .47205 .55705 L p .707 .577 .707 r
F P
0 g
s
.41966 .6876 m .42434 .70598 L .45299 .69681 L p .707 .577 .707 r
F P
0 g
s
.45299 .69681 m .4483 .67843 L .41966 .6876 L p .707 .577 .707 r
F P
0 g
s
.30724 .54724 m .30481 .60251 L .32583 .6102 L p .707 .577 .707 r
F P
0 g
s
.32458 .63739 m .3284 .67464 L .35569 .67577 L p .707 .577 .707 r
F P
0 g
s
.65485 .64811 m .65867 .68537 L .64233 .69325 L p .707 .577 .707 r
F P
0 g
s
.3586 .70186 m .36328 .72024 L .39343 .71405 L p .707 .577 .707 r
F P
0 g
s
.81897 .63476 m .82279 .67202 L .80189 .66851 L p .707 .577 .707 r
F P
0 g
s
.80189 .66851 m .79806 .63126 L .81897 .63476 L p .707 .577 .707 r
F P
0 g
s
.80203 .5566 m .79959 .61186 L .77217 .60609 L p .707 .577 .707 r
F P
0 g
s
.77217 .60609 m .7746 .55083 L .80203 .5566 L p .707 .577 .707 r
F P
0 g
s
.36328 .72024 m .3586 .70186 L .33217 .70555 L p .707 .577 .707 r
F P
0 g
s
.30481 .60251 m .30724 .54724 L .29467 .53837 L p .707 .577 .707 r
F P
0 g
s
.68229 .54948 m .67985 .60474 L .65581 .60976 L p .707 .577 .707 r
F P
0 g
s
.3284 .67464 m .32458 .63739 L .30368 .63389 L p .707 .577 .707 r
F P
0 g
s
.65269 .74922 m .64801 .73084 L .66422 .72219 L p .707 .577 .707 r
F P
0 g
s
.33217 .70555 m .33685 .72393 L .36328 .72024 L p .707 .577 .707 r
F P
0 g
s
.4483 .67843 m .45299 .69681 L .47657 .68745 L p .707 .577 .707 r
F P
0 g
s
.47657 .68745 m .47189 .66907 L .4483 .67843 L p .707 .577 .707 r
F P
0 g
s
.67985 .60474 m .68229 .54948 L .71165 .54708 L p .707 .577 .707 r
F P
0 g
s
.66422 .72219 m .6689 .74057 L .65269 .74922 L p .707 .577 .707 r
F P
0 g
s
.82406 .68486 m .82875 .70325 L .80862 .70409 L p .707 .577 .707 r
F P
0 g
s
.80862 .70409 m .80393 .68571 L .82406 .68486 L p .707 .577 .707 r
F P
0 g
s
.30368 .63389 m .3075 .67114 L .3284 .67464 L p .707 .577 .707 r
F P
0 g
s
.4678 .62054 m .47162 .65779 L .48796 .64991 L p .707 .577 .707 r
F P
0 g
s
.48796 .64991 m .48414 .61265 L .4678 .62054 L p .707 .577 .707 r
F P
0 g
s
.65867 .68537 m .65485 .64811 L .67882 .64096 L p .707 .577 .707 r
F P
0 g
s
.7746 .55083 m .77217 .60609 L .74102 .60281 L p .707 .577 .707 r
F P
0 g
s
.74102 .60281 m .74346 .54755 L .7746 .55083 L p .707 .577 .707 r
F P
0 g
s
.29467 .53837 m .29223 .59364 L .30481 .60251 L p .707 .577 .707 r
F P
0 g
s
.70921 .60235 m .71165 .54708 L .74346 .54755 L p .707 .577 .707 r
F P
0 g
s
.71165 .54708 m .70921 .60235 L .67985 .60474 L p .707 .577 .707 r
F P
0 g
s
.33685 .72393 m .33217 .70555 L .31204 .70639 L p .707 .577 .707 r
F P
0 g
s
.48841 .5499 m .48598 .60516 L .49306 .59658 L p .707 .577 .707 r
F P
0 g
s
.49306 .59658 m .4955 .54132 L .48841 .5499 L p .707 .577 .707 r
F P
0 g
s
.74346 .54755 m .74102 .60281 L .70921 .60235 L p .707 .577 .707 r
F P
0 g
s
.67882 .64096 m .68265 .67821 L .65867 .68537 L p .707 .577 .707 r
F P
0 g
s
.79806 .63126 m .80189 .66851 L .7746 .66739 L p .707 .577 .707 r
F P
0 g
s
.7746 .66739 m .77078 .63014 L .79806 .63126 L p .707 .577 .707 r
F P
0 g
s
.31204 .70639 m .31672 .72478 L .33685 .72393 L p .707 .577 .707 r
F P
0 g
s
.47189 .66907 m .47657 .68745 L .49277 .6788 L p .707 .577 .707 r
F P
0 g
s
.49277 .6788 m .48809 .66042 L .47189 .66907 L p .707 .577 .707 r
F P
0 g
s
.3075 .67114 m .30368 .63389 L .29121 .62835 L p .707 .577 .707 r
F P
0 g
s
.29223 .59364 m .29467 .53837 L .29179 .5292 L p .707 .577 .707 r
F P
0 g
s
.6689 .74057 m .66422 .72219 L .6878 .71283 L p .707 .577 .707 r
F P
0 g
s
.68265 .67821 m .67882 .64096 L .70809 .63524 L p .707 .577 .707 r
F P
0 g
s
.6878 .71283 m .69248 .73121 L .6689 .74057 L p .707 .577 .707 r
F P
0 g
s
.80393 .68571 m .80862 .70409 L .78219 .70778 L p .707 .577 .707 r
F P
0 g
s
.78219 .70778 m .7775 .6894 L .80393 .68571 L p .707 .577 .707 r
F P
0 g
s
.29121 .62835 m .29503 .6656 L .3075 .67114 L p .707 .577 .707 r
F P
0 g
s
.48414 .61265 m .48796 .64991 L .49507 .64206 L p .707 .577 .707 r
F P
0 g
s
.49507 .64206 m .49125 .60481 L .48414 .61265 L p .707 .577 .707 r
F P
0 g
s
.77078 .63014 m .7746 .66739 L .74359 .66876 L p .707 .577 .707 r
F P
0 g
s
.74359 .66876 m .73977 .63151 L .77078 .63014 L p .707 .577 .707 r
F P
0 g
s
.70809 .63524 m .71191 .67249 L .68265 .67821 L p .707 .577 .707 r
F P
0 g
s
.31672 .72478 m .31204 .70639 L .30018 .7043 L p .707 .577 .707 r
F P
0 g
s
.71191 .67249 m .70809 .63524 L .73977 .63151 L p .707 .577 .707 r
F P
0 g
s
.29179 .5292 m .28935 .58446 L .29223 .59364 L p .707 .577 .707 r
F P
0 g
s
.73977 .63151 m .74359 .66876 L .71191 .67249 L p .707 .577 .707 r
F P
0 g
s
.30018 .7043 m .30486 .72268 L .31672 .72478 L p .707 .577 .707 r
F P
0 g
s
.69248 .73121 m .6878 .71283 L .71645 .70366 L p .707 .577 .707 r
F P
0 g
s
.4955 .54132 m .49306 .59658 L .49018 .5874 L p .707 .577 .707 r
F P
0 g
s
.49018 .5874 m .49262 .53214 L .4955 .54132 L p .707 .577 .707 r
F P
0 g
s
.48809 .66042 m .49277 .6788 L .50002 .67172 L p .707 .577 .707 r
F P
0 g
s
.50002 .67172 m .49534 .65333 L .48809 .66042 L p .707 .577 .707 r
F P
0 g
s
.71645 .70366 m .72113 .72204 L .69248 .73121 L p .707 .577 .707 r
F P
0 g
s
.7775 .6894 m .78219 .70778 L .75204 .71397 L p .707 .577 .707 r
F P
0 g
s
.75204 .71397 m .74736 .69559 L .7775 .6894 L p .707 .577 .707 r
F P
0 g
s
.29503 .6656 m .29121 .62835 L .28839 .62131 L p .707 .577 .707 r
F P
0 g
s
.72113 .72204 m .71645 .70366 L .74736 .69559 L p .707 .577 .707 r
F P
0 g
s
.28935 .58446 m .29179 .5292 L .29887 .52061 L p .707 .577 .707 r
F P
0 g
s
.74736 .69559 m .75204 .71397 L .72113 .72204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28839 .62131 m .29221 .65856 L .29503 .6656 L p .707 .577 .707 r
F P
0 g
s
.49125 .60481 m .49507 .64206 L .49225 .63502 L p .707 .577 .707 r
F P
0 g
s
.49225 .63502 m .48843 .59777 L .49125 .60481 L p .707 .577 .707 r
F P
0 g
s
.30486 .72268 m .30018 .7043 L .29775 .69947 L p .707 .577 .707 r
F P
0 g
s
.29887 .52061 m .29644 .57588 L .28935 .58446 L p .707 .577 .707 r
F P
0 g
s
.29775 .69947 m .30244 .71786 L .30486 .72268 L p .707 .577 .707 r
F P
0 g
s
.49262 .53214 m .49018 .5874 L .47761 .57853 L p .707 .577 .707 r
F P
0 g
s
.47761 .57853 m .48004 .52327 L .49262 .53214 L p .707 .577 .707 r
F P
0 g
s
.49534 .65333 m .50002 .67172 L .4976 .66689 L p .707 .577 .707 r
F P
0 g
s
.4976 .66689 m .49291 .64851 L .49534 .65333 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29221 .65856 m .28839 .62131 L .2955 .61346 L p .707 .577 .707 r
F P
0 g
s
.29644 .57588 m .29887 .52061 L .31524 .51346 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2955 .61346 m .29932 .65071 L .29221 .65856 L p .707 .577 .707 r
F P
0 g
s
.48843 .59777 m .49225 .63502 L .47978 .62948 L p .707 .577 .707 r
F P
0 g
s
.47978 .62948 m .47596 .59223 L .48843 .59777 L p .707 .577 .707 r
F P
0 g
s
.30244 .71786 m .29775 .69947 L .305 .69239 L p .707 .577 .707 r
F P
0 g
s
.31524 .51346 m .3128 .56873 L .29644 .57588 L p .707 .577 .707 r
F P
0 g
s
.48004 .52327 m .47761 .57853 L .45658 .57084 L p .707 .577 .707 r
F P
0 g
s
.45658 .57084 m .45902 .51557 L .48004 .52327 L p .707 .577 .707 r
F P
0 g
s
.305 .69239 m .30968 .71077 L .30244 .71786 L p .707 .577 .707 r
F P
0 g
s
.49291 .64851 m .4976 .66689 L .48574 .6648 L p .707 .577 .707 r
F P
0 g
s
.48574 .6648 m .48105 .64641 L .49291 .64851 L p .707 .577 .707 r
F P
0 g
s
.3128 .56873 m .31524 .51346 L .33928 .50845 L p .707 .577 .707 r
F P
0 g
s
.29932 .65071 m .2955 .61346 L .31184 .60558 L p .707 .577 .707 r
F P
0 g
s
.31184 .60558 m .31566 .64283 L .29932 .65071 L p .707 .577 .707 r
F P
0 g
s
.47596 .59223 m .47978 .62948 L .45887 .62598 L p .707 .577 .707 r
F P
0 g
s
.45887 .62598 m .45505 .58872 L .47596 .59223 L p .707 .577 .707 r
F P
0 g
s
.45902 .51557 m .45658 .57084 L .42915 .56506 L p .707 .577 .707 r
F P
0 g
s
.42915 .56506 m .43159 .5098 L .45902 .51557 L p .707 .577 .707 r
F P
0 g
s
.33928 .50845 m .33684 .56371 L .3128 .56873 L p .707 .577 .707 r
F P
0 g
s
.30968 .71077 m .305 .69239 L .32121 .68374 L p .707 .577 .707 r
F P
0 g
s
.33684 .56371 m .33928 .50845 L .36864 .50606 L p .707 .577 .707 r
F P
0 g
s
.32121 .68374 m .32589 .70212 L .30968 .71077 L p .707 .577 .707 r
F P
0 g
s
.48105 .64641 m .48574 .6648 L .46561 .66564 L p .707 .577 .707 r
F P
0 g
s
.46561 .66564 m .46092 .64725 L .48105 .64641 L p .707 .577 .707 r
F P
0 g
s
.31566 .64283 m .31184 .60558 L .33581 .59842 L p .707 .577 .707 r
F P
0 g
s
.43159 .5098 m .42915 .56506 L .39801 .56179 L p .707 .577 .707 r
F P
0 g
s
.39801 .56179 m .40045 .50652 L .43159 .5098 L p .707 .577 .707 r
F P
0 g
s
.3662 .56132 m .36864 .50606 L .40045 .50652 L p .707 .577 .707 r
F P
0 g
s
.36864 .50606 m .3662 .56132 L .33684 .56371 L p .707 .577 .707 r
F P
0 g
s
.33581 .59842 m .33963 .63568 L .31566 .64283 L p .707 .577 .707 r
F P
0 g
s
.40045 .50652 m .39801 .56179 L .3662 .56132 L p .707 .577 .707 r
F P
0 g
s
.45505 .58872 m .45887 .62598 L .43158 .62485 L p .707 .577 .707 r
F P
0 g
s
.43158 .62485 m .42776 .5876 L .45505 .58872 L p .707 .577 .707 r
F P
0 g
s
.32589 .70212 m .32121 .68374 L .34479 .67438 L p .707 .577 .707 r
F P
0 g
s
.33963 .63568 m .33581 .59842 L .36508 .5927 L p .707 .577 .707 r
F P
0 g
s
.34479 .67438 m .34947 .69276 L .32589 .70212 L p .707 .577 .707 r
F P
0 g
s
.46092 .64725 m .46561 .66564 L .43918 .66933 L p .707 .577 .707 r
F P
0 g
s
.43918 .66933 m .43449 .65095 L .46092 .64725 L p .707 .577 .707 r
F P
0 g
s
.42776 .5876 m .43158 .62485 L .40058 .62623 L p .707 .577 .707 r
F P
0 g
s
.40058 .62623 m .39676 .58897 L .42776 .5876 L p .707 .577 .707 r
F P
0 g
s
.36508 .5927 m .3689 .62995 L .33963 .63568 L p .707 .577 .707 r
F P
0 g
s
.3689 .62995 m .36508 .5927 L .39676 .58897 L p .707 .577 .707 r
F P
0 g
s
.39676 .58897 m .40058 .62623 L .3689 .62995 L p .707 .577 .707 r
F P
0 g
s
.34947 .69276 m .34479 .67438 L .37344 .66521 L p .707 .577 .707 r
F P
0 g
s
.37344 .66521 m .37812 .68359 L .34947 .69276 L p .707 .577 .707 r
F P
0 g
s
.43449 .65095 m .43918 .66933 L .40903 .67552 L p .707 .577 .707 r
F P
0 g
s
.40903 .67552 m .40435 .65713 L .43449 .65095 L p .707 .577 .707 r
F P
0 g
s
.37812 .68359 m .37344 .66521 L .40435 .65713 L p .707 .577 .707 r
F P
0 g
s
.40435 .65713 m .40903 .67552 L .37812 .68359 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo5@00Ogoo001mOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol007Eoo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Eoo`00LWoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`00LGoo001^Ool40004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001^Ool006aoo`8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP<006aoo`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00JWoo001XOol20002
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006Ioo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo
001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol0
06=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`P00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Eoo`00Ggoo1P000eYF00<005YF
FUH00UYF2@000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00eYF0P00IGoo001KOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH600000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000>OolB0015Ool0059oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Moo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPH003moo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo1@000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>goo001BOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000hOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002
000eOol0059oo`03001JEP0000=JEP04001JEUYFFUH800000eYF001JEP02FUHB0006FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF1P0015YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Woo001BOol01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
1P0015YF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000031oo`00
DWoo00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002mo
o`00DWoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001B
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=J
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH30005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo001DOol00`00FUH00005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000hOolG0006Ool20005FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
;Woo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00D0
05YF001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00P00;goo
000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF1@0015YF00<005YFFUH00P00;goo000/Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000EJEP00001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEP00
00P000=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<002moo`00:goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF200000=JEP0000000`001EYF10000UYF00<005YFFUH015YF1@0000=JEP00
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF5`0000=JEP00FUH00eYF0`00;goo000[Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000eYF00<005YFFUH00eYF20000eYF00@005YFFUIJEPX000IJEP03001JEUYF00AJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0009JEP03001JEP0002moo`00:goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0001L0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF
001oo`0^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`001EYF1@001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00<7oo000[
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEPL0009JEP03001JEP00
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ80
00AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
00080003FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002moo`00:goo00<0
05YF00000eYF00@005YFFUIJEPP00003FUH005YF009JEQ<0009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool002]oo`03001JEP0000=JEP@00003FUH005YF00IJ
EP03001JEUYF00EJEPH000AJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo000[Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF1P0015YF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo000[Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`001eYF00<005YFFUH01UYF00<005YFFUH00UYF3@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00:goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0UYF1@000eYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01EYF1P0015YF0P0015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000Ioo`P000=JEP04001JEUYF
FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP0000X000EJEP03001JEUYF00MJEP03001JEUYF00@000IJ
EP@00003FUH005YF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000goo000000030005
Ool400000eYF001JEP05FUH50002FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00MJEP03001JEUYF00AJEPD000=JEP04001JEUYFFUH30005FUH00`00FUIJEP03FUH20004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH70008Ool:0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000^Ool002]oo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQX000=JEP03001JEUYF00IJEP03001JEUYF
00@000QJEP06001JEP00001JEP001eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP03001JEP0001H000=JEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<002ioo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEPT0
00IJEP<000=JEP03001JEUYF00EJEP04001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPX00003FUH007oo02eoo`00;Goo00<005YF00001EYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH00UYF0`000eYF1@000UYF10001UYF00<005YFFUH015YF0`002UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00AJEP04001JEP00000_Ool0
02ioo`8000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEUYF1`000UYF00<005YFFUH01UYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050005FUH0
0`00FUIJEP03FUH00`00FUIJEP02000^Ool002moo`80009JEP@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00=JEP<0009oo`05001JEUYF001J
EP060005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000^Ool0035o
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001J
EUYF009JEP03001JEP0000<00003FUH00000009oo`D0009JEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000_Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00
FUH000050006FUH00`00FUIJEP07FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003
FUH0000002eoo`00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000UYF00@005YFFUIJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEPD000]J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01eYF00@005YF
FUIJEPP0009JEP@002eoo`00:goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF100000=JEP00FUH025YF
00<005YFFUH015YF1P0017oo0P001EYF00<005YF0000;Goo000ZOol01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP04001J
EUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP050005Ool400000eYF001JEP04FUH2000^Ool0
02Yoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH900000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF0000000500000eYF001JEP07FUH00`00FUIJEP04FUH50007Ool30005FUH00`00FUIJ
EP03FUH00`00Oomoo`0]Ool002Yoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90006Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP060008Ool20000
0eYF001JEP06FUH00`00FUIJEP02000`Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP0009oo`<000Ioo`@00003FUH00000009JEP03001JEUYF00T00005Ool005YFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH400000goo000000030005
Ool30004FUH00`00FUIJEP04FUH3000bOol002]oo`04001JEUYF0003FUH00`00FUIJEP03FUH60009
Ool:0006FUH600000eYF001JEP03FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP040005Ool500000goo000000020007FUH00`00FUIJ
EP04FUH00`00Oomoo`0bOol002]oo`04001JEUYF0003FUH00`00FUH0000G0002FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH3000:Ool50002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000eOol002]oo`04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH0
07oo00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF009J
EP@000Qoo`@000MJEP03001JEUYF00IJEP04001JEP00000gOol002]oo`04001JEUYF0002FUH01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH0
15YF1`000goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0005FUH01000FUH0
00000eYF00<007ooOol00Woo100000=JEP00FUH025YF00<005YFFUH01EYF0`00>Goo000[Ool00`00
FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH7
0002FUH00`00FUH000020002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00EJEP800004FUH005YFFUH60006FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol002aoo`04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF
00<005YFFUH00eYF00@005YFFUH0009oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP080003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50010Ool002aoo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000AGoo000/Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEUYFFUH007oo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3000
35YF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50019Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00Ool0
0eYF00<005YFFUH00eYF00<005YFFUH01UYF20002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH010001UYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@0
04ioo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=00001GooFUIJEUYF00001EYF00<005YFFUH00eYF0`001UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUIJEP80
009JEP03001JEUYF00=JEP04001JEUYFFUH6001BOol002eoo`800003FUH005YF00AJEP03001JEUYF
00EJEP@00003FUH005YF00MJEP03001JEUYF00EJEPH000Aoo`8000AJEP04001JEP000003FUH00`00
FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH40004FUH200000eYF001JEP02FUH600000eYF0000001EOol002moo`@000=JEP04
001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool200000eYF001JEP03FUH01000
FUIJEP000eYF00<005YFFUH00eYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009JEP`0009JEP8005Eoo`00<goo
1`0000=JEP00FUH01eYF00<005YFFUH015YF1@002Woo0P000eYF00<005YFFUH00eYF0P0000EooeYF
FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000EJEP03001JEUYF009JEP@005Eoo`00=Woo0P00
0eYF00<005YFFUH01UYF00<005YFFUH0100037oo0`001UYF00@005YFFUIJEP80009oo`=JEP04001J
EP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP03FUH3001EOol003Aoo`8000EJEP03001J
EUYF00EJEPT000Moo`@00003FUH005YF00IJEP04001JEP000004Ool3FUH200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30006FUH600000eYF001oo`1DOol0039oo`<000MJEP03001JEUYF009JEP8000Ao
o`D0009oo`D000EJEP03001JEUYF00AJEP<000Ioo`9JEP05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH000070002FUH01000FUH00000EWoo000`Ool20002FUH00`00FUIJEP05FUH00`00FUH0
00020006Ool70002FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo00=JEP00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000_
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH30007Ool60005FUH00`00FUIJEP06FUH01000FUH00000
2goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
0P00EGoo000^Ool20005FUH00`00FUH000030006Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000=Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH01000
FUIJEP00EGoo000]Ool01000FUIJEP0015YF0P0017oo1P001UYF00<005YFFUH01eYF00<005YFFUH0
10004Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH00eYF
00@005YFFUH005Eoo`00;Goo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP@001Eoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP02FUH>001D
Ool002eoo`04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000JOol20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUH00000FUH01P0017oo0P0015YF00@005YF000005Ao
o`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008001moo`<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEPL000Moo`800003FUH005YF00AJEP03001JEP0005Aoo`00;Woo0`0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH00UYF1@0097oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF1@002Woo0P000eYF00<005YFFUH00eYF0P00
EGoo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH6000[Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00004000;Ool30006FUH0
1000FUIJEUYF0P00EWoo000_Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04000eOol50008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH700000goo000000030006Ool400000eYF
001JEP06FUH01000FUH00000F7oo000aOol:000nOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04
FUH<00000eYF00000005Ool500000goo000000030006FUH00`00FUIJEP04FUH2001JOol007mooaH0
0003FUH005YF00EJEP03001JEP00008000Moo`H0009JEP03001JEUYF00IJEP03001JEUYF009JEP80
05aoo`00T7oo0P0015YF00<005YFFUH00eYF0`0027oo1P001EYF00<005YFFUH01UYF00@005YF0000
05ioo`00Sgoo00<005YF00001EYF00<005YF00000P001goo100000=JEP00FUH025YF00<005YFFUH0
1EYF0`00H7oo002?Ool00`00FUH00005FUH20004Ool60006FUH00`00FUIJEP07FUH00`00FUIJEP04
001SOol008moo`04001JEUYF0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4001WOol0
08moo`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<006]o
o`00T7oo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006ioo`00
T7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P00LGoo002@Ool20002FUH0
0`00FUIJEP03FUH01000FUIJEUYF2000Mgoo002AOol200000eYF001JEP02FUH6001oOol009=oo`D0
08Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60198 .74661 m .59955 .69082 L .56841 .69031 L p .707 .577 .707 r
F P
0 g
s
.59955 .69082 m .60198 .74661 L .63379 .74458 L p .707 .577 .707 r
F P
0 g
s
.63379 .74458 m .63136 .6888 L .59955 .69082 L p .707 .577 .707 r
F P
0 g
s
.63136 .6888 m .63379 .74458 L .66315 .74021 L p .707 .577 .707 r
F P
0 g
s
.66315 .74021 m .66072 .68443 L .63136 .6888 L p .707 .577 .707 r
F P
0 g
s
.57084 .74609 m .56841 .69031 L .54098 .6873 L p .707 .577 .707 r
F P
0 g
s
.56841 .69031 m .57084 .74609 L .60198 .74661 L p .707 .577 .707 r
F P
0 g
s
.66072 .68443 m .66315 .74021 L .68719 .73393 L p .707 .577 .707 r
F P
0 g
s
.68719 .73393 m .68476 .67814 L .66072 .68443 L p .707 .577 .707 r
F P
0 g
s
.59942 .8105 m .60324 .77406 L .57223 .76893 L p .707 .577 .707 r
F P
0 g
s
.60324 .77406 m .59942 .8105 L .6311 .81264 L p .707 .577 .707 r
F P
0 g
s
.6311 .81264 m .63492 .77621 L .60324 .77406 L p .707 .577 .707 r
F P
0 g
s
.54098 .6873 m .54341 .74309 L .57084 .74609 L p .707 .577 .707 r
F P
0 g
s
.54341 .74309 m .54098 .6873 L .51995 .68209 L p .707 .577 .707 r
F P
0 g
s
.63492 .77621 m .6311 .81264 L .66036 .81158 L p .707 .577 .707 r
F P
0 g
s
.66036 .81158 m .66418 .77514 L .63492 .77621 L p .707 .577 .707 r
F P
0 g
s
.56841 .80536 m .57223 .76893 L .54494 .7613 L p .707 .577 .707 r
F P
0 g
s
.57223 .76893 m .56841 .80536 L .59942 .8105 L p .707 .577 .707 r
F P
0 g
s
.68476 .67814 m .68719 .73393 L .70356 .72634 L p .707 .577 .707 r
F P
0 g
s
.70356 .72634 m .70112 .67055 L .68476 .67814 L p .707 .577 .707 r
F P
0 g
s
.51995 .68209 m .52239 .73788 L .54341 .74309 L p .707 .577 .707 r
F P
0 g
s
.66418 .77514 m .66036 .81158 L .68434 .80741 L p .707 .577 .707 r
F P
0 g
s
.68434 .80741 m .68816 .77098 L .66418 .77514 L p .707 .577 .707 r
F P
0 g
s
.54494 .7613 m .54112 .79773 L .56841 .80536 L p .707 .577 .707 r
F P
0 g
s
.54112 .79773 m .54494 .7613 L .52404 .75193 L p .707 .577 .707 r
F P
0 g
s
.59097 .85797 m .59565 .8406 L .5655 .83083 L p .707 .577 .707 r
F P
0 g
s
.59565 .8406 m .59097 .85797 L .62188 .86429 L p .707 .577 .707 r
F P
0 g
s
.62188 .86429 m .62656 .84692 L .59565 .8406 L p .707 .577 .707 r
F P
0 g
s
.52239 .73788 m .51995 .68209 L .50738 .6752 L p .707 .577 .707 r
F P
0 g
s
.56082 .84821 m .5655 .83083 L .53907 .81857 L p .707 .577 .707 r
F P
0 g
s
.5655 .83083 m .56082 .84821 L .59097 .85797 L p .707 .577 .707 r
F P
0 g
s
.62656 .84692 m .62188 .86429 L .65053 .86655 L p .707 .577 .707 r
F P
0 g
s
.65053 .86655 m .65521 .84917 L .62656 .84692 L p .707 .577 .707 r
F P
0 g
s
.52404 .75193 m .52022 .78836 L .54112 .79773 L p .707 .577 .707 r
F P
0 g
s
.53907 .81857 m .53439 .83595 L .56082 .84821 L p .707 .577 .707 r
F P
0 g
s
.68816 .77098 m .68434 .80741 L .70068 .80056 L p .707 .577 .707 r
F P
0 g
s
.70068 .80056 m .7045 .76413 L .68816 .77098 L p .707 .577 .707 r
F P
0 g
s
.53439 .83595 m .53907 .81857 L .51894 .80502 L p .707 .577 .707 r
F P
0 g
s
.70112 .67055 m .70356 .72634 L .71064 .71819 L p .707 .577 .707 r
F P
0 g
s
.71064 .71819 m .70821 .66241 L .70112 .67055 L p .707 .577 .707 r
F P
0 g
s
.50738 .6752 m .50982 .73099 L .52239 .73788 L p .707 .577 .707 r
F P
0 g
s
.65521 .84917 m .65053 .86655 L .67411 .86451 L p .707 .577 .707 r
F P
0 g
s
.67411 .86451 m .67879 .84714 L .65521 .84917 L p .707 .577 .707 r
F P
0 g
s
.52022 .78836 m .52404 .75193 L .51157 .74173 L p .707 .577 .707 r
F P
0 g
s
.51894 .80502 m .51426 .8224 L .53439 .83595 L p .707 .577 .707 r
F P
0 g
s
.50982 .73099 m .50738 .6752 L .5045 .6673 L p .707 .577 .707 r
F P
0 g
s
.51157 .74173 m .50775 .77816 L .52022 .78836 L p .707 .577 .707 r
F P
0 g
s
.51426 .8224 m .51894 .80502 L .50709 .79151 L p .707 .577 .707 r
F P
0 g
s
.67879 .84714 m .67411 .86451 L .69031 .85839 L p .707 .577 .707 r
F P
0 g
s
.69031 .85839 m .695 .84101 L .67879 .84714 L p .707 .577 .707 r
F P
0 g
s
.7045 .76413 m .70068 .80056 L .70779 .79168 L p .707 .577 .707 r
F P
0 g
s
.70779 .79168 m .71161 .75525 L .7045 .76413 L p .707 .577 .707 r
F P
0 g
s
.50709 .79151 m .5024 .80888 L .51426 .8224 L p .707 .577 .707 r
F P
0 g
s
.5045 .6673 m .50693 .72308 L .50982 .73099 L p .707 .577 .707 r
F P
0 g
s
.70821 .66241 m .71064 .71819 L .70776 .71029 L p .707 .577 .707 r
F P
0 g
s
.70776 .71029 m .70533 .6545 L .70821 .66241 L p .707 .577 .707 r
F P
0 g
s
.50775 .77816 m .51157 .74173 L .50875 .7317 L p .707 .577 .707 r
F P
0 g
s
.47998 .82206 m .4968 .32228 L .45281 .3181 L p .707 .577 .707 r
F P
0 g
s
.50875 .7317 m .50493 .76813 L .50775 .77816 L p .707 .577 .707 r
F P
0 g
s
.50693 .72308 m .5045 .6673 L .51159 .65915 L p .707 .577 .707 r
F P
0 g
s
.5024 .80888 m .50709 .79151 L .50466 .77935 L p .707 .577 .707 r
F P
0 g
s
.50466 .77935 m .49998 .79672 L .5024 .80888 L p .707 .577 .707 r
F P
0 g
s
.51159 .65915 m .51402 .71494 L .50693 .72308 L p .707 .577 .707 r
F P
0 g
s
.50493 .76813 m .50875 .7317 L .51586 .72282 L p .707 .577 .707 r
F P
0 g
s
.51586 .72282 m .51204 .75925 L .50493 .76813 L p .707 .577 .707 r
F P
0 g
s
.51402 .71494 m .51159 .65915 L .52795 .65156 L p .707 .577 .707 r
F P
0 g
s
.49998 .79672 m .50466 .77935 L .51191 .76974 L p .707 .577 .707 r
F P
0 g
s
.51191 .76974 m .50722 .78711 L .49998 .79672 L p .707 .577 .707 r
F P
0 g
s
.52795 .65156 m .53039 .70735 L .51402 .71494 L p .707 .577 .707 r
F P
0 g
s
.51204 .75925 m .51586 .72282 L .5322 .71597 L p .707 .577 .707 r
F P
0 g
s
.5322 .71597 m .52838 .7524 L .51204 .75925 L p .707 .577 .707 r
F P
0 g
s
.50722 .78711 m .51191 .76974 L .52811 .76362 L p .707 .577 .707 r
F P
0 g
s
.52811 .76362 m .52343 .78099 L .50722 .78711 L p .707 .577 .707 r
F P
0 g
s
.4968 .32228 m .47998 .82206 L .5249 .8223 L p .707 .577 .707 r
F P
0 g
s
.53039 .70735 m .52795 .65156 L .55199 .64528 L p .707 .577 .707 r
F P
0 g
s
.52343 .78099 m .52811 .76362 L .55169 .76158 L p .707 .577 .707 r
F P
0 g
s
.55169 .76158 m .54701 .77896 L .52343 .78099 L p .707 .577 .707 r
F P
0 g
s
.5249 .8223 m .54172 .32252 L .4968 .32228 L p .707 .577 .707 r
F P
0 g
s
.55199 .64528 m .55442 .70106 L .53039 .70735 L p .707 .577 .707 r
F P
0 g
s
.52838 .7524 m .5322 .71597 L .55618 .7118 L p .707 .577 .707 r
F P
0 g
s
.55442 .70106 m .55199 .64528 L .58135 .64091 L p .707 .577 .707 r
F P
0 g
s
.55618 .7118 m .55236 .74824 L .52838 .7524 L p .707 .577 .707 r
F P
0 g
s
.58135 .64091 m .58378 .69669 L .55442 .70106 L p .707 .577 .707 r
F P
0 g
s
.55236 .74824 m .55618 .7118 L .58544 .71074 L p .707 .577 .707 r
F P
0 g
s
.58544 .71074 m .58162 .74717 L .55236 .74824 L p .707 .577 .707 r
F P
0 g
s
.54701 .77896 m .55169 .76158 L .58034 .76383 L p .707 .577 .707 r
F P
0 g
s
.58034 .76383 m .57566 .78121 L .54701 .77896 L p .707 .577 .707 r
F P
0 g
s
.54172 .32252 m .5249 .8223 L .56636 .8186 L p .707 .577 .707 r
F P
0 g
s
.56636 .8186 m .58318 .31882 L .54172 .32252 L p .707 .577 .707 r
F P
0 g
s
.695 .84101 m .69031 .85839 L .69756 .84878 L p .707 .577 .707 r
F P
0 g
s
.69756 .84878 m .70224 .8314 L .695 .84101 L p .707 .577 .707 r
F P
0 g
s
.43599 .81788 m .45281 .3181 L .41407 .31041 L p .707 .577 .707 r
F P
0 g
s
.45281 .3181 m .43599 .81788 L .47998 .82206 L p .707 .577 .707 r
F P
0 g
s
.71161 .75525 m .70779 .79168 L .70497 .78165 L p .707 .577 .707 r
F P
0 g
s
.70497 .78165 m .70879 .74522 L .71161 .75525 L p .707 .577 .707 r
F P
0 g
s
.70533 .6545 m .70776 .71029 L .69519 .70339 L p .707 .577 .707 r
F P
0 g
s
.69519 .70339 m .69276 .64761 L .70533 .6545 L p .707 .577 .707 r
F P
0 g
s
.58378 .69669 m .58135 .64091 L .61316 .63888 L p .707 .577 .707 r
F P
0 g
s
.61316 .63888 m .61559 .69467 L .58378 .69669 L p .707 .577 .707 r
F P
0 g
s
.58162 .74717 m .58544 .71074 L .61712 .71288 L p .707 .577 .707 r
F P
0 g
s
.61712 .71288 m .6133 .74932 L .58162 .74717 L p .707 .577 .707 r
F P
0 g
s
.57566 .78121 m .58034 .76383 L .61125 .77015 L p .707 .577 .707 r
F P
0 g
s
.61125 .77015 m .60657 .78753 L .57566 .78121 L p .707 .577 .707 r
F P
0 g
s
.58318 .31882 m .56636 .8186 L .60031 .81131 L p .707 .577 .707 r
F P
0 g
s
.60031 .81131 m .61713 .31153 L .58318 .31882 L p .707 .577 .707 r
F P
0 g
s
.39725 .81019 m .41407 .31041 L .38437 .29996 L p .707 .577 .707 r
F P
0 g
s
.41407 .31041 m .39725 .81019 L .43599 .81788 L p .707 .577 .707 r
F P
0 g
s
.25898 .714 m .25654 .65822 L .2254 .6577 L p .707 .577 .707 r
F P
0 g
s
.25654 .65822 m .25898 .714 L .29078 .71198 L p .707 .577 .707 r
F P
0 g
s
.29078 .71198 m .28835 .65619 L .25654 .65822 L p .707 .577 .707 r
F P
0 g
s
.28835 .65619 m .29078 .71198 L .32014 .70761 L p .707 .577 .707 r
F P
0 g
s
.32014 .70761 m .31771 .65182 L .28835 .65619 L p .707 .577 .707 r
F P
0 g
s
.70224 .8314 m .69756 .84878 L .69513 .83662 L p .707 .577 .707 r
F P
0 g
s
.69513 .83662 m .69982 .81925 L .70224 .8314 L p .707 .577 .707 r
F P
0 g
s
.22783 .71349 m .2254 .6577 L .19797 .6547 L p .707 .577 .707 r
F P
0 g
s
.2254 .6577 m .22783 .71349 L .25898 .714 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70879 .74522 m .70497 .78165 L .6925 .77145 L p .707 .577 .707 r
F P
0 g
s
.6925 .77145 m .69632 .73502 L .70879 .74522 L p .707 .577 .707 r
F P
0 g
s
.31771 .65182 m .32014 .70761 L .34418 .70132 L p .707 .577 .707 r
F P
0 g
s
.34418 .70132 m .34175 .64554 L .31771 .65182 L p .707 .577 .707 r
F P
0 g
s
.69276 .64761 m .69519 .70339 L .67416 .69819 L p .707 .577 .707 r
F P
0 g
s
.67416 .69819 m .67173 .6424 L .69276 .64761 L p .707 .577 .707 r
F P
0 g
s
.6443 .6394 m .64674 .69518 L .61559 .69467 L p .707 .577 .707 r
F P
0 g
s
.61559 .69467 m .61316 .63888 L .6443 .6394 L p .707 .577 .707 r
F P
0 g
s
.64813 .71802 m .64431 .75445 L .6133 .74932 L p .707 .577 .707 r
F P
0 g
s
.6133 .74932 m .61712 .71288 L .64813 .71802 L p .707 .577 .707 r
F P
0 g
s
.6414 .77992 m .63671 .7973 L .60657 .78753 L p .707 .577 .707 r
F P
0 g
s
.60657 .78753 m .61125 .77015 L .6414 .77992 L p .707 .577 .707 r
F P
0 g
s
.61713 .31153 m .60031 .81131 L .62341 .80114 L p .707 .577 .707 r
F P
0 g
s
.62341 .80114 m .64023 .30136 L .61713 .31153 L p .707 .577 .707 r
F P
0 g
s
.19797 .6547 m .20041 .71048 L .22783 .71349 L p .707 .577 .707 r
F P
0 g
s
.25641 .7794 m .26023 .74297 L .22922 .73784 L p .707 .577 .707 r
F P
0 g
s
.26023 .74297 m .25641 .7794 L .28809 .78155 L p .707 .577 .707 r
F P
0 g
s
.28809 .78155 m .29191 .74511 L .26023 .74297 L p .707 .577 .707 r
F P
0 g
s
.20041 .71048 m .19797 .6547 L .17694 .64949 L p .707 .577 .707 r
F P
0 g
s
.29191 .74511 m .28809 .78155 L .31735 .78048 L p .707 .577 .707 r
F P
0 g
s
.31735 .78048 m .32117 .74405 L .29191 .74511 L p .707 .577 .707 r
F P
0 g
s
.2254 .77427 m .22922 .73784 L .20193 .73021 L p .707 .577 .707 r
F P
0 g
s
.22922 .73784 m .2254 .77427 L .25641 .7794 L p .707 .577 .707 r
F P
0 g
s
.35811 .63795 m .36055 .69373 L .36764 .68559 L p .707 .577 .707 r
F P
0 g
s
.36764 .68559 m .3652 .6298 L .35811 .63795 L p .707 .577 .707 r
F P
0 g
s
.36478 .76059 m .3686 .72416 L .36149 .73303 L p .707 .577 .707 r
F P
0 g
s
.3652 .6298 m .36764 .68559 L .36475 .67768 L p .707 .577 .707 r
F P
0 g
s
.36149 .73303 m .35767 .76947 L .36478 .76059 L p .707 .577 .707 r
F P
0 g
s
.3686 .72416 m .36478 .76059 L .36196 .75056 L p .707 .577 .707 r
F P
0 g
s
.36196 .75056 m .36578 .71413 L .3686 .72416 L p .707 .577 .707 r
F P
0 g
s
.36755 .79974 m .38437 .29996 L .36661 .28776 L p .707 .577 .707 r
F P
0 g
s
.38437 .29996 m .36755 .79974 L .39725 .81019 L p .707 .577 .707 r
F P
0 g
s
.34175 .64554 m .34418 .70132 L .36055 .69373 L p .707 .577 .707 r
F P
0 g
s
.36055 .69373 m .35811 .63795 L .34175 .64554 L p .707 .577 .707 r
F P
0 g
s
.69982 .81925 m .69513 .83662 L .68328 .82311 L p .707 .577 .707 r
F P
0 g
s
.68328 .82311 m .68796 .80573 L .69982 .81925 L p .707 .577 .707 r
F P
0 g
s
.17694 .64949 m .17938 .70528 L .20041 .71048 L p .707 .577 .707 r
F P
0 g
s
.32117 .74405 m .31735 .78048 L .34133 .77632 L p .707 .577 .707 r
F P
0 g
s
.34133 .77632 m .34515 .73989 L .32117 .74405 L p .707 .577 .707 r
F P
0 g
s
.20193 .73021 m .19811 .76664 L .2254 .77427 L p .707 .577 .707 r
F P
0 g
s
.69632 .73502 m .6925 .77145 L .67159 .76208 L p .707 .577 .707 r
F P
0 g
s
.67159 .76208 m .67542 .72565 L .69632 .73502 L p .707 .577 .707 r
F P
0 g
s
.67173 .6424 m .67416 .69819 L .64674 .69518 L p .707 .577 .707 r
F P
0 g
s
.64674 .69518 m .6443 .6394 L .67173 .6424 L p .707 .577 .707 r
F P
0 g
s
.24796 .82279 m .25264 .80542 L .2225 .79565 L p .707 .577 .707 r
F P
0 g
s
.25264 .80542 m .24796 .82279 L .27887 .82911 L p .707 .577 .707 r
F P
0 g
s
.27887 .82911 m .28355 .81174 L .25264 .80542 L p .707 .577 .707 r
F P
0 g
s
.19811 .76664 m .20193 .73021 L .18103 .72084 L p .707 .577 .707 r
F P
0 g
s
.21781 .81303 m .2225 .79565 L .19606 .78339 L p .707 .577 .707 r
F P
0 g
s
.2225 .79565 m .21781 .81303 L .24796 .82279 L p .707 .577 .707 r
F P
0 g
s
.17938 .70528 m .17694 .64949 L .16437 .6426 L p .707 .577 .707 r
F P
0 g
s
.28355 .81174 m .27887 .82911 L .30752 .83137 L p .707 .577 .707 r
F P
0 g
s
.30752 .83137 m .3122 .81399 L .28355 .81174 L p .707 .577 .707 r
F P
0 g
s
.19606 .78339 m .19138 .80077 L .21781 .81303 L p .707 .577 .707 r
F P
0 g
s
.18103 .72084 m .17721 .75727 L .19811 .76664 L p .707 .577 .707 r
F P
0 g
s
.64023 .30136 m .62341 .80114 L .63342 .7891 L p .707 .577 .707 r
F P
0 g
s
.63342 .7891 m .65023 .28932 L .64023 .30136 L p .707 .577 .707 r
F P
0 g
s
.34515 .73989 m .34133 .77632 L .35767 .76947 L p .707 .577 .707 r
F P
0 g
s
.35767 .76947 m .36149 .73303 L .34515 .73989 L p .707 .577 .707 r
F P
0 g
s
.19138 .80077 m .19606 .78339 L .17593 .76984 L p .707 .577 .707 r
F P
0 g
s
.16437 .6426 m .16681 .69838 L .17938 .70528 L p .707 .577 .707 r
F P
0 g
s
.3122 .81399 m .30752 .83137 L .3311 .82933 L p .707 .577 .707 r
F P
0 g
s
.3311 .82933 m .33578 .81196 L .3122 .81399 L p .707 .577 .707 r
F P
0 g
s
.67542 .72565 m .67159 .76208 L .64431 .75445 L p .707 .577 .707 r
F P
0 g
s
.64431 .75445 m .64813 .71802 L .67542 .72565 L p .707 .577 .707 r
F P
0 g
s
.68796 .80573 m .68328 .82311 L .66315 .80956 L p .707 .577 .707 r
F P
0 g
s
.66315 .80956 m .66783 .79218 L .68796 .80573 L p .707 .577 .707 r
F P
0 g
s
.17721 .75727 m .18103 .72084 L .16856 .71064 L p .707 .577 .707 r
F P
0 g
s
.17593 .76984 m .17125 .78722 L .19138 .80077 L p .707 .577 .707 r
F P
0 g
s
.36232 .6219 m .36475 .67768 L .35218 .67079 L p .707 .577 .707 r
F P
0 g
s
.35218 .67079 m .34975 .61501 L .36232 .6219 L p .707 .577 .707 r
F P
0 g
s
.36578 .71413 m .36196 .75056 L .35413 .74415 L p .707 .577 .707 r
F P
0 g
s
.35413 .74415 m .34949 .74036 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.35433 .73257 m .36578 .71413 L .35413 .74415 L .707 .577 .707 r
F
.36661 .28776 m .36253 .27501 L p .36154 .31489 L F P
0 g
s
.34949 .74036 m .35331 .70393 L .3548 .70515 L p .707 .577 .707 r
F P
0 g
s
.3548 .70515 m .36578 .71413 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.34949 .74036 m .3548 .70515 L .35433 .73257 L .707 .577 .707 r
F
.34975 .61501 m .35218 .67079 L .33115 .66559 L p F P
0 g
s
.35213 .80144 m .34027 .78793 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35681 .78407 m .35403 .79437 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35403 .79437 m .35213 .80144 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .34495 .77055 L .35386 .7807 L p .707 .577 .707 r
F P
0 g
s
.35386 .7807 m .35681 .78407 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .35386 .7807 L .35391 .78474 L .707 .577 .707 r
F
.36191 .29349 m .35161 .59958 L p .36154 .31489 L F P
0 g
s
.35331 .70393 m .34949 .74036 L .32859 .73099 L p .707 .577 .707 r
F P
0 g
s
.32859 .73099 m .33241 .69455 L .35331 .70393 L p .707 .577 .707 r
F P
0 g
s
.35161 .59958 m .34571 .77479 L p .35165 .60243 L .707 .577 .707 r
F P
0 g
s
.36154 .31489 m .35161 .59958 L .35165 .60243 L .707 .577 .707 r
F
.34571 .77479 m .34979 .78754 L p .35256 .67613 L F P
0 g
s
.35256 .67613 m .36154 .31489 L .35165 .60243 L .707 .577 .707 r
F
.35256 .67613 m .35165 .60243 L .34571 .77479 L F
.36253 .27501 m .36191 .29349 L p .36154 .31489 L F P
0 g
s
.34979 .78754 m .35716 .56852 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.35716 .56852 m .36661 .28776 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.36475 .67768 m .36232 .6219 L .3652 .6298 L p .707 .577 .707 r
F P
0 g
s
.35213 .80144 m .35681 .78407 L .35923 .79622 L p .707 .577 .707 r
F P
0 g
s
.36661 .28776 m .34979 .78754 L .36755 .79974 L p .707 .577 .707 r
F P
0 g
s
.16681 .69838 m .16437 .6426 L .16149 .63469 L p .707 .577 .707 r
F P
0 g
s
.16856 .71064 m .16474 .74707 L .17721 .75727 L p .707 .577 .707 r
F P
0 g
s
.17125 .78722 m .17593 .76984 L .16408 .75633 L p .707 .577 .707 r
F P
0 g
s
.33578 .81196 m .3311 .82933 L .3473 .82321 L p .707 .577 .707 r
F P
0 g
s
.3473 .82321 m .35199 .80583 L .33578 .81196 L p .707 .577 .707 r
F P
0 g
s
.66783 .79218 m .66315 .80956 L .63671 .7973 L p .707 .577 .707 r
F P
0 g
s
.63671 .7973 m .6414 .77992 L .66783 .79218 L p .707 .577 .707 r
F P
0 g
s
.16408 .75633 m .15939 .7737 L .17125 .78722 L p .707 .577 .707 r
F P
0 g
s
.16149 .63469 m .16392 .69048 L .16681 .69838 L p .707 .577 .707 r
F P
0 g
s
.16474 .74707 m .16856 .71064 L .16574 .70061 L p .707 .577 .707 r
F P
0 g
s
.65023 .28932 m .63342 .7891 L .62934 .77635 L p .707 .577 .707 r
F P
0 g
s
.62934 .77635 m .64616 .27657 L .65023 .28932 L p .707 .577 .707 r
F P
0 g
s
.16574 .70061 m .16192 .73704 L .16474 .74707 L p .707 .577 .707 r
F P
0 g
s
.16392 .69048 m .16149 .63469 L .16858 .62655 L p .707 .577 .707 r
F P
0 g
s
.15939 .7737 m .16408 .75633 L .16165 .74417 L p .707 .577 .707 r
F P
0 g
s
.35199 .80583 m .3473 .82321 L .35455 .8136 L p .707 .577 .707 r
F P
0 g
s
.35455 .8136 m .35923 .79622 L .35199 .80583 L p .707 .577 .707 r
F P
0 g
s
.16165 .74417 m .15697 .76154 L .15939 .7737 L p .707 .577 .707 r
F P
0 g
s
.34571 .77479 m .36253 .27501 L .37254 .26297 L p .707 .577 .707 r
F P
0 g
s
.16858 .62655 m .17101 .68233 L .16392 .69048 L p .707 .577 .707 r
F P
0 g
s
.16192 .73704 m .16574 .70061 L .17285 .69173 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17285 .69173 m .16903 .72816 L .16192 .73704 L p .707 .577 .707 r
F P
0 g
s
.17101 .68233 m .16858 .62655 L .18494 .61896 L p .707 .577 .707 r
F P
0 g
s
.15697 .76154 m .16165 .74417 L .1689 .73456 L p .707 .577 .707 r
F P
0 g
s
.35923 .79622 m .35455 .8136 L .35213 .80144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64616 .27657 m .62934 .77635 L .61158 .76416 L p .707 .577 .707 r
F P
0 g
s
.61158 .76416 m .6284 .26438 L .64616 .27657 L p .707 .577 .707 r
F P
0 g
s
.1689 .73456 m .16421 .75193 L .15697 .76154 L p .707 .577 .707 r
F P
0 g
s
.33115 .66559 m .32872 .6098 L .34975 .61501 L p .707 .577 .707 r
F P
0 g
s
.18494 .61896 m .18738 .67475 L .17101 .68233 L p .707 .577 .707 r
F P
0 g
s
.16903 .72816 m .17285 .69173 L .18919 .68487 L p .707 .577 .707 r
F P
0 g
s
.35572 .76275 m .37254 .26297 L .39564 .2528 L p .707 .577 .707 r
F P
0 g
s
.37254 .26297 m .35572 .76275 L .34571 .77479 L p .707 .577 .707 r
F P
0 g
s
.18738 .67475 m .18494 .61896 L .20898 .61267 L p .707 .577 .707 r
F P
0 g
s
.18919 .68487 m .18537 .72131 L .16903 .72816 L p .707 .577 .707 r
F P
0 g
s
.16421 .75193 m .1689 .73456 L .1851 .72844 L p .707 .577 .707 r
F P
0 g
s
.1851 .72844 m .18042 .74581 L .16421 .75193 L p .707 .577 .707 r
F P
0 g
s
.32872 .6098 m .33115 .66559 L .30373 .66258 L p .707 .577 .707 r
F P
0 g
s
.30373 .66258 m .30129 .60679 L .32872 .6098 L p .707 .577 .707 r
F P
0 g
s
.20898 .61267 m .21141 .66846 L .18738 .67475 L p .707 .577 .707 r
F P
0 g
s
.18537 .72131 m .18919 .68487 L .21317 .68071 L p .707 .577 .707 r
F P
0 g
s
.6284 .26438 m .61158 .76416 L .58188 .7537 L p .707 .577 .707 r
F P
0 g
s
.58188 .7537 m .59869 .25392 L .6284 .26438 L p .707 .577 .707 r
F P
0 g
s
.21141 .66846 m .20898 .61267 L .23834 .6083 L p .707 .577 .707 r
F P
0 g
s
.30129 .60679 m .30373 .66258 L .27258 .66206 L p .707 .577 .707 r
F P
0 g
s
.27258 .66206 m .27015 .60628 L .30129 .60679 L p .707 .577 .707 r
F P
0 g
s
.21317 .68071 m .20935 .71714 L .18537 .72131 L p .707 .577 .707 r
F P
0 g
s
.18042 .74581 m .1851 .72844 L .20868 .7264 L p .707 .577 .707 r
F P
0 g
s
.39564 .2528 m .37882 .75258 L .35572 .76275 L p .707 .577 .707 r
F P
0 g
s
.37882 .75258 m .39564 .2528 L .42959 .24551 L p .707 .577 .707 r
F P
0 g
s
.24078 .66409 m .23834 .6083 L .27015 .60628 L p .707 .577 .707 r
F P
0 g
s
.23834 .6083 m .24078 .66409 L .21141 .66846 L p .707 .577 .707 r
F P
0 g
s
.34495 .77055 m .34027 .78793 L .32014 .77438 L p .707 .577 .707 r
F P
0 g
s
.32014 .77438 m .32482 .757 L .34495 .77055 L p .707 .577 .707 r
F P
0 g
s
.33241 .69455 m .32859 .73099 L .3013 .72336 L p .707 .577 .707 r
F P
0 g
s
.3013 .72336 m .30512 .68693 L .33241 .69455 L p .707 .577 .707 r
F P
0 g
s
.73919 .65457 m .73676 .59878 L .70561 .59827 L p .707 .577 .707 r
F P
0 g
s
.73676 .59878 m .73919 .65457 L .771 .65254 L p .707 .577 .707 r
F P
0 g
s
.771 .65254 m .76856 .59676 L .73676 .59878 L p .707 .577 .707 r
F P
0 g
s
.27015 .60628 m .27258 .66206 L .24078 .66409 L p .707 .577 .707 r
F P
0 g
s
.76856 .59676 m .771 .65254 L .80036 .64817 L p .707 .577 .707 r
F P
0 g
s
.80036 .64817 m .79792 .59239 L .76856 .59676 L p .707 .577 .707 r
F P
0 g
s
.20868 .7264 m .204 .74378 L .18042 .74581 L p .707 .577 .707 r
F P
0 g
s
.20935 .71714 m .21317 .68071 L .24243 .67965 L p .707 .577 .707 r
F P
0 g
s
.70805 .65405 m .70561 .59827 L .67819 .59526 L p .707 .577 .707 r
F P
0 g
s
.70561 .59827 m .70805 .65405 L .73919 .65457 L p .707 .577 .707 r
F P
0 g
s
.30512 .68693 m .3013 .72336 L .27029 .71822 L p .707 .577 .707 r
F P
0 g
s
.27029 .71822 m .27411 .68179 L .30512 .68693 L p .707 .577 .707 r
F P
0 g
s
.79792 .59239 m .80036 .64817 L .8244 .64189 L p .707 .577 .707 r
F P
0 g
s
.8244 .64189 m .82196 .5861 L .79792 .59239 L p .707 .577 .707 r
F P
0 g
s
.24243 .67965 m .23861 .71608 L .20935 .71714 L p .707 .577 .707 r
F P
0 g
s
.23861 .71608 m .24243 .67965 L .27411 .68179 L p .707 .577 .707 r
F P
0 g
s
.59869 .25392 m .58188 .7537 L .54314 .74601 L p .707 .577 .707 r
F P
0 g
s
.54314 .74601 m .55996 .24623 L .59869 .25392 L p .707 .577 .707 r
F P
0 g
s
.204 .74378 m .20868 .7264 L .23733 .72865 L p .707 .577 .707 r
F P
0 g
s
.32482 .757 m .32014 .77438 L .29371 .76212 L p .707 .577 .707 r
F P
0 g
s
.29371 .76212 m .29839 .74474 L .32482 .757 L p .707 .577 .707 r
F P
0 g
s
.27411 .68179 m .27029 .71822 L .23861 .71608 L p .707 .577 .707 r
F P
0 g
s
.73662 .71846 m .74044 .68203 L .70944 .67689 L p .707 .577 .707 r
F P
0 g
s
.74044 .68203 m .73662 .71846 L .7683 .7206 L p .707 .577 .707 r
F P
0 g
s
.7683 .7206 m .77212 .68417 L .74044 .68203 L p .707 .577 .707 r
F P
0 g
s
.67819 .59526 m .68062 .65105 L .70805 .65405 L p .707 .577 .707 r
F P
0 g
s
.68062 .65105 m .67819 .59526 L .65716 .59006 L p .707 .577 .707 r
F P
0 g
s
.23733 .72865 m .23265 .74603 L .204 .74378 L p .707 .577 .707 r
F P
0 g
s
.77212 .68417 m .7683 .7206 L .79757 .71954 L p .707 .577 .707 r
F P
0 g
s
.79757 .71954 m .80139 .68311 L .77212 .68417 L p .707 .577 .707 r
F P
0 g
s
.41277 .74529 m .42959 .24551 L .47105 .24181 L p .707 .577 .707 r
F P
0 g
s
.42959 .24551 m .41277 .74529 L .37882 .75258 L p .707 .577 .707 r
F P
0 g
s
.70562 .71332 m .70944 .67689 L .68215 .66926 L p .707 .577 .707 r
F P
0 g
s
.70944 .67689 m .70562 .71332 L .73662 .71846 L p .707 .577 .707 r
F P
0 g
s
.23265 .74603 m .23733 .72865 L .26824 .73497 L p .707 .577 .707 r
F P
0 g
s
.29839 .74474 m .29371 .76212 L .26356 .75235 L p .707 .577 .707 r
F P
0 g
s
.26356 .75235 m .26824 .73497 L .29839 .74474 L p .707 .577 .707 r
F P
0 g
s
.82196 .5861 m .8244 .64189 L .84076 .6343 L p .707 .577 .707 r
F P
0 g
s
.84076 .6343 m .83833 .57851 L .82196 .5861 L p .707 .577 .707 r
F P
0 g
s
.26824 .73497 m .26356 .75235 L .23265 .74603 L p .707 .577 .707 r
F P
0 g
s
.65716 .59006 m .65959 .64584 L .68062 .65105 L p .707 .577 .707 r
F P
0 g
s
.80139 .68311 m .79757 .71954 L .82154 .71537 L p .707 .577 .707 r
F P
0 g
s
.82154 .71537 m .82536 .67894 L .80139 .68311 L p .707 .577 .707 r
F P
0 g
s
.55996 .24623 m .54314 .74601 L .49915 .74184 L p .707 .577 .707 r
F P
0 g
s
.49915 .74184 m .51597 .24206 L .55996 .24623 L p .707 .577 .707 r
F P
0 g
s
.68215 .66926 m .67833 .7057 L .70562 .71332 L p .707 .577 .707 r
F P
0 g
s
.67833 .7057 m .68215 .66926 L .66124 .65989 L p .707 .577 .707 r
F P
0 g
s
.72817 .76594 m .73286 .74856 L .70271 .73879 L p .707 .577 .707 r
F P
0 g
s
.73286 .74856 m .72817 .76594 L .75908 .77225 L p .707 .577 .707 r
F P
0 g
s
.75908 .77225 m .76377 .75488 L .73286 .74856 L p .707 .577 .707 r
F P
0 g
s
.45423 .74159 m .46156 .52368 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.47105 .24181 m .45423 .74159 L .41277 .74529 L p .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .45838 .65201 L .43489 .65287 L p .707 .577 .707 r
F P
0 g
s
.43489 .65287 m .42911 .65307 L p .43356 .65926 L .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .43489 .65287 L .43356 .65926 L .707 .577 .707 r
F
.47105 .24181 m .51597 .24206 L p .51038 .28729 L F P
0 g
s
.46156 .52368 m .47105 .24181 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.65959 .64584 m .65716 .59006 L .64459 .58316 L p .707 .577 .707 r
F P
0 g
s
.69803 .75617 m .70271 .73879 L .67628 .72653 L p .707 .577 .707 r
F P
0 g
s
.70271 .73879 m .69803 .75617 L .72817 .76594 L p .707 .577 .707 r
F P
0 g
s
.51597 .24206 m .49915 .74184 L .45423 .74159 L p .707 .577 .707 r
F P
0 g
s
.76377 .75488 m .75908 .77225 L .78773 .77451 L p .707 .577 .707 r
F P
0 g
s
.78773 .77451 m .79241 .75713 L .76377 .75488 L p .707 .577 .707 r
F P
0 g
s
.66124 .65989 m .65742 .69632 L .67833 .7057 L p .707 .577 .707 r
F P
0 g
s
.67628 .72653 m .67159 .74391 L .69803 .75617 L p .707 .577 .707 r
F P
0 g
s
.82536 .67894 m .82154 .71537 L .83788 .70852 L p .707 .577 .707 r
F P
0 g
s
.83788 .70852 m .84171 .67209 L .82536 .67894 L p .707 .577 .707 r
F P
0 g
s
.67159 .74391 m .67628 .72653 L .65615 .71298 L p .707 .577 .707 r
F P
0 g
s
.83833 .57851 m .84076 .6343 L .84785 .62615 L p .707 .577 .707 r
F P
0 g
s
.84785 .62615 m .84542 .57037 L .83833 .57851 L p .707 .577 .707 r
F P
0 g
s
.64459 .58316 m .64702 .63895 L .65959 .64584 L p .707 .577 .707 r
F P
0 g
s
.79241 .75713 m .78773 .77451 L .81131 .77247 L p .707 .577 .707 r
F P
0 g
s
.81131 .77247 m .81599 .7551 L .79241 .75713 L p .707 .577 .707 r
F P
0 g
s
.65742 .69632 m .66124 .65989 L .64877 .64969 L p .707 .577 .707 r
F P
0 g
s
.65615 .71298 m .65146 .73036 L .67159 .74391 L p .707 .577 .707 r
F P
0 g
s
.64702 .63895 m .64459 .58316 L .6417 .57526 L p .707 .577 .707 r
F P
0 g
s
.64877 .64969 m .64495 .68612 L .65742 .69632 L p .707 .577 .707 r
F P
0 g
s
.65146 .73036 m .65615 .71298 L .64429 .69947 L p .707 .577 .707 r
F P
0 g
s
.81599 .7551 m .81131 .77247 L .82752 .76635 L p .707 .577 .707 r
F P
0 g
s
.82752 .76635 m .8322 .74898 L .81599 .7551 L p .707 .577 .707 r
F P
0 g
s
.84171 .67209 m .83788 .70852 L .84499 .69964 L p .707 .577 .707 r
F P
0 g
s
.84499 .69964 m .84881 .66321 L .84171 .67209 L p .707 .577 .707 r
F P
0 g
s
.64429 .69947 m .63961 .71684 L .65146 .73036 L p .707 .577 .707 r
F P
0 g
s
.6417 .57526 m .64414 .63104 L .64702 .63895 L p .707 .577 .707 r
F P
0 g
s
.84542 .57037 m .84785 .62615 L .84497 .61825 L p .707 .577 .707 r
F P
0 g
s
.84497 .61825 m .84253 .56246 L .84542 .57037 L p .707 .577 .707 r
F P
0 g
s
.64495 .68612 m .64877 .64969 L .64595 .63966 L p .707 .577 .707 r
F P
0 g
s
.64595 .63966 m .64213 .67609 L .64495 .68612 L p .707 .577 .707 r
F P
0 g
s
.64414 .63104 m .6417 .57526 L .64879 .56711 L p .707 .577 .707 r
F P
0 g
s
.63961 .71684 m .64429 .69947 L .64186 .68731 L p .707 .577 .707 r
F P
0 g
s
.8322 .74898 m .82752 .76635 L .83476 .75674 L p .707 .577 .707 r
F P
0 g
s
.83476 .75674 m .83945 .73937 L .8322 .74898 L p .707 .577 .707 r
F P
0 g
s
.64186 .68731 m .63718 .70469 L .63961 .71684 L p .707 .577 .707 r
F P
0 g
s
.84881 .66321 m .84499 .69964 L .84218 .68961 L p .707 .577 .707 r
F P
0 g
s
.84218 .68961 m .846 .65318 L .84881 .66321 L p .707 .577 .707 r
F P
0 g
s
.64879 .56711 m .65122 .6229 L .64414 .63104 L p .707 .577 .707 r
F P
0 g
s
.84253 .56246 m .84497 .61825 L .8324 .61136 L p .707 .577 .707 r
F P
0 g
s
.8324 .61136 m .82996 .55557 L .84253 .56246 L p .707 .577 .707 r
F P
0 g
s
.64213 .67609 m .64595 .63966 L .65306 .63078 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39618 .62197 m .39375 .56618 L .3626 .56566 L p .707 .577 .707 r
F P
0 g
s
.39375 .56618 m .39618 .62197 L .42799 .61994 L p .707 .577 .707 r
F P
0 g
s
.42799 .61994 m .42555 .56415 L .39375 .56618 L p .707 .577 .707 r
F P
0 g
s
.65306 .63078 m .64924 .66722 L .64213 .67609 L p .707 .577 .707 r
F P
0 g
s
.42555 .56415 m .42799 .61994 L .45735 .61557 L p .707 .577 .707 r
F P
0 g
s
.45735 .61557 m .45491 .55978 L .42555 .56415 L p .707 .577 .707 r
F P
0 g
s
.65122 .6229 m .64879 .56711 L .66516 .55953 L p .707 .577 .707 r
F P
0 g
s
.63718 .70469 m .64186 .68731 L .64911 .6777 L p .707 .577 .707 r
F P
0 g
s
.83945 .73937 m .83476 .75674 L .83234 .74458 L p .707 .577 .707 r
F P
0 g
s
.83234 .74458 m .83702 .72721 L .83945 .73937 L p .707 .577 .707 r
F P
0 g
s
.36504 .62145 m .3626 .56566 L .33518 .56266 L p .707 .577 .707 r
F P
0 g
s
.3626 .56566 m .36504 .62145 L .39618 .62197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64911 .6777 m .64443 .69508 L .63718 .70469 L p .707 .577 .707 r
F P
0 g
s
.846 .65318 m .84218 .68961 L .8297 .67941 L p .707 .577 .707 r
F P
0 g
s
.8297 .67941 m .83352 .64298 L .846 .65318 L p .707 .577 .707 r
F P
0 g
s
.45491 .55978 m .45735 .61557 L .48139 .60928 L p .707 .577 .707 r
F P
0 g
s
.48139 .60928 m .47895 .5535 L .45491 .55978 L p .707 .577 .707 r
F P
0 g
s
.82996 .55557 m .8324 .61136 L .81137 .60615 L p .707 .577 .707 r
F P
0 g
s
.81137 .60615 m .80893 .55037 L .82996 .55557 L p .707 .577 .707 r
F P
0 g
s
.66516 .55953 m .66759 .61531 L .65122 .6229 L p .707 .577 .707 r
F P
0 g
s
.64924 .66722 m .65306 .63078 L .6694 .62393 L p .707 .577 .707 r
F P
0 g
s
.33518 .56266 m .33761 .61844 L .36504 .62145 L p .707 .577 .707 r
F P
0 g
s
.39361 .68737 m .39743 .65093 L .36643 .6458 L p .707 .577 .707 r
F P
0 g
s
.39743 .65093 m .39361 .68737 L .42529 .68951 L p .707 .577 .707 r
F P
0 g
s
.42529 .68951 m .42911 .65307 L .39743 .65093 L p .707 .577 .707 r
F P
0 g
s
.33761 .61844 m .33518 .56266 L .31415 .55745 L p .707 .577 .707 r
F P
0 g
s
.42911 .65307 m .42529 .68951 L .45456 .68844 L p .707 .577 .707 r
F P
0 g
s
.36261 .68223 m .36643 .6458 L .33914 .63817 L p .707 .577 .707 r
F P
0 g
s
.36643 .6458 m .36261 .68223 L .39361 .68737 L p .707 .577 .707 r
F P
0 g
s
.66759 .61531 m .66516 .55953 L .6892 .55324 L p .707 .577 .707 r
F P
0 g
s
.6694 .62393 m .66558 .66036 L .64924 .66722 L p .707 .577 .707 r
F P
0 g
s
.64443 .69508 m .64911 .6777 L .66532 .67158 L p .707 .577 .707 r
F P
0 g
s
.47895 .5535 m .48139 .60928 L .49775 .6017 L p .707 .577 .707 r
F P
0 g
s
.49775 .6017 m .49532 .54591 L .47895 .5535 L p .707 .577 .707 r
F P
0 g
s
.83702 .72721 m .83234 .74458 L .82048 .73107 L p .707 .577 .707 r
F P
0 g
s
.82048 .73107 m .82516 .71369 L .83702 .72721 L p .707 .577 .707 r
F P
0 g
s
.31415 .55745 m .31658 .61324 L .33761 .61844 L p .707 .577 .707 r
F P
0 g
s
.45838 .65201 m .45456 .68844 L .47853 .68428 L p .707 .577 .707 r
F P
0 g
s
.47853 .68428 m .48235 .64785 L .45838 .65201 L p .707 .577 .707 r
F P
0 g
s
.33914 .63817 m .33532 .6746 L .36261 .68223 L p .707 .577 .707 r
F P
0 g
s
.83352 .64298 m .8297 .67941 L .8088 .67004 L p .707 .577 .707 r
F P
0 g
s
.8088 .67004 m .81262 .63361 L .83352 .64298 L p .707 .577 .707 r
F P
0 g
s
.66532 .67158 m .66063 .68895 L .64443 .69508 L p .707 .577 .707 r
F P
0 g
s
.80893 .55037 m .81137 .60615 L .78394 .60314 L p .707 .577 .707 r
F P
0 g
s
.78394 .60314 m .78151 .54736 L .80893 .55037 L p .707 .577 .707 r
F P
0 g
s
.38516 .73076 m .38985 .71338 L .3597 .70361 L p .707 .577 .707 r
F P
0 g
s
.38985 .71338 m .38516 .73076 L .41607 .73707 L p .707 .577 .707 r
F P
0 g
s
.41607 .73707 m .42076 .7197 L .38985 .71338 L p .707 .577 .707 r
F P
0 g
s
.33532 .6746 m .33914 .63817 L .31823 .6288 L p .707 .577 .707 r
F P
0 g
s
.6892 .55324 m .69163 .60903 L .66759 .61531 L p .707 .577 .707 r
F P
0 g
s
.66558 .66036 m .6694 .62393 L .69338 .61977 L p .707 .577 .707 r
F P
0 g
s
.35502 .72099 m .3597 .70361 L .33327 .69135 L p .707 .577 .707 r
F P
0 g
s
.3597 .70361 m .35502 .72099 L .38516 .73076 L p .707 .577 .707 r
F P
0 g
s
.31658 .61324 m .31415 .55745 L .30158 .55056 L p .707 .577 .707 r
F P
0 g
s
.42076 .7197 m .41607 .73707 L .44472 .73933 L p .707 .577 .707 r
F P
0 g
s
.44472 .73933 m .4494 .72195 L .42076 .7197 L p .707 .577 .707 r
F P
0 g
s
.69163 .60903 m .6892 .55324 L .71856 .54887 L p .707 .577 .707 r
F P
0 g
s
.33327 .69135 m .32858 .70873 L .35502 .72099 L p .707 .577 .707 r
F P
0 g
s
.31823 .6288 m .31441 .66523 L .33532 .6746 L p .707 .577 .707 r
F P
0 g
s
.78151 .54736 m .78394 .60314 L .7528 .60263 L p .707 .577 .707 r
F P
0 g
s
.7528 .60263 m .75036 .54684 L .78151 .54736 L p .707 .577 .707 r
F P
0 g
s
.69338 .61977 m .68956 .6562 L .66558 .66036 L p .707 .577 .707 r
F P
0 g
s
.48235 .64785 m .47853 .68428 L .49487 .67743 L p .707 .577 .707 r
F P
0 g
s
.49487 .67743 m .4987 .64099 L .48235 .64785 L p .707 .577 .707 r
F P
0 g
s
.32858 .70873 m .33327 .69135 L .31314 .6778 L p .707 .577 .707 r
F P
0 g
s
.66063 .68895 m .66532 .67158 L .6889 .66954 L p .707 .577 .707 r
F P
0 g
s
.49532 .54591 m .49775 .6017 L .50484 .59355 L p .707 .577 .707 r
F P
0 g
s
.50484 .59355 m .50241 .53776 L .49532 .54591 L p .707 .577 .707 r
F P
0 g
s
.72099 .60465 m .71856 .54887 L .75036 .54684 L p .707 .577 .707 r
F P
0 g
s
.71856 .54887 m .72099 .60465 L .69163 .60903 L p .707 .577 .707 r
F P
0 g
s
.30158 .55056 m .30401 .60635 L .31658 .61324 L p .707 .577 .707 r
F P
0 g
s
.4494 .72195 m .44472 .73933 L .4683 .73729 L p .707 .577 .707 r
F P
0 g
s
.4683 .73729 m .47298 .71992 L .4494 .72195 L p .707 .577 .707 r
F P
0 g
s
.81262 .63361 m .8088 .67004 L .78151 .66241 L p .707 .577 .707 r
F P
0 g
s
.78151 .66241 m .78533 .62598 L .81262 .63361 L p .707 .577 .707 r
F P
0 g
s
.82516 .71369 m .82048 .73107 L .80035 .71752 L p .707 .577 .707 r
F P
0 g
s
.80035 .71752 m .80503 .70014 L .82516 .71369 L p .707 .577 .707 r
F P
0 g
s
.75036 .54684 m .7528 .60263 L .72099 .60465 L p .707 .577 .707 r
F P
0 g
s
.31441 .66523 m .31823 .6288 L .30576 .6186 L p .707 .577 .707 r
F P
0 g
s
.68956 .6562 m .69338 .61977 L .72264 .6187 L p .707 .577 .707 r
F P
0 g
s
.31314 .6778 m .30845 .69518 L .32858 .70873 L p .707 .577 .707 r
F P
0 g
s
.6889 .66954 m .68422 .68692 L .66063 .68895 L p .707 .577 .707 r
F P
0 g
s
.30401 .60635 m .30158 .55056 L .29869 .54265 L p .707 .577 .707 r
F P
0 g
s
.30576 .6186 m .30194 .65503 L .31441 .66523 L p .707 .577 .707 r
F P
0 g
s
.78533 .62598 m .78151 .66241 L .75051 .65728 L p .707 .577 .707 r
F P
0 g
s
.75051 .65728 m .75433 .62084 L .78533 .62598 L p .707 .577 .707 r
F P
0 g
s
.72264 .6187 m .71882 .65514 L .68956 .6562 L p .707 .577 .707 r
F P
0 g
s
.71882 .65514 m .72264 .6187 L .75433 .62084 L p .707 .577 .707 r
F P
0 g
s
.30845 .69518 m .31314 .6778 L .30128 .66429 L p .707 .577 .707 r
F P
0 g
s
.68422 .68692 m .6889 .66954 L .71755 .6718 L p .707 .577 .707 r
F P
0 g
s
.75433 .62084 m .75051 .65728 L .71882 .65514 L p .707 .577 .707 r
F P
0 g
s
.47298 .71992 m .4683 .73729 L .48451 .73117 L p .707 .577 .707 r
F P
0 g
s
.48451 .73117 m .48919 .7138 L .47298 .71992 L p .707 .577 .707 r
F P
0 g
s
.80503 .70014 m .80035 .71752 L .77392 .70526 L p .707 .577 .707 r
F P
0 g
s
.77392 .70526 m .7786 .68788 L .80503 .70014 L p .707 .577 .707 r
F P
0 g
s
.4987 .64099 m .49487 .67743 L .50198 .66855 L p .707 .577 .707 r
F P
0 g
s
.50198 .66855 m .5058 .63212 L .4987 .64099 L p .707 .577 .707 r
F P
0 g
s
.30128 .66429 m .2966 .68166 L .30845 .69518 L p .707 .577 .707 r
F P
0 g
s
.71755 .6718 m .71286 .68917 L .68422 .68692 L p .707 .577 .707 r
F P
0 g
s
.29869 .54265 m .30113 .59844 L .30401 .60635 L p .707 .577 .707 r
F P
0 g
s
.50241 .53776 m .50484 .59355 L .50196 .58564 L p .707 .577 .707 r
F P
0 g
s
.50196 .58564 m .49952 .52986 L .50241 .53776 L p .707 .577 .707 r
F P
0 g
s
.30194 .65503 m .30576 .6186 L .30294 .60857 L p .707 .577 .707 r
F P
0 g
s
.71286 .68917 m .71755 .6718 L .74846 .67812 L p .707 .577 .707 r
F P
0 g
s
.7786 .68788 m .77392 .70526 L .74377 .69549 L p .707 .577 .707 r
F P
0 g
s
.74377 .69549 m .74846 .67812 L .7786 .68788 L p .707 .577 .707 r
F P
0 g
s
.74846 .67812 m .74377 .69549 L .71286 .68917 L p .707 .577 .707 r
F P
0 g
s
.30294 .60857 m .29912 .645 L .30194 .65503 L p .707 .577 .707 r
F P
0 g
s
.30113 .59844 m .29869 .54265 L .30578 .53451 L p .707 .577 .707 r
F P
0 g
s
.2966 .68166 m .30128 .66429 L .29885 .65213 L p .707 .577 .707 r
F P
0 g
s
.48919 .7138 m .48451 .73117 L .49175 .72156 L p .707 .577 .707 r
F P
0 g
s
.49175 .72156 m .49644 .70418 L .48919 .7138 L p .707 .577 .707 r
F P
0 g
s
.29885 .65213 m .29417 .66951 L .2966 .68166 L p .707 .577 .707 r
F P
0 g
s
.5058 .63212 m .50198 .66855 L .49917 .65852 L p .707 .577 .707 r
F P
0 g
s
.49917 .65852 m .50299 .62209 L .5058 .63212 L p .707 .577 .707 r
F P
0 g
s
.30578 .53451 m .30821 .59029 L .30113 .59844 L p .707 .577 .707 r
F P
0 g
s
.49952 .52986 m .50196 .58564 L .48939 .57875 L p .707 .577 .707 r
F P
0 g
s
.48939 .57875 m .48695 .52297 L .49952 .52986 L p .707 .577 .707 r
F P
0 g
s
.29912 .645 m .30294 .60857 L .31005 .59969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31005 .59969 m .30623 .63612 L .29912 .645 L p .707 .577 .707 r
F P
0 g
s
.30821 .59029 m .30578 .53451 L .32215 .52692 L p .707 .577 .707 r
F P
0 g
s
.29417 .66951 m .29885 .65213 L .3061 .64252 L p .707 .577 .707 r
F P
0 g
s
.49644 .70418 m .49175 .72156 L .48933 .7094 L p .707 .577 .707 r
F P
0 g
s
.48933 .7094 m .49401 .69203 L .49644 .70418 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3061 .64252 m .30142 .6599 L .29417 .66951 L p .707 .577 .707 r
F P
0 g
s
.50299 .62209 m .49917 .65852 L .48669 .64832 L p .707 .577 .707 r
F P
0 g
s
.48669 .64832 m .49051 .61189 L .50299 .62209 L p .707 .577 .707 r
F P
0 g
s
.48695 .52297 m .48939 .57875 L .46836 .57355 L p .707 .577 .707 r
F P
0 g
s
.46836 .57355 m .46592 .51776 L .48695 .52297 L p .707 .577 .707 r
F P
0 g
s
.32215 .52692 m .32458 .58271 L .30821 .59029 L p .707 .577 .707 r
F P
0 g
s
.30623 .63612 m .31005 .59969 L .32639 .59284 L p .707 .577 .707 r
F P
0 g
s
.32458 .58271 m .32215 .52692 L .34618 .52063 L p .707 .577 .707 r
F P
0 g
s
.32639 .59284 m .32257 .62927 L .30623 .63612 L p .707 .577 .707 r
F P
0 g
s
.30142 .6599 m .3061 .64252 L .32231 .6364 L p .707 .577 .707 r
F P
0 g
s
.49401 .69203 m .48933 .7094 L .47747 .69589 L p .707 .577 .707 r
F P
0 g
s
.47747 .69589 m .48215 .67851 L .49401 .69203 L p .707 .577 .707 r
F P
0 g
s
.32231 .6364 m .31762 .65377 L .30142 .6599 L p .707 .577 .707 r
F P
0 g
s
.49051 .61189 m .48669 .64832 L .46579 .63895 L p .707 .577 .707 r
F P
0 g
s
.46579 .63895 m .46961 .60251 L .49051 .61189 L p .707 .577 .707 r
F P
0 g
s
.46592 .51776 m .46836 .57355 L .44093 .57054 L p .707 .577 .707 r
F P
0 g
s
.44093 .57054 m .4385 .51475 L .46592 .51776 L p .707 .577 .707 r
F P
0 g
s
.34618 .52063 m .34862 .57642 L .32458 .58271 L p .707 .577 .707 r
F P
0 g
s
.32257 .62927 m .32639 .59284 L .35037 .58867 L p .707 .577 .707 r
F P
0 g
s
.34862 .57642 m .34618 .52063 L .37555 .51626 L p .707 .577 .707 r
F P
0 g
s
.4385 .51475 m .44093 .57054 L .40979 .57002 L p .707 .577 .707 r
F P
0 g
s
.40979 .57002 m .40735 .51424 L .4385 .51475 L p .707 .577 .707 r
F P
0 g
s
.35037 .58867 m .34655 .6251 L .32257 .62927 L p .707 .577 .707 r
F P
0 g
s
.31762 .65377 m .32231 .6364 L .34589 .63436 L p .707 .577 .707 r
F P
0 g
s
.37798 .57205 m .37555 .51626 L .40735 .51424 L p .707 .577 .707 r
F P
0 g
s
.37555 .51626 m .37798 .57205 L .34862 .57642 L p .707 .577 .707 r
F P
0 g
s
.48215 .67851 m .47747 .69589 L .45734 .68234 L p .707 .577 .707 r
F P
0 g
s
.45734 .68234 m .46202 .66496 L .48215 .67851 L p .707 .577 .707 r
F P
0 g
s
.46961 .60251 m .46579 .63895 L .4385 .63132 L p .707 .577 .707 r
F P
0 g
s
.4385 .63132 m .44232 .59489 L .46961 .60251 L p .707 .577 .707 r
F P
0 g
s
.40735 .51424 m .40979 .57002 L .37798 .57205 L p .707 .577 .707 r
F P
0 g
s
.34589 .63436 m .3412 .65174 L .31762 .65377 L p .707 .577 .707 r
F P
0 g
s
.34655 .6251 m .35037 .58867 L .37963 .58761 L p .707 .577 .707 r
F P
0 g
s
.44232 .59489 m .4385 .63132 L .4075 .62618 L p .707 .577 .707 r
F P
0 g
s
.4075 .62618 m .41132 .58975 L .44232 .59489 L p .707 .577 .707 r
F P
0 g
s
.37963 .58761 m .37581 .62404 L .34655 .6251 L p .707 .577 .707 r
F P
0 g
s
.37581 .62404 m .37963 .58761 L .41132 .58975 L p .707 .577 .707 r
F P
0 g
s
.3412 .65174 m .34589 .63436 L .37454 .63662 L p .707 .577 .707 r
F P
0 g
s
.46202 .66496 m .45734 .68234 L .43091 .67008 L p .707 .577 .707 r
F P
0 g
s
.43091 .67008 m .43559 .6527 L .46202 .66496 L p .707 .577 .707 r
F P
0 g
s
.41132 .58975 m .4075 .62618 L .37581 .62404 L p .707 .577 .707 r
F P
0 g
s
.37454 .63662 m .36985 .65399 L .3412 .65174 L p .707 .577 .707 r
F P
0 g
s
.36985 .65399 m .37454 .63662 L .40545 .64294 L p .707 .577 .707 r
F P
0 g
s
.43559 .6527 m .43091 .67008 L .40076 .66031 L p .707 .577 .707 r
F P
0 g
s
.40076 .66031 m .40545 .64294 L .43559 .6527 L p .707 .577 .707 r
F P
0 g
s
.40545 .64294 m .40076 .66031 L .36985 .65399 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0081ooaH008Mo
o`00N7oo20001EYF00<005YFFUH02UYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH01eYF1P00Ngoo001_Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006eoo`800003FUH005YF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00Jgoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF000006moo`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00J7oo0P001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00JWoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Moo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008006Ioo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00IWoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol006Ioo`800003FUH005YF00EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo
00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00=JEP0000001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`800003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH025YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01EYF001JEP00FUH05`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol00eYF0000000200000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IWoo001OOol60005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005]oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00FGoo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000JOolA000kOol005Aoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
015oo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH5000fOol005Aoo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003=oo`00E7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool005Aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP02
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00FUH00004FUH00`00FUIJEP03FUH60007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00EGoo00<005YF000015YF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF10000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Eo
o`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002aoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP00008000EJEQP00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000/Ool005Eoo`80009JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00@000MJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo001EOol20002FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02aoo`00EGoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool005Eoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF5`0015YF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00B7oo4@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0
000/Ool0041oo`P000AJEP03001JEUYF00IJEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000=J
EP03001oogoo02Yoo`00>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00FUIJ
EP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800004Ool005YF0003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00Ool0:goo000fOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000UYF00D005YFFUIJEP0000MJEP03001JEP00
00L000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000/Ool003=oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo001JEP030004FUH0
0`00FUH000070003FUH00`00FUIJEP02FUH700000eYF001JEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20000
1goo001JEP00FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH40004FUH01000FUIJEP00
1EYF00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP07
001JEUYFFUH005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH005YF1@001EYF00@005YFFUH000EJEP03001JEP0000@000=J
EP03001JEP0000D000IJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01P00FUH007oo001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00001JEP0=0005FUH00`00FUH000040003FUH00`00FUIJEP05FUH40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP05001JEUYFFUH0000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<000IJEP04001J
EUYFFUH=0003FUH00`00FUIJEP09FUH30005FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=J
EP000000;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60000
0eYF001JEP0:FUH00`00FUIJEP020003FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP07001JEP00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0P00<7oo000]
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000002eYF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YFFUIJ
EPD0009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUHB0007FUH0
0`00FUIJEP05FUH<0003FUH01000FUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000/Ool002eoo`03
001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
0004FUH000000005FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH0
0`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPD000=JEP05001JEUYFFUH0
000?Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00:goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF5`001EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH00`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF000005YF001JEP050005FUH01000FUIJEUYF
0P004Woo10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:goo000^Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUH000030002FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH01`00
FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00
001JEP02000015YF001JEUYF0P0015YF00@005YFFUIJEP8000Moo`<000aoo`@00003FUH005YF00AJ
EP03001JEUYF009JEP8002]oo`00;Woo00<005YF000015YF00@005YFFUIJEPH00003FUH005YF00IJ
EP03001JEUYF00IJEP07001JEP00FUH005YF00000UYF100000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF0P0025YF0`000UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH<00000eYF00000006Ool5000?Ool20005
FUH00`00FUIJEP02FUH2000[Ool002ioo`03001JEP0000AJEP@000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUH00003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020006FUH00`00FUIJEP030003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020002FUH200000eYF001JEP04FUH01000FUIJEUYF3P004Goo
0P000eYF00L005YFFUIJEP00FUH0000[Ool002ioo`03001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEUYF0004FUH20006FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20002FUH00`00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000BOol200000eYF001JEP02FUH00`00FUH0000[
Ool002ioo`03001JEP0000<000AJEQP00005FUH005YFFUH00004FUH20006FUH00`00FUH000020000
0eYF001JEP06FUH30006FUH00`00FUIJEP04FUH200000eYF001JEP05FUH30002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00002000>Ool50003FUH2000/Ool002io
o`03001JEP00009JEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00@00005FUH005YFFUH00002FUH20004FUH00`00FUH00002FUH50003FUH50005FUH00`00FUIJEP06
FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF3P000eYF00<005YF00000UYF0P00;7oo000^Ool20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH01000FUIJEUYF0`00
0UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF20000eYF00@005YFFUH0009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEQ8000IJ
EP03001JEUYF00IJEP8000EJEP03001JEUYF00AJEP03001JEUYF00@002aoo`00;Woo0P0000=JEP00
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF
00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF0000100000=JEP0000001`0015YF00@005YF
FUIJEP<000AJEP8000eJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH0000000EJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH30003
FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;7oo000^Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000050005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<002aoo`00;goo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF0000
00AJEP03001JEUYF00<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP02FUH00`00FUH0000/Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<0
05YFFUH00UYF00<005YFFUH00UYF0P00;Goo000_Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007FUH30003FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20008FUH30002FUH00`00FUIJEP02FUH2000]Ool002moo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YF
FUH00`000eYF0P00;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH20007FUH00`00FUIJEP050006FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH00eYF1000<7oo000_Ool20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH00`00FUIJEP05000;FUH00`00FUIJEP04
FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
000015YF0`001UYF00P005YFFUIJEP00FUH007oo10000UYF0`001UYF00<005YFFUH00eYF0P0000=J
EP00FUH01EYF0P00<Goo000^Ool00`00FUH00003FUH00`00FUH00003000>Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP04FUH60006FUH00`00FUH000040002FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF
00@005YFFUH000EJEP07001JEUYFFUH005YF00001Goo5@001UYF0P00<Goo000^Ool00`00FUH00003
FUH2000BOol30006Ool60006FUH00`00FUIJEP02FUH00`00FUH000020006FUH00`00FUIJEP07FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEP00FUH005YF000015YF0P000eYF00@005YFFUIJEP8000Moo`D0
00moo`8000=JEP04001JEUYF000`Ool002ioo`04001JEP00FUH20002FUH90008Ool5000;Ool40002
FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH0009JEP8000IJEP04001JEUYF0003FUH00`00Oomoo`06Ool5000A
Ool200000eYF001JEP02FUH00`00Oomoo`0]Ool002ioo`05001JEP00001JEP050003FUH01000FUIJ
EUYF3@003goo0`0015YF00@005YFFUH000EJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH20006FUH400000eYF0000000:Ool3000DOol20003FUH00`00Oomoo`0]Ool0
02ioo`D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPH0011oo`80009JEP04001J
EUYF0005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF000015YF00@005YFFUIJEP8002Eoo`04001JEUYF000_Ool002ioo`<000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000@Ool30002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH60004FUH01000FUIJEUYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP8002=oo`05001JEP00FUH0000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000aoo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEQL000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP03001JEUYF00=JEP8000QJEP<0025oo`800003FUH007oo02eoo`00;Goo00<005YF0000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP`000=JEP04001JEUYF0005
FUH00`00FUIJEP06FUH9000<FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
000NOol00`00FUH0000^Ool002eoo`80009JEPH00003FUH005YF00AJEPP000AJEP03001JEUYF00MJ
EP<000AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP04FUH5000HOol200000eYF001oo`0]Ool002eoo`@00003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000QJEP03001JEUYF0080009JEP03001JEUYF
00AJEP04001JEUYF0005FUH00`00FUH00004000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP04FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP020003FUH00`00FUIJEP07FUH00`00FUIJEP04000BOol200000eYF0000000_Ool0
02aoo`<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH0
0`00FUIJEP03FUH30006FUH01000FUIJEP0015YF0`0015YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF0000
10001EYF00<005YFFUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH01EYF1P0027oo10000eYF0P00
;goo000/Ool30003Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30000
0eYF001JEP06FUH20004FUH20002FUH00`00FUH000020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH00`00
FUH00004Ool400000eYF001JEP04FUH40007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00L0
05YFFUIJEP00FUH0000_Ool002aoo`04001JEP000004Ool300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH20008FUH30002FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03
FUH00`00FUH00008Ool20005FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80031oo`00;7oo00@005YF001JEP8000Eoo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF008000IJEP05001JEUYF001JEP0200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YF00002Woo0P000eYF00P005YFFUIJEP00FUH0
07oo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80035oo`00;7oo0P0015YF
00<007ooOol01Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP03001JEP0000aoo`80
0003FUH005YF009JEP03001JEP0000Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP00000cOol002eoo`03001JEUYF009JEP8000Qoo`<00003FUH005YF00IJEP<000IJEP03001JEUYF
00AJEP800003FUH005YF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo
00Yoo`D000=JEP03001JEP0000Yoo`H000AJEP04001JEUYFFUH5000eOol002eoo`05001JEUYFFUH0
0002FUH20009Ool50003FUH50005FUH00`00FUIJEP06FUH20006FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH200000eYF0000000:0003FUH00`00FUH00002FUH2000AOol8000jOol002ioo`04
001JEUYF0004FUH00`00Oomoo`0;Ool90004FUH00`00FUIJEP02FUH70004FUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01000Dgoo000_Ool2
0006FUH00`00Oomoo`0=Ool500000goo000000070007Ool20002FUH00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUH00000FUH00`000eYF00<005YFFUH015YF00@005YFFUIJEP<005=oo`00
<7oo00<005YFFUH015YF0`003Woo0`0057oo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<005=oo`00<Goo
0P0015YF00<005YFFUH00P0097oo00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF008000EJEP8000EJEP03001JEUYF009JEP03001JEP0005=oo`00<goo00@005YFFUH0
00EJEP8002=oo`03001JEUYF00<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000008FUH0
0`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0001COol003Aoo`<000MJEP<0025oo`<00004FUH0
00000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40008FUH30002FUH00`00FUIJEP02FUH2001DOol003Ioo`03001J
EUYF00IJEP04001JEP00000QOol01000FUH007oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH0
0P001UYF00H005YFFUH005YF0003FUH2001EOol003Moo`8000EJEP03001JEUYF009JEP<001ioo`80
00Aoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20003FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P0000=J
EP000000Egoo000iOol20003FUH00`00FUIJEP05FUH6000FOol40006Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001EYF
00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<007ooOol0Egoo000kOol30009FUH00`00FUIJEP02
FUH80008Ool60002FUH00`00Oomoo`08Ool40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP02FUH50006FUH2001HOol003eoo`<000IJ
EP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P003Woo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@0000=oo`0000000`0000=oo`000000
1`001Goo0P0015YF00<005YF0000Egoo0010Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00005Goo2@001UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
1Woo1@004Goo00@005YFFUH000=JEP03001oogoo05Aoo`00A7oo1@001UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP8001iooaX000eoo`D0019oo`<000=JEP03001oogoo05Aoo`00BGoo
10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo00<005YFFUH00UYF00@0
05YFFUIJEP8000aoo`<001Eoo`05001JEUYFFUH0001FOol004eoo`H000AJEP04001JEUYFFUH6000c
Ool20002FUH00`00FUIJEP03FUH2000SOol01@00FUH005YF0000EGoo001COol8000kOol20008FUH2
000ROol200000eYF001oo`1DOol009Moo`03001JEUYF00IJEP03001JEP000080021oo`03001JEP00
05Eoo`00V7oo0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000EGoo002JOol20003FUH00`00
FUIJEP06FUH6000EOol4001FOol009aoo`800003FUH005YF00MJEP03001JEUYF00=JEPP000Qoo`D0
009JEP8005Ioo`00WWoo0`001eYF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF009J
EP8005Ioo`00XGoo10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8005Moo`00YGoo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00
Egoo002ZOol40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001HOol00:ioo`H0
00AJEP04001JEUYFFUH6001KOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60557 .74479 m .60164 .68894 L .57054 .68928 L p .707 .577 .707 r
F P
0 g
s
.60164 .68894 m .60557 .74479 L .63734 .74199 L p .707 .577 .707 r
F P
0 g
s
.63734 .74199 m .6334 .68614 L .60164 .68894 L p .707 .577 .707 r
F P
0 g
s
.6334 .68614 m .63734 .74199 L .66666 .73701 L p .707 .577 .707 r
F P
0 g
s
.66666 .73701 m .66273 .68115 L .6334 .68614 L p .707 .577 .707 r
F P
0 g
s
.57448 .74514 m .57054 .68928 L .54317 .68713 L p .707 .577 .707 r
F P
0 g
s
.57054 .68928 m .57448 .74514 L .60557 .74479 L p .707 .577 .707 r
F P
0 g
s
.66273 .68115 m .66666 .73701 L .69068 .73033 L p .707 .577 .707 r
F P
0 g
s
.69068 .73033 m .68674 .67447 L .66273 .68115 L p .707 .577 .707 r
F P
0 g
s
.54317 .68713 m .5471 .74299 L .57448 .74514 L p .707 .577 .707 r
F P
0 g
s
.60129 .81075 m .60745 .77491 L .57672 .76781 L p .707 .577 .707 r
F P
0 g
s
.60745 .77491 m .60129 .81075 L .63273 .81467 L p .707 .577 .707 r
F P
0 g
s
.63273 .81467 m .63889 .77883 L .60745 .77491 L p .707 .577 .707 r
F P
0 g
s
.5471 .74299 m .54317 .68713 L .52218 .6827 L p .707 .577 .707 r
F P
0 g
s
.63889 .77883 m .63273 .81467 L .6618 .81501 L p .707 .577 .707 r
F P
0 g
s
.6618 .81501 m .66796 .77917 L .63889 .77883 L p .707 .577 .707 r
F P
0 g
s
.57056 .80365 m .57672 .76781 L .5497 .75822 L p .707 .577 .707 r
F P
0 g
s
.57672 .76781 m .57056 .80365 L .60129 .81075 L p .707 .577 .707 r
F P
0 g
s
.68674 .67447 m .69068 .73033 L .70704 .7226 L p .707 .577 .707 r
F P
0 g
s
.70704 .7226 m .7031 .66675 L .68674 .67447 L p .707 .577 .707 r
F P
0 g
s
.52218 .6827 m .52612 .73855 L .5471 .74299 L p .707 .577 .707 r
F P
0 g
s
.66796 .77917 m .6618 .81501 L .68565 .81175 L p .707 .577 .707 r
F P
0 g
s
.68565 .81175 m .69181 .77591 L .66796 .77917 L p .707 .577 .707 r
F P
0 g
s
.5497 .75822 m .54354 .79406 L .57056 .80365 L p .707 .577 .707 r
F P
0 g
s
.54354 .79406 m .5497 .75822 L .52904 .74708 L p .707 .577 .707 r
F P
0 g
s
.58685 .86119 m .59428 .84515 L .56577 .83087 L p .707 .577 .707 r
F P
0 g
s
.59428 .84515 m .58685 .86119 L .61629 .87158 L p .707 .577 .707 r
F P
0 g
s
.61629 .87158 m .62372 .85553 L .59428 .84515 L p .707 .577 .707 r
F P
0 g
s
.52612 .73855 m .52218 .6827 L .50965 .67642 L p .707 .577 .707 r
F P
0 g
s
.55834 .84692 m .56577 .83087 L .54098 .8141 L p .707 .577 .707 r
F P
0 g
s
.56577 .83087 m .55834 .84692 L .58685 .86119 L p .707 .577 .707 r
F P
0 g
s
.52904 .74708 m .52288 .78291 L .54354 .79406 L p .707 .577 .707 r
F P
0 g
s
.62372 .85553 m .61629 .87158 L .64376 .87706 L p .707 .577 .707 r
F P
0 g
s
.64376 .87706 m .6512 .86101 L .62372 .85553 L p .707 .577 .707 r
F P
0 g
s
.54098 .8141 m .53354 .83015 L .55834 .84692 L p .707 .577 .707 r
F P
0 g
s
.53354 .83015 m .54098 .8141 L .52232 .79648 L p .707 .577 .707 r
F P
0 g
s
.69181 .77591 m .68565 .81175 L .70195 .80521 L p .707 .577 .707 r
F P
0 g
s
.70195 .80521 m .70811 .76937 L .69181 .77591 L p .707 .577 .707 r
F P
0 g
s
.7031 .66675 m .70704 .7226 L .71413 .7146 L p .707 .577 .707 r
F P
0 g
s
.71413 .7146 m .7102 .65874 L .7031 .66675 L p .707 .577 .707 r
F P
0 g
s
.50965 .67642 m .51358 .73228 L .51827 .73462 L p .707 .577 .707 r
F P
0 g
s
.51358 .73228 m .50965 .67642 L .50679 .66891 L p .707 .577 .707 r
F P
0 g
s
.50679 .66891 m .51072 .72477 L .51175 .72747 L p .707 .577 .707 r
F P
0 g
s
.51175 .72747 m .51358 .73228 L p .51183 .71591 L .707 .577 .707 r
F P
0 g
s
.51183 .71591 m .50679 .66891 L .51175 .72747 L .707 .577 .707 r
F
.51677 .73547 m .51407 .72454 L p .51151 .75913 L F P
0 g
s
.52174 .72204 m .50965 .67642 L .51827 .73462 L .707 .577 .707 r
F
.51407 .72454 m .50791 .76037 L .5106 .77131 L p F P
0 g
s
.51407 .72454 m .52122 .71535 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.50791 .76037 m .51168 .73842 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.51168 .73842 m .51407 .72454 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.5106 .77131 m .51467 .74768 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51467 .74768 m .51677 .73547 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51827 .73462 m .52612 .73855 L p .52174 .72204 L .707 .577 .707 r
F P
0 g
s
.52288 .78291 m .52904 .74708 L .51677 .73547 L p .707 .577 .707 r
F P
0 g
s
.52232 .79648 m .51489 .81253 L .53354 .83015 L p .707 .577 .707 r
F P
0 g
s
.6512 .86101 m .64376 .87706 L .66659 .8771 L p .707 .577 .707 r
F P
0 g
s
.66659 .8771 m .67403 .86105 L .6512 .86101 L p .707 .577 .707 r
F P
0 g
s
.51677 .73547 m .5106 .77131 L .52288 .78291 L p .707 .577 .707 r
F P
0 g
s
.51489 .81253 m .52232 .79648 L .51163 .77974 L p .707 .577 .707 r
F P
0 g
s
.51163 .77974 m .5042 .79579 L .51489 .81253 L p .707 .577 .707 r
F P
0 g
s
.70811 .76937 m .70195 .80521 L .7091 .79602 L p .707 .577 .707 r
F P
0 g
s
.7091 .79602 m .71526 .76018 L .70811 .76937 L p .707 .577 .707 r
F P
0 g
s
.7102 .65874 m .71413 .7146 L .71127 .70708 L p .707 .577 .707 r
F P
0 g
s
.71127 .70708 m .70734 .65123 L .7102 .65874 L p .707 .577 .707 r
F P
0 g
s
.67403 .86105 m .66659 .8771 L .68254 .87169 L p .707 .577 .707 r
F P
0 g
s
.68254 .87169 m .68997 .85565 L .67403 .86105 L p .707 .577 .707 r
F P
0 g
s
.47349 .82204 m .5007 .32386 L .45675 .31877 L p .707 .577 .707 r
F P
0 g
s
.5042 .79579 m .51163 .77974 L .50996 .76551 L p .707 .577 .707 r
F P
0 g
s
.51072 .72477 m .50679 .66891 L .51388 .6609 L p .707 .577 .707 r
F P
0 g
s
.50996 .76551 m .50253 .78156 L .5042 .79579 L p .707 .577 .707 r
F P
0 g
s
.51388 .6609 m .51782 .71676 L .51072 .72477 L p .707 .577 .707 r
F P
0 g
s
.52122 .71535 m .51506 .75118 L .50791 .76037 L p .707 .577 .707 r
F P
0 g
s
.50253 .78156 m .50996 .76551 L .51746 .75519 L p .707 .577 .707 r
F P
0 g
s
.51746 .75519 m .51003 .77123 L .50253 .78156 L p .707 .577 .707 r
F P
0 g
s
.51506 .75118 m .52122 .71535 L .53752 .7088 L p .707 .577 .707 r
F P
0 g
s
.53752 .7088 m .53136 .74464 L .51506 .75118 L p .707 .577 .707 r
F P
0 g
s
.51003 .77123 m .51746 .75519 L .53341 .74978 L p .707 .577 .707 r
F P
0 g
s
.53341 .74978 m .52598 .76583 L .51003 .77123 L p .707 .577 .707 r
F P
0 g
s
.5007 .32386 m .47349 .82204 L .51838 .82311 L p .707 .577 .707 r
F P
0 g
s
.51782 .71676 m .51388 .6609 L .53024 .65318 L p .707 .577 .707 r
F P
0 g
s
.53024 .65318 m .53417 .70903 L .51782 .71676 L p .707 .577 .707 r
F P
0 g
s
.51838 .82311 m .54558 .32494 L .5007 .32386 L p .707 .577 .707 r
F P
0 g
s
.53417 .70903 m .53024 .65318 L .55425 .6465 L p .707 .577 .707 r
F P
0 g
s
.53136 .74464 m .53752 .7088 L .56137 .70554 L p .707 .577 .707 r
F P
0 g
s
.55425 .6465 m .55819 .70235 L .53417 .70903 L p .707 .577 .707 r
F P
0 g
s
.55819 .70235 m .55425 .6465 L .58358 .64151 L p .707 .577 .707 r
F P
0 g
s
.56137 .70554 m .55521 .74138 L .53136 .74464 L p .707 .577 .707 r
F P
0 g
s
.52598 .76583 m .53341 .74978 L .55624 .74982 L p .707 .577 .707 r
F P
0 g
s
.55624 .74982 m .54881 .76586 L .52598 .76583 L p .707 .577 .707 r
F P
0 g
s
.55521 .74138 m .56137 .70554 L .59044 .70589 L p .707 .577 .707 r
F P
0 g
s
.59044 .70589 m .58428 .74173 L .55521 .74138 L p .707 .577 .707 r
F P
0 g
s
.54881 .76586 m .55624 .74982 L .58372 .7553 L p .707 .577 .707 r
F P
0 g
s
.58372 .7553 m .57629 .77135 L .54881 .76586 L p .707 .577 .707 r
F P
0 g
s
.54558 .32494 m .51838 .82311 L .55981 .82007 L p .707 .577 .707 r
F P
0 g
s
.58358 .64151 m .58752 .69737 L .55819 .70235 L p .707 .577 .707 r
F P
0 g
s
.55981 .82007 m .58702 .32189 L .54558 .32494 L p .707 .577 .707 r
F P
0 g
s
.42955 .81695 m .45675 .31877 L .41806 .31016 L p .707 .577 .707 r
F P
0 g
s
.45675 .31877 m .42955 .81695 L .47349 .82204 L p .707 .577 .707 r
F P
0 g
s
.71526 .76018 m .7091 .79602 L .70641 .78509 L p .707 .577 .707 r
F P
0 g
s
.70641 .78509 m .71257 .74925 L .71526 .76018 L p .707 .577 .707 r
F P
0 g
s
.68997 .85565 m .68254 .87169 L .69005 .86137 L p .707 .577 .707 r
F P
0 g
s
.69005 .86137 m .69748 .84532 L .68997 .85565 L p .707 .577 .707 r
F P
0 g
s
.70734 .65123 m .71127 .70708 L .69874 .70081 L p .707 .577 .707 r
F P
0 g
s
.69874 .70081 m .6948 .64495 L .70734 .65123 L p .707 .577 .707 r
F P
0 g
s
.58752 .69737 m .58358 .64151 L .61534 .63871 L p .707 .577 .707 r
F P
0 g
s
.61534 .63871 m .61928 .69457 L .58752 .69737 L p .707 .577 .707 r
F P
0 g
s
.58428 .74173 m .59044 .70589 L .62188 .7098 L p .707 .577 .707 r
F P
0 g
s
.62188 .7098 m .61572 .74564 L .58428 .74173 L p .707 .577 .707 r
F P
0 g
s
.57629 .77135 m .58372 .7553 L .61315 .76568 L p .707 .577 .707 r
F P
0 g
s
.61315 .76568 m .60572 .78173 L .57629 .77135 L p .707 .577 .707 r
F P
0 g
s
.58702 .32189 m .55981 .82007 L .59374 .8132 L p .707 .577 .707 r
F P
0 g
s
.59374 .8132 m .62094 .31502 L .58702 .32189 L p .707 .577 .707 r
F P
0 g
s
.39085 .80834 m .41806 .31016 L .38839 .29888 L p .707 .577 .707 r
F P
0 g
s
.41806 .31016 m .39085 .80834 L .42955 .81695 L p .707 .577 .707 r
F P
0 g
s
.26256 .71479 m .25863 .65894 L .22754 .65928 L p .707 .577 .707 r
F P
0 g
s
.25863 .65894 m .26256 .71479 L .29433 .71199 L p .707 .577 .707 r
F P
0 g
s
.29433 .71199 m .29039 .65614 L .25863 .65894 L p .707 .577 .707 r
F P
0 g
s
.29039 .65614 m .29433 .71199 L .32365 .70701 L p .707 .577 .707 r
F P
0 g
s
.32365 .70701 m .31972 .65115 L .29039 .65614 L p .707 .577 .707 r
F P
0 g
s
.23147 .71513 m .22754 .65928 L .20016 .65713 L p .707 .577 .707 r
F P
0 g
s
.22754 .65928 m .23147 .71513 L .26256 .71479 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71257 .74925 m .70641 .78509 L .69413 .77348 L p .707 .577 .707 r
F P
0 g
s
.69413 .77348 m .70029 .73764 L .71257 .74925 L p .707 .577 .707 r
F P
0 g
s
.69748 .84532 m .69005 .86137 L .68837 .84714 L p .707 .577 .707 r
F P
0 g
s
.68837 .84714 m .69581 .83109 L .69748 .84532 L p .707 .577 .707 r
F P
0 g
s
.31972 .65115 m .32365 .70701 L .34767 .70033 L p .707 .577 .707 r
F P
0 g
s
.34767 .70033 m .34373 .64447 L .31972 .65115 L p .707 .577 .707 r
F P
0 g
s
.6948 .64495 m .69874 .70081 L .67775 .69637 L p .707 .577 .707 r
F P
0 g
s
.67775 .69637 m .67382 .64052 L .6948 .64495 L p .707 .577 .707 r
F P
0 g
s
.61928 .69457 m .61534 .63871 L .64644 .63837 L p .707 .577 .707 r
F P
0 g
s
.65261 .7169 m .64645 .75274 L .61572 .74564 L p .707 .577 .707 r
F P
0 g
s
.61572 .74564 m .62188 .7098 L .65261 .7169 L p .707 .577 .707 r
F P
0 g
s
.64167 .77996 m .63423 .79601 L .60572 .78173 L p .707 .577 .707 r
F P
0 g
s
.60572 .78173 m .61315 .76568 L .64167 .77996 L p .707 .577 .707 r
F P
0 g
s
.62094 .31502 m .59374 .8132 L .61684 .80318 L p .707 .577 .707 r
F P
0 g
s
.64644 .63837 m .65037 .69423 L .61928 .69457 L p .707 .577 .707 r
F P
0 g
s
.61684 .80318 m .64404 .305 L .62094 .31502 L p .707 .577 .707 r
F P
0 g
s
.20016 .65713 m .20409 .71298 L .23147 .71513 L p .707 .577 .707 r
F P
0 g
s
.25828 .7832 m .26444 .74736 L .23371 .74026 L p .707 .577 .707 r
F P
0 g
s
.26444 .74736 m .25828 .7832 L .28972 .78711 L p .707 .577 .707 r
F P
0 g
s
.28972 .78711 m .29588 .75127 L .26444 .74736 L p .707 .577 .707 r
F P
0 g
s
.20409 .71298 m .20016 .65713 L .17917 .6527 L p .707 .577 .707 r
F P
0 g
s
.29588 .75127 m .28972 .78711 L .31879 .78746 L p .707 .577 .707 r
F P
0 g
s
.31879 .78746 m .32495 .75162 L .29588 .75127 L p .707 .577 .707 r
F P
0 g
s
.22755 .7761 m .23371 .74026 L .20669 .73066 L p .707 .577 .707 r
F P
0 g
s
.23371 .74026 m .22755 .7761 L .25828 .7832 L p .707 .577 .707 r
F P
0 g
s
.34373 .64447 m .34767 .70033 L .36403 .6926 L p .707 .577 .707 r
F P
0 g
s
.36403 .6926 m .36009 .63675 L .34373 .64447 L p .707 .577 .707 r
F P
0 g
s
.36009 .63675 m .36403 .6926 L .37112 .68459 L p .707 .577 .707 r
F P
0 g
s
.37112 .68459 m .36719 .62874 L .36009 .63675 L p .707 .577 .707 r
F P
0 g
s
.35894 .77765 m .3651 .74181 L .3488 .74836 L p .707 .577 .707 r
F P
0 g
s
.3651 .74181 m .35894 .77765 L .36609 .76846 L p .707 .577 .707 r
F P
0 g
s
.36719 .62874 m .37112 .68459 L .36826 .67708 L p .707 .577 .707 r
F P
0 g
s
.36826 .67708 m .36433 .62123 L .36719 .62874 L p .707 .577 .707 r
F P
0 g
s
.36433 .62123 m .36826 .67708 L .3614 .67365 L p .707 .577 .707 r
F P
0 g
s
.3614 .67365 m .35573 .6708 L p .35863 .65407 L .707 .577 .707 r
F P
0 g
s
.35863 .65407 m .36433 .62123 L .3614 .67365 L .707 .577 .707 r
F
.38839 .29888 m .3661 .70694 L p .39085 .80834 L F P
0 g
s
.36609 .76846 m .37225 .73263 L .3651 .74181 L p .707 .577 .707 r
F P
0 g
s
.37225 .73263 m .36609 .76846 L .3634 .75753 L p .707 .577 .707 r
F P
0 g
s
.3634 .75753 m .36956 .72169 L .37225 .73263 L p .707 .577 .707 r
F P
0 g
s
.36956 .72169 m .3634 .75753 L .35638 .7509 L p .707 .577 .707 r
F P
0 g
s
.35638 .7509 m .35112 .74592 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.36106 .73286 m .36956 .72169 L .35638 .7509 L .707 .577 .707 r
F
.35112 .74592 m .35728 .71009 L .36506 .71744 L p F P
0 g
s
.36506 .71744 m .36956 .72169 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.35112 .74592 m .36506 .71744 L .36106 .73286 L .707 .577 .707 r
F
.37985 .80415 m .39085 .80834 L p .36692 .71028 L F P
0 g
s
.36692 .71028 m .3661 .70694 L .3667 .71113 L .707 .577 .707 r
F
.36692 .71028 m .3667 .71113 L .37985 .80415 L F
.36118 .79705 m .37985 .80415 L p .3667 .71113 L F P
0 g
s
.3661 .70694 m .36566 .71515 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36566 .71515 m .36118 .79705 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36118 .79705 m .38839 .29888 L .37066 .28602 L p .707 .577 .707 r
F P
0 g
s
.17917 .6527 m .18311 .70855 L .20409 .71298 L p .707 .577 .707 r
F P
0 g
s
.70029 .73764 m .69413 .77348 L .67347 .76233 L p .707 .577 .707 r
F P
0 g
s
.67347 .76233 m .67963 .7265 L .70029 .73764 L p .707 .577 .707 r
F P
0 g
s
.67382 .64052 m .67775 .69637 L .65037 .69423 L p .707 .577 .707 r
F P
0 g
s
.65037 .69423 m .64644 .63837 L .67382 .64052 L p .707 .577 .707 r
F P
0 g
s
.32495 .75162 m .31879 .78746 L .34264 .7842 L p .707 .577 .707 r
F P
0 g
s
.34264 .7842 m .3488 .74836 L .32495 .75162 L p .707 .577 .707 r
F P
0 g
s
.20669 .73066 m .20053 .7665 L .22755 .7761 L p .707 .577 .707 r
F P
0 g
s
.20053 .7665 m .20669 .73066 L .18603 .71952 L p .707 .577 .707 r
F P
0 g
s
.69581 .83109 m .68837 .84714 L .67768 .8304 L p .707 .577 .707 r
F P
0 g
s
.67768 .8304 m .68512 .81435 L .69581 .83109 L p .707 .577 .707 r
F P
0 g
s
.24384 .82703 m .25128 .81098 L .22276 .7967 L p .707 .577 .707 r
F P
0 g
s
.25128 .81098 m .24384 .82703 L .27328 .83741 L p .707 .577 .707 r
F P
0 g
s
.27328 .83741 m .28071 .82136 L .25128 .81098 L p .707 .577 .707 r
F P
0 g
s
.18311 .70855 m .17917 .6527 L .16664 .64642 L p .707 .577 .707 r
F P
0 g
s
.21533 .81275 m .22276 .7967 L .19797 .77993 L p .707 .577 .707 r
F P
0 g
s
.22276 .7967 m .21533 .81275 L .24384 .82703 L p .707 .577 .707 r
F P
0 g
s
.28071 .82136 m .27328 .83741 L .30075 .84289 L p .707 .577 .707 r
F P
0 g
s
.30075 .84289 m .30819 .82685 L .28071 .82136 L p .707 .577 .707 r
F P
0 g
s
.18603 .71952 m .17987 .75536 L .20053 .7665 L p .707 .577 .707 r
F P
0 g
s
.19797 .77993 m .19053 .79598 L .21533 .81275 L p .707 .577 .707 r
F P
0 g
s
.64404 .305 m .61684 .80318 L .62685 .79099 L p .707 .577 .707 r
F P
0 g
s
.62685 .79099 m .65405 .29281 L .64404 .305 L p .707 .577 .707 r
F P
0 g
s
.19053 .79598 m .19797 .77993 L .17931 .76231 L p .707 .577 .707 r
F P
0 g
s
.3488 .74836 m .34264 .7842 L .35894 .77765 L p .707 .577 .707 r
F P
0 g
s
.67963 .7265 m .67347 .76233 L .64645 .75274 L p .707 .577 .707 r
F P
0 g
s
.64645 .75274 m .65261 .7169 L .67963 .7265 L p .707 .577 .707 r
F P
0 g
s
.16664 .64642 m .17057 .70228 L .18311 .70855 L p .707 .577 .707 r
F P
0 g
s
.17987 .75536 m .18603 .71952 L .17376 .70791 L p .707 .577 .707 r
F P
0 g
s
.17931 .76231 m .17188 .77836 L .19053 .79598 L p .707 .577 .707 r
F P
0 g
s
.68512 .81435 m .67768 .8304 L .65903 .81278 L p .707 .577 .707 r
F P
0 g
s
.65903 .81278 m .66646 .79673 L .68512 .81435 L p .707 .577 .707 r
F P
0 g
s
.30819 .82685 m .30075 .84289 L .32358 .84293 L p .707 .577 .707 r
F P
0 g
s
.32358 .84293 m .33102 .82688 L .30819 .82685 L p .707 .577 .707 r
F P
0 g
s
.35573 .6708 m .35346 .63859 L p .36433 .62123 L .707 .577 .707 r
F P
0 g
s
.35346 .63859 m .35179 .61495 L .35543 .61677 L p .707 .577 .707 r
F P
0 g
s
.35543 .61677 m .36433 .62123 L p .35346 .63859 L .707 .577 .707 r
F P
0 g
s
.35179 .61495 m .35573 .6708 L .33474 .66637 L p .707 .577 .707 r
F P
0 g
s
.33474 .66637 m .33081 .61052 L .35179 .61495 L p .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .33662 .69894 L .34911 .70568 L p .707 .577 .707 r
F P
0 g
s
.34911 .70568 m .35728 .71009 L p .34855 .71812 L .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .34911 .70568 L .34855 .71812 L .707 .577 .707 r
F
.34661 .71435 m .35715 .52669 L .3666 .27286 L F
.37066 .28602 m .3683 .27837 L p .35715 .52669 L F P
0 g
s
.3683 .27837 m .3666 .27286 L p .35715 .52669 L .707 .577 .707 r
F P
0 g
s
.35728 .71009 m .35112 .74592 L .33046 .73478 L p .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34211 .78018 L .34644 .78697 L p .707 .577 .707 r
F P
0 g
s
.34644 .78697 m .3528 .79692 L p .34659 .79668 L .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34644 .78697 L .34659 .79668 L .707 .577 .707 r
F
.34567 .7353 m .34827 .69607 L .34661 .71435 L F
.34345 .7842 m .34576 .74186 L p .34567 .7353 L F P
0 g
s
.34576 .74186 m .34827 .69607 L p .34567 .7353 L .707 .577 .707 r
F P
0 g
s
.34827 .69607 m .37066 .28602 L p .34661 .71435 L .707 .577 .707 r
F P
0 g
s
.37066 .28602 m .34345 .7842 L .36118 .79705 L p .707 .577 .707 r
F P
0 g
s
.17376 .70791 m .16759 .74375 L .17987 .75536 L p .707 .577 .707 r
F P
0 g
s
.17057 .70228 m .16664 .64642 L .16378 .63891 L p .707 .577 .707 r
F P
0 g
s
.17188 .77836 m .17931 .76231 L .16862 .74557 L p .707 .577 .707 r
F P
0 g
s
.16862 .74557 m .16119 .76162 L .17188 .77836 L p .707 .577 .707 r
F P
0 g
s
.66646 .79673 m .65903 .81278 L .63423 .79601 L p .707 .577 .707 r
F P
0 g
s
.63423 .79601 m .64167 .77996 L .66646 .79673 L p .707 .577 .707 r
F P
0 g
s
.33102 .82688 m .32358 .84293 L .33953 .83752 L p .707 .577 .707 r
F P
0 g
s
.33953 .83752 m .34697 .82148 L .33102 .82688 L p .707 .577 .707 r
F P
0 g
s
.16887 .69782 m .17057 .70228 L p .16894 .68708 L .707 .577 .707 r
F P
0 g
s
.16759 .74375 m .17376 .70791 L .17106 .69698 L p .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .1649 .73282 L .16526 .73428 L p .707 .577 .707 r
F P
0 g
s
.16526 .73428 m .16759 .74375 L p .16908 .72371 L .707 .577 .707 r
F P
0 g
s
.16908 .72371 m .17106 .69698 L .16526 .73428 L .707 .577 .707 r
F
.16119 .76162 m .16862 .74557 L .16695 .73134 L p F P
0 g
s
.16695 .73134 m .15952 .74739 L .16119 .76162 L p .707 .577 .707 r
F P
0 g
s
.16695 .73134 m .17445 .72102 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.15952 .74739 m .16409 .73751 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.16409 .73751 m .16695 .73134 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .17821 .68779 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1649 .73282 m .1688 .71016 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1688 .71016 m .17106 .69698 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.16378 .63891 m .16771 .69476 L .16887 .69782 L p .707 .577 .707 r
F P
0 g
s
.16894 .68708 m .16378 .63891 L .16887 .69782 L .707 .577 .707 r
F
.65405 .29281 m .62685 .79099 L .62279 .77782 L p F P
0 g
s
.62279 .77782 m .64999 .27965 L .65405 .29281 L p .707 .577 .707 r
F P
0 g
s
.16771 .69476 m .16378 .63891 L .17087 .6309 L p .707 .577 .707 r
F P
0 g
s
.3666 .27286 m .33939 .77103 L .34345 .7842 L p .707 .577 .707 r
F P
0 g
s
.33939 .77103 m .3666 .27286 L .37661 .26067 L p .707 .577 .707 r
F P
0 g
s
.34697 .82148 m .33953 .83752 L .34704 .8272 L p .707 .577 .707 r
F P
0 g
s
.34704 .8272 m .35447 .81115 L .34697 .82148 L p .707 .577 .707 r
F P
0 g
s
.17087 .6309 m .17481 .68675 L .16771 .69476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17821 .68779 m .17205 .72363 L .1649 .73282 L p .707 .577 .707 r
F P
0 g
s
.17481 .68675 m .17087 .6309 L .18723 .62318 L p .707 .577 .707 r
F P
0 g
s
.19451 .68125 m .19387 .68497 L p .17205 .72363 L .707 .577 .707 r
F P
0 g
s
.16702 .73706 m .17445 .72102 L .1904 .71561 L p .707 .577 .707 r
F P
0 g
s
.19387 .68497 m .18835 .71708 L .17389 .72289 L p .707 .577 .707 r
F P
0 g
s
.17445 .72102 m .17135 .72772 L p .15952 .74739 L .707 .577 .707 r
F P
0 g
s
.17389 .72289 m .17205 .72363 L p .19387 .68497 L .707 .577 .707 r
F P
0 g
s
.17135 .72772 m .16702 .73706 L .16486 .74004 L p .707 .577 .707 r
F P
0 g
s
.16486 .74004 m .15952 .74739 L p .17135 .72772 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64999 .27965 m .62279 .77782 L .60506 .76497 L p .707 .577 .707 r
F P
0 g
s
.60506 .76497 m .63226 .26679 L .64999 .27965 L p .707 .577 .707 r
F P
0 g
s
.35447 .81115 m .34704 .8272 L .34536 .81297 L p .707 .577 .707 r
F P
0 g
s
.34536 .81297 m .3528 .79692 L .35447 .81115 L p .707 .577 .707 r
F P
0 g
s
.17205 .72363 m .17821 .68779 L .19451 .68125 L p .707 .577 .707 r
F P
0 g
s
.18723 .62318 m .19116 .67903 L .17481 .68675 L p .707 .577 .707 r
F P
0 g
s
.3494 .75884 m .37661 .26067 L .39971 .25065 L p .707 .577 .707 r
F P
0 g
s
.37661 .26067 m .3494 .75884 L .33939 .77103 L p .707 .577 .707 r
F P
0 g
s
.19116 .67903 m .18723 .62318 L .21125 .6165 L p .707 .577 .707 r
F P
0 g
s
.21836 .67799 m .21743 .68345 L p .18835 .71708 L .707 .577 .707 r
F P
0 g
s
.18297 .73166 m .1904 .71561 L .21323 .71565 L p .707 .577 .707 r
F P
0 g
s
.21743 .68345 m .2122 .71383 L .19154 .71665 L p .707 .577 .707 r
F P
0 g
s
.1904 .71561 m .18755 .72177 L p .16702 .73706 L .707 .577 .707 r
F P
0 g
s
.19154 .71665 m .18835 .71708 L p .21743 .68345 L .707 .577 .707 r
F P
0 g
s
.18755 .72177 m .18297 .73166 L .17872 .7331 L p .707 .577 .707 r
F P
0 g
s
.17872 .7331 m .16702 .73706 L p .18755 .72177 L .707 .577 .707 r
F P
0 g
s
.33081 .61052 m .33474 .66637 L .30736 .66422 L p .707 .577 .707 r
F P
0 g
s
.30736 .66422 m .30343 .60837 L .33081 .61052 L p .707 .577 .707 r
F P
0 g
s
.3528 .79692 m .34536 .81297 L .33468 .79623 L p .707 .577 .707 r
F P
0 g
s
.18835 .71708 m .19451 .68125 L .21836 .67799 L p .707 .577 .707 r
F P
0 g
s
.21125 .6165 m .21518 .67235 L .19116 .67903 L p .707 .577 .707 r
F P
0 g
s
.63226 .26679 m .60506 .76497 L .57539 .75368 L p .707 .577 .707 r
F P
0 g
s
.57539 .75368 m .6026 .25551 L .63226 .26679 L p .707 .577 .707 r
F P
0 g
s
.21518 .67235 m .21125 .6165 L .24057 .61151 L p .707 .577 .707 r
F P
0 g
s
.30343 .60837 m .30736 .66422 L .27627 .66457 L p .707 .577 .707 r
F P
0 g
s
.27627 .66457 m .27233 .60871 L .30343 .60837 L p .707 .577 .707 r
F P
0 g
s
.39971 .25065 m .3725 .74882 L .3494 .75884 L p .707 .577 .707 r
F P
0 g
s
.3725 .74882 m .39971 .25065 L .43363 .24378 L p .707 .577 .707 r
F P
0 g
s
.24451 .66737 m .24057 .61151 L .27233 .60871 L p .707 .577 .707 r
F P
0 g
s
.24057 .61151 m .24451 .66737 L .21518 .67235 L p .707 .577 .707 r
F P
0 g
s
.21323 .71565 m .2058 .73169 L .18297 .73166 L p .707 .577 .707 r
F P
0 g
s
.33662 .69894 m .33046 .73478 L .30344 .72519 L p .707 .577 .707 r
F P
0 g
s
.30344 .72519 m .3096 .68935 L .33662 .69894 L p .707 .577 .707 r
F P
0 g
s
.74278 .65275 m .73884 .5969 L .70775 .59724 L p .707 .577 .707 r
F P
0 g
s
.73884 .5969 m .74278 .65275 L .77454 .64995 L p .707 .577 .707 r
F P
0 g
s
.77454 .64995 m .77061 .5941 L .73884 .5969 L p .707 .577 .707 r
F P
0 g
s
.27233 .60871 m .27627 .66457 L .24451 .66737 L p .707 .577 .707 r
F P
0 g
s
.2122 .71383 m .21836 .67799 L .24743 .67833 L p .707 .577 .707 r
F P
0 g
s
.77061 .5941 m .77454 .64995 L .80387 .64497 L p .707 .577 .707 r
F P
0 g
s
.80387 .64497 m .79993 .58912 L .77061 .5941 L p .707 .577 .707 r
F P
0 g
s
.34211 .78018 m .33468 .79623 L .31602 .77861 L p .707 .577 .707 r
F P
0 g
s
.31602 .77861 m .32345 .76256 L .34211 .78018 L p .707 .577 .707 r
F P
0 g
s
.71168 .6531 m .70775 .59724 L .68037 .59509 L p .707 .577 .707 r
F P
0 g
s
.70775 .59724 m .71168 .6531 L .74278 .65275 L p .707 .577 .707 r
F P
0 g
s
.3096 .68935 m .30344 .72519 L .27271 .71808 L p .707 .577 .707 r
F P
0 g
s
.27271 .71808 m .27887 .68225 L .3096 .68935 L p .707 .577 .707 r
F P
0 g
s
.79993 .58912 m .80387 .64497 L .82788 .63829 L p .707 .577 .707 r
F P
0 g
s
.82788 .63829 m .82395 .58243 L .79993 .58912 L p .707 .577 .707 r
F P
0 g
s
.24743 .67833 m .24127 .71417 L .2122 .71383 L p .707 .577 .707 r
F P
0 g
s
.2058 .73169 m .21323 .71565 L .24071 .72113 L p .707 .577 .707 r
F P
0 g
s
.24127 .71417 m .24743 .67833 L .27887 .68225 L p .707 .577 .707 r
F P
0 g
s
.6026 .25551 m .57539 .75368 L .53669 .74507 L p .707 .577 .707 r
F P
0 g
s
.53669 .74507 m .5639 .2469 L .6026 .25551 L p .707 .577 .707 r
F P
0 g
s
.27887 .68225 m .27271 .71808 L .24127 .71417 L p .707 .577 .707 r
F P
0 g
s
.68037 .59509 m .68431 .65095 L .71168 .6531 L p .707 .577 .707 r
F P
0 g
s
.7385 .71871 m .74466 .68288 L .71392 .67578 L p .707 .577 .707 r
F P
0 g
s
.74466 .68288 m .7385 .71871 L .76993 .72263 L p .707 .577 .707 r
F P
0 g
s
.76993 .72263 m .7761 .68679 L .74466 .68288 L p .707 .577 .707 r
F P
0 g
s
.24071 .72113 m .23328 .73718 L .2058 .73169 L p .707 .577 .707 r
F P
0 g
s
.32345 .76256 m .31602 .77861 L .29122 .76184 L p .707 .577 .707 r
F P
0 g
s
.29122 .76184 m .29866 .74579 L .32345 .76256 L p .707 .577 .707 r
F P
0 g
s
.68431 .65095 m .68037 .59509 L .65939 .59066 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .43363 .24378 L .47507 .24073 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .3725 .74882 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.41843 .52224 m .40643 .74195 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .44786 .73891 L .40643 .74195 L p .707 .577 .707 r
F P
0 g
s
.40165 .65532 m .39549 .69116 L .42126 .69437 L p .707 .577 .707 r
F P
0 g
s
.42126 .69437 m .42692 .69507 L p .42112 .68594 L .707 .577 .707 r
F P
0 g
s
.42112 .68594 m .40165 .65532 L .42126 .69437 L .707 .577 .707 r
F
.43363 .24378 m .41843 .52224 L p .41622 .38766 L F P
0 g
s
.7761 .68679 m .76993 .72263 L .799 .72297 L p .707 .577 .707 r
F P
0 g
s
.799 .72297 m .80516 .68714 L .7761 .68679 L p .707 .577 .707 r
F P
0 g
s
.70776 .71161 m .71392 .67578 L .68691 .66618 L p .707 .577 .707 r
F P
0 g
s
.71392 .67578 m .70776 .71161 L .7385 .71871 L p .707 .577 .707 r
F P
0 g
s
.23328 .73718 m .24071 .72113 L .27014 .73151 L p .707 .577 .707 r
F P
0 g
s
.82395 .58243 m .82788 .63829 L .84424 .63057 L p .707 .577 .707 r
F P
0 g
s
.84424 .63057 m .8403 .57471 L .82395 .58243 L p .707 .577 .707 r
F P
0 g
s
.29866 .74579 m .29122 .76184 L .26271 .74756 L p .707 .577 .707 r
F P
0 g
s
.26271 .74756 m .27014 .73151 L .29866 .74579 L p .707 .577 .707 r
F P
0 g
s
.27014 .73151 m .26271 .74756 L .23328 .73718 L p .707 .577 .707 r
F P
0 g
s
.65939 .59066 m .66332 .64652 L .68431 .65095 L p .707 .577 .707 r
F P
0 g
s
.5639 .2469 m .53669 .74507 L .49275 .73998 L p .707 .577 .707 r
F P
0 g
s
.49275 .73998 m .51995 .24181 L .5639 .2469 L p .707 .577 .707 r
F P
0 g
s
.80516 .68714 m .799 .72297 L .82285 .71971 L p .707 .577 .707 r
F P
0 g
s
.82285 .71971 m .82902 .68388 L .80516 .68714 L p .707 .577 .707 r
F P
0 g
s
.68691 .66618 m .68074 .70202 L .70776 .71161 L p .707 .577 .707 r
F P
0 g
s
.68074 .70202 m .68691 .66618 L .66625 .65504 L p .707 .577 .707 r
F P
0 g
s
.4276 .5641 m .43153 .61995 L .4448 .6177 L p .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .51995 .24181 L p .46528 .61883 L .707 .577 .707 r
F P
0 g
s
.45799 .66906 m .45929 .63649 L .46528 .61883 L .707 .577 .707 r
F
.45929 .63649 m .47507 .24073 L .46528 .61883 L F
.44786 .73891 m .45234 .657 L p .45799 .66906 L F P
0 g
s
.45234 .657 m .45279 .64879 L p .45379 .65271 L .707 .577 .707 r
F P
0 g
s
.45234 .657 m .45379 .65271 L .45799 .66906 L .707 .577 .707 r
F
.43309 .65923 m .42692 .69507 L .43938 .69522 L p F P
0 g
s
.51995 .24181 m .49275 .73998 L .44786 .73891 L p .707 .577 .707 r
F P
0 g
s
.43938 .69522 m .45599 .69542 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.44513 .67826 m .43309 .65923 L .43938 .69522 L .707 .577 .707 r
F
.45279 .64879 m .47507 .24073 L p .45799 .66906 L F P
0 g
s
.45599 .69542 m .46215 .65958 L .45151 .65945 L p .707 .577 .707 r
F P
0 g
s
.45151 .65945 m .43309 .65923 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.45599 .69542 m .45151 .65945 L .44513 .67826 L .707 .577 .707 r
F
.4448 .6177 m .46086 .61497 L p .43325 .57275 L F P
0 g
s
.43325 .57275 m .4276 .5641 L .4448 .6177 L .707 .577 .707 r
F
.72406 .76916 m .73149 .75311 L .70298 .73883 L p F P
0 g
s
.73149 .75311 m .72406 .76916 L .75349 .77954 L p .707 .577 .707 r
F P
0 g
s
.75349 .77954 m .76092 .7635 L .73149 .75311 L p .707 .577 .707 r
F P
0 g
s
.66332 .64652 m .65939 .59066 L .64685 .58438 L p .707 .577 .707 r
F P
0 g
s
.69554 .75488 m .70298 .73883 L .67818 .72206 L p .707 .577 .707 r
F P
0 g
s
.70298 .73883 m .69554 .75488 L .72406 .76916 L p .707 .577 .707 r
F P
0 g
s
.66625 .65504 m .66009 .69087 L .68074 .70202 L p .707 .577 .707 r
F P
0 g
s
.76092 .7635 m .75349 .77954 L .78097 .78503 L p .707 .577 .707 r
F P
0 g
s
.78097 .78503 m .7884 .76898 L .76092 .7635 L p .707 .577 .707 r
F P
0 g
s
.67818 .72206 m .67075 .73811 L .69554 .75488 L p .707 .577 .707 r
F P
0 g
s
.67075 .73811 m .67818 .72206 L .65952 .70445 L p .707 .577 .707 r
F P
0 g
s
.82902 .68388 m .82285 .71971 L .83915 .71317 L p .707 .577 .707 r
F P
0 g
s
.83915 .71317 m .84531 .67733 L .82902 .68388 L p .707 .577 .707 r
F P
0 g
s
.8403 .57471 m .84424 .63057 L .85134 .62256 L p .707 .577 .707 r
F P
0 g
s
.85134 .62256 m .8474 .5667 L .8403 .57471 L p .707 .577 .707 r
F P
0 g
s
.64685 .58438 m .65079 .64024 L .65547 .64259 L p .707 .577 .707 r
F P
0 g
s
.65079 .64024 m .64685 .58438 L .64399 .57687 L p .707 .577 .707 r
F P
0 g
s
.64399 .57687 m .64793 .63273 L .64896 .63544 L p .707 .577 .707 r
F P
0 g
s
.64896 .63544 m .65079 .64024 L p .64903 .62387 L .707 .577 .707 r
F P
0 g
s
.64903 .62387 m .64399 .57687 L .64896 .63544 L .707 .577 .707 r
F
.65397 .64343 m .65128 .6325 L p .64871 .66709 L F P
0 g
s
.65894 .63 m .64685 .58438 L .65547 .64259 L .707 .577 .707 r
F
.65128 .6325 m .64511 .66833 L .64781 .67927 L p F P
0 g
s
.65128 .6325 m .65843 .62331 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64511 .66833 m .64889 .64639 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64889 .64639 m .65128 .6325 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64781 .67927 m .65187 .65564 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65187 .65564 m .65397 .64343 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65547 .64259 m .66332 .64652 L p .65894 .63 L .707 .577 .707 r
F P
0 g
s
.66009 .69087 m .66625 .65504 L .65397 .64343 L p .707 .577 .707 r
F P
0 g
s
.65952 .70445 m .65209 .72049 L .67075 .73811 L p .707 .577 .707 r
F P
0 g
s
.7884 .76898 m .78097 .78503 L .8038 .78506 L p .707 .577 .707 r
F P
0 g
s
.8038 .78506 m .81123 .76902 L .7884 .76898 L p .707 .577 .707 r
F P
0 g
s
.65397 .64343 m .64781 .67927 L .66009 .69087 L p .707 .577 .707 r
F P
0 g
s
.65209 .72049 m .65952 .70445 L .64884 .6877 L p .707 .577 .707 r
F P
0 g
s
.64884 .6877 m .6414 .70375 L .65209 .72049 L p .707 .577 .707 r
F P
0 g
s
.84531 .67733 m .83915 .71317 L .84631 .70398 L p .707 .577 .707 r
F P
0 g
s
.84631 .70398 m .85247 .66814 L .84531 .67733 L p .707 .577 .707 r
F P
0 g
s
.8474 .5667 m .85134 .62256 L .84848 .61505 L p .707 .577 .707 r
F P
0 g
s
.84848 .61505 m .84454 .55919 L .8474 .5667 L p .707 .577 .707 r
F P
0 g
s
.81123 .76902 m .8038 .78506 L .81975 .77966 L p .707 .577 .707 r
F P
0 g
s
.81975 .77966 m .82718 .76361 L .81123 .76902 L p .707 .577 .707 r
F P
0 g
s
.6414 .70375 m .64884 .6877 L .64716 .67347 L p .707 .577 .707 r
F P
0 g
s
.64793 .63273 m .64399 .57687 L .65109 .56886 L p .707 .577 .707 r
F P
0 g
s
.64716 .67347 m .63973 .68952 L .6414 .70375 L p .707 .577 .707 r
F P
0 g
s
.85247 .66814 m .84631 .70398 L .84361 .69305 L p .707 .577 .707 r
F P
0 g
s
.84361 .69305 m .84977 .65721 L .85247 .66814 L p .707 .577 .707 r
F P
0 g
s
.82718 .76361 m .81975 .77966 L .82725 .76933 L p .707 .577 .707 r
F P
0 g
s
.82725 .76933 m .83468 .75328 L .82718 .76361 L p .707 .577 .707 r
F P
0 g
s
.65109 .56886 m .65502 .62472 L .64793 .63273 L p .707 .577 .707 r
F P
0 g
s
.84454 .55919 m .84848 .61505 L .83594 .60877 L p .707 .577 .707 r
F P
0 g
s
.83594 .60877 m .83201 .55291 L .84454 .55919 L p .707 .577 .707 r
F P
0 g
s
.65843 .62331 m .65227 .65915 L .64511 .66833 L p .707 .577 .707 r
F P
0 g
s
.63973 .68952 m .64716 .67347 L .65467 .66315 L p .707 .577 .707 r
F P
0 g
s
.39977 .62275 m .39583 .5669 L .36474 .56724 L p .707 .577 .707 r
F P
0 g
s
.39583 .5669 m .39977 .62275 L .43153 .61995 L p .707 .577 .707 r
F P
0 g
s
.43153 .61995 m .4276 .5641 L .39583 .5669 L p .707 .577 .707 r
F P
0 g
s
.46086 .61497 m .45692 .55911 L .4276 .5641 L p .707 .577 .707 r
F P
0 g
s
.65502 .62472 m .65109 .56886 L .66744 .56114 L p .707 .577 .707 r
F P
0 g
s
.65467 .66315 m .64723 .67919 L .63973 .68952 L p .707 .577 .707 r
F P
0 g
s
.36867 .6231 m .36474 .56724 L .33736 .56509 L p .707 .577 .707 r
F P
0 g
s
.36474 .56724 m .36867 .6231 L .39977 .62275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84977 .65721 m .84361 .69305 L .83133 .68144 L p .707 .577 .707 r
F P
0 g
s
.83133 .68144 m .8375 .6456 L .84977 .65721 L p .707 .577 .707 r
F P
0 g
s
.83468 .75328 m .82725 .76933 L .82558 .7551 L p .707 .577 .707 r
F P
0 g
s
.82558 .7551 m .83301 .73905 L .83468 .75328 L p .707 .577 .707 r
F P
0 g
s
.45692 .55911 m .46086 .61497 L .48487 .60829 L p .707 .577 .707 r
F P
0 g
s
.48487 .60829 m .48094 .55243 L .45692 .55911 L p .707 .577 .707 r
F P
0 g
s
.65227 .65915 m .65843 .62331 L .67473 .61676 L p .707 .577 .707 r
F P
0 g
s
.83201 .55291 m .83594 .60877 L .81496 .60434 L p .707 .577 .707 r
F P
0 g
s
.81496 .60434 m .81102 .54848 L .83201 .55291 L p .707 .577 .707 r
F P
0 g
s
.66744 .56114 m .67138 .61699 L .65502 .62472 L p .707 .577 .707 r
F P
0 g
s
.33736 .56509 m .3413 .62095 L .36867 .6231 L p .707 .577 .707 r
F P
0 g
s
.39549 .69116 m .40165 .65532 L .37091 .64822 L p .707 .577 .707 r
F P
0 g
s
.42692 .69507 m .43309 .65923 L .40165 .65532 L p .707 .577 .707 r
F P
0 g
s
.3413 .62095 m .33736 .56509 L .31638 .56066 L p .707 .577 .707 r
F P
0 g
s
.36475 .68406 m .37091 .64822 L .3439 .63863 L p .707 .577 .707 r
F P
0 g
s
.37091 .64822 m .36475 .68406 L .39549 .69116 L p .707 .577 .707 r
F P
0 g
s
.67473 .61676 m .66857 .6526 L .65227 .65915 L p .707 .577 .707 r
F P
0 g
s
.64723 .67919 m .65467 .66315 L .67062 .65774 L p .707 .577 .707 r
F P
0 g
s
.67138 .61699 m .66744 .56114 L .69146 .55446 L p .707 .577 .707 r
F P
0 g
s
.48094 .55243 m .48487 .60829 L .50123 .60057 L p .707 .577 .707 r
F P
0 g
s
.50123 .60057 m .4973 .54471 L .48094 .55243 L p .707 .577 .707 r
F P
0 g
s
.67062 .65774 m .66318 .67379 L .64723 .67919 L p .707 .577 .707 r
F P
0 g
s
.31638 .56066 m .32031 .61652 L .3413 .62095 L p .707 .577 .707 r
F P
0 g
s
.8375 .6456 m .83133 .68144 L .81067 .6703 L p .707 .577 .707 r
F P
0 g
s
.81067 .6703 m .81684 .63446 L .8375 .6456 L p .707 .577 .707 r
F P
0 g
s
.81102 .54848 m .81496 .60434 L .78758 .60219 L p .707 .577 .707 r
F P
0 g
s
.78758 .60219 m .78364 .54633 L .81102 .54848 L p .707 .577 .707 r
F P
0 g
s
.46215 .65958 m .45599 .69542 L .47984 .69216 L p .707 .577 .707 r
F P
0 g
s
.47984 .69216 m .48601 .65632 L .46215 .65958 L p .707 .577 .707 r
F P
0 g
s
.3439 .63863 m .33773 .67446 L .36475 .68406 L p .707 .577 .707 r
F P
0 g
s
.33773 .67446 m .3439 .63863 L .32324 .62748 L p .707 .577 .707 r
F P
0 g
s
.66857 .6526 m .67473 .61676 L .69858 .61351 L p .707 .577 .707 r
F P
0 g
s
.83301 .73905 m .82558 .7551 L .81489 .73836 L p .707 .577 .707 r
F P
0 g
s
.81489 .73836 m .82232 .72231 L .83301 .73905 L p .707 .577 .707 r
F P
0 g
s
.69146 .55446 m .69539 .61031 L .67138 .61699 L p .707 .577 .707 r
F P
0 g
s
.38105 .73499 m .38848 .71894 L .35997 .70466 L p .707 .577 .707 r
F P
0 g
s
.38848 .71894 m .38105 .73499 L .41048 .74537 L p .707 .577 .707 r
F P
0 g
s
.41048 .74537 m .41791 .72933 L .38848 .71894 L p .707 .577 .707 r
F P
0 g
s
.32031 .61652 m .31638 .56066 L .30384 .55438 L p .707 .577 .707 r
F P
0 g
s
.35253 .72071 m .35997 .70466 L .33517 .68789 L p .707 .577 .707 r
F P
0 g
s
.35997 .70466 m .35253 .72071 L .38105 .73499 L p .707 .577 .707 r
F P
0 g
s
.69539 .61031 m .69146 .55446 L .72078 .54947 L p .707 .577 .707 r
F P
0 g
s
.41791 .72933 m .41048 .74537 L .43796 .75086 L p .707 .577 .707 r
F P
0 g
s
.43796 .75086 m .44539 .73481 L .41791 .72933 L p .707 .577 .707 r
F P
0 g
s
.32324 .62748 m .31708 .66332 L .33773 .67446 L p .707 .577 .707 r
F P
0 g
s
.69858 .61351 m .69242 .64934 L .66857 .6526 L p .707 .577 .707 r
F P
0 g
s
.66318 .67379 m .67062 .65774 L .69345 .65778 L p .707 .577 .707 r
F P
0 g
s
.33517 .68789 m .32774 .70394 L .35253 .72071 L p .707 .577 .707 r
F P
0 g
s
.78364 .54633 m .78758 .60219 L .75648 .60253 L p .707 .577 .707 r
F P
0 g
s
.75648 .60253 m .75255 .54667 L .78364 .54633 L p .707 .577 .707 r
F P
0 g
s
.32774 .70394 m .33517 .68789 L .31651 .67028 L p .707 .577 .707 r
F P
0 g
s
.4973 .54471 m .50123 .60057 L .50833 .59256 L p .707 .577 .707 r
F P
0 g
s
.50833 .59256 m .50439 .5367 L .4973 .54471 L p .707 .577 .707 r
F P
0 g
s
.48601 .65632 m .47984 .69216 L .49614 .68561 L p .707 .577 .707 r
F P
0 g
s
.49614 .68561 m .5023 .64978 L .48601 .65632 L p .707 .577 .707 r
F P
0 g
s
.72472 .60533 m .72078 .54947 L .75255 .54667 L p .707 .577 .707 r
F P
0 g
s
.72078 .54947 m .72472 .60533 L .69539 .61031 L p .707 .577 .707 r
F P
0 g
s
.81684 .63446 m .81067 .6703 L .78366 .6607 L p .707 .577 .707 r
F P
0 g
s
.78366 .6607 m .78982 .62487 L .81684 .63446 L p .707 .577 .707 r
F P
0 g
s
.30384 .55438 m .30777 .61024 L .32031 .61652 L p .707 .577 .707 r
F P
0 g
s
.69345 .65778 m .68601 .67383 L .66318 .67379 L p .707 .577 .707 r
F P
0 g
s
.69242 .64934 m .69858 .61351 L .72765 .61385 L p .707 .577 .707 r
F P
0 g
s
.31708 .66332 m .32324 .62748 L .31096 .61587 L p .707 .577 .707 r
F P
0 g
s
.75255 .54667 m .75648 .60253 L .72472 .60533 L p .707 .577 .707 r
F P
0 g
s
.31651 .67028 m .30908 .68632 L .32774 .70394 L p .707 .577 .707 r
F P
0 g
s
.82232 .72231 m .81489 .73836 L .79623 .72074 L p .707 .577 .707 r
F P
0 g
s
.79623 .72074 m .80367 .70469 L .82232 .72231 L p .707 .577 .707 r
F P
0 g
s
.44539 .73481 m .43796 .75086 L .46079 .75089 L p .707 .577 .707 r
F P
0 g
s
.46079 .75089 m .46822 .73485 L .44539 .73481 L p .707 .577 .707 r
F P
0 g
s
.78982 .62487 m .78366 .6607 L .75292 .6536 L p .707 .577 .707 r
F P
0 g
s
.75292 .6536 m .75909 .61776 L .78982 .62487 L p .707 .577 .707 r
F P
0 g
s
.72765 .61385 m .72148 .64969 L .69242 .64934 L p .707 .577 .707 r
F P
0 g
s
.31096 .61587 m .3048 .65171 L .31708 .66332 L p .707 .577 .707 r
F P
0 g
s
.30777 .61024 m .30384 .55438 L .30098 .54687 L p .707 .577 .707 r
F P
0 g
s
.72148 .64969 m .72765 .61385 L .75909 .61776 L p .707 .577 .707 r
F P
0 g
s
.68601 .67383 m .69345 .65778 L .72092 .66326 L p .707 .577 .707 r
F P
0 g
s
.30908 .68632 m .31651 .67028 L .30583 .65353 L p .707 .577 .707 r
F P
0 g
s
.75909 .61776 m .75292 .6536 L .72148 .64969 L p .707 .577 .707 r
F P
0 g
s
.72092 .66326 m .71349 .67931 L .68601 .67383 L p .707 .577 .707 r
F P
0 g
s
.30583 .65353 m .29839 .66958 L .30908 .68632 L p .707 .577 .707 r
F P
0 g
s
.80367 .70469 m .79623 .72074 L .77144 .70397 L p .707 .577 .707 r
F P
0 g
s
.77144 .70397 m .77887 .68792 L .80367 .70469 L p .707 .577 .707 r
F P
0 g
s
.5023 .64978 m .49614 .68561 L .5033 .67643 L p .707 .577 .707 r
F P
0 g
s
.5033 .67643 m .50946 .64059 L .5023 .64978 L p .707 .577 .707 r
F P
0 g
s
.46822 .73485 m .46079 .75089 L .47674 .74549 L p .707 .577 .707 r
F P
0 g
s
.47674 .74549 m .48417 .72944 L .46822 .73485 L p .707 .577 .707 r
F P
0 g
s
.30608 .60578 m .30777 .61024 L p .30615 .59504 L .707 .577 .707 r
F P
0 g
s
.3048 .65171 m .31096 .61587 L .30827 .60494 L p .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .3021 .64078 L .30246 .64224 L p .707 .577 .707 r
F P
0 g
s
.30246 .64224 m .3048 .65171 L p .30628 .63167 L .707 .577 .707 r
F P
0 g
s
.30628 .63167 m .30827 .60494 L .30246 .64224 L .707 .577 .707 r
F
.29839 .66958 m .30583 .65353 L .30415 .6393 L p F P
0 g
s
.30415 .6393 m .29672 .65535 L .29839 .66958 L p .707 .577 .707 r
F P
0 g
s
.30415 .6393 m .31166 .62898 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.29672 .65535 m .3013 .64547 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.3013 .64547 m .30415 .6393 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .31542 .59575 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.3021 .64078 m .306 .61812 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.306 .61812 m .30827 .60494 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.30098 .54687 m .30491 .60273 L .30608 .60578 L p .707 .577 .707 r
F P
0 g
s
.30615 .59504 m .30098 .54687 L .30608 .60578 L .707 .577 .707 r
F
.50439 .5367 m .50833 .59256 L .50547 .58504 L p F P
0 g
s
.50547 .58504 m .50153 .52919 L .50439 .5367 L p .707 .577 .707 r
F P
0 g
s
.71349 .67931 m .72092 .66326 L .75036 .67365 L p .707 .577 .707 r
F P
0 g
s
.77887 .68792 m .77144 .70397 L .74293 .68969 L p .707 .577 .707 r
F P
0 g
s
.74293 .68969 m .75036 .67365 L .77887 .68792 L p .707 .577 .707 r
F P
0 g
s
.75036 .67365 m .74293 .68969 L .71349 .67931 L p .707 .577 .707 r
F P
0 g
s
.30491 .60273 m .30098 .54687 L .30808 .53886 L p .707 .577 .707 r
F P
0 g
s
.48417 .72944 m .47674 .74549 L .48424 .73516 L p .707 .577 .707 r
F P
0 g
s
.48424 .73516 m .49167 .71911 L .48417 .72944 L p .707 .577 .707 r
F P
0 g
s
.50946 .64059 m .5033 .67643 L .5006 .66549 L p .707 .577 .707 r
F P
0 g
s
.5006 .66549 m .50676 .62965 L .50946 .64059 L p .707 .577 .707 r
F P
0 g
s
.30808 .53886 m .31201 .59472 L .30491 .60273 L p .707 .577 .707 r
F P
0 g
s
.50153 .52919 m .50547 .58504 L .49293 .57877 L p .707 .577 .707 r
F P
0 g
s
.49293 .57877 m .48899 .52291 L .50153 .52919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31542 .59575 m .30926 .63159 L .3021 .64078 L p .707 .577 .707 r
F P
0 g
s
.31201 .59472 m .30808 .53886 L .32443 .53114 L p .707 .577 .707 r
F P
0 g
s
.33172 .58921 m .33108 .59293 L p .30926 .63159 L .707 .577 .707 r
F P
0 g
s
.30422 .64502 m .31166 .62898 L .32761 .62357 L p .707 .577 .707 r
F P
0 g
s
.33108 .59293 m .32556 .62505 L .3111 .63085 L p .707 .577 .707 r
F P
0 g
s
.31166 .62898 m .30855 .63568 L p .29672 .65535 L .707 .577 .707 r
F P
0 g
s
.3111 .63085 m .30926 .63159 L p .33108 .59293 L .707 .577 .707 r
F P
0 g
s
.30855 .63568 m .30422 .64502 L .30206 .648 L p .707 .577 .707 r
F P
0 g
s
.30206 .648 m .29672 .65535 L p .30855 .63568 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49167 .71911 m .48424 .73516 L .48257 .72093 L p .707 .577 .707 r
F P
0 g
s
.48257 .72093 m .49 .70488 L .49167 .71911 L p .707 .577 .707 r
F P
0 g
s
.50676 .62965 m .5006 .66549 L .48832 .65389 L p .707 .577 .707 r
F P
0 g
s
.48832 .65389 m .49449 .61805 L .50676 .62965 L p .707 .577 .707 r
F P
0 g
s
.30926 .63159 m .31542 .59575 L .33172 .58921 L p .707 .577 .707 r
F P
0 g
s
.48899 .52291 m .49293 .57877 L .47195 .57433 L p .707 .577 .707 r
F P
0 g
s
.47195 .57433 m .46801 .51848 L .48899 .52291 L p .707 .577 .707 r
F P
0 g
s
.32443 .53114 m .32837 .58699 L .31201 .59472 L p .707 .577 .707 r
F P
0 g
s
.32837 .58699 m .32443 .53114 L .34845 .52446 L p .707 .577 .707 r
F P
0 g
s
.35557 .58595 m .35463 .59141 L p .32556 .62505 L .707 .577 .707 r
F P
0 g
s
.32017 .63962 m .32761 .62357 L .35044 .62361 L p .707 .577 .707 r
F P
0 g
s
.35463 .59141 m .34941 .62179 L .32874 .62461 L p .707 .577 .707 r
F P
0 g
s
.32761 .62357 m .32475 .62974 L p .30422 .64502 L .707 .577 .707 r
F P
0 g
s
.32874 .62461 m .32556 .62505 L p .35463 .59141 L .707 .577 .707 r
F P
0 g
s
.32475 .62974 m .32017 .63962 L .31592 .64106 L p .707 .577 .707 r
F P
0 g
s
.31592 .64106 m .30422 .64502 L p .32475 .62974 L .707 .577 .707 r
F P
0 g
s
.46801 .51848 m .47195 .57433 L .44457 .57219 L p .707 .577 .707 r
F P
0 g
s
.44457 .57219 m .44063 .51633 L .46801 .51848 L p .707 .577 .707 r
F P
0 g
s
.49449 .61805 m .48832 .65389 L .46766 .64274 L p .707 .577 .707 r
F P
0 g
s
.46766 .64274 m .47383 .6069 L .49449 .61805 L p .707 .577 .707 r
F P
0 g
s
.49 .70488 m .48257 .72093 L .47188 .70419 L p .707 .577 .707 r
F P
0 g
s
.47188 .70419 m .47931 .68814 L .49 .70488 L p .707 .577 .707 r
F P
0 g
s
.32556 .62505 m .33172 .58921 L .35557 .58595 L p .707 .577 .707 r
F P
0 g
s
.34845 .52446 m .35238 .58031 L .32837 .58699 L p .707 .577 .707 r
F P
0 g
s
.35238 .58031 m .34845 .52446 L .37777 .51947 L p .707 .577 .707 r
F P
0 g
s
.44063 .51633 m .44457 .57219 L .41347 .57253 L p .707 .577 .707 r
F P
0 g
s
.41347 .57253 m .40954 .51667 L .44063 .51633 L p .707 .577 .707 r
F P
0 g
s
.38171 .57533 m .37777 .51947 L .40954 .51667 L p .707 .577 .707 r
F P
0 g
s
.37777 .51947 m .38171 .57533 L .35238 .58031 L p .707 .577 .707 r
F P
0 g
s
.35044 .62361 m .343 .63966 L .32017 .63962 L p .707 .577 .707 r
F P
0 g
s
.47383 .6069 m .46766 .64274 L .44065 .63315 L p .707 .577 .707 r
F P
0 g
s
.44065 .63315 m .44681 .59731 L .47383 .6069 L p .707 .577 .707 r
F P
0 g
s
.40954 .51667 m .41347 .57253 L .38171 .57533 L p .707 .577 .707 r
F P
0 g
s
.34941 .62179 m .35557 .58595 L .38464 .58629 L p .707 .577 .707 r
F P
0 g
s
.47931 .68814 m .47188 .70419 L .45322 .68657 L p .707 .577 .707 r
F P
0 g
s
.45322 .68657 m .46066 .67052 L .47931 .68814 L p .707 .577 .707 r
F P
0 g
s
.44681 .59731 m .44065 .63315 L .40991 .62605 L p .707 .577 .707 r
F P
0 g
s
.40991 .62605 m .41607 .59021 L .44681 .59731 L p .707 .577 .707 r
F P
0 g
s
.38464 .58629 m .37847 .62213 L .34941 .62179 L p .707 .577 .707 r
F P
0 g
s
.343 .63966 m .35044 .62361 L .37791 .62909 L p .707 .577 .707 r
F P
0 g
s
.37847 .62213 m .38464 .58629 L .41607 .59021 L p .707 .577 .707 r
F P
0 g
s
.41607 .59021 m .40991 .62605 L .37847 .62213 L p .707 .577 .707 r
F P
0 g
s
.37791 .62909 m .37048 .64514 L .343 .63966 L p .707 .577 .707 r
F P
0 g
s
.46066 .67052 m .45322 .68657 L .42843 .6698 L p .707 .577 .707 r
F P
0 g
s
.42843 .6698 m .43586 .65375 L .46066 .67052 L p .707 .577 .707 r
F P
0 g
s
.37048 .64514 m .37791 .62909 L .40735 .63948 L p .707 .577 .707 r
F P
0 g
s
.43586 .65375 m .42843 .6698 L .39991 .65552 L p .707 .577 .707 r
F P
0 g
s
.39991 .65552 m .40735 .63948 L .43586 .65375 L p .707 .577 .707 r
F P
0 g
s
.40735 .63948 m .39991 .65552 L .37048 .64514 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0081oo`00M7oo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00NWoo001aOol30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001dOol006moo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0071oo`00KGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06ioo`00Jgoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006]oo`00JWoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JGoo
001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001XOol006Qoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUH00000IWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Eoo`00
J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH0
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001S
Ool006Qoo`03001JEP0000EJEP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo
00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03001JEUYF
00AJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF01400003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH0009JEPH000AJEP03001JEUYF00IJEP04001JEUYFFUH70007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000<00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00HWoo10001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001NOol400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Uoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00
EWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000KOolG000eOol005Eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8001=oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080039o
o`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P003Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009Ool400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000^
Ool005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<005YFFUH0
0P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPH000QJEP03001JEUYF00IJEPL000=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP80009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
05Ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD0009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00
FUH00004FUH01000FUIJEUYF1`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP@000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00FUH00004FUH400000eYF
0000000>0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000UYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000[Ool005Ioo`03
001JEP0000@00003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000:goo001FOol00`00
FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
00000eYF001JEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2000017oo001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000
00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
1Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo00@005YF000000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00Ool00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00eYF5P0015YF
00D005YFFUIJEP0002]oo`00Egoo0P0015YF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH0
0`00Oomoo`0YOol004=ooaH000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP03FUH60008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000020002FUH00`00Oomoo`0YOol003mo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`800003FUH005YF
009JEP03001JEP00018000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000[Ool0
03]oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001J
EP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00IJEP03001JEUYF
00EJEP07001JEUYFFUH005YF0000:goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH01@00FUIJEUYF000015YF3@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000goo00@005YF
001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000:goo000dOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP02FUHF0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00
FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00<Woo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`001EYF00<005YFFUH00UYF1P00
0UYF20001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`@000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP04001JEUYFFUH2000/Ool0031o
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000D00004FUH00000FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP02FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00D005YFFUIJ
EP0002eoo`00;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP000000
1EYF10001EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00@005YF000002ioo`00;Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
0eYF20001eYF00<005YFFUH01EYF10002EYF100000=JEP00FUH01EYF00<005YFFUH00UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH200000eYF000000020005FUH00`00FUH000030002FUH00`00FUIJEP07FUH3000:FUH0
0`00FUIJEP020006FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF10000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP04FUH01000
FUIJEUYF1P001eYF00@005YFFUIJEP8000QJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP80
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8002ioo`00;Woo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH015YF1@001EYF00<005YFFUH0
0eYF0P001UYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00MJEP8000AJEP03001JEUYF00IJEP80
00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP00
00=JEQ/000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0002aoo`00;Woo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP8000UJEP<000UJEPD000=JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP<00006FUH00000001J
EP001EYF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJ
EP04001JEUYFFUH90003FUH01000FUH005YF0P002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000UYF00@005YF0000009JEPd0019oo`@000MJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH<0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80009JEP800003FUH00000008000IJEP03001JEUYF009JEPD0019oo`8000AJEP03
001JEUYF00AJEP05001JEUYFFUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUH00003FUH00`00FUH000020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH200000eYF001JEP04FUH01000FUIJEUYF0`00
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P004Goo0`0000=JEP00FUH01EYF00H005YFFUH005YF000Z
Ool002moo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03
001JEP0000AJEP04001JEP00FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0008FUH00`00FUIJEP04FUH01000FUIJEUYF0`002EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF0`00
4Goo0P001UYF00H005YFFUH005YF000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPD000QJ
EP03001JEUYF00IJEP04001JEUYF0003FUH30003FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH20005FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00009JEP80009JEPT000MJEP03001JEUYF00IJEP80015oo`8000=JEP07
001JEUYFFUH005YF0000:Woo000_Ool00`00FUH00004FUH00`00FUH0000A0008FUH01000FUIJEP00
0UYF00@005YFFUH000IJEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000AJEP04
001JEUYF0004FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP@00003FUH005YF00AJEP03001JEP0000<0009JEP03001JEUYF00QJ
EP<0015oo`800003FUH005YF009JEP03001JEP0002Yoo`00;goo00<005YF00000eYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH010001EYF00L005YFFUIJEP00FUH00003FUH20003FUH00`00FUIJEP02
00000eYF001JEP06FUH30008FUH01000FUIJEP000eYF00@005YFFUIJEP80009JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF0`000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF100025YF00@005YFFUIJEP80015oo`8000=JEP8002]oo`00;goo
00@005YF001JEP<00003FUH005YF00AJEP8000MJEP03001JEUYF00AJEPH000=JEP8000IJEP04001J
EUYF0002FUH00`00FUH000030004FUH50007FUH01000FUIJEUYF0`001UYF0P000eYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00H005YF000005YF0006FUH00`00
FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP03FUH2000<Ool60002FUH2000[Ool002moo`03
001JEP00008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEP00009JEP03001JEUYF00=JEPT000IJEP03001JEUYF00AJEP03001J
EUYF00EJEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000IJEP00001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP07
FUH<0003FUH01`00FUH005YF001JEP0002]oo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJ
EPH000EJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH20009FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001o
o`0ZOol002moo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH20004FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF009JEP<0009JEPl000AJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP@00003FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01@00
FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000:goo000`Ool20004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YF
FUH00UYF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00@005YFFUIJEP80009JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400001UYF
001JEUYF001JEP@00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF00<005YFFUH00UYF0P00;7oo000`Ool20004FUH00`00FUIJEP03FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH20004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YF00000eYF0`001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF0`001EYF00<005YFFUH00UYF0P00;7oo
000`Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH01@00FUIJEUYF000025YF0P002UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF0P001UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF00<005YFFUH00eYF
00L005YFFUIJEP00FUH0000/Ool002moo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP06001JEP00001JEP0025YF0P002UYF
00<005YFFUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<0009JEP06001JEUYF001JEP001eYF100000=JEP00FUH01eYF00<005YFFUH01UYF0`001EYF
00<005YF000015YF00@005YFFUIJEP8002eoo`00;goo00<005YF00000eYF00<005YFFUH00UYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000=JEP04001JEUYF
FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH60002FUH01000FUIJEP001UYF00@005YFFUIJEP<000IJEP03
001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH01000FUIJEUYF0P00;Woo000_Ool2
0004FUHD0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH20006FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUH00002000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH30004FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPD0009JEP<000IJ
EP03001JEUYF00=JEP<000AJEP04001JEP00FUH2000`Ool002moo`80009JEP@000EJEP03001JEP00
00<000Moo`L000IJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH01000FUIJEUYF0P001Goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF0`00<Woo000_Ool015YF000000000UYF00<005YFFUH0
0eYF00<005YFFUH015YF10000Woo0`001Goo10000UYF00<005YFFUH01EYF00@005YFFUH000=JEP80
00MJEP06001JEP00001JEP002eYF00<005YFFUH01eYF00@005YF000000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000EJEP8000EJEP05001JEUYFFUH00003FUH00`00Oomoo`05
Ool500000goo0000000<0005FUH00`00Oomoo`0aOol002ioo`<000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00H000Qoo`@000EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF
009JEP<000YJEP03001JEUYF00MJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000AJEP04001JEUYF0003FUH01`00FUH00000FUH005YF008000Qoo`D000mo
o`07001JEUYFFUH005YF0000<Woo000^Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH4000<Ool400000eYF001JEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP06FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20004FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000]oo`<0015oo`06001JEUYF
001JEP00<Woo000^Ool200000eYF0000000;0004FUH00`00FUIJEP06FUH2000?Ool20005FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP02FUH@0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20005FUH2000POol20003FUH00`00
Oomoo`0_Ool002ioo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH60007FUH01000FUH000003goo
0P000eYF00<005YFFUH00eYF00<005YFFUH00P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP<001moo`05001JEUYFFUH0000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEPD000EJEP04001JEUYFFUH2000?Ool01000FUIJEP00
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02`001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P001UYF
0P007goo00D005YFFUIJEP00031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH0100000=JEP00FUH01EYF0P003Goo00@005YFFUH000EJEP03001JEUYF00D00003
FUH00000008000MJEP03001JEUYF00=JEP03001JEUYF008000YJEPP000UJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP8000AJEP04001JEP00000NOol00`00FUIJ
EP02000`Ool002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20008FUH2000;Ool01000FUIJEP001EYF0`0015YF00<005YFFUH00eYF10000UYF00<005YFFUH0
15YF0`0000=JEP00FUH02eYF00<005YFFUH00eYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000eYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEP8001eoo`04001JEP00
000`Ool002eoo`800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJEP03
001JEP0000/0009JEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH:0003FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH0
1UYF00<005YFFUH00`001UYF0P006goo0P000UYF00<007ooOol0;Goo000]Ool200001EYF001oogoo
00001EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEP04001JEUYFFUH20003FUH0
1@00FUIJEUYF00000UYF00<005YF00000P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P001UYF00<005YFFUH00eYF0P000Woo10001UYF00<0
05YFFUH00eYF00<005YFFUH01UYF0`006Goo00@005YFFUH002moo`00;Goo00D005YFFUIJEP00009o
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP80
0003FUH005YF009JEP03001JEUYF0080009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP80
00Ioo`@0009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00<001Ioo`03001JEP00031oo`00;Goo
00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP<00003FUH005YF00AJEP80
00Yoo`<000IJEP04001JEP000004FUH00`00FUIJEP03FUH3000COol00`00FUH0000`Ool002ioo`04
001JEUYFFUH20004Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH20003FUH20005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH30005FUH2000=Ool20003FUH01000FUIJEUYF0`0000=JEP00FUH025YF1@00
3Goo0`00<Goo000^Ool01000FUIJEP000UYF00<007ooOol017oo0P000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YF000015YF00@005YFFUH0009JEP8000iJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000=JEP8000mo
o`800003FUH005YF009JEP03001JEP0000<000QJEP03001JEUYF009JEPd00003FUH00000035oo`00
;goo00<005YF00000eYF0P001Woo0P0000=JEP00FUH01UYF0`0025YF00@005YFFUH000=JEP04001J
EUYFFUH3000>FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000AOol20003FUH20004Ool30005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000IJEP03001oogoo00Eoo`@0
00AJEPD000MJEP04001JEUYFFUH30006FUH00`00FUIJEP0<FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000<Ool60002
FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<goo000`Ool00`00
FUIJEP05FUH00`00Oomoo`08Ool90006FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF30000eYF00L005YF001JEP00FUH0000:Ool30006FUH0
0`00FUIJEP04FUH01000FUIJEP00=7oo000aOol00`00FUIJEP04FUH3000<Ool70004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0`0015YF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool037oo10000UYF00<005YFFUH00eYF00@005YF
000003Eoo`00<Woo00<005YFFUH00UYF00D005YFFUIJEP0000aoo`<000=oo`h000AJEP03001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00004Goo2P00=goo000cOol20002FUH00`00FUIJEP02FUH00`00Oomoo`0M
Ool20002FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF009JEP8005=oo`00=Goo0P001UYF0P007goo0P000eYF00<007oo
00002EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH30005FUH00`00FUIJEP02FUH2001COol0
03Ioo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF009JEP04001oo`000007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20002FUH20008FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005=oo`00=goo0P001UYF
0`007Woo00D005YFFUIJEP0000=oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<000IJEP8000AJEP04
001JEUYFFUH2001DOol003Uoo`03001JEUYF009JEP04001JEUYFFUH2000LOol00`00FUIJEP020005
Ool30002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEP0015YF00@005YFFUH0009JEP04001JEUYF
FUH2001EOol003Yoo`05001JEUYFFUH00005FUH2000KOol01000FUH0000027oo10002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP05001JEUYFFUH00003FUH01000FUH005YF0P00Egoo000kOol30008FUH3000HOol2
00000eYF001oo`0;Ool40005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUH000040004FUH00`00FUIJEP03FUH30005FUH3001IOol003eoo`03001JEUYF
00MJEP04001JEP00000GOol00`00FUH0000@Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH800000goo0000000;0006FUH00`00Oomoo`1HOol003ioo`8000IJ
EP03001JEUYF009JEP<001Aoo`8001Eoo`L000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@000=oo`D000ioo`03001JEUYF00=JEP8005Uoo`00@7oo0P0015YF00<005YFFUH01EYF0`00
4Goo0P0077oo3@001UYF00<005YFFUH015YF20001goo1@003goo00L005YFFUIJEP00FUH0001IOol0
049oo`800003FUH005YF00QJEP03001JEP0000<000]oo`<002Yoo`d000=JEP03001oogoo00Yoo`<0
015oo`04001JEUYF0002FUH00`00Oomoo`1FOol004Aoo`<000MJEP03001JEUYF00AJEP/00003FUH0
000003=oo`8000IJEP8001moo`8000=JEP03001oogoo05Ioo`00Agoo0P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUIJEP0003Eoo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF
009JEP03001oogoo05Eoo`00BGoo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP80
03Ioo`8000EJEP04001JEP00000NOol00`00FUIJEP02001GOol004aoo`D000AJEP03001JEUYF00AJ
EP03001JEP00008003Uoo`8000=JEP04001JEUYFFUH2000LOol00`00FUIJEP02001GOol0055oo`d0
03ioo`<000IJEP8001]oo`80009JEP03001oogoo05Aoo`00WWoo00<005YFFUH01UYF0`006Goo00@0
05YFFUH005Ioo`00Wgoo0P001UYF00<005YFFUH00`005Woo00<005YF0000Egoo002QOol20004FUH0
0`00FUIJEP03FUH3000COol00`00FUH0001GOol00:=oo`800003FUH005YF00QJEPD000eoo`<005Qo
o`00YGoo0`0025YF00<005YFFUH00UYF3@0000=JEP000000F7oo002XOol30005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000FGoo002[Ool300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00FGoo002^Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP02001JOol00;5o
o`@0009JEP03001JEUYF00=JEP04001JEP00001LOol00;Eoo`X005ioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60557 .74479 m .60164 .68894 L .57054 .68928 L p .707 .577 .707 r
F P
0 g
s
.60164 .68894 m .60557 .74479 L .63734 .74199 L p .707 .577 .707 r
F P
0 g
s
.63734 .74199 m .6334 .68614 L .60164 .68894 L p .707 .577 .707 r
F P
0 g
s
.6334 .68614 m .63734 .74199 L .66666 .73701 L p .707 .577 .707 r
F P
0 g
s
.66666 .73701 m .66273 .68115 L .6334 .68614 L p .707 .577 .707 r
F P
0 g
s
.57448 .74514 m .57054 .68928 L .54317 .68713 L p .707 .577 .707 r
F P
0 g
s
.57054 .68928 m .57448 .74514 L .60557 .74479 L p .707 .577 .707 r
F P
0 g
s
.66273 .68115 m .66666 .73701 L .69068 .73033 L p .707 .577 .707 r
F P
0 g
s
.69068 .73033 m .68674 .67447 L .66273 .68115 L p .707 .577 .707 r
F P
0 g
s
.54317 .68713 m .5471 .74299 L .57448 .74514 L p .707 .577 .707 r
F P
0 g
s
.60129 .81075 m .60745 .77491 L .57672 .76781 L p .707 .577 .707 r
F P
0 g
s
.60745 .77491 m .60129 .81075 L .63273 .81467 L p .707 .577 .707 r
F P
0 g
s
.63273 .81467 m .63889 .77883 L .60745 .77491 L p .707 .577 .707 r
F P
0 g
s
.5471 .74299 m .54317 .68713 L .52218 .6827 L p .707 .577 .707 r
F P
0 g
s
.63889 .77883 m .63273 .81467 L .6618 .81501 L p .707 .577 .707 r
F P
0 g
s
.6618 .81501 m .66796 .77917 L .63889 .77883 L p .707 .577 .707 r
F P
0 g
s
.57056 .80365 m .57672 .76781 L .5497 .75822 L p .707 .577 .707 r
F P
0 g
s
.57672 .76781 m .57056 .80365 L .60129 .81075 L p .707 .577 .707 r
F P
0 g
s
.68674 .67447 m .69068 .73033 L .70704 .7226 L p .707 .577 .707 r
F P
0 g
s
.70704 .7226 m .7031 .66675 L .68674 .67447 L p .707 .577 .707 r
F P
0 g
s
.52218 .6827 m .52612 .73855 L .5471 .74299 L p .707 .577 .707 r
F P
0 g
s
.66796 .77917 m .6618 .81501 L .68565 .81175 L p .707 .577 .707 r
F P
0 g
s
.68565 .81175 m .69181 .77591 L .66796 .77917 L p .707 .577 .707 r
F P
0 g
s
.5497 .75822 m .54354 .79406 L .57056 .80365 L p .707 .577 .707 r
F P
0 g
s
.54354 .79406 m .5497 .75822 L .52904 .74708 L p .707 .577 .707 r
F P
0 g
s
.58685 .86119 m .59428 .84515 L .56577 .83087 L p .707 .577 .707 r
F P
0 g
s
.59428 .84515 m .58685 .86119 L .61629 .87158 L p .707 .577 .707 r
F P
0 g
s
.61629 .87158 m .62372 .85553 L .59428 .84515 L p .707 .577 .707 r
F P
0 g
s
.52612 .73855 m .52218 .6827 L .50965 .67642 L p .707 .577 .707 r
F P
0 g
s
.55834 .84692 m .56577 .83087 L .54098 .8141 L p .707 .577 .707 r
F P
0 g
s
.56577 .83087 m .55834 .84692 L .58685 .86119 L p .707 .577 .707 r
F P
0 g
s
.52904 .74708 m .52288 .78291 L .54354 .79406 L p .707 .577 .707 r
F P
0 g
s
.62372 .85553 m .61629 .87158 L .64376 .87706 L p .707 .577 .707 r
F P
0 g
s
.64376 .87706 m .6512 .86101 L .62372 .85553 L p .707 .577 .707 r
F P
0 g
s
.54098 .8141 m .53354 .83015 L .55834 .84692 L p .707 .577 .707 r
F P
0 g
s
.53354 .83015 m .54098 .8141 L .52232 .79648 L p .707 .577 .707 r
F P
0 g
s
.69181 .77591 m .68565 .81175 L .70195 .80521 L p .707 .577 .707 r
F P
0 g
s
.70195 .80521 m .70811 .76937 L .69181 .77591 L p .707 .577 .707 r
F P
0 g
s
.7031 .66675 m .70704 .7226 L .71413 .7146 L p .707 .577 .707 r
F P
0 g
s
.71413 .7146 m .7102 .65874 L .7031 .66675 L p .707 .577 .707 r
F P
0 g
s
.50965 .67642 m .51358 .73228 L .51827 .73462 L p .707 .577 .707 r
F P
0 g
s
.51358 .73228 m .50965 .67642 L .50679 .66891 L p .707 .577 .707 r
F P
0 g
s
.50679 .66891 m .51072 .72477 L .51175 .72747 L p .707 .577 .707 r
F P
0 g
s
.51175 .72747 m .51358 .73228 L p .51183 .71591 L .707 .577 .707 r
F P
0 g
s
.51183 .71591 m .50679 .66891 L .51175 .72747 L .707 .577 .707 r
F
.51677 .73547 m .51407 .72454 L p .51151 .75913 L F P
0 g
s
.52174 .72204 m .50965 .67642 L .51827 .73462 L .707 .577 .707 r
F
.51407 .72454 m .50791 .76037 L .5106 .77131 L p F P
0 g
s
.51407 .72454 m .52122 .71535 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.50791 .76037 m .51168 .73842 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.51168 .73842 m .51407 .72454 L p .51162 .74781 L .707 .577 .707 r
F P
0 g
s
.5106 .77131 m .51467 .74768 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51467 .74768 m .51677 .73547 L p .51151 .75913 L .707 .577 .707 r
F P
0 g
s
.51827 .73462 m .52612 .73855 L p .52174 .72204 L .707 .577 .707 r
F P
0 g
s
.52288 .78291 m .52904 .74708 L .51677 .73547 L p .707 .577 .707 r
F P
0 g
s
.52232 .79648 m .51489 .81253 L .53354 .83015 L p .707 .577 .707 r
F P
0 g
s
.6512 .86101 m .64376 .87706 L .66659 .8771 L p .707 .577 .707 r
F P
0 g
s
.66659 .8771 m .67403 .86105 L .6512 .86101 L p .707 .577 .707 r
F P
0 g
s
.51677 .73547 m .5106 .77131 L .52288 .78291 L p .707 .577 .707 r
F P
0 g
s
.51489 .81253 m .52232 .79648 L .51163 .77974 L p .707 .577 .707 r
F P
0 g
s
.51163 .77974 m .5042 .79579 L .51489 .81253 L p .707 .577 .707 r
F P
0 g
s
.70811 .76937 m .70195 .80521 L .7091 .79602 L p .707 .577 .707 r
F P
0 g
s
.7091 .79602 m .71526 .76018 L .70811 .76937 L p .707 .577 .707 r
F P
0 g
s
.7102 .65874 m .71413 .7146 L .71127 .70708 L p .707 .577 .707 r
F P
0 g
s
.71127 .70708 m .70734 .65123 L .7102 .65874 L p .707 .577 .707 r
F P
0 g
s
.67403 .86105 m .66659 .8771 L .68254 .87169 L p .707 .577 .707 r
F P
0 g
s
.68254 .87169 m .68997 .85565 L .67403 .86105 L p .707 .577 .707 r
F P
0 g
s
.47349 .82204 m .5007 .32386 L .45675 .31877 L p .707 .577 .707 r
F P
0 g
s
.5042 .79579 m .51163 .77974 L .50996 .76551 L p .707 .577 .707 r
F P
0 g
s
.51072 .72477 m .50679 .66891 L .51388 .6609 L p .707 .577 .707 r
F P
0 g
s
.50996 .76551 m .50253 .78156 L .5042 .79579 L p .707 .577 .707 r
F P
0 g
s
.51388 .6609 m .51782 .71676 L .51072 .72477 L p .707 .577 .707 r
F P
0 g
s
.52122 .71535 m .51506 .75118 L .50791 .76037 L p .707 .577 .707 r
F P
0 g
s
.50253 .78156 m .50996 .76551 L .51746 .75519 L p .707 .577 .707 r
F P
0 g
s
.51746 .75519 m .51003 .77123 L .50253 .78156 L p .707 .577 .707 r
F P
0 g
s
.51506 .75118 m .52122 .71535 L .53752 .7088 L p .707 .577 .707 r
F P
0 g
s
.53752 .7088 m .53136 .74464 L .51506 .75118 L p .707 .577 .707 r
F P
0 g
s
.51003 .77123 m .51746 .75519 L .53341 .74978 L p .707 .577 .707 r
F P
0 g
s
.53341 .74978 m .52598 .76583 L .51003 .77123 L p .707 .577 .707 r
F P
0 g
s
.5007 .32386 m .47349 .82204 L .51838 .82311 L p .707 .577 .707 r
F P
0 g
s
.51782 .71676 m .51388 .6609 L .53024 .65318 L p .707 .577 .707 r
F P
0 g
s
.53024 .65318 m .53417 .70903 L .51782 .71676 L p .707 .577 .707 r
F P
0 g
s
.51838 .82311 m .54558 .32494 L .5007 .32386 L p .707 .577 .707 r
F P
0 g
s
.53417 .70903 m .53024 .65318 L .55425 .6465 L p .707 .577 .707 r
F P
0 g
s
.53136 .74464 m .53752 .7088 L .56137 .70554 L p .707 .577 .707 r
F P
0 g
s
.55425 .6465 m .55819 .70235 L .53417 .70903 L p .707 .577 .707 r
F P
0 g
s
.55819 .70235 m .55425 .6465 L .58358 .64151 L p .707 .577 .707 r
F P
0 g
s
.56137 .70554 m .55521 .74138 L .53136 .74464 L p .707 .577 .707 r
F P
0 g
s
.52598 .76583 m .53341 .74978 L .55624 .74982 L p .707 .577 .707 r
F P
0 g
s
.55624 .74982 m .54881 .76586 L .52598 .76583 L p .707 .577 .707 r
F P
0 g
s
.55521 .74138 m .56137 .70554 L .59044 .70589 L p .707 .577 .707 r
F P
0 g
s
.59044 .70589 m .58428 .74173 L .55521 .74138 L p .707 .577 .707 r
F P
0 g
s
.54881 .76586 m .55624 .74982 L .58372 .7553 L p .707 .577 .707 r
F P
0 g
s
.58372 .7553 m .57629 .77135 L .54881 .76586 L p .707 .577 .707 r
F P
0 g
s
.54558 .32494 m .51838 .82311 L .55981 .82007 L p .707 .577 .707 r
F P
0 g
s
.58358 .64151 m .58752 .69737 L .55819 .70235 L p .707 .577 .707 r
F P
0 g
s
.55981 .82007 m .58702 .32189 L .54558 .32494 L p .707 .577 .707 r
F P
0 g
s
.42955 .81695 m .45675 .31877 L .41806 .31016 L p .707 .577 .707 r
F P
0 g
s
.45675 .31877 m .42955 .81695 L .47349 .82204 L p .707 .577 .707 r
F P
0 g
s
.71526 .76018 m .7091 .79602 L .70641 .78509 L p .707 .577 .707 r
F P
0 g
s
.70641 .78509 m .71257 .74925 L .71526 .76018 L p .707 .577 .707 r
F P
0 g
s
.68997 .85565 m .68254 .87169 L .69005 .86137 L p .707 .577 .707 r
F P
0 g
s
.69005 .86137 m .69748 .84532 L .68997 .85565 L p .707 .577 .707 r
F P
0 g
s
.70734 .65123 m .71127 .70708 L .69874 .70081 L p .707 .577 .707 r
F P
0 g
s
.69874 .70081 m .6948 .64495 L .70734 .65123 L p .707 .577 .707 r
F P
0 g
s
.58752 .69737 m .58358 .64151 L .61534 .63871 L p .707 .577 .707 r
F P
0 g
s
.61534 .63871 m .61928 .69457 L .58752 .69737 L p .707 .577 .707 r
F P
0 g
s
.58428 .74173 m .59044 .70589 L .62188 .7098 L p .707 .577 .707 r
F P
0 g
s
.62188 .7098 m .61572 .74564 L .58428 .74173 L p .707 .577 .707 r
F P
0 g
s
.57629 .77135 m .58372 .7553 L .61315 .76568 L p .707 .577 .707 r
F P
0 g
s
.61315 .76568 m .60572 .78173 L .57629 .77135 L p .707 .577 .707 r
F P
0 g
s
.58702 .32189 m .55981 .82007 L .59374 .8132 L p .707 .577 .707 r
F P
0 g
s
.59374 .8132 m .62094 .31502 L .58702 .32189 L p .707 .577 .707 r
F P
0 g
s
.39085 .80834 m .41806 .31016 L .38839 .29888 L p .707 .577 .707 r
F P
0 g
s
.41806 .31016 m .39085 .80834 L .42955 .81695 L p .707 .577 .707 r
F P
0 g
s
.26256 .71479 m .25863 .65894 L .22754 .65928 L p .707 .577 .707 r
F P
0 g
s
.25863 .65894 m .26256 .71479 L .29433 .71199 L p .707 .577 .707 r
F P
0 g
s
.29433 .71199 m .29039 .65614 L .25863 .65894 L p .707 .577 .707 r
F P
0 g
s
.29039 .65614 m .29433 .71199 L .32365 .70701 L p .707 .577 .707 r
F P
0 g
s
.32365 .70701 m .31972 .65115 L .29039 .65614 L p .707 .577 .707 r
F P
0 g
s
.23147 .71513 m .22754 .65928 L .20016 .65713 L p .707 .577 .707 r
F P
0 g
s
.22754 .65928 m .23147 .71513 L .26256 .71479 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71257 .74925 m .70641 .78509 L .69413 .77348 L p .707 .577 .707 r
F P
0 g
s
.69413 .77348 m .70029 .73764 L .71257 .74925 L p .707 .577 .707 r
F P
0 g
s
.69748 .84532 m .69005 .86137 L .68837 .84714 L p .707 .577 .707 r
F P
0 g
s
.68837 .84714 m .69581 .83109 L .69748 .84532 L p .707 .577 .707 r
F P
0 g
s
.31972 .65115 m .32365 .70701 L .34767 .70033 L p .707 .577 .707 r
F P
0 g
s
.34767 .70033 m .34373 .64447 L .31972 .65115 L p .707 .577 .707 r
F P
0 g
s
.6948 .64495 m .69874 .70081 L .67775 .69637 L p .707 .577 .707 r
F P
0 g
s
.67775 .69637 m .67382 .64052 L .6948 .64495 L p .707 .577 .707 r
F P
0 g
s
.61928 .69457 m .61534 .63871 L .64644 .63837 L p .707 .577 .707 r
F P
0 g
s
.65261 .7169 m .64645 .75274 L .61572 .74564 L p .707 .577 .707 r
F P
0 g
s
.61572 .74564 m .62188 .7098 L .65261 .7169 L p .707 .577 .707 r
F P
0 g
s
.64167 .77996 m .63423 .79601 L .60572 .78173 L p .707 .577 .707 r
F P
0 g
s
.60572 .78173 m .61315 .76568 L .64167 .77996 L p .707 .577 .707 r
F P
0 g
s
.62094 .31502 m .59374 .8132 L .61684 .80318 L p .707 .577 .707 r
F P
0 g
s
.64644 .63837 m .65037 .69423 L .61928 .69457 L p .707 .577 .707 r
F P
0 g
s
.61684 .80318 m .64404 .305 L .62094 .31502 L p .707 .577 .707 r
F P
0 g
s
.20016 .65713 m .20409 .71298 L .23147 .71513 L p .707 .577 .707 r
F P
0 g
s
.25828 .7832 m .26444 .74736 L .23371 .74026 L p .707 .577 .707 r
F P
0 g
s
.26444 .74736 m .25828 .7832 L .28972 .78711 L p .707 .577 .707 r
F P
0 g
s
.28972 .78711 m .29588 .75127 L .26444 .74736 L p .707 .577 .707 r
F P
0 g
s
.20409 .71298 m .20016 .65713 L .17917 .6527 L p .707 .577 .707 r
F P
0 g
s
.29588 .75127 m .28972 .78711 L .31879 .78746 L p .707 .577 .707 r
F P
0 g
s
.31879 .78746 m .32495 .75162 L .29588 .75127 L p .707 .577 .707 r
F P
0 g
s
.22755 .7761 m .23371 .74026 L .20669 .73066 L p .707 .577 .707 r
F P
0 g
s
.23371 .74026 m .22755 .7761 L .25828 .7832 L p .707 .577 .707 r
F P
0 g
s
.34373 .64447 m .34767 .70033 L .36403 .6926 L p .707 .577 .707 r
F P
0 g
s
.36403 .6926 m .36009 .63675 L .34373 .64447 L p .707 .577 .707 r
F P
0 g
s
.36009 .63675 m .36403 .6926 L .37112 .68459 L p .707 .577 .707 r
F P
0 g
s
.37112 .68459 m .36719 .62874 L .36009 .63675 L p .707 .577 .707 r
F P
0 g
s
.35894 .77765 m .3651 .74181 L .3488 .74836 L p .707 .577 .707 r
F P
0 g
s
.3651 .74181 m .35894 .77765 L .36609 .76846 L p .707 .577 .707 r
F P
0 g
s
.36719 .62874 m .37112 .68459 L .36826 .67708 L p .707 .577 .707 r
F P
0 g
s
.36826 .67708 m .36433 .62123 L .36719 .62874 L p .707 .577 .707 r
F P
0 g
s
.36433 .62123 m .36826 .67708 L .3614 .67365 L p .707 .577 .707 r
F P
0 g
s
.3614 .67365 m .35573 .6708 L p .35863 .65407 L .707 .577 .707 r
F P
0 g
s
.35863 .65407 m .36433 .62123 L .3614 .67365 L .707 .577 .707 r
F
.38839 .29888 m .3661 .70694 L p .39085 .80834 L F P
0 g
s
.36609 .76846 m .37225 .73263 L .3651 .74181 L p .707 .577 .707 r
F P
0 g
s
.37225 .73263 m .36609 .76846 L .3634 .75753 L p .707 .577 .707 r
F P
0 g
s
.3634 .75753 m .36956 .72169 L .37225 .73263 L p .707 .577 .707 r
F P
0 g
s
.36956 .72169 m .3634 .75753 L .35638 .7509 L p .707 .577 .707 r
F P
0 g
s
.35638 .7509 m .35112 .74592 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.36106 .73286 m .36956 .72169 L .35638 .7509 L .707 .577 .707 r
F
.35112 .74592 m .35728 .71009 L .36506 .71744 L p F P
0 g
s
.36506 .71744 m .36956 .72169 L p .36106 .73286 L .707 .577 .707 r
F P
0 g
s
.35112 .74592 m .36506 .71744 L .36106 .73286 L .707 .577 .707 r
F
.37985 .80415 m .39085 .80834 L p .36692 .71028 L F P
0 g
s
.36692 .71028 m .3661 .70694 L .3667 .71113 L .707 .577 .707 r
F
.36692 .71028 m .3667 .71113 L .37985 .80415 L F
.36118 .79705 m .37985 .80415 L p .3667 .71113 L F P
0 g
s
.3661 .70694 m .36566 .71515 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36566 .71515 m .36118 .79705 L p .3667 .71113 L .707 .577 .707 r
F P
0 g
s
.36118 .79705 m .38839 .29888 L .37066 .28602 L p .707 .577 .707 r
F P
0 g
s
.17917 .6527 m .18311 .70855 L .20409 .71298 L p .707 .577 .707 r
F P
0 g
s
.70029 .73764 m .69413 .77348 L .67347 .76233 L p .707 .577 .707 r
F P
0 g
s
.67347 .76233 m .67963 .7265 L .70029 .73764 L p .707 .577 .707 r
F P
0 g
s
.67382 .64052 m .67775 .69637 L .65037 .69423 L p .707 .577 .707 r
F P
0 g
s
.65037 .69423 m .64644 .63837 L .67382 .64052 L p .707 .577 .707 r
F P
0 g
s
.32495 .75162 m .31879 .78746 L .34264 .7842 L p .707 .577 .707 r
F P
0 g
s
.34264 .7842 m .3488 .74836 L .32495 .75162 L p .707 .577 .707 r
F P
0 g
s
.20669 .73066 m .20053 .7665 L .22755 .7761 L p .707 .577 .707 r
F P
0 g
s
.20053 .7665 m .20669 .73066 L .18603 .71952 L p .707 .577 .707 r
F P
0 g
s
.69581 .83109 m .68837 .84714 L .67768 .8304 L p .707 .577 .707 r
F P
0 g
s
.67768 .8304 m .68512 .81435 L .69581 .83109 L p .707 .577 .707 r
F P
0 g
s
.24384 .82703 m .25128 .81098 L .22276 .7967 L p .707 .577 .707 r
F P
0 g
s
.25128 .81098 m .24384 .82703 L .27328 .83741 L p .707 .577 .707 r
F P
0 g
s
.27328 .83741 m .28071 .82136 L .25128 .81098 L p .707 .577 .707 r
F P
0 g
s
.18311 .70855 m .17917 .6527 L .16664 .64642 L p .707 .577 .707 r
F P
0 g
s
.21533 .81275 m .22276 .7967 L .19797 .77993 L p .707 .577 .707 r
F P
0 g
s
.22276 .7967 m .21533 .81275 L .24384 .82703 L p .707 .577 .707 r
F P
0 g
s
.28071 .82136 m .27328 .83741 L .30075 .84289 L p .707 .577 .707 r
F P
0 g
s
.30075 .84289 m .30819 .82685 L .28071 .82136 L p .707 .577 .707 r
F P
0 g
s
.18603 .71952 m .17987 .75536 L .20053 .7665 L p .707 .577 .707 r
F P
0 g
s
.19797 .77993 m .19053 .79598 L .21533 .81275 L p .707 .577 .707 r
F P
0 g
s
.64404 .305 m .61684 .80318 L .62685 .79099 L p .707 .577 .707 r
F P
0 g
s
.62685 .79099 m .65405 .29281 L .64404 .305 L p .707 .577 .707 r
F P
0 g
s
.19053 .79598 m .19797 .77993 L .17931 .76231 L p .707 .577 .707 r
F P
0 g
s
.3488 .74836 m .34264 .7842 L .35894 .77765 L p .707 .577 .707 r
F P
0 g
s
.67963 .7265 m .67347 .76233 L .64645 .75274 L p .707 .577 .707 r
F P
0 g
s
.64645 .75274 m .65261 .7169 L .67963 .7265 L p .707 .577 .707 r
F P
0 g
s
.16664 .64642 m .17057 .70228 L .18311 .70855 L p .707 .577 .707 r
F P
0 g
s
.17987 .75536 m .18603 .71952 L .17376 .70791 L p .707 .577 .707 r
F P
0 g
s
.17931 .76231 m .17188 .77836 L .19053 .79598 L p .707 .577 .707 r
F P
0 g
s
.68512 .81435 m .67768 .8304 L .65903 .81278 L p .707 .577 .707 r
F P
0 g
s
.65903 .81278 m .66646 .79673 L .68512 .81435 L p .707 .577 .707 r
F P
0 g
s
.30819 .82685 m .30075 .84289 L .32358 .84293 L p .707 .577 .707 r
F P
0 g
s
.32358 .84293 m .33102 .82688 L .30819 .82685 L p .707 .577 .707 r
F P
0 g
s
.35573 .6708 m .35346 .63859 L p .36433 .62123 L .707 .577 .707 r
F P
0 g
s
.35346 .63859 m .35179 .61495 L .35543 .61677 L p .707 .577 .707 r
F P
0 g
s
.35543 .61677 m .36433 .62123 L p .35346 .63859 L .707 .577 .707 r
F P
0 g
s
.35179 .61495 m .35573 .6708 L .33474 .66637 L p .707 .577 .707 r
F P
0 g
s
.33474 .66637 m .33081 .61052 L .35179 .61495 L p .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .33662 .69894 L .34911 .70568 L p .707 .577 .707 r
F P
0 g
s
.34911 .70568 m .35728 .71009 L p .34855 .71812 L .707 .577 .707 r
F P
0 g
s
.33046 .73478 m .34911 .70568 L .34855 .71812 L .707 .577 .707 r
F
.34661 .71435 m .35715 .52669 L .3666 .27286 L F
.37066 .28602 m .3683 .27837 L p .35715 .52669 L F P
0 g
s
.3683 .27837 m .3666 .27286 L p .35715 .52669 L .707 .577 .707 r
F P
0 g
s
.35728 .71009 m .35112 .74592 L .33046 .73478 L p .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34211 .78018 L .34644 .78697 L p .707 .577 .707 r
F P
0 g
s
.34644 .78697 m .3528 .79692 L p .34659 .79668 L .707 .577 .707 r
F P
0 g
s
.33468 .79623 m .34644 .78697 L .34659 .79668 L .707 .577 .707 r
F
.34567 .7353 m .34827 .69607 L .34661 .71435 L F
.34345 .7842 m .34576 .74186 L p .34567 .7353 L F P
0 g
s
.34576 .74186 m .34827 .69607 L p .34567 .7353 L .707 .577 .707 r
F P
0 g
s
.34827 .69607 m .37066 .28602 L p .34661 .71435 L .707 .577 .707 r
F P
0 g
s
.37066 .28602 m .34345 .7842 L .36118 .79705 L p .707 .577 .707 r
F P
0 g
s
.17376 .70791 m .16759 .74375 L .17987 .75536 L p .707 .577 .707 r
F P
0 g
s
.17057 .70228 m .16664 .64642 L .16378 .63891 L p .707 .577 .707 r
F P
0 g
s
.17188 .77836 m .17931 .76231 L .16862 .74557 L p .707 .577 .707 r
F P
0 g
s
.16862 .74557 m .16119 .76162 L .17188 .77836 L p .707 .577 .707 r
F P
0 g
s
.66646 .79673 m .65903 .81278 L .63423 .79601 L p .707 .577 .707 r
F P
0 g
s
.63423 .79601 m .64167 .77996 L .66646 .79673 L p .707 .577 .707 r
F P
0 g
s
.33102 .82688 m .32358 .84293 L .33953 .83752 L p .707 .577 .707 r
F P
0 g
s
.33953 .83752 m .34697 .82148 L .33102 .82688 L p .707 .577 .707 r
F P
0 g
s
.16887 .69782 m .17057 .70228 L p .16894 .68708 L .707 .577 .707 r
F P
0 g
s
.16759 .74375 m .17376 .70791 L .17106 .69698 L p .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .1649 .73282 L .16526 .73428 L p .707 .577 .707 r
F P
0 g
s
.16526 .73428 m .16759 .74375 L p .16908 .72371 L .707 .577 .707 r
F P
0 g
s
.16908 .72371 m .17106 .69698 L .16526 .73428 L .707 .577 .707 r
F
.16119 .76162 m .16862 .74557 L .16695 .73134 L p F P
0 g
s
.16695 .73134 m .15952 .74739 L .16119 .76162 L p .707 .577 .707 r
F P
0 g
s
.16695 .73134 m .17445 .72102 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.15952 .74739 m .16409 .73751 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.16409 .73751 m .16695 .73134 L p .16229 .74248 L .707 .577 .707 r
F P
0 g
s
.17106 .69698 m .17821 .68779 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1649 .73282 m .1688 .71016 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.1688 .71016 m .17106 .69698 L p .16873 .71985 L .707 .577 .707 r
F P
0 g
s
.16378 .63891 m .16771 .69476 L .16887 .69782 L p .707 .577 .707 r
F P
0 g
s
.16894 .68708 m .16378 .63891 L .16887 .69782 L .707 .577 .707 r
F
.65405 .29281 m .62685 .79099 L .62279 .77782 L p F P
0 g
s
.62279 .77782 m .64999 .27965 L .65405 .29281 L p .707 .577 .707 r
F P
0 g
s
.16771 .69476 m .16378 .63891 L .17087 .6309 L p .707 .577 .707 r
F P
0 g
s
.3666 .27286 m .33939 .77103 L .34345 .7842 L p .707 .577 .707 r
F P
0 g
s
.33939 .77103 m .3666 .27286 L .37661 .26067 L p .707 .577 .707 r
F P
0 g
s
.34697 .82148 m .33953 .83752 L .34704 .8272 L p .707 .577 .707 r
F P
0 g
s
.34704 .8272 m .35447 .81115 L .34697 .82148 L p .707 .577 .707 r
F P
0 g
s
.17087 .6309 m .17481 .68675 L .16771 .69476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17821 .68779 m .17205 .72363 L .1649 .73282 L p .707 .577 .707 r
F P
0 g
s
.17481 .68675 m .17087 .6309 L .18723 .62318 L p .707 .577 .707 r
F P
0 g
s
.19451 .68125 m .19387 .68497 L p .17205 .72363 L .707 .577 .707 r
F P
0 g
s
.16702 .73706 m .17445 .72102 L .1904 .71561 L p .707 .577 .707 r
F P
0 g
s
.19387 .68497 m .18835 .71708 L .17389 .72289 L p .707 .577 .707 r
F P
0 g
s
.17445 .72102 m .17135 .72772 L p .15952 .74739 L .707 .577 .707 r
F P
0 g
s
.17389 .72289 m .17205 .72363 L p .19387 .68497 L .707 .577 .707 r
F P
0 g
s
.17135 .72772 m .16702 .73706 L .16486 .74004 L p .707 .577 .707 r
F P
0 g
s
.16486 .74004 m .15952 .74739 L p .17135 .72772 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64999 .27965 m .62279 .77782 L .60506 .76497 L p .707 .577 .707 r
F P
0 g
s
.60506 .76497 m .63226 .26679 L .64999 .27965 L p .707 .577 .707 r
F P
0 g
s
.35447 .81115 m .34704 .8272 L .34536 .81297 L p .707 .577 .707 r
F P
0 g
s
.34536 .81297 m .3528 .79692 L .35447 .81115 L p .707 .577 .707 r
F P
0 g
s
.17205 .72363 m .17821 .68779 L .19451 .68125 L p .707 .577 .707 r
F P
0 g
s
.18723 .62318 m .19116 .67903 L .17481 .68675 L p .707 .577 .707 r
F P
0 g
s
.3494 .75884 m .37661 .26067 L .39971 .25065 L p .707 .577 .707 r
F P
0 g
s
.37661 .26067 m .3494 .75884 L .33939 .77103 L p .707 .577 .707 r
F P
0 g
s
.19116 .67903 m .18723 .62318 L .21125 .6165 L p .707 .577 .707 r
F P
0 g
s
.21836 .67799 m .21743 .68345 L p .18835 .71708 L .707 .577 .707 r
F P
0 g
s
.18297 .73166 m .1904 .71561 L .21323 .71565 L p .707 .577 .707 r
F P
0 g
s
.21743 .68345 m .2122 .71383 L .19154 .71665 L p .707 .577 .707 r
F P
0 g
s
.1904 .71561 m .18755 .72177 L p .16702 .73706 L .707 .577 .707 r
F P
0 g
s
.19154 .71665 m .18835 .71708 L p .21743 .68345 L .707 .577 .707 r
F P
0 g
s
.18755 .72177 m .18297 .73166 L .17872 .7331 L p .707 .577 .707 r
F P
0 g
s
.17872 .7331 m .16702 .73706 L p .18755 .72177 L .707 .577 .707 r
F P
0 g
s
.33081 .61052 m .33474 .66637 L .30736 .66422 L p .707 .577 .707 r
F P
0 g
s
.30736 .66422 m .30343 .60837 L .33081 .61052 L p .707 .577 .707 r
F P
0 g
s
.3528 .79692 m .34536 .81297 L .33468 .79623 L p .707 .577 .707 r
F P
0 g
s
.18835 .71708 m .19451 .68125 L .21836 .67799 L p .707 .577 .707 r
F P
0 g
s
.21125 .6165 m .21518 .67235 L .19116 .67903 L p .707 .577 .707 r
F P
0 g
s
.63226 .26679 m .60506 .76497 L .57539 .75368 L p .707 .577 .707 r
F P
0 g
s
.57539 .75368 m .6026 .25551 L .63226 .26679 L p .707 .577 .707 r
F P
0 g
s
.21518 .67235 m .21125 .6165 L .24057 .61151 L p .707 .577 .707 r
F P
0 g
s
.30343 .60837 m .30736 .66422 L .27627 .66457 L p .707 .577 .707 r
F P
0 g
s
.27627 .66457 m .27233 .60871 L .30343 .60837 L p .707 .577 .707 r
F P
0 g
s
.39971 .25065 m .3725 .74882 L .3494 .75884 L p .707 .577 .707 r
F P
0 g
s
.3725 .74882 m .39971 .25065 L .43363 .24378 L p .707 .577 .707 r
F P
0 g
s
.24451 .66737 m .24057 .61151 L .27233 .60871 L p .707 .577 .707 r
F P
0 g
s
.24057 .61151 m .24451 .66737 L .21518 .67235 L p .707 .577 .707 r
F P
0 g
s
.21323 .71565 m .2058 .73169 L .18297 .73166 L p .707 .577 .707 r
F P
0 g
s
.33662 .69894 m .33046 .73478 L .30344 .72519 L p .707 .577 .707 r
F P
0 g
s
.30344 .72519 m .3096 .68935 L .33662 .69894 L p .707 .577 .707 r
F P
0 g
s
.74278 .65275 m .73884 .5969 L .70775 .59724 L p .707 .577 .707 r
F P
0 g
s
.73884 .5969 m .74278 .65275 L .77454 .64995 L p .707 .577 .707 r
F P
0 g
s
.77454 .64995 m .77061 .5941 L .73884 .5969 L p .707 .577 .707 r
F P
0 g
s
.27233 .60871 m .27627 .66457 L .24451 .66737 L p .707 .577 .707 r
F P
0 g
s
.2122 .71383 m .21836 .67799 L .24743 .67833 L p .707 .577 .707 r
F P
0 g
s
.77061 .5941 m .77454 .64995 L .80387 .64497 L p .707 .577 .707 r
F P
0 g
s
.80387 .64497 m .79993 .58912 L .77061 .5941 L p .707 .577 .707 r
F P
0 g
s
.34211 .78018 m .33468 .79623 L .31602 .77861 L p .707 .577 .707 r
F P
0 g
s
.31602 .77861 m .32345 .76256 L .34211 .78018 L p .707 .577 .707 r
F P
0 g
s
.71168 .6531 m .70775 .59724 L .68037 .59509 L p .707 .577 .707 r
F P
0 g
s
.70775 .59724 m .71168 .6531 L .74278 .65275 L p .707 .577 .707 r
F P
0 g
s
.3096 .68935 m .30344 .72519 L .27271 .71808 L p .707 .577 .707 r
F P
0 g
s
.27271 .71808 m .27887 .68225 L .3096 .68935 L p .707 .577 .707 r
F P
0 g
s
.79993 .58912 m .80387 .64497 L .82788 .63829 L p .707 .577 .707 r
F P
0 g
s
.82788 .63829 m .82395 .58243 L .79993 .58912 L p .707 .577 .707 r
F P
0 g
s
.24743 .67833 m .24127 .71417 L .2122 .71383 L p .707 .577 .707 r
F P
0 g
s
.2058 .73169 m .21323 .71565 L .24071 .72113 L p .707 .577 .707 r
F P
0 g
s
.24127 .71417 m .24743 .67833 L .27887 .68225 L p .707 .577 .707 r
F P
0 g
s
.6026 .25551 m .57539 .75368 L .53669 .74507 L p .707 .577 .707 r
F P
0 g
s
.53669 .74507 m .5639 .2469 L .6026 .25551 L p .707 .577 .707 r
F P
0 g
s
.27887 .68225 m .27271 .71808 L .24127 .71417 L p .707 .577 .707 r
F P
0 g
s
.68037 .59509 m .68431 .65095 L .71168 .6531 L p .707 .577 .707 r
F P
0 g
s
.7385 .71871 m .74466 .68288 L .71392 .67578 L p .707 .577 .707 r
F P
0 g
s
.74466 .68288 m .7385 .71871 L .76993 .72263 L p .707 .577 .707 r
F P
0 g
s
.76993 .72263 m .7761 .68679 L .74466 .68288 L p .707 .577 .707 r
F P
0 g
s
.24071 .72113 m .23328 .73718 L .2058 .73169 L p .707 .577 .707 r
F P
0 g
s
.32345 .76256 m .31602 .77861 L .29122 .76184 L p .707 .577 .707 r
F P
0 g
s
.29122 .76184 m .29866 .74579 L .32345 .76256 L p .707 .577 .707 r
F P
0 g
s
.68431 .65095 m .68037 .59509 L .65939 .59066 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .43363 .24378 L .47507 .24073 L p .707 .577 .707 r
F P
0 g
s
.40643 .74195 m .3725 .74882 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.41843 .52224 m .40643 .74195 L p .41622 .38766 L .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .44786 .73891 L .40643 .74195 L p .707 .577 .707 r
F P
0 g
s
.40165 .65532 m .39549 .69116 L .42126 .69437 L p .707 .577 .707 r
F P
0 g
s
.42126 .69437 m .42692 .69507 L p .42112 .68594 L .707 .577 .707 r
F P
0 g
s
.42112 .68594 m .40165 .65532 L .42126 .69437 L .707 .577 .707 r
F
.43363 .24378 m .41843 .52224 L p .41622 .38766 L F P
0 g
s
.7761 .68679 m .76993 .72263 L .799 .72297 L p .707 .577 .707 r
F P
0 g
s
.799 .72297 m .80516 .68714 L .7761 .68679 L p .707 .577 .707 r
F P
0 g
s
.70776 .71161 m .71392 .67578 L .68691 .66618 L p .707 .577 .707 r
F P
0 g
s
.71392 .67578 m .70776 .71161 L .7385 .71871 L p .707 .577 .707 r
F P
0 g
s
.23328 .73718 m .24071 .72113 L .27014 .73151 L p .707 .577 .707 r
F P
0 g
s
.82395 .58243 m .82788 .63829 L .84424 .63057 L p .707 .577 .707 r
F P
0 g
s
.84424 .63057 m .8403 .57471 L .82395 .58243 L p .707 .577 .707 r
F P
0 g
s
.29866 .74579 m .29122 .76184 L .26271 .74756 L p .707 .577 .707 r
F P
0 g
s
.26271 .74756 m .27014 .73151 L .29866 .74579 L p .707 .577 .707 r
F P
0 g
s
.27014 .73151 m .26271 .74756 L .23328 .73718 L p .707 .577 .707 r
F P
0 g
s
.65939 .59066 m .66332 .64652 L .68431 .65095 L p .707 .577 .707 r
F P
0 g
s
.5639 .2469 m .53669 .74507 L .49275 .73998 L p .707 .577 .707 r
F P
0 g
s
.49275 .73998 m .51995 .24181 L .5639 .2469 L p .707 .577 .707 r
F P
0 g
s
.80516 .68714 m .799 .72297 L .82285 .71971 L p .707 .577 .707 r
F P
0 g
s
.82285 .71971 m .82902 .68388 L .80516 .68714 L p .707 .577 .707 r
F P
0 g
s
.68691 .66618 m .68074 .70202 L .70776 .71161 L p .707 .577 .707 r
F P
0 g
s
.68074 .70202 m .68691 .66618 L .66625 .65504 L p .707 .577 .707 r
F P
0 g
s
.4276 .5641 m .43153 .61995 L .4448 .6177 L p .707 .577 .707 r
F P
0 g
s
.47507 .24073 m .51995 .24181 L p .46528 .61883 L .707 .577 .707 r
F P
0 g
s
.45799 .66906 m .45929 .63649 L .46528 .61883 L .707 .577 .707 r
F
.45929 .63649 m .47507 .24073 L .46528 .61883 L F
.44786 .73891 m .45234 .657 L p .45799 .66906 L F P
0 g
s
.45234 .657 m .45279 .64879 L p .45379 .65271 L .707 .577 .707 r
F P
0 g
s
.45234 .657 m .45379 .65271 L .45799 .66906 L .707 .577 .707 r
F
.43309 .65923 m .42692 .69507 L .43938 .69522 L p F P
0 g
s
.51995 .24181 m .49275 .73998 L .44786 .73891 L p .707 .577 .707 r
F P
0 g
s
.43938 .69522 m .45599 .69542 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.44513 .67826 m .43309 .65923 L .43938 .69522 L .707 .577 .707 r
F
.45279 .64879 m .47507 .24073 L p .45799 .66906 L F P
0 g
s
.45599 .69542 m .46215 .65958 L .45151 .65945 L p .707 .577 .707 r
F P
0 g
s
.45151 .65945 m .43309 .65923 L p .44513 .67826 L .707 .577 .707 r
F P
0 g
s
.45599 .69542 m .45151 .65945 L .44513 .67826 L .707 .577 .707 r
F
.4448 .6177 m .46086 .61497 L p .43325 .57275 L F P
0 g
s
.43325 .57275 m .4276 .5641 L .4448 .6177 L .707 .577 .707 r
F
.72406 .76916 m .73149 .75311 L .70298 .73883 L p F P
0 g
s
.73149 .75311 m .72406 .76916 L .75349 .77954 L p .707 .577 .707 r
F P
0 g
s
.75349 .77954 m .76092 .7635 L .73149 .75311 L p .707 .577 .707 r
F P
0 g
s
.66332 .64652 m .65939 .59066 L .64685 .58438 L p .707 .577 .707 r
F P
0 g
s
.69554 .75488 m .70298 .73883 L .67818 .72206 L p .707 .577 .707 r
F P
0 g
s
.70298 .73883 m .69554 .75488 L .72406 .76916 L p .707 .577 .707 r
F P
0 g
s
.66625 .65504 m .66009 .69087 L .68074 .70202 L p .707 .577 .707 r
F P
0 g
s
.76092 .7635 m .75349 .77954 L .78097 .78503 L p .707 .577 .707 r
F P
0 g
s
.78097 .78503 m .7884 .76898 L .76092 .7635 L p .707 .577 .707 r
F P
0 g
s
.67818 .72206 m .67075 .73811 L .69554 .75488 L p .707 .577 .707 r
F P
0 g
s
.67075 .73811 m .67818 .72206 L .65952 .70445 L p .707 .577 .707 r
F P
0 g
s
.82902 .68388 m .82285 .71971 L .83915 .71317 L p .707 .577 .707 r
F P
0 g
s
.83915 .71317 m .84531 .67733 L .82902 .68388 L p .707 .577 .707 r
F P
0 g
s
.8403 .57471 m .84424 .63057 L .85134 .62256 L p .707 .577 .707 r
F P
0 g
s
.85134 .62256 m .8474 .5667 L .8403 .57471 L p .707 .577 .707 r
F P
0 g
s
.64685 .58438 m .65079 .64024 L .65547 .64259 L p .707 .577 .707 r
F P
0 g
s
.65079 .64024 m .64685 .58438 L .64399 .57687 L p .707 .577 .707 r
F P
0 g
s
.64399 .57687 m .64793 .63273 L .64896 .63544 L p .707 .577 .707 r
F P
0 g
s
.64896 .63544 m .65079 .64024 L p .64903 .62387 L .707 .577 .707 r
F P
0 g
s
.64903 .62387 m .64399 .57687 L .64896 .63544 L .707 .577 .707 r
F
.65397 .64343 m .65128 .6325 L p .64871 .66709 L F P
0 g
s
.65894 .63 m .64685 .58438 L .65547 .64259 L .707 .577 .707 r
F
.65128 .6325 m .64511 .66833 L .64781 .67927 L p F P
0 g
s
.65128 .6325 m .65843 .62331 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64511 .66833 m .64889 .64639 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64889 .64639 m .65128 .6325 L p .64883 .65577 L .707 .577 .707 r
F P
0 g
s
.64781 .67927 m .65187 .65564 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65187 .65564 m .65397 .64343 L p .64871 .66709 L .707 .577 .707 r
F P
0 g
s
.65547 .64259 m .66332 .64652 L p .65894 .63 L .707 .577 .707 r
F P
0 g
s
.66009 .69087 m .66625 .65504 L .65397 .64343 L p .707 .577 .707 r
F P
0 g
s
.65952 .70445 m .65209 .72049 L .67075 .73811 L p .707 .577 .707 r
F P
0 g
s
.7884 .76898 m .78097 .78503 L .8038 .78506 L p .707 .577 .707 r
F P
0 g
s
.8038 .78506 m .81123 .76902 L .7884 .76898 L p .707 .577 .707 r
F P
0 g
s
.65397 .64343 m .64781 .67927 L .66009 .69087 L p .707 .577 .707 r
F P
0 g
s
.65209 .72049 m .65952 .70445 L .64884 .6877 L p .707 .577 .707 r
F P
0 g
s
.64884 .6877 m .6414 .70375 L .65209 .72049 L p .707 .577 .707 r
F P
0 g
s
.84531 .67733 m .83915 .71317 L .84631 .70398 L p .707 .577 .707 r
F P
0 g
s
.84631 .70398 m .85247 .66814 L .84531 .67733 L p .707 .577 .707 r
F P
0 g
s
.8474 .5667 m .85134 .62256 L .84848 .61505 L p .707 .577 .707 r
F P
0 g
s
.84848 .61505 m .84454 .55919 L .8474 .5667 L p .707 .577 .707 r
F P
0 g
s
.81123 .76902 m .8038 .78506 L .81975 .77966 L p .707 .577 .707 r
F P
0 g
s
.81975 .77966 m .82718 .76361 L .81123 .76902 L p .707 .577 .707 r
F P
0 g
s
.6414 .70375 m .64884 .6877 L .64716 .67347 L p .707 .577 .707 r
F P
0 g
s
.64793 .63273 m .64399 .57687 L .65109 .56886 L p .707 .577 .707 r
F P
0 g
s
.64716 .67347 m .63973 .68952 L .6414 .70375 L p .707 .577 .707 r
F P
0 g
s
.85247 .66814 m .84631 .70398 L .84361 .69305 L p .707 .577 .707 r
F P
0 g
s
.84361 .69305 m .84977 .65721 L .85247 .66814 L p .707 .577 .707 r
F P
0 g
s
.82718 .76361 m .81975 .77966 L .82725 .76933 L p .707 .577 .707 r
F P
0 g
s
.82725 .76933 m .83468 .75328 L .82718 .76361 L p .707 .577 .707 r
F P
0 g
s
.65109 .56886 m .65502 .62472 L .64793 .63273 L p .707 .577 .707 r
F P
0 g
s
.84454 .55919 m .84848 .61505 L .83594 .60877 L p .707 .577 .707 r
F P
0 g
s
.83594 .60877 m .83201 .55291 L .84454 .55919 L p .707 .577 .707 r
F P
0 g
s
.65843 .62331 m .65227 .65915 L .64511 .66833 L p .707 .577 .707 r
F P
0 g
s
.63973 .68952 m .64716 .67347 L .65467 .66315 L p .707 .577 .707 r
F P
0 g
s
.39977 .62275 m .39583 .5669 L .36474 .56724 L p .707 .577 .707 r
F P
0 g
s
.39583 .5669 m .39977 .62275 L .43153 .61995 L p .707 .577 .707 r
F P
0 g
s
.43153 .61995 m .4276 .5641 L .39583 .5669 L p .707 .577 .707 r
F P
0 g
s
.46086 .61497 m .45692 .55911 L .4276 .5641 L p .707 .577 .707 r
F P
0 g
s
.65502 .62472 m .65109 .56886 L .66744 .56114 L p .707 .577 .707 r
F P
0 g
s
.65467 .66315 m .64723 .67919 L .63973 .68952 L p .707 .577 .707 r
F P
0 g
s
.36867 .6231 m .36474 .56724 L .33736 .56509 L p .707 .577 .707 r
F P
0 g
s
.36474 .56724 m .36867 .6231 L .39977 .62275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84977 .65721 m .84361 .69305 L .83133 .68144 L p .707 .577 .707 r
F P
0 g
s
.83133 .68144 m .8375 .6456 L .84977 .65721 L p .707 .577 .707 r
F P
0 g
s
.83468 .75328 m .82725 .76933 L .82558 .7551 L p .707 .577 .707 r
F P
0 g
s
.82558 .7551 m .83301 .73905 L .83468 .75328 L p .707 .577 .707 r
F P
0 g
s
.45692 .55911 m .46086 .61497 L .48487 .60829 L p .707 .577 .707 r
F P
0 g
s
.48487 .60829 m .48094 .55243 L .45692 .55911 L p .707 .577 .707 r
F P
0 g
s
.65227 .65915 m .65843 .62331 L .67473 .61676 L p .707 .577 .707 r
F P
0 g
s
.83201 .55291 m .83594 .60877 L .81496 .60434 L p .707 .577 .707 r
F P
0 g
s
.81496 .60434 m .81102 .54848 L .83201 .55291 L p .707 .577 .707 r
F P
0 g
s
.66744 .56114 m .67138 .61699 L .65502 .62472 L p .707 .577 .707 r
F P
0 g
s
.33736 .56509 m .3413 .62095 L .36867 .6231 L p .707 .577 .707 r
F P
0 g
s
.39549 .69116 m .40165 .65532 L .37091 .64822 L p .707 .577 .707 r
F P
0 g
s
.42692 .69507 m .43309 .65923 L .40165 .65532 L p .707 .577 .707 r
F P
0 g
s
.3413 .62095 m .33736 .56509 L .31638 .56066 L p .707 .577 .707 r
F P
0 g
s
.36475 .68406 m .37091 .64822 L .3439 .63863 L p .707 .577 .707 r
F P
0 g
s
.37091 .64822 m .36475 .68406 L .39549 .69116 L p .707 .577 .707 r
F P
0 g
s
.67473 .61676 m .66857 .6526 L .65227 .65915 L p .707 .577 .707 r
F P
0 g
s
.64723 .67919 m .65467 .66315 L .67062 .65774 L p .707 .577 .707 r
F P
0 g
s
.67138 .61699 m .66744 .56114 L .69146 .55446 L p .707 .577 .707 r
F P
0 g
s
.48094 .55243 m .48487 .60829 L .50123 .60057 L p .707 .577 .707 r
F P
0 g
s
.50123 .60057 m .4973 .54471 L .48094 .55243 L p .707 .577 .707 r
F P
0 g
s
.67062 .65774 m .66318 .67379 L .64723 .67919 L p .707 .577 .707 r
F P
0 g
s
.31638 .56066 m .32031 .61652 L .3413 .62095 L p .707 .577 .707 r
F P
0 g
s
.8375 .6456 m .83133 .68144 L .81067 .6703 L p .707 .577 .707 r
F P
0 g
s
.81067 .6703 m .81684 .63446 L .8375 .6456 L p .707 .577 .707 r
F P
0 g
s
.81102 .54848 m .81496 .60434 L .78758 .60219 L p .707 .577 .707 r
F P
0 g
s
.78758 .60219 m .78364 .54633 L .81102 .54848 L p .707 .577 .707 r
F P
0 g
s
.46215 .65958 m .45599 .69542 L .47984 .69216 L p .707 .577 .707 r
F P
0 g
s
.47984 .69216 m .48601 .65632 L .46215 .65958 L p .707 .577 .707 r
F P
0 g
s
.3439 .63863 m .33773 .67446 L .36475 .68406 L p .707 .577 .707 r
F P
0 g
s
.33773 .67446 m .3439 .63863 L .32324 .62748 L p .707 .577 .707 r
F P
0 g
s
.66857 .6526 m .67473 .61676 L .69858 .61351 L p .707 .577 .707 r
F P
0 g
s
.83301 .73905 m .82558 .7551 L .81489 .73836 L p .707 .577 .707 r
F P
0 g
s
.81489 .73836 m .82232 .72231 L .83301 .73905 L p .707 .577 .707 r
F P
0 g
s
.69146 .55446 m .69539 .61031 L .67138 .61699 L p .707 .577 .707 r
F P
0 g
s
.38105 .73499 m .38848 .71894 L .35997 .70466 L p .707 .577 .707 r
F P
0 g
s
.38848 .71894 m .38105 .73499 L .41048 .74537 L p .707 .577 .707 r
F P
0 g
s
.41048 .74537 m .41791 .72933 L .38848 .71894 L p .707 .577 .707 r
F P
0 g
s
.32031 .61652 m .31638 .56066 L .30384 .55438 L p .707 .577 .707 r
F P
0 g
s
.35253 .72071 m .35997 .70466 L .33517 .68789 L p .707 .577 .707 r
F P
0 g
s
.35997 .70466 m .35253 .72071 L .38105 .73499 L p .707 .577 .707 r
F P
0 g
s
.69539 .61031 m .69146 .55446 L .72078 .54947 L p .707 .577 .707 r
F P
0 g
s
.41791 .72933 m .41048 .74537 L .43796 .75086 L p .707 .577 .707 r
F P
0 g
s
.43796 .75086 m .44539 .73481 L .41791 .72933 L p .707 .577 .707 r
F P
0 g
s
.32324 .62748 m .31708 .66332 L .33773 .67446 L p .707 .577 .707 r
F P
0 g
s
.69858 .61351 m .69242 .64934 L .66857 .6526 L p .707 .577 .707 r
F P
0 g
s
.66318 .67379 m .67062 .65774 L .69345 .65778 L p .707 .577 .707 r
F P
0 g
s
.33517 .68789 m .32774 .70394 L .35253 .72071 L p .707 .577 .707 r
F P
0 g
s
.78364 .54633 m .78758 .60219 L .75648 .60253 L p .707 .577 .707 r
F P
0 g
s
.75648 .60253 m .75255 .54667 L .78364 .54633 L p .707 .577 .707 r
F P
0 g
s
.32774 .70394 m .33517 .68789 L .31651 .67028 L p .707 .577 .707 r
F P
0 g
s
.4973 .54471 m .50123 .60057 L .50833 .59256 L p .707 .577 .707 r
F P
0 g
s
.50833 .59256 m .50439 .5367 L .4973 .54471 L p .707 .577 .707 r
F P
0 g
s
.48601 .65632 m .47984 .69216 L .49614 .68561 L p .707 .577 .707 r
F P
0 g
s
.49614 .68561 m .5023 .64978 L .48601 .65632 L p .707 .577 .707 r
F P
0 g
s
.72472 .60533 m .72078 .54947 L .75255 .54667 L p .707 .577 .707 r
F P
0 g
s
.72078 .54947 m .72472 .60533 L .69539 .61031 L p .707 .577 .707 r
F P
0 g
s
.81684 .63446 m .81067 .6703 L .78366 .6607 L p .707 .577 .707 r
F P
0 g
s
.78366 .6607 m .78982 .62487 L .81684 .63446 L p .707 .577 .707 r
F P
0 g
s
.30384 .55438 m .30777 .61024 L .32031 .61652 L p .707 .577 .707 r
F P
0 g
s
.69345 .65778 m .68601 .67383 L .66318 .67379 L p .707 .577 .707 r
F P
0 g
s
.69242 .64934 m .69858 .61351 L .72765 .61385 L p .707 .577 .707 r
F P
0 g
s
.31708 .66332 m .32324 .62748 L .31096 .61587 L p .707 .577 .707 r
F P
0 g
s
.75255 .54667 m .75648 .60253 L .72472 .60533 L p .707 .577 .707 r
F P
0 g
s
.31651 .67028 m .30908 .68632 L .32774 .70394 L p .707 .577 .707 r
F P
0 g
s
.82232 .72231 m .81489 .73836 L .79623 .72074 L p .707 .577 .707 r
F P
0 g
s
.79623 .72074 m .80367 .70469 L .82232 .72231 L p .707 .577 .707 r
F P
0 g
s
.44539 .73481 m .43796 .75086 L .46079 .75089 L p .707 .577 .707 r
F P
0 g
s
.46079 .75089 m .46822 .73485 L .44539 .73481 L p .707 .577 .707 r
F P
0 g
s
.78982 .62487 m .78366 .6607 L .75292 .6536 L p .707 .577 .707 r
F P
0 g
s
.75292 .6536 m .75909 .61776 L .78982 .62487 L p .707 .577 .707 r
F P
0 g
s
.72765 .61385 m .72148 .64969 L .69242 .64934 L p .707 .577 .707 r
F P
0 g
s
.31096 .61587 m .3048 .65171 L .31708 .66332 L p .707 .577 .707 r
F P
0 g
s
.30777 .61024 m .30384 .55438 L .30098 .54687 L p .707 .577 .707 r
F P
0 g
s
.72148 .64969 m .72765 .61385 L .75909 .61776 L p .707 .577 .707 r
F P
0 g
s
.68601 .67383 m .69345 .65778 L .72092 .66326 L p .707 .577 .707 r
F P
0 g
s
.30908 .68632 m .31651 .67028 L .30583 .65353 L p .707 .577 .707 r
F P
0 g
s
.75909 .61776 m .75292 .6536 L .72148 .64969 L p .707 .577 .707 r
F P
0 g
s
.72092 .66326 m .71349 .67931 L .68601 .67383 L p .707 .577 .707 r
F P
0 g
s
.30583 .65353 m .29839 .66958 L .30908 .68632 L p .707 .577 .707 r
F P
0 g
s
.80367 .70469 m .79623 .72074 L .77144 .70397 L p .707 .577 .707 r
F P
0 g
s
.77144 .70397 m .77887 .68792 L .80367 .70469 L p .707 .577 .707 r
F P
0 g
s
.5023 .64978 m .49614 .68561 L .5033 .67643 L p .707 .577 .707 r
F P
0 g
s
.5033 .67643 m .50946 .64059 L .5023 .64978 L p .707 .577 .707 r
F P
0 g
s
.46822 .73485 m .46079 .75089 L .47674 .74549 L p .707 .577 .707 r
F P
0 g
s
.47674 .74549 m .48417 .72944 L .46822 .73485 L p .707 .577 .707 r
F P
0 g
s
.30608 .60578 m .30777 .61024 L p .30615 .59504 L .707 .577 .707 r
F P
0 g
s
.3048 .65171 m .31096 .61587 L .30827 .60494 L p .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .3021 .64078 L .30246 .64224 L p .707 .577 .707 r
F P
0 g
s
.30246 .64224 m .3048 .65171 L p .30628 .63167 L .707 .577 .707 r
F P
0 g
s
.30628 .63167 m .30827 .60494 L .30246 .64224 L .707 .577 .707 r
F
.29839 .66958 m .30583 .65353 L .30415 .6393 L p F P
0 g
s
.30415 .6393 m .29672 .65535 L .29839 .66958 L p .707 .577 .707 r
F P
0 g
s
.30415 .6393 m .31166 .62898 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.29672 .65535 m .3013 .64547 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.3013 .64547 m .30415 .6393 L p .2995 .65044 L .707 .577 .707 r
F P
0 g
s
.30827 .60494 m .31542 .59575 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.3021 .64078 m .306 .61812 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.306 .61812 m .30827 .60494 L p .30594 .62781 L .707 .577 .707 r
F P
0 g
s
.30098 .54687 m .30491 .60273 L .30608 .60578 L p .707 .577 .707 r
F P
0 g
s
.30615 .59504 m .30098 .54687 L .30608 .60578 L .707 .577 .707 r
F
.50439 .5367 m .50833 .59256 L .50547 .58504 L p F P
0 g
s
.50547 .58504 m .50153 .52919 L .50439 .5367 L p .707 .577 .707 r
F P
0 g
s
.71349 .67931 m .72092 .66326 L .75036 .67365 L p .707 .577 .707 r
F P
0 g
s
.77887 .68792 m .77144 .70397 L .74293 .68969 L p .707 .577 .707 r
F P
0 g
s
.74293 .68969 m .75036 .67365 L .77887 .68792 L p .707 .577 .707 r
F P
0 g
s
.75036 .67365 m .74293 .68969 L .71349 .67931 L p .707 .577 .707 r
F P
0 g
s
.30491 .60273 m .30098 .54687 L .30808 .53886 L p .707 .577 .707 r
F P
0 g
s
.48417 .72944 m .47674 .74549 L .48424 .73516 L p .707 .577 .707 r
F P
0 g
s
.48424 .73516 m .49167 .71911 L .48417 .72944 L p .707 .577 .707 r
F P
0 g
s
.50946 .64059 m .5033 .67643 L .5006 .66549 L p .707 .577 .707 r
F P
0 g
s
.5006 .66549 m .50676 .62965 L .50946 .64059 L p .707 .577 .707 r
F P
0 g
s
.30808 .53886 m .31201 .59472 L .30491 .60273 L p .707 .577 .707 r
F P
0 g
s
.50153 .52919 m .50547 .58504 L .49293 .57877 L p .707 .577 .707 r
F P
0 g
s
.49293 .57877 m .48899 .52291 L .50153 .52919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31542 .59575 m .30926 .63159 L .3021 .64078 L p .707 .577 .707 r
F P
0 g
s
.31201 .59472 m .30808 .53886 L .32443 .53114 L p .707 .577 .707 r
F P
0 g
s
.33172 .58921 m .33108 .59293 L p .30926 .63159 L .707 .577 .707 r
F P
0 g
s
.30422 .64502 m .31166 .62898 L .32761 .62357 L p .707 .577 .707 r
F P
0 g
s
.33108 .59293 m .32556 .62505 L .3111 .63085 L p .707 .577 .707 r
F P
0 g
s
.31166 .62898 m .30855 .63568 L p .29672 .65535 L .707 .577 .707 r
F P
0 g
s
.3111 .63085 m .30926 .63159 L p .33108 .59293 L .707 .577 .707 r
F P
0 g
s
.30855 .63568 m .30422 .64502 L .30206 .648 L p .707 .577 .707 r
F P
0 g
s
.30206 .648 m .29672 .65535 L p .30855 .63568 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49167 .71911 m .48424 .73516 L .48257 .72093 L p .707 .577 .707 r
F P
0 g
s
.48257 .72093 m .49 .70488 L .49167 .71911 L p .707 .577 .707 r
F P
0 g
s
.50676 .62965 m .5006 .66549 L .48832 .65389 L p .707 .577 .707 r
F P
0 g
s
.48832 .65389 m .49449 .61805 L .50676 .62965 L p .707 .577 .707 r
F P
0 g
s
.30926 .63159 m .31542 .59575 L .33172 .58921 L p .707 .577 .707 r
F P
0 g
s
.48899 .52291 m .49293 .57877 L .47195 .57433 L p .707 .577 .707 r
F P
0 g
s
.47195 .57433 m .46801 .51848 L .48899 .52291 L p .707 .577 .707 r
F P
0 g
s
.32443 .53114 m .32837 .58699 L .31201 .59472 L p .707 .577 .707 r
F P
0 g
s
.32837 .58699 m .32443 .53114 L .34845 .52446 L p .707 .577 .707 r
F P
0 g
s
.35557 .58595 m .35463 .59141 L p .32556 .62505 L .707 .577 .707 r
F P
0 g
s
.32017 .63962 m .32761 .62357 L .35044 .62361 L p .707 .577 .707 r
F P
0 g
s
.35463 .59141 m .34941 .62179 L .32874 .62461 L p .707 .577 .707 r
F P
0 g
s
.32761 .62357 m .32475 .62974 L p .30422 .64502 L .707 .577 .707 r
F P
0 g
s
.32874 .62461 m .32556 .62505 L p .35463 .59141 L .707 .577 .707 r
F P
0 g
s
.32475 .62974 m .32017 .63962 L .31592 .64106 L p .707 .577 .707 r
F P
0 g
s
.31592 .64106 m .30422 .64502 L p .32475 .62974 L .707 .577 .707 r
F P
0 g
s
.46801 .51848 m .47195 .57433 L .44457 .57219 L p .707 .577 .707 r
F P
0 g
s
.44457 .57219 m .44063 .51633 L .46801 .51848 L p .707 .577 .707 r
F P
0 g
s
.49449 .61805 m .48832 .65389 L .46766 .64274 L p .707 .577 .707 r
F P
0 g
s
.46766 .64274 m .47383 .6069 L .49449 .61805 L p .707 .577 .707 r
F P
0 g
s
.49 .70488 m .48257 .72093 L .47188 .70419 L p .707 .577 .707 r
F P
0 g
s
.47188 .70419 m .47931 .68814 L .49 .70488 L p .707 .577 .707 r
F P
0 g
s
.32556 .62505 m .33172 .58921 L .35557 .58595 L p .707 .577 .707 r
F P
0 g
s
.34845 .52446 m .35238 .58031 L .32837 .58699 L p .707 .577 .707 r
F P
0 g
s
.35238 .58031 m .34845 .52446 L .37777 .51947 L p .707 .577 .707 r
F P
0 g
s
.44063 .51633 m .44457 .57219 L .41347 .57253 L p .707 .577 .707 r
F P
0 g
s
.41347 .57253 m .40954 .51667 L .44063 .51633 L p .707 .577 .707 r
F P
0 g
s
.38171 .57533 m .37777 .51947 L .40954 .51667 L p .707 .577 .707 r
F P
0 g
s
.37777 .51947 m .38171 .57533 L .35238 .58031 L p .707 .577 .707 r
F P
0 g
s
.35044 .62361 m .343 .63966 L .32017 .63962 L p .707 .577 .707 r
F P
0 g
s
.47383 .6069 m .46766 .64274 L .44065 .63315 L p .707 .577 .707 r
F P
0 g
s
.44065 .63315 m .44681 .59731 L .47383 .6069 L p .707 .577 .707 r
F P
0 g
s
.40954 .51667 m .41347 .57253 L .38171 .57533 L p .707 .577 .707 r
F P
0 g
s
.34941 .62179 m .35557 .58595 L .38464 .58629 L p .707 .577 .707 r
F P
0 g
s
.47931 .68814 m .47188 .70419 L .45322 .68657 L p .707 .577 .707 r
F P
0 g
s
.45322 .68657 m .46066 .67052 L .47931 .68814 L p .707 .577 .707 r
F P
0 g
s
.44681 .59731 m .44065 .63315 L .40991 .62605 L p .707 .577 .707 r
F P
0 g
s
.40991 .62605 m .41607 .59021 L .44681 .59731 L p .707 .577 .707 r
F P
0 g
s
.38464 .58629 m .37847 .62213 L .34941 .62179 L p .707 .577 .707 r
F P
0 g
s
.343 .63966 m .35044 .62361 L .37791 .62909 L p .707 .577 .707 r
F P
0 g
s
.37847 .62213 m .38464 .58629 L .41607 .59021 L p .707 .577 .707 r
F P
0 g
s
.41607 .59021 m .40991 .62605 L .37847 .62213 L p .707 .577 .707 r
F P
0 g
s
.37791 .62909 m .37048 .64514 L .343 .63966 L p .707 .577 .707 r
F P
0 g
s
.46066 .67052 m .45322 .68657 L .42843 .6698 L p .707 .577 .707 r
F P
0 g
s
.42843 .6698 m .43586 .65375 L .46066 .67052 L p .707 .577 .707 r
F P
0 g
s
.37048 .64514 m .37791 .62909 L .40735 .63948 L p .707 .577 .707 r
F P
0 g
s
.43586 .65375 m .42843 .6698 L .39991 .65552 L p .707 .577 .707 r
F P
0 g
s
.39991 .65552 m .40735 .63948 L .43586 .65375 L p .707 .577 .707 r
F P
0 g
s
.40735 .63948 m .39991 .65552 L .37048 .64514 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0081oo`00M7oo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00NWoo001aOol30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001dOol006moo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0071oo`00KGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06ioo`00Jgoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006]oo`00JWoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JGoo
001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001XOol006Qoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUH00000IWoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Eoo`00
J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@0
05YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH0
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo069oo`00J7oo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001S
Ool006Qoo`03001JEP0000EJEP03001JEUYF00IJEP03Ool005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo
00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YF
FUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00@005YFFUH000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00Igoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00@005YFFUH000AJEP03001JEUYF
00AJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Eoo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF01400003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo
00@005YFFUH0009JEPH000AJEP03001JEUYF00IJEP04001JEUYFFUH70007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000<00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00HWoo10001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001NOol400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Uoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00
EWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001EOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000KOolG000eOol005Eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8001=oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080039o
o`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P003Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009Ool400000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000^
Ool005Eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<005YFFUH0
0P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPH000QJEP03001JEUYF00IJEPL000=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP80009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool0
05Ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD0009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00
FUH00004FUH01000FUIJEUYF1`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP@000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol00`00FUH00004FUH400000eYF
0000000>0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000UYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2000
25YF00<005YFFUH015YF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000[Ool005Ioo`03
001JEP0000@00003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004Ool005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000:goo001FOol00`00
FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4
00000eYF001JEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2000017oo001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000
00IJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20000
1Goo001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo00@005YF000000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00Ool00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00eYF5P0015YF
00D005YFFUIJEP0002]oo`00Egoo0P0015YF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P0000AJEP00000000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH0
0`00Oomoo`0YOol004=ooaH000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00Ool200000eYF001JEP02FUH00`00FUIJEP03FUH60008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000020002FUH00`00Oomoo`0YOol003mo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`800003FUH005YF
009JEP03001JEP00018000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000[Ool0
03]oo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001J
EP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL00003FUH005YF00IJEP03001JEUYF
00EJEP07001JEUYFFUH005YF0000:goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH01@00FUIJEUYF000015YF3@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF0`002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000goo00@005YF
001JEP@000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000:goo000dOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP02FUHF0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00
FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00<Woo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0`001EYF00<005YFFUH00UYF1P00
0UYF20001UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`@000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP04001JEUYFFUH2000/Ool0031o
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000D00004FUH00000FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP02FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00D005YFFUIJ
EP0002eoo`00;goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP000000
1EYF10001EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00@005YF000002ioo`00;Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00
0eYF20001eYF00<005YFFUH01EYF10002EYF100000=JEP00FUH01EYF00<005YFFUH00UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF1P0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1@00
<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH200000eYF000000020005FUH00`00FUH000030002FUH00`00FUIJEP07FUH3000:FUH0
0`00FUIJEP020006FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF10000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P00<7oo000^Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP04FUH01000
FUIJEUYF1P001eYF00@005YFFUIJEP8000QJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP80
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8002ioo`00;Woo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH015YF1@001EYF00<005YFFUH0
0eYF0P001UYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00MJEP8000AJEP03001JEUYF00IJEP80
00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP00
00=JEQ/000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0002aoo`00;Woo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP8000UJEP<000UJEPD000=JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP<00006FUH00000001J
EP001EYF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJ
EP04001JEUYFFUH90003FUH01000FUH005YF0P002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P000UYF00@005YF0000009JEPd0019oo`@000MJEP03001JEUYF00=JEP05001JEUYF
FUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH<0002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP80009JEP800003FUH00000008000IJEP03001JEUYF009JEPD0019oo`8000AJEP03
001JEUYF00AJEP05001JEUYFFUH0000[Ool002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUH00003FUH00`00FUH000020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH200000eYF001JEP04FUH01000FUIJEUYF0`00
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P004Goo0`0000=JEP00FUH01EYF00H005YFFUH005YF000Z
Ool002moo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03
001JEP0000AJEP04001JEP00FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0008FUH00`00FUIJEP04FUH01000FUIJEUYF0`002EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF0`00
4Goo0P001UYF00H005YFFUH005YF000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPD000QJ
EP03001JEUYF00IJEP04001JEUYF0003FUH30003FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20006FUH20005FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00009JEP80009JEPT000MJEP03001JEUYF00IJEP80015oo`8000=JEP07
001JEUYFFUH005YF0000:Woo000_Ool00`00FUH00004FUH00`00FUH0000A0008FUH01000FUIJEP00
0UYF00@005YFFUH000IJEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000AJEP04
001JEUYF0004FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00009JEP@00003FUH005YF00AJEP03001JEP0000<0009JEP03001JEUYF00QJ
EP<0015oo`800003FUH005YF009JEP03001JEP0002Yoo`00;goo00<005YF00000eYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH010001EYF00L005YFFUIJEP00FUH00003FUH20003FUH00`00FUIJEP02
00000eYF001JEP06FUH30008FUH01000FUIJEP000eYF00@005YFFUIJEP80009JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH005YF0`000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF100025YF00@005YFFUIJEP80015oo`8000=JEP8002]oo`00;goo
00@005YF001JEP<00003FUH005YF00AJEP8000MJEP03001JEUYF00AJEPH000=JEP8000IJEP04001J
EUYF0002FUH00`00FUH000030004FUH50007FUH01000FUIJEUYF0`001UYF0P000eYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00H005YF000005YF0006FUH00`00
FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP03FUH2000<Ool60002FUH2000[Ool002moo`03
001JEP00008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEP00009JEP03001JEUYF00=JEPT000IJEP03001JEUYF00AJEP03001J
EUYF00EJEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000IJEP00001JEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP07
FUH<0003FUH01`00FUH005YF001JEP0002]oo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJ
EPH000EJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH20009FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001o
o`0ZOol002moo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH20004FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF009JEP<0009JEPl000AJ
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP@00003FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000006FUH01@00
FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000:goo000`Ool20004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YF
FUH00UYF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00@005YFFUIJEP80009JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400001UYF
001JEUYF001JEP@00003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP02FUH01000FUIJEP001EYF00<005YFFUH00UYF0P00;7oo000`Ool20004FUH00`00FUIJEP03FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH20004FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<005YF00000eYF0`001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF0`001EYF00<005YFFUH00UYF0P00;7oo
000`Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH01@00FUIJEUYF000025YF0P002UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF0P001UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF00<005YFFUH00eYF
00L005YFFUIJEP00FUH0000/Ool002moo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP06001JEP00001JEP0025YF0P002UYF
00<005YFFUH01EYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<0009JEP06001JEUYF001JEP001eYF100000=JEP00FUH01eYF00<005YFFUH01UYF0`001EYF
00<005YF000015YF00@005YFFUIJEP8002eoo`00;goo00<005YF00000eYF00<005YFFUH00UYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000=JEP04001JEUYF
FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH60002FUH01000FUIJEP001UYF00@005YFFUIJEP<000IJEP03
001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH01000FUIJEUYF0P00;Woo000_Ool2
0004FUHD0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH20006FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUH00002000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH30004FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPD0009JEP<000IJ
EP03001JEUYF00=JEP<000AJEP04001JEP00FUH2000`Ool002moo`80009JEP@000EJEP03001JEP00
00<000Moo`L000IJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH01000FUIJEUYF0P001Goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF0`00<Woo000_Ool015YF000000000UYF00<005YFFUH0
0eYF00<005YFFUH015YF10000Woo0`001Goo10000UYF00<005YFFUH01EYF00@005YFFUH000=JEP80
00MJEP06001JEP00001JEP002eYF00<005YFFUH01eYF00@005YF000000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000EJEP8000EJEP05001JEUYFFUH00003FUH00`00Oomoo`05
Ool500000goo0000000<0005FUH00`00Oomoo`0aOol002ioo`<000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00H000Qoo`@000EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF
009JEP<000YJEP03001JEUYF00MJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000AJEP04001JEUYF0003FUH01`00FUH00000FUH005YF008000Qoo`D000mo
o`07001JEUYFFUH005YF0000<Woo000^Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH4000<Ool400000eYF001JEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP06FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20004FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000]oo`<0015oo`06001JEUYF
001JEP00<Woo000^Ool200000eYF0000000;0004FUH00`00FUIJEP06FUH2000?Ool20005FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP02FUH@0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20005FUH2000POol20003FUH00`00
Oomoo`0_Ool002ioo`<0009JEP03001JEUYF00AJEP04001JEUYFFUH60007FUH01000FUH000003goo
0P000eYF00<005YFFUH00eYF00<005YFFUH00P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP<001moo`05001JEUYFFUH0000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEPD000EJEP04001JEUYFFUH2000?Ool01000FUIJEP00
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02`001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P001UYF
0P007goo00D005YFFUIJEP00031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH0100000=JEP00FUH01EYF0P003Goo00@005YFFUH000EJEP03001JEUYF00D00003
FUH00000008000MJEP03001JEUYF00=JEP03001JEUYF008000YJEPP000UJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP8000AJEP04001JEP00000NOol00`00FUIJ
EP02000`Ool002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20008FUH2000;Ool01000FUIJEP001EYF0`0015YF00<005YFFUH00eYF10000UYF00<005YFFUH0
15YF0`0000=JEP00FUH02eYF00<005YFFUH00eYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000eYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEP8001eoo`04001JEP00
000`Ool002eoo`800003FUH00000008000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJEP03
001JEP0000/0009JEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH:0003FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH0
1UYF00<005YFFUH00`001UYF0P006goo0P000UYF00<007ooOol0;Goo000]Ool200001EYF001oogoo
00001EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEP04001JEUYFFUH20003FUH0
1@00FUIJEUYF00000UYF00<005YF00000P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF00000P001UYF00<005YFFUH00eYF0P000Woo10001UYF00<0
05YFFUH00eYF00<005YFFUH01UYF0`006Goo00@005YFFUH002moo`00;Goo00D005YFFUIJEP00009o
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP80
0003FUH005YF009JEP03001JEUYF0080009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP80
00Ioo`@0009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00<001Ioo`03001JEP00031oo`00;Goo
00<005YFFUH00UYF00@007ooOomoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000QJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP<00003FUH005YF00AJEP80
00Yoo`<000IJEP04001JEP000004FUH00`00FUIJEP03FUH3000COol00`00FUH0000`Ool002ioo`04
001JEUYFFUH20004Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH20003FUH20005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH30005FUH2000=Ool20003FUH01000FUIJEUYF0`0000=JEP00FUH025YF1@00
3Goo0`00<Goo000^Ool01000FUIJEP000UYF00<007ooOol017oo0P000eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YF000015YF00@005YFFUH0009JEP8000iJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000=JEP8000mo
o`800003FUH005YF009JEP03001JEP0000<000QJEP03001JEUYF009JEPd00003FUH00000035oo`00
;goo00<005YF00000eYF0P001Woo0P0000=JEP00FUH01UYF0`0025YF00@005YFFUH000=JEP04001J
EUYFFUH3000>FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000AOol20003FUH20004Ool30005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000IJEP03001oogoo00Eoo`@0
00AJEPD000MJEP04001JEUYFFUH30006FUH00`00FUIJEP0<FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000<Ool60002
FUH20007Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<goo000`Ool00`00
FUIJEP05FUH00`00Oomoo`08Ool90006FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF30000eYF00L005YF001JEP00FUH0000:Ool30006FUH0
0`00FUIJEP04FUH01000FUIJEP00=7oo000aOol00`00FUIJEP04FUH3000<Ool70004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF0`0015YF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool037oo10000UYF00<005YFFUH00eYF00@005YF
000003Eoo`00<Woo00<005YFFUH00UYF00D005YFFUIJEP0000aoo`<000=oo`h000AJEP03001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYF0002FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00004Goo2P00=goo000cOol20002FUH00`00FUIJEP02FUH00`00Oomoo`0M
Ool20002FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF009JEP8005=oo`00=Goo0P001UYF0P007goo0P000eYF00<007oo
00002EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH30005FUH00`00FUIJEP02FUH2001COol0
03Ioo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF009JEP04001oo`000007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20002FUH20008FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0005=oo`00=goo0P001UYF
0`007Woo00D005YFFUIJEP0000=oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<000IJEP8000AJEP04
001JEUYFFUH2001DOol003Uoo`03001JEUYF009JEP04001JEUYFFUH2000LOol00`00FUIJEP020005
Ool30002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEP0015YF00@005YFFUH0009JEP04001JEUYF
FUH2001EOol003Yoo`05001JEUYFFUH00005FUH2000KOol01000FUH0000027oo10002EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP05001JEUYFFUH00003FUH01000FUH005YF0P00Egoo000kOol30008FUH3000HOol2
00000eYF001oo`0;Ool40005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUH000040004FUH00`00FUIJEP03FUH30005FUH3001IOol003eoo`03001JEUYF
00MJEP04001JEP00000GOol00`00FUH0000@Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH800000goo0000000;0006FUH00`00Oomoo`1HOol003ioo`8000IJ
EP03001JEUYF009JEP<001Aoo`8001Eoo`L000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00@000=oo`D000ioo`03001JEUYF00=JEP8005Uoo`00@7oo0P0015YF00<005YFFUH01EYF0`00
4Goo0P0077oo3@001UYF00<005YFFUH015YF20001goo1@003goo00L005YFFUIJEP00FUH0001IOol0
049oo`800003FUH005YF00QJEP03001JEP0000<000]oo`<002Yoo`d000=JEP03001oogoo00Yoo`<0
015oo`04001JEUYF0002FUH00`00Oomoo`1FOol004Aoo`<000MJEP03001JEUYF00AJEP/00003FUH0
000003=oo`8000IJEP8001moo`8000=JEP03001oogoo05Ioo`00Agoo0P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUIJEP0003Eoo`03001JEUYF00IJEP03001oogoo01eoo`03001JEUYF
009JEP03001oogoo05Eoo`00BGoo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP80
03Ioo`8000EJEP04001JEP00000NOol00`00FUIJEP02001GOol004aoo`D000AJEP03001JEUYF00AJ
EP03001JEP00008003Uoo`8000=JEP04001JEUYFFUH2000LOol00`00FUIJEP02001GOol0055oo`d0
03ioo`<000IJEP8001]oo`80009JEP03001oogoo05Aoo`00WWoo00<005YFFUH01UYF0`006Goo00@0
05YFFUH005Ioo`00Wgoo0P001UYF00<005YFFUH00`005Woo00<005YF0000Egoo002QOol20004FUH0
0`00FUIJEP03FUH3000COol00`00FUH0001GOol00:=oo`800003FUH005YF00QJEPD000eoo`<005Qo
o`00YGoo0`0025YF00<005YFFUH00UYF3@0000=JEP000000F7oo002XOol30005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000FGoo002[Ool300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00FGoo002^Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP02001JOol00;5o
o`@0009JEP03001JEUYF00=JEP04001JEP00001LOol00;Eoo`X005ioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60198 .74661 m .59955 .69082 L .56841 .69031 L p .707 .577 .707 r
F P
0 g
s
.59955 .69082 m .60198 .74661 L .63379 .74458 L p .707 .577 .707 r
F P
0 g
s
.63379 .74458 m .63136 .6888 L .59955 .69082 L p .707 .577 .707 r
F P
0 g
s
.63136 .6888 m .63379 .74458 L .66315 .74021 L p .707 .577 .707 r
F P
0 g
s
.66315 .74021 m .66072 .68443 L .63136 .6888 L p .707 .577 .707 r
F P
0 g
s
.57084 .74609 m .56841 .69031 L .54098 .6873 L p .707 .577 .707 r
F P
0 g
s
.56841 .69031 m .57084 .74609 L .60198 .74661 L p .707 .577 .707 r
F P
0 g
s
.66072 .68443 m .66315 .74021 L .68719 .73393 L p .707 .577 .707 r
F P
0 g
s
.68719 .73393 m .68476 .67814 L .66072 .68443 L p .707 .577 .707 r
F P
0 g
s
.59942 .8105 m .60324 .77406 L .57223 .76893 L p .707 .577 .707 r
F P
0 g
s
.60324 .77406 m .59942 .8105 L .6311 .81264 L p .707 .577 .707 r
F P
0 g
s
.6311 .81264 m .63492 .77621 L .60324 .77406 L p .707 .577 .707 r
F P
0 g
s
.54098 .6873 m .54341 .74309 L .57084 .74609 L p .707 .577 .707 r
F P
0 g
s
.54341 .74309 m .54098 .6873 L .51995 .68209 L p .707 .577 .707 r
F P
0 g
s
.63492 .77621 m .6311 .81264 L .66036 .81158 L p .707 .577 .707 r
F P
0 g
s
.66036 .81158 m .66418 .77514 L .63492 .77621 L p .707 .577 .707 r
F P
0 g
s
.56841 .80536 m .57223 .76893 L .54494 .7613 L p .707 .577 .707 r
F P
0 g
s
.57223 .76893 m .56841 .80536 L .59942 .8105 L p .707 .577 .707 r
F P
0 g
s
.68476 .67814 m .68719 .73393 L .70356 .72634 L p .707 .577 .707 r
F P
0 g
s
.70356 .72634 m .70112 .67055 L .68476 .67814 L p .707 .577 .707 r
F P
0 g
s
.51995 .68209 m .52239 .73788 L .54341 .74309 L p .707 .577 .707 r
F P
0 g
s
.66418 .77514 m .66036 .81158 L .68434 .80741 L p .707 .577 .707 r
F P
0 g
s
.68434 .80741 m .68816 .77098 L .66418 .77514 L p .707 .577 .707 r
F P
0 g
s
.54494 .7613 m .54112 .79773 L .56841 .80536 L p .707 .577 .707 r
F P
0 g
s
.54112 .79773 m .54494 .7613 L .52404 .75193 L p .707 .577 .707 r
F P
0 g
s
.59097 .85797 m .59565 .8406 L .5655 .83083 L p .707 .577 .707 r
F P
0 g
s
.59565 .8406 m .59097 .85797 L .62188 .86429 L p .707 .577 .707 r
F P
0 g
s
.62188 .86429 m .62656 .84692 L .59565 .8406 L p .707 .577 .707 r
F P
0 g
s
.52239 .73788 m .51995 .68209 L .50738 .6752 L p .707 .577 .707 r
F P
0 g
s
.56082 .84821 m .5655 .83083 L .53907 .81857 L p .707 .577 .707 r
F P
0 g
s
.5655 .83083 m .56082 .84821 L .59097 .85797 L p .707 .577 .707 r
F P
0 g
s
.62656 .84692 m .62188 .86429 L .65053 .86655 L p .707 .577 .707 r
F P
0 g
s
.65053 .86655 m .65521 .84917 L .62656 .84692 L p .707 .577 .707 r
F P
0 g
s
.52404 .75193 m .52022 .78836 L .54112 .79773 L p .707 .577 .707 r
F P
0 g
s
.53907 .81857 m .53439 .83595 L .56082 .84821 L p .707 .577 .707 r
F P
0 g
s
.68816 .77098 m .68434 .80741 L .70068 .80056 L p .707 .577 .707 r
F P
0 g
s
.70068 .80056 m .7045 .76413 L .68816 .77098 L p .707 .577 .707 r
F P
0 g
s
.53439 .83595 m .53907 .81857 L .51894 .80502 L p .707 .577 .707 r
F P
0 g
s
.70112 .67055 m .70356 .72634 L .71064 .71819 L p .707 .577 .707 r
F P
0 g
s
.71064 .71819 m .70821 .66241 L .70112 .67055 L p .707 .577 .707 r
F P
0 g
s
.50738 .6752 m .50982 .73099 L .52239 .73788 L p .707 .577 .707 r
F P
0 g
s
.65521 .84917 m .65053 .86655 L .67411 .86451 L p .707 .577 .707 r
F P
0 g
s
.67411 .86451 m .67879 .84714 L .65521 .84917 L p .707 .577 .707 r
F P
0 g
s
.52022 .78836 m .52404 .75193 L .51157 .74173 L p .707 .577 .707 r
F P
0 g
s
.51894 .80502 m .51426 .8224 L .53439 .83595 L p .707 .577 .707 r
F P
0 g
s
.50982 .73099 m .50738 .6752 L .5045 .6673 L p .707 .577 .707 r
F P
0 g
s
.51157 .74173 m .50775 .77816 L .52022 .78836 L p .707 .577 .707 r
F P
0 g
s
.51426 .8224 m .51894 .80502 L .50709 .79151 L p .707 .577 .707 r
F P
0 g
s
.67879 .84714 m .67411 .86451 L .69031 .85839 L p .707 .577 .707 r
F P
0 g
s
.69031 .85839 m .695 .84101 L .67879 .84714 L p .707 .577 .707 r
F P
0 g
s
.7045 .76413 m .70068 .80056 L .70779 .79168 L p .707 .577 .707 r
F P
0 g
s
.70779 .79168 m .71161 .75525 L .7045 .76413 L p .707 .577 .707 r
F P
0 g
s
.50709 .79151 m .5024 .80888 L .51426 .8224 L p .707 .577 .707 r
F P
0 g
s
.5045 .6673 m .50693 .72308 L .50982 .73099 L p .707 .577 .707 r
F P
0 g
s
.70821 .66241 m .71064 .71819 L .70776 .71029 L p .707 .577 .707 r
F P
0 g
s
.70776 .71029 m .70533 .6545 L .70821 .66241 L p .707 .577 .707 r
F P
0 g
s
.50775 .77816 m .51157 .74173 L .50875 .7317 L p .707 .577 .707 r
F P
0 g
s
.47998 .82206 m .4968 .32228 L .45281 .3181 L p .707 .577 .707 r
F P
0 g
s
.50875 .7317 m .50493 .76813 L .50775 .77816 L p .707 .577 .707 r
F P
0 g
s
.50693 .72308 m .5045 .6673 L .51159 .65915 L p .707 .577 .707 r
F P
0 g
s
.5024 .80888 m .50709 .79151 L .50466 .77935 L p .707 .577 .707 r
F P
0 g
s
.50466 .77935 m .49998 .79672 L .5024 .80888 L p .707 .577 .707 r
F P
0 g
s
.51159 .65915 m .51402 .71494 L .50693 .72308 L p .707 .577 .707 r
F P
0 g
s
.50493 .76813 m .50875 .7317 L .51586 .72282 L p .707 .577 .707 r
F P
0 g
s
.51586 .72282 m .51204 .75925 L .50493 .76813 L p .707 .577 .707 r
F P
0 g
s
.51402 .71494 m .51159 .65915 L .52795 .65156 L p .707 .577 .707 r
F P
0 g
s
.49998 .79672 m .50466 .77935 L .51191 .76974 L p .707 .577 .707 r
F P
0 g
s
.51191 .76974 m .50722 .78711 L .49998 .79672 L p .707 .577 .707 r
F P
0 g
s
.52795 .65156 m .53039 .70735 L .51402 .71494 L p .707 .577 .707 r
F P
0 g
s
.51204 .75925 m .51586 .72282 L .5322 .71597 L p .707 .577 .707 r
F P
0 g
s
.5322 .71597 m .52838 .7524 L .51204 .75925 L p .707 .577 .707 r
F P
0 g
s
.50722 .78711 m .51191 .76974 L .52811 .76362 L p .707 .577 .707 r
F P
0 g
s
.52811 .76362 m .52343 .78099 L .50722 .78711 L p .707 .577 .707 r
F P
0 g
s
.4968 .32228 m .47998 .82206 L .5249 .8223 L p .707 .577 .707 r
F P
0 g
s
.53039 .70735 m .52795 .65156 L .55199 .64528 L p .707 .577 .707 r
F P
0 g
s
.52343 .78099 m .52811 .76362 L .55169 .76158 L p .707 .577 .707 r
F P
0 g
s
.55169 .76158 m .54701 .77896 L .52343 .78099 L p .707 .577 .707 r
F P
0 g
s
.5249 .8223 m .54172 .32252 L .4968 .32228 L p .707 .577 .707 r
F P
0 g
s
.55199 .64528 m .55442 .70106 L .53039 .70735 L p .707 .577 .707 r
F P
0 g
s
.52838 .7524 m .5322 .71597 L .55618 .7118 L p .707 .577 .707 r
F P
0 g
s
.55442 .70106 m .55199 .64528 L .58135 .64091 L p .707 .577 .707 r
F P
0 g
s
.55618 .7118 m .55236 .74824 L .52838 .7524 L p .707 .577 .707 r
F P
0 g
s
.58135 .64091 m .58378 .69669 L .55442 .70106 L p .707 .577 .707 r
F P
0 g
s
.55236 .74824 m .55618 .7118 L .58544 .71074 L p .707 .577 .707 r
F P
0 g
s
.58544 .71074 m .58162 .74717 L .55236 .74824 L p .707 .577 .707 r
F P
0 g
s
.54701 .77896 m .55169 .76158 L .58034 .76383 L p .707 .577 .707 r
F P
0 g
s
.58034 .76383 m .57566 .78121 L .54701 .77896 L p .707 .577 .707 r
F P
0 g
s
.54172 .32252 m .5249 .8223 L .56636 .8186 L p .707 .577 .707 r
F P
0 g
s
.56636 .8186 m .58318 .31882 L .54172 .32252 L p .707 .577 .707 r
F P
0 g
s
.695 .84101 m .69031 .85839 L .69756 .84878 L p .707 .577 .707 r
F P
0 g
s
.69756 .84878 m .70224 .8314 L .695 .84101 L p .707 .577 .707 r
F P
0 g
s
.43599 .81788 m .45281 .3181 L .41407 .31041 L p .707 .577 .707 r
F P
0 g
s
.45281 .3181 m .43599 .81788 L .47998 .82206 L p .707 .577 .707 r
F P
0 g
s
.71161 .75525 m .70779 .79168 L .70497 .78165 L p .707 .577 .707 r
F P
0 g
s
.70497 .78165 m .70879 .74522 L .71161 .75525 L p .707 .577 .707 r
F P
0 g
s
.70533 .6545 m .70776 .71029 L .69519 .70339 L p .707 .577 .707 r
F P
0 g
s
.69519 .70339 m .69276 .64761 L .70533 .6545 L p .707 .577 .707 r
F P
0 g
s
.58378 .69669 m .58135 .64091 L .61316 .63888 L p .707 .577 .707 r
F P
0 g
s
.61316 .63888 m .61559 .69467 L .58378 .69669 L p .707 .577 .707 r
F P
0 g
s
.58162 .74717 m .58544 .71074 L .61712 .71288 L p .707 .577 .707 r
F P
0 g
s
.61712 .71288 m .6133 .74932 L .58162 .74717 L p .707 .577 .707 r
F P
0 g
s
.57566 .78121 m .58034 .76383 L .61125 .77015 L p .707 .577 .707 r
F P
0 g
s
.61125 .77015 m .60657 .78753 L .57566 .78121 L p .707 .577 .707 r
F P
0 g
s
.58318 .31882 m .56636 .8186 L .60031 .81131 L p .707 .577 .707 r
F P
0 g
s
.60031 .81131 m .61713 .31153 L .58318 .31882 L p .707 .577 .707 r
F P
0 g
s
.39725 .81019 m .41407 .31041 L .38437 .29996 L p .707 .577 .707 r
F P
0 g
s
.41407 .31041 m .39725 .81019 L .43599 .81788 L p .707 .577 .707 r
F P
0 g
s
.25898 .714 m .25654 .65822 L .2254 .6577 L p .707 .577 .707 r
F P
0 g
s
.25654 .65822 m .25898 .714 L .29078 .71198 L p .707 .577 .707 r
F P
0 g
s
.29078 .71198 m .28835 .65619 L .25654 .65822 L p .707 .577 .707 r
F P
0 g
s
.28835 .65619 m .29078 .71198 L .32014 .70761 L p .707 .577 .707 r
F P
0 g
s
.32014 .70761 m .31771 .65182 L .28835 .65619 L p .707 .577 .707 r
F P
0 g
s
.70224 .8314 m .69756 .84878 L .69513 .83662 L p .707 .577 .707 r
F P
0 g
s
.69513 .83662 m .69982 .81925 L .70224 .8314 L p .707 .577 .707 r
F P
0 g
s
.22783 .71349 m .2254 .6577 L .19797 .6547 L p .707 .577 .707 r
F P
0 g
s
.2254 .6577 m .22783 .71349 L .25898 .714 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70879 .74522 m .70497 .78165 L .6925 .77145 L p .707 .577 .707 r
F P
0 g
s
.6925 .77145 m .69632 .73502 L .70879 .74522 L p .707 .577 .707 r
F P
0 g
s
.31771 .65182 m .32014 .70761 L .34418 .70132 L p .707 .577 .707 r
F P
0 g
s
.34418 .70132 m .34175 .64554 L .31771 .65182 L p .707 .577 .707 r
F P
0 g
s
.69276 .64761 m .69519 .70339 L .67416 .69819 L p .707 .577 .707 r
F P
0 g
s
.67416 .69819 m .67173 .6424 L .69276 .64761 L p .707 .577 .707 r
F P
0 g
s
.6443 .6394 m .64674 .69518 L .61559 .69467 L p .707 .577 .707 r
F P
0 g
s
.61559 .69467 m .61316 .63888 L .6443 .6394 L p .707 .577 .707 r
F P
0 g
s
.64813 .71802 m .64431 .75445 L .6133 .74932 L p .707 .577 .707 r
F P
0 g
s
.6133 .74932 m .61712 .71288 L .64813 .71802 L p .707 .577 .707 r
F P
0 g
s
.6414 .77992 m .63671 .7973 L .60657 .78753 L p .707 .577 .707 r
F P
0 g
s
.60657 .78753 m .61125 .77015 L .6414 .77992 L p .707 .577 .707 r
F P
0 g
s
.61713 .31153 m .60031 .81131 L .62341 .80114 L p .707 .577 .707 r
F P
0 g
s
.62341 .80114 m .64023 .30136 L .61713 .31153 L p .707 .577 .707 r
F P
0 g
s
.19797 .6547 m .20041 .71048 L .22783 .71349 L p .707 .577 .707 r
F P
0 g
s
.25641 .7794 m .26023 .74297 L .22922 .73784 L p .707 .577 .707 r
F P
0 g
s
.26023 .74297 m .25641 .7794 L .28809 .78155 L p .707 .577 .707 r
F P
0 g
s
.28809 .78155 m .29191 .74511 L .26023 .74297 L p .707 .577 .707 r
F P
0 g
s
.20041 .71048 m .19797 .6547 L .17694 .64949 L p .707 .577 .707 r
F P
0 g
s
.29191 .74511 m .28809 .78155 L .31735 .78048 L p .707 .577 .707 r
F P
0 g
s
.31735 .78048 m .32117 .74405 L .29191 .74511 L p .707 .577 .707 r
F P
0 g
s
.2254 .77427 m .22922 .73784 L .20193 .73021 L p .707 .577 .707 r
F P
0 g
s
.22922 .73784 m .2254 .77427 L .25641 .7794 L p .707 .577 .707 r
F P
0 g
s
.35811 .63795 m .36055 .69373 L .36764 .68559 L p .707 .577 .707 r
F P
0 g
s
.36764 .68559 m .3652 .6298 L .35811 .63795 L p .707 .577 .707 r
F P
0 g
s
.36478 .76059 m .3686 .72416 L .36149 .73303 L p .707 .577 .707 r
F P
0 g
s
.3652 .6298 m .36764 .68559 L .36475 .67768 L p .707 .577 .707 r
F P
0 g
s
.36149 .73303 m .35767 .76947 L .36478 .76059 L p .707 .577 .707 r
F P
0 g
s
.3686 .72416 m .36478 .76059 L .36196 .75056 L p .707 .577 .707 r
F P
0 g
s
.36196 .75056 m .36578 .71413 L .3686 .72416 L p .707 .577 .707 r
F P
0 g
s
.36755 .79974 m .38437 .29996 L .36661 .28776 L p .707 .577 .707 r
F P
0 g
s
.38437 .29996 m .36755 .79974 L .39725 .81019 L p .707 .577 .707 r
F P
0 g
s
.34175 .64554 m .34418 .70132 L .36055 .69373 L p .707 .577 .707 r
F P
0 g
s
.36055 .69373 m .35811 .63795 L .34175 .64554 L p .707 .577 .707 r
F P
0 g
s
.69982 .81925 m .69513 .83662 L .68328 .82311 L p .707 .577 .707 r
F P
0 g
s
.68328 .82311 m .68796 .80573 L .69982 .81925 L p .707 .577 .707 r
F P
0 g
s
.17694 .64949 m .17938 .70528 L .20041 .71048 L p .707 .577 .707 r
F P
0 g
s
.32117 .74405 m .31735 .78048 L .34133 .77632 L p .707 .577 .707 r
F P
0 g
s
.34133 .77632 m .34515 .73989 L .32117 .74405 L p .707 .577 .707 r
F P
0 g
s
.20193 .73021 m .19811 .76664 L .2254 .77427 L p .707 .577 .707 r
F P
0 g
s
.69632 .73502 m .6925 .77145 L .67159 .76208 L p .707 .577 .707 r
F P
0 g
s
.67159 .76208 m .67542 .72565 L .69632 .73502 L p .707 .577 .707 r
F P
0 g
s
.67173 .6424 m .67416 .69819 L .64674 .69518 L p .707 .577 .707 r
F P
0 g
s
.64674 .69518 m .6443 .6394 L .67173 .6424 L p .707 .577 .707 r
F P
0 g
s
.24796 .82279 m .25264 .80542 L .2225 .79565 L p .707 .577 .707 r
F P
0 g
s
.25264 .80542 m .24796 .82279 L .27887 .82911 L p .707 .577 .707 r
F P
0 g
s
.27887 .82911 m .28355 .81174 L .25264 .80542 L p .707 .577 .707 r
F P
0 g
s
.19811 .76664 m .20193 .73021 L .18103 .72084 L p .707 .577 .707 r
F P
0 g
s
.21781 .81303 m .2225 .79565 L .19606 .78339 L p .707 .577 .707 r
F P
0 g
s
.2225 .79565 m .21781 .81303 L .24796 .82279 L p .707 .577 .707 r
F P
0 g
s
.17938 .70528 m .17694 .64949 L .16437 .6426 L p .707 .577 .707 r
F P
0 g
s
.28355 .81174 m .27887 .82911 L .30752 .83137 L p .707 .577 .707 r
F P
0 g
s
.30752 .83137 m .3122 .81399 L .28355 .81174 L p .707 .577 .707 r
F P
0 g
s
.19606 .78339 m .19138 .80077 L .21781 .81303 L p .707 .577 .707 r
F P
0 g
s
.18103 .72084 m .17721 .75727 L .19811 .76664 L p .707 .577 .707 r
F P
0 g
s
.64023 .30136 m .62341 .80114 L .63342 .7891 L p .707 .577 .707 r
F P
0 g
s
.63342 .7891 m .65023 .28932 L .64023 .30136 L p .707 .577 .707 r
F P
0 g
s
.34515 .73989 m .34133 .77632 L .35767 .76947 L p .707 .577 .707 r
F P
0 g
s
.35767 .76947 m .36149 .73303 L .34515 .73989 L p .707 .577 .707 r
F P
0 g
s
.19138 .80077 m .19606 .78339 L .17593 .76984 L p .707 .577 .707 r
F P
0 g
s
.16437 .6426 m .16681 .69838 L .17938 .70528 L p .707 .577 .707 r
F P
0 g
s
.3122 .81399 m .30752 .83137 L .3311 .82933 L p .707 .577 .707 r
F P
0 g
s
.3311 .82933 m .33578 .81196 L .3122 .81399 L p .707 .577 .707 r
F P
0 g
s
.67542 .72565 m .67159 .76208 L .64431 .75445 L p .707 .577 .707 r
F P
0 g
s
.64431 .75445 m .64813 .71802 L .67542 .72565 L p .707 .577 .707 r
F P
0 g
s
.68796 .80573 m .68328 .82311 L .66315 .80956 L p .707 .577 .707 r
F P
0 g
s
.66315 .80956 m .66783 .79218 L .68796 .80573 L p .707 .577 .707 r
F P
0 g
s
.17721 .75727 m .18103 .72084 L .16856 .71064 L p .707 .577 .707 r
F P
0 g
s
.17593 .76984 m .17125 .78722 L .19138 .80077 L p .707 .577 .707 r
F P
0 g
s
.36232 .6219 m .36475 .67768 L .35218 .67079 L p .707 .577 .707 r
F P
0 g
s
.35218 .67079 m .34975 .61501 L .36232 .6219 L p .707 .577 .707 r
F P
0 g
s
.36578 .71413 m .36196 .75056 L .35413 .74415 L p .707 .577 .707 r
F P
0 g
s
.35413 .74415 m .34949 .74036 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.35433 .73257 m .36578 .71413 L .35413 .74415 L .707 .577 .707 r
F
.36661 .28776 m .36253 .27501 L p .36154 .31489 L F P
0 g
s
.34949 .74036 m .35331 .70393 L .3548 .70515 L p .707 .577 .707 r
F P
0 g
s
.3548 .70515 m .36578 .71413 L p .35433 .73257 L .707 .577 .707 r
F P
0 g
s
.34949 .74036 m .3548 .70515 L .35433 .73257 L .707 .577 .707 r
F
.34975 .61501 m .35218 .67079 L .33115 .66559 L p F P
0 g
s
.35213 .80144 m .34027 .78793 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35681 .78407 m .35403 .79437 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.35403 .79437 m .35213 .80144 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .34495 .77055 L .35386 .7807 L p .707 .577 .707 r
F P
0 g
s
.35386 .7807 m .35681 .78407 L p .35391 .78474 L .707 .577 .707 r
F P
0 g
s
.34027 .78793 m .35386 .7807 L .35391 .78474 L .707 .577 .707 r
F
.36191 .29349 m .35161 .59958 L p .36154 .31489 L F P
0 g
s
.35331 .70393 m .34949 .74036 L .32859 .73099 L p .707 .577 .707 r
F P
0 g
s
.32859 .73099 m .33241 .69455 L .35331 .70393 L p .707 .577 .707 r
F P
0 g
s
.35161 .59958 m .34571 .77479 L p .35165 .60243 L .707 .577 .707 r
F P
0 g
s
.36154 .31489 m .35161 .59958 L .35165 .60243 L .707 .577 .707 r
F
.34571 .77479 m .34979 .78754 L p .35256 .67613 L F P
0 g
s
.35256 .67613 m .36154 .31489 L .35165 .60243 L .707 .577 .707 r
F
.35256 .67613 m .35165 .60243 L .34571 .77479 L F
.36253 .27501 m .36191 .29349 L p .36154 .31489 L F P
0 g
s
.34979 .78754 m .35716 .56852 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.35716 .56852 m .36661 .28776 L p .36154 .31489 L .707 .577 .707 r
F P
0 g
s
.36475 .67768 m .36232 .6219 L .3652 .6298 L p .707 .577 .707 r
F P
0 g
s
.35213 .80144 m .35681 .78407 L .35923 .79622 L p .707 .577 .707 r
F P
0 g
s
.36661 .28776 m .34979 .78754 L .36755 .79974 L p .707 .577 .707 r
F P
0 g
s
.16681 .69838 m .16437 .6426 L .16149 .63469 L p .707 .577 .707 r
F P
0 g
s
.16856 .71064 m .16474 .74707 L .17721 .75727 L p .707 .577 .707 r
F P
0 g
s
.17125 .78722 m .17593 .76984 L .16408 .75633 L p .707 .577 .707 r
F P
0 g
s
.33578 .81196 m .3311 .82933 L .3473 .82321 L p .707 .577 .707 r
F P
0 g
s
.3473 .82321 m .35199 .80583 L .33578 .81196 L p .707 .577 .707 r
F P
0 g
s
.66783 .79218 m .66315 .80956 L .63671 .7973 L p .707 .577 .707 r
F P
0 g
s
.63671 .7973 m .6414 .77992 L .66783 .79218 L p .707 .577 .707 r
F P
0 g
s
.16408 .75633 m .15939 .7737 L .17125 .78722 L p .707 .577 .707 r
F P
0 g
s
.16149 .63469 m .16392 .69048 L .16681 .69838 L p .707 .577 .707 r
F P
0 g
s
.16474 .74707 m .16856 .71064 L .16574 .70061 L p .707 .577 .707 r
F P
0 g
s
.65023 .28932 m .63342 .7891 L .62934 .77635 L p .707 .577 .707 r
F P
0 g
s
.62934 .77635 m .64616 .27657 L .65023 .28932 L p .707 .577 .707 r
F P
0 g
s
.16574 .70061 m .16192 .73704 L .16474 .74707 L p .707 .577 .707 r
F P
0 g
s
.16392 .69048 m .16149 .63469 L .16858 .62655 L p .707 .577 .707 r
F P
0 g
s
.15939 .7737 m .16408 .75633 L .16165 .74417 L p .707 .577 .707 r
F P
0 g
s
.35199 .80583 m .3473 .82321 L .35455 .8136 L p .707 .577 .707 r
F P
0 g
s
.35455 .8136 m .35923 .79622 L .35199 .80583 L p .707 .577 .707 r
F P
0 g
s
.16165 .74417 m .15697 .76154 L .15939 .7737 L p .707 .577 .707 r
F P
0 g
s
.34571 .77479 m .36253 .27501 L .37254 .26297 L p .707 .577 .707 r
F P
0 g
s
.16858 .62655 m .17101 .68233 L .16392 .69048 L p .707 .577 .707 r
F P
0 g
s
.16192 .73704 m .16574 .70061 L .17285 .69173 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17285 .69173 m .16903 .72816 L .16192 .73704 L p .707 .577 .707 r
F P
0 g
s
.17101 .68233 m .16858 .62655 L .18494 .61896 L p .707 .577 .707 r
F P
0 g
s
.15697 .76154 m .16165 .74417 L .1689 .73456 L p .707 .577 .707 r
F P
0 g
s
.35923 .79622 m .35455 .8136 L .35213 .80144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64616 .27657 m .62934 .77635 L .61158 .76416 L p .707 .577 .707 r
F P
0 g
s
.61158 .76416 m .6284 .26438 L .64616 .27657 L p .707 .577 .707 r
F P
0 g
s
.1689 .73456 m .16421 .75193 L .15697 .76154 L p .707 .577 .707 r
F P
0 g
s
.33115 .66559 m .32872 .6098 L .34975 .61501 L p .707 .577 .707 r
F P
0 g
s
.18494 .61896 m .18738 .67475 L .17101 .68233 L p .707 .577 .707 r
F P
0 g
s
.16903 .72816 m .17285 .69173 L .18919 .68487 L p .707 .577 .707 r
F P
0 g
s
.35572 .76275 m .37254 .26297 L .39564 .2528 L p .707 .577 .707 r
F P
0 g
s
.37254 .26297 m .35572 .76275 L .34571 .77479 L p .707 .577 .707 r
F P
0 g
s
.18738 .67475 m .18494 .61896 L .20898 .61267 L p .707 .577 .707 r
F P
0 g
s
.18919 .68487 m .18537 .72131 L .16903 .72816 L p .707 .577 .707 r
F P
0 g
s
.16421 .75193 m .1689 .73456 L .1851 .72844 L p .707 .577 .707 r
F P
0 g
s
.1851 .72844 m .18042 .74581 L .16421 .75193 L p .707 .577 .707 r
F P
0 g
s
.32872 .6098 m .33115 .66559 L .30373 .66258 L p .707 .577 .707 r
F P
0 g
s
.30373 .66258 m .30129 .60679 L .32872 .6098 L p .707 .577 .707 r
F P
0 g
s
.20898 .61267 m .21141 .66846 L .18738 .67475 L p .707 .577 .707 r
F P
0 g
s
.18537 .72131 m .18919 .68487 L .21317 .68071 L p .707 .577 .707 r
F P
0 g
s
.6284 .26438 m .61158 .76416 L .58188 .7537 L p .707 .577 .707 r
F P
0 g
s
.58188 .7537 m .59869 .25392 L .6284 .26438 L p .707 .577 .707 r
F P
0 g
s
.21141 .66846 m .20898 .61267 L .23834 .6083 L p .707 .577 .707 r
F P
0 g
s
.30129 .60679 m .30373 .66258 L .27258 .66206 L p .707 .577 .707 r
F P
0 g
s
.27258 .66206 m .27015 .60628 L .30129 .60679 L p .707 .577 .707 r
F P
0 g
s
.21317 .68071 m .20935 .71714 L .18537 .72131 L p .707 .577 .707 r
F P
0 g
s
.18042 .74581 m .1851 .72844 L .20868 .7264 L p .707 .577 .707 r
F P
0 g
s
.39564 .2528 m .37882 .75258 L .35572 .76275 L p .707 .577 .707 r
F P
0 g
s
.37882 .75258 m .39564 .2528 L .42959 .24551 L p .707 .577 .707 r
F P
0 g
s
.24078 .66409 m .23834 .6083 L .27015 .60628 L p .707 .577 .707 r
F P
0 g
s
.23834 .6083 m .24078 .66409 L .21141 .66846 L p .707 .577 .707 r
F P
0 g
s
.34495 .77055 m .34027 .78793 L .32014 .77438 L p .707 .577 .707 r
F P
0 g
s
.32014 .77438 m .32482 .757 L .34495 .77055 L p .707 .577 .707 r
F P
0 g
s
.33241 .69455 m .32859 .73099 L .3013 .72336 L p .707 .577 .707 r
F P
0 g
s
.3013 .72336 m .30512 .68693 L .33241 .69455 L p .707 .577 .707 r
F P
0 g
s
.73919 .65457 m .73676 .59878 L .70561 .59827 L p .707 .577 .707 r
F P
0 g
s
.73676 .59878 m .73919 .65457 L .771 .65254 L p .707 .577 .707 r
F P
0 g
s
.771 .65254 m .76856 .59676 L .73676 .59878 L p .707 .577 .707 r
F P
0 g
s
.27015 .60628 m .27258 .66206 L .24078 .66409 L p .707 .577 .707 r
F P
0 g
s
.76856 .59676 m .771 .65254 L .80036 .64817 L p .707 .577 .707 r
F P
0 g
s
.80036 .64817 m .79792 .59239 L .76856 .59676 L p .707 .577 .707 r
F P
0 g
s
.20868 .7264 m .204 .74378 L .18042 .74581 L p .707 .577 .707 r
F P
0 g
s
.20935 .71714 m .21317 .68071 L .24243 .67965 L p .707 .577 .707 r
F P
0 g
s
.70805 .65405 m .70561 .59827 L .67819 .59526 L p .707 .577 .707 r
F P
0 g
s
.70561 .59827 m .70805 .65405 L .73919 .65457 L p .707 .577 .707 r
F P
0 g
s
.30512 .68693 m .3013 .72336 L .27029 .71822 L p .707 .577 .707 r
F P
0 g
s
.27029 .71822 m .27411 .68179 L .30512 .68693 L p .707 .577 .707 r
F P
0 g
s
.79792 .59239 m .80036 .64817 L .8244 .64189 L p .707 .577 .707 r
F P
0 g
s
.8244 .64189 m .82196 .5861 L .79792 .59239 L p .707 .577 .707 r
F P
0 g
s
.24243 .67965 m .23861 .71608 L .20935 .71714 L p .707 .577 .707 r
F P
0 g
s
.23861 .71608 m .24243 .67965 L .27411 .68179 L p .707 .577 .707 r
F P
0 g
s
.59869 .25392 m .58188 .7537 L .54314 .74601 L p .707 .577 .707 r
F P
0 g
s
.54314 .74601 m .55996 .24623 L .59869 .25392 L p .707 .577 .707 r
F P
0 g
s
.204 .74378 m .20868 .7264 L .23733 .72865 L p .707 .577 .707 r
F P
0 g
s
.32482 .757 m .32014 .77438 L .29371 .76212 L p .707 .577 .707 r
F P
0 g
s
.29371 .76212 m .29839 .74474 L .32482 .757 L p .707 .577 .707 r
F P
0 g
s
.27411 .68179 m .27029 .71822 L .23861 .71608 L p .707 .577 .707 r
F P
0 g
s
.73662 .71846 m .74044 .68203 L .70944 .67689 L p .707 .577 .707 r
F P
0 g
s
.74044 .68203 m .73662 .71846 L .7683 .7206 L p .707 .577 .707 r
F P
0 g
s
.7683 .7206 m .77212 .68417 L .74044 .68203 L p .707 .577 .707 r
F P
0 g
s
.67819 .59526 m .68062 .65105 L .70805 .65405 L p .707 .577 .707 r
F P
0 g
s
.68062 .65105 m .67819 .59526 L .65716 .59006 L p .707 .577 .707 r
F P
0 g
s
.23733 .72865 m .23265 .74603 L .204 .74378 L p .707 .577 .707 r
F P
0 g
s
.77212 .68417 m .7683 .7206 L .79757 .71954 L p .707 .577 .707 r
F P
0 g
s
.79757 .71954 m .80139 .68311 L .77212 .68417 L p .707 .577 .707 r
F P
0 g
s
.41277 .74529 m .42959 .24551 L .47105 .24181 L p .707 .577 .707 r
F P
0 g
s
.42959 .24551 m .41277 .74529 L .37882 .75258 L p .707 .577 .707 r
F P
0 g
s
.70562 .71332 m .70944 .67689 L .68215 .66926 L p .707 .577 .707 r
F P
0 g
s
.70944 .67689 m .70562 .71332 L .73662 .71846 L p .707 .577 .707 r
F P
0 g
s
.23265 .74603 m .23733 .72865 L .26824 .73497 L p .707 .577 .707 r
F P
0 g
s
.29839 .74474 m .29371 .76212 L .26356 .75235 L p .707 .577 .707 r
F P
0 g
s
.26356 .75235 m .26824 .73497 L .29839 .74474 L p .707 .577 .707 r
F P
0 g
s
.82196 .5861 m .8244 .64189 L .84076 .6343 L p .707 .577 .707 r
F P
0 g
s
.84076 .6343 m .83833 .57851 L .82196 .5861 L p .707 .577 .707 r
F P
0 g
s
.26824 .73497 m .26356 .75235 L .23265 .74603 L p .707 .577 .707 r
F P
0 g
s
.65716 .59006 m .65959 .64584 L .68062 .65105 L p .707 .577 .707 r
F P
0 g
s
.80139 .68311 m .79757 .71954 L .82154 .71537 L p .707 .577 .707 r
F P
0 g
s
.82154 .71537 m .82536 .67894 L .80139 .68311 L p .707 .577 .707 r
F P
0 g
s
.55996 .24623 m .54314 .74601 L .49915 .74184 L p .707 .577 .707 r
F P
0 g
s
.49915 .74184 m .51597 .24206 L .55996 .24623 L p .707 .577 .707 r
F P
0 g
s
.68215 .66926 m .67833 .7057 L .70562 .71332 L p .707 .577 .707 r
F P
0 g
s
.67833 .7057 m .68215 .66926 L .66124 .65989 L p .707 .577 .707 r
F P
0 g
s
.72817 .76594 m .73286 .74856 L .70271 .73879 L p .707 .577 .707 r
F P
0 g
s
.73286 .74856 m .72817 .76594 L .75908 .77225 L p .707 .577 .707 r
F P
0 g
s
.75908 .77225 m .76377 .75488 L .73286 .74856 L p .707 .577 .707 r
F P
0 g
s
.45423 .74159 m .46156 .52368 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.47105 .24181 m .45423 .74159 L .41277 .74529 L p .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .45838 .65201 L .43489 .65287 L p .707 .577 .707 r
F P
0 g
s
.43489 .65287 m .42911 .65307 L p .43356 .65926 L .707 .577 .707 r
F P
0 g
s
.45456 .68844 m .43489 .65287 L .43356 .65926 L .707 .577 .707 r
F
.47105 .24181 m .51597 .24206 L p .51038 .28729 L F P
0 g
s
.46156 .52368 m .47105 .24181 L p .51038 .28729 L .707 .577 .707 r
F P
0 g
s
.65959 .64584 m .65716 .59006 L .64459 .58316 L p .707 .577 .707 r
F P
0 g
s
.69803 .75617 m .70271 .73879 L .67628 .72653 L p .707 .577 .707 r
F P
0 g
s
.70271 .73879 m .69803 .75617 L .72817 .76594 L p .707 .577 .707 r
F P
0 g
s
.51597 .24206 m .49915 .74184 L .45423 .74159 L p .707 .577 .707 r
F P
0 g
s
.76377 .75488 m .75908 .77225 L .78773 .77451 L p .707 .577 .707 r
F P
0 g
s
.78773 .77451 m .79241 .75713 L .76377 .75488 L p .707 .577 .707 r
F P
0 g
s
.66124 .65989 m .65742 .69632 L .67833 .7057 L p .707 .577 .707 r
F P
0 g
s
.67628 .72653 m .67159 .74391 L .69803 .75617 L p .707 .577 .707 r
F P
0 g
s
.82536 .67894 m .82154 .71537 L .83788 .70852 L p .707 .577 .707 r
F P
0 g
s
.83788 .70852 m .84171 .67209 L .82536 .67894 L p .707 .577 .707 r
F P
0 g
s
.67159 .74391 m .67628 .72653 L .65615 .71298 L p .707 .577 .707 r
F P
0 g
s
.83833 .57851 m .84076 .6343 L .84785 .62615 L p .707 .577 .707 r
F P
0 g
s
.84785 .62615 m .84542 .57037 L .83833 .57851 L p .707 .577 .707 r
F P
0 g
s
.64459 .58316 m .64702 .63895 L .65959 .64584 L p .707 .577 .707 r
F P
0 g
s
.79241 .75713 m .78773 .77451 L .81131 .77247 L p .707 .577 .707 r
F P
0 g
s
.81131 .77247 m .81599 .7551 L .79241 .75713 L p .707 .577 .707 r
F P
0 g
s
.65742 .69632 m .66124 .65989 L .64877 .64969 L p .707 .577 .707 r
F P
0 g
s
.65615 .71298 m .65146 .73036 L .67159 .74391 L p .707 .577 .707 r
F P
0 g
s
.64702 .63895 m .64459 .58316 L .6417 .57526 L p .707 .577 .707 r
F P
0 g
s
.64877 .64969 m .64495 .68612 L .65742 .69632 L p .707 .577 .707 r
F P
0 g
s
.65146 .73036 m .65615 .71298 L .64429 .69947 L p .707 .577 .707 r
F P
0 g
s
.81599 .7551 m .81131 .77247 L .82752 .76635 L p .707 .577 .707 r
F P
0 g
s
.82752 .76635 m .8322 .74898 L .81599 .7551 L p .707 .577 .707 r
F P
0 g
s
.84171 .67209 m .83788 .70852 L .84499 .69964 L p .707 .577 .707 r
F P
0 g
s
.84499 .69964 m .84881 .66321 L .84171 .67209 L p .707 .577 .707 r
F P
0 g
s
.64429 .69947 m .63961 .71684 L .65146 .73036 L p .707 .577 .707 r
F P
0 g
s
.6417 .57526 m .64414 .63104 L .64702 .63895 L p .707 .577 .707 r
F P
0 g
s
.84542 .57037 m .84785 .62615 L .84497 .61825 L p .707 .577 .707 r
F P
0 g
s
.84497 .61825 m .84253 .56246 L .84542 .57037 L p .707 .577 .707 r
F P
0 g
s
.64495 .68612 m .64877 .64969 L .64595 .63966 L p .707 .577 .707 r
F P
0 g
s
.64595 .63966 m .64213 .67609 L .64495 .68612 L p .707 .577 .707 r
F P
0 g
s
.64414 .63104 m .6417 .57526 L .64879 .56711 L p .707 .577 .707 r
F P
0 g
s
.63961 .71684 m .64429 .69947 L .64186 .68731 L p .707 .577 .707 r
F P
0 g
s
.8322 .74898 m .82752 .76635 L .83476 .75674 L p .707 .577 .707 r
F P
0 g
s
.83476 .75674 m .83945 .73937 L .8322 .74898 L p .707 .577 .707 r
F P
0 g
s
.64186 .68731 m .63718 .70469 L .63961 .71684 L p .707 .577 .707 r
F P
0 g
s
.84881 .66321 m .84499 .69964 L .84218 .68961 L p .707 .577 .707 r
F P
0 g
s
.84218 .68961 m .846 .65318 L .84881 .66321 L p .707 .577 .707 r
F P
0 g
s
.64879 .56711 m .65122 .6229 L .64414 .63104 L p .707 .577 .707 r
F P
0 g
s
.84253 .56246 m .84497 .61825 L .8324 .61136 L p .707 .577 .707 r
F P
0 g
s
.8324 .61136 m .82996 .55557 L .84253 .56246 L p .707 .577 .707 r
F P
0 g
s
.64213 .67609 m .64595 .63966 L .65306 .63078 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39618 .62197 m .39375 .56618 L .3626 .56566 L p .707 .577 .707 r
F P
0 g
s
.39375 .56618 m .39618 .62197 L .42799 .61994 L p .707 .577 .707 r
F P
0 g
s
.42799 .61994 m .42555 .56415 L .39375 .56618 L p .707 .577 .707 r
F P
0 g
s
.65306 .63078 m .64924 .66722 L .64213 .67609 L p .707 .577 .707 r
F P
0 g
s
.42555 .56415 m .42799 .61994 L .45735 .61557 L p .707 .577 .707 r
F P
0 g
s
.45735 .61557 m .45491 .55978 L .42555 .56415 L p .707 .577 .707 r
F P
0 g
s
.65122 .6229 m .64879 .56711 L .66516 .55953 L p .707 .577 .707 r
F P
0 g
s
.63718 .70469 m .64186 .68731 L .64911 .6777 L p .707 .577 .707 r
F P
0 g
s
.83945 .73937 m .83476 .75674 L .83234 .74458 L p .707 .577 .707 r
F P
0 g
s
.83234 .74458 m .83702 .72721 L .83945 .73937 L p .707 .577 .707 r
F P
0 g
s
.36504 .62145 m .3626 .56566 L .33518 .56266 L p .707 .577 .707 r
F P
0 g
s
.3626 .56566 m .36504 .62145 L .39618 .62197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64911 .6777 m .64443 .69508 L .63718 .70469 L p .707 .577 .707 r
F P
0 g
s
.846 .65318 m .84218 .68961 L .8297 .67941 L p .707 .577 .707 r
F P
0 g
s
.8297 .67941 m .83352 .64298 L .846 .65318 L p .707 .577 .707 r
F P
0 g
s
.45491 .55978 m .45735 .61557 L .48139 .60928 L p .707 .577 .707 r
F P
0 g
s
.48139 .60928 m .47895 .5535 L .45491 .55978 L p .707 .577 .707 r
F P
0 g
s
.82996 .55557 m .8324 .61136 L .81137 .60615 L p .707 .577 .707 r
F P
0 g
s
.81137 .60615 m .80893 .55037 L .82996 .55557 L p .707 .577 .707 r
F P
0 g
s
.66516 .55953 m .66759 .61531 L .65122 .6229 L p .707 .577 .707 r
F P
0 g
s
.64924 .66722 m .65306 .63078 L .6694 .62393 L p .707 .577 .707 r
F P
0 g
s
.33518 .56266 m .33761 .61844 L .36504 .62145 L p .707 .577 .707 r
F P
0 g
s
.39361 .68737 m .39743 .65093 L .36643 .6458 L p .707 .577 .707 r
F P
0 g
s
.39743 .65093 m .39361 .68737 L .42529 .68951 L p .707 .577 .707 r
F P
0 g
s
.42529 .68951 m .42911 .65307 L .39743 .65093 L p .707 .577 .707 r
F P
0 g
s
.33761 .61844 m .33518 .56266 L .31415 .55745 L p .707 .577 .707 r
F P
0 g
s
.42911 .65307 m .42529 .68951 L .45456 .68844 L p .707 .577 .707 r
F P
0 g
s
.36261 .68223 m .36643 .6458 L .33914 .63817 L p .707 .577 .707 r
F P
0 g
s
.36643 .6458 m .36261 .68223 L .39361 .68737 L p .707 .577 .707 r
F P
0 g
s
.66759 .61531 m .66516 .55953 L .6892 .55324 L p .707 .577 .707 r
F P
0 g
s
.6694 .62393 m .66558 .66036 L .64924 .66722 L p .707 .577 .707 r
F P
0 g
s
.64443 .69508 m .64911 .6777 L .66532 .67158 L p .707 .577 .707 r
F P
0 g
s
.47895 .5535 m .48139 .60928 L .49775 .6017 L p .707 .577 .707 r
F P
0 g
s
.49775 .6017 m .49532 .54591 L .47895 .5535 L p .707 .577 .707 r
F P
0 g
s
.83702 .72721 m .83234 .74458 L .82048 .73107 L p .707 .577 .707 r
F P
0 g
s
.82048 .73107 m .82516 .71369 L .83702 .72721 L p .707 .577 .707 r
F P
0 g
s
.31415 .55745 m .31658 .61324 L .33761 .61844 L p .707 .577 .707 r
F P
0 g
s
.45838 .65201 m .45456 .68844 L .47853 .68428 L p .707 .577 .707 r
F P
0 g
s
.47853 .68428 m .48235 .64785 L .45838 .65201 L p .707 .577 .707 r
F P
0 g
s
.33914 .63817 m .33532 .6746 L .36261 .68223 L p .707 .577 .707 r
F P
0 g
s
.83352 .64298 m .8297 .67941 L .8088 .67004 L p .707 .577 .707 r
F P
0 g
s
.8088 .67004 m .81262 .63361 L .83352 .64298 L p .707 .577 .707 r
F P
0 g
s
.66532 .67158 m .66063 .68895 L .64443 .69508 L p .707 .577 .707 r
F P
0 g
s
.80893 .55037 m .81137 .60615 L .78394 .60314 L p .707 .577 .707 r
F P
0 g
s
.78394 .60314 m .78151 .54736 L .80893 .55037 L p .707 .577 .707 r
F P
0 g
s
.38516 .73076 m .38985 .71338 L .3597 .70361 L p .707 .577 .707 r
F P
0 g
s
.38985 .71338 m .38516 .73076 L .41607 .73707 L p .707 .577 .707 r
F P
0 g
s
.41607 .73707 m .42076 .7197 L .38985 .71338 L p .707 .577 .707 r
F P
0 g
s
.33532 .6746 m .33914 .63817 L .31823 .6288 L p .707 .577 .707 r
F P
0 g
s
.6892 .55324 m .69163 .60903 L .66759 .61531 L p .707 .577 .707 r
F P
0 g
s
.66558 .66036 m .6694 .62393 L .69338 .61977 L p .707 .577 .707 r
F P
0 g
s
.35502 .72099 m .3597 .70361 L .33327 .69135 L p .707 .577 .707 r
F P
0 g
s
.3597 .70361 m .35502 .72099 L .38516 .73076 L p .707 .577 .707 r
F P
0 g
s
.31658 .61324 m .31415 .55745 L .30158 .55056 L p .707 .577 .707 r
F P
0 g
s
.42076 .7197 m .41607 .73707 L .44472 .73933 L p .707 .577 .707 r
F P
0 g
s
.44472 .73933 m .4494 .72195 L .42076 .7197 L p .707 .577 .707 r
F P
0 g
s
.69163 .60903 m .6892 .55324 L .71856 .54887 L p .707 .577 .707 r
F P
0 g
s
.33327 .69135 m .32858 .70873 L .35502 .72099 L p .707 .577 .707 r
F P
0 g
s
.31823 .6288 m .31441 .66523 L .33532 .6746 L p .707 .577 .707 r
F P
0 g
s
.78151 .54736 m .78394 .60314 L .7528 .60263 L p .707 .577 .707 r
F P
0 g
s
.7528 .60263 m .75036 .54684 L .78151 .54736 L p .707 .577 .707 r
F P
0 g
s
.69338 .61977 m .68956 .6562 L .66558 .66036 L p .707 .577 .707 r
F P
0 g
s
.48235 .64785 m .47853 .68428 L .49487 .67743 L p .707 .577 .707 r
F P
0 g
s
.49487 .67743 m .4987 .64099 L .48235 .64785 L p .707 .577 .707 r
F P
0 g
s
.32858 .70873 m .33327 .69135 L .31314 .6778 L p .707 .577 .707 r
F P
0 g
s
.66063 .68895 m .66532 .67158 L .6889 .66954 L p .707 .577 .707 r
F P
0 g
s
.49532 .54591 m .49775 .6017 L .50484 .59355 L p .707 .577 .707 r
F P
0 g
s
.50484 .59355 m .50241 .53776 L .49532 .54591 L p .707 .577 .707 r
F P
0 g
s
.72099 .60465 m .71856 .54887 L .75036 .54684 L p .707 .577 .707 r
F P
0 g
s
.71856 .54887 m .72099 .60465 L .69163 .60903 L p .707 .577 .707 r
F P
0 g
s
.30158 .55056 m .30401 .60635 L .31658 .61324 L p .707 .577 .707 r
F P
0 g
s
.4494 .72195 m .44472 .73933 L .4683 .73729 L p .707 .577 .707 r
F P
0 g
s
.4683 .73729 m .47298 .71992 L .4494 .72195 L p .707 .577 .707 r
F P
0 g
s
.81262 .63361 m .8088 .67004 L .78151 .66241 L p .707 .577 .707 r
F P
0 g
s
.78151 .66241 m .78533 .62598 L .81262 .63361 L p .707 .577 .707 r
F P
0 g
s
.82516 .71369 m .82048 .73107 L .80035 .71752 L p .707 .577 .707 r
F P
0 g
s
.80035 .71752 m .80503 .70014 L .82516 .71369 L p .707 .577 .707 r
F P
0 g
s
.75036 .54684 m .7528 .60263 L .72099 .60465 L p .707 .577 .707 r
F P
0 g
s
.31441 .66523 m .31823 .6288 L .30576 .6186 L p .707 .577 .707 r
F P
0 g
s
.68956 .6562 m .69338 .61977 L .72264 .6187 L p .707 .577 .707 r
F P
0 g
s
.31314 .6778 m .30845 .69518 L .32858 .70873 L p .707 .577 .707 r
F P
0 g
s
.6889 .66954 m .68422 .68692 L .66063 .68895 L p .707 .577 .707 r
F P
0 g
s
.30401 .60635 m .30158 .55056 L .29869 .54265 L p .707 .577 .707 r
F P
0 g
s
.30576 .6186 m .30194 .65503 L .31441 .66523 L p .707 .577 .707 r
F P
0 g
s
.78533 .62598 m .78151 .66241 L .75051 .65728 L p .707 .577 .707 r
F P
0 g
s
.75051 .65728 m .75433 .62084 L .78533 .62598 L p .707 .577 .707 r
F P
0 g
s
.72264 .6187 m .71882 .65514 L .68956 .6562 L p .707 .577 .707 r
F P
0 g
s
.71882 .65514 m .72264 .6187 L .75433 .62084 L p .707 .577 .707 r
F P
0 g
s
.30845 .69518 m .31314 .6778 L .30128 .66429 L p .707 .577 .707 r
F P
0 g
s
.68422 .68692 m .6889 .66954 L .71755 .6718 L p .707 .577 .707 r
F P
0 g
s
.75433 .62084 m .75051 .65728 L .71882 .65514 L p .707 .577 .707 r
F P
0 g
s
.47298 .71992 m .4683 .73729 L .48451 .73117 L p .707 .577 .707 r
F P
0 g
s
.48451 .73117 m .48919 .7138 L .47298 .71992 L p .707 .577 .707 r
F P
0 g
s
.80503 .70014 m .80035 .71752 L .77392 .70526 L p .707 .577 .707 r
F P
0 g
s
.77392 .70526 m .7786 .68788 L .80503 .70014 L p .707 .577 .707 r
F P
0 g
s
.4987 .64099 m .49487 .67743 L .50198 .66855 L p .707 .577 .707 r
F P
0 g
s
.50198 .66855 m .5058 .63212 L .4987 .64099 L p .707 .577 .707 r
F P
0 g
s
.30128 .66429 m .2966 .68166 L .30845 .69518 L p .707 .577 .707 r
F P
0 g
s
.71755 .6718 m .71286 .68917 L .68422 .68692 L p .707 .577 .707 r
F P
0 g
s
.29869 .54265 m .30113 .59844 L .30401 .60635 L p .707 .577 .707 r
F P
0 g
s
.50241 .53776 m .50484 .59355 L .50196 .58564 L p .707 .577 .707 r
F P
0 g
s
.50196 .58564 m .49952 .52986 L .50241 .53776 L p .707 .577 .707 r
F P
0 g
s
.30194 .65503 m .30576 .6186 L .30294 .60857 L p .707 .577 .707 r
F P
0 g
s
.71286 .68917 m .71755 .6718 L .74846 .67812 L p .707 .577 .707 r
F P
0 g
s
.7786 .68788 m .77392 .70526 L .74377 .69549 L p .707 .577 .707 r
F P
0 g
s
.74377 .69549 m .74846 .67812 L .7786 .68788 L p .707 .577 .707 r
F P
0 g
s
.74846 .67812 m .74377 .69549 L .71286 .68917 L p .707 .577 .707 r
F P
0 g
s
.30294 .60857 m .29912 .645 L .30194 .65503 L p .707 .577 .707 r
F P
0 g
s
.30113 .59844 m .29869 .54265 L .30578 .53451 L p .707 .577 .707 r
F P
0 g
s
.2966 .68166 m .30128 .66429 L .29885 .65213 L p .707 .577 .707 r
F P
0 g
s
.48919 .7138 m .48451 .73117 L .49175 .72156 L p .707 .577 .707 r
F P
0 g
s
.49175 .72156 m .49644 .70418 L .48919 .7138 L p .707 .577 .707 r
F P
0 g
s
.29885 .65213 m .29417 .66951 L .2966 .68166 L p .707 .577 .707 r
F P
0 g
s
.5058 .63212 m .50198 .66855 L .49917 .65852 L p .707 .577 .707 r
F P
0 g
s
.49917 .65852 m .50299 .62209 L .5058 .63212 L p .707 .577 .707 r
F P
0 g
s
.30578 .53451 m .30821 .59029 L .30113 .59844 L p .707 .577 .707 r
F P
0 g
s
.49952 .52986 m .50196 .58564 L .48939 .57875 L p .707 .577 .707 r
F P
0 g
s
.48939 .57875 m .48695 .52297 L .49952 .52986 L p .707 .577 .707 r
F P
0 g
s
.29912 .645 m .30294 .60857 L .31005 .59969 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31005 .59969 m .30623 .63612 L .29912 .645 L p .707 .577 .707 r
F P
0 g
s
.30821 .59029 m .30578 .53451 L .32215 .52692 L p .707 .577 .707 r
F P
0 g
s
.29417 .66951 m .29885 .65213 L .3061 .64252 L p .707 .577 .707 r
F P
0 g
s
.49644 .70418 m .49175 .72156 L .48933 .7094 L p .707 .577 .707 r
F P
0 g
s
.48933 .7094 m .49401 .69203 L .49644 .70418 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3061 .64252 m .30142 .6599 L .29417 .66951 L p .707 .577 .707 r
F P
0 g
s
.50299 .62209 m .49917 .65852 L .48669 .64832 L p .707 .577 .707 r
F P
0 g
s
.48669 .64832 m .49051 .61189 L .50299 .62209 L p .707 .577 .707 r
F P
0 g
s
.48695 .52297 m .48939 .57875 L .46836 .57355 L p .707 .577 .707 r
F P
0 g
s
.46836 .57355 m .46592 .51776 L .48695 .52297 L p .707 .577 .707 r
F P
0 g
s
.32215 .52692 m .32458 .58271 L .30821 .59029 L p .707 .577 .707 r
F P
0 g
s
.30623 .63612 m .31005 .59969 L .32639 .59284 L p .707 .577 .707 r
F P
0 g
s
.32458 .58271 m .32215 .52692 L .34618 .52063 L p .707 .577 .707 r
F P
0 g
s
.32639 .59284 m .32257 .62927 L .30623 .63612 L p .707 .577 .707 r
F P
0 g
s
.30142 .6599 m .3061 .64252 L .32231 .6364 L p .707 .577 .707 r
F P
0 g
s
.49401 .69203 m .48933 .7094 L .47747 .69589 L p .707 .577 .707 r
F P
0 g
s
.47747 .69589 m .48215 .67851 L .49401 .69203 L p .707 .577 .707 r
F P
0 g
s
.32231 .6364 m .31762 .65377 L .30142 .6599 L p .707 .577 .707 r
F P
0 g
s
.49051 .61189 m .48669 .64832 L .46579 .63895 L p .707 .577 .707 r
F P
0 g
s
.46579 .63895 m .46961 .60251 L .49051 .61189 L p .707 .577 .707 r
F P
0 g
s
.46592 .51776 m .46836 .57355 L .44093 .57054 L p .707 .577 .707 r
F P
0 g
s
.44093 .57054 m .4385 .51475 L .46592 .51776 L p .707 .577 .707 r
F P
0 g
s
.34618 .52063 m .34862 .57642 L .32458 .58271 L p .707 .577 .707 r
F P
0 g
s
.32257 .62927 m .32639 .59284 L .35037 .58867 L p .707 .577 .707 r
F P
0 g
s
.34862 .57642 m .34618 .52063 L .37555 .51626 L p .707 .577 .707 r
F P
0 g
s
.4385 .51475 m .44093 .57054 L .40979 .57002 L p .707 .577 .707 r
F P
0 g
s
.40979 .57002 m .40735 .51424 L .4385 .51475 L p .707 .577 .707 r
F P
0 g
s
.35037 .58867 m .34655 .6251 L .32257 .62927 L p .707 .577 .707 r
F P
0 g
s
.31762 .65377 m .32231 .6364 L .34589 .63436 L p .707 .577 .707 r
F P
0 g
s
.37798 .57205 m .37555 .51626 L .40735 .51424 L p .707 .577 .707 r
F P
0 g
s
.37555 .51626 m .37798 .57205 L .34862 .57642 L p .707 .577 .707 r
F P
0 g
s
.48215 .67851 m .47747 .69589 L .45734 .68234 L p .707 .577 .707 r
F P
0 g
s
.45734 .68234 m .46202 .66496 L .48215 .67851 L p .707 .577 .707 r
F P
0 g
s
.46961 .60251 m .46579 .63895 L .4385 .63132 L p .707 .577 .707 r
F P
0 g
s
.4385 .63132 m .44232 .59489 L .46961 .60251 L p .707 .577 .707 r
F P
0 g
s
.40735 .51424 m .40979 .57002 L .37798 .57205 L p .707 .577 .707 r
F P
0 g
s
.34589 .63436 m .3412 .65174 L .31762 .65377 L p .707 .577 .707 r
F P
0 g
s
.34655 .6251 m .35037 .58867 L .37963 .58761 L p .707 .577 .707 r
F P
0 g
s
.44232 .59489 m .4385 .63132 L .4075 .62618 L p .707 .577 .707 r
F P
0 g
s
.4075 .62618 m .41132 .58975 L .44232 .59489 L p .707 .577 .707 r
F P
0 g
s
.37963 .58761 m .37581 .62404 L .34655 .6251 L p .707 .577 .707 r
F P
0 g
s
.37581 .62404 m .37963 .58761 L .41132 .58975 L p .707 .577 .707 r
F P
0 g
s
.3412 .65174 m .34589 .63436 L .37454 .63662 L p .707 .577 .707 r
F P
0 g
s
.46202 .66496 m .45734 .68234 L .43091 .67008 L p .707 .577 .707 r
F P
0 g
s
.43091 .67008 m .43559 .6527 L .46202 .66496 L p .707 .577 .707 r
F P
0 g
s
.41132 .58975 m .4075 .62618 L .37581 .62404 L p .707 .577 .707 r
F P
0 g
s
.37454 .63662 m .36985 .65399 L .3412 .65174 L p .707 .577 .707 r
F P
0 g
s
.36985 .65399 m .37454 .63662 L .40545 .64294 L p .707 .577 .707 r
F P
0 g
s
.43559 .6527 m .43091 .67008 L .40076 .66031 L p .707 .577 .707 r
F P
0 g
s
.40076 .66031 m .40545 .64294 L .43559 .6527 L p .707 .577 .707 r
F P
0 g
s
.40545 .64294 m .40076 .66031 L .36985 .65399 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0081ooaH008Mo
o`00N7oo20001EYF00<005YFFUH02UYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH01eYF1P00Ngoo001_Ool40007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006eoo`800003FUH005YF00QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00Jgoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF000006moo`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00J7oo0P001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00JWoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Moo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008006Ioo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1SOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00IWoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol006Ioo`800003FUH005YF00EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00IWoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo
00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00=JEP0000001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`800003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`800003FUH0
05YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00AJEP00FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00AJEP00
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH025YF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol015YF001JEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01EYF001JEP00FUH05`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol00eYF0000000200000eYF001J
EP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IWoo001OOol60005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005]oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00FGoo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000JOolA000kOol005Aoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
015oo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH5000fOol005Aoo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008003=oo`00E7oo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00<7oo001DOol00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002000]Ool005Aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001DOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF001oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP02
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00FUH00004FUH00`00FUIJEP03FUH60007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00EGoo00<005YF000015YF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF10000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Eo
o`03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002aoo`00EGoo00@0
05YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`03001J
EP00008000EJEQP00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000/Ool005Eoo`80009JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00@000MJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;7oo001EOol20002FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02aoo`00EGoo0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000/Ool005Eoo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30002FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF5`0015YF00<005YF
FUH00eYF00D005YFFUIJEP0002aoo`00B7oo4@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP0000000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0
000/Ool0041oo`P000AJEP03001JEUYF00IJEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000=J
EP03001oogoo02Yoo`00>Woo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00FUIJ
EP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800004Ool005YF0003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00Ool0:goo000fOol400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP000UYF00D005YFFUIJEP0000MJEP03001JEP00
00L000QJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH3000/Ool003=oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo001JEP030004FUH0
0`00FUH000070003FUH00`00FUIJEP02FUH700000eYF001JEP06FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20000
1goo001JEP00FUH005YF00D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH40004FUH01000FUIJEP00
1EYF00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP07
001JEUYFFUH005YF0000;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH005YF1@001EYF00@005YFFUH000EJEP03001JEP0000@000=J
EP03001JEP0000D000IJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01P00FUH007oo001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00001JEP0=0005FUH00`00FUH000040003FUH00`00FUIJEP05FUH40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001oo`<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP05001JEUYFFUH0000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP<000IJEP04001J
EUYFFUH=0003FUH00`00FUIJEP09FUH30005FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=J
EP000000;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60000
0eYF001JEP0:FUH00`00FUIJEP020003FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP07001JEP00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0P00<7oo000]
Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000002eYF00<0
05YFFUH00UYF0P0000MJEP00FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002moo`00;Goo00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00@005YFFUIJ
EPD0009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUHB0007FUH0
0`00FUIJEP05FUH<0003FUH01000FUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000/Ool002eoo`03
001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
0004FUH000000005FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH30004FUH0
0`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000/Ool002eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPD000=JEP05001JEUYFFUH0
000?Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00:goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF5`001EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH00`0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF000005YF001JEP050005FUH01000FUIJEUYF
0P004Woo10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:goo000^Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUH000030002FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH01`00
FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00
001JEP02000015YF001JEUYF0P0015YF00@005YFFUIJEP8000Moo`<000aoo`@00003FUH005YF00AJ
EP03001JEUYF009JEP8002]oo`00;Woo00<005YF000015YF00@005YFFUIJEPH00003FUH005YF00IJ
EP03001JEUYF00IJEP07001JEP00FUH005YF00000UYF100000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF0P0025YF0`000UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH<00000eYF00000006Ool5000?Ool20005
FUH00`00FUIJEP02FUH2000[Ool002ioo`03001JEP0000AJEP@000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUH00003FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020006FUH00`00FUIJEP030003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020002FUH200000eYF001JEP04FUH01000FUIJEUYF3P004Goo
0P000eYF00L005YFFUIJEP00FUH0000[Ool002ioo`03001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEUYF0004FUH20006FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20002FUH00`00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000BOol200000eYF001JEP02FUH00`00FUH0000[
Ool002ioo`03001JEP0000<000AJEQP00005FUH005YFFUH00004FUH20006FUH00`00FUH000020000
0eYF001JEP06FUH30006FUH00`00FUIJEP04FUH200000eYF001JEP05FUH30002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00002000>Ool50003FUH2000/Ool002io
o`03001JEP00009JEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00@00005FUH005YFFUH00002FUH20004FUH00`00FUH00002FUH50003FUH50005FUH00`00FUIJEP06
FUH20005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF3P000eYF00<005YF00000UYF0P00;7oo000^Ool20003FUH30006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH01000FUIJEUYF0`00
0UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF20000eYF00@005YFFUH0009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEQ8000IJ
EP03001JEUYF00IJEP8000EJEP03001JEUYF00AJEP03001JEUYF00@002aoo`00;Woo0P0000=JEP00
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF
00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF0000100000=JEP0000001`0015YF00@005YF
FUIJEP<000AJEP8000eJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH0000000EJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH30003
FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;7oo000^Ool40003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000050005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH40007FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<002aoo`00;goo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF0000
00AJEP03001JEUYF00<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00AJEP04001JEUYFFUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020005FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP02FUH00`00FUH0000/Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00
FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`00
0UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<0
05YFFUH00UYF00<005YFFUH00UYF0P00;Goo000_Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007FUH30003FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20008FUH30002FUH00`00FUIJEP02FUH2000]Ool002moo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YF
FUH00`000eYF0P00;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH20007FUH00`00FUIJEP050006FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH00eYF1000<7oo000_Ool20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH00`00FUIJEP05000;FUH00`00FUIJEP04
FUH2000015YF0000000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
000015YF0`001UYF00P005YFFUIJEP00FUH007oo10000UYF0`001UYF00<005YFFUH00eYF0P0000=J
EP00FUH01EYF0P00<Goo000^Ool00`00FUH00003FUH00`00FUH00003000>Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP04FUH60006FUH00`00FUH000040002FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF
00@005YFFUH000EJEP07001JEUYFFUH005YF00001Goo5@001UYF0P00<Goo000^Ool00`00FUH00003
FUH2000BOol30006Ool60006FUH00`00FUIJEP02FUH00`00FUH000020006FUH00`00FUIJEP07FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEP00FUH005YF000015YF0P000eYF00@005YFFUIJEP8000Moo`D0
00moo`8000=JEP04001JEUYF000`Ool002ioo`04001JEP00FUH20002FUH90008Ool5000;Ool40002
FUH00`00FUIJEP02FUH01@00FUIJEP00FUH010000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH0009JEP8000IJEP04001JEUYF0003FUH00`00Oomoo`06Ool5000A
Ool200000eYF001JEP02FUH00`00Oomoo`0]Ool002ioo`05001JEP00001JEP050003FUH01000FUIJ
EUYF3@003goo0`0015YF00@005YFFUH000EJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH20006FUH400000eYF0000000:Ool3000DOol20003FUH00`00Oomoo`0]Ool0
02ioo`D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPH0011oo`80009JEP04001J
EUYF0005FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF000015YF00@005YFFUIJEP8002Eoo`04001JEUYF000_Ool002ioo`<000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000@Ool30002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH60004FUH01000FUIJEUYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP8002=oo`05001JEP00FUH0000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000aoo`@0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEQL000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEP03001JEUYF00=JEP8000QJEP<0025oo`800003FUH007oo02eoo`00;Goo00<005YF0000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP`000=JEP04001JEUYF0005
FUH00`00FUIJEP06FUH9000<FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
000NOol00`00FUH0000^Ool002eoo`80009JEPH00003FUH005YF00AJEPP000AJEP03001JEUYF00MJ
EP<000AJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP04FUH5000HOol200000eYF001oo`0]Ool002eoo`@00003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000QJEP03001JEUYF0080009JEP03001JEUYF
00AJEP04001JEUYF0005FUH00`00FUH00004000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP04FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP020003FUH00`00FUIJEP07FUH00`00FUIJEP04000BOol200000eYF0000000_Ool0
02aoo`<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH0
0`00FUIJEP03FUH30006FUH01000FUIJEP0015YF0`0015YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF0000
10001EYF00<005YFFUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH01EYF1P0027oo10000eYF0P00
;goo000/Ool30003Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30000
0eYF001JEP06FUH20004FUH20002FUH00`00FUH000020007FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH00`00
FUH00004Ool400000eYF001JEP04FUH40007FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00L0
05YFFUIJEP00FUH0000_Ool002aoo`04001JEP000004Ool300000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH20008FUH30002FUH20002FUH200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP03
FUH00`00FUH00008Ool20005FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80031oo`00;7oo00@005YF001JEP8000Eoo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF008000IJEP05001JEUYF001JEP0200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YF00002Woo0P000eYF00P005YFFUIJEP00FUH0
07oo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80035oo`00;7oo0P0015YF
00<007ooOol01Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP03001JEP0000aoo`80
0003FUH005YF009JEP03001JEP0000Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP00000cOol002eoo`03001JEUYF009JEP8000Qoo`<00003FUH005YF00IJEP<000IJEP03001JEUYF
00AJEP800003FUH005YF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo
00Yoo`D000=JEP03001JEP0000Yoo`H000AJEP04001JEUYFFUH5000eOol002eoo`05001JEUYFFUH0
0002FUH20009Ool50003FUH50005FUH00`00FUIJEP06FUH20006FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH200000eYF0000000:0003FUH00`00FUH00002FUH2000AOol8000jOol002ioo`04
001JEUYF0004FUH00`00Oomoo`0;Ool90004FUH00`00FUIJEP02FUH70004FUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH2000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01000Dgoo000_Ool2
0006FUH00`00Oomoo`0=Ool500000goo000000070007Ool20002FUH00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUH00000FUH00`000eYF00<005YFFUH015YF00@005YFFUIJEP<005=oo`00
<7oo00<005YFFUH015YF0`003Woo0`0057oo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<005=oo`00<Goo
0P0015YF00<005YFFUH00P0097oo00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF008000EJEP8000EJEP03001JEUYF009JEP03001JEP0005=oo`00<goo00@005YFFUH0
00EJEP8002=oo`03001JEUYF00<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000008FUH0
0`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0001COol003Aoo`<000MJEP<0025oo`<00004FUH0
00000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40008FUH30002FUH00`00FUIJEP02FUH2001DOol003Ioo`03001J
EUYF00IJEP04001JEP00000QOol01000FUH007oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH0
0P001UYF00H005YFFUH005YF0003FUH2001EOol003Moo`8000EJEP03001JEUYF009JEP<001ioo`80
00Aoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20003FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0P0000=J
EP000000Egoo000iOol20003FUH00`00FUIJEP05FUH6000FOol40006Ool300000eYF001JEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001EYF
00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<007ooOol0Egoo000kOol30009FUH00`00FUIJEP02
FUH80008Ool60002FUH00`00Oomoo`08Ool40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP02FUH50006FUH2001HOol003eoo`<000IJ
EP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P003Woo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@0000=oo`0000000`0000=oo`000000
1`001Goo0P0015YF00<005YF0000Egoo0010Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00005Goo2@001UYF00<005YFFUH02UYF00<005YFFUH00eYF2000
1Woo1@004Goo00@005YFFUH000=JEP03001oogoo05Aoo`00A7oo1@001UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP8001iooaX000eoo`D0019oo`<000=JEP03001oogoo05Aoo`00BGoo
10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00<7oo00<005YFFUH00UYF00@0
05YFFUIJEP8000aoo`<001Eoo`05001JEUYFFUH0001FOol004eoo`H000AJEP04001JEUYFFUH6000c
Ool20002FUH00`00FUIJEP03FUH2000SOol01@00FUH005YF0000EGoo001COol8000kOol20008FUH2
000ROol200000eYF001oo`1DOol009Moo`03001JEUYF00IJEP03001JEP000080021oo`03001JEP00
05Eoo`00V7oo0P001UYF00<005YFFUH00UYF0`007Goo00<005YF0000EGoo002JOol20003FUH00`00
FUIJEP06FUH6000EOol4001FOol009aoo`800003FUH005YF00MJEP03001JEUYF00=JEPP000Qoo`D0
009JEP8005Ioo`00WWoo0`001eYF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF009J
EP8005Ioo`00XGoo10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8005Moo`00YGoo1@001eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00
Egoo002ZOol40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001HOol00:ioo`H0
00AJEP04001JEUYFFUH6001KOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59021 .75232 m .59264 .69706 L .5615 .69378 L p .707 .577 .707 r
F P
0 g
s
.59264 .69706 m .59021 .75232 L .62202 .75279 L p .707 .577 .707 r
F P
0 g
s
.62202 .75279 m .62445 .69752 L .59264 .69706 L p .707 .577 .707 r
F P
0 g
s
.62445 .69752 m .62202 .75279 L .65138 .75039 L p .707 .577 .707 r
F P
0 g
s
.65138 .75039 m .65381 .69513 L .62445 .69752 L p .707 .577 .707 r
F P
0 g
s
.55907 .74904 m .5615 .69378 L .53407 .68801 L p .707 .577 .707 r
F P
0 g
s
.5615 .69378 m .55907 .74904 L .59021 .75232 L p .707 .577 .707 r
F P
0 g
s
.65381 .69513 m .65138 .75039 L .67542 .74538 L p .707 .577 .707 r
F P
0 g
s
.67542 .74538 m .67785 .69011 L .65381 .69513 L p .707 .577 .707 r
F P
0 g
s
.53164 .74327 m .53407 .68801 L .51305 .68031 L p .707 .577 .707 r
F P
0 g
s
.53407 .68801 m .53164 .74327 L .55907 .74904 L p .707 .577 .707 r
F P
0 g
s
.5925 .80897 m .58868 .77172 L .55768 .77309 L p .707 .577 .707 r
F P
0 g
s
.58868 .77172 m .5925 .80897 L .62419 .80524 L p .707 .577 .707 r
F P
0 g
s
.62419 .80524 m .62037 .76799 L .58868 .77172 L p .707 .577 .707 r
F P
0 g
s
.62037 .76799 m .62419 .80524 L .65345 .79952 L p .707 .577 .707 r
F P
0 g
s
.65345 .79952 m .64963 .76227 L .62037 .76799 L p .707 .577 .707 r
F P
0 g
s
.5615 .81034 m .55768 .77309 L .53039 .77197 L p .707 .577 .707 r
F P
0 g
s
.55768 .77309 m .5615 .81034 L .5925 .80897 L p .707 .577 .707 r
F P
0 g
s
.59923 .84454 m .59455 .82616 L .56441 .83235 L p .707 .577 .707 r
F P
0 g
s
.59455 .82616 m .59923 .84454 L .63014 .83647 L p .707 .577 .707 r
F P
0 g
s
.63014 .83647 m .62546 .81809 L .59455 .82616 L p .707 .577 .707 r
F P
0 g
s
.64963 .76227 m .65345 .79952 L .67742 .79237 L p .707 .577 .707 r
F P
0 g
s
.67742 .79237 m .6736 .75512 L .64963 .76227 L p .707 .577 .707 r
F P
0 g
s
.67785 .69011 m .67542 .74538 L .69178 .73823 L p .707 .577 .707 r
F P
0 g
s
.69178 .73823 m .69422 .68296 L .67785 .69011 L p .707 .577 .707 r
F P
0 g
s
.62546 .81809 m .63014 .83647 L .65879 .8273 L p .707 .577 .707 r
F P
0 g
s
.65879 .8273 m .65411 .80892 L .62546 .81809 L p .707 .577 .707 r
F P
0 g
s
.51305 .68031 m .51061 .73557 L .53164 .74327 L p .707 .577 .707 r
F P
0 g
s
.56441 .83235 m .56909 .85073 L .59923 .84454 L p .707 .577 .707 r
F P
0 g
s
.53039 .77197 m .53421 .80922 L .5615 .81034 L p .707 .577 .707 r
F P
0 g
s
.56909 .85073 m .56441 .83235 L .53797 .83604 L p .707 .577 .707 r
F P
0 g
s
.51061 .73557 m .51305 .68031 L .50047 .67144 L p .707 .577 .707 r
F P
0 g
s
.53421 .80922 m .53039 .77197 L .50948 .76847 L p .707 .577 .707 r
F P
0 g
s
.53797 .83604 m .54266 .85442 L .56909 .85073 L p .707 .577 .707 r
F P
0 g
s
.65411 .80892 m .65879 .8273 L .68237 .81794 L p .707 .577 .707 r
F P
0 g
s
.68237 .81794 m .67769 .79955 L .65411 .80892 L p .707 .577 .707 r
F P
0 g
s
.50948 .76847 m .5133 .80572 L .53421 .80922 L p .707 .577 .707 r
F P
0 g
s
.6736 .75512 m .67742 .79237 L .69377 .78448 L p .707 .577 .707 r
F P
0 g
s
.69377 .78448 m .68995 .74723 L .6736 .75512 L p .707 .577 .707 r
F P
0 g
s
.50047 .67144 m .49804 .7267 L .51061 .73557 L p .707 .577 .707 r
F P
0 g
s
.54266 .85442 m .53797 .83604 L .51784 .83688 L p .707 .577 .707 r
F P
0 g
s
.69422 .68296 m .69178 .73823 L .69887 .72965 L p .707 .577 .707 r
F P
0 g
s
.69887 .72965 m .7013 .67438 L .69422 .68296 L p .707 .577 .707 r
F P
0 g
s
.51784 .83688 m .52253 .85526 L .54266 .85442 L p .707 .577 .707 r
F P
0 g
s
.67769 .79955 m .68237 .81794 L .69858 .80929 L p .707 .577 .707 r
F P
0 g
s
.69858 .80929 m .6939 .79091 L .67769 .79955 L p .707 .577 .707 r
F P
0 g
s
.5133 .80572 m .50948 .76847 L .49701 .76292 L p .707 .577 .707 r
F P
0 g
s
.49804 .7267 m .50047 .67144 L .49759 .66226 L p .707 .577 .707 r
F P
0 g
s
.49701 .76292 m .50083 .80018 L .5133 .80572 L p .707 .577 .707 r
F P
0 g
s
.68995 .74723 m .69377 .78448 L .70088 .77664 L p .707 .577 .707 r
F P
0 g
s
.70088 .77664 m .69706 .73938 L .68995 .74723 L p .707 .577 .707 r
F P
0 g
s
.52253 .85526 m .51784 .83688 L .50599 .83479 L p .707 .577 .707 r
F P
0 g
s
.49759 .66226 m .49516 .71753 L .49804 .7267 L p .707 .577 .707 r
F P
0 g
s
.50599 .83479 m .51067 .85317 L .52253 .85526 L p .707 .577 .707 r
F P
0 g
s
.7013 .67438 m .69887 .72965 L .69599 .72047 L p .707 .577 .707 r
F P
0 g
s
.69599 .72047 m .69842 .66521 L .7013 .67438 L p .707 .577 .707 r
F P
0 g
s
.6939 .79091 m .69858 .80929 L .70583 .8022 L p .707 .577 .707 r
F P
0 g
s
.70583 .8022 m .70114 .78382 L .6939 .79091 L p .707 .577 .707 r
F P
0 g
s
.50083 .80018 m .49701 .76292 L .49419 .75588 L p .707 .577 .707 r
F P
0 g
s
.49516 .71753 m .49759 .66226 L .50468 .65368 L p .707 .577 .707 r
F P
0 g
s
.49419 .75588 m .49801 .79314 L .50083 .80018 L p .707 .577 .707 r
F P
0 g
s
.50468 .65368 m .50225 .70894 L .49516 .71753 L p .707 .577 .707 r
F P
0 g
s
.49801 .79314 m .49419 .75588 L .5013 .74804 L p .707 .577 .707 r
F P
0 g
s
.5013 .74804 m .50512 .78529 L .49801 .79314 L p .707 .577 .707 r
F P
0 g
s
.50084 .82131 m .48403 .31792 L .44004 .31673 L p .707 .577 .707 r
F P
0 g
s
.50225 .70894 m .50468 .65368 L .52104 .64653 L p .707 .577 .707 r
F P
0 g
s
.52104 .64653 m .51861 .70179 L .50225 .70894 L p .707 .577 .707 r
F P
0 g
s
.51861 .70179 m .52104 .64653 L .54508 .64151 L p .707 .577 .707 r
F P
0 g
s
.50512 .78529 m .5013 .74804 L .51764 .74015 L p .707 .577 .707 r
F P
0 g
s
.51764 .74015 m .52147 .77741 L .50512 .78529 L p .707 .577 .707 r
F P
0 g
s
.54508 .64151 m .54265 .69678 L .51861 .70179 L p .707 .577 .707 r
F P
0 g
s
.51549 .84126 m .51081 .82288 L .52701 .81423 L p .707 .577 .707 r
F P
0 g
s
.52701 .81423 m .5317 .83261 L .51549 .84126 L p .707 .577 .707 r
F P
0 g
s
.52147 .77741 m .51764 .74015 L .54162 .733 L p .707 .577 .707 r
F P
0 g
s
.54162 .733 m .54544 .77025 L .52147 .77741 L p .707 .577 .707 r
F P
0 g
s
.5317 .83261 m .52701 .81423 L .55059 .80486 L p .707 .577 .707 r
F P
0 g
s
.55059 .80486 m .55528 .82325 L .5317 .83261 L p .707 .577 .707 r
F P
0 g
s
.48403 .31792 m .50084 .82131 L .54577 .81886 L p .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .54162 .733 L .56511 .72841 L p .707 .577 .707 r
F P
0 g
s
.56511 .72841 m .57088 .72728 L p .56643 .73479 L .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .56511 .72841 L .56643 .73479 L .707 .577 .707 r
F
.52895 .31547 m .48403 .31792 L p .48962 .36328 L F P
0 g
s
.54577 .81886 m .53843 .59938 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.53843 .59938 m .52895 .31547 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.54265 .69678 m .54508 .64151 L .57444 .63912 L p .707 .577 .707 r
F P
0 g
s
.57201 .69439 m .57444 .63912 L .60625 .63959 L p .707 .577 .707 r
F P
0 g
s
.57444 .63912 m .57201 .69439 L .54265 .69678 L p .707 .577 .707 r
F P
0 g
s
.60625 .63959 m .60382 .69485 L .57201 .69439 L p .707 .577 .707 r
F P
0 g
s
.57088 .72728 m .5747 .76453 L .54544 .77025 L p .707 .577 .707 r
F P
0 g
s
.5747 .76453 m .57088 .72728 L .60257 .72355 L p .707 .577 .707 r
F P
0 g
s
.60257 .72355 m .60639 .7608 L .5747 .76453 L p .707 .577 .707 r
F P
0 g
s
.55528 .82325 m .55059 .80486 L .57924 .7957 L p .707 .577 .707 r
F P
0 g
s
.57924 .7957 m .58392 .81408 L .55528 .82325 L p .707 .577 .707 r
F P
0 g
s
.58392 .81408 m .57924 .7957 L .61015 .78762 L p .707 .577 .707 r
F P
0 g
s
.61015 .78762 m .61483 .80601 L .58392 .81408 L p .707 .577 .707 r
F P
0 g
s
.52895 .31547 m .54577 .81886 L .58723 .81302 L p .707 .577 .707 r
F P
0 g
s
.58723 .81302 m .57041 .30963 L .52895 .31547 L p .707 .577 .707 r
F P
0 g
s
.45686 .82012 m .44004 .31673 L .4013 .31203 L p .707 .577 .707 r
F P
0 g
s
.44004 .31673 m .45686 .82012 L .50084 .82131 L p .707 .577 .707 r
F P
0 g
s
.69706 .73938 m .70088 .77664 L .69806 .7696 L p .707 .577 .707 r
F P
0 g
s
.69806 .7696 m .69424 .73234 L .69706 .73938 L p .707 .577 .707 r
F P
0 g
s
.51067 .85317 m .50599 .83479 L .50356 .82996 L p .707 .577 .707 r
F P
0 g
s
.50356 .82996 m .50824 .84834 L .51067 .85317 L p .707 .577 .707 r
F P
0 g
s
.63739 .64287 m .63496 .69813 L .60382 .69485 L p .707 .577 .707 r
F P
0 g
s
.60382 .69485 m .60625 .63959 L .63739 .64287 L p .707 .577 .707 r
F P
0 g
s
.63357 .72218 m .63739 .75943 L .60639 .7608 L p .707 .577 .707 r
F P
0 g
s
.60639 .7608 m .60257 .72355 L .63357 .72218 L p .707 .577 .707 r
F P
0 g
s
.6403 .78144 m .64498 .79982 L .61483 .80601 L p .707 .577 .707 r
F P
0 g
s
.61483 .80601 m .61015 .78762 L .6403 .78144 L p .707 .577 .707 r
F P
0 g
s
.57041 .30963 m .58723 .81302 L .62117 .80436 L p .707 .577 .707 r
F P
0 g
s
.62117 .80436 m .60436 .30097 L .57041 .30963 L p .707 .577 .707 r
F P
0 g
s
.69842 .66521 m .69599 .72047 L .68342 .7116 L p .707 .577 .707 r
F P
0 g
s
.68342 .7116 m .68585 .65633 L .69842 .66521 L p .707 .577 .707 r
F P
0 g
s
.70114 .78382 m .70583 .8022 L .7034 .79738 L p .707 .577 .707 r
F P
0 g
s
.7034 .79738 m .69872 .779 L .70114 .78382 L p .707 .577 .707 r
F P
0 g
s
.2472 .71129 m .24963 .65603 L .21849 .65275 L p .707 .577 .707 r
F P
0 g
s
.24963 .65603 m .2472 .71129 L .27901 .71176 L p .707 .577 .707 r
F P
0 g
s
.27901 .71176 m .28144 .6565 L .24963 .65603 L p .707 .577 .707 r
F P
0 g
s
.41812 .81542 m .4013 .31203 L .3716 .30427 L p .707 .577 .707 r
F P
0 g
s
.4013 .31203 m .41812 .81542 L .45686 .82012 L p .707 .577 .707 r
F P
0 g
s
.28144 .6565 m .27901 .71176 L .30837 .70937 L p .707 .577 .707 r
F P
0 g
s
.30837 .70937 m .3108 .6541 L .28144 .6565 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21606 .70801 m .21849 .65275 L .19106 .64698 L p .707 .577 .707 r
F P
0 g
s
.21849 .65275 m .21606 .70801 L .2472 .71129 L p .707 .577 .707 r
F P
0 g
s
.69424 .73234 m .69806 .7696 L .68558 .76405 L p .707 .577 .707 r
F P
0 g
s
.68558 .76405 m .68176 .7268 L .69424 .73234 L p .707 .577 .707 r
F P
0 g
s
.3108 .6541 m .30837 .70937 L .33241 .70435 L p .707 .577 .707 r
F P
0 g
s
.33241 .70435 m .33484 .64909 L .3108 .6541 L p .707 .577 .707 r
F P
0 g
s
.50824 .84834 m .50356 .82996 L .51081 .82288 L p .707 .577 .707 r
F P
0 g
s
.66482 .64864 m .66239 .7039 L .63496 .69813 L p .707 .577 .707 r
F P
0 g
s
.63496 .69813 m .63739 .64287 L .66482 .64864 L p .707 .577 .707 r
F P
0 g
s
.66086 .7233 m .66468 .76055 L .63739 .75943 L p .707 .577 .707 r
F P
0 g
s
.63739 .75943 m .63357 .72218 L .66086 .7233 L p .707 .577 .707 r
F P
0 g
s
.64498 .79982 m .6403 .78144 L .66673 .77774 L p .707 .577 .707 r
F P
0 g
s
.60436 .30097 m .62117 .80436 L .64428 .79372 L p .707 .577 .707 r
F P
0 g
s
.64428 .79372 m .62746 .29033 L .60436 .30097 L p .707 .577 .707 r
F P
0 g
s
.51081 .82288 m .51549 .84126 L .50824 .84834 L p .707 .577 .707 r
F P
0 g
s
.68585 .65633 m .68342 .7116 L .66239 .7039 L p .707 .577 .707 r
F P
0 g
s
.66239 .7039 m .66482 .64864 L .68585 .65633 L p .707 .577 .707 r
F P
0 g
s
.18863 .70224 m .19106 .64698 L .17004 .63928 L p .707 .577 .707 r
F P
0 g
s
.19106 .64698 m .18863 .70224 L .21606 .70801 L p .707 .577 .707 r
F P
0 g
s
.24949 .76643 m .24567 .72918 L .21467 .73055 L p .707 .577 .707 r
F P
0 g
s
.24567 .72918 m .24949 .76643 L .28118 .7627 L p .707 .577 .707 r
F P
0 g
s
.28118 .7627 m .27736 .72545 L .24567 .72918 L p .707 .577 .707 r
F P
0 g
s
.69872 .779 m .7034 .79738 L .69154 .79528 L p .707 .577 .707 r
F P
0 g
s
.69154 .79528 m .68686 .7769 L .69872 .779 L p .707 .577 .707 r
F P
0 g
s
.27736 .72545 m .28118 .7627 L .31044 .75698 L p .707 .577 .707 r
F P
0 g
s
.31044 .75698 m .30662 .71973 L .27736 .72545 L p .707 .577 .707 r
F P
0 g
s
.21849 .7678 m .21467 .73055 L .18738 .72943 L p .707 .577 .707 r
F P
0 g
s
.21467 .73055 m .21849 .7678 L .24949 .76643 L p .707 .577 .707 r
F P
0 g
s
.30662 .71973 m .31044 .75698 L .33441 .74983 L p .707 .577 .707 r
F P
0 g
s
.33441 .74983 m .33059 .71258 L .30662 .71973 L p .707 .577 .707 r
F P
0 g
s
.25623 .80609 m .25154 .78771 L .2214 .7939 L p .707 .577 .707 r
F P
0 g
s
.25154 .78771 m .25623 .80609 L .28714 .79802 L p .707 .577 .707 r
F P
0 g
s
.28714 .79802 m .28245 .77964 L .25154 .78771 L p .707 .577 .707 r
F P
0 g
s
.33484 .64909 m .33241 .70435 L .34877 .6972 L p .707 .577 .707 r
F P
0 g
s
.34877 .6972 m .35121 .64194 L .33484 .64909 L p .707 .577 .707 r
F P
0 g
s
.38842 .80766 m .3716 .30427 L .35384 .29421 L p .707 .577 .707 r
F P
0 g
s
.3716 .30427 m .38842 .80766 L .41812 .81542 L p .707 .577 .707 r
F P
0 g
s
.28245 .77964 m .28714 .79802 L .31578 .78885 L p .707 .577 .707 r
F P
0 g
s
.31578 .78885 m .3111 .77047 L .28245 .77964 L p .707 .577 .707 r
F P
0 g
s
.17004 .63928 m .1676 .69455 L .18863 .70224 L p .707 .577 .707 r
F P
0 g
s
.18738 .72943 m .1912 .76668 L .21849 .7678 L p .707 .577 .707 r
F P
0 g
s
.2214 .7939 m .22608 .81228 L .25623 .80609 L p .707 .577 .707 r
F P
0 g
s
.68176 .7268 m .68558 .76405 L .66468 .76055 L p .707 .577 .707 r
F P
0 g
s
.66468 .76055 m .66086 .7233 L .68176 .7268 L p .707 .577 .707 r
F P
0 g
s
.22608 .81228 m .2214 .7939 L .19496 .79759 L p .707 .577 .707 r
F P
0 g
s
.1676 .69455 m .17004 .63928 L .15747 .63041 L p .707 .577 .707 r
F P
0 g
s
.1912 .76668 m .18738 .72943 L .16647 .72593 L p .707 .577 .707 r
F P
0 g
s
.19496 .79759 m .19965 .81597 L .22608 .81228 L p .707 .577 .707 r
F P
0 g
s
.3111 .77047 m .31578 .78885 L .33936 .77949 L p .707 .577 .707 r
F P
0 g
s
.33936 .77949 m .33468 .7611 L .3111 .77047 L p .707 .577 .707 r
F P
0 g
s
.68686 .7769 m .69154 .79528 L .67141 .79613 L p .707 .577 .707 r
F P
0 g
s
.67141 .79613 m .66673 .77774 L .68686 .7769 L p .707 .577 .707 r
F P
0 g
s
.16647 .72593 m .17029 .76318 L .1912 .76668 L p .707 .577 .707 r
F P
0 g
s
.33059 .71258 m .33441 .74983 L .35076 .74194 L p .707 .577 .707 r
F P
0 g
s
.35076 .74194 m .34694 .70469 L .33059 .71258 L p .707 .577 .707 r
F P
0 g
s
.62746 .29033 m .64428 .79372 L .65428 .78215 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .63746 .27876 L .62746 .29033 L p .707 .577 .707 r
F P
0 g
s
.15747 .63041 m .15503 .68567 L .1676 .69455 L p .707 .577 .707 r
F P
0 g
s
.19965 .81597 m .19496 .79759 L .17483 .79843 L p .707 .577 .707 r
F P
0 g
s
.35121 .64194 m .34877 .6972 L .35586 .68862 L p .707 .577 .707 r
F P
0 g
s
.35586 .68862 m .35829 .63335 L .35121 .64194 L p .707 .577 .707 r
F P
0 g
s
.17483 .79843 m .17952 .81681 L .19965 .81597 L p .707 .577 .707 r
F P
0 g
s
.33468 .7611 m .33936 .77949 L .35557 .77084 L p .707 .577 .707 r
F P
0 g
s
.35557 .77084 m .35089 .75246 L .33468 .7611 L p .707 .577 .707 r
F P
0 g
s
.17029 .76318 m .16647 .72593 L .154 .72039 L p .707 .577 .707 r
F P
0 g
s
.15503 .68567 m .15747 .63041 L .15458 .62124 L p .707 .577 .707 r
F P
0 g
s
.37066 .7976 m .35384 .29421 L .34976 .28283 L p .707 .577 .707 r
F P
0 g
s
.35384 .29421 m .37066 .7976 L .38842 .80766 L p .707 .577 .707 r
F P
0 g
s
.66673 .77774 m .67141 .79613 L .64498 .79982 L p .707 .577 .707 r
F P
0 g
s
.154 .72039 m .15782 .75764 L .17029 .76318 L p .707 .577 .707 r
F P
0 g
s
.34694 .70469 m .35076 .74194 L .35787 .7341 L p .707 .577 .707 r
F P
0 g
s
.35787 .7341 m .35405 .69685 L .34694 .70469 L p .707 .577 .707 r
F P
0 g
s
.17952 .81681 m .17483 .79843 L .16298 .79634 L p .707 .577 .707 r
F P
0 g
s
.15458 .62124 m .15215 .6765 L .15503 .68567 L p .707 .577 .707 r
F P
0 g
s
.16298 .79634 m .16766 .81472 L .17952 .81681 L p .707 .577 .707 r
F P
0 g
s
.35829 .63335 m .35586 .68862 L .35298 .67944 L p .707 .577 .707 r
F P
0 g
s
.35298 .67944 m .35541 .62418 L .35829 .63335 L p .707 .577 .707 r
F P
0 g
s
.35089 .75246 m .35557 .77084 L .36282 .76375 L p .707 .577 .707 r
F P
0 g
s
.36282 .76375 m .35813 .74537 L .35089 .75246 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .65021 .77078 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.65021 .77078 m .63339 .26739 L .63746 .27876 L p .707 .577 .707 r
F P
0 g
s
.63339 .26739 m .65021 .77078 L .63245 .76072 L p .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64669 .67643 L .64519 .67576 L p .707 .577 .707 r
F P
0 g
s
.64519 .67576 m .63422 .67089 L p .64567 .70097 L .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64519 .67576 L .64567 .70097 L .707 .577 .707 r
F
.63746 .27876 m .63809 .29737 L p .63846 .31704 L F P
0 g
s
.63809 .29737 m .65428 .78215 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.15782 .75764 m .154 .72039 L .15118 .71335 L p .707 .577 .707 r
F P
0 g
s
.15215 .6765 m .15458 .62124 L .16167 .61265 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15118 .71335 m .155 .7506 L .15782 .75764 L p .707 .577 .707 r
F P
0 g
s
.35405 .69685 m .35787 .7341 L .35505 .72706 L p .707 .577 .707 r
F P
0 g
s
.35505 .72706 m .35123 .68981 L .35405 .69685 L p .707 .577 .707 r
F P
0 g
s
.16766 .81472 m .16298 .79634 L .16055 .79151 L p .707 .577 .707 r
F P
0 g
s
.16167 .61265 m .15924 .66792 L .15215 .6765 L p .707 .577 .707 r
F P
0 g
s
.16055 .79151 m .16523 .80989 L .16766 .81472 L p .707 .577 .707 r
F P
0 g
s
.34976 .28283 m .36658 .78622 L .37066 .7976 L p .707 .577 .707 r
F P
0 g
s
.36658 .78622 m .34976 .28283 L .35977 .27126 L p .707 .577 .707 r
F P
0 g
s
.35541 .62418 m .35298 .67944 L .34041 .67057 L p .707 .577 .707 r
F P
0 g
s
.34041 .67057 m .34284 .61531 L .35541 .62418 L p .707 .577 .707 r
F P
0 g
s
.35813 .74537 m .36282 .76375 L .36039 .75893 L p .707 .577 .707 r
F P
0 g
s
.36039 .75893 m .35571 .74055 L .35813 .74537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.155 .7506 m .15118 .71335 L .15829 .7055 L p .707 .577 .707 r
F P
0 g
s
.15924 .66792 m .16167 .61265 L .17803 .6055 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15829 .7055 m .16211 .74275 L .155 .7506 L p .707 .577 .707 r
F P
0 g
s
.63245 .76072 m .61563 .25733 L .63339 .26739 L p .707 .577 .707 r
F P
0 g
s
.35123 .68981 m .35505 .72706 L .34257 .72152 L p .707 .577 .707 r
F P
0 g
s
.34257 .72152 m .33875 .68427 L .35123 .68981 L p .707 .577 .707 r
F P
0 g
s
.16523 .80989 m .16055 .79151 L .1678 .78443 L p .707 .577 .707 r
F P
0 g
s
.17803 .6055 m .1756 .66077 L .15924 .66792 L p .707 .577 .707 r
F P
0 g
s
.34284 .61531 m .34041 .67057 L .31938 .66287 L p .707 .577 .707 r
F P
0 g
s
.31938 .66287 m .32181 .60761 L .34284 .61531 L p .707 .577 .707 r
F P
0 g
s
.1678 .78443 m .17248 .80281 L .16523 .80989 L p .707 .577 .707 r
F P
0 g
s
.35571 .74055 m .36039 .75893 L .34853 .75683 L p .707 .577 .707 r
F P
0 g
s
.34853 .75683 m .34385 .73845 L .35571 .74055 L p .707 .577 .707 r
F P
0 g
s
.1756 .66077 m .17803 .6055 L .20207 .60049 L p .707 .577 .707 r
F P
0 g
s
.16211 .74275 m .15829 .7055 L .17464 .69762 L p .707 .577 .707 r
F P
0 g
s
.37659 .77465 m .35977 .27126 L .38287 .26062 L p .707 .577 .707 r
F P
0 g
s
.35977 .27126 m .37659 .77465 L .36658 .78622 L p .707 .577 .707 r
F P
0 g
s
.17464 .69762 m .17846 .73487 L .16211 .74275 L p .707 .577 .707 r
F P
0 g
s
.33875 .68427 m .34257 .72152 L .32167 .71801 L p .707 .577 .707 r
F P
0 g
s
.32167 .71801 m .31785 .68076 L .33875 .68427 L p .707 .577 .707 r
F P
0 g
s
.32181 .60761 m .31938 .66287 L .29195 .6571 L p .707 .577 .707 r
F P
0 g
s
.29195 .6571 m .29438 .60184 L .32181 .60761 L p .707 .577 .707 r
F P
0 g
s
.20207 .60049 m .19964 .65575 L .1756 .66077 L p .707 .577 .707 r
F P
0 g
s
.17248 .80281 m .1678 .78443 L .184 .77578 L p .707 .577 .707 r
F P
0 g
s
.19964 .65575 m .20207 .60049 L .23143 .59809 L p .707 .577 .707 r
F P
0 g
s
.184 .77578 m .18869 .79416 L .17248 .80281 L p .707 .577 .707 r
F P
0 g
s
.61563 .25733 m .63245 .76072 L .60274 .75296 L p .707 .577 .707 r
F P
0 g
s
.60274 .75296 m .58592 .24956 L .61563 .25733 L p .707 .577 .707 r
F P
0 g
s
.34385 .73845 m .34853 .75683 L .3284 .75767 L p .707 .577 .707 r
F P
0 g
s
.3284 .75767 m .32372 .73929 L .34385 .73845 L p .707 .577 .707 r
F P
0 g
s
.17846 .73487 m .17464 .69762 L .19861 .69046 L p .707 .577 .707 r
F P
0 g
s
.29438 .60184 m .29195 .6571 L .26081 .65382 L p .707 .577 .707 r
F P
0 g
s
.26081 .65382 m .26324 .59856 L .29438 .60184 L p .707 .577 .707 r
F P
0 g
s
.229 .65336 m .23143 .59809 L .26324 .59856 L p .707 .577 .707 r
F P
0 g
s
.23143 .59809 m .229 .65336 L .19964 .65575 L p .707 .577 .707 r
F P
0 g
s
.19861 .69046 m .20243 .72771 L .17846 .73487 L p .707 .577 .707 r
F P
0 g
s
.26324 .59856 m .26081 .65382 L .229 .65336 L p .707 .577 .707 r
F P
0 g
s
.31785 .68076 m .32167 .71801 L .29438 .71689 L p .707 .577 .707 r
F P
0 g
s
.29438 .71689 m .29056 .67964 L .31785 .68076 L p .707 .577 .707 r
F P
0 g
s
.72741 .66028 m .72985 .60502 L .69871 .60174 L p .707 .577 .707 r
F P
0 g
s
.72985 .60502 m .72741 .66028 L .75922 .66075 L p .707 .577 .707 r
F P
0 g
s
.75922 .66075 m .76166 .60548 L .72985 .60502 L p .707 .577 .707 r
F P
0 g
s
.38287 .26062 m .39969 .76401 L .37659 .77465 L p .707 .577 .707 r
F P
0 g
s
.39969 .76401 m .38287 .26062 L .41682 .25196 L p .707 .577 .707 r
F P
0 g
s
.76166 .60548 m .75922 .66075 L .78858 .65836 L p .707 .577 .707 r
F P
0 g
s
.78858 .65836 m .79102 .60309 L .76166 .60548 L p .707 .577 .707 r
F P
0 g
s
.18869 .79416 m .184 .77578 L .20758 .76641 L p .707 .577 .707 r
F P
0 g
s
.69627 .657 m .69871 .60174 L .67128 .59597 L p .707 .577 .707 r
F P
0 g
s
.69871 .60174 m .69627 .657 L .72741 .66028 L p .707 .577 .707 r
F P
0 g
s
.20243 .72771 m .19861 .69046 L .22787 .68474 L p .707 .577 .707 r
F P
0 g
s
.20758 .76641 m .21227 .7848 L .18869 .79416 L p .707 .577 .707 r
F P
0 g
s
.32372 .73929 m .3284 .75767 L .30197 .76137 L p .707 .577 .707 r
F P
0 g
s
.30197 .76137 m .29729 .74299 L .32372 .73929 L p .707 .577 .707 r
F P
0 g
s
.29056 .67964 m .29438 .71689 L .26338 .71826 L p .707 .577 .707 r
F P
0 g
s
.26338 .71826 m .25956 .68101 L .29056 .67964 L p .707 .577 .707 r
F P
0 g
s
.79102 .60309 m .78858 .65836 L .81262 .65334 L p .707 .577 .707 r
F P
0 g
s
.81262 .65334 m .81506 .59808 L .79102 .60309 L p .707 .577 .707 r
F P
0 g
s
.22787 .68474 m .23169 .72199 L .20243 .72771 L p .707 .577 .707 r
F P
0 g
s
.58592 .24956 m .60274 .75296 L .564 .74825 L p .707 .577 .707 r
F P
0 g
s
.564 .74825 m .54719 .24486 L .58592 .24956 L p .707 .577 .707 r
F P
0 g
s
.23169 .72199 m .22787 .68474 L .25956 .68101 L p .707 .577 .707 r
F P
0 g
s
.25956 .68101 m .26338 .71826 L .23169 .72199 L p .707 .577 .707 r
F P
0 g
s
.66884 .65123 m .67128 .59597 L .65025 .58827 L p .707 .577 .707 r
F P
0 g
s
.67128 .59597 m .66884 .65123 L .69627 .657 L p .707 .577 .707 r
F P
0 g
s
.72971 .71693 m .72589 .67968 L .69488 .68105 L p .707 .577 .707 r
F P
0 g
s
.72589 .67968 m .72971 .71693 L .76139 .7132 L p .707 .577 .707 r
F P
0 g
s
.76139 .7132 m .75757 .67595 L .72589 .67968 L p .707 .577 .707 r
F P
0 g
s
.75757 .67595 m .76139 .7132 L .79065 .70748 L p .707 .577 .707 r
F P
0 g
s
.79065 .70748 m .78683 .67023 L .75757 .67595 L p .707 .577 .707 r
F P
0 g
s
.21227 .7848 m .20758 .76641 L .23623 .75725 L p .707 .577 .707 r
F P
0 g
s
.23623 .75725 m .24092 .77563 L .21227 .7848 L p .707 .577 .707 r
F P
0 g
s
.29729 .74299 m .30197 .76137 L .27183 .76756 L p .707 .577 .707 r
F P
0 g
s
.27183 .76756 m .26714 .74917 L .29729 .74299 L p .707 .577 .707 r
F P
0 g
s
.43364 .75535 m .41682 .25196 L .45828 .24612 L p .707 .577 .707 r
F P
0 g
s
.41682 .25196 m .43364 .75535 L .39969 .76401 L p .707 .577 .707 r
F P
0 g
s
.6987 .7183 m .69488 .68105 L .66759 .67993 L p .707 .577 .707 r
F P
0 g
s
.69488 .68105 m .6987 .7183 L .72971 .71693 L p .707 .577 .707 r
F P
0 g
s
.73644 .75251 m .73176 .73412 L .70161 .74031 L p .707 .577 .707 r
F P
0 g
s
.73176 .73412 m .73644 .75251 L .76735 .74443 L p .707 .577 .707 r
F P
0 g
s
.76735 .74443 m .76267 .72605 L .73176 .73412 L p .707 .577 .707 r
F P
0 g
s
.24092 .77563 m .23623 .75725 L .26714 .74917 L p .707 .577 .707 r
F P
0 g
s
.78683 .67023 m .79065 .70748 L .81463 .70033 L p .707 .577 .707 r
F P
0 g
s
.81463 .70033 m .81081 .66308 L .78683 .67023 L p .707 .577 .707 r
F P
0 g
s
.81506 .59808 m .81262 .65334 L .82899 .64619 L p .707 .577 .707 r
F P
0 g
s
.82899 .64619 m .83142 .59093 L .81506 .59808 L p .707 .577 .707 r
F P
0 g
s
.76267 .72605 m .76735 .74443 L .796 .73526 L p .707 .577 .707 r
F P
0 g
s
.796 .73526 m .79131 .71688 L .76267 .72605 L p .707 .577 .707 r
F P
0 g
s
.26714 .74917 m .27183 .76756 L .24092 .77563 L p .707 .577 .707 r
F P
0 g
s
.65025 .58827 m .64782 .64353 L .66884 .65123 L p .707 .577 .707 r
F P
0 g
s
.70161 .74031 m .70629 .75869 L .73644 .75251 L p .707 .577 .707 r
F P
0 g
s
.66759 .67993 m .67141 .71718 L .6987 .7183 L p .707 .577 .707 r
F P
0 g
s
.54719 .24486 m .564 .74825 L .52002 .74706 L p .707 .577 .707 r
F P
0 g
s
.52002 .74706 m .5032 .24367 L .54719 .24486 L p .707 .577 .707 r
F P
0 g
s
.70629 .75869 m .70161 .74031 L .67518 .744 L p .707 .577 .707 r
F P
0 g
s
.64782 .64353 m .65025 .58827 L .63768 .5794 L p .707 .577 .707 r
F P
0 g
s
.4751 .74951 m .45828 .24612 L .5032 .24367 L p .707 .577 .707 r
F P
0 g
s
.45828 .24612 m .4751 .74951 L .43364 .75535 L p .707 .577 .707 r
F P
0 g
s
.67141 .71718 m .66759 .67993 L .64669 .67643 L p .707 .577 .707 r
F P
0 g
s
.67518 .744 m .67986 .76239 L .70629 .75869 L p .707 .577 .707 r
F P
0 g
s
.79131 .71688 m .796 .73526 L .81958 .7259 L p .707 .577 .707 r
F P
0 g
s
.81958 .7259 m .81489 .70752 L .79131 .71688 L p .707 .577 .707 r
F P
0 g
s
.5032 .24367 m .52002 .74706 L .4751 .74951 L p .707 .577 .707 r
F P
0 g
s
.64669 .67643 m .65051 .71368 L .67141 .71718 L p .707 .577 .707 r
F P
0 g
s
.81081 .66308 m .81463 .70033 L .83097 .69244 L p .707 .577 .707 r
F P
0 g
s
.83097 .69244 m .82715 .65519 L .81081 .66308 L p .707 .577 .707 r
F P
0 g
s
.63768 .5794 m .63525 .63466 L .64782 .64353 L p .707 .577 .707 r
F P
0 g
s
.67986 .76239 m .67518 .744 L .65505 .74484 L p .707 .577 .707 r
F P
0 g
s
.83142 .59093 m .82899 .64619 L .83607 .63761 L p .707 .577 .707 r
F P
0 g
s
.83607 .63761 m .83851 .58234 L .83142 .59093 L p .707 .577 .707 r
F P
0 g
s
.65505 .74484 m .65973 .76323 L .67986 .76239 L p .707 .577 .707 r
F P
0 g
s
.81489 .70752 m .81958 .7259 L .83578 .71725 L p .707 .577 .707 r
F P
0 g
s
.83578 .71725 m .8311 .69887 L .81489 .70752 L p .707 .577 .707 r
F P
0 g
s
.63525 .63466 m .63768 .5794 L .6348 .57022 L p .707 .577 .707 r
F P
0 g
s
.63422 .67089 m .63804 .70814 L .65051 .71368 L p .707 .577 .707 r
F P
0 g
s
.82715 .65519 m .83097 .69244 L .83808 .6846 L p .707 .577 .707 r
F P
0 g
s
.83808 .6846 m .83426 .64734 L .82715 .65519 L p .707 .577 .707 r
F P
0 g
s
.65973 .76323 m .65505 .74484 L .64319 .74275 L p .707 .577 .707 r
F P
0 g
s
.6348 .57022 m .63236 .62549 L .63525 .63466 L p .707 .577 .707 r
F P
0 g
s
.64319 .74275 m .64787 .76113 L .65973 .76323 L p .707 .577 .707 r
F P
0 g
s
.83851 .58234 m .83607 .63761 L .83319 .62843 L p .707 .577 .707 r
F P
0 g
s
.83319 .62843 m .83563 .57317 L .83851 .58234 L p .707 .577 .707 r
F P
0 g
s
.8311 .69887 m .83578 .71725 L .84303 .71017 L p .707 .577 .707 r
F P
0 g
s
.84303 .71017 m .83835 .69178 L .8311 .69887 L p .707 .577 .707 r
F P
0 g
s
.63804 .70814 m .63422 .67089 L .6314 .66385 L p .707 .577 .707 r
F P
0 g
s
.63236 .62549 m .6348 .57022 L .64188 .56164 L p .707 .577 .707 r
F P
0 g
s
.6314 .66385 m .63522 .7011 L .63804 .70814 L p .707 .577 .707 r
F P
0 g
s
.83426 .64734 m .83808 .6846 L .83526 .67756 L p .707 .577 .707 r
F P
0 g
s
.83526 .67756 m .83144 .64031 L .83426 .64734 L p .707 .577 .707 r
F P
0 g
s
.64787 .76113 m .64319 .74275 L .64076 .73792 L p .707 .577 .707 r
F P
0 g
s
.64076 .73792 m .64545 .75631 L .64787 .76113 L p .707 .577 .707 r
F P
0 g
s
.64188 .56164 m .63945 .6169 L .63236 .62549 L p .707 .577 .707 r
F P
0 g
s
.83563 .57317 m .83319 .62843 L .82062 .61956 L p .707 .577 .707 r
F P
0 g
s
.82062 .61956 m .82305 .5643 L .83563 .57317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83835 .69178 m .84303 .71017 L .84061 .70534 L p .707 .577 .707 r
F P
0 g
s
.84061 .70534 m .83592 .68696 L .83835 .69178 L p .707 .577 .707 r
F P
0 g
s
.63522 .7011 m .6314 .66385 L .63851 .656 L p .707 .577 .707 r
F P
0 g
s
.3844 .61925 m .38684 .56399 L .3557 .56071 L p .707 .577 .707 r
F P
0 g
s
.38684 .56399 m .3844 .61925 L .41621 .61972 L p .707 .577 .707 r
F P
0 g
s
.41621 .61972 m .41865 .56446 L .38684 .56399 L p .707 .577 .707 r
F P
0 g
s
.63945 .6169 m .64188 .56164 L .65825 .55449 L p .707 .577 .707 r
F P
0 g
s
.41865 .56446 m .41621 .61972 L .44557 .61733 L p .707 .577 .707 r
F P
0 g
s
.44557 .61733 m .44801 .56206 L .41865 .56446 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35326 .61598 m .3557 .56071 L .32827 .55494 L p .707 .577 .707 r
F P
0 g
s
.3557 .56071 m .35326 .61598 L .3844 .61925 L p .707 .577 .707 r
F P
0 g
s
.63851 .656 m .64233 .69325 L .63522 .7011 L p .707 .577 .707 r
F P
0 g
s
.83144 .64031 m .83526 .67756 L .82279 .67202 L p .707 .577 .707 r
F P
0 g
s
.82279 .67202 m .81897 .63476 L .83144 .64031 L p .707 .577 .707 r
F P
0 g
s
.44801 .56206 m .44557 .61733 L .46961 .61231 L p .707 .577 .707 r
F P
0 g
s
.46961 .61231 m .47205 .55705 L .44801 .56206 L p .707 .577 .707 r
F P
0 g
s
.64545 .75631 m .64076 .73792 L .64801 .73084 L p .707 .577 .707 r
F P
0 g
s
.65825 .55449 m .65581 .60976 L .63945 .6169 L p .707 .577 .707 r
F P
0 g
s
.64801 .73084 m .65269 .74922 L .64545 .75631 L p .707 .577 .707 r
F P
0 g
s
.82305 .5643 m .82062 .61956 L .79959 .61186 L p .707 .577 .707 r
F P
0 g
s
.79959 .61186 m .80203 .5566 L .82305 .5643 L p .707 .577 .707 r
F P
0 g
s
.32583 .6102 m .32827 .55494 L .30724 .54724 L p .707 .577 .707 r
F P
0 g
s
.32827 .55494 m .32583 .6102 L .35326 .61598 L p .707 .577 .707 r
F P
0 g
s
.3867 .67439 m .38288 .63714 L .35187 .63851 L p .707 .577 .707 r
F P
0 g
s
.38288 .63714 m .3867 .67439 L .41838 .67067 L p .707 .577 .707 r
F P
0 g
s
.41838 .67067 m .41456 .63341 L .38288 .63714 L p .707 .577 .707 r
F P
0 g
s
.83592 .68696 m .84061 .70534 L .82875 .70325 L p .707 .577 .707 r
F P
0 g
s
.82875 .70325 m .82406 .68486 L .83592 .68696 L p .707 .577 .707 r
F P
0 g
s
.41456 .63341 m .41838 .67067 L .44764 .66494 L p .707 .577 .707 r
F P
0 g
s
.44764 .66494 m .44382 .62769 L .41456 .63341 L p .707 .577 .707 r
F P
0 g
s
.65581 .60976 m .65825 .55449 L .68229 .54948 L p .707 .577 .707 r
F P
0 g
s
.35569 .67577 m .35187 .63851 L .32458 .63739 L p .707 .577 .707 r
F P
0 g
s
.35187 .63851 m .35569 .67577 L .3867 .67439 L p .707 .577 .707 r
F P
0 g
s
.64233 .69325 m .63851 .656 L .65485 .64811 L p .707 .577 .707 r
F P
0 g
s
.44382 .62769 m .44764 .66494 L .47162 .65779 L p .707 .577 .707 r
F P
0 g
s
.47162 .65779 m .4678 .62054 L .44382 .62769 L p .707 .577 .707 r
F P
0 g
s
.39343 .71405 m .38875 .69567 L .3586 .70186 L p .707 .577 .707 r
F P
0 g
s
.38875 .69567 m .39343 .71405 L .42434 .70598 L p .707 .577 .707 r
F P
0 g
s
.42434 .70598 m .41966 .6876 L .38875 .69567 L p .707 .577 .707 r
F P
0 g
s
.47205 .55705 m .46961 .61231 L .48598 .60516 L p .707 .577 .707 r
F P
0 g
s
.48598 .60516 m .48841 .5499 L .47205 .55705 L p .707 .577 .707 r
F P
0 g
s
.41966 .6876 m .42434 .70598 L .45299 .69681 L p .707 .577 .707 r
F P
0 g
s
.45299 .69681 m .4483 .67843 L .41966 .6876 L p .707 .577 .707 r
F P
0 g
s
.30724 .54724 m .30481 .60251 L .32583 .6102 L p .707 .577 .707 r
F P
0 g
s
.32458 .63739 m .3284 .67464 L .35569 .67577 L p .707 .577 .707 r
F P
0 g
s
.65485 .64811 m .65867 .68537 L .64233 .69325 L p .707 .577 .707 r
F P
0 g
s
.3586 .70186 m .36328 .72024 L .39343 .71405 L p .707 .577 .707 r
F P
0 g
s
.81897 .63476 m .82279 .67202 L .80189 .66851 L p .707 .577 .707 r
F P
0 g
s
.80189 .66851 m .79806 .63126 L .81897 .63476 L p .707 .577 .707 r
F P
0 g
s
.80203 .5566 m .79959 .61186 L .77217 .60609 L p .707 .577 .707 r
F P
0 g
s
.77217 .60609 m .7746 .55083 L .80203 .5566 L p .707 .577 .707 r
F P
0 g
s
.36328 .72024 m .3586 .70186 L .33217 .70555 L p .707 .577 .707 r
F P
0 g
s
.30481 .60251 m .30724 .54724 L .29467 .53837 L p .707 .577 .707 r
F P
0 g
s
.68229 .54948 m .67985 .60474 L .65581 .60976 L p .707 .577 .707 r
F P
0 g
s
.3284 .67464 m .32458 .63739 L .30368 .63389 L p .707 .577 .707 r
F P
0 g
s
.65269 .74922 m .64801 .73084 L .66422 .72219 L p .707 .577 .707 r
F P
0 g
s
.33217 .70555 m .33685 .72393 L .36328 .72024 L p .707 .577 .707 r
F P
0 g
s
.4483 .67843 m .45299 .69681 L .47657 .68745 L p .707 .577 .707 r
F P
0 g
s
.47657 .68745 m .47189 .66907 L .4483 .67843 L p .707 .577 .707 r
F P
0 g
s
.67985 .60474 m .68229 .54948 L .71165 .54708 L p .707 .577 .707 r
F P
0 g
s
.66422 .72219 m .6689 .74057 L .65269 .74922 L p .707 .577 .707 r
F P
0 g
s
.82406 .68486 m .82875 .70325 L .80862 .70409 L p .707 .577 .707 r
F P
0 g
s
.80862 .70409 m .80393 .68571 L .82406 .68486 L p .707 .577 .707 r
F P
0 g
s
.30368 .63389 m .3075 .67114 L .3284 .67464 L p .707 .577 .707 r
F P
0 g
s
.4678 .62054 m .47162 .65779 L .48796 .64991 L p .707 .577 .707 r
F P
0 g
s
.48796 .64991 m .48414 .61265 L .4678 .62054 L p .707 .577 .707 r
F P
0 g
s
.65867 .68537 m .65485 .64811 L .67882 .64096 L p .707 .577 .707 r
F P
0 g
s
.7746 .55083 m .77217 .60609 L .74102 .60281 L p .707 .577 .707 r
F P
0 g
s
.74102 .60281 m .74346 .54755 L .7746 .55083 L p .707 .577 .707 r
F P
0 g
s
.29467 .53837 m .29223 .59364 L .30481 .60251 L p .707 .577 .707 r
F P
0 g
s
.70921 .60235 m .71165 .54708 L .74346 .54755 L p .707 .577 .707 r
F P
0 g
s
.71165 .54708 m .70921 .60235 L .67985 .60474 L p .707 .577 .707 r
F P
0 g
s
.33685 .72393 m .33217 .70555 L .31204 .70639 L p .707 .577 .707 r
F P
0 g
s
.48841 .5499 m .48598 .60516 L .49306 .59658 L p .707 .577 .707 r
F P
0 g
s
.49306 .59658 m .4955 .54132 L .48841 .5499 L p .707 .577 .707 r
F P
0 g
s
.74346 .54755 m .74102 .60281 L .70921 .60235 L p .707 .577 .707 r
F P
0 g
s
.67882 .64096 m .68265 .67821 L .65867 .68537 L p .707 .577 .707 r
F P
0 g
s
.79806 .63126 m .80189 .66851 L .7746 .66739 L p .707 .577 .707 r
F P
0 g
s
.7746 .66739 m .77078 .63014 L .79806 .63126 L p .707 .577 .707 r
F P
0 g
s
.31204 .70639 m .31672 .72478 L .33685 .72393 L p .707 .577 .707 r
F P
0 g
s
.47189 .66907 m .47657 .68745 L .49277 .6788 L p .707 .577 .707 r
F P
0 g
s
.49277 .6788 m .48809 .66042 L .47189 .66907 L p .707 .577 .707 r
F P
0 g
s
.3075 .67114 m .30368 .63389 L .29121 .62835 L p .707 .577 .707 r
F P
0 g
s
.29223 .59364 m .29467 .53837 L .29179 .5292 L p .707 .577 .707 r
F P
0 g
s
.6689 .74057 m .66422 .72219 L .6878 .71283 L p .707 .577 .707 r
F P
0 g
s
.68265 .67821 m .67882 .64096 L .70809 .63524 L p .707 .577 .707 r
F P
0 g
s
.6878 .71283 m .69248 .73121 L .6689 .74057 L p .707 .577 .707 r
F P
0 g
s
.80393 .68571 m .80862 .70409 L .78219 .70778 L p .707 .577 .707 r
F P
0 g
s
.78219 .70778 m .7775 .6894 L .80393 .68571 L p .707 .577 .707 r
F P
0 g
s
.29121 .62835 m .29503 .6656 L .3075 .67114 L p .707 .577 .707 r
F P
0 g
s
.48414 .61265 m .48796 .64991 L .49507 .64206 L p .707 .577 .707 r
F P
0 g
s
.49507 .64206 m .49125 .60481 L .48414 .61265 L p .707 .577 .707 r
F P
0 g
s
.77078 .63014 m .7746 .66739 L .74359 .66876 L p .707 .577 .707 r
F P
0 g
s
.74359 .66876 m .73977 .63151 L .77078 .63014 L p .707 .577 .707 r
F P
0 g
s
.70809 .63524 m .71191 .67249 L .68265 .67821 L p .707 .577 .707 r
F P
0 g
s
.31672 .72478 m .31204 .70639 L .30018 .7043 L p .707 .577 .707 r
F P
0 g
s
.71191 .67249 m .70809 .63524 L .73977 .63151 L p .707 .577 .707 r
F P
0 g
s
.29179 .5292 m .28935 .58446 L .29223 .59364 L p .707 .577 .707 r
F P
0 g
s
.73977 .63151 m .74359 .66876 L .71191 .67249 L p .707 .577 .707 r
F P
0 g
s
.30018 .7043 m .30486 .72268 L .31672 .72478 L p .707 .577 .707 r
F P
0 g
s
.69248 .73121 m .6878 .71283 L .71645 .70366 L p .707 .577 .707 r
F P
0 g
s
.4955 .54132 m .49306 .59658 L .49018 .5874 L p .707 .577 .707 r
F P
0 g
s
.49018 .5874 m .49262 .53214 L .4955 .54132 L p .707 .577 .707 r
F P
0 g
s
.48809 .66042 m .49277 .6788 L .50002 .67172 L p .707 .577 .707 r
F P
0 g
s
.50002 .67172 m .49534 .65333 L .48809 .66042 L p .707 .577 .707 r
F P
0 g
s
.71645 .70366 m .72113 .72204 L .69248 .73121 L p .707 .577 .707 r
F P
0 g
s
.7775 .6894 m .78219 .70778 L .75204 .71397 L p .707 .577 .707 r
F P
0 g
s
.75204 .71397 m .74736 .69559 L .7775 .6894 L p .707 .577 .707 r
F P
0 g
s
.29503 .6656 m .29121 .62835 L .28839 .62131 L p .707 .577 .707 r
F P
0 g
s
.72113 .72204 m .71645 .70366 L .74736 .69559 L p .707 .577 .707 r
F P
0 g
s
.28935 .58446 m .29179 .5292 L .29887 .52061 L p .707 .577 .707 r
F P
0 g
s
.74736 .69559 m .75204 .71397 L .72113 .72204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28839 .62131 m .29221 .65856 L .29503 .6656 L p .707 .577 .707 r
F P
0 g
s
.49125 .60481 m .49507 .64206 L .49225 .63502 L p .707 .577 .707 r
F P
0 g
s
.49225 .63502 m .48843 .59777 L .49125 .60481 L p .707 .577 .707 r
F P
0 g
s
.30486 .72268 m .30018 .7043 L .29775 .69947 L p .707 .577 .707 r
F P
0 g
s
.29887 .52061 m .29644 .57588 L .28935 .58446 L p .707 .577 .707 r
F P
0 g
s
.29775 .69947 m .30244 .71786 L .30486 .72268 L p .707 .577 .707 r
F P
0 g
s
.49262 .53214 m .49018 .5874 L .47761 .57853 L p .707 .577 .707 r
F P
0 g
s
.47761 .57853 m .48004 .52327 L .49262 .53214 L p .707 .577 .707 r
F P
0 g
s
.49534 .65333 m .50002 .67172 L .4976 .66689 L p .707 .577 .707 r
F P
0 g
s
.4976 .66689 m .49291 .64851 L .49534 .65333 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29221 .65856 m .28839 .62131 L .2955 .61346 L p .707 .577 .707 r
F P
0 g
s
.29644 .57588 m .29887 .52061 L .31524 .51346 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2955 .61346 m .29932 .65071 L .29221 .65856 L p .707 .577 .707 r
F P
0 g
s
.48843 .59777 m .49225 .63502 L .47978 .62948 L p .707 .577 .707 r
F P
0 g
s
.47978 .62948 m .47596 .59223 L .48843 .59777 L p .707 .577 .707 r
F P
0 g
s
.30244 .71786 m .29775 .69947 L .305 .69239 L p .707 .577 .707 r
F P
0 g
s
.31524 .51346 m .3128 .56873 L .29644 .57588 L p .707 .577 .707 r
F P
0 g
s
.48004 .52327 m .47761 .57853 L .45658 .57084 L p .707 .577 .707 r
F P
0 g
s
.45658 .57084 m .45902 .51557 L .48004 .52327 L p .707 .577 .707 r
F P
0 g
s
.305 .69239 m .30968 .71077 L .30244 .71786 L p .707 .577 .707 r
F P
0 g
s
.49291 .64851 m .4976 .66689 L .48574 .6648 L p .707 .577 .707 r
F P
0 g
s
.48574 .6648 m .48105 .64641 L .49291 .64851 L p .707 .577 .707 r
F P
0 g
s
.3128 .56873 m .31524 .51346 L .33928 .50845 L p .707 .577 .707 r
F P
0 g
s
.29932 .65071 m .2955 .61346 L .31184 .60558 L p .707 .577 .707 r
F P
0 g
s
.31184 .60558 m .31566 .64283 L .29932 .65071 L p .707 .577 .707 r
F P
0 g
s
.47596 .59223 m .47978 .62948 L .45887 .62598 L p .707 .577 .707 r
F P
0 g
s
.45887 .62598 m .45505 .58872 L .47596 .59223 L p .707 .577 .707 r
F P
0 g
s
.45902 .51557 m .45658 .57084 L .42915 .56506 L p .707 .577 .707 r
F P
0 g
s
.42915 .56506 m .43159 .5098 L .45902 .51557 L p .707 .577 .707 r
F P
0 g
s
.33928 .50845 m .33684 .56371 L .3128 .56873 L p .707 .577 .707 r
F P
0 g
s
.30968 .71077 m .305 .69239 L .32121 .68374 L p .707 .577 .707 r
F P
0 g
s
.33684 .56371 m .33928 .50845 L .36864 .50606 L p .707 .577 .707 r
F P
0 g
s
.32121 .68374 m .32589 .70212 L .30968 .71077 L p .707 .577 .707 r
F P
0 g
s
.48105 .64641 m .48574 .6648 L .46561 .66564 L p .707 .577 .707 r
F P
0 g
s
.46561 .66564 m .46092 .64725 L .48105 .64641 L p .707 .577 .707 r
F P
0 g
s
.31566 .64283 m .31184 .60558 L .33581 .59842 L p .707 .577 .707 r
F P
0 g
s
.43159 .5098 m .42915 .56506 L .39801 .56179 L p .707 .577 .707 r
F P
0 g
s
.39801 .56179 m .40045 .50652 L .43159 .5098 L p .707 .577 .707 r
F P
0 g
s
.3662 .56132 m .36864 .50606 L .40045 .50652 L p .707 .577 .707 r
F P
0 g
s
.36864 .50606 m .3662 .56132 L .33684 .56371 L p .707 .577 .707 r
F P
0 g
s
.33581 .59842 m .33963 .63568 L .31566 .64283 L p .707 .577 .707 r
F P
0 g
s
.40045 .50652 m .39801 .56179 L .3662 .56132 L p .707 .577 .707 r
F P
0 g
s
.45505 .58872 m .45887 .62598 L .43158 .62485 L p .707 .577 .707 r
F P
0 g
s
.43158 .62485 m .42776 .5876 L .45505 .58872 L p .707 .577 .707 r
F P
0 g
s
.32589 .70212 m .32121 .68374 L .34479 .67438 L p .707 .577 .707 r
F P
0 g
s
.33963 .63568 m .33581 .59842 L .36508 .5927 L p .707 .577 .707 r
F P
0 g
s
.34479 .67438 m .34947 .69276 L .32589 .70212 L p .707 .577 .707 r
F P
0 g
s
.46092 .64725 m .46561 .66564 L .43918 .66933 L p .707 .577 .707 r
F P
0 g
s
.43918 .66933 m .43449 .65095 L .46092 .64725 L p .707 .577 .707 r
F P
0 g
s
.42776 .5876 m .43158 .62485 L .40058 .62623 L p .707 .577 .707 r
F P
0 g
s
.40058 .62623 m .39676 .58897 L .42776 .5876 L p .707 .577 .707 r
F P
0 g
s
.36508 .5927 m .3689 .62995 L .33963 .63568 L p .707 .577 .707 r
F P
0 g
s
.3689 .62995 m .36508 .5927 L .39676 .58897 L p .707 .577 .707 r
F P
0 g
s
.39676 .58897 m .40058 .62623 L .3689 .62995 L p .707 .577 .707 r
F P
0 g
s
.34947 .69276 m .34479 .67438 L .37344 .66521 L p .707 .577 .707 r
F P
0 g
s
.37344 .66521 m .37812 .68359 L .34947 .69276 L p .707 .577 .707 r
F P
0 g
s
.43449 .65095 m .43918 .66933 L .40903 .67552 L p .707 .577 .707 r
F P
0 g
s
.40903 .67552 m .40435 .65713 L .43449 .65095 L p .707 .577 .707 r
F P
0 g
s
.37812 .68359 m .37344 .66521 L .40435 .65713 L p .707 .577 .707 r
F P
0 g
s
.40435 .65713 m .40903 .67552 L .37812 .68359 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo5@00Ogoo001mOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol007Eoo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Eoo`00LWoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`00LGoo001^Ool40004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001^Ool006aoo`8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP<006aoo`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00JWoo001XOol20002
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006Ioo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo
001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol0
06=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`P00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Eoo`00Ggoo1P000eYF00<005YF
FUH00UYF2@000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00eYF0P00IGoo001KOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH600000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000>OolB0015Ool0059oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Moo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPH003moo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo1@000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>goo001BOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000hOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002
000eOol0059oo`03001JEP0000=JEP04001JEUYFFUH800000eYF001JEP02FUHB0006FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF1P0015YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Woo001BOol01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
1P0015YF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000031oo`00
DWoo00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002mo
o`00DWoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001B
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=J
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH30005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo001DOol00`00FUH00005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000hOolG0006Ool20005FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
;Woo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00D0
05YF001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00P00;goo
000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF1@0015YF00<005YFFUH00P00;goo000/Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000EJEP00001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEP00
00P000=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<002moo`00:goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF200000=JEP0000000`001EYF10000UYF00<005YFFUH015YF1@0000=JEP00
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF5`0000=JEP00FUH00eYF0`00;goo000[Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000eYF00<005YFFUH00eYF20000eYF00@005YFFUIJEPX000IJEP03001JEUYF00AJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0009JEP03001JEP0002moo`00:goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0001L0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF
001oo`0^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`001EYF1@001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00<7oo000[
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEPL0009JEP03001JEP00
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ80
00AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
00080003FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002moo`00:goo00<0
05YF00000eYF00@005YFFUIJEPP00003FUH005YF009JEQ<0009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool002]oo`03001JEP0000=JEP@00003FUH005YF00IJ
EP03001JEUYF00EJEPH000AJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo000[Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF1P0015YF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo000[Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`001eYF00<005YFFUH01UYF00<005YFFUH00UYF3@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00:goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0UYF1@000eYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01EYF1P0015YF0P0015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000Ioo`P000=JEP04001JEUYF
FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP0000X000EJEP03001JEUYF00MJEP03001JEUYF00@000IJ
EP@00003FUH005YF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000goo000000030005
Ool400000eYF001JEP05FUH50002FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00MJEP03001JEUYF00AJEPD000=JEP04001JEUYFFUH30005FUH00`00FUIJEP03FUH20004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH70008Ool:0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000^Ool002]oo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQX000=JEP03001JEUYF00IJEP03001JEUYF
00@000QJEP06001JEP00001JEP001eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP03001JEP0001H000=JEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<002ioo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEPT0
00IJEP<000=JEP03001JEUYF00EJEP04001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPX00003FUH007oo02eoo`00;Goo00<005YF00001EYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH00UYF0`000eYF1@000UYF10001UYF00<005YFFUH015YF0`002UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00AJEP04001JEP00000_Ool0
02ioo`8000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEUYF1`000UYF00<005YFFUH01UYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050005FUH0
0`00FUIJEP03FUH00`00FUIJEP02000^Ool002moo`80009JEP@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00=JEP<0009oo`05001JEUYF001J
EP060005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000^Ool0035o
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001J
EUYF009JEP03001JEP0000<00003FUH00000009oo`D0009JEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000_Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00
FUH000050006FUH00`00FUIJEP07FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003
FUH0000002eoo`00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000UYF00@005YFFUIJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEPD000]J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01eYF00@005YF
FUIJEPP0009JEP@002eoo`00:goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF100000=JEP00FUH025YF
00<005YFFUH015YF1P0017oo0P001EYF00<005YF0000;Goo000ZOol01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP04001J
EUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP050005Ool400000eYF001JEP04FUH2000^Ool0
02Yoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH900000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF0000000500000eYF001JEP07FUH00`00FUIJEP04FUH50007Ool30005FUH00`00FUIJ
EP03FUH00`00Oomoo`0]Ool002Yoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90006Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP060008Ool20000
0eYF001JEP06FUH00`00FUIJEP02000`Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP0009oo`<000Ioo`@00003FUH00000009JEP03001JEUYF00T00005Ool005YFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH400000goo000000030005
Ool30004FUH00`00FUIJEP04FUH3000bOol002]oo`04001JEUYF0003FUH00`00FUIJEP03FUH60009
Ool:0006FUH600000eYF001JEP03FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP040005Ool500000goo000000020007FUH00`00FUIJ
EP04FUH00`00Oomoo`0bOol002]oo`04001JEUYF0003FUH00`00FUH0000G0002FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH3000:Ool50002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000eOol002]oo`04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH0
07oo00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF009J
EP@000Qoo`@000MJEP03001JEUYF00IJEP04001JEP00000gOol002]oo`04001JEUYF0002FUH01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH0
15YF1`000goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0005FUH01000FUH0
00000eYF00<007ooOol00Woo100000=JEP00FUH025YF00<005YFFUH01EYF0`00>Goo000[Ool00`00
FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH7
0002FUH00`00FUH000020002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00EJEP800004FUH005YFFUH60006FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol002aoo`04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF
00<005YFFUH00eYF00@005YFFUH0009oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP080003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50010Ool002aoo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000AGoo000/Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEUYFFUH007oo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3000
35YF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50019Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00Ool0
0eYF00<005YFFUH00eYF00<005YFFUH01UYF20002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH010001UYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@0
04ioo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=00001GooFUIJEUYF00001EYF00<005YFFUH00eYF0`001UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUIJEP80
009JEP03001JEUYF00=JEP04001JEUYFFUH6001BOol002eoo`800003FUH005YF00AJEP03001JEUYF
00EJEP@00003FUH005YF00MJEP03001JEUYF00EJEPH000Aoo`8000AJEP04001JEP000003FUH00`00
FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH40004FUH200000eYF001JEP02FUH600000eYF0000001EOol002moo`@000=JEP04
001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool200000eYF001JEP03FUH01000
FUIJEP000eYF00<005YFFUH00eYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009JEP`0009JEP8005Eoo`00<goo
1`0000=JEP00FUH01eYF00<005YFFUH015YF1@002Woo0P000eYF00<005YFFUH00eYF0P0000EooeYF
FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000EJEP03001JEUYF009JEP@005Eoo`00=Woo0P00
0eYF00<005YFFUH01UYF00<005YFFUH0100037oo0`001UYF00@005YFFUIJEP80009oo`=JEP04001J
EP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP03FUH3001EOol003Aoo`8000EJEP03001J
EUYF00EJEPT000Moo`@00003FUH005YF00IJEP04001JEP000004Ool3FUH200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30006FUH600000eYF001oo`1DOol0039oo`<000MJEP03001JEUYF009JEP8000Ao
o`D0009oo`D000EJEP03001JEUYF00AJEP<000Ioo`9JEP05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH000070002FUH01000FUH00000EWoo000`Ool20002FUH00`00FUIJEP05FUH00`00FUH0
00020006Ool70002FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo00=JEP00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000_
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH30007Ool60005FUH00`00FUIJEP06FUH01000FUH00000
2goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
0P00EGoo000^Ool20005FUH00`00FUH000030006Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000=Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH01000
FUIJEP00EGoo000]Ool01000FUIJEP0015YF0P0017oo1P001UYF00<005YFFUH01eYF00<005YFFUH0
10004Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH00eYF
00@005YFFUH005Eoo`00;Goo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP@001Eoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP02FUH>001D
Ool002eoo`04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000JOol20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUH00000FUH01P0017oo0P0015YF00@005YF000005Ao
o`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008001moo`<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEPL000Moo`800003FUH005YF00AJEP03001JEP0005Aoo`00;Woo0`0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH00UYF1@0097oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF1@002Woo0P000eYF00<005YFFUH00eYF0P00
EGoo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH6000[Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00004000;Ool30006FUH0
1000FUIJEUYF0P00EWoo000_Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04000eOol50008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH700000goo000000030006Ool400000eYF
001JEP06FUH01000FUH00000F7oo000aOol:000nOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04
FUH<00000eYF00000005Ool500000goo000000030006FUH00`00FUIJEP04FUH2001JOol007mooaH0
0003FUH005YF00EJEP03001JEP00008000Moo`H0009JEP03001JEUYF00IJEP03001JEUYF009JEP80
05aoo`00T7oo0P0015YF00<005YFFUH00eYF0`0027oo1P001EYF00<005YFFUH01UYF00@005YF0000
05ioo`00Sgoo00<005YF00001EYF00<005YF00000P001goo100000=JEP00FUH025YF00<005YFFUH0
1EYF0`00H7oo002?Ool00`00FUH00005FUH20004Ool60006FUH00`00FUIJEP07FUH00`00FUIJEP04
001SOol008moo`04001JEUYF0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4001WOol0
08moo`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<006]o
o`00T7oo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006ioo`00
T7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P00LGoo002@Ool20002FUH0
0`00FUIJEP03FUH01000FUIJEUYF2000Mgoo002AOol200000eYF001JEP02FUH6001oOol009=oo`D0
08Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58652 .75403 m .59046 .69902 L .55937 .6949 L p .707 .577 .707 r
F P
0 g
s
.59046 .69902 m .58652 .75403 L .61829 .75526 L p .707 .577 .707 r
F P
0 g
s
.61829 .75526 m .62222 .70025 L .59046 .69902 L p .707 .577 .707 r
F P
0 g
s
.62222 .70025 m .61829 .75526 L .64761 .75348 L p .707 .577 .707 r
F P
0 g
s
.64761 .75348 m .65155 .69847 L .62222 .70025 L p .707 .577 .707 r
F P
0 g
s
.55543 .7499 m .55937 .6949 L .53199 .68828 L p .707 .577 .707 r
F P
0 g
s
.55937 .6949 m .55543 .7499 L .58652 .75403 L p .707 .577 .707 r
F P
0 g
s
.65155 .69847 m .64761 .75348 L .67163 .74885 L p .707 .577 .707 r
F P
0 g
s
.67163 .74885 m .67556 .69384 L .65155 .69847 L p .707 .577 .707 r
F P
0 g
s
.52805 .74329 m .53199 .68828 L .511 .67982 L p .707 .577 .707 r
F P
0 g
s
.53199 .68828 m .52805 .74329 L .55543 .7499 L p .707 .577 .707 r
F P
0 g
s
.59008 .80831 m .58392 .77115 L .55319 .77455 L p .707 .577 .707 r
F P
0 g
s
.58392 .77115 m .59008 .80831 L .62152 .80276 L p .707 .577 .707 r
F P
0 g
s
.62152 .80276 m .61536 .7656 L .58392 .77115 L p .707 .577 .707 r
F P
0 g
s
.61536 .7656 m .62152 .80276 L .65059 .79559 L p .707 .577 .707 r
F P
0 g
s
.65059 .79559 m .64443 .75843 L .61536 .7656 L p .707 .577 .707 r
F P
0 g
s
.55319 .77455 m .55935 .81171 L .59008 .80831 L p .707 .577 .707 r
F P
0 g
s
.55935 .81171 m .55319 .77455 L .52617 .77545 L p .707 .577 .707 r
F P
0 g
s
.60008 .83994 m .59265 .82229 L .56414 .83334 L p .707 .577 .707 r
F P
0 g
s
.59265 .82229 m .60008 .83994 L .62952 .82748 L p .707 .577 .707 r
F P
0 g
s
.62952 .82748 m .62208 .80984 L .59265 .82229 L p .707 .577 .707 r
F P
0 g
s
.62208 .80984 m .62952 .82748 L .65699 .81483 L p .707 .577 .707 r
F P
0 g
s
.65699 .81483 m .64956 .79719 L .62208 .80984 L p .707 .577 .707 r
F P
0 g
s
.56414 .83334 m .57157 .85098 L .60008 .83994 L p .707 .577 .707 r
F P
0 g
s
.64443 .75843 m .65059 .79559 L .67444 .78751 L p .707 .577 .707 r
F P
0 g
s
.67444 .78751 m .66828 .75035 L .64443 .75843 L p .707 .577 .707 r
F P
0 g
s
.67556 .69384 m .67163 .74885 L .68799 .74183 L p .707 .577 .707 r
F P
0 g
s
.68799 .74183 m .69192 .68682 L .67556 .69384 L p .707 .577 .707 r
F P
0 g
s
.511 .67982 m .50707 .73483 L .52805 .74329 L p .707 .577 .707 r
F P
0 g
s
.52617 .77545 m .53233 .81261 L .55935 .81171 L p .707 .577 .707 r
F P
0 g
s
.57157 .85098 m .56414 .83334 L .53934 .8419 L p .707 .577 .707 r
F P
0 g
s
.50707 .73483 m .511 .67982 L .49847 .67034 L p .707 .577 .707 r
F P
0 g
s
.64956 .79719 m .65699 .81483 L .67982 .80323 L p .707 .577 .707 r
F P
0 g
s
.67982 .80323 m .67239 .78559 L .64956 .79719 L p .707 .577 .707 r
F P
0 g
s
.53934 .8419 m .54677 .85954 L .57157 .85098 L p .707 .577 .707 r
F P
0 g
s
.53233 .81261 m .52617 .77545 L .50551 .77377 L p .707 .577 .707 r
F P
0 g
s
.66828 .75035 m .67444 .78751 L .69074 .7793 L p .707 .577 .707 r
F P
0 g
s
.69074 .7793 m .68458 .74214 L .66828 .75035 L p .707 .577 .707 r
F P
0 g
s
.50551 .77377 m .51167 .81093 L .53233 .81261 L p .707 .577 .707 r
F P
0 g
s
.49847 .67034 m .49453 .72535 L .50707 .73483 L p .707 .577 .707 r
F P
0 g
s
.54677 .85954 m .53934 .8419 L .52068 .84712 L p .707 .577 .707 r
F P
0 g
s
.52068 .84712 m .52812 .86476 L .54677 .85954 L p .707 .577 .707 r
F P
0 g
s
.69192 .68682 m .68799 .74183 L .69508 .73312 L p .707 .577 .707 r
F P
0 g
s
.69508 .73312 m .69902 .67811 L .69192 .68682 L p .707 .577 .707 r
F P
0 g
s
.67239 .78559 m .67982 .80323 L .69577 .79381 L p .707 .577 .707 r
F P
0 g
s
.69577 .79381 m .68834 .77617 L .67239 .78559 L p .707 .577 .707 r
F P
0 g
s
.49453 .72535 m .49847 .67034 L .49561 .66077 L p .707 .577 .707 r
F P
0 g
s
.51167 .81093 m .50551 .77377 L .49323 .76968 L p .707 .577 .707 r
F P
0 g
s
.49323 .76968 m .4994 .80684 L .51167 .81093 L p .707 .577 .707 r
F P
0 g
s
.68458 .74214 m .69074 .7793 L .69789 .77177 L p .707 .577 .707 r
F P
0 g
s
.69789 .77177 m .69173 .73461 L .68458 .74214 L p .707 .577 .707 r
F P
0 g
s
.52812 .86476 m .52068 .84712 L .51 .84851 L p .707 .577 .707 r
F P
0 g
s
.51 .84851 m .51743 .86615 L .52812 .86476 L p .707 .577 .707 r
F P
0 g
s
.49561 .66077 m .49167 .71578 L .49453 .72535 L p .707 .577 .707 r
F P
0 g
s
.68834 .77617 m .69577 .79381 L .70328 .7875 L p .707 .577 .707 r
F P
0 g
s
.70328 .7875 m .69584 .76986 L .68834 .77617 L p .707 .577 .707 r
F P
0 g
s
.69902 .67811 m .69508 .73312 L .69222 .72355 L p .707 .577 .707 r
F P
0 g
s
.69222 .72355 m .69616 .66854 L .69902 .67811 L p .707 .577 .707 r
F P
0 g
s
.49167 .71578 m .49561 .66077 L .5027 .65206 L p .707 .577 .707 r
F P
0 g
s
.5027 .65206 m .49877 .70707 L .49167 .71578 L p .707 .577 .707 r
F P
0 g
s
.49877 .70707 m .5027 .65206 L .51906 .64504 L p .707 .577 .707 r
F P
0 g
s
.4994 .80684 m .49323 .76968 L .49054 .76357 L p .707 .577 .707 r
F P
0 g
s
.49054 .76357 m .4967 .80073 L .4994 .80684 L p .707 .577 .707 r
F P
0 g
s
.49769 .75605 m .50385 .79321 L .4967 .80073 L p .707 .577 .707 r
F P
0 g
s
.51906 .64504 m .51512 .70005 L .49877 .70707 L p .707 .577 .707 r
F P
0 g
s
.50385 .79321 m .49769 .75605 L .51399 .74784 L p .707 .577 .707 r
F P
0 g
s
.51399 .74784 m .52015 .785 L .50385 .79321 L p .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .48004 .31682 L .4361 .31656 L p .707 .577 .707 r
F P
0 g
s
.51512 .70005 m .51906 .64504 L .54308 .64041 L p .707 .577 .707 r
F P
0 g
s
.54308 .64041 m .53914 .69542 L .51512 .70005 L p .707 .577 .707 r
F P
0 g
s
.52015 .785 m .51399 .74784 L .53784 .73976 L p .707 .577 .707 r
F P
0 g
s
.53784 .73976 m .54401 .77692 L .52015 .785 L p .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .53784 .73976 L .54849 .73713 L p .707 .577 .707 r
F P
0 g
s
.54849 .73713 m .56691 .73259 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .54849 .73713 L .55487 .75589 L .707 .577 .707 r
F
.56691 .73259 m .57307 .76975 L .56062 .77282 L p F P
0 g
s
.56062 .77282 m .54401 .77692 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.55487 .75589 m .56691 .73259 L .56062 .77282 L .707 .577 .707 r
F
.52493 .31353 m .48004 .31682 L p .53472 .69659 L F P
0 g
s
.55213 .81755 m .54766 .73468 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .54308 .64041 L .56911 .63883 L p .707 .577 .707 r
F P
0 g
s
.56911 .63883 m .5724 .63863 L p .56675 .64828 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .56911 .63883 L .56675 .64828 L .707 .577 .707 r
F
.5724 .63863 m .56847 .69364 L .53914 .69542 L p F P
0 g
s
.54621 .7304 m .52493 .31353 L .53472 .69659 L .707 .577 .707 r
F
.54766 .73468 m .54721 .72638 L p .54621 .7304 L F P
0 g
s
.54721 .72638 m .52493 .31353 L p .54621 .7304 L .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .55213 .81755 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.48004 .31682 m .49409 .57699 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.49409 .57699 m .50725 .82083 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.56847 .69364 m .5724 .63863 L .60417 .63986 L p .707 .577 .707 r
F P
0 g
s
.60417 .63986 m .60023 .69487 L .56847 .69364 L p .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .56691 .73259 L .57934 .73039 L p .707 .577 .707 r
F P
0 g
s
.57934 .73039 m .59835 .72703 L p .57888 .75993 L .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .57934 .73039 L .57888 .75993 L .707 .577 .707 r
F
.63526 .64399 m .63132 .699 L .60023 .69487 L p F P
0 g
s
.60023 .69487 m .60417 .63986 L .63526 .64399 L p .707 .577 .707 r
F P
0 g
s
.62908 .72364 m .63524 .7608 L .60451 .76419 L p .707 .577 .707 r
F P
0 g
s
.60451 .76419 m .59835 .72703 L .62908 .72364 L p .707 .577 .707 r
F P
0 g
s
.59835 .72703 m .60451 .76419 L .57307 .76975 L p .707 .577 .707 r
F P
0 g
s
.64003 .78243 m .64746 .80007 L .61895 .81112 L p .707 .577 .707 r
F P
0 g
s
.61895 .81112 m .61152 .79348 L .64003 .78243 L p .707 .577 .707 r
F P
0 g
s
.58952 .82358 m .58208 .80593 L .61152 .79348 L p .707 .577 .707 r
F P
0 g
s
.61152 .79348 m .61895 .81112 L .58952 .82358 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .62749 .80195 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56636 .30703 m .58157 .58875 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.58157 .58875 m .59357 .81104 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56204 .83623 m .55461 .81858 L .58208 .80593 L p .707 .577 .707 r
F P
0 g
s
.58208 .80593 m .58952 .82358 L .56204 .83623 L p .707 .577 .707 r
F P
0 g
s
.52493 .31353 m .55213 .81755 L .59357 .81104 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .56636 .30703 L .52493 .31353 L p .707 .577 .707 r
F P
0 g
s
.46331 .82057 m .4361 .31656 L .3974 .31278 L p .707 .577 .707 r
F P
0 g
s
.4967 .80073 m .49054 .76357 L .49769 .75605 L p .707 .577 .707 r
F P
0 g
s
.4361 .31656 m .46331 .82057 L .50725 .82083 L p .707 .577 .707 r
F P
0 g
s
.69173 .73461 m .69789 .77177 L .6952 .76567 L p .707 .577 .707 r
F P
0 g
s
.6952 .76567 m .68904 .72851 L .69173 .73461 L p .707 .577 .707 r
F P
0 g
s
.51743 .86615 m .51 .84851 L .50832 .84591 L p .707 .578 .707 r
F P
0 g
s
.50832 .84591 m .51576 .86356 L .51743 .86615 L p .707 .578 .707 r
F P
0 g
s
.69584 .76986 m .70328 .7875 L .7016 .78491 L p .707 .578 .707 r
F P
0 g
s
.7016 .78491 m .69417 .76727 L .69584 .76986 L p .707 .578 .707 r
F P
0 g
s
.62749 .80195 m .60029 .29794 L .56636 .30703 L p .707 .577 .707 r
F P
0 g
s
.69616 .66854 m .69222 .72355 L .67969 .71407 L p .707 .577 .707 r
F P
0 g
s
.67969 .71407 m .68362 .65907 L .69616 .66854 L p .707 .577 .707 r
F P
0 g
s
.24351 .7104 m .24745 .65539 L .21636 .65127 L p .707 .577 .707 r
F P
0 g
s
.24745 .65539 m .24351 .7104 L .27528 .71163 L p .707 .577 .707 r
F P
0 g
s
.27528 .71163 m .27921 .65662 L .24745 .65539 L p .707 .577 .707 r
F P
0 g
s
.27921 .65662 m .27528 .71163 L .3046 .70985 L p .707 .577 .707 r
F P
0 g
s
.3046 .70985 m .30854 .65484 L .27921 .65662 L p .707 .577 .707 r
F P
0 g
s
.42461 .81679 m .3974 .31278 L .36774 .30585 L p .707 .577 .707 r
F P
0 g
s
.3974 .31278 m .42461 .81679 L .46331 .82057 L p .707 .577 .707 r
F P
0 g
s
.21242 .70628 m .21636 .65127 L .18898 .64465 L p .707 .577 .707 r
F P
0 g
s
.21636 .65127 m .21242 .70628 L .24351 .7104 L p .707 .577 .707 r
F P
0 g
s
.68904 .72851 m .6952 .76567 L .68292 .76157 L p .707 .577 .707 r
F P
0 g
s
.68292 .76157 m .67676 .72441 L .68904 .72851 L p .707 .577 .707 r
F P
0 g
s
.30854 .65484 m .3046 .70985 L .32862 .70522 L p .707 .577 .707 r
F P
0 g
s
.32862 .70522 m .33256 .65021 L .30854 .65484 L p .707 .577 .707 r
F P
0 g
s
.51576 .86356 m .50832 .84591 L .51583 .8396 L p .707 .577 .707 r
F P
0 g
s
.66264 .6506 m .6587 .70561 L .63132 .699 L p .707 .577 .707 r
F P
0 g
s
.63132 .699 m .63526 .64399 L .66264 .6506 L p .707 .577 .707 r
F P
0 g
s
.6561 .72273 m .66226 .7599 L .63524 .7608 L p .707 .577 .707 r
F P
0 g
s
.63524 .7608 m .62908 .72364 L .6561 .72273 L p .707 .577 .707 r
F P
0 g
s
.64746 .80007 m .64003 .78243 L .66483 .77388 L p .707 .577 .707 r
F P
0 g
s
.60029 .29794 m .62749 .80195 L .65059 .79117 L p .707 .577 .707 r
F P
0 g
s
.65059 .79117 m .62339 .28716 L .60029 .29794 L p .707 .577 .707 r
F P
0 g
s
.51583 .8396 m .52326 .85724 L .51576 .86356 L p .707 .577 .707 r
F P
0 g
s
.68362 .65907 m .67969 .71407 L .6587 .70561 L p .707 .577 .707 r
F P
0 g
s
.6587 .70561 m .66264 .6506 L .68362 .65907 L p .707 .577 .707 r
F P
0 g
s
.18504 .69966 m .18898 .64465 L .16799 .63619 L p .707 .577 .707 r
F P
0 g
s
.18898 .64465 m .18504 .69966 L .21242 .70628 L p .707 .577 .707 r
F P
0 g
s
.69417 .76727 m .7016 .78491 L .69092 .78629 L p .707 .577 .707 r
F P
0 g
s
.69092 .78629 m .68348 .76865 L .69417 .76727 L p .707 .577 .707 r
F P
0 g
s
.24708 .76224 m .24091 .72508 L .21018 .72847 L p .707 .577 .707 r
F P
0 g
s
.24091 .72508 m .24708 .76224 L .27851 .75668 L p .707 .577 .707 r
F P
0 g
s
.27851 .75668 m .27235 .71952 L .24091 .72508 L p .707 .577 .707 r
F P
0 g
s
.27235 .71952 m .27851 .75668 L .30758 .74952 L p .707 .577 .707 r
F P
0 g
s
.30758 .74952 m .30142 .71235 L .27235 .71952 L p .707 .577 .707 r
F P
0 g
s
.21018 .72847 m .21634 .76563 L .24708 .76224 L p .707 .577 .707 r
F P
0 g
s
.21634 .76563 m .21018 .72847 L .18316 .72938 L p .707 .577 .707 r
F P
0 g
s
.25707 .80048 m .24964 .78283 L .22113 .79388 L p .707 .577 .707 r
F P
0 g
s
.24964 .78283 m .25707 .80048 L .28651 .78802 L p .707 .577 .707 r
F P
0 g
s
.28651 .78802 m .27908 .77038 L .24964 .78283 L p .707 .577 .707 r
F P
0 g
s
.30142 .71235 m .30758 .74952 L .33143 .74143 L p .707 .577 .707 r
F P
0 g
s
.33143 .74143 m .32527 .70427 L .30142 .71235 L p .707 .577 .707 r
F P
0 g
s
.27908 .77038 m .28651 .78802 L .31399 .77537 L p .707 .577 .707 r
F P
0 g
s
.31399 .77537 m .30655 .75773 L .27908 .77038 L p .707 .577 .707 r
F P
0 g
s
.22113 .79388 m .22856 .81152 L .25707 .80048 L p .707 .577 .707 r
F P
0 g
s
.33256 .65021 m .32862 .70522 L .34498 .6982 L p .707 .577 .707 r
F P
0 g
s
.34498 .6982 m .34891 .6432 L .33256 .65021 L p .707 .577 .707 r
F P
0 g
s
.39494 .80986 m .36774 .30585 L .35001 .29645 L p .707 .577 .707 r
F P
0 g
s
.36774 .30585 m .39494 .80986 L .42461 .81679 L p .707 .577 .707 r
F P
0 g
s
.18316 .72938 m .18932 .76654 L .21634 .76563 L p .707 .577 .707 r
F P
0 g
s
.16799 .63619 m .16406 .6912 L .18504 .69966 L p .707 .577 .707 r
F P
0 g
s
.67676 .72441 m .68292 .76157 L .66226 .7599 L p .707 .577 .707 r
F P
0 g
s
.66226 .7599 m .6561 .72273 L .67676 .72441 L p .707 .577 .707 r
F P
0 g
s
.16406 .6912 m .16799 .63619 L .15546 .62671 L p .707 .577 .707 r
F P
0 g
s
.22856 .81152 m .22113 .79388 L .19633 .80243 L p .707 .577 .707 r
F P
0 g
s
.30655 .75773 m .31399 .77537 L .33682 .76377 L p .707 .577 .707 r
F P
0 g
s
.33682 .76377 m .32938 .74613 L .30655 .75773 L p .707 .577 .707 r
F P
0 g
s
.19633 .80243 m .20376 .82008 L .22856 .81152 L p .707 .577 .707 r
F P
0 g
s
.18932 .76654 m .18316 .72938 L .1625 .7277 L p .707 .577 .707 r
F P
0 g
s
.52326 .85724 m .51583 .8396 L .53178 .83018 L p .707 .577 .707 r
F P
0 g
s
.53178 .83018 m .53921 .84783 L .52326 .85724 L p .707 .577 .707 r
F P
0 g
s
.68348 .76865 m .69092 .78629 L .67226 .79152 L p .707 .577 .707 r
F P
0 g
s
.67226 .79152 m .66483 .77388 L .68348 .76865 L p .707 .577 .707 r
F P
0 g
s
.32527 .70427 m .33143 .74143 L .34773 .73323 L p .707 .577 .707 r
F P
0 g
s
.34773 .73323 m .34157 .69606 L .32527 .70427 L p .707 .577 .707 r
F P
0 g
s
.1625 .7277 m .16866 .76486 L .18932 .76654 L p .707 .577 .707 r
F P
0 g
s
.62339 .28716 m .65059 .79117 L .6606 .77974 L p .707 .577 .707 r
F P
0 g
s
.6606 .77974 m .6334 .27573 L .62339 .28716 L p .707 .577 .707 r
F P
0 g
s
.15546 .62671 m .15152 .68172 L .16406 .6912 L p .707 .577 .707 r
F P
0 g
s
.20376 .82008 m .19633 .80243 L .17768 .80766 L p .707 .577 .707 r
F P
0 g
s
.34891 .6432 m .34498 .6982 L .35207 .68949 L p .707 .577 .707 r
F P
0 g
s
.35207 .68949 m .35601 .63448 L .34891 .6432 L p .707 .577 .707 r
F P
0 g
s
.17768 .80766 m .18511 .8253 L .20376 .82008 L p .707 .577 .707 r
F P
0 g
s
.32938 .74613 m .33682 .76377 L .35276 .75435 L p .707 .577 .707 r
F P
0 g
s
.35276 .75435 m .34533 .73671 L .32938 .74613 L p .707 .577 .707 r
F P
0 g
s
.16866 .76486 m .1625 .7277 L .15023 .72361 L p .707 .577 .707 r
F P
0 g
s
.15152 .68172 m .15546 .62671 L .1526 .61714 L p .707 .577 .707 r
F P
0 g
s
.53921 .84783 m .53178 .83018 L .55461 .81858 L p .707 .577 .707 r
F P
0 g
s
.55461 .81858 m .56204 .83623 L .53921 .84783 L p .707 .577 .707 r
F P
0 g
s
.66483 .77388 m .67226 .79152 L .64746 .80007 L p .707 .577 .707 r
F P
0 g
s
.37721 .80047 m .35001 .29645 L .34595 .28551 L p .707 .577 .707 r
F P
0 g
s
.35001 .29645 m .37721 .80047 L .39494 .80986 L p .707 .577 .707 r
F P
0 g
s
.15023 .72361 m .15639 .76077 L .16866 .76486 L p .707 .577 .707 r
F P
0 g
s
.34157 .69606 m .34773 .73323 L .35488 .7257 L p .707 .577 .707 r
F P
0 g
s
.35488 .7257 m .34872 .68854 L .34157 .69606 L p .707 .577 .707 r
F P
0 g
s
.18511 .8253 m .17768 .80766 L .16699 .80904 L p .707 .577 .707 r
F P
0 g
s
.1526 .61714 m .14866 .67215 L .15152 .68172 L p .707 .577 .707 r
F P
0 g
s
.16699 .80904 m .17442 .82669 L .18511 .8253 L p .707 .577 .707 r
F P
0 g
s
.34533 .73671 m .35276 .75435 L .36027 .74804 L p .707 .577 .707 r
F P
0 g
s
.36027 .74804 m .35283 .7304 L .34533 .73671 L p .707 .577 .707 r
F P
0 g
s
.35601 .63448 m .35207 .68949 L .34921 .67992 L p .707 .577 .707 r
F P
0 g
s
.34921 .67992 m .35315 .62491 L .35601 .63448 L p .707 .577 .707 r
F P
0 g
s
.62934 .26478 m .65654 .7688 L .63881 .7594 L p .707 .577 .707 r
F P
0 g
s
.64427 .64279 m .64654 .61106 L p .63567 .5783 L .707 .577 .707 r
F P
0 g
s
.65338 .70144 m .6334 .27573 L .65898 .77536 L .707 .577 .707 r
F
.65654 .7688 m .64455 .5465 L p .6334 .27573 L F P
0 g
s
.64455 .5465 m .62934 .26478 L .6317 .27114 L p .707 .577 .707 r
F P
0 g
s
.6317 .27114 m .6334 .27573 L p .64455 .5465 L .707 .577 .707 r
F P
0 g
s
.6334 .27573 m .6606 .77974 L .65898 .77536 L p .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .66338 .68341 L .65089 .6824 L p .707 .577 .707 r
F P
0 g
s
.65089 .6824 m .64272 .68173 L p .65145 .69437 L .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .65089 .6824 L .65145 .69437 L .707 .577 .707 r
F
.64654 .61106 m .64821 .58778 L .64457 .58503 L p F P
0 g
s
.64457 .58503 m .63567 .5783 L p .64654 .61106 L .707 .577 .707 r
F P
0 g
s
.65898 .77536 m .65654 .7688 L p .65338 .70144 L .707 .577 .707 r
F P
0 g
s
.15639 .76077 m .15023 .72361 L .14753 .7175 L p .707 .577 .707 r
F P
0 g
s
.14866 .67215 m .1526 .61714 L .15969 .60843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.14753 .7175 m .15369 .75466 L .15639 .76077 L p .707 .577 .707 r
F P
0 g
s
.34872 .68854 m .35488 .7257 L .35219 .71959 L p .707 .577 .707 r
F P
0 g
s
.35219 .71959 m .34603 .68243 L .34872 .68854 L p .707 .577 .707 r
F P
0 g
s
.17442 .82669 m .16699 .80904 L .16531 .80645 L p .707 .578 .707 r
F P
0 g
s
.15969 .60843 m .15576 .66344 L .14866 .67215 L p .707 .577 .707 r
F P
0 g
s
.16531 .80645 m .17275 .8241 L .17442 .82669 L p .707 .578 .707 r
F P
0 g
s
.35283 .7304 m .36027 .74804 L .35859 .74545 L p .707 .578 .707 r
F P
0 g
s
.35859 .74545 m .35116 .7278 L .35283 .7304 L p .707 .578 .707 r
F P
0 g
s
.34595 .28551 m .37315 .78952 L .37721 .80047 L p .707 .577 .707 r
F P
0 g
s
.37315 .78952 m .34595 .28551 L .35596 .27408 L p .707 .577 .707 r
F P
0 g
s
.35315 .62491 m .34921 .67992 L .33668 .67045 L p .707 .577 .707 r
F P
0 g
s
.33668 .67045 m .34061 .61544 L .35315 .62491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15576 .66344 m .15969 .60843 L .17605 .60141 L p .707 .577 .707 r
F P
0 g
s
.15369 .75466 m .14753 .7175 L .15468 .70997 L p .707 .577 .707 r
F P
0 g
s
.15468 .70997 m .16085 .74713 L .15369 .75466 L p .707 .577 .707 r
F P
0 g
s
.34603 .68243 m .35219 .71959 L .33991 .7155 L p .707 .577 .707 r
F P
0 g
s
.33991 .7155 m .33375 .67834 L .34603 .68243 L p .707 .577 .707 r
F P
0 g
s
.63881 .7594 m .61161 .25539 L .62934 .26478 L p .707 .577 .707 r
F P
0 g
s
.17605 .60141 m .17211 .65642 L .15576 .66344 L p .707 .577 .707 r
F P
0 g
s
.17275 .8241 m .16531 .80645 L .17282 .80014 L p .707 .577 .707 r
F P
0 g
s
.34061 .61544 m .33668 .67045 L .31569 .66198 L p .707 .577 .707 r
F P
0 g
s
.31569 .66198 m .31963 .60697 L .34061 .61544 L p .707 .577 .707 r
F P
0 g
s
.17282 .80014 m .18025 .81778 L .17275 .8241 L p .707 .577 .707 r
F P
0 g
s
.35116 .7278 m .35859 .74545 L .34791 .74683 L p .707 .577 .707 r
F P
0 g
s
.34791 .74683 m .34047 .72919 L .35116 .7278 L p .707 .577 .707 r
F P
0 g
s
.17211 .65642 m .17605 .60141 L .20007 .59678 L p .707 .577 .707 r
F P
0 g
s
.16085 .74713 m .15468 .70997 L .17098 .70176 L p .707 .577 .707 r
F P
0 g
s
.38316 .7781 m .35596 .27408 L .37905 .2633 L p .707 .577 .707 r
F P
0 g
s
.35596 .27408 m .38316 .7781 L .37315 .78952 L p .707 .577 .707 r
F P
0 g
s
.17098 .70176 m .17714 .73893 L .16085 .74713 L p .707 .577 .707 r
F P
0 g
s
.33375 .67834 m .33991 .7155 L .31925 .71382 L p .707 .577 .707 r
F P
0 g
s
.31925 .71382 m .31309 .67666 L .33375 .67834 L p .707 .577 .707 r
F P
0 g
s
.31963 .60697 m .31569 .66198 L .28831 .65537 L p .707 .577 .707 r
F P
0 g
s
.28831 .65537 m .29225 .60036 L .31963 .60697 L p .707 .577 .707 r
F P
0 g
s
.20007 .59678 m .19613 .65179 L .17211 .65642 L p .707 .577 .707 r
F P
0 g
s
.19613 .65179 m .20007 .59678 L .22939 .595 L p .707 .577 .707 r
F P
0 g
s
.18025 .81778 m .17282 .80014 L .18877 .79072 L p .707 .577 .707 r
F P
0 g
s
.18877 .79072 m .1962 .80837 L .18025 .81778 L p .707 .577 .707 r
F P
0 g
s
.34047 .72919 m .34791 .74683 L .32925 .75206 L p .707 .577 .707 r
F P
0 g
s
.32925 .75206 m .32182 .73442 L .34047 .72919 L p .707 .577 .707 r
F P
0 g
s
.61161 .25539 m .63389 .66823 L p .63308 .671 L .707 .577 .707 r
F P
0 g
s
.60915 .75248 m .61005 .5702 L .63308 .671 L .707 .577 .707 r
F
.61005 .5702 m .61161 .25539 L .63308 .671 L F
.64888 .71889 m .64272 .68173 L .63494 .67914 L p F P
0 g
s
.63881 .7594 m .62015 .75504 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63389 .66823 m .63434 .67654 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63434 .67654 m .63881 .7594 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.62015 .75504 m .60915 .75248 L p .63389 .66823 L .707 .577 .707 r
F P
0 g
s
.63044 .67764 m .6366 .7148 L .64362 .71714 L p .707 .577 .707 r
F P
0 g
s
.64362 .71714 m .64888 .71889 L p .63894 .69665 L .707 .577 .707 r
F P
0 g
s
.63894 .69665 m .63044 .67764 L .64362 .71714 L .707 .577 .707 r
F
.63494 .67914 m .63044 .67764 L p .63894 .69665 L F P
0 g
s
.64888 .71889 m .63494 .67914 L .63894 .69665 L .707 .577 .707 r
F
.63567 .5783 m .63174 .63331 L .6386 .6385 L p F P
0 g
s
.6386 .6385 m .64427 .64279 L p .64137 .62102 L .707 .577 .707 r
F P
0 g
s
.64137 .62102 m .63567 .5783 L .6386 .6385 L .707 .577 .707 r
F
.60915 .75248 m .58194 .24846 L .61161 .25539 L p F P
0 g
s
.17714 .73893 m .17098 .70176 L .19483 .69368 L p .707 .577 .707 r
F P
0 g
s
.29225 .60036 m .28831 .65537 L .25722 .65124 L p .707 .577 .707 r
F P
0 g
s
.25722 .65124 m .26116 .59623 L .29225 .60036 L p .707 .577 .707 r
F P
0 g
s
.22546 .65001 m .22939 .595 L .26116 .59623 L p .707 .577 .707 r
F P
0 g
s
.22939 .595 m .22546 .65001 L .19613 .65179 L p .707 .577 .707 r
F P
0 g
s
.26116 .59623 m .25722 .65124 L .22546 .65001 L p .707 .577 .707 r
F P
0 g
s
.31309 .67666 m .31925 .71382 L .29223 .71472 L p .707 .577 .707 r
F P
0 g
s
.29223 .71472 m .28607 .67756 L .31309 .67666 L p .707 .577 .707 r
F P
0 g
s
.19483 .69368 m .201 .73084 L .17714 .73893 L p .707 .577 .707 r
F P
0 g
s
.72373 .66199 m .72766 .60698 L .69657 .60286 L p .707 .577 .707 r
F P
0 g
s
.72766 .60698 m .72373 .66199 L .75549 .66322 L p .707 .577 .707 r
F P
0 g
s
.75549 .66322 m .75943 .60821 L .72766 .60698 L p .707 .577 .707 r
F P
0 g
s
.37905 .2633 m .40626 .76731 L .38316 .7781 L p .707 .577 .707 r
F P
0 g
s
.40626 .76731 m .37905 .2633 L .41298 .25421 L p .707 .577 .707 r
F P
0 g
s
.75943 .60821 m .75549 .66322 L .78482 .66144 L p .707 .577 .707 r
F P
0 g
s
.78482 .66144 m .78875 .60643 L .75943 .60821 L p .707 .577 .707 r
F P
0 g
s
.1962 .80837 m .18877 .79072 L .2116 .77912 L p .707 .577 .707 r
F P
0 g
s
.69263 .65787 m .69657 .60286 L .66919 .59624 L p .707 .577 .707 r
F P
0 g
s
.69657 .60286 m .69263 .65787 L .72373 .66199 L p .707 .577 .707 r
F P
0 g
s
.2116 .77912 m .21903 .79676 L .1962 .80837 L p .707 .577 .707 r
F P
0 g
s
.201 .73084 m .19483 .69368 L .2239 .68651 L p .707 .577 .707 r
F P
0 g
s
.32182 .73442 m .32925 .75206 L .30445 .76061 L p .707 .577 .707 r
F P
0 g
s
.30445 .76061 m .29702 .74297 L .32182 .73442 L p .707 .577 .707 r
F P
0 g
s
.28607 .67756 m .29223 .71472 L .2615 .71812 L p .707 .577 .707 r
F P
0 g
s
.2615 .71812 m .25534 .68096 L .28607 .67756 L p .707 .577 .707 r
F P
0 g
s
.2239 .68651 m .23006 .72367 L .201 .73084 L p .707 .577 .707 r
F P
0 g
s
.78875 .60643 m .78482 .66144 L .80883 .65681 L p .707 .577 .707 r
F P
0 g
s
.80883 .65681 m .81277 .6018 L .78875 .60643 L p .707 .577 .707 r
F P
0 g
s
.58194 .24846 m .60915 .75248 L .57045 .7487 L p .707 .577 .707 r
F P
0 g
s
.57045 .7487 m .54324 .24468 L .58194 .24846 L p .707 .577 .707 r
F P
0 g
s
.23006 .72367 m .2239 .68651 L .25534 .68096 L p .707 .577 .707 r
F P
0 g
s
.25534 .68096 m .2615 .71812 L .23006 .72367 L p .707 .577 .707 r
F P
0 g
s
.66526 .65125 m .66919 .59624 L .64821 .58778 L p .707 .577 .707 r
F P
0 g
s
.66919 .59624 m .66526 .65125 L .69263 .65787 L p .707 .577 .707 r
F P
0 g
s
.72729 .71628 m .72113 .67911 L .69039 .68251 L p .707 .577 .707 r
F P
0 g
s
.72113 .67911 m .72729 .71628 L .75873 .71072 L p .707 .577 .707 r
F P
0 g
s
.75873 .71072 m .75257 .67356 L .72113 .67911 L p .707 .577 .707 r
F P
0 g
s
.75257 .67356 m .75873 .71072 L .78779 .70355 L p .707 .577 .707 r
F P
0 g
s
.78779 .70355 m .78163 .66639 L .75257 .67356 L p .707 .577 .707 r
F P
0 g
s
.21903 .79676 m .2116 .77912 L .23907 .76647 L p .707 .577 .707 r
F P
0 g
s
.29702 .74297 m .30445 .76061 L .27594 .77166 L p .707 .577 .707 r
F P
0 g
s
.27594 .77166 m .26851 .75402 L .29702 .74297 L p .707 .577 .707 r
F P
0 g
s
.23907 .76647 m .24651 .78412 L .21903 .79676 L p .707 .577 .707 r
F P
0 g
s
.44019 .75822 m .41298 .25421 L .45442 .2477 L p .707 .577 .707 r
F P
0 g
s
.41298 .25421 m .44019 .75822 L .40626 .76731 L p .707 .577 .707 r
F P
0 g
s
.69039 .68251 m .69656 .71967 L .72729 .71628 L p .707 .577 .707 r
F P
0 g
s
.69656 .71967 m .69039 .68251 L .66338 .68341 L p .707 .577 .707 r
F P
0 g
s
.73729 .7479 m .72985 .73026 L .70134 .7413 L p .707 .577 .707 r
F P
0 g
s
.72985 .73026 m .73729 .7479 L .76672 .73544 L p .707 .577 .707 r
F P
0 g
s
.76672 .73544 m .75929 .7178 L .72985 .73026 L p .707 .577 .707 r
F P
0 g
s
.75929 .7178 m .76672 .73544 L .7942 .7228 L p .707 .577 .707 r
F P
0 g
s
.7942 .7228 m .78677 .70515 L .75929 .7178 L p .707 .577 .707 r
F P
0 g
s
.70134 .7413 m .70877 .75895 L .73729 .7479 L p .707 .577 .707 r
F P
0 g
s
.24651 .78412 m .23907 .76647 L .26851 .75402 L p .707 .577 .707 r
F P
0 g
s
.78163 .66639 m .78779 .70355 L .81165 .69547 L p .707 .577 .707 r
F P
0 g
s
.81165 .69547 m .80548 .65831 L .78163 .66639 L p .707 .577 .707 r
F P
0 g
s
.26851 .75402 m .27594 .77166 L .24651 .78412 L p .707 .577 .707 r
F P
0 g
s
.81277 .6018 m .80883 .65681 L .82519 .6498 L p .707 .577 .707 r
F P
0 g
s
.82519 .6498 m .82913 .59479 L .81277 .6018 L p .707 .577 .707 r
F P
0 g
s
.64821 .58778 m .64427 .64279 L .66526 .65125 L p .707 .577 .707 r
F P
0 g
s
.66338 .68341 m .66954 .72057 L .69656 .71967 L p .707 .577 .707 r
F P
0 g
s
.54324 .24468 m .57045 .7487 L .52651 .74843 L p .707 .577 .707 r
F P
0 g
s
.52651 .74843 m .4993 .24442 L .54324 .24468 L p .707 .577 .707 r
F P
0 g
s
.70877 .75895 m .70134 .7413 L .67654 .74986 L p .707 .577 .707 r
F P
0 g
s
.78677 .70515 m .7942 .7228 L .81703 .71119 L p .707 .577 .707 r
F P
0 g
s
.81703 .71119 m .8096 .69355 L .78677 .70515 L p .707 .577 .707 r
F P
0 g
s
.67654 .74986 m .68398 .7675 L .70877 .75895 L p .707 .577 .707 r
F P
0 g
s
.48162 .75172 m .45442 .2477 L .4993 .24442 L p .707 .577 .707 r
F P
0 g
s
.45442 .2477 m .48162 .75172 L .44019 .75822 L p .707 .577 .707 r
F P
0 g
s
.4993 .24442 m .52651 .74843 L .48162 .75172 L p .707 .577 .707 r
F P
0 g
s
.80548 .65831 m .81165 .69547 L .82795 .68726 L p .707 .577 .707 r
F P
0 g
s
.82795 .68726 m .82178 .6501 L .80548 .65831 L p .707 .577 .707 r
F P
0 g
s
.64272 .68173 m .64888 .71889 L .66954 .72057 L p .707 .577 .707 r
F P
0 g
s
.68398 .7675 m .67654 .74986 L .65789 .75508 L p .707 .577 .707 r
F P
0 g
s
.65789 .75508 m .66532 .77273 L .68398 .7675 L p .707 .577 .707 r
F P
0 g
s
.82913 .59479 m .82519 .6498 L .83229 .64108 L p .707 .577 .707 r
F P
0 g
s
.83229 .64108 m .83622 .58607 L .82913 .59479 L p .707 .577 .707 r
F P
0 g
s
.8096 .69355 m .81703 .71119 L .83298 .70178 L p .707 .577 .707 r
F P
0 g
s
.83298 .70178 m .82554 .68413 L .8096 .69355 L p .707 .577 .707 r
F P
0 g
s
.63174 .63331 m .63567 .5783 L .63281 .56873 L p .707 .577 .707 r
F P
0 g
s
.82178 .6501 m .82795 .68726 L .8351 .67974 L p .707 .577 .707 r
F P
0 g
s
.8351 .67974 m .82894 .64258 L .82178 .6501 L p .707 .577 .707 r
F P
0 g
s
.66532 .77273 m .65789 .75508 L .6472 .75647 L p .707 .577 .707 r
F P
0 g
s
.6472 .75647 m .65463 .77411 L .66532 .77273 L p .707 .577 .707 r
F P
0 g
s
.63281 .56873 m .62888 .62374 L .63174 .63331 L p .707 .577 .707 r
F P
0 g
s
.82554 .68413 m .83298 .70178 L .84048 .69546 L p .707 .577 .707 r
F P
0 g
s
.84048 .69546 m .83305 .67782 L .82554 .68413 L p .707 .577 .707 r
F P
0 g
s
.83622 .58607 m .83229 .64108 L .82943 .63151 L p .707 .577 .707 r
F P
0 g
s
.82943 .63151 m .83336 .5765 L .83622 .58607 L p .707 .577 .707 r
F P
0 g
s
.6366 .7148 m .63044 .67764 L .62774 .67153 L p .707 .577 .707 r
F P
0 g
s
.62888 .62374 m .63281 .56873 L .63991 .56002 L p .707 .577 .707 r
F P
0 g
s
.62774 .67153 m .63391 .70869 L .6366 .7148 L p .707 .577 .707 r
F P
0 g
s
.82894 .64258 m .8351 .67974 L .8324 .67363 L p .707 .577 .707 r
F P
0 g
s
.8324 .67363 m .82624 .63647 L .82894 .64258 L p .707 .577 .707 r
F P
0 g
s
.65463 .77411 m .6472 .75647 L .64553 .75388 L p .707 .578 .707 r
F P
0 g
s
.64553 .75388 m .65296 .77152 L .65463 .77411 L p .707 .578 .707 r
F P
0 g
s
.63991 .56002 m .63597 .61503 L .62888 .62374 L p .707 .577 .707 r
F P
0 g
s
.83305 .67782 m .84048 .69546 L .83881 .69287 L p .707 .578 .707 r
F P
0 g
s
.83881 .69287 m .83137 .67523 L .83305 .67782 L p .707 .578 .707 r
F P
0 g
s
.83336 .5765 m .82943 .63151 L .81689 .62204 L p .707 .577 .707 r
F P
0 g
s
.81689 .62204 m .82083 .56703 L .83336 .5765 L p .707 .577 .707 r
F P
0 g
s
.38072 .61836 m .38465 .56335 L .35356 .55923 L p .707 .577 .707 r
F P
0 g
s
.38465 .56335 m .38072 .61836 L .41248 .61959 L p .707 .577 .707 r
F P
0 g
s
.41248 .61959 m .41642 .56458 L .38465 .56335 L p .707 .577 .707 r
F P
0 g
s
.63597 .61503 m .63991 .56002 L .65626 .553 L p .707 .577 .707 r
F P
0 g
s
.63391 .70869 m .62774 .67153 L .6349 .66401 L p .707 .577 .707 r
F P
0 g
s
.41642 .56458 m .41248 .61959 L .44181 .61781 L p .707 .577 .707 r
F P
0 g
s
.44181 .61781 m .44574 .5628 L .41642 .56458 L p .707 .577 .707 r
F P
0 g
s
.34962 .61424 m .35356 .55923 L .32618 .55261 L p .707 .577 .707 r
F P
0 g
s
.35356 .55923 m .34962 .61424 L .38072 .61836 L p .707 .577 .707 r
F P
0 g
s
.6349 .66401 m .64106 .70117 L .63391 .70869 L p .707 .577 .707 r
F P
0 g
s
.82624 .63647 m .8324 .67363 L .82013 .66953 L p .707 .577 .707 r
F P
0 g
s
.82013 .66953 m .81396 .63237 L .82624 .63647 L p .707 .577 .707 r
F P
0 g
s
.44574 .5628 m .44181 .61781 L .46582 .61318 L p .707 .577 .707 r
F P
0 g
s
.46582 .61318 m .46976 .55817 L .44574 .5628 L p .707 .577 .707 r
F P
0 g
s
.65296 .77152 m .64553 .75388 L .65303 .74756 L p .707 .577 .707 r
F P
0 g
s
.65626 .553 m .65233 .60801 L .63597 .61503 L p .707 .577 .707 r
F P
0 g
s
.65303 .74756 m .66047 .76521 L .65296 .77152 L p .707 .577 .707 r
F P
0 g
s
.82083 .56703 m .81689 .62204 L .79591 .61357 L p .707 .577 .707 r
F P
0 g
s
.79591 .61357 m .79984 .55856 L .82083 .56703 L p .707 .577 .707 r
F P
0 g
s
.32225 .60762 m .32618 .55261 L .3052 .54415 L p .707 .577 .707 r
F P
0 g
s
.32618 .55261 m .32225 .60762 L .34962 .61424 L p .707 .577 .707 r
F P
0 g
s
.83137 .67523 m .83881 .69287 L .82812 .69426 L p .707 .577 .707 r
F P
0 g
s
.82812 .69426 m .82069 .67661 L .83137 .67523 L p .707 .577 .707 r
F P
0 g
s
.38428 .6702 m .37812 .63304 L .34738 .63643 L p .707 .577 .707 r
F P
0 g
s
.37812 .63304 m .38428 .6702 L .41572 .66465 L p .707 .577 .707 r
F P
0 g
s
.41572 .66465 m .40956 .62749 L .37812 .63304 L p .707 .577 .707 r
F P
0 g
s
.40956 .62749 m .41572 .66465 L .44479 .65748 L p .707 .577 .707 r
F P
0 g
s
.44479 .65748 m .43862 .62032 L .40956 .62749 L p .707 .577 .707 r
F P
0 g
s
.65233 .60801 m .65626 .553 L .68028 .54838 L p .707 .577 .707 r
F P
0 g
s
.34738 .63643 m .35355 .67359 L .38428 .6702 L p .707 .577 .707 r
F P
0 g
s
.35355 .67359 m .34738 .63643 L .32037 .63734 L p .707 .577 .707 r
F P
0 g
s
.64106 .70117 m .6349 .66401 L .6512 .6558 L p .707 .577 .707 r
F P
0 g
s
.39428 .70844 m .38684 .6908 L .35833 .70184 L p .707 .577 .707 r
F P
0 g
s
.38684 .6908 m .39428 .70844 L .42371 .69598 L p .707 .577 .707 r
F P
0 g
s
.42371 .69598 m .41628 .67834 L .38684 .6908 L p .707 .577 .707 r
F P
0 g
s
.43862 .62032 m .44479 .65748 L .46864 .64939 L p .707 .577 .707 r
F P
0 g
s
.46864 .64939 m .46247 .61223 L .43862 .62032 L p .707 .577 .707 r
F P
0 g
s
.41628 .67834 m .42371 .69598 L .45119 .68333 L p .707 .577 .707 r
F P
0 g
s
.45119 .68333 m .44376 .66569 L .41628 .67834 L p .707 .577 .707 r
F P
0 g
s
.35833 .70184 m .36576 .71949 L .39428 .70844 L p .707 .577 .707 r
F P
0 g
s
.46976 .55817 m .46582 .61318 L .48218 .60617 L p .707 .577 .707 r
F P
0 g
s
.48218 .60617 m .48612 .55116 L .46976 .55817 L p .707 .577 .707 r
F P
0 g
s
.32037 .63734 m .32653 .6745 L .35355 .67359 L p .707 .577 .707 r
F P
0 g
s
.3052 .54415 m .30126 .59916 L .32225 .60762 L p .707 .577 .707 r
F P
0 g
s
.6512 .6558 m .65736 .69296 L .64106 .70117 L p .707 .577 .707 r
F P
0 g
s
.81396 .63237 m .82013 .66953 L .79947 .66786 L p .707 .577 .707 r
F P
0 g
s
.79947 .66786 m .79331 .6307 L .81396 .63237 L p .707 .577 .707 r
F P
0 g
s
.79984 .55856 m .79591 .61357 L .76853 .60696 L p .707 .577 .707 r
F P
0 g
s
.76853 .60696 m .77246 .55195 L .79984 .55856 L p .707 .577 .707 r
F P
0 g
s
.30126 .59916 m .3052 .54415 L .29266 .53467 L p .707 .577 .707 r
F P
0 g
s
.36576 .71949 m .35833 .70184 L .33353 .7104 L p .707 .577 .707 r
F P
0 g
s
.68028 .54838 m .67634 .60339 L .65233 .60801 L p .707 .577 .707 r
F P
0 g
s
.44376 .66569 m .45119 .68333 L .47402 .67173 L p .707 .577 .707 r
F P
0 g
s
.47402 .67173 m .46659 .65409 L .44376 .66569 L p .707 .577 .707 r
F P
0 g
s
.33353 .7104 m .34097 .72804 L .36576 .71949 L p .707 .577 .707 r
F P
0 g
s
.32653 .6745 m .32037 .63734 L .29971 .63566 L p .707 .577 .707 r
F P
0 g
s
.66047 .76521 m .65303 .74756 L .66898 .73814 L p .707 .577 .707 r
F P
0 g
s
.67634 .60339 m .68028 .54838 L .70961 .54659 L p .707 .577 .707 r
F P
0 g
s
.66898 .73814 m .67641 .75579 L .66047 .76521 L p .707 .577 .707 r
F P
0 g
s
.82069 .67661 m .82812 .69426 L .80947 .69948 L p .707 .577 .707 r
F P
0 g
s
.80947 .69948 m .80203 .68184 L .82069 .67661 L p .707 .577 .707 r
F P
0 g
s
.46247 .61223 m .46864 .64939 L .48494 .64119 L p .707 .577 .707 r
F P
0 g
s
.48494 .64119 m .47877 .60403 L .46247 .61223 L p .707 .577 .707 r
F P
0 g
s
.29971 .63566 m .30587 .67282 L .32653 .6745 L p .707 .577 .707 r
F P
0 g
s
.77246 .55195 m .76853 .60696 L .73743 .60283 L p .707 .577 .707 r
F P
0 g
s
.73743 .60283 m .74137 .54782 L .77246 .55195 L p .707 .577 .707 r
F P
0 g
s
.65736 .69296 m .6512 .6558 L .67505 .64772 L p .707 .577 .707 r
F P
0 g
s
.29266 .53467 m .28873 .58968 L .30126 .59916 L p .707 .577 .707 r
F P
0 g
s
.70567 .6016 m .70961 .54659 L .74137 .54782 L p .707 .577 .707 r
F P
0 g
s
.70961 .54659 m .70567 .6016 L .67634 .60339 L p .707 .577 .707 r
F P
0 g
s
.34097 .72804 m .33353 .7104 L .31488 .71562 L p .707 .577 .707 r
F P
0 g
s
.48612 .55116 m .48218 .60617 L .48928 .59745 L p .707 .577 .707 r
F P
0 g
s
.48928 .59745 m .49321 .54244 L .48612 .55116 L p .707 .577 .707 r
F P
0 g
s
.31488 .71562 m .32231 .73327 L .34097 .72804 L p .707 .577 .707 r
F P
0 g
s
.46659 .65409 m .47402 .67173 L .48997 .66232 L p .707 .577 .707 r
F P
0 g
s
.48997 .66232 m .48253 .64467 L .46659 .65409 L p .707 .577 .707 r
F P
0 g
s
.74137 .54782 m .73743 .60283 L .70567 .6016 L p .707 .577 .707 r
F P
0 g
s
.79331 .6307 m .79947 .66786 L .77245 .66876 L p .707 .577 .707 r
F P
0 g
s
.77245 .66876 m .76629 .6316 L .79331 .6307 L p .707 .577 .707 r
F P
0 g
s
.67505 .64772 m .68121 .68488 L .65736 .69296 L p .707 .577 .707 r
F P
0 g
s
.30587 .67282 m .29971 .63566 L .28743 .63157 L p .707 .577 .707 r
F P
0 g
s
.28873 .58968 m .29266 .53467 L .2898 .5251 L p .707 .577 .707 r
F P
0 g
s
.67641 .75579 m .66898 .73814 L .69181 .72654 L p .707 .577 .707 r
F P
0 g
s
.69181 .72654 m .69924 .74419 L .67641 .75579 L p .707 .577 .707 r
F P
0 g
s
.80203 .68184 m .80947 .69948 L .78467 .70804 L p .707 .577 .707 r
F P
0 g
s
.78467 .70804 m .77723 .69039 L .80203 .68184 L p .707 .577 .707 r
F P
0 g
s
.68121 .68488 m .67505 .64772 L .70412 .64055 L p .707 .577 .707 r
F P
0 g
s
.28743 .63157 m .29359 .66873 L .30587 .67282 L p .707 .577 .707 r
F P
0 g
s
.47877 .60403 m .48494 .64119 L .49209 .63366 L p .707 .577 .707 r
F P
0 g
s
.49209 .63366 m .48593 .5965 L .47877 .60403 L p .707 .577 .707 r
F P
0 g
s
.76629 .6316 m .77245 .66876 L .74172 .67215 L p .707 .577 .707 r
F P
0 g
s
.74172 .67215 m .73555 .63499 L .76629 .6316 L p .707 .577 .707 r
F P
0 g
s
.70412 .64055 m .71028 .67771 L .68121 .68488 L p .707 .577 .707 r
F P
0 g
s
.32231 .73327 m .31488 .71562 L .30419 .71701 L p .707 .577 .707 r
F P
0 g
s
.2898 .5251 m .28587 .58011 L .28873 .58968 L p .707 .577 .707 r
F P
0 g
s
.30419 .71701 m .31162 .73465 L .32231 .73327 L p .707 .577 .707 r
F P
0 g
s
.71028 .67771 m .70412 .64055 L .73555 .63499 L p .707 .577 .707 r
F P
0 g
s
.48253 .64467 m .48997 .66232 L .49747 .656 L p .707 .577 .707 r
F P
0 g
s
.49747 .656 m .49004 .63836 L .48253 .64467 L p .707 .577 .707 r
F P
0 g
s
.73555 .63499 m .74172 .67215 L .71028 .67771 L p .707 .577 .707 r
F P
0 g
s
.49321 .54244 m .48928 .59745 L .48642 .58788 L p .707 .577 .707 r
F P
0 g
s
.48642 .58788 m .49035 .53287 L .49321 .54244 L p .707 .577 .707 r
F P
0 g
s
.69924 .74419 m .69181 .72654 L .71929 .7139 L p .707 .577 .707 r
F P
0 g
s
.77723 .69039 m .78467 .70804 L .75616 .71908 L p .707 .577 .707 r
F P
0 g
s
.75616 .71908 m .74872 .70144 L .77723 .69039 L p .707 .577 .707 r
F P
0 g
s
.71929 .7139 m .72672 .73154 L .69924 .74419 L p .707 .577 .707 r
F P
0 g
s
.29359 .66873 m .28743 .63157 L .28473 .62546 L p .707 .577 .707 r
F P
0 g
s
.28587 .58011 m .2898 .5251 L .2969 .51639 L p .707 .577 .707 r
F P
0 g
s
.72672 .73154 m .71929 .7139 L .74872 .70144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74872 .70144 m .75616 .71908 L .72672 .73154 L p .707 .577 .707 r
F P
0 g
s
.28473 .62546 m .2909 .66262 L .29359 .66873 L p .707 .577 .707 r
F P
0 g
s
.48593 .5965 m .49209 .63366 L .48939 .62755 L p .707 .577 .707 r
F P
0 g
s
.48939 .62755 m .48323 .59039 L .48593 .5965 L p .707 .577 .707 r
F P
0 g
s
.31162 .73465 m .30419 .71701 L .30252 .71442 L p .707 .578 .707 r
F P
0 g
s
.2969 .51639 m .29296 .5714 L .28587 .58011 L p .707 .577 .707 r
F P
0 g
s
.30252 .71442 m .30995 .73206 L .31162 .73465 L p .707 .578 .707 r
F P
0 g
s
.49004 .63836 m .49747 .656 L .4958 .65341 L p .707 .578 .707 r
F P
0 g
s
.4958 .65341 m .48836 .63577 L .49004 .63836 L p .707 .578 .707 r
F P
0 g
s
.49035 .53287 m .48642 .58788 L .47388 .57841 L p .707 .577 .707 r
F P
0 g
s
.47388 .57841 m .47782 .5234 L .49035 .53287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29296 .5714 m .2969 .51639 L .31325 .50937 L p .707 .577 .707 r
F P
0 g
s
.2909 .66262 m .28473 .62546 L .29189 .61793 L p .707 .577 .707 r
F P
0 g
s
.29189 .61793 m .29805 .65509 L .2909 .66262 L p .707 .577 .707 r
F P
0 g
s
.48323 .59039 m .48939 .62755 L .47712 .62346 L p .707 .577 .707 r
F P
0 g
s
.47712 .62346 m .47095 .5863 L .48323 .59039 L p .707 .577 .707 r
F P
0 g
s
.31325 .50937 m .30932 .56438 L .29296 .5714 L p .707 .577 .707 r
F P
0 g
s
.30995 .73206 m .30252 .71442 L .31002 .7081 L p .707 .577 .707 r
F P
0 g
s
.47782 .5234 m .47388 .57841 L .4529 .56994 L p .707 .577 .707 r
F P
0 g
s
.4529 .56994 m .45683 .51493 L .47782 .5234 L p .707 .577 .707 r
F P
0 g
s
.31002 .7081 m .31746 .72575 L .30995 .73206 L p .707 .577 .707 r
F P
0 g
s
.48836 .63577 m .4958 .65341 L .48511 .65479 L p .707 .577 .707 r
F P
0 g
s
.48511 .65479 m .47768 .63715 L .48836 .63577 L p .707 .577 .707 r
F P
0 g
s
.30932 .56438 m .31325 .50937 L .33727 .50475 L p .707 .577 .707 r
F P
0 g
s
.29805 .65509 m .29189 .61793 L .30819 .60973 L p .707 .577 .707 r
F P
0 g
s
.30819 .60973 m .31435 .64689 L .29805 .65509 L p .707 .577 .707 r
F P
0 g
s
.47095 .5863 m .47712 .62346 L .45646 .62178 L p .707 .577 .707 r
F P
0 g
s
.45646 .62178 m .45029 .58462 L .47095 .5863 L p .707 .577 .707 r
F P
0 g
s
.45683 .51493 m .4529 .56994 L .42552 .56333 L p .707 .577 .707 r
F P
0 g
s
.42552 .56333 m .42945 .50832 L .45683 .51493 L p .707 .577 .707 r
F P
0 g
s
.33727 .50475 m .33333 .55976 L .30932 .56438 L p .707 .577 .707 r
F P
0 g
s
.33333 .55976 m .33727 .50475 L .3666 .50296 L p .707 .577 .707 r
F P
0 g
s
.31746 .72575 m .31002 .7081 L .32597 .69868 L p .707 .577 .707 r
F P
0 g
s
.32597 .69868 m .3334 .71633 L .31746 .72575 L p .707 .577 .707 r
F P
0 g
s
.47768 .63715 m .48511 .65479 L .46646 .66002 L p .707 .577 .707 r
F P
0 g
s
.46646 .66002 m .45902 .64238 L .47768 .63715 L p .707 .577 .707 r
F P
0 g
s
.31435 .64689 m .30819 .60973 L .33204 .60164 L p .707 .577 .707 r
F P
0 g
s
.42945 .50832 m .42552 .56333 L .39442 .5592 L p .707 .577 .707 r
F P
0 g
s
.39442 .5592 m .39836 .50419 L .42945 .50832 L p .707 .577 .707 r
F P
0 g
s
.36266 .55797 m .3666 .50296 L .39836 .50419 L p .707 .577 .707 r
F P
0 g
s
.3666 .50296 m .36266 .55797 L .33333 .55976 L p .707 .577 .707 r
F P
0 g
s
.39836 .50419 m .39442 .5592 L .36266 .55797 L p .707 .577 .707 r
F P
0 g
s
.45029 .58462 m .45646 .62178 L .42944 .62268 L p .707 .577 .707 r
F P
0 g
s
.42944 .62268 m .42328 .58552 L .45029 .58462 L p .707 .577 .707 r
F P
0 g
s
.33204 .60164 m .3382 .6388 L .31435 .64689 L p .707 .577 .707 r
F P
0 g
s
.3334 .71633 m .32597 .69868 L .3488 .68708 L p .707 .577 .707 r
F P
0 g
s
.3488 .68708 m .35623 .70473 L .3334 .71633 L p .707 .577 .707 r
F P
0 g
s
.3382 .6388 m .33204 .60164 L .3611 .59447 L p .707 .577 .707 r
F P
0 g
s
.45902 .64238 m .46646 .66002 L .44166 .66858 L p .707 .577 .707 r
F P
0 g
s
.44166 .66858 m .43422 .65093 L .45902 .64238 L p .707 .577 .707 r
F P
0 g
s
.42328 .58552 m .42944 .62268 L .39871 .62608 L p .707 .577 .707 r
F P
0 g
s
.39871 .62608 m .39254 .58892 L .42328 .58552 L p .707 .577 .707 r
F P
0 g
s
.3611 .59447 m .36727 .63163 L .3382 .6388 L p .707 .577 .707 r
F P
0 g
s
.36727 .63163 m .3611 .59447 L .39254 .58892 L p .707 .577 .707 r
F P
0 g
s
.39254 .58892 m .39871 .62608 L .36727 .63163 L p .707 .577 .707 r
F P
0 g
s
.35623 .70473 m .3488 .68708 L .37628 .67443 L p .707 .577 .707 r
F P
0 g
s
.43422 .65093 m .44166 .66858 L .41315 .67962 L p .707 .577 .707 r
F P
0 g
s
.41315 .67962 m .40571 .66198 L .43422 .65093 L p .707 .577 .707 r
F P
0 g
s
.37628 .67443 m .38371 .69208 L .35623 .70473 L p .707 .577 .707 r
F P
0 g
s
.38371 .69208 m .37628 .67443 L .40571 .66198 L p .707 .577 .707 r
F P
0 g
s
.40571 .66198 m .41315 .67962 L .38371 .69208 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6000OGoo001oOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Uoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00Lgoo1P00
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001^
Ool50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH2001]Ool006]oo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00QJEP8006]oo`00JGoo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF00<007ooOol0J7oo001XOol0
1000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH02eYFJWoo001VOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1WOol006Eoo`03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00aJEP03001oogoo06Ioo`00I7oo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02eYF00<007oo
Ool0IWoo001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1VOol0069oo`04001JEUYF
0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001W
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
0000Igoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IWoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005eooaT000=JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00F7oo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P002EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP<006Aoo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001T
Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`00I7oo001BOol00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP<006Aoo`00DWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001TOol0059oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`001goo5`00AWoo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60010Ool0055oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPD000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003aoo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Goo001AOol0
0`00FUH00003FUH01000FUIJEUYF3`000UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00L0
05YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH3000gOol0055oo`03001JEP0000=JEP@00003FUH005YF00IJEP03001JEUYF009JEQ40
00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003Eoo`00DGoo00@005YF001JEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH0
1`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DGoo00<005YF00000P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035o
o`00DGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`
Ool0055oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000`Ool0055oo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEQ<00003FUH00000008000IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002moo`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000@000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00Dgoo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP<000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00=goo60001Goo0P001EYF00<0
05YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00=7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035o
o`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@00003FUH0
05YF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004
FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000_Ool0
02moo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUH00003FUH500000eYF001JEP05FUH00`00FUIJEP02FUHB0006FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP04001JEP00FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002mo
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF0080031oo`00:goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP<00004FUH005YFFUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH01@00FUIJEUYF00001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P00
<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80006FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00<7oo000[Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP<0031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001J
EUYF00AJEPH00003FUH0000000<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUHB0002FUH3000`Ool002]oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF01000003FUH005YF00MJEP03001JEUYF00AJEP03001J
EUYF009JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH6000`Ool002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00D0009JEP03
001JEUYF00EJEP03001JEUYF00AJEPD00003FUH0000000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00<7oo000[Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005
FUH00`00FUH000030003FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YF000010001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00<7oo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH005YF<Goo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH400000eYF000000030006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<Goo000ZOol00`00FUH00003FUH01000FUIJEUYF3P000goo200015YF00<005YFFUH00`0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080031oo`00:Woo00<005YF00000eYF100000=JEP00FUH01UYF00<005YF
FUH00UYF40000UYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH015YF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080031oo`00
:Woo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH0
0`00FUIJEP04FUH40004FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF0080031oo`00:Woo00<005YF00000P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF1P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF0000031oo`00:Woo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH025YF00@005YF000000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH01000FUIJ
EP00<7oo000ZOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P001EYF
00<005YFFUH01EYF0`001eYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2@001EYF1P0000=JEP00Ool0;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUHD00000eYF00000008FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001UYF00<005YF
FUH015YF00<005YFFUH00UYF1000;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUHB0002FUH40003Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=oo`0000000P00
0UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001P00;goo000[Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01eYF1`0015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJ
EP00000007oo008000=JEP03001JEUYF00IJEP<000UJEP04001JEP000003FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000goo000000040006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000UYF00<005YF
FUH00P00;goo000/Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP050006FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P001EYF00<005YF
FUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P0025YF00<005YFFUH00`001EYF00<005YFFUH00eYF0P0025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP04001J
EUYF000_Ool002ioo`8000AJEP03001JEUYF00=JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00QJEP8000UJEP03001JEP00008000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000AJEP04
001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool300000eYF001JEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH20002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH01EYF00@005YFFUIJEPH002ioo`00<Woo100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00EJEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP05FUH40003FUH2000_Ool002moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000QJEP04
001JEP000006FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20008FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0^Ool0
02eoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP80009JEP03001JEUYF00AJEP<000QJEP03001JEUYF008000QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<000UJEP03001JEUYF008000AJEP05001J
EUYFFUH0000aOol002]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP@000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000000eYF
00<005YFFUH01UYF0`001eYF0`00<Woo000ZOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00@005YF000000AJEP03001JEUYF
00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH2000dOol002Yoo`8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF009J
EP8000MJEP03001JEP00008000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000QJEP03001JEP00008000EJEP03001JEUYF009JEP8003Ioo`00:Goo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPX000EJEP80009JEP07
001JEUYFFUH005YF00001UYF100000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00004`0000=J
EP00FUH025YF0`0025YF00@005YF000003Qoo`00:Goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00AJEPH00003Ool000000080009JEP03001JEUYF00IJEP80009JEP<0009JEP03001JEUYF
009JEP8000=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH80002FUH60004FUH00`00
FUIJEP04FUH200000eYF001JEP08FUH2000jOol002Uoo`04001JEUYF0004FUH00`00FUIJEP05FUH0
0`00FUIJEP0@00000eYF001JEP07FUH20002FUH00`00FUIJEP03FUH00`00FUH000020004Ool00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF1P001eYF00<005YFFUH00UYF0P0015YF
00<005YFFUH015YF0P00?7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH80004FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEP@00003FUH0000000Aoo`03001JEP00
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUH000020009FUH01000FUH000001UYF
00<005YFFUH00UYF0P00?Woo000ZOol00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH0
1UYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YF00001@000UYF00D005YFFUIJEP0000Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP05001JEUYFFUH00003FUH01000FUIJEUYF0`0015YF0P000eYF00<005YFFUH0
1EYF0`002EYF00@005YF0000041oo`00:Woo00<005YF00001EYF00@005YF000000EJEP03001JEUYF
00MJEP03001JEUYF00<000=JEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH00P00
0goo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP8000EJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00EJEP<0049oo`00:Woo00@005YFFUH000=JEP@000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF009JEP05001JEUYFFUH00003Ool0
0`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40007FUH00`00FUH000020005FUH00`00
FUIJEP03FUH20015Ool002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP03FUH00`00FUH000020002Ool0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH20009FUH0
0`00FUH000020017Ool002]oo`9JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00MJEP03001JEUYF00@0009JEP04001oogoo0009FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP04FUHI0005FUH00`00FUIJEP05FUH01@00FUIJEUYF
00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01EYF0`00BWoo000[Ool01EYF001JEUYF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH015YF1000
15YF0P000goo00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF2P002eYF00<005YFFUH0
2EYF20001UYF00<005YFFUH00P001UYF00@005YF000000AJEP03001JEUYF00=JEP8004eoo`00:goo
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<007ooOol00Woo00<005YFFUH01eYF00<005YF
FUH01eYF00<005YFFUH01P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF0P001eYF00<005YF00000P00Cgoo000[Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP08FUH0
1000FUH0000015YF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000800005
FUH005YFFUH00003FUH200000eYF001JEP05FUH3001BOol002aoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPH000EJEP03001JEUYF00EJEP<000MJEP<000Qoo`UJEP03001JEUYF
00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF009JEP<0009JEP<000=JEP03001JEUYF009JEP8005Eoo`00;Woo500000=oo`00000025YF
00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<007ooOol027oo2EYF00<005YF00000`002EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YF00000P00EWoo0011Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH2000;Ool8FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF
1`00EWoo000oOol20003FUH00`00FUIJEP06FUH40008FUH01000FUH000003Goo1UYF0P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF0P000UYF1@0000AJEP00FUIJEP8005Ioo`00?Goo0P001UYF00<005YFFUH00eYF0`00
00=JEP00FUH025YF0P003goo15YF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF00<005YF00000`001EYF00@005YFFUH005Io
o`00>goo0P0025YF00<005YFFUH00`001EYF00<005YFFUH015YF0P004Goo0UYF0P002EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF
00H005YFFUH005YF0005FUH01000FUIJEP00EWoo000iOol200000eYF001JEP08FUH20008FUH00`00
FUIJEP02FUH2000COol00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH01000FUIJEP00EGoo000gOol20004FUH00`00FUIJEP04FUH200000eYF001J
EP08FUH01000FUH000005Goo00=JEP00FUH00eYF00<005YFFUH03eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF
1@00EGoo000eOol20006FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH3000GOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH2001FOol003Ao
o`8000QJEP04001JEP000006FUH00`00FUIJEP03FUH2000JOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUIJEUYF0P001UYF0`0015YF00<007ooOol0EGoo000bOol20002FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP03000MOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUIJEP00FUH0009JEP@0009J
EP05001JEUYFFUH0001HOol0035oo`03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP<0021oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0009JEP<000MJEP<005Uoo`00<7oo0P00
1EYF00@005YF000000AJEP03001JEUYF00=JEP<002Aoo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00004FUH0
00000002FUH00`00FUIJEP04FUH2001KOol002moo`04001JEUYF0004FUH20007FUH00`00FUH00002
000YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05000015YF000000001EYF00<005YFFUH00UYF0P00GGoo000_Ool01000FUIJEP000eYF
00<005YF00001UYF0`00;Woo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF1@0015YF0`0025YF00@005YF000005moo`00;goo0P000UYF0`000UYF00<005YF
FUH00UYF0P00<goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPL000IJEP800003FUH005YF00QJEP80065oo`00<7oo00@005YFFUH000EJEP04001JEP00000i
Ool80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH90006FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH2001SOol0031oo`05001JEP00FUH00002FUH40013OolI0004Ool30009FUH01000FUH0
00001UYF00<005YFFUH00UYF0P00IGoo000aOol00`00FUH00003001SOol01@00FUIJEUYF00001eYF
0`002EYF00@005YF000006Moo`00<Goo0P00IGoo0P0015YF00<005YFFUH00eYF0P000eYF00<005YF
FUH01EYF0`00JGoo002FOol20007FUH00`00FUH000020005FUH00`00FUIJEP03FUH2001/Ool009Ao
o`800003FUH005YF00IJEP8000UJEP03001JEP00008006ioo`00TWoo0P0015YF00<005YFFUH00UYF
0P000UYF00<005YFFUH01EYF0`00LGoo002AOol20005FUH01@00FUIJEUYF000015YF00<005YFFUH0
0eYF0P00M7oo002@Ool01000FUIJEP001EYF0`001UYF00<005YF00000P00MWoo002@Ool01000FUIJ
EP0015YF0`001UYF0`00NGoo002AOol01@00FUIJEP00FUH00P000UYF00<005YFFUH00UYF0P00O7oo
002AOol00`00FUIJEP020005FUH01000FUH00000OWoo002BOol01EYF001JEUYF00000UYF1000P7oo
002BOol00`00FUIJEP040024Ool009=oo`8008Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58652 .75403 m .59046 .69902 L .55937 .6949 L p .707 .577 .707 r
F P
0 g
s
.59046 .69902 m .58652 .75403 L .61829 .75526 L p .707 .577 .707 r
F P
0 g
s
.61829 .75526 m .62222 .70025 L .59046 .69902 L p .707 .577 .707 r
F P
0 g
s
.62222 .70025 m .61829 .75526 L .64761 .75348 L p .707 .577 .707 r
F P
0 g
s
.64761 .75348 m .65155 .69847 L .62222 .70025 L p .707 .577 .707 r
F P
0 g
s
.55543 .7499 m .55937 .6949 L .53199 .68828 L p .707 .577 .707 r
F P
0 g
s
.55937 .6949 m .55543 .7499 L .58652 .75403 L p .707 .577 .707 r
F P
0 g
s
.65155 .69847 m .64761 .75348 L .67163 .74885 L p .707 .577 .707 r
F P
0 g
s
.67163 .74885 m .67556 .69384 L .65155 .69847 L p .707 .577 .707 r
F P
0 g
s
.52805 .74329 m .53199 .68828 L .511 .67982 L p .707 .577 .707 r
F P
0 g
s
.53199 .68828 m .52805 .74329 L .55543 .7499 L p .707 .577 .707 r
F P
0 g
s
.59008 .80831 m .58392 .77115 L .55319 .77455 L p .707 .577 .707 r
F P
0 g
s
.58392 .77115 m .59008 .80831 L .62152 .80276 L p .707 .577 .707 r
F P
0 g
s
.62152 .80276 m .61536 .7656 L .58392 .77115 L p .707 .577 .707 r
F P
0 g
s
.61536 .7656 m .62152 .80276 L .65059 .79559 L p .707 .577 .707 r
F P
0 g
s
.65059 .79559 m .64443 .75843 L .61536 .7656 L p .707 .577 .707 r
F P
0 g
s
.55319 .77455 m .55935 .81171 L .59008 .80831 L p .707 .577 .707 r
F P
0 g
s
.55935 .81171 m .55319 .77455 L .52617 .77545 L p .707 .577 .707 r
F P
0 g
s
.60008 .83994 m .59265 .82229 L .56414 .83334 L p .707 .577 .707 r
F P
0 g
s
.59265 .82229 m .60008 .83994 L .62952 .82748 L p .707 .577 .707 r
F P
0 g
s
.62952 .82748 m .62208 .80984 L .59265 .82229 L p .707 .577 .707 r
F P
0 g
s
.62208 .80984 m .62952 .82748 L .65699 .81483 L p .707 .577 .707 r
F P
0 g
s
.65699 .81483 m .64956 .79719 L .62208 .80984 L p .707 .577 .707 r
F P
0 g
s
.56414 .83334 m .57157 .85098 L .60008 .83994 L p .707 .577 .707 r
F P
0 g
s
.64443 .75843 m .65059 .79559 L .67444 .78751 L p .707 .577 .707 r
F P
0 g
s
.67444 .78751 m .66828 .75035 L .64443 .75843 L p .707 .577 .707 r
F P
0 g
s
.67556 .69384 m .67163 .74885 L .68799 .74183 L p .707 .577 .707 r
F P
0 g
s
.68799 .74183 m .69192 .68682 L .67556 .69384 L p .707 .577 .707 r
F P
0 g
s
.511 .67982 m .50707 .73483 L .52805 .74329 L p .707 .577 .707 r
F P
0 g
s
.52617 .77545 m .53233 .81261 L .55935 .81171 L p .707 .577 .707 r
F P
0 g
s
.57157 .85098 m .56414 .83334 L .53934 .8419 L p .707 .577 .707 r
F P
0 g
s
.50707 .73483 m .511 .67982 L .49847 .67034 L p .707 .577 .707 r
F P
0 g
s
.64956 .79719 m .65699 .81483 L .67982 .80323 L p .707 .577 .707 r
F P
0 g
s
.67982 .80323 m .67239 .78559 L .64956 .79719 L p .707 .577 .707 r
F P
0 g
s
.53934 .8419 m .54677 .85954 L .57157 .85098 L p .707 .577 .707 r
F P
0 g
s
.53233 .81261 m .52617 .77545 L .50551 .77377 L p .707 .577 .707 r
F P
0 g
s
.66828 .75035 m .67444 .78751 L .69074 .7793 L p .707 .577 .707 r
F P
0 g
s
.69074 .7793 m .68458 .74214 L .66828 .75035 L p .707 .577 .707 r
F P
0 g
s
.50551 .77377 m .51167 .81093 L .53233 .81261 L p .707 .577 .707 r
F P
0 g
s
.49847 .67034 m .49453 .72535 L .50707 .73483 L p .707 .577 .707 r
F P
0 g
s
.54677 .85954 m .53934 .8419 L .52068 .84712 L p .707 .577 .707 r
F P
0 g
s
.52068 .84712 m .52812 .86476 L .54677 .85954 L p .707 .577 .707 r
F P
0 g
s
.69192 .68682 m .68799 .74183 L .69508 .73312 L p .707 .577 .707 r
F P
0 g
s
.69508 .73312 m .69902 .67811 L .69192 .68682 L p .707 .577 .707 r
F P
0 g
s
.67239 .78559 m .67982 .80323 L .69577 .79381 L p .707 .577 .707 r
F P
0 g
s
.69577 .79381 m .68834 .77617 L .67239 .78559 L p .707 .577 .707 r
F P
0 g
s
.49453 .72535 m .49847 .67034 L .49561 .66077 L p .707 .577 .707 r
F P
0 g
s
.51167 .81093 m .50551 .77377 L .49323 .76968 L p .707 .577 .707 r
F P
0 g
s
.49323 .76968 m .4994 .80684 L .51167 .81093 L p .707 .577 .707 r
F P
0 g
s
.68458 .74214 m .69074 .7793 L .69789 .77177 L p .707 .577 .707 r
F P
0 g
s
.69789 .77177 m .69173 .73461 L .68458 .74214 L p .707 .577 .707 r
F P
0 g
s
.52812 .86476 m .52068 .84712 L .51 .84851 L p .707 .577 .707 r
F P
0 g
s
.51 .84851 m .51743 .86615 L .52812 .86476 L p .707 .577 .707 r
F P
0 g
s
.49561 .66077 m .49167 .71578 L .49453 .72535 L p .707 .577 .707 r
F P
0 g
s
.68834 .77617 m .69577 .79381 L .70328 .7875 L p .707 .577 .707 r
F P
0 g
s
.70328 .7875 m .69584 .76986 L .68834 .77617 L p .707 .577 .707 r
F P
0 g
s
.69902 .67811 m .69508 .73312 L .69222 .72355 L p .707 .577 .707 r
F P
0 g
s
.69222 .72355 m .69616 .66854 L .69902 .67811 L p .707 .577 .707 r
F P
0 g
s
.49167 .71578 m .49561 .66077 L .5027 .65206 L p .707 .577 .707 r
F P
0 g
s
.5027 .65206 m .49877 .70707 L .49167 .71578 L p .707 .577 .707 r
F P
0 g
s
.49877 .70707 m .5027 .65206 L .51906 .64504 L p .707 .577 .707 r
F P
0 g
s
.4994 .80684 m .49323 .76968 L .49054 .76357 L p .707 .577 .707 r
F P
0 g
s
.49054 .76357 m .4967 .80073 L .4994 .80684 L p .707 .577 .707 r
F P
0 g
s
.49769 .75605 m .50385 .79321 L .4967 .80073 L p .707 .577 .707 r
F P
0 g
s
.51906 .64504 m .51512 .70005 L .49877 .70707 L p .707 .577 .707 r
F P
0 g
s
.50385 .79321 m .49769 .75605 L .51399 .74784 L p .707 .577 .707 r
F P
0 g
s
.51399 .74784 m .52015 .785 L .50385 .79321 L p .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .48004 .31682 L .4361 .31656 L p .707 .577 .707 r
F P
0 g
s
.51512 .70005 m .51906 .64504 L .54308 .64041 L p .707 .577 .707 r
F P
0 g
s
.54308 .64041 m .53914 .69542 L .51512 .70005 L p .707 .577 .707 r
F P
0 g
s
.52015 .785 m .51399 .74784 L .53784 .73976 L p .707 .577 .707 r
F P
0 g
s
.53784 .73976 m .54401 .77692 L .52015 .785 L p .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .53784 .73976 L .54849 .73713 L p .707 .577 .707 r
F P
0 g
s
.54849 .73713 m .56691 .73259 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.54401 .77692 m .54849 .73713 L .55487 .75589 L .707 .577 .707 r
F
.56691 .73259 m .57307 .76975 L .56062 .77282 L p F P
0 g
s
.56062 .77282 m .54401 .77692 L p .55487 .75589 L .707 .577 .707 r
F P
0 g
s
.55487 .75589 m .56691 .73259 L .56062 .77282 L .707 .577 .707 r
F
.52493 .31353 m .48004 .31682 L p .53472 .69659 L F P
0 g
s
.55213 .81755 m .54766 .73468 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .54308 .64041 L .56911 .63883 L p .707 .577 .707 r
F P
0 g
s
.56911 .63883 m .5724 .63863 L p .56675 .64828 L .707 .577 .707 r
F P
0 g
s
.53914 .69542 m .56911 .63883 L .56675 .64828 L .707 .577 .707 r
F
.5724 .63863 m .56847 .69364 L .53914 .69542 L p F P
0 g
s
.54621 .7304 m .52493 .31353 L .53472 .69659 L .707 .577 .707 r
F
.54766 .73468 m .54721 .72638 L p .54621 .7304 L F P
0 g
s
.54721 .72638 m .52493 .31353 L p .54621 .7304 L .707 .577 .707 r
F P
0 g
s
.50725 .82083 m .55213 .81755 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.48004 .31682 m .49409 .57699 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.49409 .57699 m .50725 .82083 L p .53472 .69659 L .707 .577 .707 r
F P
0 g
s
.56847 .69364 m .5724 .63863 L .60417 .63986 L p .707 .577 .707 r
F P
0 g
s
.60417 .63986 m .60023 .69487 L .56847 .69364 L p .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .56691 .73259 L .57934 .73039 L p .707 .577 .707 r
F P
0 g
s
.57934 .73039 m .59835 .72703 L p .57888 .75993 L .707 .577 .707 r
F P
0 g
s
.57307 .76975 m .57934 .73039 L .57888 .75993 L .707 .577 .707 r
F
.63526 .64399 m .63132 .699 L .60023 .69487 L p F P
0 g
s
.60023 .69487 m .60417 .63986 L .63526 .64399 L p .707 .577 .707 r
F P
0 g
s
.62908 .72364 m .63524 .7608 L .60451 .76419 L p .707 .577 .707 r
F P
0 g
s
.60451 .76419 m .59835 .72703 L .62908 .72364 L p .707 .577 .707 r
F P
0 g
s
.59835 .72703 m .60451 .76419 L .57307 .76975 L p .707 .577 .707 r
F P
0 g
s
.64003 .78243 m .64746 .80007 L .61895 .81112 L p .707 .577 .707 r
F P
0 g
s
.61895 .81112 m .61152 .79348 L .64003 .78243 L p .707 .577 .707 r
F P
0 g
s
.58952 .82358 m .58208 .80593 L .61152 .79348 L p .707 .577 .707 r
F P
0 g
s
.61152 .79348 m .61895 .81112 L .58952 .82358 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .62749 .80195 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56636 .30703 m .58157 .58875 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.58157 .58875 m .59357 .81104 L p .58378 .44803 L .707 .577 .707 r
F P
0 g
s
.56204 .83623 m .55461 .81858 L .58208 .80593 L p .707 .577 .707 r
F P
0 g
s
.58208 .80593 m .58952 .82358 L .56204 .83623 L p .707 .577 .707 r
F P
0 g
s
.52493 .31353 m .55213 .81755 L .59357 .81104 L p .707 .577 .707 r
F P
0 g
s
.59357 .81104 m .56636 .30703 L .52493 .31353 L p .707 .577 .707 r
F P
0 g
s
.46331 .82057 m .4361 .31656 L .3974 .31278 L p .707 .577 .707 r
F P
0 g
s
.4967 .80073 m .49054 .76357 L .49769 .75605 L p .707 .577 .707 r
F P
0 g
s
.4361 .31656 m .46331 .82057 L .50725 .82083 L p .707 .577 .707 r
F P
0 g
s
.69173 .73461 m .69789 .77177 L .6952 .76567 L p .707 .577 .707 r
F P
0 g
s
.6952 .76567 m .68904 .72851 L .69173 .73461 L p .707 .577 .707 r
F P
0 g
s
.51743 .86615 m .51 .84851 L .50832 .84591 L p .707 .578 .707 r
F P
0 g
s
.50832 .84591 m .51576 .86356 L .51743 .86615 L p .707 .578 .707 r
F P
0 g
s
.69584 .76986 m .70328 .7875 L .7016 .78491 L p .707 .578 .707 r
F P
0 g
s
.7016 .78491 m .69417 .76727 L .69584 .76986 L p .707 .578 .707 r
F P
0 g
s
.62749 .80195 m .60029 .29794 L .56636 .30703 L p .707 .577 .707 r
F P
0 g
s
.69616 .66854 m .69222 .72355 L .67969 .71407 L p .707 .577 .707 r
F P
0 g
s
.67969 .71407 m .68362 .65907 L .69616 .66854 L p .707 .577 .707 r
F P
0 g
s
.24351 .7104 m .24745 .65539 L .21636 .65127 L p .707 .577 .707 r
F P
0 g
s
.24745 .65539 m .24351 .7104 L .27528 .71163 L p .707 .577 .707 r
F P
0 g
s
.27528 .71163 m .27921 .65662 L .24745 .65539 L p .707 .577 .707 r
F P
0 g
s
.27921 .65662 m .27528 .71163 L .3046 .70985 L p .707 .577 .707 r
F P
0 g
s
.3046 .70985 m .30854 .65484 L .27921 .65662 L p .707 .577 .707 r
F P
0 g
s
.42461 .81679 m .3974 .31278 L .36774 .30585 L p .707 .577 .707 r
F P
0 g
s
.3974 .31278 m .42461 .81679 L .46331 .82057 L p .707 .577 .707 r
F P
0 g
s
.21242 .70628 m .21636 .65127 L .18898 .64465 L p .707 .577 .707 r
F P
0 g
s
.21636 .65127 m .21242 .70628 L .24351 .7104 L p .707 .577 .707 r
F P
0 g
s
.68904 .72851 m .6952 .76567 L .68292 .76157 L p .707 .577 .707 r
F P
0 g
s
.68292 .76157 m .67676 .72441 L .68904 .72851 L p .707 .577 .707 r
F P
0 g
s
.30854 .65484 m .3046 .70985 L .32862 .70522 L p .707 .577 .707 r
F P
0 g
s
.32862 .70522 m .33256 .65021 L .30854 .65484 L p .707 .577 .707 r
F P
0 g
s
.51576 .86356 m .50832 .84591 L .51583 .8396 L p .707 .577 .707 r
F P
0 g
s
.66264 .6506 m .6587 .70561 L .63132 .699 L p .707 .577 .707 r
F P
0 g
s
.63132 .699 m .63526 .64399 L .66264 .6506 L p .707 .577 .707 r
F P
0 g
s
.6561 .72273 m .66226 .7599 L .63524 .7608 L p .707 .577 .707 r
F P
0 g
s
.63524 .7608 m .62908 .72364 L .6561 .72273 L p .707 .577 .707 r
F P
0 g
s
.64746 .80007 m .64003 .78243 L .66483 .77388 L p .707 .577 .707 r
F P
0 g
s
.60029 .29794 m .62749 .80195 L .65059 .79117 L p .707 .577 .707 r
F P
0 g
s
.65059 .79117 m .62339 .28716 L .60029 .29794 L p .707 .577 .707 r
F P
0 g
s
.51583 .8396 m .52326 .85724 L .51576 .86356 L p .707 .577 .707 r
F P
0 g
s
.68362 .65907 m .67969 .71407 L .6587 .70561 L p .707 .577 .707 r
F P
0 g
s
.6587 .70561 m .66264 .6506 L .68362 .65907 L p .707 .577 .707 r
F P
0 g
s
.18504 .69966 m .18898 .64465 L .16799 .63619 L p .707 .577 .707 r
F P
0 g
s
.18898 .64465 m .18504 .69966 L .21242 .70628 L p .707 .577 .707 r
F P
0 g
s
.69417 .76727 m .7016 .78491 L .69092 .78629 L p .707 .577 .707 r
F P
0 g
s
.69092 .78629 m .68348 .76865 L .69417 .76727 L p .707 .577 .707 r
F P
0 g
s
.24708 .76224 m .24091 .72508 L .21018 .72847 L p .707 .577 .707 r
F P
0 g
s
.24091 .72508 m .24708 .76224 L .27851 .75668 L p .707 .577 .707 r
F P
0 g
s
.27851 .75668 m .27235 .71952 L .24091 .72508 L p .707 .577 .707 r
F P
0 g
s
.27235 .71952 m .27851 .75668 L .30758 .74952 L p .707 .577 .707 r
F P
0 g
s
.30758 .74952 m .30142 .71235 L .27235 .71952 L p .707 .577 .707 r
F P
0 g
s
.21018 .72847 m .21634 .76563 L .24708 .76224 L p .707 .577 .707 r
F P
0 g
s
.21634 .76563 m .21018 .72847 L .18316 .72938 L p .707 .577 .707 r
F P
0 g
s
.25707 .80048 m .24964 .78283 L .22113 .79388 L p .707 .577 .707 r
F P
0 g
s
.24964 .78283 m .25707 .80048 L .28651 .78802 L p .707 .577 .707 r
F P
0 g
s
.28651 .78802 m .27908 .77038 L .24964 .78283 L p .707 .577 .707 r
F P
0 g
s
.30142 .71235 m .30758 .74952 L .33143 .74143 L p .707 .577 .707 r
F P
0 g
s
.33143 .74143 m .32527 .70427 L .30142 .71235 L p .707 .577 .707 r
F P
0 g
s
.27908 .77038 m .28651 .78802 L .31399 .77537 L p .707 .577 .707 r
F P
0 g
s
.31399 .77537 m .30655 .75773 L .27908 .77038 L p .707 .577 .707 r
F P
0 g
s
.22113 .79388 m .22856 .81152 L .25707 .80048 L p .707 .577 .707 r
F P
0 g
s
.33256 .65021 m .32862 .70522 L .34498 .6982 L p .707 .577 .707 r
F P
0 g
s
.34498 .6982 m .34891 .6432 L .33256 .65021 L p .707 .577 .707 r
F P
0 g
s
.39494 .80986 m .36774 .30585 L .35001 .29645 L p .707 .577 .707 r
F P
0 g
s
.36774 .30585 m .39494 .80986 L .42461 .81679 L p .707 .577 .707 r
F P
0 g
s
.18316 .72938 m .18932 .76654 L .21634 .76563 L p .707 .577 .707 r
F P
0 g
s
.16799 .63619 m .16406 .6912 L .18504 .69966 L p .707 .577 .707 r
F P
0 g
s
.67676 .72441 m .68292 .76157 L .66226 .7599 L p .707 .577 .707 r
F P
0 g
s
.66226 .7599 m .6561 .72273 L .67676 .72441 L p .707 .577 .707 r
F P
0 g
s
.16406 .6912 m .16799 .63619 L .15546 .62671 L p .707 .577 .707 r
F P
0 g
s
.22856 .81152 m .22113 .79388 L .19633 .80243 L p .707 .577 .707 r
F P
0 g
s
.30655 .75773 m .31399 .77537 L .33682 .76377 L p .707 .577 .707 r
F P
0 g
s
.33682 .76377 m .32938 .74613 L .30655 .75773 L p .707 .577 .707 r
F P
0 g
s
.19633 .80243 m .20376 .82008 L .22856 .81152 L p .707 .577 .707 r
F P
0 g
s
.18932 .76654 m .18316 .72938 L .1625 .7277 L p .707 .577 .707 r
F P
0 g
s
.52326 .85724 m .51583 .8396 L .53178 .83018 L p .707 .577 .707 r
F P
0 g
s
.53178 .83018 m .53921 .84783 L .52326 .85724 L p .707 .577 .707 r
F P
0 g
s
.68348 .76865 m .69092 .78629 L .67226 .79152 L p .707 .577 .707 r
F P
0 g
s
.67226 .79152 m .66483 .77388 L .68348 .76865 L p .707 .577 .707 r
F P
0 g
s
.32527 .70427 m .33143 .74143 L .34773 .73323 L p .707 .577 .707 r
F P
0 g
s
.34773 .73323 m .34157 .69606 L .32527 .70427 L p .707 .577 .707 r
F P
0 g
s
.1625 .7277 m .16866 .76486 L .18932 .76654 L p .707 .577 .707 r
F P
0 g
s
.62339 .28716 m .65059 .79117 L .6606 .77974 L p .707 .577 .707 r
F P
0 g
s
.6606 .77974 m .6334 .27573 L .62339 .28716 L p .707 .577 .707 r
F P
0 g
s
.15546 .62671 m .15152 .68172 L .16406 .6912 L p .707 .577 .707 r
F P
0 g
s
.20376 .82008 m .19633 .80243 L .17768 .80766 L p .707 .577 .707 r
F P
0 g
s
.34891 .6432 m .34498 .6982 L .35207 .68949 L p .707 .577 .707 r
F P
0 g
s
.35207 .68949 m .35601 .63448 L .34891 .6432 L p .707 .577 .707 r
F P
0 g
s
.17768 .80766 m .18511 .8253 L .20376 .82008 L p .707 .577 .707 r
F P
0 g
s
.32938 .74613 m .33682 .76377 L .35276 .75435 L p .707 .577 .707 r
F P
0 g
s
.35276 .75435 m .34533 .73671 L .32938 .74613 L p .707 .577 .707 r
F P
0 g
s
.16866 .76486 m .1625 .7277 L .15023 .72361 L p .707 .577 .707 r
F P
0 g
s
.15152 .68172 m .15546 .62671 L .1526 .61714 L p .707 .577 .707 r
F P
0 g
s
.53921 .84783 m .53178 .83018 L .55461 .81858 L p .707 .577 .707 r
F P
0 g
s
.55461 .81858 m .56204 .83623 L .53921 .84783 L p .707 .577 .707 r
F P
0 g
s
.66483 .77388 m .67226 .79152 L .64746 .80007 L p .707 .577 .707 r
F P
0 g
s
.37721 .80047 m .35001 .29645 L .34595 .28551 L p .707 .577 .707 r
F P
0 g
s
.35001 .29645 m .37721 .80047 L .39494 .80986 L p .707 .577 .707 r
F P
0 g
s
.15023 .72361 m .15639 .76077 L .16866 .76486 L p .707 .577 .707 r
F P
0 g
s
.34157 .69606 m .34773 .73323 L .35488 .7257 L p .707 .577 .707 r
F P
0 g
s
.35488 .7257 m .34872 .68854 L .34157 .69606 L p .707 .577 .707 r
F P
0 g
s
.18511 .8253 m .17768 .80766 L .16699 .80904 L p .707 .577 .707 r
F P
0 g
s
.1526 .61714 m .14866 .67215 L .15152 .68172 L p .707 .577 .707 r
F P
0 g
s
.16699 .80904 m .17442 .82669 L .18511 .8253 L p .707 .577 .707 r
F P
0 g
s
.34533 .73671 m .35276 .75435 L .36027 .74804 L p .707 .577 .707 r
F P
0 g
s
.36027 .74804 m .35283 .7304 L .34533 .73671 L p .707 .577 .707 r
F P
0 g
s
.35601 .63448 m .35207 .68949 L .34921 .67992 L p .707 .577 .707 r
F P
0 g
s
.34921 .67992 m .35315 .62491 L .35601 .63448 L p .707 .577 .707 r
F P
0 g
s
.62934 .26478 m .65654 .7688 L .63881 .7594 L p .707 .577 .707 r
F P
0 g
s
.64427 .64279 m .64654 .61106 L p .63567 .5783 L .707 .577 .707 r
F P
0 g
s
.65338 .70144 m .6334 .27573 L .65898 .77536 L .707 .577 .707 r
F
.65654 .7688 m .64455 .5465 L p .6334 .27573 L F P
0 g
s
.64455 .5465 m .62934 .26478 L .6317 .27114 L p .707 .577 .707 r
F P
0 g
s
.6317 .27114 m .6334 .27573 L p .64455 .5465 L .707 .577 .707 r
F P
0 g
s
.6334 .27573 m .6606 .77974 L .65898 .77536 L p .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .66338 .68341 L .65089 .6824 L p .707 .577 .707 r
F P
0 g
s
.65089 .6824 m .64272 .68173 L p .65145 .69437 L .707 .577 .707 r
F P
0 g
s
.66954 .72057 m .65089 .6824 L .65145 .69437 L .707 .577 .707 r
F
.64654 .61106 m .64821 .58778 L .64457 .58503 L p F P
0 g
s
.64457 .58503 m .63567 .5783 L p .64654 .61106 L .707 .577 .707 r
F P
0 g
s
.65898 .77536 m .65654 .7688 L p .65338 .70144 L .707 .577 .707 r
F P
0 g
s
.15639 .76077 m .15023 .72361 L .14753 .7175 L p .707 .577 .707 r
F P
0 g
s
.14866 .67215 m .1526 .61714 L .15969 .60843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.14753 .7175 m .15369 .75466 L .15639 .76077 L p .707 .577 .707 r
F P
0 g
s
.34872 .68854 m .35488 .7257 L .35219 .71959 L p .707 .577 .707 r
F P
0 g
s
.35219 .71959 m .34603 .68243 L .34872 .68854 L p .707 .577 .707 r
F P
0 g
s
.17442 .82669 m .16699 .80904 L .16531 .80645 L p .707 .578 .707 r
F P
0 g
s
.15969 .60843 m .15576 .66344 L .14866 .67215 L p .707 .577 .707 r
F P
0 g
s
.16531 .80645 m .17275 .8241 L .17442 .82669 L p .707 .578 .707 r
F P
0 g
s
.35283 .7304 m .36027 .74804 L .35859 .74545 L p .707 .578 .707 r
F P
0 g
s
.35859 .74545 m .35116 .7278 L .35283 .7304 L p .707 .578 .707 r
F P
0 g
s
.34595 .28551 m .37315 .78952 L .37721 .80047 L p .707 .577 .707 r
F P
0 g
s
.37315 .78952 m .34595 .28551 L .35596 .27408 L p .707 .577 .707 r
F P
0 g
s
.35315 .62491 m .34921 .67992 L .33668 .67045 L p .707 .577 .707 r
F P
0 g
s
.33668 .67045 m .34061 .61544 L .35315 .62491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15576 .66344 m .15969 .60843 L .17605 .60141 L p .707 .577 .707 r
F P
0 g
s
.15369 .75466 m .14753 .7175 L .15468 .70997 L p .707 .577 .707 r
F P
0 g
s
.15468 .70997 m .16085 .74713 L .15369 .75466 L p .707 .577 .707 r
F P
0 g
s
.34603 .68243 m .35219 .71959 L .33991 .7155 L p .707 .577 .707 r
F P
0 g
s
.33991 .7155 m .33375 .67834 L .34603 .68243 L p .707 .577 .707 r
F P
0 g
s
.63881 .7594 m .61161 .25539 L .62934 .26478 L p .707 .577 .707 r
F P
0 g
s
.17605 .60141 m .17211 .65642 L .15576 .66344 L p .707 .577 .707 r
F P
0 g
s
.17275 .8241 m .16531 .80645 L .17282 .80014 L p .707 .577 .707 r
F P
0 g
s
.34061 .61544 m .33668 .67045 L .31569 .66198 L p .707 .577 .707 r
F P
0 g
s
.31569 .66198 m .31963 .60697 L .34061 .61544 L p .707 .577 .707 r
F P
0 g
s
.17282 .80014 m .18025 .81778 L .17275 .8241 L p .707 .577 .707 r
F P
0 g
s
.35116 .7278 m .35859 .74545 L .34791 .74683 L p .707 .577 .707 r
F P
0 g
s
.34791 .74683 m .34047 .72919 L .35116 .7278 L p .707 .577 .707 r
F P
0 g
s
.17211 .65642 m .17605 .60141 L .20007 .59678 L p .707 .577 .707 r
F P
0 g
s
.16085 .74713 m .15468 .70997 L .17098 .70176 L p .707 .577 .707 r
F P
0 g
s
.38316 .7781 m .35596 .27408 L .37905 .2633 L p .707 .577 .707 r
F P
0 g
s
.35596 .27408 m .38316 .7781 L .37315 .78952 L p .707 .577 .707 r
F P
0 g
s
.17098 .70176 m .17714 .73893 L .16085 .74713 L p .707 .577 .707 r
F P
0 g
s
.33375 .67834 m .33991 .7155 L .31925 .71382 L p .707 .577 .707 r
F P
0 g
s
.31925 .71382 m .31309 .67666 L .33375 .67834 L p .707 .577 .707 r
F P
0 g
s
.31963 .60697 m .31569 .66198 L .28831 .65537 L p .707 .577 .707 r
F P
0 g
s
.28831 .65537 m .29225 .60036 L .31963 .60697 L p .707 .577 .707 r
F P
0 g
s
.20007 .59678 m .19613 .65179 L .17211 .65642 L p .707 .577 .707 r
F P
0 g
s
.19613 .65179 m .20007 .59678 L .22939 .595 L p .707 .577 .707 r
F P
0 g
s
.18025 .81778 m .17282 .80014 L .18877 .79072 L p .707 .577 .707 r
F P
0 g
s
.18877 .79072 m .1962 .80837 L .18025 .81778 L p .707 .577 .707 r
F P
0 g
s
.34047 .72919 m .34791 .74683 L .32925 .75206 L p .707 .577 .707 r
F P
0 g
s
.32925 .75206 m .32182 .73442 L .34047 .72919 L p .707 .577 .707 r
F P
0 g
s
.61161 .25539 m .63389 .66823 L p .63308 .671 L .707 .577 .707 r
F P
0 g
s
.60915 .75248 m .61005 .5702 L .63308 .671 L .707 .577 .707 r
F
.61005 .5702 m .61161 .25539 L .63308 .671 L F
.64888 .71889 m .64272 .68173 L .63494 .67914 L p F P
0 g
s
.63881 .7594 m .62015 .75504 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63389 .66823 m .63434 .67654 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.63434 .67654 m .63881 .7594 L p .6333 .67198 L .707 .577 .707 r
F P
0 g
s
.62015 .75504 m .60915 .75248 L p .63389 .66823 L .707 .577 .707 r
F P
0 g
s
.63044 .67764 m .6366 .7148 L .64362 .71714 L p .707 .577 .707 r
F P
0 g
s
.64362 .71714 m .64888 .71889 L p .63894 .69665 L .707 .577 .707 r
F P
0 g
s
.63894 .69665 m .63044 .67764 L .64362 .71714 L .707 .577 .707 r
F
.63494 .67914 m .63044 .67764 L p .63894 .69665 L F P
0 g
s
.64888 .71889 m .63494 .67914 L .63894 .69665 L .707 .577 .707 r
F
.63567 .5783 m .63174 .63331 L .6386 .6385 L p F P
0 g
s
.6386 .6385 m .64427 .64279 L p .64137 .62102 L .707 .577 .707 r
F P
0 g
s
.64137 .62102 m .63567 .5783 L .6386 .6385 L .707 .577 .707 r
F
.60915 .75248 m .58194 .24846 L .61161 .25539 L p F P
0 g
s
.17714 .73893 m .17098 .70176 L .19483 .69368 L p .707 .577 .707 r
F P
0 g
s
.29225 .60036 m .28831 .65537 L .25722 .65124 L p .707 .577 .707 r
F P
0 g
s
.25722 .65124 m .26116 .59623 L .29225 .60036 L p .707 .577 .707 r
F P
0 g
s
.22546 .65001 m .22939 .595 L .26116 .59623 L p .707 .577 .707 r
F P
0 g
s
.22939 .595 m .22546 .65001 L .19613 .65179 L p .707 .577 .707 r
F P
0 g
s
.26116 .59623 m .25722 .65124 L .22546 .65001 L p .707 .577 .707 r
F P
0 g
s
.31309 .67666 m .31925 .71382 L .29223 .71472 L p .707 .577 .707 r
F P
0 g
s
.29223 .71472 m .28607 .67756 L .31309 .67666 L p .707 .577 .707 r
F P
0 g
s
.19483 .69368 m .201 .73084 L .17714 .73893 L p .707 .577 .707 r
F P
0 g
s
.72373 .66199 m .72766 .60698 L .69657 .60286 L p .707 .577 .707 r
F P
0 g
s
.72766 .60698 m .72373 .66199 L .75549 .66322 L p .707 .577 .707 r
F P
0 g
s
.75549 .66322 m .75943 .60821 L .72766 .60698 L p .707 .577 .707 r
F P
0 g
s
.37905 .2633 m .40626 .76731 L .38316 .7781 L p .707 .577 .707 r
F P
0 g
s
.40626 .76731 m .37905 .2633 L .41298 .25421 L p .707 .577 .707 r
F P
0 g
s
.75943 .60821 m .75549 .66322 L .78482 .66144 L p .707 .577 .707 r
F P
0 g
s
.78482 .66144 m .78875 .60643 L .75943 .60821 L p .707 .577 .707 r
F P
0 g
s
.1962 .80837 m .18877 .79072 L .2116 .77912 L p .707 .577 .707 r
F P
0 g
s
.69263 .65787 m .69657 .60286 L .66919 .59624 L p .707 .577 .707 r
F P
0 g
s
.69657 .60286 m .69263 .65787 L .72373 .66199 L p .707 .577 .707 r
F P
0 g
s
.2116 .77912 m .21903 .79676 L .1962 .80837 L p .707 .577 .707 r
F P
0 g
s
.201 .73084 m .19483 .69368 L .2239 .68651 L p .707 .577 .707 r
F P
0 g
s
.32182 .73442 m .32925 .75206 L .30445 .76061 L p .707 .577 .707 r
F P
0 g
s
.30445 .76061 m .29702 .74297 L .32182 .73442 L p .707 .577 .707 r
F P
0 g
s
.28607 .67756 m .29223 .71472 L .2615 .71812 L p .707 .577 .707 r
F P
0 g
s
.2615 .71812 m .25534 .68096 L .28607 .67756 L p .707 .577 .707 r
F P
0 g
s
.2239 .68651 m .23006 .72367 L .201 .73084 L p .707 .577 .707 r
F P
0 g
s
.78875 .60643 m .78482 .66144 L .80883 .65681 L p .707 .577 .707 r
F P
0 g
s
.80883 .65681 m .81277 .6018 L .78875 .60643 L p .707 .577 .707 r
F P
0 g
s
.58194 .24846 m .60915 .75248 L .57045 .7487 L p .707 .577 .707 r
F P
0 g
s
.57045 .7487 m .54324 .24468 L .58194 .24846 L p .707 .577 .707 r
F P
0 g
s
.23006 .72367 m .2239 .68651 L .25534 .68096 L p .707 .577 .707 r
F P
0 g
s
.25534 .68096 m .2615 .71812 L .23006 .72367 L p .707 .577 .707 r
F P
0 g
s
.66526 .65125 m .66919 .59624 L .64821 .58778 L p .707 .577 .707 r
F P
0 g
s
.66919 .59624 m .66526 .65125 L .69263 .65787 L p .707 .577 .707 r
F P
0 g
s
.72729 .71628 m .72113 .67911 L .69039 .68251 L p .707 .577 .707 r
F P
0 g
s
.72113 .67911 m .72729 .71628 L .75873 .71072 L p .707 .577 .707 r
F P
0 g
s
.75873 .71072 m .75257 .67356 L .72113 .67911 L p .707 .577 .707 r
F P
0 g
s
.75257 .67356 m .75873 .71072 L .78779 .70355 L p .707 .577 .707 r
F P
0 g
s
.78779 .70355 m .78163 .66639 L .75257 .67356 L p .707 .577 .707 r
F P
0 g
s
.21903 .79676 m .2116 .77912 L .23907 .76647 L p .707 .577 .707 r
F P
0 g
s
.29702 .74297 m .30445 .76061 L .27594 .77166 L p .707 .577 .707 r
F P
0 g
s
.27594 .77166 m .26851 .75402 L .29702 .74297 L p .707 .577 .707 r
F P
0 g
s
.23907 .76647 m .24651 .78412 L .21903 .79676 L p .707 .577 .707 r
F P
0 g
s
.44019 .75822 m .41298 .25421 L .45442 .2477 L p .707 .577 .707 r
F P
0 g
s
.41298 .25421 m .44019 .75822 L .40626 .76731 L p .707 .577 .707 r
F P
0 g
s
.69039 .68251 m .69656 .71967 L .72729 .71628 L p .707 .577 .707 r
F P
0 g
s
.69656 .71967 m .69039 .68251 L .66338 .68341 L p .707 .577 .707 r
F P
0 g
s
.73729 .7479 m .72985 .73026 L .70134 .7413 L p .707 .577 .707 r
F P
0 g
s
.72985 .73026 m .73729 .7479 L .76672 .73544 L p .707 .577 .707 r
F P
0 g
s
.76672 .73544 m .75929 .7178 L .72985 .73026 L p .707 .577 .707 r
F P
0 g
s
.75929 .7178 m .76672 .73544 L .7942 .7228 L p .707 .577 .707 r
F P
0 g
s
.7942 .7228 m .78677 .70515 L .75929 .7178 L p .707 .577 .707 r
F P
0 g
s
.70134 .7413 m .70877 .75895 L .73729 .7479 L p .707 .577 .707 r
F P
0 g
s
.24651 .78412 m .23907 .76647 L .26851 .75402 L p .707 .577 .707 r
F P
0 g
s
.78163 .66639 m .78779 .70355 L .81165 .69547 L p .707 .577 .707 r
F P
0 g
s
.81165 .69547 m .80548 .65831 L .78163 .66639 L p .707 .577 .707 r
F P
0 g
s
.26851 .75402 m .27594 .77166 L .24651 .78412 L p .707 .577 .707 r
F P
0 g
s
.81277 .6018 m .80883 .65681 L .82519 .6498 L p .707 .577 .707 r
F P
0 g
s
.82519 .6498 m .82913 .59479 L .81277 .6018 L p .707 .577 .707 r
F P
0 g
s
.64821 .58778 m .64427 .64279 L .66526 .65125 L p .707 .577 .707 r
F P
0 g
s
.66338 .68341 m .66954 .72057 L .69656 .71967 L p .707 .577 .707 r
F P
0 g
s
.54324 .24468 m .57045 .7487 L .52651 .74843 L p .707 .577 .707 r
F P
0 g
s
.52651 .74843 m .4993 .24442 L .54324 .24468 L p .707 .577 .707 r
F P
0 g
s
.70877 .75895 m .70134 .7413 L .67654 .74986 L p .707 .577 .707 r
F P
0 g
s
.78677 .70515 m .7942 .7228 L .81703 .71119 L p .707 .577 .707 r
F P
0 g
s
.81703 .71119 m .8096 .69355 L .78677 .70515 L p .707 .577 .707 r
F P
0 g
s
.67654 .74986 m .68398 .7675 L .70877 .75895 L p .707 .577 .707 r
F P
0 g
s
.48162 .75172 m .45442 .2477 L .4993 .24442 L p .707 .577 .707 r
F P
0 g
s
.45442 .2477 m .48162 .75172 L .44019 .75822 L p .707 .577 .707 r
F P
0 g
s
.4993 .24442 m .52651 .74843 L .48162 .75172 L p .707 .577 .707 r
F P
0 g
s
.80548 .65831 m .81165 .69547 L .82795 .68726 L p .707 .577 .707 r
F P
0 g
s
.82795 .68726 m .82178 .6501 L .80548 .65831 L p .707 .577 .707 r
F P
0 g
s
.64272 .68173 m .64888 .71889 L .66954 .72057 L p .707 .577 .707 r
F P
0 g
s
.68398 .7675 m .67654 .74986 L .65789 .75508 L p .707 .577 .707 r
F P
0 g
s
.65789 .75508 m .66532 .77273 L .68398 .7675 L p .707 .577 .707 r
F P
0 g
s
.82913 .59479 m .82519 .6498 L .83229 .64108 L p .707 .577 .707 r
F P
0 g
s
.83229 .64108 m .83622 .58607 L .82913 .59479 L p .707 .577 .707 r
F P
0 g
s
.8096 .69355 m .81703 .71119 L .83298 .70178 L p .707 .577 .707 r
F P
0 g
s
.83298 .70178 m .82554 .68413 L .8096 .69355 L p .707 .577 .707 r
F P
0 g
s
.63174 .63331 m .63567 .5783 L .63281 .56873 L p .707 .577 .707 r
F P
0 g
s
.82178 .6501 m .82795 .68726 L .8351 .67974 L p .707 .577 .707 r
F P
0 g
s
.8351 .67974 m .82894 .64258 L .82178 .6501 L p .707 .577 .707 r
F P
0 g
s
.66532 .77273 m .65789 .75508 L .6472 .75647 L p .707 .577 .707 r
F P
0 g
s
.6472 .75647 m .65463 .77411 L .66532 .77273 L p .707 .577 .707 r
F P
0 g
s
.63281 .56873 m .62888 .62374 L .63174 .63331 L p .707 .577 .707 r
F P
0 g
s
.82554 .68413 m .83298 .70178 L .84048 .69546 L p .707 .577 .707 r
F P
0 g
s
.84048 .69546 m .83305 .67782 L .82554 .68413 L p .707 .577 .707 r
F P
0 g
s
.83622 .58607 m .83229 .64108 L .82943 .63151 L p .707 .577 .707 r
F P
0 g
s
.82943 .63151 m .83336 .5765 L .83622 .58607 L p .707 .577 .707 r
F P
0 g
s
.6366 .7148 m .63044 .67764 L .62774 .67153 L p .707 .577 .707 r
F P
0 g
s
.62888 .62374 m .63281 .56873 L .63991 .56002 L p .707 .577 .707 r
F P
0 g
s
.62774 .67153 m .63391 .70869 L .6366 .7148 L p .707 .577 .707 r
F P
0 g
s
.82894 .64258 m .8351 .67974 L .8324 .67363 L p .707 .577 .707 r
F P
0 g
s
.8324 .67363 m .82624 .63647 L .82894 .64258 L p .707 .577 .707 r
F P
0 g
s
.65463 .77411 m .6472 .75647 L .64553 .75388 L p .707 .578 .707 r
F P
0 g
s
.64553 .75388 m .65296 .77152 L .65463 .77411 L p .707 .578 .707 r
F P
0 g
s
.63991 .56002 m .63597 .61503 L .62888 .62374 L p .707 .577 .707 r
F P
0 g
s
.83305 .67782 m .84048 .69546 L .83881 .69287 L p .707 .578 .707 r
F P
0 g
s
.83881 .69287 m .83137 .67523 L .83305 .67782 L p .707 .578 .707 r
F P
0 g
s
.83336 .5765 m .82943 .63151 L .81689 .62204 L p .707 .577 .707 r
F P
0 g
s
.81689 .62204 m .82083 .56703 L .83336 .5765 L p .707 .577 .707 r
F P
0 g
s
.38072 .61836 m .38465 .56335 L .35356 .55923 L p .707 .577 .707 r
F P
0 g
s
.38465 .56335 m .38072 .61836 L .41248 .61959 L p .707 .577 .707 r
F P
0 g
s
.41248 .61959 m .41642 .56458 L .38465 .56335 L p .707 .577 .707 r
F P
0 g
s
.63597 .61503 m .63991 .56002 L .65626 .553 L p .707 .577 .707 r
F P
0 g
s
.63391 .70869 m .62774 .67153 L .6349 .66401 L p .707 .577 .707 r
F P
0 g
s
.41642 .56458 m .41248 .61959 L .44181 .61781 L p .707 .577 .707 r
F P
0 g
s
.44181 .61781 m .44574 .5628 L .41642 .56458 L p .707 .577 .707 r
F P
0 g
s
.34962 .61424 m .35356 .55923 L .32618 .55261 L p .707 .577 .707 r
F P
0 g
s
.35356 .55923 m .34962 .61424 L .38072 .61836 L p .707 .577 .707 r
F P
0 g
s
.6349 .66401 m .64106 .70117 L .63391 .70869 L p .707 .577 .707 r
F P
0 g
s
.82624 .63647 m .8324 .67363 L .82013 .66953 L p .707 .577 .707 r
F P
0 g
s
.82013 .66953 m .81396 .63237 L .82624 .63647 L p .707 .577 .707 r
F P
0 g
s
.44574 .5628 m .44181 .61781 L .46582 .61318 L p .707 .577 .707 r
F P
0 g
s
.46582 .61318 m .46976 .55817 L .44574 .5628 L p .707 .577 .707 r
F P
0 g
s
.65296 .77152 m .64553 .75388 L .65303 .74756 L p .707 .577 .707 r
F P
0 g
s
.65626 .553 m .65233 .60801 L .63597 .61503 L p .707 .577 .707 r
F P
0 g
s
.65303 .74756 m .66047 .76521 L .65296 .77152 L p .707 .577 .707 r
F P
0 g
s
.82083 .56703 m .81689 .62204 L .79591 .61357 L p .707 .577 .707 r
F P
0 g
s
.79591 .61357 m .79984 .55856 L .82083 .56703 L p .707 .577 .707 r
F P
0 g
s
.32225 .60762 m .32618 .55261 L .3052 .54415 L p .707 .577 .707 r
F P
0 g
s
.32618 .55261 m .32225 .60762 L .34962 .61424 L p .707 .577 .707 r
F P
0 g
s
.83137 .67523 m .83881 .69287 L .82812 .69426 L p .707 .577 .707 r
F P
0 g
s
.82812 .69426 m .82069 .67661 L .83137 .67523 L p .707 .577 .707 r
F P
0 g
s
.38428 .6702 m .37812 .63304 L .34738 .63643 L p .707 .577 .707 r
F P
0 g
s
.37812 .63304 m .38428 .6702 L .41572 .66465 L p .707 .577 .707 r
F P
0 g
s
.41572 .66465 m .40956 .62749 L .37812 .63304 L p .707 .577 .707 r
F P
0 g
s
.40956 .62749 m .41572 .66465 L .44479 .65748 L p .707 .577 .707 r
F P
0 g
s
.44479 .65748 m .43862 .62032 L .40956 .62749 L p .707 .577 .707 r
F P
0 g
s
.65233 .60801 m .65626 .553 L .68028 .54838 L p .707 .577 .707 r
F P
0 g
s
.34738 .63643 m .35355 .67359 L .38428 .6702 L p .707 .577 .707 r
F P
0 g
s
.35355 .67359 m .34738 .63643 L .32037 .63734 L p .707 .577 .707 r
F P
0 g
s
.64106 .70117 m .6349 .66401 L .6512 .6558 L p .707 .577 .707 r
F P
0 g
s
.39428 .70844 m .38684 .6908 L .35833 .70184 L p .707 .577 .707 r
F P
0 g
s
.38684 .6908 m .39428 .70844 L .42371 .69598 L p .707 .577 .707 r
F P
0 g
s
.42371 .69598 m .41628 .67834 L .38684 .6908 L p .707 .577 .707 r
F P
0 g
s
.43862 .62032 m .44479 .65748 L .46864 .64939 L p .707 .577 .707 r
F P
0 g
s
.46864 .64939 m .46247 .61223 L .43862 .62032 L p .707 .577 .707 r
F P
0 g
s
.41628 .67834 m .42371 .69598 L .45119 .68333 L p .707 .577 .707 r
F P
0 g
s
.45119 .68333 m .44376 .66569 L .41628 .67834 L p .707 .577 .707 r
F P
0 g
s
.35833 .70184 m .36576 .71949 L .39428 .70844 L p .707 .577 .707 r
F P
0 g
s
.46976 .55817 m .46582 .61318 L .48218 .60617 L p .707 .577 .707 r
F P
0 g
s
.48218 .60617 m .48612 .55116 L .46976 .55817 L p .707 .577 .707 r
F P
0 g
s
.32037 .63734 m .32653 .6745 L .35355 .67359 L p .707 .577 .707 r
F P
0 g
s
.3052 .54415 m .30126 .59916 L .32225 .60762 L p .707 .577 .707 r
F P
0 g
s
.6512 .6558 m .65736 .69296 L .64106 .70117 L p .707 .577 .707 r
F P
0 g
s
.81396 .63237 m .82013 .66953 L .79947 .66786 L p .707 .577 .707 r
F P
0 g
s
.79947 .66786 m .79331 .6307 L .81396 .63237 L p .707 .577 .707 r
F P
0 g
s
.79984 .55856 m .79591 .61357 L .76853 .60696 L p .707 .577 .707 r
F P
0 g
s
.76853 .60696 m .77246 .55195 L .79984 .55856 L p .707 .577 .707 r
F P
0 g
s
.30126 .59916 m .3052 .54415 L .29266 .53467 L p .707 .577 .707 r
F P
0 g
s
.36576 .71949 m .35833 .70184 L .33353 .7104 L p .707 .577 .707 r
F P
0 g
s
.68028 .54838 m .67634 .60339 L .65233 .60801 L p .707 .577 .707 r
F P
0 g
s
.44376 .66569 m .45119 .68333 L .47402 .67173 L p .707 .577 .707 r
F P
0 g
s
.47402 .67173 m .46659 .65409 L .44376 .66569 L p .707 .577 .707 r
F P
0 g
s
.33353 .7104 m .34097 .72804 L .36576 .71949 L p .707 .577 .707 r
F P
0 g
s
.32653 .6745 m .32037 .63734 L .29971 .63566 L p .707 .577 .707 r
F P
0 g
s
.66047 .76521 m .65303 .74756 L .66898 .73814 L p .707 .577 .707 r
F P
0 g
s
.67634 .60339 m .68028 .54838 L .70961 .54659 L p .707 .577 .707 r
F P
0 g
s
.66898 .73814 m .67641 .75579 L .66047 .76521 L p .707 .577 .707 r
F P
0 g
s
.82069 .67661 m .82812 .69426 L .80947 .69948 L p .707 .577 .707 r
F P
0 g
s
.80947 .69948 m .80203 .68184 L .82069 .67661 L p .707 .577 .707 r
F P
0 g
s
.46247 .61223 m .46864 .64939 L .48494 .64119 L p .707 .577 .707 r
F P
0 g
s
.48494 .64119 m .47877 .60403 L .46247 .61223 L p .707 .577 .707 r
F P
0 g
s
.29971 .63566 m .30587 .67282 L .32653 .6745 L p .707 .577 .707 r
F P
0 g
s
.77246 .55195 m .76853 .60696 L .73743 .60283 L p .707 .577 .707 r
F P
0 g
s
.73743 .60283 m .74137 .54782 L .77246 .55195 L p .707 .577 .707 r
F P
0 g
s
.65736 .69296 m .6512 .6558 L .67505 .64772 L p .707 .577 .707 r
F P
0 g
s
.29266 .53467 m .28873 .58968 L .30126 .59916 L p .707 .577 .707 r
F P
0 g
s
.70567 .6016 m .70961 .54659 L .74137 .54782 L p .707 .577 .707 r
F P
0 g
s
.70961 .54659 m .70567 .6016 L .67634 .60339 L p .707 .577 .707 r
F P
0 g
s
.34097 .72804 m .33353 .7104 L .31488 .71562 L p .707 .577 .707 r
F P
0 g
s
.48612 .55116 m .48218 .60617 L .48928 .59745 L p .707 .577 .707 r
F P
0 g
s
.48928 .59745 m .49321 .54244 L .48612 .55116 L p .707 .577 .707 r
F P
0 g
s
.31488 .71562 m .32231 .73327 L .34097 .72804 L p .707 .577 .707 r
F P
0 g
s
.46659 .65409 m .47402 .67173 L .48997 .66232 L p .707 .577 .707 r
F P
0 g
s
.48997 .66232 m .48253 .64467 L .46659 .65409 L p .707 .577 .707 r
F P
0 g
s
.74137 .54782 m .73743 .60283 L .70567 .6016 L p .707 .577 .707 r
F P
0 g
s
.79331 .6307 m .79947 .66786 L .77245 .66876 L p .707 .577 .707 r
F P
0 g
s
.77245 .66876 m .76629 .6316 L .79331 .6307 L p .707 .577 .707 r
F P
0 g
s
.67505 .64772 m .68121 .68488 L .65736 .69296 L p .707 .577 .707 r
F P
0 g
s
.30587 .67282 m .29971 .63566 L .28743 .63157 L p .707 .577 .707 r
F P
0 g
s
.28873 .58968 m .29266 .53467 L .2898 .5251 L p .707 .577 .707 r
F P
0 g
s
.67641 .75579 m .66898 .73814 L .69181 .72654 L p .707 .577 .707 r
F P
0 g
s
.69181 .72654 m .69924 .74419 L .67641 .75579 L p .707 .577 .707 r
F P
0 g
s
.80203 .68184 m .80947 .69948 L .78467 .70804 L p .707 .577 .707 r
F P
0 g
s
.78467 .70804 m .77723 .69039 L .80203 .68184 L p .707 .577 .707 r
F P
0 g
s
.68121 .68488 m .67505 .64772 L .70412 .64055 L p .707 .577 .707 r
F P
0 g
s
.28743 .63157 m .29359 .66873 L .30587 .67282 L p .707 .577 .707 r
F P
0 g
s
.47877 .60403 m .48494 .64119 L .49209 .63366 L p .707 .577 .707 r
F P
0 g
s
.49209 .63366 m .48593 .5965 L .47877 .60403 L p .707 .577 .707 r
F P
0 g
s
.76629 .6316 m .77245 .66876 L .74172 .67215 L p .707 .577 .707 r
F P
0 g
s
.74172 .67215 m .73555 .63499 L .76629 .6316 L p .707 .577 .707 r
F P
0 g
s
.70412 .64055 m .71028 .67771 L .68121 .68488 L p .707 .577 .707 r
F P
0 g
s
.32231 .73327 m .31488 .71562 L .30419 .71701 L p .707 .577 .707 r
F P
0 g
s
.2898 .5251 m .28587 .58011 L .28873 .58968 L p .707 .577 .707 r
F P
0 g
s
.30419 .71701 m .31162 .73465 L .32231 .73327 L p .707 .577 .707 r
F P
0 g
s
.71028 .67771 m .70412 .64055 L .73555 .63499 L p .707 .577 .707 r
F P
0 g
s
.48253 .64467 m .48997 .66232 L .49747 .656 L p .707 .577 .707 r
F P
0 g
s
.49747 .656 m .49004 .63836 L .48253 .64467 L p .707 .577 .707 r
F P
0 g
s
.73555 .63499 m .74172 .67215 L .71028 .67771 L p .707 .577 .707 r
F P
0 g
s
.49321 .54244 m .48928 .59745 L .48642 .58788 L p .707 .577 .707 r
F P
0 g
s
.48642 .58788 m .49035 .53287 L .49321 .54244 L p .707 .577 .707 r
F P
0 g
s
.69924 .74419 m .69181 .72654 L .71929 .7139 L p .707 .577 .707 r
F P
0 g
s
.77723 .69039 m .78467 .70804 L .75616 .71908 L p .707 .577 .707 r
F P
0 g
s
.75616 .71908 m .74872 .70144 L .77723 .69039 L p .707 .577 .707 r
F P
0 g
s
.71929 .7139 m .72672 .73154 L .69924 .74419 L p .707 .577 .707 r
F P
0 g
s
.29359 .66873 m .28743 .63157 L .28473 .62546 L p .707 .577 .707 r
F P
0 g
s
.28587 .58011 m .2898 .5251 L .2969 .51639 L p .707 .577 .707 r
F P
0 g
s
.72672 .73154 m .71929 .7139 L .74872 .70144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74872 .70144 m .75616 .71908 L .72672 .73154 L p .707 .577 .707 r
F P
0 g
s
.28473 .62546 m .2909 .66262 L .29359 .66873 L p .707 .577 .707 r
F P
0 g
s
.48593 .5965 m .49209 .63366 L .48939 .62755 L p .707 .577 .707 r
F P
0 g
s
.48939 .62755 m .48323 .59039 L .48593 .5965 L p .707 .577 .707 r
F P
0 g
s
.31162 .73465 m .30419 .71701 L .30252 .71442 L p .707 .578 .707 r
F P
0 g
s
.2969 .51639 m .29296 .5714 L .28587 .58011 L p .707 .577 .707 r
F P
0 g
s
.30252 .71442 m .30995 .73206 L .31162 .73465 L p .707 .578 .707 r
F P
0 g
s
.49004 .63836 m .49747 .656 L .4958 .65341 L p .707 .578 .707 r
F P
0 g
s
.4958 .65341 m .48836 .63577 L .49004 .63836 L p .707 .578 .707 r
F P
0 g
s
.49035 .53287 m .48642 .58788 L .47388 .57841 L p .707 .577 .707 r
F P
0 g
s
.47388 .57841 m .47782 .5234 L .49035 .53287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29296 .5714 m .2969 .51639 L .31325 .50937 L p .707 .577 .707 r
F P
0 g
s
.2909 .66262 m .28473 .62546 L .29189 .61793 L p .707 .577 .707 r
F P
0 g
s
.29189 .61793 m .29805 .65509 L .2909 .66262 L p .707 .577 .707 r
F P
0 g
s
.48323 .59039 m .48939 .62755 L .47712 .62346 L p .707 .577 .707 r
F P
0 g
s
.47712 .62346 m .47095 .5863 L .48323 .59039 L p .707 .577 .707 r
F P
0 g
s
.31325 .50937 m .30932 .56438 L .29296 .5714 L p .707 .577 .707 r
F P
0 g
s
.30995 .73206 m .30252 .71442 L .31002 .7081 L p .707 .577 .707 r
F P
0 g
s
.47782 .5234 m .47388 .57841 L .4529 .56994 L p .707 .577 .707 r
F P
0 g
s
.4529 .56994 m .45683 .51493 L .47782 .5234 L p .707 .577 .707 r
F P
0 g
s
.31002 .7081 m .31746 .72575 L .30995 .73206 L p .707 .577 .707 r
F P
0 g
s
.48836 .63577 m .4958 .65341 L .48511 .65479 L p .707 .577 .707 r
F P
0 g
s
.48511 .65479 m .47768 .63715 L .48836 .63577 L p .707 .577 .707 r
F P
0 g
s
.30932 .56438 m .31325 .50937 L .33727 .50475 L p .707 .577 .707 r
F P
0 g
s
.29805 .65509 m .29189 .61793 L .30819 .60973 L p .707 .577 .707 r
F P
0 g
s
.30819 .60973 m .31435 .64689 L .29805 .65509 L p .707 .577 .707 r
F P
0 g
s
.47095 .5863 m .47712 .62346 L .45646 .62178 L p .707 .577 .707 r
F P
0 g
s
.45646 .62178 m .45029 .58462 L .47095 .5863 L p .707 .577 .707 r
F P
0 g
s
.45683 .51493 m .4529 .56994 L .42552 .56333 L p .707 .577 .707 r
F P
0 g
s
.42552 .56333 m .42945 .50832 L .45683 .51493 L p .707 .577 .707 r
F P
0 g
s
.33727 .50475 m .33333 .55976 L .30932 .56438 L p .707 .577 .707 r
F P
0 g
s
.33333 .55976 m .33727 .50475 L .3666 .50296 L p .707 .577 .707 r
F P
0 g
s
.31746 .72575 m .31002 .7081 L .32597 .69868 L p .707 .577 .707 r
F P
0 g
s
.32597 .69868 m .3334 .71633 L .31746 .72575 L p .707 .577 .707 r
F P
0 g
s
.47768 .63715 m .48511 .65479 L .46646 .66002 L p .707 .577 .707 r
F P
0 g
s
.46646 .66002 m .45902 .64238 L .47768 .63715 L p .707 .577 .707 r
F P
0 g
s
.31435 .64689 m .30819 .60973 L .33204 .60164 L p .707 .577 .707 r
F P
0 g
s
.42945 .50832 m .42552 .56333 L .39442 .5592 L p .707 .577 .707 r
F P
0 g
s
.39442 .5592 m .39836 .50419 L .42945 .50832 L p .707 .577 .707 r
F P
0 g
s
.36266 .55797 m .3666 .50296 L .39836 .50419 L p .707 .577 .707 r
F P
0 g
s
.3666 .50296 m .36266 .55797 L .33333 .55976 L p .707 .577 .707 r
F P
0 g
s
.39836 .50419 m .39442 .5592 L .36266 .55797 L p .707 .577 .707 r
F P
0 g
s
.45029 .58462 m .45646 .62178 L .42944 .62268 L p .707 .577 .707 r
F P
0 g
s
.42944 .62268 m .42328 .58552 L .45029 .58462 L p .707 .577 .707 r
F P
0 g
s
.33204 .60164 m .3382 .6388 L .31435 .64689 L p .707 .577 .707 r
F P
0 g
s
.3334 .71633 m .32597 .69868 L .3488 .68708 L p .707 .577 .707 r
F P
0 g
s
.3488 .68708 m .35623 .70473 L .3334 .71633 L p .707 .577 .707 r
F P
0 g
s
.3382 .6388 m .33204 .60164 L .3611 .59447 L p .707 .577 .707 r
F P
0 g
s
.45902 .64238 m .46646 .66002 L .44166 .66858 L p .707 .577 .707 r
F P
0 g
s
.44166 .66858 m .43422 .65093 L .45902 .64238 L p .707 .577 .707 r
F P
0 g
s
.42328 .58552 m .42944 .62268 L .39871 .62608 L p .707 .577 .707 r
F P
0 g
s
.39871 .62608 m .39254 .58892 L .42328 .58552 L p .707 .577 .707 r
F P
0 g
s
.3611 .59447 m .36727 .63163 L .3382 .6388 L p .707 .577 .707 r
F P
0 g
s
.36727 .63163 m .3611 .59447 L .39254 .58892 L p .707 .577 .707 r
F P
0 g
s
.39254 .58892 m .39871 .62608 L .36727 .63163 L p .707 .577 .707 r
F P
0 g
s
.35623 .70473 m .3488 .68708 L .37628 .67443 L p .707 .577 .707 r
F P
0 g
s
.43422 .65093 m .44166 .66858 L .41315 .67962 L p .707 .577 .707 r
F P
0 g
s
.41315 .67962 m .40571 .66198 L .43422 .65093 L p .707 .577 .707 r
F P
0 g
s
.37628 .67443 m .38371 .69208 L .35623 .70473 L p .707 .577 .707 r
F P
0 g
s
.38371 .69208 m .37628 .67443 L .40571 .66198 L p .707 .577 .707 r
F P
0 g
s
.40571 .66198 m .41315 .67962 L .38371 .69208 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6000OGoo001oOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Uoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00Lgoo1P00
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001^
Ool50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH2001]Ool006]oo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00QJEP8006]oo`00JGoo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF00<007ooOol0J7oo001XOol0
1000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH02eYFJWoo001VOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1WOol006Eoo`03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00aJEP03001oogoo06Ioo`00I7oo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02eYF00<007oo
Ool0IWoo001SOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00Oomoo`1VOol0069oo`04001JEUYF
0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUH0001W
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUH0001WOol006=oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUH0001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
0000Igoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEP0006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IWoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP<006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005eooaT000=JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00F7oo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P002EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001FOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001BOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00@005YFFUIJEP<006Aoo`00DWoo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001T
Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`00I7oo001BOol00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP<006Aoo`00DWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH3001TOol0059oo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0`001goo5`00AWoo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool4
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60010Ool0055oo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPD000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003aoo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Goo001AOol0
0`00FUH00003FUH01000FUIJEUYF3`000UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00L0
05YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH3000gOol0055oo`03001JEP0000=JEP@00003FUH005YF00IJEP03001JEUYF009JEQ40
00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003Eoo`00DGoo00@005YF001JEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH0
1`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DGoo00<005YF00000P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035o
o`00DGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P00
15YF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`
Ool0055oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000`Ool0055oo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEQ<00003FUH00000008000IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002moo`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000@000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00Dgoo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP<000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002moo`00=goo60001Goo0P001EYF00<0
05YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00=7oo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035o
o`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@00003FUH0
05YF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004
FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000_Ool0
02moo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH00`00FUH00003FUH500000eYF001JEP05FUH00`00FUIJEP02FUHB0006FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002moo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP04001JEP00FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002mo
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP@000AJEP03001JEUYF0080031oo`00:goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP<00004FUH005YFFUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH01@00FUIJEUYF00001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF0P00
<7oo000[Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80006FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00<7oo000[Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP<0031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001J
EUYF00AJEPH00003FUH0000000<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUHB0002FUH3000`Ool002]oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF01000003FUH005YF00MJEP03001JEUYF00AJEP03001J
EUYF009JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000060003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH6000`Ool002]oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00D0009JEP03
001JEUYF00EJEP03001JEUYF00AJEPD00003FUH0000000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00<7oo000[Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005
FUH00`00FUH000030003FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00@0
05YFFUIJEP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH000001EYF00<005YFFUH015YF00<005YF000010001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00<7oo000ZOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH005YF<Goo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH400000eYF000000030006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<Goo000ZOol00`00FUH00003FUH01000FUIJEUYF3P000goo200015YF00<005YFFUH00`0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF0080031oo`00:Woo00<005YF00000eYF100000=JEP00FUH01UYF00<005YF
FUH00UYF40000UYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH010000UYF00<005YFFUH015YF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080031oo`00
:Woo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH0
0`00FUIJEP04FUH40004FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF0080031oo`00:Woo00<005YF00000P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF1P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF0000031oo`00:Woo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH025YF00@005YF000000AJEP04001JEUYFFUH2
0009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH01000FUIJ
EP00<7oo000ZOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P001EYF
00<005YFFUH01EYF0`001eYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2@001EYF1P0000=JEP00Ool0;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUHD00000eYF00000008FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001UYF00<005YF
FUH015YF00<005YFFUH00UYF1000;goo000ZOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUHB0002FUH40003Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=oo`0000000P00
0UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001P00;goo000[Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01eYF1`0015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJ
EP00000007oo008000=JEP03001JEUYF00IJEP<000UJEP04001JEP000003FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP0400000goo000000040006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000UYF00<005YF
FUH00P00;goo000/Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP050006FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P001EYF00<005YF
FUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P0025YF00<005YFFUH00`001EYF00<005YFFUH00eYF0P0025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP04001J
EUYF000_Ool002ioo`8000AJEP03001JEUYF00=JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<00003FUH005YF00QJEP8000UJEP03001JEP00008000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000AJEP04
001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool300000eYF001JEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH20002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH01EYF00@005YFFUIJEPH002ioo`00<Woo100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00EJEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP05FUH40003FUH2000_Ool002moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000QJEP04
001JEP000006FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20008FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0^Ool0
02eoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP80009JEP03001JEUYF00AJEP<000QJEP03001JEUYF008000QJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<000UJEP03001JEUYF008000AJEP05001J
EUYFFUH0000aOol002]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP@000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000000eYF
00<005YFFUH01UYF0`001eYF0`00<Woo000ZOol20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00@005YF000000AJEP03001JEUYF
00=JEP<000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20005FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH2000dOol002Yoo`8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF009J
EP8000MJEP03001JEP00008000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<00003FUH005YF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000QJEP03001JEP00008000EJEP03001JEUYF009JEP8003Ioo`00:Goo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPX000EJEP80009JEP07
001JEUYFFUH005YF00001UYF100000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00004`0000=J
EP00FUH025YF0`0025YF00@005YF000003Qoo`00:Goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00AJEPH00003Ool000000080009JEP03001JEUYF00IJEP80009JEP<0009JEP03001JEUYF
009JEP8000=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH80002FUH60004FUH00`00
FUIJEP04FUH200000eYF001JEP08FUH2000jOol002Uoo`04001JEUYF0004FUH00`00FUIJEP05FUH0
0`00FUIJEP0@00000eYF001JEP07FUH20002FUH00`00FUIJEP03FUH00`00FUH000020004Ool00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF1P001eYF00<005YFFUH00UYF0P0015YF
00<005YFFUH015YF0P00?7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH80004FUH00`00FUIJ
EP050002FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEP@00003FUH0000000Aoo`03001JEP00
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUH000020009FUH01000FUH000001UYF
00<005YFFUH00UYF0P00?Woo000ZOol00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH0
1UYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YF00001@000UYF00D005YFFUIJEP0000Ao
o`03001JEP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP05001JEUYFFUH00003FUH01000FUIJEUYF0`0015YF0P000eYF00<005YFFUH0
1EYF0`002EYF00@005YF0000041oo`00:Woo00<005YF00001EYF00@005YF000000EJEP03001JEUYF
00MJEP03001JEUYF00<000=JEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH00P00
0goo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP8000EJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00EJEP<0049oo`00:Woo00@005YFFUH000=JEP@000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF009JEP05001JEUYFFUH00003Ool0
0`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40007FUH00`00FUH000020005FUH00`00
FUIJEP03FUH20015Ool002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP03FUH00`00FUH000020002Ool0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH20009FUH0
0`00FUH000020017Ool002]oo`9JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00MJEP03001JEUYF00@0009JEP04001oogoo0009FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP04FUHI0005FUH00`00FUIJEP05FUH01@00FUIJEUYF
00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01EYF0`00BWoo000[Ool01EYF001JEUYF0000
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH015YF1000
15YF0P000goo00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF2P002eYF00<005YFFUH0
2EYF20001UYF00<005YFFUH00P001UYF00@005YF000000AJEP03001JEUYF00=JEP8004eoo`00:goo
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`001eYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<007ooOol00Woo00<005YFFUH01eYF00<005YF
FUH01eYF00<005YFFUH01P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF0P001eYF00<005YF00000P00Cgoo000[Ool20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP08FUH0
1000FUH0000015YF00@005YFFUIJEP8000Eoo`03001JEUYF00MJEP03001JEUYF00IJEP@0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000800005
FUH005YFFUH00003FUH200000eYF001JEP05FUH3001BOol002aoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPH000EJEP03001JEUYF00EJEP<000MJEP<000Qoo`UJEP03001JEUYF
00=JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF009JEP<0009JEP<000=JEP03001JEUYF009JEP8005Eoo`00;Woo500000=oo`00000025YF
00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<007ooOol027oo2EYF00<005YF00000`002EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YF00000P00EWoo0011Ool200000eYF001JEP08FUH00`00FUH00002
0005FUH00`00FUIJEP02FUH2000;Ool8FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF
1`00EWoo000oOol20003FUH00`00FUIJEP06FUH40008FUH01000FUH000003Goo1UYF0P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF0P000UYF1@0000AJEP00FUIJEP8005Ioo`00?Goo0P001UYF00<005YFFUH00eYF0`00
00=JEP00FUH025YF0P003goo15YF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF00<005YF00000`001EYF00@005YFFUH005Io
o`00>goo0P0025YF00<005YFFUH00`001EYF00<005YFFUH015YF0P004Goo0UYF0P002EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF
00H005YFFUH005YF0005FUH01000FUIJEP00EWoo000iOol200000eYF001JEP08FUH20008FUH00`00
FUIJEP02FUH2000COol00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH01000FUIJEP00EGoo000gOol20004FUH00`00FUIJEP04FUH200000eYF001J
EP08FUH01000FUH000005Goo00=JEP00FUH00eYF00<005YFFUH03eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF
1@00EGoo000eOol20006FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH3000GOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH2001FOol003Ao
o`8000QJEP04001JEP000006FUH00`00FUIJEP03FUH2000JOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUIJEUYF0P001UYF0`0015YF00<007ooOol0EGoo000bOol20002FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP03000MOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUIJEP00FUH0009JEP@0009J
EP05001JEUYFFUH0001HOol0035oo`03001JEUYF009JEP03001JEUYF009JEP80009JEP03001JEUYF
00IJEP<0021oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0009JEP<000MJEP<005Uoo`00<7oo0P00
1EYF00@005YF000000AJEP03001JEUYF00=JEP<002Aoo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<00004FUH0
00000002FUH00`00FUIJEP04FUH2001KOol002moo`04001JEUYF0004FUH20007FUH00`00FUH00002
000YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05000015YF000000001EYF00<005YFFUH00UYF0P00GGoo000_Ool01000FUIJEP000eYF
00<005YF00001UYF0`00;Woo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF1@0015YF0`0025YF00@005YF000005moo`00;goo0P000UYF0`000UYF00<005YF
FUH00UYF0P00<goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPL000IJEP800003FUH005YF00QJEP80065oo`00<7oo00@005YFFUH000EJEP04001JEP00000i
Ool80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH90006FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH2001SOol0031oo`05001JEP00FUH00002FUH40013OolI0004Ool30009FUH01000FUH0
00001UYF00<005YFFUH00UYF0P00IGoo000aOol00`00FUH00003001SOol01@00FUIJEUYF00001eYF
0`002EYF00@005YF000006Moo`00<Goo0P00IGoo0P0015YF00<005YFFUH00eYF0P000eYF00<005YF
FUH01EYF0`00JGoo002FOol20007FUH00`00FUH000020005FUH00`00FUIJEP03FUH2001/Ool009Ao
o`800003FUH005YF00IJEP8000UJEP03001JEP00008006ioo`00TWoo0P0015YF00<005YFFUH00UYF
0P000UYF00<005YFFUH01EYF0`00LGoo002AOol20005FUH01@00FUIJEUYF000015YF00<005YFFUH0
0eYF0P00M7oo002@Ool01000FUIJEP001EYF0`001UYF00<005YF00000P00MWoo002@Ool01000FUIJ
EP0015YF0`001UYF0`00NGoo002AOol01@00FUIJEP00FUH00P000UYF00<005YFFUH00UYF0P00O7oo
002AOol00`00FUIJEP020005FUH01000FUH00000OWoo002BOol01EYF001JEUYF00000UYF1000P7oo
002BOol00`00FUIJEP040024Ool009=oo`8008Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59021 .75232 m .59264 .69706 L .5615 .69378 L p .707 .577 .707 r
F P
0 g
s
.59264 .69706 m .59021 .75232 L .62202 .75279 L p .707 .577 .707 r
F P
0 g
s
.62202 .75279 m .62445 .69752 L .59264 .69706 L p .707 .577 .707 r
F P
0 g
s
.62445 .69752 m .62202 .75279 L .65138 .75039 L p .707 .577 .707 r
F P
0 g
s
.65138 .75039 m .65381 .69513 L .62445 .69752 L p .707 .577 .707 r
F P
0 g
s
.55907 .74904 m .5615 .69378 L .53407 .68801 L p .707 .577 .707 r
F P
0 g
s
.5615 .69378 m .55907 .74904 L .59021 .75232 L p .707 .577 .707 r
F P
0 g
s
.65381 .69513 m .65138 .75039 L .67542 .74538 L p .707 .577 .707 r
F P
0 g
s
.67542 .74538 m .67785 .69011 L .65381 .69513 L p .707 .577 .707 r
F P
0 g
s
.53164 .74327 m .53407 .68801 L .51305 .68031 L p .707 .577 .707 r
F P
0 g
s
.53407 .68801 m .53164 .74327 L .55907 .74904 L p .707 .577 .707 r
F P
0 g
s
.5925 .80897 m .58868 .77172 L .55768 .77309 L p .707 .577 .707 r
F P
0 g
s
.58868 .77172 m .5925 .80897 L .62419 .80524 L p .707 .577 .707 r
F P
0 g
s
.62419 .80524 m .62037 .76799 L .58868 .77172 L p .707 .577 .707 r
F P
0 g
s
.62037 .76799 m .62419 .80524 L .65345 .79952 L p .707 .577 .707 r
F P
0 g
s
.65345 .79952 m .64963 .76227 L .62037 .76799 L p .707 .577 .707 r
F P
0 g
s
.5615 .81034 m .55768 .77309 L .53039 .77197 L p .707 .577 .707 r
F P
0 g
s
.55768 .77309 m .5615 .81034 L .5925 .80897 L p .707 .577 .707 r
F P
0 g
s
.59923 .84454 m .59455 .82616 L .56441 .83235 L p .707 .577 .707 r
F P
0 g
s
.59455 .82616 m .59923 .84454 L .63014 .83647 L p .707 .577 .707 r
F P
0 g
s
.63014 .83647 m .62546 .81809 L .59455 .82616 L p .707 .577 .707 r
F P
0 g
s
.64963 .76227 m .65345 .79952 L .67742 .79237 L p .707 .577 .707 r
F P
0 g
s
.67742 .79237 m .6736 .75512 L .64963 .76227 L p .707 .577 .707 r
F P
0 g
s
.67785 .69011 m .67542 .74538 L .69178 .73823 L p .707 .577 .707 r
F P
0 g
s
.69178 .73823 m .69422 .68296 L .67785 .69011 L p .707 .577 .707 r
F P
0 g
s
.62546 .81809 m .63014 .83647 L .65879 .8273 L p .707 .577 .707 r
F P
0 g
s
.65879 .8273 m .65411 .80892 L .62546 .81809 L p .707 .577 .707 r
F P
0 g
s
.51305 .68031 m .51061 .73557 L .53164 .74327 L p .707 .577 .707 r
F P
0 g
s
.56441 .83235 m .56909 .85073 L .59923 .84454 L p .707 .577 .707 r
F P
0 g
s
.53039 .77197 m .53421 .80922 L .5615 .81034 L p .707 .577 .707 r
F P
0 g
s
.56909 .85073 m .56441 .83235 L .53797 .83604 L p .707 .577 .707 r
F P
0 g
s
.51061 .73557 m .51305 .68031 L .50047 .67144 L p .707 .577 .707 r
F P
0 g
s
.53421 .80922 m .53039 .77197 L .50948 .76847 L p .707 .577 .707 r
F P
0 g
s
.53797 .83604 m .54266 .85442 L .56909 .85073 L p .707 .577 .707 r
F P
0 g
s
.65411 .80892 m .65879 .8273 L .68237 .81794 L p .707 .577 .707 r
F P
0 g
s
.68237 .81794 m .67769 .79955 L .65411 .80892 L p .707 .577 .707 r
F P
0 g
s
.50948 .76847 m .5133 .80572 L .53421 .80922 L p .707 .577 .707 r
F P
0 g
s
.6736 .75512 m .67742 .79237 L .69377 .78448 L p .707 .577 .707 r
F P
0 g
s
.69377 .78448 m .68995 .74723 L .6736 .75512 L p .707 .577 .707 r
F P
0 g
s
.50047 .67144 m .49804 .7267 L .51061 .73557 L p .707 .577 .707 r
F P
0 g
s
.54266 .85442 m .53797 .83604 L .51784 .83688 L p .707 .577 .707 r
F P
0 g
s
.69422 .68296 m .69178 .73823 L .69887 .72965 L p .707 .577 .707 r
F P
0 g
s
.69887 .72965 m .7013 .67438 L .69422 .68296 L p .707 .577 .707 r
F P
0 g
s
.51784 .83688 m .52253 .85526 L .54266 .85442 L p .707 .577 .707 r
F P
0 g
s
.67769 .79955 m .68237 .81794 L .69858 .80929 L p .707 .577 .707 r
F P
0 g
s
.69858 .80929 m .6939 .79091 L .67769 .79955 L p .707 .577 .707 r
F P
0 g
s
.5133 .80572 m .50948 .76847 L .49701 .76292 L p .707 .577 .707 r
F P
0 g
s
.49804 .7267 m .50047 .67144 L .49759 .66226 L p .707 .577 .707 r
F P
0 g
s
.49701 .76292 m .50083 .80018 L .5133 .80572 L p .707 .577 .707 r
F P
0 g
s
.68995 .74723 m .69377 .78448 L .70088 .77664 L p .707 .577 .707 r
F P
0 g
s
.70088 .77664 m .69706 .73938 L .68995 .74723 L p .707 .577 .707 r
F P
0 g
s
.52253 .85526 m .51784 .83688 L .50599 .83479 L p .707 .577 .707 r
F P
0 g
s
.49759 .66226 m .49516 .71753 L .49804 .7267 L p .707 .577 .707 r
F P
0 g
s
.50599 .83479 m .51067 .85317 L .52253 .85526 L p .707 .577 .707 r
F P
0 g
s
.7013 .67438 m .69887 .72965 L .69599 .72047 L p .707 .577 .707 r
F P
0 g
s
.69599 .72047 m .69842 .66521 L .7013 .67438 L p .707 .577 .707 r
F P
0 g
s
.6939 .79091 m .69858 .80929 L .70583 .8022 L p .707 .577 .707 r
F P
0 g
s
.70583 .8022 m .70114 .78382 L .6939 .79091 L p .707 .577 .707 r
F P
0 g
s
.50083 .80018 m .49701 .76292 L .49419 .75588 L p .707 .577 .707 r
F P
0 g
s
.49516 .71753 m .49759 .66226 L .50468 .65368 L p .707 .577 .707 r
F P
0 g
s
.49419 .75588 m .49801 .79314 L .50083 .80018 L p .707 .577 .707 r
F P
0 g
s
.50468 .65368 m .50225 .70894 L .49516 .71753 L p .707 .577 .707 r
F P
0 g
s
.49801 .79314 m .49419 .75588 L .5013 .74804 L p .707 .577 .707 r
F P
0 g
s
.5013 .74804 m .50512 .78529 L .49801 .79314 L p .707 .577 .707 r
F P
0 g
s
.50084 .82131 m .48403 .31792 L .44004 .31673 L p .707 .577 .707 r
F P
0 g
s
.50225 .70894 m .50468 .65368 L .52104 .64653 L p .707 .577 .707 r
F P
0 g
s
.52104 .64653 m .51861 .70179 L .50225 .70894 L p .707 .577 .707 r
F P
0 g
s
.51861 .70179 m .52104 .64653 L .54508 .64151 L p .707 .577 .707 r
F P
0 g
s
.50512 .78529 m .5013 .74804 L .51764 .74015 L p .707 .577 .707 r
F P
0 g
s
.51764 .74015 m .52147 .77741 L .50512 .78529 L p .707 .577 .707 r
F P
0 g
s
.54508 .64151 m .54265 .69678 L .51861 .70179 L p .707 .577 .707 r
F P
0 g
s
.51549 .84126 m .51081 .82288 L .52701 .81423 L p .707 .577 .707 r
F P
0 g
s
.52701 .81423 m .5317 .83261 L .51549 .84126 L p .707 .577 .707 r
F P
0 g
s
.52147 .77741 m .51764 .74015 L .54162 .733 L p .707 .577 .707 r
F P
0 g
s
.54162 .733 m .54544 .77025 L .52147 .77741 L p .707 .577 .707 r
F P
0 g
s
.5317 .83261 m .52701 .81423 L .55059 .80486 L p .707 .577 .707 r
F P
0 g
s
.55059 .80486 m .55528 .82325 L .5317 .83261 L p .707 .577 .707 r
F P
0 g
s
.48403 .31792 m .50084 .82131 L .54577 .81886 L p .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .54162 .733 L .56511 .72841 L p .707 .577 .707 r
F P
0 g
s
.56511 .72841 m .57088 .72728 L p .56643 .73479 L .707 .577 .707 r
F P
0 g
s
.54544 .77025 m .56511 .72841 L .56643 .73479 L .707 .577 .707 r
F
.52895 .31547 m .48403 .31792 L p .48962 .36328 L F P
0 g
s
.54577 .81886 m .53843 .59938 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.53843 .59938 m .52895 .31547 L p .48962 .36328 L .707 .577 .707 r
F P
0 g
s
.54265 .69678 m .54508 .64151 L .57444 .63912 L p .707 .577 .707 r
F P
0 g
s
.57201 .69439 m .57444 .63912 L .60625 .63959 L p .707 .577 .707 r
F P
0 g
s
.57444 .63912 m .57201 .69439 L .54265 .69678 L p .707 .577 .707 r
F P
0 g
s
.60625 .63959 m .60382 .69485 L .57201 .69439 L p .707 .577 .707 r
F P
0 g
s
.57088 .72728 m .5747 .76453 L .54544 .77025 L p .707 .577 .707 r
F P
0 g
s
.5747 .76453 m .57088 .72728 L .60257 .72355 L p .707 .577 .707 r
F P
0 g
s
.60257 .72355 m .60639 .7608 L .5747 .76453 L p .707 .577 .707 r
F P
0 g
s
.55528 .82325 m .55059 .80486 L .57924 .7957 L p .707 .577 .707 r
F P
0 g
s
.57924 .7957 m .58392 .81408 L .55528 .82325 L p .707 .577 .707 r
F P
0 g
s
.58392 .81408 m .57924 .7957 L .61015 .78762 L p .707 .577 .707 r
F P
0 g
s
.61015 .78762 m .61483 .80601 L .58392 .81408 L p .707 .577 .707 r
F P
0 g
s
.52895 .31547 m .54577 .81886 L .58723 .81302 L p .707 .577 .707 r
F P
0 g
s
.58723 .81302 m .57041 .30963 L .52895 .31547 L p .707 .577 .707 r
F P
0 g
s
.45686 .82012 m .44004 .31673 L .4013 .31203 L p .707 .577 .707 r
F P
0 g
s
.44004 .31673 m .45686 .82012 L .50084 .82131 L p .707 .577 .707 r
F P
0 g
s
.69706 .73938 m .70088 .77664 L .69806 .7696 L p .707 .577 .707 r
F P
0 g
s
.69806 .7696 m .69424 .73234 L .69706 .73938 L p .707 .577 .707 r
F P
0 g
s
.51067 .85317 m .50599 .83479 L .50356 .82996 L p .707 .577 .707 r
F P
0 g
s
.50356 .82996 m .50824 .84834 L .51067 .85317 L p .707 .577 .707 r
F P
0 g
s
.63739 .64287 m .63496 .69813 L .60382 .69485 L p .707 .577 .707 r
F P
0 g
s
.60382 .69485 m .60625 .63959 L .63739 .64287 L p .707 .577 .707 r
F P
0 g
s
.63357 .72218 m .63739 .75943 L .60639 .7608 L p .707 .577 .707 r
F P
0 g
s
.60639 .7608 m .60257 .72355 L .63357 .72218 L p .707 .577 .707 r
F P
0 g
s
.6403 .78144 m .64498 .79982 L .61483 .80601 L p .707 .577 .707 r
F P
0 g
s
.61483 .80601 m .61015 .78762 L .6403 .78144 L p .707 .577 .707 r
F P
0 g
s
.57041 .30963 m .58723 .81302 L .62117 .80436 L p .707 .577 .707 r
F P
0 g
s
.62117 .80436 m .60436 .30097 L .57041 .30963 L p .707 .577 .707 r
F P
0 g
s
.69842 .66521 m .69599 .72047 L .68342 .7116 L p .707 .577 .707 r
F P
0 g
s
.68342 .7116 m .68585 .65633 L .69842 .66521 L p .707 .577 .707 r
F P
0 g
s
.70114 .78382 m .70583 .8022 L .7034 .79738 L p .707 .577 .707 r
F P
0 g
s
.7034 .79738 m .69872 .779 L .70114 .78382 L p .707 .577 .707 r
F P
0 g
s
.2472 .71129 m .24963 .65603 L .21849 .65275 L p .707 .577 .707 r
F P
0 g
s
.24963 .65603 m .2472 .71129 L .27901 .71176 L p .707 .577 .707 r
F P
0 g
s
.27901 .71176 m .28144 .6565 L .24963 .65603 L p .707 .577 .707 r
F P
0 g
s
.41812 .81542 m .4013 .31203 L .3716 .30427 L p .707 .577 .707 r
F P
0 g
s
.4013 .31203 m .41812 .81542 L .45686 .82012 L p .707 .577 .707 r
F P
0 g
s
.28144 .6565 m .27901 .71176 L .30837 .70937 L p .707 .577 .707 r
F P
0 g
s
.30837 .70937 m .3108 .6541 L .28144 .6565 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21606 .70801 m .21849 .65275 L .19106 .64698 L p .707 .577 .707 r
F P
0 g
s
.21849 .65275 m .21606 .70801 L .2472 .71129 L p .707 .577 .707 r
F P
0 g
s
.69424 .73234 m .69806 .7696 L .68558 .76405 L p .707 .577 .707 r
F P
0 g
s
.68558 .76405 m .68176 .7268 L .69424 .73234 L p .707 .577 .707 r
F P
0 g
s
.3108 .6541 m .30837 .70937 L .33241 .70435 L p .707 .577 .707 r
F P
0 g
s
.33241 .70435 m .33484 .64909 L .3108 .6541 L p .707 .577 .707 r
F P
0 g
s
.50824 .84834 m .50356 .82996 L .51081 .82288 L p .707 .577 .707 r
F P
0 g
s
.66482 .64864 m .66239 .7039 L .63496 .69813 L p .707 .577 .707 r
F P
0 g
s
.63496 .69813 m .63739 .64287 L .66482 .64864 L p .707 .577 .707 r
F P
0 g
s
.66086 .7233 m .66468 .76055 L .63739 .75943 L p .707 .577 .707 r
F P
0 g
s
.63739 .75943 m .63357 .72218 L .66086 .7233 L p .707 .577 .707 r
F P
0 g
s
.64498 .79982 m .6403 .78144 L .66673 .77774 L p .707 .577 .707 r
F P
0 g
s
.60436 .30097 m .62117 .80436 L .64428 .79372 L p .707 .577 .707 r
F P
0 g
s
.64428 .79372 m .62746 .29033 L .60436 .30097 L p .707 .577 .707 r
F P
0 g
s
.51081 .82288 m .51549 .84126 L .50824 .84834 L p .707 .577 .707 r
F P
0 g
s
.68585 .65633 m .68342 .7116 L .66239 .7039 L p .707 .577 .707 r
F P
0 g
s
.66239 .7039 m .66482 .64864 L .68585 .65633 L p .707 .577 .707 r
F P
0 g
s
.18863 .70224 m .19106 .64698 L .17004 .63928 L p .707 .577 .707 r
F P
0 g
s
.19106 .64698 m .18863 .70224 L .21606 .70801 L p .707 .577 .707 r
F P
0 g
s
.24949 .76643 m .24567 .72918 L .21467 .73055 L p .707 .577 .707 r
F P
0 g
s
.24567 .72918 m .24949 .76643 L .28118 .7627 L p .707 .577 .707 r
F P
0 g
s
.28118 .7627 m .27736 .72545 L .24567 .72918 L p .707 .577 .707 r
F P
0 g
s
.69872 .779 m .7034 .79738 L .69154 .79528 L p .707 .577 .707 r
F P
0 g
s
.69154 .79528 m .68686 .7769 L .69872 .779 L p .707 .577 .707 r
F P
0 g
s
.27736 .72545 m .28118 .7627 L .31044 .75698 L p .707 .577 .707 r
F P
0 g
s
.31044 .75698 m .30662 .71973 L .27736 .72545 L p .707 .577 .707 r
F P
0 g
s
.21849 .7678 m .21467 .73055 L .18738 .72943 L p .707 .577 .707 r
F P
0 g
s
.21467 .73055 m .21849 .7678 L .24949 .76643 L p .707 .577 .707 r
F P
0 g
s
.30662 .71973 m .31044 .75698 L .33441 .74983 L p .707 .577 .707 r
F P
0 g
s
.33441 .74983 m .33059 .71258 L .30662 .71973 L p .707 .577 .707 r
F P
0 g
s
.25623 .80609 m .25154 .78771 L .2214 .7939 L p .707 .577 .707 r
F P
0 g
s
.25154 .78771 m .25623 .80609 L .28714 .79802 L p .707 .577 .707 r
F P
0 g
s
.28714 .79802 m .28245 .77964 L .25154 .78771 L p .707 .577 .707 r
F P
0 g
s
.33484 .64909 m .33241 .70435 L .34877 .6972 L p .707 .577 .707 r
F P
0 g
s
.34877 .6972 m .35121 .64194 L .33484 .64909 L p .707 .577 .707 r
F P
0 g
s
.38842 .80766 m .3716 .30427 L .35384 .29421 L p .707 .577 .707 r
F P
0 g
s
.3716 .30427 m .38842 .80766 L .41812 .81542 L p .707 .577 .707 r
F P
0 g
s
.28245 .77964 m .28714 .79802 L .31578 .78885 L p .707 .577 .707 r
F P
0 g
s
.31578 .78885 m .3111 .77047 L .28245 .77964 L p .707 .577 .707 r
F P
0 g
s
.17004 .63928 m .1676 .69455 L .18863 .70224 L p .707 .577 .707 r
F P
0 g
s
.18738 .72943 m .1912 .76668 L .21849 .7678 L p .707 .577 .707 r
F P
0 g
s
.2214 .7939 m .22608 .81228 L .25623 .80609 L p .707 .577 .707 r
F P
0 g
s
.68176 .7268 m .68558 .76405 L .66468 .76055 L p .707 .577 .707 r
F P
0 g
s
.66468 .76055 m .66086 .7233 L .68176 .7268 L p .707 .577 .707 r
F P
0 g
s
.22608 .81228 m .2214 .7939 L .19496 .79759 L p .707 .577 .707 r
F P
0 g
s
.1676 .69455 m .17004 .63928 L .15747 .63041 L p .707 .577 .707 r
F P
0 g
s
.1912 .76668 m .18738 .72943 L .16647 .72593 L p .707 .577 .707 r
F P
0 g
s
.19496 .79759 m .19965 .81597 L .22608 .81228 L p .707 .577 .707 r
F P
0 g
s
.3111 .77047 m .31578 .78885 L .33936 .77949 L p .707 .577 .707 r
F P
0 g
s
.33936 .77949 m .33468 .7611 L .3111 .77047 L p .707 .577 .707 r
F P
0 g
s
.68686 .7769 m .69154 .79528 L .67141 .79613 L p .707 .577 .707 r
F P
0 g
s
.67141 .79613 m .66673 .77774 L .68686 .7769 L p .707 .577 .707 r
F P
0 g
s
.16647 .72593 m .17029 .76318 L .1912 .76668 L p .707 .577 .707 r
F P
0 g
s
.33059 .71258 m .33441 .74983 L .35076 .74194 L p .707 .577 .707 r
F P
0 g
s
.35076 .74194 m .34694 .70469 L .33059 .71258 L p .707 .577 .707 r
F P
0 g
s
.62746 .29033 m .64428 .79372 L .65428 .78215 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .63746 .27876 L .62746 .29033 L p .707 .577 .707 r
F P
0 g
s
.15747 .63041 m .15503 .68567 L .1676 .69455 L p .707 .577 .707 r
F P
0 g
s
.19965 .81597 m .19496 .79759 L .17483 .79843 L p .707 .577 .707 r
F P
0 g
s
.35121 .64194 m .34877 .6972 L .35586 .68862 L p .707 .577 .707 r
F P
0 g
s
.35586 .68862 m .35829 .63335 L .35121 .64194 L p .707 .577 .707 r
F P
0 g
s
.17483 .79843 m .17952 .81681 L .19965 .81597 L p .707 .577 .707 r
F P
0 g
s
.33468 .7611 m .33936 .77949 L .35557 .77084 L p .707 .577 .707 r
F P
0 g
s
.35557 .77084 m .35089 .75246 L .33468 .7611 L p .707 .577 .707 r
F P
0 g
s
.17029 .76318 m .16647 .72593 L .154 .72039 L p .707 .577 .707 r
F P
0 g
s
.15503 .68567 m .15747 .63041 L .15458 .62124 L p .707 .577 .707 r
F P
0 g
s
.37066 .7976 m .35384 .29421 L .34976 .28283 L p .707 .577 .707 r
F P
0 g
s
.35384 .29421 m .37066 .7976 L .38842 .80766 L p .707 .577 .707 r
F P
0 g
s
.66673 .77774 m .67141 .79613 L .64498 .79982 L p .707 .577 .707 r
F P
0 g
s
.154 .72039 m .15782 .75764 L .17029 .76318 L p .707 .577 .707 r
F P
0 g
s
.34694 .70469 m .35076 .74194 L .35787 .7341 L p .707 .577 .707 r
F P
0 g
s
.35787 .7341 m .35405 .69685 L .34694 .70469 L p .707 .577 .707 r
F P
0 g
s
.17952 .81681 m .17483 .79843 L .16298 .79634 L p .707 .577 .707 r
F P
0 g
s
.15458 .62124 m .15215 .6765 L .15503 .68567 L p .707 .577 .707 r
F P
0 g
s
.16298 .79634 m .16766 .81472 L .17952 .81681 L p .707 .577 .707 r
F P
0 g
s
.35829 .63335 m .35586 .68862 L .35298 .67944 L p .707 .577 .707 r
F P
0 g
s
.35298 .67944 m .35541 .62418 L .35829 .63335 L p .707 .577 .707 r
F P
0 g
s
.35089 .75246 m .35557 .77084 L .36282 .76375 L p .707 .577 .707 r
F P
0 g
s
.36282 .76375 m .35813 .74537 L .35089 .75246 L p .707 .577 .707 r
F P
0 g
s
.65428 .78215 m .65021 .77078 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.65021 .77078 m .63339 .26739 L .63746 .27876 L p .707 .577 .707 r
F P
0 g
s
.63339 .26739 m .65021 .77078 L .63245 .76072 L p .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64669 .67643 L .64519 .67576 L p .707 .577 .707 r
F P
0 g
s
.64519 .67576 m .63422 .67089 L p .64567 .70097 L .707 .577 .707 r
F P
0 g
s
.65051 .71368 m .64519 .67576 L .64567 .70097 L .707 .577 .707 r
F
.63746 .27876 m .63809 .29737 L p .63846 .31704 L F P
0 g
s
.63809 .29737 m .65428 .78215 L p .63846 .31704 L .707 .577 .707 r
F P
0 g
s
.15782 .75764 m .154 .72039 L .15118 .71335 L p .707 .577 .707 r
F P
0 g
s
.15215 .6765 m .15458 .62124 L .16167 .61265 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15118 .71335 m .155 .7506 L .15782 .75764 L p .707 .577 .707 r
F P
0 g
s
.35405 .69685 m .35787 .7341 L .35505 .72706 L p .707 .577 .707 r
F P
0 g
s
.35505 .72706 m .35123 .68981 L .35405 .69685 L p .707 .577 .707 r
F P
0 g
s
.16766 .81472 m .16298 .79634 L .16055 .79151 L p .707 .577 .707 r
F P
0 g
s
.16167 .61265 m .15924 .66792 L .15215 .6765 L p .707 .577 .707 r
F P
0 g
s
.16055 .79151 m .16523 .80989 L .16766 .81472 L p .707 .577 .707 r
F P
0 g
s
.34976 .28283 m .36658 .78622 L .37066 .7976 L p .707 .577 .707 r
F P
0 g
s
.36658 .78622 m .34976 .28283 L .35977 .27126 L p .707 .577 .707 r
F P
0 g
s
.35541 .62418 m .35298 .67944 L .34041 .67057 L p .707 .577 .707 r
F P
0 g
s
.34041 .67057 m .34284 .61531 L .35541 .62418 L p .707 .577 .707 r
F P
0 g
s
.35813 .74537 m .36282 .76375 L .36039 .75893 L p .707 .577 .707 r
F P
0 g
s
.36039 .75893 m .35571 .74055 L .35813 .74537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.155 .7506 m .15118 .71335 L .15829 .7055 L p .707 .577 .707 r
F P
0 g
s
.15924 .66792 m .16167 .61265 L .17803 .6055 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15829 .7055 m .16211 .74275 L .155 .7506 L p .707 .577 .707 r
F P
0 g
s
.63245 .76072 m .61563 .25733 L .63339 .26739 L p .707 .577 .707 r
F P
0 g
s
.35123 .68981 m .35505 .72706 L .34257 .72152 L p .707 .577 .707 r
F P
0 g
s
.34257 .72152 m .33875 .68427 L .35123 .68981 L p .707 .577 .707 r
F P
0 g
s
.16523 .80989 m .16055 .79151 L .1678 .78443 L p .707 .577 .707 r
F P
0 g
s
.17803 .6055 m .1756 .66077 L .15924 .66792 L p .707 .577 .707 r
F P
0 g
s
.34284 .61531 m .34041 .67057 L .31938 .66287 L p .707 .577 .707 r
F P
0 g
s
.31938 .66287 m .32181 .60761 L .34284 .61531 L p .707 .577 .707 r
F P
0 g
s
.1678 .78443 m .17248 .80281 L .16523 .80989 L p .707 .577 .707 r
F P
0 g
s
.35571 .74055 m .36039 .75893 L .34853 .75683 L p .707 .577 .707 r
F P
0 g
s
.34853 .75683 m .34385 .73845 L .35571 .74055 L p .707 .577 .707 r
F P
0 g
s
.1756 .66077 m .17803 .6055 L .20207 .60049 L p .707 .577 .707 r
F P
0 g
s
.16211 .74275 m .15829 .7055 L .17464 .69762 L p .707 .577 .707 r
F P
0 g
s
.37659 .77465 m .35977 .27126 L .38287 .26062 L p .707 .577 .707 r
F P
0 g
s
.35977 .27126 m .37659 .77465 L .36658 .78622 L p .707 .577 .707 r
F P
0 g
s
.17464 .69762 m .17846 .73487 L .16211 .74275 L p .707 .577 .707 r
F P
0 g
s
.33875 .68427 m .34257 .72152 L .32167 .71801 L p .707 .577 .707 r
F P
0 g
s
.32167 .71801 m .31785 .68076 L .33875 .68427 L p .707 .577 .707 r
F P
0 g
s
.32181 .60761 m .31938 .66287 L .29195 .6571 L p .707 .577 .707 r
F P
0 g
s
.29195 .6571 m .29438 .60184 L .32181 .60761 L p .707 .577 .707 r
F P
0 g
s
.20207 .60049 m .19964 .65575 L .1756 .66077 L p .707 .577 .707 r
F P
0 g
s
.17248 .80281 m .1678 .78443 L .184 .77578 L p .707 .577 .707 r
F P
0 g
s
.19964 .65575 m .20207 .60049 L .23143 .59809 L p .707 .577 .707 r
F P
0 g
s
.184 .77578 m .18869 .79416 L .17248 .80281 L p .707 .577 .707 r
F P
0 g
s
.61563 .25733 m .63245 .76072 L .60274 .75296 L p .707 .577 .707 r
F P
0 g
s
.60274 .75296 m .58592 .24956 L .61563 .25733 L p .707 .577 .707 r
F P
0 g
s
.34385 .73845 m .34853 .75683 L .3284 .75767 L p .707 .577 .707 r
F P
0 g
s
.3284 .75767 m .32372 .73929 L .34385 .73845 L p .707 .577 .707 r
F P
0 g
s
.17846 .73487 m .17464 .69762 L .19861 .69046 L p .707 .577 .707 r
F P
0 g
s
.29438 .60184 m .29195 .6571 L .26081 .65382 L p .707 .577 .707 r
F P
0 g
s
.26081 .65382 m .26324 .59856 L .29438 .60184 L p .707 .577 .707 r
F P
0 g
s
.229 .65336 m .23143 .59809 L .26324 .59856 L p .707 .577 .707 r
F P
0 g
s
.23143 .59809 m .229 .65336 L .19964 .65575 L p .707 .577 .707 r
F P
0 g
s
.19861 .69046 m .20243 .72771 L .17846 .73487 L p .707 .577 .707 r
F P
0 g
s
.26324 .59856 m .26081 .65382 L .229 .65336 L p .707 .577 .707 r
F P
0 g
s
.31785 .68076 m .32167 .71801 L .29438 .71689 L p .707 .577 .707 r
F P
0 g
s
.29438 .71689 m .29056 .67964 L .31785 .68076 L p .707 .577 .707 r
F P
0 g
s
.72741 .66028 m .72985 .60502 L .69871 .60174 L p .707 .577 .707 r
F P
0 g
s
.72985 .60502 m .72741 .66028 L .75922 .66075 L p .707 .577 .707 r
F P
0 g
s
.75922 .66075 m .76166 .60548 L .72985 .60502 L p .707 .577 .707 r
F P
0 g
s
.38287 .26062 m .39969 .76401 L .37659 .77465 L p .707 .577 .707 r
F P
0 g
s
.39969 .76401 m .38287 .26062 L .41682 .25196 L p .707 .577 .707 r
F P
0 g
s
.76166 .60548 m .75922 .66075 L .78858 .65836 L p .707 .577 .707 r
F P
0 g
s
.78858 .65836 m .79102 .60309 L .76166 .60548 L p .707 .577 .707 r
F P
0 g
s
.18869 .79416 m .184 .77578 L .20758 .76641 L p .707 .577 .707 r
F P
0 g
s
.69627 .657 m .69871 .60174 L .67128 .59597 L p .707 .577 .707 r
F P
0 g
s
.69871 .60174 m .69627 .657 L .72741 .66028 L p .707 .577 .707 r
F P
0 g
s
.20243 .72771 m .19861 .69046 L .22787 .68474 L p .707 .577 .707 r
F P
0 g
s
.20758 .76641 m .21227 .7848 L .18869 .79416 L p .707 .577 .707 r
F P
0 g
s
.32372 .73929 m .3284 .75767 L .30197 .76137 L p .707 .577 .707 r
F P
0 g
s
.30197 .76137 m .29729 .74299 L .32372 .73929 L p .707 .577 .707 r
F P
0 g
s
.29056 .67964 m .29438 .71689 L .26338 .71826 L p .707 .577 .707 r
F P
0 g
s
.26338 .71826 m .25956 .68101 L .29056 .67964 L p .707 .577 .707 r
F P
0 g
s
.79102 .60309 m .78858 .65836 L .81262 .65334 L p .707 .577 .707 r
F P
0 g
s
.81262 .65334 m .81506 .59808 L .79102 .60309 L p .707 .577 .707 r
F P
0 g
s
.22787 .68474 m .23169 .72199 L .20243 .72771 L p .707 .577 .707 r
F P
0 g
s
.58592 .24956 m .60274 .75296 L .564 .74825 L p .707 .577 .707 r
F P
0 g
s
.564 .74825 m .54719 .24486 L .58592 .24956 L p .707 .577 .707 r
F P
0 g
s
.23169 .72199 m .22787 .68474 L .25956 .68101 L p .707 .577 .707 r
F P
0 g
s
.25956 .68101 m .26338 .71826 L .23169 .72199 L p .707 .577 .707 r
F P
0 g
s
.66884 .65123 m .67128 .59597 L .65025 .58827 L p .707 .577 .707 r
F P
0 g
s
.67128 .59597 m .66884 .65123 L .69627 .657 L p .707 .577 .707 r
F P
0 g
s
.72971 .71693 m .72589 .67968 L .69488 .68105 L p .707 .577 .707 r
F P
0 g
s
.72589 .67968 m .72971 .71693 L .76139 .7132 L p .707 .577 .707 r
F P
0 g
s
.76139 .7132 m .75757 .67595 L .72589 .67968 L p .707 .577 .707 r
F P
0 g
s
.75757 .67595 m .76139 .7132 L .79065 .70748 L p .707 .577 .707 r
F P
0 g
s
.79065 .70748 m .78683 .67023 L .75757 .67595 L p .707 .577 .707 r
F P
0 g
s
.21227 .7848 m .20758 .76641 L .23623 .75725 L p .707 .577 .707 r
F P
0 g
s
.23623 .75725 m .24092 .77563 L .21227 .7848 L p .707 .577 .707 r
F P
0 g
s
.29729 .74299 m .30197 .76137 L .27183 .76756 L p .707 .577 .707 r
F P
0 g
s
.27183 .76756 m .26714 .74917 L .29729 .74299 L p .707 .577 .707 r
F P
0 g
s
.43364 .75535 m .41682 .25196 L .45828 .24612 L p .707 .577 .707 r
F P
0 g
s
.41682 .25196 m .43364 .75535 L .39969 .76401 L p .707 .577 .707 r
F P
0 g
s
.6987 .7183 m .69488 .68105 L .66759 .67993 L p .707 .577 .707 r
F P
0 g
s
.69488 .68105 m .6987 .7183 L .72971 .71693 L p .707 .577 .707 r
F P
0 g
s
.73644 .75251 m .73176 .73412 L .70161 .74031 L p .707 .577 .707 r
F P
0 g
s
.73176 .73412 m .73644 .75251 L .76735 .74443 L p .707 .577 .707 r
F P
0 g
s
.76735 .74443 m .76267 .72605 L .73176 .73412 L p .707 .577 .707 r
F P
0 g
s
.24092 .77563 m .23623 .75725 L .26714 .74917 L p .707 .577 .707 r
F P
0 g
s
.78683 .67023 m .79065 .70748 L .81463 .70033 L p .707 .577 .707 r
F P
0 g
s
.81463 .70033 m .81081 .66308 L .78683 .67023 L p .707 .577 .707 r
F P
0 g
s
.81506 .59808 m .81262 .65334 L .82899 .64619 L p .707 .577 .707 r
F P
0 g
s
.82899 .64619 m .83142 .59093 L .81506 .59808 L p .707 .577 .707 r
F P
0 g
s
.76267 .72605 m .76735 .74443 L .796 .73526 L p .707 .577 .707 r
F P
0 g
s
.796 .73526 m .79131 .71688 L .76267 .72605 L p .707 .577 .707 r
F P
0 g
s
.26714 .74917 m .27183 .76756 L .24092 .77563 L p .707 .577 .707 r
F P
0 g
s
.65025 .58827 m .64782 .64353 L .66884 .65123 L p .707 .577 .707 r
F P
0 g
s
.70161 .74031 m .70629 .75869 L .73644 .75251 L p .707 .577 .707 r
F P
0 g
s
.66759 .67993 m .67141 .71718 L .6987 .7183 L p .707 .577 .707 r
F P
0 g
s
.54719 .24486 m .564 .74825 L .52002 .74706 L p .707 .577 .707 r
F P
0 g
s
.52002 .74706 m .5032 .24367 L .54719 .24486 L p .707 .577 .707 r
F P
0 g
s
.70629 .75869 m .70161 .74031 L .67518 .744 L p .707 .577 .707 r
F P
0 g
s
.64782 .64353 m .65025 .58827 L .63768 .5794 L p .707 .577 .707 r
F P
0 g
s
.4751 .74951 m .45828 .24612 L .5032 .24367 L p .707 .577 .707 r
F P
0 g
s
.45828 .24612 m .4751 .74951 L .43364 .75535 L p .707 .577 .707 r
F P
0 g
s
.67141 .71718 m .66759 .67993 L .64669 .67643 L p .707 .577 .707 r
F P
0 g
s
.67518 .744 m .67986 .76239 L .70629 .75869 L p .707 .577 .707 r
F P
0 g
s
.79131 .71688 m .796 .73526 L .81958 .7259 L p .707 .577 .707 r
F P
0 g
s
.81958 .7259 m .81489 .70752 L .79131 .71688 L p .707 .577 .707 r
F P
0 g
s
.5032 .24367 m .52002 .74706 L .4751 .74951 L p .707 .577 .707 r
F P
0 g
s
.64669 .67643 m .65051 .71368 L .67141 .71718 L p .707 .577 .707 r
F P
0 g
s
.81081 .66308 m .81463 .70033 L .83097 .69244 L p .707 .577 .707 r
F P
0 g
s
.83097 .69244 m .82715 .65519 L .81081 .66308 L p .707 .577 .707 r
F P
0 g
s
.63768 .5794 m .63525 .63466 L .64782 .64353 L p .707 .577 .707 r
F P
0 g
s
.67986 .76239 m .67518 .744 L .65505 .74484 L p .707 .577 .707 r
F P
0 g
s
.83142 .59093 m .82899 .64619 L .83607 .63761 L p .707 .577 .707 r
F P
0 g
s
.83607 .63761 m .83851 .58234 L .83142 .59093 L p .707 .577 .707 r
F P
0 g
s
.65505 .74484 m .65973 .76323 L .67986 .76239 L p .707 .577 .707 r
F P
0 g
s
.81489 .70752 m .81958 .7259 L .83578 .71725 L p .707 .577 .707 r
F P
0 g
s
.83578 .71725 m .8311 .69887 L .81489 .70752 L p .707 .577 .707 r
F P
0 g
s
.63525 .63466 m .63768 .5794 L .6348 .57022 L p .707 .577 .707 r
F P
0 g
s
.63422 .67089 m .63804 .70814 L .65051 .71368 L p .707 .577 .707 r
F P
0 g
s
.82715 .65519 m .83097 .69244 L .83808 .6846 L p .707 .577 .707 r
F P
0 g
s
.83808 .6846 m .83426 .64734 L .82715 .65519 L p .707 .577 .707 r
F P
0 g
s
.65973 .76323 m .65505 .74484 L .64319 .74275 L p .707 .577 .707 r
F P
0 g
s
.6348 .57022 m .63236 .62549 L .63525 .63466 L p .707 .577 .707 r
F P
0 g
s
.64319 .74275 m .64787 .76113 L .65973 .76323 L p .707 .577 .707 r
F P
0 g
s
.83851 .58234 m .83607 .63761 L .83319 .62843 L p .707 .577 .707 r
F P
0 g
s
.83319 .62843 m .83563 .57317 L .83851 .58234 L p .707 .577 .707 r
F P
0 g
s
.8311 .69887 m .83578 .71725 L .84303 .71017 L p .707 .577 .707 r
F P
0 g
s
.84303 .71017 m .83835 .69178 L .8311 .69887 L p .707 .577 .707 r
F P
0 g
s
.63804 .70814 m .63422 .67089 L .6314 .66385 L p .707 .577 .707 r
F P
0 g
s
.63236 .62549 m .6348 .57022 L .64188 .56164 L p .707 .577 .707 r
F P
0 g
s
.6314 .66385 m .63522 .7011 L .63804 .70814 L p .707 .577 .707 r
F P
0 g
s
.83426 .64734 m .83808 .6846 L .83526 .67756 L p .707 .577 .707 r
F P
0 g
s
.83526 .67756 m .83144 .64031 L .83426 .64734 L p .707 .577 .707 r
F P
0 g
s
.64787 .76113 m .64319 .74275 L .64076 .73792 L p .707 .577 .707 r
F P
0 g
s
.64076 .73792 m .64545 .75631 L .64787 .76113 L p .707 .577 .707 r
F P
0 g
s
.64188 .56164 m .63945 .6169 L .63236 .62549 L p .707 .577 .707 r
F P
0 g
s
.83563 .57317 m .83319 .62843 L .82062 .61956 L p .707 .577 .707 r
F P
0 g
s
.82062 .61956 m .82305 .5643 L .83563 .57317 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83835 .69178 m .84303 .71017 L .84061 .70534 L p .707 .577 .707 r
F P
0 g
s
.84061 .70534 m .83592 .68696 L .83835 .69178 L p .707 .577 .707 r
F P
0 g
s
.63522 .7011 m .6314 .66385 L .63851 .656 L p .707 .577 .707 r
F P
0 g
s
.3844 .61925 m .38684 .56399 L .3557 .56071 L p .707 .577 .707 r
F P
0 g
s
.38684 .56399 m .3844 .61925 L .41621 .61972 L p .707 .577 .707 r
F P
0 g
s
.41621 .61972 m .41865 .56446 L .38684 .56399 L p .707 .577 .707 r
F P
0 g
s
.63945 .6169 m .64188 .56164 L .65825 .55449 L p .707 .577 .707 r
F P
0 g
s
.41865 .56446 m .41621 .61972 L .44557 .61733 L p .707 .577 .707 r
F P
0 g
s
.44557 .61733 m .44801 .56206 L .41865 .56446 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35326 .61598 m .3557 .56071 L .32827 .55494 L p .707 .577 .707 r
F P
0 g
s
.3557 .56071 m .35326 .61598 L .3844 .61925 L p .707 .577 .707 r
F P
0 g
s
.63851 .656 m .64233 .69325 L .63522 .7011 L p .707 .577 .707 r
F P
0 g
s
.83144 .64031 m .83526 .67756 L .82279 .67202 L p .707 .577 .707 r
F P
0 g
s
.82279 .67202 m .81897 .63476 L .83144 .64031 L p .707 .577 .707 r
F P
0 g
s
.44801 .56206 m .44557 .61733 L .46961 .61231 L p .707 .577 .707 r
F P
0 g
s
.46961 .61231 m .47205 .55705 L .44801 .56206 L p .707 .577 .707 r
F P
0 g
s
.64545 .75631 m .64076 .73792 L .64801 .73084 L p .707 .577 .707 r
F P
0 g
s
.65825 .55449 m .65581 .60976 L .63945 .6169 L p .707 .577 .707 r
F P
0 g
s
.64801 .73084 m .65269 .74922 L .64545 .75631 L p .707 .577 .707 r
F P
0 g
s
.82305 .5643 m .82062 .61956 L .79959 .61186 L p .707 .577 .707 r
F P
0 g
s
.79959 .61186 m .80203 .5566 L .82305 .5643 L p .707 .577 .707 r
F P
0 g
s
.32583 .6102 m .32827 .55494 L .30724 .54724 L p .707 .577 .707 r
F P
0 g
s
.32827 .55494 m .32583 .6102 L .35326 .61598 L p .707 .577 .707 r
F P
0 g
s
.3867 .67439 m .38288 .63714 L .35187 .63851 L p .707 .577 .707 r
F P
0 g
s
.38288 .63714 m .3867 .67439 L .41838 .67067 L p .707 .577 .707 r
F P
0 g
s
.41838 .67067 m .41456 .63341 L .38288 .63714 L p .707 .577 .707 r
F P
0 g
s
.83592 .68696 m .84061 .70534 L .82875 .70325 L p .707 .577 .707 r
F P
0 g
s
.82875 .70325 m .82406 .68486 L .83592 .68696 L p .707 .577 .707 r
F P
0 g
s
.41456 .63341 m .41838 .67067 L .44764 .66494 L p .707 .577 .707 r
F P
0 g
s
.44764 .66494 m .44382 .62769 L .41456 .63341 L p .707 .577 .707 r
F P
0 g
s
.65581 .60976 m .65825 .55449 L .68229 .54948 L p .707 .577 .707 r
F P
0 g
s
.35569 .67577 m .35187 .63851 L .32458 .63739 L p .707 .577 .707 r
F P
0 g
s
.35187 .63851 m .35569 .67577 L .3867 .67439 L p .707 .577 .707 r
F P
0 g
s
.64233 .69325 m .63851 .656 L .65485 .64811 L p .707 .577 .707 r
F P
0 g
s
.44382 .62769 m .44764 .66494 L .47162 .65779 L p .707 .577 .707 r
F P
0 g
s
.47162 .65779 m .4678 .62054 L .44382 .62769 L p .707 .577 .707 r
F P
0 g
s
.39343 .71405 m .38875 .69567 L .3586 .70186 L p .707 .577 .707 r
F P
0 g
s
.38875 .69567 m .39343 .71405 L .42434 .70598 L p .707 .577 .707 r
F P
0 g
s
.42434 .70598 m .41966 .6876 L .38875 .69567 L p .707 .577 .707 r
F P
0 g
s
.47205 .55705 m .46961 .61231 L .48598 .60516 L p .707 .577 .707 r
F P
0 g
s
.48598 .60516 m .48841 .5499 L .47205 .55705 L p .707 .577 .707 r
F P
0 g
s
.41966 .6876 m .42434 .70598 L .45299 .69681 L p .707 .577 .707 r
F P
0 g
s
.45299 .69681 m .4483 .67843 L .41966 .6876 L p .707 .577 .707 r
F P
0 g
s
.30724 .54724 m .30481 .60251 L .32583 .6102 L p .707 .577 .707 r
F P
0 g
s
.32458 .63739 m .3284 .67464 L .35569 .67577 L p .707 .577 .707 r
F P
0 g
s
.65485 .64811 m .65867 .68537 L .64233 .69325 L p .707 .577 .707 r
F P
0 g
s
.3586 .70186 m .36328 .72024 L .39343 .71405 L p .707 .577 .707 r
F P
0 g
s
.81897 .63476 m .82279 .67202 L .80189 .66851 L p .707 .577 .707 r
F P
0 g
s
.80189 .66851 m .79806 .63126 L .81897 .63476 L p .707 .577 .707 r
F P
0 g
s
.80203 .5566 m .79959 .61186 L .77217 .60609 L p .707 .577 .707 r
F P
0 g
s
.77217 .60609 m .7746 .55083 L .80203 .5566 L p .707 .577 .707 r
F P
0 g
s
.36328 .72024 m .3586 .70186 L .33217 .70555 L p .707 .577 .707 r
F P
0 g
s
.30481 .60251 m .30724 .54724 L .29467 .53837 L p .707 .577 .707 r
F P
0 g
s
.68229 .54948 m .67985 .60474 L .65581 .60976 L p .707 .577 .707 r
F P
0 g
s
.3284 .67464 m .32458 .63739 L .30368 .63389 L p .707 .577 .707 r
F P
0 g
s
.65269 .74922 m .64801 .73084 L .66422 .72219 L p .707 .577 .707 r
F P
0 g
s
.33217 .70555 m .33685 .72393 L .36328 .72024 L p .707 .577 .707 r
F P
0 g
s
.4483 .67843 m .45299 .69681 L .47657 .68745 L p .707 .577 .707 r
F P
0 g
s
.47657 .68745 m .47189 .66907 L .4483 .67843 L p .707 .577 .707 r
F P
0 g
s
.67985 .60474 m .68229 .54948 L .71165 .54708 L p .707 .577 .707 r
F P
0 g
s
.66422 .72219 m .6689 .74057 L .65269 .74922 L p .707 .577 .707 r
F P
0 g
s
.82406 .68486 m .82875 .70325 L .80862 .70409 L p .707 .577 .707 r
F P
0 g
s
.80862 .70409 m .80393 .68571 L .82406 .68486 L p .707 .577 .707 r
F P
0 g
s
.30368 .63389 m .3075 .67114 L .3284 .67464 L p .707 .577 .707 r
F P
0 g
s
.4678 .62054 m .47162 .65779 L .48796 .64991 L p .707 .577 .707 r
F P
0 g
s
.48796 .64991 m .48414 .61265 L .4678 .62054 L p .707 .577 .707 r
F P
0 g
s
.65867 .68537 m .65485 .64811 L .67882 .64096 L p .707 .577 .707 r
F P
0 g
s
.7746 .55083 m .77217 .60609 L .74102 .60281 L p .707 .577 .707 r
F P
0 g
s
.74102 .60281 m .74346 .54755 L .7746 .55083 L p .707 .577 .707 r
F P
0 g
s
.29467 .53837 m .29223 .59364 L .30481 .60251 L p .707 .577 .707 r
F P
0 g
s
.70921 .60235 m .71165 .54708 L .74346 .54755 L p .707 .577 .707 r
F P
0 g
s
.71165 .54708 m .70921 .60235 L .67985 .60474 L p .707 .577 .707 r
F P
0 g
s
.33685 .72393 m .33217 .70555 L .31204 .70639 L p .707 .577 .707 r
F P
0 g
s
.48841 .5499 m .48598 .60516 L .49306 .59658 L p .707 .577 .707 r
F P
0 g
s
.49306 .59658 m .4955 .54132 L .48841 .5499 L p .707 .577 .707 r
F P
0 g
s
.74346 .54755 m .74102 .60281 L .70921 .60235 L p .707 .577 .707 r
F P
0 g
s
.67882 .64096 m .68265 .67821 L .65867 .68537 L p .707 .577 .707 r
F P
0 g
s
.79806 .63126 m .80189 .66851 L .7746 .66739 L p .707 .577 .707 r
F P
0 g
s
.7746 .66739 m .77078 .63014 L .79806 .63126 L p .707 .577 .707 r
F P
0 g
s
.31204 .70639 m .31672 .72478 L .33685 .72393 L p .707 .577 .707 r
F P
0 g
s
.47189 .66907 m .47657 .68745 L .49277 .6788 L p .707 .577 .707 r
F P
0 g
s
.49277 .6788 m .48809 .66042 L .47189 .66907 L p .707 .577 .707 r
F P
0 g
s
.3075 .67114 m .30368 .63389 L .29121 .62835 L p .707 .577 .707 r
F P
0 g
s
.29223 .59364 m .29467 .53837 L .29179 .5292 L p .707 .577 .707 r
F P
0 g
s
.6689 .74057 m .66422 .72219 L .6878 .71283 L p .707 .577 .707 r
F P
0 g
s
.68265 .67821 m .67882 .64096 L .70809 .63524 L p .707 .577 .707 r
F P
0 g
s
.6878 .71283 m .69248 .73121 L .6689 .74057 L p .707 .577 .707 r
F P
0 g
s
.80393 .68571 m .80862 .70409 L .78219 .70778 L p .707 .577 .707 r
F P
0 g
s
.78219 .70778 m .7775 .6894 L .80393 .68571 L p .707 .577 .707 r
F P
0 g
s
.29121 .62835 m .29503 .6656 L .3075 .67114 L p .707 .577 .707 r
F P
0 g
s
.48414 .61265 m .48796 .64991 L .49507 .64206 L p .707 .577 .707 r
F P
0 g
s
.49507 .64206 m .49125 .60481 L .48414 .61265 L p .707 .577 .707 r
F P
0 g
s
.77078 .63014 m .7746 .66739 L .74359 .66876 L p .707 .577 .707 r
F P
0 g
s
.74359 .66876 m .73977 .63151 L .77078 .63014 L p .707 .577 .707 r
F P
0 g
s
.70809 .63524 m .71191 .67249 L .68265 .67821 L p .707 .577 .707 r
F P
0 g
s
.31672 .72478 m .31204 .70639 L .30018 .7043 L p .707 .577 .707 r
F P
0 g
s
.71191 .67249 m .70809 .63524 L .73977 .63151 L p .707 .577 .707 r
F P
0 g
s
.29179 .5292 m .28935 .58446 L .29223 .59364 L p .707 .577 .707 r
F P
0 g
s
.73977 .63151 m .74359 .66876 L .71191 .67249 L p .707 .577 .707 r
F P
0 g
s
.30018 .7043 m .30486 .72268 L .31672 .72478 L p .707 .577 .707 r
F P
0 g
s
.69248 .73121 m .6878 .71283 L .71645 .70366 L p .707 .577 .707 r
F P
0 g
s
.4955 .54132 m .49306 .59658 L .49018 .5874 L p .707 .577 .707 r
F P
0 g
s
.49018 .5874 m .49262 .53214 L .4955 .54132 L p .707 .577 .707 r
F P
0 g
s
.48809 .66042 m .49277 .6788 L .50002 .67172 L p .707 .577 .707 r
F P
0 g
s
.50002 .67172 m .49534 .65333 L .48809 .66042 L p .707 .577 .707 r
F P
0 g
s
.71645 .70366 m .72113 .72204 L .69248 .73121 L p .707 .577 .707 r
F P
0 g
s
.7775 .6894 m .78219 .70778 L .75204 .71397 L p .707 .577 .707 r
F P
0 g
s
.75204 .71397 m .74736 .69559 L .7775 .6894 L p .707 .577 .707 r
F P
0 g
s
.29503 .6656 m .29121 .62835 L .28839 .62131 L p .707 .577 .707 r
F P
0 g
s
.72113 .72204 m .71645 .70366 L .74736 .69559 L p .707 .577 .707 r
F P
0 g
s
.28935 .58446 m .29179 .5292 L .29887 .52061 L p .707 .577 .707 r
F P
0 g
s
.74736 .69559 m .75204 .71397 L .72113 .72204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28839 .62131 m .29221 .65856 L .29503 .6656 L p .707 .577 .707 r
F P
0 g
s
.49125 .60481 m .49507 .64206 L .49225 .63502 L p .707 .577 .707 r
F P
0 g
s
.49225 .63502 m .48843 .59777 L .49125 .60481 L p .707 .577 .707 r
F P
0 g
s
.30486 .72268 m .30018 .7043 L .29775 .69947 L p .707 .577 .707 r
F P
0 g
s
.29887 .52061 m .29644 .57588 L .28935 .58446 L p .707 .577 .707 r
F P
0 g
s
.29775 .69947 m .30244 .71786 L .30486 .72268 L p .707 .577 .707 r
F P
0 g
s
.49262 .53214 m .49018 .5874 L .47761 .57853 L p .707 .577 .707 r
F P
0 g
s
.47761 .57853 m .48004 .52327 L .49262 .53214 L p .707 .577 .707 r
F P
0 g
s
.49534 .65333 m .50002 .67172 L .4976 .66689 L p .707 .577 .707 r
F P
0 g
s
.4976 .66689 m .49291 .64851 L .49534 .65333 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29221 .65856 m .28839 .62131 L .2955 .61346 L p .707 .577 .707 r
F P
0 g
s
.29644 .57588 m .29887 .52061 L .31524 .51346 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2955 .61346 m .29932 .65071 L .29221 .65856 L p .707 .577 .707 r
F P
0 g
s
.48843 .59777 m .49225 .63502 L .47978 .62948 L p .707 .577 .707 r
F P
0 g
s
.47978 .62948 m .47596 .59223 L .48843 .59777 L p .707 .577 .707 r
F P
0 g
s
.30244 .71786 m .29775 .69947 L .305 .69239 L p .707 .577 .707 r
F P
0 g
s
.31524 .51346 m .3128 .56873 L .29644 .57588 L p .707 .577 .707 r
F P
0 g
s
.48004 .52327 m .47761 .57853 L .45658 .57084 L p .707 .577 .707 r
F P
0 g
s
.45658 .57084 m .45902 .51557 L .48004 .52327 L p .707 .577 .707 r
F P
0 g
s
.305 .69239 m .30968 .71077 L .30244 .71786 L p .707 .577 .707 r
F P
0 g
s
.49291 .64851 m .4976 .66689 L .48574 .6648 L p .707 .577 .707 r
F P
0 g
s
.48574 .6648 m .48105 .64641 L .49291 .64851 L p .707 .577 .707 r
F P
0 g
s
.3128 .56873 m .31524 .51346 L .33928 .50845 L p .707 .577 .707 r
F P
0 g
s
.29932 .65071 m .2955 .61346 L .31184 .60558 L p .707 .577 .707 r
F P
0 g
s
.31184 .60558 m .31566 .64283 L .29932 .65071 L p .707 .577 .707 r
F P
0 g
s
.47596 .59223 m .47978 .62948 L .45887 .62598 L p .707 .577 .707 r
F P
0 g
s
.45887 .62598 m .45505 .58872 L .47596 .59223 L p .707 .577 .707 r
F P
0 g
s
.45902 .51557 m .45658 .57084 L .42915 .56506 L p .707 .577 .707 r
F P
0 g
s
.42915 .56506 m .43159 .5098 L .45902 .51557 L p .707 .577 .707 r
F P
0 g
s
.33928 .50845 m .33684 .56371 L .3128 .56873 L p .707 .577 .707 r
F P
0 g
s
.30968 .71077 m .305 .69239 L .32121 .68374 L p .707 .577 .707 r
F P
0 g
s
.33684 .56371 m .33928 .50845 L .36864 .50606 L p .707 .577 .707 r
F P
0 g
s
.32121 .68374 m .32589 .70212 L .30968 .71077 L p .707 .577 .707 r
F P
0 g
s
.48105 .64641 m .48574 .6648 L .46561 .66564 L p .707 .577 .707 r
F P
0 g
s
.46561 .66564 m .46092 .64725 L .48105 .64641 L p .707 .577 .707 r
F P
0 g
s
.31566 .64283 m .31184 .60558 L .33581 .59842 L p .707 .577 .707 r
F P
0 g
s
.43159 .5098 m .42915 .56506 L .39801 .56179 L p .707 .577 .707 r
F P
0 g
s
.39801 .56179 m .40045 .50652 L .43159 .5098 L p .707 .577 .707 r
F P
0 g
s
.3662 .56132 m .36864 .50606 L .40045 .50652 L p .707 .577 .707 r
F P
0 g
s
.36864 .50606 m .3662 .56132 L .33684 .56371 L p .707 .577 .707 r
F P
0 g
s
.33581 .59842 m .33963 .63568 L .31566 .64283 L p .707 .577 .707 r
F P
0 g
s
.40045 .50652 m .39801 .56179 L .3662 .56132 L p .707 .577 .707 r
F P
0 g
s
.45505 .58872 m .45887 .62598 L .43158 .62485 L p .707 .577 .707 r
F P
0 g
s
.43158 .62485 m .42776 .5876 L .45505 .58872 L p .707 .577 .707 r
F P
0 g
s
.32589 .70212 m .32121 .68374 L .34479 .67438 L p .707 .577 .707 r
F P
0 g
s
.33963 .63568 m .33581 .59842 L .36508 .5927 L p .707 .577 .707 r
F P
0 g
s
.34479 .67438 m .34947 .69276 L .32589 .70212 L p .707 .577 .707 r
F P
0 g
s
.46092 .64725 m .46561 .66564 L .43918 .66933 L p .707 .577 .707 r
F P
0 g
s
.43918 .66933 m .43449 .65095 L .46092 .64725 L p .707 .577 .707 r
F P
0 g
s
.42776 .5876 m .43158 .62485 L .40058 .62623 L p .707 .577 .707 r
F P
0 g
s
.40058 .62623 m .39676 .58897 L .42776 .5876 L p .707 .577 .707 r
F P
0 g
s
.36508 .5927 m .3689 .62995 L .33963 .63568 L p .707 .577 .707 r
F P
0 g
s
.3689 .62995 m .36508 .5927 L .39676 .58897 L p .707 .577 .707 r
F P
0 g
s
.39676 .58897 m .40058 .62623 L .3689 .62995 L p .707 .577 .707 r
F P
0 g
s
.34947 .69276 m .34479 .67438 L .37344 .66521 L p .707 .577 .707 r
F P
0 g
s
.37344 .66521 m .37812 .68359 L .34947 .69276 L p .707 .577 .707 r
F P
0 g
s
.43449 .65095 m .43918 .66933 L .40903 .67552 L p .707 .577 .707 r
F P
0 g
s
.40903 .67552 m .40435 .65713 L .43449 .65095 L p .707 .577 .707 r
F P
0 g
s
.37812 .68359 m .37344 .66521 L .40435 .65713 L p .707 .577 .707 r
F P
0 g
s
.40435 .65713 m .40903 .67552 L .37812 .68359 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo5@00Ogoo001mOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol007Eoo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Eoo`00LWoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000`00LGoo001^Ool40004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001^Ool006aoo`8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP<006aoo`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00JWoo001XOol20002
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006Ioo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo
001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol0
06=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001WOol006=oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1U
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001V
Ool006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`P00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Eoo`00Ggoo1P000eYF00<005YF
FUH00UYF2@000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00eYF0P00IGoo001KOol400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH600000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000>OolB0015Ool0059oo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Moo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPH003moo`00DWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo1@000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>goo001BOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000hOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002
000eOol0059oo`03001JEP0000=JEP04001JEUYFFUH800000eYF001JEP02FUHB0006FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF1P0015YF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP04001JEUYFFUH2
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00<Woo001BOol01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
1P0015YF00<005YFFUH01EYF100015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000031oo`00
DWoo00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002mo
o`00DWoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001B
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=J
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH30005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Woo001DOol00`00FUH00005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000hOolG0006Ool20005FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
;Woo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00D0
05YF001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Woo000_Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH00P00;goo
000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF1@0015YF00<005YFFUH00P00;goo000/Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000EJEP00001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF
0P00;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00:goo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEP00
00P000=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<002moo`00:goo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH00UYF200000=JEP0000000`001EYF10000UYF00<005YFFUH015YF1@0000=JEP00
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF5`0000=JEP00FUH00eYF0`00;goo000[Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000eYF00<005YFFUH00eYF20000eYF00@005YFFUIJEPX000IJEP03001JEUYF00AJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@0009JEP03001JEP0002moo`00:goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0001L0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH400000eYF
001oo`0^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`001EYF1@001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00<7oo000[
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEPL0009JEP03001JEP00
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ80
00AJEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
00080003FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002moo`00:goo00<0
05YF00000eYF00@005YFFUIJEPP00003FUH005YF009JEQ<0009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool002]oo`03001JEP0000=JEP@00003FUH005YF00IJ
EP03001JEUYF00EJEPH000AJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01P00FUH00000FUH000QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P00;goo000[Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF1P0015YF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo000[Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJ
EUYF0`001eYF00<005YFFUH01UYF00<005YFFUH00UYF3@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00:goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0UYF1@000eYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01EYF1P0015YF0P0015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000Ioo`P000=JEP04001JEUYF
FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP0000X000EJEP03001JEUYF00MJEP03001JEUYF00@000IJ
EP@00003FUH005YF00=JEP04001JEUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000goo000000030005
Ool400000eYF001JEP05FUH50002FUH2000^Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00MJEP03001JEUYF00AJEPD000=JEP04001JEUYFFUH30005FUH00`00FUIJEP03FUH20004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH70008Ool:0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000^Ool002]oo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEQX000=JEP03001JEUYF00IJEP03001JEUYF
00@000QJEP06001JEP00001JEP001eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP03001JEP0001H000=JEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<002ioo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEP0000D000AJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEPT0
00IJEP<000=JEP03001JEUYF00EJEP04001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPX00003FUH007oo02eoo`00;Goo00<005YF00001EYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<0
05YFFUH00UYF0`000eYF1@000UYF10001UYF00<005YFFUH015YF0`002UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00AJEP04001JEP00000_Ool0
02ioo`8000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEUYF1`000UYF00<005YFFUH01UYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050005FUH0
0`00FUIJEP03FUH00`00FUIJEP02000^Ool002moo`80009JEP@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00=JEP<0009oo`05001JEUYF001J
EP060005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000^Ool0035o
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001J
EUYF009JEP03001JEP0000<00003FUH00000009oo`D0009JEP03001JEUYF00MJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000_Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20002FUH00`00
FUH000050006FUH00`00FUIJEP07FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@00003
FUH0000002eoo`00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000UYF00@005YFFUIJEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEPD000]J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01eYF00@005YF
FUIJEPP0009JEP@002eoo`00:goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF100000=JEP00FUH025YF
00<005YFFUH015YF1P0017oo0P001EYF00<005YF0000;Goo000ZOol01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@000=JEP04001J
EUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP050005Ool400000eYF001JEP04FUH2000^Ool0
02Yoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH900000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF0000000500000eYF001JEP07FUH00`00FUIJEP04FUH50007Ool30005FUH00`00FUIJ
EP03FUH00`00Oomoo`0]Ool002Yoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90006Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP060008Ool20000
0eYF001JEP06FUH00`00FUIJEP02000`Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP0009oo`<000Ioo`@00003FUH00000009JEP03001JEUYF00T00005Ool005YFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH400000goo000000030005
Ool30004FUH00`00FUIJEP04FUH3000bOol002]oo`04001JEUYF0003FUH00`00FUIJEP03FUH60009
Ool:0006FUH600000eYF001JEP03FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP040005Ool500000goo000000020007FUH00`00FUIJ
EP04FUH00`00Oomoo`0bOol002]oo`04001JEUYF0003FUH00`00FUH0000G0002FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000goo001JEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH3000:Ool50002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000eOol002]oo`04001JEUYF0003FUH200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH0
07oo00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF009J
EP@000Qoo`@000MJEP03001JEUYF00IJEP04001JEP00000gOol002]oo`04001JEUYF0002FUH01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH0
15YF1`000goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0005FUH01000FUH0
00000eYF00<007ooOol00Woo100000=JEP00FUH025YF00<005YFFUH01EYF0`00>Goo000[Ool00`00
FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH7
0002FUH00`00FUH000020002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00EJEP800004FUH005YFFUH60006FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol002aoo`04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF
00<005YFFUH00eYF00@005YFFUH0009oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP080003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50010Ool002aoo`80009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000AGoo000/Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF
009JEP06001JEUYFFUH007oo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3000
35YF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50019Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00Ool0
0eYF00<005YFFUH00eYF00<005YFFUH01UYF20002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH010001UYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@0
04ioo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=00001GooFUIJEUYF00001EYF00<005YFFUH00eYF0`001UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUIJEP80
009JEP03001JEUYF00=JEP04001JEUYFFUH6001BOol002eoo`800003FUH005YF00AJEP03001JEUYF
00EJEP@00003FUH005YF00MJEP03001JEUYF00EJEPH000Aoo`8000AJEP04001JEP000003FUH00`00
FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH40004FUH200000eYF001JEP02FUH600000eYF0000001EOol002moo`@000=JEP04
001JEUYFFUH40005FUH00`00FUIJEP07FUH00`00FUIJEP040008Ool200000eYF001JEP03FUH01000
FUIJEP000eYF00<005YFFUH00eYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009JEP`0009JEP8005Eoo`00<goo
1`0000=JEP00FUH01eYF00<005YFFUH015YF1@002Woo0P000eYF00<005YFFUH00eYF0P0000EooeYF
FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000EJEP03001JEUYF009JEP@005Eoo`00=Woo0P00
0eYF00<005YFFUH01UYF00<005YFFUH0100037oo0`001UYF00@005YFFUIJEP80009oo`=JEP04001J
EP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP03FUH3001EOol003Aoo`8000EJEP03001J
EUYF00EJEPT000Moo`@00003FUH005YF00IJEP04001JEP000004Ool3FUH200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30006FUH600000eYF001oo`1DOol0039oo`<000MJEP03001JEUYF009JEP8000Ao
o`D0009oo`D000EJEP03001JEUYF00AJEP<000Ioo`9JEP05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH000070002FUH01000FUH00000EWoo000`Ool20002FUH00`00FUIJEP05FUH00`00FUH0
00020006Ool70002FUH00`00FUIJEP06FUH01000FUIJEUYF0P002Goo00=JEP00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000_
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH30007Ool60005FUH00`00FUIJEP06FUH01000FUH00000
2goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH0
0P00EGoo000^Ool20005FUH00`00FUH000030006Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH3000=Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH01000
FUIJEP00EGoo000]Ool01000FUIJEP0015YF0P0017oo1P001UYF00<005YFFUH01eYF00<005YFFUH0
10004Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH00eYF
00@005YFFUH005Eoo`00;Goo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP@001Eoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP02FUH>001D
Ool002eoo`04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000JOol20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUH00000FUH01P0017oo0P0015YF00@005YF000005Ao
o`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008001moo`<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEPL000Moo`800003FUH005YF00AJEP03001JEP0005Aoo`00;Woo0`0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH00UYF1@0097oo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF1@002Woo0P000eYF00<005YFFUH00eYF0P00
EGoo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH6000[Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00004000;Ool30006FUH0
1000FUIJEUYF0P00EWoo000_Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP04000eOol50008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH700000goo000000030006Ool400000eYF
001JEP06FUH01000FUH00000F7oo000aOol:000nOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04
FUH<00000eYF00000005Ool500000goo000000030006FUH00`00FUIJEP04FUH2001JOol007mooaH0
0003FUH005YF00EJEP03001JEP00008000Moo`H0009JEP03001JEUYF00IJEP03001JEUYF009JEP80
05aoo`00T7oo0P0015YF00<005YFFUH00eYF0`0027oo1P001EYF00<005YFFUH01UYF00@005YF0000
05ioo`00Sgoo00<005YF00001EYF00<005YF00000P001goo100000=JEP00FUH025YF00<005YFFUH0
1EYF0`00H7oo002?Ool00`00FUH00005FUH20004Ool60006FUH00`00FUIJEP07FUH00`00FUIJEP04
001SOol008moo`04001JEUYF0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4001WOol0
08moo`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<006]o
o`00T7oo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008006ioo`00
T7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P00LGoo002@Ool20002FUH0
0`00FUIJEP03FUH01000FUIJEUYF2000Mgoo002AOol200000eYF001JEP02FUH6001oOol009=oo`D0
08Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]21\[InvisibleSpace]"     "\
\[InvisibleSpace]6.548198516685221`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 21, "     ", 6.548198516685221, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60673 .75076 m .60451 .6955 L .57301 .69515 L p .707 .577 .707 r
F P
0 g
s
.60451 .6955 m .60673 .75076 L .63833 .74825 L p .707 .577 .707 r
F P
0 g
s
.63833 .74825 m .6361 .69299 L .60451 .6955 L p .707 .577 .707 r
F P
0 g
s
.6361 .69299 m .63833 .74825 L .66692 .74312 L p .707 .577 .707 r
F P
0 g
s
.66692 .74312 m .6647 .68787 L .6361 .69299 L p .707 .577 .707 r
F P
0 g
s
.57523 .75041 m .57301 .69515 L .54468 .69198 L p .707 .577 .707 r
F P
0 g
s
.57301 .69515 m .57523 .75041 L .60673 .75076 L p .707 .577 .707 r
F P
0 g
s
.6647 .68787 m .66692 .74312 L .68972 .73589 L p .707 .577 .707 r
F P
0 g
s
.68972 .73589 m .6875 .68063 L .6647 .68787 L p .707 .577 .707 r
F P
0 g
s
.54691 .74724 m .54468 .69198 L .52231 .6863 L p .707 .577 .707 r
F P
0 g
s
.54468 .69198 m .54691 .74724 L .57523 .75041 L p .707 .577 .707 r
F P
0 g
s
.61066 .80619 m .61352 .76888 L .58183 .76576 L p .707 .577 .707 r
F P
0 g
s
.61352 .76888 m .61066 .80619 L .64188 .80695 L p .707 .577 .707 r
F P
0 g
s
.64188 .80695 m .64474 .76964 L .61352 .76888 L p .707 .577 .707 r
F P
0 g
s
.57898 .80307 m .58183 .76576 L .55279 .76059 L p .707 .577 .707 r
F P
0 g
s
.58183 .76576 m .57898 .80307 L .61066 .80619 L p .707 .577 .707 r
F P
0 g
s
.64474 .76964 m .64188 .80695 L .66959 .80528 L p .707 .577 .707 r
F P
0 g
s
.66959 .80528 m .67245 .76797 L .64474 .76964 L p .707 .577 .707 r
F P
0 g
s
.55279 .76059 m .54993 .7979 L .57898 .80307 L p .707 .577 .707 r
F P
0 g
s
.60667 .84323 m .61041 .82464 L .57918 .81806 L p .707 .577 .707 r
F P
0 g
s
.61041 .82464 m .60667 .84323 L .63724 .84798 L p .707 .577 .707 r
F P
0 g
s
.63724 .84798 m .64097 .82939 L .61041 .82464 L p .707 .577 .707 r
F P
0 g
s
.52231 .6863 m .52453 .74155 L .54691 .74724 L p .707 .577 .707 r
F P
0 g
s
.54993 .7979 m .55279 .76059 L .52924 .75387 L p .707 .577 .707 r
F P
0 g
s
.57544 .83665 m .57918 .81806 L .55033 .81029 L p .707 .577 .707 r
F P
0 g
s
.57918 .81806 m .57544 .83665 L .60667 .84323 L p .707 .577 .707 r
F P
0 g
s
.6875 .68063 m .68972 .73589 L .70449 .72725 L p .707 .577 .707 r
F P
0 g
s
.70449 .72725 m .70227 .67199 L .6875 .68063 L p .707 .577 .707 r
F P
0 g
s
.55033 .81029 m .5466 .82888 L .57544 .83665 L p .707 .577 .707 r
F P
0 g
s
.52453 .74155 m .52231 .6863 L .50807 .67865 L p .707 .577 .707 r
F P
0 g
s
.64097 .82939 m .63724 .84798 L .66415 .85043 L p .707 .577 .707 r
F P
0 g
s
.66415 .85043 m .66788 .83185 L .64097 .82939 L p .707 .577 .707 r
F P
0 g
s
.67245 .76797 m .66959 .80528 L .69106 .80135 L p .707 .577 .707 r
F P
0 g
s
.69106 .80135 m .69392 .76404 L .67245 .76797 L p .707 .577 .707 r
F P
0 g
s
.52924 .75387 m .52638 .79118 L .54993 .7979 L p .707 .577 .707 r
F P
0 g
s
.5466 .82888 m .55033 .81029 L .52671 .80209 L p .707 .577 .707 r
F P
0 g
s
.52671 .80209 m .52297 .82068 L .5466 .82888 L p .707 .577 .707 r
F P
0 g
s
.52638 .79118 m .52924 .75387 L .51347 .74627 L p .707 .577 .707 r
F P
0 g
s
.50807 .67865 m .5103 .73391 L .52453 .74155 L p .707 .577 .707 r
F P
0 g
s
.66788 .83185 m .66415 .85043 L .68476 .85035 L p .707 .577 .707 r
F P
0 g
s
.68476 .85035 m .6885 .83176 L .66788 .83185 L p .707 .577 .707 r
F P
0 g
s
.70227 .67199 m .70449 .72725 L .70978 .71805 L p .707 .577 .707 r
F P
0 g
s
.70978 .71805 m .70756 .6628 L .70227 .67199 L p .707 .577 .707 r
F P
0 g
s
.51347 .74627 m .51061 .78358 L .52638 .79118 L p .707 .577 .707 r
F P
0 g
s
.69392 .76404 m .69106 .80135 L .70421 .79553 L p .707 .577 .707 r
F P
0 g
s
.70421 .79553 m .70707 .75822 L .69392 .76404 L p .707 .577 .707 r
F P
0 g
s
.52297 .82068 m .52671 .80209 L .51061 .79426 L p .707 .577 .707 r
F P
0 g
s
.5103 .73391 m .50807 .67865 L .50337 .6698 L p .707 .577 .707 r
F P
0 g
s
.51061 .79426 m .50687 .81285 L .52297 .82068 L p .707 .577 .707 r
F P
0 g
s
.51061 .78358 m .51347 .74627 L .50704 .73852 L p .707 .577 .707 r
F P
0 g
s
.6885 .83176 m .68476 .85035 L .69707 .84773 L p .707 .577 .707 r
F P
0 g
s
.69707 .84773 m .70081 .82914 L .6885 .83176 L p .707 .577 .707 r
F P
0 g
s
.50722 .72812 m .5103 .73391 L p .50769 .70979 L .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .50418 .77583 L .51061 .78358 L p .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .51056 .73139 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50418 .77583 m .50692 .74004 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50692 .74004 m .50704 .73852 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50337 .6698 m .5056 .72506 L .50722 .72812 L p .707 .577 .707 r
F P
0 g
s
.50769 .70979 m .50337 .6698 L .50722 .72812 L .707 .577 .707 r
F
.50687 .81285 m .51061 .79426 L .50361 .78758 L p F P
0 g
s
.70756 .6628 m .70978 .71805 L .70508 .7092 L p .707 .577 .707 r
F P
0 g
s
.70508 .7092 m .70286 .65394 L .70756 .6628 L p .707 .577 .707 r
F P
0 g
s
.70707 .75822 m .70421 .79553 L .70774 .7884 L p .707 .577 .707 r
F P
0 g
s
.70774 .7884 m .7106 .75109 L .70707 .75822 L p .707 .577 .707 r
F P
0 g
s
.50361 .78758 m .49987 .80617 L .50687 .81285 L p .707 .577 .707 r
F P
0 g
s
.5056 .72506 m .50337 .6698 L .50867 .66061 L p .707 .577 .707 r
F P
0 g
s
.48352 .82167 m .48352 .31978 L .44005 .31653 L p .707 .577 .707 r
F P
0 g
s
.50867 .66061 m .51089 .71586 L .5056 .72506 L p .707 .577 .707 r
F P
0 g
s
.51056 .73139 m .50771 .7687 L .50418 .77583 L p .707 .577 .707 r
F P
0 g
s
.49987 .80617 m .50361 .78758 L .5064 .78269 L p .707 .577 .707 r
F P
0 g
s
.5064 .78269 m .50266 .80127 L .49987 .80617 L p .707 .577 .707 r
F P
0 g
s
.51089 .71586 m .50867 .66061 L .52343 .65197 L p .707 .577 .707 r
F P
0 g
s
.50771 .7687 m .51056 .73139 L .52371 .72557 L p .707 .577 .707 r
F P
0 g
s
.52343 .65197 m .52566 .70722 L .51089 .71586 L p .707 .577 .707 r
F P
0 g
s
.52371 .72557 m .52085 .76288 L .50771 .7687 L p .707 .577 .707 r
F P
0 g
s
.50266 .80127 m .5064 .78269 L .5187 .78007 L p .707 .577 .707 r
F P
0 g
s
.5187 .78007 m .51497 .79866 L .50266 .80127 L p .707 .577 .707 r
F P
0 g
s
.52085 .76288 m .52371 .72557 L .54519 .72164 L p .707 .577 .707 r
F P
0 g
s
.54519 .72164 m .54233 .75894 L .52085 .76288 L p .707 .577 .707 r
F P
0 g
s
.51497 .79866 m .5187 .78007 L .53932 .77998 L p .707 .577 .707 r
F P
0 g
s
.53932 .77998 m .53558 .79857 L .51497 .79866 L p .707 .577 .707 r
F P
0 g
s
.48352 .31978 m .48352 .82167 L .52861 .82115 L p .707 .577 .707 r
F P
0 g
s
.52566 .70722 m .52343 .65197 L .54623 .64473 L p .707 .577 .707 r
F P
0 g
s
.54623 .64473 m .54846 .69999 L .52566 .70722 L p .707 .577 .707 r
F P
0 g
s
.52861 .82115 m .52861 .31927 L .48352 .31978 L p .707 .577 .707 r
F P
0 g
s
.54846 .69999 m .54623 .64473 L .57483 .63961 L p .707 .577 .707 r
F P
0 g
s
.57483 .63961 m .57705 .69486 L .54846 .69999 L p .707 .577 .707 r
F P
0 g
s
.54233 .75894 m .54519 .72164 L .5729 .71997 L p .707 .577 .707 r
F P
0 g
s
.5729 .71997 m .57004 .75728 L .54233 .75894 L p .707 .577 .707 r
F P
0 g
s
.53558 .79857 m .53932 .77998 L .56623 .78243 L p .707 .577 .707 r
F P
0 g
s
.56623 .78243 m .56249 .80102 L .53558 .79857 L p .707 .577 .707 r
F P
0 g
s
.56249 .80102 m .56623 .78243 L .5968 .78718 L p .707 .577 .707 r
F P
0 g
s
.5968 .78718 m .59306 .80577 L .56249 .80102 L p .707 .577 .707 r
F P
0 g
s
.52861 .31927 m .52861 .82115 L .5709 .81692 L p .707 .577 .707 r
F P
0 g
s
.57004 .75728 m .5729 .71997 L .60412 .72073 L p .707 .577 .707 r
F P
0 g
s
.60412 .72073 m .60126 .75804 L .57004 .75728 L p .707 .577 .707 r
F P
0 g
s
.5709 .81692 m .5709 .31504 L .52861 .31927 L p .707 .577 .707 r
F P
0 g
s
.44005 .81842 m .44005 .31653 L .40244 .30984 L p .707 .577 .707 r
F P
0 g
s
.44005 .31653 m .44005 .81842 L .48352 .82167 L p .707 .577 .707 r
F P
0 g
s
.70081 .82914 m .69707 .84773 L .69986 .84284 L p .707 .577 .707 r
F P
0 g
s
.69986 .84284 m .7036 .82425 L .70081 .82914 L p .707 .577 .707 r
F P
0 g
s
.57705 .69486 m .57483 .63961 L .60642 .6371 L p .707 .577 .707 r
F P
0 g
s
.60642 .6371 m .60865 .69235 L .57705 .69486 L p .707 .577 .707 r
F P
0 g
s
.6358 .72385 m .63294 .76116 L .60126 .75804 L p .707 .577 .707 r
F P
0 g
s
.60126 .75804 m .60412 .72073 L .6358 .72385 L p .707 .577 .707 r
F P
0 g
s
.62803 .79377 m .62429 .81235 L .59306 .80577 L p .707 .577 .707 r
F P
0 g
s
.59306 .80577 m .5968 .78718 L .62803 .79377 L p .707 .577 .707 r
F P
0 g
s
.5709 .31504 m .5709 .81692 L .60625 .8094 L p .707 .577 .707 r
F P
0 g
s
.60625 .8094 m .60625 .30751 L .5709 .31504 L p .707 .577 .707 r
F P
0 g
s
.70286 .65394 m .70508 .7092 L .69085 .70156 L p .707 .577 .707 r
F P
0 g
s
.69085 .70156 m .68862 .6463 L .70286 .65394 L p .707 .577 .707 r
F P
0 g
s
.26102 .7104 m .26004 .6543 L .22852 .65358 L p .707 .577 .707 r
F P
0 g
s
.26004 .6543 m .26102 .7104 L .29263 .70878 L p .707 .577 .707 r
F P
0 g
s
.29263 .70878 m .29166 .65268 L .26004 .6543 L p .707 .577 .707 r
F P
0 g
s
.7106 .75109 m .70774 .7884 L .70131 .78065 L p .707 .577 .707 r
F P
0 g
s
.70131 .78065 m .70417 .74334 L .7106 .75109 L p .707 .577 .707 r
F P
0 g
s
.29166 .65268 m .29263 .70878 L .32124 .70499 L p .707 .577 .707 r
F P
0 g
s
.32124 .70499 m .32027 .64889 L .29166 .65268 L p .707 .577 .707 r
F P
0 g
s
.2295 .70968 m .22852 .65358 L .20018 .6506 L p .707 .577 .707 r
F P
0 g
s
.22852 .65358 m .2295 .70968 L .26102 .7104 L p .707 .577 .707 r
F P
0 g
s
.40244 .81173 m .40244 .30984 L .37438 .30035 L p .707 .577 .707 r
F P
0 g
s
.40244 .30984 m .40244 .81173 L .44005 .81842 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63792 .63744 m .64015 .6927 L .60865 .69235 L p .707 .577 .707 r
F P
0 g
s
.60865 .69235 m .60642 .6371 L .63792 .63744 L p .707 .577 .707 r
F P
0 g
s
.62429 .81235 m .62803 .79377 L .65687 .80154 L p .707 .577 .707 r
F P
0 g
s
.60625 .30751 m .60625 .8094 L .63119 .79931 L p .707 .577 .707 r
F P
0 g
s
.63119 .79931 m .63119 .29742 L .60625 .30751 L p .707 .577 .707 r
F P
0 g
s
.32027 .64889 m .32124 .70499 L .34405 .6994 L p .707 .577 .707 r
F P
0 g
s
.34405 .6994 m .34308 .6433 L .32027 .64889 L p .707 .577 .707 r
F P
0 g
s
.20018 .6506 m .20115 .7067 L .2295 .70968 L p .707 .577 .707 r
F P
0 g
s
.7036 .82425 m .69986 .84284 L .69286 .83615 L p .707 .577 .707 r
F P
0 g
s
.69286 .83615 m .6966 .81756 L .7036 .82425 L p .707 .577 .707 r
F P
0 g
s
.20115 .7067 m .20018 .6506 L .17779 .64565 L p .707 .577 .707 r
F P
0 g
s
.26595 .7805 m .26722 .74423 L .23547 .74207 L p .707 .577 .707 r
F P
0 g
s
.26722 .74423 m .26595 .7805 L .29724 .77933 L p .707 .577 .707 r
F P
0 g
s
.29724 .77933 m .29851 .74306 L .26722 .74423 L p .707 .577 .707 r
F P
0 g
s
.2342 .77834 m .23547 .74207 L .20635 .7368 L p .707 .577 .707 r
F P
0 g
s
.23547 .74207 m .2342 .77834 L .26595 .7805 L p .707 .577 .707 r
F P
0 g
s
.68862 .6463 m .69085 .70156 L .66847 .69587 L p .707 .577 .707 r
F P
0 g
s
.66847 .69587 m .66625 .64061 L .68862 .6463 L p .707 .577 .707 r
F P
0 g
s
.29851 .74306 m .29724 .77933 L .325 .77495 L p .707 .577 .707 r
F P
0 g
s
.325 .77495 m .32627 .73868 L .29851 .74306 L p .707 .577 .707 r
F P
0 g
s
.70417 .74334 m .70131 .78065 L .68554 .77305 L p .707 .577 .707 r
F P
0 g
s
.68554 .77305 m .6884 .73574 L .70417 .74334 L p .707 .577 .707 r
F P
0 g
s
.17779 .64565 m .17876 .70175 L .20115 .7067 L p .707 .577 .707 r
F P
0 g
s
.20508 .77307 m .20635 .7368 L .18273 .72892 L p .707 .577 .707 r
F P
0 g
s
.20635 .7368 m .20508 .77307 L .2342 .77834 L p .707 .577 .707 r
F P
0 g
s
.34308 .6433 m .34405 .6994 L .35882 .69255 L p .707 .577 .707 r
F P
0 g
s
.35882 .69255 m .35785 .63645 L .34308 .6433 L p .707 .577 .707 r
F P
0 g
s
.17876 .70175 m .17779 .64565 L .16354 .63922 L p .707 .577 .707 r
F P
0 g
s
.37438 .80224 m .37438 .30035 L .35862 .28901 L p .707 .577 .707 r
F P
0 g
s
.37438 .30035 m .37438 .80224 L .40244 .81173 L p .707 .577 .707 r
F P
0 g
s
.32627 .73868 m .325 .77495 L .34651 .76778 L p .707 .577 .707 r
F P
0 g
s
.34651 .76778 m .34778 .73151 L .32627 .73868 L p .707 .577 .707 r
F P
0 g
s
.26585 .83079 m .26754 .81348 L .23581 .80979 L p .707 .577 .707 r
F P
0 g
s
.26754 .81348 m .26585 .83079 L .29687 .83015 L p .707 .577 .707 r
F P
0 g
s
.29687 .83015 m .29855 .81283 L .26754 .81348 L p .707 .577 .707 r
F P
0 g
s
.66625 .64061 m .66847 .69587 L .64015 .6927 L p .707 .577 .707 r
F P
0 g
s
.64015 .6927 m .63792 .63744 L .66625 .64061 L p .707 .577 .707 r
F P
0 g
s
.6966 .81756 m .69286 .83615 L .67676 .82833 L p .707 .577 .707 r
F P
0 g
s
.67676 .82833 m .6805 .80974 L .6966 .81756 L p .707 .577 .707 r
F P
0 g
s
.23412 .82711 m .23581 .80979 L .20647 .80214 L p .707 .577 .707 r
F P
0 g
s
.23581 .80979 m .23412 .82711 L .26585 .83079 L p .707 .577 .707 r
F P
0 g
s
.18273 .72892 m .18146 .76519 L .20508 .77307 L p .707 .577 .707 r
F P
0 g
s
.66484 .72902 m .66198 .76633 L .63294 .76116 L p .707 .577 .707 r
F P
0 g
s
.63294 .76116 m .6358 .72385 L .66484 .72902 L p .707 .577 .707 r
F P
0 g
s
.63119 .29742 m .63119 .79931 L .6433 .78764 L p .707 .577 .707 r
F P
0 g
s
.6433 .78764 m .6433 .28575 L .63119 .29742 L p .707 .577 .707 r
F P
0 g
s
.16354 .63922 m .16451 .69532 L .17876 .70175 L p .707 .577 .707 r
F P
0 g
s
.29855 .81283 m .29687 .83015 L .32413 .82525 L p .707 .577 .707 r
F P
0 g
s
.32413 .82525 m .32581 .80793 L .29855 .81283 L p .707 .577 .707 r
F P
0 g
s
.18146 .76519 m .18273 .72892 L .16691 .71922 L p .707 .577 .707 r
F P
0 g
s
.6884 .73574 m .68554 .77305 L .66198 .76633 L p .707 .577 .707 r
F P
0 g
s
.66198 .76633 m .66484 .72902 L .6884 .73574 L p .707 .577 .707 r
F P
0 g
s
.20647 .80214 m .20479 .81946 L .23412 .82711 L p .707 .577 .707 r
F P
0 g
s
.20479 .81946 m .20647 .80214 L .18239 .79128 L p .707 .577 .707 r
F P
0 g
s
.34778 .73151 m .34651 .76778 L .35967 .75852 L p .707 .577 .707 r
F P
0 g
s
.35967 .75852 m .36094 .72226 L .34778 .73151 L p .707 .577 .707 r
F P
0 g
s
.35785 .63645 m .35882 .69255 L .36411 .68511 L p .707 .577 .707 r
F P
0 g
s
.36411 .68511 m .36314 .62901 L .35785 .63645 L p .707 .577 .707 r
F P
0 g
s
.18239 .79128 m .18071 .80859 L .20479 .81946 L p .707 .577 .707 r
F P
0 g
s
.16451 .69532 m .16354 .63922 L .15883 .63193 L p .707 .577 .707 r
F P
0 g
s
.16691 .71922 m .16564 .75549 L .18146 .76519 L p .707 .577 .707 r
F P
0 g
s
.32581 .80793 m .32413 .82525 L .34497 .81656 L p .707 .577 .707 r
F P
0 g
s
.34497 .81656 m .34666 .79924 L .32581 .80793 L p .707 .577 .707 r
F P
0 g
s
.6805 .80974 m .67676 .82833 L .65313 .82013 L p .707 .577 .707 r
F P
0 g
s
.65313 .82013 m .65687 .80154 L .6805 .80974 L p .707 .577 .707 r
F P
0 g
s
.18071 .80859 m .18239 .79128 L .16594 .77826 L p .707 .577 .707 r
F P
0 g
s
.16564 .75549 m .16691 .71922 L .16044 .70863 L p .707 .577 .707 r
F P
0 g
s
.15883 .63193 m .1598 .68803 L .16451 .69532 L p .707 .577 .707 r
F P
0 g
s
.35736 .80494 m .35904 .78763 L .34666 .79924 L p .707 .577 .707 r
F P
0 g
s
.3594 .67782 m .35843 .62172 L .36314 .62901 L p .707 .577 .707 r
F P
0 g
s
.36094 .72226 m .35967 .75852 L .36319 .7481 L p .707 .577 .707 r
F P
0 g
s
.36319 .7481 m .36446 .71183 L .36094 .72226 L p .707 .577 .707 r
F P
0 g
s
.36446 .71183 m .36319 .7481 L .35672 .73751 L p .707 .577 .707 r
F P
0 g
s
.35672 .73751 m .35799 .70124 L .36446 .71183 L p .707 .577 .707 r
F P
0 g
s
.35843 .62172 m .3594 .67782 L .34515 .67139 L p .707 .577 .707 r
F P
0 g
s
.34515 .67139 m .34418 .61529 L .35843 .62172 L p .707 .577 .707 r
F P
0 g
s
.35904 .78763 m .35736 .80494 L .36007 .79153 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .36175 .77421 L .35904 .78763 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .35284 .77763 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.36175 .77421 m .3614 .77779 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.3614 .77779 m .36007 .79153 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .3567 .27691 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .35453 .76032 L .36136 .77346 L p .707 .577 .707 r
F P
0 g
s
.36136 .77346 m .36175 .77421 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .36136 .77346 L .36137 .77436 L .707 .577 .707 r
F
.35799 .70124 m .35672 .73751 L .3409 .7278 L p F P
0 g
s
.3409 .7278 m .34217 .69154 L .35799 .70124 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .35862 .7909 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .27691 m .3567 .28823 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .28823 m .3567 .7788 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .7909 m .35862 .48812 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .48812 m .35862 .28901 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.36314 .62901 m .36411 .68511 L .3594 .67782 L p .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .35862 .7909 L .37438 .80224 L p .707 .577 .707 r
F P
0 g
s
.16594 .77826 m .16426 .79557 L .18071 .80859 L p .707 .577 .707 r
F P
0 g
s
.34666 .79924 m .34497 .81656 L .35736 .80494 L p .707 .577 .707 r
F P
0 g
s
.6433 .28575 m .6433 .78764 L .64138 .77554 L p .707 .577 .707 r
F P
0 g
s
.64138 .77554 m .64138 .27365 L .6433 .28575 L p .707 .577 .707 r
F P
0 g
s
.16044 .70863 m .15917 .7449 L .16564 .75549 L p .707 .577 .707 r
F P
0 g
s
.65687 .80154 m .65313 .82013 L .62429 .81235 L p .707 .577 .707 r
F P
0 g
s
.1598 .68803 m .15883 .63193 L .16412 .62449 L p .707 .577 .707 r
F P
0 g
s
.16426 .79557 m .16594 .77826 L .15871 .76436 L p .707 .577 .707 r
F P
0 g
s
.15871 .76436 m .15703 .78168 L .16426 .79557 L p .707 .577 .707 r
F P
0 g
s
.15917 .7449 m .16044 .70863 L .16396 .6982 L p .707 .577 .707 r
F P
0 g
s
.16412 .62449 m .16509 .68059 L .1598 .68803 L p .707 .577 .707 r
F P
0 g
s
.16396 .6982 m .16269 .73447 L .15917 .7449 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .3567 .27691 L .3688 .26524 L p .707 .577 .707 r
F P
0 g
s
.15703 .78168 m .15871 .76436 L .16143 .75095 L p .707 .577 .707 r
F P
0 g
s
.16509 .68059 m .16412 .62449 L .17889 .61764 L p .707 .577 .707 r
F P
0 g
s
.16143 .75095 m .15974 .76826 L .15703 .78168 L p .707 .577 .707 r
F P
0 g
s
.64138 .27365 m .64138 .77554 L .62562 .76419 L p .707 .577 .707 r
F P
0 g
s
.62562 .76419 m .62562 .2623 L .64138 .27365 L p .707 .577 .707 r
F P
0 g
s
.16269 .73447 m .16396 .6982 L .17712 .68895 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17889 .61764 m .17986 .67374 L .16509 .68059 L p .707 .577 .707 r
F P
0 g
s
.17712 .68895 m .17585 .72522 L .16269 .73447 L p .707 .577 .707 r
F P
0 g
s
.34418 .61529 m .34515 .67139 L .32276 .66644 L p .707 .577 .707 r
F P
0 g
s
.32276 .66644 m .32178 .61034 L .34418 .61529 L p .707 .577 .707 r
F P
0 g
s
.15974 .76826 m .16143 .75095 L .17381 .73933 L p .707 .577 .707 r
F P
0 g
s
.17986 .67374 m .17889 .61764 L .20169 .61205 L p .707 .577 .707 r
F P
0 g
s
.17381 .73933 m .17213 .75664 L .15974 .76826 L p .707 .577 .707 r
F P
0 g
s
.3688 .76713 m .3688 .26524 L .39375 .25515 L p .707 .577 .707 r
F P
0 g
s
.3688 .26524 m .3688 .76713 L .3567 .7788 L p .707 .577 .707 r
F P
0 g
s
.17585 .72522 m .17712 .68895 L .19863 .68178 L p .707 .577 .707 r
F P
0 g
s
.20169 .61205 m .20267 .66815 L .17986 .67374 L p .707 .577 .707 r
F P
0 g
s
.35453 .76032 m .35284 .77763 L .33639 .76461 L p .707 .577 .707 r
F P
0 g
s
.33639 .76461 m .33807 .7473 L .35453 .76032 L p .707 .577 .707 r
F P
0 g
s
.32178 .61034 m .32276 .66644 L .29441 .66346 L p .707 .577 .707 r
F P
0 g
s
.29441 .66346 m .29344 .60736 L .32178 .61034 L p .707 .577 .707 r
F P
0 g
s
.34217 .69154 m .3409 .7278 L .31728 .71993 L p .707 .577 .707 r
F P
0 g
s
.31728 .71993 m .31855 .68366 L .34217 .69154 L p .707 .577 .707 r
F P
0 g
s
.62562 .2623 m .62562 .76419 L .59756 .75471 L p .707 .577 .707 r
F P
0 g
s
.59756 .75471 m .59756 .25282 L .62562 .2623 L p .707 .577 .707 r
F P
0 g
s
.20267 .66815 m .20169 .61205 L .23031 .60826 L p .707 .577 .707 r
F P
0 g
s
.19863 .68178 m .19736 .71805 L .17585 .72522 L p .707 .577 .707 r
F P
0 g
s
.17213 .75664 m .17381 .73933 L .19465 .73064 L p .707 .577 .707 r
F P
0 g
s
.19736 .71805 m .19863 .68178 L .22639 .6774 L p .707 .577 .707 r
F P
0 g
s
.29344 .60736 m .29441 .66346 L .26289 .66274 L p .707 .577 .707 r
F P
0 g
s
.26289 .66274 m .26192 .60664 L .29344 .60736 L p .707 .577 .707 r
F P
0 g
s
.23031 .60826 m .23128 .66436 L .20267 .66815 L p .707 .577 .707 r
F P
0 g
s
.19465 .73064 m .19297 .74796 L .17213 .75664 L p .707 .577 .707 r
F P
0 g
s
.23128 .66436 m .23031 .60826 L .26192 .60664 L p .707 .577 .707 r
F P
0 g
s
.26192 .60664 m .26289 .66274 L .23128 .66436 L p .707 .577 .707 r
F P
0 g
s
.31855 .68366 m .31728 .71993 L .28816 .71465 L p .707 .577 .707 r
F P
0 g
s
.28816 .71465 m .28943 .67839 L .31855 .68366 L p .707 .577 .707 r
F P
0 g
s
.33807 .7473 m .33639 .76461 L .31231 .75375 L p .707 .577 .707 r
F P
0 g
s
.31231 .75375 m .314 .73643 L .33807 .7473 L p .707 .577 .707 r
F P
0 g
s
.73711 .65978 m .73808 .6048 L .70656 .60269 L p .707 .577 .707 r
F P
0 g
s
.73808 .6048 m .73711 .65978 L .76872 .65886 L p .707 .577 .707 r
F P
0 g
s
.76872 .65886 m .76969 .60388 L .73808 .6048 L p .707 .577 .707 r
F P
0 g
s
.22639 .6774 m .22512 .71367 L .19736 .71805 L p .707 .577 .707 r
F P
0 g
s
.39375 .25515 m .39375 .75704 L .3688 .76713 L p .707 .577 .707 r
F P
0 g
s
.39375 .75704 m .39375 .25515 L .4291 .24762 L p .707 .577 .707 r
F P
0 g
s
.22512 .71367 m .22639 .6774 L .25768 .67623 L p .707 .577 .707 r
F P
0 g
s
.19297 .74796 m .19465 .73064 L .22192 .72574 L p .707 .577 .707 r
F P
0 g
s
.76969 .60388 m .76872 .65886 L .79733 .655 L p .707 .577 .707 r
F P
0 g
s
.79733 .655 m .7983 .60002 L .76969 .60388 L p .707 .577 .707 r
F P
0 g
s
.70558 .65767 m .70656 .60269 L .67821 .59776 L p .707 .577 .707 r
F P
0 g
s
.70656 .60269 m .70558 .65767 L .73711 .65978 L p .707 .577 .707 r
F P
0 g
s
.28943 .67839 m .28816 .71465 L .25641 .7125 L p .707 .577 .707 r
F P
0 g
s
.25641 .7125 m .25768 .67623 L .28943 .67839 L p .707 .577 .707 r
F P
0 g
s
.59756 .25282 m .59756 .75471 L .55995 .74802 L p .707 .577 .707 r
F P
0 g
s
.55995 .74802 m .55995 .24613 L .59756 .25282 L p .707 .577 .707 r
F P
0 g
s
.25768 .67623 m .25641 .7125 L .22512 .71367 L p .707 .577 .707 r
F P
0 g
s
.22192 .72574 m .22023 .74305 L .19297 .74796 L p .707 .577 .707 r
F P
0 g
s
.314 .73643 m .31231 .75375 L .28298 .7461 L p .707 .577 .707 r
F P
0 g
s
.28298 .7461 m .28466 .72878 L .314 .73643 L p .707 .577 .707 r
F P
0 g
s
.7983 .60002 m .79733 .655 L .82014 .64857 L p .707 .577 .707 r
F P
0 g
s
.82014 .64857 m .82111 .5936 L .7983 .60002 L p .707 .577 .707 r
F P
0 g
s
.67724 .65273 m .67821 .59776 L .65582 .59048 L p .707 .577 .707 r
F P
0 g
s
.67821 .59776 m .67724 .65273 L .70558 .65767 L p .707 .577 .707 r
F P
0 g
s
.22023 .74305 m .22192 .72574 L .25293 .7251 L p .707 .577 .707 r
F P
0 g
s
.74359 .71019 m .74232 .67256 L .71056 .67287 L p .707 .577 .707 r
F P
0 g
s
.74232 .67256 m .74359 .71019 L .77488 .70786 L p .707 .577 .707 r
F P
0 g
s
.77488 .70786 m .77361 .67023 L .74232 .67256 L p .707 .577 .707 r
F P
0 g
s
.28466 .72878 m .28298 .7461 L .25125 .74241 L p .707 .577 .707 r
F P
0 g
s
.25125 .74241 m .25293 .7251 L .28466 .72878 L p .707 .577 .707 r
F P
0 g
s
.71184 .71051 m .71056 .67287 L .68145 .67113 L p .707 .577 .707 r
F P
0 g
s
.71056 .67287 m .71184 .71051 L .74359 .71019 L p .707 .577 .707 r
F P
0 g
s
.25293 .7251 m .25125 .74241 L .22023 .74305 L p .707 .577 .707 r
F P
0 g
s
.4291 .74951 m .4291 .24762 L .47139 .24339 L p .707 .577 .707 r
F P
0 g
s
.4291 .24762 m .4291 .74951 L .39375 .75704 L p .707 .577 .707 r
F P
0 g
s
.77361 .67023 m .77488 .70786 L .80264 .70374 L p .707 .577 .707 r
F P
0 g
s
.80264 .70374 m .80137 .6661 L .77361 .67023 L p .707 .577 .707 r
F P
0 g
s
.74875 .74253 m .74707 .72347 L .71534 .72597 L p .707 .577 .707 r
F P
0 g
s
.74707 .72347 m .74875 .74253 L .77976 .73909 L p .707 .577 .707 r
F P
0 g
s
.77976 .73909 m .77808 .72002 L .74707 .72347 L p .707 .577 .707 r
F P
0 g
s
.55995 .24613 m .55995 .74802 L .51648 .74477 L p .707 .577 .707 r
F P
0 g
s
.51648 .74477 m .51648 .24288 L .55995 .24613 L p .707 .577 .707 r
F P
0 g
s
.68145 .67113 m .68272 .70876 L .71184 .71051 L p .707 .577 .707 r
F P
0 g
s
.71534 .72597 m .71702 .74503 L .74875 .74253 L p .707 .577 .707 r
F P
0 g
s
.71702 .74503 m .71534 .72597 L .686 .72728 L p .707 .577 .707 r
F P
0 g
s
.65582 .59048 m .65485 .64545 L .67724 .65273 L p .707 .577 .707 r
F P
0 g
s
.686 .72728 m .68768 .74634 L .71702 .74503 L p .707 .577 .707 r
F P
0 g
s
.68272 .70876 m .68145 .67113 L .65783 .66751 L p .707 .577 .707 r
F P
0 g
s
.77808 .72002 m .77976 .73909 L .80703 .73504 L p .707 .577 .707 r
F P
0 g
s
.80703 .73504 m .80534 .71597 L .77808 .72002 L p .707 .577 .707 r
F P
0 g
s
.82111 .5936 m .82014 .64857 L .83491 .64021 L p .707 .577 .707 r
F P
0 g
s
.83491 .64021 m .83588 .58524 L .82111 .5936 L p .707 .577 .707 r
F P
0 g
s
.65485 .64545 m .65582 .59048 L .64157 .58157 L p .707 .577 .707 r
F P
0 g
s
.47139 .74528 m .47139 .24339 L .51648 .24288 L p .707 .577 .707 r
F P
0 g
s
.47139 .24339 m .47139 .74528 L .4291 .74951 L p .707 .577 .707 r
F P
0 g
s
.80137 .6661 m .80264 .70374 L .82415 .69823 L p .707 .577 .707 r
F P
0 g
s
.82415 .69823 m .82288 .66059 L .80137 .6661 L p .707 .577 .707 r
F P
0 g
s
.51648 .24288 m .51648 .74477 L .47139 .74528 L p .707 .577 .707 r
F P
0 g
s
.65783 .66751 m .6591 .70514 L .68272 .70876 L p .707 .577 .707 r
F P
0 g
s
.68768 .74634 m .686 .72728 L .66193 .72727 L p .707 .577 .707 r
F P
0 g
s
.66193 .72727 m .66361 .74633 L .68768 .74634 L p .707 .577 .707 r
F P
0 g
s
.80534 .71597 m .80703 .73504 L .82787 .73077 L p .707 .577 .707 r
F P
0 g
s
.82787 .73077 m .82619 .71171 L .80534 .71597 L p .707 .577 .707 r
F P
0 g
s
.64157 .58157 m .6406 .63655 L .65485 .64545 L p .707 .577 .707 r
F P
0 g
s
.6591 .70514 m .65783 .66751 L .64201 .66236 L p .707 .577 .707 r
F P
0 g
s
.82288 .66059 m .82415 .69823 L .83731 .69187 L p .707 .577 .707 r
F P
0 g
s
.83731 .69187 m .83604 .65423 L .82288 .66059 L p .707 .577 .707 r
F P
0 g
s
.83588 .58524 m .83491 .64021 L .8402 .63074 L p .707 .577 .707 r
F P
0 g
s
.8402 .63074 m .84117 .57576 L .83588 .58524 L p .707 .577 .707 r
F P
0 g
s
.6406 .63655 m .64157 .58157 L .63686 .57191 L p .707 .577 .707 r
F P
0 g
s
.64201 .66236 m .64328 .7 L .6591 .70514 L p .707 .577 .707 r
F P
0 g
s
.66361 .74633 m .66193 .72727 L .64547 .72594 L p .707 .577 .707 r
F P
0 g
s
.64547 .72594 m .64715 .745 L .66361 .74633 L p .707 .577 .707 r
F P
0 g
s
.82619 .71171 m .82787 .73077 L .84026 .72672 L p .707 .577 .707 r
F P
0 g
s
.84026 .72672 m .83857 .70766 L .82619 .71171 L p .707 .577 .707 r
F P
0 g
s
.63686 .57191 m .63589 .62689 L .6406 .63655 L p .707 .577 .707 r
F P
0 g
s
.64328 .7 m .64201 .66236 L .63554 .65619 L p .707 .577 .707 r
F P
0 g
s
.83604 .65423 m .83731 .69187 L .84083 .68528 L p .707 .577 .707 r
F P
0 g
s
.84083 .68528 m .83955 .64764 L .83604 .65423 L p .707 .577 .707 r
F P
0 g
s
.63554 .65619 m .63681 .69383 L .64328 .7 L p .707 .577 .707 r
F P
0 g
s
.64715 .745 m .64547 .72594 L .63825 .72343 L p .707 .577 .707 r
F P
0 g
s
.84117 .57576 m .8402 .63074 L .83549 .62107 L p .707 .577 .707 r
F P
0 g
s
.83549 .62107 m .83646 .5661 L .84117 .57576 L p .707 .577 .707 r
F P
0 g
s
.63589 .62689 m .63686 .57191 L .64215 .56244 L p .707 .577 .707 r
F P
0 g
s
.63825 .72343 m .63993 .74249 L .64715 .745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83857 .70766 m .84026 .72672 L .84297 .72327 L p .707 .577 .707 r
F P
0 g
s
.84297 .72327 m .84128 .7042 L .83857 .70766 L p .707 .577 .707 r
F P
0 g
s
.64215 .56244 m .64118 .61741 L .63589 .62689 L p .707 .577 .707 r
F P
0 g
s
.63681 .69383 m .63554 .65619 L .63906 .6496 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63906 .6496 m .64033 .68724 L .63681 .69383 L p .707 .577 .707 r
F P
0 g
s
.83955 .64764 m .84083 .68528 L .83436 .67911 L p .707 .577 .707 r
F P
0 g
s
.83436 .67911 m .83309 .64147 L .83955 .64764 L p .707 .577 .707 r
F P
0 g
s
.39135 .61944 m .39357 .56363 L .36207 .56113 L p .707 .577 .707 r
F P
0 g
s
.39357 .56363 m .39135 .61944 L .42294 .61944 L p .707 .577 .707 r
F P
0 g
s
.42294 .61944 m .42517 .56363 L .39357 .56363 L p .707 .577 .707 r
F P
0 g
s
.83646 .5661 m .83549 .62107 L .82124 .61217 L p .707 .577 .707 r
F P
0 g
s
.82124 .61217 m .82221 .55719 L .83646 .5661 L p .707 .577 .707 r
F P
0 g
s
.63993 .74249 m .63825 .72343 L .64096 .71998 L p .707 .577 .707 r
F P
0 g
s
.64118 .61741 m .64215 .56244 L .65692 .55408 L p .707 .577 .707 r
F P
0 g
s
.64096 .71998 m .64264 .73904 L .63993 .74249 L p .707 .577 .707 r
F P
0 g
s
.35985 .61693 m .36207 .56113 L .33375 .55636 L p .707 .577 .707 r
F P
0 g
s
.36207 .56113 m .35985 .61693 L .39135 .61944 L p .707 .577 .707 r
F P
0 g
s
.42517 .56363 m .42294 .61944 L .45154 .61693 L p .707 .577 .707 r
F P
0 g
s
.45154 .61693 m .45377 .56112 L .42517 .56363 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84128 .7042 m .84297 .72327 L .83574 .72075 L p .707 .577 .707 r
F P
0 g
s
.83574 .72075 m .83406 .70169 L .84128 .7042 L p .707 .577 .707 r
F P
0 g
s
.65692 .55408 m .65595 .60905 L .64118 .61741 L p .707 .577 .707 r
F P
0 g
s
.33152 .61216 m .33375 .55636 L .31137 .54979 L p .707 .577 .707 r
F P
0 g
s
.33375 .55636 m .33152 .61216 L .35985 .61693 L p .707 .577 .707 r
F P
0 g
s
.45377 .56112 m .45154 .61693 L .47434 .61216 L p .707 .577 .707 r
F P
0 g
s
.47434 .61216 m .47656 .55635 L .45377 .56112 L p .707 .577 .707 r
F P
0 g
s
.39874 .68458 m .39588 .64803 L .3642 .64921 L p .707 .577 .707 r
F P
0 g
s
.39588 .64803 m .39874 .68458 L .42996 .6804 L p .707 .577 .707 r
F P
0 g
s
.42996 .6804 m .4271 .64386 L .39588 .64803 L p .707 .577 .707 r
F P
0 g
s
.64033 .68724 m .63906 .6496 L .65222 .64324 L p .707 .577 .707 r
F P
0 g
s
.36706 .68576 m .3642 .64921 L .33516 .64727 L p .707 .577 .707 r
F P
0 g
s
.3642 .64921 m .36706 .68576 L .39874 .68458 L p .707 .577 .707 r
F P
0 g
s
.82221 .55719 m .82124 .61217 L .79885 .60489 L p .707 .577 .707 r
F P
0 g
s
.79885 .60489 m .79982 .54992 L .82221 .55719 L p .707 .577 .707 r
F P
0 g
s
.4271 .64386 m .42996 .6804 L .45767 .67363 L p .707 .577 .707 r
F P
0 g
s
.45767 .67363 m .45481 .63709 L .4271 .64386 L p .707 .577 .707 r
F P
0 g
s
.65595 .60905 m .65692 .55408 L .67973 .54765 L p .707 .577 .707 r
F P
0 g
s
.83309 .64147 m .83436 .67911 L .81854 .67396 L p .707 .577 .707 r
F P
0 g
s
.81854 .67396 m .81727 .63632 L .83309 .64147 L p .707 .577 .707 r
F P
0 g
s
.65222 .64324 m .65349 .68088 L .64033 .68724 L p .707 .577 .707 r
F P
0 g
s
.64264 .73904 m .64096 .71998 L .65334 .71592 L p .707 .577 .707 r
F P
0 g
s
.31137 .54979 m .30915 .6056 L .33152 .61216 L p .707 .577 .707 r
F P
0 g
s
.65334 .71592 m .65503 .73499 L .64264 .73904 L p .707 .577 .707 r
F P
0 g
s
.33516 .64727 m .33801 .68381 L .36706 .68576 L p .707 .577 .707 r
F P
0 g
s
.33801 .68381 m .33516 .64727 L .3116 .6424 L p .707 .577 .707 r
F P
0 g
s
.30915 .6056 m .31137 .54979 L .29714 .54207 L p .707 .577 .707 r
F P
0 g
s
.47656 .55635 m .47434 .61216 L .48911 .60559 L p .707 .577 .707 r
F P
0 g
s
.48911 .60559 m .49133 .54979 L .47656 .55635 L p .707 .577 .707 r
F P
0 g
s
.45481 .63709 m .45767 .67363 L .47915 .66493 L p .707 .577 .707 r
F P
0 g
s
.47915 .66493 m .47629 .62838 L .45481 .63709 L p .707 .577 .707 r
F P
0 g
s
.40694 .73065 m .4032 .71307 L .37197 .7178 L p .707 .577 .707 r
F P
0 g
s
.4032 .71307 m .40694 .73065 L .43751 .72241 L p .707 .577 .707 r
F P
0 g
s
.43751 .72241 m .43377 .70484 L .4032 .71307 L p .707 .577 .707 r
F P
0 g
s
.83406 .70169 m .83574 .72075 L .81929 .71943 L p .707 .577 .707 r
F P
0 g
s
.81929 .71943 m .8176 .70037 L .83406 .70169 L p .707 .577 .707 r
F P
0 g
s
.67973 .54765 m .67876 .60263 L .65595 .60905 L p .707 .577 .707 r
F P
0 g
s
.43377 .70484 m .43751 .72241 L .46441 .71148 L p .707 .577 .707 r
F P
0 g
s
.46441 .71148 m .46068 .69391 L .43377 .70484 L p .707 .577 .707 r
F P
0 g
s
.37571 .73538 m .37197 .7178 L .34313 .71857 L p .707 .577 .707 r
F P
0 g
s
.37197 .7178 m .37571 .73538 L .40694 .73065 L p .707 .577 .707 r
F P
0 g
s
.79982 .54992 m .79885 .60489 L .7705 .59996 L p .707 .577 .707 r
F P
0 g
s
.7705 .59996 m .77148 .54498 L .79982 .54992 L p .707 .577 .707 r
F P
0 g
s
.67876 .60263 m .67973 .54765 L .70834 .54379 L p .707 .577 .707 r
F P
0 g
s
.65349 .68088 m .65222 .64324 L .67373 .63773 L p .707 .577 .707 r
F P
0 g
s
.3116 .6424 m .31446 .67894 L .33801 .68381 L p .707 .577 .707 r
F P
0 g
s
.34313 .71857 m .34686 .73615 L .37571 .73538 L p .707 .577 .707 r
F P
0 g
s
.29714 .54207 m .29491 .59788 L .30915 .6056 L p .707 .577 .707 r
F P
0 g
s
.81727 .63632 m .81854 .67396 L .79492 .67034 L p .707 .577 .707 r
F P
0 g
s
.79492 .67034 m .79365 .6327 L .81727 .63632 L p .707 .577 .707 r
F P
0 g
s
.67373 .63773 m .675 .67536 L .65349 .68088 L p .707 .577 .707 r
F P
0 g
s
.31446 .67894 m .3116 .6424 L .29583 .63508 L p .707 .577 .707 r
F P
0 g
s
.46068 .69391 m .46441 .71148 L .48503 .69893 L p .707 .577 .707 r
F P
0 g
s
.48503 .69893 m .48129 .68135 L .46068 .69391 L p .707 .577 .707 r
F P
0 g
s
.65503 .73499 m .65334 .71592 L .67419 .71166 L p .707 .577 .707 r
F P
0 g
s
.34686 .73615 m .34313 .71857 L .3195 .7153 L p .707 .577 .707 r
F P
0 g
s
.77148 .54498 m .7705 .59996 L .73898 .59784 L p .707 .577 .707 r
F P
0 g
s
.73898 .59784 m .73995 .54287 L .77148 .54498 L p .707 .577 .707 r
F P
0 g
s
.70737 .59877 m .70834 .54379 L .73995 .54287 L p .707 .577 .707 r
F P
0 g
s
.70834 .54379 m .70737 .59877 L .67876 .60263 L p .707 .577 .707 r
F P
0 g
s
.67419 .71166 m .67587 .73072 L .65503 .73499 L p .707 .577 .707 r
F P
0 g
s
.47629 .62838 m .47915 .66493 L .49229 .65515 L p .707 .577 .707 r
F P
0 g
s
.49229 .65515 m .48943 .61861 L .47629 .62838 L p .707 .577 .707 r
F P
0 g
s
.73995 .54287 m .73898 .59784 L .70737 .59877 L p .707 .577 .707 r
F P
0 g
s
.29491 .59788 m .29714 .54207 L .29244 .53396 L p .707 .577 .707 r
F P
0 g
s
.3195 .7153 m .32324 .73287 L .34686 .73615 L p .707 .577 .707 r
F P
0 g
s
.49133 .54979 m .48911 .60559 L .4944 .59788 L p .707 .577 .707 r
F P
0 g
s
.4944 .59788 m .49663 .54207 L .49133 .54979 L p .707 .577 .707 r
F P
0 g
s
.8176 .70037 m .81929 .71943 L .79521 .71942 L p .707 .577 .707 r
F P
0 g
s
.79521 .71942 m .79353 .70036 L .8176 .70037 L p .707 .577 .707 r
F P
0 g
s
.29583 .63508 m .29869 .67162 L .31446 .67894 L p .707 .577 .707 r
F P
0 g
s
.675 .67536 m .67373 .63773 L .70149 .6336 L p .707 .577 .707 r
F P
0 g
s
.79365 .6327 m .79492 .67034 L .7658 .6686 L p .707 .577 .707 r
F P
0 g
s
.7658 .6686 m .76453 .63096 L .79365 .6327 L p .707 .577 .707 r
F P
0 g
s
.48129 .68135 m .48503 .69893 L .49734 .68598 L p .707 .577 .707 r
F P
0 g
s
.49734 .68598 m .4936 .6684 L .48129 .68135 L p .707 .577 .707 r
F P
0 g
s
.70149 .6336 m .70276 .67124 L .675 .67536 L p .707 .577 .707 r
F P
0 g
s
.29244 .53396 m .29021 .58977 L .29491 .59788 L p .707 .577 .707 r
F P
0 g
s
.32324 .73287 m .3195 .7153 L .3034 .7083 L p .707 .577 .707 r
F P
0 g
s
.67587 .73072 m .67419 .71166 L .70145 .70761 L p .707 .577 .707 r
F P
0 g
s
.29869 .67162 m .29583 .63508 L .2894 .62602 L p .707 .577 .707 r
F P
0 g
s
.70145 .70761 m .70313 .72667 L .67587 .73072 L p .707 .577 .707 r
F P
0 g
s
.70276 .67124 m .70149 .6336 L .73278 .63127 L p .707 .577 .707 r
F P
0 g
s
.3034 .7083 m .30714 .72588 L .32324 .73287 L p .707 .577 .707 r
F P
0 g
s
.48943 .61861 m .49229 .65515 L .49582 .64525 L p .707 .577 .707 r
F P
0 g
s
.49582 .64525 m .49296 .6087 L .48943 .61861 L p .707 .577 .707 r
F P
0 g
s
.76453 .63096 m .7658 .6686 L .73405 .66891 L p .707 .577 .707 r
F P
0 g
s
.73405 .66891 m .73278 .63127 L .76453 .63096 L p .707 .577 .707 r
F P
0 g
s
.79353 .70036 m .79521 .71942 L .76588 .72073 L p .707 .577 .707 r
F P
0 g
s
.76588 .72073 m .76419 .70167 L .79353 .70036 L p .707 .577 .707 r
F P
0 g
s
.73278 .63127 m .73405 .66891 L .70276 .67124 L p .707 .577 .707 r
F P
0 g
s
.29021 .58977 m .29244 .53396 L .29773 .52624 L p .707 .577 .707 r
F P
0 g
s
.2894 .62602 m .29226 .66257 L .29869 .67162 L p .707 .577 .707 r
F P
0 g
s
.49663 .54207 m .4944 .59788 L .4897 .58976 L p .707 .577 .707 r
F P
0 g
s
.4897 .58976 m .49192 .53395 L .49663 .54207 L p .707 .577 .707 r
F P
0 g
s
.70313 .72667 m .70145 .70761 L .73246 .70417 L p .707 .577 .707 r
F P
0 g
s
.73246 .70417 m .73415 .72323 L .70313 .72667 L p .707 .577 .707 r
F P
0 g
s
.76419 .70167 m .76588 .72073 L .73415 .72323 L p .707 .577 .707 r
F P
0 g
s
.73415 .72323 m .73246 .70417 L .76419 .70167 L p .707 .577 .707 r
F P
0 g
s
.4936 .6684 m .49734 .68598 L .50013 .67389 L p .707 .577 .707 r
F P
0 g
s
.50013 .67389 m .49639 .65632 L .4936 .6684 L p .707 .577 .707 r
F P
0 g
s
.30714 .72588 m .3034 .7083 L .2964 .69828 L p .707 .577 .707 r
F P
0 g
s
.29773 .52624 m .29551 .58205 L .29021 .58977 L p .707 .577 .707 r
F P
0 g
s
.2964 .69828 m .30014 .71585 L .30714 .72588 L p .707 .577 .707 r
F P
0 g
s
.29226 .66257 m .2894 .62602 L .29293 .61612 L p .707 .577 .707 r
F P
0 g
s
.49296 .6087 m .49582 .64525 L .48939 .6362 L p .707 .577 .707 r
F P
0 g
s
.48939 .6362 m .48653 .59965 L .49296 .6087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29293 .61612 m .29579 .65267 L .29226 .66257 L p .707 .577 .707 r
F P
0 g
s
.29551 .58205 m .29773 .52624 L .3125 .51968 L p .707 .577 .707 r
F P
0 g
s
.49192 .53395 m .4897 .58976 L .47546 .58204 L p .707 .577 .707 r
F P
0 g
s
.47546 .58204 m .47769 .52624 L .49192 .53395 L p .707 .577 .707 r
F P
0 g
s
.49639 .65632 m .50013 .67389 L .49313 .66387 L p .707 .577 .707 r
F P
0 g
s
.49313 .66387 m .48939 .64629 L .49639 .65632 L p .707 .577 .707 r
F P
0 g
s
.30014 .71585 m .2964 .69828 L .29919 .6862 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3125 .51968 m .31027 .57548 L .29551 .58205 L p .707 .577 .707 r
F P
0 g
s
.29919 .6862 m .30293 .70377 L .30014 .71585 L p .707 .577 .707 r
F P
0 g
s
.29579 .65267 m .29293 .61612 L .30607 .60634 L p .707 .577 .707 r
F P
0 g
s
.48653 .59965 m .48939 .6362 L .47362 .62888 L p .707 .577 .707 r
F P
0 g
s
.47362 .62888 m .47076 .59233 L .48653 .59965 L p .707 .577 .707 r
F P
0 g
s
.31027 .57548 m .3125 .51968 L .3353 .51491 L p .707 .577 .707 r
F P
0 g
s
.47769 .52624 m .47546 .58204 L .45309 .57548 L p .707 .577 .707 r
F P
0 g
s
.45309 .57548 m .45532 .51967 L .47769 .52624 L p .707 .577 .707 r
F P
0 g
s
.30607 .60634 m .30893 .64289 L .29579 .65267 L p .707 .577 .707 r
F P
0 g
s
.48939 .64629 m .49313 .66387 L .47703 .65688 L p .707 .577 .707 r
F P
0 g
s
.47703 .65688 m .47329 .6393 L .48939 .64629 L p .707 .577 .707 r
F P
0 g
s
.30293 .70377 m .29919 .6862 L .3115 .67324 L p .707 .577 .707 r
F P
0 g
s
.3353 .51491 m .33307 .57071 L .31027 .57548 L p .707 .577 .707 r
F P
0 g
s
.30893 .64289 m .30607 .60634 L .32755 .59764 L p .707 .577 .707 r
F P
0 g
s
.3115 .67324 m .31524 .69082 L .30293 .70377 L p .707 .577 .707 r
F P
0 g
s
.47076 .59233 m .47362 .62888 L .45006 .62401 L p .707 .577 .707 r
F P
0 g
s
.45006 .62401 m .4472 .58746 L .47076 .59233 L p .707 .577 .707 r
F P
0 g
s
.33307 .57071 m .3353 .51491 L .36389 .5124 L p .707 .577 .707 r
F P
0 g
s
.45532 .51967 m .45309 .57548 L .42477 .57071 L p .707 .577 .707 r
F P
0 g
s
.42477 .57071 m .42699 .5149 L .45532 .51967 L p .707 .577 .707 r
F P
0 g
s
.32755 .59764 m .33041 .63419 L .30893 .64289 L p .707 .577 .707 r
F P
0 g
s
.36167 .5682 m .36389 .5124 L .39549 .5124 L p .707 .577 .707 r
F P
0 g
s
.36389 .5124 m .36167 .5682 L .33307 .57071 L p .707 .577 .707 r
F P
0 g
s
.42699 .5149 m .42477 .57071 L .39326 .5682 L p .707 .577 .707 r
F P
0 g
s
.39326 .5682 m .39549 .5124 L .42699 .5149 L p .707 .577 .707 r
F P
0 g
s
.47329 .6393 m .47703 .65688 L .4534 .6536 L p .707 .577 .707 r
F P
0 g
s
.4534 .6536 m .44966 .63602 L .47329 .6393 L p .707 .577 .707 r
F P
0 g
s
.31524 .69082 m .3115 .67324 L .33211 .66069 L p .707 .577 .707 r
F P
0 g
s
.33041 .63419 m .32755 .59764 L .35526 .59087 L p .707 .577 .707 r
F P
0 g
s
.39549 .5124 m .39326 .5682 L .36167 .5682 L p .707 .577 .707 r
F P
0 g
s
.4472 .58746 m .45006 .62401 L .42102 .62207 L p .707 .577 .707 r
F P
0 g
s
.42102 .62207 m .41816 .58552 L .4472 .58746 L p .707 .577 .707 r
F P
0 g
s
.33211 .66069 m .33585 .67827 L .31524 .69082 L p .707 .577 .707 r
F P
0 g
s
.35526 .59087 m .35812 .62742 L .33041 .63419 L p .707 .577 .707 r
F P
0 g
s
.35812 .62742 m .35526 .59087 L .38648 .58669 L p .707 .577 .707 r
F P
0 g
s
.41816 .58552 m .42102 .62207 L .38934 .62324 L p .707 .577 .707 r
F P
0 g
s
.38934 .62324 m .38648 .58669 L .41816 .58552 L p .707 .577 .707 r
F P
0 g
s
.44966 .63602 m .4534 .6536 L .42456 .65437 L p .707 .577 .707 r
F P
0 g
s
.42456 .65437 m .42082 .63679 L .44966 .63602 L p .707 .577 .707 r
F P
0 g
s
.33585 .67827 m .33211 .66069 L .35902 .64976 L p .707 .577 .707 r
F P
0 g
s
.38648 .58669 m .38934 .62324 L .35812 .62742 L p .707 .577 .707 r
F P
0 g
s
.35902 .64976 m .36276 .66734 L .33585 .67827 L p .707 .577 .707 r
F P
0 g
s
.42082 .63679 m .42456 .65437 L .39333 .6591 L p .707 .577 .707 r
F P
0 g
s
.39333 .6591 m .38959 .64152 L .42082 .63679 L p .707 .577 .707 r
F P
0 g
s
.36276 .66734 m .35902 .64976 L .38959 .64152 L p .707 .577 .707 r
F P
0 g
s
.38959 .64152 m .39333 .6591 L .36276 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001TOolA0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`P0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00EWoo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0I7oo001DOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00eooa4004Ioo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`07Ool60003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH8000nOol005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00Dgoo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Oomoogoo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001COol00eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000bOol0059oo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0059oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`03001JEP0000=JEP04
001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH01000
FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000=JEP@0009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60005FUH01000FUIJEUYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01000FUH005YF0P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00UYF
0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01P00FUH00000FUH000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP80
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF40001EYF00<005YFFUH00eYF00D005YF000005YF008000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF1@000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01@0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001COol0
1@00FUIJEUYF00001EYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF0000009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00Dgoo00D0
05YFFUIJEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF009JEQP000IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;Goo001DOol200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF
009JEPh000=oo`D00003Ool0000000T0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0041o
oaT000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEUYF001JEP000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH00UYF2@0015YF
00<005YFFUH015YF100015YF00@005YFFUIJEP8002ioo`00?7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP0300000eYF001JEP02FUH2000^Ool003Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP03
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20003FUH2000^Ool0039oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF0000000^
Ool0031oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03000^Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000IJEP03001JEP0000L000=JEP03001JEUYF009JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPH000EJEP<000MJEP03001J
EUYF00MJEPD000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEPD000IJEP03001JEUYF00UJEPD00003FUH0000000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH01000FUIJEUYF6@0015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH0
0UYF100000=JEP00FUH00UYF00@005YFFUH000EJEPD000IJEP03001JEUYF00T0009JEP03001JEUYF
00<000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD000=JEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000UYF00<005YF00000P001EYF00D005YFFUIJEP00009JEP03001J
EUYF00=JEPh000=JEP04001JEUYFFUH50003FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF1`000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00<007ooOol0;Goo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002
FUH300000eYF001JEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEPL0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00P005YF001JEP00FUH005YF
100015YF00@005YFFUH0009JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP03FUH;0005FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01@00FUIJEUYF00001UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF009JEPL000=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;Goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00D005YFFUIJ
EP0000IJEP@000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00D000=JEP80
00AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP04
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF00000004FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH015YF5@0015YF00<005YFFUH0
0`0025YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00AJEP00000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF0080
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01@0025YF00<005YFFUH01UYF0`0015YF00<005YF00000UYF00<005YFFUH01EYF10001UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00;Woo000]Ool20004FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF000015YF0P0015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF0`000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUHO0003FUH00`00
FUIJEP02FUH2000^Ool002eoo`8000=JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00AJEP800003FUH005YF009JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF00<005YFFUH00eYF00<005YF
FUH05@0015YF00<005YFFUH01EYF00<005YF000010000eYF0P00;Woo000]Ool2000015YF00000000
1EYF00<005YFFUH00UYF5`000eYF0P001UYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00@005YFFUIJEP800004FUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF1@001eYF00<005YFFUH015YF1@00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP000000;Woo000]Ool30002FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP03FUH2
00000eYF001JEP06FUH00`00FUIJEP04FUH30004FUH70008FUH01000FUIJEP0015YF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
100015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000P00;Woo000]Ool20003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH0200015YF00<005YFFUH00UYF2@00
0eYF00<005YFFUH02EYF100015YF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]Ool20003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF1`00
00AJEP00FUIJEPT00003FUH0000000<000IJEP03001JEUYF00UJEP04001JEUYF0004FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20002FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P001EYF0P000eYF00@005YFFUH000EJ
EPD000IJEP03001JEUYF00MJEP8000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP03001JEP0000IJEPD0009JEP03001JEUYF00AJEP<000MJEP03001JEUYF00EJEP8000IJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000`Ool002ioo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<005YF00000P000UYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP05001JEUYF001JEP020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YF
FUH015YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0001P002moo`00;Goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF10001UYF00<0
05YFFUH00P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YF0000200015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH0
0UYF00@005YFFUH000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP8000aJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00d000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF3P0015YF00@005YFFUIJEP@0
0003FUH005YF00AJEP03001JEUYF009JEP04001JEUYF0006FUH60006FUH00`00FUIJEP05FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00@000ioo`X0
009JEPD0009JEP03001JEUYF009JEP04001JEUYF0003FUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=J
EP03001JEUYF009JEP@001]oo`80009JEP04001JEUYFFUH>0006FUH00`00FUIJEP07FUH00`00FUH0
00020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHI
00000eYF001oo`0/Ool002eoo`8000=JEP03001JEP00008001moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02
000]Ool002eoo`8000=JEP8000Qooa0000]oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00@005YFFUIJEQ4000QJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEP00000^Ool002eoo`800004FUH00000FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF1@001eYF00<005YFFUH0
0eYF100025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool30003FUH00`00FUH00002
0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003Ool50003FUH00`00FUIJEP05
FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF00000P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00<goo000]Ool30003
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003
Ool?0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00=Woo000]Ool01000FUH005YF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF
00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000kOol002eoo`03001JEP00
008000AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01eYF5P001UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEPD0009JEP03001JEUYF00AJEP03001JEUYF009JEQ4004Aoo`00
;Woo0P0000=JEP00FUH00eYF1@001eYF00<005YFFUH01UYF1`001UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP090007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF3`00E7oo
000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF00<005YFFUH01EYF0`000UYF00@005YFFUH000IJEP03001JEUYF00EJEPL000]JEP03001J
EUYF00YJEP03001JEUYF00UJEPD0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF009JEP8005=oo`00;Goo00D005YFFUH005YF008000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEP00009JEP04
001JEUYF0006FUH00`00FUIJEP050006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP03FUH2001COol002eoo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH00eYF1@002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0P0015YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF0P00
Dgoo000]Ool01000FUH007oo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0P0000=JEP00FUH00eYF0P000UYF00@005YFFUIJEP8000AJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF
00=JEP8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005=oo`00;Goo0P0017oo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00AJEP80009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<007oo00001@0015YF00<005YF
FUH00UYF00<005YF0000Dgoo000]Ool00`00Oomoo`05Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF0`001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF2`0000=JEP00FUH00eYF00<005YF0000Dgoo000]Ool2000:Ool30006FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUH0000400001EYF000005YF00000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF1@001eYF00<005YF00000P000eYF00<005YF0000Dgoo000/Ool00`00
FUH0000=Ool40002FUH00`00FUIJEP02FUH50008FUH00`00FUIJEP02FUH50005Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH2000015YF001JEP00
Dgoo000/Ool01000FUIJEP0047oo6@002goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00P001eYF00<005YFFUH00eYF0`0000=JEP00Ool0DWoo000/Ool00`00FUIJEP02000FOol5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00Dgoo000/Ool01P00FUIJEP00FUH001Ioo`<001Yoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF00=JEP04001JEUYFFUH2
001COol002eoo`8000=JEP03001oogoo031oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEP000007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000]Ool20004FUH2000_
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000E7oo000^Ool00`00FUIJEP02FUH01000FUH00000;7oo00<005YF0000
0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF00<005YFFUH00P00E7oo
000_Ool20002FUH01000FUIJEUYF0P00:7oo0P000UYF00@007ooOomoo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000AJEP@0009JEP04001JEUYFFUH5001FOol0035oo`<000EJEP@0025oo`<00005FUH005YFFUH0
0004Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P0025YF00<005YF00001@00Fgoo000cOol00`00FUIJEP04FUH0
0`00FUIJEP04000JOol30004FUH00`00FUH00007Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000FUH000QJEP04001J
EUYFFUH2001MOol003Aoo`8000AJEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP8000ao
o`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEPT000IJ
EP03001JEUYF00AJEP8005]oo`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF
00<005YFFUH00eYF0P004Goo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02@001Goo0P0015YF00<005YFFUH01EYF0`00FGoo000hOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000HOol80006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH:0002Ool50007Ool300000eYF001JEP06FUH00`00FUIJEP02001GOol003Yo
o`8000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080029ooaX0
00MJEP03001JEUYF00L000Yoo`<000EJEP03001JEUYF009JEP8005Ioo`00?7oo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo100000=JEP00FUH01eYF00<005YFFUH0
0eYF20002Goo100000=JEP00FUH00eYF00<005YF0000EGoo0010Ool70004FUH00`00FUIJEP06FUH0
0`00FUIJEP04000oOol30006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005Ool20003FUH01000
FUIJEP00EGoo0017Ool@0016Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
2@0000EJEP00FUIJEP0005Eoo`00XGoo1@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP000000EGoo002VOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH00000EWoo002ZOol50006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000EWoo002_Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
EWoo002cOolD001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6133 .75139 m .60967 .69641 L .57804 .69707 L p .707 .577 .707 r
F P
0 g
s
.60967 .69641 m .6133 .75139 L .64467 .74777 L p .707 .577 .707 r
F P
0 g
s
.64467 .74777 m .64104 .69279 L .60967 .69641 L p .707 .577 .707 r
F P
0 g
s
.58167 .75204 m .57804 .69707 L .54925 .6947 L p .707 .577 .707 r
F P
0 g
s
.57804 .69707 m .58167 .75204 L .6133 .75139 L p .707 .577 .707 r
F P
0 g
s
.64104 .69279 m .64467 .74777 L .67271 .74155 L p .707 .577 .707 r
F P
0 g
s
.67271 .74155 m .66908 .68657 L .64104 .69279 L p .707 .577 .707 r
F P
0 g
s
.55288 .74968 m .54925 .6947 L .52611 .68954 L p .707 .577 .707 r
F P
0 g
s
.54925 .6947 m .55288 .74968 L .58167 .75204 L p .707 .577 .707 r
F P
0 g
s
.66908 .68657 m .67271 .74155 L .69468 .73333 L p .707 .577 .707 r
F P
0 g
s
.69468 .73333 m .69105 .67835 L .66908 .68657 L p .707 .577 .707 r
F P
0 g
s
.61956 .80396 m .62423 .76658 L .59253 .76252 L p .707 .577 .707 r
F P
0 g
s
.62423 .76658 m .61956 .80396 L .65011 .80586 L p .707 .577 .707 r
F P
0 g
s
.65011 .80586 m .65479 .76849 L .62423 .76658 L p .707 .577 .707 r
F P
0 g
s
.58785 .79989 m .59253 .76252 L .56278 .75668 L p .707 .577 .707 r
F P
0 g
s
.59253 .76252 m .58785 .79989 L .61956 .80396 L p .707 .577 .707 r
F P
0 g
s
.56278 .75668 m .5581 .79406 L .58785 .79989 L p .707 .577 .707 r
F P
0 g
s
.65479 .76849 m .65011 .80586 L .67653 .80541 L p .707 .577 .707 r
F P
0 g
s
.67653 .80541 m .6812 .76804 L .65479 .76849 L p .707 .577 .707 r
F P
0 g
s
.5581 .79406 m .56278 .75668 L .5379 .74965 L p .707 .577 .707 r
F P
0 g
s
.58254 .82828 m .58859 .8101 L .55976 .79969 L p .707 .577 .707 r
F P
0 g
s
.58859 .8101 m .58254 .82828 L .61288 .83831 L p .707 .577 .707 r
F P
0 g
s
.61288 .83831 m .61893 .82013 L .58859 .8101 L p .707 .577 .707 r
F P
0 g
s
.52611 .68954 m .52974 .74452 L .55288 .74968 L p .707 .577 .707 r
F P
0 g
s
.61893 .82013 m .61288 .83831 L .64176 .84697 L p .707 .577 .707 r
F P
0 g
s
.64176 .84697 m .64782 .82879 L .61893 .82013 L p .707 .577 .707 r
F P
0 g
s
.55976 .79969 m .55371 .81787 L .58254 .82828 L p .707 .577 .707 r
F P
0 g
s
.52974 .74452 m .52611 .68954 L .5109 .6821 L p .707 .577 .707 r
F P
0 g
s
.69105 .67835 m .69468 .73333 L .70843 .72392 L p .707 .577 .707 r
F P
0 g
s
.70843 .72392 m .7048 .66894 L .69105 .67835 L p .707 .577 .707 r
F P
0 g
s
.5379 .74965 m .53322 .78702 L .5581 .79406 L p .707 .577 .707 r
F P
0 g
s
.55371 .81787 m .55976 .79969 L .53526 .78991 L p .707 .577 .707 r
F P
0 g
s
.53526 .78991 m .52921 .8081 L .55371 .81787 L p .707 .577 .707 r
F P
0 g
s
.64782 .82879 m .64176 .84697 L .66636 .85343 L p .707 .577 .707 r
F P
0 g
s
.66636 .85343 m .67241 .83525 L .64782 .82879 L p .707 .577 .707 r
F P
0 g
s
.6812 .76804 m .67653 .80541 L .69622 .80265 L p .707 .577 .707 r
F P
0 g
s
.69622 .80265 m .70089 .76528 L .6812 .76804 L p .707 .577 .707 r
F P
0 g
s
.53322 .78702 m .5379 .74965 L .52032 .74211 L p .707 .577 .707 r
F P
0 g
s
.5109 .6821 m .51453 .73707 L .52974 .74452 L p .707 .577 .707 r
F P
0 g
s
.52032 .74211 m .51564 .77948 L .53322 .78702 L p .707 .577 .707 r
F P
0 g
s
.52921 .8081 m .53526 .78991 L .5175 .78173 L p .707 .577 .707 r
F P
0 g
s
.5175 .78173 m .51145 .79992 L .52921 .8081 L p .707 .577 .707 r
F P
0 g
s
.67241 .83525 m .66636 .85343 L .68427 .85704 L p .707 .577 .707 r
F P
0 g
s
.68427 .85704 m .69032 .83886 L .67241 .83525 L p .707 .577 .707 r
F P
0 g
s
.51453 .73707 m .5109 .6821 L .5051 .67309 L p .707 .577 .707 r
F P
0 g
s
.7048 .66894 m .70843 .72392 L .7126 .71424 L p .707 .577 .707 r
F P
0 g
s
.7126 .71424 m .70897 .65926 L .7048 .66894 L p .707 .577 .707 r
F P
0 g
s
.70089 .76528 m .69622 .80265 L .70725 .79785 L p .707 .577 .707 r
F P
0 g
s
.70725 .79785 m .71193 .76048 L .70089 .76528 L p .707 .577 .707 r
F P
0 g
s
.51564 .77948 m .52032 .74211 L .51176 .73479 L p .707 .577 .707 r
F P
0 g
s
.51185 .73291 m .51453 .73707 L p .51271 .72476 L .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .50709 .77217 L .51564 .77948 L p .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .51307 .72843 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.50709 .77217 m .51097 .74111 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.51097 .74111 m .51176 .73479 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.5051 .67309 m .50873 .72807 L .51185 .73291 L p .707 .577 .707 r
F P
0 g
s
.51271 .72476 m .5051 .67309 L .51185 .73291 L .707 .577 .707 r
F
.51145 .79992 m .5175 .78173 L .50821 .77595 L p F P
0 g
s
.50821 .77595 m .50215 .79413 L .51145 .79992 L p .707 .577 .707 r
F P
0 g
s
.69032 .83886 m .68427 .85704 L .69373 .85745 L p .707 .577 .707 r
F P
0 g
s
.69373 .85745 m .69978 .83927 L .69032 .83886 L p .707 .577 .707 r
F P
0 g
s
.50873 .72807 m .5051 .67309 L .50928 .66341 L p .707 .577 .707 r
F P
0 g
s
.70897 .65926 m .7126 .71424 L .7068 .70523 L p .707 .577 .707 r
F P
0 g
s
.7068 .70523 m .70317 .65026 L .70897 .65926 L p .707 .577 .707 r
F P
0 g
s
.47927 .82152 m .47927 .31963 L .43617 .31604 L p .707 .577 .707 r
F P
0 g
s
.50928 .66341 m .5129 .71839 L .50873 .72807 L p .707 .577 .707 r
F P
0 g
s
.51307 .72843 m .50839 .7658 L .50709 .77217 L p .707 .577 .707 r
F P
0 g
s
.50215 .79413 m .50821 .77595 L .50829 .77313 L p .707 .578 .707 r
F P
0 g
s
.50829 .77313 m .50224 .79131 L .50215 .79413 L p .707 .578 .707 r
F P
0 g
s
.5129 .71839 m .50928 .66341 L .52302 .654 L p .707 .577 .707 r
F P
0 g
s
.50839 .7658 m .51307 .72843 L .5241 .72363 L p .707 .577 .707 r
F P
0 g
s
.52302 .654 m .52665 .70898 L .5129 .71839 L p .707 .577 .707 r
F P
0 g
s
.5241 .72363 m .51943 .761 L .50839 .7658 L p .707 .577 .707 r
F P
0 g
s
.50224 .79131 m .50829 .77313 L .51775 .77354 L p .707 .577 .707 r
F P
0 g
s
.51775 .77354 m .5117 .79172 L .50224 .79131 L p .707 .577 .707 r
F P
0 g
s
.5117 .79172 m .51775 .77354 L .53566 .77715 L p .707 .577 .707 r
F P
0 g
s
.53566 .77715 m .52961 .79534 L .5117 .79172 L p .707 .577 .707 r
F P
0 g
s
.47927 .31963 m .47927 .82152 L .52439 .82137 L p .707 .577 .707 r
F P
0 g
s
.52665 .70898 m .52302 .654 L .54499 .64578 L p .707 .577 .707 r
F P
0 g
s
.51943 .761 m .5241 .72363 L .54379 .72087 L p .707 .577 .707 r
F P
0 g
s
.54379 .72087 m .53912 .75825 L .51943 .761 L p .707 .577 .707 r
F P
0 g
s
.52439 .82137 m .52439 .31948 L .47927 .31963 L p .707 .577 .707 r
F P
0 g
s
.54499 .64578 m .54862 .70076 L .52665 .70898 L p .707 .577 .707 r
F P
0 g
s
.54862 .70076 m .54499 .64578 L .57303 .63956 L p .707 .577 .707 r
F P
0 g
s
.57303 .63956 m .57666 .69454 L .54862 .70076 L p .707 .577 .707 r
F P
0 g
s
.53912 .75825 m .54379 .72087 L .57021 .72042 L p .707 .577 .707 r
F P
0 g
s
.57021 .72042 m .56554 .75779 L .53912 .75825 L p .707 .577 .707 r
F P
0 g
s
.52961 .79534 m .53566 .77715 L .56026 .78361 L p .707 .577 .707 r
F P
0 g
s
.56026 .78361 m .55421 .80179 L .52961 .79534 L p .707 .577 .707 r
F P
0 g
s
.55421 .80179 m .56026 .78361 L .58914 .79227 L p .707 .577 .707 r
F P
0 g
s
.58914 .79227 m .58309 .81046 L .55421 .80179 L p .707 .577 .707 r
F P
0 g
s
.52439 .31948 m .52439 .82137 L .56713 .81748 L p .707 .577 .707 r
F P
0 g
s
.56554 .75779 m .57021 .72042 L .60076 .72232 L p .707 .577 .707 r
F P
0 g
s
.60076 .72232 m .59609 .7597 L .56554 .75779 L p .707 .577 .707 r
F P
0 g
s
.56713 .81748 m .56713 .31559 L .52439 .31948 L p .707 .577 .707 r
F P
0 g
s
.71193 .76048 m .70725 .79785 L .70856 .79149 L p .707 .577 .707 r
F P
0 g
s
.70856 .79149 m .71323 .75411 L .71193 .76048 L p .707 .577 .707 r
F P
0 g
s
.43617 .81793 m .43617 .31604 L .39932 .30905 L p .707 .577 .707 r
F P
0 g
s
.43617 .31604 m .43617 .81793 L .47927 .82152 L p .707 .577 .707 r
F P
0 g
s
.57666 .69454 m .57303 .63956 L .60441 .63594 L p .707 .577 .707 r
F P
0 g
s
.60441 .63594 m .60803 .69092 L .57666 .69454 L p .707 .577 .707 r
F P
0 g
s
.63247 .72639 m .62779 .76376 L .59609 .7597 L p .707 .577 .707 r
F P
0 g
s
.59609 .7597 m .60076 .72232 L .63247 .72639 L p .707 .577 .707 r
F P
0 g
s
.58309 .81046 m .58914 .79227 L .61949 .8023 L p .707 .577 .707 r
F P
0 g
s
.61949 .8023 m .61343 .82049 L .58309 .81046 L p .707 .577 .707 r
F P
0 g
s
.56713 .31559 m .56713 .81748 L .6033 .81023 L p .707 .577 .707 r
F P
0 g
s
.6033 .81023 m .6033 .30834 L .56713 .31559 L p .707 .577 .707 r
F P
0 g
s
.69978 .83927 m .69373 .85745 L .69381 .85463 L p .707 .578 .707 r
F P
0 g
s
.69381 .85463 m .69987 .83645 L .69978 .83927 L p .707 .578 .707 r
F P
0 g
s
.26593 .70896 m .26432 .6526 L .23264 .65257 L p .707 .577 .707 r
F P
0 g
s
.26432 .6526 m .26593 .70896 L .29735 .70686 L p .707 .577 .707 r
F P
0 g
s
.29735 .70686 m .29574 .65051 L .26432 .6526 L p .707 .577 .707 r
F P
0 g
s
.70317 .65026 m .7068 .70523 L .69159 .69779 L p .707 .577 .707 r
F P
0 g
s
.69159 .69779 m .68796 .64281 L .70317 .65026 L p .707 .577 .707 r
F P
0 g
s
.23425 .70893 m .23264 .65257 L .2038 .65043 L p .707 .577 .707 r
F P
0 g
s
.23264 .65257 m .23425 .70893 L .26593 .70896 L p .707 .577 .707 r
F P
0 g
s
.29574 .65051 m .29735 .70686 L .32543 .70286 L p .707 .577 .707 r
F P
0 g
s
.32543 .70286 m .32382 .6465 L .29574 .65051 L p .707 .577 .707 r
F P
0 g
s
.71323 .75411 m .70856 .79149 L .7 .78418 L p .707 .577 .707 r
F P
0 g
s
.7 .78418 m .70468 .7468 L .71323 .75411 L p .707 .577 .707 r
F P
0 g
s
.39932 .81094 m .39932 .30905 L .37233 .29934 L p .707 .577 .707 r
F P
0 g
s
.39932 .30905 m .39932 .81094 L .43617 .81793 L p .707 .577 .707 r
F P
0 g
s
.2038 .65043 m .2054 .70679 L .23425 .70893 L p .707 .577 .707 r
F P
0 g
s
.63603 .63529 m .63966 .69026 L .60803 .69092 L p .707 .577 .707 r
F P
0 g
s
.60803 .69092 m .60441 .63594 L .63603 .63529 L p .707 .577 .707 r
F P
0 g
s
.61343 .82049 m .61949 .8023 L .64832 .81271 L p .707 .577 .707 r
F P
0 g
s
.6033 .30834 m .6033 .81023 L .62935 .80035 L p .707 .577 .707 r
F P
0 g
s
.66222 .73222 m .65754 .7696 L .62779 .76376 L p .707 .577 .707 r
F P
0 g
s
.62779 .76376 m .63247 .72639 L .66222 .73222 L p .707 .577 .707 r
F P
0 g
s
.62935 .80035 m .62935 .29846 L .6033 .30834 L p .707 .577 .707 r
F P
0 g
s
.2054 .70679 m .2038 .65043 L .18062 .64638 L p .707 .577 .707 r
F P
0 g
s
.32382 .6465 m .32543 .70286 L .34742 .69733 L p .707 .577 .707 r
F P
0 g
s
.34742 .69733 m .34582 .64097 L .32382 .6465 L p .707 .577 .707 r
F P
0 g
s
.27387 .78458 m .27598 .74881 L .24409 .74671 L p .707 .577 .707 r
F P
0 g
s
.27598 .74881 m .27387 .78458 L .3046 .783 L p .707 .577 .707 r
F P
0 g
s
.3046 .783 m .30671 .74723 L .27598 .74881 L p .707 .577 .707 r
F P
0 g
s
.24198 .78248 m .24409 .74671 L .21415 .74114 L p .707 .577 .707 r
F P
0 g
s
.24409 .74671 m .24198 .78248 L .27387 .78458 L p .707 .577 .707 r
F P
0 g
s
.69987 .83645 m .69381 .85463 L .68452 .84885 L p .707 .577 .707 r
F P
0 g
s
.68452 .84885 m .69058 .83067 L .69987 .83645 L p .707 .577 .707 r
F P
0 g
s
.18062 .64638 m .18222 .70274 L .2054 .70679 L p .707 .577 .707 r
F P
0 g
s
.68796 .64281 m .69159 .69779 L .66845 .69263 L p .707 .577 .707 r
F P
0 g
s
.66845 .69263 m .66483 .63765 L .68796 .64281 L p .707 .577 .707 r
F P
0 g
s
.30671 .74723 m .3046 .783 L .33115 .77789 L p .707 .577 .707 r
F P
0 g
s
.33115 .77789 m .33326 .74213 L .30671 .74723 L p .707 .577 .707 r
F P
0 g
s
.21204 .77691 m .21415 .74114 L .1891 .73264 L p .707 .577 .707 r
F P
0 g
s
.21415 .74114 m .21204 .77691 L .24198 .78248 L p .707 .577 .707 r
F P
0 g
s
.18222 .70274 m .18062 .64638 L .16537 .64082 L p .707 .577 .707 r
F P
0 g
s
.70468 .7468 m .7 .78418 L .68242 .77663 L p .707 .577 .707 r
F P
0 g
s
.68242 .77663 m .6871 .73926 L .70468 .7468 L p .707 .577 .707 r
F P
0 g
s
.34582 .64097 m .34742 .69733 L .36117 .69082 L p .707 .577 .707 r
F P
0 g
s
.36117 .69082 m .35957 .63446 L .34582 .64097 L p .707 .577 .707 r
F P
0 g
s
.1891 .73264 m .18699 .76841 L .21204 .77691 L p .707 .577 .707 r
F P
0 g
s
.33326 .74213 m .33115 .77789 L .35093 .76976 L p .707 .577 .707 r
F P
0 g
s
.35093 .76976 m .35304 .734 L .33326 .74213 L p .707 .577 .707 r
F P
0 g
s
.37233 .80123 m .37233 .29934 L .35783 .28787 L p .707 .577 .707 r
F P
0 g
s
.37233 .29934 m .37233 .80123 L .39932 .81094 L p .707 .577 .707 r
F P
0 g
s
.18699 .76841 m .1891 .73264 L .17138 .72204 L p .707 .577 .707 r
F P
0 g
s
.16537 .64082 m .16697 .69718 L .18222 .70274 L p .707 .577 .707 r
F P
0 g
s
.66483 .63765 m .66845 .69263 L .63966 .69026 L p .707 .577 .707 r
F P
0 g
s
.63966 .69026 m .63603 .63529 L .66483 .63765 L p .707 .577 .707 r
F P
0 g
s
.62935 .29846 m .62935 .80035 L .64275 .78878 L p .707 .577 .707 r
F P
0 g
s
.64275 .78878 m .64275 .28689 L .62935 .29846 L p .707 .577 .707 r
F P
0 g
s
.24223 .83481 m .24504 .81837 L .21492 .80962 L p .707 .577 .707 r
F P
0 g
s
.24504 .81837 m .24223 .83481 L .27386 .83878 L p .707 .577 .707 r
F P
0 g
s
.27386 .83878 m .27666 .82234 L .24504 .81837 L p .707 .577 .707 r
F P
0 g
s
.27666 .82234 m .27386 .83878 L .3039 .83758 L p .707 .577 .707 r
F P
0 g
s
.3039 .83758 m .3067 .82114 L .27666 .82234 L p .707 .577 .707 r
F P
0 g
s
.69058 .83067 m .68452 .84885 L .66676 .84067 L p .707 .577 .707 r
F P
0 g
s
.66676 .84067 m .67281 .82249 L .69058 .83067 L p .707 .577 .707 r
F P
0 g
s
.21212 .82606 m .21492 .80962 L .18927 .79694 L p .707 .577 .707 r
F P
0 g
s
.21492 .80962 m .21212 .82606 L .24223 .83481 L p .707 .577 .707 r
F P
0 g
s
.17138 .72204 m .16927 .75781 L .18699 .76841 L p .707 .577 .707 r
F P
0 g
s
.16697 .69718 m .16537 .64082 L .15954 .6343 L p .707 .577 .707 r
F P
0 g
s
.3067 .82114 m .3039 .83758 L .32942 .83133 L p .707 .577 .707 r
F P
0 g
s
.32942 .83133 m .33222 .81489 L .3067 .82114 L p .707 .577 .707 r
F P
0 g
s
.6871 .73926 m .68242 .77663 L .65754 .7696 L p .707 .577 .707 r
F P
0 g
s
.65754 .7696 m .66222 .73222 L .6871 .73926 L p .707 .577 .707 r
F P
0 g
s
.18927 .79694 m .18647 .81339 L .21212 .82606 L p .707 .577 .707 r
F P
0 g
s
.35957 .63446 m .36117 .69082 L .36534 .68396 L p .707 .577 .707 r
F P
0 g
s
.36534 .68396 m .36374 .62761 L .35957 .63446 L p .707 .577 .707 r
F P
0 g
s
.35304 .734 m .35093 .76976 L .36199 .7594 L p .707 .577 .707 r
F P
0 g
s
.36199 .7594 m .36411 .72364 L .35304 .734 L p .707 .577 .707 r
F P
0 g
s
.18647 .81339 m .18927 .79694 L .17059 .78158 L p .707 .577 .707 r
F P
0 g
s
.16927 .75781 m .17138 .72204 L .16274 .71039 L p .707 .577 .707 r
F P
0 g
s
.15954 .6343 m .16114 .69065 L .16697 .69718 L p .707 .577 .707 r
F P
0 g
s
.17059 .78158 m .16778 .79803 L .18647 .81339 L p .707 .577 .707 r
F P
0 g
s
.67281 .82249 m .66676 .84067 L .64226 .8309 L p .707 .577 .707 r
F P
0 g
s
.64226 .8309 m .64832 .81271 L .67281 .82249 L p .707 .577 .707 r
F P
0 g
s
.33222 .81489 m .32942 .83133 L .34791 .82064 L p .707 .577 .707 r
F P
0 g
s
.34791 .82064 m .35072 .8042 L .33222 .81489 L p .707 .577 .707 r
F P
0 g
s
.16274 .71039 m .16063 .74615 L .16927 .75781 L p .707 .577 .707 r
F P
0 g
s
.36411 .72364 m .36199 .7594 L .36327 .74783 L p .707 .577 .707 r
F P
0 g
s
.36327 .74783 m .36538 .71206 L .36411 .72364 L p .707 .577 .707 r
F P
0 g
s
.36538 .71206 m .36327 .74783 L .35462 .73617 L p .707 .577 .707 r
F P
0 g
s
.35462 .73617 m .35674 .70041 L .36538 .71206 L p .707 .577 .707 r
F P
0 g
s
.35791 .62108 m .35952 .67744 L .34427 .67188 L p .707 .577 .707 r
F P
0 g
s
.34427 .67188 m .34266 .61552 L .35791 .62108 L p .707 .577 .707 r
F P
0 g
s
.36026 .77401 m .36038 .79011 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35746 .79046 m .35856 .78401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35856 .78401 m .36026 .77401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35725 .27577 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36026 .77401 m .35746 .79046 L .34758 .77392 L p .707 .577 .707 r
F P
0 g
s
.34758 .77392 m .35038 .75747 L .36026 .77401 L p .707 .577 .707 r
F P
0 g
s
.35783 .78976 m .35783 .75807 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.35783 .75807 m .35783 .28787 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36374 .62761 m .36534 .68396 L .35952 .67744 L p .707 .577 .707 r
F P
0 g
s
.35952 .67744 m .35791 .62108 L .36374 .62761 L p .707 .577 .707 r
F P
0 g
s
.35757 .80656 m .36038 .79011 L .35072 .8042 L p .707 .577 .707 r
F P
0 g
s
.36038 .79011 m .35757 .80656 L .35746 .79046 L p .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35783 .78976 L .37233 .80123 L p .707 .577 .707 r
F P
0 g
s
.64275 .28689 m .64275 .78878 L .64217 .77667 L p .708 .578 .707 r
F P
0 g
s
.64217 .77667 m .64217 .27478 L .64275 .28689 L p .708 .578 .707 r
F P
0 g
s
.16778 .79803 m .17059 .78158 L .16071 .76505 L p .707 .577 .707 r
F P
0 g
s
.16114 .69065 m .15954 .6343 L .16371 .62744 L p .707 .577 .707 r
F P
0 g
s
.64832 .81271 m .64226 .8309 L .61343 .82049 L p .707 .577 .707 r
F P
0 g
s
.16063 .74615 m .16274 .71039 L .16401 .69881 L p .707 .577 .707 r
F P
0 g
s
.16071 .76505 m .1579 .78149 L .16778 .79803 L p .707 .577 .707 r
F P
0 g
s
.35072 .8042 m .34791 .82064 L .35757 .80656 L p .707 .577 .707 r
F P
0 g
s
.16371 .62744 m .16531 .6838 L .16114 .69065 L p .707 .577 .707 r
F P
0 g
s
.16401 .69881 m .1619 .73458 L .16063 .74615 L p .707 .577 .707 r
F P
0 g
s
.1579 .78149 m .16071 .76505 L .16059 .74895 L p .707 .577 .707 r
F P
0 g
s
.16531 .6838 m .16371 .62744 L .17746 .62093 L p .707 .577 .707 r
F P
0 g
s
.16059 .74895 m .15779 .76539 L .1579 .78149 L p .707 .577 .707 r
F P
0 g
s
.35725 .27577 m .35725 .77766 L .35783 .78976 L p .708 .578 .707 r
F P
0 g
s
.35725 .77766 m .35725 .27577 L .37064 .2642 L p .707 .577 .707 r
F P
0 g
s
.1619 .73458 m .16401 .69881 L .17508 .68845 L p .707 .577 .707 r
F P
0 g
s
.64217 .27478 m .64217 .77667 L .62767 .76521 L p .707 .577 .707 r
F P
0 g
s
.62767 .76521 m .62767 .26332 L .64217 .27478 L p .707 .577 .707 r
F P
0 g
s
.17746 .62093 m .17907 .67729 L .16531 .6838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17508 .68845 m .17297 .72422 L .1619 .73458 L p .707 .577 .707 r
F P
0 g
s
.15779 .76539 m .16059 .74895 L .17025 .73486 L p .707 .577 .707 r
F P
0 g
s
.17907 .67729 m .17746 .62093 L .19946 .6154 L p .707 .577 .707 r
F P
0 g
s
.17025 .73486 m .16745 .7513 L .15779 .76539 L p .707 .577 .707 r
F P
0 g
s
.35674 .70041 m .35462 .73617 L .33691 .72558 L p .707 .577 .707 r
F P
0 g
s
.33691 .72558 m .33902 .68981 L .35674 .70041 L p .707 .577 .707 r
F P
0 g
s
.34266 .61552 m .34427 .67188 L .32108 .66783 L p .707 .577 .707 r
F P
0 g
s
.32108 .66783 m .31948 .61147 L .34266 .61552 L p .707 .577 .707 r
F P
0 g
s
.17297 .72422 m .17508 .68845 L .19486 .68032 L p .707 .577 .707 r
F P
0 g
s
.19946 .6154 m .20106 .67176 L .17907 .67729 L p .707 .577 .707 r
F P
0 g
s
.37064 .76609 m .37064 .2642 L .3967 .25431 L p .707 .577 .707 r
F P
0 g
s
.37064 .2642 m .37064 .76609 L .35725 .77766 L p .707 .577 .707 r
F P
0 g
s
.16745 .7513 m .17025 .73486 L .18875 .72417 L p .707 .577 .707 r
F P
0 g
s
.19486 .68032 m .19275 .71609 L .17297 .72422 L p .707 .577 .707 r
F P
0 g
s
.62767 .26332 m .62767 .76521 L .60068 .7555 L p .707 .577 .707 r
F P
0 g
s
.60068 .7555 m .60068 .25361 L .62767 .26332 L p .707 .577 .707 r
F P
0 g
s
.20106 .67176 m .19946 .6154 L .22754 .6114 L p .707 .577 .707 r
F P
0 g
s
.31948 .61147 m .32108 .66783 L .29224 .66569 L p .707 .577 .707 r
F P
0 g
s
.29224 .66569 m .29064 .60933 L .31948 .61147 L p .707 .577 .707 r
F P
0 g
s
.33902 .68981 m .33691 .72558 L .31186 .71707 L p .707 .577 .707 r
F P
0 g
s
.31186 .71707 m .31397 .68131 L .33902 .68981 L p .707 .577 .707 r
F P
0 g
s
.18875 .72417 m .18594 .74061 L .16745 .7513 L p .707 .577 .707 r
F P
0 g
s
.19275 .71609 m .19486 .68032 L .22141 .67522 L p .707 .577 .707 r
F P
0 g
s
.35038 .75747 m .34758 .77392 L .32889 .75856 L p .707 .577 .707 r
F P
0 g
s
.32889 .75856 m .3317 .74212 L .35038 .75747 L p .707 .577 .707 r
F P
0 g
s
.22754 .6114 m .22914 .66775 L .20106 .67176 L p .707 .577 .707 r
F P
0 g
s
.22914 .66775 m .22754 .6114 L .25896 .6093 L p .707 .577 .707 r
F P
0 g
s
.29064 .60933 m .29224 .66569 L .26056 .66566 L p .707 .577 .707 r
F P
0 g
s
.26056 .66566 m .25896 .6093 L .29064 .60933 L p .707 .577 .707 r
F P
0 g
s
.18594 .74061 m .18875 .72417 L .21427 .71792 L p .707 .577 .707 r
F P
0 g
s
.22141 .67522 m .2193 .71098 L .19275 .71609 L p .707 .577 .707 r
F P
0 g
s
.25896 .6093 m .26056 .66566 L .22914 .66775 L p .707 .577 .707 r
F P
0 g
s
.31397 .68131 m .31186 .71707 L .28192 .7115 L p .707 .577 .707 r
F P
0 g
s
.28192 .7115 m .28403 .67573 L .31397 .68131 L p .707 .577 .707 r
F P
0 g
s
.2193 .71098 m .22141 .67522 L .25214 .67363 L p .707 .577 .707 r
F P
0 g
s
.21427 .71792 m .21146 .73436 L .18594 .74061 L p .707 .577 .707 r
F P
0 g
s
.73944 .66108 m .74104 .60649 L .70936 .60431 L p .707 .577 .707 r
F P
0 g
s
.74104 .60649 m .73944 .66108 L .77086 .66002 L p .707 .577 .707 r
F P
0 g
s
.77086 .66002 m .77246 .60544 L .74104 .60649 L p .707 .577 .707 r
F P
0 g
s
.3317 .74212 m .32889 .75856 L .30324 .74588 L p .707 .577 .707 r
F P
0 g
s
.30324 .74588 m .30605 .72944 L .3317 .74212 L p .707 .577 .707 r
F P
0 g
s
.3967 .25431 m .3967 .7562 L .37064 .76609 L p .707 .577 .707 r
F P
0 g
s
.3967 .7562 m .3967 .25431 L .43287 .24707 L p .707 .577 .707 r
F P
0 g
s
.28403 .67573 m .28192 .7115 L .25002 .7094 L p .707 .577 .707 r
F P
0 g
s
.25002 .7094 m .25214 .67363 L .28403 .67573 L p .707 .577 .707 r
F P
0 g
s
.25214 .67363 m .25002 .7094 L .2193 .71098 L p .707 .577 .707 r
F P
0 g
s
.60068 .25361 m .60068 .7555 L .56383 .74851 L p .707 .577 .707 r
F P
0 g
s
.56383 .74851 m .56383 .24662 L .60068 .25361 L p .707 .577 .707 r
F P
0 g
s
.70776 .6589 m .70936 .60431 L .68052 .59911 L p .707 .577 .707 r
F P
0 g
s
.70936 .60431 m .70776 .6589 L .73944 .66108 L p .707 .577 .707 r
F P
0 g
s
.77246 .60544 m .77086 .66002 L .79894 .65583 L p .707 .577 .707 r
F P
0 g
s
.79894 .65583 m .80054 .60125 L .77246 .60544 L p .707 .577 .707 r
F P
0 g
s
.21146 .73436 m .21427 .71792 L .24431 .71672 L p .707 .577 .707 r
F P
0 g
s
.30605 .72944 m .30324 .74588 L .27313 .73713 L p .707 .577 .707 r
F P
0 g
s
.27313 .73713 m .27593 .72069 L .30605 .72944 L p .707 .577 .707 r
F P
0 g
s
.67891 .65369 m .68052 .59911 L .65734 .59139 L p .707 .577 .707 r
F P
0 g
s
.68052 .59911 m .67891 .65369 L .70776 .6589 L p .707 .577 .707 r
F P
0 g
s
.24431 .71672 m .2415 .73316 L .21146 .73436 L p .707 .577 .707 r
F P
0 g
s
.2415 .73316 m .24431 .71672 L .27593 .72069 L p .707 .577 .707 r
F P
0 g
s
.80054 .60125 m .79894 .65583 L .82093 .64892 L p .707 .577 .707 r
F P
0 g
s
.82093 .64892 m .82254 .59433 L .80054 .60125 L p .707 .577 .707 r
F P
0 g
s
.27593 .72069 m .27313 .73713 L .2415 .73316 L p .707 .577 .707 r
F P
0 g
s
.74997 .70547 m .74786 .66761 L .71597 .66913 L p .707 .577 .707 r
F P
0 g
s
.74786 .66761 m .74997 .70547 L .7807 .70233 L p .707 .577 .707 r
F P
0 g
s
.7807 .70233 m .77859 .66448 L .74786 .66761 L p .707 .577 .707 r
F P
0 g
s
.71808 .70698 m .71597 .66913 L .68603 .66887 L p .707 .577 .707 r
F P
0 g
s
.71597 .66913 m .71808 .70698 L .74997 .70547 L p .707 .577 .707 r
F P
0 g
s
.43287 .74896 m .43287 .24707 L .47561 .24318 L p .707 .577 .707 r
F P
0 g
s
.43287 .24707 m .43287 .74896 L .3967 .7562 L p .707 .577 .707 r
F P
0 g
s
.56383 .24662 m .56383 .74851 L .52073 .74492 L p .707 .577 .707 r
F P
0 g
s
.52073 .74492 m .52073 .24303 L .56383 .24662 L p .707 .577 .707 r
F P
0 g
s
.72687 .73695 m .72407 .71793 L .69395 .72221 L p .707 .577 .707 r
F P
0 g
s
.72407 .71793 m .72687 .73695 L .7585 .73229 L p .707 .577 .707 r
F P
0 g
s
.7585 .73229 m .75569 .71326 L .72407 .71793 L p .707 .577 .707 r
F P
0 g
s
.75569 .71326 m .7585 .73229 L .78854 .7277 L p .707 .577 .707 r
F P
0 g
s
.78854 .7277 m .78573 .70868 L .75569 .71326 L p .707 .577 .707 r
F P
0 g
s
.69395 .72221 m .69676 .74123 L .72687 .73695 L p .707 .577 .707 r
F P
0 g
s
.68603 .66887 m .68814 .70672 L .71808 .70698 L p .707 .577 .707 r
F P
0 g
s
.77859 .66448 m .7807 .70233 L .80725 .69789 L p .707 .577 .707 r
F P
0 g
s
.80725 .69789 m .80514 .66003 L .77859 .66448 L p .707 .577 .707 r
F P
0 g
s
.65734 .59139 m .65573 .64597 L .67891 .65369 L p .707 .577 .707 r
F P
0 g
s
.68814 .70672 m .68603 .66887 L .66098 .66687 L p .707 .577 .707 r
F P
0 g
s
.65573 .64597 m .65734 .59139 L .64209 .58191 L p .707 .577 .707 r
F P
0 g
s
.69676 .74123 m .69395 .72221 L .6683 .72569 L p .707 .577 .707 r
F P
0 g
s
.78573 .70868 m .78854 .7277 L .81405 .72364 L p .707 .577 .707 r
F P
0 g
s
.81405 .72364 m .81125 .70461 L .78573 .70868 L p .707 .577 .707 r
F P
0 g
s
.47561 .74507 m .47561 .24318 L .52073 .24303 L p .707 .577 .707 r
F P
0 g
s
.47561 .24318 m .47561 .74507 L .43287 .74896 L p .707 .577 .707 r
F P
0 g
s
.6683 .72569 m .6711 .74471 L .69676 .74123 L p .707 .577 .707 r
F P
0 g
s
.52073 .24303 m .52073 .74492 L .47561 .74507 L p .707 .577 .707 r
F P
0 g
s
.66098 .66687 m .66309 .70473 L .68814 .70672 L p .707 .577 .707 r
F P
0 g
s
.82254 .59433 m .82093 .64892 L .83469 .63995 L p .707 .577 .707 r
F P
0 g
s
.83469 .63995 m .83629 .58537 L .82254 .59433 L p .707 .577 .707 r
F P
0 g
s
.80514 .66003 m .80725 .69789 L .82703 .69256 L p .707 .577 .707 r
F P
0 g
s
.82703 .69256 m .82492 .65471 L .80514 .66003 L p .707 .577 .707 r
F P
0 g
s
.64209 .58191 m .64048 .6365 L .65573 .64597 L p .707 .577 .707 r
F P
0 g
s
.66309 .70473 m .66098 .66687 L .64326 .66333 L p .707 .577 .707 r
F P
0 g
s
.6711 .74471 m .6683 .72569 L .64962 .72803 L p .707 .577 .707 r
F P
0 g
s
.81125 .70461 m .81405 .72364 L .83255 .72049 L p .707 .577 .707 r
F P
0 g
s
.83255 .72049 m .82974 .70147 L .81125 .70461 L p .707 .577 .707 r
F P
0 g
s
.64962 .72803 m .65242 .74705 L .6711 .74471 L p .707 .577 .707 r
F P
0 g
s
.64326 .66333 m .64537 .70118 L .66309 .70473 L p .707 .577 .707 r
F P
0 g
s
.64048 .6365 m .64209 .58191 L .63626 .5716 L p .707 .577 .707 r
F P
0 g
s
.83629 .58537 m .83469 .63995 L .83885 .62982 L p .707 .577 .707 r
F P
0 g
s
.83885 .62982 m .84046 .57524 L .83629 .58537 L p .707 .577 .707 r
F P
0 g
s
.82492 .65471 m .82703 .69256 L .8381 .68688 L p .707 .577 .707 r
F P
0 g
s
.8381 .68688 m .83598 .64903 L .82492 .65471 L p .707 .577 .707 r
F P
0 g
s
.63626 .5716 m .63466 .62619 L .64048 .6365 L p .707 .577 .707 r
F P
0 g
s
.64537 .70118 m .64326 .66333 L .63462 .65858 L p .707 .577 .707 r
F P
0 g
s
.65242 .74705 m .64962 .72803 L .63973 .729 L p .707 .577 .707 r
F P
0 g
s
.82974 .70147 m .83255 .72049 L .84221 .71858 L p .707 .577 .707 r
F P
0 g
s
.84221 .71858 m .83941 .69956 L .82974 .70147 L p .707 .577 .707 r
F P
0 g
s
.63973 .729 m .64254 .74802 L .65242 .74705 L p .707 .577 .707 r
F P
0 g
s
.63462 .65858 m .63673 .69643 L .64537 .70118 L p .707 .577 .707 r
F P
0 g
s
.63466 .62619 m .63626 .5716 L .64043 .56147 L p .707 .577 .707 r
F P
0 g
s
.84046 .57524 m .83885 .62982 L .83303 .61952 L p .707 .577 .707 r
F P
0 g
s
.83303 .61952 m .83463 .56493 L .84046 .57524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83598 .64903 m .8381 .68688 L .83937 .6814 L p .707 .577 .707 r
F P
0 g
s
.83937 .6814 m .83726 .64355 L .83598 .64903 L p .707 .577 .707 r
F P
0 g
s
.64043 .56147 m .63882 .61606 L .63466 .62619 L p .707 .577 .707 r
F P
0 g
s
.63673 .69643 m .63462 .65858 L .63589 .6531 L p .707 .577 .707 r
F P
0 g
s
.64254 .74802 m .63973 .729 L .63962 .7285 L p .712 .581 .706 r
F P
0 g
s
.83941 .69956 m .84221 .71858 L .8421 .71809 L p .712 .581 .706 r
F P
0 g
s
.8421 .71809 m .83929 .69906 L .83941 .69956 L p .712 .581 .706 r
F P
0 g
s
.63962 .7285 m .64242 .74753 L .64254 .74802 L p .712 .581 .706 r
F P
0 g
s
.63589 .6531 m .63801 .69095 L .63673 .69643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63882 .61606 m .64043 .56147 L .65418 .55251 L p .707 .577 .707 r
F P
0 g
s
.39196 .6187 m .39559 .56278 L .36396 .55984 L p .707 .577 .707 r
F P
0 g
s
.39559 .56278 m .39196 .6187 L .42334 .61923 L p .707 .577 .707 r
F P
0 g
s
.42334 .61923 m .42696 .56331 L .39559 .56278 L p .707 .577 .707 r
F P
0 g
s
.36034 .61576 m .36396 .55984 L .33517 .55479 L p .707 .577 .707 r
F P
0 g
s
.36396 .55984 m .36034 .61576 L .39196 .6187 L p .707 .577 .707 r
F P
0 g
s
.83463 .56493 m .83303 .61952 L .81778 .61004 L p .707 .577 .707 r
F P
0 g
s
.81778 .61004 m .81938 .55546 L .83463 .56493 L p .707 .577 .707 r
F P
0 g
s
.42696 .56331 m .42334 .61923 L .45138 .6173 L p .707 .577 .707 r
F P
0 g
s
.45138 .6173 m .45501 .56138 L .42696 .56331 L p .707 .577 .707 r
F P
0 g
s
.83726 .64355 m .83937 .6814 L .83073 .67665 L p .707 .577 .707 r
F P
0 g
s
.83073 .67665 m .82862 .6388 L .83726 .64355 L p .707 .577 .707 r
F P
0 g
s
.33154 .61071 m .33517 .55479 L .31204 .54812 L p .707 .577 .707 r
F P
0 g
s
.33517 .55479 m .33154 .61071 L .36034 .61576 L p .707 .577 .707 r
F P
0 g
s
.65418 .55251 m .65258 .6071 L .63882 .61606 L p .707 .577 .707 r
F P
0 g
s
.63801 .69095 m .63589 .6531 L .64696 .64742 L p .707 .577 .707 r
F P
0 g
s
.45501 .56138 m .45138 .6173 L .47335 .61311 L p .707 .577 .707 r
F P
0 g
s
.47335 .61311 m .47698 .55719 L .45501 .56138 L p .707 .577 .707 r
F P
0 g
s
.40391 .68623 m .39923 .65021 L .36753 .65343 L p .707 .577 .707 r
F P
0 g
s
.39923 .65021 m .40391 .68623 L .43446 .67985 L p .707 .577 .707 r
F P
0 g
s
.43446 .67985 m .42979 .64382 L .39923 .65021 L p .707 .577 .707 r
F P
0 g
s
.64242 .74753 m .63962 .7285 L .64928 .72659 L p .707 .577 .707 r
F P
0 g
s
.83929 .69906 m .8421 .71809 L .83222 .71906 L p .707 .577 .707 r
F P
0 g
s
.83222 .71906 m .82941 .70003 L .83929 .69906 L p .707 .577 .707 r
F P
0 g
s
.64928 .72659 m .65209 .74562 L .64242 .74753 L p .707 .577 .707 r
F P
0 g
s
.3722 .68946 m .36753 .65343 L .33778 .65319 L p .707 .577 .707 r
F P
0 g
s
.36753 .65343 m .3722 .68946 L .40391 .68623 L p .707 .577 .707 r
F P
0 g
s
.64696 .64742 m .64907 .68527 L .63801 .69095 L p .707 .577 .707 r
F P
0 g
s
.65258 .6071 m .65418 .55251 L .67617 .5456 L p .707 .577 .707 r
F P
0 g
s
.42979 .64382 m .43446 .67985 L .46088 .67093 L p .707 .577 .707 r
F P
0 g
s
.46088 .67093 m .4562 .6349 L .42979 .64382 L p .707 .577 .707 r
F P
0 g
s
.31204 .54812 m .30841 .60404 L .33154 .61071 L p .707 .577 .707 r
F P
0 g
s
.81938 .55546 m .81778 .61004 L .7946 .60232 L p .707 .577 .707 r
F P
0 g
s
.7946 .60232 m .7962 .54774 L .81938 .55546 L p .707 .577 .707 r
F P
0 g
s
.34246 .68921 m .33778 .65319 L .3129 .64949 L p .707 .577 .707 r
F P
0 g
s
.33778 .65319 m .34246 .68921 L .3722 .68946 L p .707 .577 .707 r
F P
0 g
s
.30841 .60404 m .31204 .54812 L .29682 .54048 L p .707 .577 .707 r
F P
0 g
s
.82862 .6388 m .83073 .67665 L .81301 .6731 L p .707 .577 .707 r
F P
0 g
s
.81301 .6731 m .8109 .63525 L .82862 .6388 L p .707 .577 .707 r
F P
0 g
s
.47698 .55719 m .47335 .61311 L .48709 .60706 L p .707 .577 .707 r
F P
0 g
s
.48709 .60706 m .49072 .55114 L .47698 .55719 L p .707 .577 .707 r
F P
0 g
s
.4562 .6349 m .46088 .67093 L .48057 .66035 L p .707 .577 .707 r
F P
0 g
s
.48057 .66035 m .47589 .62433 L .4562 .6349 L p .707 .577 .707 r
F P
0 g
s
.67617 .5456 m .67457 .60018 L .65258 .6071 L p .707 .577 .707 r
F P
0 g
s
.41691 .73404 m .41085 .71764 L .38051 .72664 L p .707 .577 .707 r
F P
0 g
s
.41085 .71764 m .41691 .73404 L .44579 .72114 L p .707 .577 .707 r
F P
0 g
s
.44579 .72114 m .43974 .70474 L .41085 .71764 L p .707 .577 .707 r
F P
0 g
s
.67457 .60018 m .67617 .5456 L .70426 .54141 L p .707 .577 .707 r
F P
0 g
s
.3129 .64949 m .31757 .68551 L .34246 .68921 L p .707 .577 .707 r
F P
0 g
s
.64907 .68527 m .64696 .64742 L .66674 .64209 L p .707 .577 .707 r
F P
0 g
s
.38656 .74305 m .38051 .72664 L .35168 .73086 L p .707 .577 .707 r
F P
0 g
s
.38051 .72664 m .38656 .74305 L .41691 .73404 L p .707 .577 .707 r
F P
0 g
s
.43974 .70474 m .44579 .72114 L .47039 .7056 L p .707 .577 .707 r
F P
0 g
s
.47039 .7056 m .46434 .6892 L .43974 .70474 L p .707 .577 .707 r
F P
0 g
s
.29682 .54048 m .2932 .5964 L .30841 .60404 L p .707 .577 .707 r
F P
0 g
s
.7962 .54774 m .7946 .60232 L .76575 .59711 L p .707 .577 .707 r
F P
0 g
s
.76575 .59711 m .76736 .54253 L .7962 .54774 L p .707 .577 .707 r
F P
0 g
s
.65209 .74562 m .64928 .72659 L .66778 .72345 L p .707 .577 .707 r
F P
0 g
s
.82941 .70003 m .83222 .71906 L .81353 .7214 L p .707 .577 .707 r
F P
0 g
s
.81353 .7214 m .81073 .70237 L .82941 .70003 L p .707 .577 .707 r
F P
0 g
s
.66778 .72345 m .67058 .74247 L .65209 .74562 L p .707 .577 .707 r
F P
0 g
s
.66674 .64209 m .66885 .67994 L .64907 .68527 L p .707 .577 .707 r
F P
0 g
s
.31757 .68551 m .3129 .64949 L .29532 .64271 L p .707 .577 .707 r
F P
0 g
s
.35168 .73086 m .35773 .74727 L .38656 .74305 L p .707 .577 .707 r
F P
0 g
s
.70265 .59599 m .70426 .54141 L .73567 .54035 L p .707 .577 .707 r
F P
0 g
s
.70426 .54141 m .70265 .59599 L .67457 .60018 L p .707 .577 .707 r
F P
0 g
s
.35773 .74727 m .35168 .73086 L .32719 .72989 L p .707 .577 .707 r
F P
0 g
s
.46434 .6892 m .47039 .7056 L .4883 .68895 L p .707 .577 .707 r
F P
0 g
s
.4883 .68895 m .48224 .67255 L .46434 .6892 L p .707 .577 .707 r
F P
0 g
s
.2932 .5964 m .29682 .54048 L .29102 .53261 L p .707 .577 .707 r
F P
0 g
s
.76736 .54253 m .76575 .59711 L .73407 .59493 L p .707 .577 .707 r
F P
0 g
s
.73407 .59493 m .73567 .54035 L .76736 .54253 L p .707 .577 .707 r
F P
0 g
s
.8109 .63525 m .81301 .6731 L .78796 .67111 L p .707 .577 .707 r
F P
0 g
s
.78796 .67111 m .78585 .63325 L .8109 .63525 L p .707 .577 .707 r
F P
0 g
s
.47589 .62433 m .48057 .66035 L .4916 .64915 L p .707 .577 .707 r
F P
0 g
s
.4916 .64915 m .48693 .61312 L .47589 .62433 L p .707 .577 .707 r
F P
0 g
s
.29532 .64271 m .29999 .67873 L .31757 .68551 L p .707 .577 .707 r
F P
0 g
s
.73567 .54035 m .73407 .59493 L .70265 .59599 L p .707 .577 .707 r
F P
0 g
s
.32719 .72989 m .33324 .74629 L .35773 .74727 L p .707 .577 .707 r
F P
0 g
s
.49072 .55114 m .48709 .60706 L .49127 .59974 L p .707 .577 .707 r
F P
0 g
s
.49127 .59974 m .4949 .54383 L .49072 .55114 L p .707 .577 .707 r
F P
0 g
s
.66885 .67994 m .66674 .64209 L .69329 .63764 L p .707 .577 .707 r
F P
0 g
s
.29102 .53261 m .28739 .58853 L .2932 .5964 L p .707 .577 .707 r
F P
0 g
s
.67058 .74247 m .66778 .72345 L .6933 .71939 L p .707 .577 .707 r
F P
0 g
s
.81073 .70237 m .81353 .7214 L .78788 .72488 L p .707 .577 .707 r
F P
0 g
s
.78788 .72488 m .78508 .70585 L .81073 .70237 L p .707 .577 .707 r
F P
0 g
s
.6933 .71939 m .6961 .73841 L .67058 .74247 L p .707 .577 .707 r
F P
0 g
s
.69329 .63764 m .6954 .6755 L .66885 .67994 L p .707 .577 .707 r
F P
0 g
s
.29999 .67873 m .29532 .64271 L .28676 .6335 L p .707 .577 .707 r
F P
0 g
s
.33324 .74629 m .32719 .72989 L .30942 .72381 L p .707 .577 .707 r
F P
0 g
s
.48224 .67255 m .4883 .68895 L .49776 .67281 L p .707 .577 .707 r
F P
0 g
s
.49776 .67281 m .4917 .65641 L .48224 .67255 L p .707 .577 .707 r
F P
0 g
s
.78585 .63325 m .78796 .67111 L .75802 .67085 L p .707 .577 .707 r
F P
0 g
s
.75802 .67085 m .75591 .633 L .78585 .63325 L p .707 .577 .707 r
F P
0 g
s
.6954 .6755 m .69329 .63764 L .72402 .63451 L p .707 .577 .707 r
F P
0 g
s
.30942 .72381 m .31547 .74022 L .33324 .74629 L p .707 .577 .707 r
F P
0 g
s
.28676 .6335 m .29144 .66952 L .29999 .67873 L p .707 .577 .707 r
F P
0 g
s
.28739 .58853 m .29102 .53261 L .2952 .5253 L p .707 .577 .707 r
F P
0 g
s
.48693 .61312 m .4916 .64915 L .49291 .63842 L p .707 .577 .707 r
F P
0 g
s
.49291 .63842 m .48824 .60239 L .48693 .61312 L p .707 .577 .707 r
F P
0 g
s
.72402 .63451 m .72613 .67236 L .6954 .6755 L p .707 .577 .707 r
F P
0 g
s
.75591 .633 m .75802 .67085 L .72613 .67236 L p .707 .577 .707 r
F P
0 g
s
.72613 .67236 m .72402 .63451 L .75591 .633 L p .707 .577 .707 r
F P
0 g
s
.6961 .73841 m .6933 .71939 L .72334 .7148 L p .707 .577 .707 r
F P
0 g
s
.78508 .70585 m .78788 .72488 L .75777 .72916 L p .707 .577 .707 r
F P
0 g
s
.75777 .72916 m .75496 .71013 L .78508 .70585 L p .707 .577 .707 r
F P
0 g
s
.72334 .7148 m .72614 .73382 L .6961 .73841 L p .707 .577 .707 r
F P
0 g
s
.4949 .54383 m .49127 .59974 L .48547 .59188 L p .707 .577 .707 r
F P
0 g
s
.48547 .59188 m .4891 .53596 L .4949 .54383 L p .707 .577 .707 r
F P
0 g
s
.2952 .5253 m .29157 .58122 L .28739 .58853 L p .707 .577 .707 r
F P
0 g
s
.72614 .73382 m .72334 .7148 L .75496 .71013 L p .707 .577 .707 r
F P
0 g
s
.75496 .71013 m .75777 .72916 L .72614 .73382 L p .707 .577 .707 r
F P
0 g
s
.31547 .74022 m .30942 .72381 L .30013 .71324 L p .707 .577 .707 r
F P
0 g
s
.4917 .65641 m .49776 .67281 L .49784 .65877 L p .707 .577 .707 r
F P
0 g
s
.49784 .65877 m .49179 .64236 L .4917 .65641 L p .707 .577 .707 r
F P
0 g
s
.29144 .66952 m .28676 .6335 L .28807 .62276 L p .707 .577 .707 r
F P
0 g
s
.30013 .71324 m .30618 .72964 L .31547 .74022 L p .707 .577 .707 r
F P
0 g
s
.28807 .62276 m .29274 .65879 L .29144 .66952 L p .707 .577 .707 r
F P
0 g
s
.48824 .60239 m .49291 .63842 L .48435 .62921 L p .707 .577 .707 r
F P
0 g
s
.48435 .62921 m .47968 .59318 L .48824 .60239 L p .707 .577 .707 r
F P
0 g
s
.29157 .58122 m .2952 .5253 L .30894 .51925 L p .707 .577 .707 r
F P
0 g
s
.4891 .53596 m .48547 .59188 L .47026 .58424 L p .707 .577 .707 r
F P
0 g
s
.47026 .58424 m .47388 .52832 L .4891 .53596 L p .707 .577 .707 r
F P
0 g
s
.30618 .72964 m .30013 .71324 L .30022 .69919 L p .707 .577 .707 r
F P
0 g
s
.49179 .64236 m .49784 .65877 L .48855 .64819 L p .707 .577 .707 r
F P
0 g
s
.48855 .64819 m .4825 .63178 L .49179 .64236 L p .707 .577 .707 r
F P
0 g
s
.30894 .51925 m .30532 .57517 L .29157 .58122 L p .707 .577 .707 r
F P
0 g
s
.29274 .65879 m .28807 .62276 L .29911 .61156 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30022 .69919 m .30627 .7156 L .30618 .72964 L p .707 .577 .707 r
F P
0 g
s
.30532 .57517 m .30894 .51925 L .33091 .51506 L p .707 .577 .707 r
F P
0 g
s
.29911 .61156 m .30378 .64759 L .29274 .65879 L p .707 .577 .707 r
F P
0 g
s
.47968 .59318 m .48435 .62921 L .46677 .62242 L p .707 .577 .707 r
F P
0 g
s
.46677 .62242 m .4621 .5864 L .47968 .59318 L p .707 .577 .707 r
F P
0 g
s
.47388 .52832 m .47026 .58424 L .44712 .57757 L p .707 .577 .707 r
F P
0 g
s
.44712 .57757 m .45075 .52165 L .47388 .52832 L p .707 .577 .707 r
F P
0 g
s
.30627 .7156 m .30022 .69919 L .30968 .68305 L p .707 .577 .707 r
F P
0 g
s
.4825 .63178 m .48855 .64819 L .47079 .64212 L p .707 .577 .707 r
F P
0 g
s
.47079 .64212 m .46473 .62571 L .4825 .63178 L p .707 .577 .707 r
F P
0 g
s
.33091 .51506 m .32729 .57098 L .30532 .57517 L p .707 .577 .707 r
F P
0 g
s
.30378 .64759 m .29911 .61156 L .3188 .60098 L p .707 .577 .707 r
F P
0 g
s
.30968 .68305 m .31573 .69946 L .30627 .7156 L p .707 .577 .707 r
F P
0 g
s
.32729 .57098 m .33091 .51506 L .35896 .51313 L p .707 .577 .707 r
F P
0 g
s
.4621 .5864 m .46677 .62242 L .44189 .61872 L p .707 .577 .707 r
F P
0 g
s
.44189 .61872 m .43722 .5827 L .4621 .5864 L p .707 .577 .707 r
F P
0 g
s
.45075 .52165 m .44712 .57757 L .41833 .57251 L p .707 .577 .707 r
F P
0 g
s
.41833 .57251 m .42196 .5166 L .45075 .52165 L p .707 .577 .707 r
F P
0 g
s
.3188 .60098 m .32347 .63701 L .30378 .64759 L p .707 .577 .707 r
F P
0 g
s
.35896 .51313 m .35533 .56905 L .32729 .57098 L p .707 .577 .707 r
F P
0 g
s
.35533 .56905 m .35896 .51313 L .39033 .51366 L p .707 .577 .707 r
F P
0 g
s
.32347 .63701 m .3188 .60098 L .34521 .59206 L p .707 .577 .707 r
F P
0 g
s
.31573 .69946 m .30968 .68305 L .32758 .6664 L p .707 .577 .707 r
F P
0 g
s
.46473 .62571 m .47079 .64212 L .44629 .64115 L p .707 .577 .707 r
F P
0 g
s
.44629 .64115 m .44024 .62474 L .46473 .62571 L p .707 .577 .707 r
F P
0 g
s
.42196 .5166 m .41833 .57251 L .3867 .56958 L p .707 .577 .707 r
F P
0 g
s
.3867 .56958 m .39033 .51366 L .42196 .5166 L p .707 .577 .707 r
F P
0 g
s
.39033 .51366 m .3867 .56958 L .35533 .56905 L p .707 .577 .707 r
F P
0 g
s
.43722 .5827 m .44189 .61872 L .41214 .61848 L p .707 .577 .707 r
F P
0 g
s
.41214 .61848 m .40747 .58245 L .43722 .5827 L p .707 .577 .707 r
F P
0 g
s
.32758 .6664 m .33363 .68281 L .31573 .69946 L p .707 .577 .707 r
F P
0 g
s
.34521 .59206 m .34989 .62809 L .32347 .63701 L p .707 .577 .707 r
F P
0 g
s
.34989 .62809 m .34521 .59206 L .37577 .58568 L p .707 .577 .707 r
F P
0 g
s
.40747 .58245 m .41214 .61848 L .38044 .6217 L p .707 .577 .707 r
F P
0 g
s
.38044 .6217 m .37577 .58568 L .40747 .58245 L p .707 .577 .707 r
F P
0 g
s
.33363 .68281 m .32758 .6664 L .35218 .65086 L p .707 .577 .707 r
F P
0 g
s
.44024 .62474 m .44629 .64115 L .41746 .64537 L p .707 .577 .707 r
F P
0 g
s
.41746 .64537 m .41141 .62896 L .44024 .62474 L p .707 .577 .707 r
F P
0 g
s
.37577 .58568 m .38044 .6217 L .34989 .62809 L p .707 .577 .707 r
F P
0 g
s
.35218 .65086 m .35823 .66727 L .33363 .68281 L p .707 .577 .707 r
F P
0 g
s
.35823 .66727 m .35218 .65086 L .38107 .63796 L p .707 .577 .707 r
F P
0 g
s
.41141 .62896 m .41746 .64537 L .38712 .65437 L p .707 .577 .707 r
F P
0 g
s
.38712 .65437 m .38107 .63796 L .41141 .62896 L p .707 .577 .707 r
F P
0 g
s
.38107 .63796 m .38712 .65437 L .35823 .66727 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007=oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00Kgoo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001SOol70006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001KOol80003FUH01000FUIJEUYF400000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Egoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo0`001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol0059oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF000047oo3`00Agoo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
37oo100000=JEP00FUH01eYF00<005YFFUH00UYF2000?goo001BOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF000027oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Uoo`00DWoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000017oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Woo001BOol01@00FUIJEUYF00001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00=7oo001BOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
00001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
039oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080031oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF00<007ooOol0;Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0]Ool0055oo`8000=JEP04001JEUYFFUH80005FUH00`00FUIJEP06FUH0
0`00FUH000060006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Woo001AOol20003FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4
0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001A
Ool200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP@000AJEP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo
0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF4@0000IJEP00000005YF0003
FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF
00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P0000AJEP00FUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0059oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool005=oo`05001JEUYFFUH00005FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00UYF5`001UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool0
05Aoo`800004FUH005YFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000eYF00<005YFFUH00UYF1`002goo1@001Woo10000UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH0000^Ool005Ioo`D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUH000020003FUH01000FUIJEUYF2@00
0Woo1@002Goo1@001EYF00L005YFFUIJEP00FUH0000^Ool005Ioo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ0000EJEP@00003FUH005YF009JEP03001JEP0002ioo`00
?goo5`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF
00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0002ioo`00>goo100000=JEP00FUH01eYF
00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP00;Woo000fOol50005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0005FUH00`00FUIJEP02FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH400000eYF001oo`0]Ool0039oo`@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH90002FUH4
00000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002ioo`00<7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00IJEPh0009JEP03001JEP0000QJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<005YFFUH0
1P0015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00006FUH3
00000eYF001JEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00D005YFFUIJ
EP0000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUHQ0003FUH00`00Oomoo`0]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP8000AJEP05001JEUYFFUH0
0003FUH00`00FUIJEP020007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF10001eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00<00003FUH007oo02ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00`001EYF00D005YFFUIJEP0000=JEP@000UJ
EP03001JEUYF009JEP`000=JEP<000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH300000eYF001JEP060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<0009JEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH70006FUH00`00FUIJEP02FUH200000eYF0000
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH60005FUH01000FUIJEUYF0`001EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF001JEP00009JEP04001JEUYFFUH:0008FUH00`00FUH000020007FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002moo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH0
1EYF00<005YF00000P0025YF0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF0000;goo000]Ool00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH20002
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF0P001EYF
00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YF
000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH015YF4`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP800003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00EJEP<00006FUH005YFFUH005YF0P001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
;Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH20003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0004FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eo
o`03001JEP00009JEP04001JEUYFFUH60006FUH:0007FUH00`00FUH00003FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEP/000QJEP03001JEUYF
00=JEPL0009JEP03001JEP0002ioo`00;Goo00<005YF00000UYF10000eYF00<005YF00001`0015YF
00<005YFFUH00UYF2P0015YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP00008000MJEP<0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH01000FUIJEUYF200000=J
EP00FUH00eYF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000]Ool0
0`00FUH00002000015YF001JEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000=JEP00FUH00eYF10001eYF00<005YFFUH00eYF10001UYF10002EYF00H005YFFUH005YF
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF
FUIJEPL000QJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000^Ool002eoo`03001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP02FUH50002FUH40002
FUH00`00FUIJEP06FUH20004FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEP000UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo0`0000=JEP00000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF200015YF00<005YF
FUH00UYF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000UYF0P000UYF0P0000AJEP00FUIJEPh000QJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH300000eYF
00000003FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P00<goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEUYF00QJEP04001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00H005YF000005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006Ool2000^Ool002ioo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00001UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP04001J
EUYF0006FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=o
o`000000200000=JEP00Ool0;Goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP<000MJEP03001JEP0000aJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH>0004FUH00`00FUIJEP02FUH900000goo0000
00060003FUH00`00FUIJEP02FUH01000FUIJEP00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP800003FUH005YF00AJEP80009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00007FUH00`00FUIJ
EP04FUH00`00FUIJEP090003Ool70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF20002Goo200000=JEP00FUH00P001UYF00<0
05YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00007FUH00`00FUIJEP04FUH01000FUIJEUYF0P001Goo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;Woo00@005YFFUH000=JEPH000Ioo`T0
00Yoo`800004FUH000000005FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF
0P001UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP03FUH01000FUIJEUYF1`001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;Woo00D005YFFUH005YF0080
00Aoo`P000AJEP03001JEUYF009JEPH000Ioo`80009oo`8000=JEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00<000QJEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP080003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06000]Ool002ioo`03001JEUYF0080009o
o`@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000=oo`<000=oo`800003FUH0
05YF00=JEP8000=JEP03001JEUYF00=JEP@00003FUH005YF00MJEP8000QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH70003FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000cOol002ioo`03001J
EP0000D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<00003Ool005YF00<0
009oo`8000AJEP80009JEPL000IJEP03001JEUYF00=JEP8000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol002eoo`H0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP`000AJEP03001JEUYF00IJ
EP03001JEUYF00@000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP/003moo`00;Goo0P0000=JEP00FUH00UYF00<005YFFUH015YF3P0015YF00<005YFFUH01eYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEQ0004=oo`00;Goo10000eYF00<005YF
FUH010003Woo1P0025YF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH0000000H004Yoo`00
;Goo0P0000=JEP00FUH00UYF0`0015YF100047oo0`0015YF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03
001JEP0000X0059oo`00;Goo0`000UYF0P0000=JEP00FUH01EYF00<005YFFUH010003goo0`0000=J
EP00FUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH02EYF00<005YFFUH0
15YF60001UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00P0
0003FUH0000005Ioo`00;Goo00<005YF00000P000eYF00<005YFFUH015YF00<005YFFUH015YF5@00
1EYF3@001UYF00<005YFFUH01eYF20001UYF00<005YFFUH025YF00<005YF000015YF2@001eYF00<0
05YFFUH01EYF00@005YFFUIJEPH000MJEP04001JEUYFFUH2001DOol002eoo`04001JEP000004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJ
EP02000015YF001JEP000eYF00<005YFFUH015YF00<005YFFUH00eYF100000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YF00002eYF00<005YF000010000UYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP8005=oo`00;Goo100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00eYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YF00002eYF00<005YFFUH015YF10001UYF00D005YFFUIJEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00059oo`00;7oo0P000Woo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YF
00000eYF00<005YFFUH00eYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002eYF
00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF001BOol002aoo`8000=oo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEP0000<0009J
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJ
EP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH00007FUH00`00FUIJEP02FUH01000FUIJ
EP00DWoo000/Ool20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH20003FUH30003FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000
1eYF00<005YFFUH00UYF00@005YFFUH0059oo`00;7oo0`001Woo0P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF0080
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP80009JEPH000EJEP03001JEUYF00=JEP04001JEUYF001BOol002aoo`<0
00Qoo`@00003FUH005YF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH01@00FUH005YF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P000eYF00<0
05YF00000`0000=JEP00FUH015YF00@005YFFUH0059oo`00;7oo00@005YFFUH000]oo`<000IJEP03
001JEUYF00D00003FUH005YF00MJEP03001JEUYF00EJEP<00004Ool005YFFUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF0`000eYF00<005YFFUH0
0P00DWoo000/Ool01000FUIJEP003Woo10000UYF00<005YFFUH01@0000=JEP00FUH01eYF00<005YF
FUH00UYF100017oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
009JEP03001JEUYF00EJEP06001JEP00001JEP000UYF00<007ooOol0DGoo000/Ool01@00FUIJEUYF
00004Goo2P0000=JEP00FUH00eYF2@0027oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00Oomoo`1AOol0
02eoo`03001JEUYF008001Ioo`X0019oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001oo`1BOol002eoo`03001J
EP00009JEP80035oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YF000005=oo`00;Woo0P0015YF00<007ooOol0;Woo0P00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF001COol002moo`03001JEUYF00=JEP03001oogoo02aoo`H000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH0001COol0031oo`03001J
EUYF009JEP<002aoo`8000=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00001DOol0035oo`05001JEUYFFUH00002FUH2000YOol00`00FUH00005Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUIJEUYF1@0015YF00<005YFFUH01EYF00<005YFFUH01000EWoo000bOol200000eYF
001JEP03FUH2000UOol300000eYF001oo`06Ool300000eYF001JEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01`00FUH00000FUH005YF014005Yoo`00=7oo
0P001UYF0`0087oo0P000UYF0P002goo10001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH00UYF0`00IWoo000eOol20006FUH00`00FUH0
0003000JOol20003FUH2000@Ool50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060005FUH00`00FUIJEP05FUH3001SOol003Moo`8000=JEP03001JEUYF00AJEPL0
00moo`@00003FUH005YF009JEP8001Eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0009J
EP04001JEUYFFUH300000eYF001JEP08FUH00`00FUH00003001OOol003Uoo`800003FUH005YF00MJ
EP03001JEUYF009JEPl000EJEP05001JEUYFFUH0000OOolJ0003Ool20005FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP04FUH2001MOol003]oo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF008003moo`<00003FUH005YF00QJEP<000EJEP03001JEUYF00EJEP<0
05]oo`00?Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00A7oo0`00
25YF00<005YFFUH00`0000=JEP00FUH01UYF00@005YFFUIJEP8005Uoo`00@7oo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00eYF0P00BGoo0`0015YF00<005YFFUH015YF0`001UYF00<0
05YFFUH00eYF00<007ooOol0EWoo0013Ool60004FUH00`00FUIJEP06FUH00`00FUH00003001>Ool3
00000eYF001JEP07FUH30004FUH00`00FUIJEP03FUH3001FOol004Uoo`l005Eoo`<000MJEP03001J
EUYF00800003FUH005YF00AJEP04001JEUYF001FOol00;1oo`@0009JEP03001JEUYF00=JEP<000AJ
EP04001JEUYF001FOol00;Aoo`@000IJEP<00004FUH005YFFUH2001FOol00;Qoo`@00003FUH005YF
009JEP80009JEP03001oogoo05Eoo`00_7oo10000UYF1000Egoo0030Ool6001GOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6133 .75139 m .60967 .69641 L .57804 .69707 L p .707 .577 .707 r
F P
0 g
s
.60967 .69641 m .6133 .75139 L .64467 .74777 L p .707 .577 .707 r
F P
0 g
s
.64467 .74777 m .64104 .69279 L .60967 .69641 L p .707 .577 .707 r
F P
0 g
s
.58167 .75204 m .57804 .69707 L .54925 .6947 L p .707 .577 .707 r
F P
0 g
s
.57804 .69707 m .58167 .75204 L .6133 .75139 L p .707 .577 .707 r
F P
0 g
s
.64104 .69279 m .64467 .74777 L .67271 .74155 L p .707 .577 .707 r
F P
0 g
s
.67271 .74155 m .66908 .68657 L .64104 .69279 L p .707 .577 .707 r
F P
0 g
s
.55288 .74968 m .54925 .6947 L .52611 .68954 L p .707 .577 .707 r
F P
0 g
s
.54925 .6947 m .55288 .74968 L .58167 .75204 L p .707 .577 .707 r
F P
0 g
s
.66908 .68657 m .67271 .74155 L .69468 .73333 L p .707 .577 .707 r
F P
0 g
s
.69468 .73333 m .69105 .67835 L .66908 .68657 L p .707 .577 .707 r
F P
0 g
s
.61956 .80396 m .62423 .76658 L .59253 .76252 L p .707 .577 .707 r
F P
0 g
s
.62423 .76658 m .61956 .80396 L .65011 .80586 L p .707 .577 .707 r
F P
0 g
s
.65011 .80586 m .65479 .76849 L .62423 .76658 L p .707 .577 .707 r
F P
0 g
s
.58785 .79989 m .59253 .76252 L .56278 .75668 L p .707 .577 .707 r
F P
0 g
s
.59253 .76252 m .58785 .79989 L .61956 .80396 L p .707 .577 .707 r
F P
0 g
s
.56278 .75668 m .5581 .79406 L .58785 .79989 L p .707 .577 .707 r
F P
0 g
s
.65479 .76849 m .65011 .80586 L .67653 .80541 L p .707 .577 .707 r
F P
0 g
s
.67653 .80541 m .6812 .76804 L .65479 .76849 L p .707 .577 .707 r
F P
0 g
s
.5581 .79406 m .56278 .75668 L .5379 .74965 L p .707 .577 .707 r
F P
0 g
s
.58254 .82828 m .58859 .8101 L .55976 .79969 L p .707 .577 .707 r
F P
0 g
s
.58859 .8101 m .58254 .82828 L .61288 .83831 L p .707 .577 .707 r
F P
0 g
s
.61288 .83831 m .61893 .82013 L .58859 .8101 L p .707 .577 .707 r
F P
0 g
s
.52611 .68954 m .52974 .74452 L .55288 .74968 L p .707 .577 .707 r
F P
0 g
s
.61893 .82013 m .61288 .83831 L .64176 .84697 L p .707 .577 .707 r
F P
0 g
s
.64176 .84697 m .64782 .82879 L .61893 .82013 L p .707 .577 .707 r
F P
0 g
s
.55976 .79969 m .55371 .81787 L .58254 .82828 L p .707 .577 .707 r
F P
0 g
s
.52974 .74452 m .52611 .68954 L .5109 .6821 L p .707 .577 .707 r
F P
0 g
s
.69105 .67835 m .69468 .73333 L .70843 .72392 L p .707 .577 .707 r
F P
0 g
s
.70843 .72392 m .7048 .66894 L .69105 .67835 L p .707 .577 .707 r
F P
0 g
s
.5379 .74965 m .53322 .78702 L .5581 .79406 L p .707 .577 .707 r
F P
0 g
s
.55371 .81787 m .55976 .79969 L .53526 .78991 L p .707 .577 .707 r
F P
0 g
s
.53526 .78991 m .52921 .8081 L .55371 .81787 L p .707 .577 .707 r
F P
0 g
s
.64782 .82879 m .64176 .84697 L .66636 .85343 L p .707 .577 .707 r
F P
0 g
s
.66636 .85343 m .67241 .83525 L .64782 .82879 L p .707 .577 .707 r
F P
0 g
s
.6812 .76804 m .67653 .80541 L .69622 .80265 L p .707 .577 .707 r
F P
0 g
s
.69622 .80265 m .70089 .76528 L .6812 .76804 L p .707 .577 .707 r
F P
0 g
s
.53322 .78702 m .5379 .74965 L .52032 .74211 L p .707 .577 .707 r
F P
0 g
s
.5109 .6821 m .51453 .73707 L .52974 .74452 L p .707 .577 .707 r
F P
0 g
s
.52032 .74211 m .51564 .77948 L .53322 .78702 L p .707 .577 .707 r
F P
0 g
s
.52921 .8081 m .53526 .78991 L .5175 .78173 L p .707 .577 .707 r
F P
0 g
s
.5175 .78173 m .51145 .79992 L .52921 .8081 L p .707 .577 .707 r
F P
0 g
s
.67241 .83525 m .66636 .85343 L .68427 .85704 L p .707 .577 .707 r
F P
0 g
s
.68427 .85704 m .69032 .83886 L .67241 .83525 L p .707 .577 .707 r
F P
0 g
s
.51453 .73707 m .5109 .6821 L .5051 .67309 L p .707 .577 .707 r
F P
0 g
s
.7048 .66894 m .70843 .72392 L .7126 .71424 L p .707 .577 .707 r
F P
0 g
s
.7126 .71424 m .70897 .65926 L .7048 .66894 L p .707 .577 .707 r
F P
0 g
s
.70089 .76528 m .69622 .80265 L .70725 .79785 L p .707 .577 .707 r
F P
0 g
s
.70725 .79785 m .71193 .76048 L .70089 .76528 L p .707 .577 .707 r
F P
0 g
s
.51564 .77948 m .52032 .74211 L .51176 .73479 L p .707 .577 .707 r
F P
0 g
s
.51185 .73291 m .51453 .73707 L p .51271 .72476 L .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .50709 .77217 L .51564 .77948 L p .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .51307 .72843 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.50709 .77217 m .51097 .74111 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.51097 .74111 m .51176 .73479 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.5051 .67309 m .50873 .72807 L .51185 .73291 L p .707 .577 .707 r
F P
0 g
s
.51271 .72476 m .5051 .67309 L .51185 .73291 L .707 .577 .707 r
F
.51145 .79992 m .5175 .78173 L .50821 .77595 L p F P
0 g
s
.50821 .77595 m .50215 .79413 L .51145 .79992 L p .707 .577 .707 r
F P
0 g
s
.69032 .83886 m .68427 .85704 L .69373 .85745 L p .707 .577 .707 r
F P
0 g
s
.69373 .85745 m .69978 .83927 L .69032 .83886 L p .707 .577 .707 r
F P
0 g
s
.50873 .72807 m .5051 .67309 L .50928 .66341 L p .707 .577 .707 r
F P
0 g
s
.70897 .65926 m .7126 .71424 L .7068 .70523 L p .707 .577 .707 r
F P
0 g
s
.7068 .70523 m .70317 .65026 L .70897 .65926 L p .707 .577 .707 r
F P
0 g
s
.47927 .82152 m .47927 .31963 L .43617 .31604 L p .707 .577 .707 r
F P
0 g
s
.50928 .66341 m .5129 .71839 L .50873 .72807 L p .707 .577 .707 r
F P
0 g
s
.51307 .72843 m .50839 .7658 L .50709 .77217 L p .707 .577 .707 r
F P
0 g
s
.50215 .79413 m .50821 .77595 L .50829 .77313 L p .707 .578 .707 r
F P
0 g
s
.50829 .77313 m .50224 .79131 L .50215 .79413 L p .707 .578 .707 r
F P
0 g
s
.5129 .71839 m .50928 .66341 L .52302 .654 L p .707 .577 .707 r
F P
0 g
s
.50839 .7658 m .51307 .72843 L .5241 .72363 L p .707 .577 .707 r
F P
0 g
s
.52302 .654 m .52665 .70898 L .5129 .71839 L p .707 .577 .707 r
F P
0 g
s
.5241 .72363 m .51943 .761 L .50839 .7658 L p .707 .577 .707 r
F P
0 g
s
.50224 .79131 m .50829 .77313 L .51775 .77354 L p .707 .577 .707 r
F P
0 g
s
.51775 .77354 m .5117 .79172 L .50224 .79131 L p .707 .577 .707 r
F P
0 g
s
.5117 .79172 m .51775 .77354 L .53566 .77715 L p .707 .577 .707 r
F P
0 g
s
.53566 .77715 m .52961 .79534 L .5117 .79172 L p .707 .577 .707 r
F P
0 g
s
.47927 .31963 m .47927 .82152 L .52439 .82137 L p .707 .577 .707 r
F P
0 g
s
.52665 .70898 m .52302 .654 L .54499 .64578 L p .707 .577 .707 r
F P
0 g
s
.51943 .761 m .5241 .72363 L .54379 .72087 L p .707 .577 .707 r
F P
0 g
s
.54379 .72087 m .53912 .75825 L .51943 .761 L p .707 .577 .707 r
F P
0 g
s
.52439 .82137 m .52439 .31948 L .47927 .31963 L p .707 .577 .707 r
F P
0 g
s
.54499 .64578 m .54862 .70076 L .52665 .70898 L p .707 .577 .707 r
F P
0 g
s
.54862 .70076 m .54499 .64578 L .57303 .63956 L p .707 .577 .707 r
F P
0 g
s
.57303 .63956 m .57666 .69454 L .54862 .70076 L p .707 .577 .707 r
F P
0 g
s
.53912 .75825 m .54379 .72087 L .57021 .72042 L p .707 .577 .707 r
F P
0 g
s
.57021 .72042 m .56554 .75779 L .53912 .75825 L p .707 .577 .707 r
F P
0 g
s
.52961 .79534 m .53566 .77715 L .56026 .78361 L p .707 .577 .707 r
F P
0 g
s
.56026 .78361 m .55421 .80179 L .52961 .79534 L p .707 .577 .707 r
F P
0 g
s
.55421 .80179 m .56026 .78361 L .58914 .79227 L p .707 .577 .707 r
F P
0 g
s
.58914 .79227 m .58309 .81046 L .55421 .80179 L p .707 .577 .707 r
F P
0 g
s
.52439 .31948 m .52439 .82137 L .56713 .81748 L p .707 .577 .707 r
F P
0 g
s
.56554 .75779 m .57021 .72042 L .60076 .72232 L p .707 .577 .707 r
F P
0 g
s
.60076 .72232 m .59609 .7597 L .56554 .75779 L p .707 .577 .707 r
F P
0 g
s
.56713 .81748 m .56713 .31559 L .52439 .31948 L p .707 .577 .707 r
F P
0 g
s
.71193 .76048 m .70725 .79785 L .70856 .79149 L p .707 .577 .707 r
F P
0 g
s
.70856 .79149 m .71323 .75411 L .71193 .76048 L p .707 .577 .707 r
F P
0 g
s
.43617 .81793 m .43617 .31604 L .39932 .30905 L p .707 .577 .707 r
F P
0 g
s
.43617 .31604 m .43617 .81793 L .47927 .82152 L p .707 .577 .707 r
F P
0 g
s
.57666 .69454 m .57303 .63956 L .60441 .63594 L p .707 .577 .707 r
F P
0 g
s
.60441 .63594 m .60803 .69092 L .57666 .69454 L p .707 .577 .707 r
F P
0 g
s
.63247 .72639 m .62779 .76376 L .59609 .7597 L p .707 .577 .707 r
F P
0 g
s
.59609 .7597 m .60076 .72232 L .63247 .72639 L p .707 .577 .707 r
F P
0 g
s
.58309 .81046 m .58914 .79227 L .61949 .8023 L p .707 .577 .707 r
F P
0 g
s
.61949 .8023 m .61343 .82049 L .58309 .81046 L p .707 .577 .707 r
F P
0 g
s
.56713 .31559 m .56713 .81748 L .6033 .81023 L p .707 .577 .707 r
F P
0 g
s
.6033 .81023 m .6033 .30834 L .56713 .31559 L p .707 .577 .707 r
F P
0 g
s
.69978 .83927 m .69373 .85745 L .69381 .85463 L p .707 .578 .707 r
F P
0 g
s
.69381 .85463 m .69987 .83645 L .69978 .83927 L p .707 .578 .707 r
F P
0 g
s
.26593 .70896 m .26432 .6526 L .23264 .65257 L p .707 .577 .707 r
F P
0 g
s
.26432 .6526 m .26593 .70896 L .29735 .70686 L p .707 .577 .707 r
F P
0 g
s
.29735 .70686 m .29574 .65051 L .26432 .6526 L p .707 .577 .707 r
F P
0 g
s
.70317 .65026 m .7068 .70523 L .69159 .69779 L p .707 .577 .707 r
F P
0 g
s
.69159 .69779 m .68796 .64281 L .70317 .65026 L p .707 .577 .707 r
F P
0 g
s
.23425 .70893 m .23264 .65257 L .2038 .65043 L p .707 .577 .707 r
F P
0 g
s
.23264 .65257 m .23425 .70893 L .26593 .70896 L p .707 .577 .707 r
F P
0 g
s
.29574 .65051 m .29735 .70686 L .32543 .70286 L p .707 .577 .707 r
F P
0 g
s
.32543 .70286 m .32382 .6465 L .29574 .65051 L p .707 .577 .707 r
F P
0 g
s
.71323 .75411 m .70856 .79149 L .7 .78418 L p .707 .577 .707 r
F P
0 g
s
.7 .78418 m .70468 .7468 L .71323 .75411 L p .707 .577 .707 r
F P
0 g
s
.39932 .81094 m .39932 .30905 L .37233 .29934 L p .707 .577 .707 r
F P
0 g
s
.39932 .30905 m .39932 .81094 L .43617 .81793 L p .707 .577 .707 r
F P
0 g
s
.2038 .65043 m .2054 .70679 L .23425 .70893 L p .707 .577 .707 r
F P
0 g
s
.63603 .63529 m .63966 .69026 L .60803 .69092 L p .707 .577 .707 r
F P
0 g
s
.60803 .69092 m .60441 .63594 L .63603 .63529 L p .707 .577 .707 r
F P
0 g
s
.61343 .82049 m .61949 .8023 L .64832 .81271 L p .707 .577 .707 r
F P
0 g
s
.6033 .30834 m .6033 .81023 L .62935 .80035 L p .707 .577 .707 r
F P
0 g
s
.66222 .73222 m .65754 .7696 L .62779 .76376 L p .707 .577 .707 r
F P
0 g
s
.62779 .76376 m .63247 .72639 L .66222 .73222 L p .707 .577 .707 r
F P
0 g
s
.62935 .80035 m .62935 .29846 L .6033 .30834 L p .707 .577 .707 r
F P
0 g
s
.2054 .70679 m .2038 .65043 L .18062 .64638 L p .707 .577 .707 r
F P
0 g
s
.32382 .6465 m .32543 .70286 L .34742 .69733 L p .707 .577 .707 r
F P
0 g
s
.34742 .69733 m .34582 .64097 L .32382 .6465 L p .707 .577 .707 r
F P
0 g
s
.27387 .78458 m .27598 .74881 L .24409 .74671 L p .707 .577 .707 r
F P
0 g
s
.27598 .74881 m .27387 .78458 L .3046 .783 L p .707 .577 .707 r
F P
0 g
s
.3046 .783 m .30671 .74723 L .27598 .74881 L p .707 .577 .707 r
F P
0 g
s
.24198 .78248 m .24409 .74671 L .21415 .74114 L p .707 .577 .707 r
F P
0 g
s
.24409 .74671 m .24198 .78248 L .27387 .78458 L p .707 .577 .707 r
F P
0 g
s
.69987 .83645 m .69381 .85463 L .68452 .84885 L p .707 .577 .707 r
F P
0 g
s
.68452 .84885 m .69058 .83067 L .69987 .83645 L p .707 .577 .707 r
F P
0 g
s
.18062 .64638 m .18222 .70274 L .2054 .70679 L p .707 .577 .707 r
F P
0 g
s
.68796 .64281 m .69159 .69779 L .66845 .69263 L p .707 .577 .707 r
F P
0 g
s
.66845 .69263 m .66483 .63765 L .68796 .64281 L p .707 .577 .707 r
F P
0 g
s
.30671 .74723 m .3046 .783 L .33115 .77789 L p .707 .577 .707 r
F P
0 g
s
.33115 .77789 m .33326 .74213 L .30671 .74723 L p .707 .577 .707 r
F P
0 g
s
.21204 .77691 m .21415 .74114 L .1891 .73264 L p .707 .577 .707 r
F P
0 g
s
.21415 .74114 m .21204 .77691 L .24198 .78248 L p .707 .577 .707 r
F P
0 g
s
.18222 .70274 m .18062 .64638 L .16537 .64082 L p .707 .577 .707 r
F P
0 g
s
.70468 .7468 m .7 .78418 L .68242 .77663 L p .707 .577 .707 r
F P
0 g
s
.68242 .77663 m .6871 .73926 L .70468 .7468 L p .707 .577 .707 r
F P
0 g
s
.34582 .64097 m .34742 .69733 L .36117 .69082 L p .707 .577 .707 r
F P
0 g
s
.36117 .69082 m .35957 .63446 L .34582 .64097 L p .707 .577 .707 r
F P
0 g
s
.1891 .73264 m .18699 .76841 L .21204 .77691 L p .707 .577 .707 r
F P
0 g
s
.33326 .74213 m .33115 .77789 L .35093 .76976 L p .707 .577 .707 r
F P
0 g
s
.35093 .76976 m .35304 .734 L .33326 .74213 L p .707 .577 .707 r
F P
0 g
s
.37233 .80123 m .37233 .29934 L .35783 .28787 L p .707 .577 .707 r
F P
0 g
s
.37233 .29934 m .37233 .80123 L .39932 .81094 L p .707 .577 .707 r
F P
0 g
s
.18699 .76841 m .1891 .73264 L .17138 .72204 L p .707 .577 .707 r
F P
0 g
s
.16537 .64082 m .16697 .69718 L .18222 .70274 L p .707 .577 .707 r
F P
0 g
s
.66483 .63765 m .66845 .69263 L .63966 .69026 L p .707 .577 .707 r
F P
0 g
s
.63966 .69026 m .63603 .63529 L .66483 .63765 L p .707 .577 .707 r
F P
0 g
s
.62935 .29846 m .62935 .80035 L .64275 .78878 L p .707 .577 .707 r
F P
0 g
s
.64275 .78878 m .64275 .28689 L .62935 .29846 L p .707 .577 .707 r
F P
0 g
s
.24223 .83481 m .24504 .81837 L .21492 .80962 L p .707 .577 .707 r
F P
0 g
s
.24504 .81837 m .24223 .83481 L .27386 .83878 L p .707 .577 .707 r
F P
0 g
s
.27386 .83878 m .27666 .82234 L .24504 .81837 L p .707 .577 .707 r
F P
0 g
s
.27666 .82234 m .27386 .83878 L .3039 .83758 L p .707 .577 .707 r
F P
0 g
s
.3039 .83758 m .3067 .82114 L .27666 .82234 L p .707 .577 .707 r
F P
0 g
s
.69058 .83067 m .68452 .84885 L .66676 .84067 L p .707 .577 .707 r
F P
0 g
s
.66676 .84067 m .67281 .82249 L .69058 .83067 L p .707 .577 .707 r
F P
0 g
s
.21212 .82606 m .21492 .80962 L .18927 .79694 L p .707 .577 .707 r
F P
0 g
s
.21492 .80962 m .21212 .82606 L .24223 .83481 L p .707 .577 .707 r
F P
0 g
s
.17138 .72204 m .16927 .75781 L .18699 .76841 L p .707 .577 .707 r
F P
0 g
s
.16697 .69718 m .16537 .64082 L .15954 .6343 L p .707 .577 .707 r
F P
0 g
s
.3067 .82114 m .3039 .83758 L .32942 .83133 L p .707 .577 .707 r
F P
0 g
s
.32942 .83133 m .33222 .81489 L .3067 .82114 L p .707 .577 .707 r
F P
0 g
s
.6871 .73926 m .68242 .77663 L .65754 .7696 L p .707 .577 .707 r
F P
0 g
s
.65754 .7696 m .66222 .73222 L .6871 .73926 L p .707 .577 .707 r
F P
0 g
s
.18927 .79694 m .18647 .81339 L .21212 .82606 L p .707 .577 .707 r
F P
0 g
s
.35957 .63446 m .36117 .69082 L .36534 .68396 L p .707 .577 .707 r
F P
0 g
s
.36534 .68396 m .36374 .62761 L .35957 .63446 L p .707 .577 .707 r
F P
0 g
s
.35304 .734 m .35093 .76976 L .36199 .7594 L p .707 .577 .707 r
F P
0 g
s
.36199 .7594 m .36411 .72364 L .35304 .734 L p .707 .577 .707 r
F P
0 g
s
.18647 .81339 m .18927 .79694 L .17059 .78158 L p .707 .577 .707 r
F P
0 g
s
.16927 .75781 m .17138 .72204 L .16274 .71039 L p .707 .577 .707 r
F P
0 g
s
.15954 .6343 m .16114 .69065 L .16697 .69718 L p .707 .577 .707 r
F P
0 g
s
.17059 .78158 m .16778 .79803 L .18647 .81339 L p .707 .577 .707 r
F P
0 g
s
.67281 .82249 m .66676 .84067 L .64226 .8309 L p .707 .577 .707 r
F P
0 g
s
.64226 .8309 m .64832 .81271 L .67281 .82249 L p .707 .577 .707 r
F P
0 g
s
.33222 .81489 m .32942 .83133 L .34791 .82064 L p .707 .577 .707 r
F P
0 g
s
.34791 .82064 m .35072 .8042 L .33222 .81489 L p .707 .577 .707 r
F P
0 g
s
.16274 .71039 m .16063 .74615 L .16927 .75781 L p .707 .577 .707 r
F P
0 g
s
.36411 .72364 m .36199 .7594 L .36327 .74783 L p .707 .577 .707 r
F P
0 g
s
.36327 .74783 m .36538 .71206 L .36411 .72364 L p .707 .577 .707 r
F P
0 g
s
.36538 .71206 m .36327 .74783 L .35462 .73617 L p .707 .577 .707 r
F P
0 g
s
.35462 .73617 m .35674 .70041 L .36538 .71206 L p .707 .577 .707 r
F P
0 g
s
.35791 .62108 m .35952 .67744 L .34427 .67188 L p .707 .577 .707 r
F P
0 g
s
.34427 .67188 m .34266 .61552 L .35791 .62108 L p .707 .577 .707 r
F P
0 g
s
.36026 .77401 m .36038 .79011 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35746 .79046 m .35856 .78401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35856 .78401 m .36026 .77401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35725 .27577 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36026 .77401 m .35746 .79046 L .34758 .77392 L p .707 .577 .707 r
F P
0 g
s
.34758 .77392 m .35038 .75747 L .36026 .77401 L p .707 .577 .707 r
F P
0 g
s
.35783 .78976 m .35783 .75807 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.35783 .75807 m .35783 .28787 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36374 .62761 m .36534 .68396 L .35952 .67744 L p .707 .577 .707 r
F P
0 g
s
.35952 .67744 m .35791 .62108 L .36374 .62761 L p .707 .577 .707 r
F P
0 g
s
.35757 .80656 m .36038 .79011 L .35072 .8042 L p .707 .577 .707 r
F P
0 g
s
.36038 .79011 m .35757 .80656 L .35746 .79046 L p .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35783 .78976 L .37233 .80123 L p .707 .577 .707 r
F P
0 g
s
.64275 .28689 m .64275 .78878 L .64217 .77667 L p .708 .578 .707 r
F P
0 g
s
.64217 .77667 m .64217 .27478 L .64275 .28689 L p .708 .578 .707 r
F P
0 g
s
.16778 .79803 m .17059 .78158 L .16071 .76505 L p .707 .577 .707 r
F P
0 g
s
.16114 .69065 m .15954 .6343 L .16371 .62744 L p .707 .577 .707 r
F P
0 g
s
.64832 .81271 m .64226 .8309 L .61343 .82049 L p .707 .577 .707 r
F P
0 g
s
.16063 .74615 m .16274 .71039 L .16401 .69881 L p .707 .577 .707 r
F P
0 g
s
.16071 .76505 m .1579 .78149 L .16778 .79803 L p .707 .577 .707 r
F P
0 g
s
.35072 .8042 m .34791 .82064 L .35757 .80656 L p .707 .577 .707 r
F P
0 g
s
.16371 .62744 m .16531 .6838 L .16114 .69065 L p .707 .577 .707 r
F P
0 g
s
.16401 .69881 m .1619 .73458 L .16063 .74615 L p .707 .577 .707 r
F P
0 g
s
.1579 .78149 m .16071 .76505 L .16059 .74895 L p .707 .577 .707 r
F P
0 g
s
.16531 .6838 m .16371 .62744 L .17746 .62093 L p .707 .577 .707 r
F P
0 g
s
.16059 .74895 m .15779 .76539 L .1579 .78149 L p .707 .577 .707 r
F P
0 g
s
.35725 .27577 m .35725 .77766 L .35783 .78976 L p .708 .578 .707 r
F P
0 g
s
.35725 .77766 m .35725 .27577 L .37064 .2642 L p .707 .577 .707 r
F P
0 g
s
.1619 .73458 m .16401 .69881 L .17508 .68845 L p .707 .577 .707 r
F P
0 g
s
.64217 .27478 m .64217 .77667 L .62767 .76521 L p .707 .577 .707 r
F P
0 g
s
.62767 .76521 m .62767 .26332 L .64217 .27478 L p .707 .577 .707 r
F P
0 g
s
.17746 .62093 m .17907 .67729 L .16531 .6838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17508 .68845 m .17297 .72422 L .1619 .73458 L p .707 .577 .707 r
F P
0 g
s
.15779 .76539 m .16059 .74895 L .17025 .73486 L p .707 .577 .707 r
F P
0 g
s
.17907 .67729 m .17746 .62093 L .19946 .6154 L p .707 .577 .707 r
F P
0 g
s
.17025 .73486 m .16745 .7513 L .15779 .76539 L p .707 .577 .707 r
F P
0 g
s
.35674 .70041 m .35462 .73617 L .33691 .72558 L p .707 .577 .707 r
F P
0 g
s
.33691 .72558 m .33902 .68981 L .35674 .70041 L p .707 .577 .707 r
F P
0 g
s
.34266 .61552 m .34427 .67188 L .32108 .66783 L p .707 .577 .707 r
F P
0 g
s
.32108 .66783 m .31948 .61147 L .34266 .61552 L p .707 .577 .707 r
F P
0 g
s
.17297 .72422 m .17508 .68845 L .19486 .68032 L p .707 .577 .707 r
F P
0 g
s
.19946 .6154 m .20106 .67176 L .17907 .67729 L p .707 .577 .707 r
F P
0 g
s
.37064 .76609 m .37064 .2642 L .3967 .25431 L p .707 .577 .707 r
F P
0 g
s
.37064 .2642 m .37064 .76609 L .35725 .77766 L p .707 .577 .707 r
F P
0 g
s
.16745 .7513 m .17025 .73486 L .18875 .72417 L p .707 .577 .707 r
F P
0 g
s
.19486 .68032 m .19275 .71609 L .17297 .72422 L p .707 .577 .707 r
F P
0 g
s
.62767 .26332 m .62767 .76521 L .60068 .7555 L p .707 .577 .707 r
F P
0 g
s
.60068 .7555 m .60068 .25361 L .62767 .26332 L p .707 .577 .707 r
F P
0 g
s
.20106 .67176 m .19946 .6154 L .22754 .6114 L p .707 .577 .707 r
F P
0 g
s
.31948 .61147 m .32108 .66783 L .29224 .66569 L p .707 .577 .707 r
F P
0 g
s
.29224 .66569 m .29064 .60933 L .31948 .61147 L p .707 .577 .707 r
F P
0 g
s
.33902 .68981 m .33691 .72558 L .31186 .71707 L p .707 .577 .707 r
F P
0 g
s
.31186 .71707 m .31397 .68131 L .33902 .68981 L p .707 .577 .707 r
F P
0 g
s
.18875 .72417 m .18594 .74061 L .16745 .7513 L p .707 .577 .707 r
F P
0 g
s
.19275 .71609 m .19486 .68032 L .22141 .67522 L p .707 .577 .707 r
F P
0 g
s
.35038 .75747 m .34758 .77392 L .32889 .75856 L p .707 .577 .707 r
F P
0 g
s
.32889 .75856 m .3317 .74212 L .35038 .75747 L p .707 .577 .707 r
F P
0 g
s
.22754 .6114 m .22914 .66775 L .20106 .67176 L p .707 .577 .707 r
F P
0 g
s
.22914 .66775 m .22754 .6114 L .25896 .6093 L p .707 .577 .707 r
F P
0 g
s
.29064 .60933 m .29224 .66569 L .26056 .66566 L p .707 .577 .707 r
F P
0 g
s
.26056 .66566 m .25896 .6093 L .29064 .60933 L p .707 .577 .707 r
F P
0 g
s
.18594 .74061 m .18875 .72417 L .21427 .71792 L p .707 .577 .707 r
F P
0 g
s
.22141 .67522 m .2193 .71098 L .19275 .71609 L p .707 .577 .707 r
F P
0 g
s
.25896 .6093 m .26056 .66566 L .22914 .66775 L p .707 .577 .707 r
F P
0 g
s
.31397 .68131 m .31186 .71707 L .28192 .7115 L p .707 .577 .707 r
F P
0 g
s
.28192 .7115 m .28403 .67573 L .31397 .68131 L p .707 .577 .707 r
F P
0 g
s
.2193 .71098 m .22141 .67522 L .25214 .67363 L p .707 .577 .707 r
F P
0 g
s
.21427 .71792 m .21146 .73436 L .18594 .74061 L p .707 .577 .707 r
F P
0 g
s
.73944 .66108 m .74104 .60649 L .70936 .60431 L p .707 .577 .707 r
F P
0 g
s
.74104 .60649 m .73944 .66108 L .77086 .66002 L p .707 .577 .707 r
F P
0 g
s
.77086 .66002 m .77246 .60544 L .74104 .60649 L p .707 .577 .707 r
F P
0 g
s
.3317 .74212 m .32889 .75856 L .30324 .74588 L p .707 .577 .707 r
F P
0 g
s
.30324 .74588 m .30605 .72944 L .3317 .74212 L p .707 .577 .707 r
F P
0 g
s
.3967 .25431 m .3967 .7562 L .37064 .76609 L p .707 .577 .707 r
F P
0 g
s
.3967 .7562 m .3967 .25431 L .43287 .24707 L p .707 .577 .707 r
F P
0 g
s
.28403 .67573 m .28192 .7115 L .25002 .7094 L p .707 .577 .707 r
F P
0 g
s
.25002 .7094 m .25214 .67363 L .28403 .67573 L p .707 .577 .707 r
F P
0 g
s
.25214 .67363 m .25002 .7094 L .2193 .71098 L p .707 .577 .707 r
F P
0 g
s
.60068 .25361 m .60068 .7555 L .56383 .74851 L p .707 .577 .707 r
F P
0 g
s
.56383 .74851 m .56383 .24662 L .60068 .25361 L p .707 .577 .707 r
F P
0 g
s
.70776 .6589 m .70936 .60431 L .68052 .59911 L p .707 .577 .707 r
F P
0 g
s
.70936 .60431 m .70776 .6589 L .73944 .66108 L p .707 .577 .707 r
F P
0 g
s
.77246 .60544 m .77086 .66002 L .79894 .65583 L p .707 .577 .707 r
F P
0 g
s
.79894 .65583 m .80054 .60125 L .77246 .60544 L p .707 .577 .707 r
F P
0 g
s
.21146 .73436 m .21427 .71792 L .24431 .71672 L p .707 .577 .707 r
F P
0 g
s
.30605 .72944 m .30324 .74588 L .27313 .73713 L p .707 .577 .707 r
F P
0 g
s
.27313 .73713 m .27593 .72069 L .30605 .72944 L p .707 .577 .707 r
F P
0 g
s
.67891 .65369 m .68052 .59911 L .65734 .59139 L p .707 .577 .707 r
F P
0 g
s
.68052 .59911 m .67891 .65369 L .70776 .6589 L p .707 .577 .707 r
F P
0 g
s
.24431 .71672 m .2415 .73316 L .21146 .73436 L p .707 .577 .707 r
F P
0 g
s
.2415 .73316 m .24431 .71672 L .27593 .72069 L p .707 .577 .707 r
F P
0 g
s
.80054 .60125 m .79894 .65583 L .82093 .64892 L p .707 .577 .707 r
F P
0 g
s
.82093 .64892 m .82254 .59433 L .80054 .60125 L p .707 .577 .707 r
F P
0 g
s
.27593 .72069 m .27313 .73713 L .2415 .73316 L p .707 .577 .707 r
F P
0 g
s
.74997 .70547 m .74786 .66761 L .71597 .66913 L p .707 .577 .707 r
F P
0 g
s
.74786 .66761 m .74997 .70547 L .7807 .70233 L p .707 .577 .707 r
F P
0 g
s
.7807 .70233 m .77859 .66448 L .74786 .66761 L p .707 .577 .707 r
F P
0 g
s
.71808 .70698 m .71597 .66913 L .68603 .66887 L p .707 .577 .707 r
F P
0 g
s
.71597 .66913 m .71808 .70698 L .74997 .70547 L p .707 .577 .707 r
F P
0 g
s
.43287 .74896 m .43287 .24707 L .47561 .24318 L p .707 .577 .707 r
F P
0 g
s
.43287 .24707 m .43287 .74896 L .3967 .7562 L p .707 .577 .707 r
F P
0 g
s
.56383 .24662 m .56383 .74851 L .52073 .74492 L p .707 .577 .707 r
F P
0 g
s
.52073 .74492 m .52073 .24303 L .56383 .24662 L p .707 .577 .707 r
F P
0 g
s
.72687 .73695 m .72407 .71793 L .69395 .72221 L p .707 .577 .707 r
F P
0 g
s
.72407 .71793 m .72687 .73695 L .7585 .73229 L p .707 .577 .707 r
F P
0 g
s
.7585 .73229 m .75569 .71326 L .72407 .71793 L p .707 .577 .707 r
F P
0 g
s
.75569 .71326 m .7585 .73229 L .78854 .7277 L p .707 .577 .707 r
F P
0 g
s
.78854 .7277 m .78573 .70868 L .75569 .71326 L p .707 .577 .707 r
F P
0 g
s
.69395 .72221 m .69676 .74123 L .72687 .73695 L p .707 .577 .707 r
F P
0 g
s
.68603 .66887 m .68814 .70672 L .71808 .70698 L p .707 .577 .707 r
F P
0 g
s
.77859 .66448 m .7807 .70233 L .80725 .69789 L p .707 .577 .707 r
F P
0 g
s
.80725 .69789 m .80514 .66003 L .77859 .66448 L p .707 .577 .707 r
F P
0 g
s
.65734 .59139 m .65573 .64597 L .67891 .65369 L p .707 .577 .707 r
F P
0 g
s
.68814 .70672 m .68603 .66887 L .66098 .66687 L p .707 .577 .707 r
F P
0 g
s
.65573 .64597 m .65734 .59139 L .64209 .58191 L p .707 .577 .707 r
F P
0 g
s
.69676 .74123 m .69395 .72221 L .6683 .72569 L p .707 .577 .707 r
F P
0 g
s
.78573 .70868 m .78854 .7277 L .81405 .72364 L p .707 .577 .707 r
F P
0 g
s
.81405 .72364 m .81125 .70461 L .78573 .70868 L p .707 .577 .707 r
F P
0 g
s
.47561 .74507 m .47561 .24318 L .52073 .24303 L p .707 .577 .707 r
F P
0 g
s
.47561 .24318 m .47561 .74507 L .43287 .74896 L p .707 .577 .707 r
F P
0 g
s
.6683 .72569 m .6711 .74471 L .69676 .74123 L p .707 .577 .707 r
F P
0 g
s
.52073 .24303 m .52073 .74492 L .47561 .74507 L p .707 .577 .707 r
F P
0 g
s
.66098 .66687 m .66309 .70473 L .68814 .70672 L p .707 .577 .707 r
F P
0 g
s
.82254 .59433 m .82093 .64892 L .83469 .63995 L p .707 .577 .707 r
F P
0 g
s
.83469 .63995 m .83629 .58537 L .82254 .59433 L p .707 .577 .707 r
F P
0 g
s
.80514 .66003 m .80725 .69789 L .82703 .69256 L p .707 .577 .707 r
F P
0 g
s
.82703 .69256 m .82492 .65471 L .80514 .66003 L p .707 .577 .707 r
F P
0 g
s
.64209 .58191 m .64048 .6365 L .65573 .64597 L p .707 .577 .707 r
F P
0 g
s
.66309 .70473 m .66098 .66687 L .64326 .66333 L p .707 .577 .707 r
F P
0 g
s
.6711 .74471 m .6683 .72569 L .64962 .72803 L p .707 .577 .707 r
F P
0 g
s
.81125 .70461 m .81405 .72364 L .83255 .72049 L p .707 .577 .707 r
F P
0 g
s
.83255 .72049 m .82974 .70147 L .81125 .70461 L p .707 .577 .707 r
F P
0 g
s
.64962 .72803 m .65242 .74705 L .6711 .74471 L p .707 .577 .707 r
F P
0 g
s
.64326 .66333 m .64537 .70118 L .66309 .70473 L p .707 .577 .707 r
F P
0 g
s
.64048 .6365 m .64209 .58191 L .63626 .5716 L p .707 .577 .707 r
F P
0 g
s
.83629 .58537 m .83469 .63995 L .83885 .62982 L p .707 .577 .707 r
F P
0 g
s
.83885 .62982 m .84046 .57524 L .83629 .58537 L p .707 .577 .707 r
F P
0 g
s
.82492 .65471 m .82703 .69256 L .8381 .68688 L p .707 .577 .707 r
F P
0 g
s
.8381 .68688 m .83598 .64903 L .82492 .65471 L p .707 .577 .707 r
F P
0 g
s
.63626 .5716 m .63466 .62619 L .64048 .6365 L p .707 .577 .707 r
F P
0 g
s
.64537 .70118 m .64326 .66333 L .63462 .65858 L p .707 .577 .707 r
F P
0 g
s
.65242 .74705 m .64962 .72803 L .63973 .729 L p .707 .577 .707 r
F P
0 g
s
.82974 .70147 m .83255 .72049 L .84221 .71858 L p .707 .577 .707 r
F P
0 g
s
.84221 .71858 m .83941 .69956 L .82974 .70147 L p .707 .577 .707 r
F P
0 g
s
.63973 .729 m .64254 .74802 L .65242 .74705 L p .707 .577 .707 r
F P
0 g
s
.63462 .65858 m .63673 .69643 L .64537 .70118 L p .707 .577 .707 r
F P
0 g
s
.63466 .62619 m .63626 .5716 L .64043 .56147 L p .707 .577 .707 r
F P
0 g
s
.84046 .57524 m .83885 .62982 L .83303 .61952 L p .707 .577 .707 r
F P
0 g
s
.83303 .61952 m .83463 .56493 L .84046 .57524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83598 .64903 m .8381 .68688 L .83937 .6814 L p .707 .577 .707 r
F P
0 g
s
.83937 .6814 m .83726 .64355 L .83598 .64903 L p .707 .577 .707 r
F P
0 g
s
.64043 .56147 m .63882 .61606 L .63466 .62619 L p .707 .577 .707 r
F P
0 g
s
.63673 .69643 m .63462 .65858 L .63589 .6531 L p .707 .577 .707 r
F P
0 g
s
.64254 .74802 m .63973 .729 L .63962 .7285 L p .712 .581 .706 r
F P
0 g
s
.83941 .69956 m .84221 .71858 L .8421 .71809 L p .712 .581 .706 r
F P
0 g
s
.8421 .71809 m .83929 .69906 L .83941 .69956 L p .712 .581 .706 r
F P
0 g
s
.63962 .7285 m .64242 .74753 L .64254 .74802 L p .712 .581 .706 r
F P
0 g
s
.63589 .6531 m .63801 .69095 L .63673 .69643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63882 .61606 m .64043 .56147 L .65418 .55251 L p .707 .577 .707 r
F P
0 g
s
.39196 .6187 m .39559 .56278 L .36396 .55984 L p .707 .577 .707 r
F P
0 g
s
.39559 .56278 m .39196 .6187 L .42334 .61923 L p .707 .577 .707 r
F P
0 g
s
.42334 .61923 m .42696 .56331 L .39559 .56278 L p .707 .577 .707 r
F P
0 g
s
.36034 .61576 m .36396 .55984 L .33517 .55479 L p .707 .577 .707 r
F P
0 g
s
.36396 .55984 m .36034 .61576 L .39196 .6187 L p .707 .577 .707 r
F P
0 g
s
.83463 .56493 m .83303 .61952 L .81778 .61004 L p .707 .577 .707 r
F P
0 g
s
.81778 .61004 m .81938 .55546 L .83463 .56493 L p .707 .577 .707 r
F P
0 g
s
.42696 .56331 m .42334 .61923 L .45138 .6173 L p .707 .577 .707 r
F P
0 g
s
.45138 .6173 m .45501 .56138 L .42696 .56331 L p .707 .577 .707 r
F P
0 g
s
.83726 .64355 m .83937 .6814 L .83073 .67665 L p .707 .577 .707 r
F P
0 g
s
.83073 .67665 m .82862 .6388 L .83726 .64355 L p .707 .577 .707 r
F P
0 g
s
.33154 .61071 m .33517 .55479 L .31204 .54812 L p .707 .577 .707 r
F P
0 g
s
.33517 .55479 m .33154 .61071 L .36034 .61576 L p .707 .577 .707 r
F P
0 g
s
.65418 .55251 m .65258 .6071 L .63882 .61606 L p .707 .577 .707 r
F P
0 g
s
.63801 .69095 m .63589 .6531 L .64696 .64742 L p .707 .577 .707 r
F P
0 g
s
.45501 .56138 m .45138 .6173 L .47335 .61311 L p .707 .577 .707 r
F P
0 g
s
.47335 .61311 m .47698 .55719 L .45501 .56138 L p .707 .577 .707 r
F P
0 g
s
.40391 .68623 m .39923 .65021 L .36753 .65343 L p .707 .577 .707 r
F P
0 g
s
.39923 .65021 m .40391 .68623 L .43446 .67985 L p .707 .577 .707 r
F P
0 g
s
.43446 .67985 m .42979 .64382 L .39923 .65021 L p .707 .577 .707 r
F P
0 g
s
.64242 .74753 m .63962 .7285 L .64928 .72659 L p .707 .577 .707 r
F P
0 g
s
.83929 .69906 m .8421 .71809 L .83222 .71906 L p .707 .577 .707 r
F P
0 g
s
.83222 .71906 m .82941 .70003 L .83929 .69906 L p .707 .577 .707 r
F P
0 g
s
.64928 .72659 m .65209 .74562 L .64242 .74753 L p .707 .577 .707 r
F P
0 g
s
.3722 .68946 m .36753 .65343 L .33778 .65319 L p .707 .577 .707 r
F P
0 g
s
.36753 .65343 m .3722 .68946 L .40391 .68623 L p .707 .577 .707 r
F P
0 g
s
.64696 .64742 m .64907 .68527 L .63801 .69095 L p .707 .577 .707 r
F P
0 g
s
.65258 .6071 m .65418 .55251 L .67617 .5456 L p .707 .577 .707 r
F P
0 g
s
.42979 .64382 m .43446 .67985 L .46088 .67093 L p .707 .577 .707 r
F P
0 g
s
.46088 .67093 m .4562 .6349 L .42979 .64382 L p .707 .577 .707 r
F P
0 g
s
.31204 .54812 m .30841 .60404 L .33154 .61071 L p .707 .577 .707 r
F P
0 g
s
.81938 .55546 m .81778 .61004 L .7946 .60232 L p .707 .577 .707 r
F P
0 g
s
.7946 .60232 m .7962 .54774 L .81938 .55546 L p .707 .577 .707 r
F P
0 g
s
.34246 .68921 m .33778 .65319 L .3129 .64949 L p .707 .577 .707 r
F P
0 g
s
.33778 .65319 m .34246 .68921 L .3722 .68946 L p .707 .577 .707 r
F P
0 g
s
.30841 .60404 m .31204 .54812 L .29682 .54048 L p .707 .577 .707 r
F P
0 g
s
.82862 .6388 m .83073 .67665 L .81301 .6731 L p .707 .577 .707 r
F P
0 g
s
.81301 .6731 m .8109 .63525 L .82862 .6388 L p .707 .577 .707 r
F P
0 g
s
.47698 .55719 m .47335 .61311 L .48709 .60706 L p .707 .577 .707 r
F P
0 g
s
.48709 .60706 m .49072 .55114 L .47698 .55719 L p .707 .577 .707 r
F P
0 g
s
.4562 .6349 m .46088 .67093 L .48057 .66035 L p .707 .577 .707 r
F P
0 g
s
.48057 .66035 m .47589 .62433 L .4562 .6349 L p .707 .577 .707 r
F P
0 g
s
.67617 .5456 m .67457 .60018 L .65258 .6071 L p .707 .577 .707 r
F P
0 g
s
.41691 .73404 m .41085 .71764 L .38051 .72664 L p .707 .577 .707 r
F P
0 g
s
.41085 .71764 m .41691 .73404 L .44579 .72114 L p .707 .577 .707 r
F P
0 g
s
.44579 .72114 m .43974 .70474 L .41085 .71764 L p .707 .577 .707 r
F P
0 g
s
.67457 .60018 m .67617 .5456 L .70426 .54141 L p .707 .577 .707 r
F P
0 g
s
.3129 .64949 m .31757 .68551 L .34246 .68921 L p .707 .577 .707 r
F P
0 g
s
.64907 .68527 m .64696 .64742 L .66674 .64209 L p .707 .577 .707 r
F P
0 g
s
.38656 .74305 m .38051 .72664 L .35168 .73086 L p .707 .577 .707 r
F P
0 g
s
.38051 .72664 m .38656 .74305 L .41691 .73404 L p .707 .577 .707 r
F P
0 g
s
.43974 .70474 m .44579 .72114 L .47039 .7056 L p .707 .577 .707 r
F P
0 g
s
.47039 .7056 m .46434 .6892 L .43974 .70474 L p .707 .577 .707 r
F P
0 g
s
.29682 .54048 m .2932 .5964 L .30841 .60404 L p .707 .577 .707 r
F P
0 g
s
.7962 .54774 m .7946 .60232 L .76575 .59711 L p .707 .577 .707 r
F P
0 g
s
.76575 .59711 m .76736 .54253 L .7962 .54774 L p .707 .577 .707 r
F P
0 g
s
.65209 .74562 m .64928 .72659 L .66778 .72345 L p .707 .577 .707 r
F P
0 g
s
.82941 .70003 m .83222 .71906 L .81353 .7214 L p .707 .577 .707 r
F P
0 g
s
.81353 .7214 m .81073 .70237 L .82941 .70003 L p .707 .577 .707 r
F P
0 g
s
.66778 .72345 m .67058 .74247 L .65209 .74562 L p .707 .577 .707 r
F P
0 g
s
.66674 .64209 m .66885 .67994 L .64907 .68527 L p .707 .577 .707 r
F P
0 g
s
.31757 .68551 m .3129 .64949 L .29532 .64271 L p .707 .577 .707 r
F P
0 g
s
.35168 .73086 m .35773 .74727 L .38656 .74305 L p .707 .577 .707 r
F P
0 g
s
.70265 .59599 m .70426 .54141 L .73567 .54035 L p .707 .577 .707 r
F P
0 g
s
.70426 .54141 m .70265 .59599 L .67457 .60018 L p .707 .577 .707 r
F P
0 g
s
.35773 .74727 m .35168 .73086 L .32719 .72989 L p .707 .577 .707 r
F P
0 g
s
.46434 .6892 m .47039 .7056 L .4883 .68895 L p .707 .577 .707 r
F P
0 g
s
.4883 .68895 m .48224 .67255 L .46434 .6892 L p .707 .577 .707 r
F P
0 g
s
.2932 .5964 m .29682 .54048 L .29102 .53261 L p .707 .577 .707 r
F P
0 g
s
.76736 .54253 m .76575 .59711 L .73407 .59493 L p .707 .577 .707 r
F P
0 g
s
.73407 .59493 m .73567 .54035 L .76736 .54253 L p .707 .577 .707 r
F P
0 g
s
.8109 .63525 m .81301 .6731 L .78796 .67111 L p .707 .577 .707 r
F P
0 g
s
.78796 .67111 m .78585 .63325 L .8109 .63525 L p .707 .577 .707 r
F P
0 g
s
.47589 .62433 m .48057 .66035 L .4916 .64915 L p .707 .577 .707 r
F P
0 g
s
.4916 .64915 m .48693 .61312 L .47589 .62433 L p .707 .577 .707 r
F P
0 g
s
.29532 .64271 m .29999 .67873 L .31757 .68551 L p .707 .577 .707 r
F P
0 g
s
.73567 .54035 m .73407 .59493 L .70265 .59599 L p .707 .577 .707 r
F P
0 g
s
.32719 .72989 m .33324 .74629 L .35773 .74727 L p .707 .577 .707 r
F P
0 g
s
.49072 .55114 m .48709 .60706 L .49127 .59974 L p .707 .577 .707 r
F P
0 g
s
.49127 .59974 m .4949 .54383 L .49072 .55114 L p .707 .577 .707 r
F P
0 g
s
.66885 .67994 m .66674 .64209 L .69329 .63764 L p .707 .577 .707 r
F P
0 g
s
.29102 .53261 m .28739 .58853 L .2932 .5964 L p .707 .577 .707 r
F P
0 g
s
.67058 .74247 m .66778 .72345 L .6933 .71939 L p .707 .577 .707 r
F P
0 g
s
.81073 .70237 m .81353 .7214 L .78788 .72488 L p .707 .577 .707 r
F P
0 g
s
.78788 .72488 m .78508 .70585 L .81073 .70237 L p .707 .577 .707 r
F P
0 g
s
.6933 .71939 m .6961 .73841 L .67058 .74247 L p .707 .577 .707 r
F P
0 g
s
.69329 .63764 m .6954 .6755 L .66885 .67994 L p .707 .577 .707 r
F P
0 g
s
.29999 .67873 m .29532 .64271 L .28676 .6335 L p .707 .577 .707 r
F P
0 g
s
.33324 .74629 m .32719 .72989 L .30942 .72381 L p .707 .577 .707 r
F P
0 g
s
.48224 .67255 m .4883 .68895 L .49776 .67281 L p .707 .577 .707 r
F P
0 g
s
.49776 .67281 m .4917 .65641 L .48224 .67255 L p .707 .577 .707 r
F P
0 g
s
.78585 .63325 m .78796 .67111 L .75802 .67085 L p .707 .577 .707 r
F P
0 g
s
.75802 .67085 m .75591 .633 L .78585 .63325 L p .707 .577 .707 r
F P
0 g
s
.6954 .6755 m .69329 .63764 L .72402 .63451 L p .707 .577 .707 r
F P
0 g
s
.30942 .72381 m .31547 .74022 L .33324 .74629 L p .707 .577 .707 r
F P
0 g
s
.28676 .6335 m .29144 .66952 L .29999 .67873 L p .707 .577 .707 r
F P
0 g
s
.28739 .58853 m .29102 .53261 L .2952 .5253 L p .707 .577 .707 r
F P
0 g
s
.48693 .61312 m .4916 .64915 L .49291 .63842 L p .707 .577 .707 r
F P
0 g
s
.49291 .63842 m .48824 .60239 L .48693 .61312 L p .707 .577 .707 r
F P
0 g
s
.72402 .63451 m .72613 .67236 L .6954 .6755 L p .707 .577 .707 r
F P
0 g
s
.75591 .633 m .75802 .67085 L .72613 .67236 L p .707 .577 .707 r
F P
0 g
s
.72613 .67236 m .72402 .63451 L .75591 .633 L p .707 .577 .707 r
F P
0 g
s
.6961 .73841 m .6933 .71939 L .72334 .7148 L p .707 .577 .707 r
F P
0 g
s
.78508 .70585 m .78788 .72488 L .75777 .72916 L p .707 .577 .707 r
F P
0 g
s
.75777 .72916 m .75496 .71013 L .78508 .70585 L p .707 .577 .707 r
F P
0 g
s
.72334 .7148 m .72614 .73382 L .6961 .73841 L p .707 .577 .707 r
F P
0 g
s
.4949 .54383 m .49127 .59974 L .48547 .59188 L p .707 .577 .707 r
F P
0 g
s
.48547 .59188 m .4891 .53596 L .4949 .54383 L p .707 .577 .707 r
F P
0 g
s
.2952 .5253 m .29157 .58122 L .28739 .58853 L p .707 .577 .707 r
F P
0 g
s
.72614 .73382 m .72334 .7148 L .75496 .71013 L p .707 .577 .707 r
F P
0 g
s
.75496 .71013 m .75777 .72916 L .72614 .73382 L p .707 .577 .707 r
F P
0 g
s
.31547 .74022 m .30942 .72381 L .30013 .71324 L p .707 .577 .707 r
F P
0 g
s
.4917 .65641 m .49776 .67281 L .49784 .65877 L p .707 .577 .707 r
F P
0 g
s
.49784 .65877 m .49179 .64236 L .4917 .65641 L p .707 .577 .707 r
F P
0 g
s
.29144 .66952 m .28676 .6335 L .28807 .62276 L p .707 .577 .707 r
F P
0 g
s
.30013 .71324 m .30618 .72964 L .31547 .74022 L p .707 .577 .707 r
F P
0 g
s
.28807 .62276 m .29274 .65879 L .29144 .66952 L p .707 .577 .707 r
F P
0 g
s
.48824 .60239 m .49291 .63842 L .48435 .62921 L p .707 .577 .707 r
F P
0 g
s
.48435 .62921 m .47968 .59318 L .48824 .60239 L p .707 .577 .707 r
F P
0 g
s
.29157 .58122 m .2952 .5253 L .30894 .51925 L p .707 .577 .707 r
F P
0 g
s
.4891 .53596 m .48547 .59188 L .47026 .58424 L p .707 .577 .707 r
F P
0 g
s
.47026 .58424 m .47388 .52832 L .4891 .53596 L p .707 .577 .707 r
F P
0 g
s
.30618 .72964 m .30013 .71324 L .30022 .69919 L p .707 .577 .707 r
F P
0 g
s
.49179 .64236 m .49784 .65877 L .48855 .64819 L p .707 .577 .707 r
F P
0 g
s
.48855 .64819 m .4825 .63178 L .49179 .64236 L p .707 .577 .707 r
F P
0 g
s
.30894 .51925 m .30532 .57517 L .29157 .58122 L p .707 .577 .707 r
F P
0 g
s
.29274 .65879 m .28807 .62276 L .29911 .61156 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30022 .69919 m .30627 .7156 L .30618 .72964 L p .707 .577 .707 r
F P
0 g
s
.30532 .57517 m .30894 .51925 L .33091 .51506 L p .707 .577 .707 r
F P
0 g
s
.29911 .61156 m .30378 .64759 L .29274 .65879 L p .707 .577 .707 r
F P
0 g
s
.47968 .59318 m .48435 .62921 L .46677 .62242 L p .707 .577 .707 r
F P
0 g
s
.46677 .62242 m .4621 .5864 L .47968 .59318 L p .707 .577 .707 r
F P
0 g
s
.47388 .52832 m .47026 .58424 L .44712 .57757 L p .707 .577 .707 r
F P
0 g
s
.44712 .57757 m .45075 .52165 L .47388 .52832 L p .707 .577 .707 r
F P
0 g
s
.30627 .7156 m .30022 .69919 L .30968 .68305 L p .707 .577 .707 r
F P
0 g
s
.4825 .63178 m .48855 .64819 L .47079 .64212 L p .707 .577 .707 r
F P
0 g
s
.47079 .64212 m .46473 .62571 L .4825 .63178 L p .707 .577 .707 r
F P
0 g
s
.33091 .51506 m .32729 .57098 L .30532 .57517 L p .707 .577 .707 r
F P
0 g
s
.30378 .64759 m .29911 .61156 L .3188 .60098 L p .707 .577 .707 r
F P
0 g
s
.30968 .68305 m .31573 .69946 L .30627 .7156 L p .707 .577 .707 r
F P
0 g
s
.32729 .57098 m .33091 .51506 L .35896 .51313 L p .707 .577 .707 r
F P
0 g
s
.4621 .5864 m .46677 .62242 L .44189 .61872 L p .707 .577 .707 r
F P
0 g
s
.44189 .61872 m .43722 .5827 L .4621 .5864 L p .707 .577 .707 r
F P
0 g
s
.45075 .52165 m .44712 .57757 L .41833 .57251 L p .707 .577 .707 r
F P
0 g
s
.41833 .57251 m .42196 .5166 L .45075 .52165 L p .707 .577 .707 r
F P
0 g
s
.3188 .60098 m .32347 .63701 L .30378 .64759 L p .707 .577 .707 r
F P
0 g
s
.35896 .51313 m .35533 .56905 L .32729 .57098 L p .707 .577 .707 r
F P
0 g
s
.35533 .56905 m .35896 .51313 L .39033 .51366 L p .707 .577 .707 r
F P
0 g
s
.32347 .63701 m .3188 .60098 L .34521 .59206 L p .707 .577 .707 r
F P
0 g
s
.31573 .69946 m .30968 .68305 L .32758 .6664 L p .707 .577 .707 r
F P
0 g
s
.46473 .62571 m .47079 .64212 L .44629 .64115 L p .707 .577 .707 r
F P
0 g
s
.44629 .64115 m .44024 .62474 L .46473 .62571 L p .707 .577 .707 r
F P
0 g
s
.42196 .5166 m .41833 .57251 L .3867 .56958 L p .707 .577 .707 r
F P
0 g
s
.3867 .56958 m .39033 .51366 L .42196 .5166 L p .707 .577 .707 r
F P
0 g
s
.39033 .51366 m .3867 .56958 L .35533 .56905 L p .707 .577 .707 r
F P
0 g
s
.43722 .5827 m .44189 .61872 L .41214 .61848 L p .707 .577 .707 r
F P
0 g
s
.41214 .61848 m .40747 .58245 L .43722 .5827 L p .707 .577 .707 r
F P
0 g
s
.32758 .6664 m .33363 .68281 L .31573 .69946 L p .707 .577 .707 r
F P
0 g
s
.34521 .59206 m .34989 .62809 L .32347 .63701 L p .707 .577 .707 r
F P
0 g
s
.34989 .62809 m .34521 .59206 L .37577 .58568 L p .707 .577 .707 r
F P
0 g
s
.40747 .58245 m .41214 .61848 L .38044 .6217 L p .707 .577 .707 r
F P
0 g
s
.38044 .6217 m .37577 .58568 L .40747 .58245 L p .707 .577 .707 r
F P
0 g
s
.33363 .68281 m .32758 .6664 L .35218 .65086 L p .707 .577 .707 r
F P
0 g
s
.44024 .62474 m .44629 .64115 L .41746 .64537 L p .707 .577 .707 r
F P
0 g
s
.41746 .64537 m .41141 .62896 L .44024 .62474 L p .707 .577 .707 r
F P
0 g
s
.37577 .58568 m .38044 .6217 L .34989 .62809 L p .707 .577 .707 r
F P
0 g
s
.35218 .65086 m .35823 .66727 L .33363 .68281 L p .707 .577 .707 r
F P
0 g
s
.35823 .66727 m .35218 .65086 L .38107 .63796 L p .707 .577 .707 r
F P
0 g
s
.41141 .62896 m .41746 .64537 L .38712 .65437 L p .707 .577 .707 r
F P
0 g
s
.38712 .65437 m .38107 .63796 L .41141 .62896 L p .707 .577 .707 r
F P
0 g
s
.38107 .63796 m .38712 .65437 L .35823 .66727 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007=oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00Kgoo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001SOol70006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001KOol80003FUH01000FUIJEUYF400000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Egoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo0`001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol0059oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF000047oo3`00Agoo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
37oo100000=JEP00FUH01eYF00<005YFFUH00UYF2000?goo001BOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF000027oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Uoo`00DWoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000017oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Woo001BOol01@00FUIJEUYF00001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00=7oo001BOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
00001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
039oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080031oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF00<007ooOol0;Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0]Ool0055oo`8000=JEP04001JEUYFFUH80005FUH00`00FUIJEP06FUH0
0`00FUH000060006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Woo001AOol20003FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4
0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001A
Ool200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP@000AJEP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo
0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF4@0000IJEP00000005YF0003
FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF
00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P0000AJEP00FUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0059oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool005=oo`05001JEUYFFUH00005FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00UYF5`001UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool0
05Aoo`800004FUH005YFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000eYF00<005YFFUH00UYF1`002goo1@001Woo10000UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH0000^Ool005Ioo`D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUH000020003FUH01000FUIJEUYF2@00
0Woo1@002Goo1@001EYF00L005YFFUIJEP00FUH0000^Ool005Ioo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ0000EJEP@00003FUH005YF009JEP03001JEP0002ioo`00
?goo5`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF
00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0002ioo`00>goo100000=JEP00FUH01eYF
00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP00;Woo000fOol50005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0005FUH00`00FUIJEP02FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH400000eYF001oo`0]Ool0039oo`@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH90002FUH4
00000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002ioo`00<7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00IJEPh0009JEP03001JEP0000QJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<005YFFUH0
1P0015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00006FUH3
00000eYF001JEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00D005YFFUIJ
EP0000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUHQ0003FUH00`00Oomoo`0]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP8000AJEP05001JEUYFFUH0
0003FUH00`00FUIJEP020007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF10001eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00<00003FUH007oo02ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00`001EYF00D005YFFUIJEP0000=JEP@000UJ
EP03001JEUYF009JEP`000=JEP<000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH300000eYF001JEP060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<0009JEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH70006FUH00`00FUIJEP02FUH200000eYF0000
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH60005FUH01000FUIJEUYF0`001EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF001JEP00009JEP04001JEUYFFUH:0008FUH00`00FUH000020007FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002moo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH0
1EYF00<005YF00000P0025YF0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF0000;goo000]Ool00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH20002
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF0P001EYF
00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YF
000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH015YF4`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP800003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00EJEP<00006FUH005YFFUH005YF0P001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
;Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH20003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0004FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eo
o`03001JEP00009JEP04001JEUYFFUH60006FUH:0007FUH00`00FUH00003FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEP/000QJEP03001JEUYF
00=JEPL0009JEP03001JEP0002ioo`00;Goo00<005YF00000UYF10000eYF00<005YF00001`0015YF
00<005YFFUH00UYF2P0015YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP00008000MJEP<0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH01000FUIJEUYF200000=J
EP00FUH00eYF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000]Ool0
0`00FUH00002000015YF001JEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000=JEP00FUH00eYF10001eYF00<005YFFUH00eYF10001UYF10002EYF00H005YFFUH005YF
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF
FUIJEPL000QJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000^Ool002eoo`03001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP02FUH50002FUH40002
FUH00`00FUIJEP06FUH20004FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEP000UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo0`0000=JEP00000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF200015YF00<005YF
FUH00UYF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000UYF0P000UYF0P0000AJEP00FUIJEPh000QJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH300000eYF
00000003FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P00<goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEUYF00QJEP04001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00H005YF000005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006Ool2000^Ool002ioo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00001UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP04001J
EUYF0006FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=o
o`000000200000=JEP00Ool0;Goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP<000MJEP03001JEP0000aJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH>0004FUH00`00FUIJEP02FUH900000goo0000
00060003FUH00`00FUIJEP02FUH01000FUIJEP00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP800003FUH005YF00AJEP80009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00007FUH00`00FUIJ
EP04FUH00`00FUIJEP090003Ool70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF20002Goo200000=JEP00FUH00P001UYF00<0
05YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00007FUH00`00FUIJEP04FUH01000FUIJEUYF0P001Goo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;Woo00@005YFFUH000=JEPH000Ioo`T0
00Yoo`800004FUH000000005FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF
0P001UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP03FUH01000FUIJEUYF1`001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;Woo00D005YFFUH005YF0080
00Aoo`P000AJEP03001JEUYF009JEPH000Ioo`80009oo`8000=JEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00<000QJEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP080003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06000]Ool002ioo`03001JEUYF0080009o
o`@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000=oo`<000=oo`800003FUH0
05YF00=JEP8000=JEP03001JEUYF00=JEP@00003FUH005YF00MJEP8000QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH70003FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000cOol002ioo`03001J
EP0000D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<00003Ool005YF00<0
009oo`8000AJEP80009JEPL000IJEP03001JEUYF00=JEP8000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol002eoo`H0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP`000AJEP03001JEUYF00IJ
EP03001JEUYF00@000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP/003moo`00;Goo0P0000=JEP00FUH00UYF00<005YFFUH015YF3P0015YF00<005YFFUH01eYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEQ0004=oo`00;Goo10000eYF00<005YF
FUH010003Woo1P0025YF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH0000000H004Yoo`00
;Goo0P0000=JEP00FUH00UYF0`0015YF100047oo0`0015YF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03
001JEP0000X0059oo`00;Goo0`000UYF0P0000=JEP00FUH01EYF00<005YFFUH010003goo0`0000=J
EP00FUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH02EYF00<005YFFUH0
15YF60001UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00P0
0003FUH0000005Ioo`00;Goo00<005YF00000P000eYF00<005YFFUH015YF00<005YFFUH015YF5@00
1EYF3@001UYF00<005YFFUH01eYF20001UYF00<005YFFUH025YF00<005YF000015YF2@001eYF00<0
05YFFUH01EYF00@005YFFUIJEPH000MJEP04001JEUYFFUH2001DOol002eoo`04001JEP000004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJ
EP02000015YF001JEP000eYF00<005YFFUH015YF00<005YFFUH00eYF100000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YF00002eYF00<005YF000010000UYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP8005=oo`00;Goo100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00eYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YF00002eYF00<005YFFUH015YF10001UYF00D005YFFUIJEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00059oo`00;7oo0P000Woo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YF
00000eYF00<005YFFUH00eYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002eYF
00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF001BOol002aoo`8000=oo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEP0000<0009J
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJ
EP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH00007FUH00`00FUIJEP02FUH01000FUIJ
EP00DWoo000/Ool20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH20003FUH30003FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000
1eYF00<005YFFUH00UYF00@005YFFUH0059oo`00;7oo0`001Woo0P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF0080
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP80009JEPH000EJEP03001JEUYF00=JEP04001JEUYF001BOol002aoo`<0
00Qoo`@00003FUH005YF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH01@00FUH005YF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P000eYF00<0
05YF00000`0000=JEP00FUH015YF00@005YFFUH0059oo`00;7oo00@005YFFUH000]oo`<000IJEP03
001JEUYF00D00003FUH005YF00MJEP03001JEUYF00EJEP<00004Ool005YFFUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF0`000eYF00<005YFFUH0
0P00DWoo000/Ool01000FUIJEP003Woo10000UYF00<005YFFUH01@0000=JEP00FUH01eYF00<005YF
FUH00UYF100017oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
009JEP03001JEUYF00EJEP06001JEP00001JEP000UYF00<007ooOol0DGoo000/Ool01@00FUIJEUYF
00004Goo2P0000=JEP00FUH00eYF2@0027oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00Oomoo`1AOol0
02eoo`03001JEUYF008001Ioo`X0019oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001oo`1BOol002eoo`03001J
EP00009JEP80035oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YF000005=oo`00;Woo0P0015YF00<007ooOol0;Woo0P00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF001COol002moo`03001JEUYF00=JEP03001oogoo02aoo`H000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH0001COol0031oo`03001J
EUYF009JEP<002aoo`8000=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00001DOol0035oo`05001JEUYFFUH00002FUH2000YOol00`00FUH00005Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUIJEUYF1@0015YF00<005YFFUH01EYF00<005YFFUH01000EWoo000bOol200000eYF
001JEP03FUH2000UOol300000eYF001oo`06Ool300000eYF001JEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01`00FUH00000FUH005YF014005Yoo`00=7oo
0P001UYF0`0087oo0P000UYF0P002goo10001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH00UYF0`00IWoo000eOol20006FUH00`00FUH0
0003000JOol20003FUH2000@Ool50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060005FUH00`00FUIJEP05FUH3001SOol003Moo`8000=JEP03001JEUYF00AJEPL0
00moo`@00003FUH005YF009JEP8001Eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0009J
EP04001JEUYFFUH300000eYF001JEP08FUH00`00FUH00003001OOol003Uoo`800003FUH005YF00MJ
EP03001JEUYF009JEPl000EJEP05001JEUYFFUH0000OOolJ0003Ool20005FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP04FUH2001MOol003]oo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF008003moo`<00003FUH005YF00QJEP<000EJEP03001JEUYF00EJEP<0
05]oo`00?Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00A7oo0`00
25YF00<005YFFUH00`0000=JEP00FUH01UYF00@005YFFUIJEP8005Uoo`00@7oo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00eYF0P00BGoo0`0015YF00<005YFFUH015YF0`001UYF00<0
05YFFUH00eYF00<007ooOol0EWoo0013Ool60004FUH00`00FUIJEP06FUH00`00FUH00003001>Ool3
00000eYF001JEP07FUH30004FUH00`00FUIJEP03FUH3001FOol004Uoo`l005Eoo`<000MJEP03001J
EUYF00800003FUH005YF00AJEP04001JEUYF001FOol00;1oo`@0009JEP03001JEUYF00=JEP<000AJ
EP04001JEUYF001FOol00;Aoo`@000IJEP<00004FUH005YFFUH2001FOol00;Qoo`@00003FUH005YF
009JEP80009JEP03001oogoo05Eoo`00_7oo10000UYF1000Egoo0030Ool6001GOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60673 .75076 m .60451 .6955 L .57301 .69515 L p .707 .577 .707 r
F P
0 g
s
.60451 .6955 m .60673 .75076 L .63833 .74825 L p .707 .577 .707 r
F P
0 g
s
.63833 .74825 m .6361 .69299 L .60451 .6955 L p .707 .577 .707 r
F P
0 g
s
.6361 .69299 m .63833 .74825 L .66692 .74312 L p .707 .577 .707 r
F P
0 g
s
.66692 .74312 m .6647 .68787 L .6361 .69299 L p .707 .577 .707 r
F P
0 g
s
.57523 .75041 m .57301 .69515 L .54468 .69198 L p .707 .577 .707 r
F P
0 g
s
.57301 .69515 m .57523 .75041 L .60673 .75076 L p .707 .577 .707 r
F P
0 g
s
.6647 .68787 m .66692 .74312 L .68972 .73589 L p .707 .577 .707 r
F P
0 g
s
.68972 .73589 m .6875 .68063 L .6647 .68787 L p .707 .577 .707 r
F P
0 g
s
.54691 .74724 m .54468 .69198 L .52231 .6863 L p .707 .577 .707 r
F P
0 g
s
.54468 .69198 m .54691 .74724 L .57523 .75041 L p .707 .577 .707 r
F P
0 g
s
.61066 .80619 m .61352 .76888 L .58183 .76576 L p .707 .577 .707 r
F P
0 g
s
.61352 .76888 m .61066 .80619 L .64188 .80695 L p .707 .577 .707 r
F P
0 g
s
.64188 .80695 m .64474 .76964 L .61352 .76888 L p .707 .577 .707 r
F P
0 g
s
.57898 .80307 m .58183 .76576 L .55279 .76059 L p .707 .577 .707 r
F P
0 g
s
.58183 .76576 m .57898 .80307 L .61066 .80619 L p .707 .577 .707 r
F P
0 g
s
.64474 .76964 m .64188 .80695 L .66959 .80528 L p .707 .577 .707 r
F P
0 g
s
.66959 .80528 m .67245 .76797 L .64474 .76964 L p .707 .577 .707 r
F P
0 g
s
.55279 .76059 m .54993 .7979 L .57898 .80307 L p .707 .577 .707 r
F P
0 g
s
.60667 .84323 m .61041 .82464 L .57918 .81806 L p .707 .577 .707 r
F P
0 g
s
.61041 .82464 m .60667 .84323 L .63724 .84798 L p .707 .577 .707 r
F P
0 g
s
.63724 .84798 m .64097 .82939 L .61041 .82464 L p .707 .577 .707 r
F P
0 g
s
.52231 .6863 m .52453 .74155 L .54691 .74724 L p .707 .577 .707 r
F P
0 g
s
.54993 .7979 m .55279 .76059 L .52924 .75387 L p .707 .577 .707 r
F P
0 g
s
.57544 .83665 m .57918 .81806 L .55033 .81029 L p .707 .577 .707 r
F P
0 g
s
.57918 .81806 m .57544 .83665 L .60667 .84323 L p .707 .577 .707 r
F P
0 g
s
.6875 .68063 m .68972 .73589 L .70449 .72725 L p .707 .577 .707 r
F P
0 g
s
.70449 .72725 m .70227 .67199 L .6875 .68063 L p .707 .577 .707 r
F P
0 g
s
.55033 .81029 m .5466 .82888 L .57544 .83665 L p .707 .577 .707 r
F P
0 g
s
.52453 .74155 m .52231 .6863 L .50807 .67865 L p .707 .577 .707 r
F P
0 g
s
.64097 .82939 m .63724 .84798 L .66415 .85043 L p .707 .577 .707 r
F P
0 g
s
.66415 .85043 m .66788 .83185 L .64097 .82939 L p .707 .577 .707 r
F P
0 g
s
.67245 .76797 m .66959 .80528 L .69106 .80135 L p .707 .577 .707 r
F P
0 g
s
.69106 .80135 m .69392 .76404 L .67245 .76797 L p .707 .577 .707 r
F P
0 g
s
.52924 .75387 m .52638 .79118 L .54993 .7979 L p .707 .577 .707 r
F P
0 g
s
.5466 .82888 m .55033 .81029 L .52671 .80209 L p .707 .577 .707 r
F P
0 g
s
.52671 .80209 m .52297 .82068 L .5466 .82888 L p .707 .577 .707 r
F P
0 g
s
.52638 .79118 m .52924 .75387 L .51347 .74627 L p .707 .577 .707 r
F P
0 g
s
.50807 .67865 m .5103 .73391 L .52453 .74155 L p .707 .577 .707 r
F P
0 g
s
.66788 .83185 m .66415 .85043 L .68476 .85035 L p .707 .577 .707 r
F P
0 g
s
.68476 .85035 m .6885 .83176 L .66788 .83185 L p .707 .577 .707 r
F P
0 g
s
.70227 .67199 m .70449 .72725 L .70978 .71805 L p .707 .577 .707 r
F P
0 g
s
.70978 .71805 m .70756 .6628 L .70227 .67199 L p .707 .577 .707 r
F P
0 g
s
.51347 .74627 m .51061 .78358 L .52638 .79118 L p .707 .577 .707 r
F P
0 g
s
.69392 .76404 m .69106 .80135 L .70421 .79553 L p .707 .577 .707 r
F P
0 g
s
.70421 .79553 m .70707 .75822 L .69392 .76404 L p .707 .577 .707 r
F P
0 g
s
.52297 .82068 m .52671 .80209 L .51061 .79426 L p .707 .577 .707 r
F P
0 g
s
.5103 .73391 m .50807 .67865 L .50337 .6698 L p .707 .577 .707 r
F P
0 g
s
.51061 .79426 m .50687 .81285 L .52297 .82068 L p .707 .577 .707 r
F P
0 g
s
.51061 .78358 m .51347 .74627 L .50704 .73852 L p .707 .577 .707 r
F P
0 g
s
.6885 .83176 m .68476 .85035 L .69707 .84773 L p .707 .577 .707 r
F P
0 g
s
.69707 .84773 m .70081 .82914 L .6885 .83176 L p .707 .577 .707 r
F P
0 g
s
.50722 .72812 m .5103 .73391 L p .50769 .70979 L .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .50418 .77583 L .51061 .78358 L p .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .51056 .73139 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50418 .77583 m .50692 .74004 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50692 .74004 m .50704 .73852 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50337 .6698 m .5056 .72506 L .50722 .72812 L p .707 .577 .707 r
F P
0 g
s
.50769 .70979 m .50337 .6698 L .50722 .72812 L .707 .577 .707 r
F
.50687 .81285 m .51061 .79426 L .50361 .78758 L p F P
0 g
s
.70756 .6628 m .70978 .71805 L .70508 .7092 L p .707 .577 .707 r
F P
0 g
s
.70508 .7092 m .70286 .65394 L .70756 .6628 L p .707 .577 .707 r
F P
0 g
s
.70707 .75822 m .70421 .79553 L .70774 .7884 L p .707 .577 .707 r
F P
0 g
s
.70774 .7884 m .7106 .75109 L .70707 .75822 L p .707 .577 .707 r
F P
0 g
s
.50361 .78758 m .49987 .80617 L .50687 .81285 L p .707 .577 .707 r
F P
0 g
s
.5056 .72506 m .50337 .6698 L .50867 .66061 L p .707 .577 .707 r
F P
0 g
s
.48352 .82167 m .48352 .31978 L .44005 .31653 L p .707 .577 .707 r
F P
0 g
s
.50867 .66061 m .51089 .71586 L .5056 .72506 L p .707 .577 .707 r
F P
0 g
s
.51056 .73139 m .50771 .7687 L .50418 .77583 L p .707 .577 .707 r
F P
0 g
s
.49987 .80617 m .50361 .78758 L .5064 .78269 L p .707 .577 .707 r
F P
0 g
s
.5064 .78269 m .50266 .80127 L .49987 .80617 L p .707 .577 .707 r
F P
0 g
s
.51089 .71586 m .50867 .66061 L .52343 .65197 L p .707 .577 .707 r
F P
0 g
s
.50771 .7687 m .51056 .73139 L .52371 .72557 L p .707 .577 .707 r
F P
0 g
s
.52343 .65197 m .52566 .70722 L .51089 .71586 L p .707 .577 .707 r
F P
0 g
s
.52371 .72557 m .52085 .76288 L .50771 .7687 L p .707 .577 .707 r
F P
0 g
s
.50266 .80127 m .5064 .78269 L .5187 .78007 L p .707 .577 .707 r
F P
0 g
s
.5187 .78007 m .51497 .79866 L .50266 .80127 L p .707 .577 .707 r
F P
0 g
s
.52085 .76288 m .52371 .72557 L .54519 .72164 L p .707 .577 .707 r
F P
0 g
s
.54519 .72164 m .54233 .75894 L .52085 .76288 L p .707 .577 .707 r
F P
0 g
s
.51497 .79866 m .5187 .78007 L .53932 .77998 L p .707 .577 .707 r
F P
0 g
s
.53932 .77998 m .53558 .79857 L .51497 .79866 L p .707 .577 .707 r
F P
0 g
s
.48352 .31978 m .48352 .82167 L .52861 .82115 L p .707 .577 .707 r
F P
0 g
s
.52566 .70722 m .52343 .65197 L .54623 .64473 L p .707 .577 .707 r
F P
0 g
s
.54623 .64473 m .54846 .69999 L .52566 .70722 L p .707 .577 .707 r
F P
0 g
s
.52861 .82115 m .52861 .31927 L .48352 .31978 L p .707 .577 .707 r
F P
0 g
s
.54846 .69999 m .54623 .64473 L .57483 .63961 L p .707 .577 .707 r
F P
0 g
s
.57483 .63961 m .57705 .69486 L .54846 .69999 L p .707 .577 .707 r
F P
0 g
s
.54233 .75894 m .54519 .72164 L .5729 .71997 L p .707 .577 .707 r
F P
0 g
s
.5729 .71997 m .57004 .75728 L .54233 .75894 L p .707 .577 .707 r
F P
0 g
s
.53558 .79857 m .53932 .77998 L .56623 .78243 L p .707 .577 .707 r
F P
0 g
s
.56623 .78243 m .56249 .80102 L .53558 .79857 L p .707 .577 .707 r
F P
0 g
s
.56249 .80102 m .56623 .78243 L .5968 .78718 L p .707 .577 .707 r
F P
0 g
s
.5968 .78718 m .59306 .80577 L .56249 .80102 L p .707 .577 .707 r
F P
0 g
s
.52861 .31927 m .52861 .82115 L .5709 .81692 L p .707 .577 .707 r
F P
0 g
s
.57004 .75728 m .5729 .71997 L .60412 .72073 L p .707 .577 .707 r
F P
0 g
s
.60412 .72073 m .60126 .75804 L .57004 .75728 L p .707 .577 .707 r
F P
0 g
s
.5709 .81692 m .5709 .31504 L .52861 .31927 L p .707 .577 .707 r
F P
0 g
s
.44005 .81842 m .44005 .31653 L .40244 .30984 L p .707 .577 .707 r
F P
0 g
s
.44005 .31653 m .44005 .81842 L .48352 .82167 L p .707 .577 .707 r
F P
0 g
s
.70081 .82914 m .69707 .84773 L .69986 .84284 L p .707 .577 .707 r
F P
0 g
s
.69986 .84284 m .7036 .82425 L .70081 .82914 L p .707 .577 .707 r
F P
0 g
s
.57705 .69486 m .57483 .63961 L .60642 .6371 L p .707 .577 .707 r
F P
0 g
s
.60642 .6371 m .60865 .69235 L .57705 .69486 L p .707 .577 .707 r
F P
0 g
s
.6358 .72385 m .63294 .76116 L .60126 .75804 L p .707 .577 .707 r
F P
0 g
s
.60126 .75804 m .60412 .72073 L .6358 .72385 L p .707 .577 .707 r
F P
0 g
s
.62803 .79377 m .62429 .81235 L .59306 .80577 L p .707 .577 .707 r
F P
0 g
s
.59306 .80577 m .5968 .78718 L .62803 .79377 L p .707 .577 .707 r
F P
0 g
s
.5709 .31504 m .5709 .81692 L .60625 .8094 L p .707 .577 .707 r
F P
0 g
s
.60625 .8094 m .60625 .30751 L .5709 .31504 L p .707 .577 .707 r
F P
0 g
s
.70286 .65394 m .70508 .7092 L .69085 .70156 L p .707 .577 .707 r
F P
0 g
s
.69085 .70156 m .68862 .6463 L .70286 .65394 L p .707 .577 .707 r
F P
0 g
s
.26102 .7104 m .26004 .6543 L .22852 .65358 L p .707 .577 .707 r
F P
0 g
s
.26004 .6543 m .26102 .7104 L .29263 .70878 L p .707 .577 .707 r
F P
0 g
s
.29263 .70878 m .29166 .65268 L .26004 .6543 L p .707 .577 .707 r
F P
0 g
s
.7106 .75109 m .70774 .7884 L .70131 .78065 L p .707 .577 .707 r
F P
0 g
s
.70131 .78065 m .70417 .74334 L .7106 .75109 L p .707 .577 .707 r
F P
0 g
s
.29166 .65268 m .29263 .70878 L .32124 .70499 L p .707 .577 .707 r
F P
0 g
s
.32124 .70499 m .32027 .64889 L .29166 .65268 L p .707 .577 .707 r
F P
0 g
s
.2295 .70968 m .22852 .65358 L .20018 .6506 L p .707 .577 .707 r
F P
0 g
s
.22852 .65358 m .2295 .70968 L .26102 .7104 L p .707 .577 .707 r
F P
0 g
s
.40244 .81173 m .40244 .30984 L .37438 .30035 L p .707 .577 .707 r
F P
0 g
s
.40244 .30984 m .40244 .81173 L .44005 .81842 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63792 .63744 m .64015 .6927 L .60865 .69235 L p .707 .577 .707 r
F P
0 g
s
.60865 .69235 m .60642 .6371 L .63792 .63744 L p .707 .577 .707 r
F P
0 g
s
.62429 .81235 m .62803 .79377 L .65687 .80154 L p .707 .577 .707 r
F P
0 g
s
.60625 .30751 m .60625 .8094 L .63119 .79931 L p .707 .577 .707 r
F P
0 g
s
.63119 .79931 m .63119 .29742 L .60625 .30751 L p .707 .577 .707 r
F P
0 g
s
.32027 .64889 m .32124 .70499 L .34405 .6994 L p .707 .577 .707 r
F P
0 g
s
.34405 .6994 m .34308 .6433 L .32027 .64889 L p .707 .577 .707 r
F P
0 g
s
.20018 .6506 m .20115 .7067 L .2295 .70968 L p .707 .577 .707 r
F P
0 g
s
.7036 .82425 m .69986 .84284 L .69286 .83615 L p .707 .577 .707 r
F P
0 g
s
.69286 .83615 m .6966 .81756 L .7036 .82425 L p .707 .577 .707 r
F P
0 g
s
.20115 .7067 m .20018 .6506 L .17779 .64565 L p .707 .577 .707 r
F P
0 g
s
.26595 .7805 m .26722 .74423 L .23547 .74207 L p .707 .577 .707 r
F P
0 g
s
.26722 .74423 m .26595 .7805 L .29724 .77933 L p .707 .577 .707 r
F P
0 g
s
.29724 .77933 m .29851 .74306 L .26722 .74423 L p .707 .577 .707 r
F P
0 g
s
.2342 .77834 m .23547 .74207 L .20635 .7368 L p .707 .577 .707 r
F P
0 g
s
.23547 .74207 m .2342 .77834 L .26595 .7805 L p .707 .577 .707 r
F P
0 g
s
.68862 .6463 m .69085 .70156 L .66847 .69587 L p .707 .577 .707 r
F P
0 g
s
.66847 .69587 m .66625 .64061 L .68862 .6463 L p .707 .577 .707 r
F P
0 g
s
.29851 .74306 m .29724 .77933 L .325 .77495 L p .707 .577 .707 r
F P
0 g
s
.325 .77495 m .32627 .73868 L .29851 .74306 L p .707 .577 .707 r
F P
0 g
s
.70417 .74334 m .70131 .78065 L .68554 .77305 L p .707 .577 .707 r
F P
0 g
s
.68554 .77305 m .6884 .73574 L .70417 .74334 L p .707 .577 .707 r
F P
0 g
s
.17779 .64565 m .17876 .70175 L .20115 .7067 L p .707 .577 .707 r
F P
0 g
s
.20508 .77307 m .20635 .7368 L .18273 .72892 L p .707 .577 .707 r
F P
0 g
s
.20635 .7368 m .20508 .77307 L .2342 .77834 L p .707 .577 .707 r
F P
0 g
s
.34308 .6433 m .34405 .6994 L .35882 .69255 L p .707 .577 .707 r
F P
0 g
s
.35882 .69255 m .35785 .63645 L .34308 .6433 L p .707 .577 .707 r
F P
0 g
s
.17876 .70175 m .17779 .64565 L .16354 .63922 L p .707 .577 .707 r
F P
0 g
s
.37438 .80224 m .37438 .30035 L .35862 .28901 L p .707 .577 .707 r
F P
0 g
s
.37438 .30035 m .37438 .80224 L .40244 .81173 L p .707 .577 .707 r
F P
0 g
s
.32627 .73868 m .325 .77495 L .34651 .76778 L p .707 .577 .707 r
F P
0 g
s
.34651 .76778 m .34778 .73151 L .32627 .73868 L p .707 .577 .707 r
F P
0 g
s
.26585 .83079 m .26754 .81348 L .23581 .80979 L p .707 .577 .707 r
F P
0 g
s
.26754 .81348 m .26585 .83079 L .29687 .83015 L p .707 .577 .707 r
F P
0 g
s
.29687 .83015 m .29855 .81283 L .26754 .81348 L p .707 .577 .707 r
F P
0 g
s
.66625 .64061 m .66847 .69587 L .64015 .6927 L p .707 .577 .707 r
F P
0 g
s
.64015 .6927 m .63792 .63744 L .66625 .64061 L p .707 .577 .707 r
F P
0 g
s
.6966 .81756 m .69286 .83615 L .67676 .82833 L p .707 .577 .707 r
F P
0 g
s
.67676 .82833 m .6805 .80974 L .6966 .81756 L p .707 .577 .707 r
F P
0 g
s
.23412 .82711 m .23581 .80979 L .20647 .80214 L p .707 .577 .707 r
F P
0 g
s
.23581 .80979 m .23412 .82711 L .26585 .83079 L p .707 .577 .707 r
F P
0 g
s
.18273 .72892 m .18146 .76519 L .20508 .77307 L p .707 .577 .707 r
F P
0 g
s
.66484 .72902 m .66198 .76633 L .63294 .76116 L p .707 .577 .707 r
F P
0 g
s
.63294 .76116 m .6358 .72385 L .66484 .72902 L p .707 .577 .707 r
F P
0 g
s
.63119 .29742 m .63119 .79931 L .6433 .78764 L p .707 .577 .707 r
F P
0 g
s
.6433 .78764 m .6433 .28575 L .63119 .29742 L p .707 .577 .707 r
F P
0 g
s
.16354 .63922 m .16451 .69532 L .17876 .70175 L p .707 .577 .707 r
F P
0 g
s
.29855 .81283 m .29687 .83015 L .32413 .82525 L p .707 .577 .707 r
F P
0 g
s
.32413 .82525 m .32581 .80793 L .29855 .81283 L p .707 .577 .707 r
F P
0 g
s
.18146 .76519 m .18273 .72892 L .16691 .71922 L p .707 .577 .707 r
F P
0 g
s
.6884 .73574 m .68554 .77305 L .66198 .76633 L p .707 .577 .707 r
F P
0 g
s
.66198 .76633 m .66484 .72902 L .6884 .73574 L p .707 .577 .707 r
F P
0 g
s
.20647 .80214 m .20479 .81946 L .23412 .82711 L p .707 .577 .707 r
F P
0 g
s
.20479 .81946 m .20647 .80214 L .18239 .79128 L p .707 .577 .707 r
F P
0 g
s
.34778 .73151 m .34651 .76778 L .35967 .75852 L p .707 .577 .707 r
F P
0 g
s
.35967 .75852 m .36094 .72226 L .34778 .73151 L p .707 .577 .707 r
F P
0 g
s
.35785 .63645 m .35882 .69255 L .36411 .68511 L p .707 .577 .707 r
F P
0 g
s
.36411 .68511 m .36314 .62901 L .35785 .63645 L p .707 .577 .707 r
F P
0 g
s
.18239 .79128 m .18071 .80859 L .20479 .81946 L p .707 .577 .707 r
F P
0 g
s
.16451 .69532 m .16354 .63922 L .15883 .63193 L p .707 .577 .707 r
F P
0 g
s
.16691 .71922 m .16564 .75549 L .18146 .76519 L p .707 .577 .707 r
F P
0 g
s
.32581 .80793 m .32413 .82525 L .34497 .81656 L p .707 .577 .707 r
F P
0 g
s
.34497 .81656 m .34666 .79924 L .32581 .80793 L p .707 .577 .707 r
F P
0 g
s
.6805 .80974 m .67676 .82833 L .65313 .82013 L p .707 .577 .707 r
F P
0 g
s
.65313 .82013 m .65687 .80154 L .6805 .80974 L p .707 .577 .707 r
F P
0 g
s
.18071 .80859 m .18239 .79128 L .16594 .77826 L p .707 .577 .707 r
F P
0 g
s
.16564 .75549 m .16691 .71922 L .16044 .70863 L p .707 .577 .707 r
F P
0 g
s
.15883 .63193 m .1598 .68803 L .16451 .69532 L p .707 .577 .707 r
F P
0 g
s
.35736 .80494 m .35904 .78763 L .34666 .79924 L p .707 .577 .707 r
F P
0 g
s
.3594 .67782 m .35843 .62172 L .36314 .62901 L p .707 .577 .707 r
F P
0 g
s
.36094 .72226 m .35967 .75852 L .36319 .7481 L p .707 .577 .707 r
F P
0 g
s
.36319 .7481 m .36446 .71183 L .36094 .72226 L p .707 .577 .707 r
F P
0 g
s
.36446 .71183 m .36319 .7481 L .35672 .73751 L p .707 .577 .707 r
F P
0 g
s
.35672 .73751 m .35799 .70124 L .36446 .71183 L p .707 .577 .707 r
F P
0 g
s
.35843 .62172 m .3594 .67782 L .34515 .67139 L p .707 .577 .707 r
F P
0 g
s
.34515 .67139 m .34418 .61529 L .35843 .62172 L p .707 .577 .707 r
F P
0 g
s
.35904 .78763 m .35736 .80494 L .36007 .79153 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .36175 .77421 L .35904 .78763 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .35284 .77763 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.36175 .77421 m .3614 .77779 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.3614 .77779 m .36007 .79153 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .3567 .27691 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .35453 .76032 L .36136 .77346 L p .707 .577 .707 r
F P
0 g
s
.36136 .77346 m .36175 .77421 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .36136 .77346 L .36137 .77436 L .707 .577 .707 r
F
.35799 .70124 m .35672 .73751 L .3409 .7278 L p F P
0 g
s
.3409 .7278 m .34217 .69154 L .35799 .70124 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .35862 .7909 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .27691 m .3567 .28823 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .28823 m .3567 .7788 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .7909 m .35862 .48812 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .48812 m .35862 .28901 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.36314 .62901 m .36411 .68511 L .3594 .67782 L p .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .35862 .7909 L .37438 .80224 L p .707 .577 .707 r
F P
0 g
s
.16594 .77826 m .16426 .79557 L .18071 .80859 L p .707 .577 .707 r
F P
0 g
s
.34666 .79924 m .34497 .81656 L .35736 .80494 L p .707 .577 .707 r
F P
0 g
s
.6433 .28575 m .6433 .78764 L .64138 .77554 L p .707 .577 .707 r
F P
0 g
s
.64138 .77554 m .64138 .27365 L .6433 .28575 L p .707 .577 .707 r
F P
0 g
s
.16044 .70863 m .15917 .7449 L .16564 .75549 L p .707 .577 .707 r
F P
0 g
s
.65687 .80154 m .65313 .82013 L .62429 .81235 L p .707 .577 .707 r
F P
0 g
s
.1598 .68803 m .15883 .63193 L .16412 .62449 L p .707 .577 .707 r
F P
0 g
s
.16426 .79557 m .16594 .77826 L .15871 .76436 L p .707 .577 .707 r
F P
0 g
s
.15871 .76436 m .15703 .78168 L .16426 .79557 L p .707 .577 .707 r
F P
0 g
s
.15917 .7449 m .16044 .70863 L .16396 .6982 L p .707 .577 .707 r
F P
0 g
s
.16412 .62449 m .16509 .68059 L .1598 .68803 L p .707 .577 .707 r
F P
0 g
s
.16396 .6982 m .16269 .73447 L .15917 .7449 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .3567 .27691 L .3688 .26524 L p .707 .577 .707 r
F P
0 g
s
.15703 .78168 m .15871 .76436 L .16143 .75095 L p .707 .577 .707 r
F P
0 g
s
.16509 .68059 m .16412 .62449 L .17889 .61764 L p .707 .577 .707 r
F P
0 g
s
.16143 .75095 m .15974 .76826 L .15703 .78168 L p .707 .577 .707 r
F P
0 g
s
.64138 .27365 m .64138 .77554 L .62562 .76419 L p .707 .577 .707 r
F P
0 g
s
.62562 .76419 m .62562 .2623 L .64138 .27365 L p .707 .577 .707 r
F P
0 g
s
.16269 .73447 m .16396 .6982 L .17712 .68895 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17889 .61764 m .17986 .67374 L .16509 .68059 L p .707 .577 .707 r
F P
0 g
s
.17712 .68895 m .17585 .72522 L .16269 .73447 L p .707 .577 .707 r
F P
0 g
s
.34418 .61529 m .34515 .67139 L .32276 .66644 L p .707 .577 .707 r
F P
0 g
s
.32276 .66644 m .32178 .61034 L .34418 .61529 L p .707 .577 .707 r
F P
0 g
s
.15974 .76826 m .16143 .75095 L .17381 .73933 L p .707 .577 .707 r
F P
0 g
s
.17986 .67374 m .17889 .61764 L .20169 .61205 L p .707 .577 .707 r
F P
0 g
s
.17381 .73933 m .17213 .75664 L .15974 .76826 L p .707 .577 .707 r
F P
0 g
s
.3688 .76713 m .3688 .26524 L .39375 .25515 L p .707 .577 .707 r
F P
0 g
s
.3688 .26524 m .3688 .76713 L .3567 .7788 L p .707 .577 .707 r
F P
0 g
s
.17585 .72522 m .17712 .68895 L .19863 .68178 L p .707 .577 .707 r
F P
0 g
s
.20169 .61205 m .20267 .66815 L .17986 .67374 L p .707 .577 .707 r
F P
0 g
s
.35453 .76032 m .35284 .77763 L .33639 .76461 L p .707 .577 .707 r
F P
0 g
s
.33639 .76461 m .33807 .7473 L .35453 .76032 L p .707 .577 .707 r
F P
0 g
s
.32178 .61034 m .32276 .66644 L .29441 .66346 L p .707 .577 .707 r
F P
0 g
s
.29441 .66346 m .29344 .60736 L .32178 .61034 L p .707 .577 .707 r
F P
0 g
s
.34217 .69154 m .3409 .7278 L .31728 .71993 L p .707 .577 .707 r
F P
0 g
s
.31728 .71993 m .31855 .68366 L .34217 .69154 L p .707 .577 .707 r
F P
0 g
s
.62562 .2623 m .62562 .76419 L .59756 .75471 L p .707 .577 .707 r
F P
0 g
s
.59756 .75471 m .59756 .25282 L .62562 .2623 L p .707 .577 .707 r
F P
0 g
s
.20267 .66815 m .20169 .61205 L .23031 .60826 L p .707 .577 .707 r
F P
0 g
s
.19863 .68178 m .19736 .71805 L .17585 .72522 L p .707 .577 .707 r
F P
0 g
s
.17213 .75664 m .17381 .73933 L .19465 .73064 L p .707 .577 .707 r
F P
0 g
s
.19736 .71805 m .19863 .68178 L .22639 .6774 L p .707 .577 .707 r
F P
0 g
s
.29344 .60736 m .29441 .66346 L .26289 .66274 L p .707 .577 .707 r
F P
0 g
s
.26289 .66274 m .26192 .60664 L .29344 .60736 L p .707 .577 .707 r
F P
0 g
s
.23031 .60826 m .23128 .66436 L .20267 .66815 L p .707 .577 .707 r
F P
0 g
s
.19465 .73064 m .19297 .74796 L .17213 .75664 L p .707 .577 .707 r
F P
0 g
s
.23128 .66436 m .23031 .60826 L .26192 .60664 L p .707 .577 .707 r
F P
0 g
s
.26192 .60664 m .26289 .66274 L .23128 .66436 L p .707 .577 .707 r
F P
0 g
s
.31855 .68366 m .31728 .71993 L .28816 .71465 L p .707 .577 .707 r
F P
0 g
s
.28816 .71465 m .28943 .67839 L .31855 .68366 L p .707 .577 .707 r
F P
0 g
s
.33807 .7473 m .33639 .76461 L .31231 .75375 L p .707 .577 .707 r
F P
0 g
s
.31231 .75375 m .314 .73643 L .33807 .7473 L p .707 .577 .707 r
F P
0 g
s
.73711 .65978 m .73808 .6048 L .70656 .60269 L p .707 .577 .707 r
F P
0 g
s
.73808 .6048 m .73711 .65978 L .76872 .65886 L p .707 .577 .707 r
F P
0 g
s
.76872 .65886 m .76969 .60388 L .73808 .6048 L p .707 .577 .707 r
F P
0 g
s
.22639 .6774 m .22512 .71367 L .19736 .71805 L p .707 .577 .707 r
F P
0 g
s
.39375 .25515 m .39375 .75704 L .3688 .76713 L p .707 .577 .707 r
F P
0 g
s
.39375 .75704 m .39375 .25515 L .4291 .24762 L p .707 .577 .707 r
F P
0 g
s
.22512 .71367 m .22639 .6774 L .25768 .67623 L p .707 .577 .707 r
F P
0 g
s
.19297 .74796 m .19465 .73064 L .22192 .72574 L p .707 .577 .707 r
F P
0 g
s
.76969 .60388 m .76872 .65886 L .79733 .655 L p .707 .577 .707 r
F P
0 g
s
.79733 .655 m .7983 .60002 L .76969 .60388 L p .707 .577 .707 r
F P
0 g
s
.70558 .65767 m .70656 .60269 L .67821 .59776 L p .707 .577 .707 r
F P
0 g
s
.70656 .60269 m .70558 .65767 L .73711 .65978 L p .707 .577 .707 r
F P
0 g
s
.28943 .67839 m .28816 .71465 L .25641 .7125 L p .707 .577 .707 r
F P
0 g
s
.25641 .7125 m .25768 .67623 L .28943 .67839 L p .707 .577 .707 r
F P
0 g
s
.59756 .25282 m .59756 .75471 L .55995 .74802 L p .707 .577 .707 r
F P
0 g
s
.55995 .74802 m .55995 .24613 L .59756 .25282 L p .707 .577 .707 r
F P
0 g
s
.25768 .67623 m .25641 .7125 L .22512 .71367 L p .707 .577 .707 r
F P
0 g
s
.22192 .72574 m .22023 .74305 L .19297 .74796 L p .707 .577 .707 r
F P
0 g
s
.314 .73643 m .31231 .75375 L .28298 .7461 L p .707 .577 .707 r
F P
0 g
s
.28298 .7461 m .28466 .72878 L .314 .73643 L p .707 .577 .707 r
F P
0 g
s
.7983 .60002 m .79733 .655 L .82014 .64857 L p .707 .577 .707 r
F P
0 g
s
.82014 .64857 m .82111 .5936 L .7983 .60002 L p .707 .577 .707 r
F P
0 g
s
.67724 .65273 m .67821 .59776 L .65582 .59048 L p .707 .577 .707 r
F P
0 g
s
.67821 .59776 m .67724 .65273 L .70558 .65767 L p .707 .577 .707 r
F P
0 g
s
.22023 .74305 m .22192 .72574 L .25293 .7251 L p .707 .577 .707 r
F P
0 g
s
.74359 .71019 m .74232 .67256 L .71056 .67287 L p .707 .577 .707 r
F P
0 g
s
.74232 .67256 m .74359 .71019 L .77488 .70786 L p .707 .577 .707 r
F P
0 g
s
.77488 .70786 m .77361 .67023 L .74232 .67256 L p .707 .577 .707 r
F P
0 g
s
.28466 .72878 m .28298 .7461 L .25125 .74241 L p .707 .577 .707 r
F P
0 g
s
.25125 .74241 m .25293 .7251 L .28466 .72878 L p .707 .577 .707 r
F P
0 g
s
.71184 .71051 m .71056 .67287 L .68145 .67113 L p .707 .577 .707 r
F P
0 g
s
.71056 .67287 m .71184 .71051 L .74359 .71019 L p .707 .577 .707 r
F P
0 g
s
.25293 .7251 m .25125 .74241 L .22023 .74305 L p .707 .577 .707 r
F P
0 g
s
.4291 .74951 m .4291 .24762 L .47139 .24339 L p .707 .577 .707 r
F P
0 g
s
.4291 .24762 m .4291 .74951 L .39375 .75704 L p .707 .577 .707 r
F P
0 g
s
.77361 .67023 m .77488 .70786 L .80264 .70374 L p .707 .577 .707 r
F P
0 g
s
.80264 .70374 m .80137 .6661 L .77361 .67023 L p .707 .577 .707 r
F P
0 g
s
.74875 .74253 m .74707 .72347 L .71534 .72597 L p .707 .577 .707 r
F P
0 g
s
.74707 .72347 m .74875 .74253 L .77976 .73909 L p .707 .577 .707 r
F P
0 g
s
.77976 .73909 m .77808 .72002 L .74707 .72347 L p .707 .577 .707 r
F P
0 g
s
.55995 .24613 m .55995 .74802 L .51648 .74477 L p .707 .577 .707 r
F P
0 g
s
.51648 .74477 m .51648 .24288 L .55995 .24613 L p .707 .577 .707 r
F P
0 g
s
.68145 .67113 m .68272 .70876 L .71184 .71051 L p .707 .577 .707 r
F P
0 g
s
.71534 .72597 m .71702 .74503 L .74875 .74253 L p .707 .577 .707 r
F P
0 g
s
.71702 .74503 m .71534 .72597 L .686 .72728 L p .707 .577 .707 r
F P
0 g
s
.65582 .59048 m .65485 .64545 L .67724 .65273 L p .707 .577 .707 r
F P
0 g
s
.686 .72728 m .68768 .74634 L .71702 .74503 L p .707 .577 .707 r
F P
0 g
s
.68272 .70876 m .68145 .67113 L .65783 .66751 L p .707 .577 .707 r
F P
0 g
s
.77808 .72002 m .77976 .73909 L .80703 .73504 L p .707 .577 .707 r
F P
0 g
s
.80703 .73504 m .80534 .71597 L .77808 .72002 L p .707 .577 .707 r
F P
0 g
s
.82111 .5936 m .82014 .64857 L .83491 .64021 L p .707 .577 .707 r
F P
0 g
s
.83491 .64021 m .83588 .58524 L .82111 .5936 L p .707 .577 .707 r
F P
0 g
s
.65485 .64545 m .65582 .59048 L .64157 .58157 L p .707 .577 .707 r
F P
0 g
s
.47139 .74528 m .47139 .24339 L .51648 .24288 L p .707 .577 .707 r
F P
0 g
s
.47139 .24339 m .47139 .74528 L .4291 .74951 L p .707 .577 .707 r
F P
0 g
s
.80137 .6661 m .80264 .70374 L .82415 .69823 L p .707 .577 .707 r
F P
0 g
s
.82415 .69823 m .82288 .66059 L .80137 .6661 L p .707 .577 .707 r
F P
0 g
s
.51648 .24288 m .51648 .74477 L .47139 .74528 L p .707 .577 .707 r
F P
0 g
s
.65783 .66751 m .6591 .70514 L .68272 .70876 L p .707 .577 .707 r
F P
0 g
s
.68768 .74634 m .686 .72728 L .66193 .72727 L p .707 .577 .707 r
F P
0 g
s
.66193 .72727 m .66361 .74633 L .68768 .74634 L p .707 .577 .707 r
F P
0 g
s
.80534 .71597 m .80703 .73504 L .82787 .73077 L p .707 .577 .707 r
F P
0 g
s
.82787 .73077 m .82619 .71171 L .80534 .71597 L p .707 .577 .707 r
F P
0 g
s
.64157 .58157 m .6406 .63655 L .65485 .64545 L p .707 .577 .707 r
F P
0 g
s
.6591 .70514 m .65783 .66751 L .64201 .66236 L p .707 .577 .707 r
F P
0 g
s
.82288 .66059 m .82415 .69823 L .83731 .69187 L p .707 .577 .707 r
F P
0 g
s
.83731 .69187 m .83604 .65423 L .82288 .66059 L p .707 .577 .707 r
F P
0 g
s
.83588 .58524 m .83491 .64021 L .8402 .63074 L p .707 .577 .707 r
F P
0 g
s
.8402 .63074 m .84117 .57576 L .83588 .58524 L p .707 .577 .707 r
F P
0 g
s
.6406 .63655 m .64157 .58157 L .63686 .57191 L p .707 .577 .707 r
F P
0 g
s
.64201 .66236 m .64328 .7 L .6591 .70514 L p .707 .577 .707 r
F P
0 g
s
.66361 .74633 m .66193 .72727 L .64547 .72594 L p .707 .577 .707 r
F P
0 g
s
.64547 .72594 m .64715 .745 L .66361 .74633 L p .707 .577 .707 r
F P
0 g
s
.82619 .71171 m .82787 .73077 L .84026 .72672 L p .707 .577 .707 r
F P
0 g
s
.84026 .72672 m .83857 .70766 L .82619 .71171 L p .707 .577 .707 r
F P
0 g
s
.63686 .57191 m .63589 .62689 L .6406 .63655 L p .707 .577 .707 r
F P
0 g
s
.64328 .7 m .64201 .66236 L .63554 .65619 L p .707 .577 .707 r
F P
0 g
s
.83604 .65423 m .83731 .69187 L .84083 .68528 L p .707 .577 .707 r
F P
0 g
s
.84083 .68528 m .83955 .64764 L .83604 .65423 L p .707 .577 .707 r
F P
0 g
s
.63554 .65619 m .63681 .69383 L .64328 .7 L p .707 .577 .707 r
F P
0 g
s
.64715 .745 m .64547 .72594 L .63825 .72343 L p .707 .577 .707 r
F P
0 g
s
.84117 .57576 m .8402 .63074 L .83549 .62107 L p .707 .577 .707 r
F P
0 g
s
.83549 .62107 m .83646 .5661 L .84117 .57576 L p .707 .577 .707 r
F P
0 g
s
.63589 .62689 m .63686 .57191 L .64215 .56244 L p .707 .577 .707 r
F P
0 g
s
.63825 .72343 m .63993 .74249 L .64715 .745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83857 .70766 m .84026 .72672 L .84297 .72327 L p .707 .577 .707 r
F P
0 g
s
.84297 .72327 m .84128 .7042 L .83857 .70766 L p .707 .577 .707 r
F P
0 g
s
.64215 .56244 m .64118 .61741 L .63589 .62689 L p .707 .577 .707 r
F P
0 g
s
.63681 .69383 m .63554 .65619 L .63906 .6496 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63906 .6496 m .64033 .68724 L .63681 .69383 L p .707 .577 .707 r
F P
0 g
s
.83955 .64764 m .84083 .68528 L .83436 .67911 L p .707 .577 .707 r
F P
0 g
s
.83436 .67911 m .83309 .64147 L .83955 .64764 L p .707 .577 .707 r
F P
0 g
s
.39135 .61944 m .39357 .56363 L .36207 .56113 L p .707 .577 .707 r
F P
0 g
s
.39357 .56363 m .39135 .61944 L .42294 .61944 L p .707 .577 .707 r
F P
0 g
s
.42294 .61944 m .42517 .56363 L .39357 .56363 L p .707 .577 .707 r
F P
0 g
s
.83646 .5661 m .83549 .62107 L .82124 .61217 L p .707 .577 .707 r
F P
0 g
s
.82124 .61217 m .82221 .55719 L .83646 .5661 L p .707 .577 .707 r
F P
0 g
s
.63993 .74249 m .63825 .72343 L .64096 .71998 L p .707 .577 .707 r
F P
0 g
s
.64118 .61741 m .64215 .56244 L .65692 .55408 L p .707 .577 .707 r
F P
0 g
s
.64096 .71998 m .64264 .73904 L .63993 .74249 L p .707 .577 .707 r
F P
0 g
s
.35985 .61693 m .36207 .56113 L .33375 .55636 L p .707 .577 .707 r
F P
0 g
s
.36207 .56113 m .35985 .61693 L .39135 .61944 L p .707 .577 .707 r
F P
0 g
s
.42517 .56363 m .42294 .61944 L .45154 .61693 L p .707 .577 .707 r
F P
0 g
s
.45154 .61693 m .45377 .56112 L .42517 .56363 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84128 .7042 m .84297 .72327 L .83574 .72075 L p .707 .577 .707 r
F P
0 g
s
.83574 .72075 m .83406 .70169 L .84128 .7042 L p .707 .577 .707 r
F P
0 g
s
.65692 .55408 m .65595 .60905 L .64118 .61741 L p .707 .577 .707 r
F P
0 g
s
.33152 .61216 m .33375 .55636 L .31137 .54979 L p .707 .577 .707 r
F P
0 g
s
.33375 .55636 m .33152 .61216 L .35985 .61693 L p .707 .577 .707 r
F P
0 g
s
.45377 .56112 m .45154 .61693 L .47434 .61216 L p .707 .577 .707 r
F P
0 g
s
.47434 .61216 m .47656 .55635 L .45377 .56112 L p .707 .577 .707 r
F P
0 g
s
.39874 .68458 m .39588 .64803 L .3642 .64921 L p .707 .577 .707 r
F P
0 g
s
.39588 .64803 m .39874 .68458 L .42996 .6804 L p .707 .577 .707 r
F P
0 g
s
.42996 .6804 m .4271 .64386 L .39588 .64803 L p .707 .577 .707 r
F P
0 g
s
.64033 .68724 m .63906 .6496 L .65222 .64324 L p .707 .577 .707 r
F P
0 g
s
.36706 .68576 m .3642 .64921 L .33516 .64727 L p .707 .577 .707 r
F P
0 g
s
.3642 .64921 m .36706 .68576 L .39874 .68458 L p .707 .577 .707 r
F P
0 g
s
.82221 .55719 m .82124 .61217 L .79885 .60489 L p .707 .577 .707 r
F P
0 g
s
.79885 .60489 m .79982 .54992 L .82221 .55719 L p .707 .577 .707 r
F P
0 g
s
.4271 .64386 m .42996 .6804 L .45767 .67363 L p .707 .577 .707 r
F P
0 g
s
.45767 .67363 m .45481 .63709 L .4271 .64386 L p .707 .577 .707 r
F P
0 g
s
.65595 .60905 m .65692 .55408 L .67973 .54765 L p .707 .577 .707 r
F P
0 g
s
.83309 .64147 m .83436 .67911 L .81854 .67396 L p .707 .577 .707 r
F P
0 g
s
.81854 .67396 m .81727 .63632 L .83309 .64147 L p .707 .577 .707 r
F P
0 g
s
.65222 .64324 m .65349 .68088 L .64033 .68724 L p .707 .577 .707 r
F P
0 g
s
.64264 .73904 m .64096 .71998 L .65334 .71592 L p .707 .577 .707 r
F P
0 g
s
.31137 .54979 m .30915 .6056 L .33152 .61216 L p .707 .577 .707 r
F P
0 g
s
.65334 .71592 m .65503 .73499 L .64264 .73904 L p .707 .577 .707 r
F P
0 g
s
.33516 .64727 m .33801 .68381 L .36706 .68576 L p .707 .577 .707 r
F P
0 g
s
.33801 .68381 m .33516 .64727 L .3116 .6424 L p .707 .577 .707 r
F P
0 g
s
.30915 .6056 m .31137 .54979 L .29714 .54207 L p .707 .577 .707 r
F P
0 g
s
.47656 .55635 m .47434 .61216 L .48911 .60559 L p .707 .577 .707 r
F P
0 g
s
.48911 .60559 m .49133 .54979 L .47656 .55635 L p .707 .577 .707 r
F P
0 g
s
.45481 .63709 m .45767 .67363 L .47915 .66493 L p .707 .577 .707 r
F P
0 g
s
.47915 .66493 m .47629 .62838 L .45481 .63709 L p .707 .577 .707 r
F P
0 g
s
.40694 .73065 m .4032 .71307 L .37197 .7178 L p .707 .577 .707 r
F P
0 g
s
.4032 .71307 m .40694 .73065 L .43751 .72241 L p .707 .577 .707 r
F P
0 g
s
.43751 .72241 m .43377 .70484 L .4032 .71307 L p .707 .577 .707 r
F P
0 g
s
.83406 .70169 m .83574 .72075 L .81929 .71943 L p .707 .577 .707 r
F P
0 g
s
.81929 .71943 m .8176 .70037 L .83406 .70169 L p .707 .577 .707 r
F P
0 g
s
.67973 .54765 m .67876 .60263 L .65595 .60905 L p .707 .577 .707 r
F P
0 g
s
.43377 .70484 m .43751 .72241 L .46441 .71148 L p .707 .577 .707 r
F P
0 g
s
.46441 .71148 m .46068 .69391 L .43377 .70484 L p .707 .577 .707 r
F P
0 g
s
.37571 .73538 m .37197 .7178 L .34313 .71857 L p .707 .577 .707 r
F P
0 g
s
.37197 .7178 m .37571 .73538 L .40694 .73065 L p .707 .577 .707 r
F P
0 g
s
.79982 .54992 m .79885 .60489 L .7705 .59996 L p .707 .577 .707 r
F P
0 g
s
.7705 .59996 m .77148 .54498 L .79982 .54992 L p .707 .577 .707 r
F P
0 g
s
.67876 .60263 m .67973 .54765 L .70834 .54379 L p .707 .577 .707 r
F P
0 g
s
.65349 .68088 m .65222 .64324 L .67373 .63773 L p .707 .577 .707 r
F P
0 g
s
.3116 .6424 m .31446 .67894 L .33801 .68381 L p .707 .577 .707 r
F P
0 g
s
.34313 .71857 m .34686 .73615 L .37571 .73538 L p .707 .577 .707 r
F P
0 g
s
.29714 .54207 m .29491 .59788 L .30915 .6056 L p .707 .577 .707 r
F P
0 g
s
.81727 .63632 m .81854 .67396 L .79492 .67034 L p .707 .577 .707 r
F P
0 g
s
.79492 .67034 m .79365 .6327 L .81727 .63632 L p .707 .577 .707 r
F P
0 g
s
.67373 .63773 m .675 .67536 L .65349 .68088 L p .707 .577 .707 r
F P
0 g
s
.31446 .67894 m .3116 .6424 L .29583 .63508 L p .707 .577 .707 r
F P
0 g
s
.46068 .69391 m .46441 .71148 L .48503 .69893 L p .707 .577 .707 r
F P
0 g
s
.48503 .69893 m .48129 .68135 L .46068 .69391 L p .707 .577 .707 r
F P
0 g
s
.65503 .73499 m .65334 .71592 L .67419 .71166 L p .707 .577 .707 r
F P
0 g
s
.34686 .73615 m .34313 .71857 L .3195 .7153 L p .707 .577 .707 r
F P
0 g
s
.77148 .54498 m .7705 .59996 L .73898 .59784 L p .707 .577 .707 r
F P
0 g
s
.73898 .59784 m .73995 .54287 L .77148 .54498 L p .707 .577 .707 r
F P
0 g
s
.70737 .59877 m .70834 .54379 L .73995 .54287 L p .707 .577 .707 r
F P
0 g
s
.70834 .54379 m .70737 .59877 L .67876 .60263 L p .707 .577 .707 r
F P
0 g
s
.67419 .71166 m .67587 .73072 L .65503 .73499 L p .707 .577 .707 r
F P
0 g
s
.47629 .62838 m .47915 .66493 L .49229 .65515 L p .707 .577 .707 r
F P
0 g
s
.49229 .65515 m .48943 .61861 L .47629 .62838 L p .707 .577 .707 r
F P
0 g
s
.73995 .54287 m .73898 .59784 L .70737 .59877 L p .707 .577 .707 r
F P
0 g
s
.29491 .59788 m .29714 .54207 L .29244 .53396 L p .707 .577 .707 r
F P
0 g
s
.3195 .7153 m .32324 .73287 L .34686 .73615 L p .707 .577 .707 r
F P
0 g
s
.49133 .54979 m .48911 .60559 L .4944 .59788 L p .707 .577 .707 r
F P
0 g
s
.4944 .59788 m .49663 .54207 L .49133 .54979 L p .707 .577 .707 r
F P
0 g
s
.8176 .70037 m .81929 .71943 L .79521 .71942 L p .707 .577 .707 r
F P
0 g
s
.79521 .71942 m .79353 .70036 L .8176 .70037 L p .707 .577 .707 r
F P
0 g
s
.29583 .63508 m .29869 .67162 L .31446 .67894 L p .707 .577 .707 r
F P
0 g
s
.675 .67536 m .67373 .63773 L .70149 .6336 L p .707 .577 .707 r
F P
0 g
s
.79365 .6327 m .79492 .67034 L .7658 .6686 L p .707 .577 .707 r
F P
0 g
s
.7658 .6686 m .76453 .63096 L .79365 .6327 L p .707 .577 .707 r
F P
0 g
s
.48129 .68135 m .48503 .69893 L .49734 .68598 L p .707 .577 .707 r
F P
0 g
s
.49734 .68598 m .4936 .6684 L .48129 .68135 L p .707 .577 .707 r
F P
0 g
s
.70149 .6336 m .70276 .67124 L .675 .67536 L p .707 .577 .707 r
F P
0 g
s
.29244 .53396 m .29021 .58977 L .29491 .59788 L p .707 .577 .707 r
F P
0 g
s
.32324 .73287 m .3195 .7153 L .3034 .7083 L p .707 .577 .707 r
F P
0 g
s
.67587 .73072 m .67419 .71166 L .70145 .70761 L p .707 .577 .707 r
F P
0 g
s
.29869 .67162 m .29583 .63508 L .2894 .62602 L p .707 .577 .707 r
F P
0 g
s
.70145 .70761 m .70313 .72667 L .67587 .73072 L p .707 .577 .707 r
F P
0 g
s
.70276 .67124 m .70149 .6336 L .73278 .63127 L p .707 .577 .707 r
F P
0 g
s
.3034 .7083 m .30714 .72588 L .32324 .73287 L p .707 .577 .707 r
F P
0 g
s
.48943 .61861 m .49229 .65515 L .49582 .64525 L p .707 .577 .707 r
F P
0 g
s
.49582 .64525 m .49296 .6087 L .48943 .61861 L p .707 .577 .707 r
F P
0 g
s
.76453 .63096 m .7658 .6686 L .73405 .66891 L p .707 .577 .707 r
F P
0 g
s
.73405 .66891 m .73278 .63127 L .76453 .63096 L p .707 .577 .707 r
F P
0 g
s
.79353 .70036 m .79521 .71942 L .76588 .72073 L p .707 .577 .707 r
F P
0 g
s
.76588 .72073 m .76419 .70167 L .79353 .70036 L p .707 .577 .707 r
F P
0 g
s
.73278 .63127 m .73405 .66891 L .70276 .67124 L p .707 .577 .707 r
F P
0 g
s
.29021 .58977 m .29244 .53396 L .29773 .52624 L p .707 .577 .707 r
F P
0 g
s
.2894 .62602 m .29226 .66257 L .29869 .67162 L p .707 .577 .707 r
F P
0 g
s
.49663 .54207 m .4944 .59788 L .4897 .58976 L p .707 .577 .707 r
F P
0 g
s
.4897 .58976 m .49192 .53395 L .49663 .54207 L p .707 .577 .707 r
F P
0 g
s
.70313 .72667 m .70145 .70761 L .73246 .70417 L p .707 .577 .707 r
F P
0 g
s
.73246 .70417 m .73415 .72323 L .70313 .72667 L p .707 .577 .707 r
F P
0 g
s
.76419 .70167 m .76588 .72073 L .73415 .72323 L p .707 .577 .707 r
F P
0 g
s
.73415 .72323 m .73246 .70417 L .76419 .70167 L p .707 .577 .707 r
F P
0 g
s
.4936 .6684 m .49734 .68598 L .50013 .67389 L p .707 .577 .707 r
F P
0 g
s
.50013 .67389 m .49639 .65632 L .4936 .6684 L p .707 .577 .707 r
F P
0 g
s
.30714 .72588 m .3034 .7083 L .2964 .69828 L p .707 .577 .707 r
F P
0 g
s
.29773 .52624 m .29551 .58205 L .29021 .58977 L p .707 .577 .707 r
F P
0 g
s
.2964 .69828 m .30014 .71585 L .30714 .72588 L p .707 .577 .707 r
F P
0 g
s
.29226 .66257 m .2894 .62602 L .29293 .61612 L p .707 .577 .707 r
F P
0 g
s
.49296 .6087 m .49582 .64525 L .48939 .6362 L p .707 .577 .707 r
F P
0 g
s
.48939 .6362 m .48653 .59965 L .49296 .6087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29293 .61612 m .29579 .65267 L .29226 .66257 L p .707 .577 .707 r
F P
0 g
s
.29551 .58205 m .29773 .52624 L .3125 .51968 L p .707 .577 .707 r
F P
0 g
s
.49192 .53395 m .4897 .58976 L .47546 .58204 L p .707 .577 .707 r
F P
0 g
s
.47546 .58204 m .47769 .52624 L .49192 .53395 L p .707 .577 .707 r
F P
0 g
s
.49639 .65632 m .50013 .67389 L .49313 .66387 L p .707 .577 .707 r
F P
0 g
s
.49313 .66387 m .48939 .64629 L .49639 .65632 L p .707 .577 .707 r
F P
0 g
s
.30014 .71585 m .2964 .69828 L .29919 .6862 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3125 .51968 m .31027 .57548 L .29551 .58205 L p .707 .577 .707 r
F P
0 g
s
.29919 .6862 m .30293 .70377 L .30014 .71585 L p .707 .577 .707 r
F P
0 g
s
.29579 .65267 m .29293 .61612 L .30607 .60634 L p .707 .577 .707 r
F P
0 g
s
.48653 .59965 m .48939 .6362 L .47362 .62888 L p .707 .577 .707 r
F P
0 g
s
.47362 .62888 m .47076 .59233 L .48653 .59965 L p .707 .577 .707 r
F P
0 g
s
.31027 .57548 m .3125 .51968 L .3353 .51491 L p .707 .577 .707 r
F P
0 g
s
.47769 .52624 m .47546 .58204 L .45309 .57548 L p .707 .577 .707 r
F P
0 g
s
.45309 .57548 m .45532 .51967 L .47769 .52624 L p .707 .577 .707 r
F P
0 g
s
.30607 .60634 m .30893 .64289 L .29579 .65267 L p .707 .577 .707 r
F P
0 g
s
.48939 .64629 m .49313 .66387 L .47703 .65688 L p .707 .577 .707 r
F P
0 g
s
.47703 .65688 m .47329 .6393 L .48939 .64629 L p .707 .577 .707 r
F P
0 g
s
.30293 .70377 m .29919 .6862 L .3115 .67324 L p .707 .577 .707 r
F P
0 g
s
.3353 .51491 m .33307 .57071 L .31027 .57548 L p .707 .577 .707 r
F P
0 g
s
.30893 .64289 m .30607 .60634 L .32755 .59764 L p .707 .577 .707 r
F P
0 g
s
.3115 .67324 m .31524 .69082 L .30293 .70377 L p .707 .577 .707 r
F P
0 g
s
.47076 .59233 m .47362 .62888 L .45006 .62401 L p .707 .577 .707 r
F P
0 g
s
.45006 .62401 m .4472 .58746 L .47076 .59233 L p .707 .577 .707 r
F P
0 g
s
.33307 .57071 m .3353 .51491 L .36389 .5124 L p .707 .577 .707 r
F P
0 g
s
.45532 .51967 m .45309 .57548 L .42477 .57071 L p .707 .577 .707 r
F P
0 g
s
.42477 .57071 m .42699 .5149 L .45532 .51967 L p .707 .577 .707 r
F P
0 g
s
.32755 .59764 m .33041 .63419 L .30893 .64289 L p .707 .577 .707 r
F P
0 g
s
.36167 .5682 m .36389 .5124 L .39549 .5124 L p .707 .577 .707 r
F P
0 g
s
.36389 .5124 m .36167 .5682 L .33307 .57071 L p .707 .577 .707 r
F P
0 g
s
.42699 .5149 m .42477 .57071 L .39326 .5682 L p .707 .577 .707 r
F P
0 g
s
.39326 .5682 m .39549 .5124 L .42699 .5149 L p .707 .577 .707 r
F P
0 g
s
.47329 .6393 m .47703 .65688 L .4534 .6536 L p .707 .577 .707 r
F P
0 g
s
.4534 .6536 m .44966 .63602 L .47329 .6393 L p .707 .577 .707 r
F P
0 g
s
.31524 .69082 m .3115 .67324 L .33211 .66069 L p .707 .577 .707 r
F P
0 g
s
.33041 .63419 m .32755 .59764 L .35526 .59087 L p .707 .577 .707 r
F P
0 g
s
.39549 .5124 m .39326 .5682 L .36167 .5682 L p .707 .577 .707 r
F P
0 g
s
.4472 .58746 m .45006 .62401 L .42102 .62207 L p .707 .577 .707 r
F P
0 g
s
.42102 .62207 m .41816 .58552 L .4472 .58746 L p .707 .577 .707 r
F P
0 g
s
.33211 .66069 m .33585 .67827 L .31524 .69082 L p .707 .577 .707 r
F P
0 g
s
.35526 .59087 m .35812 .62742 L .33041 .63419 L p .707 .577 .707 r
F P
0 g
s
.35812 .62742 m .35526 .59087 L .38648 .58669 L p .707 .577 .707 r
F P
0 g
s
.41816 .58552 m .42102 .62207 L .38934 .62324 L p .707 .577 .707 r
F P
0 g
s
.38934 .62324 m .38648 .58669 L .41816 .58552 L p .707 .577 .707 r
F P
0 g
s
.44966 .63602 m .4534 .6536 L .42456 .65437 L p .707 .577 .707 r
F P
0 g
s
.42456 .65437 m .42082 .63679 L .44966 .63602 L p .707 .577 .707 r
F P
0 g
s
.33585 .67827 m .33211 .66069 L .35902 .64976 L p .707 .577 .707 r
F P
0 g
s
.38648 .58669 m .38934 .62324 L .35812 .62742 L p .707 .577 .707 r
F P
0 g
s
.35902 .64976 m .36276 .66734 L .33585 .67827 L p .707 .577 .707 r
F P
0 g
s
.42082 .63679 m .42456 .65437 L .39333 .6591 L p .707 .577 .707 r
F P
0 g
s
.39333 .6591 m .38959 .64152 L .42082 .63679 L p .707 .577 .707 r
F P
0 g
s
.36276 .66734 m .35902 .64976 L .38959 .64152 L p .707 .577 .707 r
F P
0 g
s
.38959 .64152 m .39333 .6591 L .36276 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001TOolA0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`P0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00EWoo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0I7oo001DOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00eooa4004Ioo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`07Ool60003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH8000nOol005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00Dgoo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Oomoogoo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001COol00eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000bOol0059oo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0059oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`03001JEP0000=JEP04
001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH01000
FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000=JEP@0009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60005FUH01000FUIJEUYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01000FUH005YF0P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00UYF
0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01P00FUH00000FUH000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP80
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF40001EYF00<005YFFUH00eYF00D005YF000005YF008000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF1@000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01@0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001COol0
1@00FUIJEUYF00001EYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF0000009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00Dgoo00D0
05YFFUIJEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF009JEQP000IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;Goo001DOol200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF
009JEPh000=oo`D00003Ool0000000T0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0041o
oaT000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEUYF001JEP000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH00UYF2@0015YF
00<005YFFUH015YF100015YF00@005YFFUIJEP8002ioo`00?7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP0300000eYF001JEP02FUH2000^Ool003Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP03
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20003FUH2000^Ool0039oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF0000000^
Ool0031oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03000^Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000IJEP03001JEP0000L000=JEP03001JEUYF009JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPH000EJEP<000MJEP03001J
EUYF00MJEPD000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEPD000IJEP03001JEUYF00UJEPD00003FUH0000000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH01000FUIJEUYF6@0015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH0
0UYF100000=JEP00FUH00UYF00@005YFFUH000EJEPD000IJEP03001JEUYF00T0009JEP03001JEUYF
00<000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD000=JEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000UYF00<005YF00000P001EYF00D005YFFUIJEP00009JEP03001J
EUYF00=JEPh000=JEP04001JEUYFFUH50003FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF1`000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00<007ooOol0;Goo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002
FUH300000eYF001JEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEPL0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00P005YF001JEP00FUH005YF
100015YF00@005YFFUH0009JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP03FUH;0005FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01@00FUIJEUYF00001UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF009JEPL000=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;Goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00D005YFFUIJ
EP0000IJEP@000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00D000=JEP80
00AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP04
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF00000004FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH015YF5@0015YF00<005YFFUH0
0`0025YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00AJEP00000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF0080
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01@0025YF00<005YFFUH01UYF0`0015YF00<005YF00000UYF00<005YFFUH01EYF10001UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00;Woo000]Ool20004FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF000015YF0P0015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF0`000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUHO0003FUH00`00
FUIJEP02FUH2000^Ool002eoo`8000=JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00AJEP800003FUH005YF009JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF00<005YFFUH00eYF00<005YF
FUH05@0015YF00<005YFFUH01EYF00<005YF000010000eYF0P00;Woo000]Ool2000015YF00000000
1EYF00<005YFFUH00UYF5`000eYF0P001UYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00@005YFFUIJEP800004FUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF1@001eYF00<005YFFUH015YF1@00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP000000;Woo000]Ool30002FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP03FUH2
00000eYF001JEP06FUH00`00FUIJEP04FUH30004FUH70008FUH01000FUIJEP0015YF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
100015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000P00;Woo000]Ool20003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH0200015YF00<005YFFUH00UYF2@00
0eYF00<005YFFUH02EYF100015YF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]Ool20003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF1`00
00AJEP00FUIJEPT00003FUH0000000<000IJEP03001JEUYF00UJEP04001JEUYF0004FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20002FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P001EYF0P000eYF00@005YFFUH000EJ
EPD000IJEP03001JEUYF00MJEP8000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP03001JEP0000IJEPD0009JEP03001JEUYF00AJEP<000MJEP03001JEUYF00EJEP8000IJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000`Ool002ioo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<005YF00000P000UYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP05001JEUYF001JEP020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YF
FUH015YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0001P002moo`00;Goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF10001UYF00<0
05YFFUH00P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YF0000200015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH0
0UYF00@005YFFUH000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP8000aJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00d000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF3P0015YF00@005YFFUIJEP@0
0003FUH005YF00AJEP03001JEUYF009JEP04001JEUYF0006FUH60006FUH00`00FUIJEP05FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00@000ioo`X0
009JEPD0009JEP03001JEUYF009JEP04001JEUYF0003FUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=J
EP03001JEUYF009JEP@001]oo`80009JEP04001JEUYFFUH>0006FUH00`00FUIJEP07FUH00`00FUH0
00020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHI
00000eYF001oo`0/Ool002eoo`8000=JEP03001JEP00008001moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02
000]Ool002eoo`8000=JEP8000Qooa0000]oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00@005YFFUIJEQ4000QJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEP00000^Ool002eoo`800004FUH00000FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF1@001eYF00<005YFFUH0
0eYF100025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool30003FUH00`00FUH00002
0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003Ool50003FUH00`00FUIJEP05
FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF00000P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00<goo000]Ool30003
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003
Ool?0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00=Woo000]Ool01000FUH005YF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF
00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000kOol002eoo`03001JEP00
008000AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01eYF5P001UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEPD0009JEP03001JEUYF00AJEP03001JEUYF009JEQ4004Aoo`00
;Woo0P0000=JEP00FUH00eYF1@001eYF00<005YFFUH01UYF1`001UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP090007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF3`00E7oo
000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF00<005YFFUH01EYF0`000UYF00@005YFFUH000IJEP03001JEUYF00EJEPL000]JEP03001J
EUYF00YJEP03001JEUYF00UJEPD0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF009JEP8005=oo`00;Goo00D005YFFUH005YF008000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEP00009JEP04
001JEUYF0006FUH00`00FUIJEP050006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP03FUH2001COol002eoo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH00eYF1@002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0P0015YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF0P00
Dgoo000]Ool01000FUH007oo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0P0000=JEP00FUH00eYF0P000UYF00@005YFFUIJEP8000AJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF
00=JEP8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005=oo`00;Goo0P0017oo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00AJEP80009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<007oo00001@0015YF00<005YF
FUH00UYF00<005YF0000Dgoo000]Ool00`00Oomoo`05Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF0`001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF2`0000=JEP00FUH00eYF00<005YF0000Dgoo000]Ool2000:Ool30006FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUH0000400001EYF000005YF00000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF1@001eYF00<005YF00000P000eYF00<005YF0000Dgoo000/Ool00`00
FUH0000=Ool40002FUH00`00FUIJEP02FUH50008FUH00`00FUIJEP02FUH50005Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH2000015YF001JEP00
Dgoo000/Ool01000FUIJEP0047oo6@002goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00P001eYF00<005YFFUH00eYF0`0000=JEP00Ool0DWoo000/Ool00`00FUIJEP02000FOol5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00Dgoo000/Ool01P00FUIJEP00FUH001Ioo`<001Yoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF00=JEP04001JEUYFFUH2
001COol002eoo`8000=JEP03001oogoo031oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEP000007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000]Ool20004FUH2000_
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000E7oo000^Ool00`00FUIJEP02FUH01000FUH00000;7oo00<005YF0000
0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF00<005YFFUH00P00E7oo
000_Ool20002FUH01000FUIJEUYF0P00:7oo0P000UYF00@007ooOomoo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000AJEP@0009JEP04001JEUYFFUH5001FOol0035oo`<000EJEP@0025oo`<00005FUH005YFFUH0
0004Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P0025YF00<005YF00001@00Fgoo000cOol00`00FUIJEP04FUH0
0`00FUIJEP04000JOol30004FUH00`00FUH00007Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000FUH000QJEP04001J
EUYFFUH2001MOol003Aoo`8000AJEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP8000ao
o`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEPT000IJ
EP03001JEUYF00AJEP8005]oo`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF
00<005YFFUH00eYF0P004Goo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02@001Goo0P0015YF00<005YFFUH01EYF0`00FGoo000hOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000HOol80006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH:0002Ool50007Ool300000eYF001JEP06FUH00`00FUIJEP02001GOol003Yo
o`8000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080029ooaX0
00MJEP03001JEUYF00L000Yoo`<000EJEP03001JEUYF009JEP8005Ioo`00?7oo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo100000=JEP00FUH01eYF00<005YFFUH0
0eYF20002Goo100000=JEP00FUH00eYF00<005YF0000EGoo0010Ool70004FUH00`00FUIJEP06FUH0
0`00FUIJEP04000oOol30006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005Ool20003FUH01000
FUIJEP00EGoo0017Ool@0016Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
2@0000EJEP00FUIJEP0005Eoo`00XGoo1@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP000000EGoo002VOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH00000EWoo002ZOol50006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000EWoo002_Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
EWoo002cOolD001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58557 .74796 m .58772 .6922 L .55702 .68884 L p .707 .577 .707 r
F P
0 g
s
.58772 .6922 m .58557 .74796 L .61749 .74884 L p .707 .577 .707 r
F P
0 g
s
.61749 .74884 m .61965 .69308 L .58772 .6922 L p .707 .577 .707 r
F P
0 g
s
.61965 .69308 m .61749 .74884 L .64752 .74716 L p .707 .577 .707 r
F P
0 g
s
.64752 .74716 m .64968 .6914 L .61965 .69308 L p .707 .577 .707 r
F P
0 g
s
.55487 .7446 m .55702 .68884 L .53057 .68333 L p .707 .577 .707 r
F P
0 g
s
.55702 .68884 m .55487 .7446 L .58557 .74796 L p .707 .577 .707 r
F P
0 g
s
.64968 .6914 m .64752 .74716 L .67272 .74308 L p .707 .577 .707 r
F P
0 g
s
.67272 .74308 m .67488 .68731 L .64968 .6914 L p .707 .577 .707 r
F P
0 g
s
.61342 .81155 m .61074 .77486 L .57886 .77678 L p .707 .577 .707 r
F P
0 g
s
.61074 .77486 m .61342 .81155 L .64397 .80682 L p .707 .577 .707 r
F P
0 g
s
.64397 .80682 m .64129 .77013 L .61074 .77486 L p .707 .577 .707 r
F P
0 g
s
.53057 .68333 m .52841 .7391 L .55487 .7446 L p .707 .577 .707 r
F P
0 g
s
.58154 .81347 m .57886 .77678 L .54876 .7757 L p .707 .577 .707 r
F P
0 g
s
.57886 .77678 m .58154 .81347 L .61342 .81155 L p .707 .577 .707 r
F P
0 g
s
.52841 .7391 m .53057 .68333 L .51093 .67622 L p .707 .577 .707 r
F P
0 g
s
.64129 .77013 m .64397 .80682 L .67018 .79975 L p .707 .577 .707 r
F P
0 g
s
.67018 .79975 m .6675 .76305 L .64129 .77013 L p .707 .577 .707 r
F P
0 g
s
.67488 .68731 m .67272 .74308 L .69062 .737 L p .707 .577 .707 r
F P
0 g
s
.69062 .737 m .69278 .68123 L .67488 .68731 L p .707 .577 .707 r
F P
0 g
s
.55144 .81239 m .54876 .7757 L .52339 .77173 L p .707 .577 .707 r
F P
0 g
s
.54876 .7757 m .55144 .81239 L .58154 .81347 L p .707 .577 .707 r
F P
0 g
s
.51093 .67622 m .50878 .73198 L .52841 .7391 L p .707 .577 .707 r
F P
0 g
s
.61662 .85538 m .61316 .83751 L .58176 .84242 L p .707 .577 .707 r
F P
0 g
s
.61316 .83751 m .61662 .85538 L .64697 .84738 L p .707 .577 .707 r
F P
0 g
s
.64697 .84738 m .64351 .82952 L .61316 .83751 L p .707 .577 .707 r
F P
0 g
s
.58522 .86029 m .58176 .84242 L .55236 .84377 L p .707 .577 .707 r
F P
0 g
s
.58176 .84242 m .58522 .86029 L .61662 .85538 L p .707 .577 .707 r
F P
0 g
s
.52339 .77173 m .52607 .80842 L .55144 .81239 L p .707 .577 .707 r
F P
0 g
s
.6675 .76305 m .67018 .79975 L .6895 .79101 L p .707 .577 .707 r
F P
0 g
s
.6895 .79101 m .68682 .75432 L .6675 .76305 L p .707 .577 .707 r
F P
0 g
s
.64351 .82952 m .64697 .84738 L .67329 .83709 L p .707 .577 .707 r
F P
0 g
s
.67329 .83709 m .66983 .81922 L .64351 .82952 L p .707 .577 .707 r
F P
0 g
s
.50878 .73198 m .51093 .67622 L .50005 .66819 L p .707 .577 .707 r
F P
0 g
s
.55236 .84377 m .55582 .86164 L .58522 .86029 L p .707 .577 .707 r
F P
0 g
s
.52607 .80842 m .52339 .77173 L .50524 .76525 L p .707 .577 .707 r
F P
0 g
s
.69278 .68123 m .69062 .737 L .69947 .72951 L p .707 .577 .707 r
F P
0 g
s
.69947 .72951 m .70163 .67375 L .69278 .68123 L p .707 .577 .707 r
F P
0 g
s
.55582 .86164 m .55236 .84377 L .52786 .84142 L p .707 .577 .707 r
F P
0 g
s
.66983 .81922 m .67329 .83709 L .693 .8255 L p .707 .577 .707 r
F P
0 g
s
.693 .8255 m .68954 .80763 L .66983 .81922 L p .707 .577 .707 r
F P
0 g
s
.52786 .84142 m .53132 .85929 L .55582 .86164 L p .707 .577 .707 r
F P
0 g
s
.50524 .76525 m .50792 .80194 L .52607 .80842 L p .707 .577 .707 r
F P
0 g
s
.50005 .66819 m .49789 .72395 L .50878 .73198 L p .707 .577 .707 r
F P
0 g
s
.68682 .75432 m .6895 .79101 L .70004 .78148 L p .707 .577 .707 r
F P
0 g
s
.70004 .78148 m .69736 .74479 L .68682 .75432 L p .707 .577 .707 r
F P
0 g
s
.53132 .85929 m .52786 .84142 L .51065 .8356 L p .707 .577 .707 r
F P
0 g
s
.50792 .80194 m .50524 .76525 L .49607 .7569 L p .707 .577 .707 r
F P
0 g
s
.49789 .72395 m .50005 .66819 L .49898 .66003 L p .707 .577 .707 r
F P
0 g
s
.51065 .8356 m .51411 .85347 L .53132 .85929 L p .707 .577 .707 r
F P
0 g
s
.68954 .80763 m .693 .8255 L .70418 .81375 L p .707 .577 .707 r
F P
0 g
s
.70418 .81375 m .70071 .79588 L .68954 .80763 L p .707 .577 .707 r
F P
0 g
s
.70163 .67375 m .69947 .72951 L .6984 .72136 L p .707 .577 .707 r
F P
0 g
s
.6984 .72136 m .70055 .66559 L .70163 .67375 L p .707 .577 .707 r
F P
0 g
s
.49607 .7569 m .49875 .79359 L .50792 .80194 L p .707 .577 .707 r
F P
0 g
s
.49898 .66003 m .49682 .7158 L .49789 .72395 L p .707 .577 .707 r
F P
0 g
s
.69736 .74479 m .70004 .78148 L .70076 .77208 L p .707 .577 .707 r
F P
0 g
s
.70076 .77208 m .69808 .73539 L .69736 .74479 L p .707 .577 .707 r
F P
0 g
s
.49875 .79359 m .49607 .7569 L .49679 .7475 L p .707 .577 .707 r
F P
0 g
s
.49682 .7158 m .49898 .66003 L .50782 .65254 L p .707 .577 .707 r
F P
0 g
s
.49679 .7475 m .49947 .78419 L .49875 .79359 L p .707 .577 .707 r
F P
0 g
s
.50782 .65254 m .50567 .70831 L .49682 .7158 L p .707 .577 .707 r
F P
0 g
s
.49947 .78419 m .49679 .7475 L .50733 .73797 L p .707 .577 .707 r
F P
0 g
s
.49737 .82192 m .49737 .32003 L .45293 .31792 L p .707 .577 .707 r
F P
0 g
s
.51411 .85347 m .51065 .8356 L .50242 .82689 L p .707 .577 .707 r
F P
0 g
s
.50242 .82689 m .50588 .84475 L .51411 .85347 L p .707 .577 .707 r
F P
0 g
s
.50588 .84475 m .50242 .82689 L .50396 .81613 L p .707 .577 .707 r
F P
0 g
s
.50567 .70831 m .50782 .65254 L .52572 .64646 L p .707 .577 .707 r
F P
0 g
s
.50396 .81613 m .50743 .834 L .50588 .84475 L p .707 .577 .707 r
F P
0 g
s
.50733 .73797 m .51001 .77466 L .49947 .78419 L p .707 .577 .707 r
F P
0 g
s
.52572 .64646 m .52357 .70223 L .50567 .70831 L p .707 .577 .707 r
F P
0 g
s
.50743 .834 m .50396 .81613 L .51514 .80438 L p .707 .577 .707 r
F P
0 g
s
.52357 .70223 m .52572 .64646 L .55092 .64238 L p .707 .577 .707 r
F P
0 g
s
.51001 .77466 m .50733 .73797 L .52665 .72924 L p .707 .577 .707 r
F P
0 g
s
.51514 .80438 m .5186 .82225 L .50743 .834 L p .707 .577 .707 r
F P
0 g
s
.52665 .72924 m .52933 .76593 L .51001 .77466 L p .707 .577 .707 r
F P
0 g
s
.55092 .64238 m .54877 .69815 L .52357 .70223 L p .707 .577 .707 r
F P
0 g
s
.52933 .76593 m .52665 .72924 L .55286 .72216 L p .707 .577 .707 r
F P
0 g
s
.5186 .82225 m .51514 .80438 L .53485 .79279 L p .707 .577 .707 r
F P
0 g
s
.53485 .79279 m .53831 .81066 L .5186 .82225 L p .707 .577 .707 r
F P
0 g
s
.55286 .72216 m .55554 .75885 L .52933 .76593 L p .707 .577 .707 r
F P
0 g
s
.53831 .81066 m .53485 .79279 L .56117 .78249 L p .707 .577 .707 r
F P
0 g
s
.56117 .78249 m .56463 .80036 L .53831 .81066 L p .707 .577 .707 r
F P
0 g
s
.49737 .32003 m .49737 .82192 L .54207 .82024 L p .707 .577 .707 r
F P
0 g
s
.54207 .82024 m .54207 .31835 L .49737 .32003 L p .707 .577 .707 r
F P
0 g
s
.54877 .69815 m .55092 .64238 L .58096 .6407 L p .707 .577 .707 r
F P
0 g
s
.58096 .6407 m .5788 .69647 L .54877 .69815 L p .707 .577 .707 r
F P
0 g
s
.55554 .75885 m .55286 .72216 L .58341 .71743 L p .707 .577 .707 r
F P
0 g
s
.58341 .71743 m .58609 .75412 L .55554 .75885 L p .707 .577 .707 r
F P
0 g
s
.56463 .80036 m .56117 .78249 L .59152 .7745 L p .707 .577 .707 r
F P
0 g
s
.59152 .7745 m .59498 .79237 L .56463 .80036 L p .707 .577 .707 r
F P
0 g
s
.54207 .31835 m .54207 .82024 L .58264 .81494 L p .707 .577 .707 r
F P
0 g
s
.5788 .69647 m .58096 .6407 L .61288 .64158 L p .707 .577 .707 r
F P
0 g
s
.61288 .64158 m .61073 .69735 L .5788 .69647 L p .707 .577 .707 r
F P
0 g
s
.58264 .81494 m .58264 .31305 L .54207 .31835 L p .707 .577 .707 r
F P
0 g
s
.45293 .8198 m .45293 .31792 L .4131 .31222 L p .707 .577 .707 r
F P
0 g
s
.45293 .31792 m .45293 .8198 L .49737 .82192 L p .707 .577 .707 r
F P
0 g
s
.70071 .79588 m .70418 .81375 L .70572 .80299 L p .707 .577 .707 r
F P
0 g
s
.70572 .80299 m .70226 .78512 L .70071 .79588 L p .707 .577 .707 r
F P
0 g
s
.70055 .66559 m .6984 .72136 L .68752 .71333 L p .707 .577 .707 r
F P
0 g
s
.68752 .71333 m .68967 .65756 L .70055 .66559 L p .707 .577 .707 r
F P
0 g
s
.61529 .71551 m .61797 .7522 L .58609 .75412 L p .707 .577 .707 r
F P
0 g
s
.58609 .75412 m .58341 .71743 L .61529 .71551 L p .707 .577 .707 r
F P
0 g
s
.62292 .76959 m .62638 .78746 L .59498 .79237 L p .707 .577 .707 r
F P
0 g
s
.59498 .79237 m .59152 .7745 L .62292 .76959 L p .707 .577 .707 r
F P
0 g
s
.58264 .31305 m .58264 .81494 L .61513 .80653 L p .707 .577 .707 r
F P
0 g
s
.64358 .64494 m .64143 .7007 L .61073 .69735 L p .707 .577 .707 r
F P
0 g
s
.61073 .69735 m .61288 .64158 L .64358 .64494 L p .707 .577 .707 r
F P
0 g
s
.61513 .80653 m .61513 .30465 L .58264 .31305 L p .707 .577 .707 r
F P
0 g
s
.69808 .73539 m .70076 .77208 L .69159 .76373 L p .707 .577 .707 r
F P
0 g
s
.69159 .76373 m .68891 .72704 L .69808 .73539 L p .707 .577 .707 r
F P
0 g
s
.4131 .81411 m .4131 .31222 L .38178 .30351 L p .707 .577 .707 r
F P
0 g
s
.4131 .31222 m .4131 .81411 L .45293 .8198 L p .707 .577 .707 r
F P
0 g
s
.2453 .71487 m .2462 .65995 L .21549 .65678 L p .707 .577 .707 r
F P
0 g
s
.2462 .65995 m .2453 .71487 L .27725 .71501 L p .707 .577 .707 r
F P
0 g
s
.27725 .71501 m .27815 .66009 L .2462 .65995 L p .707 .577 .707 r
F P
0 g
s
.27815 .66009 m .27725 .71501 L .3073 .71212 L p .707 .577 .707 r
F P
0 g
s
.3073 .71212 m .3082 .6572 L .27815 .66009 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70226 .78512 m .70572 .80299 L .69749 .79428 L p .707 .577 .707 r
F P
0 g
s
.69749 .79428 m .69403 .77641 L .70226 .78512 L p .707 .577 .707 r
F P
0 g
s
.21459 .7117 m .21549 .65678 L .18901 .65091 L p .707 .577 .707 r
F P
0 g
s
.21549 .65678 m .21459 .7117 L .2453 .71487 L p .707 .577 .707 r
F P
0 g
s
.68967 .65756 m .68752 .71333 L .66788 .70621 L p .707 .577 .707 r
F P
0 g
s
.66788 .70621 m .67004 .65045 L .68967 .65756 L p .707 .577 .707 r
F P
0 g
s
.3082 .6572 m .3073 .71212 L .3325 .70648 L p .707 .577 .707 r
F P
0 g
s
.3325 .70648 m .33341 .65156 L .3082 .6572 L p .707 .577 .707 r
F P
0 g
s
.64539 .71659 m .64807 .75328 L .61797 .7522 L p .707 .577 .707 r
F P
0 g
s
.61797 .7522 m .61529 .71551 L .64539 .71659 L p .707 .577 .707 r
F P
0 g
s
.65232 .76824 m .65578 .78611 L .62638 .78746 L p .707 .577 .707 r
F P
0 g
s
.62638 .78746 m .62292 .76959 L .65232 .76824 L p .707 .577 .707 r
F P
0 g
s
.61513 .30465 m .61513 .80653 L .63635 .79585 L p .707 .577 .707 r
F P
0 g
s
.63635 .79585 m .63635 .29396 L .61513 .30465 L p .707 .577 .707 r
F P
0 g
s
.68891 .72704 m .69159 .76373 L .67344 .75726 L p .707 .577 .707 r
F P
0 g
s
.67344 .75726 m .67076 .72056 L .68891 .72704 L p .707 .577 .707 r
F P
0 g
s
.27232 .76391 m .27123 .72618 L .23928 .72694 L p .707 .577 .707 r
F P
0 g
s
.27123 .72618 m .27232 .76391 L .30292 .76128 L p .707 .577 .707 r
F P
0 g
s
.30292 .76128 m .30182 .72355 L .27123 .72618 L p .707 .577 .707 r
F P
0 g
s
.24038 .76467 m .23928 .72694 L .20911 .72575 L p .707 .577 .707 r
F P
0 g
s
.23928 .72694 m .24038 .76467 L .27232 .76391 L p .707 .577 .707 r
F P
0 g
s
.38178 .80539 m .38178 .30351 L .36202 .29262 L p .707 .577 .707 r
F P
0 g
s
.38178 .30351 m .38178 .80539 L .4131 .81411 L p .707 .577 .707 r
F P
0 g
s
.18811 .70583 m .18901 .65091 L .16936 .64289 L p .707 .577 .707 r
F P
0 g
s
.18901 .65091 m .18811 .70583 L .21459 .7117 L p .707 .577 .707 r
F P
0 g
s
.33341 .65156 m .3325 .70648 L .35041 .69864 L p .707 .577 .707 r
F P
0 g
s
.35041 .69864 m .35131 .64372 L .33341 .65156 L p .707 .577 .707 r
F P
0 g
s
.20911 .72575 m .2102 .76349 L .24038 .76467 L p .707 .577 .707 r
F P
0 g
s
.30182 .72355 m .30292 .76128 L .32917 .75705 L p .707 .577 .707 r
F P
0 g
s
.32917 .75705 m .32807 .71931 L .30182 .72355 L p .707 .577 .707 r
F P
0 g
s
.27286 .79383 m .27146 .77469 L .2396 .77694 L p .707 .577 .707 r
F P
0 g
s
.27146 .77469 m .27286 .79383 L .30356 .79103 L p .707 .577 .707 r
F P
0 g
s
.30356 .79103 m .30216 .77189 L .27146 .77469 L p .707 .577 .707 r
F P
0 g
s
.2396 .77694 m .24101 .79608 L .27286 .79383 L p .707 .577 .707 r
F P
0 g
s
.67004 .65045 m .66788 .70621 L .64143 .7007 L p .707 .577 .707 r
F P
0 g
s
.64143 .7007 m .64358 .64494 L .67004 .65045 L p .707 .577 .707 r
F P
0 g
s
.2102 .76349 m .20911 .72575 L .18367 .72274 L p .707 .577 .707 r
F P
0 g
s
.24101 .79608 m .2396 .77694 L .20971 .77841 L p .707 .577 .707 r
F P
0 g
s
.69403 .77641 m .69749 .79428 L .68028 .78846 L p .707 .577 .707 r
F P
0 g
s
.68028 .78846 m .67682 .77059 L .69403 .77641 L p .707 .577 .707 r
F P
0 g
s
.20971 .77841 m .21112 .79755 L .24101 .79608 L p .707 .577 .707 r
F P
0 g
s
.30216 .77189 m .30356 .79103 L .33011 .78795 L p .707 .577 .707 r
F P
0 g
s
.33011 .78795 m .3287 .7688 L .30216 .77189 L p .707 .577 .707 r
F P
0 g
s
.18367 .72274 m .18476 .76047 L .2102 .76349 L p .707 .577 .707 r
F P
0 g
s
.16936 .64289 m .16846 .69781 L .18811 .70583 L p .707 .577 .707 r
F P
0 g
s
.21112 .79755 m .20971 .77841 L .18472 .77896 L p .707 .577 .707 r
F P
0 g
s
.18472 .77896 m .18612 .7981 L .21112 .79755 L p .707 .577 .707 r
F P
0 g
s
.67076 .72056 m .67344 .75726 L .64807 .75328 L p .707 .577 .707 r
F P
0 g
s
.64807 .75328 m .64539 .71659 L .67076 .72056 L p .707 .577 .707 r
F P
0 g
s
.16846 .69781 m .16936 .64289 L .15846 .63353 L p .707 .577 .707 r
F P
0 g
s
.32807 .71931 m .32917 .75705 L .3485 .75161 L p .707 .577 .707 r
F P
0 g
s
.3485 .75161 m .34741 .71388 L .32807 .71931 L p .707 .577 .707 r
F P
0 g
s
.18476 .76047 m .18367 .72274 L .16545 .7182 L p .707 .577 .707 r
F P
0 g
s
.35131 .64372 m .35041 .69864 L .35925 .68936 L p .707 .577 .707 r
F P
0 g
s
.35925 .68936 m .36015 .63444 L .35131 .64372 L p .707 .577 .707 r
F P
0 g
s
.3287 .7688 m .33011 .78795 L .3499 .78488 L p .707 .577 .707 r
F P
0 g
s
.3499 .78488 m .34849 .76574 L .3287 .7688 L p .707 .577 .707 r
F P
0 g
s
.63635 .29396 m .63635 .79585 L .64422 .78392 L p .707 .577 .707 r
F P
0 g
s
.64422 .78392 m .64422 .28203 L .63635 .29396 L p .707 .577 .707 r
F P
0 g
s
.16545 .7182 m .16654 .75593 L .18476 .76047 L p .707 .577 .707 r
F P
0 g
s
.67682 .77059 m .68028 .78846 L .65578 .78611 L p .707 .577 .707 r
F P
0 g
s
.65578 .78611 m .65232 .76824 L .67682 .77059 L p .707 .577 .707 r
F P
0 g
s
.36015 .63444 m .35925 .68936 L .35817 .67956 L p .707 .577 .707 r
F P
0 g
s
.35817 .67956 m .35907 .62464 L .36015 .63444 L p .707 .577 .707 r
F P
0 g
s
.35959 .76299 m .361 .78213 L .36231 .77997 L p .707 .577 .707 r
F P
0 g
s
.36231 .77997 m .36091 .76083 L .35959 .76299 L p .707 .577 .707 r
F P
0 g
s
.34849 .76574 m .3499 .78488 L .361 .78213 L p .707 .577 .707 r
F P
0 g
s
.361 .78213 m .35959 .76299 L .34849 .76574 L p .707 .577 .707 r
F P
0 g
s
.36091 .76083 m .36231 .77997 L .35372 .77861 L p .707 .577 .707 r
F P
0 g
s
.36202 .79451 m .36202 .29262 L .35578 .28062 L p .707 .577 .707 r
F P
0 g
s
.36202 .29262 m .36202 .79451 L .38178 .80539 L p .707 .577 .707 r
F P
0 g
s
.18612 .7981 m .18472 .77896 L .16706 .77853 L p .707 .577 .707 r
F P
0 g
s
.16706 .77853 m .16847 .79767 L .18612 .7981 L p .707 .577 .707 r
F P
0 g
s
.15846 .63353 m .15756 .68845 L .16846 .69781 L p .707 .577 .707 r
F P
0 g
s
.34741 .71388 m .3485 .75161 L .35902 .74551 L p .707 .577 .707 r
F P
0 g
s
.35902 .74551 m .35793 .70778 L .34741 .71388 L p .707 .577 .707 r
F P
0 g
s
.15756 .68845 m .15846 .63353 L .15738 .62373 L p .707 .577 .707 r
F P
0 g
s
.16654 .75593 m .16545 .7182 L .15623 .71257 L p .707 .577 .707 r
F P
0 g
s
.15623 .71257 m .15732 .7503 L .16654 .75593 L p .707 .577 .707 r
F P
0 g
s
.16847 .79767 m .16706 .77853 L .15847 .77717 L p .707 .577 .707 r
F P
0 g
s
.15847 .77717 m .15988 .79631 L .16847 .79767 L p .707 .577 .707 r
F P
0 g
s
.15738 .62373 m .15648 .67865 L .15756 .68845 L p .707 .577 .707 r
F P
0 g
s
.64422 .28203 m .64422 .78392 L .63797 .77193 L p .707 .577 .707 r
F P
0 g
s
.63797 .77193 m .63797 .27004 L .64422 .28203 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35793 .70778 m .35902 .74551 L .35971 .73934 L p .707 .577 .707 r
F P
0 g
s
.35971 .73934 m .35862 .70161 L .35793 .70778 L p .707 .577 .707 r
F P
0 g
s
.35907 .62464 m .35817 .67956 L .34727 .6702 L p .707 .577 .707 r
F P
0 g
s
.34727 .6702 m .34817 .61528 L .35907 .62464 L p .707 .577 .707 r
F P
0 g
s
.35862 .70161 m .35971 .73934 L .35049 .73371 L p .707 .577 .707 r
F P
0 g
s
.35049 .73371 m .3494 .69598 L .35862 .70161 L p .707 .577 .707 r
F P
0 g
s
.35372 .77861 m .35232 .75947 L .36091 .76083 L p .707 .577 .707 r
F P
0 g
s
.35578 .28062 m .35578 .78251 L .36202 .79451 L p .707 .577 .707 r
F P
0 g
s
.35578 .78251 m .35578 .28062 L .36365 .2687 L p .707 .577 .707 r
F P
0 g
s
.15648 .67865 m .15738 .62373 L .16623 .61446 L p .707 .577 .707 r
F P
0 g
s
.15732 .7503 m .15623 .71257 L .15691 .7064 L p .707 .577 .707 r
F P
0 g
s
.15691 .7064 m .15801 .74413 L .15732 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15988 .79631 m .15847 .77717 L .15979 .77501 L p .707 .577 .707 r
F P
0 g
s
.15979 .77501 m .1612 .79415 L .15988 .79631 L p .707 .577 .707 r
F P
0 g
s
.16623 .61446 m .16532 .66938 L .15648 .67865 L p .707 .577 .707 r
F P
0 g
s
.16532 .66938 m .16623 .61446 L .18413 .60662 L p .707 .577 .707 r
F P
0 g
s
.15801 .74413 m .15691 .7064 L .16744 .7003 L p .707 .577 .707 r
F P
0 g
s
.34817 .61528 m .34727 .6702 L .32762 .66219 L p .707 .577 .707 r
F P
0 g
s
.32762 .66219 m .32852 .60727 L .34817 .61528 L p .707 .577 .707 r
F P
0 g
s
.63797 .27004 m .63797 .77193 L .61822 .76104 L p .707 .577 .707 r
F P
0 g
s
.61822 .76104 m .61822 .25915 L .63797 .27004 L p .707 .577 .707 r
F P
0 g
s
.16744 .7003 m .16853 .73803 L .15801 .74413 L p .707 .577 .707 r
F P
0 g
s
.36365 .77059 m .36365 .2687 L .38487 .25801 L p .707 .577 .707 r
F P
0 g
s
.36365 .2687 m .36365 .77059 L .35578 .78251 L p .707 .577 .707 r
F P
0 g
s
.1612 .79415 m .15979 .77501 L .17089 .77226 L p .707 .577 .707 r
F P
0 g
s
.18413 .60662 m .18323 .66154 L .16532 .66938 L p .707 .577 .707 r
F P
0 g
s
.17089 .77226 m .17229 .79141 L .1612 .79415 L p .707 .577 .707 r
F P
0 g
s
.18323 .66154 m .18413 .60662 L .20934 .60097 L p .707 .577 .707 r
F P
0 g
s
.3494 .69598 m .35049 .73371 L .33227 .72917 L p .707 .577 .707 r
F P
0 g
s
.33227 .72917 m .33118 .69144 L .3494 .69598 L p .707 .577 .707 r
F P
0 g
s
.32852 .60727 m .32762 .66219 L .30114 .65631 L p .707 .577 .707 r
F P
0 g
s
.30114 .65631 m .30204 .60139 L .32852 .60727 L p .707 .577 .707 r
F P
0 g
s
.16853 .73803 m .16744 .7003 L .18677 .69487 L p .707 .577 .707 r
F P
0 g
s
.35232 .75947 m .35372 .77861 L .33607 .77819 L p .707 .577 .707 r
F P
0 g
s
.33607 .77819 m .33466 .75905 L .35232 .75947 L p .707 .577 .707 r
F P
0 g
s
.18677 .69487 m .18787 .7326 L .16853 .73803 L p .707 .577 .707 r
F P
0 g
s
.20934 .60097 m .20844 .65589 L .18323 .66154 L p .707 .577 .707 r
F P
0 g
s
.20844 .65589 m .20934 .60097 L .23938 .59808 L p .707 .577 .707 r
F P
0 g
s
.61822 .25915 m .61822 .76104 L .5869 .75232 L p .707 .577 .707 r
F P
0 g
s
.5869 .75232 m .5869 .25044 L .61822 .25915 L p .707 .577 .707 r
F P
0 g
s
.17229 .79141 m .17089 .77226 L .19068 .7692 L p .707 .577 .707 r
F P
0 g
s
.30204 .60139 m .30114 .65631 L .27043 .65315 L p .707 .577 .707 r
F P
0 g
s
.27043 .65315 m .27133 .59823 L .30204 .60139 L p .707 .577 .707 r
F P
0 g
s
.19068 .7692 m .19208 .78834 L .17229 .79141 L p .707 .577 .707 r
F P
0 g
s
.38487 .25801 m .38487 .7599 L .36365 .77059 L p .707 .577 .707 r
F P
0 g
s
.38487 .7599 m .38487 .25801 L .41735 .24961 L p .707 .577 .707 r
F P
0 g
s
.33118 .69144 m .33227 .72917 L .30683 .72616 L p .707 .577 .707 r
F P
0 g
s
.30683 .72616 m .30573 .68843 L .33118 .69144 L p .707 .577 .707 r
F P
0 g
s
.72957 .65489 m .72867 .59874 L .69795 .59718 L p .707 .577 .707 r
F P
0 g
s
.72867 .59874 m .72957 .65489 L .76151 .65415 L p .707 .577 .707 r
F P
0 g
s
.76151 .65415 m .76061 .59801 L .72867 .59874 L p .707 .577 .707 r
F P
0 g
s
.23848 .653 m .23938 .59808 L .27133 .59823 L p .707 .577 .707 r
F P
0 g
s
.23938 .59808 m .23848 .653 L .20844 .65589 L p .707 .577 .707 r
F P
0 g
s
.76061 .59801 m .76151 .65415 L .79156 .65119 L p .707 .577 .707 r
F P
0 g
s
.79156 .65119 m .79066 .59504 L .76061 .59801 L p .707 .577 .707 r
F P
0 g
s
.27133 .59823 m .27043 .65315 L .23848 .653 L p .707 .577 .707 r
F P
0 g
s
.18787 .7326 m .18677 .69487 L .21302 .69063 L p .707 .577 .707 r
F P
0 g
s
.69885 .65332 m .69795 .59718 L .67147 .59346 L p .707 .577 .707 r
F P
0 g
s
.69795 .59718 m .69885 .65332 L .72957 .65489 L p .707 .577 .707 r
F P
0 g
s
.21302 .69063 m .21411 .72836 L .18787 .7326 L p .707 .577 .707 r
F P
0 g
s
.33466 .75905 m .33607 .77819 L .31107 .77874 L p .707 .577 .707 r
F P
0 g
s
.31107 .77874 m .30967 .7596 L .33466 .75905 L p .707 .577 .707 r
F P
0 g
s
.79066 .59504 m .79156 .65119 L .81677 .64628 L p .707 .577 .707 r
F P
0 g
s
.81677 .64628 m .81587 .59014 L .79066 .59504 L p .707 .577 .707 r
F P
0 g
s
.19208 .78834 m .19068 .7692 L .21722 .76611 L p .707 .577 .707 r
F P
0 g
s
.30573 .68843 m .30683 .72616 L .27666 .72497 L p .707 .577 .707 r
F P
0 g
s
.27666 .72497 m .27556 .68724 L .30573 .68843 L p .707 .577 .707 r
F P
0 g
s
.21722 .76611 m .21863 .78525 L .19208 .78834 L p .707 .577 .707 r
F P
0 g
s
.21411 .72836 m .21302 .69063 L .24362 .688 L p .707 .577 .707 r
F P
0 g
s
.67147 .59346 m .67238 .6496 L .69885 .65332 L p .707 .577 .707 r
F P
0 g
s
.75529 .72626 m .75638 .69014 L .72443 .68905 L p .707 .577 .707 r
F P
0 g
s
.75638 .69014 m .75529 .72626 L .78588 .72391 L p .707 .577 .707 r
F P
0 g
s
.78588 .72391 m .78698 .68779 L .75638 .69014 L p .707 .577 .707 r
F P
0 g
s
.72334 .72517 m .72443 .68905 L .69426 .68463 L p .707 .577 .707 r
F P
0 g
s
.72443 .68905 m .72334 .72517 L .75529 .72626 L p .707 .577 .707 r
F P
0 g
s
.5869 .25044 m .5869 .75232 L .54706 .74663 L p .707 .577 .707 r
F P
0 g
s
.54706 .74663 m .54706 .24474 L .5869 .25044 L p .707 .577 .707 r
F P
0 g
s
.67238 .6496 m .67147 .59346 L .65182 .58796 L p .707 .577 .707 r
F P
0 g
s
.41735 .7515 m .41735 .24961 L .45793 .24431 L p .707 .577 .707 r
F P
0 g
s
.41735 .24961 m .41735 .7515 L .38487 .7599 L p .707 .577 .707 r
F P
0 g
s
.24362 .688 m .24471 .72573 L .21411 .72836 L p .707 .577 .707 r
F P
0 g
s
.27556 .68724 m .27666 .72497 L .24471 .72573 L p .707 .577 .707 r
F P
0 g
s
.24471 .72573 m .24362 .688 L .27556 .68724 L p .707 .577 .707 r
F P
0 g
s
.81587 .59014 m .81677 .64628 L .83467 .63992 L p .707 .577 .707 r
F P
0 g
s
.83467 .63992 m .83377 .58378 L .81587 .59014 L p .707 .577 .707 r
F P
0 g
s
.30967 .7596 m .31107 .77874 L .28118 .78021 L p .707 .577 .707 r
F P
0 g
s
.28118 .78021 m .27978 .76106 L .30967 .7596 L p .707 .577 .707 r
F P
0 g
s
.78698 .68779 m .78588 .72391 L .81213 .71837 L p .707 .577 .707 r
F P
0 g
s
.81213 .71837 m .81323 .68225 L .78698 .68779 L p .707 .577 .707 r
F P
0 g
s
.69317 .72076 m .69426 .68463 L .66882 .67733 L p .707 .577 .707 r
F P
0 g
s
.69426 .68463 m .69317 .72076 L .72334 .72517 L p .707 .577 .707 r
F P
0 g
s
.21863 .78525 m .21722 .76611 L .24792 .76331 L p .707 .577 .707 r
F P
0 g
s
.24792 .76331 m .24933 .78245 L .21863 .78525 L p .707 .577 .707 r
F P
0 g
s
.65182 .58796 m .65272 .6441 L .67238 .6496 L p .707 .577 .707 r
F P
0 g
s
.27978 .76106 m .28118 .78021 L .24933 .78245 L p .707 .577 .707 r
F P
0 g
s
.24933 .78245 m .24792 .76331 L .27978 .76106 L p .707 .577 .707 r
F P
0 g
s
.54706 .24474 m .54706 .74663 L .50263 .74452 L p .707 .577 .707 r
F P
0 g
s
.50263 .74452 m .50263 .24263 L .54706 .24474 L p .707 .577 .707 r
F P
0 g
s
.66882 .67733 m .66773 .71345 L .69317 .72076 L p .707 .577 .707 r
F P
0 g
s
.45793 .7462 m .45793 .24431 L .50263 .24263 L p .707 .577 .707 r
F P
0 g
s
.45793 .24431 m .45793 .7462 L .41735 .7515 L p .707 .577 .707 r
F P
0 g
s
.81323 .68225 m .81213 .71837 L .83147 .71016 L p .707 .577 .707 r
F P
0 g
s
.83147 .71016 m .83256 .67404 L .81323 .68225 L p .707 .577 .707 r
F P
0 g
s
.75067 .77875 m .75207 .76172 L .72022 .75904 L p .707 .577 .707 r
F P
0 g
s
.75207 .76172 m .75067 .77875 L .78137 .77678 L p .707 .577 .707 r
F P
0 g
s
.78137 .77678 m .78278 .75976 L .75207 .76172 L p .707 .577 .707 r
F P
0 g
s
.71881 .77607 m .72022 .75904 L .69033 .75197 L p .707 .577 .707 r
F P
0 g
s
.72022 .75904 m .71881 .77607 L .75067 .77875 L p .707 .577 .707 r
F P
0 g
s
.66773 .71345 m .66882 .67733 L .6506 .66784 L p .707 .577 .707 r
F P
0 g
s
.65272 .6441 m .65182 .58796 L .64092 .58121 L p .707 .577 .707 r
F P
0 g
s
.50263 .24263 m .50263 .74452 L .45793 .7462 L p .707 .577 .707 r
F P
0 g
s
.83377 .58378 m .83467 .63992 L .84352 .63272 L p .707 .577 .707 r
F P
0 g
s
.84352 .63272 m .84262 .57657 L .83377 .58378 L p .707 .577 .707 r
F P
0 g
s
.78278 .75976 m .78137 .77678 L .80792 .77035 L p .707 .577 .707 r
F P
0 g
s
.80792 .77035 m .80932 .75333 L .78278 .75976 L p .707 .577 .707 r
F P
0 g
s
.69033 .75197 m .68893 .769 L .71881 .77607 L p .707 .577 .707 r
F P
0 g
s
.68893 .769 m .69033 .75197 L .66534 .7412 L p .707 .577 .707 r
F P
0 g
s
.6506 .66784 m .64951 .70397 L .66773 .71345 L p .707 .577 .707 r
F P
0 g
s
.64092 .58121 m .64183 .63735 L .65272 .6441 L p .707 .577 .707 r
F P
0 g
s
.66534 .7412 m .66393 .75823 L .68893 .769 L p .707 .577 .707 r
F P
0 g
s
.83256 .67404 m .83147 .71016 L .84199 .7001 L p .707 .577 .707 r
F P
0 g
s
.84199 .7001 m .84308 .66398 L .83256 .67404 L p .707 .577 .707 r
F P
0 g
s
.64951 .70397 m .6506 .66784 L .64138 .65711 L p .707 .577 .707 r
F P
0 g
s
.80932 .75333 m .80792 .77035 L .82771 .7601 L p .707 .577 .707 r
F P
0 g
s
.82771 .7601 m .82911 .74307 L .80932 .75333 L p .707 .577 .707 r
F P
0 g
s
.66393 .75823 m .66534 .7412 L .64768 .72779 L p .707 .577 .707 r
F P
0 g
s
.64183 .63735 m .64092 .58121 L .63984 .57388 L p .707 .578 .707 r
F P
0 g
s
.64768 .72779 m .64627 .74482 L .66393 .75823 L p .707 .577 .707 r
F P
0 g
s
.84262 .57657 m .84352 .63272 L .84244 .62538 L p .707 .578 .707 r
F P
0 g
s
.84244 .62538 m .84154 .56924 L .84262 .57657 L p .707 .578 .707 r
F P
0 g
s
.64138 .65711 m .64029 .69323 L .64951 .70397 L p .707 .577 .707 r
F P
0 g
s
.63984 .57388 m .64075 .63002 L .64183 .63735 L p .707 .578 .707 r
F P
0 g
s
.82911 .74307 m .82771 .7601 L .8388 .74702 L p .707 .577 .707 r
F P
0 g
s
.8388 .74702 m .84021 .72999 L .82911 .74307 L p .707 .577 .707 r
F P
0 g
s
.64627 .74482 m .64768 .72779 L .63909 .71306 L p .707 .577 .707 r
F P
0 g
s
.84308 .66398 m .84199 .7001 L .84268 .68917 L p .707 .577 .707 r
F P
0 g
s
.84268 .68917 m .84377 .65305 L .84308 .66398 L p .707 .577 .707 r
F P
0 g
s
.64029 .69323 m .64138 .65711 L .64207 .64618 L p .707 .577 .707 r
F P
0 g
s
.63909 .71306 m .63768 .73008 L .64627 .74482 L p .707 .577 .707 r
F P
0 g
s
.64075 .63002 m .63984 .57388 L .64869 .56668 L p .707 .577 .707 r
F P
0 g
s
.64207 .64618 m .64097 .6823 L .64029 .69323 L p .707 .577 .707 r
F P
0 g
s
.84154 .56924 m .84244 .62538 L .83154 .61864 L p .707 .577 .707 r
F P
0 g
s
.83154 .61864 m .83064 .56249 L .84154 .56924 L p .707 .577 .707 r
F P
0 g
s
.64869 .56668 m .64959 .62282 L .64075 .63002 L p .707 .577 .707 r
F P
0 g
s
.84021 .72999 m .8388 .74702 L .84012 .73239 L p .705 .576 .707 r
F P
0 g
s
.84012 .73239 m .84153 .71536 L .84021 .72999 L p .705 .576 .707 r
F P
0 g
s
.63768 .73008 m .63909 .71306 L .64041 .69843 L p .705 .576 .707 r
F P
0 g
s
.84377 .65305 m .84268 .68917 L .83346 .67844 L p .707 .577 .707 r
F P
0 g
s
.83346 .67844 m .83455 .64231 L .84377 .65305 L p .707 .577 .707 r
F P
0 g
s
.64097 .6823 m .64207 .64618 L .65259 .63612 L p .707 .577 .707 r
F P
0 g
s
.64041 .69843 m .639 .71545 L .63768 .73008 L p .705 .576 .707 r
F P
0 g
s
.38927 .62182 m .38711 .56651 L .35642 .56511 L p .707 .577 .707 r
F P
0 g
s
.38711 .56651 m .38927 .62182 L .42119 .62038 L p .707 .577 .707 r
F P
0 g
s
.42119 .62038 m .41904 .56507 L .38711 .56651 L p .707 .577 .707 r
F P
0 g
s
.41904 .56507 m .42119 .62038 L .45123 .61622 L p .707 .577 .707 r
F P
0 g
s
.45123 .61622 m .44907 .56091 L .41904 .56507 L p .707 .577 .707 r
F P
0 g
s
.64959 .62282 m .64869 .56668 L .66659 .56031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35857 .62042 m .35642 .56511 L .32996 .561 L p .707 .577 .707 r
F P
0 g
s
.35642 .56511 m .35857 .62042 L .38927 .62182 L p .707 .577 .707 r
F P
0 g
s
.83064 .56249 m .83154 .61864 L .81189 .61314 L p .707 .577 .707 r
F P
0 g
s
.81189 .61314 m .81099 .55699 L .83064 .56249 L p .707 .577 .707 r
F P
0 g
s
.65259 .63612 m .6515 .67224 L .64097 .6823 L p .707 .577 .707 r
F P
0 g
s
.44907 .56091 m .45123 .61622 L .47643 .60977 L p .707 .577 .707 r
F P
0 g
s
.47643 .60977 m .47427 .55446 L .44907 .56091 L p .707 .577 .707 r
F P
0 g
s
.84153 .71536 m .84012 .73239 L .83153 .71765 L p .707 .577 .707 r
F P
0 g
s
.83153 .71765 m .83294 .70062 L .84153 .71536 L p .707 .577 .707 r
F P
0 g
s
.639 .71545 m .64041 .69843 L .65151 .68535 L p .707 .577 .707 r
F P
0 g
s
.66659 .56031 m .66749 .61645 L .64959 .62282 L p .707 .577 .707 r
F P
0 g
s
.41391 .67883 m .41659 .64161 L .38471 .63928 L p .707 .577 .707 r
F P
0 g
s
.41659 .64161 m .41391 .67883 L .44445 .67866 L p .707 .577 .707 r
F P
0 g
s
.44445 .67866 m .44713 .64144 L .41659 .64161 L p .707 .577 .707 r
F P
0 g
s
.38203 .67649 m .38471 .63928 L .35461 .63466 L p .707 .577 .707 r
F P
0 g
s
.38471 .63928 m .38203 .67649 L .41391 .67883 L p .707 .577 .707 r
F P
0 g
s
.83455 .64231 m .83346 .67844 L .81524 .66895 L p .707 .577 .707 r
F P
0 g
s
.81524 .66895 m .81633 .63283 L .83455 .64231 L p .707 .577 .707 r
F P
0 g
s
.6515 .67224 m .65259 .63612 L .67192 .62791 L p .707 .577 .707 r
F P
0 g
s
.32996 .561 m .33211 .61631 L .35857 .62042 L p .707 .577 .707 r
F P
0 g
s
.65151 .68535 m .6501 .70237 L .639 .71545 L p .707 .577 .707 r
F P
0 g
s
.33211 .61631 m .32996 .561 L .31033 .55458 L p .707 .577 .707 r
F P
0 g
s
.47427 .55446 m .47643 .60977 L .49433 .60165 L p .707 .577 .707 r
F P
0 g
s
.49433 .60165 m .49217 .54634 L .47427 .55446 L p .707 .577 .707 r
F P
0 g
s
.66749 .61645 m .66659 .56031 L .6918 .55541 L p .707 .577 .707 r
F P
0 g
s
.44713 .64144 m .44445 .67866 L .47067 .67599 L p .707 .577 .707 r
F P
0 g
s
.47067 .67599 m .47335 .63878 L .44713 .64144 L p .707 .577 .707 r
F P
0 g
s
.35461 .63466 m .35193 .67188 L .38203 .67649 L p .707 .577 .707 r
F P
0 g
s
.35193 .67188 m .35461 .63466 L .32924 .62822 L p .707 .577 .707 r
F P
0 g
s
.81099 .55699 m .81189 .61314 L .78541 .60942 L p .707 .577 .707 r
F P
0 g
s
.78541 .60942 m .78451 .55328 L .81099 .55699 L p .707 .577 .707 r
F P
0 g
s
.40502 .71857 m .40848 .70007 L .37707 .69412 L p .707 .577 .707 r
F P
0 g
s
.40848 .70007 m .40502 .71857 L .43537 .72227 L p .707 .577 .707 r
F P
0 g
s
.43537 .72227 m .43883 .70376 L .40848 .70007 L p .707 .577 .707 r
F P
0 g
s
.37361 .71263 m .37707 .69412 L .34768 .68651 L p .707 .577 .707 r
F P
0 g
s
.37707 .69412 m .37361 .71263 L .40502 .71857 L p .707 .577 .707 r
F P
0 g
s
.67192 .62791 m .67083 .66403 L .6515 .67224 L p .707 .577 .707 r
F P
0 g
s
.34768 .68651 m .34422 .70501 L .37361 .71263 L p .707 .577 .707 r
F P
0 g
s
.32924 .62822 m .32656 .66543 L .35193 .67188 L p .707 .577 .707 r
F P
0 g
s
.31033 .55458 m .31248 .60989 L .33211 .61631 L p .707 .577 .707 r
F P
0 g
s
.6918 .55541 m .6927 .61155 L .66749 .61645 L p .707 .577 .707 r
F P
0 g
s
.83294 .70062 m .83153 .71765 L .81387 .70424 L p .707 .577 .707 r
F P
0 g
s
.81387 .70424 m .81528 .68721 L .83294 .70062 L p .707 .577 .707 r
F P
0 g
s
.6501 .70237 m .65151 .68535 L .67129 .67509 L p .707 .577 .707 r
F P
0 g
s
.43883 .70376 m .43537 .72227 L .46168 .72336 L p .707 .577 .707 r
F P
0 g
s
.46168 .72336 m .46515 .70485 L .43883 .70376 L p .707 .577 .707 r
F P
0 g
s
.34422 .70501 m .34768 .68651 L .32318 .67797 L p .707 .577 .707 r
F P
0 g
s
.81633 .63283 m .81524 .66895 L .78979 .66165 L p .707 .577 .707 r
F P
0 g
s
.78979 .66165 m .79089 .62552 L .81633 .63283 L p .707 .577 .707 r
F P
0 g
s
.6927 .61155 m .6918 .55541 L .72185 .55244 L p .707 .577 .707 r
F P
0 g
s
.67083 .66403 m .67192 .62791 L .69817 .62237 L p .707 .577 .707 r
F P
0 g
s
.47335 .63878 m .47067 .67599 L .48999 .6711 L p .707 .577 .707 r
F P
0 g
s
.48999 .6711 m .49267 .63389 L .47335 .63878 L p .707 .577 .707 r
F P
0 g
s
.32318 .67797 m .31972 .69648 L .34422 .70501 L p .707 .577 .707 r
F P
0 g
s
.32656 .66543 m .32924 .62822 L .31108 .62058 L p .707 .577 .707 r
F P
0 g
s
.31248 .60989 m .31033 .55458 L .29944 .54648 L p .707 .577 .707 r
F P
0 g
s
.78451 .55328 m .78541 .60942 L .7547 .60785 L p .707 .577 .707 r
F P
0 g
s
.7547 .60785 m .75379 .55171 L .78451 .55328 L p .707 .577 .707 r
F P
0 g
s
.67129 .67509 m .66989 .69212 L .6501 .70237 L p .707 .577 .707 r
F P
0 g
s
.49217 .54634 m .49433 .60165 L .50317 .59265 L p .707 .577 .707 r
F P
0 g
s
.50317 .59265 m .50102 .53734 L .49217 .54634 L p .707 .577 .707 r
F P
0 g
s
.72275 .60859 m .72185 .55244 L .75379 .55171 L p .707 .577 .707 r
F P
0 g
s
.72185 .55244 m .72275 .60859 L .6927 .61155 L p .707 .577 .707 r
F P
0 g
s
.31108 .62058 m .3084 .6578 L .32656 .66543 L p .707 .577 .707 r
F P
0 g
s
.75379 .55171 m .7547 .60785 L .72275 .60859 L p .707 .577 .707 r
F P
0 g
s
.69817 .62237 m .69708 .65849 L .67083 .66403 L p .707 .577 .707 r
F P
0 g
s
.46515 .70485 m .46168 .72336 L .4814 .72173 L p .707 .577 .707 r
F P
0 g
s
.4814 .72173 m .48486 .70323 L .46515 .70485 L p .707 .577 .707 r
F P
0 g
s
.31972 .69648 m .32318 .67797 L .30597 .66935 L p .707 .577 .707 r
F P
0 g
s
.79089 .62552 m .78979 .66165 L .75962 .65723 L p .707 .577 .707 r
F P
0 g
s
.75962 .65723 m .76072 .62111 L .79089 .62552 L p .707 .577 .707 r
F P
0 g
s
.81528 .68721 m .81387 .70424 L .78888 .69347 L p .707 .577 .707 r
F P
0 g
s
.78888 .69347 m .79028 .67645 L .81528 .68721 L p .707 .577 .707 r
F P
0 g
s
.69708 .65849 m .69817 .62237 L .72877 .62002 L p .707 .577 .707 r
F P
0 g
s
.66989 .69212 m .67129 .67509 L .69784 .66866 L p .707 .577 .707 r
F P
0 g
s
.29944 .54648 m .3016 .60179 L .31248 .60989 L p .707 .577 .707 r
F P
0 g
s
.30597 .66935 m .30251 .68786 L .31972 .69648 L p .707 .577 .707 r
F P
0 g
s
.76072 .62111 m .75962 .65723 L .72768 .65615 L p .707 .577 .707 r
F P
0 g
s
.72768 .65615 m .72877 .62002 L .76072 .62111 L p .707 .577 .707 r
F P
0 g
s
.49267 .63389 m .48999 .6711 L .50053 .66446 L p .707 .577 .707 r
F P
0 g
s
.50053 .66446 m .50321 .62725 L .49267 .63389 L p .707 .577 .707 r
F P
0 g
s
.72877 .62002 m .72768 .65615 L .69708 .65849 L p .707 .577 .707 r
F P
0 g
s
.69784 .66866 m .69643 .68569 L .66989 .69212 L p .707 .577 .707 r
F P
0 g
s
.3084 .6578 m .31108 .62058 L .30192 .6125 L p .707 .577 .707 r
F P
0 g
s
.3016 .60179 m .29944 .54648 L .29837 .53749 L p .707 .578 .707 r
F P
0 g
s
.79028 .67645 m .78888 .69347 L .75899 .6864 L p .707 .577 .707 r
F P
0 g
s
.75899 .6864 m .7604 .66938 L .79028 .67645 L p .707 .577 .707 r
F P
0 g
s
.69643 .68569 m .69784 .66866 L .72854 .66669 L p .707 .577 .707 r
F P
0 g
s
.50102 .53734 m .50317 .59265 L .5021 .58367 L p .707 .578 .707 r
F P
0 g
s
.5021 .58367 m .49995 .52836 L .50102 .53734 L p .707 .578 .707 r
F P
0 g
s
.30192 .6125 m .29924 .64971 L .3084 .6578 L p .707 .577 .707 r
F P
0 g
s
.48486 .70323 m .4814 .72173 L .49257 .71755 L p .707 .577 .707 r
F P
0 g
s
.49257 .71755 m .49603 .69904 L .48486 .70323 L p .707 .577 .707 r
F P
0 g
s
.30251 .68786 m .30597 .66935 L .29774 .66149 L p .707 .577 .707 r
F P
0 g
s
.7604 .66938 m .75899 .6864 L .72714 .68372 L p .707 .577 .707 r
F P
0 g
s
.72714 .68372 m .72854 .66669 L .7604 .66938 L p .707 .577 .707 r
F P
0 g
s
.72854 .66669 m .72714 .68372 L .69643 .68569 L p .707 .577 .707 r
F P
0 g
s
.29774 .66149 m .29428 .68 L .30251 .68786 L p .707 .577 .707 r
F P
0 g
s
.29837 .53749 m .30052 .5928 L .3016 .60179 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.50321 .62725 m .50053 .66446 L .50125 .65671 L p .706 .576 .707 r
F P
0 g
s
.50125 .65671 m .50393 .6195 L .50321 .62725 L p .706 .576 .707 r
F P
0 g
s
.29924 .64971 m .30192 .6125 L .30264 .60475 L p .706 .576 .707 r
F P
0 g
s
.30052 .5928 m .29837 .53749 L .30722 .5285 L p .707 .577 .707 r
F P
0 g
s
.49995 .52836 m .5021 .58367 L .49122 .57557 L p .707 .577 .707 r
F P
0 g
s
.49122 .57557 m .48906 .52026 L .49995 .52836 L p .707 .577 .707 r
F P
0 g
s
.30264 .60475 m .29996 .64197 L .29924 .64971 L p .706 .576 .707 r
F P
0 g
s
.49603 .69904 m .49257 .71755 L .49412 .71122 L p .707 .577 .707 r
F P
0 g
s
.49412 .71122 m .49758 .69271 L .49603 .69904 L p .707 .577 .707 r
F P
0 g
s
.29428 .68 m .29774 .66149 L .29928 .65516 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29928 .65516 m .29582 .67367 L .29428 .68 L p .707 .577 .707 r
F P
0 g
s
.30722 .5285 m .30937 .58381 L .30052 .5928 L p .707 .577 .707 r
F P
0 g
s
.50393 .6195 m .50125 .65671 L .49208 .64863 L p .707 .577 .707 r
F P
0 g
s
.49208 .64863 m .49476 .61141 L .50393 .6195 L p .707 .577 .707 r
F P
0 g
s
.29996 .64197 m .30264 .60475 L .31317 .59811 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30937 .58381 m .30722 .5285 L .32512 .52037 L p .707 .577 .707 r
F P
0 g
s
.48906 .52026 m .49122 .57557 L .47159 .56914 L p .707 .577 .707 r
F P
0 g
s
.47159 .56914 m .46943 .51384 L .48906 .52026 L p .707 .577 .707 r
F P
0 g
s
.31317 .59811 m .31049 .63532 L .29996 .64197 L p .707 .577 .707 r
F P
0 g
s
.49758 .69271 m .49412 .71122 L .48588 .70336 L p .707 .577 .707 r
F P
0 g
s
.48588 .70336 m .48934 .68485 L .49758 .69271 L p .707 .577 .707 r
F P
0 g
s
.29582 .67367 m .29928 .65516 L .31046 .65097 L p .707 .577 .707 r
F P
0 g
s
.31046 .65097 m .307 .66948 L .29582 .67367 L p .707 .577 .707 r
F P
0 g
s
.32512 .52037 m .32727 .57568 L .30937 .58381 L p .707 .577 .707 r
F P
0 g
s
.32727 .57568 m .32512 .52037 L .35032 .51392 L p .707 .577 .707 r
F P
0 g
s
.49476 .61141 m .49208 .64863 L .47392 .64099 L p .707 .577 .707 r
F P
0 g
s
.47392 .64099 m .4766 .60378 L .49476 .61141 L p .707 .577 .707 r
F P
0 g
s
.31049 .63532 m .31317 .59811 L .3325 .59322 L p .707 .577 .707 r
F P
0 g
s
.46943 .51384 m .47159 .56914 L .44513 .56503 L p .707 .577 .707 r
F P
0 g
s
.44513 .56503 m .44297 .50972 L .46943 .51384 L p .707 .577 .707 r
F P
0 g
s
.3325 .59322 m .32981 .63043 L .31049 .63532 L p .707 .577 .707 r
F P
0 g
s
.48934 .68485 m .48588 .70336 L .46867 .69474 L p .707 .577 .707 r
F P
0 g
s
.46867 .69474 m .47213 .67623 L .48934 .68485 L p .707 .577 .707 r
F P
0 g
s
.35032 .51392 m .35247 .56923 L .32727 .57568 L p .707 .577 .707 r
F P
0 g
s
.307 .66948 m .31046 .65097 L .33017 .64935 L p .707 .577 .707 r
F P
0 g
s
.35247 .56923 m .35032 .51392 L .38035 .50977 L p .707 .577 .707 r
F P
0 g
s
.33017 .64935 m .32671 .66786 L .307 .66948 L p .707 .577 .707 r
F P
0 g
s
.44297 .50972 m .44513 .56503 L .41443 .56363 L p .707 .577 .707 r
F P
0 g
s
.41443 .56363 m .41228 .50832 L .44297 .50972 L p .707 .577 .707 r
F P
0 g
s
.4766 .60378 m .47392 .64099 L .44855 .63455 L p .707 .577 .707 r
F P
0 g
s
.44855 .63455 m .45123 .59733 L .4766 .60378 L p .707 .577 .707 r
F P
0 g
s
.32981 .63043 m .3325 .59322 L .35871 .59055 L p .707 .577 .707 r
F P
0 g
s
.3825 .56508 m .38035 .50977 L .41228 .50832 L p .707 .577 .707 r
F P
0 g
s
.38035 .50977 m .3825 .56508 L .35247 .56923 L p .707 .577 .707 r
F P
0 g
s
.41228 .50832 m .41443 .56363 L .3825 .56508 L p .707 .577 .707 r
F P
0 g
s
.35871 .59055 m .35603 .62777 L .32981 .63043 L p .707 .577 .707 r
F P
0 g
s
.47213 .67623 m .46867 .69474 L .44417 .6862 L p .707 .577 .707 r
F P
0 g
s
.44417 .6862 m .44763 .66769 L .47213 .67623 L p .707 .577 .707 r
F P
0 g
s
.32671 .66786 m .33017 .64935 L .35649 .65044 L p .707 .577 .707 r
F P
0 g
s
.45123 .59733 m .44855 .63455 L .41845 .62993 L p .707 .577 .707 r
F P
0 g
s
.41845 .62993 m .42114 .59272 L .45123 .59733 L p .707 .577 .707 r
F P
0 g
s
.35603 .62777 m .35871 .59055 L .38925 .59038 L p .707 .577 .707 r
F P
0 g
s
.35649 .65044 m .35303 .66894 L .32671 .66786 L p .707 .577 .707 r
F P
0 g
s
.42114 .59272 m .41845 .62993 L .38657 .6276 L p .707 .577 .707 r
F P
0 g
s
.38657 .6276 m .38925 .59038 L .42114 .59272 L p .707 .577 .707 r
F P
0 g
s
.38925 .59038 m .38657 .6276 L .35603 .62777 L p .707 .577 .707 r
F P
0 g
s
.44763 .66769 m .44417 .6862 L .41478 .67859 L p .707 .577 .707 r
F P
0 g
s
.41478 .67859 m .41824 .66008 L .44763 .66769 L p .707 .577 .707 r
F P
0 g
s
.35303 .66894 m .35649 .65044 L .38683 .65413 L p .707 .577 .707 r
F P
0 g
s
.38683 .65413 m .38337 .67264 L .35303 .66894 L p .707 .577 .707 r
F P
0 g
s
.41824 .66008 m .41478 .67859 L .38337 .67264 L p .707 .577 .707 r
F P
0 g
s
.38337 .67264 m .38683 .65413 L .41824 .66008 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
0UYF5@000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol50002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol0069oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00GWoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001KOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Moo`8000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Eoo`<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol01000FUIJEP001EYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0001Yoo`P004=oo`00E7oo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;Ool?0004FUH01000
FUIJEUYF2000>goo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Moo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000dOol005Aoo`04001JEUYF0005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF000017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01000<7oo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF
6@0015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00EGoo00<005YF00001EYF00<0
05YFFUH00eYF1P0000=JEP0000001`0015YF00<005YFFUH01EYF00<005YFFUH01P000eYF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<005YF00001EYF00<005YF00000`000UYF00<0
05YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0002FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Goo001EOol00`00FUH00005FUH20006FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eoo`03001J
EP0000=JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00@005YF001JEP80009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol01000FUH0000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol200000eYF001JEP03FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF000]Ool005Eoo`04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eo
o`04001JEUYF0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60005FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00>Woo5`0017oo
00<005YFFUH00`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool003Ioo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00<goo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool0
035oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH?0006FUH00`00FUIJEP080003
FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF00000`000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01P000eYF00@005YFFUH0
02eoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000`000UYF00<007ooOol0:goo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00P000UYF00<005YFFUH015YF5`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00
FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH300000eYF001JEP02FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF20000UYF00<005YF00001EYF3P0015YF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP06001J
EP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF1P0015YF1P00
0eYF00<005YFFUH00UYF1P001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<0009JEP8002ioo`00;7oo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPX000=JEP03001JEUYF00QJEP@00003FUH005YF00=JEP03
001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<002moo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEP0001<0009JEP<000=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002ioo`00;7oo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000=JEP`000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH60002FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0
000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH70006Ool50005Ool600000eYF001JEP03
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YF00000`000eYF00@005YF
FUIJEQD0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH00UYF20003goo10000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00@005YFFUH000=JEP<000MJEP03001JEUYF
00EJEP03001JEP0000@000=JEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00=JEP04
001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP02FUH5000015YF001JEP005goo10001EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00D0
05YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001J
EUYF009JEP04001JEUYF0002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP030005FUH01000FUIJEP000goo2@003Woo100000=JEP00FUH00eYF00@0
05YFFUH002eoo`00;7oo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000`0015YF2P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF0000009JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEPP000AJEP03001JEUYF
009JEPH000aoo`<000=JEP04001JEUYF000]Ool002aoo`@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEUYFFUH400000eYF00000004FUH01000FUIJEUYF3`0015YF00<0
05YFFUH01eYF00@005YFFUIJEP<00004FUH000000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01@00FUH00000FUH01@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`002goo0P0000EJEP00FUIJEP0002eoo`00;7oo00@005YFFUH0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEUYFFUH00002FUH01000
FUIJEUYF0`0000=JEP00FUH00eYF0`0000=JEP0000003P001eYF00<005YFFUH015YF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF100027oo0`000UYF00<007oo
Ool0:goo000/Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEP000004FUH01@00FUH005YF00001EYF00<0
05YF00002P0015YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH00000009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004Ool20002FUH200000eYF001oo`0/
Ool002aoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30004FUH01000FUIJEUYF0P000UYF00D005YF001JEP0000EJEPH000=JEP04001JEUYF
FUH300000eYF001JEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YFFUH00eYF3`0015YF00<005YF
FUH01UYF00@005YFFUIJEP@000AJEP04001JEP00000]Ool002aoo`04001JEUYF0005FUH00`00FUIJ
EP05FUH01000FUIJEUYF5P000eYF00<005YFFUH015YF1@0000=JEP00FUH015YF1P000eYF00<005YF
FUH015YF0`001EYF00<005YFFUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YF00000`0000=JEP00FUH00UYF2@0000=o
o`0000001@001UYF00<005YFFUH00eYF0P0015YF00@005YFFUH002eoo`00;Goo00<005YF00001EYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00EJEP03
001JEUYF00@000AJEPH000=JEP03001JEUYF00MJEP@00003FUH005YF00AJEP04001JEP00000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF0P001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF0P000eYF00@005YFFUH002eoo`00
;Woo0P0015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P001eYF00<005YFFUH015YF1@0000AJEP00000000AJEP03001JEUYF00UJEP04001JEP000004FUH0
0`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0eYF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00H005YF0000
05YF0002FUH00`00Oomoo`0[Ool002moo`D00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP09FUH01000FUIJEUYF0P000UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YFFUIJEP80009JEP03001oogoo
02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF1P002UYF00<005YFFUH00UYF
100000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
000000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEUYF000]Ool002aoo`800003FUH005YF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP0000<000IJEP03001JEUYF00MJEP04001JEUYFFUH?0002FUH2000015YF001JEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF0`00;Woo000/Ool01000FUIJ
EP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH400001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000eYF0P00;goo000/Ool01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YF001JEPH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000015YF
001JEP00;Woo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP@0009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1P0015YF10000UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001oo`020002FUH00`00
Oomoo`0[Ool002aoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00@005YF
FUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEPD000=JEP@000IJEP03001JEUYF
00D00003FUH005YF00MJEP04001JEUYFFUH50004Ool01000FUIJEP00;Goo000/Ool01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00IJEQD000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000IJEP04001JEP000002
FUH00`00FUH000040002FUH00`00FUIJEP0500000eYF001JEP03FUH80009Ool01000FUIJEP00;Goo
000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF6P000eYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005FUH01000FUIJ
EUYF0`0000=JEP00Ool00goo40004Woo0P00;Woo000/Ool01000FUIJEP001EYF00@005YFFUIJEPP0
00=JEP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00=JEPH0009JEP05001JEP00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP02FUH200000eYF
001oo`09Ool3000IOol2000^Ool002aoo`04001JEUYF0003FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP0500000eYF001JEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000AJEP00FUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP020002FUH00`00FUIJEP02FUH00`00FUH0
000WOol2000^Ool002aoo`03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJEP04001JEUYF
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH00004FUH01000FUIJEP009Goo00<005YF
0000;Woo000/Ool40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`001EYF0`000eYF00@005YFFUH002Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP05001JEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005
FUH01000FUH000000UYF00@005YFFUH002Aoo`04001JEUYF000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<0004FUH00`00
FUIJEP05FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0000015YF00@005YFFUIJ
EP800004FUH005YF000ROol30002FUH00`00Oomoo`0/Ool002aoo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800004Ool005YF0005FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP05FUH4
000POol20002FUH00`00FUH0000_Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000=oo`03001JEP0000EJ
EP03001JEUYF009JEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00<000AJEP03001JEUYF00=JEP03001JEP0000D000MJEP03001JEP0000<001]oo`8000AJEP80
031oo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
4P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF000017oo0P00
1UYF00<005YFFUH00eYF1`0047oo100000=JEP00FUH00eYF0P00<7oo000cOol50003FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH20005FUH00`00FUH00004Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0005
FUH00`00FUIJEP02FUH00`00Oomoo`0_Ool003Qooa<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP800003FUH005YF009JEP8000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH000040000
15YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80039oo`00=7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP800003FUH005YF00L000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00000dOol002moo`D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP800004FUH005YF0003FUH70002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@00=Woo000]Ool200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00D0009o
o`L000AJEP03001JEUYF009JEPP003]oo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEQ`000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool90013Ool002eoo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP04001JEUYFFUH2001FOol002eoo`04001JEUYF0005FUH00`00FUIJEP02FUH800000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00001`000eYF00<005YFFUH00UYF0P00EGoo000]Ool01000FUIJEP000eYF
1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001Goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF1P000UYF0P00EGoo000]Ool80007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH9000DOol00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF001JEP05FUH00`00FUIJEP0200000goo00000002001EOol002eooa`001ioo`80
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH30006Ool2001DOol006Uoo`04
001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF0P001goo0`00E7oo001ZOol30008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUH000001EYF00<005YF00000`001goo0P0000=JEP000000E7oo001/Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40003
FUH6000:Ool00`00FUIJEP02FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00/000ioo`<000AJEP03001oogoo
059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`004Goo0P00
0UYF00<005YFFUH00UYF00<007ooOol0DWoo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP060006Ool5000?Ool20005FUH01000FUIJEP00EGoo001nOolO000<Ool5000=Ool2
00000eYF001JEP04FUH3001FOol008ioo`80009JEP03001oogoo01Eoo`<000]oo`<000=JEP03001J
EUYF00=JEP03001oogoo05Ioo`00SWoo00@005YF000002=oo`<000IJEP03001JEUYF009JEP03001o
ogoo05Moo`00SWoo00@005YF0000025oo`800003FUH005YF00MJEP04001JEP00001JOol008ioo`03
001JEP00008001eoo`<000=JEP03001JEUYF00IJEP8005aoo`00Sgoo00AJEP00001JEP8001Eoo`H0
00MJEP03001JEUYF00AJEP8005eoo`00Sgoo00<005YF00000eYF5@0015YF00<005YFFUH01UYF00<0
05YFFUH01000Ggoo002?Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF1000Hgoo002@Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH2001WOol0099oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP00008006Uoo`00U7oo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1P00K7oo002FOolE001bOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57907 .74689 m .58251 .69108 L .55219 .68687 L p .707 .577 .707 r
F P
0 g
s
.58251 .69108 m .57907 .74689 L .61098 .74876 L p .707 .577 .707 r
F P
0 g
s
.61098 .74876 m .61442 .69294 L .58251 .69108 L p .707 .577 .707 r
F P
0 g
s
.61442 .69294 m .61098 .74876 L .64135 .74809 L p .707 .577 .707 r
F P
0 g
s
.64135 .74809 m .64479 .69228 L .61442 .69294 L p .707 .577 .707 r
F P
0 g
s
.54874 .74269 m .55219 .68687 L .52641 .68073 L p .707 .577 .707 r
F P
0 g
s
.55219 .68687 m .54874 .74269 L .57907 .74689 L p .707 .577 .707 r
F P
0 g
s
.64479 .69228 m .64135 .74809 L .6672 .74497 L p .707 .577 .707 r
F P
0 g
s
.6672 .74497 m .67065 .68915 L .64479 .69228 L p .707 .577 .707 r
F P
0 g
s
.60419 .81318 m .59998 .77674 L .56834 .77916 L p .707 .577 .707 r
F P
0 g
s
.59998 .77674 m .60419 .81318 L .6352 .80782 L p .707 .577 .707 r
F P
0 g
s
.6352 .80782 m .63099 .77137 L .59998 .77674 L p .707 .577 .707 r
F P
0 g
s
.52641 .68073 m .52297 .73655 L .54874 .74269 L p .707 .577 .707 r
F P
0 g
s
.57255 .8156 m .56834 .77916 L .53917 .77839 L p .707 .577 .707 r
F P
0 g
s
.56834 .77916 m .57255 .8156 L .60419 .81318 L p .707 .577 .707 r
F P
0 g
s
.63099 .77137 m .6352 .80782 L .66253 .80002 L p .707 .577 .707 r
F P
0 g
s
.66253 .80002 m .65832 .76358 L .63099 .77137 L p .707 .577 .707 r
F P
0 g
s
.52297 .73655 m .52641 .68073 L .5077 .67326 L p .707 .577 .707 r
F P
0 g
s
.67065 .68915 m .6672 .74497 L .68601 .73969 L p .707 .577 .707 r
F P
0 g
s
.68601 .73969 m .68945 .68387 L .67065 .68915 L p .707 .577 .707 r
F P
0 g
s
.53917 .77839 m .54338 .81483 L .57255 .8156 L p .707 .577 .707 r
F P
0 g
s
.54338 .81483 m .53917 .77839 L .51533 .7745 L p .707 .577 .707 r
F P
0 g
s
.65832 .76358 m .66253 .80002 L .68353 .79056 L p .707 .577 .707 r
F P
0 g
s
.68353 .79056 m .67932 .75412 L .65832 .76358 L p .707 .577 .707 r
F P
0 g
s
.5077 .67326 m .50426 .72907 L .52297 .73655 L p .707 .577 .707 r
F P
0 g
s
.60882 .85872 m .60347 .8414 L .57308 .84806 L p .707 .577 .707 r
F P
0 g
s
.60347 .8414 m .60882 .85872 L .63908 .84861 L p .707 .577 .707 r
F P
0 g
s
.63908 .84861 m .63373 .83129 L .60347 .8414 L p .707 .577 .707 r
F P
0 g
s
.63373 .83129 m .63908 .84861 L .66624 .83605 L p .707 .577 .707 r
F P
0 g
s
.66624 .83605 m .6609 .81873 L .63373 .83129 L p .707 .577 .707 r
F P
0 g
s
.57308 .84806 m .57843 .86538 L .60882 .85872 L p .707 .577 .707 r
F P
0 g
s
.51533 .7745 m .51954 .81095 L .54338 .81483 L p .707 .577 .707 r
F P
0 g
s
.57843 .86538 m .57308 .84806 L .54553 .85062 L p .707 .577 .707 r
F P
0 g
s
.50426 .72907 m .5077 .67326 L .4979 .66518 L p .707 .577 .707 r
F P
0 g
s
.68945 .68387 m .68601 .73969 L .69594 .73276 L p .707 .577 .707 r
F P
0 g
s
.69594 .73276 m .69938 .67695 L .68945 .68387 L p .707 .577 .707 r
F P
0 g
s
.6609 .81873 m .66624 .83605 L .68765 .82226 L p .707 .577 .707 r
F P
0 g
s
.68765 .82226 m .68231 .80494 L .6609 .81873 L p .707 .577 .707 r
F P
0 g
s
.54553 .85062 m .55088 .86794 L .57843 .86538 L p .707 .577 .707 r
F P
0 g
s
.51954 .81095 m .51533 .7745 L .49913 .76789 L p .707 .577 .707 r
F P
0 g
s
.67932 .75412 m .68353 .79056 L .69613 .78037 L p .707 .577 .707 r
F P
0 g
s
.69613 .78037 m .69192 .74392 L .67932 .75412 L p .707 .577 .707 r
F P
0 g
s
.4979 .66518 m .49446 .721 L .50426 .72907 L p .707 .577 .707 r
F P
0 g
s
.55088 .86794 m .54553 .85062 L .52352 .84883 L p .707 .577 .707 r
F P
0 g
s
.49913 .76789 m .50334 .80433 L .51954 .81095 L p .707 .577 .707 r
F P
0 g
s
.52352 .84883 m .52887 .86615 L .55088 .86794 L p .707 .577 .707 r
F P
0 g
s
.68231 .80494 m .68765 .82226 L .70122 .80859 L p .707 .577 .707 r
F P
0 g
s
.70122 .80859 m .69587 .79128 L .68231 .80494 L p .707 .577 .707 r
F P
0 g
s
.49446 .721 m .4979 .66518 L .49797 .6573 L p .708 .578 .707 r
F P
0 g
s
.69938 .67695 m .69594 .73276 L .696 .72488 L p .708 .578 .707 r
F P
0 g
s
.696 .72488 m .69944 .66907 L .69938 .67695 L p .708 .578 .707 r
F P
0 g
s
.50334 .80433 m .49913 .76789 L .49218 .75919 L p .707 .577 .707 r
F P
0 g
s
.52887 .86615 m .52352 .84883 L .50921 .84287 L p .707 .577 .707 r
F P
0 g
s
.69236 .7477 m .69613 .78037 L .69843 .77269 L p .707 .577 .707 r
F P
0 g
s
.7056 .79639 m .70025 .77907 L .69587 .79128 L p .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69503 .76952 L .69975 .77816 L p .707 .577 .707 r
F P
0 g
s
.69975 .77816 m .70025 .77907 L p .70027 .78029 L .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69975 .77816 L .70027 .78029 L .707 .577 .707 r
F
.69192 .74392 m .69236 .7477 L p .6991 .77043 L F P
0 g
s
.69843 .77269 m .6991 .77043 L p .69236 .7477 L .707 .577 .707 r
F P
0 g
s
.6991 .77043 m .69489 .73399 L .69192 .74392 L p .707 .577 .707 r
F P
0 g
s
.49797 .6573 m .49453 .71312 L .49446 .721 L p .708 .578 .707 r
F P
0 g
s
.50921 .84287 m .51456 .86019 L .52887 .86615 L p .707 .577 .707 r
F P
0 g
s
.49218 .75919 m .49639 .79563 L .50334 .80433 L p .707 .577 .707 r
F P
0 g
s
.69587 .79128 m .70122 .80859 L .7056 .79639 L p .707 .577 .707 r
F P
0 g
s
.49453 .71312 m .49797 .6573 L .50789 .65038 L p .707 .577 .707 r
F P
0 g
s
.50789 .65038 m .50445 .7062 L .49453 .71312 L p .707 .577 .707 r
F P
0 g
s
.49515 .74925 m .49936 .7857 L .49639 .79563 L p .707 .577 .707 r
F P
0 g
s
.49936 .7857 m .49515 .74925 L .50775 .73906 L p .707 .577 .707 r
F P
0 g
s
.50775 .73906 m .51196 .7755 L .49936 .7857 L p .707 .577 .707 r
F P
0 g
s
.50166 .82192 m .50166 .32003 L .45701 .31828 L p .707 .577 .707 r
F P
0 g
s
.50445 .7062 m .50789 .65038 L .5267 .6451 L p .707 .577 .707 r
F P
0 g
s
.51456 .86019 m .50921 .84287 L .50398 .83332 L p .707 .577 .707 r
F P
0 g
s
.50398 .83332 m .50933 .85064 L .51456 .86019 L p .707 .577 .707 r
F P
0 g
s
.50933 .85064 m .50398 .83332 L .50837 .82112 L p .707 .577 .707 r
F P
0 g
s
.50837 .82112 m .51372 .83844 L .50933 .85064 L p .707 .577 .707 r
F P
0 g
s
.5267 .6451 m .52326 .70091 L .50445 .7062 L p .707 .577 .707 r
F P
0 g
s
.52326 .70091 m .5267 .6451 L .55255 .64197 L p .707 .577 .707 r
F P
0 g
s
.51196 .7755 m .50775 .73906 L .52875 .7296 L p .707 .577 .707 r
F P
0 g
s
.51372 .83844 m .50837 .82112 L .52193 .80745 L p .707 .577 .707 r
F P
0 g
s
.55255 .64197 m .54911 .69779 L .52326 .70091 L p .707 .577 .707 r
F P
0 g
s
.52193 .80745 m .52728 .82477 L .51372 .83844 L p .707 .577 .707 r
F P
0 g
s
.52875 .7296 m .53296 .76604 L .51196 .7755 L p .707 .577 .707 r
F P
0 g
s
.53296 .76604 m .52875 .7296 L .55609 .7218 L p .707 .577 .707 r
F P
0 g
s
.52728 .82477 m .52193 .80745 L .54334 .79366 L p .707 .577 .707 r
F P
0 g
s
.55609 .7218 m .5603 .75825 L .53296 .76604 L p .707 .577 .707 r
F P
0 g
s
.54334 .79366 m .54869 .81098 L .52728 .82477 L p .707 .577 .707 r
F P
0 g
s
.54869 .81098 m .54334 .79366 L .5705 .7811 L p .707 .577 .707 r
F P
0 g
s
.50166 .32003 m .50166 .82192 L .54615 .81989 L p .707 .577 .707 r
F P
0 g
s
.54615 .81989 m .54615 .318 L .50166 .32003 L p .707 .577 .707 r
F P
0 g
s
.45701 .82016 m .45701 .31828 L .41657 .3129 L p .707 .577 .707 r
F P
0 g
s
.49639 .79563 m .49218 .75919 L .49515 .74925 L p .707 .577 .707 r
F P
0 g
s
.45701 .31828 m .45701 .82016 L .50166 .82192 L p .707 .577 .707 r
F P
0 g
s
.54911 .69779 m .55255 .64197 L .58292 .64131 L p .707 .577 .707 r
F P
0 g
s
.58292 .64131 m .57948 .69712 L .54911 .69779 L p .707 .577 .707 r
F P
0 g
s
.5603 .75825 m .55609 .7218 L .58709 .71643 L p .707 .577 .707 r
F P
0 g
s
.58709 .71643 m .5913 .75288 L .5603 .75825 L p .707 .577 .707 r
F P
0 g
s
.5705 .7811 m .57585 .79842 L .54869 .81098 L p .707 .577 .707 r
F P
0 g
s
.57585 .79842 m .5705 .7811 L .60076 .77099 L p .707 .577 .707 r
F P
0 g
s
.60076 .77099 m .60611 .78831 L .57585 .79842 L p .707 .577 .707 r
F P
0 g
s
.54615 .318 m .54615 .81989 L .58612 .81427 L p .707 .577 .707 r
F P
0 g
s
.57948 .69712 m .58292 .64131 L .61483 .64317 L p .707 .577 .707 r
F P
0 g
s
.61483 .64317 m .61139 .69899 L .57948 .69712 L p .707 .577 .707 r
F P
0 g
s
.58612 .81427 m .58612 .31238 L .54615 .318 L p .707 .577 .707 r
F P
0 g
s
.69944 .66907 m .696 .72488 L .6862 .71681 L p .707 .577 .707 r
F P
0 g
s
.6862 .71681 m .68964 .66099 L .69944 .66907 L p .707 .577 .707 r
F P
0 g
s
.69489 .73399 m .6991 .77043 L .69215 .76173 L p .707 .577 .707 r
F P
0 g
s
.69215 .76173 m .68794 .72529 L .69489 .73399 L p .707 .577 .707 r
F P
0 g
s
.41657 .81479 m .41657 .3129 L .38429 .30444 L p .707 .577 .707 r
F P
0 g
s
.41657 .3129 m .41657 .81479 L .45701 .82016 L p .707 .577 .707 r
F P
0 g
s
.70025 .77907 m .7056 .79639 L .70038 .78684 L p .707 .577 .707 r
F P
0 g
s
.61873 .71402 m .62294 .75046 L .5913 .75288 L p .707 .577 .707 r
F P
0 g
s
.5913 .75288 m .58709 .71643 L .61873 .71402 L p .707 .577 .707 r
F P
0 g
s
.63115 .76434 m .6365 .78165 L .60611 .78831 L p .707 .577 .707 r
F P
0 g
s
.60611 .78831 m .60076 .77099 L .63115 .76434 L p .707 .577 .707 r
F P
0 g
s
.58612 .31238 m .58612 .81427 L .61767 .80561 L p .707 .577 .707 r
F P
0 g
s
.64516 .64738 m .64172 .7032 L .61139 .69899 L p .707 .577 .707 r
F P
0 g
s
.61139 .69899 m .61483 .64317 L .64516 .64738 L p .707 .577 .707 r
F P
0 g
s
.61767 .80561 m .61767 .30372 L .58612 .31238 L p .707 .577 .707 r
F P
0 g
s
.24053 .71615 m .24194 .66172 L .21156 .65773 L p .707 .577 .707 r
F P
0 g
s
.24194 .66172 m .24053 .71615 L .27249 .71691 L p .707 .577 .707 r
F P
0 g
s
.27249 .71691 m .2739 .66247 L .24194 .66172 L p .707 .577 .707 r
F P
0 g
s
.2739 .66247 m .27249 .71691 L .30289 .71436 L p .707 .577 .707 r
F P
0 g
s
.30289 .71436 m .30431 .65992 L .2739 .66247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68964 .66099 m .6862 .71681 L .6675 .70934 L p .707 .577 .707 r
F P
0 g
s
.6675 .70934 m .67094 .65352 L .68964 .66099 L p .707 .577 .707 r
F P
0 g
s
.21015 .71217 m .21156 .65773 L .18573 .65091 L p .707 .577 .707 r
F P
0 g
s
.21156 .65773 m .21015 .71217 L .24053 .71615 L p .707 .577 .707 r
F P
0 g
s
.30431 .65992 m .30289 .71436 L .32877 .70875 L p .707 .577 .707 r
F P
0 g
s
.32877 .70875 m .33019 .65432 L .30431 .65992 L p .707 .577 .707 r
F P
0 g
s
.68794 .72529 m .69215 .76173 L .67596 .75512 L p .707 .577 .707 r
F P
0 g
s
.67596 .75512 m .67175 .71867 L .68794 .72529 L p .707 .577 .707 r
F P
0 g
s
.38429 .80633 m .38429 .30444 L .36334 .29371 L p .707 .577 .707 r
F P
0 g
s
.38429 .30444 m .38429 .80633 L .41657 .81479 L p .707 .577 .707 r
F P
0 g
s
.69503 .76952 m .70038 .78684 L .68606 .78088 L p .707 .577 .707 r
F P
0 g
s
.68606 .78088 m .68071 .76356 L .69503 .76952 L p .707 .577 .707 r
F P
0 g
s
.6479 .71479 m .65211 .75123 L .62294 .75046 L p .707 .577 .707 r
F P
0 g
s
.62294 .75046 m .61873 .71402 L .6479 .71479 L p .707 .577 .707 r
F P
0 g
s
.6587 .76177 m .66405 .77909 L .6365 .78165 L p .707 .577 .707 r
F P
0 g
s
.6365 .78165 m .63115 .76434 L .6587 .76177 L p .707 .577 .707 r
F P
0 g
s
.61767 .30372 m .61767 .80561 L .63769 .79475 L p .707 .577 .707 r
F P
0 g
s
.63769 .79475 m .63769 .29286 L .61767 .30372 L p .707 .577 .707 r
F P
0 g
s
.26441 .75817 m .26276 .72012 L .23095 .72107 L p .707 .577 .707 r
F P
0 g
s
.26276 .72012 m .26441 .75817 L .29555 .75586 L p .707 .577 .707 r
F P
0 g
s
.29555 .75586 m .2939 .7178 L .26276 .72012 L p .707 .577 .707 r
F P
0 g
s
.2326 .75912 m .23095 .72107 L .20159 .72056 L p .707 .577 .707 r
F P
0 g
s
.23095 .72107 m .2326 .75912 L .26441 .75817 L p .707 .577 .707 r
F P
0 g
s
.18432 .70534 m .18573 .65091 L .16698 .64191 L p .707 .577 .707 r
F P
0 g
s
.18573 .65091 m .18432 .70534 L .21015 .71217 L p .707 .577 .707 r
F P
0 g
s
.33019 .65432 m .32877 .70875 L .34759 .70064 L p .707 .577 .707 r
F P
0 g
s
.34759 .70064 m .349 .64621 L .33019 .65432 L p .707 .577 .707 r
F P
0 g
s
.67094 .65352 m .6675 .70934 L .64172 .7032 L p .707 .577 .707 r
F P
0 g
s
.64172 .7032 m .64516 .64738 L .67094 .65352 L p .707 .577 .707 r
F P
0 g
s
.2319 .7645 m .234 .78355 L .26555 .7798 L p .707 .577 .707 r
F P
0 g
s
.26555 .7798 m .26345 .76074 L .2319 .7645 L p .707 .577 .707 r
F P
0 g
s
.26345 .76074 m .26555 .7798 L .29673 .77687 L p .707 .577 .707 r
F P
0 g
s
.2939 .7178 m .29555 .75586 L .32298 .75241 L p .707 .577 .707 r
F P
0 g
s
.32298 .75241 m .32133 .71435 L .2939 .7178 L p .707 .577 .707 r
F P
0 g
s
.29673 .77687 m .29462 .75781 L .26345 .76074 L p .707 .577 .707 r
F P
0 g
s
.20159 .72056 m .20324 .75861 L .2326 .75912 L p .707 .577 .707 r
F P
0 g
s
.20307 .76872 m .20517 .78778 L .234 .78355 L p .707 .577 .707 r
F P
0 g
s
.234 .78355 m .2319 .7645 L .20307 .76872 L p .707 .577 .707 r
F P
0 g
s
.29462 .75781 m .29673 .77687 L .32448 .77506 L p .707 .577 .707 r
F P
0 g
s
.32448 .77506 m .32238 .75601 L .29462 .75781 L p .707 .577 .707 r
F P
0 g
s
.67175 .71867 m .67596 .75512 L .65211 .75123 L p .707 .577 .707 r
F P
0 g
s
.65211 .75123 m .6479 .71479 L .67175 .71867 L p .707 .577 .707 r
F P
0 g
s
.20324 .75861 m .20159 .72056 L .17756 .71864 L p .707 .577 .707 r
F P
0 g
s
.17756 .71864 m .1792 .7567 L .20324 .75861 L p .707 .577 .707 r
F P
0 g
s
.32133 .71435 m .32298 .75241 L .34401 .74816 L p .707 .577 .707 r
F P
0 g
s
.34401 .74816 m .34236 .7101 L .32133 .71435 L p .707 .577 .707 r
F P
0 g
s
.17977 .77299 m .18188 .79205 L .20517 .78778 L p .707 .577 .707 r
F P
0 g
s
.20517 .78778 m .20307 .76872 L .17977 .77299 L p .707 .577 .707 r
F P
0 g
s
.16698 .64191 m .16557 .69635 L .18432 .70534 L p .707 .577 .707 r
F P
0 g
s
.68071 .76356 m .68606 .78088 L .66405 .77909 L p .707 .577 .707 r
F P
0 g
s
.66405 .77909 m .6587 .76177 L .68071 .76356 L p .707 .577 .707 r
F P
0 g
s
.32238 .75601 m .32448 .77506 L .34609 .77455 L p .707 .577 .707 r
F P
0 g
s
.16557 .69635 m .16698 .64191 L .15715 .63163 L p .707 .577 .707 r
F P
0 g
s
.34609 .77455 m .34399 .75549 L .32238 .75601 L p .707 .577 .707 r
F P
0 g
s
.349 .64621 m .34759 .70064 L .3575 .69082 L p .707 .577 .707 r
F P
0 g
s
.3575 .69082 m .35892 .63639 L .349 .64621 L p .707 .577 .707 r
F P
0 g
s
.35735 .75633 m .35945 .77538 L .36324 .77748 L p .707 .577 .707 r
F P
0 g
s
.36324 .77748 m .36114 .75842 L .35735 .75633 L p .707 .577 .707 r
F P
0 g
s
.34399 .75549 m .34609 .77455 L .35945 .77538 L p .707 .577 .707 r
F P
0 g
s
.35945 .77538 m .35735 .75633 L .34399 .75549 L p .707 .577 .707 r
F P
0 g
s
.36114 .75842 m .36324 .77748 L .3571 .78064 L p .707 .577 .707 r
F P
0 g
s
.36334 .7956 m .36334 .29371 L .35576 .28178 L p .707 .577 .707 r
F P
0 g
s
.36334 .29371 m .36334 .7956 L .38429 .80633 L p .707 .577 .707 r
F P
0 g
s
.1792 .7567 m .17756 .71864 L .16119 .71551 L p .707 .577 .707 r
F P
0 g
s
.63769 .29286 m .63769 .79475 L .64423 .78277 L p .707 .577 .707 r
F P
0 g
s
.64423 .78277 m .64423 .28088 L .63769 .29286 L p .707 .577 .707 r
F P
0 g
s
.16119 .71551 m .16284 .75356 L .1792 .7567 L p .707 .577 .707 r
F P
0 g
s
.1643 .7769 m .1664 .79595 L .18188 .79205 L p .707 .577 .707 r
F P
0 g
s
.18188 .79205 m .17977 .77299 L .1643 .7769 L p .707 .577 .707 r
F P
0 g
s
.34236 .7101 m .34401 .74816 L .35658 .74353 L p .707 .577 .707 r
F P
0 g
s
.35658 .74353 m .35493 .70547 L .34236 .7101 L p .707 .577 .707 r
F P
0 g
s
.15715 .63163 m .15573 .68606 L .16557 .69635 L p .707 .577 .707 r
F P
0 g
s
.15573 .68606 m .15715 .63163 L .15719 .62105 L p .708 .578 .707 r
F P
0 g
s
.35892 .63639 m .3575 .69082 L .35754 .68025 L p .708 .578 .707 r
F P
0 g
s
.35754 .68025 m .35896 .62582 L .35892 .63639 L p .708 .578 .707 r
F P
0 g
s
.16284 .75356 m .16119 .71551 L .1541 .71146 L p .707 .577 .707 r
F P
0 g
s
.1541 .71146 m .15575 .74952 L .16284 .75356 L p .707 .577 .707 r
F P
0 g
s
.15816 .78005 m .16026 .79911 L .1664 .79595 L p .707 .577 .707 r
F P
0 g
s
.1664 .79595 m .1643 .7769 L .15816 .78005 L p .707 .577 .707 r
F P
0 g
s
.35493 .70547 m .35658 .74353 L .35946 .73896 L p .707 .577 .707 r
F P
0 g
s
.35946 .73896 m .35781 .70091 L .35493 .70547 L p .707 .577 .707 r
F P
0 g
s
.15719 .62105 m .15577 .67549 L .15573 .68606 L p .708 .578 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35896 .62582 m .35754 .68025 L .3477 .66996 L p .707 .577 .707 r
F P
0 g
s
.3477 .66996 m .34912 .61553 L .35896 .62582 L p .707 .577 .707 r
F P
0 g
s
.35781 .70091 m .35946 .73896 L .35237 .73492 L p .707 .577 .707 r
F P
0 g
s
.35237 .73492 m .35072 .69686 L .35781 .70091 L p .707 .577 .707 r
F P
0 g
s
.3571 .78064 m .355 .76158 L .36114 .75842 L p .707 .577 .707 r
F P
0 g
s
.355 .76158 m .3571 .78064 L .3478 .78298 L p .707 .577 .707 r
F P
0 g
s
.3478 .78298 m .34163 .78454 L p .34797 .77366 L .707 .577 .707 r
F P
0 g
s
.34797 .77366 m .355 .76158 L .3478 .78298 L .707 .577 .707 r
F
.35919 .51443 m .35576 .78366 L .36334 .7956 L p F P
0 g
s
.35576 .35297 m .35665 .34174 L p .35576 .28178 L .707 .577 .707 r
F P
0 g
s
.35576 .78366 m .35576 .35297 L p .36231 .26979 L .707 .577 .707 r
F P
0 g
s
.35576 .35297 m .35576 .28178 L .35713 .27928 L p .707 .577 .707 r
F P
0 g
s
.35713 .27928 m .36231 .26979 L p .35576 .35297 L .707 .577 .707 r
F P
0 g
s
.64423 .28088 m .64423 .78277 L .63666 .77083 L p .707 .577 .707 r
F P
0 g
s
.63666 .77083 m .63666 .26894 L .64423 .28088 L p .707 .577 .707 r
F P
0 g
s
.15577 .67549 m .15719 .62105 L .1671 .61123 L p .707 .577 .707 r
F P
0 g
s
.15575 .74952 m .1541 .71146 L .15699 .7069 L p .707 .577 .707 r
F P
0 g
s
.15699 .7069 m .15863 .74495 L .15575 .74952 L p .707 .577 .707 r
F P
0 g
s
.16196 .78215 m .16406 .80121 L .16026 .79911 L p .707 .577 .707 r
F P
0 g
s
.16026 .79911 m .15816 .78005 L .16196 .78215 L p .707 .577 .707 r
F P
0 g
s
.1671 .61123 m .16568 .66567 L .15577 .67549 L p .707 .577 .707 r
F P
0 g
s
.16568 .66567 m .1671 .61123 L .18592 .60312 L p .707 .577 .707 r
F P
0 g
s
.34912 .61553 m .3477 .66996 L .32895 .66097 L p .707 .577 .707 r
F P
0 g
s
.32895 .66097 m .33037 .60653 L .34912 .61553 L p .707 .577 .707 r
F P
0 g
s
.36231 .77168 m .36231 .26979 L .38233 .25894 L p .707 .577 .707 r
F P
0 g
s
.36231 .26979 m .36231 .77168 L .35576 .78366 L p .707 .577 .707 r
F P
0 g
s
.63666 .26894 m .63666 .77083 L .61571 .76011 L p .707 .577 .707 r
F P
0 g
s
.61571 .76011 m .61571 .25822 L .63666 .26894 L p .707 .577 .707 r
F P
0 g
s
.15863 .74495 m .15699 .7069 L .16956 .70227 L p .707 .577 .707 r
F P
0 g
s
.16956 .70227 m .1712 .74032 L .15863 .74495 L p .707 .577 .707 r
F P
0 g
s
.17531 .78298 m .17741 .80204 L .16406 .80121 L p .707 .577 .707 r
F P
0 g
s
.16406 .80121 m .16196 .78215 L .17531 .78298 L p .707 .577 .707 r
F P
0 g
s
.18592 .60312 m .1845 .65756 L .16568 .66567 L p .707 .577 .707 r
F P
0 g
s
.35072 .69686 m .35237 .73492 L .33601 .73178 L p .707 .577 .707 r
F P
0 g
s
.33601 .73178 m .33436 .69373 L .35072 .69686 L p .707 .577 .707 r
F P
0 g
s
.1845 .65756 m .18592 .60312 L .21179 .59752 L p .707 .577 .707 r
F P
0 g
s
.33037 .60653 m .32895 .66097 L .30312 .65414 L p .707 .577 .707 r
F P
0 g
s
.30312 .65414 m .30454 .59971 L .33037 .60653 L p .707 .577 .707 r
F P
0 g
s
.34163 .78454 m .33953 .76548 L .355 .76158 L p .707 .577 .707 r
F P
0 g
s
.1712 .74032 m .16956 .70227 L .19058 .69802 L p .707 .577 .707 r
F P
0 g
s
.21038 .65195 m .21179 .59752 L .2422 .59497 L p .707 .577 .707 r
F P
0 g
s
.21179 .59752 m .21038 .65195 L .1845 .65756 L p .707 .577 .707 r
F P
0 g
s
.38233 .25894 m .38233 .76083 L .36231 .77168 L p .707 .577 .707 r
F P
0 g
s
.38233 .76083 m .38233 .25894 L .41387 .25028 L p .707 .577 .707 r
F P
0 g
s
.30454 .59971 m .30312 .65414 L .27274 .65016 L p .707 .577 .707 r
F P
0 g
s
.27274 .65016 m .27416 .59572 L .30454 .59971 L p .707 .577 .707 r
F P
0 g
s
.19058 .69802 m .19223 .73607 L .1712 .74032 L p .707 .577 .707 r
F P
0 g
s
.61571 .25822 m .61571 .76011 L .58343 .75165 L p .707 .577 .707 r
F P
0 g
s
.58343 .75165 m .58343 .24976 L .61571 .25822 L p .707 .577 .707 r
F P
0 g
s
.19693 .78247 m .19903 .80153 L .17741 .80204 L p .707 .577 .707 r
F P
0 g
s
.17741 .80204 m .17531 .78298 L .19693 .78247 L p .707 .577 .707 r
F P
0 g
s
.75921 .65242 m .7578 .59596 L .72584 .59672 L p .707 .577 .707 r
F P
0 g
s
.7578 .59596 m .75921 .65242 L .78962 .64968 L p .707 .577 .707 r
F P
0 g
s
.78962 .64968 m .7882 .59322 L .7578 .59596 L p .707 .577 .707 r
F P
0 g
s
.72726 .65318 m .72584 .59672 L .69546 .59542 L p .707 .577 .707 r
F P
0 g
s
.72584 .59672 m .72726 .65318 L .75921 .65242 L p .707 .577 .707 r
F P
0 g
s
.33436 .69373 m .33601 .73178 L .31197 .72987 L p .707 .577 .707 r
F P
0 g
s
.31197 .72987 m .31032 .69181 L .33436 .69373 L p .707 .577 .707 r
F P
0 g
s
.24078 .6494 m .2422 .59497 L .27416 .59572 L p .707 .577 .707 r
F P
0 g
s
.2422 .59497 m .24078 .6494 L .21038 .65195 L p .707 .577 .707 r
F P
0 g
s
.27416 .59572 m .27274 .65016 L .24078 .6494 L p .707 .577 .707 r
F P
0 g
s
.33953 .76548 m .34163 .78454 L .31834 .78881 L p .707 .577 .707 r
F P
0 g
s
.31834 .78881 m .31624 .76976 L .33953 .76548 L p .707 .577 .707 r
F P
0 g
s
.7882 .59322 m .78962 .64968 L .8155 .64521 L p .707 .577 .707 r
F P
0 g
s
.8155 .64521 m .81408 .58876 L .7882 .59322 L p .707 .577 .707 r
F P
0 g
s
.69688 .65188 m .69546 .59542 L .66963 .59219 L p .707 .577 .707 r
F P
0 g
s
.69546 .59542 m .69688 .65188 L .72726 .65318 L p .707 .577 .707 r
F P
0 g
s
.19223 .73607 m .19058 .69802 L .21801 .69457 L p .707 .577 .707 r
F P
0 g
s
.21801 .69457 m .21966 .73262 L .19223 .73607 L p .707 .577 .707 r
F P
0 g
s
.31032 .69181 m .31197 .72987 L .28261 .72936 L p .707 .577 .707 r
F P
0 g
s
.28261 .72936 m .28096 .6913 L .31032 .69181 L p .707 .577 .707 r
F P
0 g
s
.7492 .73184 m .75085 .6965 L .71904 .69411 L p .707 .577 .707 r
F P
0 g
s
.75085 .6965 m .7492 .73184 L .78034 .73029 L p .707 .577 .707 r
F P
0 g
s
.78034 .73029 m .78199 .69494 L .75085 .6965 L p .707 .577 .707 r
F P
0 g
s
.66963 .59219 m .67105 .64865 L .69688 .65188 L p .707 .577 .707 r
F P
0 g
s
.22468 .78066 m .22678 .79972 L .19903 .80153 L p .707 .577 .707 r
F P
0 g
s
.19903 .80153 m .19693 .78247 L .22468 .78066 L p .707 .577 .707 r
F P
0 g
s
.71739 .72945 m .71904 .69411 L .68968 .68801 L p .707 .577 .707 r
F P
0 g
s
.71904 .69411 m .71739 .72945 L .7492 .73184 L p .707 .577 .707 r
F P
0 g
s
.41387 .75217 m .41387 .25028 L .45384 .24466 L p .707 .577 .707 r
F P
0 g
s
.41387 .25028 m .41387 .75217 L .38233 .76083 L p .707 .577 .707 r
F P
0 g
s
.58343 .24976 m .58343 .75165 L .54299 .74627 L p .707 .577 .707 r
F P
0 g
s
.54299 .74627 m .54299 .24438 L .58343 .24976 L p .707 .577 .707 r
F P
0 g
s
.81408 .58876 m .8155 .64521 L .83431 .63947 L p .707 .577 .707 r
F P
0 g
s
.83431 .63947 m .8329 .58301 L .81408 .58876 L p .707 .577 .707 r
F P
0 g
s
.31624 .76976 m .31834 .78881 L .28951 .79303 L p .707 .577 .707 r
F P
0 g
s
.67105 .64865 m .66963 .59219 L .65088 .58734 L p .707 .577 .707 r
F P
0 g
s
.78199 .69494 m .78034 .73029 L .80777 .72494 L p .707 .577 .707 r
F P
0 g
s
.80777 .72494 m .80941 .68959 L .78199 .69494 L p .707 .577 .707 r
F P
0 g
s
.28951 .79303 m .2874 .77398 L .31624 .76976 L p .707 .577 .707 r
F P
0 g
s
.21966 .73262 m .21801 .69457 L .24915 .69225 L p .707 .577 .707 r
F P
0 g
s
.28096 .6913 m .28261 .72936 L .2508 .73031 L p .707 .577 .707 r
F P
0 g
s
.2508 .73031 m .24915 .69225 L .28096 .6913 L p .707 .577 .707 r
F P
0 g
s
.68803 .72336 m .68968 .68801 L .66564 .6788 L p .707 .577 .707 r
F P
0 g
s
.68968 .68801 m .68803 .72336 L .71739 .72945 L p .707 .577 .707 r
F P
0 g
s
.24915 .69225 m .2508 .73031 L .21966 .73262 L p .707 .577 .707 r
F P
0 g
s
.25586 .77773 m .25796 .79679 L .22678 .79972 L p .707 .577 .707 r
F P
0 g
s
.22678 .79972 m .22468 .78066 L .25586 .77773 L p .707 .577 .707 r
F P
0 g
s
.65088 .58734 m .65229 .6438 L .67105 .64865 L p .707 .577 .707 r
F P
0 g
s
.2874 .77398 m .28951 .79303 L .25796 .79679 L p .707 .577 .707 r
F P
0 g
s
.25796 .79679 m .25586 .77773 L .2874 .77398 L p .707 .577 .707 r
F P
0 g
s
.80941 .68959 m .80777 .72494 L .82879 .71632 L p .707 .577 .707 r
F P
0 g
s
.82879 .71632 m .83044 .68098 L .80941 .68959 L p .707 .577 .707 r
F P
0 g
s
.45384 .74655 m .45384 .24466 L .49833 .24263 L p .707 .577 .707 r
F P
0 g
s
.45384 .24466 m .45384 .74655 L .41387 .75217 L p .707 .577 .707 r
F P
0 g
s
.54299 .24438 m .54299 .74627 L .49833 .74452 L p .707 .577 .707 r
F P
0 g
s
.49833 .74452 m .49833 .24263 L .54299 .24438 L p .707 .577 .707 r
F P
0 g
s
.66564 .6788 m .66399 .71415 L .68803 .72336 L p .707 .577 .707 r
F P
0 g
s
.8329 .58301 m .83431 .63947 L .84423 .63301 L p .707 .577 .707 r
F P
0 g
s
.84423 .63301 m .84281 .57655 L .8329 .58301 L p .707 .577 .707 r
F P
0 g
s
.49833 .24263 m .49833 .74452 L .45384 .74655 L p .707 .577 .707 r
F P
0 g
s
.66399 .71415 m .66564 .6788 L .64928 .66738 L p .707 .577 .707 r
F P
0 g
s
.65229 .6438 m .65088 .58734 L .64104 .58135 L p .707 .577 .707 r
F P
0 g
s
.74204 .79017 m .74414 .77464 L .71259 .7696 L p .707 .577 .707 r
F P
0 g
s
.74414 .77464 m .74204 .79017 L .77322 .78935 L p .707 .577 .707 r
F P
0 g
s
.77322 .78935 m .77532 .77382 L .74414 .77464 L p .707 .577 .707 r
F P
0 g
s
.71049 .78513 m .71259 .7696 L .68376 .75919 L p .707 .577 .707 r
F P
0 g
s
.71259 .7696 m .71049 .78513 L .74204 .79017 L p .707 .577 .707 r
F P
0 g
s
.77532 .77382 m .77322 .78935 L .80097 .78275 L p .707 .577 .707 r
F P
0 g
s
.80097 .78275 m .80307 .76722 L .77532 .77382 L p .707 .577 .707 r
F P
0 g
s
.64104 .58135 m .64246 .63781 L .65229 .6438 L p .707 .577 .707 r
F P
0 g
s
.83044 .68098 m .82879 .71632 L .84136 .70529 L p .707 .577 .707 r
F P
0 g
s
.84136 .70529 m .84301 .66994 L .83044 .68098 L p .707 .577 .707 r
F P
0 g
s
.68166 .77472 m .68376 .75919 L .66047 .74443 L p .707 .577 .707 r
F P
0 g
s
.68376 .75919 m .68166 .77472 L .71049 .78513 L p .707 .577 .707 r
F P
0 g
s
.64928 .66738 m .64763 .70273 L .66399 .71415 L p .707 .577 .707 r
F P
0 g
s
.64763 .70273 m .64928 .66738 L .64219 .65487 L p .707 .577 .707 r
F P
0 g
s
.66047 .74443 m .65837 .75996 L .68166 .77472 L p .707 .577 .707 r
F P
0 g
s
.80307 .76722 m .80097 .78275 L .82258 .77102 L p .707 .577 .707 r
F P
0 g
s
.82258 .77102 m .82469 .75548 L .80307 .76722 L p .707 .577 .707 r
F P
0 g
s
.84281 .57655 m .84423 .63301 L .84427 .62646 L p .706 .577 .707 r
F P
0 g
s
.84427 .62646 m .84285 .57001 L .84281 .57655 L p .706 .577 .707 r
F P
0 g
s
.64246 .63781 m .64104 .58135 L .64108 .5748 L p .706 .577 .707 r
F P
0 g
s
.65837 .75996 m .66047 .74443 L .64499 .72677 L p .707 .577 .707 r
F P
0 g
s
.64219 .65487 m .64054 .69021 L .64763 .70273 L p .707 .577 .707 r
F P
0 g
s
.84301 .66994 m .84136 .70529 L .84425 .6929 L p .707 .577 .707 r
F P
0 g
s
.84425 .6929 m .84589 .65756 L .84301 .66994 L p .707 .577 .707 r
F P
0 g
s
.64499 .72677 m .64289 .7423 L .65837 .75996 L p .707 .577 .707 r
F P
0 g
s
.64108 .5748 m .6425 .63126 L .64246 .63781 L p .706 .577 .707 r
F P
0 g
s
.82469 .75548 m .82258 .77102 L .83594 .75529 L p .707 .577 .707 r
F P
0 g
s
.83594 .75529 m .83804 .73976 L .82469 .75548 L p .707 .577 .707 r
F P
0 g
s
.64289 .7423 m .64499 .72677 L .63885 .70793 L p .707 .577 .707 r
F P
0 g
s
.64054 .69021 m .64219 .65487 L .64507 .64248 L p .707 .577 .707 r
F P
0 g
s
.84285 .57001 m .84427 .62646 L .83443 .62047 L p .707 .577 .707 r
F P
0 g
s
.83443 .62047 m .83302 .56401 L .84285 .57001 L p .707 .577 .707 r
F P
0 g
s
.6425 .63126 m .64108 .5748 L .651 .56834 L p .707 .577 .707 r
F P
0 g
s
.63885 .70793 m .63675 .72346 L .64289 .7423 L p .707 .577 .707 r
F P
0 g
s
.64507 .64248 m .64342 .67783 L .64054 .69021 L p .707 .577 .707 r
F P
0 g
s
.84589 .65756 m .84425 .6929 L .83716 .68039 L p .707 .577 .707 r
F P
0 g
s
.83716 .68039 m .83881 .64504 L .84589 .65756 L p .707 .577 .707 r
F P
0 g
s
.83804 .73976 m .83594 .75529 L .83974 .73713 L p .707 .577 .707 r
F P
0 g
s
.83974 .73713 m .84184 .7216 L .83804 .73976 L p .707 .577 .707 r
F P
0 g
s
.651 .56834 m .65241 .6248 L .6425 .63126 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63675 .72346 m .63885 .70793 L .64265 .68976 L p .707 .577 .707 r
F P
0 g
s
.64342 .67783 m .64507 .64248 L .65764 .63144 L p .707 .577 .707 r
F P
0 g
s
.42052 .62073 m .41708 .5656 L .38517 .56741 L p .707 .577 .707 r
F P
0 g
s
.41708 .5656 m .42052 .62073 L .45088 .61615 L p .707 .577 .707 r
F P
0 g
s
.45088 .61615 m .44744 .56102 L .41708 .5656 L p .707 .577 .707 r
F P
0 g
s
.38861 .62253 m .38517 .56741 L .35484 .56626 L p .707 .577 .707 r
F P
0 g
s
.38517 .56741 m .38861 .62253 L .42052 .62073 L p .707 .577 .707 r
F P
0 g
s
.64265 .68976 m .64055 .70529 L .63675 .72346 L p .707 .577 .707 r
F P
0 g
s
.83302 .56401 m .83443 .62047 L .81568 .61562 L p .707 .577 .707 r
F P
0 g
s
.81568 .61562 m .81426 .55916 L .83302 .56401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65241 .6248 m .651 .56834 L .66981 .5626 L p .707 .577 .707 r
F P
0 g
s
.44744 .56102 m .45088 .61615 L .47674 .60924 L p .707 .577 .707 r
F P
0 g
s
.47674 .60924 m .4733 .55411 L .44744 .56102 L p .707 .577 .707 r
F P
0 g
s
.84184 .7216 m .83974 .73713 L .8336 .71829 L p .707 .577 .707 r
F P
0 g
s
.8336 .71829 m .8357 .70276 L .84184 .7216 L p .707 .577 .707 r
F P
0 g
s
.35828 .62139 m .35484 .56626 L .32906 .56228 L p .707 .577 .707 r
F P
0 g
s
.35484 .56626 m .35828 .62139 L .38861 .62253 L p .707 .577 .707 r
F P
0 g
s
.65764 .63144 m .65599 .66679 L .64342 .67783 L p .707 .577 .707 r
F P
0 g
s
.83881 .64504 m .83716 .68039 L .82079 .66897 L p .707 .577 .707 r
F P
0 g
s
.82079 .66897 m .82244 .63362 L .83881 .64504 L p .707 .577 .707 r
F P
0 g
s
.66981 .5626 m .67123 .61906 L .65241 .6248 L p .707 .577 .707 r
F P
0 g
s
.64055 .70529 m .64265 .68976 L .65601 .67404 L p .707 .577 .707 r
F P
0 g
s
.40869 .67742 m .4129 .64025 L .38127 .63616 L p .707 .577 .707 r
F P
0 g
s
.4129 .64025 m .40869 .67742 L .4397 .6791 L p .707 .577 .707 r
F P
0 g
s
.4397 .6791 m .44391 .64193 L .4129 .64025 L p .707 .577 .707 r
F P
0 g
s
.37706 .67333 m .38127 .63616 L .3521 .63007 L p .707 .577 .707 r
F P
0 g
s
.38127 .63616 m .37706 .67333 L .40869 .67742 L p .707 .577 .707 r
F P
0 g
s
.65599 .66679 m .65764 .63144 L .67867 .62283 L p .707 .577 .707 r
F P
0 g
s
.4733 .55411 m .47674 .60924 L .49555 .60068 L p .707 .577 .707 r
F P
0 g
s
.49555 .60068 m .49211 .54555 L .4733 .55411 L p .707 .577 .707 r
F P
0 g
s
.32906 .56228 m .3325 .6174 L .35828 .62139 L p .707 .577 .707 r
F P
0 g
s
.65601 .67404 m .65391 .68957 L .64055 .70529 L p .707 .577 .707 r
F P
0 g
s
.3325 .6174 m .32906 .56228 L .31035 .55584 L p .707 .577 .707 r
F P
0 g
s
.81426 .55916 m .81568 .61562 L .78985 .61239 L p .707 .577 .707 r
F P
0 g
s
.78985 .61239 m .78843 .55593 L .81426 .55916 L p .707 .577 .707 r
F P
0 g
s
.44391 .64193 m .4397 .6791 L .46704 .67822 L p .707 .577 .707 r
F P
0 g
s
.46704 .67822 m .47125 .64105 L .44391 .64193 L p .707 .577 .707 r
F P
0 g
s
.67123 .61906 m .66981 .5626 L .69569 .55814 L p .707 .577 .707 r
F P
0 g
s
.3521 .63007 m .34789 .66725 L .37706 .67333 L p .707 .577 .707 r
F P
0 g
s
.39389 .71496 m .39924 .69681 L .36884 .68731 L p .707 .577 .707 r
F P
0 g
s
.39924 .69681 m .39389 .71496 L .42414 .72255 L p .707 .577 .707 r
F P
0 g
s
.42414 .72255 m .42949 .7044 L .39924 .69681 L p .707 .577 .707 r
F P
0 g
s
.8357 .70276 m .8336 .71829 L .81812 .70063 L p .707 .577 .707 r
F P
0 g
s
.81812 .70063 m .82022 .6851 L .8357 .70276 L p .707 .577 .707 r
F P
0 g
s
.34789 .66725 m .3521 .63007 L .32825 .62258 L p .707 .577 .707 r
F P
0 g
s
.36349 .70546 m .36884 .68731 L .34129 .67684 L p .707 .577 .707 r
F P
0 g
s
.36884 .68731 m .36349 .70546 L .39389 .71496 L p .707 .577 .707 r
F P
0 g
s
.82244 .63362 m .82079 .66897 L .79676 .65976 L p .707 .577 .707 r
F P
0 g
s
.79676 .65976 m .7984 .62441 L .82244 .63362 L p .707 .577 .707 r
F P
0 g
s
.67867 .62283 m .67702 .65818 L .65599 .66679 L p .707 .577 .707 r
F P
0 g
s
.34129 .67684 m .33595 .69499 L .36349 .70546 L p .707 .577 .707 r
F P
0 g
s
.42949 .7044 m .42414 .72255 L .45131 .7275 L p .707 .577 .707 r
F P
0 g
s
.45131 .7275 m .45666 .70935 L .42949 .7044 L p .707 .577 .707 r
F P
0 g
s
.65391 .68957 m .65601 .67404 L .67762 .66231 L p .707 .577 .707 r
F P
0 g
s
.69569 .55814 m .69711 .6146 L .67123 .61906 L p .707 .577 .707 r
F P
0 g
s
.32825 .62258 m .32404 .65975 L .34789 .66725 L p .707 .577 .707 r
F P
0 g
s
.31035 .55584 m .3138 .61096 L .3325 .6174 L p .707 .577 .707 r
F P
0 g
s
.47125 .64105 m .46704 .67822 L .48804 .67485 L p .707 .577 .707 r
F P
0 g
s
.48804 .67485 m .49225 .63768 L .47125 .64105 L p .707 .577 .707 r
F P
0 g
s
.67702 .65818 m .67867 .62283 L .7061 .61748 L p .707 .577 .707 r
F P
0 g
s
.78843 .55593 m .78985 .61239 L .75947 .61109 L p .707 .577 .707 r
F P
0 g
s
.75947 .61109 m .75805 .55463 L .78843 .55593 L p .707 .577 .707 r
F P
0 g
s
.69711 .6146 m .69569 .55814 L .7261 .55539 L p .707 .577 .707 r
F P
0 g
s
.33595 .69499 m .34129 .67684 L .31928 .66642 L p .707 .577 .707 r
F P
0 g
s
.49211 .54555 m .49555 .60068 L .50547 .59131 L p .707 .577 .707 r
F P
0 g
s
.50547 .59131 m .50203 .53618 L .49211 .54555 L p .707 .577 .707 r
F P
0 g
s
.31928 .66642 m .31394 .68457 L .33595 .69499 L p .707 .577 .707 r
F P
0 g
s
.67762 .66231 m .67552 .67784 L .65391 .68957 L p .707 .577 .707 r
F P
0 g
s
.3138 .61096 m .31035 .55584 L .30056 .54758 L p .707 .577 .707 r
F P
0 g
s
.32404 .65975 m .32825 .62258 L .31206 .61441 L p .707 .577 .707 r
F P
0 g
s
.7984 .62441 m .79676 .65976 L .7674 .65366 L p .707 .577 .707 r
F P
0 g
s
.7674 .65366 m .76904 .61832 L .7984 .62441 L p .707 .577 .707 r
F P
0 g
s
.45666 .70935 m .45131 .7275 L .47272 .72931 L p .707 .577 .707 r
F P
0 g
s
.47272 .72931 m .47807 .71116 L .45666 .70935 L p .707 .577 .707 r
F P
0 g
s
.82022 .6851 m .81812 .70063 L .79483 .68587 L p .707 .577 .707 r
F P
0 g
s
.79483 .68587 m .79693 .67034 L .82022 .6851 L p .707 .577 .707 r
F P
0 g
s
.75805 .55463 m .75947 .61109 L .72751 .61185 L p .707 .577 .707 r
F P
0 g
s
.72751 .61185 m .7261 .55539 L .75805 .55463 L p .707 .577 .707 r
F P
0 g
s
.7261 .55539 m .72751 .61185 L .69711 .6146 L p .707 .577 .707 r
F P
0 g
s
.7061 .61748 m .70445 .65283 L .67702 .65818 L p .707 .577 .707 r
F P
0 g
s
.67552 .67784 m .67762 .66231 L .70537 .65571 L p .707 .577 .707 r
F P
0 g
s
.70445 .65283 m .7061 .61748 L .73724 .61593 L p .707 .577 .707 r
F P
0 g
s
.31206 .61441 m .30785 .65158 L .32404 .65975 L p .707 .577 .707 r
F P
0 g
s
.76904 .61832 m .7674 .65366 L .73559 .65127 L p .707 .577 .707 r
F P
0 g
s
.73559 .65127 m .73724 .61593 L .76904 .61832 L p .707 .577 .707 r
F P
0 g
s
.73724 .61593 m .73559 .65127 L .70445 .65283 L p .707 .577 .707 r
F P
0 g
s
.31394 .68457 m .31928 .66642 L .30497 .65707 L p .707 .577 .707 r
F P
0 g
s
.49225 .63768 m .48804 .67485 L .50064 .66934 L p .707 .577 .707 r
F P
0 g
s
.50064 .66934 m .50485 .63216 L .49225 .63768 L p .707 .577 .707 r
F P
0 g
s
.30056 .54758 m .304 .60271 L .3138 .61096 L p .707 .577 .707 r
F P
0 g
s
.70537 .65571 m .70327 .67124 L .67552 .67784 L p .707 .577 .707 r
F P
0 g
s
.30497 .65707 m .29962 .67522 L .31394 .68457 L p .707 .577 .707 r
F P
0 g
s
.79693 .67034 m .79483 .68587 L .766 .67546 L p .707 .577 .707 r
F P
0 g
s
.766 .67546 m .7681 .65993 L .79693 .67034 L p .707 .577 .707 r
F P
0 g
s
.70327 .67124 m .70537 .65571 L .73655 .65489 L p .707 .577 .707 r
F P
0 g
s
.50203 .53618 m .50547 .59131 L .50553 .58204 L p .707 .577 .707 r
F P
0 g
s
.50553 .58204 m .50209 .52691 L .50203 .53618 L p .707 .577 .707 r
F P
0 g
s
.47807 .71116 m .47272 .72931 L .48628 .72782 L p .707 .577 .707 r
F P
0 g
s
.48628 .72782 m .49163 .70967 L .47807 .71116 L p .707 .577 .707 r
F P
0 g
s
.30785 .65158 m .31206 .61441 L .3051 .60637 L p .707 .577 .707 r
F P
0 g
s
.7681 .65993 m .766 .67546 L .73445 .67042 L p .707 .577 .707 r
F P
0 g
s
.73445 .67042 m .73655 .65489 L .7681 .65993 L p .707 .577 .707 r
F P
0 g
s
.73655 .65489 m .73445 .67042 L .70327 .67124 L p .707 .577 .707 r
F P
0 g
s
.304 .60271 m .30056 .54758 L .30062 .53832 L p .707 .577 .707 r
F P
0 g
s
.3051 .60637 m .30089 .64354 L .30785 .65158 L p .707 .577 .707 r
F P
0 g
s
.29962 .67522 m .30497 .65707 L .29975 .64971 L p .707 .577 .707 r
F P
0 g
s
.50485 .63216 m .50064 .66934 L .50361 .66221 L p .707 .577 .707 r
F P
0 g
s
.50361 .66221 m .50782 .62503 L .50485 .63216 L p .707 .577 .707 r
F P
0 g
s
.29975 .64971 m .2944 .66786 L .29962 .67522 L p .707 .577 .707 r
F P
0 g
s
.30062 .53832 m .30406 .59344 L .304 .60271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49163 .70967 m .48628 .72782 L .49066 .72316 L p .707 .577 .707 r
F P
0 g
s
.49066 .72316 m .49601 .70501 L .49163 .70967 L p .707 .577 .707 r
F P
0 g
s
.50209 .52691 m .50553 .58204 L .49573 .57378 L p .707 .577 .707 r
F P
0 g
s
.49573 .57378 m .49229 .51866 L .50209 .52691 L p .707 .577 .707 r
F P
0 g
s
.30089 .64354 m .3051 .60637 L .30807 .59924 L p .707 .577 .707 r
F P
0 g
s
.30406 .59344 m .30062 .53832 L .31054 .52894 L p .707 .577 .707 r
F P
0 g
s
.30807 .59924 m .30386 .63641 L .30089 .64354 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2944 .66786 m .29975 .64971 L .30413 .64505 L p .707 .577 .707 r
F P
0 g
s
.50782 .62503 m .50361 .66221 L .49665 .65416 L p .707 .577 .707 r
F P
0 g
s
.49665 .65416 m .50086 .61699 L .50782 .62503 L p .707 .577 .707 r
F P
0 g
s
.30413 .64505 m .29878 .6632 L .2944 .66786 L p .707 .577 .707 r
F P
0 g
s
.31054 .52894 m .31398 .58407 L .30406 .59344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49229 .51866 m .49573 .57378 L .47703 .56735 L p .707 .577 .707 r
F P
0 g
s
.47703 .56735 m .47359 .51222 L .49229 .51866 L p .707 .577 .707 r
F P
0 g
s
.49601 .70501 m .49066 .72316 L .48544 .7158 L p .707 .577 .707 r
F P
0 g
s
.48544 .7158 m .49079 .69765 L .49601 .70501 L p .707 .577 .707 r
F P
0 g
s
.30386 .63641 m .30807 .59924 L .32067 .59372 L p .707 .577 .707 r
F P
0 g
s
.31398 .58407 m .31054 .52894 L .32935 .52038 L p .707 .577 .707 r
F P
0 g
s
.32067 .59372 m .31646 .63089 L .30386 .63641 L p .707 .577 .707 r
F P
0 g
s
.29878 .6632 m .30413 .64505 L .31769 .64356 L p .707 .577 .707 r
F P
0 g
s
.32935 .52038 m .33279 .57551 L .31398 .58407 L p .707 .577 .707 r
F P
0 g
s
.50086 .61699 m .49665 .65416 L .48046 .646 L p .707 .577 .707 r
F P
0 g
s
.48046 .646 m .48467 .60882 L .50086 .61699 L p .707 .577 .707 r
F P
0 g
s
.31769 .64356 m .31234 .66171 L .29878 .6632 L p .707 .577 .707 r
F P
0 g
s
.47359 .51222 m .47703 .56735 L .45125 .56336 L p .707 .577 .707 r
F P
0 g
s
.45125 .56336 m .44781 .50824 L .47359 .51222 L p .707 .577 .707 r
F P
0 g
s
.33279 .57551 m .32935 .52038 L .3552 .51348 L p .707 .577 .707 r
F P
0 g
s
.49079 .69765 m .48544 .7158 L .47113 .70645 L p .707 .577 .707 r
F P
0 g
s
.47113 .70645 m .47647 .6883 L .49079 .69765 L p .707 .577 .707 r
F P
0 g
s
.31646 .63089 m .32067 .59372 L .34167 .59035 L p .707 .577 .707 r
F P
0 g
s
.34167 .59035 m .33746 .62753 L .31646 .63089 L p .707 .577 .707 r
F P
0 g
s
.44781 .50824 m .45125 .56336 L .42092 .56221 L p .707 .577 .707 r
F P
0 g
s
.42092 .56221 m .41748 .50709 L .44781 .50824 L p .707 .577 .707 r
F P
0 g
s
.3552 .51348 m .35865 .5686 L .33279 .57551 L p .707 .577 .707 r
F P
0 g
s
.35865 .5686 m .3552 .51348 L .38557 .50889 L p .707 .577 .707 r
F P
0 g
s
.48467 .60882 m .48046 .646 L .45661 .6385 L p .707 .577 .707 r
F P
0 g
s
.45661 .6385 m .46082 .60133 L .48467 .60882 L p .707 .577 .707 r
F P
0 g
s
.31234 .66171 m .31769 .64356 L .3391 .64538 L p .707 .577 .707 r
F P
0 g
s
.3391 .64538 m .33375 .66353 L .31234 .66171 L p .707 .577 .707 r
F P
0 g
s
.41748 .50709 m .42092 .56221 L .38901 .56402 L p .707 .577 .707 r
F P
0 g
s
.38901 .56402 m .38557 .50889 L .41748 .50709 L p .707 .577 .707 r
F P
0 g
s
.38557 .50889 m .38901 .56402 L .35865 .5686 L p .707 .577 .707 r
F P
0 g
s
.33746 .62753 m .34167 .59035 L .36901 .58947 L p .707 .577 .707 r
F P
0 g
s
.47647 .6883 m .47113 .70645 L .44912 .69603 L p .707 .577 .707 r
F P
0 g
s
.44912 .69603 m .45446 .67788 L .47647 .6883 L p .707 .577 .707 r
F P
0 g
s
.36901 .58947 m .3648 .62664 L .33746 .62753 L p .707 .577 .707 r
F P
0 g
s
.46082 .60133 m .45661 .6385 L .42744 .63241 L p .707 .577 .707 r
F P
0 g
s
.42744 .63241 m .43165 .59524 L .46082 .60133 L p .707 .577 .707 r
F P
0 g
s
.33375 .66353 m .3391 .64538 L .36627 .65032 L p .707 .577 .707 r
F P
0 g
s
.3648 .62664 m .36901 .58947 L .40002 .59115 L p .707 .577 .707 r
F P
0 g
s
.36627 .65032 m .36092 .66847 L .33375 .66353 L p .707 .577 .707 r
F P
0 g
s
.43165 .59524 m .42744 .63241 L .39581 .62833 L p .707 .577 .707 r
F P
0 g
s
.39581 .62833 m .40002 .59115 L .43165 .59524 L p .707 .577 .707 r
F P
0 g
s
.45446 .67788 m .44912 .69603 L .42157 .68556 L p .707 .577 .707 r
F P
0 g
s
.42157 .68556 m .42692 .66741 L .45446 .67788 L p .707 .577 .707 r
F P
0 g
s
.40002 .59115 m .39581 .62833 L .3648 .62664 L p .707 .577 .707 r
F P
0 g
s
.36092 .66847 m .36627 .65032 L .39652 .65791 L p .707 .577 .707 r
F P
0 g
s
.39652 .65791 m .39117 .67606 L .36092 .66847 L p .707 .577 .707 r
F P
0 g
s
.42692 .66741 m .42157 .68556 L .39117 .67606 L p .707 .577 .707 r
F P
0 g
s
.39117 .67606 m .39652 .65791 L .42692 .66741 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1@00L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JGoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomo
o`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Moo`00IGoo0P00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20004FUHH000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00Hgoo10001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005moo`@00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo
001LOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJ
EP00IGoo001JOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00F7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Moo`80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUIJEP00IGoo001FOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001EOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001U
Ool005Eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP004Woo4P00@Goo001EOol01000FUIJEP001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEUYF000<Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol005Eoo`05001JEUYF
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00@005YFFUH000Qoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH6000cOol005Eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0000
0eYF000000060003FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH000Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0031oo`00EGoo0P000UYF00<005YFFUH00UYF
00<005YFFUH00eYF3`000eYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEUYF001oo`030002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000^Ool005Eoo`80009JEP03001JEUYF009JEP03001JEP0000@000QJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP00;Goo001EOol20002FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00;Goo001FOol01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10002UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF00@005YFFUH002eoo`00EWoo00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEUYF000]Ool005Ioo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002eoo`00EWoo10000eYF00<005YF00003P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF000]Ool005Ioo`05001JEUYF001JEP040002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH:
0009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002eoo`00>goo5`0017oo00<005YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF0000;Goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040006
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool003=oo`@000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0002eoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF0000;Goo000_Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH0000]Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJ
EPh000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP0002eoo`00;Goo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF
FUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP0500000eYF0000000C0004FUH01000FUIJ
EUYF1P000eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00D0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF00@00003
FUH007oo02aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30002FUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH3000]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0002FUH01000FUIJEUYF600015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000`000UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF0000
05YF0005FUH00`00FUH0000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF000000040005FUH50004FUH00`00FUH00004
0002FUH60006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<005YF0000;Goo000/
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH015YF00@005YFFUIJEP/0009JEP03001JEUYF00=JEP@0009JEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP03001JEP00009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEUYF00MJEP@000EJEP03001JEUYF
009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01`00FUH0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEPH002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00<00003FUH0000001800003FUH005YF00=JEP04001JEUYF0009FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF3`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@0005FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEUYF0004FUH01000FUIJEUYF2000
27oo0`001Goo100000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF00AJEQD000IJEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00;7oo00@005YFFUH000AJ
EPH000eoo`D000Qoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEUYF001JEP002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF01<000Ioo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00;7oo00@0
05YFFUH0009JEP<000EJEPH000Moo`D000Ioo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP02FUH800000eYF001JEP07FUH00`00FUIJEP02FUH60004Ool40005FUH00`00FUIJEP02FUH00`00
FUH0000/Ool002aoo`03001JEUYF00<0009JEP03001JEUYF00EJEP04001JEUYFFUHB00000eYF0000
000;0007FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF00000P0000AJEP00000000AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00
0006Ool20003FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEP0000AJ
EP800004FUH005YFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF00000eYF0P000UYF0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
FUIJEP<000Eoo`800003FUH005YF009JEP04001JEUYF000/Ool002aoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH01000FUH00000
15YF00<005YF000010001UYF00<005YFFUH01eYF00<005YF00000P001UYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF
00<005YFFUH00P000UYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0P001Goo0P000eYF00@0
05YFFUH002aoo`00;7oo0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP80009JEP800003FUH00000009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH6000<FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000004FUH00`00FUH000040009
Ool70002FUH00`00FUIJEP06FUH30005Ool01000FUIJEP000UYF00<007ooOol0:Woo000/Ool01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000IJEP<00004FUH000000005FUH50007FUH00`00FUIJEP05FUH80005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF0P00
0UYF00<005YF00002Goo1@000Woo10001eYF00<005YFFUH00P0017oo0`0000=JEP00Ool0;7oo000/
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0000=JEP00FUH01UYF00<005YF00000`001EYF00<005YFFUH01P000UYF00<005YFFUH01eYF
0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00L005YF
001JEP00FUH00003FUH20004FUH00`00FUH0000:Ool30007Ool20004FUH00`00FUIJEP03FUH20003
Ool200000eYF001oo`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YF
000010000UYF10001eYF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEP00FUH20002FUH200000eYF00000002000015YF001JEP00
5Woo0`0000=JEP00FUH01UYF1@0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP<0009JEP03001JEP0000@0009JEP04001JEUYFFUH20005FUH00`00FUIJEP03FUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUH00000
FUH00`0000=JEP00FUH015YF10006Goo0P001eYF0P0000=JEP00FUH00P00;Goo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHL00000eYF001JEP07FUH00`00FUH0000200000eYF
000000030002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YF00000`0067oo0P001EYF00D005YF000005YF008002eoo`00;Woo0P0015YF00<005YFFUH0
0eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000MJEP03001JEUYF009J
EPD000=JEP03001JEUYF00IJEP8000IJEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH70009Ool900000eYF00000002FUH00`00FUIJEP020002FUH00`00Oomoo`0[Ool002mo
o`8000=JEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000004FUH00`00FUIJEP06FUH400000eYF001JEP09FUH20004FUH00`00FUIJEP02FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH30003
FUH01000FUIJEP00;Goo000`Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH0
10002EYF0`0000=JEP00FUH015YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YF0000;Goo000^Ool30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP@000MJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJEP04001JEP00000<FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80009JEP8000EJEP03001JEUYF
00MJEP04001JEUYFFUH60002FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH01P000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH00UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0002ioo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH20005FUH00`00FUH000030007FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01`00FUH005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEPL0
0003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH007oo02eoo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000P000UYF
1`0000=JEP00FUH01UYF00<005YFFUH00UYF1@0025YF00<005YFFUH01EYF00@005YFFUIJEP800005
Ool005YFFUH0000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001J
EUYF00IJEPL000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH000040006FUH00`00
FUIJEP02FUH50008FUH00`00FUIJEP05FUH01000FUH000000goo00@005YFFUH002eoo`00:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH015YF1`00
0eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YFFUH00P001EYF00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF009J
EPD000QJEP03001JEUYF009JEPD000Ioo`03001JEP0002eoo`00:goo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YF00001@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF0P0000=JEP0000001UYF00@005YFFUIJEP<000=oo`L00003FUH0
0000008000AJEPT000]oo`<002eoo`00;7oo00EJEP00FUIJEP0000EJEP03001JEUYF009JEPP000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800004
FUH005YF0005FUH01`00FUIJEUYF001JEP0000Yoo`T001Eoo`03001oogoo02aoo`00;7oo00EJEP00
FUIJEP0000=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0002Qoo`03001oogoo02aoo`00;7oo00=JEP00FUH01@001EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF009JEP07
001JEUYFFUH005YF0000:7oo00<007ooOol0;7oo000/Ool00eYF00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00004FUH01@00FUIJEUYF00000eYF
00<005YF00009goo0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@0000=oo`0000001EYF
00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001EYF00<005YFFUH01eYF
00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP04001JEUYFFUH2000VOol2000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70006Ool20005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP030003
FUH2000UOol00`00FUH0000_Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ<0009oo`8000EJEP03001JEUYF009JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP@000EJEP03001JEUYF009JEP08001J
EUYF001oo`00FUH000AJEP80009JEP03001JEP0002=oo`04001JEUYF000_Ool0031oobP000=JEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH400000eYF001JEP03FUH01000FUIJ
EP000Woo0P001UYF0`0000=JEP00Ool087oo0`0000=JEP00Ool0;goo0016Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP050006FUH0
0`00FUH00002000POol00`00FUIJEP02000aOol003ioo`P000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D00004FUH000000003FUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00
0eYF0`0015YF00@005YFFUIJEP<001aoo`80009JEP03001JEP00035oo`00=goo1`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEPD000=JEP04001JEUYFFUH300000eYF00000003FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH01@00FUIJEUYF00000UYF00@005YFFUH000MJEP@001Io
o`8000AJEP80039oo`00<Goo1P000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
100000=JEP00FUH01EYF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00<000QJEP03001JEUYF00@000ioo`@00003FUH005YF00=JEP03001o
ogoo035oo`00;Woo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00001P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF000015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF3P0015YF00@005YFFUIJ
EP8003Aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH04@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP0000001@000eYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000003Ioo`00;7oo40000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP02FUH800000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000hOol0
02aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH40003Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP03FUH200000goo000000070004FUH00`00FUIJEP06FUH00`00
FUIJEP04000kOol002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEPL000Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8000EJEP03001JEUYF00=JEP05001oogoo001JEP020005Ool@000oOol002eoo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH20003Ool01000FUIJEP00
E7oo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000IOol00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00@005YF000000Aoo`80009JEP03001o
ogoo059oo`00;Goo0`000UYF00@005YFFUIJEPl002=oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP001UYF0`0017oo0P000UYF00<005YF0000E7oo000`Ool6000dOol200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP040006Ool00`00FUIJEP02FUH2001EOol006aoo`@000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP<0009JEPD000Qo
o`<000EJEP03001oogoo05=oo`00L7oo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH0100000=JEP0000000P0037oo00D005YFFUIJEP0000=J
EP03001oogoo05Aoo`00M7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
2P003Woo0P0015YF00@005YFFUH005Moo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01P001Goo1@003Goo00<005YFFUH01EYF0P00F7oo001oOolO000;Ool5000;Ool30007
FUH00`00Oomoo`1GOol0091oo`03001JEUYF009JEP03001oogoo019oo`<000Yoo`8000=JEP03001J
EUYF009JEP8005Yoo`00Sgoo00<005YF00000UYF00<007ooOol07Woo0P001EYF00D005YFFUIJEP00
05aoo`00Sgoo00D005YF001JEP0001moo`8000QJEP<005eoo`00Sgoo00<005YFFUH00P0077oo0`00
00=JEP00FUH01eYF00<007ooOol0GGoo002?Ool01000FUIJEP006Woo0`0015YF00<005YFFUH015YF
0P00H7oo002@Ool00eYF001oo`0FOol40008FUH01000FUIJEUYF0P00HWoo002@Ool00eYF0000000B
Ool40002FUH00`00FUIJEP07FUH01000FUH00000I7oo002@Ool200000eYF0000000@0007FUH00`00
FUIJEP05FUH3001VOol0095oo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001YOol0095oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008006]oo`00TWoo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
06ioo`00Tgoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01000LWoo002EOolB001f
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57907 .74689 m .58251 .69108 L .55219 .68687 L p .707 .577 .707 r
F P
0 g
s
.58251 .69108 m .57907 .74689 L .61098 .74876 L p .707 .577 .707 r
F P
0 g
s
.61098 .74876 m .61442 .69294 L .58251 .69108 L p .707 .577 .707 r
F P
0 g
s
.61442 .69294 m .61098 .74876 L .64135 .74809 L p .707 .577 .707 r
F P
0 g
s
.64135 .74809 m .64479 .69228 L .61442 .69294 L p .707 .577 .707 r
F P
0 g
s
.54874 .74269 m .55219 .68687 L .52641 .68073 L p .707 .577 .707 r
F P
0 g
s
.55219 .68687 m .54874 .74269 L .57907 .74689 L p .707 .577 .707 r
F P
0 g
s
.64479 .69228 m .64135 .74809 L .6672 .74497 L p .707 .577 .707 r
F P
0 g
s
.6672 .74497 m .67065 .68915 L .64479 .69228 L p .707 .577 .707 r
F P
0 g
s
.60419 .81318 m .59998 .77674 L .56834 .77916 L p .707 .577 .707 r
F P
0 g
s
.59998 .77674 m .60419 .81318 L .6352 .80782 L p .707 .577 .707 r
F P
0 g
s
.6352 .80782 m .63099 .77137 L .59998 .77674 L p .707 .577 .707 r
F P
0 g
s
.52641 .68073 m .52297 .73655 L .54874 .74269 L p .707 .577 .707 r
F P
0 g
s
.57255 .8156 m .56834 .77916 L .53917 .77839 L p .707 .577 .707 r
F P
0 g
s
.56834 .77916 m .57255 .8156 L .60419 .81318 L p .707 .577 .707 r
F P
0 g
s
.63099 .77137 m .6352 .80782 L .66253 .80002 L p .707 .577 .707 r
F P
0 g
s
.66253 .80002 m .65832 .76358 L .63099 .77137 L p .707 .577 .707 r
F P
0 g
s
.52297 .73655 m .52641 .68073 L .5077 .67326 L p .707 .577 .707 r
F P
0 g
s
.67065 .68915 m .6672 .74497 L .68601 .73969 L p .707 .577 .707 r
F P
0 g
s
.68601 .73969 m .68945 .68387 L .67065 .68915 L p .707 .577 .707 r
F P
0 g
s
.53917 .77839 m .54338 .81483 L .57255 .8156 L p .707 .577 .707 r
F P
0 g
s
.54338 .81483 m .53917 .77839 L .51533 .7745 L p .707 .577 .707 r
F P
0 g
s
.65832 .76358 m .66253 .80002 L .68353 .79056 L p .707 .577 .707 r
F P
0 g
s
.68353 .79056 m .67932 .75412 L .65832 .76358 L p .707 .577 .707 r
F P
0 g
s
.5077 .67326 m .50426 .72907 L .52297 .73655 L p .707 .577 .707 r
F P
0 g
s
.60882 .85872 m .60347 .8414 L .57308 .84806 L p .707 .577 .707 r
F P
0 g
s
.60347 .8414 m .60882 .85872 L .63908 .84861 L p .707 .577 .707 r
F P
0 g
s
.63908 .84861 m .63373 .83129 L .60347 .8414 L p .707 .577 .707 r
F P
0 g
s
.63373 .83129 m .63908 .84861 L .66624 .83605 L p .707 .577 .707 r
F P
0 g
s
.66624 .83605 m .6609 .81873 L .63373 .83129 L p .707 .577 .707 r
F P
0 g
s
.57308 .84806 m .57843 .86538 L .60882 .85872 L p .707 .577 .707 r
F P
0 g
s
.51533 .7745 m .51954 .81095 L .54338 .81483 L p .707 .577 .707 r
F P
0 g
s
.57843 .86538 m .57308 .84806 L .54553 .85062 L p .707 .577 .707 r
F P
0 g
s
.50426 .72907 m .5077 .67326 L .4979 .66518 L p .707 .577 .707 r
F P
0 g
s
.68945 .68387 m .68601 .73969 L .69594 .73276 L p .707 .577 .707 r
F P
0 g
s
.69594 .73276 m .69938 .67695 L .68945 .68387 L p .707 .577 .707 r
F P
0 g
s
.6609 .81873 m .66624 .83605 L .68765 .82226 L p .707 .577 .707 r
F P
0 g
s
.68765 .82226 m .68231 .80494 L .6609 .81873 L p .707 .577 .707 r
F P
0 g
s
.54553 .85062 m .55088 .86794 L .57843 .86538 L p .707 .577 .707 r
F P
0 g
s
.51954 .81095 m .51533 .7745 L .49913 .76789 L p .707 .577 .707 r
F P
0 g
s
.67932 .75412 m .68353 .79056 L .69613 .78037 L p .707 .577 .707 r
F P
0 g
s
.69613 .78037 m .69192 .74392 L .67932 .75412 L p .707 .577 .707 r
F P
0 g
s
.4979 .66518 m .49446 .721 L .50426 .72907 L p .707 .577 .707 r
F P
0 g
s
.55088 .86794 m .54553 .85062 L .52352 .84883 L p .707 .577 .707 r
F P
0 g
s
.49913 .76789 m .50334 .80433 L .51954 .81095 L p .707 .577 .707 r
F P
0 g
s
.52352 .84883 m .52887 .86615 L .55088 .86794 L p .707 .577 .707 r
F P
0 g
s
.68231 .80494 m .68765 .82226 L .70122 .80859 L p .707 .577 .707 r
F P
0 g
s
.70122 .80859 m .69587 .79128 L .68231 .80494 L p .707 .577 .707 r
F P
0 g
s
.49446 .721 m .4979 .66518 L .49797 .6573 L p .708 .578 .707 r
F P
0 g
s
.69938 .67695 m .69594 .73276 L .696 .72488 L p .708 .578 .707 r
F P
0 g
s
.696 .72488 m .69944 .66907 L .69938 .67695 L p .708 .578 .707 r
F P
0 g
s
.50334 .80433 m .49913 .76789 L .49218 .75919 L p .707 .577 .707 r
F P
0 g
s
.52887 .86615 m .52352 .84883 L .50921 .84287 L p .707 .577 .707 r
F P
0 g
s
.69236 .7477 m .69613 .78037 L .69843 .77269 L p .707 .577 .707 r
F P
0 g
s
.7056 .79639 m .70025 .77907 L .69587 .79128 L p .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69503 .76952 L .69975 .77816 L p .707 .577 .707 r
F P
0 g
s
.69975 .77816 m .70025 .77907 L p .70027 .78029 L .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69975 .77816 L .70027 .78029 L .707 .577 .707 r
F
.69192 .74392 m .69236 .7477 L p .6991 .77043 L F P
0 g
s
.69843 .77269 m .6991 .77043 L p .69236 .7477 L .707 .577 .707 r
F P
0 g
s
.6991 .77043 m .69489 .73399 L .69192 .74392 L p .707 .577 .707 r
F P
0 g
s
.49797 .6573 m .49453 .71312 L .49446 .721 L p .708 .578 .707 r
F P
0 g
s
.50921 .84287 m .51456 .86019 L .52887 .86615 L p .707 .577 .707 r
F P
0 g
s
.49218 .75919 m .49639 .79563 L .50334 .80433 L p .707 .577 .707 r
F P
0 g
s
.69587 .79128 m .70122 .80859 L .7056 .79639 L p .707 .577 .707 r
F P
0 g
s
.49453 .71312 m .49797 .6573 L .50789 .65038 L p .707 .577 .707 r
F P
0 g
s
.50789 .65038 m .50445 .7062 L .49453 .71312 L p .707 .577 .707 r
F P
0 g
s
.49515 .74925 m .49936 .7857 L .49639 .79563 L p .707 .577 .707 r
F P
0 g
s
.49936 .7857 m .49515 .74925 L .50775 .73906 L p .707 .577 .707 r
F P
0 g
s
.50775 .73906 m .51196 .7755 L .49936 .7857 L p .707 .577 .707 r
F P
0 g
s
.50166 .82192 m .50166 .32003 L .45701 .31828 L p .707 .577 .707 r
F P
0 g
s
.50445 .7062 m .50789 .65038 L .5267 .6451 L p .707 .577 .707 r
F P
0 g
s
.51456 .86019 m .50921 .84287 L .50398 .83332 L p .707 .577 .707 r
F P
0 g
s
.50398 .83332 m .50933 .85064 L .51456 .86019 L p .707 .577 .707 r
F P
0 g
s
.50933 .85064 m .50398 .83332 L .50837 .82112 L p .707 .577 .707 r
F P
0 g
s
.50837 .82112 m .51372 .83844 L .50933 .85064 L p .707 .577 .707 r
F P
0 g
s
.5267 .6451 m .52326 .70091 L .50445 .7062 L p .707 .577 .707 r
F P
0 g
s
.52326 .70091 m .5267 .6451 L .55255 .64197 L p .707 .577 .707 r
F P
0 g
s
.51196 .7755 m .50775 .73906 L .52875 .7296 L p .707 .577 .707 r
F P
0 g
s
.51372 .83844 m .50837 .82112 L .52193 .80745 L p .707 .577 .707 r
F P
0 g
s
.55255 .64197 m .54911 .69779 L .52326 .70091 L p .707 .577 .707 r
F P
0 g
s
.52193 .80745 m .52728 .82477 L .51372 .83844 L p .707 .577 .707 r
F P
0 g
s
.52875 .7296 m .53296 .76604 L .51196 .7755 L p .707 .577 .707 r
F P
0 g
s
.53296 .76604 m .52875 .7296 L .55609 .7218 L p .707 .577 .707 r
F P
0 g
s
.52728 .82477 m .52193 .80745 L .54334 .79366 L p .707 .577 .707 r
F P
0 g
s
.55609 .7218 m .5603 .75825 L .53296 .76604 L p .707 .577 .707 r
F P
0 g
s
.54334 .79366 m .54869 .81098 L .52728 .82477 L p .707 .577 .707 r
F P
0 g
s
.54869 .81098 m .54334 .79366 L .5705 .7811 L p .707 .577 .707 r
F P
0 g
s
.50166 .32003 m .50166 .82192 L .54615 .81989 L p .707 .577 .707 r
F P
0 g
s
.54615 .81989 m .54615 .318 L .50166 .32003 L p .707 .577 .707 r
F P
0 g
s
.45701 .82016 m .45701 .31828 L .41657 .3129 L p .707 .577 .707 r
F P
0 g
s
.49639 .79563 m .49218 .75919 L .49515 .74925 L p .707 .577 .707 r
F P
0 g
s
.45701 .31828 m .45701 .82016 L .50166 .82192 L p .707 .577 .707 r
F P
0 g
s
.54911 .69779 m .55255 .64197 L .58292 .64131 L p .707 .577 .707 r
F P
0 g
s
.58292 .64131 m .57948 .69712 L .54911 .69779 L p .707 .577 .707 r
F P
0 g
s
.5603 .75825 m .55609 .7218 L .58709 .71643 L p .707 .577 .707 r
F P
0 g
s
.58709 .71643 m .5913 .75288 L .5603 .75825 L p .707 .577 .707 r
F P
0 g
s
.5705 .7811 m .57585 .79842 L .54869 .81098 L p .707 .577 .707 r
F P
0 g
s
.57585 .79842 m .5705 .7811 L .60076 .77099 L p .707 .577 .707 r
F P
0 g
s
.60076 .77099 m .60611 .78831 L .57585 .79842 L p .707 .577 .707 r
F P
0 g
s
.54615 .318 m .54615 .81989 L .58612 .81427 L p .707 .577 .707 r
F P
0 g
s
.57948 .69712 m .58292 .64131 L .61483 .64317 L p .707 .577 .707 r
F P
0 g
s
.61483 .64317 m .61139 .69899 L .57948 .69712 L p .707 .577 .707 r
F P
0 g
s
.58612 .81427 m .58612 .31238 L .54615 .318 L p .707 .577 .707 r
F P
0 g
s
.69944 .66907 m .696 .72488 L .6862 .71681 L p .707 .577 .707 r
F P
0 g
s
.6862 .71681 m .68964 .66099 L .69944 .66907 L p .707 .577 .707 r
F P
0 g
s
.69489 .73399 m .6991 .77043 L .69215 .76173 L p .707 .577 .707 r
F P
0 g
s
.69215 .76173 m .68794 .72529 L .69489 .73399 L p .707 .577 .707 r
F P
0 g
s
.41657 .81479 m .41657 .3129 L .38429 .30444 L p .707 .577 .707 r
F P
0 g
s
.41657 .3129 m .41657 .81479 L .45701 .82016 L p .707 .577 .707 r
F P
0 g
s
.70025 .77907 m .7056 .79639 L .70038 .78684 L p .707 .577 .707 r
F P
0 g
s
.61873 .71402 m .62294 .75046 L .5913 .75288 L p .707 .577 .707 r
F P
0 g
s
.5913 .75288 m .58709 .71643 L .61873 .71402 L p .707 .577 .707 r
F P
0 g
s
.63115 .76434 m .6365 .78165 L .60611 .78831 L p .707 .577 .707 r
F P
0 g
s
.60611 .78831 m .60076 .77099 L .63115 .76434 L p .707 .577 .707 r
F P
0 g
s
.58612 .31238 m .58612 .81427 L .61767 .80561 L p .707 .577 .707 r
F P
0 g
s
.64516 .64738 m .64172 .7032 L .61139 .69899 L p .707 .577 .707 r
F P
0 g
s
.61139 .69899 m .61483 .64317 L .64516 .64738 L p .707 .577 .707 r
F P
0 g
s
.61767 .80561 m .61767 .30372 L .58612 .31238 L p .707 .577 .707 r
F P
0 g
s
.24053 .71615 m .24194 .66172 L .21156 .65773 L p .707 .577 .707 r
F P
0 g
s
.24194 .66172 m .24053 .71615 L .27249 .71691 L p .707 .577 .707 r
F P
0 g
s
.27249 .71691 m .2739 .66247 L .24194 .66172 L p .707 .577 .707 r
F P
0 g
s
.2739 .66247 m .27249 .71691 L .30289 .71436 L p .707 .577 .707 r
F P
0 g
s
.30289 .71436 m .30431 .65992 L .2739 .66247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68964 .66099 m .6862 .71681 L .6675 .70934 L p .707 .577 .707 r
F P
0 g
s
.6675 .70934 m .67094 .65352 L .68964 .66099 L p .707 .577 .707 r
F P
0 g
s
.21015 .71217 m .21156 .65773 L .18573 .65091 L p .707 .577 .707 r
F P
0 g
s
.21156 .65773 m .21015 .71217 L .24053 .71615 L p .707 .577 .707 r
F P
0 g
s
.30431 .65992 m .30289 .71436 L .32877 .70875 L p .707 .577 .707 r
F P
0 g
s
.32877 .70875 m .33019 .65432 L .30431 .65992 L p .707 .577 .707 r
F P
0 g
s
.68794 .72529 m .69215 .76173 L .67596 .75512 L p .707 .577 .707 r
F P
0 g
s
.67596 .75512 m .67175 .71867 L .68794 .72529 L p .707 .577 .707 r
F P
0 g
s
.38429 .80633 m .38429 .30444 L .36334 .29371 L p .707 .577 .707 r
F P
0 g
s
.38429 .30444 m .38429 .80633 L .41657 .81479 L p .707 .577 .707 r
F P
0 g
s
.69503 .76952 m .70038 .78684 L .68606 .78088 L p .707 .577 .707 r
F P
0 g
s
.68606 .78088 m .68071 .76356 L .69503 .76952 L p .707 .577 .707 r
F P
0 g
s
.6479 .71479 m .65211 .75123 L .62294 .75046 L p .707 .577 .707 r
F P
0 g
s
.62294 .75046 m .61873 .71402 L .6479 .71479 L p .707 .577 .707 r
F P
0 g
s
.6587 .76177 m .66405 .77909 L .6365 .78165 L p .707 .577 .707 r
F P
0 g
s
.6365 .78165 m .63115 .76434 L .6587 .76177 L p .707 .577 .707 r
F P
0 g
s
.61767 .30372 m .61767 .80561 L .63769 .79475 L p .707 .577 .707 r
F P
0 g
s
.63769 .79475 m .63769 .29286 L .61767 .30372 L p .707 .577 .707 r
F P
0 g
s
.26441 .75817 m .26276 .72012 L .23095 .72107 L p .707 .577 .707 r
F P
0 g
s
.26276 .72012 m .26441 .75817 L .29555 .75586 L p .707 .577 .707 r
F P
0 g
s
.29555 .75586 m .2939 .7178 L .26276 .72012 L p .707 .577 .707 r
F P
0 g
s
.2326 .75912 m .23095 .72107 L .20159 .72056 L p .707 .577 .707 r
F P
0 g
s
.23095 .72107 m .2326 .75912 L .26441 .75817 L p .707 .577 .707 r
F P
0 g
s
.18432 .70534 m .18573 .65091 L .16698 .64191 L p .707 .577 .707 r
F P
0 g
s
.18573 .65091 m .18432 .70534 L .21015 .71217 L p .707 .577 .707 r
F P
0 g
s
.33019 .65432 m .32877 .70875 L .34759 .70064 L p .707 .577 .707 r
F P
0 g
s
.34759 .70064 m .349 .64621 L .33019 .65432 L p .707 .577 .707 r
F P
0 g
s
.67094 .65352 m .6675 .70934 L .64172 .7032 L p .707 .577 .707 r
F P
0 g
s
.64172 .7032 m .64516 .64738 L .67094 .65352 L p .707 .577 .707 r
F P
0 g
s
.2319 .7645 m .234 .78355 L .26555 .7798 L p .707 .577 .707 r
F P
0 g
s
.26555 .7798 m .26345 .76074 L .2319 .7645 L p .707 .577 .707 r
F P
0 g
s
.26345 .76074 m .26555 .7798 L .29673 .77687 L p .707 .577 .707 r
F P
0 g
s
.2939 .7178 m .29555 .75586 L .32298 .75241 L p .707 .577 .707 r
F P
0 g
s
.32298 .75241 m .32133 .71435 L .2939 .7178 L p .707 .577 .707 r
F P
0 g
s
.29673 .77687 m .29462 .75781 L .26345 .76074 L p .707 .577 .707 r
F P
0 g
s
.20159 .72056 m .20324 .75861 L .2326 .75912 L p .707 .577 .707 r
F P
0 g
s
.20307 .76872 m .20517 .78778 L .234 .78355 L p .707 .577 .707 r
F P
0 g
s
.234 .78355 m .2319 .7645 L .20307 .76872 L p .707 .577 .707 r
F P
0 g
s
.29462 .75781 m .29673 .77687 L .32448 .77506 L p .707 .577 .707 r
F P
0 g
s
.32448 .77506 m .32238 .75601 L .29462 .75781 L p .707 .577 .707 r
F P
0 g
s
.67175 .71867 m .67596 .75512 L .65211 .75123 L p .707 .577 .707 r
F P
0 g
s
.65211 .75123 m .6479 .71479 L .67175 .71867 L p .707 .577 .707 r
F P
0 g
s
.20324 .75861 m .20159 .72056 L .17756 .71864 L p .707 .577 .707 r
F P
0 g
s
.17756 .71864 m .1792 .7567 L .20324 .75861 L p .707 .577 .707 r
F P
0 g
s
.32133 .71435 m .32298 .75241 L .34401 .74816 L p .707 .577 .707 r
F P
0 g
s
.34401 .74816 m .34236 .7101 L .32133 .71435 L p .707 .577 .707 r
F P
0 g
s
.17977 .77299 m .18188 .79205 L .20517 .78778 L p .707 .577 .707 r
F P
0 g
s
.20517 .78778 m .20307 .76872 L .17977 .77299 L p .707 .577 .707 r
F P
0 g
s
.16698 .64191 m .16557 .69635 L .18432 .70534 L p .707 .577 .707 r
F P
0 g
s
.68071 .76356 m .68606 .78088 L .66405 .77909 L p .707 .577 .707 r
F P
0 g
s
.66405 .77909 m .6587 .76177 L .68071 .76356 L p .707 .577 .707 r
F P
0 g
s
.32238 .75601 m .32448 .77506 L .34609 .77455 L p .707 .577 .707 r
F P
0 g
s
.16557 .69635 m .16698 .64191 L .15715 .63163 L p .707 .577 .707 r
F P
0 g
s
.34609 .77455 m .34399 .75549 L .32238 .75601 L p .707 .577 .707 r
F P
0 g
s
.349 .64621 m .34759 .70064 L .3575 .69082 L p .707 .577 .707 r
F P
0 g
s
.3575 .69082 m .35892 .63639 L .349 .64621 L p .707 .577 .707 r
F P
0 g
s
.35735 .75633 m .35945 .77538 L .36324 .77748 L p .707 .577 .707 r
F P
0 g
s
.36324 .77748 m .36114 .75842 L .35735 .75633 L p .707 .577 .707 r
F P
0 g
s
.34399 .75549 m .34609 .77455 L .35945 .77538 L p .707 .577 .707 r
F P
0 g
s
.35945 .77538 m .35735 .75633 L .34399 .75549 L p .707 .577 .707 r
F P
0 g
s
.36114 .75842 m .36324 .77748 L .3571 .78064 L p .707 .577 .707 r
F P
0 g
s
.36334 .7956 m .36334 .29371 L .35576 .28178 L p .707 .577 .707 r
F P
0 g
s
.36334 .29371 m .36334 .7956 L .38429 .80633 L p .707 .577 .707 r
F P
0 g
s
.1792 .7567 m .17756 .71864 L .16119 .71551 L p .707 .577 .707 r
F P
0 g
s
.63769 .29286 m .63769 .79475 L .64423 .78277 L p .707 .577 .707 r
F P
0 g
s
.64423 .78277 m .64423 .28088 L .63769 .29286 L p .707 .577 .707 r
F P
0 g
s
.16119 .71551 m .16284 .75356 L .1792 .7567 L p .707 .577 .707 r
F P
0 g
s
.1643 .7769 m .1664 .79595 L .18188 .79205 L p .707 .577 .707 r
F P
0 g
s
.18188 .79205 m .17977 .77299 L .1643 .7769 L p .707 .577 .707 r
F P
0 g
s
.34236 .7101 m .34401 .74816 L .35658 .74353 L p .707 .577 .707 r
F P
0 g
s
.35658 .74353 m .35493 .70547 L .34236 .7101 L p .707 .577 .707 r
F P
0 g
s
.15715 .63163 m .15573 .68606 L .16557 .69635 L p .707 .577 .707 r
F P
0 g
s
.15573 .68606 m .15715 .63163 L .15719 .62105 L p .708 .578 .707 r
F P
0 g
s
.35892 .63639 m .3575 .69082 L .35754 .68025 L p .708 .578 .707 r
F P
0 g
s
.35754 .68025 m .35896 .62582 L .35892 .63639 L p .708 .578 .707 r
F P
0 g
s
.16284 .75356 m .16119 .71551 L .1541 .71146 L p .707 .577 .707 r
F P
0 g
s
.1541 .71146 m .15575 .74952 L .16284 .75356 L p .707 .577 .707 r
F P
0 g
s
.15816 .78005 m .16026 .79911 L .1664 .79595 L p .707 .577 .707 r
F P
0 g
s
.1664 .79595 m .1643 .7769 L .15816 .78005 L p .707 .577 .707 r
F P
0 g
s
.35493 .70547 m .35658 .74353 L .35946 .73896 L p .707 .577 .707 r
F P
0 g
s
.35946 .73896 m .35781 .70091 L .35493 .70547 L p .707 .577 .707 r
F P
0 g
s
.15719 .62105 m .15577 .67549 L .15573 .68606 L p .708 .578 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35896 .62582 m .35754 .68025 L .3477 .66996 L p .707 .577 .707 r
F P
0 g
s
.3477 .66996 m .34912 .61553 L .35896 .62582 L p .707 .577 .707 r
F P
0 g
s
.35781 .70091 m .35946 .73896 L .35237 .73492 L p .707 .577 .707 r
F P
0 g
s
.35237 .73492 m .35072 .69686 L .35781 .70091 L p .707 .577 .707 r
F P
0 g
s
.3571 .78064 m .355 .76158 L .36114 .75842 L p .707 .577 .707 r
F P
0 g
s
.355 .76158 m .3571 .78064 L .3478 .78298 L p .707 .577 .707 r
F P
0 g
s
.3478 .78298 m .34163 .78454 L p .34797 .77366 L .707 .577 .707 r
F P
0 g
s
.34797 .77366 m .355 .76158 L .3478 .78298 L .707 .577 .707 r
F
.35919 .51443 m .35576 .78366 L .36334 .7956 L p F P
0 g
s
.35576 .35297 m .35665 .34174 L p .35576 .28178 L .707 .577 .707 r
F P
0 g
s
.35576 .78366 m .35576 .35297 L p .36231 .26979 L .707 .577 .707 r
F P
0 g
s
.35576 .35297 m .35576 .28178 L .35713 .27928 L p .707 .577 .707 r
F P
0 g
s
.35713 .27928 m .36231 .26979 L p .35576 .35297 L .707 .577 .707 r
F P
0 g
s
.64423 .28088 m .64423 .78277 L .63666 .77083 L p .707 .577 .707 r
F P
0 g
s
.63666 .77083 m .63666 .26894 L .64423 .28088 L p .707 .577 .707 r
F P
0 g
s
.15577 .67549 m .15719 .62105 L .1671 .61123 L p .707 .577 .707 r
F P
0 g
s
.15575 .74952 m .1541 .71146 L .15699 .7069 L p .707 .577 .707 r
F P
0 g
s
.15699 .7069 m .15863 .74495 L .15575 .74952 L p .707 .577 .707 r
F P
0 g
s
.16196 .78215 m .16406 .80121 L .16026 .79911 L p .707 .577 .707 r
F P
0 g
s
.16026 .79911 m .15816 .78005 L .16196 .78215 L p .707 .577 .707 r
F P
0 g
s
.1671 .61123 m .16568 .66567 L .15577 .67549 L p .707 .577 .707 r
F P
0 g
s
.16568 .66567 m .1671 .61123 L .18592 .60312 L p .707 .577 .707 r
F P
0 g
s
.34912 .61553 m .3477 .66996 L .32895 .66097 L p .707 .577 .707 r
F P
0 g
s
.32895 .66097 m .33037 .60653 L .34912 .61553 L p .707 .577 .707 r
F P
0 g
s
.36231 .77168 m .36231 .26979 L .38233 .25894 L p .707 .577 .707 r
F P
0 g
s
.36231 .26979 m .36231 .77168 L .35576 .78366 L p .707 .577 .707 r
F P
0 g
s
.63666 .26894 m .63666 .77083 L .61571 .76011 L p .707 .577 .707 r
F P
0 g
s
.61571 .76011 m .61571 .25822 L .63666 .26894 L p .707 .577 .707 r
F P
0 g
s
.15863 .74495 m .15699 .7069 L .16956 .70227 L p .707 .577 .707 r
F P
0 g
s
.16956 .70227 m .1712 .74032 L .15863 .74495 L p .707 .577 .707 r
F P
0 g
s
.17531 .78298 m .17741 .80204 L .16406 .80121 L p .707 .577 .707 r
F P
0 g
s
.16406 .80121 m .16196 .78215 L .17531 .78298 L p .707 .577 .707 r
F P
0 g
s
.18592 .60312 m .1845 .65756 L .16568 .66567 L p .707 .577 .707 r
F P
0 g
s
.35072 .69686 m .35237 .73492 L .33601 .73178 L p .707 .577 .707 r
F P
0 g
s
.33601 .73178 m .33436 .69373 L .35072 .69686 L p .707 .577 .707 r
F P
0 g
s
.1845 .65756 m .18592 .60312 L .21179 .59752 L p .707 .577 .707 r
F P
0 g
s
.33037 .60653 m .32895 .66097 L .30312 .65414 L p .707 .577 .707 r
F P
0 g
s
.30312 .65414 m .30454 .59971 L .33037 .60653 L p .707 .577 .707 r
F P
0 g
s
.34163 .78454 m .33953 .76548 L .355 .76158 L p .707 .577 .707 r
F P
0 g
s
.1712 .74032 m .16956 .70227 L .19058 .69802 L p .707 .577 .707 r
F P
0 g
s
.21038 .65195 m .21179 .59752 L .2422 .59497 L p .707 .577 .707 r
F P
0 g
s
.21179 .59752 m .21038 .65195 L .1845 .65756 L p .707 .577 .707 r
F P
0 g
s
.38233 .25894 m .38233 .76083 L .36231 .77168 L p .707 .577 .707 r
F P
0 g
s
.38233 .76083 m .38233 .25894 L .41387 .25028 L p .707 .577 .707 r
F P
0 g
s
.30454 .59971 m .30312 .65414 L .27274 .65016 L p .707 .577 .707 r
F P
0 g
s
.27274 .65016 m .27416 .59572 L .30454 .59971 L p .707 .577 .707 r
F P
0 g
s
.19058 .69802 m .19223 .73607 L .1712 .74032 L p .707 .577 .707 r
F P
0 g
s
.61571 .25822 m .61571 .76011 L .58343 .75165 L p .707 .577 .707 r
F P
0 g
s
.58343 .75165 m .58343 .24976 L .61571 .25822 L p .707 .577 .707 r
F P
0 g
s
.19693 .78247 m .19903 .80153 L .17741 .80204 L p .707 .577 .707 r
F P
0 g
s
.17741 .80204 m .17531 .78298 L .19693 .78247 L p .707 .577 .707 r
F P
0 g
s
.75921 .65242 m .7578 .59596 L .72584 .59672 L p .707 .577 .707 r
F P
0 g
s
.7578 .59596 m .75921 .65242 L .78962 .64968 L p .707 .577 .707 r
F P
0 g
s
.78962 .64968 m .7882 .59322 L .7578 .59596 L p .707 .577 .707 r
F P
0 g
s
.72726 .65318 m .72584 .59672 L .69546 .59542 L p .707 .577 .707 r
F P
0 g
s
.72584 .59672 m .72726 .65318 L .75921 .65242 L p .707 .577 .707 r
F P
0 g
s
.33436 .69373 m .33601 .73178 L .31197 .72987 L p .707 .577 .707 r
F P
0 g
s
.31197 .72987 m .31032 .69181 L .33436 .69373 L p .707 .577 .707 r
F P
0 g
s
.24078 .6494 m .2422 .59497 L .27416 .59572 L p .707 .577 .707 r
F P
0 g
s
.2422 .59497 m .24078 .6494 L .21038 .65195 L p .707 .577 .707 r
F P
0 g
s
.27416 .59572 m .27274 .65016 L .24078 .6494 L p .707 .577 .707 r
F P
0 g
s
.33953 .76548 m .34163 .78454 L .31834 .78881 L p .707 .577 .707 r
F P
0 g
s
.31834 .78881 m .31624 .76976 L .33953 .76548 L p .707 .577 .707 r
F P
0 g
s
.7882 .59322 m .78962 .64968 L .8155 .64521 L p .707 .577 .707 r
F P
0 g
s
.8155 .64521 m .81408 .58876 L .7882 .59322 L p .707 .577 .707 r
F P
0 g
s
.69688 .65188 m .69546 .59542 L .66963 .59219 L p .707 .577 .707 r
F P
0 g
s
.69546 .59542 m .69688 .65188 L .72726 .65318 L p .707 .577 .707 r
F P
0 g
s
.19223 .73607 m .19058 .69802 L .21801 .69457 L p .707 .577 .707 r
F P
0 g
s
.21801 .69457 m .21966 .73262 L .19223 .73607 L p .707 .577 .707 r
F P
0 g
s
.31032 .69181 m .31197 .72987 L .28261 .72936 L p .707 .577 .707 r
F P
0 g
s
.28261 .72936 m .28096 .6913 L .31032 .69181 L p .707 .577 .707 r
F P
0 g
s
.7492 .73184 m .75085 .6965 L .71904 .69411 L p .707 .577 .707 r
F P
0 g
s
.75085 .6965 m .7492 .73184 L .78034 .73029 L p .707 .577 .707 r
F P
0 g
s
.78034 .73029 m .78199 .69494 L .75085 .6965 L p .707 .577 .707 r
F P
0 g
s
.66963 .59219 m .67105 .64865 L .69688 .65188 L p .707 .577 .707 r
F P
0 g
s
.22468 .78066 m .22678 .79972 L .19903 .80153 L p .707 .577 .707 r
F P
0 g
s
.19903 .80153 m .19693 .78247 L .22468 .78066 L p .707 .577 .707 r
F P
0 g
s
.71739 .72945 m .71904 .69411 L .68968 .68801 L p .707 .577 .707 r
F P
0 g
s
.71904 .69411 m .71739 .72945 L .7492 .73184 L p .707 .577 .707 r
F P
0 g
s
.41387 .75217 m .41387 .25028 L .45384 .24466 L p .707 .577 .707 r
F P
0 g
s
.41387 .25028 m .41387 .75217 L .38233 .76083 L p .707 .577 .707 r
F P
0 g
s
.58343 .24976 m .58343 .75165 L .54299 .74627 L p .707 .577 .707 r
F P
0 g
s
.54299 .74627 m .54299 .24438 L .58343 .24976 L p .707 .577 .707 r
F P
0 g
s
.81408 .58876 m .8155 .64521 L .83431 .63947 L p .707 .577 .707 r
F P
0 g
s
.83431 .63947 m .8329 .58301 L .81408 .58876 L p .707 .577 .707 r
F P
0 g
s
.31624 .76976 m .31834 .78881 L .28951 .79303 L p .707 .577 .707 r
F P
0 g
s
.67105 .64865 m .66963 .59219 L .65088 .58734 L p .707 .577 .707 r
F P
0 g
s
.78199 .69494 m .78034 .73029 L .80777 .72494 L p .707 .577 .707 r
F P
0 g
s
.80777 .72494 m .80941 .68959 L .78199 .69494 L p .707 .577 .707 r
F P
0 g
s
.28951 .79303 m .2874 .77398 L .31624 .76976 L p .707 .577 .707 r
F P
0 g
s
.21966 .73262 m .21801 .69457 L .24915 .69225 L p .707 .577 .707 r
F P
0 g
s
.28096 .6913 m .28261 .72936 L .2508 .73031 L p .707 .577 .707 r
F P
0 g
s
.2508 .73031 m .24915 .69225 L .28096 .6913 L p .707 .577 .707 r
F P
0 g
s
.68803 .72336 m .68968 .68801 L .66564 .6788 L p .707 .577 .707 r
F P
0 g
s
.68968 .68801 m .68803 .72336 L .71739 .72945 L p .707 .577 .707 r
F P
0 g
s
.24915 .69225 m .2508 .73031 L .21966 .73262 L p .707 .577 .707 r
F P
0 g
s
.25586 .77773 m .25796 .79679 L .22678 .79972 L p .707 .577 .707 r
F P
0 g
s
.22678 .79972 m .22468 .78066 L .25586 .77773 L p .707 .577 .707 r
F P
0 g
s
.65088 .58734 m .65229 .6438 L .67105 .64865 L p .707 .577 .707 r
F P
0 g
s
.2874 .77398 m .28951 .79303 L .25796 .79679 L p .707 .577 .707 r
F P
0 g
s
.25796 .79679 m .25586 .77773 L .2874 .77398 L p .707 .577 .707 r
F P
0 g
s
.80941 .68959 m .80777 .72494 L .82879 .71632 L p .707 .577 .707 r
F P
0 g
s
.82879 .71632 m .83044 .68098 L .80941 .68959 L p .707 .577 .707 r
F P
0 g
s
.45384 .74655 m .45384 .24466 L .49833 .24263 L p .707 .577 .707 r
F P
0 g
s
.45384 .24466 m .45384 .74655 L .41387 .75217 L p .707 .577 .707 r
F P
0 g
s
.54299 .24438 m .54299 .74627 L .49833 .74452 L p .707 .577 .707 r
F P
0 g
s
.49833 .74452 m .49833 .24263 L .54299 .24438 L p .707 .577 .707 r
F P
0 g
s
.66564 .6788 m .66399 .71415 L .68803 .72336 L p .707 .577 .707 r
F P
0 g
s
.8329 .58301 m .83431 .63947 L .84423 .63301 L p .707 .577 .707 r
F P
0 g
s
.84423 .63301 m .84281 .57655 L .8329 .58301 L p .707 .577 .707 r
F P
0 g
s
.49833 .24263 m .49833 .74452 L .45384 .74655 L p .707 .577 .707 r
F P
0 g
s
.66399 .71415 m .66564 .6788 L .64928 .66738 L p .707 .577 .707 r
F P
0 g
s
.65229 .6438 m .65088 .58734 L .64104 .58135 L p .707 .577 .707 r
F P
0 g
s
.74204 .79017 m .74414 .77464 L .71259 .7696 L p .707 .577 .707 r
F P
0 g
s
.74414 .77464 m .74204 .79017 L .77322 .78935 L p .707 .577 .707 r
F P
0 g
s
.77322 .78935 m .77532 .77382 L .74414 .77464 L p .707 .577 .707 r
F P
0 g
s
.71049 .78513 m .71259 .7696 L .68376 .75919 L p .707 .577 .707 r
F P
0 g
s
.71259 .7696 m .71049 .78513 L .74204 .79017 L p .707 .577 .707 r
F P
0 g
s
.77532 .77382 m .77322 .78935 L .80097 .78275 L p .707 .577 .707 r
F P
0 g
s
.80097 .78275 m .80307 .76722 L .77532 .77382 L p .707 .577 .707 r
F P
0 g
s
.64104 .58135 m .64246 .63781 L .65229 .6438 L p .707 .577 .707 r
F P
0 g
s
.83044 .68098 m .82879 .71632 L .84136 .70529 L p .707 .577 .707 r
F P
0 g
s
.84136 .70529 m .84301 .66994 L .83044 .68098 L p .707 .577 .707 r
F P
0 g
s
.68166 .77472 m .68376 .75919 L .66047 .74443 L p .707 .577 .707 r
F P
0 g
s
.68376 .75919 m .68166 .77472 L .71049 .78513 L p .707 .577 .707 r
F P
0 g
s
.64928 .66738 m .64763 .70273 L .66399 .71415 L p .707 .577 .707 r
F P
0 g
s
.64763 .70273 m .64928 .66738 L .64219 .65487 L p .707 .577 .707 r
F P
0 g
s
.66047 .74443 m .65837 .75996 L .68166 .77472 L p .707 .577 .707 r
F P
0 g
s
.80307 .76722 m .80097 .78275 L .82258 .77102 L p .707 .577 .707 r
F P
0 g
s
.82258 .77102 m .82469 .75548 L .80307 .76722 L p .707 .577 .707 r
F P
0 g
s
.84281 .57655 m .84423 .63301 L .84427 .62646 L p .706 .577 .707 r
F P
0 g
s
.84427 .62646 m .84285 .57001 L .84281 .57655 L p .706 .577 .707 r
F P
0 g
s
.64246 .63781 m .64104 .58135 L .64108 .5748 L p .706 .577 .707 r
F P
0 g
s
.65837 .75996 m .66047 .74443 L .64499 .72677 L p .707 .577 .707 r
F P
0 g
s
.64219 .65487 m .64054 .69021 L .64763 .70273 L p .707 .577 .707 r
F P
0 g
s
.84301 .66994 m .84136 .70529 L .84425 .6929 L p .707 .577 .707 r
F P
0 g
s
.84425 .6929 m .84589 .65756 L .84301 .66994 L p .707 .577 .707 r
F P
0 g
s
.64499 .72677 m .64289 .7423 L .65837 .75996 L p .707 .577 .707 r
F P
0 g
s
.64108 .5748 m .6425 .63126 L .64246 .63781 L p .706 .577 .707 r
F P
0 g
s
.82469 .75548 m .82258 .77102 L .83594 .75529 L p .707 .577 .707 r
F P
0 g
s
.83594 .75529 m .83804 .73976 L .82469 .75548 L p .707 .577 .707 r
F P
0 g
s
.64289 .7423 m .64499 .72677 L .63885 .70793 L p .707 .577 .707 r
F P
0 g
s
.64054 .69021 m .64219 .65487 L .64507 .64248 L p .707 .577 .707 r
F P
0 g
s
.84285 .57001 m .84427 .62646 L .83443 .62047 L p .707 .577 .707 r
F P
0 g
s
.83443 .62047 m .83302 .56401 L .84285 .57001 L p .707 .577 .707 r
F P
0 g
s
.6425 .63126 m .64108 .5748 L .651 .56834 L p .707 .577 .707 r
F P
0 g
s
.63885 .70793 m .63675 .72346 L .64289 .7423 L p .707 .577 .707 r
F P
0 g
s
.64507 .64248 m .64342 .67783 L .64054 .69021 L p .707 .577 .707 r
F P
0 g
s
.84589 .65756 m .84425 .6929 L .83716 .68039 L p .707 .577 .707 r
F P
0 g
s
.83716 .68039 m .83881 .64504 L .84589 .65756 L p .707 .577 .707 r
F P
0 g
s
.83804 .73976 m .83594 .75529 L .83974 .73713 L p .707 .577 .707 r
F P
0 g
s
.83974 .73713 m .84184 .7216 L .83804 .73976 L p .707 .577 .707 r
F P
0 g
s
.651 .56834 m .65241 .6248 L .6425 .63126 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63675 .72346 m .63885 .70793 L .64265 .68976 L p .707 .577 .707 r
F P
0 g
s
.64342 .67783 m .64507 .64248 L .65764 .63144 L p .707 .577 .707 r
F P
0 g
s
.42052 .62073 m .41708 .5656 L .38517 .56741 L p .707 .577 .707 r
F P
0 g
s
.41708 .5656 m .42052 .62073 L .45088 .61615 L p .707 .577 .707 r
F P
0 g
s
.45088 .61615 m .44744 .56102 L .41708 .5656 L p .707 .577 .707 r
F P
0 g
s
.38861 .62253 m .38517 .56741 L .35484 .56626 L p .707 .577 .707 r
F P
0 g
s
.38517 .56741 m .38861 .62253 L .42052 .62073 L p .707 .577 .707 r
F P
0 g
s
.64265 .68976 m .64055 .70529 L .63675 .72346 L p .707 .577 .707 r
F P
0 g
s
.83302 .56401 m .83443 .62047 L .81568 .61562 L p .707 .577 .707 r
F P
0 g
s
.81568 .61562 m .81426 .55916 L .83302 .56401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65241 .6248 m .651 .56834 L .66981 .5626 L p .707 .577 .707 r
F P
0 g
s
.44744 .56102 m .45088 .61615 L .47674 .60924 L p .707 .577 .707 r
F P
0 g
s
.47674 .60924 m .4733 .55411 L .44744 .56102 L p .707 .577 .707 r
F P
0 g
s
.84184 .7216 m .83974 .73713 L .8336 .71829 L p .707 .577 .707 r
F P
0 g
s
.8336 .71829 m .8357 .70276 L .84184 .7216 L p .707 .577 .707 r
F P
0 g
s
.35828 .62139 m .35484 .56626 L .32906 .56228 L p .707 .577 .707 r
F P
0 g
s
.35484 .56626 m .35828 .62139 L .38861 .62253 L p .707 .577 .707 r
F P
0 g
s
.65764 .63144 m .65599 .66679 L .64342 .67783 L p .707 .577 .707 r
F P
0 g
s
.83881 .64504 m .83716 .68039 L .82079 .66897 L p .707 .577 .707 r
F P
0 g
s
.82079 .66897 m .82244 .63362 L .83881 .64504 L p .707 .577 .707 r
F P
0 g
s
.66981 .5626 m .67123 .61906 L .65241 .6248 L p .707 .577 .707 r
F P
0 g
s
.64055 .70529 m .64265 .68976 L .65601 .67404 L p .707 .577 .707 r
F P
0 g
s
.40869 .67742 m .4129 .64025 L .38127 .63616 L p .707 .577 .707 r
F P
0 g
s
.4129 .64025 m .40869 .67742 L .4397 .6791 L p .707 .577 .707 r
F P
0 g
s
.4397 .6791 m .44391 .64193 L .4129 .64025 L p .707 .577 .707 r
F P
0 g
s
.37706 .67333 m .38127 .63616 L .3521 .63007 L p .707 .577 .707 r
F P
0 g
s
.38127 .63616 m .37706 .67333 L .40869 .67742 L p .707 .577 .707 r
F P
0 g
s
.65599 .66679 m .65764 .63144 L .67867 .62283 L p .707 .577 .707 r
F P
0 g
s
.4733 .55411 m .47674 .60924 L .49555 .60068 L p .707 .577 .707 r
F P
0 g
s
.49555 .60068 m .49211 .54555 L .4733 .55411 L p .707 .577 .707 r
F P
0 g
s
.32906 .56228 m .3325 .6174 L .35828 .62139 L p .707 .577 .707 r
F P
0 g
s
.65601 .67404 m .65391 .68957 L .64055 .70529 L p .707 .577 .707 r
F P
0 g
s
.3325 .6174 m .32906 .56228 L .31035 .55584 L p .707 .577 .707 r
F P
0 g
s
.81426 .55916 m .81568 .61562 L .78985 .61239 L p .707 .577 .707 r
F P
0 g
s
.78985 .61239 m .78843 .55593 L .81426 .55916 L p .707 .577 .707 r
F P
0 g
s
.44391 .64193 m .4397 .6791 L .46704 .67822 L p .707 .577 .707 r
F P
0 g
s
.46704 .67822 m .47125 .64105 L .44391 .64193 L p .707 .577 .707 r
F P
0 g
s
.67123 .61906 m .66981 .5626 L .69569 .55814 L p .707 .577 .707 r
F P
0 g
s
.3521 .63007 m .34789 .66725 L .37706 .67333 L p .707 .577 .707 r
F P
0 g
s
.39389 .71496 m .39924 .69681 L .36884 .68731 L p .707 .577 .707 r
F P
0 g
s
.39924 .69681 m .39389 .71496 L .42414 .72255 L p .707 .577 .707 r
F P
0 g
s
.42414 .72255 m .42949 .7044 L .39924 .69681 L p .707 .577 .707 r
F P
0 g
s
.8357 .70276 m .8336 .71829 L .81812 .70063 L p .707 .577 .707 r
F P
0 g
s
.81812 .70063 m .82022 .6851 L .8357 .70276 L p .707 .577 .707 r
F P
0 g
s
.34789 .66725 m .3521 .63007 L .32825 .62258 L p .707 .577 .707 r
F P
0 g
s
.36349 .70546 m .36884 .68731 L .34129 .67684 L p .707 .577 .707 r
F P
0 g
s
.36884 .68731 m .36349 .70546 L .39389 .71496 L p .707 .577 .707 r
F P
0 g
s
.82244 .63362 m .82079 .66897 L .79676 .65976 L p .707 .577 .707 r
F P
0 g
s
.79676 .65976 m .7984 .62441 L .82244 .63362 L p .707 .577 .707 r
F P
0 g
s
.67867 .62283 m .67702 .65818 L .65599 .66679 L p .707 .577 .707 r
F P
0 g
s
.34129 .67684 m .33595 .69499 L .36349 .70546 L p .707 .577 .707 r
F P
0 g
s
.42949 .7044 m .42414 .72255 L .45131 .7275 L p .707 .577 .707 r
F P
0 g
s
.45131 .7275 m .45666 .70935 L .42949 .7044 L p .707 .577 .707 r
F P
0 g
s
.65391 .68957 m .65601 .67404 L .67762 .66231 L p .707 .577 .707 r
F P
0 g
s
.69569 .55814 m .69711 .6146 L .67123 .61906 L p .707 .577 .707 r
F P
0 g
s
.32825 .62258 m .32404 .65975 L .34789 .66725 L p .707 .577 .707 r
F P
0 g
s
.31035 .55584 m .3138 .61096 L .3325 .6174 L p .707 .577 .707 r
F P
0 g
s
.47125 .64105 m .46704 .67822 L .48804 .67485 L p .707 .577 .707 r
F P
0 g
s
.48804 .67485 m .49225 .63768 L .47125 .64105 L p .707 .577 .707 r
F P
0 g
s
.67702 .65818 m .67867 .62283 L .7061 .61748 L p .707 .577 .707 r
F P
0 g
s
.78843 .55593 m .78985 .61239 L .75947 .61109 L p .707 .577 .707 r
F P
0 g
s
.75947 .61109 m .75805 .55463 L .78843 .55593 L p .707 .577 .707 r
F P
0 g
s
.69711 .6146 m .69569 .55814 L .7261 .55539 L p .707 .577 .707 r
F P
0 g
s
.33595 .69499 m .34129 .67684 L .31928 .66642 L p .707 .577 .707 r
F P
0 g
s
.49211 .54555 m .49555 .60068 L .50547 .59131 L p .707 .577 .707 r
F P
0 g
s
.50547 .59131 m .50203 .53618 L .49211 .54555 L p .707 .577 .707 r
F P
0 g
s
.31928 .66642 m .31394 .68457 L .33595 .69499 L p .707 .577 .707 r
F P
0 g
s
.67762 .66231 m .67552 .67784 L .65391 .68957 L p .707 .577 .707 r
F P
0 g
s
.3138 .61096 m .31035 .55584 L .30056 .54758 L p .707 .577 .707 r
F P
0 g
s
.32404 .65975 m .32825 .62258 L .31206 .61441 L p .707 .577 .707 r
F P
0 g
s
.7984 .62441 m .79676 .65976 L .7674 .65366 L p .707 .577 .707 r
F P
0 g
s
.7674 .65366 m .76904 .61832 L .7984 .62441 L p .707 .577 .707 r
F P
0 g
s
.45666 .70935 m .45131 .7275 L .47272 .72931 L p .707 .577 .707 r
F P
0 g
s
.47272 .72931 m .47807 .71116 L .45666 .70935 L p .707 .577 .707 r
F P
0 g
s
.82022 .6851 m .81812 .70063 L .79483 .68587 L p .707 .577 .707 r
F P
0 g
s
.79483 .68587 m .79693 .67034 L .82022 .6851 L p .707 .577 .707 r
F P
0 g
s
.75805 .55463 m .75947 .61109 L .72751 .61185 L p .707 .577 .707 r
F P
0 g
s
.72751 .61185 m .7261 .55539 L .75805 .55463 L p .707 .577 .707 r
F P
0 g
s
.7261 .55539 m .72751 .61185 L .69711 .6146 L p .707 .577 .707 r
F P
0 g
s
.7061 .61748 m .70445 .65283 L .67702 .65818 L p .707 .577 .707 r
F P
0 g
s
.67552 .67784 m .67762 .66231 L .70537 .65571 L p .707 .577 .707 r
F P
0 g
s
.70445 .65283 m .7061 .61748 L .73724 .61593 L p .707 .577 .707 r
F P
0 g
s
.31206 .61441 m .30785 .65158 L .32404 .65975 L p .707 .577 .707 r
F P
0 g
s
.76904 .61832 m .7674 .65366 L .73559 .65127 L p .707 .577 .707 r
F P
0 g
s
.73559 .65127 m .73724 .61593 L .76904 .61832 L p .707 .577 .707 r
F P
0 g
s
.73724 .61593 m .73559 .65127 L .70445 .65283 L p .707 .577 .707 r
F P
0 g
s
.31394 .68457 m .31928 .66642 L .30497 .65707 L p .707 .577 .707 r
F P
0 g
s
.49225 .63768 m .48804 .67485 L .50064 .66934 L p .707 .577 .707 r
F P
0 g
s
.50064 .66934 m .50485 .63216 L .49225 .63768 L p .707 .577 .707 r
F P
0 g
s
.30056 .54758 m .304 .60271 L .3138 .61096 L p .707 .577 .707 r
F P
0 g
s
.70537 .65571 m .70327 .67124 L .67552 .67784 L p .707 .577 .707 r
F P
0 g
s
.30497 .65707 m .29962 .67522 L .31394 .68457 L p .707 .577 .707 r
F P
0 g
s
.79693 .67034 m .79483 .68587 L .766 .67546 L p .707 .577 .707 r
F P
0 g
s
.766 .67546 m .7681 .65993 L .79693 .67034 L p .707 .577 .707 r
F P
0 g
s
.70327 .67124 m .70537 .65571 L .73655 .65489 L p .707 .577 .707 r
F P
0 g
s
.50203 .53618 m .50547 .59131 L .50553 .58204 L p .707 .577 .707 r
F P
0 g
s
.50553 .58204 m .50209 .52691 L .50203 .53618 L p .707 .577 .707 r
F P
0 g
s
.47807 .71116 m .47272 .72931 L .48628 .72782 L p .707 .577 .707 r
F P
0 g
s
.48628 .72782 m .49163 .70967 L .47807 .71116 L p .707 .577 .707 r
F P
0 g
s
.30785 .65158 m .31206 .61441 L .3051 .60637 L p .707 .577 .707 r
F P
0 g
s
.7681 .65993 m .766 .67546 L .73445 .67042 L p .707 .577 .707 r
F P
0 g
s
.73445 .67042 m .73655 .65489 L .7681 .65993 L p .707 .577 .707 r
F P
0 g
s
.73655 .65489 m .73445 .67042 L .70327 .67124 L p .707 .577 .707 r
F P
0 g
s
.304 .60271 m .30056 .54758 L .30062 .53832 L p .707 .577 .707 r
F P
0 g
s
.3051 .60637 m .30089 .64354 L .30785 .65158 L p .707 .577 .707 r
F P
0 g
s
.29962 .67522 m .30497 .65707 L .29975 .64971 L p .707 .577 .707 r
F P
0 g
s
.50485 .63216 m .50064 .66934 L .50361 .66221 L p .707 .577 .707 r
F P
0 g
s
.50361 .66221 m .50782 .62503 L .50485 .63216 L p .707 .577 .707 r
F P
0 g
s
.29975 .64971 m .2944 .66786 L .29962 .67522 L p .707 .577 .707 r
F P
0 g
s
.30062 .53832 m .30406 .59344 L .304 .60271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49163 .70967 m .48628 .72782 L .49066 .72316 L p .707 .577 .707 r
F P
0 g
s
.49066 .72316 m .49601 .70501 L .49163 .70967 L p .707 .577 .707 r
F P
0 g
s
.50209 .52691 m .50553 .58204 L .49573 .57378 L p .707 .577 .707 r
F P
0 g
s
.49573 .57378 m .49229 .51866 L .50209 .52691 L p .707 .577 .707 r
F P
0 g
s
.30089 .64354 m .3051 .60637 L .30807 .59924 L p .707 .577 .707 r
F P
0 g
s
.30406 .59344 m .30062 .53832 L .31054 .52894 L p .707 .577 .707 r
F P
0 g
s
.30807 .59924 m .30386 .63641 L .30089 .64354 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2944 .66786 m .29975 .64971 L .30413 .64505 L p .707 .577 .707 r
F P
0 g
s
.50782 .62503 m .50361 .66221 L .49665 .65416 L p .707 .577 .707 r
F P
0 g
s
.49665 .65416 m .50086 .61699 L .50782 .62503 L p .707 .577 .707 r
F P
0 g
s
.30413 .64505 m .29878 .6632 L .2944 .66786 L p .707 .577 .707 r
F P
0 g
s
.31054 .52894 m .31398 .58407 L .30406 .59344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49229 .51866 m .49573 .57378 L .47703 .56735 L p .707 .577 .707 r
F P
0 g
s
.47703 .56735 m .47359 .51222 L .49229 .51866 L p .707 .577 .707 r
F P
0 g
s
.49601 .70501 m .49066 .72316 L .48544 .7158 L p .707 .577 .707 r
F P
0 g
s
.48544 .7158 m .49079 .69765 L .49601 .70501 L p .707 .577 .707 r
F P
0 g
s
.30386 .63641 m .30807 .59924 L .32067 .59372 L p .707 .577 .707 r
F P
0 g
s
.31398 .58407 m .31054 .52894 L .32935 .52038 L p .707 .577 .707 r
F P
0 g
s
.32067 .59372 m .31646 .63089 L .30386 .63641 L p .707 .577 .707 r
F P
0 g
s
.29878 .6632 m .30413 .64505 L .31769 .64356 L p .707 .577 .707 r
F P
0 g
s
.32935 .52038 m .33279 .57551 L .31398 .58407 L p .707 .577 .707 r
F P
0 g
s
.50086 .61699 m .49665 .65416 L .48046 .646 L p .707 .577 .707 r
F P
0 g
s
.48046 .646 m .48467 .60882 L .50086 .61699 L p .707 .577 .707 r
F P
0 g
s
.31769 .64356 m .31234 .66171 L .29878 .6632 L p .707 .577 .707 r
F P
0 g
s
.47359 .51222 m .47703 .56735 L .45125 .56336 L p .707 .577 .707 r
F P
0 g
s
.45125 .56336 m .44781 .50824 L .47359 .51222 L p .707 .577 .707 r
F P
0 g
s
.33279 .57551 m .32935 .52038 L .3552 .51348 L p .707 .577 .707 r
F P
0 g
s
.49079 .69765 m .48544 .7158 L .47113 .70645 L p .707 .577 .707 r
F P
0 g
s
.47113 .70645 m .47647 .6883 L .49079 .69765 L p .707 .577 .707 r
F P
0 g
s
.31646 .63089 m .32067 .59372 L .34167 .59035 L p .707 .577 .707 r
F P
0 g
s
.34167 .59035 m .33746 .62753 L .31646 .63089 L p .707 .577 .707 r
F P
0 g
s
.44781 .50824 m .45125 .56336 L .42092 .56221 L p .707 .577 .707 r
F P
0 g
s
.42092 .56221 m .41748 .50709 L .44781 .50824 L p .707 .577 .707 r
F P
0 g
s
.3552 .51348 m .35865 .5686 L .33279 .57551 L p .707 .577 .707 r
F P
0 g
s
.35865 .5686 m .3552 .51348 L .38557 .50889 L p .707 .577 .707 r
F P
0 g
s
.48467 .60882 m .48046 .646 L .45661 .6385 L p .707 .577 .707 r
F P
0 g
s
.45661 .6385 m .46082 .60133 L .48467 .60882 L p .707 .577 .707 r
F P
0 g
s
.31234 .66171 m .31769 .64356 L .3391 .64538 L p .707 .577 .707 r
F P
0 g
s
.3391 .64538 m .33375 .66353 L .31234 .66171 L p .707 .577 .707 r
F P
0 g
s
.41748 .50709 m .42092 .56221 L .38901 .56402 L p .707 .577 .707 r
F P
0 g
s
.38901 .56402 m .38557 .50889 L .41748 .50709 L p .707 .577 .707 r
F P
0 g
s
.38557 .50889 m .38901 .56402 L .35865 .5686 L p .707 .577 .707 r
F P
0 g
s
.33746 .62753 m .34167 .59035 L .36901 .58947 L p .707 .577 .707 r
F P
0 g
s
.47647 .6883 m .47113 .70645 L .44912 .69603 L p .707 .577 .707 r
F P
0 g
s
.44912 .69603 m .45446 .67788 L .47647 .6883 L p .707 .577 .707 r
F P
0 g
s
.36901 .58947 m .3648 .62664 L .33746 .62753 L p .707 .577 .707 r
F P
0 g
s
.46082 .60133 m .45661 .6385 L .42744 .63241 L p .707 .577 .707 r
F P
0 g
s
.42744 .63241 m .43165 .59524 L .46082 .60133 L p .707 .577 .707 r
F P
0 g
s
.33375 .66353 m .3391 .64538 L .36627 .65032 L p .707 .577 .707 r
F P
0 g
s
.3648 .62664 m .36901 .58947 L .40002 .59115 L p .707 .577 .707 r
F P
0 g
s
.36627 .65032 m .36092 .66847 L .33375 .66353 L p .707 .577 .707 r
F P
0 g
s
.43165 .59524 m .42744 .63241 L .39581 .62833 L p .707 .577 .707 r
F P
0 g
s
.39581 .62833 m .40002 .59115 L .43165 .59524 L p .707 .577 .707 r
F P
0 g
s
.45446 .67788 m .44912 .69603 L .42157 .68556 L p .707 .577 .707 r
F P
0 g
s
.42157 .68556 m .42692 .66741 L .45446 .67788 L p .707 .577 .707 r
F P
0 g
s
.40002 .59115 m .39581 .62833 L .3648 .62664 L p .707 .577 .707 r
F P
0 g
s
.36092 .66847 m .36627 .65032 L .39652 .65791 L p .707 .577 .707 r
F P
0 g
s
.39652 .65791 m .39117 .67606 L .36092 .66847 L p .707 .577 .707 r
F P
0 g
s
.42692 .66741 m .42157 .68556 L .39117 .67606 L p .707 .577 .707 r
F P
0 g
s
.39117 .67606 m .39652 .65791 L .42692 .66741 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1@00L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JGoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomo
o`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Moo`00IGoo0P00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20004FUHH000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00Hgoo10001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005moo`@00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo
001LOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJ
EP00IGoo001JOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00F7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Moo`80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUIJEP00IGoo001FOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001EOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001U
Ool005Eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP004Woo4P00@Goo001EOol01000FUIJEP001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEUYF000<Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol005Eoo`05001JEUYF
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00@005YFFUH000Qoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH6000cOol005Eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0000
0eYF000000060003FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH000Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0031oo`00EGoo0P000UYF00<005YFFUH00UYF
00<005YFFUH00eYF3`000eYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEUYF001oo`030002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000^Ool005Eoo`80009JEP03001JEUYF009JEP03001JEP0000@000QJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP00;Goo001EOol20002FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00;Goo001FOol01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10002UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF00@005YFFUH002eoo`00EWoo00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEUYF000]Ool005Ioo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002eoo`00EWoo10000eYF00<005YF00003P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF000]Ool005Ioo`05001JEUYF001JEP040002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH:
0009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002eoo`00>goo5`0017oo00<005YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF0000;Goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040006
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool003=oo`@000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0002eoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF0000;Goo000_Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH0000]Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJ
EPh000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP0002eoo`00;Goo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF
FUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP0500000eYF0000000C0004FUH01000FUIJ
EUYF1P000eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00D0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF00@00003
FUH007oo02aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30002FUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH3000]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0002FUH01000FUIJEUYF600015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000`000UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF0000
05YF0005FUH00`00FUH0000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF000000040005FUH50004FUH00`00FUH00004
0002FUH60006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<005YF0000;Goo000/
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH015YF00@005YFFUIJEP/0009JEP03001JEUYF00=JEP@0009JEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP03001JEP00009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEUYF00MJEP@000EJEP03001JEUYF
009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01`00FUH0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEPH002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00<00003FUH0000001800003FUH005YF00=JEP04001JEUYF0009FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF3`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@0005FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEUYF0004FUH01000FUIJEUYF2000
27oo0`001Goo100000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF00AJEQD000IJEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00;7oo00@005YFFUH000AJ
EPH000eoo`D000Qoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEUYF001JEP002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF01<000Ioo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00;7oo00@0
05YFFUH0009JEP<000EJEPH000Moo`D000Ioo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP02FUH800000eYF001JEP07FUH00`00FUIJEP02FUH60004Ool40005FUH00`00FUIJEP02FUH00`00
FUH0000/Ool002aoo`03001JEUYF00<0009JEP03001JEUYF00EJEP04001JEUYFFUHB00000eYF0000
000;0007FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF00000P0000AJEP00000000AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00
0006Ool20003FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEP0000AJ
EP800004FUH005YFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF00000eYF0P000UYF0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
FUIJEP<000Eoo`800003FUH005YF009JEP04001JEUYF000/Ool002aoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH01000FUH00000
15YF00<005YF000010001UYF00<005YFFUH01eYF00<005YF00000P001UYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF
00<005YFFUH00P000UYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0P001Goo0P000eYF00@0
05YFFUH002aoo`00;7oo0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP80009JEP800003FUH00000009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH6000<FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000004FUH00`00FUH000040009
Ool70002FUH00`00FUIJEP06FUH30005Ool01000FUIJEP000UYF00<007ooOol0:Woo000/Ool01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000IJEP<00004FUH000000005FUH50007FUH00`00FUIJEP05FUH80005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF0P00
0UYF00<005YF00002Goo1@000Woo10001eYF00<005YFFUH00P0017oo0`0000=JEP00Ool0;7oo000/
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0000=JEP00FUH01UYF00<005YF00000`001EYF00<005YFFUH01P000UYF00<005YFFUH01eYF
0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00L005YF
001JEP00FUH00003FUH20004FUH00`00FUH0000:Ool30007Ool20004FUH00`00FUIJEP03FUH20003
Ool200000eYF001oo`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YF
000010000UYF10001eYF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEP00FUH20002FUH200000eYF00000002000015YF001JEP00
5Woo0`0000=JEP00FUH01UYF1@0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP<0009JEP03001JEP0000@0009JEP04001JEUYFFUH20005FUH00`00FUIJEP03FUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUH00000
FUH00`0000=JEP00FUH015YF10006Goo0P001eYF0P0000=JEP00FUH00P00;Goo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHL00000eYF001JEP07FUH00`00FUH0000200000eYF
000000030002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YF00000`0067oo0P001EYF00D005YF000005YF008002eoo`00;Woo0P0015YF00<005YFFUH0
0eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000MJEP03001JEUYF009J
EPD000=JEP03001JEUYF00IJEP8000IJEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH70009Ool900000eYF00000002FUH00`00FUIJEP020002FUH00`00Oomoo`0[Ool002mo
o`8000=JEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000004FUH00`00FUIJEP06FUH400000eYF001JEP09FUH20004FUH00`00FUIJEP02FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH30003
FUH01000FUIJEP00;Goo000`Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH0
10002EYF0`0000=JEP00FUH015YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YF0000;Goo000^Ool30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP@000MJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJEP04001JEP00000<FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80009JEP8000EJEP03001JEUYF
00MJEP04001JEUYFFUH60002FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH01P000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH00UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0002ioo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH20005FUH00`00FUH000030007FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01`00FUH005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEPL0
0003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH007oo02eoo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000P000UYF
1`0000=JEP00FUH01UYF00<005YFFUH00UYF1@0025YF00<005YFFUH01EYF00@005YFFUIJEP800005
Ool005YFFUH0000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001J
EUYF00IJEPL000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH000040006FUH00`00
FUIJEP02FUH50008FUH00`00FUIJEP05FUH01000FUH000000goo00@005YFFUH002eoo`00:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH015YF1`00
0eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YFFUH00P001EYF00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF009J
EPD000QJEP03001JEUYF009JEPD000Ioo`03001JEP0002eoo`00:goo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YF00001@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF0P0000=JEP0000001UYF00@005YFFUIJEP<000=oo`L00003FUH0
0000008000AJEPT000]oo`<002eoo`00;7oo00EJEP00FUIJEP0000EJEP03001JEUYF009JEPP000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800004
FUH005YF0005FUH01`00FUIJEUYF001JEP0000Yoo`T001Eoo`03001oogoo02aoo`00;7oo00EJEP00
FUIJEP0000=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0002Qoo`03001oogoo02aoo`00;7oo00=JEP00FUH01@001EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF009JEP07
001JEUYFFUH005YF0000:7oo00<007ooOol0;7oo000/Ool00eYF00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00004FUH01@00FUIJEUYF00000eYF
00<005YF00009goo0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@0000=oo`0000001EYF
00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001EYF00<005YFFUH01eYF
00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP04001JEUYFFUH2000VOol2000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70006Ool20005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP030003
FUH2000UOol00`00FUH0000_Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ<0009oo`8000EJEP03001JEUYF009JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP@000EJEP03001JEUYF009JEP08001J
EUYF001oo`00FUH000AJEP80009JEP03001JEP0002=oo`04001JEUYF000_Ool0031oobP000=JEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH400000eYF001JEP03FUH01000FUIJ
EP000Woo0P001UYF0`0000=JEP00Ool087oo0`0000=JEP00Ool0;goo0016Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP050006FUH0
0`00FUH00002000POol00`00FUIJEP02000aOol003ioo`P000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D00004FUH000000003FUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00
0eYF0`0015YF00@005YFFUIJEP<001aoo`80009JEP03001JEP00035oo`00=goo1`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEPD000=JEP04001JEUYFFUH300000eYF00000003FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH01@00FUIJEUYF00000UYF00@005YFFUH000MJEP@001Io
o`8000AJEP80039oo`00<Goo1P000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
100000=JEP00FUH01EYF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00<000QJEP03001JEUYF00@000ioo`@00003FUH005YF00=JEP03001o
ogoo035oo`00;Woo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00001P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF000015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF3P0015YF00@005YFFUIJ
EP8003Aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH04@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP0000001@000eYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000003Ioo`00;7oo40000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP02FUH800000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000hOol0
02aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH40003Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP03FUH200000goo000000070004FUH00`00FUIJEP06FUH00`00
FUIJEP04000kOol002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEPL000Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8000EJEP03001JEUYF00=JEP05001oogoo001JEP020005Ool@000oOol002eoo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH20003Ool01000FUIJEP00
E7oo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000IOol00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00@005YF000000Aoo`80009JEP03001o
ogoo059oo`00;Goo0`000UYF00@005YFFUIJEPl002=oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP001UYF0`0017oo0P000UYF00<005YF0000E7oo000`Ool6000dOol200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP040006Ool00`00FUIJEP02FUH2001EOol006aoo`@000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP<0009JEPD000Qo
o`<000EJEP03001oogoo05=oo`00L7oo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH0100000=JEP0000000P0037oo00D005YFFUIJEP0000=J
EP03001oogoo05Aoo`00M7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
2P003Woo0P0015YF00@005YFFUH005Moo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01P001Goo1@003Goo00<005YFFUH01EYF0P00F7oo001oOolO000;Ool5000;Ool30007
FUH00`00Oomoo`1GOol0091oo`03001JEUYF009JEP03001oogoo019oo`<000Yoo`8000=JEP03001J
EUYF009JEP8005Yoo`00Sgoo00<005YF00000UYF00<007ooOol07Woo0P001EYF00D005YFFUIJEP00
05aoo`00Sgoo00D005YF001JEP0001moo`8000QJEP<005eoo`00Sgoo00<005YFFUH00P0077oo0`00
00=JEP00FUH01eYF00<007ooOol0GGoo002?Ool01000FUIJEP006Woo0`0015YF00<005YFFUH015YF
0P00H7oo002@Ool00eYF001oo`0FOol40008FUH01000FUIJEUYF0P00HWoo002@Ool00eYF0000000B
Ool40002FUH00`00FUIJEP07FUH01000FUH00000I7oo002@Ool200000eYF0000000@0007FUH00`00
FUIJEP05FUH3001VOol0095oo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001YOol0095oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008006]oo`00TWoo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
06ioo`00Tgoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01000LWoo002EOolB001f
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58557 .74796 m .58772 .6922 L .55702 .68884 L p .707 .577 .707 r
F P
0 g
s
.58772 .6922 m .58557 .74796 L .61749 .74884 L p .707 .577 .707 r
F P
0 g
s
.61749 .74884 m .61965 .69308 L .58772 .6922 L p .707 .577 .707 r
F P
0 g
s
.61965 .69308 m .61749 .74884 L .64752 .74716 L p .707 .577 .707 r
F P
0 g
s
.64752 .74716 m .64968 .6914 L .61965 .69308 L p .707 .577 .707 r
F P
0 g
s
.55487 .7446 m .55702 .68884 L .53057 .68333 L p .707 .577 .707 r
F P
0 g
s
.55702 .68884 m .55487 .7446 L .58557 .74796 L p .707 .577 .707 r
F P
0 g
s
.64968 .6914 m .64752 .74716 L .67272 .74308 L p .707 .577 .707 r
F P
0 g
s
.67272 .74308 m .67488 .68731 L .64968 .6914 L p .707 .577 .707 r
F P
0 g
s
.61342 .81155 m .61074 .77486 L .57886 .77678 L p .707 .577 .707 r
F P
0 g
s
.61074 .77486 m .61342 .81155 L .64397 .80682 L p .707 .577 .707 r
F P
0 g
s
.64397 .80682 m .64129 .77013 L .61074 .77486 L p .707 .577 .707 r
F P
0 g
s
.53057 .68333 m .52841 .7391 L .55487 .7446 L p .707 .577 .707 r
F P
0 g
s
.58154 .81347 m .57886 .77678 L .54876 .7757 L p .707 .577 .707 r
F P
0 g
s
.57886 .77678 m .58154 .81347 L .61342 .81155 L p .707 .577 .707 r
F P
0 g
s
.52841 .7391 m .53057 .68333 L .51093 .67622 L p .707 .577 .707 r
F P
0 g
s
.64129 .77013 m .64397 .80682 L .67018 .79975 L p .707 .577 .707 r
F P
0 g
s
.67018 .79975 m .6675 .76305 L .64129 .77013 L p .707 .577 .707 r
F P
0 g
s
.67488 .68731 m .67272 .74308 L .69062 .737 L p .707 .577 .707 r
F P
0 g
s
.69062 .737 m .69278 .68123 L .67488 .68731 L p .707 .577 .707 r
F P
0 g
s
.55144 .81239 m .54876 .7757 L .52339 .77173 L p .707 .577 .707 r
F P
0 g
s
.54876 .7757 m .55144 .81239 L .58154 .81347 L p .707 .577 .707 r
F P
0 g
s
.51093 .67622 m .50878 .73198 L .52841 .7391 L p .707 .577 .707 r
F P
0 g
s
.61662 .85538 m .61316 .83751 L .58176 .84242 L p .707 .577 .707 r
F P
0 g
s
.61316 .83751 m .61662 .85538 L .64697 .84738 L p .707 .577 .707 r
F P
0 g
s
.64697 .84738 m .64351 .82952 L .61316 .83751 L p .707 .577 .707 r
F P
0 g
s
.58522 .86029 m .58176 .84242 L .55236 .84377 L p .707 .577 .707 r
F P
0 g
s
.58176 .84242 m .58522 .86029 L .61662 .85538 L p .707 .577 .707 r
F P
0 g
s
.52339 .77173 m .52607 .80842 L .55144 .81239 L p .707 .577 .707 r
F P
0 g
s
.6675 .76305 m .67018 .79975 L .6895 .79101 L p .707 .577 .707 r
F P
0 g
s
.6895 .79101 m .68682 .75432 L .6675 .76305 L p .707 .577 .707 r
F P
0 g
s
.64351 .82952 m .64697 .84738 L .67329 .83709 L p .707 .577 .707 r
F P
0 g
s
.67329 .83709 m .66983 .81922 L .64351 .82952 L p .707 .577 .707 r
F P
0 g
s
.50878 .73198 m .51093 .67622 L .50005 .66819 L p .707 .577 .707 r
F P
0 g
s
.55236 .84377 m .55582 .86164 L .58522 .86029 L p .707 .577 .707 r
F P
0 g
s
.52607 .80842 m .52339 .77173 L .50524 .76525 L p .707 .577 .707 r
F P
0 g
s
.69278 .68123 m .69062 .737 L .69947 .72951 L p .707 .577 .707 r
F P
0 g
s
.69947 .72951 m .70163 .67375 L .69278 .68123 L p .707 .577 .707 r
F P
0 g
s
.55582 .86164 m .55236 .84377 L .52786 .84142 L p .707 .577 .707 r
F P
0 g
s
.66983 .81922 m .67329 .83709 L .693 .8255 L p .707 .577 .707 r
F P
0 g
s
.693 .8255 m .68954 .80763 L .66983 .81922 L p .707 .577 .707 r
F P
0 g
s
.52786 .84142 m .53132 .85929 L .55582 .86164 L p .707 .577 .707 r
F P
0 g
s
.50524 .76525 m .50792 .80194 L .52607 .80842 L p .707 .577 .707 r
F P
0 g
s
.50005 .66819 m .49789 .72395 L .50878 .73198 L p .707 .577 .707 r
F P
0 g
s
.68682 .75432 m .6895 .79101 L .70004 .78148 L p .707 .577 .707 r
F P
0 g
s
.70004 .78148 m .69736 .74479 L .68682 .75432 L p .707 .577 .707 r
F P
0 g
s
.53132 .85929 m .52786 .84142 L .51065 .8356 L p .707 .577 .707 r
F P
0 g
s
.50792 .80194 m .50524 .76525 L .49607 .7569 L p .707 .577 .707 r
F P
0 g
s
.49789 .72395 m .50005 .66819 L .49898 .66003 L p .707 .577 .707 r
F P
0 g
s
.51065 .8356 m .51411 .85347 L .53132 .85929 L p .707 .577 .707 r
F P
0 g
s
.68954 .80763 m .693 .8255 L .70418 .81375 L p .707 .577 .707 r
F P
0 g
s
.70418 .81375 m .70071 .79588 L .68954 .80763 L p .707 .577 .707 r
F P
0 g
s
.70163 .67375 m .69947 .72951 L .6984 .72136 L p .707 .577 .707 r
F P
0 g
s
.6984 .72136 m .70055 .66559 L .70163 .67375 L p .707 .577 .707 r
F P
0 g
s
.49607 .7569 m .49875 .79359 L .50792 .80194 L p .707 .577 .707 r
F P
0 g
s
.49898 .66003 m .49682 .7158 L .49789 .72395 L p .707 .577 .707 r
F P
0 g
s
.69736 .74479 m .70004 .78148 L .70076 .77208 L p .707 .577 .707 r
F P
0 g
s
.70076 .77208 m .69808 .73539 L .69736 .74479 L p .707 .577 .707 r
F P
0 g
s
.49875 .79359 m .49607 .7569 L .49679 .7475 L p .707 .577 .707 r
F P
0 g
s
.49682 .7158 m .49898 .66003 L .50782 .65254 L p .707 .577 .707 r
F P
0 g
s
.49679 .7475 m .49947 .78419 L .49875 .79359 L p .707 .577 .707 r
F P
0 g
s
.50782 .65254 m .50567 .70831 L .49682 .7158 L p .707 .577 .707 r
F P
0 g
s
.49947 .78419 m .49679 .7475 L .50733 .73797 L p .707 .577 .707 r
F P
0 g
s
.49737 .82192 m .49737 .32003 L .45293 .31792 L p .707 .577 .707 r
F P
0 g
s
.51411 .85347 m .51065 .8356 L .50242 .82689 L p .707 .577 .707 r
F P
0 g
s
.50242 .82689 m .50588 .84475 L .51411 .85347 L p .707 .577 .707 r
F P
0 g
s
.50588 .84475 m .50242 .82689 L .50396 .81613 L p .707 .577 .707 r
F P
0 g
s
.50567 .70831 m .50782 .65254 L .52572 .64646 L p .707 .577 .707 r
F P
0 g
s
.50396 .81613 m .50743 .834 L .50588 .84475 L p .707 .577 .707 r
F P
0 g
s
.50733 .73797 m .51001 .77466 L .49947 .78419 L p .707 .577 .707 r
F P
0 g
s
.52572 .64646 m .52357 .70223 L .50567 .70831 L p .707 .577 .707 r
F P
0 g
s
.50743 .834 m .50396 .81613 L .51514 .80438 L p .707 .577 .707 r
F P
0 g
s
.52357 .70223 m .52572 .64646 L .55092 .64238 L p .707 .577 .707 r
F P
0 g
s
.51001 .77466 m .50733 .73797 L .52665 .72924 L p .707 .577 .707 r
F P
0 g
s
.51514 .80438 m .5186 .82225 L .50743 .834 L p .707 .577 .707 r
F P
0 g
s
.52665 .72924 m .52933 .76593 L .51001 .77466 L p .707 .577 .707 r
F P
0 g
s
.55092 .64238 m .54877 .69815 L .52357 .70223 L p .707 .577 .707 r
F P
0 g
s
.52933 .76593 m .52665 .72924 L .55286 .72216 L p .707 .577 .707 r
F P
0 g
s
.5186 .82225 m .51514 .80438 L .53485 .79279 L p .707 .577 .707 r
F P
0 g
s
.53485 .79279 m .53831 .81066 L .5186 .82225 L p .707 .577 .707 r
F P
0 g
s
.55286 .72216 m .55554 .75885 L .52933 .76593 L p .707 .577 .707 r
F P
0 g
s
.53831 .81066 m .53485 .79279 L .56117 .78249 L p .707 .577 .707 r
F P
0 g
s
.56117 .78249 m .56463 .80036 L .53831 .81066 L p .707 .577 .707 r
F P
0 g
s
.49737 .32003 m .49737 .82192 L .54207 .82024 L p .707 .577 .707 r
F P
0 g
s
.54207 .82024 m .54207 .31835 L .49737 .32003 L p .707 .577 .707 r
F P
0 g
s
.54877 .69815 m .55092 .64238 L .58096 .6407 L p .707 .577 .707 r
F P
0 g
s
.58096 .6407 m .5788 .69647 L .54877 .69815 L p .707 .577 .707 r
F P
0 g
s
.55554 .75885 m .55286 .72216 L .58341 .71743 L p .707 .577 .707 r
F P
0 g
s
.58341 .71743 m .58609 .75412 L .55554 .75885 L p .707 .577 .707 r
F P
0 g
s
.56463 .80036 m .56117 .78249 L .59152 .7745 L p .707 .577 .707 r
F P
0 g
s
.59152 .7745 m .59498 .79237 L .56463 .80036 L p .707 .577 .707 r
F P
0 g
s
.54207 .31835 m .54207 .82024 L .58264 .81494 L p .707 .577 .707 r
F P
0 g
s
.5788 .69647 m .58096 .6407 L .61288 .64158 L p .707 .577 .707 r
F P
0 g
s
.61288 .64158 m .61073 .69735 L .5788 .69647 L p .707 .577 .707 r
F P
0 g
s
.58264 .81494 m .58264 .31305 L .54207 .31835 L p .707 .577 .707 r
F P
0 g
s
.45293 .8198 m .45293 .31792 L .4131 .31222 L p .707 .577 .707 r
F P
0 g
s
.45293 .31792 m .45293 .8198 L .49737 .82192 L p .707 .577 .707 r
F P
0 g
s
.70071 .79588 m .70418 .81375 L .70572 .80299 L p .707 .577 .707 r
F P
0 g
s
.70572 .80299 m .70226 .78512 L .70071 .79588 L p .707 .577 .707 r
F P
0 g
s
.70055 .66559 m .6984 .72136 L .68752 .71333 L p .707 .577 .707 r
F P
0 g
s
.68752 .71333 m .68967 .65756 L .70055 .66559 L p .707 .577 .707 r
F P
0 g
s
.61529 .71551 m .61797 .7522 L .58609 .75412 L p .707 .577 .707 r
F P
0 g
s
.58609 .75412 m .58341 .71743 L .61529 .71551 L p .707 .577 .707 r
F P
0 g
s
.62292 .76959 m .62638 .78746 L .59498 .79237 L p .707 .577 .707 r
F P
0 g
s
.59498 .79237 m .59152 .7745 L .62292 .76959 L p .707 .577 .707 r
F P
0 g
s
.58264 .31305 m .58264 .81494 L .61513 .80653 L p .707 .577 .707 r
F P
0 g
s
.64358 .64494 m .64143 .7007 L .61073 .69735 L p .707 .577 .707 r
F P
0 g
s
.61073 .69735 m .61288 .64158 L .64358 .64494 L p .707 .577 .707 r
F P
0 g
s
.61513 .80653 m .61513 .30465 L .58264 .31305 L p .707 .577 .707 r
F P
0 g
s
.69808 .73539 m .70076 .77208 L .69159 .76373 L p .707 .577 .707 r
F P
0 g
s
.69159 .76373 m .68891 .72704 L .69808 .73539 L p .707 .577 .707 r
F P
0 g
s
.4131 .81411 m .4131 .31222 L .38178 .30351 L p .707 .577 .707 r
F P
0 g
s
.4131 .31222 m .4131 .81411 L .45293 .8198 L p .707 .577 .707 r
F P
0 g
s
.2453 .71487 m .2462 .65995 L .21549 .65678 L p .707 .577 .707 r
F P
0 g
s
.2462 .65995 m .2453 .71487 L .27725 .71501 L p .707 .577 .707 r
F P
0 g
s
.27725 .71501 m .27815 .66009 L .2462 .65995 L p .707 .577 .707 r
F P
0 g
s
.27815 .66009 m .27725 .71501 L .3073 .71212 L p .707 .577 .707 r
F P
0 g
s
.3073 .71212 m .3082 .6572 L .27815 .66009 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70226 .78512 m .70572 .80299 L .69749 .79428 L p .707 .577 .707 r
F P
0 g
s
.69749 .79428 m .69403 .77641 L .70226 .78512 L p .707 .577 .707 r
F P
0 g
s
.21459 .7117 m .21549 .65678 L .18901 .65091 L p .707 .577 .707 r
F P
0 g
s
.21549 .65678 m .21459 .7117 L .2453 .71487 L p .707 .577 .707 r
F P
0 g
s
.68967 .65756 m .68752 .71333 L .66788 .70621 L p .707 .577 .707 r
F P
0 g
s
.66788 .70621 m .67004 .65045 L .68967 .65756 L p .707 .577 .707 r
F P
0 g
s
.3082 .6572 m .3073 .71212 L .3325 .70648 L p .707 .577 .707 r
F P
0 g
s
.3325 .70648 m .33341 .65156 L .3082 .6572 L p .707 .577 .707 r
F P
0 g
s
.64539 .71659 m .64807 .75328 L .61797 .7522 L p .707 .577 .707 r
F P
0 g
s
.61797 .7522 m .61529 .71551 L .64539 .71659 L p .707 .577 .707 r
F P
0 g
s
.65232 .76824 m .65578 .78611 L .62638 .78746 L p .707 .577 .707 r
F P
0 g
s
.62638 .78746 m .62292 .76959 L .65232 .76824 L p .707 .577 .707 r
F P
0 g
s
.61513 .30465 m .61513 .80653 L .63635 .79585 L p .707 .577 .707 r
F P
0 g
s
.63635 .79585 m .63635 .29396 L .61513 .30465 L p .707 .577 .707 r
F P
0 g
s
.68891 .72704 m .69159 .76373 L .67344 .75726 L p .707 .577 .707 r
F P
0 g
s
.67344 .75726 m .67076 .72056 L .68891 .72704 L p .707 .577 .707 r
F P
0 g
s
.27232 .76391 m .27123 .72618 L .23928 .72694 L p .707 .577 .707 r
F P
0 g
s
.27123 .72618 m .27232 .76391 L .30292 .76128 L p .707 .577 .707 r
F P
0 g
s
.30292 .76128 m .30182 .72355 L .27123 .72618 L p .707 .577 .707 r
F P
0 g
s
.24038 .76467 m .23928 .72694 L .20911 .72575 L p .707 .577 .707 r
F P
0 g
s
.23928 .72694 m .24038 .76467 L .27232 .76391 L p .707 .577 .707 r
F P
0 g
s
.38178 .80539 m .38178 .30351 L .36202 .29262 L p .707 .577 .707 r
F P
0 g
s
.38178 .30351 m .38178 .80539 L .4131 .81411 L p .707 .577 .707 r
F P
0 g
s
.18811 .70583 m .18901 .65091 L .16936 .64289 L p .707 .577 .707 r
F P
0 g
s
.18901 .65091 m .18811 .70583 L .21459 .7117 L p .707 .577 .707 r
F P
0 g
s
.33341 .65156 m .3325 .70648 L .35041 .69864 L p .707 .577 .707 r
F P
0 g
s
.35041 .69864 m .35131 .64372 L .33341 .65156 L p .707 .577 .707 r
F P
0 g
s
.20911 .72575 m .2102 .76349 L .24038 .76467 L p .707 .577 .707 r
F P
0 g
s
.30182 .72355 m .30292 .76128 L .32917 .75705 L p .707 .577 .707 r
F P
0 g
s
.32917 .75705 m .32807 .71931 L .30182 .72355 L p .707 .577 .707 r
F P
0 g
s
.27286 .79383 m .27146 .77469 L .2396 .77694 L p .707 .577 .707 r
F P
0 g
s
.27146 .77469 m .27286 .79383 L .30356 .79103 L p .707 .577 .707 r
F P
0 g
s
.30356 .79103 m .30216 .77189 L .27146 .77469 L p .707 .577 .707 r
F P
0 g
s
.2396 .77694 m .24101 .79608 L .27286 .79383 L p .707 .577 .707 r
F P
0 g
s
.67004 .65045 m .66788 .70621 L .64143 .7007 L p .707 .577 .707 r
F P
0 g
s
.64143 .7007 m .64358 .64494 L .67004 .65045 L p .707 .577 .707 r
F P
0 g
s
.2102 .76349 m .20911 .72575 L .18367 .72274 L p .707 .577 .707 r
F P
0 g
s
.24101 .79608 m .2396 .77694 L .20971 .77841 L p .707 .577 .707 r
F P
0 g
s
.69403 .77641 m .69749 .79428 L .68028 .78846 L p .707 .577 .707 r
F P
0 g
s
.68028 .78846 m .67682 .77059 L .69403 .77641 L p .707 .577 .707 r
F P
0 g
s
.20971 .77841 m .21112 .79755 L .24101 .79608 L p .707 .577 .707 r
F P
0 g
s
.30216 .77189 m .30356 .79103 L .33011 .78795 L p .707 .577 .707 r
F P
0 g
s
.33011 .78795 m .3287 .7688 L .30216 .77189 L p .707 .577 .707 r
F P
0 g
s
.18367 .72274 m .18476 .76047 L .2102 .76349 L p .707 .577 .707 r
F P
0 g
s
.16936 .64289 m .16846 .69781 L .18811 .70583 L p .707 .577 .707 r
F P
0 g
s
.21112 .79755 m .20971 .77841 L .18472 .77896 L p .707 .577 .707 r
F P
0 g
s
.18472 .77896 m .18612 .7981 L .21112 .79755 L p .707 .577 .707 r
F P
0 g
s
.67076 .72056 m .67344 .75726 L .64807 .75328 L p .707 .577 .707 r
F P
0 g
s
.64807 .75328 m .64539 .71659 L .67076 .72056 L p .707 .577 .707 r
F P
0 g
s
.16846 .69781 m .16936 .64289 L .15846 .63353 L p .707 .577 .707 r
F P
0 g
s
.32807 .71931 m .32917 .75705 L .3485 .75161 L p .707 .577 .707 r
F P
0 g
s
.3485 .75161 m .34741 .71388 L .32807 .71931 L p .707 .577 .707 r
F P
0 g
s
.18476 .76047 m .18367 .72274 L .16545 .7182 L p .707 .577 .707 r
F P
0 g
s
.35131 .64372 m .35041 .69864 L .35925 .68936 L p .707 .577 .707 r
F P
0 g
s
.35925 .68936 m .36015 .63444 L .35131 .64372 L p .707 .577 .707 r
F P
0 g
s
.3287 .7688 m .33011 .78795 L .3499 .78488 L p .707 .577 .707 r
F P
0 g
s
.3499 .78488 m .34849 .76574 L .3287 .7688 L p .707 .577 .707 r
F P
0 g
s
.63635 .29396 m .63635 .79585 L .64422 .78392 L p .707 .577 .707 r
F P
0 g
s
.64422 .78392 m .64422 .28203 L .63635 .29396 L p .707 .577 .707 r
F P
0 g
s
.16545 .7182 m .16654 .75593 L .18476 .76047 L p .707 .577 .707 r
F P
0 g
s
.67682 .77059 m .68028 .78846 L .65578 .78611 L p .707 .577 .707 r
F P
0 g
s
.65578 .78611 m .65232 .76824 L .67682 .77059 L p .707 .577 .707 r
F P
0 g
s
.36015 .63444 m .35925 .68936 L .35817 .67956 L p .707 .577 .707 r
F P
0 g
s
.35817 .67956 m .35907 .62464 L .36015 .63444 L p .707 .577 .707 r
F P
0 g
s
.35959 .76299 m .361 .78213 L .36231 .77997 L p .707 .577 .707 r
F P
0 g
s
.36231 .77997 m .36091 .76083 L .35959 .76299 L p .707 .577 .707 r
F P
0 g
s
.34849 .76574 m .3499 .78488 L .361 .78213 L p .707 .577 .707 r
F P
0 g
s
.361 .78213 m .35959 .76299 L .34849 .76574 L p .707 .577 .707 r
F P
0 g
s
.36091 .76083 m .36231 .77997 L .35372 .77861 L p .707 .577 .707 r
F P
0 g
s
.36202 .79451 m .36202 .29262 L .35578 .28062 L p .707 .577 .707 r
F P
0 g
s
.36202 .29262 m .36202 .79451 L .38178 .80539 L p .707 .577 .707 r
F P
0 g
s
.18612 .7981 m .18472 .77896 L .16706 .77853 L p .707 .577 .707 r
F P
0 g
s
.16706 .77853 m .16847 .79767 L .18612 .7981 L p .707 .577 .707 r
F P
0 g
s
.15846 .63353 m .15756 .68845 L .16846 .69781 L p .707 .577 .707 r
F P
0 g
s
.34741 .71388 m .3485 .75161 L .35902 .74551 L p .707 .577 .707 r
F P
0 g
s
.35902 .74551 m .35793 .70778 L .34741 .71388 L p .707 .577 .707 r
F P
0 g
s
.15756 .68845 m .15846 .63353 L .15738 .62373 L p .707 .577 .707 r
F P
0 g
s
.16654 .75593 m .16545 .7182 L .15623 .71257 L p .707 .577 .707 r
F P
0 g
s
.15623 .71257 m .15732 .7503 L .16654 .75593 L p .707 .577 .707 r
F P
0 g
s
.16847 .79767 m .16706 .77853 L .15847 .77717 L p .707 .577 .707 r
F P
0 g
s
.15847 .77717 m .15988 .79631 L .16847 .79767 L p .707 .577 .707 r
F P
0 g
s
.15738 .62373 m .15648 .67865 L .15756 .68845 L p .707 .577 .707 r
F P
0 g
s
.64422 .28203 m .64422 .78392 L .63797 .77193 L p .707 .577 .707 r
F P
0 g
s
.63797 .77193 m .63797 .27004 L .64422 .28203 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35793 .70778 m .35902 .74551 L .35971 .73934 L p .707 .577 .707 r
F P
0 g
s
.35971 .73934 m .35862 .70161 L .35793 .70778 L p .707 .577 .707 r
F P
0 g
s
.35907 .62464 m .35817 .67956 L .34727 .6702 L p .707 .577 .707 r
F P
0 g
s
.34727 .6702 m .34817 .61528 L .35907 .62464 L p .707 .577 .707 r
F P
0 g
s
.35862 .70161 m .35971 .73934 L .35049 .73371 L p .707 .577 .707 r
F P
0 g
s
.35049 .73371 m .3494 .69598 L .35862 .70161 L p .707 .577 .707 r
F P
0 g
s
.35372 .77861 m .35232 .75947 L .36091 .76083 L p .707 .577 .707 r
F P
0 g
s
.35578 .28062 m .35578 .78251 L .36202 .79451 L p .707 .577 .707 r
F P
0 g
s
.35578 .78251 m .35578 .28062 L .36365 .2687 L p .707 .577 .707 r
F P
0 g
s
.15648 .67865 m .15738 .62373 L .16623 .61446 L p .707 .577 .707 r
F P
0 g
s
.15732 .7503 m .15623 .71257 L .15691 .7064 L p .707 .577 .707 r
F P
0 g
s
.15691 .7064 m .15801 .74413 L .15732 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15988 .79631 m .15847 .77717 L .15979 .77501 L p .707 .577 .707 r
F P
0 g
s
.15979 .77501 m .1612 .79415 L .15988 .79631 L p .707 .577 .707 r
F P
0 g
s
.16623 .61446 m .16532 .66938 L .15648 .67865 L p .707 .577 .707 r
F P
0 g
s
.16532 .66938 m .16623 .61446 L .18413 .60662 L p .707 .577 .707 r
F P
0 g
s
.15801 .74413 m .15691 .7064 L .16744 .7003 L p .707 .577 .707 r
F P
0 g
s
.34817 .61528 m .34727 .6702 L .32762 .66219 L p .707 .577 .707 r
F P
0 g
s
.32762 .66219 m .32852 .60727 L .34817 .61528 L p .707 .577 .707 r
F P
0 g
s
.63797 .27004 m .63797 .77193 L .61822 .76104 L p .707 .577 .707 r
F P
0 g
s
.61822 .76104 m .61822 .25915 L .63797 .27004 L p .707 .577 .707 r
F P
0 g
s
.16744 .7003 m .16853 .73803 L .15801 .74413 L p .707 .577 .707 r
F P
0 g
s
.36365 .77059 m .36365 .2687 L .38487 .25801 L p .707 .577 .707 r
F P
0 g
s
.36365 .2687 m .36365 .77059 L .35578 .78251 L p .707 .577 .707 r
F P
0 g
s
.1612 .79415 m .15979 .77501 L .17089 .77226 L p .707 .577 .707 r
F P
0 g
s
.18413 .60662 m .18323 .66154 L .16532 .66938 L p .707 .577 .707 r
F P
0 g
s
.17089 .77226 m .17229 .79141 L .1612 .79415 L p .707 .577 .707 r
F P
0 g
s
.18323 .66154 m .18413 .60662 L .20934 .60097 L p .707 .577 .707 r
F P
0 g
s
.3494 .69598 m .35049 .73371 L .33227 .72917 L p .707 .577 .707 r
F P
0 g
s
.33227 .72917 m .33118 .69144 L .3494 .69598 L p .707 .577 .707 r
F P
0 g
s
.32852 .60727 m .32762 .66219 L .30114 .65631 L p .707 .577 .707 r
F P
0 g
s
.30114 .65631 m .30204 .60139 L .32852 .60727 L p .707 .577 .707 r
F P
0 g
s
.16853 .73803 m .16744 .7003 L .18677 .69487 L p .707 .577 .707 r
F P
0 g
s
.35232 .75947 m .35372 .77861 L .33607 .77819 L p .707 .577 .707 r
F P
0 g
s
.33607 .77819 m .33466 .75905 L .35232 .75947 L p .707 .577 .707 r
F P
0 g
s
.18677 .69487 m .18787 .7326 L .16853 .73803 L p .707 .577 .707 r
F P
0 g
s
.20934 .60097 m .20844 .65589 L .18323 .66154 L p .707 .577 .707 r
F P
0 g
s
.20844 .65589 m .20934 .60097 L .23938 .59808 L p .707 .577 .707 r
F P
0 g
s
.61822 .25915 m .61822 .76104 L .5869 .75232 L p .707 .577 .707 r
F P
0 g
s
.5869 .75232 m .5869 .25044 L .61822 .25915 L p .707 .577 .707 r
F P
0 g
s
.17229 .79141 m .17089 .77226 L .19068 .7692 L p .707 .577 .707 r
F P
0 g
s
.30204 .60139 m .30114 .65631 L .27043 .65315 L p .707 .577 .707 r
F P
0 g
s
.27043 .65315 m .27133 .59823 L .30204 .60139 L p .707 .577 .707 r
F P
0 g
s
.19068 .7692 m .19208 .78834 L .17229 .79141 L p .707 .577 .707 r
F P
0 g
s
.38487 .25801 m .38487 .7599 L .36365 .77059 L p .707 .577 .707 r
F P
0 g
s
.38487 .7599 m .38487 .25801 L .41735 .24961 L p .707 .577 .707 r
F P
0 g
s
.33118 .69144 m .33227 .72917 L .30683 .72616 L p .707 .577 .707 r
F P
0 g
s
.30683 .72616 m .30573 .68843 L .33118 .69144 L p .707 .577 .707 r
F P
0 g
s
.72957 .65489 m .72867 .59874 L .69795 .59718 L p .707 .577 .707 r
F P
0 g
s
.72867 .59874 m .72957 .65489 L .76151 .65415 L p .707 .577 .707 r
F P
0 g
s
.76151 .65415 m .76061 .59801 L .72867 .59874 L p .707 .577 .707 r
F P
0 g
s
.23848 .653 m .23938 .59808 L .27133 .59823 L p .707 .577 .707 r
F P
0 g
s
.23938 .59808 m .23848 .653 L .20844 .65589 L p .707 .577 .707 r
F P
0 g
s
.76061 .59801 m .76151 .65415 L .79156 .65119 L p .707 .577 .707 r
F P
0 g
s
.79156 .65119 m .79066 .59504 L .76061 .59801 L p .707 .577 .707 r
F P
0 g
s
.27133 .59823 m .27043 .65315 L .23848 .653 L p .707 .577 .707 r
F P
0 g
s
.18787 .7326 m .18677 .69487 L .21302 .69063 L p .707 .577 .707 r
F P
0 g
s
.69885 .65332 m .69795 .59718 L .67147 .59346 L p .707 .577 .707 r
F P
0 g
s
.69795 .59718 m .69885 .65332 L .72957 .65489 L p .707 .577 .707 r
F P
0 g
s
.21302 .69063 m .21411 .72836 L .18787 .7326 L p .707 .577 .707 r
F P
0 g
s
.33466 .75905 m .33607 .77819 L .31107 .77874 L p .707 .577 .707 r
F P
0 g
s
.31107 .77874 m .30967 .7596 L .33466 .75905 L p .707 .577 .707 r
F P
0 g
s
.79066 .59504 m .79156 .65119 L .81677 .64628 L p .707 .577 .707 r
F P
0 g
s
.81677 .64628 m .81587 .59014 L .79066 .59504 L p .707 .577 .707 r
F P
0 g
s
.19208 .78834 m .19068 .7692 L .21722 .76611 L p .707 .577 .707 r
F P
0 g
s
.30573 .68843 m .30683 .72616 L .27666 .72497 L p .707 .577 .707 r
F P
0 g
s
.27666 .72497 m .27556 .68724 L .30573 .68843 L p .707 .577 .707 r
F P
0 g
s
.21722 .76611 m .21863 .78525 L .19208 .78834 L p .707 .577 .707 r
F P
0 g
s
.21411 .72836 m .21302 .69063 L .24362 .688 L p .707 .577 .707 r
F P
0 g
s
.67147 .59346 m .67238 .6496 L .69885 .65332 L p .707 .577 .707 r
F P
0 g
s
.75529 .72626 m .75638 .69014 L .72443 .68905 L p .707 .577 .707 r
F P
0 g
s
.75638 .69014 m .75529 .72626 L .78588 .72391 L p .707 .577 .707 r
F P
0 g
s
.78588 .72391 m .78698 .68779 L .75638 .69014 L p .707 .577 .707 r
F P
0 g
s
.72334 .72517 m .72443 .68905 L .69426 .68463 L p .707 .577 .707 r
F P
0 g
s
.72443 .68905 m .72334 .72517 L .75529 .72626 L p .707 .577 .707 r
F P
0 g
s
.5869 .25044 m .5869 .75232 L .54706 .74663 L p .707 .577 .707 r
F P
0 g
s
.54706 .74663 m .54706 .24474 L .5869 .25044 L p .707 .577 .707 r
F P
0 g
s
.67238 .6496 m .67147 .59346 L .65182 .58796 L p .707 .577 .707 r
F P
0 g
s
.41735 .7515 m .41735 .24961 L .45793 .24431 L p .707 .577 .707 r
F P
0 g
s
.41735 .24961 m .41735 .7515 L .38487 .7599 L p .707 .577 .707 r
F P
0 g
s
.24362 .688 m .24471 .72573 L .21411 .72836 L p .707 .577 .707 r
F P
0 g
s
.27556 .68724 m .27666 .72497 L .24471 .72573 L p .707 .577 .707 r
F P
0 g
s
.24471 .72573 m .24362 .688 L .27556 .68724 L p .707 .577 .707 r
F P
0 g
s
.81587 .59014 m .81677 .64628 L .83467 .63992 L p .707 .577 .707 r
F P
0 g
s
.83467 .63992 m .83377 .58378 L .81587 .59014 L p .707 .577 .707 r
F P
0 g
s
.30967 .7596 m .31107 .77874 L .28118 .78021 L p .707 .577 .707 r
F P
0 g
s
.28118 .78021 m .27978 .76106 L .30967 .7596 L p .707 .577 .707 r
F P
0 g
s
.78698 .68779 m .78588 .72391 L .81213 .71837 L p .707 .577 .707 r
F P
0 g
s
.81213 .71837 m .81323 .68225 L .78698 .68779 L p .707 .577 .707 r
F P
0 g
s
.69317 .72076 m .69426 .68463 L .66882 .67733 L p .707 .577 .707 r
F P
0 g
s
.69426 .68463 m .69317 .72076 L .72334 .72517 L p .707 .577 .707 r
F P
0 g
s
.21863 .78525 m .21722 .76611 L .24792 .76331 L p .707 .577 .707 r
F P
0 g
s
.24792 .76331 m .24933 .78245 L .21863 .78525 L p .707 .577 .707 r
F P
0 g
s
.65182 .58796 m .65272 .6441 L .67238 .6496 L p .707 .577 .707 r
F P
0 g
s
.27978 .76106 m .28118 .78021 L .24933 .78245 L p .707 .577 .707 r
F P
0 g
s
.24933 .78245 m .24792 .76331 L .27978 .76106 L p .707 .577 .707 r
F P
0 g
s
.54706 .24474 m .54706 .74663 L .50263 .74452 L p .707 .577 .707 r
F P
0 g
s
.50263 .74452 m .50263 .24263 L .54706 .24474 L p .707 .577 .707 r
F P
0 g
s
.66882 .67733 m .66773 .71345 L .69317 .72076 L p .707 .577 .707 r
F P
0 g
s
.45793 .7462 m .45793 .24431 L .50263 .24263 L p .707 .577 .707 r
F P
0 g
s
.45793 .24431 m .45793 .7462 L .41735 .7515 L p .707 .577 .707 r
F P
0 g
s
.81323 .68225 m .81213 .71837 L .83147 .71016 L p .707 .577 .707 r
F P
0 g
s
.83147 .71016 m .83256 .67404 L .81323 .68225 L p .707 .577 .707 r
F P
0 g
s
.75067 .77875 m .75207 .76172 L .72022 .75904 L p .707 .577 .707 r
F P
0 g
s
.75207 .76172 m .75067 .77875 L .78137 .77678 L p .707 .577 .707 r
F P
0 g
s
.78137 .77678 m .78278 .75976 L .75207 .76172 L p .707 .577 .707 r
F P
0 g
s
.71881 .77607 m .72022 .75904 L .69033 .75197 L p .707 .577 .707 r
F P
0 g
s
.72022 .75904 m .71881 .77607 L .75067 .77875 L p .707 .577 .707 r
F P
0 g
s
.66773 .71345 m .66882 .67733 L .6506 .66784 L p .707 .577 .707 r
F P
0 g
s
.65272 .6441 m .65182 .58796 L .64092 .58121 L p .707 .577 .707 r
F P
0 g
s
.50263 .24263 m .50263 .74452 L .45793 .7462 L p .707 .577 .707 r
F P
0 g
s
.83377 .58378 m .83467 .63992 L .84352 .63272 L p .707 .577 .707 r
F P
0 g
s
.84352 .63272 m .84262 .57657 L .83377 .58378 L p .707 .577 .707 r
F P
0 g
s
.78278 .75976 m .78137 .77678 L .80792 .77035 L p .707 .577 .707 r
F P
0 g
s
.80792 .77035 m .80932 .75333 L .78278 .75976 L p .707 .577 .707 r
F P
0 g
s
.69033 .75197 m .68893 .769 L .71881 .77607 L p .707 .577 .707 r
F P
0 g
s
.68893 .769 m .69033 .75197 L .66534 .7412 L p .707 .577 .707 r
F P
0 g
s
.6506 .66784 m .64951 .70397 L .66773 .71345 L p .707 .577 .707 r
F P
0 g
s
.64092 .58121 m .64183 .63735 L .65272 .6441 L p .707 .577 .707 r
F P
0 g
s
.66534 .7412 m .66393 .75823 L .68893 .769 L p .707 .577 .707 r
F P
0 g
s
.83256 .67404 m .83147 .71016 L .84199 .7001 L p .707 .577 .707 r
F P
0 g
s
.84199 .7001 m .84308 .66398 L .83256 .67404 L p .707 .577 .707 r
F P
0 g
s
.64951 .70397 m .6506 .66784 L .64138 .65711 L p .707 .577 .707 r
F P
0 g
s
.80932 .75333 m .80792 .77035 L .82771 .7601 L p .707 .577 .707 r
F P
0 g
s
.82771 .7601 m .82911 .74307 L .80932 .75333 L p .707 .577 .707 r
F P
0 g
s
.66393 .75823 m .66534 .7412 L .64768 .72779 L p .707 .577 .707 r
F P
0 g
s
.64183 .63735 m .64092 .58121 L .63984 .57388 L p .707 .578 .707 r
F P
0 g
s
.64768 .72779 m .64627 .74482 L .66393 .75823 L p .707 .577 .707 r
F P
0 g
s
.84262 .57657 m .84352 .63272 L .84244 .62538 L p .707 .578 .707 r
F P
0 g
s
.84244 .62538 m .84154 .56924 L .84262 .57657 L p .707 .578 .707 r
F P
0 g
s
.64138 .65711 m .64029 .69323 L .64951 .70397 L p .707 .577 .707 r
F P
0 g
s
.63984 .57388 m .64075 .63002 L .64183 .63735 L p .707 .578 .707 r
F P
0 g
s
.82911 .74307 m .82771 .7601 L .8388 .74702 L p .707 .577 .707 r
F P
0 g
s
.8388 .74702 m .84021 .72999 L .82911 .74307 L p .707 .577 .707 r
F P
0 g
s
.64627 .74482 m .64768 .72779 L .63909 .71306 L p .707 .577 .707 r
F P
0 g
s
.84308 .66398 m .84199 .7001 L .84268 .68917 L p .707 .577 .707 r
F P
0 g
s
.84268 .68917 m .84377 .65305 L .84308 .66398 L p .707 .577 .707 r
F P
0 g
s
.64029 .69323 m .64138 .65711 L .64207 .64618 L p .707 .577 .707 r
F P
0 g
s
.63909 .71306 m .63768 .73008 L .64627 .74482 L p .707 .577 .707 r
F P
0 g
s
.64075 .63002 m .63984 .57388 L .64869 .56668 L p .707 .577 .707 r
F P
0 g
s
.64207 .64618 m .64097 .6823 L .64029 .69323 L p .707 .577 .707 r
F P
0 g
s
.84154 .56924 m .84244 .62538 L .83154 .61864 L p .707 .577 .707 r
F P
0 g
s
.83154 .61864 m .83064 .56249 L .84154 .56924 L p .707 .577 .707 r
F P
0 g
s
.64869 .56668 m .64959 .62282 L .64075 .63002 L p .707 .577 .707 r
F P
0 g
s
.84021 .72999 m .8388 .74702 L .84012 .73239 L p .705 .576 .707 r
F P
0 g
s
.84012 .73239 m .84153 .71536 L .84021 .72999 L p .705 .576 .707 r
F P
0 g
s
.63768 .73008 m .63909 .71306 L .64041 .69843 L p .705 .576 .707 r
F P
0 g
s
.84377 .65305 m .84268 .68917 L .83346 .67844 L p .707 .577 .707 r
F P
0 g
s
.83346 .67844 m .83455 .64231 L .84377 .65305 L p .707 .577 .707 r
F P
0 g
s
.64097 .6823 m .64207 .64618 L .65259 .63612 L p .707 .577 .707 r
F P
0 g
s
.64041 .69843 m .639 .71545 L .63768 .73008 L p .705 .576 .707 r
F P
0 g
s
.38927 .62182 m .38711 .56651 L .35642 .56511 L p .707 .577 .707 r
F P
0 g
s
.38711 .56651 m .38927 .62182 L .42119 .62038 L p .707 .577 .707 r
F P
0 g
s
.42119 .62038 m .41904 .56507 L .38711 .56651 L p .707 .577 .707 r
F P
0 g
s
.41904 .56507 m .42119 .62038 L .45123 .61622 L p .707 .577 .707 r
F P
0 g
s
.45123 .61622 m .44907 .56091 L .41904 .56507 L p .707 .577 .707 r
F P
0 g
s
.64959 .62282 m .64869 .56668 L .66659 .56031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35857 .62042 m .35642 .56511 L .32996 .561 L p .707 .577 .707 r
F P
0 g
s
.35642 .56511 m .35857 .62042 L .38927 .62182 L p .707 .577 .707 r
F P
0 g
s
.83064 .56249 m .83154 .61864 L .81189 .61314 L p .707 .577 .707 r
F P
0 g
s
.81189 .61314 m .81099 .55699 L .83064 .56249 L p .707 .577 .707 r
F P
0 g
s
.65259 .63612 m .6515 .67224 L .64097 .6823 L p .707 .577 .707 r
F P
0 g
s
.44907 .56091 m .45123 .61622 L .47643 .60977 L p .707 .577 .707 r
F P
0 g
s
.47643 .60977 m .47427 .55446 L .44907 .56091 L p .707 .577 .707 r
F P
0 g
s
.84153 .71536 m .84012 .73239 L .83153 .71765 L p .707 .577 .707 r
F P
0 g
s
.83153 .71765 m .83294 .70062 L .84153 .71536 L p .707 .577 .707 r
F P
0 g
s
.639 .71545 m .64041 .69843 L .65151 .68535 L p .707 .577 .707 r
F P
0 g
s
.66659 .56031 m .66749 .61645 L .64959 .62282 L p .707 .577 .707 r
F P
0 g
s
.41391 .67883 m .41659 .64161 L .38471 .63928 L p .707 .577 .707 r
F P
0 g
s
.41659 .64161 m .41391 .67883 L .44445 .67866 L p .707 .577 .707 r
F P
0 g
s
.44445 .67866 m .44713 .64144 L .41659 .64161 L p .707 .577 .707 r
F P
0 g
s
.38203 .67649 m .38471 .63928 L .35461 .63466 L p .707 .577 .707 r
F P
0 g
s
.38471 .63928 m .38203 .67649 L .41391 .67883 L p .707 .577 .707 r
F P
0 g
s
.83455 .64231 m .83346 .67844 L .81524 .66895 L p .707 .577 .707 r
F P
0 g
s
.81524 .66895 m .81633 .63283 L .83455 .64231 L p .707 .577 .707 r
F P
0 g
s
.6515 .67224 m .65259 .63612 L .67192 .62791 L p .707 .577 .707 r
F P
0 g
s
.32996 .561 m .33211 .61631 L .35857 .62042 L p .707 .577 .707 r
F P
0 g
s
.65151 .68535 m .6501 .70237 L .639 .71545 L p .707 .577 .707 r
F P
0 g
s
.33211 .61631 m .32996 .561 L .31033 .55458 L p .707 .577 .707 r
F P
0 g
s
.47427 .55446 m .47643 .60977 L .49433 .60165 L p .707 .577 .707 r
F P
0 g
s
.49433 .60165 m .49217 .54634 L .47427 .55446 L p .707 .577 .707 r
F P
0 g
s
.66749 .61645 m .66659 .56031 L .6918 .55541 L p .707 .577 .707 r
F P
0 g
s
.44713 .64144 m .44445 .67866 L .47067 .67599 L p .707 .577 .707 r
F P
0 g
s
.47067 .67599 m .47335 .63878 L .44713 .64144 L p .707 .577 .707 r
F P
0 g
s
.35461 .63466 m .35193 .67188 L .38203 .67649 L p .707 .577 .707 r
F P
0 g
s
.35193 .67188 m .35461 .63466 L .32924 .62822 L p .707 .577 .707 r
F P
0 g
s
.81099 .55699 m .81189 .61314 L .78541 .60942 L p .707 .577 .707 r
F P
0 g
s
.78541 .60942 m .78451 .55328 L .81099 .55699 L p .707 .577 .707 r
F P
0 g
s
.40502 .71857 m .40848 .70007 L .37707 .69412 L p .707 .577 .707 r
F P
0 g
s
.40848 .70007 m .40502 .71857 L .43537 .72227 L p .707 .577 .707 r
F P
0 g
s
.43537 .72227 m .43883 .70376 L .40848 .70007 L p .707 .577 .707 r
F P
0 g
s
.37361 .71263 m .37707 .69412 L .34768 .68651 L p .707 .577 .707 r
F P
0 g
s
.37707 .69412 m .37361 .71263 L .40502 .71857 L p .707 .577 .707 r
F P
0 g
s
.67192 .62791 m .67083 .66403 L .6515 .67224 L p .707 .577 .707 r
F P
0 g
s
.34768 .68651 m .34422 .70501 L .37361 .71263 L p .707 .577 .707 r
F P
0 g
s
.32924 .62822 m .32656 .66543 L .35193 .67188 L p .707 .577 .707 r
F P
0 g
s
.31033 .55458 m .31248 .60989 L .33211 .61631 L p .707 .577 .707 r
F P
0 g
s
.6918 .55541 m .6927 .61155 L .66749 .61645 L p .707 .577 .707 r
F P
0 g
s
.83294 .70062 m .83153 .71765 L .81387 .70424 L p .707 .577 .707 r
F P
0 g
s
.81387 .70424 m .81528 .68721 L .83294 .70062 L p .707 .577 .707 r
F P
0 g
s
.6501 .70237 m .65151 .68535 L .67129 .67509 L p .707 .577 .707 r
F P
0 g
s
.43883 .70376 m .43537 .72227 L .46168 .72336 L p .707 .577 .707 r
F P
0 g
s
.46168 .72336 m .46515 .70485 L .43883 .70376 L p .707 .577 .707 r
F P
0 g
s
.34422 .70501 m .34768 .68651 L .32318 .67797 L p .707 .577 .707 r
F P
0 g
s
.81633 .63283 m .81524 .66895 L .78979 .66165 L p .707 .577 .707 r
F P
0 g
s
.78979 .66165 m .79089 .62552 L .81633 .63283 L p .707 .577 .707 r
F P
0 g
s
.6927 .61155 m .6918 .55541 L .72185 .55244 L p .707 .577 .707 r
F P
0 g
s
.67083 .66403 m .67192 .62791 L .69817 .62237 L p .707 .577 .707 r
F P
0 g
s
.47335 .63878 m .47067 .67599 L .48999 .6711 L p .707 .577 .707 r
F P
0 g
s
.48999 .6711 m .49267 .63389 L .47335 .63878 L p .707 .577 .707 r
F P
0 g
s
.32318 .67797 m .31972 .69648 L .34422 .70501 L p .707 .577 .707 r
F P
0 g
s
.32656 .66543 m .32924 .62822 L .31108 .62058 L p .707 .577 .707 r
F P
0 g
s
.31248 .60989 m .31033 .55458 L .29944 .54648 L p .707 .577 .707 r
F P
0 g
s
.78451 .55328 m .78541 .60942 L .7547 .60785 L p .707 .577 .707 r
F P
0 g
s
.7547 .60785 m .75379 .55171 L .78451 .55328 L p .707 .577 .707 r
F P
0 g
s
.67129 .67509 m .66989 .69212 L .6501 .70237 L p .707 .577 .707 r
F P
0 g
s
.49217 .54634 m .49433 .60165 L .50317 .59265 L p .707 .577 .707 r
F P
0 g
s
.50317 .59265 m .50102 .53734 L .49217 .54634 L p .707 .577 .707 r
F P
0 g
s
.72275 .60859 m .72185 .55244 L .75379 .55171 L p .707 .577 .707 r
F P
0 g
s
.72185 .55244 m .72275 .60859 L .6927 .61155 L p .707 .577 .707 r
F P
0 g
s
.31108 .62058 m .3084 .6578 L .32656 .66543 L p .707 .577 .707 r
F P
0 g
s
.75379 .55171 m .7547 .60785 L .72275 .60859 L p .707 .577 .707 r
F P
0 g
s
.69817 .62237 m .69708 .65849 L .67083 .66403 L p .707 .577 .707 r
F P
0 g
s
.46515 .70485 m .46168 .72336 L .4814 .72173 L p .707 .577 .707 r
F P
0 g
s
.4814 .72173 m .48486 .70323 L .46515 .70485 L p .707 .577 .707 r
F P
0 g
s
.31972 .69648 m .32318 .67797 L .30597 .66935 L p .707 .577 .707 r
F P
0 g
s
.79089 .62552 m .78979 .66165 L .75962 .65723 L p .707 .577 .707 r
F P
0 g
s
.75962 .65723 m .76072 .62111 L .79089 .62552 L p .707 .577 .707 r
F P
0 g
s
.81528 .68721 m .81387 .70424 L .78888 .69347 L p .707 .577 .707 r
F P
0 g
s
.78888 .69347 m .79028 .67645 L .81528 .68721 L p .707 .577 .707 r
F P
0 g
s
.69708 .65849 m .69817 .62237 L .72877 .62002 L p .707 .577 .707 r
F P
0 g
s
.66989 .69212 m .67129 .67509 L .69784 .66866 L p .707 .577 .707 r
F P
0 g
s
.29944 .54648 m .3016 .60179 L .31248 .60989 L p .707 .577 .707 r
F P
0 g
s
.30597 .66935 m .30251 .68786 L .31972 .69648 L p .707 .577 .707 r
F P
0 g
s
.76072 .62111 m .75962 .65723 L .72768 .65615 L p .707 .577 .707 r
F P
0 g
s
.72768 .65615 m .72877 .62002 L .76072 .62111 L p .707 .577 .707 r
F P
0 g
s
.49267 .63389 m .48999 .6711 L .50053 .66446 L p .707 .577 .707 r
F P
0 g
s
.50053 .66446 m .50321 .62725 L .49267 .63389 L p .707 .577 .707 r
F P
0 g
s
.72877 .62002 m .72768 .65615 L .69708 .65849 L p .707 .577 .707 r
F P
0 g
s
.69784 .66866 m .69643 .68569 L .66989 .69212 L p .707 .577 .707 r
F P
0 g
s
.3084 .6578 m .31108 .62058 L .30192 .6125 L p .707 .577 .707 r
F P
0 g
s
.3016 .60179 m .29944 .54648 L .29837 .53749 L p .707 .578 .707 r
F P
0 g
s
.79028 .67645 m .78888 .69347 L .75899 .6864 L p .707 .577 .707 r
F P
0 g
s
.75899 .6864 m .7604 .66938 L .79028 .67645 L p .707 .577 .707 r
F P
0 g
s
.69643 .68569 m .69784 .66866 L .72854 .66669 L p .707 .577 .707 r
F P
0 g
s
.50102 .53734 m .50317 .59265 L .5021 .58367 L p .707 .578 .707 r
F P
0 g
s
.5021 .58367 m .49995 .52836 L .50102 .53734 L p .707 .578 .707 r
F P
0 g
s
.30192 .6125 m .29924 .64971 L .3084 .6578 L p .707 .577 .707 r
F P
0 g
s
.48486 .70323 m .4814 .72173 L .49257 .71755 L p .707 .577 .707 r
F P
0 g
s
.49257 .71755 m .49603 .69904 L .48486 .70323 L p .707 .577 .707 r
F P
0 g
s
.30251 .68786 m .30597 .66935 L .29774 .66149 L p .707 .577 .707 r
F P
0 g
s
.7604 .66938 m .75899 .6864 L .72714 .68372 L p .707 .577 .707 r
F P
0 g
s
.72714 .68372 m .72854 .66669 L .7604 .66938 L p .707 .577 .707 r
F P
0 g
s
.72854 .66669 m .72714 .68372 L .69643 .68569 L p .707 .577 .707 r
F P
0 g
s
.29774 .66149 m .29428 .68 L .30251 .68786 L p .707 .577 .707 r
F P
0 g
s
.29837 .53749 m .30052 .5928 L .3016 .60179 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.50321 .62725 m .50053 .66446 L .50125 .65671 L p .706 .576 .707 r
F P
0 g
s
.50125 .65671 m .50393 .6195 L .50321 .62725 L p .706 .576 .707 r
F P
0 g
s
.29924 .64971 m .30192 .6125 L .30264 .60475 L p .706 .576 .707 r
F P
0 g
s
.30052 .5928 m .29837 .53749 L .30722 .5285 L p .707 .577 .707 r
F P
0 g
s
.49995 .52836 m .5021 .58367 L .49122 .57557 L p .707 .577 .707 r
F P
0 g
s
.49122 .57557 m .48906 .52026 L .49995 .52836 L p .707 .577 .707 r
F P
0 g
s
.30264 .60475 m .29996 .64197 L .29924 .64971 L p .706 .576 .707 r
F P
0 g
s
.49603 .69904 m .49257 .71755 L .49412 .71122 L p .707 .577 .707 r
F P
0 g
s
.49412 .71122 m .49758 .69271 L .49603 .69904 L p .707 .577 .707 r
F P
0 g
s
.29428 .68 m .29774 .66149 L .29928 .65516 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29928 .65516 m .29582 .67367 L .29428 .68 L p .707 .577 .707 r
F P
0 g
s
.30722 .5285 m .30937 .58381 L .30052 .5928 L p .707 .577 .707 r
F P
0 g
s
.50393 .6195 m .50125 .65671 L .49208 .64863 L p .707 .577 .707 r
F P
0 g
s
.49208 .64863 m .49476 .61141 L .50393 .6195 L p .707 .577 .707 r
F P
0 g
s
.29996 .64197 m .30264 .60475 L .31317 .59811 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30937 .58381 m .30722 .5285 L .32512 .52037 L p .707 .577 .707 r
F P
0 g
s
.48906 .52026 m .49122 .57557 L .47159 .56914 L p .707 .577 .707 r
F P
0 g
s
.47159 .56914 m .46943 .51384 L .48906 .52026 L p .707 .577 .707 r
F P
0 g
s
.31317 .59811 m .31049 .63532 L .29996 .64197 L p .707 .577 .707 r
F P
0 g
s
.49758 .69271 m .49412 .71122 L .48588 .70336 L p .707 .577 .707 r
F P
0 g
s
.48588 .70336 m .48934 .68485 L .49758 .69271 L p .707 .577 .707 r
F P
0 g
s
.29582 .67367 m .29928 .65516 L .31046 .65097 L p .707 .577 .707 r
F P
0 g
s
.31046 .65097 m .307 .66948 L .29582 .67367 L p .707 .577 .707 r
F P
0 g
s
.32512 .52037 m .32727 .57568 L .30937 .58381 L p .707 .577 .707 r
F P
0 g
s
.32727 .57568 m .32512 .52037 L .35032 .51392 L p .707 .577 .707 r
F P
0 g
s
.49476 .61141 m .49208 .64863 L .47392 .64099 L p .707 .577 .707 r
F P
0 g
s
.47392 .64099 m .4766 .60378 L .49476 .61141 L p .707 .577 .707 r
F P
0 g
s
.31049 .63532 m .31317 .59811 L .3325 .59322 L p .707 .577 .707 r
F P
0 g
s
.46943 .51384 m .47159 .56914 L .44513 .56503 L p .707 .577 .707 r
F P
0 g
s
.44513 .56503 m .44297 .50972 L .46943 .51384 L p .707 .577 .707 r
F P
0 g
s
.3325 .59322 m .32981 .63043 L .31049 .63532 L p .707 .577 .707 r
F P
0 g
s
.48934 .68485 m .48588 .70336 L .46867 .69474 L p .707 .577 .707 r
F P
0 g
s
.46867 .69474 m .47213 .67623 L .48934 .68485 L p .707 .577 .707 r
F P
0 g
s
.35032 .51392 m .35247 .56923 L .32727 .57568 L p .707 .577 .707 r
F P
0 g
s
.307 .66948 m .31046 .65097 L .33017 .64935 L p .707 .577 .707 r
F P
0 g
s
.35247 .56923 m .35032 .51392 L .38035 .50977 L p .707 .577 .707 r
F P
0 g
s
.33017 .64935 m .32671 .66786 L .307 .66948 L p .707 .577 .707 r
F P
0 g
s
.44297 .50972 m .44513 .56503 L .41443 .56363 L p .707 .577 .707 r
F P
0 g
s
.41443 .56363 m .41228 .50832 L .44297 .50972 L p .707 .577 .707 r
F P
0 g
s
.4766 .60378 m .47392 .64099 L .44855 .63455 L p .707 .577 .707 r
F P
0 g
s
.44855 .63455 m .45123 .59733 L .4766 .60378 L p .707 .577 .707 r
F P
0 g
s
.32981 .63043 m .3325 .59322 L .35871 .59055 L p .707 .577 .707 r
F P
0 g
s
.3825 .56508 m .38035 .50977 L .41228 .50832 L p .707 .577 .707 r
F P
0 g
s
.38035 .50977 m .3825 .56508 L .35247 .56923 L p .707 .577 .707 r
F P
0 g
s
.41228 .50832 m .41443 .56363 L .3825 .56508 L p .707 .577 .707 r
F P
0 g
s
.35871 .59055 m .35603 .62777 L .32981 .63043 L p .707 .577 .707 r
F P
0 g
s
.47213 .67623 m .46867 .69474 L .44417 .6862 L p .707 .577 .707 r
F P
0 g
s
.44417 .6862 m .44763 .66769 L .47213 .67623 L p .707 .577 .707 r
F P
0 g
s
.32671 .66786 m .33017 .64935 L .35649 .65044 L p .707 .577 .707 r
F P
0 g
s
.45123 .59733 m .44855 .63455 L .41845 .62993 L p .707 .577 .707 r
F P
0 g
s
.41845 .62993 m .42114 .59272 L .45123 .59733 L p .707 .577 .707 r
F P
0 g
s
.35603 .62777 m .35871 .59055 L .38925 .59038 L p .707 .577 .707 r
F P
0 g
s
.35649 .65044 m .35303 .66894 L .32671 .66786 L p .707 .577 .707 r
F P
0 g
s
.42114 .59272 m .41845 .62993 L .38657 .6276 L p .707 .577 .707 r
F P
0 g
s
.38657 .6276 m .38925 .59038 L .42114 .59272 L p .707 .577 .707 r
F P
0 g
s
.38925 .59038 m .38657 .6276 L .35603 .62777 L p .707 .577 .707 r
F P
0 g
s
.44763 .66769 m .44417 .6862 L .41478 .67859 L p .707 .577 .707 r
F P
0 g
s
.41478 .67859 m .41824 .66008 L .44763 .66769 L p .707 .577 .707 r
F P
0 g
s
.35303 .66894 m .35649 .65044 L .38683 .65413 L p .707 .577 .707 r
F P
0 g
s
.38683 .65413 m .38337 .67264 L .35303 .66894 L p .707 .577 .707 r
F P
0 g
s
.41824 .66008 m .41478 .67859 L .38337 .67264 L p .707 .577 .707 r
F P
0 g
s
.38337 .67264 m .38683 .65413 L .41824 .66008 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
0UYF5@000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol50002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol0069oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00GWoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001KOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Moo`8000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Eoo`<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol01000FUIJEP001EYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0001Yoo`P004=oo`00E7oo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;Ool?0004FUH01000
FUIJEUYF2000>goo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Moo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000dOol005Aoo`04001JEUYF0005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF000017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01000<7oo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF
6@0015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00EGoo00<005YF00001EYF00<0
05YFFUH00eYF1P0000=JEP0000001`0015YF00<005YFFUH01EYF00<005YFFUH01P000eYF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<005YF00001EYF00<005YF00000`000UYF00<0
05YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0002FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Goo001EOol00`00FUH00005FUH20006FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eoo`03001J
EP0000=JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00@005YF001JEP80009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol01000FUH0000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol200000eYF001JEP03FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF000]Ool005Eoo`04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eo
o`04001JEUYF0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60005FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00>Woo5`0017oo
00<005YFFUH00`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool003Ioo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00<goo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool0
035oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH?0006FUH00`00FUIJEP080003
FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF00000`000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01P000eYF00@005YFFUH0
02eoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000`000UYF00<007ooOol0:goo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00P000UYF00<005YFFUH015YF5`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00
FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH300000eYF001JEP02FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF20000UYF00<005YF00001EYF3P0015YF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP06001J
EP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF1P0015YF1P00
0eYF00<005YFFUH00UYF1P001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<0009JEP8002ioo`00;7oo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPX000=JEP03001JEUYF00QJEP@00003FUH005YF00=JEP03
001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<002moo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEP0001<0009JEP<000=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002ioo`00;7oo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000=JEP`000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH60002FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0
000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH70006Ool50005Ool600000eYF001JEP03
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YF00000`000eYF00@005YF
FUIJEQD0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH00UYF20003goo10000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00@005YFFUH000=JEP<000MJEP03001JEUYF
00EJEP03001JEP0000@000=JEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00=JEP04
001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP02FUH5000015YF001JEP005goo10001EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00D0
05YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001J
EUYF009JEP04001JEUYF0002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP030005FUH01000FUIJEP000goo2@003Woo100000=JEP00FUH00eYF00@0
05YFFUH002eoo`00;7oo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000`0015YF2P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF0000009JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEPP000AJEP03001JEUYF
009JEPH000aoo`<000=JEP04001JEUYF000]Ool002aoo`@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEUYFFUH400000eYF00000004FUH01000FUIJEUYF3`0015YF00<0
05YFFUH01eYF00@005YFFUIJEP<00004FUH000000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01@00FUH00000FUH01@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`002goo0P0000EJEP00FUIJEP0002eoo`00;7oo00@005YFFUH0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEUYFFUH00002FUH01000
FUIJEUYF0`0000=JEP00FUH00eYF0`0000=JEP0000003P001eYF00<005YFFUH015YF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF100027oo0`000UYF00<007oo
Ool0:goo000/Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEP000004FUH01@00FUH005YF00001EYF00<0
05YF00002P0015YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH00000009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004Ool20002FUH200000eYF001oo`0/
Ool002aoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30004FUH01000FUIJEUYF0P000UYF00D005YF001JEP0000EJEPH000=JEP04001JEUYF
FUH300000eYF001JEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YFFUH00eYF3`0015YF00<005YF
FUH01UYF00@005YFFUIJEP@000AJEP04001JEP00000]Ool002aoo`04001JEUYF0005FUH00`00FUIJ
EP05FUH01000FUIJEUYF5P000eYF00<005YFFUH015YF1@0000=JEP00FUH015YF1P000eYF00<005YF
FUH015YF0`001EYF00<005YFFUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YF00000`0000=JEP00FUH00UYF2@0000=o
o`0000001@001UYF00<005YFFUH00eYF0P0015YF00@005YFFUH002eoo`00;Goo00<005YF00001EYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00EJEP03
001JEUYF00@000AJEPH000=JEP03001JEUYF00MJEP@00003FUH005YF00AJEP04001JEP00000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF0P001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF0P000eYF00@005YFFUH002eoo`00
;Woo0P0015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P001eYF00<005YFFUH015YF1@0000AJEP00000000AJEP03001JEUYF00UJEP04001JEP000004FUH0
0`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0eYF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00H005YF0000
05YF0002FUH00`00Oomoo`0[Ool002moo`D00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP09FUH01000FUIJEUYF0P000UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YFFUIJEP80009JEP03001oogoo
02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF1P002UYF00<005YFFUH00UYF
100000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
000000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEUYF000]Ool002aoo`800003FUH005YF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP0000<000IJEP03001JEUYF00MJEP04001JEUYFFUH?0002FUH2000015YF001JEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF0`00;Woo000/Ool01000FUIJ
EP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH400001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000eYF0P00;goo000/Ool01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YF001JEPH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000015YF
001JEP00;Woo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP@0009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1P0015YF10000UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001oo`020002FUH00`00
Oomoo`0[Ool002aoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00@005YF
FUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEPD000=JEP@000IJEP03001JEUYF
00D00003FUH005YF00MJEP04001JEUYFFUH50004Ool01000FUIJEP00;Goo000/Ool01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00IJEQD000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000IJEP04001JEP000002
FUH00`00FUH000040002FUH00`00FUIJEP0500000eYF001JEP03FUH80009Ool01000FUIJEP00;Goo
000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF6P000eYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005FUH01000FUIJ
EUYF0`0000=JEP00Ool00goo40004Woo0P00;Woo000/Ool01000FUIJEP001EYF00@005YFFUIJEPP0
00=JEP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00=JEPH0009JEP05001JEP00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP02FUH200000eYF
001oo`09Ool3000IOol2000^Ool002aoo`04001JEUYF0003FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP0500000eYF001JEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000AJEP00FUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP020002FUH00`00FUIJEP02FUH00`00FUH0
000WOol2000^Ool002aoo`03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJEP04001JEUYF
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH00004FUH01000FUIJEP009Goo00<005YF
0000;Woo000/Ool40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`001EYF0`000eYF00@005YFFUH002Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP05001JEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005
FUH01000FUH000000UYF00@005YFFUH002Aoo`04001JEUYF000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<0004FUH00`00
FUIJEP05FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0000015YF00@005YFFUIJ
EP800004FUH005YF000ROol30002FUH00`00Oomoo`0/Ool002aoo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800004Ool005YF0005FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP05FUH4
000POol20002FUH00`00FUH0000_Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000=oo`03001JEP0000EJ
EP03001JEUYF009JEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00<000AJEP03001JEUYF00=JEP03001JEP0000D000MJEP03001JEP0000<001]oo`8000AJEP80
031oo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
4P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF000017oo0P00
1UYF00<005YFFUH00eYF1`0047oo100000=JEP00FUH00eYF0P00<7oo000cOol50003FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH20005FUH00`00FUH00004Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0005
FUH00`00FUIJEP02FUH00`00Oomoo`0_Ool003Qooa<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP800003FUH005YF009JEP8000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH000040000
15YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80039oo`00=7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP800003FUH005YF00L000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00000dOol002moo`D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP800004FUH005YF0003FUH70002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@00=Woo000]Ool200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00D0009o
o`L000AJEP03001JEUYF009JEPP003]oo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEQ`000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool90013Ool002eoo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP04001JEUYFFUH2001FOol002eoo`04001JEUYF0005FUH00`00FUIJEP02FUH800000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00001`000eYF00<005YFFUH00UYF0P00EGoo000]Ool01000FUIJEP000eYF
1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001Goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF1P000UYF0P00EGoo000]Ool80007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH9000DOol00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF001JEP05FUH00`00FUIJEP0200000goo00000002001EOol002eooa`001ioo`80
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH30006Ool2001DOol006Uoo`04
001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF0P001goo0`00E7oo001ZOol30008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUH000001EYF00<005YF00000`001goo0P0000=JEP000000E7oo001/Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40003
FUH6000:Ool00`00FUIJEP02FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00/000ioo`<000AJEP03001oogoo
059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`004Goo0P00
0UYF00<005YFFUH00UYF00<007ooOol0DWoo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP060006Ool5000?Ool20005FUH01000FUIJEP00EGoo001nOolO000<Ool5000=Ool2
00000eYF001JEP04FUH3001FOol008ioo`80009JEP03001oogoo01Eoo`<000]oo`<000=JEP03001J
EUYF00=JEP03001oogoo05Ioo`00SWoo00@005YF000002=oo`<000IJEP03001JEUYF009JEP03001o
ogoo05Moo`00SWoo00@005YF0000025oo`800003FUH005YF00MJEP04001JEP00001JOol008ioo`03
001JEP00008001eoo`<000=JEP03001JEUYF00IJEP8005aoo`00Sgoo00AJEP00001JEP8001Eoo`H0
00MJEP03001JEUYF00AJEP8005eoo`00Sgoo00<005YF00000eYF5@0015YF00<005YFFUH01UYF00<0
05YFFUH01000Ggoo002?Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF1000Hgoo002@Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH2001WOol0099oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP00008006Uoo`00U7oo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1P00K7oo002FOolE001bOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60673 .75076 m .60451 .6955 L .57301 .69515 L p .707 .577 .707 r
F P
0 g
s
.60451 .6955 m .60673 .75076 L .63833 .74825 L p .707 .577 .707 r
F P
0 g
s
.63833 .74825 m .6361 .69299 L .60451 .6955 L p .707 .577 .707 r
F P
0 g
s
.6361 .69299 m .63833 .74825 L .66692 .74312 L p .707 .577 .707 r
F P
0 g
s
.66692 .74312 m .6647 .68787 L .6361 .69299 L p .707 .577 .707 r
F P
0 g
s
.57523 .75041 m .57301 .69515 L .54468 .69198 L p .707 .577 .707 r
F P
0 g
s
.57301 .69515 m .57523 .75041 L .60673 .75076 L p .707 .577 .707 r
F P
0 g
s
.6647 .68787 m .66692 .74312 L .68972 .73589 L p .707 .577 .707 r
F P
0 g
s
.68972 .73589 m .6875 .68063 L .6647 .68787 L p .707 .577 .707 r
F P
0 g
s
.54691 .74724 m .54468 .69198 L .52231 .6863 L p .707 .577 .707 r
F P
0 g
s
.54468 .69198 m .54691 .74724 L .57523 .75041 L p .707 .577 .707 r
F P
0 g
s
.61066 .80619 m .61352 .76888 L .58183 .76576 L p .707 .577 .707 r
F P
0 g
s
.61352 .76888 m .61066 .80619 L .64188 .80695 L p .707 .577 .707 r
F P
0 g
s
.64188 .80695 m .64474 .76964 L .61352 .76888 L p .707 .577 .707 r
F P
0 g
s
.57898 .80307 m .58183 .76576 L .55279 .76059 L p .707 .577 .707 r
F P
0 g
s
.58183 .76576 m .57898 .80307 L .61066 .80619 L p .707 .577 .707 r
F P
0 g
s
.64474 .76964 m .64188 .80695 L .66959 .80528 L p .707 .577 .707 r
F P
0 g
s
.66959 .80528 m .67245 .76797 L .64474 .76964 L p .707 .577 .707 r
F P
0 g
s
.55279 .76059 m .54993 .7979 L .57898 .80307 L p .707 .577 .707 r
F P
0 g
s
.60667 .84323 m .61041 .82464 L .57918 .81806 L p .707 .577 .707 r
F P
0 g
s
.61041 .82464 m .60667 .84323 L .63724 .84798 L p .707 .577 .707 r
F P
0 g
s
.63724 .84798 m .64097 .82939 L .61041 .82464 L p .707 .577 .707 r
F P
0 g
s
.52231 .6863 m .52453 .74155 L .54691 .74724 L p .707 .577 .707 r
F P
0 g
s
.54993 .7979 m .55279 .76059 L .52924 .75387 L p .707 .577 .707 r
F P
0 g
s
.57544 .83665 m .57918 .81806 L .55033 .81029 L p .707 .577 .707 r
F P
0 g
s
.57918 .81806 m .57544 .83665 L .60667 .84323 L p .707 .577 .707 r
F P
0 g
s
.6875 .68063 m .68972 .73589 L .70449 .72725 L p .707 .577 .707 r
F P
0 g
s
.70449 .72725 m .70227 .67199 L .6875 .68063 L p .707 .577 .707 r
F P
0 g
s
.55033 .81029 m .5466 .82888 L .57544 .83665 L p .707 .577 .707 r
F P
0 g
s
.52453 .74155 m .52231 .6863 L .50807 .67865 L p .707 .577 .707 r
F P
0 g
s
.64097 .82939 m .63724 .84798 L .66415 .85043 L p .707 .577 .707 r
F P
0 g
s
.66415 .85043 m .66788 .83185 L .64097 .82939 L p .707 .577 .707 r
F P
0 g
s
.67245 .76797 m .66959 .80528 L .69106 .80135 L p .707 .577 .707 r
F P
0 g
s
.69106 .80135 m .69392 .76404 L .67245 .76797 L p .707 .577 .707 r
F P
0 g
s
.52924 .75387 m .52638 .79118 L .54993 .7979 L p .707 .577 .707 r
F P
0 g
s
.5466 .82888 m .55033 .81029 L .52671 .80209 L p .707 .577 .707 r
F P
0 g
s
.52671 .80209 m .52297 .82068 L .5466 .82888 L p .707 .577 .707 r
F P
0 g
s
.52638 .79118 m .52924 .75387 L .51347 .74627 L p .707 .577 .707 r
F P
0 g
s
.50807 .67865 m .5103 .73391 L .52453 .74155 L p .707 .577 .707 r
F P
0 g
s
.66788 .83185 m .66415 .85043 L .68476 .85035 L p .707 .577 .707 r
F P
0 g
s
.68476 .85035 m .6885 .83176 L .66788 .83185 L p .707 .577 .707 r
F P
0 g
s
.70227 .67199 m .70449 .72725 L .70978 .71805 L p .707 .577 .707 r
F P
0 g
s
.70978 .71805 m .70756 .6628 L .70227 .67199 L p .707 .577 .707 r
F P
0 g
s
.51347 .74627 m .51061 .78358 L .52638 .79118 L p .707 .577 .707 r
F P
0 g
s
.69392 .76404 m .69106 .80135 L .70421 .79553 L p .707 .577 .707 r
F P
0 g
s
.70421 .79553 m .70707 .75822 L .69392 .76404 L p .707 .577 .707 r
F P
0 g
s
.52297 .82068 m .52671 .80209 L .51061 .79426 L p .707 .577 .707 r
F P
0 g
s
.5103 .73391 m .50807 .67865 L .50337 .6698 L p .707 .577 .707 r
F P
0 g
s
.51061 .79426 m .50687 .81285 L .52297 .82068 L p .707 .577 .707 r
F P
0 g
s
.51061 .78358 m .51347 .74627 L .50704 .73852 L p .707 .577 .707 r
F P
0 g
s
.6885 .83176 m .68476 .85035 L .69707 .84773 L p .707 .577 .707 r
F P
0 g
s
.69707 .84773 m .70081 .82914 L .6885 .83176 L p .707 .577 .707 r
F P
0 g
s
.50722 .72812 m .5103 .73391 L p .50769 .70979 L .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .50418 .77583 L .51061 .78358 L p .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .51056 .73139 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50418 .77583 m .50692 .74004 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50692 .74004 m .50704 .73852 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50337 .6698 m .5056 .72506 L .50722 .72812 L p .707 .577 .707 r
F P
0 g
s
.50769 .70979 m .50337 .6698 L .50722 .72812 L .707 .577 .707 r
F
.50687 .81285 m .51061 .79426 L .50361 .78758 L p F P
0 g
s
.70756 .6628 m .70978 .71805 L .70508 .7092 L p .707 .577 .707 r
F P
0 g
s
.70508 .7092 m .70286 .65394 L .70756 .6628 L p .707 .577 .707 r
F P
0 g
s
.70707 .75822 m .70421 .79553 L .70774 .7884 L p .707 .577 .707 r
F P
0 g
s
.70774 .7884 m .7106 .75109 L .70707 .75822 L p .707 .577 .707 r
F P
0 g
s
.50361 .78758 m .49987 .80617 L .50687 .81285 L p .707 .577 .707 r
F P
0 g
s
.5056 .72506 m .50337 .6698 L .50867 .66061 L p .707 .577 .707 r
F P
0 g
s
.48352 .82167 m .48352 .31978 L .44005 .31653 L p .707 .577 .707 r
F P
0 g
s
.50867 .66061 m .51089 .71586 L .5056 .72506 L p .707 .577 .707 r
F P
0 g
s
.51056 .73139 m .50771 .7687 L .50418 .77583 L p .707 .577 .707 r
F P
0 g
s
.49987 .80617 m .50361 .78758 L .5064 .78269 L p .707 .577 .707 r
F P
0 g
s
.5064 .78269 m .50266 .80127 L .49987 .80617 L p .707 .577 .707 r
F P
0 g
s
.51089 .71586 m .50867 .66061 L .52343 .65197 L p .707 .577 .707 r
F P
0 g
s
.50771 .7687 m .51056 .73139 L .52371 .72557 L p .707 .577 .707 r
F P
0 g
s
.52343 .65197 m .52566 .70722 L .51089 .71586 L p .707 .577 .707 r
F P
0 g
s
.52371 .72557 m .52085 .76288 L .50771 .7687 L p .707 .577 .707 r
F P
0 g
s
.50266 .80127 m .5064 .78269 L .5187 .78007 L p .707 .577 .707 r
F P
0 g
s
.5187 .78007 m .51497 .79866 L .50266 .80127 L p .707 .577 .707 r
F P
0 g
s
.52085 .76288 m .52371 .72557 L .54519 .72164 L p .707 .577 .707 r
F P
0 g
s
.54519 .72164 m .54233 .75894 L .52085 .76288 L p .707 .577 .707 r
F P
0 g
s
.51497 .79866 m .5187 .78007 L .53932 .77998 L p .707 .577 .707 r
F P
0 g
s
.53932 .77998 m .53558 .79857 L .51497 .79866 L p .707 .577 .707 r
F P
0 g
s
.48352 .31978 m .48352 .82167 L .52861 .82115 L p .707 .577 .707 r
F P
0 g
s
.52566 .70722 m .52343 .65197 L .54623 .64473 L p .707 .577 .707 r
F P
0 g
s
.54623 .64473 m .54846 .69999 L .52566 .70722 L p .707 .577 .707 r
F P
0 g
s
.52861 .82115 m .52861 .31927 L .48352 .31978 L p .707 .577 .707 r
F P
0 g
s
.54846 .69999 m .54623 .64473 L .57483 .63961 L p .707 .577 .707 r
F P
0 g
s
.57483 .63961 m .57705 .69486 L .54846 .69999 L p .707 .577 .707 r
F P
0 g
s
.54233 .75894 m .54519 .72164 L .5729 .71997 L p .707 .577 .707 r
F P
0 g
s
.5729 .71997 m .57004 .75728 L .54233 .75894 L p .707 .577 .707 r
F P
0 g
s
.53558 .79857 m .53932 .77998 L .56623 .78243 L p .707 .577 .707 r
F P
0 g
s
.56623 .78243 m .56249 .80102 L .53558 .79857 L p .707 .577 .707 r
F P
0 g
s
.56249 .80102 m .56623 .78243 L .5968 .78718 L p .707 .577 .707 r
F P
0 g
s
.5968 .78718 m .59306 .80577 L .56249 .80102 L p .707 .577 .707 r
F P
0 g
s
.52861 .31927 m .52861 .82115 L .5709 .81692 L p .707 .577 .707 r
F P
0 g
s
.57004 .75728 m .5729 .71997 L .60412 .72073 L p .707 .577 .707 r
F P
0 g
s
.60412 .72073 m .60126 .75804 L .57004 .75728 L p .707 .577 .707 r
F P
0 g
s
.5709 .81692 m .5709 .31504 L .52861 .31927 L p .707 .577 .707 r
F P
0 g
s
.44005 .81842 m .44005 .31653 L .40244 .30984 L p .707 .577 .707 r
F P
0 g
s
.44005 .31653 m .44005 .81842 L .48352 .82167 L p .707 .577 .707 r
F P
0 g
s
.70081 .82914 m .69707 .84773 L .69986 .84284 L p .707 .577 .707 r
F P
0 g
s
.69986 .84284 m .7036 .82425 L .70081 .82914 L p .707 .577 .707 r
F P
0 g
s
.57705 .69486 m .57483 .63961 L .60642 .6371 L p .707 .577 .707 r
F P
0 g
s
.60642 .6371 m .60865 .69235 L .57705 .69486 L p .707 .577 .707 r
F P
0 g
s
.6358 .72385 m .63294 .76116 L .60126 .75804 L p .707 .577 .707 r
F P
0 g
s
.60126 .75804 m .60412 .72073 L .6358 .72385 L p .707 .577 .707 r
F P
0 g
s
.62803 .79377 m .62429 .81235 L .59306 .80577 L p .707 .577 .707 r
F P
0 g
s
.59306 .80577 m .5968 .78718 L .62803 .79377 L p .707 .577 .707 r
F P
0 g
s
.5709 .31504 m .5709 .81692 L .60625 .8094 L p .707 .577 .707 r
F P
0 g
s
.60625 .8094 m .60625 .30751 L .5709 .31504 L p .707 .577 .707 r
F P
0 g
s
.70286 .65394 m .70508 .7092 L .69085 .70156 L p .707 .577 .707 r
F P
0 g
s
.69085 .70156 m .68862 .6463 L .70286 .65394 L p .707 .577 .707 r
F P
0 g
s
.26102 .7104 m .26004 .6543 L .22852 .65358 L p .707 .577 .707 r
F P
0 g
s
.26004 .6543 m .26102 .7104 L .29263 .70878 L p .707 .577 .707 r
F P
0 g
s
.29263 .70878 m .29166 .65268 L .26004 .6543 L p .707 .577 .707 r
F P
0 g
s
.7106 .75109 m .70774 .7884 L .70131 .78065 L p .707 .577 .707 r
F P
0 g
s
.70131 .78065 m .70417 .74334 L .7106 .75109 L p .707 .577 .707 r
F P
0 g
s
.29166 .65268 m .29263 .70878 L .32124 .70499 L p .707 .577 .707 r
F P
0 g
s
.32124 .70499 m .32027 .64889 L .29166 .65268 L p .707 .577 .707 r
F P
0 g
s
.2295 .70968 m .22852 .65358 L .20018 .6506 L p .707 .577 .707 r
F P
0 g
s
.22852 .65358 m .2295 .70968 L .26102 .7104 L p .707 .577 .707 r
F P
0 g
s
.40244 .81173 m .40244 .30984 L .37438 .30035 L p .707 .577 .707 r
F P
0 g
s
.40244 .30984 m .40244 .81173 L .44005 .81842 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63792 .63744 m .64015 .6927 L .60865 .69235 L p .707 .577 .707 r
F P
0 g
s
.60865 .69235 m .60642 .6371 L .63792 .63744 L p .707 .577 .707 r
F P
0 g
s
.62429 .81235 m .62803 .79377 L .65687 .80154 L p .707 .577 .707 r
F P
0 g
s
.60625 .30751 m .60625 .8094 L .63119 .79931 L p .707 .577 .707 r
F P
0 g
s
.63119 .79931 m .63119 .29742 L .60625 .30751 L p .707 .577 .707 r
F P
0 g
s
.32027 .64889 m .32124 .70499 L .34405 .6994 L p .707 .577 .707 r
F P
0 g
s
.34405 .6994 m .34308 .6433 L .32027 .64889 L p .707 .577 .707 r
F P
0 g
s
.20018 .6506 m .20115 .7067 L .2295 .70968 L p .707 .577 .707 r
F P
0 g
s
.7036 .82425 m .69986 .84284 L .69286 .83615 L p .707 .577 .707 r
F P
0 g
s
.69286 .83615 m .6966 .81756 L .7036 .82425 L p .707 .577 .707 r
F P
0 g
s
.20115 .7067 m .20018 .6506 L .17779 .64565 L p .707 .577 .707 r
F P
0 g
s
.26595 .7805 m .26722 .74423 L .23547 .74207 L p .707 .577 .707 r
F P
0 g
s
.26722 .74423 m .26595 .7805 L .29724 .77933 L p .707 .577 .707 r
F P
0 g
s
.29724 .77933 m .29851 .74306 L .26722 .74423 L p .707 .577 .707 r
F P
0 g
s
.2342 .77834 m .23547 .74207 L .20635 .7368 L p .707 .577 .707 r
F P
0 g
s
.23547 .74207 m .2342 .77834 L .26595 .7805 L p .707 .577 .707 r
F P
0 g
s
.68862 .6463 m .69085 .70156 L .66847 .69587 L p .707 .577 .707 r
F P
0 g
s
.66847 .69587 m .66625 .64061 L .68862 .6463 L p .707 .577 .707 r
F P
0 g
s
.29851 .74306 m .29724 .77933 L .325 .77495 L p .707 .577 .707 r
F P
0 g
s
.325 .77495 m .32627 .73868 L .29851 .74306 L p .707 .577 .707 r
F P
0 g
s
.70417 .74334 m .70131 .78065 L .68554 .77305 L p .707 .577 .707 r
F P
0 g
s
.68554 .77305 m .6884 .73574 L .70417 .74334 L p .707 .577 .707 r
F P
0 g
s
.17779 .64565 m .17876 .70175 L .20115 .7067 L p .707 .577 .707 r
F P
0 g
s
.20508 .77307 m .20635 .7368 L .18273 .72892 L p .707 .577 .707 r
F P
0 g
s
.20635 .7368 m .20508 .77307 L .2342 .77834 L p .707 .577 .707 r
F P
0 g
s
.34308 .6433 m .34405 .6994 L .35882 .69255 L p .707 .577 .707 r
F P
0 g
s
.35882 .69255 m .35785 .63645 L .34308 .6433 L p .707 .577 .707 r
F P
0 g
s
.17876 .70175 m .17779 .64565 L .16354 .63922 L p .707 .577 .707 r
F P
0 g
s
.37438 .80224 m .37438 .30035 L .35862 .28901 L p .707 .577 .707 r
F P
0 g
s
.37438 .30035 m .37438 .80224 L .40244 .81173 L p .707 .577 .707 r
F P
0 g
s
.32627 .73868 m .325 .77495 L .34651 .76778 L p .707 .577 .707 r
F P
0 g
s
.34651 .76778 m .34778 .73151 L .32627 .73868 L p .707 .577 .707 r
F P
0 g
s
.26585 .83079 m .26754 .81348 L .23581 .80979 L p .707 .577 .707 r
F P
0 g
s
.26754 .81348 m .26585 .83079 L .29687 .83015 L p .707 .577 .707 r
F P
0 g
s
.29687 .83015 m .29855 .81283 L .26754 .81348 L p .707 .577 .707 r
F P
0 g
s
.66625 .64061 m .66847 .69587 L .64015 .6927 L p .707 .577 .707 r
F P
0 g
s
.64015 .6927 m .63792 .63744 L .66625 .64061 L p .707 .577 .707 r
F P
0 g
s
.6966 .81756 m .69286 .83615 L .67676 .82833 L p .707 .577 .707 r
F P
0 g
s
.67676 .82833 m .6805 .80974 L .6966 .81756 L p .707 .577 .707 r
F P
0 g
s
.23412 .82711 m .23581 .80979 L .20647 .80214 L p .707 .577 .707 r
F P
0 g
s
.23581 .80979 m .23412 .82711 L .26585 .83079 L p .707 .577 .707 r
F P
0 g
s
.18273 .72892 m .18146 .76519 L .20508 .77307 L p .707 .577 .707 r
F P
0 g
s
.66484 .72902 m .66198 .76633 L .63294 .76116 L p .707 .577 .707 r
F P
0 g
s
.63294 .76116 m .6358 .72385 L .66484 .72902 L p .707 .577 .707 r
F P
0 g
s
.63119 .29742 m .63119 .79931 L .6433 .78764 L p .707 .577 .707 r
F P
0 g
s
.6433 .78764 m .6433 .28575 L .63119 .29742 L p .707 .577 .707 r
F P
0 g
s
.16354 .63922 m .16451 .69532 L .17876 .70175 L p .707 .577 .707 r
F P
0 g
s
.29855 .81283 m .29687 .83015 L .32413 .82525 L p .707 .577 .707 r
F P
0 g
s
.32413 .82525 m .32581 .80793 L .29855 .81283 L p .707 .577 .707 r
F P
0 g
s
.18146 .76519 m .18273 .72892 L .16691 .71922 L p .707 .577 .707 r
F P
0 g
s
.6884 .73574 m .68554 .77305 L .66198 .76633 L p .707 .577 .707 r
F P
0 g
s
.66198 .76633 m .66484 .72902 L .6884 .73574 L p .707 .577 .707 r
F P
0 g
s
.20647 .80214 m .20479 .81946 L .23412 .82711 L p .707 .577 .707 r
F P
0 g
s
.20479 .81946 m .20647 .80214 L .18239 .79128 L p .707 .577 .707 r
F P
0 g
s
.34778 .73151 m .34651 .76778 L .35967 .75852 L p .707 .577 .707 r
F P
0 g
s
.35967 .75852 m .36094 .72226 L .34778 .73151 L p .707 .577 .707 r
F P
0 g
s
.35785 .63645 m .35882 .69255 L .36411 .68511 L p .707 .577 .707 r
F P
0 g
s
.36411 .68511 m .36314 .62901 L .35785 .63645 L p .707 .577 .707 r
F P
0 g
s
.18239 .79128 m .18071 .80859 L .20479 .81946 L p .707 .577 .707 r
F P
0 g
s
.16451 .69532 m .16354 .63922 L .15883 .63193 L p .707 .577 .707 r
F P
0 g
s
.16691 .71922 m .16564 .75549 L .18146 .76519 L p .707 .577 .707 r
F P
0 g
s
.32581 .80793 m .32413 .82525 L .34497 .81656 L p .707 .577 .707 r
F P
0 g
s
.34497 .81656 m .34666 .79924 L .32581 .80793 L p .707 .577 .707 r
F P
0 g
s
.6805 .80974 m .67676 .82833 L .65313 .82013 L p .707 .577 .707 r
F P
0 g
s
.65313 .82013 m .65687 .80154 L .6805 .80974 L p .707 .577 .707 r
F P
0 g
s
.18071 .80859 m .18239 .79128 L .16594 .77826 L p .707 .577 .707 r
F P
0 g
s
.16564 .75549 m .16691 .71922 L .16044 .70863 L p .707 .577 .707 r
F P
0 g
s
.15883 .63193 m .1598 .68803 L .16451 .69532 L p .707 .577 .707 r
F P
0 g
s
.35736 .80494 m .35904 .78763 L .34666 .79924 L p .707 .577 .707 r
F P
0 g
s
.3594 .67782 m .35843 .62172 L .36314 .62901 L p .707 .577 .707 r
F P
0 g
s
.36094 .72226 m .35967 .75852 L .36319 .7481 L p .707 .577 .707 r
F P
0 g
s
.36319 .7481 m .36446 .71183 L .36094 .72226 L p .707 .577 .707 r
F P
0 g
s
.36446 .71183 m .36319 .7481 L .35672 .73751 L p .707 .577 .707 r
F P
0 g
s
.35672 .73751 m .35799 .70124 L .36446 .71183 L p .707 .577 .707 r
F P
0 g
s
.35843 .62172 m .3594 .67782 L .34515 .67139 L p .707 .577 .707 r
F P
0 g
s
.34515 .67139 m .34418 .61529 L .35843 .62172 L p .707 .577 .707 r
F P
0 g
s
.35904 .78763 m .35736 .80494 L .36007 .79153 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .36175 .77421 L .35904 .78763 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .35284 .77763 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.36175 .77421 m .3614 .77779 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.3614 .77779 m .36007 .79153 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .3567 .27691 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .35453 .76032 L .36136 .77346 L p .707 .577 .707 r
F P
0 g
s
.36136 .77346 m .36175 .77421 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .36136 .77346 L .36137 .77436 L .707 .577 .707 r
F
.35799 .70124 m .35672 .73751 L .3409 .7278 L p F P
0 g
s
.3409 .7278 m .34217 .69154 L .35799 .70124 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .35862 .7909 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .27691 m .3567 .28823 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .28823 m .3567 .7788 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .7909 m .35862 .48812 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .48812 m .35862 .28901 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.36314 .62901 m .36411 .68511 L .3594 .67782 L p .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .35862 .7909 L .37438 .80224 L p .707 .577 .707 r
F P
0 g
s
.16594 .77826 m .16426 .79557 L .18071 .80859 L p .707 .577 .707 r
F P
0 g
s
.34666 .79924 m .34497 .81656 L .35736 .80494 L p .707 .577 .707 r
F P
0 g
s
.6433 .28575 m .6433 .78764 L .64138 .77554 L p .707 .577 .707 r
F P
0 g
s
.64138 .77554 m .64138 .27365 L .6433 .28575 L p .707 .577 .707 r
F P
0 g
s
.16044 .70863 m .15917 .7449 L .16564 .75549 L p .707 .577 .707 r
F P
0 g
s
.65687 .80154 m .65313 .82013 L .62429 .81235 L p .707 .577 .707 r
F P
0 g
s
.1598 .68803 m .15883 .63193 L .16412 .62449 L p .707 .577 .707 r
F P
0 g
s
.16426 .79557 m .16594 .77826 L .15871 .76436 L p .707 .577 .707 r
F P
0 g
s
.15871 .76436 m .15703 .78168 L .16426 .79557 L p .707 .577 .707 r
F P
0 g
s
.15917 .7449 m .16044 .70863 L .16396 .6982 L p .707 .577 .707 r
F P
0 g
s
.16412 .62449 m .16509 .68059 L .1598 .68803 L p .707 .577 .707 r
F P
0 g
s
.16396 .6982 m .16269 .73447 L .15917 .7449 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .3567 .27691 L .3688 .26524 L p .707 .577 .707 r
F P
0 g
s
.15703 .78168 m .15871 .76436 L .16143 .75095 L p .707 .577 .707 r
F P
0 g
s
.16509 .68059 m .16412 .62449 L .17889 .61764 L p .707 .577 .707 r
F P
0 g
s
.16143 .75095 m .15974 .76826 L .15703 .78168 L p .707 .577 .707 r
F P
0 g
s
.64138 .27365 m .64138 .77554 L .62562 .76419 L p .707 .577 .707 r
F P
0 g
s
.62562 .76419 m .62562 .2623 L .64138 .27365 L p .707 .577 .707 r
F P
0 g
s
.16269 .73447 m .16396 .6982 L .17712 .68895 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17889 .61764 m .17986 .67374 L .16509 .68059 L p .707 .577 .707 r
F P
0 g
s
.17712 .68895 m .17585 .72522 L .16269 .73447 L p .707 .577 .707 r
F P
0 g
s
.34418 .61529 m .34515 .67139 L .32276 .66644 L p .707 .577 .707 r
F P
0 g
s
.32276 .66644 m .32178 .61034 L .34418 .61529 L p .707 .577 .707 r
F P
0 g
s
.15974 .76826 m .16143 .75095 L .17381 .73933 L p .707 .577 .707 r
F P
0 g
s
.17986 .67374 m .17889 .61764 L .20169 .61205 L p .707 .577 .707 r
F P
0 g
s
.17381 .73933 m .17213 .75664 L .15974 .76826 L p .707 .577 .707 r
F P
0 g
s
.3688 .76713 m .3688 .26524 L .39375 .25515 L p .707 .577 .707 r
F P
0 g
s
.3688 .26524 m .3688 .76713 L .3567 .7788 L p .707 .577 .707 r
F P
0 g
s
.17585 .72522 m .17712 .68895 L .19863 .68178 L p .707 .577 .707 r
F P
0 g
s
.20169 .61205 m .20267 .66815 L .17986 .67374 L p .707 .577 .707 r
F P
0 g
s
.35453 .76032 m .35284 .77763 L .33639 .76461 L p .707 .577 .707 r
F P
0 g
s
.33639 .76461 m .33807 .7473 L .35453 .76032 L p .707 .577 .707 r
F P
0 g
s
.32178 .61034 m .32276 .66644 L .29441 .66346 L p .707 .577 .707 r
F P
0 g
s
.29441 .66346 m .29344 .60736 L .32178 .61034 L p .707 .577 .707 r
F P
0 g
s
.34217 .69154 m .3409 .7278 L .31728 .71993 L p .707 .577 .707 r
F P
0 g
s
.31728 .71993 m .31855 .68366 L .34217 .69154 L p .707 .577 .707 r
F P
0 g
s
.62562 .2623 m .62562 .76419 L .59756 .75471 L p .707 .577 .707 r
F P
0 g
s
.59756 .75471 m .59756 .25282 L .62562 .2623 L p .707 .577 .707 r
F P
0 g
s
.20267 .66815 m .20169 .61205 L .23031 .60826 L p .707 .577 .707 r
F P
0 g
s
.19863 .68178 m .19736 .71805 L .17585 .72522 L p .707 .577 .707 r
F P
0 g
s
.17213 .75664 m .17381 .73933 L .19465 .73064 L p .707 .577 .707 r
F P
0 g
s
.19736 .71805 m .19863 .68178 L .22639 .6774 L p .707 .577 .707 r
F P
0 g
s
.29344 .60736 m .29441 .66346 L .26289 .66274 L p .707 .577 .707 r
F P
0 g
s
.26289 .66274 m .26192 .60664 L .29344 .60736 L p .707 .577 .707 r
F P
0 g
s
.23031 .60826 m .23128 .66436 L .20267 .66815 L p .707 .577 .707 r
F P
0 g
s
.19465 .73064 m .19297 .74796 L .17213 .75664 L p .707 .577 .707 r
F P
0 g
s
.23128 .66436 m .23031 .60826 L .26192 .60664 L p .707 .577 .707 r
F P
0 g
s
.26192 .60664 m .26289 .66274 L .23128 .66436 L p .707 .577 .707 r
F P
0 g
s
.31855 .68366 m .31728 .71993 L .28816 .71465 L p .707 .577 .707 r
F P
0 g
s
.28816 .71465 m .28943 .67839 L .31855 .68366 L p .707 .577 .707 r
F P
0 g
s
.33807 .7473 m .33639 .76461 L .31231 .75375 L p .707 .577 .707 r
F P
0 g
s
.31231 .75375 m .314 .73643 L .33807 .7473 L p .707 .577 .707 r
F P
0 g
s
.73711 .65978 m .73808 .6048 L .70656 .60269 L p .707 .577 .707 r
F P
0 g
s
.73808 .6048 m .73711 .65978 L .76872 .65886 L p .707 .577 .707 r
F P
0 g
s
.76872 .65886 m .76969 .60388 L .73808 .6048 L p .707 .577 .707 r
F P
0 g
s
.22639 .6774 m .22512 .71367 L .19736 .71805 L p .707 .577 .707 r
F P
0 g
s
.39375 .25515 m .39375 .75704 L .3688 .76713 L p .707 .577 .707 r
F P
0 g
s
.39375 .75704 m .39375 .25515 L .4291 .24762 L p .707 .577 .707 r
F P
0 g
s
.22512 .71367 m .22639 .6774 L .25768 .67623 L p .707 .577 .707 r
F P
0 g
s
.19297 .74796 m .19465 .73064 L .22192 .72574 L p .707 .577 .707 r
F P
0 g
s
.76969 .60388 m .76872 .65886 L .79733 .655 L p .707 .577 .707 r
F P
0 g
s
.79733 .655 m .7983 .60002 L .76969 .60388 L p .707 .577 .707 r
F P
0 g
s
.70558 .65767 m .70656 .60269 L .67821 .59776 L p .707 .577 .707 r
F P
0 g
s
.70656 .60269 m .70558 .65767 L .73711 .65978 L p .707 .577 .707 r
F P
0 g
s
.28943 .67839 m .28816 .71465 L .25641 .7125 L p .707 .577 .707 r
F P
0 g
s
.25641 .7125 m .25768 .67623 L .28943 .67839 L p .707 .577 .707 r
F P
0 g
s
.59756 .25282 m .59756 .75471 L .55995 .74802 L p .707 .577 .707 r
F P
0 g
s
.55995 .74802 m .55995 .24613 L .59756 .25282 L p .707 .577 .707 r
F P
0 g
s
.25768 .67623 m .25641 .7125 L .22512 .71367 L p .707 .577 .707 r
F P
0 g
s
.22192 .72574 m .22023 .74305 L .19297 .74796 L p .707 .577 .707 r
F P
0 g
s
.314 .73643 m .31231 .75375 L .28298 .7461 L p .707 .577 .707 r
F P
0 g
s
.28298 .7461 m .28466 .72878 L .314 .73643 L p .707 .577 .707 r
F P
0 g
s
.7983 .60002 m .79733 .655 L .82014 .64857 L p .707 .577 .707 r
F P
0 g
s
.82014 .64857 m .82111 .5936 L .7983 .60002 L p .707 .577 .707 r
F P
0 g
s
.67724 .65273 m .67821 .59776 L .65582 .59048 L p .707 .577 .707 r
F P
0 g
s
.67821 .59776 m .67724 .65273 L .70558 .65767 L p .707 .577 .707 r
F P
0 g
s
.22023 .74305 m .22192 .72574 L .25293 .7251 L p .707 .577 .707 r
F P
0 g
s
.74359 .71019 m .74232 .67256 L .71056 .67287 L p .707 .577 .707 r
F P
0 g
s
.74232 .67256 m .74359 .71019 L .77488 .70786 L p .707 .577 .707 r
F P
0 g
s
.77488 .70786 m .77361 .67023 L .74232 .67256 L p .707 .577 .707 r
F P
0 g
s
.28466 .72878 m .28298 .7461 L .25125 .74241 L p .707 .577 .707 r
F P
0 g
s
.25125 .74241 m .25293 .7251 L .28466 .72878 L p .707 .577 .707 r
F P
0 g
s
.71184 .71051 m .71056 .67287 L .68145 .67113 L p .707 .577 .707 r
F P
0 g
s
.71056 .67287 m .71184 .71051 L .74359 .71019 L p .707 .577 .707 r
F P
0 g
s
.25293 .7251 m .25125 .74241 L .22023 .74305 L p .707 .577 .707 r
F P
0 g
s
.4291 .74951 m .4291 .24762 L .47139 .24339 L p .707 .577 .707 r
F P
0 g
s
.4291 .24762 m .4291 .74951 L .39375 .75704 L p .707 .577 .707 r
F P
0 g
s
.77361 .67023 m .77488 .70786 L .80264 .70374 L p .707 .577 .707 r
F P
0 g
s
.80264 .70374 m .80137 .6661 L .77361 .67023 L p .707 .577 .707 r
F P
0 g
s
.74875 .74253 m .74707 .72347 L .71534 .72597 L p .707 .577 .707 r
F P
0 g
s
.74707 .72347 m .74875 .74253 L .77976 .73909 L p .707 .577 .707 r
F P
0 g
s
.77976 .73909 m .77808 .72002 L .74707 .72347 L p .707 .577 .707 r
F P
0 g
s
.55995 .24613 m .55995 .74802 L .51648 .74477 L p .707 .577 .707 r
F P
0 g
s
.51648 .74477 m .51648 .24288 L .55995 .24613 L p .707 .577 .707 r
F P
0 g
s
.68145 .67113 m .68272 .70876 L .71184 .71051 L p .707 .577 .707 r
F P
0 g
s
.71534 .72597 m .71702 .74503 L .74875 .74253 L p .707 .577 .707 r
F P
0 g
s
.71702 .74503 m .71534 .72597 L .686 .72728 L p .707 .577 .707 r
F P
0 g
s
.65582 .59048 m .65485 .64545 L .67724 .65273 L p .707 .577 .707 r
F P
0 g
s
.686 .72728 m .68768 .74634 L .71702 .74503 L p .707 .577 .707 r
F P
0 g
s
.68272 .70876 m .68145 .67113 L .65783 .66751 L p .707 .577 .707 r
F P
0 g
s
.77808 .72002 m .77976 .73909 L .80703 .73504 L p .707 .577 .707 r
F P
0 g
s
.80703 .73504 m .80534 .71597 L .77808 .72002 L p .707 .577 .707 r
F P
0 g
s
.82111 .5936 m .82014 .64857 L .83491 .64021 L p .707 .577 .707 r
F P
0 g
s
.83491 .64021 m .83588 .58524 L .82111 .5936 L p .707 .577 .707 r
F P
0 g
s
.65485 .64545 m .65582 .59048 L .64157 .58157 L p .707 .577 .707 r
F P
0 g
s
.47139 .74528 m .47139 .24339 L .51648 .24288 L p .707 .577 .707 r
F P
0 g
s
.47139 .24339 m .47139 .74528 L .4291 .74951 L p .707 .577 .707 r
F P
0 g
s
.80137 .6661 m .80264 .70374 L .82415 .69823 L p .707 .577 .707 r
F P
0 g
s
.82415 .69823 m .82288 .66059 L .80137 .6661 L p .707 .577 .707 r
F P
0 g
s
.51648 .24288 m .51648 .74477 L .47139 .74528 L p .707 .577 .707 r
F P
0 g
s
.65783 .66751 m .6591 .70514 L .68272 .70876 L p .707 .577 .707 r
F P
0 g
s
.68768 .74634 m .686 .72728 L .66193 .72727 L p .707 .577 .707 r
F P
0 g
s
.66193 .72727 m .66361 .74633 L .68768 .74634 L p .707 .577 .707 r
F P
0 g
s
.80534 .71597 m .80703 .73504 L .82787 .73077 L p .707 .577 .707 r
F P
0 g
s
.82787 .73077 m .82619 .71171 L .80534 .71597 L p .707 .577 .707 r
F P
0 g
s
.64157 .58157 m .6406 .63655 L .65485 .64545 L p .707 .577 .707 r
F P
0 g
s
.6591 .70514 m .65783 .66751 L .64201 .66236 L p .707 .577 .707 r
F P
0 g
s
.82288 .66059 m .82415 .69823 L .83731 .69187 L p .707 .577 .707 r
F P
0 g
s
.83731 .69187 m .83604 .65423 L .82288 .66059 L p .707 .577 .707 r
F P
0 g
s
.83588 .58524 m .83491 .64021 L .8402 .63074 L p .707 .577 .707 r
F P
0 g
s
.8402 .63074 m .84117 .57576 L .83588 .58524 L p .707 .577 .707 r
F P
0 g
s
.6406 .63655 m .64157 .58157 L .63686 .57191 L p .707 .577 .707 r
F P
0 g
s
.64201 .66236 m .64328 .7 L .6591 .70514 L p .707 .577 .707 r
F P
0 g
s
.66361 .74633 m .66193 .72727 L .64547 .72594 L p .707 .577 .707 r
F P
0 g
s
.64547 .72594 m .64715 .745 L .66361 .74633 L p .707 .577 .707 r
F P
0 g
s
.82619 .71171 m .82787 .73077 L .84026 .72672 L p .707 .577 .707 r
F P
0 g
s
.84026 .72672 m .83857 .70766 L .82619 .71171 L p .707 .577 .707 r
F P
0 g
s
.63686 .57191 m .63589 .62689 L .6406 .63655 L p .707 .577 .707 r
F P
0 g
s
.64328 .7 m .64201 .66236 L .63554 .65619 L p .707 .577 .707 r
F P
0 g
s
.83604 .65423 m .83731 .69187 L .84083 .68528 L p .707 .577 .707 r
F P
0 g
s
.84083 .68528 m .83955 .64764 L .83604 .65423 L p .707 .577 .707 r
F P
0 g
s
.63554 .65619 m .63681 .69383 L .64328 .7 L p .707 .577 .707 r
F P
0 g
s
.64715 .745 m .64547 .72594 L .63825 .72343 L p .707 .577 .707 r
F P
0 g
s
.84117 .57576 m .8402 .63074 L .83549 .62107 L p .707 .577 .707 r
F P
0 g
s
.83549 .62107 m .83646 .5661 L .84117 .57576 L p .707 .577 .707 r
F P
0 g
s
.63589 .62689 m .63686 .57191 L .64215 .56244 L p .707 .577 .707 r
F P
0 g
s
.63825 .72343 m .63993 .74249 L .64715 .745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83857 .70766 m .84026 .72672 L .84297 .72327 L p .707 .577 .707 r
F P
0 g
s
.84297 .72327 m .84128 .7042 L .83857 .70766 L p .707 .577 .707 r
F P
0 g
s
.64215 .56244 m .64118 .61741 L .63589 .62689 L p .707 .577 .707 r
F P
0 g
s
.63681 .69383 m .63554 .65619 L .63906 .6496 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63906 .6496 m .64033 .68724 L .63681 .69383 L p .707 .577 .707 r
F P
0 g
s
.83955 .64764 m .84083 .68528 L .83436 .67911 L p .707 .577 .707 r
F P
0 g
s
.83436 .67911 m .83309 .64147 L .83955 .64764 L p .707 .577 .707 r
F P
0 g
s
.39135 .61944 m .39357 .56363 L .36207 .56113 L p .707 .577 .707 r
F P
0 g
s
.39357 .56363 m .39135 .61944 L .42294 .61944 L p .707 .577 .707 r
F P
0 g
s
.42294 .61944 m .42517 .56363 L .39357 .56363 L p .707 .577 .707 r
F P
0 g
s
.83646 .5661 m .83549 .62107 L .82124 .61217 L p .707 .577 .707 r
F P
0 g
s
.82124 .61217 m .82221 .55719 L .83646 .5661 L p .707 .577 .707 r
F P
0 g
s
.63993 .74249 m .63825 .72343 L .64096 .71998 L p .707 .577 .707 r
F P
0 g
s
.64118 .61741 m .64215 .56244 L .65692 .55408 L p .707 .577 .707 r
F P
0 g
s
.64096 .71998 m .64264 .73904 L .63993 .74249 L p .707 .577 .707 r
F P
0 g
s
.35985 .61693 m .36207 .56113 L .33375 .55636 L p .707 .577 .707 r
F P
0 g
s
.36207 .56113 m .35985 .61693 L .39135 .61944 L p .707 .577 .707 r
F P
0 g
s
.42517 .56363 m .42294 .61944 L .45154 .61693 L p .707 .577 .707 r
F P
0 g
s
.45154 .61693 m .45377 .56112 L .42517 .56363 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84128 .7042 m .84297 .72327 L .83574 .72075 L p .707 .577 .707 r
F P
0 g
s
.83574 .72075 m .83406 .70169 L .84128 .7042 L p .707 .577 .707 r
F P
0 g
s
.65692 .55408 m .65595 .60905 L .64118 .61741 L p .707 .577 .707 r
F P
0 g
s
.33152 .61216 m .33375 .55636 L .31137 .54979 L p .707 .577 .707 r
F P
0 g
s
.33375 .55636 m .33152 .61216 L .35985 .61693 L p .707 .577 .707 r
F P
0 g
s
.45377 .56112 m .45154 .61693 L .47434 .61216 L p .707 .577 .707 r
F P
0 g
s
.47434 .61216 m .47656 .55635 L .45377 .56112 L p .707 .577 .707 r
F P
0 g
s
.39874 .68458 m .39588 .64803 L .3642 .64921 L p .707 .577 .707 r
F P
0 g
s
.39588 .64803 m .39874 .68458 L .42996 .6804 L p .707 .577 .707 r
F P
0 g
s
.42996 .6804 m .4271 .64386 L .39588 .64803 L p .707 .577 .707 r
F P
0 g
s
.64033 .68724 m .63906 .6496 L .65222 .64324 L p .707 .577 .707 r
F P
0 g
s
.36706 .68576 m .3642 .64921 L .33516 .64727 L p .707 .577 .707 r
F P
0 g
s
.3642 .64921 m .36706 .68576 L .39874 .68458 L p .707 .577 .707 r
F P
0 g
s
.82221 .55719 m .82124 .61217 L .79885 .60489 L p .707 .577 .707 r
F P
0 g
s
.79885 .60489 m .79982 .54992 L .82221 .55719 L p .707 .577 .707 r
F P
0 g
s
.4271 .64386 m .42996 .6804 L .45767 .67363 L p .707 .577 .707 r
F P
0 g
s
.45767 .67363 m .45481 .63709 L .4271 .64386 L p .707 .577 .707 r
F P
0 g
s
.65595 .60905 m .65692 .55408 L .67973 .54765 L p .707 .577 .707 r
F P
0 g
s
.83309 .64147 m .83436 .67911 L .81854 .67396 L p .707 .577 .707 r
F P
0 g
s
.81854 .67396 m .81727 .63632 L .83309 .64147 L p .707 .577 .707 r
F P
0 g
s
.65222 .64324 m .65349 .68088 L .64033 .68724 L p .707 .577 .707 r
F P
0 g
s
.64264 .73904 m .64096 .71998 L .65334 .71592 L p .707 .577 .707 r
F P
0 g
s
.31137 .54979 m .30915 .6056 L .33152 .61216 L p .707 .577 .707 r
F P
0 g
s
.65334 .71592 m .65503 .73499 L .64264 .73904 L p .707 .577 .707 r
F P
0 g
s
.33516 .64727 m .33801 .68381 L .36706 .68576 L p .707 .577 .707 r
F P
0 g
s
.33801 .68381 m .33516 .64727 L .3116 .6424 L p .707 .577 .707 r
F P
0 g
s
.30915 .6056 m .31137 .54979 L .29714 .54207 L p .707 .577 .707 r
F P
0 g
s
.47656 .55635 m .47434 .61216 L .48911 .60559 L p .707 .577 .707 r
F P
0 g
s
.48911 .60559 m .49133 .54979 L .47656 .55635 L p .707 .577 .707 r
F P
0 g
s
.45481 .63709 m .45767 .67363 L .47915 .66493 L p .707 .577 .707 r
F P
0 g
s
.47915 .66493 m .47629 .62838 L .45481 .63709 L p .707 .577 .707 r
F P
0 g
s
.40694 .73065 m .4032 .71307 L .37197 .7178 L p .707 .577 .707 r
F P
0 g
s
.4032 .71307 m .40694 .73065 L .43751 .72241 L p .707 .577 .707 r
F P
0 g
s
.43751 .72241 m .43377 .70484 L .4032 .71307 L p .707 .577 .707 r
F P
0 g
s
.83406 .70169 m .83574 .72075 L .81929 .71943 L p .707 .577 .707 r
F P
0 g
s
.81929 .71943 m .8176 .70037 L .83406 .70169 L p .707 .577 .707 r
F P
0 g
s
.67973 .54765 m .67876 .60263 L .65595 .60905 L p .707 .577 .707 r
F P
0 g
s
.43377 .70484 m .43751 .72241 L .46441 .71148 L p .707 .577 .707 r
F P
0 g
s
.46441 .71148 m .46068 .69391 L .43377 .70484 L p .707 .577 .707 r
F P
0 g
s
.37571 .73538 m .37197 .7178 L .34313 .71857 L p .707 .577 .707 r
F P
0 g
s
.37197 .7178 m .37571 .73538 L .40694 .73065 L p .707 .577 .707 r
F P
0 g
s
.79982 .54992 m .79885 .60489 L .7705 .59996 L p .707 .577 .707 r
F P
0 g
s
.7705 .59996 m .77148 .54498 L .79982 .54992 L p .707 .577 .707 r
F P
0 g
s
.67876 .60263 m .67973 .54765 L .70834 .54379 L p .707 .577 .707 r
F P
0 g
s
.65349 .68088 m .65222 .64324 L .67373 .63773 L p .707 .577 .707 r
F P
0 g
s
.3116 .6424 m .31446 .67894 L .33801 .68381 L p .707 .577 .707 r
F P
0 g
s
.34313 .71857 m .34686 .73615 L .37571 .73538 L p .707 .577 .707 r
F P
0 g
s
.29714 .54207 m .29491 .59788 L .30915 .6056 L p .707 .577 .707 r
F P
0 g
s
.81727 .63632 m .81854 .67396 L .79492 .67034 L p .707 .577 .707 r
F P
0 g
s
.79492 .67034 m .79365 .6327 L .81727 .63632 L p .707 .577 .707 r
F P
0 g
s
.67373 .63773 m .675 .67536 L .65349 .68088 L p .707 .577 .707 r
F P
0 g
s
.31446 .67894 m .3116 .6424 L .29583 .63508 L p .707 .577 .707 r
F P
0 g
s
.46068 .69391 m .46441 .71148 L .48503 .69893 L p .707 .577 .707 r
F P
0 g
s
.48503 .69893 m .48129 .68135 L .46068 .69391 L p .707 .577 .707 r
F P
0 g
s
.65503 .73499 m .65334 .71592 L .67419 .71166 L p .707 .577 .707 r
F P
0 g
s
.34686 .73615 m .34313 .71857 L .3195 .7153 L p .707 .577 .707 r
F P
0 g
s
.77148 .54498 m .7705 .59996 L .73898 .59784 L p .707 .577 .707 r
F P
0 g
s
.73898 .59784 m .73995 .54287 L .77148 .54498 L p .707 .577 .707 r
F P
0 g
s
.70737 .59877 m .70834 .54379 L .73995 .54287 L p .707 .577 .707 r
F P
0 g
s
.70834 .54379 m .70737 .59877 L .67876 .60263 L p .707 .577 .707 r
F P
0 g
s
.67419 .71166 m .67587 .73072 L .65503 .73499 L p .707 .577 .707 r
F P
0 g
s
.47629 .62838 m .47915 .66493 L .49229 .65515 L p .707 .577 .707 r
F P
0 g
s
.49229 .65515 m .48943 .61861 L .47629 .62838 L p .707 .577 .707 r
F P
0 g
s
.73995 .54287 m .73898 .59784 L .70737 .59877 L p .707 .577 .707 r
F P
0 g
s
.29491 .59788 m .29714 .54207 L .29244 .53396 L p .707 .577 .707 r
F P
0 g
s
.3195 .7153 m .32324 .73287 L .34686 .73615 L p .707 .577 .707 r
F P
0 g
s
.49133 .54979 m .48911 .60559 L .4944 .59788 L p .707 .577 .707 r
F P
0 g
s
.4944 .59788 m .49663 .54207 L .49133 .54979 L p .707 .577 .707 r
F P
0 g
s
.8176 .70037 m .81929 .71943 L .79521 .71942 L p .707 .577 .707 r
F P
0 g
s
.79521 .71942 m .79353 .70036 L .8176 .70037 L p .707 .577 .707 r
F P
0 g
s
.29583 .63508 m .29869 .67162 L .31446 .67894 L p .707 .577 .707 r
F P
0 g
s
.675 .67536 m .67373 .63773 L .70149 .6336 L p .707 .577 .707 r
F P
0 g
s
.79365 .6327 m .79492 .67034 L .7658 .6686 L p .707 .577 .707 r
F P
0 g
s
.7658 .6686 m .76453 .63096 L .79365 .6327 L p .707 .577 .707 r
F P
0 g
s
.48129 .68135 m .48503 .69893 L .49734 .68598 L p .707 .577 .707 r
F P
0 g
s
.49734 .68598 m .4936 .6684 L .48129 .68135 L p .707 .577 .707 r
F P
0 g
s
.70149 .6336 m .70276 .67124 L .675 .67536 L p .707 .577 .707 r
F P
0 g
s
.29244 .53396 m .29021 .58977 L .29491 .59788 L p .707 .577 .707 r
F P
0 g
s
.32324 .73287 m .3195 .7153 L .3034 .7083 L p .707 .577 .707 r
F P
0 g
s
.67587 .73072 m .67419 .71166 L .70145 .70761 L p .707 .577 .707 r
F P
0 g
s
.29869 .67162 m .29583 .63508 L .2894 .62602 L p .707 .577 .707 r
F P
0 g
s
.70145 .70761 m .70313 .72667 L .67587 .73072 L p .707 .577 .707 r
F P
0 g
s
.70276 .67124 m .70149 .6336 L .73278 .63127 L p .707 .577 .707 r
F P
0 g
s
.3034 .7083 m .30714 .72588 L .32324 .73287 L p .707 .577 .707 r
F P
0 g
s
.48943 .61861 m .49229 .65515 L .49582 .64525 L p .707 .577 .707 r
F P
0 g
s
.49582 .64525 m .49296 .6087 L .48943 .61861 L p .707 .577 .707 r
F P
0 g
s
.76453 .63096 m .7658 .6686 L .73405 .66891 L p .707 .577 .707 r
F P
0 g
s
.73405 .66891 m .73278 .63127 L .76453 .63096 L p .707 .577 .707 r
F P
0 g
s
.79353 .70036 m .79521 .71942 L .76588 .72073 L p .707 .577 .707 r
F P
0 g
s
.76588 .72073 m .76419 .70167 L .79353 .70036 L p .707 .577 .707 r
F P
0 g
s
.73278 .63127 m .73405 .66891 L .70276 .67124 L p .707 .577 .707 r
F P
0 g
s
.29021 .58977 m .29244 .53396 L .29773 .52624 L p .707 .577 .707 r
F P
0 g
s
.2894 .62602 m .29226 .66257 L .29869 .67162 L p .707 .577 .707 r
F P
0 g
s
.49663 .54207 m .4944 .59788 L .4897 .58976 L p .707 .577 .707 r
F P
0 g
s
.4897 .58976 m .49192 .53395 L .49663 .54207 L p .707 .577 .707 r
F P
0 g
s
.70313 .72667 m .70145 .70761 L .73246 .70417 L p .707 .577 .707 r
F P
0 g
s
.73246 .70417 m .73415 .72323 L .70313 .72667 L p .707 .577 .707 r
F P
0 g
s
.76419 .70167 m .76588 .72073 L .73415 .72323 L p .707 .577 .707 r
F P
0 g
s
.73415 .72323 m .73246 .70417 L .76419 .70167 L p .707 .577 .707 r
F P
0 g
s
.4936 .6684 m .49734 .68598 L .50013 .67389 L p .707 .577 .707 r
F P
0 g
s
.50013 .67389 m .49639 .65632 L .4936 .6684 L p .707 .577 .707 r
F P
0 g
s
.30714 .72588 m .3034 .7083 L .2964 .69828 L p .707 .577 .707 r
F P
0 g
s
.29773 .52624 m .29551 .58205 L .29021 .58977 L p .707 .577 .707 r
F P
0 g
s
.2964 .69828 m .30014 .71585 L .30714 .72588 L p .707 .577 .707 r
F P
0 g
s
.29226 .66257 m .2894 .62602 L .29293 .61612 L p .707 .577 .707 r
F P
0 g
s
.49296 .6087 m .49582 .64525 L .48939 .6362 L p .707 .577 .707 r
F P
0 g
s
.48939 .6362 m .48653 .59965 L .49296 .6087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29293 .61612 m .29579 .65267 L .29226 .66257 L p .707 .577 .707 r
F P
0 g
s
.29551 .58205 m .29773 .52624 L .3125 .51968 L p .707 .577 .707 r
F P
0 g
s
.49192 .53395 m .4897 .58976 L .47546 .58204 L p .707 .577 .707 r
F P
0 g
s
.47546 .58204 m .47769 .52624 L .49192 .53395 L p .707 .577 .707 r
F P
0 g
s
.49639 .65632 m .50013 .67389 L .49313 .66387 L p .707 .577 .707 r
F P
0 g
s
.49313 .66387 m .48939 .64629 L .49639 .65632 L p .707 .577 .707 r
F P
0 g
s
.30014 .71585 m .2964 .69828 L .29919 .6862 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3125 .51968 m .31027 .57548 L .29551 .58205 L p .707 .577 .707 r
F P
0 g
s
.29919 .6862 m .30293 .70377 L .30014 .71585 L p .707 .577 .707 r
F P
0 g
s
.29579 .65267 m .29293 .61612 L .30607 .60634 L p .707 .577 .707 r
F P
0 g
s
.48653 .59965 m .48939 .6362 L .47362 .62888 L p .707 .577 .707 r
F P
0 g
s
.47362 .62888 m .47076 .59233 L .48653 .59965 L p .707 .577 .707 r
F P
0 g
s
.31027 .57548 m .3125 .51968 L .3353 .51491 L p .707 .577 .707 r
F P
0 g
s
.47769 .52624 m .47546 .58204 L .45309 .57548 L p .707 .577 .707 r
F P
0 g
s
.45309 .57548 m .45532 .51967 L .47769 .52624 L p .707 .577 .707 r
F P
0 g
s
.30607 .60634 m .30893 .64289 L .29579 .65267 L p .707 .577 .707 r
F P
0 g
s
.48939 .64629 m .49313 .66387 L .47703 .65688 L p .707 .577 .707 r
F P
0 g
s
.47703 .65688 m .47329 .6393 L .48939 .64629 L p .707 .577 .707 r
F P
0 g
s
.30293 .70377 m .29919 .6862 L .3115 .67324 L p .707 .577 .707 r
F P
0 g
s
.3353 .51491 m .33307 .57071 L .31027 .57548 L p .707 .577 .707 r
F P
0 g
s
.30893 .64289 m .30607 .60634 L .32755 .59764 L p .707 .577 .707 r
F P
0 g
s
.3115 .67324 m .31524 .69082 L .30293 .70377 L p .707 .577 .707 r
F P
0 g
s
.47076 .59233 m .47362 .62888 L .45006 .62401 L p .707 .577 .707 r
F P
0 g
s
.45006 .62401 m .4472 .58746 L .47076 .59233 L p .707 .577 .707 r
F P
0 g
s
.33307 .57071 m .3353 .51491 L .36389 .5124 L p .707 .577 .707 r
F P
0 g
s
.45532 .51967 m .45309 .57548 L .42477 .57071 L p .707 .577 .707 r
F P
0 g
s
.42477 .57071 m .42699 .5149 L .45532 .51967 L p .707 .577 .707 r
F P
0 g
s
.32755 .59764 m .33041 .63419 L .30893 .64289 L p .707 .577 .707 r
F P
0 g
s
.36167 .5682 m .36389 .5124 L .39549 .5124 L p .707 .577 .707 r
F P
0 g
s
.36389 .5124 m .36167 .5682 L .33307 .57071 L p .707 .577 .707 r
F P
0 g
s
.42699 .5149 m .42477 .57071 L .39326 .5682 L p .707 .577 .707 r
F P
0 g
s
.39326 .5682 m .39549 .5124 L .42699 .5149 L p .707 .577 .707 r
F P
0 g
s
.47329 .6393 m .47703 .65688 L .4534 .6536 L p .707 .577 .707 r
F P
0 g
s
.4534 .6536 m .44966 .63602 L .47329 .6393 L p .707 .577 .707 r
F P
0 g
s
.31524 .69082 m .3115 .67324 L .33211 .66069 L p .707 .577 .707 r
F P
0 g
s
.33041 .63419 m .32755 .59764 L .35526 .59087 L p .707 .577 .707 r
F P
0 g
s
.39549 .5124 m .39326 .5682 L .36167 .5682 L p .707 .577 .707 r
F P
0 g
s
.4472 .58746 m .45006 .62401 L .42102 .62207 L p .707 .577 .707 r
F P
0 g
s
.42102 .62207 m .41816 .58552 L .4472 .58746 L p .707 .577 .707 r
F P
0 g
s
.33211 .66069 m .33585 .67827 L .31524 .69082 L p .707 .577 .707 r
F P
0 g
s
.35526 .59087 m .35812 .62742 L .33041 .63419 L p .707 .577 .707 r
F P
0 g
s
.35812 .62742 m .35526 .59087 L .38648 .58669 L p .707 .577 .707 r
F P
0 g
s
.41816 .58552 m .42102 .62207 L .38934 .62324 L p .707 .577 .707 r
F P
0 g
s
.38934 .62324 m .38648 .58669 L .41816 .58552 L p .707 .577 .707 r
F P
0 g
s
.44966 .63602 m .4534 .6536 L .42456 .65437 L p .707 .577 .707 r
F P
0 g
s
.42456 .65437 m .42082 .63679 L .44966 .63602 L p .707 .577 .707 r
F P
0 g
s
.33585 .67827 m .33211 .66069 L .35902 .64976 L p .707 .577 .707 r
F P
0 g
s
.38648 .58669 m .38934 .62324 L .35812 .62742 L p .707 .577 .707 r
F P
0 g
s
.35902 .64976 m .36276 .66734 L .33585 .67827 L p .707 .577 .707 r
F P
0 g
s
.42082 .63679 m .42456 .65437 L .39333 .6591 L p .707 .577 .707 r
F P
0 g
s
.39333 .6591 m .38959 .64152 L .42082 .63679 L p .707 .577 .707 r
F P
0 g
s
.36276 .66734 m .35902 .64976 L .38959 .64152 L p .707 .577 .707 r
F P
0 g
s
.38959 .64152 m .39333 .6591 L .36276 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001TOolA0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`P0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00EWoo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0I7oo001DOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00eooa4004Ioo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`07Ool60003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH8000nOol005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00Dgoo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Oomoogoo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001COol00eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000bOol0059oo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0059oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`03001JEP0000=JEP04
001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH01000
FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000=JEP@0009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60005FUH01000FUIJEUYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01000FUH005YF0P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00UYF
0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01P00FUH00000FUH000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP80
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF40001EYF00<005YFFUH00eYF00D005YF000005YF008000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF1@000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01@0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001COol0
1@00FUIJEUYF00001EYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF0000009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00Dgoo00D0
05YFFUIJEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF009JEQP000IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;Goo001DOol200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF
009JEPh000=oo`D00003Ool0000000T0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0041o
oaT000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEUYF001JEP000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH00UYF2@0015YF
00<005YFFUH015YF100015YF00@005YFFUIJEP8002ioo`00?7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP0300000eYF001JEP02FUH2000^Ool003Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP03
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20003FUH2000^Ool0039oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF0000000^
Ool0031oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03000^Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000IJEP03001JEP0000L000=JEP03001JEUYF009JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPH000EJEP<000MJEP03001J
EUYF00MJEPD000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEPD000IJEP03001JEUYF00UJEPD00003FUH0000000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH01000FUIJEUYF6@0015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH0
0UYF100000=JEP00FUH00UYF00@005YFFUH000EJEPD000IJEP03001JEUYF00T0009JEP03001JEUYF
00<000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD000=JEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000UYF00<005YF00000P001EYF00D005YFFUIJEP00009JEP03001J
EUYF00=JEPh000=JEP04001JEUYFFUH50003FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF1`000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00<007ooOol0;Goo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002
FUH300000eYF001JEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEPL0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00P005YF001JEP00FUH005YF
100015YF00@005YFFUH0009JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP03FUH;0005FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01@00FUIJEUYF00001UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF009JEPL000=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;Goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00D005YFFUIJ
EP0000IJEP@000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00D000=JEP80
00AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP04
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF00000004FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH015YF5@0015YF00<005YFFUH0
0`0025YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00AJEP00000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF0080
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01@0025YF00<005YFFUH01UYF0`0015YF00<005YF00000UYF00<005YFFUH01EYF10001UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00;Woo000]Ool20004FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF000015YF0P0015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF0`000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUHO0003FUH00`00
FUIJEP02FUH2000^Ool002eoo`8000=JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00AJEP800003FUH005YF009JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF00<005YFFUH00eYF00<005YF
FUH05@0015YF00<005YFFUH01EYF00<005YF000010000eYF0P00;Woo000]Ool2000015YF00000000
1EYF00<005YFFUH00UYF5`000eYF0P001UYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00@005YFFUIJEP800004FUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF1@001eYF00<005YFFUH015YF1@00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP000000;Woo000]Ool30002FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP03FUH2
00000eYF001JEP06FUH00`00FUIJEP04FUH30004FUH70008FUH01000FUIJEP0015YF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
100015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000P00;Woo000]Ool20003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH0200015YF00<005YFFUH00UYF2@00
0eYF00<005YFFUH02EYF100015YF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]Ool20003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF1`00
00AJEP00FUIJEPT00003FUH0000000<000IJEP03001JEUYF00UJEP04001JEUYF0004FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20002FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P001EYF0P000eYF00@005YFFUH000EJ
EPD000IJEP03001JEUYF00MJEP8000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP03001JEP0000IJEPD0009JEP03001JEUYF00AJEP<000MJEP03001JEUYF00EJEP8000IJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000`Ool002ioo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<005YF00000P000UYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP05001JEUYF001JEP020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YF
FUH015YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0001P002moo`00;Goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF10001UYF00<0
05YFFUH00P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YF0000200015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH0
0UYF00@005YFFUH000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP8000aJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00d000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF3P0015YF00@005YFFUIJEP@0
0003FUH005YF00AJEP03001JEUYF009JEP04001JEUYF0006FUH60006FUH00`00FUIJEP05FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00@000ioo`X0
009JEPD0009JEP03001JEUYF009JEP04001JEUYF0003FUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=J
EP03001JEUYF009JEP@001]oo`80009JEP04001JEUYFFUH>0006FUH00`00FUIJEP07FUH00`00FUH0
00020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHI
00000eYF001oo`0/Ool002eoo`8000=JEP03001JEP00008001moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02
000]Ool002eoo`8000=JEP8000Qooa0000]oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00@005YFFUIJEQ4000QJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEP00000^Ool002eoo`800004FUH00000FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF1@001eYF00<005YFFUH0
0eYF100025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool30003FUH00`00FUH00002
0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003Ool50003FUH00`00FUIJEP05
FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF00000P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00<goo000]Ool30003
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003
Ool?0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00=Woo000]Ool01000FUH005YF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF
00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000kOol002eoo`03001JEP00
008000AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01eYF5P001UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEPD0009JEP03001JEUYF00AJEP03001JEUYF009JEQ4004Aoo`00
;Woo0P0000=JEP00FUH00eYF1@001eYF00<005YFFUH01UYF1`001UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP090007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF3`00E7oo
000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF00<005YFFUH01EYF0`000UYF00@005YFFUH000IJEP03001JEUYF00EJEPL000]JEP03001J
EUYF00YJEP03001JEUYF00UJEPD0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF009JEP8005=oo`00;Goo00D005YFFUH005YF008000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEP00009JEP04
001JEUYF0006FUH00`00FUIJEP050006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP03FUH2001COol002eoo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH00eYF1@002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0P0015YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF0P00
Dgoo000]Ool01000FUH007oo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0P0000=JEP00FUH00eYF0P000UYF00@005YFFUIJEP8000AJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF
00=JEP8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005=oo`00;Goo0P0017oo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00AJEP80009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<007oo00001@0015YF00<005YF
FUH00UYF00<005YF0000Dgoo000]Ool00`00Oomoo`05Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF0`001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF2`0000=JEP00FUH00eYF00<005YF0000Dgoo000]Ool2000:Ool30006FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUH0000400001EYF000005YF00000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF1@001eYF00<005YF00000P000eYF00<005YF0000Dgoo000/Ool00`00
FUH0000=Ool40002FUH00`00FUIJEP02FUH50008FUH00`00FUIJEP02FUH50005Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH2000015YF001JEP00
Dgoo000/Ool01000FUIJEP0047oo6@002goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00P001eYF00<005YFFUH00eYF0`0000=JEP00Ool0DWoo000/Ool00`00FUIJEP02000FOol5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00Dgoo000/Ool01P00FUIJEP00FUH001Ioo`<001Yoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF00=JEP04001JEUYFFUH2
001COol002eoo`8000=JEP03001oogoo031oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEP000007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000]Ool20004FUH2000_
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000E7oo000^Ool00`00FUIJEP02FUH01000FUH00000;7oo00<005YF0000
0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF00<005YFFUH00P00E7oo
000_Ool20002FUH01000FUIJEUYF0P00:7oo0P000UYF00@007ooOomoo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000AJEP@0009JEP04001JEUYFFUH5001FOol0035oo`<000EJEP@0025oo`<00005FUH005YFFUH0
0004Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P0025YF00<005YF00001@00Fgoo000cOol00`00FUIJEP04FUH0
0`00FUIJEP04000JOol30004FUH00`00FUH00007Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000FUH000QJEP04001J
EUYFFUH2001MOol003Aoo`8000AJEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP8000ao
o`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEPT000IJ
EP03001JEUYF00AJEP8005]oo`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF
00<005YFFUH00eYF0P004Goo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02@001Goo0P0015YF00<005YFFUH01EYF0`00FGoo000hOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000HOol80006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH:0002Ool50007Ool300000eYF001JEP06FUH00`00FUIJEP02001GOol003Yo
o`8000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080029ooaX0
00MJEP03001JEUYF00L000Yoo`<000EJEP03001JEUYF009JEP8005Ioo`00?7oo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo100000=JEP00FUH01eYF00<005YFFUH0
0eYF20002Goo100000=JEP00FUH00eYF00<005YF0000EGoo0010Ool70004FUH00`00FUIJEP06FUH0
0`00FUIJEP04000oOol30006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005Ool20003FUH01000
FUIJEP00EGoo0017Ool@0016Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
2@0000EJEP00FUIJEP0005Eoo`00XGoo1@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP000000EGoo002VOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH00000EWoo002ZOol50006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000EWoo002_Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
EWoo002cOolD001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6133 .75139 m .60967 .69641 L .57804 .69707 L p .707 .577 .707 r
F P
0 g
s
.60967 .69641 m .6133 .75139 L .64467 .74777 L p .707 .577 .707 r
F P
0 g
s
.64467 .74777 m .64104 .69279 L .60967 .69641 L p .707 .577 .707 r
F P
0 g
s
.58167 .75204 m .57804 .69707 L .54925 .6947 L p .707 .577 .707 r
F P
0 g
s
.57804 .69707 m .58167 .75204 L .6133 .75139 L p .707 .577 .707 r
F P
0 g
s
.64104 .69279 m .64467 .74777 L .67271 .74155 L p .707 .577 .707 r
F P
0 g
s
.67271 .74155 m .66908 .68657 L .64104 .69279 L p .707 .577 .707 r
F P
0 g
s
.55288 .74968 m .54925 .6947 L .52611 .68954 L p .707 .577 .707 r
F P
0 g
s
.54925 .6947 m .55288 .74968 L .58167 .75204 L p .707 .577 .707 r
F P
0 g
s
.66908 .68657 m .67271 .74155 L .69468 .73333 L p .707 .577 .707 r
F P
0 g
s
.69468 .73333 m .69105 .67835 L .66908 .68657 L p .707 .577 .707 r
F P
0 g
s
.61956 .80396 m .62423 .76658 L .59253 .76252 L p .707 .577 .707 r
F P
0 g
s
.62423 .76658 m .61956 .80396 L .65011 .80586 L p .707 .577 .707 r
F P
0 g
s
.65011 .80586 m .65479 .76849 L .62423 .76658 L p .707 .577 .707 r
F P
0 g
s
.58785 .79989 m .59253 .76252 L .56278 .75668 L p .707 .577 .707 r
F P
0 g
s
.59253 .76252 m .58785 .79989 L .61956 .80396 L p .707 .577 .707 r
F P
0 g
s
.56278 .75668 m .5581 .79406 L .58785 .79989 L p .707 .577 .707 r
F P
0 g
s
.65479 .76849 m .65011 .80586 L .67653 .80541 L p .707 .577 .707 r
F P
0 g
s
.67653 .80541 m .6812 .76804 L .65479 .76849 L p .707 .577 .707 r
F P
0 g
s
.5581 .79406 m .56278 .75668 L .5379 .74965 L p .707 .577 .707 r
F P
0 g
s
.58254 .82828 m .58859 .8101 L .55976 .79969 L p .707 .577 .707 r
F P
0 g
s
.58859 .8101 m .58254 .82828 L .61288 .83831 L p .707 .577 .707 r
F P
0 g
s
.61288 .83831 m .61893 .82013 L .58859 .8101 L p .707 .577 .707 r
F P
0 g
s
.52611 .68954 m .52974 .74452 L .55288 .74968 L p .707 .577 .707 r
F P
0 g
s
.61893 .82013 m .61288 .83831 L .64176 .84697 L p .707 .577 .707 r
F P
0 g
s
.64176 .84697 m .64782 .82879 L .61893 .82013 L p .707 .577 .707 r
F P
0 g
s
.55976 .79969 m .55371 .81787 L .58254 .82828 L p .707 .577 .707 r
F P
0 g
s
.52974 .74452 m .52611 .68954 L .5109 .6821 L p .707 .577 .707 r
F P
0 g
s
.69105 .67835 m .69468 .73333 L .70843 .72392 L p .707 .577 .707 r
F P
0 g
s
.70843 .72392 m .7048 .66894 L .69105 .67835 L p .707 .577 .707 r
F P
0 g
s
.5379 .74965 m .53322 .78702 L .5581 .79406 L p .707 .577 .707 r
F P
0 g
s
.55371 .81787 m .55976 .79969 L .53526 .78991 L p .707 .577 .707 r
F P
0 g
s
.53526 .78991 m .52921 .8081 L .55371 .81787 L p .707 .577 .707 r
F P
0 g
s
.64782 .82879 m .64176 .84697 L .66636 .85343 L p .707 .577 .707 r
F P
0 g
s
.66636 .85343 m .67241 .83525 L .64782 .82879 L p .707 .577 .707 r
F P
0 g
s
.6812 .76804 m .67653 .80541 L .69622 .80265 L p .707 .577 .707 r
F P
0 g
s
.69622 .80265 m .70089 .76528 L .6812 .76804 L p .707 .577 .707 r
F P
0 g
s
.53322 .78702 m .5379 .74965 L .52032 .74211 L p .707 .577 .707 r
F P
0 g
s
.5109 .6821 m .51453 .73707 L .52974 .74452 L p .707 .577 .707 r
F P
0 g
s
.52032 .74211 m .51564 .77948 L .53322 .78702 L p .707 .577 .707 r
F P
0 g
s
.52921 .8081 m .53526 .78991 L .5175 .78173 L p .707 .577 .707 r
F P
0 g
s
.5175 .78173 m .51145 .79992 L .52921 .8081 L p .707 .577 .707 r
F P
0 g
s
.67241 .83525 m .66636 .85343 L .68427 .85704 L p .707 .577 .707 r
F P
0 g
s
.68427 .85704 m .69032 .83886 L .67241 .83525 L p .707 .577 .707 r
F P
0 g
s
.51453 .73707 m .5109 .6821 L .5051 .67309 L p .707 .577 .707 r
F P
0 g
s
.7048 .66894 m .70843 .72392 L .7126 .71424 L p .707 .577 .707 r
F P
0 g
s
.7126 .71424 m .70897 .65926 L .7048 .66894 L p .707 .577 .707 r
F P
0 g
s
.70089 .76528 m .69622 .80265 L .70725 .79785 L p .707 .577 .707 r
F P
0 g
s
.70725 .79785 m .71193 .76048 L .70089 .76528 L p .707 .577 .707 r
F P
0 g
s
.51564 .77948 m .52032 .74211 L .51176 .73479 L p .707 .577 .707 r
F P
0 g
s
.51185 .73291 m .51453 .73707 L p .51271 .72476 L .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .50709 .77217 L .51564 .77948 L p .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .51307 .72843 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.50709 .77217 m .51097 .74111 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.51097 .74111 m .51176 .73479 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.5051 .67309 m .50873 .72807 L .51185 .73291 L p .707 .577 .707 r
F P
0 g
s
.51271 .72476 m .5051 .67309 L .51185 .73291 L .707 .577 .707 r
F
.51145 .79992 m .5175 .78173 L .50821 .77595 L p F P
0 g
s
.50821 .77595 m .50215 .79413 L .51145 .79992 L p .707 .577 .707 r
F P
0 g
s
.69032 .83886 m .68427 .85704 L .69373 .85745 L p .707 .577 .707 r
F P
0 g
s
.69373 .85745 m .69978 .83927 L .69032 .83886 L p .707 .577 .707 r
F P
0 g
s
.50873 .72807 m .5051 .67309 L .50928 .66341 L p .707 .577 .707 r
F P
0 g
s
.70897 .65926 m .7126 .71424 L .7068 .70523 L p .707 .577 .707 r
F P
0 g
s
.7068 .70523 m .70317 .65026 L .70897 .65926 L p .707 .577 .707 r
F P
0 g
s
.47927 .82152 m .47927 .31963 L .43617 .31604 L p .707 .577 .707 r
F P
0 g
s
.50928 .66341 m .5129 .71839 L .50873 .72807 L p .707 .577 .707 r
F P
0 g
s
.51307 .72843 m .50839 .7658 L .50709 .77217 L p .707 .577 .707 r
F P
0 g
s
.50215 .79413 m .50821 .77595 L .50829 .77313 L p .707 .578 .707 r
F P
0 g
s
.50829 .77313 m .50224 .79131 L .50215 .79413 L p .707 .578 .707 r
F P
0 g
s
.5129 .71839 m .50928 .66341 L .52302 .654 L p .707 .577 .707 r
F P
0 g
s
.50839 .7658 m .51307 .72843 L .5241 .72363 L p .707 .577 .707 r
F P
0 g
s
.52302 .654 m .52665 .70898 L .5129 .71839 L p .707 .577 .707 r
F P
0 g
s
.5241 .72363 m .51943 .761 L .50839 .7658 L p .707 .577 .707 r
F P
0 g
s
.50224 .79131 m .50829 .77313 L .51775 .77354 L p .707 .577 .707 r
F P
0 g
s
.51775 .77354 m .5117 .79172 L .50224 .79131 L p .707 .577 .707 r
F P
0 g
s
.5117 .79172 m .51775 .77354 L .53566 .77715 L p .707 .577 .707 r
F P
0 g
s
.53566 .77715 m .52961 .79534 L .5117 .79172 L p .707 .577 .707 r
F P
0 g
s
.47927 .31963 m .47927 .82152 L .52439 .82137 L p .707 .577 .707 r
F P
0 g
s
.52665 .70898 m .52302 .654 L .54499 .64578 L p .707 .577 .707 r
F P
0 g
s
.51943 .761 m .5241 .72363 L .54379 .72087 L p .707 .577 .707 r
F P
0 g
s
.54379 .72087 m .53912 .75825 L .51943 .761 L p .707 .577 .707 r
F P
0 g
s
.52439 .82137 m .52439 .31948 L .47927 .31963 L p .707 .577 .707 r
F P
0 g
s
.54499 .64578 m .54862 .70076 L .52665 .70898 L p .707 .577 .707 r
F P
0 g
s
.54862 .70076 m .54499 .64578 L .57303 .63956 L p .707 .577 .707 r
F P
0 g
s
.57303 .63956 m .57666 .69454 L .54862 .70076 L p .707 .577 .707 r
F P
0 g
s
.53912 .75825 m .54379 .72087 L .57021 .72042 L p .707 .577 .707 r
F P
0 g
s
.57021 .72042 m .56554 .75779 L .53912 .75825 L p .707 .577 .707 r
F P
0 g
s
.52961 .79534 m .53566 .77715 L .56026 .78361 L p .707 .577 .707 r
F P
0 g
s
.56026 .78361 m .55421 .80179 L .52961 .79534 L p .707 .577 .707 r
F P
0 g
s
.55421 .80179 m .56026 .78361 L .58914 .79227 L p .707 .577 .707 r
F P
0 g
s
.58914 .79227 m .58309 .81046 L .55421 .80179 L p .707 .577 .707 r
F P
0 g
s
.52439 .31948 m .52439 .82137 L .56713 .81748 L p .707 .577 .707 r
F P
0 g
s
.56554 .75779 m .57021 .72042 L .60076 .72232 L p .707 .577 .707 r
F P
0 g
s
.60076 .72232 m .59609 .7597 L .56554 .75779 L p .707 .577 .707 r
F P
0 g
s
.56713 .81748 m .56713 .31559 L .52439 .31948 L p .707 .577 .707 r
F P
0 g
s
.71193 .76048 m .70725 .79785 L .70856 .79149 L p .707 .577 .707 r
F P
0 g
s
.70856 .79149 m .71323 .75411 L .71193 .76048 L p .707 .577 .707 r
F P
0 g
s
.43617 .81793 m .43617 .31604 L .39932 .30905 L p .707 .577 .707 r
F P
0 g
s
.43617 .31604 m .43617 .81793 L .47927 .82152 L p .707 .577 .707 r
F P
0 g
s
.57666 .69454 m .57303 .63956 L .60441 .63594 L p .707 .577 .707 r
F P
0 g
s
.60441 .63594 m .60803 .69092 L .57666 .69454 L p .707 .577 .707 r
F P
0 g
s
.63247 .72639 m .62779 .76376 L .59609 .7597 L p .707 .577 .707 r
F P
0 g
s
.59609 .7597 m .60076 .72232 L .63247 .72639 L p .707 .577 .707 r
F P
0 g
s
.58309 .81046 m .58914 .79227 L .61949 .8023 L p .707 .577 .707 r
F P
0 g
s
.61949 .8023 m .61343 .82049 L .58309 .81046 L p .707 .577 .707 r
F P
0 g
s
.56713 .31559 m .56713 .81748 L .6033 .81023 L p .707 .577 .707 r
F P
0 g
s
.6033 .81023 m .6033 .30834 L .56713 .31559 L p .707 .577 .707 r
F P
0 g
s
.69978 .83927 m .69373 .85745 L .69381 .85463 L p .707 .578 .707 r
F P
0 g
s
.69381 .85463 m .69987 .83645 L .69978 .83927 L p .707 .578 .707 r
F P
0 g
s
.26593 .70896 m .26432 .6526 L .23264 .65257 L p .707 .577 .707 r
F P
0 g
s
.26432 .6526 m .26593 .70896 L .29735 .70686 L p .707 .577 .707 r
F P
0 g
s
.29735 .70686 m .29574 .65051 L .26432 .6526 L p .707 .577 .707 r
F P
0 g
s
.70317 .65026 m .7068 .70523 L .69159 .69779 L p .707 .577 .707 r
F P
0 g
s
.69159 .69779 m .68796 .64281 L .70317 .65026 L p .707 .577 .707 r
F P
0 g
s
.23425 .70893 m .23264 .65257 L .2038 .65043 L p .707 .577 .707 r
F P
0 g
s
.23264 .65257 m .23425 .70893 L .26593 .70896 L p .707 .577 .707 r
F P
0 g
s
.29574 .65051 m .29735 .70686 L .32543 .70286 L p .707 .577 .707 r
F P
0 g
s
.32543 .70286 m .32382 .6465 L .29574 .65051 L p .707 .577 .707 r
F P
0 g
s
.71323 .75411 m .70856 .79149 L .7 .78418 L p .707 .577 .707 r
F P
0 g
s
.7 .78418 m .70468 .7468 L .71323 .75411 L p .707 .577 .707 r
F P
0 g
s
.39932 .81094 m .39932 .30905 L .37233 .29934 L p .707 .577 .707 r
F P
0 g
s
.39932 .30905 m .39932 .81094 L .43617 .81793 L p .707 .577 .707 r
F P
0 g
s
.2038 .65043 m .2054 .70679 L .23425 .70893 L p .707 .577 .707 r
F P
0 g
s
.63603 .63529 m .63966 .69026 L .60803 .69092 L p .707 .577 .707 r
F P
0 g
s
.60803 .69092 m .60441 .63594 L .63603 .63529 L p .707 .577 .707 r
F P
0 g
s
.61343 .82049 m .61949 .8023 L .64832 .81271 L p .707 .577 .707 r
F P
0 g
s
.6033 .30834 m .6033 .81023 L .62935 .80035 L p .707 .577 .707 r
F P
0 g
s
.66222 .73222 m .65754 .7696 L .62779 .76376 L p .707 .577 .707 r
F P
0 g
s
.62779 .76376 m .63247 .72639 L .66222 .73222 L p .707 .577 .707 r
F P
0 g
s
.62935 .80035 m .62935 .29846 L .6033 .30834 L p .707 .577 .707 r
F P
0 g
s
.2054 .70679 m .2038 .65043 L .18062 .64638 L p .707 .577 .707 r
F P
0 g
s
.32382 .6465 m .32543 .70286 L .34742 .69733 L p .707 .577 .707 r
F P
0 g
s
.34742 .69733 m .34582 .64097 L .32382 .6465 L p .707 .577 .707 r
F P
0 g
s
.27387 .78458 m .27598 .74881 L .24409 .74671 L p .707 .577 .707 r
F P
0 g
s
.27598 .74881 m .27387 .78458 L .3046 .783 L p .707 .577 .707 r
F P
0 g
s
.3046 .783 m .30671 .74723 L .27598 .74881 L p .707 .577 .707 r
F P
0 g
s
.24198 .78248 m .24409 .74671 L .21415 .74114 L p .707 .577 .707 r
F P
0 g
s
.24409 .74671 m .24198 .78248 L .27387 .78458 L p .707 .577 .707 r
F P
0 g
s
.69987 .83645 m .69381 .85463 L .68452 .84885 L p .707 .577 .707 r
F P
0 g
s
.68452 .84885 m .69058 .83067 L .69987 .83645 L p .707 .577 .707 r
F P
0 g
s
.18062 .64638 m .18222 .70274 L .2054 .70679 L p .707 .577 .707 r
F P
0 g
s
.68796 .64281 m .69159 .69779 L .66845 .69263 L p .707 .577 .707 r
F P
0 g
s
.66845 .69263 m .66483 .63765 L .68796 .64281 L p .707 .577 .707 r
F P
0 g
s
.30671 .74723 m .3046 .783 L .33115 .77789 L p .707 .577 .707 r
F P
0 g
s
.33115 .77789 m .33326 .74213 L .30671 .74723 L p .707 .577 .707 r
F P
0 g
s
.21204 .77691 m .21415 .74114 L .1891 .73264 L p .707 .577 .707 r
F P
0 g
s
.21415 .74114 m .21204 .77691 L .24198 .78248 L p .707 .577 .707 r
F P
0 g
s
.18222 .70274 m .18062 .64638 L .16537 .64082 L p .707 .577 .707 r
F P
0 g
s
.70468 .7468 m .7 .78418 L .68242 .77663 L p .707 .577 .707 r
F P
0 g
s
.68242 .77663 m .6871 .73926 L .70468 .7468 L p .707 .577 .707 r
F P
0 g
s
.34582 .64097 m .34742 .69733 L .36117 .69082 L p .707 .577 .707 r
F P
0 g
s
.36117 .69082 m .35957 .63446 L .34582 .64097 L p .707 .577 .707 r
F P
0 g
s
.1891 .73264 m .18699 .76841 L .21204 .77691 L p .707 .577 .707 r
F P
0 g
s
.33326 .74213 m .33115 .77789 L .35093 .76976 L p .707 .577 .707 r
F P
0 g
s
.35093 .76976 m .35304 .734 L .33326 .74213 L p .707 .577 .707 r
F P
0 g
s
.37233 .80123 m .37233 .29934 L .35783 .28787 L p .707 .577 .707 r
F P
0 g
s
.37233 .29934 m .37233 .80123 L .39932 .81094 L p .707 .577 .707 r
F P
0 g
s
.18699 .76841 m .1891 .73264 L .17138 .72204 L p .707 .577 .707 r
F P
0 g
s
.16537 .64082 m .16697 .69718 L .18222 .70274 L p .707 .577 .707 r
F P
0 g
s
.66483 .63765 m .66845 .69263 L .63966 .69026 L p .707 .577 .707 r
F P
0 g
s
.63966 .69026 m .63603 .63529 L .66483 .63765 L p .707 .577 .707 r
F P
0 g
s
.62935 .29846 m .62935 .80035 L .64275 .78878 L p .707 .577 .707 r
F P
0 g
s
.64275 .78878 m .64275 .28689 L .62935 .29846 L p .707 .577 .707 r
F P
0 g
s
.24223 .83481 m .24504 .81837 L .21492 .80962 L p .707 .577 .707 r
F P
0 g
s
.24504 .81837 m .24223 .83481 L .27386 .83878 L p .707 .577 .707 r
F P
0 g
s
.27386 .83878 m .27666 .82234 L .24504 .81837 L p .707 .577 .707 r
F P
0 g
s
.27666 .82234 m .27386 .83878 L .3039 .83758 L p .707 .577 .707 r
F P
0 g
s
.3039 .83758 m .3067 .82114 L .27666 .82234 L p .707 .577 .707 r
F P
0 g
s
.69058 .83067 m .68452 .84885 L .66676 .84067 L p .707 .577 .707 r
F P
0 g
s
.66676 .84067 m .67281 .82249 L .69058 .83067 L p .707 .577 .707 r
F P
0 g
s
.21212 .82606 m .21492 .80962 L .18927 .79694 L p .707 .577 .707 r
F P
0 g
s
.21492 .80962 m .21212 .82606 L .24223 .83481 L p .707 .577 .707 r
F P
0 g
s
.17138 .72204 m .16927 .75781 L .18699 .76841 L p .707 .577 .707 r
F P
0 g
s
.16697 .69718 m .16537 .64082 L .15954 .6343 L p .707 .577 .707 r
F P
0 g
s
.3067 .82114 m .3039 .83758 L .32942 .83133 L p .707 .577 .707 r
F P
0 g
s
.32942 .83133 m .33222 .81489 L .3067 .82114 L p .707 .577 .707 r
F P
0 g
s
.6871 .73926 m .68242 .77663 L .65754 .7696 L p .707 .577 .707 r
F P
0 g
s
.65754 .7696 m .66222 .73222 L .6871 .73926 L p .707 .577 .707 r
F P
0 g
s
.18927 .79694 m .18647 .81339 L .21212 .82606 L p .707 .577 .707 r
F P
0 g
s
.35957 .63446 m .36117 .69082 L .36534 .68396 L p .707 .577 .707 r
F P
0 g
s
.36534 .68396 m .36374 .62761 L .35957 .63446 L p .707 .577 .707 r
F P
0 g
s
.35304 .734 m .35093 .76976 L .36199 .7594 L p .707 .577 .707 r
F P
0 g
s
.36199 .7594 m .36411 .72364 L .35304 .734 L p .707 .577 .707 r
F P
0 g
s
.18647 .81339 m .18927 .79694 L .17059 .78158 L p .707 .577 .707 r
F P
0 g
s
.16927 .75781 m .17138 .72204 L .16274 .71039 L p .707 .577 .707 r
F P
0 g
s
.15954 .6343 m .16114 .69065 L .16697 .69718 L p .707 .577 .707 r
F P
0 g
s
.17059 .78158 m .16778 .79803 L .18647 .81339 L p .707 .577 .707 r
F P
0 g
s
.67281 .82249 m .66676 .84067 L .64226 .8309 L p .707 .577 .707 r
F P
0 g
s
.64226 .8309 m .64832 .81271 L .67281 .82249 L p .707 .577 .707 r
F P
0 g
s
.33222 .81489 m .32942 .83133 L .34791 .82064 L p .707 .577 .707 r
F P
0 g
s
.34791 .82064 m .35072 .8042 L .33222 .81489 L p .707 .577 .707 r
F P
0 g
s
.16274 .71039 m .16063 .74615 L .16927 .75781 L p .707 .577 .707 r
F P
0 g
s
.36411 .72364 m .36199 .7594 L .36327 .74783 L p .707 .577 .707 r
F P
0 g
s
.36327 .74783 m .36538 .71206 L .36411 .72364 L p .707 .577 .707 r
F P
0 g
s
.36538 .71206 m .36327 .74783 L .35462 .73617 L p .707 .577 .707 r
F P
0 g
s
.35462 .73617 m .35674 .70041 L .36538 .71206 L p .707 .577 .707 r
F P
0 g
s
.35791 .62108 m .35952 .67744 L .34427 .67188 L p .707 .577 .707 r
F P
0 g
s
.34427 .67188 m .34266 .61552 L .35791 .62108 L p .707 .577 .707 r
F P
0 g
s
.36026 .77401 m .36038 .79011 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35746 .79046 m .35856 .78401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35856 .78401 m .36026 .77401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35725 .27577 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36026 .77401 m .35746 .79046 L .34758 .77392 L p .707 .577 .707 r
F P
0 g
s
.34758 .77392 m .35038 .75747 L .36026 .77401 L p .707 .577 .707 r
F P
0 g
s
.35783 .78976 m .35783 .75807 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.35783 .75807 m .35783 .28787 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36374 .62761 m .36534 .68396 L .35952 .67744 L p .707 .577 .707 r
F P
0 g
s
.35952 .67744 m .35791 .62108 L .36374 .62761 L p .707 .577 .707 r
F P
0 g
s
.35757 .80656 m .36038 .79011 L .35072 .8042 L p .707 .577 .707 r
F P
0 g
s
.36038 .79011 m .35757 .80656 L .35746 .79046 L p .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35783 .78976 L .37233 .80123 L p .707 .577 .707 r
F P
0 g
s
.64275 .28689 m .64275 .78878 L .64217 .77667 L p .708 .578 .707 r
F P
0 g
s
.64217 .77667 m .64217 .27478 L .64275 .28689 L p .708 .578 .707 r
F P
0 g
s
.16778 .79803 m .17059 .78158 L .16071 .76505 L p .707 .577 .707 r
F P
0 g
s
.16114 .69065 m .15954 .6343 L .16371 .62744 L p .707 .577 .707 r
F P
0 g
s
.64832 .81271 m .64226 .8309 L .61343 .82049 L p .707 .577 .707 r
F P
0 g
s
.16063 .74615 m .16274 .71039 L .16401 .69881 L p .707 .577 .707 r
F P
0 g
s
.16071 .76505 m .1579 .78149 L .16778 .79803 L p .707 .577 .707 r
F P
0 g
s
.35072 .8042 m .34791 .82064 L .35757 .80656 L p .707 .577 .707 r
F P
0 g
s
.16371 .62744 m .16531 .6838 L .16114 .69065 L p .707 .577 .707 r
F P
0 g
s
.16401 .69881 m .1619 .73458 L .16063 .74615 L p .707 .577 .707 r
F P
0 g
s
.1579 .78149 m .16071 .76505 L .16059 .74895 L p .707 .577 .707 r
F P
0 g
s
.16531 .6838 m .16371 .62744 L .17746 .62093 L p .707 .577 .707 r
F P
0 g
s
.16059 .74895 m .15779 .76539 L .1579 .78149 L p .707 .577 .707 r
F P
0 g
s
.35725 .27577 m .35725 .77766 L .35783 .78976 L p .708 .578 .707 r
F P
0 g
s
.35725 .77766 m .35725 .27577 L .37064 .2642 L p .707 .577 .707 r
F P
0 g
s
.1619 .73458 m .16401 .69881 L .17508 .68845 L p .707 .577 .707 r
F P
0 g
s
.64217 .27478 m .64217 .77667 L .62767 .76521 L p .707 .577 .707 r
F P
0 g
s
.62767 .76521 m .62767 .26332 L .64217 .27478 L p .707 .577 .707 r
F P
0 g
s
.17746 .62093 m .17907 .67729 L .16531 .6838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17508 .68845 m .17297 .72422 L .1619 .73458 L p .707 .577 .707 r
F P
0 g
s
.15779 .76539 m .16059 .74895 L .17025 .73486 L p .707 .577 .707 r
F P
0 g
s
.17907 .67729 m .17746 .62093 L .19946 .6154 L p .707 .577 .707 r
F P
0 g
s
.17025 .73486 m .16745 .7513 L .15779 .76539 L p .707 .577 .707 r
F P
0 g
s
.35674 .70041 m .35462 .73617 L .33691 .72558 L p .707 .577 .707 r
F P
0 g
s
.33691 .72558 m .33902 .68981 L .35674 .70041 L p .707 .577 .707 r
F P
0 g
s
.34266 .61552 m .34427 .67188 L .32108 .66783 L p .707 .577 .707 r
F P
0 g
s
.32108 .66783 m .31948 .61147 L .34266 .61552 L p .707 .577 .707 r
F P
0 g
s
.17297 .72422 m .17508 .68845 L .19486 .68032 L p .707 .577 .707 r
F P
0 g
s
.19946 .6154 m .20106 .67176 L .17907 .67729 L p .707 .577 .707 r
F P
0 g
s
.37064 .76609 m .37064 .2642 L .3967 .25431 L p .707 .577 .707 r
F P
0 g
s
.37064 .2642 m .37064 .76609 L .35725 .77766 L p .707 .577 .707 r
F P
0 g
s
.16745 .7513 m .17025 .73486 L .18875 .72417 L p .707 .577 .707 r
F P
0 g
s
.19486 .68032 m .19275 .71609 L .17297 .72422 L p .707 .577 .707 r
F P
0 g
s
.62767 .26332 m .62767 .76521 L .60068 .7555 L p .707 .577 .707 r
F P
0 g
s
.60068 .7555 m .60068 .25361 L .62767 .26332 L p .707 .577 .707 r
F P
0 g
s
.20106 .67176 m .19946 .6154 L .22754 .6114 L p .707 .577 .707 r
F P
0 g
s
.31948 .61147 m .32108 .66783 L .29224 .66569 L p .707 .577 .707 r
F P
0 g
s
.29224 .66569 m .29064 .60933 L .31948 .61147 L p .707 .577 .707 r
F P
0 g
s
.33902 .68981 m .33691 .72558 L .31186 .71707 L p .707 .577 .707 r
F P
0 g
s
.31186 .71707 m .31397 .68131 L .33902 .68981 L p .707 .577 .707 r
F P
0 g
s
.18875 .72417 m .18594 .74061 L .16745 .7513 L p .707 .577 .707 r
F P
0 g
s
.19275 .71609 m .19486 .68032 L .22141 .67522 L p .707 .577 .707 r
F P
0 g
s
.35038 .75747 m .34758 .77392 L .32889 .75856 L p .707 .577 .707 r
F P
0 g
s
.32889 .75856 m .3317 .74212 L .35038 .75747 L p .707 .577 .707 r
F P
0 g
s
.22754 .6114 m .22914 .66775 L .20106 .67176 L p .707 .577 .707 r
F P
0 g
s
.22914 .66775 m .22754 .6114 L .25896 .6093 L p .707 .577 .707 r
F P
0 g
s
.29064 .60933 m .29224 .66569 L .26056 .66566 L p .707 .577 .707 r
F P
0 g
s
.26056 .66566 m .25896 .6093 L .29064 .60933 L p .707 .577 .707 r
F P
0 g
s
.18594 .74061 m .18875 .72417 L .21427 .71792 L p .707 .577 .707 r
F P
0 g
s
.22141 .67522 m .2193 .71098 L .19275 .71609 L p .707 .577 .707 r
F P
0 g
s
.25896 .6093 m .26056 .66566 L .22914 .66775 L p .707 .577 .707 r
F P
0 g
s
.31397 .68131 m .31186 .71707 L .28192 .7115 L p .707 .577 .707 r
F P
0 g
s
.28192 .7115 m .28403 .67573 L .31397 .68131 L p .707 .577 .707 r
F P
0 g
s
.2193 .71098 m .22141 .67522 L .25214 .67363 L p .707 .577 .707 r
F P
0 g
s
.21427 .71792 m .21146 .73436 L .18594 .74061 L p .707 .577 .707 r
F P
0 g
s
.73944 .66108 m .74104 .60649 L .70936 .60431 L p .707 .577 .707 r
F P
0 g
s
.74104 .60649 m .73944 .66108 L .77086 .66002 L p .707 .577 .707 r
F P
0 g
s
.77086 .66002 m .77246 .60544 L .74104 .60649 L p .707 .577 .707 r
F P
0 g
s
.3317 .74212 m .32889 .75856 L .30324 .74588 L p .707 .577 .707 r
F P
0 g
s
.30324 .74588 m .30605 .72944 L .3317 .74212 L p .707 .577 .707 r
F P
0 g
s
.3967 .25431 m .3967 .7562 L .37064 .76609 L p .707 .577 .707 r
F P
0 g
s
.3967 .7562 m .3967 .25431 L .43287 .24707 L p .707 .577 .707 r
F P
0 g
s
.28403 .67573 m .28192 .7115 L .25002 .7094 L p .707 .577 .707 r
F P
0 g
s
.25002 .7094 m .25214 .67363 L .28403 .67573 L p .707 .577 .707 r
F P
0 g
s
.25214 .67363 m .25002 .7094 L .2193 .71098 L p .707 .577 .707 r
F P
0 g
s
.60068 .25361 m .60068 .7555 L .56383 .74851 L p .707 .577 .707 r
F P
0 g
s
.56383 .74851 m .56383 .24662 L .60068 .25361 L p .707 .577 .707 r
F P
0 g
s
.70776 .6589 m .70936 .60431 L .68052 .59911 L p .707 .577 .707 r
F P
0 g
s
.70936 .60431 m .70776 .6589 L .73944 .66108 L p .707 .577 .707 r
F P
0 g
s
.77246 .60544 m .77086 .66002 L .79894 .65583 L p .707 .577 .707 r
F P
0 g
s
.79894 .65583 m .80054 .60125 L .77246 .60544 L p .707 .577 .707 r
F P
0 g
s
.21146 .73436 m .21427 .71792 L .24431 .71672 L p .707 .577 .707 r
F P
0 g
s
.30605 .72944 m .30324 .74588 L .27313 .73713 L p .707 .577 .707 r
F P
0 g
s
.27313 .73713 m .27593 .72069 L .30605 .72944 L p .707 .577 .707 r
F P
0 g
s
.67891 .65369 m .68052 .59911 L .65734 .59139 L p .707 .577 .707 r
F P
0 g
s
.68052 .59911 m .67891 .65369 L .70776 .6589 L p .707 .577 .707 r
F P
0 g
s
.24431 .71672 m .2415 .73316 L .21146 .73436 L p .707 .577 .707 r
F P
0 g
s
.2415 .73316 m .24431 .71672 L .27593 .72069 L p .707 .577 .707 r
F P
0 g
s
.80054 .60125 m .79894 .65583 L .82093 .64892 L p .707 .577 .707 r
F P
0 g
s
.82093 .64892 m .82254 .59433 L .80054 .60125 L p .707 .577 .707 r
F P
0 g
s
.27593 .72069 m .27313 .73713 L .2415 .73316 L p .707 .577 .707 r
F P
0 g
s
.74997 .70547 m .74786 .66761 L .71597 .66913 L p .707 .577 .707 r
F P
0 g
s
.74786 .66761 m .74997 .70547 L .7807 .70233 L p .707 .577 .707 r
F P
0 g
s
.7807 .70233 m .77859 .66448 L .74786 .66761 L p .707 .577 .707 r
F P
0 g
s
.71808 .70698 m .71597 .66913 L .68603 .66887 L p .707 .577 .707 r
F P
0 g
s
.71597 .66913 m .71808 .70698 L .74997 .70547 L p .707 .577 .707 r
F P
0 g
s
.43287 .74896 m .43287 .24707 L .47561 .24318 L p .707 .577 .707 r
F P
0 g
s
.43287 .24707 m .43287 .74896 L .3967 .7562 L p .707 .577 .707 r
F P
0 g
s
.56383 .24662 m .56383 .74851 L .52073 .74492 L p .707 .577 .707 r
F P
0 g
s
.52073 .74492 m .52073 .24303 L .56383 .24662 L p .707 .577 .707 r
F P
0 g
s
.72687 .73695 m .72407 .71793 L .69395 .72221 L p .707 .577 .707 r
F P
0 g
s
.72407 .71793 m .72687 .73695 L .7585 .73229 L p .707 .577 .707 r
F P
0 g
s
.7585 .73229 m .75569 .71326 L .72407 .71793 L p .707 .577 .707 r
F P
0 g
s
.75569 .71326 m .7585 .73229 L .78854 .7277 L p .707 .577 .707 r
F P
0 g
s
.78854 .7277 m .78573 .70868 L .75569 .71326 L p .707 .577 .707 r
F P
0 g
s
.69395 .72221 m .69676 .74123 L .72687 .73695 L p .707 .577 .707 r
F P
0 g
s
.68603 .66887 m .68814 .70672 L .71808 .70698 L p .707 .577 .707 r
F P
0 g
s
.77859 .66448 m .7807 .70233 L .80725 .69789 L p .707 .577 .707 r
F P
0 g
s
.80725 .69789 m .80514 .66003 L .77859 .66448 L p .707 .577 .707 r
F P
0 g
s
.65734 .59139 m .65573 .64597 L .67891 .65369 L p .707 .577 .707 r
F P
0 g
s
.68814 .70672 m .68603 .66887 L .66098 .66687 L p .707 .577 .707 r
F P
0 g
s
.65573 .64597 m .65734 .59139 L .64209 .58191 L p .707 .577 .707 r
F P
0 g
s
.69676 .74123 m .69395 .72221 L .6683 .72569 L p .707 .577 .707 r
F P
0 g
s
.78573 .70868 m .78854 .7277 L .81405 .72364 L p .707 .577 .707 r
F P
0 g
s
.81405 .72364 m .81125 .70461 L .78573 .70868 L p .707 .577 .707 r
F P
0 g
s
.47561 .74507 m .47561 .24318 L .52073 .24303 L p .707 .577 .707 r
F P
0 g
s
.47561 .24318 m .47561 .74507 L .43287 .74896 L p .707 .577 .707 r
F P
0 g
s
.6683 .72569 m .6711 .74471 L .69676 .74123 L p .707 .577 .707 r
F P
0 g
s
.52073 .24303 m .52073 .74492 L .47561 .74507 L p .707 .577 .707 r
F P
0 g
s
.66098 .66687 m .66309 .70473 L .68814 .70672 L p .707 .577 .707 r
F P
0 g
s
.82254 .59433 m .82093 .64892 L .83469 .63995 L p .707 .577 .707 r
F P
0 g
s
.83469 .63995 m .83629 .58537 L .82254 .59433 L p .707 .577 .707 r
F P
0 g
s
.80514 .66003 m .80725 .69789 L .82703 .69256 L p .707 .577 .707 r
F P
0 g
s
.82703 .69256 m .82492 .65471 L .80514 .66003 L p .707 .577 .707 r
F P
0 g
s
.64209 .58191 m .64048 .6365 L .65573 .64597 L p .707 .577 .707 r
F P
0 g
s
.66309 .70473 m .66098 .66687 L .64326 .66333 L p .707 .577 .707 r
F P
0 g
s
.6711 .74471 m .6683 .72569 L .64962 .72803 L p .707 .577 .707 r
F P
0 g
s
.81125 .70461 m .81405 .72364 L .83255 .72049 L p .707 .577 .707 r
F P
0 g
s
.83255 .72049 m .82974 .70147 L .81125 .70461 L p .707 .577 .707 r
F P
0 g
s
.64962 .72803 m .65242 .74705 L .6711 .74471 L p .707 .577 .707 r
F P
0 g
s
.64326 .66333 m .64537 .70118 L .66309 .70473 L p .707 .577 .707 r
F P
0 g
s
.64048 .6365 m .64209 .58191 L .63626 .5716 L p .707 .577 .707 r
F P
0 g
s
.83629 .58537 m .83469 .63995 L .83885 .62982 L p .707 .577 .707 r
F P
0 g
s
.83885 .62982 m .84046 .57524 L .83629 .58537 L p .707 .577 .707 r
F P
0 g
s
.82492 .65471 m .82703 .69256 L .8381 .68688 L p .707 .577 .707 r
F P
0 g
s
.8381 .68688 m .83598 .64903 L .82492 .65471 L p .707 .577 .707 r
F P
0 g
s
.63626 .5716 m .63466 .62619 L .64048 .6365 L p .707 .577 .707 r
F P
0 g
s
.64537 .70118 m .64326 .66333 L .63462 .65858 L p .707 .577 .707 r
F P
0 g
s
.65242 .74705 m .64962 .72803 L .63973 .729 L p .707 .577 .707 r
F P
0 g
s
.82974 .70147 m .83255 .72049 L .84221 .71858 L p .707 .577 .707 r
F P
0 g
s
.84221 .71858 m .83941 .69956 L .82974 .70147 L p .707 .577 .707 r
F P
0 g
s
.63973 .729 m .64254 .74802 L .65242 .74705 L p .707 .577 .707 r
F P
0 g
s
.63462 .65858 m .63673 .69643 L .64537 .70118 L p .707 .577 .707 r
F P
0 g
s
.63466 .62619 m .63626 .5716 L .64043 .56147 L p .707 .577 .707 r
F P
0 g
s
.84046 .57524 m .83885 .62982 L .83303 .61952 L p .707 .577 .707 r
F P
0 g
s
.83303 .61952 m .83463 .56493 L .84046 .57524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83598 .64903 m .8381 .68688 L .83937 .6814 L p .707 .577 .707 r
F P
0 g
s
.83937 .6814 m .83726 .64355 L .83598 .64903 L p .707 .577 .707 r
F P
0 g
s
.64043 .56147 m .63882 .61606 L .63466 .62619 L p .707 .577 .707 r
F P
0 g
s
.63673 .69643 m .63462 .65858 L .63589 .6531 L p .707 .577 .707 r
F P
0 g
s
.64254 .74802 m .63973 .729 L .63962 .7285 L p .712 .581 .706 r
F P
0 g
s
.83941 .69956 m .84221 .71858 L .8421 .71809 L p .712 .581 .706 r
F P
0 g
s
.8421 .71809 m .83929 .69906 L .83941 .69956 L p .712 .581 .706 r
F P
0 g
s
.63962 .7285 m .64242 .74753 L .64254 .74802 L p .712 .581 .706 r
F P
0 g
s
.63589 .6531 m .63801 .69095 L .63673 .69643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63882 .61606 m .64043 .56147 L .65418 .55251 L p .707 .577 .707 r
F P
0 g
s
.39196 .6187 m .39559 .56278 L .36396 .55984 L p .707 .577 .707 r
F P
0 g
s
.39559 .56278 m .39196 .6187 L .42334 .61923 L p .707 .577 .707 r
F P
0 g
s
.42334 .61923 m .42696 .56331 L .39559 .56278 L p .707 .577 .707 r
F P
0 g
s
.36034 .61576 m .36396 .55984 L .33517 .55479 L p .707 .577 .707 r
F P
0 g
s
.36396 .55984 m .36034 .61576 L .39196 .6187 L p .707 .577 .707 r
F P
0 g
s
.83463 .56493 m .83303 .61952 L .81778 .61004 L p .707 .577 .707 r
F P
0 g
s
.81778 .61004 m .81938 .55546 L .83463 .56493 L p .707 .577 .707 r
F P
0 g
s
.42696 .56331 m .42334 .61923 L .45138 .6173 L p .707 .577 .707 r
F P
0 g
s
.45138 .6173 m .45501 .56138 L .42696 .56331 L p .707 .577 .707 r
F P
0 g
s
.83726 .64355 m .83937 .6814 L .83073 .67665 L p .707 .577 .707 r
F P
0 g
s
.83073 .67665 m .82862 .6388 L .83726 .64355 L p .707 .577 .707 r
F P
0 g
s
.33154 .61071 m .33517 .55479 L .31204 .54812 L p .707 .577 .707 r
F P
0 g
s
.33517 .55479 m .33154 .61071 L .36034 .61576 L p .707 .577 .707 r
F P
0 g
s
.65418 .55251 m .65258 .6071 L .63882 .61606 L p .707 .577 .707 r
F P
0 g
s
.63801 .69095 m .63589 .6531 L .64696 .64742 L p .707 .577 .707 r
F P
0 g
s
.45501 .56138 m .45138 .6173 L .47335 .61311 L p .707 .577 .707 r
F P
0 g
s
.47335 .61311 m .47698 .55719 L .45501 .56138 L p .707 .577 .707 r
F P
0 g
s
.40391 .68623 m .39923 .65021 L .36753 .65343 L p .707 .577 .707 r
F P
0 g
s
.39923 .65021 m .40391 .68623 L .43446 .67985 L p .707 .577 .707 r
F P
0 g
s
.43446 .67985 m .42979 .64382 L .39923 .65021 L p .707 .577 .707 r
F P
0 g
s
.64242 .74753 m .63962 .7285 L .64928 .72659 L p .707 .577 .707 r
F P
0 g
s
.83929 .69906 m .8421 .71809 L .83222 .71906 L p .707 .577 .707 r
F P
0 g
s
.83222 .71906 m .82941 .70003 L .83929 .69906 L p .707 .577 .707 r
F P
0 g
s
.64928 .72659 m .65209 .74562 L .64242 .74753 L p .707 .577 .707 r
F P
0 g
s
.3722 .68946 m .36753 .65343 L .33778 .65319 L p .707 .577 .707 r
F P
0 g
s
.36753 .65343 m .3722 .68946 L .40391 .68623 L p .707 .577 .707 r
F P
0 g
s
.64696 .64742 m .64907 .68527 L .63801 .69095 L p .707 .577 .707 r
F P
0 g
s
.65258 .6071 m .65418 .55251 L .67617 .5456 L p .707 .577 .707 r
F P
0 g
s
.42979 .64382 m .43446 .67985 L .46088 .67093 L p .707 .577 .707 r
F P
0 g
s
.46088 .67093 m .4562 .6349 L .42979 .64382 L p .707 .577 .707 r
F P
0 g
s
.31204 .54812 m .30841 .60404 L .33154 .61071 L p .707 .577 .707 r
F P
0 g
s
.81938 .55546 m .81778 .61004 L .7946 .60232 L p .707 .577 .707 r
F P
0 g
s
.7946 .60232 m .7962 .54774 L .81938 .55546 L p .707 .577 .707 r
F P
0 g
s
.34246 .68921 m .33778 .65319 L .3129 .64949 L p .707 .577 .707 r
F P
0 g
s
.33778 .65319 m .34246 .68921 L .3722 .68946 L p .707 .577 .707 r
F P
0 g
s
.30841 .60404 m .31204 .54812 L .29682 .54048 L p .707 .577 .707 r
F P
0 g
s
.82862 .6388 m .83073 .67665 L .81301 .6731 L p .707 .577 .707 r
F P
0 g
s
.81301 .6731 m .8109 .63525 L .82862 .6388 L p .707 .577 .707 r
F P
0 g
s
.47698 .55719 m .47335 .61311 L .48709 .60706 L p .707 .577 .707 r
F P
0 g
s
.48709 .60706 m .49072 .55114 L .47698 .55719 L p .707 .577 .707 r
F P
0 g
s
.4562 .6349 m .46088 .67093 L .48057 .66035 L p .707 .577 .707 r
F P
0 g
s
.48057 .66035 m .47589 .62433 L .4562 .6349 L p .707 .577 .707 r
F P
0 g
s
.67617 .5456 m .67457 .60018 L .65258 .6071 L p .707 .577 .707 r
F P
0 g
s
.41691 .73404 m .41085 .71764 L .38051 .72664 L p .707 .577 .707 r
F P
0 g
s
.41085 .71764 m .41691 .73404 L .44579 .72114 L p .707 .577 .707 r
F P
0 g
s
.44579 .72114 m .43974 .70474 L .41085 .71764 L p .707 .577 .707 r
F P
0 g
s
.67457 .60018 m .67617 .5456 L .70426 .54141 L p .707 .577 .707 r
F P
0 g
s
.3129 .64949 m .31757 .68551 L .34246 .68921 L p .707 .577 .707 r
F P
0 g
s
.64907 .68527 m .64696 .64742 L .66674 .64209 L p .707 .577 .707 r
F P
0 g
s
.38656 .74305 m .38051 .72664 L .35168 .73086 L p .707 .577 .707 r
F P
0 g
s
.38051 .72664 m .38656 .74305 L .41691 .73404 L p .707 .577 .707 r
F P
0 g
s
.43974 .70474 m .44579 .72114 L .47039 .7056 L p .707 .577 .707 r
F P
0 g
s
.47039 .7056 m .46434 .6892 L .43974 .70474 L p .707 .577 .707 r
F P
0 g
s
.29682 .54048 m .2932 .5964 L .30841 .60404 L p .707 .577 .707 r
F P
0 g
s
.7962 .54774 m .7946 .60232 L .76575 .59711 L p .707 .577 .707 r
F P
0 g
s
.76575 .59711 m .76736 .54253 L .7962 .54774 L p .707 .577 .707 r
F P
0 g
s
.65209 .74562 m .64928 .72659 L .66778 .72345 L p .707 .577 .707 r
F P
0 g
s
.82941 .70003 m .83222 .71906 L .81353 .7214 L p .707 .577 .707 r
F P
0 g
s
.81353 .7214 m .81073 .70237 L .82941 .70003 L p .707 .577 .707 r
F P
0 g
s
.66778 .72345 m .67058 .74247 L .65209 .74562 L p .707 .577 .707 r
F P
0 g
s
.66674 .64209 m .66885 .67994 L .64907 .68527 L p .707 .577 .707 r
F P
0 g
s
.31757 .68551 m .3129 .64949 L .29532 .64271 L p .707 .577 .707 r
F P
0 g
s
.35168 .73086 m .35773 .74727 L .38656 .74305 L p .707 .577 .707 r
F P
0 g
s
.70265 .59599 m .70426 .54141 L .73567 .54035 L p .707 .577 .707 r
F P
0 g
s
.70426 .54141 m .70265 .59599 L .67457 .60018 L p .707 .577 .707 r
F P
0 g
s
.35773 .74727 m .35168 .73086 L .32719 .72989 L p .707 .577 .707 r
F P
0 g
s
.46434 .6892 m .47039 .7056 L .4883 .68895 L p .707 .577 .707 r
F P
0 g
s
.4883 .68895 m .48224 .67255 L .46434 .6892 L p .707 .577 .707 r
F P
0 g
s
.2932 .5964 m .29682 .54048 L .29102 .53261 L p .707 .577 .707 r
F P
0 g
s
.76736 .54253 m .76575 .59711 L .73407 .59493 L p .707 .577 .707 r
F P
0 g
s
.73407 .59493 m .73567 .54035 L .76736 .54253 L p .707 .577 .707 r
F P
0 g
s
.8109 .63525 m .81301 .6731 L .78796 .67111 L p .707 .577 .707 r
F P
0 g
s
.78796 .67111 m .78585 .63325 L .8109 .63525 L p .707 .577 .707 r
F P
0 g
s
.47589 .62433 m .48057 .66035 L .4916 .64915 L p .707 .577 .707 r
F P
0 g
s
.4916 .64915 m .48693 .61312 L .47589 .62433 L p .707 .577 .707 r
F P
0 g
s
.29532 .64271 m .29999 .67873 L .31757 .68551 L p .707 .577 .707 r
F P
0 g
s
.73567 .54035 m .73407 .59493 L .70265 .59599 L p .707 .577 .707 r
F P
0 g
s
.32719 .72989 m .33324 .74629 L .35773 .74727 L p .707 .577 .707 r
F P
0 g
s
.49072 .55114 m .48709 .60706 L .49127 .59974 L p .707 .577 .707 r
F P
0 g
s
.49127 .59974 m .4949 .54383 L .49072 .55114 L p .707 .577 .707 r
F P
0 g
s
.66885 .67994 m .66674 .64209 L .69329 .63764 L p .707 .577 .707 r
F P
0 g
s
.29102 .53261 m .28739 .58853 L .2932 .5964 L p .707 .577 .707 r
F P
0 g
s
.67058 .74247 m .66778 .72345 L .6933 .71939 L p .707 .577 .707 r
F P
0 g
s
.81073 .70237 m .81353 .7214 L .78788 .72488 L p .707 .577 .707 r
F P
0 g
s
.78788 .72488 m .78508 .70585 L .81073 .70237 L p .707 .577 .707 r
F P
0 g
s
.6933 .71939 m .6961 .73841 L .67058 .74247 L p .707 .577 .707 r
F P
0 g
s
.69329 .63764 m .6954 .6755 L .66885 .67994 L p .707 .577 .707 r
F P
0 g
s
.29999 .67873 m .29532 .64271 L .28676 .6335 L p .707 .577 .707 r
F P
0 g
s
.33324 .74629 m .32719 .72989 L .30942 .72381 L p .707 .577 .707 r
F P
0 g
s
.48224 .67255 m .4883 .68895 L .49776 .67281 L p .707 .577 .707 r
F P
0 g
s
.49776 .67281 m .4917 .65641 L .48224 .67255 L p .707 .577 .707 r
F P
0 g
s
.78585 .63325 m .78796 .67111 L .75802 .67085 L p .707 .577 .707 r
F P
0 g
s
.75802 .67085 m .75591 .633 L .78585 .63325 L p .707 .577 .707 r
F P
0 g
s
.6954 .6755 m .69329 .63764 L .72402 .63451 L p .707 .577 .707 r
F P
0 g
s
.30942 .72381 m .31547 .74022 L .33324 .74629 L p .707 .577 .707 r
F P
0 g
s
.28676 .6335 m .29144 .66952 L .29999 .67873 L p .707 .577 .707 r
F P
0 g
s
.28739 .58853 m .29102 .53261 L .2952 .5253 L p .707 .577 .707 r
F P
0 g
s
.48693 .61312 m .4916 .64915 L .49291 .63842 L p .707 .577 .707 r
F P
0 g
s
.49291 .63842 m .48824 .60239 L .48693 .61312 L p .707 .577 .707 r
F P
0 g
s
.72402 .63451 m .72613 .67236 L .6954 .6755 L p .707 .577 .707 r
F P
0 g
s
.75591 .633 m .75802 .67085 L .72613 .67236 L p .707 .577 .707 r
F P
0 g
s
.72613 .67236 m .72402 .63451 L .75591 .633 L p .707 .577 .707 r
F P
0 g
s
.6961 .73841 m .6933 .71939 L .72334 .7148 L p .707 .577 .707 r
F P
0 g
s
.78508 .70585 m .78788 .72488 L .75777 .72916 L p .707 .577 .707 r
F P
0 g
s
.75777 .72916 m .75496 .71013 L .78508 .70585 L p .707 .577 .707 r
F P
0 g
s
.72334 .7148 m .72614 .73382 L .6961 .73841 L p .707 .577 .707 r
F P
0 g
s
.4949 .54383 m .49127 .59974 L .48547 .59188 L p .707 .577 .707 r
F P
0 g
s
.48547 .59188 m .4891 .53596 L .4949 .54383 L p .707 .577 .707 r
F P
0 g
s
.2952 .5253 m .29157 .58122 L .28739 .58853 L p .707 .577 .707 r
F P
0 g
s
.72614 .73382 m .72334 .7148 L .75496 .71013 L p .707 .577 .707 r
F P
0 g
s
.75496 .71013 m .75777 .72916 L .72614 .73382 L p .707 .577 .707 r
F P
0 g
s
.31547 .74022 m .30942 .72381 L .30013 .71324 L p .707 .577 .707 r
F P
0 g
s
.4917 .65641 m .49776 .67281 L .49784 .65877 L p .707 .577 .707 r
F P
0 g
s
.49784 .65877 m .49179 .64236 L .4917 .65641 L p .707 .577 .707 r
F P
0 g
s
.29144 .66952 m .28676 .6335 L .28807 .62276 L p .707 .577 .707 r
F P
0 g
s
.30013 .71324 m .30618 .72964 L .31547 .74022 L p .707 .577 .707 r
F P
0 g
s
.28807 .62276 m .29274 .65879 L .29144 .66952 L p .707 .577 .707 r
F P
0 g
s
.48824 .60239 m .49291 .63842 L .48435 .62921 L p .707 .577 .707 r
F P
0 g
s
.48435 .62921 m .47968 .59318 L .48824 .60239 L p .707 .577 .707 r
F P
0 g
s
.29157 .58122 m .2952 .5253 L .30894 .51925 L p .707 .577 .707 r
F P
0 g
s
.4891 .53596 m .48547 .59188 L .47026 .58424 L p .707 .577 .707 r
F P
0 g
s
.47026 .58424 m .47388 .52832 L .4891 .53596 L p .707 .577 .707 r
F P
0 g
s
.30618 .72964 m .30013 .71324 L .30022 .69919 L p .707 .577 .707 r
F P
0 g
s
.49179 .64236 m .49784 .65877 L .48855 .64819 L p .707 .577 .707 r
F P
0 g
s
.48855 .64819 m .4825 .63178 L .49179 .64236 L p .707 .577 .707 r
F P
0 g
s
.30894 .51925 m .30532 .57517 L .29157 .58122 L p .707 .577 .707 r
F P
0 g
s
.29274 .65879 m .28807 .62276 L .29911 .61156 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30022 .69919 m .30627 .7156 L .30618 .72964 L p .707 .577 .707 r
F P
0 g
s
.30532 .57517 m .30894 .51925 L .33091 .51506 L p .707 .577 .707 r
F P
0 g
s
.29911 .61156 m .30378 .64759 L .29274 .65879 L p .707 .577 .707 r
F P
0 g
s
.47968 .59318 m .48435 .62921 L .46677 .62242 L p .707 .577 .707 r
F P
0 g
s
.46677 .62242 m .4621 .5864 L .47968 .59318 L p .707 .577 .707 r
F P
0 g
s
.47388 .52832 m .47026 .58424 L .44712 .57757 L p .707 .577 .707 r
F P
0 g
s
.44712 .57757 m .45075 .52165 L .47388 .52832 L p .707 .577 .707 r
F P
0 g
s
.30627 .7156 m .30022 .69919 L .30968 .68305 L p .707 .577 .707 r
F P
0 g
s
.4825 .63178 m .48855 .64819 L .47079 .64212 L p .707 .577 .707 r
F P
0 g
s
.47079 .64212 m .46473 .62571 L .4825 .63178 L p .707 .577 .707 r
F P
0 g
s
.33091 .51506 m .32729 .57098 L .30532 .57517 L p .707 .577 .707 r
F P
0 g
s
.30378 .64759 m .29911 .61156 L .3188 .60098 L p .707 .577 .707 r
F P
0 g
s
.30968 .68305 m .31573 .69946 L .30627 .7156 L p .707 .577 .707 r
F P
0 g
s
.32729 .57098 m .33091 .51506 L .35896 .51313 L p .707 .577 .707 r
F P
0 g
s
.4621 .5864 m .46677 .62242 L .44189 .61872 L p .707 .577 .707 r
F P
0 g
s
.44189 .61872 m .43722 .5827 L .4621 .5864 L p .707 .577 .707 r
F P
0 g
s
.45075 .52165 m .44712 .57757 L .41833 .57251 L p .707 .577 .707 r
F P
0 g
s
.41833 .57251 m .42196 .5166 L .45075 .52165 L p .707 .577 .707 r
F P
0 g
s
.3188 .60098 m .32347 .63701 L .30378 .64759 L p .707 .577 .707 r
F P
0 g
s
.35896 .51313 m .35533 .56905 L .32729 .57098 L p .707 .577 .707 r
F P
0 g
s
.35533 .56905 m .35896 .51313 L .39033 .51366 L p .707 .577 .707 r
F P
0 g
s
.32347 .63701 m .3188 .60098 L .34521 .59206 L p .707 .577 .707 r
F P
0 g
s
.31573 .69946 m .30968 .68305 L .32758 .6664 L p .707 .577 .707 r
F P
0 g
s
.46473 .62571 m .47079 .64212 L .44629 .64115 L p .707 .577 .707 r
F P
0 g
s
.44629 .64115 m .44024 .62474 L .46473 .62571 L p .707 .577 .707 r
F P
0 g
s
.42196 .5166 m .41833 .57251 L .3867 .56958 L p .707 .577 .707 r
F P
0 g
s
.3867 .56958 m .39033 .51366 L .42196 .5166 L p .707 .577 .707 r
F P
0 g
s
.39033 .51366 m .3867 .56958 L .35533 .56905 L p .707 .577 .707 r
F P
0 g
s
.43722 .5827 m .44189 .61872 L .41214 .61848 L p .707 .577 .707 r
F P
0 g
s
.41214 .61848 m .40747 .58245 L .43722 .5827 L p .707 .577 .707 r
F P
0 g
s
.32758 .6664 m .33363 .68281 L .31573 .69946 L p .707 .577 .707 r
F P
0 g
s
.34521 .59206 m .34989 .62809 L .32347 .63701 L p .707 .577 .707 r
F P
0 g
s
.34989 .62809 m .34521 .59206 L .37577 .58568 L p .707 .577 .707 r
F P
0 g
s
.40747 .58245 m .41214 .61848 L .38044 .6217 L p .707 .577 .707 r
F P
0 g
s
.38044 .6217 m .37577 .58568 L .40747 .58245 L p .707 .577 .707 r
F P
0 g
s
.33363 .68281 m .32758 .6664 L .35218 .65086 L p .707 .577 .707 r
F P
0 g
s
.44024 .62474 m .44629 .64115 L .41746 .64537 L p .707 .577 .707 r
F P
0 g
s
.41746 .64537 m .41141 .62896 L .44024 .62474 L p .707 .577 .707 r
F P
0 g
s
.37577 .58568 m .38044 .6217 L .34989 .62809 L p .707 .577 .707 r
F P
0 g
s
.35218 .65086 m .35823 .66727 L .33363 .68281 L p .707 .577 .707 r
F P
0 g
s
.35823 .66727 m .35218 .65086 L .38107 .63796 L p .707 .577 .707 r
F P
0 g
s
.41141 .62896 m .41746 .64537 L .38712 .65437 L p .707 .577 .707 r
F P
0 g
s
.38712 .65437 m .38107 .63796 L .41141 .62896 L p .707 .577 .707 r
F P
0 g
s
.38107 .63796 m .38712 .65437 L .35823 .66727 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007=oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00Kgoo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001SOol70006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001KOol80003FUH01000FUIJEUYF400000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Egoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo0`001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol0059oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF000047oo3`00Agoo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
37oo100000=JEP00FUH01eYF00<005YFFUH00UYF2000?goo001BOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF000027oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Uoo`00DWoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000017oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Woo001BOol01@00FUIJEUYF00001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00=7oo001BOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
00001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
039oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080031oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF00<007ooOol0;Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0]Ool0055oo`8000=JEP04001JEUYFFUH80005FUH00`00FUIJEP06FUH0
0`00FUH000060006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Woo001AOol20003FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4
0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001A
Ool200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP@000AJEP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo
0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF4@0000IJEP00000005YF0003
FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF
00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P0000AJEP00FUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0059oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool005=oo`05001JEUYFFUH00005FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00UYF5`001UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool0
05Aoo`800004FUH005YFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000eYF00<005YFFUH00UYF1`002goo1@001Woo10000UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH0000^Ool005Ioo`D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUH000020003FUH01000FUIJEUYF2@00
0Woo1@002Goo1@001EYF00L005YFFUIJEP00FUH0000^Ool005Ioo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ0000EJEP@00003FUH005YF009JEP03001JEP0002ioo`00
?goo5`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF
00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0002ioo`00>goo100000=JEP00FUH01eYF
00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP00;Woo000fOol50005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0005FUH00`00FUIJEP02FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH400000eYF001oo`0]Ool0039oo`@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH90002FUH4
00000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002ioo`00<7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00IJEPh0009JEP03001JEP0000QJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<005YFFUH0
1P0015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00006FUH3
00000eYF001JEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00D005YFFUIJ
EP0000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUHQ0003FUH00`00Oomoo`0]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP8000AJEP05001JEUYFFUH0
0003FUH00`00FUIJEP020007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF10001eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00<00003FUH007oo02ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00`001EYF00D005YFFUIJEP0000=JEP@000UJ
EP03001JEUYF009JEP`000=JEP<000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH300000eYF001JEP060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<0009JEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH70006FUH00`00FUIJEP02FUH200000eYF0000
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH60005FUH01000FUIJEUYF0`001EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF001JEP00009JEP04001JEUYFFUH:0008FUH00`00FUH000020007FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002moo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH0
1EYF00<005YF00000P0025YF0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF0000;goo000]Ool00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH20002
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF0P001EYF
00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YF
000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH015YF4`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP800003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00EJEP<00006FUH005YFFUH005YF0P001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
;Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH20003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0004FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eo
o`03001JEP00009JEP04001JEUYFFUH60006FUH:0007FUH00`00FUH00003FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEP/000QJEP03001JEUYF
00=JEPL0009JEP03001JEP0002ioo`00;Goo00<005YF00000UYF10000eYF00<005YF00001`0015YF
00<005YFFUH00UYF2P0015YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP00008000MJEP<0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH01000FUIJEUYF200000=J
EP00FUH00eYF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000]Ool0
0`00FUH00002000015YF001JEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000=JEP00FUH00eYF10001eYF00<005YFFUH00eYF10001UYF10002EYF00H005YFFUH005YF
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF
FUIJEPL000QJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000^Ool002eoo`03001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP02FUH50002FUH40002
FUH00`00FUIJEP06FUH20004FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEP000UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo0`0000=JEP00000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF200015YF00<005YF
FUH00UYF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000UYF0P000UYF0P0000AJEP00FUIJEPh000QJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH300000eYF
00000003FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P00<goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEUYF00QJEP04001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00H005YF000005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006Ool2000^Ool002ioo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00001UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP04001J
EUYF0006FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=o
o`000000200000=JEP00Ool0;Goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP<000MJEP03001JEP0000aJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH>0004FUH00`00FUIJEP02FUH900000goo0000
00060003FUH00`00FUIJEP02FUH01000FUIJEP00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP800003FUH005YF00AJEP80009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00007FUH00`00FUIJ
EP04FUH00`00FUIJEP090003Ool70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF20002Goo200000=JEP00FUH00P001UYF00<0
05YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00007FUH00`00FUIJEP04FUH01000FUIJEUYF0P001Goo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;Woo00@005YFFUH000=JEPH000Ioo`T0
00Yoo`800004FUH000000005FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF
0P001UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP03FUH01000FUIJEUYF1`001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;Woo00D005YFFUH005YF0080
00Aoo`P000AJEP03001JEUYF009JEPH000Ioo`80009oo`8000=JEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00<000QJEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP080003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06000]Ool002ioo`03001JEUYF0080009o
o`@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000=oo`<000=oo`800003FUH0
05YF00=JEP8000=JEP03001JEUYF00=JEP@00003FUH005YF00MJEP8000QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH70003FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000cOol002ioo`03001J
EP0000D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<00003Ool005YF00<0
009oo`8000AJEP80009JEPL000IJEP03001JEUYF00=JEP8000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol002eoo`H0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP`000AJEP03001JEUYF00IJ
EP03001JEUYF00@000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP/003moo`00;Goo0P0000=JEP00FUH00UYF00<005YFFUH015YF3P0015YF00<005YFFUH01eYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEQ0004=oo`00;Goo10000eYF00<005YF
FUH010003Woo1P0025YF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH0000000H004Yoo`00
;Goo0P0000=JEP00FUH00UYF0`0015YF100047oo0`0015YF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03
001JEP0000X0059oo`00;Goo0`000UYF0P0000=JEP00FUH01EYF00<005YFFUH010003goo0`0000=J
EP00FUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH02EYF00<005YFFUH0
15YF60001UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00P0
0003FUH0000005Ioo`00;Goo00<005YF00000P000eYF00<005YFFUH015YF00<005YFFUH015YF5@00
1EYF3@001UYF00<005YFFUH01eYF20001UYF00<005YFFUH025YF00<005YF000015YF2@001eYF00<0
05YFFUH01EYF00@005YFFUIJEPH000MJEP04001JEUYFFUH2001DOol002eoo`04001JEP000004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJ
EP02000015YF001JEP000eYF00<005YFFUH015YF00<005YFFUH00eYF100000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YF00002eYF00<005YF000010000UYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP8005=oo`00;Goo100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00eYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YF00002eYF00<005YFFUH015YF10001UYF00D005YFFUIJEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00059oo`00;7oo0P000Woo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YF
00000eYF00<005YFFUH00eYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002eYF
00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF001BOol002aoo`8000=oo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEP0000<0009J
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJ
EP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH00007FUH00`00FUIJEP02FUH01000FUIJ
EP00DWoo000/Ool20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH20003FUH30003FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000
1eYF00<005YFFUH00UYF00@005YFFUH0059oo`00;7oo0`001Woo0P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF0080
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP80009JEPH000EJEP03001JEUYF00=JEP04001JEUYF001BOol002aoo`<0
00Qoo`@00003FUH005YF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH01@00FUH005YF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P000eYF00<0
05YF00000`0000=JEP00FUH015YF00@005YFFUH0059oo`00;7oo00@005YFFUH000]oo`<000IJEP03
001JEUYF00D00003FUH005YF00MJEP03001JEUYF00EJEP<00004Ool005YFFUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF0`000eYF00<005YFFUH0
0P00DWoo000/Ool01000FUIJEP003Woo10000UYF00<005YFFUH01@0000=JEP00FUH01eYF00<005YF
FUH00UYF100017oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
009JEP03001JEUYF00EJEP06001JEP00001JEP000UYF00<007ooOol0DGoo000/Ool01@00FUIJEUYF
00004Goo2P0000=JEP00FUH00eYF2@0027oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00Oomoo`1AOol0
02eoo`03001JEUYF008001Ioo`X0019oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001oo`1BOol002eoo`03001J
EP00009JEP80035oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YF000005=oo`00;Woo0P0015YF00<007ooOol0;Woo0P00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF001COol002moo`03001JEUYF00=JEP03001oogoo02aoo`H000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH0001COol0031oo`03001J
EUYF009JEP<002aoo`8000=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00001DOol0035oo`05001JEUYFFUH00002FUH2000YOol00`00FUH00005Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUIJEUYF1@0015YF00<005YFFUH01EYF00<005YFFUH01000EWoo000bOol200000eYF
001JEP03FUH2000UOol300000eYF001oo`06Ool300000eYF001JEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01`00FUH00000FUH005YF014005Yoo`00=7oo
0P001UYF0`0087oo0P000UYF0P002goo10001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH00UYF0`00IWoo000eOol20006FUH00`00FUH0
0003000JOol20003FUH2000@Ool50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060005FUH00`00FUIJEP05FUH3001SOol003Moo`8000=JEP03001JEUYF00AJEPL0
00moo`@00003FUH005YF009JEP8001Eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0009J
EP04001JEUYFFUH300000eYF001JEP08FUH00`00FUH00003001OOol003Uoo`800003FUH005YF00MJ
EP03001JEUYF009JEPl000EJEP05001JEUYFFUH0000OOolJ0003Ool20005FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP04FUH2001MOol003]oo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF008003moo`<00003FUH005YF00QJEP<000EJEP03001JEUYF00EJEP<0
05]oo`00?Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00A7oo0`00
25YF00<005YFFUH00`0000=JEP00FUH01UYF00@005YFFUIJEP8005Uoo`00@7oo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00eYF0P00BGoo0`0015YF00<005YFFUH015YF0`001UYF00<0
05YFFUH00eYF00<007ooOol0EWoo0013Ool60004FUH00`00FUIJEP06FUH00`00FUH00003001>Ool3
00000eYF001JEP07FUH30004FUH00`00FUIJEP03FUH3001FOol004Uoo`l005Eoo`<000MJEP03001J
EUYF00800003FUH005YF00AJEP04001JEUYF001FOol00;1oo`@0009JEP03001JEUYF00=JEP<000AJ
EP04001JEUYF001FOol00;Aoo`@000IJEP<00004FUH005YFFUH2001FOol00;Qoo`@00003FUH005YF
009JEP80009JEP03001oogoo05Eoo`00_7oo10000UYF1000Egoo0030Ool6001GOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.6133 .75139 m .60967 .69641 L .57804 .69707 L p .707 .577 .707 r
F P
0 g
s
.60967 .69641 m .6133 .75139 L .64467 .74777 L p .707 .577 .707 r
F P
0 g
s
.64467 .74777 m .64104 .69279 L .60967 .69641 L p .707 .577 .707 r
F P
0 g
s
.58167 .75204 m .57804 .69707 L .54925 .6947 L p .707 .577 .707 r
F P
0 g
s
.57804 .69707 m .58167 .75204 L .6133 .75139 L p .707 .577 .707 r
F P
0 g
s
.64104 .69279 m .64467 .74777 L .67271 .74155 L p .707 .577 .707 r
F P
0 g
s
.67271 .74155 m .66908 .68657 L .64104 .69279 L p .707 .577 .707 r
F P
0 g
s
.55288 .74968 m .54925 .6947 L .52611 .68954 L p .707 .577 .707 r
F P
0 g
s
.54925 .6947 m .55288 .74968 L .58167 .75204 L p .707 .577 .707 r
F P
0 g
s
.66908 .68657 m .67271 .74155 L .69468 .73333 L p .707 .577 .707 r
F P
0 g
s
.69468 .73333 m .69105 .67835 L .66908 .68657 L p .707 .577 .707 r
F P
0 g
s
.61956 .80396 m .62423 .76658 L .59253 .76252 L p .707 .577 .707 r
F P
0 g
s
.62423 .76658 m .61956 .80396 L .65011 .80586 L p .707 .577 .707 r
F P
0 g
s
.65011 .80586 m .65479 .76849 L .62423 .76658 L p .707 .577 .707 r
F P
0 g
s
.58785 .79989 m .59253 .76252 L .56278 .75668 L p .707 .577 .707 r
F P
0 g
s
.59253 .76252 m .58785 .79989 L .61956 .80396 L p .707 .577 .707 r
F P
0 g
s
.56278 .75668 m .5581 .79406 L .58785 .79989 L p .707 .577 .707 r
F P
0 g
s
.65479 .76849 m .65011 .80586 L .67653 .80541 L p .707 .577 .707 r
F P
0 g
s
.67653 .80541 m .6812 .76804 L .65479 .76849 L p .707 .577 .707 r
F P
0 g
s
.5581 .79406 m .56278 .75668 L .5379 .74965 L p .707 .577 .707 r
F P
0 g
s
.58254 .82828 m .58859 .8101 L .55976 .79969 L p .707 .577 .707 r
F P
0 g
s
.58859 .8101 m .58254 .82828 L .61288 .83831 L p .707 .577 .707 r
F P
0 g
s
.61288 .83831 m .61893 .82013 L .58859 .8101 L p .707 .577 .707 r
F P
0 g
s
.52611 .68954 m .52974 .74452 L .55288 .74968 L p .707 .577 .707 r
F P
0 g
s
.61893 .82013 m .61288 .83831 L .64176 .84697 L p .707 .577 .707 r
F P
0 g
s
.64176 .84697 m .64782 .82879 L .61893 .82013 L p .707 .577 .707 r
F P
0 g
s
.55976 .79969 m .55371 .81787 L .58254 .82828 L p .707 .577 .707 r
F P
0 g
s
.52974 .74452 m .52611 .68954 L .5109 .6821 L p .707 .577 .707 r
F P
0 g
s
.69105 .67835 m .69468 .73333 L .70843 .72392 L p .707 .577 .707 r
F P
0 g
s
.70843 .72392 m .7048 .66894 L .69105 .67835 L p .707 .577 .707 r
F P
0 g
s
.5379 .74965 m .53322 .78702 L .5581 .79406 L p .707 .577 .707 r
F P
0 g
s
.55371 .81787 m .55976 .79969 L .53526 .78991 L p .707 .577 .707 r
F P
0 g
s
.53526 .78991 m .52921 .8081 L .55371 .81787 L p .707 .577 .707 r
F P
0 g
s
.64782 .82879 m .64176 .84697 L .66636 .85343 L p .707 .577 .707 r
F P
0 g
s
.66636 .85343 m .67241 .83525 L .64782 .82879 L p .707 .577 .707 r
F P
0 g
s
.6812 .76804 m .67653 .80541 L .69622 .80265 L p .707 .577 .707 r
F P
0 g
s
.69622 .80265 m .70089 .76528 L .6812 .76804 L p .707 .577 .707 r
F P
0 g
s
.53322 .78702 m .5379 .74965 L .52032 .74211 L p .707 .577 .707 r
F P
0 g
s
.5109 .6821 m .51453 .73707 L .52974 .74452 L p .707 .577 .707 r
F P
0 g
s
.52032 .74211 m .51564 .77948 L .53322 .78702 L p .707 .577 .707 r
F P
0 g
s
.52921 .8081 m .53526 .78991 L .5175 .78173 L p .707 .577 .707 r
F P
0 g
s
.5175 .78173 m .51145 .79992 L .52921 .8081 L p .707 .577 .707 r
F P
0 g
s
.67241 .83525 m .66636 .85343 L .68427 .85704 L p .707 .577 .707 r
F P
0 g
s
.68427 .85704 m .69032 .83886 L .67241 .83525 L p .707 .577 .707 r
F P
0 g
s
.51453 .73707 m .5109 .6821 L .5051 .67309 L p .707 .577 .707 r
F P
0 g
s
.7048 .66894 m .70843 .72392 L .7126 .71424 L p .707 .577 .707 r
F P
0 g
s
.7126 .71424 m .70897 .65926 L .7048 .66894 L p .707 .577 .707 r
F P
0 g
s
.70089 .76528 m .69622 .80265 L .70725 .79785 L p .707 .577 .707 r
F P
0 g
s
.70725 .79785 m .71193 .76048 L .70089 .76528 L p .707 .577 .707 r
F P
0 g
s
.51564 .77948 m .52032 .74211 L .51176 .73479 L p .707 .577 .707 r
F P
0 g
s
.51185 .73291 m .51453 .73707 L p .51271 .72476 L .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .50709 .77217 L .51564 .77948 L p .707 .577 .707 r
F P
0 g
s
.51176 .73479 m .51307 .72843 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.50709 .77217 m .51097 .74111 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.51097 .74111 m .51176 .73479 L p .5097 .75305 L .707 .577 .707 r
F P
0 g
s
.5051 .67309 m .50873 .72807 L .51185 .73291 L p .707 .577 .707 r
F P
0 g
s
.51271 .72476 m .5051 .67309 L .51185 .73291 L .707 .577 .707 r
F
.51145 .79992 m .5175 .78173 L .50821 .77595 L p F P
0 g
s
.50821 .77595 m .50215 .79413 L .51145 .79992 L p .707 .577 .707 r
F P
0 g
s
.69032 .83886 m .68427 .85704 L .69373 .85745 L p .707 .577 .707 r
F P
0 g
s
.69373 .85745 m .69978 .83927 L .69032 .83886 L p .707 .577 .707 r
F P
0 g
s
.50873 .72807 m .5051 .67309 L .50928 .66341 L p .707 .577 .707 r
F P
0 g
s
.70897 .65926 m .7126 .71424 L .7068 .70523 L p .707 .577 .707 r
F P
0 g
s
.7068 .70523 m .70317 .65026 L .70897 .65926 L p .707 .577 .707 r
F P
0 g
s
.47927 .82152 m .47927 .31963 L .43617 .31604 L p .707 .577 .707 r
F P
0 g
s
.50928 .66341 m .5129 .71839 L .50873 .72807 L p .707 .577 .707 r
F P
0 g
s
.51307 .72843 m .50839 .7658 L .50709 .77217 L p .707 .577 .707 r
F P
0 g
s
.50215 .79413 m .50821 .77595 L .50829 .77313 L p .707 .578 .707 r
F P
0 g
s
.50829 .77313 m .50224 .79131 L .50215 .79413 L p .707 .578 .707 r
F P
0 g
s
.5129 .71839 m .50928 .66341 L .52302 .654 L p .707 .577 .707 r
F P
0 g
s
.50839 .7658 m .51307 .72843 L .5241 .72363 L p .707 .577 .707 r
F P
0 g
s
.52302 .654 m .52665 .70898 L .5129 .71839 L p .707 .577 .707 r
F P
0 g
s
.5241 .72363 m .51943 .761 L .50839 .7658 L p .707 .577 .707 r
F P
0 g
s
.50224 .79131 m .50829 .77313 L .51775 .77354 L p .707 .577 .707 r
F P
0 g
s
.51775 .77354 m .5117 .79172 L .50224 .79131 L p .707 .577 .707 r
F P
0 g
s
.5117 .79172 m .51775 .77354 L .53566 .77715 L p .707 .577 .707 r
F P
0 g
s
.53566 .77715 m .52961 .79534 L .5117 .79172 L p .707 .577 .707 r
F P
0 g
s
.47927 .31963 m .47927 .82152 L .52439 .82137 L p .707 .577 .707 r
F P
0 g
s
.52665 .70898 m .52302 .654 L .54499 .64578 L p .707 .577 .707 r
F P
0 g
s
.51943 .761 m .5241 .72363 L .54379 .72087 L p .707 .577 .707 r
F P
0 g
s
.54379 .72087 m .53912 .75825 L .51943 .761 L p .707 .577 .707 r
F P
0 g
s
.52439 .82137 m .52439 .31948 L .47927 .31963 L p .707 .577 .707 r
F P
0 g
s
.54499 .64578 m .54862 .70076 L .52665 .70898 L p .707 .577 .707 r
F P
0 g
s
.54862 .70076 m .54499 .64578 L .57303 .63956 L p .707 .577 .707 r
F P
0 g
s
.57303 .63956 m .57666 .69454 L .54862 .70076 L p .707 .577 .707 r
F P
0 g
s
.53912 .75825 m .54379 .72087 L .57021 .72042 L p .707 .577 .707 r
F P
0 g
s
.57021 .72042 m .56554 .75779 L .53912 .75825 L p .707 .577 .707 r
F P
0 g
s
.52961 .79534 m .53566 .77715 L .56026 .78361 L p .707 .577 .707 r
F P
0 g
s
.56026 .78361 m .55421 .80179 L .52961 .79534 L p .707 .577 .707 r
F P
0 g
s
.55421 .80179 m .56026 .78361 L .58914 .79227 L p .707 .577 .707 r
F P
0 g
s
.58914 .79227 m .58309 .81046 L .55421 .80179 L p .707 .577 .707 r
F P
0 g
s
.52439 .31948 m .52439 .82137 L .56713 .81748 L p .707 .577 .707 r
F P
0 g
s
.56554 .75779 m .57021 .72042 L .60076 .72232 L p .707 .577 .707 r
F P
0 g
s
.60076 .72232 m .59609 .7597 L .56554 .75779 L p .707 .577 .707 r
F P
0 g
s
.56713 .81748 m .56713 .31559 L .52439 .31948 L p .707 .577 .707 r
F P
0 g
s
.71193 .76048 m .70725 .79785 L .70856 .79149 L p .707 .577 .707 r
F P
0 g
s
.70856 .79149 m .71323 .75411 L .71193 .76048 L p .707 .577 .707 r
F P
0 g
s
.43617 .81793 m .43617 .31604 L .39932 .30905 L p .707 .577 .707 r
F P
0 g
s
.43617 .31604 m .43617 .81793 L .47927 .82152 L p .707 .577 .707 r
F P
0 g
s
.57666 .69454 m .57303 .63956 L .60441 .63594 L p .707 .577 .707 r
F P
0 g
s
.60441 .63594 m .60803 .69092 L .57666 .69454 L p .707 .577 .707 r
F P
0 g
s
.63247 .72639 m .62779 .76376 L .59609 .7597 L p .707 .577 .707 r
F P
0 g
s
.59609 .7597 m .60076 .72232 L .63247 .72639 L p .707 .577 .707 r
F P
0 g
s
.58309 .81046 m .58914 .79227 L .61949 .8023 L p .707 .577 .707 r
F P
0 g
s
.61949 .8023 m .61343 .82049 L .58309 .81046 L p .707 .577 .707 r
F P
0 g
s
.56713 .31559 m .56713 .81748 L .6033 .81023 L p .707 .577 .707 r
F P
0 g
s
.6033 .81023 m .6033 .30834 L .56713 .31559 L p .707 .577 .707 r
F P
0 g
s
.69978 .83927 m .69373 .85745 L .69381 .85463 L p .707 .578 .707 r
F P
0 g
s
.69381 .85463 m .69987 .83645 L .69978 .83927 L p .707 .578 .707 r
F P
0 g
s
.26593 .70896 m .26432 .6526 L .23264 .65257 L p .707 .577 .707 r
F P
0 g
s
.26432 .6526 m .26593 .70896 L .29735 .70686 L p .707 .577 .707 r
F P
0 g
s
.29735 .70686 m .29574 .65051 L .26432 .6526 L p .707 .577 .707 r
F P
0 g
s
.70317 .65026 m .7068 .70523 L .69159 .69779 L p .707 .577 .707 r
F P
0 g
s
.69159 .69779 m .68796 .64281 L .70317 .65026 L p .707 .577 .707 r
F P
0 g
s
.23425 .70893 m .23264 .65257 L .2038 .65043 L p .707 .577 .707 r
F P
0 g
s
.23264 .65257 m .23425 .70893 L .26593 .70896 L p .707 .577 .707 r
F P
0 g
s
.29574 .65051 m .29735 .70686 L .32543 .70286 L p .707 .577 .707 r
F P
0 g
s
.32543 .70286 m .32382 .6465 L .29574 .65051 L p .707 .577 .707 r
F P
0 g
s
.71323 .75411 m .70856 .79149 L .7 .78418 L p .707 .577 .707 r
F P
0 g
s
.7 .78418 m .70468 .7468 L .71323 .75411 L p .707 .577 .707 r
F P
0 g
s
.39932 .81094 m .39932 .30905 L .37233 .29934 L p .707 .577 .707 r
F P
0 g
s
.39932 .30905 m .39932 .81094 L .43617 .81793 L p .707 .577 .707 r
F P
0 g
s
.2038 .65043 m .2054 .70679 L .23425 .70893 L p .707 .577 .707 r
F P
0 g
s
.63603 .63529 m .63966 .69026 L .60803 .69092 L p .707 .577 .707 r
F P
0 g
s
.60803 .69092 m .60441 .63594 L .63603 .63529 L p .707 .577 .707 r
F P
0 g
s
.61343 .82049 m .61949 .8023 L .64832 .81271 L p .707 .577 .707 r
F P
0 g
s
.6033 .30834 m .6033 .81023 L .62935 .80035 L p .707 .577 .707 r
F P
0 g
s
.66222 .73222 m .65754 .7696 L .62779 .76376 L p .707 .577 .707 r
F P
0 g
s
.62779 .76376 m .63247 .72639 L .66222 .73222 L p .707 .577 .707 r
F P
0 g
s
.62935 .80035 m .62935 .29846 L .6033 .30834 L p .707 .577 .707 r
F P
0 g
s
.2054 .70679 m .2038 .65043 L .18062 .64638 L p .707 .577 .707 r
F P
0 g
s
.32382 .6465 m .32543 .70286 L .34742 .69733 L p .707 .577 .707 r
F P
0 g
s
.34742 .69733 m .34582 .64097 L .32382 .6465 L p .707 .577 .707 r
F P
0 g
s
.27387 .78458 m .27598 .74881 L .24409 .74671 L p .707 .577 .707 r
F P
0 g
s
.27598 .74881 m .27387 .78458 L .3046 .783 L p .707 .577 .707 r
F P
0 g
s
.3046 .783 m .30671 .74723 L .27598 .74881 L p .707 .577 .707 r
F P
0 g
s
.24198 .78248 m .24409 .74671 L .21415 .74114 L p .707 .577 .707 r
F P
0 g
s
.24409 .74671 m .24198 .78248 L .27387 .78458 L p .707 .577 .707 r
F P
0 g
s
.69987 .83645 m .69381 .85463 L .68452 .84885 L p .707 .577 .707 r
F P
0 g
s
.68452 .84885 m .69058 .83067 L .69987 .83645 L p .707 .577 .707 r
F P
0 g
s
.18062 .64638 m .18222 .70274 L .2054 .70679 L p .707 .577 .707 r
F P
0 g
s
.68796 .64281 m .69159 .69779 L .66845 .69263 L p .707 .577 .707 r
F P
0 g
s
.66845 .69263 m .66483 .63765 L .68796 .64281 L p .707 .577 .707 r
F P
0 g
s
.30671 .74723 m .3046 .783 L .33115 .77789 L p .707 .577 .707 r
F P
0 g
s
.33115 .77789 m .33326 .74213 L .30671 .74723 L p .707 .577 .707 r
F P
0 g
s
.21204 .77691 m .21415 .74114 L .1891 .73264 L p .707 .577 .707 r
F P
0 g
s
.21415 .74114 m .21204 .77691 L .24198 .78248 L p .707 .577 .707 r
F P
0 g
s
.18222 .70274 m .18062 .64638 L .16537 .64082 L p .707 .577 .707 r
F P
0 g
s
.70468 .7468 m .7 .78418 L .68242 .77663 L p .707 .577 .707 r
F P
0 g
s
.68242 .77663 m .6871 .73926 L .70468 .7468 L p .707 .577 .707 r
F P
0 g
s
.34582 .64097 m .34742 .69733 L .36117 .69082 L p .707 .577 .707 r
F P
0 g
s
.36117 .69082 m .35957 .63446 L .34582 .64097 L p .707 .577 .707 r
F P
0 g
s
.1891 .73264 m .18699 .76841 L .21204 .77691 L p .707 .577 .707 r
F P
0 g
s
.33326 .74213 m .33115 .77789 L .35093 .76976 L p .707 .577 .707 r
F P
0 g
s
.35093 .76976 m .35304 .734 L .33326 .74213 L p .707 .577 .707 r
F P
0 g
s
.37233 .80123 m .37233 .29934 L .35783 .28787 L p .707 .577 .707 r
F P
0 g
s
.37233 .29934 m .37233 .80123 L .39932 .81094 L p .707 .577 .707 r
F P
0 g
s
.18699 .76841 m .1891 .73264 L .17138 .72204 L p .707 .577 .707 r
F P
0 g
s
.16537 .64082 m .16697 .69718 L .18222 .70274 L p .707 .577 .707 r
F P
0 g
s
.66483 .63765 m .66845 .69263 L .63966 .69026 L p .707 .577 .707 r
F P
0 g
s
.63966 .69026 m .63603 .63529 L .66483 .63765 L p .707 .577 .707 r
F P
0 g
s
.62935 .29846 m .62935 .80035 L .64275 .78878 L p .707 .577 .707 r
F P
0 g
s
.64275 .78878 m .64275 .28689 L .62935 .29846 L p .707 .577 .707 r
F P
0 g
s
.24223 .83481 m .24504 .81837 L .21492 .80962 L p .707 .577 .707 r
F P
0 g
s
.24504 .81837 m .24223 .83481 L .27386 .83878 L p .707 .577 .707 r
F P
0 g
s
.27386 .83878 m .27666 .82234 L .24504 .81837 L p .707 .577 .707 r
F P
0 g
s
.27666 .82234 m .27386 .83878 L .3039 .83758 L p .707 .577 .707 r
F P
0 g
s
.3039 .83758 m .3067 .82114 L .27666 .82234 L p .707 .577 .707 r
F P
0 g
s
.69058 .83067 m .68452 .84885 L .66676 .84067 L p .707 .577 .707 r
F P
0 g
s
.66676 .84067 m .67281 .82249 L .69058 .83067 L p .707 .577 .707 r
F P
0 g
s
.21212 .82606 m .21492 .80962 L .18927 .79694 L p .707 .577 .707 r
F P
0 g
s
.21492 .80962 m .21212 .82606 L .24223 .83481 L p .707 .577 .707 r
F P
0 g
s
.17138 .72204 m .16927 .75781 L .18699 .76841 L p .707 .577 .707 r
F P
0 g
s
.16697 .69718 m .16537 .64082 L .15954 .6343 L p .707 .577 .707 r
F P
0 g
s
.3067 .82114 m .3039 .83758 L .32942 .83133 L p .707 .577 .707 r
F P
0 g
s
.32942 .83133 m .33222 .81489 L .3067 .82114 L p .707 .577 .707 r
F P
0 g
s
.6871 .73926 m .68242 .77663 L .65754 .7696 L p .707 .577 .707 r
F P
0 g
s
.65754 .7696 m .66222 .73222 L .6871 .73926 L p .707 .577 .707 r
F P
0 g
s
.18927 .79694 m .18647 .81339 L .21212 .82606 L p .707 .577 .707 r
F P
0 g
s
.35957 .63446 m .36117 .69082 L .36534 .68396 L p .707 .577 .707 r
F P
0 g
s
.36534 .68396 m .36374 .62761 L .35957 .63446 L p .707 .577 .707 r
F P
0 g
s
.35304 .734 m .35093 .76976 L .36199 .7594 L p .707 .577 .707 r
F P
0 g
s
.36199 .7594 m .36411 .72364 L .35304 .734 L p .707 .577 .707 r
F P
0 g
s
.18647 .81339 m .18927 .79694 L .17059 .78158 L p .707 .577 .707 r
F P
0 g
s
.16927 .75781 m .17138 .72204 L .16274 .71039 L p .707 .577 .707 r
F P
0 g
s
.15954 .6343 m .16114 .69065 L .16697 .69718 L p .707 .577 .707 r
F P
0 g
s
.17059 .78158 m .16778 .79803 L .18647 .81339 L p .707 .577 .707 r
F P
0 g
s
.67281 .82249 m .66676 .84067 L .64226 .8309 L p .707 .577 .707 r
F P
0 g
s
.64226 .8309 m .64832 .81271 L .67281 .82249 L p .707 .577 .707 r
F P
0 g
s
.33222 .81489 m .32942 .83133 L .34791 .82064 L p .707 .577 .707 r
F P
0 g
s
.34791 .82064 m .35072 .8042 L .33222 .81489 L p .707 .577 .707 r
F P
0 g
s
.16274 .71039 m .16063 .74615 L .16927 .75781 L p .707 .577 .707 r
F P
0 g
s
.36411 .72364 m .36199 .7594 L .36327 .74783 L p .707 .577 .707 r
F P
0 g
s
.36327 .74783 m .36538 .71206 L .36411 .72364 L p .707 .577 .707 r
F P
0 g
s
.36538 .71206 m .36327 .74783 L .35462 .73617 L p .707 .577 .707 r
F P
0 g
s
.35462 .73617 m .35674 .70041 L .36538 .71206 L p .707 .577 .707 r
F P
0 g
s
.35791 .62108 m .35952 .67744 L .34427 .67188 L p .707 .577 .707 r
F P
0 g
s
.34427 .67188 m .34266 .61552 L .35791 .62108 L p .707 .577 .707 r
F P
0 g
s
.36026 .77401 m .36038 .79011 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35746 .79046 m .35856 .78401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35856 .78401 m .36026 .77401 L p .35873 .79031 L .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35725 .27577 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36026 .77401 m .35746 .79046 L .34758 .77392 L p .707 .577 .707 r
F P
0 g
s
.34758 .77392 m .35038 .75747 L .36026 .77401 L p .707 .577 .707 r
F P
0 g
s
.35783 .78976 m .35783 .75807 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.35783 .75807 m .35783 .28787 L p .35779 .75674 L .708 .578 .707 r
F P
0 g
s
.36374 .62761 m .36534 .68396 L .35952 .67744 L p .707 .577 .707 r
F P
0 g
s
.35952 .67744 m .35791 .62108 L .36374 .62761 L p .707 .577 .707 r
F P
0 g
s
.35757 .80656 m .36038 .79011 L .35072 .8042 L p .707 .577 .707 r
F P
0 g
s
.36038 .79011 m .35757 .80656 L .35746 .79046 L p .707 .577 .707 r
F P
0 g
s
.35783 .28787 m .35783 .78976 L .37233 .80123 L p .707 .577 .707 r
F P
0 g
s
.64275 .28689 m .64275 .78878 L .64217 .77667 L p .708 .578 .707 r
F P
0 g
s
.64217 .77667 m .64217 .27478 L .64275 .28689 L p .708 .578 .707 r
F P
0 g
s
.16778 .79803 m .17059 .78158 L .16071 .76505 L p .707 .577 .707 r
F P
0 g
s
.16114 .69065 m .15954 .6343 L .16371 .62744 L p .707 .577 .707 r
F P
0 g
s
.64832 .81271 m .64226 .8309 L .61343 .82049 L p .707 .577 .707 r
F P
0 g
s
.16063 .74615 m .16274 .71039 L .16401 .69881 L p .707 .577 .707 r
F P
0 g
s
.16071 .76505 m .1579 .78149 L .16778 .79803 L p .707 .577 .707 r
F P
0 g
s
.35072 .8042 m .34791 .82064 L .35757 .80656 L p .707 .577 .707 r
F P
0 g
s
.16371 .62744 m .16531 .6838 L .16114 .69065 L p .707 .577 .707 r
F P
0 g
s
.16401 .69881 m .1619 .73458 L .16063 .74615 L p .707 .577 .707 r
F P
0 g
s
.1579 .78149 m .16071 .76505 L .16059 .74895 L p .707 .577 .707 r
F P
0 g
s
.16531 .6838 m .16371 .62744 L .17746 .62093 L p .707 .577 .707 r
F P
0 g
s
.16059 .74895 m .15779 .76539 L .1579 .78149 L p .707 .577 .707 r
F P
0 g
s
.35725 .27577 m .35725 .77766 L .35783 .78976 L p .708 .578 .707 r
F P
0 g
s
.35725 .77766 m .35725 .27577 L .37064 .2642 L p .707 .577 .707 r
F P
0 g
s
.1619 .73458 m .16401 .69881 L .17508 .68845 L p .707 .577 .707 r
F P
0 g
s
.64217 .27478 m .64217 .77667 L .62767 .76521 L p .707 .577 .707 r
F P
0 g
s
.62767 .76521 m .62767 .26332 L .64217 .27478 L p .707 .577 .707 r
F P
0 g
s
.17746 .62093 m .17907 .67729 L .16531 .6838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17508 .68845 m .17297 .72422 L .1619 .73458 L p .707 .577 .707 r
F P
0 g
s
.15779 .76539 m .16059 .74895 L .17025 .73486 L p .707 .577 .707 r
F P
0 g
s
.17907 .67729 m .17746 .62093 L .19946 .6154 L p .707 .577 .707 r
F P
0 g
s
.17025 .73486 m .16745 .7513 L .15779 .76539 L p .707 .577 .707 r
F P
0 g
s
.35674 .70041 m .35462 .73617 L .33691 .72558 L p .707 .577 .707 r
F P
0 g
s
.33691 .72558 m .33902 .68981 L .35674 .70041 L p .707 .577 .707 r
F P
0 g
s
.34266 .61552 m .34427 .67188 L .32108 .66783 L p .707 .577 .707 r
F P
0 g
s
.32108 .66783 m .31948 .61147 L .34266 .61552 L p .707 .577 .707 r
F P
0 g
s
.17297 .72422 m .17508 .68845 L .19486 .68032 L p .707 .577 .707 r
F P
0 g
s
.19946 .6154 m .20106 .67176 L .17907 .67729 L p .707 .577 .707 r
F P
0 g
s
.37064 .76609 m .37064 .2642 L .3967 .25431 L p .707 .577 .707 r
F P
0 g
s
.37064 .2642 m .37064 .76609 L .35725 .77766 L p .707 .577 .707 r
F P
0 g
s
.16745 .7513 m .17025 .73486 L .18875 .72417 L p .707 .577 .707 r
F P
0 g
s
.19486 .68032 m .19275 .71609 L .17297 .72422 L p .707 .577 .707 r
F P
0 g
s
.62767 .26332 m .62767 .76521 L .60068 .7555 L p .707 .577 .707 r
F P
0 g
s
.60068 .7555 m .60068 .25361 L .62767 .26332 L p .707 .577 .707 r
F P
0 g
s
.20106 .67176 m .19946 .6154 L .22754 .6114 L p .707 .577 .707 r
F P
0 g
s
.31948 .61147 m .32108 .66783 L .29224 .66569 L p .707 .577 .707 r
F P
0 g
s
.29224 .66569 m .29064 .60933 L .31948 .61147 L p .707 .577 .707 r
F P
0 g
s
.33902 .68981 m .33691 .72558 L .31186 .71707 L p .707 .577 .707 r
F P
0 g
s
.31186 .71707 m .31397 .68131 L .33902 .68981 L p .707 .577 .707 r
F P
0 g
s
.18875 .72417 m .18594 .74061 L .16745 .7513 L p .707 .577 .707 r
F P
0 g
s
.19275 .71609 m .19486 .68032 L .22141 .67522 L p .707 .577 .707 r
F P
0 g
s
.35038 .75747 m .34758 .77392 L .32889 .75856 L p .707 .577 .707 r
F P
0 g
s
.32889 .75856 m .3317 .74212 L .35038 .75747 L p .707 .577 .707 r
F P
0 g
s
.22754 .6114 m .22914 .66775 L .20106 .67176 L p .707 .577 .707 r
F P
0 g
s
.22914 .66775 m .22754 .6114 L .25896 .6093 L p .707 .577 .707 r
F P
0 g
s
.29064 .60933 m .29224 .66569 L .26056 .66566 L p .707 .577 .707 r
F P
0 g
s
.26056 .66566 m .25896 .6093 L .29064 .60933 L p .707 .577 .707 r
F P
0 g
s
.18594 .74061 m .18875 .72417 L .21427 .71792 L p .707 .577 .707 r
F P
0 g
s
.22141 .67522 m .2193 .71098 L .19275 .71609 L p .707 .577 .707 r
F P
0 g
s
.25896 .6093 m .26056 .66566 L .22914 .66775 L p .707 .577 .707 r
F P
0 g
s
.31397 .68131 m .31186 .71707 L .28192 .7115 L p .707 .577 .707 r
F P
0 g
s
.28192 .7115 m .28403 .67573 L .31397 .68131 L p .707 .577 .707 r
F P
0 g
s
.2193 .71098 m .22141 .67522 L .25214 .67363 L p .707 .577 .707 r
F P
0 g
s
.21427 .71792 m .21146 .73436 L .18594 .74061 L p .707 .577 .707 r
F P
0 g
s
.73944 .66108 m .74104 .60649 L .70936 .60431 L p .707 .577 .707 r
F P
0 g
s
.74104 .60649 m .73944 .66108 L .77086 .66002 L p .707 .577 .707 r
F P
0 g
s
.77086 .66002 m .77246 .60544 L .74104 .60649 L p .707 .577 .707 r
F P
0 g
s
.3317 .74212 m .32889 .75856 L .30324 .74588 L p .707 .577 .707 r
F P
0 g
s
.30324 .74588 m .30605 .72944 L .3317 .74212 L p .707 .577 .707 r
F P
0 g
s
.3967 .25431 m .3967 .7562 L .37064 .76609 L p .707 .577 .707 r
F P
0 g
s
.3967 .7562 m .3967 .25431 L .43287 .24707 L p .707 .577 .707 r
F P
0 g
s
.28403 .67573 m .28192 .7115 L .25002 .7094 L p .707 .577 .707 r
F P
0 g
s
.25002 .7094 m .25214 .67363 L .28403 .67573 L p .707 .577 .707 r
F P
0 g
s
.25214 .67363 m .25002 .7094 L .2193 .71098 L p .707 .577 .707 r
F P
0 g
s
.60068 .25361 m .60068 .7555 L .56383 .74851 L p .707 .577 .707 r
F P
0 g
s
.56383 .74851 m .56383 .24662 L .60068 .25361 L p .707 .577 .707 r
F P
0 g
s
.70776 .6589 m .70936 .60431 L .68052 .59911 L p .707 .577 .707 r
F P
0 g
s
.70936 .60431 m .70776 .6589 L .73944 .66108 L p .707 .577 .707 r
F P
0 g
s
.77246 .60544 m .77086 .66002 L .79894 .65583 L p .707 .577 .707 r
F P
0 g
s
.79894 .65583 m .80054 .60125 L .77246 .60544 L p .707 .577 .707 r
F P
0 g
s
.21146 .73436 m .21427 .71792 L .24431 .71672 L p .707 .577 .707 r
F P
0 g
s
.30605 .72944 m .30324 .74588 L .27313 .73713 L p .707 .577 .707 r
F P
0 g
s
.27313 .73713 m .27593 .72069 L .30605 .72944 L p .707 .577 .707 r
F P
0 g
s
.67891 .65369 m .68052 .59911 L .65734 .59139 L p .707 .577 .707 r
F P
0 g
s
.68052 .59911 m .67891 .65369 L .70776 .6589 L p .707 .577 .707 r
F P
0 g
s
.24431 .71672 m .2415 .73316 L .21146 .73436 L p .707 .577 .707 r
F P
0 g
s
.2415 .73316 m .24431 .71672 L .27593 .72069 L p .707 .577 .707 r
F P
0 g
s
.80054 .60125 m .79894 .65583 L .82093 .64892 L p .707 .577 .707 r
F P
0 g
s
.82093 .64892 m .82254 .59433 L .80054 .60125 L p .707 .577 .707 r
F P
0 g
s
.27593 .72069 m .27313 .73713 L .2415 .73316 L p .707 .577 .707 r
F P
0 g
s
.74997 .70547 m .74786 .66761 L .71597 .66913 L p .707 .577 .707 r
F P
0 g
s
.74786 .66761 m .74997 .70547 L .7807 .70233 L p .707 .577 .707 r
F P
0 g
s
.7807 .70233 m .77859 .66448 L .74786 .66761 L p .707 .577 .707 r
F P
0 g
s
.71808 .70698 m .71597 .66913 L .68603 .66887 L p .707 .577 .707 r
F P
0 g
s
.71597 .66913 m .71808 .70698 L .74997 .70547 L p .707 .577 .707 r
F P
0 g
s
.43287 .74896 m .43287 .24707 L .47561 .24318 L p .707 .577 .707 r
F P
0 g
s
.43287 .24707 m .43287 .74896 L .3967 .7562 L p .707 .577 .707 r
F P
0 g
s
.56383 .24662 m .56383 .74851 L .52073 .74492 L p .707 .577 .707 r
F P
0 g
s
.52073 .74492 m .52073 .24303 L .56383 .24662 L p .707 .577 .707 r
F P
0 g
s
.72687 .73695 m .72407 .71793 L .69395 .72221 L p .707 .577 .707 r
F P
0 g
s
.72407 .71793 m .72687 .73695 L .7585 .73229 L p .707 .577 .707 r
F P
0 g
s
.7585 .73229 m .75569 .71326 L .72407 .71793 L p .707 .577 .707 r
F P
0 g
s
.75569 .71326 m .7585 .73229 L .78854 .7277 L p .707 .577 .707 r
F P
0 g
s
.78854 .7277 m .78573 .70868 L .75569 .71326 L p .707 .577 .707 r
F P
0 g
s
.69395 .72221 m .69676 .74123 L .72687 .73695 L p .707 .577 .707 r
F P
0 g
s
.68603 .66887 m .68814 .70672 L .71808 .70698 L p .707 .577 .707 r
F P
0 g
s
.77859 .66448 m .7807 .70233 L .80725 .69789 L p .707 .577 .707 r
F P
0 g
s
.80725 .69789 m .80514 .66003 L .77859 .66448 L p .707 .577 .707 r
F P
0 g
s
.65734 .59139 m .65573 .64597 L .67891 .65369 L p .707 .577 .707 r
F P
0 g
s
.68814 .70672 m .68603 .66887 L .66098 .66687 L p .707 .577 .707 r
F P
0 g
s
.65573 .64597 m .65734 .59139 L .64209 .58191 L p .707 .577 .707 r
F P
0 g
s
.69676 .74123 m .69395 .72221 L .6683 .72569 L p .707 .577 .707 r
F P
0 g
s
.78573 .70868 m .78854 .7277 L .81405 .72364 L p .707 .577 .707 r
F P
0 g
s
.81405 .72364 m .81125 .70461 L .78573 .70868 L p .707 .577 .707 r
F P
0 g
s
.47561 .74507 m .47561 .24318 L .52073 .24303 L p .707 .577 .707 r
F P
0 g
s
.47561 .24318 m .47561 .74507 L .43287 .74896 L p .707 .577 .707 r
F P
0 g
s
.6683 .72569 m .6711 .74471 L .69676 .74123 L p .707 .577 .707 r
F P
0 g
s
.52073 .24303 m .52073 .74492 L .47561 .74507 L p .707 .577 .707 r
F P
0 g
s
.66098 .66687 m .66309 .70473 L .68814 .70672 L p .707 .577 .707 r
F P
0 g
s
.82254 .59433 m .82093 .64892 L .83469 .63995 L p .707 .577 .707 r
F P
0 g
s
.83469 .63995 m .83629 .58537 L .82254 .59433 L p .707 .577 .707 r
F P
0 g
s
.80514 .66003 m .80725 .69789 L .82703 .69256 L p .707 .577 .707 r
F P
0 g
s
.82703 .69256 m .82492 .65471 L .80514 .66003 L p .707 .577 .707 r
F P
0 g
s
.64209 .58191 m .64048 .6365 L .65573 .64597 L p .707 .577 .707 r
F P
0 g
s
.66309 .70473 m .66098 .66687 L .64326 .66333 L p .707 .577 .707 r
F P
0 g
s
.6711 .74471 m .6683 .72569 L .64962 .72803 L p .707 .577 .707 r
F P
0 g
s
.81125 .70461 m .81405 .72364 L .83255 .72049 L p .707 .577 .707 r
F P
0 g
s
.83255 .72049 m .82974 .70147 L .81125 .70461 L p .707 .577 .707 r
F P
0 g
s
.64962 .72803 m .65242 .74705 L .6711 .74471 L p .707 .577 .707 r
F P
0 g
s
.64326 .66333 m .64537 .70118 L .66309 .70473 L p .707 .577 .707 r
F P
0 g
s
.64048 .6365 m .64209 .58191 L .63626 .5716 L p .707 .577 .707 r
F P
0 g
s
.83629 .58537 m .83469 .63995 L .83885 .62982 L p .707 .577 .707 r
F P
0 g
s
.83885 .62982 m .84046 .57524 L .83629 .58537 L p .707 .577 .707 r
F P
0 g
s
.82492 .65471 m .82703 .69256 L .8381 .68688 L p .707 .577 .707 r
F P
0 g
s
.8381 .68688 m .83598 .64903 L .82492 .65471 L p .707 .577 .707 r
F P
0 g
s
.63626 .5716 m .63466 .62619 L .64048 .6365 L p .707 .577 .707 r
F P
0 g
s
.64537 .70118 m .64326 .66333 L .63462 .65858 L p .707 .577 .707 r
F P
0 g
s
.65242 .74705 m .64962 .72803 L .63973 .729 L p .707 .577 .707 r
F P
0 g
s
.82974 .70147 m .83255 .72049 L .84221 .71858 L p .707 .577 .707 r
F P
0 g
s
.84221 .71858 m .83941 .69956 L .82974 .70147 L p .707 .577 .707 r
F P
0 g
s
.63973 .729 m .64254 .74802 L .65242 .74705 L p .707 .577 .707 r
F P
0 g
s
.63462 .65858 m .63673 .69643 L .64537 .70118 L p .707 .577 .707 r
F P
0 g
s
.63466 .62619 m .63626 .5716 L .64043 .56147 L p .707 .577 .707 r
F P
0 g
s
.84046 .57524 m .83885 .62982 L .83303 .61952 L p .707 .577 .707 r
F P
0 g
s
.83303 .61952 m .83463 .56493 L .84046 .57524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83598 .64903 m .8381 .68688 L .83937 .6814 L p .707 .577 .707 r
F P
0 g
s
.83937 .6814 m .83726 .64355 L .83598 .64903 L p .707 .577 .707 r
F P
0 g
s
.64043 .56147 m .63882 .61606 L .63466 .62619 L p .707 .577 .707 r
F P
0 g
s
.63673 .69643 m .63462 .65858 L .63589 .6531 L p .707 .577 .707 r
F P
0 g
s
.64254 .74802 m .63973 .729 L .63962 .7285 L p .712 .581 .706 r
F P
0 g
s
.83941 .69956 m .84221 .71858 L .8421 .71809 L p .712 .581 .706 r
F P
0 g
s
.8421 .71809 m .83929 .69906 L .83941 .69956 L p .712 .581 .706 r
F P
0 g
s
.63962 .7285 m .64242 .74753 L .64254 .74802 L p .712 .581 .706 r
F P
0 g
s
.63589 .6531 m .63801 .69095 L .63673 .69643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63882 .61606 m .64043 .56147 L .65418 .55251 L p .707 .577 .707 r
F P
0 g
s
.39196 .6187 m .39559 .56278 L .36396 .55984 L p .707 .577 .707 r
F P
0 g
s
.39559 .56278 m .39196 .6187 L .42334 .61923 L p .707 .577 .707 r
F P
0 g
s
.42334 .61923 m .42696 .56331 L .39559 .56278 L p .707 .577 .707 r
F P
0 g
s
.36034 .61576 m .36396 .55984 L .33517 .55479 L p .707 .577 .707 r
F P
0 g
s
.36396 .55984 m .36034 .61576 L .39196 .6187 L p .707 .577 .707 r
F P
0 g
s
.83463 .56493 m .83303 .61952 L .81778 .61004 L p .707 .577 .707 r
F P
0 g
s
.81778 .61004 m .81938 .55546 L .83463 .56493 L p .707 .577 .707 r
F P
0 g
s
.42696 .56331 m .42334 .61923 L .45138 .6173 L p .707 .577 .707 r
F P
0 g
s
.45138 .6173 m .45501 .56138 L .42696 .56331 L p .707 .577 .707 r
F P
0 g
s
.83726 .64355 m .83937 .6814 L .83073 .67665 L p .707 .577 .707 r
F P
0 g
s
.83073 .67665 m .82862 .6388 L .83726 .64355 L p .707 .577 .707 r
F P
0 g
s
.33154 .61071 m .33517 .55479 L .31204 .54812 L p .707 .577 .707 r
F P
0 g
s
.33517 .55479 m .33154 .61071 L .36034 .61576 L p .707 .577 .707 r
F P
0 g
s
.65418 .55251 m .65258 .6071 L .63882 .61606 L p .707 .577 .707 r
F P
0 g
s
.63801 .69095 m .63589 .6531 L .64696 .64742 L p .707 .577 .707 r
F P
0 g
s
.45501 .56138 m .45138 .6173 L .47335 .61311 L p .707 .577 .707 r
F P
0 g
s
.47335 .61311 m .47698 .55719 L .45501 .56138 L p .707 .577 .707 r
F P
0 g
s
.40391 .68623 m .39923 .65021 L .36753 .65343 L p .707 .577 .707 r
F P
0 g
s
.39923 .65021 m .40391 .68623 L .43446 .67985 L p .707 .577 .707 r
F P
0 g
s
.43446 .67985 m .42979 .64382 L .39923 .65021 L p .707 .577 .707 r
F P
0 g
s
.64242 .74753 m .63962 .7285 L .64928 .72659 L p .707 .577 .707 r
F P
0 g
s
.83929 .69906 m .8421 .71809 L .83222 .71906 L p .707 .577 .707 r
F P
0 g
s
.83222 .71906 m .82941 .70003 L .83929 .69906 L p .707 .577 .707 r
F P
0 g
s
.64928 .72659 m .65209 .74562 L .64242 .74753 L p .707 .577 .707 r
F P
0 g
s
.3722 .68946 m .36753 .65343 L .33778 .65319 L p .707 .577 .707 r
F P
0 g
s
.36753 .65343 m .3722 .68946 L .40391 .68623 L p .707 .577 .707 r
F P
0 g
s
.64696 .64742 m .64907 .68527 L .63801 .69095 L p .707 .577 .707 r
F P
0 g
s
.65258 .6071 m .65418 .55251 L .67617 .5456 L p .707 .577 .707 r
F P
0 g
s
.42979 .64382 m .43446 .67985 L .46088 .67093 L p .707 .577 .707 r
F P
0 g
s
.46088 .67093 m .4562 .6349 L .42979 .64382 L p .707 .577 .707 r
F P
0 g
s
.31204 .54812 m .30841 .60404 L .33154 .61071 L p .707 .577 .707 r
F P
0 g
s
.81938 .55546 m .81778 .61004 L .7946 .60232 L p .707 .577 .707 r
F P
0 g
s
.7946 .60232 m .7962 .54774 L .81938 .55546 L p .707 .577 .707 r
F P
0 g
s
.34246 .68921 m .33778 .65319 L .3129 .64949 L p .707 .577 .707 r
F P
0 g
s
.33778 .65319 m .34246 .68921 L .3722 .68946 L p .707 .577 .707 r
F P
0 g
s
.30841 .60404 m .31204 .54812 L .29682 .54048 L p .707 .577 .707 r
F P
0 g
s
.82862 .6388 m .83073 .67665 L .81301 .6731 L p .707 .577 .707 r
F P
0 g
s
.81301 .6731 m .8109 .63525 L .82862 .6388 L p .707 .577 .707 r
F P
0 g
s
.47698 .55719 m .47335 .61311 L .48709 .60706 L p .707 .577 .707 r
F P
0 g
s
.48709 .60706 m .49072 .55114 L .47698 .55719 L p .707 .577 .707 r
F P
0 g
s
.4562 .6349 m .46088 .67093 L .48057 .66035 L p .707 .577 .707 r
F P
0 g
s
.48057 .66035 m .47589 .62433 L .4562 .6349 L p .707 .577 .707 r
F P
0 g
s
.67617 .5456 m .67457 .60018 L .65258 .6071 L p .707 .577 .707 r
F P
0 g
s
.41691 .73404 m .41085 .71764 L .38051 .72664 L p .707 .577 .707 r
F P
0 g
s
.41085 .71764 m .41691 .73404 L .44579 .72114 L p .707 .577 .707 r
F P
0 g
s
.44579 .72114 m .43974 .70474 L .41085 .71764 L p .707 .577 .707 r
F P
0 g
s
.67457 .60018 m .67617 .5456 L .70426 .54141 L p .707 .577 .707 r
F P
0 g
s
.3129 .64949 m .31757 .68551 L .34246 .68921 L p .707 .577 .707 r
F P
0 g
s
.64907 .68527 m .64696 .64742 L .66674 .64209 L p .707 .577 .707 r
F P
0 g
s
.38656 .74305 m .38051 .72664 L .35168 .73086 L p .707 .577 .707 r
F P
0 g
s
.38051 .72664 m .38656 .74305 L .41691 .73404 L p .707 .577 .707 r
F P
0 g
s
.43974 .70474 m .44579 .72114 L .47039 .7056 L p .707 .577 .707 r
F P
0 g
s
.47039 .7056 m .46434 .6892 L .43974 .70474 L p .707 .577 .707 r
F P
0 g
s
.29682 .54048 m .2932 .5964 L .30841 .60404 L p .707 .577 .707 r
F P
0 g
s
.7962 .54774 m .7946 .60232 L .76575 .59711 L p .707 .577 .707 r
F P
0 g
s
.76575 .59711 m .76736 .54253 L .7962 .54774 L p .707 .577 .707 r
F P
0 g
s
.65209 .74562 m .64928 .72659 L .66778 .72345 L p .707 .577 .707 r
F P
0 g
s
.82941 .70003 m .83222 .71906 L .81353 .7214 L p .707 .577 .707 r
F P
0 g
s
.81353 .7214 m .81073 .70237 L .82941 .70003 L p .707 .577 .707 r
F P
0 g
s
.66778 .72345 m .67058 .74247 L .65209 .74562 L p .707 .577 .707 r
F P
0 g
s
.66674 .64209 m .66885 .67994 L .64907 .68527 L p .707 .577 .707 r
F P
0 g
s
.31757 .68551 m .3129 .64949 L .29532 .64271 L p .707 .577 .707 r
F P
0 g
s
.35168 .73086 m .35773 .74727 L .38656 .74305 L p .707 .577 .707 r
F P
0 g
s
.70265 .59599 m .70426 .54141 L .73567 .54035 L p .707 .577 .707 r
F P
0 g
s
.70426 .54141 m .70265 .59599 L .67457 .60018 L p .707 .577 .707 r
F P
0 g
s
.35773 .74727 m .35168 .73086 L .32719 .72989 L p .707 .577 .707 r
F P
0 g
s
.46434 .6892 m .47039 .7056 L .4883 .68895 L p .707 .577 .707 r
F P
0 g
s
.4883 .68895 m .48224 .67255 L .46434 .6892 L p .707 .577 .707 r
F P
0 g
s
.2932 .5964 m .29682 .54048 L .29102 .53261 L p .707 .577 .707 r
F P
0 g
s
.76736 .54253 m .76575 .59711 L .73407 .59493 L p .707 .577 .707 r
F P
0 g
s
.73407 .59493 m .73567 .54035 L .76736 .54253 L p .707 .577 .707 r
F P
0 g
s
.8109 .63525 m .81301 .6731 L .78796 .67111 L p .707 .577 .707 r
F P
0 g
s
.78796 .67111 m .78585 .63325 L .8109 .63525 L p .707 .577 .707 r
F P
0 g
s
.47589 .62433 m .48057 .66035 L .4916 .64915 L p .707 .577 .707 r
F P
0 g
s
.4916 .64915 m .48693 .61312 L .47589 .62433 L p .707 .577 .707 r
F P
0 g
s
.29532 .64271 m .29999 .67873 L .31757 .68551 L p .707 .577 .707 r
F P
0 g
s
.73567 .54035 m .73407 .59493 L .70265 .59599 L p .707 .577 .707 r
F P
0 g
s
.32719 .72989 m .33324 .74629 L .35773 .74727 L p .707 .577 .707 r
F P
0 g
s
.49072 .55114 m .48709 .60706 L .49127 .59974 L p .707 .577 .707 r
F P
0 g
s
.49127 .59974 m .4949 .54383 L .49072 .55114 L p .707 .577 .707 r
F P
0 g
s
.66885 .67994 m .66674 .64209 L .69329 .63764 L p .707 .577 .707 r
F P
0 g
s
.29102 .53261 m .28739 .58853 L .2932 .5964 L p .707 .577 .707 r
F P
0 g
s
.67058 .74247 m .66778 .72345 L .6933 .71939 L p .707 .577 .707 r
F P
0 g
s
.81073 .70237 m .81353 .7214 L .78788 .72488 L p .707 .577 .707 r
F P
0 g
s
.78788 .72488 m .78508 .70585 L .81073 .70237 L p .707 .577 .707 r
F P
0 g
s
.6933 .71939 m .6961 .73841 L .67058 .74247 L p .707 .577 .707 r
F P
0 g
s
.69329 .63764 m .6954 .6755 L .66885 .67994 L p .707 .577 .707 r
F P
0 g
s
.29999 .67873 m .29532 .64271 L .28676 .6335 L p .707 .577 .707 r
F P
0 g
s
.33324 .74629 m .32719 .72989 L .30942 .72381 L p .707 .577 .707 r
F P
0 g
s
.48224 .67255 m .4883 .68895 L .49776 .67281 L p .707 .577 .707 r
F P
0 g
s
.49776 .67281 m .4917 .65641 L .48224 .67255 L p .707 .577 .707 r
F P
0 g
s
.78585 .63325 m .78796 .67111 L .75802 .67085 L p .707 .577 .707 r
F P
0 g
s
.75802 .67085 m .75591 .633 L .78585 .63325 L p .707 .577 .707 r
F P
0 g
s
.6954 .6755 m .69329 .63764 L .72402 .63451 L p .707 .577 .707 r
F P
0 g
s
.30942 .72381 m .31547 .74022 L .33324 .74629 L p .707 .577 .707 r
F P
0 g
s
.28676 .6335 m .29144 .66952 L .29999 .67873 L p .707 .577 .707 r
F P
0 g
s
.28739 .58853 m .29102 .53261 L .2952 .5253 L p .707 .577 .707 r
F P
0 g
s
.48693 .61312 m .4916 .64915 L .49291 .63842 L p .707 .577 .707 r
F P
0 g
s
.49291 .63842 m .48824 .60239 L .48693 .61312 L p .707 .577 .707 r
F P
0 g
s
.72402 .63451 m .72613 .67236 L .6954 .6755 L p .707 .577 .707 r
F P
0 g
s
.75591 .633 m .75802 .67085 L .72613 .67236 L p .707 .577 .707 r
F P
0 g
s
.72613 .67236 m .72402 .63451 L .75591 .633 L p .707 .577 .707 r
F P
0 g
s
.6961 .73841 m .6933 .71939 L .72334 .7148 L p .707 .577 .707 r
F P
0 g
s
.78508 .70585 m .78788 .72488 L .75777 .72916 L p .707 .577 .707 r
F P
0 g
s
.75777 .72916 m .75496 .71013 L .78508 .70585 L p .707 .577 .707 r
F P
0 g
s
.72334 .7148 m .72614 .73382 L .6961 .73841 L p .707 .577 .707 r
F P
0 g
s
.4949 .54383 m .49127 .59974 L .48547 .59188 L p .707 .577 .707 r
F P
0 g
s
.48547 .59188 m .4891 .53596 L .4949 .54383 L p .707 .577 .707 r
F P
0 g
s
.2952 .5253 m .29157 .58122 L .28739 .58853 L p .707 .577 .707 r
F P
0 g
s
.72614 .73382 m .72334 .7148 L .75496 .71013 L p .707 .577 .707 r
F P
0 g
s
.75496 .71013 m .75777 .72916 L .72614 .73382 L p .707 .577 .707 r
F P
0 g
s
.31547 .74022 m .30942 .72381 L .30013 .71324 L p .707 .577 .707 r
F P
0 g
s
.4917 .65641 m .49776 .67281 L .49784 .65877 L p .707 .577 .707 r
F P
0 g
s
.49784 .65877 m .49179 .64236 L .4917 .65641 L p .707 .577 .707 r
F P
0 g
s
.29144 .66952 m .28676 .6335 L .28807 .62276 L p .707 .577 .707 r
F P
0 g
s
.30013 .71324 m .30618 .72964 L .31547 .74022 L p .707 .577 .707 r
F P
0 g
s
.28807 .62276 m .29274 .65879 L .29144 .66952 L p .707 .577 .707 r
F P
0 g
s
.48824 .60239 m .49291 .63842 L .48435 .62921 L p .707 .577 .707 r
F P
0 g
s
.48435 .62921 m .47968 .59318 L .48824 .60239 L p .707 .577 .707 r
F P
0 g
s
.29157 .58122 m .2952 .5253 L .30894 .51925 L p .707 .577 .707 r
F P
0 g
s
.4891 .53596 m .48547 .59188 L .47026 .58424 L p .707 .577 .707 r
F P
0 g
s
.47026 .58424 m .47388 .52832 L .4891 .53596 L p .707 .577 .707 r
F P
0 g
s
.30618 .72964 m .30013 .71324 L .30022 .69919 L p .707 .577 .707 r
F P
0 g
s
.49179 .64236 m .49784 .65877 L .48855 .64819 L p .707 .577 .707 r
F P
0 g
s
.48855 .64819 m .4825 .63178 L .49179 .64236 L p .707 .577 .707 r
F P
0 g
s
.30894 .51925 m .30532 .57517 L .29157 .58122 L p .707 .577 .707 r
F P
0 g
s
.29274 .65879 m .28807 .62276 L .29911 .61156 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30022 .69919 m .30627 .7156 L .30618 .72964 L p .707 .577 .707 r
F P
0 g
s
.30532 .57517 m .30894 .51925 L .33091 .51506 L p .707 .577 .707 r
F P
0 g
s
.29911 .61156 m .30378 .64759 L .29274 .65879 L p .707 .577 .707 r
F P
0 g
s
.47968 .59318 m .48435 .62921 L .46677 .62242 L p .707 .577 .707 r
F P
0 g
s
.46677 .62242 m .4621 .5864 L .47968 .59318 L p .707 .577 .707 r
F P
0 g
s
.47388 .52832 m .47026 .58424 L .44712 .57757 L p .707 .577 .707 r
F P
0 g
s
.44712 .57757 m .45075 .52165 L .47388 .52832 L p .707 .577 .707 r
F P
0 g
s
.30627 .7156 m .30022 .69919 L .30968 .68305 L p .707 .577 .707 r
F P
0 g
s
.4825 .63178 m .48855 .64819 L .47079 .64212 L p .707 .577 .707 r
F P
0 g
s
.47079 .64212 m .46473 .62571 L .4825 .63178 L p .707 .577 .707 r
F P
0 g
s
.33091 .51506 m .32729 .57098 L .30532 .57517 L p .707 .577 .707 r
F P
0 g
s
.30378 .64759 m .29911 .61156 L .3188 .60098 L p .707 .577 .707 r
F P
0 g
s
.30968 .68305 m .31573 .69946 L .30627 .7156 L p .707 .577 .707 r
F P
0 g
s
.32729 .57098 m .33091 .51506 L .35896 .51313 L p .707 .577 .707 r
F P
0 g
s
.4621 .5864 m .46677 .62242 L .44189 .61872 L p .707 .577 .707 r
F P
0 g
s
.44189 .61872 m .43722 .5827 L .4621 .5864 L p .707 .577 .707 r
F P
0 g
s
.45075 .52165 m .44712 .57757 L .41833 .57251 L p .707 .577 .707 r
F P
0 g
s
.41833 .57251 m .42196 .5166 L .45075 .52165 L p .707 .577 .707 r
F P
0 g
s
.3188 .60098 m .32347 .63701 L .30378 .64759 L p .707 .577 .707 r
F P
0 g
s
.35896 .51313 m .35533 .56905 L .32729 .57098 L p .707 .577 .707 r
F P
0 g
s
.35533 .56905 m .35896 .51313 L .39033 .51366 L p .707 .577 .707 r
F P
0 g
s
.32347 .63701 m .3188 .60098 L .34521 .59206 L p .707 .577 .707 r
F P
0 g
s
.31573 .69946 m .30968 .68305 L .32758 .6664 L p .707 .577 .707 r
F P
0 g
s
.46473 .62571 m .47079 .64212 L .44629 .64115 L p .707 .577 .707 r
F P
0 g
s
.44629 .64115 m .44024 .62474 L .46473 .62571 L p .707 .577 .707 r
F P
0 g
s
.42196 .5166 m .41833 .57251 L .3867 .56958 L p .707 .577 .707 r
F P
0 g
s
.3867 .56958 m .39033 .51366 L .42196 .5166 L p .707 .577 .707 r
F P
0 g
s
.39033 .51366 m .3867 .56958 L .35533 .56905 L p .707 .577 .707 r
F P
0 g
s
.43722 .5827 m .44189 .61872 L .41214 .61848 L p .707 .577 .707 r
F P
0 g
s
.41214 .61848 m .40747 .58245 L .43722 .5827 L p .707 .577 .707 r
F P
0 g
s
.32758 .6664 m .33363 .68281 L .31573 .69946 L p .707 .577 .707 r
F P
0 g
s
.34521 .59206 m .34989 .62809 L .32347 .63701 L p .707 .577 .707 r
F P
0 g
s
.34989 .62809 m .34521 .59206 L .37577 .58568 L p .707 .577 .707 r
F P
0 g
s
.40747 .58245 m .41214 .61848 L .38044 .6217 L p .707 .577 .707 r
F P
0 g
s
.38044 .6217 m .37577 .58568 L .40747 .58245 L p .707 .577 .707 r
F P
0 g
s
.33363 .68281 m .32758 .6664 L .35218 .65086 L p .707 .577 .707 r
F P
0 g
s
.44024 .62474 m .44629 .64115 L .41746 .64537 L p .707 .577 .707 r
F P
0 g
s
.41746 .64537 m .41141 .62896 L .44024 .62474 L p .707 .577 .707 r
F P
0 g
s
.37577 .58568 m .38044 .6217 L .34989 .62809 L p .707 .577 .707 r
F P
0 g
s
.35218 .65086 m .35823 .66727 L .33363 .68281 L p .707 .577 .707 r
F P
0 g
s
.35823 .66727 m .35218 .65086 L .38107 .63796 L p .707 .577 .707 r
F P
0 g
s
.41141 .62896 m .41746 .64537 L .38712 .65437 L p .707 .577 .707 r
F P
0 g
s
.38712 .65437 m .38107 .63796 L .41141 .62896 L p .707 .577 .707 r
F P
0 g
s
.38107 .63796 m .38712 .65437 L .35823 .66727 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007=oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00Kgoo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001SOol70006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001KOol80003FUH01000FUIJEUYF400000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Egoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo0`001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0035YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol0059oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF000047oo3`00Agoo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
37oo100000=JEP00FUH01eYF00<005YFFUH00UYF2000?goo001BOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF000027oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Uoo`00DWoo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF000017oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Woo001BOol01@00FUIJEUYF00001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00=7oo001BOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
00001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
039oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080031oo`00DGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF00<007ooOol0;Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@
0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0]Ool0055oo`8000=JEP04001JEUYFFUH80005FUH00`00FUIJEP06FUH0
0`00FUH000060006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
0P00;Woo001AOol20003FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4
0002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001A
Ool200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEP@000AJEP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo
0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF4@0000IJEP00000005YF0003
FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUH000050004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF
00<005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00DGoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P0000AJEP00FUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0059oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool005=oo`05001JEUYFFUH00005FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00UYF5`001UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool0
05Aoo`800004FUH005YFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000eYF00<005YFFUH00UYF1`002goo1@001Woo10000UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH0000^Ool005Ioo`D000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUH000020003FUH01000FUIJEUYF2@00
0Woo1@002Goo1@001EYF00L005YFFUIJEP00FUH0000^Ool005Ioo`80009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP8000IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ0000EJEP@00003FUH005YF009JEP03001JEP0002ioo`00
?goo5`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF
00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0002ioo`00>goo100000=JEP00FUH01eYF
00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP00;Woo000fOol50005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0005FUH00`00FUIJEP02FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH400000eYF001oo`0]Ool0039oo`@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH90002FUH4
00000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002ioo`00<7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00IJEPh0009JEP03001JEP0000QJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00001EYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<005YFFUH0
1P0015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00006FUH3
00000eYF001JEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000eYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00D005YFFUIJ
EP0000AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH40007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUHQ0003FUH00`00Oomoo`0]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP8000AJEP05001JEUYFFUH0
0003FUH00`00FUIJEP020007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF10001eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00<00003FUH007oo02ioo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00`001EYF00D005YFFUIJEP0000=JEP@000UJ
EP03001JEUYF009JEP`000=JEP<000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH300000eYF001JEP060003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000`Ool002eoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP<0009JEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH70006FUH00`00FUIJEP02FUH200000eYF0000
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH60005FUH01000FUIJEUYF0`001EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
02moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF001JEP00009JEP04001JEUYFFUH:0008FUH00`00FUH000020007FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002moo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH0
1EYF00<005YF00000P0025YF0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF0000;goo000]Ool00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH20002
FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF0P001EYF
00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YF
000000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH015YF4`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP800003FUH005YF00MJEP03001JEUYF
00MJEP03001JEUYF00EJEP<00006FUH005YFFUH005YF0P001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
;Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH20003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0004FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eo
o`03001JEP00009JEP04001JEUYFFUH60006FUH:0007FUH00`00FUH00003FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEP/000QJEP03001JEUYF
00=JEPL0009JEP03001JEP0002ioo`00;Goo00<005YF00000UYF10000eYF00<005YF00001`0015YF
00<005YFFUH00UYF2P0015YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP00008000MJEP<0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP03FUH01000FUIJEUYF200000=J
EP00FUH00eYF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00Ool0;Goo000]Ool0
0`00FUH00002000015YF001JEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000=JEP00FUH00eYF10001eYF00<005YFFUH00eYF10001UYF10002EYF00H005YFFUH005YF
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF
FUIJEPL000QJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000^Ool002eoo`03001JEP0000=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP02FUH50002FUH40002
FUH00`00FUIJEP06FUH20004FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEP000UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo0`0000=JEP00000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF200015YF00<005YF
FUH00UYF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000UYF0P000UYF0P0000AJEP00FUIJEPh000QJEP03001JEUYF00AJ
EP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH300000eYF
00000003FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P00<goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEUYF00QJEP04001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00H005YF000005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006Ool2000^Ool002ioo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00001UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP04001J
EUYF0006FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=o
o`000000200000=JEP00Ool0;Goo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP<000MJEP03001JEP0000aJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH>0004FUH00`00FUIJEP02FUH900000goo0000
00060003FUH00`00FUIJEP02FUH01000FUIJEP00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP800003FUH005YF00AJEP80009JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00007FUH00`00FUIJ
EP04FUH00`00FUIJEP090003Ool70004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00
;Woo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF20002Goo200000=JEP00FUH00P001UYF00<0
05YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00007FUH00`00FUIJEP04FUH01000FUIJEUYF0P001Goo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00;Woo00@005YFFUH000=JEPH000Ioo`T0
00Yoo`800004FUH000000005FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH00eYF
0P001UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP03FUH01000FUIJEUYF1`001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;Woo00D005YFFUH005YF0080
00Aoo`P000AJEP03001JEUYF009JEPH000Ioo`80009oo`8000=JEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00<000QJEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00008FUH00`00FUIJEP080003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06000]Ool002ioo`03001JEUYF0080009o
o`@000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000=oo`<000=oo`800003FUH0
05YF00=JEP8000=JEP03001JEUYF00=JEP@00003FUH005YF00MJEP8000QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH70003FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000cOol002ioo`03001J
EP0000D000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<00003Ool005YF00<0
009oo`8000AJEP80009JEPL000IJEP03001JEUYF00=JEP8000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol002eoo`H0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP`000AJEP03001JEUYF00IJ
EP03001JEUYF00@000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP/003moo`00;Goo0P0000=JEP00FUH00UYF00<005YFFUH015YF3P0015YF00<005YFFUH01eYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEQ0004=oo`00;Goo10000eYF00<005YF
FUH010003Woo1P0025YF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH0000000H004Yoo`00
;Goo0P0000=JEP00FUH00UYF0`0015YF100047oo0`0015YF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03
001JEP0000X0059oo`00;Goo0`000UYF0P0000=JEP00FUH01EYF00<005YFFUH010003goo0`0000=J
EP00FUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH02EYF00<005YFFUH0
15YF60001UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00P0
0003FUH0000005Ioo`00;Goo00<005YF00000P000eYF00<005YFFUH015YF00<005YFFUH015YF5@00
1EYF3@001UYF00<005YFFUH01eYF20001UYF00<005YFFUH025YF00<005YF000015YF2@001eYF00<0
05YFFUH01EYF00@005YFFUIJEPH000MJEP04001JEUYFFUH2001DOol002eoo`04001JEP000004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJ
EP02000015YF001JEP000eYF00<005YFFUH015YF00<005YFFUH00eYF100000=JEP00FUH02eYF00<0
05YFFUH025YF00<005YF00002eYF00<005YF000010000UYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP8005=oo`00;Goo100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00eYF0P00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YF00002eYF00<005YFFUH015YF10001UYF00D005YFFUIJEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00059oo`00;7oo0P000Woo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YF
00000eYF00<005YFFUH00eYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002eYF
00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF001BOol002aoo`8000=oo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000=JEP03001JEP0000<0009J
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJ
EP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH00007FUH00`00FUIJEP02FUH01000FUIJ
EP00DWoo000/Ool20005Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH20003FUH30003FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000
1eYF00<005YFFUH00UYF00@005YFFUH0059oo`00;7oo0`001Woo0P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF001JEP00009JEP03001JEUYF0080
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP80009JEPH000EJEP03001JEUYF00=JEP04001JEUYF001BOol002aoo`<0
00Qoo`@00003FUH005YF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH01@00FUH005YF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P000eYF00<0
05YF00000`0000=JEP00FUH015YF00@005YFFUH0059oo`00;7oo00@005YFFUH000]oo`<000IJEP03
001JEUYF00D00003FUH005YF00MJEP03001JEUYF00EJEP<00004Ool005YFFUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF0`000eYF00<005YFFUH0
0P00DWoo000/Ool01000FUIJEP003Woo10000UYF00<005YFFUH01@0000=JEP00FUH01eYF00<005YF
FUH00UYF100017oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
009JEP03001JEUYF00EJEP06001JEP00001JEP000UYF00<007ooOol0DGoo000/Ool01@00FUIJEUYF
00004Goo2P0000=JEP00FUH00eYF2@0027oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00Oomoo`1AOol0
02eoo`03001JEUYF008001Ioo`X0019oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001oo`1BOol002eoo`03001J
EP00009JEP80035oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YF000005=oo`00;Woo0P0015YF00<007ooOol0;Woo0P00
0UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF001COol002moo`03001JEUYF00=JEP03001oogoo02aoo`H000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH0001COol0031oo`03001J
EUYF009JEP<002aoo`8000=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00001DOol0035oo`05001JEUYFFUH00002FUH2000YOol00`00FUH00005Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUIJEUYF1@0015YF00<005YFFUH01EYF00<005YFFUH01000EWoo000bOol200000eYF
001JEP03FUH2000UOol300000eYF001oo`06Ool300000eYF001JEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01`00FUH00000FUH005YF014005Yoo`00=7oo
0P001UYF0`0087oo0P000UYF0P002goo10001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF10000UYF00<005YFFUH00UYF0`00IWoo000eOol20006FUH00`00FUH0
0003000JOol20003FUH2000@Ool50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060005FUH00`00FUIJEP05FUH3001SOol003Moo`8000=JEP03001JEUYF00AJEPL0
00moo`@00003FUH005YF009JEP8001Eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0009J
EP04001JEUYFFUH300000eYF001JEP08FUH00`00FUH00003001OOol003Uoo`800003FUH005YF00MJ
EP03001JEUYF009JEPl000EJEP05001JEUYFFUH0000OOolJ0003Ool20005FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP04FUH2001MOol003]oo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF008003moo`<00003FUH005YF00QJEP<000EJEP03001JEUYF00EJEP<0
05]oo`00?Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00A7oo0`00
25YF00<005YFFUH00`0000=JEP00FUH01UYF00@005YFFUIJEP8005Uoo`00@7oo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00eYF0P00BGoo0`0015YF00<005YFFUH015YF0`001UYF00<0
05YFFUH00eYF00<007ooOol0EWoo0013Ool60004FUH00`00FUIJEP06FUH00`00FUH00003001>Ool3
00000eYF001JEP07FUH30004FUH00`00FUIJEP03FUH3001FOol004Uoo`l005Eoo`<000MJEP03001J
EUYF00800003FUH005YF00AJEP04001JEUYF001FOol00;1oo`@0009JEP03001JEUYF00=JEP<000AJ
EP04001JEUYF001FOol00;Aoo`@000IJEP<00004FUH005YFFUH2001FOol00;Qoo`@00003FUH005YF
009JEP80009JEP03001oogoo05Eoo`00_7oo10000UYF1000Egoo0030Ool6001GOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60673 .75076 m .60451 .6955 L .57301 .69515 L p .707 .577 .707 r
F P
0 g
s
.60451 .6955 m .60673 .75076 L .63833 .74825 L p .707 .577 .707 r
F P
0 g
s
.63833 .74825 m .6361 .69299 L .60451 .6955 L p .707 .577 .707 r
F P
0 g
s
.6361 .69299 m .63833 .74825 L .66692 .74312 L p .707 .577 .707 r
F P
0 g
s
.66692 .74312 m .6647 .68787 L .6361 .69299 L p .707 .577 .707 r
F P
0 g
s
.57523 .75041 m .57301 .69515 L .54468 .69198 L p .707 .577 .707 r
F P
0 g
s
.57301 .69515 m .57523 .75041 L .60673 .75076 L p .707 .577 .707 r
F P
0 g
s
.6647 .68787 m .66692 .74312 L .68972 .73589 L p .707 .577 .707 r
F P
0 g
s
.68972 .73589 m .6875 .68063 L .6647 .68787 L p .707 .577 .707 r
F P
0 g
s
.54691 .74724 m .54468 .69198 L .52231 .6863 L p .707 .577 .707 r
F P
0 g
s
.54468 .69198 m .54691 .74724 L .57523 .75041 L p .707 .577 .707 r
F P
0 g
s
.61066 .80619 m .61352 .76888 L .58183 .76576 L p .707 .577 .707 r
F P
0 g
s
.61352 .76888 m .61066 .80619 L .64188 .80695 L p .707 .577 .707 r
F P
0 g
s
.64188 .80695 m .64474 .76964 L .61352 .76888 L p .707 .577 .707 r
F P
0 g
s
.57898 .80307 m .58183 .76576 L .55279 .76059 L p .707 .577 .707 r
F P
0 g
s
.58183 .76576 m .57898 .80307 L .61066 .80619 L p .707 .577 .707 r
F P
0 g
s
.64474 .76964 m .64188 .80695 L .66959 .80528 L p .707 .577 .707 r
F P
0 g
s
.66959 .80528 m .67245 .76797 L .64474 .76964 L p .707 .577 .707 r
F P
0 g
s
.55279 .76059 m .54993 .7979 L .57898 .80307 L p .707 .577 .707 r
F P
0 g
s
.60667 .84323 m .61041 .82464 L .57918 .81806 L p .707 .577 .707 r
F P
0 g
s
.61041 .82464 m .60667 .84323 L .63724 .84798 L p .707 .577 .707 r
F P
0 g
s
.63724 .84798 m .64097 .82939 L .61041 .82464 L p .707 .577 .707 r
F P
0 g
s
.52231 .6863 m .52453 .74155 L .54691 .74724 L p .707 .577 .707 r
F P
0 g
s
.54993 .7979 m .55279 .76059 L .52924 .75387 L p .707 .577 .707 r
F P
0 g
s
.57544 .83665 m .57918 .81806 L .55033 .81029 L p .707 .577 .707 r
F P
0 g
s
.57918 .81806 m .57544 .83665 L .60667 .84323 L p .707 .577 .707 r
F P
0 g
s
.6875 .68063 m .68972 .73589 L .70449 .72725 L p .707 .577 .707 r
F P
0 g
s
.70449 .72725 m .70227 .67199 L .6875 .68063 L p .707 .577 .707 r
F P
0 g
s
.55033 .81029 m .5466 .82888 L .57544 .83665 L p .707 .577 .707 r
F P
0 g
s
.52453 .74155 m .52231 .6863 L .50807 .67865 L p .707 .577 .707 r
F P
0 g
s
.64097 .82939 m .63724 .84798 L .66415 .85043 L p .707 .577 .707 r
F P
0 g
s
.66415 .85043 m .66788 .83185 L .64097 .82939 L p .707 .577 .707 r
F P
0 g
s
.67245 .76797 m .66959 .80528 L .69106 .80135 L p .707 .577 .707 r
F P
0 g
s
.69106 .80135 m .69392 .76404 L .67245 .76797 L p .707 .577 .707 r
F P
0 g
s
.52924 .75387 m .52638 .79118 L .54993 .7979 L p .707 .577 .707 r
F P
0 g
s
.5466 .82888 m .55033 .81029 L .52671 .80209 L p .707 .577 .707 r
F P
0 g
s
.52671 .80209 m .52297 .82068 L .5466 .82888 L p .707 .577 .707 r
F P
0 g
s
.52638 .79118 m .52924 .75387 L .51347 .74627 L p .707 .577 .707 r
F P
0 g
s
.50807 .67865 m .5103 .73391 L .52453 .74155 L p .707 .577 .707 r
F P
0 g
s
.66788 .83185 m .66415 .85043 L .68476 .85035 L p .707 .577 .707 r
F P
0 g
s
.68476 .85035 m .6885 .83176 L .66788 .83185 L p .707 .577 .707 r
F P
0 g
s
.70227 .67199 m .70449 .72725 L .70978 .71805 L p .707 .577 .707 r
F P
0 g
s
.70978 .71805 m .70756 .6628 L .70227 .67199 L p .707 .577 .707 r
F P
0 g
s
.51347 .74627 m .51061 .78358 L .52638 .79118 L p .707 .577 .707 r
F P
0 g
s
.69392 .76404 m .69106 .80135 L .70421 .79553 L p .707 .577 .707 r
F P
0 g
s
.70421 .79553 m .70707 .75822 L .69392 .76404 L p .707 .577 .707 r
F P
0 g
s
.52297 .82068 m .52671 .80209 L .51061 .79426 L p .707 .577 .707 r
F P
0 g
s
.5103 .73391 m .50807 .67865 L .50337 .6698 L p .707 .577 .707 r
F P
0 g
s
.51061 .79426 m .50687 .81285 L .52297 .82068 L p .707 .577 .707 r
F P
0 g
s
.51061 .78358 m .51347 .74627 L .50704 .73852 L p .707 .577 .707 r
F P
0 g
s
.6885 .83176 m .68476 .85035 L .69707 .84773 L p .707 .577 .707 r
F P
0 g
s
.69707 .84773 m .70081 .82914 L .6885 .83176 L p .707 .577 .707 r
F P
0 g
s
.50722 .72812 m .5103 .73391 L p .50769 .70979 L .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .50418 .77583 L .51061 .78358 L p .707 .577 .707 r
F P
0 g
s
.50704 .73852 m .51056 .73139 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50418 .77583 m .50692 .74004 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50692 .74004 m .50704 .73852 L p .5064 .76037 L .707 .577 .707 r
F P
0 g
s
.50337 .6698 m .5056 .72506 L .50722 .72812 L p .707 .577 .707 r
F P
0 g
s
.50769 .70979 m .50337 .6698 L .50722 .72812 L .707 .577 .707 r
F
.50687 .81285 m .51061 .79426 L .50361 .78758 L p F P
0 g
s
.70756 .6628 m .70978 .71805 L .70508 .7092 L p .707 .577 .707 r
F P
0 g
s
.70508 .7092 m .70286 .65394 L .70756 .6628 L p .707 .577 .707 r
F P
0 g
s
.70707 .75822 m .70421 .79553 L .70774 .7884 L p .707 .577 .707 r
F P
0 g
s
.70774 .7884 m .7106 .75109 L .70707 .75822 L p .707 .577 .707 r
F P
0 g
s
.50361 .78758 m .49987 .80617 L .50687 .81285 L p .707 .577 .707 r
F P
0 g
s
.5056 .72506 m .50337 .6698 L .50867 .66061 L p .707 .577 .707 r
F P
0 g
s
.48352 .82167 m .48352 .31978 L .44005 .31653 L p .707 .577 .707 r
F P
0 g
s
.50867 .66061 m .51089 .71586 L .5056 .72506 L p .707 .577 .707 r
F P
0 g
s
.51056 .73139 m .50771 .7687 L .50418 .77583 L p .707 .577 .707 r
F P
0 g
s
.49987 .80617 m .50361 .78758 L .5064 .78269 L p .707 .577 .707 r
F P
0 g
s
.5064 .78269 m .50266 .80127 L .49987 .80617 L p .707 .577 .707 r
F P
0 g
s
.51089 .71586 m .50867 .66061 L .52343 .65197 L p .707 .577 .707 r
F P
0 g
s
.50771 .7687 m .51056 .73139 L .52371 .72557 L p .707 .577 .707 r
F P
0 g
s
.52343 .65197 m .52566 .70722 L .51089 .71586 L p .707 .577 .707 r
F P
0 g
s
.52371 .72557 m .52085 .76288 L .50771 .7687 L p .707 .577 .707 r
F P
0 g
s
.50266 .80127 m .5064 .78269 L .5187 .78007 L p .707 .577 .707 r
F P
0 g
s
.5187 .78007 m .51497 .79866 L .50266 .80127 L p .707 .577 .707 r
F P
0 g
s
.52085 .76288 m .52371 .72557 L .54519 .72164 L p .707 .577 .707 r
F P
0 g
s
.54519 .72164 m .54233 .75894 L .52085 .76288 L p .707 .577 .707 r
F P
0 g
s
.51497 .79866 m .5187 .78007 L .53932 .77998 L p .707 .577 .707 r
F P
0 g
s
.53932 .77998 m .53558 .79857 L .51497 .79866 L p .707 .577 .707 r
F P
0 g
s
.48352 .31978 m .48352 .82167 L .52861 .82115 L p .707 .577 .707 r
F P
0 g
s
.52566 .70722 m .52343 .65197 L .54623 .64473 L p .707 .577 .707 r
F P
0 g
s
.54623 .64473 m .54846 .69999 L .52566 .70722 L p .707 .577 .707 r
F P
0 g
s
.52861 .82115 m .52861 .31927 L .48352 .31978 L p .707 .577 .707 r
F P
0 g
s
.54846 .69999 m .54623 .64473 L .57483 .63961 L p .707 .577 .707 r
F P
0 g
s
.57483 .63961 m .57705 .69486 L .54846 .69999 L p .707 .577 .707 r
F P
0 g
s
.54233 .75894 m .54519 .72164 L .5729 .71997 L p .707 .577 .707 r
F P
0 g
s
.5729 .71997 m .57004 .75728 L .54233 .75894 L p .707 .577 .707 r
F P
0 g
s
.53558 .79857 m .53932 .77998 L .56623 .78243 L p .707 .577 .707 r
F P
0 g
s
.56623 .78243 m .56249 .80102 L .53558 .79857 L p .707 .577 .707 r
F P
0 g
s
.56249 .80102 m .56623 .78243 L .5968 .78718 L p .707 .577 .707 r
F P
0 g
s
.5968 .78718 m .59306 .80577 L .56249 .80102 L p .707 .577 .707 r
F P
0 g
s
.52861 .31927 m .52861 .82115 L .5709 .81692 L p .707 .577 .707 r
F P
0 g
s
.57004 .75728 m .5729 .71997 L .60412 .72073 L p .707 .577 .707 r
F P
0 g
s
.60412 .72073 m .60126 .75804 L .57004 .75728 L p .707 .577 .707 r
F P
0 g
s
.5709 .81692 m .5709 .31504 L .52861 .31927 L p .707 .577 .707 r
F P
0 g
s
.44005 .81842 m .44005 .31653 L .40244 .30984 L p .707 .577 .707 r
F P
0 g
s
.44005 .31653 m .44005 .81842 L .48352 .82167 L p .707 .577 .707 r
F P
0 g
s
.70081 .82914 m .69707 .84773 L .69986 .84284 L p .707 .577 .707 r
F P
0 g
s
.69986 .84284 m .7036 .82425 L .70081 .82914 L p .707 .577 .707 r
F P
0 g
s
.57705 .69486 m .57483 .63961 L .60642 .6371 L p .707 .577 .707 r
F P
0 g
s
.60642 .6371 m .60865 .69235 L .57705 .69486 L p .707 .577 .707 r
F P
0 g
s
.6358 .72385 m .63294 .76116 L .60126 .75804 L p .707 .577 .707 r
F P
0 g
s
.60126 .75804 m .60412 .72073 L .6358 .72385 L p .707 .577 .707 r
F P
0 g
s
.62803 .79377 m .62429 .81235 L .59306 .80577 L p .707 .577 .707 r
F P
0 g
s
.59306 .80577 m .5968 .78718 L .62803 .79377 L p .707 .577 .707 r
F P
0 g
s
.5709 .31504 m .5709 .81692 L .60625 .8094 L p .707 .577 .707 r
F P
0 g
s
.60625 .8094 m .60625 .30751 L .5709 .31504 L p .707 .577 .707 r
F P
0 g
s
.70286 .65394 m .70508 .7092 L .69085 .70156 L p .707 .577 .707 r
F P
0 g
s
.69085 .70156 m .68862 .6463 L .70286 .65394 L p .707 .577 .707 r
F P
0 g
s
.26102 .7104 m .26004 .6543 L .22852 .65358 L p .707 .577 .707 r
F P
0 g
s
.26004 .6543 m .26102 .7104 L .29263 .70878 L p .707 .577 .707 r
F P
0 g
s
.29263 .70878 m .29166 .65268 L .26004 .6543 L p .707 .577 .707 r
F P
0 g
s
.7106 .75109 m .70774 .7884 L .70131 .78065 L p .707 .577 .707 r
F P
0 g
s
.70131 .78065 m .70417 .74334 L .7106 .75109 L p .707 .577 .707 r
F P
0 g
s
.29166 .65268 m .29263 .70878 L .32124 .70499 L p .707 .577 .707 r
F P
0 g
s
.32124 .70499 m .32027 .64889 L .29166 .65268 L p .707 .577 .707 r
F P
0 g
s
.2295 .70968 m .22852 .65358 L .20018 .6506 L p .707 .577 .707 r
F P
0 g
s
.22852 .65358 m .2295 .70968 L .26102 .7104 L p .707 .577 .707 r
F P
0 g
s
.40244 .81173 m .40244 .30984 L .37438 .30035 L p .707 .577 .707 r
F P
0 g
s
.40244 .30984 m .40244 .81173 L .44005 .81842 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63792 .63744 m .64015 .6927 L .60865 .69235 L p .707 .577 .707 r
F P
0 g
s
.60865 .69235 m .60642 .6371 L .63792 .63744 L p .707 .577 .707 r
F P
0 g
s
.62429 .81235 m .62803 .79377 L .65687 .80154 L p .707 .577 .707 r
F P
0 g
s
.60625 .30751 m .60625 .8094 L .63119 .79931 L p .707 .577 .707 r
F P
0 g
s
.63119 .79931 m .63119 .29742 L .60625 .30751 L p .707 .577 .707 r
F P
0 g
s
.32027 .64889 m .32124 .70499 L .34405 .6994 L p .707 .577 .707 r
F P
0 g
s
.34405 .6994 m .34308 .6433 L .32027 .64889 L p .707 .577 .707 r
F P
0 g
s
.20018 .6506 m .20115 .7067 L .2295 .70968 L p .707 .577 .707 r
F P
0 g
s
.7036 .82425 m .69986 .84284 L .69286 .83615 L p .707 .577 .707 r
F P
0 g
s
.69286 .83615 m .6966 .81756 L .7036 .82425 L p .707 .577 .707 r
F P
0 g
s
.20115 .7067 m .20018 .6506 L .17779 .64565 L p .707 .577 .707 r
F P
0 g
s
.26595 .7805 m .26722 .74423 L .23547 .74207 L p .707 .577 .707 r
F P
0 g
s
.26722 .74423 m .26595 .7805 L .29724 .77933 L p .707 .577 .707 r
F P
0 g
s
.29724 .77933 m .29851 .74306 L .26722 .74423 L p .707 .577 .707 r
F P
0 g
s
.2342 .77834 m .23547 .74207 L .20635 .7368 L p .707 .577 .707 r
F P
0 g
s
.23547 .74207 m .2342 .77834 L .26595 .7805 L p .707 .577 .707 r
F P
0 g
s
.68862 .6463 m .69085 .70156 L .66847 .69587 L p .707 .577 .707 r
F P
0 g
s
.66847 .69587 m .66625 .64061 L .68862 .6463 L p .707 .577 .707 r
F P
0 g
s
.29851 .74306 m .29724 .77933 L .325 .77495 L p .707 .577 .707 r
F P
0 g
s
.325 .77495 m .32627 .73868 L .29851 .74306 L p .707 .577 .707 r
F P
0 g
s
.70417 .74334 m .70131 .78065 L .68554 .77305 L p .707 .577 .707 r
F P
0 g
s
.68554 .77305 m .6884 .73574 L .70417 .74334 L p .707 .577 .707 r
F P
0 g
s
.17779 .64565 m .17876 .70175 L .20115 .7067 L p .707 .577 .707 r
F P
0 g
s
.20508 .77307 m .20635 .7368 L .18273 .72892 L p .707 .577 .707 r
F P
0 g
s
.20635 .7368 m .20508 .77307 L .2342 .77834 L p .707 .577 .707 r
F P
0 g
s
.34308 .6433 m .34405 .6994 L .35882 .69255 L p .707 .577 .707 r
F P
0 g
s
.35882 .69255 m .35785 .63645 L .34308 .6433 L p .707 .577 .707 r
F P
0 g
s
.17876 .70175 m .17779 .64565 L .16354 .63922 L p .707 .577 .707 r
F P
0 g
s
.37438 .80224 m .37438 .30035 L .35862 .28901 L p .707 .577 .707 r
F P
0 g
s
.37438 .30035 m .37438 .80224 L .40244 .81173 L p .707 .577 .707 r
F P
0 g
s
.32627 .73868 m .325 .77495 L .34651 .76778 L p .707 .577 .707 r
F P
0 g
s
.34651 .76778 m .34778 .73151 L .32627 .73868 L p .707 .577 .707 r
F P
0 g
s
.26585 .83079 m .26754 .81348 L .23581 .80979 L p .707 .577 .707 r
F P
0 g
s
.26754 .81348 m .26585 .83079 L .29687 .83015 L p .707 .577 .707 r
F P
0 g
s
.29687 .83015 m .29855 .81283 L .26754 .81348 L p .707 .577 .707 r
F P
0 g
s
.66625 .64061 m .66847 .69587 L .64015 .6927 L p .707 .577 .707 r
F P
0 g
s
.64015 .6927 m .63792 .63744 L .66625 .64061 L p .707 .577 .707 r
F P
0 g
s
.6966 .81756 m .69286 .83615 L .67676 .82833 L p .707 .577 .707 r
F P
0 g
s
.67676 .82833 m .6805 .80974 L .6966 .81756 L p .707 .577 .707 r
F P
0 g
s
.23412 .82711 m .23581 .80979 L .20647 .80214 L p .707 .577 .707 r
F P
0 g
s
.23581 .80979 m .23412 .82711 L .26585 .83079 L p .707 .577 .707 r
F P
0 g
s
.18273 .72892 m .18146 .76519 L .20508 .77307 L p .707 .577 .707 r
F P
0 g
s
.66484 .72902 m .66198 .76633 L .63294 .76116 L p .707 .577 .707 r
F P
0 g
s
.63294 .76116 m .6358 .72385 L .66484 .72902 L p .707 .577 .707 r
F P
0 g
s
.63119 .29742 m .63119 .79931 L .6433 .78764 L p .707 .577 .707 r
F P
0 g
s
.6433 .78764 m .6433 .28575 L .63119 .29742 L p .707 .577 .707 r
F P
0 g
s
.16354 .63922 m .16451 .69532 L .17876 .70175 L p .707 .577 .707 r
F P
0 g
s
.29855 .81283 m .29687 .83015 L .32413 .82525 L p .707 .577 .707 r
F P
0 g
s
.32413 .82525 m .32581 .80793 L .29855 .81283 L p .707 .577 .707 r
F P
0 g
s
.18146 .76519 m .18273 .72892 L .16691 .71922 L p .707 .577 .707 r
F P
0 g
s
.6884 .73574 m .68554 .77305 L .66198 .76633 L p .707 .577 .707 r
F P
0 g
s
.66198 .76633 m .66484 .72902 L .6884 .73574 L p .707 .577 .707 r
F P
0 g
s
.20647 .80214 m .20479 .81946 L .23412 .82711 L p .707 .577 .707 r
F P
0 g
s
.20479 .81946 m .20647 .80214 L .18239 .79128 L p .707 .577 .707 r
F P
0 g
s
.34778 .73151 m .34651 .76778 L .35967 .75852 L p .707 .577 .707 r
F P
0 g
s
.35967 .75852 m .36094 .72226 L .34778 .73151 L p .707 .577 .707 r
F P
0 g
s
.35785 .63645 m .35882 .69255 L .36411 .68511 L p .707 .577 .707 r
F P
0 g
s
.36411 .68511 m .36314 .62901 L .35785 .63645 L p .707 .577 .707 r
F P
0 g
s
.18239 .79128 m .18071 .80859 L .20479 .81946 L p .707 .577 .707 r
F P
0 g
s
.16451 .69532 m .16354 .63922 L .15883 .63193 L p .707 .577 .707 r
F P
0 g
s
.16691 .71922 m .16564 .75549 L .18146 .76519 L p .707 .577 .707 r
F P
0 g
s
.32581 .80793 m .32413 .82525 L .34497 .81656 L p .707 .577 .707 r
F P
0 g
s
.34497 .81656 m .34666 .79924 L .32581 .80793 L p .707 .577 .707 r
F P
0 g
s
.6805 .80974 m .67676 .82833 L .65313 .82013 L p .707 .577 .707 r
F P
0 g
s
.65313 .82013 m .65687 .80154 L .6805 .80974 L p .707 .577 .707 r
F P
0 g
s
.18071 .80859 m .18239 .79128 L .16594 .77826 L p .707 .577 .707 r
F P
0 g
s
.16564 .75549 m .16691 .71922 L .16044 .70863 L p .707 .577 .707 r
F P
0 g
s
.15883 .63193 m .1598 .68803 L .16451 .69532 L p .707 .577 .707 r
F P
0 g
s
.35736 .80494 m .35904 .78763 L .34666 .79924 L p .707 .577 .707 r
F P
0 g
s
.3594 .67782 m .35843 .62172 L .36314 .62901 L p .707 .577 .707 r
F P
0 g
s
.36094 .72226 m .35967 .75852 L .36319 .7481 L p .707 .577 .707 r
F P
0 g
s
.36319 .7481 m .36446 .71183 L .36094 .72226 L p .707 .577 .707 r
F P
0 g
s
.36446 .71183 m .36319 .7481 L .35672 .73751 L p .707 .577 .707 r
F P
0 g
s
.35672 .73751 m .35799 .70124 L .36446 .71183 L p .707 .577 .707 r
F P
0 g
s
.35843 .62172 m .3594 .67782 L .34515 .67139 L p .707 .577 .707 r
F P
0 g
s
.34515 .67139 m .34418 .61529 L .35843 .62172 L p .707 .577 .707 r
F P
0 g
s
.35904 .78763 m .35736 .80494 L .36007 .79153 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .36175 .77421 L .35904 .78763 L p .707 .577 .707 r
F P
0 g
s
.36007 .79153 m .35284 .77763 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.36175 .77421 m .3614 .77779 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.3614 .77779 m .36007 .79153 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .3567 .27691 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .35453 .76032 L .36136 .77346 L p .707 .577 .707 r
F P
0 g
s
.36136 .77346 m .36175 .77421 L p .36137 .77436 L .707 .577 .707 r
F P
0 g
s
.35284 .77763 m .36136 .77346 L .36137 .77436 L .707 .577 .707 r
F
.35799 .70124 m .35672 .73751 L .3409 .7278 L p F P
0 g
s
.3409 .7278 m .34217 .69154 L .35799 .70124 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .35862 .7909 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .27691 m .3567 .28823 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.3567 .28823 m .3567 .7788 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .7909 m .35862 .48812 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.35862 .48812 m .35862 .28901 L p .35677 .29544 L .707 .577 .707 r
F P
0 g
s
.36314 .62901 m .36411 .68511 L .3594 .67782 L p .707 .577 .707 r
F P
0 g
s
.35862 .28901 m .35862 .7909 L .37438 .80224 L p .707 .577 .707 r
F P
0 g
s
.16594 .77826 m .16426 .79557 L .18071 .80859 L p .707 .577 .707 r
F P
0 g
s
.34666 .79924 m .34497 .81656 L .35736 .80494 L p .707 .577 .707 r
F P
0 g
s
.6433 .28575 m .6433 .78764 L .64138 .77554 L p .707 .577 .707 r
F P
0 g
s
.64138 .77554 m .64138 .27365 L .6433 .28575 L p .707 .577 .707 r
F P
0 g
s
.16044 .70863 m .15917 .7449 L .16564 .75549 L p .707 .577 .707 r
F P
0 g
s
.65687 .80154 m .65313 .82013 L .62429 .81235 L p .707 .577 .707 r
F P
0 g
s
.1598 .68803 m .15883 .63193 L .16412 .62449 L p .707 .577 .707 r
F P
0 g
s
.16426 .79557 m .16594 .77826 L .15871 .76436 L p .707 .577 .707 r
F P
0 g
s
.15871 .76436 m .15703 .78168 L .16426 .79557 L p .707 .577 .707 r
F P
0 g
s
.15917 .7449 m .16044 .70863 L .16396 .6982 L p .707 .577 .707 r
F P
0 g
s
.16412 .62449 m .16509 .68059 L .1598 .68803 L p .707 .577 .707 r
F P
0 g
s
.16396 .6982 m .16269 .73447 L .15917 .7449 L p .707 .577 .707 r
F P
0 g
s
.3567 .7788 m .3567 .27691 L .3688 .26524 L p .707 .577 .707 r
F P
0 g
s
.15703 .78168 m .15871 .76436 L .16143 .75095 L p .707 .577 .707 r
F P
0 g
s
.16509 .68059 m .16412 .62449 L .17889 .61764 L p .707 .577 .707 r
F P
0 g
s
.16143 .75095 m .15974 .76826 L .15703 .78168 L p .707 .577 .707 r
F P
0 g
s
.64138 .27365 m .64138 .77554 L .62562 .76419 L p .707 .577 .707 r
F P
0 g
s
.62562 .76419 m .62562 .2623 L .64138 .27365 L p .707 .577 .707 r
F P
0 g
s
.16269 .73447 m .16396 .6982 L .17712 .68895 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17889 .61764 m .17986 .67374 L .16509 .68059 L p .707 .577 .707 r
F P
0 g
s
.17712 .68895 m .17585 .72522 L .16269 .73447 L p .707 .577 .707 r
F P
0 g
s
.34418 .61529 m .34515 .67139 L .32276 .66644 L p .707 .577 .707 r
F P
0 g
s
.32276 .66644 m .32178 .61034 L .34418 .61529 L p .707 .577 .707 r
F P
0 g
s
.15974 .76826 m .16143 .75095 L .17381 .73933 L p .707 .577 .707 r
F P
0 g
s
.17986 .67374 m .17889 .61764 L .20169 .61205 L p .707 .577 .707 r
F P
0 g
s
.17381 .73933 m .17213 .75664 L .15974 .76826 L p .707 .577 .707 r
F P
0 g
s
.3688 .76713 m .3688 .26524 L .39375 .25515 L p .707 .577 .707 r
F P
0 g
s
.3688 .26524 m .3688 .76713 L .3567 .7788 L p .707 .577 .707 r
F P
0 g
s
.17585 .72522 m .17712 .68895 L .19863 .68178 L p .707 .577 .707 r
F P
0 g
s
.20169 .61205 m .20267 .66815 L .17986 .67374 L p .707 .577 .707 r
F P
0 g
s
.35453 .76032 m .35284 .77763 L .33639 .76461 L p .707 .577 .707 r
F P
0 g
s
.33639 .76461 m .33807 .7473 L .35453 .76032 L p .707 .577 .707 r
F P
0 g
s
.32178 .61034 m .32276 .66644 L .29441 .66346 L p .707 .577 .707 r
F P
0 g
s
.29441 .66346 m .29344 .60736 L .32178 .61034 L p .707 .577 .707 r
F P
0 g
s
.34217 .69154 m .3409 .7278 L .31728 .71993 L p .707 .577 .707 r
F P
0 g
s
.31728 .71993 m .31855 .68366 L .34217 .69154 L p .707 .577 .707 r
F P
0 g
s
.62562 .2623 m .62562 .76419 L .59756 .75471 L p .707 .577 .707 r
F P
0 g
s
.59756 .75471 m .59756 .25282 L .62562 .2623 L p .707 .577 .707 r
F P
0 g
s
.20267 .66815 m .20169 .61205 L .23031 .60826 L p .707 .577 .707 r
F P
0 g
s
.19863 .68178 m .19736 .71805 L .17585 .72522 L p .707 .577 .707 r
F P
0 g
s
.17213 .75664 m .17381 .73933 L .19465 .73064 L p .707 .577 .707 r
F P
0 g
s
.19736 .71805 m .19863 .68178 L .22639 .6774 L p .707 .577 .707 r
F P
0 g
s
.29344 .60736 m .29441 .66346 L .26289 .66274 L p .707 .577 .707 r
F P
0 g
s
.26289 .66274 m .26192 .60664 L .29344 .60736 L p .707 .577 .707 r
F P
0 g
s
.23031 .60826 m .23128 .66436 L .20267 .66815 L p .707 .577 .707 r
F P
0 g
s
.19465 .73064 m .19297 .74796 L .17213 .75664 L p .707 .577 .707 r
F P
0 g
s
.23128 .66436 m .23031 .60826 L .26192 .60664 L p .707 .577 .707 r
F P
0 g
s
.26192 .60664 m .26289 .66274 L .23128 .66436 L p .707 .577 .707 r
F P
0 g
s
.31855 .68366 m .31728 .71993 L .28816 .71465 L p .707 .577 .707 r
F P
0 g
s
.28816 .71465 m .28943 .67839 L .31855 .68366 L p .707 .577 .707 r
F P
0 g
s
.33807 .7473 m .33639 .76461 L .31231 .75375 L p .707 .577 .707 r
F P
0 g
s
.31231 .75375 m .314 .73643 L .33807 .7473 L p .707 .577 .707 r
F P
0 g
s
.73711 .65978 m .73808 .6048 L .70656 .60269 L p .707 .577 .707 r
F P
0 g
s
.73808 .6048 m .73711 .65978 L .76872 .65886 L p .707 .577 .707 r
F P
0 g
s
.76872 .65886 m .76969 .60388 L .73808 .6048 L p .707 .577 .707 r
F P
0 g
s
.22639 .6774 m .22512 .71367 L .19736 .71805 L p .707 .577 .707 r
F P
0 g
s
.39375 .25515 m .39375 .75704 L .3688 .76713 L p .707 .577 .707 r
F P
0 g
s
.39375 .75704 m .39375 .25515 L .4291 .24762 L p .707 .577 .707 r
F P
0 g
s
.22512 .71367 m .22639 .6774 L .25768 .67623 L p .707 .577 .707 r
F P
0 g
s
.19297 .74796 m .19465 .73064 L .22192 .72574 L p .707 .577 .707 r
F P
0 g
s
.76969 .60388 m .76872 .65886 L .79733 .655 L p .707 .577 .707 r
F P
0 g
s
.79733 .655 m .7983 .60002 L .76969 .60388 L p .707 .577 .707 r
F P
0 g
s
.70558 .65767 m .70656 .60269 L .67821 .59776 L p .707 .577 .707 r
F P
0 g
s
.70656 .60269 m .70558 .65767 L .73711 .65978 L p .707 .577 .707 r
F P
0 g
s
.28943 .67839 m .28816 .71465 L .25641 .7125 L p .707 .577 .707 r
F P
0 g
s
.25641 .7125 m .25768 .67623 L .28943 .67839 L p .707 .577 .707 r
F P
0 g
s
.59756 .25282 m .59756 .75471 L .55995 .74802 L p .707 .577 .707 r
F P
0 g
s
.55995 .74802 m .55995 .24613 L .59756 .25282 L p .707 .577 .707 r
F P
0 g
s
.25768 .67623 m .25641 .7125 L .22512 .71367 L p .707 .577 .707 r
F P
0 g
s
.22192 .72574 m .22023 .74305 L .19297 .74796 L p .707 .577 .707 r
F P
0 g
s
.314 .73643 m .31231 .75375 L .28298 .7461 L p .707 .577 .707 r
F P
0 g
s
.28298 .7461 m .28466 .72878 L .314 .73643 L p .707 .577 .707 r
F P
0 g
s
.7983 .60002 m .79733 .655 L .82014 .64857 L p .707 .577 .707 r
F P
0 g
s
.82014 .64857 m .82111 .5936 L .7983 .60002 L p .707 .577 .707 r
F P
0 g
s
.67724 .65273 m .67821 .59776 L .65582 .59048 L p .707 .577 .707 r
F P
0 g
s
.67821 .59776 m .67724 .65273 L .70558 .65767 L p .707 .577 .707 r
F P
0 g
s
.22023 .74305 m .22192 .72574 L .25293 .7251 L p .707 .577 .707 r
F P
0 g
s
.74359 .71019 m .74232 .67256 L .71056 .67287 L p .707 .577 .707 r
F P
0 g
s
.74232 .67256 m .74359 .71019 L .77488 .70786 L p .707 .577 .707 r
F P
0 g
s
.77488 .70786 m .77361 .67023 L .74232 .67256 L p .707 .577 .707 r
F P
0 g
s
.28466 .72878 m .28298 .7461 L .25125 .74241 L p .707 .577 .707 r
F P
0 g
s
.25125 .74241 m .25293 .7251 L .28466 .72878 L p .707 .577 .707 r
F P
0 g
s
.71184 .71051 m .71056 .67287 L .68145 .67113 L p .707 .577 .707 r
F P
0 g
s
.71056 .67287 m .71184 .71051 L .74359 .71019 L p .707 .577 .707 r
F P
0 g
s
.25293 .7251 m .25125 .74241 L .22023 .74305 L p .707 .577 .707 r
F P
0 g
s
.4291 .74951 m .4291 .24762 L .47139 .24339 L p .707 .577 .707 r
F P
0 g
s
.4291 .24762 m .4291 .74951 L .39375 .75704 L p .707 .577 .707 r
F P
0 g
s
.77361 .67023 m .77488 .70786 L .80264 .70374 L p .707 .577 .707 r
F P
0 g
s
.80264 .70374 m .80137 .6661 L .77361 .67023 L p .707 .577 .707 r
F P
0 g
s
.74875 .74253 m .74707 .72347 L .71534 .72597 L p .707 .577 .707 r
F P
0 g
s
.74707 .72347 m .74875 .74253 L .77976 .73909 L p .707 .577 .707 r
F P
0 g
s
.77976 .73909 m .77808 .72002 L .74707 .72347 L p .707 .577 .707 r
F P
0 g
s
.55995 .24613 m .55995 .74802 L .51648 .74477 L p .707 .577 .707 r
F P
0 g
s
.51648 .74477 m .51648 .24288 L .55995 .24613 L p .707 .577 .707 r
F P
0 g
s
.68145 .67113 m .68272 .70876 L .71184 .71051 L p .707 .577 .707 r
F P
0 g
s
.71534 .72597 m .71702 .74503 L .74875 .74253 L p .707 .577 .707 r
F P
0 g
s
.71702 .74503 m .71534 .72597 L .686 .72728 L p .707 .577 .707 r
F P
0 g
s
.65582 .59048 m .65485 .64545 L .67724 .65273 L p .707 .577 .707 r
F P
0 g
s
.686 .72728 m .68768 .74634 L .71702 .74503 L p .707 .577 .707 r
F P
0 g
s
.68272 .70876 m .68145 .67113 L .65783 .66751 L p .707 .577 .707 r
F P
0 g
s
.77808 .72002 m .77976 .73909 L .80703 .73504 L p .707 .577 .707 r
F P
0 g
s
.80703 .73504 m .80534 .71597 L .77808 .72002 L p .707 .577 .707 r
F P
0 g
s
.82111 .5936 m .82014 .64857 L .83491 .64021 L p .707 .577 .707 r
F P
0 g
s
.83491 .64021 m .83588 .58524 L .82111 .5936 L p .707 .577 .707 r
F P
0 g
s
.65485 .64545 m .65582 .59048 L .64157 .58157 L p .707 .577 .707 r
F P
0 g
s
.47139 .74528 m .47139 .24339 L .51648 .24288 L p .707 .577 .707 r
F P
0 g
s
.47139 .24339 m .47139 .74528 L .4291 .74951 L p .707 .577 .707 r
F P
0 g
s
.80137 .6661 m .80264 .70374 L .82415 .69823 L p .707 .577 .707 r
F P
0 g
s
.82415 .69823 m .82288 .66059 L .80137 .6661 L p .707 .577 .707 r
F P
0 g
s
.51648 .24288 m .51648 .74477 L .47139 .74528 L p .707 .577 .707 r
F P
0 g
s
.65783 .66751 m .6591 .70514 L .68272 .70876 L p .707 .577 .707 r
F P
0 g
s
.68768 .74634 m .686 .72728 L .66193 .72727 L p .707 .577 .707 r
F P
0 g
s
.66193 .72727 m .66361 .74633 L .68768 .74634 L p .707 .577 .707 r
F P
0 g
s
.80534 .71597 m .80703 .73504 L .82787 .73077 L p .707 .577 .707 r
F P
0 g
s
.82787 .73077 m .82619 .71171 L .80534 .71597 L p .707 .577 .707 r
F P
0 g
s
.64157 .58157 m .6406 .63655 L .65485 .64545 L p .707 .577 .707 r
F P
0 g
s
.6591 .70514 m .65783 .66751 L .64201 .66236 L p .707 .577 .707 r
F P
0 g
s
.82288 .66059 m .82415 .69823 L .83731 .69187 L p .707 .577 .707 r
F P
0 g
s
.83731 .69187 m .83604 .65423 L .82288 .66059 L p .707 .577 .707 r
F P
0 g
s
.83588 .58524 m .83491 .64021 L .8402 .63074 L p .707 .577 .707 r
F P
0 g
s
.8402 .63074 m .84117 .57576 L .83588 .58524 L p .707 .577 .707 r
F P
0 g
s
.6406 .63655 m .64157 .58157 L .63686 .57191 L p .707 .577 .707 r
F P
0 g
s
.64201 .66236 m .64328 .7 L .6591 .70514 L p .707 .577 .707 r
F P
0 g
s
.66361 .74633 m .66193 .72727 L .64547 .72594 L p .707 .577 .707 r
F P
0 g
s
.64547 .72594 m .64715 .745 L .66361 .74633 L p .707 .577 .707 r
F P
0 g
s
.82619 .71171 m .82787 .73077 L .84026 .72672 L p .707 .577 .707 r
F P
0 g
s
.84026 .72672 m .83857 .70766 L .82619 .71171 L p .707 .577 .707 r
F P
0 g
s
.63686 .57191 m .63589 .62689 L .6406 .63655 L p .707 .577 .707 r
F P
0 g
s
.64328 .7 m .64201 .66236 L .63554 .65619 L p .707 .577 .707 r
F P
0 g
s
.83604 .65423 m .83731 .69187 L .84083 .68528 L p .707 .577 .707 r
F P
0 g
s
.84083 .68528 m .83955 .64764 L .83604 .65423 L p .707 .577 .707 r
F P
0 g
s
.63554 .65619 m .63681 .69383 L .64328 .7 L p .707 .577 .707 r
F P
0 g
s
.64715 .745 m .64547 .72594 L .63825 .72343 L p .707 .577 .707 r
F P
0 g
s
.84117 .57576 m .8402 .63074 L .83549 .62107 L p .707 .577 .707 r
F P
0 g
s
.83549 .62107 m .83646 .5661 L .84117 .57576 L p .707 .577 .707 r
F P
0 g
s
.63589 .62689 m .63686 .57191 L .64215 .56244 L p .707 .577 .707 r
F P
0 g
s
.63825 .72343 m .63993 .74249 L .64715 .745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83857 .70766 m .84026 .72672 L .84297 .72327 L p .707 .577 .707 r
F P
0 g
s
.84297 .72327 m .84128 .7042 L .83857 .70766 L p .707 .577 .707 r
F P
0 g
s
.64215 .56244 m .64118 .61741 L .63589 .62689 L p .707 .577 .707 r
F P
0 g
s
.63681 .69383 m .63554 .65619 L .63906 .6496 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63906 .6496 m .64033 .68724 L .63681 .69383 L p .707 .577 .707 r
F P
0 g
s
.83955 .64764 m .84083 .68528 L .83436 .67911 L p .707 .577 .707 r
F P
0 g
s
.83436 .67911 m .83309 .64147 L .83955 .64764 L p .707 .577 .707 r
F P
0 g
s
.39135 .61944 m .39357 .56363 L .36207 .56113 L p .707 .577 .707 r
F P
0 g
s
.39357 .56363 m .39135 .61944 L .42294 .61944 L p .707 .577 .707 r
F P
0 g
s
.42294 .61944 m .42517 .56363 L .39357 .56363 L p .707 .577 .707 r
F P
0 g
s
.83646 .5661 m .83549 .62107 L .82124 .61217 L p .707 .577 .707 r
F P
0 g
s
.82124 .61217 m .82221 .55719 L .83646 .5661 L p .707 .577 .707 r
F P
0 g
s
.63993 .74249 m .63825 .72343 L .64096 .71998 L p .707 .577 .707 r
F P
0 g
s
.64118 .61741 m .64215 .56244 L .65692 .55408 L p .707 .577 .707 r
F P
0 g
s
.64096 .71998 m .64264 .73904 L .63993 .74249 L p .707 .577 .707 r
F P
0 g
s
.35985 .61693 m .36207 .56113 L .33375 .55636 L p .707 .577 .707 r
F P
0 g
s
.36207 .56113 m .35985 .61693 L .39135 .61944 L p .707 .577 .707 r
F P
0 g
s
.42517 .56363 m .42294 .61944 L .45154 .61693 L p .707 .577 .707 r
F P
0 g
s
.45154 .61693 m .45377 .56112 L .42517 .56363 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84128 .7042 m .84297 .72327 L .83574 .72075 L p .707 .577 .707 r
F P
0 g
s
.83574 .72075 m .83406 .70169 L .84128 .7042 L p .707 .577 .707 r
F P
0 g
s
.65692 .55408 m .65595 .60905 L .64118 .61741 L p .707 .577 .707 r
F P
0 g
s
.33152 .61216 m .33375 .55636 L .31137 .54979 L p .707 .577 .707 r
F P
0 g
s
.33375 .55636 m .33152 .61216 L .35985 .61693 L p .707 .577 .707 r
F P
0 g
s
.45377 .56112 m .45154 .61693 L .47434 .61216 L p .707 .577 .707 r
F P
0 g
s
.47434 .61216 m .47656 .55635 L .45377 .56112 L p .707 .577 .707 r
F P
0 g
s
.39874 .68458 m .39588 .64803 L .3642 .64921 L p .707 .577 .707 r
F P
0 g
s
.39588 .64803 m .39874 .68458 L .42996 .6804 L p .707 .577 .707 r
F P
0 g
s
.42996 .6804 m .4271 .64386 L .39588 .64803 L p .707 .577 .707 r
F P
0 g
s
.64033 .68724 m .63906 .6496 L .65222 .64324 L p .707 .577 .707 r
F P
0 g
s
.36706 .68576 m .3642 .64921 L .33516 .64727 L p .707 .577 .707 r
F P
0 g
s
.3642 .64921 m .36706 .68576 L .39874 .68458 L p .707 .577 .707 r
F P
0 g
s
.82221 .55719 m .82124 .61217 L .79885 .60489 L p .707 .577 .707 r
F P
0 g
s
.79885 .60489 m .79982 .54992 L .82221 .55719 L p .707 .577 .707 r
F P
0 g
s
.4271 .64386 m .42996 .6804 L .45767 .67363 L p .707 .577 .707 r
F P
0 g
s
.45767 .67363 m .45481 .63709 L .4271 .64386 L p .707 .577 .707 r
F P
0 g
s
.65595 .60905 m .65692 .55408 L .67973 .54765 L p .707 .577 .707 r
F P
0 g
s
.83309 .64147 m .83436 .67911 L .81854 .67396 L p .707 .577 .707 r
F P
0 g
s
.81854 .67396 m .81727 .63632 L .83309 .64147 L p .707 .577 .707 r
F P
0 g
s
.65222 .64324 m .65349 .68088 L .64033 .68724 L p .707 .577 .707 r
F P
0 g
s
.64264 .73904 m .64096 .71998 L .65334 .71592 L p .707 .577 .707 r
F P
0 g
s
.31137 .54979 m .30915 .6056 L .33152 .61216 L p .707 .577 .707 r
F P
0 g
s
.65334 .71592 m .65503 .73499 L .64264 .73904 L p .707 .577 .707 r
F P
0 g
s
.33516 .64727 m .33801 .68381 L .36706 .68576 L p .707 .577 .707 r
F P
0 g
s
.33801 .68381 m .33516 .64727 L .3116 .6424 L p .707 .577 .707 r
F P
0 g
s
.30915 .6056 m .31137 .54979 L .29714 .54207 L p .707 .577 .707 r
F P
0 g
s
.47656 .55635 m .47434 .61216 L .48911 .60559 L p .707 .577 .707 r
F P
0 g
s
.48911 .60559 m .49133 .54979 L .47656 .55635 L p .707 .577 .707 r
F P
0 g
s
.45481 .63709 m .45767 .67363 L .47915 .66493 L p .707 .577 .707 r
F P
0 g
s
.47915 .66493 m .47629 .62838 L .45481 .63709 L p .707 .577 .707 r
F P
0 g
s
.40694 .73065 m .4032 .71307 L .37197 .7178 L p .707 .577 .707 r
F P
0 g
s
.4032 .71307 m .40694 .73065 L .43751 .72241 L p .707 .577 .707 r
F P
0 g
s
.43751 .72241 m .43377 .70484 L .4032 .71307 L p .707 .577 .707 r
F P
0 g
s
.83406 .70169 m .83574 .72075 L .81929 .71943 L p .707 .577 .707 r
F P
0 g
s
.81929 .71943 m .8176 .70037 L .83406 .70169 L p .707 .577 .707 r
F P
0 g
s
.67973 .54765 m .67876 .60263 L .65595 .60905 L p .707 .577 .707 r
F P
0 g
s
.43377 .70484 m .43751 .72241 L .46441 .71148 L p .707 .577 .707 r
F P
0 g
s
.46441 .71148 m .46068 .69391 L .43377 .70484 L p .707 .577 .707 r
F P
0 g
s
.37571 .73538 m .37197 .7178 L .34313 .71857 L p .707 .577 .707 r
F P
0 g
s
.37197 .7178 m .37571 .73538 L .40694 .73065 L p .707 .577 .707 r
F P
0 g
s
.79982 .54992 m .79885 .60489 L .7705 .59996 L p .707 .577 .707 r
F P
0 g
s
.7705 .59996 m .77148 .54498 L .79982 .54992 L p .707 .577 .707 r
F P
0 g
s
.67876 .60263 m .67973 .54765 L .70834 .54379 L p .707 .577 .707 r
F P
0 g
s
.65349 .68088 m .65222 .64324 L .67373 .63773 L p .707 .577 .707 r
F P
0 g
s
.3116 .6424 m .31446 .67894 L .33801 .68381 L p .707 .577 .707 r
F P
0 g
s
.34313 .71857 m .34686 .73615 L .37571 .73538 L p .707 .577 .707 r
F P
0 g
s
.29714 .54207 m .29491 .59788 L .30915 .6056 L p .707 .577 .707 r
F P
0 g
s
.81727 .63632 m .81854 .67396 L .79492 .67034 L p .707 .577 .707 r
F P
0 g
s
.79492 .67034 m .79365 .6327 L .81727 .63632 L p .707 .577 .707 r
F P
0 g
s
.67373 .63773 m .675 .67536 L .65349 .68088 L p .707 .577 .707 r
F P
0 g
s
.31446 .67894 m .3116 .6424 L .29583 .63508 L p .707 .577 .707 r
F P
0 g
s
.46068 .69391 m .46441 .71148 L .48503 .69893 L p .707 .577 .707 r
F P
0 g
s
.48503 .69893 m .48129 .68135 L .46068 .69391 L p .707 .577 .707 r
F P
0 g
s
.65503 .73499 m .65334 .71592 L .67419 .71166 L p .707 .577 .707 r
F P
0 g
s
.34686 .73615 m .34313 .71857 L .3195 .7153 L p .707 .577 .707 r
F P
0 g
s
.77148 .54498 m .7705 .59996 L .73898 .59784 L p .707 .577 .707 r
F P
0 g
s
.73898 .59784 m .73995 .54287 L .77148 .54498 L p .707 .577 .707 r
F P
0 g
s
.70737 .59877 m .70834 .54379 L .73995 .54287 L p .707 .577 .707 r
F P
0 g
s
.70834 .54379 m .70737 .59877 L .67876 .60263 L p .707 .577 .707 r
F P
0 g
s
.67419 .71166 m .67587 .73072 L .65503 .73499 L p .707 .577 .707 r
F P
0 g
s
.47629 .62838 m .47915 .66493 L .49229 .65515 L p .707 .577 .707 r
F P
0 g
s
.49229 .65515 m .48943 .61861 L .47629 .62838 L p .707 .577 .707 r
F P
0 g
s
.73995 .54287 m .73898 .59784 L .70737 .59877 L p .707 .577 .707 r
F P
0 g
s
.29491 .59788 m .29714 .54207 L .29244 .53396 L p .707 .577 .707 r
F P
0 g
s
.3195 .7153 m .32324 .73287 L .34686 .73615 L p .707 .577 .707 r
F P
0 g
s
.49133 .54979 m .48911 .60559 L .4944 .59788 L p .707 .577 .707 r
F P
0 g
s
.4944 .59788 m .49663 .54207 L .49133 .54979 L p .707 .577 .707 r
F P
0 g
s
.8176 .70037 m .81929 .71943 L .79521 .71942 L p .707 .577 .707 r
F P
0 g
s
.79521 .71942 m .79353 .70036 L .8176 .70037 L p .707 .577 .707 r
F P
0 g
s
.29583 .63508 m .29869 .67162 L .31446 .67894 L p .707 .577 .707 r
F P
0 g
s
.675 .67536 m .67373 .63773 L .70149 .6336 L p .707 .577 .707 r
F P
0 g
s
.79365 .6327 m .79492 .67034 L .7658 .6686 L p .707 .577 .707 r
F P
0 g
s
.7658 .6686 m .76453 .63096 L .79365 .6327 L p .707 .577 .707 r
F P
0 g
s
.48129 .68135 m .48503 .69893 L .49734 .68598 L p .707 .577 .707 r
F P
0 g
s
.49734 .68598 m .4936 .6684 L .48129 .68135 L p .707 .577 .707 r
F P
0 g
s
.70149 .6336 m .70276 .67124 L .675 .67536 L p .707 .577 .707 r
F P
0 g
s
.29244 .53396 m .29021 .58977 L .29491 .59788 L p .707 .577 .707 r
F P
0 g
s
.32324 .73287 m .3195 .7153 L .3034 .7083 L p .707 .577 .707 r
F P
0 g
s
.67587 .73072 m .67419 .71166 L .70145 .70761 L p .707 .577 .707 r
F P
0 g
s
.29869 .67162 m .29583 .63508 L .2894 .62602 L p .707 .577 .707 r
F P
0 g
s
.70145 .70761 m .70313 .72667 L .67587 .73072 L p .707 .577 .707 r
F P
0 g
s
.70276 .67124 m .70149 .6336 L .73278 .63127 L p .707 .577 .707 r
F P
0 g
s
.3034 .7083 m .30714 .72588 L .32324 .73287 L p .707 .577 .707 r
F P
0 g
s
.48943 .61861 m .49229 .65515 L .49582 .64525 L p .707 .577 .707 r
F P
0 g
s
.49582 .64525 m .49296 .6087 L .48943 .61861 L p .707 .577 .707 r
F P
0 g
s
.76453 .63096 m .7658 .6686 L .73405 .66891 L p .707 .577 .707 r
F P
0 g
s
.73405 .66891 m .73278 .63127 L .76453 .63096 L p .707 .577 .707 r
F P
0 g
s
.79353 .70036 m .79521 .71942 L .76588 .72073 L p .707 .577 .707 r
F P
0 g
s
.76588 .72073 m .76419 .70167 L .79353 .70036 L p .707 .577 .707 r
F P
0 g
s
.73278 .63127 m .73405 .66891 L .70276 .67124 L p .707 .577 .707 r
F P
0 g
s
.29021 .58977 m .29244 .53396 L .29773 .52624 L p .707 .577 .707 r
F P
0 g
s
.2894 .62602 m .29226 .66257 L .29869 .67162 L p .707 .577 .707 r
F P
0 g
s
.49663 .54207 m .4944 .59788 L .4897 .58976 L p .707 .577 .707 r
F P
0 g
s
.4897 .58976 m .49192 .53395 L .49663 .54207 L p .707 .577 .707 r
F P
0 g
s
.70313 .72667 m .70145 .70761 L .73246 .70417 L p .707 .577 .707 r
F P
0 g
s
.73246 .70417 m .73415 .72323 L .70313 .72667 L p .707 .577 .707 r
F P
0 g
s
.76419 .70167 m .76588 .72073 L .73415 .72323 L p .707 .577 .707 r
F P
0 g
s
.73415 .72323 m .73246 .70417 L .76419 .70167 L p .707 .577 .707 r
F P
0 g
s
.4936 .6684 m .49734 .68598 L .50013 .67389 L p .707 .577 .707 r
F P
0 g
s
.50013 .67389 m .49639 .65632 L .4936 .6684 L p .707 .577 .707 r
F P
0 g
s
.30714 .72588 m .3034 .7083 L .2964 .69828 L p .707 .577 .707 r
F P
0 g
s
.29773 .52624 m .29551 .58205 L .29021 .58977 L p .707 .577 .707 r
F P
0 g
s
.2964 .69828 m .30014 .71585 L .30714 .72588 L p .707 .577 .707 r
F P
0 g
s
.29226 .66257 m .2894 .62602 L .29293 .61612 L p .707 .577 .707 r
F P
0 g
s
.49296 .6087 m .49582 .64525 L .48939 .6362 L p .707 .577 .707 r
F P
0 g
s
.48939 .6362 m .48653 .59965 L .49296 .6087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29293 .61612 m .29579 .65267 L .29226 .66257 L p .707 .577 .707 r
F P
0 g
s
.29551 .58205 m .29773 .52624 L .3125 .51968 L p .707 .577 .707 r
F P
0 g
s
.49192 .53395 m .4897 .58976 L .47546 .58204 L p .707 .577 .707 r
F P
0 g
s
.47546 .58204 m .47769 .52624 L .49192 .53395 L p .707 .577 .707 r
F P
0 g
s
.49639 .65632 m .50013 .67389 L .49313 .66387 L p .707 .577 .707 r
F P
0 g
s
.49313 .66387 m .48939 .64629 L .49639 .65632 L p .707 .577 .707 r
F P
0 g
s
.30014 .71585 m .2964 .69828 L .29919 .6862 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3125 .51968 m .31027 .57548 L .29551 .58205 L p .707 .577 .707 r
F P
0 g
s
.29919 .6862 m .30293 .70377 L .30014 .71585 L p .707 .577 .707 r
F P
0 g
s
.29579 .65267 m .29293 .61612 L .30607 .60634 L p .707 .577 .707 r
F P
0 g
s
.48653 .59965 m .48939 .6362 L .47362 .62888 L p .707 .577 .707 r
F P
0 g
s
.47362 .62888 m .47076 .59233 L .48653 .59965 L p .707 .577 .707 r
F P
0 g
s
.31027 .57548 m .3125 .51968 L .3353 .51491 L p .707 .577 .707 r
F P
0 g
s
.47769 .52624 m .47546 .58204 L .45309 .57548 L p .707 .577 .707 r
F P
0 g
s
.45309 .57548 m .45532 .51967 L .47769 .52624 L p .707 .577 .707 r
F P
0 g
s
.30607 .60634 m .30893 .64289 L .29579 .65267 L p .707 .577 .707 r
F P
0 g
s
.48939 .64629 m .49313 .66387 L .47703 .65688 L p .707 .577 .707 r
F P
0 g
s
.47703 .65688 m .47329 .6393 L .48939 .64629 L p .707 .577 .707 r
F P
0 g
s
.30293 .70377 m .29919 .6862 L .3115 .67324 L p .707 .577 .707 r
F P
0 g
s
.3353 .51491 m .33307 .57071 L .31027 .57548 L p .707 .577 .707 r
F P
0 g
s
.30893 .64289 m .30607 .60634 L .32755 .59764 L p .707 .577 .707 r
F P
0 g
s
.3115 .67324 m .31524 .69082 L .30293 .70377 L p .707 .577 .707 r
F P
0 g
s
.47076 .59233 m .47362 .62888 L .45006 .62401 L p .707 .577 .707 r
F P
0 g
s
.45006 .62401 m .4472 .58746 L .47076 .59233 L p .707 .577 .707 r
F P
0 g
s
.33307 .57071 m .3353 .51491 L .36389 .5124 L p .707 .577 .707 r
F P
0 g
s
.45532 .51967 m .45309 .57548 L .42477 .57071 L p .707 .577 .707 r
F P
0 g
s
.42477 .57071 m .42699 .5149 L .45532 .51967 L p .707 .577 .707 r
F P
0 g
s
.32755 .59764 m .33041 .63419 L .30893 .64289 L p .707 .577 .707 r
F P
0 g
s
.36167 .5682 m .36389 .5124 L .39549 .5124 L p .707 .577 .707 r
F P
0 g
s
.36389 .5124 m .36167 .5682 L .33307 .57071 L p .707 .577 .707 r
F P
0 g
s
.42699 .5149 m .42477 .57071 L .39326 .5682 L p .707 .577 .707 r
F P
0 g
s
.39326 .5682 m .39549 .5124 L .42699 .5149 L p .707 .577 .707 r
F P
0 g
s
.47329 .6393 m .47703 .65688 L .4534 .6536 L p .707 .577 .707 r
F P
0 g
s
.4534 .6536 m .44966 .63602 L .47329 .6393 L p .707 .577 .707 r
F P
0 g
s
.31524 .69082 m .3115 .67324 L .33211 .66069 L p .707 .577 .707 r
F P
0 g
s
.33041 .63419 m .32755 .59764 L .35526 .59087 L p .707 .577 .707 r
F P
0 g
s
.39549 .5124 m .39326 .5682 L .36167 .5682 L p .707 .577 .707 r
F P
0 g
s
.4472 .58746 m .45006 .62401 L .42102 .62207 L p .707 .577 .707 r
F P
0 g
s
.42102 .62207 m .41816 .58552 L .4472 .58746 L p .707 .577 .707 r
F P
0 g
s
.33211 .66069 m .33585 .67827 L .31524 .69082 L p .707 .577 .707 r
F P
0 g
s
.35526 .59087 m .35812 .62742 L .33041 .63419 L p .707 .577 .707 r
F P
0 g
s
.35812 .62742 m .35526 .59087 L .38648 .58669 L p .707 .577 .707 r
F P
0 g
s
.41816 .58552 m .42102 .62207 L .38934 .62324 L p .707 .577 .707 r
F P
0 g
s
.38934 .62324 m .38648 .58669 L .41816 .58552 L p .707 .577 .707 r
F P
0 g
s
.44966 .63602 m .4534 .6536 L .42456 .65437 L p .707 .577 .707 r
F P
0 g
s
.42456 .65437 m .42082 .63679 L .44966 .63602 L p .707 .577 .707 r
F P
0 g
s
.33585 .67827 m .33211 .66069 L .35902 .64976 L p .707 .577 .707 r
F P
0 g
s
.38648 .58669 m .38934 .62324 L .35812 .62742 L p .707 .577 .707 r
F P
0 g
s
.35902 .64976 m .36276 .66734 L .33585 .67827 L p .707 .577 .707 r
F P
0 g
s
.42082 .63679 m .42456 .65437 L .39333 .6591 L p .707 .577 .707 r
F P
0 g
s
.39333 .6591 m .38959 .64152 L .42082 .63679 L p .707 .577 .707 r
F P
0 g
s
.36276 .66734 m .35902 .64976 L .38959 .64152 L p .707 .577 .707 r
F P
0 g
s
.38959 .64152 m .39333 .6591 L .36276 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6@00Q7oo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH;001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001TOolA0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`P0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00EWoo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0I7oo001DOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005=oo`8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Aoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol20003FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00eooa4004Ioo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`07Ool60003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH8000nOol005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00Dgoo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Oomoogoo0P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001COol00eYF001JEP02
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oo`00008000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00DWoo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000bOol0059oo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000`Ool0059oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool0059oo`03001JEP0000=JEP04
001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH01000
FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0059oo`03001JEP0000=JEP@0009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60005FUH01000FUIJEUYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01000FUH005YF0P001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00UYF
0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001BOol01P00FUH00000FUH000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP80
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF40001EYF00<005YFFUH00eYF00D005YF000005YF008000EJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF1@000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEP<000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0002eoo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01@0015YF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001COol0
1@00FUIJEUYF00001EYF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF0000009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00Dgoo00D0
05YFFUIJEP0000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH40005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF009JEQP000IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;Goo001DOol200000eYF001JEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF
009JEPh000=oo`D00003Ool0000000T0009JEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0041o
oaT000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEUYF001JEP000eYF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH00UYF2@0015YF
00<005YFFUH015YF100015YF00@005YFFUIJEP8002ioo`00?7oo100000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP0300000eYF001JEP02FUH2000^Ool003Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUH005YF001JEP03
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20003FUH2000^Ool0039oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYF001JEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF0000000^
Ool0031oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03000^Ool002ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000IJEP03001JEP0000L000=JEP03001JEUYF009JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPH000EJEP<000MJEP03001J
EUYF00MJEPD000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEPD000IJEP03001JEUYF00UJEPD00003FUH0000000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH01000FUIJEUYF6@0015YF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH0
0UYF100000=JEP00FUH00UYF00@005YFFUH000EJEPD000IJEP03001JEUYF00T0009JEP03001JEUYF
00<000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUIJEP03FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD000=JEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000UYF00<005YF00000P001EYF00D005YFFUIJEP00009JEP03001J
EUYF00=JEPh000=JEP04001JEUYFFUH50003FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF1`000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00<007ooOol0;Goo000]Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002
FUH300000eYF001JEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEPL0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<002moo`00;Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00P005YF001JEP00FUH005YF
100015YF00@005YFFUH0009JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH20002FUH00`00FUIJEP03FUH;0005FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01@00FUIJEUYF00001UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF009JEPL000=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;Goo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00D005YFFUIJ
EP0000IJEP@000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00D000=JEP80
00AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000;Woo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP04
FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF00000004FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH015YF5@0015YF00<005YFFUH0
0`0025YF00<005YFFUH010000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00AJEP00000000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF0080
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01@0025YF00<005YFFUH01UYF0`0015YF00<005YF00000UYF00<005YFFUH01EYF10001UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00;Woo000]Ool20004FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF000015YF0P0015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P001EYF0`000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUHO0003FUH00`00
FUIJEP02FUH2000^Ool002eoo`8000=JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00AJEP800003FUH005YF009JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF00<005YFFUH00eYF00<005YF
FUH05@0015YF00<005YFFUH01EYF00<005YF000010000eYF0P00;Woo000]Ool2000015YF00000000
1EYF00<005YFFUH00UYF5`000eYF0P001UYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00@005YFFUIJEP800004FUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF1@001eYF00<005YFFUH015YF1@00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP000000;Woo000]Ool30002FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP03FUH2
00000eYF001JEP06FUH00`00FUIJEP04FUH30004FUH70008FUH01000FUIJEP0015YF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
100015YF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YF00000P00;Woo000]Ool20003FUH00`00FUH0000200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH0200015YF00<005YFFUH00UYF2@00
0eYF00<005YFFUH02EYF100015YF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]Ool20003
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF1`00
00AJEP00FUIJEPT00003FUH0000000<000IJEP03001JEUYF00UJEP04001JEUYF0004FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20002FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P001EYF0P000eYF00@005YFFUH000EJ
EPD000IJEP03001JEUYF00MJEP8000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000
009JEP03001JEP0000IJEPD0009JEP03001JEUYF00AJEP<000MJEP03001JEUYF00EJEP8000IJEP<0
00IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000`Ool002ioo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH015YF00<005YF00000P000UYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP05001JEUYF001JEP020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YF
FUH015YF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0001P002moo`00;Goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01eYF10001UYF00<0
05YFFUH00P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH01P000eYF00<005YFFUH01EYF00<005YF0000200015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH0
0UYF00@005YFFUH000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP8000aJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00d000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF3P0015YF00@005YFFUIJEP@0
0003FUH005YF00AJEP03001JEUYF009JEP04001JEUYF0006FUH60006FUH00`00FUIJEP05FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00@000ioo`X0
009JEPD0009JEP03001JEUYF009JEP04001JEUYF0003FUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000=J
EP03001JEUYF009JEP@001]oo`80009JEP04001JEUYFFUH>0006FUH00`00FUIJEP07FUH00`00FUH0
00020004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHI
00000eYF001oo`0/Ool002eoo`8000=JEP03001JEP00008001moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000MJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02
000]Ool002eoo`8000=JEP8000Qooa0000]oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00@005YFFUIJEQ4000QJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEP00000^Ool002eoo`800004FUH00000FUH20002Ool50003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF1@001eYF00<005YFFUH0
0eYF100025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool30003FUH00`00FUH00002
0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003Ool50003FUH00`00FUIJEP05
FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF00000P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00<goo000]Ool30003
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003
Ool?0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF10001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00=Woo000]Ool01000FUH005YF0P000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF
00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000kOol002eoo`03001JEP00
008000AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01eYF5P001UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEPD0009JEP03001JEUYF00AJEP03001JEUYF009JEQ4004Aoo`00
;Woo0P0000=JEP00FUH00eYF1@001eYF00<005YFFUH01UYF1`001UYF00<005YFFUH015YF0P0000EJ
EP00FUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP090007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF3`00E7oo
000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF00<005YFFUH01EYF0`000UYF00@005YFFUH000IJEP03001JEUYF00EJEPL000]JEP03001J
EUYF00YJEP03001JEUYF00UJEPD0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF009JEP8005=oo`00;Goo00D005YFFUH005YF008000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEP00009JEP04
001JEUYF0006FUH00`00FUIJEP050006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP03FUH2001COol002eoo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH00eYF1@002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF0P0015YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF0P00
Dgoo000]Ool01000FUH007oo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0P0000=JEP00FUH00eYF0P000UYF00@005YFFUIJEP8000AJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF
00=JEP8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005=oo`00;Goo0P0017oo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000
00AJEP80009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<007oo00001@0015YF00<005YF
FUH00UYF00<005YF0000Dgoo000]Ool00`00Oomoo`05Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF0`001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF2`0000=JEP00FUH00eYF00<005YF0000Dgoo000]Ool2000:Ool30006FUH00`00
FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUH0000400001EYF000005YF00000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF1@001eYF00<005YF00000P000eYF00<005YF0000Dgoo000/Ool00`00
FUH0000=Ool40002FUH00`00FUIJEP02FUH50008FUH00`00FUIJEP02FUH50005Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH2000015YF001JEP00
Dgoo000/Ool01000FUIJEP0047oo6@002goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00P001eYF00<005YFFUH00eYF0`0000=JEP00Ool0DWoo000/Ool00`00FUIJEP02000FOol5
000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00Dgoo000/Ool01P00FUIJEP00FUH001Ioo`<001Yoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF00=JEP04001JEUYFFUH2
001COol002eoo`8000=JEP03001oogoo031oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP04001JEP000007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000]Ool20004FUH2000_
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000E7oo000^Ool00`00FUIJEP02FUH01000FUH00000;7oo00<005YF0000
0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF00<005YFFUH00P00E7oo
000_Ool20002FUH01000FUIJEUYF0P00:7oo0P000UYF00@007ooOomoo`8000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000AJEP@0009JEP04001JEUYFFUH5001FOol0035oo`<000EJEP@0025oo`<00005FUH005YFFUH0
0004Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P0025YF00<005YF00001@00Fgoo000cOol00`00FUIJEP04FUH0
0`00FUIJEP04000JOol30004FUH00`00FUH00007Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000FUH000QJEP04001J
EUYFFUH2001MOol003Aoo`8000AJEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP8000ao
o`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEPT000IJ
EP03001JEUYF00AJEP8005]oo`00=Woo0P000UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF
00<005YFFUH00eYF0P004Goo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02@001Goo0P0015YF00<005YFFUH01EYF0`00FGoo000hOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000HOol80006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH:0002Ool50007Ool300000eYF001JEP06FUH00`00FUIJEP02001GOol003Yo
o`8000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP000080029ooaX0
00MJEP03001JEUYF00L000Yoo`<000EJEP03001JEUYF009JEP8005Ioo`00?7oo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo100000=JEP00FUH01eYF00<005YFFUH0
0eYF20002Goo100000=JEP00FUH00eYF00<005YF0000EGoo0010Ool70004FUH00`00FUIJEP06FUH0
0`00FUIJEP04000oOol30006FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005Ool20003FUH01000
FUIJEP00EGoo0017Ool@0016Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
2@0000EJEP00FUIJEP0005Eoo`00XGoo1@001UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP000000EGoo002VOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUH00000EWoo002ZOol50006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000EWoo002_Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
EWoo002cOolD001FOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58557 .74796 m .58772 .6922 L .55702 .68884 L p .707 .577 .707 r
F P
0 g
s
.58772 .6922 m .58557 .74796 L .61749 .74884 L p .707 .577 .707 r
F P
0 g
s
.61749 .74884 m .61965 .69308 L .58772 .6922 L p .707 .577 .707 r
F P
0 g
s
.61965 .69308 m .61749 .74884 L .64752 .74716 L p .707 .577 .707 r
F P
0 g
s
.64752 .74716 m .64968 .6914 L .61965 .69308 L p .707 .577 .707 r
F P
0 g
s
.55487 .7446 m .55702 .68884 L .53057 .68333 L p .707 .577 .707 r
F P
0 g
s
.55702 .68884 m .55487 .7446 L .58557 .74796 L p .707 .577 .707 r
F P
0 g
s
.64968 .6914 m .64752 .74716 L .67272 .74308 L p .707 .577 .707 r
F P
0 g
s
.67272 .74308 m .67488 .68731 L .64968 .6914 L p .707 .577 .707 r
F P
0 g
s
.61342 .81155 m .61074 .77486 L .57886 .77678 L p .707 .577 .707 r
F P
0 g
s
.61074 .77486 m .61342 .81155 L .64397 .80682 L p .707 .577 .707 r
F P
0 g
s
.64397 .80682 m .64129 .77013 L .61074 .77486 L p .707 .577 .707 r
F P
0 g
s
.53057 .68333 m .52841 .7391 L .55487 .7446 L p .707 .577 .707 r
F P
0 g
s
.58154 .81347 m .57886 .77678 L .54876 .7757 L p .707 .577 .707 r
F P
0 g
s
.57886 .77678 m .58154 .81347 L .61342 .81155 L p .707 .577 .707 r
F P
0 g
s
.52841 .7391 m .53057 .68333 L .51093 .67622 L p .707 .577 .707 r
F P
0 g
s
.64129 .77013 m .64397 .80682 L .67018 .79975 L p .707 .577 .707 r
F P
0 g
s
.67018 .79975 m .6675 .76305 L .64129 .77013 L p .707 .577 .707 r
F P
0 g
s
.67488 .68731 m .67272 .74308 L .69062 .737 L p .707 .577 .707 r
F P
0 g
s
.69062 .737 m .69278 .68123 L .67488 .68731 L p .707 .577 .707 r
F P
0 g
s
.55144 .81239 m .54876 .7757 L .52339 .77173 L p .707 .577 .707 r
F P
0 g
s
.54876 .7757 m .55144 .81239 L .58154 .81347 L p .707 .577 .707 r
F P
0 g
s
.51093 .67622 m .50878 .73198 L .52841 .7391 L p .707 .577 .707 r
F P
0 g
s
.61662 .85538 m .61316 .83751 L .58176 .84242 L p .707 .577 .707 r
F P
0 g
s
.61316 .83751 m .61662 .85538 L .64697 .84738 L p .707 .577 .707 r
F P
0 g
s
.64697 .84738 m .64351 .82952 L .61316 .83751 L p .707 .577 .707 r
F P
0 g
s
.58522 .86029 m .58176 .84242 L .55236 .84377 L p .707 .577 .707 r
F P
0 g
s
.58176 .84242 m .58522 .86029 L .61662 .85538 L p .707 .577 .707 r
F P
0 g
s
.52339 .77173 m .52607 .80842 L .55144 .81239 L p .707 .577 .707 r
F P
0 g
s
.6675 .76305 m .67018 .79975 L .6895 .79101 L p .707 .577 .707 r
F P
0 g
s
.6895 .79101 m .68682 .75432 L .6675 .76305 L p .707 .577 .707 r
F P
0 g
s
.64351 .82952 m .64697 .84738 L .67329 .83709 L p .707 .577 .707 r
F P
0 g
s
.67329 .83709 m .66983 .81922 L .64351 .82952 L p .707 .577 .707 r
F P
0 g
s
.50878 .73198 m .51093 .67622 L .50005 .66819 L p .707 .577 .707 r
F P
0 g
s
.55236 .84377 m .55582 .86164 L .58522 .86029 L p .707 .577 .707 r
F P
0 g
s
.52607 .80842 m .52339 .77173 L .50524 .76525 L p .707 .577 .707 r
F P
0 g
s
.69278 .68123 m .69062 .737 L .69947 .72951 L p .707 .577 .707 r
F P
0 g
s
.69947 .72951 m .70163 .67375 L .69278 .68123 L p .707 .577 .707 r
F P
0 g
s
.55582 .86164 m .55236 .84377 L .52786 .84142 L p .707 .577 .707 r
F P
0 g
s
.66983 .81922 m .67329 .83709 L .693 .8255 L p .707 .577 .707 r
F P
0 g
s
.693 .8255 m .68954 .80763 L .66983 .81922 L p .707 .577 .707 r
F P
0 g
s
.52786 .84142 m .53132 .85929 L .55582 .86164 L p .707 .577 .707 r
F P
0 g
s
.50524 .76525 m .50792 .80194 L .52607 .80842 L p .707 .577 .707 r
F P
0 g
s
.50005 .66819 m .49789 .72395 L .50878 .73198 L p .707 .577 .707 r
F P
0 g
s
.68682 .75432 m .6895 .79101 L .70004 .78148 L p .707 .577 .707 r
F P
0 g
s
.70004 .78148 m .69736 .74479 L .68682 .75432 L p .707 .577 .707 r
F P
0 g
s
.53132 .85929 m .52786 .84142 L .51065 .8356 L p .707 .577 .707 r
F P
0 g
s
.50792 .80194 m .50524 .76525 L .49607 .7569 L p .707 .577 .707 r
F P
0 g
s
.49789 .72395 m .50005 .66819 L .49898 .66003 L p .707 .577 .707 r
F P
0 g
s
.51065 .8356 m .51411 .85347 L .53132 .85929 L p .707 .577 .707 r
F P
0 g
s
.68954 .80763 m .693 .8255 L .70418 .81375 L p .707 .577 .707 r
F P
0 g
s
.70418 .81375 m .70071 .79588 L .68954 .80763 L p .707 .577 .707 r
F P
0 g
s
.70163 .67375 m .69947 .72951 L .6984 .72136 L p .707 .577 .707 r
F P
0 g
s
.6984 .72136 m .70055 .66559 L .70163 .67375 L p .707 .577 .707 r
F P
0 g
s
.49607 .7569 m .49875 .79359 L .50792 .80194 L p .707 .577 .707 r
F P
0 g
s
.49898 .66003 m .49682 .7158 L .49789 .72395 L p .707 .577 .707 r
F P
0 g
s
.69736 .74479 m .70004 .78148 L .70076 .77208 L p .707 .577 .707 r
F P
0 g
s
.70076 .77208 m .69808 .73539 L .69736 .74479 L p .707 .577 .707 r
F P
0 g
s
.49875 .79359 m .49607 .7569 L .49679 .7475 L p .707 .577 .707 r
F P
0 g
s
.49682 .7158 m .49898 .66003 L .50782 .65254 L p .707 .577 .707 r
F P
0 g
s
.49679 .7475 m .49947 .78419 L .49875 .79359 L p .707 .577 .707 r
F P
0 g
s
.50782 .65254 m .50567 .70831 L .49682 .7158 L p .707 .577 .707 r
F P
0 g
s
.49947 .78419 m .49679 .7475 L .50733 .73797 L p .707 .577 .707 r
F P
0 g
s
.49737 .82192 m .49737 .32003 L .45293 .31792 L p .707 .577 .707 r
F P
0 g
s
.51411 .85347 m .51065 .8356 L .50242 .82689 L p .707 .577 .707 r
F P
0 g
s
.50242 .82689 m .50588 .84475 L .51411 .85347 L p .707 .577 .707 r
F P
0 g
s
.50588 .84475 m .50242 .82689 L .50396 .81613 L p .707 .577 .707 r
F P
0 g
s
.50567 .70831 m .50782 .65254 L .52572 .64646 L p .707 .577 .707 r
F P
0 g
s
.50396 .81613 m .50743 .834 L .50588 .84475 L p .707 .577 .707 r
F P
0 g
s
.50733 .73797 m .51001 .77466 L .49947 .78419 L p .707 .577 .707 r
F P
0 g
s
.52572 .64646 m .52357 .70223 L .50567 .70831 L p .707 .577 .707 r
F P
0 g
s
.50743 .834 m .50396 .81613 L .51514 .80438 L p .707 .577 .707 r
F P
0 g
s
.52357 .70223 m .52572 .64646 L .55092 .64238 L p .707 .577 .707 r
F P
0 g
s
.51001 .77466 m .50733 .73797 L .52665 .72924 L p .707 .577 .707 r
F P
0 g
s
.51514 .80438 m .5186 .82225 L .50743 .834 L p .707 .577 .707 r
F P
0 g
s
.52665 .72924 m .52933 .76593 L .51001 .77466 L p .707 .577 .707 r
F P
0 g
s
.55092 .64238 m .54877 .69815 L .52357 .70223 L p .707 .577 .707 r
F P
0 g
s
.52933 .76593 m .52665 .72924 L .55286 .72216 L p .707 .577 .707 r
F P
0 g
s
.5186 .82225 m .51514 .80438 L .53485 .79279 L p .707 .577 .707 r
F P
0 g
s
.53485 .79279 m .53831 .81066 L .5186 .82225 L p .707 .577 .707 r
F P
0 g
s
.55286 .72216 m .55554 .75885 L .52933 .76593 L p .707 .577 .707 r
F P
0 g
s
.53831 .81066 m .53485 .79279 L .56117 .78249 L p .707 .577 .707 r
F P
0 g
s
.56117 .78249 m .56463 .80036 L .53831 .81066 L p .707 .577 .707 r
F P
0 g
s
.49737 .32003 m .49737 .82192 L .54207 .82024 L p .707 .577 .707 r
F P
0 g
s
.54207 .82024 m .54207 .31835 L .49737 .32003 L p .707 .577 .707 r
F P
0 g
s
.54877 .69815 m .55092 .64238 L .58096 .6407 L p .707 .577 .707 r
F P
0 g
s
.58096 .6407 m .5788 .69647 L .54877 .69815 L p .707 .577 .707 r
F P
0 g
s
.55554 .75885 m .55286 .72216 L .58341 .71743 L p .707 .577 .707 r
F P
0 g
s
.58341 .71743 m .58609 .75412 L .55554 .75885 L p .707 .577 .707 r
F P
0 g
s
.56463 .80036 m .56117 .78249 L .59152 .7745 L p .707 .577 .707 r
F P
0 g
s
.59152 .7745 m .59498 .79237 L .56463 .80036 L p .707 .577 .707 r
F P
0 g
s
.54207 .31835 m .54207 .82024 L .58264 .81494 L p .707 .577 .707 r
F P
0 g
s
.5788 .69647 m .58096 .6407 L .61288 .64158 L p .707 .577 .707 r
F P
0 g
s
.61288 .64158 m .61073 .69735 L .5788 .69647 L p .707 .577 .707 r
F P
0 g
s
.58264 .81494 m .58264 .31305 L .54207 .31835 L p .707 .577 .707 r
F P
0 g
s
.45293 .8198 m .45293 .31792 L .4131 .31222 L p .707 .577 .707 r
F P
0 g
s
.45293 .31792 m .45293 .8198 L .49737 .82192 L p .707 .577 .707 r
F P
0 g
s
.70071 .79588 m .70418 .81375 L .70572 .80299 L p .707 .577 .707 r
F P
0 g
s
.70572 .80299 m .70226 .78512 L .70071 .79588 L p .707 .577 .707 r
F P
0 g
s
.70055 .66559 m .6984 .72136 L .68752 .71333 L p .707 .577 .707 r
F P
0 g
s
.68752 .71333 m .68967 .65756 L .70055 .66559 L p .707 .577 .707 r
F P
0 g
s
.61529 .71551 m .61797 .7522 L .58609 .75412 L p .707 .577 .707 r
F P
0 g
s
.58609 .75412 m .58341 .71743 L .61529 .71551 L p .707 .577 .707 r
F P
0 g
s
.62292 .76959 m .62638 .78746 L .59498 .79237 L p .707 .577 .707 r
F P
0 g
s
.59498 .79237 m .59152 .7745 L .62292 .76959 L p .707 .577 .707 r
F P
0 g
s
.58264 .31305 m .58264 .81494 L .61513 .80653 L p .707 .577 .707 r
F P
0 g
s
.64358 .64494 m .64143 .7007 L .61073 .69735 L p .707 .577 .707 r
F P
0 g
s
.61073 .69735 m .61288 .64158 L .64358 .64494 L p .707 .577 .707 r
F P
0 g
s
.61513 .80653 m .61513 .30465 L .58264 .31305 L p .707 .577 .707 r
F P
0 g
s
.69808 .73539 m .70076 .77208 L .69159 .76373 L p .707 .577 .707 r
F P
0 g
s
.69159 .76373 m .68891 .72704 L .69808 .73539 L p .707 .577 .707 r
F P
0 g
s
.4131 .81411 m .4131 .31222 L .38178 .30351 L p .707 .577 .707 r
F P
0 g
s
.4131 .31222 m .4131 .81411 L .45293 .8198 L p .707 .577 .707 r
F P
0 g
s
.2453 .71487 m .2462 .65995 L .21549 .65678 L p .707 .577 .707 r
F P
0 g
s
.2462 .65995 m .2453 .71487 L .27725 .71501 L p .707 .577 .707 r
F P
0 g
s
.27725 .71501 m .27815 .66009 L .2462 .65995 L p .707 .577 .707 r
F P
0 g
s
.27815 .66009 m .27725 .71501 L .3073 .71212 L p .707 .577 .707 r
F P
0 g
s
.3073 .71212 m .3082 .6572 L .27815 .66009 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70226 .78512 m .70572 .80299 L .69749 .79428 L p .707 .577 .707 r
F P
0 g
s
.69749 .79428 m .69403 .77641 L .70226 .78512 L p .707 .577 .707 r
F P
0 g
s
.21459 .7117 m .21549 .65678 L .18901 .65091 L p .707 .577 .707 r
F P
0 g
s
.21549 .65678 m .21459 .7117 L .2453 .71487 L p .707 .577 .707 r
F P
0 g
s
.68967 .65756 m .68752 .71333 L .66788 .70621 L p .707 .577 .707 r
F P
0 g
s
.66788 .70621 m .67004 .65045 L .68967 .65756 L p .707 .577 .707 r
F P
0 g
s
.3082 .6572 m .3073 .71212 L .3325 .70648 L p .707 .577 .707 r
F P
0 g
s
.3325 .70648 m .33341 .65156 L .3082 .6572 L p .707 .577 .707 r
F P
0 g
s
.64539 .71659 m .64807 .75328 L .61797 .7522 L p .707 .577 .707 r
F P
0 g
s
.61797 .7522 m .61529 .71551 L .64539 .71659 L p .707 .577 .707 r
F P
0 g
s
.65232 .76824 m .65578 .78611 L .62638 .78746 L p .707 .577 .707 r
F P
0 g
s
.62638 .78746 m .62292 .76959 L .65232 .76824 L p .707 .577 .707 r
F P
0 g
s
.61513 .30465 m .61513 .80653 L .63635 .79585 L p .707 .577 .707 r
F P
0 g
s
.63635 .79585 m .63635 .29396 L .61513 .30465 L p .707 .577 .707 r
F P
0 g
s
.68891 .72704 m .69159 .76373 L .67344 .75726 L p .707 .577 .707 r
F P
0 g
s
.67344 .75726 m .67076 .72056 L .68891 .72704 L p .707 .577 .707 r
F P
0 g
s
.27232 .76391 m .27123 .72618 L .23928 .72694 L p .707 .577 .707 r
F P
0 g
s
.27123 .72618 m .27232 .76391 L .30292 .76128 L p .707 .577 .707 r
F P
0 g
s
.30292 .76128 m .30182 .72355 L .27123 .72618 L p .707 .577 .707 r
F P
0 g
s
.24038 .76467 m .23928 .72694 L .20911 .72575 L p .707 .577 .707 r
F P
0 g
s
.23928 .72694 m .24038 .76467 L .27232 .76391 L p .707 .577 .707 r
F P
0 g
s
.38178 .80539 m .38178 .30351 L .36202 .29262 L p .707 .577 .707 r
F P
0 g
s
.38178 .30351 m .38178 .80539 L .4131 .81411 L p .707 .577 .707 r
F P
0 g
s
.18811 .70583 m .18901 .65091 L .16936 .64289 L p .707 .577 .707 r
F P
0 g
s
.18901 .65091 m .18811 .70583 L .21459 .7117 L p .707 .577 .707 r
F P
0 g
s
.33341 .65156 m .3325 .70648 L .35041 .69864 L p .707 .577 .707 r
F P
0 g
s
.35041 .69864 m .35131 .64372 L .33341 .65156 L p .707 .577 .707 r
F P
0 g
s
.20911 .72575 m .2102 .76349 L .24038 .76467 L p .707 .577 .707 r
F P
0 g
s
.30182 .72355 m .30292 .76128 L .32917 .75705 L p .707 .577 .707 r
F P
0 g
s
.32917 .75705 m .32807 .71931 L .30182 .72355 L p .707 .577 .707 r
F P
0 g
s
.27286 .79383 m .27146 .77469 L .2396 .77694 L p .707 .577 .707 r
F P
0 g
s
.27146 .77469 m .27286 .79383 L .30356 .79103 L p .707 .577 .707 r
F P
0 g
s
.30356 .79103 m .30216 .77189 L .27146 .77469 L p .707 .577 .707 r
F P
0 g
s
.2396 .77694 m .24101 .79608 L .27286 .79383 L p .707 .577 .707 r
F P
0 g
s
.67004 .65045 m .66788 .70621 L .64143 .7007 L p .707 .577 .707 r
F P
0 g
s
.64143 .7007 m .64358 .64494 L .67004 .65045 L p .707 .577 .707 r
F P
0 g
s
.2102 .76349 m .20911 .72575 L .18367 .72274 L p .707 .577 .707 r
F P
0 g
s
.24101 .79608 m .2396 .77694 L .20971 .77841 L p .707 .577 .707 r
F P
0 g
s
.69403 .77641 m .69749 .79428 L .68028 .78846 L p .707 .577 .707 r
F P
0 g
s
.68028 .78846 m .67682 .77059 L .69403 .77641 L p .707 .577 .707 r
F P
0 g
s
.20971 .77841 m .21112 .79755 L .24101 .79608 L p .707 .577 .707 r
F P
0 g
s
.30216 .77189 m .30356 .79103 L .33011 .78795 L p .707 .577 .707 r
F P
0 g
s
.33011 .78795 m .3287 .7688 L .30216 .77189 L p .707 .577 .707 r
F P
0 g
s
.18367 .72274 m .18476 .76047 L .2102 .76349 L p .707 .577 .707 r
F P
0 g
s
.16936 .64289 m .16846 .69781 L .18811 .70583 L p .707 .577 .707 r
F P
0 g
s
.21112 .79755 m .20971 .77841 L .18472 .77896 L p .707 .577 .707 r
F P
0 g
s
.18472 .77896 m .18612 .7981 L .21112 .79755 L p .707 .577 .707 r
F P
0 g
s
.67076 .72056 m .67344 .75726 L .64807 .75328 L p .707 .577 .707 r
F P
0 g
s
.64807 .75328 m .64539 .71659 L .67076 .72056 L p .707 .577 .707 r
F P
0 g
s
.16846 .69781 m .16936 .64289 L .15846 .63353 L p .707 .577 .707 r
F P
0 g
s
.32807 .71931 m .32917 .75705 L .3485 .75161 L p .707 .577 .707 r
F P
0 g
s
.3485 .75161 m .34741 .71388 L .32807 .71931 L p .707 .577 .707 r
F P
0 g
s
.18476 .76047 m .18367 .72274 L .16545 .7182 L p .707 .577 .707 r
F P
0 g
s
.35131 .64372 m .35041 .69864 L .35925 .68936 L p .707 .577 .707 r
F P
0 g
s
.35925 .68936 m .36015 .63444 L .35131 .64372 L p .707 .577 .707 r
F P
0 g
s
.3287 .7688 m .33011 .78795 L .3499 .78488 L p .707 .577 .707 r
F P
0 g
s
.3499 .78488 m .34849 .76574 L .3287 .7688 L p .707 .577 .707 r
F P
0 g
s
.63635 .29396 m .63635 .79585 L .64422 .78392 L p .707 .577 .707 r
F P
0 g
s
.64422 .78392 m .64422 .28203 L .63635 .29396 L p .707 .577 .707 r
F P
0 g
s
.16545 .7182 m .16654 .75593 L .18476 .76047 L p .707 .577 .707 r
F P
0 g
s
.67682 .77059 m .68028 .78846 L .65578 .78611 L p .707 .577 .707 r
F P
0 g
s
.65578 .78611 m .65232 .76824 L .67682 .77059 L p .707 .577 .707 r
F P
0 g
s
.36015 .63444 m .35925 .68936 L .35817 .67956 L p .707 .577 .707 r
F P
0 g
s
.35817 .67956 m .35907 .62464 L .36015 .63444 L p .707 .577 .707 r
F P
0 g
s
.35959 .76299 m .361 .78213 L .36231 .77997 L p .707 .577 .707 r
F P
0 g
s
.36231 .77997 m .36091 .76083 L .35959 .76299 L p .707 .577 .707 r
F P
0 g
s
.34849 .76574 m .3499 .78488 L .361 .78213 L p .707 .577 .707 r
F P
0 g
s
.361 .78213 m .35959 .76299 L .34849 .76574 L p .707 .577 .707 r
F P
0 g
s
.36091 .76083 m .36231 .77997 L .35372 .77861 L p .707 .577 .707 r
F P
0 g
s
.36202 .79451 m .36202 .29262 L .35578 .28062 L p .707 .577 .707 r
F P
0 g
s
.36202 .29262 m .36202 .79451 L .38178 .80539 L p .707 .577 .707 r
F P
0 g
s
.18612 .7981 m .18472 .77896 L .16706 .77853 L p .707 .577 .707 r
F P
0 g
s
.16706 .77853 m .16847 .79767 L .18612 .7981 L p .707 .577 .707 r
F P
0 g
s
.15846 .63353 m .15756 .68845 L .16846 .69781 L p .707 .577 .707 r
F P
0 g
s
.34741 .71388 m .3485 .75161 L .35902 .74551 L p .707 .577 .707 r
F P
0 g
s
.35902 .74551 m .35793 .70778 L .34741 .71388 L p .707 .577 .707 r
F P
0 g
s
.15756 .68845 m .15846 .63353 L .15738 .62373 L p .707 .577 .707 r
F P
0 g
s
.16654 .75593 m .16545 .7182 L .15623 .71257 L p .707 .577 .707 r
F P
0 g
s
.15623 .71257 m .15732 .7503 L .16654 .75593 L p .707 .577 .707 r
F P
0 g
s
.16847 .79767 m .16706 .77853 L .15847 .77717 L p .707 .577 .707 r
F P
0 g
s
.15847 .77717 m .15988 .79631 L .16847 .79767 L p .707 .577 .707 r
F P
0 g
s
.15738 .62373 m .15648 .67865 L .15756 .68845 L p .707 .577 .707 r
F P
0 g
s
.64422 .28203 m .64422 .78392 L .63797 .77193 L p .707 .577 .707 r
F P
0 g
s
.63797 .77193 m .63797 .27004 L .64422 .28203 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35793 .70778 m .35902 .74551 L .35971 .73934 L p .707 .577 .707 r
F P
0 g
s
.35971 .73934 m .35862 .70161 L .35793 .70778 L p .707 .577 .707 r
F P
0 g
s
.35907 .62464 m .35817 .67956 L .34727 .6702 L p .707 .577 .707 r
F P
0 g
s
.34727 .6702 m .34817 .61528 L .35907 .62464 L p .707 .577 .707 r
F P
0 g
s
.35862 .70161 m .35971 .73934 L .35049 .73371 L p .707 .577 .707 r
F P
0 g
s
.35049 .73371 m .3494 .69598 L .35862 .70161 L p .707 .577 .707 r
F P
0 g
s
.35372 .77861 m .35232 .75947 L .36091 .76083 L p .707 .577 .707 r
F P
0 g
s
.35578 .28062 m .35578 .78251 L .36202 .79451 L p .707 .577 .707 r
F P
0 g
s
.35578 .78251 m .35578 .28062 L .36365 .2687 L p .707 .577 .707 r
F P
0 g
s
.15648 .67865 m .15738 .62373 L .16623 .61446 L p .707 .577 .707 r
F P
0 g
s
.15732 .7503 m .15623 .71257 L .15691 .7064 L p .707 .577 .707 r
F P
0 g
s
.15691 .7064 m .15801 .74413 L .15732 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15988 .79631 m .15847 .77717 L .15979 .77501 L p .707 .577 .707 r
F P
0 g
s
.15979 .77501 m .1612 .79415 L .15988 .79631 L p .707 .577 .707 r
F P
0 g
s
.16623 .61446 m .16532 .66938 L .15648 .67865 L p .707 .577 .707 r
F P
0 g
s
.16532 .66938 m .16623 .61446 L .18413 .60662 L p .707 .577 .707 r
F P
0 g
s
.15801 .74413 m .15691 .7064 L .16744 .7003 L p .707 .577 .707 r
F P
0 g
s
.34817 .61528 m .34727 .6702 L .32762 .66219 L p .707 .577 .707 r
F P
0 g
s
.32762 .66219 m .32852 .60727 L .34817 .61528 L p .707 .577 .707 r
F P
0 g
s
.63797 .27004 m .63797 .77193 L .61822 .76104 L p .707 .577 .707 r
F P
0 g
s
.61822 .76104 m .61822 .25915 L .63797 .27004 L p .707 .577 .707 r
F P
0 g
s
.16744 .7003 m .16853 .73803 L .15801 .74413 L p .707 .577 .707 r
F P
0 g
s
.36365 .77059 m .36365 .2687 L .38487 .25801 L p .707 .577 .707 r
F P
0 g
s
.36365 .2687 m .36365 .77059 L .35578 .78251 L p .707 .577 .707 r
F P
0 g
s
.1612 .79415 m .15979 .77501 L .17089 .77226 L p .707 .577 .707 r
F P
0 g
s
.18413 .60662 m .18323 .66154 L .16532 .66938 L p .707 .577 .707 r
F P
0 g
s
.17089 .77226 m .17229 .79141 L .1612 .79415 L p .707 .577 .707 r
F P
0 g
s
.18323 .66154 m .18413 .60662 L .20934 .60097 L p .707 .577 .707 r
F P
0 g
s
.3494 .69598 m .35049 .73371 L .33227 .72917 L p .707 .577 .707 r
F P
0 g
s
.33227 .72917 m .33118 .69144 L .3494 .69598 L p .707 .577 .707 r
F P
0 g
s
.32852 .60727 m .32762 .66219 L .30114 .65631 L p .707 .577 .707 r
F P
0 g
s
.30114 .65631 m .30204 .60139 L .32852 .60727 L p .707 .577 .707 r
F P
0 g
s
.16853 .73803 m .16744 .7003 L .18677 .69487 L p .707 .577 .707 r
F P
0 g
s
.35232 .75947 m .35372 .77861 L .33607 .77819 L p .707 .577 .707 r
F P
0 g
s
.33607 .77819 m .33466 .75905 L .35232 .75947 L p .707 .577 .707 r
F P
0 g
s
.18677 .69487 m .18787 .7326 L .16853 .73803 L p .707 .577 .707 r
F P
0 g
s
.20934 .60097 m .20844 .65589 L .18323 .66154 L p .707 .577 .707 r
F P
0 g
s
.20844 .65589 m .20934 .60097 L .23938 .59808 L p .707 .577 .707 r
F P
0 g
s
.61822 .25915 m .61822 .76104 L .5869 .75232 L p .707 .577 .707 r
F P
0 g
s
.5869 .75232 m .5869 .25044 L .61822 .25915 L p .707 .577 .707 r
F P
0 g
s
.17229 .79141 m .17089 .77226 L .19068 .7692 L p .707 .577 .707 r
F P
0 g
s
.30204 .60139 m .30114 .65631 L .27043 .65315 L p .707 .577 .707 r
F P
0 g
s
.27043 .65315 m .27133 .59823 L .30204 .60139 L p .707 .577 .707 r
F P
0 g
s
.19068 .7692 m .19208 .78834 L .17229 .79141 L p .707 .577 .707 r
F P
0 g
s
.38487 .25801 m .38487 .7599 L .36365 .77059 L p .707 .577 .707 r
F P
0 g
s
.38487 .7599 m .38487 .25801 L .41735 .24961 L p .707 .577 .707 r
F P
0 g
s
.33118 .69144 m .33227 .72917 L .30683 .72616 L p .707 .577 .707 r
F P
0 g
s
.30683 .72616 m .30573 .68843 L .33118 .69144 L p .707 .577 .707 r
F P
0 g
s
.72957 .65489 m .72867 .59874 L .69795 .59718 L p .707 .577 .707 r
F P
0 g
s
.72867 .59874 m .72957 .65489 L .76151 .65415 L p .707 .577 .707 r
F P
0 g
s
.76151 .65415 m .76061 .59801 L .72867 .59874 L p .707 .577 .707 r
F P
0 g
s
.23848 .653 m .23938 .59808 L .27133 .59823 L p .707 .577 .707 r
F P
0 g
s
.23938 .59808 m .23848 .653 L .20844 .65589 L p .707 .577 .707 r
F P
0 g
s
.76061 .59801 m .76151 .65415 L .79156 .65119 L p .707 .577 .707 r
F P
0 g
s
.79156 .65119 m .79066 .59504 L .76061 .59801 L p .707 .577 .707 r
F P
0 g
s
.27133 .59823 m .27043 .65315 L .23848 .653 L p .707 .577 .707 r
F P
0 g
s
.18787 .7326 m .18677 .69487 L .21302 .69063 L p .707 .577 .707 r
F P
0 g
s
.69885 .65332 m .69795 .59718 L .67147 .59346 L p .707 .577 .707 r
F P
0 g
s
.69795 .59718 m .69885 .65332 L .72957 .65489 L p .707 .577 .707 r
F P
0 g
s
.21302 .69063 m .21411 .72836 L .18787 .7326 L p .707 .577 .707 r
F P
0 g
s
.33466 .75905 m .33607 .77819 L .31107 .77874 L p .707 .577 .707 r
F P
0 g
s
.31107 .77874 m .30967 .7596 L .33466 .75905 L p .707 .577 .707 r
F P
0 g
s
.79066 .59504 m .79156 .65119 L .81677 .64628 L p .707 .577 .707 r
F P
0 g
s
.81677 .64628 m .81587 .59014 L .79066 .59504 L p .707 .577 .707 r
F P
0 g
s
.19208 .78834 m .19068 .7692 L .21722 .76611 L p .707 .577 .707 r
F P
0 g
s
.30573 .68843 m .30683 .72616 L .27666 .72497 L p .707 .577 .707 r
F P
0 g
s
.27666 .72497 m .27556 .68724 L .30573 .68843 L p .707 .577 .707 r
F P
0 g
s
.21722 .76611 m .21863 .78525 L .19208 .78834 L p .707 .577 .707 r
F P
0 g
s
.21411 .72836 m .21302 .69063 L .24362 .688 L p .707 .577 .707 r
F P
0 g
s
.67147 .59346 m .67238 .6496 L .69885 .65332 L p .707 .577 .707 r
F P
0 g
s
.75529 .72626 m .75638 .69014 L .72443 .68905 L p .707 .577 .707 r
F P
0 g
s
.75638 .69014 m .75529 .72626 L .78588 .72391 L p .707 .577 .707 r
F P
0 g
s
.78588 .72391 m .78698 .68779 L .75638 .69014 L p .707 .577 .707 r
F P
0 g
s
.72334 .72517 m .72443 .68905 L .69426 .68463 L p .707 .577 .707 r
F P
0 g
s
.72443 .68905 m .72334 .72517 L .75529 .72626 L p .707 .577 .707 r
F P
0 g
s
.5869 .25044 m .5869 .75232 L .54706 .74663 L p .707 .577 .707 r
F P
0 g
s
.54706 .74663 m .54706 .24474 L .5869 .25044 L p .707 .577 .707 r
F P
0 g
s
.67238 .6496 m .67147 .59346 L .65182 .58796 L p .707 .577 .707 r
F P
0 g
s
.41735 .7515 m .41735 .24961 L .45793 .24431 L p .707 .577 .707 r
F P
0 g
s
.41735 .24961 m .41735 .7515 L .38487 .7599 L p .707 .577 .707 r
F P
0 g
s
.24362 .688 m .24471 .72573 L .21411 .72836 L p .707 .577 .707 r
F P
0 g
s
.27556 .68724 m .27666 .72497 L .24471 .72573 L p .707 .577 .707 r
F P
0 g
s
.24471 .72573 m .24362 .688 L .27556 .68724 L p .707 .577 .707 r
F P
0 g
s
.81587 .59014 m .81677 .64628 L .83467 .63992 L p .707 .577 .707 r
F P
0 g
s
.83467 .63992 m .83377 .58378 L .81587 .59014 L p .707 .577 .707 r
F P
0 g
s
.30967 .7596 m .31107 .77874 L .28118 .78021 L p .707 .577 .707 r
F P
0 g
s
.28118 .78021 m .27978 .76106 L .30967 .7596 L p .707 .577 .707 r
F P
0 g
s
.78698 .68779 m .78588 .72391 L .81213 .71837 L p .707 .577 .707 r
F P
0 g
s
.81213 .71837 m .81323 .68225 L .78698 .68779 L p .707 .577 .707 r
F P
0 g
s
.69317 .72076 m .69426 .68463 L .66882 .67733 L p .707 .577 .707 r
F P
0 g
s
.69426 .68463 m .69317 .72076 L .72334 .72517 L p .707 .577 .707 r
F P
0 g
s
.21863 .78525 m .21722 .76611 L .24792 .76331 L p .707 .577 .707 r
F P
0 g
s
.24792 .76331 m .24933 .78245 L .21863 .78525 L p .707 .577 .707 r
F P
0 g
s
.65182 .58796 m .65272 .6441 L .67238 .6496 L p .707 .577 .707 r
F P
0 g
s
.27978 .76106 m .28118 .78021 L .24933 .78245 L p .707 .577 .707 r
F P
0 g
s
.24933 .78245 m .24792 .76331 L .27978 .76106 L p .707 .577 .707 r
F P
0 g
s
.54706 .24474 m .54706 .74663 L .50263 .74452 L p .707 .577 .707 r
F P
0 g
s
.50263 .74452 m .50263 .24263 L .54706 .24474 L p .707 .577 .707 r
F P
0 g
s
.66882 .67733 m .66773 .71345 L .69317 .72076 L p .707 .577 .707 r
F P
0 g
s
.45793 .7462 m .45793 .24431 L .50263 .24263 L p .707 .577 .707 r
F P
0 g
s
.45793 .24431 m .45793 .7462 L .41735 .7515 L p .707 .577 .707 r
F P
0 g
s
.81323 .68225 m .81213 .71837 L .83147 .71016 L p .707 .577 .707 r
F P
0 g
s
.83147 .71016 m .83256 .67404 L .81323 .68225 L p .707 .577 .707 r
F P
0 g
s
.75067 .77875 m .75207 .76172 L .72022 .75904 L p .707 .577 .707 r
F P
0 g
s
.75207 .76172 m .75067 .77875 L .78137 .77678 L p .707 .577 .707 r
F P
0 g
s
.78137 .77678 m .78278 .75976 L .75207 .76172 L p .707 .577 .707 r
F P
0 g
s
.71881 .77607 m .72022 .75904 L .69033 .75197 L p .707 .577 .707 r
F P
0 g
s
.72022 .75904 m .71881 .77607 L .75067 .77875 L p .707 .577 .707 r
F P
0 g
s
.66773 .71345 m .66882 .67733 L .6506 .66784 L p .707 .577 .707 r
F P
0 g
s
.65272 .6441 m .65182 .58796 L .64092 .58121 L p .707 .577 .707 r
F P
0 g
s
.50263 .24263 m .50263 .74452 L .45793 .7462 L p .707 .577 .707 r
F P
0 g
s
.83377 .58378 m .83467 .63992 L .84352 .63272 L p .707 .577 .707 r
F P
0 g
s
.84352 .63272 m .84262 .57657 L .83377 .58378 L p .707 .577 .707 r
F P
0 g
s
.78278 .75976 m .78137 .77678 L .80792 .77035 L p .707 .577 .707 r
F P
0 g
s
.80792 .77035 m .80932 .75333 L .78278 .75976 L p .707 .577 .707 r
F P
0 g
s
.69033 .75197 m .68893 .769 L .71881 .77607 L p .707 .577 .707 r
F P
0 g
s
.68893 .769 m .69033 .75197 L .66534 .7412 L p .707 .577 .707 r
F P
0 g
s
.6506 .66784 m .64951 .70397 L .66773 .71345 L p .707 .577 .707 r
F P
0 g
s
.64092 .58121 m .64183 .63735 L .65272 .6441 L p .707 .577 .707 r
F P
0 g
s
.66534 .7412 m .66393 .75823 L .68893 .769 L p .707 .577 .707 r
F P
0 g
s
.83256 .67404 m .83147 .71016 L .84199 .7001 L p .707 .577 .707 r
F P
0 g
s
.84199 .7001 m .84308 .66398 L .83256 .67404 L p .707 .577 .707 r
F P
0 g
s
.64951 .70397 m .6506 .66784 L .64138 .65711 L p .707 .577 .707 r
F P
0 g
s
.80932 .75333 m .80792 .77035 L .82771 .7601 L p .707 .577 .707 r
F P
0 g
s
.82771 .7601 m .82911 .74307 L .80932 .75333 L p .707 .577 .707 r
F P
0 g
s
.66393 .75823 m .66534 .7412 L .64768 .72779 L p .707 .577 .707 r
F P
0 g
s
.64183 .63735 m .64092 .58121 L .63984 .57388 L p .707 .578 .707 r
F P
0 g
s
.64768 .72779 m .64627 .74482 L .66393 .75823 L p .707 .577 .707 r
F P
0 g
s
.84262 .57657 m .84352 .63272 L .84244 .62538 L p .707 .578 .707 r
F P
0 g
s
.84244 .62538 m .84154 .56924 L .84262 .57657 L p .707 .578 .707 r
F P
0 g
s
.64138 .65711 m .64029 .69323 L .64951 .70397 L p .707 .577 .707 r
F P
0 g
s
.63984 .57388 m .64075 .63002 L .64183 .63735 L p .707 .578 .707 r
F P
0 g
s
.82911 .74307 m .82771 .7601 L .8388 .74702 L p .707 .577 .707 r
F P
0 g
s
.8388 .74702 m .84021 .72999 L .82911 .74307 L p .707 .577 .707 r
F P
0 g
s
.64627 .74482 m .64768 .72779 L .63909 .71306 L p .707 .577 .707 r
F P
0 g
s
.84308 .66398 m .84199 .7001 L .84268 .68917 L p .707 .577 .707 r
F P
0 g
s
.84268 .68917 m .84377 .65305 L .84308 .66398 L p .707 .577 .707 r
F P
0 g
s
.64029 .69323 m .64138 .65711 L .64207 .64618 L p .707 .577 .707 r
F P
0 g
s
.63909 .71306 m .63768 .73008 L .64627 .74482 L p .707 .577 .707 r
F P
0 g
s
.64075 .63002 m .63984 .57388 L .64869 .56668 L p .707 .577 .707 r
F P
0 g
s
.64207 .64618 m .64097 .6823 L .64029 .69323 L p .707 .577 .707 r
F P
0 g
s
.84154 .56924 m .84244 .62538 L .83154 .61864 L p .707 .577 .707 r
F P
0 g
s
.83154 .61864 m .83064 .56249 L .84154 .56924 L p .707 .577 .707 r
F P
0 g
s
.64869 .56668 m .64959 .62282 L .64075 .63002 L p .707 .577 .707 r
F P
0 g
s
.84021 .72999 m .8388 .74702 L .84012 .73239 L p .705 .576 .707 r
F P
0 g
s
.84012 .73239 m .84153 .71536 L .84021 .72999 L p .705 .576 .707 r
F P
0 g
s
.63768 .73008 m .63909 .71306 L .64041 .69843 L p .705 .576 .707 r
F P
0 g
s
.84377 .65305 m .84268 .68917 L .83346 .67844 L p .707 .577 .707 r
F P
0 g
s
.83346 .67844 m .83455 .64231 L .84377 .65305 L p .707 .577 .707 r
F P
0 g
s
.64097 .6823 m .64207 .64618 L .65259 .63612 L p .707 .577 .707 r
F P
0 g
s
.64041 .69843 m .639 .71545 L .63768 .73008 L p .705 .576 .707 r
F P
0 g
s
.38927 .62182 m .38711 .56651 L .35642 .56511 L p .707 .577 .707 r
F P
0 g
s
.38711 .56651 m .38927 .62182 L .42119 .62038 L p .707 .577 .707 r
F P
0 g
s
.42119 .62038 m .41904 .56507 L .38711 .56651 L p .707 .577 .707 r
F P
0 g
s
.41904 .56507 m .42119 .62038 L .45123 .61622 L p .707 .577 .707 r
F P
0 g
s
.45123 .61622 m .44907 .56091 L .41904 .56507 L p .707 .577 .707 r
F P
0 g
s
.64959 .62282 m .64869 .56668 L .66659 .56031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35857 .62042 m .35642 .56511 L .32996 .561 L p .707 .577 .707 r
F P
0 g
s
.35642 .56511 m .35857 .62042 L .38927 .62182 L p .707 .577 .707 r
F P
0 g
s
.83064 .56249 m .83154 .61864 L .81189 .61314 L p .707 .577 .707 r
F P
0 g
s
.81189 .61314 m .81099 .55699 L .83064 .56249 L p .707 .577 .707 r
F P
0 g
s
.65259 .63612 m .6515 .67224 L .64097 .6823 L p .707 .577 .707 r
F P
0 g
s
.44907 .56091 m .45123 .61622 L .47643 .60977 L p .707 .577 .707 r
F P
0 g
s
.47643 .60977 m .47427 .55446 L .44907 .56091 L p .707 .577 .707 r
F P
0 g
s
.84153 .71536 m .84012 .73239 L .83153 .71765 L p .707 .577 .707 r
F P
0 g
s
.83153 .71765 m .83294 .70062 L .84153 .71536 L p .707 .577 .707 r
F P
0 g
s
.639 .71545 m .64041 .69843 L .65151 .68535 L p .707 .577 .707 r
F P
0 g
s
.66659 .56031 m .66749 .61645 L .64959 .62282 L p .707 .577 .707 r
F P
0 g
s
.41391 .67883 m .41659 .64161 L .38471 .63928 L p .707 .577 .707 r
F P
0 g
s
.41659 .64161 m .41391 .67883 L .44445 .67866 L p .707 .577 .707 r
F P
0 g
s
.44445 .67866 m .44713 .64144 L .41659 .64161 L p .707 .577 .707 r
F P
0 g
s
.38203 .67649 m .38471 .63928 L .35461 .63466 L p .707 .577 .707 r
F P
0 g
s
.38471 .63928 m .38203 .67649 L .41391 .67883 L p .707 .577 .707 r
F P
0 g
s
.83455 .64231 m .83346 .67844 L .81524 .66895 L p .707 .577 .707 r
F P
0 g
s
.81524 .66895 m .81633 .63283 L .83455 .64231 L p .707 .577 .707 r
F P
0 g
s
.6515 .67224 m .65259 .63612 L .67192 .62791 L p .707 .577 .707 r
F P
0 g
s
.32996 .561 m .33211 .61631 L .35857 .62042 L p .707 .577 .707 r
F P
0 g
s
.65151 .68535 m .6501 .70237 L .639 .71545 L p .707 .577 .707 r
F P
0 g
s
.33211 .61631 m .32996 .561 L .31033 .55458 L p .707 .577 .707 r
F P
0 g
s
.47427 .55446 m .47643 .60977 L .49433 .60165 L p .707 .577 .707 r
F P
0 g
s
.49433 .60165 m .49217 .54634 L .47427 .55446 L p .707 .577 .707 r
F P
0 g
s
.66749 .61645 m .66659 .56031 L .6918 .55541 L p .707 .577 .707 r
F P
0 g
s
.44713 .64144 m .44445 .67866 L .47067 .67599 L p .707 .577 .707 r
F P
0 g
s
.47067 .67599 m .47335 .63878 L .44713 .64144 L p .707 .577 .707 r
F P
0 g
s
.35461 .63466 m .35193 .67188 L .38203 .67649 L p .707 .577 .707 r
F P
0 g
s
.35193 .67188 m .35461 .63466 L .32924 .62822 L p .707 .577 .707 r
F P
0 g
s
.81099 .55699 m .81189 .61314 L .78541 .60942 L p .707 .577 .707 r
F P
0 g
s
.78541 .60942 m .78451 .55328 L .81099 .55699 L p .707 .577 .707 r
F P
0 g
s
.40502 .71857 m .40848 .70007 L .37707 .69412 L p .707 .577 .707 r
F P
0 g
s
.40848 .70007 m .40502 .71857 L .43537 .72227 L p .707 .577 .707 r
F P
0 g
s
.43537 .72227 m .43883 .70376 L .40848 .70007 L p .707 .577 .707 r
F P
0 g
s
.37361 .71263 m .37707 .69412 L .34768 .68651 L p .707 .577 .707 r
F P
0 g
s
.37707 .69412 m .37361 .71263 L .40502 .71857 L p .707 .577 .707 r
F P
0 g
s
.67192 .62791 m .67083 .66403 L .6515 .67224 L p .707 .577 .707 r
F P
0 g
s
.34768 .68651 m .34422 .70501 L .37361 .71263 L p .707 .577 .707 r
F P
0 g
s
.32924 .62822 m .32656 .66543 L .35193 .67188 L p .707 .577 .707 r
F P
0 g
s
.31033 .55458 m .31248 .60989 L .33211 .61631 L p .707 .577 .707 r
F P
0 g
s
.6918 .55541 m .6927 .61155 L .66749 .61645 L p .707 .577 .707 r
F P
0 g
s
.83294 .70062 m .83153 .71765 L .81387 .70424 L p .707 .577 .707 r
F P
0 g
s
.81387 .70424 m .81528 .68721 L .83294 .70062 L p .707 .577 .707 r
F P
0 g
s
.6501 .70237 m .65151 .68535 L .67129 .67509 L p .707 .577 .707 r
F P
0 g
s
.43883 .70376 m .43537 .72227 L .46168 .72336 L p .707 .577 .707 r
F P
0 g
s
.46168 .72336 m .46515 .70485 L .43883 .70376 L p .707 .577 .707 r
F P
0 g
s
.34422 .70501 m .34768 .68651 L .32318 .67797 L p .707 .577 .707 r
F P
0 g
s
.81633 .63283 m .81524 .66895 L .78979 .66165 L p .707 .577 .707 r
F P
0 g
s
.78979 .66165 m .79089 .62552 L .81633 .63283 L p .707 .577 .707 r
F P
0 g
s
.6927 .61155 m .6918 .55541 L .72185 .55244 L p .707 .577 .707 r
F P
0 g
s
.67083 .66403 m .67192 .62791 L .69817 .62237 L p .707 .577 .707 r
F P
0 g
s
.47335 .63878 m .47067 .67599 L .48999 .6711 L p .707 .577 .707 r
F P
0 g
s
.48999 .6711 m .49267 .63389 L .47335 .63878 L p .707 .577 .707 r
F P
0 g
s
.32318 .67797 m .31972 .69648 L .34422 .70501 L p .707 .577 .707 r
F P
0 g
s
.32656 .66543 m .32924 .62822 L .31108 .62058 L p .707 .577 .707 r
F P
0 g
s
.31248 .60989 m .31033 .55458 L .29944 .54648 L p .707 .577 .707 r
F P
0 g
s
.78451 .55328 m .78541 .60942 L .7547 .60785 L p .707 .577 .707 r
F P
0 g
s
.7547 .60785 m .75379 .55171 L .78451 .55328 L p .707 .577 .707 r
F P
0 g
s
.67129 .67509 m .66989 .69212 L .6501 .70237 L p .707 .577 .707 r
F P
0 g
s
.49217 .54634 m .49433 .60165 L .50317 .59265 L p .707 .577 .707 r
F P
0 g
s
.50317 .59265 m .50102 .53734 L .49217 .54634 L p .707 .577 .707 r
F P
0 g
s
.72275 .60859 m .72185 .55244 L .75379 .55171 L p .707 .577 .707 r
F P
0 g
s
.72185 .55244 m .72275 .60859 L .6927 .61155 L p .707 .577 .707 r
F P
0 g
s
.31108 .62058 m .3084 .6578 L .32656 .66543 L p .707 .577 .707 r
F P
0 g
s
.75379 .55171 m .7547 .60785 L .72275 .60859 L p .707 .577 .707 r
F P
0 g
s
.69817 .62237 m .69708 .65849 L .67083 .66403 L p .707 .577 .707 r
F P
0 g
s
.46515 .70485 m .46168 .72336 L .4814 .72173 L p .707 .577 .707 r
F P
0 g
s
.4814 .72173 m .48486 .70323 L .46515 .70485 L p .707 .577 .707 r
F P
0 g
s
.31972 .69648 m .32318 .67797 L .30597 .66935 L p .707 .577 .707 r
F P
0 g
s
.79089 .62552 m .78979 .66165 L .75962 .65723 L p .707 .577 .707 r
F P
0 g
s
.75962 .65723 m .76072 .62111 L .79089 .62552 L p .707 .577 .707 r
F P
0 g
s
.81528 .68721 m .81387 .70424 L .78888 .69347 L p .707 .577 .707 r
F P
0 g
s
.78888 .69347 m .79028 .67645 L .81528 .68721 L p .707 .577 .707 r
F P
0 g
s
.69708 .65849 m .69817 .62237 L .72877 .62002 L p .707 .577 .707 r
F P
0 g
s
.66989 .69212 m .67129 .67509 L .69784 .66866 L p .707 .577 .707 r
F P
0 g
s
.29944 .54648 m .3016 .60179 L .31248 .60989 L p .707 .577 .707 r
F P
0 g
s
.30597 .66935 m .30251 .68786 L .31972 .69648 L p .707 .577 .707 r
F P
0 g
s
.76072 .62111 m .75962 .65723 L .72768 .65615 L p .707 .577 .707 r
F P
0 g
s
.72768 .65615 m .72877 .62002 L .76072 .62111 L p .707 .577 .707 r
F P
0 g
s
.49267 .63389 m .48999 .6711 L .50053 .66446 L p .707 .577 .707 r
F P
0 g
s
.50053 .66446 m .50321 .62725 L .49267 .63389 L p .707 .577 .707 r
F P
0 g
s
.72877 .62002 m .72768 .65615 L .69708 .65849 L p .707 .577 .707 r
F P
0 g
s
.69784 .66866 m .69643 .68569 L .66989 .69212 L p .707 .577 .707 r
F P
0 g
s
.3084 .6578 m .31108 .62058 L .30192 .6125 L p .707 .577 .707 r
F P
0 g
s
.3016 .60179 m .29944 .54648 L .29837 .53749 L p .707 .578 .707 r
F P
0 g
s
.79028 .67645 m .78888 .69347 L .75899 .6864 L p .707 .577 .707 r
F P
0 g
s
.75899 .6864 m .7604 .66938 L .79028 .67645 L p .707 .577 .707 r
F P
0 g
s
.69643 .68569 m .69784 .66866 L .72854 .66669 L p .707 .577 .707 r
F P
0 g
s
.50102 .53734 m .50317 .59265 L .5021 .58367 L p .707 .578 .707 r
F P
0 g
s
.5021 .58367 m .49995 .52836 L .50102 .53734 L p .707 .578 .707 r
F P
0 g
s
.30192 .6125 m .29924 .64971 L .3084 .6578 L p .707 .577 .707 r
F P
0 g
s
.48486 .70323 m .4814 .72173 L .49257 .71755 L p .707 .577 .707 r
F P
0 g
s
.49257 .71755 m .49603 .69904 L .48486 .70323 L p .707 .577 .707 r
F P
0 g
s
.30251 .68786 m .30597 .66935 L .29774 .66149 L p .707 .577 .707 r
F P
0 g
s
.7604 .66938 m .75899 .6864 L .72714 .68372 L p .707 .577 .707 r
F P
0 g
s
.72714 .68372 m .72854 .66669 L .7604 .66938 L p .707 .577 .707 r
F P
0 g
s
.72854 .66669 m .72714 .68372 L .69643 .68569 L p .707 .577 .707 r
F P
0 g
s
.29774 .66149 m .29428 .68 L .30251 .68786 L p .707 .577 .707 r
F P
0 g
s
.29837 .53749 m .30052 .5928 L .3016 .60179 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.50321 .62725 m .50053 .66446 L .50125 .65671 L p .706 .576 .707 r
F P
0 g
s
.50125 .65671 m .50393 .6195 L .50321 .62725 L p .706 .576 .707 r
F P
0 g
s
.29924 .64971 m .30192 .6125 L .30264 .60475 L p .706 .576 .707 r
F P
0 g
s
.30052 .5928 m .29837 .53749 L .30722 .5285 L p .707 .577 .707 r
F P
0 g
s
.49995 .52836 m .5021 .58367 L .49122 .57557 L p .707 .577 .707 r
F P
0 g
s
.49122 .57557 m .48906 .52026 L .49995 .52836 L p .707 .577 .707 r
F P
0 g
s
.30264 .60475 m .29996 .64197 L .29924 .64971 L p .706 .576 .707 r
F P
0 g
s
.49603 .69904 m .49257 .71755 L .49412 .71122 L p .707 .577 .707 r
F P
0 g
s
.49412 .71122 m .49758 .69271 L .49603 .69904 L p .707 .577 .707 r
F P
0 g
s
.29428 .68 m .29774 .66149 L .29928 .65516 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29928 .65516 m .29582 .67367 L .29428 .68 L p .707 .577 .707 r
F P
0 g
s
.30722 .5285 m .30937 .58381 L .30052 .5928 L p .707 .577 .707 r
F P
0 g
s
.50393 .6195 m .50125 .65671 L .49208 .64863 L p .707 .577 .707 r
F P
0 g
s
.49208 .64863 m .49476 .61141 L .50393 .6195 L p .707 .577 .707 r
F P
0 g
s
.29996 .64197 m .30264 .60475 L .31317 .59811 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30937 .58381 m .30722 .5285 L .32512 .52037 L p .707 .577 .707 r
F P
0 g
s
.48906 .52026 m .49122 .57557 L .47159 .56914 L p .707 .577 .707 r
F P
0 g
s
.47159 .56914 m .46943 .51384 L .48906 .52026 L p .707 .577 .707 r
F P
0 g
s
.31317 .59811 m .31049 .63532 L .29996 .64197 L p .707 .577 .707 r
F P
0 g
s
.49758 .69271 m .49412 .71122 L .48588 .70336 L p .707 .577 .707 r
F P
0 g
s
.48588 .70336 m .48934 .68485 L .49758 .69271 L p .707 .577 .707 r
F P
0 g
s
.29582 .67367 m .29928 .65516 L .31046 .65097 L p .707 .577 .707 r
F P
0 g
s
.31046 .65097 m .307 .66948 L .29582 .67367 L p .707 .577 .707 r
F P
0 g
s
.32512 .52037 m .32727 .57568 L .30937 .58381 L p .707 .577 .707 r
F P
0 g
s
.32727 .57568 m .32512 .52037 L .35032 .51392 L p .707 .577 .707 r
F P
0 g
s
.49476 .61141 m .49208 .64863 L .47392 .64099 L p .707 .577 .707 r
F P
0 g
s
.47392 .64099 m .4766 .60378 L .49476 .61141 L p .707 .577 .707 r
F P
0 g
s
.31049 .63532 m .31317 .59811 L .3325 .59322 L p .707 .577 .707 r
F P
0 g
s
.46943 .51384 m .47159 .56914 L .44513 .56503 L p .707 .577 .707 r
F P
0 g
s
.44513 .56503 m .44297 .50972 L .46943 .51384 L p .707 .577 .707 r
F P
0 g
s
.3325 .59322 m .32981 .63043 L .31049 .63532 L p .707 .577 .707 r
F P
0 g
s
.48934 .68485 m .48588 .70336 L .46867 .69474 L p .707 .577 .707 r
F P
0 g
s
.46867 .69474 m .47213 .67623 L .48934 .68485 L p .707 .577 .707 r
F P
0 g
s
.35032 .51392 m .35247 .56923 L .32727 .57568 L p .707 .577 .707 r
F P
0 g
s
.307 .66948 m .31046 .65097 L .33017 .64935 L p .707 .577 .707 r
F P
0 g
s
.35247 .56923 m .35032 .51392 L .38035 .50977 L p .707 .577 .707 r
F P
0 g
s
.33017 .64935 m .32671 .66786 L .307 .66948 L p .707 .577 .707 r
F P
0 g
s
.44297 .50972 m .44513 .56503 L .41443 .56363 L p .707 .577 .707 r
F P
0 g
s
.41443 .56363 m .41228 .50832 L .44297 .50972 L p .707 .577 .707 r
F P
0 g
s
.4766 .60378 m .47392 .64099 L .44855 .63455 L p .707 .577 .707 r
F P
0 g
s
.44855 .63455 m .45123 .59733 L .4766 .60378 L p .707 .577 .707 r
F P
0 g
s
.32981 .63043 m .3325 .59322 L .35871 .59055 L p .707 .577 .707 r
F P
0 g
s
.3825 .56508 m .38035 .50977 L .41228 .50832 L p .707 .577 .707 r
F P
0 g
s
.38035 .50977 m .3825 .56508 L .35247 .56923 L p .707 .577 .707 r
F P
0 g
s
.41228 .50832 m .41443 .56363 L .3825 .56508 L p .707 .577 .707 r
F P
0 g
s
.35871 .59055 m .35603 .62777 L .32981 .63043 L p .707 .577 .707 r
F P
0 g
s
.47213 .67623 m .46867 .69474 L .44417 .6862 L p .707 .577 .707 r
F P
0 g
s
.44417 .6862 m .44763 .66769 L .47213 .67623 L p .707 .577 .707 r
F P
0 g
s
.32671 .66786 m .33017 .64935 L .35649 .65044 L p .707 .577 .707 r
F P
0 g
s
.45123 .59733 m .44855 .63455 L .41845 .62993 L p .707 .577 .707 r
F P
0 g
s
.41845 .62993 m .42114 .59272 L .45123 .59733 L p .707 .577 .707 r
F P
0 g
s
.35603 .62777 m .35871 .59055 L .38925 .59038 L p .707 .577 .707 r
F P
0 g
s
.35649 .65044 m .35303 .66894 L .32671 .66786 L p .707 .577 .707 r
F P
0 g
s
.42114 .59272 m .41845 .62993 L .38657 .6276 L p .707 .577 .707 r
F P
0 g
s
.38657 .6276 m .38925 .59038 L .42114 .59272 L p .707 .577 .707 r
F P
0 g
s
.38925 .59038 m .38657 .6276 L .35603 .62777 L p .707 .577 .707 r
F P
0 g
s
.44763 .66769 m .44417 .6862 L .41478 .67859 L p .707 .577 .707 r
F P
0 g
s
.41478 .67859 m .41824 .66008 L .44763 .66769 L p .707 .577 .707 r
F P
0 g
s
.35303 .66894 m .35649 .65044 L .38683 .65413 L p .707 .577 .707 r
F P
0 g
s
.38683 .65413 m .38337 .67264 L .35303 .66894 L p .707 .577 .707 r
F P
0 g
s
.41824 .66008 m .41478 .67859 L .38337 .67264 L p .707 .577 .707 r
F P
0 g
s
.38337 .67264 m .38683 .65413 L .41824 .66008 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
0UYF5@000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol50002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol0069oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00GWoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001KOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Moo`8000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Eoo`<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol01000FUIJEP001EYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0001Yoo`P004=oo`00E7oo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;Ool?0004FUH01000
FUIJEUYF2000>goo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Moo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000dOol005Aoo`04001JEUYF0005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF000017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01000<7oo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF
6@0015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00EGoo00<005YF00001EYF00<0
05YFFUH00eYF1P0000=JEP0000001`0015YF00<005YFFUH01EYF00<005YFFUH01P000eYF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<005YF00001EYF00<005YF00000`000UYF00<0
05YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0002FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Goo001EOol00`00FUH00005FUH20006FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eoo`03001J
EP0000=JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00@005YF001JEP80009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol01000FUH0000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol200000eYF001JEP03FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF000]Ool005Eoo`04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eo
o`04001JEUYF0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60005FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00>Woo5`0017oo
00<005YFFUH00`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool003Ioo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00<goo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool0
035oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH?0006FUH00`00FUIJEP080003
FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF00000`000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01P000eYF00@005YFFUH0
02eoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000`000UYF00<007ooOol0:goo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00P000UYF00<005YFFUH015YF5`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00
FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH300000eYF001JEP02FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF20000UYF00<005YF00001EYF3P0015YF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP06001J
EP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF1P0015YF1P00
0eYF00<005YFFUH00UYF1P001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<0009JEP8002ioo`00;7oo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPX000=JEP03001JEUYF00QJEP@00003FUH005YF00=JEP03
001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<002moo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEP0001<0009JEP<000=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002ioo`00;7oo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000=JEP`000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH60002FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0
000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH70006Ool50005Ool600000eYF001JEP03
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YF00000`000eYF00@005YF
FUIJEQD0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH00UYF20003goo10000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00@005YFFUH000=JEP<000MJEP03001JEUYF
00EJEP03001JEP0000@000=JEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00=JEP04
001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP02FUH5000015YF001JEP005goo10001EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00D0
05YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001J
EUYF009JEP04001JEUYF0002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP030005FUH01000FUIJEP000goo2@003Woo100000=JEP00FUH00eYF00@0
05YFFUH002eoo`00;7oo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000`0015YF2P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF0000009JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEPP000AJEP03001JEUYF
009JEPH000aoo`<000=JEP04001JEUYF000]Ool002aoo`@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEUYFFUH400000eYF00000004FUH01000FUIJEUYF3`0015YF00<0
05YFFUH01eYF00@005YFFUIJEP<00004FUH000000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01@00FUH00000FUH01@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`002goo0P0000EJEP00FUIJEP0002eoo`00;7oo00@005YFFUH0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEUYFFUH00002FUH01000
FUIJEUYF0`0000=JEP00FUH00eYF0`0000=JEP0000003P001eYF00<005YFFUH015YF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF100027oo0`000UYF00<007oo
Ool0:goo000/Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEP000004FUH01@00FUH005YF00001EYF00<0
05YF00002P0015YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH00000009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004Ool20002FUH200000eYF001oo`0/
Ool002aoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30004FUH01000FUIJEUYF0P000UYF00D005YF001JEP0000EJEPH000=JEP04001JEUYF
FUH300000eYF001JEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YFFUH00eYF3`0015YF00<005YF
FUH01UYF00@005YFFUIJEP@000AJEP04001JEP00000]Ool002aoo`04001JEUYF0005FUH00`00FUIJ
EP05FUH01000FUIJEUYF5P000eYF00<005YFFUH015YF1@0000=JEP00FUH015YF1P000eYF00<005YF
FUH015YF0`001EYF00<005YFFUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YF00000`0000=JEP00FUH00UYF2@0000=o
o`0000001@001UYF00<005YFFUH00eYF0P0015YF00@005YFFUH002eoo`00;Goo00<005YF00001EYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00EJEP03
001JEUYF00@000AJEPH000=JEP03001JEUYF00MJEP@00003FUH005YF00AJEP04001JEP00000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF0P001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF0P000eYF00@005YFFUH002eoo`00
;Woo0P0015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P001eYF00<005YFFUH015YF1@0000AJEP00000000AJEP03001JEUYF00UJEP04001JEP000004FUH0
0`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0eYF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00H005YF0000
05YF0002FUH00`00Oomoo`0[Ool002moo`D00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP09FUH01000FUIJEUYF0P000UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YFFUIJEP80009JEP03001oogoo
02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF1P002UYF00<005YFFUH00UYF
100000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
000000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEUYF000]Ool002aoo`800003FUH005YF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP0000<000IJEP03001JEUYF00MJEP04001JEUYFFUH?0002FUH2000015YF001JEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF0`00;Woo000/Ool01000FUIJ
EP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH400001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000eYF0P00;goo000/Ool01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YF001JEPH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000015YF
001JEP00;Woo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP@0009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1P0015YF10000UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001oo`020002FUH00`00
Oomoo`0[Ool002aoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00@005YF
FUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEPD000=JEP@000IJEP03001JEUYF
00D00003FUH005YF00MJEP04001JEUYFFUH50004Ool01000FUIJEP00;Goo000/Ool01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00IJEQD000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000IJEP04001JEP000002
FUH00`00FUH000040002FUH00`00FUIJEP0500000eYF001JEP03FUH80009Ool01000FUIJEP00;Goo
000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF6P000eYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005FUH01000FUIJ
EUYF0`0000=JEP00Ool00goo40004Woo0P00;Woo000/Ool01000FUIJEP001EYF00@005YFFUIJEPP0
00=JEP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00=JEPH0009JEP05001JEP00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP02FUH200000eYF
001oo`09Ool3000IOol2000^Ool002aoo`04001JEUYF0003FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP0500000eYF001JEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000AJEP00FUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP020002FUH00`00FUIJEP02FUH00`00FUH0
000WOol2000^Ool002aoo`03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJEP04001JEUYF
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH00004FUH01000FUIJEP009Goo00<005YF
0000;Woo000/Ool40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`001EYF0`000eYF00@005YFFUH002Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP05001JEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005
FUH01000FUH000000UYF00@005YFFUH002Aoo`04001JEUYF000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<0004FUH00`00
FUIJEP05FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0000015YF00@005YFFUIJ
EP800004FUH005YF000ROol30002FUH00`00Oomoo`0/Ool002aoo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800004Ool005YF0005FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP05FUH4
000POol20002FUH00`00FUH0000_Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000=oo`03001JEP0000EJ
EP03001JEUYF009JEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00<000AJEP03001JEUYF00=JEP03001JEP0000D000MJEP03001JEP0000<001]oo`8000AJEP80
031oo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
4P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF000017oo0P00
1UYF00<005YFFUH00eYF1`0047oo100000=JEP00FUH00eYF0P00<7oo000cOol50003FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH20005FUH00`00FUH00004Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0005
FUH00`00FUIJEP02FUH00`00Oomoo`0_Ool003Qooa<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP800003FUH005YF009JEP8000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH000040000
15YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80039oo`00=7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP800003FUH005YF00L000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00000dOol002moo`D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP800004FUH005YF0003FUH70002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@00=Woo000]Ool200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00D0009o
o`L000AJEP03001JEUYF009JEPP003]oo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEQ`000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool90013Ool002eoo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP04001JEUYFFUH2001FOol002eoo`04001JEUYF0005FUH00`00FUIJEP02FUH800000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00001`000eYF00<005YFFUH00UYF0P00EGoo000]Ool01000FUIJEP000eYF
1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001Goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF1P000UYF0P00EGoo000]Ool80007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH9000DOol00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF001JEP05FUH00`00FUIJEP0200000goo00000002001EOol002eooa`001ioo`80
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH30006Ool2001DOol006Uoo`04
001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF0P001goo0`00E7oo001ZOol30008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUH000001EYF00<005YF00000`001goo0P0000=JEP000000E7oo001/Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40003
FUH6000:Ool00`00FUIJEP02FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00/000ioo`<000AJEP03001oogoo
059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`004Goo0P00
0UYF00<005YFFUH00UYF00<007ooOol0DWoo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP060006Ool5000?Ool20005FUH01000FUIJEP00EGoo001nOolO000<Ool5000=Ool2
00000eYF001JEP04FUH3001FOol008ioo`80009JEP03001oogoo01Eoo`<000]oo`<000=JEP03001J
EUYF00=JEP03001oogoo05Ioo`00SWoo00@005YF000002=oo`<000IJEP03001JEUYF009JEP03001o
ogoo05Moo`00SWoo00@005YF0000025oo`800003FUH005YF00MJEP04001JEP00001JOol008ioo`03
001JEP00008001eoo`<000=JEP03001JEUYF00IJEP8005aoo`00Sgoo00AJEP00001JEP8001Eoo`H0
00MJEP03001JEUYF00AJEP8005eoo`00Sgoo00<005YF00000eYF5@0015YF00<005YFFUH01UYF00<0
05YFFUH01000Ggoo002?Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF1000Hgoo002@Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH2001WOol0099oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP00008006Uoo`00U7oo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1P00K7oo002FOolE001bOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57907 .74689 m .58251 .69108 L .55219 .68687 L p .707 .577 .707 r
F P
0 g
s
.58251 .69108 m .57907 .74689 L .61098 .74876 L p .707 .577 .707 r
F P
0 g
s
.61098 .74876 m .61442 .69294 L .58251 .69108 L p .707 .577 .707 r
F P
0 g
s
.61442 .69294 m .61098 .74876 L .64135 .74809 L p .707 .577 .707 r
F P
0 g
s
.64135 .74809 m .64479 .69228 L .61442 .69294 L p .707 .577 .707 r
F P
0 g
s
.54874 .74269 m .55219 .68687 L .52641 .68073 L p .707 .577 .707 r
F P
0 g
s
.55219 .68687 m .54874 .74269 L .57907 .74689 L p .707 .577 .707 r
F P
0 g
s
.64479 .69228 m .64135 .74809 L .6672 .74497 L p .707 .577 .707 r
F P
0 g
s
.6672 .74497 m .67065 .68915 L .64479 .69228 L p .707 .577 .707 r
F P
0 g
s
.60419 .81318 m .59998 .77674 L .56834 .77916 L p .707 .577 .707 r
F P
0 g
s
.59998 .77674 m .60419 .81318 L .6352 .80782 L p .707 .577 .707 r
F P
0 g
s
.6352 .80782 m .63099 .77137 L .59998 .77674 L p .707 .577 .707 r
F P
0 g
s
.52641 .68073 m .52297 .73655 L .54874 .74269 L p .707 .577 .707 r
F P
0 g
s
.57255 .8156 m .56834 .77916 L .53917 .77839 L p .707 .577 .707 r
F P
0 g
s
.56834 .77916 m .57255 .8156 L .60419 .81318 L p .707 .577 .707 r
F P
0 g
s
.63099 .77137 m .6352 .80782 L .66253 .80002 L p .707 .577 .707 r
F P
0 g
s
.66253 .80002 m .65832 .76358 L .63099 .77137 L p .707 .577 .707 r
F P
0 g
s
.52297 .73655 m .52641 .68073 L .5077 .67326 L p .707 .577 .707 r
F P
0 g
s
.67065 .68915 m .6672 .74497 L .68601 .73969 L p .707 .577 .707 r
F P
0 g
s
.68601 .73969 m .68945 .68387 L .67065 .68915 L p .707 .577 .707 r
F P
0 g
s
.53917 .77839 m .54338 .81483 L .57255 .8156 L p .707 .577 .707 r
F P
0 g
s
.54338 .81483 m .53917 .77839 L .51533 .7745 L p .707 .577 .707 r
F P
0 g
s
.65832 .76358 m .66253 .80002 L .68353 .79056 L p .707 .577 .707 r
F P
0 g
s
.68353 .79056 m .67932 .75412 L .65832 .76358 L p .707 .577 .707 r
F P
0 g
s
.5077 .67326 m .50426 .72907 L .52297 .73655 L p .707 .577 .707 r
F P
0 g
s
.60882 .85872 m .60347 .8414 L .57308 .84806 L p .707 .577 .707 r
F P
0 g
s
.60347 .8414 m .60882 .85872 L .63908 .84861 L p .707 .577 .707 r
F P
0 g
s
.63908 .84861 m .63373 .83129 L .60347 .8414 L p .707 .577 .707 r
F P
0 g
s
.63373 .83129 m .63908 .84861 L .66624 .83605 L p .707 .577 .707 r
F P
0 g
s
.66624 .83605 m .6609 .81873 L .63373 .83129 L p .707 .577 .707 r
F P
0 g
s
.57308 .84806 m .57843 .86538 L .60882 .85872 L p .707 .577 .707 r
F P
0 g
s
.51533 .7745 m .51954 .81095 L .54338 .81483 L p .707 .577 .707 r
F P
0 g
s
.57843 .86538 m .57308 .84806 L .54553 .85062 L p .707 .577 .707 r
F P
0 g
s
.50426 .72907 m .5077 .67326 L .4979 .66518 L p .707 .577 .707 r
F P
0 g
s
.68945 .68387 m .68601 .73969 L .69594 .73276 L p .707 .577 .707 r
F P
0 g
s
.69594 .73276 m .69938 .67695 L .68945 .68387 L p .707 .577 .707 r
F P
0 g
s
.6609 .81873 m .66624 .83605 L .68765 .82226 L p .707 .577 .707 r
F P
0 g
s
.68765 .82226 m .68231 .80494 L .6609 .81873 L p .707 .577 .707 r
F P
0 g
s
.54553 .85062 m .55088 .86794 L .57843 .86538 L p .707 .577 .707 r
F P
0 g
s
.51954 .81095 m .51533 .7745 L .49913 .76789 L p .707 .577 .707 r
F P
0 g
s
.67932 .75412 m .68353 .79056 L .69613 .78037 L p .707 .577 .707 r
F P
0 g
s
.69613 .78037 m .69192 .74392 L .67932 .75412 L p .707 .577 .707 r
F P
0 g
s
.4979 .66518 m .49446 .721 L .50426 .72907 L p .707 .577 .707 r
F P
0 g
s
.55088 .86794 m .54553 .85062 L .52352 .84883 L p .707 .577 .707 r
F P
0 g
s
.49913 .76789 m .50334 .80433 L .51954 .81095 L p .707 .577 .707 r
F P
0 g
s
.52352 .84883 m .52887 .86615 L .55088 .86794 L p .707 .577 .707 r
F P
0 g
s
.68231 .80494 m .68765 .82226 L .70122 .80859 L p .707 .577 .707 r
F P
0 g
s
.70122 .80859 m .69587 .79128 L .68231 .80494 L p .707 .577 .707 r
F P
0 g
s
.49446 .721 m .4979 .66518 L .49797 .6573 L p .708 .578 .707 r
F P
0 g
s
.69938 .67695 m .69594 .73276 L .696 .72488 L p .708 .578 .707 r
F P
0 g
s
.696 .72488 m .69944 .66907 L .69938 .67695 L p .708 .578 .707 r
F P
0 g
s
.50334 .80433 m .49913 .76789 L .49218 .75919 L p .707 .577 .707 r
F P
0 g
s
.52887 .86615 m .52352 .84883 L .50921 .84287 L p .707 .577 .707 r
F P
0 g
s
.69236 .7477 m .69613 .78037 L .69843 .77269 L p .707 .577 .707 r
F P
0 g
s
.7056 .79639 m .70025 .77907 L .69587 .79128 L p .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69503 .76952 L .69975 .77816 L p .707 .577 .707 r
F P
0 g
s
.69975 .77816 m .70025 .77907 L p .70027 .78029 L .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69975 .77816 L .70027 .78029 L .707 .577 .707 r
F
.69192 .74392 m .69236 .7477 L p .6991 .77043 L F P
0 g
s
.69843 .77269 m .6991 .77043 L p .69236 .7477 L .707 .577 .707 r
F P
0 g
s
.6991 .77043 m .69489 .73399 L .69192 .74392 L p .707 .577 .707 r
F P
0 g
s
.49797 .6573 m .49453 .71312 L .49446 .721 L p .708 .578 .707 r
F P
0 g
s
.50921 .84287 m .51456 .86019 L .52887 .86615 L p .707 .577 .707 r
F P
0 g
s
.49218 .75919 m .49639 .79563 L .50334 .80433 L p .707 .577 .707 r
F P
0 g
s
.69587 .79128 m .70122 .80859 L .7056 .79639 L p .707 .577 .707 r
F P
0 g
s
.49453 .71312 m .49797 .6573 L .50789 .65038 L p .707 .577 .707 r
F P
0 g
s
.50789 .65038 m .50445 .7062 L .49453 .71312 L p .707 .577 .707 r
F P
0 g
s
.49515 .74925 m .49936 .7857 L .49639 .79563 L p .707 .577 .707 r
F P
0 g
s
.49936 .7857 m .49515 .74925 L .50775 .73906 L p .707 .577 .707 r
F P
0 g
s
.50775 .73906 m .51196 .7755 L .49936 .7857 L p .707 .577 .707 r
F P
0 g
s
.50166 .82192 m .50166 .32003 L .45701 .31828 L p .707 .577 .707 r
F P
0 g
s
.50445 .7062 m .50789 .65038 L .5267 .6451 L p .707 .577 .707 r
F P
0 g
s
.51456 .86019 m .50921 .84287 L .50398 .83332 L p .707 .577 .707 r
F P
0 g
s
.50398 .83332 m .50933 .85064 L .51456 .86019 L p .707 .577 .707 r
F P
0 g
s
.50933 .85064 m .50398 .83332 L .50837 .82112 L p .707 .577 .707 r
F P
0 g
s
.50837 .82112 m .51372 .83844 L .50933 .85064 L p .707 .577 .707 r
F P
0 g
s
.5267 .6451 m .52326 .70091 L .50445 .7062 L p .707 .577 .707 r
F P
0 g
s
.52326 .70091 m .5267 .6451 L .55255 .64197 L p .707 .577 .707 r
F P
0 g
s
.51196 .7755 m .50775 .73906 L .52875 .7296 L p .707 .577 .707 r
F P
0 g
s
.51372 .83844 m .50837 .82112 L .52193 .80745 L p .707 .577 .707 r
F P
0 g
s
.55255 .64197 m .54911 .69779 L .52326 .70091 L p .707 .577 .707 r
F P
0 g
s
.52193 .80745 m .52728 .82477 L .51372 .83844 L p .707 .577 .707 r
F P
0 g
s
.52875 .7296 m .53296 .76604 L .51196 .7755 L p .707 .577 .707 r
F P
0 g
s
.53296 .76604 m .52875 .7296 L .55609 .7218 L p .707 .577 .707 r
F P
0 g
s
.52728 .82477 m .52193 .80745 L .54334 .79366 L p .707 .577 .707 r
F P
0 g
s
.55609 .7218 m .5603 .75825 L .53296 .76604 L p .707 .577 .707 r
F P
0 g
s
.54334 .79366 m .54869 .81098 L .52728 .82477 L p .707 .577 .707 r
F P
0 g
s
.54869 .81098 m .54334 .79366 L .5705 .7811 L p .707 .577 .707 r
F P
0 g
s
.50166 .32003 m .50166 .82192 L .54615 .81989 L p .707 .577 .707 r
F P
0 g
s
.54615 .81989 m .54615 .318 L .50166 .32003 L p .707 .577 .707 r
F P
0 g
s
.45701 .82016 m .45701 .31828 L .41657 .3129 L p .707 .577 .707 r
F P
0 g
s
.49639 .79563 m .49218 .75919 L .49515 .74925 L p .707 .577 .707 r
F P
0 g
s
.45701 .31828 m .45701 .82016 L .50166 .82192 L p .707 .577 .707 r
F P
0 g
s
.54911 .69779 m .55255 .64197 L .58292 .64131 L p .707 .577 .707 r
F P
0 g
s
.58292 .64131 m .57948 .69712 L .54911 .69779 L p .707 .577 .707 r
F P
0 g
s
.5603 .75825 m .55609 .7218 L .58709 .71643 L p .707 .577 .707 r
F P
0 g
s
.58709 .71643 m .5913 .75288 L .5603 .75825 L p .707 .577 .707 r
F P
0 g
s
.5705 .7811 m .57585 .79842 L .54869 .81098 L p .707 .577 .707 r
F P
0 g
s
.57585 .79842 m .5705 .7811 L .60076 .77099 L p .707 .577 .707 r
F P
0 g
s
.60076 .77099 m .60611 .78831 L .57585 .79842 L p .707 .577 .707 r
F P
0 g
s
.54615 .318 m .54615 .81989 L .58612 .81427 L p .707 .577 .707 r
F P
0 g
s
.57948 .69712 m .58292 .64131 L .61483 .64317 L p .707 .577 .707 r
F P
0 g
s
.61483 .64317 m .61139 .69899 L .57948 .69712 L p .707 .577 .707 r
F P
0 g
s
.58612 .81427 m .58612 .31238 L .54615 .318 L p .707 .577 .707 r
F P
0 g
s
.69944 .66907 m .696 .72488 L .6862 .71681 L p .707 .577 .707 r
F P
0 g
s
.6862 .71681 m .68964 .66099 L .69944 .66907 L p .707 .577 .707 r
F P
0 g
s
.69489 .73399 m .6991 .77043 L .69215 .76173 L p .707 .577 .707 r
F P
0 g
s
.69215 .76173 m .68794 .72529 L .69489 .73399 L p .707 .577 .707 r
F P
0 g
s
.41657 .81479 m .41657 .3129 L .38429 .30444 L p .707 .577 .707 r
F P
0 g
s
.41657 .3129 m .41657 .81479 L .45701 .82016 L p .707 .577 .707 r
F P
0 g
s
.70025 .77907 m .7056 .79639 L .70038 .78684 L p .707 .577 .707 r
F P
0 g
s
.61873 .71402 m .62294 .75046 L .5913 .75288 L p .707 .577 .707 r
F P
0 g
s
.5913 .75288 m .58709 .71643 L .61873 .71402 L p .707 .577 .707 r
F P
0 g
s
.63115 .76434 m .6365 .78165 L .60611 .78831 L p .707 .577 .707 r
F P
0 g
s
.60611 .78831 m .60076 .77099 L .63115 .76434 L p .707 .577 .707 r
F P
0 g
s
.58612 .31238 m .58612 .81427 L .61767 .80561 L p .707 .577 .707 r
F P
0 g
s
.64516 .64738 m .64172 .7032 L .61139 .69899 L p .707 .577 .707 r
F P
0 g
s
.61139 .69899 m .61483 .64317 L .64516 .64738 L p .707 .577 .707 r
F P
0 g
s
.61767 .80561 m .61767 .30372 L .58612 .31238 L p .707 .577 .707 r
F P
0 g
s
.24053 .71615 m .24194 .66172 L .21156 .65773 L p .707 .577 .707 r
F P
0 g
s
.24194 .66172 m .24053 .71615 L .27249 .71691 L p .707 .577 .707 r
F P
0 g
s
.27249 .71691 m .2739 .66247 L .24194 .66172 L p .707 .577 .707 r
F P
0 g
s
.2739 .66247 m .27249 .71691 L .30289 .71436 L p .707 .577 .707 r
F P
0 g
s
.30289 .71436 m .30431 .65992 L .2739 .66247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68964 .66099 m .6862 .71681 L .6675 .70934 L p .707 .577 .707 r
F P
0 g
s
.6675 .70934 m .67094 .65352 L .68964 .66099 L p .707 .577 .707 r
F P
0 g
s
.21015 .71217 m .21156 .65773 L .18573 .65091 L p .707 .577 .707 r
F P
0 g
s
.21156 .65773 m .21015 .71217 L .24053 .71615 L p .707 .577 .707 r
F P
0 g
s
.30431 .65992 m .30289 .71436 L .32877 .70875 L p .707 .577 .707 r
F P
0 g
s
.32877 .70875 m .33019 .65432 L .30431 .65992 L p .707 .577 .707 r
F P
0 g
s
.68794 .72529 m .69215 .76173 L .67596 .75512 L p .707 .577 .707 r
F P
0 g
s
.67596 .75512 m .67175 .71867 L .68794 .72529 L p .707 .577 .707 r
F P
0 g
s
.38429 .80633 m .38429 .30444 L .36334 .29371 L p .707 .577 .707 r
F P
0 g
s
.38429 .30444 m .38429 .80633 L .41657 .81479 L p .707 .577 .707 r
F P
0 g
s
.69503 .76952 m .70038 .78684 L .68606 .78088 L p .707 .577 .707 r
F P
0 g
s
.68606 .78088 m .68071 .76356 L .69503 .76952 L p .707 .577 .707 r
F P
0 g
s
.6479 .71479 m .65211 .75123 L .62294 .75046 L p .707 .577 .707 r
F P
0 g
s
.62294 .75046 m .61873 .71402 L .6479 .71479 L p .707 .577 .707 r
F P
0 g
s
.6587 .76177 m .66405 .77909 L .6365 .78165 L p .707 .577 .707 r
F P
0 g
s
.6365 .78165 m .63115 .76434 L .6587 .76177 L p .707 .577 .707 r
F P
0 g
s
.61767 .30372 m .61767 .80561 L .63769 .79475 L p .707 .577 .707 r
F P
0 g
s
.63769 .79475 m .63769 .29286 L .61767 .30372 L p .707 .577 .707 r
F P
0 g
s
.26441 .75817 m .26276 .72012 L .23095 .72107 L p .707 .577 .707 r
F P
0 g
s
.26276 .72012 m .26441 .75817 L .29555 .75586 L p .707 .577 .707 r
F P
0 g
s
.29555 .75586 m .2939 .7178 L .26276 .72012 L p .707 .577 .707 r
F P
0 g
s
.2326 .75912 m .23095 .72107 L .20159 .72056 L p .707 .577 .707 r
F P
0 g
s
.23095 .72107 m .2326 .75912 L .26441 .75817 L p .707 .577 .707 r
F P
0 g
s
.18432 .70534 m .18573 .65091 L .16698 .64191 L p .707 .577 .707 r
F P
0 g
s
.18573 .65091 m .18432 .70534 L .21015 .71217 L p .707 .577 .707 r
F P
0 g
s
.33019 .65432 m .32877 .70875 L .34759 .70064 L p .707 .577 .707 r
F P
0 g
s
.34759 .70064 m .349 .64621 L .33019 .65432 L p .707 .577 .707 r
F P
0 g
s
.67094 .65352 m .6675 .70934 L .64172 .7032 L p .707 .577 .707 r
F P
0 g
s
.64172 .7032 m .64516 .64738 L .67094 .65352 L p .707 .577 .707 r
F P
0 g
s
.2319 .7645 m .234 .78355 L .26555 .7798 L p .707 .577 .707 r
F P
0 g
s
.26555 .7798 m .26345 .76074 L .2319 .7645 L p .707 .577 .707 r
F P
0 g
s
.26345 .76074 m .26555 .7798 L .29673 .77687 L p .707 .577 .707 r
F P
0 g
s
.2939 .7178 m .29555 .75586 L .32298 .75241 L p .707 .577 .707 r
F P
0 g
s
.32298 .75241 m .32133 .71435 L .2939 .7178 L p .707 .577 .707 r
F P
0 g
s
.29673 .77687 m .29462 .75781 L .26345 .76074 L p .707 .577 .707 r
F P
0 g
s
.20159 .72056 m .20324 .75861 L .2326 .75912 L p .707 .577 .707 r
F P
0 g
s
.20307 .76872 m .20517 .78778 L .234 .78355 L p .707 .577 .707 r
F P
0 g
s
.234 .78355 m .2319 .7645 L .20307 .76872 L p .707 .577 .707 r
F P
0 g
s
.29462 .75781 m .29673 .77687 L .32448 .77506 L p .707 .577 .707 r
F P
0 g
s
.32448 .77506 m .32238 .75601 L .29462 .75781 L p .707 .577 .707 r
F P
0 g
s
.67175 .71867 m .67596 .75512 L .65211 .75123 L p .707 .577 .707 r
F P
0 g
s
.65211 .75123 m .6479 .71479 L .67175 .71867 L p .707 .577 .707 r
F P
0 g
s
.20324 .75861 m .20159 .72056 L .17756 .71864 L p .707 .577 .707 r
F P
0 g
s
.17756 .71864 m .1792 .7567 L .20324 .75861 L p .707 .577 .707 r
F P
0 g
s
.32133 .71435 m .32298 .75241 L .34401 .74816 L p .707 .577 .707 r
F P
0 g
s
.34401 .74816 m .34236 .7101 L .32133 .71435 L p .707 .577 .707 r
F P
0 g
s
.17977 .77299 m .18188 .79205 L .20517 .78778 L p .707 .577 .707 r
F P
0 g
s
.20517 .78778 m .20307 .76872 L .17977 .77299 L p .707 .577 .707 r
F P
0 g
s
.16698 .64191 m .16557 .69635 L .18432 .70534 L p .707 .577 .707 r
F P
0 g
s
.68071 .76356 m .68606 .78088 L .66405 .77909 L p .707 .577 .707 r
F P
0 g
s
.66405 .77909 m .6587 .76177 L .68071 .76356 L p .707 .577 .707 r
F P
0 g
s
.32238 .75601 m .32448 .77506 L .34609 .77455 L p .707 .577 .707 r
F P
0 g
s
.16557 .69635 m .16698 .64191 L .15715 .63163 L p .707 .577 .707 r
F P
0 g
s
.34609 .77455 m .34399 .75549 L .32238 .75601 L p .707 .577 .707 r
F P
0 g
s
.349 .64621 m .34759 .70064 L .3575 .69082 L p .707 .577 .707 r
F P
0 g
s
.3575 .69082 m .35892 .63639 L .349 .64621 L p .707 .577 .707 r
F P
0 g
s
.35735 .75633 m .35945 .77538 L .36324 .77748 L p .707 .577 .707 r
F P
0 g
s
.36324 .77748 m .36114 .75842 L .35735 .75633 L p .707 .577 .707 r
F P
0 g
s
.34399 .75549 m .34609 .77455 L .35945 .77538 L p .707 .577 .707 r
F P
0 g
s
.35945 .77538 m .35735 .75633 L .34399 .75549 L p .707 .577 .707 r
F P
0 g
s
.36114 .75842 m .36324 .77748 L .3571 .78064 L p .707 .577 .707 r
F P
0 g
s
.36334 .7956 m .36334 .29371 L .35576 .28178 L p .707 .577 .707 r
F P
0 g
s
.36334 .29371 m .36334 .7956 L .38429 .80633 L p .707 .577 .707 r
F P
0 g
s
.1792 .7567 m .17756 .71864 L .16119 .71551 L p .707 .577 .707 r
F P
0 g
s
.63769 .29286 m .63769 .79475 L .64423 .78277 L p .707 .577 .707 r
F P
0 g
s
.64423 .78277 m .64423 .28088 L .63769 .29286 L p .707 .577 .707 r
F P
0 g
s
.16119 .71551 m .16284 .75356 L .1792 .7567 L p .707 .577 .707 r
F P
0 g
s
.1643 .7769 m .1664 .79595 L .18188 .79205 L p .707 .577 .707 r
F P
0 g
s
.18188 .79205 m .17977 .77299 L .1643 .7769 L p .707 .577 .707 r
F P
0 g
s
.34236 .7101 m .34401 .74816 L .35658 .74353 L p .707 .577 .707 r
F P
0 g
s
.35658 .74353 m .35493 .70547 L .34236 .7101 L p .707 .577 .707 r
F P
0 g
s
.15715 .63163 m .15573 .68606 L .16557 .69635 L p .707 .577 .707 r
F P
0 g
s
.15573 .68606 m .15715 .63163 L .15719 .62105 L p .708 .578 .707 r
F P
0 g
s
.35892 .63639 m .3575 .69082 L .35754 .68025 L p .708 .578 .707 r
F P
0 g
s
.35754 .68025 m .35896 .62582 L .35892 .63639 L p .708 .578 .707 r
F P
0 g
s
.16284 .75356 m .16119 .71551 L .1541 .71146 L p .707 .577 .707 r
F P
0 g
s
.1541 .71146 m .15575 .74952 L .16284 .75356 L p .707 .577 .707 r
F P
0 g
s
.15816 .78005 m .16026 .79911 L .1664 .79595 L p .707 .577 .707 r
F P
0 g
s
.1664 .79595 m .1643 .7769 L .15816 .78005 L p .707 .577 .707 r
F P
0 g
s
.35493 .70547 m .35658 .74353 L .35946 .73896 L p .707 .577 .707 r
F P
0 g
s
.35946 .73896 m .35781 .70091 L .35493 .70547 L p .707 .577 .707 r
F P
0 g
s
.15719 .62105 m .15577 .67549 L .15573 .68606 L p .708 .578 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35896 .62582 m .35754 .68025 L .3477 .66996 L p .707 .577 .707 r
F P
0 g
s
.3477 .66996 m .34912 .61553 L .35896 .62582 L p .707 .577 .707 r
F P
0 g
s
.35781 .70091 m .35946 .73896 L .35237 .73492 L p .707 .577 .707 r
F P
0 g
s
.35237 .73492 m .35072 .69686 L .35781 .70091 L p .707 .577 .707 r
F P
0 g
s
.3571 .78064 m .355 .76158 L .36114 .75842 L p .707 .577 .707 r
F P
0 g
s
.355 .76158 m .3571 .78064 L .3478 .78298 L p .707 .577 .707 r
F P
0 g
s
.3478 .78298 m .34163 .78454 L p .34797 .77366 L .707 .577 .707 r
F P
0 g
s
.34797 .77366 m .355 .76158 L .3478 .78298 L .707 .577 .707 r
F
.35919 .51443 m .35576 .78366 L .36334 .7956 L p F P
0 g
s
.35576 .35297 m .35665 .34174 L p .35576 .28178 L .707 .577 .707 r
F P
0 g
s
.35576 .78366 m .35576 .35297 L p .36231 .26979 L .707 .577 .707 r
F P
0 g
s
.35576 .35297 m .35576 .28178 L .35713 .27928 L p .707 .577 .707 r
F P
0 g
s
.35713 .27928 m .36231 .26979 L p .35576 .35297 L .707 .577 .707 r
F P
0 g
s
.64423 .28088 m .64423 .78277 L .63666 .77083 L p .707 .577 .707 r
F P
0 g
s
.63666 .77083 m .63666 .26894 L .64423 .28088 L p .707 .577 .707 r
F P
0 g
s
.15577 .67549 m .15719 .62105 L .1671 .61123 L p .707 .577 .707 r
F P
0 g
s
.15575 .74952 m .1541 .71146 L .15699 .7069 L p .707 .577 .707 r
F P
0 g
s
.15699 .7069 m .15863 .74495 L .15575 .74952 L p .707 .577 .707 r
F P
0 g
s
.16196 .78215 m .16406 .80121 L .16026 .79911 L p .707 .577 .707 r
F P
0 g
s
.16026 .79911 m .15816 .78005 L .16196 .78215 L p .707 .577 .707 r
F P
0 g
s
.1671 .61123 m .16568 .66567 L .15577 .67549 L p .707 .577 .707 r
F P
0 g
s
.16568 .66567 m .1671 .61123 L .18592 .60312 L p .707 .577 .707 r
F P
0 g
s
.34912 .61553 m .3477 .66996 L .32895 .66097 L p .707 .577 .707 r
F P
0 g
s
.32895 .66097 m .33037 .60653 L .34912 .61553 L p .707 .577 .707 r
F P
0 g
s
.36231 .77168 m .36231 .26979 L .38233 .25894 L p .707 .577 .707 r
F P
0 g
s
.36231 .26979 m .36231 .77168 L .35576 .78366 L p .707 .577 .707 r
F P
0 g
s
.63666 .26894 m .63666 .77083 L .61571 .76011 L p .707 .577 .707 r
F P
0 g
s
.61571 .76011 m .61571 .25822 L .63666 .26894 L p .707 .577 .707 r
F P
0 g
s
.15863 .74495 m .15699 .7069 L .16956 .70227 L p .707 .577 .707 r
F P
0 g
s
.16956 .70227 m .1712 .74032 L .15863 .74495 L p .707 .577 .707 r
F P
0 g
s
.17531 .78298 m .17741 .80204 L .16406 .80121 L p .707 .577 .707 r
F P
0 g
s
.16406 .80121 m .16196 .78215 L .17531 .78298 L p .707 .577 .707 r
F P
0 g
s
.18592 .60312 m .1845 .65756 L .16568 .66567 L p .707 .577 .707 r
F P
0 g
s
.35072 .69686 m .35237 .73492 L .33601 .73178 L p .707 .577 .707 r
F P
0 g
s
.33601 .73178 m .33436 .69373 L .35072 .69686 L p .707 .577 .707 r
F P
0 g
s
.1845 .65756 m .18592 .60312 L .21179 .59752 L p .707 .577 .707 r
F P
0 g
s
.33037 .60653 m .32895 .66097 L .30312 .65414 L p .707 .577 .707 r
F P
0 g
s
.30312 .65414 m .30454 .59971 L .33037 .60653 L p .707 .577 .707 r
F P
0 g
s
.34163 .78454 m .33953 .76548 L .355 .76158 L p .707 .577 .707 r
F P
0 g
s
.1712 .74032 m .16956 .70227 L .19058 .69802 L p .707 .577 .707 r
F P
0 g
s
.21038 .65195 m .21179 .59752 L .2422 .59497 L p .707 .577 .707 r
F P
0 g
s
.21179 .59752 m .21038 .65195 L .1845 .65756 L p .707 .577 .707 r
F P
0 g
s
.38233 .25894 m .38233 .76083 L .36231 .77168 L p .707 .577 .707 r
F P
0 g
s
.38233 .76083 m .38233 .25894 L .41387 .25028 L p .707 .577 .707 r
F P
0 g
s
.30454 .59971 m .30312 .65414 L .27274 .65016 L p .707 .577 .707 r
F P
0 g
s
.27274 .65016 m .27416 .59572 L .30454 .59971 L p .707 .577 .707 r
F P
0 g
s
.19058 .69802 m .19223 .73607 L .1712 .74032 L p .707 .577 .707 r
F P
0 g
s
.61571 .25822 m .61571 .76011 L .58343 .75165 L p .707 .577 .707 r
F P
0 g
s
.58343 .75165 m .58343 .24976 L .61571 .25822 L p .707 .577 .707 r
F P
0 g
s
.19693 .78247 m .19903 .80153 L .17741 .80204 L p .707 .577 .707 r
F P
0 g
s
.17741 .80204 m .17531 .78298 L .19693 .78247 L p .707 .577 .707 r
F P
0 g
s
.75921 .65242 m .7578 .59596 L .72584 .59672 L p .707 .577 .707 r
F P
0 g
s
.7578 .59596 m .75921 .65242 L .78962 .64968 L p .707 .577 .707 r
F P
0 g
s
.78962 .64968 m .7882 .59322 L .7578 .59596 L p .707 .577 .707 r
F P
0 g
s
.72726 .65318 m .72584 .59672 L .69546 .59542 L p .707 .577 .707 r
F P
0 g
s
.72584 .59672 m .72726 .65318 L .75921 .65242 L p .707 .577 .707 r
F P
0 g
s
.33436 .69373 m .33601 .73178 L .31197 .72987 L p .707 .577 .707 r
F P
0 g
s
.31197 .72987 m .31032 .69181 L .33436 .69373 L p .707 .577 .707 r
F P
0 g
s
.24078 .6494 m .2422 .59497 L .27416 .59572 L p .707 .577 .707 r
F P
0 g
s
.2422 .59497 m .24078 .6494 L .21038 .65195 L p .707 .577 .707 r
F P
0 g
s
.27416 .59572 m .27274 .65016 L .24078 .6494 L p .707 .577 .707 r
F P
0 g
s
.33953 .76548 m .34163 .78454 L .31834 .78881 L p .707 .577 .707 r
F P
0 g
s
.31834 .78881 m .31624 .76976 L .33953 .76548 L p .707 .577 .707 r
F P
0 g
s
.7882 .59322 m .78962 .64968 L .8155 .64521 L p .707 .577 .707 r
F P
0 g
s
.8155 .64521 m .81408 .58876 L .7882 .59322 L p .707 .577 .707 r
F P
0 g
s
.69688 .65188 m .69546 .59542 L .66963 .59219 L p .707 .577 .707 r
F P
0 g
s
.69546 .59542 m .69688 .65188 L .72726 .65318 L p .707 .577 .707 r
F P
0 g
s
.19223 .73607 m .19058 .69802 L .21801 .69457 L p .707 .577 .707 r
F P
0 g
s
.21801 .69457 m .21966 .73262 L .19223 .73607 L p .707 .577 .707 r
F P
0 g
s
.31032 .69181 m .31197 .72987 L .28261 .72936 L p .707 .577 .707 r
F P
0 g
s
.28261 .72936 m .28096 .6913 L .31032 .69181 L p .707 .577 .707 r
F P
0 g
s
.7492 .73184 m .75085 .6965 L .71904 .69411 L p .707 .577 .707 r
F P
0 g
s
.75085 .6965 m .7492 .73184 L .78034 .73029 L p .707 .577 .707 r
F P
0 g
s
.78034 .73029 m .78199 .69494 L .75085 .6965 L p .707 .577 .707 r
F P
0 g
s
.66963 .59219 m .67105 .64865 L .69688 .65188 L p .707 .577 .707 r
F P
0 g
s
.22468 .78066 m .22678 .79972 L .19903 .80153 L p .707 .577 .707 r
F P
0 g
s
.19903 .80153 m .19693 .78247 L .22468 .78066 L p .707 .577 .707 r
F P
0 g
s
.71739 .72945 m .71904 .69411 L .68968 .68801 L p .707 .577 .707 r
F P
0 g
s
.71904 .69411 m .71739 .72945 L .7492 .73184 L p .707 .577 .707 r
F P
0 g
s
.41387 .75217 m .41387 .25028 L .45384 .24466 L p .707 .577 .707 r
F P
0 g
s
.41387 .25028 m .41387 .75217 L .38233 .76083 L p .707 .577 .707 r
F P
0 g
s
.58343 .24976 m .58343 .75165 L .54299 .74627 L p .707 .577 .707 r
F P
0 g
s
.54299 .74627 m .54299 .24438 L .58343 .24976 L p .707 .577 .707 r
F P
0 g
s
.81408 .58876 m .8155 .64521 L .83431 .63947 L p .707 .577 .707 r
F P
0 g
s
.83431 .63947 m .8329 .58301 L .81408 .58876 L p .707 .577 .707 r
F P
0 g
s
.31624 .76976 m .31834 .78881 L .28951 .79303 L p .707 .577 .707 r
F P
0 g
s
.67105 .64865 m .66963 .59219 L .65088 .58734 L p .707 .577 .707 r
F P
0 g
s
.78199 .69494 m .78034 .73029 L .80777 .72494 L p .707 .577 .707 r
F P
0 g
s
.80777 .72494 m .80941 .68959 L .78199 .69494 L p .707 .577 .707 r
F P
0 g
s
.28951 .79303 m .2874 .77398 L .31624 .76976 L p .707 .577 .707 r
F P
0 g
s
.21966 .73262 m .21801 .69457 L .24915 .69225 L p .707 .577 .707 r
F P
0 g
s
.28096 .6913 m .28261 .72936 L .2508 .73031 L p .707 .577 .707 r
F P
0 g
s
.2508 .73031 m .24915 .69225 L .28096 .6913 L p .707 .577 .707 r
F P
0 g
s
.68803 .72336 m .68968 .68801 L .66564 .6788 L p .707 .577 .707 r
F P
0 g
s
.68968 .68801 m .68803 .72336 L .71739 .72945 L p .707 .577 .707 r
F P
0 g
s
.24915 .69225 m .2508 .73031 L .21966 .73262 L p .707 .577 .707 r
F P
0 g
s
.25586 .77773 m .25796 .79679 L .22678 .79972 L p .707 .577 .707 r
F P
0 g
s
.22678 .79972 m .22468 .78066 L .25586 .77773 L p .707 .577 .707 r
F P
0 g
s
.65088 .58734 m .65229 .6438 L .67105 .64865 L p .707 .577 .707 r
F P
0 g
s
.2874 .77398 m .28951 .79303 L .25796 .79679 L p .707 .577 .707 r
F P
0 g
s
.25796 .79679 m .25586 .77773 L .2874 .77398 L p .707 .577 .707 r
F P
0 g
s
.80941 .68959 m .80777 .72494 L .82879 .71632 L p .707 .577 .707 r
F P
0 g
s
.82879 .71632 m .83044 .68098 L .80941 .68959 L p .707 .577 .707 r
F P
0 g
s
.45384 .74655 m .45384 .24466 L .49833 .24263 L p .707 .577 .707 r
F P
0 g
s
.45384 .24466 m .45384 .74655 L .41387 .75217 L p .707 .577 .707 r
F P
0 g
s
.54299 .24438 m .54299 .74627 L .49833 .74452 L p .707 .577 .707 r
F P
0 g
s
.49833 .74452 m .49833 .24263 L .54299 .24438 L p .707 .577 .707 r
F P
0 g
s
.66564 .6788 m .66399 .71415 L .68803 .72336 L p .707 .577 .707 r
F P
0 g
s
.8329 .58301 m .83431 .63947 L .84423 .63301 L p .707 .577 .707 r
F P
0 g
s
.84423 .63301 m .84281 .57655 L .8329 .58301 L p .707 .577 .707 r
F P
0 g
s
.49833 .24263 m .49833 .74452 L .45384 .74655 L p .707 .577 .707 r
F P
0 g
s
.66399 .71415 m .66564 .6788 L .64928 .66738 L p .707 .577 .707 r
F P
0 g
s
.65229 .6438 m .65088 .58734 L .64104 .58135 L p .707 .577 .707 r
F P
0 g
s
.74204 .79017 m .74414 .77464 L .71259 .7696 L p .707 .577 .707 r
F P
0 g
s
.74414 .77464 m .74204 .79017 L .77322 .78935 L p .707 .577 .707 r
F P
0 g
s
.77322 .78935 m .77532 .77382 L .74414 .77464 L p .707 .577 .707 r
F P
0 g
s
.71049 .78513 m .71259 .7696 L .68376 .75919 L p .707 .577 .707 r
F P
0 g
s
.71259 .7696 m .71049 .78513 L .74204 .79017 L p .707 .577 .707 r
F P
0 g
s
.77532 .77382 m .77322 .78935 L .80097 .78275 L p .707 .577 .707 r
F P
0 g
s
.80097 .78275 m .80307 .76722 L .77532 .77382 L p .707 .577 .707 r
F P
0 g
s
.64104 .58135 m .64246 .63781 L .65229 .6438 L p .707 .577 .707 r
F P
0 g
s
.83044 .68098 m .82879 .71632 L .84136 .70529 L p .707 .577 .707 r
F P
0 g
s
.84136 .70529 m .84301 .66994 L .83044 .68098 L p .707 .577 .707 r
F P
0 g
s
.68166 .77472 m .68376 .75919 L .66047 .74443 L p .707 .577 .707 r
F P
0 g
s
.68376 .75919 m .68166 .77472 L .71049 .78513 L p .707 .577 .707 r
F P
0 g
s
.64928 .66738 m .64763 .70273 L .66399 .71415 L p .707 .577 .707 r
F P
0 g
s
.64763 .70273 m .64928 .66738 L .64219 .65487 L p .707 .577 .707 r
F P
0 g
s
.66047 .74443 m .65837 .75996 L .68166 .77472 L p .707 .577 .707 r
F P
0 g
s
.80307 .76722 m .80097 .78275 L .82258 .77102 L p .707 .577 .707 r
F P
0 g
s
.82258 .77102 m .82469 .75548 L .80307 .76722 L p .707 .577 .707 r
F P
0 g
s
.84281 .57655 m .84423 .63301 L .84427 .62646 L p .706 .577 .707 r
F P
0 g
s
.84427 .62646 m .84285 .57001 L .84281 .57655 L p .706 .577 .707 r
F P
0 g
s
.64246 .63781 m .64104 .58135 L .64108 .5748 L p .706 .577 .707 r
F P
0 g
s
.65837 .75996 m .66047 .74443 L .64499 .72677 L p .707 .577 .707 r
F P
0 g
s
.64219 .65487 m .64054 .69021 L .64763 .70273 L p .707 .577 .707 r
F P
0 g
s
.84301 .66994 m .84136 .70529 L .84425 .6929 L p .707 .577 .707 r
F P
0 g
s
.84425 .6929 m .84589 .65756 L .84301 .66994 L p .707 .577 .707 r
F P
0 g
s
.64499 .72677 m .64289 .7423 L .65837 .75996 L p .707 .577 .707 r
F P
0 g
s
.64108 .5748 m .6425 .63126 L .64246 .63781 L p .706 .577 .707 r
F P
0 g
s
.82469 .75548 m .82258 .77102 L .83594 .75529 L p .707 .577 .707 r
F P
0 g
s
.83594 .75529 m .83804 .73976 L .82469 .75548 L p .707 .577 .707 r
F P
0 g
s
.64289 .7423 m .64499 .72677 L .63885 .70793 L p .707 .577 .707 r
F P
0 g
s
.64054 .69021 m .64219 .65487 L .64507 .64248 L p .707 .577 .707 r
F P
0 g
s
.84285 .57001 m .84427 .62646 L .83443 .62047 L p .707 .577 .707 r
F P
0 g
s
.83443 .62047 m .83302 .56401 L .84285 .57001 L p .707 .577 .707 r
F P
0 g
s
.6425 .63126 m .64108 .5748 L .651 .56834 L p .707 .577 .707 r
F P
0 g
s
.63885 .70793 m .63675 .72346 L .64289 .7423 L p .707 .577 .707 r
F P
0 g
s
.64507 .64248 m .64342 .67783 L .64054 .69021 L p .707 .577 .707 r
F P
0 g
s
.84589 .65756 m .84425 .6929 L .83716 .68039 L p .707 .577 .707 r
F P
0 g
s
.83716 .68039 m .83881 .64504 L .84589 .65756 L p .707 .577 .707 r
F P
0 g
s
.83804 .73976 m .83594 .75529 L .83974 .73713 L p .707 .577 .707 r
F P
0 g
s
.83974 .73713 m .84184 .7216 L .83804 .73976 L p .707 .577 .707 r
F P
0 g
s
.651 .56834 m .65241 .6248 L .6425 .63126 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63675 .72346 m .63885 .70793 L .64265 .68976 L p .707 .577 .707 r
F P
0 g
s
.64342 .67783 m .64507 .64248 L .65764 .63144 L p .707 .577 .707 r
F P
0 g
s
.42052 .62073 m .41708 .5656 L .38517 .56741 L p .707 .577 .707 r
F P
0 g
s
.41708 .5656 m .42052 .62073 L .45088 .61615 L p .707 .577 .707 r
F P
0 g
s
.45088 .61615 m .44744 .56102 L .41708 .5656 L p .707 .577 .707 r
F P
0 g
s
.38861 .62253 m .38517 .56741 L .35484 .56626 L p .707 .577 .707 r
F P
0 g
s
.38517 .56741 m .38861 .62253 L .42052 .62073 L p .707 .577 .707 r
F P
0 g
s
.64265 .68976 m .64055 .70529 L .63675 .72346 L p .707 .577 .707 r
F P
0 g
s
.83302 .56401 m .83443 .62047 L .81568 .61562 L p .707 .577 .707 r
F P
0 g
s
.81568 .61562 m .81426 .55916 L .83302 .56401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65241 .6248 m .651 .56834 L .66981 .5626 L p .707 .577 .707 r
F P
0 g
s
.44744 .56102 m .45088 .61615 L .47674 .60924 L p .707 .577 .707 r
F P
0 g
s
.47674 .60924 m .4733 .55411 L .44744 .56102 L p .707 .577 .707 r
F P
0 g
s
.84184 .7216 m .83974 .73713 L .8336 .71829 L p .707 .577 .707 r
F P
0 g
s
.8336 .71829 m .8357 .70276 L .84184 .7216 L p .707 .577 .707 r
F P
0 g
s
.35828 .62139 m .35484 .56626 L .32906 .56228 L p .707 .577 .707 r
F P
0 g
s
.35484 .56626 m .35828 .62139 L .38861 .62253 L p .707 .577 .707 r
F P
0 g
s
.65764 .63144 m .65599 .66679 L .64342 .67783 L p .707 .577 .707 r
F P
0 g
s
.83881 .64504 m .83716 .68039 L .82079 .66897 L p .707 .577 .707 r
F P
0 g
s
.82079 .66897 m .82244 .63362 L .83881 .64504 L p .707 .577 .707 r
F P
0 g
s
.66981 .5626 m .67123 .61906 L .65241 .6248 L p .707 .577 .707 r
F P
0 g
s
.64055 .70529 m .64265 .68976 L .65601 .67404 L p .707 .577 .707 r
F P
0 g
s
.40869 .67742 m .4129 .64025 L .38127 .63616 L p .707 .577 .707 r
F P
0 g
s
.4129 .64025 m .40869 .67742 L .4397 .6791 L p .707 .577 .707 r
F P
0 g
s
.4397 .6791 m .44391 .64193 L .4129 .64025 L p .707 .577 .707 r
F P
0 g
s
.37706 .67333 m .38127 .63616 L .3521 .63007 L p .707 .577 .707 r
F P
0 g
s
.38127 .63616 m .37706 .67333 L .40869 .67742 L p .707 .577 .707 r
F P
0 g
s
.65599 .66679 m .65764 .63144 L .67867 .62283 L p .707 .577 .707 r
F P
0 g
s
.4733 .55411 m .47674 .60924 L .49555 .60068 L p .707 .577 .707 r
F P
0 g
s
.49555 .60068 m .49211 .54555 L .4733 .55411 L p .707 .577 .707 r
F P
0 g
s
.32906 .56228 m .3325 .6174 L .35828 .62139 L p .707 .577 .707 r
F P
0 g
s
.65601 .67404 m .65391 .68957 L .64055 .70529 L p .707 .577 .707 r
F P
0 g
s
.3325 .6174 m .32906 .56228 L .31035 .55584 L p .707 .577 .707 r
F P
0 g
s
.81426 .55916 m .81568 .61562 L .78985 .61239 L p .707 .577 .707 r
F P
0 g
s
.78985 .61239 m .78843 .55593 L .81426 .55916 L p .707 .577 .707 r
F P
0 g
s
.44391 .64193 m .4397 .6791 L .46704 .67822 L p .707 .577 .707 r
F P
0 g
s
.46704 .67822 m .47125 .64105 L .44391 .64193 L p .707 .577 .707 r
F P
0 g
s
.67123 .61906 m .66981 .5626 L .69569 .55814 L p .707 .577 .707 r
F P
0 g
s
.3521 .63007 m .34789 .66725 L .37706 .67333 L p .707 .577 .707 r
F P
0 g
s
.39389 .71496 m .39924 .69681 L .36884 .68731 L p .707 .577 .707 r
F P
0 g
s
.39924 .69681 m .39389 .71496 L .42414 .72255 L p .707 .577 .707 r
F P
0 g
s
.42414 .72255 m .42949 .7044 L .39924 .69681 L p .707 .577 .707 r
F P
0 g
s
.8357 .70276 m .8336 .71829 L .81812 .70063 L p .707 .577 .707 r
F P
0 g
s
.81812 .70063 m .82022 .6851 L .8357 .70276 L p .707 .577 .707 r
F P
0 g
s
.34789 .66725 m .3521 .63007 L .32825 .62258 L p .707 .577 .707 r
F P
0 g
s
.36349 .70546 m .36884 .68731 L .34129 .67684 L p .707 .577 .707 r
F P
0 g
s
.36884 .68731 m .36349 .70546 L .39389 .71496 L p .707 .577 .707 r
F P
0 g
s
.82244 .63362 m .82079 .66897 L .79676 .65976 L p .707 .577 .707 r
F P
0 g
s
.79676 .65976 m .7984 .62441 L .82244 .63362 L p .707 .577 .707 r
F P
0 g
s
.67867 .62283 m .67702 .65818 L .65599 .66679 L p .707 .577 .707 r
F P
0 g
s
.34129 .67684 m .33595 .69499 L .36349 .70546 L p .707 .577 .707 r
F P
0 g
s
.42949 .7044 m .42414 .72255 L .45131 .7275 L p .707 .577 .707 r
F P
0 g
s
.45131 .7275 m .45666 .70935 L .42949 .7044 L p .707 .577 .707 r
F P
0 g
s
.65391 .68957 m .65601 .67404 L .67762 .66231 L p .707 .577 .707 r
F P
0 g
s
.69569 .55814 m .69711 .6146 L .67123 .61906 L p .707 .577 .707 r
F P
0 g
s
.32825 .62258 m .32404 .65975 L .34789 .66725 L p .707 .577 .707 r
F P
0 g
s
.31035 .55584 m .3138 .61096 L .3325 .6174 L p .707 .577 .707 r
F P
0 g
s
.47125 .64105 m .46704 .67822 L .48804 .67485 L p .707 .577 .707 r
F P
0 g
s
.48804 .67485 m .49225 .63768 L .47125 .64105 L p .707 .577 .707 r
F P
0 g
s
.67702 .65818 m .67867 .62283 L .7061 .61748 L p .707 .577 .707 r
F P
0 g
s
.78843 .55593 m .78985 .61239 L .75947 .61109 L p .707 .577 .707 r
F P
0 g
s
.75947 .61109 m .75805 .55463 L .78843 .55593 L p .707 .577 .707 r
F P
0 g
s
.69711 .6146 m .69569 .55814 L .7261 .55539 L p .707 .577 .707 r
F P
0 g
s
.33595 .69499 m .34129 .67684 L .31928 .66642 L p .707 .577 .707 r
F P
0 g
s
.49211 .54555 m .49555 .60068 L .50547 .59131 L p .707 .577 .707 r
F P
0 g
s
.50547 .59131 m .50203 .53618 L .49211 .54555 L p .707 .577 .707 r
F P
0 g
s
.31928 .66642 m .31394 .68457 L .33595 .69499 L p .707 .577 .707 r
F P
0 g
s
.67762 .66231 m .67552 .67784 L .65391 .68957 L p .707 .577 .707 r
F P
0 g
s
.3138 .61096 m .31035 .55584 L .30056 .54758 L p .707 .577 .707 r
F P
0 g
s
.32404 .65975 m .32825 .62258 L .31206 .61441 L p .707 .577 .707 r
F P
0 g
s
.7984 .62441 m .79676 .65976 L .7674 .65366 L p .707 .577 .707 r
F P
0 g
s
.7674 .65366 m .76904 .61832 L .7984 .62441 L p .707 .577 .707 r
F P
0 g
s
.45666 .70935 m .45131 .7275 L .47272 .72931 L p .707 .577 .707 r
F P
0 g
s
.47272 .72931 m .47807 .71116 L .45666 .70935 L p .707 .577 .707 r
F P
0 g
s
.82022 .6851 m .81812 .70063 L .79483 .68587 L p .707 .577 .707 r
F P
0 g
s
.79483 .68587 m .79693 .67034 L .82022 .6851 L p .707 .577 .707 r
F P
0 g
s
.75805 .55463 m .75947 .61109 L .72751 .61185 L p .707 .577 .707 r
F P
0 g
s
.72751 .61185 m .7261 .55539 L .75805 .55463 L p .707 .577 .707 r
F P
0 g
s
.7261 .55539 m .72751 .61185 L .69711 .6146 L p .707 .577 .707 r
F P
0 g
s
.7061 .61748 m .70445 .65283 L .67702 .65818 L p .707 .577 .707 r
F P
0 g
s
.67552 .67784 m .67762 .66231 L .70537 .65571 L p .707 .577 .707 r
F P
0 g
s
.70445 .65283 m .7061 .61748 L .73724 .61593 L p .707 .577 .707 r
F P
0 g
s
.31206 .61441 m .30785 .65158 L .32404 .65975 L p .707 .577 .707 r
F P
0 g
s
.76904 .61832 m .7674 .65366 L .73559 .65127 L p .707 .577 .707 r
F P
0 g
s
.73559 .65127 m .73724 .61593 L .76904 .61832 L p .707 .577 .707 r
F P
0 g
s
.73724 .61593 m .73559 .65127 L .70445 .65283 L p .707 .577 .707 r
F P
0 g
s
.31394 .68457 m .31928 .66642 L .30497 .65707 L p .707 .577 .707 r
F P
0 g
s
.49225 .63768 m .48804 .67485 L .50064 .66934 L p .707 .577 .707 r
F P
0 g
s
.50064 .66934 m .50485 .63216 L .49225 .63768 L p .707 .577 .707 r
F P
0 g
s
.30056 .54758 m .304 .60271 L .3138 .61096 L p .707 .577 .707 r
F P
0 g
s
.70537 .65571 m .70327 .67124 L .67552 .67784 L p .707 .577 .707 r
F P
0 g
s
.30497 .65707 m .29962 .67522 L .31394 .68457 L p .707 .577 .707 r
F P
0 g
s
.79693 .67034 m .79483 .68587 L .766 .67546 L p .707 .577 .707 r
F P
0 g
s
.766 .67546 m .7681 .65993 L .79693 .67034 L p .707 .577 .707 r
F P
0 g
s
.70327 .67124 m .70537 .65571 L .73655 .65489 L p .707 .577 .707 r
F P
0 g
s
.50203 .53618 m .50547 .59131 L .50553 .58204 L p .707 .577 .707 r
F P
0 g
s
.50553 .58204 m .50209 .52691 L .50203 .53618 L p .707 .577 .707 r
F P
0 g
s
.47807 .71116 m .47272 .72931 L .48628 .72782 L p .707 .577 .707 r
F P
0 g
s
.48628 .72782 m .49163 .70967 L .47807 .71116 L p .707 .577 .707 r
F P
0 g
s
.30785 .65158 m .31206 .61441 L .3051 .60637 L p .707 .577 .707 r
F P
0 g
s
.7681 .65993 m .766 .67546 L .73445 .67042 L p .707 .577 .707 r
F P
0 g
s
.73445 .67042 m .73655 .65489 L .7681 .65993 L p .707 .577 .707 r
F P
0 g
s
.73655 .65489 m .73445 .67042 L .70327 .67124 L p .707 .577 .707 r
F P
0 g
s
.304 .60271 m .30056 .54758 L .30062 .53832 L p .707 .577 .707 r
F P
0 g
s
.3051 .60637 m .30089 .64354 L .30785 .65158 L p .707 .577 .707 r
F P
0 g
s
.29962 .67522 m .30497 .65707 L .29975 .64971 L p .707 .577 .707 r
F P
0 g
s
.50485 .63216 m .50064 .66934 L .50361 .66221 L p .707 .577 .707 r
F P
0 g
s
.50361 .66221 m .50782 .62503 L .50485 .63216 L p .707 .577 .707 r
F P
0 g
s
.29975 .64971 m .2944 .66786 L .29962 .67522 L p .707 .577 .707 r
F P
0 g
s
.30062 .53832 m .30406 .59344 L .304 .60271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49163 .70967 m .48628 .72782 L .49066 .72316 L p .707 .577 .707 r
F P
0 g
s
.49066 .72316 m .49601 .70501 L .49163 .70967 L p .707 .577 .707 r
F P
0 g
s
.50209 .52691 m .50553 .58204 L .49573 .57378 L p .707 .577 .707 r
F P
0 g
s
.49573 .57378 m .49229 .51866 L .50209 .52691 L p .707 .577 .707 r
F P
0 g
s
.30089 .64354 m .3051 .60637 L .30807 .59924 L p .707 .577 .707 r
F P
0 g
s
.30406 .59344 m .30062 .53832 L .31054 .52894 L p .707 .577 .707 r
F P
0 g
s
.30807 .59924 m .30386 .63641 L .30089 .64354 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2944 .66786 m .29975 .64971 L .30413 .64505 L p .707 .577 .707 r
F P
0 g
s
.50782 .62503 m .50361 .66221 L .49665 .65416 L p .707 .577 .707 r
F P
0 g
s
.49665 .65416 m .50086 .61699 L .50782 .62503 L p .707 .577 .707 r
F P
0 g
s
.30413 .64505 m .29878 .6632 L .2944 .66786 L p .707 .577 .707 r
F P
0 g
s
.31054 .52894 m .31398 .58407 L .30406 .59344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49229 .51866 m .49573 .57378 L .47703 .56735 L p .707 .577 .707 r
F P
0 g
s
.47703 .56735 m .47359 .51222 L .49229 .51866 L p .707 .577 .707 r
F P
0 g
s
.49601 .70501 m .49066 .72316 L .48544 .7158 L p .707 .577 .707 r
F P
0 g
s
.48544 .7158 m .49079 .69765 L .49601 .70501 L p .707 .577 .707 r
F P
0 g
s
.30386 .63641 m .30807 .59924 L .32067 .59372 L p .707 .577 .707 r
F P
0 g
s
.31398 .58407 m .31054 .52894 L .32935 .52038 L p .707 .577 .707 r
F P
0 g
s
.32067 .59372 m .31646 .63089 L .30386 .63641 L p .707 .577 .707 r
F P
0 g
s
.29878 .6632 m .30413 .64505 L .31769 .64356 L p .707 .577 .707 r
F P
0 g
s
.32935 .52038 m .33279 .57551 L .31398 .58407 L p .707 .577 .707 r
F P
0 g
s
.50086 .61699 m .49665 .65416 L .48046 .646 L p .707 .577 .707 r
F P
0 g
s
.48046 .646 m .48467 .60882 L .50086 .61699 L p .707 .577 .707 r
F P
0 g
s
.31769 .64356 m .31234 .66171 L .29878 .6632 L p .707 .577 .707 r
F P
0 g
s
.47359 .51222 m .47703 .56735 L .45125 .56336 L p .707 .577 .707 r
F P
0 g
s
.45125 .56336 m .44781 .50824 L .47359 .51222 L p .707 .577 .707 r
F P
0 g
s
.33279 .57551 m .32935 .52038 L .3552 .51348 L p .707 .577 .707 r
F P
0 g
s
.49079 .69765 m .48544 .7158 L .47113 .70645 L p .707 .577 .707 r
F P
0 g
s
.47113 .70645 m .47647 .6883 L .49079 .69765 L p .707 .577 .707 r
F P
0 g
s
.31646 .63089 m .32067 .59372 L .34167 .59035 L p .707 .577 .707 r
F P
0 g
s
.34167 .59035 m .33746 .62753 L .31646 .63089 L p .707 .577 .707 r
F P
0 g
s
.44781 .50824 m .45125 .56336 L .42092 .56221 L p .707 .577 .707 r
F P
0 g
s
.42092 .56221 m .41748 .50709 L .44781 .50824 L p .707 .577 .707 r
F P
0 g
s
.3552 .51348 m .35865 .5686 L .33279 .57551 L p .707 .577 .707 r
F P
0 g
s
.35865 .5686 m .3552 .51348 L .38557 .50889 L p .707 .577 .707 r
F P
0 g
s
.48467 .60882 m .48046 .646 L .45661 .6385 L p .707 .577 .707 r
F P
0 g
s
.45661 .6385 m .46082 .60133 L .48467 .60882 L p .707 .577 .707 r
F P
0 g
s
.31234 .66171 m .31769 .64356 L .3391 .64538 L p .707 .577 .707 r
F P
0 g
s
.3391 .64538 m .33375 .66353 L .31234 .66171 L p .707 .577 .707 r
F P
0 g
s
.41748 .50709 m .42092 .56221 L .38901 .56402 L p .707 .577 .707 r
F P
0 g
s
.38901 .56402 m .38557 .50889 L .41748 .50709 L p .707 .577 .707 r
F P
0 g
s
.38557 .50889 m .38901 .56402 L .35865 .5686 L p .707 .577 .707 r
F P
0 g
s
.33746 .62753 m .34167 .59035 L .36901 .58947 L p .707 .577 .707 r
F P
0 g
s
.47647 .6883 m .47113 .70645 L .44912 .69603 L p .707 .577 .707 r
F P
0 g
s
.44912 .69603 m .45446 .67788 L .47647 .6883 L p .707 .577 .707 r
F P
0 g
s
.36901 .58947 m .3648 .62664 L .33746 .62753 L p .707 .577 .707 r
F P
0 g
s
.46082 .60133 m .45661 .6385 L .42744 .63241 L p .707 .577 .707 r
F P
0 g
s
.42744 .63241 m .43165 .59524 L .46082 .60133 L p .707 .577 .707 r
F P
0 g
s
.33375 .66353 m .3391 .64538 L .36627 .65032 L p .707 .577 .707 r
F P
0 g
s
.3648 .62664 m .36901 .58947 L .40002 .59115 L p .707 .577 .707 r
F P
0 g
s
.36627 .65032 m .36092 .66847 L .33375 .66353 L p .707 .577 .707 r
F P
0 g
s
.43165 .59524 m .42744 .63241 L .39581 .62833 L p .707 .577 .707 r
F P
0 g
s
.39581 .62833 m .40002 .59115 L .43165 .59524 L p .707 .577 .707 r
F P
0 g
s
.45446 .67788 m .44912 .69603 L .42157 .68556 L p .707 .577 .707 r
F P
0 g
s
.42157 .68556 m .42692 .66741 L .45446 .67788 L p .707 .577 .707 r
F P
0 g
s
.40002 .59115 m .39581 .62833 L .3648 .62664 L p .707 .577 .707 r
F P
0 g
s
.36092 .66847 m .36627 .65032 L .39652 .65791 L p .707 .577 .707 r
F P
0 g
s
.39652 .65791 m .39117 .67606 L .36092 .66847 L p .707 .577 .707 r
F P
0 g
s
.42692 .66741 m .42157 .68556 L .39117 .67606 L p .707 .577 .707 r
F P
0 g
s
.39117 .67606 m .39652 .65791 L .42692 .66741 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1@00L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JGoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomo
o`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Moo`00IGoo0P00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20004FUHH000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00Hgoo10001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005moo`@00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo
001LOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJ
EP00IGoo001JOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00F7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Moo`80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUIJEP00IGoo001FOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001EOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001U
Ool005Eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP004Woo4P00@Goo001EOol01000FUIJEP001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEUYF000<Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol005Eoo`05001JEUYF
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00@005YFFUH000Qoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH6000cOol005Eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0000
0eYF000000060003FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH000Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0031oo`00EGoo0P000UYF00<005YFFUH00UYF
00<005YFFUH00eYF3`000eYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEUYF001oo`030002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000^Ool005Eoo`80009JEP03001JEUYF009JEP03001JEP0000@000QJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP00;Goo001EOol20002FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00;Goo001FOol01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10002UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF00@005YFFUH002eoo`00EWoo00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEUYF000]Ool005Ioo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002eoo`00EWoo10000eYF00<005YF00003P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF000]Ool005Ioo`05001JEUYF001JEP040002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH:
0009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002eoo`00>goo5`0017oo00<005YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF0000;Goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040006
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool003=oo`@000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0002eoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF0000;Goo000_Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH0000]Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJ
EPh000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP0002eoo`00;Goo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF
FUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP0500000eYF0000000C0004FUH01000FUIJ
EUYF1P000eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00D0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF00@00003
FUH007oo02aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30002FUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH3000]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0002FUH01000FUIJEUYF600015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000`000UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF0000
05YF0005FUH00`00FUH0000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF000000040005FUH50004FUH00`00FUH00004
0002FUH60006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<005YF0000;Goo000/
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH015YF00@005YFFUIJEP/0009JEP03001JEUYF00=JEP@0009JEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP03001JEP00009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEUYF00MJEP@000EJEP03001JEUYF
009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01`00FUH0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEPH002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00<00003FUH0000001800003FUH005YF00=JEP04001JEUYF0009FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF3`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@0005FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEUYF0004FUH01000FUIJEUYF2000
27oo0`001Goo100000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF00AJEQD000IJEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00;7oo00@005YFFUH000AJ
EPH000eoo`D000Qoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEUYF001JEP002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF01<000Ioo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00;7oo00@0
05YFFUH0009JEP<000EJEPH000Moo`D000Ioo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP02FUH800000eYF001JEP07FUH00`00FUIJEP02FUH60004Ool40005FUH00`00FUIJEP02FUH00`00
FUH0000/Ool002aoo`03001JEUYF00<0009JEP03001JEUYF00EJEP04001JEUYFFUHB00000eYF0000
000;0007FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF00000P0000AJEP00000000AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00
0006Ool20003FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEP0000AJ
EP800004FUH005YFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF00000eYF0P000UYF0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
FUIJEP<000Eoo`800003FUH005YF009JEP04001JEUYF000/Ool002aoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH01000FUH00000
15YF00<005YF000010001UYF00<005YFFUH01eYF00<005YF00000P001UYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF
00<005YFFUH00P000UYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0P001Goo0P000eYF00@0
05YFFUH002aoo`00;7oo0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP80009JEP800003FUH00000009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH6000<FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000004FUH00`00FUH000040009
Ool70002FUH00`00FUIJEP06FUH30005Ool01000FUIJEP000UYF00<007ooOol0:Woo000/Ool01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000IJEP<00004FUH000000005FUH50007FUH00`00FUIJEP05FUH80005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF0P00
0UYF00<005YF00002Goo1@000Woo10001eYF00<005YFFUH00P0017oo0`0000=JEP00Ool0;7oo000/
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0000=JEP00FUH01UYF00<005YF00000`001EYF00<005YFFUH01P000UYF00<005YFFUH01eYF
0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00L005YF
001JEP00FUH00003FUH20004FUH00`00FUH0000:Ool30007Ool20004FUH00`00FUIJEP03FUH20003
Ool200000eYF001oo`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YF
000010000UYF10001eYF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEP00FUH20002FUH200000eYF00000002000015YF001JEP00
5Woo0`0000=JEP00FUH01UYF1@0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP<0009JEP03001JEP0000@0009JEP04001JEUYFFUH20005FUH00`00FUIJEP03FUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUH00000
FUH00`0000=JEP00FUH015YF10006Goo0P001eYF0P0000=JEP00FUH00P00;Goo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHL00000eYF001JEP07FUH00`00FUH0000200000eYF
000000030002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YF00000`0067oo0P001EYF00D005YF000005YF008002eoo`00;Woo0P0015YF00<005YFFUH0
0eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000MJEP03001JEUYF009J
EPD000=JEP03001JEUYF00IJEP8000IJEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH70009Ool900000eYF00000002FUH00`00FUIJEP020002FUH00`00Oomoo`0[Ool002mo
o`8000=JEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000004FUH00`00FUIJEP06FUH400000eYF001JEP09FUH20004FUH00`00FUIJEP02FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH30003
FUH01000FUIJEP00;Goo000`Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH0
10002EYF0`0000=JEP00FUH015YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YF0000;Goo000^Ool30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP@000MJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJEP04001JEP00000<FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80009JEP8000EJEP03001JEUYF
00MJEP04001JEUYFFUH60002FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH01P000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH00UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0002ioo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH20005FUH00`00FUH000030007FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01`00FUH005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEPL0
0003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH007oo02eoo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000P000UYF
1`0000=JEP00FUH01UYF00<005YFFUH00UYF1@0025YF00<005YFFUH01EYF00@005YFFUIJEP800005
Ool005YFFUH0000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001J
EUYF00IJEPL000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH000040006FUH00`00
FUIJEP02FUH50008FUH00`00FUIJEP05FUH01000FUH000000goo00@005YFFUH002eoo`00:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH015YF1`00
0eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YFFUH00P001EYF00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF009J
EPD000QJEP03001JEUYF009JEPD000Ioo`03001JEP0002eoo`00:goo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YF00001@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF0P0000=JEP0000001UYF00@005YFFUIJEP<000=oo`L00003FUH0
0000008000AJEPT000]oo`<002eoo`00;7oo00EJEP00FUIJEP0000EJEP03001JEUYF009JEPP000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800004
FUH005YF0005FUH01`00FUIJEUYF001JEP0000Yoo`T001Eoo`03001oogoo02aoo`00;7oo00EJEP00
FUIJEP0000=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0002Qoo`03001oogoo02aoo`00;7oo00=JEP00FUH01@001EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF009JEP07
001JEUYFFUH005YF0000:7oo00<007ooOol0;7oo000/Ool00eYF00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00004FUH01@00FUIJEUYF00000eYF
00<005YF00009goo0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@0000=oo`0000001EYF
00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001EYF00<005YFFUH01eYF
00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP04001JEUYFFUH2000VOol2000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70006Ool20005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP030003
FUH2000UOol00`00FUH0000_Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ<0009oo`8000EJEP03001JEUYF009JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP@000EJEP03001JEUYF009JEP08001J
EUYF001oo`00FUH000AJEP80009JEP03001JEP0002=oo`04001JEUYF000_Ool0031oobP000=JEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH400000eYF001JEP03FUH01000FUIJ
EP000Woo0P001UYF0`0000=JEP00Ool087oo0`0000=JEP00Ool0;goo0016Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP050006FUH0
0`00FUH00002000POol00`00FUIJEP02000aOol003ioo`P000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D00004FUH000000003FUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00
0eYF0`0015YF00@005YFFUIJEP<001aoo`80009JEP03001JEP00035oo`00=goo1`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEPD000=JEP04001JEUYFFUH300000eYF00000003FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH01@00FUIJEUYF00000UYF00@005YFFUH000MJEP@001Io
o`8000AJEP80039oo`00<Goo1P000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
100000=JEP00FUH01EYF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00<000QJEP03001JEUYF00@000ioo`@00003FUH005YF00=JEP03001o
ogoo035oo`00;Woo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00001P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF000015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF3P0015YF00@005YFFUIJ
EP8003Aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH04@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP0000001@000eYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000003Ioo`00;7oo40000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP02FUH800000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000hOol0
02aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH40003Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP03FUH200000goo000000070004FUH00`00FUIJEP06FUH00`00
FUIJEP04000kOol002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEPL000Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8000EJEP03001JEUYF00=JEP05001oogoo001JEP020005Ool@000oOol002eoo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH20003Ool01000FUIJEP00
E7oo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000IOol00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00@005YF000000Aoo`80009JEP03001o
ogoo059oo`00;Goo0`000UYF00@005YFFUIJEPl002=oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP001UYF0`0017oo0P000UYF00<005YF0000E7oo000`Ool6000dOol200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP040006Ool00`00FUIJEP02FUH2001EOol006aoo`@000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP<0009JEPD000Qo
o`<000EJEP03001oogoo05=oo`00L7oo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH0100000=JEP0000000P0037oo00D005YFFUIJEP0000=J
EP03001oogoo05Aoo`00M7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
2P003Woo0P0015YF00@005YFFUH005Moo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01P001Goo1@003Goo00<005YFFUH01EYF0P00F7oo001oOolO000;Ool5000;Ool30007
FUH00`00Oomoo`1GOol0091oo`03001JEUYF009JEP03001oogoo019oo`<000Yoo`8000=JEP03001J
EUYF009JEP8005Yoo`00Sgoo00<005YF00000UYF00<007ooOol07Woo0P001EYF00D005YFFUIJEP00
05aoo`00Sgoo00D005YF001JEP0001moo`8000QJEP<005eoo`00Sgoo00<005YFFUH00P0077oo0`00
00=JEP00FUH01eYF00<007ooOol0GGoo002?Ool01000FUIJEP006Woo0`0015YF00<005YFFUH015YF
0P00H7oo002@Ool00eYF001oo`0FOol40008FUH01000FUIJEUYF0P00HWoo002@Ool00eYF0000000B
Ool40002FUH00`00FUIJEP07FUH01000FUH00000I7oo002@Ool200000eYF0000000@0007FUH00`00
FUIJEP05FUH3001VOol0095oo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001YOol0095oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008006]oo`00TWoo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
06ioo`00Tgoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01000LWoo002EOolB001f
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57907 .74689 m .58251 .69108 L .55219 .68687 L p .707 .577 .707 r
F P
0 g
s
.58251 .69108 m .57907 .74689 L .61098 .74876 L p .707 .577 .707 r
F P
0 g
s
.61098 .74876 m .61442 .69294 L .58251 .69108 L p .707 .577 .707 r
F P
0 g
s
.61442 .69294 m .61098 .74876 L .64135 .74809 L p .707 .577 .707 r
F P
0 g
s
.64135 .74809 m .64479 .69228 L .61442 .69294 L p .707 .577 .707 r
F P
0 g
s
.54874 .74269 m .55219 .68687 L .52641 .68073 L p .707 .577 .707 r
F P
0 g
s
.55219 .68687 m .54874 .74269 L .57907 .74689 L p .707 .577 .707 r
F P
0 g
s
.64479 .69228 m .64135 .74809 L .6672 .74497 L p .707 .577 .707 r
F P
0 g
s
.6672 .74497 m .67065 .68915 L .64479 .69228 L p .707 .577 .707 r
F P
0 g
s
.60419 .81318 m .59998 .77674 L .56834 .77916 L p .707 .577 .707 r
F P
0 g
s
.59998 .77674 m .60419 .81318 L .6352 .80782 L p .707 .577 .707 r
F P
0 g
s
.6352 .80782 m .63099 .77137 L .59998 .77674 L p .707 .577 .707 r
F P
0 g
s
.52641 .68073 m .52297 .73655 L .54874 .74269 L p .707 .577 .707 r
F P
0 g
s
.57255 .8156 m .56834 .77916 L .53917 .77839 L p .707 .577 .707 r
F P
0 g
s
.56834 .77916 m .57255 .8156 L .60419 .81318 L p .707 .577 .707 r
F P
0 g
s
.63099 .77137 m .6352 .80782 L .66253 .80002 L p .707 .577 .707 r
F P
0 g
s
.66253 .80002 m .65832 .76358 L .63099 .77137 L p .707 .577 .707 r
F P
0 g
s
.52297 .73655 m .52641 .68073 L .5077 .67326 L p .707 .577 .707 r
F P
0 g
s
.67065 .68915 m .6672 .74497 L .68601 .73969 L p .707 .577 .707 r
F P
0 g
s
.68601 .73969 m .68945 .68387 L .67065 .68915 L p .707 .577 .707 r
F P
0 g
s
.53917 .77839 m .54338 .81483 L .57255 .8156 L p .707 .577 .707 r
F P
0 g
s
.54338 .81483 m .53917 .77839 L .51533 .7745 L p .707 .577 .707 r
F P
0 g
s
.65832 .76358 m .66253 .80002 L .68353 .79056 L p .707 .577 .707 r
F P
0 g
s
.68353 .79056 m .67932 .75412 L .65832 .76358 L p .707 .577 .707 r
F P
0 g
s
.5077 .67326 m .50426 .72907 L .52297 .73655 L p .707 .577 .707 r
F P
0 g
s
.60882 .85872 m .60347 .8414 L .57308 .84806 L p .707 .577 .707 r
F P
0 g
s
.60347 .8414 m .60882 .85872 L .63908 .84861 L p .707 .577 .707 r
F P
0 g
s
.63908 .84861 m .63373 .83129 L .60347 .8414 L p .707 .577 .707 r
F P
0 g
s
.63373 .83129 m .63908 .84861 L .66624 .83605 L p .707 .577 .707 r
F P
0 g
s
.66624 .83605 m .6609 .81873 L .63373 .83129 L p .707 .577 .707 r
F P
0 g
s
.57308 .84806 m .57843 .86538 L .60882 .85872 L p .707 .577 .707 r
F P
0 g
s
.51533 .7745 m .51954 .81095 L .54338 .81483 L p .707 .577 .707 r
F P
0 g
s
.57843 .86538 m .57308 .84806 L .54553 .85062 L p .707 .577 .707 r
F P
0 g
s
.50426 .72907 m .5077 .67326 L .4979 .66518 L p .707 .577 .707 r
F P
0 g
s
.68945 .68387 m .68601 .73969 L .69594 .73276 L p .707 .577 .707 r
F P
0 g
s
.69594 .73276 m .69938 .67695 L .68945 .68387 L p .707 .577 .707 r
F P
0 g
s
.6609 .81873 m .66624 .83605 L .68765 .82226 L p .707 .577 .707 r
F P
0 g
s
.68765 .82226 m .68231 .80494 L .6609 .81873 L p .707 .577 .707 r
F P
0 g
s
.54553 .85062 m .55088 .86794 L .57843 .86538 L p .707 .577 .707 r
F P
0 g
s
.51954 .81095 m .51533 .7745 L .49913 .76789 L p .707 .577 .707 r
F P
0 g
s
.67932 .75412 m .68353 .79056 L .69613 .78037 L p .707 .577 .707 r
F P
0 g
s
.69613 .78037 m .69192 .74392 L .67932 .75412 L p .707 .577 .707 r
F P
0 g
s
.4979 .66518 m .49446 .721 L .50426 .72907 L p .707 .577 .707 r
F P
0 g
s
.55088 .86794 m .54553 .85062 L .52352 .84883 L p .707 .577 .707 r
F P
0 g
s
.49913 .76789 m .50334 .80433 L .51954 .81095 L p .707 .577 .707 r
F P
0 g
s
.52352 .84883 m .52887 .86615 L .55088 .86794 L p .707 .577 .707 r
F P
0 g
s
.68231 .80494 m .68765 .82226 L .70122 .80859 L p .707 .577 .707 r
F P
0 g
s
.70122 .80859 m .69587 .79128 L .68231 .80494 L p .707 .577 .707 r
F P
0 g
s
.49446 .721 m .4979 .66518 L .49797 .6573 L p .708 .578 .707 r
F P
0 g
s
.69938 .67695 m .69594 .73276 L .696 .72488 L p .708 .578 .707 r
F P
0 g
s
.696 .72488 m .69944 .66907 L .69938 .67695 L p .708 .578 .707 r
F P
0 g
s
.50334 .80433 m .49913 .76789 L .49218 .75919 L p .707 .577 .707 r
F P
0 g
s
.52887 .86615 m .52352 .84883 L .50921 .84287 L p .707 .577 .707 r
F P
0 g
s
.69236 .7477 m .69613 .78037 L .69843 .77269 L p .707 .577 .707 r
F P
0 g
s
.7056 .79639 m .70025 .77907 L .69587 .79128 L p .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69503 .76952 L .69975 .77816 L p .707 .577 .707 r
F P
0 g
s
.69975 .77816 m .70025 .77907 L p .70027 .78029 L .707 .577 .707 r
F P
0 g
s
.70038 .78684 m .69975 .77816 L .70027 .78029 L .707 .577 .707 r
F
.69192 .74392 m .69236 .7477 L p .6991 .77043 L F P
0 g
s
.69843 .77269 m .6991 .77043 L p .69236 .7477 L .707 .577 .707 r
F P
0 g
s
.6991 .77043 m .69489 .73399 L .69192 .74392 L p .707 .577 .707 r
F P
0 g
s
.49797 .6573 m .49453 .71312 L .49446 .721 L p .708 .578 .707 r
F P
0 g
s
.50921 .84287 m .51456 .86019 L .52887 .86615 L p .707 .577 .707 r
F P
0 g
s
.49218 .75919 m .49639 .79563 L .50334 .80433 L p .707 .577 .707 r
F P
0 g
s
.69587 .79128 m .70122 .80859 L .7056 .79639 L p .707 .577 .707 r
F P
0 g
s
.49453 .71312 m .49797 .6573 L .50789 .65038 L p .707 .577 .707 r
F P
0 g
s
.50789 .65038 m .50445 .7062 L .49453 .71312 L p .707 .577 .707 r
F P
0 g
s
.49515 .74925 m .49936 .7857 L .49639 .79563 L p .707 .577 .707 r
F P
0 g
s
.49936 .7857 m .49515 .74925 L .50775 .73906 L p .707 .577 .707 r
F P
0 g
s
.50775 .73906 m .51196 .7755 L .49936 .7857 L p .707 .577 .707 r
F P
0 g
s
.50166 .82192 m .50166 .32003 L .45701 .31828 L p .707 .577 .707 r
F P
0 g
s
.50445 .7062 m .50789 .65038 L .5267 .6451 L p .707 .577 .707 r
F P
0 g
s
.51456 .86019 m .50921 .84287 L .50398 .83332 L p .707 .577 .707 r
F P
0 g
s
.50398 .83332 m .50933 .85064 L .51456 .86019 L p .707 .577 .707 r
F P
0 g
s
.50933 .85064 m .50398 .83332 L .50837 .82112 L p .707 .577 .707 r
F P
0 g
s
.50837 .82112 m .51372 .83844 L .50933 .85064 L p .707 .577 .707 r
F P
0 g
s
.5267 .6451 m .52326 .70091 L .50445 .7062 L p .707 .577 .707 r
F P
0 g
s
.52326 .70091 m .5267 .6451 L .55255 .64197 L p .707 .577 .707 r
F P
0 g
s
.51196 .7755 m .50775 .73906 L .52875 .7296 L p .707 .577 .707 r
F P
0 g
s
.51372 .83844 m .50837 .82112 L .52193 .80745 L p .707 .577 .707 r
F P
0 g
s
.55255 .64197 m .54911 .69779 L .52326 .70091 L p .707 .577 .707 r
F P
0 g
s
.52193 .80745 m .52728 .82477 L .51372 .83844 L p .707 .577 .707 r
F P
0 g
s
.52875 .7296 m .53296 .76604 L .51196 .7755 L p .707 .577 .707 r
F P
0 g
s
.53296 .76604 m .52875 .7296 L .55609 .7218 L p .707 .577 .707 r
F P
0 g
s
.52728 .82477 m .52193 .80745 L .54334 .79366 L p .707 .577 .707 r
F P
0 g
s
.55609 .7218 m .5603 .75825 L .53296 .76604 L p .707 .577 .707 r
F P
0 g
s
.54334 .79366 m .54869 .81098 L .52728 .82477 L p .707 .577 .707 r
F P
0 g
s
.54869 .81098 m .54334 .79366 L .5705 .7811 L p .707 .577 .707 r
F P
0 g
s
.50166 .32003 m .50166 .82192 L .54615 .81989 L p .707 .577 .707 r
F P
0 g
s
.54615 .81989 m .54615 .318 L .50166 .32003 L p .707 .577 .707 r
F P
0 g
s
.45701 .82016 m .45701 .31828 L .41657 .3129 L p .707 .577 .707 r
F P
0 g
s
.49639 .79563 m .49218 .75919 L .49515 .74925 L p .707 .577 .707 r
F P
0 g
s
.45701 .31828 m .45701 .82016 L .50166 .82192 L p .707 .577 .707 r
F P
0 g
s
.54911 .69779 m .55255 .64197 L .58292 .64131 L p .707 .577 .707 r
F P
0 g
s
.58292 .64131 m .57948 .69712 L .54911 .69779 L p .707 .577 .707 r
F P
0 g
s
.5603 .75825 m .55609 .7218 L .58709 .71643 L p .707 .577 .707 r
F P
0 g
s
.58709 .71643 m .5913 .75288 L .5603 .75825 L p .707 .577 .707 r
F P
0 g
s
.5705 .7811 m .57585 .79842 L .54869 .81098 L p .707 .577 .707 r
F P
0 g
s
.57585 .79842 m .5705 .7811 L .60076 .77099 L p .707 .577 .707 r
F P
0 g
s
.60076 .77099 m .60611 .78831 L .57585 .79842 L p .707 .577 .707 r
F P
0 g
s
.54615 .318 m .54615 .81989 L .58612 .81427 L p .707 .577 .707 r
F P
0 g
s
.57948 .69712 m .58292 .64131 L .61483 .64317 L p .707 .577 .707 r
F P
0 g
s
.61483 .64317 m .61139 .69899 L .57948 .69712 L p .707 .577 .707 r
F P
0 g
s
.58612 .81427 m .58612 .31238 L .54615 .318 L p .707 .577 .707 r
F P
0 g
s
.69944 .66907 m .696 .72488 L .6862 .71681 L p .707 .577 .707 r
F P
0 g
s
.6862 .71681 m .68964 .66099 L .69944 .66907 L p .707 .577 .707 r
F P
0 g
s
.69489 .73399 m .6991 .77043 L .69215 .76173 L p .707 .577 .707 r
F P
0 g
s
.69215 .76173 m .68794 .72529 L .69489 .73399 L p .707 .577 .707 r
F P
0 g
s
.41657 .81479 m .41657 .3129 L .38429 .30444 L p .707 .577 .707 r
F P
0 g
s
.41657 .3129 m .41657 .81479 L .45701 .82016 L p .707 .577 .707 r
F P
0 g
s
.70025 .77907 m .7056 .79639 L .70038 .78684 L p .707 .577 .707 r
F P
0 g
s
.61873 .71402 m .62294 .75046 L .5913 .75288 L p .707 .577 .707 r
F P
0 g
s
.5913 .75288 m .58709 .71643 L .61873 .71402 L p .707 .577 .707 r
F P
0 g
s
.63115 .76434 m .6365 .78165 L .60611 .78831 L p .707 .577 .707 r
F P
0 g
s
.60611 .78831 m .60076 .77099 L .63115 .76434 L p .707 .577 .707 r
F P
0 g
s
.58612 .31238 m .58612 .81427 L .61767 .80561 L p .707 .577 .707 r
F P
0 g
s
.64516 .64738 m .64172 .7032 L .61139 .69899 L p .707 .577 .707 r
F P
0 g
s
.61139 .69899 m .61483 .64317 L .64516 .64738 L p .707 .577 .707 r
F P
0 g
s
.61767 .80561 m .61767 .30372 L .58612 .31238 L p .707 .577 .707 r
F P
0 g
s
.24053 .71615 m .24194 .66172 L .21156 .65773 L p .707 .577 .707 r
F P
0 g
s
.24194 .66172 m .24053 .71615 L .27249 .71691 L p .707 .577 .707 r
F P
0 g
s
.27249 .71691 m .2739 .66247 L .24194 .66172 L p .707 .577 .707 r
F P
0 g
s
.2739 .66247 m .27249 .71691 L .30289 .71436 L p .707 .577 .707 r
F P
0 g
s
.30289 .71436 m .30431 .65992 L .2739 .66247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68964 .66099 m .6862 .71681 L .6675 .70934 L p .707 .577 .707 r
F P
0 g
s
.6675 .70934 m .67094 .65352 L .68964 .66099 L p .707 .577 .707 r
F P
0 g
s
.21015 .71217 m .21156 .65773 L .18573 .65091 L p .707 .577 .707 r
F P
0 g
s
.21156 .65773 m .21015 .71217 L .24053 .71615 L p .707 .577 .707 r
F P
0 g
s
.30431 .65992 m .30289 .71436 L .32877 .70875 L p .707 .577 .707 r
F P
0 g
s
.32877 .70875 m .33019 .65432 L .30431 .65992 L p .707 .577 .707 r
F P
0 g
s
.68794 .72529 m .69215 .76173 L .67596 .75512 L p .707 .577 .707 r
F P
0 g
s
.67596 .75512 m .67175 .71867 L .68794 .72529 L p .707 .577 .707 r
F P
0 g
s
.38429 .80633 m .38429 .30444 L .36334 .29371 L p .707 .577 .707 r
F P
0 g
s
.38429 .30444 m .38429 .80633 L .41657 .81479 L p .707 .577 .707 r
F P
0 g
s
.69503 .76952 m .70038 .78684 L .68606 .78088 L p .707 .577 .707 r
F P
0 g
s
.68606 .78088 m .68071 .76356 L .69503 .76952 L p .707 .577 .707 r
F P
0 g
s
.6479 .71479 m .65211 .75123 L .62294 .75046 L p .707 .577 .707 r
F P
0 g
s
.62294 .75046 m .61873 .71402 L .6479 .71479 L p .707 .577 .707 r
F P
0 g
s
.6587 .76177 m .66405 .77909 L .6365 .78165 L p .707 .577 .707 r
F P
0 g
s
.6365 .78165 m .63115 .76434 L .6587 .76177 L p .707 .577 .707 r
F P
0 g
s
.61767 .30372 m .61767 .80561 L .63769 .79475 L p .707 .577 .707 r
F P
0 g
s
.63769 .79475 m .63769 .29286 L .61767 .30372 L p .707 .577 .707 r
F P
0 g
s
.26441 .75817 m .26276 .72012 L .23095 .72107 L p .707 .577 .707 r
F P
0 g
s
.26276 .72012 m .26441 .75817 L .29555 .75586 L p .707 .577 .707 r
F P
0 g
s
.29555 .75586 m .2939 .7178 L .26276 .72012 L p .707 .577 .707 r
F P
0 g
s
.2326 .75912 m .23095 .72107 L .20159 .72056 L p .707 .577 .707 r
F P
0 g
s
.23095 .72107 m .2326 .75912 L .26441 .75817 L p .707 .577 .707 r
F P
0 g
s
.18432 .70534 m .18573 .65091 L .16698 .64191 L p .707 .577 .707 r
F P
0 g
s
.18573 .65091 m .18432 .70534 L .21015 .71217 L p .707 .577 .707 r
F P
0 g
s
.33019 .65432 m .32877 .70875 L .34759 .70064 L p .707 .577 .707 r
F P
0 g
s
.34759 .70064 m .349 .64621 L .33019 .65432 L p .707 .577 .707 r
F P
0 g
s
.67094 .65352 m .6675 .70934 L .64172 .7032 L p .707 .577 .707 r
F P
0 g
s
.64172 .7032 m .64516 .64738 L .67094 .65352 L p .707 .577 .707 r
F P
0 g
s
.2319 .7645 m .234 .78355 L .26555 .7798 L p .707 .577 .707 r
F P
0 g
s
.26555 .7798 m .26345 .76074 L .2319 .7645 L p .707 .577 .707 r
F P
0 g
s
.26345 .76074 m .26555 .7798 L .29673 .77687 L p .707 .577 .707 r
F P
0 g
s
.2939 .7178 m .29555 .75586 L .32298 .75241 L p .707 .577 .707 r
F P
0 g
s
.32298 .75241 m .32133 .71435 L .2939 .7178 L p .707 .577 .707 r
F P
0 g
s
.29673 .77687 m .29462 .75781 L .26345 .76074 L p .707 .577 .707 r
F P
0 g
s
.20159 .72056 m .20324 .75861 L .2326 .75912 L p .707 .577 .707 r
F P
0 g
s
.20307 .76872 m .20517 .78778 L .234 .78355 L p .707 .577 .707 r
F P
0 g
s
.234 .78355 m .2319 .7645 L .20307 .76872 L p .707 .577 .707 r
F P
0 g
s
.29462 .75781 m .29673 .77687 L .32448 .77506 L p .707 .577 .707 r
F P
0 g
s
.32448 .77506 m .32238 .75601 L .29462 .75781 L p .707 .577 .707 r
F P
0 g
s
.67175 .71867 m .67596 .75512 L .65211 .75123 L p .707 .577 .707 r
F P
0 g
s
.65211 .75123 m .6479 .71479 L .67175 .71867 L p .707 .577 .707 r
F P
0 g
s
.20324 .75861 m .20159 .72056 L .17756 .71864 L p .707 .577 .707 r
F P
0 g
s
.17756 .71864 m .1792 .7567 L .20324 .75861 L p .707 .577 .707 r
F P
0 g
s
.32133 .71435 m .32298 .75241 L .34401 .74816 L p .707 .577 .707 r
F P
0 g
s
.34401 .74816 m .34236 .7101 L .32133 .71435 L p .707 .577 .707 r
F P
0 g
s
.17977 .77299 m .18188 .79205 L .20517 .78778 L p .707 .577 .707 r
F P
0 g
s
.20517 .78778 m .20307 .76872 L .17977 .77299 L p .707 .577 .707 r
F P
0 g
s
.16698 .64191 m .16557 .69635 L .18432 .70534 L p .707 .577 .707 r
F P
0 g
s
.68071 .76356 m .68606 .78088 L .66405 .77909 L p .707 .577 .707 r
F P
0 g
s
.66405 .77909 m .6587 .76177 L .68071 .76356 L p .707 .577 .707 r
F P
0 g
s
.32238 .75601 m .32448 .77506 L .34609 .77455 L p .707 .577 .707 r
F P
0 g
s
.16557 .69635 m .16698 .64191 L .15715 .63163 L p .707 .577 .707 r
F P
0 g
s
.34609 .77455 m .34399 .75549 L .32238 .75601 L p .707 .577 .707 r
F P
0 g
s
.349 .64621 m .34759 .70064 L .3575 .69082 L p .707 .577 .707 r
F P
0 g
s
.3575 .69082 m .35892 .63639 L .349 .64621 L p .707 .577 .707 r
F P
0 g
s
.35735 .75633 m .35945 .77538 L .36324 .77748 L p .707 .577 .707 r
F P
0 g
s
.36324 .77748 m .36114 .75842 L .35735 .75633 L p .707 .577 .707 r
F P
0 g
s
.34399 .75549 m .34609 .77455 L .35945 .77538 L p .707 .577 .707 r
F P
0 g
s
.35945 .77538 m .35735 .75633 L .34399 .75549 L p .707 .577 .707 r
F P
0 g
s
.36114 .75842 m .36324 .77748 L .3571 .78064 L p .707 .577 .707 r
F P
0 g
s
.36334 .7956 m .36334 .29371 L .35576 .28178 L p .707 .577 .707 r
F P
0 g
s
.36334 .29371 m .36334 .7956 L .38429 .80633 L p .707 .577 .707 r
F P
0 g
s
.1792 .7567 m .17756 .71864 L .16119 .71551 L p .707 .577 .707 r
F P
0 g
s
.63769 .29286 m .63769 .79475 L .64423 .78277 L p .707 .577 .707 r
F P
0 g
s
.64423 .78277 m .64423 .28088 L .63769 .29286 L p .707 .577 .707 r
F P
0 g
s
.16119 .71551 m .16284 .75356 L .1792 .7567 L p .707 .577 .707 r
F P
0 g
s
.1643 .7769 m .1664 .79595 L .18188 .79205 L p .707 .577 .707 r
F P
0 g
s
.18188 .79205 m .17977 .77299 L .1643 .7769 L p .707 .577 .707 r
F P
0 g
s
.34236 .7101 m .34401 .74816 L .35658 .74353 L p .707 .577 .707 r
F P
0 g
s
.35658 .74353 m .35493 .70547 L .34236 .7101 L p .707 .577 .707 r
F P
0 g
s
.15715 .63163 m .15573 .68606 L .16557 .69635 L p .707 .577 .707 r
F P
0 g
s
.15573 .68606 m .15715 .63163 L .15719 .62105 L p .708 .578 .707 r
F P
0 g
s
.35892 .63639 m .3575 .69082 L .35754 .68025 L p .708 .578 .707 r
F P
0 g
s
.35754 .68025 m .35896 .62582 L .35892 .63639 L p .708 .578 .707 r
F P
0 g
s
.16284 .75356 m .16119 .71551 L .1541 .71146 L p .707 .577 .707 r
F P
0 g
s
.1541 .71146 m .15575 .74952 L .16284 .75356 L p .707 .577 .707 r
F P
0 g
s
.15816 .78005 m .16026 .79911 L .1664 .79595 L p .707 .577 .707 r
F P
0 g
s
.1664 .79595 m .1643 .7769 L .15816 .78005 L p .707 .577 .707 r
F P
0 g
s
.35493 .70547 m .35658 .74353 L .35946 .73896 L p .707 .577 .707 r
F P
0 g
s
.35946 .73896 m .35781 .70091 L .35493 .70547 L p .707 .577 .707 r
F P
0 g
s
.15719 .62105 m .15577 .67549 L .15573 .68606 L p .708 .578 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35896 .62582 m .35754 .68025 L .3477 .66996 L p .707 .577 .707 r
F P
0 g
s
.3477 .66996 m .34912 .61553 L .35896 .62582 L p .707 .577 .707 r
F P
0 g
s
.35781 .70091 m .35946 .73896 L .35237 .73492 L p .707 .577 .707 r
F P
0 g
s
.35237 .73492 m .35072 .69686 L .35781 .70091 L p .707 .577 .707 r
F P
0 g
s
.3571 .78064 m .355 .76158 L .36114 .75842 L p .707 .577 .707 r
F P
0 g
s
.355 .76158 m .3571 .78064 L .3478 .78298 L p .707 .577 .707 r
F P
0 g
s
.3478 .78298 m .34163 .78454 L p .34797 .77366 L .707 .577 .707 r
F P
0 g
s
.34797 .77366 m .355 .76158 L .3478 .78298 L .707 .577 .707 r
F
.35919 .51443 m .35576 .78366 L .36334 .7956 L p F P
0 g
s
.35576 .35297 m .35665 .34174 L p .35576 .28178 L .707 .577 .707 r
F P
0 g
s
.35576 .78366 m .35576 .35297 L p .36231 .26979 L .707 .577 .707 r
F P
0 g
s
.35576 .35297 m .35576 .28178 L .35713 .27928 L p .707 .577 .707 r
F P
0 g
s
.35713 .27928 m .36231 .26979 L p .35576 .35297 L .707 .577 .707 r
F P
0 g
s
.64423 .28088 m .64423 .78277 L .63666 .77083 L p .707 .577 .707 r
F P
0 g
s
.63666 .77083 m .63666 .26894 L .64423 .28088 L p .707 .577 .707 r
F P
0 g
s
.15577 .67549 m .15719 .62105 L .1671 .61123 L p .707 .577 .707 r
F P
0 g
s
.15575 .74952 m .1541 .71146 L .15699 .7069 L p .707 .577 .707 r
F P
0 g
s
.15699 .7069 m .15863 .74495 L .15575 .74952 L p .707 .577 .707 r
F P
0 g
s
.16196 .78215 m .16406 .80121 L .16026 .79911 L p .707 .577 .707 r
F P
0 g
s
.16026 .79911 m .15816 .78005 L .16196 .78215 L p .707 .577 .707 r
F P
0 g
s
.1671 .61123 m .16568 .66567 L .15577 .67549 L p .707 .577 .707 r
F P
0 g
s
.16568 .66567 m .1671 .61123 L .18592 .60312 L p .707 .577 .707 r
F P
0 g
s
.34912 .61553 m .3477 .66996 L .32895 .66097 L p .707 .577 .707 r
F P
0 g
s
.32895 .66097 m .33037 .60653 L .34912 .61553 L p .707 .577 .707 r
F P
0 g
s
.36231 .77168 m .36231 .26979 L .38233 .25894 L p .707 .577 .707 r
F P
0 g
s
.36231 .26979 m .36231 .77168 L .35576 .78366 L p .707 .577 .707 r
F P
0 g
s
.63666 .26894 m .63666 .77083 L .61571 .76011 L p .707 .577 .707 r
F P
0 g
s
.61571 .76011 m .61571 .25822 L .63666 .26894 L p .707 .577 .707 r
F P
0 g
s
.15863 .74495 m .15699 .7069 L .16956 .70227 L p .707 .577 .707 r
F P
0 g
s
.16956 .70227 m .1712 .74032 L .15863 .74495 L p .707 .577 .707 r
F P
0 g
s
.17531 .78298 m .17741 .80204 L .16406 .80121 L p .707 .577 .707 r
F P
0 g
s
.16406 .80121 m .16196 .78215 L .17531 .78298 L p .707 .577 .707 r
F P
0 g
s
.18592 .60312 m .1845 .65756 L .16568 .66567 L p .707 .577 .707 r
F P
0 g
s
.35072 .69686 m .35237 .73492 L .33601 .73178 L p .707 .577 .707 r
F P
0 g
s
.33601 .73178 m .33436 .69373 L .35072 .69686 L p .707 .577 .707 r
F P
0 g
s
.1845 .65756 m .18592 .60312 L .21179 .59752 L p .707 .577 .707 r
F P
0 g
s
.33037 .60653 m .32895 .66097 L .30312 .65414 L p .707 .577 .707 r
F P
0 g
s
.30312 .65414 m .30454 .59971 L .33037 .60653 L p .707 .577 .707 r
F P
0 g
s
.34163 .78454 m .33953 .76548 L .355 .76158 L p .707 .577 .707 r
F P
0 g
s
.1712 .74032 m .16956 .70227 L .19058 .69802 L p .707 .577 .707 r
F P
0 g
s
.21038 .65195 m .21179 .59752 L .2422 .59497 L p .707 .577 .707 r
F P
0 g
s
.21179 .59752 m .21038 .65195 L .1845 .65756 L p .707 .577 .707 r
F P
0 g
s
.38233 .25894 m .38233 .76083 L .36231 .77168 L p .707 .577 .707 r
F P
0 g
s
.38233 .76083 m .38233 .25894 L .41387 .25028 L p .707 .577 .707 r
F P
0 g
s
.30454 .59971 m .30312 .65414 L .27274 .65016 L p .707 .577 .707 r
F P
0 g
s
.27274 .65016 m .27416 .59572 L .30454 .59971 L p .707 .577 .707 r
F P
0 g
s
.19058 .69802 m .19223 .73607 L .1712 .74032 L p .707 .577 .707 r
F P
0 g
s
.61571 .25822 m .61571 .76011 L .58343 .75165 L p .707 .577 .707 r
F P
0 g
s
.58343 .75165 m .58343 .24976 L .61571 .25822 L p .707 .577 .707 r
F P
0 g
s
.19693 .78247 m .19903 .80153 L .17741 .80204 L p .707 .577 .707 r
F P
0 g
s
.17741 .80204 m .17531 .78298 L .19693 .78247 L p .707 .577 .707 r
F P
0 g
s
.75921 .65242 m .7578 .59596 L .72584 .59672 L p .707 .577 .707 r
F P
0 g
s
.7578 .59596 m .75921 .65242 L .78962 .64968 L p .707 .577 .707 r
F P
0 g
s
.78962 .64968 m .7882 .59322 L .7578 .59596 L p .707 .577 .707 r
F P
0 g
s
.72726 .65318 m .72584 .59672 L .69546 .59542 L p .707 .577 .707 r
F P
0 g
s
.72584 .59672 m .72726 .65318 L .75921 .65242 L p .707 .577 .707 r
F P
0 g
s
.33436 .69373 m .33601 .73178 L .31197 .72987 L p .707 .577 .707 r
F P
0 g
s
.31197 .72987 m .31032 .69181 L .33436 .69373 L p .707 .577 .707 r
F P
0 g
s
.24078 .6494 m .2422 .59497 L .27416 .59572 L p .707 .577 .707 r
F P
0 g
s
.2422 .59497 m .24078 .6494 L .21038 .65195 L p .707 .577 .707 r
F P
0 g
s
.27416 .59572 m .27274 .65016 L .24078 .6494 L p .707 .577 .707 r
F P
0 g
s
.33953 .76548 m .34163 .78454 L .31834 .78881 L p .707 .577 .707 r
F P
0 g
s
.31834 .78881 m .31624 .76976 L .33953 .76548 L p .707 .577 .707 r
F P
0 g
s
.7882 .59322 m .78962 .64968 L .8155 .64521 L p .707 .577 .707 r
F P
0 g
s
.8155 .64521 m .81408 .58876 L .7882 .59322 L p .707 .577 .707 r
F P
0 g
s
.69688 .65188 m .69546 .59542 L .66963 .59219 L p .707 .577 .707 r
F P
0 g
s
.69546 .59542 m .69688 .65188 L .72726 .65318 L p .707 .577 .707 r
F P
0 g
s
.19223 .73607 m .19058 .69802 L .21801 .69457 L p .707 .577 .707 r
F P
0 g
s
.21801 .69457 m .21966 .73262 L .19223 .73607 L p .707 .577 .707 r
F P
0 g
s
.31032 .69181 m .31197 .72987 L .28261 .72936 L p .707 .577 .707 r
F P
0 g
s
.28261 .72936 m .28096 .6913 L .31032 .69181 L p .707 .577 .707 r
F P
0 g
s
.7492 .73184 m .75085 .6965 L .71904 .69411 L p .707 .577 .707 r
F P
0 g
s
.75085 .6965 m .7492 .73184 L .78034 .73029 L p .707 .577 .707 r
F P
0 g
s
.78034 .73029 m .78199 .69494 L .75085 .6965 L p .707 .577 .707 r
F P
0 g
s
.66963 .59219 m .67105 .64865 L .69688 .65188 L p .707 .577 .707 r
F P
0 g
s
.22468 .78066 m .22678 .79972 L .19903 .80153 L p .707 .577 .707 r
F P
0 g
s
.19903 .80153 m .19693 .78247 L .22468 .78066 L p .707 .577 .707 r
F P
0 g
s
.71739 .72945 m .71904 .69411 L .68968 .68801 L p .707 .577 .707 r
F P
0 g
s
.71904 .69411 m .71739 .72945 L .7492 .73184 L p .707 .577 .707 r
F P
0 g
s
.41387 .75217 m .41387 .25028 L .45384 .24466 L p .707 .577 .707 r
F P
0 g
s
.41387 .25028 m .41387 .75217 L .38233 .76083 L p .707 .577 .707 r
F P
0 g
s
.58343 .24976 m .58343 .75165 L .54299 .74627 L p .707 .577 .707 r
F P
0 g
s
.54299 .74627 m .54299 .24438 L .58343 .24976 L p .707 .577 .707 r
F P
0 g
s
.81408 .58876 m .8155 .64521 L .83431 .63947 L p .707 .577 .707 r
F P
0 g
s
.83431 .63947 m .8329 .58301 L .81408 .58876 L p .707 .577 .707 r
F P
0 g
s
.31624 .76976 m .31834 .78881 L .28951 .79303 L p .707 .577 .707 r
F P
0 g
s
.67105 .64865 m .66963 .59219 L .65088 .58734 L p .707 .577 .707 r
F P
0 g
s
.78199 .69494 m .78034 .73029 L .80777 .72494 L p .707 .577 .707 r
F P
0 g
s
.80777 .72494 m .80941 .68959 L .78199 .69494 L p .707 .577 .707 r
F P
0 g
s
.28951 .79303 m .2874 .77398 L .31624 .76976 L p .707 .577 .707 r
F P
0 g
s
.21966 .73262 m .21801 .69457 L .24915 .69225 L p .707 .577 .707 r
F P
0 g
s
.28096 .6913 m .28261 .72936 L .2508 .73031 L p .707 .577 .707 r
F P
0 g
s
.2508 .73031 m .24915 .69225 L .28096 .6913 L p .707 .577 .707 r
F P
0 g
s
.68803 .72336 m .68968 .68801 L .66564 .6788 L p .707 .577 .707 r
F P
0 g
s
.68968 .68801 m .68803 .72336 L .71739 .72945 L p .707 .577 .707 r
F P
0 g
s
.24915 .69225 m .2508 .73031 L .21966 .73262 L p .707 .577 .707 r
F P
0 g
s
.25586 .77773 m .25796 .79679 L .22678 .79972 L p .707 .577 .707 r
F P
0 g
s
.22678 .79972 m .22468 .78066 L .25586 .77773 L p .707 .577 .707 r
F P
0 g
s
.65088 .58734 m .65229 .6438 L .67105 .64865 L p .707 .577 .707 r
F P
0 g
s
.2874 .77398 m .28951 .79303 L .25796 .79679 L p .707 .577 .707 r
F P
0 g
s
.25796 .79679 m .25586 .77773 L .2874 .77398 L p .707 .577 .707 r
F P
0 g
s
.80941 .68959 m .80777 .72494 L .82879 .71632 L p .707 .577 .707 r
F P
0 g
s
.82879 .71632 m .83044 .68098 L .80941 .68959 L p .707 .577 .707 r
F P
0 g
s
.45384 .74655 m .45384 .24466 L .49833 .24263 L p .707 .577 .707 r
F P
0 g
s
.45384 .24466 m .45384 .74655 L .41387 .75217 L p .707 .577 .707 r
F P
0 g
s
.54299 .24438 m .54299 .74627 L .49833 .74452 L p .707 .577 .707 r
F P
0 g
s
.49833 .74452 m .49833 .24263 L .54299 .24438 L p .707 .577 .707 r
F P
0 g
s
.66564 .6788 m .66399 .71415 L .68803 .72336 L p .707 .577 .707 r
F P
0 g
s
.8329 .58301 m .83431 .63947 L .84423 .63301 L p .707 .577 .707 r
F P
0 g
s
.84423 .63301 m .84281 .57655 L .8329 .58301 L p .707 .577 .707 r
F P
0 g
s
.49833 .24263 m .49833 .74452 L .45384 .74655 L p .707 .577 .707 r
F P
0 g
s
.66399 .71415 m .66564 .6788 L .64928 .66738 L p .707 .577 .707 r
F P
0 g
s
.65229 .6438 m .65088 .58734 L .64104 .58135 L p .707 .577 .707 r
F P
0 g
s
.74204 .79017 m .74414 .77464 L .71259 .7696 L p .707 .577 .707 r
F P
0 g
s
.74414 .77464 m .74204 .79017 L .77322 .78935 L p .707 .577 .707 r
F P
0 g
s
.77322 .78935 m .77532 .77382 L .74414 .77464 L p .707 .577 .707 r
F P
0 g
s
.71049 .78513 m .71259 .7696 L .68376 .75919 L p .707 .577 .707 r
F P
0 g
s
.71259 .7696 m .71049 .78513 L .74204 .79017 L p .707 .577 .707 r
F P
0 g
s
.77532 .77382 m .77322 .78935 L .80097 .78275 L p .707 .577 .707 r
F P
0 g
s
.80097 .78275 m .80307 .76722 L .77532 .77382 L p .707 .577 .707 r
F P
0 g
s
.64104 .58135 m .64246 .63781 L .65229 .6438 L p .707 .577 .707 r
F P
0 g
s
.83044 .68098 m .82879 .71632 L .84136 .70529 L p .707 .577 .707 r
F P
0 g
s
.84136 .70529 m .84301 .66994 L .83044 .68098 L p .707 .577 .707 r
F P
0 g
s
.68166 .77472 m .68376 .75919 L .66047 .74443 L p .707 .577 .707 r
F P
0 g
s
.68376 .75919 m .68166 .77472 L .71049 .78513 L p .707 .577 .707 r
F P
0 g
s
.64928 .66738 m .64763 .70273 L .66399 .71415 L p .707 .577 .707 r
F P
0 g
s
.64763 .70273 m .64928 .66738 L .64219 .65487 L p .707 .577 .707 r
F P
0 g
s
.66047 .74443 m .65837 .75996 L .68166 .77472 L p .707 .577 .707 r
F P
0 g
s
.80307 .76722 m .80097 .78275 L .82258 .77102 L p .707 .577 .707 r
F P
0 g
s
.82258 .77102 m .82469 .75548 L .80307 .76722 L p .707 .577 .707 r
F P
0 g
s
.84281 .57655 m .84423 .63301 L .84427 .62646 L p .706 .577 .707 r
F P
0 g
s
.84427 .62646 m .84285 .57001 L .84281 .57655 L p .706 .577 .707 r
F P
0 g
s
.64246 .63781 m .64104 .58135 L .64108 .5748 L p .706 .577 .707 r
F P
0 g
s
.65837 .75996 m .66047 .74443 L .64499 .72677 L p .707 .577 .707 r
F P
0 g
s
.64219 .65487 m .64054 .69021 L .64763 .70273 L p .707 .577 .707 r
F P
0 g
s
.84301 .66994 m .84136 .70529 L .84425 .6929 L p .707 .577 .707 r
F P
0 g
s
.84425 .6929 m .84589 .65756 L .84301 .66994 L p .707 .577 .707 r
F P
0 g
s
.64499 .72677 m .64289 .7423 L .65837 .75996 L p .707 .577 .707 r
F P
0 g
s
.64108 .5748 m .6425 .63126 L .64246 .63781 L p .706 .577 .707 r
F P
0 g
s
.82469 .75548 m .82258 .77102 L .83594 .75529 L p .707 .577 .707 r
F P
0 g
s
.83594 .75529 m .83804 .73976 L .82469 .75548 L p .707 .577 .707 r
F P
0 g
s
.64289 .7423 m .64499 .72677 L .63885 .70793 L p .707 .577 .707 r
F P
0 g
s
.64054 .69021 m .64219 .65487 L .64507 .64248 L p .707 .577 .707 r
F P
0 g
s
.84285 .57001 m .84427 .62646 L .83443 .62047 L p .707 .577 .707 r
F P
0 g
s
.83443 .62047 m .83302 .56401 L .84285 .57001 L p .707 .577 .707 r
F P
0 g
s
.6425 .63126 m .64108 .5748 L .651 .56834 L p .707 .577 .707 r
F P
0 g
s
.63885 .70793 m .63675 .72346 L .64289 .7423 L p .707 .577 .707 r
F P
0 g
s
.64507 .64248 m .64342 .67783 L .64054 .69021 L p .707 .577 .707 r
F P
0 g
s
.84589 .65756 m .84425 .6929 L .83716 .68039 L p .707 .577 .707 r
F P
0 g
s
.83716 .68039 m .83881 .64504 L .84589 .65756 L p .707 .577 .707 r
F P
0 g
s
.83804 .73976 m .83594 .75529 L .83974 .73713 L p .707 .577 .707 r
F P
0 g
s
.83974 .73713 m .84184 .7216 L .83804 .73976 L p .707 .577 .707 r
F P
0 g
s
.651 .56834 m .65241 .6248 L .6425 .63126 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63675 .72346 m .63885 .70793 L .64265 .68976 L p .707 .577 .707 r
F P
0 g
s
.64342 .67783 m .64507 .64248 L .65764 .63144 L p .707 .577 .707 r
F P
0 g
s
.42052 .62073 m .41708 .5656 L .38517 .56741 L p .707 .577 .707 r
F P
0 g
s
.41708 .5656 m .42052 .62073 L .45088 .61615 L p .707 .577 .707 r
F P
0 g
s
.45088 .61615 m .44744 .56102 L .41708 .5656 L p .707 .577 .707 r
F P
0 g
s
.38861 .62253 m .38517 .56741 L .35484 .56626 L p .707 .577 .707 r
F P
0 g
s
.38517 .56741 m .38861 .62253 L .42052 .62073 L p .707 .577 .707 r
F P
0 g
s
.64265 .68976 m .64055 .70529 L .63675 .72346 L p .707 .577 .707 r
F P
0 g
s
.83302 .56401 m .83443 .62047 L .81568 .61562 L p .707 .577 .707 r
F P
0 g
s
.81568 .61562 m .81426 .55916 L .83302 .56401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65241 .6248 m .651 .56834 L .66981 .5626 L p .707 .577 .707 r
F P
0 g
s
.44744 .56102 m .45088 .61615 L .47674 .60924 L p .707 .577 .707 r
F P
0 g
s
.47674 .60924 m .4733 .55411 L .44744 .56102 L p .707 .577 .707 r
F P
0 g
s
.84184 .7216 m .83974 .73713 L .8336 .71829 L p .707 .577 .707 r
F P
0 g
s
.8336 .71829 m .8357 .70276 L .84184 .7216 L p .707 .577 .707 r
F P
0 g
s
.35828 .62139 m .35484 .56626 L .32906 .56228 L p .707 .577 .707 r
F P
0 g
s
.35484 .56626 m .35828 .62139 L .38861 .62253 L p .707 .577 .707 r
F P
0 g
s
.65764 .63144 m .65599 .66679 L .64342 .67783 L p .707 .577 .707 r
F P
0 g
s
.83881 .64504 m .83716 .68039 L .82079 .66897 L p .707 .577 .707 r
F P
0 g
s
.82079 .66897 m .82244 .63362 L .83881 .64504 L p .707 .577 .707 r
F P
0 g
s
.66981 .5626 m .67123 .61906 L .65241 .6248 L p .707 .577 .707 r
F P
0 g
s
.64055 .70529 m .64265 .68976 L .65601 .67404 L p .707 .577 .707 r
F P
0 g
s
.40869 .67742 m .4129 .64025 L .38127 .63616 L p .707 .577 .707 r
F P
0 g
s
.4129 .64025 m .40869 .67742 L .4397 .6791 L p .707 .577 .707 r
F P
0 g
s
.4397 .6791 m .44391 .64193 L .4129 .64025 L p .707 .577 .707 r
F P
0 g
s
.37706 .67333 m .38127 .63616 L .3521 .63007 L p .707 .577 .707 r
F P
0 g
s
.38127 .63616 m .37706 .67333 L .40869 .67742 L p .707 .577 .707 r
F P
0 g
s
.65599 .66679 m .65764 .63144 L .67867 .62283 L p .707 .577 .707 r
F P
0 g
s
.4733 .55411 m .47674 .60924 L .49555 .60068 L p .707 .577 .707 r
F P
0 g
s
.49555 .60068 m .49211 .54555 L .4733 .55411 L p .707 .577 .707 r
F P
0 g
s
.32906 .56228 m .3325 .6174 L .35828 .62139 L p .707 .577 .707 r
F P
0 g
s
.65601 .67404 m .65391 .68957 L .64055 .70529 L p .707 .577 .707 r
F P
0 g
s
.3325 .6174 m .32906 .56228 L .31035 .55584 L p .707 .577 .707 r
F P
0 g
s
.81426 .55916 m .81568 .61562 L .78985 .61239 L p .707 .577 .707 r
F P
0 g
s
.78985 .61239 m .78843 .55593 L .81426 .55916 L p .707 .577 .707 r
F P
0 g
s
.44391 .64193 m .4397 .6791 L .46704 .67822 L p .707 .577 .707 r
F P
0 g
s
.46704 .67822 m .47125 .64105 L .44391 .64193 L p .707 .577 .707 r
F P
0 g
s
.67123 .61906 m .66981 .5626 L .69569 .55814 L p .707 .577 .707 r
F P
0 g
s
.3521 .63007 m .34789 .66725 L .37706 .67333 L p .707 .577 .707 r
F P
0 g
s
.39389 .71496 m .39924 .69681 L .36884 .68731 L p .707 .577 .707 r
F P
0 g
s
.39924 .69681 m .39389 .71496 L .42414 .72255 L p .707 .577 .707 r
F P
0 g
s
.42414 .72255 m .42949 .7044 L .39924 .69681 L p .707 .577 .707 r
F P
0 g
s
.8357 .70276 m .8336 .71829 L .81812 .70063 L p .707 .577 .707 r
F P
0 g
s
.81812 .70063 m .82022 .6851 L .8357 .70276 L p .707 .577 .707 r
F P
0 g
s
.34789 .66725 m .3521 .63007 L .32825 .62258 L p .707 .577 .707 r
F P
0 g
s
.36349 .70546 m .36884 .68731 L .34129 .67684 L p .707 .577 .707 r
F P
0 g
s
.36884 .68731 m .36349 .70546 L .39389 .71496 L p .707 .577 .707 r
F P
0 g
s
.82244 .63362 m .82079 .66897 L .79676 .65976 L p .707 .577 .707 r
F P
0 g
s
.79676 .65976 m .7984 .62441 L .82244 .63362 L p .707 .577 .707 r
F P
0 g
s
.67867 .62283 m .67702 .65818 L .65599 .66679 L p .707 .577 .707 r
F P
0 g
s
.34129 .67684 m .33595 .69499 L .36349 .70546 L p .707 .577 .707 r
F P
0 g
s
.42949 .7044 m .42414 .72255 L .45131 .7275 L p .707 .577 .707 r
F P
0 g
s
.45131 .7275 m .45666 .70935 L .42949 .7044 L p .707 .577 .707 r
F P
0 g
s
.65391 .68957 m .65601 .67404 L .67762 .66231 L p .707 .577 .707 r
F P
0 g
s
.69569 .55814 m .69711 .6146 L .67123 .61906 L p .707 .577 .707 r
F P
0 g
s
.32825 .62258 m .32404 .65975 L .34789 .66725 L p .707 .577 .707 r
F P
0 g
s
.31035 .55584 m .3138 .61096 L .3325 .6174 L p .707 .577 .707 r
F P
0 g
s
.47125 .64105 m .46704 .67822 L .48804 .67485 L p .707 .577 .707 r
F P
0 g
s
.48804 .67485 m .49225 .63768 L .47125 .64105 L p .707 .577 .707 r
F P
0 g
s
.67702 .65818 m .67867 .62283 L .7061 .61748 L p .707 .577 .707 r
F P
0 g
s
.78843 .55593 m .78985 .61239 L .75947 .61109 L p .707 .577 .707 r
F P
0 g
s
.75947 .61109 m .75805 .55463 L .78843 .55593 L p .707 .577 .707 r
F P
0 g
s
.69711 .6146 m .69569 .55814 L .7261 .55539 L p .707 .577 .707 r
F P
0 g
s
.33595 .69499 m .34129 .67684 L .31928 .66642 L p .707 .577 .707 r
F P
0 g
s
.49211 .54555 m .49555 .60068 L .50547 .59131 L p .707 .577 .707 r
F P
0 g
s
.50547 .59131 m .50203 .53618 L .49211 .54555 L p .707 .577 .707 r
F P
0 g
s
.31928 .66642 m .31394 .68457 L .33595 .69499 L p .707 .577 .707 r
F P
0 g
s
.67762 .66231 m .67552 .67784 L .65391 .68957 L p .707 .577 .707 r
F P
0 g
s
.3138 .61096 m .31035 .55584 L .30056 .54758 L p .707 .577 .707 r
F P
0 g
s
.32404 .65975 m .32825 .62258 L .31206 .61441 L p .707 .577 .707 r
F P
0 g
s
.7984 .62441 m .79676 .65976 L .7674 .65366 L p .707 .577 .707 r
F P
0 g
s
.7674 .65366 m .76904 .61832 L .7984 .62441 L p .707 .577 .707 r
F P
0 g
s
.45666 .70935 m .45131 .7275 L .47272 .72931 L p .707 .577 .707 r
F P
0 g
s
.47272 .72931 m .47807 .71116 L .45666 .70935 L p .707 .577 .707 r
F P
0 g
s
.82022 .6851 m .81812 .70063 L .79483 .68587 L p .707 .577 .707 r
F P
0 g
s
.79483 .68587 m .79693 .67034 L .82022 .6851 L p .707 .577 .707 r
F P
0 g
s
.75805 .55463 m .75947 .61109 L .72751 .61185 L p .707 .577 .707 r
F P
0 g
s
.72751 .61185 m .7261 .55539 L .75805 .55463 L p .707 .577 .707 r
F P
0 g
s
.7261 .55539 m .72751 .61185 L .69711 .6146 L p .707 .577 .707 r
F P
0 g
s
.7061 .61748 m .70445 .65283 L .67702 .65818 L p .707 .577 .707 r
F P
0 g
s
.67552 .67784 m .67762 .66231 L .70537 .65571 L p .707 .577 .707 r
F P
0 g
s
.70445 .65283 m .7061 .61748 L .73724 .61593 L p .707 .577 .707 r
F P
0 g
s
.31206 .61441 m .30785 .65158 L .32404 .65975 L p .707 .577 .707 r
F P
0 g
s
.76904 .61832 m .7674 .65366 L .73559 .65127 L p .707 .577 .707 r
F P
0 g
s
.73559 .65127 m .73724 .61593 L .76904 .61832 L p .707 .577 .707 r
F P
0 g
s
.73724 .61593 m .73559 .65127 L .70445 .65283 L p .707 .577 .707 r
F P
0 g
s
.31394 .68457 m .31928 .66642 L .30497 .65707 L p .707 .577 .707 r
F P
0 g
s
.49225 .63768 m .48804 .67485 L .50064 .66934 L p .707 .577 .707 r
F P
0 g
s
.50064 .66934 m .50485 .63216 L .49225 .63768 L p .707 .577 .707 r
F P
0 g
s
.30056 .54758 m .304 .60271 L .3138 .61096 L p .707 .577 .707 r
F P
0 g
s
.70537 .65571 m .70327 .67124 L .67552 .67784 L p .707 .577 .707 r
F P
0 g
s
.30497 .65707 m .29962 .67522 L .31394 .68457 L p .707 .577 .707 r
F P
0 g
s
.79693 .67034 m .79483 .68587 L .766 .67546 L p .707 .577 .707 r
F P
0 g
s
.766 .67546 m .7681 .65993 L .79693 .67034 L p .707 .577 .707 r
F P
0 g
s
.70327 .67124 m .70537 .65571 L .73655 .65489 L p .707 .577 .707 r
F P
0 g
s
.50203 .53618 m .50547 .59131 L .50553 .58204 L p .707 .577 .707 r
F P
0 g
s
.50553 .58204 m .50209 .52691 L .50203 .53618 L p .707 .577 .707 r
F P
0 g
s
.47807 .71116 m .47272 .72931 L .48628 .72782 L p .707 .577 .707 r
F P
0 g
s
.48628 .72782 m .49163 .70967 L .47807 .71116 L p .707 .577 .707 r
F P
0 g
s
.30785 .65158 m .31206 .61441 L .3051 .60637 L p .707 .577 .707 r
F P
0 g
s
.7681 .65993 m .766 .67546 L .73445 .67042 L p .707 .577 .707 r
F P
0 g
s
.73445 .67042 m .73655 .65489 L .7681 .65993 L p .707 .577 .707 r
F P
0 g
s
.73655 .65489 m .73445 .67042 L .70327 .67124 L p .707 .577 .707 r
F P
0 g
s
.304 .60271 m .30056 .54758 L .30062 .53832 L p .707 .577 .707 r
F P
0 g
s
.3051 .60637 m .30089 .64354 L .30785 .65158 L p .707 .577 .707 r
F P
0 g
s
.29962 .67522 m .30497 .65707 L .29975 .64971 L p .707 .577 .707 r
F P
0 g
s
.50485 .63216 m .50064 .66934 L .50361 .66221 L p .707 .577 .707 r
F P
0 g
s
.50361 .66221 m .50782 .62503 L .50485 .63216 L p .707 .577 .707 r
F P
0 g
s
.29975 .64971 m .2944 .66786 L .29962 .67522 L p .707 .577 .707 r
F P
0 g
s
.30062 .53832 m .30406 .59344 L .304 .60271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49163 .70967 m .48628 .72782 L .49066 .72316 L p .707 .577 .707 r
F P
0 g
s
.49066 .72316 m .49601 .70501 L .49163 .70967 L p .707 .577 .707 r
F P
0 g
s
.50209 .52691 m .50553 .58204 L .49573 .57378 L p .707 .577 .707 r
F P
0 g
s
.49573 .57378 m .49229 .51866 L .50209 .52691 L p .707 .577 .707 r
F P
0 g
s
.30089 .64354 m .3051 .60637 L .30807 .59924 L p .707 .577 .707 r
F P
0 g
s
.30406 .59344 m .30062 .53832 L .31054 .52894 L p .707 .577 .707 r
F P
0 g
s
.30807 .59924 m .30386 .63641 L .30089 .64354 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2944 .66786 m .29975 .64971 L .30413 .64505 L p .707 .577 .707 r
F P
0 g
s
.50782 .62503 m .50361 .66221 L .49665 .65416 L p .707 .577 .707 r
F P
0 g
s
.49665 .65416 m .50086 .61699 L .50782 .62503 L p .707 .577 .707 r
F P
0 g
s
.30413 .64505 m .29878 .6632 L .2944 .66786 L p .707 .577 .707 r
F P
0 g
s
.31054 .52894 m .31398 .58407 L .30406 .59344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49229 .51866 m .49573 .57378 L .47703 .56735 L p .707 .577 .707 r
F P
0 g
s
.47703 .56735 m .47359 .51222 L .49229 .51866 L p .707 .577 .707 r
F P
0 g
s
.49601 .70501 m .49066 .72316 L .48544 .7158 L p .707 .577 .707 r
F P
0 g
s
.48544 .7158 m .49079 .69765 L .49601 .70501 L p .707 .577 .707 r
F P
0 g
s
.30386 .63641 m .30807 .59924 L .32067 .59372 L p .707 .577 .707 r
F P
0 g
s
.31398 .58407 m .31054 .52894 L .32935 .52038 L p .707 .577 .707 r
F P
0 g
s
.32067 .59372 m .31646 .63089 L .30386 .63641 L p .707 .577 .707 r
F P
0 g
s
.29878 .6632 m .30413 .64505 L .31769 .64356 L p .707 .577 .707 r
F P
0 g
s
.32935 .52038 m .33279 .57551 L .31398 .58407 L p .707 .577 .707 r
F P
0 g
s
.50086 .61699 m .49665 .65416 L .48046 .646 L p .707 .577 .707 r
F P
0 g
s
.48046 .646 m .48467 .60882 L .50086 .61699 L p .707 .577 .707 r
F P
0 g
s
.31769 .64356 m .31234 .66171 L .29878 .6632 L p .707 .577 .707 r
F P
0 g
s
.47359 .51222 m .47703 .56735 L .45125 .56336 L p .707 .577 .707 r
F P
0 g
s
.45125 .56336 m .44781 .50824 L .47359 .51222 L p .707 .577 .707 r
F P
0 g
s
.33279 .57551 m .32935 .52038 L .3552 .51348 L p .707 .577 .707 r
F P
0 g
s
.49079 .69765 m .48544 .7158 L .47113 .70645 L p .707 .577 .707 r
F P
0 g
s
.47113 .70645 m .47647 .6883 L .49079 .69765 L p .707 .577 .707 r
F P
0 g
s
.31646 .63089 m .32067 .59372 L .34167 .59035 L p .707 .577 .707 r
F P
0 g
s
.34167 .59035 m .33746 .62753 L .31646 .63089 L p .707 .577 .707 r
F P
0 g
s
.44781 .50824 m .45125 .56336 L .42092 .56221 L p .707 .577 .707 r
F P
0 g
s
.42092 .56221 m .41748 .50709 L .44781 .50824 L p .707 .577 .707 r
F P
0 g
s
.3552 .51348 m .35865 .5686 L .33279 .57551 L p .707 .577 .707 r
F P
0 g
s
.35865 .5686 m .3552 .51348 L .38557 .50889 L p .707 .577 .707 r
F P
0 g
s
.48467 .60882 m .48046 .646 L .45661 .6385 L p .707 .577 .707 r
F P
0 g
s
.45661 .6385 m .46082 .60133 L .48467 .60882 L p .707 .577 .707 r
F P
0 g
s
.31234 .66171 m .31769 .64356 L .3391 .64538 L p .707 .577 .707 r
F P
0 g
s
.3391 .64538 m .33375 .66353 L .31234 .66171 L p .707 .577 .707 r
F P
0 g
s
.41748 .50709 m .42092 .56221 L .38901 .56402 L p .707 .577 .707 r
F P
0 g
s
.38901 .56402 m .38557 .50889 L .41748 .50709 L p .707 .577 .707 r
F P
0 g
s
.38557 .50889 m .38901 .56402 L .35865 .5686 L p .707 .577 .707 r
F P
0 g
s
.33746 .62753 m .34167 .59035 L .36901 .58947 L p .707 .577 .707 r
F P
0 g
s
.47647 .6883 m .47113 .70645 L .44912 .69603 L p .707 .577 .707 r
F P
0 g
s
.44912 .69603 m .45446 .67788 L .47647 .6883 L p .707 .577 .707 r
F P
0 g
s
.36901 .58947 m .3648 .62664 L .33746 .62753 L p .707 .577 .707 r
F P
0 g
s
.46082 .60133 m .45661 .6385 L .42744 .63241 L p .707 .577 .707 r
F P
0 g
s
.42744 .63241 m .43165 .59524 L .46082 .60133 L p .707 .577 .707 r
F P
0 g
s
.33375 .66353 m .3391 .64538 L .36627 .65032 L p .707 .577 .707 r
F P
0 g
s
.3648 .62664 m .36901 .58947 L .40002 .59115 L p .707 .577 .707 r
F P
0 g
s
.36627 .65032 m .36092 .66847 L .33375 .66353 L p .707 .577 .707 r
F P
0 g
s
.43165 .59524 m .42744 .63241 L .39581 .62833 L p .707 .577 .707 r
F P
0 g
s
.39581 .62833 m .40002 .59115 L .43165 .59524 L p .707 .577 .707 r
F P
0 g
s
.45446 .67788 m .44912 .69603 L .42157 .68556 L p .707 .577 .707 r
F P
0 g
s
.42157 .68556 m .42692 .66741 L .45446 .67788 L p .707 .577 .707 r
F P
0 g
s
.40002 .59115 m .39581 .62833 L .3648 .62664 L p .707 .577 .707 r
F P
0 g
s
.36092 .66847 m .36627 .65032 L .39652 .65791 L p .707 .577 .707 r
F P
0 g
s
.39652 .65791 m .39117 .67606 L .36092 .66847 L p .707 .577 .707 r
F P
0 g
s
.42692 .66741 m .42157 .68556 L .39117 .67606 L p .707 .577 .707 r
F P
0 g
s
.39117 .67606 m .39652 .65791 L .42692 .66741 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1@00L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JGoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomo
o`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Moo`00IGoo0P00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00
IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001UOol20004FUHH000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo001U
Ool60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00Hgoo10001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005moo`@00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP00IGoo
001LOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJ
EP00IGoo001JOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00F7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Moo`80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUIJEP00IGoo001FOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH01000FUIJEP00IGoo001EOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001UOol005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00@005YFFUH006Eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF001U
Ool005Eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP004Woo4P00@Goo001EOol01000FUIJEP001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04
001JEUYF000<Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000iOol005Eoo`05001JEUYF
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF00@005YFFUH000Qoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH6000cOol005Eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0000
0eYF000000060003FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00@005YFFUH000Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<0031oo`00EGoo0P000UYF00<005YFFUH00UYF
00<005YFFUH00eYF3`000eYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YFFUH000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEUYF001oo`030002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000^Ool005Eoo`80009JEP03001JEUYF009JEP03001JEP0000@000QJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP00;Goo001EOol20002FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUH000020004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00;Goo001FOol01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF10002UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF00@005YFFUH002eoo`00EWoo00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEUYF000]Ool005Ioo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002eoo`00EWoo10000eYF00<005YF00003P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEUYF000]Ool005Ioo`05001JEUYF001JEP040002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH:
0009FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002eoo`00>goo5`0017oo00<005YFFUH00`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF1P0015YF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF0000;Goo000gOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040006
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool003=oo`@000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0002eoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF0000;Goo000_Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH0000]Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJ
EPh000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP0002eoo`00;Goo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF
FUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP0500000eYF0000000C0004FUH01000FUIJ
EUYF1P000eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00D0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000@000IJEP03001JEUYF00@00003
FUH007oo02aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30002FUH50005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03FUH3000]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0002FUH01000FUIJEUYF600015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000`000UYF
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF0000
05YF0005FUH00`00FUH0000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF000000040005FUH50004FUH00`00FUH00004
0002FUH60006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00009FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH30004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<005YF0000;Goo000/
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH015YF00@005YFFUIJEP/0009JEP03001JEUYF00=JEP@0009JEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP03001JEP00009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEUYF00MJEP@000EJEP03001JEUYF
009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01`00FUH0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEPH002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00<00003FUH0000001800003FUH005YF00=JEP04001JEUYF0009FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF3`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH@0005FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEUYF0004FUH01000FUIJEUYF2000
27oo0`001Goo100000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF00AJEQD000IJEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00;7oo00@005YFFUH000AJ
EPH000eoo`D000Qoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEUYF001JEP002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF01<000Ioo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00;7oo00@0
05YFFUH0009JEP<000EJEPH000Moo`D000Ioo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP02FUH800000eYF001JEP07FUH00`00FUIJEP02FUH60004Ool40005FUH00`00FUIJEP02FUH00`00
FUH0000/Ool002aoo`03001JEUYF00<0009JEP03001JEUYF00EJEP04001JEUYFFUHB00000eYF0000
000;0007FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YF00000P0000AJEP00000000AJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00
0006Ool20003FUH01@00FUIJEUYF00000UYF00<007ooOol0:Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00=JEP03001JEP0000AJ
EP800004FUH005YFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF00000eYF0P000UYF0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
FUIJEP<000Eoo`800003FUH005YF009JEP04001JEUYF000/Ool002aoo`04001JEP000004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH01000FUH00000
15YF00<005YF000010001UYF00<005YFFUH01eYF00<005YF00000P001UYF00<005YFFUH00eYF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000UYF
00<005YFFUH00P000UYF00<005YFFUH00eYF3@001UYF00<005YFFUH01EYF0P001Goo0P000eYF00@0
05YFFUH002aoo`00;7oo0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF0P0015YF00@005YFFUIJEP80009JEP800003FUH00000009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP04001JEUYFFUH6000<FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH0000200000eYF00000004FUH00`00FUH000040009
Ool70002FUH00`00FUIJEP06FUH30005Ool01000FUIJEP000UYF00<007ooOol0:Woo000/Ool01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000IJEP<00004FUH000000005FUH50007FUH00`00FUIJEP05FUH80005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01000FUH005YF0`001EYF0P00
0UYF00<005YF00002Goo1@000Woo10001eYF00<005YFFUH00P0017oo0`0000=JEP00Ool0;7oo000/
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0000=JEP00FUH01UYF00<005YF00000`001EYF00<005YFFUH01P000UYF00<005YFFUH01eYF
0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00L005YF
001JEP00FUH00003FUH20004FUH00`00FUH0000:Ool30007Ool20004FUH00`00FUIJEP03FUH20003
Ool200000eYF001oo`0/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00UYF0P001EYF00<005YF
000010000UYF10001eYF00@005YFFUIJEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEP00FUH20002FUH200000eYF00000002000015YF001JEP00
5Woo0`0000=JEP00FUH01UYF1@0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP<0009JEP03001JEP0000@0009JEP04001JEUYFFUH20005FUH00`00FUIJEP03FUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH01@00FUH00000
FUH00`0000=JEP00FUH015YF10006Goo0P001eYF0P0000=JEP00FUH00P00;Goo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHL00000eYF001JEP07FUH00`00FUH0000200000eYF
000000030002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH20004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YF00000`0067oo0P001EYF00D005YF000005YF008002eoo`00;Woo0P0015YF00<005YFFUH0
0eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000MJEP03001JEUYF009J
EPD000=JEP03001JEUYF00IJEP8000IJEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH70009Ool900000eYF00000002FUH00`00FUIJEP020002FUH00`00Oomoo`0[Ool002mo
o`8000=JEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000004FUH00`00FUIJEP06FUH400000eYF001JEP09FUH20004FUH00`00FUIJEP02FUH0
0`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH000020003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH30003
FUH01000FUIJEP00;Goo000`Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH025YF00<005YFFUH0
10002EYF0`0000=JEP00FUH015YF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YF0000;Goo000^Ool30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP@000MJEP03001JEUYF00EJEPH000=JEP03001JEUYF008000AJEP04001JEP00000<FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF0000
;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80009JEP8000EJEP03001JEUYF
00MJEP04001JEUYFFUH60002FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP04001JEP000002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH01P000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH00UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0002ioo`00:goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH20005FUH00`00FUH000030007FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01`00FUH005YF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEPL0
0003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00=JEP@000QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800003FUH007oo02eoo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
1EYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00000P000UYF
1`0000=JEP00FUH01UYF00<005YFFUH00UYF1@0025YF00<005YFFUH01EYF00@005YFFUIJEP800005
Ool005YFFUH0000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001J
EUYF00IJEPL000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH000040006FUH00`00
FUIJEP02FUH50008FUH00`00FUIJEP05FUH01000FUH000000goo00@005YFFUH002eoo`00:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH015YF1`00
0eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YFFUH00P001EYF00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF009J
EPD000QJEP03001JEUYF009JEPD000Ioo`03001JEP0002eoo`00:goo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YF00001@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00UYF0P0000=JEP0000001UYF00@005YFFUIJEP<000=oo`L00003FUH0
0000008000AJEPT000]oo`<002eoo`00;7oo00EJEP00FUIJEP0000EJEP03001JEUYF009JEPP000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP800004
FUH005YF0005FUH01`00FUIJEUYF001JEP0000Yoo`T001Eoo`03001oogoo02aoo`00;7oo00EJEP00
FUIJEP0000=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0002Qoo`03001oogoo02aoo`00;7oo00=JEP00FUH01@001EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF009JEP07
001JEUYFFUH005YF0000:7oo00<007ooOol0;7oo000/Ool00eYF00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUH00004FUH01@00FUIJEUYF00000eYF
00<005YF00009goo0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@0000=oo`0000001EYF
00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001EYF00<005YFFUH01eYF
00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP04001JEUYFFUH2000VOol2000_Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70006Ool20005FUH00`00FUIJEP05FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP030003
FUH2000UOol00`00FUH0000_Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ<0009oo`8000EJEP03001JEUYF009JEP<0009JEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP@000EJEP03001JEUYF009JEP08001J
EUYF001oo`00FUH000AJEP80009JEP03001JEP0002=oo`04001JEUYF000_Ool0031oobP000=JEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH400000eYF001JEP03FUH01000FUIJ
EP000Woo0P001UYF0`0000=JEP00Ool087oo0`0000=JEP00Ool0;goo0016Ool90004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP050006FUH0
0`00FUH00002000POol00`00FUIJEP02000aOol003ioo`P000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000D00004FUH000000003FUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00
0eYF0`0015YF00@005YFFUIJEP<001aoo`80009JEP03001JEP00035oo`00=goo1`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEPD000=JEP04001JEUYFFUH300000eYF00000003FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH01@00FUIJEUYF00000UYF00@005YFFUH000MJEP@001Io
o`8000AJEP80039oo`00<Goo1P000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
100000=JEP00FUH01EYF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000AJEP03001JEUYF00<000QJEP03001JEUYF00@000ioo`@00003FUH005YF00=JEP03001o
ogoo035oo`00;Woo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00001P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF000015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF3P0015YF00@005YFFUIJ
EP8003Aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH04@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP0000001@000eYF0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000003Ioo`00;7oo40000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF0`0000Aoo`00FUH000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP02FUH800000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000hOol0
02aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH40003Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP03FUH200000goo000000070004FUH00`00FUIJEP06FUH00`00
FUIJEP04000kOol002aoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEPL000Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8000EJEP03001JEUYF00=JEP05001oogoo001JEP020005Ool@000oOol002eoo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT000moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH20003Ool01000FUIJEP00
E7oo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000IOol00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00@005YF000000Aoo`80009JEP03001o
ogoo059oo`00;Goo0`000UYF00@005YFFUIJEPl002=oo`8000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
001JEP001UYF0`0017oo0P000UYF00<005YF0000E7oo000`Ool6000dOol200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP040006Ool00`00FUIJEP02FUH2001EOol006aoo`@000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP<0009JEPD000Qo
o`<000EJEP03001oogoo05=oo`00L7oo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH0100000=JEP0000000P0037oo00D005YFFUIJEP0000=J
EP03001oogoo05Aoo`00M7oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF
2P003Woo0P0015YF00@005YFFUH005Moo`00NGoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01P001Goo1@003Goo00<005YFFUH01EYF0P00F7oo001oOolO000;Ool5000;Ool30007
FUH00`00Oomoo`1GOol0091oo`03001JEUYF009JEP03001oogoo019oo`<000Yoo`8000=JEP03001J
EUYF009JEP8005Yoo`00Sgoo00<005YF00000UYF00<007ooOol07Woo0P001EYF00D005YFFUIJEP00
05aoo`00Sgoo00D005YF001JEP0001moo`8000QJEP<005eoo`00Sgoo00<005YFFUH00P0077oo0`00
00=JEP00FUH01eYF00<007ooOol0GGoo002?Ool01000FUIJEP006Woo0`0015YF00<005YFFUH015YF
0P00H7oo002@Ool00eYF001oo`0FOol40008FUH01000FUIJEUYF0P00HWoo002@Ool00eYF0000000B
Ool40002FUH00`00FUIJEP07FUH01000FUH00000I7oo002@Ool200000eYF0000000@0007FUH00`00
FUIJEP05FUH3001VOol0095oo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001YOol0095oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP00008006]oo`00TWoo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
06ioo`00Tgoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01000LWoo002EOolB001f
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58557 .74796 m .58772 .6922 L .55702 .68884 L p .707 .577 .707 r
F P
0 g
s
.58772 .6922 m .58557 .74796 L .61749 .74884 L p .707 .577 .707 r
F P
0 g
s
.61749 .74884 m .61965 .69308 L .58772 .6922 L p .707 .577 .707 r
F P
0 g
s
.61965 .69308 m .61749 .74884 L .64752 .74716 L p .707 .577 .707 r
F P
0 g
s
.64752 .74716 m .64968 .6914 L .61965 .69308 L p .707 .577 .707 r
F P
0 g
s
.55487 .7446 m .55702 .68884 L .53057 .68333 L p .707 .577 .707 r
F P
0 g
s
.55702 .68884 m .55487 .7446 L .58557 .74796 L p .707 .577 .707 r
F P
0 g
s
.64968 .6914 m .64752 .74716 L .67272 .74308 L p .707 .577 .707 r
F P
0 g
s
.67272 .74308 m .67488 .68731 L .64968 .6914 L p .707 .577 .707 r
F P
0 g
s
.61342 .81155 m .61074 .77486 L .57886 .77678 L p .707 .577 .707 r
F P
0 g
s
.61074 .77486 m .61342 .81155 L .64397 .80682 L p .707 .577 .707 r
F P
0 g
s
.64397 .80682 m .64129 .77013 L .61074 .77486 L p .707 .577 .707 r
F P
0 g
s
.53057 .68333 m .52841 .7391 L .55487 .7446 L p .707 .577 .707 r
F P
0 g
s
.58154 .81347 m .57886 .77678 L .54876 .7757 L p .707 .577 .707 r
F P
0 g
s
.57886 .77678 m .58154 .81347 L .61342 .81155 L p .707 .577 .707 r
F P
0 g
s
.52841 .7391 m .53057 .68333 L .51093 .67622 L p .707 .577 .707 r
F P
0 g
s
.64129 .77013 m .64397 .80682 L .67018 .79975 L p .707 .577 .707 r
F P
0 g
s
.67018 .79975 m .6675 .76305 L .64129 .77013 L p .707 .577 .707 r
F P
0 g
s
.67488 .68731 m .67272 .74308 L .69062 .737 L p .707 .577 .707 r
F P
0 g
s
.69062 .737 m .69278 .68123 L .67488 .68731 L p .707 .577 .707 r
F P
0 g
s
.55144 .81239 m .54876 .7757 L .52339 .77173 L p .707 .577 .707 r
F P
0 g
s
.54876 .7757 m .55144 .81239 L .58154 .81347 L p .707 .577 .707 r
F P
0 g
s
.51093 .67622 m .50878 .73198 L .52841 .7391 L p .707 .577 .707 r
F P
0 g
s
.61662 .85538 m .61316 .83751 L .58176 .84242 L p .707 .577 .707 r
F P
0 g
s
.61316 .83751 m .61662 .85538 L .64697 .84738 L p .707 .577 .707 r
F P
0 g
s
.64697 .84738 m .64351 .82952 L .61316 .83751 L p .707 .577 .707 r
F P
0 g
s
.58522 .86029 m .58176 .84242 L .55236 .84377 L p .707 .577 .707 r
F P
0 g
s
.58176 .84242 m .58522 .86029 L .61662 .85538 L p .707 .577 .707 r
F P
0 g
s
.52339 .77173 m .52607 .80842 L .55144 .81239 L p .707 .577 .707 r
F P
0 g
s
.6675 .76305 m .67018 .79975 L .6895 .79101 L p .707 .577 .707 r
F P
0 g
s
.6895 .79101 m .68682 .75432 L .6675 .76305 L p .707 .577 .707 r
F P
0 g
s
.64351 .82952 m .64697 .84738 L .67329 .83709 L p .707 .577 .707 r
F P
0 g
s
.67329 .83709 m .66983 .81922 L .64351 .82952 L p .707 .577 .707 r
F P
0 g
s
.50878 .73198 m .51093 .67622 L .50005 .66819 L p .707 .577 .707 r
F P
0 g
s
.55236 .84377 m .55582 .86164 L .58522 .86029 L p .707 .577 .707 r
F P
0 g
s
.52607 .80842 m .52339 .77173 L .50524 .76525 L p .707 .577 .707 r
F P
0 g
s
.69278 .68123 m .69062 .737 L .69947 .72951 L p .707 .577 .707 r
F P
0 g
s
.69947 .72951 m .70163 .67375 L .69278 .68123 L p .707 .577 .707 r
F P
0 g
s
.55582 .86164 m .55236 .84377 L .52786 .84142 L p .707 .577 .707 r
F P
0 g
s
.66983 .81922 m .67329 .83709 L .693 .8255 L p .707 .577 .707 r
F P
0 g
s
.693 .8255 m .68954 .80763 L .66983 .81922 L p .707 .577 .707 r
F P
0 g
s
.52786 .84142 m .53132 .85929 L .55582 .86164 L p .707 .577 .707 r
F P
0 g
s
.50524 .76525 m .50792 .80194 L .52607 .80842 L p .707 .577 .707 r
F P
0 g
s
.50005 .66819 m .49789 .72395 L .50878 .73198 L p .707 .577 .707 r
F P
0 g
s
.68682 .75432 m .6895 .79101 L .70004 .78148 L p .707 .577 .707 r
F P
0 g
s
.70004 .78148 m .69736 .74479 L .68682 .75432 L p .707 .577 .707 r
F P
0 g
s
.53132 .85929 m .52786 .84142 L .51065 .8356 L p .707 .577 .707 r
F P
0 g
s
.50792 .80194 m .50524 .76525 L .49607 .7569 L p .707 .577 .707 r
F P
0 g
s
.49789 .72395 m .50005 .66819 L .49898 .66003 L p .707 .577 .707 r
F P
0 g
s
.51065 .8356 m .51411 .85347 L .53132 .85929 L p .707 .577 .707 r
F P
0 g
s
.68954 .80763 m .693 .8255 L .70418 .81375 L p .707 .577 .707 r
F P
0 g
s
.70418 .81375 m .70071 .79588 L .68954 .80763 L p .707 .577 .707 r
F P
0 g
s
.70163 .67375 m .69947 .72951 L .6984 .72136 L p .707 .577 .707 r
F P
0 g
s
.6984 .72136 m .70055 .66559 L .70163 .67375 L p .707 .577 .707 r
F P
0 g
s
.49607 .7569 m .49875 .79359 L .50792 .80194 L p .707 .577 .707 r
F P
0 g
s
.49898 .66003 m .49682 .7158 L .49789 .72395 L p .707 .577 .707 r
F P
0 g
s
.69736 .74479 m .70004 .78148 L .70076 .77208 L p .707 .577 .707 r
F P
0 g
s
.70076 .77208 m .69808 .73539 L .69736 .74479 L p .707 .577 .707 r
F P
0 g
s
.49875 .79359 m .49607 .7569 L .49679 .7475 L p .707 .577 .707 r
F P
0 g
s
.49682 .7158 m .49898 .66003 L .50782 .65254 L p .707 .577 .707 r
F P
0 g
s
.49679 .7475 m .49947 .78419 L .49875 .79359 L p .707 .577 .707 r
F P
0 g
s
.50782 .65254 m .50567 .70831 L .49682 .7158 L p .707 .577 .707 r
F P
0 g
s
.49947 .78419 m .49679 .7475 L .50733 .73797 L p .707 .577 .707 r
F P
0 g
s
.49737 .82192 m .49737 .32003 L .45293 .31792 L p .707 .577 .707 r
F P
0 g
s
.51411 .85347 m .51065 .8356 L .50242 .82689 L p .707 .577 .707 r
F P
0 g
s
.50242 .82689 m .50588 .84475 L .51411 .85347 L p .707 .577 .707 r
F P
0 g
s
.50588 .84475 m .50242 .82689 L .50396 .81613 L p .707 .577 .707 r
F P
0 g
s
.50567 .70831 m .50782 .65254 L .52572 .64646 L p .707 .577 .707 r
F P
0 g
s
.50396 .81613 m .50743 .834 L .50588 .84475 L p .707 .577 .707 r
F P
0 g
s
.50733 .73797 m .51001 .77466 L .49947 .78419 L p .707 .577 .707 r
F P
0 g
s
.52572 .64646 m .52357 .70223 L .50567 .70831 L p .707 .577 .707 r
F P
0 g
s
.50743 .834 m .50396 .81613 L .51514 .80438 L p .707 .577 .707 r
F P
0 g
s
.52357 .70223 m .52572 .64646 L .55092 .64238 L p .707 .577 .707 r
F P
0 g
s
.51001 .77466 m .50733 .73797 L .52665 .72924 L p .707 .577 .707 r
F P
0 g
s
.51514 .80438 m .5186 .82225 L .50743 .834 L p .707 .577 .707 r
F P
0 g
s
.52665 .72924 m .52933 .76593 L .51001 .77466 L p .707 .577 .707 r
F P
0 g
s
.55092 .64238 m .54877 .69815 L .52357 .70223 L p .707 .577 .707 r
F P
0 g
s
.52933 .76593 m .52665 .72924 L .55286 .72216 L p .707 .577 .707 r
F P
0 g
s
.5186 .82225 m .51514 .80438 L .53485 .79279 L p .707 .577 .707 r
F P
0 g
s
.53485 .79279 m .53831 .81066 L .5186 .82225 L p .707 .577 .707 r
F P
0 g
s
.55286 .72216 m .55554 .75885 L .52933 .76593 L p .707 .577 .707 r
F P
0 g
s
.53831 .81066 m .53485 .79279 L .56117 .78249 L p .707 .577 .707 r
F P
0 g
s
.56117 .78249 m .56463 .80036 L .53831 .81066 L p .707 .577 .707 r
F P
0 g
s
.49737 .32003 m .49737 .82192 L .54207 .82024 L p .707 .577 .707 r
F P
0 g
s
.54207 .82024 m .54207 .31835 L .49737 .32003 L p .707 .577 .707 r
F P
0 g
s
.54877 .69815 m .55092 .64238 L .58096 .6407 L p .707 .577 .707 r
F P
0 g
s
.58096 .6407 m .5788 .69647 L .54877 .69815 L p .707 .577 .707 r
F P
0 g
s
.55554 .75885 m .55286 .72216 L .58341 .71743 L p .707 .577 .707 r
F P
0 g
s
.58341 .71743 m .58609 .75412 L .55554 .75885 L p .707 .577 .707 r
F P
0 g
s
.56463 .80036 m .56117 .78249 L .59152 .7745 L p .707 .577 .707 r
F P
0 g
s
.59152 .7745 m .59498 .79237 L .56463 .80036 L p .707 .577 .707 r
F P
0 g
s
.54207 .31835 m .54207 .82024 L .58264 .81494 L p .707 .577 .707 r
F P
0 g
s
.5788 .69647 m .58096 .6407 L .61288 .64158 L p .707 .577 .707 r
F P
0 g
s
.61288 .64158 m .61073 .69735 L .5788 .69647 L p .707 .577 .707 r
F P
0 g
s
.58264 .81494 m .58264 .31305 L .54207 .31835 L p .707 .577 .707 r
F P
0 g
s
.45293 .8198 m .45293 .31792 L .4131 .31222 L p .707 .577 .707 r
F P
0 g
s
.45293 .31792 m .45293 .8198 L .49737 .82192 L p .707 .577 .707 r
F P
0 g
s
.70071 .79588 m .70418 .81375 L .70572 .80299 L p .707 .577 .707 r
F P
0 g
s
.70572 .80299 m .70226 .78512 L .70071 .79588 L p .707 .577 .707 r
F P
0 g
s
.70055 .66559 m .6984 .72136 L .68752 .71333 L p .707 .577 .707 r
F P
0 g
s
.68752 .71333 m .68967 .65756 L .70055 .66559 L p .707 .577 .707 r
F P
0 g
s
.61529 .71551 m .61797 .7522 L .58609 .75412 L p .707 .577 .707 r
F P
0 g
s
.58609 .75412 m .58341 .71743 L .61529 .71551 L p .707 .577 .707 r
F P
0 g
s
.62292 .76959 m .62638 .78746 L .59498 .79237 L p .707 .577 .707 r
F P
0 g
s
.59498 .79237 m .59152 .7745 L .62292 .76959 L p .707 .577 .707 r
F P
0 g
s
.58264 .31305 m .58264 .81494 L .61513 .80653 L p .707 .577 .707 r
F P
0 g
s
.64358 .64494 m .64143 .7007 L .61073 .69735 L p .707 .577 .707 r
F P
0 g
s
.61073 .69735 m .61288 .64158 L .64358 .64494 L p .707 .577 .707 r
F P
0 g
s
.61513 .80653 m .61513 .30465 L .58264 .31305 L p .707 .577 .707 r
F P
0 g
s
.69808 .73539 m .70076 .77208 L .69159 .76373 L p .707 .577 .707 r
F P
0 g
s
.69159 .76373 m .68891 .72704 L .69808 .73539 L p .707 .577 .707 r
F P
0 g
s
.4131 .81411 m .4131 .31222 L .38178 .30351 L p .707 .577 .707 r
F P
0 g
s
.4131 .31222 m .4131 .81411 L .45293 .8198 L p .707 .577 .707 r
F P
0 g
s
.2453 .71487 m .2462 .65995 L .21549 .65678 L p .707 .577 .707 r
F P
0 g
s
.2462 .65995 m .2453 .71487 L .27725 .71501 L p .707 .577 .707 r
F P
0 g
s
.27725 .71501 m .27815 .66009 L .2462 .65995 L p .707 .577 .707 r
F P
0 g
s
.27815 .66009 m .27725 .71501 L .3073 .71212 L p .707 .577 .707 r
F P
0 g
s
.3073 .71212 m .3082 .6572 L .27815 .66009 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70226 .78512 m .70572 .80299 L .69749 .79428 L p .707 .577 .707 r
F P
0 g
s
.69749 .79428 m .69403 .77641 L .70226 .78512 L p .707 .577 .707 r
F P
0 g
s
.21459 .7117 m .21549 .65678 L .18901 .65091 L p .707 .577 .707 r
F P
0 g
s
.21549 .65678 m .21459 .7117 L .2453 .71487 L p .707 .577 .707 r
F P
0 g
s
.68967 .65756 m .68752 .71333 L .66788 .70621 L p .707 .577 .707 r
F P
0 g
s
.66788 .70621 m .67004 .65045 L .68967 .65756 L p .707 .577 .707 r
F P
0 g
s
.3082 .6572 m .3073 .71212 L .3325 .70648 L p .707 .577 .707 r
F P
0 g
s
.3325 .70648 m .33341 .65156 L .3082 .6572 L p .707 .577 .707 r
F P
0 g
s
.64539 .71659 m .64807 .75328 L .61797 .7522 L p .707 .577 .707 r
F P
0 g
s
.61797 .7522 m .61529 .71551 L .64539 .71659 L p .707 .577 .707 r
F P
0 g
s
.65232 .76824 m .65578 .78611 L .62638 .78746 L p .707 .577 .707 r
F P
0 g
s
.62638 .78746 m .62292 .76959 L .65232 .76824 L p .707 .577 .707 r
F P
0 g
s
.61513 .30465 m .61513 .80653 L .63635 .79585 L p .707 .577 .707 r
F P
0 g
s
.63635 .79585 m .63635 .29396 L .61513 .30465 L p .707 .577 .707 r
F P
0 g
s
.68891 .72704 m .69159 .76373 L .67344 .75726 L p .707 .577 .707 r
F P
0 g
s
.67344 .75726 m .67076 .72056 L .68891 .72704 L p .707 .577 .707 r
F P
0 g
s
.27232 .76391 m .27123 .72618 L .23928 .72694 L p .707 .577 .707 r
F P
0 g
s
.27123 .72618 m .27232 .76391 L .30292 .76128 L p .707 .577 .707 r
F P
0 g
s
.30292 .76128 m .30182 .72355 L .27123 .72618 L p .707 .577 .707 r
F P
0 g
s
.24038 .76467 m .23928 .72694 L .20911 .72575 L p .707 .577 .707 r
F P
0 g
s
.23928 .72694 m .24038 .76467 L .27232 .76391 L p .707 .577 .707 r
F P
0 g
s
.38178 .80539 m .38178 .30351 L .36202 .29262 L p .707 .577 .707 r
F P
0 g
s
.38178 .30351 m .38178 .80539 L .4131 .81411 L p .707 .577 .707 r
F P
0 g
s
.18811 .70583 m .18901 .65091 L .16936 .64289 L p .707 .577 .707 r
F P
0 g
s
.18901 .65091 m .18811 .70583 L .21459 .7117 L p .707 .577 .707 r
F P
0 g
s
.33341 .65156 m .3325 .70648 L .35041 .69864 L p .707 .577 .707 r
F P
0 g
s
.35041 .69864 m .35131 .64372 L .33341 .65156 L p .707 .577 .707 r
F P
0 g
s
.20911 .72575 m .2102 .76349 L .24038 .76467 L p .707 .577 .707 r
F P
0 g
s
.30182 .72355 m .30292 .76128 L .32917 .75705 L p .707 .577 .707 r
F P
0 g
s
.32917 .75705 m .32807 .71931 L .30182 .72355 L p .707 .577 .707 r
F P
0 g
s
.27286 .79383 m .27146 .77469 L .2396 .77694 L p .707 .577 .707 r
F P
0 g
s
.27146 .77469 m .27286 .79383 L .30356 .79103 L p .707 .577 .707 r
F P
0 g
s
.30356 .79103 m .30216 .77189 L .27146 .77469 L p .707 .577 .707 r
F P
0 g
s
.2396 .77694 m .24101 .79608 L .27286 .79383 L p .707 .577 .707 r
F P
0 g
s
.67004 .65045 m .66788 .70621 L .64143 .7007 L p .707 .577 .707 r
F P
0 g
s
.64143 .7007 m .64358 .64494 L .67004 .65045 L p .707 .577 .707 r
F P
0 g
s
.2102 .76349 m .20911 .72575 L .18367 .72274 L p .707 .577 .707 r
F P
0 g
s
.24101 .79608 m .2396 .77694 L .20971 .77841 L p .707 .577 .707 r
F P
0 g
s
.69403 .77641 m .69749 .79428 L .68028 .78846 L p .707 .577 .707 r
F P
0 g
s
.68028 .78846 m .67682 .77059 L .69403 .77641 L p .707 .577 .707 r
F P
0 g
s
.20971 .77841 m .21112 .79755 L .24101 .79608 L p .707 .577 .707 r
F P
0 g
s
.30216 .77189 m .30356 .79103 L .33011 .78795 L p .707 .577 .707 r
F P
0 g
s
.33011 .78795 m .3287 .7688 L .30216 .77189 L p .707 .577 .707 r
F P
0 g
s
.18367 .72274 m .18476 .76047 L .2102 .76349 L p .707 .577 .707 r
F P
0 g
s
.16936 .64289 m .16846 .69781 L .18811 .70583 L p .707 .577 .707 r
F P
0 g
s
.21112 .79755 m .20971 .77841 L .18472 .77896 L p .707 .577 .707 r
F P
0 g
s
.18472 .77896 m .18612 .7981 L .21112 .79755 L p .707 .577 .707 r
F P
0 g
s
.67076 .72056 m .67344 .75726 L .64807 .75328 L p .707 .577 .707 r
F P
0 g
s
.64807 .75328 m .64539 .71659 L .67076 .72056 L p .707 .577 .707 r
F P
0 g
s
.16846 .69781 m .16936 .64289 L .15846 .63353 L p .707 .577 .707 r
F P
0 g
s
.32807 .71931 m .32917 .75705 L .3485 .75161 L p .707 .577 .707 r
F P
0 g
s
.3485 .75161 m .34741 .71388 L .32807 .71931 L p .707 .577 .707 r
F P
0 g
s
.18476 .76047 m .18367 .72274 L .16545 .7182 L p .707 .577 .707 r
F P
0 g
s
.35131 .64372 m .35041 .69864 L .35925 .68936 L p .707 .577 .707 r
F P
0 g
s
.35925 .68936 m .36015 .63444 L .35131 .64372 L p .707 .577 .707 r
F P
0 g
s
.3287 .7688 m .33011 .78795 L .3499 .78488 L p .707 .577 .707 r
F P
0 g
s
.3499 .78488 m .34849 .76574 L .3287 .7688 L p .707 .577 .707 r
F P
0 g
s
.63635 .29396 m .63635 .79585 L .64422 .78392 L p .707 .577 .707 r
F P
0 g
s
.64422 .78392 m .64422 .28203 L .63635 .29396 L p .707 .577 .707 r
F P
0 g
s
.16545 .7182 m .16654 .75593 L .18476 .76047 L p .707 .577 .707 r
F P
0 g
s
.67682 .77059 m .68028 .78846 L .65578 .78611 L p .707 .577 .707 r
F P
0 g
s
.65578 .78611 m .65232 .76824 L .67682 .77059 L p .707 .577 .707 r
F P
0 g
s
.36015 .63444 m .35925 .68936 L .35817 .67956 L p .707 .577 .707 r
F P
0 g
s
.35817 .67956 m .35907 .62464 L .36015 .63444 L p .707 .577 .707 r
F P
0 g
s
.35959 .76299 m .361 .78213 L .36231 .77997 L p .707 .577 .707 r
F P
0 g
s
.36231 .77997 m .36091 .76083 L .35959 .76299 L p .707 .577 .707 r
F P
0 g
s
.34849 .76574 m .3499 .78488 L .361 .78213 L p .707 .577 .707 r
F P
0 g
s
.361 .78213 m .35959 .76299 L .34849 .76574 L p .707 .577 .707 r
F P
0 g
s
.36091 .76083 m .36231 .77997 L .35372 .77861 L p .707 .577 .707 r
F P
0 g
s
.36202 .79451 m .36202 .29262 L .35578 .28062 L p .707 .577 .707 r
F P
0 g
s
.36202 .29262 m .36202 .79451 L .38178 .80539 L p .707 .577 .707 r
F P
0 g
s
.18612 .7981 m .18472 .77896 L .16706 .77853 L p .707 .577 .707 r
F P
0 g
s
.16706 .77853 m .16847 .79767 L .18612 .7981 L p .707 .577 .707 r
F P
0 g
s
.15846 .63353 m .15756 .68845 L .16846 .69781 L p .707 .577 .707 r
F P
0 g
s
.34741 .71388 m .3485 .75161 L .35902 .74551 L p .707 .577 .707 r
F P
0 g
s
.35902 .74551 m .35793 .70778 L .34741 .71388 L p .707 .577 .707 r
F P
0 g
s
.15756 .68845 m .15846 .63353 L .15738 .62373 L p .707 .577 .707 r
F P
0 g
s
.16654 .75593 m .16545 .7182 L .15623 .71257 L p .707 .577 .707 r
F P
0 g
s
.15623 .71257 m .15732 .7503 L .16654 .75593 L p .707 .577 .707 r
F P
0 g
s
.16847 .79767 m .16706 .77853 L .15847 .77717 L p .707 .577 .707 r
F P
0 g
s
.15847 .77717 m .15988 .79631 L .16847 .79767 L p .707 .577 .707 r
F P
0 g
s
.15738 .62373 m .15648 .67865 L .15756 .68845 L p .707 .577 .707 r
F P
0 g
s
.64422 .28203 m .64422 .78392 L .63797 .77193 L p .707 .577 .707 r
F P
0 g
s
.63797 .77193 m .63797 .27004 L .64422 .28203 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35793 .70778 m .35902 .74551 L .35971 .73934 L p .707 .577 .707 r
F P
0 g
s
.35971 .73934 m .35862 .70161 L .35793 .70778 L p .707 .577 .707 r
F P
0 g
s
.35907 .62464 m .35817 .67956 L .34727 .6702 L p .707 .577 .707 r
F P
0 g
s
.34727 .6702 m .34817 .61528 L .35907 .62464 L p .707 .577 .707 r
F P
0 g
s
.35862 .70161 m .35971 .73934 L .35049 .73371 L p .707 .577 .707 r
F P
0 g
s
.35049 .73371 m .3494 .69598 L .35862 .70161 L p .707 .577 .707 r
F P
0 g
s
.35372 .77861 m .35232 .75947 L .36091 .76083 L p .707 .577 .707 r
F P
0 g
s
.35578 .28062 m .35578 .78251 L .36202 .79451 L p .707 .577 .707 r
F P
0 g
s
.35578 .78251 m .35578 .28062 L .36365 .2687 L p .707 .577 .707 r
F P
0 g
s
.15648 .67865 m .15738 .62373 L .16623 .61446 L p .707 .577 .707 r
F P
0 g
s
.15732 .7503 m .15623 .71257 L .15691 .7064 L p .707 .577 .707 r
F P
0 g
s
.15691 .7064 m .15801 .74413 L .15732 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15988 .79631 m .15847 .77717 L .15979 .77501 L p .707 .577 .707 r
F P
0 g
s
.15979 .77501 m .1612 .79415 L .15988 .79631 L p .707 .577 .707 r
F P
0 g
s
.16623 .61446 m .16532 .66938 L .15648 .67865 L p .707 .577 .707 r
F P
0 g
s
.16532 .66938 m .16623 .61446 L .18413 .60662 L p .707 .577 .707 r
F P
0 g
s
.15801 .74413 m .15691 .7064 L .16744 .7003 L p .707 .577 .707 r
F P
0 g
s
.34817 .61528 m .34727 .6702 L .32762 .66219 L p .707 .577 .707 r
F P
0 g
s
.32762 .66219 m .32852 .60727 L .34817 .61528 L p .707 .577 .707 r
F P
0 g
s
.63797 .27004 m .63797 .77193 L .61822 .76104 L p .707 .577 .707 r
F P
0 g
s
.61822 .76104 m .61822 .25915 L .63797 .27004 L p .707 .577 .707 r
F P
0 g
s
.16744 .7003 m .16853 .73803 L .15801 .74413 L p .707 .577 .707 r
F P
0 g
s
.36365 .77059 m .36365 .2687 L .38487 .25801 L p .707 .577 .707 r
F P
0 g
s
.36365 .2687 m .36365 .77059 L .35578 .78251 L p .707 .577 .707 r
F P
0 g
s
.1612 .79415 m .15979 .77501 L .17089 .77226 L p .707 .577 .707 r
F P
0 g
s
.18413 .60662 m .18323 .66154 L .16532 .66938 L p .707 .577 .707 r
F P
0 g
s
.17089 .77226 m .17229 .79141 L .1612 .79415 L p .707 .577 .707 r
F P
0 g
s
.18323 .66154 m .18413 .60662 L .20934 .60097 L p .707 .577 .707 r
F P
0 g
s
.3494 .69598 m .35049 .73371 L .33227 .72917 L p .707 .577 .707 r
F P
0 g
s
.33227 .72917 m .33118 .69144 L .3494 .69598 L p .707 .577 .707 r
F P
0 g
s
.32852 .60727 m .32762 .66219 L .30114 .65631 L p .707 .577 .707 r
F P
0 g
s
.30114 .65631 m .30204 .60139 L .32852 .60727 L p .707 .577 .707 r
F P
0 g
s
.16853 .73803 m .16744 .7003 L .18677 .69487 L p .707 .577 .707 r
F P
0 g
s
.35232 .75947 m .35372 .77861 L .33607 .77819 L p .707 .577 .707 r
F P
0 g
s
.33607 .77819 m .33466 .75905 L .35232 .75947 L p .707 .577 .707 r
F P
0 g
s
.18677 .69487 m .18787 .7326 L .16853 .73803 L p .707 .577 .707 r
F P
0 g
s
.20934 .60097 m .20844 .65589 L .18323 .66154 L p .707 .577 .707 r
F P
0 g
s
.20844 .65589 m .20934 .60097 L .23938 .59808 L p .707 .577 .707 r
F P
0 g
s
.61822 .25915 m .61822 .76104 L .5869 .75232 L p .707 .577 .707 r
F P
0 g
s
.5869 .75232 m .5869 .25044 L .61822 .25915 L p .707 .577 .707 r
F P
0 g
s
.17229 .79141 m .17089 .77226 L .19068 .7692 L p .707 .577 .707 r
F P
0 g
s
.30204 .60139 m .30114 .65631 L .27043 .65315 L p .707 .577 .707 r
F P
0 g
s
.27043 .65315 m .27133 .59823 L .30204 .60139 L p .707 .577 .707 r
F P
0 g
s
.19068 .7692 m .19208 .78834 L .17229 .79141 L p .707 .577 .707 r
F P
0 g
s
.38487 .25801 m .38487 .7599 L .36365 .77059 L p .707 .577 .707 r
F P
0 g
s
.38487 .7599 m .38487 .25801 L .41735 .24961 L p .707 .577 .707 r
F P
0 g
s
.33118 .69144 m .33227 .72917 L .30683 .72616 L p .707 .577 .707 r
F P
0 g
s
.30683 .72616 m .30573 .68843 L .33118 .69144 L p .707 .577 .707 r
F P
0 g
s
.72957 .65489 m .72867 .59874 L .69795 .59718 L p .707 .577 .707 r
F P
0 g
s
.72867 .59874 m .72957 .65489 L .76151 .65415 L p .707 .577 .707 r
F P
0 g
s
.76151 .65415 m .76061 .59801 L .72867 .59874 L p .707 .577 .707 r
F P
0 g
s
.23848 .653 m .23938 .59808 L .27133 .59823 L p .707 .577 .707 r
F P
0 g
s
.23938 .59808 m .23848 .653 L .20844 .65589 L p .707 .577 .707 r
F P
0 g
s
.76061 .59801 m .76151 .65415 L .79156 .65119 L p .707 .577 .707 r
F P
0 g
s
.79156 .65119 m .79066 .59504 L .76061 .59801 L p .707 .577 .707 r
F P
0 g
s
.27133 .59823 m .27043 .65315 L .23848 .653 L p .707 .577 .707 r
F P
0 g
s
.18787 .7326 m .18677 .69487 L .21302 .69063 L p .707 .577 .707 r
F P
0 g
s
.69885 .65332 m .69795 .59718 L .67147 .59346 L p .707 .577 .707 r
F P
0 g
s
.69795 .59718 m .69885 .65332 L .72957 .65489 L p .707 .577 .707 r
F P
0 g
s
.21302 .69063 m .21411 .72836 L .18787 .7326 L p .707 .577 .707 r
F P
0 g
s
.33466 .75905 m .33607 .77819 L .31107 .77874 L p .707 .577 .707 r
F P
0 g
s
.31107 .77874 m .30967 .7596 L .33466 .75905 L p .707 .577 .707 r
F P
0 g
s
.79066 .59504 m .79156 .65119 L .81677 .64628 L p .707 .577 .707 r
F P
0 g
s
.81677 .64628 m .81587 .59014 L .79066 .59504 L p .707 .577 .707 r
F P
0 g
s
.19208 .78834 m .19068 .7692 L .21722 .76611 L p .707 .577 .707 r
F P
0 g
s
.30573 .68843 m .30683 .72616 L .27666 .72497 L p .707 .577 .707 r
F P
0 g
s
.27666 .72497 m .27556 .68724 L .30573 .68843 L p .707 .577 .707 r
F P
0 g
s
.21722 .76611 m .21863 .78525 L .19208 .78834 L p .707 .577 .707 r
F P
0 g
s
.21411 .72836 m .21302 .69063 L .24362 .688 L p .707 .577 .707 r
F P
0 g
s
.67147 .59346 m .67238 .6496 L .69885 .65332 L p .707 .577 .707 r
F P
0 g
s
.75529 .72626 m .75638 .69014 L .72443 .68905 L p .707 .577 .707 r
F P
0 g
s
.75638 .69014 m .75529 .72626 L .78588 .72391 L p .707 .577 .707 r
F P
0 g
s
.78588 .72391 m .78698 .68779 L .75638 .69014 L p .707 .577 .707 r
F P
0 g
s
.72334 .72517 m .72443 .68905 L .69426 .68463 L p .707 .577 .707 r
F P
0 g
s
.72443 .68905 m .72334 .72517 L .75529 .72626 L p .707 .577 .707 r
F P
0 g
s
.5869 .25044 m .5869 .75232 L .54706 .74663 L p .707 .577 .707 r
F P
0 g
s
.54706 .74663 m .54706 .24474 L .5869 .25044 L p .707 .577 .707 r
F P
0 g
s
.67238 .6496 m .67147 .59346 L .65182 .58796 L p .707 .577 .707 r
F P
0 g
s
.41735 .7515 m .41735 .24961 L .45793 .24431 L p .707 .577 .707 r
F P
0 g
s
.41735 .24961 m .41735 .7515 L .38487 .7599 L p .707 .577 .707 r
F P
0 g
s
.24362 .688 m .24471 .72573 L .21411 .72836 L p .707 .577 .707 r
F P
0 g
s
.27556 .68724 m .27666 .72497 L .24471 .72573 L p .707 .577 .707 r
F P
0 g
s
.24471 .72573 m .24362 .688 L .27556 .68724 L p .707 .577 .707 r
F P
0 g
s
.81587 .59014 m .81677 .64628 L .83467 .63992 L p .707 .577 .707 r
F P
0 g
s
.83467 .63992 m .83377 .58378 L .81587 .59014 L p .707 .577 .707 r
F P
0 g
s
.30967 .7596 m .31107 .77874 L .28118 .78021 L p .707 .577 .707 r
F P
0 g
s
.28118 .78021 m .27978 .76106 L .30967 .7596 L p .707 .577 .707 r
F P
0 g
s
.78698 .68779 m .78588 .72391 L .81213 .71837 L p .707 .577 .707 r
F P
0 g
s
.81213 .71837 m .81323 .68225 L .78698 .68779 L p .707 .577 .707 r
F P
0 g
s
.69317 .72076 m .69426 .68463 L .66882 .67733 L p .707 .577 .707 r
F P
0 g
s
.69426 .68463 m .69317 .72076 L .72334 .72517 L p .707 .577 .707 r
F P
0 g
s
.21863 .78525 m .21722 .76611 L .24792 .76331 L p .707 .577 .707 r
F P
0 g
s
.24792 .76331 m .24933 .78245 L .21863 .78525 L p .707 .577 .707 r
F P
0 g
s
.65182 .58796 m .65272 .6441 L .67238 .6496 L p .707 .577 .707 r
F P
0 g
s
.27978 .76106 m .28118 .78021 L .24933 .78245 L p .707 .577 .707 r
F P
0 g
s
.24933 .78245 m .24792 .76331 L .27978 .76106 L p .707 .577 .707 r
F P
0 g
s
.54706 .24474 m .54706 .74663 L .50263 .74452 L p .707 .577 .707 r
F P
0 g
s
.50263 .74452 m .50263 .24263 L .54706 .24474 L p .707 .577 .707 r
F P
0 g
s
.66882 .67733 m .66773 .71345 L .69317 .72076 L p .707 .577 .707 r
F P
0 g
s
.45793 .7462 m .45793 .24431 L .50263 .24263 L p .707 .577 .707 r
F P
0 g
s
.45793 .24431 m .45793 .7462 L .41735 .7515 L p .707 .577 .707 r
F P
0 g
s
.81323 .68225 m .81213 .71837 L .83147 .71016 L p .707 .577 .707 r
F P
0 g
s
.83147 .71016 m .83256 .67404 L .81323 .68225 L p .707 .577 .707 r
F P
0 g
s
.75067 .77875 m .75207 .76172 L .72022 .75904 L p .707 .577 .707 r
F P
0 g
s
.75207 .76172 m .75067 .77875 L .78137 .77678 L p .707 .577 .707 r
F P
0 g
s
.78137 .77678 m .78278 .75976 L .75207 .76172 L p .707 .577 .707 r
F P
0 g
s
.71881 .77607 m .72022 .75904 L .69033 .75197 L p .707 .577 .707 r
F P
0 g
s
.72022 .75904 m .71881 .77607 L .75067 .77875 L p .707 .577 .707 r
F P
0 g
s
.66773 .71345 m .66882 .67733 L .6506 .66784 L p .707 .577 .707 r
F P
0 g
s
.65272 .6441 m .65182 .58796 L .64092 .58121 L p .707 .577 .707 r
F P
0 g
s
.50263 .24263 m .50263 .74452 L .45793 .7462 L p .707 .577 .707 r
F P
0 g
s
.83377 .58378 m .83467 .63992 L .84352 .63272 L p .707 .577 .707 r
F P
0 g
s
.84352 .63272 m .84262 .57657 L .83377 .58378 L p .707 .577 .707 r
F P
0 g
s
.78278 .75976 m .78137 .77678 L .80792 .77035 L p .707 .577 .707 r
F P
0 g
s
.80792 .77035 m .80932 .75333 L .78278 .75976 L p .707 .577 .707 r
F P
0 g
s
.69033 .75197 m .68893 .769 L .71881 .77607 L p .707 .577 .707 r
F P
0 g
s
.68893 .769 m .69033 .75197 L .66534 .7412 L p .707 .577 .707 r
F P
0 g
s
.6506 .66784 m .64951 .70397 L .66773 .71345 L p .707 .577 .707 r
F P
0 g
s
.64092 .58121 m .64183 .63735 L .65272 .6441 L p .707 .577 .707 r
F P
0 g
s
.66534 .7412 m .66393 .75823 L .68893 .769 L p .707 .577 .707 r
F P
0 g
s
.83256 .67404 m .83147 .71016 L .84199 .7001 L p .707 .577 .707 r
F P
0 g
s
.84199 .7001 m .84308 .66398 L .83256 .67404 L p .707 .577 .707 r
F P
0 g
s
.64951 .70397 m .6506 .66784 L .64138 .65711 L p .707 .577 .707 r
F P
0 g
s
.80932 .75333 m .80792 .77035 L .82771 .7601 L p .707 .577 .707 r
F P
0 g
s
.82771 .7601 m .82911 .74307 L .80932 .75333 L p .707 .577 .707 r
F P
0 g
s
.66393 .75823 m .66534 .7412 L .64768 .72779 L p .707 .577 .707 r
F P
0 g
s
.64183 .63735 m .64092 .58121 L .63984 .57388 L p .707 .578 .707 r
F P
0 g
s
.64768 .72779 m .64627 .74482 L .66393 .75823 L p .707 .577 .707 r
F P
0 g
s
.84262 .57657 m .84352 .63272 L .84244 .62538 L p .707 .578 .707 r
F P
0 g
s
.84244 .62538 m .84154 .56924 L .84262 .57657 L p .707 .578 .707 r
F P
0 g
s
.64138 .65711 m .64029 .69323 L .64951 .70397 L p .707 .577 .707 r
F P
0 g
s
.63984 .57388 m .64075 .63002 L .64183 .63735 L p .707 .578 .707 r
F P
0 g
s
.82911 .74307 m .82771 .7601 L .8388 .74702 L p .707 .577 .707 r
F P
0 g
s
.8388 .74702 m .84021 .72999 L .82911 .74307 L p .707 .577 .707 r
F P
0 g
s
.64627 .74482 m .64768 .72779 L .63909 .71306 L p .707 .577 .707 r
F P
0 g
s
.84308 .66398 m .84199 .7001 L .84268 .68917 L p .707 .577 .707 r
F P
0 g
s
.84268 .68917 m .84377 .65305 L .84308 .66398 L p .707 .577 .707 r
F P
0 g
s
.64029 .69323 m .64138 .65711 L .64207 .64618 L p .707 .577 .707 r
F P
0 g
s
.63909 .71306 m .63768 .73008 L .64627 .74482 L p .707 .577 .707 r
F P
0 g
s
.64075 .63002 m .63984 .57388 L .64869 .56668 L p .707 .577 .707 r
F P
0 g
s
.64207 .64618 m .64097 .6823 L .64029 .69323 L p .707 .577 .707 r
F P
0 g
s
.84154 .56924 m .84244 .62538 L .83154 .61864 L p .707 .577 .707 r
F P
0 g
s
.83154 .61864 m .83064 .56249 L .84154 .56924 L p .707 .577 .707 r
F P
0 g
s
.64869 .56668 m .64959 .62282 L .64075 .63002 L p .707 .577 .707 r
F P
0 g
s
.84021 .72999 m .8388 .74702 L .84012 .73239 L p .705 .576 .707 r
F P
0 g
s
.84012 .73239 m .84153 .71536 L .84021 .72999 L p .705 .576 .707 r
F P
0 g
s
.63768 .73008 m .63909 .71306 L .64041 .69843 L p .705 .576 .707 r
F P
0 g
s
.84377 .65305 m .84268 .68917 L .83346 .67844 L p .707 .577 .707 r
F P
0 g
s
.83346 .67844 m .83455 .64231 L .84377 .65305 L p .707 .577 .707 r
F P
0 g
s
.64097 .6823 m .64207 .64618 L .65259 .63612 L p .707 .577 .707 r
F P
0 g
s
.64041 .69843 m .639 .71545 L .63768 .73008 L p .705 .576 .707 r
F P
0 g
s
.38927 .62182 m .38711 .56651 L .35642 .56511 L p .707 .577 .707 r
F P
0 g
s
.38711 .56651 m .38927 .62182 L .42119 .62038 L p .707 .577 .707 r
F P
0 g
s
.42119 .62038 m .41904 .56507 L .38711 .56651 L p .707 .577 .707 r
F P
0 g
s
.41904 .56507 m .42119 .62038 L .45123 .61622 L p .707 .577 .707 r
F P
0 g
s
.45123 .61622 m .44907 .56091 L .41904 .56507 L p .707 .577 .707 r
F P
0 g
s
.64959 .62282 m .64869 .56668 L .66659 .56031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35857 .62042 m .35642 .56511 L .32996 .561 L p .707 .577 .707 r
F P
0 g
s
.35642 .56511 m .35857 .62042 L .38927 .62182 L p .707 .577 .707 r
F P
0 g
s
.83064 .56249 m .83154 .61864 L .81189 .61314 L p .707 .577 .707 r
F P
0 g
s
.81189 .61314 m .81099 .55699 L .83064 .56249 L p .707 .577 .707 r
F P
0 g
s
.65259 .63612 m .6515 .67224 L .64097 .6823 L p .707 .577 .707 r
F P
0 g
s
.44907 .56091 m .45123 .61622 L .47643 .60977 L p .707 .577 .707 r
F P
0 g
s
.47643 .60977 m .47427 .55446 L .44907 .56091 L p .707 .577 .707 r
F P
0 g
s
.84153 .71536 m .84012 .73239 L .83153 .71765 L p .707 .577 .707 r
F P
0 g
s
.83153 .71765 m .83294 .70062 L .84153 .71536 L p .707 .577 .707 r
F P
0 g
s
.639 .71545 m .64041 .69843 L .65151 .68535 L p .707 .577 .707 r
F P
0 g
s
.66659 .56031 m .66749 .61645 L .64959 .62282 L p .707 .577 .707 r
F P
0 g
s
.41391 .67883 m .41659 .64161 L .38471 .63928 L p .707 .577 .707 r
F P
0 g
s
.41659 .64161 m .41391 .67883 L .44445 .67866 L p .707 .577 .707 r
F P
0 g
s
.44445 .67866 m .44713 .64144 L .41659 .64161 L p .707 .577 .707 r
F P
0 g
s
.38203 .67649 m .38471 .63928 L .35461 .63466 L p .707 .577 .707 r
F P
0 g
s
.38471 .63928 m .38203 .67649 L .41391 .67883 L p .707 .577 .707 r
F P
0 g
s
.83455 .64231 m .83346 .67844 L .81524 .66895 L p .707 .577 .707 r
F P
0 g
s
.81524 .66895 m .81633 .63283 L .83455 .64231 L p .707 .577 .707 r
F P
0 g
s
.6515 .67224 m .65259 .63612 L .67192 .62791 L p .707 .577 .707 r
F P
0 g
s
.32996 .561 m .33211 .61631 L .35857 .62042 L p .707 .577 .707 r
F P
0 g
s
.65151 .68535 m .6501 .70237 L .639 .71545 L p .707 .577 .707 r
F P
0 g
s
.33211 .61631 m .32996 .561 L .31033 .55458 L p .707 .577 .707 r
F P
0 g
s
.47427 .55446 m .47643 .60977 L .49433 .60165 L p .707 .577 .707 r
F P
0 g
s
.49433 .60165 m .49217 .54634 L .47427 .55446 L p .707 .577 .707 r
F P
0 g
s
.66749 .61645 m .66659 .56031 L .6918 .55541 L p .707 .577 .707 r
F P
0 g
s
.44713 .64144 m .44445 .67866 L .47067 .67599 L p .707 .577 .707 r
F P
0 g
s
.47067 .67599 m .47335 .63878 L .44713 .64144 L p .707 .577 .707 r
F P
0 g
s
.35461 .63466 m .35193 .67188 L .38203 .67649 L p .707 .577 .707 r
F P
0 g
s
.35193 .67188 m .35461 .63466 L .32924 .62822 L p .707 .577 .707 r
F P
0 g
s
.81099 .55699 m .81189 .61314 L .78541 .60942 L p .707 .577 .707 r
F P
0 g
s
.78541 .60942 m .78451 .55328 L .81099 .55699 L p .707 .577 .707 r
F P
0 g
s
.40502 .71857 m .40848 .70007 L .37707 .69412 L p .707 .577 .707 r
F P
0 g
s
.40848 .70007 m .40502 .71857 L .43537 .72227 L p .707 .577 .707 r
F P
0 g
s
.43537 .72227 m .43883 .70376 L .40848 .70007 L p .707 .577 .707 r
F P
0 g
s
.37361 .71263 m .37707 .69412 L .34768 .68651 L p .707 .577 .707 r
F P
0 g
s
.37707 .69412 m .37361 .71263 L .40502 .71857 L p .707 .577 .707 r
F P
0 g
s
.67192 .62791 m .67083 .66403 L .6515 .67224 L p .707 .577 .707 r
F P
0 g
s
.34768 .68651 m .34422 .70501 L .37361 .71263 L p .707 .577 .707 r
F P
0 g
s
.32924 .62822 m .32656 .66543 L .35193 .67188 L p .707 .577 .707 r
F P
0 g
s
.31033 .55458 m .31248 .60989 L .33211 .61631 L p .707 .577 .707 r
F P
0 g
s
.6918 .55541 m .6927 .61155 L .66749 .61645 L p .707 .577 .707 r
F P
0 g
s
.83294 .70062 m .83153 .71765 L .81387 .70424 L p .707 .577 .707 r
F P
0 g
s
.81387 .70424 m .81528 .68721 L .83294 .70062 L p .707 .577 .707 r
F P
0 g
s
.6501 .70237 m .65151 .68535 L .67129 .67509 L p .707 .577 .707 r
F P
0 g
s
.43883 .70376 m .43537 .72227 L .46168 .72336 L p .707 .577 .707 r
F P
0 g
s
.46168 .72336 m .46515 .70485 L .43883 .70376 L p .707 .577 .707 r
F P
0 g
s
.34422 .70501 m .34768 .68651 L .32318 .67797 L p .707 .577 .707 r
F P
0 g
s
.81633 .63283 m .81524 .66895 L .78979 .66165 L p .707 .577 .707 r
F P
0 g
s
.78979 .66165 m .79089 .62552 L .81633 .63283 L p .707 .577 .707 r
F P
0 g
s
.6927 .61155 m .6918 .55541 L .72185 .55244 L p .707 .577 .707 r
F P
0 g
s
.67083 .66403 m .67192 .62791 L .69817 .62237 L p .707 .577 .707 r
F P
0 g
s
.47335 .63878 m .47067 .67599 L .48999 .6711 L p .707 .577 .707 r
F P
0 g
s
.48999 .6711 m .49267 .63389 L .47335 .63878 L p .707 .577 .707 r
F P
0 g
s
.32318 .67797 m .31972 .69648 L .34422 .70501 L p .707 .577 .707 r
F P
0 g
s
.32656 .66543 m .32924 .62822 L .31108 .62058 L p .707 .577 .707 r
F P
0 g
s
.31248 .60989 m .31033 .55458 L .29944 .54648 L p .707 .577 .707 r
F P
0 g
s
.78451 .55328 m .78541 .60942 L .7547 .60785 L p .707 .577 .707 r
F P
0 g
s
.7547 .60785 m .75379 .55171 L .78451 .55328 L p .707 .577 .707 r
F P
0 g
s
.67129 .67509 m .66989 .69212 L .6501 .70237 L p .707 .577 .707 r
F P
0 g
s
.49217 .54634 m .49433 .60165 L .50317 .59265 L p .707 .577 .707 r
F P
0 g
s
.50317 .59265 m .50102 .53734 L .49217 .54634 L p .707 .577 .707 r
F P
0 g
s
.72275 .60859 m .72185 .55244 L .75379 .55171 L p .707 .577 .707 r
F P
0 g
s
.72185 .55244 m .72275 .60859 L .6927 .61155 L p .707 .577 .707 r
F P
0 g
s
.31108 .62058 m .3084 .6578 L .32656 .66543 L p .707 .577 .707 r
F P
0 g
s
.75379 .55171 m .7547 .60785 L .72275 .60859 L p .707 .577 .707 r
F P
0 g
s
.69817 .62237 m .69708 .65849 L .67083 .66403 L p .707 .577 .707 r
F P
0 g
s
.46515 .70485 m .46168 .72336 L .4814 .72173 L p .707 .577 .707 r
F P
0 g
s
.4814 .72173 m .48486 .70323 L .46515 .70485 L p .707 .577 .707 r
F P
0 g
s
.31972 .69648 m .32318 .67797 L .30597 .66935 L p .707 .577 .707 r
F P
0 g
s
.79089 .62552 m .78979 .66165 L .75962 .65723 L p .707 .577 .707 r
F P
0 g
s
.75962 .65723 m .76072 .62111 L .79089 .62552 L p .707 .577 .707 r
F P
0 g
s
.81528 .68721 m .81387 .70424 L .78888 .69347 L p .707 .577 .707 r
F P
0 g
s
.78888 .69347 m .79028 .67645 L .81528 .68721 L p .707 .577 .707 r
F P
0 g
s
.69708 .65849 m .69817 .62237 L .72877 .62002 L p .707 .577 .707 r
F P
0 g
s
.66989 .69212 m .67129 .67509 L .69784 .66866 L p .707 .577 .707 r
F P
0 g
s
.29944 .54648 m .3016 .60179 L .31248 .60989 L p .707 .577 .707 r
F P
0 g
s
.30597 .66935 m .30251 .68786 L .31972 .69648 L p .707 .577 .707 r
F P
0 g
s
.76072 .62111 m .75962 .65723 L .72768 .65615 L p .707 .577 .707 r
F P
0 g
s
.72768 .65615 m .72877 .62002 L .76072 .62111 L p .707 .577 .707 r
F P
0 g
s
.49267 .63389 m .48999 .6711 L .50053 .66446 L p .707 .577 .707 r
F P
0 g
s
.50053 .66446 m .50321 .62725 L .49267 .63389 L p .707 .577 .707 r
F P
0 g
s
.72877 .62002 m .72768 .65615 L .69708 .65849 L p .707 .577 .707 r
F P
0 g
s
.69784 .66866 m .69643 .68569 L .66989 .69212 L p .707 .577 .707 r
F P
0 g
s
.3084 .6578 m .31108 .62058 L .30192 .6125 L p .707 .577 .707 r
F P
0 g
s
.3016 .60179 m .29944 .54648 L .29837 .53749 L p .707 .578 .707 r
F P
0 g
s
.79028 .67645 m .78888 .69347 L .75899 .6864 L p .707 .577 .707 r
F P
0 g
s
.75899 .6864 m .7604 .66938 L .79028 .67645 L p .707 .577 .707 r
F P
0 g
s
.69643 .68569 m .69784 .66866 L .72854 .66669 L p .707 .577 .707 r
F P
0 g
s
.50102 .53734 m .50317 .59265 L .5021 .58367 L p .707 .578 .707 r
F P
0 g
s
.5021 .58367 m .49995 .52836 L .50102 .53734 L p .707 .578 .707 r
F P
0 g
s
.30192 .6125 m .29924 .64971 L .3084 .6578 L p .707 .577 .707 r
F P
0 g
s
.48486 .70323 m .4814 .72173 L .49257 .71755 L p .707 .577 .707 r
F P
0 g
s
.49257 .71755 m .49603 .69904 L .48486 .70323 L p .707 .577 .707 r
F P
0 g
s
.30251 .68786 m .30597 .66935 L .29774 .66149 L p .707 .577 .707 r
F P
0 g
s
.7604 .66938 m .75899 .6864 L .72714 .68372 L p .707 .577 .707 r
F P
0 g
s
.72714 .68372 m .72854 .66669 L .7604 .66938 L p .707 .577 .707 r
F P
0 g
s
.72854 .66669 m .72714 .68372 L .69643 .68569 L p .707 .577 .707 r
F P
0 g
s
.29774 .66149 m .29428 .68 L .30251 .68786 L p .707 .577 .707 r
F P
0 g
s
.29837 .53749 m .30052 .5928 L .3016 .60179 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.50321 .62725 m .50053 .66446 L .50125 .65671 L p .706 .576 .707 r
F P
0 g
s
.50125 .65671 m .50393 .6195 L .50321 .62725 L p .706 .576 .707 r
F P
0 g
s
.29924 .64971 m .30192 .6125 L .30264 .60475 L p .706 .576 .707 r
F P
0 g
s
.30052 .5928 m .29837 .53749 L .30722 .5285 L p .707 .577 .707 r
F P
0 g
s
.49995 .52836 m .5021 .58367 L .49122 .57557 L p .707 .577 .707 r
F P
0 g
s
.49122 .57557 m .48906 .52026 L .49995 .52836 L p .707 .577 .707 r
F P
0 g
s
.30264 .60475 m .29996 .64197 L .29924 .64971 L p .706 .576 .707 r
F P
0 g
s
.49603 .69904 m .49257 .71755 L .49412 .71122 L p .707 .577 .707 r
F P
0 g
s
.49412 .71122 m .49758 .69271 L .49603 .69904 L p .707 .577 .707 r
F P
0 g
s
.29428 .68 m .29774 .66149 L .29928 .65516 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29928 .65516 m .29582 .67367 L .29428 .68 L p .707 .577 .707 r
F P
0 g
s
.30722 .5285 m .30937 .58381 L .30052 .5928 L p .707 .577 .707 r
F P
0 g
s
.50393 .6195 m .50125 .65671 L .49208 .64863 L p .707 .577 .707 r
F P
0 g
s
.49208 .64863 m .49476 .61141 L .50393 .6195 L p .707 .577 .707 r
F P
0 g
s
.29996 .64197 m .30264 .60475 L .31317 .59811 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30937 .58381 m .30722 .5285 L .32512 .52037 L p .707 .577 .707 r
F P
0 g
s
.48906 .52026 m .49122 .57557 L .47159 .56914 L p .707 .577 .707 r
F P
0 g
s
.47159 .56914 m .46943 .51384 L .48906 .52026 L p .707 .577 .707 r
F P
0 g
s
.31317 .59811 m .31049 .63532 L .29996 .64197 L p .707 .577 .707 r
F P
0 g
s
.49758 .69271 m .49412 .71122 L .48588 .70336 L p .707 .577 .707 r
F P
0 g
s
.48588 .70336 m .48934 .68485 L .49758 .69271 L p .707 .577 .707 r
F P
0 g
s
.29582 .67367 m .29928 .65516 L .31046 .65097 L p .707 .577 .707 r
F P
0 g
s
.31046 .65097 m .307 .66948 L .29582 .67367 L p .707 .577 .707 r
F P
0 g
s
.32512 .52037 m .32727 .57568 L .30937 .58381 L p .707 .577 .707 r
F P
0 g
s
.32727 .57568 m .32512 .52037 L .35032 .51392 L p .707 .577 .707 r
F P
0 g
s
.49476 .61141 m .49208 .64863 L .47392 .64099 L p .707 .577 .707 r
F P
0 g
s
.47392 .64099 m .4766 .60378 L .49476 .61141 L p .707 .577 .707 r
F P
0 g
s
.31049 .63532 m .31317 .59811 L .3325 .59322 L p .707 .577 .707 r
F P
0 g
s
.46943 .51384 m .47159 .56914 L .44513 .56503 L p .707 .577 .707 r
F P
0 g
s
.44513 .56503 m .44297 .50972 L .46943 .51384 L p .707 .577 .707 r
F P
0 g
s
.3325 .59322 m .32981 .63043 L .31049 .63532 L p .707 .577 .707 r
F P
0 g
s
.48934 .68485 m .48588 .70336 L .46867 .69474 L p .707 .577 .707 r
F P
0 g
s
.46867 .69474 m .47213 .67623 L .48934 .68485 L p .707 .577 .707 r
F P
0 g
s
.35032 .51392 m .35247 .56923 L .32727 .57568 L p .707 .577 .707 r
F P
0 g
s
.307 .66948 m .31046 .65097 L .33017 .64935 L p .707 .577 .707 r
F P
0 g
s
.35247 .56923 m .35032 .51392 L .38035 .50977 L p .707 .577 .707 r
F P
0 g
s
.33017 .64935 m .32671 .66786 L .307 .66948 L p .707 .577 .707 r
F P
0 g
s
.44297 .50972 m .44513 .56503 L .41443 .56363 L p .707 .577 .707 r
F P
0 g
s
.41443 .56363 m .41228 .50832 L .44297 .50972 L p .707 .577 .707 r
F P
0 g
s
.4766 .60378 m .47392 .64099 L .44855 .63455 L p .707 .577 .707 r
F P
0 g
s
.44855 .63455 m .45123 .59733 L .4766 .60378 L p .707 .577 .707 r
F P
0 g
s
.32981 .63043 m .3325 .59322 L .35871 .59055 L p .707 .577 .707 r
F P
0 g
s
.3825 .56508 m .38035 .50977 L .41228 .50832 L p .707 .577 .707 r
F P
0 g
s
.38035 .50977 m .3825 .56508 L .35247 .56923 L p .707 .577 .707 r
F P
0 g
s
.41228 .50832 m .41443 .56363 L .3825 .56508 L p .707 .577 .707 r
F P
0 g
s
.35871 .59055 m .35603 .62777 L .32981 .63043 L p .707 .577 .707 r
F P
0 g
s
.47213 .67623 m .46867 .69474 L .44417 .6862 L p .707 .577 .707 r
F P
0 g
s
.44417 .6862 m .44763 .66769 L .47213 .67623 L p .707 .577 .707 r
F P
0 g
s
.32671 .66786 m .33017 .64935 L .35649 .65044 L p .707 .577 .707 r
F P
0 g
s
.45123 .59733 m .44855 .63455 L .41845 .62993 L p .707 .577 .707 r
F P
0 g
s
.41845 .62993 m .42114 .59272 L .45123 .59733 L p .707 .577 .707 r
F P
0 g
s
.35603 .62777 m .35871 .59055 L .38925 .59038 L p .707 .577 .707 r
F P
0 g
s
.35649 .65044 m .35303 .66894 L .32671 .66786 L p .707 .577 .707 r
F P
0 g
s
.42114 .59272 m .41845 .62993 L .38657 .6276 L p .707 .577 .707 r
F P
0 g
s
.38657 .6276 m .38925 .59038 L .42114 .59272 L p .707 .577 .707 r
F P
0 g
s
.38925 .59038 m .38657 .6276 L .35603 .62777 L p .707 .577 .707 r
F P
0 g
s
.44763 .66769 m .44417 .6862 L .41478 .67859 L p .707 .577 .707 r
F P
0 g
s
.41478 .67859 m .41824 .66008 L .44763 .66769 L p .707 .577 .707 r
F P
0 g
s
.35303 .66894 m .35649 .65044 L .38683 .65413 L p .707 .577 .707 r
F P
0 g
s
.38683 .65413 m .38337 .67264 L .35303 .66894 L p .707 .577 .707 r
F P
0 g
s
.41824 .66008 m .41478 .67859 L .38337 .67264 L p .707 .577 .707 r
F P
0 g
s
.38337 .67264 m .38683 .65413 L .41824 .66008 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
0UYF5@000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol50002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00003000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol0069oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00GWoo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001KOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Uoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Moo`8000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Eoo`<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol01000FUIJEP001EYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0001Yoo`P004=oo`00E7oo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000;Ool?0004FUH01000
FUIJEUYF2000>goo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Moo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000dOol005Aoo`04001JEUYF0005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF000017oo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01000<7oo001DOol01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF
6@0015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP00009oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00EGoo00<005YF00001EYF00<0
05YFFUH00eYF1P0000=JEP0000001`0015YF00<005YFFUH01EYF00<005YFFUH01P000eYF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<005YF00001EYF00<005YF00000`000UYF00<0
05YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0002FUH2000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Goo001EOol00`00FUH00005FUH20006FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eoo`03001J
EP0000=JEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00@005YF001JEP80009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP@000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol01000FUH0000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol200000eYF001JEP03FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF000]Ool005Eoo`04001JEUYF0004FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eo
o`04001JEUYF0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60005FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002eoo`00>Woo5`0017oo
00<005YFFUH00`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`0000=JEP00FUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool003Ioo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH002eoo`00<goo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool0
035oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH?0006FUH00`00FUIJEP080003
FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF00000`000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01P000eYF00@005YFFUH0
02eoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000`000UYF00<007ooOol0:goo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00P000UYF00<005YFFUH015YF5`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000005FUH00`00
FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF009JEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH300000eYF001JEP02FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF20000UYF00<005YF00001EYF3P0015YF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP06001J
EP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF1P0015YF1P00
0eYF00<005YFFUH00UYF1P001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<0009JEP8002ioo`00;7oo00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPX000=JEP03001JEUYF00QJEP@00003FUH005YF00=JEP03
001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<002moo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEP0001<0009JEP<000=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUH00000FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002ioo`00;7oo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000=JEP`000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH60002FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0
000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH70006Ool50005Ool600000eYF001JEP03
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YF00000`000eYF00@005YF
FUIJEQD0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH00UYF20003goo10000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00@005YFFUH000=JEP<000MJEP03001JEUYF
00EJEP03001JEP0000@000=JEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00=JEP04
001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP02FUH5000015YF001JEP005goo10001EYF00<005YFFUH00UYF00@005YFFUH002eoo`00;7oo00D0
05YFFUH005YF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001J
EUYF009JEP04001JEUYF0002FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40004FUH00`00FUIJEP03FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP030005FUH01000FUIJEP000goo2@003Woo100000=JEP00FUH00eYF00@0
05YFFUH002eoo`00;7oo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000`0015YF2P0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF0000009JEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEPP000AJEP03001JEUYF
009JEPH000aoo`<000=JEP04001JEUYF000]Ool002aoo`@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEUYFFUH400000eYF00000004FUH01000FUIJEUYF3`0015YF00<0
05YFFUH01eYF00@005YFFUIJEP<00004FUH000000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01@00FUH00000FUH01@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`002goo0P0000EJEP00FUIJEP0002eoo`00;7oo00@005YFFUH0
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEUYFFUH00002FUH01000
FUIJEUYF0`0000=JEP00FUH00eYF0`0000=JEP0000003P001eYF00<005YFFUH015YF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF100027oo0`000UYF00<007oo
Ool0:goo000/Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEP000004FUH01@00FUH005YF00001EYF00<0
05YF00002P0015YF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH00000009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004Ool20002FUH200000eYF001oo`0/
Ool002aoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30004FUH01000FUIJEUYF0P000UYF00D005YF001JEP0000EJEPH000=JEP04001JEUYF
FUH300000eYF001JEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YFFUH00eYF3`0015YF00<005YF
FUH01UYF00@005YFFUIJEP@000AJEP04001JEP00000]Ool002aoo`04001JEUYF0005FUH00`00FUIJ
EP05FUH01000FUIJEUYF5P000eYF00<005YFFUH015YF1@0000=JEP00FUH015YF1P000eYF00<005YF
FUH015YF0`001EYF00<005YFFUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00000015YF00<005YF00000`0000=JEP00FUH00UYF2@0000=o
o`0000001@001UYF00<005YFFUH00eYF0P0015YF00@005YFFUH002eoo`00;Goo00<005YF00001EYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03001JEUYF00EJEP03
001JEUYF00@000AJEPH000=JEP03001JEUYF00MJEP@00003FUH005YF00AJEP04001JEP00000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF0P001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF0P000eYF00@005YFFUH002eoo`00
;Woo0P0015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P001eYF00<005YFFUH015YF1@0000AJEP00000000AJEP03001JEUYF00UJEP04001JEP000004FUH0
0`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0eYF0P001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00H005YF0000
05YF0002FUH00`00Oomoo`0[Ool002moo`D00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP09FUH01000FUIJEUYF0P000UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YFFUIJEP80009JEP03001oogoo
02]oo`00;Woo0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF1P002UYF00<005YFFUH00UYF
100000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
000000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEUYF000]Ool002aoo`800003FUH005YF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP0000<000IJEP03001JEUYF00MJEP04001JEUYFFUH?0002FUH2000015YF001JEP0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF0`00;Woo000/Ool01000FUIJ
EP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH400001EYF000005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000eYF0P00;goo000/Ool01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YF001JEPH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40003FUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000015YF
001JEP00;Woo000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP@0009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEUYFFUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF1P0015YF10000UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001oo`020002FUH00`00
Oomoo`0[Ool002aoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00@005YF
FUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEPD000=JEP@000IJEP03001JEUYF
00D00003FUH005YF00MJEP04001JEUYFFUH50004Ool01000FUIJEP00;Goo000/Ool01000FUIJEP00
1EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00IJEQD000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000IJEP04001JEP000002
FUH00`00FUH000040002FUH00`00FUIJEP0500000eYF001JEP03FUH80009Ool01000FUIJEP00;Goo
000/Ool01000FUIJEP001EYF00<005YFFUH015YF00<005YFFUH00UYF6P000eYF00<005YFFUH00UYF
00D005YF001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005FUH01000FUIJ
EUYF0`0000=JEP00Ool00goo40004Woo0P00;Woo000/Ool01000FUIJEP001EYF00@005YFFUIJEPP0
00=JEP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00=JEPH0009JEP05001JEP00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP02FUH200000eYF
001oo`09Ool3000IOol2000^Ool002aoo`04001JEUYF0003FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP0500000eYF001JEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000AJEP00FUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP020002FUH00`00FUIJEP02FUH00`00FUH0
000WOol2000^Ool002aoo`03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJEP04001JEUYF
FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH00004FUH01000FUIJEP009Goo00<005YF
0000;Woo000/Ool40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0`001EYF0`000eYF00@005YFFUH002Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP05001JEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005
FUH01000FUH000000UYF00@005YFFUH002Aoo`04001JEUYF000^Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<0004FUH00`00
FUIJEP05FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0000015YF00@005YFFUIJ
EP800004FUH005YF000ROol30002FUH00`00Oomoo`0/Ool002aoo`800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800004Ool005YF0005FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP05FUH4
000POol20002FUH00`00FUH0000_Ool002ioo`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000=oo`03001JEP0000EJ
EP03001JEUYF009JEP@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00<000AJEP03001JEUYF00=JEP03001JEP0000D000MJEP03001JEP0000<001]oo`8000AJEP80
031oo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
4P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF000017oo0P00
1UYF00<005YFFUH00eYF1`0047oo100000=JEP00FUH00eYF0P00<7oo000cOol50003FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH20005FUH00`00FUH00004Ool40003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH@0005
FUH00`00FUIJEP02FUH00`00Oomoo`0_Ool003Qooa<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP800003FUH005YF009JEP8000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH000040000
15YF001JEUYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80039oo`00=7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP800003FUH005YF00L000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEP00000dOol002moo`D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP800004FUH005YF0003FUH70002FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@00=Woo000]Ool200000eYF001JEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00D0009o
o`L000AJEP03001JEUYF009JEPP003]oo`00;Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEQ`000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool90013Ool002eoo`04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP04001JEUYFFUH2001FOol002eoo`04001JEUYF0005FUH00`00FUIJEP02FUH800000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1P001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00001`000eYF00<005YFFUH00UYF0P00EGoo000]Ool01000FUIJEP000eYF
1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001Goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF1P000UYF0P00EGoo000]Ool80007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH9000DOol00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF001JEP05FUH00`00FUIJEP0200000goo00000002001EOol002eooa`001ioo`80
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0006FUH30006Ool2001DOol006Uoo`04
001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF0P001goo0`00E7oo001ZOol30008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUH000001EYF00<005YF00000`001goo0P0000=JEP000000E7oo001/Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40003
FUH6000:Ool00`00FUIJEP02FUH00`00Oomoo`1BOol006moo`@0009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00/000ioo`<000AJEP03001oogoo
059oo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`004Goo0P00
0UYF00<005YFFUH00UYF00<007ooOol0DWoo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP060006Ool5000?Ool20005FUH01000FUIJEP00EGoo001nOolO000<Ool5000=Ool2
00000eYF001JEP04FUH3001FOol008ioo`80009JEP03001oogoo01Eoo`<000]oo`<000=JEP03001J
EUYF00=JEP03001oogoo05Ioo`00SWoo00@005YF000002=oo`<000IJEP03001JEUYF009JEP03001o
ogoo05Moo`00SWoo00@005YF0000025oo`800003FUH005YF00MJEP04001JEP00001JOol008ioo`03
001JEP00008001eoo`<000=JEP03001JEUYF00IJEP8005aoo`00Sgoo00AJEP00001JEP8001Eoo`H0
00MJEP03001JEUYF00AJEP8005eoo`00Sgoo00<005YF00000eYF5@0015YF00<005YFFUH01UYF00<0
05YFFUH01000Ggoo002?Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF1000Hgoo002@Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH2001WOol0099oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP00008006Uoo`00U7oo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1P00K7oo002FOolE001bOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]22\[InvisibleSpace]"     "\
\[InvisibleSpace]6.577070071926744`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 22, "     ", 6.5770700719267436, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59612 .73349 m .59798 .67687 L .56681 .67455 L p .707 .577 .707 r
F P
0 g
s
.59798 .67687 m .59612 .73349 L .62794 .73394 L p .707 .577 .707 r
F P
0 g
s
.62794 .73394 m .62979 .67732 L .59798 .67687 L p .707 .577 .707 r
F P
0 g
s
.62979 .67732 m .62794 .73394 L .65729 .73247 L p .707 .577 .707 r
F P
0 g
s
.65729 .73247 m .65914 .67585 L .62979 .67732 L p .707 .577 .707 r
F P
0 g
s
.56496 .73117 m .56681 .67455 L .53935 .67058 L p .707 .577 .707 r
F P
0 g
s
.56681 .67455 m .56496 .73117 L .59612 .73349 L p .707 .577 .707 r
F P
0 g
s
.65914 .67585 m .65729 .73247 L .6813 .72922 L p .707 .577 .707 r
F P
0 g
s
.6813 .72922 m .68316 .6726 L .65914 .67585 L p .707 .577 .707 r
F P
0 g
s
.53935 .67058 m .53749 .7272 L .56496 .73117 L p .707 .577 .707 r
F P
0 g
s
.59466 .79056 m .5976 .75233 L .56647 .74941 L p .707 .577 .707 r
F P
0 g
s
.5976 .75233 m .59466 .79056 L .62638 .79274 L p .707 .577 .707 r
F P
0 g
s
.62638 .79274 m .62932 .7545 L .5976 .75233 L p .707 .577 .707 r
F P
0 g
s
.53749 .7272 m .53935 .67058 L .51827 .66535 L p .707 .577 .707 r
F P
0 g
s
.56647 .74941 m .56353 .78764 L .59466 .79056 L p .707 .577 .707 r
F P
0 g
s
.62932 .7545 m .62638 .79274 L .65558 .79396 L p .707 .577 .707 r
F P
0 g
s
.65558 .79396 m .65852 .75572 L .62932 .7545 L p .707 .577 .707 r
F P
0 g
s
.56353 .78764 m .56647 .74941 L .53897 .74603 L p .707 .577 .707 r
F P
0 g
s
.53897 .74603 m .53603 .78427 L .56353 .78764 L p .707 .577 .707 r
F P
0 g
s
.51827 .66535 m .51642 .72197 L .53749 .7272 L p .707 .577 .707 r
F P
0 g
s
.65852 .75572 m .65558 .79396 L .67941 .7941 L p .707 .577 .707 r
F P
0 g
s
.67941 .7941 m .68235 .75587 L .65852 .75572 L p .707 .577 .707 r
F P
0 g
s
.68316 .6726 m .6813 .72922 L .69763 .72452 L p .707 .577 .707 r
F P
0 g
s
.69763 .72452 m .69948 .6679 L .68316 .6726 L p .707 .577 .707 r
F P
0 g
s
.59541 .84916 m .59661 .83009 L .56546 .82736 L p .707 .577 .707 r
F P
0 g
s
.59661 .83009 m .59541 .84916 L .62716 .8508 L p .707 .577 .707 r
F P
0 g
s
.62716 .8508 m .62837 .83173 L .59661 .83009 L p .707 .577 .707 r
F P
0 g
s
.56546 .82736 m .56426 .84643 L .59541 .84916 L p .707 .577 .707 r
F P
0 g
s
.62837 .83173 m .62716 .8508 L .65643 .85117 L p .707 .577 .707 r
F P
0 g
s
.65643 .85117 m .65763 .8321 L .62837 .83173 L p .707 .577 .707 r
F P
0 g
s
.53603 .78427 m .53897 .74603 L .5178 .74253 L p .707 .577 .707 r
F P
0 g
s
.5178 .74253 m .51486 .78077 L .53603 .78427 L p .707 .577 .707 r
F P
0 g
s
.56426 .84643 m .56546 .82736 L .53798 .8238 L p .707 .577 .707 r
F P
0 g
s
.51642 .72197 m .51827 .66535 L .50565 .65937 L p .707 .577 .707 r
F P
0 g
s
.53798 .8238 m .53677 .84287 L .56426 .84643 L p .707 .577 .707 r
F P
0 g
s
.65763 .8321 m .65643 .85117 L .68033 .85025 L p .707 .577 .707 r
F P
0 g
s
.68033 .85025 m .68153 .83118 L .65763 .8321 L p .707 .577 .707 r
F P
0 g
s
.50565 .65937 m .50379 .71599 L .51642 .72197 L p .707 .577 .707 r
F P
0 g
s
.68235 .75587 m .67941 .7941 L .69553 .79316 L p .707 .577 .707 r
F P
0 g
s
.69553 .79316 m .69847 .75492 L .68235 .75587 L p .707 .577 .707 r
F P
0 g
s
.53677 .84287 m .53798 .8238 L .51685 .81976 L p .707 .577 .707 r
F P
0 g
s
.69948 .6679 m .69763 .72452 L .70467 .71882 L p .707 .577 .707 r
F P
0 g
s
.70467 .71882 m .70652 .6622 L .69948 .6679 L p .707 .577 .707 r
F P
0 g
s
.51685 .81976 m .51564 .83883 L .53677 .84287 L p .707 .577 .707 r
F P
0 g
s
.51486 .78077 m .5178 .74253 L .50503 .73925 L p .707 .577 .707 r
F P
0 g
s
.50503 .73925 m .50209 .77748 L .51486 .78077 L p .707 .577 .707 r
F P
0 g
s
.50379 .71599 m .50565 .65937 L .50271 .65324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83118 m .68033 .85025 L .69653 .84813 L p .707 .577 .707 r
F P
0 g
s
.69653 .84813 m .69773 .82906 L .68153 .83118 L p .707 .577 .707 r
F P
0 g
s
.69847 .75492 m .69553 .79316 L .70236 .79121 L p .707 .577 .707 r
F P
0 g
s
.70236 .79121 m .7053 .75298 L .69847 .75492 L p .707 .577 .707 r
F P
0 g
s
.51564 .83883 m .51685 .81976 L .50413 .81563 L p .707 .577 .707 r
F P
0 g
s
.50271 .65324 m .50086 .70985 L .50379 .71599 L p .707 .577 .707 r
F P
0 g
s
.50413 .81563 m .50293 .8347 L .51564 .83883 L p .707 .577 .707 r
F P
0 g
s
.70652 .6622 m .70467 .71882 L .70173 .71268 L p .707 .577 .707 r
F P
0 g
s
.70173 .71268 m .70359 .65606 L .70652 .6622 L p .707 .577 .707 r
F P
0 g
s
.50209 .77748 m .50503 .73925 L .5019 .7365 L p .707 .577 .707 r
F P
0 g
s
.5019 .7365 m .49896 .77473 L .50209 .77748 L p .707 .577 .707 r
F P
0 g
s
.4942 .82231 m .48971 .32357 L .4457 .32104 L p .707 .577 .707 r
F P
0 g
s
.50086 .70985 m .50271 .65324 L .50975 .64754 L p .707 .577 .707 r
F P
0 g
s
.50293 .8347 m .50413 .81563 L .50109 .81182 L p .707 .577 .707 r
F P
0 g
s
.50109 .81182 m .49988 .83089 L .50293 .8347 L p .707 .577 .707 r
F P
0 g
s
.50975 .64754 m .50789 .70415 L .50086 .70985 L p .707 .577 .707 r
F P
0 g
s
.49896 .77473 m .5019 .7365 L .50873 .73456 L p .707 .577 .707 r
F P
0 g
s
.50873 .73456 m .5058 .77279 L .49896 .77473 L p .707 .577 .707 r
F P
0 g
s
.50789 .70415 m .50975 .64754 L .52608 .64283 L p .707 .577 .707 r
F P
0 g
s
.49988 .83089 m .50109 .81182 L .508 .80869 L p .707 .577 .707 r
F P
0 g
s
.52608 .64283 m .52422 .69945 L .50789 .70415 L p .707 .577 .707 r
F P
0 g
s
.508 .80869 m .5068 .82776 L .49988 .83089 L p .707 .577 .707 r
F P
0 g
s
.5058 .77279 m .50873 .73456 L .52485 .73361 L p .707 .577 .707 r
F P
0 g
s
.52485 .73361 m .52192 .77185 L .5058 .77279 L p .707 .577 .707 r
F P
0 g
s
.52422 .69945 m .52608 .64283 L .55009 .63959 L p .707 .577 .707 r
F P
0 g
s
.55009 .63959 m .54823 .6962 L .52422 .69945 L p .707 .577 .707 r
F P
0 g
s
.5068 .82776 m .508 .80869 L .5242 .80657 L p .707 .577 .707 r
F P
0 g
s
.5242 .80657 m .523 .82564 L .5068 .82776 L p .707 .577 .707 r
F P
0 g
s
.52192 .77185 m .52485 .73361 L .54868 .73376 L p .707 .577 .707 r
F P
0 g
s
.54868 .73376 m .54574 .77199 L .52192 .77185 L p .707 .577 .707 r
F P
0 g
s
.523 .82564 m .5242 .80657 L .5481 .80565 L p .707 .577 .707 r
F P
0 g
s
.5481 .80565 m .5469 .82472 L .523 .82564 L p .707 .577 .707 r
F P
0 g
s
.48971 .32357 m .4942 .82231 L .53914 .82076 L p .707 .577 .707 r
F P
0 g
s
.53914 .82076 m .53465 .32201 L .48971 .32357 L p .707 .577 .707 r
F P
0 g
s
.69773 .82906 m .69653 .84813 L .70344 .84501 L p .707 .577 .707 r
F P
0 g
s
.70344 .84501 m .70465 .82594 L .69773 .82906 L p .707 .577 .707 r
F P
0 g
s
.54823 .6962 m .55009 .63959 L .57944 .63811 L p .707 .577 .707 r
F P
0 g
s
.57944 .63811 m .57758 .69473 L .54823 .6962 L p .707 .577 .707 r
F P
0 g
s
.54574 .77199 m .54868 .73376 L .57788 .73498 L p .707 .577 .707 r
F P
0 g
s
.57788 .73498 m .57495 .77321 L .54574 .77199 L p .707 .577 .707 r
F P
0 g
s
.57495 .77321 m .57788 .73498 L .6096 .73715 L p .707 .577 .707 r
F P
0 g
s
.6096 .73715 m .60667 .77539 L .57495 .77321 L p .707 .577 .707 r
F P
0 g
s
.5469 .82472 m .5481 .80565 L .57737 .80603 L p .707 .577 .707 r
F P
0 g
s
.57737 .80603 m .57616 .8251 L .5469 .82472 L p .707 .577 .707 r
F P
0 g
s
.57616 .8251 m .57737 .80603 L .60912 .80766 L p .707 .577 .707 r
F P
0 g
s
.53465 .32201 m .53914 .82076 L .58062 .81528 L p .707 .577 .707 r
F P
0 g
s
.57758 .69473 m .57944 .63811 L .61126 .63856 L p .707 .577 .707 r
F P
0 g
s
.61126 .63856 m .6094 .69518 L .57758 .69473 L p .707 .577 .707 r
F P
0 g
s
.58062 .81528 m .57613 .31653 L .53465 .32201 L p .707 .577 .707 r
F P
0 g
s
.45019 .81979 m .4457 .32104 L .40694 .31468 L p .707 .577 .707 r
F P
0 g
s
.4457 .32104 m .45019 .81979 L .4942 .82231 L p .707 .577 .707 r
F P
0 g
s
.7053 .75298 m .70236 .79121 L .69924 .78847 L p .707 .577 .707 r
F P
0 g
s
.69924 .78847 m .70218 .75023 L .7053 .75298 L p .707 .577 .707 r
F P
0 g
s
.64074 .74007 m .6378 .77831 L .61405 .77608 L p .707 .577 .707 r
F P
0 g
s
.61405 .77608 m .60667 .77539 L p .61441 .76736 L .707 .577 .707 r
F P
0 g
s
.61441 .76736 m .64074 .74007 L .61405 .77608 L .707 .577 .707 r
F
.66989 .64485 m .66803 .70147 L .64056 .6975 L p F P
0 g
s
.64056 .6975 m .64242 .64088 L .66989 .64485 L p .707 .577 .707 r
F P
0 g
s
.64242 .64088 m .64056 .6975 L .6094 .69518 L p .707 .577 .707 r
F P
0 g
s
.6094 .69518 m .61126 .63856 L .64242 .64088 L p .707 .577 .707 r
F P
0 g
s
.66823 .74345 m .6653 .78168 L .6378 .77831 L p .707 .577 .707 r
F P
0 g
s
.6378 .77831 m .64074 .74007 L .66823 .74345 L p .707 .577 .707 r
F P
0 g
s
.60667 .77539 m .6096 .73715 L .64074 .74007 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .64767 .78221 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63319 .29627 m .63334 .31324 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63334 .31324 m .63768 .79501 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.60792 .82673 m .60912 .80766 L .64027 .81039 L p .707 .577 .707 r
F P
0 g
s
.60912 .80766 m .60792 .82673 L .57616 .8251 L p .707 .577 .707 r
F P
0 g
s
.57613 .31653 m .58062 .81528 L .61457 .8064 L p .707 .577 .707 r
F P
0 g
s
.61457 .8064 m .61008 .30766 L .57613 .31653 L p .707 .577 .707 r
F P
0 g
s
.70359 .65606 m .70173 .71268 L .68911 .7067 L p .707 .577 .707 r
F P
0 g
s
.68911 .7067 m .69096 .65008 L .70359 .65606 L p .707 .577 .707 r
F P
0 g
s
.25311 .69668 m .25497 .64006 L .2238 .63774 L p .707 .577 .707 r
F P
0 g
s
.25497 .64006 m .25311 .69668 L .28493 .69712 L p .707 .577 .707 r
F P
0 g
s
.28493 .69712 m .28678 .64051 L .25497 .64006 L p .707 .577 .707 r
F P
0 g
s
.41143 .81343 m .40694 .31468 L .37721 .30512 L p .707 .577 .707 r
F P
0 g
s
.40694 .31468 m .41143 .81343 L .45019 .81979 L p .707 .577 .707 r
F P
0 g
s
.70465 .82594 m .70344 .84501 L .70039 .8412 L p .707 .577 .707 r
F P
0 g
s
.70039 .8412 m .7016 .82213 L .70465 .82594 L p .707 .577 .707 r
F P
0 g
s
.28678 .64051 m .28493 .69712 L .31428 .69565 L p .707 .577 .707 r
F P
0 g
s
.31428 .69565 m .31614 .63903 L .28678 .64051 L p .707 .577 .707 r
F P
0 g
s
.22195 .69435 m .2238 .63774 L .19634 .63376 L p .707 .577 .707 r
F P
0 g
s
.2238 .63774 m .22195 .69435 L .25311 .69668 L p .707 .577 .707 r
F P
0 g
s
.31614 .63903 m .31428 .69565 L .33829 .69241 L p .707 .577 .707 r
F P
0 g
s
.33829 .69241 m .34015 .63579 L .31614 .63903 L p .707 .577 .707 r
F P
0 g
s
.70218 .75023 m .69924 .78847 L .68647 .78518 L p .707 .577 .707 r
F P
0 g
s
.68647 .78518 m .6894 .74695 L .70218 .75023 L p .707 .577 .707 r
F P
0 g
s
.61008 .30766 m .61457 .8064 L .63768 .79501 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .63319 .29627 L .61008 .30766 L p .707 .577 .707 r
F P
0 g
s
.19634 .63376 m .19448 .69038 L .22195 .69435 L p .707 .577 .707 r
F P
0 g
s
.25165 .75375 m .25459 .71551 L .22346 .71259 L p .707 .577 .707 r
F P
0 g
s
.25459 .71551 m .25165 .75375 L .28337 .75592 L p .707 .577 .707 r
F P
0 g
s
.28337 .75592 m .28631 .71769 L .25459 .71551 L p .707 .577 .707 r
F P
0 g
s
.69096 .65008 m .68911 .7067 L .66803 .70147 L p .707 .577 .707 r
F P
0 g
s
.66803 .70147 m .66989 .64485 L .69096 .65008 L p .707 .577 .707 r
F P
0 g
s
.19448 .69038 m .19634 .63376 L .17526 .62854 L p .707 .577 .707 r
F P
0 g
s
.22346 .71259 m .22052 .75083 L .25165 .75375 L p .707 .577 .707 r
F P
0 g
s
.28631 .71769 m .28337 .75592 L .31257 .75714 L p .707 .577 .707 r
F P
0 g
s
.31257 .75714 m .31551 .71891 L .28631 .71769 L p .707 .577 .707 r
F P
0 g
s
.22052 .75083 m .22346 .71259 L .19596 .70922 L p .707 .577 .707 r
F P
0 g
s
.19596 .70922 m .19302 .74745 L .22052 .75083 L p .707 .577 .707 r
F P
0 g
s
.3817 .80386 m .37721 .30512 L .35943 .29327 L p .707 .577 .707 r
F P
0 g
s
.37721 .30512 m .3817 .80386 L .41143 .81343 L p .707 .577 .707 r
F P
0 g
s
.17526 .62854 m .17341 .68515 L .19448 .69038 L p .707 .577 .707 r
F P
0 g
s
.7016 .82213 m .70039 .8412 L .68768 .83707 L p .707 .577 .707 r
F P
0 g
s
.68768 .83707 m .68889 .818 L .7016 .82213 L p .707 .577 .707 r
F P
0 g
s
.31551 .71891 m .31257 .75714 L .3364 .75729 L p .707 .577 .707 r
F P
0 g
s
.3364 .75729 m .33934 .71905 L .31551 .71891 L p .707 .577 .707 r
F P
0 g
s
.34015 .63579 m .33829 .69241 L .35462 .6877 L p .707 .577 .707 r
F P
0 g
s
.35462 .6877 m .35647 .63108 L .34015 .63579 L p .707 .577 .707 r
F P
0 g
s
.2524 .81235 m .2536 .79328 L .22246 .79055 L p .707 .577 .707 r
F P
0 g
s
.2536 .79328 m .2524 .81235 L .28415 .81398 L p .707 .577 .707 r
F P
0 g
s
.28415 .81398 m .28536 .79491 L .2536 .79328 L p .707 .577 .707 r
F P
0 g
s
.22246 .79055 m .22125 .80962 L .2524 .81235 L p .707 .577 .707 r
F P
0 g
s
.28536 .79491 m .28415 .81398 L .31342 .81436 L p .707 .577 .707 r
F P
0 g
s
.31342 .81436 m .31462 .79529 L .28536 .79491 L p .707 .577 .707 r
F P
0 g
s
.19302 .74745 m .19596 .70922 L .17479 .70572 L p .707 .577 .707 r
F P
0 g
s
.6894 .74695 m .68647 .78518 L .6653 .78168 L p .707 .577 .707 r
F P
0 g
s
.6653 .78168 m .66823 .74345 L .6894 .74695 L p .707 .577 .707 r
F P
0 g
s
.17479 .70572 m .17185 .74395 L .19302 .74745 L p .707 .577 .707 r
F P
0 g
s
.22125 .80962 m .22246 .79055 L .19497 .78699 L p .707 .577 .707 r
F P
0 g
s
.17341 .68515 m .17526 .62854 L .16264 .62256 L p .707 .577 .707 r
F P
0 g
s
.19497 .78699 m .19377 .80606 L .22125 .80962 L p .707 .577 .707 r
F P
0 g
s
.64767 .78221 m .64318 .28347 L .63319 .29627 L p .707 .577 .707 r
F P
0 g
s
.31462 .79529 m .31342 .81436 L .33732 .81344 L p .707 .577 .707 r
F P
0 g
s
.33732 .81344 m .33852 .79437 L .31462 .79529 L p .707 .577 .707 r
F P
0 g
s
.16264 .62256 m .16078 .67918 L .17341 .68515 L p .707 .577 .707 r
F P
0 g
s
.33934 .71905 m .3364 .75729 L .35252 .75634 L p .707 .577 .707 r
F P
0 g
s
.35252 .75634 m .35546 .71811 L .33934 .71905 L p .707 .577 .707 r
F P
0 g
s
.19377 .80606 m .19497 .78699 L .17384 .78294 L p .707 .577 .707 r
F P
0 g
s
.68889 .818 m .68768 .83707 L .66655 .83302 L p .707 .577 .707 r
F P
0 g
s
.66655 .83302 m .66775 .81395 L .68889 .818 L p .707 .577 .707 r
F P
0 g
s
.35647 .63108 m .35462 .6877 L .36166 .682 L p .707 .577 .707 r
F P
0 g
s
.36166 .682 m .36351 .62538 L .35647 .63108 L p .707 .577 .707 r
F P
0 g
s
.17384 .78294 m .17263 .80201 L .19377 .80606 L p .707 .577 .707 r
F P
0 g
s
.17185 .74395 m .17479 .70572 L .16202 .70243 L p .707 .577 .707 r
F P
0 g
s
.16202 .70243 m .15908 .74067 L .17185 .74395 L p .707 .577 .707 r
F P
0 g
s
.36351 .62538 m .36166 .682 L .35872 .67586 L p .707 .577 .707 r
F P
0 g
s
.35872 .67586 m .36058 .61925 L .36351 .62538 L p .707 .577 .707 r
F P
0 g
s
.36392 .79202 m .35943 .29327 L .35534 .28032 L p .707 .577 .707 r
F P
0 g
s
.35943 .29327 m .36392 .79202 L .3817 .80386 L p .707 .577 .707 r
F P
0 g
s
.16078 .67918 m .16264 .62256 L .1597 .61642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79437 m .33732 .81344 L .35352 .81131 L p .707 .577 .707 r
F P
0 g
s
.35352 .81131 m .35472 .79224 L .33852 .79437 L p .707 .577 .707 r
F P
0 g
s
.35546 .71811 m .35252 .75634 L .35935 .7544 L p .707 .577 .707 r
F P
0 g
s
.35935 .7544 m .36229 .71617 L .35546 .71811 L p .707 .577 .707 r
F P
0 g
s
.17263 .80201 m .17384 .78294 L .16112 .77881 L p .707 .577 .707 r
F P
0 g
s
.1597 .61642 m .15785 .67304 L .16078 .67918 L p .707 .577 .707 r
F P
0 g
s
.66775 .81395 m .66655 .83302 L .63906 .82946 L p .707 .577 .707 r
F P
0 g
s
.63906 .82946 m .64027 .81039 L .66775 .81395 L p .707 .577 .707 r
F P
0 g
s
.16112 .77881 m .15992 .79788 L .17263 .80201 L p .707 .577 .707 r
F P
0 g
s
.15908 .74067 m .16202 .70243 L .15889 .69968 L p .707 .577 .707 r
F P
0 g
s
.64318 .28347 m .64767 .78221 L .64492 .77349 L p .707 .577 .707 r
F P
0 g
s
.64356 .74773 m .64318 .28347 L .64492 .77349 L .707 .577 .707 r
F
.64358 .76925 m .63909 .27051 L .64318 .28347 L p F P
0 g
s
.63909 .27051 m .64358 .76925 L .6258 .75741 L p .707 .577 .707 r
F P
0 g
s
.64223 .64848 m .63992 .67852 L p .65206 .69 L .707 .577 .707 r
F P
0 g
s
.63992 .67852 m .63929 .68671 L .64037 .68699 L p .707 .577 .707 r
F P
0 g
s
.64037 .68699 m .65206 .69 L p .63992 .67852 L .707 .577 .707 r
F P
0 g
s
.64492 .77349 m .64358 .76925 L p .64356 .74773 L .707 .577 .707 r
F P
0 g
s
.15889 .69968 m .15596 .73792 L .15908 .74067 L p .707 .577 .707 r
F P
0 g
s
.64027 .81039 m .63906 .82946 L .60792 .82673 L p .707 .577 .707 r
F P
0 g
s
.35472 .79224 m .35352 .81131 L .36043 .80819 L p .707 .577 .707 r
F P
0 g
s
.36043 .80819 m .36164 .78912 L .35472 .79224 L p .707 .577 .707 r
F P
0 g
s
.15785 .67304 m .1597 .61642 L .16674 .61072 L p .707 .577 .707 r
F P
0 g
s
.15992 .79788 m .16112 .77881 L .15808 .775 L p .707 .577 .707 r
F P
0 g
s
.36229 .71617 m .35935 .7544 L .35623 .75165 L p .707 .577 .707 r
F P
0 g
s
.35623 .75165 m .35917 .71342 L .36229 .71617 L p .707 .577 .707 r
F P
0 g
s
.36058 .61925 m .35872 .67586 L .3461 .66989 L p .707 .577 .707 r
F P
0 g
s
.3461 .66989 m .34795 .61327 L .36058 .61925 L p .707 .577 .707 r
F P
0 g
s
.35534 .28032 m .35982 .77906 L .36392 .79202 L p .707 .577 .707 r
F P
0 g
s
.35982 .77906 m .35534 .28032 L .36533 .26752 L p .707 .577 .707 r
F P
0 g
s
.15808 .775 m .15687 .79407 L .15992 .79788 L p .707 .577 .707 r
F P
0 g
s
.16674 .61072 m .16489 .66734 L .15785 .67304 L p .707 .577 .707 r
F P
0 g
s
.15596 .73792 m .15889 .69968 L .16573 .69774 L p .707 .577 .707 r
F P
0 g
s
.16573 .69774 m .16279 .73598 L .15596 .73792 L p .707 .577 .707 r
F P
0 g
s
.36164 .78912 m .36043 .80819 L .35739 .80438 L p .707 .577 .707 r
F P
0 g
s
.35739 .80438 m .35859 .78531 L .36164 .78912 L p .707 .577 .707 r
F P
0 g
s
.16489 .66734 m .16674 .61072 L .18307 .60602 L p .707 .577 .707 r
F P
0 g
s
.6258 .75741 m .62131 .25867 L .63909 .27051 L p .707 .577 .707 r
F P
0 g
s
.15687 .79407 m .15808 .775 L .16499 .77188 L p .707 .577 .707 r
F P
0 g
s
.18307 .60602 m .18121 .66264 L .16489 .66734 L p .707 .577 .707 r
F P
0 g
s
.35917 .71342 m .35623 .75165 L .34346 .74837 L p .707 .577 .707 r
F P
0 g
s
.34346 .74837 m .3464 .71013 L .35917 .71342 L p .707 .577 .707 r
F P
0 g
s
.16499 .77188 m .16379 .79095 L .15687 .79407 L p .707 .577 .707 r
F P
0 g
s
.34795 .61327 m .3461 .66989 L .32502 .66466 L p .707 .577 .707 r
F P
0 g
s
.32502 .66466 m .32688 .60804 L .34795 .61327 L p .707 .577 .707 r
F P
0 g
s
.36982 .76626 m .36533 .26752 L .38844 .25612 L p .707 .577 .707 r
F P
0 g
s
.36533 .26752 m .36982 .76626 L .35982 .77906 L p .707 .577 .707 r
F P
0 g
s
.16279 .73598 m .16573 .69774 L .18184 .6968 L p .707 .577 .707 r
F P
0 g
s
.18184 .6968 m .17891 .73503 L .16279 .73598 L p .707 .577 .707 r
F P
0 g
s
.18121 .66264 m .18307 .60602 L .20708 .60277 L p .707 .577 .707 r
F P
0 g
s
.35859 .78531 m .35739 .80438 L .34467 .80025 L p .707 .577 .707 r
F P
0 g
s
.34467 .80025 m .34588 .78118 L .35859 .78531 L p .707 .577 .707 r
F P
0 g
s
.20708 .60277 m .20522 .65939 L .18121 .66264 L p .707 .577 .707 r
F P
0 g
s
.16379 .79095 m .16499 .77188 L .18119 .76976 L p .707 .577 .707 r
F P
0 g
s
.3464 .71013 m .34346 .74837 L .32229 .74487 L p .707 .577 .707 r
F P
0 g
s
.32229 .74487 m .32522 .70663 L .3464 .71013 L p .707 .577 .707 r
F P
0 g
s
.32688 .60804 m .32502 .66466 L .29755 .66069 L p .707 .577 .707 r
F P
0 g
s
.29755 .66069 m .29941 .60407 L .32688 .60804 L p .707 .577 .707 r
F P
0 g
s
.18119 .76976 m .17999 .78883 L .16379 .79095 L p .707 .577 .707 r
F P
0 g
s
.62131 .25867 m .6258 .75741 L .59607 .74784 L p .707 .577 .707 r
F P
0 g
s
.59607 .74784 m .59158 .2491 L .62131 .25867 L p .707 .577 .707 r
F P
0 g
s
.20522 .65939 m .20708 .60277 L .23643 .6013 L p .707 .577 .707 r
F P
0 g
s
.17891 .73503 m .18184 .6968 L .20567 .69694 L p .707 .577 .707 r
F P
0 g
s
.20567 .69694 m .20273 .73518 L .17891 .73503 L p .707 .577 .707 r
F P
0 g
s
.29941 .60407 m .29755 .66069 L .26639 .65837 L p .707 .577 .707 r
F P
0 g
s
.26639 .65837 m .26825 .60175 L .29941 .60407 L p .707 .577 .707 r
F P
0 g
s
.38844 .25612 m .39292 .75487 L .36982 .76626 L p .707 .577 .707 r
F P
0 g
s
.39292 .75487 m .38844 .25612 L .42239 .24725 L p .707 .577 .707 r
F P
0 g
s
.23643 .6013 m .23457 .65792 L .20522 .65939 L p .707 .577 .707 r
F P
0 g
s
.34588 .78118 m .34467 .80025 L .32354 .79621 L p .707 .577 .707 r
F P
0 g
s
.32354 .79621 m .32474 .77714 L .34588 .78118 L p .707 .577 .707 r
F P
0 g
s
.23457 .65792 m .23643 .6013 L .26825 .60175 L p .707 .577 .707 r
F P
0 g
s
.26825 .60175 m .26639 .65837 L .23457 .65792 L p .707 .577 .707 r
F P
0 g
s
.32522 .70663 m .32229 .74487 L .29479 .74149 L p .707 .577 .707 r
F P
0 g
s
.29479 .74149 m .29773 .70326 L .32522 .70663 L p .707 .577 .707 r
F P
0 g
s
.73333 .65704 m .73518 .60042 L .70402 .5981 L p .707 .577 .707 r
F P
0 g
s
.73518 .60042 m .73333 .65704 L .76514 .65749 L p .707 .577 .707 r
F P
0 g
s
.76514 .65749 m .767 .60087 L .73518 .60042 L p .707 .577 .707 r
F P
0 g
s
.17999 .78883 m .18119 .76976 L .20509 .76884 L p .707 .577 .707 r
F P
0 g
s
.767 .60087 m .76514 .65749 L .79449 .65602 L p .707 .577 .707 r
F P
0 g
s
.79449 .65602 m .79635 .5994 L .767 .60087 L p .707 .577 .707 r
F P
0 g
s
.20509 .76884 m .20389 .78791 L .17999 .78883 L p .707 .577 .707 r
F P
0 g
s
.20273 .73518 m .20567 .69694 L .23487 .69816 L p .707 .577 .707 r
F P
0 g
s
.70216 .65472 m .70402 .5981 L .67655 .59413 L p .707 .577 .707 r
F P
0 g
s
.70402 .5981 m .70216 .65472 L .73333 .65704 L p .707 .577 .707 r
F P
0 g
s
.23487 .69816 m .23194 .7364 L .20273 .73518 L p .707 .577 .707 r
F P
0 g
s
.59158 .2491 m .59607 .74784 L .55731 .74149 L p .707 .577 .707 r
F P
0 g
s
.55731 .74149 m .55282 .24274 L .59158 .2491 L p .707 .577 .707 r
F P
0 g
s
.29773 .70326 m .29479 .74149 L .26366 .73857 L p .707 .577 .707 r
F P
0 g
s
.26366 .73857 m .26659 .70034 L .29773 .70326 L p .707 .577 .707 r
F P
0 g
s
.79635 .5994 m .79449 .65602 L .81851 .65277 L p .707 .577 .707 r
F P
0 g
s
.81851 .65277 m .82036 .59615 L .79635 .5994 L p .707 .577 .707 r
F P
0 g
s
.73186 .69979 m .7348 .66156 L .70367 .65864 L p .707 .577 .707 r
F P
0 g
s
.7348 .66156 m .73186 .69979 L .76358 .70197 L p .707 .577 .707 r
F P
0 g
s
.76358 .70197 m .76652 .66373 L .7348 .66156 L p .707 .577 .707 r
F P
0 g
s
.32474 .77714 m .32354 .79621 L .29606 .79265 L p .707 .577 .707 r
F P
0 g
s
.29606 .79265 m .29726 .77358 L .32474 .77714 L p .707 .577 .707 r
F P
0 g
s
.23194 .7364 m .23487 .69816 L .26659 .70034 L p .707 .577 .707 r
F P
0 g
s
.67655 .59413 m .6747 .65075 L .70216 .65472 L p .707 .577 .707 r
F P
0 g
s
.70367 .65864 m .70073 .69687 L .73186 .69979 L p .707 .577 .707 r
F P
0 g
s
.76652 .66373 m .76358 .70197 L .79279 .70319 L p .707 .577 .707 r
F P
0 g
s
.79279 .70319 m .79573 .66495 L .76652 .66373 L p .707 .577 .707 r
F P
0 g
s
.26659 .70034 m .26366 .73857 L .23194 .7364 L p .707 .577 .707 r
F P
0 g
s
.42688 .74599 m .42239 .24725 L .46387 .24177 L p .707 .577 .707 r
F P
0 g
s
.42239 .24725 m .42665 .72043 L p .39292 .75487 L .707 .577 .707 r
F P
0 g
s
.46387 .24177 m .46836 .74051 L .42688 .74599 L p .707 .577 .707 r
F P
0 g
s
.42351 .62692 m .42057 .66515 L .44732 .66627 L p .707 .577 .707 r
F P
0 g
s
.44732 .66627 m .44978 .66637 L p .44819 .66399 L .707 .577 .707 r
F P
0 g
s
.44819 .66399 m .42351 .62692 L .44732 .66627 L .707 .577 .707 r
F
.42665 .72043 m .42688 .74599 L .41578 .74889 L p F P
0 g
s
.41578 .74889 m .39292 .75487 L p .42665 .72043 L .707 .577 .707 r
F P
0 g
s
.6747 .65075 m .67655 .59413 L .65548 .5889 L p .707 .577 .707 r
F P
0 g
s
.70073 .69687 m .70367 .65864 L .67617 .65526 L p .707 .577 .707 r
F P
0 g
s
.20389 .78791 m .20509 .76884 L .23436 .76921 L p .707 .577 .707 r
F P
0 g
s
.23436 .76921 m .23315 .78828 L .20389 .78791 L p .707 .577 .707 r
F P
0 g
s
.67617 .65526 m .67323 .6935 L .70073 .69687 L p .707 .577 .707 r
F P
0 g
s
.73261 .7313 m .73381 .71223 L .70267 .7095 L p .707 .577 .707 r
F P
0 g
s
.73381 .71223 m .73261 .7313 L .76437 .73294 L p .707 .577 .707 r
F P
0 g
s
.76437 .73294 m .76557 .71387 L .73381 .71223 L p .707 .577 .707 r
F P
0 g
s
.70267 .7095 m .70146 .72857 L .73261 .7313 L p .707 .577 .707 r
F P
0 g
s
.76557 .71387 m .76437 .73294 L .79363 .73331 L p .707 .577 .707 r
F P
0 g
s
.79363 .73331 m .79483 .71424 L .76557 .71387 L p .707 .577 .707 r
F P
0 g
s
.55282 .24274 m .55731 .74149 L .5133 .73896 L p .707 .577 .707 r
F P
0 g
s
.5133 .73896 m .50881 .24022 L .55282 .24274 L p .707 .577 .707 r
F P
0 g
s
.79573 .66495 m .79279 .70319 L .81661 .70333 L p .707 .577 .707 r
F P
0 g
s
.81661 .70333 m .81955 .6651 L .79573 .66495 L p .707 .577 .707 r
F P
0 g
s
.29726 .77358 m .29606 .79265 L .26491 .78991 L p .707 .577 .707 r
F P
0 g
s
.26491 .78991 m .26611 .77084 L .29726 .77358 L p .707 .577 .707 r
F P
0 g
s
.65548 .5889 m .65362 .64552 L .6747 .65075 L p .707 .577 .707 r
F P
0 g
s
.70146 .72857 m .70267 .7095 L .67518 .70594 L p .707 .577 .707 r
F P
0 g
s
.23315 .78828 m .23436 .76921 L .26611 .77084 L p .707 .577 .707 r
F P
0 g
s
.67518 .70594 m .67398 .72501 L .70146 .72857 L p .707 .577 .707 r
F P
0 g
s
.82036 .59615 m .81851 .65277 L .83483 .64807 L p .707 .577 .707 r
F P
0 g
s
.83483 .64807 m .83669 .59145 L .82036 .59615 L p .707 .577 .707 r
F P
0 g
s
.46836 .74051 m .46387 .24177 L .50881 .24022 L p .707 .577 .707 r
F P
0 g
s
.26611 .77084 m .26491 .78991 L .23315 .78828 L p .707 .577 .707 r
F P
0 g
s
.67323 .6935 m .67617 .65526 L .655 .65176 L p .707 .577 .707 r
F P
0 g
s
.50881 .24022 m .5133 .73896 L .46836 .74051 L p .707 .577 .707 r
F P
0 g
s
.655 .65176 m .65206 .69 L .67323 .6935 L p .707 .577 .707 r
F P
0 g
s
.79483 .71424 m .79363 .73331 L .81753 .73239 L p .707 .577 .707 r
F P
0 g
s
.81753 .73239 m .81874 .71332 L .79483 .71424 L p .707 .577 .707 r
F P
0 g
s
.65362 .64552 m .65548 .5889 L .64285 .58292 L p .707 .577 .707 r
F P
0 g
s
.67398 .72501 m .67518 .70594 L .65405 .7019 L p .707 .577 .707 r
F P
0 g
s
.65405 .7019 m .65285 .72097 L .67398 .72501 L p .707 .577 .707 r
F P
0 g
s
.81955 .6651 m .81661 .70333 L .83273 .70239 L p .707 .577 .707 r
F P
0 g
s
.83273 .70239 m .83567 .66415 L .81955 .6651 L p .707 .577 .707 r
F P
0 g
s
.64285 .58292 m .641 .63954 L .65362 .64552 L p .707 .577 .707 r
F P
0 g
s
.65206 .69 m .655 .65176 L .64223 .64848 L p .707 .577 .707 r
F P
0 g
s
.83669 .59145 m .83483 .64807 L .84187 .64237 L p .707 .577 .707 r
F P
0 g
s
.84187 .64237 m .84373 .58575 L .83669 .59145 L p .707 .577 .707 r
F P
0 g
s
.81874 .71332 m .81753 .73239 L .83373 .73027 L p .707 .577 .707 r
F P
0 g
s
.83373 .73027 m .83494 .7112 L .81874 .71332 L p .707 .577 .707 r
F P
0 g
s
.65285 .72097 m .65405 .7019 L .64134 .69777 L p .707 .577 .707 r
F P
0 g
s
.641 .63954 m .64285 .58292 L .63992 .57679 L p .707 .577 .707 r
F P
0 g
s
.64134 .69777 m .64013 .71684 L .65285 .72097 L p .707 .577 .707 r
F P
0 g
s
.83567 .66415 m .83273 .70239 L .83957 .70045 L p .707 .577 .707 r
F P
0 g
s
.83957 .70045 m .8425 .66221 L .83567 .66415 L p .707 .577 .707 r
F P
0 g
s
.63992 .57679 m .63806 .6334 L .641 .63954 L p .707 .577 .707 r
F P
0 g
s
.63929 .68671 m .64223 .64848 L .63911 .64573 L p .707 .577 .707 r
F P
0 g
s
.83494 .7112 m .83373 .73027 L .84065 .72715 L p .707 .577 .707 r
F P
0 g
s
.84065 .72715 m .84185 .70808 L .83494 .7112 L p .707 .577 .707 r
F P
0 g
s
.84373 .58575 m .84187 .64237 L .83893 .63623 L p .707 .577 .707 r
F P
0 g
s
.83893 .63623 m .84079 .57961 L .84373 .58575 L p .707 .577 .707 r
F P
0 g
s
.63911 .64573 m .63617 .68396 L .63929 .68671 L p .707 .577 .707 r
F P
0 g
s
.64013 .71684 m .64134 .69777 L .63829 .69396 L p .707 .577 .707 r
F P
0 g
s
.63829 .69396 m .63709 .71303 L .64013 .71684 L p .707 .577 .707 r
F P
0 g
s
.63806 .6334 m .63992 .57679 L .64696 .57109 L p .707 .577 .707 r
F P
0 g
s
.8425 .66221 m .83957 .70045 L .83644 .6977 L p .707 .577 .707 r
F P
0 g
s
.83644 .6977 m .83938 .65946 L .8425 .66221 L p .707 .577 .707 r
F P
0 g
s
.64696 .57109 m .6451 .6277 L .63806 .6334 L p .707 .577 .707 r
F P
0 g
s
.63617 .68396 m .63911 .64573 L .64594 .64379 L p .707 .577 .707 r
F P
0 g
s
.84185 .70808 m .84065 .72715 L .8376 .72334 L p .707 .577 .707 r
F P
0 g
s
.8376 .72334 m .8388 .70427 L .84185 .70808 L p .707 .577 .707 r
F P
0 g
s
.84079 .57961 m .83893 .63623 L .82631 .63025 L p .707 .577 .707 r
F P
0 g
s
.82631 .63025 m .82817 .57363 L .84079 .57961 L p .707 .577 .707 r
F P
0 g
s
.64594 .64379 m .643 .68202 L .63617 .68396 L p .707 .577 .707 r
F P
0 g
s
.39032 .62023 m .39217 .56361 L .36101 .56129 L p .707 .577 .707 r
F P
0 g
s
.39217 .56361 m .39032 .62023 L .42213 .62067 L p .707 .577 .707 r
F P
0 g
s
.42213 .62067 m .42399 .56406 L .39217 .56361 L p .707 .577 .707 r
F P
0 g
s
.63709 .71303 m .63829 .69396 L .64521 .69083 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42399 .56406 m .42213 .62067 L .45148 .6192 L p .707 .577 .707 r
F P
0 g
s
.45148 .6192 m .45334 .56258 L .42399 .56406 L p .707 .577 .707 r
F P
0 g
s
.64521 .69083 m .644 .70991 L .63709 .71303 L p .707 .577 .707 r
F P
0 g
s
.6451 .6277 m .64696 .57109 L .66328 .56638 L p .707 .577 .707 r
F P
0 g
s
.35915 .6179 m .36101 .56129 L .33354 .55731 L p .707 .577 .707 r
F P
0 g
s
.36101 .56129 m .35915 .6179 L .39032 .62023 L p .707 .577 .707 r
F P
0 g
s
.83938 .65946 m .83644 .6977 L .82367 .69441 L p .707 .577 .707 r
F P
0 g
s
.82367 .69441 m .82661 .65618 L .83938 .65946 L p .707 .577 .707 r
F P
0 g
s
.66328 .56638 m .66142 .623 L .6451 .6277 L p .707 .577 .707 r
F P
0 g
s
.45334 .56258 m .45148 .6192 L .4755 .61596 L p .707 .577 .707 r
F P
0 g
s
.4755 .61596 m .47735 .55934 L .45334 .56258 L p .707 .577 .707 r
F P
0 g
s
.38885 .66298 m .39179 .62474 L .36066 .62182 L p .707 .577 .707 r
F P
0 g
s
.39179 .62474 m .38885 .66298 L .42057 .66515 L p .707 .577 .707 r
F P
0 g
s
.42057 .66515 m .42351 .62692 L .39179 .62474 L p .707 .577 .707 r
F P
0 g
s
.33354 .55731 m .33169 .61393 L .35915 .6179 L p .707 .577 .707 r
F P
0 g
s
.36066 .62182 m .35772 .66006 L .38885 .66298 L p .707 .577 .707 r
F P
0 g
s
.44978 .66637 m .45272 .62814 L .42351 .62692 L p .707 .577 .707 r
F P
0 g
s
.82817 .57363 m .82631 .63025 L .80523 .62502 L p .707 .577 .707 r
F P
0 g
s
.80523 .62502 m .80709 .56841 L .82817 .57363 L p .707 .577 .707 r
F P
0 g
s
.643 .68202 m .64594 .64379 L .66206 .64284 L p .707 .577 .707 r
F P
0 g
s
.33169 .61393 m .33354 .55731 L .31247 .55209 L p .707 .577 .707 r
F P
0 g
s
.35772 .66006 m .36066 .62182 L .33316 .61845 L p .707 .577 .707 r
F P
0 g
s
.8388 .70427 m .8376 .72334 L .82489 .71921 L p .707 .577 .707 r
F P
0 g
s
.82489 .71921 m .82609 .70014 L .8388 .70427 L p .707 .577 .707 r
F P
0 g
s
.66206 .64284 m .65912 .68108 L .643 .68202 L p .707 .577 .707 r
F P
0 g
s
.33316 .61845 m .33022 .65668 L .35772 .66006 L p .707 .577 .707 r
F P
0 g
s
.3896 .69449 m .3908 .67542 L .35966 .67269 L p .707 .577 .707 r
F P
0 g
s
.3908 .67542 m .3896 .69449 L .42136 .69612 L p .707 .577 .707 r
F P
0 g
s
.42136 .69612 m .42256 .67705 L .3908 .67542 L p .707 .577 .707 r
F P
0 g
s
.35966 .67269 m .35845 .69176 L .3896 .69449 L p .707 .577 .707 r
F P
0 g
s
.42256 .67705 m .42136 .69612 L .45062 .6965 L p .707 .577 .707 r
F P
0 g
s
.45062 .6965 m .45182 .67743 L .42256 .67705 L p .707 .577 .707 r
F P
0 g
s
.66142 .623 m .66328 .56638 L .68729 .56314 L p .707 .577 .707 r
F P
0 g
s
.45272 .62814 m .44978 .66637 L .4736 .66652 L p .707 .577 .707 r
F P
0 g
s
.4736 .66652 m .47654 .62828 L .45272 .62814 L p .707 .577 .707 r
F P
0 g
s
.644 .70991 m .64521 .69083 L .66141 .68871 L p .707 .577 .707 r
F P
0 g
s
.31247 .55209 m .31061 .6087 L .33169 .61393 L p .707 .577 .707 r
F P
0 g
s
.35845 .69176 m .35966 .67269 L .33217 .66913 L p .707 .577 .707 r
F P
0 g
s
.66141 .68871 m .6602 .70778 L .644 .70991 L p .707 .577 .707 r
F P
0 g
s
.33217 .66913 m .33097 .6882 L .35845 .69176 L p .707 .577 .707 r
F P
0 g
s
.47735 .55934 m .4755 .61596 L .49182 .61125 L p .707 .577 .707 r
F P
0 g
s
.49182 .61125 m .49368 .55463 L .47735 .55934 L p .707 .577 .707 r
F P
0 g
s
.33022 .65668 m .33316 .61845 L .31199 .61495 L p .707 .577 .707 r
F P
0 g
s
.82661 .65618 m .82367 .69441 L .8025 .69091 L p .707 .577 .707 r
F P
0 g
s
.8025 .69091 m .80544 .65268 L .82661 .65618 L p .707 .577 .707 r
F P
0 g
s
.31199 .61495 m .30905 .65318 L .33022 .65668 L p .707 .577 .707 r
F P
0 g
s
.68729 .56314 m .68544 .61975 L .66142 .623 L p .707 .577 .707 r
F P
0 g
s
.45182 .67743 m .45062 .6965 L .47452 .69558 L p .707 .577 .707 r
F P
0 g
s
.47452 .69558 m .47573 .67651 L .45182 .67743 L p .707 .577 .707 r
F P
0 g
s
.80709 .56841 m .80523 .62502 L .77777 .62105 L p .707 .577 .707 r
F P
0 g
s
.77777 .62105 m .77963 .56443 L .80709 .56841 L p .707 .577 .707 r
F P
0 g
s
.31061 .6087 m .31247 .55209 L .29984 .54611 L p .707 .577 .707 r
F P
0 g
s
.65912 .68108 m .66206 .64284 L .68588 .64299 L p .707 .577 .707 r
F P
0 g
s
.33097 .6882 m .33217 .66913 L .31104 .66508 L p .707 .577 .707 r
F P
0 g
s
.82609 .70014 m .82489 .71921 L .80375 .71516 L p .707 .577 .707 r
F P
0 g
s
.80375 .71516 m .80496 .69609 L .82609 .70014 L p .707 .577 .707 r
F P
0 g
s
.31104 .66508 m .30984 .68415 L .33097 .6882 L p .707 .577 .707 r
F P
0 g
s
.68544 .61975 m .68729 .56314 L .71664 .56166 L p .707 .577 .707 r
F P
0 g
s
.68588 .64299 m .68295 .68122 L .65912 .68108 L p .707 .577 .707 r
F P
0 g
s
.47654 .62828 m .4736 .66652 L .48972 .66557 L p .707 .577 .707 r
F P
0 g
s
.48972 .66557 m .49266 .62734 L .47654 .62828 L p .707 .577 .707 r
F P
0 g
s
.29984 .54611 m .29799 .60273 L .31061 .6087 L p .707 .577 .707 r
F P
0 g
s
.6602 .70778 m .66141 .68871 L .68531 .68779 L p .707 .577 .707 r
F P
0 g
s
.77963 .56443 m .77777 .62105 L .7466 .61873 L p .707 .577 .707 r
F P
0 g
s
.7466 .61873 m .74846 .56211 L .77963 .56443 L p .707 .577 .707 r
F P
0 g
s
.30905 .65318 m .31199 .61495 L .29922 .61166 L p .707 .577 .707 r
F P
0 g
s
.68531 .68779 m .6841 .70686 L .6602 .70778 L p .707 .577 .707 r
F P
0 g
s
.71664 .56166 m .71479 .61828 L .68544 .61975 L p .707 .577 .707 r
F P
0 g
s
.49368 .55463 m .49182 .61125 L .49886 .60555 L p .707 .577 .707 r
F P
0 g
s
.49886 .60555 m .50072 .54893 L .49368 .55463 L p .707 .577 .707 r
F P
0 g
s
.80544 .65268 m .8025 .69091 L .775 .68754 L p .707 .577 .707 r
F P
0 g
s
.775 .68754 m .77794 .6493 L .80544 .65268 L p .707 .577 .707 r
F P
0 g
s
.47573 .67651 m .47452 .69558 L .49072 .69345 L p .707 .577 .707 r
F P
0 g
s
.49072 .69345 m .49193 .67438 L .47573 .67651 L p .707 .577 .707 r
F P
0 g
s
.71479 .61828 m .71664 .56166 L .74846 .56211 L p .707 .577 .707 r
F P
0 g
s
.29922 .61166 m .29628 .6499 L .30905 .65318 L p .707 .577 .707 r
F P
0 g
s
.74846 .56211 m .7466 .61873 L .71479 .61828 L p .707 .577 .707 r
F P
0 g
s
.68295 .68122 m .68588 .64299 L .71509 .64421 L p .707 .577 .707 r
F P
0 g
s
.30984 .68415 m .31104 .66508 L .29833 .66095 L p .707 .577 .707 r
F P
0 g
s
.71509 .64421 m .71215 .68244 L .68295 .68122 L p .707 .577 .707 r
F P
0 g
s
.29799 .60273 m .29984 .54611 L .29691 .53997 L p .707 .577 .707 r
F P
0 g
s
.80496 .69609 m .80375 .71516 L .77627 .7116 L p .707 .577 .707 r
F P
0 g
s
.77627 .7116 m .77747 .69253 L .80496 .69609 L p .707 .577 .707 r
F P
0 g
s
.29833 .66095 m .29712 .68002 L .30984 .68415 L p .707 .577 .707 r
F P
0 g
s
.77794 .6493 m .775 .68754 L .74387 .68462 L p .707 .577 .707 r
F P
0 g
s
.74387 .68462 m .74681 .64638 L .77794 .6493 L p .707 .577 .707 r
F P
0 g
s
.49266 .62734 m .48972 .66557 L .49656 .66363 L p .707 .577 .707 r
F P
0 g
s
.49656 .66363 m .49949 .6254 L .49266 .62734 L p .707 .577 .707 r
F P
0 g
s
.6841 .70686 m .68531 .68779 L .71457 .68817 L p .707 .577 .707 r
F P
0 g
s
.71215 .68244 m .71509 .64421 L .74681 .64638 L p .707 .577 .707 r
F P
0 g
s
.71457 .68817 m .71337 .70724 L .6841 .70686 L p .707 .577 .707 r
F P
0 g
s
.29691 .53997 m .29505 .59659 L .29799 .60273 L p .707 .577 .707 r
F P
0 g
s
.74681 .64638 m .74387 .68462 L .71215 .68244 L p .707 .577 .707 r
F P
0 g
s
.29628 .6499 m .29922 .61166 L .2961 .60891 L p .707 .577 .707 r
F P
0 g
s
.77747 .69253 m .77627 .7116 L .74512 .70887 L p .707 .577 .707 r
F P
0 g
s
.74512 .70887 m .74633 .6898 L .77747 .69253 L p .707 .577 .707 r
F P
0 g
s
.49193 .67438 m .49072 .69345 L .49764 .69033 L p .707 .577 .707 r
F P
0 g
s
.49764 .69033 m .49884 .67126 L .49193 .67438 L p .707 .577 .707 r
F P
0 g
s
.50072 .54893 m .49886 .60555 L .49592 .59941 L p .707 .577 .707 r
F P
0 g
s
.49592 .59941 m .49778 .5428 L .50072 .54893 L p .707 .577 .707 r
F P
0 g
s
.2961 .60891 m .29316 .64715 L .29628 .6499 L p .707 .577 .707 r
F P
0 g
s
.71337 .70724 m .71457 .68817 L .74633 .6898 L p .707 .577 .707 r
F P
0 g
s
.74633 .6898 m .74512 .70887 L .71337 .70724 L p .707 .577 .707 r
F P
0 g
s
.29712 .68002 m .29833 .66095 L .29528 .65714 L p .707 .577 .707 r
F P
0 g
s
.29528 .65714 m .29407 .67621 L .29712 .68002 L p .707 .577 .707 r
F P
0 g
s
.29505 .59659 m .29691 .53997 L .30394 .53427 L p .707 .577 .707 r
F P
0 g
s
.49949 .6254 m .49656 .66363 L .49343 .66088 L p .707 .577 .707 r
F P
0 g
s
.49343 .66088 m .49637 .62265 L .49949 .6254 L p .707 .577 .707 r
F P
0 g
s
.30394 .53427 m .30209 .59089 L .29505 .59659 L p .707 .577 .707 r
F P
0 g
s
.29316 .64715 m .2961 .60891 L .30293 .60697 L p .707 .577 .707 r
F P
0 g
s
.49884 .67126 m .49764 .69033 L .49459 .68652 L p .707 .577 .707 r
F P
0 g
s
.49459 .68652 m .49579 .66745 L .49884 .67126 L p .707 .577 .707 r
F P
0 g
s
.49778 .5428 m .49592 .59941 L .4833 .59344 L p .707 .577 .707 r
F P
0 g
s
.4833 .59344 m .48516 .53682 L .49778 .5428 L p .707 .577 .707 r
F P
0 g
s
.30293 .60697 m .29999 .64521 L .29316 .64715 L p .707 .577 .707 r
F P
0 g
s
.29407 .67621 m .29528 .65714 L .30219 .65402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30219 .65402 m .30099 .67309 L .29407 .67621 L p .707 .577 .707 r
F P
0 g
s
.30209 .59089 m .30394 .53427 L .32027 .52957 L p .707 .577 .707 r
F P
0 g
s
.49637 .62265 m .49343 .66088 L .48066 .6576 L p .707 .577 .707 r
F P
0 g
s
.48066 .6576 m .4836 .61936 L .49637 .62265 L p .707 .577 .707 r
F P
0 g
s
.32027 .52957 m .31841 .58619 L .30209 .59089 L p .707 .577 .707 r
F P
0 g
s
.48516 .53682 m .4833 .59344 L .46222 .58821 L p .707 .577 .707 r
F P
0 g
s
.46222 .58821 m .46408 .53159 L .48516 .53682 L p .707 .577 .707 r
F P
0 g
s
.29999 .64521 m .30293 .60697 L .31905 .60603 L p .707 .577 .707 r
F P
0 g
s
.49579 .66745 m .49459 .68652 L .48188 .68239 L p .707 .577 .707 r
F P
0 g
s
.48188 .68239 m .48308 .66332 L .49579 .66745 L p .707 .577 .707 r
F P
0 g
s
.31905 .60603 m .31611 .64426 L .29999 .64521 L p .707 .577 .707 r
F P
0 g
s
.31841 .58619 m .32027 .52957 L .34428 .52632 L p .707 .577 .707 r
F P
0 g
s
.30099 .67309 m .30219 .65402 L .3184 .6519 L p .707 .577 .707 r
F P
0 g
s
.3184 .6519 m .31719 .67097 L .30099 .67309 L p .707 .577 .707 r
F P
0 g
s
.4836 .61936 m .48066 .6576 L .45949 .65409 L p .707 .577 .707 r
F P
0 g
s
.45949 .65409 m .46243 .61586 L .4836 .61936 L p .707 .577 .707 r
F P
0 g
s
.34428 .52632 m .34243 .58294 L .31841 .58619 L p .707 .577 .707 r
F P
0 g
s
.46408 .53159 m .46222 .58821 L .43476 .58424 L p .707 .577 .707 r
F P
0 g
s
.43476 .58424 m .43661 .52762 L .46408 .53159 L p .707 .577 .707 r
F P
0 g
s
.31611 .64426 m .31905 .60603 L .34287 .60617 L p .707 .577 .707 r
F P
0 g
s
.48308 .66332 m .48188 .68239 L .46074 .67835 L p .707 .577 .707 r
F P
0 g
s
.46074 .67835 m .46195 .65928 L .48308 .66332 L p .707 .577 .707 r
F P
0 g
s
.34243 .58294 m .34428 .52632 L .37363 .52485 L p .707 .577 .707 r
F P
0 g
s
.34287 .60617 m .33994 .64441 L .31611 .64426 L p .707 .577 .707 r
F P
0 g
s
.31719 .67097 m .3184 .6519 L .3423 .65098 L p .707 .577 .707 r
F P
0 g
s
.43661 .52762 m .43476 .58424 L .40359 .58192 L p .707 .577 .707 r
F P
0 g
s
.40359 .58192 m .40545 .5253 L .43661 .52762 L p .707 .577 .707 r
F P
0 g
s
.3423 .65098 m .34109 .67005 L .31719 .67097 L p .707 .577 .707 r
F P
0 g
s
.37363 .52485 m .37178 .58147 L .34243 .58294 L p .707 .577 .707 r
F P
0 g
s
.46243 .61586 m .45949 .65409 L .43199 .65072 L p .707 .577 .707 r
F P
0 g
s
.43199 .65072 m .43493 .61249 L .46243 .61586 L p .707 .577 .707 r
F P
0 g
s
.37178 .58147 m .37363 .52485 L .40545 .5253 L p .707 .577 .707 r
F P
0 g
s
.40545 .5253 m .40359 .58192 L .37178 .58147 L p .707 .577 .707 r
F P
0 g
s
.33994 .64441 m .34287 .60617 L .37208 .60739 L p .707 .577 .707 r
F P
0 g
s
.37208 .60739 m .36914 .64563 L .33994 .64441 L p .707 .577 .707 r
F P
0 g
s
.46195 .65928 m .46074 .67835 L .43326 .67479 L p .707 .577 .707 r
F P
0 g
s
.43326 .67479 m .43446 .65572 L .46195 .65928 L p .707 .577 .707 r
F P
0 g
s
.43493 .61249 m .43199 .65072 L .40086 .6478 L p .707 .577 .707 r
F P
0 g
s
.40086 .6478 m .4038 .60957 L .43493 .61249 L p .707 .577 .707 r
F P
0 g
s
.34109 .67005 m .3423 .65098 L .37156 .65135 L p .707 .577 .707 r
F P
0 g
s
.36914 .64563 m .37208 .60739 L .4038 .60957 L p .707 .577 .707 r
F P
0 g
s
.37156 .65135 m .37035 .67042 L .34109 .67005 L p .707 .577 .707 r
F P
0 g
s
.4038 .60957 m .40086 .6478 L .36914 .64563 L p .707 .577 .707 r
F P
0 g
s
.43446 .65572 m .43326 .67479 L .40211 .67205 L p .707 .577 .707 r
F P
0 g
s
.40211 .67205 m .40332 .65298 L .43446 .65572 L p .707 .577 .707 r
F P
0 g
s
.37035 .67042 m .37156 .65135 L .40332 .65298 L p .707 .577 .707 r
F P
0 g
s
.40332 .65298 m .40211 .67205 L .37035 .67042 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaH008Io
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH015YF3000NWoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^
Ool006aoo`<000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH00000JGoo001WOol00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000J7oo001VOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Io
o`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo6@0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001IOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000@OolA0014
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool80003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool60003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Woo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000`Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00Dgoo00<005YF0000
15YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000eYF1P001eYF00<005YFFUH01UYF00<005YF
FUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool005=oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH70003FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002eoo`00>7oo
7@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
<Woo1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF6P0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02moo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF00AJEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00
0006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH:0008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPL00003FUH005YF00IJEP03001JEUYF00IJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00000UYF1P0025YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00
15YF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@0009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000QJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00005`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHC0007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000IJEP03001JEUYF00<002moo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF:P0015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPX0039oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH0
1000FUIJEUYF7@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPl000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000/Ool00`00
FUH00002FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH01000FUH005YF10001EYF00@005YFFUIJEPT000=JEQ4000=JEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0004FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF010000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000_Ool40004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30002FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003=o
o`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00H000=JEP03001JEUYF00IJEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00
00005P001eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000fOol50004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF3@0015YF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF5`000eYF00<005YFFUH00P00;Woo000kOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH70009Ool00`00FUIJEP0C0004FUH01000FUIJEUYF2@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF0000000300000eYF0000000^Ool002eo
obT0011oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0800000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008000=JEP<002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF4@003Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`001goo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUHQ
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@000goo200015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH400000eYF0000000@0003FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000UYF00<007ooOol0;7oo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00FUH005YF1`0015YF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF5`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001@005goo5P00<Woo000/OolJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUHA0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1eYF7P0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000006=oo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF1P00GGoo000c
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH80002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP05001HOol003Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH40002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUH00002001EOol004=ooa4000AJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03001JEUYF009JEP03001J
EUYF00=JEP04001JEUYFFUH2001DOol005Aooa<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH00000
1UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00D005YFFUH005YF
008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
E7oo001VOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000aOolF000OOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA000>Ool20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH00P00
EGoo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJ
EP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00=JEP03001J
EUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000Woo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH020000eYF00<005YFFUH00P00EGoo000/Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
0002FUH00`00FUIJEP03FUH500000eYF0000001EOol002aoo`03001JEP00024000AJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00AJEP04001JEUYFFUH3001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000=oo`P000=JEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUHB001FOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P00Igoo000^Ool200000eYF001JEP04FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH20003Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo000`Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF10001Goo0P001UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000
06]oo`00=7oo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF00001goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@00K7oo000kOolA0004FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP04000:Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0400000eYF001JEP02FUH8001TOol004aooaH0015o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00EJ
EP04001JEUYFFUH7001MOol007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP04001JEUYF
FUH70008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05001HOol007eoob0000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00SWoo00<005YF00000UYF5@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00SWoo00<005YF00000P001EYF00@005YFFUIJEPT000=ooa4000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQX000AJEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP03001oogoo05=oo`00T7oo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<007ooOol0Dgoo002EOol7
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00EGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Eoo`00YGoo4@0015YF00@005YFFUIJEPT005Ioo`00]Woo2000Ggoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59626 .72343 m .59925 .66638 L .5681 .6638 L p .707 .577 .707 r
F P
0 g
s
.59925 .66638 m .59626 .72343 L .62804 .72464 L p .707 .577 .707 r
F P
0 g
s
.62804 .72464 m .63104 .6676 L .59925 .66638 L p .707 .577 .707 r
F P
0 g
s
.63104 .6676 m .62804 .72464 L .65734 .72437 L p .707 .577 .707 r
F P
0 g
s
.65734 .72437 m .66034 .66732 L .63104 .6676 L p .707 .577 .707 r
F P
0 g
s
.5651 .72084 m .5681 .6638 L .54062 .66009 L p .707 .577 .707 r
F P
0 g
s
.5681 .6638 m .5651 .72084 L .59626 .72343 L p .707 .577 .707 r
F P
0 g
s
.54062 .66009 m .53763 .71714 L .5651 .72084 L p .707 .577 .707 r
F P
0 g
s
.66034 .66732 m .65734 .72437 L .68129 .72262 L p .707 .577 .707 r
F P
0 g
s
.68129 .72262 m .68429 .66558 L .66034 .66732 L p .707 .577 .707 r
F P
0 g
s
.56817 .73638 m .56347 .77452 L .59454 .77808 L p .707 .577 .707 r
F P
0 g
s
.59454 .77808 m .59924 .73993 L .56817 .73638 L p .707 .577 .707 r
F P
0 g
s
.59924 .73993 m .59454 .77808 L .62608 .7821 L p .707 .577 .707 r
F P
0 g
s
.62608 .7821 m .63077 .74395 L .59924 .73993 L p .707 .577 .707 r
F P
0 g
s
.63077 .74395 m .62608 .7821 L .65499 .7862 L p .707 .577 .707 r
F P
0 g
s
.53763 .71714 m .54062 .66009 L .51952 .65563 L p .707 .577 .707 r
F P
0 g
s
.65499 .7862 m .65969 .74805 L .63077 .74395 L p .707 .577 .707 r
F P
0 g
s
.54061 .73364 m .53591 .77178 L .56347 .77452 L p .707 .577 .707 r
F P
0 g
s
.56347 .77452 m .56817 .73638 L .54061 .73364 L p .707 .577 .707 r
F P
0 g
s
.51952 .65563 m .51652 .71267 L .53763 .71714 L p .707 .577 .707 r
F P
0 g
s
.65969 .74805 m .65499 .7862 L .67846 .78996 L p .707 .577 .707 r
F P
0 g
s
.67846 .78996 m .68315 .75182 L .65969 .74805 L p .707 .577 .707 r
F P
0 g
s
.68429 .66558 m .68129 .72262 L .69754 .71959 L p .707 .577 .707 r
F P
0 g
s
.69754 .71959 m .70054 .66254 L .68429 .66558 L p .707 .577 .707 r
F P
0 g
s
.59548 .84732 m .59741 .82819 L .56631 .82493 L p .707 .577 .707 r
F P
0 g
s
.59741 .82819 m .59548 .84732 L .62711 .85046 L p .707 .577 .707 r
F P
0 g
s
.62711 .85046 m .62905 .83133 L .59741 .82819 L p .707 .577 .707 r
F P
0 g
s
.56631 .82493 m .56438 .84407 L .59548 .84732 L p .707 .577 .707 r
F P
0 g
s
.51925 .73198 m .51455 .77013 L .53591 .77178 L p .707 .577 .707 r
F P
0 g
s
.53591 .77178 m .54061 .73364 L .51925 .73198 L p .707 .577 .707 r
F P
0 g
s
.62905 .83133 m .62711 .85046 L .65618 .85319 L p .707 .577 .707 r
F P
0 g
s
.65618 .85319 m .65812 .83406 L .62905 .83133 L p .707 .577 .707 r
F P
0 g
s
.51652 .71267 m .51952 .65563 L .50684 .65084 L p .707 .577 .707 r
F P
0 g
s
.56438 .84407 m .56631 .82493 L .53878 .82189 L p .707 .577 .707 r
F P
0 g
s
.53878 .82189 m .53685 .84103 L .56438 .84407 L p .707 .577 .707 r
F P
0 g
s
.50684 .65084 m .50384 .70789 L .51652 .71267 L p .707 .577 .707 r
F P
0 g
s
.68315 .75182 m .67846 .78996 L .69417 .79304 L p .707 .577 .707 r
F P
0 g
s
.65812 .83406 m .65618 .85319 L .67984 .85524 L p .707 .577 .707 r
F P
0 g
s
.67984 .85524 m .68177 .83611 L .65812 .83406 L p .707 .577 .707 r
F P
0 g
s
.69417 .79304 m .69887 .75489 L .68315 .75182 L p .707 .577 .707 r
F P
0 g
s
.53685 .84103 m .53878 .82189 L .51753 .81936 L p .707 .577 .707 r
F P
0 g
s
.51753 .81936 m .51559 .83849 L .53685 .84103 L p .707 .577 .707 r
F P
0 g
s
.70054 .66254 m .69754 .71959 L .70451 .71556 L p .707 .577 .707 r
F P
0 g
s
.70451 .71556 m .70751 .65851 L .70054 .66254 L p .707 .577 .707 r
F P
0 g
s
.50619 .73158 m .5015 .76972 L .51455 .77013 L p .707 .577 .707 r
F P
0 g
s
.51455 .77013 m .51925 .73198 L .50619 .73158 L p .707 .577 .707 r
F P
0 g
s
.50384 .70789 m .50684 .65084 L .50384 .64621 L p .707 .577 .707 r
F P
0 g
s
.68177 .83611 m .67984 .85524 L .69577 .8564 L p .707 .577 .707 r
F P
0 g
s
.69577 .8564 m .6977 .83727 L .68177 .83611 L p .707 .577 .707 r
F P
0 g
s
.50384 .64621 m .50084 .70326 L .50384 .70789 L p .707 .577 .707 r
F P
0 g
s
.69887 .75489 m .69417 .79304 L .7006 .79512 L p .707 .577 .707 r
F P
0 g
s
.7006 .79512 m .7053 .75697 L .69887 .75489 L p .707 .577 .707 r
F P
0 g
s
.51559 .83849 m .51753 .81936 L .50462 .81759 L p .707 .577 .707 r
F P
0 g
s
.50462 .81759 m .50268 .83672 L .51559 .83849 L p .707 .577 .707 r
F P
0 g
s
.50271 .73245 m .49801 .7706 L .5015 .76972 L p .707 .577 .707 r
F P
0 g
s
.5015 .76972 m .50619 .73158 L .50271 .73245 L p .707 .577 .707 r
F P
0 g
s
.70751 .65851 m .70451 .71556 L .70151 .71092 L p .707 .577 .707 r
F P
0 g
s
.70151 .71092 m .70451 .65388 L .70751 .65851 L p .707 .577 .707 r
F P
0 g
s
.49654 .82253 m .48928 .32586 L .44527 .32343 L p .707 .577 .707 r
F P
0 g
s
.50084 .70326 m .50384 .64621 L .51081 .64218 L p .707 .577 .707 r
F P
0 g
s
.51081 .64218 m .50781 .69922 L .50084 .70326 L p .707 .577 .707 r
F P
0 g
s
.50268 .83672 m .50462 .81759 L .50133 .81674 L p .707 .577 .707 r
F P
0 g
s
.50133 .81674 m .49939 .83587 L .50268 .83672 L p .707 .577 .707 r
F P
0 g
s
.50914 .73453 m .50444 .77267 L .49801 .7706 L p .707 .577 .707 r
F P
0 g
s
.49801 .7706 m .50271 .73245 L .50914 .73453 L p .707 .577 .707 r
F P
0 g
s
.50781 .69922 m .51081 .64218 L .52706 .63914 L p .707 .577 .707 r
F P
0 g
s
.52706 .63914 m .52406 .69619 L .50781 .69922 L p .707 .577 .707 r
F P
0 g
s
.49939 .83587 m .50133 .81674 L .50797 .81691 L p .707 .577 .707 r
F P
0 g
s
.50797 .81691 m .50604 .83604 L .49939 .83587 L p .707 .577 .707 r
F P
0 g
s
.52486 .7376 m .52016 .77575 L .50444 .77267 L p .707 .577 .707 r
F P
0 g
s
.50444 .77267 m .50914 .73453 L .52486 .7376 L p .707 .577 .707 r
F P
0 g
s
.52406 .69619 m .52706 .63914 L .55101 .6374 L p .707 .577 .707 r
F P
0 g
s
.55101 .6374 m .54801 .69445 L .52406 .69619 L p .707 .577 .707 r
F P
0 g
s
.50604 .83604 m .50797 .81691 L .5239 .81807 L p .707 .577 .707 r
F P
0 g
s
.5239 .81807 m .52197 .8372 L .50604 .83604 L p .707 .577 .707 r
F P
0 g
s
.54832 .74137 m .54362 .77952 L .52016 .77575 L p .707 .577 .707 r
F P
0 g
s
.52016 .77575 m .52486 .7376 L .54832 .74137 L p .707 .577 .707 r
F P
0 g
s
.52197 .8372 m .5239 .81807 L .54756 .82012 L p .707 .577 .707 r
F P
0 g
s
.48928 .32586 m .49654 .82253 L .54148 .82069 L p .707 .577 .707 r
F P
0 g
s
.54148 .82069 m .53422 .32403 L .48928 .32586 L p .707 .577 .707 r
F P
0 g
s
.54801 .69445 m .55101 .6374 L .58031 .63712 L p .707 .577 .707 r
F P
0 g
s
.58031 .63712 m .57731 .69417 L .54801 .69445 L p .707 .577 .707 r
F P
0 g
s
.57724 .74547 m .57254 .78362 L .54362 .77952 L p .707 .577 .707 r
F P
0 g
s
.54362 .77952 m .54832 .74137 L .57724 .74547 L p .707 .577 .707 r
F P
0 g
s
.60877 .74949 m .60407 .78764 L .57254 .78362 L p .707 .577 .707 r
F P
0 g
s
.57254 .78362 m .57724 .74547 L .60877 .74949 L p .707 .577 .707 r
F P
0 g
s
.53422 .32403 m .54148 .82069 L .58295 .81477 L p .707 .577 .707 r
F P
0 g
s
.57731 .69417 m .58031 .63712 L .61209 .63834 L p .707 .577 .707 r
F P
0 g
s
.61209 .63834 m .6091 .69538 L .57731 .69417 L p .707 .577 .707 r
F P
0 g
s
.58295 .81477 m .57569 .31811 L .53422 .32403 L p .707 .577 .707 r
F P
0 g
s
.6977 .83727 m .69577 .8564 L .70241 .85657 L p .707 .577 .707 r
F P
0 g
s
.70241 .85657 m .70435 .83744 L .6977 .83727 L p .707 .577 .707 r
F P
0 g
s
.45253 .8201 m .44527 .32343 L .40651 .31698 L p .707 .577 .707 r
F P
0 g
s
.44527 .32343 m .45253 .8201 L .49654 .82253 L p .707 .577 .707 r
F P
0 g
s
.7053 .75697 m .7006 .79512 L .69712 .79599 L p .707 .577 .707 r
F P
0 g
s
.69712 .79599 m .70182 .75785 L .7053 .75697 L p .707 .577 .707 r
F P
0 g
s
.63984 .75305 m .63514 .79119 L .61341 .78871 L p .707 .577 .707 r
F P
0 g
s
.61341 .78871 m .60407 .78764 L p .61413 .77791 L .707 .577 .707 r
F P
0 g
s
.61413 .77791 m .63984 .75305 L .61341 .78871 L .707 .577 .707 r
F
.67072 .64463 m .66773 .70168 L .64025 .69797 L p F P
0 g
s
.64025 .69797 m .64325 .64092 L .67072 .64463 L p .707 .577 .707 r
F P
0 g
s
.64325 .64092 m .64025 .69797 L .6091 .69538 L p .707 .577 .707 r
F P
0 g
s
.6091 .69538 m .61209 .63834 L .64325 .64092 L p .707 .577 .707 r
F P
0 g
s
.6674 .75579 m .6627 .79393 L .63514 .79119 L p .707 .577 .707 r
F P
0 g
s
.63514 .79119 m .63984 .75305 L .6674 .75579 L p .707 .577 .707 r
F P
0 g
s
.60407 .78764 m .60877 .74949 L .63984 .75305 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .64998 .77993 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63273 .29668 m .63517 .46314 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63517 .46314 m .63999 .79335 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.57569 .31811 m .58295 .81477 L .6169 .80535 L p .707 .577 .707 r
F P
0 g
s
.6169 .80535 m .60964 .30869 L .57569 .31811 L p .707 .577 .707 r
F P
0 g
s
.70451 .65388 m .70151 .71092 L .68883 .70614 L p .707 .577 .707 r
F P
0 g
s
.68883 .70614 m .69183 .64909 L .70451 .65388 L p .707 .577 .707 r
F P
0 g
s
.41377 .81364 m .40651 .31698 L .37677 .30713 L p .707 .577 .707 r
F P
0 g
s
.40651 .31698 m .41377 .81364 L .45253 .8201 L p .707 .577 .707 r
F P
0 g
s
.25325 .68661 m .25625 .62957 L .22509 .62698 L p .707 .577 .707 r
F P
0 g
s
.25625 .62957 m .25325 .68661 L .28503 .68783 L p .707 .577 .707 r
F P
0 g
s
.28503 .68783 m .28803 .63078 L .25625 .62957 L p .707 .577 .707 r
F P
0 g
s
.28803 .63078 m .28503 .68783 L .31433 .68755 L p .707 .577 .707 r
F P
0 g
s
.31433 .68755 m .31733 .6305 L .28803 .63078 L p .707 .577 .707 r
F P
0 g
s
.70435 .83744 m .70241 .85657 L .69912 .85573 L p .707 .577 .707 r
F P
0 g
s
.69912 .85573 m .70106 .83659 L .70435 .83744 L p .707 .577 .707 r
F P
0 g
s
.22209 .68403 m .22509 .62698 L .19762 .62328 L p .707 .577 .707 r
F P
0 g
s
.22509 .62698 m .22209 .68403 L .25325 .68661 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19762 .62328 m .19462 .68032 L .22209 .68403 L p .707 .577 .707 r
F P
0 g
s
.70182 .75785 m .69712 .79599 L .68406 .79559 L p .707 .577 .707 r
F P
0 g
s
.31733 .6305 m .31433 .68755 L .33828 .68581 L p .707 .577 .707 r
F P
0 g
s
.33828 .68581 m .34128 .62876 L .31733 .6305 L p .707 .577 .707 r
F P
0 g
s
.60964 .30869 m .6169 .80535 L .63999 .79335 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .63273 .29668 L .60964 .30869 L p .707 .577 .707 r
F P
0 g
s
.68406 .79559 m .68876 .75744 L .70182 .75785 L p .707 .577 .707 r
F P
0 g
s
.22516 .69956 m .22046 .73771 L .25153 .74126 L p .707 .577 .707 r
F P
0 g
s
.25153 .74126 m .25623 .70312 L .22516 .69956 L p .707 .577 .707 r
F P
0 g
s
.25623 .70312 m .25153 .74126 L .28307 .74528 L p .707 .577 .707 r
F P
0 g
s
.28307 .74528 m .28777 .70714 L .25623 .70312 L p .707 .577 .707 r
F P
0 g
s
.28777 .70714 m .28307 .74528 L .31198 .74938 L p .707 .577 .707 r
F P
0 g
s
.19462 .68032 m .19762 .62328 L .17651 .61881 L p .707 .577 .707 r
F P
0 g
s
.69183 .64909 m .68883 .70614 L .66773 .70168 L p .707 .577 .707 r
F P
0 g
s
.66773 .70168 m .67072 .64463 L .69183 .64909 L p .707 .577 .707 r
F P
0 g
s
.31198 .74938 m .31668 .71123 L .28777 .70714 L p .707 .577 .707 r
F P
0 g
s
.1976 .69682 m .1929 .73497 L .22046 .73771 L p .707 .577 .707 r
F P
0 g
s
.22046 .73771 m .22516 .69956 L .1976 .69682 L p .707 .577 .707 r
F P
0 g
s
.17651 .61881 m .17351 .67586 L .19462 .68032 L p .707 .577 .707 r
F P
0 g
s
.38403 .80379 m .37677 .30713 L .35899 .29485 L p .707 .577 .707 r
F P
0 g
s
.37677 .30713 m .38403 .80379 L .41377 .81364 L p .707 .577 .707 r
F P
0 g
s
.31668 .71123 m .31198 .74938 L .33545 .75315 L p .707 .577 .707 r
F P
0 g
s
.70106 .83659 m .69912 .85573 L .68622 .85395 L p .707 .577 .707 r
F P
0 g
s
.68622 .85395 m .68815 .83482 L .70106 .83659 L p .707 .577 .707 r
F P
0 g
s
.33545 .75315 m .34015 .715 L .31668 .71123 L p .707 .577 .707 r
F P
0 g
s
.34128 .62876 m .33828 .68581 L .35453 .68277 L p .707 .577 .707 r
F P
0 g
s
.35453 .68277 m .35753 .62573 L .34128 .62876 L p .707 .577 .707 r
F P
0 g
s
.25247 .8105 m .2544 .79137 L .2233 .78812 L p .707 .577 .707 r
F P
0 g
s
.2544 .79137 m .25247 .8105 L .2841 .81365 L p .707 .577 .707 r
F P
0 g
s
.2841 .81365 m .28604 .79452 L .2544 .79137 L p .707 .577 .707 r
F P
0 g
s
.2233 .78812 m .22137 .80725 L .25247 .8105 L p .707 .577 .707 r
F P
0 g
s
.17624 .69517 m .17155 .73331 L .1929 .73497 L p .707 .577 .707 r
F P
0 g
s
.1929 .73497 m .1976 .69682 L .17624 .69517 L p .707 .577 .707 r
F P
0 g
s
.28604 .79452 m .2841 .81365 L .31317 .81638 L p .707 .577 .707 r
F P
0 g
s
.31317 .81638 m .31511 .79724 L .28604 .79452 L p .707 .577 .707 r
F P
0 g
s
.68876 .75744 m .68406 .79559 L .6627 .79393 L p .707 .577 .707 r
F P
0 g
s
.6627 .79393 m .6674 .75579 L .68876 .75744 L p .707 .577 .707 r
F P
0 g
s
.17351 .67586 m .17651 .61881 L .16383 .61403 L p .707 .577 .707 r
F P
0 g
s
.22137 .80725 m .2233 .78812 L .19577 .78508 L p .707 .577 .707 r
F P
0 g
s
.19577 .78508 m .19384 .80421 L .22137 .80725 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64272 .28327 L .63273 .29668 L p .707 .577 .707 r
F P
0 g
s
.16383 .61403 m .16083 .67108 L .17351 .67586 L p .707 .577 .707 r
F P
0 g
s
.34015 .715 m .33545 .75315 L .35116 .75622 L p .707 .577 .707 r
F P
0 g
s
.31511 .79724 m .31317 .81638 L .33683 .81842 L p .707 .577 .707 r
F P
0 g
s
.33683 .81842 m .33876 .79929 L .31511 .79724 L p .707 .577 .707 r
F P
0 g
s
.35116 .75622 m .35586 .71808 L .34015 .715 L p .707 .577 .707 r
F P
0 g
s
.19384 .80421 m .19577 .78508 L .17452 .78255 L p .707 .577 .707 r
F P
0 g
s
.17452 .78255 m .17258 .80168 L .19384 .80421 L p .707 .577 .707 r
F P
0 g
s
.35753 .62573 m .35453 .68277 L .3615 .67874 L p .707 .577 .707 r
F P
0 g
s
.3615 .67874 m .3645 .62169 L .35753 .62573 L p .707 .577 .707 r
F P
0 g
s
.16318 .69476 m .15849 .73291 L .17155 .73331 L p .707 .577 .707 r
F P
0 g
s
.17155 .73331 m .17624 .69517 L .16318 .69476 L p .707 .577 .707 r
F P
0 g
s
.68815 .83482 m .68622 .85395 L .66496 .85142 L p .707 .577 .707 r
F P
0 g
s
.66496 .85142 m .66689 .83228 L .68815 .83482 L p .707 .577 .707 r
F P
0 g
s
.3645 .62169 m .3615 .67874 L .3585 .67411 L p .707 .577 .707 r
F P
0 g
s
.3585 .67411 m .3615 .61706 L .3645 .62169 L p .707 .577 .707 r
F P
0 g
s
.36625 .79152 m .35899 .29485 L .35489 .28134 L p .707 .577 .707 r
F P
0 g
s
.35899 .29485 m .36625 .79152 L .38403 .80379 L p .707 .577 .707 r
F P
0 g
s
.54756 .82012 m .54563 .83925 L .52197 .8372 L p .707 .577 .707 r
F P
0 g
s
.16083 .67108 m .16383 .61403 L .16083 .6094 L p .707 .577 .707 r
F P
0 g
s
.33876 .79929 m .33683 .81842 L .35276 .81959 L p .707 .577 .707 r
F P
0 g
s
.35276 .81959 m .35469 .80046 L .33876 .79929 L p .707 .577 .707 r
F P
0 g
s
.16083 .6094 m .15783 .66644 L .16083 .67108 L p .707 .577 .707 r
F P
0 g
s
.35586 .71808 m .35116 .75622 L .35759 .7583 L p .707 .577 .707 r
F P
0 g
s
.35759 .7583 m .36229 .72016 L .35586 .71808 L p .707 .577 .707 r
F P
0 g
s
.17258 .80168 m .17452 .78255 L .16161 .78077 L p .707 .577 .707 r
F P
0 g
s
.16161 .78077 m .15968 .7999 L .17258 .80168 L p .707 .577 .707 r
F P
0 g
s
.66689 .83228 m .66496 .85142 L .63743 .84838 L p .707 .577 .707 r
F P
0 g
s
.63743 .84838 m .63937 .82924 L .66689 .83228 L p .707 .577 .707 r
F P
0 g
s
.1597 .69564 m .155 .73378 L .15849 .73291 L p .707 .577 .707 r
F P
0 g
s
.15849 .73291 m .16318 .69476 L .1597 .69564 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64769 .77239 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64272 .28327 m .64964 .75634 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64964 .75634 m .64998 .77993 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64564 .72985 m .64272 .28327 L .6476 .76343 L .707 .577 .707 r
F
.64655 .74877 m .6476 .76343 L .64769 .77239 L F
.64564 .72985 m .6476 .76343 L .64655 .74877 L F
.63862 .26976 m .64272 .28327 L p .6451 .64759 L F P
0 g
s
.64431 .64561 m .63862 .26976 L .6451 .64759 L .707 .577 .707 r
F
.64538 .73238 m .63862 .26976 L p .64569 .73662 L F P
0 g
s
.63862 .26976 m .64588 .76643 L .6281 .75415 L p .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64104 .5794 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64105 .64108 m .64121 .6379 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64404 .58403 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64569 .73662 m .64431 .64561 L .6451 .64759 L .707 .577 .707 r
F
.64588 .76643 m .64538 .73238 L p .64569 .73662 L F P
0 g
s
.64182 .68377 m .63989 .7029 L .64331 .70337 L p .707 .577 .707 r
F P
0 g
s
.64331 .70337 m .65279 .70468 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.64193 .68397 m .64182 .68377 L .64331 .70337 L .707 .577 .707 r
F
.65279 .70468 m .65473 .68554 L .64192 .68378 L p F P
0 g
s
.64192 .68378 m .64182 .68377 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.65279 .70468 m .64192 .68378 L .64193 .68397 L .707 .577 .707 r
F
.64137 .6412 m .65372 .64586 L p .64121 .6379 L F P
0 g
s
.6434 .64159 m .64149 .65704 L p .65176 .68014 L .707 .577 .707 r
F P
0 g
s
.64149 .65704 m .6387 .67973 L .64337 .67988 L p .707 .577 .707 r
F P
0 g
s
.64337 .67988 m .65176 .68014 L p .64149 .65704 L .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64121 .6379 L p .65372 .64586 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64105 .64108 L .64137 .6412 L p .707 .577 .707 r
F P
0 g
s
.64769 .77239 m .64588 .76643 L p .64564 .72985 L .707 .577 .707 r
F P
0 g
s
.54563 .83925 m .54756 .82012 L .57663 .82285 L p .707 .577 .707 r
F P
0 g
s
.57663 .82285 m .57469 .84198 L .54563 .83925 L p .707 .577 .707 r
F P
0 g
s
.63937 .82924 m .63743 .84838 L .60633 .84512 L p .707 .577 .707 r
F P
0 g
s
.60633 .84512 m .60826 .82599 L .63937 .82924 L p .707 .577 .707 r
F P
0 g
s
.35469 .80046 m .35276 .81959 L .3594 .81976 L p .707 .577 .707 r
F P
0 g
s
.3594 .81976 m .36134 .80062 L .35469 .80046 L p .707 .577 .707 r
F P
0 g
s
.15783 .66644 m .16083 .6094 L .1678 .60536 L p .707 .577 .707 r
F P
0 g
s
.57469 .84198 m .57663 .82285 L .60826 .82599 L p .707 .577 .707 r
F P
0 g
s
.60826 .82599 m .60633 .84512 L .57469 .84198 L p .707 .577 .707 r
F P
0 g
s
.36229 .72016 m .35759 .7583 L .35411 .75918 L p .707 .577 .707 r
F P
0 g
s
.35411 .75918 m .35881 .72103 L .36229 .72016 L p .707 .577 .707 r
F P
0 g
s
.3615 .61706 m .3585 .67411 L .34583 .66932 L p .707 .577 .707 r
F P
0 g
s
.34583 .66932 m .34882 .61228 L .3615 .61706 L p .707 .577 .707 r
F P
0 g
s
.35489 .28134 m .36215 .77801 L .36625 .79152 L p .707 .577 .707 r
F P
0 g
s
.36215 .77801 m .35489 .28134 L .36488 .26793 L p .707 .577 .707 r
F P
0 g
s
.1678 .60536 m .1648 .66241 L .15783 .66644 L p .707 .577 .707 r
F P
0 g
s
.15968 .7999 m .16161 .78077 L .15832 .77992 L p .707 .577 .707 r
F P
0 g
s
.15832 .77992 m .15638 .79906 L .15968 .7999 L p .707 .577 .707 r
F P
0 g
s
.16613 .69771 m .16143 .73586 L .155 .73378 L p .707 .577 .707 r
F P
0 g
s
.155 .73378 m .1597 .69564 L .16613 .69771 L p .707 .577 .707 r
F P
0 g
s
.36134 .80062 m .3594 .81976 L .35611 .81891 L p .707 .577 .707 r
F P
0 g
s
.35611 .81891 m .35805 .79978 L .36134 .80062 L p .707 .577 .707 r
F P
0 g
s
.1648 .66241 m .1678 .60536 L .18405 .60233 L p .707 .577 .707 r
F P
0 g
s
.6281 .75415 m .62084 .25749 L .63862 .26976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18405 .60233 m .18105 .65937 L .1648 .66241 L p .707 .577 .707 r
F P
0 g
s
.35881 .72103 m .35411 .75918 L .34105 .75877 L p .707 .577 .707 r
F P
0 g
s
.15638 .79906 m .15832 .77992 L .16496 .78009 L p .707 .577 .707 r
F P
0 g
s
.16496 .78009 m .16303 .79922 L .15638 .79906 L p .707 .577 .707 r
F P
0 g
s
.34105 .75877 m .34575 .72062 L .35881 .72103 L p .707 .577 .707 r
F P
0 g
s
.34882 .61228 m .34583 .66932 L .32472 .66486 L p .707 .577 .707 r
F P
0 g
s
.32472 .66486 m .32771 .60781 L .34882 .61228 L p .707 .577 .707 r
F P
0 g
s
.37214 .7646 m .36488 .26793 L .38797 .25593 L p .707 .577 .707 r
F P
0 g
s
.36488 .26793 m .37214 .7646 L .36215 .77801 L p .707 .577 .707 r
F P
0 g
s
.18185 .70079 m .17715 .73893 L .16143 .73586 L p .707 .577 .707 r
F P
0 g
s
.16143 .73586 m .16613 .69771 L .18185 .70079 L p .707 .577 .707 r
F P
0 g
s
.18105 .65937 m .18405 .60233 L .208 .60058 L p .707 .577 .707 r
F P
0 g
s
.35805 .79978 m .35611 .81891 L .34321 .81713 L p .707 .577 .707 r
F P
0 g
s
.34321 .81713 m .34514 .798 L .35805 .79978 L p .707 .577 .707 r
F P
0 g
s
.208 .60058 m .205 .65763 L .18105 .65937 L p .707 .577 .707 r
F P
0 g
s
.34575 .72062 m .34105 .75877 L .31969 .75712 L p .707 .577 .707 r
F P
0 g
s
.62084 .25749 m .6281 .75415 L .59836 .7443 L p .707 .577 .707 r
F P
0 g
s
.59836 .7443 m .5911 .24764 L .62084 .25749 L p .707 .577 .707 r
F P
0 g
s
.31969 .75712 m .32439 .71897 L .34575 .72062 L p .707 .577 .707 r
F P
0 g
s
.16303 .79922 m .16496 .78009 L .18089 .78126 L p .707 .577 .707 r
F P
0 g
s
.18089 .78126 m .17896 .80039 L .16303 .79922 L p .707 .577 .707 r
F P
0 g
s
.32771 .60781 m .32472 .66486 L .29724 .66115 L p .707 .577 .707 r
F P
0 g
s
.29724 .66115 m .30024 .60411 L .32771 .60781 L p .707 .577 .707 r
F P
0 g
s
.20531 .70456 m .20061 .7427 L .17715 .73893 L p .707 .577 .707 r
F P
0 g
s
.17715 .73893 m .18185 .70079 L .20531 .70456 L p .707 .577 .707 r
F P
0 g
s
.205 .65763 m .208 .60058 L .2373 .60031 L p .707 .577 .707 r
F P
0 g
s
.38797 .25593 m .39512 .74509 L p .37214 .7646 L .707 .577 .707 r
F P
0 g
s
.39523 .75259 m .38797 .25593 L .42192 .2465 L p .707 .577 .707 r
F P
0 g
s
.42192 .2465 m .42819 .67517 L p .39663 .72619 L .707 .577 .707 r
F P
0 g
s
.42918 .74317 m .42192 .2465 L .46339 .24059 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .47065 .73725 L .42918 .74317 L p .707 .577 .707 r
F P
0 g
s
.42523 .56397 m .42223 .62101 L .43945 .62085 L p .707 .577 .707 r
F P
0 g
s
.43945 .62085 m .45078 .62074 L p .44589 .60988 L .707 .577 .707 r
F P
0 g
s
.44589 .60988 m .42523 .56397 L .43945 .62085 L .707 .577 .707 r
F
.39345 .56275 m .39045 .6198 L .42223 .62101 L p F P
0 g
s
.42223 .62101 m .42523 .56397 L .39345 .56275 L p .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .39343 .61313 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42027 .6553 m .42055 .653 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42055 .653 m .42497 .61715 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .42027 .6553 L .43885 .65793 L p .707 .577 .707 r
F P
0 g
s
.43885 .65793 m .44919 .65939 L p .44378 .64996 L .707 .577 .707 r
F P
0 g
s
.44378 .64996 m .42497 .61715 L .43885 .65793 L .707 .577 .707 r
F
.39523 .75259 m .39663 .72619 L .42852 .69778 L F
.42819 .67517 m .42852 .69778 L p .39663 .72619 L F P
0 g
s
.42852 .69778 m .42918 .74317 L .4142 .74733 L p .707 .577 .707 r
F P
0 g
s
.4142 .74733 m .39523 .75259 L p .42852 .69778 L .707 .577 .707 r
F P
0 g
s
.45078 .62074 m .45153 .62074 L p .45107 .61974 L .707 .577 .707 r
F P
0 g
s
.45107 .61974 m .42523 .56397 L .45078 .62074 L .707 .577 .707 r
F
.39343 .61313 m .38873 .65128 L .41278 .65434 L p F P
0 g
s
.41278 .65434 m .42027 .6553 L p .41439 .64606 L .707 .577 .707 r
F P
0 g
s
.41439 .64606 m .39343 .61313 L .41278 .65434 L .707 .577 .707 r
F
.39512 .74509 m .39523 .75259 L .39349 .7535 L p F P
0 g
s
.39349 .7535 m .37214 .7646 L p .39512 .74509 L .707 .577 .707 r
F P
0 g
s
.2373 .60031 m .2343 .65735 L .205 .65763 L p .707 .577 .707 r
F P
0 g
s
.30024 .60411 m .29724 .66115 L .26609 .65857 L p .707 .577 .707 r
F P
0 g
s
.26609 .65857 m .26908 .60152 L .30024 .60411 L p .707 .577 .707 r
F P
0 g
s
.34514 .798 m .34321 .81713 L .32195 .8146 L p .707 .577 .707 r
F P
0 g
s
.32195 .8146 m .32388 .79547 L .34514 .798 L p .707 .577 .707 r
F P
0 g
s
.2343 .65735 m .2373 .60031 L .26908 .60152 L p .707 .577 .707 r
F P
0 g
s
.32439 .71897 m .31969 .75712 L .29213 .75438 L p .707 .577 .707 r
F P
0 g
s
.29213 .75438 m .29683 .71623 L .32439 .71897 L p .707 .577 .707 r
F P
0 g
s
.26908 .60152 m .26609 .65857 L .2343 .65735 L p .707 .577 .707 r
F P
0 g
s
.73346 .65661 m .73646 .59957 L .7053 .59698 L p .707 .577 .707 r
F P
0 g
s
.73646 .59957 m .73346 .65661 L .76524 .65783 L p .707 .577 .707 r
F P
0 g
s
.76524 .65783 m .76824 .60078 L .73646 .59957 L p .707 .577 .707 r
F P
0 g
s
.23423 .70866 m .22953 .7468 L .20061 .7427 L p .707 .577 .707 r
F P
0 g
s
.20061 .7427 m .20531 .70456 L .23423 .70866 L p .707 .577 .707 r
F P
0 g
s
.17896 .80039 m .18089 .78126 L .20455 .7833 L p .707 .577 .707 r
F P
0 g
s
.20455 .7833 m .20262 .80244 L .17896 .80039 L p .707 .577 .707 r
F P
0 g
s
.76824 .60078 m .76524 .65783 L .78246 .65767 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .73644 .64995 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76328 .69211 m .76356 .68982 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76356 .68982 m .76798 .65397 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.78246 .65767 m .79454 .65755 L p .78925 .64612 L .707 .577 .707 r
F P
0 g
s
.78925 .64612 m .76824 .60078 L .78246 .65767 L .707 .577 .707 r
F
.79454 .65755 m .79754 .6005 L .76824 .60078 L p F P
0 g
s
.5911 .24764 m .59836 .7443 L .5596 .73785 L p .707 .577 .707 r
F P
0 g
s
.5596 .73785 m .55234 .24118 L .5911 .24764 L p .707 .577 .707 r
F P
0 g
s
.70231 .65403 m .7053 .59698 L .67783 .59328 L p .707 .577 .707 r
F P
0 g
s
.7053 .59698 m .70231 .65403 L .73346 .65661 L p .707 .577 .707 r
F P
0 g
s
.29683 .71623 m .29213 .75438 L .26106 .75082 L p .707 .577 .707 r
F P
0 g
s
.70537 .64639 m .70068 .68454 L .73174 .68809 L p .707 .577 .707 r
F P
0 g
s
.73174 .68809 m .73644 .64995 L .70537 .64639 L p .707 .577 .707 r
F P
0 g
s
.73644 .64995 m .73174 .68809 L .76328 .69211 L p .707 .577 .707 r
F P
0 g
s
.26106 .75082 m .26576 .71268 L .29683 .71623 L p .707 .577 .707 r
F P
0 g
s
.26576 .71268 m .26106 .75082 L .22953 .7468 L p .707 .577 .707 r
F P
0 g
s
.22953 .7468 m .23423 .70866 L .26576 .71268 L p .707 .577 .707 r
F P
0 g
s
.67783 .59328 m .67483 .65032 L .70231 .65403 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .76328 .69211 L .7922 .69621 L p .707 .577 .707 r
F P
0 g
s
.79754 .6005 m .79454 .65755 L .81849 .65581 L p .707 .577 .707 r
F P
0 g
s
.81849 .65581 m .82149 .59876 L .79754 .6005 L p .707 .577 .707 r
F P
0 g
s
.32388 .79547 m .32195 .8146 L .29442 .81156 L p .707 .577 .707 r
F P
0 g
s
.29442 .81156 m .29636 .79243 L .32388 .79547 L p .707 .577 .707 r
F P
0 g
s
.7922 .69621 m .79689 .65806 L .76798 .65397 L p .707 .577 .707 r
F P
0 g
s
.67781 .64365 m .67311 .6818 L .70068 .68454 L p .707 .577 .707 r
F P
0 g
s
.70068 .68454 m .70537 .64639 L .67781 .64365 L p .707 .577 .707 r
F P
0 g
s
.73268 .7135 m .73462 .69437 L .70351 .69112 L p .707 .577 .707 r
F P
0 g
s
.73462 .69437 m .73268 .7135 L .76432 .71665 L p .707 .577 .707 r
F P
0 g
s
.76432 .71665 m .76625 .69751 L .73462 .69437 L p .707 .577 .707 r
F P
0 g
s
.70351 .69112 m .70158 .71025 L .73268 .7135 L p .707 .577 .707 r
F P
0 g
s
.67483 .65032 m .67783 .59328 L .65672 .58881 L p .707 .577 .707 r
F P
0 g
s
.20262 .80244 m .20455 .7833 L .23362 .78603 L p .707 .577 .707 r
F P
0 g
s
.23362 .78603 m .23169 .80516 L .20262 .80244 L p .707 .577 .707 r
F P
0 g
s
.76625 .69751 m .76432 .71665 L .79339 .71937 L p .707 .577 .707 r
F P
0 g
s
.79339 .71937 m .79532 .70024 L .76625 .69751 L p .707 .577 .707 r
F P
0 g
s
.55234 .24118 m .5596 .73785 L .51559 .73542 L p .707 .577 .707 r
F P
0 g
s
.51559 .73542 m .50833 .23875 L .55234 .24118 L p .707 .577 .707 r
F P
0 g
s
.70158 .71025 m .70351 .69112 L .67599 .68808 L p .707 .577 .707 r
F P
0 g
s
.67599 .68808 m .67405 .70721 L .70158 .71025 L p .707 .577 .707 r
F P
0 g
s
.79689 .65806 m .7922 .69621 L .81566 .69998 L p .707 .577 .707 r
F P
0 g
s
.81566 .69998 m .82036 .66183 L .79689 .65806 L p .707 .577 .707 r
F P
0 g
s
.65672 .58881 m .65372 .64586 L .67483 .65032 L p .707 .577 .707 r
F P
0 g
s
.29636 .79243 m .29442 .81156 L .26332 .80831 L p .707 .577 .707 r
F P
0 g
s
.26332 .80831 m .26525 .78918 L .29636 .79243 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .50833 .23875 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.47038 .71851 m .46339 .24059 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.45388 .62125 m .45009 .65202 L p .47265 .66316 L .707 .577 .707 r
F P
0 g
s
.45009 .65202 m .44919 .65939 L .45251 .65993 L p .707 .577 .707 r
F P
0 g
s
.45251 .65993 m .47265 .66316 L p .45009 .65202 L .707 .577 .707 r
F P
0 g
s
.47065 .73725 m .47038 .71851 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.65646 .642 m .65176 .68014 L .67311 .6818 L p .707 .577 .707 r
F P
0 g
s
.67311 .6818 m .67781 .64365 L .65646 .642 L p .707 .577 .707 r
F P
0 g
s
.23169 .80516 m .23362 .78603 L .26525 .78918 L p .707 .577 .707 r
F P
0 g
s
.26525 .78918 m .26332 .80831 L .23169 .80516 L p .707 .577 .707 r
F P
0 g
s
.50833 .23875 m .51559 .73542 L .47065 .73725 L p .707 .577 .707 r
F P
0 g
s
.82149 .59876 m .81849 .65581 L .83475 .65277 L p .707 .577 .707 r
F P
0 g
s
.83475 .65277 m .83774 .59573 L .82149 .59876 L p .707 .577 .707 r
F P
0 g
s
.79532 .70024 m .79339 .71937 L .81704 .72142 L p .707 .577 .707 r
F P
0 g
s
.81704 .72142 m .81898 .70229 L .79532 .70024 L p .707 .577 .707 r
F P
0 g
s
.67405 .70721 m .67599 .68808 L .65473 .68554 L p .707 .577 .707 r
F P
0 g
s
.65473 .68554 m .65279 .70468 L .67405 .70721 L p .707 .577 .707 r
F P
0 g
s
.65372 .64586 m .65672 .58881 L .64404 .58403 L p .707 .577 .707 r
F P
0 g
s
.82036 .66183 m .81566 .69998 L .83138 .70305 L p .707 .577 .707 r
F P
0 g
s
.83138 .70305 m .83608 .66491 L .82036 .66183 L p .707 .577 .707 r
F P
0 g
s
.65176 .68014 m .65646 .642 L .6434 .64159 L p .707 .577 .707 r
F P
0 g
s
.81898 .70229 m .81704 .72142 L .83297 .72259 L p .707 .577 .707 r
F P
0 g
s
.83608 .66491 m .83138 .70305 L .83239 .70338 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .83491 .70345 L .8324 .70327 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .8324 .70327 L .83056 .71908 L .707 .577 .707 r
F
.83491 .70345 m .83297 .72259 L .83962 .72275 L p F P
0 g
s
.83962 .72275 m .84155 .70362 L .83491 .70345 L p .707 .577 .707 r
F P
0 g
s
.83239 .70338 m .83781 .70513 L p .83629 .66993 L .707 .577 .707 r
F P
0 g
s
.83629 .66993 m .83608 .66491 L .83239 .70338 L .707 .577 .707 r
F
.8324 .70327 m .81898 .70229 L p .83056 .71908 L F P
0 g
s
.83774 .59573 m .83475 .65277 L .84171 .64874 L p .707 .577 .707 r
F P
0 g
s
.84171 .64874 m .84471 .59169 L .83774 .59573 L p .707 .577 .707 r
F P
0 g
s
.83781 .70513 m .84251 .66699 L .83608 .66491 L p .707 .577 .707 r
F P
0 g
s
.64104 .5794 m .63805 .63644 L .64105 .64108 L p .707 .577 .707 r
F P
0 g
s
.63991 .64247 m .63521 .68061 L .6387 .67973 L p .707 .577 .707 r
F P
0 g
s
.6387 .67973 m .6434 .64159 L .63991 .64247 L p .707 .577 .707 r
F P
0 g
s
.84471 .59169 m .84171 .64874 L .83871 .64411 L p .707 .577 .707 r
F P
0 g
s
.83871 .64411 m .84171 .58706 L .84471 .59169 L p .707 .577 .707 r
F P
0 g
s
.63989 .7029 m .64182 .68377 L .63853 .68292 L p .707 .577 .707 r
F P
0 g
s
.63853 .68292 m .6366 .70205 L .63989 .7029 L p .707 .577 .707 r
F P
0 g
s
.63805 .63644 m .64104 .5794 L .64801 .57536 L p .707 .577 .707 r
F P
0 g
s
.84251 .66699 m .83781 .70513 L .83432 .70601 L p .707 .577 .707 r
F P
0 g
s
.83432 .70601 m .83902 .66786 L .84251 .66699 L p .707 .577 .707 r
F P
0 g
s
.64801 .57536 m .64501 .63241 L .63805 .63644 L p .707 .577 .707 r
F P
0 g
s
.84155 .70362 m .83962 .72275 L .83633 .72191 L p .707 .577 .707 r
F P
0 g
s
.83633 .72191 m .83826 .70277 L .84155 .70362 L p .707 .577 .707 r
F P
0 g
s
.64634 .64454 m .64164 .68269 L .63521 .68061 L p .707 .577 .707 r
F P
0 g
s
.63521 .68061 m .63991 .64247 L .64634 .64454 L p .707 .577 .707 r
F P
0 g
s
.84171 .58706 m .83871 .64411 L .82604 .63932 L p .707 .577 .707 r
F P
0 g
s
.82604 .63932 m .82904 .58228 L .84171 .58706 L p .707 .577 .707 r
F P
0 g
s
.66206 .64762 m .65736 .68576 L .64412 .68317 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .63853 .68292 L .64413 .68306 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .64413 .68306 L .6438 .68613 L .707 .577 .707 r
F
.64412 .68317 m .64164 .68269 L p .64474 .67737 L F P
0 g
s
.64474 .67737 m .66206 .64762 L .64412 .68317 L .707 .577 .707 r
F
.64413 .68306 m .64518 .68309 L p .6438 .68613 L F P
0 g
s
.64518 .68309 m .64324 .70222 L .6366 .70205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39045 .6198 m .39345 .56275 L .36229 .56017 L p .707 .577 .707 r
F P
0 g
s
.45153 .62074 m .45453 .56369 L .42523 .56397 L p .707 .577 .707 r
F P
0 g
s
.64501 .63241 m .64801 .57536 L .66427 .57233 L p .707 .577 .707 r
F P
0 g
s
.3593 .61721 m .36229 .56017 L .33482 .55646 L p .707 .577 .707 r
F P
0 g
s
.36229 .56017 m .3593 .61721 L .39045 .6198 L p .707 .577 .707 r
F P
0 g
s
.83902 .66786 m .83432 .70601 L .82126 .7056 L p .707 .577 .707 r
F P
0 g
s
.82126 .7056 m .82596 .66745 L .83902 .66786 L p .707 .577 .707 r
F P
0 g
s
.36236 .60958 m .35767 .64772 L .38873 .65128 L p .707 .577 .707 r
F P
0 g
s
.38873 .65128 m .39343 .61313 L .36236 .60958 L p .707 .577 .707 r
F P
0 g
s
.66427 .57233 m .66127 .62937 L .64501 .63241 L p .707 .577 .707 r
F P
0 g
s
.33482 .55646 m .33182 .61351 L .3593 .61721 L p .707 .577 .707 r
F P
0 g
s
.45453 .56369 m .45153 .62074 L .47548 .61899 L p .707 .577 .707 r
F P
0 g
s
.47548 .61899 m .47848 .56195 L .45453 .56369 L p .707 .577 .707 r
F P
0 g
s
.44919 .65939 m .45388 .62125 L .42497 .61715 L p .707 .577 .707 r
F P
0 g
s
.83826 .70277 m .83633 .72191 L .82342 .72013 L p .707 .577 .707 r
F P
0 g
s
.82342 .72013 m .82536 .701 L .83826 .70277 L p .707 .577 .707 r
F P
0 g
s
.64164 .68269 m .64634 .64454 L .66206 .64762 L p .707 .577 .707 r
F P
0 g
s
.3348 .60684 m .3301 .64498 L .35767 .64772 L p .707 .577 .707 r
F P
0 g
s
.35767 .64772 m .36236 .60958 L .3348 .60684 L p .707 .577 .707 r
F P
0 g
s
.38967 .67669 m .39161 .65755 L .3605 .6543 L p .707 .577 .707 r
F P
0 g
s
.39161 .65755 m .38967 .67669 L .42131 .67983 L p .707 .577 .707 r
F P
0 g
s
.42131 .67983 m .42324 .6607 L .39161 .65755 L p .707 .577 .707 r
F P
0 g
s
.3605 .6543 m .35857 .67343 L .38967 .67669 L p .707 .577 .707 r
F P
0 g
s
.33182 .61351 m .33482 .55646 L .31371 .552 L p .707 .577 .707 r
F P
0 g
s
.82904 .58228 m .82604 .63932 L .80493 .63486 L p .707 .577 .707 r
F P
0 g
s
.80493 .63486 m .80793 .57781 L .82904 .58228 L p .707 .577 .707 r
F P
0 g
s
.42324 .6607 m .42131 .67983 L .45038 .68256 L p .707 .577 .707 r
F P
0 g
s
.45038 .68256 m .45231 .66343 L .42324 .6607 L p .707 .577 .707 r
F P
0 g
s
.68552 .65139 m .68083 .68953 L .65736 .68576 L p .707 .577 .707 r
F P
0 g
s
.65736 .68576 m .66206 .64762 L .68552 .65139 L p .707 .577 .707 r
F P
0 g
s
.64324 .70222 m .64518 .68309 L .66111 .68425 L p .707 .577 .707 r
F P
0 g
s
.35857 .67343 m .3605 .6543 L .33298 .65126 L p .707 .577 .707 r
F P
0 g
s
.66111 .68425 m .65917 .70339 L .64324 .70222 L p .707 .577 .707 r
F P
0 g
s
.33298 .65126 m .33104 .67039 L .35857 .67343 L p .707 .577 .707 r
F P
0 g
s
.47265 .66316 m .47735 .62502 L .45388 .62125 L p .707 .577 .707 r
F P
0 g
s
.31371 .552 m .31071 .60904 L .33182 .61351 L p .707 .577 .707 r
F P
0 g
s
.66127 .62937 m .66427 .57233 L .68822 .57058 L p .707 .577 .707 r
F P
0 g
s
.31345 .60518 m .30875 .64333 L .3301 .64498 L p .707 .577 .707 r
F P
0 g
s
.3301 .64498 m .3348 .60684 L .31345 .60518 L p .707 .577 .707 r
F P
0 g
s
.47848 .56195 m .47548 .61899 L .49174 .61596 L p .707 .577 .707 r
F P
0 g
s
.49174 .61596 m .49473 .55891 L .47848 .56195 L p .707 .577 .707 r
F P
0 g
s
.82596 .66745 m .82126 .7056 L .79991 .70394 L p .707 .577 .707 r
F P
0 g
s
.45231 .66343 m .45038 .68256 L .47403 .68461 L p .707 .577 .707 r
F P
0 g
s
.47403 .68461 m .47597 .66547 L .45231 .66343 L p .707 .577 .707 r
F P
0 g
s
.79991 .70394 m .80461 .6658 L .82596 .66745 L p .707 .577 .707 r
F P
0 g
s
.68822 .57058 m .68522 .62763 L .66127 .62937 L p .707 .577 .707 r
F P
0 g
s
.33104 .67039 m .33298 .65126 L .31172 .64873 L p .707 .577 .707 r
F P
0 g
s
.31172 .64873 m .30978 .66786 L .33104 .67039 L p .707 .577 .707 r
F P
0 g
s
.31071 .60904 m .31371 .552 L .30103 .54721 L p .707 .577 .707 r
F P
0 g
s
.82536 .701 m .82342 .72013 L .80216 .7176 L p .707 .577 .707 r
F P
0 g
s
.80216 .7176 m .8041 .69847 L .82536 .701 L p .707 .577 .707 r
F P
0 g
s
.80793 .57781 m .80493 .63486 L .77745 .63115 L p .707 .577 .707 r
F P
0 g
s
.77745 .63115 m .78045 .57411 L .80793 .57781 L p .707 .577 .707 r
F P
0 g
s
.47735 .62502 m .47265 .66316 L .48837 .66624 L p .707 .577 .707 r
F P
0 g
s
.48837 .66624 m .49307 .62809 L .47735 .62502 L p .707 .577 .707 r
F P
0 g
s
.68522 .62763 m .68822 .57058 L .71752 .57031 L p .707 .577 .707 r
F P
0 g
s
.30103 .54721 m .29804 .60426 L .31071 .60904 L p .707 .577 .707 r
F P
0 g
s
.71444 .65548 m .70974 .69363 L .68083 .68953 L p .707 .577 .707 r
F P
0 g
s
.68083 .68953 m .68552 .65139 L .71444 .65548 L p .707 .577 .707 r
F P
0 g
s
.65917 .70339 m .66111 .68425 L .68477 .6863 L p .707 .577 .707 r
F P
0 g
s
.68477 .6863 m .68283 .70543 L .65917 .70339 L p .707 .577 .707 r
F P
0 g
s
.30039 .60477 m .29569 .64292 L .30875 .64333 L p .707 .577 .707 r
F P
0 g
s
.30875 .64333 m .31345 .60518 L .30039 .60477 L p .707 .577 .707 r
F P
0 g
s
.47597 .66547 m .47403 .68461 L .48996 .68577 L p .707 .577 .707 r
F P
0 g
s
.49307 .62809 m .48837 .66624 L .48938 .66656 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .4919 .66664 L .48939 .66645 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .48939 .66645 L .48755 .68227 L .707 .577 .707 r
F
.4919 .66664 m .48996 .68577 L .49661 .68594 L p F P
0 g
s
.49661 .68594 m .49854 .6668 L .4919 .66664 L p .707 .577 .707 r
F P
0 g
s
.48938 .66656 m .4948 .66832 L p .49328 .63312 L .707 .577 .707 r
F P
0 g
s
.49328 .63312 m .49307 .62809 L .48938 .66656 L .707 .577 .707 r
F
.48939 .66645 m .47597 .66547 L p .48755 .68227 L F P
0 g
s
.80461 .6658 m .79991 .70394 L .77235 .70121 L p .707 .577 .707 r
F P
0 g
s
.71752 .57031 m .71452 .62735 L .68522 .62763 L p .707 .577 .707 r
F P
0 g
s
.77235 .70121 m .77705 .66306 L .80461 .6658 L p .707 .577 .707 r
F P
0 g
s
.78045 .57411 m .77745 .63115 L .7463 .62857 L p .707 .577 .707 r
F P
0 g
s
.7463 .62857 m .7493 .57152 L .78045 .57411 L p .707 .577 .707 r
F P
0 g
s
.49473 .55891 m .49174 .61596 L .4987 .61193 L p .707 .577 .707 r
F P
0 g
s
.4987 .61193 m .5017 .55488 L .49473 .55891 L p .707 .577 .707 r
F P
0 g
s
.71452 .62735 m .71752 .57031 L .7493 .57152 L p .707 .577 .707 r
F P
0 g
s
.30978 .66786 m .31172 .64873 L .29881 .64695 L p .707 .577 .707 r
F P
0 g
s
.29881 .64695 m .29688 .66608 L .30978 .66786 L p .707 .577 .707 r
F P
0 g
s
.7493 .57152 m .7463 .62857 L .71452 .62735 L p .707 .577 .707 r
F P
0 g
s
.8041 .69847 m .80216 .7176 L .77464 .71456 L p .707 .577 .707 r
F P
0 g
s
.77464 .71456 m .77657 .69542 L .8041 .69847 L p .707 .577 .707 r
F P
0 g
s
.29804 .60426 m .30103 .54721 L .29803 .54258 L p .707 .577 .707 r
F P
0 g
s
.70974 .69363 m .71444 .65548 L .74598 .65951 L p .707 .577 .707 r
F P
0 g
s
.68283 .70543 m .68477 .6863 L .71383 .68903 L p .707 .577 .707 r
F P
0 g
s
.74598 .65951 m .74128 .69765 L .70974 .69363 L p .707 .577 .707 r
F P
0 g
s
.71383 .68903 m .7119 .70816 L .68283 .70543 L p .707 .577 .707 r
F P
0 g
s
.77705 .66306 m .77235 .70121 L .74128 .69765 L p .707 .577 .707 r
F P
0 g
s
.74128 .69765 m .74598 .65951 L .77705 .66306 L p .707 .577 .707 r
F P
0 g
s
.4948 .66832 m .4995 .63017 L .49307 .62809 L p .707 .577 .707 r
F P
0 g
s
.29803 .54258 m .29504 .59963 L .29804 .60426 L p .707 .577 .707 r
F P
0 g
s
.77657 .69542 m .77464 .71456 L .74353 .71131 L p .707 .577 .707 r
F P
0 g
s
.74353 .71131 m .74547 .69217 L .77657 .69542 L p .707 .577 .707 r
F P
0 g
s
.2969 .60565 m .2922 .6438 L .29569 .64292 L p .707 .577 .707 r
F P
0 g
s
.29569 .64292 m .30039 .60477 L .2969 .60565 L p .707 .577 .707 r
F P
0 g
s
.7119 .70816 m .71383 .68903 L .74547 .69217 L p .707 .577 .707 r
F P
0 g
s
.74547 .69217 m .74353 .71131 L .7119 .70816 L p .707 .577 .707 r
F P
0 g
s
.5017 .55488 m .4987 .61193 L .4957 .60729 L p .707 .577 .707 r
F P
0 g
s
.4957 .60729 m .4987 .55024 L .5017 .55488 L p .707 .577 .707 r
F P
0 g
s
.29688 .66608 m .29881 .64695 L .29552 .64611 L p .707 .577 .707 r
F P
0 g
s
.29552 .64611 m .29359 .66524 L .29688 .66608 L p .707 .577 .707 r
F P
0 g
s
.29504 .59963 m .29803 .54258 L .305 .53855 L p .707 .577 .707 r
F P
0 g
s
.4995 .63017 m .4948 .66832 L .49131 .66919 L p .707 .577 .707 r
F P
0 g
s
.49131 .66919 m .49601 .63105 L .4995 .63017 L p .707 .577 .707 r
F P
0 g
s
.305 .53855 m .302 .59559 L .29504 .59963 L p .707 .577 .707 r
F P
0 g
s
.49854 .6668 m .49661 .68594 L .49332 .68509 L p .707 .577 .707 r
F P
0 g
s
.49332 .68509 m .49525 .66596 L .49854 .6668 L p .707 .577 .707 r
F P
0 g
s
.30333 .60773 m .29863 .64587 L .2922 .6438 L p .707 .577 .707 r
F P
0 g
s
.2922 .6438 m .2969 .60565 L .30333 .60773 L p .707 .577 .707 r
F P
0 g
s
.4987 .55024 m .4957 .60729 L .48303 .60251 L p .707 .577 .707 r
F P
0 g
s
.48303 .60251 m .48603 .54546 L .4987 .55024 L p .707 .577 .707 r
F P
0 g
s
.31905 .6108 m .31435 .64895 L .30111 .64636 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .29552 .64611 L .30112 .64625 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .30112 .64625 L .30079 .64931 L .707 .577 .707 r
F
.30111 .64636 m .29863 .64587 L p .30173 .64055 L F P
0 g
s
.30173 .64055 m .31905 .6108 L .30111 .64636 L .707 .577 .707 r
F
.30112 .64625 m .30217 .64627 L p .30079 .64931 L F P
0 g
s
.30217 .64627 m .30023 .66541 L .29359 .66524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.302 .59559 m .305 .53855 L .32126 .53551 L p .707 .577 .707 r
F P
0 g
s
.49601 .63105 m .49131 .66919 L .47825 .66878 L p .707 .577 .707 r
F P
0 g
s
.47825 .66878 m .48295 .63064 L .49601 .63105 L p .707 .577 .707 r
F P
0 g
s
.32126 .53551 m .31826 .59256 L .302 .59559 L p .707 .577 .707 r
F P
0 g
s
.49525 .66596 m .49332 .68509 L .48041 .68332 L p .707 .577 .707 r
F P
0 g
s
.48041 .68332 m .48235 .66418 L .49525 .66596 L p .707 .577 .707 r
F P
0 g
s
.29863 .64587 m .30333 .60773 L .31905 .6108 L p .707 .577 .707 r
F P
0 g
s
.48603 .54546 m .48303 .60251 L .46192 .59805 L p .707 .577 .707 r
F P
0 g
s
.46192 .59805 m .46492 .541 L .48603 .54546 L p .707 .577 .707 r
F P
0 g
s
.34251 .61457 m .33782 .65272 L .31435 .64895 L p .707 .577 .707 r
F P
0 g
s
.31435 .64895 m .31905 .6108 L .34251 .61457 L p .707 .577 .707 r
F P
0 g
s
.30023 .66541 m .30217 .64627 L .3181 .64744 L p .707 .577 .707 r
F P
0 g
s
.3181 .64744 m .31616 .66657 L .30023 .66541 L p .707 .577 .707 r
F P
0 g
s
.31826 .59256 m .32126 .53551 L .3452 .53377 L p .707 .577 .707 r
F P
0 g
s
.48295 .63064 m .47825 .66878 L .4569 .66713 L p .707 .577 .707 r
F P
0 g
s
.4569 .66713 m .4616 .62898 L .48295 .63064 L p .707 .577 .707 r
F P
0 g
s
.3452 .53377 m .34221 .59082 L .31826 .59256 L p .707 .577 .707 r
F P
0 g
s
.48235 .66418 m .48041 .68332 L .45915 .68078 L p .707 .577 .707 r
F P
0 g
s
.45915 .68078 m .46109 .66165 L .48235 .66418 L p .707 .577 .707 r
F P
0 g
s
.46492 .541 m .46192 .59805 L .43444 .59434 L p .707 .577 .707 r
F P
0 g
s
.43444 .59434 m .43744 .53729 L .46492 .541 L p .707 .577 .707 r
F P
0 g
s
.34221 .59082 m .3452 .53377 L .3745 .53349 L p .707 .577 .707 r
F P
0 g
s
.37143 .61867 m .36673 .65681 L .33782 .65272 L p .707 .577 .707 r
F P
0 g
s
.33782 .65272 m .34251 .61457 L .37143 .61867 L p .707 .577 .707 r
F P
0 g
s
.31616 .66657 m .3181 .64744 L .34175 .64948 L p .707 .577 .707 r
F P
0 g
s
.34175 .64948 m .33982 .66862 L .31616 .66657 L p .707 .577 .707 r
F P
0 g
s
.4616 .62898 m .4569 .66713 L .42934 .66439 L p .707 .577 .707 r
F P
0 g
s
.3745 .53349 m .37151 .59054 L .34221 .59082 L p .707 .577 .707 r
F P
0 g
s
.42934 .66439 m .43403 .62625 L .4616 .62898 L p .707 .577 .707 r
F P
0 g
s
.43744 .53729 m .43444 .59434 L .40329 .59175 L p .707 .577 .707 r
F P
0 g
s
.40329 .59175 m .40629 .53471 L .43744 .53729 L p .707 .577 .707 r
F P
0 g
s
.37151 .59054 m .3745 .53349 L .40629 .53471 L p .707 .577 .707 r
F P
0 g
s
.40629 .53471 m .40329 .59175 L .37151 .59054 L p .707 .577 .707 r
F P
0 g
s
.46109 .66165 m .45915 .68078 L .43163 .67774 L p .707 .577 .707 r
F P
0 g
s
.43163 .67774 m .43356 .65861 L .46109 .66165 L p .707 .577 .707 r
F P
0 g
s
.36673 .65681 m .37143 .61867 L .40297 .62269 L p .707 .577 .707 r
F P
0 g
s
.33982 .66862 m .34175 .64948 L .37082 .65221 L p .707 .577 .707 r
F P
0 g
s
.40297 .62269 m .39827 .66084 L .36673 .65681 L p .707 .577 .707 r
F P
0 g
s
.37082 .65221 m .36889 .67135 L .33982 .66862 L p .707 .577 .707 r
F P
0 g
s
.43403 .62625 m .42934 .66439 L .39827 .66084 L p .707 .577 .707 r
F P
0 g
s
.39827 .66084 m .40297 .62269 L .43403 .62625 L p .707 .577 .707 r
F P
0 g
s
.43356 .65861 m .43163 .67774 L .40052 .67449 L p .707 .577 .707 r
F P
0 g
s
.40052 .67449 m .40246 .65536 L .43356 .65861 L p .707 .577 .707 r
F P
0 g
s
.36889 .67135 m .37082 .65221 L .40246 .65536 L p .707 .577 .707 r
F P
0 g
s
.40246 .65536 m .40052 .67449 L .36889 .67135 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002:Ool=0026Ool0085oo`T0
00IJEP03001JEUYF00AJEPT007eoo`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001eOol60008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol0075oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEP00001aOol006ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Mo
o`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Io
o`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005mooa4000QJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Aoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001F
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0I7oo001DOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo009ooah004Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003aoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0031oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Goo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001COol00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol@000;Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH70003FUH00`00
FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol60003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF00000003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo000_Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH?0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000]Ool30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF1P0000=JEP00FUH0
0UYF20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF1`000UYF
00@005YFFUIJEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP04001JEUYFFUH7
0003FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040008FUH00`00FUIJEP02FUH=0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPL00003FUH005YF00MJEP03001JEUYF
00H000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`0000AJEP00FUIJEP<000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF7P0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH0200015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00P0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF1@00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00H0009JEQ0000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF1@0000=JEP00FUH01UYF00<005YFFUH00UYF
2@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF2@000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YFFUH005YF0004FUH00`00FUIJEP0800000eYF001JEP07FUH00`00FUIJEP02FUH60005FUH0
0`00FUIJEP04FUH00`00FUIJEP04000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0000=JEP00FUH01eYF00<005YF00003P00<Woo000/Ool00`00FUH00002
FUH?0007FUH90003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00=JEPH003Moo`00;7oo00<005YF00000`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPh000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00@005YFFUIJEPD0039oo`00;7oo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH@000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000A0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
0UYF2P000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000dOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP<00003FUH0000000L0009JEPL000=JEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00UYF1@001UYF0P0000=J
EP000000400015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00A7oo7`000goo00@005YFFUH000AJEPD000IJEP8000YJEP04001J
EUYFFUH50004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001VOol01000FUIJEP0015YF1@001UYF0P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000]Ool8000aOol01000FUIJEP001EYF0`001eYF0P002UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`@00004FUH005YFFUH?000ROol01000FUIJEP001UYF00<005YFFUH01UYF
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70002FUH01000FUIJEUYF0P00;Woo000]Ool01000FUH005YF1P0000=JEP00FUH01UYF
00@005YFFUIJEPL001]oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000040002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08
000^Ool002eoo`03001JEP0000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04
000GOol01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<0
05YFFUH015YF00@005YFFUIJEPT00003FUH005YF00EJEPL0011oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH005YF4`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH00eYF1`002Goo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEP0000IJEP03001JEUYF009JEP<000=oo``000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP060003Ool01000FUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH00UYF00<005YF000027oo0`0000=oo`000000
2@000eYF00<005YFFUH015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3`000UYF00<005YF
FUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH0100027oo1@0027oo3`00
00=JEP000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH<000<Ool5000@Ool:000^Ool002aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`0EOol50018Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF
000@FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`0FOol30019Ool002aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol002eoo`<0009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP06FUHO0008FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol0031oo`H000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0>FUH00`00FUIJEP06000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003Ioo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP040006FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003eoo`T000AJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF
00<005YFFUH00eYF1`00GWoo0016Ool90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`000UYF00<005YFFUH015YF00H005YF000005YF000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEP000eYF1@00FGoo
001?Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@0
05YF000000EJEPP0009JEP03001JEP00008005Ioo`00Egoo40000UYF00@005YFFUIJEP8000IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP09001DOol006Ioo`05001JEUYF001JEP03
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
001VOol00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol004Qoo`<001]oo`<0
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0017Ool5000JOol30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00;Goo10005Woo1@006Woo00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol002eoo`80009JEPd000Uoo`D001Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP03001J
EUYF00AJEP04001JEUYFFUH9000017oo0000000077oo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200047oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01`000eYF00@005YFFUIJEP8005Eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEP`000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH2000:Ool9001EOol0
02aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00008000Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF001ZOol003Aooa8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000Ioo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<006]oo`00
>goo20000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP<006eoo`00@goo2@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000Yoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0071oo`00
C7oo2@000UYF1`000eYF00@005YFFUIJEP8000eoo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEPD00003Ool0000000<006moo`00EGoo4P004Goo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00@005YFFUIJEPH000Ioo`D006moo`00HWoo1@005goo:P0000=oo`0000000`00
Kgoo002>Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001/
Ool008eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPP006Aoo`00SGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL005eoo`00SGoo1@000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH02000EGoo
002@Ool?0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo002EOol70003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002LOolE0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH005Aoo`00[Woo2`0015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo002fOol?
00000eYF0000001EOol00;ioo`X005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59626 .72343 m .59925 .66638 L .5681 .6638 L p .707 .577 .707 r
F P
0 g
s
.59925 .66638 m .59626 .72343 L .62804 .72464 L p .707 .577 .707 r
F P
0 g
s
.62804 .72464 m .63104 .6676 L .59925 .66638 L p .707 .577 .707 r
F P
0 g
s
.63104 .6676 m .62804 .72464 L .65734 .72437 L p .707 .577 .707 r
F P
0 g
s
.65734 .72437 m .66034 .66732 L .63104 .6676 L p .707 .577 .707 r
F P
0 g
s
.5651 .72084 m .5681 .6638 L .54062 .66009 L p .707 .577 .707 r
F P
0 g
s
.5681 .6638 m .5651 .72084 L .59626 .72343 L p .707 .577 .707 r
F P
0 g
s
.54062 .66009 m .53763 .71714 L .5651 .72084 L p .707 .577 .707 r
F P
0 g
s
.66034 .66732 m .65734 .72437 L .68129 .72262 L p .707 .577 .707 r
F P
0 g
s
.68129 .72262 m .68429 .66558 L .66034 .66732 L p .707 .577 .707 r
F P
0 g
s
.56817 .73638 m .56347 .77452 L .59454 .77808 L p .707 .577 .707 r
F P
0 g
s
.59454 .77808 m .59924 .73993 L .56817 .73638 L p .707 .577 .707 r
F P
0 g
s
.59924 .73993 m .59454 .77808 L .62608 .7821 L p .707 .577 .707 r
F P
0 g
s
.62608 .7821 m .63077 .74395 L .59924 .73993 L p .707 .577 .707 r
F P
0 g
s
.63077 .74395 m .62608 .7821 L .65499 .7862 L p .707 .577 .707 r
F P
0 g
s
.53763 .71714 m .54062 .66009 L .51952 .65563 L p .707 .577 .707 r
F P
0 g
s
.65499 .7862 m .65969 .74805 L .63077 .74395 L p .707 .577 .707 r
F P
0 g
s
.54061 .73364 m .53591 .77178 L .56347 .77452 L p .707 .577 .707 r
F P
0 g
s
.56347 .77452 m .56817 .73638 L .54061 .73364 L p .707 .577 .707 r
F P
0 g
s
.51952 .65563 m .51652 .71267 L .53763 .71714 L p .707 .577 .707 r
F P
0 g
s
.65969 .74805 m .65499 .7862 L .67846 .78996 L p .707 .577 .707 r
F P
0 g
s
.67846 .78996 m .68315 .75182 L .65969 .74805 L p .707 .577 .707 r
F P
0 g
s
.68429 .66558 m .68129 .72262 L .69754 .71959 L p .707 .577 .707 r
F P
0 g
s
.69754 .71959 m .70054 .66254 L .68429 .66558 L p .707 .577 .707 r
F P
0 g
s
.59548 .84732 m .59741 .82819 L .56631 .82493 L p .707 .577 .707 r
F P
0 g
s
.59741 .82819 m .59548 .84732 L .62711 .85046 L p .707 .577 .707 r
F P
0 g
s
.62711 .85046 m .62905 .83133 L .59741 .82819 L p .707 .577 .707 r
F P
0 g
s
.56631 .82493 m .56438 .84407 L .59548 .84732 L p .707 .577 .707 r
F P
0 g
s
.51925 .73198 m .51455 .77013 L .53591 .77178 L p .707 .577 .707 r
F P
0 g
s
.53591 .77178 m .54061 .73364 L .51925 .73198 L p .707 .577 .707 r
F P
0 g
s
.62905 .83133 m .62711 .85046 L .65618 .85319 L p .707 .577 .707 r
F P
0 g
s
.65618 .85319 m .65812 .83406 L .62905 .83133 L p .707 .577 .707 r
F P
0 g
s
.51652 .71267 m .51952 .65563 L .50684 .65084 L p .707 .577 .707 r
F P
0 g
s
.56438 .84407 m .56631 .82493 L .53878 .82189 L p .707 .577 .707 r
F P
0 g
s
.53878 .82189 m .53685 .84103 L .56438 .84407 L p .707 .577 .707 r
F P
0 g
s
.50684 .65084 m .50384 .70789 L .51652 .71267 L p .707 .577 .707 r
F P
0 g
s
.68315 .75182 m .67846 .78996 L .69417 .79304 L p .707 .577 .707 r
F P
0 g
s
.65812 .83406 m .65618 .85319 L .67984 .85524 L p .707 .577 .707 r
F P
0 g
s
.67984 .85524 m .68177 .83611 L .65812 .83406 L p .707 .577 .707 r
F P
0 g
s
.69417 .79304 m .69887 .75489 L .68315 .75182 L p .707 .577 .707 r
F P
0 g
s
.53685 .84103 m .53878 .82189 L .51753 .81936 L p .707 .577 .707 r
F P
0 g
s
.51753 .81936 m .51559 .83849 L .53685 .84103 L p .707 .577 .707 r
F P
0 g
s
.70054 .66254 m .69754 .71959 L .70451 .71556 L p .707 .577 .707 r
F P
0 g
s
.70451 .71556 m .70751 .65851 L .70054 .66254 L p .707 .577 .707 r
F P
0 g
s
.50619 .73158 m .5015 .76972 L .51455 .77013 L p .707 .577 .707 r
F P
0 g
s
.51455 .77013 m .51925 .73198 L .50619 .73158 L p .707 .577 .707 r
F P
0 g
s
.50384 .70789 m .50684 .65084 L .50384 .64621 L p .707 .577 .707 r
F P
0 g
s
.68177 .83611 m .67984 .85524 L .69577 .8564 L p .707 .577 .707 r
F P
0 g
s
.69577 .8564 m .6977 .83727 L .68177 .83611 L p .707 .577 .707 r
F P
0 g
s
.50384 .64621 m .50084 .70326 L .50384 .70789 L p .707 .577 .707 r
F P
0 g
s
.69887 .75489 m .69417 .79304 L .7006 .79512 L p .707 .577 .707 r
F P
0 g
s
.7006 .79512 m .7053 .75697 L .69887 .75489 L p .707 .577 .707 r
F P
0 g
s
.51559 .83849 m .51753 .81936 L .50462 .81759 L p .707 .577 .707 r
F P
0 g
s
.50462 .81759 m .50268 .83672 L .51559 .83849 L p .707 .577 .707 r
F P
0 g
s
.50271 .73245 m .49801 .7706 L .5015 .76972 L p .707 .577 .707 r
F P
0 g
s
.5015 .76972 m .50619 .73158 L .50271 .73245 L p .707 .577 .707 r
F P
0 g
s
.70751 .65851 m .70451 .71556 L .70151 .71092 L p .707 .577 .707 r
F P
0 g
s
.70151 .71092 m .70451 .65388 L .70751 .65851 L p .707 .577 .707 r
F P
0 g
s
.49654 .82253 m .48928 .32586 L .44527 .32343 L p .707 .577 .707 r
F P
0 g
s
.50084 .70326 m .50384 .64621 L .51081 .64218 L p .707 .577 .707 r
F P
0 g
s
.51081 .64218 m .50781 .69922 L .50084 .70326 L p .707 .577 .707 r
F P
0 g
s
.50268 .83672 m .50462 .81759 L .50133 .81674 L p .707 .577 .707 r
F P
0 g
s
.50133 .81674 m .49939 .83587 L .50268 .83672 L p .707 .577 .707 r
F P
0 g
s
.50914 .73453 m .50444 .77267 L .49801 .7706 L p .707 .577 .707 r
F P
0 g
s
.49801 .7706 m .50271 .73245 L .50914 .73453 L p .707 .577 .707 r
F P
0 g
s
.50781 .69922 m .51081 .64218 L .52706 .63914 L p .707 .577 .707 r
F P
0 g
s
.52706 .63914 m .52406 .69619 L .50781 .69922 L p .707 .577 .707 r
F P
0 g
s
.49939 .83587 m .50133 .81674 L .50797 .81691 L p .707 .577 .707 r
F P
0 g
s
.50797 .81691 m .50604 .83604 L .49939 .83587 L p .707 .577 .707 r
F P
0 g
s
.52486 .7376 m .52016 .77575 L .50444 .77267 L p .707 .577 .707 r
F P
0 g
s
.50444 .77267 m .50914 .73453 L .52486 .7376 L p .707 .577 .707 r
F P
0 g
s
.52406 .69619 m .52706 .63914 L .55101 .6374 L p .707 .577 .707 r
F P
0 g
s
.55101 .6374 m .54801 .69445 L .52406 .69619 L p .707 .577 .707 r
F P
0 g
s
.50604 .83604 m .50797 .81691 L .5239 .81807 L p .707 .577 .707 r
F P
0 g
s
.5239 .81807 m .52197 .8372 L .50604 .83604 L p .707 .577 .707 r
F P
0 g
s
.54832 .74137 m .54362 .77952 L .52016 .77575 L p .707 .577 .707 r
F P
0 g
s
.52016 .77575 m .52486 .7376 L .54832 .74137 L p .707 .577 .707 r
F P
0 g
s
.52197 .8372 m .5239 .81807 L .54756 .82012 L p .707 .577 .707 r
F P
0 g
s
.48928 .32586 m .49654 .82253 L .54148 .82069 L p .707 .577 .707 r
F P
0 g
s
.54148 .82069 m .53422 .32403 L .48928 .32586 L p .707 .577 .707 r
F P
0 g
s
.54801 .69445 m .55101 .6374 L .58031 .63712 L p .707 .577 .707 r
F P
0 g
s
.58031 .63712 m .57731 .69417 L .54801 .69445 L p .707 .577 .707 r
F P
0 g
s
.57724 .74547 m .57254 .78362 L .54362 .77952 L p .707 .577 .707 r
F P
0 g
s
.54362 .77952 m .54832 .74137 L .57724 .74547 L p .707 .577 .707 r
F P
0 g
s
.60877 .74949 m .60407 .78764 L .57254 .78362 L p .707 .577 .707 r
F P
0 g
s
.57254 .78362 m .57724 .74547 L .60877 .74949 L p .707 .577 .707 r
F P
0 g
s
.53422 .32403 m .54148 .82069 L .58295 .81477 L p .707 .577 .707 r
F P
0 g
s
.57731 .69417 m .58031 .63712 L .61209 .63834 L p .707 .577 .707 r
F P
0 g
s
.61209 .63834 m .6091 .69538 L .57731 .69417 L p .707 .577 .707 r
F P
0 g
s
.58295 .81477 m .57569 .31811 L .53422 .32403 L p .707 .577 .707 r
F P
0 g
s
.6977 .83727 m .69577 .8564 L .70241 .85657 L p .707 .577 .707 r
F P
0 g
s
.70241 .85657 m .70435 .83744 L .6977 .83727 L p .707 .577 .707 r
F P
0 g
s
.45253 .8201 m .44527 .32343 L .40651 .31698 L p .707 .577 .707 r
F P
0 g
s
.44527 .32343 m .45253 .8201 L .49654 .82253 L p .707 .577 .707 r
F P
0 g
s
.7053 .75697 m .7006 .79512 L .69712 .79599 L p .707 .577 .707 r
F P
0 g
s
.69712 .79599 m .70182 .75785 L .7053 .75697 L p .707 .577 .707 r
F P
0 g
s
.63984 .75305 m .63514 .79119 L .61341 .78871 L p .707 .577 .707 r
F P
0 g
s
.61341 .78871 m .60407 .78764 L p .61413 .77791 L .707 .577 .707 r
F P
0 g
s
.61413 .77791 m .63984 .75305 L .61341 .78871 L .707 .577 .707 r
F
.67072 .64463 m .66773 .70168 L .64025 .69797 L p F P
0 g
s
.64025 .69797 m .64325 .64092 L .67072 .64463 L p .707 .577 .707 r
F P
0 g
s
.64325 .64092 m .64025 .69797 L .6091 .69538 L p .707 .577 .707 r
F P
0 g
s
.6091 .69538 m .61209 .63834 L .64325 .64092 L p .707 .577 .707 r
F P
0 g
s
.6674 .75579 m .6627 .79393 L .63514 .79119 L p .707 .577 .707 r
F P
0 g
s
.63514 .79119 m .63984 .75305 L .6674 .75579 L p .707 .577 .707 r
F P
0 g
s
.60407 .78764 m .60877 .74949 L .63984 .75305 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .64998 .77993 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63273 .29668 m .63517 .46314 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63517 .46314 m .63999 .79335 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.57569 .31811 m .58295 .81477 L .6169 .80535 L p .707 .577 .707 r
F P
0 g
s
.6169 .80535 m .60964 .30869 L .57569 .31811 L p .707 .577 .707 r
F P
0 g
s
.70451 .65388 m .70151 .71092 L .68883 .70614 L p .707 .577 .707 r
F P
0 g
s
.68883 .70614 m .69183 .64909 L .70451 .65388 L p .707 .577 .707 r
F P
0 g
s
.41377 .81364 m .40651 .31698 L .37677 .30713 L p .707 .577 .707 r
F P
0 g
s
.40651 .31698 m .41377 .81364 L .45253 .8201 L p .707 .577 .707 r
F P
0 g
s
.25325 .68661 m .25625 .62957 L .22509 .62698 L p .707 .577 .707 r
F P
0 g
s
.25625 .62957 m .25325 .68661 L .28503 .68783 L p .707 .577 .707 r
F P
0 g
s
.28503 .68783 m .28803 .63078 L .25625 .62957 L p .707 .577 .707 r
F P
0 g
s
.28803 .63078 m .28503 .68783 L .31433 .68755 L p .707 .577 .707 r
F P
0 g
s
.31433 .68755 m .31733 .6305 L .28803 .63078 L p .707 .577 .707 r
F P
0 g
s
.70435 .83744 m .70241 .85657 L .69912 .85573 L p .707 .577 .707 r
F P
0 g
s
.69912 .85573 m .70106 .83659 L .70435 .83744 L p .707 .577 .707 r
F P
0 g
s
.22209 .68403 m .22509 .62698 L .19762 .62328 L p .707 .577 .707 r
F P
0 g
s
.22509 .62698 m .22209 .68403 L .25325 .68661 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19762 .62328 m .19462 .68032 L .22209 .68403 L p .707 .577 .707 r
F P
0 g
s
.70182 .75785 m .69712 .79599 L .68406 .79559 L p .707 .577 .707 r
F P
0 g
s
.31733 .6305 m .31433 .68755 L .33828 .68581 L p .707 .577 .707 r
F P
0 g
s
.33828 .68581 m .34128 .62876 L .31733 .6305 L p .707 .577 .707 r
F P
0 g
s
.60964 .30869 m .6169 .80535 L .63999 .79335 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .63273 .29668 L .60964 .30869 L p .707 .577 .707 r
F P
0 g
s
.68406 .79559 m .68876 .75744 L .70182 .75785 L p .707 .577 .707 r
F P
0 g
s
.22516 .69956 m .22046 .73771 L .25153 .74126 L p .707 .577 .707 r
F P
0 g
s
.25153 .74126 m .25623 .70312 L .22516 .69956 L p .707 .577 .707 r
F P
0 g
s
.25623 .70312 m .25153 .74126 L .28307 .74528 L p .707 .577 .707 r
F P
0 g
s
.28307 .74528 m .28777 .70714 L .25623 .70312 L p .707 .577 .707 r
F P
0 g
s
.28777 .70714 m .28307 .74528 L .31198 .74938 L p .707 .577 .707 r
F P
0 g
s
.19462 .68032 m .19762 .62328 L .17651 .61881 L p .707 .577 .707 r
F P
0 g
s
.69183 .64909 m .68883 .70614 L .66773 .70168 L p .707 .577 .707 r
F P
0 g
s
.66773 .70168 m .67072 .64463 L .69183 .64909 L p .707 .577 .707 r
F P
0 g
s
.31198 .74938 m .31668 .71123 L .28777 .70714 L p .707 .577 .707 r
F P
0 g
s
.1976 .69682 m .1929 .73497 L .22046 .73771 L p .707 .577 .707 r
F P
0 g
s
.22046 .73771 m .22516 .69956 L .1976 .69682 L p .707 .577 .707 r
F P
0 g
s
.17651 .61881 m .17351 .67586 L .19462 .68032 L p .707 .577 .707 r
F P
0 g
s
.38403 .80379 m .37677 .30713 L .35899 .29485 L p .707 .577 .707 r
F P
0 g
s
.37677 .30713 m .38403 .80379 L .41377 .81364 L p .707 .577 .707 r
F P
0 g
s
.31668 .71123 m .31198 .74938 L .33545 .75315 L p .707 .577 .707 r
F P
0 g
s
.70106 .83659 m .69912 .85573 L .68622 .85395 L p .707 .577 .707 r
F P
0 g
s
.68622 .85395 m .68815 .83482 L .70106 .83659 L p .707 .577 .707 r
F P
0 g
s
.33545 .75315 m .34015 .715 L .31668 .71123 L p .707 .577 .707 r
F P
0 g
s
.34128 .62876 m .33828 .68581 L .35453 .68277 L p .707 .577 .707 r
F P
0 g
s
.35453 .68277 m .35753 .62573 L .34128 .62876 L p .707 .577 .707 r
F P
0 g
s
.25247 .8105 m .2544 .79137 L .2233 .78812 L p .707 .577 .707 r
F P
0 g
s
.2544 .79137 m .25247 .8105 L .2841 .81365 L p .707 .577 .707 r
F P
0 g
s
.2841 .81365 m .28604 .79452 L .2544 .79137 L p .707 .577 .707 r
F P
0 g
s
.2233 .78812 m .22137 .80725 L .25247 .8105 L p .707 .577 .707 r
F P
0 g
s
.17624 .69517 m .17155 .73331 L .1929 .73497 L p .707 .577 .707 r
F P
0 g
s
.1929 .73497 m .1976 .69682 L .17624 .69517 L p .707 .577 .707 r
F P
0 g
s
.28604 .79452 m .2841 .81365 L .31317 .81638 L p .707 .577 .707 r
F P
0 g
s
.31317 .81638 m .31511 .79724 L .28604 .79452 L p .707 .577 .707 r
F P
0 g
s
.68876 .75744 m .68406 .79559 L .6627 .79393 L p .707 .577 .707 r
F P
0 g
s
.6627 .79393 m .6674 .75579 L .68876 .75744 L p .707 .577 .707 r
F P
0 g
s
.17351 .67586 m .17651 .61881 L .16383 .61403 L p .707 .577 .707 r
F P
0 g
s
.22137 .80725 m .2233 .78812 L .19577 .78508 L p .707 .577 .707 r
F P
0 g
s
.19577 .78508 m .19384 .80421 L .22137 .80725 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64272 .28327 L .63273 .29668 L p .707 .577 .707 r
F P
0 g
s
.16383 .61403 m .16083 .67108 L .17351 .67586 L p .707 .577 .707 r
F P
0 g
s
.34015 .715 m .33545 .75315 L .35116 .75622 L p .707 .577 .707 r
F P
0 g
s
.31511 .79724 m .31317 .81638 L .33683 .81842 L p .707 .577 .707 r
F P
0 g
s
.33683 .81842 m .33876 .79929 L .31511 .79724 L p .707 .577 .707 r
F P
0 g
s
.35116 .75622 m .35586 .71808 L .34015 .715 L p .707 .577 .707 r
F P
0 g
s
.19384 .80421 m .19577 .78508 L .17452 .78255 L p .707 .577 .707 r
F P
0 g
s
.17452 .78255 m .17258 .80168 L .19384 .80421 L p .707 .577 .707 r
F P
0 g
s
.35753 .62573 m .35453 .68277 L .3615 .67874 L p .707 .577 .707 r
F P
0 g
s
.3615 .67874 m .3645 .62169 L .35753 .62573 L p .707 .577 .707 r
F P
0 g
s
.16318 .69476 m .15849 .73291 L .17155 .73331 L p .707 .577 .707 r
F P
0 g
s
.17155 .73331 m .17624 .69517 L .16318 .69476 L p .707 .577 .707 r
F P
0 g
s
.68815 .83482 m .68622 .85395 L .66496 .85142 L p .707 .577 .707 r
F P
0 g
s
.66496 .85142 m .66689 .83228 L .68815 .83482 L p .707 .577 .707 r
F P
0 g
s
.3645 .62169 m .3615 .67874 L .3585 .67411 L p .707 .577 .707 r
F P
0 g
s
.3585 .67411 m .3615 .61706 L .3645 .62169 L p .707 .577 .707 r
F P
0 g
s
.36625 .79152 m .35899 .29485 L .35489 .28134 L p .707 .577 .707 r
F P
0 g
s
.35899 .29485 m .36625 .79152 L .38403 .80379 L p .707 .577 .707 r
F P
0 g
s
.54756 .82012 m .54563 .83925 L .52197 .8372 L p .707 .577 .707 r
F P
0 g
s
.16083 .67108 m .16383 .61403 L .16083 .6094 L p .707 .577 .707 r
F P
0 g
s
.33876 .79929 m .33683 .81842 L .35276 .81959 L p .707 .577 .707 r
F P
0 g
s
.35276 .81959 m .35469 .80046 L .33876 .79929 L p .707 .577 .707 r
F P
0 g
s
.16083 .6094 m .15783 .66644 L .16083 .67108 L p .707 .577 .707 r
F P
0 g
s
.35586 .71808 m .35116 .75622 L .35759 .7583 L p .707 .577 .707 r
F P
0 g
s
.35759 .7583 m .36229 .72016 L .35586 .71808 L p .707 .577 .707 r
F P
0 g
s
.17258 .80168 m .17452 .78255 L .16161 .78077 L p .707 .577 .707 r
F P
0 g
s
.16161 .78077 m .15968 .7999 L .17258 .80168 L p .707 .577 .707 r
F P
0 g
s
.66689 .83228 m .66496 .85142 L .63743 .84838 L p .707 .577 .707 r
F P
0 g
s
.63743 .84838 m .63937 .82924 L .66689 .83228 L p .707 .577 .707 r
F P
0 g
s
.1597 .69564 m .155 .73378 L .15849 .73291 L p .707 .577 .707 r
F P
0 g
s
.15849 .73291 m .16318 .69476 L .1597 .69564 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64769 .77239 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64272 .28327 m .64964 .75634 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64964 .75634 m .64998 .77993 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64564 .72985 m .64272 .28327 L .6476 .76343 L .707 .577 .707 r
F
.64655 .74877 m .6476 .76343 L .64769 .77239 L F
.64564 .72985 m .6476 .76343 L .64655 .74877 L F
.63862 .26976 m .64272 .28327 L p .6451 .64759 L F P
0 g
s
.64431 .64561 m .63862 .26976 L .6451 .64759 L .707 .577 .707 r
F
.64538 .73238 m .63862 .26976 L p .64569 .73662 L F P
0 g
s
.63862 .26976 m .64588 .76643 L .6281 .75415 L p .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64104 .5794 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64105 .64108 m .64121 .6379 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64404 .58403 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64569 .73662 m .64431 .64561 L .6451 .64759 L .707 .577 .707 r
F
.64588 .76643 m .64538 .73238 L p .64569 .73662 L F P
0 g
s
.64182 .68377 m .63989 .7029 L .64331 .70337 L p .707 .577 .707 r
F P
0 g
s
.64331 .70337 m .65279 .70468 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.64193 .68397 m .64182 .68377 L .64331 .70337 L .707 .577 .707 r
F
.65279 .70468 m .65473 .68554 L .64192 .68378 L p F P
0 g
s
.64192 .68378 m .64182 .68377 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.65279 .70468 m .64192 .68378 L .64193 .68397 L .707 .577 .707 r
F
.64137 .6412 m .65372 .64586 L p .64121 .6379 L F P
0 g
s
.6434 .64159 m .64149 .65704 L p .65176 .68014 L .707 .577 .707 r
F P
0 g
s
.64149 .65704 m .6387 .67973 L .64337 .67988 L p .707 .577 .707 r
F P
0 g
s
.64337 .67988 m .65176 .68014 L p .64149 .65704 L .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64121 .6379 L p .65372 .64586 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64105 .64108 L .64137 .6412 L p .707 .577 .707 r
F P
0 g
s
.64769 .77239 m .64588 .76643 L p .64564 .72985 L .707 .577 .707 r
F P
0 g
s
.54563 .83925 m .54756 .82012 L .57663 .82285 L p .707 .577 .707 r
F P
0 g
s
.57663 .82285 m .57469 .84198 L .54563 .83925 L p .707 .577 .707 r
F P
0 g
s
.63937 .82924 m .63743 .84838 L .60633 .84512 L p .707 .577 .707 r
F P
0 g
s
.60633 .84512 m .60826 .82599 L .63937 .82924 L p .707 .577 .707 r
F P
0 g
s
.35469 .80046 m .35276 .81959 L .3594 .81976 L p .707 .577 .707 r
F P
0 g
s
.3594 .81976 m .36134 .80062 L .35469 .80046 L p .707 .577 .707 r
F P
0 g
s
.15783 .66644 m .16083 .6094 L .1678 .60536 L p .707 .577 .707 r
F P
0 g
s
.57469 .84198 m .57663 .82285 L .60826 .82599 L p .707 .577 .707 r
F P
0 g
s
.60826 .82599 m .60633 .84512 L .57469 .84198 L p .707 .577 .707 r
F P
0 g
s
.36229 .72016 m .35759 .7583 L .35411 .75918 L p .707 .577 .707 r
F P
0 g
s
.35411 .75918 m .35881 .72103 L .36229 .72016 L p .707 .577 .707 r
F P
0 g
s
.3615 .61706 m .3585 .67411 L .34583 .66932 L p .707 .577 .707 r
F P
0 g
s
.34583 .66932 m .34882 .61228 L .3615 .61706 L p .707 .577 .707 r
F P
0 g
s
.35489 .28134 m .36215 .77801 L .36625 .79152 L p .707 .577 .707 r
F P
0 g
s
.36215 .77801 m .35489 .28134 L .36488 .26793 L p .707 .577 .707 r
F P
0 g
s
.1678 .60536 m .1648 .66241 L .15783 .66644 L p .707 .577 .707 r
F P
0 g
s
.15968 .7999 m .16161 .78077 L .15832 .77992 L p .707 .577 .707 r
F P
0 g
s
.15832 .77992 m .15638 .79906 L .15968 .7999 L p .707 .577 .707 r
F P
0 g
s
.16613 .69771 m .16143 .73586 L .155 .73378 L p .707 .577 .707 r
F P
0 g
s
.155 .73378 m .1597 .69564 L .16613 .69771 L p .707 .577 .707 r
F P
0 g
s
.36134 .80062 m .3594 .81976 L .35611 .81891 L p .707 .577 .707 r
F P
0 g
s
.35611 .81891 m .35805 .79978 L .36134 .80062 L p .707 .577 .707 r
F P
0 g
s
.1648 .66241 m .1678 .60536 L .18405 .60233 L p .707 .577 .707 r
F P
0 g
s
.6281 .75415 m .62084 .25749 L .63862 .26976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18405 .60233 m .18105 .65937 L .1648 .66241 L p .707 .577 .707 r
F P
0 g
s
.35881 .72103 m .35411 .75918 L .34105 .75877 L p .707 .577 .707 r
F P
0 g
s
.15638 .79906 m .15832 .77992 L .16496 .78009 L p .707 .577 .707 r
F P
0 g
s
.16496 .78009 m .16303 .79922 L .15638 .79906 L p .707 .577 .707 r
F P
0 g
s
.34105 .75877 m .34575 .72062 L .35881 .72103 L p .707 .577 .707 r
F P
0 g
s
.34882 .61228 m .34583 .66932 L .32472 .66486 L p .707 .577 .707 r
F P
0 g
s
.32472 .66486 m .32771 .60781 L .34882 .61228 L p .707 .577 .707 r
F P
0 g
s
.37214 .7646 m .36488 .26793 L .38797 .25593 L p .707 .577 .707 r
F P
0 g
s
.36488 .26793 m .37214 .7646 L .36215 .77801 L p .707 .577 .707 r
F P
0 g
s
.18185 .70079 m .17715 .73893 L .16143 .73586 L p .707 .577 .707 r
F P
0 g
s
.16143 .73586 m .16613 .69771 L .18185 .70079 L p .707 .577 .707 r
F P
0 g
s
.18105 .65937 m .18405 .60233 L .208 .60058 L p .707 .577 .707 r
F P
0 g
s
.35805 .79978 m .35611 .81891 L .34321 .81713 L p .707 .577 .707 r
F P
0 g
s
.34321 .81713 m .34514 .798 L .35805 .79978 L p .707 .577 .707 r
F P
0 g
s
.208 .60058 m .205 .65763 L .18105 .65937 L p .707 .577 .707 r
F P
0 g
s
.34575 .72062 m .34105 .75877 L .31969 .75712 L p .707 .577 .707 r
F P
0 g
s
.62084 .25749 m .6281 .75415 L .59836 .7443 L p .707 .577 .707 r
F P
0 g
s
.59836 .7443 m .5911 .24764 L .62084 .25749 L p .707 .577 .707 r
F P
0 g
s
.31969 .75712 m .32439 .71897 L .34575 .72062 L p .707 .577 .707 r
F P
0 g
s
.16303 .79922 m .16496 .78009 L .18089 .78126 L p .707 .577 .707 r
F P
0 g
s
.18089 .78126 m .17896 .80039 L .16303 .79922 L p .707 .577 .707 r
F P
0 g
s
.32771 .60781 m .32472 .66486 L .29724 .66115 L p .707 .577 .707 r
F P
0 g
s
.29724 .66115 m .30024 .60411 L .32771 .60781 L p .707 .577 .707 r
F P
0 g
s
.20531 .70456 m .20061 .7427 L .17715 .73893 L p .707 .577 .707 r
F P
0 g
s
.17715 .73893 m .18185 .70079 L .20531 .70456 L p .707 .577 .707 r
F P
0 g
s
.205 .65763 m .208 .60058 L .2373 .60031 L p .707 .577 .707 r
F P
0 g
s
.38797 .25593 m .39512 .74509 L p .37214 .7646 L .707 .577 .707 r
F P
0 g
s
.39523 .75259 m .38797 .25593 L .42192 .2465 L p .707 .577 .707 r
F P
0 g
s
.42192 .2465 m .42819 .67517 L p .39663 .72619 L .707 .577 .707 r
F P
0 g
s
.42918 .74317 m .42192 .2465 L .46339 .24059 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .47065 .73725 L .42918 .74317 L p .707 .577 .707 r
F P
0 g
s
.42523 .56397 m .42223 .62101 L .43945 .62085 L p .707 .577 .707 r
F P
0 g
s
.43945 .62085 m .45078 .62074 L p .44589 .60988 L .707 .577 .707 r
F P
0 g
s
.44589 .60988 m .42523 .56397 L .43945 .62085 L .707 .577 .707 r
F
.39345 .56275 m .39045 .6198 L .42223 .62101 L p F P
0 g
s
.42223 .62101 m .42523 .56397 L .39345 .56275 L p .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .39343 .61313 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42027 .6553 m .42055 .653 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42055 .653 m .42497 .61715 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .42027 .6553 L .43885 .65793 L p .707 .577 .707 r
F P
0 g
s
.43885 .65793 m .44919 .65939 L p .44378 .64996 L .707 .577 .707 r
F P
0 g
s
.44378 .64996 m .42497 .61715 L .43885 .65793 L .707 .577 .707 r
F
.39523 .75259 m .39663 .72619 L .42852 .69778 L F
.42819 .67517 m .42852 .69778 L p .39663 .72619 L F P
0 g
s
.42852 .69778 m .42918 .74317 L .4142 .74733 L p .707 .577 .707 r
F P
0 g
s
.4142 .74733 m .39523 .75259 L p .42852 .69778 L .707 .577 .707 r
F P
0 g
s
.45078 .62074 m .45153 .62074 L p .45107 .61974 L .707 .577 .707 r
F P
0 g
s
.45107 .61974 m .42523 .56397 L .45078 .62074 L .707 .577 .707 r
F
.39343 .61313 m .38873 .65128 L .41278 .65434 L p F P
0 g
s
.41278 .65434 m .42027 .6553 L p .41439 .64606 L .707 .577 .707 r
F P
0 g
s
.41439 .64606 m .39343 .61313 L .41278 .65434 L .707 .577 .707 r
F
.39512 .74509 m .39523 .75259 L .39349 .7535 L p F P
0 g
s
.39349 .7535 m .37214 .7646 L p .39512 .74509 L .707 .577 .707 r
F P
0 g
s
.2373 .60031 m .2343 .65735 L .205 .65763 L p .707 .577 .707 r
F P
0 g
s
.30024 .60411 m .29724 .66115 L .26609 .65857 L p .707 .577 .707 r
F P
0 g
s
.26609 .65857 m .26908 .60152 L .30024 .60411 L p .707 .577 .707 r
F P
0 g
s
.34514 .798 m .34321 .81713 L .32195 .8146 L p .707 .577 .707 r
F P
0 g
s
.32195 .8146 m .32388 .79547 L .34514 .798 L p .707 .577 .707 r
F P
0 g
s
.2343 .65735 m .2373 .60031 L .26908 .60152 L p .707 .577 .707 r
F P
0 g
s
.32439 .71897 m .31969 .75712 L .29213 .75438 L p .707 .577 .707 r
F P
0 g
s
.29213 .75438 m .29683 .71623 L .32439 .71897 L p .707 .577 .707 r
F P
0 g
s
.26908 .60152 m .26609 .65857 L .2343 .65735 L p .707 .577 .707 r
F P
0 g
s
.73346 .65661 m .73646 .59957 L .7053 .59698 L p .707 .577 .707 r
F P
0 g
s
.73646 .59957 m .73346 .65661 L .76524 .65783 L p .707 .577 .707 r
F P
0 g
s
.76524 .65783 m .76824 .60078 L .73646 .59957 L p .707 .577 .707 r
F P
0 g
s
.23423 .70866 m .22953 .7468 L .20061 .7427 L p .707 .577 .707 r
F P
0 g
s
.20061 .7427 m .20531 .70456 L .23423 .70866 L p .707 .577 .707 r
F P
0 g
s
.17896 .80039 m .18089 .78126 L .20455 .7833 L p .707 .577 .707 r
F P
0 g
s
.20455 .7833 m .20262 .80244 L .17896 .80039 L p .707 .577 .707 r
F P
0 g
s
.76824 .60078 m .76524 .65783 L .78246 .65767 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .73644 .64995 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76328 .69211 m .76356 .68982 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76356 .68982 m .76798 .65397 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.78246 .65767 m .79454 .65755 L p .78925 .64612 L .707 .577 .707 r
F P
0 g
s
.78925 .64612 m .76824 .60078 L .78246 .65767 L .707 .577 .707 r
F
.79454 .65755 m .79754 .6005 L .76824 .60078 L p F P
0 g
s
.5911 .24764 m .59836 .7443 L .5596 .73785 L p .707 .577 .707 r
F P
0 g
s
.5596 .73785 m .55234 .24118 L .5911 .24764 L p .707 .577 .707 r
F P
0 g
s
.70231 .65403 m .7053 .59698 L .67783 .59328 L p .707 .577 .707 r
F P
0 g
s
.7053 .59698 m .70231 .65403 L .73346 .65661 L p .707 .577 .707 r
F P
0 g
s
.29683 .71623 m .29213 .75438 L .26106 .75082 L p .707 .577 .707 r
F P
0 g
s
.70537 .64639 m .70068 .68454 L .73174 .68809 L p .707 .577 .707 r
F P
0 g
s
.73174 .68809 m .73644 .64995 L .70537 .64639 L p .707 .577 .707 r
F P
0 g
s
.73644 .64995 m .73174 .68809 L .76328 .69211 L p .707 .577 .707 r
F P
0 g
s
.26106 .75082 m .26576 .71268 L .29683 .71623 L p .707 .577 .707 r
F P
0 g
s
.26576 .71268 m .26106 .75082 L .22953 .7468 L p .707 .577 .707 r
F P
0 g
s
.22953 .7468 m .23423 .70866 L .26576 .71268 L p .707 .577 .707 r
F P
0 g
s
.67783 .59328 m .67483 .65032 L .70231 .65403 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .76328 .69211 L .7922 .69621 L p .707 .577 .707 r
F P
0 g
s
.79754 .6005 m .79454 .65755 L .81849 .65581 L p .707 .577 .707 r
F P
0 g
s
.81849 .65581 m .82149 .59876 L .79754 .6005 L p .707 .577 .707 r
F P
0 g
s
.32388 .79547 m .32195 .8146 L .29442 .81156 L p .707 .577 .707 r
F P
0 g
s
.29442 .81156 m .29636 .79243 L .32388 .79547 L p .707 .577 .707 r
F P
0 g
s
.7922 .69621 m .79689 .65806 L .76798 .65397 L p .707 .577 .707 r
F P
0 g
s
.67781 .64365 m .67311 .6818 L .70068 .68454 L p .707 .577 .707 r
F P
0 g
s
.70068 .68454 m .70537 .64639 L .67781 .64365 L p .707 .577 .707 r
F P
0 g
s
.73268 .7135 m .73462 .69437 L .70351 .69112 L p .707 .577 .707 r
F P
0 g
s
.73462 .69437 m .73268 .7135 L .76432 .71665 L p .707 .577 .707 r
F P
0 g
s
.76432 .71665 m .76625 .69751 L .73462 .69437 L p .707 .577 .707 r
F P
0 g
s
.70351 .69112 m .70158 .71025 L .73268 .7135 L p .707 .577 .707 r
F P
0 g
s
.67483 .65032 m .67783 .59328 L .65672 .58881 L p .707 .577 .707 r
F P
0 g
s
.20262 .80244 m .20455 .7833 L .23362 .78603 L p .707 .577 .707 r
F P
0 g
s
.23362 .78603 m .23169 .80516 L .20262 .80244 L p .707 .577 .707 r
F P
0 g
s
.76625 .69751 m .76432 .71665 L .79339 .71937 L p .707 .577 .707 r
F P
0 g
s
.79339 .71937 m .79532 .70024 L .76625 .69751 L p .707 .577 .707 r
F P
0 g
s
.55234 .24118 m .5596 .73785 L .51559 .73542 L p .707 .577 .707 r
F P
0 g
s
.51559 .73542 m .50833 .23875 L .55234 .24118 L p .707 .577 .707 r
F P
0 g
s
.70158 .71025 m .70351 .69112 L .67599 .68808 L p .707 .577 .707 r
F P
0 g
s
.67599 .68808 m .67405 .70721 L .70158 .71025 L p .707 .577 .707 r
F P
0 g
s
.79689 .65806 m .7922 .69621 L .81566 .69998 L p .707 .577 .707 r
F P
0 g
s
.81566 .69998 m .82036 .66183 L .79689 .65806 L p .707 .577 .707 r
F P
0 g
s
.65672 .58881 m .65372 .64586 L .67483 .65032 L p .707 .577 .707 r
F P
0 g
s
.29636 .79243 m .29442 .81156 L .26332 .80831 L p .707 .577 .707 r
F P
0 g
s
.26332 .80831 m .26525 .78918 L .29636 .79243 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .50833 .23875 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.47038 .71851 m .46339 .24059 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.45388 .62125 m .45009 .65202 L p .47265 .66316 L .707 .577 .707 r
F P
0 g
s
.45009 .65202 m .44919 .65939 L .45251 .65993 L p .707 .577 .707 r
F P
0 g
s
.45251 .65993 m .47265 .66316 L p .45009 .65202 L .707 .577 .707 r
F P
0 g
s
.47065 .73725 m .47038 .71851 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.65646 .642 m .65176 .68014 L .67311 .6818 L p .707 .577 .707 r
F P
0 g
s
.67311 .6818 m .67781 .64365 L .65646 .642 L p .707 .577 .707 r
F P
0 g
s
.23169 .80516 m .23362 .78603 L .26525 .78918 L p .707 .577 .707 r
F P
0 g
s
.26525 .78918 m .26332 .80831 L .23169 .80516 L p .707 .577 .707 r
F P
0 g
s
.50833 .23875 m .51559 .73542 L .47065 .73725 L p .707 .577 .707 r
F P
0 g
s
.82149 .59876 m .81849 .65581 L .83475 .65277 L p .707 .577 .707 r
F P
0 g
s
.83475 .65277 m .83774 .59573 L .82149 .59876 L p .707 .577 .707 r
F P
0 g
s
.79532 .70024 m .79339 .71937 L .81704 .72142 L p .707 .577 .707 r
F P
0 g
s
.81704 .72142 m .81898 .70229 L .79532 .70024 L p .707 .577 .707 r
F P
0 g
s
.67405 .70721 m .67599 .68808 L .65473 .68554 L p .707 .577 .707 r
F P
0 g
s
.65473 .68554 m .65279 .70468 L .67405 .70721 L p .707 .577 .707 r
F P
0 g
s
.65372 .64586 m .65672 .58881 L .64404 .58403 L p .707 .577 .707 r
F P
0 g
s
.82036 .66183 m .81566 .69998 L .83138 .70305 L p .707 .577 .707 r
F P
0 g
s
.83138 .70305 m .83608 .66491 L .82036 .66183 L p .707 .577 .707 r
F P
0 g
s
.65176 .68014 m .65646 .642 L .6434 .64159 L p .707 .577 .707 r
F P
0 g
s
.81898 .70229 m .81704 .72142 L .83297 .72259 L p .707 .577 .707 r
F P
0 g
s
.83608 .66491 m .83138 .70305 L .83239 .70338 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .83491 .70345 L .8324 .70327 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .8324 .70327 L .83056 .71908 L .707 .577 .707 r
F
.83491 .70345 m .83297 .72259 L .83962 .72275 L p F P
0 g
s
.83962 .72275 m .84155 .70362 L .83491 .70345 L p .707 .577 .707 r
F P
0 g
s
.83239 .70338 m .83781 .70513 L p .83629 .66993 L .707 .577 .707 r
F P
0 g
s
.83629 .66993 m .83608 .66491 L .83239 .70338 L .707 .577 .707 r
F
.8324 .70327 m .81898 .70229 L p .83056 .71908 L F P
0 g
s
.83774 .59573 m .83475 .65277 L .84171 .64874 L p .707 .577 .707 r
F P
0 g
s
.84171 .64874 m .84471 .59169 L .83774 .59573 L p .707 .577 .707 r
F P
0 g
s
.83781 .70513 m .84251 .66699 L .83608 .66491 L p .707 .577 .707 r
F P
0 g
s
.64104 .5794 m .63805 .63644 L .64105 .64108 L p .707 .577 .707 r
F P
0 g
s
.63991 .64247 m .63521 .68061 L .6387 .67973 L p .707 .577 .707 r
F P
0 g
s
.6387 .67973 m .6434 .64159 L .63991 .64247 L p .707 .577 .707 r
F P
0 g
s
.84471 .59169 m .84171 .64874 L .83871 .64411 L p .707 .577 .707 r
F P
0 g
s
.83871 .64411 m .84171 .58706 L .84471 .59169 L p .707 .577 .707 r
F P
0 g
s
.63989 .7029 m .64182 .68377 L .63853 .68292 L p .707 .577 .707 r
F P
0 g
s
.63853 .68292 m .6366 .70205 L .63989 .7029 L p .707 .577 .707 r
F P
0 g
s
.63805 .63644 m .64104 .5794 L .64801 .57536 L p .707 .577 .707 r
F P
0 g
s
.84251 .66699 m .83781 .70513 L .83432 .70601 L p .707 .577 .707 r
F P
0 g
s
.83432 .70601 m .83902 .66786 L .84251 .66699 L p .707 .577 .707 r
F P
0 g
s
.64801 .57536 m .64501 .63241 L .63805 .63644 L p .707 .577 .707 r
F P
0 g
s
.84155 .70362 m .83962 .72275 L .83633 .72191 L p .707 .577 .707 r
F P
0 g
s
.83633 .72191 m .83826 .70277 L .84155 .70362 L p .707 .577 .707 r
F P
0 g
s
.64634 .64454 m .64164 .68269 L .63521 .68061 L p .707 .577 .707 r
F P
0 g
s
.63521 .68061 m .63991 .64247 L .64634 .64454 L p .707 .577 .707 r
F P
0 g
s
.84171 .58706 m .83871 .64411 L .82604 .63932 L p .707 .577 .707 r
F P
0 g
s
.82604 .63932 m .82904 .58228 L .84171 .58706 L p .707 .577 .707 r
F P
0 g
s
.66206 .64762 m .65736 .68576 L .64412 .68317 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .63853 .68292 L .64413 .68306 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .64413 .68306 L .6438 .68613 L .707 .577 .707 r
F
.64412 .68317 m .64164 .68269 L p .64474 .67737 L F P
0 g
s
.64474 .67737 m .66206 .64762 L .64412 .68317 L .707 .577 .707 r
F
.64413 .68306 m .64518 .68309 L p .6438 .68613 L F P
0 g
s
.64518 .68309 m .64324 .70222 L .6366 .70205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39045 .6198 m .39345 .56275 L .36229 .56017 L p .707 .577 .707 r
F P
0 g
s
.45153 .62074 m .45453 .56369 L .42523 .56397 L p .707 .577 .707 r
F P
0 g
s
.64501 .63241 m .64801 .57536 L .66427 .57233 L p .707 .577 .707 r
F P
0 g
s
.3593 .61721 m .36229 .56017 L .33482 .55646 L p .707 .577 .707 r
F P
0 g
s
.36229 .56017 m .3593 .61721 L .39045 .6198 L p .707 .577 .707 r
F P
0 g
s
.83902 .66786 m .83432 .70601 L .82126 .7056 L p .707 .577 .707 r
F P
0 g
s
.82126 .7056 m .82596 .66745 L .83902 .66786 L p .707 .577 .707 r
F P
0 g
s
.36236 .60958 m .35767 .64772 L .38873 .65128 L p .707 .577 .707 r
F P
0 g
s
.38873 .65128 m .39343 .61313 L .36236 .60958 L p .707 .577 .707 r
F P
0 g
s
.66427 .57233 m .66127 .62937 L .64501 .63241 L p .707 .577 .707 r
F P
0 g
s
.33482 .55646 m .33182 .61351 L .3593 .61721 L p .707 .577 .707 r
F P
0 g
s
.45453 .56369 m .45153 .62074 L .47548 .61899 L p .707 .577 .707 r
F P
0 g
s
.47548 .61899 m .47848 .56195 L .45453 .56369 L p .707 .577 .707 r
F P
0 g
s
.44919 .65939 m .45388 .62125 L .42497 .61715 L p .707 .577 .707 r
F P
0 g
s
.83826 .70277 m .83633 .72191 L .82342 .72013 L p .707 .577 .707 r
F P
0 g
s
.82342 .72013 m .82536 .701 L .83826 .70277 L p .707 .577 .707 r
F P
0 g
s
.64164 .68269 m .64634 .64454 L .66206 .64762 L p .707 .577 .707 r
F P
0 g
s
.3348 .60684 m .3301 .64498 L .35767 .64772 L p .707 .577 .707 r
F P
0 g
s
.35767 .64772 m .36236 .60958 L .3348 .60684 L p .707 .577 .707 r
F P
0 g
s
.38967 .67669 m .39161 .65755 L .3605 .6543 L p .707 .577 .707 r
F P
0 g
s
.39161 .65755 m .38967 .67669 L .42131 .67983 L p .707 .577 .707 r
F P
0 g
s
.42131 .67983 m .42324 .6607 L .39161 .65755 L p .707 .577 .707 r
F P
0 g
s
.3605 .6543 m .35857 .67343 L .38967 .67669 L p .707 .577 .707 r
F P
0 g
s
.33182 .61351 m .33482 .55646 L .31371 .552 L p .707 .577 .707 r
F P
0 g
s
.82904 .58228 m .82604 .63932 L .80493 .63486 L p .707 .577 .707 r
F P
0 g
s
.80493 .63486 m .80793 .57781 L .82904 .58228 L p .707 .577 .707 r
F P
0 g
s
.42324 .6607 m .42131 .67983 L .45038 .68256 L p .707 .577 .707 r
F P
0 g
s
.45038 .68256 m .45231 .66343 L .42324 .6607 L p .707 .577 .707 r
F P
0 g
s
.68552 .65139 m .68083 .68953 L .65736 .68576 L p .707 .577 .707 r
F P
0 g
s
.65736 .68576 m .66206 .64762 L .68552 .65139 L p .707 .577 .707 r
F P
0 g
s
.64324 .70222 m .64518 .68309 L .66111 .68425 L p .707 .577 .707 r
F P
0 g
s
.35857 .67343 m .3605 .6543 L .33298 .65126 L p .707 .577 .707 r
F P
0 g
s
.66111 .68425 m .65917 .70339 L .64324 .70222 L p .707 .577 .707 r
F P
0 g
s
.33298 .65126 m .33104 .67039 L .35857 .67343 L p .707 .577 .707 r
F P
0 g
s
.47265 .66316 m .47735 .62502 L .45388 .62125 L p .707 .577 .707 r
F P
0 g
s
.31371 .552 m .31071 .60904 L .33182 .61351 L p .707 .577 .707 r
F P
0 g
s
.66127 .62937 m .66427 .57233 L .68822 .57058 L p .707 .577 .707 r
F P
0 g
s
.31345 .60518 m .30875 .64333 L .3301 .64498 L p .707 .577 .707 r
F P
0 g
s
.3301 .64498 m .3348 .60684 L .31345 .60518 L p .707 .577 .707 r
F P
0 g
s
.47848 .56195 m .47548 .61899 L .49174 .61596 L p .707 .577 .707 r
F P
0 g
s
.49174 .61596 m .49473 .55891 L .47848 .56195 L p .707 .577 .707 r
F P
0 g
s
.82596 .66745 m .82126 .7056 L .79991 .70394 L p .707 .577 .707 r
F P
0 g
s
.45231 .66343 m .45038 .68256 L .47403 .68461 L p .707 .577 .707 r
F P
0 g
s
.47403 .68461 m .47597 .66547 L .45231 .66343 L p .707 .577 .707 r
F P
0 g
s
.79991 .70394 m .80461 .6658 L .82596 .66745 L p .707 .577 .707 r
F P
0 g
s
.68822 .57058 m .68522 .62763 L .66127 .62937 L p .707 .577 .707 r
F P
0 g
s
.33104 .67039 m .33298 .65126 L .31172 .64873 L p .707 .577 .707 r
F P
0 g
s
.31172 .64873 m .30978 .66786 L .33104 .67039 L p .707 .577 .707 r
F P
0 g
s
.31071 .60904 m .31371 .552 L .30103 .54721 L p .707 .577 .707 r
F P
0 g
s
.82536 .701 m .82342 .72013 L .80216 .7176 L p .707 .577 .707 r
F P
0 g
s
.80216 .7176 m .8041 .69847 L .82536 .701 L p .707 .577 .707 r
F P
0 g
s
.80793 .57781 m .80493 .63486 L .77745 .63115 L p .707 .577 .707 r
F P
0 g
s
.77745 .63115 m .78045 .57411 L .80793 .57781 L p .707 .577 .707 r
F P
0 g
s
.47735 .62502 m .47265 .66316 L .48837 .66624 L p .707 .577 .707 r
F P
0 g
s
.48837 .66624 m .49307 .62809 L .47735 .62502 L p .707 .577 .707 r
F P
0 g
s
.68522 .62763 m .68822 .57058 L .71752 .57031 L p .707 .577 .707 r
F P
0 g
s
.30103 .54721 m .29804 .60426 L .31071 .60904 L p .707 .577 .707 r
F P
0 g
s
.71444 .65548 m .70974 .69363 L .68083 .68953 L p .707 .577 .707 r
F P
0 g
s
.68083 .68953 m .68552 .65139 L .71444 .65548 L p .707 .577 .707 r
F P
0 g
s
.65917 .70339 m .66111 .68425 L .68477 .6863 L p .707 .577 .707 r
F P
0 g
s
.68477 .6863 m .68283 .70543 L .65917 .70339 L p .707 .577 .707 r
F P
0 g
s
.30039 .60477 m .29569 .64292 L .30875 .64333 L p .707 .577 .707 r
F P
0 g
s
.30875 .64333 m .31345 .60518 L .30039 .60477 L p .707 .577 .707 r
F P
0 g
s
.47597 .66547 m .47403 .68461 L .48996 .68577 L p .707 .577 .707 r
F P
0 g
s
.49307 .62809 m .48837 .66624 L .48938 .66656 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .4919 .66664 L .48939 .66645 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .48939 .66645 L .48755 .68227 L .707 .577 .707 r
F
.4919 .66664 m .48996 .68577 L .49661 .68594 L p F P
0 g
s
.49661 .68594 m .49854 .6668 L .4919 .66664 L p .707 .577 .707 r
F P
0 g
s
.48938 .66656 m .4948 .66832 L p .49328 .63312 L .707 .577 .707 r
F P
0 g
s
.49328 .63312 m .49307 .62809 L .48938 .66656 L .707 .577 .707 r
F
.48939 .66645 m .47597 .66547 L p .48755 .68227 L F P
0 g
s
.80461 .6658 m .79991 .70394 L .77235 .70121 L p .707 .577 .707 r
F P
0 g
s
.71752 .57031 m .71452 .62735 L .68522 .62763 L p .707 .577 .707 r
F P
0 g
s
.77235 .70121 m .77705 .66306 L .80461 .6658 L p .707 .577 .707 r
F P
0 g
s
.78045 .57411 m .77745 .63115 L .7463 .62857 L p .707 .577 .707 r
F P
0 g
s
.7463 .62857 m .7493 .57152 L .78045 .57411 L p .707 .577 .707 r
F P
0 g
s
.49473 .55891 m .49174 .61596 L .4987 .61193 L p .707 .577 .707 r
F P
0 g
s
.4987 .61193 m .5017 .55488 L .49473 .55891 L p .707 .577 .707 r
F P
0 g
s
.71452 .62735 m .71752 .57031 L .7493 .57152 L p .707 .577 .707 r
F P
0 g
s
.30978 .66786 m .31172 .64873 L .29881 .64695 L p .707 .577 .707 r
F P
0 g
s
.29881 .64695 m .29688 .66608 L .30978 .66786 L p .707 .577 .707 r
F P
0 g
s
.7493 .57152 m .7463 .62857 L .71452 .62735 L p .707 .577 .707 r
F P
0 g
s
.8041 .69847 m .80216 .7176 L .77464 .71456 L p .707 .577 .707 r
F P
0 g
s
.77464 .71456 m .77657 .69542 L .8041 .69847 L p .707 .577 .707 r
F P
0 g
s
.29804 .60426 m .30103 .54721 L .29803 .54258 L p .707 .577 .707 r
F P
0 g
s
.70974 .69363 m .71444 .65548 L .74598 .65951 L p .707 .577 .707 r
F P
0 g
s
.68283 .70543 m .68477 .6863 L .71383 .68903 L p .707 .577 .707 r
F P
0 g
s
.74598 .65951 m .74128 .69765 L .70974 .69363 L p .707 .577 .707 r
F P
0 g
s
.71383 .68903 m .7119 .70816 L .68283 .70543 L p .707 .577 .707 r
F P
0 g
s
.77705 .66306 m .77235 .70121 L .74128 .69765 L p .707 .577 .707 r
F P
0 g
s
.74128 .69765 m .74598 .65951 L .77705 .66306 L p .707 .577 .707 r
F P
0 g
s
.4948 .66832 m .4995 .63017 L .49307 .62809 L p .707 .577 .707 r
F P
0 g
s
.29803 .54258 m .29504 .59963 L .29804 .60426 L p .707 .577 .707 r
F P
0 g
s
.77657 .69542 m .77464 .71456 L .74353 .71131 L p .707 .577 .707 r
F P
0 g
s
.74353 .71131 m .74547 .69217 L .77657 .69542 L p .707 .577 .707 r
F P
0 g
s
.2969 .60565 m .2922 .6438 L .29569 .64292 L p .707 .577 .707 r
F P
0 g
s
.29569 .64292 m .30039 .60477 L .2969 .60565 L p .707 .577 .707 r
F P
0 g
s
.7119 .70816 m .71383 .68903 L .74547 .69217 L p .707 .577 .707 r
F P
0 g
s
.74547 .69217 m .74353 .71131 L .7119 .70816 L p .707 .577 .707 r
F P
0 g
s
.5017 .55488 m .4987 .61193 L .4957 .60729 L p .707 .577 .707 r
F P
0 g
s
.4957 .60729 m .4987 .55024 L .5017 .55488 L p .707 .577 .707 r
F P
0 g
s
.29688 .66608 m .29881 .64695 L .29552 .64611 L p .707 .577 .707 r
F P
0 g
s
.29552 .64611 m .29359 .66524 L .29688 .66608 L p .707 .577 .707 r
F P
0 g
s
.29504 .59963 m .29803 .54258 L .305 .53855 L p .707 .577 .707 r
F P
0 g
s
.4995 .63017 m .4948 .66832 L .49131 .66919 L p .707 .577 .707 r
F P
0 g
s
.49131 .66919 m .49601 .63105 L .4995 .63017 L p .707 .577 .707 r
F P
0 g
s
.305 .53855 m .302 .59559 L .29504 .59963 L p .707 .577 .707 r
F P
0 g
s
.49854 .6668 m .49661 .68594 L .49332 .68509 L p .707 .577 .707 r
F P
0 g
s
.49332 .68509 m .49525 .66596 L .49854 .6668 L p .707 .577 .707 r
F P
0 g
s
.30333 .60773 m .29863 .64587 L .2922 .6438 L p .707 .577 .707 r
F P
0 g
s
.2922 .6438 m .2969 .60565 L .30333 .60773 L p .707 .577 .707 r
F P
0 g
s
.4987 .55024 m .4957 .60729 L .48303 .60251 L p .707 .577 .707 r
F P
0 g
s
.48303 .60251 m .48603 .54546 L .4987 .55024 L p .707 .577 .707 r
F P
0 g
s
.31905 .6108 m .31435 .64895 L .30111 .64636 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .29552 .64611 L .30112 .64625 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .30112 .64625 L .30079 .64931 L .707 .577 .707 r
F
.30111 .64636 m .29863 .64587 L p .30173 .64055 L F P
0 g
s
.30173 .64055 m .31905 .6108 L .30111 .64636 L .707 .577 .707 r
F
.30112 .64625 m .30217 .64627 L p .30079 .64931 L F P
0 g
s
.30217 .64627 m .30023 .66541 L .29359 .66524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.302 .59559 m .305 .53855 L .32126 .53551 L p .707 .577 .707 r
F P
0 g
s
.49601 .63105 m .49131 .66919 L .47825 .66878 L p .707 .577 .707 r
F P
0 g
s
.47825 .66878 m .48295 .63064 L .49601 .63105 L p .707 .577 .707 r
F P
0 g
s
.32126 .53551 m .31826 .59256 L .302 .59559 L p .707 .577 .707 r
F P
0 g
s
.49525 .66596 m .49332 .68509 L .48041 .68332 L p .707 .577 .707 r
F P
0 g
s
.48041 .68332 m .48235 .66418 L .49525 .66596 L p .707 .577 .707 r
F P
0 g
s
.29863 .64587 m .30333 .60773 L .31905 .6108 L p .707 .577 .707 r
F P
0 g
s
.48603 .54546 m .48303 .60251 L .46192 .59805 L p .707 .577 .707 r
F P
0 g
s
.46192 .59805 m .46492 .541 L .48603 .54546 L p .707 .577 .707 r
F P
0 g
s
.34251 .61457 m .33782 .65272 L .31435 .64895 L p .707 .577 .707 r
F P
0 g
s
.31435 .64895 m .31905 .6108 L .34251 .61457 L p .707 .577 .707 r
F P
0 g
s
.30023 .66541 m .30217 .64627 L .3181 .64744 L p .707 .577 .707 r
F P
0 g
s
.3181 .64744 m .31616 .66657 L .30023 .66541 L p .707 .577 .707 r
F P
0 g
s
.31826 .59256 m .32126 .53551 L .3452 .53377 L p .707 .577 .707 r
F P
0 g
s
.48295 .63064 m .47825 .66878 L .4569 .66713 L p .707 .577 .707 r
F P
0 g
s
.4569 .66713 m .4616 .62898 L .48295 .63064 L p .707 .577 .707 r
F P
0 g
s
.3452 .53377 m .34221 .59082 L .31826 .59256 L p .707 .577 .707 r
F P
0 g
s
.48235 .66418 m .48041 .68332 L .45915 .68078 L p .707 .577 .707 r
F P
0 g
s
.45915 .68078 m .46109 .66165 L .48235 .66418 L p .707 .577 .707 r
F P
0 g
s
.46492 .541 m .46192 .59805 L .43444 .59434 L p .707 .577 .707 r
F P
0 g
s
.43444 .59434 m .43744 .53729 L .46492 .541 L p .707 .577 .707 r
F P
0 g
s
.34221 .59082 m .3452 .53377 L .3745 .53349 L p .707 .577 .707 r
F P
0 g
s
.37143 .61867 m .36673 .65681 L .33782 .65272 L p .707 .577 .707 r
F P
0 g
s
.33782 .65272 m .34251 .61457 L .37143 .61867 L p .707 .577 .707 r
F P
0 g
s
.31616 .66657 m .3181 .64744 L .34175 .64948 L p .707 .577 .707 r
F P
0 g
s
.34175 .64948 m .33982 .66862 L .31616 .66657 L p .707 .577 .707 r
F P
0 g
s
.4616 .62898 m .4569 .66713 L .42934 .66439 L p .707 .577 .707 r
F P
0 g
s
.3745 .53349 m .37151 .59054 L .34221 .59082 L p .707 .577 .707 r
F P
0 g
s
.42934 .66439 m .43403 .62625 L .4616 .62898 L p .707 .577 .707 r
F P
0 g
s
.43744 .53729 m .43444 .59434 L .40329 .59175 L p .707 .577 .707 r
F P
0 g
s
.40329 .59175 m .40629 .53471 L .43744 .53729 L p .707 .577 .707 r
F P
0 g
s
.37151 .59054 m .3745 .53349 L .40629 .53471 L p .707 .577 .707 r
F P
0 g
s
.40629 .53471 m .40329 .59175 L .37151 .59054 L p .707 .577 .707 r
F P
0 g
s
.46109 .66165 m .45915 .68078 L .43163 .67774 L p .707 .577 .707 r
F P
0 g
s
.43163 .67774 m .43356 .65861 L .46109 .66165 L p .707 .577 .707 r
F P
0 g
s
.36673 .65681 m .37143 .61867 L .40297 .62269 L p .707 .577 .707 r
F P
0 g
s
.33982 .66862 m .34175 .64948 L .37082 .65221 L p .707 .577 .707 r
F P
0 g
s
.40297 .62269 m .39827 .66084 L .36673 .65681 L p .707 .577 .707 r
F P
0 g
s
.37082 .65221 m .36889 .67135 L .33982 .66862 L p .707 .577 .707 r
F P
0 g
s
.43403 .62625 m .42934 .66439 L .39827 .66084 L p .707 .577 .707 r
F P
0 g
s
.39827 .66084 m .40297 .62269 L .43403 .62625 L p .707 .577 .707 r
F P
0 g
s
.43356 .65861 m .43163 .67774 L .40052 .67449 L p .707 .577 .707 r
F P
0 g
s
.40052 .67449 m .40246 .65536 L .43356 .65861 L p .707 .577 .707 r
F P
0 g
s
.36889 .67135 m .37082 .65221 L .40246 .65536 L p .707 .577 .707 r
F P
0 g
s
.40246 .65536 m .40052 .67449 L .36889 .67135 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002:Ool=0026Ool0085oo`T0
00IJEP03001JEUYF00AJEPT007eoo`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001eOol60008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol0075oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEP00001aOol006ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Mo
o`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Io
o`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005mooa4000QJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Aoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001F
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0I7oo001DOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo009ooah004Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003aoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0031oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Goo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001COol00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol@000;Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH70003FUH00`00
FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol60003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF00000003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo000_Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH?0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000]Ool30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF1P0000=JEP00FUH0
0UYF20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF1`000UYF
00@005YFFUIJEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP04001JEUYFFUH7
0003FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040008FUH00`00FUIJEP02FUH=0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPL00003FUH005YF00MJEP03001JEUYF
00H000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`0000AJEP00FUIJEP<000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF7P0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH0200015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00P0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF1@00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00H0009JEQ0000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF1@0000=JEP00FUH01UYF00<005YFFUH00UYF
2@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF2@000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YFFUH005YF0004FUH00`00FUIJEP0800000eYF001JEP07FUH00`00FUIJEP02FUH60005FUH0
0`00FUIJEP04FUH00`00FUIJEP04000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0000=JEP00FUH01eYF00<005YF00003P00<Woo000/Ool00`00FUH00002
FUH?0007FUH90003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00=JEPH003Moo`00;7oo00<005YF00000`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPh000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00@005YFFUIJEPD0039oo`00;7oo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH@000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000A0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
0UYF2P000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000dOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP<00003FUH0000000L0009JEPL000=JEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00UYF1@001UYF0P0000=J
EP000000400015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00A7oo7`000goo00@005YFFUH000AJEPD000IJEP8000YJEP04001J
EUYFFUH50004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001VOol01000FUIJEP0015YF1@001UYF0P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000]Ool8000aOol01000FUIJEP001EYF0`001eYF0P002UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`@00004FUH005YFFUH?000ROol01000FUIJEP001UYF00<005YFFUH01UYF
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70002FUH01000FUIJEUYF0P00;Woo000]Ool01000FUH005YF1P0000=JEP00FUH01UYF
00@005YFFUIJEPL001]oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000040002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08
000^Ool002eoo`03001JEP0000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04
000GOol01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<0
05YFFUH015YF00@005YFFUIJEPT00003FUH005YF00EJEPL0011oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH005YF4`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH00eYF1`002Goo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEP0000IJEP03001JEUYF009JEP<000=oo``000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP060003Ool01000FUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH00UYF00<005YF000027oo0`0000=oo`000000
2@000eYF00<005YFFUH015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3`000UYF00<005YF
FUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH0100027oo1@0027oo3`00
00=JEP000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH<000<Ool5000@Ool:000^Ool002aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`0EOol50018Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF
000@FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`0FOol30019Ool002aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol002eoo`<0009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP06FUHO0008FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol0031oo`H000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0>FUH00`00FUIJEP06000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003Ioo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP040006FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003eoo`T000AJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF
00<005YFFUH00eYF1`00GWoo0016Ool90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`000UYF00<005YFFUH015YF00H005YF000005YF000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEP000eYF1@00FGoo
001?Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@0
05YF000000EJEPP0009JEP03001JEP00008005Ioo`00Egoo40000UYF00@005YFFUIJEP8000IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP09001DOol006Ioo`05001JEUYF001JEP03
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
001VOol00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol004Qoo`<001]oo`<0
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0017Ool5000JOol30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00;Goo10005Woo1@006Woo00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol002eoo`80009JEPd000Uoo`D001Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP03001J
EUYF00AJEP04001JEUYFFUH9000017oo0000000077oo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200047oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01`000eYF00@005YFFUIJEP8005Eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEP`000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH2000:Ool9001EOol0
02aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00008000Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF001ZOol003Aooa8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000Ioo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<006]oo`00
>goo20000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP<006eoo`00@goo2@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000Yoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0071oo`00
C7oo2@000UYF1`000eYF00@005YFFUIJEP8000eoo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEPD00003Ool0000000<006moo`00EGoo4P004Goo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00@005YFFUIJEPH000Ioo`D006moo`00HWoo1@005goo:P0000=oo`0000000`00
Kgoo002>Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001/
Ool008eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPP006Aoo`00SGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL005eoo`00SGoo1@000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH02000EGoo
002@Ool?0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo002EOol70003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002LOolE0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH005Aoo`00[Woo2`0015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo002fOol?
00000eYF0000001EOol00;ioo`X005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59612 .73349 m .59798 .67687 L .56681 .67455 L p .707 .577 .707 r
F P
0 g
s
.59798 .67687 m .59612 .73349 L .62794 .73394 L p .707 .577 .707 r
F P
0 g
s
.62794 .73394 m .62979 .67732 L .59798 .67687 L p .707 .577 .707 r
F P
0 g
s
.62979 .67732 m .62794 .73394 L .65729 .73247 L p .707 .577 .707 r
F P
0 g
s
.65729 .73247 m .65914 .67585 L .62979 .67732 L p .707 .577 .707 r
F P
0 g
s
.56496 .73117 m .56681 .67455 L .53935 .67058 L p .707 .577 .707 r
F P
0 g
s
.56681 .67455 m .56496 .73117 L .59612 .73349 L p .707 .577 .707 r
F P
0 g
s
.65914 .67585 m .65729 .73247 L .6813 .72922 L p .707 .577 .707 r
F P
0 g
s
.6813 .72922 m .68316 .6726 L .65914 .67585 L p .707 .577 .707 r
F P
0 g
s
.53935 .67058 m .53749 .7272 L .56496 .73117 L p .707 .577 .707 r
F P
0 g
s
.59466 .79056 m .5976 .75233 L .56647 .74941 L p .707 .577 .707 r
F P
0 g
s
.5976 .75233 m .59466 .79056 L .62638 .79274 L p .707 .577 .707 r
F P
0 g
s
.62638 .79274 m .62932 .7545 L .5976 .75233 L p .707 .577 .707 r
F P
0 g
s
.53749 .7272 m .53935 .67058 L .51827 .66535 L p .707 .577 .707 r
F P
0 g
s
.56647 .74941 m .56353 .78764 L .59466 .79056 L p .707 .577 .707 r
F P
0 g
s
.62932 .7545 m .62638 .79274 L .65558 .79396 L p .707 .577 .707 r
F P
0 g
s
.65558 .79396 m .65852 .75572 L .62932 .7545 L p .707 .577 .707 r
F P
0 g
s
.56353 .78764 m .56647 .74941 L .53897 .74603 L p .707 .577 .707 r
F P
0 g
s
.53897 .74603 m .53603 .78427 L .56353 .78764 L p .707 .577 .707 r
F P
0 g
s
.51827 .66535 m .51642 .72197 L .53749 .7272 L p .707 .577 .707 r
F P
0 g
s
.65852 .75572 m .65558 .79396 L .67941 .7941 L p .707 .577 .707 r
F P
0 g
s
.67941 .7941 m .68235 .75587 L .65852 .75572 L p .707 .577 .707 r
F P
0 g
s
.68316 .6726 m .6813 .72922 L .69763 .72452 L p .707 .577 .707 r
F P
0 g
s
.69763 .72452 m .69948 .6679 L .68316 .6726 L p .707 .577 .707 r
F P
0 g
s
.59541 .84916 m .59661 .83009 L .56546 .82736 L p .707 .577 .707 r
F P
0 g
s
.59661 .83009 m .59541 .84916 L .62716 .8508 L p .707 .577 .707 r
F P
0 g
s
.62716 .8508 m .62837 .83173 L .59661 .83009 L p .707 .577 .707 r
F P
0 g
s
.56546 .82736 m .56426 .84643 L .59541 .84916 L p .707 .577 .707 r
F P
0 g
s
.62837 .83173 m .62716 .8508 L .65643 .85117 L p .707 .577 .707 r
F P
0 g
s
.65643 .85117 m .65763 .8321 L .62837 .83173 L p .707 .577 .707 r
F P
0 g
s
.53603 .78427 m .53897 .74603 L .5178 .74253 L p .707 .577 .707 r
F P
0 g
s
.5178 .74253 m .51486 .78077 L .53603 .78427 L p .707 .577 .707 r
F P
0 g
s
.56426 .84643 m .56546 .82736 L .53798 .8238 L p .707 .577 .707 r
F P
0 g
s
.51642 .72197 m .51827 .66535 L .50565 .65937 L p .707 .577 .707 r
F P
0 g
s
.53798 .8238 m .53677 .84287 L .56426 .84643 L p .707 .577 .707 r
F P
0 g
s
.65763 .8321 m .65643 .85117 L .68033 .85025 L p .707 .577 .707 r
F P
0 g
s
.68033 .85025 m .68153 .83118 L .65763 .8321 L p .707 .577 .707 r
F P
0 g
s
.50565 .65937 m .50379 .71599 L .51642 .72197 L p .707 .577 .707 r
F P
0 g
s
.68235 .75587 m .67941 .7941 L .69553 .79316 L p .707 .577 .707 r
F P
0 g
s
.69553 .79316 m .69847 .75492 L .68235 .75587 L p .707 .577 .707 r
F P
0 g
s
.53677 .84287 m .53798 .8238 L .51685 .81976 L p .707 .577 .707 r
F P
0 g
s
.69948 .6679 m .69763 .72452 L .70467 .71882 L p .707 .577 .707 r
F P
0 g
s
.70467 .71882 m .70652 .6622 L .69948 .6679 L p .707 .577 .707 r
F P
0 g
s
.51685 .81976 m .51564 .83883 L .53677 .84287 L p .707 .577 .707 r
F P
0 g
s
.51486 .78077 m .5178 .74253 L .50503 .73925 L p .707 .577 .707 r
F P
0 g
s
.50503 .73925 m .50209 .77748 L .51486 .78077 L p .707 .577 .707 r
F P
0 g
s
.50379 .71599 m .50565 .65937 L .50271 .65324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83118 m .68033 .85025 L .69653 .84813 L p .707 .577 .707 r
F P
0 g
s
.69653 .84813 m .69773 .82906 L .68153 .83118 L p .707 .577 .707 r
F P
0 g
s
.69847 .75492 m .69553 .79316 L .70236 .79121 L p .707 .577 .707 r
F P
0 g
s
.70236 .79121 m .7053 .75298 L .69847 .75492 L p .707 .577 .707 r
F P
0 g
s
.51564 .83883 m .51685 .81976 L .50413 .81563 L p .707 .577 .707 r
F P
0 g
s
.50271 .65324 m .50086 .70985 L .50379 .71599 L p .707 .577 .707 r
F P
0 g
s
.50413 .81563 m .50293 .8347 L .51564 .83883 L p .707 .577 .707 r
F P
0 g
s
.70652 .6622 m .70467 .71882 L .70173 .71268 L p .707 .577 .707 r
F P
0 g
s
.70173 .71268 m .70359 .65606 L .70652 .6622 L p .707 .577 .707 r
F P
0 g
s
.50209 .77748 m .50503 .73925 L .5019 .7365 L p .707 .577 .707 r
F P
0 g
s
.5019 .7365 m .49896 .77473 L .50209 .77748 L p .707 .577 .707 r
F P
0 g
s
.4942 .82231 m .48971 .32357 L .4457 .32104 L p .707 .577 .707 r
F P
0 g
s
.50086 .70985 m .50271 .65324 L .50975 .64754 L p .707 .577 .707 r
F P
0 g
s
.50293 .8347 m .50413 .81563 L .50109 .81182 L p .707 .577 .707 r
F P
0 g
s
.50109 .81182 m .49988 .83089 L .50293 .8347 L p .707 .577 .707 r
F P
0 g
s
.50975 .64754 m .50789 .70415 L .50086 .70985 L p .707 .577 .707 r
F P
0 g
s
.49896 .77473 m .5019 .7365 L .50873 .73456 L p .707 .577 .707 r
F P
0 g
s
.50873 .73456 m .5058 .77279 L .49896 .77473 L p .707 .577 .707 r
F P
0 g
s
.50789 .70415 m .50975 .64754 L .52608 .64283 L p .707 .577 .707 r
F P
0 g
s
.49988 .83089 m .50109 .81182 L .508 .80869 L p .707 .577 .707 r
F P
0 g
s
.52608 .64283 m .52422 .69945 L .50789 .70415 L p .707 .577 .707 r
F P
0 g
s
.508 .80869 m .5068 .82776 L .49988 .83089 L p .707 .577 .707 r
F P
0 g
s
.5058 .77279 m .50873 .73456 L .52485 .73361 L p .707 .577 .707 r
F P
0 g
s
.52485 .73361 m .52192 .77185 L .5058 .77279 L p .707 .577 .707 r
F P
0 g
s
.52422 .69945 m .52608 .64283 L .55009 .63959 L p .707 .577 .707 r
F P
0 g
s
.55009 .63959 m .54823 .6962 L .52422 .69945 L p .707 .577 .707 r
F P
0 g
s
.5068 .82776 m .508 .80869 L .5242 .80657 L p .707 .577 .707 r
F P
0 g
s
.5242 .80657 m .523 .82564 L .5068 .82776 L p .707 .577 .707 r
F P
0 g
s
.52192 .77185 m .52485 .73361 L .54868 .73376 L p .707 .577 .707 r
F P
0 g
s
.54868 .73376 m .54574 .77199 L .52192 .77185 L p .707 .577 .707 r
F P
0 g
s
.523 .82564 m .5242 .80657 L .5481 .80565 L p .707 .577 .707 r
F P
0 g
s
.5481 .80565 m .5469 .82472 L .523 .82564 L p .707 .577 .707 r
F P
0 g
s
.48971 .32357 m .4942 .82231 L .53914 .82076 L p .707 .577 .707 r
F P
0 g
s
.53914 .82076 m .53465 .32201 L .48971 .32357 L p .707 .577 .707 r
F P
0 g
s
.69773 .82906 m .69653 .84813 L .70344 .84501 L p .707 .577 .707 r
F P
0 g
s
.70344 .84501 m .70465 .82594 L .69773 .82906 L p .707 .577 .707 r
F P
0 g
s
.54823 .6962 m .55009 .63959 L .57944 .63811 L p .707 .577 .707 r
F P
0 g
s
.57944 .63811 m .57758 .69473 L .54823 .6962 L p .707 .577 .707 r
F P
0 g
s
.54574 .77199 m .54868 .73376 L .57788 .73498 L p .707 .577 .707 r
F P
0 g
s
.57788 .73498 m .57495 .77321 L .54574 .77199 L p .707 .577 .707 r
F P
0 g
s
.57495 .77321 m .57788 .73498 L .6096 .73715 L p .707 .577 .707 r
F P
0 g
s
.6096 .73715 m .60667 .77539 L .57495 .77321 L p .707 .577 .707 r
F P
0 g
s
.5469 .82472 m .5481 .80565 L .57737 .80603 L p .707 .577 .707 r
F P
0 g
s
.57737 .80603 m .57616 .8251 L .5469 .82472 L p .707 .577 .707 r
F P
0 g
s
.57616 .8251 m .57737 .80603 L .60912 .80766 L p .707 .577 .707 r
F P
0 g
s
.53465 .32201 m .53914 .82076 L .58062 .81528 L p .707 .577 .707 r
F P
0 g
s
.57758 .69473 m .57944 .63811 L .61126 .63856 L p .707 .577 .707 r
F P
0 g
s
.61126 .63856 m .6094 .69518 L .57758 .69473 L p .707 .577 .707 r
F P
0 g
s
.58062 .81528 m .57613 .31653 L .53465 .32201 L p .707 .577 .707 r
F P
0 g
s
.45019 .81979 m .4457 .32104 L .40694 .31468 L p .707 .577 .707 r
F P
0 g
s
.4457 .32104 m .45019 .81979 L .4942 .82231 L p .707 .577 .707 r
F P
0 g
s
.7053 .75298 m .70236 .79121 L .69924 .78847 L p .707 .577 .707 r
F P
0 g
s
.69924 .78847 m .70218 .75023 L .7053 .75298 L p .707 .577 .707 r
F P
0 g
s
.64074 .74007 m .6378 .77831 L .61405 .77608 L p .707 .577 .707 r
F P
0 g
s
.61405 .77608 m .60667 .77539 L p .61441 .76736 L .707 .577 .707 r
F P
0 g
s
.61441 .76736 m .64074 .74007 L .61405 .77608 L .707 .577 .707 r
F
.66989 .64485 m .66803 .70147 L .64056 .6975 L p F P
0 g
s
.64056 .6975 m .64242 .64088 L .66989 .64485 L p .707 .577 .707 r
F P
0 g
s
.64242 .64088 m .64056 .6975 L .6094 .69518 L p .707 .577 .707 r
F P
0 g
s
.6094 .69518 m .61126 .63856 L .64242 .64088 L p .707 .577 .707 r
F P
0 g
s
.66823 .74345 m .6653 .78168 L .6378 .77831 L p .707 .577 .707 r
F P
0 g
s
.6378 .77831 m .64074 .74007 L .66823 .74345 L p .707 .577 .707 r
F P
0 g
s
.60667 .77539 m .6096 .73715 L .64074 .74007 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .64767 .78221 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63319 .29627 m .63334 .31324 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63334 .31324 m .63768 .79501 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.60792 .82673 m .60912 .80766 L .64027 .81039 L p .707 .577 .707 r
F P
0 g
s
.60912 .80766 m .60792 .82673 L .57616 .8251 L p .707 .577 .707 r
F P
0 g
s
.57613 .31653 m .58062 .81528 L .61457 .8064 L p .707 .577 .707 r
F P
0 g
s
.61457 .8064 m .61008 .30766 L .57613 .31653 L p .707 .577 .707 r
F P
0 g
s
.70359 .65606 m .70173 .71268 L .68911 .7067 L p .707 .577 .707 r
F P
0 g
s
.68911 .7067 m .69096 .65008 L .70359 .65606 L p .707 .577 .707 r
F P
0 g
s
.25311 .69668 m .25497 .64006 L .2238 .63774 L p .707 .577 .707 r
F P
0 g
s
.25497 .64006 m .25311 .69668 L .28493 .69712 L p .707 .577 .707 r
F P
0 g
s
.28493 .69712 m .28678 .64051 L .25497 .64006 L p .707 .577 .707 r
F P
0 g
s
.41143 .81343 m .40694 .31468 L .37721 .30512 L p .707 .577 .707 r
F P
0 g
s
.40694 .31468 m .41143 .81343 L .45019 .81979 L p .707 .577 .707 r
F P
0 g
s
.70465 .82594 m .70344 .84501 L .70039 .8412 L p .707 .577 .707 r
F P
0 g
s
.70039 .8412 m .7016 .82213 L .70465 .82594 L p .707 .577 .707 r
F P
0 g
s
.28678 .64051 m .28493 .69712 L .31428 .69565 L p .707 .577 .707 r
F P
0 g
s
.31428 .69565 m .31614 .63903 L .28678 .64051 L p .707 .577 .707 r
F P
0 g
s
.22195 .69435 m .2238 .63774 L .19634 .63376 L p .707 .577 .707 r
F P
0 g
s
.2238 .63774 m .22195 .69435 L .25311 .69668 L p .707 .577 .707 r
F P
0 g
s
.31614 .63903 m .31428 .69565 L .33829 .69241 L p .707 .577 .707 r
F P
0 g
s
.33829 .69241 m .34015 .63579 L .31614 .63903 L p .707 .577 .707 r
F P
0 g
s
.70218 .75023 m .69924 .78847 L .68647 .78518 L p .707 .577 .707 r
F P
0 g
s
.68647 .78518 m .6894 .74695 L .70218 .75023 L p .707 .577 .707 r
F P
0 g
s
.61008 .30766 m .61457 .8064 L .63768 .79501 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .63319 .29627 L .61008 .30766 L p .707 .577 .707 r
F P
0 g
s
.19634 .63376 m .19448 .69038 L .22195 .69435 L p .707 .577 .707 r
F P
0 g
s
.25165 .75375 m .25459 .71551 L .22346 .71259 L p .707 .577 .707 r
F P
0 g
s
.25459 .71551 m .25165 .75375 L .28337 .75592 L p .707 .577 .707 r
F P
0 g
s
.28337 .75592 m .28631 .71769 L .25459 .71551 L p .707 .577 .707 r
F P
0 g
s
.69096 .65008 m .68911 .7067 L .66803 .70147 L p .707 .577 .707 r
F P
0 g
s
.66803 .70147 m .66989 .64485 L .69096 .65008 L p .707 .577 .707 r
F P
0 g
s
.19448 .69038 m .19634 .63376 L .17526 .62854 L p .707 .577 .707 r
F P
0 g
s
.22346 .71259 m .22052 .75083 L .25165 .75375 L p .707 .577 .707 r
F P
0 g
s
.28631 .71769 m .28337 .75592 L .31257 .75714 L p .707 .577 .707 r
F P
0 g
s
.31257 .75714 m .31551 .71891 L .28631 .71769 L p .707 .577 .707 r
F P
0 g
s
.22052 .75083 m .22346 .71259 L .19596 .70922 L p .707 .577 .707 r
F P
0 g
s
.19596 .70922 m .19302 .74745 L .22052 .75083 L p .707 .577 .707 r
F P
0 g
s
.3817 .80386 m .37721 .30512 L .35943 .29327 L p .707 .577 .707 r
F P
0 g
s
.37721 .30512 m .3817 .80386 L .41143 .81343 L p .707 .577 .707 r
F P
0 g
s
.17526 .62854 m .17341 .68515 L .19448 .69038 L p .707 .577 .707 r
F P
0 g
s
.7016 .82213 m .70039 .8412 L .68768 .83707 L p .707 .577 .707 r
F P
0 g
s
.68768 .83707 m .68889 .818 L .7016 .82213 L p .707 .577 .707 r
F P
0 g
s
.31551 .71891 m .31257 .75714 L .3364 .75729 L p .707 .577 .707 r
F P
0 g
s
.3364 .75729 m .33934 .71905 L .31551 .71891 L p .707 .577 .707 r
F P
0 g
s
.34015 .63579 m .33829 .69241 L .35462 .6877 L p .707 .577 .707 r
F P
0 g
s
.35462 .6877 m .35647 .63108 L .34015 .63579 L p .707 .577 .707 r
F P
0 g
s
.2524 .81235 m .2536 .79328 L .22246 .79055 L p .707 .577 .707 r
F P
0 g
s
.2536 .79328 m .2524 .81235 L .28415 .81398 L p .707 .577 .707 r
F P
0 g
s
.28415 .81398 m .28536 .79491 L .2536 .79328 L p .707 .577 .707 r
F P
0 g
s
.22246 .79055 m .22125 .80962 L .2524 .81235 L p .707 .577 .707 r
F P
0 g
s
.28536 .79491 m .28415 .81398 L .31342 .81436 L p .707 .577 .707 r
F P
0 g
s
.31342 .81436 m .31462 .79529 L .28536 .79491 L p .707 .577 .707 r
F P
0 g
s
.19302 .74745 m .19596 .70922 L .17479 .70572 L p .707 .577 .707 r
F P
0 g
s
.6894 .74695 m .68647 .78518 L .6653 .78168 L p .707 .577 .707 r
F P
0 g
s
.6653 .78168 m .66823 .74345 L .6894 .74695 L p .707 .577 .707 r
F P
0 g
s
.17479 .70572 m .17185 .74395 L .19302 .74745 L p .707 .577 .707 r
F P
0 g
s
.22125 .80962 m .22246 .79055 L .19497 .78699 L p .707 .577 .707 r
F P
0 g
s
.17341 .68515 m .17526 .62854 L .16264 .62256 L p .707 .577 .707 r
F P
0 g
s
.19497 .78699 m .19377 .80606 L .22125 .80962 L p .707 .577 .707 r
F P
0 g
s
.64767 .78221 m .64318 .28347 L .63319 .29627 L p .707 .577 .707 r
F P
0 g
s
.31462 .79529 m .31342 .81436 L .33732 .81344 L p .707 .577 .707 r
F P
0 g
s
.33732 .81344 m .33852 .79437 L .31462 .79529 L p .707 .577 .707 r
F P
0 g
s
.16264 .62256 m .16078 .67918 L .17341 .68515 L p .707 .577 .707 r
F P
0 g
s
.33934 .71905 m .3364 .75729 L .35252 .75634 L p .707 .577 .707 r
F P
0 g
s
.35252 .75634 m .35546 .71811 L .33934 .71905 L p .707 .577 .707 r
F P
0 g
s
.19377 .80606 m .19497 .78699 L .17384 .78294 L p .707 .577 .707 r
F P
0 g
s
.68889 .818 m .68768 .83707 L .66655 .83302 L p .707 .577 .707 r
F P
0 g
s
.66655 .83302 m .66775 .81395 L .68889 .818 L p .707 .577 .707 r
F P
0 g
s
.35647 .63108 m .35462 .6877 L .36166 .682 L p .707 .577 .707 r
F P
0 g
s
.36166 .682 m .36351 .62538 L .35647 .63108 L p .707 .577 .707 r
F P
0 g
s
.17384 .78294 m .17263 .80201 L .19377 .80606 L p .707 .577 .707 r
F P
0 g
s
.17185 .74395 m .17479 .70572 L .16202 .70243 L p .707 .577 .707 r
F P
0 g
s
.16202 .70243 m .15908 .74067 L .17185 .74395 L p .707 .577 .707 r
F P
0 g
s
.36351 .62538 m .36166 .682 L .35872 .67586 L p .707 .577 .707 r
F P
0 g
s
.35872 .67586 m .36058 .61925 L .36351 .62538 L p .707 .577 .707 r
F P
0 g
s
.36392 .79202 m .35943 .29327 L .35534 .28032 L p .707 .577 .707 r
F P
0 g
s
.35943 .29327 m .36392 .79202 L .3817 .80386 L p .707 .577 .707 r
F P
0 g
s
.16078 .67918 m .16264 .62256 L .1597 .61642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79437 m .33732 .81344 L .35352 .81131 L p .707 .577 .707 r
F P
0 g
s
.35352 .81131 m .35472 .79224 L .33852 .79437 L p .707 .577 .707 r
F P
0 g
s
.35546 .71811 m .35252 .75634 L .35935 .7544 L p .707 .577 .707 r
F P
0 g
s
.35935 .7544 m .36229 .71617 L .35546 .71811 L p .707 .577 .707 r
F P
0 g
s
.17263 .80201 m .17384 .78294 L .16112 .77881 L p .707 .577 .707 r
F P
0 g
s
.1597 .61642 m .15785 .67304 L .16078 .67918 L p .707 .577 .707 r
F P
0 g
s
.66775 .81395 m .66655 .83302 L .63906 .82946 L p .707 .577 .707 r
F P
0 g
s
.63906 .82946 m .64027 .81039 L .66775 .81395 L p .707 .577 .707 r
F P
0 g
s
.16112 .77881 m .15992 .79788 L .17263 .80201 L p .707 .577 .707 r
F P
0 g
s
.15908 .74067 m .16202 .70243 L .15889 .69968 L p .707 .577 .707 r
F P
0 g
s
.64318 .28347 m .64767 .78221 L .64492 .77349 L p .707 .577 .707 r
F P
0 g
s
.64356 .74773 m .64318 .28347 L .64492 .77349 L .707 .577 .707 r
F
.64358 .76925 m .63909 .27051 L .64318 .28347 L p F P
0 g
s
.63909 .27051 m .64358 .76925 L .6258 .75741 L p .707 .577 .707 r
F P
0 g
s
.64223 .64848 m .63992 .67852 L p .65206 .69 L .707 .577 .707 r
F P
0 g
s
.63992 .67852 m .63929 .68671 L .64037 .68699 L p .707 .577 .707 r
F P
0 g
s
.64037 .68699 m .65206 .69 L p .63992 .67852 L .707 .577 .707 r
F P
0 g
s
.64492 .77349 m .64358 .76925 L p .64356 .74773 L .707 .577 .707 r
F P
0 g
s
.15889 .69968 m .15596 .73792 L .15908 .74067 L p .707 .577 .707 r
F P
0 g
s
.64027 .81039 m .63906 .82946 L .60792 .82673 L p .707 .577 .707 r
F P
0 g
s
.35472 .79224 m .35352 .81131 L .36043 .80819 L p .707 .577 .707 r
F P
0 g
s
.36043 .80819 m .36164 .78912 L .35472 .79224 L p .707 .577 .707 r
F P
0 g
s
.15785 .67304 m .1597 .61642 L .16674 .61072 L p .707 .577 .707 r
F P
0 g
s
.15992 .79788 m .16112 .77881 L .15808 .775 L p .707 .577 .707 r
F P
0 g
s
.36229 .71617 m .35935 .7544 L .35623 .75165 L p .707 .577 .707 r
F P
0 g
s
.35623 .75165 m .35917 .71342 L .36229 .71617 L p .707 .577 .707 r
F P
0 g
s
.36058 .61925 m .35872 .67586 L .3461 .66989 L p .707 .577 .707 r
F P
0 g
s
.3461 .66989 m .34795 .61327 L .36058 .61925 L p .707 .577 .707 r
F P
0 g
s
.35534 .28032 m .35982 .77906 L .36392 .79202 L p .707 .577 .707 r
F P
0 g
s
.35982 .77906 m .35534 .28032 L .36533 .26752 L p .707 .577 .707 r
F P
0 g
s
.15808 .775 m .15687 .79407 L .15992 .79788 L p .707 .577 .707 r
F P
0 g
s
.16674 .61072 m .16489 .66734 L .15785 .67304 L p .707 .577 .707 r
F P
0 g
s
.15596 .73792 m .15889 .69968 L .16573 .69774 L p .707 .577 .707 r
F P
0 g
s
.16573 .69774 m .16279 .73598 L .15596 .73792 L p .707 .577 .707 r
F P
0 g
s
.36164 .78912 m .36043 .80819 L .35739 .80438 L p .707 .577 .707 r
F P
0 g
s
.35739 .80438 m .35859 .78531 L .36164 .78912 L p .707 .577 .707 r
F P
0 g
s
.16489 .66734 m .16674 .61072 L .18307 .60602 L p .707 .577 .707 r
F P
0 g
s
.6258 .75741 m .62131 .25867 L .63909 .27051 L p .707 .577 .707 r
F P
0 g
s
.15687 .79407 m .15808 .775 L .16499 .77188 L p .707 .577 .707 r
F P
0 g
s
.18307 .60602 m .18121 .66264 L .16489 .66734 L p .707 .577 .707 r
F P
0 g
s
.35917 .71342 m .35623 .75165 L .34346 .74837 L p .707 .577 .707 r
F P
0 g
s
.34346 .74837 m .3464 .71013 L .35917 .71342 L p .707 .577 .707 r
F P
0 g
s
.16499 .77188 m .16379 .79095 L .15687 .79407 L p .707 .577 .707 r
F P
0 g
s
.34795 .61327 m .3461 .66989 L .32502 .66466 L p .707 .577 .707 r
F P
0 g
s
.32502 .66466 m .32688 .60804 L .34795 .61327 L p .707 .577 .707 r
F P
0 g
s
.36982 .76626 m .36533 .26752 L .38844 .25612 L p .707 .577 .707 r
F P
0 g
s
.36533 .26752 m .36982 .76626 L .35982 .77906 L p .707 .577 .707 r
F P
0 g
s
.16279 .73598 m .16573 .69774 L .18184 .6968 L p .707 .577 .707 r
F P
0 g
s
.18184 .6968 m .17891 .73503 L .16279 .73598 L p .707 .577 .707 r
F P
0 g
s
.18121 .66264 m .18307 .60602 L .20708 .60277 L p .707 .577 .707 r
F P
0 g
s
.35859 .78531 m .35739 .80438 L .34467 .80025 L p .707 .577 .707 r
F P
0 g
s
.34467 .80025 m .34588 .78118 L .35859 .78531 L p .707 .577 .707 r
F P
0 g
s
.20708 .60277 m .20522 .65939 L .18121 .66264 L p .707 .577 .707 r
F P
0 g
s
.16379 .79095 m .16499 .77188 L .18119 .76976 L p .707 .577 .707 r
F P
0 g
s
.3464 .71013 m .34346 .74837 L .32229 .74487 L p .707 .577 .707 r
F P
0 g
s
.32229 .74487 m .32522 .70663 L .3464 .71013 L p .707 .577 .707 r
F P
0 g
s
.32688 .60804 m .32502 .66466 L .29755 .66069 L p .707 .577 .707 r
F P
0 g
s
.29755 .66069 m .29941 .60407 L .32688 .60804 L p .707 .577 .707 r
F P
0 g
s
.18119 .76976 m .17999 .78883 L .16379 .79095 L p .707 .577 .707 r
F P
0 g
s
.62131 .25867 m .6258 .75741 L .59607 .74784 L p .707 .577 .707 r
F P
0 g
s
.59607 .74784 m .59158 .2491 L .62131 .25867 L p .707 .577 .707 r
F P
0 g
s
.20522 .65939 m .20708 .60277 L .23643 .6013 L p .707 .577 .707 r
F P
0 g
s
.17891 .73503 m .18184 .6968 L .20567 .69694 L p .707 .577 .707 r
F P
0 g
s
.20567 .69694 m .20273 .73518 L .17891 .73503 L p .707 .577 .707 r
F P
0 g
s
.29941 .60407 m .29755 .66069 L .26639 .65837 L p .707 .577 .707 r
F P
0 g
s
.26639 .65837 m .26825 .60175 L .29941 .60407 L p .707 .577 .707 r
F P
0 g
s
.38844 .25612 m .39292 .75487 L .36982 .76626 L p .707 .577 .707 r
F P
0 g
s
.39292 .75487 m .38844 .25612 L .42239 .24725 L p .707 .577 .707 r
F P
0 g
s
.23643 .6013 m .23457 .65792 L .20522 .65939 L p .707 .577 .707 r
F P
0 g
s
.34588 .78118 m .34467 .80025 L .32354 .79621 L p .707 .577 .707 r
F P
0 g
s
.32354 .79621 m .32474 .77714 L .34588 .78118 L p .707 .577 .707 r
F P
0 g
s
.23457 .65792 m .23643 .6013 L .26825 .60175 L p .707 .577 .707 r
F P
0 g
s
.26825 .60175 m .26639 .65837 L .23457 .65792 L p .707 .577 .707 r
F P
0 g
s
.32522 .70663 m .32229 .74487 L .29479 .74149 L p .707 .577 .707 r
F P
0 g
s
.29479 .74149 m .29773 .70326 L .32522 .70663 L p .707 .577 .707 r
F P
0 g
s
.73333 .65704 m .73518 .60042 L .70402 .5981 L p .707 .577 .707 r
F P
0 g
s
.73518 .60042 m .73333 .65704 L .76514 .65749 L p .707 .577 .707 r
F P
0 g
s
.76514 .65749 m .767 .60087 L .73518 .60042 L p .707 .577 .707 r
F P
0 g
s
.17999 .78883 m .18119 .76976 L .20509 .76884 L p .707 .577 .707 r
F P
0 g
s
.767 .60087 m .76514 .65749 L .79449 .65602 L p .707 .577 .707 r
F P
0 g
s
.79449 .65602 m .79635 .5994 L .767 .60087 L p .707 .577 .707 r
F P
0 g
s
.20509 .76884 m .20389 .78791 L .17999 .78883 L p .707 .577 .707 r
F P
0 g
s
.20273 .73518 m .20567 .69694 L .23487 .69816 L p .707 .577 .707 r
F P
0 g
s
.70216 .65472 m .70402 .5981 L .67655 .59413 L p .707 .577 .707 r
F P
0 g
s
.70402 .5981 m .70216 .65472 L .73333 .65704 L p .707 .577 .707 r
F P
0 g
s
.23487 .69816 m .23194 .7364 L .20273 .73518 L p .707 .577 .707 r
F P
0 g
s
.59158 .2491 m .59607 .74784 L .55731 .74149 L p .707 .577 .707 r
F P
0 g
s
.55731 .74149 m .55282 .24274 L .59158 .2491 L p .707 .577 .707 r
F P
0 g
s
.29773 .70326 m .29479 .74149 L .26366 .73857 L p .707 .577 .707 r
F P
0 g
s
.26366 .73857 m .26659 .70034 L .29773 .70326 L p .707 .577 .707 r
F P
0 g
s
.79635 .5994 m .79449 .65602 L .81851 .65277 L p .707 .577 .707 r
F P
0 g
s
.81851 .65277 m .82036 .59615 L .79635 .5994 L p .707 .577 .707 r
F P
0 g
s
.73186 .69979 m .7348 .66156 L .70367 .65864 L p .707 .577 .707 r
F P
0 g
s
.7348 .66156 m .73186 .69979 L .76358 .70197 L p .707 .577 .707 r
F P
0 g
s
.76358 .70197 m .76652 .66373 L .7348 .66156 L p .707 .577 .707 r
F P
0 g
s
.32474 .77714 m .32354 .79621 L .29606 .79265 L p .707 .577 .707 r
F P
0 g
s
.29606 .79265 m .29726 .77358 L .32474 .77714 L p .707 .577 .707 r
F P
0 g
s
.23194 .7364 m .23487 .69816 L .26659 .70034 L p .707 .577 .707 r
F P
0 g
s
.67655 .59413 m .6747 .65075 L .70216 .65472 L p .707 .577 .707 r
F P
0 g
s
.70367 .65864 m .70073 .69687 L .73186 .69979 L p .707 .577 .707 r
F P
0 g
s
.76652 .66373 m .76358 .70197 L .79279 .70319 L p .707 .577 .707 r
F P
0 g
s
.79279 .70319 m .79573 .66495 L .76652 .66373 L p .707 .577 .707 r
F P
0 g
s
.26659 .70034 m .26366 .73857 L .23194 .7364 L p .707 .577 .707 r
F P
0 g
s
.42688 .74599 m .42239 .24725 L .46387 .24177 L p .707 .577 .707 r
F P
0 g
s
.42239 .24725 m .42665 .72043 L p .39292 .75487 L .707 .577 .707 r
F P
0 g
s
.46387 .24177 m .46836 .74051 L .42688 .74599 L p .707 .577 .707 r
F P
0 g
s
.42351 .62692 m .42057 .66515 L .44732 .66627 L p .707 .577 .707 r
F P
0 g
s
.44732 .66627 m .44978 .66637 L p .44819 .66399 L .707 .577 .707 r
F P
0 g
s
.44819 .66399 m .42351 .62692 L .44732 .66627 L .707 .577 .707 r
F
.42665 .72043 m .42688 .74599 L .41578 .74889 L p F P
0 g
s
.41578 .74889 m .39292 .75487 L p .42665 .72043 L .707 .577 .707 r
F P
0 g
s
.6747 .65075 m .67655 .59413 L .65548 .5889 L p .707 .577 .707 r
F P
0 g
s
.70073 .69687 m .70367 .65864 L .67617 .65526 L p .707 .577 .707 r
F P
0 g
s
.20389 .78791 m .20509 .76884 L .23436 .76921 L p .707 .577 .707 r
F P
0 g
s
.23436 .76921 m .23315 .78828 L .20389 .78791 L p .707 .577 .707 r
F P
0 g
s
.67617 .65526 m .67323 .6935 L .70073 .69687 L p .707 .577 .707 r
F P
0 g
s
.73261 .7313 m .73381 .71223 L .70267 .7095 L p .707 .577 .707 r
F P
0 g
s
.73381 .71223 m .73261 .7313 L .76437 .73294 L p .707 .577 .707 r
F P
0 g
s
.76437 .73294 m .76557 .71387 L .73381 .71223 L p .707 .577 .707 r
F P
0 g
s
.70267 .7095 m .70146 .72857 L .73261 .7313 L p .707 .577 .707 r
F P
0 g
s
.76557 .71387 m .76437 .73294 L .79363 .73331 L p .707 .577 .707 r
F P
0 g
s
.79363 .73331 m .79483 .71424 L .76557 .71387 L p .707 .577 .707 r
F P
0 g
s
.55282 .24274 m .55731 .74149 L .5133 .73896 L p .707 .577 .707 r
F P
0 g
s
.5133 .73896 m .50881 .24022 L .55282 .24274 L p .707 .577 .707 r
F P
0 g
s
.79573 .66495 m .79279 .70319 L .81661 .70333 L p .707 .577 .707 r
F P
0 g
s
.81661 .70333 m .81955 .6651 L .79573 .66495 L p .707 .577 .707 r
F P
0 g
s
.29726 .77358 m .29606 .79265 L .26491 .78991 L p .707 .577 .707 r
F P
0 g
s
.26491 .78991 m .26611 .77084 L .29726 .77358 L p .707 .577 .707 r
F P
0 g
s
.65548 .5889 m .65362 .64552 L .6747 .65075 L p .707 .577 .707 r
F P
0 g
s
.70146 .72857 m .70267 .7095 L .67518 .70594 L p .707 .577 .707 r
F P
0 g
s
.23315 .78828 m .23436 .76921 L .26611 .77084 L p .707 .577 .707 r
F P
0 g
s
.67518 .70594 m .67398 .72501 L .70146 .72857 L p .707 .577 .707 r
F P
0 g
s
.82036 .59615 m .81851 .65277 L .83483 .64807 L p .707 .577 .707 r
F P
0 g
s
.83483 .64807 m .83669 .59145 L .82036 .59615 L p .707 .577 .707 r
F P
0 g
s
.46836 .74051 m .46387 .24177 L .50881 .24022 L p .707 .577 .707 r
F P
0 g
s
.26611 .77084 m .26491 .78991 L .23315 .78828 L p .707 .577 .707 r
F P
0 g
s
.67323 .6935 m .67617 .65526 L .655 .65176 L p .707 .577 .707 r
F P
0 g
s
.50881 .24022 m .5133 .73896 L .46836 .74051 L p .707 .577 .707 r
F P
0 g
s
.655 .65176 m .65206 .69 L .67323 .6935 L p .707 .577 .707 r
F P
0 g
s
.79483 .71424 m .79363 .73331 L .81753 .73239 L p .707 .577 .707 r
F P
0 g
s
.81753 .73239 m .81874 .71332 L .79483 .71424 L p .707 .577 .707 r
F P
0 g
s
.65362 .64552 m .65548 .5889 L .64285 .58292 L p .707 .577 .707 r
F P
0 g
s
.67398 .72501 m .67518 .70594 L .65405 .7019 L p .707 .577 .707 r
F P
0 g
s
.65405 .7019 m .65285 .72097 L .67398 .72501 L p .707 .577 .707 r
F P
0 g
s
.81955 .6651 m .81661 .70333 L .83273 .70239 L p .707 .577 .707 r
F P
0 g
s
.83273 .70239 m .83567 .66415 L .81955 .6651 L p .707 .577 .707 r
F P
0 g
s
.64285 .58292 m .641 .63954 L .65362 .64552 L p .707 .577 .707 r
F P
0 g
s
.65206 .69 m .655 .65176 L .64223 .64848 L p .707 .577 .707 r
F P
0 g
s
.83669 .59145 m .83483 .64807 L .84187 .64237 L p .707 .577 .707 r
F P
0 g
s
.84187 .64237 m .84373 .58575 L .83669 .59145 L p .707 .577 .707 r
F P
0 g
s
.81874 .71332 m .81753 .73239 L .83373 .73027 L p .707 .577 .707 r
F P
0 g
s
.83373 .73027 m .83494 .7112 L .81874 .71332 L p .707 .577 .707 r
F P
0 g
s
.65285 .72097 m .65405 .7019 L .64134 .69777 L p .707 .577 .707 r
F P
0 g
s
.641 .63954 m .64285 .58292 L .63992 .57679 L p .707 .577 .707 r
F P
0 g
s
.64134 .69777 m .64013 .71684 L .65285 .72097 L p .707 .577 .707 r
F P
0 g
s
.83567 .66415 m .83273 .70239 L .83957 .70045 L p .707 .577 .707 r
F P
0 g
s
.83957 .70045 m .8425 .66221 L .83567 .66415 L p .707 .577 .707 r
F P
0 g
s
.63992 .57679 m .63806 .6334 L .641 .63954 L p .707 .577 .707 r
F P
0 g
s
.63929 .68671 m .64223 .64848 L .63911 .64573 L p .707 .577 .707 r
F P
0 g
s
.83494 .7112 m .83373 .73027 L .84065 .72715 L p .707 .577 .707 r
F P
0 g
s
.84065 .72715 m .84185 .70808 L .83494 .7112 L p .707 .577 .707 r
F P
0 g
s
.84373 .58575 m .84187 .64237 L .83893 .63623 L p .707 .577 .707 r
F P
0 g
s
.83893 .63623 m .84079 .57961 L .84373 .58575 L p .707 .577 .707 r
F P
0 g
s
.63911 .64573 m .63617 .68396 L .63929 .68671 L p .707 .577 .707 r
F P
0 g
s
.64013 .71684 m .64134 .69777 L .63829 .69396 L p .707 .577 .707 r
F P
0 g
s
.63829 .69396 m .63709 .71303 L .64013 .71684 L p .707 .577 .707 r
F P
0 g
s
.63806 .6334 m .63992 .57679 L .64696 .57109 L p .707 .577 .707 r
F P
0 g
s
.8425 .66221 m .83957 .70045 L .83644 .6977 L p .707 .577 .707 r
F P
0 g
s
.83644 .6977 m .83938 .65946 L .8425 .66221 L p .707 .577 .707 r
F P
0 g
s
.64696 .57109 m .6451 .6277 L .63806 .6334 L p .707 .577 .707 r
F P
0 g
s
.63617 .68396 m .63911 .64573 L .64594 .64379 L p .707 .577 .707 r
F P
0 g
s
.84185 .70808 m .84065 .72715 L .8376 .72334 L p .707 .577 .707 r
F P
0 g
s
.8376 .72334 m .8388 .70427 L .84185 .70808 L p .707 .577 .707 r
F P
0 g
s
.84079 .57961 m .83893 .63623 L .82631 .63025 L p .707 .577 .707 r
F P
0 g
s
.82631 .63025 m .82817 .57363 L .84079 .57961 L p .707 .577 .707 r
F P
0 g
s
.64594 .64379 m .643 .68202 L .63617 .68396 L p .707 .577 .707 r
F P
0 g
s
.39032 .62023 m .39217 .56361 L .36101 .56129 L p .707 .577 .707 r
F P
0 g
s
.39217 .56361 m .39032 .62023 L .42213 .62067 L p .707 .577 .707 r
F P
0 g
s
.42213 .62067 m .42399 .56406 L .39217 .56361 L p .707 .577 .707 r
F P
0 g
s
.63709 .71303 m .63829 .69396 L .64521 .69083 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42399 .56406 m .42213 .62067 L .45148 .6192 L p .707 .577 .707 r
F P
0 g
s
.45148 .6192 m .45334 .56258 L .42399 .56406 L p .707 .577 .707 r
F P
0 g
s
.64521 .69083 m .644 .70991 L .63709 .71303 L p .707 .577 .707 r
F P
0 g
s
.6451 .6277 m .64696 .57109 L .66328 .56638 L p .707 .577 .707 r
F P
0 g
s
.35915 .6179 m .36101 .56129 L .33354 .55731 L p .707 .577 .707 r
F P
0 g
s
.36101 .56129 m .35915 .6179 L .39032 .62023 L p .707 .577 .707 r
F P
0 g
s
.83938 .65946 m .83644 .6977 L .82367 .69441 L p .707 .577 .707 r
F P
0 g
s
.82367 .69441 m .82661 .65618 L .83938 .65946 L p .707 .577 .707 r
F P
0 g
s
.66328 .56638 m .66142 .623 L .6451 .6277 L p .707 .577 .707 r
F P
0 g
s
.45334 .56258 m .45148 .6192 L .4755 .61596 L p .707 .577 .707 r
F P
0 g
s
.4755 .61596 m .47735 .55934 L .45334 .56258 L p .707 .577 .707 r
F P
0 g
s
.38885 .66298 m .39179 .62474 L .36066 .62182 L p .707 .577 .707 r
F P
0 g
s
.39179 .62474 m .38885 .66298 L .42057 .66515 L p .707 .577 .707 r
F P
0 g
s
.42057 .66515 m .42351 .62692 L .39179 .62474 L p .707 .577 .707 r
F P
0 g
s
.33354 .55731 m .33169 .61393 L .35915 .6179 L p .707 .577 .707 r
F P
0 g
s
.36066 .62182 m .35772 .66006 L .38885 .66298 L p .707 .577 .707 r
F P
0 g
s
.44978 .66637 m .45272 .62814 L .42351 .62692 L p .707 .577 .707 r
F P
0 g
s
.82817 .57363 m .82631 .63025 L .80523 .62502 L p .707 .577 .707 r
F P
0 g
s
.80523 .62502 m .80709 .56841 L .82817 .57363 L p .707 .577 .707 r
F P
0 g
s
.643 .68202 m .64594 .64379 L .66206 .64284 L p .707 .577 .707 r
F P
0 g
s
.33169 .61393 m .33354 .55731 L .31247 .55209 L p .707 .577 .707 r
F P
0 g
s
.35772 .66006 m .36066 .62182 L .33316 .61845 L p .707 .577 .707 r
F P
0 g
s
.8388 .70427 m .8376 .72334 L .82489 .71921 L p .707 .577 .707 r
F P
0 g
s
.82489 .71921 m .82609 .70014 L .8388 .70427 L p .707 .577 .707 r
F P
0 g
s
.66206 .64284 m .65912 .68108 L .643 .68202 L p .707 .577 .707 r
F P
0 g
s
.33316 .61845 m .33022 .65668 L .35772 .66006 L p .707 .577 .707 r
F P
0 g
s
.3896 .69449 m .3908 .67542 L .35966 .67269 L p .707 .577 .707 r
F P
0 g
s
.3908 .67542 m .3896 .69449 L .42136 .69612 L p .707 .577 .707 r
F P
0 g
s
.42136 .69612 m .42256 .67705 L .3908 .67542 L p .707 .577 .707 r
F P
0 g
s
.35966 .67269 m .35845 .69176 L .3896 .69449 L p .707 .577 .707 r
F P
0 g
s
.42256 .67705 m .42136 .69612 L .45062 .6965 L p .707 .577 .707 r
F P
0 g
s
.45062 .6965 m .45182 .67743 L .42256 .67705 L p .707 .577 .707 r
F P
0 g
s
.66142 .623 m .66328 .56638 L .68729 .56314 L p .707 .577 .707 r
F P
0 g
s
.45272 .62814 m .44978 .66637 L .4736 .66652 L p .707 .577 .707 r
F P
0 g
s
.4736 .66652 m .47654 .62828 L .45272 .62814 L p .707 .577 .707 r
F P
0 g
s
.644 .70991 m .64521 .69083 L .66141 .68871 L p .707 .577 .707 r
F P
0 g
s
.31247 .55209 m .31061 .6087 L .33169 .61393 L p .707 .577 .707 r
F P
0 g
s
.35845 .69176 m .35966 .67269 L .33217 .66913 L p .707 .577 .707 r
F P
0 g
s
.66141 .68871 m .6602 .70778 L .644 .70991 L p .707 .577 .707 r
F P
0 g
s
.33217 .66913 m .33097 .6882 L .35845 .69176 L p .707 .577 .707 r
F P
0 g
s
.47735 .55934 m .4755 .61596 L .49182 .61125 L p .707 .577 .707 r
F P
0 g
s
.49182 .61125 m .49368 .55463 L .47735 .55934 L p .707 .577 .707 r
F P
0 g
s
.33022 .65668 m .33316 .61845 L .31199 .61495 L p .707 .577 .707 r
F P
0 g
s
.82661 .65618 m .82367 .69441 L .8025 .69091 L p .707 .577 .707 r
F P
0 g
s
.8025 .69091 m .80544 .65268 L .82661 .65618 L p .707 .577 .707 r
F P
0 g
s
.31199 .61495 m .30905 .65318 L .33022 .65668 L p .707 .577 .707 r
F P
0 g
s
.68729 .56314 m .68544 .61975 L .66142 .623 L p .707 .577 .707 r
F P
0 g
s
.45182 .67743 m .45062 .6965 L .47452 .69558 L p .707 .577 .707 r
F P
0 g
s
.47452 .69558 m .47573 .67651 L .45182 .67743 L p .707 .577 .707 r
F P
0 g
s
.80709 .56841 m .80523 .62502 L .77777 .62105 L p .707 .577 .707 r
F P
0 g
s
.77777 .62105 m .77963 .56443 L .80709 .56841 L p .707 .577 .707 r
F P
0 g
s
.31061 .6087 m .31247 .55209 L .29984 .54611 L p .707 .577 .707 r
F P
0 g
s
.65912 .68108 m .66206 .64284 L .68588 .64299 L p .707 .577 .707 r
F P
0 g
s
.33097 .6882 m .33217 .66913 L .31104 .66508 L p .707 .577 .707 r
F P
0 g
s
.82609 .70014 m .82489 .71921 L .80375 .71516 L p .707 .577 .707 r
F P
0 g
s
.80375 .71516 m .80496 .69609 L .82609 .70014 L p .707 .577 .707 r
F P
0 g
s
.31104 .66508 m .30984 .68415 L .33097 .6882 L p .707 .577 .707 r
F P
0 g
s
.68544 .61975 m .68729 .56314 L .71664 .56166 L p .707 .577 .707 r
F P
0 g
s
.68588 .64299 m .68295 .68122 L .65912 .68108 L p .707 .577 .707 r
F P
0 g
s
.47654 .62828 m .4736 .66652 L .48972 .66557 L p .707 .577 .707 r
F P
0 g
s
.48972 .66557 m .49266 .62734 L .47654 .62828 L p .707 .577 .707 r
F P
0 g
s
.29984 .54611 m .29799 .60273 L .31061 .6087 L p .707 .577 .707 r
F P
0 g
s
.6602 .70778 m .66141 .68871 L .68531 .68779 L p .707 .577 .707 r
F P
0 g
s
.77963 .56443 m .77777 .62105 L .7466 .61873 L p .707 .577 .707 r
F P
0 g
s
.7466 .61873 m .74846 .56211 L .77963 .56443 L p .707 .577 .707 r
F P
0 g
s
.30905 .65318 m .31199 .61495 L .29922 .61166 L p .707 .577 .707 r
F P
0 g
s
.68531 .68779 m .6841 .70686 L .6602 .70778 L p .707 .577 .707 r
F P
0 g
s
.71664 .56166 m .71479 .61828 L .68544 .61975 L p .707 .577 .707 r
F P
0 g
s
.49368 .55463 m .49182 .61125 L .49886 .60555 L p .707 .577 .707 r
F P
0 g
s
.49886 .60555 m .50072 .54893 L .49368 .55463 L p .707 .577 .707 r
F P
0 g
s
.80544 .65268 m .8025 .69091 L .775 .68754 L p .707 .577 .707 r
F P
0 g
s
.775 .68754 m .77794 .6493 L .80544 .65268 L p .707 .577 .707 r
F P
0 g
s
.47573 .67651 m .47452 .69558 L .49072 .69345 L p .707 .577 .707 r
F P
0 g
s
.49072 .69345 m .49193 .67438 L .47573 .67651 L p .707 .577 .707 r
F P
0 g
s
.71479 .61828 m .71664 .56166 L .74846 .56211 L p .707 .577 .707 r
F P
0 g
s
.29922 .61166 m .29628 .6499 L .30905 .65318 L p .707 .577 .707 r
F P
0 g
s
.74846 .56211 m .7466 .61873 L .71479 .61828 L p .707 .577 .707 r
F P
0 g
s
.68295 .68122 m .68588 .64299 L .71509 .64421 L p .707 .577 .707 r
F P
0 g
s
.30984 .68415 m .31104 .66508 L .29833 .66095 L p .707 .577 .707 r
F P
0 g
s
.71509 .64421 m .71215 .68244 L .68295 .68122 L p .707 .577 .707 r
F P
0 g
s
.29799 .60273 m .29984 .54611 L .29691 .53997 L p .707 .577 .707 r
F P
0 g
s
.80496 .69609 m .80375 .71516 L .77627 .7116 L p .707 .577 .707 r
F P
0 g
s
.77627 .7116 m .77747 .69253 L .80496 .69609 L p .707 .577 .707 r
F P
0 g
s
.29833 .66095 m .29712 .68002 L .30984 .68415 L p .707 .577 .707 r
F P
0 g
s
.77794 .6493 m .775 .68754 L .74387 .68462 L p .707 .577 .707 r
F P
0 g
s
.74387 .68462 m .74681 .64638 L .77794 .6493 L p .707 .577 .707 r
F P
0 g
s
.49266 .62734 m .48972 .66557 L .49656 .66363 L p .707 .577 .707 r
F P
0 g
s
.49656 .66363 m .49949 .6254 L .49266 .62734 L p .707 .577 .707 r
F P
0 g
s
.6841 .70686 m .68531 .68779 L .71457 .68817 L p .707 .577 .707 r
F P
0 g
s
.71215 .68244 m .71509 .64421 L .74681 .64638 L p .707 .577 .707 r
F P
0 g
s
.71457 .68817 m .71337 .70724 L .6841 .70686 L p .707 .577 .707 r
F P
0 g
s
.29691 .53997 m .29505 .59659 L .29799 .60273 L p .707 .577 .707 r
F P
0 g
s
.74681 .64638 m .74387 .68462 L .71215 .68244 L p .707 .577 .707 r
F P
0 g
s
.29628 .6499 m .29922 .61166 L .2961 .60891 L p .707 .577 .707 r
F P
0 g
s
.77747 .69253 m .77627 .7116 L .74512 .70887 L p .707 .577 .707 r
F P
0 g
s
.74512 .70887 m .74633 .6898 L .77747 .69253 L p .707 .577 .707 r
F P
0 g
s
.49193 .67438 m .49072 .69345 L .49764 .69033 L p .707 .577 .707 r
F P
0 g
s
.49764 .69033 m .49884 .67126 L .49193 .67438 L p .707 .577 .707 r
F P
0 g
s
.50072 .54893 m .49886 .60555 L .49592 .59941 L p .707 .577 .707 r
F P
0 g
s
.49592 .59941 m .49778 .5428 L .50072 .54893 L p .707 .577 .707 r
F P
0 g
s
.2961 .60891 m .29316 .64715 L .29628 .6499 L p .707 .577 .707 r
F P
0 g
s
.71337 .70724 m .71457 .68817 L .74633 .6898 L p .707 .577 .707 r
F P
0 g
s
.74633 .6898 m .74512 .70887 L .71337 .70724 L p .707 .577 .707 r
F P
0 g
s
.29712 .68002 m .29833 .66095 L .29528 .65714 L p .707 .577 .707 r
F P
0 g
s
.29528 .65714 m .29407 .67621 L .29712 .68002 L p .707 .577 .707 r
F P
0 g
s
.29505 .59659 m .29691 .53997 L .30394 .53427 L p .707 .577 .707 r
F P
0 g
s
.49949 .6254 m .49656 .66363 L .49343 .66088 L p .707 .577 .707 r
F P
0 g
s
.49343 .66088 m .49637 .62265 L .49949 .6254 L p .707 .577 .707 r
F P
0 g
s
.30394 .53427 m .30209 .59089 L .29505 .59659 L p .707 .577 .707 r
F P
0 g
s
.29316 .64715 m .2961 .60891 L .30293 .60697 L p .707 .577 .707 r
F P
0 g
s
.49884 .67126 m .49764 .69033 L .49459 .68652 L p .707 .577 .707 r
F P
0 g
s
.49459 .68652 m .49579 .66745 L .49884 .67126 L p .707 .577 .707 r
F P
0 g
s
.49778 .5428 m .49592 .59941 L .4833 .59344 L p .707 .577 .707 r
F P
0 g
s
.4833 .59344 m .48516 .53682 L .49778 .5428 L p .707 .577 .707 r
F P
0 g
s
.30293 .60697 m .29999 .64521 L .29316 .64715 L p .707 .577 .707 r
F P
0 g
s
.29407 .67621 m .29528 .65714 L .30219 .65402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30219 .65402 m .30099 .67309 L .29407 .67621 L p .707 .577 .707 r
F P
0 g
s
.30209 .59089 m .30394 .53427 L .32027 .52957 L p .707 .577 .707 r
F P
0 g
s
.49637 .62265 m .49343 .66088 L .48066 .6576 L p .707 .577 .707 r
F P
0 g
s
.48066 .6576 m .4836 .61936 L .49637 .62265 L p .707 .577 .707 r
F P
0 g
s
.32027 .52957 m .31841 .58619 L .30209 .59089 L p .707 .577 .707 r
F P
0 g
s
.48516 .53682 m .4833 .59344 L .46222 .58821 L p .707 .577 .707 r
F P
0 g
s
.46222 .58821 m .46408 .53159 L .48516 .53682 L p .707 .577 .707 r
F P
0 g
s
.29999 .64521 m .30293 .60697 L .31905 .60603 L p .707 .577 .707 r
F P
0 g
s
.49579 .66745 m .49459 .68652 L .48188 .68239 L p .707 .577 .707 r
F P
0 g
s
.48188 .68239 m .48308 .66332 L .49579 .66745 L p .707 .577 .707 r
F P
0 g
s
.31905 .60603 m .31611 .64426 L .29999 .64521 L p .707 .577 .707 r
F P
0 g
s
.31841 .58619 m .32027 .52957 L .34428 .52632 L p .707 .577 .707 r
F P
0 g
s
.30099 .67309 m .30219 .65402 L .3184 .6519 L p .707 .577 .707 r
F P
0 g
s
.3184 .6519 m .31719 .67097 L .30099 .67309 L p .707 .577 .707 r
F P
0 g
s
.4836 .61936 m .48066 .6576 L .45949 .65409 L p .707 .577 .707 r
F P
0 g
s
.45949 .65409 m .46243 .61586 L .4836 .61936 L p .707 .577 .707 r
F P
0 g
s
.34428 .52632 m .34243 .58294 L .31841 .58619 L p .707 .577 .707 r
F P
0 g
s
.46408 .53159 m .46222 .58821 L .43476 .58424 L p .707 .577 .707 r
F P
0 g
s
.43476 .58424 m .43661 .52762 L .46408 .53159 L p .707 .577 .707 r
F P
0 g
s
.31611 .64426 m .31905 .60603 L .34287 .60617 L p .707 .577 .707 r
F P
0 g
s
.48308 .66332 m .48188 .68239 L .46074 .67835 L p .707 .577 .707 r
F P
0 g
s
.46074 .67835 m .46195 .65928 L .48308 .66332 L p .707 .577 .707 r
F P
0 g
s
.34243 .58294 m .34428 .52632 L .37363 .52485 L p .707 .577 .707 r
F P
0 g
s
.34287 .60617 m .33994 .64441 L .31611 .64426 L p .707 .577 .707 r
F P
0 g
s
.31719 .67097 m .3184 .6519 L .3423 .65098 L p .707 .577 .707 r
F P
0 g
s
.43661 .52762 m .43476 .58424 L .40359 .58192 L p .707 .577 .707 r
F P
0 g
s
.40359 .58192 m .40545 .5253 L .43661 .52762 L p .707 .577 .707 r
F P
0 g
s
.3423 .65098 m .34109 .67005 L .31719 .67097 L p .707 .577 .707 r
F P
0 g
s
.37363 .52485 m .37178 .58147 L .34243 .58294 L p .707 .577 .707 r
F P
0 g
s
.46243 .61586 m .45949 .65409 L .43199 .65072 L p .707 .577 .707 r
F P
0 g
s
.43199 .65072 m .43493 .61249 L .46243 .61586 L p .707 .577 .707 r
F P
0 g
s
.37178 .58147 m .37363 .52485 L .40545 .5253 L p .707 .577 .707 r
F P
0 g
s
.40545 .5253 m .40359 .58192 L .37178 .58147 L p .707 .577 .707 r
F P
0 g
s
.33994 .64441 m .34287 .60617 L .37208 .60739 L p .707 .577 .707 r
F P
0 g
s
.37208 .60739 m .36914 .64563 L .33994 .64441 L p .707 .577 .707 r
F P
0 g
s
.46195 .65928 m .46074 .67835 L .43326 .67479 L p .707 .577 .707 r
F P
0 g
s
.43326 .67479 m .43446 .65572 L .46195 .65928 L p .707 .577 .707 r
F P
0 g
s
.43493 .61249 m .43199 .65072 L .40086 .6478 L p .707 .577 .707 r
F P
0 g
s
.40086 .6478 m .4038 .60957 L .43493 .61249 L p .707 .577 .707 r
F P
0 g
s
.34109 .67005 m .3423 .65098 L .37156 .65135 L p .707 .577 .707 r
F P
0 g
s
.36914 .64563 m .37208 .60739 L .4038 .60957 L p .707 .577 .707 r
F P
0 g
s
.37156 .65135 m .37035 .67042 L .34109 .67005 L p .707 .577 .707 r
F P
0 g
s
.4038 .60957 m .40086 .6478 L .36914 .64563 L p .707 .577 .707 r
F P
0 g
s
.43446 .65572 m .43326 .67479 L .40211 .67205 L p .707 .577 .707 r
F P
0 g
s
.40211 .67205 m .40332 .65298 L .43446 .65572 L p .707 .577 .707 r
F P
0 g
s
.37035 .67042 m .37156 .65135 L .40332 .65298 L p .707 .577 .707 r
F P
0 g
s
.40332 .65298 m .40211 .67205 L .37035 .67042 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaH008Io
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH015YF3000NWoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^
Ool006aoo`<000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH00000JGoo001WOol00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000J7oo001VOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Io
o`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo6@0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001IOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000@OolA0014
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool80003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool60003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Woo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000`Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00Dgoo00<005YF0000
15YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000eYF1P001eYF00<005YFFUH01UYF00<005YF
FUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool005=oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH70003FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002eoo`00>7oo
7@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
<Woo1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF6P0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02moo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF00AJEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00
0006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH:0008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPL00003FUH005YF00IJEP03001JEUYF00IJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00000UYF1P0025YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00
15YF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@0009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000QJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00005`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHC0007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000IJEP03001JEUYF00<002moo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF:P0015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPX0039oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH0
1000FUIJEUYF7@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPl000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000/Ool00`00
FUH00002FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH01000FUH005YF10001EYF00@005YFFUIJEPT000=JEQ4000=JEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0004FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF010000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000_Ool40004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30002FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003=o
o`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00H000=JEP03001JEUYF00IJEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00
00005P001eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000fOol50004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF3@0015YF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF5`000eYF00<005YFFUH00P00;Woo000kOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH70009Ool00`00FUIJEP0C0004FUH01000FUIJEUYF2@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF0000000300000eYF0000000^Ool002eo
obT0011oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0800000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008000=JEP<002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF4@003Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`001goo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUHQ
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@000goo200015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH400000eYF0000000@0003FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000UYF00<007ooOol0;7oo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00FUH005YF1`0015YF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF5`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001@005goo5P00<Woo000/OolJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUHA0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1eYF7P0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000006=oo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF1P00GGoo000c
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH80002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP05001HOol003Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH40002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUH00002001EOol004=ooa4000AJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03001JEUYF009JEP03001J
EUYF00=JEP04001JEUYFFUH2001DOol005Aooa<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH00000
1UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00D005YFFUH005YF
008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
E7oo001VOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000aOolF000OOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA000>Ool20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH00P00
EGoo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJ
EP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00=JEP03001J
EUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000Woo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH020000eYF00<005YFFUH00P00EGoo000/Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
0002FUH00`00FUIJEP03FUH500000eYF0000001EOol002aoo`03001JEP00024000AJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00AJEP04001JEUYFFUH3001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000=oo`P000=JEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUHB001FOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P00Igoo000^Ool200000eYF001JEP04FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH20003Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo000`Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF10001Goo0P001UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000
06]oo`00=7oo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF00001goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@00K7oo000kOolA0004FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP04000:Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0400000eYF001JEP02FUH8001TOol004aooaH0015o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00EJ
EP04001JEUYFFUH7001MOol007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP04001JEUYF
FUH70008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05001HOol007eoob0000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00SWoo00<005YF00000UYF5@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00SWoo00<005YF00000P001EYF00@005YFFUIJEPT000=ooa4000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQX000AJEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP03001oogoo05=oo`00T7oo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<007ooOol0Dgoo002EOol7
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00EGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Eoo`00YGoo4@0015YF00@005YFFUIJEPT005Ioo`00]Woo2000Ggoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5964 .76511 m .59455 .71098 L .56338 .70949 L p .707 .577 .707 r
F P
0 g
s
.59455 .71098 m .5964 .76511 L .62822 .76313 L p .707 .577 .707 r
F P
0 g
s
.62822 .76313 m .62636 .70901 L .59455 .71098 L p .707 .577 .707 r
F P
0 g
s
.62636 .70901 m .62822 .76313 L .65757 .75789 L p .707 .577 .707 r
F P
0 g
s
.65757 .75789 m .65571 .70376 L .62636 .70901 L p .707 .577 .707 r
F P
0 g
s
.56524 .76362 m .56338 .70949 L .53592 .70469 L p .707 .577 .707 r
F P
0 g
s
.56338 .70949 m .56524 .76362 L .5964 .76511 L p .707 .577 .707 r
F P
0 g
s
.65571 .70376 m .65757 .75789 L .68158 .74989 L p .707 .577 .707 r
F P
0 g
s
.68158 .74989 m .67973 .69576 L .65571 .70376 L p .707 .577 .707 r
F P
0 g
s
.53777 .75882 m .53592 .70469 L .51484 .69704 L p .707 .577 .707 r
F P
0 g
s
.53592 .70469 m .53777 .75882 L .56524 .76362 L p .707 .577 .707 r
F P
0 g
s
.59914 .82733 m .5962 .79304 L .56507 .7921 L p .707 .577 .707 r
F P
0 g
s
.5962 .79304 m .59914 .82733 L .63086 .82375 L p .707 .577 .707 r
F P
0 g
s
.63086 .82375 m .62792 .78946 L .5962 .79304 L p .707 .577 .707 r
F P
0 g
s
.62792 .78946 m .63086 .82375 L .66006 .81602 L p .707 .577 .707 r
F P
0 g
s
.66006 .81602 m .65712 .78172 L .62792 .78946 L p .707 .577 .707 r
F P
0 g
s
.67973 .69576 m .68158 .74989 L .69791 .73992 L p .707 .577 .707 r
F P
0 g
s
.69791 .73992 m .69605 .68579 L .67973 .69576 L p .707 .577 .707 r
F P
0 g
s
.56801 .82639 m .56507 .7921 L .53757 .78674 L p .707 .577 .707 r
F P
0 g
s
.56507 .7921 m .56801 .82639 L .59914 .82733 L p .707 .577 .707 r
F P
0 g
s
.65712 .78172 m .66006 .81602 L .68389 .80488 L p .707 .577 .707 r
F P
0 g
s
.68389 .80488 m .68095 .77058 L .65712 .78172 L p .707 .577 .707 r
F P
0 g
s
.59788 .85326 m .59668 .83581 L .56553 .8347 L p .707 .577 .707 r
F P
0 g
s
.59668 .83581 m .59788 .85326 L .62964 .85018 L p .707 .577 .707 r
F P
0 g
s
.62964 .85018 m .62844 .83272 L .59668 .83581 L p .707 .577 .707 r
F P
0 g
s
.62844 .83272 m .62964 .85018 L .6589 .84321 L p .707 .577 .707 r
F P
0 g
s
.6589 .84321 m .6577 .82575 L .62844 .83272 L p .707 .577 .707 r
F P
0 g
s
.51484 .69704 m .5167 .75116 L .53777 .75882 L p .707 .577 .707 r
F P
0 g
s
.5167 .75116 m .51484 .69704 L .50222 .68729 L p .707 .577 .707 r
F P
0 g
s
.56674 .85216 m .56553 .8347 L .53805 .82952 L p .707 .577 .707 r
F P
0 g
s
.56553 .8347 m .56674 .85216 L .59788 .85326 L p .707 .577 .707 r
F P
0 g
s
.54051 .82104 m .53757 .78674 L .5164 .77749 L p .707 .577 .707 r
F P
0 g
s
.53757 .78674 m .54051 .82104 L .56801 .82639 L p .707 .577 .707 r
F P
0 g
s
.6577 .82575 m .6589 .84321 L .68281 .83303 L p .707 .577 .707 r
F P
0 g
s
.68281 .83303 m .6816 .81558 L .6577 .82575 L p .707 .577 .707 r
F P
0 g
s
.53805 .82952 m .53925 .84697 L .56674 .85216 L p .707 .577 .707 r
F P
0 g
s
.68095 .77058 m .68389 .80488 L .70001 .79142 L p .707 .577 .707 r
F P
0 g
s
.70001 .79142 m .69707 .75713 L .68095 .77058 L p .707 .577 .707 r
F P
0 g
s
.69605 .68579 m .69791 .73992 L .70495 .72895 L p .707 .577 .707 r
F P
0 g
s
.70495 .72895 m .70309 .67482 L .69605 .68579 L p .707 .577 .707 r
F P
0 g
s
.53925 .84697 m .53805 .82952 L .51692 .82076 L p .707 .577 .707 r
F P
0 g
s
.50222 .68729 m .50407 .74142 L .5167 .75116 L p .707 .577 .707 r
F P
0 g
s
.5164 .77749 m .51934 .81178 L .54051 .82104 L p .707 .577 .707 r
F P
0 g
s
.51692 .82076 m .51812 .83821 L .53925 .84697 L p .707 .577 .707 r
F P
0 g
s
.6816 .81558 m .68281 .83303 L .69901 .82064 L p .707 .577 .707 r
F P
0 g
s
.69901 .82064 m .6978 .80319 L .6816 .81558 L p .707 .577 .707 r
F P
0 g
s
.51934 .81178 m .5164 .77749 L .50363 .76525 L p .707 .577 .707 r
F P
0 g
s
.50407 .74142 m .50222 .68729 L .49928 .6764 L p .707 .577 .707 r
F P
0 g
s
.69707 .75713 m .70001 .79142 L .70684 .77697 L p .707 .577 .707 r
F P
0 g
s
.70684 .77697 m .7039 .74268 L .69707 .75713 L p .707 .577 .707 r
F P
0 g
s
.51812 .83821 m .51692 .82076 L .5042 .80928 L p .707 .577 .707 r
F P
0 g
s
.70309 .67482 m .70495 .72895 L .70201 .71806 L p .707 .577 .707 r
F P
0 g
s
.70201 .71806 m .70015 .66393 L .70309 .67482 L p .707 .577 .707 r
F P
0 g
s
.50363 .76525 m .50656 .79954 L .51934 .81178 L p .707 .577 .707 r
F P
0 g
s
.49928 .6764 m .50114 .73052 L .50407 .74142 L p .707 .577 .707 r
F P
0 g
s
.5042 .80928 m .50541 .82673 L .51812 .83821 L p .707 .577 .707 r
F P
0 g
s
.6978 .80319 m .69901 .82064 L .70592 .80726 L p .707 .577 .707 r
F P
0 g
s
.70592 .80726 m .70472 .78981 L .6978 .80319 L p .707 .577 .707 r
F P
0 g
s
.50656 .79954 m .50363 .76525 L .5005 .75122 L p .707 .577 .707 r
F P
0 g
s
.4867 .82121 m .49119 .31645 L .44718 .31361 L p .707 .577 .707 r
F P
0 g
s
.50114 .73052 m .49928 .6764 L .50632 .66543 L p .707 .577 .707 r
F P
0 g
s
.50541 .82673 m .5042 .80928 L .50116 .79621 L p .707 .577 .707 r
F P
0 g
s
.5005 .75122 m .50344 .78551 L .50656 .79954 L p .707 .577 .707 r
F P
0 g
s
.50116 .79621 m .50236 .81366 L .50541 .82673 L p .707 .577 .707 r
F P
0 g
s
.50632 .66543 m .50818 .71955 L .50114 .73052 L p .707 .577 .707 r
F P
0 g
s
.50344 .78551 m .5005 .75122 L .50734 .73676 L p .707 .577 .707 r
F P
0 g
s
.50818 .71955 m .50632 .66543 L .52265 .65545 L p .707 .577 .707 r
F P
0 g
s
.50236 .81366 m .50116 .79621 L .50807 .78283 L p .707 .577 .707 r
F P
0 g
s
.50734 .73676 m .51027 .77106 L .50344 .78551 L p .707 .577 .707 r
F P
0 g
s
.50807 .78283 m .50928 .80028 L .50236 .81366 L p .707 .577 .707 r
F P
0 g
s
.52265 .65545 m .5245 .70958 L .50818 .71955 L p .707 .577 .707 r
F P
0 g
s
.51027 .77106 m .50734 .73676 L .52346 .72331 L p .707 .577 .707 r
F P
0 g
s
.50928 .80028 m .50807 .78283 L .52427 .77044 L p .707 .577 .707 r
F P
0 g
s
.52346 .72331 m .52639 .7576 L .51027 .77106 L p .707 .577 .707 r
F P
0 g
s
.52427 .77044 m .52548 .78789 L .50928 .80028 L p .707 .577 .707 r
F P
0 g
s
.52639 .7576 m .52346 .72331 L .54728 .71217 L p .707 .577 .707 r
F P
0 g
s
.52548 .78789 m .52427 .77044 L .54817 .76026 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .55022 .74646 L .52639 .7576 L p .707 .577 .707 r
F P
0 g
s
.54817 .76026 m .54938 .77772 L .52548 .78789 L p .707 .577 .707 r
F P
0 g
s
.49119 .31645 m .4867 .82121 L .53164 .82057 L p .707 .577 .707 r
F P
0 g
s
.5245 .70958 m .52265 .65545 L .54666 .64745 L p .707 .577 .707 r
F P
0 g
s
.54666 .64745 m .54851 .70158 L .5245 .70958 L p .707 .577 .707 r
F P
0 g
s
.53164 .82057 m .53613 .31581 L .49119 .31645 L p .707 .577 .707 r
F P
0 g
s
.54851 .70158 m .54666 .64745 L .57601 .64221 L p .707 .577 .707 r
F P
0 g
s
.57601 .64221 m .57787 .69634 L .54851 .70158 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .57648 .70443 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.55022 .74646 m .54959 .73911 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.54959 .73911 m .54728 .71217 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.57787 .69634 m .57601 .64221 L .60782 .64023 L p .707 .577 .707 r
F P
0 g
s
.60782 .64023 m .60968 .69436 L .57787 .69634 L p .707 .577 .707 r
F P
0 g
s
.57942 .73872 m .57648 .70443 L .6082 .70086 L p .707 .577 .707 r
F P
0 g
s
.57648 .70443 m .57942 .73872 L .55022 .74646 L p .707 .577 .707 r
F P
0 g
s
.6082 .70086 m .61114 .73515 L .57942 .73872 L p .707 .577 .707 r
F P
0 g
s
.54938 .77772 m .54817 .76026 L .57743 .75329 L p .707 .577 .707 r
F P
0 g
s
.57743 .75329 m .57864 .77075 L .54938 .77772 L p .707 .577 .707 r
F P
0 g
s
.57864 .77075 m .57743 .75329 L .60919 .75021 L p .707 .577 .707 r
F P
0 g
s
.60919 .75021 m .6104 .76766 L .57864 .77075 L p .707 .577 .707 r
F P
0 g
s
.57761 .31175 m .57335 .79065 L p .60707 .80944 L .707 .577 .707 r
F P
0 g
s
.57335 .79065 m .57312 .81652 L .58421 .81421 L p .707 .577 .707 r
F P
0 g
s
.58421 .81421 m .60707 .80944 L p .57335 .79065 L .707 .577 .707 r
F P
0 g
s
.53613 .31581 m .53164 .82057 L .57312 .81652 L p .707 .577 .707 r
F P
0 g
s
.57312 .81652 m .57761 .31175 L .53613 .31581 L p .707 .577 .707 r
F P
0 g
s
.7039 .74268 m .70684 .77697 L .70372 .76294 L p .707 .577 .707 r
F P
0 g
s
.70372 .76294 m .70078 .72864 L .7039 .74268 L p .707 .577 .707 r
F P
0 g
s
.44269 .81837 m .44718 .31361 L .40842 .30756 L p .707 .577 .707 r
F P
0 g
s
.44718 .31361 m .44269 .81837 L .4867 .82121 L p .707 .577 .707 r
F P
0 g
s
.70015 .66393 m .70201 .71806 L .68939 .70831 L p .707 .577 .707 r
F P
0 g
s
.68939 .70831 m .68753 .65418 L .70015 .66393 L p .707 .577 .707 r
F P
0 g
s
.60968 .69436 m .60782 .64023 L .63899 .64172 L p .707 .577 .707 r
F P
0 g
s
.60707 .80944 m .61156 .30468 L .57761 .31175 L p .707 .577 .707 r
F P
0 g
s
.70472 .78981 m .70592 .80726 L .70287 .79419 L p .707 .577 .707 r
F P
0 g
s
.70287 .79419 m .70167 .77674 L .70472 .78981 L p .707 .577 .707 r
F P
0 g
s
.2534 .72829 m .25154 .67417 L .22037 .67268 L p .707 .577 .707 r
F P
0 g
s
.25154 .67417 m .2534 .72829 L .28521 .72632 L p .707 .577 .707 r
F P
0 g
s
.28521 .72632 m .28335 .67219 L .25154 .67417 L p .707 .577 .707 r
F P
0 g
s
.40393 .81233 m .40842 .30756 L .37869 .29891 L p .707 .577 .707 r
F P
0 g
s
.40842 .30756 m .40393 .81233 L .44269 .81837 L p .707 .577 .707 r
F P
0 g
s
.28335 .67219 m .28521 .72632 L .31456 .72108 L p .707 .577 .707 r
F P
0 g
s
.31456 .72108 m .3127 .66695 L .28335 .67219 L p .707 .577 .707 r
F P
0 g
s
.70078 .72864 m .70372 .76294 L .69094 .75069 L p .707 .577 .707 r
F P
0 g
s
.69094 .75069 m .68801 .7164 L .70078 .72864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22223 .72681 m .22037 .67268 L .19291 .66787 L p .707 .577 .707 r
F P
0 g
s
.22037 .67268 m .22223 .72681 L .2534 .72829 L p .707 .577 .707 r
F P
0 g
s
.68753 .65418 m .68939 .70831 L .66831 .70065 L p .707 .577 .707 r
F P
0 g
s
.66831 .70065 m .66645 .64653 L .68753 .65418 L p .707 .577 .707 r
F P
0 g
s
.3127 .66695 m .31456 .72108 L .33857 .71308 L p .707 .577 .707 r
F P
0 g
s
.33857 .71308 m .33672 .65895 L .3127 .66695 L p .707 .577 .707 r
F P
0 g
s
.63899 .64172 m .64085 .69585 L .60968 .69436 L p .707 .577 .707 r
F P
0 g
s
.63934 .70179 m .64228 .73609 L .61114 .73515 L p .707 .577 .707 r
F P
0 g
s
.61114 .73515 m .6082 .70086 L .63934 .70179 L p .707 .577 .707 r
F P
0 g
s
.64034 .75131 m .64154 .76877 L .6104 .76766 L p .707 .577 .707 r
F P
0 g
s
.6104 .76766 m .60919 .75021 L .64034 .75131 L p .707 .577 .707 r
F P
0 g
s
.61156 .30468 m .60707 .80944 L .63018 .80004 L p .707 .577 .707 r
F P
0 g
s
.63018 .80004 m .63467 .29528 L .61156 .30468 L p .707 .577 .707 r
F P
0 g
s
.70167 .77674 m .70287 .79419 L .69016 .78272 L p .707 .577 .707 r
F P
0 g
s
.69016 .78272 m .68896 .76526 L .70167 .77674 L p .707 .577 .707 r
F P
0 g
s
.19476 .722 m .19291 .66787 L .17183 .66022 L p .707 .577 .707 r
F P
0 g
s
.19291 .66787 m .19476 .722 L .22223 .72681 L p .707 .577 .707 r
F P
0 g
s
.25613 .79051 m .25319 .75622 L .22206 .75528 L p .707 .577 .707 r
F P
0 g
s
.25319 .75622 m .25613 .79051 L .28785 .78694 L p .707 .577 .707 r
F P
0 g
s
.28785 .78694 m .28491 .75265 L .25319 .75622 L p .707 .577 .707 r
F P
0 g
s
.28491 .75265 m .28785 .78694 L .31705 .7792 L p .707 .577 .707 r
F P
0 g
s
.31705 .7792 m .31411 .74491 L .28491 .75265 L p .707 .577 .707 r
F P
0 g
s
.68801 .7164 m .69094 .75069 L .66977 .74144 L p .707 .577 .707 r
F P
0 g
s
.66977 .74144 m .66684 .70715 L .68801 .7164 L p .707 .577 .707 r
F P
0 g
s
.33672 .65895 m .33857 .71308 L .3549 .7031 L p .707 .577 .707 r
F P
0 g
s
.3549 .7031 m .35304 .64897 L .33672 .65895 L p .707 .577 .707 r
F P
0 g
s
.225 .78958 m .22206 .75528 L .19456 .74993 L p .707 .577 .707 r
F P
0 g
s
.22206 .75528 m .225 .78958 L .25613 .79051 L p .707 .577 .707 r
F P
0 g
s
.3742 .80367 m .37869 .29891 L .36091 .2885 L p .707 .577 .707 r
F P
0 g
s
.37869 .29891 m .3742 .80367 L .40393 .81233 L p .707 .577 .707 r
F P
0 g
s
.66645 .64653 m .66831 .70065 L .64085 .69585 L p .707 .577 .707 r
F P
0 g
s
.64085 .69585 m .63899 .64172 L .66645 .64653 L p .707 .577 .707 r
F P
0 g
s
.31411 .74491 m .31705 .7792 L .34088 .76806 L p .707 .577 .707 r
F P
0 g
s
.34088 .76806 m .33794 .73377 L .31411 .74491 L p .707 .577 .707 r
F P
0 g
s
.25488 .81645 m .25367 .79899 L .22252 .79789 L p .707 .577 .707 r
F P
0 g
s
.25367 .79899 m .25488 .81645 L .28663 .81336 L p .707 .577 .707 r
F P
0 g
s
.28663 .81336 m .28543 .79591 L .25367 .79899 L p .707 .577 .707 r
F P
0 g
s
.28543 .79591 m .28663 .81336 L .3159 .80639 L p .707 .577 .707 r
F P
0 g
s
.3159 .80639 m .31469 .78894 L .28543 .79591 L p .707 .577 .707 r
F P
0 g
s
.17183 .66022 m .17369 .71435 L .19476 .722 L p .707 .577 .707 r
F P
0 g
s
.17369 .71435 m .17183 .66022 L .15921 .65047 L p .707 .577 .707 r
F P
0 g
s
.22373 .81534 m .22252 .79789 L .19504 .7927 L p .707 .577 .707 r
F P
0 g
s
.22252 .79789 m .22373 .81534 L .25488 .81645 L p .707 .577 .707 r
F P
0 g
s
.68896 .76526 m .69016 .78272 L .66903 .77396 L p .707 .577 .707 r
F P
0 g
s
.66903 .77396 m .66782 .7565 L .68896 .76526 L p .707 .577 .707 r
F P
0 g
s
.1975 .78422 m .19456 .74993 L .17339 .74068 L p .707 .577 .707 r
F P
0 g
s
.19456 .74993 m .1975 .78422 L .225 .78958 L p .707 .577 .707 r
F P
0 g
s
.31469 .78894 m .3159 .80639 L .3398 .79621 L p .707 .577 .707 r
F P
0 g
s
.3398 .79621 m .33859 .77876 L .31469 .78894 L p .707 .577 .707 r
F P
0 g
s
.66684 .70715 m .66977 .74144 L .64228 .73609 L p .707 .577 .707 r
F P
0 g
s
.64228 .73609 m .63934 .70179 L .66684 .70715 L p .707 .577 .707 r
F P
0 g
s
.19504 .7927 m .19624 .81015 L .22373 .81534 L p .707 .577 .707 r
F P
0 g
s
.33794 .73377 m .34088 .76806 L .357 .75461 L p .707 .577 .707 r
F P
0 g
s
.357 .75461 m .35406 .72031 L .33794 .73377 L p .707 .577 .707 r
F P
0 g
s
.63467 .29528 m .63018 .80004 L .64017 .78923 L p .707 .577 .707 r
F P
0 g
s
.64154 .76877 m .64034 .75131 L .66782 .7565 L p .707 .577 .707 r
F P
0 g
s
.64017 .78923 m .64466 .28447 L .63467 .29528 L p .707 .577 .707 r
F P
0 g
s
.35304 .64897 m .3549 .7031 L .36194 .69213 L p .707 .577 .707 r
F P
0 g
s
.36194 .69213 m .36008 .638 L .35304 .64897 L p .707 .577 .707 r
F P
0 g
s
.19624 .81015 m .19504 .7927 L .17391 .78394 L p .707 .577 .707 r
F P
0 g
s
.15921 .65047 m .16106 .7046 L .17369 .71435 L p .707 .577 .707 r
F P
0 g
s
.17339 .74068 m .17633 .77497 L .1975 .78422 L p .707 .577 .707 r
F P
0 g
s
.66782 .7565 m .66903 .77396 L .64154 .76877 L p .707 .577 .707 r
F P
0 g
s
.17391 .78394 m .17511 .80139 L .19624 .81015 L p .707 .577 .707 r
F P
0 g
s
.33859 .77876 m .3398 .79621 L .356 .78383 L p .707 .577 .707 r
F P
0 g
s
.356 .78383 m .35479 .76638 L .33859 .77876 L p .707 .577 .707 r
F P
0 g
s
.17633 .77497 m .17339 .74068 L .16062 .72843 L p .707 .577 .707 r
F P
0 g
s
.16106 .7046 m .15921 .65047 L .15627 .63958 L p .707 .577 .707 r
F P
0 g
s
.35406 .72031 m .357 .75461 L .36383 .74015 L p .707 .577 .707 r
F P
0 g
s
.36383 .74015 m .36089 .70586 L .35406 .72031 L p .707 .577 .707 r
F P
0 g
s
.359 .68124 m .35715 .62711 L .36008 .638 L p .707 .577 .707 r
F P
0 g
s
.35479 .76638 m .356 .78383 L .36291 .77045 L p .707 .577 .707 r
F P
0 g
s
.36291 .77045 m .36171 .75299 L .35479 .76638 L p .707 .577 .707 r
F P
0 g
s
.35715 .62711 m .359 .68124 L .34638 .67149 L p .707 .577 .707 r
F P
0 g
s
.34638 .67149 m .34452 .61736 L .35715 .62711 L p .707 .577 .707 r
F P
0 g
s
.35777 .69183 m .36008 .71877 L p .34793 .71388 L .707 .577 .707 r
F P
0 g
s
.36008 .71877 m .36071 .72612 L .35963 .72509 L p .707 .577 .707 r
F P
0 g
s
.35963 .72509 m .34793 .71388 L p .36008 .71877 L .707 .577 .707 r
F P
0 g
s
.34793 .71388 m .345 .67959 L .35777 .69183 L p .707 .577 .707 r
F P
0 g
s
.35866 .73992 m .35986 .75738 L .34715 .7459 L p .707 .577 .707 r
F P
0 g
s
.34715 .7459 m .34595 .72845 L .35866 .73992 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35681 .27734 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35642 .79326 m .35665 .76739 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35665 .76739 m .36091 .2885 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.36008 .638 m .36194 .69213 L .359 .68124 L p .707 .577 .707 r
F P
0 g
s
.36089 .70586 m .36383 .74015 L .36071 .72612 L p .707 .577 .707 r
F P
0 g
s
.36071 .72612 m .35777 .69183 L .36089 .70586 L p .707 .577 .707 r
F P
0 g
s
.36171 .75299 m .36291 .77045 L .35986 .75738 L p .707 .577 .707 r
F P
0 g
s
.35986 .75738 m .35866 .73992 L .36171 .75299 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35642 .79326 L .3742 .80367 L p .707 .577 .707 r
F P
0 g
s
.17511 .80139 m .17391 .78394 L .16119 .77246 L p .707 .577 .707 r
F P
0 g
s
.16062 .72843 m .16356 .76273 L .17633 .77497 L p .707 .577 .707 r
F P
0 g
s
.15627 .63958 m .15813 .69371 L .16106 .7046 L p .707 .577 .707 r
F P
0 g
s
.16119 .77246 m .1624 .78992 L .17511 .80139 L p .707 .577 .707 r
F P
0 g
s
.16356 .76273 m .16062 .72843 L .15749 .7144 L p .707 .577 .707 r
F P
0 g
s
.64466 .28447 m .64017 .78923 L .63608 .77807 L p .707 .577 .707 r
F P
0 g
s
.63608 .77807 m .64057 .27331 L .64466 .28447 L p .707 .577 .707 r
F P
0 g
s
.15813 .69371 m .15627 .63958 L .16331 .62861 L p .707 .577 .707 r
F P
0 g
s
.1624 .78992 m .16119 .77246 L .15815 .75939 L p .707 .577 .707 r
F P
0 g
s
.15749 .7144 m .16043 .74869 L .16356 .76273 L p .707 .577 .707 r
F P
0 g
s
.35681 .27734 m .35233 .7821 L .35642 .79326 L p .707 .577 .707 r
F P
0 g
s
.35233 .7821 m .35681 .27734 L .36681 .26653 L p .707 .577 .707 r
F P
0 g
s
.15815 .75939 m .15935 .77685 L .1624 .78992 L p .707 .577 .707 r
F P
0 g
s
.16331 .62861 m .16517 .68274 L .15813 .69371 L p .707 .577 .707 r
F P
0 g
s
.16043 .74869 m .15749 .7144 L .16433 .69995 L p .707 .577 .707 r
F P
0 g
s
.16517 .68274 m .16331 .62861 L .17964 .61864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15935 .77685 m .15815 .75939 L .16506 .74601 L p .707 .577 .707 r
F P
0 g
s
.64057 .27331 m .63608 .77807 L .6183 .76766 L p .707 .577 .707 r
F P
0 g
s
.6183 .76766 m .62279 .26289 L .64057 .27331 L p .707 .577 .707 r
F P
0 g
s
.16433 .69995 m .16726 .73424 L .16043 .74869 L p .707 .577 .707 r
F P
0 g
s
.34452 .61736 m .34638 .67149 L .3253 .66384 L p .707 .577 .707 r
F P
0 g
s
.3253 .66384 m .32345 .60971 L .34452 .61736 L p .707 .577 .707 r
F P
0 g
s
.16506 .74601 m .16627 .76347 L .15935 .77685 L p .707 .577 .707 r
F P
0 g
s
.17964 .61864 m .18149 .67277 L .16517 .68274 L p .707 .577 .707 r
F P
0 g
s
.16726 .73424 m .16433 .69995 L .18045 .6865 L p .707 .577 .707 r
F P
0 g
s
.18149 .67277 m .17964 .61864 L .20365 .61064 L p .707 .577 .707 r
F P
0 g
s
.36232 .77129 m .36681 .26653 L .38991 .25712 L p .707 .577 .707 r
F P
0 g
s
.36681 .26653 m .36232 .77129 L .35233 .7821 L p .707 .577 .707 r
F P
0 g
s
.345 .67959 m .34793 .71388 L .32676 .70463 L p .707 .577 .707 r
F P
0 g
s
.32676 .70463 m .32383 .67034 L .345 .67959 L p .707 .577 .707 r
F P
0 g
s
.32345 .60971 m .3253 .66384 L .29784 .65903 L p .707 .577 .707 r
F P
0 g
s
.29784 .65903 m .29598 .60491 L .32345 .60971 L p .707 .577 .707 r
F P
0 g
s
.16627 .76347 m .16506 .74601 L .18126 .73363 L p .707 .577 .707 r
F P
0 g
s
.18045 .6865 m .18338 .72079 L .16726 .73424 L p .707 .577 .707 r
F P
0 g
s
.20551 .66477 m .20365 .61064 L .233 .60539 L p .707 .577 .707 r
F P
0 g
s
.20365 .61064 m .20551 .66477 L .18149 .67277 L p .707 .577 .707 r
F P
0 g
s
.18126 .73363 m .18247 .75108 L .16627 .76347 L p .707 .577 .707 r
F P
0 g
s
.18338 .72079 m .18045 .6865 L .20427 .67535 L p .707 .577 .707 r
F P
0 g
s
.34595 .72845 m .34715 .7459 L .32602 .73714 L p .707 .577 .707 r
F P
0 g
s
.32602 .73714 m .32481 .71969 L .34595 .72845 L p .707 .577 .707 r
F P
0 g
s
.62279 .26289 m .6183 .76766 L .58857 .759 L p .707 .577 .707 r
F P
0 g
s
.58857 .759 m .59306 .25424 L .62279 .26289 L p .707 .577 .707 r
F P
0 g
s
.29598 .60491 m .29784 .65903 L .26667 .65755 L p .707 .577 .707 r
F P
0 g
s
.26667 .65755 m .26482 .60342 L .29598 .60491 L p .707 .577 .707 r
F P
0 g
s
.32383 .67034 m .32676 .70463 L .29927 .69927 L p .707 .577 .707 r
F P
0 g
s
.29927 .69927 m .29633 .66498 L .32383 .67034 L p .707 .577 .707 r
F P
0 g
s
.23486 .65952 m .233 .60539 L .26482 .60342 L p .707 .577 .707 r
F P
0 g
s
.233 .60539 m .23486 .65952 L .20551 .66477 L p .707 .577 .707 r
F P
0 g
s
.26482 .60342 m .26667 .65755 L .23486 .65952 L p .707 .577 .707 r
F P
0 g
s
.73361 .65748 m .73175 .60335 L .70059 .60187 L p .707 .577 .707 r
F P
0 g
s
.73175 .60335 m .73361 .65748 L .76542 .65551 L p .707 .577 .707 r
F P
0 g
s
.76542 .65551 m .76357 .60138 L .73175 .60335 L p .707 .577 .707 r
F P
0 g
s
.18247 .75108 m .18126 .73363 L .20516 .72345 L p .707 .577 .707 r
F P
0 g
s
.20427 .67535 m .20721 .70965 L .18338 .72079 L p .707 .577 .707 r
F P
0 g
s
.76357 .60138 m .76542 .65551 L .79477 .65026 L p .707 .577 .707 r
F P
0 g
s
.79477 .65026 m .79292 .59614 L .76357 .60138 L p .707 .577 .707 r
F P
0 g
s
.20721 .70965 m .20427 .67535 L .23348 .66762 L p .707 .577 .707 r
F P
0 g
s
.38991 .25712 m .38543 .76189 L .36232 .77129 L p .707 .577 .707 r
F P
0 g
s
.38543 .76189 m .38991 .25712 L .42387 .25005 L p .707 .577 .707 r
F P
0 g
s
.70244 .65599 m .70059 .60187 L .67312 .59706 L p .707 .577 .707 r
F P
0 g
s
.70059 .60187 m .70244 .65599 L .73361 .65748 L p .707 .577 .707 r
F P
0 g
s
.29633 .66498 m .29927 .69927 L .26813 .69833 L p .707 .577 .707 r
F P
0 g
s
.26813 .69833 m .2652 .66404 L .29633 .66498 L p .707 .577 .707 r
F P
0 g
s
.20516 .72345 m .20637 .7409 L .18247 .75108 L p .707 .577 .707 r
F P
0 g
s
.32481 .71969 m .32602 .73714 L .29853 .73195 L p .707 .577 .707 r
F P
0 g
s
.29853 .73195 m .29733 .7145 L .32481 .71969 L p .707 .577 .707 r
F P
0 g
s
.23641 .70191 m .23348 .66762 L .2652 .66404 L p .707 .577 .707 r
F P
0 g
s
.23348 .66762 m .23641 .70191 L .20721 .70965 L p .707 .577 .707 r
F P
0 g
s
.79292 .59614 m .79477 .65026 L .81879 .64226 L p .707 .577 .707 r
F P
0 g
s
.81879 .64226 m .81693 .58814 L .79292 .59614 L p .707 .577 .707 r
F P
0 g
s
.2652 .66404 m .26813 .69833 L .23641 .70191 L p .707 .577 .707 r
F P
0 g
s
.20637 .7409 m .20516 .72345 L .23442 .71648 L p .707 .577 .707 r
F P
0 g
s
.67498 .65119 m .67312 .59706 L .65205 .58941 L p .707 .577 .707 r
F P
0 g
s
.67312 .59706 m .67498 .65119 L .70244 .65599 L p .707 .577 .707 r
F P
0 g
s
.59306 .25424 m .58857 .759 L .54981 .75296 L p .707 .577 .707 r
F P
0 g
s
.54981 .75296 m .55429 .2482 L .59306 .25424 L p .707 .577 .707 r
F P
0 g
s
.29733 .7145 m .29853 .73195 L .26739 .73085 L p .707 .577 .707 r
F P
0 g
s
.26739 .73085 m .26618 .71339 L .29733 .7145 L p .707 .577 .707 r
F P
0 g
s
.23442 .71648 m .23563 .73393 L .20637 .7409 L p .707 .577 .707 r
F P
0 g
s
.23563 .73393 m .23442 .71648 L .26618 .71339 L p .707 .577 .707 r
F P
0 g
s
.73634 .73402 m .7334 .69973 L .70227 .69879 L p .707 .577 .707 r
F P
0 g
s
.7334 .69973 m .73634 .73402 L .76806 .73045 L p .707 .577 .707 r
F P
0 g
s
.76806 .73045 m .76512 .69615 L .7334 .69973 L p .707 .577 .707 r
F P
0 g
s
.26618 .71339 m .26739 .73085 L .23563 .73393 L p .707 .577 .707 r
F P
0 g
s
.76512 .69615 m .76806 .73045 L .79727 .72271 L p .707 .577 .707 r
F P
0 g
s
.79727 .72271 m .79433 .68842 L .76512 .69615 L p .707 .577 .707 r
F P
0 g
s
.41938 .75481 m .42387 .25005 L .46534 .24599 L p .707 .577 .707 r
F P
0 g
s
.42387 .25005 m .41938 .75481 L .38543 .76189 L p .707 .577 .707 r
F P
0 g
s
.81693 .58814 m .81879 .64226 L .83511 .63229 L p .707 .577 .707 r
F P
0 g
s
.83511 .63229 m .83326 .57816 L .81693 .58814 L p .707 .577 .707 r
F P
0 g
s
.70521 .73309 m .70227 .69879 L .67477 .69344 L p .707 .577 .707 r
F P
0 g
s
.70227 .69879 m .70521 .73309 L .73634 .73402 L p .707 .577 .707 r
F P
0 g
s
.65205 .58941 m .6539 .64354 L .67498 .65119 L p .707 .577 .707 r
F P
0 g
s
.79433 .68842 m .79727 .72271 L .82109 .71157 L p .707 .577 .707 r
F P
0 g
s
.82109 .71157 m .81815 .67728 L .79433 .68842 L p .707 .577 .707 r
F P
0 g
s
.55429 .2482 m .54981 .75296 L .5058 .75012 L p .707 .577 .707 r
F P
0 g
s
.5058 .75012 m .51029 .24536 L .55429 .2482 L p .707 .577 .707 r
F P
0 g
s
.6539 .64354 m .65205 .58941 L .63942 .57966 L p .707 .577 .707 r
F P
0 g
s
.46086 .75076 m .46534 .24599 L .51029 .24536 L p .707 .577 .707 r
F P
0 g
s
.46534 .24599 m .46086 .75076 L .41938 .75481 L p .707 .577 .707 r
F P
0 g
s
.73509 .78705 m .73388 .76959 L .70274 .76849 L p .707 .577 .707 r
F P
0 g
s
.73388 .76959 m .73509 .78705 L .76685 .78396 L p .707 .577 .707 r
F P
0 g
s
.76685 .78396 m .76564 .76651 L .73388 .76959 L p .707 .577 .707 r
F P
0 g
s
.67771 .72773 m .67477 .69344 L .6536 .68418 L p .707 .577 .707 r
F P
0 g
s
.67477 .69344 m .67771 .72773 L .70521 .73309 L p .707 .577 .707 r
F P
0 g
s
.76564 .76651 m .76685 .78396 L .79611 .77699 L p .707 .577 .707 r
F P
0 g
s
.79611 .77699 m .7949 .75954 L .76564 .76651 L p .707 .577 .707 r
F P
0 g
s
.51029 .24536 m .5058 .75012 L .46086 .75076 L p .707 .577 .707 r
F P
0 g
s
.70394 .78594 m .70274 .76849 L .67525 .7633 L p .707 .577 .707 r
F P
0 g
s
.70274 .76849 m .70394 .78594 L .73509 .78705 L p .707 .577 .707 r
F P
0 g
s
.83326 .57816 m .83511 .63229 L .84215 .62132 L p .707 .577 .707 r
F P
0 g
s
.84215 .62132 m .8403 .56719 L .83326 .57816 L p .707 .577 .707 r
F P
0 g
s
.81815 .67728 m .82109 .71157 L .83721 .69811 L p .707 .577 .707 r
F P
0 g
s
.83721 .69811 m .83427 .66382 L .81815 .67728 L p .707 .577 .707 r
F P
0 g
s
.7949 .75954 m .79611 .77699 L .82001 .76681 L p .707 .577 .707 r
F P
0 g
s
.82001 .76681 m .81881 .74936 L .7949 .75954 L p .707 .577 .707 r
F P
0 g
s
.63942 .57966 m .64128 .63379 L .6539 .64354 L p .707 .577 .707 r
F P
0 g
s
.67525 .7633 m .67646 .78075 L .70394 .78594 L p .707 .577 .707 r
F P
0 g
s
.6536 .68418 m .65654 .71848 L .67771 .72773 L p .707 .577 .707 r
F P
0 g
s
.64128 .63379 m .63942 .57966 L .63649 .56877 L p .707 .577 .707 r
F P
0 g
s
.67646 .78075 m .67525 .7633 L .65412 .75454 L p .707 .577 .707 r
F P
0 g
s
.65654 .71848 m .6536 .68418 L .64083 .67194 L p .707 .577 .707 r
F P
0 g
s
.65412 .75454 m .65533 .77199 L .67646 .78075 L p .707 .577 .707 r
F P
0 g
s
.81881 .74936 m .82001 .76681 L .83621 .75443 L p .707 .577 .707 r
F P
0 g
s
.83621 .75443 m .83501 .73697 L .81881 .74936 L p .707 .577 .707 r
F P
0 g
s
.83427 .66382 m .83721 .69811 L .84404 .68366 L p .707 .577 .707 r
F P
0 g
s
.84404 .68366 m .84111 .64937 L .83427 .66382 L p .707 .577 .707 r
F P
0 g
s
.8403 .56719 m .84215 .62132 L .83922 .61043 L p .707 .577 .707 r
F P
0 g
s
.83922 .61043 m .83736 .5563 L .8403 .56719 L p .707 .577 .707 r
F P
0 g
s
.63649 .56877 m .63834 .6229 L .64128 .63379 L p .707 .577 .707 r
F P
0 g
s
.64083 .67194 m .64377 .70624 L .65654 .71848 L p .707 .577 .707 r
F P
0 g
s
.65533 .77199 m .65412 .75454 L .64141 .74306 L p .707 .577 .707 r
F P
0 g
s
.64377 .70624 m .64083 .67194 L .63771 .65791 L p .707 .577 .707 r
F P
0 g
s
.63834 .6229 m .63649 .56877 L .64352 .5578 L p .707 .577 .707 r
F P
0 g
s
.64141 .74306 m .64261 .76052 L .65533 .77199 L p .707 .577 .707 r
F P
0 g
s
.83501 .73697 m .83621 .75443 L .84313 .74105 L p .707 .577 .707 r
F P
0 g
s
.84313 .74105 m .84192 .72359 L .83501 .73697 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84111 .64937 m .84404 .68366 L .84092 .66963 L p .707 .577 .707 r
F P
0 g
s
.84092 .66963 m .83798 .63534 L .84111 .64937 L p .707 .577 .707 r
F P
0 g
s
.83736 .5563 m .83922 .61043 L .82659 .60068 L p .707 .577 .707 r
F P
0 g
s
.82659 .60068 m .82474 .54655 L .83736 .5563 L p .707 .577 .707 r
F P
0 g
s
.63771 .65791 m .64065 .6922 L .64377 .70624 L p .707 .577 .707 r
F P
0 g
s
.64352 .5578 m .64538 .61193 L .63834 .6229 L p .707 .577 .707 r
F P
0 g
s
.64261 .76052 m .64141 .74306 L .63836 .72999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64065 .6922 m .63771 .65791 L .64454 .64346 L p .707 .577 .707 r
F P
0 g
s
.63836 .72999 m .63956 .74745 L .64261 .76052 L p .707 .577 .707 r
F P
0 g
s
.3906 .62067 m .38874 .56654 L .35758 .56505 L p .707 .577 .707 r
F P
0 g
s
.38874 .56654 m .3906 .62067 L .42241 .61869 L p .707 .577 .707 r
F P
0 g
s
.42241 .61869 m .42056 .56456 L .38874 .56654 L p .707 .577 .707 r
F P
0 g
s
.64538 .61193 m .64352 .5578 L .65985 .54783 L p .707 .577 .707 r
F P
0 g
s
.42056 .56456 m .42241 .61869 L .45176 .61345 L p .707 .577 .707 r
F P
0 g
s
.45176 .61345 m .44991 .55932 L .42056 .56456 L p .707 .577 .707 r
F P
0 g
s
.84192 .72359 m .84313 .74105 L .84008 .72798 L p .707 .577 .707 r
F P
0 g
s
.84008 .72798 m .83887 .71052 L .84192 .72359 L p .707 .577 .707 r
F P
0 g
s
.35943 .61918 m .35758 .56505 L .33011 .56025 L p .707 .577 .707 r
F P
0 g
s
.35758 .56505 m .35943 .61918 L .3906 .62067 L p .707 .577 .707 r
F P
0 g
s
.83798 .63534 m .84092 .66963 L .82815 .65739 L p .707 .577 .707 r
F P
0 g
s
.82815 .65739 m .82521 .6231 L .83798 .63534 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82474 .54655 m .82659 .60068 L .80552 .59303 L p .707 .577 .707 r
F P
0 g
s
.80552 .59303 m .80366 .5389 L .82474 .54655 L p .707 .577 .707 r
F P
0 g
s
.44991 .55932 m .45176 .61345 L .47578 .60545 L p .707 .577 .707 r
F P
0 g
s
.47578 .60545 m .47392 .55132 L .44991 .55932 L p .707 .577 .707 r
F P
0 g
s
.64454 .64346 m .64748 .67775 L .64065 .6922 L p .707 .577 .707 r
F P
0 g
s
.65985 .54783 m .66171 .60195 L .64538 .61193 L p .707 .577 .707 r
F P
0 g
s
.63956 .74745 m .63836 .72999 L .64527 .71661 L p .707 .577 .707 r
F P
0 g
s
.33197 .61437 m .33011 .56025 L .30904 .55259 L p .707 .577 .707 r
F P
0 g
s
.33011 .56025 m .33197 .61437 L .35943 .61918 L p .707 .577 .707 r
F P
0 g
s
.66171 .60195 m .65985 .54783 L .68386 .53983 L p .707 .577 .707 r
F P
0 g
s
.64748 .67775 m .64454 .64346 L .66066 .63 L p .707 .577 .707 r
F P
0 g
s
.64527 .71661 m .64648 .73406 L .63956 .74745 L p .707 .577 .707 r
F P
0 g
s
.39333 .69721 m .39039 .66291 L .35926 .66198 L p .707 .577 .707 r
F P
0 g
s
.39039 .66291 m .39333 .69721 L .42505 .69363 L p .707 .577 .707 r
F P
0 g
s
.42505 .69363 m .42211 .65934 L .39039 .66291 L p .707 .577 .707 r
F P
0 g
s
.42211 .65934 m .42505 .69363 L .45426 .68589 L p .707 .577 .707 r
F P
0 g
s
.45426 .68589 m .45132 .6516 L .42211 .65934 L p .707 .577 .707 r
F P
0 g
s
.83887 .71052 m .84008 .72798 L .82737 .7165 L p .707 .577 .707 r
F P
0 g
s
.82737 .7165 m .82616 .69905 L .83887 .71052 L p .707 .577 .707 r
F P
0 g
s
.47392 .55132 m .47578 .60545 L .4921 .59547 L p .707 .577 .707 r
F P
0 g
s
.4921 .59547 m .49025 .54135 L .47392 .55132 L p .707 .577 .707 r
F P
0 g
s
.82521 .6231 m .82815 .65739 L .80698 .64814 L p .707 .577 .707 r
F P
0 g
s
.80698 .64814 m .80404 .61384 L .82521 .6231 L p .707 .577 .707 r
F P
0 g
s
.80366 .5389 m .80552 .59303 L .77805 .58822 L p .707 .577 .707 r
F P
0 g
s
.77805 .58822 m .77619 .53409 L .80366 .5389 L p .707 .577 .707 r
F P
0 g
s
.3622 .69627 m .35926 .66198 L .33176 .65662 L p .707 .577 .707 r
F P
0 g
s
.35926 .66198 m .3622 .69627 L .39333 .69721 L p .707 .577 .707 r
F P
0 g
s
.30904 .55259 m .31089 .60672 L .33197 .61437 L p .707 .577 .707 r
F P
0 g
s
.45132 .6516 m .45426 .68589 L .47808 .67475 L p .707 .577 .707 r
F P
0 g
s
.47808 .67475 m .47514 .64046 L .45132 .6516 L p .707 .577 .707 r
F P
0 g
s
.66066 .63 m .6636 .6643 L .64748 .67775 L p .707 .577 .707 r
F P
0 g
s
.68572 .59395 m .68386 .53983 L .71321 .53458 L p .707 .577 .707 r
F P
0 g
s
.68386 .53983 m .68572 .59395 L .66171 .60195 L p .707 .577 .707 r
F P
0 g
s
.31089 .60672 m .30904 .55259 L .29641 .54284 L p .707 .577 .707 r
F P
0 g
s
.64648 .73406 m .64527 .71661 L .66148 .70422 L p .707 .577 .707 r
F P
0 g
s
.6636 .6643 m .66066 .63 L .68449 .61886 L p .707 .577 .707 r
F P
0 g
s
.39208 .75023 m .39087 .73278 L .35973 .73167 L p .707 .577 .707 r
F P
0 g
s
.39087 .73278 m .39208 .75023 L .42384 .74715 L p .707 .577 .707 r
F P
0 g
s
.42384 .74715 m .42263 .72969 L .39087 .73278 L p .707 .577 .707 r
F P
0 g
s
.77619 .53409 m .77805 .58822 L .74689 .58673 L p .707 .577 .707 r
F P
0 g
s
.74689 .58673 m .74503 .53261 L .77619 .53409 L p .707 .577 .707 r
F P
0 g
s
.3347 .69091 m .33176 .65662 L .31059 .64737 L p .707 .577 .707 r
F P
0 g
s
.33176 .65662 m .3347 .69091 L .3622 .69627 L p .707 .577 .707 r
F P
0 g
s
.42263 .72969 m .42384 .74715 L .4531 .74018 L p .707 .577 .707 r
F P
0 g
s
.4531 .74018 m .45189 .72272 L .42263 .72969 L p .707 .577 .707 r
F P
0 g
s
.71507 .58871 m .71321 .53458 L .74503 .53261 L p .707 .577 .707 r
F P
0 g
s
.71321 .53458 m .71507 .58871 L .68572 .59395 L p .707 .577 .707 r
F P
0 g
s
.66148 .70422 m .66268 .72168 L .64648 .73406 L p .707 .577 .707 r
F P
0 g
s
.80404 .61384 m .80698 .64814 L .77948 .64278 L p .707 .577 .707 r
F P
0 g
s
.77948 .64278 m .77654 .60849 L .80404 .61384 L p .707 .577 .707 r
F P
0 g
s
.36093 .74912 m .35973 .73167 L .33224 .72648 L p .707 .577 .707 r
F P
0 g
s
.35973 .73167 m .36093 .74912 L .39208 .75023 L p .707 .577 .707 r
F P
0 g
s
.49025 .54135 m .4921 .59547 L .49914 .58451 L p .707 .577 .707 r
F P
0 g
s
.49914 .58451 m .49729 .53038 L .49025 .54135 L p .707 .577 .707 r
F P
0 g
s
.74503 .53261 m .74689 .58673 L .71507 .58871 L p .707 .577 .707 r
F P
0 g
s
.82616 .69905 m .82737 .7165 L .80623 .70774 L p .707 .577 .707 r
F P
0 g
s
.80623 .70774 m .80503 .69029 L .82616 .69905 L p .707 .577 .707 r
F P
0 g
s
.47514 .64046 m .47808 .67475 L .4942 .6613 L p .707 .577 .707 r
F P
0 g
s
.4942 .6613 m .49126 .62701 L .47514 .64046 L p .707 .577 .707 r
F P
0 g
s
.45189 .72272 m .4531 .74018 L .477 .73 L p .707 .577 .707 r
F P
0 g
s
.477 .73 m .4758 .71254 L .45189 .72272 L p .707 .577 .707 r
F P
0 g
s
.29641 .54284 m .29827 .59697 L .31089 .60672 L p .707 .577 .707 r
F P
0 g
s
.33224 .72648 m .33345 .74394 L .36093 .74912 L p .707 .577 .707 r
F P
0 g
s
.68449 .61886 m .68742 .65315 L .6636 .6643 L p .707 .577 .707 r
F P
0 g
s
.68742 .65315 m .68449 .61886 L .71369 .61113 L p .707 .577 .707 r
F P
0 g
s
.31059 .64737 m .31353 .68166 L .3347 .69091 L p .707 .577 .707 r
F P
0 g
s
.29827 .59697 m .29641 .54284 L .29348 .53195 L p .707 .577 .707 r
F P
0 g
s
.66268 .72168 m .66148 .70422 L .68538 .69405 L p .707 .577 .707 r
F P
0 g
s
.77654 .60849 m .77948 .64278 L .74835 .64184 L p .707 .577 .707 r
F P
0 g
s
.74835 .64184 m .74541 .60755 L .77654 .60849 L p .707 .577 .707 r
F P
0 g
s
.33345 .74394 m .33224 .72648 L .31111 .71772 L p .707 .577 .707 r
F P
0 g
s
.31353 .68166 m .31059 .64737 L .29782 .63513 L p .707 .577 .707 r
F P
0 g
s
.71663 .64542 m .71369 .61113 L .74541 .60755 L p .707 .577 .707 r
F P
0 g
s
.71369 .61113 m .71663 .64542 L .68742 .65315 L p .707 .577 .707 r
F P
0 g
s
.74541 .60755 m .74835 .64184 L .71663 .64542 L p .707 .577 .707 r
F P
0 g
s
.68538 .69405 m .68658 .7115 L .66268 .72168 L p .707 .577 .707 r
F P
0 g
s
.80503 .69029 m .80623 .70774 L .77875 .70255 L p .707 .577 .707 r
F P
0 g
s
.77875 .70255 m .77754 .6851 L .80503 .69029 L p .707 .577 .707 r
F P
0 g
s
.31111 .71772 m .31231 .73518 L .33345 .74394 L p .707 .577 .707 r
F P
0 g
s
.4758 .71254 m .477 .73 L .4932 .71761 L p .707 .577 .707 r
F P
0 g
s
.4932 .71761 m .492 .70016 L .4758 .71254 L p .707 .577 .707 r
F P
0 g
s
.49126 .62701 m .4942 .6613 L .50103 .64685 L p .707 .577 .707 r
F P
0 g
s
.50103 .64685 m .4981 .61256 L .49126 .62701 L p .707 .577 .707 r
F P
0 g
s
.49729 .53038 m .49914 .58451 L .49621 .57361 L p .707 .577 .707 r
F P
0 g
s
.49621 .57361 m .49435 .51948 L .49729 .53038 L p .707 .577 .707 r
F P
0 g
s
.68658 .7115 m .68538 .69405 L .71464 .68708 L p .707 .577 .707 r
F P
0 g
s
.29348 .53195 m .29533 .58608 L .29827 .59697 L p .707 .577 .707 r
F P
0 g
s
.29782 .63513 m .30076 .66942 L .31353 .68166 L p .707 .577 .707 r
F P
0 g
s
.31231 .73518 m .31111 .71772 L .2984 .70625 L p .707 .577 .707 r
F P
0 g
s
.77754 .6851 m .77875 .70255 L .7476 .70145 L p .707 .577 .707 r
F P
0 g
s
.7476 .70145 m .7464 .68399 L .77754 .6851 L p .707 .577 .707 r
F P
0 g
s
.71464 .68708 m .71584 .70453 L .68658 .7115 L p .707 .577 .707 r
F P
0 g
s
.30076 .66942 m .29782 .63513 L .2947 .62109 L p .707 .577 .707 r
F P
0 g
s
.71584 .70453 m .71464 .68708 L .7464 .68399 L p .707 .577 .707 r
F P
0 g
s
.29533 .58608 m .29348 .53195 L .30051 .52098 L p .707 .577 .707 r
F P
0 g
s
.2984 .70625 m .2996 .7237 L .31231 .73518 L p .707 .577 .707 r
F P
0 g
s
.7464 .68399 m .7476 .70145 L .71584 .70453 L p .707 .577 .707 r
F P
0 g
s
.492 .70016 m .4932 .71761 L .50012 .70423 L p .707 .577 .707 r
F P
0 g
s
.50012 .70423 m .49891 .68678 L .492 .70016 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4981 .61256 m .50103 .64685 L .49791 .63281 L p .707 .577 .707 r
F P
0 g
s
.49791 .63281 m .49497 .59852 L .4981 .61256 L p .707 .577 .707 r
F P
0 g
s
.49435 .51948 m .49621 .57361 L .48358 .56386 L p .707 .577 .707 r
F P
0 g
s
.48358 .56386 m .48173 .50974 L .49435 .51948 L p .707 .577 .707 r
F P
0 g
s
.2947 .62109 m .29764 .65539 L .30076 .66942 L p .707 .577 .707 r
F P
0 g
s
.30051 .52098 m .30237 .57511 L .29533 .58608 L p .707 .577 .707 r
F P
0 g
s
.2996 .7237 m .2984 .70625 L .29535 .69318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29764 .65539 m .2947 .62109 L .30153 .60664 L p .707 .577 .707 r
F P
0 g
s
.29535 .69318 m .29655 .71063 L .2996 .7237 L p .707 .577 .707 r
F P
0 g
s
.30237 .57511 m .30051 .52098 L .31684 .51101 L p .707 .577 .707 r
F P
0 g
s
.49891 .68678 m .50012 .70423 L .49707 .69116 L p .707 .577 .707 r
F P
0 g
s
.49707 .69116 m .49586 .67371 L .49891 .68678 L p .707 .577 .707 r
F P
0 g
s
.49497 .59852 m .49791 .63281 L .48514 .62057 L p .707 .577 .707 r
F P
0 g
s
.48514 .62057 m .4822 .58628 L .49497 .59852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48173 .50974 m .48358 .56386 L .46251 .55621 L p .707 .577 .707 r
F P
0 g
s
.46251 .55621 m .46065 .50208 L .48173 .50974 L p .707 .577 .707 r
F P
0 g
s
.30153 .60664 m .30447 .64093 L .29764 .65539 L p .707 .577 .707 r
F P
0 g
s
.31684 .51101 m .3187 .56514 L .30237 .57511 L p .707 .577 .707 r
F P
0 g
s
.29655 .71063 m .29535 .69318 L .30226 .67979 L p .707 .577 .707 r
F P
0 g
s
.3187 .56514 m .31684 .51101 L .34085 .50301 L p .707 .577 .707 r
F P
0 g
s
.30447 .64093 m .30153 .60664 L .31765 .59319 L p .707 .577 .707 r
F P
0 g
s
.30226 .67979 m .30347 .69725 L .29655 .71063 L p .707 .577 .707 r
F P
0 g
s
.49586 .67371 m .49707 .69116 L .48436 .67968 L p .707 .577 .707 r
F P
0 g
s
.48436 .67968 m .48315 .66223 L .49586 .67371 L p .707 .577 .707 r
F P
0 g
s
.4822 .58628 m .48514 .62057 L .46397 .61132 L p .707 .577 .707 r
F P
0 g
s
.46397 .61132 m .46103 .57703 L .4822 .58628 L p .707 .577 .707 r
F P
0 g
s
.46065 .50208 m .46251 .55621 L .43504 .55141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55141 m .43318 .49728 L .46065 .50208 L p .707 .577 .707 r
F P
0 g
s
.31765 .59319 m .32059 .62748 L .30447 .64093 L p .707 .577 .707 r
F P
0 g
s
.34271 .55714 m .34085 .50301 L .3702 .49777 L p .707 .577 .707 r
F P
0 g
s
.34085 .50301 m .34271 .55714 L .3187 .56514 L p .707 .577 .707 r
F P
0 g
s
.30347 .69725 m .30226 .67979 L .31846 .66741 L p .707 .577 .707 r
F P
0 g
s
.32059 .62748 m .31765 .59319 L .34148 .58205 L p .707 .577 .707 r
F P
0 g
s
.43318 .49728 m .43504 .55141 L .40387 .54992 L p .707 .577 .707 r
F P
0 g
s
.40387 .54992 m .40202 .49579 L .43318 .49728 L p .707 .577 .707 r
F P
0 g
s
.37206 .55189 m .3702 .49777 L .40202 .49579 L p .707 .577 .707 r
F P
0 g
s
.3702 .49777 m .37206 .55189 L .34271 .55714 L p .707 .577 .707 r
F P
0 g
s
.31846 .66741 m .31967 .68486 L .30347 .69725 L p .707 .577 .707 r
F P
0 g
s
.46103 .57703 m .46397 .61132 L .43647 .60596 L p .707 .577 .707 r
F P
0 g
s
.43647 .60596 m .43353 .57167 L .46103 .57703 L p .707 .577 .707 r
F P
0 g
s
.40202 .49579 m .40387 .54992 L .37206 .55189 L p .707 .577 .707 r
F P
0 g
s
.48315 .66223 m .48436 .67968 L .46322 .67092 L p .707 .577 .707 r
F P
0 g
s
.46322 .67092 m .46202 .65347 L .48315 .66223 L p .707 .577 .707 r
F P
0 g
s
.34148 .58205 m .34441 .61634 L .32059 .62748 L p .707 .577 .707 r
F P
0 g
s
.34441 .61634 m .34148 .58205 L .37068 .57431 L p .707 .577 .707 r
F P
0 g
s
.31967 .68486 m .31846 .66741 L .34237 .65723 L p .707 .577 .707 r
F P
0 g
s
.43353 .57167 m .43647 .60596 L .40534 .60503 L p .707 .577 .707 r
F P
0 g
s
.40534 .60503 m .4024 .57073 L .43353 .57167 L p .707 .577 .707 r
F P
0 g
s
.37362 .6086 m .37068 .57431 L .4024 .57073 L p .707 .577 .707 r
F P
0 g
s
.37068 .57431 m .37362 .6086 L .34441 .61634 L p .707 .577 .707 r
F P
0 g
s
.4024 .57073 m .40534 .60503 L .37362 .6086 L p .707 .577 .707 r
F P
0 g
s
.34237 .65723 m .34357 .67469 L .31967 .68486 L p .707 .577 .707 r
F P
0 g
s
.46202 .65347 m .46322 .67092 L .43574 .66574 L p .707 .577 .707 r
F P
0 g
s
.43574 .66574 m .43453 .64828 L .46202 .65347 L p .707 .577 .707 r
F P
0 g
s
.34357 .67469 m .34237 .65723 L .37163 .65026 L p .707 .577 .707 r
F P
0 g
s
.43453 .64828 m .43574 .66574 L .40459 .66463 L p .707 .577 .707 r
F P
0 g
s
.40459 .66463 m .40339 .64718 L .43453 .64828 L p .707 .577 .707 r
F P
0 g
s
.37163 .65026 m .37283 .66771 L .34357 .67469 L p .707 .577 .707 r
F P
0 g
s
.37283 .66771 m .37163 .65026 L .40339 .64718 L p .707 .577 .707 r
F P
0 g
s
.40339 .64718 m .40459 .66463 L .37283 .66771 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0006FUH00`00FUIJEP03FUH9001mOol007Ioo`T000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool40007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool006Yoo`<00003FUH0
05YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00005`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0035YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001OOol40006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005aoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001HOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol0
0`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0067oo3`00?goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
47oo200015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01eYF100015YF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03
001JEP0000AJEP03001JEP0000@000=oo`04001JEUYF0005FUH00`00FUH000020005FUH00`00FUIJ
EP02FUH50004FUH300000eYF001JEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0000=JEP00FUH00UYF2@000eYF3`000eYF00<005YFFUH015YF00@005YF000000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF3`000UYF00<005YFFUH015YF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`001EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000^Ool005=oo`8000=JEP03001JEUYF009JEP03001JEUYF00@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001D
Ool01P00FUIJEUYF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH5000JOol50004FUH01@00
FUIJEUYF0000;Woo001DOol01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEUYFFUH2
000?Ool3000<Ool30003FUH300000eYF001JEP02FUH2000]Ool005Eoo`06001JEP00001JEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP05001JEP00001JEP04000;Ool50007Ool400000eYF001JEP05FUH30003FUH2
000]Ool004Moo`T000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF0P0000=JEP00FUH015YF
5`001EYF00<005YFFUH015YF00@005YFFUH0009JEP8002eoo`00?Woo2@0015YF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF4@000eYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP03
001JEUYF00AJEP04001JEUYFFUH4000]Ool003Qoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEPP000QJEP03001JEUYF00EJEP@000EJEP03001J
EUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH0
05YF00EJEP03001JEUYF009JEP<002eoo`00=Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH010001eYF00<005YFFUH01UYF00<005YF
FUH00UYF1@0000AJEP00000000=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH200000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH00UYF0`00;Goo000cOol2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJ
EP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP0200000eYF001J
EP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0000=JEP00FUH00eYF00<005YF0000;Goo000aOol30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH01000FUIJEUYF100000=oo`0000003P000eYF
00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;goo
0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00001EYF00@005YF0000009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8002ioo`00;Woo00<005YFFUH0
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0
00AJEP8000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP000000;Woo000]Ool20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0P001EYF
00@005YFFUH0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03001JEUYF00AJEP800004
FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01000FUH0
00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YF000002moo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00800003FUH005YF00AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH60004FUH00`00FUIJEP09FUH00`00FUIJEP03FUH01000FUH005YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00UJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00000P00
1EYF00<005YFFUH02EYF00<005YFFUH00P000eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP<00003FUH005YF009J
EP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03
001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03
001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF0P000UYF00<005YFFUH00eYF00H005YF001JEP00FUHG0003
FUH20003FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YF
FUH015YF1`0015YF00<005YFFUH00P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<000EJEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00FUIJEP02FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF
00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH010001goo0`0000AJ
EP00FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0015YF0P000UYF00<005YFFUH00UYF1`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`0000=JEP00FUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00@005YFFUIJEQ`000ioo`8000=JEP03001o
ogoo02]oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1P000UYF
00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEP000003FUH3000VOol01000FUIJEP00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006Ool90004Ool20002FUH01000FUIJEUYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH20005FUH00`00FUIJEP02000UOol00`00FUH0000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP@000Aoo`H000AJEP03001JEUYF009JEPH000=JEP<000EJEP03001J
EUYF00AJEQL000AJEP03001JEUYF00=JEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP06001JEUYF001JEP001EYF00D005YFFUIJEP0000Uoo`<0
01Qoo`@002eoo`00;7oo00<005YF000015YF00<005YF00001P000goo0P0000=JEP00FUH01eYF00<0
05YFFUH01UYF0P000eYF0P001UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`D001Eoo`80
0004FUH005YF000]Ool002aoo`03001JEP0000AJEP800003FUH005YF00AJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00AJEP@0009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03
FUH01@00FUIJEUYF000027oo1@0057oo00L005YFFUIJEP00FUH0000]Ool002aoo`03001JEP00009J
EP8000=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP04
001JEUYFFUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
0`0000EJEP00FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF00=JEP03001JEUYF00=JEP05001JEUYFFUH00008Ool5000BOol20004
FUH00`00FUH0000]Ool002aoo`03001JEP00008000EJEP<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP06001JEP00001JEP001UYF00<005YFFUH01EYF10001UYF00<005YF
FUH01UYF00@005YFFUH000=JEP80009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP03FUH01@00FUIJEUYF00002Goo0`004Goo0P0000=J
EP00FUH00eYF00<005YF0000;Goo000/Ool01@00FUH005YF000015YF0P000eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH01UYF0`001UYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH400000eYF001JEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF000027oo
3`0017oo0P000eYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH300000eYF001JEP06FUH300000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH300000eYF001J
EP04FUH01P00FUIJEUYF001oo`L000AJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
009JEP8002ioo`00;7oo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0003FUH00`00FUH000020005FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP040004FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30002FUH00`00FUIJEP020005FUH00`00FUH000030002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH2000^Ool002aoo`80009JEP80
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
00AJEP03001JEUYF009JEP@00003FUH005YF00MJEP<0009JEPL000QJEP03001JEUYF00IJEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
009JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000AJ
EP03001oogoo02eoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF30000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF00003`000eYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YF00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH70009FUH01P00FUH005YF001JEP@00003FUH005YF00AJEP05001JEP00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH3000`Ool002eoo`8000EJEP03001J
EUYF00=JEP03001JEUYF00@000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP04001JEP000005
FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000UYF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YF000000EJ
EP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00031o
o`00;Goo0P001EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000=JEP05001JEP00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP02FUH200001UYF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH30006FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH50004FUH00`00FUH0000_Ool002aoo`03001JEP0000EJEP04001JEUYFFUH20005
FUH00`00FUIJEP05FUH900001eYF001JEUYF001JEP00009JEP03001JEUYF00=JEP800006FUH005YF
001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0015YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0002ioo`00;7oo00<005YF00001EYF00@005YF000000MJEP03001JEP0000D000AJEP03
001JEUYF009JEPH00004FUH005YF0003FUH20002Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF0`0000=JEP00FUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH4
0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo0P000UYF00<007ooOol0;7oo000/Ool01000
FUIJEP0015YF0P0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF0P000UYF1@00
1Woo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF0P000eYF00<005YFFUH00UYF
00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001J
EP00008000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04001JEP000006Ool01000FUH0
0000;Goo000/Ool01000FUIJEP000eYF00<007ooOol01`001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000UYF00<005YF0000100017oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
15YF0`0027oo00@005YF000002eoo`00;7oo00D005YFFUH005YF008000Aoo`800003FUH005YF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH400001Woo001JEP00FUH000IJ
EP03001JEUYF00MJEP04001JEUYFFUH400000eYF001JEP05FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEUYF0P000UYF10001UYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH0100037oo0`00;Goo000/Ool00`00FUIJEP020004Ool20003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80004FUH01@00FUH005YF00001EYF00<005YF00001000
00=JEP00FUH01EYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH7000AOol2000]Ool002eoo`03001JEP0000=oo`8000EJ
EP03001JEUYF00AJEPL000Qoo`T000EJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP04001J
EUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP0@000GOol3000]Ool002eoo`@00003Ool0
000000IJEP03001JEUYF00@001Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH01000FUIJEP009Goo00<005YF0000;Goo
000]Ool200001EYF000005YF00001EYF10007Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF1@001EYF00<005YFFUH00P008goo0P0000=JEP00
Ool0;7oo000]Ool00`00FUH00003FUH01000FUIJEUYF0P007goo0`000UYF0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF0P000eYF00<005YF
FUH00P008Goo0P0000=JEP000000;Woo000]Ool20004FUH01000FUH000007Woo0`0000=JEP00FUH0
1EYF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF0P00
00=JEP00FUH00UYF00<007ooOol07Woo00@005YFFUIJEP8002ioo`00;Goo0P0015YF0P0000=JEP00
00000`005goo0`0015YF00<005YFFUH015YF00<005YFFUH04@000eYF00<005YFFUH015YF60001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUH000EJEP800003Ool0
000000=JEP03001oogoo01aoo`8000AJEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH00UYF
00@005YFFUIJEPP000Uoo`H000MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
1`001Goo00@005YFFUH001Yoo`@00003FUH005YF00=JEP03001oogoo02eoo`00;7oo00H005YFFUH0
05YF0005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH30002FUH60007Ool3000GOol30005FUH01@00FUIJ
EUYF0000<7oo000/Ool00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP04
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20004FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02000015YF000000000goo0P00
00=JEP00Ool04Woo100000=JEP00FUH01UYF00<005YF0000<Goo000/Ool01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000Woo00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF10000UYF00@005YF
FUIJEPL00004FUH005YF000<Ool70005FUH00`00FUIJEP05FUH2000bOol002eoo`800004Ool005YF
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00Oomoo`0200000eYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF1`0015YF00@005YFFUIJ
EQ8000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000Woo0P001EYF00<005YF
FUH015YF00<005YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP80009oo`04001JEP00
FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000Woo0`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000]Ool20003
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUH00000
0goo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10001Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000]Ool01000FUH0
00000goo0`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF10000goo0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001Woo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000?Goo000]Ool20002FUH00`00Oomoo`03Ool30005
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040005Ool200000eYF001JEP02FUH20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003Ool30003FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70011Ool002ioo`03001JEUYF00<000Ioo`@00003FUH005YF00MJEP<0009JEPL000Moo`8000=J
EP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001J
EP05FUH00`00FUIJEP0A0018Ool002ioo`04001JEUYF0002FUH20008Ool?000;Ool30005FUH01P00
FUH00000Ool000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00EJ
EP04001JEUYFFUH3001DOol002moo`03001JEP0000AJEPD001Uoo`@00003FUH005YF00EJEP8000=o
o`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP04001J
EUYFFUH3001DOol0031oo`8000EJEP04001JEUYFFUH90009Ool70005FUH00`00FUIJEP03FUH20005
Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP05FUH01@00FUIJEP00
Ool00P00E7oo000aOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH01EYF
0`0000Aoo`00000005Aoo`00<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH00`00FUIJEP04
FUH01`00Oomoogoo001JEP0005Aoo`00=7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009oo`<00003FUH007oo05=oo`00=Woo1@0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH0100067oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF10001EYF00<005YFFUH01EYF00<005YFFUH00P000Woo0P000UYF0P00EGoo000k
Ool90004FUH00`00FUIJEP02FUH7000QOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP090005FUH00`00FUIJEP05FUH30002Ool20004FUH2001EOol004Aoo`T0
02ioo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPP000AJEPD000EJEP03001JEUYF00AJEP80
009oo`800003FUH005YF00=JEP03001oogoo05Aoo`00Q7oo6@0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH010000Woo0P000eYF00<005YFFUH00UYF00<007ooOol0E7oo002?Ool01@00FUIJEP00
FUH00`001Woo2@0015YF0`000UYF1`000goo0`001UYF00@005YFFUH005Moo`00Sgoo00@005YFFUH0
00AJEP<000aoo`T000Ioo`@00003FUH005YF00IJEP<005Qoo`00T7oo00@005YFFUH000AJEP03001J
EP0000<0011oo`L000EJEP03001JEUYF00AJEP8005Yoo`00TGoo0`0015YF00<005YFFUH00eYF4000
15YF00<005YFFUH01UYF00@005YFFUIJEP8005aoo`00Tgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005ioo`00UGoo0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000H7oo002HOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001TOol009]oo`@0009JEP03001JEUYF00EJEP03
001JEUYF009JEPL006Qoo`00Wgoo3`00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59671 .77454 m .59371 .72151 L .56256 .72028 L p .707 .577 .707 r
F P
0 g
s
.59371 .72151 m .59671 .77454 L .62849 .77184 L p .707 .577 .707 r
F P
0 g
s
.62849 .77184 m .62549 .71882 L .59371 .72151 L p .707 .577 .707 r
F P
0 g
s
.62549 .71882 m .62849 .77184 L .65779 .76547 L p .707 .577 .707 r
F P
0 g
s
.65779 .76547 m .65479 .71245 L .62549 .71882 L p .707 .577 .707 r
F P
0 g
s
.56555 .7733 m .56256 .72028 L .53508 .71522 L p .707 .577 .707 r
F P
0 g
s
.56256 .72028 m .56555 .7733 L .59671 .77454 L p .707 .577 .707 r
F P
0 g
s
.65479 .71245 m .65779 .76547 L .68174 .75605 L p .707 .577 .707 r
F P
0 g
s
.68174 .75605 m .67874 .70303 L .65479 .71245 L p .707 .577 .707 r
F P
0 g
s
.53808 .76825 m .53508 .71522 L .51397 .70685 L p .707 .577 .707 r
F P
0 g
s
.53508 .71522 m .53808 .76825 L .56555 .7733 L p .707 .577 .707 r
F P
0 g
s
.63111 .84914 m .62917 .8326 L .59754 .83703 L p .707 .577 .707 r
F P
0 g
s
.60173 .83688 m .59703 .80504 L .56596 .80466 L p .707 .577 .707 r
F P
0 g
s
.66018 .84007 m .65824 .82353 L .62917 .8326 L p .707 .577 .707 r
F P
0 g
s
.59703 .80504 m .60173 .83688 L .63327 .83171 L p .707 .577 .707 r
F P
0 g
s
.63327 .83171 m .62857 .79987 L .59703 .80504 L p .707 .577 .707 r
F P
0 g
s
.67874 .70303 m .68174 .75605 L .69799 .74451 L p .707 .577 .707 r
F P
0 g
s
.69799 .74451 m .69499 .69148 L .67874 .70303 L p .707 .577 .707 r
F P
0 g
s
.68383 .82725 m .6819 .81072 L .65824 .82353 L p .707 .577 .707 r
F P
0 g
s
.62857 .79987 m .63327 .83171 L .66218 .82148 L p .707 .577 .707 r
F P
0 g
s
.66218 .82148 m .65748 .78964 L .62857 .79987 L p .707 .577 .707 r
F P
0 g
s
.59947 .85356 m .59754 .83703 L .56644 .83638 L p .707 .577 .707 r
F P
0 g
s
.57066 .8365 m .56596 .80466 L .5384 .79875 L p .707 .577 .707 r
F P
0 g
s
.56596 .80466 m .57066 .8365 L .60173 .83688 L p .707 .577 .707 r
F P
0 g
s
.69977 .81194 m .69783 .79541 L .6819 .81072 L p .707 .577 .707 r
F P
0 g
s
.65748 .78964 m .66218 .82148 L .68565 .8072 L p .707 .577 .707 r
F P
0 g
s
.68565 .8072 m .68095 .77536 L .65748 .78964 L p .707 .577 .707 r
F P
0 g
s
.59754 .83703 m .59947 .85356 L .63111 .84914 L p .707 .577 .707 r
F P
0 g
s
.62917 .8326 m .63111 .84914 L .66018 .84007 L p .707 .577 .707 r
F P
0 g
s
.51697 .75987 m .51397 .70685 L .5013 .69597 L p .707 .577 .707 r
F P
0 g
s
.51397 .70685 m .51697 .75987 L .53808 .76825 L p .707 .577 .707 r
F P
0 g
s
.56837 .85292 m .56644 .83638 L .53891 .83073 L p .707 .577 .707 r
F P
0 g
s
.56644 .83638 m .56837 .85292 L .59947 .85356 L p .707 .577 .707 r
F P
0 g
s
.65824 .82353 m .66018 .84007 L .68383 .82725 L p .707 .577 .707 r
F P
0 g
s
.5431 .83059 m .5384 .79875 L .51705 .7879 L p .707 .577 .707 r
F P
0 g
s
.5384 .79875 m .5431 .83059 L .57066 .8365 L p .707 .577 .707 r
F P
0 g
s
.69499 .69148 m .69799 .74451 L .70496 .73197 L p .707 .577 .707 r
F P
0 g
s
.70496 .73197 m .70196 .67894 L .69499 .69148 L p .707 .577 .707 r
F P
0 g
s
.69889 .79293 m .70136 .79027 L p .69826 .78801 L .707 .577 .707 r
F P
0 g
s
.70136 .79027 m .69666 .75843 L .68095 .77536 L p .707 .577 .707 r
F P
0 g
s
.69666 .75843 m .70136 .79027 L .70779 .77234 L p .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .70448 .7791 L .69888 .79284 L p .707 .577 .707 r
F P
0 g
s
.69888 .79284 m .69783 .79541 L p .69921 .79544 L .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .69888 .79284 L .69921 .79544 L .707 .577 .707 r
F
.68095 .77536 m .68565 .8072 L .69889 .79293 L p F P
0 g
s
.69826 .78801 m .68095 .77536 L .69889 .79293 L .707 .577 .707 r
F
.53891 .83073 m .54084 .84727 L .56837 .85292 L p F P
0 g
s
.54084 .84727 m .53891 .83073 L .51765 .82063 L p .707 .577 .707 r
F P
0 g
s
.5013 .69597 m .50429 .749 L .51697 .75987 L p .707 .577 .707 r
F P
0 g
s
.6819 .81072 m .68383 .82725 L .69977 .81194 L p .707 .577 .707 r
F P
0 g
s
.50429 .749 m .5013 .69597 L .4983 .68366 L p .707 .577 .707 r
F P
0 g
s
.51765 .82063 m .51959 .83717 L .54084 .84727 L p .707 .577 .707 r
F P
0 g
s
.51705 .7879 m .52174 .81974 L .5431 .83059 L p .707 .577 .707 r
F P
0 g
s
.52174 .81974 m .51705 .7879 L .50399 .77317 L p .707 .577 .707 r
F P
0 g
s
.70779 .77234 m .70309 .7405 L .69666 .75843 L p .707 .577 .707 r
F P
0 g
s
.70196 .67894 m .70496 .73197 L .70196 .71966 L p .707 .577 .707 r
F P
0 g
s
.70196 .71966 m .69896 .66663 L .70196 .67894 L p .707 .577 .707 r
F P
0 g
s
.51959 .83717 m .51765 .82063 L .50475 .80706 L p .707 .577 .707 r
F P
0 g
s
.69783 .79541 m .69977 .81194 L .70641 .79563 L p .707 .577 .707 r
F P
0 g
s
.4983 .68366 m .50129 .73669 L .50429 .749 L p .707 .577 .707 r
F P
0 g
s
.50475 .80706 m .50668 .8236 L .51959 .83717 L p .707 .577 .707 r
F P
0 g
s
.50399 .77317 m .50869 .80501 L .52174 .81974 L p .707 .577 .707 r
F P
0 g
s
.50869 .80501 m .50399 .77317 L .5005 .75599 L p .707 .578 .707 r
F P
0 g
s
.50129 .73669 m .4983 .68366 L .50526 .67112 L p .707 .577 .707 r
F P
0 g
s
.48441 .82075 m .49167 .31434 L .44766 .3114 L p .707 .577 .707 r
F P
0 g
s
.50668 .8236 m .50475 .80706 L .50145 .79135 L p .707 .577 .707 r
F P
0 g
s
.50145 .79135 m .50339 .80789 L .50668 .8236 L p .707 .577 .707 r
F P
0 g
s
.5005 .75599 m .5052 .78783 L .50869 .80501 L p .707 .578 .707 r
F P
0 g
s
.50526 .67112 m .50826 .72415 L .50129 .73669 L p .707 .577 .707 r
F P
0 g
s
.5052 .78783 m .5005 .75599 L .50693 .73806 L p .707 .577 .707 r
F P
0 g
s
.50826 .72415 m .50526 .67112 L .52152 .65958 L p .707 .577 .707 r
F P
0 g
s
.51061 .77263 m .52403 .75973 L p .51245 .78608 L .707 .577 .707 r
F P
0 g
s
.50693 .73806 m .51163 .7699 L .51062 .77273 L p .707 .577 .707 r
F P
0 g
s
.51062 .77273 m .5052 .78783 L p .50672 .74428 L .707 .577 .707 r
F P
0 g
s
.50672 .74428 m .50693 .73806 L .51062 .77273 L .707 .577 .707 r
F
.51003 .79158 m .5081 .77504 L .51061 .77263 L p F P
0 g
s
.51003 .79158 m .51061 .77263 L .51245 .78608 L .707 .577 .707 r
F
.50339 .80789 m .50145 .79135 L .5081 .77504 L p F P
0 g
s
.5081 .77504 m .51003 .79158 L .50339 .80789 L p .707 .577 .707 r
F P
0 g
s
.52152 .65958 m .52451 .7126 L .50826 .72415 L p .707 .577 .707 r
F P
0 g
s
.51163 .7699 m .50693 .73806 L .52265 .72113 L p .707 .577 .707 r
F P
0 g
s
.52265 .72113 m .52735 .75297 L .51163 .7699 L p .707 .577 .707 r
F P
0 g
s
.52403 .75973 m .52596 .77627 L .51003 .79158 L p .707 .577 .707 r
F P
0 g
s
.52596 .77627 m .52403 .75973 L .54769 .74691 L p .707 .577 .707 r
F P
0 g
s
.54769 .74691 m .54962 .76345 L .52596 .77627 L p .707 .577 .707 r
F P
0 g
s
.49167 .31434 m .48441 .82075 L .52934 .82039 L p .707 .577 .707 r
F P
0 g
s
.52451 .7126 m .52152 .65958 L .54547 .65016 L p .707 .577 .707 r
F P
0 g
s
.54547 .65016 m .54846 .70318 L .52451 .7126 L p .707 .577 .707 r
F P
0 g
s
.52735 .75297 m .52265 .72113 L .54611 .70685 L p .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .5499 .73253 L p .52735 .75297 L .707 .577 .707 r
F P
0 g
s
.5499 .73253 m .55081 .73869 L .54749 .74071 L p .707 .577 .707 r
F P
0 g
s
.54749 .74071 m .52735 .75297 L p .5499 .73253 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .49167 .31434 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52934 .82039 m .52962 .80129 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52962 .80129 m .5366 .31399 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.70309 .7405 m .70779 .77234 L .70431 .75517 L p .707 .578 .707 r
F P
0 g
s
.70431 .75517 m .69961 .72332 L .70309 .7405 L p .707 .578 .707 r
F P
0 g
s
.54547 .65016 m .57477 .64379 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.54846 .70318 m .5483 .70023 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.5483 .70023 m .54547 .65016 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.57503 .69662 m .57987 .69583 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.57944 .72655 m .57503 .69662 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .57503 .69662 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.55081 .73869 m .54802 .71975 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.54802 .71975 m .54611 .70685 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .60337 .78419 L .57148 .7705 L .707 .577 .707 r
F
.57503 .69662 m .57973 .72846 L .55081 .73869 L p F P
0 g
s
.57477 .64379 m .57776 .69681 L .56055 .70056 L p .707 .577 .707 r
F P
0 g
s
.55376 .69122 m .57477 .64379 L .56055 .70056 L .707 .577 .707 r
F
.57973 .72846 m .57944 .72655 L p .57973 .72694 L F P
0 g
s
.57987 .69583 m .60656 .69145 L p .58561 .72035 L .707 .577 .707 r
F P
0 g
s
.57973 .72846 m .57987 .69583 L .58561 .72035 L .707 .577 .707 r
F
.59578 .642 m .60655 .64109 L p .59674 .66007 L F P
0 g
s
.57776 .69681 m .59578 .642 L .59674 .66007 L .707 .577 .707 r
F
.57776 .69681 m .57477 .64379 L .59578 .642 L p F P
0 g
s
.60656 .69145 m .63763 .69183 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.61115 .72255 m .60656 .69145 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.60656 .69145 m .61126 .72329 L .57973 .72846 L p .707 .577 .707 r
F P
0 g
s
.60655 .64109 m .60955 .69412 L .58998 .69578 L p .707 .577 .707 r
F P
0 g
s
.58998 .69578 m .57776 .69681 L p .58291 .68684 L .707 .577 .707 r
F P
0 g
s
.58291 .68684 m .60655 .64109 L .58998 .69578 L .707 .577 .707 r
F
.61126 .72329 m .61115 .72255 L p .61151 .723 L F P
0 g
s
.54962 .76345 m .54769 .74691 L .57676 .73785 L p .707 .577 .707 r
F P
0 g
s
.57676 .73785 m .57869 .75439 L .54962 .76345 L p .707 .577 .707 r
F P
0 g
s
.57869 .75439 m .57676 .73785 L .60839 .73342 L p .707 .577 .707 r
F P
0 g
s
.60839 .73342 m .61032 .74996 L .57869 .75439 L p .707 .577 .707 r
F P
0 g
s
.57808 .31038 m .57181 .74745 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.57181 .74745 m .57148 .7705 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.56055 .70056 m .54846 .70318 L p .55376 .69122 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .66519 .69774 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.64228 .72334 m .63763 .69183 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .64233 .72367 L .61126 .72329 L p .707 .577 .707 r
F P
0 g
s
.6377 .64233 m .6407 .69535 L .62217 .69462 L p .707 .577 .707 r
F P
0 g
s
.62217 .69462 m .60955 .69412 L p .61491 .68426 L .707 .577 .707 r
F P
0 g
s
.61491 .68426 m .6377 .64233 L .62217 .69462 L .707 .577 .707 r
F
.64233 .72367 m .64228 .72334 L p .64244 .72356 L F P
0 g
s
.60955 .69412 m .60655 .64109 L .6377 .64233 L p .707 .577 .707 r
F P
0 g
s
.63949 .73406 m .64143 .7506 L .61032 .74996 L p .707 .577 .707 r
F P
0 g
s
.61032 .74996 m .60839 .73342 L .63949 .73406 L p .707 .577 .707 r
F P
0 g
s
.61202 .30386 m .60487 .80261 L p .62786 .80149 L .707 .577 .707 r
F P
0 g
s
.60487 .80261 m .60476 .81027 L .60651 .8096 L p .707 .577 .707 r
F P
0 g
s
.60651 .8096 m .62786 .80149 L p .60487 .80261 L .707 .577 .707 r
F P
0 g
s
.57148 .7705 m .57082 .81678 L .5858 .81391 L p .707 .577 .707 r
F P
0 g
s
.5858 .81391 m .60476 .81027 L p .57148 .7705 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .52934 .82039 L .57082 .81678 L p .707 .577 .707 r
F P
0 g
s
.57082 .81678 m .57808 .31038 L .5366 .31399 L p .707 .577 .707 r
F P
0 g
s
.4404 .81781 m .44766 .3114 L .40889 .30546 L p .707 .577 .707 r
F P
0 g
s
.44766 .3114 m .4404 .81781 L .48441 .82075 L p .707 .577 .707 r
F P
0 g
s
.69896 .66663 m .70196 .71966 L .68928 .70878 L p .707 .577 .707 r
F P
0 g
s
.68928 .70878 m .68629 .65576 L .69896 .66663 L p .707 .577 .707 r
F P
0 g
s
.70448 .7791 m .70641 .79563 L .70312 .77993 L p .707 .577 .707 r
F P
0 g
s
.70312 .77993 m .70118 .76339 L .70448 .7791 L p .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .61202 .30386 L .57808 .31038 L p .707 .577 .707 r
F P
0 g
s
.2537 .73772 m .2507 .6847 L .21955 .68346 L p .707 .577 .707 r
F P
0 g
s
.2507 .6847 m .2537 .73772 L .28548 .73503 L p .707 .577 .707 r
F P
0 g
s
.28548 .73503 m .28248 .682 L .2507 .6847 L p .707 .577 .707 r
F P
0 g
s
.69961 .72332 m .70431 .75517 L .69125 .74043 L p .707 .577 .707 r
F P
0 g
s
.69125 .74043 m .68655 .70859 L .69961 .72332 L p .707 .577 .707 r
F P
0 g
s
.40163 .81186 m .40889 .30546 L .37916 .29709 L p .707 .577 .707 r
F P
0 g
s
.40889 .30546 m .40163 .81186 L .4404 .81781 L p .707 .577 .707 r
F P
0 g
s
.28248 .682 m .28548 .73503 L .31478 .72866 L p .707 .577 .707 r
F P
0 g
s
.31478 .72866 m .31178 .67563 L .28248 .682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22254 .73649 m .21955 .68346 L .19207 .67841 L p .707 .577 .707 r
F P
0 g
s
.21955 .68346 m .22254 .73649 L .2537 .73772 L p .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .68655 .70859 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66989 .72958 m .66978 .72884 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66978 .72884 m .66519 .69774 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .66989 .72958 L .64233 .72367 L p .707 .577 .707 r
F P
0 g
s
.66518 .64738 m .66818 .70041 L .65346 .6977 L p .707 .577 .707 r
F P
0 g
s
.65346 .6977 m .6407 .69535 L p .64639 .68421 L .707 .577 .707 r
F P
0 g
s
.64639 .68421 m .66518 .64738 L .65346 .6977 L .707 .577 .707 r
F
.68629 .65576 m .68928 .70878 L .66818 .70041 L p F P
0 g
s
.66818 .70041 m .66518 .64738 L .68629 .65576 L p .707 .577 .707 r
F P
0 g
s
.31178 .67563 m .31478 .72866 L .33873 .71924 L p .707 .577 .707 r
F P
0 g
s
.33873 .71924 m .33573 .66621 L .31178 .67563 L p .707 .577 .707 r
F P
0 g
s
.70118 .76339 m .70312 .77993 L .69021 .76636 L p .707 .577 .707 r
F P
0 g
s
.69021 .76636 m .68828 .74982 L .70118 .76339 L p .707 .577 .707 r
F P
0 g
s
.62786 .80149 m .63512 .29508 L .61202 .30386 L p .707 .577 .707 r
F P
0 g
s
.19507 .73143 m .19207 .67841 L .17096 .67003 L p .707 .577 .707 r
F P
0 g
s
.19207 .67841 m .19507 .73143 L .22254 .73649 L p .707 .577 .707 r
F P
0 g
s
.68655 .70859 m .69125 .74043 L .66989 .72958 L p .707 .577 .707 r
F P
0 g
s
.2881 .81232 m .28616 .79578 L .25453 .80021 L p .707 .577 .707 r
F P
0 g
s
.25872 .80007 m .25402 .76823 L .22295 .76784 L p .707 .577 .707 r
F P
0 g
s
.31717 .80325 m .31523 .78672 L .28616 .79578 L p .707 .577 .707 r
F P
0 g
s
.25402 .76823 m .25872 .80007 L .29026 .79489 L p .707 .577 .707 r
F P
0 g
s
.29026 .79489 m .28556 .76305 L .25402 .76823 L p .707 .577 .707 r
F P
0 g
s
.33573 .66621 m .33873 .71924 L .35498 .70769 L p .707 .577 .707 r
F P
0 g
s
.35498 .70769 m .35199 .65467 L .33573 .66621 L p .707 .577 .707 r
F P
0 g
s
.6407 .69535 m .6377 .64233 L .66518 .64738 L p .707 .577 .707 r
F P
0 g
s
.34083 .79044 m .33889 .7739 L .31523 .78672 L p .707 .577 .707 r
F P
0 g
s
.28556 .76305 m .29026 .79489 L .31917 .78467 L p .707 .577 .707 r
F P
0 g
s
.31917 .78467 m .31447 .75283 L .28556 .76305 L p .707 .577 .707 r
F P
0 g
s
.3719 .8035 m .37916 .29709 L .36138 .28712 L p .707 .577 .707 r
F P
0 g
s
.37916 .29709 m .3719 .8035 L .40163 .81186 L p .707 .577 .707 r
F P
0 g
s
.25647 .81675 m .25453 .80021 L .22343 .79957 L p .707 .577 .707 r
F P
0 g
s
.22765 .79968 m .22295 .76784 L .19539 .76193 L p .707 .577 .707 r
F P
0 g
s
.22295 .76784 m .22765 .79968 L .25872 .80007 L p .707 .577 .707 r
F P
0 g
s
.68828 .74982 m .69021 .76636 L .66895 .75625 L p .707 .577 .707 r
F P
0 g
s
.66895 .75625 m .66702 .73971 L .68828 .74982 L p .707 .577 .707 r
F P
0 g
s
.35676 .77513 m .35482 .75859 L .33889 .7739 L p .707 .577 .707 r
F P
0 g
s
.31447 .75283 m .31917 .78467 L .34264 .77039 L p .707 .577 .707 r
F P
0 g
s
.34264 .77039 m .33794 .73855 L .31447 .75283 L p .707 .577 .707 r
F P
0 g
s
.25453 .80021 m .25647 .81675 L .2881 .81232 L p .707 .577 .707 r
F P
0 g
s
.28616 .79578 m .2881 .81232 L .31717 .80325 L p .707 .577 .707 r
F P
0 g
s
.17396 .72306 m .17096 .67003 L .15829 .65916 L p .707 .577 .707 r
F P
0 g
s
.17096 .67003 m .17396 .72306 L .19507 .73143 L p .707 .577 .707 r
F P
0 g
s
.22536 .81611 m .22343 .79957 L .1959 .79392 L p .707 .577 .707 r
F P
0 g
s
.22343 .79957 m .22536 .81611 L .25647 .81675 L p .707 .577 .707 r
F P
0 g
s
.31523 .78672 m .31717 .80325 L .34083 .79044 L p .707 .577 .707 r
F P
0 g
s
.20009 .79378 m .19539 .76193 L .17404 .75108 L p .707 .577 .707 r
F P
0 g
s
.19539 .76193 m .20009 .79378 L .22765 .79968 L p .707 .577 .707 r
F P
0 g
s
.35199 .65467 m .35498 .70769 L .36195 .69515 L p .707 .577 .707 r
F P
0 g
s
.36195 .69515 m .35895 .64213 L .35199 .65467 L p .707 .577 .707 r
F P
0 g
s
.63512 .29508 m .62786 .80149 L .63785 .7913 L p .707 .577 .707 r
F P
0 g
s
.63785 .7913 m .64511 .28489 L .63512 .29508 L p .707 .577 .707 r
F P
0 g
s
.35588 .75612 m .35835 .75345 L p .35525 .75119 L .707 .577 .707 r
F P
0 g
s
.35835 .75345 m .35365 .72161 L .33794 .73855 L p .707 .577 .707 r
F P
0 g
s
.35365 .72161 m .35835 .75345 L .36141 .74494 L p .707 .577 .707 r
F P
0 g
s
.36141 .74494 m .36478 .73552 L p .36138 .73126 L .707 .577 .707 r
F P
0 g
s
.36138 .73126 m .35365 .72161 L .36141 .74494 L .707 .577 .707 r
F
.35587 .75602 m .35482 .75859 L p .3562 .75863 L F P
0 g
s
.33794 .73855 m .34264 .77039 L .35588 .75612 L p .707 .577 .707 r
F P
0 g
s
.35525 .75119 m .33794 .73855 L .35588 .75612 L .707 .577 .707 r
F
.33889 .7739 m .34083 .79044 L .35676 .77513 L p F P
0 g
s
.36478 .73552 m .36009 .70368 L .35365 .72161 L p .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35895 .64213 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35895 .68284 m .35878 .67989 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35595 .62982 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35878 .67989 L p .34628 .67197 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35895 .68284 L .35862 .68256 L p .707 .577 .707 r
F P
0 g
s
.35862 .68256 m .34628 .67197 L p .35878 .67989 L .707 .577 .707 r
F P
0 g
s
.34628 .67197 m .34328 .61894 L .35595 .62982 L p .707 .577 .707 r
F P
0 g
s
.3566 .68651 m .3585 .69941 L p .34824 .70362 L .707 .577 .707 r
F P
0 g
s
.3585 .69941 m .3613 .71835 L .35663 .71308 L p .707 .577 .707 r
F P
0 g
s
.35663 .71308 m .34824 .70362 L p .3585 .69941 L .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35231 .78885 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.34824 .70362 m .34354 .67178 L .3566 .68651 L p .707 .577 .707 r
F P
0 g
s
.35817 .72657 m .36011 .74311 L .35668 .73951 L p .707 .577 .707 r
F P
0 g
s
.35668 .73951 m .3472 .72954 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.35807 .7266 m .35817 .72657 L .35668 .73951 L .707 .577 .707 r
F
.3472 .72954 m .34527 .713 L .35808 .72648 L p F P
0 g
s
.35808 .72648 m .35817 .72657 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.3472 .72954 m .35808 .72648 L .35807 .7266 L .707 .577 .707 r
F
.35431 .76163 m .35589 .66982 L .35489 .66636 L F
.35412 .79352 m .35461 .7588 L p .35431 .76163 L F P
0 g
s
.35461 .7588 m .35589 .66982 L p .35431 .76163 L .707 .577 .707 r
F P
0 g
s
.35436 .75438 m .35728 .27652 L .3524 .77946 L .707 .577 .707 r
F
.35344 .76971 m .3524 .77946 L .35231 .78885 L F
.35436 .75438 m .3524 .77946 L .35344 .76971 L F
.35728 .27652 m .35036 .75887 L p .35277 .7413 L F P
0 g
s
.35036 .75887 m .35002 .78293 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.35231 .78885 m .35412 .79352 L p .35436 .75438 L .707 .577 .707 r
F P
0 g
s
.35489 .66636 m .3605 .34794 L .35728 .27652 L .707 .577 .707 r
F
.35589 .66982 m .3605 .34794 L p .35489 .66636 L F P
0 g
s
.3605 .34794 m .36138 .28712 L .36036 .28449 L p .707 .577 .707 r
F P
0 g
s
.36036 .28449 m .35728 .27652 L p .3605 .34794 L .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .36147 .74228 L .35587 .75602 L p .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .35587 .75602 L .3562 .75863 L .707 .577 .707 r
F
.1959 .79392 m .19783 .81046 L .22536 .81611 L p F P
0 g
s
.66702 .73971 m .66895 .75625 L .64143 .7506 L p .707 .577 .707 r
F P
0 g
s
.64143 .7506 m .63949 .73406 L .66702 .73971 L p .707 .577 .707 r
F P
0 g
s
.19783 .81046 m .1959 .79392 L .17464 .78381 L p .707 .577 .707 r
F P
0 g
s
.15829 .65916 m .16128 .71218 L .17396 .72306 L p .707 .577 .707 r
F P
0 g
s
.16128 .71218 m .15829 .65916 L .15529 .64685 L p .707 .577 .707 r
F P
0 g
s
.17464 .78381 m .17658 .80035 L .19783 .81046 L p .707 .577 .707 r
F P
0 g
s
.35895 .64213 m .36195 .69515 L .35895 .68284 L p .707 .577 .707 r
F P
0 g
s
.35482 .75859 m .35676 .77513 L .3634 .75882 L p .707 .577 .707 r
F P
0 g
s
.36009 .70368 m .36478 .73552 L .3613 .71835 L p .707 .578 .707 r
F P
0 g
s
.3613 .71835 m .3566 .68651 L .36009 .70368 L p .707 .578 .707 r
F P
0 g
s
.36147 .74228 m .3634 .75882 L .36011 .74311 L p .707 .577 .707 r
F P
0 g
s
.36011 .74311 m .35817 .72657 L .36147 .74228 L p .707 .577 .707 r
F P
0 g
s
.36138 .28712 m .35412 .79352 L .3719 .8035 L p .707 .577 .707 r
F P
0 g
s
.17404 .75108 m .17874 .78292 L .20009 .79378 L p .707 .577 .707 r
F P
0 g
s
.17874 .78292 m .17404 .75108 L .16098 .73635 L p .707 .577 .707 r
F P
0 g
s
.17658 .80035 m .17464 .78381 L .16174 .77024 L p .707 .577 .707 r
F P
0 g
s
.15529 .64685 m .15828 .69987 L .16128 .71218 L p .707 .577 .707 r
F P
0 g
s
.16174 .77024 m .16367 .78678 L .17658 .80035 L p .707 .577 .707 r
F P
0 g
s
.16098 .73635 m .16568 .76819 L .17874 .78292 L p .707 .577 .707 r
F P
0 g
s
.64511 .28489 m .63785 .7913 L .63375 .7807 L p .707 .577 .707 r
F P
0 g
s
.63375 .7807 m .64101 .27429 L .64511 .28489 L p .707 .577 .707 r
F P
0 g
s
.16568 .76819 m .16098 .73635 L .15749 .71918 L p .707 .578 .707 r
F P
0 g
s
.15828 .69987 m .15529 .64685 L .16225 .63431 L p .707 .577 .707 r
F P
0 g
s
.16367 .78678 m .16174 .77024 L .15844 .75453 L p .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35728 .27652 L .36726 .26633 L p .707 .577 .707 r
F P
0 g
s
.15844 .75453 m .16038 .77107 L .16367 .78678 L p .707 .577 .707 r
F P
0 g
s
.15749 .71918 m .16219 .75102 L .16568 .76819 L p .707 .578 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16225 .63431 m .16525 .68733 L .15828 .69987 L p .707 .577 .707 r
F P
0 g
s
.16219 .75102 m .15749 .71918 L .16392 .70125 L p .707 .577 .707 r
F P
0 g
s
.16525 .68733 m .16225 .63431 L .17851 .62276 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1676 .73582 m .18102 .72291 L p .16944 .74926 L .707 .577 .707 r
F P
0 g
s
.16392 .70125 m .16862 .73309 L .16761 .73591 L p .707 .577 .707 r
F P
0 g
s
.16761 .73591 m .16219 .75102 L p .16371 .70747 L .707 .577 .707 r
F P
0 g
s
.16371 .70747 m .16392 .70125 L .16761 .73591 L .707 .577 .707 r
F
.16702 .75476 m .16509 .73823 L .1676 .73582 L p F P
0 g
s
.16702 .75476 m .1676 .73582 L .16944 .74926 L .707 .577 .707 r
F
.16038 .77107 m .15844 .75453 L .16509 .73823 L p F P
0 g
s
.32218 .66092 m .34354 .67178 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32688 .69277 m .32677 .69202 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32677 .69202 m .32218 .66092 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32218 .66092 m .32688 .69277 L .29932 .68686 L p .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .32218 .66092 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29932 .68686 m .29927 .68652 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29927 .68652 m .29462 .65502 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .29932 .68686 L .26825 .68647 L p .707 .577 .707 r
F P
0 g
s
.26355 .65463 m .29462 .65502 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26825 .68647 m .26814 .68573 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26814 .68573 m .26355 .65463 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .26355 .65463 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23672 .69165 m .23643 .68973 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23643 .68973 m .23202 .65981 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.2078 .70188 m .2031 .67003 L .23202 .65981 L p .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .23672 .69165 L .2078 .70188 L p .707 .577 .707 r
F P
0 g
s
.23176 .60697 m .23475 .66 L .21754 .66374 L p .707 .577 .707 r
F P
0 g
s
.21754 .66374 m .20545 .66637 L p .21075 .65441 L .707 .577 .707 r
F P
0 g
s
.21075 .65441 m .23176 .60697 L .21754 .66374 L .707 .577 .707 r
F
.26355 .65463 m .26825 .68647 L .23672 .69165 L p F P
0 g
s
.26354 .60428 m .26654 .6573 L .24697 .65896 L p .707 .577 .707 r
F P
0 g
s
.24697 .65896 m .23475 .66 L p .2399 .65003 L .707 .577 .707 r
F P
0 g
s
.2399 .65003 m .26354 .60428 L .24697 .65896 L .707 .577 .707 r
F
.29469 .60551 m .29769 .65854 L .27916 .6578 L p F P
0 g
s
.27916 .6578 m .26654 .6573 L p .2719 .64744 L .707 .577 .707 r
F P
0 g
s
.2719 .64744 m .29469 .60551 L .27916 .6578 L .707 .577 .707 r
F
.32217 .61057 m .32517 .66359 L .31045 .66089 L p F P
0 g
s
.31045 .66089 m .29769 .65854 L p .30338 .64739 L .707 .577 .707 r
F P
0 g
s
.30338 .64739 m .32217 .61057 L .31045 .66089 L .707 .577 .707 r
F
.34328 .61894 m .34628 .67197 L .32517 .66359 L p F P
0 g
s
.32517 .66359 m .32217 .61057 L .34328 .61894 L p .707 .577 .707 r
F P
0 g
s
.64101 .27429 m .63375 .7807 L .61596 .77073 L p .707 .577 .707 r
F P
0 g
s
.61596 .77073 m .62322 .26432 L .64101 .27429 L p .707 .577 .707 r
F P
0 g
s
.16509 .73823 m .16702 .75476 L .16038 .77107 L p .707 .577 .707 r
F P
0 g
s
.17851 .62276 m .18151 .67579 L .16525 .68733 L p .707 .577 .707 r
F P
0 g
s
.16862 .73309 m .16392 .70125 L .17964 .68431 L p .707 .577 .707 r
F P
0 g
s
.18151 .67579 m .17851 .62276 L .20246 .61334 L p .707 .577 .707 r
F P
0 g
s
.34354 .67178 m .34824 .70362 L .32688 .69277 L p .707 .577 .707 r
F P
0 g
s
.36 .77274 m .36726 .26633 L .39036 .25755 L p .707 .577 .707 r
F P
0 g
s
.36726 .26633 m .36 .77274 L .35002 .78293 L p .707 .577 .707 r
F P
0 g
s
.29769 .65854 m .29469 .60551 L .32217 .61057 L p .707 .577 .707 r
F P
0 g
s
.34527 .713 m .3472 .72954 L .32595 .71943 L p .707 .577 .707 r
F P
0 g
s
.32595 .71943 m .32401 .7029 L .34527 .713 L p .707 .577 .707 r
F P
0 g
s
.20545 .66637 m .20246 .61334 L .23176 .60697 L p .707 .577 .707 r
F P
0 g
s
.20246 .61334 m .20545 .66637 L .18151 .67579 L p .707 .577 .707 r
F P
0 g
s
.17964 .68431 m .18434 .71615 L .16862 .73309 L p .707 .577 .707 r
F P
0 g
s
.18434 .71615 m .17964 .68431 L .2031 .67003 L p .707 .577 .707 r
F P
0 g
s
.18102 .72291 m .18295 .73945 L .16702 .75476 L p .707 .577 .707 r
F P
0 g
s
.26654 .6573 m .26354 .60428 L .29469 .60551 L p .707 .577 .707 r
F P
0 g
s
.62322 .26432 m .61596 .77073 L .58623 .76236 L p .707 .577 .707 r
F P
0 g
s
.58623 .76236 m .59349 .25595 L .62322 .26432 L p .707 .577 .707 r
F P
0 g
s
.23475 .66 m .23176 .60697 L .26354 .60428 L p .707 .577 .707 r
F P
0 g
s
.18295 .73945 m .18102 .72291 L .20468 .7101 L p .707 .577 .707 r
F P
0 g
s
.73391 .65728 m .73091 .60425 L .69976 .60301 L p .707 .577 .707 r
F P
0 g
s
.73091 .60425 m .73391 .65728 L .76569 .65458 L p .707 .577 .707 r
F P
0 g
s
.76569 .65458 m .7627 .60156 L .73091 .60425 L p .707 .577 .707 r
F P
0 g
s
.2031 .67003 m .2078 .70188 L .18434 .71615 L p .707 .577 .707 r
F P
0 g
s
.7627 .60156 m .76569 .65458 L .79499 .64821 L p .707 .577 .707 r
F P
0 g
s
.79499 .64821 m .792 .59519 L .7627 .60156 L p .707 .577 .707 r
F P
0 g
s
.32401 .7029 m .32595 .71943 L .29842 .71378 L p .707 .577 .707 r
F P
0 g
s
.29842 .71378 m .29648 .69725 L .32401 .7029 L p .707 .577 .707 r
F P
0 g
s
.70276 .65604 m .69976 .60301 L .67228 .59796 L p .707 .577 .707 r
F P
0 g
s
.69976 .60301 m .70276 .65604 L .73391 .65728 L p .707 .577 .707 r
F P
0 g
s
.39036 .25755 m .3831 .76395 L .36 .77274 L p .707 .577 .707 r
F P
0 g
s
.3831 .76395 m .39036 .25755 L .42431 .25103 L p .707 .577 .707 r
F P
0 g
s
.20468 .7101 m .20661 .72664 L .18295 .73945 L p .707 .577 .707 r
F P
0 g
s
.792 .59519 m .79499 .64821 L .81894 .63879 L p .707 .577 .707 r
F P
0 g
s
.81894 .63879 m .81595 .58577 L .792 .59519 L p .707 .577 .707 r
F P
0 g
s
.20661 .72664 m .20468 .7101 L .23375 .70103 L p .707 .577 .707 r
F P
0 g
s
.29648 .69725 m .29842 .71378 L .26732 .71314 L p .707 .577 .707 r
F P
0 g
s
.26732 .71314 m .26538 .6966 L .29648 .69725 L p .707 .577 .707 r
F P
0 g
s
.67528 .65098 m .67228 .59796 L .65117 .58959 L p .707 .577 .707 r
F P
0 g
s
.67228 .59796 m .67528 .65098 L .70276 .65604 L p .707 .577 .707 r
F P
0 g
s
.23375 .70103 m .23568 .71757 L .20661 .72664 L p .707 .577 .707 r
F P
0 g
s
.23568 .71757 m .23375 .70103 L .26538 .6966 L p .707 .577 .707 r
F P
0 g
s
.59349 .25595 m .58623 .76236 L .54747 .75641 L p .707 .577 .707 r
F P
0 g
s
.54747 .75641 m .55473 .25001 L .59349 .25595 L p .707 .577 .707 r
F P
0 g
s
.26538 .6966 m .26732 .71314 L .23568 .71757 L p .707 .577 .707 r
F P
0 g
s
.81595 .58577 m .81894 .63879 L .8352 .62725 L p .707 .577 .707 r
F P
0 g
s
.8352 .62725 m .8322 .57422 L .81595 .58577 L p .707 .577 .707 r
F P
0 g
s
.41705 .75744 m .42431 .25103 L .46578 .24742 L p .707 .577 .707 r
F P
0 g
s
.42431 .25103 m .41705 .75744 L .3831 .76395 L p .707 .577 .707 r
F P
0 g
s
.73893 .74279 m .73424 .71095 L .70317 .71057 L p .707 .577 .707 r
F P
0 g
s
.73424 .71095 m .73893 .74279 L .77047 .73762 L p .707 .577 .707 r
F P
0 g
s
.77047 .73762 m .76577 .70578 L .73424 .71095 L p .707 .577 .707 r
F P
0 g
s
.76577 .70578 m .77047 .73762 L .79939 .72739 L p .707 .577 .707 r
F P
0 g
s
.79939 .72739 m .79469 .69555 L .76577 .70578 L p .707 .577 .707 r
F P
0 g
s
.65417 .64261 m .65117 .58959 L .6385 .57871 L p .707 .577 .707 r
F P
0 g
s
.65117 .58959 m .65417 .64261 L .67528 .65098 L p .707 .577 .707 r
F P
0 g
s
.70787 .74241 m .70317 .71057 L .67561 .70466 L p .707 .577 .707 r
F P
0 g
s
.70317 .71057 m .70787 .74241 L .73893 .74279 L p .707 .577 .707 r
F P
0 g
s
.79469 .69555 m .79939 .72739 L .82285 .71311 L p .707 .577 .707 r
F P
0 g
s
.82285 .71311 m .81815 .68127 L .79469 .69555 L p .707 .577 .707 r
F P
0 g
s
.55473 .25001 m .54747 .75641 L .50346 .75347 L p .707 .577 .707 r
F P
0 g
s
.50346 .75347 m .51072 .24707 L .55473 .25001 L p .707 .577 .707 r
F P
0 g
s
.45852 .75383 m .46578 .24742 L .51072 .24707 L p .707 .577 .707 r
F P
0 g
s
.46578 .24742 m .45852 .75383 L .41705 .75744 L p .707 .577 .707 r
F P
0 g
s
.8322 .57422 m .8352 .62725 L .84216 .61471 L p .707 .577 .707 r
F P
0 g
s
.84216 .61471 m .83917 .56168 L .8322 .57422 L p .707 .577 .707 r
F P
0 g
s
.51072 .24707 m .50346 .75347 L .45852 .75383 L p .707 .577 .707 r
F P
0 g
s
.73668 .80331 m .73474 .78677 L .70364 .78613 L p .707 .577 .707 r
F P
0 g
s
.73474 .78677 m .73668 .80331 L .76831 .79888 L p .707 .577 .707 r
F P
0 g
s
.76831 .79888 m .76638 .78234 L .73474 .78677 L p .707 .577 .707 r
F P
0 g
s
.6803 .7365 m .67561 .70466 L .65425 .69381 L p .707 .577 .707 r
F P
0 g
s
.67561 .70466 m .6803 .7365 L .70787 .74241 L p .707 .577 .707 r
F P
0 g
s
.76638 .78234 m .76831 .79888 L .79738 .78981 L p .707 .577 .707 r
F P
0 g
s
.79738 .78981 m .79545 .77327 L .76638 .78234 L p .707 .577 .707 r
F P
0 g
s
.81815 .68127 m .82285 .71311 L .83857 .69618 L p .707 .577 .707 r
F P
0 g
s
.83857 .69618 m .83387 .66434 L .81815 .68127 L p .707 .577 .707 r
F P
0 g
s
.6385 .57871 m .6415 .63174 L .65417 .64261 L p .707 .577 .707 r
F P
0 g
s
.70558 .80266 m .70364 .78613 L .67611 .78048 L p .707 .577 .707 r
F P
0 g
s
.70364 .78613 m .70558 .80266 L .73668 .80331 L p .707 .577 .707 r
F P
0 g
s
.79545 .77327 m .79738 .78981 L .82104 .777 L p .707 .577 .707 r
F P
0 g
s
.82104 .777 m .8191 .76046 L .79545 .77327 L p .707 .577 .707 r
F P
0 g
s
.6415 .63174 m .6385 .57871 L .6355 .5664 L p .707 .577 .707 r
F P
0 g
s
.67611 .78048 m .67805 .79701 L .70558 .80266 L p .707 .577 .707 r
F P
0 g
s
.65425 .69381 m .65895 .72565 L .6803 .7365 L p .707 .577 .707 r
F P
0 g
s
.65895 .72565 m .65425 .69381 L .64119 .67908 L p .707 .577 .707 r
F P
0 g
s
.67805 .79701 m .67611 .78048 L .65486 .77037 L p .707 .577 .707 r
F P
0 g
s
.83917 .56168 m .84216 .61471 L .83916 .6024 L p .707 .577 .707 r
F P
0 g
s
.83916 .6024 m .83617 .54937 L .83917 .56168 L p .707 .577 .707 r
F P
0 g
s
.83387 .66434 m .83857 .69618 L .845 .67825 L p .707 .577 .707 r
F P
0 g
s
.845 .67825 m .8403 .64641 L .83387 .66434 L p .707 .577 .707 r
F P
0 g
s
.8191 .76046 m .82104 .777 L .83697 .76168 L p .707 .577 .707 r
F P
0 g
s
.83697 .76168 m .83504 .74515 L .8191 .76046 L p .707 .577 .707 r
F P
0 g
s
.65486 .77037 m .65679 .78691 L .67805 .79701 L p .707 .577 .707 r
F P
0 g
s
.6355 .5664 m .6385 .61943 L .6415 .63174 L p .707 .577 .707 r
F P
0 g
s
.6385 .61943 m .6355 .5664 L .64247 .55386 L p .707 .577 .707 r
F P
0 g
s
.64119 .67908 m .64589 .71092 L .65895 .72565 L p .707 .577 .707 r
F P
0 g
s
.65679 .78691 m .65486 .77037 L .64195 .7568 L p .707 .577 .707 r
F P
0 g
s
.64589 .71092 m .64119 .67908 L .63771 .6619 L p .707 .578 .707 r
F P
0 g
s
.83504 .74515 m .83697 .76168 L .84361 .74538 L p .707 .577 .707 r
F P
0 g
s
.84361 .74538 m .84168 .72884 L .83504 .74515 L p .707 .577 .707 r
F P
0 g
s
.8403 .64641 m .845 .67825 L .84151 .66107 L p .707 .578 .707 r
F P
0 g
s
.84151 .66107 m .83681 .62923 L .8403 .64641 L p .707 .578 .707 r
F P
0 g
s
.64195 .7568 m .64388 .77334 L .65679 .78691 L p .707 .577 .707 r
F P
0 g
s
.83617 .54937 m .83916 .6024 L .82649 .59152 L p .707 .577 .707 r
F P
0 g
s
.82649 .59152 m .82349 .5385 L .83617 .54937 L p .707 .577 .707 r
F P
0 g
s
.64247 .55386 m .64546 .60688 L .6385 .61943 L p .707 .577 .707 r
F P
0 g
s
.63771 .6619 m .6424 .69374 L .64589 .71092 L p .707 .578 .707 r
F P
0 g
s
.64546 .60688 m .64247 .55386 L .65872 .54231 L p .707 .577 .707 r
F P
0 g
s
.64388 .77334 m .64195 .7568 L .63866 .74109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3909 .62046 m .3879 .56744 L .35675 .5662 L p .707 .577 .707 r
F P
0 g
s
.3879 .56744 m .3909 .62046 L .42268 .61777 L p .707 .577 .707 r
F P
0 g
s
.42268 .61777 m .41969 .56474 L .3879 .56744 L p .707 .577 .707 r
F P
0 g
s
.6424 .69374 m .63771 .6619 L .64414 .64397 L p .707 .577 .707 r
F P
0 g
s
.41969 .56474 m .42268 .61777 L .45198 .6114 L p .707 .577 .707 r
F P
0 g
s
.45198 .6114 m .44899 .55837 L .41969 .56474 L p .707 .577 .707 r
F P
0 g
s
.84168 .72884 m .84361 .74538 L .84032 .72967 L p .707 .577 .707 r
F P
0 g
s
.84032 .72967 m .83839 .71313 L .84168 .72884 L p .707 .577 .707 r
F P
0 g
s
.83681 .62923 m .84151 .66107 L .82845 .64634 L p .707 .577 .707 r
F P
0 g
s
.82845 .64634 m .82375 .6145 L .83681 .62923 L p .707 .577 .707 r
F P
0 g
s
.35975 .61922 m .35675 .5662 L .32927 .56114 L p .707 .577 .707 r
F P
0 g
s
.35675 .5662 m .35975 .61922 L .3909 .62046 L p .707 .577 .707 r
F P
0 g
s
.63866 .74109 m .64059 .75763 L .64388 .77334 L p .707 .577 .707 r
F P
0 g
s
.82349 .5385 m .82649 .59152 L .80538 .58315 L p .707 .577 .707 r
F P
0 g
s
.80538 .58315 m .80238 .53012 L .82349 .5385 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44899 .55837 m .45198 .6114 L .47593 .60198 L p .707 .577 .707 r
F P
0 g
s
.47593 .60198 m .47294 .54895 L .44899 .55837 L p .707 .577 .707 r
F P
0 g
s
.65872 .54231 m .66172 .59534 L .64546 .60688 L p .707 .577 .707 r
F P
0 g
s
.33227 .61417 m .32927 .56114 L .30816 .55277 L p .707 .577 .707 r
F P
0 g
s
.32927 .56114 m .33227 .61417 L .35975 .61922 L p .707 .577 .707 r
F P
0 g
s
.64414 .64397 m .64883 .67581 L .6424 .69374 L p .707 .577 .707 r
F P
0 g
s
.66172 .59534 m .65872 .54231 L .68267 .5329 L p .707 .577 .707 r
F P
0 g
s
.64059 .75763 m .63866 .74109 L .6453 .72478 L p .707 .577 .707 r
F P
0 g
s
.64883 .67581 m .64414 .64397 L .65985 .62704 L p .707 .577 .707 r
F P
0 g
s
.82375 .6145 m .82845 .64634 L .8071 .63549 L p .707 .577 .707 r
F P
0 g
s
.8071 .63549 m .8024 .60365 L .82375 .6145 L p .707 .577 .707 r
F P
0 g
s
.47294 .54895 m .47593 .60198 L .49219 .59043 L p .707 .577 .707 r
F P
0 g
s
.49219 .59043 m .48919 .53741 L .47294 .54895 L p .707 .577 .707 r
F P
0 g
s
.80238 .53012 m .80538 .58315 L .7779 .57809 L p .707 .577 .707 r
F P
0 g
s
.7779 .57809 m .77491 .52507 L .80238 .53012 L p .707 .577 .707 r
F P
0 g
s
.83839 .71313 m .84032 .72967 L .82742 .7161 L p .707 .577 .707 r
F P
0 g
s
.82742 .7161 m .82548 .69956 L .83839 .71313 L p .707 .577 .707 r
F P
0 g
s
.6453 .72478 m .64724 .74132 L .64059 .75763 L p .707 .577 .707 r
F P
0 g
s
.39592 .70598 m .39123 .67414 L .36016 .67375 L p .707 .577 .707 r
F P
0 g
s
.39123 .67414 m .39592 .70598 L .42746 .7008 L p .707 .577 .707 r
F P
0 g
s
.42746 .7008 m .42276 .66896 L .39123 .67414 L p .707 .577 .707 r
F P
0 g
s
.42276 .66896 m .42746 .7008 L .45638 .69058 L p .707 .577 .707 r
F P
0 g
s
.45638 .69058 m .45168 .65873 L .42276 .66896 L p .707 .577 .707 r
F P
0 g
s
.68567 .58592 m .68267 .5329 L .71197 .52653 L p .707 .577 .707 r
F P
0 g
s
.68267 .5329 m .68567 .58592 L .66172 .59534 L p .707 .577 .707 r
F P
0 g
s
.31116 .6058 m .30816 .55277 L .29549 .5419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55277 m .31116 .6058 L .33227 .61417 L p .707 .577 .707 r
F P
0 g
s
.36486 .70559 m .36016 .67375 L .3326 .66784 L p .707 .577 .707 r
F P
0 g
s
.36016 .67375 m .36486 .70559 L .39592 .70598 L p .707 .577 .707 r
F P
0 g
s
.45168 .65873 m .45638 .69058 L .47984 .6763 L p .707 .577 .707 r
F P
0 g
s
.47984 .6763 m .47514 .64446 L .45168 .65873 L p .707 .577 .707 r
F P
0 g
s
.77491 .52507 m .7779 .57809 L .74675 .57685 L p .707 .577 .707 r
F P
0 g
s
.74675 .57685 m .74375 .52383 L .77491 .52507 L p .707 .577 .707 r
F P
0 g
s
.65985 .62704 m .66455 .65888 L .64883 .67581 L p .707 .577 .707 r
F P
0 g
s
.66455 .65888 m .65985 .62704 L .68332 .61276 L p .707 .577 .707 r
F P
0 g
s
.64724 .74132 m .6453 .72478 L .66123 .70947 L p .707 .577 .707 r
F P
0 g
s
.71497 .57955 m .71197 .52653 L .74375 .52383 L p .707 .577 .707 r
F P
0 g
s
.71197 .52653 m .71497 .57955 L .68567 .58592 L p .707 .577 .707 r
F P
0 g
s
.8024 .60365 m .8071 .63549 L .77954 .62958 L p .707 .577 .707 r
F P
0 g
s
.77954 .62958 m .77484 .59774 L .8024 .60365 L p .707 .577 .707 r
F P
0 g
s
.74375 .52383 m .74675 .57685 L .71497 .57955 L p .707 .577 .707 r
F P
0 g
s
.48919 .53741 m .49219 .59043 L .49915 .57789 L p .707 .577 .707 r
F P
0 g
s
.49915 .57789 m .49616 .52487 L .48919 .53741 L p .707 .577 .707 r
F P
0 g
s
.82548 .69956 m .82742 .7161 L .80616 .70599 L p .707 .577 .707 r
F P
0 g
s
.80616 .70599 m .80423 .68945 L .82548 .69956 L p .707 .577 .707 r
F P
0 g
s
.39367 .76649 m .39173 .74995 L .36063 .74931 L p .707 .577 .707 r
F P
0 g
s
.39173 .74995 m .39367 .76649 L .4253 .76206 L p .707 .577 .707 r
F P
0 g
s
.4253 .76206 m .42337 .74553 L .39173 .74995 L p .707 .577 .707 r
F P
0 g
s
.33729 .69969 m .3326 .66784 L .31124 .65699 L p .707 .577 .707 r
F P
0 g
s
.3326 .66784 m .33729 .69969 L .36486 .70559 L p .707 .577 .707 r
F P
0 g
s
.42337 .74553 m .4253 .76206 L .45437 .753 L p .707 .577 .707 r
F P
0 g
s
.45437 .753 m .45244 .73646 L .42337 .74553 L p .707 .577 .707 r
F P
0 g
s
.66123 .70947 m .66317 .72601 L .64724 .74132 L p .707 .577 .707 r
F P
0 g
s
.47514 .64446 m .47984 .6763 L .49556 .65936 L p .707 .577 .707 r
F P
0 g
s
.49556 .65936 m .49086 .62752 L .47514 .64446 L p .707 .577 .707 r
F P
0 g
s
.68802 .6446 m .68332 .61276 L .71223 .60253 L p .707 .577 .707 r
F P
0 g
s
.68332 .61276 m .68802 .6446 L .66455 .65888 L p .707 .577 .707 r
F P
0 g
s
.29549 .5419 m .29849 .59492 L .31116 .6058 L p .707 .577 .707 r
F P
0 g
s
.36257 .76585 m .36063 .74931 L .3331 .74366 L p .707 .577 .707 r
F P
0 g
s
.36063 .74931 m .36257 .76585 L .39367 .76649 L p .707 .577 .707 r
F P
0 g
s
.77484 .59774 m .77954 .62958 L .74847 .6292 L p .707 .577 .707 r
F P
0 g
s
.74847 .6292 m .74377 .59736 L .77484 .59774 L p .707 .577 .707 r
F P
0 g
s
.45244 .73646 m .45437 .753 L .47803 .74018 L p .707 .577 .707 r
F P
0 g
s
.47803 .74018 m .47609 .72364 L .45244 .73646 L p .707 .577 .707 r
F P
0 g
s
.29849 .59492 m .29549 .5419 L .29249 .52958 L p .707 .577 .707 r
F P
0 g
s
.71693 .63437 m .71223 .60253 L .74377 .59736 L p .707 .577 .707 r
F P
0 g
s
.71223 .60253 m .71693 .63437 L .68802 .6446 L p .707 .577 .707 r
F P
0 g
s
.74377 .59736 m .74847 .6292 L .71693 .63437 L p .707 .577 .707 r
F P
0 g
s
.66317 .72601 m .66123 .70947 L .68489 .69666 L p .707 .577 .707 r
F P
0 g
s
.3331 .74366 m .33504 .7602 L .36257 .76585 L p .707 .577 .707 r
F P
0 g
s
.80423 .68945 m .80616 .70599 L .77863 .70034 L p .707 .577 .707 r
F P
0 g
s
.77863 .70034 m .7767 .6838 L .80423 .68945 L p .707 .577 .707 r
F P
0 g
s
.31124 .65699 m .31594 .68883 L .33729 .69969 L p .707 .577 .707 r
F P
0 g
s
.31594 .68883 m .31124 .65699 L .29818 .64226 L p .707 .577 .707 r
F P
0 g
s
.33504 .7602 m .3331 .74366 L .31185 .73356 L p .707 .577 .707 r
F P
0 g
s
.49616 .52487 m .49915 .57789 L .49615 .56558 L p .707 .577 .707 r
F P
0 g
s
.49615 .56558 m .49316 .51255 L .49616 .52487 L p .707 .577 .707 r
F P
0 g
s
.68489 .69666 m .68683 .71319 L .66317 .72601 L p .707 .577 .707 r
F P
0 g
s
.49086 .62752 m .49556 .65936 L .50199 .64143 L p .707 .577 .707 r
F P
0 g
s
.50199 .64143 m .49729 .60959 L .49086 .62752 L p .707 .577 .707 r
F P
0 g
s
.47609 .72364 m .47803 .74018 L .49396 .72487 L p .707 .577 .707 r
F P
0 g
s
.49396 .72487 m .49203 .70833 L .47609 .72364 L p .707 .577 .707 r
F P
0 g
s
.31185 .73356 m .31378 .75009 L .33504 .7602 L p .707 .577 .707 r
F P
0 g
s
.68683 .71319 m .68489 .69666 L .71396 .68759 L p .707 .577 .707 r
F P
0 g
s
.29249 .52958 m .29549 .58261 L .29849 .59492 L p .707 .577 .707 r
F P
0 g
s
.7767 .6838 m .77863 .70034 L .74753 .6997 L p .707 .577 .707 r
F P
0 g
s
.74753 .6997 m .74559 .68316 L .7767 .6838 L p .707 .577 .707 r
F P
0 g
s
.29549 .58261 m .29249 .52958 L .29946 .51704 L p .707 .577 .707 r
F P
0 g
s
.71396 .68759 m .7159 .70413 L .68683 .71319 L p .707 .577 .707 r
F P
0 g
s
.7159 .70413 m .71396 .68759 L .74559 .68316 L p .707 .577 .707 r
F P
0 g
s
.29818 .64226 m .30288 .6741 L .31594 .68883 L p .707 .577 .707 r
F P
0 g
s
.74559 .68316 m .74753 .6997 L .7159 .70413 L p .707 .577 .707 r
F P
0 g
s
.31378 .75009 m .31185 .73356 L .29894 .71998 L p .707 .577 .707 r
F P
0 g
s
.30288 .6741 m .29818 .64226 L .29469 .62509 L p .707 .578 .707 r
F P
0 g
s
.49203 .70833 m .49396 .72487 L .5006 .70856 L p .707 .577 .707 r
F P
0 g
s
.5006 .70856 m .49867 .69202 L .49203 .70833 L p .707 .577 .707 r
F P
0 g
s
.49729 .60959 m .50199 .64143 L .4985 .62426 L p .707 .578 .707 r
F P
0 g
s
.4985 .62426 m .4938 .59242 L .49729 .60959 L p .707 .578 .707 r
F P
0 g
s
.29894 .71998 m .30087 .73652 L .31378 .75009 L p .707 .577 .707 r
F P
0 g
s
.49316 .51255 m .49615 .56558 L .48348 .55471 L p .707 .577 .707 r
F P
0 g
s
.48348 .55471 m .48048 .50168 L .49316 .51255 L p .707 .577 .707 r
F P
0 g
s
.29946 .51704 m .30245 .57007 L .29549 .58261 L p .707 .577 .707 r
F P
0 g
s
.29469 .62509 m .29939 .65693 L .30288 .6741 L p .707 .578 .707 r
F P
0 g
s
.30245 .57007 m .29946 .51704 L .31571 .5055 L p .707 .577 .707 r
F P
0 g
s
.30087 .73652 m .29894 .71998 L .29565 .70428 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29939 .65693 m .29469 .62509 L .30113 .60716 L p .707 .577 .707 r
F P
0 g
s
.49867 .69202 m .5006 .70856 L .49731 .69285 L p .707 .577 .707 r
F P
0 g
s
.49731 .69285 m .49538 .67632 L .49867 .69202 L p .707 .577 .707 r
F P
0 g
s
.4938 .59242 m .4985 .62426 L .48544 .60953 L p .707 .577 .707 r
F P
0 g
s
.48544 .60953 m .48074 .57768 L .4938 .59242 L p .707 .577 .707 r
F P
0 g
s
.29565 .70428 m .29758 .72081 L .30087 .73652 L p .707 .577 .707 r
F P
0 g
s
.48048 .50168 m .48348 .55471 L .46237 .54633 L p .707 .577 .707 r
F P
0 g
s
.46237 .54633 m .45937 .49331 L .48048 .50168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31571 .5055 m .31871 .55852 L .30245 .57007 L p .707 .577 .707 r
F P
0 g
s
.30113 .60716 m .30582 .639 L .29939 .65693 L p .707 .577 .707 r
F P
0 g
s
.31871 .55852 m .31571 .5055 L .33966 .49608 L p .707 .577 .707 r
F P
0 g
s
.29758 .72081 m .29565 .70428 L .30229 .68797 L p .707 .577 .707 r
F P
0 g
s
.30582 .639 m .30113 .60716 L .31684 .59022 L p .707 .577 .707 r
F P
0 g
s
.48074 .57768 m .48544 .60953 L .46409 .59867 L p .707 .577 .707 r
F P
0 g
s
.46409 .59867 m .45939 .56683 L .48074 .57768 L p .707 .577 .707 r
F P
0 g
s
.45937 .49331 m .46237 .54633 L .43489 .54128 L p .707 .577 .707 r
F P
0 g
s
.43489 .54128 m .4319 .48825 L .45937 .49331 L p .707 .577 .707 r
F P
0 g
s
.49538 .67632 m .49731 .69285 L .48441 .67928 L p .707 .577 .707 r
F P
0 g
s
.48441 .67928 m .48247 .66274 L .49538 .67632 L p .707 .577 .707 r
F P
0 g
s
.30229 .68797 m .30423 .70451 L .29758 .72081 L p .707 .577 .707 r
F P
0 g
s
.34266 .54911 m .33966 .49608 L .36896 .48971 L p .707 .577 .707 r
F P
0 g
s
.33966 .49608 m .34266 .54911 L .31871 .55852 L p .707 .577 .707 r
F P
0 g
s
.4319 .48825 m .43489 .54128 L .40374 .54004 L p .707 .577 .707 r
F P
0 g
s
.40374 .54004 m .40074 .48701 L .4319 .48825 L p .707 .577 .707 r
F P
0 g
s
.31684 .59022 m .32154 .62206 L .30582 .639 L p .707 .577 .707 r
F P
0 g
s
.32154 .62206 m .31684 .59022 L .34031 .57594 L p .707 .577 .707 r
F P
0 g
s
.30423 .70451 m .30229 .68797 L .31822 .67266 L p .707 .577 .707 r
F P
0 g
s
.37196 .54274 m .36896 .48971 L .40074 .48701 L p .707 .577 .707 r
F P
0 g
s
.36896 .48971 m .37196 .54274 L .34266 .54911 L p .707 .577 .707 r
F P
0 g
s
.45939 .56683 m .46409 .59867 L .43653 .59277 L p .707 .577 .707 r
F P
0 g
s
.43653 .59277 m .43183 .56093 L .45939 .56683 L p .707 .577 .707 r
F P
0 g
s
.40074 .48701 m .40374 .54004 L .37196 .54274 L p .707 .577 .707 r
F P
0 g
s
.48247 .66274 m .48441 .67928 L .46315 .66918 L p .707 .577 .707 r
F P
0 g
s
.46315 .66918 m .46121 .65264 L .48247 .66274 L p .707 .577 .707 r
F P
0 g
s
.31822 .67266 m .32016 .68919 L .30423 .70451 L p .707 .577 .707 r
F P
0 g
s
.34501 .60778 m .34031 .57594 L .36922 .56572 L p .707 .577 .707 r
F P
0 g
s
.34031 .57594 m .34501 .60778 L .32154 .62206 L p .707 .577 .707 r
F P
0 g
s
.43183 .56093 m .43653 .59277 L .40546 .59238 L p .707 .577 .707 r
F P
0 g
s
.40546 .59238 m .40076 .56054 L .43183 .56093 L p .707 .577 .707 r
F P
0 g
s
.37392 .59756 m .36922 .56572 L .40076 .56054 L p .707 .577 .707 r
F P
0 g
s
.36922 .56572 m .37392 .59756 L .34501 .60778 L p .707 .577 .707 r
F P
0 g
s
.40076 .56054 m .40546 .59238 L .37392 .59756 L p .707 .577 .707 r
F P
0 g
s
.32016 .68919 m .31822 .67266 L .34188 .65984 L p .707 .577 .707 r
F P
0 g
s
.46121 .65264 m .46315 .66918 L .43562 .66353 L p .707 .577 .707 r
F P
0 g
s
.43562 .66353 m .43369 .64699 L .46121 .65264 L p .707 .577 .707 r
F P
0 g
s
.34188 .65984 m .34382 .67638 L .32016 .68919 L p .707 .577 .707 r
F P
0 g
s
.34382 .67638 m .34188 .65984 L .37095 .65077 L p .707 .577 .707 r
F P
0 g
s
.43369 .64699 m .43562 .66353 L .40452 .66288 L p .707 .577 .707 r
F P
0 g
s
.40452 .66288 m .40258 .64635 L .43369 .64699 L p .707 .577 .707 r
F P
0 g
s
.37095 .65077 m .37288 .66731 L .34382 .67638 L p .707 .577 .707 r
F P
0 g
s
.37288 .66731 m .37095 .65077 L .40258 .64635 L p .707 .577 .707 r
F P
0 g
s
.40258 .64635 m .40452 .66288 L .37288 .66731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolH0026Ool007Ioo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEP`007Yoo`00
LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF1`00
Lgoo001]Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUH00002001`Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00J7oo0P0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P00Jgoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008006Moo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEPl000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Moo`03001JEP0000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol01@00FUIJEUYF00001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`T004Eoo`00E7oo0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF009JEPP003eoo`00Dgoo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD0
03Qoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo10001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`00=Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20008Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000UJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00MJEP@000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo001COol00`00FUH00004FUH00`00FUH000030004Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH01eYF100000=JEP00FUH00P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool005Aoo`8000AJ
EP8000Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30005FUH01@00FUIJEUYF
00000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo0P000eYF00<005YFFUH00`001Goo00@005YF
FUH000EJEQ400003FUH005YF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P0000=JEP00000015YF00<005YF00000`0000Aoo`00FUIJEPH000AJEP03001JEUYF00IJ
EP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol40005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
E7oo0P0000=JEP00FUH015YF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool005Aoo`800003FUH005YF00AJEP03001JEUYF008000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol01000FUIJEP001EYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP04FUHH0003FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01@00FUIJEUYF000015YF00@005YFFUH000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH00000
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04000HOol40005FUH01@00FUIJEUYF0000;Woo001D
Ool01@00FUIJEUYF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP<0021o
o`8000=JEP05001JEUYFFUH0000^Ool005Aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P008goo100000=JEP00FUH00UYF0P00;Goo001DOol01000FUIJEUYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUH000008goo0P000UYF00@005YF000000=JEP8002eoo`00E7oo00L005YFFUIJEP00
FUH00006FUH00`00FUIJEP05FUH70008FUH00`00FUIJEP03FUH400000eYF001JEP04FUH01000FUIJ
EP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF0P004goo3@0000=oo`0000000P0015YF00D005YFFUIJEP00009JEP8002eoo`00EGoo00<0
05YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000EJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20002FUH5000:Ool40002FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP02FUH4000]Ool004Ioo`T000Moo`05001JEUYFFUH00007FUH0
0`00FUH000020008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF00@005YFFUIJEPX000IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP<002eoo`00@7oo1P0015YF00<005YFFUH00UYF1`001EYF00<005YFFUH015YF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@0000AJEP00FUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EP00FUH00005FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH40005FUH3000]Ool003aoo`@00003FUH005YF00IJEP03Ool005YF00MJEP03001JEP0000EJEP03
001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH0
05YF00=JEP8000=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool003Qoo`@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00@000AJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUH0000]Ool003Ioo`800003FUH005YF00IJEP03001JEUYF00AJEP03OomJEP0000QJEP<000EJEPT0
009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00EJEP03001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF
00=JEP@000MJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH0000002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00001EYF00<005YFFUH00UYF0P000Woo40000eYF00<005YFFUH02EYF00<005YFFUH01UYF
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP000000;Woo000bOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH017ooFUIJEP0025YF00@005YFFUH000=JEP8000EJEP800005Ool005YFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH00000;goo000aOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF00<005YF00001EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009JEP03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPL0
00AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000_Ool002moo`800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF009JEP05001JEUYFFUIoo`03FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH2000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF0`001eYF00<005YFFUH01EYF00<005YFFUH010001eYF200015YF00<005YF
FUH00eYF00<005YF0000;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00002FUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000015YF001JEP001eYF00<005YFFUH015YF1000
0UYF00<005YFFUH01UYF00<005YFFUH01EYF1@001EYF00<005YF0000;goo000]Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEWoo1EYF00@005YFFUIoo`EJEP04001JEP00Ool4FUH0
0`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000^Ool002eoo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
009JEP04001JEP000002FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH01000FUIJEP000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000Eoo`00FUIJEP0000MJEP03001JEP00008000QJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH200001Goo000005YF00000UYF00<007ooOol0;7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIoo`06FUH00`00FUIoo`06FUH00`00FUH00005FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000EJEP04001JEUYFFUH=0005FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000Eoo`80009JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF0`0000=JEP00
FUH015YF10000UYF00<005YFFUH01UYF00<005YF00000`0000AJEP00FUIJEP<000AJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009J
EP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Uoo`03001JEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<007ooFUH01UYF00<005YF
FUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH010001UYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010003Goo00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40007FUH20002FUH01@00FUIJEUYF00001EYF1P00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH30003FUHJ
000AOol3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPT00004FUH0
05YFFUH90002FUH300000eYF001JEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P001EYF0P00:7oo00<005YF0000;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP020002FUH30008FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01P00FUIJEP00FUH000EJEP03001JEP0002Moo`03001JEP0002eoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF1@000eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF001JEP00
00AJEP80009JEP03001JEUYF00EJEPH000MJEP04001JEUYFFUH70002FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00
FUH00002FUH00`00FUIJEP03FUH01000FUIJEP002Woo0`0067oo0P0000=JEP00Ool0;7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP00009JEP8000AJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJEPH000IJEP@000EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EP00009JEP03001JEUYF00=JEP04001JEUYF0009Ool5000FOol00`00FUH00002FUH00`00Oomoo`0Z
Ool002aoo`03001JEP0000AJEP03001JEP0000@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00009JEP8000IJEP03001JEP00010000AJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20003FUH00`00FUIJEP03FUH01000FUIJEP002Goo1@005Goo00@005YFFUH0009JEP03001o
ogoo02Yoo`00;Goo0P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUH005YF008000IJEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP800005FUH005YFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
0008Ool5000DOol01@00FUIJEUYF00000UYF00<007ooOol0:Woo000]Ool20002FUH200000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUH00000FUH000AJEP80
00EJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00
FUIJEP03FUH00`00FUIJEP020009Ool3000DOol00`00FUIJEP03FUH00`00FUH0000/Ool002eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEP00008000IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF008000AJEP03
001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00EJEP03001JEUYF00=JEP03001JEUYF008000Moo`l000Qoo`<000EJEP8002eoo`00;Goo0P0000=J
EP00FUH00P001UYF00<005YFFUH01UYF00<005YFFUH00UYF3P001EYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF0`001eYF00D005YF001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000EJEP03001JEUYF00=JEP03001JEUYF00800003
Ool0000000@000AJEP03001JEUYF00IJEP03001JEP0000<0009oo`80009JEP03001JEUYF00=JEP80
02eoo`00;Goo0P0000EJEP00001JEP0000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF009JEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0
00UJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001oogoo02aoo`00;Goo00@005YFFUH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF
FUH005YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH025YF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P001EYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUH000020007FUH>000015YF001JEP0015YF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P0015YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH00`000eYF0`001eYF00<005YFFUH015YF1`0015YF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20005FUH00`00FUIJ
EP04FUH2000015YF001JEUYF1P0015YF00<005YFFUH01UYF00<005YF00001P000UYF1P000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH01eYF10002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
10001goo200015YF00<005YFFUH00UYF0`00<7oo000]Ool20005FUH00`00FUIJEP02FUH20002FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH00005FUH300000eYF0000000200000eYF0000
000>00000eYF001JEP0:FUH00`00FUIJEP06FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF001JEUYF00000UYF0P000eYF00<005YFFUH01EYF1000
2Goo10001UYF1@0015YF00<005YF0000<7oo000]Ool20005FUH00`00FUIJEP02000015YF00000000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF00<005YFFUH00P000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP<000IJEP03001JEUYF00@000Uoo`@0009J
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUH0000_Ool002eoo`8000EJEPL000QJEP03
001JEUYF00AJEP`000IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00EJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@0009JEP8000MJEQ0000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH0
05YFFUH0000^Ool002aoo`03001JEP0000EJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH01@00FUIJEP00FUH010000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF00L005YF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF000005YF00001EYF0P0015YF00<005YF
FUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<007ooOol0
;7oo000/Ool01000FUIJEP000eYF0`0015YF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00@0
05YFFUH000AJEP@000EJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30002FUH01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01eYF00@005YFFUH000Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0009JEP8000IJEP03001J
EUYF00@000MJEP<000IJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJ
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF0`000UYF00<005YF
FUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`001Woo00@005YF000002eoo`00;7oo
00D005YFFUH005YF00<000IJEP<0009JEP03001JEUYF00EJEPD000EJEP06001JEUYF001JEP000UYF
00@005YF0000009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00<000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP05FUH20009Ool3000]Ool002eoo`03001JEP0000800003FUH005YF00=JEP80
00EJEP03001JEUYF00EJEPD000EJEP06001JEUYFFUH005YF10001Woo0`000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF0`000UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP<000IJEP03001JEUYF009JEP<000aoo`8002eoo`00;Goo00@005YF000000=JEP05
001JEUYF001oo`040002FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP020002FUH00`00Oomoo`07
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20004FUH01000FUH00000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00
00000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003goo
0P00;Goo000]Ool30004FUH30006OolG000017oo001JEUYF0`001Woo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000P001EYF0`001UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Woo0P00;Goo000]Ool20005FUH00`00Oomoo`0OOol00`00FUH0
0002FUH20003Ool01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`000UYF00<005YFFUH0
1UYF00<005YFFUH0100057oo00<005YF0000;Goo000]Ool20004FUH00`00Oomoo`0QOol00`00FUH0
0003FUH40002FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001JEUYF
009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF00AJEP<00003FUH005YF009JEP03001JEP0000d001Qoo`03001JEP0002eoo`00;Goo
00@005YF001JEP8002Eoo`8000AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJ
EPH000MJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP020002FUH300000eYF001oo`0ROol200000eYF
001oo`0/Ool002eoo`03001JEP00008002Moo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000IJEP04001JEUYFFUH20002Ool3000ROol01000FUH00000;Woo000]Ool01000FUH005YF
0`0097oo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
5P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000P000UYF
00<005YFFUH00UYF0P0000Aoo`00FUH0025oo`03001JEUYF008002ioo`00;Goo00D005YF001JEP00
009JEP8001ioo`@00004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000:FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
0003FUH00`00FUH000030003FUH01P00FUH00000FUH0021oo`05001JEUYFFUH0000_Ool002eoo`<0
0003FUH005YF00=JEP<001Ioo`D000EJEP03001JEUYF009JEPD000AJEP03001JEUYF00EJEP03001J
EUYF009JEPL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001J
EUYF009JEP@0009JEP04001JEP000002Ool300001UYF001JEP00FUH001moo`03001JEUYF009JEP03
001oogoo02eoo`00;Goo0`0000=JEP00FUH015YF00<005YF00000`003Woo10000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF000040002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`0000=JEP0000000P001goo0P000UYF
00<005YF000077oo0`000eYF00<007ooOol0;Woo000]Ool00`00Ool00002FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH>0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30002FUH00`00FUH000020007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH300000eYF001JEP03FUH400000eYF001oo`08Ool01`00FUH005YF001JEP0001Yoo`80009JEP04
001JEUYF000aOol002eoo`06001oogoo001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF0P0000Aoo`00FUIJEP8000Ioo`08001JEUYF001JEP00FUH001Moo`<000EJEP80039oo`00;Goo
0P0000Aoo`00FUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
0000009oo`04001JEP00FUH30002Ool00`00FUIJEP02FUH4000DOol300000eYF001JEP05FUH00`00
Oomoo`0aOol002eoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00IJEP03001JEUYF00800004FUH005YFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40002Ool00`00FUH00004FUH30005FUH2000BOol30004FUH00`00FUIJEP02FUH2000dOol002io
o`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP<0
00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003Ool20005
FUH00`00FUH0000300000eYF0000000<Ool60007FUH00`00FUIJEP02000fOol002ioo`03001JEUYF
00@000=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP8000EJEP800003
Ool0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3000hOol002moo`03001JEP00009JEP<00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP05001oogooOol0
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000goo10000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00>Woo000`Ool00`00FUH00003FUH4
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020002FUH00`00FUIJEP02FUH20004
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00Ool00P0000AJEP00
FUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8003ao
o`00<Goo0P0015YF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@0
05YFFUH000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD000=JEP03001JEUYF009JEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008003ioo`00<Woo00<005YFFUH00UYF
00<005YFFUH00eYF4@000eYF00<005YFFUH01UYF0`002Woo0`0025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Goo000cOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000>Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30008FUH00`00FUIJEP04FUH300000eYF0000000>0017Ool003Eoo`800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@001Aoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0001FOol003Moo`<000IJEP03
001JEUYF00EJEP03001JEUYF00AJEPD001aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00AJEPD000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03
001oogoo05Aoo`00>Woo10000UYF00<005YFFUH01EYF00<005YFFUH010009Woo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02@001EYF00<005YFFUH01UYF00<0
05YFFUH00`000eYF00<007ooOol0EGoo000nOol=000`Ool80006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH80004FUH50005FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00F7oo0023OolJ0004FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH30004FUH00`00FUH0001HOol0091oo`03001JEUYF
00@000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000MJEP03001JEUYF009JEP<000IJEP8005Uo
o`00TGoo00<005YF00000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P000UYF00<005YFFUH00eYF0P00FWoo002AOol00`00FUH00004FUH60004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P00G7oo002BOol20005FUH01000FUIJEUYF
4`000UYF00<005YFFUH01UYF00@005YF000005ioo`00Tgoo0P0015YF00<005YFFUH01EYF00@005YF
FUIJEPL000IJEP03001JEUYF00EJEP<0061oo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002HOol30006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH00002001UOol009]oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH006Qo
o`00Wgoo4000KWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59671 .77454 m .59371 .72151 L .56256 .72028 L p .707 .577 .707 r
F P
0 g
s
.59371 .72151 m .59671 .77454 L .62849 .77184 L p .707 .577 .707 r
F P
0 g
s
.62849 .77184 m .62549 .71882 L .59371 .72151 L p .707 .577 .707 r
F P
0 g
s
.62549 .71882 m .62849 .77184 L .65779 .76547 L p .707 .577 .707 r
F P
0 g
s
.65779 .76547 m .65479 .71245 L .62549 .71882 L p .707 .577 .707 r
F P
0 g
s
.56555 .7733 m .56256 .72028 L .53508 .71522 L p .707 .577 .707 r
F P
0 g
s
.56256 .72028 m .56555 .7733 L .59671 .77454 L p .707 .577 .707 r
F P
0 g
s
.65479 .71245 m .65779 .76547 L .68174 .75605 L p .707 .577 .707 r
F P
0 g
s
.68174 .75605 m .67874 .70303 L .65479 .71245 L p .707 .577 .707 r
F P
0 g
s
.53808 .76825 m .53508 .71522 L .51397 .70685 L p .707 .577 .707 r
F P
0 g
s
.53508 .71522 m .53808 .76825 L .56555 .7733 L p .707 .577 .707 r
F P
0 g
s
.63111 .84914 m .62917 .8326 L .59754 .83703 L p .707 .577 .707 r
F P
0 g
s
.60173 .83688 m .59703 .80504 L .56596 .80466 L p .707 .577 .707 r
F P
0 g
s
.66018 .84007 m .65824 .82353 L .62917 .8326 L p .707 .577 .707 r
F P
0 g
s
.59703 .80504 m .60173 .83688 L .63327 .83171 L p .707 .577 .707 r
F P
0 g
s
.63327 .83171 m .62857 .79987 L .59703 .80504 L p .707 .577 .707 r
F P
0 g
s
.67874 .70303 m .68174 .75605 L .69799 .74451 L p .707 .577 .707 r
F P
0 g
s
.69799 .74451 m .69499 .69148 L .67874 .70303 L p .707 .577 .707 r
F P
0 g
s
.68383 .82725 m .6819 .81072 L .65824 .82353 L p .707 .577 .707 r
F P
0 g
s
.62857 .79987 m .63327 .83171 L .66218 .82148 L p .707 .577 .707 r
F P
0 g
s
.66218 .82148 m .65748 .78964 L .62857 .79987 L p .707 .577 .707 r
F P
0 g
s
.59947 .85356 m .59754 .83703 L .56644 .83638 L p .707 .577 .707 r
F P
0 g
s
.57066 .8365 m .56596 .80466 L .5384 .79875 L p .707 .577 .707 r
F P
0 g
s
.56596 .80466 m .57066 .8365 L .60173 .83688 L p .707 .577 .707 r
F P
0 g
s
.69977 .81194 m .69783 .79541 L .6819 .81072 L p .707 .577 .707 r
F P
0 g
s
.65748 .78964 m .66218 .82148 L .68565 .8072 L p .707 .577 .707 r
F P
0 g
s
.68565 .8072 m .68095 .77536 L .65748 .78964 L p .707 .577 .707 r
F P
0 g
s
.59754 .83703 m .59947 .85356 L .63111 .84914 L p .707 .577 .707 r
F P
0 g
s
.62917 .8326 m .63111 .84914 L .66018 .84007 L p .707 .577 .707 r
F P
0 g
s
.51697 .75987 m .51397 .70685 L .5013 .69597 L p .707 .577 .707 r
F P
0 g
s
.51397 .70685 m .51697 .75987 L .53808 .76825 L p .707 .577 .707 r
F P
0 g
s
.56837 .85292 m .56644 .83638 L .53891 .83073 L p .707 .577 .707 r
F P
0 g
s
.56644 .83638 m .56837 .85292 L .59947 .85356 L p .707 .577 .707 r
F P
0 g
s
.65824 .82353 m .66018 .84007 L .68383 .82725 L p .707 .577 .707 r
F P
0 g
s
.5431 .83059 m .5384 .79875 L .51705 .7879 L p .707 .577 .707 r
F P
0 g
s
.5384 .79875 m .5431 .83059 L .57066 .8365 L p .707 .577 .707 r
F P
0 g
s
.69499 .69148 m .69799 .74451 L .70496 .73197 L p .707 .577 .707 r
F P
0 g
s
.70496 .73197 m .70196 .67894 L .69499 .69148 L p .707 .577 .707 r
F P
0 g
s
.69889 .79293 m .70136 .79027 L p .69826 .78801 L .707 .577 .707 r
F P
0 g
s
.70136 .79027 m .69666 .75843 L .68095 .77536 L p .707 .577 .707 r
F P
0 g
s
.69666 .75843 m .70136 .79027 L .70779 .77234 L p .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .70448 .7791 L .69888 .79284 L p .707 .577 .707 r
F P
0 g
s
.69888 .79284 m .69783 .79541 L p .69921 .79544 L .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .69888 .79284 L .69921 .79544 L .707 .577 .707 r
F
.68095 .77536 m .68565 .8072 L .69889 .79293 L p F P
0 g
s
.69826 .78801 m .68095 .77536 L .69889 .79293 L .707 .577 .707 r
F
.53891 .83073 m .54084 .84727 L .56837 .85292 L p F P
0 g
s
.54084 .84727 m .53891 .83073 L .51765 .82063 L p .707 .577 .707 r
F P
0 g
s
.5013 .69597 m .50429 .749 L .51697 .75987 L p .707 .577 .707 r
F P
0 g
s
.6819 .81072 m .68383 .82725 L .69977 .81194 L p .707 .577 .707 r
F P
0 g
s
.50429 .749 m .5013 .69597 L .4983 .68366 L p .707 .577 .707 r
F P
0 g
s
.51765 .82063 m .51959 .83717 L .54084 .84727 L p .707 .577 .707 r
F P
0 g
s
.51705 .7879 m .52174 .81974 L .5431 .83059 L p .707 .577 .707 r
F P
0 g
s
.52174 .81974 m .51705 .7879 L .50399 .77317 L p .707 .577 .707 r
F P
0 g
s
.70779 .77234 m .70309 .7405 L .69666 .75843 L p .707 .577 .707 r
F P
0 g
s
.70196 .67894 m .70496 .73197 L .70196 .71966 L p .707 .577 .707 r
F P
0 g
s
.70196 .71966 m .69896 .66663 L .70196 .67894 L p .707 .577 .707 r
F P
0 g
s
.51959 .83717 m .51765 .82063 L .50475 .80706 L p .707 .577 .707 r
F P
0 g
s
.69783 .79541 m .69977 .81194 L .70641 .79563 L p .707 .577 .707 r
F P
0 g
s
.4983 .68366 m .50129 .73669 L .50429 .749 L p .707 .577 .707 r
F P
0 g
s
.50475 .80706 m .50668 .8236 L .51959 .83717 L p .707 .577 .707 r
F P
0 g
s
.50399 .77317 m .50869 .80501 L .52174 .81974 L p .707 .577 .707 r
F P
0 g
s
.50869 .80501 m .50399 .77317 L .5005 .75599 L p .707 .578 .707 r
F P
0 g
s
.50129 .73669 m .4983 .68366 L .50526 .67112 L p .707 .577 .707 r
F P
0 g
s
.48441 .82075 m .49167 .31434 L .44766 .3114 L p .707 .577 .707 r
F P
0 g
s
.50668 .8236 m .50475 .80706 L .50145 .79135 L p .707 .577 .707 r
F P
0 g
s
.50145 .79135 m .50339 .80789 L .50668 .8236 L p .707 .577 .707 r
F P
0 g
s
.5005 .75599 m .5052 .78783 L .50869 .80501 L p .707 .578 .707 r
F P
0 g
s
.50526 .67112 m .50826 .72415 L .50129 .73669 L p .707 .577 .707 r
F P
0 g
s
.5052 .78783 m .5005 .75599 L .50693 .73806 L p .707 .577 .707 r
F P
0 g
s
.50826 .72415 m .50526 .67112 L .52152 .65958 L p .707 .577 .707 r
F P
0 g
s
.51061 .77263 m .52403 .75973 L p .51245 .78608 L .707 .577 .707 r
F P
0 g
s
.50693 .73806 m .51163 .7699 L .51062 .77273 L p .707 .577 .707 r
F P
0 g
s
.51062 .77273 m .5052 .78783 L p .50672 .74428 L .707 .577 .707 r
F P
0 g
s
.50672 .74428 m .50693 .73806 L .51062 .77273 L .707 .577 .707 r
F
.51003 .79158 m .5081 .77504 L .51061 .77263 L p F P
0 g
s
.51003 .79158 m .51061 .77263 L .51245 .78608 L .707 .577 .707 r
F
.50339 .80789 m .50145 .79135 L .5081 .77504 L p F P
0 g
s
.5081 .77504 m .51003 .79158 L .50339 .80789 L p .707 .577 .707 r
F P
0 g
s
.52152 .65958 m .52451 .7126 L .50826 .72415 L p .707 .577 .707 r
F P
0 g
s
.51163 .7699 m .50693 .73806 L .52265 .72113 L p .707 .577 .707 r
F P
0 g
s
.52265 .72113 m .52735 .75297 L .51163 .7699 L p .707 .577 .707 r
F P
0 g
s
.52403 .75973 m .52596 .77627 L .51003 .79158 L p .707 .577 .707 r
F P
0 g
s
.52596 .77627 m .52403 .75973 L .54769 .74691 L p .707 .577 .707 r
F P
0 g
s
.54769 .74691 m .54962 .76345 L .52596 .77627 L p .707 .577 .707 r
F P
0 g
s
.49167 .31434 m .48441 .82075 L .52934 .82039 L p .707 .577 .707 r
F P
0 g
s
.52451 .7126 m .52152 .65958 L .54547 .65016 L p .707 .577 .707 r
F P
0 g
s
.54547 .65016 m .54846 .70318 L .52451 .7126 L p .707 .577 .707 r
F P
0 g
s
.52735 .75297 m .52265 .72113 L .54611 .70685 L p .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .5499 .73253 L p .52735 .75297 L .707 .577 .707 r
F P
0 g
s
.5499 .73253 m .55081 .73869 L .54749 .74071 L p .707 .577 .707 r
F P
0 g
s
.54749 .74071 m .52735 .75297 L p .5499 .73253 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .49167 .31434 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52934 .82039 m .52962 .80129 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52962 .80129 m .5366 .31399 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.70309 .7405 m .70779 .77234 L .70431 .75517 L p .707 .578 .707 r
F P
0 g
s
.70431 .75517 m .69961 .72332 L .70309 .7405 L p .707 .578 .707 r
F P
0 g
s
.54547 .65016 m .57477 .64379 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.54846 .70318 m .5483 .70023 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.5483 .70023 m .54547 .65016 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.57503 .69662 m .57987 .69583 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.57944 .72655 m .57503 .69662 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .57503 .69662 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.55081 .73869 m .54802 .71975 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.54802 .71975 m .54611 .70685 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .60337 .78419 L .57148 .7705 L .707 .577 .707 r
F
.57503 .69662 m .57973 .72846 L .55081 .73869 L p F P
0 g
s
.57477 .64379 m .57776 .69681 L .56055 .70056 L p .707 .577 .707 r
F P
0 g
s
.55376 .69122 m .57477 .64379 L .56055 .70056 L .707 .577 .707 r
F
.57973 .72846 m .57944 .72655 L p .57973 .72694 L F P
0 g
s
.57987 .69583 m .60656 .69145 L p .58561 .72035 L .707 .577 .707 r
F P
0 g
s
.57973 .72846 m .57987 .69583 L .58561 .72035 L .707 .577 .707 r
F
.59578 .642 m .60655 .64109 L p .59674 .66007 L F P
0 g
s
.57776 .69681 m .59578 .642 L .59674 .66007 L .707 .577 .707 r
F
.57776 .69681 m .57477 .64379 L .59578 .642 L p F P
0 g
s
.60656 .69145 m .63763 .69183 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.61115 .72255 m .60656 .69145 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.60656 .69145 m .61126 .72329 L .57973 .72846 L p .707 .577 .707 r
F P
0 g
s
.60655 .64109 m .60955 .69412 L .58998 .69578 L p .707 .577 .707 r
F P
0 g
s
.58998 .69578 m .57776 .69681 L p .58291 .68684 L .707 .577 .707 r
F P
0 g
s
.58291 .68684 m .60655 .64109 L .58998 .69578 L .707 .577 .707 r
F
.61126 .72329 m .61115 .72255 L p .61151 .723 L F P
0 g
s
.54962 .76345 m .54769 .74691 L .57676 .73785 L p .707 .577 .707 r
F P
0 g
s
.57676 .73785 m .57869 .75439 L .54962 .76345 L p .707 .577 .707 r
F P
0 g
s
.57869 .75439 m .57676 .73785 L .60839 .73342 L p .707 .577 .707 r
F P
0 g
s
.60839 .73342 m .61032 .74996 L .57869 .75439 L p .707 .577 .707 r
F P
0 g
s
.57808 .31038 m .57181 .74745 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.57181 .74745 m .57148 .7705 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.56055 .70056 m .54846 .70318 L p .55376 .69122 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .66519 .69774 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.64228 .72334 m .63763 .69183 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .64233 .72367 L .61126 .72329 L p .707 .577 .707 r
F P
0 g
s
.6377 .64233 m .6407 .69535 L .62217 .69462 L p .707 .577 .707 r
F P
0 g
s
.62217 .69462 m .60955 .69412 L p .61491 .68426 L .707 .577 .707 r
F P
0 g
s
.61491 .68426 m .6377 .64233 L .62217 .69462 L .707 .577 .707 r
F
.64233 .72367 m .64228 .72334 L p .64244 .72356 L F P
0 g
s
.60955 .69412 m .60655 .64109 L .6377 .64233 L p .707 .577 .707 r
F P
0 g
s
.63949 .73406 m .64143 .7506 L .61032 .74996 L p .707 .577 .707 r
F P
0 g
s
.61032 .74996 m .60839 .73342 L .63949 .73406 L p .707 .577 .707 r
F P
0 g
s
.61202 .30386 m .60487 .80261 L p .62786 .80149 L .707 .577 .707 r
F P
0 g
s
.60487 .80261 m .60476 .81027 L .60651 .8096 L p .707 .577 .707 r
F P
0 g
s
.60651 .8096 m .62786 .80149 L p .60487 .80261 L .707 .577 .707 r
F P
0 g
s
.57148 .7705 m .57082 .81678 L .5858 .81391 L p .707 .577 .707 r
F P
0 g
s
.5858 .81391 m .60476 .81027 L p .57148 .7705 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .52934 .82039 L .57082 .81678 L p .707 .577 .707 r
F P
0 g
s
.57082 .81678 m .57808 .31038 L .5366 .31399 L p .707 .577 .707 r
F P
0 g
s
.4404 .81781 m .44766 .3114 L .40889 .30546 L p .707 .577 .707 r
F P
0 g
s
.44766 .3114 m .4404 .81781 L .48441 .82075 L p .707 .577 .707 r
F P
0 g
s
.69896 .66663 m .70196 .71966 L .68928 .70878 L p .707 .577 .707 r
F P
0 g
s
.68928 .70878 m .68629 .65576 L .69896 .66663 L p .707 .577 .707 r
F P
0 g
s
.70448 .7791 m .70641 .79563 L .70312 .77993 L p .707 .577 .707 r
F P
0 g
s
.70312 .77993 m .70118 .76339 L .70448 .7791 L p .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .61202 .30386 L .57808 .31038 L p .707 .577 .707 r
F P
0 g
s
.2537 .73772 m .2507 .6847 L .21955 .68346 L p .707 .577 .707 r
F P
0 g
s
.2507 .6847 m .2537 .73772 L .28548 .73503 L p .707 .577 .707 r
F P
0 g
s
.28548 .73503 m .28248 .682 L .2507 .6847 L p .707 .577 .707 r
F P
0 g
s
.69961 .72332 m .70431 .75517 L .69125 .74043 L p .707 .577 .707 r
F P
0 g
s
.69125 .74043 m .68655 .70859 L .69961 .72332 L p .707 .577 .707 r
F P
0 g
s
.40163 .81186 m .40889 .30546 L .37916 .29709 L p .707 .577 .707 r
F P
0 g
s
.40889 .30546 m .40163 .81186 L .4404 .81781 L p .707 .577 .707 r
F P
0 g
s
.28248 .682 m .28548 .73503 L .31478 .72866 L p .707 .577 .707 r
F P
0 g
s
.31478 .72866 m .31178 .67563 L .28248 .682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22254 .73649 m .21955 .68346 L .19207 .67841 L p .707 .577 .707 r
F P
0 g
s
.21955 .68346 m .22254 .73649 L .2537 .73772 L p .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .68655 .70859 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66989 .72958 m .66978 .72884 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66978 .72884 m .66519 .69774 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .66989 .72958 L .64233 .72367 L p .707 .577 .707 r
F P
0 g
s
.66518 .64738 m .66818 .70041 L .65346 .6977 L p .707 .577 .707 r
F P
0 g
s
.65346 .6977 m .6407 .69535 L p .64639 .68421 L .707 .577 .707 r
F P
0 g
s
.64639 .68421 m .66518 .64738 L .65346 .6977 L .707 .577 .707 r
F
.68629 .65576 m .68928 .70878 L .66818 .70041 L p F P
0 g
s
.66818 .70041 m .66518 .64738 L .68629 .65576 L p .707 .577 .707 r
F P
0 g
s
.31178 .67563 m .31478 .72866 L .33873 .71924 L p .707 .577 .707 r
F P
0 g
s
.33873 .71924 m .33573 .66621 L .31178 .67563 L p .707 .577 .707 r
F P
0 g
s
.70118 .76339 m .70312 .77993 L .69021 .76636 L p .707 .577 .707 r
F P
0 g
s
.69021 .76636 m .68828 .74982 L .70118 .76339 L p .707 .577 .707 r
F P
0 g
s
.62786 .80149 m .63512 .29508 L .61202 .30386 L p .707 .577 .707 r
F P
0 g
s
.19507 .73143 m .19207 .67841 L .17096 .67003 L p .707 .577 .707 r
F P
0 g
s
.19207 .67841 m .19507 .73143 L .22254 .73649 L p .707 .577 .707 r
F P
0 g
s
.68655 .70859 m .69125 .74043 L .66989 .72958 L p .707 .577 .707 r
F P
0 g
s
.2881 .81232 m .28616 .79578 L .25453 .80021 L p .707 .577 .707 r
F P
0 g
s
.25872 .80007 m .25402 .76823 L .22295 .76784 L p .707 .577 .707 r
F P
0 g
s
.31717 .80325 m .31523 .78672 L .28616 .79578 L p .707 .577 .707 r
F P
0 g
s
.25402 .76823 m .25872 .80007 L .29026 .79489 L p .707 .577 .707 r
F P
0 g
s
.29026 .79489 m .28556 .76305 L .25402 .76823 L p .707 .577 .707 r
F P
0 g
s
.33573 .66621 m .33873 .71924 L .35498 .70769 L p .707 .577 .707 r
F P
0 g
s
.35498 .70769 m .35199 .65467 L .33573 .66621 L p .707 .577 .707 r
F P
0 g
s
.6407 .69535 m .6377 .64233 L .66518 .64738 L p .707 .577 .707 r
F P
0 g
s
.34083 .79044 m .33889 .7739 L .31523 .78672 L p .707 .577 .707 r
F P
0 g
s
.28556 .76305 m .29026 .79489 L .31917 .78467 L p .707 .577 .707 r
F P
0 g
s
.31917 .78467 m .31447 .75283 L .28556 .76305 L p .707 .577 .707 r
F P
0 g
s
.3719 .8035 m .37916 .29709 L .36138 .28712 L p .707 .577 .707 r
F P
0 g
s
.37916 .29709 m .3719 .8035 L .40163 .81186 L p .707 .577 .707 r
F P
0 g
s
.25647 .81675 m .25453 .80021 L .22343 .79957 L p .707 .577 .707 r
F P
0 g
s
.22765 .79968 m .22295 .76784 L .19539 .76193 L p .707 .577 .707 r
F P
0 g
s
.22295 .76784 m .22765 .79968 L .25872 .80007 L p .707 .577 .707 r
F P
0 g
s
.68828 .74982 m .69021 .76636 L .66895 .75625 L p .707 .577 .707 r
F P
0 g
s
.66895 .75625 m .66702 .73971 L .68828 .74982 L p .707 .577 .707 r
F P
0 g
s
.35676 .77513 m .35482 .75859 L .33889 .7739 L p .707 .577 .707 r
F P
0 g
s
.31447 .75283 m .31917 .78467 L .34264 .77039 L p .707 .577 .707 r
F P
0 g
s
.34264 .77039 m .33794 .73855 L .31447 .75283 L p .707 .577 .707 r
F P
0 g
s
.25453 .80021 m .25647 .81675 L .2881 .81232 L p .707 .577 .707 r
F P
0 g
s
.28616 .79578 m .2881 .81232 L .31717 .80325 L p .707 .577 .707 r
F P
0 g
s
.17396 .72306 m .17096 .67003 L .15829 .65916 L p .707 .577 .707 r
F P
0 g
s
.17096 .67003 m .17396 .72306 L .19507 .73143 L p .707 .577 .707 r
F P
0 g
s
.22536 .81611 m .22343 .79957 L .1959 .79392 L p .707 .577 .707 r
F P
0 g
s
.22343 .79957 m .22536 .81611 L .25647 .81675 L p .707 .577 .707 r
F P
0 g
s
.31523 .78672 m .31717 .80325 L .34083 .79044 L p .707 .577 .707 r
F P
0 g
s
.20009 .79378 m .19539 .76193 L .17404 .75108 L p .707 .577 .707 r
F P
0 g
s
.19539 .76193 m .20009 .79378 L .22765 .79968 L p .707 .577 .707 r
F P
0 g
s
.35199 .65467 m .35498 .70769 L .36195 .69515 L p .707 .577 .707 r
F P
0 g
s
.36195 .69515 m .35895 .64213 L .35199 .65467 L p .707 .577 .707 r
F P
0 g
s
.63512 .29508 m .62786 .80149 L .63785 .7913 L p .707 .577 .707 r
F P
0 g
s
.63785 .7913 m .64511 .28489 L .63512 .29508 L p .707 .577 .707 r
F P
0 g
s
.35588 .75612 m .35835 .75345 L p .35525 .75119 L .707 .577 .707 r
F P
0 g
s
.35835 .75345 m .35365 .72161 L .33794 .73855 L p .707 .577 .707 r
F P
0 g
s
.35365 .72161 m .35835 .75345 L .36141 .74494 L p .707 .577 .707 r
F P
0 g
s
.36141 .74494 m .36478 .73552 L p .36138 .73126 L .707 .577 .707 r
F P
0 g
s
.36138 .73126 m .35365 .72161 L .36141 .74494 L .707 .577 .707 r
F
.35587 .75602 m .35482 .75859 L p .3562 .75863 L F P
0 g
s
.33794 .73855 m .34264 .77039 L .35588 .75612 L p .707 .577 .707 r
F P
0 g
s
.35525 .75119 m .33794 .73855 L .35588 .75612 L .707 .577 .707 r
F
.33889 .7739 m .34083 .79044 L .35676 .77513 L p F P
0 g
s
.36478 .73552 m .36009 .70368 L .35365 .72161 L p .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35895 .64213 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35895 .68284 m .35878 .67989 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35595 .62982 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35878 .67989 L p .34628 .67197 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35895 .68284 L .35862 .68256 L p .707 .577 .707 r
F P
0 g
s
.35862 .68256 m .34628 .67197 L p .35878 .67989 L .707 .577 .707 r
F P
0 g
s
.34628 .67197 m .34328 .61894 L .35595 .62982 L p .707 .577 .707 r
F P
0 g
s
.3566 .68651 m .3585 .69941 L p .34824 .70362 L .707 .577 .707 r
F P
0 g
s
.3585 .69941 m .3613 .71835 L .35663 .71308 L p .707 .577 .707 r
F P
0 g
s
.35663 .71308 m .34824 .70362 L p .3585 .69941 L .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35231 .78885 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.34824 .70362 m .34354 .67178 L .3566 .68651 L p .707 .577 .707 r
F P
0 g
s
.35817 .72657 m .36011 .74311 L .35668 .73951 L p .707 .577 .707 r
F P
0 g
s
.35668 .73951 m .3472 .72954 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.35807 .7266 m .35817 .72657 L .35668 .73951 L .707 .577 .707 r
F
.3472 .72954 m .34527 .713 L .35808 .72648 L p F P
0 g
s
.35808 .72648 m .35817 .72657 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.3472 .72954 m .35808 .72648 L .35807 .7266 L .707 .577 .707 r
F
.35431 .76163 m .35589 .66982 L .35489 .66636 L F
.35412 .79352 m .35461 .7588 L p .35431 .76163 L F P
0 g
s
.35461 .7588 m .35589 .66982 L p .35431 .76163 L .707 .577 .707 r
F P
0 g
s
.35436 .75438 m .35728 .27652 L .3524 .77946 L .707 .577 .707 r
F
.35344 .76971 m .3524 .77946 L .35231 .78885 L F
.35436 .75438 m .3524 .77946 L .35344 .76971 L F
.35728 .27652 m .35036 .75887 L p .35277 .7413 L F P
0 g
s
.35036 .75887 m .35002 .78293 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.35231 .78885 m .35412 .79352 L p .35436 .75438 L .707 .577 .707 r
F P
0 g
s
.35489 .66636 m .3605 .34794 L .35728 .27652 L .707 .577 .707 r
F
.35589 .66982 m .3605 .34794 L p .35489 .66636 L F P
0 g
s
.3605 .34794 m .36138 .28712 L .36036 .28449 L p .707 .577 .707 r
F P
0 g
s
.36036 .28449 m .35728 .27652 L p .3605 .34794 L .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .36147 .74228 L .35587 .75602 L p .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .35587 .75602 L .3562 .75863 L .707 .577 .707 r
F
.1959 .79392 m .19783 .81046 L .22536 .81611 L p F P
0 g
s
.66702 .73971 m .66895 .75625 L .64143 .7506 L p .707 .577 .707 r
F P
0 g
s
.64143 .7506 m .63949 .73406 L .66702 .73971 L p .707 .577 .707 r
F P
0 g
s
.19783 .81046 m .1959 .79392 L .17464 .78381 L p .707 .577 .707 r
F P
0 g
s
.15829 .65916 m .16128 .71218 L .17396 .72306 L p .707 .577 .707 r
F P
0 g
s
.16128 .71218 m .15829 .65916 L .15529 .64685 L p .707 .577 .707 r
F P
0 g
s
.17464 .78381 m .17658 .80035 L .19783 .81046 L p .707 .577 .707 r
F P
0 g
s
.35895 .64213 m .36195 .69515 L .35895 .68284 L p .707 .577 .707 r
F P
0 g
s
.35482 .75859 m .35676 .77513 L .3634 .75882 L p .707 .577 .707 r
F P
0 g
s
.36009 .70368 m .36478 .73552 L .3613 .71835 L p .707 .578 .707 r
F P
0 g
s
.3613 .71835 m .3566 .68651 L .36009 .70368 L p .707 .578 .707 r
F P
0 g
s
.36147 .74228 m .3634 .75882 L .36011 .74311 L p .707 .577 .707 r
F P
0 g
s
.36011 .74311 m .35817 .72657 L .36147 .74228 L p .707 .577 .707 r
F P
0 g
s
.36138 .28712 m .35412 .79352 L .3719 .8035 L p .707 .577 .707 r
F P
0 g
s
.17404 .75108 m .17874 .78292 L .20009 .79378 L p .707 .577 .707 r
F P
0 g
s
.17874 .78292 m .17404 .75108 L .16098 .73635 L p .707 .577 .707 r
F P
0 g
s
.17658 .80035 m .17464 .78381 L .16174 .77024 L p .707 .577 .707 r
F P
0 g
s
.15529 .64685 m .15828 .69987 L .16128 .71218 L p .707 .577 .707 r
F P
0 g
s
.16174 .77024 m .16367 .78678 L .17658 .80035 L p .707 .577 .707 r
F P
0 g
s
.16098 .73635 m .16568 .76819 L .17874 .78292 L p .707 .577 .707 r
F P
0 g
s
.64511 .28489 m .63785 .7913 L .63375 .7807 L p .707 .577 .707 r
F P
0 g
s
.63375 .7807 m .64101 .27429 L .64511 .28489 L p .707 .577 .707 r
F P
0 g
s
.16568 .76819 m .16098 .73635 L .15749 .71918 L p .707 .578 .707 r
F P
0 g
s
.15828 .69987 m .15529 .64685 L .16225 .63431 L p .707 .577 .707 r
F P
0 g
s
.16367 .78678 m .16174 .77024 L .15844 .75453 L p .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35728 .27652 L .36726 .26633 L p .707 .577 .707 r
F P
0 g
s
.15844 .75453 m .16038 .77107 L .16367 .78678 L p .707 .577 .707 r
F P
0 g
s
.15749 .71918 m .16219 .75102 L .16568 .76819 L p .707 .578 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16225 .63431 m .16525 .68733 L .15828 .69987 L p .707 .577 .707 r
F P
0 g
s
.16219 .75102 m .15749 .71918 L .16392 .70125 L p .707 .577 .707 r
F P
0 g
s
.16525 .68733 m .16225 .63431 L .17851 .62276 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1676 .73582 m .18102 .72291 L p .16944 .74926 L .707 .577 .707 r
F P
0 g
s
.16392 .70125 m .16862 .73309 L .16761 .73591 L p .707 .577 .707 r
F P
0 g
s
.16761 .73591 m .16219 .75102 L p .16371 .70747 L .707 .577 .707 r
F P
0 g
s
.16371 .70747 m .16392 .70125 L .16761 .73591 L .707 .577 .707 r
F
.16702 .75476 m .16509 .73823 L .1676 .73582 L p F P
0 g
s
.16702 .75476 m .1676 .73582 L .16944 .74926 L .707 .577 .707 r
F
.16038 .77107 m .15844 .75453 L .16509 .73823 L p F P
0 g
s
.32218 .66092 m .34354 .67178 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32688 .69277 m .32677 .69202 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32677 .69202 m .32218 .66092 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32218 .66092 m .32688 .69277 L .29932 .68686 L p .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .32218 .66092 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29932 .68686 m .29927 .68652 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29927 .68652 m .29462 .65502 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .29932 .68686 L .26825 .68647 L p .707 .577 .707 r
F P
0 g
s
.26355 .65463 m .29462 .65502 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26825 .68647 m .26814 .68573 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26814 .68573 m .26355 .65463 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .26355 .65463 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23672 .69165 m .23643 .68973 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23643 .68973 m .23202 .65981 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.2078 .70188 m .2031 .67003 L .23202 .65981 L p .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .23672 .69165 L .2078 .70188 L p .707 .577 .707 r
F P
0 g
s
.23176 .60697 m .23475 .66 L .21754 .66374 L p .707 .577 .707 r
F P
0 g
s
.21754 .66374 m .20545 .66637 L p .21075 .65441 L .707 .577 .707 r
F P
0 g
s
.21075 .65441 m .23176 .60697 L .21754 .66374 L .707 .577 .707 r
F
.26355 .65463 m .26825 .68647 L .23672 .69165 L p F P
0 g
s
.26354 .60428 m .26654 .6573 L .24697 .65896 L p .707 .577 .707 r
F P
0 g
s
.24697 .65896 m .23475 .66 L p .2399 .65003 L .707 .577 .707 r
F P
0 g
s
.2399 .65003 m .26354 .60428 L .24697 .65896 L .707 .577 .707 r
F
.29469 .60551 m .29769 .65854 L .27916 .6578 L p F P
0 g
s
.27916 .6578 m .26654 .6573 L p .2719 .64744 L .707 .577 .707 r
F P
0 g
s
.2719 .64744 m .29469 .60551 L .27916 .6578 L .707 .577 .707 r
F
.32217 .61057 m .32517 .66359 L .31045 .66089 L p F P
0 g
s
.31045 .66089 m .29769 .65854 L p .30338 .64739 L .707 .577 .707 r
F P
0 g
s
.30338 .64739 m .32217 .61057 L .31045 .66089 L .707 .577 .707 r
F
.34328 .61894 m .34628 .67197 L .32517 .66359 L p F P
0 g
s
.32517 .66359 m .32217 .61057 L .34328 .61894 L p .707 .577 .707 r
F P
0 g
s
.64101 .27429 m .63375 .7807 L .61596 .77073 L p .707 .577 .707 r
F P
0 g
s
.61596 .77073 m .62322 .26432 L .64101 .27429 L p .707 .577 .707 r
F P
0 g
s
.16509 .73823 m .16702 .75476 L .16038 .77107 L p .707 .577 .707 r
F P
0 g
s
.17851 .62276 m .18151 .67579 L .16525 .68733 L p .707 .577 .707 r
F P
0 g
s
.16862 .73309 m .16392 .70125 L .17964 .68431 L p .707 .577 .707 r
F P
0 g
s
.18151 .67579 m .17851 .62276 L .20246 .61334 L p .707 .577 .707 r
F P
0 g
s
.34354 .67178 m .34824 .70362 L .32688 .69277 L p .707 .577 .707 r
F P
0 g
s
.36 .77274 m .36726 .26633 L .39036 .25755 L p .707 .577 .707 r
F P
0 g
s
.36726 .26633 m .36 .77274 L .35002 .78293 L p .707 .577 .707 r
F P
0 g
s
.29769 .65854 m .29469 .60551 L .32217 .61057 L p .707 .577 .707 r
F P
0 g
s
.34527 .713 m .3472 .72954 L .32595 .71943 L p .707 .577 .707 r
F P
0 g
s
.32595 .71943 m .32401 .7029 L .34527 .713 L p .707 .577 .707 r
F P
0 g
s
.20545 .66637 m .20246 .61334 L .23176 .60697 L p .707 .577 .707 r
F P
0 g
s
.20246 .61334 m .20545 .66637 L .18151 .67579 L p .707 .577 .707 r
F P
0 g
s
.17964 .68431 m .18434 .71615 L .16862 .73309 L p .707 .577 .707 r
F P
0 g
s
.18434 .71615 m .17964 .68431 L .2031 .67003 L p .707 .577 .707 r
F P
0 g
s
.18102 .72291 m .18295 .73945 L .16702 .75476 L p .707 .577 .707 r
F P
0 g
s
.26654 .6573 m .26354 .60428 L .29469 .60551 L p .707 .577 .707 r
F P
0 g
s
.62322 .26432 m .61596 .77073 L .58623 .76236 L p .707 .577 .707 r
F P
0 g
s
.58623 .76236 m .59349 .25595 L .62322 .26432 L p .707 .577 .707 r
F P
0 g
s
.23475 .66 m .23176 .60697 L .26354 .60428 L p .707 .577 .707 r
F P
0 g
s
.18295 .73945 m .18102 .72291 L .20468 .7101 L p .707 .577 .707 r
F P
0 g
s
.73391 .65728 m .73091 .60425 L .69976 .60301 L p .707 .577 .707 r
F P
0 g
s
.73091 .60425 m .73391 .65728 L .76569 .65458 L p .707 .577 .707 r
F P
0 g
s
.76569 .65458 m .7627 .60156 L .73091 .60425 L p .707 .577 .707 r
F P
0 g
s
.2031 .67003 m .2078 .70188 L .18434 .71615 L p .707 .577 .707 r
F P
0 g
s
.7627 .60156 m .76569 .65458 L .79499 .64821 L p .707 .577 .707 r
F P
0 g
s
.79499 .64821 m .792 .59519 L .7627 .60156 L p .707 .577 .707 r
F P
0 g
s
.32401 .7029 m .32595 .71943 L .29842 .71378 L p .707 .577 .707 r
F P
0 g
s
.29842 .71378 m .29648 .69725 L .32401 .7029 L p .707 .577 .707 r
F P
0 g
s
.70276 .65604 m .69976 .60301 L .67228 .59796 L p .707 .577 .707 r
F P
0 g
s
.69976 .60301 m .70276 .65604 L .73391 .65728 L p .707 .577 .707 r
F P
0 g
s
.39036 .25755 m .3831 .76395 L .36 .77274 L p .707 .577 .707 r
F P
0 g
s
.3831 .76395 m .39036 .25755 L .42431 .25103 L p .707 .577 .707 r
F P
0 g
s
.20468 .7101 m .20661 .72664 L .18295 .73945 L p .707 .577 .707 r
F P
0 g
s
.792 .59519 m .79499 .64821 L .81894 .63879 L p .707 .577 .707 r
F P
0 g
s
.81894 .63879 m .81595 .58577 L .792 .59519 L p .707 .577 .707 r
F P
0 g
s
.20661 .72664 m .20468 .7101 L .23375 .70103 L p .707 .577 .707 r
F P
0 g
s
.29648 .69725 m .29842 .71378 L .26732 .71314 L p .707 .577 .707 r
F P
0 g
s
.26732 .71314 m .26538 .6966 L .29648 .69725 L p .707 .577 .707 r
F P
0 g
s
.67528 .65098 m .67228 .59796 L .65117 .58959 L p .707 .577 .707 r
F P
0 g
s
.67228 .59796 m .67528 .65098 L .70276 .65604 L p .707 .577 .707 r
F P
0 g
s
.23375 .70103 m .23568 .71757 L .20661 .72664 L p .707 .577 .707 r
F P
0 g
s
.23568 .71757 m .23375 .70103 L .26538 .6966 L p .707 .577 .707 r
F P
0 g
s
.59349 .25595 m .58623 .76236 L .54747 .75641 L p .707 .577 .707 r
F P
0 g
s
.54747 .75641 m .55473 .25001 L .59349 .25595 L p .707 .577 .707 r
F P
0 g
s
.26538 .6966 m .26732 .71314 L .23568 .71757 L p .707 .577 .707 r
F P
0 g
s
.81595 .58577 m .81894 .63879 L .8352 .62725 L p .707 .577 .707 r
F P
0 g
s
.8352 .62725 m .8322 .57422 L .81595 .58577 L p .707 .577 .707 r
F P
0 g
s
.41705 .75744 m .42431 .25103 L .46578 .24742 L p .707 .577 .707 r
F P
0 g
s
.42431 .25103 m .41705 .75744 L .3831 .76395 L p .707 .577 .707 r
F P
0 g
s
.73893 .74279 m .73424 .71095 L .70317 .71057 L p .707 .577 .707 r
F P
0 g
s
.73424 .71095 m .73893 .74279 L .77047 .73762 L p .707 .577 .707 r
F P
0 g
s
.77047 .73762 m .76577 .70578 L .73424 .71095 L p .707 .577 .707 r
F P
0 g
s
.76577 .70578 m .77047 .73762 L .79939 .72739 L p .707 .577 .707 r
F P
0 g
s
.79939 .72739 m .79469 .69555 L .76577 .70578 L p .707 .577 .707 r
F P
0 g
s
.65417 .64261 m .65117 .58959 L .6385 .57871 L p .707 .577 .707 r
F P
0 g
s
.65117 .58959 m .65417 .64261 L .67528 .65098 L p .707 .577 .707 r
F P
0 g
s
.70787 .74241 m .70317 .71057 L .67561 .70466 L p .707 .577 .707 r
F P
0 g
s
.70317 .71057 m .70787 .74241 L .73893 .74279 L p .707 .577 .707 r
F P
0 g
s
.79469 .69555 m .79939 .72739 L .82285 .71311 L p .707 .577 .707 r
F P
0 g
s
.82285 .71311 m .81815 .68127 L .79469 .69555 L p .707 .577 .707 r
F P
0 g
s
.55473 .25001 m .54747 .75641 L .50346 .75347 L p .707 .577 .707 r
F P
0 g
s
.50346 .75347 m .51072 .24707 L .55473 .25001 L p .707 .577 .707 r
F P
0 g
s
.45852 .75383 m .46578 .24742 L .51072 .24707 L p .707 .577 .707 r
F P
0 g
s
.46578 .24742 m .45852 .75383 L .41705 .75744 L p .707 .577 .707 r
F P
0 g
s
.8322 .57422 m .8352 .62725 L .84216 .61471 L p .707 .577 .707 r
F P
0 g
s
.84216 .61471 m .83917 .56168 L .8322 .57422 L p .707 .577 .707 r
F P
0 g
s
.51072 .24707 m .50346 .75347 L .45852 .75383 L p .707 .577 .707 r
F P
0 g
s
.73668 .80331 m .73474 .78677 L .70364 .78613 L p .707 .577 .707 r
F P
0 g
s
.73474 .78677 m .73668 .80331 L .76831 .79888 L p .707 .577 .707 r
F P
0 g
s
.76831 .79888 m .76638 .78234 L .73474 .78677 L p .707 .577 .707 r
F P
0 g
s
.6803 .7365 m .67561 .70466 L .65425 .69381 L p .707 .577 .707 r
F P
0 g
s
.67561 .70466 m .6803 .7365 L .70787 .74241 L p .707 .577 .707 r
F P
0 g
s
.76638 .78234 m .76831 .79888 L .79738 .78981 L p .707 .577 .707 r
F P
0 g
s
.79738 .78981 m .79545 .77327 L .76638 .78234 L p .707 .577 .707 r
F P
0 g
s
.81815 .68127 m .82285 .71311 L .83857 .69618 L p .707 .577 .707 r
F P
0 g
s
.83857 .69618 m .83387 .66434 L .81815 .68127 L p .707 .577 .707 r
F P
0 g
s
.6385 .57871 m .6415 .63174 L .65417 .64261 L p .707 .577 .707 r
F P
0 g
s
.70558 .80266 m .70364 .78613 L .67611 .78048 L p .707 .577 .707 r
F P
0 g
s
.70364 .78613 m .70558 .80266 L .73668 .80331 L p .707 .577 .707 r
F P
0 g
s
.79545 .77327 m .79738 .78981 L .82104 .777 L p .707 .577 .707 r
F P
0 g
s
.82104 .777 m .8191 .76046 L .79545 .77327 L p .707 .577 .707 r
F P
0 g
s
.6415 .63174 m .6385 .57871 L .6355 .5664 L p .707 .577 .707 r
F P
0 g
s
.67611 .78048 m .67805 .79701 L .70558 .80266 L p .707 .577 .707 r
F P
0 g
s
.65425 .69381 m .65895 .72565 L .6803 .7365 L p .707 .577 .707 r
F P
0 g
s
.65895 .72565 m .65425 .69381 L .64119 .67908 L p .707 .577 .707 r
F P
0 g
s
.67805 .79701 m .67611 .78048 L .65486 .77037 L p .707 .577 .707 r
F P
0 g
s
.83917 .56168 m .84216 .61471 L .83916 .6024 L p .707 .577 .707 r
F P
0 g
s
.83916 .6024 m .83617 .54937 L .83917 .56168 L p .707 .577 .707 r
F P
0 g
s
.83387 .66434 m .83857 .69618 L .845 .67825 L p .707 .577 .707 r
F P
0 g
s
.845 .67825 m .8403 .64641 L .83387 .66434 L p .707 .577 .707 r
F P
0 g
s
.8191 .76046 m .82104 .777 L .83697 .76168 L p .707 .577 .707 r
F P
0 g
s
.83697 .76168 m .83504 .74515 L .8191 .76046 L p .707 .577 .707 r
F P
0 g
s
.65486 .77037 m .65679 .78691 L .67805 .79701 L p .707 .577 .707 r
F P
0 g
s
.6355 .5664 m .6385 .61943 L .6415 .63174 L p .707 .577 .707 r
F P
0 g
s
.6385 .61943 m .6355 .5664 L .64247 .55386 L p .707 .577 .707 r
F P
0 g
s
.64119 .67908 m .64589 .71092 L .65895 .72565 L p .707 .577 .707 r
F P
0 g
s
.65679 .78691 m .65486 .77037 L .64195 .7568 L p .707 .577 .707 r
F P
0 g
s
.64589 .71092 m .64119 .67908 L .63771 .6619 L p .707 .578 .707 r
F P
0 g
s
.83504 .74515 m .83697 .76168 L .84361 .74538 L p .707 .577 .707 r
F P
0 g
s
.84361 .74538 m .84168 .72884 L .83504 .74515 L p .707 .577 .707 r
F P
0 g
s
.8403 .64641 m .845 .67825 L .84151 .66107 L p .707 .578 .707 r
F P
0 g
s
.84151 .66107 m .83681 .62923 L .8403 .64641 L p .707 .578 .707 r
F P
0 g
s
.64195 .7568 m .64388 .77334 L .65679 .78691 L p .707 .577 .707 r
F P
0 g
s
.83617 .54937 m .83916 .6024 L .82649 .59152 L p .707 .577 .707 r
F P
0 g
s
.82649 .59152 m .82349 .5385 L .83617 .54937 L p .707 .577 .707 r
F P
0 g
s
.64247 .55386 m .64546 .60688 L .6385 .61943 L p .707 .577 .707 r
F P
0 g
s
.63771 .6619 m .6424 .69374 L .64589 .71092 L p .707 .578 .707 r
F P
0 g
s
.64546 .60688 m .64247 .55386 L .65872 .54231 L p .707 .577 .707 r
F P
0 g
s
.64388 .77334 m .64195 .7568 L .63866 .74109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3909 .62046 m .3879 .56744 L .35675 .5662 L p .707 .577 .707 r
F P
0 g
s
.3879 .56744 m .3909 .62046 L .42268 .61777 L p .707 .577 .707 r
F P
0 g
s
.42268 .61777 m .41969 .56474 L .3879 .56744 L p .707 .577 .707 r
F P
0 g
s
.6424 .69374 m .63771 .6619 L .64414 .64397 L p .707 .577 .707 r
F P
0 g
s
.41969 .56474 m .42268 .61777 L .45198 .6114 L p .707 .577 .707 r
F P
0 g
s
.45198 .6114 m .44899 .55837 L .41969 .56474 L p .707 .577 .707 r
F P
0 g
s
.84168 .72884 m .84361 .74538 L .84032 .72967 L p .707 .577 .707 r
F P
0 g
s
.84032 .72967 m .83839 .71313 L .84168 .72884 L p .707 .577 .707 r
F P
0 g
s
.83681 .62923 m .84151 .66107 L .82845 .64634 L p .707 .577 .707 r
F P
0 g
s
.82845 .64634 m .82375 .6145 L .83681 .62923 L p .707 .577 .707 r
F P
0 g
s
.35975 .61922 m .35675 .5662 L .32927 .56114 L p .707 .577 .707 r
F P
0 g
s
.35675 .5662 m .35975 .61922 L .3909 .62046 L p .707 .577 .707 r
F P
0 g
s
.63866 .74109 m .64059 .75763 L .64388 .77334 L p .707 .577 .707 r
F P
0 g
s
.82349 .5385 m .82649 .59152 L .80538 .58315 L p .707 .577 .707 r
F P
0 g
s
.80538 .58315 m .80238 .53012 L .82349 .5385 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44899 .55837 m .45198 .6114 L .47593 .60198 L p .707 .577 .707 r
F P
0 g
s
.47593 .60198 m .47294 .54895 L .44899 .55837 L p .707 .577 .707 r
F P
0 g
s
.65872 .54231 m .66172 .59534 L .64546 .60688 L p .707 .577 .707 r
F P
0 g
s
.33227 .61417 m .32927 .56114 L .30816 .55277 L p .707 .577 .707 r
F P
0 g
s
.32927 .56114 m .33227 .61417 L .35975 .61922 L p .707 .577 .707 r
F P
0 g
s
.64414 .64397 m .64883 .67581 L .6424 .69374 L p .707 .577 .707 r
F P
0 g
s
.66172 .59534 m .65872 .54231 L .68267 .5329 L p .707 .577 .707 r
F P
0 g
s
.64059 .75763 m .63866 .74109 L .6453 .72478 L p .707 .577 .707 r
F P
0 g
s
.64883 .67581 m .64414 .64397 L .65985 .62704 L p .707 .577 .707 r
F P
0 g
s
.82375 .6145 m .82845 .64634 L .8071 .63549 L p .707 .577 .707 r
F P
0 g
s
.8071 .63549 m .8024 .60365 L .82375 .6145 L p .707 .577 .707 r
F P
0 g
s
.47294 .54895 m .47593 .60198 L .49219 .59043 L p .707 .577 .707 r
F P
0 g
s
.49219 .59043 m .48919 .53741 L .47294 .54895 L p .707 .577 .707 r
F P
0 g
s
.80238 .53012 m .80538 .58315 L .7779 .57809 L p .707 .577 .707 r
F P
0 g
s
.7779 .57809 m .77491 .52507 L .80238 .53012 L p .707 .577 .707 r
F P
0 g
s
.83839 .71313 m .84032 .72967 L .82742 .7161 L p .707 .577 .707 r
F P
0 g
s
.82742 .7161 m .82548 .69956 L .83839 .71313 L p .707 .577 .707 r
F P
0 g
s
.6453 .72478 m .64724 .74132 L .64059 .75763 L p .707 .577 .707 r
F P
0 g
s
.39592 .70598 m .39123 .67414 L .36016 .67375 L p .707 .577 .707 r
F P
0 g
s
.39123 .67414 m .39592 .70598 L .42746 .7008 L p .707 .577 .707 r
F P
0 g
s
.42746 .7008 m .42276 .66896 L .39123 .67414 L p .707 .577 .707 r
F P
0 g
s
.42276 .66896 m .42746 .7008 L .45638 .69058 L p .707 .577 .707 r
F P
0 g
s
.45638 .69058 m .45168 .65873 L .42276 .66896 L p .707 .577 .707 r
F P
0 g
s
.68567 .58592 m .68267 .5329 L .71197 .52653 L p .707 .577 .707 r
F P
0 g
s
.68267 .5329 m .68567 .58592 L .66172 .59534 L p .707 .577 .707 r
F P
0 g
s
.31116 .6058 m .30816 .55277 L .29549 .5419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55277 m .31116 .6058 L .33227 .61417 L p .707 .577 .707 r
F P
0 g
s
.36486 .70559 m .36016 .67375 L .3326 .66784 L p .707 .577 .707 r
F P
0 g
s
.36016 .67375 m .36486 .70559 L .39592 .70598 L p .707 .577 .707 r
F P
0 g
s
.45168 .65873 m .45638 .69058 L .47984 .6763 L p .707 .577 .707 r
F P
0 g
s
.47984 .6763 m .47514 .64446 L .45168 .65873 L p .707 .577 .707 r
F P
0 g
s
.77491 .52507 m .7779 .57809 L .74675 .57685 L p .707 .577 .707 r
F P
0 g
s
.74675 .57685 m .74375 .52383 L .77491 .52507 L p .707 .577 .707 r
F P
0 g
s
.65985 .62704 m .66455 .65888 L .64883 .67581 L p .707 .577 .707 r
F P
0 g
s
.66455 .65888 m .65985 .62704 L .68332 .61276 L p .707 .577 .707 r
F P
0 g
s
.64724 .74132 m .6453 .72478 L .66123 .70947 L p .707 .577 .707 r
F P
0 g
s
.71497 .57955 m .71197 .52653 L .74375 .52383 L p .707 .577 .707 r
F P
0 g
s
.71197 .52653 m .71497 .57955 L .68567 .58592 L p .707 .577 .707 r
F P
0 g
s
.8024 .60365 m .8071 .63549 L .77954 .62958 L p .707 .577 .707 r
F P
0 g
s
.77954 .62958 m .77484 .59774 L .8024 .60365 L p .707 .577 .707 r
F P
0 g
s
.74375 .52383 m .74675 .57685 L .71497 .57955 L p .707 .577 .707 r
F P
0 g
s
.48919 .53741 m .49219 .59043 L .49915 .57789 L p .707 .577 .707 r
F P
0 g
s
.49915 .57789 m .49616 .52487 L .48919 .53741 L p .707 .577 .707 r
F P
0 g
s
.82548 .69956 m .82742 .7161 L .80616 .70599 L p .707 .577 .707 r
F P
0 g
s
.80616 .70599 m .80423 .68945 L .82548 .69956 L p .707 .577 .707 r
F P
0 g
s
.39367 .76649 m .39173 .74995 L .36063 .74931 L p .707 .577 .707 r
F P
0 g
s
.39173 .74995 m .39367 .76649 L .4253 .76206 L p .707 .577 .707 r
F P
0 g
s
.4253 .76206 m .42337 .74553 L .39173 .74995 L p .707 .577 .707 r
F P
0 g
s
.33729 .69969 m .3326 .66784 L .31124 .65699 L p .707 .577 .707 r
F P
0 g
s
.3326 .66784 m .33729 .69969 L .36486 .70559 L p .707 .577 .707 r
F P
0 g
s
.42337 .74553 m .4253 .76206 L .45437 .753 L p .707 .577 .707 r
F P
0 g
s
.45437 .753 m .45244 .73646 L .42337 .74553 L p .707 .577 .707 r
F P
0 g
s
.66123 .70947 m .66317 .72601 L .64724 .74132 L p .707 .577 .707 r
F P
0 g
s
.47514 .64446 m .47984 .6763 L .49556 .65936 L p .707 .577 .707 r
F P
0 g
s
.49556 .65936 m .49086 .62752 L .47514 .64446 L p .707 .577 .707 r
F P
0 g
s
.68802 .6446 m .68332 .61276 L .71223 .60253 L p .707 .577 .707 r
F P
0 g
s
.68332 .61276 m .68802 .6446 L .66455 .65888 L p .707 .577 .707 r
F P
0 g
s
.29549 .5419 m .29849 .59492 L .31116 .6058 L p .707 .577 .707 r
F P
0 g
s
.36257 .76585 m .36063 .74931 L .3331 .74366 L p .707 .577 .707 r
F P
0 g
s
.36063 .74931 m .36257 .76585 L .39367 .76649 L p .707 .577 .707 r
F P
0 g
s
.77484 .59774 m .77954 .62958 L .74847 .6292 L p .707 .577 .707 r
F P
0 g
s
.74847 .6292 m .74377 .59736 L .77484 .59774 L p .707 .577 .707 r
F P
0 g
s
.45244 .73646 m .45437 .753 L .47803 .74018 L p .707 .577 .707 r
F P
0 g
s
.47803 .74018 m .47609 .72364 L .45244 .73646 L p .707 .577 .707 r
F P
0 g
s
.29849 .59492 m .29549 .5419 L .29249 .52958 L p .707 .577 .707 r
F P
0 g
s
.71693 .63437 m .71223 .60253 L .74377 .59736 L p .707 .577 .707 r
F P
0 g
s
.71223 .60253 m .71693 .63437 L .68802 .6446 L p .707 .577 .707 r
F P
0 g
s
.74377 .59736 m .74847 .6292 L .71693 .63437 L p .707 .577 .707 r
F P
0 g
s
.66317 .72601 m .66123 .70947 L .68489 .69666 L p .707 .577 .707 r
F P
0 g
s
.3331 .74366 m .33504 .7602 L .36257 .76585 L p .707 .577 .707 r
F P
0 g
s
.80423 .68945 m .80616 .70599 L .77863 .70034 L p .707 .577 .707 r
F P
0 g
s
.77863 .70034 m .7767 .6838 L .80423 .68945 L p .707 .577 .707 r
F P
0 g
s
.31124 .65699 m .31594 .68883 L .33729 .69969 L p .707 .577 .707 r
F P
0 g
s
.31594 .68883 m .31124 .65699 L .29818 .64226 L p .707 .577 .707 r
F P
0 g
s
.33504 .7602 m .3331 .74366 L .31185 .73356 L p .707 .577 .707 r
F P
0 g
s
.49616 .52487 m .49915 .57789 L .49615 .56558 L p .707 .577 .707 r
F P
0 g
s
.49615 .56558 m .49316 .51255 L .49616 .52487 L p .707 .577 .707 r
F P
0 g
s
.68489 .69666 m .68683 .71319 L .66317 .72601 L p .707 .577 .707 r
F P
0 g
s
.49086 .62752 m .49556 .65936 L .50199 .64143 L p .707 .577 .707 r
F P
0 g
s
.50199 .64143 m .49729 .60959 L .49086 .62752 L p .707 .577 .707 r
F P
0 g
s
.47609 .72364 m .47803 .74018 L .49396 .72487 L p .707 .577 .707 r
F P
0 g
s
.49396 .72487 m .49203 .70833 L .47609 .72364 L p .707 .577 .707 r
F P
0 g
s
.31185 .73356 m .31378 .75009 L .33504 .7602 L p .707 .577 .707 r
F P
0 g
s
.68683 .71319 m .68489 .69666 L .71396 .68759 L p .707 .577 .707 r
F P
0 g
s
.29249 .52958 m .29549 .58261 L .29849 .59492 L p .707 .577 .707 r
F P
0 g
s
.7767 .6838 m .77863 .70034 L .74753 .6997 L p .707 .577 .707 r
F P
0 g
s
.74753 .6997 m .74559 .68316 L .7767 .6838 L p .707 .577 .707 r
F P
0 g
s
.29549 .58261 m .29249 .52958 L .29946 .51704 L p .707 .577 .707 r
F P
0 g
s
.71396 .68759 m .7159 .70413 L .68683 .71319 L p .707 .577 .707 r
F P
0 g
s
.7159 .70413 m .71396 .68759 L .74559 .68316 L p .707 .577 .707 r
F P
0 g
s
.29818 .64226 m .30288 .6741 L .31594 .68883 L p .707 .577 .707 r
F P
0 g
s
.74559 .68316 m .74753 .6997 L .7159 .70413 L p .707 .577 .707 r
F P
0 g
s
.31378 .75009 m .31185 .73356 L .29894 .71998 L p .707 .577 .707 r
F P
0 g
s
.30288 .6741 m .29818 .64226 L .29469 .62509 L p .707 .578 .707 r
F P
0 g
s
.49203 .70833 m .49396 .72487 L .5006 .70856 L p .707 .577 .707 r
F P
0 g
s
.5006 .70856 m .49867 .69202 L .49203 .70833 L p .707 .577 .707 r
F P
0 g
s
.49729 .60959 m .50199 .64143 L .4985 .62426 L p .707 .578 .707 r
F P
0 g
s
.4985 .62426 m .4938 .59242 L .49729 .60959 L p .707 .578 .707 r
F P
0 g
s
.29894 .71998 m .30087 .73652 L .31378 .75009 L p .707 .577 .707 r
F P
0 g
s
.49316 .51255 m .49615 .56558 L .48348 .55471 L p .707 .577 .707 r
F P
0 g
s
.48348 .55471 m .48048 .50168 L .49316 .51255 L p .707 .577 .707 r
F P
0 g
s
.29946 .51704 m .30245 .57007 L .29549 .58261 L p .707 .577 .707 r
F P
0 g
s
.29469 .62509 m .29939 .65693 L .30288 .6741 L p .707 .578 .707 r
F P
0 g
s
.30245 .57007 m .29946 .51704 L .31571 .5055 L p .707 .577 .707 r
F P
0 g
s
.30087 .73652 m .29894 .71998 L .29565 .70428 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29939 .65693 m .29469 .62509 L .30113 .60716 L p .707 .577 .707 r
F P
0 g
s
.49867 .69202 m .5006 .70856 L .49731 .69285 L p .707 .577 .707 r
F P
0 g
s
.49731 .69285 m .49538 .67632 L .49867 .69202 L p .707 .577 .707 r
F P
0 g
s
.4938 .59242 m .4985 .62426 L .48544 .60953 L p .707 .577 .707 r
F P
0 g
s
.48544 .60953 m .48074 .57768 L .4938 .59242 L p .707 .577 .707 r
F P
0 g
s
.29565 .70428 m .29758 .72081 L .30087 .73652 L p .707 .577 .707 r
F P
0 g
s
.48048 .50168 m .48348 .55471 L .46237 .54633 L p .707 .577 .707 r
F P
0 g
s
.46237 .54633 m .45937 .49331 L .48048 .50168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31571 .5055 m .31871 .55852 L .30245 .57007 L p .707 .577 .707 r
F P
0 g
s
.30113 .60716 m .30582 .639 L .29939 .65693 L p .707 .577 .707 r
F P
0 g
s
.31871 .55852 m .31571 .5055 L .33966 .49608 L p .707 .577 .707 r
F P
0 g
s
.29758 .72081 m .29565 .70428 L .30229 .68797 L p .707 .577 .707 r
F P
0 g
s
.30582 .639 m .30113 .60716 L .31684 .59022 L p .707 .577 .707 r
F P
0 g
s
.48074 .57768 m .48544 .60953 L .46409 .59867 L p .707 .577 .707 r
F P
0 g
s
.46409 .59867 m .45939 .56683 L .48074 .57768 L p .707 .577 .707 r
F P
0 g
s
.45937 .49331 m .46237 .54633 L .43489 .54128 L p .707 .577 .707 r
F P
0 g
s
.43489 .54128 m .4319 .48825 L .45937 .49331 L p .707 .577 .707 r
F P
0 g
s
.49538 .67632 m .49731 .69285 L .48441 .67928 L p .707 .577 .707 r
F P
0 g
s
.48441 .67928 m .48247 .66274 L .49538 .67632 L p .707 .577 .707 r
F P
0 g
s
.30229 .68797 m .30423 .70451 L .29758 .72081 L p .707 .577 .707 r
F P
0 g
s
.34266 .54911 m .33966 .49608 L .36896 .48971 L p .707 .577 .707 r
F P
0 g
s
.33966 .49608 m .34266 .54911 L .31871 .55852 L p .707 .577 .707 r
F P
0 g
s
.4319 .48825 m .43489 .54128 L .40374 .54004 L p .707 .577 .707 r
F P
0 g
s
.40374 .54004 m .40074 .48701 L .4319 .48825 L p .707 .577 .707 r
F P
0 g
s
.31684 .59022 m .32154 .62206 L .30582 .639 L p .707 .577 .707 r
F P
0 g
s
.32154 .62206 m .31684 .59022 L .34031 .57594 L p .707 .577 .707 r
F P
0 g
s
.30423 .70451 m .30229 .68797 L .31822 .67266 L p .707 .577 .707 r
F P
0 g
s
.37196 .54274 m .36896 .48971 L .40074 .48701 L p .707 .577 .707 r
F P
0 g
s
.36896 .48971 m .37196 .54274 L .34266 .54911 L p .707 .577 .707 r
F P
0 g
s
.45939 .56683 m .46409 .59867 L .43653 .59277 L p .707 .577 .707 r
F P
0 g
s
.43653 .59277 m .43183 .56093 L .45939 .56683 L p .707 .577 .707 r
F P
0 g
s
.40074 .48701 m .40374 .54004 L .37196 .54274 L p .707 .577 .707 r
F P
0 g
s
.48247 .66274 m .48441 .67928 L .46315 .66918 L p .707 .577 .707 r
F P
0 g
s
.46315 .66918 m .46121 .65264 L .48247 .66274 L p .707 .577 .707 r
F P
0 g
s
.31822 .67266 m .32016 .68919 L .30423 .70451 L p .707 .577 .707 r
F P
0 g
s
.34501 .60778 m .34031 .57594 L .36922 .56572 L p .707 .577 .707 r
F P
0 g
s
.34031 .57594 m .34501 .60778 L .32154 .62206 L p .707 .577 .707 r
F P
0 g
s
.43183 .56093 m .43653 .59277 L .40546 .59238 L p .707 .577 .707 r
F P
0 g
s
.40546 .59238 m .40076 .56054 L .43183 .56093 L p .707 .577 .707 r
F P
0 g
s
.37392 .59756 m .36922 .56572 L .40076 .56054 L p .707 .577 .707 r
F P
0 g
s
.36922 .56572 m .37392 .59756 L .34501 .60778 L p .707 .577 .707 r
F P
0 g
s
.40076 .56054 m .40546 .59238 L .37392 .59756 L p .707 .577 .707 r
F P
0 g
s
.32016 .68919 m .31822 .67266 L .34188 .65984 L p .707 .577 .707 r
F P
0 g
s
.46121 .65264 m .46315 .66918 L .43562 .66353 L p .707 .577 .707 r
F P
0 g
s
.43562 .66353 m .43369 .64699 L .46121 .65264 L p .707 .577 .707 r
F P
0 g
s
.34188 .65984 m .34382 .67638 L .32016 .68919 L p .707 .577 .707 r
F P
0 g
s
.34382 .67638 m .34188 .65984 L .37095 .65077 L p .707 .577 .707 r
F P
0 g
s
.43369 .64699 m .43562 .66353 L .40452 .66288 L p .707 .577 .707 r
F P
0 g
s
.40452 .66288 m .40258 .64635 L .43369 .64699 L p .707 .577 .707 r
F P
0 g
s
.37095 .65077 m .37288 .66731 L .34382 .67638 L p .707 .577 .707 r
F P
0 g
s
.37288 .66731 m .37095 .65077 L .40258 .64635 L p .707 .577 .707 r
F P
0 g
s
.40258 .64635 m .40452 .66288 L .37288 .66731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolH0026Ool007Ioo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEP`007Yoo`00
LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF1`00
Lgoo001]Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUH00002001`Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00J7oo0P0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P00Jgoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008006Moo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEPl000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Moo`03001JEP0000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol01@00FUIJEUYF00001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`T004Eoo`00E7oo0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF009JEPP003eoo`00Dgoo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD0
03Qoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo10001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`00=Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20008Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000UJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00MJEP@000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo001COol00`00FUH00004FUH00`00FUH000030004Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH01eYF100000=JEP00FUH00P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool005Aoo`8000AJ
EP8000Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30005FUH01@00FUIJEUYF
00000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo0P000eYF00<005YFFUH00`001Goo00@005YF
FUH000EJEQ400003FUH005YF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P0000=JEP00000015YF00<005YF00000`0000Aoo`00FUIJEPH000AJEP03001JEUYF00IJ
EP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol40005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
E7oo0P0000=JEP00FUH015YF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool005Aoo`800003FUH005YF00AJEP03001JEUYF008000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol01000FUIJEP001EYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP04FUHH0003FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01@00FUIJEUYF000015YF00@005YFFUH000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH00000
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04000HOol40005FUH01@00FUIJEUYF0000;Woo001D
Ool01@00FUIJEUYF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP<0021o
o`8000=JEP05001JEUYFFUH0000^Ool005Aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P008goo100000=JEP00FUH00UYF0P00;Goo001DOol01000FUIJEUYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUH000008goo0P000UYF00@005YF000000=JEP8002eoo`00E7oo00L005YFFUIJEP00
FUH00006FUH00`00FUIJEP05FUH70008FUH00`00FUIJEP03FUH400000eYF001JEP04FUH01000FUIJ
EP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF0P004goo3@0000=oo`0000000P0015YF00D005YFFUIJEP00009JEP8002eoo`00EGoo00<0
05YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000EJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20002FUH5000:Ool40002FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP02FUH4000]Ool004Ioo`T000Moo`05001JEUYFFUH00007FUH0
0`00FUH000020008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF00@005YFFUIJEPX000IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP<002eoo`00@7oo1P0015YF00<005YFFUH00UYF1`001EYF00<005YFFUH015YF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@0000AJEP00FUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EP00FUH00005FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH40005FUH3000]Ool003aoo`@00003FUH005YF00IJEP03Ool005YF00MJEP03001JEP0000EJEP03
001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH0
05YF00=JEP8000=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool003Qoo`@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00@000AJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUH0000]Ool003Ioo`800003FUH005YF00IJEP03001JEUYF00AJEP03OomJEP0000QJEP<000EJEPT0
009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00EJEP03001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF
00=JEP@000MJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH0000002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00001EYF00<005YFFUH00UYF0P000Woo40000eYF00<005YFFUH02EYF00<005YFFUH01UYF
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP000000;Woo000bOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH017ooFUIJEP0025YF00@005YFFUH000=JEP8000EJEP800005Ool005YFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH00000;goo000aOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF00<005YF00001EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009JEP03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPL0
00AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000_Ool002moo`800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF009JEP05001JEUYFFUIoo`03FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH2000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF0`001eYF00<005YFFUH01EYF00<005YFFUH010001eYF200015YF00<005YF
FUH00eYF00<005YF0000;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00002FUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000015YF001JEP001eYF00<005YFFUH015YF1000
0UYF00<005YFFUH01UYF00<005YFFUH01EYF1@001EYF00<005YF0000;goo000]Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEWoo1EYF00@005YFFUIoo`EJEP04001JEP00Ool4FUH0
0`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000^Ool002eoo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
009JEP04001JEP000002FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH01000FUIJEP000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000Eoo`00FUIJEP0000MJEP03001JEP00008000QJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH200001Goo000005YF00000UYF00<007ooOol0;7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIoo`06FUH00`00FUIoo`06FUH00`00FUH00005FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000EJEP04001JEUYFFUH=0005FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000Eoo`80009JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF0`0000=JEP00
FUH015YF10000UYF00<005YFFUH01UYF00<005YF00000`0000AJEP00FUIJEP<000AJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009J
EP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Uoo`03001JEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<007ooFUH01UYF00<005YF
FUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH010001UYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010003Goo00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40007FUH20002FUH01@00FUIJEUYF00001EYF1P00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH30003FUHJ
000AOol3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPT00004FUH0
05YFFUH90002FUH300000eYF001JEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P001EYF0P00:7oo00<005YF0000;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP020002FUH30008FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01P00FUIJEP00FUH000EJEP03001JEP0002Moo`03001JEP0002eoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF1@000eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF001JEP00
00AJEP80009JEP03001JEUYF00EJEPH000MJEP04001JEUYFFUH70002FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00
FUH00002FUH00`00FUIJEP03FUH01000FUIJEP002Woo0`0067oo0P0000=JEP00Ool0;7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP00009JEP8000AJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJEPH000IJEP@000EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EP00009JEP03001JEUYF00=JEP04001JEUYF0009Ool5000FOol00`00FUH00002FUH00`00Oomoo`0Z
Ool002aoo`03001JEP0000AJEP03001JEP0000@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00009JEP8000IJEP03001JEP00010000AJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20003FUH00`00FUIJEP03FUH01000FUIJEP002Goo1@005Goo00@005YFFUH0009JEP03001o
ogoo02Yoo`00;Goo0P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUH005YF008000IJEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP800005FUH005YFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
0008Ool5000DOol01@00FUIJEUYF00000UYF00<007ooOol0:Woo000]Ool20002FUH200000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUH00000FUH000AJEP80
00EJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00
FUIJEP03FUH00`00FUIJEP020009Ool3000DOol00`00FUIJEP03FUH00`00FUH0000/Ool002eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEP00008000IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF008000AJEP03
001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00EJEP03001JEUYF00=JEP03001JEUYF008000Moo`l000Qoo`<000EJEP8002eoo`00;Goo0P0000=J
EP00FUH00P001UYF00<005YFFUH01UYF00<005YFFUH00UYF3P001EYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF0`001eYF00D005YF001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000EJEP03001JEUYF00=JEP03001JEUYF00800003
Ool0000000@000AJEP03001JEUYF00IJEP03001JEP0000<0009oo`80009JEP03001JEUYF00=JEP80
02eoo`00;Goo0P0000EJEP00001JEP0000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF009JEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0
00UJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001oogoo02aoo`00;Goo00@005YFFUH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF
FUH005YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH025YF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P001EYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUH000020007FUH>000015YF001JEP0015YF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P0015YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH00`000eYF0`001eYF00<005YFFUH015YF1`0015YF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20005FUH00`00FUIJ
EP04FUH2000015YF001JEUYF1P0015YF00<005YFFUH01UYF00<005YF00001P000UYF1P000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH01eYF10002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
10001goo200015YF00<005YFFUH00UYF0`00<7oo000]Ool20005FUH00`00FUIJEP02FUH20002FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH00005FUH300000eYF0000000200000eYF0000
000>00000eYF001JEP0:FUH00`00FUIJEP06FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF001JEUYF00000UYF0P000eYF00<005YFFUH01EYF1000
2Goo10001UYF1@0015YF00<005YF0000<7oo000]Ool20005FUH00`00FUIJEP02000015YF00000000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF00<005YFFUH00P000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP<000IJEP03001JEUYF00@000Uoo`@0009J
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUH0000_Ool002eoo`8000EJEPL000QJEP03
001JEUYF00AJEP`000IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00EJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@0009JEP8000MJEQ0000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH0
05YFFUH0000^Ool002aoo`03001JEP0000EJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH01@00FUIJEP00FUH010000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF00L005YF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF000005YF00001EYF0P0015YF00<005YF
FUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<007ooOol0
;7oo000/Ool01000FUIJEP000eYF0`0015YF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00@0
05YFFUH000AJEP@000EJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30002FUH01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01eYF00@005YFFUH000Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0009JEP8000IJEP03001J
EUYF00@000MJEP<000IJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJ
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF0`000UYF00<005YF
FUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`001Woo00@005YF000002eoo`00;7oo
00D005YFFUH005YF00<000IJEP<0009JEP03001JEUYF00EJEPD000EJEP06001JEUYF001JEP000UYF
00@005YF0000009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00<000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP05FUH20009Ool3000]Ool002eoo`03001JEP0000800003FUH005YF00=JEP80
00EJEP03001JEUYF00EJEPD000EJEP06001JEUYFFUH005YF10001Woo0`000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF0`000UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP<000IJEP03001JEUYF009JEP<000aoo`8002eoo`00;Goo00@005YF000000=JEP05
001JEUYF001oo`040002FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP020002FUH00`00Oomoo`07
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20004FUH01000FUH00000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00
00000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003goo
0P00;Goo000]Ool30004FUH30006OolG000017oo001JEUYF0`001Woo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000P001EYF0`001UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Woo0P00;Goo000]Ool20005FUH00`00Oomoo`0OOol00`00FUH0
0002FUH20003Ool01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`000UYF00<005YFFUH0
1UYF00<005YFFUH0100057oo00<005YF0000;Goo000]Ool20004FUH00`00Oomoo`0QOol00`00FUH0
0003FUH40002FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001JEUYF
009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF00AJEP<00003FUH005YF009JEP03001JEP0000d001Qoo`03001JEP0002eoo`00;Goo
00@005YF001JEP8002Eoo`8000AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJ
EPH000MJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP020002FUH300000eYF001oo`0ROol200000eYF
001oo`0/Ool002eoo`03001JEP00008002Moo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000IJEP04001JEUYFFUH20002Ool3000ROol01000FUH00000;Woo000]Ool01000FUH005YF
0`0097oo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
5P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000P000UYF
00<005YFFUH00UYF0P0000Aoo`00FUH0025oo`03001JEUYF008002ioo`00;Goo00D005YF001JEP00
009JEP8001ioo`@00004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000:FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
0003FUH00`00FUH000030003FUH01P00FUH00000FUH0021oo`05001JEUYFFUH0000_Ool002eoo`<0
0003FUH005YF00=JEP<001Ioo`D000EJEP03001JEUYF009JEPD000AJEP03001JEUYF00EJEP03001J
EUYF009JEPL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001J
EUYF009JEP@0009JEP04001JEP000002Ool300001UYF001JEP00FUH001moo`03001JEUYF009JEP03
001oogoo02eoo`00;Goo0`0000=JEP00FUH015YF00<005YF00000`003Woo10000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF000040002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`0000=JEP0000000P001goo0P000UYF
00<005YF000077oo0`000eYF00<007ooOol0;Woo000]Ool00`00Ool00002FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH>0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30002FUH00`00FUH000020007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH300000eYF001JEP03FUH400000eYF001oo`08Ool01`00FUH005YF001JEP0001Yoo`80009JEP04
001JEUYF000aOol002eoo`06001oogoo001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF0P0000Aoo`00FUIJEP8000Ioo`08001JEUYF001JEP00FUH001Moo`<000EJEP80039oo`00;Goo
0P0000Aoo`00FUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
0000009oo`04001JEP00FUH30002Ool00`00FUIJEP02FUH4000DOol300000eYF001JEP05FUH00`00
Oomoo`0aOol002eoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00IJEP03001JEUYF00800004FUH005YFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40002Ool00`00FUH00004FUH30005FUH2000BOol30004FUH00`00FUIJEP02FUH2000dOol002io
o`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP<0
00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003Ool20005
FUH00`00FUH0000300000eYF0000000<Ool60007FUH00`00FUIJEP02000fOol002ioo`03001JEUYF
00@000=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP8000EJEP800003
Ool0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3000hOol002moo`03001JEP00009JEP<00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP05001oogooOol0
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000goo10000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00>Woo000`Ool00`00FUH00003FUH4
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020002FUH00`00FUIJEP02FUH20004
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00Ool00P0000AJEP00
FUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8003ao
o`00<Goo0P0015YF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@0
05YFFUH000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD000=JEP03001JEUYF009JEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008003ioo`00<Woo00<005YFFUH00UYF
00<005YFFUH00eYF4@000eYF00<005YFFUH01UYF0`002Woo0`0025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Goo000cOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000>Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30008FUH00`00FUIJEP04FUH300000eYF0000000>0017Ool003Eoo`800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@001Aoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0001FOol003Moo`<000IJEP03
001JEUYF00EJEP03001JEUYF00AJEPD001aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00AJEPD000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03
001oogoo05Aoo`00>Woo10000UYF00<005YFFUH01EYF00<005YFFUH010009Woo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02@001EYF00<005YFFUH01UYF00<0
05YFFUH00`000eYF00<007ooOol0EGoo000nOol=000`Ool80006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH80004FUH50005FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00F7oo0023OolJ0004FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH30004FUH00`00FUH0001HOol0091oo`03001JEUYF
00@000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000MJEP03001JEUYF009JEP<000IJEP8005Uo
o`00TGoo00<005YF00000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P000UYF00<005YFFUH00eYF0P00FWoo002AOol00`00FUH00004FUH60004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P00G7oo002BOol20005FUH01000FUIJEUYF
4`000UYF00<005YFFUH01UYF00@005YF000005ioo`00Tgoo0P0015YF00<005YFFUH01EYF00@005YF
FUIJEPL000IJEP03001JEUYF00EJEP<0061oo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002HOol30006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH00002001UOol009]oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH006Qo
o`00Wgoo4000KWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5964 .76511 m .59455 .71098 L .56338 .70949 L p .707 .577 .707 r
F P
0 g
s
.59455 .71098 m .5964 .76511 L .62822 .76313 L p .707 .577 .707 r
F P
0 g
s
.62822 .76313 m .62636 .70901 L .59455 .71098 L p .707 .577 .707 r
F P
0 g
s
.62636 .70901 m .62822 .76313 L .65757 .75789 L p .707 .577 .707 r
F P
0 g
s
.65757 .75789 m .65571 .70376 L .62636 .70901 L p .707 .577 .707 r
F P
0 g
s
.56524 .76362 m .56338 .70949 L .53592 .70469 L p .707 .577 .707 r
F P
0 g
s
.56338 .70949 m .56524 .76362 L .5964 .76511 L p .707 .577 .707 r
F P
0 g
s
.65571 .70376 m .65757 .75789 L .68158 .74989 L p .707 .577 .707 r
F P
0 g
s
.68158 .74989 m .67973 .69576 L .65571 .70376 L p .707 .577 .707 r
F P
0 g
s
.53777 .75882 m .53592 .70469 L .51484 .69704 L p .707 .577 .707 r
F P
0 g
s
.53592 .70469 m .53777 .75882 L .56524 .76362 L p .707 .577 .707 r
F P
0 g
s
.59914 .82733 m .5962 .79304 L .56507 .7921 L p .707 .577 .707 r
F P
0 g
s
.5962 .79304 m .59914 .82733 L .63086 .82375 L p .707 .577 .707 r
F P
0 g
s
.63086 .82375 m .62792 .78946 L .5962 .79304 L p .707 .577 .707 r
F P
0 g
s
.62792 .78946 m .63086 .82375 L .66006 .81602 L p .707 .577 .707 r
F P
0 g
s
.66006 .81602 m .65712 .78172 L .62792 .78946 L p .707 .577 .707 r
F P
0 g
s
.67973 .69576 m .68158 .74989 L .69791 .73992 L p .707 .577 .707 r
F P
0 g
s
.69791 .73992 m .69605 .68579 L .67973 .69576 L p .707 .577 .707 r
F P
0 g
s
.56801 .82639 m .56507 .7921 L .53757 .78674 L p .707 .577 .707 r
F P
0 g
s
.56507 .7921 m .56801 .82639 L .59914 .82733 L p .707 .577 .707 r
F P
0 g
s
.65712 .78172 m .66006 .81602 L .68389 .80488 L p .707 .577 .707 r
F P
0 g
s
.68389 .80488 m .68095 .77058 L .65712 .78172 L p .707 .577 .707 r
F P
0 g
s
.59788 .85326 m .59668 .83581 L .56553 .8347 L p .707 .577 .707 r
F P
0 g
s
.59668 .83581 m .59788 .85326 L .62964 .85018 L p .707 .577 .707 r
F P
0 g
s
.62964 .85018 m .62844 .83272 L .59668 .83581 L p .707 .577 .707 r
F P
0 g
s
.62844 .83272 m .62964 .85018 L .6589 .84321 L p .707 .577 .707 r
F P
0 g
s
.6589 .84321 m .6577 .82575 L .62844 .83272 L p .707 .577 .707 r
F P
0 g
s
.51484 .69704 m .5167 .75116 L .53777 .75882 L p .707 .577 .707 r
F P
0 g
s
.5167 .75116 m .51484 .69704 L .50222 .68729 L p .707 .577 .707 r
F P
0 g
s
.56674 .85216 m .56553 .8347 L .53805 .82952 L p .707 .577 .707 r
F P
0 g
s
.56553 .8347 m .56674 .85216 L .59788 .85326 L p .707 .577 .707 r
F P
0 g
s
.54051 .82104 m .53757 .78674 L .5164 .77749 L p .707 .577 .707 r
F P
0 g
s
.53757 .78674 m .54051 .82104 L .56801 .82639 L p .707 .577 .707 r
F P
0 g
s
.6577 .82575 m .6589 .84321 L .68281 .83303 L p .707 .577 .707 r
F P
0 g
s
.68281 .83303 m .6816 .81558 L .6577 .82575 L p .707 .577 .707 r
F P
0 g
s
.53805 .82952 m .53925 .84697 L .56674 .85216 L p .707 .577 .707 r
F P
0 g
s
.68095 .77058 m .68389 .80488 L .70001 .79142 L p .707 .577 .707 r
F P
0 g
s
.70001 .79142 m .69707 .75713 L .68095 .77058 L p .707 .577 .707 r
F P
0 g
s
.69605 .68579 m .69791 .73992 L .70495 .72895 L p .707 .577 .707 r
F P
0 g
s
.70495 .72895 m .70309 .67482 L .69605 .68579 L p .707 .577 .707 r
F P
0 g
s
.53925 .84697 m .53805 .82952 L .51692 .82076 L p .707 .577 .707 r
F P
0 g
s
.50222 .68729 m .50407 .74142 L .5167 .75116 L p .707 .577 .707 r
F P
0 g
s
.5164 .77749 m .51934 .81178 L .54051 .82104 L p .707 .577 .707 r
F P
0 g
s
.51692 .82076 m .51812 .83821 L .53925 .84697 L p .707 .577 .707 r
F P
0 g
s
.6816 .81558 m .68281 .83303 L .69901 .82064 L p .707 .577 .707 r
F P
0 g
s
.69901 .82064 m .6978 .80319 L .6816 .81558 L p .707 .577 .707 r
F P
0 g
s
.51934 .81178 m .5164 .77749 L .50363 .76525 L p .707 .577 .707 r
F P
0 g
s
.50407 .74142 m .50222 .68729 L .49928 .6764 L p .707 .577 .707 r
F P
0 g
s
.69707 .75713 m .70001 .79142 L .70684 .77697 L p .707 .577 .707 r
F P
0 g
s
.70684 .77697 m .7039 .74268 L .69707 .75713 L p .707 .577 .707 r
F P
0 g
s
.51812 .83821 m .51692 .82076 L .5042 .80928 L p .707 .577 .707 r
F P
0 g
s
.70309 .67482 m .70495 .72895 L .70201 .71806 L p .707 .577 .707 r
F P
0 g
s
.70201 .71806 m .70015 .66393 L .70309 .67482 L p .707 .577 .707 r
F P
0 g
s
.50363 .76525 m .50656 .79954 L .51934 .81178 L p .707 .577 .707 r
F P
0 g
s
.49928 .6764 m .50114 .73052 L .50407 .74142 L p .707 .577 .707 r
F P
0 g
s
.5042 .80928 m .50541 .82673 L .51812 .83821 L p .707 .577 .707 r
F P
0 g
s
.6978 .80319 m .69901 .82064 L .70592 .80726 L p .707 .577 .707 r
F P
0 g
s
.70592 .80726 m .70472 .78981 L .6978 .80319 L p .707 .577 .707 r
F P
0 g
s
.50656 .79954 m .50363 .76525 L .5005 .75122 L p .707 .577 .707 r
F P
0 g
s
.4867 .82121 m .49119 .31645 L .44718 .31361 L p .707 .577 .707 r
F P
0 g
s
.50114 .73052 m .49928 .6764 L .50632 .66543 L p .707 .577 .707 r
F P
0 g
s
.50541 .82673 m .5042 .80928 L .50116 .79621 L p .707 .577 .707 r
F P
0 g
s
.5005 .75122 m .50344 .78551 L .50656 .79954 L p .707 .577 .707 r
F P
0 g
s
.50116 .79621 m .50236 .81366 L .50541 .82673 L p .707 .577 .707 r
F P
0 g
s
.50632 .66543 m .50818 .71955 L .50114 .73052 L p .707 .577 .707 r
F P
0 g
s
.50344 .78551 m .5005 .75122 L .50734 .73676 L p .707 .577 .707 r
F P
0 g
s
.50818 .71955 m .50632 .66543 L .52265 .65545 L p .707 .577 .707 r
F P
0 g
s
.50236 .81366 m .50116 .79621 L .50807 .78283 L p .707 .577 .707 r
F P
0 g
s
.50734 .73676 m .51027 .77106 L .50344 .78551 L p .707 .577 .707 r
F P
0 g
s
.50807 .78283 m .50928 .80028 L .50236 .81366 L p .707 .577 .707 r
F P
0 g
s
.52265 .65545 m .5245 .70958 L .50818 .71955 L p .707 .577 .707 r
F P
0 g
s
.51027 .77106 m .50734 .73676 L .52346 .72331 L p .707 .577 .707 r
F P
0 g
s
.50928 .80028 m .50807 .78283 L .52427 .77044 L p .707 .577 .707 r
F P
0 g
s
.52346 .72331 m .52639 .7576 L .51027 .77106 L p .707 .577 .707 r
F P
0 g
s
.52427 .77044 m .52548 .78789 L .50928 .80028 L p .707 .577 .707 r
F P
0 g
s
.52639 .7576 m .52346 .72331 L .54728 .71217 L p .707 .577 .707 r
F P
0 g
s
.52548 .78789 m .52427 .77044 L .54817 .76026 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .55022 .74646 L .52639 .7576 L p .707 .577 .707 r
F P
0 g
s
.54817 .76026 m .54938 .77772 L .52548 .78789 L p .707 .577 .707 r
F P
0 g
s
.49119 .31645 m .4867 .82121 L .53164 .82057 L p .707 .577 .707 r
F P
0 g
s
.5245 .70958 m .52265 .65545 L .54666 .64745 L p .707 .577 .707 r
F P
0 g
s
.54666 .64745 m .54851 .70158 L .5245 .70958 L p .707 .577 .707 r
F P
0 g
s
.53164 .82057 m .53613 .31581 L .49119 .31645 L p .707 .577 .707 r
F P
0 g
s
.54851 .70158 m .54666 .64745 L .57601 .64221 L p .707 .577 .707 r
F P
0 g
s
.57601 .64221 m .57787 .69634 L .54851 .70158 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .57648 .70443 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.55022 .74646 m .54959 .73911 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.54959 .73911 m .54728 .71217 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.57787 .69634 m .57601 .64221 L .60782 .64023 L p .707 .577 .707 r
F P
0 g
s
.60782 .64023 m .60968 .69436 L .57787 .69634 L p .707 .577 .707 r
F P
0 g
s
.57942 .73872 m .57648 .70443 L .6082 .70086 L p .707 .577 .707 r
F P
0 g
s
.57648 .70443 m .57942 .73872 L .55022 .74646 L p .707 .577 .707 r
F P
0 g
s
.6082 .70086 m .61114 .73515 L .57942 .73872 L p .707 .577 .707 r
F P
0 g
s
.54938 .77772 m .54817 .76026 L .57743 .75329 L p .707 .577 .707 r
F P
0 g
s
.57743 .75329 m .57864 .77075 L .54938 .77772 L p .707 .577 .707 r
F P
0 g
s
.57864 .77075 m .57743 .75329 L .60919 .75021 L p .707 .577 .707 r
F P
0 g
s
.60919 .75021 m .6104 .76766 L .57864 .77075 L p .707 .577 .707 r
F P
0 g
s
.57761 .31175 m .57335 .79065 L p .60707 .80944 L .707 .577 .707 r
F P
0 g
s
.57335 .79065 m .57312 .81652 L .58421 .81421 L p .707 .577 .707 r
F P
0 g
s
.58421 .81421 m .60707 .80944 L p .57335 .79065 L .707 .577 .707 r
F P
0 g
s
.53613 .31581 m .53164 .82057 L .57312 .81652 L p .707 .577 .707 r
F P
0 g
s
.57312 .81652 m .57761 .31175 L .53613 .31581 L p .707 .577 .707 r
F P
0 g
s
.7039 .74268 m .70684 .77697 L .70372 .76294 L p .707 .577 .707 r
F P
0 g
s
.70372 .76294 m .70078 .72864 L .7039 .74268 L p .707 .577 .707 r
F P
0 g
s
.44269 .81837 m .44718 .31361 L .40842 .30756 L p .707 .577 .707 r
F P
0 g
s
.44718 .31361 m .44269 .81837 L .4867 .82121 L p .707 .577 .707 r
F P
0 g
s
.70015 .66393 m .70201 .71806 L .68939 .70831 L p .707 .577 .707 r
F P
0 g
s
.68939 .70831 m .68753 .65418 L .70015 .66393 L p .707 .577 .707 r
F P
0 g
s
.60968 .69436 m .60782 .64023 L .63899 .64172 L p .707 .577 .707 r
F P
0 g
s
.60707 .80944 m .61156 .30468 L .57761 .31175 L p .707 .577 .707 r
F P
0 g
s
.70472 .78981 m .70592 .80726 L .70287 .79419 L p .707 .577 .707 r
F P
0 g
s
.70287 .79419 m .70167 .77674 L .70472 .78981 L p .707 .577 .707 r
F P
0 g
s
.2534 .72829 m .25154 .67417 L .22037 .67268 L p .707 .577 .707 r
F P
0 g
s
.25154 .67417 m .2534 .72829 L .28521 .72632 L p .707 .577 .707 r
F P
0 g
s
.28521 .72632 m .28335 .67219 L .25154 .67417 L p .707 .577 .707 r
F P
0 g
s
.40393 .81233 m .40842 .30756 L .37869 .29891 L p .707 .577 .707 r
F P
0 g
s
.40842 .30756 m .40393 .81233 L .44269 .81837 L p .707 .577 .707 r
F P
0 g
s
.28335 .67219 m .28521 .72632 L .31456 .72108 L p .707 .577 .707 r
F P
0 g
s
.31456 .72108 m .3127 .66695 L .28335 .67219 L p .707 .577 .707 r
F P
0 g
s
.70078 .72864 m .70372 .76294 L .69094 .75069 L p .707 .577 .707 r
F P
0 g
s
.69094 .75069 m .68801 .7164 L .70078 .72864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22223 .72681 m .22037 .67268 L .19291 .66787 L p .707 .577 .707 r
F P
0 g
s
.22037 .67268 m .22223 .72681 L .2534 .72829 L p .707 .577 .707 r
F P
0 g
s
.68753 .65418 m .68939 .70831 L .66831 .70065 L p .707 .577 .707 r
F P
0 g
s
.66831 .70065 m .66645 .64653 L .68753 .65418 L p .707 .577 .707 r
F P
0 g
s
.3127 .66695 m .31456 .72108 L .33857 .71308 L p .707 .577 .707 r
F P
0 g
s
.33857 .71308 m .33672 .65895 L .3127 .66695 L p .707 .577 .707 r
F P
0 g
s
.63899 .64172 m .64085 .69585 L .60968 .69436 L p .707 .577 .707 r
F P
0 g
s
.63934 .70179 m .64228 .73609 L .61114 .73515 L p .707 .577 .707 r
F P
0 g
s
.61114 .73515 m .6082 .70086 L .63934 .70179 L p .707 .577 .707 r
F P
0 g
s
.64034 .75131 m .64154 .76877 L .6104 .76766 L p .707 .577 .707 r
F P
0 g
s
.6104 .76766 m .60919 .75021 L .64034 .75131 L p .707 .577 .707 r
F P
0 g
s
.61156 .30468 m .60707 .80944 L .63018 .80004 L p .707 .577 .707 r
F P
0 g
s
.63018 .80004 m .63467 .29528 L .61156 .30468 L p .707 .577 .707 r
F P
0 g
s
.70167 .77674 m .70287 .79419 L .69016 .78272 L p .707 .577 .707 r
F P
0 g
s
.69016 .78272 m .68896 .76526 L .70167 .77674 L p .707 .577 .707 r
F P
0 g
s
.19476 .722 m .19291 .66787 L .17183 .66022 L p .707 .577 .707 r
F P
0 g
s
.19291 .66787 m .19476 .722 L .22223 .72681 L p .707 .577 .707 r
F P
0 g
s
.25613 .79051 m .25319 .75622 L .22206 .75528 L p .707 .577 .707 r
F P
0 g
s
.25319 .75622 m .25613 .79051 L .28785 .78694 L p .707 .577 .707 r
F P
0 g
s
.28785 .78694 m .28491 .75265 L .25319 .75622 L p .707 .577 .707 r
F P
0 g
s
.28491 .75265 m .28785 .78694 L .31705 .7792 L p .707 .577 .707 r
F P
0 g
s
.31705 .7792 m .31411 .74491 L .28491 .75265 L p .707 .577 .707 r
F P
0 g
s
.68801 .7164 m .69094 .75069 L .66977 .74144 L p .707 .577 .707 r
F P
0 g
s
.66977 .74144 m .66684 .70715 L .68801 .7164 L p .707 .577 .707 r
F P
0 g
s
.33672 .65895 m .33857 .71308 L .3549 .7031 L p .707 .577 .707 r
F P
0 g
s
.3549 .7031 m .35304 .64897 L .33672 .65895 L p .707 .577 .707 r
F P
0 g
s
.225 .78958 m .22206 .75528 L .19456 .74993 L p .707 .577 .707 r
F P
0 g
s
.22206 .75528 m .225 .78958 L .25613 .79051 L p .707 .577 .707 r
F P
0 g
s
.3742 .80367 m .37869 .29891 L .36091 .2885 L p .707 .577 .707 r
F P
0 g
s
.37869 .29891 m .3742 .80367 L .40393 .81233 L p .707 .577 .707 r
F P
0 g
s
.66645 .64653 m .66831 .70065 L .64085 .69585 L p .707 .577 .707 r
F P
0 g
s
.64085 .69585 m .63899 .64172 L .66645 .64653 L p .707 .577 .707 r
F P
0 g
s
.31411 .74491 m .31705 .7792 L .34088 .76806 L p .707 .577 .707 r
F P
0 g
s
.34088 .76806 m .33794 .73377 L .31411 .74491 L p .707 .577 .707 r
F P
0 g
s
.25488 .81645 m .25367 .79899 L .22252 .79789 L p .707 .577 .707 r
F P
0 g
s
.25367 .79899 m .25488 .81645 L .28663 .81336 L p .707 .577 .707 r
F P
0 g
s
.28663 .81336 m .28543 .79591 L .25367 .79899 L p .707 .577 .707 r
F P
0 g
s
.28543 .79591 m .28663 .81336 L .3159 .80639 L p .707 .577 .707 r
F P
0 g
s
.3159 .80639 m .31469 .78894 L .28543 .79591 L p .707 .577 .707 r
F P
0 g
s
.17183 .66022 m .17369 .71435 L .19476 .722 L p .707 .577 .707 r
F P
0 g
s
.17369 .71435 m .17183 .66022 L .15921 .65047 L p .707 .577 .707 r
F P
0 g
s
.22373 .81534 m .22252 .79789 L .19504 .7927 L p .707 .577 .707 r
F P
0 g
s
.22252 .79789 m .22373 .81534 L .25488 .81645 L p .707 .577 .707 r
F P
0 g
s
.68896 .76526 m .69016 .78272 L .66903 .77396 L p .707 .577 .707 r
F P
0 g
s
.66903 .77396 m .66782 .7565 L .68896 .76526 L p .707 .577 .707 r
F P
0 g
s
.1975 .78422 m .19456 .74993 L .17339 .74068 L p .707 .577 .707 r
F P
0 g
s
.19456 .74993 m .1975 .78422 L .225 .78958 L p .707 .577 .707 r
F P
0 g
s
.31469 .78894 m .3159 .80639 L .3398 .79621 L p .707 .577 .707 r
F P
0 g
s
.3398 .79621 m .33859 .77876 L .31469 .78894 L p .707 .577 .707 r
F P
0 g
s
.66684 .70715 m .66977 .74144 L .64228 .73609 L p .707 .577 .707 r
F P
0 g
s
.64228 .73609 m .63934 .70179 L .66684 .70715 L p .707 .577 .707 r
F P
0 g
s
.19504 .7927 m .19624 .81015 L .22373 .81534 L p .707 .577 .707 r
F P
0 g
s
.33794 .73377 m .34088 .76806 L .357 .75461 L p .707 .577 .707 r
F P
0 g
s
.357 .75461 m .35406 .72031 L .33794 .73377 L p .707 .577 .707 r
F P
0 g
s
.63467 .29528 m .63018 .80004 L .64017 .78923 L p .707 .577 .707 r
F P
0 g
s
.64154 .76877 m .64034 .75131 L .66782 .7565 L p .707 .577 .707 r
F P
0 g
s
.64017 .78923 m .64466 .28447 L .63467 .29528 L p .707 .577 .707 r
F P
0 g
s
.35304 .64897 m .3549 .7031 L .36194 .69213 L p .707 .577 .707 r
F P
0 g
s
.36194 .69213 m .36008 .638 L .35304 .64897 L p .707 .577 .707 r
F P
0 g
s
.19624 .81015 m .19504 .7927 L .17391 .78394 L p .707 .577 .707 r
F P
0 g
s
.15921 .65047 m .16106 .7046 L .17369 .71435 L p .707 .577 .707 r
F P
0 g
s
.17339 .74068 m .17633 .77497 L .1975 .78422 L p .707 .577 .707 r
F P
0 g
s
.66782 .7565 m .66903 .77396 L .64154 .76877 L p .707 .577 .707 r
F P
0 g
s
.17391 .78394 m .17511 .80139 L .19624 .81015 L p .707 .577 .707 r
F P
0 g
s
.33859 .77876 m .3398 .79621 L .356 .78383 L p .707 .577 .707 r
F P
0 g
s
.356 .78383 m .35479 .76638 L .33859 .77876 L p .707 .577 .707 r
F P
0 g
s
.17633 .77497 m .17339 .74068 L .16062 .72843 L p .707 .577 .707 r
F P
0 g
s
.16106 .7046 m .15921 .65047 L .15627 .63958 L p .707 .577 .707 r
F P
0 g
s
.35406 .72031 m .357 .75461 L .36383 .74015 L p .707 .577 .707 r
F P
0 g
s
.36383 .74015 m .36089 .70586 L .35406 .72031 L p .707 .577 .707 r
F P
0 g
s
.359 .68124 m .35715 .62711 L .36008 .638 L p .707 .577 .707 r
F P
0 g
s
.35479 .76638 m .356 .78383 L .36291 .77045 L p .707 .577 .707 r
F P
0 g
s
.36291 .77045 m .36171 .75299 L .35479 .76638 L p .707 .577 .707 r
F P
0 g
s
.35715 .62711 m .359 .68124 L .34638 .67149 L p .707 .577 .707 r
F P
0 g
s
.34638 .67149 m .34452 .61736 L .35715 .62711 L p .707 .577 .707 r
F P
0 g
s
.35777 .69183 m .36008 .71877 L p .34793 .71388 L .707 .577 .707 r
F P
0 g
s
.36008 .71877 m .36071 .72612 L .35963 .72509 L p .707 .577 .707 r
F P
0 g
s
.35963 .72509 m .34793 .71388 L p .36008 .71877 L .707 .577 .707 r
F P
0 g
s
.34793 .71388 m .345 .67959 L .35777 .69183 L p .707 .577 .707 r
F P
0 g
s
.35866 .73992 m .35986 .75738 L .34715 .7459 L p .707 .577 .707 r
F P
0 g
s
.34715 .7459 m .34595 .72845 L .35866 .73992 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35681 .27734 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35642 .79326 m .35665 .76739 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35665 .76739 m .36091 .2885 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.36008 .638 m .36194 .69213 L .359 .68124 L p .707 .577 .707 r
F P
0 g
s
.36089 .70586 m .36383 .74015 L .36071 .72612 L p .707 .577 .707 r
F P
0 g
s
.36071 .72612 m .35777 .69183 L .36089 .70586 L p .707 .577 .707 r
F P
0 g
s
.36171 .75299 m .36291 .77045 L .35986 .75738 L p .707 .577 .707 r
F P
0 g
s
.35986 .75738 m .35866 .73992 L .36171 .75299 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35642 .79326 L .3742 .80367 L p .707 .577 .707 r
F P
0 g
s
.17511 .80139 m .17391 .78394 L .16119 .77246 L p .707 .577 .707 r
F P
0 g
s
.16062 .72843 m .16356 .76273 L .17633 .77497 L p .707 .577 .707 r
F P
0 g
s
.15627 .63958 m .15813 .69371 L .16106 .7046 L p .707 .577 .707 r
F P
0 g
s
.16119 .77246 m .1624 .78992 L .17511 .80139 L p .707 .577 .707 r
F P
0 g
s
.16356 .76273 m .16062 .72843 L .15749 .7144 L p .707 .577 .707 r
F P
0 g
s
.64466 .28447 m .64017 .78923 L .63608 .77807 L p .707 .577 .707 r
F P
0 g
s
.63608 .77807 m .64057 .27331 L .64466 .28447 L p .707 .577 .707 r
F P
0 g
s
.15813 .69371 m .15627 .63958 L .16331 .62861 L p .707 .577 .707 r
F P
0 g
s
.1624 .78992 m .16119 .77246 L .15815 .75939 L p .707 .577 .707 r
F P
0 g
s
.15749 .7144 m .16043 .74869 L .16356 .76273 L p .707 .577 .707 r
F P
0 g
s
.35681 .27734 m .35233 .7821 L .35642 .79326 L p .707 .577 .707 r
F P
0 g
s
.35233 .7821 m .35681 .27734 L .36681 .26653 L p .707 .577 .707 r
F P
0 g
s
.15815 .75939 m .15935 .77685 L .1624 .78992 L p .707 .577 .707 r
F P
0 g
s
.16331 .62861 m .16517 .68274 L .15813 .69371 L p .707 .577 .707 r
F P
0 g
s
.16043 .74869 m .15749 .7144 L .16433 .69995 L p .707 .577 .707 r
F P
0 g
s
.16517 .68274 m .16331 .62861 L .17964 .61864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15935 .77685 m .15815 .75939 L .16506 .74601 L p .707 .577 .707 r
F P
0 g
s
.64057 .27331 m .63608 .77807 L .6183 .76766 L p .707 .577 .707 r
F P
0 g
s
.6183 .76766 m .62279 .26289 L .64057 .27331 L p .707 .577 .707 r
F P
0 g
s
.16433 .69995 m .16726 .73424 L .16043 .74869 L p .707 .577 .707 r
F P
0 g
s
.34452 .61736 m .34638 .67149 L .3253 .66384 L p .707 .577 .707 r
F P
0 g
s
.3253 .66384 m .32345 .60971 L .34452 .61736 L p .707 .577 .707 r
F P
0 g
s
.16506 .74601 m .16627 .76347 L .15935 .77685 L p .707 .577 .707 r
F P
0 g
s
.17964 .61864 m .18149 .67277 L .16517 .68274 L p .707 .577 .707 r
F P
0 g
s
.16726 .73424 m .16433 .69995 L .18045 .6865 L p .707 .577 .707 r
F P
0 g
s
.18149 .67277 m .17964 .61864 L .20365 .61064 L p .707 .577 .707 r
F P
0 g
s
.36232 .77129 m .36681 .26653 L .38991 .25712 L p .707 .577 .707 r
F P
0 g
s
.36681 .26653 m .36232 .77129 L .35233 .7821 L p .707 .577 .707 r
F P
0 g
s
.345 .67959 m .34793 .71388 L .32676 .70463 L p .707 .577 .707 r
F P
0 g
s
.32676 .70463 m .32383 .67034 L .345 .67959 L p .707 .577 .707 r
F P
0 g
s
.32345 .60971 m .3253 .66384 L .29784 .65903 L p .707 .577 .707 r
F P
0 g
s
.29784 .65903 m .29598 .60491 L .32345 .60971 L p .707 .577 .707 r
F P
0 g
s
.16627 .76347 m .16506 .74601 L .18126 .73363 L p .707 .577 .707 r
F P
0 g
s
.18045 .6865 m .18338 .72079 L .16726 .73424 L p .707 .577 .707 r
F P
0 g
s
.20551 .66477 m .20365 .61064 L .233 .60539 L p .707 .577 .707 r
F P
0 g
s
.20365 .61064 m .20551 .66477 L .18149 .67277 L p .707 .577 .707 r
F P
0 g
s
.18126 .73363 m .18247 .75108 L .16627 .76347 L p .707 .577 .707 r
F P
0 g
s
.18338 .72079 m .18045 .6865 L .20427 .67535 L p .707 .577 .707 r
F P
0 g
s
.34595 .72845 m .34715 .7459 L .32602 .73714 L p .707 .577 .707 r
F P
0 g
s
.32602 .73714 m .32481 .71969 L .34595 .72845 L p .707 .577 .707 r
F P
0 g
s
.62279 .26289 m .6183 .76766 L .58857 .759 L p .707 .577 .707 r
F P
0 g
s
.58857 .759 m .59306 .25424 L .62279 .26289 L p .707 .577 .707 r
F P
0 g
s
.29598 .60491 m .29784 .65903 L .26667 .65755 L p .707 .577 .707 r
F P
0 g
s
.26667 .65755 m .26482 .60342 L .29598 .60491 L p .707 .577 .707 r
F P
0 g
s
.32383 .67034 m .32676 .70463 L .29927 .69927 L p .707 .577 .707 r
F P
0 g
s
.29927 .69927 m .29633 .66498 L .32383 .67034 L p .707 .577 .707 r
F P
0 g
s
.23486 .65952 m .233 .60539 L .26482 .60342 L p .707 .577 .707 r
F P
0 g
s
.233 .60539 m .23486 .65952 L .20551 .66477 L p .707 .577 .707 r
F P
0 g
s
.26482 .60342 m .26667 .65755 L .23486 .65952 L p .707 .577 .707 r
F P
0 g
s
.73361 .65748 m .73175 .60335 L .70059 .60187 L p .707 .577 .707 r
F P
0 g
s
.73175 .60335 m .73361 .65748 L .76542 .65551 L p .707 .577 .707 r
F P
0 g
s
.76542 .65551 m .76357 .60138 L .73175 .60335 L p .707 .577 .707 r
F P
0 g
s
.18247 .75108 m .18126 .73363 L .20516 .72345 L p .707 .577 .707 r
F P
0 g
s
.20427 .67535 m .20721 .70965 L .18338 .72079 L p .707 .577 .707 r
F P
0 g
s
.76357 .60138 m .76542 .65551 L .79477 .65026 L p .707 .577 .707 r
F P
0 g
s
.79477 .65026 m .79292 .59614 L .76357 .60138 L p .707 .577 .707 r
F P
0 g
s
.20721 .70965 m .20427 .67535 L .23348 .66762 L p .707 .577 .707 r
F P
0 g
s
.38991 .25712 m .38543 .76189 L .36232 .77129 L p .707 .577 .707 r
F P
0 g
s
.38543 .76189 m .38991 .25712 L .42387 .25005 L p .707 .577 .707 r
F P
0 g
s
.70244 .65599 m .70059 .60187 L .67312 .59706 L p .707 .577 .707 r
F P
0 g
s
.70059 .60187 m .70244 .65599 L .73361 .65748 L p .707 .577 .707 r
F P
0 g
s
.29633 .66498 m .29927 .69927 L .26813 .69833 L p .707 .577 .707 r
F P
0 g
s
.26813 .69833 m .2652 .66404 L .29633 .66498 L p .707 .577 .707 r
F P
0 g
s
.20516 .72345 m .20637 .7409 L .18247 .75108 L p .707 .577 .707 r
F P
0 g
s
.32481 .71969 m .32602 .73714 L .29853 .73195 L p .707 .577 .707 r
F P
0 g
s
.29853 .73195 m .29733 .7145 L .32481 .71969 L p .707 .577 .707 r
F P
0 g
s
.23641 .70191 m .23348 .66762 L .2652 .66404 L p .707 .577 .707 r
F P
0 g
s
.23348 .66762 m .23641 .70191 L .20721 .70965 L p .707 .577 .707 r
F P
0 g
s
.79292 .59614 m .79477 .65026 L .81879 .64226 L p .707 .577 .707 r
F P
0 g
s
.81879 .64226 m .81693 .58814 L .79292 .59614 L p .707 .577 .707 r
F P
0 g
s
.2652 .66404 m .26813 .69833 L .23641 .70191 L p .707 .577 .707 r
F P
0 g
s
.20637 .7409 m .20516 .72345 L .23442 .71648 L p .707 .577 .707 r
F P
0 g
s
.67498 .65119 m .67312 .59706 L .65205 .58941 L p .707 .577 .707 r
F P
0 g
s
.67312 .59706 m .67498 .65119 L .70244 .65599 L p .707 .577 .707 r
F P
0 g
s
.59306 .25424 m .58857 .759 L .54981 .75296 L p .707 .577 .707 r
F P
0 g
s
.54981 .75296 m .55429 .2482 L .59306 .25424 L p .707 .577 .707 r
F P
0 g
s
.29733 .7145 m .29853 .73195 L .26739 .73085 L p .707 .577 .707 r
F P
0 g
s
.26739 .73085 m .26618 .71339 L .29733 .7145 L p .707 .577 .707 r
F P
0 g
s
.23442 .71648 m .23563 .73393 L .20637 .7409 L p .707 .577 .707 r
F P
0 g
s
.23563 .73393 m .23442 .71648 L .26618 .71339 L p .707 .577 .707 r
F P
0 g
s
.73634 .73402 m .7334 .69973 L .70227 .69879 L p .707 .577 .707 r
F P
0 g
s
.7334 .69973 m .73634 .73402 L .76806 .73045 L p .707 .577 .707 r
F P
0 g
s
.76806 .73045 m .76512 .69615 L .7334 .69973 L p .707 .577 .707 r
F P
0 g
s
.26618 .71339 m .26739 .73085 L .23563 .73393 L p .707 .577 .707 r
F P
0 g
s
.76512 .69615 m .76806 .73045 L .79727 .72271 L p .707 .577 .707 r
F P
0 g
s
.79727 .72271 m .79433 .68842 L .76512 .69615 L p .707 .577 .707 r
F P
0 g
s
.41938 .75481 m .42387 .25005 L .46534 .24599 L p .707 .577 .707 r
F P
0 g
s
.42387 .25005 m .41938 .75481 L .38543 .76189 L p .707 .577 .707 r
F P
0 g
s
.81693 .58814 m .81879 .64226 L .83511 .63229 L p .707 .577 .707 r
F P
0 g
s
.83511 .63229 m .83326 .57816 L .81693 .58814 L p .707 .577 .707 r
F P
0 g
s
.70521 .73309 m .70227 .69879 L .67477 .69344 L p .707 .577 .707 r
F P
0 g
s
.70227 .69879 m .70521 .73309 L .73634 .73402 L p .707 .577 .707 r
F P
0 g
s
.65205 .58941 m .6539 .64354 L .67498 .65119 L p .707 .577 .707 r
F P
0 g
s
.79433 .68842 m .79727 .72271 L .82109 .71157 L p .707 .577 .707 r
F P
0 g
s
.82109 .71157 m .81815 .67728 L .79433 .68842 L p .707 .577 .707 r
F P
0 g
s
.55429 .2482 m .54981 .75296 L .5058 .75012 L p .707 .577 .707 r
F P
0 g
s
.5058 .75012 m .51029 .24536 L .55429 .2482 L p .707 .577 .707 r
F P
0 g
s
.6539 .64354 m .65205 .58941 L .63942 .57966 L p .707 .577 .707 r
F P
0 g
s
.46086 .75076 m .46534 .24599 L .51029 .24536 L p .707 .577 .707 r
F P
0 g
s
.46534 .24599 m .46086 .75076 L .41938 .75481 L p .707 .577 .707 r
F P
0 g
s
.73509 .78705 m .73388 .76959 L .70274 .76849 L p .707 .577 .707 r
F P
0 g
s
.73388 .76959 m .73509 .78705 L .76685 .78396 L p .707 .577 .707 r
F P
0 g
s
.76685 .78396 m .76564 .76651 L .73388 .76959 L p .707 .577 .707 r
F P
0 g
s
.67771 .72773 m .67477 .69344 L .6536 .68418 L p .707 .577 .707 r
F P
0 g
s
.67477 .69344 m .67771 .72773 L .70521 .73309 L p .707 .577 .707 r
F P
0 g
s
.76564 .76651 m .76685 .78396 L .79611 .77699 L p .707 .577 .707 r
F P
0 g
s
.79611 .77699 m .7949 .75954 L .76564 .76651 L p .707 .577 .707 r
F P
0 g
s
.51029 .24536 m .5058 .75012 L .46086 .75076 L p .707 .577 .707 r
F P
0 g
s
.70394 .78594 m .70274 .76849 L .67525 .7633 L p .707 .577 .707 r
F P
0 g
s
.70274 .76849 m .70394 .78594 L .73509 .78705 L p .707 .577 .707 r
F P
0 g
s
.83326 .57816 m .83511 .63229 L .84215 .62132 L p .707 .577 .707 r
F P
0 g
s
.84215 .62132 m .8403 .56719 L .83326 .57816 L p .707 .577 .707 r
F P
0 g
s
.81815 .67728 m .82109 .71157 L .83721 .69811 L p .707 .577 .707 r
F P
0 g
s
.83721 .69811 m .83427 .66382 L .81815 .67728 L p .707 .577 .707 r
F P
0 g
s
.7949 .75954 m .79611 .77699 L .82001 .76681 L p .707 .577 .707 r
F P
0 g
s
.82001 .76681 m .81881 .74936 L .7949 .75954 L p .707 .577 .707 r
F P
0 g
s
.63942 .57966 m .64128 .63379 L .6539 .64354 L p .707 .577 .707 r
F P
0 g
s
.67525 .7633 m .67646 .78075 L .70394 .78594 L p .707 .577 .707 r
F P
0 g
s
.6536 .68418 m .65654 .71848 L .67771 .72773 L p .707 .577 .707 r
F P
0 g
s
.64128 .63379 m .63942 .57966 L .63649 .56877 L p .707 .577 .707 r
F P
0 g
s
.67646 .78075 m .67525 .7633 L .65412 .75454 L p .707 .577 .707 r
F P
0 g
s
.65654 .71848 m .6536 .68418 L .64083 .67194 L p .707 .577 .707 r
F P
0 g
s
.65412 .75454 m .65533 .77199 L .67646 .78075 L p .707 .577 .707 r
F P
0 g
s
.81881 .74936 m .82001 .76681 L .83621 .75443 L p .707 .577 .707 r
F P
0 g
s
.83621 .75443 m .83501 .73697 L .81881 .74936 L p .707 .577 .707 r
F P
0 g
s
.83427 .66382 m .83721 .69811 L .84404 .68366 L p .707 .577 .707 r
F P
0 g
s
.84404 .68366 m .84111 .64937 L .83427 .66382 L p .707 .577 .707 r
F P
0 g
s
.8403 .56719 m .84215 .62132 L .83922 .61043 L p .707 .577 .707 r
F P
0 g
s
.83922 .61043 m .83736 .5563 L .8403 .56719 L p .707 .577 .707 r
F P
0 g
s
.63649 .56877 m .63834 .6229 L .64128 .63379 L p .707 .577 .707 r
F P
0 g
s
.64083 .67194 m .64377 .70624 L .65654 .71848 L p .707 .577 .707 r
F P
0 g
s
.65533 .77199 m .65412 .75454 L .64141 .74306 L p .707 .577 .707 r
F P
0 g
s
.64377 .70624 m .64083 .67194 L .63771 .65791 L p .707 .577 .707 r
F P
0 g
s
.63834 .6229 m .63649 .56877 L .64352 .5578 L p .707 .577 .707 r
F P
0 g
s
.64141 .74306 m .64261 .76052 L .65533 .77199 L p .707 .577 .707 r
F P
0 g
s
.83501 .73697 m .83621 .75443 L .84313 .74105 L p .707 .577 .707 r
F P
0 g
s
.84313 .74105 m .84192 .72359 L .83501 .73697 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84111 .64937 m .84404 .68366 L .84092 .66963 L p .707 .577 .707 r
F P
0 g
s
.84092 .66963 m .83798 .63534 L .84111 .64937 L p .707 .577 .707 r
F P
0 g
s
.83736 .5563 m .83922 .61043 L .82659 .60068 L p .707 .577 .707 r
F P
0 g
s
.82659 .60068 m .82474 .54655 L .83736 .5563 L p .707 .577 .707 r
F P
0 g
s
.63771 .65791 m .64065 .6922 L .64377 .70624 L p .707 .577 .707 r
F P
0 g
s
.64352 .5578 m .64538 .61193 L .63834 .6229 L p .707 .577 .707 r
F P
0 g
s
.64261 .76052 m .64141 .74306 L .63836 .72999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64065 .6922 m .63771 .65791 L .64454 .64346 L p .707 .577 .707 r
F P
0 g
s
.63836 .72999 m .63956 .74745 L .64261 .76052 L p .707 .577 .707 r
F P
0 g
s
.3906 .62067 m .38874 .56654 L .35758 .56505 L p .707 .577 .707 r
F P
0 g
s
.38874 .56654 m .3906 .62067 L .42241 .61869 L p .707 .577 .707 r
F P
0 g
s
.42241 .61869 m .42056 .56456 L .38874 .56654 L p .707 .577 .707 r
F P
0 g
s
.64538 .61193 m .64352 .5578 L .65985 .54783 L p .707 .577 .707 r
F P
0 g
s
.42056 .56456 m .42241 .61869 L .45176 .61345 L p .707 .577 .707 r
F P
0 g
s
.45176 .61345 m .44991 .55932 L .42056 .56456 L p .707 .577 .707 r
F P
0 g
s
.84192 .72359 m .84313 .74105 L .84008 .72798 L p .707 .577 .707 r
F P
0 g
s
.84008 .72798 m .83887 .71052 L .84192 .72359 L p .707 .577 .707 r
F P
0 g
s
.35943 .61918 m .35758 .56505 L .33011 .56025 L p .707 .577 .707 r
F P
0 g
s
.35758 .56505 m .35943 .61918 L .3906 .62067 L p .707 .577 .707 r
F P
0 g
s
.83798 .63534 m .84092 .66963 L .82815 .65739 L p .707 .577 .707 r
F P
0 g
s
.82815 .65739 m .82521 .6231 L .83798 .63534 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82474 .54655 m .82659 .60068 L .80552 .59303 L p .707 .577 .707 r
F P
0 g
s
.80552 .59303 m .80366 .5389 L .82474 .54655 L p .707 .577 .707 r
F P
0 g
s
.44991 .55932 m .45176 .61345 L .47578 .60545 L p .707 .577 .707 r
F P
0 g
s
.47578 .60545 m .47392 .55132 L .44991 .55932 L p .707 .577 .707 r
F P
0 g
s
.64454 .64346 m .64748 .67775 L .64065 .6922 L p .707 .577 .707 r
F P
0 g
s
.65985 .54783 m .66171 .60195 L .64538 .61193 L p .707 .577 .707 r
F P
0 g
s
.63956 .74745 m .63836 .72999 L .64527 .71661 L p .707 .577 .707 r
F P
0 g
s
.33197 .61437 m .33011 .56025 L .30904 .55259 L p .707 .577 .707 r
F P
0 g
s
.33011 .56025 m .33197 .61437 L .35943 .61918 L p .707 .577 .707 r
F P
0 g
s
.66171 .60195 m .65985 .54783 L .68386 .53983 L p .707 .577 .707 r
F P
0 g
s
.64748 .67775 m .64454 .64346 L .66066 .63 L p .707 .577 .707 r
F P
0 g
s
.64527 .71661 m .64648 .73406 L .63956 .74745 L p .707 .577 .707 r
F P
0 g
s
.39333 .69721 m .39039 .66291 L .35926 .66198 L p .707 .577 .707 r
F P
0 g
s
.39039 .66291 m .39333 .69721 L .42505 .69363 L p .707 .577 .707 r
F P
0 g
s
.42505 .69363 m .42211 .65934 L .39039 .66291 L p .707 .577 .707 r
F P
0 g
s
.42211 .65934 m .42505 .69363 L .45426 .68589 L p .707 .577 .707 r
F P
0 g
s
.45426 .68589 m .45132 .6516 L .42211 .65934 L p .707 .577 .707 r
F P
0 g
s
.83887 .71052 m .84008 .72798 L .82737 .7165 L p .707 .577 .707 r
F P
0 g
s
.82737 .7165 m .82616 .69905 L .83887 .71052 L p .707 .577 .707 r
F P
0 g
s
.47392 .55132 m .47578 .60545 L .4921 .59547 L p .707 .577 .707 r
F P
0 g
s
.4921 .59547 m .49025 .54135 L .47392 .55132 L p .707 .577 .707 r
F P
0 g
s
.82521 .6231 m .82815 .65739 L .80698 .64814 L p .707 .577 .707 r
F P
0 g
s
.80698 .64814 m .80404 .61384 L .82521 .6231 L p .707 .577 .707 r
F P
0 g
s
.80366 .5389 m .80552 .59303 L .77805 .58822 L p .707 .577 .707 r
F P
0 g
s
.77805 .58822 m .77619 .53409 L .80366 .5389 L p .707 .577 .707 r
F P
0 g
s
.3622 .69627 m .35926 .66198 L .33176 .65662 L p .707 .577 .707 r
F P
0 g
s
.35926 .66198 m .3622 .69627 L .39333 .69721 L p .707 .577 .707 r
F P
0 g
s
.30904 .55259 m .31089 .60672 L .33197 .61437 L p .707 .577 .707 r
F P
0 g
s
.45132 .6516 m .45426 .68589 L .47808 .67475 L p .707 .577 .707 r
F P
0 g
s
.47808 .67475 m .47514 .64046 L .45132 .6516 L p .707 .577 .707 r
F P
0 g
s
.66066 .63 m .6636 .6643 L .64748 .67775 L p .707 .577 .707 r
F P
0 g
s
.68572 .59395 m .68386 .53983 L .71321 .53458 L p .707 .577 .707 r
F P
0 g
s
.68386 .53983 m .68572 .59395 L .66171 .60195 L p .707 .577 .707 r
F P
0 g
s
.31089 .60672 m .30904 .55259 L .29641 .54284 L p .707 .577 .707 r
F P
0 g
s
.64648 .73406 m .64527 .71661 L .66148 .70422 L p .707 .577 .707 r
F P
0 g
s
.6636 .6643 m .66066 .63 L .68449 .61886 L p .707 .577 .707 r
F P
0 g
s
.39208 .75023 m .39087 .73278 L .35973 .73167 L p .707 .577 .707 r
F P
0 g
s
.39087 .73278 m .39208 .75023 L .42384 .74715 L p .707 .577 .707 r
F P
0 g
s
.42384 .74715 m .42263 .72969 L .39087 .73278 L p .707 .577 .707 r
F P
0 g
s
.77619 .53409 m .77805 .58822 L .74689 .58673 L p .707 .577 .707 r
F P
0 g
s
.74689 .58673 m .74503 .53261 L .77619 .53409 L p .707 .577 .707 r
F P
0 g
s
.3347 .69091 m .33176 .65662 L .31059 .64737 L p .707 .577 .707 r
F P
0 g
s
.33176 .65662 m .3347 .69091 L .3622 .69627 L p .707 .577 .707 r
F P
0 g
s
.42263 .72969 m .42384 .74715 L .4531 .74018 L p .707 .577 .707 r
F P
0 g
s
.4531 .74018 m .45189 .72272 L .42263 .72969 L p .707 .577 .707 r
F P
0 g
s
.71507 .58871 m .71321 .53458 L .74503 .53261 L p .707 .577 .707 r
F P
0 g
s
.71321 .53458 m .71507 .58871 L .68572 .59395 L p .707 .577 .707 r
F P
0 g
s
.66148 .70422 m .66268 .72168 L .64648 .73406 L p .707 .577 .707 r
F P
0 g
s
.80404 .61384 m .80698 .64814 L .77948 .64278 L p .707 .577 .707 r
F P
0 g
s
.77948 .64278 m .77654 .60849 L .80404 .61384 L p .707 .577 .707 r
F P
0 g
s
.36093 .74912 m .35973 .73167 L .33224 .72648 L p .707 .577 .707 r
F P
0 g
s
.35973 .73167 m .36093 .74912 L .39208 .75023 L p .707 .577 .707 r
F P
0 g
s
.49025 .54135 m .4921 .59547 L .49914 .58451 L p .707 .577 .707 r
F P
0 g
s
.49914 .58451 m .49729 .53038 L .49025 .54135 L p .707 .577 .707 r
F P
0 g
s
.74503 .53261 m .74689 .58673 L .71507 .58871 L p .707 .577 .707 r
F P
0 g
s
.82616 .69905 m .82737 .7165 L .80623 .70774 L p .707 .577 .707 r
F P
0 g
s
.80623 .70774 m .80503 .69029 L .82616 .69905 L p .707 .577 .707 r
F P
0 g
s
.47514 .64046 m .47808 .67475 L .4942 .6613 L p .707 .577 .707 r
F P
0 g
s
.4942 .6613 m .49126 .62701 L .47514 .64046 L p .707 .577 .707 r
F P
0 g
s
.45189 .72272 m .4531 .74018 L .477 .73 L p .707 .577 .707 r
F P
0 g
s
.477 .73 m .4758 .71254 L .45189 .72272 L p .707 .577 .707 r
F P
0 g
s
.29641 .54284 m .29827 .59697 L .31089 .60672 L p .707 .577 .707 r
F P
0 g
s
.33224 .72648 m .33345 .74394 L .36093 .74912 L p .707 .577 .707 r
F P
0 g
s
.68449 .61886 m .68742 .65315 L .6636 .6643 L p .707 .577 .707 r
F P
0 g
s
.68742 .65315 m .68449 .61886 L .71369 .61113 L p .707 .577 .707 r
F P
0 g
s
.31059 .64737 m .31353 .68166 L .3347 .69091 L p .707 .577 .707 r
F P
0 g
s
.29827 .59697 m .29641 .54284 L .29348 .53195 L p .707 .577 .707 r
F P
0 g
s
.66268 .72168 m .66148 .70422 L .68538 .69405 L p .707 .577 .707 r
F P
0 g
s
.77654 .60849 m .77948 .64278 L .74835 .64184 L p .707 .577 .707 r
F P
0 g
s
.74835 .64184 m .74541 .60755 L .77654 .60849 L p .707 .577 .707 r
F P
0 g
s
.33345 .74394 m .33224 .72648 L .31111 .71772 L p .707 .577 .707 r
F P
0 g
s
.31353 .68166 m .31059 .64737 L .29782 .63513 L p .707 .577 .707 r
F P
0 g
s
.71663 .64542 m .71369 .61113 L .74541 .60755 L p .707 .577 .707 r
F P
0 g
s
.71369 .61113 m .71663 .64542 L .68742 .65315 L p .707 .577 .707 r
F P
0 g
s
.74541 .60755 m .74835 .64184 L .71663 .64542 L p .707 .577 .707 r
F P
0 g
s
.68538 .69405 m .68658 .7115 L .66268 .72168 L p .707 .577 .707 r
F P
0 g
s
.80503 .69029 m .80623 .70774 L .77875 .70255 L p .707 .577 .707 r
F P
0 g
s
.77875 .70255 m .77754 .6851 L .80503 .69029 L p .707 .577 .707 r
F P
0 g
s
.31111 .71772 m .31231 .73518 L .33345 .74394 L p .707 .577 .707 r
F P
0 g
s
.4758 .71254 m .477 .73 L .4932 .71761 L p .707 .577 .707 r
F P
0 g
s
.4932 .71761 m .492 .70016 L .4758 .71254 L p .707 .577 .707 r
F P
0 g
s
.49126 .62701 m .4942 .6613 L .50103 .64685 L p .707 .577 .707 r
F P
0 g
s
.50103 .64685 m .4981 .61256 L .49126 .62701 L p .707 .577 .707 r
F P
0 g
s
.49729 .53038 m .49914 .58451 L .49621 .57361 L p .707 .577 .707 r
F P
0 g
s
.49621 .57361 m .49435 .51948 L .49729 .53038 L p .707 .577 .707 r
F P
0 g
s
.68658 .7115 m .68538 .69405 L .71464 .68708 L p .707 .577 .707 r
F P
0 g
s
.29348 .53195 m .29533 .58608 L .29827 .59697 L p .707 .577 .707 r
F P
0 g
s
.29782 .63513 m .30076 .66942 L .31353 .68166 L p .707 .577 .707 r
F P
0 g
s
.31231 .73518 m .31111 .71772 L .2984 .70625 L p .707 .577 .707 r
F P
0 g
s
.77754 .6851 m .77875 .70255 L .7476 .70145 L p .707 .577 .707 r
F P
0 g
s
.7476 .70145 m .7464 .68399 L .77754 .6851 L p .707 .577 .707 r
F P
0 g
s
.71464 .68708 m .71584 .70453 L .68658 .7115 L p .707 .577 .707 r
F P
0 g
s
.30076 .66942 m .29782 .63513 L .2947 .62109 L p .707 .577 .707 r
F P
0 g
s
.71584 .70453 m .71464 .68708 L .7464 .68399 L p .707 .577 .707 r
F P
0 g
s
.29533 .58608 m .29348 .53195 L .30051 .52098 L p .707 .577 .707 r
F P
0 g
s
.2984 .70625 m .2996 .7237 L .31231 .73518 L p .707 .577 .707 r
F P
0 g
s
.7464 .68399 m .7476 .70145 L .71584 .70453 L p .707 .577 .707 r
F P
0 g
s
.492 .70016 m .4932 .71761 L .50012 .70423 L p .707 .577 .707 r
F P
0 g
s
.50012 .70423 m .49891 .68678 L .492 .70016 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4981 .61256 m .50103 .64685 L .49791 .63281 L p .707 .577 .707 r
F P
0 g
s
.49791 .63281 m .49497 .59852 L .4981 .61256 L p .707 .577 .707 r
F P
0 g
s
.49435 .51948 m .49621 .57361 L .48358 .56386 L p .707 .577 .707 r
F P
0 g
s
.48358 .56386 m .48173 .50974 L .49435 .51948 L p .707 .577 .707 r
F P
0 g
s
.2947 .62109 m .29764 .65539 L .30076 .66942 L p .707 .577 .707 r
F P
0 g
s
.30051 .52098 m .30237 .57511 L .29533 .58608 L p .707 .577 .707 r
F P
0 g
s
.2996 .7237 m .2984 .70625 L .29535 .69318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29764 .65539 m .2947 .62109 L .30153 .60664 L p .707 .577 .707 r
F P
0 g
s
.29535 .69318 m .29655 .71063 L .2996 .7237 L p .707 .577 .707 r
F P
0 g
s
.30237 .57511 m .30051 .52098 L .31684 .51101 L p .707 .577 .707 r
F P
0 g
s
.49891 .68678 m .50012 .70423 L .49707 .69116 L p .707 .577 .707 r
F P
0 g
s
.49707 .69116 m .49586 .67371 L .49891 .68678 L p .707 .577 .707 r
F P
0 g
s
.49497 .59852 m .49791 .63281 L .48514 .62057 L p .707 .577 .707 r
F P
0 g
s
.48514 .62057 m .4822 .58628 L .49497 .59852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48173 .50974 m .48358 .56386 L .46251 .55621 L p .707 .577 .707 r
F P
0 g
s
.46251 .55621 m .46065 .50208 L .48173 .50974 L p .707 .577 .707 r
F P
0 g
s
.30153 .60664 m .30447 .64093 L .29764 .65539 L p .707 .577 .707 r
F P
0 g
s
.31684 .51101 m .3187 .56514 L .30237 .57511 L p .707 .577 .707 r
F P
0 g
s
.29655 .71063 m .29535 .69318 L .30226 .67979 L p .707 .577 .707 r
F P
0 g
s
.3187 .56514 m .31684 .51101 L .34085 .50301 L p .707 .577 .707 r
F P
0 g
s
.30447 .64093 m .30153 .60664 L .31765 .59319 L p .707 .577 .707 r
F P
0 g
s
.30226 .67979 m .30347 .69725 L .29655 .71063 L p .707 .577 .707 r
F P
0 g
s
.49586 .67371 m .49707 .69116 L .48436 .67968 L p .707 .577 .707 r
F P
0 g
s
.48436 .67968 m .48315 .66223 L .49586 .67371 L p .707 .577 .707 r
F P
0 g
s
.4822 .58628 m .48514 .62057 L .46397 .61132 L p .707 .577 .707 r
F P
0 g
s
.46397 .61132 m .46103 .57703 L .4822 .58628 L p .707 .577 .707 r
F P
0 g
s
.46065 .50208 m .46251 .55621 L .43504 .55141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55141 m .43318 .49728 L .46065 .50208 L p .707 .577 .707 r
F P
0 g
s
.31765 .59319 m .32059 .62748 L .30447 .64093 L p .707 .577 .707 r
F P
0 g
s
.34271 .55714 m .34085 .50301 L .3702 .49777 L p .707 .577 .707 r
F P
0 g
s
.34085 .50301 m .34271 .55714 L .3187 .56514 L p .707 .577 .707 r
F P
0 g
s
.30347 .69725 m .30226 .67979 L .31846 .66741 L p .707 .577 .707 r
F P
0 g
s
.32059 .62748 m .31765 .59319 L .34148 .58205 L p .707 .577 .707 r
F P
0 g
s
.43318 .49728 m .43504 .55141 L .40387 .54992 L p .707 .577 .707 r
F P
0 g
s
.40387 .54992 m .40202 .49579 L .43318 .49728 L p .707 .577 .707 r
F P
0 g
s
.37206 .55189 m .3702 .49777 L .40202 .49579 L p .707 .577 .707 r
F P
0 g
s
.3702 .49777 m .37206 .55189 L .34271 .55714 L p .707 .577 .707 r
F P
0 g
s
.31846 .66741 m .31967 .68486 L .30347 .69725 L p .707 .577 .707 r
F P
0 g
s
.46103 .57703 m .46397 .61132 L .43647 .60596 L p .707 .577 .707 r
F P
0 g
s
.43647 .60596 m .43353 .57167 L .46103 .57703 L p .707 .577 .707 r
F P
0 g
s
.40202 .49579 m .40387 .54992 L .37206 .55189 L p .707 .577 .707 r
F P
0 g
s
.48315 .66223 m .48436 .67968 L .46322 .67092 L p .707 .577 .707 r
F P
0 g
s
.46322 .67092 m .46202 .65347 L .48315 .66223 L p .707 .577 .707 r
F P
0 g
s
.34148 .58205 m .34441 .61634 L .32059 .62748 L p .707 .577 .707 r
F P
0 g
s
.34441 .61634 m .34148 .58205 L .37068 .57431 L p .707 .577 .707 r
F P
0 g
s
.31967 .68486 m .31846 .66741 L .34237 .65723 L p .707 .577 .707 r
F P
0 g
s
.43353 .57167 m .43647 .60596 L .40534 .60503 L p .707 .577 .707 r
F P
0 g
s
.40534 .60503 m .4024 .57073 L .43353 .57167 L p .707 .577 .707 r
F P
0 g
s
.37362 .6086 m .37068 .57431 L .4024 .57073 L p .707 .577 .707 r
F P
0 g
s
.37068 .57431 m .37362 .6086 L .34441 .61634 L p .707 .577 .707 r
F P
0 g
s
.4024 .57073 m .40534 .60503 L .37362 .6086 L p .707 .577 .707 r
F P
0 g
s
.34237 .65723 m .34357 .67469 L .31967 .68486 L p .707 .577 .707 r
F P
0 g
s
.46202 .65347 m .46322 .67092 L .43574 .66574 L p .707 .577 .707 r
F P
0 g
s
.43574 .66574 m .43453 .64828 L .46202 .65347 L p .707 .577 .707 r
F P
0 g
s
.34357 .67469 m .34237 .65723 L .37163 .65026 L p .707 .577 .707 r
F P
0 g
s
.43453 .64828 m .43574 .66574 L .40459 .66463 L p .707 .577 .707 r
F P
0 g
s
.40459 .66463 m .40339 .64718 L .43453 .64828 L p .707 .577 .707 r
F P
0 g
s
.37163 .65026 m .37283 .66771 L .34357 .67469 L p .707 .577 .707 r
F P
0 g
s
.37283 .66771 m .37163 .65026 L .40339 .64718 L p .707 .577 .707 r
F P
0 g
s
.40339 .64718 m .40459 .66463 L .37283 .66771 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0006FUH00`00FUIJEP03FUH9001mOol007Ioo`T000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool40007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool006Yoo`<00003FUH0
05YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00005`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0035YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001OOol40006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005aoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001HOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol0
0`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0067oo3`00?goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
47oo200015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01eYF100015YF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03
001JEP0000AJEP03001JEP0000@000=oo`04001JEUYF0005FUH00`00FUH000020005FUH00`00FUIJ
EP02FUH50004FUH300000eYF001JEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0000=JEP00FUH00UYF2@000eYF3`000eYF00<005YFFUH015YF00@005YF000000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF3`000UYF00<005YFFUH015YF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`001EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000^Ool005=oo`8000=JEP03001JEUYF009JEP03001JEUYF00@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001D
Ool01P00FUIJEUYF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH5000JOol50004FUH01@00
FUIJEUYF0000;Woo001DOol01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEUYFFUH2
000?Ool3000<Ool30003FUH300000eYF001JEP02FUH2000]Ool005Eoo`06001JEP00001JEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP05001JEP00001JEP04000;Ool50007Ool400000eYF001JEP05FUH30003FUH2
000]Ool004Moo`T000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF0P0000=JEP00FUH015YF
5`001EYF00<005YFFUH015YF00@005YFFUH0009JEP8002eoo`00?Woo2@0015YF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF4@000eYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP03
001JEUYF00AJEP04001JEUYFFUH4000]Ool003Qoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEPP000QJEP03001JEUYF00EJEP@000EJEP03001J
EUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH0
05YF00EJEP03001JEUYF009JEP<002eoo`00=Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH010001eYF00<005YFFUH01UYF00<005YF
FUH00UYF1@0000AJEP00000000=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH200000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH00UYF0`00;Goo000cOol2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJ
EP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP0200000eYF001J
EP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0000=JEP00FUH00eYF00<005YF0000;Goo000aOol30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH01000FUIJEUYF100000=oo`0000003P000eYF
00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;goo
0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00001EYF00@005YF0000009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8002ioo`00;Woo00<005YFFUH0
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0
00AJEP8000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP000000;Woo000]Ool20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0P001EYF
00@005YFFUH0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03001JEUYF00AJEP800004
FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01000FUH0
00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YF000002moo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00800003FUH005YF00AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH60004FUH00`00FUIJEP09FUH00`00FUIJEP03FUH01000FUH005YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00UJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00000P00
1EYF00<005YFFUH02EYF00<005YFFUH00P000eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP<00003FUH005YF009J
EP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03
001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03
001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF0P000UYF00<005YFFUH00eYF00H005YF001JEP00FUHG0003
FUH20003FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YF
FUH015YF1`0015YF00<005YFFUH00P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<000EJEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00FUIJEP02FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF
00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH010001goo0`0000AJ
EP00FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0015YF0P000UYF00<005YFFUH00UYF1`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`0000=JEP00FUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00@005YFFUIJEQ`000ioo`8000=JEP03001o
ogoo02]oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1P000UYF
00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEP000003FUH3000VOol01000FUIJEP00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006Ool90004Ool20002FUH01000FUIJEUYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH20005FUH00`00FUIJEP02000UOol00`00FUH0000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP@000Aoo`H000AJEP03001JEUYF009JEPH000=JEP<000EJEP03001J
EUYF00AJEQL000AJEP03001JEUYF00=JEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP06001JEUYF001JEP001EYF00D005YFFUIJEP0000Uoo`<0
01Qoo`@002eoo`00;7oo00<005YF000015YF00<005YF00001P000goo0P0000=JEP00FUH01eYF00<0
05YFFUH01UYF0P000eYF0P001UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`D001Eoo`80
0004FUH005YF000]Ool002aoo`03001JEP0000AJEP800003FUH005YF00AJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00AJEP@0009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03
FUH01@00FUIJEUYF000027oo1@0057oo00L005YFFUIJEP00FUH0000]Ool002aoo`03001JEP00009J
EP8000=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP04
001JEUYFFUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
0`0000EJEP00FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF00=JEP03001JEUYF00=JEP05001JEUYFFUH00008Ool5000BOol20004
FUH00`00FUH0000]Ool002aoo`03001JEP00008000EJEP<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP06001JEP00001JEP001UYF00<005YFFUH01EYF10001UYF00<005YF
FUH01UYF00@005YFFUH000=JEP80009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP03FUH01@00FUIJEUYF00002Goo0`004Goo0P0000=J
EP00FUH00eYF00<005YF0000;Goo000/Ool01@00FUH005YF000015YF0P000eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH01UYF0`001UYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH400000eYF001JEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF000027oo
3`0017oo0P000eYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH300000eYF001JEP06FUH300000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH300000eYF001J
EP04FUH01P00FUIJEUYF001oo`L000AJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
009JEP8002ioo`00;7oo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0003FUH00`00FUH000020005FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP040004FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30002FUH00`00FUIJEP020005FUH00`00FUH000030002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH2000^Ool002aoo`80009JEP80
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
00AJEP03001JEUYF009JEP@00003FUH005YF00MJEP<0009JEPL000QJEP03001JEUYF00IJEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
009JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000AJ
EP03001oogoo02eoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF30000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF00003`000eYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YF00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH70009FUH01P00FUH005YF001JEP@00003FUH005YF00AJEP05001JEP00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH3000`Ool002eoo`8000EJEP03001J
EUYF00=JEP03001JEUYF00@000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP04001JEP000005
FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000UYF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YF000000EJ
EP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00031o
o`00;Goo0P001EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000=JEP05001JEP00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP02FUH200001UYF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH30006FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH50004FUH00`00FUH0000_Ool002aoo`03001JEP0000EJEP04001JEUYFFUH20005
FUH00`00FUIJEP05FUH900001eYF001JEUYF001JEP00009JEP03001JEUYF00=JEP800006FUH005YF
001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0015YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0002ioo`00;7oo00<005YF00001EYF00@005YF000000MJEP03001JEP0000D000AJEP03
001JEUYF009JEPH00004FUH005YF0003FUH20002Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF0`0000=JEP00FUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH4
0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo0P000UYF00<007ooOol0;7oo000/Ool01000
FUIJEP0015YF0P0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF0P000UYF1@00
1Woo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF0P000eYF00<005YFFUH00UYF
00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001J
EP00008000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04001JEP000006Ool01000FUH0
0000;Goo000/Ool01000FUIJEP000eYF00<007ooOol01`001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000UYF00<005YF0000100017oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
15YF0`0027oo00@005YF000002eoo`00;7oo00D005YFFUH005YF008000Aoo`800003FUH005YF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH400001Woo001JEP00FUH000IJ
EP03001JEUYF00MJEP04001JEUYFFUH400000eYF001JEP05FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEUYF0P000UYF10001UYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH0100037oo0`00;Goo000/Ool00`00FUIJEP020004Ool20003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80004FUH01@00FUH005YF00001EYF00<005YF00001000
00=JEP00FUH01EYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH7000AOol2000]Ool002eoo`03001JEP0000=oo`8000EJ
EP03001JEUYF00AJEPL000Qoo`T000EJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP04001J
EUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP0@000GOol3000]Ool002eoo`@00003Ool0
000000IJEP03001JEUYF00@001Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH01000FUIJEP009Goo00<005YF0000;Goo
000]Ool200001EYF000005YF00001EYF10007Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF1@001EYF00<005YFFUH00P008goo0P0000=JEP00
Ool0;7oo000]Ool00`00FUH00003FUH01000FUIJEUYF0P007goo0`000UYF0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF0P000eYF00<005YF
FUH00P008Goo0P0000=JEP000000;Woo000]Ool20004FUH01000FUH000007Woo0`0000=JEP00FUH0
1EYF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF0P00
00=JEP00FUH00UYF00<007ooOol07Woo00@005YFFUIJEP8002ioo`00;Goo0P0015YF0P0000=JEP00
00000`005goo0`0015YF00<005YFFUH015YF00<005YFFUH04@000eYF00<005YFFUH015YF60001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUH000EJEP800003Ool0
000000=JEP03001oogoo01aoo`8000AJEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH00UYF
00@005YFFUIJEPP000Uoo`H000MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
1`001Goo00@005YFFUH001Yoo`@00003FUH005YF00=JEP03001oogoo02eoo`00;7oo00H005YFFUH0
05YF0005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH30002FUH60007Ool3000GOol30005FUH01@00FUIJ
EUYF0000<7oo000/Ool00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP04
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20004FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02000015YF000000000goo0P00
00=JEP00Ool04Woo100000=JEP00FUH01UYF00<005YF0000<Goo000/Ool01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000Woo00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF10000UYF00@005YF
FUIJEPL00004FUH005YF000<Ool70005FUH00`00FUIJEP05FUH2000bOol002eoo`800004Ool005YF
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00Oomoo`0200000eYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF1`0015YF00@005YFFUIJ
EQ8000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000Woo0P001EYF00<005YF
FUH015YF00<005YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP80009oo`04001JEP00
FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000Woo0`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000]Ool20003
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUH00000
0goo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10001Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000]Ool01000FUH0
00000goo0`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF10000goo0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001Woo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000?Goo000]Ool20002FUH00`00Oomoo`03Ool30005
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040005Ool200000eYF001JEP02FUH20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003Ool30003FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70011Ool002ioo`03001JEUYF00<000Ioo`@00003FUH005YF00MJEP<0009JEPL000Moo`8000=J
EP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001J
EP05FUH00`00FUIJEP0A0018Ool002ioo`04001JEUYF0002FUH20008Ool?000;Ool30005FUH01P00
FUH00000Ool000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00EJ
EP04001JEUYFFUH3001DOol002moo`03001JEP0000AJEPD001Uoo`@00003FUH005YF00EJEP8000=o
o`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP04001J
EUYFFUH3001DOol0031oo`8000EJEP04001JEUYFFUH90009Ool70005FUH00`00FUIJEP03FUH20005
Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP05FUH01@00FUIJEP00
Ool00P00E7oo000aOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH01EYF
0`0000Aoo`00000005Aoo`00<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH00`00FUIJEP04
FUH01`00Oomoogoo001JEP0005Aoo`00=7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009oo`<00003FUH007oo05=oo`00=Woo1@0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH0100067oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF10001EYF00<005YFFUH01EYF00<005YFFUH00P000Woo0P000UYF0P00EGoo000k
Ool90004FUH00`00FUIJEP02FUH7000QOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP090005FUH00`00FUIJEP05FUH30002Ool20004FUH2001EOol004Aoo`T0
02ioo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPP000AJEPD000EJEP03001JEUYF00AJEP80
009oo`800003FUH005YF00=JEP03001oogoo05Aoo`00Q7oo6@0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH010000Woo0P000eYF00<005YFFUH00UYF00<007ooOol0E7oo002?Ool01@00FUIJEP00
FUH00`001Woo2@0015YF0`000UYF1`000goo0`001UYF00@005YFFUH005Moo`00Sgoo00@005YFFUH0
00AJEP<000aoo`T000Ioo`@00003FUH005YF00IJEP<005Qoo`00T7oo00@005YFFUH000AJEP03001J
EP0000<0011oo`L000EJEP03001JEUYF00AJEP8005Yoo`00TGoo0`0015YF00<005YFFUH00eYF4000
15YF00<005YFFUH01UYF00@005YFFUIJEP8005aoo`00Tgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005ioo`00UGoo0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000H7oo002HOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001TOol009]oo`@0009JEP03001JEUYF00EJEP03
001JEUYF009JEPL006Qoo`00Wgoo3`00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59612 .73349 m .59798 .67687 L .56681 .67455 L p .707 .577 .707 r
F P
0 g
s
.59798 .67687 m .59612 .73349 L .62794 .73394 L p .707 .577 .707 r
F P
0 g
s
.62794 .73394 m .62979 .67732 L .59798 .67687 L p .707 .577 .707 r
F P
0 g
s
.62979 .67732 m .62794 .73394 L .65729 .73247 L p .707 .577 .707 r
F P
0 g
s
.65729 .73247 m .65914 .67585 L .62979 .67732 L p .707 .577 .707 r
F P
0 g
s
.56496 .73117 m .56681 .67455 L .53935 .67058 L p .707 .577 .707 r
F P
0 g
s
.56681 .67455 m .56496 .73117 L .59612 .73349 L p .707 .577 .707 r
F P
0 g
s
.65914 .67585 m .65729 .73247 L .6813 .72922 L p .707 .577 .707 r
F P
0 g
s
.6813 .72922 m .68316 .6726 L .65914 .67585 L p .707 .577 .707 r
F P
0 g
s
.53935 .67058 m .53749 .7272 L .56496 .73117 L p .707 .577 .707 r
F P
0 g
s
.59466 .79056 m .5976 .75233 L .56647 .74941 L p .707 .577 .707 r
F P
0 g
s
.5976 .75233 m .59466 .79056 L .62638 .79274 L p .707 .577 .707 r
F P
0 g
s
.62638 .79274 m .62932 .7545 L .5976 .75233 L p .707 .577 .707 r
F P
0 g
s
.53749 .7272 m .53935 .67058 L .51827 .66535 L p .707 .577 .707 r
F P
0 g
s
.56647 .74941 m .56353 .78764 L .59466 .79056 L p .707 .577 .707 r
F P
0 g
s
.62932 .7545 m .62638 .79274 L .65558 .79396 L p .707 .577 .707 r
F P
0 g
s
.65558 .79396 m .65852 .75572 L .62932 .7545 L p .707 .577 .707 r
F P
0 g
s
.56353 .78764 m .56647 .74941 L .53897 .74603 L p .707 .577 .707 r
F P
0 g
s
.53897 .74603 m .53603 .78427 L .56353 .78764 L p .707 .577 .707 r
F P
0 g
s
.51827 .66535 m .51642 .72197 L .53749 .7272 L p .707 .577 .707 r
F P
0 g
s
.65852 .75572 m .65558 .79396 L .67941 .7941 L p .707 .577 .707 r
F P
0 g
s
.67941 .7941 m .68235 .75587 L .65852 .75572 L p .707 .577 .707 r
F P
0 g
s
.68316 .6726 m .6813 .72922 L .69763 .72452 L p .707 .577 .707 r
F P
0 g
s
.69763 .72452 m .69948 .6679 L .68316 .6726 L p .707 .577 .707 r
F P
0 g
s
.59541 .84916 m .59661 .83009 L .56546 .82736 L p .707 .577 .707 r
F P
0 g
s
.59661 .83009 m .59541 .84916 L .62716 .8508 L p .707 .577 .707 r
F P
0 g
s
.62716 .8508 m .62837 .83173 L .59661 .83009 L p .707 .577 .707 r
F P
0 g
s
.56546 .82736 m .56426 .84643 L .59541 .84916 L p .707 .577 .707 r
F P
0 g
s
.62837 .83173 m .62716 .8508 L .65643 .85117 L p .707 .577 .707 r
F P
0 g
s
.65643 .85117 m .65763 .8321 L .62837 .83173 L p .707 .577 .707 r
F P
0 g
s
.53603 .78427 m .53897 .74603 L .5178 .74253 L p .707 .577 .707 r
F P
0 g
s
.5178 .74253 m .51486 .78077 L .53603 .78427 L p .707 .577 .707 r
F P
0 g
s
.56426 .84643 m .56546 .82736 L .53798 .8238 L p .707 .577 .707 r
F P
0 g
s
.51642 .72197 m .51827 .66535 L .50565 .65937 L p .707 .577 .707 r
F P
0 g
s
.53798 .8238 m .53677 .84287 L .56426 .84643 L p .707 .577 .707 r
F P
0 g
s
.65763 .8321 m .65643 .85117 L .68033 .85025 L p .707 .577 .707 r
F P
0 g
s
.68033 .85025 m .68153 .83118 L .65763 .8321 L p .707 .577 .707 r
F P
0 g
s
.50565 .65937 m .50379 .71599 L .51642 .72197 L p .707 .577 .707 r
F P
0 g
s
.68235 .75587 m .67941 .7941 L .69553 .79316 L p .707 .577 .707 r
F P
0 g
s
.69553 .79316 m .69847 .75492 L .68235 .75587 L p .707 .577 .707 r
F P
0 g
s
.53677 .84287 m .53798 .8238 L .51685 .81976 L p .707 .577 .707 r
F P
0 g
s
.69948 .6679 m .69763 .72452 L .70467 .71882 L p .707 .577 .707 r
F P
0 g
s
.70467 .71882 m .70652 .6622 L .69948 .6679 L p .707 .577 .707 r
F P
0 g
s
.51685 .81976 m .51564 .83883 L .53677 .84287 L p .707 .577 .707 r
F P
0 g
s
.51486 .78077 m .5178 .74253 L .50503 .73925 L p .707 .577 .707 r
F P
0 g
s
.50503 .73925 m .50209 .77748 L .51486 .78077 L p .707 .577 .707 r
F P
0 g
s
.50379 .71599 m .50565 .65937 L .50271 .65324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83118 m .68033 .85025 L .69653 .84813 L p .707 .577 .707 r
F P
0 g
s
.69653 .84813 m .69773 .82906 L .68153 .83118 L p .707 .577 .707 r
F P
0 g
s
.69847 .75492 m .69553 .79316 L .70236 .79121 L p .707 .577 .707 r
F P
0 g
s
.70236 .79121 m .7053 .75298 L .69847 .75492 L p .707 .577 .707 r
F P
0 g
s
.51564 .83883 m .51685 .81976 L .50413 .81563 L p .707 .577 .707 r
F P
0 g
s
.50271 .65324 m .50086 .70985 L .50379 .71599 L p .707 .577 .707 r
F P
0 g
s
.50413 .81563 m .50293 .8347 L .51564 .83883 L p .707 .577 .707 r
F P
0 g
s
.70652 .6622 m .70467 .71882 L .70173 .71268 L p .707 .577 .707 r
F P
0 g
s
.70173 .71268 m .70359 .65606 L .70652 .6622 L p .707 .577 .707 r
F P
0 g
s
.50209 .77748 m .50503 .73925 L .5019 .7365 L p .707 .577 .707 r
F P
0 g
s
.5019 .7365 m .49896 .77473 L .50209 .77748 L p .707 .577 .707 r
F P
0 g
s
.4942 .82231 m .48971 .32357 L .4457 .32104 L p .707 .577 .707 r
F P
0 g
s
.50086 .70985 m .50271 .65324 L .50975 .64754 L p .707 .577 .707 r
F P
0 g
s
.50293 .8347 m .50413 .81563 L .50109 .81182 L p .707 .577 .707 r
F P
0 g
s
.50109 .81182 m .49988 .83089 L .50293 .8347 L p .707 .577 .707 r
F P
0 g
s
.50975 .64754 m .50789 .70415 L .50086 .70985 L p .707 .577 .707 r
F P
0 g
s
.49896 .77473 m .5019 .7365 L .50873 .73456 L p .707 .577 .707 r
F P
0 g
s
.50873 .73456 m .5058 .77279 L .49896 .77473 L p .707 .577 .707 r
F P
0 g
s
.50789 .70415 m .50975 .64754 L .52608 .64283 L p .707 .577 .707 r
F P
0 g
s
.49988 .83089 m .50109 .81182 L .508 .80869 L p .707 .577 .707 r
F P
0 g
s
.52608 .64283 m .52422 .69945 L .50789 .70415 L p .707 .577 .707 r
F P
0 g
s
.508 .80869 m .5068 .82776 L .49988 .83089 L p .707 .577 .707 r
F P
0 g
s
.5058 .77279 m .50873 .73456 L .52485 .73361 L p .707 .577 .707 r
F P
0 g
s
.52485 .73361 m .52192 .77185 L .5058 .77279 L p .707 .577 .707 r
F P
0 g
s
.52422 .69945 m .52608 .64283 L .55009 .63959 L p .707 .577 .707 r
F P
0 g
s
.55009 .63959 m .54823 .6962 L .52422 .69945 L p .707 .577 .707 r
F P
0 g
s
.5068 .82776 m .508 .80869 L .5242 .80657 L p .707 .577 .707 r
F P
0 g
s
.5242 .80657 m .523 .82564 L .5068 .82776 L p .707 .577 .707 r
F P
0 g
s
.52192 .77185 m .52485 .73361 L .54868 .73376 L p .707 .577 .707 r
F P
0 g
s
.54868 .73376 m .54574 .77199 L .52192 .77185 L p .707 .577 .707 r
F P
0 g
s
.523 .82564 m .5242 .80657 L .5481 .80565 L p .707 .577 .707 r
F P
0 g
s
.5481 .80565 m .5469 .82472 L .523 .82564 L p .707 .577 .707 r
F P
0 g
s
.48971 .32357 m .4942 .82231 L .53914 .82076 L p .707 .577 .707 r
F P
0 g
s
.53914 .82076 m .53465 .32201 L .48971 .32357 L p .707 .577 .707 r
F P
0 g
s
.69773 .82906 m .69653 .84813 L .70344 .84501 L p .707 .577 .707 r
F P
0 g
s
.70344 .84501 m .70465 .82594 L .69773 .82906 L p .707 .577 .707 r
F P
0 g
s
.54823 .6962 m .55009 .63959 L .57944 .63811 L p .707 .577 .707 r
F P
0 g
s
.57944 .63811 m .57758 .69473 L .54823 .6962 L p .707 .577 .707 r
F P
0 g
s
.54574 .77199 m .54868 .73376 L .57788 .73498 L p .707 .577 .707 r
F P
0 g
s
.57788 .73498 m .57495 .77321 L .54574 .77199 L p .707 .577 .707 r
F P
0 g
s
.57495 .77321 m .57788 .73498 L .6096 .73715 L p .707 .577 .707 r
F P
0 g
s
.6096 .73715 m .60667 .77539 L .57495 .77321 L p .707 .577 .707 r
F P
0 g
s
.5469 .82472 m .5481 .80565 L .57737 .80603 L p .707 .577 .707 r
F P
0 g
s
.57737 .80603 m .57616 .8251 L .5469 .82472 L p .707 .577 .707 r
F P
0 g
s
.57616 .8251 m .57737 .80603 L .60912 .80766 L p .707 .577 .707 r
F P
0 g
s
.53465 .32201 m .53914 .82076 L .58062 .81528 L p .707 .577 .707 r
F P
0 g
s
.57758 .69473 m .57944 .63811 L .61126 .63856 L p .707 .577 .707 r
F P
0 g
s
.61126 .63856 m .6094 .69518 L .57758 .69473 L p .707 .577 .707 r
F P
0 g
s
.58062 .81528 m .57613 .31653 L .53465 .32201 L p .707 .577 .707 r
F P
0 g
s
.45019 .81979 m .4457 .32104 L .40694 .31468 L p .707 .577 .707 r
F P
0 g
s
.4457 .32104 m .45019 .81979 L .4942 .82231 L p .707 .577 .707 r
F P
0 g
s
.7053 .75298 m .70236 .79121 L .69924 .78847 L p .707 .577 .707 r
F P
0 g
s
.69924 .78847 m .70218 .75023 L .7053 .75298 L p .707 .577 .707 r
F P
0 g
s
.64074 .74007 m .6378 .77831 L .61405 .77608 L p .707 .577 .707 r
F P
0 g
s
.61405 .77608 m .60667 .77539 L p .61441 .76736 L .707 .577 .707 r
F P
0 g
s
.61441 .76736 m .64074 .74007 L .61405 .77608 L .707 .577 .707 r
F
.66989 .64485 m .66803 .70147 L .64056 .6975 L p F P
0 g
s
.64056 .6975 m .64242 .64088 L .66989 .64485 L p .707 .577 .707 r
F P
0 g
s
.64242 .64088 m .64056 .6975 L .6094 .69518 L p .707 .577 .707 r
F P
0 g
s
.6094 .69518 m .61126 .63856 L .64242 .64088 L p .707 .577 .707 r
F P
0 g
s
.66823 .74345 m .6653 .78168 L .6378 .77831 L p .707 .577 .707 r
F P
0 g
s
.6378 .77831 m .64074 .74007 L .66823 .74345 L p .707 .577 .707 r
F P
0 g
s
.60667 .77539 m .6096 .73715 L .64074 .74007 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .64767 .78221 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63319 .29627 m .63334 .31324 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63334 .31324 m .63768 .79501 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.60792 .82673 m .60912 .80766 L .64027 .81039 L p .707 .577 .707 r
F P
0 g
s
.60912 .80766 m .60792 .82673 L .57616 .8251 L p .707 .577 .707 r
F P
0 g
s
.57613 .31653 m .58062 .81528 L .61457 .8064 L p .707 .577 .707 r
F P
0 g
s
.61457 .8064 m .61008 .30766 L .57613 .31653 L p .707 .577 .707 r
F P
0 g
s
.70359 .65606 m .70173 .71268 L .68911 .7067 L p .707 .577 .707 r
F P
0 g
s
.68911 .7067 m .69096 .65008 L .70359 .65606 L p .707 .577 .707 r
F P
0 g
s
.25311 .69668 m .25497 .64006 L .2238 .63774 L p .707 .577 .707 r
F P
0 g
s
.25497 .64006 m .25311 .69668 L .28493 .69712 L p .707 .577 .707 r
F P
0 g
s
.28493 .69712 m .28678 .64051 L .25497 .64006 L p .707 .577 .707 r
F P
0 g
s
.41143 .81343 m .40694 .31468 L .37721 .30512 L p .707 .577 .707 r
F P
0 g
s
.40694 .31468 m .41143 .81343 L .45019 .81979 L p .707 .577 .707 r
F P
0 g
s
.70465 .82594 m .70344 .84501 L .70039 .8412 L p .707 .577 .707 r
F P
0 g
s
.70039 .8412 m .7016 .82213 L .70465 .82594 L p .707 .577 .707 r
F P
0 g
s
.28678 .64051 m .28493 .69712 L .31428 .69565 L p .707 .577 .707 r
F P
0 g
s
.31428 .69565 m .31614 .63903 L .28678 .64051 L p .707 .577 .707 r
F P
0 g
s
.22195 .69435 m .2238 .63774 L .19634 .63376 L p .707 .577 .707 r
F P
0 g
s
.2238 .63774 m .22195 .69435 L .25311 .69668 L p .707 .577 .707 r
F P
0 g
s
.31614 .63903 m .31428 .69565 L .33829 .69241 L p .707 .577 .707 r
F P
0 g
s
.33829 .69241 m .34015 .63579 L .31614 .63903 L p .707 .577 .707 r
F P
0 g
s
.70218 .75023 m .69924 .78847 L .68647 .78518 L p .707 .577 .707 r
F P
0 g
s
.68647 .78518 m .6894 .74695 L .70218 .75023 L p .707 .577 .707 r
F P
0 g
s
.61008 .30766 m .61457 .8064 L .63768 .79501 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .63319 .29627 L .61008 .30766 L p .707 .577 .707 r
F P
0 g
s
.19634 .63376 m .19448 .69038 L .22195 .69435 L p .707 .577 .707 r
F P
0 g
s
.25165 .75375 m .25459 .71551 L .22346 .71259 L p .707 .577 .707 r
F P
0 g
s
.25459 .71551 m .25165 .75375 L .28337 .75592 L p .707 .577 .707 r
F P
0 g
s
.28337 .75592 m .28631 .71769 L .25459 .71551 L p .707 .577 .707 r
F P
0 g
s
.69096 .65008 m .68911 .7067 L .66803 .70147 L p .707 .577 .707 r
F P
0 g
s
.66803 .70147 m .66989 .64485 L .69096 .65008 L p .707 .577 .707 r
F P
0 g
s
.19448 .69038 m .19634 .63376 L .17526 .62854 L p .707 .577 .707 r
F P
0 g
s
.22346 .71259 m .22052 .75083 L .25165 .75375 L p .707 .577 .707 r
F P
0 g
s
.28631 .71769 m .28337 .75592 L .31257 .75714 L p .707 .577 .707 r
F P
0 g
s
.31257 .75714 m .31551 .71891 L .28631 .71769 L p .707 .577 .707 r
F P
0 g
s
.22052 .75083 m .22346 .71259 L .19596 .70922 L p .707 .577 .707 r
F P
0 g
s
.19596 .70922 m .19302 .74745 L .22052 .75083 L p .707 .577 .707 r
F P
0 g
s
.3817 .80386 m .37721 .30512 L .35943 .29327 L p .707 .577 .707 r
F P
0 g
s
.37721 .30512 m .3817 .80386 L .41143 .81343 L p .707 .577 .707 r
F P
0 g
s
.17526 .62854 m .17341 .68515 L .19448 .69038 L p .707 .577 .707 r
F P
0 g
s
.7016 .82213 m .70039 .8412 L .68768 .83707 L p .707 .577 .707 r
F P
0 g
s
.68768 .83707 m .68889 .818 L .7016 .82213 L p .707 .577 .707 r
F P
0 g
s
.31551 .71891 m .31257 .75714 L .3364 .75729 L p .707 .577 .707 r
F P
0 g
s
.3364 .75729 m .33934 .71905 L .31551 .71891 L p .707 .577 .707 r
F P
0 g
s
.34015 .63579 m .33829 .69241 L .35462 .6877 L p .707 .577 .707 r
F P
0 g
s
.35462 .6877 m .35647 .63108 L .34015 .63579 L p .707 .577 .707 r
F P
0 g
s
.2524 .81235 m .2536 .79328 L .22246 .79055 L p .707 .577 .707 r
F P
0 g
s
.2536 .79328 m .2524 .81235 L .28415 .81398 L p .707 .577 .707 r
F P
0 g
s
.28415 .81398 m .28536 .79491 L .2536 .79328 L p .707 .577 .707 r
F P
0 g
s
.22246 .79055 m .22125 .80962 L .2524 .81235 L p .707 .577 .707 r
F P
0 g
s
.28536 .79491 m .28415 .81398 L .31342 .81436 L p .707 .577 .707 r
F P
0 g
s
.31342 .81436 m .31462 .79529 L .28536 .79491 L p .707 .577 .707 r
F P
0 g
s
.19302 .74745 m .19596 .70922 L .17479 .70572 L p .707 .577 .707 r
F P
0 g
s
.6894 .74695 m .68647 .78518 L .6653 .78168 L p .707 .577 .707 r
F P
0 g
s
.6653 .78168 m .66823 .74345 L .6894 .74695 L p .707 .577 .707 r
F P
0 g
s
.17479 .70572 m .17185 .74395 L .19302 .74745 L p .707 .577 .707 r
F P
0 g
s
.22125 .80962 m .22246 .79055 L .19497 .78699 L p .707 .577 .707 r
F P
0 g
s
.17341 .68515 m .17526 .62854 L .16264 .62256 L p .707 .577 .707 r
F P
0 g
s
.19497 .78699 m .19377 .80606 L .22125 .80962 L p .707 .577 .707 r
F P
0 g
s
.64767 .78221 m .64318 .28347 L .63319 .29627 L p .707 .577 .707 r
F P
0 g
s
.31462 .79529 m .31342 .81436 L .33732 .81344 L p .707 .577 .707 r
F P
0 g
s
.33732 .81344 m .33852 .79437 L .31462 .79529 L p .707 .577 .707 r
F P
0 g
s
.16264 .62256 m .16078 .67918 L .17341 .68515 L p .707 .577 .707 r
F P
0 g
s
.33934 .71905 m .3364 .75729 L .35252 .75634 L p .707 .577 .707 r
F P
0 g
s
.35252 .75634 m .35546 .71811 L .33934 .71905 L p .707 .577 .707 r
F P
0 g
s
.19377 .80606 m .19497 .78699 L .17384 .78294 L p .707 .577 .707 r
F P
0 g
s
.68889 .818 m .68768 .83707 L .66655 .83302 L p .707 .577 .707 r
F P
0 g
s
.66655 .83302 m .66775 .81395 L .68889 .818 L p .707 .577 .707 r
F P
0 g
s
.35647 .63108 m .35462 .6877 L .36166 .682 L p .707 .577 .707 r
F P
0 g
s
.36166 .682 m .36351 .62538 L .35647 .63108 L p .707 .577 .707 r
F P
0 g
s
.17384 .78294 m .17263 .80201 L .19377 .80606 L p .707 .577 .707 r
F P
0 g
s
.17185 .74395 m .17479 .70572 L .16202 .70243 L p .707 .577 .707 r
F P
0 g
s
.16202 .70243 m .15908 .74067 L .17185 .74395 L p .707 .577 .707 r
F P
0 g
s
.36351 .62538 m .36166 .682 L .35872 .67586 L p .707 .577 .707 r
F P
0 g
s
.35872 .67586 m .36058 .61925 L .36351 .62538 L p .707 .577 .707 r
F P
0 g
s
.36392 .79202 m .35943 .29327 L .35534 .28032 L p .707 .577 .707 r
F P
0 g
s
.35943 .29327 m .36392 .79202 L .3817 .80386 L p .707 .577 .707 r
F P
0 g
s
.16078 .67918 m .16264 .62256 L .1597 .61642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79437 m .33732 .81344 L .35352 .81131 L p .707 .577 .707 r
F P
0 g
s
.35352 .81131 m .35472 .79224 L .33852 .79437 L p .707 .577 .707 r
F P
0 g
s
.35546 .71811 m .35252 .75634 L .35935 .7544 L p .707 .577 .707 r
F P
0 g
s
.35935 .7544 m .36229 .71617 L .35546 .71811 L p .707 .577 .707 r
F P
0 g
s
.17263 .80201 m .17384 .78294 L .16112 .77881 L p .707 .577 .707 r
F P
0 g
s
.1597 .61642 m .15785 .67304 L .16078 .67918 L p .707 .577 .707 r
F P
0 g
s
.66775 .81395 m .66655 .83302 L .63906 .82946 L p .707 .577 .707 r
F P
0 g
s
.63906 .82946 m .64027 .81039 L .66775 .81395 L p .707 .577 .707 r
F P
0 g
s
.16112 .77881 m .15992 .79788 L .17263 .80201 L p .707 .577 .707 r
F P
0 g
s
.15908 .74067 m .16202 .70243 L .15889 .69968 L p .707 .577 .707 r
F P
0 g
s
.64318 .28347 m .64767 .78221 L .64492 .77349 L p .707 .577 .707 r
F P
0 g
s
.64356 .74773 m .64318 .28347 L .64492 .77349 L .707 .577 .707 r
F
.64358 .76925 m .63909 .27051 L .64318 .28347 L p F P
0 g
s
.63909 .27051 m .64358 .76925 L .6258 .75741 L p .707 .577 .707 r
F P
0 g
s
.64223 .64848 m .63992 .67852 L p .65206 .69 L .707 .577 .707 r
F P
0 g
s
.63992 .67852 m .63929 .68671 L .64037 .68699 L p .707 .577 .707 r
F P
0 g
s
.64037 .68699 m .65206 .69 L p .63992 .67852 L .707 .577 .707 r
F P
0 g
s
.64492 .77349 m .64358 .76925 L p .64356 .74773 L .707 .577 .707 r
F P
0 g
s
.15889 .69968 m .15596 .73792 L .15908 .74067 L p .707 .577 .707 r
F P
0 g
s
.64027 .81039 m .63906 .82946 L .60792 .82673 L p .707 .577 .707 r
F P
0 g
s
.35472 .79224 m .35352 .81131 L .36043 .80819 L p .707 .577 .707 r
F P
0 g
s
.36043 .80819 m .36164 .78912 L .35472 .79224 L p .707 .577 .707 r
F P
0 g
s
.15785 .67304 m .1597 .61642 L .16674 .61072 L p .707 .577 .707 r
F P
0 g
s
.15992 .79788 m .16112 .77881 L .15808 .775 L p .707 .577 .707 r
F P
0 g
s
.36229 .71617 m .35935 .7544 L .35623 .75165 L p .707 .577 .707 r
F P
0 g
s
.35623 .75165 m .35917 .71342 L .36229 .71617 L p .707 .577 .707 r
F P
0 g
s
.36058 .61925 m .35872 .67586 L .3461 .66989 L p .707 .577 .707 r
F P
0 g
s
.3461 .66989 m .34795 .61327 L .36058 .61925 L p .707 .577 .707 r
F P
0 g
s
.35534 .28032 m .35982 .77906 L .36392 .79202 L p .707 .577 .707 r
F P
0 g
s
.35982 .77906 m .35534 .28032 L .36533 .26752 L p .707 .577 .707 r
F P
0 g
s
.15808 .775 m .15687 .79407 L .15992 .79788 L p .707 .577 .707 r
F P
0 g
s
.16674 .61072 m .16489 .66734 L .15785 .67304 L p .707 .577 .707 r
F P
0 g
s
.15596 .73792 m .15889 .69968 L .16573 .69774 L p .707 .577 .707 r
F P
0 g
s
.16573 .69774 m .16279 .73598 L .15596 .73792 L p .707 .577 .707 r
F P
0 g
s
.36164 .78912 m .36043 .80819 L .35739 .80438 L p .707 .577 .707 r
F P
0 g
s
.35739 .80438 m .35859 .78531 L .36164 .78912 L p .707 .577 .707 r
F P
0 g
s
.16489 .66734 m .16674 .61072 L .18307 .60602 L p .707 .577 .707 r
F P
0 g
s
.6258 .75741 m .62131 .25867 L .63909 .27051 L p .707 .577 .707 r
F P
0 g
s
.15687 .79407 m .15808 .775 L .16499 .77188 L p .707 .577 .707 r
F P
0 g
s
.18307 .60602 m .18121 .66264 L .16489 .66734 L p .707 .577 .707 r
F P
0 g
s
.35917 .71342 m .35623 .75165 L .34346 .74837 L p .707 .577 .707 r
F P
0 g
s
.34346 .74837 m .3464 .71013 L .35917 .71342 L p .707 .577 .707 r
F P
0 g
s
.16499 .77188 m .16379 .79095 L .15687 .79407 L p .707 .577 .707 r
F P
0 g
s
.34795 .61327 m .3461 .66989 L .32502 .66466 L p .707 .577 .707 r
F P
0 g
s
.32502 .66466 m .32688 .60804 L .34795 .61327 L p .707 .577 .707 r
F P
0 g
s
.36982 .76626 m .36533 .26752 L .38844 .25612 L p .707 .577 .707 r
F P
0 g
s
.36533 .26752 m .36982 .76626 L .35982 .77906 L p .707 .577 .707 r
F P
0 g
s
.16279 .73598 m .16573 .69774 L .18184 .6968 L p .707 .577 .707 r
F P
0 g
s
.18184 .6968 m .17891 .73503 L .16279 .73598 L p .707 .577 .707 r
F P
0 g
s
.18121 .66264 m .18307 .60602 L .20708 .60277 L p .707 .577 .707 r
F P
0 g
s
.35859 .78531 m .35739 .80438 L .34467 .80025 L p .707 .577 .707 r
F P
0 g
s
.34467 .80025 m .34588 .78118 L .35859 .78531 L p .707 .577 .707 r
F P
0 g
s
.20708 .60277 m .20522 .65939 L .18121 .66264 L p .707 .577 .707 r
F P
0 g
s
.16379 .79095 m .16499 .77188 L .18119 .76976 L p .707 .577 .707 r
F P
0 g
s
.3464 .71013 m .34346 .74837 L .32229 .74487 L p .707 .577 .707 r
F P
0 g
s
.32229 .74487 m .32522 .70663 L .3464 .71013 L p .707 .577 .707 r
F P
0 g
s
.32688 .60804 m .32502 .66466 L .29755 .66069 L p .707 .577 .707 r
F P
0 g
s
.29755 .66069 m .29941 .60407 L .32688 .60804 L p .707 .577 .707 r
F P
0 g
s
.18119 .76976 m .17999 .78883 L .16379 .79095 L p .707 .577 .707 r
F P
0 g
s
.62131 .25867 m .6258 .75741 L .59607 .74784 L p .707 .577 .707 r
F P
0 g
s
.59607 .74784 m .59158 .2491 L .62131 .25867 L p .707 .577 .707 r
F P
0 g
s
.20522 .65939 m .20708 .60277 L .23643 .6013 L p .707 .577 .707 r
F P
0 g
s
.17891 .73503 m .18184 .6968 L .20567 .69694 L p .707 .577 .707 r
F P
0 g
s
.20567 .69694 m .20273 .73518 L .17891 .73503 L p .707 .577 .707 r
F P
0 g
s
.29941 .60407 m .29755 .66069 L .26639 .65837 L p .707 .577 .707 r
F P
0 g
s
.26639 .65837 m .26825 .60175 L .29941 .60407 L p .707 .577 .707 r
F P
0 g
s
.38844 .25612 m .39292 .75487 L .36982 .76626 L p .707 .577 .707 r
F P
0 g
s
.39292 .75487 m .38844 .25612 L .42239 .24725 L p .707 .577 .707 r
F P
0 g
s
.23643 .6013 m .23457 .65792 L .20522 .65939 L p .707 .577 .707 r
F P
0 g
s
.34588 .78118 m .34467 .80025 L .32354 .79621 L p .707 .577 .707 r
F P
0 g
s
.32354 .79621 m .32474 .77714 L .34588 .78118 L p .707 .577 .707 r
F P
0 g
s
.23457 .65792 m .23643 .6013 L .26825 .60175 L p .707 .577 .707 r
F P
0 g
s
.26825 .60175 m .26639 .65837 L .23457 .65792 L p .707 .577 .707 r
F P
0 g
s
.32522 .70663 m .32229 .74487 L .29479 .74149 L p .707 .577 .707 r
F P
0 g
s
.29479 .74149 m .29773 .70326 L .32522 .70663 L p .707 .577 .707 r
F P
0 g
s
.73333 .65704 m .73518 .60042 L .70402 .5981 L p .707 .577 .707 r
F P
0 g
s
.73518 .60042 m .73333 .65704 L .76514 .65749 L p .707 .577 .707 r
F P
0 g
s
.76514 .65749 m .767 .60087 L .73518 .60042 L p .707 .577 .707 r
F P
0 g
s
.17999 .78883 m .18119 .76976 L .20509 .76884 L p .707 .577 .707 r
F P
0 g
s
.767 .60087 m .76514 .65749 L .79449 .65602 L p .707 .577 .707 r
F P
0 g
s
.79449 .65602 m .79635 .5994 L .767 .60087 L p .707 .577 .707 r
F P
0 g
s
.20509 .76884 m .20389 .78791 L .17999 .78883 L p .707 .577 .707 r
F P
0 g
s
.20273 .73518 m .20567 .69694 L .23487 .69816 L p .707 .577 .707 r
F P
0 g
s
.70216 .65472 m .70402 .5981 L .67655 .59413 L p .707 .577 .707 r
F P
0 g
s
.70402 .5981 m .70216 .65472 L .73333 .65704 L p .707 .577 .707 r
F P
0 g
s
.23487 .69816 m .23194 .7364 L .20273 .73518 L p .707 .577 .707 r
F P
0 g
s
.59158 .2491 m .59607 .74784 L .55731 .74149 L p .707 .577 .707 r
F P
0 g
s
.55731 .74149 m .55282 .24274 L .59158 .2491 L p .707 .577 .707 r
F P
0 g
s
.29773 .70326 m .29479 .74149 L .26366 .73857 L p .707 .577 .707 r
F P
0 g
s
.26366 .73857 m .26659 .70034 L .29773 .70326 L p .707 .577 .707 r
F P
0 g
s
.79635 .5994 m .79449 .65602 L .81851 .65277 L p .707 .577 .707 r
F P
0 g
s
.81851 .65277 m .82036 .59615 L .79635 .5994 L p .707 .577 .707 r
F P
0 g
s
.73186 .69979 m .7348 .66156 L .70367 .65864 L p .707 .577 .707 r
F P
0 g
s
.7348 .66156 m .73186 .69979 L .76358 .70197 L p .707 .577 .707 r
F P
0 g
s
.76358 .70197 m .76652 .66373 L .7348 .66156 L p .707 .577 .707 r
F P
0 g
s
.32474 .77714 m .32354 .79621 L .29606 .79265 L p .707 .577 .707 r
F P
0 g
s
.29606 .79265 m .29726 .77358 L .32474 .77714 L p .707 .577 .707 r
F P
0 g
s
.23194 .7364 m .23487 .69816 L .26659 .70034 L p .707 .577 .707 r
F P
0 g
s
.67655 .59413 m .6747 .65075 L .70216 .65472 L p .707 .577 .707 r
F P
0 g
s
.70367 .65864 m .70073 .69687 L .73186 .69979 L p .707 .577 .707 r
F P
0 g
s
.76652 .66373 m .76358 .70197 L .79279 .70319 L p .707 .577 .707 r
F P
0 g
s
.79279 .70319 m .79573 .66495 L .76652 .66373 L p .707 .577 .707 r
F P
0 g
s
.26659 .70034 m .26366 .73857 L .23194 .7364 L p .707 .577 .707 r
F P
0 g
s
.42688 .74599 m .42239 .24725 L .46387 .24177 L p .707 .577 .707 r
F P
0 g
s
.42239 .24725 m .42665 .72043 L p .39292 .75487 L .707 .577 .707 r
F P
0 g
s
.46387 .24177 m .46836 .74051 L .42688 .74599 L p .707 .577 .707 r
F P
0 g
s
.42351 .62692 m .42057 .66515 L .44732 .66627 L p .707 .577 .707 r
F P
0 g
s
.44732 .66627 m .44978 .66637 L p .44819 .66399 L .707 .577 .707 r
F P
0 g
s
.44819 .66399 m .42351 .62692 L .44732 .66627 L .707 .577 .707 r
F
.42665 .72043 m .42688 .74599 L .41578 .74889 L p F P
0 g
s
.41578 .74889 m .39292 .75487 L p .42665 .72043 L .707 .577 .707 r
F P
0 g
s
.6747 .65075 m .67655 .59413 L .65548 .5889 L p .707 .577 .707 r
F P
0 g
s
.70073 .69687 m .70367 .65864 L .67617 .65526 L p .707 .577 .707 r
F P
0 g
s
.20389 .78791 m .20509 .76884 L .23436 .76921 L p .707 .577 .707 r
F P
0 g
s
.23436 .76921 m .23315 .78828 L .20389 .78791 L p .707 .577 .707 r
F P
0 g
s
.67617 .65526 m .67323 .6935 L .70073 .69687 L p .707 .577 .707 r
F P
0 g
s
.73261 .7313 m .73381 .71223 L .70267 .7095 L p .707 .577 .707 r
F P
0 g
s
.73381 .71223 m .73261 .7313 L .76437 .73294 L p .707 .577 .707 r
F P
0 g
s
.76437 .73294 m .76557 .71387 L .73381 .71223 L p .707 .577 .707 r
F P
0 g
s
.70267 .7095 m .70146 .72857 L .73261 .7313 L p .707 .577 .707 r
F P
0 g
s
.76557 .71387 m .76437 .73294 L .79363 .73331 L p .707 .577 .707 r
F P
0 g
s
.79363 .73331 m .79483 .71424 L .76557 .71387 L p .707 .577 .707 r
F P
0 g
s
.55282 .24274 m .55731 .74149 L .5133 .73896 L p .707 .577 .707 r
F P
0 g
s
.5133 .73896 m .50881 .24022 L .55282 .24274 L p .707 .577 .707 r
F P
0 g
s
.79573 .66495 m .79279 .70319 L .81661 .70333 L p .707 .577 .707 r
F P
0 g
s
.81661 .70333 m .81955 .6651 L .79573 .66495 L p .707 .577 .707 r
F P
0 g
s
.29726 .77358 m .29606 .79265 L .26491 .78991 L p .707 .577 .707 r
F P
0 g
s
.26491 .78991 m .26611 .77084 L .29726 .77358 L p .707 .577 .707 r
F P
0 g
s
.65548 .5889 m .65362 .64552 L .6747 .65075 L p .707 .577 .707 r
F P
0 g
s
.70146 .72857 m .70267 .7095 L .67518 .70594 L p .707 .577 .707 r
F P
0 g
s
.23315 .78828 m .23436 .76921 L .26611 .77084 L p .707 .577 .707 r
F P
0 g
s
.67518 .70594 m .67398 .72501 L .70146 .72857 L p .707 .577 .707 r
F P
0 g
s
.82036 .59615 m .81851 .65277 L .83483 .64807 L p .707 .577 .707 r
F P
0 g
s
.83483 .64807 m .83669 .59145 L .82036 .59615 L p .707 .577 .707 r
F P
0 g
s
.46836 .74051 m .46387 .24177 L .50881 .24022 L p .707 .577 .707 r
F P
0 g
s
.26611 .77084 m .26491 .78991 L .23315 .78828 L p .707 .577 .707 r
F P
0 g
s
.67323 .6935 m .67617 .65526 L .655 .65176 L p .707 .577 .707 r
F P
0 g
s
.50881 .24022 m .5133 .73896 L .46836 .74051 L p .707 .577 .707 r
F P
0 g
s
.655 .65176 m .65206 .69 L .67323 .6935 L p .707 .577 .707 r
F P
0 g
s
.79483 .71424 m .79363 .73331 L .81753 .73239 L p .707 .577 .707 r
F P
0 g
s
.81753 .73239 m .81874 .71332 L .79483 .71424 L p .707 .577 .707 r
F P
0 g
s
.65362 .64552 m .65548 .5889 L .64285 .58292 L p .707 .577 .707 r
F P
0 g
s
.67398 .72501 m .67518 .70594 L .65405 .7019 L p .707 .577 .707 r
F P
0 g
s
.65405 .7019 m .65285 .72097 L .67398 .72501 L p .707 .577 .707 r
F P
0 g
s
.81955 .6651 m .81661 .70333 L .83273 .70239 L p .707 .577 .707 r
F P
0 g
s
.83273 .70239 m .83567 .66415 L .81955 .6651 L p .707 .577 .707 r
F P
0 g
s
.64285 .58292 m .641 .63954 L .65362 .64552 L p .707 .577 .707 r
F P
0 g
s
.65206 .69 m .655 .65176 L .64223 .64848 L p .707 .577 .707 r
F P
0 g
s
.83669 .59145 m .83483 .64807 L .84187 .64237 L p .707 .577 .707 r
F P
0 g
s
.84187 .64237 m .84373 .58575 L .83669 .59145 L p .707 .577 .707 r
F P
0 g
s
.81874 .71332 m .81753 .73239 L .83373 .73027 L p .707 .577 .707 r
F P
0 g
s
.83373 .73027 m .83494 .7112 L .81874 .71332 L p .707 .577 .707 r
F P
0 g
s
.65285 .72097 m .65405 .7019 L .64134 .69777 L p .707 .577 .707 r
F P
0 g
s
.641 .63954 m .64285 .58292 L .63992 .57679 L p .707 .577 .707 r
F P
0 g
s
.64134 .69777 m .64013 .71684 L .65285 .72097 L p .707 .577 .707 r
F P
0 g
s
.83567 .66415 m .83273 .70239 L .83957 .70045 L p .707 .577 .707 r
F P
0 g
s
.83957 .70045 m .8425 .66221 L .83567 .66415 L p .707 .577 .707 r
F P
0 g
s
.63992 .57679 m .63806 .6334 L .641 .63954 L p .707 .577 .707 r
F P
0 g
s
.63929 .68671 m .64223 .64848 L .63911 .64573 L p .707 .577 .707 r
F P
0 g
s
.83494 .7112 m .83373 .73027 L .84065 .72715 L p .707 .577 .707 r
F P
0 g
s
.84065 .72715 m .84185 .70808 L .83494 .7112 L p .707 .577 .707 r
F P
0 g
s
.84373 .58575 m .84187 .64237 L .83893 .63623 L p .707 .577 .707 r
F P
0 g
s
.83893 .63623 m .84079 .57961 L .84373 .58575 L p .707 .577 .707 r
F P
0 g
s
.63911 .64573 m .63617 .68396 L .63929 .68671 L p .707 .577 .707 r
F P
0 g
s
.64013 .71684 m .64134 .69777 L .63829 .69396 L p .707 .577 .707 r
F P
0 g
s
.63829 .69396 m .63709 .71303 L .64013 .71684 L p .707 .577 .707 r
F P
0 g
s
.63806 .6334 m .63992 .57679 L .64696 .57109 L p .707 .577 .707 r
F P
0 g
s
.8425 .66221 m .83957 .70045 L .83644 .6977 L p .707 .577 .707 r
F P
0 g
s
.83644 .6977 m .83938 .65946 L .8425 .66221 L p .707 .577 .707 r
F P
0 g
s
.64696 .57109 m .6451 .6277 L .63806 .6334 L p .707 .577 .707 r
F P
0 g
s
.63617 .68396 m .63911 .64573 L .64594 .64379 L p .707 .577 .707 r
F P
0 g
s
.84185 .70808 m .84065 .72715 L .8376 .72334 L p .707 .577 .707 r
F P
0 g
s
.8376 .72334 m .8388 .70427 L .84185 .70808 L p .707 .577 .707 r
F P
0 g
s
.84079 .57961 m .83893 .63623 L .82631 .63025 L p .707 .577 .707 r
F P
0 g
s
.82631 .63025 m .82817 .57363 L .84079 .57961 L p .707 .577 .707 r
F P
0 g
s
.64594 .64379 m .643 .68202 L .63617 .68396 L p .707 .577 .707 r
F P
0 g
s
.39032 .62023 m .39217 .56361 L .36101 .56129 L p .707 .577 .707 r
F P
0 g
s
.39217 .56361 m .39032 .62023 L .42213 .62067 L p .707 .577 .707 r
F P
0 g
s
.42213 .62067 m .42399 .56406 L .39217 .56361 L p .707 .577 .707 r
F P
0 g
s
.63709 .71303 m .63829 .69396 L .64521 .69083 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42399 .56406 m .42213 .62067 L .45148 .6192 L p .707 .577 .707 r
F P
0 g
s
.45148 .6192 m .45334 .56258 L .42399 .56406 L p .707 .577 .707 r
F P
0 g
s
.64521 .69083 m .644 .70991 L .63709 .71303 L p .707 .577 .707 r
F P
0 g
s
.6451 .6277 m .64696 .57109 L .66328 .56638 L p .707 .577 .707 r
F P
0 g
s
.35915 .6179 m .36101 .56129 L .33354 .55731 L p .707 .577 .707 r
F P
0 g
s
.36101 .56129 m .35915 .6179 L .39032 .62023 L p .707 .577 .707 r
F P
0 g
s
.83938 .65946 m .83644 .6977 L .82367 .69441 L p .707 .577 .707 r
F P
0 g
s
.82367 .69441 m .82661 .65618 L .83938 .65946 L p .707 .577 .707 r
F P
0 g
s
.66328 .56638 m .66142 .623 L .6451 .6277 L p .707 .577 .707 r
F P
0 g
s
.45334 .56258 m .45148 .6192 L .4755 .61596 L p .707 .577 .707 r
F P
0 g
s
.4755 .61596 m .47735 .55934 L .45334 .56258 L p .707 .577 .707 r
F P
0 g
s
.38885 .66298 m .39179 .62474 L .36066 .62182 L p .707 .577 .707 r
F P
0 g
s
.39179 .62474 m .38885 .66298 L .42057 .66515 L p .707 .577 .707 r
F P
0 g
s
.42057 .66515 m .42351 .62692 L .39179 .62474 L p .707 .577 .707 r
F P
0 g
s
.33354 .55731 m .33169 .61393 L .35915 .6179 L p .707 .577 .707 r
F P
0 g
s
.36066 .62182 m .35772 .66006 L .38885 .66298 L p .707 .577 .707 r
F P
0 g
s
.44978 .66637 m .45272 .62814 L .42351 .62692 L p .707 .577 .707 r
F P
0 g
s
.82817 .57363 m .82631 .63025 L .80523 .62502 L p .707 .577 .707 r
F P
0 g
s
.80523 .62502 m .80709 .56841 L .82817 .57363 L p .707 .577 .707 r
F P
0 g
s
.643 .68202 m .64594 .64379 L .66206 .64284 L p .707 .577 .707 r
F P
0 g
s
.33169 .61393 m .33354 .55731 L .31247 .55209 L p .707 .577 .707 r
F P
0 g
s
.35772 .66006 m .36066 .62182 L .33316 .61845 L p .707 .577 .707 r
F P
0 g
s
.8388 .70427 m .8376 .72334 L .82489 .71921 L p .707 .577 .707 r
F P
0 g
s
.82489 .71921 m .82609 .70014 L .8388 .70427 L p .707 .577 .707 r
F P
0 g
s
.66206 .64284 m .65912 .68108 L .643 .68202 L p .707 .577 .707 r
F P
0 g
s
.33316 .61845 m .33022 .65668 L .35772 .66006 L p .707 .577 .707 r
F P
0 g
s
.3896 .69449 m .3908 .67542 L .35966 .67269 L p .707 .577 .707 r
F P
0 g
s
.3908 .67542 m .3896 .69449 L .42136 .69612 L p .707 .577 .707 r
F P
0 g
s
.42136 .69612 m .42256 .67705 L .3908 .67542 L p .707 .577 .707 r
F P
0 g
s
.35966 .67269 m .35845 .69176 L .3896 .69449 L p .707 .577 .707 r
F P
0 g
s
.42256 .67705 m .42136 .69612 L .45062 .6965 L p .707 .577 .707 r
F P
0 g
s
.45062 .6965 m .45182 .67743 L .42256 .67705 L p .707 .577 .707 r
F P
0 g
s
.66142 .623 m .66328 .56638 L .68729 .56314 L p .707 .577 .707 r
F P
0 g
s
.45272 .62814 m .44978 .66637 L .4736 .66652 L p .707 .577 .707 r
F P
0 g
s
.4736 .66652 m .47654 .62828 L .45272 .62814 L p .707 .577 .707 r
F P
0 g
s
.644 .70991 m .64521 .69083 L .66141 .68871 L p .707 .577 .707 r
F P
0 g
s
.31247 .55209 m .31061 .6087 L .33169 .61393 L p .707 .577 .707 r
F P
0 g
s
.35845 .69176 m .35966 .67269 L .33217 .66913 L p .707 .577 .707 r
F P
0 g
s
.66141 .68871 m .6602 .70778 L .644 .70991 L p .707 .577 .707 r
F P
0 g
s
.33217 .66913 m .33097 .6882 L .35845 .69176 L p .707 .577 .707 r
F P
0 g
s
.47735 .55934 m .4755 .61596 L .49182 .61125 L p .707 .577 .707 r
F P
0 g
s
.49182 .61125 m .49368 .55463 L .47735 .55934 L p .707 .577 .707 r
F P
0 g
s
.33022 .65668 m .33316 .61845 L .31199 .61495 L p .707 .577 .707 r
F P
0 g
s
.82661 .65618 m .82367 .69441 L .8025 .69091 L p .707 .577 .707 r
F P
0 g
s
.8025 .69091 m .80544 .65268 L .82661 .65618 L p .707 .577 .707 r
F P
0 g
s
.31199 .61495 m .30905 .65318 L .33022 .65668 L p .707 .577 .707 r
F P
0 g
s
.68729 .56314 m .68544 .61975 L .66142 .623 L p .707 .577 .707 r
F P
0 g
s
.45182 .67743 m .45062 .6965 L .47452 .69558 L p .707 .577 .707 r
F P
0 g
s
.47452 .69558 m .47573 .67651 L .45182 .67743 L p .707 .577 .707 r
F P
0 g
s
.80709 .56841 m .80523 .62502 L .77777 .62105 L p .707 .577 .707 r
F P
0 g
s
.77777 .62105 m .77963 .56443 L .80709 .56841 L p .707 .577 .707 r
F P
0 g
s
.31061 .6087 m .31247 .55209 L .29984 .54611 L p .707 .577 .707 r
F P
0 g
s
.65912 .68108 m .66206 .64284 L .68588 .64299 L p .707 .577 .707 r
F P
0 g
s
.33097 .6882 m .33217 .66913 L .31104 .66508 L p .707 .577 .707 r
F P
0 g
s
.82609 .70014 m .82489 .71921 L .80375 .71516 L p .707 .577 .707 r
F P
0 g
s
.80375 .71516 m .80496 .69609 L .82609 .70014 L p .707 .577 .707 r
F P
0 g
s
.31104 .66508 m .30984 .68415 L .33097 .6882 L p .707 .577 .707 r
F P
0 g
s
.68544 .61975 m .68729 .56314 L .71664 .56166 L p .707 .577 .707 r
F P
0 g
s
.68588 .64299 m .68295 .68122 L .65912 .68108 L p .707 .577 .707 r
F P
0 g
s
.47654 .62828 m .4736 .66652 L .48972 .66557 L p .707 .577 .707 r
F P
0 g
s
.48972 .66557 m .49266 .62734 L .47654 .62828 L p .707 .577 .707 r
F P
0 g
s
.29984 .54611 m .29799 .60273 L .31061 .6087 L p .707 .577 .707 r
F P
0 g
s
.6602 .70778 m .66141 .68871 L .68531 .68779 L p .707 .577 .707 r
F P
0 g
s
.77963 .56443 m .77777 .62105 L .7466 .61873 L p .707 .577 .707 r
F P
0 g
s
.7466 .61873 m .74846 .56211 L .77963 .56443 L p .707 .577 .707 r
F P
0 g
s
.30905 .65318 m .31199 .61495 L .29922 .61166 L p .707 .577 .707 r
F P
0 g
s
.68531 .68779 m .6841 .70686 L .6602 .70778 L p .707 .577 .707 r
F P
0 g
s
.71664 .56166 m .71479 .61828 L .68544 .61975 L p .707 .577 .707 r
F P
0 g
s
.49368 .55463 m .49182 .61125 L .49886 .60555 L p .707 .577 .707 r
F P
0 g
s
.49886 .60555 m .50072 .54893 L .49368 .55463 L p .707 .577 .707 r
F P
0 g
s
.80544 .65268 m .8025 .69091 L .775 .68754 L p .707 .577 .707 r
F P
0 g
s
.775 .68754 m .77794 .6493 L .80544 .65268 L p .707 .577 .707 r
F P
0 g
s
.47573 .67651 m .47452 .69558 L .49072 .69345 L p .707 .577 .707 r
F P
0 g
s
.49072 .69345 m .49193 .67438 L .47573 .67651 L p .707 .577 .707 r
F P
0 g
s
.71479 .61828 m .71664 .56166 L .74846 .56211 L p .707 .577 .707 r
F P
0 g
s
.29922 .61166 m .29628 .6499 L .30905 .65318 L p .707 .577 .707 r
F P
0 g
s
.74846 .56211 m .7466 .61873 L .71479 .61828 L p .707 .577 .707 r
F P
0 g
s
.68295 .68122 m .68588 .64299 L .71509 .64421 L p .707 .577 .707 r
F P
0 g
s
.30984 .68415 m .31104 .66508 L .29833 .66095 L p .707 .577 .707 r
F P
0 g
s
.71509 .64421 m .71215 .68244 L .68295 .68122 L p .707 .577 .707 r
F P
0 g
s
.29799 .60273 m .29984 .54611 L .29691 .53997 L p .707 .577 .707 r
F P
0 g
s
.80496 .69609 m .80375 .71516 L .77627 .7116 L p .707 .577 .707 r
F P
0 g
s
.77627 .7116 m .77747 .69253 L .80496 .69609 L p .707 .577 .707 r
F P
0 g
s
.29833 .66095 m .29712 .68002 L .30984 .68415 L p .707 .577 .707 r
F P
0 g
s
.77794 .6493 m .775 .68754 L .74387 .68462 L p .707 .577 .707 r
F P
0 g
s
.74387 .68462 m .74681 .64638 L .77794 .6493 L p .707 .577 .707 r
F P
0 g
s
.49266 .62734 m .48972 .66557 L .49656 .66363 L p .707 .577 .707 r
F P
0 g
s
.49656 .66363 m .49949 .6254 L .49266 .62734 L p .707 .577 .707 r
F P
0 g
s
.6841 .70686 m .68531 .68779 L .71457 .68817 L p .707 .577 .707 r
F P
0 g
s
.71215 .68244 m .71509 .64421 L .74681 .64638 L p .707 .577 .707 r
F P
0 g
s
.71457 .68817 m .71337 .70724 L .6841 .70686 L p .707 .577 .707 r
F P
0 g
s
.29691 .53997 m .29505 .59659 L .29799 .60273 L p .707 .577 .707 r
F P
0 g
s
.74681 .64638 m .74387 .68462 L .71215 .68244 L p .707 .577 .707 r
F P
0 g
s
.29628 .6499 m .29922 .61166 L .2961 .60891 L p .707 .577 .707 r
F P
0 g
s
.77747 .69253 m .77627 .7116 L .74512 .70887 L p .707 .577 .707 r
F P
0 g
s
.74512 .70887 m .74633 .6898 L .77747 .69253 L p .707 .577 .707 r
F P
0 g
s
.49193 .67438 m .49072 .69345 L .49764 .69033 L p .707 .577 .707 r
F P
0 g
s
.49764 .69033 m .49884 .67126 L .49193 .67438 L p .707 .577 .707 r
F P
0 g
s
.50072 .54893 m .49886 .60555 L .49592 .59941 L p .707 .577 .707 r
F P
0 g
s
.49592 .59941 m .49778 .5428 L .50072 .54893 L p .707 .577 .707 r
F P
0 g
s
.2961 .60891 m .29316 .64715 L .29628 .6499 L p .707 .577 .707 r
F P
0 g
s
.71337 .70724 m .71457 .68817 L .74633 .6898 L p .707 .577 .707 r
F P
0 g
s
.74633 .6898 m .74512 .70887 L .71337 .70724 L p .707 .577 .707 r
F P
0 g
s
.29712 .68002 m .29833 .66095 L .29528 .65714 L p .707 .577 .707 r
F P
0 g
s
.29528 .65714 m .29407 .67621 L .29712 .68002 L p .707 .577 .707 r
F P
0 g
s
.29505 .59659 m .29691 .53997 L .30394 .53427 L p .707 .577 .707 r
F P
0 g
s
.49949 .6254 m .49656 .66363 L .49343 .66088 L p .707 .577 .707 r
F P
0 g
s
.49343 .66088 m .49637 .62265 L .49949 .6254 L p .707 .577 .707 r
F P
0 g
s
.30394 .53427 m .30209 .59089 L .29505 .59659 L p .707 .577 .707 r
F P
0 g
s
.29316 .64715 m .2961 .60891 L .30293 .60697 L p .707 .577 .707 r
F P
0 g
s
.49884 .67126 m .49764 .69033 L .49459 .68652 L p .707 .577 .707 r
F P
0 g
s
.49459 .68652 m .49579 .66745 L .49884 .67126 L p .707 .577 .707 r
F P
0 g
s
.49778 .5428 m .49592 .59941 L .4833 .59344 L p .707 .577 .707 r
F P
0 g
s
.4833 .59344 m .48516 .53682 L .49778 .5428 L p .707 .577 .707 r
F P
0 g
s
.30293 .60697 m .29999 .64521 L .29316 .64715 L p .707 .577 .707 r
F P
0 g
s
.29407 .67621 m .29528 .65714 L .30219 .65402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30219 .65402 m .30099 .67309 L .29407 .67621 L p .707 .577 .707 r
F P
0 g
s
.30209 .59089 m .30394 .53427 L .32027 .52957 L p .707 .577 .707 r
F P
0 g
s
.49637 .62265 m .49343 .66088 L .48066 .6576 L p .707 .577 .707 r
F P
0 g
s
.48066 .6576 m .4836 .61936 L .49637 .62265 L p .707 .577 .707 r
F P
0 g
s
.32027 .52957 m .31841 .58619 L .30209 .59089 L p .707 .577 .707 r
F P
0 g
s
.48516 .53682 m .4833 .59344 L .46222 .58821 L p .707 .577 .707 r
F P
0 g
s
.46222 .58821 m .46408 .53159 L .48516 .53682 L p .707 .577 .707 r
F P
0 g
s
.29999 .64521 m .30293 .60697 L .31905 .60603 L p .707 .577 .707 r
F P
0 g
s
.49579 .66745 m .49459 .68652 L .48188 .68239 L p .707 .577 .707 r
F P
0 g
s
.48188 .68239 m .48308 .66332 L .49579 .66745 L p .707 .577 .707 r
F P
0 g
s
.31905 .60603 m .31611 .64426 L .29999 .64521 L p .707 .577 .707 r
F P
0 g
s
.31841 .58619 m .32027 .52957 L .34428 .52632 L p .707 .577 .707 r
F P
0 g
s
.30099 .67309 m .30219 .65402 L .3184 .6519 L p .707 .577 .707 r
F P
0 g
s
.3184 .6519 m .31719 .67097 L .30099 .67309 L p .707 .577 .707 r
F P
0 g
s
.4836 .61936 m .48066 .6576 L .45949 .65409 L p .707 .577 .707 r
F P
0 g
s
.45949 .65409 m .46243 .61586 L .4836 .61936 L p .707 .577 .707 r
F P
0 g
s
.34428 .52632 m .34243 .58294 L .31841 .58619 L p .707 .577 .707 r
F P
0 g
s
.46408 .53159 m .46222 .58821 L .43476 .58424 L p .707 .577 .707 r
F P
0 g
s
.43476 .58424 m .43661 .52762 L .46408 .53159 L p .707 .577 .707 r
F P
0 g
s
.31611 .64426 m .31905 .60603 L .34287 .60617 L p .707 .577 .707 r
F P
0 g
s
.48308 .66332 m .48188 .68239 L .46074 .67835 L p .707 .577 .707 r
F P
0 g
s
.46074 .67835 m .46195 .65928 L .48308 .66332 L p .707 .577 .707 r
F P
0 g
s
.34243 .58294 m .34428 .52632 L .37363 .52485 L p .707 .577 .707 r
F P
0 g
s
.34287 .60617 m .33994 .64441 L .31611 .64426 L p .707 .577 .707 r
F P
0 g
s
.31719 .67097 m .3184 .6519 L .3423 .65098 L p .707 .577 .707 r
F P
0 g
s
.43661 .52762 m .43476 .58424 L .40359 .58192 L p .707 .577 .707 r
F P
0 g
s
.40359 .58192 m .40545 .5253 L .43661 .52762 L p .707 .577 .707 r
F P
0 g
s
.3423 .65098 m .34109 .67005 L .31719 .67097 L p .707 .577 .707 r
F P
0 g
s
.37363 .52485 m .37178 .58147 L .34243 .58294 L p .707 .577 .707 r
F P
0 g
s
.46243 .61586 m .45949 .65409 L .43199 .65072 L p .707 .577 .707 r
F P
0 g
s
.43199 .65072 m .43493 .61249 L .46243 .61586 L p .707 .577 .707 r
F P
0 g
s
.37178 .58147 m .37363 .52485 L .40545 .5253 L p .707 .577 .707 r
F P
0 g
s
.40545 .5253 m .40359 .58192 L .37178 .58147 L p .707 .577 .707 r
F P
0 g
s
.33994 .64441 m .34287 .60617 L .37208 .60739 L p .707 .577 .707 r
F P
0 g
s
.37208 .60739 m .36914 .64563 L .33994 .64441 L p .707 .577 .707 r
F P
0 g
s
.46195 .65928 m .46074 .67835 L .43326 .67479 L p .707 .577 .707 r
F P
0 g
s
.43326 .67479 m .43446 .65572 L .46195 .65928 L p .707 .577 .707 r
F P
0 g
s
.43493 .61249 m .43199 .65072 L .40086 .6478 L p .707 .577 .707 r
F P
0 g
s
.40086 .6478 m .4038 .60957 L .43493 .61249 L p .707 .577 .707 r
F P
0 g
s
.34109 .67005 m .3423 .65098 L .37156 .65135 L p .707 .577 .707 r
F P
0 g
s
.36914 .64563 m .37208 .60739 L .4038 .60957 L p .707 .577 .707 r
F P
0 g
s
.37156 .65135 m .37035 .67042 L .34109 .67005 L p .707 .577 .707 r
F P
0 g
s
.4038 .60957 m .40086 .6478 L .36914 .64563 L p .707 .577 .707 r
F P
0 g
s
.43446 .65572 m .43326 .67479 L .40211 .67205 L p .707 .577 .707 r
F P
0 g
s
.40211 .67205 m .40332 .65298 L .43446 .65572 L p .707 .577 .707 r
F P
0 g
s
.37035 .67042 m .37156 .65135 L .40332 .65298 L p .707 .577 .707 r
F P
0 g
s
.40332 .65298 m .40211 .67205 L .37035 .67042 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaH008Io
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH015YF3000NWoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^
Ool006aoo`<000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH00000JGoo001WOol00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000J7oo001VOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Io
o`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo6@0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001IOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000@OolA0014
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool80003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool60003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Woo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000`Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00Dgoo00<005YF0000
15YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000eYF1P001eYF00<005YFFUH01UYF00<005YF
FUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool005=oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH70003FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002eoo`00>7oo
7@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
<Woo1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF6P0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02moo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF00AJEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00
0006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH:0008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPL00003FUH005YF00IJEP03001JEUYF00IJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00000UYF1P0025YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00
15YF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@0009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000QJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00005`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHC0007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000IJEP03001JEUYF00<002moo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF:P0015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPX0039oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH0
1000FUIJEUYF7@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPl000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000/Ool00`00
FUH00002FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH01000FUH005YF10001EYF00@005YFFUIJEPT000=JEQ4000=JEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0004FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF010000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000_Ool40004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30002FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003=o
o`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00H000=JEP03001JEUYF00IJEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00
00005P001eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000fOol50004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF3@0015YF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF5`000eYF00<005YFFUH00P00;Woo000kOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH70009Ool00`00FUIJEP0C0004FUH01000FUIJEUYF2@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF0000000300000eYF0000000^Ool002eo
obT0011oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0800000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008000=JEP<002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF4@003Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`001goo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUHQ
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@000goo200015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH400000eYF0000000@0003FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000UYF00<007ooOol0;7oo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00FUH005YF1`0015YF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF5`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001@005goo5P00<Woo000/OolJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUHA0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1eYF7P0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000006=oo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF1P00GGoo000c
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH80002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP05001HOol003Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH40002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUH00002001EOol004=ooa4000AJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03001JEUYF009JEP03001J
EUYF00=JEP04001JEUYFFUH2001DOol005Aooa<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH00000
1UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00D005YFFUH005YF
008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
E7oo001VOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000aOolF000OOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA000>Ool20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH00P00
EGoo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJ
EP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00=JEP03001J
EUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000Woo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH020000eYF00<005YFFUH00P00EGoo000/Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
0002FUH00`00FUIJEP03FUH500000eYF0000001EOol002aoo`03001JEP00024000AJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00AJEP04001JEUYFFUH3001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000=oo`P000=JEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUHB001FOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P00Igoo000^Ool200000eYF001JEP04FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH20003Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo000`Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF10001Goo0P001UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000
06]oo`00=7oo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF00001goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@00K7oo000kOolA0004FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP04000:Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0400000eYF001JEP02FUH8001TOol004aooaH0015o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00EJ
EP04001JEUYFFUH7001MOol007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP04001JEUYF
FUH70008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05001HOol007eoob0000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00SWoo00<005YF00000UYF5@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00SWoo00<005YF00000P001EYF00@005YFFUIJEPT000=ooa4000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQX000AJEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP03001oogoo05=oo`00T7oo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<007ooOol0Dgoo002EOol7
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00EGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Eoo`00YGoo4@0015YF00@005YFFUIJEPT005Ioo`00]Woo2000Ggoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59626 .72343 m .59925 .66638 L .5681 .6638 L p .707 .577 .707 r
F P
0 g
s
.59925 .66638 m .59626 .72343 L .62804 .72464 L p .707 .577 .707 r
F P
0 g
s
.62804 .72464 m .63104 .6676 L .59925 .66638 L p .707 .577 .707 r
F P
0 g
s
.63104 .6676 m .62804 .72464 L .65734 .72437 L p .707 .577 .707 r
F P
0 g
s
.65734 .72437 m .66034 .66732 L .63104 .6676 L p .707 .577 .707 r
F P
0 g
s
.5651 .72084 m .5681 .6638 L .54062 .66009 L p .707 .577 .707 r
F P
0 g
s
.5681 .6638 m .5651 .72084 L .59626 .72343 L p .707 .577 .707 r
F P
0 g
s
.54062 .66009 m .53763 .71714 L .5651 .72084 L p .707 .577 .707 r
F P
0 g
s
.66034 .66732 m .65734 .72437 L .68129 .72262 L p .707 .577 .707 r
F P
0 g
s
.68129 .72262 m .68429 .66558 L .66034 .66732 L p .707 .577 .707 r
F P
0 g
s
.56817 .73638 m .56347 .77452 L .59454 .77808 L p .707 .577 .707 r
F P
0 g
s
.59454 .77808 m .59924 .73993 L .56817 .73638 L p .707 .577 .707 r
F P
0 g
s
.59924 .73993 m .59454 .77808 L .62608 .7821 L p .707 .577 .707 r
F P
0 g
s
.62608 .7821 m .63077 .74395 L .59924 .73993 L p .707 .577 .707 r
F P
0 g
s
.63077 .74395 m .62608 .7821 L .65499 .7862 L p .707 .577 .707 r
F P
0 g
s
.53763 .71714 m .54062 .66009 L .51952 .65563 L p .707 .577 .707 r
F P
0 g
s
.65499 .7862 m .65969 .74805 L .63077 .74395 L p .707 .577 .707 r
F P
0 g
s
.54061 .73364 m .53591 .77178 L .56347 .77452 L p .707 .577 .707 r
F P
0 g
s
.56347 .77452 m .56817 .73638 L .54061 .73364 L p .707 .577 .707 r
F P
0 g
s
.51952 .65563 m .51652 .71267 L .53763 .71714 L p .707 .577 .707 r
F P
0 g
s
.65969 .74805 m .65499 .7862 L .67846 .78996 L p .707 .577 .707 r
F P
0 g
s
.67846 .78996 m .68315 .75182 L .65969 .74805 L p .707 .577 .707 r
F P
0 g
s
.68429 .66558 m .68129 .72262 L .69754 .71959 L p .707 .577 .707 r
F P
0 g
s
.69754 .71959 m .70054 .66254 L .68429 .66558 L p .707 .577 .707 r
F P
0 g
s
.59548 .84732 m .59741 .82819 L .56631 .82493 L p .707 .577 .707 r
F P
0 g
s
.59741 .82819 m .59548 .84732 L .62711 .85046 L p .707 .577 .707 r
F P
0 g
s
.62711 .85046 m .62905 .83133 L .59741 .82819 L p .707 .577 .707 r
F P
0 g
s
.56631 .82493 m .56438 .84407 L .59548 .84732 L p .707 .577 .707 r
F P
0 g
s
.51925 .73198 m .51455 .77013 L .53591 .77178 L p .707 .577 .707 r
F P
0 g
s
.53591 .77178 m .54061 .73364 L .51925 .73198 L p .707 .577 .707 r
F P
0 g
s
.62905 .83133 m .62711 .85046 L .65618 .85319 L p .707 .577 .707 r
F P
0 g
s
.65618 .85319 m .65812 .83406 L .62905 .83133 L p .707 .577 .707 r
F P
0 g
s
.51652 .71267 m .51952 .65563 L .50684 .65084 L p .707 .577 .707 r
F P
0 g
s
.56438 .84407 m .56631 .82493 L .53878 .82189 L p .707 .577 .707 r
F P
0 g
s
.53878 .82189 m .53685 .84103 L .56438 .84407 L p .707 .577 .707 r
F P
0 g
s
.50684 .65084 m .50384 .70789 L .51652 .71267 L p .707 .577 .707 r
F P
0 g
s
.68315 .75182 m .67846 .78996 L .69417 .79304 L p .707 .577 .707 r
F P
0 g
s
.65812 .83406 m .65618 .85319 L .67984 .85524 L p .707 .577 .707 r
F P
0 g
s
.67984 .85524 m .68177 .83611 L .65812 .83406 L p .707 .577 .707 r
F P
0 g
s
.69417 .79304 m .69887 .75489 L .68315 .75182 L p .707 .577 .707 r
F P
0 g
s
.53685 .84103 m .53878 .82189 L .51753 .81936 L p .707 .577 .707 r
F P
0 g
s
.51753 .81936 m .51559 .83849 L .53685 .84103 L p .707 .577 .707 r
F P
0 g
s
.70054 .66254 m .69754 .71959 L .70451 .71556 L p .707 .577 .707 r
F P
0 g
s
.70451 .71556 m .70751 .65851 L .70054 .66254 L p .707 .577 .707 r
F P
0 g
s
.50619 .73158 m .5015 .76972 L .51455 .77013 L p .707 .577 .707 r
F P
0 g
s
.51455 .77013 m .51925 .73198 L .50619 .73158 L p .707 .577 .707 r
F P
0 g
s
.50384 .70789 m .50684 .65084 L .50384 .64621 L p .707 .577 .707 r
F P
0 g
s
.68177 .83611 m .67984 .85524 L .69577 .8564 L p .707 .577 .707 r
F P
0 g
s
.69577 .8564 m .6977 .83727 L .68177 .83611 L p .707 .577 .707 r
F P
0 g
s
.50384 .64621 m .50084 .70326 L .50384 .70789 L p .707 .577 .707 r
F P
0 g
s
.69887 .75489 m .69417 .79304 L .7006 .79512 L p .707 .577 .707 r
F P
0 g
s
.7006 .79512 m .7053 .75697 L .69887 .75489 L p .707 .577 .707 r
F P
0 g
s
.51559 .83849 m .51753 .81936 L .50462 .81759 L p .707 .577 .707 r
F P
0 g
s
.50462 .81759 m .50268 .83672 L .51559 .83849 L p .707 .577 .707 r
F P
0 g
s
.50271 .73245 m .49801 .7706 L .5015 .76972 L p .707 .577 .707 r
F P
0 g
s
.5015 .76972 m .50619 .73158 L .50271 .73245 L p .707 .577 .707 r
F P
0 g
s
.70751 .65851 m .70451 .71556 L .70151 .71092 L p .707 .577 .707 r
F P
0 g
s
.70151 .71092 m .70451 .65388 L .70751 .65851 L p .707 .577 .707 r
F P
0 g
s
.49654 .82253 m .48928 .32586 L .44527 .32343 L p .707 .577 .707 r
F P
0 g
s
.50084 .70326 m .50384 .64621 L .51081 .64218 L p .707 .577 .707 r
F P
0 g
s
.51081 .64218 m .50781 .69922 L .50084 .70326 L p .707 .577 .707 r
F P
0 g
s
.50268 .83672 m .50462 .81759 L .50133 .81674 L p .707 .577 .707 r
F P
0 g
s
.50133 .81674 m .49939 .83587 L .50268 .83672 L p .707 .577 .707 r
F P
0 g
s
.50914 .73453 m .50444 .77267 L .49801 .7706 L p .707 .577 .707 r
F P
0 g
s
.49801 .7706 m .50271 .73245 L .50914 .73453 L p .707 .577 .707 r
F P
0 g
s
.50781 .69922 m .51081 .64218 L .52706 .63914 L p .707 .577 .707 r
F P
0 g
s
.52706 .63914 m .52406 .69619 L .50781 .69922 L p .707 .577 .707 r
F P
0 g
s
.49939 .83587 m .50133 .81674 L .50797 .81691 L p .707 .577 .707 r
F P
0 g
s
.50797 .81691 m .50604 .83604 L .49939 .83587 L p .707 .577 .707 r
F P
0 g
s
.52486 .7376 m .52016 .77575 L .50444 .77267 L p .707 .577 .707 r
F P
0 g
s
.50444 .77267 m .50914 .73453 L .52486 .7376 L p .707 .577 .707 r
F P
0 g
s
.52406 .69619 m .52706 .63914 L .55101 .6374 L p .707 .577 .707 r
F P
0 g
s
.55101 .6374 m .54801 .69445 L .52406 .69619 L p .707 .577 .707 r
F P
0 g
s
.50604 .83604 m .50797 .81691 L .5239 .81807 L p .707 .577 .707 r
F P
0 g
s
.5239 .81807 m .52197 .8372 L .50604 .83604 L p .707 .577 .707 r
F P
0 g
s
.54832 .74137 m .54362 .77952 L .52016 .77575 L p .707 .577 .707 r
F P
0 g
s
.52016 .77575 m .52486 .7376 L .54832 .74137 L p .707 .577 .707 r
F P
0 g
s
.52197 .8372 m .5239 .81807 L .54756 .82012 L p .707 .577 .707 r
F P
0 g
s
.48928 .32586 m .49654 .82253 L .54148 .82069 L p .707 .577 .707 r
F P
0 g
s
.54148 .82069 m .53422 .32403 L .48928 .32586 L p .707 .577 .707 r
F P
0 g
s
.54801 .69445 m .55101 .6374 L .58031 .63712 L p .707 .577 .707 r
F P
0 g
s
.58031 .63712 m .57731 .69417 L .54801 .69445 L p .707 .577 .707 r
F P
0 g
s
.57724 .74547 m .57254 .78362 L .54362 .77952 L p .707 .577 .707 r
F P
0 g
s
.54362 .77952 m .54832 .74137 L .57724 .74547 L p .707 .577 .707 r
F P
0 g
s
.60877 .74949 m .60407 .78764 L .57254 .78362 L p .707 .577 .707 r
F P
0 g
s
.57254 .78362 m .57724 .74547 L .60877 .74949 L p .707 .577 .707 r
F P
0 g
s
.53422 .32403 m .54148 .82069 L .58295 .81477 L p .707 .577 .707 r
F P
0 g
s
.57731 .69417 m .58031 .63712 L .61209 .63834 L p .707 .577 .707 r
F P
0 g
s
.61209 .63834 m .6091 .69538 L .57731 .69417 L p .707 .577 .707 r
F P
0 g
s
.58295 .81477 m .57569 .31811 L .53422 .32403 L p .707 .577 .707 r
F P
0 g
s
.6977 .83727 m .69577 .8564 L .70241 .85657 L p .707 .577 .707 r
F P
0 g
s
.70241 .85657 m .70435 .83744 L .6977 .83727 L p .707 .577 .707 r
F P
0 g
s
.45253 .8201 m .44527 .32343 L .40651 .31698 L p .707 .577 .707 r
F P
0 g
s
.44527 .32343 m .45253 .8201 L .49654 .82253 L p .707 .577 .707 r
F P
0 g
s
.7053 .75697 m .7006 .79512 L .69712 .79599 L p .707 .577 .707 r
F P
0 g
s
.69712 .79599 m .70182 .75785 L .7053 .75697 L p .707 .577 .707 r
F P
0 g
s
.63984 .75305 m .63514 .79119 L .61341 .78871 L p .707 .577 .707 r
F P
0 g
s
.61341 .78871 m .60407 .78764 L p .61413 .77791 L .707 .577 .707 r
F P
0 g
s
.61413 .77791 m .63984 .75305 L .61341 .78871 L .707 .577 .707 r
F
.67072 .64463 m .66773 .70168 L .64025 .69797 L p F P
0 g
s
.64025 .69797 m .64325 .64092 L .67072 .64463 L p .707 .577 .707 r
F P
0 g
s
.64325 .64092 m .64025 .69797 L .6091 .69538 L p .707 .577 .707 r
F P
0 g
s
.6091 .69538 m .61209 .63834 L .64325 .64092 L p .707 .577 .707 r
F P
0 g
s
.6674 .75579 m .6627 .79393 L .63514 .79119 L p .707 .577 .707 r
F P
0 g
s
.63514 .79119 m .63984 .75305 L .6674 .75579 L p .707 .577 .707 r
F P
0 g
s
.60407 .78764 m .60877 .74949 L .63984 .75305 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .64998 .77993 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63273 .29668 m .63517 .46314 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63517 .46314 m .63999 .79335 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.57569 .31811 m .58295 .81477 L .6169 .80535 L p .707 .577 .707 r
F P
0 g
s
.6169 .80535 m .60964 .30869 L .57569 .31811 L p .707 .577 .707 r
F P
0 g
s
.70451 .65388 m .70151 .71092 L .68883 .70614 L p .707 .577 .707 r
F P
0 g
s
.68883 .70614 m .69183 .64909 L .70451 .65388 L p .707 .577 .707 r
F P
0 g
s
.41377 .81364 m .40651 .31698 L .37677 .30713 L p .707 .577 .707 r
F P
0 g
s
.40651 .31698 m .41377 .81364 L .45253 .8201 L p .707 .577 .707 r
F P
0 g
s
.25325 .68661 m .25625 .62957 L .22509 .62698 L p .707 .577 .707 r
F P
0 g
s
.25625 .62957 m .25325 .68661 L .28503 .68783 L p .707 .577 .707 r
F P
0 g
s
.28503 .68783 m .28803 .63078 L .25625 .62957 L p .707 .577 .707 r
F P
0 g
s
.28803 .63078 m .28503 .68783 L .31433 .68755 L p .707 .577 .707 r
F P
0 g
s
.31433 .68755 m .31733 .6305 L .28803 .63078 L p .707 .577 .707 r
F P
0 g
s
.70435 .83744 m .70241 .85657 L .69912 .85573 L p .707 .577 .707 r
F P
0 g
s
.69912 .85573 m .70106 .83659 L .70435 .83744 L p .707 .577 .707 r
F P
0 g
s
.22209 .68403 m .22509 .62698 L .19762 .62328 L p .707 .577 .707 r
F P
0 g
s
.22509 .62698 m .22209 .68403 L .25325 .68661 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19762 .62328 m .19462 .68032 L .22209 .68403 L p .707 .577 .707 r
F P
0 g
s
.70182 .75785 m .69712 .79599 L .68406 .79559 L p .707 .577 .707 r
F P
0 g
s
.31733 .6305 m .31433 .68755 L .33828 .68581 L p .707 .577 .707 r
F P
0 g
s
.33828 .68581 m .34128 .62876 L .31733 .6305 L p .707 .577 .707 r
F P
0 g
s
.60964 .30869 m .6169 .80535 L .63999 .79335 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .63273 .29668 L .60964 .30869 L p .707 .577 .707 r
F P
0 g
s
.68406 .79559 m .68876 .75744 L .70182 .75785 L p .707 .577 .707 r
F P
0 g
s
.22516 .69956 m .22046 .73771 L .25153 .74126 L p .707 .577 .707 r
F P
0 g
s
.25153 .74126 m .25623 .70312 L .22516 .69956 L p .707 .577 .707 r
F P
0 g
s
.25623 .70312 m .25153 .74126 L .28307 .74528 L p .707 .577 .707 r
F P
0 g
s
.28307 .74528 m .28777 .70714 L .25623 .70312 L p .707 .577 .707 r
F P
0 g
s
.28777 .70714 m .28307 .74528 L .31198 .74938 L p .707 .577 .707 r
F P
0 g
s
.19462 .68032 m .19762 .62328 L .17651 .61881 L p .707 .577 .707 r
F P
0 g
s
.69183 .64909 m .68883 .70614 L .66773 .70168 L p .707 .577 .707 r
F P
0 g
s
.66773 .70168 m .67072 .64463 L .69183 .64909 L p .707 .577 .707 r
F P
0 g
s
.31198 .74938 m .31668 .71123 L .28777 .70714 L p .707 .577 .707 r
F P
0 g
s
.1976 .69682 m .1929 .73497 L .22046 .73771 L p .707 .577 .707 r
F P
0 g
s
.22046 .73771 m .22516 .69956 L .1976 .69682 L p .707 .577 .707 r
F P
0 g
s
.17651 .61881 m .17351 .67586 L .19462 .68032 L p .707 .577 .707 r
F P
0 g
s
.38403 .80379 m .37677 .30713 L .35899 .29485 L p .707 .577 .707 r
F P
0 g
s
.37677 .30713 m .38403 .80379 L .41377 .81364 L p .707 .577 .707 r
F P
0 g
s
.31668 .71123 m .31198 .74938 L .33545 .75315 L p .707 .577 .707 r
F P
0 g
s
.70106 .83659 m .69912 .85573 L .68622 .85395 L p .707 .577 .707 r
F P
0 g
s
.68622 .85395 m .68815 .83482 L .70106 .83659 L p .707 .577 .707 r
F P
0 g
s
.33545 .75315 m .34015 .715 L .31668 .71123 L p .707 .577 .707 r
F P
0 g
s
.34128 .62876 m .33828 .68581 L .35453 .68277 L p .707 .577 .707 r
F P
0 g
s
.35453 .68277 m .35753 .62573 L .34128 .62876 L p .707 .577 .707 r
F P
0 g
s
.25247 .8105 m .2544 .79137 L .2233 .78812 L p .707 .577 .707 r
F P
0 g
s
.2544 .79137 m .25247 .8105 L .2841 .81365 L p .707 .577 .707 r
F P
0 g
s
.2841 .81365 m .28604 .79452 L .2544 .79137 L p .707 .577 .707 r
F P
0 g
s
.2233 .78812 m .22137 .80725 L .25247 .8105 L p .707 .577 .707 r
F P
0 g
s
.17624 .69517 m .17155 .73331 L .1929 .73497 L p .707 .577 .707 r
F P
0 g
s
.1929 .73497 m .1976 .69682 L .17624 .69517 L p .707 .577 .707 r
F P
0 g
s
.28604 .79452 m .2841 .81365 L .31317 .81638 L p .707 .577 .707 r
F P
0 g
s
.31317 .81638 m .31511 .79724 L .28604 .79452 L p .707 .577 .707 r
F P
0 g
s
.68876 .75744 m .68406 .79559 L .6627 .79393 L p .707 .577 .707 r
F P
0 g
s
.6627 .79393 m .6674 .75579 L .68876 .75744 L p .707 .577 .707 r
F P
0 g
s
.17351 .67586 m .17651 .61881 L .16383 .61403 L p .707 .577 .707 r
F P
0 g
s
.22137 .80725 m .2233 .78812 L .19577 .78508 L p .707 .577 .707 r
F P
0 g
s
.19577 .78508 m .19384 .80421 L .22137 .80725 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64272 .28327 L .63273 .29668 L p .707 .577 .707 r
F P
0 g
s
.16383 .61403 m .16083 .67108 L .17351 .67586 L p .707 .577 .707 r
F P
0 g
s
.34015 .715 m .33545 .75315 L .35116 .75622 L p .707 .577 .707 r
F P
0 g
s
.31511 .79724 m .31317 .81638 L .33683 .81842 L p .707 .577 .707 r
F P
0 g
s
.33683 .81842 m .33876 .79929 L .31511 .79724 L p .707 .577 .707 r
F P
0 g
s
.35116 .75622 m .35586 .71808 L .34015 .715 L p .707 .577 .707 r
F P
0 g
s
.19384 .80421 m .19577 .78508 L .17452 .78255 L p .707 .577 .707 r
F P
0 g
s
.17452 .78255 m .17258 .80168 L .19384 .80421 L p .707 .577 .707 r
F P
0 g
s
.35753 .62573 m .35453 .68277 L .3615 .67874 L p .707 .577 .707 r
F P
0 g
s
.3615 .67874 m .3645 .62169 L .35753 .62573 L p .707 .577 .707 r
F P
0 g
s
.16318 .69476 m .15849 .73291 L .17155 .73331 L p .707 .577 .707 r
F P
0 g
s
.17155 .73331 m .17624 .69517 L .16318 .69476 L p .707 .577 .707 r
F P
0 g
s
.68815 .83482 m .68622 .85395 L .66496 .85142 L p .707 .577 .707 r
F P
0 g
s
.66496 .85142 m .66689 .83228 L .68815 .83482 L p .707 .577 .707 r
F P
0 g
s
.3645 .62169 m .3615 .67874 L .3585 .67411 L p .707 .577 .707 r
F P
0 g
s
.3585 .67411 m .3615 .61706 L .3645 .62169 L p .707 .577 .707 r
F P
0 g
s
.36625 .79152 m .35899 .29485 L .35489 .28134 L p .707 .577 .707 r
F P
0 g
s
.35899 .29485 m .36625 .79152 L .38403 .80379 L p .707 .577 .707 r
F P
0 g
s
.54756 .82012 m .54563 .83925 L .52197 .8372 L p .707 .577 .707 r
F P
0 g
s
.16083 .67108 m .16383 .61403 L .16083 .6094 L p .707 .577 .707 r
F P
0 g
s
.33876 .79929 m .33683 .81842 L .35276 .81959 L p .707 .577 .707 r
F P
0 g
s
.35276 .81959 m .35469 .80046 L .33876 .79929 L p .707 .577 .707 r
F P
0 g
s
.16083 .6094 m .15783 .66644 L .16083 .67108 L p .707 .577 .707 r
F P
0 g
s
.35586 .71808 m .35116 .75622 L .35759 .7583 L p .707 .577 .707 r
F P
0 g
s
.35759 .7583 m .36229 .72016 L .35586 .71808 L p .707 .577 .707 r
F P
0 g
s
.17258 .80168 m .17452 .78255 L .16161 .78077 L p .707 .577 .707 r
F P
0 g
s
.16161 .78077 m .15968 .7999 L .17258 .80168 L p .707 .577 .707 r
F P
0 g
s
.66689 .83228 m .66496 .85142 L .63743 .84838 L p .707 .577 .707 r
F P
0 g
s
.63743 .84838 m .63937 .82924 L .66689 .83228 L p .707 .577 .707 r
F P
0 g
s
.1597 .69564 m .155 .73378 L .15849 .73291 L p .707 .577 .707 r
F P
0 g
s
.15849 .73291 m .16318 .69476 L .1597 .69564 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64769 .77239 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64272 .28327 m .64964 .75634 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64964 .75634 m .64998 .77993 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64564 .72985 m .64272 .28327 L .6476 .76343 L .707 .577 .707 r
F
.64655 .74877 m .6476 .76343 L .64769 .77239 L F
.64564 .72985 m .6476 .76343 L .64655 .74877 L F
.63862 .26976 m .64272 .28327 L p .6451 .64759 L F P
0 g
s
.64431 .64561 m .63862 .26976 L .6451 .64759 L .707 .577 .707 r
F
.64538 .73238 m .63862 .26976 L p .64569 .73662 L F P
0 g
s
.63862 .26976 m .64588 .76643 L .6281 .75415 L p .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64104 .5794 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64105 .64108 m .64121 .6379 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64404 .58403 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64569 .73662 m .64431 .64561 L .6451 .64759 L .707 .577 .707 r
F
.64588 .76643 m .64538 .73238 L p .64569 .73662 L F P
0 g
s
.64182 .68377 m .63989 .7029 L .64331 .70337 L p .707 .577 .707 r
F P
0 g
s
.64331 .70337 m .65279 .70468 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.64193 .68397 m .64182 .68377 L .64331 .70337 L .707 .577 .707 r
F
.65279 .70468 m .65473 .68554 L .64192 .68378 L p F P
0 g
s
.64192 .68378 m .64182 .68377 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.65279 .70468 m .64192 .68378 L .64193 .68397 L .707 .577 .707 r
F
.64137 .6412 m .65372 .64586 L p .64121 .6379 L F P
0 g
s
.6434 .64159 m .64149 .65704 L p .65176 .68014 L .707 .577 .707 r
F P
0 g
s
.64149 .65704 m .6387 .67973 L .64337 .67988 L p .707 .577 .707 r
F P
0 g
s
.64337 .67988 m .65176 .68014 L p .64149 .65704 L .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64121 .6379 L p .65372 .64586 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64105 .64108 L .64137 .6412 L p .707 .577 .707 r
F P
0 g
s
.64769 .77239 m .64588 .76643 L p .64564 .72985 L .707 .577 .707 r
F P
0 g
s
.54563 .83925 m .54756 .82012 L .57663 .82285 L p .707 .577 .707 r
F P
0 g
s
.57663 .82285 m .57469 .84198 L .54563 .83925 L p .707 .577 .707 r
F P
0 g
s
.63937 .82924 m .63743 .84838 L .60633 .84512 L p .707 .577 .707 r
F P
0 g
s
.60633 .84512 m .60826 .82599 L .63937 .82924 L p .707 .577 .707 r
F P
0 g
s
.35469 .80046 m .35276 .81959 L .3594 .81976 L p .707 .577 .707 r
F P
0 g
s
.3594 .81976 m .36134 .80062 L .35469 .80046 L p .707 .577 .707 r
F P
0 g
s
.15783 .66644 m .16083 .6094 L .1678 .60536 L p .707 .577 .707 r
F P
0 g
s
.57469 .84198 m .57663 .82285 L .60826 .82599 L p .707 .577 .707 r
F P
0 g
s
.60826 .82599 m .60633 .84512 L .57469 .84198 L p .707 .577 .707 r
F P
0 g
s
.36229 .72016 m .35759 .7583 L .35411 .75918 L p .707 .577 .707 r
F P
0 g
s
.35411 .75918 m .35881 .72103 L .36229 .72016 L p .707 .577 .707 r
F P
0 g
s
.3615 .61706 m .3585 .67411 L .34583 .66932 L p .707 .577 .707 r
F P
0 g
s
.34583 .66932 m .34882 .61228 L .3615 .61706 L p .707 .577 .707 r
F P
0 g
s
.35489 .28134 m .36215 .77801 L .36625 .79152 L p .707 .577 .707 r
F P
0 g
s
.36215 .77801 m .35489 .28134 L .36488 .26793 L p .707 .577 .707 r
F P
0 g
s
.1678 .60536 m .1648 .66241 L .15783 .66644 L p .707 .577 .707 r
F P
0 g
s
.15968 .7999 m .16161 .78077 L .15832 .77992 L p .707 .577 .707 r
F P
0 g
s
.15832 .77992 m .15638 .79906 L .15968 .7999 L p .707 .577 .707 r
F P
0 g
s
.16613 .69771 m .16143 .73586 L .155 .73378 L p .707 .577 .707 r
F P
0 g
s
.155 .73378 m .1597 .69564 L .16613 .69771 L p .707 .577 .707 r
F P
0 g
s
.36134 .80062 m .3594 .81976 L .35611 .81891 L p .707 .577 .707 r
F P
0 g
s
.35611 .81891 m .35805 .79978 L .36134 .80062 L p .707 .577 .707 r
F P
0 g
s
.1648 .66241 m .1678 .60536 L .18405 .60233 L p .707 .577 .707 r
F P
0 g
s
.6281 .75415 m .62084 .25749 L .63862 .26976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18405 .60233 m .18105 .65937 L .1648 .66241 L p .707 .577 .707 r
F P
0 g
s
.35881 .72103 m .35411 .75918 L .34105 .75877 L p .707 .577 .707 r
F P
0 g
s
.15638 .79906 m .15832 .77992 L .16496 .78009 L p .707 .577 .707 r
F P
0 g
s
.16496 .78009 m .16303 .79922 L .15638 .79906 L p .707 .577 .707 r
F P
0 g
s
.34105 .75877 m .34575 .72062 L .35881 .72103 L p .707 .577 .707 r
F P
0 g
s
.34882 .61228 m .34583 .66932 L .32472 .66486 L p .707 .577 .707 r
F P
0 g
s
.32472 .66486 m .32771 .60781 L .34882 .61228 L p .707 .577 .707 r
F P
0 g
s
.37214 .7646 m .36488 .26793 L .38797 .25593 L p .707 .577 .707 r
F P
0 g
s
.36488 .26793 m .37214 .7646 L .36215 .77801 L p .707 .577 .707 r
F P
0 g
s
.18185 .70079 m .17715 .73893 L .16143 .73586 L p .707 .577 .707 r
F P
0 g
s
.16143 .73586 m .16613 .69771 L .18185 .70079 L p .707 .577 .707 r
F P
0 g
s
.18105 .65937 m .18405 .60233 L .208 .60058 L p .707 .577 .707 r
F P
0 g
s
.35805 .79978 m .35611 .81891 L .34321 .81713 L p .707 .577 .707 r
F P
0 g
s
.34321 .81713 m .34514 .798 L .35805 .79978 L p .707 .577 .707 r
F P
0 g
s
.208 .60058 m .205 .65763 L .18105 .65937 L p .707 .577 .707 r
F P
0 g
s
.34575 .72062 m .34105 .75877 L .31969 .75712 L p .707 .577 .707 r
F P
0 g
s
.62084 .25749 m .6281 .75415 L .59836 .7443 L p .707 .577 .707 r
F P
0 g
s
.59836 .7443 m .5911 .24764 L .62084 .25749 L p .707 .577 .707 r
F P
0 g
s
.31969 .75712 m .32439 .71897 L .34575 .72062 L p .707 .577 .707 r
F P
0 g
s
.16303 .79922 m .16496 .78009 L .18089 .78126 L p .707 .577 .707 r
F P
0 g
s
.18089 .78126 m .17896 .80039 L .16303 .79922 L p .707 .577 .707 r
F P
0 g
s
.32771 .60781 m .32472 .66486 L .29724 .66115 L p .707 .577 .707 r
F P
0 g
s
.29724 .66115 m .30024 .60411 L .32771 .60781 L p .707 .577 .707 r
F P
0 g
s
.20531 .70456 m .20061 .7427 L .17715 .73893 L p .707 .577 .707 r
F P
0 g
s
.17715 .73893 m .18185 .70079 L .20531 .70456 L p .707 .577 .707 r
F P
0 g
s
.205 .65763 m .208 .60058 L .2373 .60031 L p .707 .577 .707 r
F P
0 g
s
.38797 .25593 m .39512 .74509 L p .37214 .7646 L .707 .577 .707 r
F P
0 g
s
.39523 .75259 m .38797 .25593 L .42192 .2465 L p .707 .577 .707 r
F P
0 g
s
.42192 .2465 m .42819 .67517 L p .39663 .72619 L .707 .577 .707 r
F P
0 g
s
.42918 .74317 m .42192 .2465 L .46339 .24059 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .47065 .73725 L .42918 .74317 L p .707 .577 .707 r
F P
0 g
s
.42523 .56397 m .42223 .62101 L .43945 .62085 L p .707 .577 .707 r
F P
0 g
s
.43945 .62085 m .45078 .62074 L p .44589 .60988 L .707 .577 .707 r
F P
0 g
s
.44589 .60988 m .42523 .56397 L .43945 .62085 L .707 .577 .707 r
F
.39345 .56275 m .39045 .6198 L .42223 .62101 L p F P
0 g
s
.42223 .62101 m .42523 .56397 L .39345 .56275 L p .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .39343 .61313 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42027 .6553 m .42055 .653 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42055 .653 m .42497 .61715 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .42027 .6553 L .43885 .65793 L p .707 .577 .707 r
F P
0 g
s
.43885 .65793 m .44919 .65939 L p .44378 .64996 L .707 .577 .707 r
F P
0 g
s
.44378 .64996 m .42497 .61715 L .43885 .65793 L .707 .577 .707 r
F
.39523 .75259 m .39663 .72619 L .42852 .69778 L F
.42819 .67517 m .42852 .69778 L p .39663 .72619 L F P
0 g
s
.42852 .69778 m .42918 .74317 L .4142 .74733 L p .707 .577 .707 r
F P
0 g
s
.4142 .74733 m .39523 .75259 L p .42852 .69778 L .707 .577 .707 r
F P
0 g
s
.45078 .62074 m .45153 .62074 L p .45107 .61974 L .707 .577 .707 r
F P
0 g
s
.45107 .61974 m .42523 .56397 L .45078 .62074 L .707 .577 .707 r
F
.39343 .61313 m .38873 .65128 L .41278 .65434 L p F P
0 g
s
.41278 .65434 m .42027 .6553 L p .41439 .64606 L .707 .577 .707 r
F P
0 g
s
.41439 .64606 m .39343 .61313 L .41278 .65434 L .707 .577 .707 r
F
.39512 .74509 m .39523 .75259 L .39349 .7535 L p F P
0 g
s
.39349 .7535 m .37214 .7646 L p .39512 .74509 L .707 .577 .707 r
F P
0 g
s
.2373 .60031 m .2343 .65735 L .205 .65763 L p .707 .577 .707 r
F P
0 g
s
.30024 .60411 m .29724 .66115 L .26609 .65857 L p .707 .577 .707 r
F P
0 g
s
.26609 .65857 m .26908 .60152 L .30024 .60411 L p .707 .577 .707 r
F P
0 g
s
.34514 .798 m .34321 .81713 L .32195 .8146 L p .707 .577 .707 r
F P
0 g
s
.32195 .8146 m .32388 .79547 L .34514 .798 L p .707 .577 .707 r
F P
0 g
s
.2343 .65735 m .2373 .60031 L .26908 .60152 L p .707 .577 .707 r
F P
0 g
s
.32439 .71897 m .31969 .75712 L .29213 .75438 L p .707 .577 .707 r
F P
0 g
s
.29213 .75438 m .29683 .71623 L .32439 .71897 L p .707 .577 .707 r
F P
0 g
s
.26908 .60152 m .26609 .65857 L .2343 .65735 L p .707 .577 .707 r
F P
0 g
s
.73346 .65661 m .73646 .59957 L .7053 .59698 L p .707 .577 .707 r
F P
0 g
s
.73646 .59957 m .73346 .65661 L .76524 .65783 L p .707 .577 .707 r
F P
0 g
s
.76524 .65783 m .76824 .60078 L .73646 .59957 L p .707 .577 .707 r
F P
0 g
s
.23423 .70866 m .22953 .7468 L .20061 .7427 L p .707 .577 .707 r
F P
0 g
s
.20061 .7427 m .20531 .70456 L .23423 .70866 L p .707 .577 .707 r
F P
0 g
s
.17896 .80039 m .18089 .78126 L .20455 .7833 L p .707 .577 .707 r
F P
0 g
s
.20455 .7833 m .20262 .80244 L .17896 .80039 L p .707 .577 .707 r
F P
0 g
s
.76824 .60078 m .76524 .65783 L .78246 .65767 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .73644 .64995 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76328 .69211 m .76356 .68982 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76356 .68982 m .76798 .65397 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.78246 .65767 m .79454 .65755 L p .78925 .64612 L .707 .577 .707 r
F P
0 g
s
.78925 .64612 m .76824 .60078 L .78246 .65767 L .707 .577 .707 r
F
.79454 .65755 m .79754 .6005 L .76824 .60078 L p F P
0 g
s
.5911 .24764 m .59836 .7443 L .5596 .73785 L p .707 .577 .707 r
F P
0 g
s
.5596 .73785 m .55234 .24118 L .5911 .24764 L p .707 .577 .707 r
F P
0 g
s
.70231 .65403 m .7053 .59698 L .67783 .59328 L p .707 .577 .707 r
F P
0 g
s
.7053 .59698 m .70231 .65403 L .73346 .65661 L p .707 .577 .707 r
F P
0 g
s
.29683 .71623 m .29213 .75438 L .26106 .75082 L p .707 .577 .707 r
F P
0 g
s
.70537 .64639 m .70068 .68454 L .73174 .68809 L p .707 .577 .707 r
F P
0 g
s
.73174 .68809 m .73644 .64995 L .70537 .64639 L p .707 .577 .707 r
F P
0 g
s
.73644 .64995 m .73174 .68809 L .76328 .69211 L p .707 .577 .707 r
F P
0 g
s
.26106 .75082 m .26576 .71268 L .29683 .71623 L p .707 .577 .707 r
F P
0 g
s
.26576 .71268 m .26106 .75082 L .22953 .7468 L p .707 .577 .707 r
F P
0 g
s
.22953 .7468 m .23423 .70866 L .26576 .71268 L p .707 .577 .707 r
F P
0 g
s
.67783 .59328 m .67483 .65032 L .70231 .65403 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .76328 .69211 L .7922 .69621 L p .707 .577 .707 r
F P
0 g
s
.79754 .6005 m .79454 .65755 L .81849 .65581 L p .707 .577 .707 r
F P
0 g
s
.81849 .65581 m .82149 .59876 L .79754 .6005 L p .707 .577 .707 r
F P
0 g
s
.32388 .79547 m .32195 .8146 L .29442 .81156 L p .707 .577 .707 r
F P
0 g
s
.29442 .81156 m .29636 .79243 L .32388 .79547 L p .707 .577 .707 r
F P
0 g
s
.7922 .69621 m .79689 .65806 L .76798 .65397 L p .707 .577 .707 r
F P
0 g
s
.67781 .64365 m .67311 .6818 L .70068 .68454 L p .707 .577 .707 r
F P
0 g
s
.70068 .68454 m .70537 .64639 L .67781 .64365 L p .707 .577 .707 r
F P
0 g
s
.73268 .7135 m .73462 .69437 L .70351 .69112 L p .707 .577 .707 r
F P
0 g
s
.73462 .69437 m .73268 .7135 L .76432 .71665 L p .707 .577 .707 r
F P
0 g
s
.76432 .71665 m .76625 .69751 L .73462 .69437 L p .707 .577 .707 r
F P
0 g
s
.70351 .69112 m .70158 .71025 L .73268 .7135 L p .707 .577 .707 r
F P
0 g
s
.67483 .65032 m .67783 .59328 L .65672 .58881 L p .707 .577 .707 r
F P
0 g
s
.20262 .80244 m .20455 .7833 L .23362 .78603 L p .707 .577 .707 r
F P
0 g
s
.23362 .78603 m .23169 .80516 L .20262 .80244 L p .707 .577 .707 r
F P
0 g
s
.76625 .69751 m .76432 .71665 L .79339 .71937 L p .707 .577 .707 r
F P
0 g
s
.79339 .71937 m .79532 .70024 L .76625 .69751 L p .707 .577 .707 r
F P
0 g
s
.55234 .24118 m .5596 .73785 L .51559 .73542 L p .707 .577 .707 r
F P
0 g
s
.51559 .73542 m .50833 .23875 L .55234 .24118 L p .707 .577 .707 r
F P
0 g
s
.70158 .71025 m .70351 .69112 L .67599 .68808 L p .707 .577 .707 r
F P
0 g
s
.67599 .68808 m .67405 .70721 L .70158 .71025 L p .707 .577 .707 r
F P
0 g
s
.79689 .65806 m .7922 .69621 L .81566 .69998 L p .707 .577 .707 r
F P
0 g
s
.81566 .69998 m .82036 .66183 L .79689 .65806 L p .707 .577 .707 r
F P
0 g
s
.65672 .58881 m .65372 .64586 L .67483 .65032 L p .707 .577 .707 r
F P
0 g
s
.29636 .79243 m .29442 .81156 L .26332 .80831 L p .707 .577 .707 r
F P
0 g
s
.26332 .80831 m .26525 .78918 L .29636 .79243 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .50833 .23875 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.47038 .71851 m .46339 .24059 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.45388 .62125 m .45009 .65202 L p .47265 .66316 L .707 .577 .707 r
F P
0 g
s
.45009 .65202 m .44919 .65939 L .45251 .65993 L p .707 .577 .707 r
F P
0 g
s
.45251 .65993 m .47265 .66316 L p .45009 .65202 L .707 .577 .707 r
F P
0 g
s
.47065 .73725 m .47038 .71851 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.65646 .642 m .65176 .68014 L .67311 .6818 L p .707 .577 .707 r
F P
0 g
s
.67311 .6818 m .67781 .64365 L .65646 .642 L p .707 .577 .707 r
F P
0 g
s
.23169 .80516 m .23362 .78603 L .26525 .78918 L p .707 .577 .707 r
F P
0 g
s
.26525 .78918 m .26332 .80831 L .23169 .80516 L p .707 .577 .707 r
F P
0 g
s
.50833 .23875 m .51559 .73542 L .47065 .73725 L p .707 .577 .707 r
F P
0 g
s
.82149 .59876 m .81849 .65581 L .83475 .65277 L p .707 .577 .707 r
F P
0 g
s
.83475 .65277 m .83774 .59573 L .82149 .59876 L p .707 .577 .707 r
F P
0 g
s
.79532 .70024 m .79339 .71937 L .81704 .72142 L p .707 .577 .707 r
F P
0 g
s
.81704 .72142 m .81898 .70229 L .79532 .70024 L p .707 .577 .707 r
F P
0 g
s
.67405 .70721 m .67599 .68808 L .65473 .68554 L p .707 .577 .707 r
F P
0 g
s
.65473 .68554 m .65279 .70468 L .67405 .70721 L p .707 .577 .707 r
F P
0 g
s
.65372 .64586 m .65672 .58881 L .64404 .58403 L p .707 .577 .707 r
F P
0 g
s
.82036 .66183 m .81566 .69998 L .83138 .70305 L p .707 .577 .707 r
F P
0 g
s
.83138 .70305 m .83608 .66491 L .82036 .66183 L p .707 .577 .707 r
F P
0 g
s
.65176 .68014 m .65646 .642 L .6434 .64159 L p .707 .577 .707 r
F P
0 g
s
.81898 .70229 m .81704 .72142 L .83297 .72259 L p .707 .577 .707 r
F P
0 g
s
.83608 .66491 m .83138 .70305 L .83239 .70338 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .83491 .70345 L .8324 .70327 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .8324 .70327 L .83056 .71908 L .707 .577 .707 r
F
.83491 .70345 m .83297 .72259 L .83962 .72275 L p F P
0 g
s
.83962 .72275 m .84155 .70362 L .83491 .70345 L p .707 .577 .707 r
F P
0 g
s
.83239 .70338 m .83781 .70513 L p .83629 .66993 L .707 .577 .707 r
F P
0 g
s
.83629 .66993 m .83608 .66491 L .83239 .70338 L .707 .577 .707 r
F
.8324 .70327 m .81898 .70229 L p .83056 .71908 L F P
0 g
s
.83774 .59573 m .83475 .65277 L .84171 .64874 L p .707 .577 .707 r
F P
0 g
s
.84171 .64874 m .84471 .59169 L .83774 .59573 L p .707 .577 .707 r
F P
0 g
s
.83781 .70513 m .84251 .66699 L .83608 .66491 L p .707 .577 .707 r
F P
0 g
s
.64104 .5794 m .63805 .63644 L .64105 .64108 L p .707 .577 .707 r
F P
0 g
s
.63991 .64247 m .63521 .68061 L .6387 .67973 L p .707 .577 .707 r
F P
0 g
s
.6387 .67973 m .6434 .64159 L .63991 .64247 L p .707 .577 .707 r
F P
0 g
s
.84471 .59169 m .84171 .64874 L .83871 .64411 L p .707 .577 .707 r
F P
0 g
s
.83871 .64411 m .84171 .58706 L .84471 .59169 L p .707 .577 .707 r
F P
0 g
s
.63989 .7029 m .64182 .68377 L .63853 .68292 L p .707 .577 .707 r
F P
0 g
s
.63853 .68292 m .6366 .70205 L .63989 .7029 L p .707 .577 .707 r
F P
0 g
s
.63805 .63644 m .64104 .5794 L .64801 .57536 L p .707 .577 .707 r
F P
0 g
s
.84251 .66699 m .83781 .70513 L .83432 .70601 L p .707 .577 .707 r
F P
0 g
s
.83432 .70601 m .83902 .66786 L .84251 .66699 L p .707 .577 .707 r
F P
0 g
s
.64801 .57536 m .64501 .63241 L .63805 .63644 L p .707 .577 .707 r
F P
0 g
s
.84155 .70362 m .83962 .72275 L .83633 .72191 L p .707 .577 .707 r
F P
0 g
s
.83633 .72191 m .83826 .70277 L .84155 .70362 L p .707 .577 .707 r
F P
0 g
s
.64634 .64454 m .64164 .68269 L .63521 .68061 L p .707 .577 .707 r
F P
0 g
s
.63521 .68061 m .63991 .64247 L .64634 .64454 L p .707 .577 .707 r
F P
0 g
s
.84171 .58706 m .83871 .64411 L .82604 .63932 L p .707 .577 .707 r
F P
0 g
s
.82604 .63932 m .82904 .58228 L .84171 .58706 L p .707 .577 .707 r
F P
0 g
s
.66206 .64762 m .65736 .68576 L .64412 .68317 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .63853 .68292 L .64413 .68306 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .64413 .68306 L .6438 .68613 L .707 .577 .707 r
F
.64412 .68317 m .64164 .68269 L p .64474 .67737 L F P
0 g
s
.64474 .67737 m .66206 .64762 L .64412 .68317 L .707 .577 .707 r
F
.64413 .68306 m .64518 .68309 L p .6438 .68613 L F P
0 g
s
.64518 .68309 m .64324 .70222 L .6366 .70205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39045 .6198 m .39345 .56275 L .36229 .56017 L p .707 .577 .707 r
F P
0 g
s
.45153 .62074 m .45453 .56369 L .42523 .56397 L p .707 .577 .707 r
F P
0 g
s
.64501 .63241 m .64801 .57536 L .66427 .57233 L p .707 .577 .707 r
F P
0 g
s
.3593 .61721 m .36229 .56017 L .33482 .55646 L p .707 .577 .707 r
F P
0 g
s
.36229 .56017 m .3593 .61721 L .39045 .6198 L p .707 .577 .707 r
F P
0 g
s
.83902 .66786 m .83432 .70601 L .82126 .7056 L p .707 .577 .707 r
F P
0 g
s
.82126 .7056 m .82596 .66745 L .83902 .66786 L p .707 .577 .707 r
F P
0 g
s
.36236 .60958 m .35767 .64772 L .38873 .65128 L p .707 .577 .707 r
F P
0 g
s
.38873 .65128 m .39343 .61313 L .36236 .60958 L p .707 .577 .707 r
F P
0 g
s
.66427 .57233 m .66127 .62937 L .64501 .63241 L p .707 .577 .707 r
F P
0 g
s
.33482 .55646 m .33182 .61351 L .3593 .61721 L p .707 .577 .707 r
F P
0 g
s
.45453 .56369 m .45153 .62074 L .47548 .61899 L p .707 .577 .707 r
F P
0 g
s
.47548 .61899 m .47848 .56195 L .45453 .56369 L p .707 .577 .707 r
F P
0 g
s
.44919 .65939 m .45388 .62125 L .42497 .61715 L p .707 .577 .707 r
F P
0 g
s
.83826 .70277 m .83633 .72191 L .82342 .72013 L p .707 .577 .707 r
F P
0 g
s
.82342 .72013 m .82536 .701 L .83826 .70277 L p .707 .577 .707 r
F P
0 g
s
.64164 .68269 m .64634 .64454 L .66206 .64762 L p .707 .577 .707 r
F P
0 g
s
.3348 .60684 m .3301 .64498 L .35767 .64772 L p .707 .577 .707 r
F P
0 g
s
.35767 .64772 m .36236 .60958 L .3348 .60684 L p .707 .577 .707 r
F P
0 g
s
.38967 .67669 m .39161 .65755 L .3605 .6543 L p .707 .577 .707 r
F P
0 g
s
.39161 .65755 m .38967 .67669 L .42131 .67983 L p .707 .577 .707 r
F P
0 g
s
.42131 .67983 m .42324 .6607 L .39161 .65755 L p .707 .577 .707 r
F P
0 g
s
.3605 .6543 m .35857 .67343 L .38967 .67669 L p .707 .577 .707 r
F P
0 g
s
.33182 .61351 m .33482 .55646 L .31371 .552 L p .707 .577 .707 r
F P
0 g
s
.82904 .58228 m .82604 .63932 L .80493 .63486 L p .707 .577 .707 r
F P
0 g
s
.80493 .63486 m .80793 .57781 L .82904 .58228 L p .707 .577 .707 r
F P
0 g
s
.42324 .6607 m .42131 .67983 L .45038 .68256 L p .707 .577 .707 r
F P
0 g
s
.45038 .68256 m .45231 .66343 L .42324 .6607 L p .707 .577 .707 r
F P
0 g
s
.68552 .65139 m .68083 .68953 L .65736 .68576 L p .707 .577 .707 r
F P
0 g
s
.65736 .68576 m .66206 .64762 L .68552 .65139 L p .707 .577 .707 r
F P
0 g
s
.64324 .70222 m .64518 .68309 L .66111 .68425 L p .707 .577 .707 r
F P
0 g
s
.35857 .67343 m .3605 .6543 L .33298 .65126 L p .707 .577 .707 r
F P
0 g
s
.66111 .68425 m .65917 .70339 L .64324 .70222 L p .707 .577 .707 r
F P
0 g
s
.33298 .65126 m .33104 .67039 L .35857 .67343 L p .707 .577 .707 r
F P
0 g
s
.47265 .66316 m .47735 .62502 L .45388 .62125 L p .707 .577 .707 r
F P
0 g
s
.31371 .552 m .31071 .60904 L .33182 .61351 L p .707 .577 .707 r
F P
0 g
s
.66127 .62937 m .66427 .57233 L .68822 .57058 L p .707 .577 .707 r
F P
0 g
s
.31345 .60518 m .30875 .64333 L .3301 .64498 L p .707 .577 .707 r
F P
0 g
s
.3301 .64498 m .3348 .60684 L .31345 .60518 L p .707 .577 .707 r
F P
0 g
s
.47848 .56195 m .47548 .61899 L .49174 .61596 L p .707 .577 .707 r
F P
0 g
s
.49174 .61596 m .49473 .55891 L .47848 .56195 L p .707 .577 .707 r
F P
0 g
s
.82596 .66745 m .82126 .7056 L .79991 .70394 L p .707 .577 .707 r
F P
0 g
s
.45231 .66343 m .45038 .68256 L .47403 .68461 L p .707 .577 .707 r
F P
0 g
s
.47403 .68461 m .47597 .66547 L .45231 .66343 L p .707 .577 .707 r
F P
0 g
s
.79991 .70394 m .80461 .6658 L .82596 .66745 L p .707 .577 .707 r
F P
0 g
s
.68822 .57058 m .68522 .62763 L .66127 .62937 L p .707 .577 .707 r
F P
0 g
s
.33104 .67039 m .33298 .65126 L .31172 .64873 L p .707 .577 .707 r
F P
0 g
s
.31172 .64873 m .30978 .66786 L .33104 .67039 L p .707 .577 .707 r
F P
0 g
s
.31071 .60904 m .31371 .552 L .30103 .54721 L p .707 .577 .707 r
F P
0 g
s
.82536 .701 m .82342 .72013 L .80216 .7176 L p .707 .577 .707 r
F P
0 g
s
.80216 .7176 m .8041 .69847 L .82536 .701 L p .707 .577 .707 r
F P
0 g
s
.80793 .57781 m .80493 .63486 L .77745 .63115 L p .707 .577 .707 r
F P
0 g
s
.77745 .63115 m .78045 .57411 L .80793 .57781 L p .707 .577 .707 r
F P
0 g
s
.47735 .62502 m .47265 .66316 L .48837 .66624 L p .707 .577 .707 r
F P
0 g
s
.48837 .66624 m .49307 .62809 L .47735 .62502 L p .707 .577 .707 r
F P
0 g
s
.68522 .62763 m .68822 .57058 L .71752 .57031 L p .707 .577 .707 r
F P
0 g
s
.30103 .54721 m .29804 .60426 L .31071 .60904 L p .707 .577 .707 r
F P
0 g
s
.71444 .65548 m .70974 .69363 L .68083 .68953 L p .707 .577 .707 r
F P
0 g
s
.68083 .68953 m .68552 .65139 L .71444 .65548 L p .707 .577 .707 r
F P
0 g
s
.65917 .70339 m .66111 .68425 L .68477 .6863 L p .707 .577 .707 r
F P
0 g
s
.68477 .6863 m .68283 .70543 L .65917 .70339 L p .707 .577 .707 r
F P
0 g
s
.30039 .60477 m .29569 .64292 L .30875 .64333 L p .707 .577 .707 r
F P
0 g
s
.30875 .64333 m .31345 .60518 L .30039 .60477 L p .707 .577 .707 r
F P
0 g
s
.47597 .66547 m .47403 .68461 L .48996 .68577 L p .707 .577 .707 r
F P
0 g
s
.49307 .62809 m .48837 .66624 L .48938 .66656 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .4919 .66664 L .48939 .66645 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .48939 .66645 L .48755 .68227 L .707 .577 .707 r
F
.4919 .66664 m .48996 .68577 L .49661 .68594 L p F P
0 g
s
.49661 .68594 m .49854 .6668 L .4919 .66664 L p .707 .577 .707 r
F P
0 g
s
.48938 .66656 m .4948 .66832 L p .49328 .63312 L .707 .577 .707 r
F P
0 g
s
.49328 .63312 m .49307 .62809 L .48938 .66656 L .707 .577 .707 r
F
.48939 .66645 m .47597 .66547 L p .48755 .68227 L F P
0 g
s
.80461 .6658 m .79991 .70394 L .77235 .70121 L p .707 .577 .707 r
F P
0 g
s
.71752 .57031 m .71452 .62735 L .68522 .62763 L p .707 .577 .707 r
F P
0 g
s
.77235 .70121 m .77705 .66306 L .80461 .6658 L p .707 .577 .707 r
F P
0 g
s
.78045 .57411 m .77745 .63115 L .7463 .62857 L p .707 .577 .707 r
F P
0 g
s
.7463 .62857 m .7493 .57152 L .78045 .57411 L p .707 .577 .707 r
F P
0 g
s
.49473 .55891 m .49174 .61596 L .4987 .61193 L p .707 .577 .707 r
F P
0 g
s
.4987 .61193 m .5017 .55488 L .49473 .55891 L p .707 .577 .707 r
F P
0 g
s
.71452 .62735 m .71752 .57031 L .7493 .57152 L p .707 .577 .707 r
F P
0 g
s
.30978 .66786 m .31172 .64873 L .29881 .64695 L p .707 .577 .707 r
F P
0 g
s
.29881 .64695 m .29688 .66608 L .30978 .66786 L p .707 .577 .707 r
F P
0 g
s
.7493 .57152 m .7463 .62857 L .71452 .62735 L p .707 .577 .707 r
F P
0 g
s
.8041 .69847 m .80216 .7176 L .77464 .71456 L p .707 .577 .707 r
F P
0 g
s
.77464 .71456 m .77657 .69542 L .8041 .69847 L p .707 .577 .707 r
F P
0 g
s
.29804 .60426 m .30103 .54721 L .29803 .54258 L p .707 .577 .707 r
F P
0 g
s
.70974 .69363 m .71444 .65548 L .74598 .65951 L p .707 .577 .707 r
F P
0 g
s
.68283 .70543 m .68477 .6863 L .71383 .68903 L p .707 .577 .707 r
F P
0 g
s
.74598 .65951 m .74128 .69765 L .70974 .69363 L p .707 .577 .707 r
F P
0 g
s
.71383 .68903 m .7119 .70816 L .68283 .70543 L p .707 .577 .707 r
F P
0 g
s
.77705 .66306 m .77235 .70121 L .74128 .69765 L p .707 .577 .707 r
F P
0 g
s
.74128 .69765 m .74598 .65951 L .77705 .66306 L p .707 .577 .707 r
F P
0 g
s
.4948 .66832 m .4995 .63017 L .49307 .62809 L p .707 .577 .707 r
F P
0 g
s
.29803 .54258 m .29504 .59963 L .29804 .60426 L p .707 .577 .707 r
F P
0 g
s
.77657 .69542 m .77464 .71456 L .74353 .71131 L p .707 .577 .707 r
F P
0 g
s
.74353 .71131 m .74547 .69217 L .77657 .69542 L p .707 .577 .707 r
F P
0 g
s
.2969 .60565 m .2922 .6438 L .29569 .64292 L p .707 .577 .707 r
F P
0 g
s
.29569 .64292 m .30039 .60477 L .2969 .60565 L p .707 .577 .707 r
F P
0 g
s
.7119 .70816 m .71383 .68903 L .74547 .69217 L p .707 .577 .707 r
F P
0 g
s
.74547 .69217 m .74353 .71131 L .7119 .70816 L p .707 .577 .707 r
F P
0 g
s
.5017 .55488 m .4987 .61193 L .4957 .60729 L p .707 .577 .707 r
F P
0 g
s
.4957 .60729 m .4987 .55024 L .5017 .55488 L p .707 .577 .707 r
F P
0 g
s
.29688 .66608 m .29881 .64695 L .29552 .64611 L p .707 .577 .707 r
F P
0 g
s
.29552 .64611 m .29359 .66524 L .29688 .66608 L p .707 .577 .707 r
F P
0 g
s
.29504 .59963 m .29803 .54258 L .305 .53855 L p .707 .577 .707 r
F P
0 g
s
.4995 .63017 m .4948 .66832 L .49131 .66919 L p .707 .577 .707 r
F P
0 g
s
.49131 .66919 m .49601 .63105 L .4995 .63017 L p .707 .577 .707 r
F P
0 g
s
.305 .53855 m .302 .59559 L .29504 .59963 L p .707 .577 .707 r
F P
0 g
s
.49854 .6668 m .49661 .68594 L .49332 .68509 L p .707 .577 .707 r
F P
0 g
s
.49332 .68509 m .49525 .66596 L .49854 .6668 L p .707 .577 .707 r
F P
0 g
s
.30333 .60773 m .29863 .64587 L .2922 .6438 L p .707 .577 .707 r
F P
0 g
s
.2922 .6438 m .2969 .60565 L .30333 .60773 L p .707 .577 .707 r
F P
0 g
s
.4987 .55024 m .4957 .60729 L .48303 .60251 L p .707 .577 .707 r
F P
0 g
s
.48303 .60251 m .48603 .54546 L .4987 .55024 L p .707 .577 .707 r
F P
0 g
s
.31905 .6108 m .31435 .64895 L .30111 .64636 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .29552 .64611 L .30112 .64625 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .30112 .64625 L .30079 .64931 L .707 .577 .707 r
F
.30111 .64636 m .29863 .64587 L p .30173 .64055 L F P
0 g
s
.30173 .64055 m .31905 .6108 L .30111 .64636 L .707 .577 .707 r
F
.30112 .64625 m .30217 .64627 L p .30079 .64931 L F P
0 g
s
.30217 .64627 m .30023 .66541 L .29359 .66524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.302 .59559 m .305 .53855 L .32126 .53551 L p .707 .577 .707 r
F P
0 g
s
.49601 .63105 m .49131 .66919 L .47825 .66878 L p .707 .577 .707 r
F P
0 g
s
.47825 .66878 m .48295 .63064 L .49601 .63105 L p .707 .577 .707 r
F P
0 g
s
.32126 .53551 m .31826 .59256 L .302 .59559 L p .707 .577 .707 r
F P
0 g
s
.49525 .66596 m .49332 .68509 L .48041 .68332 L p .707 .577 .707 r
F P
0 g
s
.48041 .68332 m .48235 .66418 L .49525 .66596 L p .707 .577 .707 r
F P
0 g
s
.29863 .64587 m .30333 .60773 L .31905 .6108 L p .707 .577 .707 r
F P
0 g
s
.48603 .54546 m .48303 .60251 L .46192 .59805 L p .707 .577 .707 r
F P
0 g
s
.46192 .59805 m .46492 .541 L .48603 .54546 L p .707 .577 .707 r
F P
0 g
s
.34251 .61457 m .33782 .65272 L .31435 .64895 L p .707 .577 .707 r
F P
0 g
s
.31435 .64895 m .31905 .6108 L .34251 .61457 L p .707 .577 .707 r
F P
0 g
s
.30023 .66541 m .30217 .64627 L .3181 .64744 L p .707 .577 .707 r
F P
0 g
s
.3181 .64744 m .31616 .66657 L .30023 .66541 L p .707 .577 .707 r
F P
0 g
s
.31826 .59256 m .32126 .53551 L .3452 .53377 L p .707 .577 .707 r
F P
0 g
s
.48295 .63064 m .47825 .66878 L .4569 .66713 L p .707 .577 .707 r
F P
0 g
s
.4569 .66713 m .4616 .62898 L .48295 .63064 L p .707 .577 .707 r
F P
0 g
s
.3452 .53377 m .34221 .59082 L .31826 .59256 L p .707 .577 .707 r
F P
0 g
s
.48235 .66418 m .48041 .68332 L .45915 .68078 L p .707 .577 .707 r
F P
0 g
s
.45915 .68078 m .46109 .66165 L .48235 .66418 L p .707 .577 .707 r
F P
0 g
s
.46492 .541 m .46192 .59805 L .43444 .59434 L p .707 .577 .707 r
F P
0 g
s
.43444 .59434 m .43744 .53729 L .46492 .541 L p .707 .577 .707 r
F P
0 g
s
.34221 .59082 m .3452 .53377 L .3745 .53349 L p .707 .577 .707 r
F P
0 g
s
.37143 .61867 m .36673 .65681 L .33782 .65272 L p .707 .577 .707 r
F P
0 g
s
.33782 .65272 m .34251 .61457 L .37143 .61867 L p .707 .577 .707 r
F P
0 g
s
.31616 .66657 m .3181 .64744 L .34175 .64948 L p .707 .577 .707 r
F P
0 g
s
.34175 .64948 m .33982 .66862 L .31616 .66657 L p .707 .577 .707 r
F P
0 g
s
.4616 .62898 m .4569 .66713 L .42934 .66439 L p .707 .577 .707 r
F P
0 g
s
.3745 .53349 m .37151 .59054 L .34221 .59082 L p .707 .577 .707 r
F P
0 g
s
.42934 .66439 m .43403 .62625 L .4616 .62898 L p .707 .577 .707 r
F P
0 g
s
.43744 .53729 m .43444 .59434 L .40329 .59175 L p .707 .577 .707 r
F P
0 g
s
.40329 .59175 m .40629 .53471 L .43744 .53729 L p .707 .577 .707 r
F P
0 g
s
.37151 .59054 m .3745 .53349 L .40629 .53471 L p .707 .577 .707 r
F P
0 g
s
.40629 .53471 m .40329 .59175 L .37151 .59054 L p .707 .577 .707 r
F P
0 g
s
.46109 .66165 m .45915 .68078 L .43163 .67774 L p .707 .577 .707 r
F P
0 g
s
.43163 .67774 m .43356 .65861 L .46109 .66165 L p .707 .577 .707 r
F P
0 g
s
.36673 .65681 m .37143 .61867 L .40297 .62269 L p .707 .577 .707 r
F P
0 g
s
.33982 .66862 m .34175 .64948 L .37082 .65221 L p .707 .577 .707 r
F P
0 g
s
.40297 .62269 m .39827 .66084 L .36673 .65681 L p .707 .577 .707 r
F P
0 g
s
.37082 .65221 m .36889 .67135 L .33982 .66862 L p .707 .577 .707 r
F P
0 g
s
.43403 .62625 m .42934 .66439 L .39827 .66084 L p .707 .577 .707 r
F P
0 g
s
.39827 .66084 m .40297 .62269 L .43403 .62625 L p .707 .577 .707 r
F P
0 g
s
.43356 .65861 m .43163 .67774 L .40052 .67449 L p .707 .577 .707 r
F P
0 g
s
.40052 .67449 m .40246 .65536 L .43356 .65861 L p .707 .577 .707 r
F P
0 g
s
.36889 .67135 m .37082 .65221 L .40246 .65536 L p .707 .577 .707 r
F P
0 g
s
.40246 .65536 m .40052 .67449 L .36889 .67135 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002:Ool=0026Ool0085oo`T0
00IJEP03001JEUYF00AJEPT007eoo`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001eOol60008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol0075oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEP00001aOol006ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Mo
o`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Io
o`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005mooa4000QJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Aoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001F
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0I7oo001DOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo009ooah004Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003aoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0031oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Goo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001COol00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol@000;Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH70003FUH00`00
FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol60003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF00000003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo000_Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH?0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000]Ool30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF1P0000=JEP00FUH0
0UYF20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF1`000UYF
00@005YFFUIJEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP04001JEUYFFUH7
0003FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040008FUH00`00FUIJEP02FUH=0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPL00003FUH005YF00MJEP03001JEUYF
00H000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`0000AJEP00FUIJEP<000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF7P0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH0200015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00P0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF1@00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00H0009JEQ0000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF1@0000=JEP00FUH01UYF00<005YFFUH00UYF
2@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF2@000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YFFUH005YF0004FUH00`00FUIJEP0800000eYF001JEP07FUH00`00FUIJEP02FUH60005FUH0
0`00FUIJEP04FUH00`00FUIJEP04000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0000=JEP00FUH01eYF00<005YF00003P00<Woo000/Ool00`00FUH00002
FUH?0007FUH90003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00=JEPH003Moo`00;7oo00<005YF00000`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPh000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00@005YFFUIJEPD0039oo`00;7oo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH@000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000A0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
0UYF2P000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000dOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP<00003FUH0000000L0009JEPL000=JEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00UYF1@001UYF0P0000=J
EP000000400015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00A7oo7`000goo00@005YFFUH000AJEPD000IJEP8000YJEP04001J
EUYFFUH50004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001VOol01000FUIJEP0015YF1@001UYF0P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000]Ool8000aOol01000FUIJEP001EYF0`001eYF0P002UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`@00004FUH005YFFUH?000ROol01000FUIJEP001UYF00<005YFFUH01UYF
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70002FUH01000FUIJEUYF0P00;Woo000]Ool01000FUH005YF1P0000=JEP00FUH01UYF
00@005YFFUIJEPL001]oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000040002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08
000^Ool002eoo`03001JEP0000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04
000GOol01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<0
05YFFUH015YF00@005YFFUIJEPT00003FUH005YF00EJEPL0011oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH005YF4`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH00eYF1`002Goo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEP0000IJEP03001JEUYF009JEP<000=oo``000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP060003Ool01000FUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH00UYF00<005YF000027oo0`0000=oo`000000
2@000eYF00<005YFFUH015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3`000UYF00<005YF
FUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH0100027oo1@0027oo3`00
00=JEP000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH<000<Ool5000@Ool:000^Ool002aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`0EOol50018Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF
000@FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`0FOol30019Ool002aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol002eoo`<0009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP06FUHO0008FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol0031oo`H000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0>FUH00`00FUIJEP06000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003Ioo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP040006FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003eoo`T000AJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF
00<005YFFUH00eYF1`00GWoo0016Ool90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`000UYF00<005YFFUH015YF00H005YF000005YF000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEP000eYF1@00FGoo
001?Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@0
05YF000000EJEPP0009JEP03001JEP00008005Ioo`00Egoo40000UYF00@005YFFUIJEP8000IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP09001DOol006Ioo`05001JEUYF001JEP03
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
001VOol00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol004Qoo`<001]oo`<0
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0017Ool5000JOol30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00;Goo10005Woo1@006Woo00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol002eoo`80009JEPd000Uoo`D001Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP03001J
EUYF00AJEP04001JEUYFFUH9000017oo0000000077oo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200047oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01`000eYF00@005YFFUIJEP8005Eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEP`000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH2000:Ool9001EOol0
02aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00008000Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF001ZOol003Aooa8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000Ioo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<006]oo`00
>goo20000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP<006eoo`00@goo2@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000Yoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0071oo`00
C7oo2@000UYF1`000eYF00@005YFFUIJEP8000eoo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEPD00003Ool0000000<006moo`00EGoo4P004Goo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00@005YFFUIJEPH000Ioo`D006moo`00HWoo1@005goo:P0000=oo`0000000`00
Kgoo002>Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001/
Ool008eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPP006Aoo`00SGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL005eoo`00SGoo1@000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH02000EGoo
002@Ool?0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo002EOol70003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002LOolE0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH005Aoo`00[Woo2`0015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo002fOol?
00000eYF0000001EOol00;ioo`X005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59626 .72343 m .59925 .66638 L .5681 .6638 L p .707 .577 .707 r
F P
0 g
s
.59925 .66638 m .59626 .72343 L .62804 .72464 L p .707 .577 .707 r
F P
0 g
s
.62804 .72464 m .63104 .6676 L .59925 .66638 L p .707 .577 .707 r
F P
0 g
s
.63104 .6676 m .62804 .72464 L .65734 .72437 L p .707 .577 .707 r
F P
0 g
s
.65734 .72437 m .66034 .66732 L .63104 .6676 L p .707 .577 .707 r
F P
0 g
s
.5651 .72084 m .5681 .6638 L .54062 .66009 L p .707 .577 .707 r
F P
0 g
s
.5681 .6638 m .5651 .72084 L .59626 .72343 L p .707 .577 .707 r
F P
0 g
s
.54062 .66009 m .53763 .71714 L .5651 .72084 L p .707 .577 .707 r
F P
0 g
s
.66034 .66732 m .65734 .72437 L .68129 .72262 L p .707 .577 .707 r
F P
0 g
s
.68129 .72262 m .68429 .66558 L .66034 .66732 L p .707 .577 .707 r
F P
0 g
s
.56817 .73638 m .56347 .77452 L .59454 .77808 L p .707 .577 .707 r
F P
0 g
s
.59454 .77808 m .59924 .73993 L .56817 .73638 L p .707 .577 .707 r
F P
0 g
s
.59924 .73993 m .59454 .77808 L .62608 .7821 L p .707 .577 .707 r
F P
0 g
s
.62608 .7821 m .63077 .74395 L .59924 .73993 L p .707 .577 .707 r
F P
0 g
s
.63077 .74395 m .62608 .7821 L .65499 .7862 L p .707 .577 .707 r
F P
0 g
s
.53763 .71714 m .54062 .66009 L .51952 .65563 L p .707 .577 .707 r
F P
0 g
s
.65499 .7862 m .65969 .74805 L .63077 .74395 L p .707 .577 .707 r
F P
0 g
s
.54061 .73364 m .53591 .77178 L .56347 .77452 L p .707 .577 .707 r
F P
0 g
s
.56347 .77452 m .56817 .73638 L .54061 .73364 L p .707 .577 .707 r
F P
0 g
s
.51952 .65563 m .51652 .71267 L .53763 .71714 L p .707 .577 .707 r
F P
0 g
s
.65969 .74805 m .65499 .7862 L .67846 .78996 L p .707 .577 .707 r
F P
0 g
s
.67846 .78996 m .68315 .75182 L .65969 .74805 L p .707 .577 .707 r
F P
0 g
s
.68429 .66558 m .68129 .72262 L .69754 .71959 L p .707 .577 .707 r
F P
0 g
s
.69754 .71959 m .70054 .66254 L .68429 .66558 L p .707 .577 .707 r
F P
0 g
s
.59548 .84732 m .59741 .82819 L .56631 .82493 L p .707 .577 .707 r
F P
0 g
s
.59741 .82819 m .59548 .84732 L .62711 .85046 L p .707 .577 .707 r
F P
0 g
s
.62711 .85046 m .62905 .83133 L .59741 .82819 L p .707 .577 .707 r
F P
0 g
s
.56631 .82493 m .56438 .84407 L .59548 .84732 L p .707 .577 .707 r
F P
0 g
s
.51925 .73198 m .51455 .77013 L .53591 .77178 L p .707 .577 .707 r
F P
0 g
s
.53591 .77178 m .54061 .73364 L .51925 .73198 L p .707 .577 .707 r
F P
0 g
s
.62905 .83133 m .62711 .85046 L .65618 .85319 L p .707 .577 .707 r
F P
0 g
s
.65618 .85319 m .65812 .83406 L .62905 .83133 L p .707 .577 .707 r
F P
0 g
s
.51652 .71267 m .51952 .65563 L .50684 .65084 L p .707 .577 .707 r
F P
0 g
s
.56438 .84407 m .56631 .82493 L .53878 .82189 L p .707 .577 .707 r
F P
0 g
s
.53878 .82189 m .53685 .84103 L .56438 .84407 L p .707 .577 .707 r
F P
0 g
s
.50684 .65084 m .50384 .70789 L .51652 .71267 L p .707 .577 .707 r
F P
0 g
s
.68315 .75182 m .67846 .78996 L .69417 .79304 L p .707 .577 .707 r
F P
0 g
s
.65812 .83406 m .65618 .85319 L .67984 .85524 L p .707 .577 .707 r
F P
0 g
s
.67984 .85524 m .68177 .83611 L .65812 .83406 L p .707 .577 .707 r
F P
0 g
s
.69417 .79304 m .69887 .75489 L .68315 .75182 L p .707 .577 .707 r
F P
0 g
s
.53685 .84103 m .53878 .82189 L .51753 .81936 L p .707 .577 .707 r
F P
0 g
s
.51753 .81936 m .51559 .83849 L .53685 .84103 L p .707 .577 .707 r
F P
0 g
s
.70054 .66254 m .69754 .71959 L .70451 .71556 L p .707 .577 .707 r
F P
0 g
s
.70451 .71556 m .70751 .65851 L .70054 .66254 L p .707 .577 .707 r
F P
0 g
s
.50619 .73158 m .5015 .76972 L .51455 .77013 L p .707 .577 .707 r
F P
0 g
s
.51455 .77013 m .51925 .73198 L .50619 .73158 L p .707 .577 .707 r
F P
0 g
s
.50384 .70789 m .50684 .65084 L .50384 .64621 L p .707 .577 .707 r
F P
0 g
s
.68177 .83611 m .67984 .85524 L .69577 .8564 L p .707 .577 .707 r
F P
0 g
s
.69577 .8564 m .6977 .83727 L .68177 .83611 L p .707 .577 .707 r
F P
0 g
s
.50384 .64621 m .50084 .70326 L .50384 .70789 L p .707 .577 .707 r
F P
0 g
s
.69887 .75489 m .69417 .79304 L .7006 .79512 L p .707 .577 .707 r
F P
0 g
s
.7006 .79512 m .7053 .75697 L .69887 .75489 L p .707 .577 .707 r
F P
0 g
s
.51559 .83849 m .51753 .81936 L .50462 .81759 L p .707 .577 .707 r
F P
0 g
s
.50462 .81759 m .50268 .83672 L .51559 .83849 L p .707 .577 .707 r
F P
0 g
s
.50271 .73245 m .49801 .7706 L .5015 .76972 L p .707 .577 .707 r
F P
0 g
s
.5015 .76972 m .50619 .73158 L .50271 .73245 L p .707 .577 .707 r
F P
0 g
s
.70751 .65851 m .70451 .71556 L .70151 .71092 L p .707 .577 .707 r
F P
0 g
s
.70151 .71092 m .70451 .65388 L .70751 .65851 L p .707 .577 .707 r
F P
0 g
s
.49654 .82253 m .48928 .32586 L .44527 .32343 L p .707 .577 .707 r
F P
0 g
s
.50084 .70326 m .50384 .64621 L .51081 .64218 L p .707 .577 .707 r
F P
0 g
s
.51081 .64218 m .50781 .69922 L .50084 .70326 L p .707 .577 .707 r
F P
0 g
s
.50268 .83672 m .50462 .81759 L .50133 .81674 L p .707 .577 .707 r
F P
0 g
s
.50133 .81674 m .49939 .83587 L .50268 .83672 L p .707 .577 .707 r
F P
0 g
s
.50914 .73453 m .50444 .77267 L .49801 .7706 L p .707 .577 .707 r
F P
0 g
s
.49801 .7706 m .50271 .73245 L .50914 .73453 L p .707 .577 .707 r
F P
0 g
s
.50781 .69922 m .51081 .64218 L .52706 .63914 L p .707 .577 .707 r
F P
0 g
s
.52706 .63914 m .52406 .69619 L .50781 .69922 L p .707 .577 .707 r
F P
0 g
s
.49939 .83587 m .50133 .81674 L .50797 .81691 L p .707 .577 .707 r
F P
0 g
s
.50797 .81691 m .50604 .83604 L .49939 .83587 L p .707 .577 .707 r
F P
0 g
s
.52486 .7376 m .52016 .77575 L .50444 .77267 L p .707 .577 .707 r
F P
0 g
s
.50444 .77267 m .50914 .73453 L .52486 .7376 L p .707 .577 .707 r
F P
0 g
s
.52406 .69619 m .52706 .63914 L .55101 .6374 L p .707 .577 .707 r
F P
0 g
s
.55101 .6374 m .54801 .69445 L .52406 .69619 L p .707 .577 .707 r
F P
0 g
s
.50604 .83604 m .50797 .81691 L .5239 .81807 L p .707 .577 .707 r
F P
0 g
s
.5239 .81807 m .52197 .8372 L .50604 .83604 L p .707 .577 .707 r
F P
0 g
s
.54832 .74137 m .54362 .77952 L .52016 .77575 L p .707 .577 .707 r
F P
0 g
s
.52016 .77575 m .52486 .7376 L .54832 .74137 L p .707 .577 .707 r
F P
0 g
s
.52197 .8372 m .5239 .81807 L .54756 .82012 L p .707 .577 .707 r
F P
0 g
s
.48928 .32586 m .49654 .82253 L .54148 .82069 L p .707 .577 .707 r
F P
0 g
s
.54148 .82069 m .53422 .32403 L .48928 .32586 L p .707 .577 .707 r
F P
0 g
s
.54801 .69445 m .55101 .6374 L .58031 .63712 L p .707 .577 .707 r
F P
0 g
s
.58031 .63712 m .57731 .69417 L .54801 .69445 L p .707 .577 .707 r
F P
0 g
s
.57724 .74547 m .57254 .78362 L .54362 .77952 L p .707 .577 .707 r
F P
0 g
s
.54362 .77952 m .54832 .74137 L .57724 .74547 L p .707 .577 .707 r
F P
0 g
s
.60877 .74949 m .60407 .78764 L .57254 .78362 L p .707 .577 .707 r
F P
0 g
s
.57254 .78362 m .57724 .74547 L .60877 .74949 L p .707 .577 .707 r
F P
0 g
s
.53422 .32403 m .54148 .82069 L .58295 .81477 L p .707 .577 .707 r
F P
0 g
s
.57731 .69417 m .58031 .63712 L .61209 .63834 L p .707 .577 .707 r
F P
0 g
s
.61209 .63834 m .6091 .69538 L .57731 .69417 L p .707 .577 .707 r
F P
0 g
s
.58295 .81477 m .57569 .31811 L .53422 .32403 L p .707 .577 .707 r
F P
0 g
s
.6977 .83727 m .69577 .8564 L .70241 .85657 L p .707 .577 .707 r
F P
0 g
s
.70241 .85657 m .70435 .83744 L .6977 .83727 L p .707 .577 .707 r
F P
0 g
s
.45253 .8201 m .44527 .32343 L .40651 .31698 L p .707 .577 .707 r
F P
0 g
s
.44527 .32343 m .45253 .8201 L .49654 .82253 L p .707 .577 .707 r
F P
0 g
s
.7053 .75697 m .7006 .79512 L .69712 .79599 L p .707 .577 .707 r
F P
0 g
s
.69712 .79599 m .70182 .75785 L .7053 .75697 L p .707 .577 .707 r
F P
0 g
s
.63984 .75305 m .63514 .79119 L .61341 .78871 L p .707 .577 .707 r
F P
0 g
s
.61341 .78871 m .60407 .78764 L p .61413 .77791 L .707 .577 .707 r
F P
0 g
s
.61413 .77791 m .63984 .75305 L .61341 .78871 L .707 .577 .707 r
F
.67072 .64463 m .66773 .70168 L .64025 .69797 L p F P
0 g
s
.64025 .69797 m .64325 .64092 L .67072 .64463 L p .707 .577 .707 r
F P
0 g
s
.64325 .64092 m .64025 .69797 L .6091 .69538 L p .707 .577 .707 r
F P
0 g
s
.6091 .69538 m .61209 .63834 L .64325 .64092 L p .707 .577 .707 r
F P
0 g
s
.6674 .75579 m .6627 .79393 L .63514 .79119 L p .707 .577 .707 r
F P
0 g
s
.63514 .79119 m .63984 .75305 L .6674 .75579 L p .707 .577 .707 r
F P
0 g
s
.60407 .78764 m .60877 .74949 L .63984 .75305 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .64998 .77993 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63273 .29668 m .63517 .46314 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.63517 .46314 m .63999 .79335 L p .63745 .42892 L .707 .577 .707 r
F P
0 g
s
.57569 .31811 m .58295 .81477 L .6169 .80535 L p .707 .577 .707 r
F P
0 g
s
.6169 .80535 m .60964 .30869 L .57569 .31811 L p .707 .577 .707 r
F P
0 g
s
.70451 .65388 m .70151 .71092 L .68883 .70614 L p .707 .577 .707 r
F P
0 g
s
.68883 .70614 m .69183 .64909 L .70451 .65388 L p .707 .577 .707 r
F P
0 g
s
.41377 .81364 m .40651 .31698 L .37677 .30713 L p .707 .577 .707 r
F P
0 g
s
.40651 .31698 m .41377 .81364 L .45253 .8201 L p .707 .577 .707 r
F P
0 g
s
.25325 .68661 m .25625 .62957 L .22509 .62698 L p .707 .577 .707 r
F P
0 g
s
.25625 .62957 m .25325 .68661 L .28503 .68783 L p .707 .577 .707 r
F P
0 g
s
.28503 .68783 m .28803 .63078 L .25625 .62957 L p .707 .577 .707 r
F P
0 g
s
.28803 .63078 m .28503 .68783 L .31433 .68755 L p .707 .577 .707 r
F P
0 g
s
.31433 .68755 m .31733 .6305 L .28803 .63078 L p .707 .577 .707 r
F P
0 g
s
.70435 .83744 m .70241 .85657 L .69912 .85573 L p .707 .577 .707 r
F P
0 g
s
.69912 .85573 m .70106 .83659 L .70435 .83744 L p .707 .577 .707 r
F P
0 g
s
.22209 .68403 m .22509 .62698 L .19762 .62328 L p .707 .577 .707 r
F P
0 g
s
.22509 .62698 m .22209 .68403 L .25325 .68661 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19762 .62328 m .19462 .68032 L .22209 .68403 L p .707 .577 .707 r
F P
0 g
s
.70182 .75785 m .69712 .79599 L .68406 .79559 L p .707 .577 .707 r
F P
0 g
s
.31733 .6305 m .31433 .68755 L .33828 .68581 L p .707 .577 .707 r
F P
0 g
s
.33828 .68581 m .34128 .62876 L .31733 .6305 L p .707 .577 .707 r
F P
0 g
s
.60964 .30869 m .6169 .80535 L .63999 .79335 L p .707 .577 .707 r
F P
0 g
s
.63999 .79335 m .63273 .29668 L .60964 .30869 L p .707 .577 .707 r
F P
0 g
s
.68406 .79559 m .68876 .75744 L .70182 .75785 L p .707 .577 .707 r
F P
0 g
s
.22516 .69956 m .22046 .73771 L .25153 .74126 L p .707 .577 .707 r
F P
0 g
s
.25153 .74126 m .25623 .70312 L .22516 .69956 L p .707 .577 .707 r
F P
0 g
s
.25623 .70312 m .25153 .74126 L .28307 .74528 L p .707 .577 .707 r
F P
0 g
s
.28307 .74528 m .28777 .70714 L .25623 .70312 L p .707 .577 .707 r
F P
0 g
s
.28777 .70714 m .28307 .74528 L .31198 .74938 L p .707 .577 .707 r
F P
0 g
s
.19462 .68032 m .19762 .62328 L .17651 .61881 L p .707 .577 .707 r
F P
0 g
s
.69183 .64909 m .68883 .70614 L .66773 .70168 L p .707 .577 .707 r
F P
0 g
s
.66773 .70168 m .67072 .64463 L .69183 .64909 L p .707 .577 .707 r
F P
0 g
s
.31198 .74938 m .31668 .71123 L .28777 .70714 L p .707 .577 .707 r
F P
0 g
s
.1976 .69682 m .1929 .73497 L .22046 .73771 L p .707 .577 .707 r
F P
0 g
s
.22046 .73771 m .22516 .69956 L .1976 .69682 L p .707 .577 .707 r
F P
0 g
s
.17651 .61881 m .17351 .67586 L .19462 .68032 L p .707 .577 .707 r
F P
0 g
s
.38403 .80379 m .37677 .30713 L .35899 .29485 L p .707 .577 .707 r
F P
0 g
s
.37677 .30713 m .38403 .80379 L .41377 .81364 L p .707 .577 .707 r
F P
0 g
s
.31668 .71123 m .31198 .74938 L .33545 .75315 L p .707 .577 .707 r
F P
0 g
s
.70106 .83659 m .69912 .85573 L .68622 .85395 L p .707 .577 .707 r
F P
0 g
s
.68622 .85395 m .68815 .83482 L .70106 .83659 L p .707 .577 .707 r
F P
0 g
s
.33545 .75315 m .34015 .715 L .31668 .71123 L p .707 .577 .707 r
F P
0 g
s
.34128 .62876 m .33828 .68581 L .35453 .68277 L p .707 .577 .707 r
F P
0 g
s
.35453 .68277 m .35753 .62573 L .34128 .62876 L p .707 .577 .707 r
F P
0 g
s
.25247 .8105 m .2544 .79137 L .2233 .78812 L p .707 .577 .707 r
F P
0 g
s
.2544 .79137 m .25247 .8105 L .2841 .81365 L p .707 .577 .707 r
F P
0 g
s
.2841 .81365 m .28604 .79452 L .2544 .79137 L p .707 .577 .707 r
F P
0 g
s
.2233 .78812 m .22137 .80725 L .25247 .8105 L p .707 .577 .707 r
F P
0 g
s
.17624 .69517 m .17155 .73331 L .1929 .73497 L p .707 .577 .707 r
F P
0 g
s
.1929 .73497 m .1976 .69682 L .17624 .69517 L p .707 .577 .707 r
F P
0 g
s
.28604 .79452 m .2841 .81365 L .31317 .81638 L p .707 .577 .707 r
F P
0 g
s
.31317 .81638 m .31511 .79724 L .28604 .79452 L p .707 .577 .707 r
F P
0 g
s
.68876 .75744 m .68406 .79559 L .6627 .79393 L p .707 .577 .707 r
F P
0 g
s
.6627 .79393 m .6674 .75579 L .68876 .75744 L p .707 .577 .707 r
F P
0 g
s
.17351 .67586 m .17651 .61881 L .16383 .61403 L p .707 .577 .707 r
F P
0 g
s
.22137 .80725 m .2233 .78812 L .19577 .78508 L p .707 .577 .707 r
F P
0 g
s
.19577 .78508 m .19384 .80421 L .22137 .80725 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64272 .28327 L .63273 .29668 L p .707 .577 .707 r
F P
0 g
s
.16383 .61403 m .16083 .67108 L .17351 .67586 L p .707 .577 .707 r
F P
0 g
s
.34015 .715 m .33545 .75315 L .35116 .75622 L p .707 .577 .707 r
F P
0 g
s
.31511 .79724 m .31317 .81638 L .33683 .81842 L p .707 .577 .707 r
F P
0 g
s
.33683 .81842 m .33876 .79929 L .31511 .79724 L p .707 .577 .707 r
F P
0 g
s
.35116 .75622 m .35586 .71808 L .34015 .715 L p .707 .577 .707 r
F P
0 g
s
.19384 .80421 m .19577 .78508 L .17452 .78255 L p .707 .577 .707 r
F P
0 g
s
.17452 .78255 m .17258 .80168 L .19384 .80421 L p .707 .577 .707 r
F P
0 g
s
.35753 .62573 m .35453 .68277 L .3615 .67874 L p .707 .577 .707 r
F P
0 g
s
.3615 .67874 m .3645 .62169 L .35753 .62573 L p .707 .577 .707 r
F P
0 g
s
.16318 .69476 m .15849 .73291 L .17155 .73331 L p .707 .577 .707 r
F P
0 g
s
.17155 .73331 m .17624 .69517 L .16318 .69476 L p .707 .577 .707 r
F P
0 g
s
.68815 .83482 m .68622 .85395 L .66496 .85142 L p .707 .577 .707 r
F P
0 g
s
.66496 .85142 m .66689 .83228 L .68815 .83482 L p .707 .577 .707 r
F P
0 g
s
.3645 .62169 m .3615 .67874 L .3585 .67411 L p .707 .577 .707 r
F P
0 g
s
.3585 .67411 m .3615 .61706 L .3645 .62169 L p .707 .577 .707 r
F P
0 g
s
.36625 .79152 m .35899 .29485 L .35489 .28134 L p .707 .577 .707 r
F P
0 g
s
.35899 .29485 m .36625 .79152 L .38403 .80379 L p .707 .577 .707 r
F P
0 g
s
.54756 .82012 m .54563 .83925 L .52197 .8372 L p .707 .577 .707 r
F P
0 g
s
.16083 .67108 m .16383 .61403 L .16083 .6094 L p .707 .577 .707 r
F P
0 g
s
.33876 .79929 m .33683 .81842 L .35276 .81959 L p .707 .577 .707 r
F P
0 g
s
.35276 .81959 m .35469 .80046 L .33876 .79929 L p .707 .577 .707 r
F P
0 g
s
.16083 .6094 m .15783 .66644 L .16083 .67108 L p .707 .577 .707 r
F P
0 g
s
.35586 .71808 m .35116 .75622 L .35759 .7583 L p .707 .577 .707 r
F P
0 g
s
.35759 .7583 m .36229 .72016 L .35586 .71808 L p .707 .577 .707 r
F P
0 g
s
.17258 .80168 m .17452 .78255 L .16161 .78077 L p .707 .577 .707 r
F P
0 g
s
.16161 .78077 m .15968 .7999 L .17258 .80168 L p .707 .577 .707 r
F P
0 g
s
.66689 .83228 m .66496 .85142 L .63743 .84838 L p .707 .577 .707 r
F P
0 g
s
.63743 .84838 m .63937 .82924 L .66689 .83228 L p .707 .577 .707 r
F P
0 g
s
.1597 .69564 m .155 .73378 L .15849 .73291 L p .707 .577 .707 r
F P
0 g
s
.15849 .73291 m .16318 .69476 L .1597 .69564 L p .707 .577 .707 r
F P
0 g
s
.64998 .77993 m .64769 .77239 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64272 .28327 m .64964 .75634 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64964 .75634 m .64998 .77993 L p .64723 .72699 L .707 .577 .707 r
F P
0 g
s
.64564 .72985 m .64272 .28327 L .6476 .76343 L .707 .577 .707 r
F
.64655 .74877 m .6476 .76343 L .64769 .77239 L F
.64564 .72985 m .6476 .76343 L .64655 .74877 L F
.63862 .26976 m .64272 .28327 L p .6451 .64759 L F P
0 g
s
.64431 .64561 m .63862 .26976 L .6451 .64759 L .707 .577 .707 r
F
.64538 .73238 m .63862 .26976 L p .64569 .73662 L F P
0 g
s
.63862 .26976 m .64588 .76643 L .6281 .75415 L p .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64104 .5794 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64105 .64108 m .64121 .6379 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64404 .58403 L p .64105 .63748 L .707 .577 .707 r
F P
0 g
s
.64569 .73662 m .64431 .64561 L .6451 .64759 L .707 .577 .707 r
F
.64588 .76643 m .64538 .73238 L p .64569 .73662 L F P
0 g
s
.64182 .68377 m .63989 .7029 L .64331 .70337 L p .707 .577 .707 r
F P
0 g
s
.64331 .70337 m .65279 .70468 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.64193 .68397 m .64182 .68377 L .64331 .70337 L .707 .577 .707 r
F
.65279 .70468 m .65473 .68554 L .64192 .68378 L p F P
0 g
s
.64192 .68378 m .64182 .68377 L p .64193 .68397 L .707 .577 .707 r
F P
0 g
s
.65279 .70468 m .64192 .68378 L .64193 .68397 L .707 .577 .707 r
F
.64137 .6412 m .65372 .64586 L p .64121 .6379 L F P
0 g
s
.6434 .64159 m .64149 .65704 L p .65176 .68014 L .707 .577 .707 r
F P
0 g
s
.64149 .65704 m .6387 .67973 L .64337 .67988 L p .707 .577 .707 r
F P
0 g
s
.64337 .67988 m .65176 .68014 L p .64149 .65704 L .707 .577 .707 r
F P
0 g
s
.64404 .58403 m .64121 .6379 L p .65372 .64586 L .707 .577 .707 r
F P
0 g
s
.64121 .6379 m .64105 .64108 L .64137 .6412 L p .707 .577 .707 r
F P
0 g
s
.64769 .77239 m .64588 .76643 L p .64564 .72985 L .707 .577 .707 r
F P
0 g
s
.54563 .83925 m .54756 .82012 L .57663 .82285 L p .707 .577 .707 r
F P
0 g
s
.57663 .82285 m .57469 .84198 L .54563 .83925 L p .707 .577 .707 r
F P
0 g
s
.63937 .82924 m .63743 .84838 L .60633 .84512 L p .707 .577 .707 r
F P
0 g
s
.60633 .84512 m .60826 .82599 L .63937 .82924 L p .707 .577 .707 r
F P
0 g
s
.35469 .80046 m .35276 .81959 L .3594 .81976 L p .707 .577 .707 r
F P
0 g
s
.3594 .81976 m .36134 .80062 L .35469 .80046 L p .707 .577 .707 r
F P
0 g
s
.15783 .66644 m .16083 .6094 L .1678 .60536 L p .707 .577 .707 r
F P
0 g
s
.57469 .84198 m .57663 .82285 L .60826 .82599 L p .707 .577 .707 r
F P
0 g
s
.60826 .82599 m .60633 .84512 L .57469 .84198 L p .707 .577 .707 r
F P
0 g
s
.36229 .72016 m .35759 .7583 L .35411 .75918 L p .707 .577 .707 r
F P
0 g
s
.35411 .75918 m .35881 .72103 L .36229 .72016 L p .707 .577 .707 r
F P
0 g
s
.3615 .61706 m .3585 .67411 L .34583 .66932 L p .707 .577 .707 r
F P
0 g
s
.34583 .66932 m .34882 .61228 L .3615 .61706 L p .707 .577 .707 r
F P
0 g
s
.35489 .28134 m .36215 .77801 L .36625 .79152 L p .707 .577 .707 r
F P
0 g
s
.36215 .77801 m .35489 .28134 L .36488 .26793 L p .707 .577 .707 r
F P
0 g
s
.1678 .60536 m .1648 .66241 L .15783 .66644 L p .707 .577 .707 r
F P
0 g
s
.15968 .7999 m .16161 .78077 L .15832 .77992 L p .707 .577 .707 r
F P
0 g
s
.15832 .77992 m .15638 .79906 L .15968 .7999 L p .707 .577 .707 r
F P
0 g
s
.16613 .69771 m .16143 .73586 L .155 .73378 L p .707 .577 .707 r
F P
0 g
s
.155 .73378 m .1597 .69564 L .16613 .69771 L p .707 .577 .707 r
F P
0 g
s
.36134 .80062 m .3594 .81976 L .35611 .81891 L p .707 .577 .707 r
F P
0 g
s
.35611 .81891 m .35805 .79978 L .36134 .80062 L p .707 .577 .707 r
F P
0 g
s
.1648 .66241 m .1678 .60536 L .18405 .60233 L p .707 .577 .707 r
F P
0 g
s
.6281 .75415 m .62084 .25749 L .63862 .26976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18405 .60233 m .18105 .65937 L .1648 .66241 L p .707 .577 .707 r
F P
0 g
s
.35881 .72103 m .35411 .75918 L .34105 .75877 L p .707 .577 .707 r
F P
0 g
s
.15638 .79906 m .15832 .77992 L .16496 .78009 L p .707 .577 .707 r
F P
0 g
s
.16496 .78009 m .16303 .79922 L .15638 .79906 L p .707 .577 .707 r
F P
0 g
s
.34105 .75877 m .34575 .72062 L .35881 .72103 L p .707 .577 .707 r
F P
0 g
s
.34882 .61228 m .34583 .66932 L .32472 .66486 L p .707 .577 .707 r
F P
0 g
s
.32472 .66486 m .32771 .60781 L .34882 .61228 L p .707 .577 .707 r
F P
0 g
s
.37214 .7646 m .36488 .26793 L .38797 .25593 L p .707 .577 .707 r
F P
0 g
s
.36488 .26793 m .37214 .7646 L .36215 .77801 L p .707 .577 .707 r
F P
0 g
s
.18185 .70079 m .17715 .73893 L .16143 .73586 L p .707 .577 .707 r
F P
0 g
s
.16143 .73586 m .16613 .69771 L .18185 .70079 L p .707 .577 .707 r
F P
0 g
s
.18105 .65937 m .18405 .60233 L .208 .60058 L p .707 .577 .707 r
F P
0 g
s
.35805 .79978 m .35611 .81891 L .34321 .81713 L p .707 .577 .707 r
F P
0 g
s
.34321 .81713 m .34514 .798 L .35805 .79978 L p .707 .577 .707 r
F P
0 g
s
.208 .60058 m .205 .65763 L .18105 .65937 L p .707 .577 .707 r
F P
0 g
s
.34575 .72062 m .34105 .75877 L .31969 .75712 L p .707 .577 .707 r
F P
0 g
s
.62084 .25749 m .6281 .75415 L .59836 .7443 L p .707 .577 .707 r
F P
0 g
s
.59836 .7443 m .5911 .24764 L .62084 .25749 L p .707 .577 .707 r
F P
0 g
s
.31969 .75712 m .32439 .71897 L .34575 .72062 L p .707 .577 .707 r
F P
0 g
s
.16303 .79922 m .16496 .78009 L .18089 .78126 L p .707 .577 .707 r
F P
0 g
s
.18089 .78126 m .17896 .80039 L .16303 .79922 L p .707 .577 .707 r
F P
0 g
s
.32771 .60781 m .32472 .66486 L .29724 .66115 L p .707 .577 .707 r
F P
0 g
s
.29724 .66115 m .30024 .60411 L .32771 .60781 L p .707 .577 .707 r
F P
0 g
s
.20531 .70456 m .20061 .7427 L .17715 .73893 L p .707 .577 .707 r
F P
0 g
s
.17715 .73893 m .18185 .70079 L .20531 .70456 L p .707 .577 .707 r
F P
0 g
s
.205 .65763 m .208 .60058 L .2373 .60031 L p .707 .577 .707 r
F P
0 g
s
.38797 .25593 m .39512 .74509 L p .37214 .7646 L .707 .577 .707 r
F P
0 g
s
.39523 .75259 m .38797 .25593 L .42192 .2465 L p .707 .577 .707 r
F P
0 g
s
.42192 .2465 m .42819 .67517 L p .39663 .72619 L .707 .577 .707 r
F P
0 g
s
.42918 .74317 m .42192 .2465 L .46339 .24059 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .47065 .73725 L .42918 .74317 L p .707 .577 .707 r
F P
0 g
s
.42523 .56397 m .42223 .62101 L .43945 .62085 L p .707 .577 .707 r
F P
0 g
s
.43945 .62085 m .45078 .62074 L p .44589 .60988 L .707 .577 .707 r
F P
0 g
s
.44589 .60988 m .42523 .56397 L .43945 .62085 L .707 .577 .707 r
F
.39345 .56275 m .39045 .6198 L .42223 .62101 L p F P
0 g
s
.42223 .62101 m .42523 .56397 L .39345 .56275 L p .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .39343 .61313 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42027 .6553 m .42055 .653 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42055 .653 m .42497 .61715 L p .41972 .65443 L .707 .577 .707 r
F P
0 g
s
.42497 .61715 m .42027 .6553 L .43885 .65793 L p .707 .577 .707 r
F P
0 g
s
.43885 .65793 m .44919 .65939 L p .44378 .64996 L .707 .577 .707 r
F P
0 g
s
.44378 .64996 m .42497 .61715 L .43885 .65793 L .707 .577 .707 r
F
.39523 .75259 m .39663 .72619 L .42852 .69778 L F
.42819 .67517 m .42852 .69778 L p .39663 .72619 L F P
0 g
s
.42852 .69778 m .42918 .74317 L .4142 .74733 L p .707 .577 .707 r
F P
0 g
s
.4142 .74733 m .39523 .75259 L p .42852 .69778 L .707 .577 .707 r
F P
0 g
s
.45078 .62074 m .45153 .62074 L p .45107 .61974 L .707 .577 .707 r
F P
0 g
s
.45107 .61974 m .42523 .56397 L .45078 .62074 L .707 .577 .707 r
F
.39343 .61313 m .38873 .65128 L .41278 .65434 L p F P
0 g
s
.41278 .65434 m .42027 .6553 L p .41439 .64606 L .707 .577 .707 r
F P
0 g
s
.41439 .64606 m .39343 .61313 L .41278 .65434 L .707 .577 .707 r
F
.39512 .74509 m .39523 .75259 L .39349 .7535 L p F P
0 g
s
.39349 .7535 m .37214 .7646 L p .39512 .74509 L .707 .577 .707 r
F P
0 g
s
.2373 .60031 m .2343 .65735 L .205 .65763 L p .707 .577 .707 r
F P
0 g
s
.30024 .60411 m .29724 .66115 L .26609 .65857 L p .707 .577 .707 r
F P
0 g
s
.26609 .65857 m .26908 .60152 L .30024 .60411 L p .707 .577 .707 r
F P
0 g
s
.34514 .798 m .34321 .81713 L .32195 .8146 L p .707 .577 .707 r
F P
0 g
s
.32195 .8146 m .32388 .79547 L .34514 .798 L p .707 .577 .707 r
F P
0 g
s
.2343 .65735 m .2373 .60031 L .26908 .60152 L p .707 .577 .707 r
F P
0 g
s
.32439 .71897 m .31969 .75712 L .29213 .75438 L p .707 .577 .707 r
F P
0 g
s
.29213 .75438 m .29683 .71623 L .32439 .71897 L p .707 .577 .707 r
F P
0 g
s
.26908 .60152 m .26609 .65857 L .2343 .65735 L p .707 .577 .707 r
F P
0 g
s
.73346 .65661 m .73646 .59957 L .7053 .59698 L p .707 .577 .707 r
F P
0 g
s
.73646 .59957 m .73346 .65661 L .76524 .65783 L p .707 .577 .707 r
F P
0 g
s
.76524 .65783 m .76824 .60078 L .73646 .59957 L p .707 .577 .707 r
F P
0 g
s
.23423 .70866 m .22953 .7468 L .20061 .7427 L p .707 .577 .707 r
F P
0 g
s
.20061 .7427 m .20531 .70456 L .23423 .70866 L p .707 .577 .707 r
F P
0 g
s
.17896 .80039 m .18089 .78126 L .20455 .7833 L p .707 .577 .707 r
F P
0 g
s
.20455 .7833 m .20262 .80244 L .17896 .80039 L p .707 .577 .707 r
F P
0 g
s
.76824 .60078 m .76524 .65783 L .78246 .65767 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .73644 .64995 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76328 .69211 m .76356 .68982 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.76356 .68982 m .76798 .65397 L p .76273 .69124 L .707 .577 .707 r
F P
0 g
s
.78246 .65767 m .79454 .65755 L p .78925 .64612 L .707 .577 .707 r
F P
0 g
s
.78925 .64612 m .76824 .60078 L .78246 .65767 L .707 .577 .707 r
F
.79454 .65755 m .79754 .6005 L .76824 .60078 L p F P
0 g
s
.5911 .24764 m .59836 .7443 L .5596 .73785 L p .707 .577 .707 r
F P
0 g
s
.5596 .73785 m .55234 .24118 L .5911 .24764 L p .707 .577 .707 r
F P
0 g
s
.70231 .65403 m .7053 .59698 L .67783 .59328 L p .707 .577 .707 r
F P
0 g
s
.7053 .59698 m .70231 .65403 L .73346 .65661 L p .707 .577 .707 r
F P
0 g
s
.29683 .71623 m .29213 .75438 L .26106 .75082 L p .707 .577 .707 r
F P
0 g
s
.70537 .64639 m .70068 .68454 L .73174 .68809 L p .707 .577 .707 r
F P
0 g
s
.73174 .68809 m .73644 .64995 L .70537 .64639 L p .707 .577 .707 r
F P
0 g
s
.73644 .64995 m .73174 .68809 L .76328 .69211 L p .707 .577 .707 r
F P
0 g
s
.26106 .75082 m .26576 .71268 L .29683 .71623 L p .707 .577 .707 r
F P
0 g
s
.26576 .71268 m .26106 .75082 L .22953 .7468 L p .707 .577 .707 r
F P
0 g
s
.22953 .7468 m .23423 .70866 L .26576 .71268 L p .707 .577 .707 r
F P
0 g
s
.67783 .59328 m .67483 .65032 L .70231 .65403 L p .707 .577 .707 r
F P
0 g
s
.76798 .65397 m .76328 .69211 L .7922 .69621 L p .707 .577 .707 r
F P
0 g
s
.79754 .6005 m .79454 .65755 L .81849 .65581 L p .707 .577 .707 r
F P
0 g
s
.81849 .65581 m .82149 .59876 L .79754 .6005 L p .707 .577 .707 r
F P
0 g
s
.32388 .79547 m .32195 .8146 L .29442 .81156 L p .707 .577 .707 r
F P
0 g
s
.29442 .81156 m .29636 .79243 L .32388 .79547 L p .707 .577 .707 r
F P
0 g
s
.7922 .69621 m .79689 .65806 L .76798 .65397 L p .707 .577 .707 r
F P
0 g
s
.67781 .64365 m .67311 .6818 L .70068 .68454 L p .707 .577 .707 r
F P
0 g
s
.70068 .68454 m .70537 .64639 L .67781 .64365 L p .707 .577 .707 r
F P
0 g
s
.73268 .7135 m .73462 .69437 L .70351 .69112 L p .707 .577 .707 r
F P
0 g
s
.73462 .69437 m .73268 .7135 L .76432 .71665 L p .707 .577 .707 r
F P
0 g
s
.76432 .71665 m .76625 .69751 L .73462 .69437 L p .707 .577 .707 r
F P
0 g
s
.70351 .69112 m .70158 .71025 L .73268 .7135 L p .707 .577 .707 r
F P
0 g
s
.67483 .65032 m .67783 .59328 L .65672 .58881 L p .707 .577 .707 r
F P
0 g
s
.20262 .80244 m .20455 .7833 L .23362 .78603 L p .707 .577 .707 r
F P
0 g
s
.23362 .78603 m .23169 .80516 L .20262 .80244 L p .707 .577 .707 r
F P
0 g
s
.76625 .69751 m .76432 .71665 L .79339 .71937 L p .707 .577 .707 r
F P
0 g
s
.79339 .71937 m .79532 .70024 L .76625 .69751 L p .707 .577 .707 r
F P
0 g
s
.55234 .24118 m .5596 .73785 L .51559 .73542 L p .707 .577 .707 r
F P
0 g
s
.51559 .73542 m .50833 .23875 L .55234 .24118 L p .707 .577 .707 r
F P
0 g
s
.70158 .71025 m .70351 .69112 L .67599 .68808 L p .707 .577 .707 r
F P
0 g
s
.67599 .68808 m .67405 .70721 L .70158 .71025 L p .707 .577 .707 r
F P
0 g
s
.79689 .65806 m .7922 .69621 L .81566 .69998 L p .707 .577 .707 r
F P
0 g
s
.81566 .69998 m .82036 .66183 L .79689 .65806 L p .707 .577 .707 r
F P
0 g
s
.65672 .58881 m .65372 .64586 L .67483 .65032 L p .707 .577 .707 r
F P
0 g
s
.29636 .79243 m .29442 .81156 L .26332 .80831 L p .707 .577 .707 r
F P
0 g
s
.26332 .80831 m .26525 .78918 L .29636 .79243 L p .707 .577 .707 r
F P
0 g
s
.46339 .24059 m .50833 .23875 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.47038 .71851 m .46339 .24059 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.45388 .62125 m .45009 .65202 L p .47265 .66316 L .707 .577 .707 r
F P
0 g
s
.45009 .65202 m .44919 .65939 L .45251 .65993 L p .707 .577 .707 r
F P
0 g
s
.45251 .65993 m .47265 .66316 L p .45009 .65202 L .707 .577 .707 r
F P
0 g
s
.47065 .73725 m .47038 .71851 L p .47173 .72295 L .707 .577 .707 r
F P
0 g
s
.65646 .642 m .65176 .68014 L .67311 .6818 L p .707 .577 .707 r
F P
0 g
s
.67311 .6818 m .67781 .64365 L .65646 .642 L p .707 .577 .707 r
F P
0 g
s
.23169 .80516 m .23362 .78603 L .26525 .78918 L p .707 .577 .707 r
F P
0 g
s
.26525 .78918 m .26332 .80831 L .23169 .80516 L p .707 .577 .707 r
F P
0 g
s
.50833 .23875 m .51559 .73542 L .47065 .73725 L p .707 .577 .707 r
F P
0 g
s
.82149 .59876 m .81849 .65581 L .83475 .65277 L p .707 .577 .707 r
F P
0 g
s
.83475 .65277 m .83774 .59573 L .82149 .59876 L p .707 .577 .707 r
F P
0 g
s
.79532 .70024 m .79339 .71937 L .81704 .72142 L p .707 .577 .707 r
F P
0 g
s
.81704 .72142 m .81898 .70229 L .79532 .70024 L p .707 .577 .707 r
F P
0 g
s
.67405 .70721 m .67599 .68808 L .65473 .68554 L p .707 .577 .707 r
F P
0 g
s
.65473 .68554 m .65279 .70468 L .67405 .70721 L p .707 .577 .707 r
F P
0 g
s
.65372 .64586 m .65672 .58881 L .64404 .58403 L p .707 .577 .707 r
F P
0 g
s
.82036 .66183 m .81566 .69998 L .83138 .70305 L p .707 .577 .707 r
F P
0 g
s
.83138 .70305 m .83608 .66491 L .82036 .66183 L p .707 .577 .707 r
F P
0 g
s
.65176 .68014 m .65646 .642 L .6434 .64159 L p .707 .577 .707 r
F P
0 g
s
.81898 .70229 m .81704 .72142 L .83297 .72259 L p .707 .577 .707 r
F P
0 g
s
.83608 .66491 m .83138 .70305 L .83239 .70338 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .83491 .70345 L .8324 .70327 L p .707 .577 .707 r
F P
0 g
s
.83297 .72259 m .8324 .70327 L .83056 .71908 L .707 .577 .707 r
F
.83491 .70345 m .83297 .72259 L .83962 .72275 L p F P
0 g
s
.83962 .72275 m .84155 .70362 L .83491 .70345 L p .707 .577 .707 r
F P
0 g
s
.83239 .70338 m .83781 .70513 L p .83629 .66993 L .707 .577 .707 r
F P
0 g
s
.83629 .66993 m .83608 .66491 L .83239 .70338 L .707 .577 .707 r
F
.8324 .70327 m .81898 .70229 L p .83056 .71908 L F P
0 g
s
.83774 .59573 m .83475 .65277 L .84171 .64874 L p .707 .577 .707 r
F P
0 g
s
.84171 .64874 m .84471 .59169 L .83774 .59573 L p .707 .577 .707 r
F P
0 g
s
.83781 .70513 m .84251 .66699 L .83608 .66491 L p .707 .577 .707 r
F P
0 g
s
.64104 .5794 m .63805 .63644 L .64105 .64108 L p .707 .577 .707 r
F P
0 g
s
.63991 .64247 m .63521 .68061 L .6387 .67973 L p .707 .577 .707 r
F P
0 g
s
.6387 .67973 m .6434 .64159 L .63991 .64247 L p .707 .577 .707 r
F P
0 g
s
.84471 .59169 m .84171 .64874 L .83871 .64411 L p .707 .577 .707 r
F P
0 g
s
.83871 .64411 m .84171 .58706 L .84471 .59169 L p .707 .577 .707 r
F P
0 g
s
.63989 .7029 m .64182 .68377 L .63853 .68292 L p .707 .577 .707 r
F P
0 g
s
.63853 .68292 m .6366 .70205 L .63989 .7029 L p .707 .577 .707 r
F P
0 g
s
.63805 .63644 m .64104 .5794 L .64801 .57536 L p .707 .577 .707 r
F P
0 g
s
.84251 .66699 m .83781 .70513 L .83432 .70601 L p .707 .577 .707 r
F P
0 g
s
.83432 .70601 m .83902 .66786 L .84251 .66699 L p .707 .577 .707 r
F P
0 g
s
.64801 .57536 m .64501 .63241 L .63805 .63644 L p .707 .577 .707 r
F P
0 g
s
.84155 .70362 m .83962 .72275 L .83633 .72191 L p .707 .577 .707 r
F P
0 g
s
.83633 .72191 m .83826 .70277 L .84155 .70362 L p .707 .577 .707 r
F P
0 g
s
.64634 .64454 m .64164 .68269 L .63521 .68061 L p .707 .577 .707 r
F P
0 g
s
.63521 .68061 m .63991 .64247 L .64634 .64454 L p .707 .577 .707 r
F P
0 g
s
.84171 .58706 m .83871 .64411 L .82604 .63932 L p .707 .577 .707 r
F P
0 g
s
.82604 .63932 m .82904 .58228 L .84171 .58706 L p .707 .577 .707 r
F P
0 g
s
.66206 .64762 m .65736 .68576 L .64412 .68317 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .63853 .68292 L .64413 .68306 L p .707 .577 .707 r
F P
0 g
s
.6366 .70205 m .64413 .68306 L .6438 .68613 L .707 .577 .707 r
F
.64412 .68317 m .64164 .68269 L p .64474 .67737 L F P
0 g
s
.64474 .67737 m .66206 .64762 L .64412 .68317 L .707 .577 .707 r
F
.64413 .68306 m .64518 .68309 L p .6438 .68613 L F P
0 g
s
.64518 .68309 m .64324 .70222 L .6366 .70205 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39045 .6198 m .39345 .56275 L .36229 .56017 L p .707 .577 .707 r
F P
0 g
s
.45153 .62074 m .45453 .56369 L .42523 .56397 L p .707 .577 .707 r
F P
0 g
s
.64501 .63241 m .64801 .57536 L .66427 .57233 L p .707 .577 .707 r
F P
0 g
s
.3593 .61721 m .36229 .56017 L .33482 .55646 L p .707 .577 .707 r
F P
0 g
s
.36229 .56017 m .3593 .61721 L .39045 .6198 L p .707 .577 .707 r
F P
0 g
s
.83902 .66786 m .83432 .70601 L .82126 .7056 L p .707 .577 .707 r
F P
0 g
s
.82126 .7056 m .82596 .66745 L .83902 .66786 L p .707 .577 .707 r
F P
0 g
s
.36236 .60958 m .35767 .64772 L .38873 .65128 L p .707 .577 .707 r
F P
0 g
s
.38873 .65128 m .39343 .61313 L .36236 .60958 L p .707 .577 .707 r
F P
0 g
s
.66427 .57233 m .66127 .62937 L .64501 .63241 L p .707 .577 .707 r
F P
0 g
s
.33482 .55646 m .33182 .61351 L .3593 .61721 L p .707 .577 .707 r
F P
0 g
s
.45453 .56369 m .45153 .62074 L .47548 .61899 L p .707 .577 .707 r
F P
0 g
s
.47548 .61899 m .47848 .56195 L .45453 .56369 L p .707 .577 .707 r
F P
0 g
s
.44919 .65939 m .45388 .62125 L .42497 .61715 L p .707 .577 .707 r
F P
0 g
s
.83826 .70277 m .83633 .72191 L .82342 .72013 L p .707 .577 .707 r
F P
0 g
s
.82342 .72013 m .82536 .701 L .83826 .70277 L p .707 .577 .707 r
F P
0 g
s
.64164 .68269 m .64634 .64454 L .66206 .64762 L p .707 .577 .707 r
F P
0 g
s
.3348 .60684 m .3301 .64498 L .35767 .64772 L p .707 .577 .707 r
F P
0 g
s
.35767 .64772 m .36236 .60958 L .3348 .60684 L p .707 .577 .707 r
F P
0 g
s
.38967 .67669 m .39161 .65755 L .3605 .6543 L p .707 .577 .707 r
F P
0 g
s
.39161 .65755 m .38967 .67669 L .42131 .67983 L p .707 .577 .707 r
F P
0 g
s
.42131 .67983 m .42324 .6607 L .39161 .65755 L p .707 .577 .707 r
F P
0 g
s
.3605 .6543 m .35857 .67343 L .38967 .67669 L p .707 .577 .707 r
F P
0 g
s
.33182 .61351 m .33482 .55646 L .31371 .552 L p .707 .577 .707 r
F P
0 g
s
.82904 .58228 m .82604 .63932 L .80493 .63486 L p .707 .577 .707 r
F P
0 g
s
.80493 .63486 m .80793 .57781 L .82904 .58228 L p .707 .577 .707 r
F P
0 g
s
.42324 .6607 m .42131 .67983 L .45038 .68256 L p .707 .577 .707 r
F P
0 g
s
.45038 .68256 m .45231 .66343 L .42324 .6607 L p .707 .577 .707 r
F P
0 g
s
.68552 .65139 m .68083 .68953 L .65736 .68576 L p .707 .577 .707 r
F P
0 g
s
.65736 .68576 m .66206 .64762 L .68552 .65139 L p .707 .577 .707 r
F P
0 g
s
.64324 .70222 m .64518 .68309 L .66111 .68425 L p .707 .577 .707 r
F P
0 g
s
.35857 .67343 m .3605 .6543 L .33298 .65126 L p .707 .577 .707 r
F P
0 g
s
.66111 .68425 m .65917 .70339 L .64324 .70222 L p .707 .577 .707 r
F P
0 g
s
.33298 .65126 m .33104 .67039 L .35857 .67343 L p .707 .577 .707 r
F P
0 g
s
.47265 .66316 m .47735 .62502 L .45388 .62125 L p .707 .577 .707 r
F P
0 g
s
.31371 .552 m .31071 .60904 L .33182 .61351 L p .707 .577 .707 r
F P
0 g
s
.66127 .62937 m .66427 .57233 L .68822 .57058 L p .707 .577 .707 r
F P
0 g
s
.31345 .60518 m .30875 .64333 L .3301 .64498 L p .707 .577 .707 r
F P
0 g
s
.3301 .64498 m .3348 .60684 L .31345 .60518 L p .707 .577 .707 r
F P
0 g
s
.47848 .56195 m .47548 .61899 L .49174 .61596 L p .707 .577 .707 r
F P
0 g
s
.49174 .61596 m .49473 .55891 L .47848 .56195 L p .707 .577 .707 r
F P
0 g
s
.82596 .66745 m .82126 .7056 L .79991 .70394 L p .707 .577 .707 r
F P
0 g
s
.45231 .66343 m .45038 .68256 L .47403 .68461 L p .707 .577 .707 r
F P
0 g
s
.47403 .68461 m .47597 .66547 L .45231 .66343 L p .707 .577 .707 r
F P
0 g
s
.79991 .70394 m .80461 .6658 L .82596 .66745 L p .707 .577 .707 r
F P
0 g
s
.68822 .57058 m .68522 .62763 L .66127 .62937 L p .707 .577 .707 r
F P
0 g
s
.33104 .67039 m .33298 .65126 L .31172 .64873 L p .707 .577 .707 r
F P
0 g
s
.31172 .64873 m .30978 .66786 L .33104 .67039 L p .707 .577 .707 r
F P
0 g
s
.31071 .60904 m .31371 .552 L .30103 .54721 L p .707 .577 .707 r
F P
0 g
s
.82536 .701 m .82342 .72013 L .80216 .7176 L p .707 .577 .707 r
F P
0 g
s
.80216 .7176 m .8041 .69847 L .82536 .701 L p .707 .577 .707 r
F P
0 g
s
.80793 .57781 m .80493 .63486 L .77745 .63115 L p .707 .577 .707 r
F P
0 g
s
.77745 .63115 m .78045 .57411 L .80793 .57781 L p .707 .577 .707 r
F P
0 g
s
.47735 .62502 m .47265 .66316 L .48837 .66624 L p .707 .577 .707 r
F P
0 g
s
.48837 .66624 m .49307 .62809 L .47735 .62502 L p .707 .577 .707 r
F P
0 g
s
.68522 .62763 m .68822 .57058 L .71752 .57031 L p .707 .577 .707 r
F P
0 g
s
.30103 .54721 m .29804 .60426 L .31071 .60904 L p .707 .577 .707 r
F P
0 g
s
.71444 .65548 m .70974 .69363 L .68083 .68953 L p .707 .577 .707 r
F P
0 g
s
.68083 .68953 m .68552 .65139 L .71444 .65548 L p .707 .577 .707 r
F P
0 g
s
.65917 .70339 m .66111 .68425 L .68477 .6863 L p .707 .577 .707 r
F P
0 g
s
.68477 .6863 m .68283 .70543 L .65917 .70339 L p .707 .577 .707 r
F P
0 g
s
.30039 .60477 m .29569 .64292 L .30875 .64333 L p .707 .577 .707 r
F P
0 g
s
.30875 .64333 m .31345 .60518 L .30039 .60477 L p .707 .577 .707 r
F P
0 g
s
.47597 .66547 m .47403 .68461 L .48996 .68577 L p .707 .577 .707 r
F P
0 g
s
.49307 .62809 m .48837 .66624 L .48938 .66656 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .4919 .66664 L .48939 .66645 L p .707 .577 .707 r
F P
0 g
s
.48996 .68577 m .48939 .66645 L .48755 .68227 L .707 .577 .707 r
F
.4919 .66664 m .48996 .68577 L .49661 .68594 L p F P
0 g
s
.49661 .68594 m .49854 .6668 L .4919 .66664 L p .707 .577 .707 r
F P
0 g
s
.48938 .66656 m .4948 .66832 L p .49328 .63312 L .707 .577 .707 r
F P
0 g
s
.49328 .63312 m .49307 .62809 L .48938 .66656 L .707 .577 .707 r
F
.48939 .66645 m .47597 .66547 L p .48755 .68227 L F P
0 g
s
.80461 .6658 m .79991 .70394 L .77235 .70121 L p .707 .577 .707 r
F P
0 g
s
.71752 .57031 m .71452 .62735 L .68522 .62763 L p .707 .577 .707 r
F P
0 g
s
.77235 .70121 m .77705 .66306 L .80461 .6658 L p .707 .577 .707 r
F P
0 g
s
.78045 .57411 m .77745 .63115 L .7463 .62857 L p .707 .577 .707 r
F P
0 g
s
.7463 .62857 m .7493 .57152 L .78045 .57411 L p .707 .577 .707 r
F P
0 g
s
.49473 .55891 m .49174 .61596 L .4987 .61193 L p .707 .577 .707 r
F P
0 g
s
.4987 .61193 m .5017 .55488 L .49473 .55891 L p .707 .577 .707 r
F P
0 g
s
.71452 .62735 m .71752 .57031 L .7493 .57152 L p .707 .577 .707 r
F P
0 g
s
.30978 .66786 m .31172 .64873 L .29881 .64695 L p .707 .577 .707 r
F P
0 g
s
.29881 .64695 m .29688 .66608 L .30978 .66786 L p .707 .577 .707 r
F P
0 g
s
.7493 .57152 m .7463 .62857 L .71452 .62735 L p .707 .577 .707 r
F P
0 g
s
.8041 .69847 m .80216 .7176 L .77464 .71456 L p .707 .577 .707 r
F P
0 g
s
.77464 .71456 m .77657 .69542 L .8041 .69847 L p .707 .577 .707 r
F P
0 g
s
.29804 .60426 m .30103 .54721 L .29803 .54258 L p .707 .577 .707 r
F P
0 g
s
.70974 .69363 m .71444 .65548 L .74598 .65951 L p .707 .577 .707 r
F P
0 g
s
.68283 .70543 m .68477 .6863 L .71383 .68903 L p .707 .577 .707 r
F P
0 g
s
.74598 .65951 m .74128 .69765 L .70974 .69363 L p .707 .577 .707 r
F P
0 g
s
.71383 .68903 m .7119 .70816 L .68283 .70543 L p .707 .577 .707 r
F P
0 g
s
.77705 .66306 m .77235 .70121 L .74128 .69765 L p .707 .577 .707 r
F P
0 g
s
.74128 .69765 m .74598 .65951 L .77705 .66306 L p .707 .577 .707 r
F P
0 g
s
.4948 .66832 m .4995 .63017 L .49307 .62809 L p .707 .577 .707 r
F P
0 g
s
.29803 .54258 m .29504 .59963 L .29804 .60426 L p .707 .577 .707 r
F P
0 g
s
.77657 .69542 m .77464 .71456 L .74353 .71131 L p .707 .577 .707 r
F P
0 g
s
.74353 .71131 m .74547 .69217 L .77657 .69542 L p .707 .577 .707 r
F P
0 g
s
.2969 .60565 m .2922 .6438 L .29569 .64292 L p .707 .577 .707 r
F P
0 g
s
.29569 .64292 m .30039 .60477 L .2969 .60565 L p .707 .577 .707 r
F P
0 g
s
.7119 .70816 m .71383 .68903 L .74547 .69217 L p .707 .577 .707 r
F P
0 g
s
.74547 .69217 m .74353 .71131 L .7119 .70816 L p .707 .577 .707 r
F P
0 g
s
.5017 .55488 m .4987 .61193 L .4957 .60729 L p .707 .577 .707 r
F P
0 g
s
.4957 .60729 m .4987 .55024 L .5017 .55488 L p .707 .577 .707 r
F P
0 g
s
.29688 .66608 m .29881 .64695 L .29552 .64611 L p .707 .577 .707 r
F P
0 g
s
.29552 .64611 m .29359 .66524 L .29688 .66608 L p .707 .577 .707 r
F P
0 g
s
.29504 .59963 m .29803 .54258 L .305 .53855 L p .707 .577 .707 r
F P
0 g
s
.4995 .63017 m .4948 .66832 L .49131 .66919 L p .707 .577 .707 r
F P
0 g
s
.49131 .66919 m .49601 .63105 L .4995 .63017 L p .707 .577 .707 r
F P
0 g
s
.305 .53855 m .302 .59559 L .29504 .59963 L p .707 .577 .707 r
F P
0 g
s
.49854 .6668 m .49661 .68594 L .49332 .68509 L p .707 .577 .707 r
F P
0 g
s
.49332 .68509 m .49525 .66596 L .49854 .6668 L p .707 .577 .707 r
F P
0 g
s
.30333 .60773 m .29863 .64587 L .2922 .6438 L p .707 .577 .707 r
F P
0 g
s
.2922 .6438 m .2969 .60565 L .30333 .60773 L p .707 .577 .707 r
F P
0 g
s
.4987 .55024 m .4957 .60729 L .48303 .60251 L p .707 .577 .707 r
F P
0 g
s
.48303 .60251 m .48603 .54546 L .4987 .55024 L p .707 .577 .707 r
F P
0 g
s
.31905 .6108 m .31435 .64895 L .30111 .64636 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .29552 .64611 L .30112 .64625 L p .707 .577 .707 r
F P
0 g
s
.29359 .66524 m .30112 .64625 L .30079 .64931 L .707 .577 .707 r
F
.30111 .64636 m .29863 .64587 L p .30173 .64055 L F P
0 g
s
.30173 .64055 m .31905 .6108 L .30111 .64636 L .707 .577 .707 r
F
.30112 .64625 m .30217 .64627 L p .30079 .64931 L F P
0 g
s
.30217 .64627 m .30023 .66541 L .29359 .66524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.302 .59559 m .305 .53855 L .32126 .53551 L p .707 .577 .707 r
F P
0 g
s
.49601 .63105 m .49131 .66919 L .47825 .66878 L p .707 .577 .707 r
F P
0 g
s
.47825 .66878 m .48295 .63064 L .49601 .63105 L p .707 .577 .707 r
F P
0 g
s
.32126 .53551 m .31826 .59256 L .302 .59559 L p .707 .577 .707 r
F P
0 g
s
.49525 .66596 m .49332 .68509 L .48041 .68332 L p .707 .577 .707 r
F P
0 g
s
.48041 .68332 m .48235 .66418 L .49525 .66596 L p .707 .577 .707 r
F P
0 g
s
.29863 .64587 m .30333 .60773 L .31905 .6108 L p .707 .577 .707 r
F P
0 g
s
.48603 .54546 m .48303 .60251 L .46192 .59805 L p .707 .577 .707 r
F P
0 g
s
.46192 .59805 m .46492 .541 L .48603 .54546 L p .707 .577 .707 r
F P
0 g
s
.34251 .61457 m .33782 .65272 L .31435 .64895 L p .707 .577 .707 r
F P
0 g
s
.31435 .64895 m .31905 .6108 L .34251 .61457 L p .707 .577 .707 r
F P
0 g
s
.30023 .66541 m .30217 .64627 L .3181 .64744 L p .707 .577 .707 r
F P
0 g
s
.3181 .64744 m .31616 .66657 L .30023 .66541 L p .707 .577 .707 r
F P
0 g
s
.31826 .59256 m .32126 .53551 L .3452 .53377 L p .707 .577 .707 r
F P
0 g
s
.48295 .63064 m .47825 .66878 L .4569 .66713 L p .707 .577 .707 r
F P
0 g
s
.4569 .66713 m .4616 .62898 L .48295 .63064 L p .707 .577 .707 r
F P
0 g
s
.3452 .53377 m .34221 .59082 L .31826 .59256 L p .707 .577 .707 r
F P
0 g
s
.48235 .66418 m .48041 .68332 L .45915 .68078 L p .707 .577 .707 r
F P
0 g
s
.45915 .68078 m .46109 .66165 L .48235 .66418 L p .707 .577 .707 r
F P
0 g
s
.46492 .541 m .46192 .59805 L .43444 .59434 L p .707 .577 .707 r
F P
0 g
s
.43444 .59434 m .43744 .53729 L .46492 .541 L p .707 .577 .707 r
F P
0 g
s
.34221 .59082 m .3452 .53377 L .3745 .53349 L p .707 .577 .707 r
F P
0 g
s
.37143 .61867 m .36673 .65681 L .33782 .65272 L p .707 .577 .707 r
F P
0 g
s
.33782 .65272 m .34251 .61457 L .37143 .61867 L p .707 .577 .707 r
F P
0 g
s
.31616 .66657 m .3181 .64744 L .34175 .64948 L p .707 .577 .707 r
F P
0 g
s
.34175 .64948 m .33982 .66862 L .31616 .66657 L p .707 .577 .707 r
F P
0 g
s
.4616 .62898 m .4569 .66713 L .42934 .66439 L p .707 .577 .707 r
F P
0 g
s
.3745 .53349 m .37151 .59054 L .34221 .59082 L p .707 .577 .707 r
F P
0 g
s
.42934 .66439 m .43403 .62625 L .4616 .62898 L p .707 .577 .707 r
F P
0 g
s
.43744 .53729 m .43444 .59434 L .40329 .59175 L p .707 .577 .707 r
F P
0 g
s
.40329 .59175 m .40629 .53471 L .43744 .53729 L p .707 .577 .707 r
F P
0 g
s
.37151 .59054 m .3745 .53349 L .40629 .53471 L p .707 .577 .707 r
F P
0 g
s
.40629 .53471 m .40329 .59175 L .37151 .59054 L p .707 .577 .707 r
F P
0 g
s
.46109 .66165 m .45915 .68078 L .43163 .67774 L p .707 .577 .707 r
F P
0 g
s
.43163 .67774 m .43356 .65861 L .46109 .66165 L p .707 .577 .707 r
F P
0 g
s
.36673 .65681 m .37143 .61867 L .40297 .62269 L p .707 .577 .707 r
F P
0 g
s
.33982 .66862 m .34175 .64948 L .37082 .65221 L p .707 .577 .707 r
F P
0 g
s
.40297 .62269 m .39827 .66084 L .36673 .65681 L p .707 .577 .707 r
F P
0 g
s
.37082 .65221 m .36889 .67135 L .33982 .66862 L p .707 .577 .707 r
F P
0 g
s
.43403 .62625 m .42934 .66439 L .39827 .66084 L p .707 .577 .707 r
F P
0 g
s
.39827 .66084 m .40297 .62269 L .43403 .62625 L p .707 .577 .707 r
F P
0 g
s
.43356 .65861 m .43163 .67774 L .40052 .67449 L p .707 .577 .707 r
F P
0 g
s
.40052 .67449 m .40246 .65536 L .43356 .65861 L p .707 .577 .707 r
F P
0 g
s
.36889 .67135 m .37082 .65221 L .40246 .65536 L p .707 .577 .707 r
F P
0 g
s
.40246 .65536 m .40052 .67449 L .36889 .67135 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002:Ool=0026Ool0085oo`T0
00IJEP03001JEUYF00AJEPT007eoo`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001eOol60008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol0075oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP04001JEP00001aOol006ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^Ool006aoo`<000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Mo
o`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Io
o`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Aoo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005mooa4000QJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Aoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001F
Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0I7oo001DOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo009ooah004Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003aoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0031oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Goo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol00`00FUH00002FUH?0007FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001COol00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol@000;Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH70003FUH00`00
FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol60003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH?00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000eYF00000003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo000_Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH?0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000]Ool30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF1P0000=JEP00FUH0
0UYF20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF0P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF1`000UYF
00@005YFFUIJEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP04001JEUYFFUH7
0003FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040008FUH00`00FUIJEP02FUH=0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPL00003FUH005YF00MJEP03001JEUYF
00H000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3`0000AJEP00FUIJEP<000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF7P0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH0200015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00P0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF1@00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00H0009JEQ0000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000UYF1@0000=JEP00FUH01UYF00<005YFFUH00UYF
2@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF2@000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YFFUH005YF0004FUH00`00FUIJEP0800000eYF001JEP07FUH00`00FUIJEP02FUH60005FUH0
0`00FUIJEP04FUH00`00FUIJEP04000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0000=JEP00FUH01eYF00<005YF00003P00<Woo000/Ool00`00FUH00002
FUH?0007FUH90003FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00=JEPH003Moo`00;7oo00<005YF00000`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPh000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00@005YFFUIJEPD0039oo`00;7oo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00002@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH@000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000A0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YF00001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
0UYF2P000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000dOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP<00003FUH0000000L0009JEPL000=JEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH010000UYF00<005YFFUH00UYF1@001UYF0P0000=J
EP000000400015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00A7oo7`000goo00@005YFFUH000AJEPD000IJEP8000YJEP04001J
EUYFFUH50004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Woo001VOol01000FUIJEP0015YF1@001UYF0P002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000]Ool8000aOol01000FUIJEP001EYF0`001eYF0P002UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`@00004FUH005YFFUH?000ROol01000FUIJEP001UYF00<005YFFUH01UYF
0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH70002FUH01000FUIJEUYF0P00;Woo000]Ool01000FUH005YF1P0000=JEP00FUH01UYF
00@005YFFUIJEPL001]oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000040002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP08
000^Ool002eoo`03001JEP0000=JEP04001JEUYFFUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04
000GOol01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<0
05YFFUH015YF00@005YFFUIJEPT00003FUH005YF00EJEPL0011oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH005YF4`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH00eYF1`002Goo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEP0000IJEP03001JEUYF009JEP<000=oo``000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP060003Ool01000FUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH00UYF00<005YF000027oo0`0000=oo`000000
2@000eYF00<005YFFUH015YF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3`000UYF00<005YF
FUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH0100027oo1@0027oo3`00
00=JEP000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH<000<Ool5000@Ool:000^Ool002aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`0EOol50018Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF
000@FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`0FOol30019Ool002aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol002eoo`<0009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0>FUH00`00FUIJEP06FUHO0008FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol0031oo`H000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0>FUH00`00FUIJEP06000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003Ioo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP040006FUH00`00FUIJEP03FUH00`00Oomoo`1ROol003eoo`T000AJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF
00<005YFFUH00eYF1`00GWoo0016Ool90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`000UYF00<005YFFUH015YF00H005YF000005YF000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEP000eYF1@00FGoo
001?Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@0
05YF000000EJEPP0009JEP03001JEP00008005Ioo`00Egoo40000UYF00@005YFFUIJEP8000IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP09001DOol006Ioo`05001JEUYF001JEP03
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
001VOol00`00FUIJEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YF000000AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol004Qoo`<001]oo`<0
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0017Ool5000JOol30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00;Goo10005Woo1@006Woo00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol002eoo`80009JEPd000Uoo`D001Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`8000AJEP03001J
EUYF00AJEP04001JEUYFFUH9000017oo0000000077oo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@005goo0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200047oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01`000eYF00@005YFFUIJEP8005Eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEP`000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH2000:Ool9001EOol0
02aoo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP00008000Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF001ZOol003Aooa8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000Ioo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<006]oo`00
>goo20000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP<006eoo`00@goo2@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000Yoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0071oo`00
C7oo2@000UYF1`000eYF00@005YFFUIJEP8000eoo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEPD00003Ool0000000<006moo`00EGoo4P004Goo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00@005YFFUIJEPH000Ioo`D006moo`00HWoo1@005goo:P0000=oo`0000000`00
Kgoo002>Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001/
Ool008eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPP006Aoo`00SGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL005eoo`00SGoo1@000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH02000EGoo
002@Ool?0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo002EOol70003FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo002LOolE0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH005Aoo`00[Woo2`0015YF00<005YFFUH00eYF00<005YFFUH00P00EGoo002fOol?
00000eYF0000001EOol00;ioo`X005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59612 .73349 m .59798 .67687 L .56681 .67455 L p .707 .577 .707 r
F P
0 g
s
.59798 .67687 m .59612 .73349 L .62794 .73394 L p .707 .577 .707 r
F P
0 g
s
.62794 .73394 m .62979 .67732 L .59798 .67687 L p .707 .577 .707 r
F P
0 g
s
.62979 .67732 m .62794 .73394 L .65729 .73247 L p .707 .577 .707 r
F P
0 g
s
.65729 .73247 m .65914 .67585 L .62979 .67732 L p .707 .577 .707 r
F P
0 g
s
.56496 .73117 m .56681 .67455 L .53935 .67058 L p .707 .577 .707 r
F P
0 g
s
.56681 .67455 m .56496 .73117 L .59612 .73349 L p .707 .577 .707 r
F P
0 g
s
.65914 .67585 m .65729 .73247 L .6813 .72922 L p .707 .577 .707 r
F P
0 g
s
.6813 .72922 m .68316 .6726 L .65914 .67585 L p .707 .577 .707 r
F P
0 g
s
.53935 .67058 m .53749 .7272 L .56496 .73117 L p .707 .577 .707 r
F P
0 g
s
.59466 .79056 m .5976 .75233 L .56647 .74941 L p .707 .577 .707 r
F P
0 g
s
.5976 .75233 m .59466 .79056 L .62638 .79274 L p .707 .577 .707 r
F P
0 g
s
.62638 .79274 m .62932 .7545 L .5976 .75233 L p .707 .577 .707 r
F P
0 g
s
.53749 .7272 m .53935 .67058 L .51827 .66535 L p .707 .577 .707 r
F P
0 g
s
.56647 .74941 m .56353 .78764 L .59466 .79056 L p .707 .577 .707 r
F P
0 g
s
.62932 .7545 m .62638 .79274 L .65558 .79396 L p .707 .577 .707 r
F P
0 g
s
.65558 .79396 m .65852 .75572 L .62932 .7545 L p .707 .577 .707 r
F P
0 g
s
.56353 .78764 m .56647 .74941 L .53897 .74603 L p .707 .577 .707 r
F P
0 g
s
.53897 .74603 m .53603 .78427 L .56353 .78764 L p .707 .577 .707 r
F P
0 g
s
.51827 .66535 m .51642 .72197 L .53749 .7272 L p .707 .577 .707 r
F P
0 g
s
.65852 .75572 m .65558 .79396 L .67941 .7941 L p .707 .577 .707 r
F P
0 g
s
.67941 .7941 m .68235 .75587 L .65852 .75572 L p .707 .577 .707 r
F P
0 g
s
.68316 .6726 m .6813 .72922 L .69763 .72452 L p .707 .577 .707 r
F P
0 g
s
.69763 .72452 m .69948 .6679 L .68316 .6726 L p .707 .577 .707 r
F P
0 g
s
.59541 .84916 m .59661 .83009 L .56546 .82736 L p .707 .577 .707 r
F P
0 g
s
.59661 .83009 m .59541 .84916 L .62716 .8508 L p .707 .577 .707 r
F P
0 g
s
.62716 .8508 m .62837 .83173 L .59661 .83009 L p .707 .577 .707 r
F P
0 g
s
.56546 .82736 m .56426 .84643 L .59541 .84916 L p .707 .577 .707 r
F P
0 g
s
.62837 .83173 m .62716 .8508 L .65643 .85117 L p .707 .577 .707 r
F P
0 g
s
.65643 .85117 m .65763 .8321 L .62837 .83173 L p .707 .577 .707 r
F P
0 g
s
.53603 .78427 m .53897 .74603 L .5178 .74253 L p .707 .577 .707 r
F P
0 g
s
.5178 .74253 m .51486 .78077 L .53603 .78427 L p .707 .577 .707 r
F P
0 g
s
.56426 .84643 m .56546 .82736 L .53798 .8238 L p .707 .577 .707 r
F P
0 g
s
.51642 .72197 m .51827 .66535 L .50565 .65937 L p .707 .577 .707 r
F P
0 g
s
.53798 .8238 m .53677 .84287 L .56426 .84643 L p .707 .577 .707 r
F P
0 g
s
.65763 .8321 m .65643 .85117 L .68033 .85025 L p .707 .577 .707 r
F P
0 g
s
.68033 .85025 m .68153 .83118 L .65763 .8321 L p .707 .577 .707 r
F P
0 g
s
.50565 .65937 m .50379 .71599 L .51642 .72197 L p .707 .577 .707 r
F P
0 g
s
.68235 .75587 m .67941 .7941 L .69553 .79316 L p .707 .577 .707 r
F P
0 g
s
.69553 .79316 m .69847 .75492 L .68235 .75587 L p .707 .577 .707 r
F P
0 g
s
.53677 .84287 m .53798 .8238 L .51685 .81976 L p .707 .577 .707 r
F P
0 g
s
.69948 .6679 m .69763 .72452 L .70467 .71882 L p .707 .577 .707 r
F P
0 g
s
.70467 .71882 m .70652 .6622 L .69948 .6679 L p .707 .577 .707 r
F P
0 g
s
.51685 .81976 m .51564 .83883 L .53677 .84287 L p .707 .577 .707 r
F P
0 g
s
.51486 .78077 m .5178 .74253 L .50503 .73925 L p .707 .577 .707 r
F P
0 g
s
.50503 .73925 m .50209 .77748 L .51486 .78077 L p .707 .577 .707 r
F P
0 g
s
.50379 .71599 m .50565 .65937 L .50271 .65324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83118 m .68033 .85025 L .69653 .84813 L p .707 .577 .707 r
F P
0 g
s
.69653 .84813 m .69773 .82906 L .68153 .83118 L p .707 .577 .707 r
F P
0 g
s
.69847 .75492 m .69553 .79316 L .70236 .79121 L p .707 .577 .707 r
F P
0 g
s
.70236 .79121 m .7053 .75298 L .69847 .75492 L p .707 .577 .707 r
F P
0 g
s
.51564 .83883 m .51685 .81976 L .50413 .81563 L p .707 .577 .707 r
F P
0 g
s
.50271 .65324 m .50086 .70985 L .50379 .71599 L p .707 .577 .707 r
F P
0 g
s
.50413 .81563 m .50293 .8347 L .51564 .83883 L p .707 .577 .707 r
F P
0 g
s
.70652 .6622 m .70467 .71882 L .70173 .71268 L p .707 .577 .707 r
F P
0 g
s
.70173 .71268 m .70359 .65606 L .70652 .6622 L p .707 .577 .707 r
F P
0 g
s
.50209 .77748 m .50503 .73925 L .5019 .7365 L p .707 .577 .707 r
F P
0 g
s
.5019 .7365 m .49896 .77473 L .50209 .77748 L p .707 .577 .707 r
F P
0 g
s
.4942 .82231 m .48971 .32357 L .4457 .32104 L p .707 .577 .707 r
F P
0 g
s
.50086 .70985 m .50271 .65324 L .50975 .64754 L p .707 .577 .707 r
F P
0 g
s
.50293 .8347 m .50413 .81563 L .50109 .81182 L p .707 .577 .707 r
F P
0 g
s
.50109 .81182 m .49988 .83089 L .50293 .8347 L p .707 .577 .707 r
F P
0 g
s
.50975 .64754 m .50789 .70415 L .50086 .70985 L p .707 .577 .707 r
F P
0 g
s
.49896 .77473 m .5019 .7365 L .50873 .73456 L p .707 .577 .707 r
F P
0 g
s
.50873 .73456 m .5058 .77279 L .49896 .77473 L p .707 .577 .707 r
F P
0 g
s
.50789 .70415 m .50975 .64754 L .52608 .64283 L p .707 .577 .707 r
F P
0 g
s
.49988 .83089 m .50109 .81182 L .508 .80869 L p .707 .577 .707 r
F P
0 g
s
.52608 .64283 m .52422 .69945 L .50789 .70415 L p .707 .577 .707 r
F P
0 g
s
.508 .80869 m .5068 .82776 L .49988 .83089 L p .707 .577 .707 r
F P
0 g
s
.5058 .77279 m .50873 .73456 L .52485 .73361 L p .707 .577 .707 r
F P
0 g
s
.52485 .73361 m .52192 .77185 L .5058 .77279 L p .707 .577 .707 r
F P
0 g
s
.52422 .69945 m .52608 .64283 L .55009 .63959 L p .707 .577 .707 r
F P
0 g
s
.55009 .63959 m .54823 .6962 L .52422 .69945 L p .707 .577 .707 r
F P
0 g
s
.5068 .82776 m .508 .80869 L .5242 .80657 L p .707 .577 .707 r
F P
0 g
s
.5242 .80657 m .523 .82564 L .5068 .82776 L p .707 .577 .707 r
F P
0 g
s
.52192 .77185 m .52485 .73361 L .54868 .73376 L p .707 .577 .707 r
F P
0 g
s
.54868 .73376 m .54574 .77199 L .52192 .77185 L p .707 .577 .707 r
F P
0 g
s
.523 .82564 m .5242 .80657 L .5481 .80565 L p .707 .577 .707 r
F P
0 g
s
.5481 .80565 m .5469 .82472 L .523 .82564 L p .707 .577 .707 r
F P
0 g
s
.48971 .32357 m .4942 .82231 L .53914 .82076 L p .707 .577 .707 r
F P
0 g
s
.53914 .82076 m .53465 .32201 L .48971 .32357 L p .707 .577 .707 r
F P
0 g
s
.69773 .82906 m .69653 .84813 L .70344 .84501 L p .707 .577 .707 r
F P
0 g
s
.70344 .84501 m .70465 .82594 L .69773 .82906 L p .707 .577 .707 r
F P
0 g
s
.54823 .6962 m .55009 .63959 L .57944 .63811 L p .707 .577 .707 r
F P
0 g
s
.57944 .63811 m .57758 .69473 L .54823 .6962 L p .707 .577 .707 r
F P
0 g
s
.54574 .77199 m .54868 .73376 L .57788 .73498 L p .707 .577 .707 r
F P
0 g
s
.57788 .73498 m .57495 .77321 L .54574 .77199 L p .707 .577 .707 r
F P
0 g
s
.57495 .77321 m .57788 .73498 L .6096 .73715 L p .707 .577 .707 r
F P
0 g
s
.6096 .73715 m .60667 .77539 L .57495 .77321 L p .707 .577 .707 r
F P
0 g
s
.5469 .82472 m .5481 .80565 L .57737 .80603 L p .707 .577 .707 r
F P
0 g
s
.57737 .80603 m .57616 .8251 L .5469 .82472 L p .707 .577 .707 r
F P
0 g
s
.57616 .8251 m .57737 .80603 L .60912 .80766 L p .707 .577 .707 r
F P
0 g
s
.53465 .32201 m .53914 .82076 L .58062 .81528 L p .707 .577 .707 r
F P
0 g
s
.57758 .69473 m .57944 .63811 L .61126 .63856 L p .707 .577 .707 r
F P
0 g
s
.61126 .63856 m .6094 .69518 L .57758 .69473 L p .707 .577 .707 r
F P
0 g
s
.58062 .81528 m .57613 .31653 L .53465 .32201 L p .707 .577 .707 r
F P
0 g
s
.45019 .81979 m .4457 .32104 L .40694 .31468 L p .707 .577 .707 r
F P
0 g
s
.4457 .32104 m .45019 .81979 L .4942 .82231 L p .707 .577 .707 r
F P
0 g
s
.7053 .75298 m .70236 .79121 L .69924 .78847 L p .707 .577 .707 r
F P
0 g
s
.69924 .78847 m .70218 .75023 L .7053 .75298 L p .707 .577 .707 r
F P
0 g
s
.64074 .74007 m .6378 .77831 L .61405 .77608 L p .707 .577 .707 r
F P
0 g
s
.61405 .77608 m .60667 .77539 L p .61441 .76736 L .707 .577 .707 r
F P
0 g
s
.61441 .76736 m .64074 .74007 L .61405 .77608 L .707 .577 .707 r
F
.66989 .64485 m .66803 .70147 L .64056 .6975 L p F P
0 g
s
.64056 .6975 m .64242 .64088 L .66989 .64485 L p .707 .577 .707 r
F P
0 g
s
.64242 .64088 m .64056 .6975 L .6094 .69518 L p .707 .577 .707 r
F P
0 g
s
.6094 .69518 m .61126 .63856 L .64242 .64088 L p .707 .577 .707 r
F P
0 g
s
.66823 .74345 m .6653 .78168 L .6378 .77831 L p .707 .577 .707 r
F P
0 g
s
.6378 .77831 m .64074 .74007 L .66823 .74345 L p .707 .577 .707 r
F P
0 g
s
.60667 .77539 m .6096 .73715 L .64074 .74007 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .64767 .78221 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63319 .29627 m .63334 .31324 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.63334 .31324 m .63768 .79501 L p .63355 .3083 L .707 .577 .707 r
F P
0 g
s
.60792 .82673 m .60912 .80766 L .64027 .81039 L p .707 .577 .707 r
F P
0 g
s
.60912 .80766 m .60792 .82673 L .57616 .8251 L p .707 .577 .707 r
F P
0 g
s
.57613 .31653 m .58062 .81528 L .61457 .8064 L p .707 .577 .707 r
F P
0 g
s
.61457 .8064 m .61008 .30766 L .57613 .31653 L p .707 .577 .707 r
F P
0 g
s
.70359 .65606 m .70173 .71268 L .68911 .7067 L p .707 .577 .707 r
F P
0 g
s
.68911 .7067 m .69096 .65008 L .70359 .65606 L p .707 .577 .707 r
F P
0 g
s
.25311 .69668 m .25497 .64006 L .2238 .63774 L p .707 .577 .707 r
F P
0 g
s
.25497 .64006 m .25311 .69668 L .28493 .69712 L p .707 .577 .707 r
F P
0 g
s
.28493 .69712 m .28678 .64051 L .25497 .64006 L p .707 .577 .707 r
F P
0 g
s
.41143 .81343 m .40694 .31468 L .37721 .30512 L p .707 .577 .707 r
F P
0 g
s
.40694 .31468 m .41143 .81343 L .45019 .81979 L p .707 .577 .707 r
F P
0 g
s
.70465 .82594 m .70344 .84501 L .70039 .8412 L p .707 .577 .707 r
F P
0 g
s
.70039 .8412 m .7016 .82213 L .70465 .82594 L p .707 .577 .707 r
F P
0 g
s
.28678 .64051 m .28493 .69712 L .31428 .69565 L p .707 .577 .707 r
F P
0 g
s
.31428 .69565 m .31614 .63903 L .28678 .64051 L p .707 .577 .707 r
F P
0 g
s
.22195 .69435 m .2238 .63774 L .19634 .63376 L p .707 .577 .707 r
F P
0 g
s
.2238 .63774 m .22195 .69435 L .25311 .69668 L p .707 .577 .707 r
F P
0 g
s
.31614 .63903 m .31428 .69565 L .33829 .69241 L p .707 .577 .707 r
F P
0 g
s
.33829 .69241 m .34015 .63579 L .31614 .63903 L p .707 .577 .707 r
F P
0 g
s
.70218 .75023 m .69924 .78847 L .68647 .78518 L p .707 .577 .707 r
F P
0 g
s
.68647 .78518 m .6894 .74695 L .70218 .75023 L p .707 .577 .707 r
F P
0 g
s
.61008 .30766 m .61457 .8064 L .63768 .79501 L p .707 .577 .707 r
F P
0 g
s
.63768 .79501 m .63319 .29627 L .61008 .30766 L p .707 .577 .707 r
F P
0 g
s
.19634 .63376 m .19448 .69038 L .22195 .69435 L p .707 .577 .707 r
F P
0 g
s
.25165 .75375 m .25459 .71551 L .22346 .71259 L p .707 .577 .707 r
F P
0 g
s
.25459 .71551 m .25165 .75375 L .28337 .75592 L p .707 .577 .707 r
F P
0 g
s
.28337 .75592 m .28631 .71769 L .25459 .71551 L p .707 .577 .707 r
F P
0 g
s
.69096 .65008 m .68911 .7067 L .66803 .70147 L p .707 .577 .707 r
F P
0 g
s
.66803 .70147 m .66989 .64485 L .69096 .65008 L p .707 .577 .707 r
F P
0 g
s
.19448 .69038 m .19634 .63376 L .17526 .62854 L p .707 .577 .707 r
F P
0 g
s
.22346 .71259 m .22052 .75083 L .25165 .75375 L p .707 .577 .707 r
F P
0 g
s
.28631 .71769 m .28337 .75592 L .31257 .75714 L p .707 .577 .707 r
F P
0 g
s
.31257 .75714 m .31551 .71891 L .28631 .71769 L p .707 .577 .707 r
F P
0 g
s
.22052 .75083 m .22346 .71259 L .19596 .70922 L p .707 .577 .707 r
F P
0 g
s
.19596 .70922 m .19302 .74745 L .22052 .75083 L p .707 .577 .707 r
F P
0 g
s
.3817 .80386 m .37721 .30512 L .35943 .29327 L p .707 .577 .707 r
F P
0 g
s
.37721 .30512 m .3817 .80386 L .41143 .81343 L p .707 .577 .707 r
F P
0 g
s
.17526 .62854 m .17341 .68515 L .19448 .69038 L p .707 .577 .707 r
F P
0 g
s
.7016 .82213 m .70039 .8412 L .68768 .83707 L p .707 .577 .707 r
F P
0 g
s
.68768 .83707 m .68889 .818 L .7016 .82213 L p .707 .577 .707 r
F P
0 g
s
.31551 .71891 m .31257 .75714 L .3364 .75729 L p .707 .577 .707 r
F P
0 g
s
.3364 .75729 m .33934 .71905 L .31551 .71891 L p .707 .577 .707 r
F P
0 g
s
.34015 .63579 m .33829 .69241 L .35462 .6877 L p .707 .577 .707 r
F P
0 g
s
.35462 .6877 m .35647 .63108 L .34015 .63579 L p .707 .577 .707 r
F P
0 g
s
.2524 .81235 m .2536 .79328 L .22246 .79055 L p .707 .577 .707 r
F P
0 g
s
.2536 .79328 m .2524 .81235 L .28415 .81398 L p .707 .577 .707 r
F P
0 g
s
.28415 .81398 m .28536 .79491 L .2536 .79328 L p .707 .577 .707 r
F P
0 g
s
.22246 .79055 m .22125 .80962 L .2524 .81235 L p .707 .577 .707 r
F P
0 g
s
.28536 .79491 m .28415 .81398 L .31342 .81436 L p .707 .577 .707 r
F P
0 g
s
.31342 .81436 m .31462 .79529 L .28536 .79491 L p .707 .577 .707 r
F P
0 g
s
.19302 .74745 m .19596 .70922 L .17479 .70572 L p .707 .577 .707 r
F P
0 g
s
.6894 .74695 m .68647 .78518 L .6653 .78168 L p .707 .577 .707 r
F P
0 g
s
.6653 .78168 m .66823 .74345 L .6894 .74695 L p .707 .577 .707 r
F P
0 g
s
.17479 .70572 m .17185 .74395 L .19302 .74745 L p .707 .577 .707 r
F P
0 g
s
.22125 .80962 m .22246 .79055 L .19497 .78699 L p .707 .577 .707 r
F P
0 g
s
.17341 .68515 m .17526 .62854 L .16264 .62256 L p .707 .577 .707 r
F P
0 g
s
.19497 .78699 m .19377 .80606 L .22125 .80962 L p .707 .577 .707 r
F P
0 g
s
.64767 .78221 m .64318 .28347 L .63319 .29627 L p .707 .577 .707 r
F P
0 g
s
.31462 .79529 m .31342 .81436 L .33732 .81344 L p .707 .577 .707 r
F P
0 g
s
.33732 .81344 m .33852 .79437 L .31462 .79529 L p .707 .577 .707 r
F P
0 g
s
.16264 .62256 m .16078 .67918 L .17341 .68515 L p .707 .577 .707 r
F P
0 g
s
.33934 .71905 m .3364 .75729 L .35252 .75634 L p .707 .577 .707 r
F P
0 g
s
.35252 .75634 m .35546 .71811 L .33934 .71905 L p .707 .577 .707 r
F P
0 g
s
.19377 .80606 m .19497 .78699 L .17384 .78294 L p .707 .577 .707 r
F P
0 g
s
.68889 .818 m .68768 .83707 L .66655 .83302 L p .707 .577 .707 r
F P
0 g
s
.66655 .83302 m .66775 .81395 L .68889 .818 L p .707 .577 .707 r
F P
0 g
s
.35647 .63108 m .35462 .6877 L .36166 .682 L p .707 .577 .707 r
F P
0 g
s
.36166 .682 m .36351 .62538 L .35647 .63108 L p .707 .577 .707 r
F P
0 g
s
.17384 .78294 m .17263 .80201 L .19377 .80606 L p .707 .577 .707 r
F P
0 g
s
.17185 .74395 m .17479 .70572 L .16202 .70243 L p .707 .577 .707 r
F P
0 g
s
.16202 .70243 m .15908 .74067 L .17185 .74395 L p .707 .577 .707 r
F P
0 g
s
.36351 .62538 m .36166 .682 L .35872 .67586 L p .707 .577 .707 r
F P
0 g
s
.35872 .67586 m .36058 .61925 L .36351 .62538 L p .707 .577 .707 r
F P
0 g
s
.36392 .79202 m .35943 .29327 L .35534 .28032 L p .707 .577 .707 r
F P
0 g
s
.35943 .29327 m .36392 .79202 L .3817 .80386 L p .707 .577 .707 r
F P
0 g
s
.16078 .67918 m .16264 .62256 L .1597 .61642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79437 m .33732 .81344 L .35352 .81131 L p .707 .577 .707 r
F P
0 g
s
.35352 .81131 m .35472 .79224 L .33852 .79437 L p .707 .577 .707 r
F P
0 g
s
.35546 .71811 m .35252 .75634 L .35935 .7544 L p .707 .577 .707 r
F P
0 g
s
.35935 .7544 m .36229 .71617 L .35546 .71811 L p .707 .577 .707 r
F P
0 g
s
.17263 .80201 m .17384 .78294 L .16112 .77881 L p .707 .577 .707 r
F P
0 g
s
.1597 .61642 m .15785 .67304 L .16078 .67918 L p .707 .577 .707 r
F P
0 g
s
.66775 .81395 m .66655 .83302 L .63906 .82946 L p .707 .577 .707 r
F P
0 g
s
.63906 .82946 m .64027 .81039 L .66775 .81395 L p .707 .577 .707 r
F P
0 g
s
.16112 .77881 m .15992 .79788 L .17263 .80201 L p .707 .577 .707 r
F P
0 g
s
.15908 .74067 m .16202 .70243 L .15889 .69968 L p .707 .577 .707 r
F P
0 g
s
.64318 .28347 m .64767 .78221 L .64492 .77349 L p .707 .577 .707 r
F P
0 g
s
.64356 .74773 m .64318 .28347 L .64492 .77349 L .707 .577 .707 r
F
.64358 .76925 m .63909 .27051 L .64318 .28347 L p F P
0 g
s
.63909 .27051 m .64358 .76925 L .6258 .75741 L p .707 .577 .707 r
F P
0 g
s
.64223 .64848 m .63992 .67852 L p .65206 .69 L .707 .577 .707 r
F P
0 g
s
.63992 .67852 m .63929 .68671 L .64037 .68699 L p .707 .577 .707 r
F P
0 g
s
.64037 .68699 m .65206 .69 L p .63992 .67852 L .707 .577 .707 r
F P
0 g
s
.64492 .77349 m .64358 .76925 L p .64356 .74773 L .707 .577 .707 r
F P
0 g
s
.15889 .69968 m .15596 .73792 L .15908 .74067 L p .707 .577 .707 r
F P
0 g
s
.64027 .81039 m .63906 .82946 L .60792 .82673 L p .707 .577 .707 r
F P
0 g
s
.35472 .79224 m .35352 .81131 L .36043 .80819 L p .707 .577 .707 r
F P
0 g
s
.36043 .80819 m .36164 .78912 L .35472 .79224 L p .707 .577 .707 r
F P
0 g
s
.15785 .67304 m .1597 .61642 L .16674 .61072 L p .707 .577 .707 r
F P
0 g
s
.15992 .79788 m .16112 .77881 L .15808 .775 L p .707 .577 .707 r
F P
0 g
s
.36229 .71617 m .35935 .7544 L .35623 .75165 L p .707 .577 .707 r
F P
0 g
s
.35623 .75165 m .35917 .71342 L .36229 .71617 L p .707 .577 .707 r
F P
0 g
s
.36058 .61925 m .35872 .67586 L .3461 .66989 L p .707 .577 .707 r
F P
0 g
s
.3461 .66989 m .34795 .61327 L .36058 .61925 L p .707 .577 .707 r
F P
0 g
s
.35534 .28032 m .35982 .77906 L .36392 .79202 L p .707 .577 .707 r
F P
0 g
s
.35982 .77906 m .35534 .28032 L .36533 .26752 L p .707 .577 .707 r
F P
0 g
s
.15808 .775 m .15687 .79407 L .15992 .79788 L p .707 .577 .707 r
F P
0 g
s
.16674 .61072 m .16489 .66734 L .15785 .67304 L p .707 .577 .707 r
F P
0 g
s
.15596 .73792 m .15889 .69968 L .16573 .69774 L p .707 .577 .707 r
F P
0 g
s
.16573 .69774 m .16279 .73598 L .15596 .73792 L p .707 .577 .707 r
F P
0 g
s
.36164 .78912 m .36043 .80819 L .35739 .80438 L p .707 .577 .707 r
F P
0 g
s
.35739 .80438 m .35859 .78531 L .36164 .78912 L p .707 .577 .707 r
F P
0 g
s
.16489 .66734 m .16674 .61072 L .18307 .60602 L p .707 .577 .707 r
F P
0 g
s
.6258 .75741 m .62131 .25867 L .63909 .27051 L p .707 .577 .707 r
F P
0 g
s
.15687 .79407 m .15808 .775 L .16499 .77188 L p .707 .577 .707 r
F P
0 g
s
.18307 .60602 m .18121 .66264 L .16489 .66734 L p .707 .577 .707 r
F P
0 g
s
.35917 .71342 m .35623 .75165 L .34346 .74837 L p .707 .577 .707 r
F P
0 g
s
.34346 .74837 m .3464 .71013 L .35917 .71342 L p .707 .577 .707 r
F P
0 g
s
.16499 .77188 m .16379 .79095 L .15687 .79407 L p .707 .577 .707 r
F P
0 g
s
.34795 .61327 m .3461 .66989 L .32502 .66466 L p .707 .577 .707 r
F P
0 g
s
.32502 .66466 m .32688 .60804 L .34795 .61327 L p .707 .577 .707 r
F P
0 g
s
.36982 .76626 m .36533 .26752 L .38844 .25612 L p .707 .577 .707 r
F P
0 g
s
.36533 .26752 m .36982 .76626 L .35982 .77906 L p .707 .577 .707 r
F P
0 g
s
.16279 .73598 m .16573 .69774 L .18184 .6968 L p .707 .577 .707 r
F P
0 g
s
.18184 .6968 m .17891 .73503 L .16279 .73598 L p .707 .577 .707 r
F P
0 g
s
.18121 .66264 m .18307 .60602 L .20708 .60277 L p .707 .577 .707 r
F P
0 g
s
.35859 .78531 m .35739 .80438 L .34467 .80025 L p .707 .577 .707 r
F P
0 g
s
.34467 .80025 m .34588 .78118 L .35859 .78531 L p .707 .577 .707 r
F P
0 g
s
.20708 .60277 m .20522 .65939 L .18121 .66264 L p .707 .577 .707 r
F P
0 g
s
.16379 .79095 m .16499 .77188 L .18119 .76976 L p .707 .577 .707 r
F P
0 g
s
.3464 .71013 m .34346 .74837 L .32229 .74487 L p .707 .577 .707 r
F P
0 g
s
.32229 .74487 m .32522 .70663 L .3464 .71013 L p .707 .577 .707 r
F P
0 g
s
.32688 .60804 m .32502 .66466 L .29755 .66069 L p .707 .577 .707 r
F P
0 g
s
.29755 .66069 m .29941 .60407 L .32688 .60804 L p .707 .577 .707 r
F P
0 g
s
.18119 .76976 m .17999 .78883 L .16379 .79095 L p .707 .577 .707 r
F P
0 g
s
.62131 .25867 m .6258 .75741 L .59607 .74784 L p .707 .577 .707 r
F P
0 g
s
.59607 .74784 m .59158 .2491 L .62131 .25867 L p .707 .577 .707 r
F P
0 g
s
.20522 .65939 m .20708 .60277 L .23643 .6013 L p .707 .577 .707 r
F P
0 g
s
.17891 .73503 m .18184 .6968 L .20567 .69694 L p .707 .577 .707 r
F P
0 g
s
.20567 .69694 m .20273 .73518 L .17891 .73503 L p .707 .577 .707 r
F P
0 g
s
.29941 .60407 m .29755 .66069 L .26639 .65837 L p .707 .577 .707 r
F P
0 g
s
.26639 .65837 m .26825 .60175 L .29941 .60407 L p .707 .577 .707 r
F P
0 g
s
.38844 .25612 m .39292 .75487 L .36982 .76626 L p .707 .577 .707 r
F P
0 g
s
.39292 .75487 m .38844 .25612 L .42239 .24725 L p .707 .577 .707 r
F P
0 g
s
.23643 .6013 m .23457 .65792 L .20522 .65939 L p .707 .577 .707 r
F P
0 g
s
.34588 .78118 m .34467 .80025 L .32354 .79621 L p .707 .577 .707 r
F P
0 g
s
.32354 .79621 m .32474 .77714 L .34588 .78118 L p .707 .577 .707 r
F P
0 g
s
.23457 .65792 m .23643 .6013 L .26825 .60175 L p .707 .577 .707 r
F P
0 g
s
.26825 .60175 m .26639 .65837 L .23457 .65792 L p .707 .577 .707 r
F P
0 g
s
.32522 .70663 m .32229 .74487 L .29479 .74149 L p .707 .577 .707 r
F P
0 g
s
.29479 .74149 m .29773 .70326 L .32522 .70663 L p .707 .577 .707 r
F P
0 g
s
.73333 .65704 m .73518 .60042 L .70402 .5981 L p .707 .577 .707 r
F P
0 g
s
.73518 .60042 m .73333 .65704 L .76514 .65749 L p .707 .577 .707 r
F P
0 g
s
.76514 .65749 m .767 .60087 L .73518 .60042 L p .707 .577 .707 r
F P
0 g
s
.17999 .78883 m .18119 .76976 L .20509 .76884 L p .707 .577 .707 r
F P
0 g
s
.767 .60087 m .76514 .65749 L .79449 .65602 L p .707 .577 .707 r
F P
0 g
s
.79449 .65602 m .79635 .5994 L .767 .60087 L p .707 .577 .707 r
F P
0 g
s
.20509 .76884 m .20389 .78791 L .17999 .78883 L p .707 .577 .707 r
F P
0 g
s
.20273 .73518 m .20567 .69694 L .23487 .69816 L p .707 .577 .707 r
F P
0 g
s
.70216 .65472 m .70402 .5981 L .67655 .59413 L p .707 .577 .707 r
F P
0 g
s
.70402 .5981 m .70216 .65472 L .73333 .65704 L p .707 .577 .707 r
F P
0 g
s
.23487 .69816 m .23194 .7364 L .20273 .73518 L p .707 .577 .707 r
F P
0 g
s
.59158 .2491 m .59607 .74784 L .55731 .74149 L p .707 .577 .707 r
F P
0 g
s
.55731 .74149 m .55282 .24274 L .59158 .2491 L p .707 .577 .707 r
F P
0 g
s
.29773 .70326 m .29479 .74149 L .26366 .73857 L p .707 .577 .707 r
F P
0 g
s
.26366 .73857 m .26659 .70034 L .29773 .70326 L p .707 .577 .707 r
F P
0 g
s
.79635 .5994 m .79449 .65602 L .81851 .65277 L p .707 .577 .707 r
F P
0 g
s
.81851 .65277 m .82036 .59615 L .79635 .5994 L p .707 .577 .707 r
F P
0 g
s
.73186 .69979 m .7348 .66156 L .70367 .65864 L p .707 .577 .707 r
F P
0 g
s
.7348 .66156 m .73186 .69979 L .76358 .70197 L p .707 .577 .707 r
F P
0 g
s
.76358 .70197 m .76652 .66373 L .7348 .66156 L p .707 .577 .707 r
F P
0 g
s
.32474 .77714 m .32354 .79621 L .29606 .79265 L p .707 .577 .707 r
F P
0 g
s
.29606 .79265 m .29726 .77358 L .32474 .77714 L p .707 .577 .707 r
F P
0 g
s
.23194 .7364 m .23487 .69816 L .26659 .70034 L p .707 .577 .707 r
F P
0 g
s
.67655 .59413 m .6747 .65075 L .70216 .65472 L p .707 .577 .707 r
F P
0 g
s
.70367 .65864 m .70073 .69687 L .73186 .69979 L p .707 .577 .707 r
F P
0 g
s
.76652 .66373 m .76358 .70197 L .79279 .70319 L p .707 .577 .707 r
F P
0 g
s
.79279 .70319 m .79573 .66495 L .76652 .66373 L p .707 .577 .707 r
F P
0 g
s
.26659 .70034 m .26366 .73857 L .23194 .7364 L p .707 .577 .707 r
F P
0 g
s
.42688 .74599 m .42239 .24725 L .46387 .24177 L p .707 .577 .707 r
F P
0 g
s
.42239 .24725 m .42665 .72043 L p .39292 .75487 L .707 .577 .707 r
F P
0 g
s
.46387 .24177 m .46836 .74051 L .42688 .74599 L p .707 .577 .707 r
F P
0 g
s
.42351 .62692 m .42057 .66515 L .44732 .66627 L p .707 .577 .707 r
F P
0 g
s
.44732 .66627 m .44978 .66637 L p .44819 .66399 L .707 .577 .707 r
F P
0 g
s
.44819 .66399 m .42351 .62692 L .44732 .66627 L .707 .577 .707 r
F
.42665 .72043 m .42688 .74599 L .41578 .74889 L p F P
0 g
s
.41578 .74889 m .39292 .75487 L p .42665 .72043 L .707 .577 .707 r
F P
0 g
s
.6747 .65075 m .67655 .59413 L .65548 .5889 L p .707 .577 .707 r
F P
0 g
s
.70073 .69687 m .70367 .65864 L .67617 .65526 L p .707 .577 .707 r
F P
0 g
s
.20389 .78791 m .20509 .76884 L .23436 .76921 L p .707 .577 .707 r
F P
0 g
s
.23436 .76921 m .23315 .78828 L .20389 .78791 L p .707 .577 .707 r
F P
0 g
s
.67617 .65526 m .67323 .6935 L .70073 .69687 L p .707 .577 .707 r
F P
0 g
s
.73261 .7313 m .73381 .71223 L .70267 .7095 L p .707 .577 .707 r
F P
0 g
s
.73381 .71223 m .73261 .7313 L .76437 .73294 L p .707 .577 .707 r
F P
0 g
s
.76437 .73294 m .76557 .71387 L .73381 .71223 L p .707 .577 .707 r
F P
0 g
s
.70267 .7095 m .70146 .72857 L .73261 .7313 L p .707 .577 .707 r
F P
0 g
s
.76557 .71387 m .76437 .73294 L .79363 .73331 L p .707 .577 .707 r
F P
0 g
s
.79363 .73331 m .79483 .71424 L .76557 .71387 L p .707 .577 .707 r
F P
0 g
s
.55282 .24274 m .55731 .74149 L .5133 .73896 L p .707 .577 .707 r
F P
0 g
s
.5133 .73896 m .50881 .24022 L .55282 .24274 L p .707 .577 .707 r
F P
0 g
s
.79573 .66495 m .79279 .70319 L .81661 .70333 L p .707 .577 .707 r
F P
0 g
s
.81661 .70333 m .81955 .6651 L .79573 .66495 L p .707 .577 .707 r
F P
0 g
s
.29726 .77358 m .29606 .79265 L .26491 .78991 L p .707 .577 .707 r
F P
0 g
s
.26491 .78991 m .26611 .77084 L .29726 .77358 L p .707 .577 .707 r
F P
0 g
s
.65548 .5889 m .65362 .64552 L .6747 .65075 L p .707 .577 .707 r
F P
0 g
s
.70146 .72857 m .70267 .7095 L .67518 .70594 L p .707 .577 .707 r
F P
0 g
s
.23315 .78828 m .23436 .76921 L .26611 .77084 L p .707 .577 .707 r
F P
0 g
s
.67518 .70594 m .67398 .72501 L .70146 .72857 L p .707 .577 .707 r
F P
0 g
s
.82036 .59615 m .81851 .65277 L .83483 .64807 L p .707 .577 .707 r
F P
0 g
s
.83483 .64807 m .83669 .59145 L .82036 .59615 L p .707 .577 .707 r
F P
0 g
s
.46836 .74051 m .46387 .24177 L .50881 .24022 L p .707 .577 .707 r
F P
0 g
s
.26611 .77084 m .26491 .78991 L .23315 .78828 L p .707 .577 .707 r
F P
0 g
s
.67323 .6935 m .67617 .65526 L .655 .65176 L p .707 .577 .707 r
F P
0 g
s
.50881 .24022 m .5133 .73896 L .46836 .74051 L p .707 .577 .707 r
F P
0 g
s
.655 .65176 m .65206 .69 L .67323 .6935 L p .707 .577 .707 r
F P
0 g
s
.79483 .71424 m .79363 .73331 L .81753 .73239 L p .707 .577 .707 r
F P
0 g
s
.81753 .73239 m .81874 .71332 L .79483 .71424 L p .707 .577 .707 r
F P
0 g
s
.65362 .64552 m .65548 .5889 L .64285 .58292 L p .707 .577 .707 r
F P
0 g
s
.67398 .72501 m .67518 .70594 L .65405 .7019 L p .707 .577 .707 r
F P
0 g
s
.65405 .7019 m .65285 .72097 L .67398 .72501 L p .707 .577 .707 r
F P
0 g
s
.81955 .6651 m .81661 .70333 L .83273 .70239 L p .707 .577 .707 r
F P
0 g
s
.83273 .70239 m .83567 .66415 L .81955 .6651 L p .707 .577 .707 r
F P
0 g
s
.64285 .58292 m .641 .63954 L .65362 .64552 L p .707 .577 .707 r
F P
0 g
s
.65206 .69 m .655 .65176 L .64223 .64848 L p .707 .577 .707 r
F P
0 g
s
.83669 .59145 m .83483 .64807 L .84187 .64237 L p .707 .577 .707 r
F P
0 g
s
.84187 .64237 m .84373 .58575 L .83669 .59145 L p .707 .577 .707 r
F P
0 g
s
.81874 .71332 m .81753 .73239 L .83373 .73027 L p .707 .577 .707 r
F P
0 g
s
.83373 .73027 m .83494 .7112 L .81874 .71332 L p .707 .577 .707 r
F P
0 g
s
.65285 .72097 m .65405 .7019 L .64134 .69777 L p .707 .577 .707 r
F P
0 g
s
.641 .63954 m .64285 .58292 L .63992 .57679 L p .707 .577 .707 r
F P
0 g
s
.64134 .69777 m .64013 .71684 L .65285 .72097 L p .707 .577 .707 r
F P
0 g
s
.83567 .66415 m .83273 .70239 L .83957 .70045 L p .707 .577 .707 r
F P
0 g
s
.83957 .70045 m .8425 .66221 L .83567 .66415 L p .707 .577 .707 r
F P
0 g
s
.63992 .57679 m .63806 .6334 L .641 .63954 L p .707 .577 .707 r
F P
0 g
s
.63929 .68671 m .64223 .64848 L .63911 .64573 L p .707 .577 .707 r
F P
0 g
s
.83494 .7112 m .83373 .73027 L .84065 .72715 L p .707 .577 .707 r
F P
0 g
s
.84065 .72715 m .84185 .70808 L .83494 .7112 L p .707 .577 .707 r
F P
0 g
s
.84373 .58575 m .84187 .64237 L .83893 .63623 L p .707 .577 .707 r
F P
0 g
s
.83893 .63623 m .84079 .57961 L .84373 .58575 L p .707 .577 .707 r
F P
0 g
s
.63911 .64573 m .63617 .68396 L .63929 .68671 L p .707 .577 .707 r
F P
0 g
s
.64013 .71684 m .64134 .69777 L .63829 .69396 L p .707 .577 .707 r
F P
0 g
s
.63829 .69396 m .63709 .71303 L .64013 .71684 L p .707 .577 .707 r
F P
0 g
s
.63806 .6334 m .63992 .57679 L .64696 .57109 L p .707 .577 .707 r
F P
0 g
s
.8425 .66221 m .83957 .70045 L .83644 .6977 L p .707 .577 .707 r
F P
0 g
s
.83644 .6977 m .83938 .65946 L .8425 .66221 L p .707 .577 .707 r
F P
0 g
s
.64696 .57109 m .6451 .6277 L .63806 .6334 L p .707 .577 .707 r
F P
0 g
s
.63617 .68396 m .63911 .64573 L .64594 .64379 L p .707 .577 .707 r
F P
0 g
s
.84185 .70808 m .84065 .72715 L .8376 .72334 L p .707 .577 .707 r
F P
0 g
s
.8376 .72334 m .8388 .70427 L .84185 .70808 L p .707 .577 .707 r
F P
0 g
s
.84079 .57961 m .83893 .63623 L .82631 .63025 L p .707 .577 .707 r
F P
0 g
s
.82631 .63025 m .82817 .57363 L .84079 .57961 L p .707 .577 .707 r
F P
0 g
s
.64594 .64379 m .643 .68202 L .63617 .68396 L p .707 .577 .707 r
F P
0 g
s
.39032 .62023 m .39217 .56361 L .36101 .56129 L p .707 .577 .707 r
F P
0 g
s
.39217 .56361 m .39032 .62023 L .42213 .62067 L p .707 .577 .707 r
F P
0 g
s
.42213 .62067 m .42399 .56406 L .39217 .56361 L p .707 .577 .707 r
F P
0 g
s
.63709 .71303 m .63829 .69396 L .64521 .69083 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42399 .56406 m .42213 .62067 L .45148 .6192 L p .707 .577 .707 r
F P
0 g
s
.45148 .6192 m .45334 .56258 L .42399 .56406 L p .707 .577 .707 r
F P
0 g
s
.64521 .69083 m .644 .70991 L .63709 .71303 L p .707 .577 .707 r
F P
0 g
s
.6451 .6277 m .64696 .57109 L .66328 .56638 L p .707 .577 .707 r
F P
0 g
s
.35915 .6179 m .36101 .56129 L .33354 .55731 L p .707 .577 .707 r
F P
0 g
s
.36101 .56129 m .35915 .6179 L .39032 .62023 L p .707 .577 .707 r
F P
0 g
s
.83938 .65946 m .83644 .6977 L .82367 .69441 L p .707 .577 .707 r
F P
0 g
s
.82367 .69441 m .82661 .65618 L .83938 .65946 L p .707 .577 .707 r
F P
0 g
s
.66328 .56638 m .66142 .623 L .6451 .6277 L p .707 .577 .707 r
F P
0 g
s
.45334 .56258 m .45148 .6192 L .4755 .61596 L p .707 .577 .707 r
F P
0 g
s
.4755 .61596 m .47735 .55934 L .45334 .56258 L p .707 .577 .707 r
F P
0 g
s
.38885 .66298 m .39179 .62474 L .36066 .62182 L p .707 .577 .707 r
F P
0 g
s
.39179 .62474 m .38885 .66298 L .42057 .66515 L p .707 .577 .707 r
F P
0 g
s
.42057 .66515 m .42351 .62692 L .39179 .62474 L p .707 .577 .707 r
F P
0 g
s
.33354 .55731 m .33169 .61393 L .35915 .6179 L p .707 .577 .707 r
F P
0 g
s
.36066 .62182 m .35772 .66006 L .38885 .66298 L p .707 .577 .707 r
F P
0 g
s
.44978 .66637 m .45272 .62814 L .42351 .62692 L p .707 .577 .707 r
F P
0 g
s
.82817 .57363 m .82631 .63025 L .80523 .62502 L p .707 .577 .707 r
F P
0 g
s
.80523 .62502 m .80709 .56841 L .82817 .57363 L p .707 .577 .707 r
F P
0 g
s
.643 .68202 m .64594 .64379 L .66206 .64284 L p .707 .577 .707 r
F P
0 g
s
.33169 .61393 m .33354 .55731 L .31247 .55209 L p .707 .577 .707 r
F P
0 g
s
.35772 .66006 m .36066 .62182 L .33316 .61845 L p .707 .577 .707 r
F P
0 g
s
.8388 .70427 m .8376 .72334 L .82489 .71921 L p .707 .577 .707 r
F P
0 g
s
.82489 .71921 m .82609 .70014 L .8388 .70427 L p .707 .577 .707 r
F P
0 g
s
.66206 .64284 m .65912 .68108 L .643 .68202 L p .707 .577 .707 r
F P
0 g
s
.33316 .61845 m .33022 .65668 L .35772 .66006 L p .707 .577 .707 r
F P
0 g
s
.3896 .69449 m .3908 .67542 L .35966 .67269 L p .707 .577 .707 r
F P
0 g
s
.3908 .67542 m .3896 .69449 L .42136 .69612 L p .707 .577 .707 r
F P
0 g
s
.42136 .69612 m .42256 .67705 L .3908 .67542 L p .707 .577 .707 r
F P
0 g
s
.35966 .67269 m .35845 .69176 L .3896 .69449 L p .707 .577 .707 r
F P
0 g
s
.42256 .67705 m .42136 .69612 L .45062 .6965 L p .707 .577 .707 r
F P
0 g
s
.45062 .6965 m .45182 .67743 L .42256 .67705 L p .707 .577 .707 r
F P
0 g
s
.66142 .623 m .66328 .56638 L .68729 .56314 L p .707 .577 .707 r
F P
0 g
s
.45272 .62814 m .44978 .66637 L .4736 .66652 L p .707 .577 .707 r
F P
0 g
s
.4736 .66652 m .47654 .62828 L .45272 .62814 L p .707 .577 .707 r
F P
0 g
s
.644 .70991 m .64521 .69083 L .66141 .68871 L p .707 .577 .707 r
F P
0 g
s
.31247 .55209 m .31061 .6087 L .33169 .61393 L p .707 .577 .707 r
F P
0 g
s
.35845 .69176 m .35966 .67269 L .33217 .66913 L p .707 .577 .707 r
F P
0 g
s
.66141 .68871 m .6602 .70778 L .644 .70991 L p .707 .577 .707 r
F P
0 g
s
.33217 .66913 m .33097 .6882 L .35845 .69176 L p .707 .577 .707 r
F P
0 g
s
.47735 .55934 m .4755 .61596 L .49182 .61125 L p .707 .577 .707 r
F P
0 g
s
.49182 .61125 m .49368 .55463 L .47735 .55934 L p .707 .577 .707 r
F P
0 g
s
.33022 .65668 m .33316 .61845 L .31199 .61495 L p .707 .577 .707 r
F P
0 g
s
.82661 .65618 m .82367 .69441 L .8025 .69091 L p .707 .577 .707 r
F P
0 g
s
.8025 .69091 m .80544 .65268 L .82661 .65618 L p .707 .577 .707 r
F P
0 g
s
.31199 .61495 m .30905 .65318 L .33022 .65668 L p .707 .577 .707 r
F P
0 g
s
.68729 .56314 m .68544 .61975 L .66142 .623 L p .707 .577 .707 r
F P
0 g
s
.45182 .67743 m .45062 .6965 L .47452 .69558 L p .707 .577 .707 r
F P
0 g
s
.47452 .69558 m .47573 .67651 L .45182 .67743 L p .707 .577 .707 r
F P
0 g
s
.80709 .56841 m .80523 .62502 L .77777 .62105 L p .707 .577 .707 r
F P
0 g
s
.77777 .62105 m .77963 .56443 L .80709 .56841 L p .707 .577 .707 r
F P
0 g
s
.31061 .6087 m .31247 .55209 L .29984 .54611 L p .707 .577 .707 r
F P
0 g
s
.65912 .68108 m .66206 .64284 L .68588 .64299 L p .707 .577 .707 r
F P
0 g
s
.33097 .6882 m .33217 .66913 L .31104 .66508 L p .707 .577 .707 r
F P
0 g
s
.82609 .70014 m .82489 .71921 L .80375 .71516 L p .707 .577 .707 r
F P
0 g
s
.80375 .71516 m .80496 .69609 L .82609 .70014 L p .707 .577 .707 r
F P
0 g
s
.31104 .66508 m .30984 .68415 L .33097 .6882 L p .707 .577 .707 r
F P
0 g
s
.68544 .61975 m .68729 .56314 L .71664 .56166 L p .707 .577 .707 r
F P
0 g
s
.68588 .64299 m .68295 .68122 L .65912 .68108 L p .707 .577 .707 r
F P
0 g
s
.47654 .62828 m .4736 .66652 L .48972 .66557 L p .707 .577 .707 r
F P
0 g
s
.48972 .66557 m .49266 .62734 L .47654 .62828 L p .707 .577 .707 r
F P
0 g
s
.29984 .54611 m .29799 .60273 L .31061 .6087 L p .707 .577 .707 r
F P
0 g
s
.6602 .70778 m .66141 .68871 L .68531 .68779 L p .707 .577 .707 r
F P
0 g
s
.77963 .56443 m .77777 .62105 L .7466 .61873 L p .707 .577 .707 r
F P
0 g
s
.7466 .61873 m .74846 .56211 L .77963 .56443 L p .707 .577 .707 r
F P
0 g
s
.30905 .65318 m .31199 .61495 L .29922 .61166 L p .707 .577 .707 r
F P
0 g
s
.68531 .68779 m .6841 .70686 L .6602 .70778 L p .707 .577 .707 r
F P
0 g
s
.71664 .56166 m .71479 .61828 L .68544 .61975 L p .707 .577 .707 r
F P
0 g
s
.49368 .55463 m .49182 .61125 L .49886 .60555 L p .707 .577 .707 r
F P
0 g
s
.49886 .60555 m .50072 .54893 L .49368 .55463 L p .707 .577 .707 r
F P
0 g
s
.80544 .65268 m .8025 .69091 L .775 .68754 L p .707 .577 .707 r
F P
0 g
s
.775 .68754 m .77794 .6493 L .80544 .65268 L p .707 .577 .707 r
F P
0 g
s
.47573 .67651 m .47452 .69558 L .49072 .69345 L p .707 .577 .707 r
F P
0 g
s
.49072 .69345 m .49193 .67438 L .47573 .67651 L p .707 .577 .707 r
F P
0 g
s
.71479 .61828 m .71664 .56166 L .74846 .56211 L p .707 .577 .707 r
F P
0 g
s
.29922 .61166 m .29628 .6499 L .30905 .65318 L p .707 .577 .707 r
F P
0 g
s
.74846 .56211 m .7466 .61873 L .71479 .61828 L p .707 .577 .707 r
F P
0 g
s
.68295 .68122 m .68588 .64299 L .71509 .64421 L p .707 .577 .707 r
F P
0 g
s
.30984 .68415 m .31104 .66508 L .29833 .66095 L p .707 .577 .707 r
F P
0 g
s
.71509 .64421 m .71215 .68244 L .68295 .68122 L p .707 .577 .707 r
F P
0 g
s
.29799 .60273 m .29984 .54611 L .29691 .53997 L p .707 .577 .707 r
F P
0 g
s
.80496 .69609 m .80375 .71516 L .77627 .7116 L p .707 .577 .707 r
F P
0 g
s
.77627 .7116 m .77747 .69253 L .80496 .69609 L p .707 .577 .707 r
F P
0 g
s
.29833 .66095 m .29712 .68002 L .30984 .68415 L p .707 .577 .707 r
F P
0 g
s
.77794 .6493 m .775 .68754 L .74387 .68462 L p .707 .577 .707 r
F P
0 g
s
.74387 .68462 m .74681 .64638 L .77794 .6493 L p .707 .577 .707 r
F P
0 g
s
.49266 .62734 m .48972 .66557 L .49656 .66363 L p .707 .577 .707 r
F P
0 g
s
.49656 .66363 m .49949 .6254 L .49266 .62734 L p .707 .577 .707 r
F P
0 g
s
.6841 .70686 m .68531 .68779 L .71457 .68817 L p .707 .577 .707 r
F P
0 g
s
.71215 .68244 m .71509 .64421 L .74681 .64638 L p .707 .577 .707 r
F P
0 g
s
.71457 .68817 m .71337 .70724 L .6841 .70686 L p .707 .577 .707 r
F P
0 g
s
.29691 .53997 m .29505 .59659 L .29799 .60273 L p .707 .577 .707 r
F P
0 g
s
.74681 .64638 m .74387 .68462 L .71215 .68244 L p .707 .577 .707 r
F P
0 g
s
.29628 .6499 m .29922 .61166 L .2961 .60891 L p .707 .577 .707 r
F P
0 g
s
.77747 .69253 m .77627 .7116 L .74512 .70887 L p .707 .577 .707 r
F P
0 g
s
.74512 .70887 m .74633 .6898 L .77747 .69253 L p .707 .577 .707 r
F P
0 g
s
.49193 .67438 m .49072 .69345 L .49764 .69033 L p .707 .577 .707 r
F P
0 g
s
.49764 .69033 m .49884 .67126 L .49193 .67438 L p .707 .577 .707 r
F P
0 g
s
.50072 .54893 m .49886 .60555 L .49592 .59941 L p .707 .577 .707 r
F P
0 g
s
.49592 .59941 m .49778 .5428 L .50072 .54893 L p .707 .577 .707 r
F P
0 g
s
.2961 .60891 m .29316 .64715 L .29628 .6499 L p .707 .577 .707 r
F P
0 g
s
.71337 .70724 m .71457 .68817 L .74633 .6898 L p .707 .577 .707 r
F P
0 g
s
.74633 .6898 m .74512 .70887 L .71337 .70724 L p .707 .577 .707 r
F P
0 g
s
.29712 .68002 m .29833 .66095 L .29528 .65714 L p .707 .577 .707 r
F P
0 g
s
.29528 .65714 m .29407 .67621 L .29712 .68002 L p .707 .577 .707 r
F P
0 g
s
.29505 .59659 m .29691 .53997 L .30394 .53427 L p .707 .577 .707 r
F P
0 g
s
.49949 .6254 m .49656 .66363 L .49343 .66088 L p .707 .577 .707 r
F P
0 g
s
.49343 .66088 m .49637 .62265 L .49949 .6254 L p .707 .577 .707 r
F P
0 g
s
.30394 .53427 m .30209 .59089 L .29505 .59659 L p .707 .577 .707 r
F P
0 g
s
.29316 .64715 m .2961 .60891 L .30293 .60697 L p .707 .577 .707 r
F P
0 g
s
.49884 .67126 m .49764 .69033 L .49459 .68652 L p .707 .577 .707 r
F P
0 g
s
.49459 .68652 m .49579 .66745 L .49884 .67126 L p .707 .577 .707 r
F P
0 g
s
.49778 .5428 m .49592 .59941 L .4833 .59344 L p .707 .577 .707 r
F P
0 g
s
.4833 .59344 m .48516 .53682 L .49778 .5428 L p .707 .577 .707 r
F P
0 g
s
.30293 .60697 m .29999 .64521 L .29316 .64715 L p .707 .577 .707 r
F P
0 g
s
.29407 .67621 m .29528 .65714 L .30219 .65402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30219 .65402 m .30099 .67309 L .29407 .67621 L p .707 .577 .707 r
F P
0 g
s
.30209 .59089 m .30394 .53427 L .32027 .52957 L p .707 .577 .707 r
F P
0 g
s
.49637 .62265 m .49343 .66088 L .48066 .6576 L p .707 .577 .707 r
F P
0 g
s
.48066 .6576 m .4836 .61936 L .49637 .62265 L p .707 .577 .707 r
F P
0 g
s
.32027 .52957 m .31841 .58619 L .30209 .59089 L p .707 .577 .707 r
F P
0 g
s
.48516 .53682 m .4833 .59344 L .46222 .58821 L p .707 .577 .707 r
F P
0 g
s
.46222 .58821 m .46408 .53159 L .48516 .53682 L p .707 .577 .707 r
F P
0 g
s
.29999 .64521 m .30293 .60697 L .31905 .60603 L p .707 .577 .707 r
F P
0 g
s
.49579 .66745 m .49459 .68652 L .48188 .68239 L p .707 .577 .707 r
F P
0 g
s
.48188 .68239 m .48308 .66332 L .49579 .66745 L p .707 .577 .707 r
F P
0 g
s
.31905 .60603 m .31611 .64426 L .29999 .64521 L p .707 .577 .707 r
F P
0 g
s
.31841 .58619 m .32027 .52957 L .34428 .52632 L p .707 .577 .707 r
F P
0 g
s
.30099 .67309 m .30219 .65402 L .3184 .6519 L p .707 .577 .707 r
F P
0 g
s
.3184 .6519 m .31719 .67097 L .30099 .67309 L p .707 .577 .707 r
F P
0 g
s
.4836 .61936 m .48066 .6576 L .45949 .65409 L p .707 .577 .707 r
F P
0 g
s
.45949 .65409 m .46243 .61586 L .4836 .61936 L p .707 .577 .707 r
F P
0 g
s
.34428 .52632 m .34243 .58294 L .31841 .58619 L p .707 .577 .707 r
F P
0 g
s
.46408 .53159 m .46222 .58821 L .43476 .58424 L p .707 .577 .707 r
F P
0 g
s
.43476 .58424 m .43661 .52762 L .46408 .53159 L p .707 .577 .707 r
F P
0 g
s
.31611 .64426 m .31905 .60603 L .34287 .60617 L p .707 .577 .707 r
F P
0 g
s
.48308 .66332 m .48188 .68239 L .46074 .67835 L p .707 .577 .707 r
F P
0 g
s
.46074 .67835 m .46195 .65928 L .48308 .66332 L p .707 .577 .707 r
F P
0 g
s
.34243 .58294 m .34428 .52632 L .37363 .52485 L p .707 .577 .707 r
F P
0 g
s
.34287 .60617 m .33994 .64441 L .31611 .64426 L p .707 .577 .707 r
F P
0 g
s
.31719 .67097 m .3184 .6519 L .3423 .65098 L p .707 .577 .707 r
F P
0 g
s
.43661 .52762 m .43476 .58424 L .40359 .58192 L p .707 .577 .707 r
F P
0 g
s
.40359 .58192 m .40545 .5253 L .43661 .52762 L p .707 .577 .707 r
F P
0 g
s
.3423 .65098 m .34109 .67005 L .31719 .67097 L p .707 .577 .707 r
F P
0 g
s
.37363 .52485 m .37178 .58147 L .34243 .58294 L p .707 .577 .707 r
F P
0 g
s
.46243 .61586 m .45949 .65409 L .43199 .65072 L p .707 .577 .707 r
F P
0 g
s
.43199 .65072 m .43493 .61249 L .46243 .61586 L p .707 .577 .707 r
F P
0 g
s
.37178 .58147 m .37363 .52485 L .40545 .5253 L p .707 .577 .707 r
F P
0 g
s
.40545 .5253 m .40359 .58192 L .37178 .58147 L p .707 .577 .707 r
F P
0 g
s
.33994 .64441 m .34287 .60617 L .37208 .60739 L p .707 .577 .707 r
F P
0 g
s
.37208 .60739 m .36914 .64563 L .33994 .64441 L p .707 .577 .707 r
F P
0 g
s
.46195 .65928 m .46074 .67835 L .43326 .67479 L p .707 .577 .707 r
F P
0 g
s
.43326 .67479 m .43446 .65572 L .46195 .65928 L p .707 .577 .707 r
F P
0 g
s
.43493 .61249 m .43199 .65072 L .40086 .6478 L p .707 .577 .707 r
F P
0 g
s
.40086 .6478 m .4038 .60957 L .43493 .61249 L p .707 .577 .707 r
F P
0 g
s
.34109 .67005 m .3423 .65098 L .37156 .65135 L p .707 .577 .707 r
F P
0 g
s
.36914 .64563 m .37208 .60739 L .4038 .60957 L p .707 .577 .707 r
F P
0 g
s
.37156 .65135 m .37035 .67042 L .34109 .67005 L p .707 .577 .707 r
F P
0 g
s
.4038 .60957 m .40086 .6478 L .36914 .64563 L p .707 .577 .707 r
F P
0 g
s
.43446 .65572 m .43326 .67479 L .40211 .67205 L p .707 .577 .707 r
F P
0 g
s
.40211 .67205 m .40332 .65298 L .43446 .65572 L p .707 .577 .707 r
F P
0 g
s
.37035 .67042 m .37156 .65135 L .40332 .65298 L p .707 .577 .707 r
F P
0 g
s
.40332 .65298 m .40211 .67205 L .37035 .67042 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaH008Io
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH015YF3000NWoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^
Ool006aoo`<000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00Jgoo001XOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH00000JGoo001WOol00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000J7oo001VOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Io
o`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo6@0000=JEP00FUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001IOol60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000@OolA0014
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool80003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool60003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Woo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000`Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00Dgoo00<005YF0000
15YF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000eYF1P001eYF00<005YFFUH01UYF00<005YF
FUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool005=oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH70003FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo
00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008002eoo`00>7oo
7@000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
<Woo1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF6P0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02moo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF00AJEP04
001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP04001JEP00
0006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH:0008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00D000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPL00003FUH005YF00IJEP03001JEUYF00IJ
EPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF00000UYF1P0025YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00
15YF00@005YFFUIJEP8002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@0009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEQ8000QJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00005`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH50002FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHC0007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000IJEP03001JEUYF00<002moo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF:P0015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPX0039oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH0
1000FUIJEUYF7@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPl000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000/Ool00`00
FUH00002FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH01000FUH005YF10001EYF00@005YFFUIJEPT000=JEQ4000=JEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0004FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF010000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000_Ool40004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30002FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUHB0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003=o
o`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00H000=JEP03001JEUYF00IJEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00
00005P001eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000fOol50004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF3@0015YF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF5`000eYF00<005YFFUH00P00;Woo000kOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH70009Ool00`00FUIJEP0C0004FUH01000FUIJEUYF2@0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF0000000300000eYF0000000^Ool002eo
obT0011oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0800000eYF001JEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008000=JEP<002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF4@003Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`001goo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUHQ
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@000goo200015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH400000eYF0000000@0003FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@000UYF00<007ooOol0;7oo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00FUH005YF1`0015YF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF5`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001@005goo5P00<Woo000/OolJ0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUHA0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1eYF7P0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000006=oo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF1P00GGoo000c
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH80002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH000030006FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP05001HOol003Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH40002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUH00002001EOol004=ooa4000AJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03001JEUYF009JEP03001J
EUYF00=JEP04001JEUYFFUH2001DOol005Aooa<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH00000
1UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo00D005YFFUH005YF
008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
E7oo001VOol00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000aOolF000OOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA000>Ool20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH00P00
EGoo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJ
EP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00=JEP03001J
EUYF008005Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000Woo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH020000eYF00<005YFFUH00P00EGoo000/Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
0002FUH00`00FUIJEP03FUH500000eYF0000001EOol002aoo`03001JEP00024000AJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=J
EP03001JEUYF00AJEP04001JEUYFFUH3001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPT000=oo`P000=JEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUHB001FOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P00Igoo000^Ool200000eYF001JEP04FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH20003Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo000`Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF10001Goo0P001UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000
06]oo`00=7oo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF00001goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@00K7oo000kOolA0004FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIJEP04000:Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0400000eYF001JEP02FUH8001TOol004aooaH0015o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00EJ
EP04001JEUYFFUH7001MOol007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP04001JEUYF
FUH70008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05001HOol007eoob0000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00SWoo00<005YF00000UYF5@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Aoo`00SWoo00<005YF00000P001EYF00@005YFFUIJEPT000=ooa4000AJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF009JEQX000AJEP04001JEUYFFUH2001DOol008ioo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP03001oogoo05=oo`00T7oo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<007ooOol0Dgoo002EOol7
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00EGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Eoo`00YGoo4@0015YF00@005YFFUIJEPT005Ioo`00]Woo2000Ggoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5964 .76511 m .59455 .71098 L .56338 .70949 L p .707 .577 .707 r
F P
0 g
s
.59455 .71098 m .5964 .76511 L .62822 .76313 L p .707 .577 .707 r
F P
0 g
s
.62822 .76313 m .62636 .70901 L .59455 .71098 L p .707 .577 .707 r
F P
0 g
s
.62636 .70901 m .62822 .76313 L .65757 .75789 L p .707 .577 .707 r
F P
0 g
s
.65757 .75789 m .65571 .70376 L .62636 .70901 L p .707 .577 .707 r
F P
0 g
s
.56524 .76362 m .56338 .70949 L .53592 .70469 L p .707 .577 .707 r
F P
0 g
s
.56338 .70949 m .56524 .76362 L .5964 .76511 L p .707 .577 .707 r
F P
0 g
s
.65571 .70376 m .65757 .75789 L .68158 .74989 L p .707 .577 .707 r
F P
0 g
s
.68158 .74989 m .67973 .69576 L .65571 .70376 L p .707 .577 .707 r
F P
0 g
s
.53777 .75882 m .53592 .70469 L .51484 .69704 L p .707 .577 .707 r
F P
0 g
s
.53592 .70469 m .53777 .75882 L .56524 .76362 L p .707 .577 .707 r
F P
0 g
s
.59914 .82733 m .5962 .79304 L .56507 .7921 L p .707 .577 .707 r
F P
0 g
s
.5962 .79304 m .59914 .82733 L .63086 .82375 L p .707 .577 .707 r
F P
0 g
s
.63086 .82375 m .62792 .78946 L .5962 .79304 L p .707 .577 .707 r
F P
0 g
s
.62792 .78946 m .63086 .82375 L .66006 .81602 L p .707 .577 .707 r
F P
0 g
s
.66006 .81602 m .65712 .78172 L .62792 .78946 L p .707 .577 .707 r
F P
0 g
s
.67973 .69576 m .68158 .74989 L .69791 .73992 L p .707 .577 .707 r
F P
0 g
s
.69791 .73992 m .69605 .68579 L .67973 .69576 L p .707 .577 .707 r
F P
0 g
s
.56801 .82639 m .56507 .7921 L .53757 .78674 L p .707 .577 .707 r
F P
0 g
s
.56507 .7921 m .56801 .82639 L .59914 .82733 L p .707 .577 .707 r
F P
0 g
s
.65712 .78172 m .66006 .81602 L .68389 .80488 L p .707 .577 .707 r
F P
0 g
s
.68389 .80488 m .68095 .77058 L .65712 .78172 L p .707 .577 .707 r
F P
0 g
s
.59788 .85326 m .59668 .83581 L .56553 .8347 L p .707 .577 .707 r
F P
0 g
s
.59668 .83581 m .59788 .85326 L .62964 .85018 L p .707 .577 .707 r
F P
0 g
s
.62964 .85018 m .62844 .83272 L .59668 .83581 L p .707 .577 .707 r
F P
0 g
s
.62844 .83272 m .62964 .85018 L .6589 .84321 L p .707 .577 .707 r
F P
0 g
s
.6589 .84321 m .6577 .82575 L .62844 .83272 L p .707 .577 .707 r
F P
0 g
s
.51484 .69704 m .5167 .75116 L .53777 .75882 L p .707 .577 .707 r
F P
0 g
s
.5167 .75116 m .51484 .69704 L .50222 .68729 L p .707 .577 .707 r
F P
0 g
s
.56674 .85216 m .56553 .8347 L .53805 .82952 L p .707 .577 .707 r
F P
0 g
s
.56553 .8347 m .56674 .85216 L .59788 .85326 L p .707 .577 .707 r
F P
0 g
s
.54051 .82104 m .53757 .78674 L .5164 .77749 L p .707 .577 .707 r
F P
0 g
s
.53757 .78674 m .54051 .82104 L .56801 .82639 L p .707 .577 .707 r
F P
0 g
s
.6577 .82575 m .6589 .84321 L .68281 .83303 L p .707 .577 .707 r
F P
0 g
s
.68281 .83303 m .6816 .81558 L .6577 .82575 L p .707 .577 .707 r
F P
0 g
s
.53805 .82952 m .53925 .84697 L .56674 .85216 L p .707 .577 .707 r
F P
0 g
s
.68095 .77058 m .68389 .80488 L .70001 .79142 L p .707 .577 .707 r
F P
0 g
s
.70001 .79142 m .69707 .75713 L .68095 .77058 L p .707 .577 .707 r
F P
0 g
s
.69605 .68579 m .69791 .73992 L .70495 .72895 L p .707 .577 .707 r
F P
0 g
s
.70495 .72895 m .70309 .67482 L .69605 .68579 L p .707 .577 .707 r
F P
0 g
s
.53925 .84697 m .53805 .82952 L .51692 .82076 L p .707 .577 .707 r
F P
0 g
s
.50222 .68729 m .50407 .74142 L .5167 .75116 L p .707 .577 .707 r
F P
0 g
s
.5164 .77749 m .51934 .81178 L .54051 .82104 L p .707 .577 .707 r
F P
0 g
s
.51692 .82076 m .51812 .83821 L .53925 .84697 L p .707 .577 .707 r
F P
0 g
s
.6816 .81558 m .68281 .83303 L .69901 .82064 L p .707 .577 .707 r
F P
0 g
s
.69901 .82064 m .6978 .80319 L .6816 .81558 L p .707 .577 .707 r
F P
0 g
s
.51934 .81178 m .5164 .77749 L .50363 .76525 L p .707 .577 .707 r
F P
0 g
s
.50407 .74142 m .50222 .68729 L .49928 .6764 L p .707 .577 .707 r
F P
0 g
s
.69707 .75713 m .70001 .79142 L .70684 .77697 L p .707 .577 .707 r
F P
0 g
s
.70684 .77697 m .7039 .74268 L .69707 .75713 L p .707 .577 .707 r
F P
0 g
s
.51812 .83821 m .51692 .82076 L .5042 .80928 L p .707 .577 .707 r
F P
0 g
s
.70309 .67482 m .70495 .72895 L .70201 .71806 L p .707 .577 .707 r
F P
0 g
s
.70201 .71806 m .70015 .66393 L .70309 .67482 L p .707 .577 .707 r
F P
0 g
s
.50363 .76525 m .50656 .79954 L .51934 .81178 L p .707 .577 .707 r
F P
0 g
s
.49928 .6764 m .50114 .73052 L .50407 .74142 L p .707 .577 .707 r
F P
0 g
s
.5042 .80928 m .50541 .82673 L .51812 .83821 L p .707 .577 .707 r
F P
0 g
s
.6978 .80319 m .69901 .82064 L .70592 .80726 L p .707 .577 .707 r
F P
0 g
s
.70592 .80726 m .70472 .78981 L .6978 .80319 L p .707 .577 .707 r
F P
0 g
s
.50656 .79954 m .50363 .76525 L .5005 .75122 L p .707 .577 .707 r
F P
0 g
s
.4867 .82121 m .49119 .31645 L .44718 .31361 L p .707 .577 .707 r
F P
0 g
s
.50114 .73052 m .49928 .6764 L .50632 .66543 L p .707 .577 .707 r
F P
0 g
s
.50541 .82673 m .5042 .80928 L .50116 .79621 L p .707 .577 .707 r
F P
0 g
s
.5005 .75122 m .50344 .78551 L .50656 .79954 L p .707 .577 .707 r
F P
0 g
s
.50116 .79621 m .50236 .81366 L .50541 .82673 L p .707 .577 .707 r
F P
0 g
s
.50632 .66543 m .50818 .71955 L .50114 .73052 L p .707 .577 .707 r
F P
0 g
s
.50344 .78551 m .5005 .75122 L .50734 .73676 L p .707 .577 .707 r
F P
0 g
s
.50818 .71955 m .50632 .66543 L .52265 .65545 L p .707 .577 .707 r
F P
0 g
s
.50236 .81366 m .50116 .79621 L .50807 .78283 L p .707 .577 .707 r
F P
0 g
s
.50734 .73676 m .51027 .77106 L .50344 .78551 L p .707 .577 .707 r
F P
0 g
s
.50807 .78283 m .50928 .80028 L .50236 .81366 L p .707 .577 .707 r
F P
0 g
s
.52265 .65545 m .5245 .70958 L .50818 .71955 L p .707 .577 .707 r
F P
0 g
s
.51027 .77106 m .50734 .73676 L .52346 .72331 L p .707 .577 .707 r
F P
0 g
s
.50928 .80028 m .50807 .78283 L .52427 .77044 L p .707 .577 .707 r
F P
0 g
s
.52346 .72331 m .52639 .7576 L .51027 .77106 L p .707 .577 .707 r
F P
0 g
s
.52427 .77044 m .52548 .78789 L .50928 .80028 L p .707 .577 .707 r
F P
0 g
s
.52639 .7576 m .52346 .72331 L .54728 .71217 L p .707 .577 .707 r
F P
0 g
s
.52548 .78789 m .52427 .77044 L .54817 .76026 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .55022 .74646 L .52639 .7576 L p .707 .577 .707 r
F P
0 g
s
.54817 .76026 m .54938 .77772 L .52548 .78789 L p .707 .577 .707 r
F P
0 g
s
.49119 .31645 m .4867 .82121 L .53164 .82057 L p .707 .577 .707 r
F P
0 g
s
.5245 .70958 m .52265 .65545 L .54666 .64745 L p .707 .577 .707 r
F P
0 g
s
.54666 .64745 m .54851 .70158 L .5245 .70958 L p .707 .577 .707 r
F P
0 g
s
.53164 .82057 m .53613 .31581 L .49119 .31645 L p .707 .577 .707 r
F P
0 g
s
.54851 .70158 m .54666 .64745 L .57601 .64221 L p .707 .577 .707 r
F P
0 g
s
.57601 .64221 m .57787 .69634 L .54851 .70158 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .57648 .70443 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.55022 .74646 m .54959 .73911 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.54959 .73911 m .54728 .71217 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.57787 .69634 m .57601 .64221 L .60782 .64023 L p .707 .577 .707 r
F P
0 g
s
.60782 .64023 m .60968 .69436 L .57787 .69634 L p .707 .577 .707 r
F P
0 g
s
.57942 .73872 m .57648 .70443 L .6082 .70086 L p .707 .577 .707 r
F P
0 g
s
.57648 .70443 m .57942 .73872 L .55022 .74646 L p .707 .577 .707 r
F P
0 g
s
.6082 .70086 m .61114 .73515 L .57942 .73872 L p .707 .577 .707 r
F P
0 g
s
.54938 .77772 m .54817 .76026 L .57743 .75329 L p .707 .577 .707 r
F P
0 g
s
.57743 .75329 m .57864 .77075 L .54938 .77772 L p .707 .577 .707 r
F P
0 g
s
.57864 .77075 m .57743 .75329 L .60919 .75021 L p .707 .577 .707 r
F P
0 g
s
.60919 .75021 m .6104 .76766 L .57864 .77075 L p .707 .577 .707 r
F P
0 g
s
.57761 .31175 m .57335 .79065 L p .60707 .80944 L .707 .577 .707 r
F P
0 g
s
.57335 .79065 m .57312 .81652 L .58421 .81421 L p .707 .577 .707 r
F P
0 g
s
.58421 .81421 m .60707 .80944 L p .57335 .79065 L .707 .577 .707 r
F P
0 g
s
.53613 .31581 m .53164 .82057 L .57312 .81652 L p .707 .577 .707 r
F P
0 g
s
.57312 .81652 m .57761 .31175 L .53613 .31581 L p .707 .577 .707 r
F P
0 g
s
.7039 .74268 m .70684 .77697 L .70372 .76294 L p .707 .577 .707 r
F P
0 g
s
.70372 .76294 m .70078 .72864 L .7039 .74268 L p .707 .577 .707 r
F P
0 g
s
.44269 .81837 m .44718 .31361 L .40842 .30756 L p .707 .577 .707 r
F P
0 g
s
.44718 .31361 m .44269 .81837 L .4867 .82121 L p .707 .577 .707 r
F P
0 g
s
.70015 .66393 m .70201 .71806 L .68939 .70831 L p .707 .577 .707 r
F P
0 g
s
.68939 .70831 m .68753 .65418 L .70015 .66393 L p .707 .577 .707 r
F P
0 g
s
.60968 .69436 m .60782 .64023 L .63899 .64172 L p .707 .577 .707 r
F P
0 g
s
.60707 .80944 m .61156 .30468 L .57761 .31175 L p .707 .577 .707 r
F P
0 g
s
.70472 .78981 m .70592 .80726 L .70287 .79419 L p .707 .577 .707 r
F P
0 g
s
.70287 .79419 m .70167 .77674 L .70472 .78981 L p .707 .577 .707 r
F P
0 g
s
.2534 .72829 m .25154 .67417 L .22037 .67268 L p .707 .577 .707 r
F P
0 g
s
.25154 .67417 m .2534 .72829 L .28521 .72632 L p .707 .577 .707 r
F P
0 g
s
.28521 .72632 m .28335 .67219 L .25154 .67417 L p .707 .577 .707 r
F P
0 g
s
.40393 .81233 m .40842 .30756 L .37869 .29891 L p .707 .577 .707 r
F P
0 g
s
.40842 .30756 m .40393 .81233 L .44269 .81837 L p .707 .577 .707 r
F P
0 g
s
.28335 .67219 m .28521 .72632 L .31456 .72108 L p .707 .577 .707 r
F P
0 g
s
.31456 .72108 m .3127 .66695 L .28335 .67219 L p .707 .577 .707 r
F P
0 g
s
.70078 .72864 m .70372 .76294 L .69094 .75069 L p .707 .577 .707 r
F P
0 g
s
.69094 .75069 m .68801 .7164 L .70078 .72864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22223 .72681 m .22037 .67268 L .19291 .66787 L p .707 .577 .707 r
F P
0 g
s
.22037 .67268 m .22223 .72681 L .2534 .72829 L p .707 .577 .707 r
F P
0 g
s
.68753 .65418 m .68939 .70831 L .66831 .70065 L p .707 .577 .707 r
F P
0 g
s
.66831 .70065 m .66645 .64653 L .68753 .65418 L p .707 .577 .707 r
F P
0 g
s
.3127 .66695 m .31456 .72108 L .33857 .71308 L p .707 .577 .707 r
F P
0 g
s
.33857 .71308 m .33672 .65895 L .3127 .66695 L p .707 .577 .707 r
F P
0 g
s
.63899 .64172 m .64085 .69585 L .60968 .69436 L p .707 .577 .707 r
F P
0 g
s
.63934 .70179 m .64228 .73609 L .61114 .73515 L p .707 .577 .707 r
F P
0 g
s
.61114 .73515 m .6082 .70086 L .63934 .70179 L p .707 .577 .707 r
F P
0 g
s
.64034 .75131 m .64154 .76877 L .6104 .76766 L p .707 .577 .707 r
F P
0 g
s
.6104 .76766 m .60919 .75021 L .64034 .75131 L p .707 .577 .707 r
F P
0 g
s
.61156 .30468 m .60707 .80944 L .63018 .80004 L p .707 .577 .707 r
F P
0 g
s
.63018 .80004 m .63467 .29528 L .61156 .30468 L p .707 .577 .707 r
F P
0 g
s
.70167 .77674 m .70287 .79419 L .69016 .78272 L p .707 .577 .707 r
F P
0 g
s
.69016 .78272 m .68896 .76526 L .70167 .77674 L p .707 .577 .707 r
F P
0 g
s
.19476 .722 m .19291 .66787 L .17183 .66022 L p .707 .577 .707 r
F P
0 g
s
.19291 .66787 m .19476 .722 L .22223 .72681 L p .707 .577 .707 r
F P
0 g
s
.25613 .79051 m .25319 .75622 L .22206 .75528 L p .707 .577 .707 r
F P
0 g
s
.25319 .75622 m .25613 .79051 L .28785 .78694 L p .707 .577 .707 r
F P
0 g
s
.28785 .78694 m .28491 .75265 L .25319 .75622 L p .707 .577 .707 r
F P
0 g
s
.28491 .75265 m .28785 .78694 L .31705 .7792 L p .707 .577 .707 r
F P
0 g
s
.31705 .7792 m .31411 .74491 L .28491 .75265 L p .707 .577 .707 r
F P
0 g
s
.68801 .7164 m .69094 .75069 L .66977 .74144 L p .707 .577 .707 r
F P
0 g
s
.66977 .74144 m .66684 .70715 L .68801 .7164 L p .707 .577 .707 r
F P
0 g
s
.33672 .65895 m .33857 .71308 L .3549 .7031 L p .707 .577 .707 r
F P
0 g
s
.3549 .7031 m .35304 .64897 L .33672 .65895 L p .707 .577 .707 r
F P
0 g
s
.225 .78958 m .22206 .75528 L .19456 .74993 L p .707 .577 .707 r
F P
0 g
s
.22206 .75528 m .225 .78958 L .25613 .79051 L p .707 .577 .707 r
F P
0 g
s
.3742 .80367 m .37869 .29891 L .36091 .2885 L p .707 .577 .707 r
F P
0 g
s
.37869 .29891 m .3742 .80367 L .40393 .81233 L p .707 .577 .707 r
F P
0 g
s
.66645 .64653 m .66831 .70065 L .64085 .69585 L p .707 .577 .707 r
F P
0 g
s
.64085 .69585 m .63899 .64172 L .66645 .64653 L p .707 .577 .707 r
F P
0 g
s
.31411 .74491 m .31705 .7792 L .34088 .76806 L p .707 .577 .707 r
F P
0 g
s
.34088 .76806 m .33794 .73377 L .31411 .74491 L p .707 .577 .707 r
F P
0 g
s
.25488 .81645 m .25367 .79899 L .22252 .79789 L p .707 .577 .707 r
F P
0 g
s
.25367 .79899 m .25488 .81645 L .28663 .81336 L p .707 .577 .707 r
F P
0 g
s
.28663 .81336 m .28543 .79591 L .25367 .79899 L p .707 .577 .707 r
F P
0 g
s
.28543 .79591 m .28663 .81336 L .3159 .80639 L p .707 .577 .707 r
F P
0 g
s
.3159 .80639 m .31469 .78894 L .28543 .79591 L p .707 .577 .707 r
F P
0 g
s
.17183 .66022 m .17369 .71435 L .19476 .722 L p .707 .577 .707 r
F P
0 g
s
.17369 .71435 m .17183 .66022 L .15921 .65047 L p .707 .577 .707 r
F P
0 g
s
.22373 .81534 m .22252 .79789 L .19504 .7927 L p .707 .577 .707 r
F P
0 g
s
.22252 .79789 m .22373 .81534 L .25488 .81645 L p .707 .577 .707 r
F P
0 g
s
.68896 .76526 m .69016 .78272 L .66903 .77396 L p .707 .577 .707 r
F P
0 g
s
.66903 .77396 m .66782 .7565 L .68896 .76526 L p .707 .577 .707 r
F P
0 g
s
.1975 .78422 m .19456 .74993 L .17339 .74068 L p .707 .577 .707 r
F P
0 g
s
.19456 .74993 m .1975 .78422 L .225 .78958 L p .707 .577 .707 r
F P
0 g
s
.31469 .78894 m .3159 .80639 L .3398 .79621 L p .707 .577 .707 r
F P
0 g
s
.3398 .79621 m .33859 .77876 L .31469 .78894 L p .707 .577 .707 r
F P
0 g
s
.66684 .70715 m .66977 .74144 L .64228 .73609 L p .707 .577 .707 r
F P
0 g
s
.64228 .73609 m .63934 .70179 L .66684 .70715 L p .707 .577 .707 r
F P
0 g
s
.19504 .7927 m .19624 .81015 L .22373 .81534 L p .707 .577 .707 r
F P
0 g
s
.33794 .73377 m .34088 .76806 L .357 .75461 L p .707 .577 .707 r
F P
0 g
s
.357 .75461 m .35406 .72031 L .33794 .73377 L p .707 .577 .707 r
F P
0 g
s
.63467 .29528 m .63018 .80004 L .64017 .78923 L p .707 .577 .707 r
F P
0 g
s
.64154 .76877 m .64034 .75131 L .66782 .7565 L p .707 .577 .707 r
F P
0 g
s
.64017 .78923 m .64466 .28447 L .63467 .29528 L p .707 .577 .707 r
F P
0 g
s
.35304 .64897 m .3549 .7031 L .36194 .69213 L p .707 .577 .707 r
F P
0 g
s
.36194 .69213 m .36008 .638 L .35304 .64897 L p .707 .577 .707 r
F P
0 g
s
.19624 .81015 m .19504 .7927 L .17391 .78394 L p .707 .577 .707 r
F P
0 g
s
.15921 .65047 m .16106 .7046 L .17369 .71435 L p .707 .577 .707 r
F P
0 g
s
.17339 .74068 m .17633 .77497 L .1975 .78422 L p .707 .577 .707 r
F P
0 g
s
.66782 .7565 m .66903 .77396 L .64154 .76877 L p .707 .577 .707 r
F P
0 g
s
.17391 .78394 m .17511 .80139 L .19624 .81015 L p .707 .577 .707 r
F P
0 g
s
.33859 .77876 m .3398 .79621 L .356 .78383 L p .707 .577 .707 r
F P
0 g
s
.356 .78383 m .35479 .76638 L .33859 .77876 L p .707 .577 .707 r
F P
0 g
s
.17633 .77497 m .17339 .74068 L .16062 .72843 L p .707 .577 .707 r
F P
0 g
s
.16106 .7046 m .15921 .65047 L .15627 .63958 L p .707 .577 .707 r
F P
0 g
s
.35406 .72031 m .357 .75461 L .36383 .74015 L p .707 .577 .707 r
F P
0 g
s
.36383 .74015 m .36089 .70586 L .35406 .72031 L p .707 .577 .707 r
F P
0 g
s
.359 .68124 m .35715 .62711 L .36008 .638 L p .707 .577 .707 r
F P
0 g
s
.35479 .76638 m .356 .78383 L .36291 .77045 L p .707 .577 .707 r
F P
0 g
s
.36291 .77045 m .36171 .75299 L .35479 .76638 L p .707 .577 .707 r
F P
0 g
s
.35715 .62711 m .359 .68124 L .34638 .67149 L p .707 .577 .707 r
F P
0 g
s
.34638 .67149 m .34452 .61736 L .35715 .62711 L p .707 .577 .707 r
F P
0 g
s
.35777 .69183 m .36008 .71877 L p .34793 .71388 L .707 .577 .707 r
F P
0 g
s
.36008 .71877 m .36071 .72612 L .35963 .72509 L p .707 .577 .707 r
F P
0 g
s
.35963 .72509 m .34793 .71388 L p .36008 .71877 L .707 .577 .707 r
F P
0 g
s
.34793 .71388 m .345 .67959 L .35777 .69183 L p .707 .577 .707 r
F P
0 g
s
.35866 .73992 m .35986 .75738 L .34715 .7459 L p .707 .577 .707 r
F P
0 g
s
.34715 .7459 m .34595 .72845 L .35866 .73992 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35681 .27734 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35642 .79326 m .35665 .76739 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35665 .76739 m .36091 .2885 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.36008 .638 m .36194 .69213 L .359 .68124 L p .707 .577 .707 r
F P
0 g
s
.36089 .70586 m .36383 .74015 L .36071 .72612 L p .707 .577 .707 r
F P
0 g
s
.36071 .72612 m .35777 .69183 L .36089 .70586 L p .707 .577 .707 r
F P
0 g
s
.36171 .75299 m .36291 .77045 L .35986 .75738 L p .707 .577 .707 r
F P
0 g
s
.35986 .75738 m .35866 .73992 L .36171 .75299 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35642 .79326 L .3742 .80367 L p .707 .577 .707 r
F P
0 g
s
.17511 .80139 m .17391 .78394 L .16119 .77246 L p .707 .577 .707 r
F P
0 g
s
.16062 .72843 m .16356 .76273 L .17633 .77497 L p .707 .577 .707 r
F P
0 g
s
.15627 .63958 m .15813 .69371 L .16106 .7046 L p .707 .577 .707 r
F P
0 g
s
.16119 .77246 m .1624 .78992 L .17511 .80139 L p .707 .577 .707 r
F P
0 g
s
.16356 .76273 m .16062 .72843 L .15749 .7144 L p .707 .577 .707 r
F P
0 g
s
.64466 .28447 m .64017 .78923 L .63608 .77807 L p .707 .577 .707 r
F P
0 g
s
.63608 .77807 m .64057 .27331 L .64466 .28447 L p .707 .577 .707 r
F P
0 g
s
.15813 .69371 m .15627 .63958 L .16331 .62861 L p .707 .577 .707 r
F P
0 g
s
.1624 .78992 m .16119 .77246 L .15815 .75939 L p .707 .577 .707 r
F P
0 g
s
.15749 .7144 m .16043 .74869 L .16356 .76273 L p .707 .577 .707 r
F P
0 g
s
.35681 .27734 m .35233 .7821 L .35642 .79326 L p .707 .577 .707 r
F P
0 g
s
.35233 .7821 m .35681 .27734 L .36681 .26653 L p .707 .577 .707 r
F P
0 g
s
.15815 .75939 m .15935 .77685 L .1624 .78992 L p .707 .577 .707 r
F P
0 g
s
.16331 .62861 m .16517 .68274 L .15813 .69371 L p .707 .577 .707 r
F P
0 g
s
.16043 .74869 m .15749 .7144 L .16433 .69995 L p .707 .577 .707 r
F P
0 g
s
.16517 .68274 m .16331 .62861 L .17964 .61864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15935 .77685 m .15815 .75939 L .16506 .74601 L p .707 .577 .707 r
F P
0 g
s
.64057 .27331 m .63608 .77807 L .6183 .76766 L p .707 .577 .707 r
F P
0 g
s
.6183 .76766 m .62279 .26289 L .64057 .27331 L p .707 .577 .707 r
F P
0 g
s
.16433 .69995 m .16726 .73424 L .16043 .74869 L p .707 .577 .707 r
F P
0 g
s
.34452 .61736 m .34638 .67149 L .3253 .66384 L p .707 .577 .707 r
F P
0 g
s
.3253 .66384 m .32345 .60971 L .34452 .61736 L p .707 .577 .707 r
F P
0 g
s
.16506 .74601 m .16627 .76347 L .15935 .77685 L p .707 .577 .707 r
F P
0 g
s
.17964 .61864 m .18149 .67277 L .16517 .68274 L p .707 .577 .707 r
F P
0 g
s
.16726 .73424 m .16433 .69995 L .18045 .6865 L p .707 .577 .707 r
F P
0 g
s
.18149 .67277 m .17964 .61864 L .20365 .61064 L p .707 .577 .707 r
F P
0 g
s
.36232 .77129 m .36681 .26653 L .38991 .25712 L p .707 .577 .707 r
F P
0 g
s
.36681 .26653 m .36232 .77129 L .35233 .7821 L p .707 .577 .707 r
F P
0 g
s
.345 .67959 m .34793 .71388 L .32676 .70463 L p .707 .577 .707 r
F P
0 g
s
.32676 .70463 m .32383 .67034 L .345 .67959 L p .707 .577 .707 r
F P
0 g
s
.32345 .60971 m .3253 .66384 L .29784 .65903 L p .707 .577 .707 r
F P
0 g
s
.29784 .65903 m .29598 .60491 L .32345 .60971 L p .707 .577 .707 r
F P
0 g
s
.16627 .76347 m .16506 .74601 L .18126 .73363 L p .707 .577 .707 r
F P
0 g
s
.18045 .6865 m .18338 .72079 L .16726 .73424 L p .707 .577 .707 r
F P
0 g
s
.20551 .66477 m .20365 .61064 L .233 .60539 L p .707 .577 .707 r
F P
0 g
s
.20365 .61064 m .20551 .66477 L .18149 .67277 L p .707 .577 .707 r
F P
0 g
s
.18126 .73363 m .18247 .75108 L .16627 .76347 L p .707 .577 .707 r
F P
0 g
s
.18338 .72079 m .18045 .6865 L .20427 .67535 L p .707 .577 .707 r
F P
0 g
s
.34595 .72845 m .34715 .7459 L .32602 .73714 L p .707 .577 .707 r
F P
0 g
s
.32602 .73714 m .32481 .71969 L .34595 .72845 L p .707 .577 .707 r
F P
0 g
s
.62279 .26289 m .6183 .76766 L .58857 .759 L p .707 .577 .707 r
F P
0 g
s
.58857 .759 m .59306 .25424 L .62279 .26289 L p .707 .577 .707 r
F P
0 g
s
.29598 .60491 m .29784 .65903 L .26667 .65755 L p .707 .577 .707 r
F P
0 g
s
.26667 .65755 m .26482 .60342 L .29598 .60491 L p .707 .577 .707 r
F P
0 g
s
.32383 .67034 m .32676 .70463 L .29927 .69927 L p .707 .577 .707 r
F P
0 g
s
.29927 .69927 m .29633 .66498 L .32383 .67034 L p .707 .577 .707 r
F P
0 g
s
.23486 .65952 m .233 .60539 L .26482 .60342 L p .707 .577 .707 r
F P
0 g
s
.233 .60539 m .23486 .65952 L .20551 .66477 L p .707 .577 .707 r
F P
0 g
s
.26482 .60342 m .26667 .65755 L .23486 .65952 L p .707 .577 .707 r
F P
0 g
s
.73361 .65748 m .73175 .60335 L .70059 .60187 L p .707 .577 .707 r
F P
0 g
s
.73175 .60335 m .73361 .65748 L .76542 .65551 L p .707 .577 .707 r
F P
0 g
s
.76542 .65551 m .76357 .60138 L .73175 .60335 L p .707 .577 .707 r
F P
0 g
s
.18247 .75108 m .18126 .73363 L .20516 .72345 L p .707 .577 .707 r
F P
0 g
s
.20427 .67535 m .20721 .70965 L .18338 .72079 L p .707 .577 .707 r
F P
0 g
s
.76357 .60138 m .76542 .65551 L .79477 .65026 L p .707 .577 .707 r
F P
0 g
s
.79477 .65026 m .79292 .59614 L .76357 .60138 L p .707 .577 .707 r
F P
0 g
s
.20721 .70965 m .20427 .67535 L .23348 .66762 L p .707 .577 .707 r
F P
0 g
s
.38991 .25712 m .38543 .76189 L .36232 .77129 L p .707 .577 .707 r
F P
0 g
s
.38543 .76189 m .38991 .25712 L .42387 .25005 L p .707 .577 .707 r
F P
0 g
s
.70244 .65599 m .70059 .60187 L .67312 .59706 L p .707 .577 .707 r
F P
0 g
s
.70059 .60187 m .70244 .65599 L .73361 .65748 L p .707 .577 .707 r
F P
0 g
s
.29633 .66498 m .29927 .69927 L .26813 .69833 L p .707 .577 .707 r
F P
0 g
s
.26813 .69833 m .2652 .66404 L .29633 .66498 L p .707 .577 .707 r
F P
0 g
s
.20516 .72345 m .20637 .7409 L .18247 .75108 L p .707 .577 .707 r
F P
0 g
s
.32481 .71969 m .32602 .73714 L .29853 .73195 L p .707 .577 .707 r
F P
0 g
s
.29853 .73195 m .29733 .7145 L .32481 .71969 L p .707 .577 .707 r
F P
0 g
s
.23641 .70191 m .23348 .66762 L .2652 .66404 L p .707 .577 .707 r
F P
0 g
s
.23348 .66762 m .23641 .70191 L .20721 .70965 L p .707 .577 .707 r
F P
0 g
s
.79292 .59614 m .79477 .65026 L .81879 .64226 L p .707 .577 .707 r
F P
0 g
s
.81879 .64226 m .81693 .58814 L .79292 .59614 L p .707 .577 .707 r
F P
0 g
s
.2652 .66404 m .26813 .69833 L .23641 .70191 L p .707 .577 .707 r
F P
0 g
s
.20637 .7409 m .20516 .72345 L .23442 .71648 L p .707 .577 .707 r
F P
0 g
s
.67498 .65119 m .67312 .59706 L .65205 .58941 L p .707 .577 .707 r
F P
0 g
s
.67312 .59706 m .67498 .65119 L .70244 .65599 L p .707 .577 .707 r
F P
0 g
s
.59306 .25424 m .58857 .759 L .54981 .75296 L p .707 .577 .707 r
F P
0 g
s
.54981 .75296 m .55429 .2482 L .59306 .25424 L p .707 .577 .707 r
F P
0 g
s
.29733 .7145 m .29853 .73195 L .26739 .73085 L p .707 .577 .707 r
F P
0 g
s
.26739 .73085 m .26618 .71339 L .29733 .7145 L p .707 .577 .707 r
F P
0 g
s
.23442 .71648 m .23563 .73393 L .20637 .7409 L p .707 .577 .707 r
F P
0 g
s
.23563 .73393 m .23442 .71648 L .26618 .71339 L p .707 .577 .707 r
F P
0 g
s
.73634 .73402 m .7334 .69973 L .70227 .69879 L p .707 .577 .707 r
F P
0 g
s
.7334 .69973 m .73634 .73402 L .76806 .73045 L p .707 .577 .707 r
F P
0 g
s
.76806 .73045 m .76512 .69615 L .7334 .69973 L p .707 .577 .707 r
F P
0 g
s
.26618 .71339 m .26739 .73085 L .23563 .73393 L p .707 .577 .707 r
F P
0 g
s
.76512 .69615 m .76806 .73045 L .79727 .72271 L p .707 .577 .707 r
F P
0 g
s
.79727 .72271 m .79433 .68842 L .76512 .69615 L p .707 .577 .707 r
F P
0 g
s
.41938 .75481 m .42387 .25005 L .46534 .24599 L p .707 .577 .707 r
F P
0 g
s
.42387 .25005 m .41938 .75481 L .38543 .76189 L p .707 .577 .707 r
F P
0 g
s
.81693 .58814 m .81879 .64226 L .83511 .63229 L p .707 .577 .707 r
F P
0 g
s
.83511 .63229 m .83326 .57816 L .81693 .58814 L p .707 .577 .707 r
F P
0 g
s
.70521 .73309 m .70227 .69879 L .67477 .69344 L p .707 .577 .707 r
F P
0 g
s
.70227 .69879 m .70521 .73309 L .73634 .73402 L p .707 .577 .707 r
F P
0 g
s
.65205 .58941 m .6539 .64354 L .67498 .65119 L p .707 .577 .707 r
F P
0 g
s
.79433 .68842 m .79727 .72271 L .82109 .71157 L p .707 .577 .707 r
F P
0 g
s
.82109 .71157 m .81815 .67728 L .79433 .68842 L p .707 .577 .707 r
F P
0 g
s
.55429 .2482 m .54981 .75296 L .5058 .75012 L p .707 .577 .707 r
F P
0 g
s
.5058 .75012 m .51029 .24536 L .55429 .2482 L p .707 .577 .707 r
F P
0 g
s
.6539 .64354 m .65205 .58941 L .63942 .57966 L p .707 .577 .707 r
F P
0 g
s
.46086 .75076 m .46534 .24599 L .51029 .24536 L p .707 .577 .707 r
F P
0 g
s
.46534 .24599 m .46086 .75076 L .41938 .75481 L p .707 .577 .707 r
F P
0 g
s
.73509 .78705 m .73388 .76959 L .70274 .76849 L p .707 .577 .707 r
F P
0 g
s
.73388 .76959 m .73509 .78705 L .76685 .78396 L p .707 .577 .707 r
F P
0 g
s
.76685 .78396 m .76564 .76651 L .73388 .76959 L p .707 .577 .707 r
F P
0 g
s
.67771 .72773 m .67477 .69344 L .6536 .68418 L p .707 .577 .707 r
F P
0 g
s
.67477 .69344 m .67771 .72773 L .70521 .73309 L p .707 .577 .707 r
F P
0 g
s
.76564 .76651 m .76685 .78396 L .79611 .77699 L p .707 .577 .707 r
F P
0 g
s
.79611 .77699 m .7949 .75954 L .76564 .76651 L p .707 .577 .707 r
F P
0 g
s
.51029 .24536 m .5058 .75012 L .46086 .75076 L p .707 .577 .707 r
F P
0 g
s
.70394 .78594 m .70274 .76849 L .67525 .7633 L p .707 .577 .707 r
F P
0 g
s
.70274 .76849 m .70394 .78594 L .73509 .78705 L p .707 .577 .707 r
F P
0 g
s
.83326 .57816 m .83511 .63229 L .84215 .62132 L p .707 .577 .707 r
F P
0 g
s
.84215 .62132 m .8403 .56719 L .83326 .57816 L p .707 .577 .707 r
F P
0 g
s
.81815 .67728 m .82109 .71157 L .83721 .69811 L p .707 .577 .707 r
F P
0 g
s
.83721 .69811 m .83427 .66382 L .81815 .67728 L p .707 .577 .707 r
F P
0 g
s
.7949 .75954 m .79611 .77699 L .82001 .76681 L p .707 .577 .707 r
F P
0 g
s
.82001 .76681 m .81881 .74936 L .7949 .75954 L p .707 .577 .707 r
F P
0 g
s
.63942 .57966 m .64128 .63379 L .6539 .64354 L p .707 .577 .707 r
F P
0 g
s
.67525 .7633 m .67646 .78075 L .70394 .78594 L p .707 .577 .707 r
F P
0 g
s
.6536 .68418 m .65654 .71848 L .67771 .72773 L p .707 .577 .707 r
F P
0 g
s
.64128 .63379 m .63942 .57966 L .63649 .56877 L p .707 .577 .707 r
F P
0 g
s
.67646 .78075 m .67525 .7633 L .65412 .75454 L p .707 .577 .707 r
F P
0 g
s
.65654 .71848 m .6536 .68418 L .64083 .67194 L p .707 .577 .707 r
F P
0 g
s
.65412 .75454 m .65533 .77199 L .67646 .78075 L p .707 .577 .707 r
F P
0 g
s
.81881 .74936 m .82001 .76681 L .83621 .75443 L p .707 .577 .707 r
F P
0 g
s
.83621 .75443 m .83501 .73697 L .81881 .74936 L p .707 .577 .707 r
F P
0 g
s
.83427 .66382 m .83721 .69811 L .84404 .68366 L p .707 .577 .707 r
F P
0 g
s
.84404 .68366 m .84111 .64937 L .83427 .66382 L p .707 .577 .707 r
F P
0 g
s
.8403 .56719 m .84215 .62132 L .83922 .61043 L p .707 .577 .707 r
F P
0 g
s
.83922 .61043 m .83736 .5563 L .8403 .56719 L p .707 .577 .707 r
F P
0 g
s
.63649 .56877 m .63834 .6229 L .64128 .63379 L p .707 .577 .707 r
F P
0 g
s
.64083 .67194 m .64377 .70624 L .65654 .71848 L p .707 .577 .707 r
F P
0 g
s
.65533 .77199 m .65412 .75454 L .64141 .74306 L p .707 .577 .707 r
F P
0 g
s
.64377 .70624 m .64083 .67194 L .63771 .65791 L p .707 .577 .707 r
F P
0 g
s
.63834 .6229 m .63649 .56877 L .64352 .5578 L p .707 .577 .707 r
F P
0 g
s
.64141 .74306 m .64261 .76052 L .65533 .77199 L p .707 .577 .707 r
F P
0 g
s
.83501 .73697 m .83621 .75443 L .84313 .74105 L p .707 .577 .707 r
F P
0 g
s
.84313 .74105 m .84192 .72359 L .83501 .73697 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84111 .64937 m .84404 .68366 L .84092 .66963 L p .707 .577 .707 r
F P
0 g
s
.84092 .66963 m .83798 .63534 L .84111 .64937 L p .707 .577 .707 r
F P
0 g
s
.83736 .5563 m .83922 .61043 L .82659 .60068 L p .707 .577 .707 r
F P
0 g
s
.82659 .60068 m .82474 .54655 L .83736 .5563 L p .707 .577 .707 r
F P
0 g
s
.63771 .65791 m .64065 .6922 L .64377 .70624 L p .707 .577 .707 r
F P
0 g
s
.64352 .5578 m .64538 .61193 L .63834 .6229 L p .707 .577 .707 r
F P
0 g
s
.64261 .76052 m .64141 .74306 L .63836 .72999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64065 .6922 m .63771 .65791 L .64454 .64346 L p .707 .577 .707 r
F P
0 g
s
.63836 .72999 m .63956 .74745 L .64261 .76052 L p .707 .577 .707 r
F P
0 g
s
.3906 .62067 m .38874 .56654 L .35758 .56505 L p .707 .577 .707 r
F P
0 g
s
.38874 .56654 m .3906 .62067 L .42241 .61869 L p .707 .577 .707 r
F P
0 g
s
.42241 .61869 m .42056 .56456 L .38874 .56654 L p .707 .577 .707 r
F P
0 g
s
.64538 .61193 m .64352 .5578 L .65985 .54783 L p .707 .577 .707 r
F P
0 g
s
.42056 .56456 m .42241 .61869 L .45176 .61345 L p .707 .577 .707 r
F P
0 g
s
.45176 .61345 m .44991 .55932 L .42056 .56456 L p .707 .577 .707 r
F P
0 g
s
.84192 .72359 m .84313 .74105 L .84008 .72798 L p .707 .577 .707 r
F P
0 g
s
.84008 .72798 m .83887 .71052 L .84192 .72359 L p .707 .577 .707 r
F P
0 g
s
.35943 .61918 m .35758 .56505 L .33011 .56025 L p .707 .577 .707 r
F P
0 g
s
.35758 .56505 m .35943 .61918 L .3906 .62067 L p .707 .577 .707 r
F P
0 g
s
.83798 .63534 m .84092 .66963 L .82815 .65739 L p .707 .577 .707 r
F P
0 g
s
.82815 .65739 m .82521 .6231 L .83798 .63534 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82474 .54655 m .82659 .60068 L .80552 .59303 L p .707 .577 .707 r
F P
0 g
s
.80552 .59303 m .80366 .5389 L .82474 .54655 L p .707 .577 .707 r
F P
0 g
s
.44991 .55932 m .45176 .61345 L .47578 .60545 L p .707 .577 .707 r
F P
0 g
s
.47578 .60545 m .47392 .55132 L .44991 .55932 L p .707 .577 .707 r
F P
0 g
s
.64454 .64346 m .64748 .67775 L .64065 .6922 L p .707 .577 .707 r
F P
0 g
s
.65985 .54783 m .66171 .60195 L .64538 .61193 L p .707 .577 .707 r
F P
0 g
s
.63956 .74745 m .63836 .72999 L .64527 .71661 L p .707 .577 .707 r
F P
0 g
s
.33197 .61437 m .33011 .56025 L .30904 .55259 L p .707 .577 .707 r
F P
0 g
s
.33011 .56025 m .33197 .61437 L .35943 .61918 L p .707 .577 .707 r
F P
0 g
s
.66171 .60195 m .65985 .54783 L .68386 .53983 L p .707 .577 .707 r
F P
0 g
s
.64748 .67775 m .64454 .64346 L .66066 .63 L p .707 .577 .707 r
F P
0 g
s
.64527 .71661 m .64648 .73406 L .63956 .74745 L p .707 .577 .707 r
F P
0 g
s
.39333 .69721 m .39039 .66291 L .35926 .66198 L p .707 .577 .707 r
F P
0 g
s
.39039 .66291 m .39333 .69721 L .42505 .69363 L p .707 .577 .707 r
F P
0 g
s
.42505 .69363 m .42211 .65934 L .39039 .66291 L p .707 .577 .707 r
F P
0 g
s
.42211 .65934 m .42505 .69363 L .45426 .68589 L p .707 .577 .707 r
F P
0 g
s
.45426 .68589 m .45132 .6516 L .42211 .65934 L p .707 .577 .707 r
F P
0 g
s
.83887 .71052 m .84008 .72798 L .82737 .7165 L p .707 .577 .707 r
F P
0 g
s
.82737 .7165 m .82616 .69905 L .83887 .71052 L p .707 .577 .707 r
F P
0 g
s
.47392 .55132 m .47578 .60545 L .4921 .59547 L p .707 .577 .707 r
F P
0 g
s
.4921 .59547 m .49025 .54135 L .47392 .55132 L p .707 .577 .707 r
F P
0 g
s
.82521 .6231 m .82815 .65739 L .80698 .64814 L p .707 .577 .707 r
F P
0 g
s
.80698 .64814 m .80404 .61384 L .82521 .6231 L p .707 .577 .707 r
F P
0 g
s
.80366 .5389 m .80552 .59303 L .77805 .58822 L p .707 .577 .707 r
F P
0 g
s
.77805 .58822 m .77619 .53409 L .80366 .5389 L p .707 .577 .707 r
F P
0 g
s
.3622 .69627 m .35926 .66198 L .33176 .65662 L p .707 .577 .707 r
F P
0 g
s
.35926 .66198 m .3622 .69627 L .39333 .69721 L p .707 .577 .707 r
F P
0 g
s
.30904 .55259 m .31089 .60672 L .33197 .61437 L p .707 .577 .707 r
F P
0 g
s
.45132 .6516 m .45426 .68589 L .47808 .67475 L p .707 .577 .707 r
F P
0 g
s
.47808 .67475 m .47514 .64046 L .45132 .6516 L p .707 .577 .707 r
F P
0 g
s
.66066 .63 m .6636 .6643 L .64748 .67775 L p .707 .577 .707 r
F P
0 g
s
.68572 .59395 m .68386 .53983 L .71321 .53458 L p .707 .577 .707 r
F P
0 g
s
.68386 .53983 m .68572 .59395 L .66171 .60195 L p .707 .577 .707 r
F P
0 g
s
.31089 .60672 m .30904 .55259 L .29641 .54284 L p .707 .577 .707 r
F P
0 g
s
.64648 .73406 m .64527 .71661 L .66148 .70422 L p .707 .577 .707 r
F P
0 g
s
.6636 .6643 m .66066 .63 L .68449 .61886 L p .707 .577 .707 r
F P
0 g
s
.39208 .75023 m .39087 .73278 L .35973 .73167 L p .707 .577 .707 r
F P
0 g
s
.39087 .73278 m .39208 .75023 L .42384 .74715 L p .707 .577 .707 r
F P
0 g
s
.42384 .74715 m .42263 .72969 L .39087 .73278 L p .707 .577 .707 r
F P
0 g
s
.77619 .53409 m .77805 .58822 L .74689 .58673 L p .707 .577 .707 r
F P
0 g
s
.74689 .58673 m .74503 .53261 L .77619 .53409 L p .707 .577 .707 r
F P
0 g
s
.3347 .69091 m .33176 .65662 L .31059 .64737 L p .707 .577 .707 r
F P
0 g
s
.33176 .65662 m .3347 .69091 L .3622 .69627 L p .707 .577 .707 r
F P
0 g
s
.42263 .72969 m .42384 .74715 L .4531 .74018 L p .707 .577 .707 r
F P
0 g
s
.4531 .74018 m .45189 .72272 L .42263 .72969 L p .707 .577 .707 r
F P
0 g
s
.71507 .58871 m .71321 .53458 L .74503 .53261 L p .707 .577 .707 r
F P
0 g
s
.71321 .53458 m .71507 .58871 L .68572 .59395 L p .707 .577 .707 r
F P
0 g
s
.66148 .70422 m .66268 .72168 L .64648 .73406 L p .707 .577 .707 r
F P
0 g
s
.80404 .61384 m .80698 .64814 L .77948 .64278 L p .707 .577 .707 r
F P
0 g
s
.77948 .64278 m .77654 .60849 L .80404 .61384 L p .707 .577 .707 r
F P
0 g
s
.36093 .74912 m .35973 .73167 L .33224 .72648 L p .707 .577 .707 r
F P
0 g
s
.35973 .73167 m .36093 .74912 L .39208 .75023 L p .707 .577 .707 r
F P
0 g
s
.49025 .54135 m .4921 .59547 L .49914 .58451 L p .707 .577 .707 r
F P
0 g
s
.49914 .58451 m .49729 .53038 L .49025 .54135 L p .707 .577 .707 r
F P
0 g
s
.74503 .53261 m .74689 .58673 L .71507 .58871 L p .707 .577 .707 r
F P
0 g
s
.82616 .69905 m .82737 .7165 L .80623 .70774 L p .707 .577 .707 r
F P
0 g
s
.80623 .70774 m .80503 .69029 L .82616 .69905 L p .707 .577 .707 r
F P
0 g
s
.47514 .64046 m .47808 .67475 L .4942 .6613 L p .707 .577 .707 r
F P
0 g
s
.4942 .6613 m .49126 .62701 L .47514 .64046 L p .707 .577 .707 r
F P
0 g
s
.45189 .72272 m .4531 .74018 L .477 .73 L p .707 .577 .707 r
F P
0 g
s
.477 .73 m .4758 .71254 L .45189 .72272 L p .707 .577 .707 r
F P
0 g
s
.29641 .54284 m .29827 .59697 L .31089 .60672 L p .707 .577 .707 r
F P
0 g
s
.33224 .72648 m .33345 .74394 L .36093 .74912 L p .707 .577 .707 r
F P
0 g
s
.68449 .61886 m .68742 .65315 L .6636 .6643 L p .707 .577 .707 r
F P
0 g
s
.68742 .65315 m .68449 .61886 L .71369 .61113 L p .707 .577 .707 r
F P
0 g
s
.31059 .64737 m .31353 .68166 L .3347 .69091 L p .707 .577 .707 r
F P
0 g
s
.29827 .59697 m .29641 .54284 L .29348 .53195 L p .707 .577 .707 r
F P
0 g
s
.66268 .72168 m .66148 .70422 L .68538 .69405 L p .707 .577 .707 r
F P
0 g
s
.77654 .60849 m .77948 .64278 L .74835 .64184 L p .707 .577 .707 r
F P
0 g
s
.74835 .64184 m .74541 .60755 L .77654 .60849 L p .707 .577 .707 r
F P
0 g
s
.33345 .74394 m .33224 .72648 L .31111 .71772 L p .707 .577 .707 r
F P
0 g
s
.31353 .68166 m .31059 .64737 L .29782 .63513 L p .707 .577 .707 r
F P
0 g
s
.71663 .64542 m .71369 .61113 L .74541 .60755 L p .707 .577 .707 r
F P
0 g
s
.71369 .61113 m .71663 .64542 L .68742 .65315 L p .707 .577 .707 r
F P
0 g
s
.74541 .60755 m .74835 .64184 L .71663 .64542 L p .707 .577 .707 r
F P
0 g
s
.68538 .69405 m .68658 .7115 L .66268 .72168 L p .707 .577 .707 r
F P
0 g
s
.80503 .69029 m .80623 .70774 L .77875 .70255 L p .707 .577 .707 r
F P
0 g
s
.77875 .70255 m .77754 .6851 L .80503 .69029 L p .707 .577 .707 r
F P
0 g
s
.31111 .71772 m .31231 .73518 L .33345 .74394 L p .707 .577 .707 r
F P
0 g
s
.4758 .71254 m .477 .73 L .4932 .71761 L p .707 .577 .707 r
F P
0 g
s
.4932 .71761 m .492 .70016 L .4758 .71254 L p .707 .577 .707 r
F P
0 g
s
.49126 .62701 m .4942 .6613 L .50103 .64685 L p .707 .577 .707 r
F P
0 g
s
.50103 .64685 m .4981 .61256 L .49126 .62701 L p .707 .577 .707 r
F P
0 g
s
.49729 .53038 m .49914 .58451 L .49621 .57361 L p .707 .577 .707 r
F P
0 g
s
.49621 .57361 m .49435 .51948 L .49729 .53038 L p .707 .577 .707 r
F P
0 g
s
.68658 .7115 m .68538 .69405 L .71464 .68708 L p .707 .577 .707 r
F P
0 g
s
.29348 .53195 m .29533 .58608 L .29827 .59697 L p .707 .577 .707 r
F P
0 g
s
.29782 .63513 m .30076 .66942 L .31353 .68166 L p .707 .577 .707 r
F P
0 g
s
.31231 .73518 m .31111 .71772 L .2984 .70625 L p .707 .577 .707 r
F P
0 g
s
.77754 .6851 m .77875 .70255 L .7476 .70145 L p .707 .577 .707 r
F P
0 g
s
.7476 .70145 m .7464 .68399 L .77754 .6851 L p .707 .577 .707 r
F P
0 g
s
.71464 .68708 m .71584 .70453 L .68658 .7115 L p .707 .577 .707 r
F P
0 g
s
.30076 .66942 m .29782 .63513 L .2947 .62109 L p .707 .577 .707 r
F P
0 g
s
.71584 .70453 m .71464 .68708 L .7464 .68399 L p .707 .577 .707 r
F P
0 g
s
.29533 .58608 m .29348 .53195 L .30051 .52098 L p .707 .577 .707 r
F P
0 g
s
.2984 .70625 m .2996 .7237 L .31231 .73518 L p .707 .577 .707 r
F P
0 g
s
.7464 .68399 m .7476 .70145 L .71584 .70453 L p .707 .577 .707 r
F P
0 g
s
.492 .70016 m .4932 .71761 L .50012 .70423 L p .707 .577 .707 r
F P
0 g
s
.50012 .70423 m .49891 .68678 L .492 .70016 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4981 .61256 m .50103 .64685 L .49791 .63281 L p .707 .577 .707 r
F P
0 g
s
.49791 .63281 m .49497 .59852 L .4981 .61256 L p .707 .577 .707 r
F P
0 g
s
.49435 .51948 m .49621 .57361 L .48358 .56386 L p .707 .577 .707 r
F P
0 g
s
.48358 .56386 m .48173 .50974 L .49435 .51948 L p .707 .577 .707 r
F P
0 g
s
.2947 .62109 m .29764 .65539 L .30076 .66942 L p .707 .577 .707 r
F P
0 g
s
.30051 .52098 m .30237 .57511 L .29533 .58608 L p .707 .577 .707 r
F P
0 g
s
.2996 .7237 m .2984 .70625 L .29535 .69318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29764 .65539 m .2947 .62109 L .30153 .60664 L p .707 .577 .707 r
F P
0 g
s
.29535 .69318 m .29655 .71063 L .2996 .7237 L p .707 .577 .707 r
F P
0 g
s
.30237 .57511 m .30051 .52098 L .31684 .51101 L p .707 .577 .707 r
F P
0 g
s
.49891 .68678 m .50012 .70423 L .49707 .69116 L p .707 .577 .707 r
F P
0 g
s
.49707 .69116 m .49586 .67371 L .49891 .68678 L p .707 .577 .707 r
F P
0 g
s
.49497 .59852 m .49791 .63281 L .48514 .62057 L p .707 .577 .707 r
F P
0 g
s
.48514 .62057 m .4822 .58628 L .49497 .59852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48173 .50974 m .48358 .56386 L .46251 .55621 L p .707 .577 .707 r
F P
0 g
s
.46251 .55621 m .46065 .50208 L .48173 .50974 L p .707 .577 .707 r
F P
0 g
s
.30153 .60664 m .30447 .64093 L .29764 .65539 L p .707 .577 .707 r
F P
0 g
s
.31684 .51101 m .3187 .56514 L .30237 .57511 L p .707 .577 .707 r
F P
0 g
s
.29655 .71063 m .29535 .69318 L .30226 .67979 L p .707 .577 .707 r
F P
0 g
s
.3187 .56514 m .31684 .51101 L .34085 .50301 L p .707 .577 .707 r
F P
0 g
s
.30447 .64093 m .30153 .60664 L .31765 .59319 L p .707 .577 .707 r
F P
0 g
s
.30226 .67979 m .30347 .69725 L .29655 .71063 L p .707 .577 .707 r
F P
0 g
s
.49586 .67371 m .49707 .69116 L .48436 .67968 L p .707 .577 .707 r
F P
0 g
s
.48436 .67968 m .48315 .66223 L .49586 .67371 L p .707 .577 .707 r
F P
0 g
s
.4822 .58628 m .48514 .62057 L .46397 .61132 L p .707 .577 .707 r
F P
0 g
s
.46397 .61132 m .46103 .57703 L .4822 .58628 L p .707 .577 .707 r
F P
0 g
s
.46065 .50208 m .46251 .55621 L .43504 .55141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55141 m .43318 .49728 L .46065 .50208 L p .707 .577 .707 r
F P
0 g
s
.31765 .59319 m .32059 .62748 L .30447 .64093 L p .707 .577 .707 r
F P
0 g
s
.34271 .55714 m .34085 .50301 L .3702 .49777 L p .707 .577 .707 r
F P
0 g
s
.34085 .50301 m .34271 .55714 L .3187 .56514 L p .707 .577 .707 r
F P
0 g
s
.30347 .69725 m .30226 .67979 L .31846 .66741 L p .707 .577 .707 r
F P
0 g
s
.32059 .62748 m .31765 .59319 L .34148 .58205 L p .707 .577 .707 r
F P
0 g
s
.43318 .49728 m .43504 .55141 L .40387 .54992 L p .707 .577 .707 r
F P
0 g
s
.40387 .54992 m .40202 .49579 L .43318 .49728 L p .707 .577 .707 r
F P
0 g
s
.37206 .55189 m .3702 .49777 L .40202 .49579 L p .707 .577 .707 r
F P
0 g
s
.3702 .49777 m .37206 .55189 L .34271 .55714 L p .707 .577 .707 r
F P
0 g
s
.31846 .66741 m .31967 .68486 L .30347 .69725 L p .707 .577 .707 r
F P
0 g
s
.46103 .57703 m .46397 .61132 L .43647 .60596 L p .707 .577 .707 r
F P
0 g
s
.43647 .60596 m .43353 .57167 L .46103 .57703 L p .707 .577 .707 r
F P
0 g
s
.40202 .49579 m .40387 .54992 L .37206 .55189 L p .707 .577 .707 r
F P
0 g
s
.48315 .66223 m .48436 .67968 L .46322 .67092 L p .707 .577 .707 r
F P
0 g
s
.46322 .67092 m .46202 .65347 L .48315 .66223 L p .707 .577 .707 r
F P
0 g
s
.34148 .58205 m .34441 .61634 L .32059 .62748 L p .707 .577 .707 r
F P
0 g
s
.34441 .61634 m .34148 .58205 L .37068 .57431 L p .707 .577 .707 r
F P
0 g
s
.31967 .68486 m .31846 .66741 L .34237 .65723 L p .707 .577 .707 r
F P
0 g
s
.43353 .57167 m .43647 .60596 L .40534 .60503 L p .707 .577 .707 r
F P
0 g
s
.40534 .60503 m .4024 .57073 L .43353 .57167 L p .707 .577 .707 r
F P
0 g
s
.37362 .6086 m .37068 .57431 L .4024 .57073 L p .707 .577 .707 r
F P
0 g
s
.37068 .57431 m .37362 .6086 L .34441 .61634 L p .707 .577 .707 r
F P
0 g
s
.4024 .57073 m .40534 .60503 L .37362 .6086 L p .707 .577 .707 r
F P
0 g
s
.34237 .65723 m .34357 .67469 L .31967 .68486 L p .707 .577 .707 r
F P
0 g
s
.46202 .65347 m .46322 .67092 L .43574 .66574 L p .707 .577 .707 r
F P
0 g
s
.43574 .66574 m .43453 .64828 L .46202 .65347 L p .707 .577 .707 r
F P
0 g
s
.34357 .67469 m .34237 .65723 L .37163 .65026 L p .707 .577 .707 r
F P
0 g
s
.43453 .64828 m .43574 .66574 L .40459 .66463 L p .707 .577 .707 r
F P
0 g
s
.40459 .66463 m .40339 .64718 L .43453 .64828 L p .707 .577 .707 r
F P
0 g
s
.37163 .65026 m .37283 .66771 L .34357 .67469 L p .707 .577 .707 r
F P
0 g
s
.37283 .66771 m .37163 .65026 L .40339 .64718 L p .707 .577 .707 r
F P
0 g
s
.40339 .64718 m .40459 .66463 L .37283 .66771 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0006FUH00`00FUIJEP03FUH9001mOol007Ioo`T000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool40007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool006Yoo`<00003FUH0
05YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00005`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0035YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001OOol40006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005aoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001HOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol0
0`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0067oo3`00?goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
47oo200015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01eYF100015YF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03
001JEP0000AJEP03001JEP0000@000=oo`04001JEUYF0005FUH00`00FUH000020005FUH00`00FUIJ
EP02FUH50004FUH300000eYF001JEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0000=JEP00FUH00UYF2@000eYF3`000eYF00<005YFFUH015YF00@005YF000000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF3`000UYF00<005YFFUH015YF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`001EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000^Ool005=oo`8000=JEP03001JEUYF009JEP03001JEUYF00@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001D
Ool01P00FUIJEUYF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH5000JOol50004FUH01@00
FUIJEUYF0000;Woo001DOol01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEUYFFUH2
000?Ool3000<Ool30003FUH300000eYF001JEP02FUH2000]Ool005Eoo`06001JEP00001JEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP05001JEP00001JEP04000;Ool50007Ool400000eYF001JEP05FUH30003FUH2
000]Ool004Moo`T000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF0P0000=JEP00FUH015YF
5`001EYF00<005YFFUH015YF00@005YFFUH0009JEP8002eoo`00?Woo2@0015YF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF4@000eYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP03
001JEUYF00AJEP04001JEUYFFUH4000]Ool003Qoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEPP000QJEP03001JEUYF00EJEP@000EJEP03001J
EUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH0
05YF00EJEP03001JEUYF009JEP<002eoo`00=Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH010001eYF00<005YFFUH01UYF00<005YF
FUH00UYF1@0000AJEP00000000=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH200000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH00UYF0`00;Goo000cOol2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJ
EP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP0200000eYF001J
EP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0000=JEP00FUH00eYF00<005YF0000;Goo000aOol30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH01000FUIJEUYF100000=oo`0000003P000eYF
00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;goo
0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00001EYF00@005YF0000009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8002ioo`00;Woo00<005YFFUH0
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0
00AJEP8000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP000000;Woo000]Ool20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0P001EYF
00@005YFFUH0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03001JEUYF00AJEP800004
FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01000FUH0
00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YF000002moo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00800003FUH005YF00AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH60004FUH00`00FUIJEP09FUH00`00FUIJEP03FUH01000FUH005YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00UJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00000P00
1EYF00<005YFFUH02EYF00<005YFFUH00P000eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP<00003FUH005YF009J
EP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03
001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03
001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF0P000UYF00<005YFFUH00eYF00H005YF001JEP00FUHG0003
FUH20003FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YF
FUH015YF1`0015YF00<005YFFUH00P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<000EJEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00FUIJEP02FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF
00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH010001goo0`0000AJ
EP00FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0015YF0P000UYF00<005YFFUH00UYF1`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`0000=JEP00FUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00@005YFFUIJEQ`000ioo`8000=JEP03001o
ogoo02]oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1P000UYF
00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEP000003FUH3000VOol01000FUIJEP00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006Ool90004Ool20002FUH01000FUIJEUYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH20005FUH00`00FUIJEP02000UOol00`00FUH0000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP@000Aoo`H000AJEP03001JEUYF009JEPH000=JEP<000EJEP03001J
EUYF00AJEQL000AJEP03001JEUYF00=JEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP06001JEUYF001JEP001EYF00D005YFFUIJEP0000Uoo`<0
01Qoo`@002eoo`00;7oo00<005YF000015YF00<005YF00001P000goo0P0000=JEP00FUH01eYF00<0
05YFFUH01UYF0P000eYF0P001UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`D001Eoo`80
0004FUH005YF000]Ool002aoo`03001JEP0000AJEP800003FUH005YF00AJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00AJEP@0009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03
FUH01@00FUIJEUYF000027oo1@0057oo00L005YFFUIJEP00FUH0000]Ool002aoo`03001JEP00009J
EP8000=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP04
001JEUYFFUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
0`0000EJEP00FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF00=JEP03001JEUYF00=JEP05001JEUYFFUH00008Ool5000BOol20004
FUH00`00FUH0000]Ool002aoo`03001JEP00008000EJEP<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP06001JEP00001JEP001UYF00<005YFFUH01EYF10001UYF00<005YF
FUH01UYF00@005YFFUH000=JEP80009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP03FUH01@00FUIJEUYF00002Goo0`004Goo0P0000=J
EP00FUH00eYF00<005YF0000;Goo000/Ool01@00FUH005YF000015YF0P000eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH01UYF0`001UYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH400000eYF001JEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF000027oo
3`0017oo0P000eYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH300000eYF001JEP06FUH300000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH300000eYF001J
EP04FUH01P00FUIJEUYF001oo`L000AJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
009JEP8002ioo`00;7oo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0003FUH00`00FUH000020005FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP040004FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30002FUH00`00FUIJEP020005FUH00`00FUH000030002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH2000^Ool002aoo`80009JEP80
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
00AJEP03001JEUYF009JEP@00003FUH005YF00MJEP<0009JEPL000QJEP03001JEUYF00IJEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
009JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000AJ
EP03001oogoo02eoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF30000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF00003`000eYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YF00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH70009FUH01P00FUH005YF001JEP@00003FUH005YF00AJEP05001JEP00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH3000`Ool002eoo`8000EJEP03001J
EUYF00=JEP03001JEUYF00@000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP04001JEP000005
FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000UYF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YF000000EJ
EP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00031o
o`00;Goo0P001EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000=JEP05001JEP00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP02FUH200001UYF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH30006FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH50004FUH00`00FUH0000_Ool002aoo`03001JEP0000EJEP04001JEUYFFUH20005
FUH00`00FUIJEP05FUH900001eYF001JEUYF001JEP00009JEP03001JEUYF00=JEP800006FUH005YF
001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0015YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0002ioo`00;7oo00<005YF00001EYF00@005YF000000MJEP03001JEP0000D000AJEP03
001JEUYF009JEPH00004FUH005YF0003FUH20002Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF0`0000=JEP00FUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH4
0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo0P000UYF00<007ooOol0;7oo000/Ool01000
FUIJEP0015YF0P0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF0P000UYF1@00
1Woo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF0P000eYF00<005YFFUH00UYF
00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001J
EP00008000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04001JEP000006Ool01000FUH0
0000;Goo000/Ool01000FUIJEP000eYF00<007ooOol01`001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000UYF00<005YF0000100017oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
15YF0`0027oo00@005YF000002eoo`00;7oo00D005YFFUH005YF008000Aoo`800003FUH005YF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH400001Woo001JEP00FUH000IJ
EP03001JEUYF00MJEP04001JEUYFFUH400000eYF001JEP05FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEUYF0P000UYF10001UYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH0100037oo0`00;Goo000/Ool00`00FUIJEP020004Ool20003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80004FUH01@00FUH005YF00001EYF00<005YF00001000
00=JEP00FUH01EYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH7000AOol2000]Ool002eoo`03001JEP0000=oo`8000EJ
EP03001JEUYF00AJEPL000Qoo`T000EJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP04001J
EUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP0@000GOol3000]Ool002eoo`@00003Ool0
000000IJEP03001JEUYF00@001Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH01000FUIJEP009Goo00<005YF0000;Goo
000]Ool200001EYF000005YF00001EYF10007Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF1@001EYF00<005YFFUH00P008goo0P0000=JEP00
Ool0;7oo000]Ool00`00FUH00003FUH01000FUIJEUYF0P007goo0`000UYF0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF0P000eYF00<005YF
FUH00P008Goo0P0000=JEP000000;Woo000]Ool20004FUH01000FUH000007Woo0`0000=JEP00FUH0
1EYF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF0P00
00=JEP00FUH00UYF00<007ooOol07Woo00@005YFFUIJEP8002ioo`00;Goo0P0015YF0P0000=JEP00
00000`005goo0`0015YF00<005YFFUH015YF00<005YFFUH04@000eYF00<005YFFUH015YF60001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUH000EJEP800003Ool0
000000=JEP03001oogoo01aoo`8000AJEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH00UYF
00@005YFFUIJEPP000Uoo`H000MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
1`001Goo00@005YFFUH001Yoo`@00003FUH005YF00=JEP03001oogoo02eoo`00;7oo00H005YFFUH0
05YF0005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH30002FUH60007Ool3000GOol30005FUH01@00FUIJ
EUYF0000<7oo000/Ool00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP04
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20004FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02000015YF000000000goo0P00
00=JEP00Ool04Woo100000=JEP00FUH01UYF00<005YF0000<Goo000/Ool01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000Woo00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF10000UYF00@005YF
FUIJEPL00004FUH005YF000<Ool70005FUH00`00FUIJEP05FUH2000bOol002eoo`800004Ool005YF
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00Oomoo`0200000eYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF1`0015YF00@005YFFUIJ
EQ8000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000Woo0P001EYF00<005YF
FUH015YF00<005YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP80009oo`04001JEP00
FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000Woo0`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000]Ool20003
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUH00000
0goo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10001Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000]Ool01000FUH0
00000goo0`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF10000goo0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001Woo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000?Goo000]Ool20002FUH00`00Oomoo`03Ool30005
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040005Ool200000eYF001JEP02FUH20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003Ool30003FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70011Ool002ioo`03001JEUYF00<000Ioo`@00003FUH005YF00MJEP<0009JEPL000Moo`8000=J
EP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001J
EP05FUH00`00FUIJEP0A0018Ool002ioo`04001JEUYF0002FUH20008Ool?000;Ool30005FUH01P00
FUH00000Ool000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00EJ
EP04001JEUYFFUH3001DOol002moo`03001JEP0000AJEPD001Uoo`@00003FUH005YF00EJEP8000=o
o`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP04001J
EUYFFUH3001DOol0031oo`8000EJEP04001JEUYFFUH90009Ool70005FUH00`00FUIJEP03FUH20005
Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP05FUH01@00FUIJEP00
Ool00P00E7oo000aOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH01EYF
0`0000Aoo`00000005Aoo`00<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH00`00FUIJEP04
FUH01`00Oomoogoo001JEP0005Aoo`00=7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009oo`<00003FUH007oo05=oo`00=Woo1@0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH0100067oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF10001EYF00<005YFFUH01EYF00<005YFFUH00P000Woo0P000UYF0P00EGoo000k
Ool90004FUH00`00FUIJEP02FUH7000QOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP090005FUH00`00FUIJEP05FUH30002Ool20004FUH2001EOol004Aoo`T0
02ioo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPP000AJEPD000EJEP03001JEUYF00AJEP80
009oo`800003FUH005YF00=JEP03001oogoo05Aoo`00Q7oo6@0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH010000Woo0P000eYF00<005YFFUH00UYF00<007ooOol0E7oo002?Ool01@00FUIJEP00
FUH00`001Woo2@0015YF0`000UYF1`000goo0`001UYF00@005YFFUH005Moo`00Sgoo00@005YFFUH0
00AJEP<000aoo`T000Ioo`@00003FUH005YF00IJEP<005Qoo`00T7oo00@005YFFUH000AJEP03001J
EP0000<0011oo`L000EJEP03001JEUYF00AJEP8005Yoo`00TGoo0`0015YF00<005YFFUH00eYF4000
15YF00<005YFFUH01UYF00@005YFFUIJEP8005aoo`00Tgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005ioo`00UGoo0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000H7oo002HOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001TOol009]oo`@0009JEP03001JEUYF00EJEP03
001JEUYF009JEPL006Qoo`00Wgoo3`00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59671 .77454 m .59371 .72151 L .56256 .72028 L p .707 .577 .707 r
F P
0 g
s
.59371 .72151 m .59671 .77454 L .62849 .77184 L p .707 .577 .707 r
F P
0 g
s
.62849 .77184 m .62549 .71882 L .59371 .72151 L p .707 .577 .707 r
F P
0 g
s
.62549 .71882 m .62849 .77184 L .65779 .76547 L p .707 .577 .707 r
F P
0 g
s
.65779 .76547 m .65479 .71245 L .62549 .71882 L p .707 .577 .707 r
F P
0 g
s
.56555 .7733 m .56256 .72028 L .53508 .71522 L p .707 .577 .707 r
F P
0 g
s
.56256 .72028 m .56555 .7733 L .59671 .77454 L p .707 .577 .707 r
F P
0 g
s
.65479 .71245 m .65779 .76547 L .68174 .75605 L p .707 .577 .707 r
F P
0 g
s
.68174 .75605 m .67874 .70303 L .65479 .71245 L p .707 .577 .707 r
F P
0 g
s
.53808 .76825 m .53508 .71522 L .51397 .70685 L p .707 .577 .707 r
F P
0 g
s
.53508 .71522 m .53808 .76825 L .56555 .7733 L p .707 .577 .707 r
F P
0 g
s
.63111 .84914 m .62917 .8326 L .59754 .83703 L p .707 .577 .707 r
F P
0 g
s
.60173 .83688 m .59703 .80504 L .56596 .80466 L p .707 .577 .707 r
F P
0 g
s
.66018 .84007 m .65824 .82353 L .62917 .8326 L p .707 .577 .707 r
F P
0 g
s
.59703 .80504 m .60173 .83688 L .63327 .83171 L p .707 .577 .707 r
F P
0 g
s
.63327 .83171 m .62857 .79987 L .59703 .80504 L p .707 .577 .707 r
F P
0 g
s
.67874 .70303 m .68174 .75605 L .69799 .74451 L p .707 .577 .707 r
F P
0 g
s
.69799 .74451 m .69499 .69148 L .67874 .70303 L p .707 .577 .707 r
F P
0 g
s
.68383 .82725 m .6819 .81072 L .65824 .82353 L p .707 .577 .707 r
F P
0 g
s
.62857 .79987 m .63327 .83171 L .66218 .82148 L p .707 .577 .707 r
F P
0 g
s
.66218 .82148 m .65748 .78964 L .62857 .79987 L p .707 .577 .707 r
F P
0 g
s
.59947 .85356 m .59754 .83703 L .56644 .83638 L p .707 .577 .707 r
F P
0 g
s
.57066 .8365 m .56596 .80466 L .5384 .79875 L p .707 .577 .707 r
F P
0 g
s
.56596 .80466 m .57066 .8365 L .60173 .83688 L p .707 .577 .707 r
F P
0 g
s
.69977 .81194 m .69783 .79541 L .6819 .81072 L p .707 .577 .707 r
F P
0 g
s
.65748 .78964 m .66218 .82148 L .68565 .8072 L p .707 .577 .707 r
F P
0 g
s
.68565 .8072 m .68095 .77536 L .65748 .78964 L p .707 .577 .707 r
F P
0 g
s
.59754 .83703 m .59947 .85356 L .63111 .84914 L p .707 .577 .707 r
F P
0 g
s
.62917 .8326 m .63111 .84914 L .66018 .84007 L p .707 .577 .707 r
F P
0 g
s
.51697 .75987 m .51397 .70685 L .5013 .69597 L p .707 .577 .707 r
F P
0 g
s
.51397 .70685 m .51697 .75987 L .53808 .76825 L p .707 .577 .707 r
F P
0 g
s
.56837 .85292 m .56644 .83638 L .53891 .83073 L p .707 .577 .707 r
F P
0 g
s
.56644 .83638 m .56837 .85292 L .59947 .85356 L p .707 .577 .707 r
F P
0 g
s
.65824 .82353 m .66018 .84007 L .68383 .82725 L p .707 .577 .707 r
F P
0 g
s
.5431 .83059 m .5384 .79875 L .51705 .7879 L p .707 .577 .707 r
F P
0 g
s
.5384 .79875 m .5431 .83059 L .57066 .8365 L p .707 .577 .707 r
F P
0 g
s
.69499 .69148 m .69799 .74451 L .70496 .73197 L p .707 .577 .707 r
F P
0 g
s
.70496 .73197 m .70196 .67894 L .69499 .69148 L p .707 .577 .707 r
F P
0 g
s
.69889 .79293 m .70136 .79027 L p .69826 .78801 L .707 .577 .707 r
F P
0 g
s
.70136 .79027 m .69666 .75843 L .68095 .77536 L p .707 .577 .707 r
F P
0 g
s
.69666 .75843 m .70136 .79027 L .70779 .77234 L p .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .70448 .7791 L .69888 .79284 L p .707 .577 .707 r
F P
0 g
s
.69888 .79284 m .69783 .79541 L p .69921 .79544 L .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .69888 .79284 L .69921 .79544 L .707 .577 .707 r
F
.68095 .77536 m .68565 .8072 L .69889 .79293 L p F P
0 g
s
.69826 .78801 m .68095 .77536 L .69889 .79293 L .707 .577 .707 r
F
.53891 .83073 m .54084 .84727 L .56837 .85292 L p F P
0 g
s
.54084 .84727 m .53891 .83073 L .51765 .82063 L p .707 .577 .707 r
F P
0 g
s
.5013 .69597 m .50429 .749 L .51697 .75987 L p .707 .577 .707 r
F P
0 g
s
.6819 .81072 m .68383 .82725 L .69977 .81194 L p .707 .577 .707 r
F P
0 g
s
.50429 .749 m .5013 .69597 L .4983 .68366 L p .707 .577 .707 r
F P
0 g
s
.51765 .82063 m .51959 .83717 L .54084 .84727 L p .707 .577 .707 r
F P
0 g
s
.51705 .7879 m .52174 .81974 L .5431 .83059 L p .707 .577 .707 r
F P
0 g
s
.52174 .81974 m .51705 .7879 L .50399 .77317 L p .707 .577 .707 r
F P
0 g
s
.70779 .77234 m .70309 .7405 L .69666 .75843 L p .707 .577 .707 r
F P
0 g
s
.70196 .67894 m .70496 .73197 L .70196 .71966 L p .707 .577 .707 r
F P
0 g
s
.70196 .71966 m .69896 .66663 L .70196 .67894 L p .707 .577 .707 r
F P
0 g
s
.51959 .83717 m .51765 .82063 L .50475 .80706 L p .707 .577 .707 r
F P
0 g
s
.69783 .79541 m .69977 .81194 L .70641 .79563 L p .707 .577 .707 r
F P
0 g
s
.4983 .68366 m .50129 .73669 L .50429 .749 L p .707 .577 .707 r
F P
0 g
s
.50475 .80706 m .50668 .8236 L .51959 .83717 L p .707 .577 .707 r
F P
0 g
s
.50399 .77317 m .50869 .80501 L .52174 .81974 L p .707 .577 .707 r
F P
0 g
s
.50869 .80501 m .50399 .77317 L .5005 .75599 L p .707 .578 .707 r
F P
0 g
s
.50129 .73669 m .4983 .68366 L .50526 .67112 L p .707 .577 .707 r
F P
0 g
s
.48441 .82075 m .49167 .31434 L .44766 .3114 L p .707 .577 .707 r
F P
0 g
s
.50668 .8236 m .50475 .80706 L .50145 .79135 L p .707 .577 .707 r
F P
0 g
s
.50145 .79135 m .50339 .80789 L .50668 .8236 L p .707 .577 .707 r
F P
0 g
s
.5005 .75599 m .5052 .78783 L .50869 .80501 L p .707 .578 .707 r
F P
0 g
s
.50526 .67112 m .50826 .72415 L .50129 .73669 L p .707 .577 .707 r
F P
0 g
s
.5052 .78783 m .5005 .75599 L .50693 .73806 L p .707 .577 .707 r
F P
0 g
s
.50826 .72415 m .50526 .67112 L .52152 .65958 L p .707 .577 .707 r
F P
0 g
s
.51061 .77263 m .52403 .75973 L p .51245 .78608 L .707 .577 .707 r
F P
0 g
s
.50693 .73806 m .51163 .7699 L .51062 .77273 L p .707 .577 .707 r
F P
0 g
s
.51062 .77273 m .5052 .78783 L p .50672 .74428 L .707 .577 .707 r
F P
0 g
s
.50672 .74428 m .50693 .73806 L .51062 .77273 L .707 .577 .707 r
F
.51003 .79158 m .5081 .77504 L .51061 .77263 L p F P
0 g
s
.51003 .79158 m .51061 .77263 L .51245 .78608 L .707 .577 .707 r
F
.50339 .80789 m .50145 .79135 L .5081 .77504 L p F P
0 g
s
.5081 .77504 m .51003 .79158 L .50339 .80789 L p .707 .577 .707 r
F P
0 g
s
.52152 .65958 m .52451 .7126 L .50826 .72415 L p .707 .577 .707 r
F P
0 g
s
.51163 .7699 m .50693 .73806 L .52265 .72113 L p .707 .577 .707 r
F P
0 g
s
.52265 .72113 m .52735 .75297 L .51163 .7699 L p .707 .577 .707 r
F P
0 g
s
.52403 .75973 m .52596 .77627 L .51003 .79158 L p .707 .577 .707 r
F P
0 g
s
.52596 .77627 m .52403 .75973 L .54769 .74691 L p .707 .577 .707 r
F P
0 g
s
.54769 .74691 m .54962 .76345 L .52596 .77627 L p .707 .577 .707 r
F P
0 g
s
.49167 .31434 m .48441 .82075 L .52934 .82039 L p .707 .577 .707 r
F P
0 g
s
.52451 .7126 m .52152 .65958 L .54547 .65016 L p .707 .577 .707 r
F P
0 g
s
.54547 .65016 m .54846 .70318 L .52451 .7126 L p .707 .577 .707 r
F P
0 g
s
.52735 .75297 m .52265 .72113 L .54611 .70685 L p .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .5499 .73253 L p .52735 .75297 L .707 .577 .707 r
F P
0 g
s
.5499 .73253 m .55081 .73869 L .54749 .74071 L p .707 .577 .707 r
F P
0 g
s
.54749 .74071 m .52735 .75297 L p .5499 .73253 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .49167 .31434 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52934 .82039 m .52962 .80129 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52962 .80129 m .5366 .31399 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.70309 .7405 m .70779 .77234 L .70431 .75517 L p .707 .578 .707 r
F P
0 g
s
.70431 .75517 m .69961 .72332 L .70309 .7405 L p .707 .578 .707 r
F P
0 g
s
.54547 .65016 m .57477 .64379 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.54846 .70318 m .5483 .70023 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.5483 .70023 m .54547 .65016 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.57503 .69662 m .57987 .69583 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.57944 .72655 m .57503 .69662 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .57503 .69662 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.55081 .73869 m .54802 .71975 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.54802 .71975 m .54611 .70685 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .60337 .78419 L .57148 .7705 L .707 .577 .707 r
F
.57503 .69662 m .57973 .72846 L .55081 .73869 L p F P
0 g
s
.57477 .64379 m .57776 .69681 L .56055 .70056 L p .707 .577 .707 r
F P
0 g
s
.55376 .69122 m .57477 .64379 L .56055 .70056 L .707 .577 .707 r
F
.57973 .72846 m .57944 .72655 L p .57973 .72694 L F P
0 g
s
.57987 .69583 m .60656 .69145 L p .58561 .72035 L .707 .577 .707 r
F P
0 g
s
.57973 .72846 m .57987 .69583 L .58561 .72035 L .707 .577 .707 r
F
.59578 .642 m .60655 .64109 L p .59674 .66007 L F P
0 g
s
.57776 .69681 m .59578 .642 L .59674 .66007 L .707 .577 .707 r
F
.57776 .69681 m .57477 .64379 L .59578 .642 L p F P
0 g
s
.60656 .69145 m .63763 .69183 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.61115 .72255 m .60656 .69145 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.60656 .69145 m .61126 .72329 L .57973 .72846 L p .707 .577 .707 r
F P
0 g
s
.60655 .64109 m .60955 .69412 L .58998 .69578 L p .707 .577 .707 r
F P
0 g
s
.58998 .69578 m .57776 .69681 L p .58291 .68684 L .707 .577 .707 r
F P
0 g
s
.58291 .68684 m .60655 .64109 L .58998 .69578 L .707 .577 .707 r
F
.61126 .72329 m .61115 .72255 L p .61151 .723 L F P
0 g
s
.54962 .76345 m .54769 .74691 L .57676 .73785 L p .707 .577 .707 r
F P
0 g
s
.57676 .73785 m .57869 .75439 L .54962 .76345 L p .707 .577 .707 r
F P
0 g
s
.57869 .75439 m .57676 .73785 L .60839 .73342 L p .707 .577 .707 r
F P
0 g
s
.60839 .73342 m .61032 .74996 L .57869 .75439 L p .707 .577 .707 r
F P
0 g
s
.57808 .31038 m .57181 .74745 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.57181 .74745 m .57148 .7705 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.56055 .70056 m .54846 .70318 L p .55376 .69122 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .66519 .69774 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.64228 .72334 m .63763 .69183 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .64233 .72367 L .61126 .72329 L p .707 .577 .707 r
F P
0 g
s
.6377 .64233 m .6407 .69535 L .62217 .69462 L p .707 .577 .707 r
F P
0 g
s
.62217 .69462 m .60955 .69412 L p .61491 .68426 L .707 .577 .707 r
F P
0 g
s
.61491 .68426 m .6377 .64233 L .62217 .69462 L .707 .577 .707 r
F
.64233 .72367 m .64228 .72334 L p .64244 .72356 L F P
0 g
s
.60955 .69412 m .60655 .64109 L .6377 .64233 L p .707 .577 .707 r
F P
0 g
s
.63949 .73406 m .64143 .7506 L .61032 .74996 L p .707 .577 .707 r
F P
0 g
s
.61032 .74996 m .60839 .73342 L .63949 .73406 L p .707 .577 .707 r
F P
0 g
s
.61202 .30386 m .60487 .80261 L p .62786 .80149 L .707 .577 .707 r
F P
0 g
s
.60487 .80261 m .60476 .81027 L .60651 .8096 L p .707 .577 .707 r
F P
0 g
s
.60651 .8096 m .62786 .80149 L p .60487 .80261 L .707 .577 .707 r
F P
0 g
s
.57148 .7705 m .57082 .81678 L .5858 .81391 L p .707 .577 .707 r
F P
0 g
s
.5858 .81391 m .60476 .81027 L p .57148 .7705 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .52934 .82039 L .57082 .81678 L p .707 .577 .707 r
F P
0 g
s
.57082 .81678 m .57808 .31038 L .5366 .31399 L p .707 .577 .707 r
F P
0 g
s
.4404 .81781 m .44766 .3114 L .40889 .30546 L p .707 .577 .707 r
F P
0 g
s
.44766 .3114 m .4404 .81781 L .48441 .82075 L p .707 .577 .707 r
F P
0 g
s
.69896 .66663 m .70196 .71966 L .68928 .70878 L p .707 .577 .707 r
F P
0 g
s
.68928 .70878 m .68629 .65576 L .69896 .66663 L p .707 .577 .707 r
F P
0 g
s
.70448 .7791 m .70641 .79563 L .70312 .77993 L p .707 .577 .707 r
F P
0 g
s
.70312 .77993 m .70118 .76339 L .70448 .7791 L p .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .61202 .30386 L .57808 .31038 L p .707 .577 .707 r
F P
0 g
s
.2537 .73772 m .2507 .6847 L .21955 .68346 L p .707 .577 .707 r
F P
0 g
s
.2507 .6847 m .2537 .73772 L .28548 .73503 L p .707 .577 .707 r
F P
0 g
s
.28548 .73503 m .28248 .682 L .2507 .6847 L p .707 .577 .707 r
F P
0 g
s
.69961 .72332 m .70431 .75517 L .69125 .74043 L p .707 .577 .707 r
F P
0 g
s
.69125 .74043 m .68655 .70859 L .69961 .72332 L p .707 .577 .707 r
F P
0 g
s
.40163 .81186 m .40889 .30546 L .37916 .29709 L p .707 .577 .707 r
F P
0 g
s
.40889 .30546 m .40163 .81186 L .4404 .81781 L p .707 .577 .707 r
F P
0 g
s
.28248 .682 m .28548 .73503 L .31478 .72866 L p .707 .577 .707 r
F P
0 g
s
.31478 .72866 m .31178 .67563 L .28248 .682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22254 .73649 m .21955 .68346 L .19207 .67841 L p .707 .577 .707 r
F P
0 g
s
.21955 .68346 m .22254 .73649 L .2537 .73772 L p .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .68655 .70859 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66989 .72958 m .66978 .72884 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66978 .72884 m .66519 .69774 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .66989 .72958 L .64233 .72367 L p .707 .577 .707 r
F P
0 g
s
.66518 .64738 m .66818 .70041 L .65346 .6977 L p .707 .577 .707 r
F P
0 g
s
.65346 .6977 m .6407 .69535 L p .64639 .68421 L .707 .577 .707 r
F P
0 g
s
.64639 .68421 m .66518 .64738 L .65346 .6977 L .707 .577 .707 r
F
.68629 .65576 m .68928 .70878 L .66818 .70041 L p F P
0 g
s
.66818 .70041 m .66518 .64738 L .68629 .65576 L p .707 .577 .707 r
F P
0 g
s
.31178 .67563 m .31478 .72866 L .33873 .71924 L p .707 .577 .707 r
F P
0 g
s
.33873 .71924 m .33573 .66621 L .31178 .67563 L p .707 .577 .707 r
F P
0 g
s
.70118 .76339 m .70312 .77993 L .69021 .76636 L p .707 .577 .707 r
F P
0 g
s
.69021 .76636 m .68828 .74982 L .70118 .76339 L p .707 .577 .707 r
F P
0 g
s
.62786 .80149 m .63512 .29508 L .61202 .30386 L p .707 .577 .707 r
F P
0 g
s
.19507 .73143 m .19207 .67841 L .17096 .67003 L p .707 .577 .707 r
F P
0 g
s
.19207 .67841 m .19507 .73143 L .22254 .73649 L p .707 .577 .707 r
F P
0 g
s
.68655 .70859 m .69125 .74043 L .66989 .72958 L p .707 .577 .707 r
F P
0 g
s
.2881 .81232 m .28616 .79578 L .25453 .80021 L p .707 .577 .707 r
F P
0 g
s
.25872 .80007 m .25402 .76823 L .22295 .76784 L p .707 .577 .707 r
F P
0 g
s
.31717 .80325 m .31523 .78672 L .28616 .79578 L p .707 .577 .707 r
F P
0 g
s
.25402 .76823 m .25872 .80007 L .29026 .79489 L p .707 .577 .707 r
F P
0 g
s
.29026 .79489 m .28556 .76305 L .25402 .76823 L p .707 .577 .707 r
F P
0 g
s
.33573 .66621 m .33873 .71924 L .35498 .70769 L p .707 .577 .707 r
F P
0 g
s
.35498 .70769 m .35199 .65467 L .33573 .66621 L p .707 .577 .707 r
F P
0 g
s
.6407 .69535 m .6377 .64233 L .66518 .64738 L p .707 .577 .707 r
F P
0 g
s
.34083 .79044 m .33889 .7739 L .31523 .78672 L p .707 .577 .707 r
F P
0 g
s
.28556 .76305 m .29026 .79489 L .31917 .78467 L p .707 .577 .707 r
F P
0 g
s
.31917 .78467 m .31447 .75283 L .28556 .76305 L p .707 .577 .707 r
F P
0 g
s
.3719 .8035 m .37916 .29709 L .36138 .28712 L p .707 .577 .707 r
F P
0 g
s
.37916 .29709 m .3719 .8035 L .40163 .81186 L p .707 .577 .707 r
F P
0 g
s
.25647 .81675 m .25453 .80021 L .22343 .79957 L p .707 .577 .707 r
F P
0 g
s
.22765 .79968 m .22295 .76784 L .19539 .76193 L p .707 .577 .707 r
F P
0 g
s
.22295 .76784 m .22765 .79968 L .25872 .80007 L p .707 .577 .707 r
F P
0 g
s
.68828 .74982 m .69021 .76636 L .66895 .75625 L p .707 .577 .707 r
F P
0 g
s
.66895 .75625 m .66702 .73971 L .68828 .74982 L p .707 .577 .707 r
F P
0 g
s
.35676 .77513 m .35482 .75859 L .33889 .7739 L p .707 .577 .707 r
F P
0 g
s
.31447 .75283 m .31917 .78467 L .34264 .77039 L p .707 .577 .707 r
F P
0 g
s
.34264 .77039 m .33794 .73855 L .31447 .75283 L p .707 .577 .707 r
F P
0 g
s
.25453 .80021 m .25647 .81675 L .2881 .81232 L p .707 .577 .707 r
F P
0 g
s
.28616 .79578 m .2881 .81232 L .31717 .80325 L p .707 .577 .707 r
F P
0 g
s
.17396 .72306 m .17096 .67003 L .15829 .65916 L p .707 .577 .707 r
F P
0 g
s
.17096 .67003 m .17396 .72306 L .19507 .73143 L p .707 .577 .707 r
F P
0 g
s
.22536 .81611 m .22343 .79957 L .1959 .79392 L p .707 .577 .707 r
F P
0 g
s
.22343 .79957 m .22536 .81611 L .25647 .81675 L p .707 .577 .707 r
F P
0 g
s
.31523 .78672 m .31717 .80325 L .34083 .79044 L p .707 .577 .707 r
F P
0 g
s
.20009 .79378 m .19539 .76193 L .17404 .75108 L p .707 .577 .707 r
F P
0 g
s
.19539 .76193 m .20009 .79378 L .22765 .79968 L p .707 .577 .707 r
F P
0 g
s
.35199 .65467 m .35498 .70769 L .36195 .69515 L p .707 .577 .707 r
F P
0 g
s
.36195 .69515 m .35895 .64213 L .35199 .65467 L p .707 .577 .707 r
F P
0 g
s
.63512 .29508 m .62786 .80149 L .63785 .7913 L p .707 .577 .707 r
F P
0 g
s
.63785 .7913 m .64511 .28489 L .63512 .29508 L p .707 .577 .707 r
F P
0 g
s
.35588 .75612 m .35835 .75345 L p .35525 .75119 L .707 .577 .707 r
F P
0 g
s
.35835 .75345 m .35365 .72161 L .33794 .73855 L p .707 .577 .707 r
F P
0 g
s
.35365 .72161 m .35835 .75345 L .36141 .74494 L p .707 .577 .707 r
F P
0 g
s
.36141 .74494 m .36478 .73552 L p .36138 .73126 L .707 .577 .707 r
F P
0 g
s
.36138 .73126 m .35365 .72161 L .36141 .74494 L .707 .577 .707 r
F
.35587 .75602 m .35482 .75859 L p .3562 .75863 L F P
0 g
s
.33794 .73855 m .34264 .77039 L .35588 .75612 L p .707 .577 .707 r
F P
0 g
s
.35525 .75119 m .33794 .73855 L .35588 .75612 L .707 .577 .707 r
F
.33889 .7739 m .34083 .79044 L .35676 .77513 L p F P
0 g
s
.36478 .73552 m .36009 .70368 L .35365 .72161 L p .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35895 .64213 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35895 .68284 m .35878 .67989 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35595 .62982 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35878 .67989 L p .34628 .67197 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35895 .68284 L .35862 .68256 L p .707 .577 .707 r
F P
0 g
s
.35862 .68256 m .34628 .67197 L p .35878 .67989 L .707 .577 .707 r
F P
0 g
s
.34628 .67197 m .34328 .61894 L .35595 .62982 L p .707 .577 .707 r
F P
0 g
s
.3566 .68651 m .3585 .69941 L p .34824 .70362 L .707 .577 .707 r
F P
0 g
s
.3585 .69941 m .3613 .71835 L .35663 .71308 L p .707 .577 .707 r
F P
0 g
s
.35663 .71308 m .34824 .70362 L p .3585 .69941 L .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35231 .78885 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.34824 .70362 m .34354 .67178 L .3566 .68651 L p .707 .577 .707 r
F P
0 g
s
.35817 .72657 m .36011 .74311 L .35668 .73951 L p .707 .577 .707 r
F P
0 g
s
.35668 .73951 m .3472 .72954 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.35807 .7266 m .35817 .72657 L .35668 .73951 L .707 .577 .707 r
F
.3472 .72954 m .34527 .713 L .35808 .72648 L p F P
0 g
s
.35808 .72648 m .35817 .72657 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.3472 .72954 m .35808 .72648 L .35807 .7266 L .707 .577 .707 r
F
.35431 .76163 m .35589 .66982 L .35489 .66636 L F
.35412 .79352 m .35461 .7588 L p .35431 .76163 L F P
0 g
s
.35461 .7588 m .35589 .66982 L p .35431 .76163 L .707 .577 .707 r
F P
0 g
s
.35436 .75438 m .35728 .27652 L .3524 .77946 L .707 .577 .707 r
F
.35344 .76971 m .3524 .77946 L .35231 .78885 L F
.35436 .75438 m .3524 .77946 L .35344 .76971 L F
.35728 .27652 m .35036 .75887 L p .35277 .7413 L F P
0 g
s
.35036 .75887 m .35002 .78293 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.35231 .78885 m .35412 .79352 L p .35436 .75438 L .707 .577 .707 r
F P
0 g
s
.35489 .66636 m .3605 .34794 L .35728 .27652 L .707 .577 .707 r
F
.35589 .66982 m .3605 .34794 L p .35489 .66636 L F P
0 g
s
.3605 .34794 m .36138 .28712 L .36036 .28449 L p .707 .577 .707 r
F P
0 g
s
.36036 .28449 m .35728 .27652 L p .3605 .34794 L .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .36147 .74228 L .35587 .75602 L p .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .35587 .75602 L .3562 .75863 L .707 .577 .707 r
F
.1959 .79392 m .19783 .81046 L .22536 .81611 L p F P
0 g
s
.66702 .73971 m .66895 .75625 L .64143 .7506 L p .707 .577 .707 r
F P
0 g
s
.64143 .7506 m .63949 .73406 L .66702 .73971 L p .707 .577 .707 r
F P
0 g
s
.19783 .81046 m .1959 .79392 L .17464 .78381 L p .707 .577 .707 r
F P
0 g
s
.15829 .65916 m .16128 .71218 L .17396 .72306 L p .707 .577 .707 r
F P
0 g
s
.16128 .71218 m .15829 .65916 L .15529 .64685 L p .707 .577 .707 r
F P
0 g
s
.17464 .78381 m .17658 .80035 L .19783 .81046 L p .707 .577 .707 r
F P
0 g
s
.35895 .64213 m .36195 .69515 L .35895 .68284 L p .707 .577 .707 r
F P
0 g
s
.35482 .75859 m .35676 .77513 L .3634 .75882 L p .707 .577 .707 r
F P
0 g
s
.36009 .70368 m .36478 .73552 L .3613 .71835 L p .707 .578 .707 r
F P
0 g
s
.3613 .71835 m .3566 .68651 L .36009 .70368 L p .707 .578 .707 r
F P
0 g
s
.36147 .74228 m .3634 .75882 L .36011 .74311 L p .707 .577 .707 r
F P
0 g
s
.36011 .74311 m .35817 .72657 L .36147 .74228 L p .707 .577 .707 r
F P
0 g
s
.36138 .28712 m .35412 .79352 L .3719 .8035 L p .707 .577 .707 r
F P
0 g
s
.17404 .75108 m .17874 .78292 L .20009 .79378 L p .707 .577 .707 r
F P
0 g
s
.17874 .78292 m .17404 .75108 L .16098 .73635 L p .707 .577 .707 r
F P
0 g
s
.17658 .80035 m .17464 .78381 L .16174 .77024 L p .707 .577 .707 r
F P
0 g
s
.15529 .64685 m .15828 .69987 L .16128 .71218 L p .707 .577 .707 r
F P
0 g
s
.16174 .77024 m .16367 .78678 L .17658 .80035 L p .707 .577 .707 r
F P
0 g
s
.16098 .73635 m .16568 .76819 L .17874 .78292 L p .707 .577 .707 r
F P
0 g
s
.64511 .28489 m .63785 .7913 L .63375 .7807 L p .707 .577 .707 r
F P
0 g
s
.63375 .7807 m .64101 .27429 L .64511 .28489 L p .707 .577 .707 r
F P
0 g
s
.16568 .76819 m .16098 .73635 L .15749 .71918 L p .707 .578 .707 r
F P
0 g
s
.15828 .69987 m .15529 .64685 L .16225 .63431 L p .707 .577 .707 r
F P
0 g
s
.16367 .78678 m .16174 .77024 L .15844 .75453 L p .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35728 .27652 L .36726 .26633 L p .707 .577 .707 r
F P
0 g
s
.15844 .75453 m .16038 .77107 L .16367 .78678 L p .707 .577 .707 r
F P
0 g
s
.15749 .71918 m .16219 .75102 L .16568 .76819 L p .707 .578 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16225 .63431 m .16525 .68733 L .15828 .69987 L p .707 .577 .707 r
F P
0 g
s
.16219 .75102 m .15749 .71918 L .16392 .70125 L p .707 .577 .707 r
F P
0 g
s
.16525 .68733 m .16225 .63431 L .17851 .62276 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1676 .73582 m .18102 .72291 L p .16944 .74926 L .707 .577 .707 r
F P
0 g
s
.16392 .70125 m .16862 .73309 L .16761 .73591 L p .707 .577 .707 r
F P
0 g
s
.16761 .73591 m .16219 .75102 L p .16371 .70747 L .707 .577 .707 r
F P
0 g
s
.16371 .70747 m .16392 .70125 L .16761 .73591 L .707 .577 .707 r
F
.16702 .75476 m .16509 .73823 L .1676 .73582 L p F P
0 g
s
.16702 .75476 m .1676 .73582 L .16944 .74926 L .707 .577 .707 r
F
.16038 .77107 m .15844 .75453 L .16509 .73823 L p F P
0 g
s
.32218 .66092 m .34354 .67178 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32688 .69277 m .32677 .69202 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32677 .69202 m .32218 .66092 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32218 .66092 m .32688 .69277 L .29932 .68686 L p .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .32218 .66092 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29932 .68686 m .29927 .68652 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29927 .68652 m .29462 .65502 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .29932 .68686 L .26825 .68647 L p .707 .577 .707 r
F P
0 g
s
.26355 .65463 m .29462 .65502 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26825 .68647 m .26814 .68573 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26814 .68573 m .26355 .65463 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .26355 .65463 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23672 .69165 m .23643 .68973 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23643 .68973 m .23202 .65981 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.2078 .70188 m .2031 .67003 L .23202 .65981 L p .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .23672 .69165 L .2078 .70188 L p .707 .577 .707 r
F P
0 g
s
.23176 .60697 m .23475 .66 L .21754 .66374 L p .707 .577 .707 r
F P
0 g
s
.21754 .66374 m .20545 .66637 L p .21075 .65441 L .707 .577 .707 r
F P
0 g
s
.21075 .65441 m .23176 .60697 L .21754 .66374 L .707 .577 .707 r
F
.26355 .65463 m .26825 .68647 L .23672 .69165 L p F P
0 g
s
.26354 .60428 m .26654 .6573 L .24697 .65896 L p .707 .577 .707 r
F P
0 g
s
.24697 .65896 m .23475 .66 L p .2399 .65003 L .707 .577 .707 r
F P
0 g
s
.2399 .65003 m .26354 .60428 L .24697 .65896 L .707 .577 .707 r
F
.29469 .60551 m .29769 .65854 L .27916 .6578 L p F P
0 g
s
.27916 .6578 m .26654 .6573 L p .2719 .64744 L .707 .577 .707 r
F P
0 g
s
.2719 .64744 m .29469 .60551 L .27916 .6578 L .707 .577 .707 r
F
.32217 .61057 m .32517 .66359 L .31045 .66089 L p F P
0 g
s
.31045 .66089 m .29769 .65854 L p .30338 .64739 L .707 .577 .707 r
F P
0 g
s
.30338 .64739 m .32217 .61057 L .31045 .66089 L .707 .577 .707 r
F
.34328 .61894 m .34628 .67197 L .32517 .66359 L p F P
0 g
s
.32517 .66359 m .32217 .61057 L .34328 .61894 L p .707 .577 .707 r
F P
0 g
s
.64101 .27429 m .63375 .7807 L .61596 .77073 L p .707 .577 .707 r
F P
0 g
s
.61596 .77073 m .62322 .26432 L .64101 .27429 L p .707 .577 .707 r
F P
0 g
s
.16509 .73823 m .16702 .75476 L .16038 .77107 L p .707 .577 .707 r
F P
0 g
s
.17851 .62276 m .18151 .67579 L .16525 .68733 L p .707 .577 .707 r
F P
0 g
s
.16862 .73309 m .16392 .70125 L .17964 .68431 L p .707 .577 .707 r
F P
0 g
s
.18151 .67579 m .17851 .62276 L .20246 .61334 L p .707 .577 .707 r
F P
0 g
s
.34354 .67178 m .34824 .70362 L .32688 .69277 L p .707 .577 .707 r
F P
0 g
s
.36 .77274 m .36726 .26633 L .39036 .25755 L p .707 .577 .707 r
F P
0 g
s
.36726 .26633 m .36 .77274 L .35002 .78293 L p .707 .577 .707 r
F P
0 g
s
.29769 .65854 m .29469 .60551 L .32217 .61057 L p .707 .577 .707 r
F P
0 g
s
.34527 .713 m .3472 .72954 L .32595 .71943 L p .707 .577 .707 r
F P
0 g
s
.32595 .71943 m .32401 .7029 L .34527 .713 L p .707 .577 .707 r
F P
0 g
s
.20545 .66637 m .20246 .61334 L .23176 .60697 L p .707 .577 .707 r
F P
0 g
s
.20246 .61334 m .20545 .66637 L .18151 .67579 L p .707 .577 .707 r
F P
0 g
s
.17964 .68431 m .18434 .71615 L .16862 .73309 L p .707 .577 .707 r
F P
0 g
s
.18434 .71615 m .17964 .68431 L .2031 .67003 L p .707 .577 .707 r
F P
0 g
s
.18102 .72291 m .18295 .73945 L .16702 .75476 L p .707 .577 .707 r
F P
0 g
s
.26654 .6573 m .26354 .60428 L .29469 .60551 L p .707 .577 .707 r
F P
0 g
s
.62322 .26432 m .61596 .77073 L .58623 .76236 L p .707 .577 .707 r
F P
0 g
s
.58623 .76236 m .59349 .25595 L .62322 .26432 L p .707 .577 .707 r
F P
0 g
s
.23475 .66 m .23176 .60697 L .26354 .60428 L p .707 .577 .707 r
F P
0 g
s
.18295 .73945 m .18102 .72291 L .20468 .7101 L p .707 .577 .707 r
F P
0 g
s
.73391 .65728 m .73091 .60425 L .69976 .60301 L p .707 .577 .707 r
F P
0 g
s
.73091 .60425 m .73391 .65728 L .76569 .65458 L p .707 .577 .707 r
F P
0 g
s
.76569 .65458 m .7627 .60156 L .73091 .60425 L p .707 .577 .707 r
F P
0 g
s
.2031 .67003 m .2078 .70188 L .18434 .71615 L p .707 .577 .707 r
F P
0 g
s
.7627 .60156 m .76569 .65458 L .79499 .64821 L p .707 .577 .707 r
F P
0 g
s
.79499 .64821 m .792 .59519 L .7627 .60156 L p .707 .577 .707 r
F P
0 g
s
.32401 .7029 m .32595 .71943 L .29842 .71378 L p .707 .577 .707 r
F P
0 g
s
.29842 .71378 m .29648 .69725 L .32401 .7029 L p .707 .577 .707 r
F P
0 g
s
.70276 .65604 m .69976 .60301 L .67228 .59796 L p .707 .577 .707 r
F P
0 g
s
.69976 .60301 m .70276 .65604 L .73391 .65728 L p .707 .577 .707 r
F P
0 g
s
.39036 .25755 m .3831 .76395 L .36 .77274 L p .707 .577 .707 r
F P
0 g
s
.3831 .76395 m .39036 .25755 L .42431 .25103 L p .707 .577 .707 r
F P
0 g
s
.20468 .7101 m .20661 .72664 L .18295 .73945 L p .707 .577 .707 r
F P
0 g
s
.792 .59519 m .79499 .64821 L .81894 .63879 L p .707 .577 .707 r
F P
0 g
s
.81894 .63879 m .81595 .58577 L .792 .59519 L p .707 .577 .707 r
F P
0 g
s
.20661 .72664 m .20468 .7101 L .23375 .70103 L p .707 .577 .707 r
F P
0 g
s
.29648 .69725 m .29842 .71378 L .26732 .71314 L p .707 .577 .707 r
F P
0 g
s
.26732 .71314 m .26538 .6966 L .29648 .69725 L p .707 .577 .707 r
F P
0 g
s
.67528 .65098 m .67228 .59796 L .65117 .58959 L p .707 .577 .707 r
F P
0 g
s
.67228 .59796 m .67528 .65098 L .70276 .65604 L p .707 .577 .707 r
F P
0 g
s
.23375 .70103 m .23568 .71757 L .20661 .72664 L p .707 .577 .707 r
F P
0 g
s
.23568 .71757 m .23375 .70103 L .26538 .6966 L p .707 .577 .707 r
F P
0 g
s
.59349 .25595 m .58623 .76236 L .54747 .75641 L p .707 .577 .707 r
F P
0 g
s
.54747 .75641 m .55473 .25001 L .59349 .25595 L p .707 .577 .707 r
F P
0 g
s
.26538 .6966 m .26732 .71314 L .23568 .71757 L p .707 .577 .707 r
F P
0 g
s
.81595 .58577 m .81894 .63879 L .8352 .62725 L p .707 .577 .707 r
F P
0 g
s
.8352 .62725 m .8322 .57422 L .81595 .58577 L p .707 .577 .707 r
F P
0 g
s
.41705 .75744 m .42431 .25103 L .46578 .24742 L p .707 .577 .707 r
F P
0 g
s
.42431 .25103 m .41705 .75744 L .3831 .76395 L p .707 .577 .707 r
F P
0 g
s
.73893 .74279 m .73424 .71095 L .70317 .71057 L p .707 .577 .707 r
F P
0 g
s
.73424 .71095 m .73893 .74279 L .77047 .73762 L p .707 .577 .707 r
F P
0 g
s
.77047 .73762 m .76577 .70578 L .73424 .71095 L p .707 .577 .707 r
F P
0 g
s
.76577 .70578 m .77047 .73762 L .79939 .72739 L p .707 .577 .707 r
F P
0 g
s
.79939 .72739 m .79469 .69555 L .76577 .70578 L p .707 .577 .707 r
F P
0 g
s
.65417 .64261 m .65117 .58959 L .6385 .57871 L p .707 .577 .707 r
F P
0 g
s
.65117 .58959 m .65417 .64261 L .67528 .65098 L p .707 .577 .707 r
F P
0 g
s
.70787 .74241 m .70317 .71057 L .67561 .70466 L p .707 .577 .707 r
F P
0 g
s
.70317 .71057 m .70787 .74241 L .73893 .74279 L p .707 .577 .707 r
F P
0 g
s
.79469 .69555 m .79939 .72739 L .82285 .71311 L p .707 .577 .707 r
F P
0 g
s
.82285 .71311 m .81815 .68127 L .79469 .69555 L p .707 .577 .707 r
F P
0 g
s
.55473 .25001 m .54747 .75641 L .50346 .75347 L p .707 .577 .707 r
F P
0 g
s
.50346 .75347 m .51072 .24707 L .55473 .25001 L p .707 .577 .707 r
F P
0 g
s
.45852 .75383 m .46578 .24742 L .51072 .24707 L p .707 .577 .707 r
F P
0 g
s
.46578 .24742 m .45852 .75383 L .41705 .75744 L p .707 .577 .707 r
F P
0 g
s
.8322 .57422 m .8352 .62725 L .84216 .61471 L p .707 .577 .707 r
F P
0 g
s
.84216 .61471 m .83917 .56168 L .8322 .57422 L p .707 .577 .707 r
F P
0 g
s
.51072 .24707 m .50346 .75347 L .45852 .75383 L p .707 .577 .707 r
F P
0 g
s
.73668 .80331 m .73474 .78677 L .70364 .78613 L p .707 .577 .707 r
F P
0 g
s
.73474 .78677 m .73668 .80331 L .76831 .79888 L p .707 .577 .707 r
F P
0 g
s
.76831 .79888 m .76638 .78234 L .73474 .78677 L p .707 .577 .707 r
F P
0 g
s
.6803 .7365 m .67561 .70466 L .65425 .69381 L p .707 .577 .707 r
F P
0 g
s
.67561 .70466 m .6803 .7365 L .70787 .74241 L p .707 .577 .707 r
F P
0 g
s
.76638 .78234 m .76831 .79888 L .79738 .78981 L p .707 .577 .707 r
F P
0 g
s
.79738 .78981 m .79545 .77327 L .76638 .78234 L p .707 .577 .707 r
F P
0 g
s
.81815 .68127 m .82285 .71311 L .83857 .69618 L p .707 .577 .707 r
F P
0 g
s
.83857 .69618 m .83387 .66434 L .81815 .68127 L p .707 .577 .707 r
F P
0 g
s
.6385 .57871 m .6415 .63174 L .65417 .64261 L p .707 .577 .707 r
F P
0 g
s
.70558 .80266 m .70364 .78613 L .67611 .78048 L p .707 .577 .707 r
F P
0 g
s
.70364 .78613 m .70558 .80266 L .73668 .80331 L p .707 .577 .707 r
F P
0 g
s
.79545 .77327 m .79738 .78981 L .82104 .777 L p .707 .577 .707 r
F P
0 g
s
.82104 .777 m .8191 .76046 L .79545 .77327 L p .707 .577 .707 r
F P
0 g
s
.6415 .63174 m .6385 .57871 L .6355 .5664 L p .707 .577 .707 r
F P
0 g
s
.67611 .78048 m .67805 .79701 L .70558 .80266 L p .707 .577 .707 r
F P
0 g
s
.65425 .69381 m .65895 .72565 L .6803 .7365 L p .707 .577 .707 r
F P
0 g
s
.65895 .72565 m .65425 .69381 L .64119 .67908 L p .707 .577 .707 r
F P
0 g
s
.67805 .79701 m .67611 .78048 L .65486 .77037 L p .707 .577 .707 r
F P
0 g
s
.83917 .56168 m .84216 .61471 L .83916 .6024 L p .707 .577 .707 r
F P
0 g
s
.83916 .6024 m .83617 .54937 L .83917 .56168 L p .707 .577 .707 r
F P
0 g
s
.83387 .66434 m .83857 .69618 L .845 .67825 L p .707 .577 .707 r
F P
0 g
s
.845 .67825 m .8403 .64641 L .83387 .66434 L p .707 .577 .707 r
F P
0 g
s
.8191 .76046 m .82104 .777 L .83697 .76168 L p .707 .577 .707 r
F P
0 g
s
.83697 .76168 m .83504 .74515 L .8191 .76046 L p .707 .577 .707 r
F P
0 g
s
.65486 .77037 m .65679 .78691 L .67805 .79701 L p .707 .577 .707 r
F P
0 g
s
.6355 .5664 m .6385 .61943 L .6415 .63174 L p .707 .577 .707 r
F P
0 g
s
.6385 .61943 m .6355 .5664 L .64247 .55386 L p .707 .577 .707 r
F P
0 g
s
.64119 .67908 m .64589 .71092 L .65895 .72565 L p .707 .577 .707 r
F P
0 g
s
.65679 .78691 m .65486 .77037 L .64195 .7568 L p .707 .577 .707 r
F P
0 g
s
.64589 .71092 m .64119 .67908 L .63771 .6619 L p .707 .578 .707 r
F P
0 g
s
.83504 .74515 m .83697 .76168 L .84361 .74538 L p .707 .577 .707 r
F P
0 g
s
.84361 .74538 m .84168 .72884 L .83504 .74515 L p .707 .577 .707 r
F P
0 g
s
.8403 .64641 m .845 .67825 L .84151 .66107 L p .707 .578 .707 r
F P
0 g
s
.84151 .66107 m .83681 .62923 L .8403 .64641 L p .707 .578 .707 r
F P
0 g
s
.64195 .7568 m .64388 .77334 L .65679 .78691 L p .707 .577 .707 r
F P
0 g
s
.83617 .54937 m .83916 .6024 L .82649 .59152 L p .707 .577 .707 r
F P
0 g
s
.82649 .59152 m .82349 .5385 L .83617 .54937 L p .707 .577 .707 r
F P
0 g
s
.64247 .55386 m .64546 .60688 L .6385 .61943 L p .707 .577 .707 r
F P
0 g
s
.63771 .6619 m .6424 .69374 L .64589 .71092 L p .707 .578 .707 r
F P
0 g
s
.64546 .60688 m .64247 .55386 L .65872 .54231 L p .707 .577 .707 r
F P
0 g
s
.64388 .77334 m .64195 .7568 L .63866 .74109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3909 .62046 m .3879 .56744 L .35675 .5662 L p .707 .577 .707 r
F P
0 g
s
.3879 .56744 m .3909 .62046 L .42268 .61777 L p .707 .577 .707 r
F P
0 g
s
.42268 .61777 m .41969 .56474 L .3879 .56744 L p .707 .577 .707 r
F P
0 g
s
.6424 .69374 m .63771 .6619 L .64414 .64397 L p .707 .577 .707 r
F P
0 g
s
.41969 .56474 m .42268 .61777 L .45198 .6114 L p .707 .577 .707 r
F P
0 g
s
.45198 .6114 m .44899 .55837 L .41969 .56474 L p .707 .577 .707 r
F P
0 g
s
.84168 .72884 m .84361 .74538 L .84032 .72967 L p .707 .577 .707 r
F P
0 g
s
.84032 .72967 m .83839 .71313 L .84168 .72884 L p .707 .577 .707 r
F P
0 g
s
.83681 .62923 m .84151 .66107 L .82845 .64634 L p .707 .577 .707 r
F P
0 g
s
.82845 .64634 m .82375 .6145 L .83681 .62923 L p .707 .577 .707 r
F P
0 g
s
.35975 .61922 m .35675 .5662 L .32927 .56114 L p .707 .577 .707 r
F P
0 g
s
.35675 .5662 m .35975 .61922 L .3909 .62046 L p .707 .577 .707 r
F P
0 g
s
.63866 .74109 m .64059 .75763 L .64388 .77334 L p .707 .577 .707 r
F P
0 g
s
.82349 .5385 m .82649 .59152 L .80538 .58315 L p .707 .577 .707 r
F P
0 g
s
.80538 .58315 m .80238 .53012 L .82349 .5385 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44899 .55837 m .45198 .6114 L .47593 .60198 L p .707 .577 .707 r
F P
0 g
s
.47593 .60198 m .47294 .54895 L .44899 .55837 L p .707 .577 .707 r
F P
0 g
s
.65872 .54231 m .66172 .59534 L .64546 .60688 L p .707 .577 .707 r
F P
0 g
s
.33227 .61417 m .32927 .56114 L .30816 .55277 L p .707 .577 .707 r
F P
0 g
s
.32927 .56114 m .33227 .61417 L .35975 .61922 L p .707 .577 .707 r
F P
0 g
s
.64414 .64397 m .64883 .67581 L .6424 .69374 L p .707 .577 .707 r
F P
0 g
s
.66172 .59534 m .65872 .54231 L .68267 .5329 L p .707 .577 .707 r
F P
0 g
s
.64059 .75763 m .63866 .74109 L .6453 .72478 L p .707 .577 .707 r
F P
0 g
s
.64883 .67581 m .64414 .64397 L .65985 .62704 L p .707 .577 .707 r
F P
0 g
s
.82375 .6145 m .82845 .64634 L .8071 .63549 L p .707 .577 .707 r
F P
0 g
s
.8071 .63549 m .8024 .60365 L .82375 .6145 L p .707 .577 .707 r
F P
0 g
s
.47294 .54895 m .47593 .60198 L .49219 .59043 L p .707 .577 .707 r
F P
0 g
s
.49219 .59043 m .48919 .53741 L .47294 .54895 L p .707 .577 .707 r
F P
0 g
s
.80238 .53012 m .80538 .58315 L .7779 .57809 L p .707 .577 .707 r
F P
0 g
s
.7779 .57809 m .77491 .52507 L .80238 .53012 L p .707 .577 .707 r
F P
0 g
s
.83839 .71313 m .84032 .72967 L .82742 .7161 L p .707 .577 .707 r
F P
0 g
s
.82742 .7161 m .82548 .69956 L .83839 .71313 L p .707 .577 .707 r
F P
0 g
s
.6453 .72478 m .64724 .74132 L .64059 .75763 L p .707 .577 .707 r
F P
0 g
s
.39592 .70598 m .39123 .67414 L .36016 .67375 L p .707 .577 .707 r
F P
0 g
s
.39123 .67414 m .39592 .70598 L .42746 .7008 L p .707 .577 .707 r
F P
0 g
s
.42746 .7008 m .42276 .66896 L .39123 .67414 L p .707 .577 .707 r
F P
0 g
s
.42276 .66896 m .42746 .7008 L .45638 .69058 L p .707 .577 .707 r
F P
0 g
s
.45638 .69058 m .45168 .65873 L .42276 .66896 L p .707 .577 .707 r
F P
0 g
s
.68567 .58592 m .68267 .5329 L .71197 .52653 L p .707 .577 .707 r
F P
0 g
s
.68267 .5329 m .68567 .58592 L .66172 .59534 L p .707 .577 .707 r
F P
0 g
s
.31116 .6058 m .30816 .55277 L .29549 .5419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55277 m .31116 .6058 L .33227 .61417 L p .707 .577 .707 r
F P
0 g
s
.36486 .70559 m .36016 .67375 L .3326 .66784 L p .707 .577 .707 r
F P
0 g
s
.36016 .67375 m .36486 .70559 L .39592 .70598 L p .707 .577 .707 r
F P
0 g
s
.45168 .65873 m .45638 .69058 L .47984 .6763 L p .707 .577 .707 r
F P
0 g
s
.47984 .6763 m .47514 .64446 L .45168 .65873 L p .707 .577 .707 r
F P
0 g
s
.77491 .52507 m .7779 .57809 L .74675 .57685 L p .707 .577 .707 r
F P
0 g
s
.74675 .57685 m .74375 .52383 L .77491 .52507 L p .707 .577 .707 r
F P
0 g
s
.65985 .62704 m .66455 .65888 L .64883 .67581 L p .707 .577 .707 r
F P
0 g
s
.66455 .65888 m .65985 .62704 L .68332 .61276 L p .707 .577 .707 r
F P
0 g
s
.64724 .74132 m .6453 .72478 L .66123 .70947 L p .707 .577 .707 r
F P
0 g
s
.71497 .57955 m .71197 .52653 L .74375 .52383 L p .707 .577 .707 r
F P
0 g
s
.71197 .52653 m .71497 .57955 L .68567 .58592 L p .707 .577 .707 r
F P
0 g
s
.8024 .60365 m .8071 .63549 L .77954 .62958 L p .707 .577 .707 r
F P
0 g
s
.77954 .62958 m .77484 .59774 L .8024 .60365 L p .707 .577 .707 r
F P
0 g
s
.74375 .52383 m .74675 .57685 L .71497 .57955 L p .707 .577 .707 r
F P
0 g
s
.48919 .53741 m .49219 .59043 L .49915 .57789 L p .707 .577 .707 r
F P
0 g
s
.49915 .57789 m .49616 .52487 L .48919 .53741 L p .707 .577 .707 r
F P
0 g
s
.82548 .69956 m .82742 .7161 L .80616 .70599 L p .707 .577 .707 r
F P
0 g
s
.80616 .70599 m .80423 .68945 L .82548 .69956 L p .707 .577 .707 r
F P
0 g
s
.39367 .76649 m .39173 .74995 L .36063 .74931 L p .707 .577 .707 r
F P
0 g
s
.39173 .74995 m .39367 .76649 L .4253 .76206 L p .707 .577 .707 r
F P
0 g
s
.4253 .76206 m .42337 .74553 L .39173 .74995 L p .707 .577 .707 r
F P
0 g
s
.33729 .69969 m .3326 .66784 L .31124 .65699 L p .707 .577 .707 r
F P
0 g
s
.3326 .66784 m .33729 .69969 L .36486 .70559 L p .707 .577 .707 r
F P
0 g
s
.42337 .74553 m .4253 .76206 L .45437 .753 L p .707 .577 .707 r
F P
0 g
s
.45437 .753 m .45244 .73646 L .42337 .74553 L p .707 .577 .707 r
F P
0 g
s
.66123 .70947 m .66317 .72601 L .64724 .74132 L p .707 .577 .707 r
F P
0 g
s
.47514 .64446 m .47984 .6763 L .49556 .65936 L p .707 .577 .707 r
F P
0 g
s
.49556 .65936 m .49086 .62752 L .47514 .64446 L p .707 .577 .707 r
F P
0 g
s
.68802 .6446 m .68332 .61276 L .71223 .60253 L p .707 .577 .707 r
F P
0 g
s
.68332 .61276 m .68802 .6446 L .66455 .65888 L p .707 .577 .707 r
F P
0 g
s
.29549 .5419 m .29849 .59492 L .31116 .6058 L p .707 .577 .707 r
F P
0 g
s
.36257 .76585 m .36063 .74931 L .3331 .74366 L p .707 .577 .707 r
F P
0 g
s
.36063 .74931 m .36257 .76585 L .39367 .76649 L p .707 .577 .707 r
F P
0 g
s
.77484 .59774 m .77954 .62958 L .74847 .6292 L p .707 .577 .707 r
F P
0 g
s
.74847 .6292 m .74377 .59736 L .77484 .59774 L p .707 .577 .707 r
F P
0 g
s
.45244 .73646 m .45437 .753 L .47803 .74018 L p .707 .577 .707 r
F P
0 g
s
.47803 .74018 m .47609 .72364 L .45244 .73646 L p .707 .577 .707 r
F P
0 g
s
.29849 .59492 m .29549 .5419 L .29249 .52958 L p .707 .577 .707 r
F P
0 g
s
.71693 .63437 m .71223 .60253 L .74377 .59736 L p .707 .577 .707 r
F P
0 g
s
.71223 .60253 m .71693 .63437 L .68802 .6446 L p .707 .577 .707 r
F P
0 g
s
.74377 .59736 m .74847 .6292 L .71693 .63437 L p .707 .577 .707 r
F P
0 g
s
.66317 .72601 m .66123 .70947 L .68489 .69666 L p .707 .577 .707 r
F P
0 g
s
.3331 .74366 m .33504 .7602 L .36257 .76585 L p .707 .577 .707 r
F P
0 g
s
.80423 .68945 m .80616 .70599 L .77863 .70034 L p .707 .577 .707 r
F P
0 g
s
.77863 .70034 m .7767 .6838 L .80423 .68945 L p .707 .577 .707 r
F P
0 g
s
.31124 .65699 m .31594 .68883 L .33729 .69969 L p .707 .577 .707 r
F P
0 g
s
.31594 .68883 m .31124 .65699 L .29818 .64226 L p .707 .577 .707 r
F P
0 g
s
.33504 .7602 m .3331 .74366 L .31185 .73356 L p .707 .577 .707 r
F P
0 g
s
.49616 .52487 m .49915 .57789 L .49615 .56558 L p .707 .577 .707 r
F P
0 g
s
.49615 .56558 m .49316 .51255 L .49616 .52487 L p .707 .577 .707 r
F P
0 g
s
.68489 .69666 m .68683 .71319 L .66317 .72601 L p .707 .577 .707 r
F P
0 g
s
.49086 .62752 m .49556 .65936 L .50199 .64143 L p .707 .577 .707 r
F P
0 g
s
.50199 .64143 m .49729 .60959 L .49086 .62752 L p .707 .577 .707 r
F P
0 g
s
.47609 .72364 m .47803 .74018 L .49396 .72487 L p .707 .577 .707 r
F P
0 g
s
.49396 .72487 m .49203 .70833 L .47609 .72364 L p .707 .577 .707 r
F P
0 g
s
.31185 .73356 m .31378 .75009 L .33504 .7602 L p .707 .577 .707 r
F P
0 g
s
.68683 .71319 m .68489 .69666 L .71396 .68759 L p .707 .577 .707 r
F P
0 g
s
.29249 .52958 m .29549 .58261 L .29849 .59492 L p .707 .577 .707 r
F P
0 g
s
.7767 .6838 m .77863 .70034 L .74753 .6997 L p .707 .577 .707 r
F P
0 g
s
.74753 .6997 m .74559 .68316 L .7767 .6838 L p .707 .577 .707 r
F P
0 g
s
.29549 .58261 m .29249 .52958 L .29946 .51704 L p .707 .577 .707 r
F P
0 g
s
.71396 .68759 m .7159 .70413 L .68683 .71319 L p .707 .577 .707 r
F P
0 g
s
.7159 .70413 m .71396 .68759 L .74559 .68316 L p .707 .577 .707 r
F P
0 g
s
.29818 .64226 m .30288 .6741 L .31594 .68883 L p .707 .577 .707 r
F P
0 g
s
.74559 .68316 m .74753 .6997 L .7159 .70413 L p .707 .577 .707 r
F P
0 g
s
.31378 .75009 m .31185 .73356 L .29894 .71998 L p .707 .577 .707 r
F P
0 g
s
.30288 .6741 m .29818 .64226 L .29469 .62509 L p .707 .578 .707 r
F P
0 g
s
.49203 .70833 m .49396 .72487 L .5006 .70856 L p .707 .577 .707 r
F P
0 g
s
.5006 .70856 m .49867 .69202 L .49203 .70833 L p .707 .577 .707 r
F P
0 g
s
.49729 .60959 m .50199 .64143 L .4985 .62426 L p .707 .578 .707 r
F P
0 g
s
.4985 .62426 m .4938 .59242 L .49729 .60959 L p .707 .578 .707 r
F P
0 g
s
.29894 .71998 m .30087 .73652 L .31378 .75009 L p .707 .577 .707 r
F P
0 g
s
.49316 .51255 m .49615 .56558 L .48348 .55471 L p .707 .577 .707 r
F P
0 g
s
.48348 .55471 m .48048 .50168 L .49316 .51255 L p .707 .577 .707 r
F P
0 g
s
.29946 .51704 m .30245 .57007 L .29549 .58261 L p .707 .577 .707 r
F P
0 g
s
.29469 .62509 m .29939 .65693 L .30288 .6741 L p .707 .578 .707 r
F P
0 g
s
.30245 .57007 m .29946 .51704 L .31571 .5055 L p .707 .577 .707 r
F P
0 g
s
.30087 .73652 m .29894 .71998 L .29565 .70428 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29939 .65693 m .29469 .62509 L .30113 .60716 L p .707 .577 .707 r
F P
0 g
s
.49867 .69202 m .5006 .70856 L .49731 .69285 L p .707 .577 .707 r
F P
0 g
s
.49731 .69285 m .49538 .67632 L .49867 .69202 L p .707 .577 .707 r
F P
0 g
s
.4938 .59242 m .4985 .62426 L .48544 .60953 L p .707 .577 .707 r
F P
0 g
s
.48544 .60953 m .48074 .57768 L .4938 .59242 L p .707 .577 .707 r
F P
0 g
s
.29565 .70428 m .29758 .72081 L .30087 .73652 L p .707 .577 .707 r
F P
0 g
s
.48048 .50168 m .48348 .55471 L .46237 .54633 L p .707 .577 .707 r
F P
0 g
s
.46237 .54633 m .45937 .49331 L .48048 .50168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31571 .5055 m .31871 .55852 L .30245 .57007 L p .707 .577 .707 r
F P
0 g
s
.30113 .60716 m .30582 .639 L .29939 .65693 L p .707 .577 .707 r
F P
0 g
s
.31871 .55852 m .31571 .5055 L .33966 .49608 L p .707 .577 .707 r
F P
0 g
s
.29758 .72081 m .29565 .70428 L .30229 .68797 L p .707 .577 .707 r
F P
0 g
s
.30582 .639 m .30113 .60716 L .31684 .59022 L p .707 .577 .707 r
F P
0 g
s
.48074 .57768 m .48544 .60953 L .46409 .59867 L p .707 .577 .707 r
F P
0 g
s
.46409 .59867 m .45939 .56683 L .48074 .57768 L p .707 .577 .707 r
F P
0 g
s
.45937 .49331 m .46237 .54633 L .43489 .54128 L p .707 .577 .707 r
F P
0 g
s
.43489 .54128 m .4319 .48825 L .45937 .49331 L p .707 .577 .707 r
F P
0 g
s
.49538 .67632 m .49731 .69285 L .48441 .67928 L p .707 .577 .707 r
F P
0 g
s
.48441 .67928 m .48247 .66274 L .49538 .67632 L p .707 .577 .707 r
F P
0 g
s
.30229 .68797 m .30423 .70451 L .29758 .72081 L p .707 .577 .707 r
F P
0 g
s
.34266 .54911 m .33966 .49608 L .36896 .48971 L p .707 .577 .707 r
F P
0 g
s
.33966 .49608 m .34266 .54911 L .31871 .55852 L p .707 .577 .707 r
F P
0 g
s
.4319 .48825 m .43489 .54128 L .40374 .54004 L p .707 .577 .707 r
F P
0 g
s
.40374 .54004 m .40074 .48701 L .4319 .48825 L p .707 .577 .707 r
F P
0 g
s
.31684 .59022 m .32154 .62206 L .30582 .639 L p .707 .577 .707 r
F P
0 g
s
.32154 .62206 m .31684 .59022 L .34031 .57594 L p .707 .577 .707 r
F P
0 g
s
.30423 .70451 m .30229 .68797 L .31822 .67266 L p .707 .577 .707 r
F P
0 g
s
.37196 .54274 m .36896 .48971 L .40074 .48701 L p .707 .577 .707 r
F P
0 g
s
.36896 .48971 m .37196 .54274 L .34266 .54911 L p .707 .577 .707 r
F P
0 g
s
.45939 .56683 m .46409 .59867 L .43653 .59277 L p .707 .577 .707 r
F P
0 g
s
.43653 .59277 m .43183 .56093 L .45939 .56683 L p .707 .577 .707 r
F P
0 g
s
.40074 .48701 m .40374 .54004 L .37196 .54274 L p .707 .577 .707 r
F P
0 g
s
.48247 .66274 m .48441 .67928 L .46315 .66918 L p .707 .577 .707 r
F P
0 g
s
.46315 .66918 m .46121 .65264 L .48247 .66274 L p .707 .577 .707 r
F P
0 g
s
.31822 .67266 m .32016 .68919 L .30423 .70451 L p .707 .577 .707 r
F P
0 g
s
.34501 .60778 m .34031 .57594 L .36922 .56572 L p .707 .577 .707 r
F P
0 g
s
.34031 .57594 m .34501 .60778 L .32154 .62206 L p .707 .577 .707 r
F P
0 g
s
.43183 .56093 m .43653 .59277 L .40546 .59238 L p .707 .577 .707 r
F P
0 g
s
.40546 .59238 m .40076 .56054 L .43183 .56093 L p .707 .577 .707 r
F P
0 g
s
.37392 .59756 m .36922 .56572 L .40076 .56054 L p .707 .577 .707 r
F P
0 g
s
.36922 .56572 m .37392 .59756 L .34501 .60778 L p .707 .577 .707 r
F P
0 g
s
.40076 .56054 m .40546 .59238 L .37392 .59756 L p .707 .577 .707 r
F P
0 g
s
.32016 .68919 m .31822 .67266 L .34188 .65984 L p .707 .577 .707 r
F P
0 g
s
.46121 .65264 m .46315 .66918 L .43562 .66353 L p .707 .577 .707 r
F P
0 g
s
.43562 .66353 m .43369 .64699 L .46121 .65264 L p .707 .577 .707 r
F P
0 g
s
.34188 .65984 m .34382 .67638 L .32016 .68919 L p .707 .577 .707 r
F P
0 g
s
.34382 .67638 m .34188 .65984 L .37095 .65077 L p .707 .577 .707 r
F P
0 g
s
.43369 .64699 m .43562 .66353 L .40452 .66288 L p .707 .577 .707 r
F P
0 g
s
.40452 .66288 m .40258 .64635 L .43369 .64699 L p .707 .577 .707 r
F P
0 g
s
.37095 .65077 m .37288 .66731 L .34382 .67638 L p .707 .577 .707 r
F P
0 g
s
.37288 .66731 m .37095 .65077 L .40258 .64635 L p .707 .577 .707 r
F P
0 g
s
.40258 .64635 m .40452 .66288 L .37288 .66731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolH0026Ool007Ioo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEP`007Yoo`00
LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF1`00
Lgoo001]Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUH00002001`Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00J7oo0P0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P00Jgoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008006Moo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEPl000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Moo`03001JEP0000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol01@00FUIJEUYF00001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`T004Eoo`00E7oo0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF009JEPP003eoo`00Dgoo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD0
03Qoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo10001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`00=Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20008Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000UJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00MJEP@000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo001COol00`00FUH00004FUH00`00FUH000030004Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH01eYF100000=JEP00FUH00P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool005Aoo`8000AJ
EP8000Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30005FUH01@00FUIJEUYF
00000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo0P000eYF00<005YFFUH00`001Goo00@005YF
FUH000EJEQ400003FUH005YF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P0000=JEP00000015YF00<005YF00000`0000Aoo`00FUIJEPH000AJEP03001JEUYF00IJ
EP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol40005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
E7oo0P0000=JEP00FUH015YF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool005Aoo`800003FUH005YF00AJEP03001JEUYF008000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol01000FUIJEP001EYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP04FUHH0003FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01@00FUIJEUYF000015YF00@005YFFUH000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH00000
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04000HOol40005FUH01@00FUIJEUYF0000;Woo001D
Ool01@00FUIJEUYF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP<0021o
o`8000=JEP05001JEUYFFUH0000^Ool005Aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P008goo100000=JEP00FUH00UYF0P00;Goo001DOol01000FUIJEUYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUH000008goo0P000UYF00@005YF000000=JEP8002eoo`00E7oo00L005YFFUIJEP00
FUH00006FUH00`00FUIJEP05FUH70008FUH00`00FUIJEP03FUH400000eYF001JEP04FUH01000FUIJ
EP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF0P004goo3@0000=oo`0000000P0015YF00D005YFFUIJEP00009JEP8002eoo`00EGoo00<0
05YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000EJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20002FUH5000:Ool40002FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP02FUH4000]Ool004Ioo`T000Moo`05001JEUYFFUH00007FUH0
0`00FUH000020008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF00@005YFFUIJEPX000IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP<002eoo`00@7oo1P0015YF00<005YFFUH00UYF1`001EYF00<005YFFUH015YF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@0000AJEP00FUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EP00FUH00005FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH40005FUH3000]Ool003aoo`@00003FUH005YF00IJEP03Ool005YF00MJEP03001JEP0000EJEP03
001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH0
05YF00=JEP8000=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool003Qoo`@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00@000AJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUH0000]Ool003Ioo`800003FUH005YF00IJEP03001JEUYF00AJEP03OomJEP0000QJEP<000EJEPT0
009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00EJEP03001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF
00=JEP@000MJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH0000002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00001EYF00<005YFFUH00UYF0P000Woo40000eYF00<005YFFUH02EYF00<005YFFUH01UYF
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP000000;Woo000bOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH017ooFUIJEP0025YF00@005YFFUH000=JEP8000EJEP800005Ool005YFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH00000;goo000aOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF00<005YF00001EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009JEP03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPL0
00AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000_Ool002moo`800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF009JEP05001JEUYFFUIoo`03FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH2000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF0`001eYF00<005YFFUH01EYF00<005YFFUH010001eYF200015YF00<005YF
FUH00eYF00<005YF0000;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00002FUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000015YF001JEP001eYF00<005YFFUH015YF1000
0UYF00<005YFFUH01UYF00<005YFFUH01EYF1@001EYF00<005YF0000;goo000]Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEWoo1EYF00@005YFFUIoo`EJEP04001JEP00Ool4FUH0
0`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000^Ool002eoo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
009JEP04001JEP000002FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH01000FUIJEP000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000Eoo`00FUIJEP0000MJEP03001JEP00008000QJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH200001Goo000005YF00000UYF00<007ooOol0;7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIoo`06FUH00`00FUIoo`06FUH00`00FUH00005FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000EJEP04001JEUYFFUH=0005FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000Eoo`80009JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF0`0000=JEP00
FUH015YF10000UYF00<005YFFUH01UYF00<005YF00000`0000AJEP00FUIJEP<000AJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009J
EP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Uoo`03001JEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<007ooFUH01UYF00<005YF
FUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH010001UYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010003Goo00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40007FUH20002FUH01@00FUIJEUYF00001EYF1P00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH30003FUHJ
000AOol3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPT00004FUH0
05YFFUH90002FUH300000eYF001JEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P001EYF0P00:7oo00<005YF0000;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP020002FUH30008FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01P00FUIJEP00FUH000EJEP03001JEP0002Moo`03001JEP0002eoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF1@000eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF001JEP00
00AJEP80009JEP03001JEUYF00EJEPH000MJEP04001JEUYFFUH70002FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00
FUH00002FUH00`00FUIJEP03FUH01000FUIJEP002Woo0`0067oo0P0000=JEP00Ool0;7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP00009JEP8000AJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJEPH000IJEP@000EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EP00009JEP03001JEUYF00=JEP04001JEUYF0009Ool5000FOol00`00FUH00002FUH00`00Oomoo`0Z
Ool002aoo`03001JEP0000AJEP03001JEP0000@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00009JEP8000IJEP03001JEP00010000AJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20003FUH00`00FUIJEP03FUH01000FUIJEP002Goo1@005Goo00@005YFFUH0009JEP03001o
ogoo02Yoo`00;Goo0P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUH005YF008000IJEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP800005FUH005YFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
0008Ool5000DOol01@00FUIJEUYF00000UYF00<007ooOol0:Woo000]Ool20002FUH200000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUH00000FUH000AJEP80
00EJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00
FUIJEP03FUH00`00FUIJEP020009Ool3000DOol00`00FUIJEP03FUH00`00FUH0000/Ool002eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEP00008000IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF008000AJEP03
001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00EJEP03001JEUYF00=JEP03001JEUYF008000Moo`l000Qoo`<000EJEP8002eoo`00;Goo0P0000=J
EP00FUH00P001UYF00<005YFFUH01UYF00<005YFFUH00UYF3P001EYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF0`001eYF00D005YF001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000EJEP03001JEUYF00=JEP03001JEUYF00800003
Ool0000000@000AJEP03001JEUYF00IJEP03001JEP0000<0009oo`80009JEP03001JEUYF00=JEP80
02eoo`00;Goo0P0000EJEP00001JEP0000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF009JEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0
00UJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001oogoo02aoo`00;Goo00@005YFFUH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF
FUH005YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH025YF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P001EYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUH000020007FUH>000015YF001JEP0015YF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P0015YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH00`000eYF0`001eYF00<005YFFUH015YF1`0015YF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20005FUH00`00FUIJ
EP04FUH2000015YF001JEUYF1P0015YF00<005YFFUH01UYF00<005YF00001P000UYF1P000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH01eYF10002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
10001goo200015YF00<005YFFUH00UYF0`00<7oo000]Ool20005FUH00`00FUIJEP02FUH20002FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH00005FUH300000eYF0000000200000eYF0000
000>00000eYF001JEP0:FUH00`00FUIJEP06FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF001JEUYF00000UYF0P000eYF00<005YFFUH01EYF1000
2Goo10001UYF1@0015YF00<005YF0000<7oo000]Ool20005FUH00`00FUIJEP02000015YF00000000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF00<005YFFUH00P000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP<000IJEP03001JEUYF00@000Uoo`@0009J
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUH0000_Ool002eoo`8000EJEPL000QJEP03
001JEUYF00AJEP`000IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00EJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@0009JEP8000MJEQ0000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH0
05YFFUH0000^Ool002aoo`03001JEP0000EJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH01@00FUIJEP00FUH010000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF00L005YF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF000005YF00001EYF0P0015YF00<005YF
FUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<007ooOol0
;7oo000/Ool01000FUIJEP000eYF0`0015YF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00@0
05YFFUH000AJEP@000EJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30002FUH01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01eYF00@005YFFUH000Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0009JEP8000IJEP03001J
EUYF00@000MJEP<000IJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJ
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF0`000UYF00<005YF
FUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`001Woo00@005YF000002eoo`00;7oo
00D005YFFUH005YF00<000IJEP<0009JEP03001JEUYF00EJEPD000EJEP06001JEUYF001JEP000UYF
00@005YF0000009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00<000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP05FUH20009Ool3000]Ool002eoo`03001JEP0000800003FUH005YF00=JEP80
00EJEP03001JEUYF00EJEPD000EJEP06001JEUYFFUH005YF10001Woo0`000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF0`000UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP<000IJEP03001JEUYF009JEP<000aoo`8002eoo`00;Goo00@005YF000000=JEP05
001JEUYF001oo`040002FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP020002FUH00`00Oomoo`07
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20004FUH01000FUH00000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00
00000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003goo
0P00;Goo000]Ool30004FUH30006OolG000017oo001JEUYF0`001Woo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000P001EYF0`001UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Woo0P00;Goo000]Ool20005FUH00`00Oomoo`0OOol00`00FUH0
0002FUH20003Ool01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`000UYF00<005YFFUH0
1UYF00<005YFFUH0100057oo00<005YF0000;Goo000]Ool20004FUH00`00Oomoo`0QOol00`00FUH0
0003FUH40002FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001JEUYF
009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF00AJEP<00003FUH005YF009JEP03001JEP0000d001Qoo`03001JEP0002eoo`00;Goo
00@005YF001JEP8002Eoo`8000AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJ
EPH000MJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP020002FUH300000eYF001oo`0ROol200000eYF
001oo`0/Ool002eoo`03001JEP00008002Moo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000IJEP04001JEUYFFUH20002Ool3000ROol01000FUH00000;Woo000]Ool01000FUH005YF
0`0097oo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
5P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000P000UYF
00<005YFFUH00UYF0P0000Aoo`00FUH0025oo`03001JEUYF008002ioo`00;Goo00D005YF001JEP00
009JEP8001ioo`@00004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000:FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
0003FUH00`00FUH000030003FUH01P00FUH00000FUH0021oo`05001JEUYFFUH0000_Ool002eoo`<0
0003FUH005YF00=JEP<001Ioo`D000EJEP03001JEUYF009JEPD000AJEP03001JEUYF00EJEP03001J
EUYF009JEPL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001J
EUYF009JEP@0009JEP04001JEP000002Ool300001UYF001JEP00FUH001moo`03001JEUYF009JEP03
001oogoo02eoo`00;Goo0`0000=JEP00FUH015YF00<005YF00000`003Woo10000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF000040002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`0000=JEP0000000P001goo0P000UYF
00<005YF000077oo0`000eYF00<007ooOol0;Woo000]Ool00`00Ool00002FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH>0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30002FUH00`00FUH000020007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH300000eYF001JEP03FUH400000eYF001oo`08Ool01`00FUH005YF001JEP0001Yoo`80009JEP04
001JEUYF000aOol002eoo`06001oogoo001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF0P0000Aoo`00FUIJEP8000Ioo`08001JEUYF001JEP00FUH001Moo`<000EJEP80039oo`00;Goo
0P0000Aoo`00FUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
0000009oo`04001JEP00FUH30002Ool00`00FUIJEP02FUH4000DOol300000eYF001JEP05FUH00`00
Oomoo`0aOol002eoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00IJEP03001JEUYF00800004FUH005YFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40002Ool00`00FUH00004FUH30005FUH2000BOol30004FUH00`00FUIJEP02FUH2000dOol002io
o`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP<0
00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003Ool20005
FUH00`00FUH0000300000eYF0000000<Ool60007FUH00`00FUIJEP02000fOol002ioo`03001JEUYF
00@000=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP8000EJEP800003
Ool0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3000hOol002moo`03001JEP00009JEP<00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP05001oogooOol0
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000goo10000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00>Woo000`Ool00`00FUH00003FUH4
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020002FUH00`00FUIJEP02FUH20004
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00Ool00P0000AJEP00
FUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8003ao
o`00<Goo0P0015YF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@0
05YFFUH000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD000=JEP03001JEUYF009JEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008003ioo`00<Woo00<005YFFUH00UYF
00<005YFFUH00eYF4@000eYF00<005YFFUH01UYF0`002Woo0`0025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Goo000cOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000>Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30008FUH00`00FUIJEP04FUH300000eYF0000000>0017Ool003Eoo`800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@001Aoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0001FOol003Moo`<000IJEP03
001JEUYF00EJEP03001JEUYF00AJEPD001aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00AJEPD000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03
001oogoo05Aoo`00>Woo10000UYF00<005YFFUH01EYF00<005YFFUH010009Woo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02@001EYF00<005YFFUH01UYF00<0
05YFFUH00`000eYF00<007ooOol0EGoo000nOol=000`Ool80006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH80004FUH50005FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00F7oo0023OolJ0004FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH30004FUH00`00FUH0001HOol0091oo`03001JEUYF
00@000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000MJEP03001JEUYF009JEP<000IJEP8005Uo
o`00TGoo00<005YF00000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P000UYF00<005YFFUH00eYF0P00FWoo002AOol00`00FUH00004FUH60004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P00G7oo002BOol20005FUH01000FUIJEUYF
4`000UYF00<005YFFUH01UYF00@005YF000005ioo`00Tgoo0P0015YF00<005YFFUH01EYF00@005YF
FUIJEPL000IJEP03001JEUYF00EJEP<0061oo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002HOol30006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH00002001UOol009]oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH006Qo
o`00Wgoo4000KWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59671 .77454 m .59371 .72151 L .56256 .72028 L p .707 .577 .707 r
F P
0 g
s
.59371 .72151 m .59671 .77454 L .62849 .77184 L p .707 .577 .707 r
F P
0 g
s
.62849 .77184 m .62549 .71882 L .59371 .72151 L p .707 .577 .707 r
F P
0 g
s
.62549 .71882 m .62849 .77184 L .65779 .76547 L p .707 .577 .707 r
F P
0 g
s
.65779 .76547 m .65479 .71245 L .62549 .71882 L p .707 .577 .707 r
F P
0 g
s
.56555 .7733 m .56256 .72028 L .53508 .71522 L p .707 .577 .707 r
F P
0 g
s
.56256 .72028 m .56555 .7733 L .59671 .77454 L p .707 .577 .707 r
F P
0 g
s
.65479 .71245 m .65779 .76547 L .68174 .75605 L p .707 .577 .707 r
F P
0 g
s
.68174 .75605 m .67874 .70303 L .65479 .71245 L p .707 .577 .707 r
F P
0 g
s
.53808 .76825 m .53508 .71522 L .51397 .70685 L p .707 .577 .707 r
F P
0 g
s
.53508 .71522 m .53808 .76825 L .56555 .7733 L p .707 .577 .707 r
F P
0 g
s
.63111 .84914 m .62917 .8326 L .59754 .83703 L p .707 .577 .707 r
F P
0 g
s
.60173 .83688 m .59703 .80504 L .56596 .80466 L p .707 .577 .707 r
F P
0 g
s
.66018 .84007 m .65824 .82353 L .62917 .8326 L p .707 .577 .707 r
F P
0 g
s
.59703 .80504 m .60173 .83688 L .63327 .83171 L p .707 .577 .707 r
F P
0 g
s
.63327 .83171 m .62857 .79987 L .59703 .80504 L p .707 .577 .707 r
F P
0 g
s
.67874 .70303 m .68174 .75605 L .69799 .74451 L p .707 .577 .707 r
F P
0 g
s
.69799 .74451 m .69499 .69148 L .67874 .70303 L p .707 .577 .707 r
F P
0 g
s
.68383 .82725 m .6819 .81072 L .65824 .82353 L p .707 .577 .707 r
F P
0 g
s
.62857 .79987 m .63327 .83171 L .66218 .82148 L p .707 .577 .707 r
F P
0 g
s
.66218 .82148 m .65748 .78964 L .62857 .79987 L p .707 .577 .707 r
F P
0 g
s
.59947 .85356 m .59754 .83703 L .56644 .83638 L p .707 .577 .707 r
F P
0 g
s
.57066 .8365 m .56596 .80466 L .5384 .79875 L p .707 .577 .707 r
F P
0 g
s
.56596 .80466 m .57066 .8365 L .60173 .83688 L p .707 .577 .707 r
F P
0 g
s
.69977 .81194 m .69783 .79541 L .6819 .81072 L p .707 .577 .707 r
F P
0 g
s
.65748 .78964 m .66218 .82148 L .68565 .8072 L p .707 .577 .707 r
F P
0 g
s
.68565 .8072 m .68095 .77536 L .65748 .78964 L p .707 .577 .707 r
F P
0 g
s
.59754 .83703 m .59947 .85356 L .63111 .84914 L p .707 .577 .707 r
F P
0 g
s
.62917 .8326 m .63111 .84914 L .66018 .84007 L p .707 .577 .707 r
F P
0 g
s
.51697 .75987 m .51397 .70685 L .5013 .69597 L p .707 .577 .707 r
F P
0 g
s
.51397 .70685 m .51697 .75987 L .53808 .76825 L p .707 .577 .707 r
F P
0 g
s
.56837 .85292 m .56644 .83638 L .53891 .83073 L p .707 .577 .707 r
F P
0 g
s
.56644 .83638 m .56837 .85292 L .59947 .85356 L p .707 .577 .707 r
F P
0 g
s
.65824 .82353 m .66018 .84007 L .68383 .82725 L p .707 .577 .707 r
F P
0 g
s
.5431 .83059 m .5384 .79875 L .51705 .7879 L p .707 .577 .707 r
F P
0 g
s
.5384 .79875 m .5431 .83059 L .57066 .8365 L p .707 .577 .707 r
F P
0 g
s
.69499 .69148 m .69799 .74451 L .70496 .73197 L p .707 .577 .707 r
F P
0 g
s
.70496 .73197 m .70196 .67894 L .69499 .69148 L p .707 .577 .707 r
F P
0 g
s
.69889 .79293 m .70136 .79027 L p .69826 .78801 L .707 .577 .707 r
F P
0 g
s
.70136 .79027 m .69666 .75843 L .68095 .77536 L p .707 .577 .707 r
F P
0 g
s
.69666 .75843 m .70136 .79027 L .70779 .77234 L p .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .70448 .7791 L .69888 .79284 L p .707 .577 .707 r
F P
0 g
s
.69888 .79284 m .69783 .79541 L p .69921 .79544 L .707 .577 .707 r
F P
0 g
s
.70641 .79563 m .69888 .79284 L .69921 .79544 L .707 .577 .707 r
F
.68095 .77536 m .68565 .8072 L .69889 .79293 L p F P
0 g
s
.69826 .78801 m .68095 .77536 L .69889 .79293 L .707 .577 .707 r
F
.53891 .83073 m .54084 .84727 L .56837 .85292 L p F P
0 g
s
.54084 .84727 m .53891 .83073 L .51765 .82063 L p .707 .577 .707 r
F P
0 g
s
.5013 .69597 m .50429 .749 L .51697 .75987 L p .707 .577 .707 r
F P
0 g
s
.6819 .81072 m .68383 .82725 L .69977 .81194 L p .707 .577 .707 r
F P
0 g
s
.50429 .749 m .5013 .69597 L .4983 .68366 L p .707 .577 .707 r
F P
0 g
s
.51765 .82063 m .51959 .83717 L .54084 .84727 L p .707 .577 .707 r
F P
0 g
s
.51705 .7879 m .52174 .81974 L .5431 .83059 L p .707 .577 .707 r
F P
0 g
s
.52174 .81974 m .51705 .7879 L .50399 .77317 L p .707 .577 .707 r
F P
0 g
s
.70779 .77234 m .70309 .7405 L .69666 .75843 L p .707 .577 .707 r
F P
0 g
s
.70196 .67894 m .70496 .73197 L .70196 .71966 L p .707 .577 .707 r
F P
0 g
s
.70196 .71966 m .69896 .66663 L .70196 .67894 L p .707 .577 .707 r
F P
0 g
s
.51959 .83717 m .51765 .82063 L .50475 .80706 L p .707 .577 .707 r
F P
0 g
s
.69783 .79541 m .69977 .81194 L .70641 .79563 L p .707 .577 .707 r
F P
0 g
s
.4983 .68366 m .50129 .73669 L .50429 .749 L p .707 .577 .707 r
F P
0 g
s
.50475 .80706 m .50668 .8236 L .51959 .83717 L p .707 .577 .707 r
F P
0 g
s
.50399 .77317 m .50869 .80501 L .52174 .81974 L p .707 .577 .707 r
F P
0 g
s
.50869 .80501 m .50399 .77317 L .5005 .75599 L p .707 .578 .707 r
F P
0 g
s
.50129 .73669 m .4983 .68366 L .50526 .67112 L p .707 .577 .707 r
F P
0 g
s
.48441 .82075 m .49167 .31434 L .44766 .3114 L p .707 .577 .707 r
F P
0 g
s
.50668 .8236 m .50475 .80706 L .50145 .79135 L p .707 .577 .707 r
F P
0 g
s
.50145 .79135 m .50339 .80789 L .50668 .8236 L p .707 .577 .707 r
F P
0 g
s
.5005 .75599 m .5052 .78783 L .50869 .80501 L p .707 .578 .707 r
F P
0 g
s
.50526 .67112 m .50826 .72415 L .50129 .73669 L p .707 .577 .707 r
F P
0 g
s
.5052 .78783 m .5005 .75599 L .50693 .73806 L p .707 .577 .707 r
F P
0 g
s
.50826 .72415 m .50526 .67112 L .52152 .65958 L p .707 .577 .707 r
F P
0 g
s
.51061 .77263 m .52403 .75973 L p .51245 .78608 L .707 .577 .707 r
F P
0 g
s
.50693 .73806 m .51163 .7699 L .51062 .77273 L p .707 .577 .707 r
F P
0 g
s
.51062 .77273 m .5052 .78783 L p .50672 .74428 L .707 .577 .707 r
F P
0 g
s
.50672 .74428 m .50693 .73806 L .51062 .77273 L .707 .577 .707 r
F
.51003 .79158 m .5081 .77504 L .51061 .77263 L p F P
0 g
s
.51003 .79158 m .51061 .77263 L .51245 .78608 L .707 .577 .707 r
F
.50339 .80789 m .50145 .79135 L .5081 .77504 L p F P
0 g
s
.5081 .77504 m .51003 .79158 L .50339 .80789 L p .707 .577 .707 r
F P
0 g
s
.52152 .65958 m .52451 .7126 L .50826 .72415 L p .707 .577 .707 r
F P
0 g
s
.51163 .7699 m .50693 .73806 L .52265 .72113 L p .707 .577 .707 r
F P
0 g
s
.52265 .72113 m .52735 .75297 L .51163 .7699 L p .707 .577 .707 r
F P
0 g
s
.52403 .75973 m .52596 .77627 L .51003 .79158 L p .707 .577 .707 r
F P
0 g
s
.52596 .77627 m .52403 .75973 L .54769 .74691 L p .707 .577 .707 r
F P
0 g
s
.54769 .74691 m .54962 .76345 L .52596 .77627 L p .707 .577 .707 r
F P
0 g
s
.49167 .31434 m .48441 .82075 L .52934 .82039 L p .707 .577 .707 r
F P
0 g
s
.52451 .7126 m .52152 .65958 L .54547 .65016 L p .707 .577 .707 r
F P
0 g
s
.54547 .65016 m .54846 .70318 L .52451 .7126 L p .707 .577 .707 r
F P
0 g
s
.52735 .75297 m .52265 .72113 L .54611 .70685 L p .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .5499 .73253 L p .52735 .75297 L .707 .577 .707 r
F P
0 g
s
.5499 .73253 m .55081 .73869 L .54749 .74071 L p .707 .577 .707 r
F P
0 g
s
.54749 .74071 m .52735 .75297 L p .5499 .73253 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .49167 .31434 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52934 .82039 m .52962 .80129 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.52962 .80129 m .5366 .31399 L p .52826 .80588 L .707 .577 .707 r
F P
0 g
s
.70309 .7405 m .70779 .77234 L .70431 .75517 L p .707 .578 .707 r
F P
0 g
s
.70431 .75517 m .69961 .72332 L .70309 .7405 L p .707 .578 .707 r
F P
0 g
s
.54547 .65016 m .57477 .64379 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.54846 .70318 m .5483 .70023 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.5483 .70023 m .54547 .65016 L p .54893 .70214 L .707 .577 .707 r
F P
0 g
s
.57503 .69662 m .57987 .69583 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.57944 .72655 m .57503 .69662 L p .57973 .72694 L .707 .577 .707 r
F P
0 g
s
.54611 .70685 m .57503 .69662 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.55081 .73869 m .54802 .71975 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.54802 .71975 m .54611 .70685 L p .55622 .7293 L .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .60337 .78419 L .57148 .7705 L .707 .577 .707 r
F
.57503 .69662 m .57973 .72846 L .55081 .73869 L p F P
0 g
s
.57477 .64379 m .57776 .69681 L .56055 .70056 L p .707 .577 .707 r
F P
0 g
s
.55376 .69122 m .57477 .64379 L .56055 .70056 L .707 .577 .707 r
F
.57973 .72846 m .57944 .72655 L p .57973 .72694 L F P
0 g
s
.57987 .69583 m .60656 .69145 L p .58561 .72035 L .707 .577 .707 r
F P
0 g
s
.57973 .72846 m .57987 .69583 L .58561 .72035 L .707 .577 .707 r
F
.59578 .642 m .60655 .64109 L p .59674 .66007 L F P
0 g
s
.57776 .69681 m .59578 .642 L .59674 .66007 L .707 .577 .707 r
F
.57776 .69681 m .57477 .64379 L .59578 .642 L p F P
0 g
s
.60656 .69145 m .63763 .69183 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.61115 .72255 m .60656 .69145 L p .61151 .723 L .707 .577 .707 r
F P
0 g
s
.60656 .69145 m .61126 .72329 L .57973 .72846 L p .707 .577 .707 r
F P
0 g
s
.60655 .64109 m .60955 .69412 L .58998 .69578 L p .707 .577 .707 r
F P
0 g
s
.58998 .69578 m .57776 .69681 L p .58291 .68684 L .707 .577 .707 r
F P
0 g
s
.58291 .68684 m .60655 .64109 L .58998 .69578 L .707 .577 .707 r
F
.61126 .72329 m .61115 .72255 L p .61151 .723 L F P
0 g
s
.54962 .76345 m .54769 .74691 L .57676 .73785 L p .707 .577 .707 r
F P
0 g
s
.57676 .73785 m .57869 .75439 L .54962 .76345 L p .707 .577 .707 r
F P
0 g
s
.57869 .75439 m .57676 .73785 L .60839 .73342 L p .707 .577 .707 r
F P
0 g
s
.60839 .73342 m .61032 .74996 L .57869 .75439 L p .707 .577 .707 r
F P
0 g
s
.57808 .31038 m .57181 .74745 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.57181 .74745 m .57148 .7705 L p .60337 .78419 L .707 .577 .707 r
F P
0 g
s
.56055 .70056 m .54846 .70318 L p .55376 .69122 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .66519 .69774 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.64228 .72334 m .63763 .69183 L p .64244 .72356 L .707 .577 .707 r
F P
0 g
s
.63763 .69183 m .64233 .72367 L .61126 .72329 L p .707 .577 .707 r
F P
0 g
s
.6377 .64233 m .6407 .69535 L .62217 .69462 L p .707 .577 .707 r
F P
0 g
s
.62217 .69462 m .60955 .69412 L p .61491 .68426 L .707 .577 .707 r
F P
0 g
s
.61491 .68426 m .6377 .64233 L .62217 .69462 L .707 .577 .707 r
F
.64233 .72367 m .64228 .72334 L p .64244 .72356 L F P
0 g
s
.60955 .69412 m .60655 .64109 L .6377 .64233 L p .707 .577 .707 r
F P
0 g
s
.63949 .73406 m .64143 .7506 L .61032 .74996 L p .707 .577 .707 r
F P
0 g
s
.61032 .74996 m .60839 .73342 L .63949 .73406 L p .707 .577 .707 r
F P
0 g
s
.61202 .30386 m .60487 .80261 L p .62786 .80149 L .707 .577 .707 r
F P
0 g
s
.60487 .80261 m .60476 .81027 L .60651 .8096 L p .707 .577 .707 r
F P
0 g
s
.60651 .8096 m .62786 .80149 L p .60487 .80261 L .707 .577 .707 r
F P
0 g
s
.57148 .7705 m .57082 .81678 L .5858 .81391 L p .707 .577 .707 r
F P
0 g
s
.5858 .81391 m .60476 .81027 L p .57148 .7705 L .707 .577 .707 r
F P
0 g
s
.5366 .31399 m .52934 .82039 L .57082 .81678 L p .707 .577 .707 r
F P
0 g
s
.57082 .81678 m .57808 .31038 L .5366 .31399 L p .707 .577 .707 r
F P
0 g
s
.4404 .81781 m .44766 .3114 L .40889 .30546 L p .707 .577 .707 r
F P
0 g
s
.44766 .3114 m .4404 .81781 L .48441 .82075 L p .707 .577 .707 r
F P
0 g
s
.69896 .66663 m .70196 .71966 L .68928 .70878 L p .707 .577 .707 r
F P
0 g
s
.68928 .70878 m .68629 .65576 L .69896 .66663 L p .707 .577 .707 r
F P
0 g
s
.70448 .7791 m .70641 .79563 L .70312 .77993 L p .707 .577 .707 r
F P
0 g
s
.70312 .77993 m .70118 .76339 L .70448 .7791 L p .707 .577 .707 r
F P
0 g
s
.60476 .81027 m .61202 .30386 L .57808 .31038 L p .707 .577 .707 r
F P
0 g
s
.2537 .73772 m .2507 .6847 L .21955 .68346 L p .707 .577 .707 r
F P
0 g
s
.2507 .6847 m .2537 .73772 L .28548 .73503 L p .707 .577 .707 r
F P
0 g
s
.28548 .73503 m .28248 .682 L .2507 .6847 L p .707 .577 .707 r
F P
0 g
s
.69961 .72332 m .70431 .75517 L .69125 .74043 L p .707 .577 .707 r
F P
0 g
s
.69125 .74043 m .68655 .70859 L .69961 .72332 L p .707 .577 .707 r
F P
0 g
s
.40163 .81186 m .40889 .30546 L .37916 .29709 L p .707 .577 .707 r
F P
0 g
s
.40889 .30546 m .40163 .81186 L .4404 .81781 L p .707 .577 .707 r
F P
0 g
s
.28248 .682 m .28548 .73503 L .31478 .72866 L p .707 .577 .707 r
F P
0 g
s
.31478 .72866 m .31178 .67563 L .28248 .682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22254 .73649 m .21955 .68346 L .19207 .67841 L p .707 .577 .707 r
F P
0 g
s
.21955 .68346 m .22254 .73649 L .2537 .73772 L p .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .68655 .70859 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66989 .72958 m .66978 .72884 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66978 .72884 m .66519 .69774 L p .67006 .72937 L .707 .577 .707 r
F P
0 g
s
.66519 .69774 m .66989 .72958 L .64233 .72367 L p .707 .577 .707 r
F P
0 g
s
.66518 .64738 m .66818 .70041 L .65346 .6977 L p .707 .577 .707 r
F P
0 g
s
.65346 .6977 m .6407 .69535 L p .64639 .68421 L .707 .577 .707 r
F P
0 g
s
.64639 .68421 m .66518 .64738 L .65346 .6977 L .707 .577 .707 r
F
.68629 .65576 m .68928 .70878 L .66818 .70041 L p F P
0 g
s
.66818 .70041 m .66518 .64738 L .68629 .65576 L p .707 .577 .707 r
F P
0 g
s
.31178 .67563 m .31478 .72866 L .33873 .71924 L p .707 .577 .707 r
F P
0 g
s
.33873 .71924 m .33573 .66621 L .31178 .67563 L p .707 .577 .707 r
F P
0 g
s
.70118 .76339 m .70312 .77993 L .69021 .76636 L p .707 .577 .707 r
F P
0 g
s
.69021 .76636 m .68828 .74982 L .70118 .76339 L p .707 .577 .707 r
F P
0 g
s
.62786 .80149 m .63512 .29508 L .61202 .30386 L p .707 .577 .707 r
F P
0 g
s
.19507 .73143 m .19207 .67841 L .17096 .67003 L p .707 .577 .707 r
F P
0 g
s
.19207 .67841 m .19507 .73143 L .22254 .73649 L p .707 .577 .707 r
F P
0 g
s
.68655 .70859 m .69125 .74043 L .66989 .72958 L p .707 .577 .707 r
F P
0 g
s
.2881 .81232 m .28616 .79578 L .25453 .80021 L p .707 .577 .707 r
F P
0 g
s
.25872 .80007 m .25402 .76823 L .22295 .76784 L p .707 .577 .707 r
F P
0 g
s
.31717 .80325 m .31523 .78672 L .28616 .79578 L p .707 .577 .707 r
F P
0 g
s
.25402 .76823 m .25872 .80007 L .29026 .79489 L p .707 .577 .707 r
F P
0 g
s
.29026 .79489 m .28556 .76305 L .25402 .76823 L p .707 .577 .707 r
F P
0 g
s
.33573 .66621 m .33873 .71924 L .35498 .70769 L p .707 .577 .707 r
F P
0 g
s
.35498 .70769 m .35199 .65467 L .33573 .66621 L p .707 .577 .707 r
F P
0 g
s
.6407 .69535 m .6377 .64233 L .66518 .64738 L p .707 .577 .707 r
F P
0 g
s
.34083 .79044 m .33889 .7739 L .31523 .78672 L p .707 .577 .707 r
F P
0 g
s
.28556 .76305 m .29026 .79489 L .31917 .78467 L p .707 .577 .707 r
F P
0 g
s
.31917 .78467 m .31447 .75283 L .28556 .76305 L p .707 .577 .707 r
F P
0 g
s
.3719 .8035 m .37916 .29709 L .36138 .28712 L p .707 .577 .707 r
F P
0 g
s
.37916 .29709 m .3719 .8035 L .40163 .81186 L p .707 .577 .707 r
F P
0 g
s
.25647 .81675 m .25453 .80021 L .22343 .79957 L p .707 .577 .707 r
F P
0 g
s
.22765 .79968 m .22295 .76784 L .19539 .76193 L p .707 .577 .707 r
F P
0 g
s
.22295 .76784 m .22765 .79968 L .25872 .80007 L p .707 .577 .707 r
F P
0 g
s
.68828 .74982 m .69021 .76636 L .66895 .75625 L p .707 .577 .707 r
F P
0 g
s
.66895 .75625 m .66702 .73971 L .68828 .74982 L p .707 .577 .707 r
F P
0 g
s
.35676 .77513 m .35482 .75859 L .33889 .7739 L p .707 .577 .707 r
F P
0 g
s
.31447 .75283 m .31917 .78467 L .34264 .77039 L p .707 .577 .707 r
F P
0 g
s
.34264 .77039 m .33794 .73855 L .31447 .75283 L p .707 .577 .707 r
F P
0 g
s
.25453 .80021 m .25647 .81675 L .2881 .81232 L p .707 .577 .707 r
F P
0 g
s
.28616 .79578 m .2881 .81232 L .31717 .80325 L p .707 .577 .707 r
F P
0 g
s
.17396 .72306 m .17096 .67003 L .15829 .65916 L p .707 .577 .707 r
F P
0 g
s
.17096 .67003 m .17396 .72306 L .19507 .73143 L p .707 .577 .707 r
F P
0 g
s
.22536 .81611 m .22343 .79957 L .1959 .79392 L p .707 .577 .707 r
F P
0 g
s
.22343 .79957 m .22536 .81611 L .25647 .81675 L p .707 .577 .707 r
F P
0 g
s
.31523 .78672 m .31717 .80325 L .34083 .79044 L p .707 .577 .707 r
F P
0 g
s
.20009 .79378 m .19539 .76193 L .17404 .75108 L p .707 .577 .707 r
F P
0 g
s
.19539 .76193 m .20009 .79378 L .22765 .79968 L p .707 .577 .707 r
F P
0 g
s
.35199 .65467 m .35498 .70769 L .36195 .69515 L p .707 .577 .707 r
F P
0 g
s
.36195 .69515 m .35895 .64213 L .35199 .65467 L p .707 .577 .707 r
F P
0 g
s
.63512 .29508 m .62786 .80149 L .63785 .7913 L p .707 .577 .707 r
F P
0 g
s
.63785 .7913 m .64511 .28489 L .63512 .29508 L p .707 .577 .707 r
F P
0 g
s
.35588 .75612 m .35835 .75345 L p .35525 .75119 L .707 .577 .707 r
F P
0 g
s
.35835 .75345 m .35365 .72161 L .33794 .73855 L p .707 .577 .707 r
F P
0 g
s
.35365 .72161 m .35835 .75345 L .36141 .74494 L p .707 .577 .707 r
F P
0 g
s
.36141 .74494 m .36478 .73552 L p .36138 .73126 L .707 .577 .707 r
F P
0 g
s
.36138 .73126 m .35365 .72161 L .36141 .74494 L .707 .577 .707 r
F
.35587 .75602 m .35482 .75859 L p .3562 .75863 L F P
0 g
s
.33794 .73855 m .34264 .77039 L .35588 .75612 L p .707 .577 .707 r
F P
0 g
s
.35525 .75119 m .33794 .73855 L .35588 .75612 L .707 .577 .707 r
F
.33889 .7739 m .34083 .79044 L .35676 .77513 L p F P
0 g
s
.36478 .73552 m .36009 .70368 L .35365 .72161 L p .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35895 .64213 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35895 .68284 m .35878 .67989 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35595 .62982 L p .35895 .68047 L .707 .577 .707 r
F P
0 g
s
.35595 .62982 m .35878 .67989 L p .34628 .67197 L .707 .577 .707 r
F P
0 g
s
.35878 .67989 m .35895 .68284 L .35862 .68256 L p .707 .577 .707 r
F P
0 g
s
.35862 .68256 m .34628 .67197 L p .35878 .67989 L .707 .577 .707 r
F P
0 g
s
.34628 .67197 m .34328 .61894 L .35595 .62982 L p .707 .577 .707 r
F P
0 g
s
.3566 .68651 m .3585 .69941 L p .34824 .70362 L .707 .577 .707 r
F P
0 g
s
.3585 .69941 m .3613 .71835 L .35663 .71308 L p .707 .577 .707 r
F P
0 g
s
.35663 .71308 m .34824 .70362 L p .3585 .69941 L .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35231 .78885 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.34824 .70362 m .34354 .67178 L .3566 .68651 L p .707 .577 .707 r
F P
0 g
s
.35817 .72657 m .36011 .74311 L .35668 .73951 L p .707 .577 .707 r
F P
0 g
s
.35668 .73951 m .3472 .72954 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.35807 .7266 m .35817 .72657 L .35668 .73951 L .707 .577 .707 r
F
.3472 .72954 m .34527 .713 L .35808 .72648 L p F P
0 g
s
.35808 .72648 m .35817 .72657 L p .35807 .7266 L .707 .577 .707 r
F P
0 g
s
.3472 .72954 m .35808 .72648 L .35807 .7266 L .707 .577 .707 r
F
.35431 .76163 m .35589 .66982 L .35489 .66636 L F
.35412 .79352 m .35461 .7588 L p .35431 .76163 L F P
0 g
s
.35461 .7588 m .35589 .66982 L p .35431 .76163 L .707 .577 .707 r
F P
0 g
s
.35436 .75438 m .35728 .27652 L .3524 .77946 L .707 .577 .707 r
F
.35344 .76971 m .3524 .77946 L .35231 .78885 L F
.35436 .75438 m .3524 .77946 L .35344 .76971 L F
.35728 .27652 m .35036 .75887 L p .35277 .7413 L F P
0 g
s
.35036 .75887 m .35002 .78293 L p .35277 .7413 L .707 .577 .707 r
F P
0 g
s
.35231 .78885 m .35412 .79352 L p .35436 .75438 L .707 .577 .707 r
F P
0 g
s
.35489 .66636 m .3605 .34794 L .35728 .27652 L .707 .577 .707 r
F
.35589 .66982 m .3605 .34794 L p .35489 .66636 L F P
0 g
s
.3605 .34794 m .36138 .28712 L .36036 .28449 L p .707 .577 .707 r
F P
0 g
s
.36036 .28449 m .35728 .27652 L p .3605 .34794 L .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .36147 .74228 L .35587 .75602 L p .707 .577 .707 r
F P
0 g
s
.3634 .75882 m .35587 .75602 L .3562 .75863 L .707 .577 .707 r
F
.1959 .79392 m .19783 .81046 L .22536 .81611 L p F P
0 g
s
.66702 .73971 m .66895 .75625 L .64143 .7506 L p .707 .577 .707 r
F P
0 g
s
.64143 .7506 m .63949 .73406 L .66702 .73971 L p .707 .577 .707 r
F P
0 g
s
.19783 .81046 m .1959 .79392 L .17464 .78381 L p .707 .577 .707 r
F P
0 g
s
.15829 .65916 m .16128 .71218 L .17396 .72306 L p .707 .577 .707 r
F P
0 g
s
.16128 .71218 m .15829 .65916 L .15529 .64685 L p .707 .577 .707 r
F P
0 g
s
.17464 .78381 m .17658 .80035 L .19783 .81046 L p .707 .577 .707 r
F P
0 g
s
.35895 .64213 m .36195 .69515 L .35895 .68284 L p .707 .577 .707 r
F P
0 g
s
.35482 .75859 m .35676 .77513 L .3634 .75882 L p .707 .577 .707 r
F P
0 g
s
.36009 .70368 m .36478 .73552 L .3613 .71835 L p .707 .578 .707 r
F P
0 g
s
.3613 .71835 m .3566 .68651 L .36009 .70368 L p .707 .578 .707 r
F P
0 g
s
.36147 .74228 m .3634 .75882 L .36011 .74311 L p .707 .577 .707 r
F P
0 g
s
.36011 .74311 m .35817 .72657 L .36147 .74228 L p .707 .577 .707 r
F P
0 g
s
.36138 .28712 m .35412 .79352 L .3719 .8035 L p .707 .577 .707 r
F P
0 g
s
.17404 .75108 m .17874 .78292 L .20009 .79378 L p .707 .577 .707 r
F P
0 g
s
.17874 .78292 m .17404 .75108 L .16098 .73635 L p .707 .577 .707 r
F P
0 g
s
.17658 .80035 m .17464 .78381 L .16174 .77024 L p .707 .577 .707 r
F P
0 g
s
.15529 .64685 m .15828 .69987 L .16128 .71218 L p .707 .577 .707 r
F P
0 g
s
.16174 .77024 m .16367 .78678 L .17658 .80035 L p .707 .577 .707 r
F P
0 g
s
.16098 .73635 m .16568 .76819 L .17874 .78292 L p .707 .577 .707 r
F P
0 g
s
.64511 .28489 m .63785 .7913 L .63375 .7807 L p .707 .577 .707 r
F P
0 g
s
.63375 .7807 m .64101 .27429 L .64511 .28489 L p .707 .577 .707 r
F P
0 g
s
.16568 .76819 m .16098 .73635 L .15749 .71918 L p .707 .578 .707 r
F P
0 g
s
.15828 .69987 m .15529 .64685 L .16225 .63431 L p .707 .577 .707 r
F P
0 g
s
.16367 .78678 m .16174 .77024 L .15844 .75453 L p .707 .577 .707 r
F P
0 g
s
.35002 .78293 m .35728 .27652 L .36726 .26633 L p .707 .577 .707 r
F P
0 g
s
.15844 .75453 m .16038 .77107 L .16367 .78678 L p .707 .577 .707 r
F P
0 g
s
.15749 .71918 m .16219 .75102 L .16568 .76819 L p .707 .578 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16225 .63431 m .16525 .68733 L .15828 .69987 L p .707 .577 .707 r
F P
0 g
s
.16219 .75102 m .15749 .71918 L .16392 .70125 L p .707 .577 .707 r
F P
0 g
s
.16525 .68733 m .16225 .63431 L .17851 .62276 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1676 .73582 m .18102 .72291 L p .16944 .74926 L .707 .577 .707 r
F P
0 g
s
.16392 .70125 m .16862 .73309 L .16761 .73591 L p .707 .577 .707 r
F P
0 g
s
.16761 .73591 m .16219 .75102 L p .16371 .70747 L .707 .577 .707 r
F P
0 g
s
.16371 .70747 m .16392 .70125 L .16761 .73591 L .707 .577 .707 r
F
.16702 .75476 m .16509 .73823 L .1676 .73582 L p F P
0 g
s
.16702 .75476 m .1676 .73582 L .16944 .74926 L .707 .577 .707 r
F
.16038 .77107 m .15844 .75453 L .16509 .73823 L p F P
0 g
s
.32218 .66092 m .34354 .67178 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32688 .69277 m .32677 .69202 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32677 .69202 m .32218 .66092 L p .32705 .69255 L .707 .577 .707 r
F P
0 g
s
.32218 .66092 m .32688 .69277 L .29932 .68686 L p .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .32218 .66092 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29932 .68686 m .29927 .68652 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29927 .68652 m .29462 .65502 L p .29943 .68674 L .707 .577 .707 r
F P
0 g
s
.29462 .65502 m .29932 .68686 L .26825 .68647 L p .707 .577 .707 r
F P
0 g
s
.26355 .65463 m .29462 .65502 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26825 .68647 m .26814 .68573 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.26814 .68573 m .26355 .65463 L p .2685 .68618 L .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .26355 .65463 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23672 .69165 m .23643 .68973 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.23643 .68973 m .23202 .65981 L p .23727 .69088 L .707 .577 .707 r
F P
0 g
s
.2078 .70188 m .2031 .67003 L .23202 .65981 L p .707 .577 .707 r
F P
0 g
s
.23202 .65981 m .23672 .69165 L .2078 .70188 L p .707 .577 .707 r
F P
0 g
s
.23176 .60697 m .23475 .66 L .21754 .66374 L p .707 .577 .707 r
F P
0 g
s
.21754 .66374 m .20545 .66637 L p .21075 .65441 L .707 .577 .707 r
F P
0 g
s
.21075 .65441 m .23176 .60697 L .21754 .66374 L .707 .577 .707 r
F
.26355 .65463 m .26825 .68647 L .23672 .69165 L p F P
0 g
s
.26354 .60428 m .26654 .6573 L .24697 .65896 L p .707 .577 .707 r
F P
0 g
s
.24697 .65896 m .23475 .66 L p .2399 .65003 L .707 .577 .707 r
F P
0 g
s
.2399 .65003 m .26354 .60428 L .24697 .65896 L .707 .577 .707 r
F
.29469 .60551 m .29769 .65854 L .27916 .6578 L p F P
0 g
s
.27916 .6578 m .26654 .6573 L p .2719 .64744 L .707 .577 .707 r
F P
0 g
s
.2719 .64744 m .29469 .60551 L .27916 .6578 L .707 .577 .707 r
F
.32217 .61057 m .32517 .66359 L .31045 .66089 L p F P
0 g
s
.31045 .66089 m .29769 .65854 L p .30338 .64739 L .707 .577 .707 r
F P
0 g
s
.30338 .64739 m .32217 .61057 L .31045 .66089 L .707 .577 .707 r
F
.34328 .61894 m .34628 .67197 L .32517 .66359 L p F P
0 g
s
.32517 .66359 m .32217 .61057 L .34328 .61894 L p .707 .577 .707 r
F P
0 g
s
.64101 .27429 m .63375 .7807 L .61596 .77073 L p .707 .577 .707 r
F P
0 g
s
.61596 .77073 m .62322 .26432 L .64101 .27429 L p .707 .577 .707 r
F P
0 g
s
.16509 .73823 m .16702 .75476 L .16038 .77107 L p .707 .577 .707 r
F P
0 g
s
.17851 .62276 m .18151 .67579 L .16525 .68733 L p .707 .577 .707 r
F P
0 g
s
.16862 .73309 m .16392 .70125 L .17964 .68431 L p .707 .577 .707 r
F P
0 g
s
.18151 .67579 m .17851 .62276 L .20246 .61334 L p .707 .577 .707 r
F P
0 g
s
.34354 .67178 m .34824 .70362 L .32688 .69277 L p .707 .577 .707 r
F P
0 g
s
.36 .77274 m .36726 .26633 L .39036 .25755 L p .707 .577 .707 r
F P
0 g
s
.36726 .26633 m .36 .77274 L .35002 .78293 L p .707 .577 .707 r
F P
0 g
s
.29769 .65854 m .29469 .60551 L .32217 .61057 L p .707 .577 .707 r
F P
0 g
s
.34527 .713 m .3472 .72954 L .32595 .71943 L p .707 .577 .707 r
F P
0 g
s
.32595 .71943 m .32401 .7029 L .34527 .713 L p .707 .577 .707 r
F P
0 g
s
.20545 .66637 m .20246 .61334 L .23176 .60697 L p .707 .577 .707 r
F P
0 g
s
.20246 .61334 m .20545 .66637 L .18151 .67579 L p .707 .577 .707 r
F P
0 g
s
.17964 .68431 m .18434 .71615 L .16862 .73309 L p .707 .577 .707 r
F P
0 g
s
.18434 .71615 m .17964 .68431 L .2031 .67003 L p .707 .577 .707 r
F P
0 g
s
.18102 .72291 m .18295 .73945 L .16702 .75476 L p .707 .577 .707 r
F P
0 g
s
.26654 .6573 m .26354 .60428 L .29469 .60551 L p .707 .577 .707 r
F P
0 g
s
.62322 .26432 m .61596 .77073 L .58623 .76236 L p .707 .577 .707 r
F P
0 g
s
.58623 .76236 m .59349 .25595 L .62322 .26432 L p .707 .577 .707 r
F P
0 g
s
.23475 .66 m .23176 .60697 L .26354 .60428 L p .707 .577 .707 r
F P
0 g
s
.18295 .73945 m .18102 .72291 L .20468 .7101 L p .707 .577 .707 r
F P
0 g
s
.73391 .65728 m .73091 .60425 L .69976 .60301 L p .707 .577 .707 r
F P
0 g
s
.73091 .60425 m .73391 .65728 L .76569 .65458 L p .707 .577 .707 r
F P
0 g
s
.76569 .65458 m .7627 .60156 L .73091 .60425 L p .707 .577 .707 r
F P
0 g
s
.2031 .67003 m .2078 .70188 L .18434 .71615 L p .707 .577 .707 r
F P
0 g
s
.7627 .60156 m .76569 .65458 L .79499 .64821 L p .707 .577 .707 r
F P
0 g
s
.79499 .64821 m .792 .59519 L .7627 .60156 L p .707 .577 .707 r
F P
0 g
s
.32401 .7029 m .32595 .71943 L .29842 .71378 L p .707 .577 .707 r
F P
0 g
s
.29842 .71378 m .29648 .69725 L .32401 .7029 L p .707 .577 .707 r
F P
0 g
s
.70276 .65604 m .69976 .60301 L .67228 .59796 L p .707 .577 .707 r
F P
0 g
s
.69976 .60301 m .70276 .65604 L .73391 .65728 L p .707 .577 .707 r
F P
0 g
s
.39036 .25755 m .3831 .76395 L .36 .77274 L p .707 .577 .707 r
F P
0 g
s
.3831 .76395 m .39036 .25755 L .42431 .25103 L p .707 .577 .707 r
F P
0 g
s
.20468 .7101 m .20661 .72664 L .18295 .73945 L p .707 .577 .707 r
F P
0 g
s
.792 .59519 m .79499 .64821 L .81894 .63879 L p .707 .577 .707 r
F P
0 g
s
.81894 .63879 m .81595 .58577 L .792 .59519 L p .707 .577 .707 r
F P
0 g
s
.20661 .72664 m .20468 .7101 L .23375 .70103 L p .707 .577 .707 r
F P
0 g
s
.29648 .69725 m .29842 .71378 L .26732 .71314 L p .707 .577 .707 r
F P
0 g
s
.26732 .71314 m .26538 .6966 L .29648 .69725 L p .707 .577 .707 r
F P
0 g
s
.67528 .65098 m .67228 .59796 L .65117 .58959 L p .707 .577 .707 r
F P
0 g
s
.67228 .59796 m .67528 .65098 L .70276 .65604 L p .707 .577 .707 r
F P
0 g
s
.23375 .70103 m .23568 .71757 L .20661 .72664 L p .707 .577 .707 r
F P
0 g
s
.23568 .71757 m .23375 .70103 L .26538 .6966 L p .707 .577 .707 r
F P
0 g
s
.59349 .25595 m .58623 .76236 L .54747 .75641 L p .707 .577 .707 r
F P
0 g
s
.54747 .75641 m .55473 .25001 L .59349 .25595 L p .707 .577 .707 r
F P
0 g
s
.26538 .6966 m .26732 .71314 L .23568 .71757 L p .707 .577 .707 r
F P
0 g
s
.81595 .58577 m .81894 .63879 L .8352 .62725 L p .707 .577 .707 r
F P
0 g
s
.8352 .62725 m .8322 .57422 L .81595 .58577 L p .707 .577 .707 r
F P
0 g
s
.41705 .75744 m .42431 .25103 L .46578 .24742 L p .707 .577 .707 r
F P
0 g
s
.42431 .25103 m .41705 .75744 L .3831 .76395 L p .707 .577 .707 r
F P
0 g
s
.73893 .74279 m .73424 .71095 L .70317 .71057 L p .707 .577 .707 r
F P
0 g
s
.73424 .71095 m .73893 .74279 L .77047 .73762 L p .707 .577 .707 r
F P
0 g
s
.77047 .73762 m .76577 .70578 L .73424 .71095 L p .707 .577 .707 r
F P
0 g
s
.76577 .70578 m .77047 .73762 L .79939 .72739 L p .707 .577 .707 r
F P
0 g
s
.79939 .72739 m .79469 .69555 L .76577 .70578 L p .707 .577 .707 r
F P
0 g
s
.65417 .64261 m .65117 .58959 L .6385 .57871 L p .707 .577 .707 r
F P
0 g
s
.65117 .58959 m .65417 .64261 L .67528 .65098 L p .707 .577 .707 r
F P
0 g
s
.70787 .74241 m .70317 .71057 L .67561 .70466 L p .707 .577 .707 r
F P
0 g
s
.70317 .71057 m .70787 .74241 L .73893 .74279 L p .707 .577 .707 r
F P
0 g
s
.79469 .69555 m .79939 .72739 L .82285 .71311 L p .707 .577 .707 r
F P
0 g
s
.82285 .71311 m .81815 .68127 L .79469 .69555 L p .707 .577 .707 r
F P
0 g
s
.55473 .25001 m .54747 .75641 L .50346 .75347 L p .707 .577 .707 r
F P
0 g
s
.50346 .75347 m .51072 .24707 L .55473 .25001 L p .707 .577 .707 r
F P
0 g
s
.45852 .75383 m .46578 .24742 L .51072 .24707 L p .707 .577 .707 r
F P
0 g
s
.46578 .24742 m .45852 .75383 L .41705 .75744 L p .707 .577 .707 r
F P
0 g
s
.8322 .57422 m .8352 .62725 L .84216 .61471 L p .707 .577 .707 r
F P
0 g
s
.84216 .61471 m .83917 .56168 L .8322 .57422 L p .707 .577 .707 r
F P
0 g
s
.51072 .24707 m .50346 .75347 L .45852 .75383 L p .707 .577 .707 r
F P
0 g
s
.73668 .80331 m .73474 .78677 L .70364 .78613 L p .707 .577 .707 r
F P
0 g
s
.73474 .78677 m .73668 .80331 L .76831 .79888 L p .707 .577 .707 r
F P
0 g
s
.76831 .79888 m .76638 .78234 L .73474 .78677 L p .707 .577 .707 r
F P
0 g
s
.6803 .7365 m .67561 .70466 L .65425 .69381 L p .707 .577 .707 r
F P
0 g
s
.67561 .70466 m .6803 .7365 L .70787 .74241 L p .707 .577 .707 r
F P
0 g
s
.76638 .78234 m .76831 .79888 L .79738 .78981 L p .707 .577 .707 r
F P
0 g
s
.79738 .78981 m .79545 .77327 L .76638 .78234 L p .707 .577 .707 r
F P
0 g
s
.81815 .68127 m .82285 .71311 L .83857 .69618 L p .707 .577 .707 r
F P
0 g
s
.83857 .69618 m .83387 .66434 L .81815 .68127 L p .707 .577 .707 r
F P
0 g
s
.6385 .57871 m .6415 .63174 L .65417 .64261 L p .707 .577 .707 r
F P
0 g
s
.70558 .80266 m .70364 .78613 L .67611 .78048 L p .707 .577 .707 r
F P
0 g
s
.70364 .78613 m .70558 .80266 L .73668 .80331 L p .707 .577 .707 r
F P
0 g
s
.79545 .77327 m .79738 .78981 L .82104 .777 L p .707 .577 .707 r
F P
0 g
s
.82104 .777 m .8191 .76046 L .79545 .77327 L p .707 .577 .707 r
F P
0 g
s
.6415 .63174 m .6385 .57871 L .6355 .5664 L p .707 .577 .707 r
F P
0 g
s
.67611 .78048 m .67805 .79701 L .70558 .80266 L p .707 .577 .707 r
F P
0 g
s
.65425 .69381 m .65895 .72565 L .6803 .7365 L p .707 .577 .707 r
F P
0 g
s
.65895 .72565 m .65425 .69381 L .64119 .67908 L p .707 .577 .707 r
F P
0 g
s
.67805 .79701 m .67611 .78048 L .65486 .77037 L p .707 .577 .707 r
F P
0 g
s
.83917 .56168 m .84216 .61471 L .83916 .6024 L p .707 .577 .707 r
F P
0 g
s
.83916 .6024 m .83617 .54937 L .83917 .56168 L p .707 .577 .707 r
F P
0 g
s
.83387 .66434 m .83857 .69618 L .845 .67825 L p .707 .577 .707 r
F P
0 g
s
.845 .67825 m .8403 .64641 L .83387 .66434 L p .707 .577 .707 r
F P
0 g
s
.8191 .76046 m .82104 .777 L .83697 .76168 L p .707 .577 .707 r
F P
0 g
s
.83697 .76168 m .83504 .74515 L .8191 .76046 L p .707 .577 .707 r
F P
0 g
s
.65486 .77037 m .65679 .78691 L .67805 .79701 L p .707 .577 .707 r
F P
0 g
s
.6355 .5664 m .6385 .61943 L .6415 .63174 L p .707 .577 .707 r
F P
0 g
s
.6385 .61943 m .6355 .5664 L .64247 .55386 L p .707 .577 .707 r
F P
0 g
s
.64119 .67908 m .64589 .71092 L .65895 .72565 L p .707 .577 .707 r
F P
0 g
s
.65679 .78691 m .65486 .77037 L .64195 .7568 L p .707 .577 .707 r
F P
0 g
s
.64589 .71092 m .64119 .67908 L .63771 .6619 L p .707 .578 .707 r
F P
0 g
s
.83504 .74515 m .83697 .76168 L .84361 .74538 L p .707 .577 .707 r
F P
0 g
s
.84361 .74538 m .84168 .72884 L .83504 .74515 L p .707 .577 .707 r
F P
0 g
s
.8403 .64641 m .845 .67825 L .84151 .66107 L p .707 .578 .707 r
F P
0 g
s
.84151 .66107 m .83681 .62923 L .8403 .64641 L p .707 .578 .707 r
F P
0 g
s
.64195 .7568 m .64388 .77334 L .65679 .78691 L p .707 .577 .707 r
F P
0 g
s
.83617 .54937 m .83916 .6024 L .82649 .59152 L p .707 .577 .707 r
F P
0 g
s
.82649 .59152 m .82349 .5385 L .83617 .54937 L p .707 .577 .707 r
F P
0 g
s
.64247 .55386 m .64546 .60688 L .6385 .61943 L p .707 .577 .707 r
F P
0 g
s
.63771 .6619 m .6424 .69374 L .64589 .71092 L p .707 .578 .707 r
F P
0 g
s
.64546 .60688 m .64247 .55386 L .65872 .54231 L p .707 .577 .707 r
F P
0 g
s
.64388 .77334 m .64195 .7568 L .63866 .74109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.3909 .62046 m .3879 .56744 L .35675 .5662 L p .707 .577 .707 r
F P
0 g
s
.3879 .56744 m .3909 .62046 L .42268 .61777 L p .707 .577 .707 r
F P
0 g
s
.42268 .61777 m .41969 .56474 L .3879 .56744 L p .707 .577 .707 r
F P
0 g
s
.6424 .69374 m .63771 .6619 L .64414 .64397 L p .707 .577 .707 r
F P
0 g
s
.41969 .56474 m .42268 .61777 L .45198 .6114 L p .707 .577 .707 r
F P
0 g
s
.45198 .6114 m .44899 .55837 L .41969 .56474 L p .707 .577 .707 r
F P
0 g
s
.84168 .72884 m .84361 .74538 L .84032 .72967 L p .707 .577 .707 r
F P
0 g
s
.84032 .72967 m .83839 .71313 L .84168 .72884 L p .707 .577 .707 r
F P
0 g
s
.83681 .62923 m .84151 .66107 L .82845 .64634 L p .707 .577 .707 r
F P
0 g
s
.82845 .64634 m .82375 .6145 L .83681 .62923 L p .707 .577 .707 r
F P
0 g
s
.35975 .61922 m .35675 .5662 L .32927 .56114 L p .707 .577 .707 r
F P
0 g
s
.35675 .5662 m .35975 .61922 L .3909 .62046 L p .707 .577 .707 r
F P
0 g
s
.63866 .74109 m .64059 .75763 L .64388 .77334 L p .707 .577 .707 r
F P
0 g
s
.82349 .5385 m .82649 .59152 L .80538 .58315 L p .707 .577 .707 r
F P
0 g
s
.80538 .58315 m .80238 .53012 L .82349 .5385 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44899 .55837 m .45198 .6114 L .47593 .60198 L p .707 .577 .707 r
F P
0 g
s
.47593 .60198 m .47294 .54895 L .44899 .55837 L p .707 .577 .707 r
F P
0 g
s
.65872 .54231 m .66172 .59534 L .64546 .60688 L p .707 .577 .707 r
F P
0 g
s
.33227 .61417 m .32927 .56114 L .30816 .55277 L p .707 .577 .707 r
F P
0 g
s
.32927 .56114 m .33227 .61417 L .35975 .61922 L p .707 .577 .707 r
F P
0 g
s
.64414 .64397 m .64883 .67581 L .6424 .69374 L p .707 .577 .707 r
F P
0 g
s
.66172 .59534 m .65872 .54231 L .68267 .5329 L p .707 .577 .707 r
F P
0 g
s
.64059 .75763 m .63866 .74109 L .6453 .72478 L p .707 .577 .707 r
F P
0 g
s
.64883 .67581 m .64414 .64397 L .65985 .62704 L p .707 .577 .707 r
F P
0 g
s
.82375 .6145 m .82845 .64634 L .8071 .63549 L p .707 .577 .707 r
F P
0 g
s
.8071 .63549 m .8024 .60365 L .82375 .6145 L p .707 .577 .707 r
F P
0 g
s
.47294 .54895 m .47593 .60198 L .49219 .59043 L p .707 .577 .707 r
F P
0 g
s
.49219 .59043 m .48919 .53741 L .47294 .54895 L p .707 .577 .707 r
F P
0 g
s
.80238 .53012 m .80538 .58315 L .7779 .57809 L p .707 .577 .707 r
F P
0 g
s
.7779 .57809 m .77491 .52507 L .80238 .53012 L p .707 .577 .707 r
F P
0 g
s
.83839 .71313 m .84032 .72967 L .82742 .7161 L p .707 .577 .707 r
F P
0 g
s
.82742 .7161 m .82548 .69956 L .83839 .71313 L p .707 .577 .707 r
F P
0 g
s
.6453 .72478 m .64724 .74132 L .64059 .75763 L p .707 .577 .707 r
F P
0 g
s
.39592 .70598 m .39123 .67414 L .36016 .67375 L p .707 .577 .707 r
F P
0 g
s
.39123 .67414 m .39592 .70598 L .42746 .7008 L p .707 .577 .707 r
F P
0 g
s
.42746 .7008 m .42276 .66896 L .39123 .67414 L p .707 .577 .707 r
F P
0 g
s
.42276 .66896 m .42746 .7008 L .45638 .69058 L p .707 .577 .707 r
F P
0 g
s
.45638 .69058 m .45168 .65873 L .42276 .66896 L p .707 .577 .707 r
F P
0 g
s
.68567 .58592 m .68267 .5329 L .71197 .52653 L p .707 .577 .707 r
F P
0 g
s
.68267 .5329 m .68567 .58592 L .66172 .59534 L p .707 .577 .707 r
F P
0 g
s
.31116 .6058 m .30816 .55277 L .29549 .5419 L p .707 .577 .707 r
F P
0 g
s
.30816 .55277 m .31116 .6058 L .33227 .61417 L p .707 .577 .707 r
F P
0 g
s
.36486 .70559 m .36016 .67375 L .3326 .66784 L p .707 .577 .707 r
F P
0 g
s
.36016 .67375 m .36486 .70559 L .39592 .70598 L p .707 .577 .707 r
F P
0 g
s
.45168 .65873 m .45638 .69058 L .47984 .6763 L p .707 .577 .707 r
F P
0 g
s
.47984 .6763 m .47514 .64446 L .45168 .65873 L p .707 .577 .707 r
F P
0 g
s
.77491 .52507 m .7779 .57809 L .74675 .57685 L p .707 .577 .707 r
F P
0 g
s
.74675 .57685 m .74375 .52383 L .77491 .52507 L p .707 .577 .707 r
F P
0 g
s
.65985 .62704 m .66455 .65888 L .64883 .67581 L p .707 .577 .707 r
F P
0 g
s
.66455 .65888 m .65985 .62704 L .68332 .61276 L p .707 .577 .707 r
F P
0 g
s
.64724 .74132 m .6453 .72478 L .66123 .70947 L p .707 .577 .707 r
F P
0 g
s
.71497 .57955 m .71197 .52653 L .74375 .52383 L p .707 .577 .707 r
F P
0 g
s
.71197 .52653 m .71497 .57955 L .68567 .58592 L p .707 .577 .707 r
F P
0 g
s
.8024 .60365 m .8071 .63549 L .77954 .62958 L p .707 .577 .707 r
F P
0 g
s
.77954 .62958 m .77484 .59774 L .8024 .60365 L p .707 .577 .707 r
F P
0 g
s
.74375 .52383 m .74675 .57685 L .71497 .57955 L p .707 .577 .707 r
F P
0 g
s
.48919 .53741 m .49219 .59043 L .49915 .57789 L p .707 .577 .707 r
F P
0 g
s
.49915 .57789 m .49616 .52487 L .48919 .53741 L p .707 .577 .707 r
F P
0 g
s
.82548 .69956 m .82742 .7161 L .80616 .70599 L p .707 .577 .707 r
F P
0 g
s
.80616 .70599 m .80423 .68945 L .82548 .69956 L p .707 .577 .707 r
F P
0 g
s
.39367 .76649 m .39173 .74995 L .36063 .74931 L p .707 .577 .707 r
F P
0 g
s
.39173 .74995 m .39367 .76649 L .4253 .76206 L p .707 .577 .707 r
F P
0 g
s
.4253 .76206 m .42337 .74553 L .39173 .74995 L p .707 .577 .707 r
F P
0 g
s
.33729 .69969 m .3326 .66784 L .31124 .65699 L p .707 .577 .707 r
F P
0 g
s
.3326 .66784 m .33729 .69969 L .36486 .70559 L p .707 .577 .707 r
F P
0 g
s
.42337 .74553 m .4253 .76206 L .45437 .753 L p .707 .577 .707 r
F P
0 g
s
.45437 .753 m .45244 .73646 L .42337 .74553 L p .707 .577 .707 r
F P
0 g
s
.66123 .70947 m .66317 .72601 L .64724 .74132 L p .707 .577 .707 r
F P
0 g
s
.47514 .64446 m .47984 .6763 L .49556 .65936 L p .707 .577 .707 r
F P
0 g
s
.49556 .65936 m .49086 .62752 L .47514 .64446 L p .707 .577 .707 r
F P
0 g
s
.68802 .6446 m .68332 .61276 L .71223 .60253 L p .707 .577 .707 r
F P
0 g
s
.68332 .61276 m .68802 .6446 L .66455 .65888 L p .707 .577 .707 r
F P
0 g
s
.29549 .5419 m .29849 .59492 L .31116 .6058 L p .707 .577 .707 r
F P
0 g
s
.36257 .76585 m .36063 .74931 L .3331 .74366 L p .707 .577 .707 r
F P
0 g
s
.36063 .74931 m .36257 .76585 L .39367 .76649 L p .707 .577 .707 r
F P
0 g
s
.77484 .59774 m .77954 .62958 L .74847 .6292 L p .707 .577 .707 r
F P
0 g
s
.74847 .6292 m .74377 .59736 L .77484 .59774 L p .707 .577 .707 r
F P
0 g
s
.45244 .73646 m .45437 .753 L .47803 .74018 L p .707 .577 .707 r
F P
0 g
s
.47803 .74018 m .47609 .72364 L .45244 .73646 L p .707 .577 .707 r
F P
0 g
s
.29849 .59492 m .29549 .5419 L .29249 .52958 L p .707 .577 .707 r
F P
0 g
s
.71693 .63437 m .71223 .60253 L .74377 .59736 L p .707 .577 .707 r
F P
0 g
s
.71223 .60253 m .71693 .63437 L .68802 .6446 L p .707 .577 .707 r
F P
0 g
s
.74377 .59736 m .74847 .6292 L .71693 .63437 L p .707 .577 .707 r
F P
0 g
s
.66317 .72601 m .66123 .70947 L .68489 .69666 L p .707 .577 .707 r
F P
0 g
s
.3331 .74366 m .33504 .7602 L .36257 .76585 L p .707 .577 .707 r
F P
0 g
s
.80423 .68945 m .80616 .70599 L .77863 .70034 L p .707 .577 .707 r
F P
0 g
s
.77863 .70034 m .7767 .6838 L .80423 .68945 L p .707 .577 .707 r
F P
0 g
s
.31124 .65699 m .31594 .68883 L .33729 .69969 L p .707 .577 .707 r
F P
0 g
s
.31594 .68883 m .31124 .65699 L .29818 .64226 L p .707 .577 .707 r
F P
0 g
s
.33504 .7602 m .3331 .74366 L .31185 .73356 L p .707 .577 .707 r
F P
0 g
s
.49616 .52487 m .49915 .57789 L .49615 .56558 L p .707 .577 .707 r
F P
0 g
s
.49615 .56558 m .49316 .51255 L .49616 .52487 L p .707 .577 .707 r
F P
0 g
s
.68489 .69666 m .68683 .71319 L .66317 .72601 L p .707 .577 .707 r
F P
0 g
s
.49086 .62752 m .49556 .65936 L .50199 .64143 L p .707 .577 .707 r
F P
0 g
s
.50199 .64143 m .49729 .60959 L .49086 .62752 L p .707 .577 .707 r
F P
0 g
s
.47609 .72364 m .47803 .74018 L .49396 .72487 L p .707 .577 .707 r
F P
0 g
s
.49396 .72487 m .49203 .70833 L .47609 .72364 L p .707 .577 .707 r
F P
0 g
s
.31185 .73356 m .31378 .75009 L .33504 .7602 L p .707 .577 .707 r
F P
0 g
s
.68683 .71319 m .68489 .69666 L .71396 .68759 L p .707 .577 .707 r
F P
0 g
s
.29249 .52958 m .29549 .58261 L .29849 .59492 L p .707 .577 .707 r
F P
0 g
s
.7767 .6838 m .77863 .70034 L .74753 .6997 L p .707 .577 .707 r
F P
0 g
s
.74753 .6997 m .74559 .68316 L .7767 .6838 L p .707 .577 .707 r
F P
0 g
s
.29549 .58261 m .29249 .52958 L .29946 .51704 L p .707 .577 .707 r
F P
0 g
s
.71396 .68759 m .7159 .70413 L .68683 .71319 L p .707 .577 .707 r
F P
0 g
s
.7159 .70413 m .71396 .68759 L .74559 .68316 L p .707 .577 .707 r
F P
0 g
s
.29818 .64226 m .30288 .6741 L .31594 .68883 L p .707 .577 .707 r
F P
0 g
s
.74559 .68316 m .74753 .6997 L .7159 .70413 L p .707 .577 .707 r
F P
0 g
s
.31378 .75009 m .31185 .73356 L .29894 .71998 L p .707 .577 .707 r
F P
0 g
s
.30288 .6741 m .29818 .64226 L .29469 .62509 L p .707 .578 .707 r
F P
0 g
s
.49203 .70833 m .49396 .72487 L .5006 .70856 L p .707 .577 .707 r
F P
0 g
s
.5006 .70856 m .49867 .69202 L .49203 .70833 L p .707 .577 .707 r
F P
0 g
s
.49729 .60959 m .50199 .64143 L .4985 .62426 L p .707 .578 .707 r
F P
0 g
s
.4985 .62426 m .4938 .59242 L .49729 .60959 L p .707 .578 .707 r
F P
0 g
s
.29894 .71998 m .30087 .73652 L .31378 .75009 L p .707 .577 .707 r
F P
0 g
s
.49316 .51255 m .49615 .56558 L .48348 .55471 L p .707 .577 .707 r
F P
0 g
s
.48348 .55471 m .48048 .50168 L .49316 .51255 L p .707 .577 .707 r
F P
0 g
s
.29946 .51704 m .30245 .57007 L .29549 .58261 L p .707 .577 .707 r
F P
0 g
s
.29469 .62509 m .29939 .65693 L .30288 .6741 L p .707 .578 .707 r
F P
0 g
s
.30245 .57007 m .29946 .51704 L .31571 .5055 L p .707 .577 .707 r
F P
0 g
s
.30087 .73652 m .29894 .71998 L .29565 .70428 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29939 .65693 m .29469 .62509 L .30113 .60716 L p .707 .577 .707 r
F P
0 g
s
.49867 .69202 m .5006 .70856 L .49731 .69285 L p .707 .577 .707 r
F P
0 g
s
.49731 .69285 m .49538 .67632 L .49867 .69202 L p .707 .577 .707 r
F P
0 g
s
.4938 .59242 m .4985 .62426 L .48544 .60953 L p .707 .577 .707 r
F P
0 g
s
.48544 .60953 m .48074 .57768 L .4938 .59242 L p .707 .577 .707 r
F P
0 g
s
.29565 .70428 m .29758 .72081 L .30087 .73652 L p .707 .577 .707 r
F P
0 g
s
.48048 .50168 m .48348 .55471 L .46237 .54633 L p .707 .577 .707 r
F P
0 g
s
.46237 .54633 m .45937 .49331 L .48048 .50168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31571 .5055 m .31871 .55852 L .30245 .57007 L p .707 .577 .707 r
F P
0 g
s
.30113 .60716 m .30582 .639 L .29939 .65693 L p .707 .577 .707 r
F P
0 g
s
.31871 .55852 m .31571 .5055 L .33966 .49608 L p .707 .577 .707 r
F P
0 g
s
.29758 .72081 m .29565 .70428 L .30229 .68797 L p .707 .577 .707 r
F P
0 g
s
.30582 .639 m .30113 .60716 L .31684 .59022 L p .707 .577 .707 r
F P
0 g
s
.48074 .57768 m .48544 .60953 L .46409 .59867 L p .707 .577 .707 r
F P
0 g
s
.46409 .59867 m .45939 .56683 L .48074 .57768 L p .707 .577 .707 r
F P
0 g
s
.45937 .49331 m .46237 .54633 L .43489 .54128 L p .707 .577 .707 r
F P
0 g
s
.43489 .54128 m .4319 .48825 L .45937 .49331 L p .707 .577 .707 r
F P
0 g
s
.49538 .67632 m .49731 .69285 L .48441 .67928 L p .707 .577 .707 r
F P
0 g
s
.48441 .67928 m .48247 .66274 L .49538 .67632 L p .707 .577 .707 r
F P
0 g
s
.30229 .68797 m .30423 .70451 L .29758 .72081 L p .707 .577 .707 r
F P
0 g
s
.34266 .54911 m .33966 .49608 L .36896 .48971 L p .707 .577 .707 r
F P
0 g
s
.33966 .49608 m .34266 .54911 L .31871 .55852 L p .707 .577 .707 r
F P
0 g
s
.4319 .48825 m .43489 .54128 L .40374 .54004 L p .707 .577 .707 r
F P
0 g
s
.40374 .54004 m .40074 .48701 L .4319 .48825 L p .707 .577 .707 r
F P
0 g
s
.31684 .59022 m .32154 .62206 L .30582 .639 L p .707 .577 .707 r
F P
0 g
s
.32154 .62206 m .31684 .59022 L .34031 .57594 L p .707 .577 .707 r
F P
0 g
s
.30423 .70451 m .30229 .68797 L .31822 .67266 L p .707 .577 .707 r
F P
0 g
s
.37196 .54274 m .36896 .48971 L .40074 .48701 L p .707 .577 .707 r
F P
0 g
s
.36896 .48971 m .37196 .54274 L .34266 .54911 L p .707 .577 .707 r
F P
0 g
s
.45939 .56683 m .46409 .59867 L .43653 .59277 L p .707 .577 .707 r
F P
0 g
s
.43653 .59277 m .43183 .56093 L .45939 .56683 L p .707 .577 .707 r
F P
0 g
s
.40074 .48701 m .40374 .54004 L .37196 .54274 L p .707 .577 .707 r
F P
0 g
s
.48247 .66274 m .48441 .67928 L .46315 .66918 L p .707 .577 .707 r
F P
0 g
s
.46315 .66918 m .46121 .65264 L .48247 .66274 L p .707 .577 .707 r
F P
0 g
s
.31822 .67266 m .32016 .68919 L .30423 .70451 L p .707 .577 .707 r
F P
0 g
s
.34501 .60778 m .34031 .57594 L .36922 .56572 L p .707 .577 .707 r
F P
0 g
s
.34031 .57594 m .34501 .60778 L .32154 .62206 L p .707 .577 .707 r
F P
0 g
s
.43183 .56093 m .43653 .59277 L .40546 .59238 L p .707 .577 .707 r
F P
0 g
s
.40546 .59238 m .40076 .56054 L .43183 .56093 L p .707 .577 .707 r
F P
0 g
s
.37392 .59756 m .36922 .56572 L .40076 .56054 L p .707 .577 .707 r
F P
0 g
s
.36922 .56572 m .37392 .59756 L .34501 .60778 L p .707 .577 .707 r
F P
0 g
s
.40076 .56054 m .40546 .59238 L .37392 .59756 L p .707 .577 .707 r
F P
0 g
s
.32016 .68919 m .31822 .67266 L .34188 .65984 L p .707 .577 .707 r
F P
0 g
s
.46121 .65264 m .46315 .66918 L .43562 .66353 L p .707 .577 .707 r
F P
0 g
s
.43562 .66353 m .43369 .64699 L .46121 .65264 L p .707 .577 .707 r
F P
0 g
s
.34188 .65984 m .34382 .67638 L .32016 .68919 L p .707 .577 .707 r
F P
0 g
s
.34382 .67638 m .34188 .65984 L .37095 .65077 L p .707 .577 .707 r
F P
0 g
s
.43369 .64699 m .43562 .66353 L .40452 .66288 L p .707 .577 .707 r
F P
0 g
s
.40452 .66288 m .40258 .64635 L .43369 .64699 L p .707 .577 .707 r
F P
0 g
s
.37095 .65077 m .37288 .66731 L .34382 .67638 L p .707 .577 .707 r
F P
0 g
s
.37288 .66731 m .37095 .65077 L .40258 .64635 L p .707 .577 .707 r
F P
0 g
s
.40258 .64635 m .40452 .66288 L .37288 .66731 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolH0026Ool007Ioo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEP`007Yoo`00
LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF1`00
Lgoo001]Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUH00002001`Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00J7oo0P0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P00Jgoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008006Moo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEPl000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Moo`03001JEP0000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol01@00FUIJEUYF00001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`T004Eoo`00E7oo0P000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF009JEPP003eoo`00Dgoo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD0
03Qoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo10001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`00=Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20008Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000UJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00MJEP@000AJEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPD0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo001COol00`00FUH00004FUH00`00FUH000030004Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH01eYF100000=JEP00FUH00P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool005Aoo`8000AJ
EP8000Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30005FUH01@00FUIJEUYF
00000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo0P000eYF00<005YFFUH00`001Goo00@005YF
FUH000EJEQ400003FUH005YF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P0000=JEP00000015YF00<005YF00000`0000Aoo`00FUIJEPH000AJEP03001JEUYF00IJ
EP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol40005FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
E7oo0P0000=JEP00FUH015YF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000=JEP00FUH00eYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool005Aoo`800003FUH005YF00AJEP03001JEUYF008000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo001DOol01000FUIJEP001EYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP04FUHH0003FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01@00FUIJEUYF000015YF00@005YFFUH000QJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH00000
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04000HOol40005FUH01@00FUIJEUYF0000;Woo001D
Ool01@00FUIJEUYF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP<0021o
o`8000=JEP05001JEUYFFUH0000^Ool005Aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P008goo100000=JEP00FUH00UYF0P00;Goo001DOol01000FUIJEUYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH01000FUH000008goo0P000UYF00@005YF000000=JEP8002eoo`00E7oo00L005YFFUIJEP00
FUH00006FUH00`00FUIJEP05FUH70008FUH00`00FUIJEP03FUH400000eYF001JEP04FUH01000FUIJ
EP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
000015YF0P004goo3@0000=oo`0000000P0015YF00D005YFFUIJEP00009JEP8002eoo`00EGoo00<0
05YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000EJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20002FUH5000:Ool40002FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP02FUH4000]Ool004Ioo`T000Moo`05001JEUYFFUH00007FUH0
0`00FUH000020008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF00@005YFFUIJEPX000IJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP<002eoo`00@7oo1P0015YF00<005YFFUH00UYF1`001EYF00<005YFFUH015YF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001@0000AJEP00FUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EP00FUH00005FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH40005FUH3000]Ool003aoo`@00003FUH005YF00IJEP03Ool005YF00MJEP03001JEP0000EJEP03
001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH0
05YF00=JEP8000=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool003Qoo`@000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00@000AJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUH0000]Ool003Ioo`800003FUH005YF00IJEP03001JEUYF00AJEP03OomJEP0000QJEP<000EJEPT0
009JEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00EJEP03001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF
00=JEP@000MJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80
0003FUH0000002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00001EYF00<005YFFUH00UYF0P000Woo40000eYF00<005YFFUH02EYF00<005YFFUH01UYF
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP000000;Woo000bOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH017ooFUIJEP0025YF00@005YFFUH000=JEP8000EJEP800005Ool005YFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH00000;goo000aOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF00<005YF00001EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009JEP03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPL0
00AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000_Ool002moo`800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF009JEP05001JEUYFFUIoo`03FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH2000015YF000000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF0`001eYF00<005YFFUH01EYF00<005YFFUH010001eYF200015YF00<005YF
FUH00eYF00<005YF0000;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUH00002FUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000015YF001JEP001eYF00<005YFFUH015YF1000
0UYF00<005YFFUH01UYF00<005YFFUH01EYF1@001EYF00<005YF0000;goo000]Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEWoo1EYF00@005YFFUIoo`EJEP04001JEP00Ool4FUH0
0`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000^Ool002eoo`8000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
009JEP04001JEP000002FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00
FUIJEP03FUH01000FUIJEP000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000Eoo`00FUIJEP0000MJEP03001JEP00008000QJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH200001Goo000005YF00000UYF00<007ooOol0;7oo000/Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIoo`06FUH00`00FUIoo`06FUH00`00FUH00005FUH0
0`00FUIJEP02FUH01P00FUH00000FUH000EJEP04001JEUYFFUH=0005FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000Eoo`80009JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF0`0000=JEP00
FUH015YF10000UYF00<005YFFUH01UYF00<005YF00000`0000AJEP00FUIJEP<000AJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF009J
EP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Uoo`03001JEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<007ooFUH01UYF00<005YF
FUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH010001UYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010003Goo00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40007FUH20002FUH01@00FUIJEUYF00001EYF1P00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH30003FUHJ
000AOol3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPT00004FUH0
05YFFUH90002FUH300000eYF001JEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF0P001EYF0P00:7oo00<005YF0000;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP020002FUH30008FUH00`00FUIJEP02FUH>0006FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01P00FUIJEP00FUH000EJEP03001JEP0002Moo`03001JEP0002eoo`00;7oo00<005YF
000015YF00<005YFFUH00eYF1@000eYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF001JEP00
00AJEP80009JEP03001JEUYF00EJEPH000MJEP04001JEUYFFUH70002FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00
FUH00002FUH00`00FUIJEP03FUH01000FUIJEP002Woo0`0067oo0P0000=JEP00Ool0;7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP00009JEP8000AJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJEPH000IJEP@000EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EP00009JEP03001JEUYF00=JEP04001JEUYF0009Ool5000FOol00`00FUH00002FUH00`00Oomoo`0Z
Ool002aoo`03001JEP0000AJEP03001JEP0000@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00009JEP8000IJEP03001JEP00010000AJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH0
0`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20003FUH00`00FUIJEP03FUH01000FUIJEP002Goo1@005Goo00@005YFFUH0009JEP03001o
ogoo02Yoo`00;Goo0P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUH005YF008000IJEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP800005FUH005YFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP02
0008Ool5000DOol01@00FUIJEUYF00000UYF00<007ooOol0:Woo000]Ool20002FUH200000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUH00000FUH000AJEP80
00EJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00
FUIJEP03FUH00`00FUIJEP020009Ool3000DOol00`00FUIJEP03FUH00`00FUH0000/Ool002eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEP00008000IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF008000AJEP03
001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00EJEP03001JEUYF00=JEP03001JEUYF008000Moo`l000Qoo`<000EJEP8002eoo`00;Goo0P0000=J
EP00FUH00P001UYF00<005YFFUH01UYF00<005YFFUH00UYF3P001EYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF0`001eYF00D005YF001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000EJEP03001JEUYF00=JEP03001JEUYF00800003
Ool0000000@000AJEP03001JEUYF00IJEP03001JEP0000<0009oo`80009JEP03001JEUYF00=JEP80
02eoo`00;Goo0P0000EJEP00001JEP0000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF009JEP03
001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJEP<0
00UJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001oogoo02aoo`00;Goo00@005YFFUH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEUYF
FUH005YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH025YF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P001EYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUH000020007FUH>000015YF001JEP0015YF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P0015YF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH00`000eYF0`001eYF00<005YFFUH015YF1`0015YF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20005FUH00`00FUIJ
EP04FUH2000015YF001JEUYF1P0015YF00<005YFFUH01UYF00<005YF00001P000UYF1P000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH01eYF10002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
10001goo200015YF00<005YFFUH00UYF0`00<7oo000]Ool20005FUH00`00FUIJEP02FUH20002FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH00005FUH300000eYF0000000200000eYF0000
000>00000eYF001JEP0:FUH00`00FUIJEP06FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF001JEUYF00000UYF0P000eYF00<005YFFUH01EYF1000
2Goo10001UYF1@0015YF00<005YF0000<7oo000]Ool20005FUH00`00FUIJEP02000015YF00000000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF00<005YFFUH00P000UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP<000IJEP03001JEUYF00@000Uoo`@0009J
EP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUH0000_Ool002eoo`8000EJEPL000QJEP03
001JEUYF00AJEP`000IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00EJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@0009JEP8000MJEQ0000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH0
05YFFUH0000^Ool002aoo`03001JEP0000EJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJ
EP040007FUH01@00FUIJEP00FUH010000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF00L005YF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF000005YF00001EYF0P0015YF00<005YF
FUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<007ooOol0
;7oo000/Ool01000FUIJEP000eYF0`0015YF00<005YFFUH015YF1@000UYF00<005YFFUH01UYF00@0
05YFFUH000AJEP@000EJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30002FUH01000FUIJEP000UYF0P001UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01eYF00@005YFFUH000Eoo`03001JEP0002ioo`00;7oo00@005YFFUH0009JEP8000IJEP03001J
EUYF00@000MJEP<000IJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUIJ
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF0`000UYF00<005YF
FUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`001Woo00@005YF000002eoo`00;7oo
00D005YFFUH005YF00<000IJEP<0009JEP03001JEUYF00EJEPD000EJEP06001JEUYF001JEP000UYF
00@005YF0000009oo`800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00<000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP05FUH20009Ool3000]Ool002eoo`03001JEP0000800003FUH005YF00=JEP80
00EJEP03001JEUYF00EJEPD000EJEP06001JEUYFFUH005YF10001Woo0`000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF0`000UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP<000IJEP03001JEUYF009JEP<000aoo`8002eoo`00;Goo00@005YF000000=JEP05
001JEUYF001oo`040002FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP020002FUH00`00Oomoo`07
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20004FUH01000FUH00000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00
00000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003goo
0P00;Goo000]Ool30004FUH30006OolG000017oo001JEUYF0`001Woo00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000P001EYF0`001UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Woo0P00;Goo000]Ool20005FUH00`00Oomoo`0OOol00`00FUH0
0002FUH20003Ool01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`000eYF00<005YF00000`000UYF00<005YFFUH0
1UYF00<005YFFUH0100057oo00<005YF0000;Goo000]Ool20004FUH00`00Oomoo`0QOol00`00FUH0
0003FUH40002FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001JEUYF
009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF00AJEP<00003FUH005YF009JEP03001JEP0000d001Qoo`03001JEP0002eoo`00;Goo
00@005YF001JEP8002Eoo`8000AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJ
EPH000MJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP020002FUH300000eYF001oo`0ROol200000eYF
001oo`0/Ool002eoo`03001JEP00008002Moo`03001JEUYF009JEP03001JEUYF00=JEQ0000AJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000IJEP04001JEUYFFUH20002Ool3000ROol01000FUH00000;Woo000]Ool01000FUH005YF
0`0097oo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
5P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000P000UYF
00<005YFFUH00UYF0P0000Aoo`00FUH0025oo`03001JEUYF008002ioo`00;Goo00D005YF001JEP00
009JEP8001ioo`@00004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000:FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
0003FUH00`00FUH000030003FUH01P00FUH00000FUH0021oo`05001JEUYFFUH0000_Ool002eoo`<0
0003FUH005YF00=JEP<001Ioo`D000EJEP03001JEUYF009JEPD000AJEP03001JEUYF00EJEP03001J
EUYF009JEPL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001J
EUYF009JEP@0009JEP04001JEP000002Ool300001UYF001JEP00FUH001moo`03001JEUYF009JEP03
001oogoo02eoo`00;Goo0`0000=JEP00FUH015YF00<005YF00000`003Woo10000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF000040002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`0000=JEP0000000P001goo0P000UYF
00<005YF000077oo0`000eYF00<007ooOol0;Woo000]Ool00`00Ool00002FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH>0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30002FUH00`00FUH000020007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH300000eYF001JEP03FUH400000eYF001oo`08Ool01`00FUH005YF001JEP0001Yoo`80009JEP04
001JEUYF000aOol002eoo`06001oogoo001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P0000=JEP00FUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF0P002eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF0P0000Aoo`00FUIJEP8000Ioo`08001JEUYF001JEP00FUH001Moo`<000EJEP80039oo`00;Goo
0P0000Aoo`00FUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
0000009oo`04001JEP00FUH30002Ool00`00FUIJEP02FUH4000DOol300000eYF001JEP05FUH00`00
Oomoo`0aOol002eoo`03001JEP0000<000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00IJEP03001JEUYF00800004FUH005YFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40002Ool00`00FUH00004FUH30005FUH2000BOol30004FUH00`00FUIJEP02FUH2000dOol002io
o`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP<0
00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003Ool20005
FUH00`00FUH0000300000eYF0000000<Ool60007FUH00`00FUIJEP02000fOol002ioo`03001JEUYF
00@000=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP8000EJEP800003
Ool0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3000hOol002moo`03001JEP00009JEP<00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP05001oogooOol0
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000goo10000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00>Woo000`Ool00`00FUH00003FUH4
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020002FUH00`00FUIJEP02FUH20004
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEP00Ool00P0000AJEP00
FUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8003ao
o`00<Goo0P0015YF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@0
05YFFUH000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPD000=JEP03001JEUYF009JEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008003ioo`00<Woo00<005YFFUH00UYF
00<005YFFUH00eYF4@000eYF00<005YFFUH01UYF0`002Woo0`0025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00@Goo000cOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000>Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30008FUH00`00FUIJEP04FUH300000eYF0000000>0017Ool003Eoo`800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@001Aoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0001FOol003Moo`<000IJEP03
001JEUYF00EJEP03001JEUYF00AJEPD001aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00AJEPD000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03
001oogoo05Aoo`00>Woo10000UYF00<005YFFUH01EYF00<005YFFUH010009Woo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02@001EYF00<005YFFUH01UYF00<0
05YFFUH00`000eYF00<007ooOol0EGoo000nOol=000`Ool80006FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH80004FUH50005FUH00`00FUIJEP06FUH30002FUH01000FUIJEP00F7oo0023OolJ0004FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH30004FUH00`00FUH0001HOol0091oo`03001JEUYF
00@000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000MJEP03001JEUYF009JEP<000IJEP8005Uo
o`00TGoo00<005YF00000UYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P000UYF00<005YFFUH00eYF0P00FWoo002AOol00`00FUH00004FUH60004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P00G7oo002BOol20005FUH01000FUIJEUYF
4`000UYF00<005YFFUH01UYF00@005YF000005ioo`00Tgoo0P0015YF00<005YFFUH01EYF00@005YF
FUIJEPL000IJEP03001JEUYF00EJEP<0061oo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002HOol30006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUH00002001UOol009]oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH006Qo
o`00Wgoo4000KWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5964 .76511 m .59455 .71098 L .56338 .70949 L p .707 .577 .707 r
F P
0 g
s
.59455 .71098 m .5964 .76511 L .62822 .76313 L p .707 .577 .707 r
F P
0 g
s
.62822 .76313 m .62636 .70901 L .59455 .71098 L p .707 .577 .707 r
F P
0 g
s
.62636 .70901 m .62822 .76313 L .65757 .75789 L p .707 .577 .707 r
F P
0 g
s
.65757 .75789 m .65571 .70376 L .62636 .70901 L p .707 .577 .707 r
F P
0 g
s
.56524 .76362 m .56338 .70949 L .53592 .70469 L p .707 .577 .707 r
F P
0 g
s
.56338 .70949 m .56524 .76362 L .5964 .76511 L p .707 .577 .707 r
F P
0 g
s
.65571 .70376 m .65757 .75789 L .68158 .74989 L p .707 .577 .707 r
F P
0 g
s
.68158 .74989 m .67973 .69576 L .65571 .70376 L p .707 .577 .707 r
F P
0 g
s
.53777 .75882 m .53592 .70469 L .51484 .69704 L p .707 .577 .707 r
F P
0 g
s
.53592 .70469 m .53777 .75882 L .56524 .76362 L p .707 .577 .707 r
F P
0 g
s
.59914 .82733 m .5962 .79304 L .56507 .7921 L p .707 .577 .707 r
F P
0 g
s
.5962 .79304 m .59914 .82733 L .63086 .82375 L p .707 .577 .707 r
F P
0 g
s
.63086 .82375 m .62792 .78946 L .5962 .79304 L p .707 .577 .707 r
F P
0 g
s
.62792 .78946 m .63086 .82375 L .66006 .81602 L p .707 .577 .707 r
F P
0 g
s
.66006 .81602 m .65712 .78172 L .62792 .78946 L p .707 .577 .707 r
F P
0 g
s
.67973 .69576 m .68158 .74989 L .69791 .73992 L p .707 .577 .707 r
F P
0 g
s
.69791 .73992 m .69605 .68579 L .67973 .69576 L p .707 .577 .707 r
F P
0 g
s
.56801 .82639 m .56507 .7921 L .53757 .78674 L p .707 .577 .707 r
F P
0 g
s
.56507 .7921 m .56801 .82639 L .59914 .82733 L p .707 .577 .707 r
F P
0 g
s
.65712 .78172 m .66006 .81602 L .68389 .80488 L p .707 .577 .707 r
F P
0 g
s
.68389 .80488 m .68095 .77058 L .65712 .78172 L p .707 .577 .707 r
F P
0 g
s
.59788 .85326 m .59668 .83581 L .56553 .8347 L p .707 .577 .707 r
F P
0 g
s
.59668 .83581 m .59788 .85326 L .62964 .85018 L p .707 .577 .707 r
F P
0 g
s
.62964 .85018 m .62844 .83272 L .59668 .83581 L p .707 .577 .707 r
F P
0 g
s
.62844 .83272 m .62964 .85018 L .6589 .84321 L p .707 .577 .707 r
F P
0 g
s
.6589 .84321 m .6577 .82575 L .62844 .83272 L p .707 .577 .707 r
F P
0 g
s
.51484 .69704 m .5167 .75116 L .53777 .75882 L p .707 .577 .707 r
F P
0 g
s
.5167 .75116 m .51484 .69704 L .50222 .68729 L p .707 .577 .707 r
F P
0 g
s
.56674 .85216 m .56553 .8347 L .53805 .82952 L p .707 .577 .707 r
F P
0 g
s
.56553 .8347 m .56674 .85216 L .59788 .85326 L p .707 .577 .707 r
F P
0 g
s
.54051 .82104 m .53757 .78674 L .5164 .77749 L p .707 .577 .707 r
F P
0 g
s
.53757 .78674 m .54051 .82104 L .56801 .82639 L p .707 .577 .707 r
F P
0 g
s
.6577 .82575 m .6589 .84321 L .68281 .83303 L p .707 .577 .707 r
F P
0 g
s
.68281 .83303 m .6816 .81558 L .6577 .82575 L p .707 .577 .707 r
F P
0 g
s
.53805 .82952 m .53925 .84697 L .56674 .85216 L p .707 .577 .707 r
F P
0 g
s
.68095 .77058 m .68389 .80488 L .70001 .79142 L p .707 .577 .707 r
F P
0 g
s
.70001 .79142 m .69707 .75713 L .68095 .77058 L p .707 .577 .707 r
F P
0 g
s
.69605 .68579 m .69791 .73992 L .70495 .72895 L p .707 .577 .707 r
F P
0 g
s
.70495 .72895 m .70309 .67482 L .69605 .68579 L p .707 .577 .707 r
F P
0 g
s
.53925 .84697 m .53805 .82952 L .51692 .82076 L p .707 .577 .707 r
F P
0 g
s
.50222 .68729 m .50407 .74142 L .5167 .75116 L p .707 .577 .707 r
F P
0 g
s
.5164 .77749 m .51934 .81178 L .54051 .82104 L p .707 .577 .707 r
F P
0 g
s
.51692 .82076 m .51812 .83821 L .53925 .84697 L p .707 .577 .707 r
F P
0 g
s
.6816 .81558 m .68281 .83303 L .69901 .82064 L p .707 .577 .707 r
F P
0 g
s
.69901 .82064 m .6978 .80319 L .6816 .81558 L p .707 .577 .707 r
F P
0 g
s
.51934 .81178 m .5164 .77749 L .50363 .76525 L p .707 .577 .707 r
F P
0 g
s
.50407 .74142 m .50222 .68729 L .49928 .6764 L p .707 .577 .707 r
F P
0 g
s
.69707 .75713 m .70001 .79142 L .70684 .77697 L p .707 .577 .707 r
F P
0 g
s
.70684 .77697 m .7039 .74268 L .69707 .75713 L p .707 .577 .707 r
F P
0 g
s
.51812 .83821 m .51692 .82076 L .5042 .80928 L p .707 .577 .707 r
F P
0 g
s
.70309 .67482 m .70495 .72895 L .70201 .71806 L p .707 .577 .707 r
F P
0 g
s
.70201 .71806 m .70015 .66393 L .70309 .67482 L p .707 .577 .707 r
F P
0 g
s
.50363 .76525 m .50656 .79954 L .51934 .81178 L p .707 .577 .707 r
F P
0 g
s
.49928 .6764 m .50114 .73052 L .50407 .74142 L p .707 .577 .707 r
F P
0 g
s
.5042 .80928 m .50541 .82673 L .51812 .83821 L p .707 .577 .707 r
F P
0 g
s
.6978 .80319 m .69901 .82064 L .70592 .80726 L p .707 .577 .707 r
F P
0 g
s
.70592 .80726 m .70472 .78981 L .6978 .80319 L p .707 .577 .707 r
F P
0 g
s
.50656 .79954 m .50363 .76525 L .5005 .75122 L p .707 .577 .707 r
F P
0 g
s
.4867 .82121 m .49119 .31645 L .44718 .31361 L p .707 .577 .707 r
F P
0 g
s
.50114 .73052 m .49928 .6764 L .50632 .66543 L p .707 .577 .707 r
F P
0 g
s
.50541 .82673 m .5042 .80928 L .50116 .79621 L p .707 .577 .707 r
F P
0 g
s
.5005 .75122 m .50344 .78551 L .50656 .79954 L p .707 .577 .707 r
F P
0 g
s
.50116 .79621 m .50236 .81366 L .50541 .82673 L p .707 .577 .707 r
F P
0 g
s
.50632 .66543 m .50818 .71955 L .50114 .73052 L p .707 .577 .707 r
F P
0 g
s
.50344 .78551 m .5005 .75122 L .50734 .73676 L p .707 .577 .707 r
F P
0 g
s
.50818 .71955 m .50632 .66543 L .52265 .65545 L p .707 .577 .707 r
F P
0 g
s
.50236 .81366 m .50116 .79621 L .50807 .78283 L p .707 .577 .707 r
F P
0 g
s
.50734 .73676 m .51027 .77106 L .50344 .78551 L p .707 .577 .707 r
F P
0 g
s
.50807 .78283 m .50928 .80028 L .50236 .81366 L p .707 .577 .707 r
F P
0 g
s
.52265 .65545 m .5245 .70958 L .50818 .71955 L p .707 .577 .707 r
F P
0 g
s
.51027 .77106 m .50734 .73676 L .52346 .72331 L p .707 .577 .707 r
F P
0 g
s
.50928 .80028 m .50807 .78283 L .52427 .77044 L p .707 .577 .707 r
F P
0 g
s
.52346 .72331 m .52639 .7576 L .51027 .77106 L p .707 .577 .707 r
F P
0 g
s
.52427 .77044 m .52548 .78789 L .50928 .80028 L p .707 .577 .707 r
F P
0 g
s
.52639 .7576 m .52346 .72331 L .54728 .71217 L p .707 .577 .707 r
F P
0 g
s
.52548 .78789 m .52427 .77044 L .54817 .76026 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .55022 .74646 L .52639 .7576 L p .707 .577 .707 r
F P
0 g
s
.54817 .76026 m .54938 .77772 L .52548 .78789 L p .707 .577 .707 r
F P
0 g
s
.49119 .31645 m .4867 .82121 L .53164 .82057 L p .707 .577 .707 r
F P
0 g
s
.5245 .70958 m .52265 .65545 L .54666 .64745 L p .707 .577 .707 r
F P
0 g
s
.54666 .64745 m .54851 .70158 L .5245 .70958 L p .707 .577 .707 r
F P
0 g
s
.53164 .82057 m .53613 .31581 L .49119 .31645 L p .707 .577 .707 r
F P
0 g
s
.54851 .70158 m .54666 .64745 L .57601 .64221 L p .707 .577 .707 r
F P
0 g
s
.57601 .64221 m .57787 .69634 L .54851 .70158 L p .707 .577 .707 r
F P
0 g
s
.54728 .71217 m .57648 .70443 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.55022 .74646 m .54959 .73911 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.54959 .73911 m .54728 .71217 L p .55181 .74392 L .707 .577 .707 r
F P
0 g
s
.57787 .69634 m .57601 .64221 L .60782 .64023 L p .707 .577 .707 r
F P
0 g
s
.60782 .64023 m .60968 .69436 L .57787 .69634 L p .707 .577 .707 r
F P
0 g
s
.57942 .73872 m .57648 .70443 L .6082 .70086 L p .707 .577 .707 r
F P
0 g
s
.57648 .70443 m .57942 .73872 L .55022 .74646 L p .707 .577 .707 r
F P
0 g
s
.6082 .70086 m .61114 .73515 L .57942 .73872 L p .707 .577 .707 r
F P
0 g
s
.54938 .77772 m .54817 .76026 L .57743 .75329 L p .707 .577 .707 r
F P
0 g
s
.57743 .75329 m .57864 .77075 L .54938 .77772 L p .707 .577 .707 r
F P
0 g
s
.57864 .77075 m .57743 .75329 L .60919 .75021 L p .707 .577 .707 r
F P
0 g
s
.60919 .75021 m .6104 .76766 L .57864 .77075 L p .707 .577 .707 r
F P
0 g
s
.57761 .31175 m .57335 .79065 L p .60707 .80944 L .707 .577 .707 r
F P
0 g
s
.57335 .79065 m .57312 .81652 L .58421 .81421 L p .707 .577 .707 r
F P
0 g
s
.58421 .81421 m .60707 .80944 L p .57335 .79065 L .707 .577 .707 r
F P
0 g
s
.53613 .31581 m .53164 .82057 L .57312 .81652 L p .707 .577 .707 r
F P
0 g
s
.57312 .81652 m .57761 .31175 L .53613 .31581 L p .707 .577 .707 r
F P
0 g
s
.7039 .74268 m .70684 .77697 L .70372 .76294 L p .707 .577 .707 r
F P
0 g
s
.70372 .76294 m .70078 .72864 L .7039 .74268 L p .707 .577 .707 r
F P
0 g
s
.44269 .81837 m .44718 .31361 L .40842 .30756 L p .707 .577 .707 r
F P
0 g
s
.44718 .31361 m .44269 .81837 L .4867 .82121 L p .707 .577 .707 r
F P
0 g
s
.70015 .66393 m .70201 .71806 L .68939 .70831 L p .707 .577 .707 r
F P
0 g
s
.68939 .70831 m .68753 .65418 L .70015 .66393 L p .707 .577 .707 r
F P
0 g
s
.60968 .69436 m .60782 .64023 L .63899 .64172 L p .707 .577 .707 r
F P
0 g
s
.60707 .80944 m .61156 .30468 L .57761 .31175 L p .707 .577 .707 r
F P
0 g
s
.70472 .78981 m .70592 .80726 L .70287 .79419 L p .707 .577 .707 r
F P
0 g
s
.70287 .79419 m .70167 .77674 L .70472 .78981 L p .707 .577 .707 r
F P
0 g
s
.2534 .72829 m .25154 .67417 L .22037 .67268 L p .707 .577 .707 r
F P
0 g
s
.25154 .67417 m .2534 .72829 L .28521 .72632 L p .707 .577 .707 r
F P
0 g
s
.28521 .72632 m .28335 .67219 L .25154 .67417 L p .707 .577 .707 r
F P
0 g
s
.40393 .81233 m .40842 .30756 L .37869 .29891 L p .707 .577 .707 r
F P
0 g
s
.40842 .30756 m .40393 .81233 L .44269 .81837 L p .707 .577 .707 r
F P
0 g
s
.28335 .67219 m .28521 .72632 L .31456 .72108 L p .707 .577 .707 r
F P
0 g
s
.31456 .72108 m .3127 .66695 L .28335 .67219 L p .707 .577 .707 r
F P
0 g
s
.70078 .72864 m .70372 .76294 L .69094 .75069 L p .707 .577 .707 r
F P
0 g
s
.69094 .75069 m .68801 .7164 L .70078 .72864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22223 .72681 m .22037 .67268 L .19291 .66787 L p .707 .577 .707 r
F P
0 g
s
.22037 .67268 m .22223 .72681 L .2534 .72829 L p .707 .577 .707 r
F P
0 g
s
.68753 .65418 m .68939 .70831 L .66831 .70065 L p .707 .577 .707 r
F P
0 g
s
.66831 .70065 m .66645 .64653 L .68753 .65418 L p .707 .577 .707 r
F P
0 g
s
.3127 .66695 m .31456 .72108 L .33857 .71308 L p .707 .577 .707 r
F P
0 g
s
.33857 .71308 m .33672 .65895 L .3127 .66695 L p .707 .577 .707 r
F P
0 g
s
.63899 .64172 m .64085 .69585 L .60968 .69436 L p .707 .577 .707 r
F P
0 g
s
.63934 .70179 m .64228 .73609 L .61114 .73515 L p .707 .577 .707 r
F P
0 g
s
.61114 .73515 m .6082 .70086 L .63934 .70179 L p .707 .577 .707 r
F P
0 g
s
.64034 .75131 m .64154 .76877 L .6104 .76766 L p .707 .577 .707 r
F P
0 g
s
.6104 .76766 m .60919 .75021 L .64034 .75131 L p .707 .577 .707 r
F P
0 g
s
.61156 .30468 m .60707 .80944 L .63018 .80004 L p .707 .577 .707 r
F P
0 g
s
.63018 .80004 m .63467 .29528 L .61156 .30468 L p .707 .577 .707 r
F P
0 g
s
.70167 .77674 m .70287 .79419 L .69016 .78272 L p .707 .577 .707 r
F P
0 g
s
.69016 .78272 m .68896 .76526 L .70167 .77674 L p .707 .577 .707 r
F P
0 g
s
.19476 .722 m .19291 .66787 L .17183 .66022 L p .707 .577 .707 r
F P
0 g
s
.19291 .66787 m .19476 .722 L .22223 .72681 L p .707 .577 .707 r
F P
0 g
s
.25613 .79051 m .25319 .75622 L .22206 .75528 L p .707 .577 .707 r
F P
0 g
s
.25319 .75622 m .25613 .79051 L .28785 .78694 L p .707 .577 .707 r
F P
0 g
s
.28785 .78694 m .28491 .75265 L .25319 .75622 L p .707 .577 .707 r
F P
0 g
s
.28491 .75265 m .28785 .78694 L .31705 .7792 L p .707 .577 .707 r
F P
0 g
s
.31705 .7792 m .31411 .74491 L .28491 .75265 L p .707 .577 .707 r
F P
0 g
s
.68801 .7164 m .69094 .75069 L .66977 .74144 L p .707 .577 .707 r
F P
0 g
s
.66977 .74144 m .66684 .70715 L .68801 .7164 L p .707 .577 .707 r
F P
0 g
s
.33672 .65895 m .33857 .71308 L .3549 .7031 L p .707 .577 .707 r
F P
0 g
s
.3549 .7031 m .35304 .64897 L .33672 .65895 L p .707 .577 .707 r
F P
0 g
s
.225 .78958 m .22206 .75528 L .19456 .74993 L p .707 .577 .707 r
F P
0 g
s
.22206 .75528 m .225 .78958 L .25613 .79051 L p .707 .577 .707 r
F P
0 g
s
.3742 .80367 m .37869 .29891 L .36091 .2885 L p .707 .577 .707 r
F P
0 g
s
.37869 .29891 m .3742 .80367 L .40393 .81233 L p .707 .577 .707 r
F P
0 g
s
.66645 .64653 m .66831 .70065 L .64085 .69585 L p .707 .577 .707 r
F P
0 g
s
.64085 .69585 m .63899 .64172 L .66645 .64653 L p .707 .577 .707 r
F P
0 g
s
.31411 .74491 m .31705 .7792 L .34088 .76806 L p .707 .577 .707 r
F P
0 g
s
.34088 .76806 m .33794 .73377 L .31411 .74491 L p .707 .577 .707 r
F P
0 g
s
.25488 .81645 m .25367 .79899 L .22252 .79789 L p .707 .577 .707 r
F P
0 g
s
.25367 .79899 m .25488 .81645 L .28663 .81336 L p .707 .577 .707 r
F P
0 g
s
.28663 .81336 m .28543 .79591 L .25367 .79899 L p .707 .577 .707 r
F P
0 g
s
.28543 .79591 m .28663 .81336 L .3159 .80639 L p .707 .577 .707 r
F P
0 g
s
.3159 .80639 m .31469 .78894 L .28543 .79591 L p .707 .577 .707 r
F P
0 g
s
.17183 .66022 m .17369 .71435 L .19476 .722 L p .707 .577 .707 r
F P
0 g
s
.17369 .71435 m .17183 .66022 L .15921 .65047 L p .707 .577 .707 r
F P
0 g
s
.22373 .81534 m .22252 .79789 L .19504 .7927 L p .707 .577 .707 r
F P
0 g
s
.22252 .79789 m .22373 .81534 L .25488 .81645 L p .707 .577 .707 r
F P
0 g
s
.68896 .76526 m .69016 .78272 L .66903 .77396 L p .707 .577 .707 r
F P
0 g
s
.66903 .77396 m .66782 .7565 L .68896 .76526 L p .707 .577 .707 r
F P
0 g
s
.1975 .78422 m .19456 .74993 L .17339 .74068 L p .707 .577 .707 r
F P
0 g
s
.19456 .74993 m .1975 .78422 L .225 .78958 L p .707 .577 .707 r
F P
0 g
s
.31469 .78894 m .3159 .80639 L .3398 .79621 L p .707 .577 .707 r
F P
0 g
s
.3398 .79621 m .33859 .77876 L .31469 .78894 L p .707 .577 .707 r
F P
0 g
s
.66684 .70715 m .66977 .74144 L .64228 .73609 L p .707 .577 .707 r
F P
0 g
s
.64228 .73609 m .63934 .70179 L .66684 .70715 L p .707 .577 .707 r
F P
0 g
s
.19504 .7927 m .19624 .81015 L .22373 .81534 L p .707 .577 .707 r
F P
0 g
s
.33794 .73377 m .34088 .76806 L .357 .75461 L p .707 .577 .707 r
F P
0 g
s
.357 .75461 m .35406 .72031 L .33794 .73377 L p .707 .577 .707 r
F P
0 g
s
.63467 .29528 m .63018 .80004 L .64017 .78923 L p .707 .577 .707 r
F P
0 g
s
.64154 .76877 m .64034 .75131 L .66782 .7565 L p .707 .577 .707 r
F P
0 g
s
.64017 .78923 m .64466 .28447 L .63467 .29528 L p .707 .577 .707 r
F P
0 g
s
.35304 .64897 m .3549 .7031 L .36194 .69213 L p .707 .577 .707 r
F P
0 g
s
.36194 .69213 m .36008 .638 L .35304 .64897 L p .707 .577 .707 r
F P
0 g
s
.19624 .81015 m .19504 .7927 L .17391 .78394 L p .707 .577 .707 r
F P
0 g
s
.15921 .65047 m .16106 .7046 L .17369 .71435 L p .707 .577 .707 r
F P
0 g
s
.17339 .74068 m .17633 .77497 L .1975 .78422 L p .707 .577 .707 r
F P
0 g
s
.66782 .7565 m .66903 .77396 L .64154 .76877 L p .707 .577 .707 r
F P
0 g
s
.17391 .78394 m .17511 .80139 L .19624 .81015 L p .707 .577 .707 r
F P
0 g
s
.33859 .77876 m .3398 .79621 L .356 .78383 L p .707 .577 .707 r
F P
0 g
s
.356 .78383 m .35479 .76638 L .33859 .77876 L p .707 .577 .707 r
F P
0 g
s
.17633 .77497 m .17339 .74068 L .16062 .72843 L p .707 .577 .707 r
F P
0 g
s
.16106 .7046 m .15921 .65047 L .15627 .63958 L p .707 .577 .707 r
F P
0 g
s
.35406 .72031 m .357 .75461 L .36383 .74015 L p .707 .577 .707 r
F P
0 g
s
.36383 .74015 m .36089 .70586 L .35406 .72031 L p .707 .577 .707 r
F P
0 g
s
.359 .68124 m .35715 .62711 L .36008 .638 L p .707 .577 .707 r
F P
0 g
s
.35479 .76638 m .356 .78383 L .36291 .77045 L p .707 .577 .707 r
F P
0 g
s
.36291 .77045 m .36171 .75299 L .35479 .76638 L p .707 .577 .707 r
F P
0 g
s
.35715 .62711 m .359 .68124 L .34638 .67149 L p .707 .577 .707 r
F P
0 g
s
.34638 .67149 m .34452 .61736 L .35715 .62711 L p .707 .577 .707 r
F P
0 g
s
.35777 .69183 m .36008 .71877 L p .34793 .71388 L .707 .577 .707 r
F P
0 g
s
.36008 .71877 m .36071 .72612 L .35963 .72509 L p .707 .577 .707 r
F P
0 g
s
.35963 .72509 m .34793 .71388 L p .36008 .71877 L .707 .577 .707 r
F P
0 g
s
.34793 .71388 m .345 .67959 L .35777 .69183 L p .707 .577 .707 r
F P
0 g
s
.35866 .73992 m .35986 .75738 L .34715 .7459 L p .707 .577 .707 r
F P
0 g
s
.34715 .7459 m .34595 .72845 L .35866 .73992 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35681 .27734 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35642 .79326 m .35665 .76739 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.35665 .76739 m .36091 .2885 L p .35644 .7704 L .707 .577 .707 r
F P
0 g
s
.36008 .638 m .36194 .69213 L .359 .68124 L p .707 .577 .707 r
F P
0 g
s
.36089 .70586 m .36383 .74015 L .36071 .72612 L p .707 .577 .707 r
F P
0 g
s
.36071 .72612 m .35777 .69183 L .36089 .70586 L p .707 .577 .707 r
F P
0 g
s
.36171 .75299 m .36291 .77045 L .35986 .75738 L p .707 .577 .707 r
F P
0 g
s
.35986 .75738 m .35866 .73992 L .36171 .75299 L p .707 .577 .707 r
F P
0 g
s
.36091 .2885 m .35642 .79326 L .3742 .80367 L p .707 .577 .707 r
F P
0 g
s
.17511 .80139 m .17391 .78394 L .16119 .77246 L p .707 .577 .707 r
F P
0 g
s
.16062 .72843 m .16356 .76273 L .17633 .77497 L p .707 .577 .707 r
F P
0 g
s
.15627 .63958 m .15813 .69371 L .16106 .7046 L p .707 .577 .707 r
F P
0 g
s
.16119 .77246 m .1624 .78992 L .17511 .80139 L p .707 .577 .707 r
F P
0 g
s
.16356 .76273 m .16062 .72843 L .15749 .7144 L p .707 .577 .707 r
F P
0 g
s
.64466 .28447 m .64017 .78923 L .63608 .77807 L p .707 .577 .707 r
F P
0 g
s
.63608 .77807 m .64057 .27331 L .64466 .28447 L p .707 .577 .707 r
F P
0 g
s
.15813 .69371 m .15627 .63958 L .16331 .62861 L p .707 .577 .707 r
F P
0 g
s
.1624 .78992 m .16119 .77246 L .15815 .75939 L p .707 .577 .707 r
F P
0 g
s
.15749 .7144 m .16043 .74869 L .16356 .76273 L p .707 .577 .707 r
F P
0 g
s
.35681 .27734 m .35233 .7821 L .35642 .79326 L p .707 .577 .707 r
F P
0 g
s
.35233 .7821 m .35681 .27734 L .36681 .26653 L p .707 .577 .707 r
F P
0 g
s
.15815 .75939 m .15935 .77685 L .1624 .78992 L p .707 .577 .707 r
F P
0 g
s
.16331 .62861 m .16517 .68274 L .15813 .69371 L p .707 .577 .707 r
F P
0 g
s
.16043 .74869 m .15749 .7144 L .16433 .69995 L p .707 .577 .707 r
F P
0 g
s
.16517 .68274 m .16331 .62861 L .17964 .61864 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15935 .77685 m .15815 .75939 L .16506 .74601 L p .707 .577 .707 r
F P
0 g
s
.64057 .27331 m .63608 .77807 L .6183 .76766 L p .707 .577 .707 r
F P
0 g
s
.6183 .76766 m .62279 .26289 L .64057 .27331 L p .707 .577 .707 r
F P
0 g
s
.16433 .69995 m .16726 .73424 L .16043 .74869 L p .707 .577 .707 r
F P
0 g
s
.34452 .61736 m .34638 .67149 L .3253 .66384 L p .707 .577 .707 r
F P
0 g
s
.3253 .66384 m .32345 .60971 L .34452 .61736 L p .707 .577 .707 r
F P
0 g
s
.16506 .74601 m .16627 .76347 L .15935 .77685 L p .707 .577 .707 r
F P
0 g
s
.17964 .61864 m .18149 .67277 L .16517 .68274 L p .707 .577 .707 r
F P
0 g
s
.16726 .73424 m .16433 .69995 L .18045 .6865 L p .707 .577 .707 r
F P
0 g
s
.18149 .67277 m .17964 .61864 L .20365 .61064 L p .707 .577 .707 r
F P
0 g
s
.36232 .77129 m .36681 .26653 L .38991 .25712 L p .707 .577 .707 r
F P
0 g
s
.36681 .26653 m .36232 .77129 L .35233 .7821 L p .707 .577 .707 r
F P
0 g
s
.345 .67959 m .34793 .71388 L .32676 .70463 L p .707 .577 .707 r
F P
0 g
s
.32676 .70463 m .32383 .67034 L .345 .67959 L p .707 .577 .707 r
F P
0 g
s
.32345 .60971 m .3253 .66384 L .29784 .65903 L p .707 .577 .707 r
F P
0 g
s
.29784 .65903 m .29598 .60491 L .32345 .60971 L p .707 .577 .707 r
F P
0 g
s
.16627 .76347 m .16506 .74601 L .18126 .73363 L p .707 .577 .707 r
F P
0 g
s
.18045 .6865 m .18338 .72079 L .16726 .73424 L p .707 .577 .707 r
F P
0 g
s
.20551 .66477 m .20365 .61064 L .233 .60539 L p .707 .577 .707 r
F P
0 g
s
.20365 .61064 m .20551 .66477 L .18149 .67277 L p .707 .577 .707 r
F P
0 g
s
.18126 .73363 m .18247 .75108 L .16627 .76347 L p .707 .577 .707 r
F P
0 g
s
.18338 .72079 m .18045 .6865 L .20427 .67535 L p .707 .577 .707 r
F P
0 g
s
.34595 .72845 m .34715 .7459 L .32602 .73714 L p .707 .577 .707 r
F P
0 g
s
.32602 .73714 m .32481 .71969 L .34595 .72845 L p .707 .577 .707 r
F P
0 g
s
.62279 .26289 m .6183 .76766 L .58857 .759 L p .707 .577 .707 r
F P
0 g
s
.58857 .759 m .59306 .25424 L .62279 .26289 L p .707 .577 .707 r
F P
0 g
s
.29598 .60491 m .29784 .65903 L .26667 .65755 L p .707 .577 .707 r
F P
0 g
s
.26667 .65755 m .26482 .60342 L .29598 .60491 L p .707 .577 .707 r
F P
0 g
s
.32383 .67034 m .32676 .70463 L .29927 .69927 L p .707 .577 .707 r
F P
0 g
s
.29927 .69927 m .29633 .66498 L .32383 .67034 L p .707 .577 .707 r
F P
0 g
s
.23486 .65952 m .233 .60539 L .26482 .60342 L p .707 .577 .707 r
F P
0 g
s
.233 .60539 m .23486 .65952 L .20551 .66477 L p .707 .577 .707 r
F P
0 g
s
.26482 .60342 m .26667 .65755 L .23486 .65952 L p .707 .577 .707 r
F P
0 g
s
.73361 .65748 m .73175 .60335 L .70059 .60187 L p .707 .577 .707 r
F P
0 g
s
.73175 .60335 m .73361 .65748 L .76542 .65551 L p .707 .577 .707 r
F P
0 g
s
.76542 .65551 m .76357 .60138 L .73175 .60335 L p .707 .577 .707 r
F P
0 g
s
.18247 .75108 m .18126 .73363 L .20516 .72345 L p .707 .577 .707 r
F P
0 g
s
.20427 .67535 m .20721 .70965 L .18338 .72079 L p .707 .577 .707 r
F P
0 g
s
.76357 .60138 m .76542 .65551 L .79477 .65026 L p .707 .577 .707 r
F P
0 g
s
.79477 .65026 m .79292 .59614 L .76357 .60138 L p .707 .577 .707 r
F P
0 g
s
.20721 .70965 m .20427 .67535 L .23348 .66762 L p .707 .577 .707 r
F P
0 g
s
.38991 .25712 m .38543 .76189 L .36232 .77129 L p .707 .577 .707 r
F P
0 g
s
.38543 .76189 m .38991 .25712 L .42387 .25005 L p .707 .577 .707 r
F P
0 g
s
.70244 .65599 m .70059 .60187 L .67312 .59706 L p .707 .577 .707 r
F P
0 g
s
.70059 .60187 m .70244 .65599 L .73361 .65748 L p .707 .577 .707 r
F P
0 g
s
.29633 .66498 m .29927 .69927 L .26813 .69833 L p .707 .577 .707 r
F P
0 g
s
.26813 .69833 m .2652 .66404 L .29633 .66498 L p .707 .577 .707 r
F P
0 g
s
.20516 .72345 m .20637 .7409 L .18247 .75108 L p .707 .577 .707 r
F P
0 g
s
.32481 .71969 m .32602 .73714 L .29853 .73195 L p .707 .577 .707 r
F P
0 g
s
.29853 .73195 m .29733 .7145 L .32481 .71969 L p .707 .577 .707 r
F P
0 g
s
.23641 .70191 m .23348 .66762 L .2652 .66404 L p .707 .577 .707 r
F P
0 g
s
.23348 .66762 m .23641 .70191 L .20721 .70965 L p .707 .577 .707 r
F P
0 g
s
.79292 .59614 m .79477 .65026 L .81879 .64226 L p .707 .577 .707 r
F P
0 g
s
.81879 .64226 m .81693 .58814 L .79292 .59614 L p .707 .577 .707 r
F P
0 g
s
.2652 .66404 m .26813 .69833 L .23641 .70191 L p .707 .577 .707 r
F P
0 g
s
.20637 .7409 m .20516 .72345 L .23442 .71648 L p .707 .577 .707 r
F P
0 g
s
.67498 .65119 m .67312 .59706 L .65205 .58941 L p .707 .577 .707 r
F P
0 g
s
.67312 .59706 m .67498 .65119 L .70244 .65599 L p .707 .577 .707 r
F P
0 g
s
.59306 .25424 m .58857 .759 L .54981 .75296 L p .707 .577 .707 r
F P
0 g
s
.54981 .75296 m .55429 .2482 L .59306 .25424 L p .707 .577 .707 r
F P
0 g
s
.29733 .7145 m .29853 .73195 L .26739 .73085 L p .707 .577 .707 r
F P
0 g
s
.26739 .73085 m .26618 .71339 L .29733 .7145 L p .707 .577 .707 r
F P
0 g
s
.23442 .71648 m .23563 .73393 L .20637 .7409 L p .707 .577 .707 r
F P
0 g
s
.23563 .73393 m .23442 .71648 L .26618 .71339 L p .707 .577 .707 r
F P
0 g
s
.73634 .73402 m .7334 .69973 L .70227 .69879 L p .707 .577 .707 r
F P
0 g
s
.7334 .69973 m .73634 .73402 L .76806 .73045 L p .707 .577 .707 r
F P
0 g
s
.76806 .73045 m .76512 .69615 L .7334 .69973 L p .707 .577 .707 r
F P
0 g
s
.26618 .71339 m .26739 .73085 L .23563 .73393 L p .707 .577 .707 r
F P
0 g
s
.76512 .69615 m .76806 .73045 L .79727 .72271 L p .707 .577 .707 r
F P
0 g
s
.79727 .72271 m .79433 .68842 L .76512 .69615 L p .707 .577 .707 r
F P
0 g
s
.41938 .75481 m .42387 .25005 L .46534 .24599 L p .707 .577 .707 r
F P
0 g
s
.42387 .25005 m .41938 .75481 L .38543 .76189 L p .707 .577 .707 r
F P
0 g
s
.81693 .58814 m .81879 .64226 L .83511 .63229 L p .707 .577 .707 r
F P
0 g
s
.83511 .63229 m .83326 .57816 L .81693 .58814 L p .707 .577 .707 r
F P
0 g
s
.70521 .73309 m .70227 .69879 L .67477 .69344 L p .707 .577 .707 r
F P
0 g
s
.70227 .69879 m .70521 .73309 L .73634 .73402 L p .707 .577 .707 r
F P
0 g
s
.65205 .58941 m .6539 .64354 L .67498 .65119 L p .707 .577 .707 r
F P
0 g
s
.79433 .68842 m .79727 .72271 L .82109 .71157 L p .707 .577 .707 r
F P
0 g
s
.82109 .71157 m .81815 .67728 L .79433 .68842 L p .707 .577 .707 r
F P
0 g
s
.55429 .2482 m .54981 .75296 L .5058 .75012 L p .707 .577 .707 r
F P
0 g
s
.5058 .75012 m .51029 .24536 L .55429 .2482 L p .707 .577 .707 r
F P
0 g
s
.6539 .64354 m .65205 .58941 L .63942 .57966 L p .707 .577 .707 r
F P
0 g
s
.46086 .75076 m .46534 .24599 L .51029 .24536 L p .707 .577 .707 r
F P
0 g
s
.46534 .24599 m .46086 .75076 L .41938 .75481 L p .707 .577 .707 r
F P
0 g
s
.73509 .78705 m .73388 .76959 L .70274 .76849 L p .707 .577 .707 r
F P
0 g
s
.73388 .76959 m .73509 .78705 L .76685 .78396 L p .707 .577 .707 r
F P
0 g
s
.76685 .78396 m .76564 .76651 L .73388 .76959 L p .707 .577 .707 r
F P
0 g
s
.67771 .72773 m .67477 .69344 L .6536 .68418 L p .707 .577 .707 r
F P
0 g
s
.67477 .69344 m .67771 .72773 L .70521 .73309 L p .707 .577 .707 r
F P
0 g
s
.76564 .76651 m .76685 .78396 L .79611 .77699 L p .707 .577 .707 r
F P
0 g
s
.79611 .77699 m .7949 .75954 L .76564 .76651 L p .707 .577 .707 r
F P
0 g
s
.51029 .24536 m .5058 .75012 L .46086 .75076 L p .707 .577 .707 r
F P
0 g
s
.70394 .78594 m .70274 .76849 L .67525 .7633 L p .707 .577 .707 r
F P
0 g
s
.70274 .76849 m .70394 .78594 L .73509 .78705 L p .707 .577 .707 r
F P
0 g
s
.83326 .57816 m .83511 .63229 L .84215 .62132 L p .707 .577 .707 r
F P
0 g
s
.84215 .62132 m .8403 .56719 L .83326 .57816 L p .707 .577 .707 r
F P
0 g
s
.81815 .67728 m .82109 .71157 L .83721 .69811 L p .707 .577 .707 r
F P
0 g
s
.83721 .69811 m .83427 .66382 L .81815 .67728 L p .707 .577 .707 r
F P
0 g
s
.7949 .75954 m .79611 .77699 L .82001 .76681 L p .707 .577 .707 r
F P
0 g
s
.82001 .76681 m .81881 .74936 L .7949 .75954 L p .707 .577 .707 r
F P
0 g
s
.63942 .57966 m .64128 .63379 L .6539 .64354 L p .707 .577 .707 r
F P
0 g
s
.67525 .7633 m .67646 .78075 L .70394 .78594 L p .707 .577 .707 r
F P
0 g
s
.6536 .68418 m .65654 .71848 L .67771 .72773 L p .707 .577 .707 r
F P
0 g
s
.64128 .63379 m .63942 .57966 L .63649 .56877 L p .707 .577 .707 r
F P
0 g
s
.67646 .78075 m .67525 .7633 L .65412 .75454 L p .707 .577 .707 r
F P
0 g
s
.65654 .71848 m .6536 .68418 L .64083 .67194 L p .707 .577 .707 r
F P
0 g
s
.65412 .75454 m .65533 .77199 L .67646 .78075 L p .707 .577 .707 r
F P
0 g
s
.81881 .74936 m .82001 .76681 L .83621 .75443 L p .707 .577 .707 r
F P
0 g
s
.83621 .75443 m .83501 .73697 L .81881 .74936 L p .707 .577 .707 r
F P
0 g
s
.83427 .66382 m .83721 .69811 L .84404 .68366 L p .707 .577 .707 r
F P
0 g
s
.84404 .68366 m .84111 .64937 L .83427 .66382 L p .707 .577 .707 r
F P
0 g
s
.8403 .56719 m .84215 .62132 L .83922 .61043 L p .707 .577 .707 r
F P
0 g
s
.83922 .61043 m .83736 .5563 L .8403 .56719 L p .707 .577 .707 r
F P
0 g
s
.63649 .56877 m .63834 .6229 L .64128 .63379 L p .707 .577 .707 r
F P
0 g
s
.64083 .67194 m .64377 .70624 L .65654 .71848 L p .707 .577 .707 r
F P
0 g
s
.65533 .77199 m .65412 .75454 L .64141 .74306 L p .707 .577 .707 r
F P
0 g
s
.64377 .70624 m .64083 .67194 L .63771 .65791 L p .707 .577 .707 r
F P
0 g
s
.63834 .6229 m .63649 .56877 L .64352 .5578 L p .707 .577 .707 r
F P
0 g
s
.64141 .74306 m .64261 .76052 L .65533 .77199 L p .707 .577 .707 r
F P
0 g
s
.83501 .73697 m .83621 .75443 L .84313 .74105 L p .707 .577 .707 r
F P
0 g
s
.84313 .74105 m .84192 .72359 L .83501 .73697 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84111 .64937 m .84404 .68366 L .84092 .66963 L p .707 .577 .707 r
F P
0 g
s
.84092 .66963 m .83798 .63534 L .84111 .64937 L p .707 .577 .707 r
F P
0 g
s
.83736 .5563 m .83922 .61043 L .82659 .60068 L p .707 .577 .707 r
F P
0 g
s
.82659 .60068 m .82474 .54655 L .83736 .5563 L p .707 .577 .707 r
F P
0 g
s
.63771 .65791 m .64065 .6922 L .64377 .70624 L p .707 .577 .707 r
F P
0 g
s
.64352 .5578 m .64538 .61193 L .63834 .6229 L p .707 .577 .707 r
F P
0 g
s
.64261 .76052 m .64141 .74306 L .63836 .72999 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64065 .6922 m .63771 .65791 L .64454 .64346 L p .707 .577 .707 r
F P
0 g
s
.63836 .72999 m .63956 .74745 L .64261 .76052 L p .707 .577 .707 r
F P
0 g
s
.3906 .62067 m .38874 .56654 L .35758 .56505 L p .707 .577 .707 r
F P
0 g
s
.38874 .56654 m .3906 .62067 L .42241 .61869 L p .707 .577 .707 r
F P
0 g
s
.42241 .61869 m .42056 .56456 L .38874 .56654 L p .707 .577 .707 r
F P
0 g
s
.64538 .61193 m .64352 .5578 L .65985 .54783 L p .707 .577 .707 r
F P
0 g
s
.42056 .56456 m .42241 .61869 L .45176 .61345 L p .707 .577 .707 r
F P
0 g
s
.45176 .61345 m .44991 .55932 L .42056 .56456 L p .707 .577 .707 r
F P
0 g
s
.84192 .72359 m .84313 .74105 L .84008 .72798 L p .707 .577 .707 r
F P
0 g
s
.84008 .72798 m .83887 .71052 L .84192 .72359 L p .707 .577 .707 r
F P
0 g
s
.35943 .61918 m .35758 .56505 L .33011 .56025 L p .707 .577 .707 r
F P
0 g
s
.35758 .56505 m .35943 .61918 L .3906 .62067 L p .707 .577 .707 r
F P
0 g
s
.83798 .63534 m .84092 .66963 L .82815 .65739 L p .707 .577 .707 r
F P
0 g
s
.82815 .65739 m .82521 .6231 L .83798 .63534 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82474 .54655 m .82659 .60068 L .80552 .59303 L p .707 .577 .707 r
F P
0 g
s
.80552 .59303 m .80366 .5389 L .82474 .54655 L p .707 .577 .707 r
F P
0 g
s
.44991 .55932 m .45176 .61345 L .47578 .60545 L p .707 .577 .707 r
F P
0 g
s
.47578 .60545 m .47392 .55132 L .44991 .55932 L p .707 .577 .707 r
F P
0 g
s
.64454 .64346 m .64748 .67775 L .64065 .6922 L p .707 .577 .707 r
F P
0 g
s
.65985 .54783 m .66171 .60195 L .64538 .61193 L p .707 .577 .707 r
F P
0 g
s
.63956 .74745 m .63836 .72999 L .64527 .71661 L p .707 .577 .707 r
F P
0 g
s
.33197 .61437 m .33011 .56025 L .30904 .55259 L p .707 .577 .707 r
F P
0 g
s
.33011 .56025 m .33197 .61437 L .35943 .61918 L p .707 .577 .707 r
F P
0 g
s
.66171 .60195 m .65985 .54783 L .68386 .53983 L p .707 .577 .707 r
F P
0 g
s
.64748 .67775 m .64454 .64346 L .66066 .63 L p .707 .577 .707 r
F P
0 g
s
.64527 .71661 m .64648 .73406 L .63956 .74745 L p .707 .577 .707 r
F P
0 g
s
.39333 .69721 m .39039 .66291 L .35926 .66198 L p .707 .577 .707 r
F P
0 g
s
.39039 .66291 m .39333 .69721 L .42505 .69363 L p .707 .577 .707 r
F P
0 g
s
.42505 .69363 m .42211 .65934 L .39039 .66291 L p .707 .577 .707 r
F P
0 g
s
.42211 .65934 m .42505 .69363 L .45426 .68589 L p .707 .577 .707 r
F P
0 g
s
.45426 .68589 m .45132 .6516 L .42211 .65934 L p .707 .577 .707 r
F P
0 g
s
.83887 .71052 m .84008 .72798 L .82737 .7165 L p .707 .577 .707 r
F P
0 g
s
.82737 .7165 m .82616 .69905 L .83887 .71052 L p .707 .577 .707 r
F P
0 g
s
.47392 .55132 m .47578 .60545 L .4921 .59547 L p .707 .577 .707 r
F P
0 g
s
.4921 .59547 m .49025 .54135 L .47392 .55132 L p .707 .577 .707 r
F P
0 g
s
.82521 .6231 m .82815 .65739 L .80698 .64814 L p .707 .577 .707 r
F P
0 g
s
.80698 .64814 m .80404 .61384 L .82521 .6231 L p .707 .577 .707 r
F P
0 g
s
.80366 .5389 m .80552 .59303 L .77805 .58822 L p .707 .577 .707 r
F P
0 g
s
.77805 .58822 m .77619 .53409 L .80366 .5389 L p .707 .577 .707 r
F P
0 g
s
.3622 .69627 m .35926 .66198 L .33176 .65662 L p .707 .577 .707 r
F P
0 g
s
.35926 .66198 m .3622 .69627 L .39333 .69721 L p .707 .577 .707 r
F P
0 g
s
.30904 .55259 m .31089 .60672 L .33197 .61437 L p .707 .577 .707 r
F P
0 g
s
.45132 .6516 m .45426 .68589 L .47808 .67475 L p .707 .577 .707 r
F P
0 g
s
.47808 .67475 m .47514 .64046 L .45132 .6516 L p .707 .577 .707 r
F P
0 g
s
.66066 .63 m .6636 .6643 L .64748 .67775 L p .707 .577 .707 r
F P
0 g
s
.68572 .59395 m .68386 .53983 L .71321 .53458 L p .707 .577 .707 r
F P
0 g
s
.68386 .53983 m .68572 .59395 L .66171 .60195 L p .707 .577 .707 r
F P
0 g
s
.31089 .60672 m .30904 .55259 L .29641 .54284 L p .707 .577 .707 r
F P
0 g
s
.64648 .73406 m .64527 .71661 L .66148 .70422 L p .707 .577 .707 r
F P
0 g
s
.6636 .6643 m .66066 .63 L .68449 .61886 L p .707 .577 .707 r
F P
0 g
s
.39208 .75023 m .39087 .73278 L .35973 .73167 L p .707 .577 .707 r
F P
0 g
s
.39087 .73278 m .39208 .75023 L .42384 .74715 L p .707 .577 .707 r
F P
0 g
s
.42384 .74715 m .42263 .72969 L .39087 .73278 L p .707 .577 .707 r
F P
0 g
s
.77619 .53409 m .77805 .58822 L .74689 .58673 L p .707 .577 .707 r
F P
0 g
s
.74689 .58673 m .74503 .53261 L .77619 .53409 L p .707 .577 .707 r
F P
0 g
s
.3347 .69091 m .33176 .65662 L .31059 .64737 L p .707 .577 .707 r
F P
0 g
s
.33176 .65662 m .3347 .69091 L .3622 .69627 L p .707 .577 .707 r
F P
0 g
s
.42263 .72969 m .42384 .74715 L .4531 .74018 L p .707 .577 .707 r
F P
0 g
s
.4531 .74018 m .45189 .72272 L .42263 .72969 L p .707 .577 .707 r
F P
0 g
s
.71507 .58871 m .71321 .53458 L .74503 .53261 L p .707 .577 .707 r
F P
0 g
s
.71321 .53458 m .71507 .58871 L .68572 .59395 L p .707 .577 .707 r
F P
0 g
s
.66148 .70422 m .66268 .72168 L .64648 .73406 L p .707 .577 .707 r
F P
0 g
s
.80404 .61384 m .80698 .64814 L .77948 .64278 L p .707 .577 .707 r
F P
0 g
s
.77948 .64278 m .77654 .60849 L .80404 .61384 L p .707 .577 .707 r
F P
0 g
s
.36093 .74912 m .35973 .73167 L .33224 .72648 L p .707 .577 .707 r
F P
0 g
s
.35973 .73167 m .36093 .74912 L .39208 .75023 L p .707 .577 .707 r
F P
0 g
s
.49025 .54135 m .4921 .59547 L .49914 .58451 L p .707 .577 .707 r
F P
0 g
s
.49914 .58451 m .49729 .53038 L .49025 .54135 L p .707 .577 .707 r
F P
0 g
s
.74503 .53261 m .74689 .58673 L .71507 .58871 L p .707 .577 .707 r
F P
0 g
s
.82616 .69905 m .82737 .7165 L .80623 .70774 L p .707 .577 .707 r
F P
0 g
s
.80623 .70774 m .80503 .69029 L .82616 .69905 L p .707 .577 .707 r
F P
0 g
s
.47514 .64046 m .47808 .67475 L .4942 .6613 L p .707 .577 .707 r
F P
0 g
s
.4942 .6613 m .49126 .62701 L .47514 .64046 L p .707 .577 .707 r
F P
0 g
s
.45189 .72272 m .4531 .74018 L .477 .73 L p .707 .577 .707 r
F P
0 g
s
.477 .73 m .4758 .71254 L .45189 .72272 L p .707 .577 .707 r
F P
0 g
s
.29641 .54284 m .29827 .59697 L .31089 .60672 L p .707 .577 .707 r
F P
0 g
s
.33224 .72648 m .33345 .74394 L .36093 .74912 L p .707 .577 .707 r
F P
0 g
s
.68449 .61886 m .68742 .65315 L .6636 .6643 L p .707 .577 .707 r
F P
0 g
s
.68742 .65315 m .68449 .61886 L .71369 .61113 L p .707 .577 .707 r
F P
0 g
s
.31059 .64737 m .31353 .68166 L .3347 .69091 L p .707 .577 .707 r
F P
0 g
s
.29827 .59697 m .29641 .54284 L .29348 .53195 L p .707 .577 .707 r
F P
0 g
s
.66268 .72168 m .66148 .70422 L .68538 .69405 L p .707 .577 .707 r
F P
0 g
s
.77654 .60849 m .77948 .64278 L .74835 .64184 L p .707 .577 .707 r
F P
0 g
s
.74835 .64184 m .74541 .60755 L .77654 .60849 L p .707 .577 .707 r
F P
0 g
s
.33345 .74394 m .33224 .72648 L .31111 .71772 L p .707 .577 .707 r
F P
0 g
s
.31353 .68166 m .31059 .64737 L .29782 .63513 L p .707 .577 .707 r
F P
0 g
s
.71663 .64542 m .71369 .61113 L .74541 .60755 L p .707 .577 .707 r
F P
0 g
s
.71369 .61113 m .71663 .64542 L .68742 .65315 L p .707 .577 .707 r
F P
0 g
s
.74541 .60755 m .74835 .64184 L .71663 .64542 L p .707 .577 .707 r
F P
0 g
s
.68538 .69405 m .68658 .7115 L .66268 .72168 L p .707 .577 .707 r
F P
0 g
s
.80503 .69029 m .80623 .70774 L .77875 .70255 L p .707 .577 .707 r
F P
0 g
s
.77875 .70255 m .77754 .6851 L .80503 .69029 L p .707 .577 .707 r
F P
0 g
s
.31111 .71772 m .31231 .73518 L .33345 .74394 L p .707 .577 .707 r
F P
0 g
s
.4758 .71254 m .477 .73 L .4932 .71761 L p .707 .577 .707 r
F P
0 g
s
.4932 .71761 m .492 .70016 L .4758 .71254 L p .707 .577 .707 r
F P
0 g
s
.49126 .62701 m .4942 .6613 L .50103 .64685 L p .707 .577 .707 r
F P
0 g
s
.50103 .64685 m .4981 .61256 L .49126 .62701 L p .707 .577 .707 r
F P
0 g
s
.49729 .53038 m .49914 .58451 L .49621 .57361 L p .707 .577 .707 r
F P
0 g
s
.49621 .57361 m .49435 .51948 L .49729 .53038 L p .707 .577 .707 r
F P
0 g
s
.68658 .7115 m .68538 .69405 L .71464 .68708 L p .707 .577 .707 r
F P
0 g
s
.29348 .53195 m .29533 .58608 L .29827 .59697 L p .707 .577 .707 r
F P
0 g
s
.29782 .63513 m .30076 .66942 L .31353 .68166 L p .707 .577 .707 r
F P
0 g
s
.31231 .73518 m .31111 .71772 L .2984 .70625 L p .707 .577 .707 r
F P
0 g
s
.77754 .6851 m .77875 .70255 L .7476 .70145 L p .707 .577 .707 r
F P
0 g
s
.7476 .70145 m .7464 .68399 L .77754 .6851 L p .707 .577 .707 r
F P
0 g
s
.71464 .68708 m .71584 .70453 L .68658 .7115 L p .707 .577 .707 r
F P
0 g
s
.30076 .66942 m .29782 .63513 L .2947 .62109 L p .707 .577 .707 r
F P
0 g
s
.71584 .70453 m .71464 .68708 L .7464 .68399 L p .707 .577 .707 r
F P
0 g
s
.29533 .58608 m .29348 .53195 L .30051 .52098 L p .707 .577 .707 r
F P
0 g
s
.2984 .70625 m .2996 .7237 L .31231 .73518 L p .707 .577 .707 r
F P
0 g
s
.7464 .68399 m .7476 .70145 L .71584 .70453 L p .707 .577 .707 r
F P
0 g
s
.492 .70016 m .4932 .71761 L .50012 .70423 L p .707 .577 .707 r
F P
0 g
s
.50012 .70423 m .49891 .68678 L .492 .70016 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4981 .61256 m .50103 .64685 L .49791 .63281 L p .707 .577 .707 r
F P
0 g
s
.49791 .63281 m .49497 .59852 L .4981 .61256 L p .707 .577 .707 r
F P
0 g
s
.49435 .51948 m .49621 .57361 L .48358 .56386 L p .707 .577 .707 r
F P
0 g
s
.48358 .56386 m .48173 .50974 L .49435 .51948 L p .707 .577 .707 r
F P
0 g
s
.2947 .62109 m .29764 .65539 L .30076 .66942 L p .707 .577 .707 r
F P
0 g
s
.30051 .52098 m .30237 .57511 L .29533 .58608 L p .707 .577 .707 r
F P
0 g
s
.2996 .7237 m .2984 .70625 L .29535 .69318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29764 .65539 m .2947 .62109 L .30153 .60664 L p .707 .577 .707 r
F P
0 g
s
.29535 .69318 m .29655 .71063 L .2996 .7237 L p .707 .577 .707 r
F P
0 g
s
.30237 .57511 m .30051 .52098 L .31684 .51101 L p .707 .577 .707 r
F P
0 g
s
.49891 .68678 m .50012 .70423 L .49707 .69116 L p .707 .577 .707 r
F P
0 g
s
.49707 .69116 m .49586 .67371 L .49891 .68678 L p .707 .577 .707 r
F P
0 g
s
.49497 .59852 m .49791 .63281 L .48514 .62057 L p .707 .577 .707 r
F P
0 g
s
.48514 .62057 m .4822 .58628 L .49497 .59852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48173 .50974 m .48358 .56386 L .46251 .55621 L p .707 .577 .707 r
F P
0 g
s
.46251 .55621 m .46065 .50208 L .48173 .50974 L p .707 .577 .707 r
F P
0 g
s
.30153 .60664 m .30447 .64093 L .29764 .65539 L p .707 .577 .707 r
F P
0 g
s
.31684 .51101 m .3187 .56514 L .30237 .57511 L p .707 .577 .707 r
F P
0 g
s
.29655 .71063 m .29535 .69318 L .30226 .67979 L p .707 .577 .707 r
F P
0 g
s
.3187 .56514 m .31684 .51101 L .34085 .50301 L p .707 .577 .707 r
F P
0 g
s
.30447 .64093 m .30153 .60664 L .31765 .59319 L p .707 .577 .707 r
F P
0 g
s
.30226 .67979 m .30347 .69725 L .29655 .71063 L p .707 .577 .707 r
F P
0 g
s
.49586 .67371 m .49707 .69116 L .48436 .67968 L p .707 .577 .707 r
F P
0 g
s
.48436 .67968 m .48315 .66223 L .49586 .67371 L p .707 .577 .707 r
F P
0 g
s
.4822 .58628 m .48514 .62057 L .46397 .61132 L p .707 .577 .707 r
F P
0 g
s
.46397 .61132 m .46103 .57703 L .4822 .58628 L p .707 .577 .707 r
F P
0 g
s
.46065 .50208 m .46251 .55621 L .43504 .55141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55141 m .43318 .49728 L .46065 .50208 L p .707 .577 .707 r
F P
0 g
s
.31765 .59319 m .32059 .62748 L .30447 .64093 L p .707 .577 .707 r
F P
0 g
s
.34271 .55714 m .34085 .50301 L .3702 .49777 L p .707 .577 .707 r
F P
0 g
s
.34085 .50301 m .34271 .55714 L .3187 .56514 L p .707 .577 .707 r
F P
0 g
s
.30347 .69725 m .30226 .67979 L .31846 .66741 L p .707 .577 .707 r
F P
0 g
s
.32059 .62748 m .31765 .59319 L .34148 .58205 L p .707 .577 .707 r
F P
0 g
s
.43318 .49728 m .43504 .55141 L .40387 .54992 L p .707 .577 .707 r
F P
0 g
s
.40387 .54992 m .40202 .49579 L .43318 .49728 L p .707 .577 .707 r
F P
0 g
s
.37206 .55189 m .3702 .49777 L .40202 .49579 L p .707 .577 .707 r
F P
0 g
s
.3702 .49777 m .37206 .55189 L .34271 .55714 L p .707 .577 .707 r
F P
0 g
s
.31846 .66741 m .31967 .68486 L .30347 .69725 L p .707 .577 .707 r
F P
0 g
s
.46103 .57703 m .46397 .61132 L .43647 .60596 L p .707 .577 .707 r
F P
0 g
s
.43647 .60596 m .43353 .57167 L .46103 .57703 L p .707 .577 .707 r
F P
0 g
s
.40202 .49579 m .40387 .54992 L .37206 .55189 L p .707 .577 .707 r
F P
0 g
s
.48315 .66223 m .48436 .67968 L .46322 .67092 L p .707 .577 .707 r
F P
0 g
s
.46322 .67092 m .46202 .65347 L .48315 .66223 L p .707 .577 .707 r
F P
0 g
s
.34148 .58205 m .34441 .61634 L .32059 .62748 L p .707 .577 .707 r
F P
0 g
s
.34441 .61634 m .34148 .58205 L .37068 .57431 L p .707 .577 .707 r
F P
0 g
s
.31967 .68486 m .31846 .66741 L .34237 .65723 L p .707 .577 .707 r
F P
0 g
s
.43353 .57167 m .43647 .60596 L .40534 .60503 L p .707 .577 .707 r
F P
0 g
s
.40534 .60503 m .4024 .57073 L .43353 .57167 L p .707 .577 .707 r
F P
0 g
s
.37362 .6086 m .37068 .57431 L .4024 .57073 L p .707 .577 .707 r
F P
0 g
s
.37068 .57431 m .37362 .6086 L .34441 .61634 L p .707 .577 .707 r
F P
0 g
s
.4024 .57073 m .40534 .60503 L .37362 .6086 L p .707 .577 .707 r
F P
0 g
s
.34237 .65723 m .34357 .67469 L .31967 .68486 L p .707 .577 .707 r
F P
0 g
s
.46202 .65347 m .46322 .67092 L .43574 .66574 L p .707 .577 .707 r
F P
0 g
s
.43574 .66574 m .43453 .64828 L .46202 .65347 L p .707 .577 .707 r
F P
0 g
s
.34357 .67469 m .34237 .65723 L .37163 .65026 L p .707 .577 .707 r
F P
0 g
s
.43453 .64828 m .43574 .66574 L .40459 .66463 L p .707 .577 .707 r
F P
0 g
s
.40459 .66463 m .40339 .64718 L .43453 .64828 L p .707 .577 .707 r
F P
0 g
s
.37163 .65026 m .37283 .66771 L .34357 .67469 L p .707 .577 .707 r
F P
0 g
s
.37283 .66771 m .37163 .65026 L .40339 .64718 L p .707 .577 .707 r
F P
0 g
s
.40339 .64718 m .40459 .66463 L .37283 .66771 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0006FUH00`00FUIJEP03FUH9001mOol007Ioo`T000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool40007FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool006Yoo`<00003FUH0
05YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00005`001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0035YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001OOol40006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005aoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001HOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol0
0`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0067oo3`00?goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
47oo200015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000g
Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUHE0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002moo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01eYF100015YF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03
001JEP0000AJEP03001JEP0000@000=oo`04001JEUYF0005FUH00`00FUH000020005FUH00`00FUIJ
EP02FUH50004FUH300000eYF001JEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0000=JEP00FUH00UYF2@000eYF3`000eYF00<005YFFUH015YF00@005YF000000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00002FUH20003FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF3`000UYF00<005YFFUH015YF00<005YFFUH00UYF0`000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH0
1UYF00<005YF00000`001EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP03FUH00`00FUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000^Ool005=oo`8000=JEP03001JEUYF009JEP03001JEUYF00@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00<005YFFUH00UYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00Dgoo0P000eYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90009Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001D
Ool01P00FUIJEUYF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH5000JOol50004FUH01@00
FUIJEUYF0000;Woo001DOol01000FUIJEUYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009JEP04001JEUYFFUH2
000?Ool3000<Ool30003FUH300000eYF001JEP02FUH2000]Ool005Eoo`06001JEP00001JEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP05001JEP00001JEP04000;Ool50007Ool400000eYF001JEP05FUH30003FUH2
000]Ool004Moo`T000Ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF0P0000=JEP00FUH015YF
5`001EYF00<005YFFUH015YF00@005YFFUH0009JEP8002eoo`00?Woo2@0015YF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF4@000eYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP03
001JEUYF00AJEP04001JEUYFFUH4000]Ool003Qoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEPP000QJEP03001JEUYF00EJEP@000EJEP03001J
EUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH0
05YF00EJEP03001JEUYF009JEP<002eoo`00=Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH010001eYF00<005YFFUH01UYF00<005YF
FUH00UYF1@0000AJEP00000000=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH200000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH00UYF0`00;Goo000cOol2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJ
EP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP0200000eYF001J
EP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0`0000=JEP00FUH00eYF00<005YF0000;Goo000aOol30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH01000FUIJEUYF100000=oo`0000003P000eYF
00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00008000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEP0002eoo`00;goo
0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00001EYF00@005YF0000009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP8002ioo`00;Woo00<005YFFUH0
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0
00AJEP8000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP000000;Woo000]Ool20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0P001EYF
00@005YFFUH0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03001JEUYF00AJEP800004
FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01000FUH0
00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YF000002moo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00800003FUH005YF00AJEP04001JEUYF0002FUH0
0`00FUIJEP03FUH60004FUH00`00FUIJEP09FUH00`00FUIJEP03FUH01000FUH005YF0`0035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002io
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00UJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00005FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00000P00
1EYF00<005YFFUH02EYF00<005YFFUH00P000eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00D005YF001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP<00003FUH005YF009J
EP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03
001JEUYF00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03
001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF0P000UYF00<005YFFUH00eYF00H005YF001JEP00FUHG0003
FUH20003FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YF
FUH015YF1`0015YF00<005YFFUH00P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<000EJEP03001JEP00
00<00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH00`00FUIJEP02FUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF
00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH010001goo0`0000AJ
EP00FUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0015YF0P000UYF00<005YFFUH00UYF1`001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`0000=JEP00FUH00eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00@005YFFUIJEQ`000ioo`8000=JEP03001o
ogoo02]oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P002Goo1P000UYF
00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH005YF00=JEP04001JEP000003FUH3000VOol01000FUIJEP00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040006Ool90004Ool20002FUH01000FUIJEUYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH20005FUH00`00FUIJEP02000UOol00`00FUH0000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP@000Aoo`H000AJEP03001JEUYF009JEPH000=JEP<000EJEP03001J
EUYF00AJEQL000AJEP03001JEUYF00=JEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP06001JEUYF001JEP001EYF00D005YFFUIJEP0000Uoo`<0
01Qoo`@002eoo`00;7oo00<005YF000015YF00<005YF00001P000goo0P0000=JEP00FUH01eYF00<0
05YFFUH01UYF0P000eYF0P001UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@001EYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF00D005YFFUIJEP0000Qoo`D001Eoo`80
0004FUH005YF000]Ool002aoo`03001JEP0000AJEP800003FUH005YF00AJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00AJEP@0009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF008000=JEP04001JEUYF0002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03
FUH01@00FUIJEUYF000027oo1@0057oo00L005YFFUIJEP00FUH0000]Ool002aoo`03001JEP00009J
EP8000=JEP03001JEUYF00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP04
001JEUYFFUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
0`0000EJEP00FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF00=JEP03001JEUYF00=JEP05001JEUYFFUH00008Ool5000BOol20004
FUH00`00FUH0000]Ool002aoo`03001JEP00008000EJEP<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP06001JEP00001JEP001UYF00<005YFFUH01EYF10001UYF00<005YF
FUH01UYF00@005YFFUH000=JEP80009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH50004FUH00`00FUIJEP03FUH01@00FUIJEUYF00002Goo0`004Goo0P0000=J
EP00FUH00eYF00<005YF0000;Goo000/Ool01@00FUH005YF000015YF0P000eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH01UYF0`001UYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH400000eYF001JEP02FUH00`00FUIJEP03FUH01@00FUIJEUYF000027oo
3`0017oo0P000eYF00<005YFFUH00UYF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP0200000eYF
001JEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH300000eYF001JEP06FUH300000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH300000eYF001J
EP04FUH01P00FUIJEUYF001oo`L000AJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF
009JEP8002ioo`00;7oo0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0003FUH00`00FUH000020005FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP040004FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30002FUH00`00FUIJEP020005FUH00`00FUH000030002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH2000^Ool002aoo`80009JEP80
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
00AJEP03001JEUYF009JEP@00003FUH005YF00MJEP<0009JEPL000QJEP03001JEUYF00IJEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF
009JEPL000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008000AJ
EP03001oogoo02eoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF30000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF00003`000eYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YF00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000UYF00<007ooOol0;Goo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH70009FUH01P00FUH005YF001JEP@00003FUH005YF00AJEP05001JEP00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH3000`Ool002eoo`8000EJEP03001J
EUYF00=JEP03001JEUYF00@000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP04001JEP000005
FUH01@00FUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000UYF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YF000000EJ
EP03001JEUYF00AJEPL000QJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00031o
o`00;Goo0P001EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF00@005YFFUIJEP8000=JEP05001JEP00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP02FUH200001UYF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH30006FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH50004FUH00`00FUH0000_Ool002aoo`03001JEP0000EJEP04001JEUYFFUH20005
FUH00`00FUIJEP05FUH900001eYF001JEUYF001JEP00009JEP03001JEUYF00=JEP800006FUH005YF
001JEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0015YF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH0
0eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000EJ
EP00FUIJEP0002ioo`00;7oo00<005YF00001EYF00@005YF000000MJEP03001JEP0000D000AJEP03
001JEUYF009JEPH00004FUH005YF0003FUH20002Ool2000015YF001JEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF0`0000=JEP00FUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH4
0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P000Woo0P000UYF00<007ooOol0;7oo000/Ool01000
FUIJEP0015YF0P0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH01UYF0P000UYF1@00
1Woo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF0P000eYF00<005YFFUH00UYF
00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001J
EP00008000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP04001JEP000006Ool01000FUH0
0000;Goo000/Ool01000FUIJEP000eYF00<007ooOol01`001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000UYF00<005YF0000100017oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF0`001EYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
15YF0`0027oo00@005YF000002eoo`00;7oo00D005YFFUH005YF008000Aoo`800003FUH005YF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH400001Woo001JEP00FUH000IJ
EP03001JEUYF00MJEP04001JEUYFFUH400000eYF001JEP05FUH30005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEUYF0P000UYF10001UYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH0100037oo0`00;Goo000/Ool00`00FUIJEP020004Ool20003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80004FUH01@00FUH005YF00001EYF00<005YF00001000
00=JEP00FUH01EYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH30002FUH7000AOol2000]Ool002eoo`03001JEP0000=oo`8000EJ
EP03001JEUYF00AJEPL000Qoo`T000EJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP04001J
EUYFFUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP0@000GOol3000]Ool002eoo`@00003Ool0
000000IJEP03001JEUYF00@001Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH01000FUIJEP009Goo00<005YF0000;Goo
000]Ool200001EYF000005YF00001EYF10007Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF1@001EYF00<005YFFUH00P008goo0P0000=JEP00
Ool0;7oo000]Ool00`00FUH00003FUH01000FUIJEUYF0P007goo0`000UYF0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF0P000eYF00<005YF
FUH00P008Goo0P0000=JEP000000;Woo000]Ool20004FUH01000FUH000007Woo0`0000=JEP00FUH0
1EYF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF0P00
00=JEP00FUH00UYF00<007ooOol07Woo00@005YFFUIJEP8002ioo`00;Goo0P0015YF0P0000=JEP00
00000`005goo0`0015YF00<005YFFUH015YF00<005YFFUH04@000eYF00<005YFFUH015YF60001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00FUH000EJEP800003Ool0
000000=JEP03001oogoo01aoo`8000AJEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH00UYF
00@005YFFUIJEPP000Uoo`H000MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
1`001Goo00@005YFFUH001Yoo`@00003FUH005YF00=JEP03001oogoo02eoo`00;7oo00H005YFFUH0
05YF0005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00006FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH30002FUH60007Ool3000GOol30005FUH01@00FUIJ
EUYF0000<7oo000/Ool00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP04
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH20004FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02000015YF000000000goo0P00
00=JEP00Ool04Woo100000=JEP00FUH01UYF00<005YF0000<Goo000/Ool01000FUIJEP000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000Woo00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF10000UYF00@005YF
FUIJEPL00004FUH005YF000<Ool70005FUH00`00FUIJEP05FUH2000bOol002eoo`800004Ool005YF
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00Oomoo`0200000eYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF1`0015YF00@005YFFUIJ
EQ8000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000Woo0P001EYF00<005YF
FUH015YF00<005YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP80009oo`04001JEP00
FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000Woo0`0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000]Ool20003
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUH00000
0goo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10001Goo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000]Ool01000FUH0
00000goo0`0000=JEP00FUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF10000goo0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001Woo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000?Goo000]Ool20002FUH00`00Oomoo`03Ool30005
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040005Ool200000eYF001JEP02FUH20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003Ool30003FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70011Ool002ioo`03001JEUYF00<000Ioo`@00003FUH005YF00MJEP<0009JEPL000Moo`8000=J
EP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001J
EP05FUH00`00FUIJEP0A0018Ool002ioo`04001JEUYF0002FUH20008Ool?000;Ool30005FUH01P00
FUH00000Ool000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00EJ
EP04001JEUYFFUH3001DOol002moo`03001JEP0000AJEPD001Uoo`@00003FUH005YF00EJEP8000=o
o`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP04001J
EUYFFUH3001DOol0031oo`8000EJEP04001JEUYFFUH90009Ool70005FUH00`00FUIJEP03FUH20005
Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP05FUH01@00FUIJEP00
Ool00P00E7oo000aOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH01EYF
0`0000Aoo`00000005Aoo`00<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH00`00FUIJEP04
FUH01`00Oomoogoo001JEP0005Aoo`00=7oo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0`004Goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009oo`<00003FUH007oo05=oo`00=Woo1@0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH0100067oo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF10001EYF00<005YFFUH01EYF00<005YFFUH00P000Woo0P000UYF0P00EGoo000k
Ool90004FUH00`00FUIJEP02FUH7000QOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP090005FUH00`00FUIJEP05FUH30002Ool20004FUH2001EOol004Aoo`T0
02ioo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPP000AJEPD000EJEP03001JEUYF00AJEP80
009oo`800003FUH005YF00=JEP03001oogoo05Aoo`00Q7oo6@0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH010000Woo0P000eYF00<005YFFUH00UYF00<007ooOol0E7oo002?Ool01@00FUIJEP00
FUH00`001Woo2@0015YF0`000UYF1`000goo0`001UYF00@005YFFUH005Moo`00Sgoo00@005YFFUH0
00AJEP<000aoo`T000Ioo`@00003FUH005YF00IJEP<005Qoo`00T7oo00@005YFFUH000AJEP03001J
EP0000<0011oo`L000EJEP03001JEUYF00AJEP8005Yoo`00TGoo0`0015YF00<005YFFUH00eYF4000
15YF00<005YFFUH01UYF00@005YFFUIJEP8005aoo`00Tgoo0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000005ioo`00UGoo0`0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000H7oo002HOol30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001TOol009]oo`@0009JEP03001JEUYF00EJEP03
001JEUYF009JEPL006Qoo`00Wgoo3`00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]28\[InvisibleSpace]"     "\
\[InvisibleSpace]9.714617314885999`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 28, "     ", 9.7146173148859987, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59579 .75929 m .59924 .70419 L .56813 .70034 L p .707 .577 .707 r
F P
0 g
s
.59924 .70419 m .59579 .75929 L .62757 .76027 L p .707 .577 .707 r
F P
0 g
s
.62757 .76027 m .63102 .70517 L .59924 .70419 L p .707 .577 .707 r
F P
0 g
s
.63102 .70517 m .62757 .76027 L .65691 .75829 L p .707 .577 .707 r
F P
0 g
s
.65691 .75829 m .66036 .70319 L .63102 .70517 L p .707 .577 .707 r
F P
0 g
s
.56468 .75543 m .56813 .70034 L .54073 .69399 L p .707 .577 .707 r
F P
0 g
s
.56813 .70034 m .56468 .75543 L .59579 .75929 L p .707 .577 .707 r
F P
0 g
s
.66036 .70319 m .65691 .75829 L .68093 .75354 L p .707 .577 .707 r
F P
0 g
s
.68093 .75354 m .68438 .69844 L .66036 .70319 L p .707 .577 .707 r
F P
0 g
s
.53728 .74909 m .54073 .69399 L .51973 .68578 L p .707 .577 .707 r
F P
0 g
s
.54073 .69399 m .53728 .74909 L .56468 .75543 L p .707 .577 .707 r
F P
0 g
s
.59099 .8152 m .59774 .77954 L .5671 .77195 L p .707 .577 .707 r
F P
0 g
s
.59774 .77954 m .59099 .8152 L .62235 .81957 L p .707 .577 .707 r
F P
0 g
s
.62235 .81957 m .6291 .78391 L .59774 .77954 L p .707 .577 .707 r
F P
0 g
s
.6291 .78391 m .62235 .81957 L .65135 .82027 L p .707 .577 .707 r
F P
0 g
s
.65135 .82027 m .6581 .7846 L .6291 .78391 L p .707 .577 .707 r
F P
0 g
s
.56034 .80761 m .5671 .77195 L .54017 .76186 L p .707 .577 .707 r
F P
0 g
s
.5671 .77195 m .56034 .80761 L .59099 .8152 L p .707 .577 .707 r
F P
0 g
s
.59237 .8439 m .59586 .82611 L .56526 .81832 L p .707 .577 .707 r
F P
0 g
s
.59586 .82611 m .59237 .8439 L .62369 .84844 L p .707 .577 .707 r
F P
0 g
s
.62369 .84844 m .62719 .83064 L .59586 .82611 L p .707 .577 .707 r
F P
0 g
s
.68438 .69844 m .68093 .75354 L .69729 .74648 L p .707 .577 .707 r
F P
0 g
s
.69729 .74648 m .70074 .69138 L .68438 .69844 L p .707 .577 .707 r
F P
0 g
s
.51973 .68578 m .51628 .74087 L .53728 .74909 L p .707 .577 .707 r
F P
0 g
s
.54017 .76186 m .53341 .79752 L .56034 .80761 L p .707 .577 .707 r
F P
0 g
s
.6581 .7846 m .65135 .82027 L .67516 .81723 L p .707 .577 .707 r
F P
0 g
s
.67516 .81723 m .68191 .78157 L .6581 .7846 L p .707 .577 .707 r
F P
0 g
s
.62719 .83064 m .62369 .84844 L .65267 .84928 L p .707 .577 .707 r
F P
0 g
s
.65267 .84928 m .65617 .83148 L .62719 .83064 L p .707 .577 .707 r
F P
0 g
s
.56176 .83611 m .56526 .81832 L .53837 .80804 L p .707 .577 .707 r
F P
0 g
s
.56526 .81832 m .56176 .83611 L .59237 .8439 L p .707 .577 .707 r
F P
0 g
s
.53341 .79752 m .54017 .76186 L .51959 .75027 L p .707 .577 .707 r
F P
0 g
s
.51628 .74087 m .51973 .68578 L .50718 .6765 L p .707 .577 .707 r
F P
0 g
s
.53837 .80804 m .53487 .82583 L .56176 .83611 L p .707 .577 .707 r
F P
0 g
s
.65617 .83148 m .65267 .84928 L .67646 .84633 L p .707 .577 .707 r
F P
0 g
s
.67646 .84633 m .67996 .82854 L .65617 .83148 L p .707 .577 .707 r
F P
0 g
s
.51959 .75027 m .51284 .78593 L .53341 .79752 L p .707 .577 .707 r
F P
0 g
s
.53487 .82583 m .53837 .80804 L .51782 .79627 L p .707 .577 .707 r
F P
0 g
s
.68191 .78157 m .67516 .81723 L .69144 .81077 L p .707 .577 .707 r
F P
0 g
s
.69144 .81077 m .6982 .77511 L .68191 .78157 L p .707 .577 .707 r
F P
0 g
s
.51782 .79627 m .51433 .81406 L .53487 .82583 L p .707 .577 .707 r
F P
0 g
s
.50718 .6765 m .50373 .73159 L .51628 .74087 L p .707 .577 .707 r
F P
0 g
s
.51284 .78593 m .51959 .75027 L .50738 .73831 L p .707 .577 .707 r
F P
0 g
s
.70074 .69138 m .69729 .74648 L .70438 .7378 L p .707 .577 .707 r
F P
0 g
s
.70438 .7378 m .70783 .68271 L .70074 .69138 L p .707 .577 .707 r
F P
0 g
s
.50373 .73159 m .50718 .6765 L .50431 .66706 L p .707 .577 .707 r
F P
0 g
s
.67996 .82854 m .67646 .84633 L .69274 .8399 L p .707 .577 .707 r
F P
0 g
s
.69274 .8399 m .69624 .8221 L .67996 .82854 L p .707 .577 .707 r
F P
0 g
s
.50738 .73831 m .50062 .77397 L .51284 .78593 L p .707 .577 .707 r
F P
0 g
s
.51433 .81406 m .51782 .79627 L .50564 .78417 L p .707 .577 .707 r
F P
0 g
s
.50564 .78417 m .50214 .80196 L .51433 .81406 L p .707 .577 .707 r
F P
0 g
s
.6982 .77511 m .69144 .81077 L .69861 .8015 L p .707 .577 .707 r
F P
0 g
s
.69861 .8015 m .70537 .76584 L .6982 .77511 L p .707 .577 .707 r
F P
0 g
s
.50431 .66706 m .50086 .72215 L .50373 .73159 L p .707 .577 .707 r
F P
0 g
s
.50062 .77397 m .50738 .73831 L .50472 .72714 L p .707 .577 .707 r
F P
0 g
s
.70783 .68271 m .70438 .7378 L .70152 .72837 L p .707 .577 .707 r
F P
0 g
s
.70152 .72837 m .70497 .67327 L .70783 .68271 L p .707 .577 .707 r
F P
0 g
s
.49821 .82185 m .48943 .3191 L .44543 .3172 L p .707 .577 .707 r
F P
0 g
s
.50472 .72714 m .49797 .76281 L .50062 .77397 L p .707 .577 .707 r
F P
0 g
s
.50086 .72215 m .50431 .66706 L .5114 .65838 L p .707 .577 .707 r
F P
0 g
s
.50214 .80196 m .50564 .78417 L .503 .77292 L p .707 .577 .707 r
F P
0 g
s
.503 .77292 m .49951 .79071 L .50214 .80196 L p .707 .577 .707 r
F P
0 g
s
.49797 .76281 m .50472 .72714 L .51189 .71788 L p .707 .577 .707 r
F P
0 g
s
.5114 .65838 m .50795 .71348 L .50086 .72215 L p .707 .577 .707 r
F P
0 g
s
.51189 .71788 m .50514 .75354 L .49797 .76281 L p .707 .577 .707 r
F P
0 g
s
.50795 .71348 m .5114 .65838 L .52776 .65132 L p .707 .577 .707 r
F P
0 g
s
.49951 .79071 m .503 .77292 L .51017 .76362 L p .707 .577 .707 r
F P
0 g
s
.51017 .76362 m .50668 .78141 L .49951 .79071 L p .707 .577 .707 r
F P
0 g
s
.50514 .75354 m .51189 .71788 L .52818 .71141 L p .707 .577 .707 r
F P
0 g
s
.52776 .65132 m .52431 .70642 L .50795 .71348 L p .707 .577 .707 r
F P
0 g
s
.52431 .70642 m .52776 .65132 L .55179 .64657 L p .707 .577 .707 r
F P
0 g
s
.52818 .71141 m .52142 .74707 L .50514 .75354 L p .707 .577 .707 r
F P
0 g
s
.50668 .78141 m .51017 .76362 L .52645 .75719 L p .707 .577 .707 r
F P
0 g
s
.52645 .75719 m .52296 .77498 L .50668 .78141 L p .707 .577 .707 r
F P
0 g
s
.52142 .74707 m .52818 .71141 L .55199 .70838 L p .707 .577 .707 r
F P
0 g
s
.55179 .64657 m .54834 .70167 L .52431 .70642 L p .707 .577 .707 r
F P
0 g
s
.55199 .70838 m .54523 .74404 L .52142 .74707 L p .707 .577 .707 r
F P
0 g
s
.52296 .77498 m .52645 .75719 L .55024 .75424 L p .707 .577 .707 r
F P
0 g
s
.55024 .75424 m .54675 .77204 L .52296 .77498 L p .707 .577 .707 r
F P
0 g
s
.48943 .3191 m .49821 .82185 L .54314 .82005 L p .707 .577 .707 r
F P
0 g
s
.54314 .82005 m .53437 .3173 L .48943 .3191 L p .707 .577 .707 r
F P
0 g
s
.69624 .8221 m .69274 .8399 L .69992 .8306 L p .707 .577 .707 r
F P
0 g
s
.69992 .8306 m .70341 .81281 L .69624 .8221 L p .707 .577 .707 r
F P
0 g
s
.54834 .70167 m .55179 .64657 L .58113 .64459 L p .707 .577 .707 r
F P
0 g
s
.58113 .64459 m .57768 .69969 L .54834 .70167 L p .707 .577 .707 r
F P
0 g
s
.54523 .74404 m .55199 .70838 L .58099 .70908 L p .707 .577 .707 r
F P
0 g
s
.58099 .70908 m .57424 .74474 L .54523 .74404 L p .707 .577 .707 r
F P
0 g
s
.57424 .74474 m .58099 .70908 L .61235 .71344 L p .707 .577 .707 r
F P
0 g
s
.54675 .77204 m .55024 .75424 L .57922 .75508 L p .707 .577 .707 r
F P
0 g
s
.61235 .71344 m .60559 .7491 L .57424 .74474 L p .707 .577 .707 r
F P
0 g
s
.57922 .75508 m .57573 .77288 L .54675 .77204 L p .707 .577 .707 r
F P
0 g
s
.57573 .77288 m .57922 .75508 L .61055 .75962 L p .707 .577 .707 r
F P
0 g
s
.61055 .75962 m .60705 .77741 L .57573 .77288 L p .707 .577 .707 r
F P
0 g
s
.53437 .3173 m .54314 .82005 L .58462 .81472 L p .707 .577 .707 r
F P
0 g
s
.57768 .69969 m .58113 .64459 L .61291 .64557 L p .707 .577 .707 r
F P
0 g
s
.61291 .64557 m .60946 .70067 L .57768 .69969 L p .707 .577 .707 r
F P
0 g
s
.58462 .81472 m .57584 .31197 L .53437 .3173 L p .707 .577 .707 r
F P
0 g
s
.4542 .81995 m .44543 .3172 L .40667 .31178 L p .707 .577 .707 r
F P
0 g
s
.44543 .3172 m .4542 .81995 L .49821 .82185 L p .707 .577 .707 r
F P
0 g
s
.70537 .76584 m .69861 .8015 L .69596 .79034 L p .707 .577 .707 r
F P
0 g
s
.69596 .79034 m .70271 .75468 L .70537 .76584 L p .707 .577 .707 r
F P
0 g
s
.64299 .72104 m .63624 .7567 L .60559 .7491 L p .707 .577 .707 r
F P
0 g
s
.60559 .7491 m .61235 .71344 L .64299 .72104 L p .707 .577 .707 r
F P
0 g
s
.64115 .76741 m .63766 .7852 L .60705 .77741 L p .707 .577 .707 r
F P
0 g
s
.60705 .77741 m .61055 .75962 L .64115 .76741 L p .707 .577 .707 r
F P
0 g
s
.57584 .31197 m .58462 .81472 L .61857 .80639 L p .707 .577 .707 r
F P
0 g
s
.64402 .64943 m .64057 .70452 L .60946 .70067 L p .707 .577 .707 r
F P
0 g
s
.60946 .70067 m .61291 .64557 L .64402 .64943 L p .707 .577 .707 r
F P
0 g
s
.61857 .80639 m .6098 .30364 L .57584 .31197 L p .707 .577 .707 r
F P
0 g
s
.70497 .67327 m .70152 .72837 L .68897 .71908 L p .707 .577 .707 r
F P
0 g
s
.68897 .71908 m .69242 .66399 L .70497 .67327 L p .707 .577 .707 r
F P
0 g
s
.25278 .70662 m .25623 .65152 L .22512 .64767 L p .707 .577 .707 r
F P
0 g
s
.25623 .65152 m .25278 .70662 L .28456 .7076 L p .707 .577 .707 r
F P
0 g
s
.28456 .7076 m .28801 .65251 L .25623 .65152 L p .707 .577 .707 r
F P
0 g
s
.70341 .81281 m .69992 .8306 L .69728 .81935 L p .707 .577 .707 r
F P
0 g
s
.69728 .81935 m .70077 .80156 L .70341 .81281 L p .707 .577 .707 r
F P
0 g
s
.28801 .65251 m .28456 .7076 L .3139 .70562 L p .707 .577 .707 r
F P
0 g
s
.3139 .70562 m .31735 .65053 L .28801 .65251 L p .707 .577 .707 r
F P
0 g
s
.41545 .81453 m .40667 .31178 L .37695 .30337 L p .707 .577 .707 r
F P
0 g
s
.40667 .31178 m .41545 .81453 L .4542 .81995 L p .707 .577 .707 r
F P
0 g
s
.22167 .70277 m .22512 .64767 L .19772 .64133 L p .707 .577 .707 r
F P
0 g
s
.22512 .64767 m .22167 .70277 L .25278 .70662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31735 .65053 m .3139 .70562 L .33792 .70087 L p .707 .577 .707 r
F P
0 g
s
.33792 .70087 m .34137 .64577 L .31735 .65053 L p .707 .577 .707 r
F P
0 g
s
.70271 .75468 m .69596 .79034 L .68374 .77838 L p .707 .577 .707 r
F P
0 g
s
.68374 .77838 m .6905 .74272 L .70271 .75468 L p .707 .577 .707 r
F P
0 g
s
.19427 .69642 m .19772 .64133 L .17672 .63311 L p .707 .577 .707 r
F P
0 g
s
.19772 .64133 m .19427 .69642 L .22167 .70277 L p .707 .577 .707 r
F P
0 g
s
.66992 .73113 m .66317 .76679 L .63624 .7567 L p .707 .577 .707 r
F P
0 g
s
.63624 .7567 m .64299 .72104 L .66992 .73113 L p .707 .577 .707 r
F P
0 g
s
.66804 .77769 m .66455 .79548 L .63766 .7852 L p .707 .577 .707 r
F P
0 g
s
.63766 .7852 m .64115 .76741 L .66804 .77769 L p .707 .577 .707 r
F P
0 g
s
.6098 .30364 m .61857 .80639 L .64168 .79586 L p .707 .577 .707 r
F P
0 g
s
.64168 .79586 m .63291 .29311 L .6098 .30364 L p .707 .577 .707 r
F P
0 g
s
.69242 .66399 m .68897 .71908 L .66797 .71087 L p .707 .577 .707 r
F P
0 g
s
.66797 .71087 m .67142 .65577 L .69242 .66399 L p .707 .577 .707 r
F P
0 g
s
.24798 .77743 m .25473 .74177 L .22409 .73417 L p .707 .577 .707 r
F P
0 g
s
.25473 .74177 m .24798 .77743 L .27934 .78179 L p .707 .577 .707 r
F P
0 g
s
.27934 .78179 m .28609 .74613 L .25473 .74177 L p .707 .577 .707 r
F P
0 g
s
.28609 .74613 m .27934 .78179 L .30834 .78249 L p .707 .577 .707 r
F P
0 g
s
.30834 .78249 m .31509 .74683 L .28609 .74613 L p .707 .577 .707 r
F P
0 g
s
.21733 .76983 m .22409 .73417 L .19716 .72408 L p .707 .577 .707 r
F P
0 g
s
.22409 .73417 m .21733 .76983 L .24798 .77743 L p .707 .577 .707 r
F P
0 g
s
.70077 .80156 m .69728 .81935 L .68509 .80725 L p .707 .577 .707 r
F P
0 g
s
.68509 .80725 m .68859 .78946 L .70077 .80156 L p .707 .577 .707 r
F P
0 g
s
.34137 .64577 m .33792 .70087 L .35428 .69381 L p .707 .577 .707 r
F P
0 g
s
.35428 .69381 m .35773 .63871 L .34137 .64577 L p .707 .577 .707 r
F P
0 g
s
.38573 .80612 m .37695 .30337 L .35918 .2928 L p .707 .577 .707 r
F P
0 g
s
.37695 .30337 m .38573 .80612 L .41545 .81453 L p .707 .577 .707 r
F P
0 g
s
.17672 .63311 m .17327 .68821 L .19427 .69642 L p .707 .577 .707 r
F P
0 g
s
.19716 .72408 m .19041 .75974 L .21733 .76983 L p .707 .577 .707 r
F P
0 g
s
.31509 .74683 m .30834 .78249 L .33215 .77946 L p .707 .577 .707 r
F P
0 g
s
.33215 .77946 m .3389 .7438 L .31509 .74683 L p .707 .577 .707 r
F P
0 g
s
.17327 .68821 m .17672 .63311 L .16417 .62383 L p .707 .577 .707 r
F P
0 g
s
.19041 .75974 m .19716 .72408 L .17658 .71249 L p .707 .577 .707 r
F P
0 g
s
.67142 .65577 m .66797 .71087 L .64057 .70452 L p .707 .577 .707 r
F P
0 g
s
.64057 .70452 m .64402 .64943 L .67142 .65577 L p .707 .577 .707 r
F P
0 g
s
.6905 .74272 m .68374 .77838 L .66317 .76679 L p .707 .577 .707 r
F P
0 g
s
.66317 .76679 m .66992 .73113 L .6905 .74272 L p .707 .577 .707 r
F P
0 g
s
.24936 .83341 m .25286 .81561 L .22225 .80782 L p .707 .577 .707 r
F P
0 g
s
.25286 .81561 m .24936 .83341 L .28069 .83794 L p .707 .577 .707 r
F P
0 g
s
.28069 .83794 m .28418 .82015 L .25286 .81561 L p .707 .577 .707 r
F P
0 g
s
.28418 .82015 m .28069 .83794 L .30966 .83878 L p .707 .577 .707 r
F P
0 g
s
.30966 .83878 m .31316 .82098 L .28418 .82015 L p .707 .577 .707 r
F P
0 g
s
.21876 .82561 m .22225 .80782 L .19536 .79754 L p .707 .577 .707 r
F P
0 g
s
.22225 .80782 m .21876 .82561 L .24936 .83341 L p .707 .577 .707 r
F P
0 g
s
.17658 .71249 m .16983 .74815 L .19041 .75974 L p .707 .577 .707 r
F P
0 g
s
.19536 .79754 m .19186 .81533 L .21876 .82561 L p .707 .577 .707 r
F P
0 g
s
.63291 .29311 m .64168 .79586 L .65168 .78418 L p .707 .577 .707 r
F P
0 g
s
.65168 .78418 m .64291 .28143 L .63291 .29311 L p .707 .577 .707 r
F P
0 g
s
.68859 .78946 m .68509 .80725 L .66455 .79548 L p .707 .577 .707 r
F P
0 g
s
.66455 .79548 m .66804 .77769 L .68859 .78946 L p .707 .577 .707 r
F P
0 g
s
.16417 .62383 m .16072 .67893 L .17327 .68821 L p .707 .577 .707 r
F P
0 g
s
.35773 .63871 m .35428 .69381 L .36138 .68514 L p .707 .577 .707 r
F P
0 g
s
.36138 .68514 m .36483 .63004 L .35773 .63871 L p .707 .577 .707 r
F P
0 g
s
.3389 .7438 m .33215 .77946 L .34843 .77299 L p .707 .577 .707 r
F P
0 g
s
.34843 .77299 m .35519 .73733 L .3389 .7438 L p .707 .577 .707 r
F P
0 g
s
.31316 .82098 m .30966 .83878 L .33346 .83584 L p .707 .577 .707 r
F P
0 g
s
.33346 .83584 m .33695 .81804 L .31316 .82098 L p .707 .577 .707 r
F P
0 g
s
.19186 .81533 m .19536 .79754 L .17481 .78577 L p .707 .577 .707 r
F P
0 g
s
.16983 .74815 m .17658 .71249 L .16437 .70053 L p .707 .577 .707 r
F P
0 g
s
.16072 .67893 m .16417 .62383 L .1613 .61439 L p .707 .577 .707 r
F P
0 g
s
.17481 .78577 m .17132 .80357 L .19186 .81533 L p .707 .577 .707 r
F P
0 g
s
.36483 .63004 m .36138 .68514 L .35851 .6757 L p .707 .577 .707 r
F P
0 g
s
.35851 .6757 m .36196 .6206 L .36483 .63004 L p .707 .577 .707 r
F P
0 g
s
.36795 .79555 m .35918 .2928 L .35509 .2811 L p .707 .577 .707 r
F P
0 g
s
.35918 .2928 m .36795 .79555 L .38573 .80612 L p .707 .577 .707 r
F P
0 g
s
.16437 .70053 m .15761 .73619 L .16983 .74815 L p .707 .577 .707 r
F P
0 g
s
.33695 .81804 m .33346 .83584 L .34973 .8294 L p .707 .577 .707 r
F P
0 g
s
.34973 .8294 m .35323 .81161 L .33695 .81804 L p .707 .577 .707 r
F P
0 g
s
.17132 .80357 m .17481 .78577 L .16263 .77367 L p .707 .577 .707 r
F P
0 g
s
.1613 .61439 m .15785 .66949 L .16072 .67893 L p .707 .577 .707 r
F P
0 g
s
.35519 .73733 m .34843 .77299 L .3556 .76373 L p .707 .577 .707 r
F P
0 g
s
.3556 .76373 m .36236 .72806 L .35519 .73733 L p .707 .577 .707 r
F P
0 g
s
.15761 .73619 m .16437 .70053 L .16172 .68937 L p .707 .577 .707 r
F P
0 g
s
.16263 .77367 m .15913 .79146 L .17132 .80357 L p .707 .577 .707 r
F P
0 g
s
.64291 .28143 m .65168 .78418 L .64789 .77331 L p .707 .577 .707 r
F P
0 g
s
.64754 .76699 m .64291 .28143 L .64789 .77331 L .707 .577 .707 r
F
.63882 .26973 m .64291 .28143 L p .64642 .64895 L F P
0 g
s
.6476 .77248 m .64539 .6458 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.64539 .6458 m .63882 .26973 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.63882 .26973 m .6476 .77248 L .62982 .7619 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64152 .57502 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64093 .63955 m .64132 .63339 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64132 .63339 m .64438 .58446 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64458 .64627 m .6418 .66095 L p .65004 .69389 L .707 .577 .707 r
F P
0 g
s
.6418 .66095 m .63783 .68193 L .64322 .68721 L p .707 .577 .707 r
F P
0 g
s
.64322 .68721 m .65004 .69389 L p .6418 .66095 L .707 .577 .707 r
F P
0 g
s
.64789 .77331 m .6476 .77248 L p .64754 .76699 L .707 .577 .707 r
F P
0 g
s
.15785 .66949 m .1613 .61439 L .16839 .60572 L p .707 .577 .707 r
F P
0 g
s
.16172 .68937 m .15496 .72503 L .15761 .73619 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35323 .81161 m .34973 .8294 L .35691 .8201 L p .707 .577 .707 r
F P
0 g
s
.35691 .8201 m .3604 .80231 L .35323 .81161 L p .707 .577 .707 r
F P
0 g
s
.15913 .79146 m .16263 .77367 L .15999 .76242 L p .707 .577 .707 r
F P
0 g
s
.16839 .60572 m .16494 .66081 L .15785 .66949 L p .707 .577 .707 r
F P
0 g
s
.15999 .76242 m .1565 .78021 L .15913 .79146 L p .707 .577 .707 r
F P
0 g
s
.36196 .6206 m .35851 .6757 L .34596 .66642 L p .707 .577 .707 r
F P
0 g
s
.34596 .66642 m .34941 .61132 L .36196 .6206 L p .707 .577 .707 r
F P
0 g
s
.35509 .2811 m .36387 .78385 L .36795 .79555 L p .707 .577 .707 r
F P
0 g
s
.36387 .78385 m .35509 .2811 L .36509 .26941 L p .707 .577 .707 r
F P
0 g
s
.36236 .72806 m .3556 .76373 L .35295 .75256 L p .707 .577 .707 r
F P
0 g
s
.35295 .75256 m .3597 .7169 L .36236 .72806 L p .707 .577 .707 r
F P
0 g
s
.15496 .72503 m .16172 .68937 L .16888 .6801 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16494 .66081 m .16839 .60572 L .18475 .59866 L p .707 .577 .707 r
F P
0 g
s
.16888 .6801 m .16213 .71576 L .15496 .72503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3604 .80231 m .35691 .8201 L .35427 .80886 L p .707 .577 .707 r
F P
0 g
s
.35427 .80886 m .35776 .79106 L .3604 .80231 L p .707 .577 .707 r
F P
0 g
s
.1565 .78021 m .15999 .76242 L .16716 .75312 L p .707 .577 .707 r
F P
0 g
s
.62982 .7619 m .62105 .25916 L .63882 .26973 L p .707 .577 .707 r
F P
0 g
s
.18475 .59866 m .1813 .65375 L .16494 .66081 L p .707 .577 .707 r
F P
0 g
s
.16716 .75312 m .16367 .77092 L .1565 .78021 L p .707 .577 .707 r
F P
0 g
s
.3597 .7169 m .35295 .75256 L .34073 .7406 L p .707 .577 .707 r
F P
0 g
s
.34073 .7406 m .34749 .70494 L .3597 .7169 L p .707 .577 .707 r
F P
0 g
s
.34941 .61132 m .34596 .66642 L .32496 .6582 L p .707 .577 .707 r
F P
0 g
s
.32496 .6582 m .32841 .6031 L .34941 .61132 L p .707 .577 .707 r
F P
0 g
s
.16213 .71576 m .16888 .6801 L .18517 .67364 L p .707 .577 .707 r
F P
0 g
s
.1813 .65375 m .18475 .59866 L .20878 .5939 L p .707 .577 .707 r
F P
0 g
s
.37387 .77216 m .36509 .26941 L .3882 .25889 L p .707 .577 .707 r
F P
0 g
s
.36509 .26941 m .37387 .77216 L .36387 .78385 L p .707 .577 .707 r
F P
0 g
s
.18517 .67364 m .17841 .7093 L .16213 .71576 L p .707 .577 .707 r
F P
0 g
s
.35776 .79106 m .35427 .80886 L .34208 .79675 L p .707 .577 .707 r
F P
0 g
s
.34208 .79675 m .34558 .77896 L .35776 .79106 L p .707 .577 .707 r
F P
0 g
s
.32841 .6031 m .32496 .6582 L .29756 .65186 L p .707 .577 .707 r
F P
0 g
s
.29756 .65186 m .30101 .59676 L .32841 .6031 L p .707 .577 .707 r
F P
0 g
s
.16367 .77092 m .16716 .75312 L .18344 .74669 L p .707 .577 .707 r
F P
0 g
s
.20878 .5939 m .20533 .649 L .1813 .65375 L p .707 .577 .707 r
F P
0 g
s
.34749 .70494 m .34073 .7406 L .32016 .72901 L p .707 .577 .707 r
F P
0 g
s
.32016 .72901 m .32691 .69335 L .34749 .70494 L p .707 .577 .707 r
F P
0 g
s
.20533 .649 m .20878 .5939 L .23812 .59192 L p .707 .577 .707 r
F P
0 g
s
.17841 .7093 m .18517 .67364 L .20898 .6706 L p .707 .577 .707 r
F P
0 g
s
.18344 .74669 m .17995 .76448 L .16367 .77092 L p .707 .577 .707 r
F P
0 g
s
.62105 .25916 m .62982 .7619 L .6001 .7535 L p .707 .577 .707 r
F P
0 g
s
.6001 .7535 m .59133 .25075 L .62105 .25916 L p .707 .577 .707 r
F P
0 g
s
.30101 .59676 m .29756 .65186 L .26645 .648 L p .707 .577 .707 r
F P
0 g
s
.26645 .648 m .2699 .59291 L .30101 .59676 L p .707 .577 .707 r
F P
0 g
s
.23467 .64702 m .23812 .59192 L .2699 .59291 L p .707 .577 .707 r
F P
0 g
s
.23812 .59192 m .23467 .64702 L .20533 .649 L p .707 .577 .707 r
F P
0 g
s
.20898 .6706 m .20222 .70627 L .17841 .7093 L p .707 .577 .707 r
F P
0 g
s
.2699 .59291 m .26645 .648 L .23467 .64702 L p .707 .577 .707 r
F P
0 g
s
.34558 .77896 m .34208 .79675 L .32154 .78499 L p .707 .577 .707 r
F P
0 g
s
.32154 .78499 m .32503 .76719 L .34558 .77896 L p .707 .577 .707 r
F P
0 g
s
.32691 .69335 m .32016 .72901 L .29323 .71892 L p .707 .577 .707 r
F P
0 g
s
.29323 .71892 m .29998 .68326 L .32691 .69335 L p .707 .577 .707 r
F P
0 g
s
.17995 .76448 m .18344 .74669 L .20723 .74375 L p .707 .577 .707 r
F P
0 g
s
.20222 .70627 m .20898 .6706 L .23798 .6713 L p .707 .577 .707 r
F P
0 g
s
.3882 .25889 m .39698 .76164 L .37387 .77216 L p .707 .577 .707 r
F P
0 g
s
.39698 .76164 m .3882 .25889 L .42216 .25055 L p .707 .577 .707 r
F P
0 g
s
.73299 .66725 m .73644 .61215 L .70533 .6083 L p .707 .577 .707 r
F P
0 g
s
.73644 .61215 m .73299 .66725 L .76477 .66823 L p .707 .577 .707 r
F P
0 g
s
.76477 .66823 m .76822 .61314 L .73644 .61215 L p .707 .577 .707 r
F P
0 g
s
.76822 .61314 m .76477 .66823 L .79411 .66625 L p .707 .577 .707 r
F P
0 g
s
.79411 .66625 m .79756 .61115 L .76822 .61314 L p .707 .577 .707 r
F P
0 g
s
.20723 .74375 m .20374 .76154 L .17995 .76448 L p .707 .577 .707 r
F P
0 g
s
.70188 .6634 m .70533 .6083 L .67793 .60195 L p .707 .577 .707 r
F P
0 g
s
.70533 .6083 m .70188 .6634 L .73299 .66725 L p .707 .577 .707 r
F P
0 g
s
.23798 .6713 m .23123 .70696 L .20222 .70627 L p .707 .577 .707 r
F P
0 g
s
.29998 .68326 m .29323 .71892 L .26258 .71133 L p .707 .577 .707 r
F P
0 g
s
.26258 .71133 m .26934 .67566 L .29998 .68326 L p .707 .577 .707 r
F P
0 g
s
.23123 .70696 m .23798 .6713 L .26934 .67566 L p .707 .577 .707 r
F P
0 g
s
.59133 .25075 m .6001 .7535 L .56135 .74808 L p .707 .577 .707 r
F P
0 g
s
.56135 .74808 m .55257 .24533 L .59133 .25075 L p .707 .577 .707 r
F P
0 g
s
.79756 .61115 m .79411 .66625 L .81814 .6615 L p .707 .577 .707 r
F P
0 g
s
.81814 .6615 m .82159 .6064 L .79756 .61115 L p .707 .577 .707 r
F P
0 g
s
.26934 .67566 m .26258 .71133 L .23123 .70696 L p .707 .577 .707 r
F P
0 g
s
.32503 .76719 m .32154 .78499 L .29465 .7747 L p .707 .577 .707 r
F P
0 g
s
.29465 .7747 m .29814 .75691 L .32503 .76719 L p .707 .577 .707 r
F P
0 g
s
.20374 .76154 m .20723 .74375 L .23621 .74458 L p .707 .577 .707 r
F P
0 g
s
.67448 .65705 m .67793 .60195 L .65693 .59374 L p .707 .577 .707 r
F P
0 g
s
.67793 .60195 m .67448 .65705 L .70188 .6634 L p .707 .577 .707 r
F P
0 g
s
.72819 .72317 m .73495 .68751 L .7043 .67991 L p .707 .577 .707 r
F P
0 g
s
.73495 .68751 m .72819 .72317 L .75955 .72753 L p .707 .577 .707 r
F P
0 g
s
.75955 .72753 m .7663 .69187 L .73495 .68751 L p .707 .577 .707 r
F P
0 g
s
.23621 .74458 m .23272 .76238 L .20374 .76154 L p .707 .577 .707 r
F P
0 g
s
.7663 .69187 m .75955 .72753 L .78855 .72823 L p .707 .577 .707 r
F P
0 g
s
.78855 .72823 m .79531 .69257 L .7663 .69187 L p .707 .577 .707 r
F P
0 g
s
.69755 .71557 m .7043 .67991 L .67737 .66982 L p .707 .577 .707 r
F P
0 g
s
.7043 .67991 m .69755 .71557 L .72819 .72317 L p .707 .577 .707 r
F P
0 g
s
.43093 .7533 m .42216 .25055 L .46363 .24522 L p .707 .577 .707 r
F P
0 g
s
.42216 .25055 m .43093 .7533 L .39698 .76164 L p .707 .577 .707 r
F P
0 g
s
.29814 .75691 m .29465 .7747 L .26404 .76691 L p .707 .577 .707 r
F P
0 g
s
.26404 .76691 m .26754 .74912 L .29814 .75691 L p .707 .577 .707 r
F P
0 g
s
.23272 .76238 m .23621 .74458 L .26754 .74912 L p .707 .577 .707 r
F P
0 g
s
.72957 .75186 m .73307 .73407 L .70246 .72628 L p .707 .577 .707 r
F P
0 g
s
.73307 .73407 m .72957 .75186 L .7609 .7564 L p .707 .577 .707 r
F P
0 g
s
.7609 .7564 m .76439 .73861 L .73307 .73407 L p .707 .577 .707 r
F P
0 g
s
.82159 .6064 m .81814 .6615 L .8345 .65444 L p .707 .577 .707 r
F P
0 g
s
.8345 .65444 m .83795 .59934 L .82159 .6064 L p .707 .577 .707 r
F P
0 g
s
.26754 .74912 m .26404 .76691 L .23272 .76238 L p .707 .577 .707 r
F P
0 g
s
.55257 .24533 m .56135 .74808 L .51735 .74617 L p .707 .577 .707 r
F P
0 g
s
.51735 .74617 m .50857 .24342 L .55257 .24533 L p .707 .577 .707 r
F P
0 g
s
.65693 .59374 m .65348 .64884 L .67448 .65705 L p .707 .577 .707 r
F P
0 g
s
.67737 .66982 m .67062 .70548 L .69755 .71557 L p .707 .577 .707 r
F P
0 g
s
.79531 .69257 m .78855 .72823 L .81236 .7252 L p .707 .577 .707 r
F P
0 g
s
.81236 .7252 m .81912 .68953 L .79531 .69257 L p .707 .577 .707 r
F P
0 g
s
.76439 .73861 m .7609 .7564 L .78988 .75724 L p .707 .577 .707 r
F P
0 g
s
.78988 .75724 m .79337 .73944 L .76439 .73861 L p .707 .577 .707 r
F P
0 g
s
.69897 .74407 m .70246 .72628 L .67557 .716 L p .707 .577 .707 r
F P
0 g
s
.70246 .72628 m .69897 .74407 L .72957 .75186 L p .707 .577 .707 r
F P
0 g
s
.67062 .70548 m .67737 .66982 L .6568 .65823 L p .707 .577 .707 r
F P
0 g
s
.47241 .74797 m .46363 .24522 L .50857 .24342 L p .707 .577 .707 r
F P
0 g
s
.46363 .24522 m .47241 .74797 L .43093 .7533 L p .707 .577 .707 r
F P
0 g
s
.65348 .64884 m .65693 .59374 L .64438 .58446 L p .707 .577 .707 r
F P
0 g
s
.67557 .716 m .67208 .73379 L .69897 .74407 L p .707 .577 .707 r
F P
0 g
s
.50857 .24342 m .51735 .74617 L .47241 .74797 L p .707 .577 .707 r
F P
0 g
s
.79337 .73944 m .78988 .75724 L .81367 .7543 L p .707 .577 .707 r
F P
0 g
s
.81367 .7543 m .81716 .7365 L .79337 .73944 L p .707 .577 .707 r
F P
0 g
s
.6568 .65823 m .65004 .69389 L .67062 .70548 L p .707 .577 .707 r
F P
0 g
s
.67208 .73379 m .67557 .716 L .65503 .70423 L p .707 .577 .707 r
F P
0 g
s
.81912 .68953 m .81236 .7252 L .82865 .71873 L p .707 .577 .707 r
F P
0 g
s
.82865 .71873 m .8354 .68307 L .81912 .68953 L p .707 .577 .707 r
F P
0 g
s
.65503 .70423 m .65153 .72202 L .67208 .73379 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64093 .63955 L .65348 .64884 L p .707 .577 .707 r
F P
0 g
s
.65004 .69389 m .6568 .65823 L .64458 .64627 L p .707 .577 .707 r
F P
0 g
s
.83795 .59934 m .8345 .65444 L .84159 .64577 L p .707 .577 .707 r
F P
0 g
s
.84159 .64577 m .84504 .59067 L .83795 .59934 L p .707 .577 .707 r
F P
0 g
s
.81716 .7365 m .81367 .7543 L .82995 .74786 L p .707 .577 .707 r
F P
0 g
s
.82995 .74786 m .83344 .73007 L .81716 .7365 L p .707 .577 .707 r
F P
0 g
s
.65153 .72202 m .65503 .70423 L .64284 .69213 L p .707 .577 .707 r
F P
0 g
s
.64284 .69213 m .63935 .70992 L .65153 .72202 L p .707 .577 .707 r
F P
0 g
s
.8354 .68307 m .82865 .71873 L .83582 .70946 L p .707 .577 .707 r
F P
0 g
s
.83582 .70946 m .84257 .6738 L .8354 .68307 L p .707 .577 .707 r
F P
0 g
s
.64152 .57502 m .63807 .63011 L .64093 .63955 L p .707 .577 .707 r
F P
0 g
s
.63783 .68193 m .64458 .64627 L .64193 .63511 L p .707 .577 .707 r
F P
0 g
s
.84504 .59067 m .84159 .64577 L .83872 .63633 L p .707 .577 .707 r
F P
0 g
s
.83872 .63633 m .84217 .58123 L .84504 .59067 L p .707 .577 .707 r
F P
0 g
s
.83344 .73007 m .82995 .74786 L .83712 .73856 L p .707 .577 .707 r
F P
0 g
s
.83712 .73856 m .84061 .72077 L .83344 .73007 L p .707 .577 .707 r
F P
0 g
s
.64193 .63511 m .63517 .67077 L .63783 .68193 L p .707 .577 .707 r
F P
0 g
s
.63807 .63011 m .64152 .57502 L .64861 .56634 L p .707 .577 .707 r
F P
0 g
s
.63935 .70992 m .64284 .69213 L .6402 .68088 L p .707 .577 .707 r
F P
0 g
s
.6402 .68088 m .63671 .69867 L .63935 .70992 L p .707 .577 .707 r
F P
0 g
s
.84257 .6738 m .83582 .70946 L .83316 .6983 L p .707 .577 .707 r
F P
0 g
s
.83316 .6983 m .83992 .66264 L .84257 .6738 L p .707 .577 .707 r
F P
0 g
s
.63517 .67077 m .64193 .63511 L .6491 .62584 L p .707 .577 .707 r
F P
0 g
s
.64861 .56634 m .64516 .62144 L .63807 .63011 L p .707 .577 .707 r
F P
0 g
s
.84217 .58123 m .83872 .63633 L .82617 .62704 L p .707 .577 .707 r
F P
0 g
s
.82617 .62704 m .82962 .57195 L .84217 .58123 L p .707 .577 .707 r
F P
0 g
s
.38998 .61458 m .39343 .55948 L .36232 .55563 L p .707 .577 .707 r
F P
0 g
s
.39343 .55948 m .38998 .61458 L .42176 .61556 L p .707 .577 .707 r
F P
0 g
s
.42176 .61556 m .42521 .56047 L .39343 .55948 L p .707 .577 .707 r
F P
0 g
s
.84061 .72077 m .83712 .73856 L .83449 .72731 L p .707 .577 .707 r
F P
0 g
s
.83449 .72731 m .83798 .70952 L .84061 .72077 L p .707 .577 .707 r
F P
0 g
s
.42521 .56047 m .42176 .61556 L .4511 .61358 L p .707 .577 .707 r
F P
0 g
s
.4511 .61358 m .45455 .55849 L .42521 .56047 L p .707 .577 .707 r
F P
0 g
s
.6491 .62584 m .64234 .6615 L .63517 .67077 L p .707 .577 .707 r
F P
0 g
s
.64516 .62144 m .64861 .56634 L .66497 .55929 L p .707 .577 .707 r
F P
0 g
s
.63671 .69867 m .6402 .68088 L .64738 .67158 L p .707 .577 .707 r
F P
0 g
s
.35887 .61073 m .36232 .55563 L .33492 .54929 L p .707 .577 .707 r
F P
0 g
s
.36232 .55563 m .35887 .61073 L .38998 .61458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64738 .67158 m .64388 .68938 L .63671 .69867 L p .707 .577 .707 r
F P
0 g
s
.45455 .55849 m .4511 .61358 L .47513 .60883 L p .707 .577 .707 r
F P
0 g
s
.47513 .60883 m .47858 .55373 L .45455 .55849 L p .707 .577 .707 r
F P
0 g
s
.83992 .66264 m .83316 .6983 L .82095 .68634 L p .707 .577 .707 r
F P
0 g
s
.82095 .68634 m .8277 .65068 L .83992 .66264 L p .707 .577 .707 r
F P
0 g
s
.64234 .6615 m .6491 .62584 L .66538 .61937 L p .707 .577 .707 r
F P
0 g
s
.66497 .55929 m .66152 .61438 L .64516 .62144 L p .707 .577 .707 r
F P
0 g
s
.33147 .60438 m .33492 .54929 L .31392 .54107 L p .707 .577 .707 r
F P
0 g
s
.33492 .54929 m .33147 .60438 L .35887 .61073 L p .707 .577 .707 r
F P
0 g
s
.82962 .57195 m .82617 .62704 L .80517 .61883 L p .707 .577 .707 r
F P
0 g
s
.80517 .61883 m .80862 .56373 L .82962 .57195 L p .707 .577 .707 r
F P
0 g
s
.38518 .68539 m .39194 .64973 L .36129 .64213 L p .707 .577 .707 r
F P
0 g
s
.39194 .64973 m .38518 .68539 L .41654 .68975 L p .707 .577 .707 r
F P
0 g
s
.41654 .68975 m .42329 .65409 L .39194 .64973 L p .707 .577 .707 r
F P
0 g
s
.42329 .65409 m .41654 .68975 L .44554 .69045 L p .707 .577 .707 r
F P
0 g
s
.44554 .69045 m .4523 .65479 L .42329 .65409 L p .707 .577 .707 r
F P
0 g
s
.35454 .67779 m .36129 .64213 L .33436 .63204 L p .707 .577 .707 r
F P
0 g
s
.36129 .64213 m .35454 .67779 L .38518 .68539 L p .707 .577 .707 r
F P
0 g
s
.66152 .61438 m .66497 .55929 L .68899 .55453 L p .707 .577 .707 r
F P
0 g
s
.83798 .70952 m .83449 .72731 L .8223 .71521 L p .707 .577 .707 r
F P
0 g
s
.8223 .71521 m .82579 .69742 L .83798 .70952 L p .707 .577 .707 r
F P
0 g
s
.66538 .61937 m .65863 .65504 L .64234 .6615 L p .707 .577 .707 r
F P
0 g
s
.64388 .68938 m .64738 .67158 L .66366 .66515 L p .707 .577 .707 r
F P
0 g
s
.47858 .55373 m .47513 .60883 L .49149 .60177 L p .707 .577 .707 r
F P
0 g
s
.49149 .60177 m .49494 .54668 L .47858 .55373 L p .707 .577 .707 r
F P
0 g
s
.31392 .54107 m .31047 .59617 L .33147 .60438 L p .707 .577 .707 r
F P
0 g
s
.66366 .66515 m .66016 .68294 L .64388 .68938 L p .707 .577 .707 r
F P
0 g
s
.33436 .63204 m .32761 .66771 L .35454 .67779 L p .707 .577 .707 r
F P
0 g
s
.4523 .65479 m .44554 .69045 L .46935 .68742 L p .707 .577 .707 r
F P
0 g
s
.46935 .68742 m .47611 .65176 L .4523 .65479 L p .707 .577 .707 r
F P
0 g
s
.31047 .59617 m .31392 .54107 L .30137 .53179 L p .707 .577 .707 r
F P
0 g
s
.32761 .66771 m .33436 .63204 L .31379 .62045 L p .707 .577 .707 r
F P
0 g
s
.80862 .56373 m .80517 .61883 L .77777 .61249 L p .707 .577 .707 r
F P
0 g
s
.77777 .61249 m .78122 .55739 L .80862 .56373 L p .707 .577 .707 r
F P
0 g
s
.8277 .65068 m .82095 .68634 L .80037 .67475 L p .707 .577 .707 r
F P
0 g
s
.80037 .67475 m .80713 .63909 L .8277 .65068 L p .707 .577 .707 r
F P
0 g
s
.38656 .74137 m .39006 .72357 L .35945 .71578 L p .707 .577 .707 r
F P
0 g
s
.39006 .72357 m .38656 .74137 L .41789 .7459 L p .707 .577 .707 r
F P
0 g
s
.41789 .7459 m .42138 .72811 L .39006 .72357 L p .707 .577 .707 r
F P
0 g
s
.65863 .65504 m .66538 .61937 L .68919 .61634 L p .707 .577 .707 r
F P
0 g
s
.68899 .55453 m .68554 .60963 L .66152 .61438 L p .707 .577 .707 r
F P
0 g
s
.42138 .72811 m .41789 .7459 L .44687 .74674 L p .707 .577 .707 r
F P
0 g
s
.44687 .74674 m .45036 .72895 L .42138 .72811 L p .707 .577 .707 r
F P
0 g
s
.68554 .60963 m .68899 .55453 L .71833 .55255 L p .707 .577 .707 r
F P
0 g
s
.35596 .73358 m .35945 .71578 L .33256 .7055 L p .707 .577 .707 r
F P
0 g
s
.35945 .71578 m .35596 .73358 L .38656 .74137 L p .707 .577 .707 r
F P
0 g
s
.31379 .62045 m .30703 .65611 L .32761 .66771 L p .707 .577 .707 r
F P
0 g
s
.33256 .7055 m .32907 .72329 L .35596 .73358 L p .707 .577 .707 r
F P
0 g
s
.82579 .69742 m .8223 .71521 L .80175 .70345 L p .707 .577 .707 r
F P
0 g
s
.80175 .70345 m .80525 .68565 L .82579 .69742 L p .707 .577 .707 r
F P
0 g
s
.68919 .61634 m .68244 .652 L .65863 .65504 L p .707 .577 .707 r
F P
0 g
s
.30137 .53179 m .29792 .58689 L .31047 .59617 L p .707 .577 .707 r
F P
0 g
s
.66016 .68294 m .66366 .66515 L .68745 .6622 L p .707 .577 .707 r
F P
0 g
s
.78122 .55739 m .77777 .61249 L .74666 .60863 L p .707 .577 .707 r
F P
0 g
s
.74666 .60863 m .75011 .55354 L .78122 .55739 L p .707 .577 .707 r
F P
0 g
s
.49494 .54668 m .49149 .60177 L .49858 .5931 L p .707 .577 .707 r
F P
0 g
s
.49858 .5931 m .50203 .538 L .49494 .54668 L p .707 .577 .707 r
F P
0 g
s
.71488 .60765 m .71833 .55255 L .75011 .55354 L p .707 .577 .707 r
F P
0 g
s
.71833 .55255 m .71488 .60765 L .68554 .60963 L p .707 .577 .707 r
F P
0 g
s
.47611 .65176 m .46935 .68742 L .48564 .68095 L p .707 .577 .707 r
F P
0 g
s
.48564 .68095 m .49239 .64529 L .47611 .65176 L p .707 .577 .707 r
F P
0 g
s
.45036 .72895 m .44687 .74674 L .47066 .7438 L p .707 .577 .707 r
F P
0 g
s
.47066 .7438 m .47415 .726 L .45036 .72895 L p .707 .577 .707 r
F P
0 g
s
.32907 .72329 m .33256 .7055 L .31202 .69373 L p .707 .577 .707 r
F P
0 g
s
.30703 .65611 m .31379 .62045 L .30157 .60849 L p .707 .577 .707 r
F P
0 g
s
.75011 .55354 m .74666 .60863 L .71488 .60765 L p .707 .577 .707 r
F P
0 g
s
.68745 .6622 m .68395 .68 L .66016 .68294 L p .707 .577 .707 r
F P
0 g
s
.80713 .63909 m .80037 .67475 L .77344 .66466 L p .707 .577 .707 r
F P
0 g
s
.77344 .66466 m .7802 .629 L .80713 .63909 L p .707 .577 .707 r
F P
0 g
s
.68244 .652 m .68919 .61634 L .71819 .61704 L p .707 .577 .707 r
F P
0 g
s
.29792 .58689 m .30137 .53179 L .2985 .52235 L p .707 .577 .707 r
F P
0 g
s
.31202 .69373 m .30852 .71153 L .32907 .72329 L p .707 .577 .707 r
F P
0 g
s
.30157 .60849 m .29482 .64415 L .30703 .65611 L p .707 .577 .707 r
F P
0 g
s
.80525 .68565 m .80175 .70345 L .77486 .69316 L p .707 .577 .707 r
F P
0 g
s
.77486 .69316 m .77836 .67537 L .80525 .68565 L p .707 .577 .707 r
F P
0 g
s
.71819 .61704 m .71144 .6527 L .68244 .652 L p .707 .577 .707 r
F P
0 g
s
.7802 .629 m .77344 .66466 L .7428 .65706 L p .707 .577 .707 r
F P
0 g
s
.7428 .65706 m .74955 .6214 L .7802 .629 L p .707 .577 .707 r
F P
0 g
s
.71144 .6527 m .71819 .61704 L .74955 .6214 L p .707 .577 .707 r
F P
0 g
s
.68395 .68 m .68745 .6622 L .71643 .66304 L p .707 .577 .707 r
F P
0 g
s
.47415 .726 m .47066 .7438 L .48694 .73736 L p .707 .577 .707 r
F P
0 g
s
.48694 .73736 m .49043 .71957 L .47415 .726 L p .707 .577 .707 r
F P
0 g
s
.74955 .6214 m .7428 .65706 L .71144 .6527 L p .707 .577 .707 r
F P
0 g
s
.30852 .71153 m .31202 .69373 L .29983 .68163 L p .707 .577 .707 r
F P
0 g
s
.71643 .66304 m .71293 .68084 L .68395 .68 L p .707 .577 .707 r
F P
0 g
s
.2985 .52235 m .29505 .57745 L .29792 .58689 L p .707 .577 .707 r
F P
0 g
s
.49239 .64529 m .48564 .68095 L .49281 .67169 L p .707 .577 .707 r
F P
0 g
s
.49281 .67169 m .49956 .63603 L .49239 .64529 L p .707 .577 .707 r
F P
0 g
s
.50203 .538 m .49858 .5931 L .49571 .58366 L p .707 .577 .707 r
F P
0 g
s
.49571 .58366 m .49916 .52856 L .50203 .538 L p .707 .577 .707 r
F P
0 g
s
.29482 .64415 m .30157 .60849 L .29892 .59733 L p .707 .577 .707 r
F P
0 g
s
.29983 .68163 m .29634 .69943 L .30852 .71153 L p .707 .577 .707 r
F P
0 g
s
.77836 .67537 m .77486 .69316 L .74426 .68537 L p .707 .577 .707 r
F P
0 g
s
.74426 .68537 m .74775 .66758 L .77836 .67537 L p .707 .577 .707 r
F P
0 g
s
.71293 .68084 m .71643 .66304 L .74775 .66758 L p .707 .577 .707 r
F P
0 g
s
.74775 .66758 m .74426 .68537 L .71293 .68084 L p .707 .577 .707 r
F P
0 g
s
.29505 .57745 m .2985 .52235 L .3056 .51368 L p .707 .577 .707 r
F P
0 g
s
.29892 .59733 m .29216 .63299 L .29482 .64415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49043 .71957 m .48694 .73736 L .49411 .72807 L p .707 .577 .707 r
F P
0 g
s
.49411 .72807 m .4976 .71027 L .49043 .71957 L p .707 .577 .707 r
F P
0 g
s
.29634 .69943 m .29983 .68163 L .29719 .67038 L p .707 .577 .707 r
F P
0 g
s
.3056 .51368 m .30215 .56877 L .29505 .57745 L p .707 .577 .707 r
F P
0 g
s
.29719 .67038 m .2937 .68818 L .29634 .69943 L p .707 .577 .707 r
F P
0 g
s
.49956 .63603 m .49281 .67169 L .49015 .66053 L p .707 .577 .707 r
F P
0 g
s
.49015 .66053 m .49691 .62487 L .49956 .63603 L p .707 .577 .707 r
F P
0 g
s
.29216 .63299 m .29892 .59733 L .30609 .58806 L p .707 .577 .707 r
F P
0 g
s
.49916 .52856 m .49571 .58366 L .48316 .57438 L p .707 .577 .707 r
F P
0 g
s
.48316 .57438 m .48661 .51928 L .49916 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30215 .56877 m .3056 .51368 L .32196 .50662 L p .707 .577 .707 r
F P
0 g
s
.30609 .58806 m .29933 .62372 L .29216 .63299 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4976 .71027 m .49411 .72807 L .49147 .71682 L p .707 .577 .707 r
F P
0 g
s
.49147 .71682 m .49497 .69902 L .4976 .71027 L p .707 .577 .707 r
F P
0 g
s
.2937 .68818 m .29719 .67038 L .30437 .66108 L p .707 .577 .707 r
F P
0 g
s
.32196 .50662 m .31851 .56171 L .30215 .56877 L p .707 .577 .707 r
F P
0 g
s
.30437 .66108 m .30087 .67888 L .2937 .68818 L p .707 .577 .707 r
F P
0 g
s
.49691 .62487 m .49015 .66053 L .47794 .64856 L p .707 .577 .707 r
F P
0 g
s
.47794 .64856 m .48469 .6129 L .49691 .62487 L p .707 .577 .707 r
F P
0 g
s
.48661 .51928 m .48316 .57438 L .46216 .56616 L p .707 .577 .707 r
F P
0 g
s
.46216 .56616 m .46561 .51107 L .48661 .51928 L p .707 .577 .707 r
F P
0 g
s
.29933 .62372 m .30609 .58806 L .32237 .5816 L p .707 .577 .707 r
F P
0 g
s
.31851 .56171 m .32196 .50662 L .34598 .50187 L p .707 .577 .707 r
F P
0 g
s
.32237 .5816 m .31562 .61726 L .29933 .62372 L p .707 .577 .707 r
F P
0 g
s
.49497 .69902 m .49147 .71682 L .47929 .70472 L p .707 .577 .707 r
F P
0 g
s
.47929 .70472 m .48278 .68692 L .49497 .69902 L p .707 .577 .707 r
F P
0 g
s
.46561 .51107 m .46216 .56616 L .43476 .55982 L p .707 .577 .707 r
F P
0 g
s
.43476 .55982 m .43821 .50472 L .46561 .51107 L p .707 .577 .707 r
F P
0 g
s
.30087 .67888 m .30437 .66108 L .32065 .65465 L p .707 .577 .707 r
F P
0 g
s
.34598 .50187 m .34253 .55696 L .31851 .56171 L p .707 .577 .707 r
F P
0 g
s
.48469 .6129 m .47794 .64856 L .45736 .63697 L p .707 .577 .707 r
F P
0 g
s
.45736 .63697 m .46411 .60131 L .48469 .6129 L p .707 .577 .707 r
F P
0 g
s
.34253 .55696 m .34598 .50187 L .37532 .49988 L p .707 .577 .707 r
F P
0 g
s
.31562 .61726 m .32237 .5816 L .34618 .57857 L p .707 .577 .707 r
F P
0 g
s
.32065 .65465 m .31715 .67244 L .30087 .67888 L p .707 .577 .707 r
F P
0 g
s
.43821 .50472 m .43476 .55982 L .40365 .55596 L p .707 .577 .707 r
F P
0 g
s
.40365 .55596 m .4071 .50087 L .43821 .50472 L p .707 .577 .707 r
F P
0 g
s
.37187 .55498 m .37532 .49988 L .4071 .50087 L p .707 .577 .707 r
F P
0 g
s
.37532 .49988 m .37187 .55498 L .34253 .55696 L p .707 .577 .707 r
F P
0 g
s
.34618 .57857 m .33943 .61423 L .31562 .61726 L p .707 .577 .707 r
F P
0 g
s
.4071 .50087 m .40365 .55596 L .37187 .55498 L p .707 .577 .707 r
F P
0 g
s
.48278 .68692 m .47929 .70472 L .45874 .69295 L p .707 .577 .707 r
F P
0 g
s
.45874 .69295 m .46224 .67515 L .48278 .68692 L p .707 .577 .707 r
F P
0 g
s
.46411 .60131 m .45736 .63697 L .43043 .62688 L p .707 .577 .707 r
F P
0 g
s
.43043 .62688 m .43719 .59122 L .46411 .60131 L p .707 .577 .707 r
F P
0 g
s
.31715 .67244 m .32065 .65465 L .34444 .65171 L p .707 .577 .707 r
F P
0 g
s
.33943 .61423 m .34618 .57857 L .37518 .57926 L p .707 .577 .707 r
F P
0 g
s
.34444 .65171 m .34094 .6695 L .31715 .67244 L p .707 .577 .707 r
F P
0 g
s
.37518 .57926 m .36843 .61493 L .33943 .61423 L p .707 .577 .707 r
F P
0 g
s
.43719 .59122 m .43043 .62688 L .39979 .61929 L p .707 .577 .707 r
F P
0 g
s
.39979 .61929 m .40654 .58363 L .43719 .59122 L p .707 .577 .707 r
F P
0 g
s
.36843 .61493 m .37518 .57926 L .40654 .58363 L p .707 .577 .707 r
F P
0 g
s
.40654 .58363 m .39979 .61929 L .36843 .61493 L p .707 .577 .707 r
F P
0 g
s
.46224 .67515 m .45874 .69295 L .43185 .68267 L p .707 .577 .707 r
F P
0 g
s
.43185 .68267 m .43535 .66487 L .46224 .67515 L p .707 .577 .707 r
F P
0 g
s
.34094 .6695 m .34444 .65171 L .37341 .65255 L p .707 .577 .707 r
F P
0 g
s
.37341 .65255 m .36992 .67034 L .34094 .6695 L p .707 .577 .707 r
F P
0 g
s
.43535 .66487 m .43185 .68267 L .40125 .67488 L p .707 .577 .707 r
F P
0 g
s
.40125 .67488 m .40474 .65708 L .43535 .66487 L p .707 .577 .707 r
F P
0 g
s
.36992 .67034 m .37341 .65255 L .40474 .65708 L p .707 .577 .707 r
F P
0 g
s
.40474 .65708 m .40125 .67488 L .36992 .67034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7`00OGoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Ioo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00LGoo1@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000
0`00Kgoo001]Ool40007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH3001/Ool006]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUIVOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol0065ooaL00003FUH005YF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00GGoo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001JOol30005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qo
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001U
Ool005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001D
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Goo6000@goo
001COol00`00FUH00004FUH01000FUIJEUYF3@000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000mOol0
05=oo`03001JEP0000=JEPD00003FUH005YF00EJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=J
EP06001JEUYF001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000`00>Goo001COol01000FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001Goo000005YF00001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00=Woo001COol01P00FUH0
0000FUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP@000AJEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003=oo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01UYF00@005YFFUIJEP<00004FUH005YFFUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<7oo001COol20003
FUH00`00FUIJEP03FUHB0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEP00000^Ool005=oo`8000=JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYFFUH40006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo001EOol01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool003YooaL000Aoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YF00000P001UYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000c
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF
00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000/Ool0035oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP05001JEUYF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00;goo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEPd000=oo`T000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00
FUIJEP02FUHD0003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF1@001EYF00@005YF0000009JEP03001JEP0000<0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYF001JEP00FUH00P001EYF4P0025YF00<005YFFUH015YF10001EYF00@005YFFUIJEP8002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF001JEP<000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50006
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUH005YF00<00003FUH0000000@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP000002FUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000AJEP000000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000MJEP03001J
EUYF009JEP800003FUH005YF009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P001EYF00@005YF
FUH0009JEP03001JEUYF00=JEP<000IJEP@000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001JEUYF
00AJEP8000=JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF0`000UYF00@005YFFUH0009JEP03
001JEUYF009JEPD000MJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP040003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP05001J
EP00001JEP02000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEP000080009JEP04001JEUYF0004FUH5
0007FUH01000FUIJEUYF0`0000=JEP00FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00UYF0`00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000AJEPD000MJ
EP03001JEUYF00AJEP8000EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH015YF1@001EYF0`0025YF00<005YFFUH01UYF
0P000UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00IJEP@000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH025YF
0`0015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF00<005YF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF6@00
15YF00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD000QJEP03001JEUYF00QJEP03
001JEP0000AJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH500000eYF001J
EP06FUH01000FUIJEUYF50001UYF4P000UYF100015YF00<005YFFUH01eYF1@000UYF00<005YF0000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000
FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002io
o`00;7oo00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001JEUYF
009JEP80009JEPD0009JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH0000000`000=JEP03
001JEP0000800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF008000=JEPL000IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<002moo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000EJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEP00001JEP001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP<000=JEP03001JEP0000@0009JEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
02moo`00;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@001EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJ
EP<000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P000UYF0`0000=JEP00FUH04@001UYF0`0000=J
EP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF0`001UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00AJEP04001JEUYF
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH6
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH40006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH?0002FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUH000030005FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH005YF
0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00002P000UYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH010000eYF00<005YFFUH01EYF
00<005YFFUH010001eYF00<005YFFUH00P000eYF1@000UYF0`0000=JEP00FUH025YF1P001eYF00<0
05YFFUH00eYF0`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH30005Ool30006FUH01P00FUIJEP00FUH002eoo`00;Goo00@005YFFUIJ
EP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00800005FUH00000FUH0
0005FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP06FUH40003FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200001EYF001JEUYF
00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001Goo0P0015YF00H005YF
FUH005YF000]Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00D00003FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH70002FUH0
0`00FUH000020004FUH300000eYF001JEP07FUH01000FUIJEP000UYF0P0025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP07FUH00`00FUH000030003Ool01000FUIJEP000eYF00<005YF0000;Goo000^Ool30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP00009JEP03001JEP0000L000=JEP03001JEUYF00<000IJEP03001J
EUYF009JEP8000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH50008FUH00`00FUH0000300000goo000000040008FUH00`00FUIJEP03FUH20002Ool30003
FUH2000^Ool002ioo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000@000IJEP04001JEUYFFUH30002FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF
00=JEPX000AJEP03001JEUYF00EJEP<0009oo`04001JEUYFFUH2000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP04001J
EP000005FUH01000FUIJEUYF0`000eYF00@005YFFUIJEPD00003FUH0000000/00003FUH005YF00EJ
EP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF00@00004
FUH005YF000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH20003FUH01`00FUIJEUYF001oo`0000=JEP03
001JEUYF009JEP<000QJEP03001JEUYF00AJEP8000IJEP03001JEP0000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEPH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF009JEP800005FUH00000FUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300001eYF00000000FUH005YF0080009oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00`000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00D005YF001JEP0002ioo`00;Goo00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00P000UYF0`001Goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF
0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`000eYF00H005YF000005YF0008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH200000eYF001JEP05FUH4000_Ool002eoo`03001JEP00009JEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH300000eYF00000004Ool3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30003FUH20005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP030007FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30006FUH01000FUH00000;goo000/Ool00`00FUH00003FUH40007
Ool90004FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YF00000`000goo0eYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF000015YF10000UYF0P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<007ooOol0
;7oo000/Ool01000FUH005YF0`004goo1`001UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH40000
1GooFUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJ
EP020003FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00Oomoo`0/Ool002aoo`04001JEP000002FUH3000HOol40002FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP<00003FUH005YF00<000IJEP03001JEUYF00<000AJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001oogoo02aoo`00;7oo0P0015YF00<005YF
FUH00P006Woo10001EYF0P0000=JEP00FUH01eYF00<005YF00000`0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000IJEP04001JEP000003FUH50002FUH00`00FUH000040002FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00;Woo000/Ool20003FUH00`00FUIJEP03
FUH3000>Ool3000:Ool20004FUH40007FUH00`00FUIJEP03FUH50009FUH00`00FUIJEP09FUH01@00
FUH00000FUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF00@005YFFUIJEP800003FUH0000000=oo`T0009JEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEP00001oo`04000^Ool002aoo`8000=JEP03001JEUYF00AJEP04001JEP00000;Ool5
000;Ool300000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJ
EP07FUH40003FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH40006Ool<0004FUH01000FUIJEUYF10001Goo0P00;Woo000/
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P002Goo1@003Woo0P001EYF0`0000=J
EP00FUH01eYF00<005YFFUH015YF3`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP06FUH00`00
FUIJEP040003Ool30008Ool80008Ool2000_Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00AJEP@000Eoo`D0011oo`80009JEP04001JEUYFFUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`001UYF00<005YFFUH015YF1@005goo1000;goo
000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool3000C
Ool30004FUH00`00FUH000030002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF0P00
;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH015YF1@005Goo00<005YFFUH0
0UYF0P000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP<0
0003FUH005YF00QJEP03001JEUYF00AJEPh000=JEP06001JEUYF001JEP00;goo000^Ool30006FUH?
0002FUH00`00FUIJEP04000>Ool50002FUH00`00FUH00003FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00<005YFFUH015YF1@001UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P00<7oo000`Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH0
0`00FUIJEP040005FUH>0003FUH00`00FUH0000200000eYF001JEP02FUH00`00FUIJEP03FUH01000
FUIJEUYF3`0000=JEP000000700025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF
FUH015YF0`000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00035oo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH015YF10000eYF
00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF00001Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000039oo`00;goo0P000eYF00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YF00000`001eYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEP0000@000IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=J
EP05001JEUYFFUH0000:Ool40002FUH00`00FUIJEP05FUH01000FUIJEUYF1@00=7oo000^Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000EooeYFFUIJEP0000EJEP03001JEUYF00D000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000>Ool>000iOol002eoo`03001JEP0000=JEP04001J
EUYFFUH>0006FUH00`00FUIJEP06FUH00`00FUH000020006FUH02000FUIJEUYF001JEP00Ool3FUH0
0`00FUIJEP03FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00E7oo000]Ool20003FUH500000goo0000000200000eYF001JEP06FUH40002FUH00`00FUIJEP06
FUH01000FUIJEUYF0`0015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP<00003FUH005YF00EJEP06001JEUYF001JEP00E7oo000]Ool200000eYF0000
000:Ool30008FUH00`00FUH000030006FUH00`00FUIJEP05FUH20002FUH01000FUIJEUYF0P000Woo
0eYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH007oo008000IJEP06001JEUYF001JEP00
E7oo000/Ool01000FUH000003goo0`0015YF00<005YF00000P000UYF10000UYF00<005YFFUH01UYF
0`000eYF0P000goo0eYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=oo`8000=J
EP07001JEUYFFUH005YF0000E7oo000/Ool4000BOol300000eYF000000040003FUH00`00FUH00003
0007FUH00`00FUIJEP030005Ool2FUH01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0`000goo0P0000=JEP00FUH00UYF0P00EGoo000/Ool01000FUH000005Goo1`000eYF00<005YFFUH0
0eYF0P0015YF00<005YFFUH00eYF0P0017oo00=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00@005YFFUH0009JEP8000=oo`8000=JEP8005Eoo`00;7oo0P000UYF00<007ooOol057oo4`00
00=JEP00FUH01EYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000=J
EPL00004FUH005YF001EOol002aoo`8000=JEP03001oogoo01Aoo`<000moo`8000IJEP03001JEP00
009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF0080009J
EP800003FUH007oo05Aoo`00;Goo00@005YFFUIJEP<002Qoo`8000=JEP06001JEUYFFUH007oo0P00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0P0000AJEP00FUH005Eo
o`00;Goo00D005YFFUIJEP00009JEP8002Qoo`800003FUH005YF009JEP04001oogoo0004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200001EYF000005YF00001UYF1000EWoo000^Ool00`00FUH00005
FUH3000WOol20003FUH01000Oomoo`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF0`00
1UYF00@005YF000005Ioo`00;goo0P001UYF00@005YF000002Moo`05001JEP00FUH00002Ool20002
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<0
07ooOol0Dgoo000`Ool00`00FUIJEP04FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool00goo0`00
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF009JEP800003FUH005YF00=JEP03001oogoo05=oo`00<Goo
0P000eYF00<005YFFUH01EYF0`008goo00<005YF00001Woo0`001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@0025YF00<005YFFUH00eYF
0`0015YF00<007ooOol0Dgoo000cOol200000eYF001JEP07FUH00`00FUH00003000NOol200000eYF
001oo`08Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00
EGoo000eOol30007FUH00`00FUIJEP03FUH5000GOol200000eYF0000000>Ool50008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH:0002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH00000Ool01000EGoo000hOol20004FUH00`00FUIJEP06FUH00`00FUIJEP04000?Ool40003
FUH2000COol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@000UYF
00<005YFFUH01UYF00@005YFFUIJEP@000Eoo`8005Eoo`00>Woo0`0000=JEP00FUH01eYF00<005YF
FUH015YF3`000UYF00L005YFFUIJEP00FUH0000IOolO0002FUH00`00FUIJEP040002OolD0008Ool3
001EOol003eoo`<000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
FUH2000bOol30006FUH00`00FUIJEP04FUH6000FOol4001FOol0041oo`@0009JEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000fOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP04000>Ool50002FUH2001FOol004Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00000jOol200000eYF001JEP08FUH00`00FUIJEP04FUH>0003FUH01P00FUIJEP00FUH0
05Ioo`00BGoo10000UYF00<005YFFUH01UYF00@005YFFUIJEP@003ioo`@000IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Moo`00CGoo3`00AWoo10000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0005Qoo`00YWoo1@001UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Uoo`00Zgoo10000UYF00<005YFFUH01EYF
00@005YFFUIJEPD005]oo`00[goo3P00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59552 .76527 m .6011 .71059 L .57008 .70554 L p .707 .577 .707 r
F P
0 g
s
.6011 .71059 m .59552 .76527 L .62721 .76733 L p .707 .577 .707 r
F P
0 g
s
.62721 .76733 m .63279 .71265 L .6011 .71059 L p .707 .577 .707 r
F P
0 g
s
.63279 .71265 m .62721 .76733 L .65648 .76621 L p .707 .577 .707 r
F P
0 g
s
.65648 .76621 m .66206 .71153 L .63279 .71265 L p .707 .577 .707 r
F P
0 g
s
.56451 .76022 m .57008 .70554 L .54278 .698 L p .707 .577 .707 r
F P
0 g
s
.57008 .70554 m .56451 .76022 L .59552 .76527 L p .707 .577 .707 r
F P
0 g
s
.66206 .71153 m .65648 .76621 L .68046 .76201 L p .707 .577 .707 r
F P
0 g
s
.68046 .76201 m .68604 .70732 L .66206 .71153 L p .707 .577 .707 r
F P
0 g
s
.53721 .75268 m .54278 .698 L .52187 .6887 L p .707 .577 .707 r
F P
0 g
s
.54278 .698 m .53721 .75268 L .56451 .76022 L p .707 .577 .707 r
F P
0 g
s
.58734 .81804 m .59816 .78389 L .56837 .77292 L p .707 .577 .707 r
F P
0 g
s
.59816 .78389 m .58734 .81804 L .61793 .82544 L p .707 .577 .707 r
F P
0 g
s
.61793 .82544 m .62876 .79129 L .59816 .78389 L p .707 .577 .707 r
F P
0 g
s
.55755 .80707 m .56837 .77292 L .54229 .75946 L p .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56542 .81049 L .56176 .80855 L p .707 .577 .707 r
F P
0 g
s
.56837 .77292 m .55755 .80707 L .56174 .80861 L p .707 .577 .707 r
F P
0 g
s
.57115 .77952 m .56837 .77292 L .56174 .80861 L .707 .577 .707 r
F
.54229 .75946 m .53147 .79361 L .55755 .80707 L p F P
0 g
s
.56176 .80855 m .53943 .79673 L p .55701 .82324 L .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56176 .80855 L .55701 .82324 L .707 .577 .707 r
F
.56174 .80861 m .58734 .81804 L p .57115 .77952 L F P
0 g
s
.62876 .79129 m .61793 .82544 L .64633 .82856 L p .707 .577 .707 r
F P
0 g
s
.64633 .82856 m .65715 .79441 L .62876 .79129 L p .707 .577 .707 r
F P
0 g
s
.58952 .83875 m .59511 .82176 L .56542 .81049 L p .707 .577 .707 r
F P
0 g
s
.59511 .82176 m .58952 .83875 L .62002 .84643 L p .707 .577 .707 r
F P
0 g
s
.62002 .84643 m .62562 .82943 L .59511 .82176 L p .707 .577 .707 r
F P
0 g
s
.56542 .81049 m .55982 .82748 L .58952 .83875 L p .707 .577 .707 r
F P
0 g
s
.68604 .70732 m .68046 .76201 L .6968 .75514 L p .707 .577 .707 r
F P
0 g
s
.6968 .75514 m .70238 .70046 L .68604 .70732 L p .707 .577 .707 r
F P
0 g
s
.52187 .6887 m .5163 .74339 L .52659 .74796 L p .707 .577 .707 r
F P
0 g
s
.52659 .74796 m .53721 .75268 L p .53305 .73533 L .707 .577 .707 r
F P
0 g
s
.53305 .73533 m .52187 .6887 L .52659 .74796 L .707 .577 .707 r
F
.5163 .74339 m .52187 .6887 L .50939 .67857 L p F P
0 g
s
.50939 .67857 m .50382 .73325 L .51101 .73909 L p .707 .577 .707 r
F P
0 g
s
.51101 .73909 m .5163 .74339 L p .5149 .7303 L .707 .577 .707 r
F P
0 g
s
.5149 .7303 m .50939 .67857 L .51101 .73909 L .707 .577 .707 r
F
.51087 .73044 m .50861 .71773 L p .50029 .76331 L F P
0 g
s
.50005 .76459 m .50089 .76194 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.50089 .76194 m .51087 .73044 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51087 .73044 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51166 .77897 m .51315 .77426 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51315 .77426 m .52248 .74482 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.53147 .79361 m .54229 .75946 L .52248 .74482 L p .707 .577 .707 r
F P
0 g
s
.62562 .82943 m .62002 .84643 L .64835 .84976 L p .707 .577 .707 r
F P
0 g
s
.64835 .84976 m .65394 .83276 L .62562 .82943 L p .707 .577 .707 r
F P
0 g
s
.65715 .79441 m .64633 .82856 L .66975 .82708 L p .707 .577 .707 r
F P
0 g
s
.66975 .82708 m .68057 .79292 L .65715 .79441 L p .707 .577 .707 r
F P
0 g
s
.53943 .79673 m .53384 .81372 L .55982 .82748 L p .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51166 .77897 L .53147 .79361 L p .707 .577 .707 r
F P
0 g
s
.53384 .81372 m .53943 .79673 L .51971 .78182 L p .707 .577 .707 r
F P
0 g
s
.65394 .83276 m .64835 .84976 L .67172 .84841 L p .707 .577 .707 r
F P
0 g
s
.67172 .84841 m .67732 .83142 L .65394 .83276 L p .707 .577 .707 r
F P
0 g
s
.51971 .78182 m .51412 .79882 L .53384 .81372 L p .707 .577 .707 r
F P
0 g
s
.68057 .79292 m .66975 .82708 L .6859 .82114 L p .707 .577 .707 r
F P
0 g
s
.6859 .82114 m .69672 .78699 L .68057 .79292 L p .707 .577 .707 r
F P
0 g
s
.70238 .70046 m .6968 .75514 L .70391 .74627 L p .707 .577 .707 r
F P
0 g
s
.70391 .74627 m .70949 .69159 L .70238 .70046 L p .707 .577 .707 r
F P
0 g
s
.51087 .73044 m .50005 .76459 L .51166 .77897 L p .707 .577 .707 r
F P
0 g
s
.51412 .79882 m .51971 .78182 L .50817 .76723 L p .707 .577 .707 r
F P
0 g
s
.50382 .73325 m .50939 .67857 L .50657 .66858 L p .707 .577 .707 r
F P
0 g
s
.67732 .83142 m .67172 .84841 L .68786 .84253 L p .707 .577 .707 r
F P
0 g
s
.68786 .84253 m .69345 .82554 L .67732 .83142 L p .707 .577 .707 r
F P
0 g
s
.50817 .76723 m .50258 .78422 L .51412 .79882 L p .707 .577 .707 r
F P
0 g
s
.50269 .72925 m .50382 .73325 L p .50432 .7215 L .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .49779 .75188 L .50005 .76459 L p .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .51591 .70793 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49779 .75188 m .49821 .75054 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49821 .75054 m .50861 .71773 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.50657 .66858 m .50099 .72326 L .50269 .72925 L p .707 .577 .707 r
F P
0 g
s
.50432 .7215 m .50657 .66858 L .50269 .72925 L .707 .577 .707 r
F
.69672 .78699 m .6859 .82114 L .6932 .81134 L p F P
0 g
s
.6932 .81134 m .70402 .77719 L .69672 .78699 L p .707 .577 .707 r
F P
0 g
s
.70949 .69159 m .70391 .74627 L .70109 .73628 L p .707 .577 .707 r
F P
0 g
s
.70109 .73628 m .70666 .6816 L .70949 .69159 L p .707 .577 .707 r
F P
0 g
s
.50258 .78422 m .50817 .76723 L .50595 .75438 L p .707 .577 .707 r
F P
0 g
s
.50595 .75438 m .50036 .77137 L .50258 .78422 L p .707 .577 .707 r
F P
0 g
s
.50036 .77137 m .50595 .75438 L .51327 .74453 L p .707 .577 .707 r
F P
0 g
s
.51591 .70793 m .50537 .74119 L p .49779 .75188 L .707 .577 .707 r
F P
0 g
s
.50537 .74119 m .50509 .74208 L .50494 .74228 L p .707 .577 .707 r
F P
0 g
s
.50494 .74228 m .49779 .75188 L p .50537 .74119 L .707 .577 .707 r
F P
0 g
s
.53002 .65284 m .52644 .68793 L p .5081 .71439 L .707 .577 .707 r
F P
0 g
s
.50509 .74208 m .51591 .70793 L .53206 .702 L p .707 .577 .707 r
F P
0 g
s
.52644 .68793 m .52445 .70753 L .51754 .71043 L p .707 .577 .707 r
F P
0 g
s
.51754 .71043 m .5081 .71439 L p .52644 .68793 L .707 .577 .707 r
F P
0 g
s
.51327 .74453 m .50768 .76153 L .50036 .77137 L p .707 .577 .707 r
F P
0 g
s
.503 .82182 m .4888 .31862 L .44481 .3172 L p .707 .577 .707 r
F P
0 g
s
.50099 .72326 m .50657 .66858 L .51368 .65971 L p .707 .577 .707 r
F P
0 g
s
.51368 .65971 m .5081 .71439 L .50099 .72326 L p .707 .577 .707 r
F P
0 g
s
.5081 .71439 m .51368 .65971 L .53002 .65284 L p .707 .577 .707 r
F P
0 g
s
.50768 .76153 m .51327 .74453 L .52941 .73865 L p .707 .577 .707 r
F P
0 g
s
.53206 .702 m .52166 .73481 L p .50509 .74208 L .707 .577 .707 r
F P
0 g
s
.52166 .73481 m .52124 .73615 L .5208 .73631 L p .707 .577 .707 r
F P
0 g
s
.5208 .73631 m .50509 .74208 L p .52166 .73481 L .707 .577 .707 r
F P
0 g
s
.554 .64864 m .55028 .68514 L p .52445 .70753 L .707 .577 .707 r
F P
0 g
s
.52124 .73615 m .53206 .702 L .55548 .70052 L p .707 .577 .707 r
F P
0 g
s
.55028 .68514 m .54843 .70332 L .53884 .705 L p .707 .577 .707 r
F P
0 g
s
.53884 .705 m .52445 .70753 L p .55028 .68514 L .707 .577 .707 r
F P
0 g
s
.52445 .70753 m .53002 .65284 L .554 .64864 L p .707 .577 .707 r
F P
0 g
s
.52941 .73865 m .52381 .75564 L .50768 .76153 L p .707 .577 .707 r
F P
0 g
s
.52381 .75564 m .52941 .73865 L .55278 .7373 L p .707 .577 .707 r
F P
0 g
s
.55548 .70052 m .5455 .73201 L p .52124 .73615 L .707 .577 .707 r
F P
0 g
s
.5455 .73201 m .54466 .73467 L .54366 .73473 L p .707 .577 .707 r
F P
0 g
s
.54366 .73473 m .52124 .73615 L p .5455 .73201 L .707 .577 .707 r
F P
0 g
s
.58327 .64752 m .57985 .68111 L p .54843 .70332 L .707 .577 .707 r
F P
0 g
s
.54466 .73467 m .55548 .70052 L .58388 .70363 L p .707 .577 .707 r
F P
0 g
s
.57985 .68111 m .5777 .7022 L .5653 .70267 L p .707 .577 .707 r
F P
0 g
s
.5653 .70267 m .54843 .70332 L p .57985 .68111 L .707 .577 .707 r
F P
0 g
s
.55278 .7373 m .54719 .7543 L .52381 .75564 L p .707 .577 .707 r
F P
0 g
s
.4888 .31862 m .503 .82182 L .54793 .81958 L p .707 .577 .707 r
F P
0 g
s
.58388 .70363 m .57739 .72412 L p .54466 .73467 L .707 .577 .707 r
F P
0 g
s
.57739 .72412 m .57305 .73778 L .56677 .7371 L p .707 .577 .707 r
F P
0 g
s
.56677 .7371 m .54466 .73467 L p .57739 .72412 L .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .4888 .31862 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54793 .81958 m .54631 .76213 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54631 .76213 m .53373 .31639 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.69345 .82554 m .68786 .84253 L .69518 .83268 L p .707 .577 .707 r
F P
0 g
s
.69518 .83268 m .70077 .81569 L .69345 .82554 L p .707 .577 .707 r
F P
0 g
s
.54843 .70332 m .554 .64864 L .58327 .64752 L p .707 .577 .707 r
F P
0 g
s
.54719 .7543 m .55278 .7373 L .58111 .74063 L p .707 .577 .707 r
F P
0 g
s
.57305 .73778 m .58388 .70363 L .61447 .71104 L p .707 .577 .707 r
F P
0 g
s
.58111 .74063 m .57551 .75763 L .54719 .7543 L p .707 .577 .707 r
F P
0 g
s
.61447 .71104 m .60365 .74519 L .57305 .73778 L p .707 .577 .707 r
F P
0 g
s
.57551 .75763 m .58111 .74063 L .61161 .74831 L p .707 .577 .707 r
F P
0 g
s
.61161 .74831 m .60602 .7653 L .57551 .75763 L p .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .54793 .81958 L .5894 .81391 L p .707 .577 .707 r
F P
0 g
s
.5777 .7022 m .58327 .64752 L .61496 .64958 L p .707 .577 .707 r
F P
0 g
s
.61496 .64958 m .60939 .70426 L .5777 .7022 L p .707 .577 .707 r
F P
0 g
s
.5894 .81391 m .5752 .31071 L .53373 .31639 L p .707 .577 .707 r
F P
0 g
s
.45901 .8204 m .44481 .3172 L .40606 .31226 L p .707 .577 .707 r
F P
0 g
s
.44481 .3172 m .45901 .8204 L .503 .82182 L p .707 .577 .707 r
F P
0 g
s
.64598 .65463 m .6404 .70931 L .60939 .70426 L p .707 .577 .707 r
F P
0 g
s
.60939 .70426 m .61496 .64958 L .64598 .65463 L p .707 .577 .707 r
F P
0 g
s
.64426 .72201 m .63344 .75616 L .60365 .74519 L p .707 .577 .707 r
F P
0 g
s
.60365 .74519 m .61447 .71104 L .64426 .72201 L p .707 .577 .707 r
F P
0 g
s
.67034 .73547 m .65952 .76962 L .63711 .75805 L p .707 .577 .707 r
F P
0 g
s
.64131 .75958 m .63572 .77657 L .63163 .77502 L p .707 .577 .707 r
F P
0 g
s
.63163 .77502 m .60602 .7653 L p .63636 .76038 L .707 .577 .707 r
F P
0 g
s
.63636 .76038 m .64131 .75958 L .63163 .77502 L .707 .577 .707 r
F
.63867 .75323 m .67034 .73547 L .63711 .75805 L F
.60602 .7653 m .61161 .74831 L .64131 .75958 L p F P
0 g
s
.63711 .75805 m .63344 .75616 L p .63867 .75323 L .707 .577 .707 r
F P
0 g
s
.5752 .31071 m .5894 .81391 L .62335 .80535 L p .707 .577 .707 r
F P
0 g
s
.62335 .80535 m .60915 .30216 L .5752 .31071 L p .707 .577 .707 r
F P
0 g
s
.70402 .77719 m .6932 .81134 L .69094 .79863 L p .707 .577 .707 r
F P
0 g
s
.69094 .79863 m .70176 .76448 L .70402 .77719 L p .707 .577 .707 r
F P
0 g
s
.70666 .6816 m .70109 .73628 L .68861 .72615 L p .707 .577 .707 r
F P
0 g
s
.68861 .72615 m .69419 .67146 L .70666 .6816 L p .707 .577 .707 r
F P
0 g
s
.25251 .70281 m .25809 .64812 L .22707 .64307 L p .707 .577 .707 r
F P
0 g
s
.25809 .64812 m .25251 .70281 L .2842 .70487 L p .707 .577 .707 r
F P
0 g
s
.2842 .70487 m .28978 .65019 L .25809 .64812 L p .707 .577 .707 r
F P
0 g
s
.28978 .65019 m .2842 .70487 L .31347 .70374 L p .707 .577 .707 r
F P
0 g
s
.31347 .70374 m .31905 .64906 L .28978 .65019 L p .707 .577 .707 r
F P
0 g
s
.2215 .69776 m .22707 .64307 L .19978 .63553 L p .707 .577 .707 r
F P
0 g
s
.22707 .64307 m .2215 .69776 L .25251 .70281 L p .707 .577 .707 r
F P
0 g
s
.42026 .81546 m .40606 .31226 L .37635 .30429 L p .707 .577 .707 r
F P
0 g
s
.40606 .31226 m .42026 .81546 L .45901 .8204 L p .707 .577 .707 r
F P
0 g
s
.70077 .81569 m .69518 .83268 L .69296 .81983 L p .707 .577 .707 r
F P
0 g
s
.69296 .81983 m .69855 .80284 L .70077 .81569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31905 .64906 m .31347 .70374 L .33745 .69954 L p .707 .577 .707 r
F P
0 g
s
.33745 .69954 m .34303 .64486 L .31905 .64906 L p .707 .577 .707 r
F P
0 g
s
.1942 .69022 m .19978 .63553 L .17886 .62624 L p .707 .577 .707 r
F P
0 g
s
.19978 .63553 m .1942 .69022 L .2215 .69776 L p .707 .577 .707 r
F P
0 g
s
.63344 .75616 m .64426 .72201 L .67034 .73547 L p .707 .577 .707 r
F P
0 g
s
.69015 .75011 m .67933 .78426 L .65952 .76962 L p .707 .577 .707 r
F P
0 g
s
.66729 .77334 m .6617 .79034 L .63572 .77657 L p .707 .577 .707 r
F P
0 g
s
.65952 .76962 m .67034 .73547 L .69015 .75011 L p .707 .577 .707 r
F P
0 g
s
.63572 .77657 m .64131 .75958 L .66729 .77334 L p .707 .577 .707 r
F P
0 g
s
.60915 .30216 m .62335 .80535 L .64645 .79475 L p .707 .577 .707 r
F P
0 g
s
.67327 .66217 m .6677 .71685 L .6404 .70931 L p .707 .577 .707 r
F P
0 g
s
.6404 .70931 m .64598 .65463 L .67327 .66217 L p .707 .577 .707 r
F P
0 g
s
.64645 .79475 m .63225 .29155 L .60915 .30216 L p .707 .577 .707 r
F P
0 g
s
.70176 .76448 m .69094 .79863 L .67933 .78426 L p .707 .577 .707 r
F P
0 g
s
.67933 .78426 m .69015 .75011 L .70176 .76448 L p .707 .577 .707 r
F P
0 g
s
.69419 .67146 m .68861 .72615 L .6677 .71685 L p .707 .577 .707 r
F P
0 g
s
.6677 .71685 m .67327 .66217 L .69419 .67146 L p .707 .577 .707 r
F P
0 g
s
.24433 .77967 m .25516 .74552 L .22536 .73455 L p .707 .577 .707 r
F P
0 g
s
.25516 .74552 m .24433 .77967 L .27492 .78707 L p .707 .577 .707 r
F P
0 g
s
.27492 .78707 m .28575 .75292 L .25516 .74552 L p .707 .577 .707 r
F P
0 g
s
.21454 .7687 m .22536 .73455 L .19928 .72109 L p .707 .577 .707 r
F P
0 g
s
.22536 .73455 m .21454 .7687 L .24433 .77967 L p .707 .577 .707 r
F P
0 g
s
.28575 .75292 m .27492 .78707 L .30332 .79019 L p .707 .577 .707 r
F P
0 g
s
.30332 .79019 m .31414 .75604 L .28575 .75292 L p .707 .577 .707 r
F P
0 g
s
.69855 .80284 m .69296 .81983 L .68142 .80524 L p .707 .577 .707 r
F P
0 g
s
.68142 .80524 m .68702 .78825 L .69855 .80284 L p .707 .577 .707 r
F P
0 g
s
.34303 .64486 m .33745 .69954 L .3538 .69267 L p .707 .577 .707 r
F P
0 g
s
.3538 .69267 m .35937 .63799 L .34303 .64486 L p .707 .577 .707 r
F P
0 g
s
.17886 .62624 m .17329 .68092 L .1942 .69022 L p .707 .577 .707 r
F P
0 g
s
.39055 .80749 m .37635 .30429 L .35859 .29406 L p .707 .577 .707 r
F P
0 g
s
.37635 .30429 m .39055 .80749 L .42026 .81546 L p .707 .577 .707 r
F P
0 g
s
.17329 .68092 m .17886 .62624 L .16638 .6161 L p .707 .577 .707 r
F P
0 g
s
.18846 .75524 m .19928 .72109 L .17947 .70645 L p .707 .577 .707 r
F P
0 g
s
.19928 .72109 m .18846 .75524 L .21454 .7687 L p .707 .577 .707 r
F P
0 g
s
.31414 .75604 m .30332 .79019 L .32674 .78871 L p .707 .577 .707 r
F P
0 g
s
.32674 .78871 m .33756 .75455 L .31414 .75604 L p .707 .577 .707 r
F P
0 g
s
.24651 .84452 m .2521 .82753 L .22241 .81626 L p .707 .577 .707 r
F P
0 g
s
.2521 .82753 m .24651 .84452 L .27701 .8522 L p .707 .577 .707 r
F P
0 g
s
.27701 .8522 m .28261 .8352 L .2521 .82753 L p .707 .577 .707 r
F P
0 g
s
.21681 .83325 m .22241 .81626 L .19642 .8025 L p .707 .577 .707 r
F P
0 g
s
.22241 .81626 m .21681 .83325 L .24651 .84452 L p .707 .577 .707 r
F P
0 g
s
.28261 .8352 m .27701 .8522 L .30534 .85553 L p .707 .577 .707 r
F P
0 g
s
.30534 .85553 m .31093 .83853 L .28261 .8352 L p .707 .577 .707 r
F P
0 g
s
.17947 .70645 m .16865 .7406 L .18846 .75524 L p .707 .577 .707 r
F P
0 g
s
.63225 .29155 m .64645 .79475 L .65645 .78314 L p .707 .577 .707 r
F P
0 g
s
.65645 .78314 m .64225 .27994 L .63225 .29155 L p .707 .577 .707 r
F P
0 g
s
.16638 .6161 m .16081 .67078 L .17329 .68092 L p .707 .577 .707 r
F P
0 g
s
.68702 .78825 m .68142 .80524 L .6617 .79034 L p .707 .577 .707 r
F P
0 g
s
.6617 .79034 m .66729 .77334 L .68702 .78825 L p .707 .577 .707 r
F P
0 g
s
.19642 .8025 m .19083 .81949 L .21681 .83325 L p .707 .577 .707 r
F P
0 g
s
.35937 .63799 m .3538 .69267 L .3609 .68381 L p .707 .577 .707 r
F P
0 g
s
.3609 .68381 m .36648 .62913 L .35937 .63799 L p .707 .577 .707 r
F P
0 g
s
.16865 .7406 m .17947 .70645 L .16786 .69207 L p .707 .577 .707 r
F P
0 g
s
.19083 .81949 m .19642 .8025 L .1767 .78759 L p .707 .577 .707 r
F P
0 g
s
.33756 .75455 m .32674 .78871 L .34289 .78277 L p .707 .577 .707 r
F P
0 g
s
.34289 .78277 m .35371 .74862 L .33756 .75455 L p .707 .577 .707 r
F P
0 g
s
.16081 .67078 m .16638 .6161 L .16356 .60611 L p .707 .577 .707 r
F P
0 g
s
.31093 .83853 m .30534 .85553 L .32872 .85418 L p .707 .577 .707 r
F P
0 g
s
.32872 .85418 m .33431 .83719 L .31093 .83853 L p .707 .577 .707 r
F P
0 g
s
.1767 .78759 m .17111 .80458 L .19083 .81949 L p .707 .577 .707 r
F P
0 g
s
.16786 .69207 m .15704 .72622 L .16865 .7406 L p .707 .577 .707 r
F P
0 g
s
.37279 .79726 m .35859 .29406 L .35451 .28258 L p .707 .577 .707 r
F P
0 g
s
.35859 .29406 m .37279 .79726 L .39055 .80749 L p .707 .577 .707 r
F P
0 g
s
.16356 .60611 m .15799 .66079 L .16081 .67078 L p .707 .577 .707 r
F P
0 g
s
.17111 .80458 m .1767 .78759 L .16516 .773 L p .707 .577 .707 r
F P
0 g
s
.15704 .72622 m .16786 .69207 L .1656 .67936 L p .707 .577 .707 r
F P
0 g
s
.36648 .62913 m .3609 .68381 L .35808 .67382 L p .707 .577 .707 r
F P
0 g
s
.35808 .67382 m .36366 .61914 L .36648 .62913 L p .707 .577 .707 r
F P
0 g
s
.33431 .83719 m .32872 .85418 L .34485 .8483 L p .707 .577 .707 r
F P
0 g
s
.34485 .8483 m .35044 .8313 L .33431 .83719 L p .707 .577 .707 r
F P
0 g
s
.16516 .773 m .15957 .78999 L .17111 .80458 L p .707 .577 .707 r
F P
0 g
s
.35371 .74862 m .34289 .78277 L .35019 .77297 L p .707 .577 .707 r
F P
0 g
s
.35019 .77297 m .36101 .73882 L .35371 .74862 L p .707 .577 .707 r
F P
0 g
s
.15799 .66079 m .16356 .60611 L .17067 .59725 L p .707 .577 .707 r
F P
0 g
s
.64225 .27994 m .65645 .78314 L .65428 .77704 L p .707 .577 .707 r
F P
0 g
s
.65428 .77704 m .65255 .77216 L p .65209 .75001 L .707 .577 .707 r
F P
0 g
s
.65209 .75001 m .64225 .27994 L .65428 .77704 L .707 .577 .707 r
F
.65228 .76689 m .64225 .27994 L .65255 .77216 L F
.65237 .77166 m .63817 .26847 L .64225 .27994 L p F P
0 g
s
.63817 .26847 m .65237 .77166 L .63461 .76144 L p .707 .577 .707 r
F P
0 g
s
.65908 .59667 m .6535 .65135 L .6638 .65592 L p .707 .577 .707 r
F P
0 g
s
.6638 .65592 m .67441 .66064 L p .67025 .64329 L .707 .577 .707 r
F P
0 g
s
.67025 .64329 m .65908 .59667 L .6638 .65592 L .707 .577 .707 r
F
.6466 .58653 m .64411 .61091 L p .6535 .65135 L F P
0 g
s
.64591 .64518 m .6535 .65135 L p .64411 .61091 L .707 .577 .707 r
F P
0 g
s
.6535 .65135 m .65908 .59667 L .6466 .58653 L p .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64808 .63841 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.64886 .68693 m .65035 .68222 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65035 .68222 m .65968 .65278 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64886 .68693 L .66867 .70157 L p .707 .577 .707 r
F P
0 g
s
.64808 .63841 m .63725 .67256 L .64886 .68693 L p .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .65691 .68978 L .64608 .67608 L p .707 .577 .707 r
F P
0 g
s
.64608 .67608 m .64538 .67519 L p .64649 .68109 L .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .64608 .67608 L .64649 .68109 L .707 .577 .707 r
F
.64411 .61091 m .64102 .64121 L .64591 .64518 L p F P
0 g
s
.65255 .77216 m .65237 .77166 L p .65228 .76689 L .707 .577 .707 r
F P
0 g
s
.1656 .67936 m .15478 .71351 L .15704 .72622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15957 .78999 m .16516 .773 L .16295 .76015 L p .707 .577 .707 r
F P
0 g
s
.17067 .59725 m .16509 .65193 L .15799 .66079 L p .707 .577 .707 r
F P
0 g
s
.15478 .71351 m .1656 .67936 L .1729 .66956 L p .707 .577 .707 r
F P
0 g
s
.35044 .8313 m .34485 .8483 L .35217 .83845 L p .707 .577 .707 r
F P
0 g
s
.35217 .83845 m .35776 .82146 L .35044 .8313 L p .707 .577 .707 r
F P
0 g
s
.16295 .76015 m .15735 .77714 L .15957 .78999 L p .707 .577 .707 r
F P
0 g
s
.35451 .28258 m .36871 .78578 L .37279 .79726 L p .707 .577 .707 r
F P
0 g
s
.36871 .78578 m .35451 .28258 L .36451 .27097 L p .707 .577 .707 r
F P
0 g
s
.36366 .61914 m .35808 .67382 L .3456 .66368 L p .707 .577 .707 r
F P
0 g
s
.3456 .66368 m .35118 .609 L .36366 .61914 L p .707 .577 .707 r
F P
0 g
s
.36101 .73882 m .35019 .77297 L .34793 .76026 L p .707 .577 .707 r
F P
0 g
s
.34793 .76026 m .35875 .72611 L .36101 .73882 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16509 .65193 m .17067 .59725 L .18701 .59038 L p .707 .577 .707 r
F P
0 g
s
.1729 .66956 m .16208 .70371 L .15478 .71351 L p .707 .577 .707 r
F P
0 g
s
.15735 .77714 m .16295 .76015 L .17026 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63461 .76144 m .62041 .25824 L .63817 .26847 L p .707 .577 .707 r
F P
0 g
s
.18701 .59038 m .18144 .64506 L .16509 .65193 L p .707 .577 .707 r
F P
0 g
s
.16208 .70371 m .1729 .66956 L .18905 .66363 L p .707 .577 .707 r
F P
0 g
s
.35776 .82146 m .35217 .83845 L .34995 .8256 L p .707 .577 .707 r
F P
0 g
s
.34995 .8256 m .35554 .80861 L .35776 .82146 L p .707 .577 .707 r
F P
0 g
s
.17026 .7503 m .16467 .76729 L .15735 .77714 L p .707 .577 .707 r
F P
0 g
s
.35118 .609 m .3456 .66368 L .32469 .65439 L p .707 .577 .707 r
F P
0 g
s
.32469 .65439 m .33027 .59971 L .35118 .609 L p .707 .577 .707 r
F P
0 g
s
.35875 .72611 m .34793 .76026 L .33632 .74589 L p .707 .577 .707 r
F P
0 g
s
.33632 .74589 m .34715 .71173 L .35875 .72611 L p .707 .577 .707 r
F P
0 g
s
.18144 .64506 m .18701 .59038 L .21099 .58618 L p .707 .577 .707 r
F P
0 g
s
.18905 .66363 m .17823 .69778 L .16208 .70371 L p .707 .577 .707 r
F P
0 g
s
.37871 .77417 m .36451 .27097 L .38762 .26037 L p .707 .577 .707 r
F P
0 g
s
.36451 .27097 m .37871 .77417 L .36871 .78578 L p .707 .577 .707 r
F P
0 g
s
.16467 .76729 m .17026 .7503 L .1864 .74442 L p .707 .577 .707 r
F P
0 g
s
.33027 .59971 m .32469 .65439 L .29739 .64685 L p .707 .577 .707 r
F P
0 g
s
.29739 .64685 m .30297 .59216 L .33027 .59971 L p .707 .577 .707 r
F P
0 g
s
.21099 .58618 m .20542 .64086 L .18144 .64506 L p .707 .577 .707 r
F P
0 g
s
.17823 .69778 m .18905 .66363 L .21247 .66215 L p .707 .577 .707 r
F P
0 g
s
.20542 .64086 m .21099 .58618 L .24026 .58505 L p .707 .577 .707 r
F P
0 g
s
.35554 .80861 m .34995 .8256 L .33841 .81101 L p .707 .577 .707 r
F P
0 g
s
.33841 .81101 m .34401 .79402 L .35554 .80861 L p .707 .577 .707 r
F P
0 g
s
.1864 .74442 m .1808 .76141 L .16467 .76729 L p .707 .577 .707 r
F P
0 g
s
.34715 .71173 m .33632 .74589 L .31651 .73125 L p .707 .577 .707 r
F P
0 g
s
.31651 .73125 m .32733 .6971 L .34715 .71173 L p .707 .577 .707 r
F P
0 g
s
.62041 .25824 m .63461 .76144 L .6049 .75346 L p .707 .577 .707 r
F P
0 g
s
.6049 .75346 m .5907 .25027 L .62041 .25824 L p .707 .577 .707 r
F P
0 g
s
.30297 .59216 m .29739 .64685 L .26638 .6418 L p .707 .577 .707 r
F P
0 g
s
.26638 .6418 m .27195 .58712 L .30297 .59216 L p .707 .577 .707 r
F P
0 g
s
.23469 .63973 m .24026 .58505 L .27195 .58712 L p .707 .577 .707 r
F P
0 g
s
.24026 .58505 m .23469 .63973 L .20542 .64086 L p .707 .577 .707 r
F P
0 g
s
.21247 .66215 m .20165 .6963 L .17823 .69778 L p .707 .577 .707 r
F P
0 g
s
.27195 .58712 m .26638 .6418 L .23469 .63973 L p .707 .577 .707 r
F P
0 g
s
.20165 .6963 m .21247 .66215 L .24087 .66526 L p .707 .577 .707 r
F P
0 g
s
.1808 .76141 m .1864 .74442 L .20977 .74307 L p .707 .577 .707 r
F P
0 g
s
.32733 .6971 m .31651 .73125 L .29043 .71779 L p .707 .577 .707 r
F P
0 g
s
.29043 .71779 m .30125 .68364 L .32733 .6971 L p .707 .577 .707 r
F P
0 g
s
.38762 .26037 m .40182 .76357 L .37871 .77417 L p .707 .577 .707 r
F P
0 g
s
.40182 .76357 m .38762 .26037 L .42157 .25182 L p .707 .577 .707 r
F P
0 g
s
.73272 .67323 m .7383 .61855 L .70729 .6135 L p .707 .577 .707 r
F P
0 g
s
.7383 .61855 m .73272 .67323 L .76442 .6753 L p .707 .577 .707 r
F P
0 g
s
.76442 .6753 m .76999 .62061 L .7383 .61855 L p .707 .577 .707 r
F P
0 g
s
.34401 .79402 m .33841 .81101 L .31869 .7961 L p .707 .577 .707 r
F P
0 g
s
.31869 .7961 m .32428 .77911 L .34401 .79402 L p .707 .577 .707 r
F P
0 g
s
.20977 .74307 m .20418 .76007 L .1808 .76141 L p .707 .577 .707 r
F P
0 g
s
.76999 .62061 m .76442 .6753 L .79368 .67417 L p .707 .577 .707 r
F P
0 g
s
.79368 .67417 m .79926 .61949 L .76999 .62061 L p .707 .577 .707 r
F P
0 g
s
.70171 .66818 m .70729 .6135 L .67999 .60596 L p .707 .577 .707 r
F P
0 g
s
.70729 .6135 m .70171 .66818 L .73272 .67323 L p .707 .577 .707 r
F P
0 g
s
.24087 .66526 m .23004 .69941 L .20165 .6963 L p .707 .577 .707 r
F P
0 g
s
.23004 .69941 m .24087 .66526 L .27146 .67267 L p .707 .577 .707 r
F P
0 g
s
.30125 .68364 m .29043 .71779 L .26064 .70682 L p .707 .577 .707 r
F P
0 g
s
.26064 .70682 m .27146 .67267 L .30125 .68364 L p .707 .577 .707 r
F P
0 g
s
.27146 .67267 m .26064 .70682 L .23004 .69941 L p .707 .577 .707 r
F P
0 g
s
.5907 .25027 m .6049 .75346 L .56615 .74852 L p .707 .577 .707 r
F P
0 g
s
.56615 .74852 m .55195 .24533 L .5907 .25027 L p .707 .577 .707 r
F P
0 g
s
.79926 .61949 m .79368 .67417 L .81766 .66997 L p .707 .577 .707 r
F P
0 g
s
.81766 .66997 m .82324 .61529 L .79926 .61949 L p .707 .577 .707 r
F P
0 g
s
.20418 .76007 m .20977 .74307 L .2381 .7464 L p .707 .577 .707 r
F P
0 g
s
.67441 .66064 m .67999 .60596 L .65908 .59667 L p .707 .577 .707 r
F P
0 g
s
.67999 .60596 m .67441 .66064 L .70171 .66818 L p .707 .577 .707 r
F P
0 g
s
.32428 .77911 m .31869 .7961 L .29271 .78234 L p .707 .577 .707 r
F P
0 g
s
.29271 .78234 m .2983 .76535 L .32428 .77911 L p .707 .577 .707 r
F P
0 g
s
.72455 .726 m .73537 .69185 L .70557 .68088 L p .707 .577 .707 r
F P
0 g
s
.73537 .69185 m .72455 .726 L .75514 .7334 L p .707 .577 .707 r
F P
0 g
s
.75514 .7334 m .76596 .69925 L .73537 .69185 L p .707 .577 .707 r
F P
0 g
s
.2381 .7464 m .2325 .7634 L .20418 .76007 L p .707 .577 .707 r
F P
0 g
s
.69475 .71503 m .70557 .68088 L .67949 .66742 L p .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .70262 .71845 L .69896 .71651 L p .707 .577 .707 r
F P
0 g
s
.70557 .68088 m .69475 .71503 L .69894 .71657 L p .707 .577 .707 r
F P
0 g
s
.70835 .68748 m .70557 .68088 L .69894 .71657 L .707 .577 .707 r
F
.67949 .66742 m .66867 .70157 L .69475 .71503 L p F P
0 g
s
.69896 .71651 m .67664 .70469 L p .69421 .7312 L .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .69896 .71651 L .69421 .7312 L .707 .577 .707 r
F
.69894 .71657 m .72455 .726 L p .70835 .68748 L F P
0 g
s
.43577 .75501 m .42157 .25182 L .46303 .24614 L p .707 .577 .707 r
F P
0 g
s
.42157 .25182 m .43577 .75501 L .40182 .76357 L p .707 .577 .707 r
F P
0 g
s
.76596 .69925 m .75514 .7334 L .78353 .73652 L p .707 .577 .707 r
F P
0 g
s
.78353 .73652 m .79436 .70237 L .76596 .69925 L p .707 .577 .707 r
F P
0 g
s
.2325 .7634 m .2381 .7464 L .2686 .75408 L p .707 .577 .707 r
F P
0 g
s
.2983 .76535 m .29271 .78234 L .26301 .77107 L p .707 .577 .707 r
F P
0 g
s
.26301 .77107 m .2686 .75408 L .2983 .76535 L p .707 .577 .707 r
F P
0 g
s
.72672 .74672 m .73232 .72972 L .70262 .71845 L p .707 .577 .707 r
F P
0 g
s
.73232 .72972 m .72672 .74672 L .75723 .75439 L p .707 .577 .707 r
F P
0 g
s
.75723 .75439 m .76282 .7374 L .73232 .72972 L p .707 .577 .707 r
F P
0 g
s
.55195 .24533 m .56615 .74852 L .52216 .7471 L p .707 .577 .707 r
F P
0 g
s
.52216 .7471 m .50796 .24391 L .55195 .24533 L p .707 .577 .707 r
F P
0 g
s
.2686 .75408 m .26301 .77107 L .2325 .7634 L p .707 .577 .707 r
F P
0 g
s
.70262 .71845 m .69703 .73545 L .72672 .74672 L p .707 .577 .707 r
F P
0 g
s
.82324 .61529 m .81766 .66997 L .83401 .6631 L p .707 .577 .707 r
F P
0 g
s
.83401 .6631 m .83958 .60842 L .82324 .61529 L p .707 .577 .707 r
F P
0 g
s
.66867 .70157 m .67949 .66742 L .65968 .65278 L p .707 .577 .707 r
F P
0 g
s
.76282 .7374 m .75723 .75439 L .78555 .75772 L p .707 .577 .707 r
F P
0 g
s
.78555 .75772 m .79115 .74072 L .76282 .7374 L p .707 .577 .707 r
F P
0 g
s
.79436 .70237 m .78353 .73652 L .80695 .73504 L p .707 .577 .707 r
F P
0 g
s
.80695 .73504 m .81777 .70089 L .79436 .70237 L p .707 .577 .707 r
F P
0 g
s
.47723 .74934 m .46303 .24614 L .50796 .24391 L p .707 .577 .707 r
F P
0 g
s
.46303 .24614 m .47723 .74934 L .43577 .75501 L p .707 .577 .707 r
F P
0 g
s
.67664 .70469 m .67104 .72168 L .69703 .73545 L p .707 .577 .707 r
F P
0 g
s
.50796 .24391 m .52216 .7471 L .47723 .74934 L p .707 .577 .707 r
F P
0 g
s
.67104 .72168 m .67664 .70469 L .65691 .68978 L p .707 .577 .707 r
F P
0 g
s
.79115 .74072 m .78555 .75772 L .80893 .75638 L p .707 .577 .707 r
F P
0 g
s
.80893 .75638 m .81452 .73938 L .79115 .74072 L p .707 .577 .707 r
F P
0 g
s
.65691 .68978 m .65132 .70678 L .67104 .72168 L p .707 .577 .707 r
F P
0 g
s
.81777 .70089 m .80695 .73504 L .8231 .72911 L p .707 .577 .707 r
F P
0 g
s
.8231 .72911 m .83393 .69496 L .81777 .70089 L p .707 .577 .707 r
F P
0 g
s
.83958 .60842 m .83401 .6631 L .84112 .65424 L p .707 .577 .707 r
F P
0 g
s
.84112 .65424 m .84669 .59955 L .83958 .60842 L p .707 .577 .707 r
F P
0 g
s
.64102 .64121 m .6466 .58653 L .64377 .57654 L p .707 .577 .707 r
F P
0 g
s
.81452 .73938 m .80893 .75638 L .82506 .75049 L p .707 .577 .707 r
F P
0 g
s
.82506 .75049 m .83066 .7335 L .81452 .73938 L p .707 .577 .707 r
F P
0 g
s
.64538 .67519 m .63978 .69219 L .65132 .70678 L p .707 .577 .707 r
F P
0 g
s
.63725 .67256 m .64808 .63841 L .64581 .62569 L p .707 .577 .707 r
F P
0 g
s
.63989 .63721 m .64102 .64121 L p .64152 .62946 L .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .63499 .65985 L .63725 .67256 L p .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .65312 .61589 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63499 .65985 m .63542 .6585 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63542 .6585 m .64581 .62569 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.64377 .57654 m .6382 .63122 L .63989 .63721 L p .707 .577 .707 r
F P
0 g
s
.64152 .62946 m .64377 .57654 L .63989 .63721 L .707 .577 .707 r
F
.83393 .69496 m .8231 .72911 L .8304 .71931 L p F P
0 g
s
.8304 .71931 m .84123 .68515 L .83393 .69496 L p .707 .577 .707 r
F P
0 g
s
.84669 .59955 m .84112 .65424 L .83829 .64425 L p .707 .577 .707 r
F P
0 g
s
.83829 .64425 m .84387 .58956 L .84669 .59955 L p .707 .577 .707 r
F P
0 g
s
.63978 .69219 m .64538 .67519 L .64316 .66234 L p .707 .577 .707 r
F P
0 g
s
.6382 .63122 m .64377 .57654 L .65088 .56767 L p .707 .577 .707 r
F P
0 g
s
.83066 .7335 m .82506 .75049 L .83238 .74064 L p .707 .577 .707 r
F P
0 g
s
.83238 .74064 m .83798 .72365 L .83066 .7335 L p .707 .577 .707 r
F P
0 g
s
.64316 .66234 m .63757 .67934 L .63978 .69219 L p .707 .577 .707 r
F P
0 g
s
.65088 .56767 m .64531 .62236 L .6382 .63122 L p .707 .577 .707 r
F P
0 g
s
.84123 .68515 m .8304 .71931 L .82814 .70659 L p .707 .577 .707 r
F P
0 g
s
.82814 .70659 m .83896 .67244 L .84123 .68515 L p .707 .577 .707 r
F P
0 g
s
.84387 .58956 m .83829 .64425 L .82582 .63411 L p .707 .577 .707 r
F P
0 g
s
.82582 .63411 m .83139 .57943 L .84387 .58956 L p .707 .577 .707 r
F P
0 g
s
.38971 .61077 m .39529 .55609 L .36428 .55104 L p .707 .577 .707 r
F P
0 g
s
.39529 .55609 m .38971 .61077 L .42141 .61283 L p .707 .577 .707 r
F P
0 g
s
.42141 .61283 m .42698 .55815 L .39529 .55609 L p .707 .577 .707 r
F P
0 g
s
.63757 .67934 m .64316 .66234 L .65048 .65249 L p .707 .577 .707 r
F P
0 g
s
.66723 .56081 m .66365 .59589 L p .64531 .62236 L .707 .577 .707 r
F P
0 g
s
.64229 .65004 m .65312 .61589 L .66927 .60996 L p .707 .577 .707 r
F P
0 g
s
.66365 .59589 m .66165 .61549 L .65475 .61839 L p .707 .577 .707 r
F P
0 g
s
.65312 .61589 m .64257 .64916 L p .63499 .65985 L .707 .577 .707 r
F P
0 g
s
.65475 .61839 m .64531 .62236 L p .66365 .59589 L .707 .577 .707 r
F P
0 g
s
.64257 .64916 m .64229 .65004 L .64214 .65025 L p .707 .577 .707 r
F P
0 g
s
.64214 .65025 m .63499 .65985 L p .64257 .64916 L .707 .577 .707 r
F P
0 g
s
.42698 .55815 m .42141 .61283 L .45067 .61171 L p .707 .577 .707 r
F P
0 g
s
.45067 .61171 m .45625 .55702 L .42698 .55815 L p .707 .577 .707 r
F P
0 g
s
.64531 .62236 m .65088 .56767 L .66723 .56081 L p .707 .577 .707 r
F P
0 g
s
.3587 .60572 m .36428 .55104 L .33698 .54349 L p .707 .577 .707 r
F P
0 g
s
.36428 .55104 m .3587 .60572 L .38971 .61077 L p .707 .577 .707 r
F P
0 g
s
.83798 .72365 m .83238 .74064 L .83016 .7278 L p .707 .577 .707 r
F P
0 g
s
.83016 .7278 m .83576 .7108 L .83798 .72365 L p .707 .577 .707 r
F P
0 g
s
.65048 .65249 m .64488 .66949 L .63757 .67934 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45625 .55702 m .45067 .61171 L .47465 .6075 L p .707 .577 .707 r
F P
0 g
s
.47465 .6075 m .48023 .55282 L .45625 .55702 L p .707 .577 .707 r
F P
0 g
s
.3314 .59818 m .33698 .54349 L .31607 .5342 L p .707 .577 .707 r
F P
0 g
s
.33698 .54349 m .3314 .59818 L .3587 .60572 L p .707 .577 .707 r
F P
0 g
s
.83896 .67244 m .82814 .70659 L .81654 .69222 L p .707 .577 .707 r
F P
0 g
s
.81654 .69222 m .82736 .65807 L .83896 .67244 L p .707 .577 .707 r
F P
0 g
s
.83139 .57943 m .82582 .63411 L .8049 .62481 L p .707 .577 .707 r
F P
0 g
s
.8049 .62481 m .81048 .57013 L .83139 .57943 L p .707 .577 .707 r
F P
0 g
s
.38154 .68763 m .39236 .65348 L .36256 .64251 L p .707 .577 .707 r
F P
0 g
s
.39236 .65348 m .38154 .68763 L .41213 .69503 L p .707 .577 .707 r
F P
0 g
s
.41213 .69503 m .42295 .66088 L .39236 .65348 L p .707 .577 .707 r
F P
0 g
s
.64488 .66949 m .65048 .65249 L .66661 .64661 L p .707 .577 .707 r
F P
0 g
s
.35174 .67666 m .36256 .64251 L .33648 .62905 L p .707 .577 .707 r
F P
0 g
s
.36256 .64251 m .35174 .67666 L .38154 .68763 L p .707 .577 .707 r
F P
0 g
s
.69121 .5566 m .68749 .5931 L p .66165 .61549 L .707 .577 .707 r
F P
0 g
s
.65844 .64411 m .66927 .60996 L .69269 .60848 L p .707 .577 .707 r
F P
0 g
s
.68749 .5931 m .68563 .61128 L .67604 .61297 L p .707 .577 .707 r
F P
0 g
s
.66927 .60996 m .65887 .64277 L p .64229 .65004 L .707 .577 .707 r
F P
0 g
s
.67604 .61297 m .66165 .61549 L p .68749 .5931 L .707 .577 .707 r
F P
0 g
s
.65887 .64277 m .65844 .64411 L .658 .64428 L p .707 .577 .707 r
F P
0 g
s
.658 .64428 m .64229 .65004 L p .65887 .64277 L .707 .577 .707 r
F P
0 g
s
.66165 .61549 m .66723 .56081 L .69121 .5566 L p .707 .577 .707 r
F P
0 g
s
.42295 .66088 m .41213 .69503 L .44052 .69815 L p .707 .577 .707 r
F P
0 g
s
.44052 .69815 m .45135 .664 L .42295 .66088 L p .707 .577 .707 r
F P
0 g
s
.83576 .7108 m .83016 .7278 L .81863 .7132 L p .707 .577 .707 r
F P
0 g
s
.81863 .7132 m .82422 .69621 L .83576 .7108 L p .707 .577 .707 r
F P
0 g
s
.66661 .64661 m .66102 .6636 L .64488 .66949 L p .707 .577 .707 r
F P
0 g
s
.48023 .55282 m .47465 .6075 L .491 .60063 L p .707 .577 .707 r
F P
0 g
s
.491 .60063 m .49657 .54595 L .48023 .55282 L p .707 .577 .707 r
F P
0 g
s
.31607 .5342 m .31049 .58888 L .3314 .59818 L p .707 .577 .707 r
F P
0 g
s
.31049 .58888 m .31607 .5342 L .30359 .52406 L p .707 .577 .707 r
F P
0 g
s
.32566 .6632 m .33648 .62905 L .31667 .61441 L p .707 .577 .707 r
F P
0 g
s
.33648 .62905 m .32566 .6632 L .35174 .67666 L p .707 .577 .707 r
F P
0 g
s
.45135 .664 m .44052 .69815 L .46394 .69667 L p .707 .577 .707 r
F P
0 g
s
.46394 .69667 m .47477 .66252 L .45135 .664 L p .707 .577 .707 r
F P
0 g
s
.81048 .57013 m .8049 .62481 L .7776 .61727 L p .707 .577 .707 r
F P
0 g
s
.7776 .61727 m .78318 .56259 L .81048 .57013 L p .707 .577 .707 r
F P
0 g
s
.82736 .65807 m .81654 .69222 L .79672 .67758 L p .707 .577 .707 r
F P
0 g
s
.79672 .67758 m .80755 .64343 L .82736 .65807 L p .707 .577 .707 r
F P
0 g
s
.38371 .75248 m .38931 .73549 L .35961 .72422 L p .707 .577 .707 r
F P
0 g
s
.38931 .73549 m .38371 .75248 L .41422 .76016 L p .707 .577 .707 r
F P
0 g
s
.41422 .76016 m .41981 .74316 L .38931 .73549 L p .707 .577 .707 r
F P
0 g
s
.68563 .61128 m .69121 .5566 L .72048 .55548 L p .707 .577 .707 r
F P
0 g
s
.35402 .74121 m .35961 .72422 L .33363 .71046 L p .707 .577 .707 r
F P
0 g
s
.35961 .72422 m .35402 .74121 L .38371 .75248 L p .707 .577 .707 r
F P
0 g
s
.66102 .6636 m .66661 .64661 L .68999 .64527 L p .707 .577 .707 r
F P
0 g
s
.41981 .74316 m .41422 .76016 L .44254 .76349 L p .707 .577 .707 r
F P
0 g
s
.44254 .76349 m .44814 .74649 L .41981 .74316 L p .707 .577 .707 r
F P
0 g
s
.31667 .61441 m .30585 .64856 L .32566 .6632 L p .707 .577 .707 r
F P
0 g
s
.72048 .55548 m .71705 .58907 L p .68563 .61128 L .707 .577 .707 r
F P
0 g
s
.68186 .64263 m .69269 .60848 L .72108 .6116 L p .707 .577 .707 r
F P
0 g
s
.71705 .58907 m .7149 .61016 L .7025 .61064 L p .707 .577 .707 r
F P
0 g
s
.69269 .60848 m .68271 .63997 L p .65844 .64411 L .707 .577 .707 r
F P
0 g
s
.7025 .61064 m .68563 .61128 L p .71705 .58907 L .707 .577 .707 r
F P
0 g
s
.68271 .63997 m .68186 .64263 L .68087 .6427 L p .707 .577 .707 r
F P
0 g
s
.68087 .6427 m .65844 .64411 L p .68271 .63997 L .707 .577 .707 r
F P
0 g
s
.30359 .52406 m .29801 .57874 L .31049 .58888 L p .707 .577 .707 r
F P
0 g
s
.82422 .69621 m .81863 .7132 L .7989 .6983 L p .707 .577 .707 r
F P
0 g
s
.7989 .6983 m .8045 .6813 L .82422 .69621 L p .707 .577 .707 r
F P
0 g
s
.33363 .71046 m .32803 .72745 L .35402 .74121 L p .707 .577 .707 r
F P
0 g
s
.68999 .64527 m .68439 .66226 L .66102 .6636 L p .707 .577 .707 r
F P
0 g
s
.78318 .56259 m .7776 .61727 L .74659 .61222 L p .707 .577 .707 r
F P
0 g
s
.74659 .61222 m .75217 .55754 L .78318 .56259 L p .707 .577 .707 r
F P
0 g
s
.49657 .54595 m .491 .60063 L .49811 .59177 L p .707 .577 .707 r
F P
0 g
s
.49811 .59177 m .50368 .53709 L .49657 .54595 L p .707 .577 .707 r
F P
0 g
s
.30585 .64856 m .31667 .61441 L .30507 .60003 L p .707 .577 .707 r
F P
0 g
s
.7149 .61016 m .72048 .55548 L .75217 .55754 L p .707 .577 .707 r
F P
0 g
s
.32803 .72745 m .33363 .71046 L .3139 .69555 L p .707 .577 .707 r
F P
0 g
s
.75217 .55754 m .74659 .61222 L .7149 .61016 L p .707 .577 .707 r
F P
0 g
s
.47477 .66252 m .46394 .69667 L .48009 .69074 L p .707 .577 .707 r
F P
0 g
s
.48009 .69074 m .49092 .65658 L .47477 .66252 L p .707 .577 .707 r
F P
0 g
s
.80755 .64343 m .79672 .67758 L .77431 .66601 L p .707 .577 .707 r
F P
0 g
s
.77851 .66754 m .77292 .68454 L .76884 .68299 L p .707 .577 .707 r
F P
0 g
s
.76884 .68299 m .74322 .67326 L p .77356 .66834 L .707 .577 .707 r
F P
0 g
s
.77356 .66834 m .77851 .66754 L .76884 .68299 L .707 .577 .707 r
F
.77587 .66119 m .80755 .64343 L .77431 .66601 L F
.74322 .67326 m .74882 .65627 L .77851 .66754 L p F P
0 g
s
.77431 .66601 m .77064 .66412 L p .77587 .66119 L .707 .577 .707 r
F P
0 g
s
.77064 .66412 m .78147 .62997 L .80755 .64343 L p .707 .577 .707 r
F P
0 g
s
.29801 .57874 m .30359 .52406 L .30076 .51407 L p .707 .577 .707 r
F P
0 g
s
.44814 .74649 m .44254 .76349 L .46592 .76214 L p .707 .577 .707 r
F P
0 g
s
.46592 .76214 m .47151 .74515 L .44814 .74649 L p .707 .577 .707 r
F P
0 g
s
.3139 .69555 m .30831 .71255 L .32803 .72745 L p .707 .577 .707 r
F P
0 g
s
.68439 .66226 m .68999 .64527 L .71831 .6486 L p .707 .577 .707 r
F P
0 g
s
.30507 .60003 m .29424 .63419 L .30585 .64856 L p .707 .577 .707 r
F P
0 g
s
.72108 .6116 m .71026 .64575 L .68186 .64263 L p .707 .577 .707 r
F P
0 g
s
.71026 .64575 m .72108 .6116 L .75167 .619 L p .707 .577 .707 r
F P
0 g
s
.8045 .6813 m .7989 .6983 L .77292 .68454 L p .707 .577 .707 r
F P
0 g
s
.77292 .68454 m .77851 .66754 L .8045 .6813 L p .707 .577 .707 r
F P
0 g
s
.78147 .62997 m .77064 .66412 L .74085 .65315 L p .707 .577 .707 r
F P
0 g
s
.74085 .65315 m .75167 .619 L .78147 .62997 L p .707 .577 .707 r
F P
0 g
s
.71831 .6486 m .71272 .66559 L .68439 .66226 L p .707 .577 .707 r
F P
0 g
s
.75167 .619 m .74085 .65315 L .71026 .64575 L p .707 .577 .707 r
F P
0 g
s
.30076 .51407 m .29519 .56875 L .29801 .57874 L p .707 .577 .707 r
F P
0 g
s
.30831 .71255 m .3139 .69555 L .30237 .68096 L p .707 .577 .707 r
F P
0 g
s
.29424 .63419 m .30507 .60003 L .3028 .58732 L p .707 .577 .707 r
F P
0 g
s
.71272 .66559 m .71831 .6486 L .74882 .65627 L p .707 .577 .707 r
F P
0 g
s
.50368 .53709 m .49811 .59177 L .49528 .58178 L p .707 .577 .707 r
F P
0 g
s
.49528 .58178 m .50086 .5271 L .50368 .53709 L p .707 .577 .707 r
F P
0 g
s
.47151 .74515 m .46592 .76214 L .48205 .75626 L p .707 .577 .707 r
F P
0 g
s
.48205 .75626 m .48765 .73927 L .47151 .74515 L p .707 .577 .707 r
F P
0 g
s
.30237 .68096 m .29677 .69795 L .30831 .71255 L p .707 .577 .707 r
F P
0 g
s
.49092 .65658 m .48009 .69074 L .48739 .68093 L p .707 .577 .707 r
F P
0 g
s
.48739 .68093 m .49822 .64678 L .49092 .65658 L p .707 .577 .707 r
F P
0 g
s
.74882 .65627 m .74322 .67326 L .71272 .66559 L p .707 .577 .707 r
F P
0 g
s
.29519 .56875 m .30076 .51407 L .30787 .50521 L p .707 .577 .707 r
F P
0 g
s
.3028 .58732 m .29198 .62147 L .29424 .63419 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29677 .69795 m .30237 .68096 L .30015 .66811 L p .707 .577 .707 r
F P
0 g
s
.30787 .50521 m .3023 .55989 L .29519 .56875 L p .707 .577 .707 r
F P
0 g
s
.29198 .62147 m .3028 .58732 L .31011 .57752 L p .707 .577 .707 r
F P
0 g
s
.48765 .73927 m .48205 .75626 L .48937 .74641 L p .707 .577 .707 r
F P
0 g
s
.48937 .74641 m .49497 .72942 L .48765 .73927 L p .707 .577 .707 r
F P
0 g
s
.30015 .66811 m .29455 .6851 L .29677 .69795 L p .707 .577 .707 r
F P
0 g
s
.50086 .5271 m .49528 .58178 L .48281 .57164 L p .707 .577 .707 r
F P
0 g
s
.48281 .57164 m .48838 .51696 L .50086 .5271 L p .707 .577 .707 r
F P
0 g
s
.49822 .64678 m .48739 .68093 L .48513 .66822 L p .707 .577 .707 r
F P
0 g
s
.48513 .66822 m .49595 .63407 L .49822 .64678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3023 .55989 m .30787 .50521 L .32422 .49834 L p .707 .577 .707 r
F P
0 g
s
.31011 .57752 m .29928 .61167 L .29198 .62147 L p .707 .577 .707 r
F P
0 g
s
.29455 .6851 m .30015 .66811 L .30747 .65826 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32422 .49834 m .31864 .55302 L .3023 .55989 L p .707 .577 .707 r
F P
0 g
s
.29928 .61167 m .31011 .57752 L .32626 .57159 L p .707 .577 .707 r
F P
0 g
s
.49497 .72942 m .48937 .74641 L .48715 .73356 L p .707 .577 .707 r
F P
0 g
s
.48715 .73356 m .49275 .71657 L .49497 .72942 L p .707 .577 .707 r
F P
0 g
s
.30747 .65826 m .30187 .67526 L .29455 .6851 L p .707 .577 .707 r
F P
0 g
s
.48838 .51696 m .48281 .57164 L .46189 .56235 L p .707 .577 .707 r
F P
0 g
s
.46189 .56235 m .46747 .50767 L .48838 .51696 L p .707 .577 .707 r
F P
0 g
s
.49595 .63407 m .48513 .66822 L .47353 .65385 L p .707 .577 .707 r
F P
0 g
s
.47353 .65385 m .48435 .6197 L .49595 .63407 L p .707 .577 .707 r
F P
0 g
s
.31864 .55302 m .32422 .49834 L .3482 .49414 L p .707 .577 .707 r
F P
0 g
s
.32626 .57159 m .31543 .60574 L .29928 .61167 L p .707 .577 .707 r
F P
0 g
s
.30187 .67526 m .30747 .65826 L .3236 .65238 L p .707 .577 .707 r
F P
0 g
s
.46747 .50767 m .46189 .56235 L .43459 .55481 L p .707 .577 .707 r
F P
0 g
s
.43459 .55481 m .44017 .50013 L .46747 .50767 L p .707 .577 .707 r
F P
0 g
s
.3482 .49414 m .34262 .54882 L .31864 .55302 L p .707 .577 .707 r
F P
0 g
s
.31543 .60574 m .32626 .57159 L .34968 .57011 L p .707 .577 .707 r
F P
0 g
s
.34262 .54882 m .3482 .49414 L .37746 .49301 L p .707 .577 .707 r
F P
0 g
s
.49275 .71657 m .48715 .73356 L .47562 .71897 L p .707 .577 .707 r
F P
0 g
s
.47562 .71897 m .48121 .70198 L .49275 .71657 L p .707 .577 .707 r
F P
0 g
s
.3236 .65238 m .31801 .66937 L .30187 .67526 L p .707 .577 .707 r
F P
0 g
s
.48435 .6197 m .47353 .65385 L .45371 .63921 L p .707 .577 .707 r
F P
0 g
s
.45371 .63921 m .46454 .60506 L .48435 .6197 L p .707 .577 .707 r
F P
0 g
s
.44017 .50013 m .43459 .55481 L .40358 .54976 L p .707 .577 .707 r
F P
0 g
s
.40358 .54976 m .40916 .49508 L .44017 .50013 L p .707 .577 .707 r
F P
0 g
s
.37189 .54769 m .37746 .49301 L .40916 .49508 L p .707 .577 .707 r
F P
0 g
s
.37746 .49301 m .37189 .54769 L .34262 .54882 L p .707 .577 .707 r
F P
0 g
s
.34968 .57011 m .33885 .60426 L .31543 .60574 L p .707 .577 .707 r
F P
0 g
s
.40916 .49508 m .40358 .54976 L .37189 .54769 L p .707 .577 .707 r
F P
0 g
s
.33885 .60426 m .34968 .57011 L .37807 .57322 L p .707 .577 .707 r
F P
0 g
s
.31801 .66937 m .3236 .65238 L .34698 .65103 L p .707 .577 .707 r
F P
0 g
s
.46454 .60506 m .45371 .63921 L .42763 .62575 L p .707 .577 .707 r
F P
0 g
s
.42763 .62575 m .43846 .5916 L .46454 .60506 L p .707 .577 .707 r
F P
0 g
s
.48121 .70198 m .47562 .71897 L .45589 .70407 L p .707 .577 .707 r
F P
0 g
s
.45589 .70407 m .46149 .68707 L .48121 .70198 L p .707 .577 .707 r
F P
0 g
s
.34698 .65103 m .34138 .66803 L .31801 .66937 L p .707 .577 .707 r
F P
0 g
s
.37807 .57322 m .36725 .60738 L .33885 .60426 L p .707 .577 .707 r
F P
0 g
s
.36725 .60738 m .37807 .57322 L .40866 .58063 L p .707 .577 .707 r
F P
0 g
s
.43846 .5916 m .42763 .62575 L .39784 .61478 L p .707 .577 .707 r
F P
0 g
s
.39784 .61478 m .40866 .58063 L .43846 .5916 L p .707 .577 .707 r
F P
0 g
s
.40866 .58063 m .39784 .61478 L .36725 .60738 L p .707 .577 .707 r
F P
0 g
s
.34138 .66803 m .34698 .65103 L .3753 .65436 L p .707 .577 .707 r
F P
0 g
s
.46149 .68707 m .45589 .70407 L .42991 .6903 L p .707 .577 .707 r
F P
0 g
s
.42991 .6903 m .4355 .67331 L .46149 .68707 L p .707 .577 .707 r
F P
0 g
s
.3753 .65436 m .36971 .67136 L .34138 .66803 L p .707 .577 .707 r
F P
0 g
s
.36971 .67136 m .3753 .65436 L .40581 .66204 L p .707 .577 .707 r
F P
0 g
s
.4355 .67331 m .42991 .6903 L .40021 .67903 L p .707 .577 .707 r
F P
0 g
s
.40021 .67903 m .40581 .66204 L .4355 .67331 L p .707 .577 .707 r
F P
0 g
s
.40581 .66204 m .40021 .67903 L .36971 .67136 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo001nOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol007Ioo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00Lgoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000Kgoo001`Ool30004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001/Ool006eoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP<006Yoo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00J7oo
001YOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVEoo`00IGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIGoo
001UOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol006Eoo`04001JEUYF
0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001T
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol0061ooaL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00Fgoo1@000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001IOol200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Moo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00EWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00EGoo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUH005YF0002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00E7oo0P0015YF00@005YFFUIJEP`000AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol005Aoo`03FUH005YF009JEPD00003FUH005YF00IJEP03001JEUYF00@0009JEP03001J
EUYF00AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000@Ool8001<Ool005=oo`04001JEP00FUH30005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUHC0002FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0027oo20000eYF
00<005YFFUH00UYF1`00AGoo001COol01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF
00EJEP<000MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool40003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040011Ool005=oo`<0009JEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005=oo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF
009JEP800007FUH005YFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00>Goo001COol00`00FUIJEP02FUH01000FUIJEUYF2`001eYF1@00
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF0P0025YF00<005YFFUH01UYF00<005YFFUH00eYF1000=Goo001DOol01P00FUIJEUYF001JEP<0
00IJEP04001JEUYFFUH7000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YF
FUH005YF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0
009JEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002000bOol005Aoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF008000EJEP03
001JEUYF00EJEP8000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00
EGoo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00;goo000iOolG0006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEP0002ioo`00=7oo1@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010000Woo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000]Ool0039oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Goo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30000
0eYF001JEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH0
1000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000_Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00@005YF000000UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP05001JEUYFFUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH60002FUH20002Ool70007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
1@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH00UYF0P00
0goo00<005YFFUH01@000UYF00<005YFFUH01UYF00<005YFFUH01eYF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEPh000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001J
EUYF0005FUH20002Ool01000FUIJEP0015YF10001eYF00<005YFFUH01UYF00<005YFFUH00P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF
00<0009JEP03001JEUYF00EJEP03001JEP0000X000AJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH2000/Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000EJEP800003FUH005YF00AJEP03001JEP000080009JEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEPH000EJEP03001JEUYF00AJEP03
001JEUYF00=JEPD000=oo`H000EJEP03001JEUYF00AJEP06001JEUYF001JEP00;7oo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP020005FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUIJEP<00003
FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEP00FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH?00000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP8000QJEP03
001JEUYF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
00<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000QJEP80
00EJEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00@005YFFUH000AJEP<000QJEP8000EJEP03001JEUYF00AJEP03001JEP0000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEP<000IJEP04001JEP000003FUH01000FUIJEUYF
0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01000FUIJEP00
0eYF1@001eYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP<000=JEP04001JEUYFFUH200000eYF001JEP02FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20002FUH20002FUH01000
FUIJEUYF1@001eYF00@005YFFUIJEP<000MJEP05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUH000020006FUH20003FUH2000]Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00
FUIJEP03FUH40002FUH01000FUIJEUYF1@001eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000P000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P001EYF00<005YF00000UYF0P00;Goo000]Ool20004FUH01000FUIJEUYF300017oo2@0015YF
00@005YFFUH000IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<000QJEP03001JEUYF00AJEP80
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool00eYF001JEP02FUH500000eYF001JEP06
FUH00`00FUIJEP040009Ool70006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000002FUHC0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH3000]Ool002aoo`04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH@0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH30004FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH0000300001EYF000005YF00001UYF00@005YFFUIJEPP0009JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000AJEP<002eoo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF009JEP80009JEP`000MJEP@000QJEP03
001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF001JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP0000D000QJ
EP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002aoo`<0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00AJEP<000IJEP04001JEUYF
FUH70002FUH00`00FUIJEP040004FUH00`00FUIJEP09FUH20002FUH00`00FUH00006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00
;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH010001EYF1P002UYF
0P000UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000AJ
EP000000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003
FUH005YF00IJEP03001JEUYF00EJEP04001JEP00000^Ool002aoo`03001JEUYF009JEP04001JEUYF
FUH;0007FUH50005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40003FUH01000FUIJEUYF3@0000=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF0P0000=JEP0000000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH00UYF
0`001eYF00<005YFFUH01EYF0`00;goo000]Ool01P00FUIJEUYF001JEP<000IJEP04001JEUYFFUH7
000015YF000000001UYF00@005YFFUIJEP8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH0
0`00FUH000020008FUH00`00FUIJEP03FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP800004FUH00000FUH20006FUH<0006FUH00`00FUIJEP06FUH20005
FUH00`00FUIJEP04FUH00`00FUH0000`Ool002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040006FUH01000FUIJEUYF0P000UYF1@0000=JEP0000000eYF1`001eYF
00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000040007FUH;00000eYF000000020002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00@005YFFUH002moo`00;Woo00@0
05YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00800005FUH00000FUH00005FUH40007FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000800003FUH005YF00EJEP04001JEUYFFUH30005Ool90007FUH01000FUIJEUYF0`001eYF
00D005YFFUIJEP0002ioo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YF00000P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH00P0025YF0`0000=JEP00
FUH025YF0`0000=JEP00FUH015YF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00=JEP8000eoo`8000EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP03001oogoo02aoo`00;goo0P000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF
00@005YFFUIJEP@000EJEP03001JEP0000<000QJEP03001JEUYF008000AJEP03001JEUYF009JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00001JEP020006FUH0
0`00FUIJEP05FUH2000=Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF0000009JEP03001JEUYF00AJEP06001JEUYFFUH005YF1@0000=JEP00FUH02000
15YF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0006FUH00`00FUIJEP08FUH3000<Ool30008
FUH30002FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00005FUH00`00FUIJEP02FUH2
000017oo001JEUYF2@000eYF0`0000=JEP00FUH01UYF0`000eYF0P002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0037oo0P001UYF00<005YFFUH00P0015YF00<005YF0000;Goo000^Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0005FUH01000FUIJEUYF0P000Woo00@005YFFUH000=JEPD0009JEP04001JEUYFFUH20008FUH20002
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH3000;Ool20003FUH00`00FUIJEP02FUH20002
FUH00`00FUH0000^Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP04001JEP000004Ool01000FUIJEP0015YF0`00
00=JEP00000010000UYF0P001EYF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP0000<000Uoo`800003FUH005YF00EJEP05001JEP00FUH0000^Ool002eoo`03001JEP00009JEQ80
00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000<000Ioo`04001JEUYF0006FUH0
0`00FUIJEP05FUH60003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000Eoo`8000IJEP<00003FUH007oo02eoo`00;Goo0P0000AJEP000000011oo`D0009J
EP03001JEUYF00IJEP03001JEP00009JEP05001JEUYF001JEP020008Ool01000FUIJEP001UYF00<0
05YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF200015YF00D005YF001JEP0002moo`00;Goo00=JEP0000000eYF00<007ooOol04Woo
0`0025YF00<005YF00000UYF00D005YFFUIJEP00009JEP8000Ioo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF008002moo`00;7oo0P001EYF0P00
5Woo0P001UYF00<005YFFUH00P001EYF00D005YFFUIJEP0000Eoo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20004FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`001EYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF0P000eYF0P00;goo000/Ool20004FUH01000FUIJEP005goo0P00
15YF00D005YFFUIJEP0000IJEP80009JEP03001oogoo009oo`04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEP<000UJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000AJEP03001oogoo02eoo`00;7oo0P0015YF00D005YF
FUIJEP0001Qoo`800003FUH005YF00AJEP8000AJEP03001JEP0000<000=oo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF0`00
1UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P00;goo
000/Ool20003FUH00`00FUIJEP03FUH00`00Oomoo`0GOol30006FUH01000FUIJEP0015YF0`000Woo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00<000QJEP<000AJEP03001JEP0000@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUH0000^Ool002aoo`03001JEUYF009JEP03001JEUYF00AJEP8000ioo`<000Uoo`80
00AJEP@000MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP80
00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0008FUH00`00FUH00002000015YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001oogoo02aoo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00@0
05YF000000]oo`D000Yoo`800003FUH005YF009JEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP8000IJEP03001JEUYF009JEPT0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001oogoo02aoo`00;Goo00@005YFFUH0
00IJEP03001JEUYF009JEP<000Qoo`D000aoo`8000AJEP8000EJEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP8000=JEP03001JEUYF00IJEPD0009JEP03001J
EUYF00IJEP03001JEUYF00AJEP08001JEUYF001oo`00FUH002moo`00;Goo00@005YFFUH000IJEP03
001JEUYF00EJEP<000Eoo`D000ioo`03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00000015YF0`0000=JEP00FUH025YF00<0
05YF00001`0015YF00<005YFFUH015YF00@005YF0000009oo`03001JEP0002moo`00;Woo0P001eYF
00<005YFFUH01UYF00@005YF000000Aoo`<0011oo`03001JEUYF009JEP03001JEP00008000QJEP@0
0003FUH005YF00MJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP<000MJEP03001J
EUYF00AJEQ40009oo`800003FUH007oo02moo`00;goo00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`005Goo0P000UYF00@005YFFUIJEP8000QJEP03001JEUYF00@000IJEP03001JEUYF
00UJEP03001JEP00008000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8000=JEP@000AJEP@000EJEP03001JEUYF00IJEP04001JEUYFFUH=0002FUH2000`Ool0
031oo`80009JEP`000MJEP<001Aoo`8000=JEP03001JEUYF00<000AJEP03001JEUYF00EJEPL000MJ
EPH00003FUH0000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00004FUH01000FUH007oo0`0000=JEP00FUH025YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00<Woo0P0000=JEP00FUH015YF00@005YFFUIJ
EPL0009JEP03001JEP000080019oo`07001JEUYFFUH005YF00000Woo00IJEP00000005YF0009FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP80009JEQD000QJEP03001JEUYF00IJEP03001JEUYF009J
EP80009JEP03001JEUYF009JEP80009JEP03001JEP0000Aoo`@000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH2000aOol0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP<0011oo`06001JEUYF001JEP000Woo0eYF10001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00IJEPH0009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00AJEP04001JEP000009Ool40002FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEQ40009JEP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF0P0035YF00<005YF0000
10001UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`003Woo1P0015YF00<005YFFUH00eYF00@0
05YF000003Aoo`00;goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP06001J
EP00001JEP001eYF00<005YFFUH00eYF00H005YF000005YF0003Ool3FUH00`00FUIJEP03FUH30000
0eYF001JEP07FUH00`00FUIJEP03FUH00`00FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUH0000EOol<
000fOol002ioo`80009JEP`000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH015YF00<005YF0000100015YF00@005YF
FUIJEPH000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@000AJEP800003FUH0
05YF00EJEP04001JEUYF001FOol002eoo`800003FUH0000000Qoo`800003FUH0000000D000MJEP03
001JEUYF00EJEP8000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH0
0eYF0`000eYF00<005YF00001`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP80009JEP<000MJEP05001JEUYFFUH0001EOol002eoo`<000aoo`<0
00EJEP@0009JEP03001JEUYF00MJEP<00003FUH005YF00AJEP04001JEUYFFUH20004Ool3FUH01000
FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF009JEP03001oogoo
05=oo`00;7oo0`0047oo0P001EYF00<005YF00000`0025YF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P0017oo0eYF00<005YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
009JEP07001JEUYFFUH005YF0000E7oo000/Ool01000FUH000004Goo0`0000=JEP00FUH0200015YF
00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<007ooOol00goo0eYF0P000UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YF0000009JEP8000=JEP07001JEUYFFUH005YF0000E7oo000/Ool0
1@00FUH005YF00004goo20000eYF0`0000=JEP00FUH01UYF0`000eYF0P001Goo0UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEP00009JEP07001JEUYF
FUH005YF0000E7oo000/Ool00`00FUIJEP02FUH00`00Oomoo`0COol50002FUH01000FUIJEUYF0P00
25YF0P000UYF0P001Woo00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH0
05YF0003FUH20003FUH00`00FUH0001EOol002eoo`03001JEUYF009JEP03001oogoo01=oo`<00003
Ool0000000@0009JEP8000EJEP03001JEUYF008000Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00H005YFFUH005YF001EOol002eoo`03001JEUYF009JEP8001io
o`H000=JEP03001JEUYF009JEP03001oogoo00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000IJEP05001JEP00FUH0001EOol002ioo`04001JEUYF0002FUH00`00Oomoo`0QOol3
0006FUH00`00Oomoo`05Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH70004FUH0
0`00FUH00002001FOol002ioo`04001JEUYF0003FUH00`00Oomoo`0ROol00`00FUIJEP04FUH20006
Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP80009JEP05
001JEP00FUH0001FOol002moo`8000EJEP03001oogoo029oo`8000AJEP03001JEP0000Ioo`8000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEUYF0004FUH00`00FUIJEP04FUH20003FUH2001FOol0031oo`03001J
EUYF00AJEP03001oogoo02=oo`04001JEUYF0003FUH00`00Oomoo`05Ool200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3
0005FUH00`00FUIJEP04FUH20004FUH00`00Oomoo`1DOol0035oo`03001JEUYF00=JEP<002Aoo`<0
00AJEP03001oogoo00Ioo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP03001JEP0000=JEP03001oogoo
05Aoo`00<Woo00<005YFFUH00UYF00<005YFFUH00P0097oo00<005YFFUH00UYF00<007ooOol02Goo
10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0005Eoo`00<goo
0P0000=JEP00FUH015YF0P008goo00<005YFFUH00P003goo1@0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF0000EGoo000eOol20007FUH3000POol00`00FUIJEP02000DOol60002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF3`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00`000UYF00<007ooOol0Dgoo000fOol20006FUH00`00FUIJEP02000OOol200000eYF001oo`0I
OolP0008FUH600000eYF001JEP07FUH00`00FUIJEP04FUH02000FUIJEP00Ool005YF001FOol003Qo
o`8000AJEP03001JEUYF009JEP<001eoo`03001JEP0003Ioo`800003FUH005YF00QJEPX000AJEP03
001JEUYF00AJEP04001JEP000002Ool00`00FUH0001FOol003Yoo`800003FUH005YF00MJEP@001Uo
o`03001JEP0003Qoo`<000MJEP03001JEUYF00AJEQ40009oo`800003FUH007oo05Ioo`00?7oo0`00
25YF00<005YFFUH010005Goo0P00?7oo0P001EYF00<005YFFUH01UYF00@005YFFUIJEPd0009JEP80
05Moo`00?goo0P001UYF00<005YFFUH015YF1P003Goo1000?Woo0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005Qoo`00@Goo0P000eYF00<005YFFUH01eYF00@0
05YFFUIJEPd0009JEP80045oo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
001HOol004=oo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0016Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001IOol004Eoo`<000MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001:Ool60004FUH00`00FUIJEP03FUH0
1000FUH00000Fgoo0018Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001A
Ool<001MOol004aoo`H000AJEP04001JEUYFFUH6002mOol0059oo`P00<=oo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59552 .76527 m .6011 .71059 L .57008 .70554 L p .707 .577 .707 r
F P
0 g
s
.6011 .71059 m .59552 .76527 L .62721 .76733 L p .707 .577 .707 r
F P
0 g
s
.62721 .76733 m .63279 .71265 L .6011 .71059 L p .707 .577 .707 r
F P
0 g
s
.63279 .71265 m .62721 .76733 L .65648 .76621 L p .707 .577 .707 r
F P
0 g
s
.65648 .76621 m .66206 .71153 L .63279 .71265 L p .707 .577 .707 r
F P
0 g
s
.56451 .76022 m .57008 .70554 L .54278 .698 L p .707 .577 .707 r
F P
0 g
s
.57008 .70554 m .56451 .76022 L .59552 .76527 L p .707 .577 .707 r
F P
0 g
s
.66206 .71153 m .65648 .76621 L .68046 .76201 L p .707 .577 .707 r
F P
0 g
s
.68046 .76201 m .68604 .70732 L .66206 .71153 L p .707 .577 .707 r
F P
0 g
s
.53721 .75268 m .54278 .698 L .52187 .6887 L p .707 .577 .707 r
F P
0 g
s
.54278 .698 m .53721 .75268 L .56451 .76022 L p .707 .577 .707 r
F P
0 g
s
.58734 .81804 m .59816 .78389 L .56837 .77292 L p .707 .577 .707 r
F P
0 g
s
.59816 .78389 m .58734 .81804 L .61793 .82544 L p .707 .577 .707 r
F P
0 g
s
.61793 .82544 m .62876 .79129 L .59816 .78389 L p .707 .577 .707 r
F P
0 g
s
.55755 .80707 m .56837 .77292 L .54229 .75946 L p .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56542 .81049 L .56176 .80855 L p .707 .577 .707 r
F P
0 g
s
.56837 .77292 m .55755 .80707 L .56174 .80861 L p .707 .577 .707 r
F P
0 g
s
.57115 .77952 m .56837 .77292 L .56174 .80861 L .707 .577 .707 r
F
.54229 .75946 m .53147 .79361 L .55755 .80707 L p F P
0 g
s
.56176 .80855 m .53943 .79673 L p .55701 .82324 L .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56176 .80855 L .55701 .82324 L .707 .577 .707 r
F
.56174 .80861 m .58734 .81804 L p .57115 .77952 L F P
0 g
s
.62876 .79129 m .61793 .82544 L .64633 .82856 L p .707 .577 .707 r
F P
0 g
s
.64633 .82856 m .65715 .79441 L .62876 .79129 L p .707 .577 .707 r
F P
0 g
s
.58952 .83875 m .59511 .82176 L .56542 .81049 L p .707 .577 .707 r
F P
0 g
s
.59511 .82176 m .58952 .83875 L .62002 .84643 L p .707 .577 .707 r
F P
0 g
s
.62002 .84643 m .62562 .82943 L .59511 .82176 L p .707 .577 .707 r
F P
0 g
s
.56542 .81049 m .55982 .82748 L .58952 .83875 L p .707 .577 .707 r
F P
0 g
s
.68604 .70732 m .68046 .76201 L .6968 .75514 L p .707 .577 .707 r
F P
0 g
s
.6968 .75514 m .70238 .70046 L .68604 .70732 L p .707 .577 .707 r
F P
0 g
s
.52187 .6887 m .5163 .74339 L .52659 .74796 L p .707 .577 .707 r
F P
0 g
s
.52659 .74796 m .53721 .75268 L p .53305 .73533 L .707 .577 .707 r
F P
0 g
s
.53305 .73533 m .52187 .6887 L .52659 .74796 L .707 .577 .707 r
F
.5163 .74339 m .52187 .6887 L .50939 .67857 L p F P
0 g
s
.50939 .67857 m .50382 .73325 L .51101 .73909 L p .707 .577 .707 r
F P
0 g
s
.51101 .73909 m .5163 .74339 L p .5149 .7303 L .707 .577 .707 r
F P
0 g
s
.5149 .7303 m .50939 .67857 L .51101 .73909 L .707 .577 .707 r
F
.51087 .73044 m .50861 .71773 L p .50029 .76331 L F P
0 g
s
.50005 .76459 m .50089 .76194 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.50089 .76194 m .51087 .73044 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51087 .73044 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51166 .77897 m .51315 .77426 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51315 .77426 m .52248 .74482 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.53147 .79361 m .54229 .75946 L .52248 .74482 L p .707 .577 .707 r
F P
0 g
s
.62562 .82943 m .62002 .84643 L .64835 .84976 L p .707 .577 .707 r
F P
0 g
s
.64835 .84976 m .65394 .83276 L .62562 .82943 L p .707 .577 .707 r
F P
0 g
s
.65715 .79441 m .64633 .82856 L .66975 .82708 L p .707 .577 .707 r
F P
0 g
s
.66975 .82708 m .68057 .79292 L .65715 .79441 L p .707 .577 .707 r
F P
0 g
s
.53943 .79673 m .53384 .81372 L .55982 .82748 L p .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51166 .77897 L .53147 .79361 L p .707 .577 .707 r
F P
0 g
s
.53384 .81372 m .53943 .79673 L .51971 .78182 L p .707 .577 .707 r
F P
0 g
s
.65394 .83276 m .64835 .84976 L .67172 .84841 L p .707 .577 .707 r
F P
0 g
s
.67172 .84841 m .67732 .83142 L .65394 .83276 L p .707 .577 .707 r
F P
0 g
s
.51971 .78182 m .51412 .79882 L .53384 .81372 L p .707 .577 .707 r
F P
0 g
s
.68057 .79292 m .66975 .82708 L .6859 .82114 L p .707 .577 .707 r
F P
0 g
s
.6859 .82114 m .69672 .78699 L .68057 .79292 L p .707 .577 .707 r
F P
0 g
s
.70238 .70046 m .6968 .75514 L .70391 .74627 L p .707 .577 .707 r
F P
0 g
s
.70391 .74627 m .70949 .69159 L .70238 .70046 L p .707 .577 .707 r
F P
0 g
s
.51087 .73044 m .50005 .76459 L .51166 .77897 L p .707 .577 .707 r
F P
0 g
s
.51412 .79882 m .51971 .78182 L .50817 .76723 L p .707 .577 .707 r
F P
0 g
s
.50382 .73325 m .50939 .67857 L .50657 .66858 L p .707 .577 .707 r
F P
0 g
s
.67732 .83142 m .67172 .84841 L .68786 .84253 L p .707 .577 .707 r
F P
0 g
s
.68786 .84253 m .69345 .82554 L .67732 .83142 L p .707 .577 .707 r
F P
0 g
s
.50817 .76723 m .50258 .78422 L .51412 .79882 L p .707 .577 .707 r
F P
0 g
s
.50269 .72925 m .50382 .73325 L p .50432 .7215 L .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .49779 .75188 L .50005 .76459 L p .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .51591 .70793 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49779 .75188 m .49821 .75054 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49821 .75054 m .50861 .71773 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.50657 .66858 m .50099 .72326 L .50269 .72925 L p .707 .577 .707 r
F P
0 g
s
.50432 .7215 m .50657 .66858 L .50269 .72925 L .707 .577 .707 r
F
.69672 .78699 m .6859 .82114 L .6932 .81134 L p F P
0 g
s
.6932 .81134 m .70402 .77719 L .69672 .78699 L p .707 .577 .707 r
F P
0 g
s
.70949 .69159 m .70391 .74627 L .70109 .73628 L p .707 .577 .707 r
F P
0 g
s
.70109 .73628 m .70666 .6816 L .70949 .69159 L p .707 .577 .707 r
F P
0 g
s
.50258 .78422 m .50817 .76723 L .50595 .75438 L p .707 .577 .707 r
F P
0 g
s
.50595 .75438 m .50036 .77137 L .50258 .78422 L p .707 .577 .707 r
F P
0 g
s
.50036 .77137 m .50595 .75438 L .51327 .74453 L p .707 .577 .707 r
F P
0 g
s
.51591 .70793 m .50537 .74119 L p .49779 .75188 L .707 .577 .707 r
F P
0 g
s
.50537 .74119 m .50509 .74208 L .50494 .74228 L p .707 .577 .707 r
F P
0 g
s
.50494 .74228 m .49779 .75188 L p .50537 .74119 L .707 .577 .707 r
F P
0 g
s
.53002 .65284 m .52644 .68793 L p .5081 .71439 L .707 .577 .707 r
F P
0 g
s
.50509 .74208 m .51591 .70793 L .53206 .702 L p .707 .577 .707 r
F P
0 g
s
.52644 .68793 m .52445 .70753 L .51754 .71043 L p .707 .577 .707 r
F P
0 g
s
.51754 .71043 m .5081 .71439 L p .52644 .68793 L .707 .577 .707 r
F P
0 g
s
.51327 .74453 m .50768 .76153 L .50036 .77137 L p .707 .577 .707 r
F P
0 g
s
.503 .82182 m .4888 .31862 L .44481 .3172 L p .707 .577 .707 r
F P
0 g
s
.50099 .72326 m .50657 .66858 L .51368 .65971 L p .707 .577 .707 r
F P
0 g
s
.51368 .65971 m .5081 .71439 L .50099 .72326 L p .707 .577 .707 r
F P
0 g
s
.5081 .71439 m .51368 .65971 L .53002 .65284 L p .707 .577 .707 r
F P
0 g
s
.50768 .76153 m .51327 .74453 L .52941 .73865 L p .707 .577 .707 r
F P
0 g
s
.53206 .702 m .52166 .73481 L p .50509 .74208 L .707 .577 .707 r
F P
0 g
s
.52166 .73481 m .52124 .73615 L .5208 .73631 L p .707 .577 .707 r
F P
0 g
s
.5208 .73631 m .50509 .74208 L p .52166 .73481 L .707 .577 .707 r
F P
0 g
s
.554 .64864 m .55028 .68514 L p .52445 .70753 L .707 .577 .707 r
F P
0 g
s
.52124 .73615 m .53206 .702 L .55548 .70052 L p .707 .577 .707 r
F P
0 g
s
.55028 .68514 m .54843 .70332 L .53884 .705 L p .707 .577 .707 r
F P
0 g
s
.53884 .705 m .52445 .70753 L p .55028 .68514 L .707 .577 .707 r
F P
0 g
s
.52445 .70753 m .53002 .65284 L .554 .64864 L p .707 .577 .707 r
F P
0 g
s
.52941 .73865 m .52381 .75564 L .50768 .76153 L p .707 .577 .707 r
F P
0 g
s
.52381 .75564 m .52941 .73865 L .55278 .7373 L p .707 .577 .707 r
F P
0 g
s
.55548 .70052 m .5455 .73201 L p .52124 .73615 L .707 .577 .707 r
F P
0 g
s
.5455 .73201 m .54466 .73467 L .54366 .73473 L p .707 .577 .707 r
F P
0 g
s
.54366 .73473 m .52124 .73615 L p .5455 .73201 L .707 .577 .707 r
F P
0 g
s
.58327 .64752 m .57985 .68111 L p .54843 .70332 L .707 .577 .707 r
F P
0 g
s
.54466 .73467 m .55548 .70052 L .58388 .70363 L p .707 .577 .707 r
F P
0 g
s
.57985 .68111 m .5777 .7022 L .5653 .70267 L p .707 .577 .707 r
F P
0 g
s
.5653 .70267 m .54843 .70332 L p .57985 .68111 L .707 .577 .707 r
F P
0 g
s
.55278 .7373 m .54719 .7543 L .52381 .75564 L p .707 .577 .707 r
F P
0 g
s
.4888 .31862 m .503 .82182 L .54793 .81958 L p .707 .577 .707 r
F P
0 g
s
.58388 .70363 m .57739 .72412 L p .54466 .73467 L .707 .577 .707 r
F P
0 g
s
.57739 .72412 m .57305 .73778 L .56677 .7371 L p .707 .577 .707 r
F P
0 g
s
.56677 .7371 m .54466 .73467 L p .57739 .72412 L .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .4888 .31862 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54793 .81958 m .54631 .76213 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54631 .76213 m .53373 .31639 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.69345 .82554 m .68786 .84253 L .69518 .83268 L p .707 .577 .707 r
F P
0 g
s
.69518 .83268 m .70077 .81569 L .69345 .82554 L p .707 .577 .707 r
F P
0 g
s
.54843 .70332 m .554 .64864 L .58327 .64752 L p .707 .577 .707 r
F P
0 g
s
.54719 .7543 m .55278 .7373 L .58111 .74063 L p .707 .577 .707 r
F P
0 g
s
.57305 .73778 m .58388 .70363 L .61447 .71104 L p .707 .577 .707 r
F P
0 g
s
.58111 .74063 m .57551 .75763 L .54719 .7543 L p .707 .577 .707 r
F P
0 g
s
.61447 .71104 m .60365 .74519 L .57305 .73778 L p .707 .577 .707 r
F P
0 g
s
.57551 .75763 m .58111 .74063 L .61161 .74831 L p .707 .577 .707 r
F P
0 g
s
.61161 .74831 m .60602 .7653 L .57551 .75763 L p .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .54793 .81958 L .5894 .81391 L p .707 .577 .707 r
F P
0 g
s
.5777 .7022 m .58327 .64752 L .61496 .64958 L p .707 .577 .707 r
F P
0 g
s
.61496 .64958 m .60939 .70426 L .5777 .7022 L p .707 .577 .707 r
F P
0 g
s
.5894 .81391 m .5752 .31071 L .53373 .31639 L p .707 .577 .707 r
F P
0 g
s
.45901 .8204 m .44481 .3172 L .40606 .31226 L p .707 .577 .707 r
F P
0 g
s
.44481 .3172 m .45901 .8204 L .503 .82182 L p .707 .577 .707 r
F P
0 g
s
.64598 .65463 m .6404 .70931 L .60939 .70426 L p .707 .577 .707 r
F P
0 g
s
.60939 .70426 m .61496 .64958 L .64598 .65463 L p .707 .577 .707 r
F P
0 g
s
.64426 .72201 m .63344 .75616 L .60365 .74519 L p .707 .577 .707 r
F P
0 g
s
.60365 .74519 m .61447 .71104 L .64426 .72201 L p .707 .577 .707 r
F P
0 g
s
.67034 .73547 m .65952 .76962 L .63711 .75805 L p .707 .577 .707 r
F P
0 g
s
.64131 .75958 m .63572 .77657 L .63163 .77502 L p .707 .577 .707 r
F P
0 g
s
.63163 .77502 m .60602 .7653 L p .63636 .76038 L .707 .577 .707 r
F P
0 g
s
.63636 .76038 m .64131 .75958 L .63163 .77502 L .707 .577 .707 r
F
.63867 .75323 m .67034 .73547 L .63711 .75805 L F
.60602 .7653 m .61161 .74831 L .64131 .75958 L p F P
0 g
s
.63711 .75805 m .63344 .75616 L p .63867 .75323 L .707 .577 .707 r
F P
0 g
s
.5752 .31071 m .5894 .81391 L .62335 .80535 L p .707 .577 .707 r
F P
0 g
s
.62335 .80535 m .60915 .30216 L .5752 .31071 L p .707 .577 .707 r
F P
0 g
s
.70402 .77719 m .6932 .81134 L .69094 .79863 L p .707 .577 .707 r
F P
0 g
s
.69094 .79863 m .70176 .76448 L .70402 .77719 L p .707 .577 .707 r
F P
0 g
s
.70666 .6816 m .70109 .73628 L .68861 .72615 L p .707 .577 .707 r
F P
0 g
s
.68861 .72615 m .69419 .67146 L .70666 .6816 L p .707 .577 .707 r
F P
0 g
s
.25251 .70281 m .25809 .64812 L .22707 .64307 L p .707 .577 .707 r
F P
0 g
s
.25809 .64812 m .25251 .70281 L .2842 .70487 L p .707 .577 .707 r
F P
0 g
s
.2842 .70487 m .28978 .65019 L .25809 .64812 L p .707 .577 .707 r
F P
0 g
s
.28978 .65019 m .2842 .70487 L .31347 .70374 L p .707 .577 .707 r
F P
0 g
s
.31347 .70374 m .31905 .64906 L .28978 .65019 L p .707 .577 .707 r
F P
0 g
s
.2215 .69776 m .22707 .64307 L .19978 .63553 L p .707 .577 .707 r
F P
0 g
s
.22707 .64307 m .2215 .69776 L .25251 .70281 L p .707 .577 .707 r
F P
0 g
s
.42026 .81546 m .40606 .31226 L .37635 .30429 L p .707 .577 .707 r
F P
0 g
s
.40606 .31226 m .42026 .81546 L .45901 .8204 L p .707 .577 .707 r
F P
0 g
s
.70077 .81569 m .69518 .83268 L .69296 .81983 L p .707 .577 .707 r
F P
0 g
s
.69296 .81983 m .69855 .80284 L .70077 .81569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31905 .64906 m .31347 .70374 L .33745 .69954 L p .707 .577 .707 r
F P
0 g
s
.33745 .69954 m .34303 .64486 L .31905 .64906 L p .707 .577 .707 r
F P
0 g
s
.1942 .69022 m .19978 .63553 L .17886 .62624 L p .707 .577 .707 r
F P
0 g
s
.19978 .63553 m .1942 .69022 L .2215 .69776 L p .707 .577 .707 r
F P
0 g
s
.63344 .75616 m .64426 .72201 L .67034 .73547 L p .707 .577 .707 r
F P
0 g
s
.69015 .75011 m .67933 .78426 L .65952 .76962 L p .707 .577 .707 r
F P
0 g
s
.66729 .77334 m .6617 .79034 L .63572 .77657 L p .707 .577 .707 r
F P
0 g
s
.65952 .76962 m .67034 .73547 L .69015 .75011 L p .707 .577 .707 r
F P
0 g
s
.63572 .77657 m .64131 .75958 L .66729 .77334 L p .707 .577 .707 r
F P
0 g
s
.60915 .30216 m .62335 .80535 L .64645 .79475 L p .707 .577 .707 r
F P
0 g
s
.67327 .66217 m .6677 .71685 L .6404 .70931 L p .707 .577 .707 r
F P
0 g
s
.6404 .70931 m .64598 .65463 L .67327 .66217 L p .707 .577 .707 r
F P
0 g
s
.64645 .79475 m .63225 .29155 L .60915 .30216 L p .707 .577 .707 r
F P
0 g
s
.70176 .76448 m .69094 .79863 L .67933 .78426 L p .707 .577 .707 r
F P
0 g
s
.67933 .78426 m .69015 .75011 L .70176 .76448 L p .707 .577 .707 r
F P
0 g
s
.69419 .67146 m .68861 .72615 L .6677 .71685 L p .707 .577 .707 r
F P
0 g
s
.6677 .71685 m .67327 .66217 L .69419 .67146 L p .707 .577 .707 r
F P
0 g
s
.24433 .77967 m .25516 .74552 L .22536 .73455 L p .707 .577 .707 r
F P
0 g
s
.25516 .74552 m .24433 .77967 L .27492 .78707 L p .707 .577 .707 r
F P
0 g
s
.27492 .78707 m .28575 .75292 L .25516 .74552 L p .707 .577 .707 r
F P
0 g
s
.21454 .7687 m .22536 .73455 L .19928 .72109 L p .707 .577 .707 r
F P
0 g
s
.22536 .73455 m .21454 .7687 L .24433 .77967 L p .707 .577 .707 r
F P
0 g
s
.28575 .75292 m .27492 .78707 L .30332 .79019 L p .707 .577 .707 r
F P
0 g
s
.30332 .79019 m .31414 .75604 L .28575 .75292 L p .707 .577 .707 r
F P
0 g
s
.69855 .80284 m .69296 .81983 L .68142 .80524 L p .707 .577 .707 r
F P
0 g
s
.68142 .80524 m .68702 .78825 L .69855 .80284 L p .707 .577 .707 r
F P
0 g
s
.34303 .64486 m .33745 .69954 L .3538 .69267 L p .707 .577 .707 r
F P
0 g
s
.3538 .69267 m .35937 .63799 L .34303 .64486 L p .707 .577 .707 r
F P
0 g
s
.17886 .62624 m .17329 .68092 L .1942 .69022 L p .707 .577 .707 r
F P
0 g
s
.39055 .80749 m .37635 .30429 L .35859 .29406 L p .707 .577 .707 r
F P
0 g
s
.37635 .30429 m .39055 .80749 L .42026 .81546 L p .707 .577 .707 r
F P
0 g
s
.17329 .68092 m .17886 .62624 L .16638 .6161 L p .707 .577 .707 r
F P
0 g
s
.18846 .75524 m .19928 .72109 L .17947 .70645 L p .707 .577 .707 r
F P
0 g
s
.19928 .72109 m .18846 .75524 L .21454 .7687 L p .707 .577 .707 r
F P
0 g
s
.31414 .75604 m .30332 .79019 L .32674 .78871 L p .707 .577 .707 r
F P
0 g
s
.32674 .78871 m .33756 .75455 L .31414 .75604 L p .707 .577 .707 r
F P
0 g
s
.24651 .84452 m .2521 .82753 L .22241 .81626 L p .707 .577 .707 r
F P
0 g
s
.2521 .82753 m .24651 .84452 L .27701 .8522 L p .707 .577 .707 r
F P
0 g
s
.27701 .8522 m .28261 .8352 L .2521 .82753 L p .707 .577 .707 r
F P
0 g
s
.21681 .83325 m .22241 .81626 L .19642 .8025 L p .707 .577 .707 r
F P
0 g
s
.22241 .81626 m .21681 .83325 L .24651 .84452 L p .707 .577 .707 r
F P
0 g
s
.28261 .8352 m .27701 .8522 L .30534 .85553 L p .707 .577 .707 r
F P
0 g
s
.30534 .85553 m .31093 .83853 L .28261 .8352 L p .707 .577 .707 r
F P
0 g
s
.17947 .70645 m .16865 .7406 L .18846 .75524 L p .707 .577 .707 r
F P
0 g
s
.63225 .29155 m .64645 .79475 L .65645 .78314 L p .707 .577 .707 r
F P
0 g
s
.65645 .78314 m .64225 .27994 L .63225 .29155 L p .707 .577 .707 r
F P
0 g
s
.16638 .6161 m .16081 .67078 L .17329 .68092 L p .707 .577 .707 r
F P
0 g
s
.68702 .78825 m .68142 .80524 L .6617 .79034 L p .707 .577 .707 r
F P
0 g
s
.6617 .79034 m .66729 .77334 L .68702 .78825 L p .707 .577 .707 r
F P
0 g
s
.19642 .8025 m .19083 .81949 L .21681 .83325 L p .707 .577 .707 r
F P
0 g
s
.35937 .63799 m .3538 .69267 L .3609 .68381 L p .707 .577 .707 r
F P
0 g
s
.3609 .68381 m .36648 .62913 L .35937 .63799 L p .707 .577 .707 r
F P
0 g
s
.16865 .7406 m .17947 .70645 L .16786 .69207 L p .707 .577 .707 r
F P
0 g
s
.19083 .81949 m .19642 .8025 L .1767 .78759 L p .707 .577 .707 r
F P
0 g
s
.33756 .75455 m .32674 .78871 L .34289 .78277 L p .707 .577 .707 r
F P
0 g
s
.34289 .78277 m .35371 .74862 L .33756 .75455 L p .707 .577 .707 r
F P
0 g
s
.16081 .67078 m .16638 .6161 L .16356 .60611 L p .707 .577 .707 r
F P
0 g
s
.31093 .83853 m .30534 .85553 L .32872 .85418 L p .707 .577 .707 r
F P
0 g
s
.32872 .85418 m .33431 .83719 L .31093 .83853 L p .707 .577 .707 r
F P
0 g
s
.1767 .78759 m .17111 .80458 L .19083 .81949 L p .707 .577 .707 r
F P
0 g
s
.16786 .69207 m .15704 .72622 L .16865 .7406 L p .707 .577 .707 r
F P
0 g
s
.37279 .79726 m .35859 .29406 L .35451 .28258 L p .707 .577 .707 r
F P
0 g
s
.35859 .29406 m .37279 .79726 L .39055 .80749 L p .707 .577 .707 r
F P
0 g
s
.16356 .60611 m .15799 .66079 L .16081 .67078 L p .707 .577 .707 r
F P
0 g
s
.17111 .80458 m .1767 .78759 L .16516 .773 L p .707 .577 .707 r
F P
0 g
s
.15704 .72622 m .16786 .69207 L .1656 .67936 L p .707 .577 .707 r
F P
0 g
s
.36648 .62913 m .3609 .68381 L .35808 .67382 L p .707 .577 .707 r
F P
0 g
s
.35808 .67382 m .36366 .61914 L .36648 .62913 L p .707 .577 .707 r
F P
0 g
s
.33431 .83719 m .32872 .85418 L .34485 .8483 L p .707 .577 .707 r
F P
0 g
s
.34485 .8483 m .35044 .8313 L .33431 .83719 L p .707 .577 .707 r
F P
0 g
s
.16516 .773 m .15957 .78999 L .17111 .80458 L p .707 .577 .707 r
F P
0 g
s
.35371 .74862 m .34289 .78277 L .35019 .77297 L p .707 .577 .707 r
F P
0 g
s
.35019 .77297 m .36101 .73882 L .35371 .74862 L p .707 .577 .707 r
F P
0 g
s
.15799 .66079 m .16356 .60611 L .17067 .59725 L p .707 .577 .707 r
F P
0 g
s
.64225 .27994 m .65645 .78314 L .65428 .77704 L p .707 .577 .707 r
F P
0 g
s
.65428 .77704 m .65255 .77216 L p .65209 .75001 L .707 .577 .707 r
F P
0 g
s
.65209 .75001 m .64225 .27994 L .65428 .77704 L .707 .577 .707 r
F
.65228 .76689 m .64225 .27994 L .65255 .77216 L F
.65237 .77166 m .63817 .26847 L .64225 .27994 L p F P
0 g
s
.63817 .26847 m .65237 .77166 L .63461 .76144 L p .707 .577 .707 r
F P
0 g
s
.65908 .59667 m .6535 .65135 L .6638 .65592 L p .707 .577 .707 r
F P
0 g
s
.6638 .65592 m .67441 .66064 L p .67025 .64329 L .707 .577 .707 r
F P
0 g
s
.67025 .64329 m .65908 .59667 L .6638 .65592 L .707 .577 .707 r
F
.6466 .58653 m .64411 .61091 L p .6535 .65135 L F P
0 g
s
.64591 .64518 m .6535 .65135 L p .64411 .61091 L .707 .577 .707 r
F P
0 g
s
.6535 .65135 m .65908 .59667 L .6466 .58653 L p .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64808 .63841 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.64886 .68693 m .65035 .68222 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65035 .68222 m .65968 .65278 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64886 .68693 L .66867 .70157 L p .707 .577 .707 r
F P
0 g
s
.64808 .63841 m .63725 .67256 L .64886 .68693 L p .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .65691 .68978 L .64608 .67608 L p .707 .577 .707 r
F P
0 g
s
.64608 .67608 m .64538 .67519 L p .64649 .68109 L .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .64608 .67608 L .64649 .68109 L .707 .577 .707 r
F
.64411 .61091 m .64102 .64121 L .64591 .64518 L p F P
0 g
s
.65255 .77216 m .65237 .77166 L p .65228 .76689 L .707 .577 .707 r
F P
0 g
s
.1656 .67936 m .15478 .71351 L .15704 .72622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15957 .78999 m .16516 .773 L .16295 .76015 L p .707 .577 .707 r
F P
0 g
s
.17067 .59725 m .16509 .65193 L .15799 .66079 L p .707 .577 .707 r
F P
0 g
s
.15478 .71351 m .1656 .67936 L .1729 .66956 L p .707 .577 .707 r
F P
0 g
s
.35044 .8313 m .34485 .8483 L .35217 .83845 L p .707 .577 .707 r
F P
0 g
s
.35217 .83845 m .35776 .82146 L .35044 .8313 L p .707 .577 .707 r
F P
0 g
s
.16295 .76015 m .15735 .77714 L .15957 .78999 L p .707 .577 .707 r
F P
0 g
s
.35451 .28258 m .36871 .78578 L .37279 .79726 L p .707 .577 .707 r
F P
0 g
s
.36871 .78578 m .35451 .28258 L .36451 .27097 L p .707 .577 .707 r
F P
0 g
s
.36366 .61914 m .35808 .67382 L .3456 .66368 L p .707 .577 .707 r
F P
0 g
s
.3456 .66368 m .35118 .609 L .36366 .61914 L p .707 .577 .707 r
F P
0 g
s
.36101 .73882 m .35019 .77297 L .34793 .76026 L p .707 .577 .707 r
F P
0 g
s
.34793 .76026 m .35875 .72611 L .36101 .73882 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16509 .65193 m .17067 .59725 L .18701 .59038 L p .707 .577 .707 r
F P
0 g
s
.1729 .66956 m .16208 .70371 L .15478 .71351 L p .707 .577 .707 r
F P
0 g
s
.15735 .77714 m .16295 .76015 L .17026 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63461 .76144 m .62041 .25824 L .63817 .26847 L p .707 .577 .707 r
F P
0 g
s
.18701 .59038 m .18144 .64506 L .16509 .65193 L p .707 .577 .707 r
F P
0 g
s
.16208 .70371 m .1729 .66956 L .18905 .66363 L p .707 .577 .707 r
F P
0 g
s
.35776 .82146 m .35217 .83845 L .34995 .8256 L p .707 .577 .707 r
F P
0 g
s
.34995 .8256 m .35554 .80861 L .35776 .82146 L p .707 .577 .707 r
F P
0 g
s
.17026 .7503 m .16467 .76729 L .15735 .77714 L p .707 .577 .707 r
F P
0 g
s
.35118 .609 m .3456 .66368 L .32469 .65439 L p .707 .577 .707 r
F P
0 g
s
.32469 .65439 m .33027 .59971 L .35118 .609 L p .707 .577 .707 r
F P
0 g
s
.35875 .72611 m .34793 .76026 L .33632 .74589 L p .707 .577 .707 r
F P
0 g
s
.33632 .74589 m .34715 .71173 L .35875 .72611 L p .707 .577 .707 r
F P
0 g
s
.18144 .64506 m .18701 .59038 L .21099 .58618 L p .707 .577 .707 r
F P
0 g
s
.18905 .66363 m .17823 .69778 L .16208 .70371 L p .707 .577 .707 r
F P
0 g
s
.37871 .77417 m .36451 .27097 L .38762 .26037 L p .707 .577 .707 r
F P
0 g
s
.36451 .27097 m .37871 .77417 L .36871 .78578 L p .707 .577 .707 r
F P
0 g
s
.16467 .76729 m .17026 .7503 L .1864 .74442 L p .707 .577 .707 r
F P
0 g
s
.33027 .59971 m .32469 .65439 L .29739 .64685 L p .707 .577 .707 r
F P
0 g
s
.29739 .64685 m .30297 .59216 L .33027 .59971 L p .707 .577 .707 r
F P
0 g
s
.21099 .58618 m .20542 .64086 L .18144 .64506 L p .707 .577 .707 r
F P
0 g
s
.17823 .69778 m .18905 .66363 L .21247 .66215 L p .707 .577 .707 r
F P
0 g
s
.20542 .64086 m .21099 .58618 L .24026 .58505 L p .707 .577 .707 r
F P
0 g
s
.35554 .80861 m .34995 .8256 L .33841 .81101 L p .707 .577 .707 r
F P
0 g
s
.33841 .81101 m .34401 .79402 L .35554 .80861 L p .707 .577 .707 r
F P
0 g
s
.1864 .74442 m .1808 .76141 L .16467 .76729 L p .707 .577 .707 r
F P
0 g
s
.34715 .71173 m .33632 .74589 L .31651 .73125 L p .707 .577 .707 r
F P
0 g
s
.31651 .73125 m .32733 .6971 L .34715 .71173 L p .707 .577 .707 r
F P
0 g
s
.62041 .25824 m .63461 .76144 L .6049 .75346 L p .707 .577 .707 r
F P
0 g
s
.6049 .75346 m .5907 .25027 L .62041 .25824 L p .707 .577 .707 r
F P
0 g
s
.30297 .59216 m .29739 .64685 L .26638 .6418 L p .707 .577 .707 r
F P
0 g
s
.26638 .6418 m .27195 .58712 L .30297 .59216 L p .707 .577 .707 r
F P
0 g
s
.23469 .63973 m .24026 .58505 L .27195 .58712 L p .707 .577 .707 r
F P
0 g
s
.24026 .58505 m .23469 .63973 L .20542 .64086 L p .707 .577 .707 r
F P
0 g
s
.21247 .66215 m .20165 .6963 L .17823 .69778 L p .707 .577 .707 r
F P
0 g
s
.27195 .58712 m .26638 .6418 L .23469 .63973 L p .707 .577 .707 r
F P
0 g
s
.20165 .6963 m .21247 .66215 L .24087 .66526 L p .707 .577 .707 r
F P
0 g
s
.1808 .76141 m .1864 .74442 L .20977 .74307 L p .707 .577 .707 r
F P
0 g
s
.32733 .6971 m .31651 .73125 L .29043 .71779 L p .707 .577 .707 r
F P
0 g
s
.29043 .71779 m .30125 .68364 L .32733 .6971 L p .707 .577 .707 r
F P
0 g
s
.38762 .26037 m .40182 .76357 L .37871 .77417 L p .707 .577 .707 r
F P
0 g
s
.40182 .76357 m .38762 .26037 L .42157 .25182 L p .707 .577 .707 r
F P
0 g
s
.73272 .67323 m .7383 .61855 L .70729 .6135 L p .707 .577 .707 r
F P
0 g
s
.7383 .61855 m .73272 .67323 L .76442 .6753 L p .707 .577 .707 r
F P
0 g
s
.76442 .6753 m .76999 .62061 L .7383 .61855 L p .707 .577 .707 r
F P
0 g
s
.34401 .79402 m .33841 .81101 L .31869 .7961 L p .707 .577 .707 r
F P
0 g
s
.31869 .7961 m .32428 .77911 L .34401 .79402 L p .707 .577 .707 r
F P
0 g
s
.20977 .74307 m .20418 .76007 L .1808 .76141 L p .707 .577 .707 r
F P
0 g
s
.76999 .62061 m .76442 .6753 L .79368 .67417 L p .707 .577 .707 r
F P
0 g
s
.79368 .67417 m .79926 .61949 L .76999 .62061 L p .707 .577 .707 r
F P
0 g
s
.70171 .66818 m .70729 .6135 L .67999 .60596 L p .707 .577 .707 r
F P
0 g
s
.70729 .6135 m .70171 .66818 L .73272 .67323 L p .707 .577 .707 r
F P
0 g
s
.24087 .66526 m .23004 .69941 L .20165 .6963 L p .707 .577 .707 r
F P
0 g
s
.23004 .69941 m .24087 .66526 L .27146 .67267 L p .707 .577 .707 r
F P
0 g
s
.30125 .68364 m .29043 .71779 L .26064 .70682 L p .707 .577 .707 r
F P
0 g
s
.26064 .70682 m .27146 .67267 L .30125 .68364 L p .707 .577 .707 r
F P
0 g
s
.27146 .67267 m .26064 .70682 L .23004 .69941 L p .707 .577 .707 r
F P
0 g
s
.5907 .25027 m .6049 .75346 L .56615 .74852 L p .707 .577 .707 r
F P
0 g
s
.56615 .74852 m .55195 .24533 L .5907 .25027 L p .707 .577 .707 r
F P
0 g
s
.79926 .61949 m .79368 .67417 L .81766 .66997 L p .707 .577 .707 r
F P
0 g
s
.81766 .66997 m .82324 .61529 L .79926 .61949 L p .707 .577 .707 r
F P
0 g
s
.20418 .76007 m .20977 .74307 L .2381 .7464 L p .707 .577 .707 r
F P
0 g
s
.67441 .66064 m .67999 .60596 L .65908 .59667 L p .707 .577 .707 r
F P
0 g
s
.67999 .60596 m .67441 .66064 L .70171 .66818 L p .707 .577 .707 r
F P
0 g
s
.32428 .77911 m .31869 .7961 L .29271 .78234 L p .707 .577 .707 r
F P
0 g
s
.29271 .78234 m .2983 .76535 L .32428 .77911 L p .707 .577 .707 r
F P
0 g
s
.72455 .726 m .73537 .69185 L .70557 .68088 L p .707 .577 .707 r
F P
0 g
s
.73537 .69185 m .72455 .726 L .75514 .7334 L p .707 .577 .707 r
F P
0 g
s
.75514 .7334 m .76596 .69925 L .73537 .69185 L p .707 .577 .707 r
F P
0 g
s
.2381 .7464 m .2325 .7634 L .20418 .76007 L p .707 .577 .707 r
F P
0 g
s
.69475 .71503 m .70557 .68088 L .67949 .66742 L p .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .70262 .71845 L .69896 .71651 L p .707 .577 .707 r
F P
0 g
s
.70557 .68088 m .69475 .71503 L .69894 .71657 L p .707 .577 .707 r
F P
0 g
s
.70835 .68748 m .70557 .68088 L .69894 .71657 L .707 .577 .707 r
F
.67949 .66742 m .66867 .70157 L .69475 .71503 L p F P
0 g
s
.69896 .71651 m .67664 .70469 L p .69421 .7312 L .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .69896 .71651 L .69421 .7312 L .707 .577 .707 r
F
.69894 .71657 m .72455 .726 L p .70835 .68748 L F P
0 g
s
.43577 .75501 m .42157 .25182 L .46303 .24614 L p .707 .577 .707 r
F P
0 g
s
.42157 .25182 m .43577 .75501 L .40182 .76357 L p .707 .577 .707 r
F P
0 g
s
.76596 .69925 m .75514 .7334 L .78353 .73652 L p .707 .577 .707 r
F P
0 g
s
.78353 .73652 m .79436 .70237 L .76596 .69925 L p .707 .577 .707 r
F P
0 g
s
.2325 .7634 m .2381 .7464 L .2686 .75408 L p .707 .577 .707 r
F P
0 g
s
.2983 .76535 m .29271 .78234 L .26301 .77107 L p .707 .577 .707 r
F P
0 g
s
.26301 .77107 m .2686 .75408 L .2983 .76535 L p .707 .577 .707 r
F P
0 g
s
.72672 .74672 m .73232 .72972 L .70262 .71845 L p .707 .577 .707 r
F P
0 g
s
.73232 .72972 m .72672 .74672 L .75723 .75439 L p .707 .577 .707 r
F P
0 g
s
.75723 .75439 m .76282 .7374 L .73232 .72972 L p .707 .577 .707 r
F P
0 g
s
.55195 .24533 m .56615 .74852 L .52216 .7471 L p .707 .577 .707 r
F P
0 g
s
.52216 .7471 m .50796 .24391 L .55195 .24533 L p .707 .577 .707 r
F P
0 g
s
.2686 .75408 m .26301 .77107 L .2325 .7634 L p .707 .577 .707 r
F P
0 g
s
.70262 .71845 m .69703 .73545 L .72672 .74672 L p .707 .577 .707 r
F P
0 g
s
.82324 .61529 m .81766 .66997 L .83401 .6631 L p .707 .577 .707 r
F P
0 g
s
.83401 .6631 m .83958 .60842 L .82324 .61529 L p .707 .577 .707 r
F P
0 g
s
.66867 .70157 m .67949 .66742 L .65968 .65278 L p .707 .577 .707 r
F P
0 g
s
.76282 .7374 m .75723 .75439 L .78555 .75772 L p .707 .577 .707 r
F P
0 g
s
.78555 .75772 m .79115 .74072 L .76282 .7374 L p .707 .577 .707 r
F P
0 g
s
.79436 .70237 m .78353 .73652 L .80695 .73504 L p .707 .577 .707 r
F P
0 g
s
.80695 .73504 m .81777 .70089 L .79436 .70237 L p .707 .577 .707 r
F P
0 g
s
.47723 .74934 m .46303 .24614 L .50796 .24391 L p .707 .577 .707 r
F P
0 g
s
.46303 .24614 m .47723 .74934 L .43577 .75501 L p .707 .577 .707 r
F P
0 g
s
.67664 .70469 m .67104 .72168 L .69703 .73545 L p .707 .577 .707 r
F P
0 g
s
.50796 .24391 m .52216 .7471 L .47723 .74934 L p .707 .577 .707 r
F P
0 g
s
.67104 .72168 m .67664 .70469 L .65691 .68978 L p .707 .577 .707 r
F P
0 g
s
.79115 .74072 m .78555 .75772 L .80893 .75638 L p .707 .577 .707 r
F P
0 g
s
.80893 .75638 m .81452 .73938 L .79115 .74072 L p .707 .577 .707 r
F P
0 g
s
.65691 .68978 m .65132 .70678 L .67104 .72168 L p .707 .577 .707 r
F P
0 g
s
.81777 .70089 m .80695 .73504 L .8231 .72911 L p .707 .577 .707 r
F P
0 g
s
.8231 .72911 m .83393 .69496 L .81777 .70089 L p .707 .577 .707 r
F P
0 g
s
.83958 .60842 m .83401 .6631 L .84112 .65424 L p .707 .577 .707 r
F P
0 g
s
.84112 .65424 m .84669 .59955 L .83958 .60842 L p .707 .577 .707 r
F P
0 g
s
.64102 .64121 m .6466 .58653 L .64377 .57654 L p .707 .577 .707 r
F P
0 g
s
.81452 .73938 m .80893 .75638 L .82506 .75049 L p .707 .577 .707 r
F P
0 g
s
.82506 .75049 m .83066 .7335 L .81452 .73938 L p .707 .577 .707 r
F P
0 g
s
.64538 .67519 m .63978 .69219 L .65132 .70678 L p .707 .577 .707 r
F P
0 g
s
.63725 .67256 m .64808 .63841 L .64581 .62569 L p .707 .577 .707 r
F P
0 g
s
.63989 .63721 m .64102 .64121 L p .64152 .62946 L .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .63499 .65985 L .63725 .67256 L p .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .65312 .61589 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63499 .65985 m .63542 .6585 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63542 .6585 m .64581 .62569 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.64377 .57654 m .6382 .63122 L .63989 .63721 L p .707 .577 .707 r
F P
0 g
s
.64152 .62946 m .64377 .57654 L .63989 .63721 L .707 .577 .707 r
F
.83393 .69496 m .8231 .72911 L .8304 .71931 L p F P
0 g
s
.8304 .71931 m .84123 .68515 L .83393 .69496 L p .707 .577 .707 r
F P
0 g
s
.84669 .59955 m .84112 .65424 L .83829 .64425 L p .707 .577 .707 r
F P
0 g
s
.83829 .64425 m .84387 .58956 L .84669 .59955 L p .707 .577 .707 r
F P
0 g
s
.63978 .69219 m .64538 .67519 L .64316 .66234 L p .707 .577 .707 r
F P
0 g
s
.6382 .63122 m .64377 .57654 L .65088 .56767 L p .707 .577 .707 r
F P
0 g
s
.83066 .7335 m .82506 .75049 L .83238 .74064 L p .707 .577 .707 r
F P
0 g
s
.83238 .74064 m .83798 .72365 L .83066 .7335 L p .707 .577 .707 r
F P
0 g
s
.64316 .66234 m .63757 .67934 L .63978 .69219 L p .707 .577 .707 r
F P
0 g
s
.65088 .56767 m .64531 .62236 L .6382 .63122 L p .707 .577 .707 r
F P
0 g
s
.84123 .68515 m .8304 .71931 L .82814 .70659 L p .707 .577 .707 r
F P
0 g
s
.82814 .70659 m .83896 .67244 L .84123 .68515 L p .707 .577 .707 r
F P
0 g
s
.84387 .58956 m .83829 .64425 L .82582 .63411 L p .707 .577 .707 r
F P
0 g
s
.82582 .63411 m .83139 .57943 L .84387 .58956 L p .707 .577 .707 r
F P
0 g
s
.38971 .61077 m .39529 .55609 L .36428 .55104 L p .707 .577 .707 r
F P
0 g
s
.39529 .55609 m .38971 .61077 L .42141 .61283 L p .707 .577 .707 r
F P
0 g
s
.42141 .61283 m .42698 .55815 L .39529 .55609 L p .707 .577 .707 r
F P
0 g
s
.63757 .67934 m .64316 .66234 L .65048 .65249 L p .707 .577 .707 r
F P
0 g
s
.66723 .56081 m .66365 .59589 L p .64531 .62236 L .707 .577 .707 r
F P
0 g
s
.64229 .65004 m .65312 .61589 L .66927 .60996 L p .707 .577 .707 r
F P
0 g
s
.66365 .59589 m .66165 .61549 L .65475 .61839 L p .707 .577 .707 r
F P
0 g
s
.65312 .61589 m .64257 .64916 L p .63499 .65985 L .707 .577 .707 r
F P
0 g
s
.65475 .61839 m .64531 .62236 L p .66365 .59589 L .707 .577 .707 r
F P
0 g
s
.64257 .64916 m .64229 .65004 L .64214 .65025 L p .707 .577 .707 r
F P
0 g
s
.64214 .65025 m .63499 .65985 L p .64257 .64916 L .707 .577 .707 r
F P
0 g
s
.42698 .55815 m .42141 .61283 L .45067 .61171 L p .707 .577 .707 r
F P
0 g
s
.45067 .61171 m .45625 .55702 L .42698 .55815 L p .707 .577 .707 r
F P
0 g
s
.64531 .62236 m .65088 .56767 L .66723 .56081 L p .707 .577 .707 r
F P
0 g
s
.3587 .60572 m .36428 .55104 L .33698 .54349 L p .707 .577 .707 r
F P
0 g
s
.36428 .55104 m .3587 .60572 L .38971 .61077 L p .707 .577 .707 r
F P
0 g
s
.83798 .72365 m .83238 .74064 L .83016 .7278 L p .707 .577 .707 r
F P
0 g
s
.83016 .7278 m .83576 .7108 L .83798 .72365 L p .707 .577 .707 r
F P
0 g
s
.65048 .65249 m .64488 .66949 L .63757 .67934 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45625 .55702 m .45067 .61171 L .47465 .6075 L p .707 .577 .707 r
F P
0 g
s
.47465 .6075 m .48023 .55282 L .45625 .55702 L p .707 .577 .707 r
F P
0 g
s
.3314 .59818 m .33698 .54349 L .31607 .5342 L p .707 .577 .707 r
F P
0 g
s
.33698 .54349 m .3314 .59818 L .3587 .60572 L p .707 .577 .707 r
F P
0 g
s
.83896 .67244 m .82814 .70659 L .81654 .69222 L p .707 .577 .707 r
F P
0 g
s
.81654 .69222 m .82736 .65807 L .83896 .67244 L p .707 .577 .707 r
F P
0 g
s
.83139 .57943 m .82582 .63411 L .8049 .62481 L p .707 .577 .707 r
F P
0 g
s
.8049 .62481 m .81048 .57013 L .83139 .57943 L p .707 .577 .707 r
F P
0 g
s
.38154 .68763 m .39236 .65348 L .36256 .64251 L p .707 .577 .707 r
F P
0 g
s
.39236 .65348 m .38154 .68763 L .41213 .69503 L p .707 .577 .707 r
F P
0 g
s
.41213 .69503 m .42295 .66088 L .39236 .65348 L p .707 .577 .707 r
F P
0 g
s
.64488 .66949 m .65048 .65249 L .66661 .64661 L p .707 .577 .707 r
F P
0 g
s
.35174 .67666 m .36256 .64251 L .33648 .62905 L p .707 .577 .707 r
F P
0 g
s
.36256 .64251 m .35174 .67666 L .38154 .68763 L p .707 .577 .707 r
F P
0 g
s
.69121 .5566 m .68749 .5931 L p .66165 .61549 L .707 .577 .707 r
F P
0 g
s
.65844 .64411 m .66927 .60996 L .69269 .60848 L p .707 .577 .707 r
F P
0 g
s
.68749 .5931 m .68563 .61128 L .67604 .61297 L p .707 .577 .707 r
F P
0 g
s
.66927 .60996 m .65887 .64277 L p .64229 .65004 L .707 .577 .707 r
F P
0 g
s
.67604 .61297 m .66165 .61549 L p .68749 .5931 L .707 .577 .707 r
F P
0 g
s
.65887 .64277 m .65844 .64411 L .658 .64428 L p .707 .577 .707 r
F P
0 g
s
.658 .64428 m .64229 .65004 L p .65887 .64277 L .707 .577 .707 r
F P
0 g
s
.66165 .61549 m .66723 .56081 L .69121 .5566 L p .707 .577 .707 r
F P
0 g
s
.42295 .66088 m .41213 .69503 L .44052 .69815 L p .707 .577 .707 r
F P
0 g
s
.44052 .69815 m .45135 .664 L .42295 .66088 L p .707 .577 .707 r
F P
0 g
s
.83576 .7108 m .83016 .7278 L .81863 .7132 L p .707 .577 .707 r
F P
0 g
s
.81863 .7132 m .82422 .69621 L .83576 .7108 L p .707 .577 .707 r
F P
0 g
s
.66661 .64661 m .66102 .6636 L .64488 .66949 L p .707 .577 .707 r
F P
0 g
s
.48023 .55282 m .47465 .6075 L .491 .60063 L p .707 .577 .707 r
F P
0 g
s
.491 .60063 m .49657 .54595 L .48023 .55282 L p .707 .577 .707 r
F P
0 g
s
.31607 .5342 m .31049 .58888 L .3314 .59818 L p .707 .577 .707 r
F P
0 g
s
.31049 .58888 m .31607 .5342 L .30359 .52406 L p .707 .577 .707 r
F P
0 g
s
.32566 .6632 m .33648 .62905 L .31667 .61441 L p .707 .577 .707 r
F P
0 g
s
.33648 .62905 m .32566 .6632 L .35174 .67666 L p .707 .577 .707 r
F P
0 g
s
.45135 .664 m .44052 .69815 L .46394 .69667 L p .707 .577 .707 r
F P
0 g
s
.46394 .69667 m .47477 .66252 L .45135 .664 L p .707 .577 .707 r
F P
0 g
s
.81048 .57013 m .8049 .62481 L .7776 .61727 L p .707 .577 .707 r
F P
0 g
s
.7776 .61727 m .78318 .56259 L .81048 .57013 L p .707 .577 .707 r
F P
0 g
s
.82736 .65807 m .81654 .69222 L .79672 .67758 L p .707 .577 .707 r
F P
0 g
s
.79672 .67758 m .80755 .64343 L .82736 .65807 L p .707 .577 .707 r
F P
0 g
s
.38371 .75248 m .38931 .73549 L .35961 .72422 L p .707 .577 .707 r
F P
0 g
s
.38931 .73549 m .38371 .75248 L .41422 .76016 L p .707 .577 .707 r
F P
0 g
s
.41422 .76016 m .41981 .74316 L .38931 .73549 L p .707 .577 .707 r
F P
0 g
s
.68563 .61128 m .69121 .5566 L .72048 .55548 L p .707 .577 .707 r
F P
0 g
s
.35402 .74121 m .35961 .72422 L .33363 .71046 L p .707 .577 .707 r
F P
0 g
s
.35961 .72422 m .35402 .74121 L .38371 .75248 L p .707 .577 .707 r
F P
0 g
s
.66102 .6636 m .66661 .64661 L .68999 .64527 L p .707 .577 .707 r
F P
0 g
s
.41981 .74316 m .41422 .76016 L .44254 .76349 L p .707 .577 .707 r
F P
0 g
s
.44254 .76349 m .44814 .74649 L .41981 .74316 L p .707 .577 .707 r
F P
0 g
s
.31667 .61441 m .30585 .64856 L .32566 .6632 L p .707 .577 .707 r
F P
0 g
s
.72048 .55548 m .71705 .58907 L p .68563 .61128 L .707 .577 .707 r
F P
0 g
s
.68186 .64263 m .69269 .60848 L .72108 .6116 L p .707 .577 .707 r
F P
0 g
s
.71705 .58907 m .7149 .61016 L .7025 .61064 L p .707 .577 .707 r
F P
0 g
s
.69269 .60848 m .68271 .63997 L p .65844 .64411 L .707 .577 .707 r
F P
0 g
s
.7025 .61064 m .68563 .61128 L p .71705 .58907 L .707 .577 .707 r
F P
0 g
s
.68271 .63997 m .68186 .64263 L .68087 .6427 L p .707 .577 .707 r
F P
0 g
s
.68087 .6427 m .65844 .64411 L p .68271 .63997 L .707 .577 .707 r
F P
0 g
s
.30359 .52406 m .29801 .57874 L .31049 .58888 L p .707 .577 .707 r
F P
0 g
s
.82422 .69621 m .81863 .7132 L .7989 .6983 L p .707 .577 .707 r
F P
0 g
s
.7989 .6983 m .8045 .6813 L .82422 .69621 L p .707 .577 .707 r
F P
0 g
s
.33363 .71046 m .32803 .72745 L .35402 .74121 L p .707 .577 .707 r
F P
0 g
s
.68999 .64527 m .68439 .66226 L .66102 .6636 L p .707 .577 .707 r
F P
0 g
s
.78318 .56259 m .7776 .61727 L .74659 .61222 L p .707 .577 .707 r
F P
0 g
s
.74659 .61222 m .75217 .55754 L .78318 .56259 L p .707 .577 .707 r
F P
0 g
s
.49657 .54595 m .491 .60063 L .49811 .59177 L p .707 .577 .707 r
F P
0 g
s
.49811 .59177 m .50368 .53709 L .49657 .54595 L p .707 .577 .707 r
F P
0 g
s
.30585 .64856 m .31667 .61441 L .30507 .60003 L p .707 .577 .707 r
F P
0 g
s
.7149 .61016 m .72048 .55548 L .75217 .55754 L p .707 .577 .707 r
F P
0 g
s
.32803 .72745 m .33363 .71046 L .3139 .69555 L p .707 .577 .707 r
F P
0 g
s
.75217 .55754 m .74659 .61222 L .7149 .61016 L p .707 .577 .707 r
F P
0 g
s
.47477 .66252 m .46394 .69667 L .48009 .69074 L p .707 .577 .707 r
F P
0 g
s
.48009 .69074 m .49092 .65658 L .47477 .66252 L p .707 .577 .707 r
F P
0 g
s
.80755 .64343 m .79672 .67758 L .77431 .66601 L p .707 .577 .707 r
F P
0 g
s
.77851 .66754 m .77292 .68454 L .76884 .68299 L p .707 .577 .707 r
F P
0 g
s
.76884 .68299 m .74322 .67326 L p .77356 .66834 L .707 .577 .707 r
F P
0 g
s
.77356 .66834 m .77851 .66754 L .76884 .68299 L .707 .577 .707 r
F
.77587 .66119 m .80755 .64343 L .77431 .66601 L F
.74322 .67326 m .74882 .65627 L .77851 .66754 L p F P
0 g
s
.77431 .66601 m .77064 .66412 L p .77587 .66119 L .707 .577 .707 r
F P
0 g
s
.77064 .66412 m .78147 .62997 L .80755 .64343 L p .707 .577 .707 r
F P
0 g
s
.29801 .57874 m .30359 .52406 L .30076 .51407 L p .707 .577 .707 r
F P
0 g
s
.44814 .74649 m .44254 .76349 L .46592 .76214 L p .707 .577 .707 r
F P
0 g
s
.46592 .76214 m .47151 .74515 L .44814 .74649 L p .707 .577 .707 r
F P
0 g
s
.3139 .69555 m .30831 .71255 L .32803 .72745 L p .707 .577 .707 r
F P
0 g
s
.68439 .66226 m .68999 .64527 L .71831 .6486 L p .707 .577 .707 r
F P
0 g
s
.30507 .60003 m .29424 .63419 L .30585 .64856 L p .707 .577 .707 r
F P
0 g
s
.72108 .6116 m .71026 .64575 L .68186 .64263 L p .707 .577 .707 r
F P
0 g
s
.71026 .64575 m .72108 .6116 L .75167 .619 L p .707 .577 .707 r
F P
0 g
s
.8045 .6813 m .7989 .6983 L .77292 .68454 L p .707 .577 .707 r
F P
0 g
s
.77292 .68454 m .77851 .66754 L .8045 .6813 L p .707 .577 .707 r
F P
0 g
s
.78147 .62997 m .77064 .66412 L .74085 .65315 L p .707 .577 .707 r
F P
0 g
s
.74085 .65315 m .75167 .619 L .78147 .62997 L p .707 .577 .707 r
F P
0 g
s
.71831 .6486 m .71272 .66559 L .68439 .66226 L p .707 .577 .707 r
F P
0 g
s
.75167 .619 m .74085 .65315 L .71026 .64575 L p .707 .577 .707 r
F P
0 g
s
.30076 .51407 m .29519 .56875 L .29801 .57874 L p .707 .577 .707 r
F P
0 g
s
.30831 .71255 m .3139 .69555 L .30237 .68096 L p .707 .577 .707 r
F P
0 g
s
.29424 .63419 m .30507 .60003 L .3028 .58732 L p .707 .577 .707 r
F P
0 g
s
.71272 .66559 m .71831 .6486 L .74882 .65627 L p .707 .577 .707 r
F P
0 g
s
.50368 .53709 m .49811 .59177 L .49528 .58178 L p .707 .577 .707 r
F P
0 g
s
.49528 .58178 m .50086 .5271 L .50368 .53709 L p .707 .577 .707 r
F P
0 g
s
.47151 .74515 m .46592 .76214 L .48205 .75626 L p .707 .577 .707 r
F P
0 g
s
.48205 .75626 m .48765 .73927 L .47151 .74515 L p .707 .577 .707 r
F P
0 g
s
.30237 .68096 m .29677 .69795 L .30831 .71255 L p .707 .577 .707 r
F P
0 g
s
.49092 .65658 m .48009 .69074 L .48739 .68093 L p .707 .577 .707 r
F P
0 g
s
.48739 .68093 m .49822 .64678 L .49092 .65658 L p .707 .577 .707 r
F P
0 g
s
.74882 .65627 m .74322 .67326 L .71272 .66559 L p .707 .577 .707 r
F P
0 g
s
.29519 .56875 m .30076 .51407 L .30787 .50521 L p .707 .577 .707 r
F P
0 g
s
.3028 .58732 m .29198 .62147 L .29424 .63419 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29677 .69795 m .30237 .68096 L .30015 .66811 L p .707 .577 .707 r
F P
0 g
s
.30787 .50521 m .3023 .55989 L .29519 .56875 L p .707 .577 .707 r
F P
0 g
s
.29198 .62147 m .3028 .58732 L .31011 .57752 L p .707 .577 .707 r
F P
0 g
s
.48765 .73927 m .48205 .75626 L .48937 .74641 L p .707 .577 .707 r
F P
0 g
s
.48937 .74641 m .49497 .72942 L .48765 .73927 L p .707 .577 .707 r
F P
0 g
s
.30015 .66811 m .29455 .6851 L .29677 .69795 L p .707 .577 .707 r
F P
0 g
s
.50086 .5271 m .49528 .58178 L .48281 .57164 L p .707 .577 .707 r
F P
0 g
s
.48281 .57164 m .48838 .51696 L .50086 .5271 L p .707 .577 .707 r
F P
0 g
s
.49822 .64678 m .48739 .68093 L .48513 .66822 L p .707 .577 .707 r
F P
0 g
s
.48513 .66822 m .49595 .63407 L .49822 .64678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3023 .55989 m .30787 .50521 L .32422 .49834 L p .707 .577 .707 r
F P
0 g
s
.31011 .57752 m .29928 .61167 L .29198 .62147 L p .707 .577 .707 r
F P
0 g
s
.29455 .6851 m .30015 .66811 L .30747 .65826 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32422 .49834 m .31864 .55302 L .3023 .55989 L p .707 .577 .707 r
F P
0 g
s
.29928 .61167 m .31011 .57752 L .32626 .57159 L p .707 .577 .707 r
F P
0 g
s
.49497 .72942 m .48937 .74641 L .48715 .73356 L p .707 .577 .707 r
F P
0 g
s
.48715 .73356 m .49275 .71657 L .49497 .72942 L p .707 .577 .707 r
F P
0 g
s
.30747 .65826 m .30187 .67526 L .29455 .6851 L p .707 .577 .707 r
F P
0 g
s
.48838 .51696 m .48281 .57164 L .46189 .56235 L p .707 .577 .707 r
F P
0 g
s
.46189 .56235 m .46747 .50767 L .48838 .51696 L p .707 .577 .707 r
F P
0 g
s
.49595 .63407 m .48513 .66822 L .47353 .65385 L p .707 .577 .707 r
F P
0 g
s
.47353 .65385 m .48435 .6197 L .49595 .63407 L p .707 .577 .707 r
F P
0 g
s
.31864 .55302 m .32422 .49834 L .3482 .49414 L p .707 .577 .707 r
F P
0 g
s
.32626 .57159 m .31543 .60574 L .29928 .61167 L p .707 .577 .707 r
F P
0 g
s
.30187 .67526 m .30747 .65826 L .3236 .65238 L p .707 .577 .707 r
F P
0 g
s
.46747 .50767 m .46189 .56235 L .43459 .55481 L p .707 .577 .707 r
F P
0 g
s
.43459 .55481 m .44017 .50013 L .46747 .50767 L p .707 .577 .707 r
F P
0 g
s
.3482 .49414 m .34262 .54882 L .31864 .55302 L p .707 .577 .707 r
F P
0 g
s
.31543 .60574 m .32626 .57159 L .34968 .57011 L p .707 .577 .707 r
F P
0 g
s
.34262 .54882 m .3482 .49414 L .37746 .49301 L p .707 .577 .707 r
F P
0 g
s
.49275 .71657 m .48715 .73356 L .47562 .71897 L p .707 .577 .707 r
F P
0 g
s
.47562 .71897 m .48121 .70198 L .49275 .71657 L p .707 .577 .707 r
F P
0 g
s
.3236 .65238 m .31801 .66937 L .30187 .67526 L p .707 .577 .707 r
F P
0 g
s
.48435 .6197 m .47353 .65385 L .45371 .63921 L p .707 .577 .707 r
F P
0 g
s
.45371 .63921 m .46454 .60506 L .48435 .6197 L p .707 .577 .707 r
F P
0 g
s
.44017 .50013 m .43459 .55481 L .40358 .54976 L p .707 .577 .707 r
F P
0 g
s
.40358 .54976 m .40916 .49508 L .44017 .50013 L p .707 .577 .707 r
F P
0 g
s
.37189 .54769 m .37746 .49301 L .40916 .49508 L p .707 .577 .707 r
F P
0 g
s
.37746 .49301 m .37189 .54769 L .34262 .54882 L p .707 .577 .707 r
F P
0 g
s
.34968 .57011 m .33885 .60426 L .31543 .60574 L p .707 .577 .707 r
F P
0 g
s
.40916 .49508 m .40358 .54976 L .37189 .54769 L p .707 .577 .707 r
F P
0 g
s
.33885 .60426 m .34968 .57011 L .37807 .57322 L p .707 .577 .707 r
F P
0 g
s
.31801 .66937 m .3236 .65238 L .34698 .65103 L p .707 .577 .707 r
F P
0 g
s
.46454 .60506 m .45371 .63921 L .42763 .62575 L p .707 .577 .707 r
F P
0 g
s
.42763 .62575 m .43846 .5916 L .46454 .60506 L p .707 .577 .707 r
F P
0 g
s
.48121 .70198 m .47562 .71897 L .45589 .70407 L p .707 .577 .707 r
F P
0 g
s
.45589 .70407 m .46149 .68707 L .48121 .70198 L p .707 .577 .707 r
F P
0 g
s
.34698 .65103 m .34138 .66803 L .31801 .66937 L p .707 .577 .707 r
F P
0 g
s
.37807 .57322 m .36725 .60738 L .33885 .60426 L p .707 .577 .707 r
F P
0 g
s
.36725 .60738 m .37807 .57322 L .40866 .58063 L p .707 .577 .707 r
F P
0 g
s
.43846 .5916 m .42763 .62575 L .39784 .61478 L p .707 .577 .707 r
F P
0 g
s
.39784 .61478 m .40866 .58063 L .43846 .5916 L p .707 .577 .707 r
F P
0 g
s
.40866 .58063 m .39784 .61478 L .36725 .60738 L p .707 .577 .707 r
F P
0 g
s
.34138 .66803 m .34698 .65103 L .3753 .65436 L p .707 .577 .707 r
F P
0 g
s
.46149 .68707 m .45589 .70407 L .42991 .6903 L p .707 .577 .707 r
F P
0 g
s
.42991 .6903 m .4355 .67331 L .46149 .68707 L p .707 .577 .707 r
F P
0 g
s
.3753 .65436 m .36971 .67136 L .34138 .66803 L p .707 .577 .707 r
F P
0 g
s
.36971 .67136 m .3753 .65436 L .40581 .66204 L p .707 .577 .707 r
F P
0 g
s
.4355 .67331 m .42991 .6903 L .40021 .67903 L p .707 .577 .707 r
F P
0 g
s
.40021 .67903 m .40581 .66204 L .4355 .67331 L p .707 .577 .707 r
F P
0 g
s
.40581 .66204 m .40021 .67903 L .36971 .67136 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo001nOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol007Ioo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00Lgoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000Kgoo001`Ool30004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001/Ool006eoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP<006Yoo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00J7oo
001YOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVEoo`00IGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIGoo
001UOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol006Eoo`04001JEUYF
0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001T
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol0061ooaL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00Fgoo1@000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001IOol200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Moo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00EWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00EGoo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUH005YF0002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00E7oo0P0015YF00@005YFFUIJEP`000AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol005Aoo`03FUH005YF009JEPD00003FUH005YF00IJEP03001JEUYF00@0009JEP03001J
EUYF00AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000@Ool8001<Ool005=oo`04001JEP00FUH30005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUHC0002FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0027oo20000eYF
00<005YFFUH00UYF1`00AGoo001COol01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF
00EJEP<000MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool40003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040011Ool005=oo`<0009JEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005=oo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF
009JEP800007FUH005YFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00>Goo001COol00`00FUIJEP02FUH01000FUIJEUYF2`001eYF1@00
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF0P0025YF00<005YFFUH01UYF00<005YFFUH00eYF1000=Goo001DOol01P00FUIJEUYF001JEP<0
00IJEP04001JEUYFFUH7000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YF
FUH005YF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0
009JEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002000bOol005Aoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF008000EJEP03
001JEUYF00EJEP8000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00
EGoo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00;goo000iOolG0006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEP0002ioo`00=7oo1@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010000Woo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000]Ool0039oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Goo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30000
0eYF001JEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH0
1000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000_Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00@005YF000000UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP05001JEUYFFUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH60002FUH20002Ool70007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
1@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH00UYF0P00
0goo00<005YFFUH01@000UYF00<005YFFUH01UYF00<005YFFUH01eYF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEPh000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001J
EUYF0005FUH20002Ool01000FUIJEP0015YF10001eYF00<005YFFUH01UYF00<005YFFUH00P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF
00<0009JEP03001JEUYF00EJEP03001JEP0000X000AJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH2000/Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000EJEP800003FUH005YF00AJEP03001JEP000080009JEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEPH000EJEP03001JEUYF00AJEP03
001JEUYF00=JEPD000=oo`H000EJEP03001JEUYF00AJEP06001JEUYF001JEP00;7oo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP020005FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUIJEP<00003
FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEP00FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH?00000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP8000QJEP03
001JEUYF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
00<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000QJEP80
00EJEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00@005YFFUH000AJEP<000QJEP8000EJEP03001JEUYF00AJEP03001JEP0000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEP<000IJEP04001JEP000003FUH01000FUIJEUYF
0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01000FUIJEP00
0eYF1@001eYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP<000=JEP04001JEUYFFUH200000eYF001JEP02FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20002FUH20002FUH01000
FUIJEUYF1@001eYF00@005YFFUIJEP<000MJEP05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUH000020006FUH20003FUH2000]Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00
FUIJEP03FUH40002FUH01000FUIJEUYF1@001eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000P000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P001EYF00<005YF00000UYF0P00;Goo000]Ool20004FUH01000FUIJEUYF300017oo2@0015YF
00@005YFFUH000IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<000QJEP03001JEUYF00AJEP80
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool00eYF001JEP02FUH500000eYF001JEP06
FUH00`00FUIJEP040009Ool70006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000002FUHC0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH3000]Ool002aoo`04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH@0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH30004FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH0000300001EYF000005YF00001UYF00@005YFFUIJEPP0009JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000AJEP<002eoo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF009JEP80009JEP`000MJEP@000QJEP03
001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF001JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP0000D000QJ
EP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002aoo`<0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00AJEP<000IJEP04001JEUYF
FUH70002FUH00`00FUIJEP040004FUH00`00FUIJEP09FUH20002FUH00`00FUH00006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00
;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH010001EYF1P002UYF
0P000UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000AJ
EP000000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003
FUH005YF00IJEP03001JEUYF00EJEP04001JEP00000^Ool002aoo`03001JEUYF009JEP04001JEUYF
FUH;0007FUH50005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40003FUH01000FUIJEUYF3@0000=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF0P0000=JEP0000000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH00UYF
0`001eYF00<005YFFUH01EYF0`00;goo000]Ool01P00FUIJEUYF001JEP<000IJEP04001JEUYFFUH7
000015YF000000001UYF00@005YFFUIJEP8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH0
0`00FUH000020008FUH00`00FUIJEP03FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP800004FUH00000FUH20006FUH<0006FUH00`00FUIJEP06FUH20005
FUH00`00FUIJEP04FUH00`00FUH0000`Ool002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040006FUH01000FUIJEUYF0P000UYF1@0000=JEP0000000eYF1`001eYF
00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000040007FUH;00000eYF000000020002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00@005YFFUH002moo`00;Woo00@0
05YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00800005FUH00000FUH00005FUH40007FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000800003FUH005YF00EJEP04001JEUYFFUH30005Ool90007FUH01000FUIJEUYF0`001eYF
00D005YFFUIJEP0002ioo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YF00000P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH00P0025YF0`0000=JEP00
FUH025YF0`0000=JEP00FUH015YF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00=JEP8000eoo`8000EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP03001oogoo02aoo`00;goo0P000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF
00@005YFFUIJEP@000EJEP03001JEP0000<000QJEP03001JEUYF008000AJEP03001JEUYF009JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00001JEP020006FUH0
0`00FUIJEP05FUH2000=Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF0000009JEP03001JEUYF00AJEP06001JEUYFFUH005YF1@0000=JEP00FUH02000
15YF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0006FUH00`00FUIJEP08FUH3000<Ool30008
FUH30002FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00005FUH00`00FUIJEP02FUH2
000017oo001JEUYF2@000eYF0`0000=JEP00FUH01UYF0`000eYF0P002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0037oo0P001UYF00<005YFFUH00P0015YF00<005YF0000;Goo000^Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0005FUH01000FUIJEUYF0P000Woo00@005YFFUH000=JEPD0009JEP04001JEUYFFUH20008FUH20002
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH3000;Ool20003FUH00`00FUIJEP02FUH20002
FUH00`00FUH0000^Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP04001JEP000004Ool01000FUIJEP0015YF0`00
00=JEP00000010000UYF0P001EYF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP0000<000Uoo`800003FUH005YF00EJEP05001JEP00FUH0000^Ool002eoo`03001JEP00009JEQ80
00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000<000Ioo`04001JEUYF0006FUH0
0`00FUIJEP05FUH60003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000Eoo`8000IJEP<00003FUH007oo02eoo`00;Goo0P0000AJEP000000011oo`D0009J
EP03001JEUYF00IJEP03001JEP00009JEP05001JEUYF001JEP020008Ool01000FUIJEP001UYF00<0
05YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF200015YF00D005YF001JEP0002moo`00;Goo00=JEP0000000eYF00<007ooOol04Woo
0`0025YF00<005YF00000UYF00D005YFFUIJEP00009JEP8000Ioo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF008002moo`00;7oo0P001EYF0P00
5Woo0P001UYF00<005YFFUH00P001EYF00D005YFFUIJEP0000Eoo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20004FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`001EYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF0P000eYF0P00;goo000/Ool20004FUH01000FUIJEP005goo0P00
15YF00D005YFFUIJEP0000IJEP80009JEP03001oogoo009oo`04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEP<000UJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000AJEP03001oogoo02eoo`00;7oo0P0015YF00D005YF
FUIJEP0001Qoo`800003FUH005YF00AJEP8000AJEP03001JEP0000<000=oo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF0`00
1UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P00;goo
000/Ool20003FUH00`00FUIJEP03FUH00`00Oomoo`0GOol30006FUH01000FUIJEP0015YF0`000Woo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00<000QJEP<000AJEP03001JEP0000@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUH0000^Ool002aoo`03001JEUYF009JEP03001JEUYF00AJEP8000ioo`<000Uoo`80
00AJEP@000MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP80
00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0008FUH00`00FUH00002000015YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001oogoo02aoo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00@0
05YF000000]oo`D000Yoo`800003FUH005YF009JEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP8000IJEP03001JEUYF009JEPT0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001oogoo02aoo`00;Goo00@005YFFUH0
00IJEP03001JEUYF009JEP<000Qoo`D000aoo`8000AJEP8000EJEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP8000=JEP03001JEUYF00IJEPD0009JEP03001J
EUYF00IJEP03001JEUYF00AJEP08001JEUYF001oo`00FUH002moo`00;Goo00@005YFFUH000IJEP03
001JEUYF00EJEP<000Eoo`D000ioo`03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00000015YF0`0000=JEP00FUH025YF00<0
05YF00001`0015YF00<005YFFUH015YF00@005YF0000009oo`03001JEP0002moo`00;Woo0P001eYF
00<005YFFUH01UYF00@005YF000000Aoo`<0011oo`03001JEUYF009JEP03001JEP00008000QJEP@0
0003FUH005YF00MJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP<000MJEP03001J
EUYF00AJEQ40009oo`800003FUH007oo02moo`00;goo00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`005Goo0P000UYF00@005YFFUIJEP8000QJEP03001JEUYF00@000IJEP03001JEUYF
00UJEP03001JEP00008000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8000=JEP@000AJEP@000EJEP03001JEUYF00IJEP04001JEUYFFUH=0002FUH2000`Ool0
031oo`80009JEP`000MJEP<001Aoo`8000=JEP03001JEUYF00<000AJEP03001JEUYF00EJEPL000MJ
EPH00003FUH0000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00004FUH01000FUH007oo0`0000=JEP00FUH025YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00<Woo0P0000=JEP00FUH015YF00@005YFFUIJ
EPL0009JEP03001JEP000080019oo`07001JEUYFFUH005YF00000Woo00IJEP00000005YF0009FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP80009JEQD000QJEP03001JEUYF00IJEP03001JEUYF009J
EP80009JEP03001JEUYF009JEP80009JEP03001JEP0000Aoo`@000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH2000aOol0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP<0011oo`06001JEUYF001JEP000Woo0eYF10001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00IJEPH0009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00AJEP04001JEP000009Ool40002FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEQ40009JEP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF0P0035YF00<005YF0000
10001UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`003Woo1P0015YF00<005YFFUH00eYF00@0
05YF000003Aoo`00;goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP06001J
EP00001JEP001eYF00<005YFFUH00eYF00H005YF000005YF0003Ool3FUH00`00FUIJEP03FUH30000
0eYF001JEP07FUH00`00FUIJEP03FUH00`00FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUH0000EOol<
000fOol002ioo`80009JEP`000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH015YF00<005YF0000100015YF00@005YF
FUIJEPH000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@000AJEP800003FUH0
05YF00EJEP04001JEUYF001FOol002eoo`800003FUH0000000Qoo`800003FUH0000000D000MJEP03
001JEUYF00EJEP8000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH0
0eYF0`000eYF00<005YF00001`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP80009JEP<000MJEP05001JEUYFFUH0001EOol002eoo`<000aoo`<0
00EJEP@0009JEP03001JEUYF00MJEP<00003FUH005YF00AJEP04001JEUYFFUH20004Ool3FUH01000
FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF009JEP03001oogoo
05=oo`00;7oo0`0047oo0P001EYF00<005YF00000`0025YF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P0017oo0eYF00<005YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
009JEP07001JEUYFFUH005YF0000E7oo000/Ool01000FUH000004Goo0`0000=JEP00FUH0200015YF
00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<007ooOol00goo0eYF0P000UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YF0000009JEP8000=JEP07001JEUYFFUH005YF0000E7oo000/Ool0
1@00FUH005YF00004goo20000eYF0`0000=JEP00FUH01UYF0`000eYF0P001Goo0UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEP00009JEP07001JEUYF
FUH005YF0000E7oo000/Ool00`00FUIJEP02FUH00`00Oomoo`0COol50002FUH01000FUIJEUYF0P00
25YF0P000UYF0P001Woo00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH0
05YF0003FUH20003FUH00`00FUH0001EOol002eoo`03001JEUYF009JEP03001oogoo01=oo`<00003
Ool0000000@0009JEP8000EJEP03001JEUYF008000Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00H005YFFUH005YF001EOol002eoo`03001JEUYF009JEP8001io
o`H000=JEP03001JEUYF009JEP03001oogoo00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000IJEP05001JEP00FUH0001EOol002ioo`04001JEUYF0002FUH00`00Oomoo`0QOol3
0006FUH00`00Oomoo`05Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH70004FUH0
0`00FUH00002001FOol002ioo`04001JEUYF0003FUH00`00Oomoo`0ROol00`00FUIJEP04FUH20006
Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP80009JEP05
001JEP00FUH0001FOol002moo`8000EJEP03001oogoo029oo`8000AJEP03001JEP0000Ioo`8000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEUYF0004FUH00`00FUIJEP04FUH20003FUH2001FOol0031oo`03001J
EUYF00AJEP03001oogoo02=oo`04001JEUYF0003FUH00`00Oomoo`05Ool200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3
0005FUH00`00FUIJEP04FUH20004FUH00`00Oomoo`1DOol0035oo`03001JEUYF00=JEP<002Aoo`<0
00AJEP03001oogoo00Ioo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP03001JEP0000=JEP03001oogoo
05Aoo`00<Woo00<005YFFUH00UYF00<005YFFUH00P0097oo00<005YFFUH00UYF00<007ooOol02Goo
10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0005Eoo`00<goo
0P0000=JEP00FUH015YF0P008goo00<005YFFUH00P003goo1@0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF0000EGoo000eOol20007FUH3000POol00`00FUIJEP02000DOol60002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF3`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00`000UYF00<007ooOol0Dgoo000fOol20006FUH00`00FUIJEP02000OOol200000eYF001oo`0I
OolP0008FUH600000eYF001JEP07FUH00`00FUIJEP04FUH02000FUIJEP00Ool005YF001FOol003Qo
o`8000AJEP03001JEUYF009JEP<001eoo`03001JEP0003Ioo`800003FUH005YF00QJEPX000AJEP03
001JEUYF00AJEP04001JEP000002Ool00`00FUH0001FOol003Yoo`800003FUH005YF00MJEP@001Uo
o`03001JEP0003Qoo`<000MJEP03001JEUYF00AJEQ40009oo`800003FUH007oo05Ioo`00?7oo0`00
25YF00<005YFFUH010005Goo0P00?7oo0P001EYF00<005YFFUH01UYF00@005YFFUIJEPd0009JEP80
05Moo`00?goo0P001UYF00<005YFFUH015YF1P003Goo1000?Woo0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005Qoo`00@Goo0P000eYF00<005YFFUH01eYF00@0
05YFFUIJEPd0009JEP80045oo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
001HOol004=oo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0016Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001IOol004Eoo`<000MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001:Ool60004FUH00`00FUIJEP03FUH0
1000FUH00000Fgoo0018Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001A
Ool<001MOol004aoo`H000AJEP04001JEUYFFUH6002mOol0059oo`P00<=oo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59579 .75929 m .59924 .70419 L .56813 .70034 L p .707 .577 .707 r
F P
0 g
s
.59924 .70419 m .59579 .75929 L .62757 .76027 L p .707 .577 .707 r
F P
0 g
s
.62757 .76027 m .63102 .70517 L .59924 .70419 L p .707 .577 .707 r
F P
0 g
s
.63102 .70517 m .62757 .76027 L .65691 .75829 L p .707 .577 .707 r
F P
0 g
s
.65691 .75829 m .66036 .70319 L .63102 .70517 L p .707 .577 .707 r
F P
0 g
s
.56468 .75543 m .56813 .70034 L .54073 .69399 L p .707 .577 .707 r
F P
0 g
s
.56813 .70034 m .56468 .75543 L .59579 .75929 L p .707 .577 .707 r
F P
0 g
s
.66036 .70319 m .65691 .75829 L .68093 .75354 L p .707 .577 .707 r
F P
0 g
s
.68093 .75354 m .68438 .69844 L .66036 .70319 L p .707 .577 .707 r
F P
0 g
s
.53728 .74909 m .54073 .69399 L .51973 .68578 L p .707 .577 .707 r
F P
0 g
s
.54073 .69399 m .53728 .74909 L .56468 .75543 L p .707 .577 .707 r
F P
0 g
s
.59099 .8152 m .59774 .77954 L .5671 .77195 L p .707 .577 .707 r
F P
0 g
s
.59774 .77954 m .59099 .8152 L .62235 .81957 L p .707 .577 .707 r
F P
0 g
s
.62235 .81957 m .6291 .78391 L .59774 .77954 L p .707 .577 .707 r
F P
0 g
s
.6291 .78391 m .62235 .81957 L .65135 .82027 L p .707 .577 .707 r
F P
0 g
s
.65135 .82027 m .6581 .7846 L .6291 .78391 L p .707 .577 .707 r
F P
0 g
s
.56034 .80761 m .5671 .77195 L .54017 .76186 L p .707 .577 .707 r
F P
0 g
s
.5671 .77195 m .56034 .80761 L .59099 .8152 L p .707 .577 .707 r
F P
0 g
s
.59237 .8439 m .59586 .82611 L .56526 .81832 L p .707 .577 .707 r
F P
0 g
s
.59586 .82611 m .59237 .8439 L .62369 .84844 L p .707 .577 .707 r
F P
0 g
s
.62369 .84844 m .62719 .83064 L .59586 .82611 L p .707 .577 .707 r
F P
0 g
s
.68438 .69844 m .68093 .75354 L .69729 .74648 L p .707 .577 .707 r
F P
0 g
s
.69729 .74648 m .70074 .69138 L .68438 .69844 L p .707 .577 .707 r
F P
0 g
s
.51973 .68578 m .51628 .74087 L .53728 .74909 L p .707 .577 .707 r
F P
0 g
s
.54017 .76186 m .53341 .79752 L .56034 .80761 L p .707 .577 .707 r
F P
0 g
s
.6581 .7846 m .65135 .82027 L .67516 .81723 L p .707 .577 .707 r
F P
0 g
s
.67516 .81723 m .68191 .78157 L .6581 .7846 L p .707 .577 .707 r
F P
0 g
s
.62719 .83064 m .62369 .84844 L .65267 .84928 L p .707 .577 .707 r
F P
0 g
s
.65267 .84928 m .65617 .83148 L .62719 .83064 L p .707 .577 .707 r
F P
0 g
s
.56176 .83611 m .56526 .81832 L .53837 .80804 L p .707 .577 .707 r
F P
0 g
s
.56526 .81832 m .56176 .83611 L .59237 .8439 L p .707 .577 .707 r
F P
0 g
s
.53341 .79752 m .54017 .76186 L .51959 .75027 L p .707 .577 .707 r
F P
0 g
s
.51628 .74087 m .51973 .68578 L .50718 .6765 L p .707 .577 .707 r
F P
0 g
s
.53837 .80804 m .53487 .82583 L .56176 .83611 L p .707 .577 .707 r
F P
0 g
s
.65617 .83148 m .65267 .84928 L .67646 .84633 L p .707 .577 .707 r
F P
0 g
s
.67646 .84633 m .67996 .82854 L .65617 .83148 L p .707 .577 .707 r
F P
0 g
s
.51959 .75027 m .51284 .78593 L .53341 .79752 L p .707 .577 .707 r
F P
0 g
s
.53487 .82583 m .53837 .80804 L .51782 .79627 L p .707 .577 .707 r
F P
0 g
s
.68191 .78157 m .67516 .81723 L .69144 .81077 L p .707 .577 .707 r
F P
0 g
s
.69144 .81077 m .6982 .77511 L .68191 .78157 L p .707 .577 .707 r
F P
0 g
s
.51782 .79627 m .51433 .81406 L .53487 .82583 L p .707 .577 .707 r
F P
0 g
s
.50718 .6765 m .50373 .73159 L .51628 .74087 L p .707 .577 .707 r
F P
0 g
s
.51284 .78593 m .51959 .75027 L .50738 .73831 L p .707 .577 .707 r
F P
0 g
s
.70074 .69138 m .69729 .74648 L .70438 .7378 L p .707 .577 .707 r
F P
0 g
s
.70438 .7378 m .70783 .68271 L .70074 .69138 L p .707 .577 .707 r
F P
0 g
s
.50373 .73159 m .50718 .6765 L .50431 .66706 L p .707 .577 .707 r
F P
0 g
s
.67996 .82854 m .67646 .84633 L .69274 .8399 L p .707 .577 .707 r
F P
0 g
s
.69274 .8399 m .69624 .8221 L .67996 .82854 L p .707 .577 .707 r
F P
0 g
s
.50738 .73831 m .50062 .77397 L .51284 .78593 L p .707 .577 .707 r
F P
0 g
s
.51433 .81406 m .51782 .79627 L .50564 .78417 L p .707 .577 .707 r
F P
0 g
s
.50564 .78417 m .50214 .80196 L .51433 .81406 L p .707 .577 .707 r
F P
0 g
s
.6982 .77511 m .69144 .81077 L .69861 .8015 L p .707 .577 .707 r
F P
0 g
s
.69861 .8015 m .70537 .76584 L .6982 .77511 L p .707 .577 .707 r
F P
0 g
s
.50431 .66706 m .50086 .72215 L .50373 .73159 L p .707 .577 .707 r
F P
0 g
s
.50062 .77397 m .50738 .73831 L .50472 .72714 L p .707 .577 .707 r
F P
0 g
s
.70783 .68271 m .70438 .7378 L .70152 .72837 L p .707 .577 .707 r
F P
0 g
s
.70152 .72837 m .70497 .67327 L .70783 .68271 L p .707 .577 .707 r
F P
0 g
s
.49821 .82185 m .48943 .3191 L .44543 .3172 L p .707 .577 .707 r
F P
0 g
s
.50472 .72714 m .49797 .76281 L .50062 .77397 L p .707 .577 .707 r
F P
0 g
s
.50086 .72215 m .50431 .66706 L .5114 .65838 L p .707 .577 .707 r
F P
0 g
s
.50214 .80196 m .50564 .78417 L .503 .77292 L p .707 .577 .707 r
F P
0 g
s
.503 .77292 m .49951 .79071 L .50214 .80196 L p .707 .577 .707 r
F P
0 g
s
.49797 .76281 m .50472 .72714 L .51189 .71788 L p .707 .577 .707 r
F P
0 g
s
.5114 .65838 m .50795 .71348 L .50086 .72215 L p .707 .577 .707 r
F P
0 g
s
.51189 .71788 m .50514 .75354 L .49797 .76281 L p .707 .577 .707 r
F P
0 g
s
.50795 .71348 m .5114 .65838 L .52776 .65132 L p .707 .577 .707 r
F P
0 g
s
.49951 .79071 m .503 .77292 L .51017 .76362 L p .707 .577 .707 r
F P
0 g
s
.51017 .76362 m .50668 .78141 L .49951 .79071 L p .707 .577 .707 r
F P
0 g
s
.50514 .75354 m .51189 .71788 L .52818 .71141 L p .707 .577 .707 r
F P
0 g
s
.52776 .65132 m .52431 .70642 L .50795 .71348 L p .707 .577 .707 r
F P
0 g
s
.52431 .70642 m .52776 .65132 L .55179 .64657 L p .707 .577 .707 r
F P
0 g
s
.52818 .71141 m .52142 .74707 L .50514 .75354 L p .707 .577 .707 r
F P
0 g
s
.50668 .78141 m .51017 .76362 L .52645 .75719 L p .707 .577 .707 r
F P
0 g
s
.52645 .75719 m .52296 .77498 L .50668 .78141 L p .707 .577 .707 r
F P
0 g
s
.52142 .74707 m .52818 .71141 L .55199 .70838 L p .707 .577 .707 r
F P
0 g
s
.55179 .64657 m .54834 .70167 L .52431 .70642 L p .707 .577 .707 r
F P
0 g
s
.55199 .70838 m .54523 .74404 L .52142 .74707 L p .707 .577 .707 r
F P
0 g
s
.52296 .77498 m .52645 .75719 L .55024 .75424 L p .707 .577 .707 r
F P
0 g
s
.55024 .75424 m .54675 .77204 L .52296 .77498 L p .707 .577 .707 r
F P
0 g
s
.48943 .3191 m .49821 .82185 L .54314 .82005 L p .707 .577 .707 r
F P
0 g
s
.54314 .82005 m .53437 .3173 L .48943 .3191 L p .707 .577 .707 r
F P
0 g
s
.69624 .8221 m .69274 .8399 L .69992 .8306 L p .707 .577 .707 r
F P
0 g
s
.69992 .8306 m .70341 .81281 L .69624 .8221 L p .707 .577 .707 r
F P
0 g
s
.54834 .70167 m .55179 .64657 L .58113 .64459 L p .707 .577 .707 r
F P
0 g
s
.58113 .64459 m .57768 .69969 L .54834 .70167 L p .707 .577 .707 r
F P
0 g
s
.54523 .74404 m .55199 .70838 L .58099 .70908 L p .707 .577 .707 r
F P
0 g
s
.58099 .70908 m .57424 .74474 L .54523 .74404 L p .707 .577 .707 r
F P
0 g
s
.57424 .74474 m .58099 .70908 L .61235 .71344 L p .707 .577 .707 r
F P
0 g
s
.54675 .77204 m .55024 .75424 L .57922 .75508 L p .707 .577 .707 r
F P
0 g
s
.61235 .71344 m .60559 .7491 L .57424 .74474 L p .707 .577 .707 r
F P
0 g
s
.57922 .75508 m .57573 .77288 L .54675 .77204 L p .707 .577 .707 r
F P
0 g
s
.57573 .77288 m .57922 .75508 L .61055 .75962 L p .707 .577 .707 r
F P
0 g
s
.61055 .75962 m .60705 .77741 L .57573 .77288 L p .707 .577 .707 r
F P
0 g
s
.53437 .3173 m .54314 .82005 L .58462 .81472 L p .707 .577 .707 r
F P
0 g
s
.57768 .69969 m .58113 .64459 L .61291 .64557 L p .707 .577 .707 r
F P
0 g
s
.61291 .64557 m .60946 .70067 L .57768 .69969 L p .707 .577 .707 r
F P
0 g
s
.58462 .81472 m .57584 .31197 L .53437 .3173 L p .707 .577 .707 r
F P
0 g
s
.4542 .81995 m .44543 .3172 L .40667 .31178 L p .707 .577 .707 r
F P
0 g
s
.44543 .3172 m .4542 .81995 L .49821 .82185 L p .707 .577 .707 r
F P
0 g
s
.70537 .76584 m .69861 .8015 L .69596 .79034 L p .707 .577 .707 r
F P
0 g
s
.69596 .79034 m .70271 .75468 L .70537 .76584 L p .707 .577 .707 r
F P
0 g
s
.64299 .72104 m .63624 .7567 L .60559 .7491 L p .707 .577 .707 r
F P
0 g
s
.60559 .7491 m .61235 .71344 L .64299 .72104 L p .707 .577 .707 r
F P
0 g
s
.64115 .76741 m .63766 .7852 L .60705 .77741 L p .707 .577 .707 r
F P
0 g
s
.60705 .77741 m .61055 .75962 L .64115 .76741 L p .707 .577 .707 r
F P
0 g
s
.57584 .31197 m .58462 .81472 L .61857 .80639 L p .707 .577 .707 r
F P
0 g
s
.64402 .64943 m .64057 .70452 L .60946 .70067 L p .707 .577 .707 r
F P
0 g
s
.60946 .70067 m .61291 .64557 L .64402 .64943 L p .707 .577 .707 r
F P
0 g
s
.61857 .80639 m .6098 .30364 L .57584 .31197 L p .707 .577 .707 r
F P
0 g
s
.70497 .67327 m .70152 .72837 L .68897 .71908 L p .707 .577 .707 r
F P
0 g
s
.68897 .71908 m .69242 .66399 L .70497 .67327 L p .707 .577 .707 r
F P
0 g
s
.25278 .70662 m .25623 .65152 L .22512 .64767 L p .707 .577 .707 r
F P
0 g
s
.25623 .65152 m .25278 .70662 L .28456 .7076 L p .707 .577 .707 r
F P
0 g
s
.28456 .7076 m .28801 .65251 L .25623 .65152 L p .707 .577 .707 r
F P
0 g
s
.70341 .81281 m .69992 .8306 L .69728 .81935 L p .707 .577 .707 r
F P
0 g
s
.69728 .81935 m .70077 .80156 L .70341 .81281 L p .707 .577 .707 r
F P
0 g
s
.28801 .65251 m .28456 .7076 L .3139 .70562 L p .707 .577 .707 r
F P
0 g
s
.3139 .70562 m .31735 .65053 L .28801 .65251 L p .707 .577 .707 r
F P
0 g
s
.41545 .81453 m .40667 .31178 L .37695 .30337 L p .707 .577 .707 r
F P
0 g
s
.40667 .31178 m .41545 .81453 L .4542 .81995 L p .707 .577 .707 r
F P
0 g
s
.22167 .70277 m .22512 .64767 L .19772 .64133 L p .707 .577 .707 r
F P
0 g
s
.22512 .64767 m .22167 .70277 L .25278 .70662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31735 .65053 m .3139 .70562 L .33792 .70087 L p .707 .577 .707 r
F P
0 g
s
.33792 .70087 m .34137 .64577 L .31735 .65053 L p .707 .577 .707 r
F P
0 g
s
.70271 .75468 m .69596 .79034 L .68374 .77838 L p .707 .577 .707 r
F P
0 g
s
.68374 .77838 m .6905 .74272 L .70271 .75468 L p .707 .577 .707 r
F P
0 g
s
.19427 .69642 m .19772 .64133 L .17672 .63311 L p .707 .577 .707 r
F P
0 g
s
.19772 .64133 m .19427 .69642 L .22167 .70277 L p .707 .577 .707 r
F P
0 g
s
.66992 .73113 m .66317 .76679 L .63624 .7567 L p .707 .577 .707 r
F P
0 g
s
.63624 .7567 m .64299 .72104 L .66992 .73113 L p .707 .577 .707 r
F P
0 g
s
.66804 .77769 m .66455 .79548 L .63766 .7852 L p .707 .577 .707 r
F P
0 g
s
.63766 .7852 m .64115 .76741 L .66804 .77769 L p .707 .577 .707 r
F P
0 g
s
.6098 .30364 m .61857 .80639 L .64168 .79586 L p .707 .577 .707 r
F P
0 g
s
.64168 .79586 m .63291 .29311 L .6098 .30364 L p .707 .577 .707 r
F P
0 g
s
.69242 .66399 m .68897 .71908 L .66797 .71087 L p .707 .577 .707 r
F P
0 g
s
.66797 .71087 m .67142 .65577 L .69242 .66399 L p .707 .577 .707 r
F P
0 g
s
.24798 .77743 m .25473 .74177 L .22409 .73417 L p .707 .577 .707 r
F P
0 g
s
.25473 .74177 m .24798 .77743 L .27934 .78179 L p .707 .577 .707 r
F P
0 g
s
.27934 .78179 m .28609 .74613 L .25473 .74177 L p .707 .577 .707 r
F P
0 g
s
.28609 .74613 m .27934 .78179 L .30834 .78249 L p .707 .577 .707 r
F P
0 g
s
.30834 .78249 m .31509 .74683 L .28609 .74613 L p .707 .577 .707 r
F P
0 g
s
.21733 .76983 m .22409 .73417 L .19716 .72408 L p .707 .577 .707 r
F P
0 g
s
.22409 .73417 m .21733 .76983 L .24798 .77743 L p .707 .577 .707 r
F P
0 g
s
.70077 .80156 m .69728 .81935 L .68509 .80725 L p .707 .577 .707 r
F P
0 g
s
.68509 .80725 m .68859 .78946 L .70077 .80156 L p .707 .577 .707 r
F P
0 g
s
.34137 .64577 m .33792 .70087 L .35428 .69381 L p .707 .577 .707 r
F P
0 g
s
.35428 .69381 m .35773 .63871 L .34137 .64577 L p .707 .577 .707 r
F P
0 g
s
.38573 .80612 m .37695 .30337 L .35918 .2928 L p .707 .577 .707 r
F P
0 g
s
.37695 .30337 m .38573 .80612 L .41545 .81453 L p .707 .577 .707 r
F P
0 g
s
.17672 .63311 m .17327 .68821 L .19427 .69642 L p .707 .577 .707 r
F P
0 g
s
.19716 .72408 m .19041 .75974 L .21733 .76983 L p .707 .577 .707 r
F P
0 g
s
.31509 .74683 m .30834 .78249 L .33215 .77946 L p .707 .577 .707 r
F P
0 g
s
.33215 .77946 m .3389 .7438 L .31509 .74683 L p .707 .577 .707 r
F P
0 g
s
.17327 .68821 m .17672 .63311 L .16417 .62383 L p .707 .577 .707 r
F P
0 g
s
.19041 .75974 m .19716 .72408 L .17658 .71249 L p .707 .577 .707 r
F P
0 g
s
.67142 .65577 m .66797 .71087 L .64057 .70452 L p .707 .577 .707 r
F P
0 g
s
.64057 .70452 m .64402 .64943 L .67142 .65577 L p .707 .577 .707 r
F P
0 g
s
.6905 .74272 m .68374 .77838 L .66317 .76679 L p .707 .577 .707 r
F P
0 g
s
.66317 .76679 m .66992 .73113 L .6905 .74272 L p .707 .577 .707 r
F P
0 g
s
.24936 .83341 m .25286 .81561 L .22225 .80782 L p .707 .577 .707 r
F P
0 g
s
.25286 .81561 m .24936 .83341 L .28069 .83794 L p .707 .577 .707 r
F P
0 g
s
.28069 .83794 m .28418 .82015 L .25286 .81561 L p .707 .577 .707 r
F P
0 g
s
.28418 .82015 m .28069 .83794 L .30966 .83878 L p .707 .577 .707 r
F P
0 g
s
.30966 .83878 m .31316 .82098 L .28418 .82015 L p .707 .577 .707 r
F P
0 g
s
.21876 .82561 m .22225 .80782 L .19536 .79754 L p .707 .577 .707 r
F P
0 g
s
.22225 .80782 m .21876 .82561 L .24936 .83341 L p .707 .577 .707 r
F P
0 g
s
.17658 .71249 m .16983 .74815 L .19041 .75974 L p .707 .577 .707 r
F P
0 g
s
.19536 .79754 m .19186 .81533 L .21876 .82561 L p .707 .577 .707 r
F P
0 g
s
.63291 .29311 m .64168 .79586 L .65168 .78418 L p .707 .577 .707 r
F P
0 g
s
.65168 .78418 m .64291 .28143 L .63291 .29311 L p .707 .577 .707 r
F P
0 g
s
.68859 .78946 m .68509 .80725 L .66455 .79548 L p .707 .577 .707 r
F P
0 g
s
.66455 .79548 m .66804 .77769 L .68859 .78946 L p .707 .577 .707 r
F P
0 g
s
.16417 .62383 m .16072 .67893 L .17327 .68821 L p .707 .577 .707 r
F P
0 g
s
.35773 .63871 m .35428 .69381 L .36138 .68514 L p .707 .577 .707 r
F P
0 g
s
.36138 .68514 m .36483 .63004 L .35773 .63871 L p .707 .577 .707 r
F P
0 g
s
.3389 .7438 m .33215 .77946 L .34843 .77299 L p .707 .577 .707 r
F P
0 g
s
.34843 .77299 m .35519 .73733 L .3389 .7438 L p .707 .577 .707 r
F P
0 g
s
.31316 .82098 m .30966 .83878 L .33346 .83584 L p .707 .577 .707 r
F P
0 g
s
.33346 .83584 m .33695 .81804 L .31316 .82098 L p .707 .577 .707 r
F P
0 g
s
.19186 .81533 m .19536 .79754 L .17481 .78577 L p .707 .577 .707 r
F P
0 g
s
.16983 .74815 m .17658 .71249 L .16437 .70053 L p .707 .577 .707 r
F P
0 g
s
.16072 .67893 m .16417 .62383 L .1613 .61439 L p .707 .577 .707 r
F P
0 g
s
.17481 .78577 m .17132 .80357 L .19186 .81533 L p .707 .577 .707 r
F P
0 g
s
.36483 .63004 m .36138 .68514 L .35851 .6757 L p .707 .577 .707 r
F P
0 g
s
.35851 .6757 m .36196 .6206 L .36483 .63004 L p .707 .577 .707 r
F P
0 g
s
.36795 .79555 m .35918 .2928 L .35509 .2811 L p .707 .577 .707 r
F P
0 g
s
.35918 .2928 m .36795 .79555 L .38573 .80612 L p .707 .577 .707 r
F P
0 g
s
.16437 .70053 m .15761 .73619 L .16983 .74815 L p .707 .577 .707 r
F P
0 g
s
.33695 .81804 m .33346 .83584 L .34973 .8294 L p .707 .577 .707 r
F P
0 g
s
.34973 .8294 m .35323 .81161 L .33695 .81804 L p .707 .577 .707 r
F P
0 g
s
.17132 .80357 m .17481 .78577 L .16263 .77367 L p .707 .577 .707 r
F P
0 g
s
.1613 .61439 m .15785 .66949 L .16072 .67893 L p .707 .577 .707 r
F P
0 g
s
.35519 .73733 m .34843 .77299 L .3556 .76373 L p .707 .577 .707 r
F P
0 g
s
.3556 .76373 m .36236 .72806 L .35519 .73733 L p .707 .577 .707 r
F P
0 g
s
.15761 .73619 m .16437 .70053 L .16172 .68937 L p .707 .577 .707 r
F P
0 g
s
.16263 .77367 m .15913 .79146 L .17132 .80357 L p .707 .577 .707 r
F P
0 g
s
.64291 .28143 m .65168 .78418 L .64789 .77331 L p .707 .577 .707 r
F P
0 g
s
.64754 .76699 m .64291 .28143 L .64789 .77331 L .707 .577 .707 r
F
.63882 .26973 m .64291 .28143 L p .64642 .64895 L F P
0 g
s
.6476 .77248 m .64539 .6458 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.64539 .6458 m .63882 .26973 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.63882 .26973 m .6476 .77248 L .62982 .7619 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64152 .57502 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64093 .63955 m .64132 .63339 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64132 .63339 m .64438 .58446 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64458 .64627 m .6418 .66095 L p .65004 .69389 L .707 .577 .707 r
F P
0 g
s
.6418 .66095 m .63783 .68193 L .64322 .68721 L p .707 .577 .707 r
F P
0 g
s
.64322 .68721 m .65004 .69389 L p .6418 .66095 L .707 .577 .707 r
F P
0 g
s
.64789 .77331 m .6476 .77248 L p .64754 .76699 L .707 .577 .707 r
F P
0 g
s
.15785 .66949 m .1613 .61439 L .16839 .60572 L p .707 .577 .707 r
F P
0 g
s
.16172 .68937 m .15496 .72503 L .15761 .73619 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35323 .81161 m .34973 .8294 L .35691 .8201 L p .707 .577 .707 r
F P
0 g
s
.35691 .8201 m .3604 .80231 L .35323 .81161 L p .707 .577 .707 r
F P
0 g
s
.15913 .79146 m .16263 .77367 L .15999 .76242 L p .707 .577 .707 r
F P
0 g
s
.16839 .60572 m .16494 .66081 L .15785 .66949 L p .707 .577 .707 r
F P
0 g
s
.15999 .76242 m .1565 .78021 L .15913 .79146 L p .707 .577 .707 r
F P
0 g
s
.36196 .6206 m .35851 .6757 L .34596 .66642 L p .707 .577 .707 r
F P
0 g
s
.34596 .66642 m .34941 .61132 L .36196 .6206 L p .707 .577 .707 r
F P
0 g
s
.35509 .2811 m .36387 .78385 L .36795 .79555 L p .707 .577 .707 r
F P
0 g
s
.36387 .78385 m .35509 .2811 L .36509 .26941 L p .707 .577 .707 r
F P
0 g
s
.36236 .72806 m .3556 .76373 L .35295 .75256 L p .707 .577 .707 r
F P
0 g
s
.35295 .75256 m .3597 .7169 L .36236 .72806 L p .707 .577 .707 r
F P
0 g
s
.15496 .72503 m .16172 .68937 L .16888 .6801 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16494 .66081 m .16839 .60572 L .18475 .59866 L p .707 .577 .707 r
F P
0 g
s
.16888 .6801 m .16213 .71576 L .15496 .72503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3604 .80231 m .35691 .8201 L .35427 .80886 L p .707 .577 .707 r
F P
0 g
s
.35427 .80886 m .35776 .79106 L .3604 .80231 L p .707 .577 .707 r
F P
0 g
s
.1565 .78021 m .15999 .76242 L .16716 .75312 L p .707 .577 .707 r
F P
0 g
s
.62982 .7619 m .62105 .25916 L .63882 .26973 L p .707 .577 .707 r
F P
0 g
s
.18475 .59866 m .1813 .65375 L .16494 .66081 L p .707 .577 .707 r
F P
0 g
s
.16716 .75312 m .16367 .77092 L .1565 .78021 L p .707 .577 .707 r
F P
0 g
s
.3597 .7169 m .35295 .75256 L .34073 .7406 L p .707 .577 .707 r
F P
0 g
s
.34073 .7406 m .34749 .70494 L .3597 .7169 L p .707 .577 .707 r
F P
0 g
s
.34941 .61132 m .34596 .66642 L .32496 .6582 L p .707 .577 .707 r
F P
0 g
s
.32496 .6582 m .32841 .6031 L .34941 .61132 L p .707 .577 .707 r
F P
0 g
s
.16213 .71576 m .16888 .6801 L .18517 .67364 L p .707 .577 .707 r
F P
0 g
s
.1813 .65375 m .18475 .59866 L .20878 .5939 L p .707 .577 .707 r
F P
0 g
s
.37387 .77216 m .36509 .26941 L .3882 .25889 L p .707 .577 .707 r
F P
0 g
s
.36509 .26941 m .37387 .77216 L .36387 .78385 L p .707 .577 .707 r
F P
0 g
s
.18517 .67364 m .17841 .7093 L .16213 .71576 L p .707 .577 .707 r
F P
0 g
s
.35776 .79106 m .35427 .80886 L .34208 .79675 L p .707 .577 .707 r
F P
0 g
s
.34208 .79675 m .34558 .77896 L .35776 .79106 L p .707 .577 .707 r
F P
0 g
s
.32841 .6031 m .32496 .6582 L .29756 .65186 L p .707 .577 .707 r
F P
0 g
s
.29756 .65186 m .30101 .59676 L .32841 .6031 L p .707 .577 .707 r
F P
0 g
s
.16367 .77092 m .16716 .75312 L .18344 .74669 L p .707 .577 .707 r
F P
0 g
s
.20878 .5939 m .20533 .649 L .1813 .65375 L p .707 .577 .707 r
F P
0 g
s
.34749 .70494 m .34073 .7406 L .32016 .72901 L p .707 .577 .707 r
F P
0 g
s
.32016 .72901 m .32691 .69335 L .34749 .70494 L p .707 .577 .707 r
F P
0 g
s
.20533 .649 m .20878 .5939 L .23812 .59192 L p .707 .577 .707 r
F P
0 g
s
.17841 .7093 m .18517 .67364 L .20898 .6706 L p .707 .577 .707 r
F P
0 g
s
.18344 .74669 m .17995 .76448 L .16367 .77092 L p .707 .577 .707 r
F P
0 g
s
.62105 .25916 m .62982 .7619 L .6001 .7535 L p .707 .577 .707 r
F P
0 g
s
.6001 .7535 m .59133 .25075 L .62105 .25916 L p .707 .577 .707 r
F P
0 g
s
.30101 .59676 m .29756 .65186 L .26645 .648 L p .707 .577 .707 r
F P
0 g
s
.26645 .648 m .2699 .59291 L .30101 .59676 L p .707 .577 .707 r
F P
0 g
s
.23467 .64702 m .23812 .59192 L .2699 .59291 L p .707 .577 .707 r
F P
0 g
s
.23812 .59192 m .23467 .64702 L .20533 .649 L p .707 .577 .707 r
F P
0 g
s
.20898 .6706 m .20222 .70627 L .17841 .7093 L p .707 .577 .707 r
F P
0 g
s
.2699 .59291 m .26645 .648 L .23467 .64702 L p .707 .577 .707 r
F P
0 g
s
.34558 .77896 m .34208 .79675 L .32154 .78499 L p .707 .577 .707 r
F P
0 g
s
.32154 .78499 m .32503 .76719 L .34558 .77896 L p .707 .577 .707 r
F P
0 g
s
.32691 .69335 m .32016 .72901 L .29323 .71892 L p .707 .577 .707 r
F P
0 g
s
.29323 .71892 m .29998 .68326 L .32691 .69335 L p .707 .577 .707 r
F P
0 g
s
.17995 .76448 m .18344 .74669 L .20723 .74375 L p .707 .577 .707 r
F P
0 g
s
.20222 .70627 m .20898 .6706 L .23798 .6713 L p .707 .577 .707 r
F P
0 g
s
.3882 .25889 m .39698 .76164 L .37387 .77216 L p .707 .577 .707 r
F P
0 g
s
.39698 .76164 m .3882 .25889 L .42216 .25055 L p .707 .577 .707 r
F P
0 g
s
.73299 .66725 m .73644 .61215 L .70533 .6083 L p .707 .577 .707 r
F P
0 g
s
.73644 .61215 m .73299 .66725 L .76477 .66823 L p .707 .577 .707 r
F P
0 g
s
.76477 .66823 m .76822 .61314 L .73644 .61215 L p .707 .577 .707 r
F P
0 g
s
.76822 .61314 m .76477 .66823 L .79411 .66625 L p .707 .577 .707 r
F P
0 g
s
.79411 .66625 m .79756 .61115 L .76822 .61314 L p .707 .577 .707 r
F P
0 g
s
.20723 .74375 m .20374 .76154 L .17995 .76448 L p .707 .577 .707 r
F P
0 g
s
.70188 .6634 m .70533 .6083 L .67793 .60195 L p .707 .577 .707 r
F P
0 g
s
.70533 .6083 m .70188 .6634 L .73299 .66725 L p .707 .577 .707 r
F P
0 g
s
.23798 .6713 m .23123 .70696 L .20222 .70627 L p .707 .577 .707 r
F P
0 g
s
.29998 .68326 m .29323 .71892 L .26258 .71133 L p .707 .577 .707 r
F P
0 g
s
.26258 .71133 m .26934 .67566 L .29998 .68326 L p .707 .577 .707 r
F P
0 g
s
.23123 .70696 m .23798 .6713 L .26934 .67566 L p .707 .577 .707 r
F P
0 g
s
.59133 .25075 m .6001 .7535 L .56135 .74808 L p .707 .577 .707 r
F P
0 g
s
.56135 .74808 m .55257 .24533 L .59133 .25075 L p .707 .577 .707 r
F P
0 g
s
.79756 .61115 m .79411 .66625 L .81814 .6615 L p .707 .577 .707 r
F P
0 g
s
.81814 .6615 m .82159 .6064 L .79756 .61115 L p .707 .577 .707 r
F P
0 g
s
.26934 .67566 m .26258 .71133 L .23123 .70696 L p .707 .577 .707 r
F P
0 g
s
.32503 .76719 m .32154 .78499 L .29465 .7747 L p .707 .577 .707 r
F P
0 g
s
.29465 .7747 m .29814 .75691 L .32503 .76719 L p .707 .577 .707 r
F P
0 g
s
.20374 .76154 m .20723 .74375 L .23621 .74458 L p .707 .577 .707 r
F P
0 g
s
.67448 .65705 m .67793 .60195 L .65693 .59374 L p .707 .577 .707 r
F P
0 g
s
.67793 .60195 m .67448 .65705 L .70188 .6634 L p .707 .577 .707 r
F P
0 g
s
.72819 .72317 m .73495 .68751 L .7043 .67991 L p .707 .577 .707 r
F P
0 g
s
.73495 .68751 m .72819 .72317 L .75955 .72753 L p .707 .577 .707 r
F P
0 g
s
.75955 .72753 m .7663 .69187 L .73495 .68751 L p .707 .577 .707 r
F P
0 g
s
.23621 .74458 m .23272 .76238 L .20374 .76154 L p .707 .577 .707 r
F P
0 g
s
.7663 .69187 m .75955 .72753 L .78855 .72823 L p .707 .577 .707 r
F P
0 g
s
.78855 .72823 m .79531 .69257 L .7663 .69187 L p .707 .577 .707 r
F P
0 g
s
.69755 .71557 m .7043 .67991 L .67737 .66982 L p .707 .577 .707 r
F P
0 g
s
.7043 .67991 m .69755 .71557 L .72819 .72317 L p .707 .577 .707 r
F P
0 g
s
.43093 .7533 m .42216 .25055 L .46363 .24522 L p .707 .577 .707 r
F P
0 g
s
.42216 .25055 m .43093 .7533 L .39698 .76164 L p .707 .577 .707 r
F P
0 g
s
.29814 .75691 m .29465 .7747 L .26404 .76691 L p .707 .577 .707 r
F P
0 g
s
.26404 .76691 m .26754 .74912 L .29814 .75691 L p .707 .577 .707 r
F P
0 g
s
.23272 .76238 m .23621 .74458 L .26754 .74912 L p .707 .577 .707 r
F P
0 g
s
.72957 .75186 m .73307 .73407 L .70246 .72628 L p .707 .577 .707 r
F P
0 g
s
.73307 .73407 m .72957 .75186 L .7609 .7564 L p .707 .577 .707 r
F P
0 g
s
.7609 .7564 m .76439 .73861 L .73307 .73407 L p .707 .577 .707 r
F P
0 g
s
.82159 .6064 m .81814 .6615 L .8345 .65444 L p .707 .577 .707 r
F P
0 g
s
.8345 .65444 m .83795 .59934 L .82159 .6064 L p .707 .577 .707 r
F P
0 g
s
.26754 .74912 m .26404 .76691 L .23272 .76238 L p .707 .577 .707 r
F P
0 g
s
.55257 .24533 m .56135 .74808 L .51735 .74617 L p .707 .577 .707 r
F P
0 g
s
.51735 .74617 m .50857 .24342 L .55257 .24533 L p .707 .577 .707 r
F P
0 g
s
.65693 .59374 m .65348 .64884 L .67448 .65705 L p .707 .577 .707 r
F P
0 g
s
.67737 .66982 m .67062 .70548 L .69755 .71557 L p .707 .577 .707 r
F P
0 g
s
.79531 .69257 m .78855 .72823 L .81236 .7252 L p .707 .577 .707 r
F P
0 g
s
.81236 .7252 m .81912 .68953 L .79531 .69257 L p .707 .577 .707 r
F P
0 g
s
.76439 .73861 m .7609 .7564 L .78988 .75724 L p .707 .577 .707 r
F P
0 g
s
.78988 .75724 m .79337 .73944 L .76439 .73861 L p .707 .577 .707 r
F P
0 g
s
.69897 .74407 m .70246 .72628 L .67557 .716 L p .707 .577 .707 r
F P
0 g
s
.70246 .72628 m .69897 .74407 L .72957 .75186 L p .707 .577 .707 r
F P
0 g
s
.67062 .70548 m .67737 .66982 L .6568 .65823 L p .707 .577 .707 r
F P
0 g
s
.47241 .74797 m .46363 .24522 L .50857 .24342 L p .707 .577 .707 r
F P
0 g
s
.46363 .24522 m .47241 .74797 L .43093 .7533 L p .707 .577 .707 r
F P
0 g
s
.65348 .64884 m .65693 .59374 L .64438 .58446 L p .707 .577 .707 r
F P
0 g
s
.67557 .716 m .67208 .73379 L .69897 .74407 L p .707 .577 .707 r
F P
0 g
s
.50857 .24342 m .51735 .74617 L .47241 .74797 L p .707 .577 .707 r
F P
0 g
s
.79337 .73944 m .78988 .75724 L .81367 .7543 L p .707 .577 .707 r
F P
0 g
s
.81367 .7543 m .81716 .7365 L .79337 .73944 L p .707 .577 .707 r
F P
0 g
s
.6568 .65823 m .65004 .69389 L .67062 .70548 L p .707 .577 .707 r
F P
0 g
s
.67208 .73379 m .67557 .716 L .65503 .70423 L p .707 .577 .707 r
F P
0 g
s
.81912 .68953 m .81236 .7252 L .82865 .71873 L p .707 .577 .707 r
F P
0 g
s
.82865 .71873 m .8354 .68307 L .81912 .68953 L p .707 .577 .707 r
F P
0 g
s
.65503 .70423 m .65153 .72202 L .67208 .73379 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64093 .63955 L .65348 .64884 L p .707 .577 .707 r
F P
0 g
s
.65004 .69389 m .6568 .65823 L .64458 .64627 L p .707 .577 .707 r
F P
0 g
s
.83795 .59934 m .8345 .65444 L .84159 .64577 L p .707 .577 .707 r
F P
0 g
s
.84159 .64577 m .84504 .59067 L .83795 .59934 L p .707 .577 .707 r
F P
0 g
s
.81716 .7365 m .81367 .7543 L .82995 .74786 L p .707 .577 .707 r
F P
0 g
s
.82995 .74786 m .83344 .73007 L .81716 .7365 L p .707 .577 .707 r
F P
0 g
s
.65153 .72202 m .65503 .70423 L .64284 .69213 L p .707 .577 .707 r
F P
0 g
s
.64284 .69213 m .63935 .70992 L .65153 .72202 L p .707 .577 .707 r
F P
0 g
s
.8354 .68307 m .82865 .71873 L .83582 .70946 L p .707 .577 .707 r
F P
0 g
s
.83582 .70946 m .84257 .6738 L .8354 .68307 L p .707 .577 .707 r
F P
0 g
s
.64152 .57502 m .63807 .63011 L .64093 .63955 L p .707 .577 .707 r
F P
0 g
s
.63783 .68193 m .64458 .64627 L .64193 .63511 L p .707 .577 .707 r
F P
0 g
s
.84504 .59067 m .84159 .64577 L .83872 .63633 L p .707 .577 .707 r
F P
0 g
s
.83872 .63633 m .84217 .58123 L .84504 .59067 L p .707 .577 .707 r
F P
0 g
s
.83344 .73007 m .82995 .74786 L .83712 .73856 L p .707 .577 .707 r
F P
0 g
s
.83712 .73856 m .84061 .72077 L .83344 .73007 L p .707 .577 .707 r
F P
0 g
s
.64193 .63511 m .63517 .67077 L .63783 .68193 L p .707 .577 .707 r
F P
0 g
s
.63807 .63011 m .64152 .57502 L .64861 .56634 L p .707 .577 .707 r
F P
0 g
s
.63935 .70992 m .64284 .69213 L .6402 .68088 L p .707 .577 .707 r
F P
0 g
s
.6402 .68088 m .63671 .69867 L .63935 .70992 L p .707 .577 .707 r
F P
0 g
s
.84257 .6738 m .83582 .70946 L .83316 .6983 L p .707 .577 .707 r
F P
0 g
s
.83316 .6983 m .83992 .66264 L .84257 .6738 L p .707 .577 .707 r
F P
0 g
s
.63517 .67077 m .64193 .63511 L .6491 .62584 L p .707 .577 .707 r
F P
0 g
s
.64861 .56634 m .64516 .62144 L .63807 .63011 L p .707 .577 .707 r
F P
0 g
s
.84217 .58123 m .83872 .63633 L .82617 .62704 L p .707 .577 .707 r
F P
0 g
s
.82617 .62704 m .82962 .57195 L .84217 .58123 L p .707 .577 .707 r
F P
0 g
s
.38998 .61458 m .39343 .55948 L .36232 .55563 L p .707 .577 .707 r
F P
0 g
s
.39343 .55948 m .38998 .61458 L .42176 .61556 L p .707 .577 .707 r
F P
0 g
s
.42176 .61556 m .42521 .56047 L .39343 .55948 L p .707 .577 .707 r
F P
0 g
s
.84061 .72077 m .83712 .73856 L .83449 .72731 L p .707 .577 .707 r
F P
0 g
s
.83449 .72731 m .83798 .70952 L .84061 .72077 L p .707 .577 .707 r
F P
0 g
s
.42521 .56047 m .42176 .61556 L .4511 .61358 L p .707 .577 .707 r
F P
0 g
s
.4511 .61358 m .45455 .55849 L .42521 .56047 L p .707 .577 .707 r
F P
0 g
s
.6491 .62584 m .64234 .6615 L .63517 .67077 L p .707 .577 .707 r
F P
0 g
s
.64516 .62144 m .64861 .56634 L .66497 .55929 L p .707 .577 .707 r
F P
0 g
s
.63671 .69867 m .6402 .68088 L .64738 .67158 L p .707 .577 .707 r
F P
0 g
s
.35887 .61073 m .36232 .55563 L .33492 .54929 L p .707 .577 .707 r
F P
0 g
s
.36232 .55563 m .35887 .61073 L .38998 .61458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64738 .67158 m .64388 .68938 L .63671 .69867 L p .707 .577 .707 r
F P
0 g
s
.45455 .55849 m .4511 .61358 L .47513 .60883 L p .707 .577 .707 r
F P
0 g
s
.47513 .60883 m .47858 .55373 L .45455 .55849 L p .707 .577 .707 r
F P
0 g
s
.83992 .66264 m .83316 .6983 L .82095 .68634 L p .707 .577 .707 r
F P
0 g
s
.82095 .68634 m .8277 .65068 L .83992 .66264 L p .707 .577 .707 r
F P
0 g
s
.64234 .6615 m .6491 .62584 L .66538 .61937 L p .707 .577 .707 r
F P
0 g
s
.66497 .55929 m .66152 .61438 L .64516 .62144 L p .707 .577 .707 r
F P
0 g
s
.33147 .60438 m .33492 .54929 L .31392 .54107 L p .707 .577 .707 r
F P
0 g
s
.33492 .54929 m .33147 .60438 L .35887 .61073 L p .707 .577 .707 r
F P
0 g
s
.82962 .57195 m .82617 .62704 L .80517 .61883 L p .707 .577 .707 r
F P
0 g
s
.80517 .61883 m .80862 .56373 L .82962 .57195 L p .707 .577 .707 r
F P
0 g
s
.38518 .68539 m .39194 .64973 L .36129 .64213 L p .707 .577 .707 r
F P
0 g
s
.39194 .64973 m .38518 .68539 L .41654 .68975 L p .707 .577 .707 r
F P
0 g
s
.41654 .68975 m .42329 .65409 L .39194 .64973 L p .707 .577 .707 r
F P
0 g
s
.42329 .65409 m .41654 .68975 L .44554 .69045 L p .707 .577 .707 r
F P
0 g
s
.44554 .69045 m .4523 .65479 L .42329 .65409 L p .707 .577 .707 r
F P
0 g
s
.35454 .67779 m .36129 .64213 L .33436 .63204 L p .707 .577 .707 r
F P
0 g
s
.36129 .64213 m .35454 .67779 L .38518 .68539 L p .707 .577 .707 r
F P
0 g
s
.66152 .61438 m .66497 .55929 L .68899 .55453 L p .707 .577 .707 r
F P
0 g
s
.83798 .70952 m .83449 .72731 L .8223 .71521 L p .707 .577 .707 r
F P
0 g
s
.8223 .71521 m .82579 .69742 L .83798 .70952 L p .707 .577 .707 r
F P
0 g
s
.66538 .61937 m .65863 .65504 L .64234 .6615 L p .707 .577 .707 r
F P
0 g
s
.64388 .68938 m .64738 .67158 L .66366 .66515 L p .707 .577 .707 r
F P
0 g
s
.47858 .55373 m .47513 .60883 L .49149 .60177 L p .707 .577 .707 r
F P
0 g
s
.49149 .60177 m .49494 .54668 L .47858 .55373 L p .707 .577 .707 r
F P
0 g
s
.31392 .54107 m .31047 .59617 L .33147 .60438 L p .707 .577 .707 r
F P
0 g
s
.66366 .66515 m .66016 .68294 L .64388 .68938 L p .707 .577 .707 r
F P
0 g
s
.33436 .63204 m .32761 .66771 L .35454 .67779 L p .707 .577 .707 r
F P
0 g
s
.4523 .65479 m .44554 .69045 L .46935 .68742 L p .707 .577 .707 r
F P
0 g
s
.46935 .68742 m .47611 .65176 L .4523 .65479 L p .707 .577 .707 r
F P
0 g
s
.31047 .59617 m .31392 .54107 L .30137 .53179 L p .707 .577 .707 r
F P
0 g
s
.32761 .66771 m .33436 .63204 L .31379 .62045 L p .707 .577 .707 r
F P
0 g
s
.80862 .56373 m .80517 .61883 L .77777 .61249 L p .707 .577 .707 r
F P
0 g
s
.77777 .61249 m .78122 .55739 L .80862 .56373 L p .707 .577 .707 r
F P
0 g
s
.8277 .65068 m .82095 .68634 L .80037 .67475 L p .707 .577 .707 r
F P
0 g
s
.80037 .67475 m .80713 .63909 L .8277 .65068 L p .707 .577 .707 r
F P
0 g
s
.38656 .74137 m .39006 .72357 L .35945 .71578 L p .707 .577 .707 r
F P
0 g
s
.39006 .72357 m .38656 .74137 L .41789 .7459 L p .707 .577 .707 r
F P
0 g
s
.41789 .7459 m .42138 .72811 L .39006 .72357 L p .707 .577 .707 r
F P
0 g
s
.65863 .65504 m .66538 .61937 L .68919 .61634 L p .707 .577 .707 r
F P
0 g
s
.68899 .55453 m .68554 .60963 L .66152 .61438 L p .707 .577 .707 r
F P
0 g
s
.42138 .72811 m .41789 .7459 L .44687 .74674 L p .707 .577 .707 r
F P
0 g
s
.44687 .74674 m .45036 .72895 L .42138 .72811 L p .707 .577 .707 r
F P
0 g
s
.68554 .60963 m .68899 .55453 L .71833 .55255 L p .707 .577 .707 r
F P
0 g
s
.35596 .73358 m .35945 .71578 L .33256 .7055 L p .707 .577 .707 r
F P
0 g
s
.35945 .71578 m .35596 .73358 L .38656 .74137 L p .707 .577 .707 r
F P
0 g
s
.31379 .62045 m .30703 .65611 L .32761 .66771 L p .707 .577 .707 r
F P
0 g
s
.33256 .7055 m .32907 .72329 L .35596 .73358 L p .707 .577 .707 r
F P
0 g
s
.82579 .69742 m .8223 .71521 L .80175 .70345 L p .707 .577 .707 r
F P
0 g
s
.80175 .70345 m .80525 .68565 L .82579 .69742 L p .707 .577 .707 r
F P
0 g
s
.68919 .61634 m .68244 .652 L .65863 .65504 L p .707 .577 .707 r
F P
0 g
s
.30137 .53179 m .29792 .58689 L .31047 .59617 L p .707 .577 .707 r
F P
0 g
s
.66016 .68294 m .66366 .66515 L .68745 .6622 L p .707 .577 .707 r
F P
0 g
s
.78122 .55739 m .77777 .61249 L .74666 .60863 L p .707 .577 .707 r
F P
0 g
s
.74666 .60863 m .75011 .55354 L .78122 .55739 L p .707 .577 .707 r
F P
0 g
s
.49494 .54668 m .49149 .60177 L .49858 .5931 L p .707 .577 .707 r
F P
0 g
s
.49858 .5931 m .50203 .538 L .49494 .54668 L p .707 .577 .707 r
F P
0 g
s
.71488 .60765 m .71833 .55255 L .75011 .55354 L p .707 .577 .707 r
F P
0 g
s
.71833 .55255 m .71488 .60765 L .68554 .60963 L p .707 .577 .707 r
F P
0 g
s
.47611 .65176 m .46935 .68742 L .48564 .68095 L p .707 .577 .707 r
F P
0 g
s
.48564 .68095 m .49239 .64529 L .47611 .65176 L p .707 .577 .707 r
F P
0 g
s
.45036 .72895 m .44687 .74674 L .47066 .7438 L p .707 .577 .707 r
F P
0 g
s
.47066 .7438 m .47415 .726 L .45036 .72895 L p .707 .577 .707 r
F P
0 g
s
.32907 .72329 m .33256 .7055 L .31202 .69373 L p .707 .577 .707 r
F P
0 g
s
.30703 .65611 m .31379 .62045 L .30157 .60849 L p .707 .577 .707 r
F P
0 g
s
.75011 .55354 m .74666 .60863 L .71488 .60765 L p .707 .577 .707 r
F P
0 g
s
.68745 .6622 m .68395 .68 L .66016 .68294 L p .707 .577 .707 r
F P
0 g
s
.80713 .63909 m .80037 .67475 L .77344 .66466 L p .707 .577 .707 r
F P
0 g
s
.77344 .66466 m .7802 .629 L .80713 .63909 L p .707 .577 .707 r
F P
0 g
s
.68244 .652 m .68919 .61634 L .71819 .61704 L p .707 .577 .707 r
F P
0 g
s
.29792 .58689 m .30137 .53179 L .2985 .52235 L p .707 .577 .707 r
F P
0 g
s
.31202 .69373 m .30852 .71153 L .32907 .72329 L p .707 .577 .707 r
F P
0 g
s
.30157 .60849 m .29482 .64415 L .30703 .65611 L p .707 .577 .707 r
F P
0 g
s
.80525 .68565 m .80175 .70345 L .77486 .69316 L p .707 .577 .707 r
F P
0 g
s
.77486 .69316 m .77836 .67537 L .80525 .68565 L p .707 .577 .707 r
F P
0 g
s
.71819 .61704 m .71144 .6527 L .68244 .652 L p .707 .577 .707 r
F P
0 g
s
.7802 .629 m .77344 .66466 L .7428 .65706 L p .707 .577 .707 r
F P
0 g
s
.7428 .65706 m .74955 .6214 L .7802 .629 L p .707 .577 .707 r
F P
0 g
s
.71144 .6527 m .71819 .61704 L .74955 .6214 L p .707 .577 .707 r
F P
0 g
s
.68395 .68 m .68745 .6622 L .71643 .66304 L p .707 .577 .707 r
F P
0 g
s
.47415 .726 m .47066 .7438 L .48694 .73736 L p .707 .577 .707 r
F P
0 g
s
.48694 .73736 m .49043 .71957 L .47415 .726 L p .707 .577 .707 r
F P
0 g
s
.74955 .6214 m .7428 .65706 L .71144 .6527 L p .707 .577 .707 r
F P
0 g
s
.30852 .71153 m .31202 .69373 L .29983 .68163 L p .707 .577 .707 r
F P
0 g
s
.71643 .66304 m .71293 .68084 L .68395 .68 L p .707 .577 .707 r
F P
0 g
s
.2985 .52235 m .29505 .57745 L .29792 .58689 L p .707 .577 .707 r
F P
0 g
s
.49239 .64529 m .48564 .68095 L .49281 .67169 L p .707 .577 .707 r
F P
0 g
s
.49281 .67169 m .49956 .63603 L .49239 .64529 L p .707 .577 .707 r
F P
0 g
s
.50203 .538 m .49858 .5931 L .49571 .58366 L p .707 .577 .707 r
F P
0 g
s
.49571 .58366 m .49916 .52856 L .50203 .538 L p .707 .577 .707 r
F P
0 g
s
.29482 .64415 m .30157 .60849 L .29892 .59733 L p .707 .577 .707 r
F P
0 g
s
.29983 .68163 m .29634 .69943 L .30852 .71153 L p .707 .577 .707 r
F P
0 g
s
.77836 .67537 m .77486 .69316 L .74426 .68537 L p .707 .577 .707 r
F P
0 g
s
.74426 .68537 m .74775 .66758 L .77836 .67537 L p .707 .577 .707 r
F P
0 g
s
.71293 .68084 m .71643 .66304 L .74775 .66758 L p .707 .577 .707 r
F P
0 g
s
.74775 .66758 m .74426 .68537 L .71293 .68084 L p .707 .577 .707 r
F P
0 g
s
.29505 .57745 m .2985 .52235 L .3056 .51368 L p .707 .577 .707 r
F P
0 g
s
.29892 .59733 m .29216 .63299 L .29482 .64415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49043 .71957 m .48694 .73736 L .49411 .72807 L p .707 .577 .707 r
F P
0 g
s
.49411 .72807 m .4976 .71027 L .49043 .71957 L p .707 .577 .707 r
F P
0 g
s
.29634 .69943 m .29983 .68163 L .29719 .67038 L p .707 .577 .707 r
F P
0 g
s
.3056 .51368 m .30215 .56877 L .29505 .57745 L p .707 .577 .707 r
F P
0 g
s
.29719 .67038 m .2937 .68818 L .29634 .69943 L p .707 .577 .707 r
F P
0 g
s
.49956 .63603 m .49281 .67169 L .49015 .66053 L p .707 .577 .707 r
F P
0 g
s
.49015 .66053 m .49691 .62487 L .49956 .63603 L p .707 .577 .707 r
F P
0 g
s
.29216 .63299 m .29892 .59733 L .30609 .58806 L p .707 .577 .707 r
F P
0 g
s
.49916 .52856 m .49571 .58366 L .48316 .57438 L p .707 .577 .707 r
F P
0 g
s
.48316 .57438 m .48661 .51928 L .49916 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30215 .56877 m .3056 .51368 L .32196 .50662 L p .707 .577 .707 r
F P
0 g
s
.30609 .58806 m .29933 .62372 L .29216 .63299 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4976 .71027 m .49411 .72807 L .49147 .71682 L p .707 .577 .707 r
F P
0 g
s
.49147 .71682 m .49497 .69902 L .4976 .71027 L p .707 .577 .707 r
F P
0 g
s
.2937 .68818 m .29719 .67038 L .30437 .66108 L p .707 .577 .707 r
F P
0 g
s
.32196 .50662 m .31851 .56171 L .30215 .56877 L p .707 .577 .707 r
F P
0 g
s
.30437 .66108 m .30087 .67888 L .2937 .68818 L p .707 .577 .707 r
F P
0 g
s
.49691 .62487 m .49015 .66053 L .47794 .64856 L p .707 .577 .707 r
F P
0 g
s
.47794 .64856 m .48469 .6129 L .49691 .62487 L p .707 .577 .707 r
F P
0 g
s
.48661 .51928 m .48316 .57438 L .46216 .56616 L p .707 .577 .707 r
F P
0 g
s
.46216 .56616 m .46561 .51107 L .48661 .51928 L p .707 .577 .707 r
F P
0 g
s
.29933 .62372 m .30609 .58806 L .32237 .5816 L p .707 .577 .707 r
F P
0 g
s
.31851 .56171 m .32196 .50662 L .34598 .50187 L p .707 .577 .707 r
F P
0 g
s
.32237 .5816 m .31562 .61726 L .29933 .62372 L p .707 .577 .707 r
F P
0 g
s
.49497 .69902 m .49147 .71682 L .47929 .70472 L p .707 .577 .707 r
F P
0 g
s
.47929 .70472 m .48278 .68692 L .49497 .69902 L p .707 .577 .707 r
F P
0 g
s
.46561 .51107 m .46216 .56616 L .43476 .55982 L p .707 .577 .707 r
F P
0 g
s
.43476 .55982 m .43821 .50472 L .46561 .51107 L p .707 .577 .707 r
F P
0 g
s
.30087 .67888 m .30437 .66108 L .32065 .65465 L p .707 .577 .707 r
F P
0 g
s
.34598 .50187 m .34253 .55696 L .31851 .56171 L p .707 .577 .707 r
F P
0 g
s
.48469 .6129 m .47794 .64856 L .45736 .63697 L p .707 .577 .707 r
F P
0 g
s
.45736 .63697 m .46411 .60131 L .48469 .6129 L p .707 .577 .707 r
F P
0 g
s
.34253 .55696 m .34598 .50187 L .37532 .49988 L p .707 .577 .707 r
F P
0 g
s
.31562 .61726 m .32237 .5816 L .34618 .57857 L p .707 .577 .707 r
F P
0 g
s
.32065 .65465 m .31715 .67244 L .30087 .67888 L p .707 .577 .707 r
F P
0 g
s
.43821 .50472 m .43476 .55982 L .40365 .55596 L p .707 .577 .707 r
F P
0 g
s
.40365 .55596 m .4071 .50087 L .43821 .50472 L p .707 .577 .707 r
F P
0 g
s
.37187 .55498 m .37532 .49988 L .4071 .50087 L p .707 .577 .707 r
F P
0 g
s
.37532 .49988 m .37187 .55498 L .34253 .55696 L p .707 .577 .707 r
F P
0 g
s
.34618 .57857 m .33943 .61423 L .31562 .61726 L p .707 .577 .707 r
F P
0 g
s
.4071 .50087 m .40365 .55596 L .37187 .55498 L p .707 .577 .707 r
F P
0 g
s
.48278 .68692 m .47929 .70472 L .45874 .69295 L p .707 .577 .707 r
F P
0 g
s
.45874 .69295 m .46224 .67515 L .48278 .68692 L p .707 .577 .707 r
F P
0 g
s
.46411 .60131 m .45736 .63697 L .43043 .62688 L p .707 .577 .707 r
F P
0 g
s
.43043 .62688 m .43719 .59122 L .46411 .60131 L p .707 .577 .707 r
F P
0 g
s
.31715 .67244 m .32065 .65465 L .34444 .65171 L p .707 .577 .707 r
F P
0 g
s
.33943 .61423 m .34618 .57857 L .37518 .57926 L p .707 .577 .707 r
F P
0 g
s
.34444 .65171 m .34094 .6695 L .31715 .67244 L p .707 .577 .707 r
F P
0 g
s
.37518 .57926 m .36843 .61493 L .33943 .61423 L p .707 .577 .707 r
F P
0 g
s
.43719 .59122 m .43043 .62688 L .39979 .61929 L p .707 .577 .707 r
F P
0 g
s
.39979 .61929 m .40654 .58363 L .43719 .59122 L p .707 .577 .707 r
F P
0 g
s
.36843 .61493 m .37518 .57926 L .40654 .58363 L p .707 .577 .707 r
F P
0 g
s
.40654 .58363 m .39979 .61929 L .36843 .61493 L p .707 .577 .707 r
F P
0 g
s
.46224 .67515 m .45874 .69295 L .43185 .68267 L p .707 .577 .707 r
F P
0 g
s
.43185 .68267 m .43535 .66487 L .46224 .67515 L p .707 .577 .707 r
F P
0 g
s
.34094 .6695 m .34444 .65171 L .37341 .65255 L p .707 .577 .707 r
F P
0 g
s
.37341 .65255 m .36992 .67034 L .34094 .6695 L p .707 .577 .707 r
F P
0 g
s
.43535 .66487 m .43185 .68267 L .40125 .67488 L p .707 .577 .707 r
F P
0 g
s
.40125 .67488 m .40474 .65708 L .43535 .66487 L p .707 .577 .707 r
F P
0 g
s
.36992 .67034 m .37341 .65255 L .40474 .65708 L p .707 .577 .707 r
F P
0 g
s
.40474 .65708 m .40125 .67488 L .36992 .67034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7`00OGoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Ioo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00LGoo1@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000
0`00Kgoo001]Ool40007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH3001/Ool006]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUIVOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol0065ooaL00003FUH005YF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00GGoo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001JOol30005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qo
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001U
Ool005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001D
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Goo6000@goo
001COol00`00FUH00004FUH01000FUIJEUYF3@000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000mOol0
05=oo`03001JEP0000=JEPD00003FUH005YF00EJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=J
EP06001JEUYF001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000`00>Goo001COol01000FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001Goo000005YF00001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00=Woo001COol01P00FUH0
0000FUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP@000AJEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003=oo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01UYF00@005YFFUIJEP<00004FUH005YFFUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<7oo001COol20003
FUH00`00FUIJEP03FUHB0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEP00000^Ool005=oo`8000=JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYFFUH40006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo001EOol01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool003YooaL000Aoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YF00000P001UYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000c
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF
00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000/Ool0035oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP05001JEUYF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00;goo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEPd000=oo`T000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00
FUIJEP02FUHD0003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF1@001EYF00@005YF0000009JEP03001JEP0000<0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYF001JEP00FUH00P001EYF4P0025YF00<005YFFUH015YF10001EYF00@005YFFUIJEP8002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF001JEP<000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50006
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUH005YF00<00003FUH0000000@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP000002FUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000AJEP000000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000MJEP03001J
EUYF009JEP800003FUH005YF009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P001EYF00@005YF
FUH0009JEP03001JEUYF00=JEP<000IJEP@000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001JEUYF
00AJEP8000=JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF0`000UYF00@005YFFUH0009JEP03
001JEUYF009JEPD000MJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP040003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP05001J
EP00001JEP02000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEP000080009JEP04001JEUYF0004FUH5
0007FUH01000FUIJEUYF0`0000=JEP00FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00UYF0`00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000AJEPD000MJ
EP03001JEUYF00AJEP8000EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH015YF1@001EYF0`0025YF00<005YFFUH01UYF
0P000UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00IJEP@000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH025YF
0`0015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF00<005YF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF6@00
15YF00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD000QJEP03001JEUYF00QJEP03
001JEP0000AJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH500000eYF001J
EP06FUH01000FUIJEUYF50001UYF4P000UYF100015YF00<005YFFUH01eYF1@000UYF00<005YF0000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000
FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002io
o`00;7oo00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001JEUYF
009JEP80009JEPD0009JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH0000000`000=JEP03
001JEP0000800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF008000=JEPL000IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<002moo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000EJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEP00001JEP001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP<000=JEP03001JEP0000@0009JEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
02moo`00;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@001EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJ
EP<000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P000UYF0`0000=JEP00FUH04@001UYF0`0000=J
EP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF0`001UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00AJEP04001JEUYF
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH6
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH40006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH?0002FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUH000030005FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH005YF
0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00002P000UYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH010000eYF00<005YFFUH01EYF
00<005YFFUH010001eYF00<005YFFUH00P000eYF1@000UYF0`0000=JEP00FUH025YF1P001eYF00<0
05YFFUH00eYF0`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH30005Ool30006FUH01P00FUIJEP00FUH002eoo`00;Goo00@005YFFUIJ
EP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00800005FUH00000FUH0
0005FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP06FUH40003FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200001EYF001JEUYF
00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001Goo0P0015YF00H005YF
FUH005YF000]Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00D00003FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH70002FUH0
0`00FUH000020004FUH300000eYF001JEP07FUH01000FUIJEP000UYF0P0025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP07FUH00`00FUH000030003Ool01000FUIJEP000eYF00<005YF0000;Goo000^Ool30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP00009JEP03001JEP0000L000=JEP03001JEUYF00<000IJEP03001J
EUYF009JEP8000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH50008FUH00`00FUH0000300000goo000000040008FUH00`00FUIJEP03FUH20002Ool30003
FUH2000^Ool002ioo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000@000IJEP04001JEUYFFUH30002FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF
00=JEPX000AJEP03001JEUYF00EJEP<0009oo`04001JEUYFFUH2000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP04001J
EP000005FUH01000FUIJEUYF0`000eYF00@005YFFUIJEPD00003FUH0000000/00003FUH005YF00EJ
EP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF00@00004
FUH005YF000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH20003FUH01`00FUIJEUYF001oo`0000=JEP03
001JEUYF009JEP<000QJEP03001JEUYF00AJEP8000IJEP03001JEP0000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEPH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF009JEP800005FUH00000FUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300001eYF00000000FUH005YF0080009oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00`000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00D005YF001JEP0002ioo`00;Goo00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00P000UYF0`001Goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF
0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`000eYF00H005YF000005YF0008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH200000eYF001JEP05FUH4000_Ool002eoo`03001JEP00009JEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH300000eYF00000004Ool3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30003FUH20005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP030007FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30006FUH01000FUH00000;goo000/Ool00`00FUH00003FUH40007
Ool90004FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YF00000`000goo0eYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF000015YF10000UYF0P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<007ooOol0
;7oo000/Ool01000FUH005YF0`004goo1`001UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH40000
1GooFUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJ
EP020003FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00Oomoo`0/Ool002aoo`04001JEP000002FUH3000HOol40002FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP<00003FUH005YF00<000IJEP03001JEUYF00<000AJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001oogoo02aoo`00;7oo0P0015YF00<005YF
FUH00P006Woo10001EYF0P0000=JEP00FUH01eYF00<005YF00000`0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000IJEP04001JEP000003FUH50002FUH00`00FUH000040002FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00;Woo000/Ool20003FUH00`00FUIJEP03
FUH3000>Ool3000:Ool20004FUH40007FUH00`00FUIJEP03FUH50009FUH00`00FUIJEP09FUH01@00
FUH00000FUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF00@005YFFUIJEP800003FUH0000000=oo`T0009JEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEP00001oo`04000^Ool002aoo`8000=JEP03001JEUYF00AJEP04001JEP00000;Ool5
000;Ool300000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJ
EP07FUH40003FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH40006Ool<0004FUH01000FUIJEUYF10001Goo0P00;Woo000/
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P002Goo1@003Woo0P001EYF0`0000=J
EP00FUH01eYF00<005YFFUH015YF3`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP06FUH00`00
FUIJEP040003Ool30008Ool80008Ool2000_Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00AJEP@000Eoo`D0011oo`80009JEP04001JEUYFFUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`001UYF00<005YFFUH015YF1@005goo1000;goo
000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool3000C
Ool30004FUH00`00FUH000030002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF0P00
;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH015YF1@005Goo00<005YFFUH0
0UYF0P000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP<0
0003FUH005YF00QJEP03001JEUYF00AJEPh000=JEP06001JEUYF001JEP00;goo000^Ool30006FUH?
0002FUH00`00FUIJEP04000>Ool50002FUH00`00FUH00003FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00<005YFFUH015YF1@001UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P00<7oo000`Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH0
0`00FUIJEP040005FUH>0003FUH00`00FUH0000200000eYF001JEP02FUH00`00FUIJEP03FUH01000
FUIJEUYF3`0000=JEP000000700025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF
FUH015YF0`000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00035oo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH015YF10000eYF
00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF00001Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000039oo`00;goo0P000eYF00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YF00000`001eYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEP0000@000IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=J
EP05001JEUYFFUH0000:Ool40002FUH00`00FUIJEP05FUH01000FUIJEUYF1@00=7oo000^Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000EooeYFFUIJEP0000EJEP03001JEUYF00D000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000>Ool>000iOol002eoo`03001JEP0000=JEP04001J
EUYFFUH>0006FUH00`00FUIJEP06FUH00`00FUH000020006FUH02000FUIJEUYF001JEP00Ool3FUH0
0`00FUIJEP03FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00E7oo000]Ool20003FUH500000goo0000000200000eYF001JEP06FUH40002FUH00`00FUIJEP06
FUH01000FUIJEUYF0`0015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP<00003FUH005YF00EJEP06001JEUYF001JEP00E7oo000]Ool200000eYF0000
000:Ool30008FUH00`00FUH000030006FUH00`00FUIJEP05FUH20002FUH01000FUIJEUYF0P000Woo
0eYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH007oo008000IJEP06001JEUYF001JEP00
E7oo000/Ool01000FUH000003goo0`0015YF00<005YF00000P000UYF10000UYF00<005YFFUH01UYF
0`000eYF0P000goo0eYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=oo`8000=J
EP07001JEUYFFUH005YF0000E7oo000/Ool4000BOol300000eYF000000040003FUH00`00FUH00003
0007FUH00`00FUIJEP030005Ool2FUH01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0`000goo0P0000=JEP00FUH00UYF0P00EGoo000/Ool01000FUH000005Goo1`000eYF00<005YFFUH0
0eYF0P0015YF00<005YFFUH00eYF0P0017oo00=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00@005YFFUH0009JEP8000=oo`8000=JEP8005Eoo`00;7oo0P000UYF00<007ooOol057oo4`00
00=JEP00FUH01EYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000=J
EPL00004FUH005YF001EOol002aoo`8000=JEP03001oogoo01Aoo`<000moo`8000IJEP03001JEP00
009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF0080009J
EP800003FUH007oo05Aoo`00;Goo00@005YFFUIJEP<002Qoo`8000=JEP06001JEUYFFUH007oo0P00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0P0000AJEP00FUH005Eo
o`00;Goo00D005YFFUIJEP00009JEP8002Qoo`800003FUH005YF009JEP04001oogoo0004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200001EYF000005YF00001UYF1000EWoo000^Ool00`00FUH00005
FUH3000WOol20003FUH01000Oomoo`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF0`00
1UYF00@005YF000005Ioo`00;goo0P001UYF00@005YF000002Moo`05001JEP00FUH00002Ool20002
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<0
07ooOol0Dgoo000`Ool00`00FUIJEP04FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool00goo0`00
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF009JEP800003FUH005YF00=JEP03001oogoo05=oo`00<Goo
0P000eYF00<005YFFUH01EYF0`008goo00<005YF00001Woo0`001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@0025YF00<005YFFUH00eYF
0`0015YF00<007ooOol0Dgoo000cOol200000eYF001JEP07FUH00`00FUH00003000NOol200000eYF
001oo`08Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00
EGoo000eOol30007FUH00`00FUIJEP03FUH5000GOol200000eYF0000000>Ool50008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH:0002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH00000Ool01000EGoo000hOol20004FUH00`00FUIJEP06FUH00`00FUIJEP04000?Ool40003
FUH2000COol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@000UYF
00<005YFFUH01UYF00@005YFFUIJEP@000Eoo`8005Eoo`00>Woo0`0000=JEP00FUH01eYF00<005YF
FUH015YF3`000UYF00L005YFFUIJEP00FUH0000IOolO0002FUH00`00FUIJEP040002OolD0008Ool3
001EOol003eoo`<000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
FUH2000bOol30006FUH00`00FUIJEP04FUH6000FOol4001FOol0041oo`@0009JEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000fOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP04000>Ool50002FUH2001FOol004Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00000jOol200000eYF001JEP08FUH00`00FUIJEP04FUH>0003FUH01P00FUIJEP00FUH0
05Ioo`00BGoo10000UYF00<005YFFUH01UYF00@005YFFUIJEP@003ioo`@000IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Moo`00CGoo3`00AWoo10000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0005Qoo`00YWoo1@001UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Uoo`00Zgoo10000UYF00<005YFFUH01EYF
00@005YFFUIJEPD005]oo`00[goo3P00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59635 .73958 m .5929 .68374 L .56178 .6838 L p .707 .577 .707 r
F P
0 g
s
.5929 .68374 m .59635 .73958 L .62813 .73703 L p .707 .577 .707 r
F P
0 g
s
.62813 .73703 m .62468 .68119 L .5929 .68374 L p .707 .577 .707 r
F P
0 g
s
.62468 .68119 m .62813 .73703 L .65746 .73224 L p .707 .577 .707 r
F P
0 g
s
.65746 .73224 m .65401 .6764 L .62468 .68119 L p .707 .577 .707 r
F P
0 g
s
.56523 .73964 m .56178 .6838 L .53439 .68138 L p .707 .577 .707 r
F P
0 g
s
.56178 .6838 m .56523 .73964 L .59635 .73958 L p .707 .577 .707 r
F P
0 g
s
.65401 .6764 m .65746 .73224 L .68149 .72569 L p .707 .577 .707 r
F P
0 g
s
.68149 .72569 m .67804 .66985 L .65401 .6764 L p .707 .577 .707 r
F P
0 g
s
.53439 .68138 m .53784 .73721 L .56523 .73964 L p .707 .577 .707 r
F P
0 g
s
.60021 .80373 m .59345 .76662 L .56281 .77053 L p .707 .577 .707 r
F P
0 g
s
.59345 .76662 m .60021 .80373 L .63157 .79771 L p .707 .577 .707 r
F P
0 g
s
.63157 .79771 m .62481 .7606 L .59345 .76662 L p .707 .577 .707 r
F P
0 g
s
.53784 .73721 m .53439 .68138 L .51339 .6767 L p .707 .577 .707 r
F P
0 g
s
.62481 .7606 m .63157 .79771 L .66057 .79017 L p .707 .577 .707 r
F P
0 g
s
.66057 .79017 m .65382 .75306 L .62481 .7606 L p .707 .577 .707 r
F P
0 g
s
.56281 .77053 m .56957 .80764 L .60021 .80373 L p .707 .577 .707 r
F P
0 g
s
.56957 .80764 m .56281 .77053 L .53588 .77194 L p .707 .577 .707 r
F P
0 g
s
.67804 .66985 m .68149 .72569 L .69785 .71801 L p .707 .577 .707 r
F P
0 g
s
.69785 .71801 m .6944 .66217 L .67804 .66985 L p .707 .577 .707 r
F P
0 g
s
.65382 .75306 m .66057 .79017 L .68438 .78185 L p .707 .577 .707 r
F P
0 g
s
.68438 .78185 m .67763 .74474 L .65382 .75306 L p .707 .577 .707 r
F P
0 g
s
.51339 .6767 m .51684 .73253 L .53784 .73721 L p .707 .577 .707 r
F P
0 g
s
.53588 .77194 m .54264 .80905 L .56957 .80764 L p .707 .577 .707 r
F P
0 g
s
.59875 .859 m .59526 .84046 L .56465 .84457 L p .707 .577 .707 r
F P
0 g
s
.59526 .84046 m .59875 .859 L .63008 .8528 L p .707 .577 .707 r
F P
0 g
s
.63008 .8528 m .62658 .83426 L .59526 .84046 L p .707 .577 .707 r
F P
0 g
s
.62658 .83426 m .63008 .8528 L .65905 .84512 L p .707 .577 .707 r
F P
0 g
s
.65905 .84512 m .65556 .82658 L .62658 .83426 L p .707 .577 .707 r
F P
0 g
s
.56465 .84457 m .56815 .86311 L .59875 .859 L p .707 .577 .707 r
F P
0 g
s
.51684 .73253 m .51339 .6767 L .50084 .67022 L p .707 .577 .707 r
F P
0 g
s
.54264 .80905 m .53588 .77194 L .5153 .77073 L p .707 .577 .707 r
F P
0 g
s
.56815 .86311 m .56465 .84457 L .53776 .84619 L p .707 .577 .707 r
F P
0 g
s
.53776 .84619 m .54125 .86473 L .56815 .86311 L p .707 .577 .707 r
F P
0 g
s
.67763 .74474 m .68438 .78185 L .70067 .77356 L p .707 .577 .707 r
F P
0 g
s
.70067 .77356 m .69391 .73645 L .67763 .74474 L p .707 .577 .707 r
F P
0 g
s
.65556 .82658 m .65905 .84512 L .68284 .83671 L p .707 .577 .707 r
F P
0 g
s
.68284 .83671 m .67935 .81816 L .65556 .82658 L p .707 .577 .707 r
F P
0 g
s
.5153 .77073 m .52206 .80784 L .54264 .80905 L p .707 .577 .707 r
F P
0 g
s
.6944 .66217 m .69785 .71801 L .70494 .70996 L p .707 .577 .707 r
F P
0 g
s
.70494 .70996 m .70149 .65412 L .6944 .66217 L p .707 .577 .707 r
F P
0 g
s
.50084 .67022 m .50429 .72606 L .51684 .73253 L p .707 .577 .707 r
F P
0 g
s
.54125 .86473 m .53776 .84619 L .51722 .84516 L p .707 .577 .707 r
F P
0 g
s
.51722 .84516 m .52071 .8637 L .54125 .86473 L p .707 .577 .707 r
F P
0 g
s
.52206 .80784 m .5153 .77073 L .50309 .76701 L p .707 .577 .707 r
F P
0 g
s
.67935 .81816 m .68284 .83671 L .69912 .82839 L p .707 .577 .707 r
F P
0 g
s
.69912 .82839 m .69563 .80984 L .67935 .81816 L p .707 .577 .707 r
F P
0 g
s
.50429 .72606 m .50084 .67022 L .49797 .66258 L p .707 .577 .707 r
F P
0 g
s
.50309 .76701 m .50985 .80412 L .52206 .80784 L p .707 .577 .707 r
F P
0 g
s
.69391 .73645 m .70067 .77356 L .70783 .76612 L p .707 .577 .707 r
F P
0 g
s
.70783 .76612 m .70108 .72901 L .69391 .73645 L p .707 .577 .707 r
F P
0 g
s
.49797 .66258 m .50142 .71842 L .50429 .72606 L p .707 .577 .707 r
F P
0 g
s
.70149 .65412 m .70494 .70996 L .70207 .70232 L p .707 .577 .707 r
F P
0 g
s
.70207 .70232 m .69862 .64648 L .70149 .65412 L p .707 .577 .707 r
F P
0 g
s
.52071 .8637 m .51722 .84516 L .50503 .84158 L p .707 .577 .707 r
F P
0 g
s
.50503 .84158 m .50852 .86012 L .52071 .8637 L p .707 .577 .707 r
F P
0 g
s
.69563 .80984 m .69912 .82839 L .7063 .82098 L p .707 .577 .707 r
F P
0 g
s
.7063 .82098 m .7028 .80243 L .69563 .80984 L p .707 .577 .707 r
F P
0 g
s
.50985 .80412 m .50309 .76701 L .50044 .76113 L p .707 .577 .707 r
F P
0 g
s
.48265 .82174 m .49143 .32088 L .44743 .31742 L p .707 .577 .707 r
F P
0 g
s
.50142 .71842 m .49797 .66258 L .50506 .65453 L p .707 .577 .707 r
F P
0 g
s
.50044 .76113 m .50719 .79824 L .50985 .80412 L p .707 .577 .707 r
F P
0 g
s
.50506 .65453 m .50851 .71036 L .50142 .71842 L p .707 .577 .707 r
F P
0 g
s
.50719 .79824 m .50044 .76113 L .5076 .75369 L p .707 .577 .707 r
F P
0 g
s
.50851 .71036 m .50506 .65453 L .52142 .64685 L p .707 .577 .707 r
F P
0 g
s
.5076 .75369 m .51436 .7908 L .50719 .79824 L p .707 .577 .707 r
F P
0 g
s
.52142 .64685 m .52487 .70269 L .50851 .71036 L p .707 .577 .707 r
F P
0 g
s
.51436 .7908 m .5076 .75369 L .52389 .7454 L p .707 .577 .707 r
F P
0 g
s
.52389 .7454 m .53064 .78251 L .51436 .7908 L p .707 .577 .707 r
F P
0 g
s
.51306 .84693 m .50957 .82839 L .52585 .82007 L p .707 .577 .707 r
F P
0 g
s
.52585 .82007 m .52934 .83861 L .51306 .84693 L p .707 .577 .707 r
F P
0 g
s
.52934 .83861 m .52585 .82007 L .54964 .81165 L p .707 .577 .707 r
F P
0 g
s
.49143 .32088 m .48265 .82174 L .52759 .82134 L p .707 .577 .707 r
F P
0 g
s
.52487 .70269 m .52142 .64685 L .54545 .6403 L p .707 .577 .707 r
F P
0 g
s
.54545 .6403 m .5489 .69613 L .52487 .70269 L p .707 .577 .707 r
F P
0 g
s
.53064 .78251 m .52389 .7454 L .5477 .73708 L p .707 .577 .707 r
F P
0 g
s
.52759 .82134 m .53637 .32048 L .49143 .32088 L p .707 .577 .707 r
F P
0 g
s
.5489 .69613 m .54545 .6403 L .57478 .63551 L p .707 .577 .707 r
F P
0 g
s
.57478 .63551 m .57823 .69135 L .5489 .69613 L p .707 .577 .707 r
F P
0 g
s
.5477 .73708 m .55445 .77419 L .53064 .78251 L p .707 .577 .707 r
F P
0 g
s
.55445 .77419 m .5477 .73708 L .5767 .72954 L p .707 .577 .707 r
F P
0 g
s
.54964 .81165 m .55313 .8302 L .52934 .83861 L p .707 .577 .707 r
F P
0 g
s
.5767 .72954 m .58346 .76665 L .55445 .77419 L p .707 .577 .707 r
F P
0 g
s
.55313 .8302 m .54964 .81165 L .57861 .80397 L p .707 .577 .707 r
F P
0 g
s
.57861 .80397 m .58211 .82252 L .55313 .8302 L p .707 .577 .707 r
F P
0 g
s
.53637 .32048 m .52759 .82134 L .56907 .81713 L p .707 .577 .707 r
F P
0 g
s
.56907 .81713 m .57784 .31627 L .53637 .32048 L p .707 .577 .707 r
F P
0 g
s
.70108 .72901 m .70783 .76612 L .70518 .76025 L p .707 .577 .707 r
F P
0 g
s
.70518 .76025 m .69843 .72314 L .70108 .72901 L p .707 .577 .707 r
F P
0 g
s
.43865 .81828 m .44743 .31742 L .40867 .31044 L p .707 .577 .707 r
F P
0 g
s
.44743 .31742 m .43865 .81828 L .48265 .82174 L p .707 .577 .707 r
F P
0 g
s
.69862 .64648 m .70207 .70232 L .68952 .69584 L p .707 .577 .707 r
F P
0 g
s
.68952 .69584 m .68607 .64 L .69862 .64648 L p .707 .577 .707 r
F P
0 g
s
.50852 .86012 m .50503 .84158 L .50239 .8358 L p .707 .577 .707 r
F P
0 g
s
.57823 .69135 m .57478 .63551 L .60657 .63296 L p .707 .577 .707 r
F P
0 g
s
.60657 .63296 m .61002 .6888 L .57823 .69135 L p .707 .577 .707 r
F P
0 g
s
.58346 .76665 m .5767 .72954 L .60806 .72353 L p .707 .577 .707 r
F P
0 g
s
.60806 .72353 m .61482 .76064 L .58346 .76665 L p .707 .577 .707 r
F P
0 g
s
.58211 .82252 m .57861 .80397 L .60994 .79777 L p .707 .577 .707 r
F P
0 g
s
.60994 .79777 m .61343 .81632 L .58211 .82252 L p .707 .577 .707 r
F P
0 g
s
.57784 .31627 m .56907 .81713 L .60302 .80951 L p .707 .577 .707 r
F P
0 g
s
.60302 .80951 m .6118 .30865 L .57784 .31627 L p .707 .577 .707 r
F P
0 g
s
.50239 .8358 m .50589 .85434 L .50852 .86012 L p .707 .577 .707 r
F P
0 g
s
.7028 .80243 m .7063 .82098 L .70366 .8152 L p .707 .577 .707 r
F P
0 g
s
.70366 .8152 m .70017 .79665 L .7028 .80243 L p .707 .577 .707 r
F P
0 g
s
.39989 .8113 m .40867 .31044 L .37895 .30062 L p .707 .577 .707 r
F P
0 g
s
.40867 .31044 m .39989 .8113 L .43865 .81828 L p .707 .577 .707 r
F P
0 g
s
.25334 .71861 m .24989 .66278 L .21878 .66284 L p .707 .577 .707 r
F P
0 g
s
.24989 .66278 m .25334 .71861 L .28512 .71606 L p .707 .577 .707 r
F P
0 g
s
.28512 .71606 m .28167 .66023 L .24989 .66278 L p .707 .577 .707 r
F P
0 g
s
.28167 .66023 m .28512 .71606 L .31446 .71128 L p .707 .577 .707 r
F P
0 g
s
.31446 .71128 m .31101 .65544 L .28167 .66023 L p .707 .577 .707 r
F P
0 g
s
.69843 .72314 m .70518 .76025 L .69297 .75652 L p .707 .577 .707 r
F P
0 g
s
.69297 .75652 m .68621 .71941 L .69843 .72314 L p .707 .577 .707 r
F P
0 g
s
.22222 .71868 m .21878 .66284 L .19138 .66041 L p .707 .577 .707 r
F P
0 g
s
.21878 .66284 m .22222 .71868 L .25334 .71861 L p .707 .577 .707 r
F P
0 g
s
.68607 .64 m .68952 .69584 L .66852 .69116 L p .707 .577 .707 r
F P
0 g
s
.66852 .69116 m .66507 .63532 L .68607 .64 L p .707 .577 .707 r
F P
0 g
s
.31101 .65544 m .31446 .71128 L .33848 .70472 L p .707 .577 .707 r
F P
0 g
s
.33848 .70472 m .33503 .64889 L .31101 .65544 L p .707 .577 .707 r
F P
0 g
s
.63768 .63289 m .64113 .68873 L .61002 .6888 L p .707 .577 .707 r
F P
0 g
s
.61002 .6888 m .60657 .63296 L .63768 .63289 L p .707 .577 .707 r
F P
0 g
s
.6387 .71962 m .64546 .75673 L .61482 .76064 L p .707 .577 .707 r
F P
0 g
s
.61482 .76064 m .60806 .72353 L .6387 .71962 L p .707 .577 .707 r
F P
0 g
s
.61343 .81632 m .60994 .79777 L .64054 .79366 L p .707 .577 .707 r
F P
0 g
s
.6118 .30865 m .60302 .80951 L .62613 .79924 L p .707 .577 .707 r
F P
0 g
s
.62613 .79924 m .6349 .29837 L .6118 .30865 L p .707 .577 .707 r
F P
0 g
s
.50589 .85434 m .50239 .8358 L .50957 .82839 L p .707 .577 .707 r
F P
0 g
s
.2572 .76787 m .25045 .73076 L .2198 .73467 L p .707 .577 .707 r
F P
0 g
s
.25045 .73076 m .2572 .76787 L .28856 .76186 L p .707 .577 .707 r
F P
0 g
s
.28856 .76186 m .2818 .72475 L .25045 .73076 L p .707 .577 .707 r
F P
0 g
s
.2818 .72475 m .28856 .76186 L .31756 .75432 L p .707 .577 .707 r
F P
0 g
s
.31756 .75432 m .31081 .71721 L .2818 .72475 L p .707 .577 .707 r
F P
0 g
s
.50957 .82839 m .51306 .84693 L .50589 .85434 L p .707 .577 .707 r
F P
0 g
s
.19138 .66041 m .19483 .71625 L .22222 .71868 L p .707 .577 .707 r
F P
0 g
s
.19483 .71625 m .19138 .66041 L .17038 .65573 L p .707 .577 .707 r
F P
0 g
s
.70017 .79665 m .70366 .8152 L .69147 .81162 L p .707 .577 .707 r
F P
0 g
s
.69147 .81162 m .68798 .79307 L .70017 .79665 L p .707 .577 .707 r
F P
0 g
s
.2198 .73467 m .22656 .77178 L .2572 .76787 L p .707 .577 .707 r
F P
0 g
s
.22656 .77178 m .2198 .73467 L .19287 .73609 L p .707 .577 .707 r
F P
0 g
s
.37017 .80149 m .37895 .30062 L .36118 .28893 L p .707 .577 .707 r
F P
0 g
s
.37895 .30062 m .37017 .80149 L .39989 .8113 L p .707 .577 .707 r
F P
0 g
s
.25574 .79587 m .25225 .77733 L .22164 .78144 L p .707 .577 .707 r
F P
0 g
s
.25225 .77733 m .25574 .79587 L .28707 .78967 L p .707 .577 .707 r
F P
0 g
s
.28707 .78967 m .28357 .77113 L .25225 .77733 L p .707 .577 .707 r
F P
0 g
s
.31081 .71721 m .31756 .75432 L .34137 .746 L p .707 .577 .707 r
F P
0 g
s
.34137 .746 m .33462 .70889 L .31081 .71721 L p .707 .577 .707 r
F P
0 g
s
.28357 .77113 m .28707 .78967 L .31604 .78199 L p .707 .577 .707 r
F P
0 g
s
.31604 .78199 m .31255 .76344 L .28357 .77113 L p .707 .577 .707 r
F P
0 g
s
.33503 .64889 m .33848 .70472 L .35484 .69705 L p .707 .577 .707 r
F P
0 g
s
.35484 .69705 m .35139 .64121 L .33503 .64889 L p .707 .577 .707 r
F P
0 g
s
.19287 .73609 m .19963 .7732 L .22656 .77178 L p .707 .577 .707 r
F P
0 g
s
.22164 .78144 m .22514 .79998 L .25574 .79587 L p .707 .577 .707 r
F P
0 g
s
.68621 .71941 m .69297 .75652 L .67239 .75531 L p .707 .577 .707 r
F P
0 g
s
.67239 .75531 m .66563 .7182 L .68621 .71941 L p .707 .577 .707 r
F P
0 g
s
.66507 .63532 m .66852 .69116 L .64113 .68873 L p .707 .577 .707 r
F P
0 g
s
.64113 .68873 m .63768 .63289 L .66507 .63532 L p .707 .577 .707 r
F P
0 g
s
.17038 .65573 m .17383 .71157 L .19483 .71625 L p .707 .577 .707 r
F P
0 g
s
.22514 .79998 m .22164 .78144 L .19475 .78306 L p .707 .577 .707 r
F P
0 g
s
.19475 .78306 m .19825 .8016 L .22514 .79998 L p .707 .577 .707 r
F P
0 g
s
.31255 .76344 m .31604 .78199 L .33984 .77357 L p .707 .577 .707 r
F P
0 g
s
.33984 .77357 m .33634 .75503 L .31255 .76344 L p .707 .577 .707 r
F P
0 g
s
.19963 .7732 m .19287 .73609 L .1723 .73488 L p .707 .577 .707 r
F P
0 g
s
.17383 .71157 m .17038 .65573 L .15783 .64926 L p .707 .577 .707 r
F P
0 g
s
.33462 .70889 m .34137 .746 L .35766 .73771 L p .707 .577 .707 r
F P
0 g
s
.35766 .73771 m .3509 .7006 L .33462 .70889 L p .707 .577 .707 r
F P
0 g
s
.1723 .73488 m .17905 .77199 L .19963 .7732 L p .707 .577 .707 r
F P
0 g
s
.6349 .29837 m .62613 .79924 L .63613 .7873 L p .707 .577 .707 r
F P
0 g
s
.63613 .7873 m .64491 .28644 L .6349 .29837 L p .707 .577 .707 r
F P
0 g
s
.68798 .79307 m .69147 .81162 L .67093 .81059 L p .707 .577 .707 r
F P
0 g
s
.67093 .81059 m .66744 .79204 L .68798 .79307 L p .707 .577 .707 r
F P
0 g
s
.19825 .8016 m .19475 .78306 L .17421 .78203 L p .707 .577 .707 r
F P
0 g
s
.66563 .7182 m .67239 .75531 L .64546 .75673 L p .707 .577 .707 r
F P
0 g
s
.64546 .75673 m .6387 .71962 L .66563 .7182 L p .707 .577 .707 r
F P
0 g
s
.17421 .78203 m .1777 .80057 L .19825 .8016 L p .707 .577 .707 r
F P
0 g
s
.35139 .64121 m .35484 .69705 L .36162 .68934 L p .707 .577 .707 r
F P
0 g
s
.36161 .68754 m .35139 .64121 L .36162 .68934 L .707 .577 .707 r
F
.36193 .68899 m .35848 .63316 L .35139 .64121 L p F P
0 g
s
.33634 .75503 m .33984 .77357 L .35612 .76525 L p .707 .577 .707 r
F P
0 g
s
.35612 .76525 m .35262 .74671 L .33634 .75503 L p .707 .577 .707 r
F P
0 g
s
.3509 .7006 m .35766 .73771 L .36203 .73317 L p .707 .577 .707 r
F P
0 g
s
.36203 .73317 m .36482 .73027 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36165 .7235 m .3509 .7006 L .36203 .73317 L .707 .577 .707 r
F
.35464 .54447 m .35951 .38388 L .35709 .27652 L F
.35807 .69316 m .3509 .7006 L p .36165 .7235 L F P
0 g
s
.36482 .73027 m .36112 .7099 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36112 .7099 m .35807 .69316 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.35262 .74671 m .35612 .76525 L .36329 .75784 L p .707 .577 .707 r
F P
0 g
s
.36329 .75784 m .35979 .7393 L .35262 .74671 L p .707 .577 .707 r
F P
0 g
s
.35561 .62552 m .35906 .68135 L .34652 .67488 L p .707 .577 .707 r
F P
0 g
s
.34652 .67488 m .34307 .61904 L .35561 .62552 L p .707 .577 .707 r
F P
0 g
s
.35542 .68728 m .3582 .70256 L p .34996 .72067 L .707 .577 .707 r
F P
0 g
s
.3582 .70256 m .36217 .72439 L .35677 .72275 L p .707 .577 .707 r
F P
0 g
s
.35677 .72275 m .34996 .72067 L p .3582 .70256 L .707 .577 .707 r
F P
0 g
s
.34996 .72067 m .3432 .68356 L .35542 .68728 L p .707 .577 .707 r
F P
0 g
s
.35716 .73352 m .36065 .75206 L .34846 .74848 L p .707 .577 .707 r
F P
0 g
s
.34846 .74848 m .34497 .72994 L .35716 .73352 L p .707 .577 .707 r
F P
0 g
s
.3432 .68356 m .34996 .72067 L .32938 .71946 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35211 .78892 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35211 .78892 m .3524 .7898 L p .35245 .78406 L .707 .577 .707 r
F P
0 g
s
.35245 .78406 m .35464 .54447 L .35211 .78892 L .707 .577 .707 r
F
.35709 .27652 m .35309 .50482 L p .35464 .54447 L F P
0 g
s
.35309 .50482 m .34831 .77738 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.3524 .7898 m .35606 .58077 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35606 .58077 m .35951 .38388 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35951 .38388 m .36118 .28893 L .35881 .28173 L p .707 .577 .707 r
F P
0 g
s
.35881 .28173 m .35709 .27652 L p .35951 .38388 L .707 .577 .707 r
F P
0 g
s
.36162 .68934 m .36193 .68899 L p .36161 .68754 L .707 .577 .707 r
F P
0 g
s
.15783 .64926 m .16128 .70509 L .17383 .71157 L p .707 .577 .707 r
F P
0 g
s
.17905 .77199 m .1723 .73488 L .16008 .73115 L p .707 .577 .707 r
F P
0 g
s
.35848 .63316 m .36193 .68899 L .35906 .68135 L p .707 .577 .707 r
F P
0 g
s
.35906 .68135 m .35561 .62552 L .35848 .63316 L p .707 .577 .707 r
F P
0 g
s
.35807 .69316 m .36482 .73027 L .36217 .72439 L p .707 .577 .707 r
F P
0 g
s
.36217 .72439 m .35542 .68728 L .35807 .69316 L p .707 .577 .707 r
F P
0 g
s
.35979 .7393 m .36329 .75784 L .36065 .75206 L p .707 .577 .707 r
F P
0 g
s
.36065 .75206 m .35716 .73352 L .35979 .7393 L p .707 .577 .707 r
F P
0 g
s
.36118 .28893 m .3524 .7898 L .37017 .80149 L p .707 .577 .707 r
F P
0 g
s
.16128 .70509 m .15783 .64926 L .15496 .64162 L p .707 .577 .707 r
F P
0 g
s
.16008 .73115 m .16684 .76826 L .17905 .77199 L p .707 .577 .707 r
F P
0 g
s
.66744 .79204 m .67093 .81059 L .64404 .8122 L p .707 .577 .707 r
F P
0 g
s
.64404 .8122 m .64054 .79366 L .66744 .79204 L p .707 .577 .707 r
F P
0 g
s
.1777 .80057 m .17421 .78203 L .16202 .77845 L p .707 .577 .707 r
F P
0 g
s
.16202 .77845 m .16551 .79699 L .1777 .80057 L p .707 .577 .707 r
F P
0 g
s
.15496 .64162 m .15841 .69745 L .16128 .70509 L p .707 .577 .707 r
F P
0 g
s
.64491 .28644 m .63613 .7873 L .63204 .77489 L p .707 .577 .707 r
F P
0 g
s
.63204 .77489 m .64082 .27402 L .64491 .28644 L p .707 .577 .707 r
F P
0 g
s
.64054 .79366 m .64404 .8122 L .61343 .81632 L p .707 .577 .707 r
F P
0 g
s
.16684 .76826 m .16008 .73115 L .15743 .72528 L p .707 .577 .707 r
F P
0 g
s
.15743 .72528 m .16418 .76239 L .16684 .76826 L p .707 .577 .707 r
F P
0 g
s
.15841 .69745 m .15496 .64162 L .16205 .63356 L p .707 .577 .707 r
F P
0 g
s
.16551 .79699 m .16202 .77845 L .15938 .77267 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35709 .27652 L .36709 .26458 L p .707 .577 .707 r
F P
0 g
s
.15938 .77267 m .16288 .79121 L .16551 .79699 L p .707 .577 .707 r
F P
0 g
s
.16205 .63356 m .1655 .6894 L .15841 .69745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16418 .76239 m .15743 .72528 L .16459 .71784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16459 .71784 m .17135 .75495 L .16418 .76239 L p .707 .577 .707 r
F P
0 g
s
.1655 .6894 m .16205 .63356 L .17841 .62588 L p .707 .577 .707 r
F P
0 g
s
.64082 .27402 m .63204 .77489 L .61427 .7632 L p .707 .577 .707 r
F P
0 g
s
.61427 .7632 m .62305 .26233 L .64082 .27402 L p .707 .577 .707 r
F P
0 g
s
.16288 .79121 m .15938 .77267 L .16656 .76525 L p .707 .577 .707 r
F P
0 g
s
.16656 .76525 m .17005 .7838 L .16288 .79121 L p .707 .577 .707 r
F P
0 g
s
.34307 .61904 m .34652 .67488 L .32551 .6702 L p .707 .577 .707 r
F P
0 g
s
.32551 .6702 m .32206 .61436 L .34307 .61904 L p .707 .577 .707 r
F P
0 g
s
.17841 .62588 m .18186 .68172 L .1655 .6894 L p .707 .577 .707 r
F P
0 g
s
.35832 .76545 m .36709 .26458 L .3902 .25431 L p .707 .577 .707 r
F P
0 g
s
.36709 .26458 m .35832 .76545 L .34831 .77738 L p .707 .577 .707 r
F P
0 g
s
.17135 .75495 m .16459 .71784 L .18088 .70955 L p .707 .577 .707 r
F P
0 g
s
.18186 .68172 m .17841 .62588 L .20244 .61933 L p .707 .577 .707 r
F P
0 g
s
.18088 .70955 m .18764 .74666 L .17135 .75495 L p .707 .577 .707 r
F P
0 g
s
.32938 .71946 m .32262 .68235 L .3432 .68356 L p .707 .577 .707 r
F P
0 g
s
.17005 .7838 m .16656 .76525 L .18284 .75693 L p .707 .577 .707 r
F P
0 g
s
.32206 .61436 m .32551 .6702 L .29812 .66777 L p .707 .577 .707 r
F P
0 g
s
.29812 .66777 m .29467 .61193 L .32206 .61436 L p .707 .577 .707 r
F P
0 g
s
.18284 .75693 m .18633 .77548 L .17005 .7838 L p .707 .577 .707 r
F P
0 g
s
.20244 .61933 m .20589 .67517 L .18186 .68172 L p .707 .577 .707 r
F P
0 g
s
.62305 .26233 m .61427 .7632 L .58455 .75338 L p .707 .577 .707 r
F P
0 g
s
.58455 .75338 m .59333 .25252 L .62305 .26233 L p .707 .577 .707 r
F P
0 g
s
.34497 .72994 m .34846 .74848 L .32792 .74745 L p .707 .577 .707 r
F P
0 g
s
.32792 .74745 m .32443 .72891 L .34497 .72994 L p .707 .577 .707 r
F P
0 g
s
.20589 .67517 m .20244 .61933 L .23178 .61455 L p .707 .577 .707 r
F P
0 g
s
.18764 .74666 m .18088 .70955 L .20469 .70123 L p .707 .577 .707 r
F P
0 g
s
.29467 .61193 m .29812 .66777 L .26701 .66783 L p .707 .577 .707 r
F P
0 g
s
.26701 .66783 m .26356 .612 L .29467 .61193 L p .707 .577 .707 r
F P
0 g
s
.32262 .68235 m .32938 .71946 L .30245 .72087 L p .707 .577 .707 r
F P
0 g
s
.30245 .72087 m .29569 .68376 L .32262 .68235 L p .707 .577 .707 r
F P
0 g
s
.3902 .25431 m .38142 .75517 L .35832 .76545 L p .707 .577 .707 r
F P
0 g
s
.38142 .75517 m .3902 .25431 L .42415 .24669 L p .707 .577 .707 r
F P
0 g
s
.20469 .70123 m .21144 .73834 L .18764 .74666 L p .707 .577 .707 r
F P
0 g
s
.73355 .64754 m .7301 .5917 L .69899 .59177 L p .707 .577 .707 r
F P
0 g
s
.7301 .5917 m .73355 .64754 L .76533 .64499 L p .707 .577 .707 r
F P
0 g
s
.76533 .64499 m .76188 .58915 L .7301 .5917 L p .707 .577 .707 r
F P
0 g
s
.23522 .67038 m .23178 .61455 L .26356 .612 L p .707 .577 .707 r
F P
0 g
s
.23178 .61455 m .23522 .67038 L .20589 .67517 L p .707 .577 .707 r
F P
0 g
s
.76188 .58915 m .76533 .64499 L .79467 .6402 L p .707 .577 .707 r
F P
0 g
s
.79467 .6402 m .79122 .58437 L .76188 .58915 L p .707 .577 .707 r
F P
0 g
s
.26356 .612 m .26701 .66783 L .23522 .67038 L p .707 .577 .707 r
F P
0 g
s
.18633 .77548 m .18284 .75693 L .20663 .74852 L p .707 .577 .707 r
F P
0 g
s
.70244 .6476 m .69899 .59177 L .67159 .58934 L p .707 .577 .707 r
F P
0 g
s
.69899 .59177 m .70244 .6476 L .73355 .64754 L p .707 .577 .707 r
F P
0 g
s
.20663 .74852 m .21012 .76707 L .18633 .77548 L p .707 .577 .707 r
F P
0 g
s
.32443 .72891 m .32792 .74745 L .30103 .74907 L p .707 .577 .707 r
F P
0 g
s
.30103 .74907 m .29754 .73053 L .32443 .72891 L p .707 .577 .707 r
F P
0 g
s
.21144 .73834 m .20469 .70123 L .23369 .69369 L p .707 .577 .707 r
F P
0 g
s
.79122 .58437 m .79467 .6402 L .81869 .63365 L p .707 .577 .707 r
F P
0 g
s
.81869 .63365 m .81524 .57781 L .79122 .58437 L p .707 .577 .707 r
F P
0 g
s
.29569 .68376 m .30245 .72087 L .27181 .72478 L p .707 .577 .707 r
F P
0 g
s
.27181 .72478 m .26505 .68767 L .29569 .68376 L p .707 .577 .707 r
F P
0 g
s
.59333 .25252 m .58455 .75338 L .54579 .74641 L p .707 .577 .707 r
F P
0 g
s
.54579 .74641 m .55457 .24554 L .59333 .25252 L p .707 .577 .707 r
F P
0 g
s
.23369 .69369 m .24045 .7308 L .21144 .73834 L p .707 .577 .707 r
F P
0 g
s
.67159 .58934 m .67504 .64518 L .70244 .6476 L p .707 .577 .707 r
F P
0 g
s
.24045 .7308 m .23369 .69369 L .26505 .68767 L p .707 .577 .707 r
F P
0 g
s
.73741 .71169 m .73066 .67458 L .70002 .67849 L p .707 .577 .707 r
F P
0 g
s
.73066 .67458 m .73741 .71169 L .76877 .70567 L p .707 .577 .707 r
F P
0 g
s
.76877 .70567 m .76202 .66856 L .73066 .67458 L p .707 .577 .707 r
F P
0 g
s
.67504 .64518 m .67159 .58934 L .65059 .58466 L p .707 .577 .707 r
F P
0 g
s
.21012 .76707 m .20663 .74852 L .2356 .74084 L p .707 .577 .707 r
F P
0 g
s
.26505 .68767 m .27181 .72478 L .24045 .7308 L p .707 .577 .707 r
F P
0 g
s
.76202 .66856 m .76877 .70567 L .79778 .69813 L p .707 .577 .707 r
F P
0 g
s
.79778 .69813 m .79102 .66102 L .76202 .66856 L p .707 .577 .707 r
F P
0 g
s
.2356 .74084 m .2391 .75938 L .21012 .76707 L p .707 .577 .707 r
F P
0 g
s
.41538 .74755 m .42415 .24669 L .46563 .24247 L p .707 .577 .707 r
F P
0 g
s
.42415 .24669 m .41538 .74755 L .38142 .75517 L p .707 .577 .707 r
F P
0 g
s
.29754 .73053 m .30103 .74907 L .27042 .75318 L p .707 .577 .707 r
F P
0 g
s
.27042 .75318 m .26693 .73464 L .29754 .73053 L p .707 .577 .707 r
F P
0 g
s
.70002 .67849 m .70677 .7156 L .73741 .71169 L p .707 .577 .707 r
F P
0 g
s
.70677 .7156 m .70002 .67849 L .67309 .67991 L p .707 .577 .707 r
F P
0 g
s
.81524 .57781 m .81869 .63365 L .83505 .62597 L p .707 .577 .707 r
F P
0 g
s
.83505 .62597 m .8316 .57013 L .81524 .57781 L p .707 .577 .707 r
F P
0 g
s
.2391 .75938 m .2356 .74084 L .26693 .73464 L p .707 .577 .707 r
F P
0 g
s
.79102 .66102 m .79778 .69813 L .82159 .68981 L p .707 .577 .707 r
F P
0 g
s
.82159 .68981 m .81483 .6527 L .79102 .66102 L p .707 .577 .707 r
F P
0 g
s
.26693 .73464 m .27042 .75318 L .2391 .75938 L p .707 .577 .707 r
F P
0 g
s
.65059 .58466 m .65404 .64049 L .67504 .64518 L p .707 .577 .707 r
F P
0 g
s
.67309 .67991 m .67984 .71702 L .70677 .7156 L p .707 .577 .707 r
F P
0 g
s
.55457 .24554 m .54579 .74641 L .50179 .74294 L p .707 .577 .707 r
F P
0 g
s
.50179 .74294 m .51057 .24208 L .55457 .24554 L p .707 .577 .707 r
F P
0 g
s
.73596 .76697 m .73246 .74842 L .70186 .75253 L p .707 .577 .707 r
F P
0 g
s
.73246 .74842 m .73596 .76697 L .76728 .76077 L p .707 .577 .707 r
F P
0 g
s
.76728 .76077 m .76379 .74222 L .73246 .74842 L p .707 .577 .707 r
F P
0 g
s
.76379 .74222 m .76728 .76077 L .79626 .75308 L p .707 .577 .707 r
F P
0 g
s
.79626 .75308 m .79276 .73454 L .76379 .74222 L p .707 .577 .707 r
F P
0 g
s
.45685 .74334 m .46563 .24247 L .51057 .24208 L p .707 .577 .707 r
F P
0 g
s
.46563 .24247 m .45685 .74334 L .41538 .74755 L p .707 .577 .707 r
F P
0 g
s
.70186 .75253 m .70535 .77108 L .73596 .76697 L p .707 .577 .707 r
F P
0 g
s
.65404 .64049 m .65059 .58466 L .63804 .57818 L p .707 .577 .707 r
F P
0 g
s
.67984 .71702 m .67309 .67991 L .65251 .67869 L p .707 .577 .707 r
F P
0 g
s
.51057 .24208 m .50179 .74294 L .45685 .74334 L p .707 .577 .707 r
F P
0 g
s
.70535 .77108 m .70186 .75253 L .67496 .75415 L p .707 .577 .707 r
F P
0 g
s
.67496 .75415 m .67846 .7727 L .70535 .77108 L p .707 .577 .707 r
F P
0 g
s
.81483 .6527 m .82159 .68981 L .83787 .68153 L p .707 .577 .707 r
F P
0 g
s
.83787 .68153 m .83112 .64442 L .81483 .6527 L p .707 .577 .707 r
F P
0 g
s
.79276 .73454 m .79626 .75308 L .82005 .74467 L p .707 .577 .707 r
F P
0 g
s
.82005 .74467 m .81656 .72613 L .79276 .73454 L p .707 .577 .707 r
F P
0 g
s
.65251 .67869 m .65926 .7158 L .67984 .71702 L p .707 .577 .707 r
F P
0 g
s
.8316 .57013 m .83505 .62597 L .84215 .61792 L p .707 .577 .707 r
F P
0 g
s
.84215 .61792 m .8387 .56208 L .8316 .57013 L p .707 .577 .707 r
F P
0 g
s
.63804 .57818 m .64149 .63402 L .65404 .64049 L p .707 .577 .707 r
F P
0 g
s
.67846 .7727 m .67496 .75415 L .65442 .75312 L p .707 .577 .707 r
F P
0 g
s
.65442 .75312 m .65791 .77167 L .67846 .7727 L p .707 .577 .707 r
F P
0 g
s
.65926 .7158 m .65251 .67869 L .64029 .67497 L p .707 .577 .707 r
F P
0 g
s
.81656 .72613 m .82005 .74467 L .83633 .73635 L p .707 .577 .707 r
F P
0 g
s
.83633 .73635 m .83284 .71781 L .81656 .72613 L p .707 .577 .707 r
F P
0 g
s
.64149 .63402 m .63804 .57818 L .63517 .57054 L p .707 .577 .707 r
F P
0 g
s
.64029 .67497 m .64705 .71208 L .65926 .7158 L p .707 .577 .707 r
F P
0 g
s
.83112 .64442 m .83787 .68153 L .84504 .67408 L p .707 .577 .707 r
F P
0 g
s
.84504 .67408 m .83828 .63697 L .83112 .64442 L p .707 .577 .707 r
F P
0 g
s
.63517 .57054 m .63862 .62638 L .64149 .63402 L p .707 .577 .707 r
F P
0 g
s
.8387 .56208 m .84215 .61792 L .83928 .61028 L p .707 .577 .707 r
F P
0 g
s
.83928 .61028 m .83583 .55444 L .8387 .56208 L p .707 .577 .707 r
F P
0 g
s
.65791 .77167 m .65442 .75312 L .64223 .74954 L p .707 .577 .707 r
F P
0 g
s
.64223 .74954 m .64573 .76808 L .65791 .77167 L p .707 .577 .707 r
F P
0 g
s
.83284 .71781 m .83633 .73635 L .8435 .72894 L p .707 .577 .707 r
F P
0 g
s
.8435 .72894 m .84001 .71039 L .83284 .71781 L p .707 .577 .707 r
F P
0 g
s
.64705 .71208 m .64029 .67497 L .63764 .6691 L p .707 .577 .707 r
F P
0 g
s
.63862 .62638 m .63517 .57054 L .64227 .56249 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63764 .6691 m .6444 .70621 L .64705 .71208 L p .707 .577 .707 r
F P
0 g
s
.83828 .63697 m .84504 .67408 L .84238 .66821 L p .707 .577 .707 r
F P
0 g
s
.84238 .66821 m .83563 .6311 L .83828 .63697 L p .707 .577 .707 r
F P
0 g
s
.64227 .56249 m .64572 .61833 L .63862 .62638 L p .707 .577 .707 r
F P
0 g
s
.83583 .55444 m .83928 .61028 L .82673 .6038 L p .707 .577 .707 r
F P
0 g
s
.82673 .6038 m .82328 .54796 L .83583 .55444 L p .707 .577 .707 r
F P
0 g
s
.64573 .76808 m .64223 .74954 L .6396 .74376 L p .707 .577 .707 r
F P
0 g
s
.6396 .74376 m .64309 .76231 L .64573 .76808 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84001 .71039 m .8435 .72894 L .84087 .72316 L p .707 .577 .707 r
F P
0 g
s
.84087 .72316 m .83737 .70461 L .84001 .71039 L p .707 .577 .707 r
F P
0 g
s
.6444 .70621 m .63764 .6691 L .64481 .66165 L p .707 .577 .707 r
F P
0 g
s
.39054 .62658 m .38709 .57074 L .35598 .5708 L p .707 .577 .707 r
F P
0 g
s
.38709 .57074 m .39054 .62658 L .42232 .62402 L p .707 .577 .707 r
F P
0 g
s
.42232 .62402 m .41887 .56819 L .38709 .57074 L p .707 .577 .707 r
F P
0 g
s
.64572 .61833 m .64227 .56249 L .65863 .55481 L p .707 .577 .707 r
F P
0 g
s
.41887 .56819 m .42232 .62402 L .45166 .61924 L p .707 .577 .707 r
F P
0 g
s
.45166 .61924 m .44821 .5634 L .41887 .56819 L p .707 .577 .707 r
F P
0 g
s
.64481 .66165 m .65156 .69876 L .6444 .70621 L p .707 .577 .707 r
F P
0 g
s
.83563 .6311 m .84238 .66821 L .83017 .66449 L p .707 .577 .707 r
F P
0 g
s
.83017 .66449 m .82342 .62737 L .83563 .6311 L p .707 .577 .707 r
F P
0 g
s
.35943 .62664 m .35598 .5708 L .32858 .56838 L p .707 .577 .707 r
F P
0 g
s
.35598 .5708 m .35943 .62664 L .39054 .62658 L p .707 .577 .707 r
F P
0 g
s
.82328 .54796 m .82673 .6038 L .80573 .59912 L p .707 .577 .707 r
F P
0 g
s
.80573 .59912 m .80228 .54328 L .82328 .54796 L p .707 .577 .707 r
F P
0 g
s
.44821 .5634 m .45166 .61924 L .47568 .61269 L p .707 .577 .707 r
F P
0 g
s
.47568 .61269 m .47223 .55685 L .44821 .5634 L p .707 .577 .707 r
F P
0 g
s
.65863 .55481 m .66208 .61065 L .64572 .61833 L p .707 .577 .707 r
F P
0 g
s
.64309 .76231 m .6396 .74376 L .64677 .73635 L p .707 .577 .707 r
F P
0 g
s
.3944 .67584 m .38765 .63872 L .35701 .64263 L p .707 .577 .707 r
F P
0 g
s
.38765 .63872 m .3944 .67584 L .42576 .66982 L p .707 .577 .707 r
F P
0 g
s
.42576 .66982 m .41901 .63271 L .38765 .63872 L p .707 .577 .707 r
F P
0 g
s
.41901 .63271 m .42576 .66982 L .45477 .66228 L p .707 .577 .707 r
F P
0 g
s
.45477 .66228 m .44801 .62517 L .41901 .63271 L p .707 .577 .707 r
F P
0 g
s
.64677 .73635 m .65026 .75489 L .64309 .76231 L p .707 .577 .707 r
F P
0 g
s
.32858 .56838 m .33203 .62421 L .35943 .62664 L p .707 .577 .707 r
F P
0 g
s
.33203 .62421 m .32858 .56838 L .30758 .56369 L p .707 .577 .707 r
F P
0 g
s
.83737 .70461 m .84087 .72316 L .82868 .71958 L p .707 .577 .707 r
F P
0 g
s
.82868 .71958 m .82519 .70103 L .83737 .70461 L p .707 .577 .707 r
F P
0 g
s
.35701 .64263 m .36376 .67974 L .3944 .67584 L p .707 .577 .707 r
F P
0 g
s
.66208 .61065 m .65863 .55481 L .68265 .54826 L p .707 .577 .707 r
F P
0 g
s
.36376 .67974 m .35701 .64263 L .33008 .64405 L p .707 .577 .707 r
F P
0 g
s
.65156 .69876 m .64481 .66165 L .66109 .65336 L p .707 .577 .707 r
F P
0 g
s
.39295 .70383 m .38945 .68529 L .35885 .6894 L p .707 .577 .707 r
F P
0 g
s
.38945 .68529 m .39295 .70383 L .42427 .69763 L p .707 .577 .707 r
F P
0 g
s
.42427 .69763 m .42078 .67909 L .38945 .68529 L p .707 .577 .707 r
F P
0 g
s
.44801 .62517 m .45477 .66228 L .47858 .65396 L p .707 .577 .707 r
F P
0 g
s
.47858 .65396 m .47182 .61685 L .44801 .62517 L p .707 .577 .707 r
F P
0 g
s
.42078 .67909 m .42427 .69763 L .45325 .68995 L p .707 .577 .707 r
F P
0 g
s
.45325 .68995 m .44975 .6714 L .42078 .67909 L p .707 .577 .707 r
F P
0 g
s
.47223 .55685 m .47568 .61269 L .49204 .60501 L p .707 .577 .707 r
F P
0 g
s
.49204 .60501 m .48859 .54917 L .47223 .55685 L p .707 .577 .707 r
F P
0 g
s
.33008 .64405 m .33683 .68116 L .36376 .67974 L p .707 .577 .707 r
F P
0 g
s
.66109 .65336 m .66785 .69047 L .65156 .69876 L p .707 .577 .707 r
F P
0 g
s
.35885 .6894 m .36234 .70794 L .39295 .70383 L p .707 .577 .707 r
F P
0 g
s
.82342 .62737 m .83017 .66449 L .80959 .66327 L p .707 .577 .707 r
F P
0 g
s
.80959 .66327 m .80284 .62616 L .82342 .62737 L p .707 .577 .707 r
F P
0 g
s
.80228 .54328 m .80573 .59912 L .77833 .59669 L p .707 .577 .707 r
F P
0 g
s
.77833 .59669 m .77488 .54086 L .80228 .54328 L p .707 .577 .707 r
F P
0 g
s
.30758 .56369 m .31103 .61953 L .33203 .62421 L p .707 .577 .707 r
F P
0 g
s
.36234 .70794 m .35885 .6894 L .33195 .69102 L p .707 .577 .707 r
F P
0 g
s
.68265 .54826 m .6861 .60409 L .66208 .61065 L p .707 .577 .707 r
F P
0 g
s
.33195 .69102 m .33545 .70956 L .36234 .70794 L p .707 .577 .707 r
F P
0 g
s
.44975 .6714 m .45325 .68995 L .47704 .68154 L p .707 .577 .707 r
F P
0 g
s
.47704 .68154 m .47355 .66299 L .44975 .6714 L p .707 .577 .707 r
F P
0 g
s
.33683 .68116 m .33008 .64405 L .3095 .64284 L p .707 .577 .707 r
F P
0 g
s
.6861 .60409 m .68265 .54826 L .71199 .54347 L p .707 .577 .707 r
F P
0 g
s
.65026 .75489 m .64677 .73635 L .66305 .72803 L p .707 .577 .707 r
F P
0 g
s
.31103 .61953 m .30758 .56369 L .29503 .55722 L p .707 .577 .707 r
F P
0 g
s
.66305 .72803 m .66654 .74657 L .65026 .75489 L p .707 .577 .707 r
F P
0 g
s
.47182 .61685 m .47858 .65396 L .49486 .64567 L p .707 .577 .707 r
F P
0 g
s
.49486 .64567 m .48811 .60856 L .47182 .61685 L p .707 .577 .707 r
F P
0 g
s
.3095 .64284 m .31625 .67995 L .33683 .68116 L p .707 .577 .707 r
F P
0 g
s
.66785 .69047 m .66109 .65336 L .6849 .64504 L p .707 .577 .707 r
F P
0 g
s
.77488 .54086 m .77833 .59669 L .74722 .59676 L p .707 .577 .707 r
F P
0 g
s
.74722 .59676 m .74377 .54092 L .77488 .54086 L p .707 .577 .707 r
F P
0 g
s
.82519 .70103 m .82868 .71958 L .80813 .71855 L p .707 .577 .707 r
F P
0 g
s
.80813 .71855 m .80464 .7 L .82519 .70103 L p .707 .577 .707 r
F P
0 g
s
.33545 .70956 m .33195 .69102 L .31141 .68999 L p .707 .577 .707 r
F P
0 g
s
.71544 .59931 m .71199 .54347 L .74377 .54092 L p .707 .577 .707 r
F P
0 g
s
.71199 .54347 m .71544 .59931 L .6861 .60409 L p .707 .577 .707 r
F P
0 g
s
.80284 .62616 m .80959 .66327 L .78266 .66469 L p .707 .577 .707 r
F P
0 g
s
.78266 .66469 m .77591 .62758 L .80284 .62616 L p .707 .577 .707 r
F P
0 g
s
.31141 .68999 m .3149 .70853 L .33545 .70956 L p .707 .577 .707 r
F P
0 g
s
.48859 .54917 m .49204 .60501 L .49914 .59695 L p .707 .577 .707 r
F P
0 g
s
.49914 .59695 m .49569 .54112 L .48859 .54917 L p .707 .577 .707 r
F P
0 g
s
.6849 .64504 m .69166 .68215 L .66785 .69047 L p .707 .577 .707 r
F P
0 g
s
.74377 .54092 m .74722 .59676 L .71544 .59931 L p .707 .577 .707 r
F P
0 g
s
.29503 .55722 m .29848 .61305 L .31103 .61953 L p .707 .577 .707 r
F P
0 g
s
.47355 .66299 m .47704 .68154 L .49332 .67322 L p .707 .577 .707 r
F P
0 g
s
.49332 .67322 m .48983 .65467 L .47355 .66299 L p .707 .577 .707 r
F P
0 g
s
.31625 .67995 m .3095 .64284 L .29728 .63911 L p .707 .577 .707 r
F P
0 g
s
.69166 .68215 m .6849 .64504 L .71391 .6375 L p .707 .577 .707 r
F P
0 g
s
.66654 .74657 m .66305 .72803 L .68684 .71962 L p .707 .577 .707 r
F P
0 g
s
.29848 .61305 m .29503 .55722 L .29216 .54958 L p .707 .577 .707 r
F P
0 g
s
.29728 .63911 m .30404 .67622 L .31625 .67995 L p .707 .577 .707 r
F P
0 g
s
.68684 .71962 m .69034 .73816 L .66654 .74657 L p .707 .577 .707 r
F P
0 g
s
.48811 .60856 m .49486 .64567 L .50203 .63823 L p .707 .577 .707 r
F P
0 g
s
.50203 .63823 m .49527 .60112 L .48811 .60856 L p .707 .577 .707 r
F P
0 g
s
.77591 .62758 m .78266 .66469 L .75202 .6686 L p .707 .577 .707 r
F P
0 g
s
.75202 .6686 m .74527 .63149 L .77591 .62758 L p .707 .577 .707 r
F P
0 g
s
.80464 .7 m .80813 .71855 L .78124 .72017 L p .707 .577 .707 r
F P
0 g
s
.78124 .72017 m .77775 .70162 L .80464 .7 L p .707 .577 .707 r
F P
0 g
s
.71391 .6375 m .72066 .67462 L .69166 .68215 L p .707 .577 .707 r
F P
0 g
s
.3149 .70853 m .31141 .68999 L .29922 .68641 L p .707 .577 .707 r
F P
0 g
s
.72066 .67462 m .71391 .6375 L .74527 .63149 L p .707 .577 .707 r
F P
0 g
s
.29922 .68641 m .30272 .70495 L .3149 .70853 L p .707 .577 .707 r
F P
0 g
s
.74527 .63149 m .75202 .6686 L .72066 .67462 L p .707 .577 .707 r
F P
0 g
s
.48983 .65467 m .49332 .67322 L .50049 .6658 L p .707 .577 .707 r
F P
0 g
s
.50049 .6658 m .497 .64726 L .48983 .65467 L p .707 .577 .707 r
F P
0 g
s
.29216 .54958 m .29561 .60542 L .29848 .61305 L p .707 .577 .707 r
F P
0 g
s
.49569 .54112 m .49914 .59695 L .49627 .58931 L p .707 .577 .707 r
F P
0 g
s
.49627 .58931 m .49282 .53348 L .49569 .54112 L p .707 .577 .707 r
F P
0 g
s
.69034 .73816 m .68684 .71962 L .71582 .71193 L p .707 .577 .707 r
F P
0 g
s
.71582 .71193 m .71931 .73048 L .69034 .73816 L p .707 .577 .707 r
F P
0 g
s
.77775 .70162 m .78124 .72017 L .75064 .72428 L p .707 .577 .707 r
F P
0 g
s
.75064 .72428 m .74714 .70573 L .77775 .70162 L p .707 .577 .707 r
F P
0 g
s
.30404 .67622 m .29728 .63911 L .29463 .63324 L p .707 .577 .707 r
F P
0 g
s
.71931 .73048 m .71582 .71193 L .74714 .70573 L p .707 .577 .707 r
F P
0 g
s
.29463 .63324 m .30139 .67035 L .30404 .67622 L p .707 .577 .707 r
F P
0 g
s
.74714 .70573 m .75064 .72428 L .71931 .73048 L p .707 .577 .707 r
F P
0 g
s
.29561 .60542 m .29216 .54958 L .29925 .54152 L p .707 .577 .707 r
F P
0 g
s
.49527 .60112 m .50203 .63823 L .49937 .63236 L p .707 .577 .707 r
F P
0 g
s
.49937 .63236 m .49262 .59524 L .49527 .60112 L p .707 .577 .707 r
F P
0 g
s
.30272 .70495 m .29922 .68641 L .29659 .68063 L p .707 .577 .707 r
F P
0 g
s
.29659 .68063 m .30008 .69917 L .30272 .70495 L p .707 .577 .707 r
F P
0 g
s
.497 .64726 m .50049 .6658 L .49786 .66002 L p .707 .577 .707 r
F P
0 g
s
.49786 .66002 m .49436 .64148 L .497 .64726 L p .707 .577 .707 r
F P
0 g
s
.29925 .54152 m .3027 .59736 L .29561 .60542 L p .707 .577 .707 r
F P
0 g
s
.49282 .53348 m .49627 .58931 L .48372 .58284 L p .707 .577 .707 r
F P
0 g
s
.48372 .58284 m .48027 .527 L .49282 .53348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30139 .67035 m .29463 .63324 L .3018 .6258 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3018 .6258 m .30855 .66291 L .30139 .67035 L p .707 .577 .707 r
F P
0 g
s
.3027 .59736 m .29925 .54152 L .31561 .53385 L p .707 .577 .707 r
F P
0 g
s
.49262 .59524 m .49937 .63236 L .48716 .62863 L p .707 .577 .707 r
F P
0 g
s
.48716 .62863 m .48041 .59152 L .49262 .59524 L p .707 .577 .707 r
F P
0 g
s
.30008 .69917 m .29659 .68063 L .30376 .67322 L p .707 .577 .707 r
F P
0 g
s
.30376 .67322 m .30725 .69176 L .30008 .69917 L p .707 .577 .707 r
F P
0 g
s
.48027 .527 m .48372 .58284 L .46272 .57816 L p .707 .577 .707 r
F P
0 g
s
.46272 .57816 m .45927 .52232 L .48027 .527 L p .707 .577 .707 r
F P
0 g
s
.49436 .64148 m .49786 .66002 L .48567 .65644 L p .707 .577 .707 r
F P
0 g
s
.48567 .65644 m .48218 .6379 L .49436 .64148 L p .707 .577 .707 r
F P
0 g
s
.31561 .53385 m .31906 .58968 L .3027 .59736 L p .707 .577 .707 r
F P
0 g
s
.30855 .66291 m .3018 .6258 L .31808 .61751 L p .707 .577 .707 r
F P
0 g
s
.31906 .58968 m .31561 .53385 L .33964 .52729 L p .707 .577 .707 r
F P
0 g
s
.31808 .61751 m .32484 .65462 L .30855 .66291 L p .707 .577 .707 r
F P
0 g
s
.48041 .59152 m .48716 .62863 L .46658 .62742 L p .707 .577 .707 r
F P
0 g
s
.46658 .62742 m .45983 .59031 L .48041 .59152 L p .707 .577 .707 r
F P
0 g
s
.30725 .69176 m .30376 .67322 L .32004 .6649 L p .707 .577 .707 r
F P
0 g
s
.45927 .52232 m .46272 .57816 L .43532 .57573 L p .707 .577 .707 r
F P
0 g
s
.43532 .57573 m .43187 .51989 L .45927 .52232 L p .707 .577 .707 r
F P
0 g
s
.32004 .6649 m .32353 .68344 L .30725 .69176 L p .707 .577 .707 r
F P
0 g
s
.33964 .52729 m .34309 .58313 L .31906 .58968 L p .707 .577 .707 r
F P
0 g
s
.48218 .6379 m .48567 .65644 L .46512 .65541 L p .707 .577 .707 r
F P
0 g
s
.46512 .65541 m .46163 .63687 L .48218 .6379 L p .707 .577 .707 r
F P
0 g
s
.34309 .58313 m .33964 .52729 L .36898 .52251 L p .707 .577 .707 r
F P
0 g
s
.32484 .65462 m .31808 .61751 L .34189 .60919 L p .707 .577 .707 r
F P
0 g
s
.43187 .51989 m .43532 .57573 L .40421 .57579 L p .707 .577 .707 r
F P
0 g
s
.40421 .57579 m .40076 .51996 L .43187 .51989 L p .707 .577 .707 r
F P
0 g
s
.45983 .59031 m .46658 .62742 L .43965 .62883 L p .707 .577 .707 r
F P
0 g
s
.43965 .62883 m .4329 .59172 L .45983 .59031 L p .707 .577 .707 r
F P
0 g
s
.34189 .60919 m .34865 .6463 L .32484 .65462 L p .707 .577 .707 r
F P
0 g
s
.37243 .57834 m .36898 .52251 L .40076 .51996 L p .707 .577 .707 r
F P
0 g
s
.36898 .52251 m .37243 .57834 L .34309 .58313 L p .707 .577 .707 r
F P
0 g
s
.40076 .51996 m .40421 .57579 L .37243 .57834 L p .707 .577 .707 r
F P
0 g
s
.32353 .68344 m .32004 .6649 L .34383 .65648 L p .707 .577 .707 r
F P
0 g
s
.34383 .65648 m .34733 .67503 L .32353 .68344 L p .707 .577 .707 r
F P
0 g
s
.46163 .63687 m .46512 .65541 L .43823 .65703 L p .707 .577 .707 r
F P
0 g
s
.43823 .65703 m .43474 .63849 L .46163 .63687 L p .707 .577 .707 r
F P
0 g
s
.34865 .6463 m .34189 .60919 L .3709 .60165 L p .707 .577 .707 r
F P
0 g
s
.4329 .59172 m .43965 .62883 L .40901 .63274 L p .707 .577 .707 r
F P
0 g
s
.40901 .63274 m .40226 .59563 L .4329 .59172 L p .707 .577 .707 r
F P
0 g
s
.3709 .60165 m .37765 .63876 L .34865 .6463 L p .707 .577 .707 r
F P
0 g
s
.37765 .63876 m .3709 .60165 L .40226 .59563 L p .707 .577 .707 r
F P
0 g
s
.34733 .67503 m .34383 .65648 L .37281 .6488 L p .707 .577 .707 r
F P
0 g
s
.40226 .59563 m .40901 .63274 L .37765 .63876 L p .707 .577 .707 r
F P
0 g
s
.37281 .6488 m .3763 .66734 L .34733 .67503 L p .707 .577 .707 r
F P
0 g
s
.43474 .63849 m .43823 .65703 L .40763 .66114 L p .707 .577 .707 r
F P
0 g
s
.40763 .66114 m .40413 .6426 L .43474 .63849 L p .707 .577 .707 r
F P
0 g
s
.3763 .66734 m .37281 .6488 L .40413 .6426 L p .707 .577 .707 r
F P
0 g
s
.40413 .6426 m .40763 .66114 L .3763 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001UYF00<005YFFUH00eYF2@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001J
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF00AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol00`00FUH00006FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`T000AJEP03001JEUYF
00IJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Qo
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001WOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000IOolA000mOol005Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00
E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00@0039oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000_Ool005=oo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<0
05YFFUH01EYF1`000eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`800003
FUH005YF009JEP03001JEUYF00=JEPH000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@000=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00Dgoo0P0000=JEP00FUH00UYF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00003FUH2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH01000
FUIJEUYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00@005YF001JEP8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPP000=JEP03001JEUYF00D00006FUH005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000H000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPd000=JEP03001JEUYF00EJEPP0009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH2000]Ool005Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0000002eoo`00E7oo00D005YFFUIJ
EP0000EJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00@7oo5@000eYF00@005YFFUIJ
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00?7oo100000=JEP00FUH01eYF
00<005YFFUH01UYF00D005YF000005YF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00=Woo1P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000bOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000^Ool0035oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0
0004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUHF000_Ool002moo`800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPP000EJEP03001JEUYF00EJEP04001JEUYFFUH5000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00L0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF008000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUH0
00030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004
FUH00`00FUIJEP04FUH40006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF2@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00005FUH01000FUH0000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20005FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH4
00000eYF000000020005FUH00`00FUIJEP07FUH00`00FUIJEP04FUHB000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
10001eYF00@005YF000000=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH015YF0`00
0UYF0`000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEPT000=JEP03001oogoo02]oo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPh00005FUH005YF001JEP020006FUH00`00FUIJEP04FUH70009FUH00`00
FUIJEP0400000eYF0000000200000eYF001JEP04FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF0P0000=JEP000000;7oo000/Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00UYF0P0000AJEP00000000MJ
EP03001JEUYF00@000MJEP03001JEUYF00AJEPD0009JEP<000EJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00AJEP03001JEUYF009JEP@002ao
o`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01000
1EYF0P0000=JEP00FUH01UYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000/Ool002aoo`800003FUH0
05YF009JEP04001JEUYFFUH600000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00`000eYF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP040004FUH60003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH2000]Ool002eoo`03001JEP0000=JEP@000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF00003`000UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF100025YF00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<007ooOol0;7oo000]Ool00`00
FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF1@000UYF00@005YF
FUIJEPT00003FUH005YF00EJEPL000AJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000
FUIJEUYF0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00P00;goo000]Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH000060004FUH01@00FUIJEP00FUH00`001EYF00D005YF001JEP0000=JEP@00003FUH00000
00<000AJEP03001JEUYF00IJEP04001JEP00000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`00<Goo000]Ool01@00FUH005YF0000
1EYF00<005YFFUH015YF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P0000=JEP0000004000
1EYF1@001EYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP04001J
EP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000eOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH0
0`00FUIJEP05FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH000000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF0`00>Goo000]Ool01@00FUIJEUYF00001EYF00<005YF00000`001EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF4`00<Goo000]Ool01@00FUIJEUYF00000eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJ
EPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Woo0P0000=JEP00
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH05@002EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0031o
o`@000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYF000^Ool002moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000AJEQ400003FUH005YF00QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002ioo`03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ000003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEQ<000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001o
ogoo02]oo`00;Goo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01@000eYF00<005YFFUH01EYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP04FUH7000@Ool6000]Ool002ao
o`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001J
EUYF00AJEP06001JEUYF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF0`000eYF
00<005YFFUH01UYF00<005YFFUH0100057oo0`000UYF00@005YFFUH002eoo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP<000IJEP03001JEUYF00AJEP@001Aoo`@00003FUH0
05YF00=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00@0
00AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH200000eYF001JEP06FUH00`00FUIJEP04000EOol30005
FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP@000IJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP04FUH5000FOol200000eYF001J
EP06FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YF
FUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEP800004FUH005YFFUH2
000BOol30003FUH00`00FUIJEP05FUH01000FUH00000<7oo000]Ool00`00FUH00005FUH01000FUH0
000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF6@001UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00@005YF000000=JEP03001JEUYF008000aoo`H0
00IJEP03001JEUYF00AJEP<0039oo`00;Goo00@005YFFUH000=JEP@00003FUH00000008000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPX00003FUH005YF00EJEP03001JEUYF00EJ
EPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP04001J
EUYFFUH40004FUH00`00FUIJEP020003Ool90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000]Ool01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2P0000=JEP0000000P0000Ioo`00000005YF0006FUH00`00FUIJEP050008FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002
FUH01000FUH000000eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000003Moo`00;Woo0UYF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=J
EP00FUH01EYF0`000Woo0`000UYF00<005YF00001EYF10000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P0000=J
EP00FUH030000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00>Goo000^Ool0
1EYF001JEP00FUH00P001EYF00<005YFFUH01EYF1`002EYF00<005YFFUH010000goo0P0000=JEP00
FUH00UYF00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF1@000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?7oo000^Ool20000
15YF000000001eYF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@001Goo0P000eYF00P005YF
FUIJEP00FUH005YF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF0P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00@7oo000^Ool30002FUH00`00FUIJ
EP05FUH00`00FUH000030008FUH00`00FUIJEP040007Ool30006FUH01@00FUIJEP00FUH00P000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000AJEP800003FUH0000000=JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@004Eoo`00;Woo0P0015YF00<005YFFUH00eYF0`000eYF
00<005YFFUH00UYF1`001goo100000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP80009JEP80009JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
009JEPL004Uoo`00;Goo00<005YF000015YF00<005YF00003P000goo0`000goo1@001EYF00<005YF
FUH015YF0`0000=oo`00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100015YF5000D7oo000]
Ool01000FUIJEP000eYF0P004Goo1`000UYF00<005YFFUH01UYF00@005YFFUIJEP8000Aoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP02
001FOol002eoo`05001JEUYF001JEP02000@Ool80004FUH00`00FUIJEP06FUH01000FUH000001Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00EJEP<005Qo
o`00;Woo00<005YF00004`000eYF1@001EYF00<005YFFUH015YF0`0027oo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00=JEP8005Yoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH0100037oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEP0000<005aoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0047oo00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001UYF0`00H7oo000^Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000FOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHD001HOol002moo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPH001aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP00008005Eoo`00<Goo500097oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00Jgoo0P0015YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF001EOol006eoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001J
EP000008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000E7oo001`Ool40008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH400000eYF001JEP05
FUHA0002FUH00`00Oomoo`1BOol007Aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00D000EJEP03001JEUYF00@000ioo`H005Aoo`00NWoo2@001UYF00<005YF
FUH02EYF00<005YFFUH015YF200000=JEP00FUH00eYF1`003goo0`000UYF00@005YFFUH005Aoo`00
Pgoo6P001eYF1P0057oo0P0000=JEP00FUH00eYF00<005YF0000E7oo002BOol200000eYF001JEP06
FUH00`00FUIJEP02FUH2000HOol20003FUH00`00FUIJEP02FUH2001EOol0091oo`8000=JEP03001J
EUYF00EJEP03001JEP00008001Moo`<000IJEP05001JEUYFFUH0001FOol008moo`8000EJEP03001J
EUYF00=JEP<001Ioo`@00003FUH005YF00IJEP04001JEP00001GOol008ioo`03001JEP0000EJEP03
001JEP0000<0019oo`L000EJEP03001JEUYF00AJEP<005Uoo`00SWoo00@005YFFUH000=JEP<000mo
o`L000AJEP03001JEUYF00IJEP04001JEUYFFUH2001LOol008ioo`05001JEUYF001JEP02000>Ool4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002?Ool00`00FUH0000A0006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol008moo`80009JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00Sgoo0P000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00Igoo002?Ool20003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001/Ool0091oo`80
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0071oo`00TWoo5000Mgoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59642 .73339 m .59084 .67751 L .55983 .67879 L p .707 .577 .707 r
F P
0 g
s
.59084 .67751 m .59642 .73339 L .62811 .72974 L p .707 .577 .707 r
F P
0 g
s
.62811 .72974 m .62253 .67386 L .59084 .67751 L p .707 .577 .707 r
F P
0 g
s
.62253 .67386 m .62811 .72974 L .65738 .72408 L p .707 .577 .707 r
F P
0 g
s
.65738 .72408 m .6518 .6682 L .62253 .67386 L p .707 .577 .707 r
F P
0 g
s
.5654 .73467 m .55983 .67879 L .53253 .67758 L p .707 .577 .707 r
F P
0 g
s
.55983 .67879 m .5654 .73467 L .59642 .73339 L p .707 .577 .707 r
F P
0 g
s
.6518 .6682 m .65738 .72408 L .68136 .71697 L p .707 .577 .707 r
F P
0 g
s
.68136 .71697 m .67578 .66109 L .6518 .6682 L p .707 .577 .707 r
F P
0 g
s
.53253 .67758 m .5381 .73346 L .5654 .73467 L p .707 .577 .707 r
F P
0 g
s
.60216 .79964 m .59133 .76317 L .56154 .77063 L p .707 .577 .707 r
F P
0 g
s
.59133 .76317 m .60216 .79964 L .63275 .79041 L p .707 .577 .707 r
F P
0 g
s
.63275 .79041 m .62193 .75394 L .59133 .76317 L p .707 .577 .707 r
F P
0 g
s
.5381 .73346 m .53253 .67758 L .51162 .674 L p .707 .577 .707 r
F P
0 g
s
.62193 .75394 m .63275 .79041 L .66114 .78033 L p .707 .577 .707 r
F P
0 g
s
.66114 .78033 m .65032 .74386 L .62193 .75394 L p .707 .577 .707 r
F P
0 g
s
.56154 .77063 m .57236 .8071 L .60216 .79964 L p .707 .577 .707 r
F P
0 g
s
.57236 .8071 m .56154 .77063 L .53546 .7756 L p .707 .577 .707 r
F P
0 g
s
.67578 .66109 m .68136 .71697 L .6977 .70909 L p .707 .577 .707 r
F P
0 g
s
.6977 .70909 m .69212 .65322 L .67578 .66109 L p .707 .577 .707 r
F P
0 g
s
.65032 .74386 m .66114 .78033 L .68456 .77038 L p .707 .577 .707 r
F P
0 g
s
.68456 .77038 m .67374 .7339 L .65032 .74386 L p .707 .577 .707 r
F P
0 g
s
.51162 .674 m .51719 .72988 L .5381 .73346 L p .707 .577 .707 r
F P
0 g
s
.53546 .7756 m .54628 .81208 L .57236 .8071 L p .707 .577 .707 r
F P
0 g
s
.59978 .86338 m .59419 .84519 L .56449 .85297 L p .707 .577 .707 r
F P
0 g
s
.59419 .84519 m .59978 .86338 L .63029 .85387 L p .707 .577 .707 r
F P
0 g
s
.63029 .85387 m .6247 .83567 L .59419 .84519 L p .707 .577 .707 r
F P
0 g
s
.6247 .83567 m .63029 .85387 L .65861 .84355 L p .707 .577 .707 r
F P
0 g
s
.65861 .84355 m .65302 .82536 L .6247 .83567 L p .707 .577 .707 r
F P
0 g
s
.56449 .85297 m .57009 .87117 L .59978 .86338 L p .707 .577 .707 r
F P
0 g
s
.51719 .72988 m .51162 .674 L .49914 .66839 L p .707 .577 .707 r
F P
0 g
s
.54628 .81208 m .53546 .7756 L .51565 .7776 L p .707 .577 .707 r
F P
0 g
s
.57009 .87117 m .56449 .85297 L .53851 .85827 L p .707 .577 .707 r
F P
0 g
s
.67374 .7339 m .68456 .77038 L .70071 .76152 L p .707 .577 .707 r
F P
0 g
s
.70071 .76152 m .68989 .72505 L .67374 .7339 L p .707 .577 .707 r
F P
0 g
s
.51565 .7776 m .52647 .81407 L .54628 .81208 L p .707 .577 .707 r
F P
0 g
s
.65302 .82536 m .65861 .84355 L .68199 .83345 L p .707 .577 .707 r
F P
0 g
s
.68199 .83345 m .6764 .81526 L .65302 .82536 L p .707 .577 .707 r
F P
0 g
s
.53851 .85827 m .54411 .87646 L .57009 .87117 L p .707 .577 .707 r
F P
0 g
s
.69212 .65322 m .6977 .70909 L .70481 .70123 L p .707 .577 .707 r
F P
0 g
s
.70481 .70123 m .69923 .64536 L .69212 .65322 L p .707 .577 .707 r
F P
0 g
s
.49914 .66839 m .50471 .72427 L .51719 .72988 L p .707 .577 .707 r
F P
0 g
s
.54411 .87646 m .53851 .85827 L .51879 .86055 L p .707 .577 .707 r
F P
0 g
s
.51879 .86055 m .52438 .87875 L .54411 .87646 L p .707 .577 .707 r
F P
0 g
s
.52647 .81407 m .51565 .7776 L .50404 .77642 L p .707 .577 .707 r
F P
0 g
s
.6764 .81526 m .68199 .83345 L .69813 .82455 L p .707 .577 .707 r
F P
0 g
s
.69813 .82455 m .69253 .80636 L .6764 .81526 L p .707 .577 .707 r
F P
0 g
s
.50471 .72427 m .49914 .66839 L .49631 .66131 L p .707 .577 .707 r
F P
0 g
s
.68989 .72505 m .70071 .76152 L .70802 .75464 L p .707 .577 .707 r
F P
0 g
s
.70802 .75464 m .69719 .71817 L .68989 .72505 L p .707 .577 .707 r
F P
0 g
s
.50404 .77642 m .51487 .81289 L .52647 .81407 L p .707 .577 .707 r
F P
0 g
s
.69923 .64536 m .70481 .70123 L .70198 .69416 L p .707 .577 .707 r
F P
0 g
s
.70198 .69416 m .69641 .63828 L .69923 .64536 L p .707 .577 .707 r
F P
0 g
s
.49631 .66131 m .50189 .71719 L .50471 .72427 L p .707 .577 .707 r
F P
0 g
s
.52438 .87875 m .51879 .86055 L .50725 .8596 L p .707 .577 .707 r
F P
0 g
s
.50725 .8596 m .51284 .8778 L .52438 .87875 L p .707 .577 .707 r
F P
0 g
s
.69253 .80636 m .69813 .82455 L .70544 .81772 L p .707 .577 .707 r
F P
0 g
s
.70544 .81772 m .69985 .79952 L .69253 .80636 L p .707 .577 .707 r
F P
0 g
s
.47783 .82164 m .49203 .32149 L .44804 .31755 L p .707 .577 .707 r
F P
0 g
s
.51487 .81289 m .50404 .77642 L .50178 .77218 L p .707 .577 .707 r
F P
0 g
s
.50189 .71719 m .49631 .66131 L .50342 .65345 L p .707 .577 .707 r
F P
0 g
s
.50178 .77218 m .5126 .80865 L .51487 .81289 L p .707 .577 .707 r
F P
0 g
s
.50342 .65345 m .509 .70933 L .50189 .71719 L p .707 .577 .707 r
F P
0 g
s
.5126 .80865 m .50178 .77218 L .50908 .7653 L p .707 .577 .707 r
F P
0 g
s
.509 .70933 m .50342 .65345 L .51977 .64558 L p .707 .577 .707 r
F P
0 g
s
.50908 .7653 m .5199 .80177 L .5126 .80865 L p .707 .577 .707 r
F P
0 g
s
.51977 .64558 m .52534 .70146 L .509 .70933 L p .707 .577 .707 r
F P
0 g
s
.5199 .80177 m .50908 .7653 L .52523 .75645 L p .707 .577 .707 r
F P
0 g
s
.52523 .75645 m .53606 .79292 L .5199 .80177 L p .707 .577 .707 r
F P
0 g
s
.49203 .32149 m .47783 .82164 L .52276 .82168 L p .707 .577 .707 r
F P
0 g
s
.52534 .70146 m .51977 .64558 L .54375 .63847 L p .707 .577 .707 r
F P
0 g
s
.54375 .63847 m .54932 .69435 L .52534 .70146 L p .707 .577 .707 r
F P
0 g
s
.52276 .82168 m .53696 .32153 L .49203 .32149 L p .707 .577 .707 r
F P
0 g
s
.54932 .69435 m .54375 .63847 L .57301 .63281 L p .707 .577 .707 r
F P
0 g
s
.53606 .79292 m .52523 .75645 L .54865 .74649 L p .707 .577 .707 r
F P
0 g
s
.57301 .63281 m .57859 .68869 L .54932 .69435 L p .707 .577 .707 r
F P
0 g
s
.54865 .74649 m .55947 .78297 L .53606 .79292 L p .707 .577 .707 r
F P
0 g
s
.55947 .78297 m .54865 .74649 L .57705 .73641 L p .707 .577 .707 r
F P
0 g
s
.57705 .73641 m .58787 .77288 L .55947 .78297 L p .707 .577 .707 r
F P
0 g
s
.53696 .32153 m .52276 .82168 L .56423 .81781 L p .707 .577 .707 r
F P
0 g
s
.56423 .81781 m .57843 .31766 L .53696 .32153 L p .707 .577 .707 r
F P
0 g
s
.69719 .71817 m .70802 .75464 L .70575 .75041 L p .707 .577 .707 r
F P
0 g
s
.70575 .75041 m .69493 .71393 L .69719 .71817 L p .707 .577 .707 r
F P
0 g
s
.43384 .8177 m .44804 .31755 L .4093 .31009 L p .707 .577 .707 r
F P
0 g
s
.44804 .31755 m .43384 .8177 L .47783 .82164 L p .707 .577 .707 r
F P
0 g
s
.69641 .63828 m .70198 .69416 L .68951 .68855 L p .707 .577 .707 r
F P
0 g
s
.68951 .68855 m .68393 .63267 L .69641 .63828 L p .707 .577 .707 r
F P
0 g
s
.57859 .68869 m .57301 .63281 L .60471 .62916 L p .707 .577 .707 r
F P
0 g
s
.60471 .62916 m .61028 .68504 L .57859 .68869 L p .707 .577 .707 r
F P
0 g
s
.58787 .77288 m .57705 .73641 L .60764 .72718 L p .707 .577 .707 r
F P
0 g
s
.60764 .72718 m .61846 .76366 L .58787 .77288 L p .707 .577 .707 r
F P
0 g
s
.57843 .31766 m .56423 .81781 L .59818 .81041 L p .707 .577 .707 r
F P
0 g
s
.59818 .81041 m .61238 .31026 L .57843 .31766 L p .707 .577 .707 r
F P
0 g
s
.51284 .8778 m .50725 .8596 L .50503 .85551 L p .707 .577 .707 r
F P
0 g
s
.50503 .85551 m .51063 .87371 L .51284 .8778 L p .707 .577 .707 r
F P
0 g
s
.69985 .79952 m .70544 .81772 L .70322 .81363 L p .707 .577 .707 r
F P
0 g
s
.70322 .81363 m .69763 .79543 L .69985 .79952 L p .707 .577 .707 r
F P
0 g
s
.3951 .81024 m .4093 .31009 L .37959 .29984 L p .707 .577 .707 r
F P
0 g
s
.4093 .31009 m .3951 .81024 L .43384 .8177 L p .707 .577 .707 r
F P
0 g
s
.25341 .72222 m .24783 .66634 L .21682 .66762 L p .707 .577 .707 r
F P
0 g
s
.24783 .66634 m .25341 .72222 L .2851 .71857 L p .707 .577 .707 r
F P
0 g
s
.2851 .71857 m .27952 .66269 L .24783 .66634 L p .707 .577 .707 r
F P
0 g
s
.27952 .66269 m .2851 .71857 L .31437 .71291 L p .707 .577 .707 r
F P
0 g
s
.31437 .71291 m .30879 .65703 L .27952 .66269 L p .707 .577 .707 r
F P
0 g
s
.69493 .71393 m .70575 .75041 L .69415 .74923 L p .707 .577 .707 r
F P
0 g
s
.69415 .74923 m .68332 .71275 L .69493 .71393 L p .707 .577 .707 r
F P
0 g
s
.22239 .7235 m .21682 .66762 L .18952 .66641 L p .707 .577 .707 r
F P
0 g
s
.21682 .66762 m .22239 .7235 L .25341 .72222 L p .707 .577 .707 r
F P
0 g
s
.68393 .63267 m .68951 .68855 L .66859 .68497 L p .707 .577 .707 r
F P
0 g
s
.66859 .68497 m .66302 .62909 L .68393 .63267 L p .707 .577 .707 r
F P
0 g
s
.30879 .65703 m .31437 .71291 L .33835 .7058 L p .707 .577 .707 r
F P
0 g
s
.33835 .7058 m .33277 .64992 L .30879 .65703 L p .707 .577 .707 r
F P
0 g
s
.63572 .62788 m .6413 .68376 L .61028 .68504 L p .707 .577 .707 r
F P
0 g
s
.61028 .68504 m .60471 .62916 L .63572 .62788 L p .707 .577 .707 r
F P
0 g
s
.63743 .71972 m .64826 .75619 L .61846 .76366 L p .707 .577 .707 r
F P
0 g
s
.61846 .76366 m .60764 .72718 L .63743 .71972 L p .707 .577 .707 r
F P
0 g
s
.61238 .31026 m .59818 .81041 L .62129 .80021 L p .707 .577 .707 r
F P
0 g
s
.62129 .80021 m .63549 .30006 L .61238 .31026 L p .707 .577 .707 r
F P
0 g
s
.25915 .76438 m .24833 .72791 L .21853 .73537 L p .707 .577 .707 r
F P
0 g
s
.24833 .72791 m .25915 .76438 L .28974 .75515 L p .707 .577 .707 r
F P
0 g
s
.28974 .75515 m .27892 .71868 L .24833 .72791 L p .707 .577 .707 r
F P
0 g
s
.27892 .71868 m .28974 .75515 L .31814 .74507 L p .707 .577 .707 r
F P
0 g
s
.31814 .74507 m .30731 .7086 L .27892 .71868 L p .707 .577 .707 r
F P
0 g
s
.51063 .87371 m .50503 .85551 L .51235 .84868 L p .707 .577 .707 r
F P
0 g
s
.18952 .66641 m .1951 .72229 L .22239 .7235 L p .707 .577 .707 r
F P
0 g
s
.51235 .84868 m .51794 .86688 L .51063 .87371 L p .707 .577 .707 r
F P
0 g
s
.21853 .73537 m .22935 .77184 L .25915 .76438 L p .707 .577 .707 r
F P
0 g
s
.1951 .72229 m .18952 .66641 L .16861 .66283 L p .707 .577 .707 r
F P
0 g
s
.69763 .79543 m .70322 .81363 L .69169 .81268 L p .707 .577 .707 r
F P
0 g
s
.69169 .81268 m .68609 .79449 L .69763 .79543 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21853 .73537 L .21469 .7361 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21469 .7361 L .22413 .76738 L .707 .577 .707 r
F
.22566 .77248 m .22148 .77357 L p .22644 .77503 L F P
0 g
s
.19245 .74034 m .20327 .77682 L .22935 .77184 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .25118 .76579 L .22566 .77248 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .22566 .77248 L .22644 .77503 L .707 .577 .707 r
F
.21469 .7361 m .19245 .74034 L p .22413 .76738 L F P
0 g
s
.25118 .76579 m .25678 .78398 L .28728 .77447 L p .707 .577 .707 r
F P
0 g
s
.28728 .77447 m .28169 .75627 L .25118 .76579 L p .707 .577 .707 r
F P
0 g
s
.28169 .75627 m .28728 .77447 L .31561 .76416 L p .707 .577 .707 r
F P
0 g
s
.31561 .76416 m .31001 .74596 L .28169 .75627 L p .707 .577 .707 r
F P
0 g
s
.33277 .64992 m .33835 .7058 L .35469 .69793 L p .707 .577 .707 r
F P
0 g
s
.34688 .68979 m .35771 .72626 L .35957 .72451 L p .707 .577 .707 r
F P
0 g
s
.35957 .72451 m .36501 .71938 L p .35864 .70899 L .707 .577 .707 r
F P
0 g
s
.35864 .70899 m .34688 .68979 L .35957 .72451 L .707 .577 .707 r
F
.36182 .28781 m .35774 .27517 L p .35152 .59032 L F P
0 g
s
.35469 .69793 m .34911 .64205 L .33277 .64992 L p .707 .577 .707 r
F P
0 g
s
.33073 .69864 m .34155 .73512 L .35771 .72626 L p .707 .577 .707 r
F P
0 g
s
.35771 .72626 m .34688 .68979 L .33073 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .7086 m .31814 .74507 L .34155 .73512 L p .707 .577 .707 r
F P
0 g
s
.33339 .73586 m .33898 .75405 L .35512 .74515 L p .707 .577 .707 r
F P
0 g
s
.34155 .73512 m .33073 .69864 L .30731 .7086 L p .707 .577 .707 r
F P
0 g
s
.35512 .74515 m .34952 .72696 L .33339 .73586 L p .707 .577 .707 r
F P
0 g
s
.34911 .64205 m .35469 .69793 L .3618 .69007 L p .707 .577 .707 r
F P
0 g
s
.3618 .69007 m .35622 .63419 L .34911 .64205 L p .707 .577 .707 r
F P
0 g
s
.36501 .71938 m .35418 .68291 L .34688 .68979 L p .707 .577 .707 r
F P
0 g
s
.3534 .62711 m .35589 .65202 L p .3465 .67738 L .707 .577 .707 r
F P
0 g
s
.35589 .65202 m .35898 .68299 L .35409 .6808 L p .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .35418 .68291 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.36274 .71515 m .3619 .71231 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.3619 .71231 m .35192 .67867 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .36274 .71515 L .35114 .71397 L p .707 .577 .707 r
F P
0 g
s
.35114 .71397 m .34032 .67749 L .35192 .67867 L p .707 .577 .707 r
F P
0 g
s
.35409 .6808 m .35178 .67976 L p .35589 .65202 L .707 .577 .707 r
F P
0 g
s
.35178 .67976 m .3465 .67738 L p .34897 .67071 L .707 .577 .707 r
F P
0 g
s
.34897 .67071 m .35589 .65202 L .35178 .67976 L .707 .577 .707 r
F
.3465 .67738 m .34092 .62151 L .3534 .62711 L p F P
0 g
s
.34952 .72696 m .35512 .74515 L .36243 .73832 L p .707 .577 .707 r
F P
0 g
s
.36243 .73832 m .35684 .72013 L .34952 .72696 L p .707 .577 .707 r
F P
0 g
s
.35462 .71604 m .36021 .73423 L .35174 .73353 L p .707 .577 .707 r
F P
0 g
s
.35174 .73353 m .34868 .73328 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.35351 .71926 m .35462 .71604 L .35174 .73353 L .707 .577 .707 r
F
.34868 .73328 m .34308 .71509 L .35392 .71598 L p F P
0 g
s
.35392 .71598 m .35462 .71604 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.34868 .73328 m .35392 .71598 L .35351 .71926 L .707 .577 .707 r
F
.3478 .78171 m .34841 .76035 L p .34772 .78298 L F P
0 g
s
.34032 .67749 m .35114 .71397 L .33133 .71596 L p .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .35268 .60969 L p .34836 .76074 L .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .34836 .76074 L .34772 .78298 L .707 .577 .707 r
F
.34812 .76263 m .35268 .60969 L .35152 .59032 L F
.34772 .78298 m .34836 .76074 L .34812 .76263 L F
.34836 .76074 m .35268 .60969 L .34812 .76263 L F
.34762 .78796 m .3478 .78171 L p .34772 .78298 L F P
0 g
s
.35268 .60969 m .36182 .28781 L p .35152 .59032 L .707 .577 .707 r
F P
0 g
s
.35418 .68291 m .36501 .71938 L .36274 .71515 L p .707 .577 .707 r
F P
0 g
s
.36539 .79999 m .37959 .29984 L .36182 .28781 L p .707 .577 .707 r
F P
0 g
s
.37959 .29984 m .36539 .79999 L .3951 .81024 L p .707 .577 .707 r
F P
0 g
s
.22148 .77357 m .22708 .79177 L .25678 .78398 L p .707 .577 .707 r
F P
0 g
s
.68332 .71275 m .69415 .74923 L .67434 .75122 L p .707 .577 .707 r
F P
0 g
s
.67434 .75122 m .66351 .71475 L .68332 .71275 L p .707 .577 .707 r
F P
0 g
s
.66302 .62909 m .66859 .68497 L .6413 .68376 L p .707 .577 .707 r
F P
0 g
s
.6413 .68376 m .63572 .62788 L .66302 .62909 L p .707 .577 .707 r
F P
0 g
s
.22708 .79177 m .22148 .77357 L .1955 .77887 L p .707 .577 .707 r
F P
0 g
s
.16861 .66283 m .17418 .71871 L .1951 .72229 L p .707 .577 .707 r
F P
0 g
s
.31001 .74596 m .31561 .76416 L .33898 .75405 L p .707 .577 .707 r
F P
0 g
s
.33898 .75405 m .33339 .73586 L .31001 .74596 L p .707 .577 .707 r
F P
0 g
s
.1955 .77887 m .2011 .79706 L .22708 .79177 L p .707 .577 .707 r
F P
0 g
s
.20327 .77682 m .19245 .74034 L .17264 .74234 L p .707 .577 .707 r
F P
0 g
s
.17418 .71871 m .16861 .66283 L .15613 .65723 L p .707 .577 .707 r
F P
0 g
s
.17264 .74234 m .18346 .77881 L .20327 .77682 L p .707 .577 .707 r
F P
0 g
s
.51794 .86688 m .51235 .84868 L .52848 .83978 L p .707 .577 .707 r
F P
0 g
s
.63549 .30006 m .62129 .80021 L .63129 .7882 L p .707 .577 .707 r
F P
0 g
s
.63129 .7882 m .64549 .28805 L .63549 .30006 L p .707 .577 .707 r
F P
0 g
s
.52848 .83978 m .53408 .85798 L .51794 .86688 L p .707 .577 .707 r
F P
0 g
s
.2011 .79706 m .1955 .77887 L .17578 .78115 L p .707 .577 .707 r
F P
0 g
s
.68609 .79449 m .69169 .81268 L .67196 .81496 L p .707 .577 .707 r
F P
0 g
s
.67196 .81496 m .66637 .79677 L .68609 .79449 L p .707 .577 .707 r
F P
0 g
s
.17578 .78115 m .18137 .79935 L .2011 .79706 L p .707 .577 .707 r
F P
0 g
s
.66351 .71475 m .67434 .75122 L .64826 .75619 L p .707 .577 .707 r
F P
0 g
s
.64826 .75619 m .63743 .71972 L .66351 .71475 L p .707 .577 .707 r
F P
0 g
s
.15613 .65723 m .1617 .7131 L .17418 .71871 L p .707 .577 .707 r
F P
0 g
s
.35622 .63419 m .3618 .69007 L .35898 .68299 L p .707 .577 .707 r
F P
0 g
s
.35898 .68299 m .3534 .62711 L .35622 .63419 L p .707 .577 .707 r
F P
0 g
s
.35684 .72013 m .36243 .73832 L .36021 .73423 L p .707 .577 .707 r
F P
0 g
s
.36021 .73423 m .35462 .71604 L .35684 .72013 L p .707 .577 .707 r
F P
0 g
s
.36182 .28781 m .34762 .78796 L .36539 .79999 L p .707 .577 .707 r
F P
0 g
s
.18346 .77881 m .17264 .74234 L .16103 .74116 L p .707 .577 .707 r
F P
0 g
s
.16103 .74116 m .17186 .77763 L .18346 .77881 L p .707 .577 .707 r
F P
0 g
s
.53408 .85798 m .52848 .83978 L .55186 .82968 L p .707 .577 .707 r
F P
0 g
s
.1617 .7131 m .15613 .65723 L .15331 .65015 L p .707 .577 .707 r
F P
0 g
s
.18137 .79935 m .17578 .78115 L .16424 .7802 L p .707 .577 .707 r
F P
0 g
s
.55186 .82968 m .55745 .84787 L .53408 .85798 L p .707 .577 .707 r
F P
0 g
s
.66637 .79677 m .67196 .81496 L .64598 .82026 L p .707 .577 .707 r
F P
0 g
s
.64598 .82026 m .64039 .80206 L .66637 .79677 L p .707 .577 .707 r
F P
0 g
s
.16424 .7802 m .16984 .7984 L .18137 .79935 L p .707 .577 .707 r
F P
0 g
s
.15331 .65015 m .15888 .70602 L .1617 .7131 L p .707 .577 .707 r
F P
0 g
s
.64549 .28805 m .63129 .7882 L .62721 .77556 L p .707 .577 .707 r
F P
0 g
s
.62721 .77556 m .64141 .27541 L .64549 .28805 L p .707 .577 .707 r
F P
0 g
s
.55745 .84787 m .55186 .82968 L .58019 .81936 L p .707 .577 .707 r
F P
0 g
s
.64039 .80206 m .64598 .82026 L .61628 .82804 L p .707 .577 .707 r
F P
0 g
s
.61628 .82804 m .61069 .80985 L .64039 .80206 L p .707 .577 .707 r
F P
0 g
s
.58019 .81936 m .58578 .83756 L .55745 .84787 L p .707 .577 .707 r
F P
0 g
s
.17186 .77763 m .16103 .74116 L .15877 .73692 L p .707 .577 .707 r
F P
0 g
s
.15877 .73692 m .16959 .77339 L .17186 .77763 L p .707 .577 .707 r
F P
0 g
s
.58578 .83756 m .58019 .81936 L .61069 .80985 L p .707 .577 .707 r
F P
0 g
s
.61069 .80985 m .61628 .82804 L .58578 .83756 L p .707 .577 .707 r
F P
0 g
s
.16984 .7984 m .16424 .7802 L .16202 .77611 L p .707 .577 .707 r
F P
0 g
s
.15888 .70602 m .15331 .65015 L .16041 .64229 L p .707 .577 .707 r
F P
0 g
s
.16202 .77611 m .16762 .79431 L .16984 .7984 L p .707 .577 .707 r
F P
0 g
s
.34092 .62151 m .3465 .67738 L .32559 .6738 L p .707 .577 .707 r
F P
0 g
s
.34308 .71509 m .34868 .73328 L .32895 .73557 L p .707 .577 .707 r
F P
0 g
s
.35774 .27517 m .34354 .77532 L .34762 .78796 L p .707 .577 .707 r
F P
0 g
s
.34354 .77532 m .35774 .27517 L .36774 .26316 L p .707 .577 .707 r
F P
0 g
s
.16041 .64229 m .16599 .69816 L .15888 .70602 L p .707 .577 .707 r
F P
0 g
s
.16959 .77339 m .15877 .73692 L .16607 .73004 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16607 .73004 m .1769 .76651 L .16959 .77339 L p .707 .577 .707 r
F P
0 g
s
.64141 .27541 m .62721 .77556 L .60944 .76353 L p .707 .577 .707 r
F P
0 g
s
.60944 .76353 m .62364 .26338 L .64141 .27541 L p .707 .577 .707 r
F P
0 g
s
.16599 .69816 m .16041 .64229 L .17676 .63441 L p .707 .577 .707 r
F P
0 g
s
.16762 .79431 m .16202 .77611 L .16934 .76928 L p .707 .577 .707 r
F P
0 g
s
.16934 .76928 m .17493 .78748 L .16762 .79431 L p .707 .577 .707 r
F P
0 g
s
.32559 .6738 m .32001 .61792 L .34092 .62151 L p .707 .577 .707 r
F P
0 g
s
.17676 .63441 m .18233 .69029 L .16599 .69816 L p .707 .577 .707 r
F P
0 g
s
.35354 .76331 m .36774 .26316 L .39085 .25296 L p .707 .577 .707 r
F P
0 g
s
.36774 .26316 m .35354 .76331 L .34354 .77532 L p .707 .577 .707 r
F P
0 g
s
.1769 .76651 m .16607 .73004 L .18222 .72119 L p .707 .577 .707 r
F P
0 g
s
.18233 .69029 m .17676 .63441 L .20074 .6273 L p .707 .577 .707 r
F P
0 g
s
.33133 .71596 m .3205 .67949 L .34032 .67749 L p .707 .577 .707 r
F P
0 g
s
.18222 .72119 m .19305 .75766 L .1769 .76651 L p .707 .577 .707 r
F P
0 g
s
.17493 .78748 m .16934 .76928 L .18548 .76038 L p .707 .577 .707 r
F P
0 g
s
.18548 .76038 m .19107 .77858 L .17493 .78748 L p .707 .577 .707 r
F P
0 g
s
.32001 .61792 m .32559 .6738 L .29829 .67259 L p .707 .577 .707 r
F P
0 g
s
.29829 .67259 m .29271 .61671 L .32001 .61792 L p .707 .577 .707 r
F P
0 g
s
.32895 .73557 m .32336 .71737 L .34308 .71509 L p .707 .577 .707 r
F P
0 g
s
.62364 .26338 m .60944 .76353 L .57973 .75328 L p .707 .577 .707 r
F P
0 g
s
.57973 .75328 m .59393 .25313 L .62364 .26338 L p .707 .577 .707 r
F P
0 g
s
.20074 .6273 m .20631 .68318 L .18233 .69029 L p .707 .577 .707 r
F P
0 g
s
.20631 .68318 m .20074 .6273 L .23001 .62164 L p .707 .577 .707 r
F P
0 g
s
.19305 .75766 m .18222 .72119 L .20564 .71123 L p .707 .577 .707 r
F P
0 g
s
.29271 .61671 m .29829 .67259 L .26727 .67387 L p .707 .577 .707 r
F P
0 g
s
.26727 .67387 m .2617 .618 L .29271 .61671 L p .707 .577 .707 r
F P
0 g
s
.39085 .25296 m .37665 .75311 L .35354 .76331 L p .707 .577 .707 r
F P
0 g
s
.37665 .75311 m .39085 .25296 L .4248 .24556 L p .707 .577 .707 r
F P
0 g
s
.32336 .71737 m .32895 .73557 L .30297 .74086 L p .707 .577 .707 r
F P
0 g
s
.30105 .72198 m .27545 .7284 L p .29165 .69089 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .29738 .72266 L .30103 .72192 L p .707 .577 .707 r
F P
0 g
s
.30103 .72192 m .32336 .71737 L p .30578 .73762 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .30103 .72192 L .30578 .73762 L .707 .577 .707 r
F
.29442 .68446 m .30525 .72093 L .30105 .72198 L p F P
0 g
s
.29165 .69089 m .29442 .68446 L .30105 .72198 L .707 .577 .707 r
F
.3205 .67949 m .33133 .71596 L .30525 .72093 L p F P
0 g
s
.30525 .72093 m .29442 .68446 L .3205 .67949 L p .707 .577 .707 r
F P
0 g
s
.73362 .64135 m .72804 .58547 L .69703 .58675 L p .707 .577 .707 r
F P
0 g
s
.72804 .58547 m .73362 .64135 L .76531 .6377 L p .707 .577 .707 r
F P
0 g
s
.76531 .6377 m .75974 .58182 L .72804 .58547 L p .707 .577 .707 r
F P
0 g
s
.20564 .71123 m .21647 .74771 L .19305 .75766 L p .707 .577 .707 r
F P
0 g
s
.75974 .58182 m .76531 .6377 L .79458 .63204 L p .707 .577 .707 r
F P
0 g
s
.79458 .63204 m .789 .57616 L .75974 .58182 L p .707 .577 .707 r
F P
0 g
s
.23558 .67752 m .23001 .62164 L .2617 .618 L p .707 .577 .707 r
F P
0 g
s
.23001 .62164 m .23558 .67752 L .20631 .68318 L p .707 .577 .707 r
F P
0 g
s
.19107 .77858 m .18548 .76038 L .20885 .75028 L p .707 .577 .707 r
F P
0 g
s
.2617 .618 m .26727 .67387 L .23558 .67752 L p .707 .577 .707 r
F P
0 g
s
.70261 .64263 m .69703 .58675 L .66973 .58554 L p .707 .577 .707 r
F P
0 g
s
.69703 .58675 m .70261 .64263 L .73362 .64135 L p .707 .577 .707 r
F P
0 g
s
.20885 .75028 m .21444 .76847 L .19107 .77858 L p .707 .577 .707 r
F P
0 g
s
.789 .57616 m .79458 .63204 L .81856 .62493 L p .707 .577 .707 r
F P
0 g
s
.81856 .62493 m .81298 .56905 L .789 .57616 L p .707 .577 .707 r
F P
0 g
s
.21647 .74771 m .20564 .71123 L .23404 .70115 L p .707 .577 .707 r
F P
0 g
s
.27545 .7284 m .26463 .69192 L .29442 .68446 L p .707 .577 .707 r
F P
0 g
s
.59393 .25313 m .57973 .75328 L .54099 .74582 L p .707 .577 .707 r
F P
0 g
s
.54099 .74582 m .55519 .24567 L .59393 .25313 L p .707 .577 .707 r
F P
0 g
s
.23404 .70115 m .24486 .73762 L .21647 .74771 L p .707 .577 .707 r
F P
0 g
s
.66973 .58554 m .67531 .64142 L .70261 .64263 L p .707 .577 .707 r
F P
0 g
s
.73936 .7076 m .72854 .67113 L .69874 .67859 L p .707 .577 .707 r
F P
0 g
s
.72854 .67113 m .73936 .7076 L .76995 .69838 L p .707 .577 .707 r
F P
0 g
s
.76995 .69838 m .75913 .6619 L .72854 .67113 L p .707 .577 .707 r
F P
0 g
s
.67531 .64142 m .66973 .58554 L .64882 .58196 L p .707 .577 .707 r
F P
0 g
s
.21444 .76847 m .20885 .75028 L .23718 .73997 L p .707 .577 .707 r
F P
0 g
s
.75913 .6619 m .76995 .69838 L .79835 .68829 L p .707 .577 .707 r
F P
0 g
s
.79835 .68829 m .78753 .65182 L .75913 .6619 L p .707 .577 .707 r
F P
0 g
s
.24486 .73762 m .23404 .70115 L .26463 .69192 L p .707 .577 .707 r
F P
0 g
s
.26463 .69192 m .27545 .7284 L .24486 .73762 L p .707 .577 .707 r
F P
0 g
s
.29738 .72266 m .30297 .74086 L .27327 .74865 L p .707 .577 .707 r
F P
0 g
s
.27327 .74865 m .26768 .73045 L .29738 .72266 L p .707 .577 .707 r
F P
0 g
s
.23718 .73997 m .24277 .75816 L .21444 .76847 L p .707 .577 .707 r
F P
0 g
s
.4106 .74571 m .4248 .24556 L .46627 .24169 L p .707 .577 .707 r
F P
0 g
s
.4248 .24556 m .4106 .74571 L .37665 .75311 L p .707 .577 .707 r
F P
0 g
s
.69874 .67859 m .70957 .71507 L .73936 .7076 L p .707 .577 .707 r
F P
0 g
s
.70957 .71507 m .69874 .67859 L .67266 .68356 L p .707 .577 .707 r
F P
0 g
s
.81298 .56905 m .81856 .62493 L .8349 .61706 L p .707 .577 .707 r
F P
0 g
s
.8349 .61706 m .82933 .56118 L .81298 .56905 L p .707 .577 .707 r
F P
0 g
s
.24277 .75816 m .23718 .73997 L .26768 .73045 L p .707 .577 .707 r
F P
0 g
s
.78753 .65182 m .79835 .68829 L .82177 .67834 L p .707 .577 .707 r
F P
0 g
s
.82177 .67834 m .81095 .64186 L .78753 .65182 L p .707 .577 .707 r
F P
0 g
s
.26768 .73045 m .27327 .74865 L .24277 .75816 L p .707 .577 .707 r
F P
0 g
s
.64882 .58196 m .6544 .63784 L .67531 .64142 L p .707 .577 .707 r
F P
0 g
s
.67266 .68356 m .68349 .72004 L .70957 .71507 L p .707 .577 .707 r
F P
0 g
s
.55519 .24567 m .54099 .74582 L .497 .74188 L p .707 .577 .707 r
F P
0 g
s
.497 .74188 m .5112 .24173 L .55519 .24567 L p .707 .577 .707 r
F P
0 g
s
.73699 .77134 m .7314 .75315 L .7017 .76094 L p .707 .577 .707 r
F P
0 g
s
.7314 .75315 m .73699 .77134 L .76749 .76183 L p .707 .577 .707 r
F P
0 g
s
.76749 .76183 m .7619 .74363 L .7314 .75315 L p .707 .577 .707 r
F P
0 g
s
.45369 .68474 m .46627 .24169 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .45207 .74184 L .4106 .74571 L p .707 .577 .707 r
F P
0 g
s
.38503 .5743 m .39061 .63018 L .4223 .62653 L p .707 .577 .707 r
F P
0 g
s
.41612 .62664 m .42261 .64852 L p .45534 .65303 L .707 .577 .707 r
F P
0 g
s
.42261 .64852 m .42694 .66312 L .43322 .66089 L p .707 .577 .707 r
F P
0 g
s
.43322 .66089 m .45534 .65303 L p .42261 .64852 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .5112 .24173 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.45207 .74184 m .45369 .68474 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.7619 .74363 m .76749 .76183 L .79582 .75152 L p .707 .577 .707 r
F P
0 g
s
.79582 .75152 m .79023 .73332 L .7619 .74363 L p .707 .577 .707 r
F P
0 g
s
.7017 .76094 m .70729 .77913 L .73699 .77134 L p .707 .577 .707 r
F P
0 g
s
.6544 .63784 m .64882 .58196 L .63634 .57635 L p .707 .577 .707 r
F P
0 g
s
.5112 .24173 m .497 .74188 L .45207 .74184 L p .707 .577 .707 r
F P
0 g
s
.68349 .72004 m .67266 .68356 L .65285 .68556 L p .707 .577 .707 r
F P
0 g
s
.70729 .77913 m .7017 .76094 L .67572 .76623 L p .707 .577 .707 r
F P
0 g
s
.81095 .64186 m .82177 .67834 L .83792 .66949 L p .707 .577 .707 r
F P
0 g
s
.83792 .66949 m .8271 .63301 L .81095 .64186 L p .707 .577 .707 r
F P
0 g
s
.65285 .68556 m .66368 .72203 L .68349 .72004 L p .707 .577 .707 r
F P
0 g
s
.79023 .73332 m .79582 .75152 L .81919 .74141 L p .707 .577 .707 r
F P
0 g
s
.81919 .74141 m .8136 .72322 L .79023 .73332 L p .707 .577 .707 r
F P
0 g
s
.67572 .76623 m .68131 .78442 L .70729 .77913 L p .707 .577 .707 r
F P
0 g
s
.82933 .56118 m .8349 .61706 L .84201 .6092 L p .707 .577 .707 r
F P
0 g
s
.84201 .6092 m .83644 .55332 L .82933 .56118 L p .707 .577 .707 r
F P
0 g
s
.63634 .57635 m .64192 .63223 L .6544 .63784 L p .707 .577 .707 r
F P
0 g
s
.68131 .78442 m .67572 .76623 L .65599 .76851 L p .707 .577 .707 r
F P
0 g
s
.65599 .76851 m .66158 .78671 L .68131 .78442 L p .707 .577 .707 r
F P
0 g
s
.66368 .72203 m .65285 .68556 L .64125 .68438 L p .707 .577 .707 r
F P
0 g
s
.8136 .72322 m .81919 .74141 L .83533 .73251 L p .707 .577 .707 r
F P
0 g
s
.83533 .73251 m .82974 .71432 L .8136 .72322 L p .707 .577 .707 r
F P
0 g
s
.64192 .63223 m .63634 .57635 L .63352 .56927 L p .707 .577 .707 r
F P
0 g
s
.8271 .63301 m .83792 .66949 L .84522 .6626 L p .707 .577 .707 r
F P
0 g
s
.84522 .6626 m .8344 .62613 L .8271 .63301 L p .707 .577 .707 r
F P
0 g
s
.64125 .68438 m .65207 .72085 L .66368 .72203 L p .707 .577 .707 r
F P
0 g
s
.83644 .55332 m .84201 .6092 L .83919 .60212 L p .707 .577 .707 r
F P
0 g
s
.83919 .60212 m .83361 .54624 L .83644 .55332 L p .707 .577 .707 r
F P
0 g
s
.63352 .56927 m .63909 .62515 L .64192 .63223 L p .707 .577 .707 r
F P
0 g
s
.66158 .78671 m .65599 .76851 L .64445 .76756 L p .707 .577 .707 r
F P
0 g
s
.64445 .76756 m .65005 .78576 L .66158 .78671 L p .707 .577 .707 r
F P
0 g
s
.82974 .71432 m .83533 .73251 L .84265 .72568 L p .707 .577 .707 r
F P
0 g
s
.84265 .72568 m .83705 .70749 L .82974 .71432 L p .707 .577 .707 r
F P
0 g
s
.65207 .72085 m .64125 .68438 L .63898 .68014 L p .707 .577 .707 r
F P
0 g
s
.63909 .62515 m .63352 .56927 L .64063 .56141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63898 .68014 m .64981 .71662 L .65207 .72085 L p .707 .577 .707 r
F P
0 g
s
.8344 .62613 m .84522 .6626 L .84296 .65837 L p .707 .577 .707 r
F P
0 g
s
.84296 .65837 m .83213 .62189 L .8344 .62613 L p .707 .577 .707 r
F P
0 g
s
.83361 .54624 m .83919 .60212 L .82671 .59651 L p .707 .577 .707 r
F P
0 g
s
.82671 .59651 m .82114 .54063 L .83361 .54624 L p .707 .577 .707 r
F P
0 g
s
.64063 .56141 m .6462 .61729 L .63909 .62515 L p .707 .577 .707 r
F P
0 g
s
.65005 .78576 m .64445 .76756 L .64224 .76347 L p .707 .577 .707 r
F P
0 g
s
.64224 .76347 m .64783 .78167 L .65005 .78576 L p .707 .577 .707 r
F P
0 g
s
.83705 .70749 m .84265 .72568 L .84043 .72159 L p .707 .577 .707 r
F P
0 g
s
.84043 .72159 m .83483 .7034 L .83705 .70749 L p .707 .577 .707 r
F P
0 g
s
.64981 .71662 m .63898 .68014 L .64629 .67326 L p .707 .577 .707 r
F P
0 g
s
.6462 .61729 m .64063 .56141 L .65697 .55354 L p .707 .577 .707 r
F P
0 g
s
.39061 .63018 m .38503 .5743 L .35402 .57558 L p .707 .577 .707 r
F P
0 g
s
.4223 .62653 m .41673 .57065 L .38503 .5743 L p .707 .577 .707 r
F P
0 g
s
.41673 .57065 m .4223 .62653 L .45157 .62087 L p .707 .577 .707 r
F P
0 g
s
.45157 .62087 m .44599 .565 L .41673 .57065 L p .707 .577 .707 r
F P
0 g
s
.64629 .67326 m .65711 .70973 L .64981 .71662 L p .707 .577 .707 r
F P
0 g
s
.83213 .62189 m .84296 .65837 L .83135 .65719 L p .707 .577 .707 r
F P
0 g
s
.83135 .65719 m .82053 .62071 L .83213 .62189 L p .707 .577 .707 r
F P
0 g
s
.3596 .63146 m .35402 .57558 L .32672 .57437 L p .707 .577 .707 r
F P
0 g
s
.35402 .57558 m .3596 .63146 L .39061 .63018 L p .707 .577 .707 r
F P
0 g
s
.82114 .54063 m .82671 .59651 L .8058 .59293 L p .707 .577 .707 r
F P
0 g
s
.8058 .59293 m .80022 .53705 L .82114 .54063 L p .707 .577 .707 r
F P
0 g
s
.65697 .55354 m .66255 .60942 L .6462 .61729 L p .707 .577 .707 r
F P
0 g
s
.44599 .565 m .45157 .62087 L .47555 .61376 L p .707 .577 .707 r
F P
0 g
s
.47555 .61376 m .46997 .55788 L .44599 .565 L p .707 .577 .707 r
F P
0 g
s
.39635 .67234 m .38553 .63587 L .35573 .64333 L p .707 .577 .707 r
F P
0 g
s
.38553 .63587 m .39635 .67234 L .42694 .66312 L p .707 .577 .707 r
F P
0 g
s
.42694 .66312 m .41612 .62664 L .38553 .63587 L p .707 .577 .707 r
F P
0 g
s
.45534 .65303 m .44452 .61656 L .41612 .62664 L p .707 .577 .707 r
F P
0 g
s
.64783 .78167 m .64224 .76347 L .64955 .75664 L p .707 .577 .707 r
F P
0 g
s
.32672 .57437 m .3323 .63025 L .3596 .63146 L p .707 .577 .707 r
F P
0 g
s
.64955 .75664 m .65515 .77484 L .64783 .78167 L p .707 .577 .707 r
F P
0 g
s
.35573 .64333 m .36656 .67981 L .39635 .67234 L p .707 .577 .707 r
F P
0 g
s
.3323 .63025 m .32672 .57437 L .30581 .57079 L p .707 .577 .707 r
F P
0 g
s
.83483 .7034 m .84043 .72159 L .82889 .72064 L p .707 .577 .707 r
F P
0 g
s
.82889 .72064 m .8233 .70245 L .83483 .7034 L p .707 .577 .707 r
F P
0 g
s
.66255 .60942 m .65697 .55354 L .68095 .54643 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35573 .64333 L .35189 .64406 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35189 .64406 L .36133 .67534 L .707 .577 .707 r
F
.36287 .68044 m .35869 .68154 L p .36364 .683 L F P
0 g
s
.32965 .6483 m .34048 .68478 L .36656 .67981 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .38839 .67375 L .36287 .68044 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .36287 .68044 L .36364 .683 L .707 .577 .707 r
F
.35189 .64406 m .32965 .6483 L p .36133 .67534 L F P
0 g
s
.38839 .67375 m .39398 .69195 L .42448 .68243 L p .707 .577 .707 r
F P
0 g
s
.42448 .68243 m .41889 .66424 L .38839 .67375 L p .707 .577 .707 r
F P
0 g
s
.41889 .66424 m .42448 .68243 L .45281 .67212 L p .707 .577 .707 r
F P
0 g
s
.45281 .67212 m .44722 .65392 L .41889 .66424 L p .707 .577 .707 r
F P
0 g
s
.65711 .70973 m .64629 .67326 L .66244 .66441 L p .707 .577 .707 r
F P
0 g
s
.44452 .61656 m .45534 .65303 L .47876 .64308 L p .707 .577 .707 r
F P
0 g
s
.47876 .64308 m .46794 .6066 L .44452 .61656 L p .707 .577 .707 r
F P
0 g
s
.35869 .68154 m .36428 .69973 L .39398 .69195 L p .707 .577 .707 r
F P
0 g
s
.82053 .62071 m .83135 .65719 L .81154 .65918 L p .707 .577 .707 r
F P
0 g
s
.81154 .65918 m .80072 .62271 L .82053 .62071 L p .707 .577 .707 r
F P
0 g
s
.66244 .66441 m .67326 .70088 L .65711 .70973 L p .707 .577 .707 r
F P
0 g
s
.46997 .55788 m .47555 .61376 L .49189 .60589 L p .707 .577 .707 r
F P
0 g
s
.49189 .60589 m .48632 .55001 L .46997 .55788 L p .707 .577 .707 r
F P
0 g
s
.80022 .53705 m .8058 .59293 L .7785 .59172 L p .707 .577 .707 r
F P
0 g
s
.7785 .59172 m .77292 .53584 L .80022 .53705 L p .707 .577 .707 r
F P
0 g
s
.36428 .69973 m .35869 .68154 L .33271 .68683 L p .707 .577 .707 r
F P
0 g
s
.30581 .57079 m .31139 .62667 L .3323 .63025 L p .707 .577 .707 r
F P
0 g
s
.44722 .65392 m .45281 .67212 L .47618 .66201 L p .707 .577 .707 r
F P
0 g
s
.47618 .66201 m .47059 .64382 L .44722 .65392 L p .707 .577 .707 r
F P
0 g
s
.33271 .68683 m .3383 .70503 L .36428 .69973 L p .707 .577 .707 r
F P
0 g
s
.68095 .54643 m .68653 .60231 L .66255 .60942 L p .707 .577 .707 r
F P
0 g
s
.34048 .68478 m .32965 .6483 L .30984 .6503 L p .707 .577 .707 r
F P
0 g
s
.68653 .60231 m .68095 .54643 L .71022 .54077 L p .707 .577 .707 r
F P
0 g
s
.46794 .6066 m .47876 .64308 L .49491 .63423 L p .707 .577 .707 r
F P
0 g
s
.49491 .63423 m .48409 .59775 L .46794 .6066 L p .707 .577 .707 r
F P
0 g
s
.31139 .62667 m .30581 .57079 L .29333 .56519 L p .707 .577 .707 r
F P
0 g
s
.30984 .6503 m .32067 .68677 L .34048 .68478 L p .707 .577 .707 r
F P
0 g
s
.65515 .77484 m .64955 .75664 L .66569 .74774 L p .707 .577 .707 r
F P
0 g
s
.77292 .53584 m .7785 .59172 L .74749 .593 L p .707 .577 .707 r
F P
0 g
s
.74749 .593 m .74191 .53712 L .77292 .53584 L p .707 .577 .707 r
F P
0 g
s
.66569 .74774 m .67128 .76594 L .65515 .77484 L p .707 .577 .707 r
F P
0 g
s
.3383 .70503 m .33271 .68683 L .31298 .68911 L p .707 .577 .707 r
F P
0 g
s
.67326 .70088 m .66244 .66441 L .68586 .65446 L p .707 .577 .707 r
F P
0 g
s
.8233 .70245 m .82889 .72064 L .80917 .72293 L p .707 .577 .707 r
F P
0 g
s
.80917 .72293 m .80357 .70473 L .8233 .70245 L p .707 .577 .707 r
F P
0 g
s
.31298 .68911 m .31857 .70731 L .3383 .70503 L p .707 .577 .707 r
F P
0 g
s
.7158 .59665 m .71022 .54077 L .74191 .53712 L p .707 .577 .707 r
F P
0 g
s
.71022 .54077 m .7158 .59665 L .68653 .60231 L p .707 .577 .707 r
F P
0 g
s
.47059 .64382 m .47618 .66201 L .49232 .65311 L p .707 .577 .707 r
F P
0 g
s
.49232 .65311 m .48673 .63492 L .47059 .64382 L p .707 .577 .707 r
F P
0 g
s
.80072 .62271 m .81154 .65918 L .78546 .66416 L p .707 .577 .707 r
F P
0 g
s
.78546 .66416 m .77464 .62768 L .80072 .62271 L p .707 .577 .707 r
F P
0 g
s
.74191 .53712 m .74749 .593 L .7158 .59665 L p .707 .577 .707 r
F P
0 g
s
.68586 .65446 m .69668 .69093 L .67326 .70088 L p .707 .577 .707 r
F P
0 g
s
.48632 .55001 m .49189 .60589 L .499 .59803 L p .707 .577 .707 r
F P
0 g
s
.499 .59803 m .49343 .54215 L .48632 .55001 L p .707 .577 .707 r
F P
0 g
s
.29333 .56519 m .29891 .62107 L .31139 .62667 L p .707 .577 .707 r
F P
0 g
s
.32067 .68677 m .30984 .6503 L .29824 .64912 L p .707 .577 .707 r
F P
0 g
s
.69668 .69093 m .68586 .65446 L .71425 .64437 L p .707 .577 .707 r
F P
0 g
s
.48409 .59775 m .49491 .63423 L .50221 .62734 L p .707 .577 .707 r
F P
0 g
s
.50221 .62734 m .49139 .59087 L .48409 .59775 L p .707 .577 .707 r
F P
0 g
s
.29824 .64912 m .30906 .68559 L .32067 .68677 L p .707 .577 .707 r
F P
0 g
s
.67128 .76594 m .66569 .74774 L .68906 .73764 L p .707 .577 .707 r
F P
0 g
s
.77464 .62768 m .78546 .66416 L .75567 .67162 L p .707 .577 .707 r
F P
0 g
s
.75567 .67162 m .74484 .63515 L .77464 .62768 L p .707 .577 .707 r
F P
0 g
s
.29891 .62107 m .29333 .56519 L .29051 .55811 L p .707 .577 .707 r
F P
0 g
s
.31857 .70731 m .31298 .68911 L .30144 .68816 L p .707 .577 .707 r
F P
0 g
s
.68906 .73764 m .69466 .75584 L .67128 .76594 L p .707 .577 .707 r
F P
0 g
s
.71425 .64437 m .72507 .68085 L .69668 .69093 L p .707 .577 .707 r
F P
0 g
s
.80357 .70473 m .80917 .72293 L .78319 .72822 L p .707 .577 .707 r
F P
0 g
s
.78319 .72822 m .77759 .71003 L .80357 .70473 L p .707 .577 .707 r
F P
0 g
s
.30144 .68816 m .30704 .70636 L .31857 .70731 L p .707 .577 .707 r
F P
0 g
s
.48673 .63492 m .49232 .65311 L .49964 .64628 L p .707 .577 .707 r
F P
0 g
s
.49964 .64628 m .49404 .62809 L .48673 .63492 L p .707 .577 .707 r
F P
0 g
s
.72507 .68085 m .71425 .64437 L .74484 .63515 L p .707 .577 .707 r
F P
0 g
s
.74484 .63515 m .75567 .67162 L .72507 .68085 L p .707 .577 .707 r
F P
0 g
s
.49343 .54215 m .499 .59803 L .49618 .59095 L p .707 .577 .707 r
F P
0 g
s
.49618 .59095 m .4906 .53507 L .49343 .54215 L p .707 .577 .707 r
F P
0 g
s
.29051 .55811 m .29608 .61399 L .29891 .62107 L p .707 .577 .707 r
F P
0 g
s
.69466 .75584 m .68906 .73764 L .71739 .72733 L p .707 .577 .707 r
F P
0 g
s
.77759 .71003 m .78319 .72822 L .75349 .73601 L p .707 .577 .707 r
F P
0 g
s
.75349 .73601 m .74789 .71781 L .77759 .71003 L p .707 .577 .707 r
F P
0 g
s
.71739 .72733 m .72298 .74552 L .69466 .75584 L p .707 .577 .707 r
F P
0 g
s
.30906 .68559 m .29824 .64912 L .29597 .64488 L p .707 .577 .707 r
F P
0 g
s
.29597 .64488 m .3068 .68136 L .30906 .68559 L p .707 .577 .707 r
F P
0 g
s
.49139 .59087 m .50221 .62734 L .49995 .62311 L p .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49139 .59087 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.4991 .62027 m .48912 .58663 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49995 .62311 L .48834 .62193 L p .707 .577 .707 r
F P
0 g
s
.48834 .62193 m .47752 .58545 L .48912 .58663 L p .707 .577 .707 r
F P
0 g
s
.4906 .53507 m .49618 .59095 L .48899 .58772 L p .707 .577 .707 r
F P
0 g
s
.48899 .58772 m .4837 .58535 L p .48509 .5752 L .707 .577 .707 r
F P
0 g
s
.48509 .5752 m .4906 .53507 L .48899 .58772 L .707 .577 .707 r
F
.49995 .62311 m .4991 .62027 L p .49971 .62222 L F P
0 g
s
.72298 .74552 m .71739 .72733 L .74789 .71781 L p .707 .577 .707 r
F P
0 g
s
.74789 .71781 m .75349 .73601 L .72298 .74552 L p .707 .577 .707 r
F P
0 g
s
.30704 .70636 m .30144 .68816 L .29923 .68407 L p .707 .577 .707 r
F P
0 g
s
.29608 .61399 m .29051 .55811 L .29762 .55025 L p .707 .577 .707 r
F P
0 g
s
.29923 .68407 m .30482 .70227 L .30704 .70636 L p .707 .577 .707 r
F P
0 g
s
.49404 .62809 m .49964 .64628 L .49742 .64219 L p .707 .577 .707 r
F P
0 g
s
.49742 .64219 m .49182 .624 L .49404 .62809 L p .707 .577 .707 r
F P
0 g
s
.4837 .58535 m .47813 .52947 L .4906 .53507 L p .707 .577 .707 r
F P
0 g
s
.29762 .55025 m .30319 .60613 L .29608 .61399 L p .707 .577 .707 r
F P
0 g
s
.3068 .68136 m .29597 .64488 L .30328 .638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30328 .638 m .3141 .67447 L .3068 .68136 L p .707 .577 .707 r
F P
0 g
s
.30319 .60613 m .29762 .55025 L .31396 .54238 L p .707 .577 .707 r
F P
0 g
s
.30482 .70227 m .29923 .68407 L .30654 .67724 L p .707 .577 .707 r
F P
0 g
s
.30654 .67724 m .31214 .69544 L .30482 .70227 L p .707 .577 .707 r
F P
0 g
s
.49182 .624 m .49742 .64219 L .48588 .64124 L p .707 .577 .707 r
F P
0 g
s
.48588 .64124 m .48029 .62305 L .49182 .624 L p .707 .577 .707 r
F P
0 g
s
.47813 .52947 m .4837 .58535 L .46279 .58176 L p .707 .577 .707 r
F P
0 g
s
.46279 .58176 m .45721 .52588 L .47813 .52947 L p .707 .577 .707 r
F P
0 g
s
.31396 .54238 m .31954 .59825 L .30319 .60613 L p .707 .577 .707 r
F P
0 g
s
.3141 .67447 m .30328 .638 L .31943 .62915 L p .707 .577 .707 r
F P
0 g
s
.31954 .59825 m .31396 .54238 L .33794 .53526 L p .707 .577 .707 r
F P
0 g
s
.47752 .58545 m .48834 .62193 L .46853 .62392 L p .707 .577 .707 r
F P
0 g
s
.46853 .62392 m .45771 .58745 L .47752 .58545 L p .707 .577 .707 r
F P
0 g
s
.31943 .62915 m .33025 .66562 L .3141 .67447 L p .707 .577 .707 r
F P
0 g
s
.31214 .69544 m .30654 .67724 L .32268 .66834 L p .707 .577 .707 r
F P
0 g
s
.32268 .66834 m .32827 .68654 L .31214 .69544 L p .707 .577 .707 r
F P
0 g
s
.45721 .52588 m .46279 .58176 L .43549 .58055 L p .707 .577 .707 r
F P
0 g
s
.43549 .58055 m .42991 .52467 L .45721 .52588 L p .707 .577 .707 r
F P
0 g
s
.48029 .62305 m .48588 .64124 L .46616 .64353 L p .707 .577 .707 r
F P
0 g
s
.46616 .64353 m .46056 .62533 L .48029 .62305 L p .707 .577 .707 r
F P
0 g
s
.33794 .53526 m .34352 .59114 L .31954 .59825 L p .707 .577 .707 r
F P
0 g
s
.34352 .59114 m .33794 .53526 L .36721 .5296 L p .707 .577 .707 r
F P
0 g
s
.33025 .66562 m .31943 .62915 L .34285 .61919 L p .707 .577 .707 r
F P
0 g
s
.42991 .52467 m .43549 .58055 L .40448 .58184 L p .707 .577 .707 r
F P
0 g
s
.40448 .58184 m .3989 .52596 L .42991 .52467 L p .707 .577 .707 r
F P
0 g
s
.46056 .62533 m .46616 .64353 L .44017 .64882 L p .707 .577 .707 r
F P
0 g
s
.43826 .62995 m .41266 .63636 L p .42885 .59885 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43458 .63063 L .43824 .62988 L p .707 .577 .707 r
F P
0 g
s
.43824 .62988 m .46056 .62533 L p .44299 .64558 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43824 .62988 L .44299 .64558 L .707 .577 .707 r
F
.43163 .59242 m .44245 .6289 L .43826 .62995 L p F P
0 g
s
.42885 .59885 m .43163 .59242 L .43826 .62995 L .707 .577 .707 r
F
.45771 .58745 m .46853 .62392 L .44245 .6289 L p F P
0 g
s
.44245 .6289 m .43163 .59242 L .45771 .58745 L p .707 .577 .707 r
F P
0 g
s
.34285 .61919 m .35367 .65567 L .33025 .66562 L p .707 .577 .707 r
F P
0 g
s
.37278 .58548 m .36721 .5296 L .3989 .52596 L p .707 .577 .707 r
F P
0 g
s
.36721 .5296 m .37278 .58548 L .34352 .59114 L p .707 .577 .707 r
F P
0 g
s
.32827 .68654 m .32268 .66834 L .34605 .65824 L p .707 .577 .707 r
F P
0 g
s
.3989 .52596 m .40448 .58184 L .37278 .58548 L p .707 .577 .707 r
F P
0 g
s
.34605 .65824 m .35165 .67644 L .32827 .68654 L p .707 .577 .707 r
F P
0 g
s
.35367 .65567 m .34285 .61919 L .37124 .60911 L p .707 .577 .707 r
F P
0 g
s
.41266 .63636 m .40183 .59989 L .43163 .59242 L p .707 .577 .707 r
F P
0 g
s
.37124 .60911 m .38206 .64559 L .35367 .65567 L p .707 .577 .707 r
F P
0 g
s
.35165 .67644 m .34605 .65824 L .37438 .64793 L p .707 .577 .707 r
F P
0 g
s
.38206 .64559 m .37124 .60911 L .40183 .59989 L p .707 .577 .707 r
F P
0 g
s
.40183 .59989 m .41266 .63636 L .38206 .64559 L p .707 .577 .707 r
F P
0 g
s
.43458 .63063 m .44017 .64882 L .41048 .65661 L p .707 .577 .707 r
F P
0 g
s
.41048 .65661 m .40488 .63841 L .43458 .63063 L p .707 .577 .707 r
F P
0 g
s
.37438 .64793 m .37997 .66612 L .35165 .67644 L p .707 .577 .707 r
F P
0 g
s
.37997 .66612 m .37438 .64793 L .40488 .63841 L p .707 .577 .707 r
F P
0 g
s
.40488 .63841 m .41048 .65661 L .37997 .66612 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20004UYF00<005YFFUH00eYF2000OWoo001dOol300000eYF001JEP0GFUH00`00FUIJEP09
FUH00`00FUH00003001jOol0075oo`<000AJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF
00=JEP@007Ioo`00KWoo0`001eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH01eYF1000
LWoo001ZOol400000eYF001JEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04001^Ool006Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00Igoo0P001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001VOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH00000J7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001V
Ool006Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEQL000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00Hgoo00<005YFFUH01`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8001QooaP003Moo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@003=oo`00F7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00EWoo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Yoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000`Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001C
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002moo`00DWoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20002Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001BOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYF001JEP0_Ool0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P0025YF
00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH6
0002FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`03001JEP00
00AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000D000=JEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF60000UYF00D005YF
FUIJEP0002ioo`00Dgoo00@005YFFUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH015YF
1P0000AJEP00000000=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001oogoo02aoo`00
Dgoo00@005YFFUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<0
05YF000010000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP000000;Goo
001DOol2FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP03FUH50008FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF1000;Goo001DOol2FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo001DOol015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH0
0`0025YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP@000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00E7oo00@005YFFUH000EJEP03001JEUYF00EJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0
04Ioo`l000=JEP03001JEUYF009JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo0010Ool60004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF0000000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000`Ool003aoo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP06001JEP00001JEP000eYF100000=JEP00FUH01eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF3@002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF1`000UYF00@005YFFUH0031oo`00>7oo10001EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EPH000EJEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EPL000=JEP03001JEUYF00AJEP04001JEUYF000_Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04
001JEUYFFUH50005FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0000=JEP00FUH01UYF00<0
05YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000`001eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF10000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0000=JEP00FUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000MJEQ@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00AJEP04001JEUYF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH40004FUH0
0`00FUIJEP07FUH01000FUIJEUYF1`000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP03001JEUYF008000=oo`<000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH900000eYF001JEP04FUH4
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH0
1@00FUIJEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
00000eYF001JEP08FUH00`00FUIJEP040003FUH30005FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YF000002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF100015YF00<005YFFUH01EYF
100000=JEP00FUH00UYF0P0000=JEP00FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP04001JEUYFFUH30008FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00Ool0;7oo000[
Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00D005YFFUIJEP0000AJEP<000MJEP03001JEUYF00=JEP8000IJEP<000=JEP03001J
EUYF00EJEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000MJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH70003
FUH4000/Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH01P00FUH00000FUH000UJEP03001JEP000080
00EJEP<000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000IJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPH000EJEP03001JEUYF009JEP04001JEUYF000/Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00=JEP8000=J
EP03001JEUYF00IJEP<00003FUH005YF009JEP<00003FUH005YF00MJEP04001JEUYFFUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH30006FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00009JEP04001JEP000006FUH00`00FUIJEP02FUH30005FUH30004
FUH00`00FUIJEP06FUH01000FUH000002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF10001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0002FUH30007FUH00`00FUH000020005FUH3
0007FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000<7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04
FUH20003FUH500000eYF001JEP08FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000bOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP800003FUH0000000<000EJEP@000IJEP03001J
EP00008000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP@000MJEP03
001JEUYF00IJEP03001JEUYF009JEP8003Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH015YF00<005YF00001000
00=JEP00FUH01eYF1@000eYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;7oo00@005YF
FUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00004FUH005YF0002
FUH01000FUIJEUYF10001UYF00<005YFFUH01EYF20002UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00@005YF
FUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP80009JEP04001J
EP000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH500000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
1EYF00<005YFFUH015YF0`002EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00?7oo000]Ool2FUH0
1000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00@005YF001J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH000000002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
1EYF001JEUYF000015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YF00000P00?Woo000]Ool2FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00
FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP800005FUH005YFFUH00005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01EYF
0`00@Goo000]Ool015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH00`0025YF00<005YFFUH0
1EYF00H005YF000005YF0006FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
0002FUH00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000?Ool4000aOol0
02eoo`04001JEUYF0005FUH00`00FUIJEP05FUH300000eYF001JEP08FUH00`00FUIJEP06FUH01P00
FUH00000FUH000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUH00002000:Ool7
0002FUH01000FUH00000;goo000]Ool01@00FUIJEUYF000015YF00<005YFFUH00eYF0`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00Qoo`D000=JEP03001JEUYF00=JEP04001JEUYF000_Ool002eoo`05001JEUYFFUH00005FUH00`00
FUH000020007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP040009Ool300000eYF001JEP05FUH00`00FUIJEP04FUH00`00FUH0000_Ool0
02ioo`800003FUH005YF00AJEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEPD0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP800003FUH005YF00EJEP04001JEUYFFUH6000:Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool400000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00001P0000=JEP00FUH00UYF1`002goo10001eYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH007oo02eoo`00<goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF1P000eYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH50003FUH01000FUIJEP001goo10000UYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000eYF1000;Goo000aOol30007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH500000eYF001J
EP06FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF
001JEP0000IJEP03001JEUYF00=JEP03001JEUYF0080009oo`@000MJEP03001JEUYF00IJEP03001J
EP0000D00003FUH005YF00=JEP04001JEUYF000]Ool002moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP05FUH30002Ool20003FUH00`00FUIJEP03FUH2000^
Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP040002Ool30006FUH01000FUIJEUYF0P00;goo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH01EYF100015YF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03
001JEUYF00EJEPD000Aoo`800003FUH005YF00IJEP04001JEP00000aOol002eoo`04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH7000015YF000000000UYF
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00MJEQ8000UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00<000UJEP03001JEUYF
00@000Ioo`<000AJEP03001JEUYF00AJEP8003=oo`00;Goo0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH010001EYF0`000eYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000YJEP03001JEUYF00EJEPH000=JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP<000=JEP03
001JEUYF00EJEP@000Moo`<000MJEP03001JEUYF009JEP8003Eoo`00;Woo00<005YF000015YF00<0
05YFFUH015YF100015YF00<005YFFUH01EYF100000=JEP00FUH015YF0`001EYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH015YF1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF1`0025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF
0P0027oo0`0000=JEP00FUH025YF00@005YF000003Moo`00;Woo00@005YFFUH000=JEP03001JEUYF
009JEP<000MJEP03001JEUYF00=JEP8000IJEP03001JEP0000800003FUH005YF00IJEP80009JEP03
001JEUYF00AJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJ
EPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH30007FUH00`00FUH0
00020007Ool30005FUH00`00FUIJEP05FUH3000iOol002ioo`04001JEUYF0004FUH01P00FUH00000
FUH000UJEP03001JEP00008000MJEP@000=JEP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEP@0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPD000MJEP03
001JEUYF009JEP8000AJEP<0009JEP03001JEUYF00AJEP<0009JEP03001oogoo009oo`<000QJEP03
001JEUYF00=JEP8003aoo`00;Woo0P0000=JEP00FUH00eYF0P000eYF00<005YFFUH01UYF0`0000=J
EP00FUH015YF10001eYF00@005YFFUIJEP80009oo`04001JEUYF0003FUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP02FUH20002FUH30005FUH01000FUIJEUYF0P000eYF0P0000=oo`0000000P0000=JEP00FUH0
2EYF00<005YF00000P00?Woo000_Ool01@00FUIJEP00FUH00P001UYF00<005YFFUH00UYF0`001EYF
1@000UYF00<005YFFUH01UYF00@005YF000000Aoo`05001JEUYF001JEP020008FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001J
EP03FUH400000eYF00000005FUH01000FUH000000UYF1P001UYF00<005YFFUH01UYF0`00@Goo000_
Ool00`00FUIJEP030007FUH00`00FUH000020005FUH40006FUH00`00FUIJEP05FUH30006Ool00`00
FUIJEP0200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000UYF00@005YFFUH000AJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP<004Aoo`00;goo0`000eYF00<005YFFUH015YF0P000eYF1@00
00=JEP00FUH025YF00<005YFFUH00UYF0P002Goo00<005YF00000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP80009JEP04001JEUYF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
00000P00Agoo000_Ool20004FUH00`00FUIJEP02FUH200000eYF000000030006FUH30006FUH00`00
FUH00002000;Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001:Ool002ioo`03001JEP0000EJEP03001JEP0000@0
0003FUH005YF00MJEPD000AJEP<000ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEP000003FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP04001=Ool002io
o`04001JEUYF0003FUH40006FUH00`00FUIJEP05FUH9000AOol00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF00001EYF00<005YFFUH015YF1000DGoo000^
Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@005Goo00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP05001JEUYFFUH00004FUH00`00
FUIJEP04001EOol002moo`04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000GOol0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00FUH03`00FGoo000_Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUH00002000MOol00`00FUIJEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP02001XOol002moo`04001JEUYF0006FUH01000FUIJEUYF
1@008Goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00003Woo1000F7oo000_Ool2
0002FUH01000FUIJEUYF1P00:7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P002Woo1@000UYF00@005YF0000
05Ioo`00<7oo1`00<7oo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01Goo100000=JEP00FUH015YF
00@005YFFUH005Ioo`00JGoo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`@000EJEP03001JEUYF00=JEP04
001JEUYF001FOol006aoo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo001_Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo001c
Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP080002FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH<001DOol007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF
00AJEP`000MJEP03001JEUYF00IJEP03001JEP0000D00003FUH005YF00=JEP04001JEUYF001DOol0
085ooaX000Ioo`800003FUH005YF00QJEP03001JEUYF00EJEP<0009oo`8000=JEP03001JEUYF00=J
EP8005Eoo`00WWoo0`0015YF00<005YFFUH01eYF00<005YFFUH010000Woo0`001UYF00@005YFFUIJ
EP8005Ioo`00W7oo0P001eYF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF0000
05Qoo`00VWoo0`0025YF00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0P00FWoo002H
Ool20003FUH00`00FUIJEP06FUH00`00FUH000020005Ool30007FUH00`00FUIJEP02FUH2001LOol0
09Ioo`8000EJEP03001JEUYF00EJEP<000Eoo`<00003FUH005YF00QJEP04001JEP00001NOol009Ao
o`<000IJEP03001JEUYF00=JEP8000Eoo`<000EJEP03001JEUYF00EJEP<0061oo`00TWoo0P000UYF
00<005YFFUH01EYF00<005YF00000P0017oo0`0025YF00<005YFFUH00eYF0P00Hgoo002AOol00`00
FUIJEP03FUH00`00FUIJEP03FUH30003Ool400000eYF001JEP09FUH00`00FUH00002001UOol0091o
o`8000EJEP03001JEP0000<0009oo`@000IJEP03001JEUYF00IJEP<006Qoo`00Sgoo00@005YFFUH0
00AJEP80009oo`@00003FUH005YF00MJEP03001JEUYF00=JEP<006]oo`00Sgoo00@005YFFUH000=J
EPD000IJEP03001JEUYF00IJEP03001JEP00008006ioo`00T7oo00<005YFFUH00`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF0`00LGoo002@Ool00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00
FUIJEP04001dOol0095oo`04FUH005YF0005FUH00`00FUIJEP04FUH4001hOol0095oo`05001JEUYF
FUH00004FUH00`00FUIJEP04001lOol0095oo``0081oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59642 .73339 m .59084 .67751 L .55983 .67879 L p .707 .577 .707 r
F P
0 g
s
.59084 .67751 m .59642 .73339 L .62811 .72974 L p .707 .577 .707 r
F P
0 g
s
.62811 .72974 m .62253 .67386 L .59084 .67751 L p .707 .577 .707 r
F P
0 g
s
.62253 .67386 m .62811 .72974 L .65738 .72408 L p .707 .577 .707 r
F P
0 g
s
.65738 .72408 m .6518 .6682 L .62253 .67386 L p .707 .577 .707 r
F P
0 g
s
.5654 .73467 m .55983 .67879 L .53253 .67758 L p .707 .577 .707 r
F P
0 g
s
.55983 .67879 m .5654 .73467 L .59642 .73339 L p .707 .577 .707 r
F P
0 g
s
.6518 .6682 m .65738 .72408 L .68136 .71697 L p .707 .577 .707 r
F P
0 g
s
.68136 .71697 m .67578 .66109 L .6518 .6682 L p .707 .577 .707 r
F P
0 g
s
.53253 .67758 m .5381 .73346 L .5654 .73467 L p .707 .577 .707 r
F P
0 g
s
.60216 .79964 m .59133 .76317 L .56154 .77063 L p .707 .577 .707 r
F P
0 g
s
.59133 .76317 m .60216 .79964 L .63275 .79041 L p .707 .577 .707 r
F P
0 g
s
.63275 .79041 m .62193 .75394 L .59133 .76317 L p .707 .577 .707 r
F P
0 g
s
.5381 .73346 m .53253 .67758 L .51162 .674 L p .707 .577 .707 r
F P
0 g
s
.62193 .75394 m .63275 .79041 L .66114 .78033 L p .707 .577 .707 r
F P
0 g
s
.66114 .78033 m .65032 .74386 L .62193 .75394 L p .707 .577 .707 r
F P
0 g
s
.56154 .77063 m .57236 .8071 L .60216 .79964 L p .707 .577 .707 r
F P
0 g
s
.57236 .8071 m .56154 .77063 L .53546 .7756 L p .707 .577 .707 r
F P
0 g
s
.67578 .66109 m .68136 .71697 L .6977 .70909 L p .707 .577 .707 r
F P
0 g
s
.6977 .70909 m .69212 .65322 L .67578 .66109 L p .707 .577 .707 r
F P
0 g
s
.65032 .74386 m .66114 .78033 L .68456 .77038 L p .707 .577 .707 r
F P
0 g
s
.68456 .77038 m .67374 .7339 L .65032 .74386 L p .707 .577 .707 r
F P
0 g
s
.51162 .674 m .51719 .72988 L .5381 .73346 L p .707 .577 .707 r
F P
0 g
s
.53546 .7756 m .54628 .81208 L .57236 .8071 L p .707 .577 .707 r
F P
0 g
s
.59978 .86338 m .59419 .84519 L .56449 .85297 L p .707 .577 .707 r
F P
0 g
s
.59419 .84519 m .59978 .86338 L .63029 .85387 L p .707 .577 .707 r
F P
0 g
s
.63029 .85387 m .6247 .83567 L .59419 .84519 L p .707 .577 .707 r
F P
0 g
s
.6247 .83567 m .63029 .85387 L .65861 .84355 L p .707 .577 .707 r
F P
0 g
s
.65861 .84355 m .65302 .82536 L .6247 .83567 L p .707 .577 .707 r
F P
0 g
s
.56449 .85297 m .57009 .87117 L .59978 .86338 L p .707 .577 .707 r
F P
0 g
s
.51719 .72988 m .51162 .674 L .49914 .66839 L p .707 .577 .707 r
F P
0 g
s
.54628 .81208 m .53546 .7756 L .51565 .7776 L p .707 .577 .707 r
F P
0 g
s
.57009 .87117 m .56449 .85297 L .53851 .85827 L p .707 .577 .707 r
F P
0 g
s
.67374 .7339 m .68456 .77038 L .70071 .76152 L p .707 .577 .707 r
F P
0 g
s
.70071 .76152 m .68989 .72505 L .67374 .7339 L p .707 .577 .707 r
F P
0 g
s
.51565 .7776 m .52647 .81407 L .54628 .81208 L p .707 .577 .707 r
F P
0 g
s
.65302 .82536 m .65861 .84355 L .68199 .83345 L p .707 .577 .707 r
F P
0 g
s
.68199 .83345 m .6764 .81526 L .65302 .82536 L p .707 .577 .707 r
F P
0 g
s
.53851 .85827 m .54411 .87646 L .57009 .87117 L p .707 .577 .707 r
F P
0 g
s
.69212 .65322 m .6977 .70909 L .70481 .70123 L p .707 .577 .707 r
F P
0 g
s
.70481 .70123 m .69923 .64536 L .69212 .65322 L p .707 .577 .707 r
F P
0 g
s
.49914 .66839 m .50471 .72427 L .51719 .72988 L p .707 .577 .707 r
F P
0 g
s
.54411 .87646 m .53851 .85827 L .51879 .86055 L p .707 .577 .707 r
F P
0 g
s
.51879 .86055 m .52438 .87875 L .54411 .87646 L p .707 .577 .707 r
F P
0 g
s
.52647 .81407 m .51565 .7776 L .50404 .77642 L p .707 .577 .707 r
F P
0 g
s
.6764 .81526 m .68199 .83345 L .69813 .82455 L p .707 .577 .707 r
F P
0 g
s
.69813 .82455 m .69253 .80636 L .6764 .81526 L p .707 .577 .707 r
F P
0 g
s
.50471 .72427 m .49914 .66839 L .49631 .66131 L p .707 .577 .707 r
F P
0 g
s
.68989 .72505 m .70071 .76152 L .70802 .75464 L p .707 .577 .707 r
F P
0 g
s
.70802 .75464 m .69719 .71817 L .68989 .72505 L p .707 .577 .707 r
F P
0 g
s
.50404 .77642 m .51487 .81289 L .52647 .81407 L p .707 .577 .707 r
F P
0 g
s
.69923 .64536 m .70481 .70123 L .70198 .69416 L p .707 .577 .707 r
F P
0 g
s
.70198 .69416 m .69641 .63828 L .69923 .64536 L p .707 .577 .707 r
F P
0 g
s
.49631 .66131 m .50189 .71719 L .50471 .72427 L p .707 .577 .707 r
F P
0 g
s
.52438 .87875 m .51879 .86055 L .50725 .8596 L p .707 .577 .707 r
F P
0 g
s
.50725 .8596 m .51284 .8778 L .52438 .87875 L p .707 .577 .707 r
F P
0 g
s
.69253 .80636 m .69813 .82455 L .70544 .81772 L p .707 .577 .707 r
F P
0 g
s
.70544 .81772 m .69985 .79952 L .69253 .80636 L p .707 .577 .707 r
F P
0 g
s
.47783 .82164 m .49203 .32149 L .44804 .31755 L p .707 .577 .707 r
F P
0 g
s
.51487 .81289 m .50404 .77642 L .50178 .77218 L p .707 .577 .707 r
F P
0 g
s
.50189 .71719 m .49631 .66131 L .50342 .65345 L p .707 .577 .707 r
F P
0 g
s
.50178 .77218 m .5126 .80865 L .51487 .81289 L p .707 .577 .707 r
F P
0 g
s
.50342 .65345 m .509 .70933 L .50189 .71719 L p .707 .577 .707 r
F P
0 g
s
.5126 .80865 m .50178 .77218 L .50908 .7653 L p .707 .577 .707 r
F P
0 g
s
.509 .70933 m .50342 .65345 L .51977 .64558 L p .707 .577 .707 r
F P
0 g
s
.50908 .7653 m .5199 .80177 L .5126 .80865 L p .707 .577 .707 r
F P
0 g
s
.51977 .64558 m .52534 .70146 L .509 .70933 L p .707 .577 .707 r
F P
0 g
s
.5199 .80177 m .50908 .7653 L .52523 .75645 L p .707 .577 .707 r
F P
0 g
s
.52523 .75645 m .53606 .79292 L .5199 .80177 L p .707 .577 .707 r
F P
0 g
s
.49203 .32149 m .47783 .82164 L .52276 .82168 L p .707 .577 .707 r
F P
0 g
s
.52534 .70146 m .51977 .64558 L .54375 .63847 L p .707 .577 .707 r
F P
0 g
s
.54375 .63847 m .54932 .69435 L .52534 .70146 L p .707 .577 .707 r
F P
0 g
s
.52276 .82168 m .53696 .32153 L .49203 .32149 L p .707 .577 .707 r
F P
0 g
s
.54932 .69435 m .54375 .63847 L .57301 .63281 L p .707 .577 .707 r
F P
0 g
s
.53606 .79292 m .52523 .75645 L .54865 .74649 L p .707 .577 .707 r
F P
0 g
s
.57301 .63281 m .57859 .68869 L .54932 .69435 L p .707 .577 .707 r
F P
0 g
s
.54865 .74649 m .55947 .78297 L .53606 .79292 L p .707 .577 .707 r
F P
0 g
s
.55947 .78297 m .54865 .74649 L .57705 .73641 L p .707 .577 .707 r
F P
0 g
s
.57705 .73641 m .58787 .77288 L .55947 .78297 L p .707 .577 .707 r
F P
0 g
s
.53696 .32153 m .52276 .82168 L .56423 .81781 L p .707 .577 .707 r
F P
0 g
s
.56423 .81781 m .57843 .31766 L .53696 .32153 L p .707 .577 .707 r
F P
0 g
s
.69719 .71817 m .70802 .75464 L .70575 .75041 L p .707 .577 .707 r
F P
0 g
s
.70575 .75041 m .69493 .71393 L .69719 .71817 L p .707 .577 .707 r
F P
0 g
s
.43384 .8177 m .44804 .31755 L .4093 .31009 L p .707 .577 .707 r
F P
0 g
s
.44804 .31755 m .43384 .8177 L .47783 .82164 L p .707 .577 .707 r
F P
0 g
s
.69641 .63828 m .70198 .69416 L .68951 .68855 L p .707 .577 .707 r
F P
0 g
s
.68951 .68855 m .68393 .63267 L .69641 .63828 L p .707 .577 .707 r
F P
0 g
s
.57859 .68869 m .57301 .63281 L .60471 .62916 L p .707 .577 .707 r
F P
0 g
s
.60471 .62916 m .61028 .68504 L .57859 .68869 L p .707 .577 .707 r
F P
0 g
s
.58787 .77288 m .57705 .73641 L .60764 .72718 L p .707 .577 .707 r
F P
0 g
s
.60764 .72718 m .61846 .76366 L .58787 .77288 L p .707 .577 .707 r
F P
0 g
s
.57843 .31766 m .56423 .81781 L .59818 .81041 L p .707 .577 .707 r
F P
0 g
s
.59818 .81041 m .61238 .31026 L .57843 .31766 L p .707 .577 .707 r
F P
0 g
s
.51284 .8778 m .50725 .8596 L .50503 .85551 L p .707 .577 .707 r
F P
0 g
s
.50503 .85551 m .51063 .87371 L .51284 .8778 L p .707 .577 .707 r
F P
0 g
s
.69985 .79952 m .70544 .81772 L .70322 .81363 L p .707 .577 .707 r
F P
0 g
s
.70322 .81363 m .69763 .79543 L .69985 .79952 L p .707 .577 .707 r
F P
0 g
s
.3951 .81024 m .4093 .31009 L .37959 .29984 L p .707 .577 .707 r
F P
0 g
s
.4093 .31009 m .3951 .81024 L .43384 .8177 L p .707 .577 .707 r
F P
0 g
s
.25341 .72222 m .24783 .66634 L .21682 .66762 L p .707 .577 .707 r
F P
0 g
s
.24783 .66634 m .25341 .72222 L .2851 .71857 L p .707 .577 .707 r
F P
0 g
s
.2851 .71857 m .27952 .66269 L .24783 .66634 L p .707 .577 .707 r
F P
0 g
s
.27952 .66269 m .2851 .71857 L .31437 .71291 L p .707 .577 .707 r
F P
0 g
s
.31437 .71291 m .30879 .65703 L .27952 .66269 L p .707 .577 .707 r
F P
0 g
s
.69493 .71393 m .70575 .75041 L .69415 .74923 L p .707 .577 .707 r
F P
0 g
s
.69415 .74923 m .68332 .71275 L .69493 .71393 L p .707 .577 .707 r
F P
0 g
s
.22239 .7235 m .21682 .66762 L .18952 .66641 L p .707 .577 .707 r
F P
0 g
s
.21682 .66762 m .22239 .7235 L .25341 .72222 L p .707 .577 .707 r
F P
0 g
s
.68393 .63267 m .68951 .68855 L .66859 .68497 L p .707 .577 .707 r
F P
0 g
s
.66859 .68497 m .66302 .62909 L .68393 .63267 L p .707 .577 .707 r
F P
0 g
s
.30879 .65703 m .31437 .71291 L .33835 .7058 L p .707 .577 .707 r
F P
0 g
s
.33835 .7058 m .33277 .64992 L .30879 .65703 L p .707 .577 .707 r
F P
0 g
s
.63572 .62788 m .6413 .68376 L .61028 .68504 L p .707 .577 .707 r
F P
0 g
s
.61028 .68504 m .60471 .62916 L .63572 .62788 L p .707 .577 .707 r
F P
0 g
s
.63743 .71972 m .64826 .75619 L .61846 .76366 L p .707 .577 .707 r
F P
0 g
s
.61846 .76366 m .60764 .72718 L .63743 .71972 L p .707 .577 .707 r
F P
0 g
s
.61238 .31026 m .59818 .81041 L .62129 .80021 L p .707 .577 .707 r
F P
0 g
s
.62129 .80021 m .63549 .30006 L .61238 .31026 L p .707 .577 .707 r
F P
0 g
s
.25915 .76438 m .24833 .72791 L .21853 .73537 L p .707 .577 .707 r
F P
0 g
s
.24833 .72791 m .25915 .76438 L .28974 .75515 L p .707 .577 .707 r
F P
0 g
s
.28974 .75515 m .27892 .71868 L .24833 .72791 L p .707 .577 .707 r
F P
0 g
s
.27892 .71868 m .28974 .75515 L .31814 .74507 L p .707 .577 .707 r
F P
0 g
s
.31814 .74507 m .30731 .7086 L .27892 .71868 L p .707 .577 .707 r
F P
0 g
s
.51063 .87371 m .50503 .85551 L .51235 .84868 L p .707 .577 .707 r
F P
0 g
s
.18952 .66641 m .1951 .72229 L .22239 .7235 L p .707 .577 .707 r
F P
0 g
s
.51235 .84868 m .51794 .86688 L .51063 .87371 L p .707 .577 .707 r
F P
0 g
s
.21853 .73537 m .22935 .77184 L .25915 .76438 L p .707 .577 .707 r
F P
0 g
s
.1951 .72229 m .18952 .66641 L .16861 .66283 L p .707 .577 .707 r
F P
0 g
s
.69763 .79543 m .70322 .81363 L .69169 .81268 L p .707 .577 .707 r
F P
0 g
s
.69169 .81268 m .68609 .79449 L .69763 .79543 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21853 .73537 L .21469 .7361 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21469 .7361 L .22413 .76738 L .707 .577 .707 r
F
.22566 .77248 m .22148 .77357 L p .22644 .77503 L F P
0 g
s
.19245 .74034 m .20327 .77682 L .22935 .77184 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .25118 .76579 L .22566 .77248 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .22566 .77248 L .22644 .77503 L .707 .577 .707 r
F
.21469 .7361 m .19245 .74034 L p .22413 .76738 L F P
0 g
s
.25118 .76579 m .25678 .78398 L .28728 .77447 L p .707 .577 .707 r
F P
0 g
s
.28728 .77447 m .28169 .75627 L .25118 .76579 L p .707 .577 .707 r
F P
0 g
s
.28169 .75627 m .28728 .77447 L .31561 .76416 L p .707 .577 .707 r
F P
0 g
s
.31561 .76416 m .31001 .74596 L .28169 .75627 L p .707 .577 .707 r
F P
0 g
s
.33277 .64992 m .33835 .7058 L .35469 .69793 L p .707 .577 .707 r
F P
0 g
s
.34688 .68979 m .35771 .72626 L .35957 .72451 L p .707 .577 .707 r
F P
0 g
s
.35957 .72451 m .36501 .71938 L p .35864 .70899 L .707 .577 .707 r
F P
0 g
s
.35864 .70899 m .34688 .68979 L .35957 .72451 L .707 .577 .707 r
F
.36182 .28781 m .35774 .27517 L p .35152 .59032 L F P
0 g
s
.35469 .69793 m .34911 .64205 L .33277 .64992 L p .707 .577 .707 r
F P
0 g
s
.33073 .69864 m .34155 .73512 L .35771 .72626 L p .707 .577 .707 r
F P
0 g
s
.35771 .72626 m .34688 .68979 L .33073 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .7086 m .31814 .74507 L .34155 .73512 L p .707 .577 .707 r
F P
0 g
s
.33339 .73586 m .33898 .75405 L .35512 .74515 L p .707 .577 .707 r
F P
0 g
s
.34155 .73512 m .33073 .69864 L .30731 .7086 L p .707 .577 .707 r
F P
0 g
s
.35512 .74515 m .34952 .72696 L .33339 .73586 L p .707 .577 .707 r
F P
0 g
s
.34911 .64205 m .35469 .69793 L .3618 .69007 L p .707 .577 .707 r
F P
0 g
s
.3618 .69007 m .35622 .63419 L .34911 .64205 L p .707 .577 .707 r
F P
0 g
s
.36501 .71938 m .35418 .68291 L .34688 .68979 L p .707 .577 .707 r
F P
0 g
s
.3534 .62711 m .35589 .65202 L p .3465 .67738 L .707 .577 .707 r
F P
0 g
s
.35589 .65202 m .35898 .68299 L .35409 .6808 L p .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .35418 .68291 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.36274 .71515 m .3619 .71231 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.3619 .71231 m .35192 .67867 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .36274 .71515 L .35114 .71397 L p .707 .577 .707 r
F P
0 g
s
.35114 .71397 m .34032 .67749 L .35192 .67867 L p .707 .577 .707 r
F P
0 g
s
.35409 .6808 m .35178 .67976 L p .35589 .65202 L .707 .577 .707 r
F P
0 g
s
.35178 .67976 m .3465 .67738 L p .34897 .67071 L .707 .577 .707 r
F P
0 g
s
.34897 .67071 m .35589 .65202 L .35178 .67976 L .707 .577 .707 r
F
.3465 .67738 m .34092 .62151 L .3534 .62711 L p F P
0 g
s
.34952 .72696 m .35512 .74515 L .36243 .73832 L p .707 .577 .707 r
F P
0 g
s
.36243 .73832 m .35684 .72013 L .34952 .72696 L p .707 .577 .707 r
F P
0 g
s
.35462 .71604 m .36021 .73423 L .35174 .73353 L p .707 .577 .707 r
F P
0 g
s
.35174 .73353 m .34868 .73328 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.35351 .71926 m .35462 .71604 L .35174 .73353 L .707 .577 .707 r
F
.34868 .73328 m .34308 .71509 L .35392 .71598 L p F P
0 g
s
.35392 .71598 m .35462 .71604 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.34868 .73328 m .35392 .71598 L .35351 .71926 L .707 .577 .707 r
F
.3478 .78171 m .34841 .76035 L p .34772 .78298 L F P
0 g
s
.34032 .67749 m .35114 .71397 L .33133 .71596 L p .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .35268 .60969 L p .34836 .76074 L .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .34836 .76074 L .34772 .78298 L .707 .577 .707 r
F
.34812 .76263 m .35268 .60969 L .35152 .59032 L F
.34772 .78298 m .34836 .76074 L .34812 .76263 L F
.34836 .76074 m .35268 .60969 L .34812 .76263 L F
.34762 .78796 m .3478 .78171 L p .34772 .78298 L F P
0 g
s
.35268 .60969 m .36182 .28781 L p .35152 .59032 L .707 .577 .707 r
F P
0 g
s
.35418 .68291 m .36501 .71938 L .36274 .71515 L p .707 .577 .707 r
F P
0 g
s
.36539 .79999 m .37959 .29984 L .36182 .28781 L p .707 .577 .707 r
F P
0 g
s
.37959 .29984 m .36539 .79999 L .3951 .81024 L p .707 .577 .707 r
F P
0 g
s
.22148 .77357 m .22708 .79177 L .25678 .78398 L p .707 .577 .707 r
F P
0 g
s
.68332 .71275 m .69415 .74923 L .67434 .75122 L p .707 .577 .707 r
F P
0 g
s
.67434 .75122 m .66351 .71475 L .68332 .71275 L p .707 .577 .707 r
F P
0 g
s
.66302 .62909 m .66859 .68497 L .6413 .68376 L p .707 .577 .707 r
F P
0 g
s
.6413 .68376 m .63572 .62788 L .66302 .62909 L p .707 .577 .707 r
F P
0 g
s
.22708 .79177 m .22148 .77357 L .1955 .77887 L p .707 .577 .707 r
F P
0 g
s
.16861 .66283 m .17418 .71871 L .1951 .72229 L p .707 .577 .707 r
F P
0 g
s
.31001 .74596 m .31561 .76416 L .33898 .75405 L p .707 .577 .707 r
F P
0 g
s
.33898 .75405 m .33339 .73586 L .31001 .74596 L p .707 .577 .707 r
F P
0 g
s
.1955 .77887 m .2011 .79706 L .22708 .79177 L p .707 .577 .707 r
F P
0 g
s
.20327 .77682 m .19245 .74034 L .17264 .74234 L p .707 .577 .707 r
F P
0 g
s
.17418 .71871 m .16861 .66283 L .15613 .65723 L p .707 .577 .707 r
F P
0 g
s
.17264 .74234 m .18346 .77881 L .20327 .77682 L p .707 .577 .707 r
F P
0 g
s
.51794 .86688 m .51235 .84868 L .52848 .83978 L p .707 .577 .707 r
F P
0 g
s
.63549 .30006 m .62129 .80021 L .63129 .7882 L p .707 .577 .707 r
F P
0 g
s
.63129 .7882 m .64549 .28805 L .63549 .30006 L p .707 .577 .707 r
F P
0 g
s
.52848 .83978 m .53408 .85798 L .51794 .86688 L p .707 .577 .707 r
F P
0 g
s
.2011 .79706 m .1955 .77887 L .17578 .78115 L p .707 .577 .707 r
F P
0 g
s
.68609 .79449 m .69169 .81268 L .67196 .81496 L p .707 .577 .707 r
F P
0 g
s
.67196 .81496 m .66637 .79677 L .68609 .79449 L p .707 .577 .707 r
F P
0 g
s
.17578 .78115 m .18137 .79935 L .2011 .79706 L p .707 .577 .707 r
F P
0 g
s
.66351 .71475 m .67434 .75122 L .64826 .75619 L p .707 .577 .707 r
F P
0 g
s
.64826 .75619 m .63743 .71972 L .66351 .71475 L p .707 .577 .707 r
F P
0 g
s
.15613 .65723 m .1617 .7131 L .17418 .71871 L p .707 .577 .707 r
F P
0 g
s
.35622 .63419 m .3618 .69007 L .35898 .68299 L p .707 .577 .707 r
F P
0 g
s
.35898 .68299 m .3534 .62711 L .35622 .63419 L p .707 .577 .707 r
F P
0 g
s
.35684 .72013 m .36243 .73832 L .36021 .73423 L p .707 .577 .707 r
F P
0 g
s
.36021 .73423 m .35462 .71604 L .35684 .72013 L p .707 .577 .707 r
F P
0 g
s
.36182 .28781 m .34762 .78796 L .36539 .79999 L p .707 .577 .707 r
F P
0 g
s
.18346 .77881 m .17264 .74234 L .16103 .74116 L p .707 .577 .707 r
F P
0 g
s
.16103 .74116 m .17186 .77763 L .18346 .77881 L p .707 .577 .707 r
F P
0 g
s
.53408 .85798 m .52848 .83978 L .55186 .82968 L p .707 .577 .707 r
F P
0 g
s
.1617 .7131 m .15613 .65723 L .15331 .65015 L p .707 .577 .707 r
F P
0 g
s
.18137 .79935 m .17578 .78115 L .16424 .7802 L p .707 .577 .707 r
F P
0 g
s
.55186 .82968 m .55745 .84787 L .53408 .85798 L p .707 .577 .707 r
F P
0 g
s
.66637 .79677 m .67196 .81496 L .64598 .82026 L p .707 .577 .707 r
F P
0 g
s
.64598 .82026 m .64039 .80206 L .66637 .79677 L p .707 .577 .707 r
F P
0 g
s
.16424 .7802 m .16984 .7984 L .18137 .79935 L p .707 .577 .707 r
F P
0 g
s
.15331 .65015 m .15888 .70602 L .1617 .7131 L p .707 .577 .707 r
F P
0 g
s
.64549 .28805 m .63129 .7882 L .62721 .77556 L p .707 .577 .707 r
F P
0 g
s
.62721 .77556 m .64141 .27541 L .64549 .28805 L p .707 .577 .707 r
F P
0 g
s
.55745 .84787 m .55186 .82968 L .58019 .81936 L p .707 .577 .707 r
F P
0 g
s
.64039 .80206 m .64598 .82026 L .61628 .82804 L p .707 .577 .707 r
F P
0 g
s
.61628 .82804 m .61069 .80985 L .64039 .80206 L p .707 .577 .707 r
F P
0 g
s
.58019 .81936 m .58578 .83756 L .55745 .84787 L p .707 .577 .707 r
F P
0 g
s
.17186 .77763 m .16103 .74116 L .15877 .73692 L p .707 .577 .707 r
F P
0 g
s
.15877 .73692 m .16959 .77339 L .17186 .77763 L p .707 .577 .707 r
F P
0 g
s
.58578 .83756 m .58019 .81936 L .61069 .80985 L p .707 .577 .707 r
F P
0 g
s
.61069 .80985 m .61628 .82804 L .58578 .83756 L p .707 .577 .707 r
F P
0 g
s
.16984 .7984 m .16424 .7802 L .16202 .77611 L p .707 .577 .707 r
F P
0 g
s
.15888 .70602 m .15331 .65015 L .16041 .64229 L p .707 .577 .707 r
F P
0 g
s
.16202 .77611 m .16762 .79431 L .16984 .7984 L p .707 .577 .707 r
F P
0 g
s
.34092 .62151 m .3465 .67738 L .32559 .6738 L p .707 .577 .707 r
F P
0 g
s
.34308 .71509 m .34868 .73328 L .32895 .73557 L p .707 .577 .707 r
F P
0 g
s
.35774 .27517 m .34354 .77532 L .34762 .78796 L p .707 .577 .707 r
F P
0 g
s
.34354 .77532 m .35774 .27517 L .36774 .26316 L p .707 .577 .707 r
F P
0 g
s
.16041 .64229 m .16599 .69816 L .15888 .70602 L p .707 .577 .707 r
F P
0 g
s
.16959 .77339 m .15877 .73692 L .16607 .73004 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16607 .73004 m .1769 .76651 L .16959 .77339 L p .707 .577 .707 r
F P
0 g
s
.64141 .27541 m .62721 .77556 L .60944 .76353 L p .707 .577 .707 r
F P
0 g
s
.60944 .76353 m .62364 .26338 L .64141 .27541 L p .707 .577 .707 r
F P
0 g
s
.16599 .69816 m .16041 .64229 L .17676 .63441 L p .707 .577 .707 r
F P
0 g
s
.16762 .79431 m .16202 .77611 L .16934 .76928 L p .707 .577 .707 r
F P
0 g
s
.16934 .76928 m .17493 .78748 L .16762 .79431 L p .707 .577 .707 r
F P
0 g
s
.32559 .6738 m .32001 .61792 L .34092 .62151 L p .707 .577 .707 r
F P
0 g
s
.17676 .63441 m .18233 .69029 L .16599 .69816 L p .707 .577 .707 r
F P
0 g
s
.35354 .76331 m .36774 .26316 L .39085 .25296 L p .707 .577 .707 r
F P
0 g
s
.36774 .26316 m .35354 .76331 L .34354 .77532 L p .707 .577 .707 r
F P
0 g
s
.1769 .76651 m .16607 .73004 L .18222 .72119 L p .707 .577 .707 r
F P
0 g
s
.18233 .69029 m .17676 .63441 L .20074 .6273 L p .707 .577 .707 r
F P
0 g
s
.33133 .71596 m .3205 .67949 L .34032 .67749 L p .707 .577 .707 r
F P
0 g
s
.18222 .72119 m .19305 .75766 L .1769 .76651 L p .707 .577 .707 r
F P
0 g
s
.17493 .78748 m .16934 .76928 L .18548 .76038 L p .707 .577 .707 r
F P
0 g
s
.18548 .76038 m .19107 .77858 L .17493 .78748 L p .707 .577 .707 r
F P
0 g
s
.32001 .61792 m .32559 .6738 L .29829 .67259 L p .707 .577 .707 r
F P
0 g
s
.29829 .67259 m .29271 .61671 L .32001 .61792 L p .707 .577 .707 r
F P
0 g
s
.32895 .73557 m .32336 .71737 L .34308 .71509 L p .707 .577 .707 r
F P
0 g
s
.62364 .26338 m .60944 .76353 L .57973 .75328 L p .707 .577 .707 r
F P
0 g
s
.57973 .75328 m .59393 .25313 L .62364 .26338 L p .707 .577 .707 r
F P
0 g
s
.20074 .6273 m .20631 .68318 L .18233 .69029 L p .707 .577 .707 r
F P
0 g
s
.20631 .68318 m .20074 .6273 L .23001 .62164 L p .707 .577 .707 r
F P
0 g
s
.19305 .75766 m .18222 .72119 L .20564 .71123 L p .707 .577 .707 r
F P
0 g
s
.29271 .61671 m .29829 .67259 L .26727 .67387 L p .707 .577 .707 r
F P
0 g
s
.26727 .67387 m .2617 .618 L .29271 .61671 L p .707 .577 .707 r
F P
0 g
s
.39085 .25296 m .37665 .75311 L .35354 .76331 L p .707 .577 .707 r
F P
0 g
s
.37665 .75311 m .39085 .25296 L .4248 .24556 L p .707 .577 .707 r
F P
0 g
s
.32336 .71737 m .32895 .73557 L .30297 .74086 L p .707 .577 .707 r
F P
0 g
s
.30105 .72198 m .27545 .7284 L p .29165 .69089 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .29738 .72266 L .30103 .72192 L p .707 .577 .707 r
F P
0 g
s
.30103 .72192 m .32336 .71737 L p .30578 .73762 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .30103 .72192 L .30578 .73762 L .707 .577 .707 r
F
.29442 .68446 m .30525 .72093 L .30105 .72198 L p F P
0 g
s
.29165 .69089 m .29442 .68446 L .30105 .72198 L .707 .577 .707 r
F
.3205 .67949 m .33133 .71596 L .30525 .72093 L p F P
0 g
s
.30525 .72093 m .29442 .68446 L .3205 .67949 L p .707 .577 .707 r
F P
0 g
s
.73362 .64135 m .72804 .58547 L .69703 .58675 L p .707 .577 .707 r
F P
0 g
s
.72804 .58547 m .73362 .64135 L .76531 .6377 L p .707 .577 .707 r
F P
0 g
s
.76531 .6377 m .75974 .58182 L .72804 .58547 L p .707 .577 .707 r
F P
0 g
s
.20564 .71123 m .21647 .74771 L .19305 .75766 L p .707 .577 .707 r
F P
0 g
s
.75974 .58182 m .76531 .6377 L .79458 .63204 L p .707 .577 .707 r
F P
0 g
s
.79458 .63204 m .789 .57616 L .75974 .58182 L p .707 .577 .707 r
F P
0 g
s
.23558 .67752 m .23001 .62164 L .2617 .618 L p .707 .577 .707 r
F P
0 g
s
.23001 .62164 m .23558 .67752 L .20631 .68318 L p .707 .577 .707 r
F P
0 g
s
.19107 .77858 m .18548 .76038 L .20885 .75028 L p .707 .577 .707 r
F P
0 g
s
.2617 .618 m .26727 .67387 L .23558 .67752 L p .707 .577 .707 r
F P
0 g
s
.70261 .64263 m .69703 .58675 L .66973 .58554 L p .707 .577 .707 r
F P
0 g
s
.69703 .58675 m .70261 .64263 L .73362 .64135 L p .707 .577 .707 r
F P
0 g
s
.20885 .75028 m .21444 .76847 L .19107 .77858 L p .707 .577 .707 r
F P
0 g
s
.789 .57616 m .79458 .63204 L .81856 .62493 L p .707 .577 .707 r
F P
0 g
s
.81856 .62493 m .81298 .56905 L .789 .57616 L p .707 .577 .707 r
F P
0 g
s
.21647 .74771 m .20564 .71123 L .23404 .70115 L p .707 .577 .707 r
F P
0 g
s
.27545 .7284 m .26463 .69192 L .29442 .68446 L p .707 .577 .707 r
F P
0 g
s
.59393 .25313 m .57973 .75328 L .54099 .74582 L p .707 .577 .707 r
F P
0 g
s
.54099 .74582 m .55519 .24567 L .59393 .25313 L p .707 .577 .707 r
F P
0 g
s
.23404 .70115 m .24486 .73762 L .21647 .74771 L p .707 .577 .707 r
F P
0 g
s
.66973 .58554 m .67531 .64142 L .70261 .64263 L p .707 .577 .707 r
F P
0 g
s
.73936 .7076 m .72854 .67113 L .69874 .67859 L p .707 .577 .707 r
F P
0 g
s
.72854 .67113 m .73936 .7076 L .76995 .69838 L p .707 .577 .707 r
F P
0 g
s
.76995 .69838 m .75913 .6619 L .72854 .67113 L p .707 .577 .707 r
F P
0 g
s
.67531 .64142 m .66973 .58554 L .64882 .58196 L p .707 .577 .707 r
F P
0 g
s
.21444 .76847 m .20885 .75028 L .23718 .73997 L p .707 .577 .707 r
F P
0 g
s
.75913 .6619 m .76995 .69838 L .79835 .68829 L p .707 .577 .707 r
F P
0 g
s
.79835 .68829 m .78753 .65182 L .75913 .6619 L p .707 .577 .707 r
F P
0 g
s
.24486 .73762 m .23404 .70115 L .26463 .69192 L p .707 .577 .707 r
F P
0 g
s
.26463 .69192 m .27545 .7284 L .24486 .73762 L p .707 .577 .707 r
F P
0 g
s
.29738 .72266 m .30297 .74086 L .27327 .74865 L p .707 .577 .707 r
F P
0 g
s
.27327 .74865 m .26768 .73045 L .29738 .72266 L p .707 .577 .707 r
F P
0 g
s
.23718 .73997 m .24277 .75816 L .21444 .76847 L p .707 .577 .707 r
F P
0 g
s
.4106 .74571 m .4248 .24556 L .46627 .24169 L p .707 .577 .707 r
F P
0 g
s
.4248 .24556 m .4106 .74571 L .37665 .75311 L p .707 .577 .707 r
F P
0 g
s
.69874 .67859 m .70957 .71507 L .73936 .7076 L p .707 .577 .707 r
F P
0 g
s
.70957 .71507 m .69874 .67859 L .67266 .68356 L p .707 .577 .707 r
F P
0 g
s
.81298 .56905 m .81856 .62493 L .8349 .61706 L p .707 .577 .707 r
F P
0 g
s
.8349 .61706 m .82933 .56118 L .81298 .56905 L p .707 .577 .707 r
F P
0 g
s
.24277 .75816 m .23718 .73997 L .26768 .73045 L p .707 .577 .707 r
F P
0 g
s
.78753 .65182 m .79835 .68829 L .82177 .67834 L p .707 .577 .707 r
F P
0 g
s
.82177 .67834 m .81095 .64186 L .78753 .65182 L p .707 .577 .707 r
F P
0 g
s
.26768 .73045 m .27327 .74865 L .24277 .75816 L p .707 .577 .707 r
F P
0 g
s
.64882 .58196 m .6544 .63784 L .67531 .64142 L p .707 .577 .707 r
F P
0 g
s
.67266 .68356 m .68349 .72004 L .70957 .71507 L p .707 .577 .707 r
F P
0 g
s
.55519 .24567 m .54099 .74582 L .497 .74188 L p .707 .577 .707 r
F P
0 g
s
.497 .74188 m .5112 .24173 L .55519 .24567 L p .707 .577 .707 r
F P
0 g
s
.73699 .77134 m .7314 .75315 L .7017 .76094 L p .707 .577 .707 r
F P
0 g
s
.7314 .75315 m .73699 .77134 L .76749 .76183 L p .707 .577 .707 r
F P
0 g
s
.76749 .76183 m .7619 .74363 L .7314 .75315 L p .707 .577 .707 r
F P
0 g
s
.45369 .68474 m .46627 .24169 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .45207 .74184 L .4106 .74571 L p .707 .577 .707 r
F P
0 g
s
.38503 .5743 m .39061 .63018 L .4223 .62653 L p .707 .577 .707 r
F P
0 g
s
.41612 .62664 m .42261 .64852 L p .45534 .65303 L .707 .577 .707 r
F P
0 g
s
.42261 .64852 m .42694 .66312 L .43322 .66089 L p .707 .577 .707 r
F P
0 g
s
.43322 .66089 m .45534 .65303 L p .42261 .64852 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .5112 .24173 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.45207 .74184 m .45369 .68474 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.7619 .74363 m .76749 .76183 L .79582 .75152 L p .707 .577 .707 r
F P
0 g
s
.79582 .75152 m .79023 .73332 L .7619 .74363 L p .707 .577 .707 r
F P
0 g
s
.7017 .76094 m .70729 .77913 L .73699 .77134 L p .707 .577 .707 r
F P
0 g
s
.6544 .63784 m .64882 .58196 L .63634 .57635 L p .707 .577 .707 r
F P
0 g
s
.5112 .24173 m .497 .74188 L .45207 .74184 L p .707 .577 .707 r
F P
0 g
s
.68349 .72004 m .67266 .68356 L .65285 .68556 L p .707 .577 .707 r
F P
0 g
s
.70729 .77913 m .7017 .76094 L .67572 .76623 L p .707 .577 .707 r
F P
0 g
s
.81095 .64186 m .82177 .67834 L .83792 .66949 L p .707 .577 .707 r
F P
0 g
s
.83792 .66949 m .8271 .63301 L .81095 .64186 L p .707 .577 .707 r
F P
0 g
s
.65285 .68556 m .66368 .72203 L .68349 .72004 L p .707 .577 .707 r
F P
0 g
s
.79023 .73332 m .79582 .75152 L .81919 .74141 L p .707 .577 .707 r
F P
0 g
s
.81919 .74141 m .8136 .72322 L .79023 .73332 L p .707 .577 .707 r
F P
0 g
s
.67572 .76623 m .68131 .78442 L .70729 .77913 L p .707 .577 .707 r
F P
0 g
s
.82933 .56118 m .8349 .61706 L .84201 .6092 L p .707 .577 .707 r
F P
0 g
s
.84201 .6092 m .83644 .55332 L .82933 .56118 L p .707 .577 .707 r
F P
0 g
s
.63634 .57635 m .64192 .63223 L .6544 .63784 L p .707 .577 .707 r
F P
0 g
s
.68131 .78442 m .67572 .76623 L .65599 .76851 L p .707 .577 .707 r
F P
0 g
s
.65599 .76851 m .66158 .78671 L .68131 .78442 L p .707 .577 .707 r
F P
0 g
s
.66368 .72203 m .65285 .68556 L .64125 .68438 L p .707 .577 .707 r
F P
0 g
s
.8136 .72322 m .81919 .74141 L .83533 .73251 L p .707 .577 .707 r
F P
0 g
s
.83533 .73251 m .82974 .71432 L .8136 .72322 L p .707 .577 .707 r
F P
0 g
s
.64192 .63223 m .63634 .57635 L .63352 .56927 L p .707 .577 .707 r
F P
0 g
s
.8271 .63301 m .83792 .66949 L .84522 .6626 L p .707 .577 .707 r
F P
0 g
s
.84522 .6626 m .8344 .62613 L .8271 .63301 L p .707 .577 .707 r
F P
0 g
s
.64125 .68438 m .65207 .72085 L .66368 .72203 L p .707 .577 .707 r
F P
0 g
s
.83644 .55332 m .84201 .6092 L .83919 .60212 L p .707 .577 .707 r
F P
0 g
s
.83919 .60212 m .83361 .54624 L .83644 .55332 L p .707 .577 .707 r
F P
0 g
s
.63352 .56927 m .63909 .62515 L .64192 .63223 L p .707 .577 .707 r
F P
0 g
s
.66158 .78671 m .65599 .76851 L .64445 .76756 L p .707 .577 .707 r
F P
0 g
s
.64445 .76756 m .65005 .78576 L .66158 .78671 L p .707 .577 .707 r
F P
0 g
s
.82974 .71432 m .83533 .73251 L .84265 .72568 L p .707 .577 .707 r
F P
0 g
s
.84265 .72568 m .83705 .70749 L .82974 .71432 L p .707 .577 .707 r
F P
0 g
s
.65207 .72085 m .64125 .68438 L .63898 .68014 L p .707 .577 .707 r
F P
0 g
s
.63909 .62515 m .63352 .56927 L .64063 .56141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63898 .68014 m .64981 .71662 L .65207 .72085 L p .707 .577 .707 r
F P
0 g
s
.8344 .62613 m .84522 .6626 L .84296 .65837 L p .707 .577 .707 r
F P
0 g
s
.84296 .65837 m .83213 .62189 L .8344 .62613 L p .707 .577 .707 r
F P
0 g
s
.83361 .54624 m .83919 .60212 L .82671 .59651 L p .707 .577 .707 r
F P
0 g
s
.82671 .59651 m .82114 .54063 L .83361 .54624 L p .707 .577 .707 r
F P
0 g
s
.64063 .56141 m .6462 .61729 L .63909 .62515 L p .707 .577 .707 r
F P
0 g
s
.65005 .78576 m .64445 .76756 L .64224 .76347 L p .707 .577 .707 r
F P
0 g
s
.64224 .76347 m .64783 .78167 L .65005 .78576 L p .707 .577 .707 r
F P
0 g
s
.83705 .70749 m .84265 .72568 L .84043 .72159 L p .707 .577 .707 r
F P
0 g
s
.84043 .72159 m .83483 .7034 L .83705 .70749 L p .707 .577 .707 r
F P
0 g
s
.64981 .71662 m .63898 .68014 L .64629 .67326 L p .707 .577 .707 r
F P
0 g
s
.6462 .61729 m .64063 .56141 L .65697 .55354 L p .707 .577 .707 r
F P
0 g
s
.39061 .63018 m .38503 .5743 L .35402 .57558 L p .707 .577 .707 r
F P
0 g
s
.4223 .62653 m .41673 .57065 L .38503 .5743 L p .707 .577 .707 r
F P
0 g
s
.41673 .57065 m .4223 .62653 L .45157 .62087 L p .707 .577 .707 r
F P
0 g
s
.45157 .62087 m .44599 .565 L .41673 .57065 L p .707 .577 .707 r
F P
0 g
s
.64629 .67326 m .65711 .70973 L .64981 .71662 L p .707 .577 .707 r
F P
0 g
s
.83213 .62189 m .84296 .65837 L .83135 .65719 L p .707 .577 .707 r
F P
0 g
s
.83135 .65719 m .82053 .62071 L .83213 .62189 L p .707 .577 .707 r
F P
0 g
s
.3596 .63146 m .35402 .57558 L .32672 .57437 L p .707 .577 .707 r
F P
0 g
s
.35402 .57558 m .3596 .63146 L .39061 .63018 L p .707 .577 .707 r
F P
0 g
s
.82114 .54063 m .82671 .59651 L .8058 .59293 L p .707 .577 .707 r
F P
0 g
s
.8058 .59293 m .80022 .53705 L .82114 .54063 L p .707 .577 .707 r
F P
0 g
s
.65697 .55354 m .66255 .60942 L .6462 .61729 L p .707 .577 .707 r
F P
0 g
s
.44599 .565 m .45157 .62087 L .47555 .61376 L p .707 .577 .707 r
F P
0 g
s
.47555 .61376 m .46997 .55788 L .44599 .565 L p .707 .577 .707 r
F P
0 g
s
.39635 .67234 m .38553 .63587 L .35573 .64333 L p .707 .577 .707 r
F P
0 g
s
.38553 .63587 m .39635 .67234 L .42694 .66312 L p .707 .577 .707 r
F P
0 g
s
.42694 .66312 m .41612 .62664 L .38553 .63587 L p .707 .577 .707 r
F P
0 g
s
.45534 .65303 m .44452 .61656 L .41612 .62664 L p .707 .577 .707 r
F P
0 g
s
.64783 .78167 m .64224 .76347 L .64955 .75664 L p .707 .577 .707 r
F P
0 g
s
.32672 .57437 m .3323 .63025 L .3596 .63146 L p .707 .577 .707 r
F P
0 g
s
.64955 .75664 m .65515 .77484 L .64783 .78167 L p .707 .577 .707 r
F P
0 g
s
.35573 .64333 m .36656 .67981 L .39635 .67234 L p .707 .577 .707 r
F P
0 g
s
.3323 .63025 m .32672 .57437 L .30581 .57079 L p .707 .577 .707 r
F P
0 g
s
.83483 .7034 m .84043 .72159 L .82889 .72064 L p .707 .577 .707 r
F P
0 g
s
.82889 .72064 m .8233 .70245 L .83483 .7034 L p .707 .577 .707 r
F P
0 g
s
.66255 .60942 m .65697 .55354 L .68095 .54643 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35573 .64333 L .35189 .64406 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35189 .64406 L .36133 .67534 L .707 .577 .707 r
F
.36287 .68044 m .35869 .68154 L p .36364 .683 L F P
0 g
s
.32965 .6483 m .34048 .68478 L .36656 .67981 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .38839 .67375 L .36287 .68044 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .36287 .68044 L .36364 .683 L .707 .577 .707 r
F
.35189 .64406 m .32965 .6483 L p .36133 .67534 L F P
0 g
s
.38839 .67375 m .39398 .69195 L .42448 .68243 L p .707 .577 .707 r
F P
0 g
s
.42448 .68243 m .41889 .66424 L .38839 .67375 L p .707 .577 .707 r
F P
0 g
s
.41889 .66424 m .42448 .68243 L .45281 .67212 L p .707 .577 .707 r
F P
0 g
s
.45281 .67212 m .44722 .65392 L .41889 .66424 L p .707 .577 .707 r
F P
0 g
s
.65711 .70973 m .64629 .67326 L .66244 .66441 L p .707 .577 .707 r
F P
0 g
s
.44452 .61656 m .45534 .65303 L .47876 .64308 L p .707 .577 .707 r
F P
0 g
s
.47876 .64308 m .46794 .6066 L .44452 .61656 L p .707 .577 .707 r
F P
0 g
s
.35869 .68154 m .36428 .69973 L .39398 .69195 L p .707 .577 .707 r
F P
0 g
s
.82053 .62071 m .83135 .65719 L .81154 .65918 L p .707 .577 .707 r
F P
0 g
s
.81154 .65918 m .80072 .62271 L .82053 .62071 L p .707 .577 .707 r
F P
0 g
s
.66244 .66441 m .67326 .70088 L .65711 .70973 L p .707 .577 .707 r
F P
0 g
s
.46997 .55788 m .47555 .61376 L .49189 .60589 L p .707 .577 .707 r
F P
0 g
s
.49189 .60589 m .48632 .55001 L .46997 .55788 L p .707 .577 .707 r
F P
0 g
s
.80022 .53705 m .8058 .59293 L .7785 .59172 L p .707 .577 .707 r
F P
0 g
s
.7785 .59172 m .77292 .53584 L .80022 .53705 L p .707 .577 .707 r
F P
0 g
s
.36428 .69973 m .35869 .68154 L .33271 .68683 L p .707 .577 .707 r
F P
0 g
s
.30581 .57079 m .31139 .62667 L .3323 .63025 L p .707 .577 .707 r
F P
0 g
s
.44722 .65392 m .45281 .67212 L .47618 .66201 L p .707 .577 .707 r
F P
0 g
s
.47618 .66201 m .47059 .64382 L .44722 .65392 L p .707 .577 .707 r
F P
0 g
s
.33271 .68683 m .3383 .70503 L .36428 .69973 L p .707 .577 .707 r
F P
0 g
s
.68095 .54643 m .68653 .60231 L .66255 .60942 L p .707 .577 .707 r
F P
0 g
s
.34048 .68478 m .32965 .6483 L .30984 .6503 L p .707 .577 .707 r
F P
0 g
s
.68653 .60231 m .68095 .54643 L .71022 .54077 L p .707 .577 .707 r
F P
0 g
s
.46794 .6066 m .47876 .64308 L .49491 .63423 L p .707 .577 .707 r
F P
0 g
s
.49491 .63423 m .48409 .59775 L .46794 .6066 L p .707 .577 .707 r
F P
0 g
s
.31139 .62667 m .30581 .57079 L .29333 .56519 L p .707 .577 .707 r
F P
0 g
s
.30984 .6503 m .32067 .68677 L .34048 .68478 L p .707 .577 .707 r
F P
0 g
s
.65515 .77484 m .64955 .75664 L .66569 .74774 L p .707 .577 .707 r
F P
0 g
s
.77292 .53584 m .7785 .59172 L .74749 .593 L p .707 .577 .707 r
F P
0 g
s
.74749 .593 m .74191 .53712 L .77292 .53584 L p .707 .577 .707 r
F P
0 g
s
.66569 .74774 m .67128 .76594 L .65515 .77484 L p .707 .577 .707 r
F P
0 g
s
.3383 .70503 m .33271 .68683 L .31298 .68911 L p .707 .577 .707 r
F P
0 g
s
.67326 .70088 m .66244 .66441 L .68586 .65446 L p .707 .577 .707 r
F P
0 g
s
.8233 .70245 m .82889 .72064 L .80917 .72293 L p .707 .577 .707 r
F P
0 g
s
.80917 .72293 m .80357 .70473 L .8233 .70245 L p .707 .577 .707 r
F P
0 g
s
.31298 .68911 m .31857 .70731 L .3383 .70503 L p .707 .577 .707 r
F P
0 g
s
.7158 .59665 m .71022 .54077 L .74191 .53712 L p .707 .577 .707 r
F P
0 g
s
.71022 .54077 m .7158 .59665 L .68653 .60231 L p .707 .577 .707 r
F P
0 g
s
.47059 .64382 m .47618 .66201 L .49232 .65311 L p .707 .577 .707 r
F P
0 g
s
.49232 .65311 m .48673 .63492 L .47059 .64382 L p .707 .577 .707 r
F P
0 g
s
.80072 .62271 m .81154 .65918 L .78546 .66416 L p .707 .577 .707 r
F P
0 g
s
.78546 .66416 m .77464 .62768 L .80072 .62271 L p .707 .577 .707 r
F P
0 g
s
.74191 .53712 m .74749 .593 L .7158 .59665 L p .707 .577 .707 r
F P
0 g
s
.68586 .65446 m .69668 .69093 L .67326 .70088 L p .707 .577 .707 r
F P
0 g
s
.48632 .55001 m .49189 .60589 L .499 .59803 L p .707 .577 .707 r
F P
0 g
s
.499 .59803 m .49343 .54215 L .48632 .55001 L p .707 .577 .707 r
F P
0 g
s
.29333 .56519 m .29891 .62107 L .31139 .62667 L p .707 .577 .707 r
F P
0 g
s
.32067 .68677 m .30984 .6503 L .29824 .64912 L p .707 .577 .707 r
F P
0 g
s
.69668 .69093 m .68586 .65446 L .71425 .64437 L p .707 .577 .707 r
F P
0 g
s
.48409 .59775 m .49491 .63423 L .50221 .62734 L p .707 .577 .707 r
F P
0 g
s
.50221 .62734 m .49139 .59087 L .48409 .59775 L p .707 .577 .707 r
F P
0 g
s
.29824 .64912 m .30906 .68559 L .32067 .68677 L p .707 .577 .707 r
F P
0 g
s
.67128 .76594 m .66569 .74774 L .68906 .73764 L p .707 .577 .707 r
F P
0 g
s
.77464 .62768 m .78546 .66416 L .75567 .67162 L p .707 .577 .707 r
F P
0 g
s
.75567 .67162 m .74484 .63515 L .77464 .62768 L p .707 .577 .707 r
F P
0 g
s
.29891 .62107 m .29333 .56519 L .29051 .55811 L p .707 .577 .707 r
F P
0 g
s
.31857 .70731 m .31298 .68911 L .30144 .68816 L p .707 .577 .707 r
F P
0 g
s
.68906 .73764 m .69466 .75584 L .67128 .76594 L p .707 .577 .707 r
F P
0 g
s
.71425 .64437 m .72507 .68085 L .69668 .69093 L p .707 .577 .707 r
F P
0 g
s
.80357 .70473 m .80917 .72293 L .78319 .72822 L p .707 .577 .707 r
F P
0 g
s
.78319 .72822 m .77759 .71003 L .80357 .70473 L p .707 .577 .707 r
F P
0 g
s
.30144 .68816 m .30704 .70636 L .31857 .70731 L p .707 .577 .707 r
F P
0 g
s
.48673 .63492 m .49232 .65311 L .49964 .64628 L p .707 .577 .707 r
F P
0 g
s
.49964 .64628 m .49404 .62809 L .48673 .63492 L p .707 .577 .707 r
F P
0 g
s
.72507 .68085 m .71425 .64437 L .74484 .63515 L p .707 .577 .707 r
F P
0 g
s
.74484 .63515 m .75567 .67162 L .72507 .68085 L p .707 .577 .707 r
F P
0 g
s
.49343 .54215 m .499 .59803 L .49618 .59095 L p .707 .577 .707 r
F P
0 g
s
.49618 .59095 m .4906 .53507 L .49343 .54215 L p .707 .577 .707 r
F P
0 g
s
.29051 .55811 m .29608 .61399 L .29891 .62107 L p .707 .577 .707 r
F P
0 g
s
.69466 .75584 m .68906 .73764 L .71739 .72733 L p .707 .577 .707 r
F P
0 g
s
.77759 .71003 m .78319 .72822 L .75349 .73601 L p .707 .577 .707 r
F P
0 g
s
.75349 .73601 m .74789 .71781 L .77759 .71003 L p .707 .577 .707 r
F P
0 g
s
.71739 .72733 m .72298 .74552 L .69466 .75584 L p .707 .577 .707 r
F P
0 g
s
.30906 .68559 m .29824 .64912 L .29597 .64488 L p .707 .577 .707 r
F P
0 g
s
.29597 .64488 m .3068 .68136 L .30906 .68559 L p .707 .577 .707 r
F P
0 g
s
.49139 .59087 m .50221 .62734 L .49995 .62311 L p .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49139 .59087 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.4991 .62027 m .48912 .58663 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49995 .62311 L .48834 .62193 L p .707 .577 .707 r
F P
0 g
s
.48834 .62193 m .47752 .58545 L .48912 .58663 L p .707 .577 .707 r
F P
0 g
s
.4906 .53507 m .49618 .59095 L .48899 .58772 L p .707 .577 .707 r
F P
0 g
s
.48899 .58772 m .4837 .58535 L p .48509 .5752 L .707 .577 .707 r
F P
0 g
s
.48509 .5752 m .4906 .53507 L .48899 .58772 L .707 .577 .707 r
F
.49995 .62311 m .4991 .62027 L p .49971 .62222 L F P
0 g
s
.72298 .74552 m .71739 .72733 L .74789 .71781 L p .707 .577 .707 r
F P
0 g
s
.74789 .71781 m .75349 .73601 L .72298 .74552 L p .707 .577 .707 r
F P
0 g
s
.30704 .70636 m .30144 .68816 L .29923 .68407 L p .707 .577 .707 r
F P
0 g
s
.29608 .61399 m .29051 .55811 L .29762 .55025 L p .707 .577 .707 r
F P
0 g
s
.29923 .68407 m .30482 .70227 L .30704 .70636 L p .707 .577 .707 r
F P
0 g
s
.49404 .62809 m .49964 .64628 L .49742 .64219 L p .707 .577 .707 r
F P
0 g
s
.49742 .64219 m .49182 .624 L .49404 .62809 L p .707 .577 .707 r
F P
0 g
s
.4837 .58535 m .47813 .52947 L .4906 .53507 L p .707 .577 .707 r
F P
0 g
s
.29762 .55025 m .30319 .60613 L .29608 .61399 L p .707 .577 .707 r
F P
0 g
s
.3068 .68136 m .29597 .64488 L .30328 .638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30328 .638 m .3141 .67447 L .3068 .68136 L p .707 .577 .707 r
F P
0 g
s
.30319 .60613 m .29762 .55025 L .31396 .54238 L p .707 .577 .707 r
F P
0 g
s
.30482 .70227 m .29923 .68407 L .30654 .67724 L p .707 .577 .707 r
F P
0 g
s
.30654 .67724 m .31214 .69544 L .30482 .70227 L p .707 .577 .707 r
F P
0 g
s
.49182 .624 m .49742 .64219 L .48588 .64124 L p .707 .577 .707 r
F P
0 g
s
.48588 .64124 m .48029 .62305 L .49182 .624 L p .707 .577 .707 r
F P
0 g
s
.47813 .52947 m .4837 .58535 L .46279 .58176 L p .707 .577 .707 r
F P
0 g
s
.46279 .58176 m .45721 .52588 L .47813 .52947 L p .707 .577 .707 r
F P
0 g
s
.31396 .54238 m .31954 .59825 L .30319 .60613 L p .707 .577 .707 r
F P
0 g
s
.3141 .67447 m .30328 .638 L .31943 .62915 L p .707 .577 .707 r
F P
0 g
s
.31954 .59825 m .31396 .54238 L .33794 .53526 L p .707 .577 .707 r
F P
0 g
s
.47752 .58545 m .48834 .62193 L .46853 .62392 L p .707 .577 .707 r
F P
0 g
s
.46853 .62392 m .45771 .58745 L .47752 .58545 L p .707 .577 .707 r
F P
0 g
s
.31943 .62915 m .33025 .66562 L .3141 .67447 L p .707 .577 .707 r
F P
0 g
s
.31214 .69544 m .30654 .67724 L .32268 .66834 L p .707 .577 .707 r
F P
0 g
s
.32268 .66834 m .32827 .68654 L .31214 .69544 L p .707 .577 .707 r
F P
0 g
s
.45721 .52588 m .46279 .58176 L .43549 .58055 L p .707 .577 .707 r
F P
0 g
s
.43549 .58055 m .42991 .52467 L .45721 .52588 L p .707 .577 .707 r
F P
0 g
s
.48029 .62305 m .48588 .64124 L .46616 .64353 L p .707 .577 .707 r
F P
0 g
s
.46616 .64353 m .46056 .62533 L .48029 .62305 L p .707 .577 .707 r
F P
0 g
s
.33794 .53526 m .34352 .59114 L .31954 .59825 L p .707 .577 .707 r
F P
0 g
s
.34352 .59114 m .33794 .53526 L .36721 .5296 L p .707 .577 .707 r
F P
0 g
s
.33025 .66562 m .31943 .62915 L .34285 .61919 L p .707 .577 .707 r
F P
0 g
s
.42991 .52467 m .43549 .58055 L .40448 .58184 L p .707 .577 .707 r
F P
0 g
s
.40448 .58184 m .3989 .52596 L .42991 .52467 L p .707 .577 .707 r
F P
0 g
s
.46056 .62533 m .46616 .64353 L .44017 .64882 L p .707 .577 .707 r
F P
0 g
s
.43826 .62995 m .41266 .63636 L p .42885 .59885 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43458 .63063 L .43824 .62988 L p .707 .577 .707 r
F P
0 g
s
.43824 .62988 m .46056 .62533 L p .44299 .64558 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43824 .62988 L .44299 .64558 L .707 .577 .707 r
F
.43163 .59242 m .44245 .6289 L .43826 .62995 L p F P
0 g
s
.42885 .59885 m .43163 .59242 L .43826 .62995 L .707 .577 .707 r
F
.45771 .58745 m .46853 .62392 L .44245 .6289 L p F P
0 g
s
.44245 .6289 m .43163 .59242 L .45771 .58745 L p .707 .577 .707 r
F P
0 g
s
.34285 .61919 m .35367 .65567 L .33025 .66562 L p .707 .577 .707 r
F P
0 g
s
.37278 .58548 m .36721 .5296 L .3989 .52596 L p .707 .577 .707 r
F P
0 g
s
.36721 .5296 m .37278 .58548 L .34352 .59114 L p .707 .577 .707 r
F P
0 g
s
.32827 .68654 m .32268 .66834 L .34605 .65824 L p .707 .577 .707 r
F P
0 g
s
.3989 .52596 m .40448 .58184 L .37278 .58548 L p .707 .577 .707 r
F P
0 g
s
.34605 .65824 m .35165 .67644 L .32827 .68654 L p .707 .577 .707 r
F P
0 g
s
.35367 .65567 m .34285 .61919 L .37124 .60911 L p .707 .577 .707 r
F P
0 g
s
.41266 .63636 m .40183 .59989 L .43163 .59242 L p .707 .577 .707 r
F P
0 g
s
.37124 .60911 m .38206 .64559 L .35367 .65567 L p .707 .577 .707 r
F P
0 g
s
.35165 .67644 m .34605 .65824 L .37438 .64793 L p .707 .577 .707 r
F P
0 g
s
.38206 .64559 m .37124 .60911 L .40183 .59989 L p .707 .577 .707 r
F P
0 g
s
.40183 .59989 m .41266 .63636 L .38206 .64559 L p .707 .577 .707 r
F P
0 g
s
.43458 .63063 m .44017 .64882 L .41048 .65661 L p .707 .577 .707 r
F P
0 g
s
.41048 .65661 m .40488 .63841 L .43458 .63063 L p .707 .577 .707 r
F P
0 g
s
.37438 .64793 m .37997 .66612 L .35165 .67644 L p .707 .577 .707 r
F P
0 g
s
.37997 .66612 m .37438 .64793 L .40488 .63841 L p .707 .577 .707 r
F P
0 g
s
.40488 .63841 m .41048 .65661 L .37997 .66612 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20004UYF00<005YFFUH00eYF2000OWoo001dOol300000eYF001JEP0GFUH00`00FUIJEP09
FUH00`00FUH00003001jOol0075oo`<000AJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF
00=JEP@007Ioo`00KWoo0`001eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH01eYF1000
LWoo001ZOol400000eYF001JEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04001^Ool006Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00Igoo0P001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001VOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH00000J7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001V
Ool006Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEQL000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00Hgoo00<005YFFUH01`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8001QooaP003Moo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@003=oo`00F7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00EWoo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Yoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000`Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001C
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002moo`00DWoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20002Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001BOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYF001JEP0_Ool0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P0025YF
00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH6
0002FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`03001JEP00
00AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000D000=JEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF60000UYF00D005YF
FUIJEP0002ioo`00Dgoo00@005YFFUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH015YF
1P0000AJEP00000000=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001oogoo02aoo`00
Dgoo00@005YFFUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<0
05YF000010000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP000000;Goo
001DOol2FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP03FUH50008FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF1000;Goo001DOol2FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo001DOol015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH0
0`0025YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP@000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00E7oo00@005YFFUH000EJEP03001JEUYF00EJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0
04Ioo`l000=JEP03001JEUYF009JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo0010Ool60004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF0000000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000`Ool003aoo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP06001JEP00001JEP000eYF100000=JEP00FUH01eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF3@002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF1`000UYF00@005YFFUH0031oo`00>7oo10001EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EPH000EJEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EPL000=JEP03001JEUYF00AJEP04001JEUYF000_Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04
001JEUYFFUH50005FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0000=JEP00FUH01UYF00<0
05YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000`001eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF10000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0000=JEP00FUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000MJEQ@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00AJEP04001JEUYF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH40004FUH0
0`00FUIJEP07FUH01000FUIJEUYF1`000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP03001JEUYF008000=oo`<000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH900000eYF001JEP04FUH4
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH0
1@00FUIJEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
00000eYF001JEP08FUH00`00FUIJEP040003FUH30005FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YF000002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF100015YF00<005YFFUH01EYF
100000=JEP00FUH00UYF0P0000=JEP00FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP04001JEUYFFUH30008FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00Ool0;7oo000[
Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00D005YFFUIJEP0000AJEP<000MJEP03001JEUYF00=JEP8000IJEP<000=JEP03001J
EUYF00EJEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000MJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH70003
FUH4000/Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH01P00FUH00000FUH000UJEP03001JEP000080
00EJEP<000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000IJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPH000EJEP03001JEUYF009JEP04001JEUYF000/Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00=JEP8000=J
EP03001JEUYF00IJEP<00003FUH005YF009JEP<00003FUH005YF00MJEP04001JEUYFFUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH30006FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00009JEP04001JEP000006FUH00`00FUIJEP02FUH30005FUH30004
FUH00`00FUIJEP06FUH01000FUH000002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF10001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0002FUH30007FUH00`00FUH000020005FUH3
0007FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000<7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04
FUH20003FUH500000eYF001JEP08FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000bOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP800003FUH0000000<000EJEP@000IJEP03001J
EP00008000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP@000MJEP03
001JEUYF00IJEP03001JEUYF009JEP8003Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH015YF00<005YF00001000
00=JEP00FUH01eYF1@000eYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;7oo00@005YF
FUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00004FUH005YF0002
FUH01000FUIJEUYF10001UYF00<005YFFUH01EYF20002UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00@005YF
FUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP80009JEP04001J
EP000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH500000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
1EYF00<005YFFUH015YF0`002EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00?7oo000]Ool2FUH0
1000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00@005YF001J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH000000002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
1EYF001JEUYF000015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YF00000P00?Woo000]Ool2FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00
FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP800005FUH005YFFUH00005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01EYF
0`00@Goo000]Ool015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH00`0025YF00<005YFFUH0
1EYF00H005YF000005YF0006FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
0002FUH00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000?Ool4000aOol0
02eoo`04001JEUYF0005FUH00`00FUIJEP05FUH300000eYF001JEP08FUH00`00FUIJEP06FUH01P00
FUH00000FUH000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUH00002000:Ool7
0002FUH01000FUH00000;goo000]Ool01@00FUIJEUYF000015YF00<005YFFUH00eYF0`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00Qoo`D000=JEP03001JEUYF00=JEP04001JEUYF000_Ool002eoo`05001JEUYFFUH00005FUH00`00
FUH000020007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP040009Ool300000eYF001JEP05FUH00`00FUIJEP04FUH00`00FUH0000_Ool0
02ioo`800003FUH005YF00AJEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEPD0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP800003FUH005YF00EJEP04001JEUYFFUH6000:Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool400000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00001P0000=JEP00FUH00UYF1`002goo10001eYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH007oo02eoo`00<goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF1P000eYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH50003FUH01000FUIJEP001goo10000UYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000eYF1000;Goo000aOol30007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH500000eYF001J
EP06FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF
001JEP0000IJEP03001JEUYF00=JEP03001JEUYF0080009oo`@000MJEP03001JEUYF00IJEP03001J
EP0000D00003FUH005YF00=JEP04001JEUYF000]Ool002moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP05FUH30002Ool20003FUH00`00FUIJEP03FUH2000^
Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP040002Ool30006FUH01000FUIJEUYF0P00;goo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH01EYF100015YF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03
001JEUYF00EJEPD000Aoo`800003FUH005YF00IJEP04001JEP00000aOol002eoo`04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH7000015YF000000000UYF
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00MJEQ8000UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00<000UJEP03001JEUYF
00@000Ioo`<000AJEP03001JEUYF00AJEP8003=oo`00;Goo0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH010001EYF0`000eYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000YJEP03001JEUYF00EJEPH000=JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP<000=JEP03
001JEUYF00EJEP@000Moo`<000MJEP03001JEUYF009JEP8003Eoo`00;Woo00<005YF000015YF00<0
05YFFUH015YF100015YF00<005YFFUH01EYF100000=JEP00FUH015YF0`001EYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH015YF1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF1`0025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF
0P0027oo0`0000=JEP00FUH025YF00@005YF000003Moo`00;Woo00@005YFFUH000=JEP03001JEUYF
009JEP<000MJEP03001JEUYF00=JEP8000IJEP03001JEP0000800003FUH005YF00IJEP80009JEP03
001JEUYF00AJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJ
EPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH30007FUH00`00FUH0
00020007Ool30005FUH00`00FUIJEP05FUH3000iOol002ioo`04001JEUYF0004FUH01P00FUH00000
FUH000UJEP03001JEP00008000MJEP@000=JEP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEP@0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPD000MJEP03
001JEUYF009JEP8000AJEP<0009JEP03001JEUYF00AJEP<0009JEP03001oogoo009oo`<000QJEP03
001JEUYF00=JEP8003aoo`00;Woo0P0000=JEP00FUH00eYF0P000eYF00<005YFFUH01UYF0`0000=J
EP00FUH015YF10001eYF00@005YFFUIJEP80009oo`04001JEUYF0003FUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP02FUH20002FUH30005FUH01000FUIJEUYF0P000eYF0P0000=oo`0000000P0000=JEP00FUH0
2EYF00<005YF00000P00?Woo000_Ool01@00FUIJEP00FUH00P001UYF00<005YFFUH00UYF0`001EYF
1@000UYF00<005YFFUH01UYF00@005YF000000Aoo`05001JEUYF001JEP020008FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001J
EP03FUH400000eYF00000005FUH01000FUH000000UYF1P001UYF00<005YFFUH01UYF0`00@Goo000_
Ool00`00FUIJEP030007FUH00`00FUH000020005FUH40006FUH00`00FUIJEP05FUH30006Ool00`00
FUIJEP0200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000UYF00@005YFFUH000AJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP<004Aoo`00;goo0`000eYF00<005YFFUH015YF0P000eYF1@00
00=JEP00FUH025YF00<005YFFUH00UYF0P002Goo00<005YF00000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP80009JEP04001JEUYF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
00000P00Agoo000_Ool20004FUH00`00FUIJEP02FUH200000eYF000000030006FUH30006FUH00`00
FUH00002000;Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001:Ool002ioo`03001JEP0000EJEP03001JEP0000@0
0003FUH005YF00MJEPD000AJEP<000ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEP000003FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP04001=Ool002io
o`04001JEUYF0003FUH40006FUH00`00FUIJEP05FUH9000AOol00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF00001EYF00<005YFFUH015YF1000DGoo000^
Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@005Goo00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP05001JEUYFFUH00004FUH00`00
FUIJEP04001EOol002moo`04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000GOol0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00FUH03`00FGoo000_Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUH00002000MOol00`00FUIJEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP02001XOol002moo`04001JEUYF0006FUH01000FUIJEUYF
1@008Goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00003Woo1000F7oo000_Ool2
0002FUH01000FUIJEUYF1P00:7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P002Woo1@000UYF00@005YF0000
05Ioo`00<7oo1`00<7oo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01Goo100000=JEP00FUH015YF
00@005YFFUH005Ioo`00JGoo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`@000EJEP03001JEUYF00=JEP04
001JEUYF001FOol006aoo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo001_Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo001c
Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP080002FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH<001DOol007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF
00AJEP`000MJEP03001JEUYF00IJEP03001JEP0000D00003FUH005YF00=JEP04001JEUYF001DOol0
085ooaX000Ioo`800003FUH005YF00QJEP03001JEUYF00EJEP<0009oo`8000=JEP03001JEUYF00=J
EP8005Eoo`00WWoo0`0015YF00<005YFFUH01eYF00<005YFFUH010000Woo0`001UYF00@005YFFUIJ
EP8005Ioo`00W7oo0P001eYF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF0000
05Qoo`00VWoo0`0025YF00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0P00FWoo002H
Ool20003FUH00`00FUIJEP06FUH00`00FUH000020005Ool30007FUH00`00FUIJEP02FUH2001LOol0
09Ioo`8000EJEP03001JEUYF00EJEP<000Eoo`<00003FUH005YF00QJEP04001JEP00001NOol009Ao
o`<000IJEP03001JEUYF00=JEP8000Eoo`<000EJEP03001JEUYF00EJEP<0061oo`00TWoo0P000UYF
00<005YFFUH01EYF00<005YF00000P0017oo0`0025YF00<005YFFUH00eYF0P00Hgoo002AOol00`00
FUIJEP03FUH00`00FUIJEP03FUH30003Ool400000eYF001JEP09FUH00`00FUH00002001UOol0091o
o`8000EJEP03001JEP0000<0009oo`@000IJEP03001JEUYF00IJEP<006Qoo`00Sgoo00@005YFFUH0
00AJEP80009oo`@00003FUH005YF00MJEP03001JEUYF00=JEP<006]oo`00Sgoo00@005YFFUH000=J
EPD000IJEP03001JEUYF00IJEP03001JEP00008006ioo`00T7oo00<005YFFUH00`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF0`00LGoo002@Ool00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00
FUIJEP04001dOol0095oo`04FUH005YF0005FUH00`00FUIJEP04FUH4001hOol0095oo`05001JEUYF
FUH00004FUH00`00FUIJEP04001lOol0095oo``0081oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59635 .73958 m .5929 .68374 L .56178 .6838 L p .707 .577 .707 r
F P
0 g
s
.5929 .68374 m .59635 .73958 L .62813 .73703 L p .707 .577 .707 r
F P
0 g
s
.62813 .73703 m .62468 .68119 L .5929 .68374 L p .707 .577 .707 r
F P
0 g
s
.62468 .68119 m .62813 .73703 L .65746 .73224 L p .707 .577 .707 r
F P
0 g
s
.65746 .73224 m .65401 .6764 L .62468 .68119 L p .707 .577 .707 r
F P
0 g
s
.56523 .73964 m .56178 .6838 L .53439 .68138 L p .707 .577 .707 r
F P
0 g
s
.56178 .6838 m .56523 .73964 L .59635 .73958 L p .707 .577 .707 r
F P
0 g
s
.65401 .6764 m .65746 .73224 L .68149 .72569 L p .707 .577 .707 r
F P
0 g
s
.68149 .72569 m .67804 .66985 L .65401 .6764 L p .707 .577 .707 r
F P
0 g
s
.53439 .68138 m .53784 .73721 L .56523 .73964 L p .707 .577 .707 r
F P
0 g
s
.60021 .80373 m .59345 .76662 L .56281 .77053 L p .707 .577 .707 r
F P
0 g
s
.59345 .76662 m .60021 .80373 L .63157 .79771 L p .707 .577 .707 r
F P
0 g
s
.63157 .79771 m .62481 .7606 L .59345 .76662 L p .707 .577 .707 r
F P
0 g
s
.53784 .73721 m .53439 .68138 L .51339 .6767 L p .707 .577 .707 r
F P
0 g
s
.62481 .7606 m .63157 .79771 L .66057 .79017 L p .707 .577 .707 r
F P
0 g
s
.66057 .79017 m .65382 .75306 L .62481 .7606 L p .707 .577 .707 r
F P
0 g
s
.56281 .77053 m .56957 .80764 L .60021 .80373 L p .707 .577 .707 r
F P
0 g
s
.56957 .80764 m .56281 .77053 L .53588 .77194 L p .707 .577 .707 r
F P
0 g
s
.67804 .66985 m .68149 .72569 L .69785 .71801 L p .707 .577 .707 r
F P
0 g
s
.69785 .71801 m .6944 .66217 L .67804 .66985 L p .707 .577 .707 r
F P
0 g
s
.65382 .75306 m .66057 .79017 L .68438 .78185 L p .707 .577 .707 r
F P
0 g
s
.68438 .78185 m .67763 .74474 L .65382 .75306 L p .707 .577 .707 r
F P
0 g
s
.51339 .6767 m .51684 .73253 L .53784 .73721 L p .707 .577 .707 r
F P
0 g
s
.53588 .77194 m .54264 .80905 L .56957 .80764 L p .707 .577 .707 r
F P
0 g
s
.59875 .859 m .59526 .84046 L .56465 .84457 L p .707 .577 .707 r
F P
0 g
s
.59526 .84046 m .59875 .859 L .63008 .8528 L p .707 .577 .707 r
F P
0 g
s
.63008 .8528 m .62658 .83426 L .59526 .84046 L p .707 .577 .707 r
F P
0 g
s
.62658 .83426 m .63008 .8528 L .65905 .84512 L p .707 .577 .707 r
F P
0 g
s
.65905 .84512 m .65556 .82658 L .62658 .83426 L p .707 .577 .707 r
F P
0 g
s
.56465 .84457 m .56815 .86311 L .59875 .859 L p .707 .577 .707 r
F P
0 g
s
.51684 .73253 m .51339 .6767 L .50084 .67022 L p .707 .577 .707 r
F P
0 g
s
.54264 .80905 m .53588 .77194 L .5153 .77073 L p .707 .577 .707 r
F P
0 g
s
.56815 .86311 m .56465 .84457 L .53776 .84619 L p .707 .577 .707 r
F P
0 g
s
.53776 .84619 m .54125 .86473 L .56815 .86311 L p .707 .577 .707 r
F P
0 g
s
.67763 .74474 m .68438 .78185 L .70067 .77356 L p .707 .577 .707 r
F P
0 g
s
.70067 .77356 m .69391 .73645 L .67763 .74474 L p .707 .577 .707 r
F P
0 g
s
.65556 .82658 m .65905 .84512 L .68284 .83671 L p .707 .577 .707 r
F P
0 g
s
.68284 .83671 m .67935 .81816 L .65556 .82658 L p .707 .577 .707 r
F P
0 g
s
.5153 .77073 m .52206 .80784 L .54264 .80905 L p .707 .577 .707 r
F P
0 g
s
.6944 .66217 m .69785 .71801 L .70494 .70996 L p .707 .577 .707 r
F P
0 g
s
.70494 .70996 m .70149 .65412 L .6944 .66217 L p .707 .577 .707 r
F P
0 g
s
.50084 .67022 m .50429 .72606 L .51684 .73253 L p .707 .577 .707 r
F P
0 g
s
.54125 .86473 m .53776 .84619 L .51722 .84516 L p .707 .577 .707 r
F P
0 g
s
.51722 .84516 m .52071 .8637 L .54125 .86473 L p .707 .577 .707 r
F P
0 g
s
.52206 .80784 m .5153 .77073 L .50309 .76701 L p .707 .577 .707 r
F P
0 g
s
.67935 .81816 m .68284 .83671 L .69912 .82839 L p .707 .577 .707 r
F P
0 g
s
.69912 .82839 m .69563 .80984 L .67935 .81816 L p .707 .577 .707 r
F P
0 g
s
.50429 .72606 m .50084 .67022 L .49797 .66258 L p .707 .577 .707 r
F P
0 g
s
.50309 .76701 m .50985 .80412 L .52206 .80784 L p .707 .577 .707 r
F P
0 g
s
.69391 .73645 m .70067 .77356 L .70783 .76612 L p .707 .577 .707 r
F P
0 g
s
.70783 .76612 m .70108 .72901 L .69391 .73645 L p .707 .577 .707 r
F P
0 g
s
.49797 .66258 m .50142 .71842 L .50429 .72606 L p .707 .577 .707 r
F P
0 g
s
.70149 .65412 m .70494 .70996 L .70207 .70232 L p .707 .577 .707 r
F P
0 g
s
.70207 .70232 m .69862 .64648 L .70149 .65412 L p .707 .577 .707 r
F P
0 g
s
.52071 .8637 m .51722 .84516 L .50503 .84158 L p .707 .577 .707 r
F P
0 g
s
.50503 .84158 m .50852 .86012 L .52071 .8637 L p .707 .577 .707 r
F P
0 g
s
.69563 .80984 m .69912 .82839 L .7063 .82098 L p .707 .577 .707 r
F P
0 g
s
.7063 .82098 m .7028 .80243 L .69563 .80984 L p .707 .577 .707 r
F P
0 g
s
.50985 .80412 m .50309 .76701 L .50044 .76113 L p .707 .577 .707 r
F P
0 g
s
.48265 .82174 m .49143 .32088 L .44743 .31742 L p .707 .577 .707 r
F P
0 g
s
.50142 .71842 m .49797 .66258 L .50506 .65453 L p .707 .577 .707 r
F P
0 g
s
.50044 .76113 m .50719 .79824 L .50985 .80412 L p .707 .577 .707 r
F P
0 g
s
.50506 .65453 m .50851 .71036 L .50142 .71842 L p .707 .577 .707 r
F P
0 g
s
.50719 .79824 m .50044 .76113 L .5076 .75369 L p .707 .577 .707 r
F P
0 g
s
.50851 .71036 m .50506 .65453 L .52142 .64685 L p .707 .577 .707 r
F P
0 g
s
.5076 .75369 m .51436 .7908 L .50719 .79824 L p .707 .577 .707 r
F P
0 g
s
.52142 .64685 m .52487 .70269 L .50851 .71036 L p .707 .577 .707 r
F P
0 g
s
.51436 .7908 m .5076 .75369 L .52389 .7454 L p .707 .577 .707 r
F P
0 g
s
.52389 .7454 m .53064 .78251 L .51436 .7908 L p .707 .577 .707 r
F P
0 g
s
.51306 .84693 m .50957 .82839 L .52585 .82007 L p .707 .577 .707 r
F P
0 g
s
.52585 .82007 m .52934 .83861 L .51306 .84693 L p .707 .577 .707 r
F P
0 g
s
.52934 .83861 m .52585 .82007 L .54964 .81165 L p .707 .577 .707 r
F P
0 g
s
.49143 .32088 m .48265 .82174 L .52759 .82134 L p .707 .577 .707 r
F P
0 g
s
.52487 .70269 m .52142 .64685 L .54545 .6403 L p .707 .577 .707 r
F P
0 g
s
.54545 .6403 m .5489 .69613 L .52487 .70269 L p .707 .577 .707 r
F P
0 g
s
.53064 .78251 m .52389 .7454 L .5477 .73708 L p .707 .577 .707 r
F P
0 g
s
.52759 .82134 m .53637 .32048 L .49143 .32088 L p .707 .577 .707 r
F P
0 g
s
.5489 .69613 m .54545 .6403 L .57478 .63551 L p .707 .577 .707 r
F P
0 g
s
.57478 .63551 m .57823 .69135 L .5489 .69613 L p .707 .577 .707 r
F P
0 g
s
.5477 .73708 m .55445 .77419 L .53064 .78251 L p .707 .577 .707 r
F P
0 g
s
.55445 .77419 m .5477 .73708 L .5767 .72954 L p .707 .577 .707 r
F P
0 g
s
.54964 .81165 m .55313 .8302 L .52934 .83861 L p .707 .577 .707 r
F P
0 g
s
.5767 .72954 m .58346 .76665 L .55445 .77419 L p .707 .577 .707 r
F P
0 g
s
.55313 .8302 m .54964 .81165 L .57861 .80397 L p .707 .577 .707 r
F P
0 g
s
.57861 .80397 m .58211 .82252 L .55313 .8302 L p .707 .577 .707 r
F P
0 g
s
.53637 .32048 m .52759 .82134 L .56907 .81713 L p .707 .577 .707 r
F P
0 g
s
.56907 .81713 m .57784 .31627 L .53637 .32048 L p .707 .577 .707 r
F P
0 g
s
.70108 .72901 m .70783 .76612 L .70518 .76025 L p .707 .577 .707 r
F P
0 g
s
.70518 .76025 m .69843 .72314 L .70108 .72901 L p .707 .577 .707 r
F P
0 g
s
.43865 .81828 m .44743 .31742 L .40867 .31044 L p .707 .577 .707 r
F P
0 g
s
.44743 .31742 m .43865 .81828 L .48265 .82174 L p .707 .577 .707 r
F P
0 g
s
.69862 .64648 m .70207 .70232 L .68952 .69584 L p .707 .577 .707 r
F P
0 g
s
.68952 .69584 m .68607 .64 L .69862 .64648 L p .707 .577 .707 r
F P
0 g
s
.50852 .86012 m .50503 .84158 L .50239 .8358 L p .707 .577 .707 r
F P
0 g
s
.57823 .69135 m .57478 .63551 L .60657 .63296 L p .707 .577 .707 r
F P
0 g
s
.60657 .63296 m .61002 .6888 L .57823 .69135 L p .707 .577 .707 r
F P
0 g
s
.58346 .76665 m .5767 .72954 L .60806 .72353 L p .707 .577 .707 r
F P
0 g
s
.60806 .72353 m .61482 .76064 L .58346 .76665 L p .707 .577 .707 r
F P
0 g
s
.58211 .82252 m .57861 .80397 L .60994 .79777 L p .707 .577 .707 r
F P
0 g
s
.60994 .79777 m .61343 .81632 L .58211 .82252 L p .707 .577 .707 r
F P
0 g
s
.57784 .31627 m .56907 .81713 L .60302 .80951 L p .707 .577 .707 r
F P
0 g
s
.60302 .80951 m .6118 .30865 L .57784 .31627 L p .707 .577 .707 r
F P
0 g
s
.50239 .8358 m .50589 .85434 L .50852 .86012 L p .707 .577 .707 r
F P
0 g
s
.7028 .80243 m .7063 .82098 L .70366 .8152 L p .707 .577 .707 r
F P
0 g
s
.70366 .8152 m .70017 .79665 L .7028 .80243 L p .707 .577 .707 r
F P
0 g
s
.39989 .8113 m .40867 .31044 L .37895 .30062 L p .707 .577 .707 r
F P
0 g
s
.40867 .31044 m .39989 .8113 L .43865 .81828 L p .707 .577 .707 r
F P
0 g
s
.25334 .71861 m .24989 .66278 L .21878 .66284 L p .707 .577 .707 r
F P
0 g
s
.24989 .66278 m .25334 .71861 L .28512 .71606 L p .707 .577 .707 r
F P
0 g
s
.28512 .71606 m .28167 .66023 L .24989 .66278 L p .707 .577 .707 r
F P
0 g
s
.28167 .66023 m .28512 .71606 L .31446 .71128 L p .707 .577 .707 r
F P
0 g
s
.31446 .71128 m .31101 .65544 L .28167 .66023 L p .707 .577 .707 r
F P
0 g
s
.69843 .72314 m .70518 .76025 L .69297 .75652 L p .707 .577 .707 r
F P
0 g
s
.69297 .75652 m .68621 .71941 L .69843 .72314 L p .707 .577 .707 r
F P
0 g
s
.22222 .71868 m .21878 .66284 L .19138 .66041 L p .707 .577 .707 r
F P
0 g
s
.21878 .66284 m .22222 .71868 L .25334 .71861 L p .707 .577 .707 r
F P
0 g
s
.68607 .64 m .68952 .69584 L .66852 .69116 L p .707 .577 .707 r
F P
0 g
s
.66852 .69116 m .66507 .63532 L .68607 .64 L p .707 .577 .707 r
F P
0 g
s
.31101 .65544 m .31446 .71128 L .33848 .70472 L p .707 .577 .707 r
F P
0 g
s
.33848 .70472 m .33503 .64889 L .31101 .65544 L p .707 .577 .707 r
F P
0 g
s
.63768 .63289 m .64113 .68873 L .61002 .6888 L p .707 .577 .707 r
F P
0 g
s
.61002 .6888 m .60657 .63296 L .63768 .63289 L p .707 .577 .707 r
F P
0 g
s
.6387 .71962 m .64546 .75673 L .61482 .76064 L p .707 .577 .707 r
F P
0 g
s
.61482 .76064 m .60806 .72353 L .6387 .71962 L p .707 .577 .707 r
F P
0 g
s
.61343 .81632 m .60994 .79777 L .64054 .79366 L p .707 .577 .707 r
F P
0 g
s
.6118 .30865 m .60302 .80951 L .62613 .79924 L p .707 .577 .707 r
F P
0 g
s
.62613 .79924 m .6349 .29837 L .6118 .30865 L p .707 .577 .707 r
F P
0 g
s
.50589 .85434 m .50239 .8358 L .50957 .82839 L p .707 .577 .707 r
F P
0 g
s
.2572 .76787 m .25045 .73076 L .2198 .73467 L p .707 .577 .707 r
F P
0 g
s
.25045 .73076 m .2572 .76787 L .28856 .76186 L p .707 .577 .707 r
F P
0 g
s
.28856 .76186 m .2818 .72475 L .25045 .73076 L p .707 .577 .707 r
F P
0 g
s
.2818 .72475 m .28856 .76186 L .31756 .75432 L p .707 .577 .707 r
F P
0 g
s
.31756 .75432 m .31081 .71721 L .2818 .72475 L p .707 .577 .707 r
F P
0 g
s
.50957 .82839 m .51306 .84693 L .50589 .85434 L p .707 .577 .707 r
F P
0 g
s
.19138 .66041 m .19483 .71625 L .22222 .71868 L p .707 .577 .707 r
F P
0 g
s
.19483 .71625 m .19138 .66041 L .17038 .65573 L p .707 .577 .707 r
F P
0 g
s
.70017 .79665 m .70366 .8152 L .69147 .81162 L p .707 .577 .707 r
F P
0 g
s
.69147 .81162 m .68798 .79307 L .70017 .79665 L p .707 .577 .707 r
F P
0 g
s
.2198 .73467 m .22656 .77178 L .2572 .76787 L p .707 .577 .707 r
F P
0 g
s
.22656 .77178 m .2198 .73467 L .19287 .73609 L p .707 .577 .707 r
F P
0 g
s
.37017 .80149 m .37895 .30062 L .36118 .28893 L p .707 .577 .707 r
F P
0 g
s
.37895 .30062 m .37017 .80149 L .39989 .8113 L p .707 .577 .707 r
F P
0 g
s
.25574 .79587 m .25225 .77733 L .22164 .78144 L p .707 .577 .707 r
F P
0 g
s
.25225 .77733 m .25574 .79587 L .28707 .78967 L p .707 .577 .707 r
F P
0 g
s
.28707 .78967 m .28357 .77113 L .25225 .77733 L p .707 .577 .707 r
F P
0 g
s
.31081 .71721 m .31756 .75432 L .34137 .746 L p .707 .577 .707 r
F P
0 g
s
.34137 .746 m .33462 .70889 L .31081 .71721 L p .707 .577 .707 r
F P
0 g
s
.28357 .77113 m .28707 .78967 L .31604 .78199 L p .707 .577 .707 r
F P
0 g
s
.31604 .78199 m .31255 .76344 L .28357 .77113 L p .707 .577 .707 r
F P
0 g
s
.33503 .64889 m .33848 .70472 L .35484 .69705 L p .707 .577 .707 r
F P
0 g
s
.35484 .69705 m .35139 .64121 L .33503 .64889 L p .707 .577 .707 r
F P
0 g
s
.19287 .73609 m .19963 .7732 L .22656 .77178 L p .707 .577 .707 r
F P
0 g
s
.22164 .78144 m .22514 .79998 L .25574 .79587 L p .707 .577 .707 r
F P
0 g
s
.68621 .71941 m .69297 .75652 L .67239 .75531 L p .707 .577 .707 r
F P
0 g
s
.67239 .75531 m .66563 .7182 L .68621 .71941 L p .707 .577 .707 r
F P
0 g
s
.66507 .63532 m .66852 .69116 L .64113 .68873 L p .707 .577 .707 r
F P
0 g
s
.64113 .68873 m .63768 .63289 L .66507 .63532 L p .707 .577 .707 r
F P
0 g
s
.17038 .65573 m .17383 .71157 L .19483 .71625 L p .707 .577 .707 r
F P
0 g
s
.22514 .79998 m .22164 .78144 L .19475 .78306 L p .707 .577 .707 r
F P
0 g
s
.19475 .78306 m .19825 .8016 L .22514 .79998 L p .707 .577 .707 r
F P
0 g
s
.31255 .76344 m .31604 .78199 L .33984 .77357 L p .707 .577 .707 r
F P
0 g
s
.33984 .77357 m .33634 .75503 L .31255 .76344 L p .707 .577 .707 r
F P
0 g
s
.19963 .7732 m .19287 .73609 L .1723 .73488 L p .707 .577 .707 r
F P
0 g
s
.17383 .71157 m .17038 .65573 L .15783 .64926 L p .707 .577 .707 r
F P
0 g
s
.33462 .70889 m .34137 .746 L .35766 .73771 L p .707 .577 .707 r
F P
0 g
s
.35766 .73771 m .3509 .7006 L .33462 .70889 L p .707 .577 .707 r
F P
0 g
s
.1723 .73488 m .17905 .77199 L .19963 .7732 L p .707 .577 .707 r
F P
0 g
s
.6349 .29837 m .62613 .79924 L .63613 .7873 L p .707 .577 .707 r
F P
0 g
s
.63613 .7873 m .64491 .28644 L .6349 .29837 L p .707 .577 .707 r
F P
0 g
s
.68798 .79307 m .69147 .81162 L .67093 .81059 L p .707 .577 .707 r
F P
0 g
s
.67093 .81059 m .66744 .79204 L .68798 .79307 L p .707 .577 .707 r
F P
0 g
s
.19825 .8016 m .19475 .78306 L .17421 .78203 L p .707 .577 .707 r
F P
0 g
s
.66563 .7182 m .67239 .75531 L .64546 .75673 L p .707 .577 .707 r
F P
0 g
s
.64546 .75673 m .6387 .71962 L .66563 .7182 L p .707 .577 .707 r
F P
0 g
s
.17421 .78203 m .1777 .80057 L .19825 .8016 L p .707 .577 .707 r
F P
0 g
s
.35139 .64121 m .35484 .69705 L .36162 .68934 L p .707 .577 .707 r
F P
0 g
s
.36161 .68754 m .35139 .64121 L .36162 .68934 L .707 .577 .707 r
F
.36193 .68899 m .35848 .63316 L .35139 .64121 L p F P
0 g
s
.33634 .75503 m .33984 .77357 L .35612 .76525 L p .707 .577 .707 r
F P
0 g
s
.35612 .76525 m .35262 .74671 L .33634 .75503 L p .707 .577 .707 r
F P
0 g
s
.3509 .7006 m .35766 .73771 L .36203 .73317 L p .707 .577 .707 r
F P
0 g
s
.36203 .73317 m .36482 .73027 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36165 .7235 m .3509 .7006 L .36203 .73317 L .707 .577 .707 r
F
.35464 .54447 m .35951 .38388 L .35709 .27652 L F
.35807 .69316 m .3509 .7006 L p .36165 .7235 L F P
0 g
s
.36482 .73027 m .36112 .7099 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36112 .7099 m .35807 .69316 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.35262 .74671 m .35612 .76525 L .36329 .75784 L p .707 .577 .707 r
F P
0 g
s
.36329 .75784 m .35979 .7393 L .35262 .74671 L p .707 .577 .707 r
F P
0 g
s
.35561 .62552 m .35906 .68135 L .34652 .67488 L p .707 .577 .707 r
F P
0 g
s
.34652 .67488 m .34307 .61904 L .35561 .62552 L p .707 .577 .707 r
F P
0 g
s
.35542 .68728 m .3582 .70256 L p .34996 .72067 L .707 .577 .707 r
F P
0 g
s
.3582 .70256 m .36217 .72439 L .35677 .72275 L p .707 .577 .707 r
F P
0 g
s
.35677 .72275 m .34996 .72067 L p .3582 .70256 L .707 .577 .707 r
F P
0 g
s
.34996 .72067 m .3432 .68356 L .35542 .68728 L p .707 .577 .707 r
F P
0 g
s
.35716 .73352 m .36065 .75206 L .34846 .74848 L p .707 .577 .707 r
F P
0 g
s
.34846 .74848 m .34497 .72994 L .35716 .73352 L p .707 .577 .707 r
F P
0 g
s
.3432 .68356 m .34996 .72067 L .32938 .71946 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35211 .78892 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35211 .78892 m .3524 .7898 L p .35245 .78406 L .707 .577 .707 r
F P
0 g
s
.35245 .78406 m .35464 .54447 L .35211 .78892 L .707 .577 .707 r
F
.35709 .27652 m .35309 .50482 L p .35464 .54447 L F P
0 g
s
.35309 .50482 m .34831 .77738 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.3524 .7898 m .35606 .58077 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35606 .58077 m .35951 .38388 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35951 .38388 m .36118 .28893 L .35881 .28173 L p .707 .577 .707 r
F P
0 g
s
.35881 .28173 m .35709 .27652 L p .35951 .38388 L .707 .577 .707 r
F P
0 g
s
.36162 .68934 m .36193 .68899 L p .36161 .68754 L .707 .577 .707 r
F P
0 g
s
.15783 .64926 m .16128 .70509 L .17383 .71157 L p .707 .577 .707 r
F P
0 g
s
.17905 .77199 m .1723 .73488 L .16008 .73115 L p .707 .577 .707 r
F P
0 g
s
.35848 .63316 m .36193 .68899 L .35906 .68135 L p .707 .577 .707 r
F P
0 g
s
.35906 .68135 m .35561 .62552 L .35848 .63316 L p .707 .577 .707 r
F P
0 g
s
.35807 .69316 m .36482 .73027 L .36217 .72439 L p .707 .577 .707 r
F P
0 g
s
.36217 .72439 m .35542 .68728 L .35807 .69316 L p .707 .577 .707 r
F P
0 g
s
.35979 .7393 m .36329 .75784 L .36065 .75206 L p .707 .577 .707 r
F P
0 g
s
.36065 .75206 m .35716 .73352 L .35979 .7393 L p .707 .577 .707 r
F P
0 g
s
.36118 .28893 m .3524 .7898 L .37017 .80149 L p .707 .577 .707 r
F P
0 g
s
.16128 .70509 m .15783 .64926 L .15496 .64162 L p .707 .577 .707 r
F P
0 g
s
.16008 .73115 m .16684 .76826 L .17905 .77199 L p .707 .577 .707 r
F P
0 g
s
.66744 .79204 m .67093 .81059 L .64404 .8122 L p .707 .577 .707 r
F P
0 g
s
.64404 .8122 m .64054 .79366 L .66744 .79204 L p .707 .577 .707 r
F P
0 g
s
.1777 .80057 m .17421 .78203 L .16202 .77845 L p .707 .577 .707 r
F P
0 g
s
.16202 .77845 m .16551 .79699 L .1777 .80057 L p .707 .577 .707 r
F P
0 g
s
.15496 .64162 m .15841 .69745 L .16128 .70509 L p .707 .577 .707 r
F P
0 g
s
.64491 .28644 m .63613 .7873 L .63204 .77489 L p .707 .577 .707 r
F P
0 g
s
.63204 .77489 m .64082 .27402 L .64491 .28644 L p .707 .577 .707 r
F P
0 g
s
.64054 .79366 m .64404 .8122 L .61343 .81632 L p .707 .577 .707 r
F P
0 g
s
.16684 .76826 m .16008 .73115 L .15743 .72528 L p .707 .577 .707 r
F P
0 g
s
.15743 .72528 m .16418 .76239 L .16684 .76826 L p .707 .577 .707 r
F P
0 g
s
.15841 .69745 m .15496 .64162 L .16205 .63356 L p .707 .577 .707 r
F P
0 g
s
.16551 .79699 m .16202 .77845 L .15938 .77267 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35709 .27652 L .36709 .26458 L p .707 .577 .707 r
F P
0 g
s
.15938 .77267 m .16288 .79121 L .16551 .79699 L p .707 .577 .707 r
F P
0 g
s
.16205 .63356 m .1655 .6894 L .15841 .69745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16418 .76239 m .15743 .72528 L .16459 .71784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16459 .71784 m .17135 .75495 L .16418 .76239 L p .707 .577 .707 r
F P
0 g
s
.1655 .6894 m .16205 .63356 L .17841 .62588 L p .707 .577 .707 r
F P
0 g
s
.64082 .27402 m .63204 .77489 L .61427 .7632 L p .707 .577 .707 r
F P
0 g
s
.61427 .7632 m .62305 .26233 L .64082 .27402 L p .707 .577 .707 r
F P
0 g
s
.16288 .79121 m .15938 .77267 L .16656 .76525 L p .707 .577 .707 r
F P
0 g
s
.16656 .76525 m .17005 .7838 L .16288 .79121 L p .707 .577 .707 r
F P
0 g
s
.34307 .61904 m .34652 .67488 L .32551 .6702 L p .707 .577 .707 r
F P
0 g
s
.32551 .6702 m .32206 .61436 L .34307 .61904 L p .707 .577 .707 r
F P
0 g
s
.17841 .62588 m .18186 .68172 L .1655 .6894 L p .707 .577 .707 r
F P
0 g
s
.35832 .76545 m .36709 .26458 L .3902 .25431 L p .707 .577 .707 r
F P
0 g
s
.36709 .26458 m .35832 .76545 L .34831 .77738 L p .707 .577 .707 r
F P
0 g
s
.17135 .75495 m .16459 .71784 L .18088 .70955 L p .707 .577 .707 r
F P
0 g
s
.18186 .68172 m .17841 .62588 L .20244 .61933 L p .707 .577 .707 r
F P
0 g
s
.18088 .70955 m .18764 .74666 L .17135 .75495 L p .707 .577 .707 r
F P
0 g
s
.32938 .71946 m .32262 .68235 L .3432 .68356 L p .707 .577 .707 r
F P
0 g
s
.17005 .7838 m .16656 .76525 L .18284 .75693 L p .707 .577 .707 r
F P
0 g
s
.32206 .61436 m .32551 .6702 L .29812 .66777 L p .707 .577 .707 r
F P
0 g
s
.29812 .66777 m .29467 .61193 L .32206 .61436 L p .707 .577 .707 r
F P
0 g
s
.18284 .75693 m .18633 .77548 L .17005 .7838 L p .707 .577 .707 r
F P
0 g
s
.20244 .61933 m .20589 .67517 L .18186 .68172 L p .707 .577 .707 r
F P
0 g
s
.62305 .26233 m .61427 .7632 L .58455 .75338 L p .707 .577 .707 r
F P
0 g
s
.58455 .75338 m .59333 .25252 L .62305 .26233 L p .707 .577 .707 r
F P
0 g
s
.34497 .72994 m .34846 .74848 L .32792 .74745 L p .707 .577 .707 r
F P
0 g
s
.32792 .74745 m .32443 .72891 L .34497 .72994 L p .707 .577 .707 r
F P
0 g
s
.20589 .67517 m .20244 .61933 L .23178 .61455 L p .707 .577 .707 r
F P
0 g
s
.18764 .74666 m .18088 .70955 L .20469 .70123 L p .707 .577 .707 r
F P
0 g
s
.29467 .61193 m .29812 .66777 L .26701 .66783 L p .707 .577 .707 r
F P
0 g
s
.26701 .66783 m .26356 .612 L .29467 .61193 L p .707 .577 .707 r
F P
0 g
s
.32262 .68235 m .32938 .71946 L .30245 .72087 L p .707 .577 .707 r
F P
0 g
s
.30245 .72087 m .29569 .68376 L .32262 .68235 L p .707 .577 .707 r
F P
0 g
s
.3902 .25431 m .38142 .75517 L .35832 .76545 L p .707 .577 .707 r
F P
0 g
s
.38142 .75517 m .3902 .25431 L .42415 .24669 L p .707 .577 .707 r
F P
0 g
s
.20469 .70123 m .21144 .73834 L .18764 .74666 L p .707 .577 .707 r
F P
0 g
s
.73355 .64754 m .7301 .5917 L .69899 .59177 L p .707 .577 .707 r
F P
0 g
s
.7301 .5917 m .73355 .64754 L .76533 .64499 L p .707 .577 .707 r
F P
0 g
s
.76533 .64499 m .76188 .58915 L .7301 .5917 L p .707 .577 .707 r
F P
0 g
s
.23522 .67038 m .23178 .61455 L .26356 .612 L p .707 .577 .707 r
F P
0 g
s
.23178 .61455 m .23522 .67038 L .20589 .67517 L p .707 .577 .707 r
F P
0 g
s
.76188 .58915 m .76533 .64499 L .79467 .6402 L p .707 .577 .707 r
F P
0 g
s
.79467 .6402 m .79122 .58437 L .76188 .58915 L p .707 .577 .707 r
F P
0 g
s
.26356 .612 m .26701 .66783 L .23522 .67038 L p .707 .577 .707 r
F P
0 g
s
.18633 .77548 m .18284 .75693 L .20663 .74852 L p .707 .577 .707 r
F P
0 g
s
.70244 .6476 m .69899 .59177 L .67159 .58934 L p .707 .577 .707 r
F P
0 g
s
.69899 .59177 m .70244 .6476 L .73355 .64754 L p .707 .577 .707 r
F P
0 g
s
.20663 .74852 m .21012 .76707 L .18633 .77548 L p .707 .577 .707 r
F P
0 g
s
.32443 .72891 m .32792 .74745 L .30103 .74907 L p .707 .577 .707 r
F P
0 g
s
.30103 .74907 m .29754 .73053 L .32443 .72891 L p .707 .577 .707 r
F P
0 g
s
.21144 .73834 m .20469 .70123 L .23369 .69369 L p .707 .577 .707 r
F P
0 g
s
.79122 .58437 m .79467 .6402 L .81869 .63365 L p .707 .577 .707 r
F P
0 g
s
.81869 .63365 m .81524 .57781 L .79122 .58437 L p .707 .577 .707 r
F P
0 g
s
.29569 .68376 m .30245 .72087 L .27181 .72478 L p .707 .577 .707 r
F P
0 g
s
.27181 .72478 m .26505 .68767 L .29569 .68376 L p .707 .577 .707 r
F P
0 g
s
.59333 .25252 m .58455 .75338 L .54579 .74641 L p .707 .577 .707 r
F P
0 g
s
.54579 .74641 m .55457 .24554 L .59333 .25252 L p .707 .577 .707 r
F P
0 g
s
.23369 .69369 m .24045 .7308 L .21144 .73834 L p .707 .577 .707 r
F P
0 g
s
.67159 .58934 m .67504 .64518 L .70244 .6476 L p .707 .577 .707 r
F P
0 g
s
.24045 .7308 m .23369 .69369 L .26505 .68767 L p .707 .577 .707 r
F P
0 g
s
.73741 .71169 m .73066 .67458 L .70002 .67849 L p .707 .577 .707 r
F P
0 g
s
.73066 .67458 m .73741 .71169 L .76877 .70567 L p .707 .577 .707 r
F P
0 g
s
.76877 .70567 m .76202 .66856 L .73066 .67458 L p .707 .577 .707 r
F P
0 g
s
.67504 .64518 m .67159 .58934 L .65059 .58466 L p .707 .577 .707 r
F P
0 g
s
.21012 .76707 m .20663 .74852 L .2356 .74084 L p .707 .577 .707 r
F P
0 g
s
.26505 .68767 m .27181 .72478 L .24045 .7308 L p .707 .577 .707 r
F P
0 g
s
.76202 .66856 m .76877 .70567 L .79778 .69813 L p .707 .577 .707 r
F P
0 g
s
.79778 .69813 m .79102 .66102 L .76202 .66856 L p .707 .577 .707 r
F P
0 g
s
.2356 .74084 m .2391 .75938 L .21012 .76707 L p .707 .577 .707 r
F P
0 g
s
.41538 .74755 m .42415 .24669 L .46563 .24247 L p .707 .577 .707 r
F P
0 g
s
.42415 .24669 m .41538 .74755 L .38142 .75517 L p .707 .577 .707 r
F P
0 g
s
.29754 .73053 m .30103 .74907 L .27042 .75318 L p .707 .577 .707 r
F P
0 g
s
.27042 .75318 m .26693 .73464 L .29754 .73053 L p .707 .577 .707 r
F P
0 g
s
.70002 .67849 m .70677 .7156 L .73741 .71169 L p .707 .577 .707 r
F P
0 g
s
.70677 .7156 m .70002 .67849 L .67309 .67991 L p .707 .577 .707 r
F P
0 g
s
.81524 .57781 m .81869 .63365 L .83505 .62597 L p .707 .577 .707 r
F P
0 g
s
.83505 .62597 m .8316 .57013 L .81524 .57781 L p .707 .577 .707 r
F P
0 g
s
.2391 .75938 m .2356 .74084 L .26693 .73464 L p .707 .577 .707 r
F P
0 g
s
.79102 .66102 m .79778 .69813 L .82159 .68981 L p .707 .577 .707 r
F P
0 g
s
.82159 .68981 m .81483 .6527 L .79102 .66102 L p .707 .577 .707 r
F P
0 g
s
.26693 .73464 m .27042 .75318 L .2391 .75938 L p .707 .577 .707 r
F P
0 g
s
.65059 .58466 m .65404 .64049 L .67504 .64518 L p .707 .577 .707 r
F P
0 g
s
.67309 .67991 m .67984 .71702 L .70677 .7156 L p .707 .577 .707 r
F P
0 g
s
.55457 .24554 m .54579 .74641 L .50179 .74294 L p .707 .577 .707 r
F P
0 g
s
.50179 .74294 m .51057 .24208 L .55457 .24554 L p .707 .577 .707 r
F P
0 g
s
.73596 .76697 m .73246 .74842 L .70186 .75253 L p .707 .577 .707 r
F P
0 g
s
.73246 .74842 m .73596 .76697 L .76728 .76077 L p .707 .577 .707 r
F P
0 g
s
.76728 .76077 m .76379 .74222 L .73246 .74842 L p .707 .577 .707 r
F P
0 g
s
.76379 .74222 m .76728 .76077 L .79626 .75308 L p .707 .577 .707 r
F P
0 g
s
.79626 .75308 m .79276 .73454 L .76379 .74222 L p .707 .577 .707 r
F P
0 g
s
.45685 .74334 m .46563 .24247 L .51057 .24208 L p .707 .577 .707 r
F P
0 g
s
.46563 .24247 m .45685 .74334 L .41538 .74755 L p .707 .577 .707 r
F P
0 g
s
.70186 .75253 m .70535 .77108 L .73596 .76697 L p .707 .577 .707 r
F P
0 g
s
.65404 .64049 m .65059 .58466 L .63804 .57818 L p .707 .577 .707 r
F P
0 g
s
.67984 .71702 m .67309 .67991 L .65251 .67869 L p .707 .577 .707 r
F P
0 g
s
.51057 .24208 m .50179 .74294 L .45685 .74334 L p .707 .577 .707 r
F P
0 g
s
.70535 .77108 m .70186 .75253 L .67496 .75415 L p .707 .577 .707 r
F P
0 g
s
.67496 .75415 m .67846 .7727 L .70535 .77108 L p .707 .577 .707 r
F P
0 g
s
.81483 .6527 m .82159 .68981 L .83787 .68153 L p .707 .577 .707 r
F P
0 g
s
.83787 .68153 m .83112 .64442 L .81483 .6527 L p .707 .577 .707 r
F P
0 g
s
.79276 .73454 m .79626 .75308 L .82005 .74467 L p .707 .577 .707 r
F P
0 g
s
.82005 .74467 m .81656 .72613 L .79276 .73454 L p .707 .577 .707 r
F P
0 g
s
.65251 .67869 m .65926 .7158 L .67984 .71702 L p .707 .577 .707 r
F P
0 g
s
.8316 .57013 m .83505 .62597 L .84215 .61792 L p .707 .577 .707 r
F P
0 g
s
.84215 .61792 m .8387 .56208 L .8316 .57013 L p .707 .577 .707 r
F P
0 g
s
.63804 .57818 m .64149 .63402 L .65404 .64049 L p .707 .577 .707 r
F P
0 g
s
.67846 .7727 m .67496 .75415 L .65442 .75312 L p .707 .577 .707 r
F P
0 g
s
.65442 .75312 m .65791 .77167 L .67846 .7727 L p .707 .577 .707 r
F P
0 g
s
.65926 .7158 m .65251 .67869 L .64029 .67497 L p .707 .577 .707 r
F P
0 g
s
.81656 .72613 m .82005 .74467 L .83633 .73635 L p .707 .577 .707 r
F P
0 g
s
.83633 .73635 m .83284 .71781 L .81656 .72613 L p .707 .577 .707 r
F P
0 g
s
.64149 .63402 m .63804 .57818 L .63517 .57054 L p .707 .577 .707 r
F P
0 g
s
.64029 .67497 m .64705 .71208 L .65926 .7158 L p .707 .577 .707 r
F P
0 g
s
.83112 .64442 m .83787 .68153 L .84504 .67408 L p .707 .577 .707 r
F P
0 g
s
.84504 .67408 m .83828 .63697 L .83112 .64442 L p .707 .577 .707 r
F P
0 g
s
.63517 .57054 m .63862 .62638 L .64149 .63402 L p .707 .577 .707 r
F P
0 g
s
.8387 .56208 m .84215 .61792 L .83928 .61028 L p .707 .577 .707 r
F P
0 g
s
.83928 .61028 m .83583 .55444 L .8387 .56208 L p .707 .577 .707 r
F P
0 g
s
.65791 .77167 m .65442 .75312 L .64223 .74954 L p .707 .577 .707 r
F P
0 g
s
.64223 .74954 m .64573 .76808 L .65791 .77167 L p .707 .577 .707 r
F P
0 g
s
.83284 .71781 m .83633 .73635 L .8435 .72894 L p .707 .577 .707 r
F P
0 g
s
.8435 .72894 m .84001 .71039 L .83284 .71781 L p .707 .577 .707 r
F P
0 g
s
.64705 .71208 m .64029 .67497 L .63764 .6691 L p .707 .577 .707 r
F P
0 g
s
.63862 .62638 m .63517 .57054 L .64227 .56249 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63764 .6691 m .6444 .70621 L .64705 .71208 L p .707 .577 .707 r
F P
0 g
s
.83828 .63697 m .84504 .67408 L .84238 .66821 L p .707 .577 .707 r
F P
0 g
s
.84238 .66821 m .83563 .6311 L .83828 .63697 L p .707 .577 .707 r
F P
0 g
s
.64227 .56249 m .64572 .61833 L .63862 .62638 L p .707 .577 .707 r
F P
0 g
s
.83583 .55444 m .83928 .61028 L .82673 .6038 L p .707 .577 .707 r
F P
0 g
s
.82673 .6038 m .82328 .54796 L .83583 .55444 L p .707 .577 .707 r
F P
0 g
s
.64573 .76808 m .64223 .74954 L .6396 .74376 L p .707 .577 .707 r
F P
0 g
s
.6396 .74376 m .64309 .76231 L .64573 .76808 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84001 .71039 m .8435 .72894 L .84087 .72316 L p .707 .577 .707 r
F P
0 g
s
.84087 .72316 m .83737 .70461 L .84001 .71039 L p .707 .577 .707 r
F P
0 g
s
.6444 .70621 m .63764 .6691 L .64481 .66165 L p .707 .577 .707 r
F P
0 g
s
.39054 .62658 m .38709 .57074 L .35598 .5708 L p .707 .577 .707 r
F P
0 g
s
.38709 .57074 m .39054 .62658 L .42232 .62402 L p .707 .577 .707 r
F P
0 g
s
.42232 .62402 m .41887 .56819 L .38709 .57074 L p .707 .577 .707 r
F P
0 g
s
.64572 .61833 m .64227 .56249 L .65863 .55481 L p .707 .577 .707 r
F P
0 g
s
.41887 .56819 m .42232 .62402 L .45166 .61924 L p .707 .577 .707 r
F P
0 g
s
.45166 .61924 m .44821 .5634 L .41887 .56819 L p .707 .577 .707 r
F P
0 g
s
.64481 .66165 m .65156 .69876 L .6444 .70621 L p .707 .577 .707 r
F P
0 g
s
.83563 .6311 m .84238 .66821 L .83017 .66449 L p .707 .577 .707 r
F P
0 g
s
.83017 .66449 m .82342 .62737 L .83563 .6311 L p .707 .577 .707 r
F P
0 g
s
.35943 .62664 m .35598 .5708 L .32858 .56838 L p .707 .577 .707 r
F P
0 g
s
.35598 .5708 m .35943 .62664 L .39054 .62658 L p .707 .577 .707 r
F P
0 g
s
.82328 .54796 m .82673 .6038 L .80573 .59912 L p .707 .577 .707 r
F P
0 g
s
.80573 .59912 m .80228 .54328 L .82328 .54796 L p .707 .577 .707 r
F P
0 g
s
.44821 .5634 m .45166 .61924 L .47568 .61269 L p .707 .577 .707 r
F P
0 g
s
.47568 .61269 m .47223 .55685 L .44821 .5634 L p .707 .577 .707 r
F P
0 g
s
.65863 .55481 m .66208 .61065 L .64572 .61833 L p .707 .577 .707 r
F P
0 g
s
.64309 .76231 m .6396 .74376 L .64677 .73635 L p .707 .577 .707 r
F P
0 g
s
.3944 .67584 m .38765 .63872 L .35701 .64263 L p .707 .577 .707 r
F P
0 g
s
.38765 .63872 m .3944 .67584 L .42576 .66982 L p .707 .577 .707 r
F P
0 g
s
.42576 .66982 m .41901 .63271 L .38765 .63872 L p .707 .577 .707 r
F P
0 g
s
.41901 .63271 m .42576 .66982 L .45477 .66228 L p .707 .577 .707 r
F P
0 g
s
.45477 .66228 m .44801 .62517 L .41901 .63271 L p .707 .577 .707 r
F P
0 g
s
.64677 .73635 m .65026 .75489 L .64309 .76231 L p .707 .577 .707 r
F P
0 g
s
.32858 .56838 m .33203 .62421 L .35943 .62664 L p .707 .577 .707 r
F P
0 g
s
.33203 .62421 m .32858 .56838 L .30758 .56369 L p .707 .577 .707 r
F P
0 g
s
.83737 .70461 m .84087 .72316 L .82868 .71958 L p .707 .577 .707 r
F P
0 g
s
.82868 .71958 m .82519 .70103 L .83737 .70461 L p .707 .577 .707 r
F P
0 g
s
.35701 .64263 m .36376 .67974 L .3944 .67584 L p .707 .577 .707 r
F P
0 g
s
.66208 .61065 m .65863 .55481 L .68265 .54826 L p .707 .577 .707 r
F P
0 g
s
.36376 .67974 m .35701 .64263 L .33008 .64405 L p .707 .577 .707 r
F P
0 g
s
.65156 .69876 m .64481 .66165 L .66109 .65336 L p .707 .577 .707 r
F P
0 g
s
.39295 .70383 m .38945 .68529 L .35885 .6894 L p .707 .577 .707 r
F P
0 g
s
.38945 .68529 m .39295 .70383 L .42427 .69763 L p .707 .577 .707 r
F P
0 g
s
.42427 .69763 m .42078 .67909 L .38945 .68529 L p .707 .577 .707 r
F P
0 g
s
.44801 .62517 m .45477 .66228 L .47858 .65396 L p .707 .577 .707 r
F P
0 g
s
.47858 .65396 m .47182 .61685 L .44801 .62517 L p .707 .577 .707 r
F P
0 g
s
.42078 .67909 m .42427 .69763 L .45325 .68995 L p .707 .577 .707 r
F P
0 g
s
.45325 .68995 m .44975 .6714 L .42078 .67909 L p .707 .577 .707 r
F P
0 g
s
.47223 .55685 m .47568 .61269 L .49204 .60501 L p .707 .577 .707 r
F P
0 g
s
.49204 .60501 m .48859 .54917 L .47223 .55685 L p .707 .577 .707 r
F P
0 g
s
.33008 .64405 m .33683 .68116 L .36376 .67974 L p .707 .577 .707 r
F P
0 g
s
.66109 .65336 m .66785 .69047 L .65156 .69876 L p .707 .577 .707 r
F P
0 g
s
.35885 .6894 m .36234 .70794 L .39295 .70383 L p .707 .577 .707 r
F P
0 g
s
.82342 .62737 m .83017 .66449 L .80959 .66327 L p .707 .577 .707 r
F P
0 g
s
.80959 .66327 m .80284 .62616 L .82342 .62737 L p .707 .577 .707 r
F P
0 g
s
.80228 .54328 m .80573 .59912 L .77833 .59669 L p .707 .577 .707 r
F P
0 g
s
.77833 .59669 m .77488 .54086 L .80228 .54328 L p .707 .577 .707 r
F P
0 g
s
.30758 .56369 m .31103 .61953 L .33203 .62421 L p .707 .577 .707 r
F P
0 g
s
.36234 .70794 m .35885 .6894 L .33195 .69102 L p .707 .577 .707 r
F P
0 g
s
.68265 .54826 m .6861 .60409 L .66208 .61065 L p .707 .577 .707 r
F P
0 g
s
.33195 .69102 m .33545 .70956 L .36234 .70794 L p .707 .577 .707 r
F P
0 g
s
.44975 .6714 m .45325 .68995 L .47704 .68154 L p .707 .577 .707 r
F P
0 g
s
.47704 .68154 m .47355 .66299 L .44975 .6714 L p .707 .577 .707 r
F P
0 g
s
.33683 .68116 m .33008 .64405 L .3095 .64284 L p .707 .577 .707 r
F P
0 g
s
.6861 .60409 m .68265 .54826 L .71199 .54347 L p .707 .577 .707 r
F P
0 g
s
.65026 .75489 m .64677 .73635 L .66305 .72803 L p .707 .577 .707 r
F P
0 g
s
.31103 .61953 m .30758 .56369 L .29503 .55722 L p .707 .577 .707 r
F P
0 g
s
.66305 .72803 m .66654 .74657 L .65026 .75489 L p .707 .577 .707 r
F P
0 g
s
.47182 .61685 m .47858 .65396 L .49486 .64567 L p .707 .577 .707 r
F P
0 g
s
.49486 .64567 m .48811 .60856 L .47182 .61685 L p .707 .577 .707 r
F P
0 g
s
.3095 .64284 m .31625 .67995 L .33683 .68116 L p .707 .577 .707 r
F P
0 g
s
.66785 .69047 m .66109 .65336 L .6849 .64504 L p .707 .577 .707 r
F P
0 g
s
.77488 .54086 m .77833 .59669 L .74722 .59676 L p .707 .577 .707 r
F P
0 g
s
.74722 .59676 m .74377 .54092 L .77488 .54086 L p .707 .577 .707 r
F P
0 g
s
.82519 .70103 m .82868 .71958 L .80813 .71855 L p .707 .577 .707 r
F P
0 g
s
.80813 .71855 m .80464 .7 L .82519 .70103 L p .707 .577 .707 r
F P
0 g
s
.33545 .70956 m .33195 .69102 L .31141 .68999 L p .707 .577 .707 r
F P
0 g
s
.71544 .59931 m .71199 .54347 L .74377 .54092 L p .707 .577 .707 r
F P
0 g
s
.71199 .54347 m .71544 .59931 L .6861 .60409 L p .707 .577 .707 r
F P
0 g
s
.80284 .62616 m .80959 .66327 L .78266 .66469 L p .707 .577 .707 r
F P
0 g
s
.78266 .66469 m .77591 .62758 L .80284 .62616 L p .707 .577 .707 r
F P
0 g
s
.31141 .68999 m .3149 .70853 L .33545 .70956 L p .707 .577 .707 r
F P
0 g
s
.48859 .54917 m .49204 .60501 L .49914 .59695 L p .707 .577 .707 r
F P
0 g
s
.49914 .59695 m .49569 .54112 L .48859 .54917 L p .707 .577 .707 r
F P
0 g
s
.6849 .64504 m .69166 .68215 L .66785 .69047 L p .707 .577 .707 r
F P
0 g
s
.74377 .54092 m .74722 .59676 L .71544 .59931 L p .707 .577 .707 r
F P
0 g
s
.29503 .55722 m .29848 .61305 L .31103 .61953 L p .707 .577 .707 r
F P
0 g
s
.47355 .66299 m .47704 .68154 L .49332 .67322 L p .707 .577 .707 r
F P
0 g
s
.49332 .67322 m .48983 .65467 L .47355 .66299 L p .707 .577 .707 r
F P
0 g
s
.31625 .67995 m .3095 .64284 L .29728 .63911 L p .707 .577 .707 r
F P
0 g
s
.69166 .68215 m .6849 .64504 L .71391 .6375 L p .707 .577 .707 r
F P
0 g
s
.66654 .74657 m .66305 .72803 L .68684 .71962 L p .707 .577 .707 r
F P
0 g
s
.29848 .61305 m .29503 .55722 L .29216 .54958 L p .707 .577 .707 r
F P
0 g
s
.29728 .63911 m .30404 .67622 L .31625 .67995 L p .707 .577 .707 r
F P
0 g
s
.68684 .71962 m .69034 .73816 L .66654 .74657 L p .707 .577 .707 r
F P
0 g
s
.48811 .60856 m .49486 .64567 L .50203 .63823 L p .707 .577 .707 r
F P
0 g
s
.50203 .63823 m .49527 .60112 L .48811 .60856 L p .707 .577 .707 r
F P
0 g
s
.77591 .62758 m .78266 .66469 L .75202 .6686 L p .707 .577 .707 r
F P
0 g
s
.75202 .6686 m .74527 .63149 L .77591 .62758 L p .707 .577 .707 r
F P
0 g
s
.80464 .7 m .80813 .71855 L .78124 .72017 L p .707 .577 .707 r
F P
0 g
s
.78124 .72017 m .77775 .70162 L .80464 .7 L p .707 .577 .707 r
F P
0 g
s
.71391 .6375 m .72066 .67462 L .69166 .68215 L p .707 .577 .707 r
F P
0 g
s
.3149 .70853 m .31141 .68999 L .29922 .68641 L p .707 .577 .707 r
F P
0 g
s
.72066 .67462 m .71391 .6375 L .74527 .63149 L p .707 .577 .707 r
F P
0 g
s
.29922 .68641 m .30272 .70495 L .3149 .70853 L p .707 .577 .707 r
F P
0 g
s
.74527 .63149 m .75202 .6686 L .72066 .67462 L p .707 .577 .707 r
F P
0 g
s
.48983 .65467 m .49332 .67322 L .50049 .6658 L p .707 .577 .707 r
F P
0 g
s
.50049 .6658 m .497 .64726 L .48983 .65467 L p .707 .577 .707 r
F P
0 g
s
.29216 .54958 m .29561 .60542 L .29848 .61305 L p .707 .577 .707 r
F P
0 g
s
.49569 .54112 m .49914 .59695 L .49627 .58931 L p .707 .577 .707 r
F P
0 g
s
.49627 .58931 m .49282 .53348 L .49569 .54112 L p .707 .577 .707 r
F P
0 g
s
.69034 .73816 m .68684 .71962 L .71582 .71193 L p .707 .577 .707 r
F P
0 g
s
.71582 .71193 m .71931 .73048 L .69034 .73816 L p .707 .577 .707 r
F P
0 g
s
.77775 .70162 m .78124 .72017 L .75064 .72428 L p .707 .577 .707 r
F P
0 g
s
.75064 .72428 m .74714 .70573 L .77775 .70162 L p .707 .577 .707 r
F P
0 g
s
.30404 .67622 m .29728 .63911 L .29463 .63324 L p .707 .577 .707 r
F P
0 g
s
.71931 .73048 m .71582 .71193 L .74714 .70573 L p .707 .577 .707 r
F P
0 g
s
.29463 .63324 m .30139 .67035 L .30404 .67622 L p .707 .577 .707 r
F P
0 g
s
.74714 .70573 m .75064 .72428 L .71931 .73048 L p .707 .577 .707 r
F P
0 g
s
.29561 .60542 m .29216 .54958 L .29925 .54152 L p .707 .577 .707 r
F P
0 g
s
.49527 .60112 m .50203 .63823 L .49937 .63236 L p .707 .577 .707 r
F P
0 g
s
.49937 .63236 m .49262 .59524 L .49527 .60112 L p .707 .577 .707 r
F P
0 g
s
.30272 .70495 m .29922 .68641 L .29659 .68063 L p .707 .577 .707 r
F P
0 g
s
.29659 .68063 m .30008 .69917 L .30272 .70495 L p .707 .577 .707 r
F P
0 g
s
.497 .64726 m .50049 .6658 L .49786 .66002 L p .707 .577 .707 r
F P
0 g
s
.49786 .66002 m .49436 .64148 L .497 .64726 L p .707 .577 .707 r
F P
0 g
s
.29925 .54152 m .3027 .59736 L .29561 .60542 L p .707 .577 .707 r
F P
0 g
s
.49282 .53348 m .49627 .58931 L .48372 .58284 L p .707 .577 .707 r
F P
0 g
s
.48372 .58284 m .48027 .527 L .49282 .53348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30139 .67035 m .29463 .63324 L .3018 .6258 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3018 .6258 m .30855 .66291 L .30139 .67035 L p .707 .577 .707 r
F P
0 g
s
.3027 .59736 m .29925 .54152 L .31561 .53385 L p .707 .577 .707 r
F P
0 g
s
.49262 .59524 m .49937 .63236 L .48716 .62863 L p .707 .577 .707 r
F P
0 g
s
.48716 .62863 m .48041 .59152 L .49262 .59524 L p .707 .577 .707 r
F P
0 g
s
.30008 .69917 m .29659 .68063 L .30376 .67322 L p .707 .577 .707 r
F P
0 g
s
.30376 .67322 m .30725 .69176 L .30008 .69917 L p .707 .577 .707 r
F P
0 g
s
.48027 .527 m .48372 .58284 L .46272 .57816 L p .707 .577 .707 r
F P
0 g
s
.46272 .57816 m .45927 .52232 L .48027 .527 L p .707 .577 .707 r
F P
0 g
s
.49436 .64148 m .49786 .66002 L .48567 .65644 L p .707 .577 .707 r
F P
0 g
s
.48567 .65644 m .48218 .6379 L .49436 .64148 L p .707 .577 .707 r
F P
0 g
s
.31561 .53385 m .31906 .58968 L .3027 .59736 L p .707 .577 .707 r
F P
0 g
s
.30855 .66291 m .3018 .6258 L .31808 .61751 L p .707 .577 .707 r
F P
0 g
s
.31906 .58968 m .31561 .53385 L .33964 .52729 L p .707 .577 .707 r
F P
0 g
s
.31808 .61751 m .32484 .65462 L .30855 .66291 L p .707 .577 .707 r
F P
0 g
s
.48041 .59152 m .48716 .62863 L .46658 .62742 L p .707 .577 .707 r
F P
0 g
s
.46658 .62742 m .45983 .59031 L .48041 .59152 L p .707 .577 .707 r
F P
0 g
s
.30725 .69176 m .30376 .67322 L .32004 .6649 L p .707 .577 .707 r
F P
0 g
s
.45927 .52232 m .46272 .57816 L .43532 .57573 L p .707 .577 .707 r
F P
0 g
s
.43532 .57573 m .43187 .51989 L .45927 .52232 L p .707 .577 .707 r
F P
0 g
s
.32004 .6649 m .32353 .68344 L .30725 .69176 L p .707 .577 .707 r
F P
0 g
s
.33964 .52729 m .34309 .58313 L .31906 .58968 L p .707 .577 .707 r
F P
0 g
s
.48218 .6379 m .48567 .65644 L .46512 .65541 L p .707 .577 .707 r
F P
0 g
s
.46512 .65541 m .46163 .63687 L .48218 .6379 L p .707 .577 .707 r
F P
0 g
s
.34309 .58313 m .33964 .52729 L .36898 .52251 L p .707 .577 .707 r
F P
0 g
s
.32484 .65462 m .31808 .61751 L .34189 .60919 L p .707 .577 .707 r
F P
0 g
s
.43187 .51989 m .43532 .57573 L .40421 .57579 L p .707 .577 .707 r
F P
0 g
s
.40421 .57579 m .40076 .51996 L .43187 .51989 L p .707 .577 .707 r
F P
0 g
s
.45983 .59031 m .46658 .62742 L .43965 .62883 L p .707 .577 .707 r
F P
0 g
s
.43965 .62883 m .4329 .59172 L .45983 .59031 L p .707 .577 .707 r
F P
0 g
s
.34189 .60919 m .34865 .6463 L .32484 .65462 L p .707 .577 .707 r
F P
0 g
s
.37243 .57834 m .36898 .52251 L .40076 .51996 L p .707 .577 .707 r
F P
0 g
s
.36898 .52251 m .37243 .57834 L .34309 .58313 L p .707 .577 .707 r
F P
0 g
s
.40076 .51996 m .40421 .57579 L .37243 .57834 L p .707 .577 .707 r
F P
0 g
s
.32353 .68344 m .32004 .6649 L .34383 .65648 L p .707 .577 .707 r
F P
0 g
s
.34383 .65648 m .34733 .67503 L .32353 .68344 L p .707 .577 .707 r
F P
0 g
s
.46163 .63687 m .46512 .65541 L .43823 .65703 L p .707 .577 .707 r
F P
0 g
s
.43823 .65703 m .43474 .63849 L .46163 .63687 L p .707 .577 .707 r
F P
0 g
s
.34865 .6463 m .34189 .60919 L .3709 .60165 L p .707 .577 .707 r
F P
0 g
s
.4329 .59172 m .43965 .62883 L .40901 .63274 L p .707 .577 .707 r
F P
0 g
s
.40901 .63274 m .40226 .59563 L .4329 .59172 L p .707 .577 .707 r
F P
0 g
s
.3709 .60165 m .37765 .63876 L .34865 .6463 L p .707 .577 .707 r
F P
0 g
s
.37765 .63876 m .3709 .60165 L .40226 .59563 L p .707 .577 .707 r
F P
0 g
s
.34733 .67503 m .34383 .65648 L .37281 .6488 L p .707 .577 .707 r
F P
0 g
s
.40226 .59563 m .40901 .63274 L .37765 .63876 L p .707 .577 .707 r
F P
0 g
s
.37281 .6488 m .3763 .66734 L .34733 .67503 L p .707 .577 .707 r
F P
0 g
s
.43474 .63849 m .43823 .65703 L .40763 .66114 L p .707 .577 .707 r
F P
0 g
s
.40763 .66114 m .40413 .6426 L .43474 .63849 L p .707 .577 .707 r
F P
0 g
s
.3763 .66734 m .37281 .6488 L .40413 .6426 L p .707 .577 .707 r
F P
0 g
s
.40413 .6426 m .40763 .66114 L .3763 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001UYF00<005YFFUH00eYF2@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001J
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF00AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol00`00FUH00006FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`T000AJEP03001JEUYF
00IJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Qo
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001WOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000IOolA000mOol005Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00
E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00@0039oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000_Ool005=oo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<0
05YFFUH01EYF1`000eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`800003
FUH005YF009JEP03001JEUYF00=JEPH000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@000=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00Dgoo0P0000=JEP00FUH00UYF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00003FUH2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH01000
FUIJEUYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00@005YF001JEP8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPP000=JEP03001JEUYF00D00006FUH005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000H000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPd000=JEP03001JEUYF00EJEPP0009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH2000]Ool005Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0000002eoo`00E7oo00D005YFFUIJ
EP0000EJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00@7oo5@000eYF00@005YFFUIJ
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00?7oo100000=JEP00FUH01eYF
00<005YFFUH01UYF00D005YF000005YF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00=Woo1P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000bOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000^Ool0035oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0
0004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUHF000_Ool002moo`800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPP000EJEP03001JEUYF00EJEP04001JEUYFFUH5000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00L0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF008000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUH0
00030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004
FUH00`00FUIJEP04FUH40006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF2@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00005FUH01000FUH0000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20005FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH4
00000eYF000000020005FUH00`00FUIJEP07FUH00`00FUIJEP04FUHB000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
10001eYF00@005YF000000=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH015YF0`00
0UYF0`000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEPT000=JEP03001oogoo02]oo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPh00005FUH005YF001JEP020006FUH00`00FUIJEP04FUH70009FUH00`00
FUIJEP0400000eYF0000000200000eYF001JEP04FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF0P0000=JEP000000;7oo000/Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00UYF0P0000AJEP00000000MJ
EP03001JEUYF00@000MJEP03001JEUYF00AJEPD0009JEP<000EJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00AJEP03001JEUYF009JEP@002ao
o`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01000
1EYF0P0000=JEP00FUH01UYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000/Ool002aoo`800003FUH0
05YF009JEP04001JEUYFFUH600000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00`000eYF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP040004FUH60003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH2000]Ool002eoo`03001JEP0000=JEP@000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF00003`000UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF100025YF00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<007ooOol0;7oo000]Ool00`00
FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF1@000UYF00@005YF
FUIJEPT00003FUH005YF00EJEPL000AJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000
FUIJEUYF0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00P00;goo000]Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH000060004FUH01@00FUIJEP00FUH00`001EYF00D005YF001JEP0000=JEP@00003FUH00000
00<000AJEP03001JEUYF00IJEP04001JEP00000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`00<Goo000]Ool01@00FUH005YF0000
1EYF00<005YFFUH015YF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P0000=JEP0000004000
1EYF1@001EYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP04001J
EP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000eOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH0
0`00FUIJEP05FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH000000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF0`00>Goo000]Ool01@00FUIJEUYF00001EYF00<005YF00000`001EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF4`00<Goo000]Ool01@00FUIJEUYF00000eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJ
EPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Woo0P0000=JEP00
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH05@002EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0031o
o`@000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYF000^Ool002moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000AJEQ400003FUH005YF00QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002ioo`03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ000003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEQ<000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001o
ogoo02]oo`00;Goo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01@000eYF00<005YFFUH01EYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP04FUH7000@Ool6000]Ool002ao
o`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001J
EUYF00AJEP06001JEUYF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF0`000eYF
00<005YFFUH01UYF00<005YFFUH0100057oo0`000UYF00@005YFFUH002eoo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP<000IJEP03001JEUYF00AJEP@001Aoo`@00003FUH0
05YF00=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00@0
00AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH200000eYF001JEP06FUH00`00FUIJEP04000EOol30005
FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP@000IJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP04FUH5000FOol200000eYF001J
EP06FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YF
FUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEP800004FUH005YFFUH2
000BOol30003FUH00`00FUIJEP05FUH01000FUH00000<7oo000]Ool00`00FUH00005FUH01000FUH0
000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF6@001UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00@005YF000000=JEP03001JEUYF008000aoo`H0
00IJEP03001JEUYF00AJEP<0039oo`00;Goo00@005YFFUH000=JEP@00003FUH00000008000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPX00003FUH005YF00EJEP03001JEUYF00EJ
EPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP04001J
EUYFFUH40004FUH00`00FUIJEP020003Ool90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000]Ool01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2P0000=JEP0000000P0000Ioo`00000005YF0006FUH00`00FUIJEP050008FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002
FUH01000FUH000000eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000003Moo`00;Woo0UYF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=J
EP00FUH01EYF0`000Woo0`000UYF00<005YF00001EYF10000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P0000=J
EP00FUH030000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00>Goo000^Ool0
1EYF001JEP00FUH00P001EYF00<005YFFUH01EYF1`002EYF00<005YFFUH010000goo0P0000=JEP00
FUH00UYF00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF1@000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?7oo000^Ool20000
15YF000000001eYF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@001Goo0P000eYF00P005YF
FUIJEP00FUH005YF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF0P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00@7oo000^Ool30002FUH00`00FUIJ
EP05FUH00`00FUH000030008FUH00`00FUIJEP040007Ool30006FUH01@00FUIJEP00FUH00P000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000AJEP800003FUH0000000=JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@004Eoo`00;Woo0P0015YF00<005YFFUH00eYF0`000eYF
00<005YFFUH00UYF1`001goo100000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP80009JEP80009JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
009JEPL004Uoo`00;Goo00<005YF000015YF00<005YF00003P000goo0`000goo1@001EYF00<005YF
FUH015YF0`0000=oo`00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100015YF5000D7oo000]
Ool01000FUIJEP000eYF0P004Goo1`000UYF00<005YFFUH01UYF00@005YFFUIJEP8000Aoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP02
001FOol002eoo`05001JEUYF001JEP02000@Ool80004FUH00`00FUIJEP06FUH01000FUH000001Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00EJEP<005Qo
o`00;Woo00<005YF00004`000eYF1@001EYF00<005YFFUH015YF0`0027oo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00=JEP8005Yoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH0100037oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEP0000<005aoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0047oo00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001UYF0`00H7oo000^Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000FOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHD001HOol002moo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPH001aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP00008005Eoo`00<Goo500097oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00Jgoo0P0015YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF001EOol006eoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001J
EP000008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000E7oo001`Ool40008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH400000eYF001JEP05
FUHA0002FUH00`00Oomoo`1BOol007Aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00D000EJEP03001JEUYF00@000ioo`H005Aoo`00NWoo2@001UYF00<005YF
FUH02EYF00<005YFFUH015YF200000=JEP00FUH00eYF1`003goo0`000UYF00@005YFFUH005Aoo`00
Pgoo6P001eYF1P0057oo0P0000=JEP00FUH00eYF00<005YF0000E7oo002BOol200000eYF001JEP06
FUH00`00FUIJEP02FUH2000HOol20003FUH00`00FUIJEP02FUH2001EOol0091oo`8000=JEP03001J
EUYF00EJEP03001JEP00008001Moo`<000IJEP05001JEUYFFUH0001FOol008moo`8000EJEP03001J
EUYF00=JEP<001Ioo`@00003FUH005YF00IJEP04001JEP00001GOol008ioo`03001JEP0000EJEP03
001JEP0000<0019oo`L000EJEP03001JEUYF00AJEP<005Uoo`00SWoo00@005YFFUH000=JEP<000mo
o`L000AJEP03001JEUYF00IJEP04001JEUYFFUH2001LOol008ioo`05001JEUYF001JEP02000>Ool4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002?Ool00`00FUH0000A0006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol008moo`80009JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00Sgoo0P000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00Igoo002?Ool20003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001/Ool0091oo`80
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0071oo`00TWoo5000Mgoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59579 .75929 m .59924 .70419 L .56813 .70034 L p .707 .577 .707 r
F P
0 g
s
.59924 .70419 m .59579 .75929 L .62757 .76027 L p .707 .577 .707 r
F P
0 g
s
.62757 .76027 m .63102 .70517 L .59924 .70419 L p .707 .577 .707 r
F P
0 g
s
.63102 .70517 m .62757 .76027 L .65691 .75829 L p .707 .577 .707 r
F P
0 g
s
.65691 .75829 m .66036 .70319 L .63102 .70517 L p .707 .577 .707 r
F P
0 g
s
.56468 .75543 m .56813 .70034 L .54073 .69399 L p .707 .577 .707 r
F P
0 g
s
.56813 .70034 m .56468 .75543 L .59579 .75929 L p .707 .577 .707 r
F P
0 g
s
.66036 .70319 m .65691 .75829 L .68093 .75354 L p .707 .577 .707 r
F P
0 g
s
.68093 .75354 m .68438 .69844 L .66036 .70319 L p .707 .577 .707 r
F P
0 g
s
.53728 .74909 m .54073 .69399 L .51973 .68578 L p .707 .577 .707 r
F P
0 g
s
.54073 .69399 m .53728 .74909 L .56468 .75543 L p .707 .577 .707 r
F P
0 g
s
.59099 .8152 m .59774 .77954 L .5671 .77195 L p .707 .577 .707 r
F P
0 g
s
.59774 .77954 m .59099 .8152 L .62235 .81957 L p .707 .577 .707 r
F P
0 g
s
.62235 .81957 m .6291 .78391 L .59774 .77954 L p .707 .577 .707 r
F P
0 g
s
.6291 .78391 m .62235 .81957 L .65135 .82027 L p .707 .577 .707 r
F P
0 g
s
.65135 .82027 m .6581 .7846 L .6291 .78391 L p .707 .577 .707 r
F P
0 g
s
.56034 .80761 m .5671 .77195 L .54017 .76186 L p .707 .577 .707 r
F P
0 g
s
.5671 .77195 m .56034 .80761 L .59099 .8152 L p .707 .577 .707 r
F P
0 g
s
.59237 .8439 m .59586 .82611 L .56526 .81832 L p .707 .577 .707 r
F P
0 g
s
.59586 .82611 m .59237 .8439 L .62369 .84844 L p .707 .577 .707 r
F P
0 g
s
.62369 .84844 m .62719 .83064 L .59586 .82611 L p .707 .577 .707 r
F P
0 g
s
.68438 .69844 m .68093 .75354 L .69729 .74648 L p .707 .577 .707 r
F P
0 g
s
.69729 .74648 m .70074 .69138 L .68438 .69844 L p .707 .577 .707 r
F P
0 g
s
.51973 .68578 m .51628 .74087 L .53728 .74909 L p .707 .577 .707 r
F P
0 g
s
.54017 .76186 m .53341 .79752 L .56034 .80761 L p .707 .577 .707 r
F P
0 g
s
.6581 .7846 m .65135 .82027 L .67516 .81723 L p .707 .577 .707 r
F P
0 g
s
.67516 .81723 m .68191 .78157 L .6581 .7846 L p .707 .577 .707 r
F P
0 g
s
.62719 .83064 m .62369 .84844 L .65267 .84928 L p .707 .577 .707 r
F P
0 g
s
.65267 .84928 m .65617 .83148 L .62719 .83064 L p .707 .577 .707 r
F P
0 g
s
.56176 .83611 m .56526 .81832 L .53837 .80804 L p .707 .577 .707 r
F P
0 g
s
.56526 .81832 m .56176 .83611 L .59237 .8439 L p .707 .577 .707 r
F P
0 g
s
.53341 .79752 m .54017 .76186 L .51959 .75027 L p .707 .577 .707 r
F P
0 g
s
.51628 .74087 m .51973 .68578 L .50718 .6765 L p .707 .577 .707 r
F P
0 g
s
.53837 .80804 m .53487 .82583 L .56176 .83611 L p .707 .577 .707 r
F P
0 g
s
.65617 .83148 m .65267 .84928 L .67646 .84633 L p .707 .577 .707 r
F P
0 g
s
.67646 .84633 m .67996 .82854 L .65617 .83148 L p .707 .577 .707 r
F P
0 g
s
.51959 .75027 m .51284 .78593 L .53341 .79752 L p .707 .577 .707 r
F P
0 g
s
.53487 .82583 m .53837 .80804 L .51782 .79627 L p .707 .577 .707 r
F P
0 g
s
.68191 .78157 m .67516 .81723 L .69144 .81077 L p .707 .577 .707 r
F P
0 g
s
.69144 .81077 m .6982 .77511 L .68191 .78157 L p .707 .577 .707 r
F P
0 g
s
.51782 .79627 m .51433 .81406 L .53487 .82583 L p .707 .577 .707 r
F P
0 g
s
.50718 .6765 m .50373 .73159 L .51628 .74087 L p .707 .577 .707 r
F P
0 g
s
.51284 .78593 m .51959 .75027 L .50738 .73831 L p .707 .577 .707 r
F P
0 g
s
.70074 .69138 m .69729 .74648 L .70438 .7378 L p .707 .577 .707 r
F P
0 g
s
.70438 .7378 m .70783 .68271 L .70074 .69138 L p .707 .577 .707 r
F P
0 g
s
.50373 .73159 m .50718 .6765 L .50431 .66706 L p .707 .577 .707 r
F P
0 g
s
.67996 .82854 m .67646 .84633 L .69274 .8399 L p .707 .577 .707 r
F P
0 g
s
.69274 .8399 m .69624 .8221 L .67996 .82854 L p .707 .577 .707 r
F P
0 g
s
.50738 .73831 m .50062 .77397 L .51284 .78593 L p .707 .577 .707 r
F P
0 g
s
.51433 .81406 m .51782 .79627 L .50564 .78417 L p .707 .577 .707 r
F P
0 g
s
.50564 .78417 m .50214 .80196 L .51433 .81406 L p .707 .577 .707 r
F P
0 g
s
.6982 .77511 m .69144 .81077 L .69861 .8015 L p .707 .577 .707 r
F P
0 g
s
.69861 .8015 m .70537 .76584 L .6982 .77511 L p .707 .577 .707 r
F P
0 g
s
.50431 .66706 m .50086 .72215 L .50373 .73159 L p .707 .577 .707 r
F P
0 g
s
.50062 .77397 m .50738 .73831 L .50472 .72714 L p .707 .577 .707 r
F P
0 g
s
.70783 .68271 m .70438 .7378 L .70152 .72837 L p .707 .577 .707 r
F P
0 g
s
.70152 .72837 m .70497 .67327 L .70783 .68271 L p .707 .577 .707 r
F P
0 g
s
.49821 .82185 m .48943 .3191 L .44543 .3172 L p .707 .577 .707 r
F P
0 g
s
.50472 .72714 m .49797 .76281 L .50062 .77397 L p .707 .577 .707 r
F P
0 g
s
.50086 .72215 m .50431 .66706 L .5114 .65838 L p .707 .577 .707 r
F P
0 g
s
.50214 .80196 m .50564 .78417 L .503 .77292 L p .707 .577 .707 r
F P
0 g
s
.503 .77292 m .49951 .79071 L .50214 .80196 L p .707 .577 .707 r
F P
0 g
s
.49797 .76281 m .50472 .72714 L .51189 .71788 L p .707 .577 .707 r
F P
0 g
s
.5114 .65838 m .50795 .71348 L .50086 .72215 L p .707 .577 .707 r
F P
0 g
s
.51189 .71788 m .50514 .75354 L .49797 .76281 L p .707 .577 .707 r
F P
0 g
s
.50795 .71348 m .5114 .65838 L .52776 .65132 L p .707 .577 .707 r
F P
0 g
s
.49951 .79071 m .503 .77292 L .51017 .76362 L p .707 .577 .707 r
F P
0 g
s
.51017 .76362 m .50668 .78141 L .49951 .79071 L p .707 .577 .707 r
F P
0 g
s
.50514 .75354 m .51189 .71788 L .52818 .71141 L p .707 .577 .707 r
F P
0 g
s
.52776 .65132 m .52431 .70642 L .50795 .71348 L p .707 .577 .707 r
F P
0 g
s
.52431 .70642 m .52776 .65132 L .55179 .64657 L p .707 .577 .707 r
F P
0 g
s
.52818 .71141 m .52142 .74707 L .50514 .75354 L p .707 .577 .707 r
F P
0 g
s
.50668 .78141 m .51017 .76362 L .52645 .75719 L p .707 .577 .707 r
F P
0 g
s
.52645 .75719 m .52296 .77498 L .50668 .78141 L p .707 .577 .707 r
F P
0 g
s
.52142 .74707 m .52818 .71141 L .55199 .70838 L p .707 .577 .707 r
F P
0 g
s
.55179 .64657 m .54834 .70167 L .52431 .70642 L p .707 .577 .707 r
F P
0 g
s
.55199 .70838 m .54523 .74404 L .52142 .74707 L p .707 .577 .707 r
F P
0 g
s
.52296 .77498 m .52645 .75719 L .55024 .75424 L p .707 .577 .707 r
F P
0 g
s
.55024 .75424 m .54675 .77204 L .52296 .77498 L p .707 .577 .707 r
F P
0 g
s
.48943 .3191 m .49821 .82185 L .54314 .82005 L p .707 .577 .707 r
F P
0 g
s
.54314 .82005 m .53437 .3173 L .48943 .3191 L p .707 .577 .707 r
F P
0 g
s
.69624 .8221 m .69274 .8399 L .69992 .8306 L p .707 .577 .707 r
F P
0 g
s
.69992 .8306 m .70341 .81281 L .69624 .8221 L p .707 .577 .707 r
F P
0 g
s
.54834 .70167 m .55179 .64657 L .58113 .64459 L p .707 .577 .707 r
F P
0 g
s
.58113 .64459 m .57768 .69969 L .54834 .70167 L p .707 .577 .707 r
F P
0 g
s
.54523 .74404 m .55199 .70838 L .58099 .70908 L p .707 .577 .707 r
F P
0 g
s
.58099 .70908 m .57424 .74474 L .54523 .74404 L p .707 .577 .707 r
F P
0 g
s
.57424 .74474 m .58099 .70908 L .61235 .71344 L p .707 .577 .707 r
F P
0 g
s
.54675 .77204 m .55024 .75424 L .57922 .75508 L p .707 .577 .707 r
F P
0 g
s
.61235 .71344 m .60559 .7491 L .57424 .74474 L p .707 .577 .707 r
F P
0 g
s
.57922 .75508 m .57573 .77288 L .54675 .77204 L p .707 .577 .707 r
F P
0 g
s
.57573 .77288 m .57922 .75508 L .61055 .75962 L p .707 .577 .707 r
F P
0 g
s
.61055 .75962 m .60705 .77741 L .57573 .77288 L p .707 .577 .707 r
F P
0 g
s
.53437 .3173 m .54314 .82005 L .58462 .81472 L p .707 .577 .707 r
F P
0 g
s
.57768 .69969 m .58113 .64459 L .61291 .64557 L p .707 .577 .707 r
F P
0 g
s
.61291 .64557 m .60946 .70067 L .57768 .69969 L p .707 .577 .707 r
F P
0 g
s
.58462 .81472 m .57584 .31197 L .53437 .3173 L p .707 .577 .707 r
F P
0 g
s
.4542 .81995 m .44543 .3172 L .40667 .31178 L p .707 .577 .707 r
F P
0 g
s
.44543 .3172 m .4542 .81995 L .49821 .82185 L p .707 .577 .707 r
F P
0 g
s
.70537 .76584 m .69861 .8015 L .69596 .79034 L p .707 .577 .707 r
F P
0 g
s
.69596 .79034 m .70271 .75468 L .70537 .76584 L p .707 .577 .707 r
F P
0 g
s
.64299 .72104 m .63624 .7567 L .60559 .7491 L p .707 .577 .707 r
F P
0 g
s
.60559 .7491 m .61235 .71344 L .64299 .72104 L p .707 .577 .707 r
F P
0 g
s
.64115 .76741 m .63766 .7852 L .60705 .77741 L p .707 .577 .707 r
F P
0 g
s
.60705 .77741 m .61055 .75962 L .64115 .76741 L p .707 .577 .707 r
F P
0 g
s
.57584 .31197 m .58462 .81472 L .61857 .80639 L p .707 .577 .707 r
F P
0 g
s
.64402 .64943 m .64057 .70452 L .60946 .70067 L p .707 .577 .707 r
F P
0 g
s
.60946 .70067 m .61291 .64557 L .64402 .64943 L p .707 .577 .707 r
F P
0 g
s
.61857 .80639 m .6098 .30364 L .57584 .31197 L p .707 .577 .707 r
F P
0 g
s
.70497 .67327 m .70152 .72837 L .68897 .71908 L p .707 .577 .707 r
F P
0 g
s
.68897 .71908 m .69242 .66399 L .70497 .67327 L p .707 .577 .707 r
F P
0 g
s
.25278 .70662 m .25623 .65152 L .22512 .64767 L p .707 .577 .707 r
F P
0 g
s
.25623 .65152 m .25278 .70662 L .28456 .7076 L p .707 .577 .707 r
F P
0 g
s
.28456 .7076 m .28801 .65251 L .25623 .65152 L p .707 .577 .707 r
F P
0 g
s
.70341 .81281 m .69992 .8306 L .69728 .81935 L p .707 .577 .707 r
F P
0 g
s
.69728 .81935 m .70077 .80156 L .70341 .81281 L p .707 .577 .707 r
F P
0 g
s
.28801 .65251 m .28456 .7076 L .3139 .70562 L p .707 .577 .707 r
F P
0 g
s
.3139 .70562 m .31735 .65053 L .28801 .65251 L p .707 .577 .707 r
F P
0 g
s
.41545 .81453 m .40667 .31178 L .37695 .30337 L p .707 .577 .707 r
F P
0 g
s
.40667 .31178 m .41545 .81453 L .4542 .81995 L p .707 .577 .707 r
F P
0 g
s
.22167 .70277 m .22512 .64767 L .19772 .64133 L p .707 .577 .707 r
F P
0 g
s
.22512 .64767 m .22167 .70277 L .25278 .70662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31735 .65053 m .3139 .70562 L .33792 .70087 L p .707 .577 .707 r
F P
0 g
s
.33792 .70087 m .34137 .64577 L .31735 .65053 L p .707 .577 .707 r
F P
0 g
s
.70271 .75468 m .69596 .79034 L .68374 .77838 L p .707 .577 .707 r
F P
0 g
s
.68374 .77838 m .6905 .74272 L .70271 .75468 L p .707 .577 .707 r
F P
0 g
s
.19427 .69642 m .19772 .64133 L .17672 .63311 L p .707 .577 .707 r
F P
0 g
s
.19772 .64133 m .19427 .69642 L .22167 .70277 L p .707 .577 .707 r
F P
0 g
s
.66992 .73113 m .66317 .76679 L .63624 .7567 L p .707 .577 .707 r
F P
0 g
s
.63624 .7567 m .64299 .72104 L .66992 .73113 L p .707 .577 .707 r
F P
0 g
s
.66804 .77769 m .66455 .79548 L .63766 .7852 L p .707 .577 .707 r
F P
0 g
s
.63766 .7852 m .64115 .76741 L .66804 .77769 L p .707 .577 .707 r
F P
0 g
s
.6098 .30364 m .61857 .80639 L .64168 .79586 L p .707 .577 .707 r
F P
0 g
s
.64168 .79586 m .63291 .29311 L .6098 .30364 L p .707 .577 .707 r
F P
0 g
s
.69242 .66399 m .68897 .71908 L .66797 .71087 L p .707 .577 .707 r
F P
0 g
s
.66797 .71087 m .67142 .65577 L .69242 .66399 L p .707 .577 .707 r
F P
0 g
s
.24798 .77743 m .25473 .74177 L .22409 .73417 L p .707 .577 .707 r
F P
0 g
s
.25473 .74177 m .24798 .77743 L .27934 .78179 L p .707 .577 .707 r
F P
0 g
s
.27934 .78179 m .28609 .74613 L .25473 .74177 L p .707 .577 .707 r
F P
0 g
s
.28609 .74613 m .27934 .78179 L .30834 .78249 L p .707 .577 .707 r
F P
0 g
s
.30834 .78249 m .31509 .74683 L .28609 .74613 L p .707 .577 .707 r
F P
0 g
s
.21733 .76983 m .22409 .73417 L .19716 .72408 L p .707 .577 .707 r
F P
0 g
s
.22409 .73417 m .21733 .76983 L .24798 .77743 L p .707 .577 .707 r
F P
0 g
s
.70077 .80156 m .69728 .81935 L .68509 .80725 L p .707 .577 .707 r
F P
0 g
s
.68509 .80725 m .68859 .78946 L .70077 .80156 L p .707 .577 .707 r
F P
0 g
s
.34137 .64577 m .33792 .70087 L .35428 .69381 L p .707 .577 .707 r
F P
0 g
s
.35428 .69381 m .35773 .63871 L .34137 .64577 L p .707 .577 .707 r
F P
0 g
s
.38573 .80612 m .37695 .30337 L .35918 .2928 L p .707 .577 .707 r
F P
0 g
s
.37695 .30337 m .38573 .80612 L .41545 .81453 L p .707 .577 .707 r
F P
0 g
s
.17672 .63311 m .17327 .68821 L .19427 .69642 L p .707 .577 .707 r
F P
0 g
s
.19716 .72408 m .19041 .75974 L .21733 .76983 L p .707 .577 .707 r
F P
0 g
s
.31509 .74683 m .30834 .78249 L .33215 .77946 L p .707 .577 .707 r
F P
0 g
s
.33215 .77946 m .3389 .7438 L .31509 .74683 L p .707 .577 .707 r
F P
0 g
s
.17327 .68821 m .17672 .63311 L .16417 .62383 L p .707 .577 .707 r
F P
0 g
s
.19041 .75974 m .19716 .72408 L .17658 .71249 L p .707 .577 .707 r
F P
0 g
s
.67142 .65577 m .66797 .71087 L .64057 .70452 L p .707 .577 .707 r
F P
0 g
s
.64057 .70452 m .64402 .64943 L .67142 .65577 L p .707 .577 .707 r
F P
0 g
s
.6905 .74272 m .68374 .77838 L .66317 .76679 L p .707 .577 .707 r
F P
0 g
s
.66317 .76679 m .66992 .73113 L .6905 .74272 L p .707 .577 .707 r
F P
0 g
s
.24936 .83341 m .25286 .81561 L .22225 .80782 L p .707 .577 .707 r
F P
0 g
s
.25286 .81561 m .24936 .83341 L .28069 .83794 L p .707 .577 .707 r
F P
0 g
s
.28069 .83794 m .28418 .82015 L .25286 .81561 L p .707 .577 .707 r
F P
0 g
s
.28418 .82015 m .28069 .83794 L .30966 .83878 L p .707 .577 .707 r
F P
0 g
s
.30966 .83878 m .31316 .82098 L .28418 .82015 L p .707 .577 .707 r
F P
0 g
s
.21876 .82561 m .22225 .80782 L .19536 .79754 L p .707 .577 .707 r
F P
0 g
s
.22225 .80782 m .21876 .82561 L .24936 .83341 L p .707 .577 .707 r
F P
0 g
s
.17658 .71249 m .16983 .74815 L .19041 .75974 L p .707 .577 .707 r
F P
0 g
s
.19536 .79754 m .19186 .81533 L .21876 .82561 L p .707 .577 .707 r
F P
0 g
s
.63291 .29311 m .64168 .79586 L .65168 .78418 L p .707 .577 .707 r
F P
0 g
s
.65168 .78418 m .64291 .28143 L .63291 .29311 L p .707 .577 .707 r
F P
0 g
s
.68859 .78946 m .68509 .80725 L .66455 .79548 L p .707 .577 .707 r
F P
0 g
s
.66455 .79548 m .66804 .77769 L .68859 .78946 L p .707 .577 .707 r
F P
0 g
s
.16417 .62383 m .16072 .67893 L .17327 .68821 L p .707 .577 .707 r
F P
0 g
s
.35773 .63871 m .35428 .69381 L .36138 .68514 L p .707 .577 .707 r
F P
0 g
s
.36138 .68514 m .36483 .63004 L .35773 .63871 L p .707 .577 .707 r
F P
0 g
s
.3389 .7438 m .33215 .77946 L .34843 .77299 L p .707 .577 .707 r
F P
0 g
s
.34843 .77299 m .35519 .73733 L .3389 .7438 L p .707 .577 .707 r
F P
0 g
s
.31316 .82098 m .30966 .83878 L .33346 .83584 L p .707 .577 .707 r
F P
0 g
s
.33346 .83584 m .33695 .81804 L .31316 .82098 L p .707 .577 .707 r
F P
0 g
s
.19186 .81533 m .19536 .79754 L .17481 .78577 L p .707 .577 .707 r
F P
0 g
s
.16983 .74815 m .17658 .71249 L .16437 .70053 L p .707 .577 .707 r
F P
0 g
s
.16072 .67893 m .16417 .62383 L .1613 .61439 L p .707 .577 .707 r
F P
0 g
s
.17481 .78577 m .17132 .80357 L .19186 .81533 L p .707 .577 .707 r
F P
0 g
s
.36483 .63004 m .36138 .68514 L .35851 .6757 L p .707 .577 .707 r
F P
0 g
s
.35851 .6757 m .36196 .6206 L .36483 .63004 L p .707 .577 .707 r
F P
0 g
s
.36795 .79555 m .35918 .2928 L .35509 .2811 L p .707 .577 .707 r
F P
0 g
s
.35918 .2928 m .36795 .79555 L .38573 .80612 L p .707 .577 .707 r
F P
0 g
s
.16437 .70053 m .15761 .73619 L .16983 .74815 L p .707 .577 .707 r
F P
0 g
s
.33695 .81804 m .33346 .83584 L .34973 .8294 L p .707 .577 .707 r
F P
0 g
s
.34973 .8294 m .35323 .81161 L .33695 .81804 L p .707 .577 .707 r
F P
0 g
s
.17132 .80357 m .17481 .78577 L .16263 .77367 L p .707 .577 .707 r
F P
0 g
s
.1613 .61439 m .15785 .66949 L .16072 .67893 L p .707 .577 .707 r
F P
0 g
s
.35519 .73733 m .34843 .77299 L .3556 .76373 L p .707 .577 .707 r
F P
0 g
s
.3556 .76373 m .36236 .72806 L .35519 .73733 L p .707 .577 .707 r
F P
0 g
s
.15761 .73619 m .16437 .70053 L .16172 .68937 L p .707 .577 .707 r
F P
0 g
s
.16263 .77367 m .15913 .79146 L .17132 .80357 L p .707 .577 .707 r
F P
0 g
s
.64291 .28143 m .65168 .78418 L .64789 .77331 L p .707 .577 .707 r
F P
0 g
s
.64754 .76699 m .64291 .28143 L .64789 .77331 L .707 .577 .707 r
F
.63882 .26973 m .64291 .28143 L p .64642 .64895 L F P
0 g
s
.6476 .77248 m .64539 .6458 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.64539 .6458 m .63882 .26973 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.63882 .26973 m .6476 .77248 L .62982 .7619 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64152 .57502 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64093 .63955 m .64132 .63339 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64132 .63339 m .64438 .58446 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64458 .64627 m .6418 .66095 L p .65004 .69389 L .707 .577 .707 r
F P
0 g
s
.6418 .66095 m .63783 .68193 L .64322 .68721 L p .707 .577 .707 r
F P
0 g
s
.64322 .68721 m .65004 .69389 L p .6418 .66095 L .707 .577 .707 r
F P
0 g
s
.64789 .77331 m .6476 .77248 L p .64754 .76699 L .707 .577 .707 r
F P
0 g
s
.15785 .66949 m .1613 .61439 L .16839 .60572 L p .707 .577 .707 r
F P
0 g
s
.16172 .68937 m .15496 .72503 L .15761 .73619 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35323 .81161 m .34973 .8294 L .35691 .8201 L p .707 .577 .707 r
F P
0 g
s
.35691 .8201 m .3604 .80231 L .35323 .81161 L p .707 .577 .707 r
F P
0 g
s
.15913 .79146 m .16263 .77367 L .15999 .76242 L p .707 .577 .707 r
F P
0 g
s
.16839 .60572 m .16494 .66081 L .15785 .66949 L p .707 .577 .707 r
F P
0 g
s
.15999 .76242 m .1565 .78021 L .15913 .79146 L p .707 .577 .707 r
F P
0 g
s
.36196 .6206 m .35851 .6757 L .34596 .66642 L p .707 .577 .707 r
F P
0 g
s
.34596 .66642 m .34941 .61132 L .36196 .6206 L p .707 .577 .707 r
F P
0 g
s
.35509 .2811 m .36387 .78385 L .36795 .79555 L p .707 .577 .707 r
F P
0 g
s
.36387 .78385 m .35509 .2811 L .36509 .26941 L p .707 .577 .707 r
F P
0 g
s
.36236 .72806 m .3556 .76373 L .35295 .75256 L p .707 .577 .707 r
F P
0 g
s
.35295 .75256 m .3597 .7169 L .36236 .72806 L p .707 .577 .707 r
F P
0 g
s
.15496 .72503 m .16172 .68937 L .16888 .6801 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16494 .66081 m .16839 .60572 L .18475 .59866 L p .707 .577 .707 r
F P
0 g
s
.16888 .6801 m .16213 .71576 L .15496 .72503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3604 .80231 m .35691 .8201 L .35427 .80886 L p .707 .577 .707 r
F P
0 g
s
.35427 .80886 m .35776 .79106 L .3604 .80231 L p .707 .577 .707 r
F P
0 g
s
.1565 .78021 m .15999 .76242 L .16716 .75312 L p .707 .577 .707 r
F P
0 g
s
.62982 .7619 m .62105 .25916 L .63882 .26973 L p .707 .577 .707 r
F P
0 g
s
.18475 .59866 m .1813 .65375 L .16494 .66081 L p .707 .577 .707 r
F P
0 g
s
.16716 .75312 m .16367 .77092 L .1565 .78021 L p .707 .577 .707 r
F P
0 g
s
.3597 .7169 m .35295 .75256 L .34073 .7406 L p .707 .577 .707 r
F P
0 g
s
.34073 .7406 m .34749 .70494 L .3597 .7169 L p .707 .577 .707 r
F P
0 g
s
.34941 .61132 m .34596 .66642 L .32496 .6582 L p .707 .577 .707 r
F P
0 g
s
.32496 .6582 m .32841 .6031 L .34941 .61132 L p .707 .577 .707 r
F P
0 g
s
.16213 .71576 m .16888 .6801 L .18517 .67364 L p .707 .577 .707 r
F P
0 g
s
.1813 .65375 m .18475 .59866 L .20878 .5939 L p .707 .577 .707 r
F P
0 g
s
.37387 .77216 m .36509 .26941 L .3882 .25889 L p .707 .577 .707 r
F P
0 g
s
.36509 .26941 m .37387 .77216 L .36387 .78385 L p .707 .577 .707 r
F P
0 g
s
.18517 .67364 m .17841 .7093 L .16213 .71576 L p .707 .577 .707 r
F P
0 g
s
.35776 .79106 m .35427 .80886 L .34208 .79675 L p .707 .577 .707 r
F P
0 g
s
.34208 .79675 m .34558 .77896 L .35776 .79106 L p .707 .577 .707 r
F P
0 g
s
.32841 .6031 m .32496 .6582 L .29756 .65186 L p .707 .577 .707 r
F P
0 g
s
.29756 .65186 m .30101 .59676 L .32841 .6031 L p .707 .577 .707 r
F P
0 g
s
.16367 .77092 m .16716 .75312 L .18344 .74669 L p .707 .577 .707 r
F P
0 g
s
.20878 .5939 m .20533 .649 L .1813 .65375 L p .707 .577 .707 r
F P
0 g
s
.34749 .70494 m .34073 .7406 L .32016 .72901 L p .707 .577 .707 r
F P
0 g
s
.32016 .72901 m .32691 .69335 L .34749 .70494 L p .707 .577 .707 r
F P
0 g
s
.20533 .649 m .20878 .5939 L .23812 .59192 L p .707 .577 .707 r
F P
0 g
s
.17841 .7093 m .18517 .67364 L .20898 .6706 L p .707 .577 .707 r
F P
0 g
s
.18344 .74669 m .17995 .76448 L .16367 .77092 L p .707 .577 .707 r
F P
0 g
s
.62105 .25916 m .62982 .7619 L .6001 .7535 L p .707 .577 .707 r
F P
0 g
s
.6001 .7535 m .59133 .25075 L .62105 .25916 L p .707 .577 .707 r
F P
0 g
s
.30101 .59676 m .29756 .65186 L .26645 .648 L p .707 .577 .707 r
F P
0 g
s
.26645 .648 m .2699 .59291 L .30101 .59676 L p .707 .577 .707 r
F P
0 g
s
.23467 .64702 m .23812 .59192 L .2699 .59291 L p .707 .577 .707 r
F P
0 g
s
.23812 .59192 m .23467 .64702 L .20533 .649 L p .707 .577 .707 r
F P
0 g
s
.20898 .6706 m .20222 .70627 L .17841 .7093 L p .707 .577 .707 r
F P
0 g
s
.2699 .59291 m .26645 .648 L .23467 .64702 L p .707 .577 .707 r
F P
0 g
s
.34558 .77896 m .34208 .79675 L .32154 .78499 L p .707 .577 .707 r
F P
0 g
s
.32154 .78499 m .32503 .76719 L .34558 .77896 L p .707 .577 .707 r
F P
0 g
s
.32691 .69335 m .32016 .72901 L .29323 .71892 L p .707 .577 .707 r
F P
0 g
s
.29323 .71892 m .29998 .68326 L .32691 .69335 L p .707 .577 .707 r
F P
0 g
s
.17995 .76448 m .18344 .74669 L .20723 .74375 L p .707 .577 .707 r
F P
0 g
s
.20222 .70627 m .20898 .6706 L .23798 .6713 L p .707 .577 .707 r
F P
0 g
s
.3882 .25889 m .39698 .76164 L .37387 .77216 L p .707 .577 .707 r
F P
0 g
s
.39698 .76164 m .3882 .25889 L .42216 .25055 L p .707 .577 .707 r
F P
0 g
s
.73299 .66725 m .73644 .61215 L .70533 .6083 L p .707 .577 .707 r
F P
0 g
s
.73644 .61215 m .73299 .66725 L .76477 .66823 L p .707 .577 .707 r
F P
0 g
s
.76477 .66823 m .76822 .61314 L .73644 .61215 L p .707 .577 .707 r
F P
0 g
s
.76822 .61314 m .76477 .66823 L .79411 .66625 L p .707 .577 .707 r
F P
0 g
s
.79411 .66625 m .79756 .61115 L .76822 .61314 L p .707 .577 .707 r
F P
0 g
s
.20723 .74375 m .20374 .76154 L .17995 .76448 L p .707 .577 .707 r
F P
0 g
s
.70188 .6634 m .70533 .6083 L .67793 .60195 L p .707 .577 .707 r
F P
0 g
s
.70533 .6083 m .70188 .6634 L .73299 .66725 L p .707 .577 .707 r
F P
0 g
s
.23798 .6713 m .23123 .70696 L .20222 .70627 L p .707 .577 .707 r
F P
0 g
s
.29998 .68326 m .29323 .71892 L .26258 .71133 L p .707 .577 .707 r
F P
0 g
s
.26258 .71133 m .26934 .67566 L .29998 .68326 L p .707 .577 .707 r
F P
0 g
s
.23123 .70696 m .23798 .6713 L .26934 .67566 L p .707 .577 .707 r
F P
0 g
s
.59133 .25075 m .6001 .7535 L .56135 .74808 L p .707 .577 .707 r
F P
0 g
s
.56135 .74808 m .55257 .24533 L .59133 .25075 L p .707 .577 .707 r
F P
0 g
s
.79756 .61115 m .79411 .66625 L .81814 .6615 L p .707 .577 .707 r
F P
0 g
s
.81814 .6615 m .82159 .6064 L .79756 .61115 L p .707 .577 .707 r
F P
0 g
s
.26934 .67566 m .26258 .71133 L .23123 .70696 L p .707 .577 .707 r
F P
0 g
s
.32503 .76719 m .32154 .78499 L .29465 .7747 L p .707 .577 .707 r
F P
0 g
s
.29465 .7747 m .29814 .75691 L .32503 .76719 L p .707 .577 .707 r
F P
0 g
s
.20374 .76154 m .20723 .74375 L .23621 .74458 L p .707 .577 .707 r
F P
0 g
s
.67448 .65705 m .67793 .60195 L .65693 .59374 L p .707 .577 .707 r
F P
0 g
s
.67793 .60195 m .67448 .65705 L .70188 .6634 L p .707 .577 .707 r
F P
0 g
s
.72819 .72317 m .73495 .68751 L .7043 .67991 L p .707 .577 .707 r
F P
0 g
s
.73495 .68751 m .72819 .72317 L .75955 .72753 L p .707 .577 .707 r
F P
0 g
s
.75955 .72753 m .7663 .69187 L .73495 .68751 L p .707 .577 .707 r
F P
0 g
s
.23621 .74458 m .23272 .76238 L .20374 .76154 L p .707 .577 .707 r
F P
0 g
s
.7663 .69187 m .75955 .72753 L .78855 .72823 L p .707 .577 .707 r
F P
0 g
s
.78855 .72823 m .79531 .69257 L .7663 .69187 L p .707 .577 .707 r
F P
0 g
s
.69755 .71557 m .7043 .67991 L .67737 .66982 L p .707 .577 .707 r
F P
0 g
s
.7043 .67991 m .69755 .71557 L .72819 .72317 L p .707 .577 .707 r
F P
0 g
s
.43093 .7533 m .42216 .25055 L .46363 .24522 L p .707 .577 .707 r
F P
0 g
s
.42216 .25055 m .43093 .7533 L .39698 .76164 L p .707 .577 .707 r
F P
0 g
s
.29814 .75691 m .29465 .7747 L .26404 .76691 L p .707 .577 .707 r
F P
0 g
s
.26404 .76691 m .26754 .74912 L .29814 .75691 L p .707 .577 .707 r
F P
0 g
s
.23272 .76238 m .23621 .74458 L .26754 .74912 L p .707 .577 .707 r
F P
0 g
s
.72957 .75186 m .73307 .73407 L .70246 .72628 L p .707 .577 .707 r
F P
0 g
s
.73307 .73407 m .72957 .75186 L .7609 .7564 L p .707 .577 .707 r
F P
0 g
s
.7609 .7564 m .76439 .73861 L .73307 .73407 L p .707 .577 .707 r
F P
0 g
s
.82159 .6064 m .81814 .6615 L .8345 .65444 L p .707 .577 .707 r
F P
0 g
s
.8345 .65444 m .83795 .59934 L .82159 .6064 L p .707 .577 .707 r
F P
0 g
s
.26754 .74912 m .26404 .76691 L .23272 .76238 L p .707 .577 .707 r
F P
0 g
s
.55257 .24533 m .56135 .74808 L .51735 .74617 L p .707 .577 .707 r
F P
0 g
s
.51735 .74617 m .50857 .24342 L .55257 .24533 L p .707 .577 .707 r
F P
0 g
s
.65693 .59374 m .65348 .64884 L .67448 .65705 L p .707 .577 .707 r
F P
0 g
s
.67737 .66982 m .67062 .70548 L .69755 .71557 L p .707 .577 .707 r
F P
0 g
s
.79531 .69257 m .78855 .72823 L .81236 .7252 L p .707 .577 .707 r
F P
0 g
s
.81236 .7252 m .81912 .68953 L .79531 .69257 L p .707 .577 .707 r
F P
0 g
s
.76439 .73861 m .7609 .7564 L .78988 .75724 L p .707 .577 .707 r
F P
0 g
s
.78988 .75724 m .79337 .73944 L .76439 .73861 L p .707 .577 .707 r
F P
0 g
s
.69897 .74407 m .70246 .72628 L .67557 .716 L p .707 .577 .707 r
F P
0 g
s
.70246 .72628 m .69897 .74407 L .72957 .75186 L p .707 .577 .707 r
F P
0 g
s
.67062 .70548 m .67737 .66982 L .6568 .65823 L p .707 .577 .707 r
F P
0 g
s
.47241 .74797 m .46363 .24522 L .50857 .24342 L p .707 .577 .707 r
F P
0 g
s
.46363 .24522 m .47241 .74797 L .43093 .7533 L p .707 .577 .707 r
F P
0 g
s
.65348 .64884 m .65693 .59374 L .64438 .58446 L p .707 .577 .707 r
F P
0 g
s
.67557 .716 m .67208 .73379 L .69897 .74407 L p .707 .577 .707 r
F P
0 g
s
.50857 .24342 m .51735 .74617 L .47241 .74797 L p .707 .577 .707 r
F P
0 g
s
.79337 .73944 m .78988 .75724 L .81367 .7543 L p .707 .577 .707 r
F P
0 g
s
.81367 .7543 m .81716 .7365 L .79337 .73944 L p .707 .577 .707 r
F P
0 g
s
.6568 .65823 m .65004 .69389 L .67062 .70548 L p .707 .577 .707 r
F P
0 g
s
.67208 .73379 m .67557 .716 L .65503 .70423 L p .707 .577 .707 r
F P
0 g
s
.81912 .68953 m .81236 .7252 L .82865 .71873 L p .707 .577 .707 r
F P
0 g
s
.82865 .71873 m .8354 .68307 L .81912 .68953 L p .707 .577 .707 r
F P
0 g
s
.65503 .70423 m .65153 .72202 L .67208 .73379 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64093 .63955 L .65348 .64884 L p .707 .577 .707 r
F P
0 g
s
.65004 .69389 m .6568 .65823 L .64458 .64627 L p .707 .577 .707 r
F P
0 g
s
.83795 .59934 m .8345 .65444 L .84159 .64577 L p .707 .577 .707 r
F P
0 g
s
.84159 .64577 m .84504 .59067 L .83795 .59934 L p .707 .577 .707 r
F P
0 g
s
.81716 .7365 m .81367 .7543 L .82995 .74786 L p .707 .577 .707 r
F P
0 g
s
.82995 .74786 m .83344 .73007 L .81716 .7365 L p .707 .577 .707 r
F P
0 g
s
.65153 .72202 m .65503 .70423 L .64284 .69213 L p .707 .577 .707 r
F P
0 g
s
.64284 .69213 m .63935 .70992 L .65153 .72202 L p .707 .577 .707 r
F P
0 g
s
.8354 .68307 m .82865 .71873 L .83582 .70946 L p .707 .577 .707 r
F P
0 g
s
.83582 .70946 m .84257 .6738 L .8354 .68307 L p .707 .577 .707 r
F P
0 g
s
.64152 .57502 m .63807 .63011 L .64093 .63955 L p .707 .577 .707 r
F P
0 g
s
.63783 .68193 m .64458 .64627 L .64193 .63511 L p .707 .577 .707 r
F P
0 g
s
.84504 .59067 m .84159 .64577 L .83872 .63633 L p .707 .577 .707 r
F P
0 g
s
.83872 .63633 m .84217 .58123 L .84504 .59067 L p .707 .577 .707 r
F P
0 g
s
.83344 .73007 m .82995 .74786 L .83712 .73856 L p .707 .577 .707 r
F P
0 g
s
.83712 .73856 m .84061 .72077 L .83344 .73007 L p .707 .577 .707 r
F P
0 g
s
.64193 .63511 m .63517 .67077 L .63783 .68193 L p .707 .577 .707 r
F P
0 g
s
.63807 .63011 m .64152 .57502 L .64861 .56634 L p .707 .577 .707 r
F P
0 g
s
.63935 .70992 m .64284 .69213 L .6402 .68088 L p .707 .577 .707 r
F P
0 g
s
.6402 .68088 m .63671 .69867 L .63935 .70992 L p .707 .577 .707 r
F P
0 g
s
.84257 .6738 m .83582 .70946 L .83316 .6983 L p .707 .577 .707 r
F P
0 g
s
.83316 .6983 m .83992 .66264 L .84257 .6738 L p .707 .577 .707 r
F P
0 g
s
.63517 .67077 m .64193 .63511 L .6491 .62584 L p .707 .577 .707 r
F P
0 g
s
.64861 .56634 m .64516 .62144 L .63807 .63011 L p .707 .577 .707 r
F P
0 g
s
.84217 .58123 m .83872 .63633 L .82617 .62704 L p .707 .577 .707 r
F P
0 g
s
.82617 .62704 m .82962 .57195 L .84217 .58123 L p .707 .577 .707 r
F P
0 g
s
.38998 .61458 m .39343 .55948 L .36232 .55563 L p .707 .577 .707 r
F P
0 g
s
.39343 .55948 m .38998 .61458 L .42176 .61556 L p .707 .577 .707 r
F P
0 g
s
.42176 .61556 m .42521 .56047 L .39343 .55948 L p .707 .577 .707 r
F P
0 g
s
.84061 .72077 m .83712 .73856 L .83449 .72731 L p .707 .577 .707 r
F P
0 g
s
.83449 .72731 m .83798 .70952 L .84061 .72077 L p .707 .577 .707 r
F P
0 g
s
.42521 .56047 m .42176 .61556 L .4511 .61358 L p .707 .577 .707 r
F P
0 g
s
.4511 .61358 m .45455 .55849 L .42521 .56047 L p .707 .577 .707 r
F P
0 g
s
.6491 .62584 m .64234 .6615 L .63517 .67077 L p .707 .577 .707 r
F P
0 g
s
.64516 .62144 m .64861 .56634 L .66497 .55929 L p .707 .577 .707 r
F P
0 g
s
.63671 .69867 m .6402 .68088 L .64738 .67158 L p .707 .577 .707 r
F P
0 g
s
.35887 .61073 m .36232 .55563 L .33492 .54929 L p .707 .577 .707 r
F P
0 g
s
.36232 .55563 m .35887 .61073 L .38998 .61458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64738 .67158 m .64388 .68938 L .63671 .69867 L p .707 .577 .707 r
F P
0 g
s
.45455 .55849 m .4511 .61358 L .47513 .60883 L p .707 .577 .707 r
F P
0 g
s
.47513 .60883 m .47858 .55373 L .45455 .55849 L p .707 .577 .707 r
F P
0 g
s
.83992 .66264 m .83316 .6983 L .82095 .68634 L p .707 .577 .707 r
F P
0 g
s
.82095 .68634 m .8277 .65068 L .83992 .66264 L p .707 .577 .707 r
F P
0 g
s
.64234 .6615 m .6491 .62584 L .66538 .61937 L p .707 .577 .707 r
F P
0 g
s
.66497 .55929 m .66152 .61438 L .64516 .62144 L p .707 .577 .707 r
F P
0 g
s
.33147 .60438 m .33492 .54929 L .31392 .54107 L p .707 .577 .707 r
F P
0 g
s
.33492 .54929 m .33147 .60438 L .35887 .61073 L p .707 .577 .707 r
F P
0 g
s
.82962 .57195 m .82617 .62704 L .80517 .61883 L p .707 .577 .707 r
F P
0 g
s
.80517 .61883 m .80862 .56373 L .82962 .57195 L p .707 .577 .707 r
F P
0 g
s
.38518 .68539 m .39194 .64973 L .36129 .64213 L p .707 .577 .707 r
F P
0 g
s
.39194 .64973 m .38518 .68539 L .41654 .68975 L p .707 .577 .707 r
F P
0 g
s
.41654 .68975 m .42329 .65409 L .39194 .64973 L p .707 .577 .707 r
F P
0 g
s
.42329 .65409 m .41654 .68975 L .44554 .69045 L p .707 .577 .707 r
F P
0 g
s
.44554 .69045 m .4523 .65479 L .42329 .65409 L p .707 .577 .707 r
F P
0 g
s
.35454 .67779 m .36129 .64213 L .33436 .63204 L p .707 .577 .707 r
F P
0 g
s
.36129 .64213 m .35454 .67779 L .38518 .68539 L p .707 .577 .707 r
F P
0 g
s
.66152 .61438 m .66497 .55929 L .68899 .55453 L p .707 .577 .707 r
F P
0 g
s
.83798 .70952 m .83449 .72731 L .8223 .71521 L p .707 .577 .707 r
F P
0 g
s
.8223 .71521 m .82579 .69742 L .83798 .70952 L p .707 .577 .707 r
F P
0 g
s
.66538 .61937 m .65863 .65504 L .64234 .6615 L p .707 .577 .707 r
F P
0 g
s
.64388 .68938 m .64738 .67158 L .66366 .66515 L p .707 .577 .707 r
F P
0 g
s
.47858 .55373 m .47513 .60883 L .49149 .60177 L p .707 .577 .707 r
F P
0 g
s
.49149 .60177 m .49494 .54668 L .47858 .55373 L p .707 .577 .707 r
F P
0 g
s
.31392 .54107 m .31047 .59617 L .33147 .60438 L p .707 .577 .707 r
F P
0 g
s
.66366 .66515 m .66016 .68294 L .64388 .68938 L p .707 .577 .707 r
F P
0 g
s
.33436 .63204 m .32761 .66771 L .35454 .67779 L p .707 .577 .707 r
F P
0 g
s
.4523 .65479 m .44554 .69045 L .46935 .68742 L p .707 .577 .707 r
F P
0 g
s
.46935 .68742 m .47611 .65176 L .4523 .65479 L p .707 .577 .707 r
F P
0 g
s
.31047 .59617 m .31392 .54107 L .30137 .53179 L p .707 .577 .707 r
F P
0 g
s
.32761 .66771 m .33436 .63204 L .31379 .62045 L p .707 .577 .707 r
F P
0 g
s
.80862 .56373 m .80517 .61883 L .77777 .61249 L p .707 .577 .707 r
F P
0 g
s
.77777 .61249 m .78122 .55739 L .80862 .56373 L p .707 .577 .707 r
F P
0 g
s
.8277 .65068 m .82095 .68634 L .80037 .67475 L p .707 .577 .707 r
F P
0 g
s
.80037 .67475 m .80713 .63909 L .8277 .65068 L p .707 .577 .707 r
F P
0 g
s
.38656 .74137 m .39006 .72357 L .35945 .71578 L p .707 .577 .707 r
F P
0 g
s
.39006 .72357 m .38656 .74137 L .41789 .7459 L p .707 .577 .707 r
F P
0 g
s
.41789 .7459 m .42138 .72811 L .39006 .72357 L p .707 .577 .707 r
F P
0 g
s
.65863 .65504 m .66538 .61937 L .68919 .61634 L p .707 .577 .707 r
F P
0 g
s
.68899 .55453 m .68554 .60963 L .66152 .61438 L p .707 .577 .707 r
F P
0 g
s
.42138 .72811 m .41789 .7459 L .44687 .74674 L p .707 .577 .707 r
F P
0 g
s
.44687 .74674 m .45036 .72895 L .42138 .72811 L p .707 .577 .707 r
F P
0 g
s
.68554 .60963 m .68899 .55453 L .71833 .55255 L p .707 .577 .707 r
F P
0 g
s
.35596 .73358 m .35945 .71578 L .33256 .7055 L p .707 .577 .707 r
F P
0 g
s
.35945 .71578 m .35596 .73358 L .38656 .74137 L p .707 .577 .707 r
F P
0 g
s
.31379 .62045 m .30703 .65611 L .32761 .66771 L p .707 .577 .707 r
F P
0 g
s
.33256 .7055 m .32907 .72329 L .35596 .73358 L p .707 .577 .707 r
F P
0 g
s
.82579 .69742 m .8223 .71521 L .80175 .70345 L p .707 .577 .707 r
F P
0 g
s
.80175 .70345 m .80525 .68565 L .82579 .69742 L p .707 .577 .707 r
F P
0 g
s
.68919 .61634 m .68244 .652 L .65863 .65504 L p .707 .577 .707 r
F P
0 g
s
.30137 .53179 m .29792 .58689 L .31047 .59617 L p .707 .577 .707 r
F P
0 g
s
.66016 .68294 m .66366 .66515 L .68745 .6622 L p .707 .577 .707 r
F P
0 g
s
.78122 .55739 m .77777 .61249 L .74666 .60863 L p .707 .577 .707 r
F P
0 g
s
.74666 .60863 m .75011 .55354 L .78122 .55739 L p .707 .577 .707 r
F P
0 g
s
.49494 .54668 m .49149 .60177 L .49858 .5931 L p .707 .577 .707 r
F P
0 g
s
.49858 .5931 m .50203 .538 L .49494 .54668 L p .707 .577 .707 r
F P
0 g
s
.71488 .60765 m .71833 .55255 L .75011 .55354 L p .707 .577 .707 r
F P
0 g
s
.71833 .55255 m .71488 .60765 L .68554 .60963 L p .707 .577 .707 r
F P
0 g
s
.47611 .65176 m .46935 .68742 L .48564 .68095 L p .707 .577 .707 r
F P
0 g
s
.48564 .68095 m .49239 .64529 L .47611 .65176 L p .707 .577 .707 r
F P
0 g
s
.45036 .72895 m .44687 .74674 L .47066 .7438 L p .707 .577 .707 r
F P
0 g
s
.47066 .7438 m .47415 .726 L .45036 .72895 L p .707 .577 .707 r
F P
0 g
s
.32907 .72329 m .33256 .7055 L .31202 .69373 L p .707 .577 .707 r
F P
0 g
s
.30703 .65611 m .31379 .62045 L .30157 .60849 L p .707 .577 .707 r
F P
0 g
s
.75011 .55354 m .74666 .60863 L .71488 .60765 L p .707 .577 .707 r
F P
0 g
s
.68745 .6622 m .68395 .68 L .66016 .68294 L p .707 .577 .707 r
F P
0 g
s
.80713 .63909 m .80037 .67475 L .77344 .66466 L p .707 .577 .707 r
F P
0 g
s
.77344 .66466 m .7802 .629 L .80713 .63909 L p .707 .577 .707 r
F P
0 g
s
.68244 .652 m .68919 .61634 L .71819 .61704 L p .707 .577 .707 r
F P
0 g
s
.29792 .58689 m .30137 .53179 L .2985 .52235 L p .707 .577 .707 r
F P
0 g
s
.31202 .69373 m .30852 .71153 L .32907 .72329 L p .707 .577 .707 r
F P
0 g
s
.30157 .60849 m .29482 .64415 L .30703 .65611 L p .707 .577 .707 r
F P
0 g
s
.80525 .68565 m .80175 .70345 L .77486 .69316 L p .707 .577 .707 r
F P
0 g
s
.77486 .69316 m .77836 .67537 L .80525 .68565 L p .707 .577 .707 r
F P
0 g
s
.71819 .61704 m .71144 .6527 L .68244 .652 L p .707 .577 .707 r
F P
0 g
s
.7802 .629 m .77344 .66466 L .7428 .65706 L p .707 .577 .707 r
F P
0 g
s
.7428 .65706 m .74955 .6214 L .7802 .629 L p .707 .577 .707 r
F P
0 g
s
.71144 .6527 m .71819 .61704 L .74955 .6214 L p .707 .577 .707 r
F P
0 g
s
.68395 .68 m .68745 .6622 L .71643 .66304 L p .707 .577 .707 r
F P
0 g
s
.47415 .726 m .47066 .7438 L .48694 .73736 L p .707 .577 .707 r
F P
0 g
s
.48694 .73736 m .49043 .71957 L .47415 .726 L p .707 .577 .707 r
F P
0 g
s
.74955 .6214 m .7428 .65706 L .71144 .6527 L p .707 .577 .707 r
F P
0 g
s
.30852 .71153 m .31202 .69373 L .29983 .68163 L p .707 .577 .707 r
F P
0 g
s
.71643 .66304 m .71293 .68084 L .68395 .68 L p .707 .577 .707 r
F P
0 g
s
.2985 .52235 m .29505 .57745 L .29792 .58689 L p .707 .577 .707 r
F P
0 g
s
.49239 .64529 m .48564 .68095 L .49281 .67169 L p .707 .577 .707 r
F P
0 g
s
.49281 .67169 m .49956 .63603 L .49239 .64529 L p .707 .577 .707 r
F P
0 g
s
.50203 .538 m .49858 .5931 L .49571 .58366 L p .707 .577 .707 r
F P
0 g
s
.49571 .58366 m .49916 .52856 L .50203 .538 L p .707 .577 .707 r
F P
0 g
s
.29482 .64415 m .30157 .60849 L .29892 .59733 L p .707 .577 .707 r
F P
0 g
s
.29983 .68163 m .29634 .69943 L .30852 .71153 L p .707 .577 .707 r
F P
0 g
s
.77836 .67537 m .77486 .69316 L .74426 .68537 L p .707 .577 .707 r
F P
0 g
s
.74426 .68537 m .74775 .66758 L .77836 .67537 L p .707 .577 .707 r
F P
0 g
s
.71293 .68084 m .71643 .66304 L .74775 .66758 L p .707 .577 .707 r
F P
0 g
s
.74775 .66758 m .74426 .68537 L .71293 .68084 L p .707 .577 .707 r
F P
0 g
s
.29505 .57745 m .2985 .52235 L .3056 .51368 L p .707 .577 .707 r
F P
0 g
s
.29892 .59733 m .29216 .63299 L .29482 .64415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49043 .71957 m .48694 .73736 L .49411 .72807 L p .707 .577 .707 r
F P
0 g
s
.49411 .72807 m .4976 .71027 L .49043 .71957 L p .707 .577 .707 r
F P
0 g
s
.29634 .69943 m .29983 .68163 L .29719 .67038 L p .707 .577 .707 r
F P
0 g
s
.3056 .51368 m .30215 .56877 L .29505 .57745 L p .707 .577 .707 r
F P
0 g
s
.29719 .67038 m .2937 .68818 L .29634 .69943 L p .707 .577 .707 r
F P
0 g
s
.49956 .63603 m .49281 .67169 L .49015 .66053 L p .707 .577 .707 r
F P
0 g
s
.49015 .66053 m .49691 .62487 L .49956 .63603 L p .707 .577 .707 r
F P
0 g
s
.29216 .63299 m .29892 .59733 L .30609 .58806 L p .707 .577 .707 r
F P
0 g
s
.49916 .52856 m .49571 .58366 L .48316 .57438 L p .707 .577 .707 r
F P
0 g
s
.48316 .57438 m .48661 .51928 L .49916 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30215 .56877 m .3056 .51368 L .32196 .50662 L p .707 .577 .707 r
F P
0 g
s
.30609 .58806 m .29933 .62372 L .29216 .63299 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4976 .71027 m .49411 .72807 L .49147 .71682 L p .707 .577 .707 r
F P
0 g
s
.49147 .71682 m .49497 .69902 L .4976 .71027 L p .707 .577 .707 r
F P
0 g
s
.2937 .68818 m .29719 .67038 L .30437 .66108 L p .707 .577 .707 r
F P
0 g
s
.32196 .50662 m .31851 .56171 L .30215 .56877 L p .707 .577 .707 r
F P
0 g
s
.30437 .66108 m .30087 .67888 L .2937 .68818 L p .707 .577 .707 r
F P
0 g
s
.49691 .62487 m .49015 .66053 L .47794 .64856 L p .707 .577 .707 r
F P
0 g
s
.47794 .64856 m .48469 .6129 L .49691 .62487 L p .707 .577 .707 r
F P
0 g
s
.48661 .51928 m .48316 .57438 L .46216 .56616 L p .707 .577 .707 r
F P
0 g
s
.46216 .56616 m .46561 .51107 L .48661 .51928 L p .707 .577 .707 r
F P
0 g
s
.29933 .62372 m .30609 .58806 L .32237 .5816 L p .707 .577 .707 r
F P
0 g
s
.31851 .56171 m .32196 .50662 L .34598 .50187 L p .707 .577 .707 r
F P
0 g
s
.32237 .5816 m .31562 .61726 L .29933 .62372 L p .707 .577 .707 r
F P
0 g
s
.49497 .69902 m .49147 .71682 L .47929 .70472 L p .707 .577 .707 r
F P
0 g
s
.47929 .70472 m .48278 .68692 L .49497 .69902 L p .707 .577 .707 r
F P
0 g
s
.46561 .51107 m .46216 .56616 L .43476 .55982 L p .707 .577 .707 r
F P
0 g
s
.43476 .55982 m .43821 .50472 L .46561 .51107 L p .707 .577 .707 r
F P
0 g
s
.30087 .67888 m .30437 .66108 L .32065 .65465 L p .707 .577 .707 r
F P
0 g
s
.34598 .50187 m .34253 .55696 L .31851 .56171 L p .707 .577 .707 r
F P
0 g
s
.48469 .6129 m .47794 .64856 L .45736 .63697 L p .707 .577 .707 r
F P
0 g
s
.45736 .63697 m .46411 .60131 L .48469 .6129 L p .707 .577 .707 r
F P
0 g
s
.34253 .55696 m .34598 .50187 L .37532 .49988 L p .707 .577 .707 r
F P
0 g
s
.31562 .61726 m .32237 .5816 L .34618 .57857 L p .707 .577 .707 r
F P
0 g
s
.32065 .65465 m .31715 .67244 L .30087 .67888 L p .707 .577 .707 r
F P
0 g
s
.43821 .50472 m .43476 .55982 L .40365 .55596 L p .707 .577 .707 r
F P
0 g
s
.40365 .55596 m .4071 .50087 L .43821 .50472 L p .707 .577 .707 r
F P
0 g
s
.37187 .55498 m .37532 .49988 L .4071 .50087 L p .707 .577 .707 r
F P
0 g
s
.37532 .49988 m .37187 .55498 L .34253 .55696 L p .707 .577 .707 r
F P
0 g
s
.34618 .57857 m .33943 .61423 L .31562 .61726 L p .707 .577 .707 r
F P
0 g
s
.4071 .50087 m .40365 .55596 L .37187 .55498 L p .707 .577 .707 r
F P
0 g
s
.48278 .68692 m .47929 .70472 L .45874 .69295 L p .707 .577 .707 r
F P
0 g
s
.45874 .69295 m .46224 .67515 L .48278 .68692 L p .707 .577 .707 r
F P
0 g
s
.46411 .60131 m .45736 .63697 L .43043 .62688 L p .707 .577 .707 r
F P
0 g
s
.43043 .62688 m .43719 .59122 L .46411 .60131 L p .707 .577 .707 r
F P
0 g
s
.31715 .67244 m .32065 .65465 L .34444 .65171 L p .707 .577 .707 r
F P
0 g
s
.33943 .61423 m .34618 .57857 L .37518 .57926 L p .707 .577 .707 r
F P
0 g
s
.34444 .65171 m .34094 .6695 L .31715 .67244 L p .707 .577 .707 r
F P
0 g
s
.37518 .57926 m .36843 .61493 L .33943 .61423 L p .707 .577 .707 r
F P
0 g
s
.43719 .59122 m .43043 .62688 L .39979 .61929 L p .707 .577 .707 r
F P
0 g
s
.39979 .61929 m .40654 .58363 L .43719 .59122 L p .707 .577 .707 r
F P
0 g
s
.36843 .61493 m .37518 .57926 L .40654 .58363 L p .707 .577 .707 r
F P
0 g
s
.40654 .58363 m .39979 .61929 L .36843 .61493 L p .707 .577 .707 r
F P
0 g
s
.46224 .67515 m .45874 .69295 L .43185 .68267 L p .707 .577 .707 r
F P
0 g
s
.43185 .68267 m .43535 .66487 L .46224 .67515 L p .707 .577 .707 r
F P
0 g
s
.34094 .6695 m .34444 .65171 L .37341 .65255 L p .707 .577 .707 r
F P
0 g
s
.37341 .65255 m .36992 .67034 L .34094 .6695 L p .707 .577 .707 r
F P
0 g
s
.43535 .66487 m .43185 .68267 L .40125 .67488 L p .707 .577 .707 r
F P
0 g
s
.40125 .67488 m .40474 .65708 L .43535 .66487 L p .707 .577 .707 r
F P
0 g
s
.36992 .67034 m .37341 .65255 L .40474 .65708 L p .707 .577 .707 r
F P
0 g
s
.40474 .65708 m .40125 .67488 L .36992 .67034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7`00OGoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Ioo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00LGoo1@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000
0`00Kgoo001]Ool40007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH3001/Ool006]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUIVOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol0065ooaL00003FUH005YF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00GGoo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001JOol30005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qo
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001U
Ool005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001D
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Goo6000@goo
001COol00`00FUH00004FUH01000FUIJEUYF3@000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000mOol0
05=oo`03001JEP0000=JEPD00003FUH005YF00EJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=J
EP06001JEUYF001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000`00>Goo001COol01000FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001Goo000005YF00001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00=Woo001COol01P00FUH0
0000FUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP@000AJEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003=oo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01UYF00@005YFFUIJEP<00004FUH005YFFUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<7oo001COol20003
FUH00`00FUIJEP03FUHB0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEP00000^Ool005=oo`8000=JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYFFUH40006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo001EOol01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool003YooaL000Aoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YF00000P001UYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000c
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF
00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000/Ool0035oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP05001JEUYF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00;goo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEPd000=oo`T000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00
FUIJEP02FUHD0003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF1@001EYF00@005YF0000009JEP03001JEP0000<0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYF001JEP00FUH00P001EYF4P0025YF00<005YFFUH015YF10001EYF00@005YFFUIJEP8002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF001JEP<000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50006
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUH005YF00<00003FUH0000000@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP000002FUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000AJEP000000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000MJEP03001J
EUYF009JEP800003FUH005YF009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P001EYF00@005YF
FUH0009JEP03001JEUYF00=JEP<000IJEP@000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001JEUYF
00AJEP8000=JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF0`000UYF00@005YFFUH0009JEP03
001JEUYF009JEPD000MJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP040003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP05001J
EP00001JEP02000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEP000080009JEP04001JEUYF0004FUH5
0007FUH01000FUIJEUYF0`0000=JEP00FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00UYF0`00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000AJEPD000MJ
EP03001JEUYF00AJEP8000EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH015YF1@001EYF0`0025YF00<005YFFUH01UYF
0P000UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00IJEP@000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH025YF
0`0015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF00<005YF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF6@00
15YF00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD000QJEP03001JEUYF00QJEP03
001JEP0000AJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH500000eYF001J
EP06FUH01000FUIJEUYF50001UYF4P000UYF100015YF00<005YFFUH01eYF1@000UYF00<005YF0000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000
FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002io
o`00;7oo00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001JEUYF
009JEP80009JEPD0009JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH0000000`000=JEP03
001JEP0000800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF008000=JEPL000IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<002moo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000EJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEP00001JEP001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP<000=JEP03001JEP0000@0009JEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
02moo`00;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@001EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJ
EP<000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P000UYF0`0000=JEP00FUH04@001UYF0`0000=J
EP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF0`001UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00AJEP04001JEUYF
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH6
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH40006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH?0002FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUH000030005FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH005YF
0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00002P000UYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH010000eYF00<005YFFUH01EYF
00<005YFFUH010001eYF00<005YFFUH00P000eYF1@000UYF0`0000=JEP00FUH025YF1P001eYF00<0
05YFFUH00eYF0`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH30005Ool30006FUH01P00FUIJEP00FUH002eoo`00;Goo00@005YFFUIJ
EP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00800005FUH00000FUH0
0005FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP06FUH40003FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200001EYF001JEUYF
00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001Goo0P0015YF00H005YF
FUH005YF000]Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00D00003FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH70002FUH0
0`00FUH000020004FUH300000eYF001JEP07FUH01000FUIJEP000UYF0P0025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP07FUH00`00FUH000030003Ool01000FUIJEP000eYF00<005YF0000;Goo000^Ool30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP00009JEP03001JEP0000L000=JEP03001JEUYF00<000IJEP03001J
EUYF009JEP8000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH50008FUH00`00FUH0000300000goo000000040008FUH00`00FUIJEP03FUH20002Ool30003
FUH2000^Ool002ioo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000@000IJEP04001JEUYFFUH30002FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF
00=JEPX000AJEP03001JEUYF00EJEP<0009oo`04001JEUYFFUH2000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP04001J
EP000005FUH01000FUIJEUYF0`000eYF00@005YFFUIJEPD00003FUH0000000/00003FUH005YF00EJ
EP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF00@00004
FUH005YF000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH20003FUH01`00FUIJEUYF001oo`0000=JEP03
001JEUYF009JEP<000QJEP03001JEUYF00AJEP8000IJEP03001JEP0000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEPH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF009JEP800005FUH00000FUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300001eYF00000000FUH005YF0080009oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00`000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00D005YF001JEP0002ioo`00;Goo00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00P000UYF0`001Goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF
0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`000eYF00H005YF000005YF0008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH200000eYF001JEP05FUH4000_Ool002eoo`03001JEP00009JEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH300000eYF00000004Ool3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30003FUH20005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP030007FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30006FUH01000FUH00000;goo000/Ool00`00FUH00003FUH40007
Ool90004FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YF00000`000goo0eYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF000015YF10000UYF0P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<007ooOol0
;7oo000/Ool01000FUH005YF0`004goo1`001UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH40000
1GooFUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJ
EP020003FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00Oomoo`0/Ool002aoo`04001JEP000002FUH3000HOol40002FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP<00003FUH005YF00<000IJEP03001JEUYF00<000AJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001oogoo02aoo`00;7oo0P0015YF00<005YF
FUH00P006Woo10001EYF0P0000=JEP00FUH01eYF00<005YF00000`0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000IJEP04001JEP000003FUH50002FUH00`00FUH000040002FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00;Woo000/Ool20003FUH00`00FUIJEP03
FUH3000>Ool3000:Ool20004FUH40007FUH00`00FUIJEP03FUH50009FUH00`00FUIJEP09FUH01@00
FUH00000FUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF00@005YFFUIJEP800003FUH0000000=oo`T0009JEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEP00001oo`04000^Ool002aoo`8000=JEP03001JEUYF00AJEP04001JEP00000;Ool5
000;Ool300000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJ
EP07FUH40003FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH40006Ool<0004FUH01000FUIJEUYF10001Goo0P00;Woo000/
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P002Goo1@003Woo0P001EYF0`0000=J
EP00FUH01eYF00<005YFFUH015YF3`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP06FUH00`00
FUIJEP040003Ool30008Ool80008Ool2000_Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00AJEP@000Eoo`D0011oo`80009JEP04001JEUYFFUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`001UYF00<005YFFUH015YF1@005goo1000;goo
000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool3000C
Ool30004FUH00`00FUH000030002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF0P00
;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH015YF1@005Goo00<005YFFUH0
0UYF0P000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP<0
0003FUH005YF00QJEP03001JEUYF00AJEPh000=JEP06001JEUYF001JEP00;goo000^Ool30006FUH?
0002FUH00`00FUIJEP04000>Ool50002FUH00`00FUH00003FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00<005YFFUH015YF1@001UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P00<7oo000`Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH0
0`00FUIJEP040005FUH>0003FUH00`00FUH0000200000eYF001JEP02FUH00`00FUIJEP03FUH01000
FUIJEUYF3`0000=JEP000000700025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF
FUH015YF0`000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00035oo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH015YF10000eYF
00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF00001Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000039oo`00;goo0P000eYF00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YF00000`001eYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEP0000@000IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=J
EP05001JEUYFFUH0000:Ool40002FUH00`00FUIJEP05FUH01000FUIJEUYF1@00=7oo000^Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000EooeYFFUIJEP0000EJEP03001JEUYF00D000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000>Ool>000iOol002eoo`03001JEP0000=JEP04001J
EUYFFUH>0006FUH00`00FUIJEP06FUH00`00FUH000020006FUH02000FUIJEUYF001JEP00Ool3FUH0
0`00FUIJEP03FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00E7oo000]Ool20003FUH500000goo0000000200000eYF001JEP06FUH40002FUH00`00FUIJEP06
FUH01000FUIJEUYF0`0015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP<00003FUH005YF00EJEP06001JEUYF001JEP00E7oo000]Ool200000eYF0000
000:Ool30008FUH00`00FUH000030006FUH00`00FUIJEP05FUH20002FUH01000FUIJEUYF0P000Woo
0eYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH007oo008000IJEP06001JEUYF001JEP00
E7oo000/Ool01000FUH000003goo0`0015YF00<005YF00000P000UYF10000UYF00<005YFFUH01UYF
0`000eYF0P000goo0eYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=oo`8000=J
EP07001JEUYFFUH005YF0000E7oo000/Ool4000BOol300000eYF000000040003FUH00`00FUH00003
0007FUH00`00FUIJEP030005Ool2FUH01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0`000goo0P0000=JEP00FUH00UYF0P00EGoo000/Ool01000FUH000005Goo1`000eYF00<005YFFUH0
0eYF0P0015YF00<005YFFUH00eYF0P0017oo00=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00@005YFFUH0009JEP8000=oo`8000=JEP8005Eoo`00;7oo0P000UYF00<007ooOol057oo4`00
00=JEP00FUH01EYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000=J
EPL00004FUH005YF001EOol002aoo`8000=JEP03001oogoo01Aoo`<000moo`8000IJEP03001JEP00
009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF0080009J
EP800003FUH007oo05Aoo`00;Goo00@005YFFUIJEP<002Qoo`8000=JEP06001JEUYFFUH007oo0P00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0P0000AJEP00FUH005Eo
o`00;Goo00D005YFFUIJEP00009JEP8002Qoo`800003FUH005YF009JEP04001oogoo0004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200001EYF000005YF00001UYF1000EWoo000^Ool00`00FUH00005
FUH3000WOol20003FUH01000Oomoo`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF0`00
1UYF00@005YF000005Ioo`00;goo0P001UYF00@005YF000002Moo`05001JEP00FUH00002Ool20002
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<0
07ooOol0Dgoo000`Ool00`00FUIJEP04FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool00goo0`00
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF009JEP800003FUH005YF00=JEP03001oogoo05=oo`00<Goo
0P000eYF00<005YFFUH01EYF0`008goo00<005YF00001Woo0`001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@0025YF00<005YFFUH00eYF
0`0015YF00<007ooOol0Dgoo000cOol200000eYF001JEP07FUH00`00FUH00003000NOol200000eYF
001oo`08Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00
EGoo000eOol30007FUH00`00FUIJEP03FUH5000GOol200000eYF0000000>Ool50008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH:0002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH00000Ool01000EGoo000hOol20004FUH00`00FUIJEP06FUH00`00FUIJEP04000?Ool40003
FUH2000COol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@000UYF
00<005YFFUH01UYF00@005YFFUIJEP@000Eoo`8005Eoo`00>Woo0`0000=JEP00FUH01eYF00<005YF
FUH015YF3`000UYF00L005YFFUIJEP00FUH0000IOolO0002FUH00`00FUIJEP040002OolD0008Ool3
001EOol003eoo`<000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
FUH2000bOol30006FUH00`00FUIJEP04FUH6000FOol4001FOol0041oo`@0009JEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000fOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP04000>Ool50002FUH2001FOol004Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00000jOol200000eYF001JEP08FUH00`00FUIJEP04FUH>0003FUH01P00FUIJEP00FUH0
05Ioo`00BGoo10000UYF00<005YFFUH01UYF00@005YFFUIJEP@003ioo`@000IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Moo`00CGoo3`00AWoo10000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0005Qoo`00YWoo1@001UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Uoo`00Zgoo10000UYF00<005YFFUH01EYF
00@005YFFUIJEPD005]oo`00[goo3P00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59552 .76527 m .6011 .71059 L .57008 .70554 L p .707 .577 .707 r
F P
0 g
s
.6011 .71059 m .59552 .76527 L .62721 .76733 L p .707 .577 .707 r
F P
0 g
s
.62721 .76733 m .63279 .71265 L .6011 .71059 L p .707 .577 .707 r
F P
0 g
s
.63279 .71265 m .62721 .76733 L .65648 .76621 L p .707 .577 .707 r
F P
0 g
s
.65648 .76621 m .66206 .71153 L .63279 .71265 L p .707 .577 .707 r
F P
0 g
s
.56451 .76022 m .57008 .70554 L .54278 .698 L p .707 .577 .707 r
F P
0 g
s
.57008 .70554 m .56451 .76022 L .59552 .76527 L p .707 .577 .707 r
F P
0 g
s
.66206 .71153 m .65648 .76621 L .68046 .76201 L p .707 .577 .707 r
F P
0 g
s
.68046 .76201 m .68604 .70732 L .66206 .71153 L p .707 .577 .707 r
F P
0 g
s
.53721 .75268 m .54278 .698 L .52187 .6887 L p .707 .577 .707 r
F P
0 g
s
.54278 .698 m .53721 .75268 L .56451 .76022 L p .707 .577 .707 r
F P
0 g
s
.58734 .81804 m .59816 .78389 L .56837 .77292 L p .707 .577 .707 r
F P
0 g
s
.59816 .78389 m .58734 .81804 L .61793 .82544 L p .707 .577 .707 r
F P
0 g
s
.61793 .82544 m .62876 .79129 L .59816 .78389 L p .707 .577 .707 r
F P
0 g
s
.55755 .80707 m .56837 .77292 L .54229 .75946 L p .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56542 .81049 L .56176 .80855 L p .707 .577 .707 r
F P
0 g
s
.56837 .77292 m .55755 .80707 L .56174 .80861 L p .707 .577 .707 r
F P
0 g
s
.57115 .77952 m .56837 .77292 L .56174 .80861 L .707 .577 .707 r
F
.54229 .75946 m .53147 .79361 L .55755 .80707 L p F P
0 g
s
.56176 .80855 m .53943 .79673 L p .55701 .82324 L .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56176 .80855 L .55701 .82324 L .707 .577 .707 r
F
.56174 .80861 m .58734 .81804 L p .57115 .77952 L F P
0 g
s
.62876 .79129 m .61793 .82544 L .64633 .82856 L p .707 .577 .707 r
F P
0 g
s
.64633 .82856 m .65715 .79441 L .62876 .79129 L p .707 .577 .707 r
F P
0 g
s
.58952 .83875 m .59511 .82176 L .56542 .81049 L p .707 .577 .707 r
F P
0 g
s
.59511 .82176 m .58952 .83875 L .62002 .84643 L p .707 .577 .707 r
F P
0 g
s
.62002 .84643 m .62562 .82943 L .59511 .82176 L p .707 .577 .707 r
F P
0 g
s
.56542 .81049 m .55982 .82748 L .58952 .83875 L p .707 .577 .707 r
F P
0 g
s
.68604 .70732 m .68046 .76201 L .6968 .75514 L p .707 .577 .707 r
F P
0 g
s
.6968 .75514 m .70238 .70046 L .68604 .70732 L p .707 .577 .707 r
F P
0 g
s
.52187 .6887 m .5163 .74339 L .52659 .74796 L p .707 .577 .707 r
F P
0 g
s
.52659 .74796 m .53721 .75268 L p .53305 .73533 L .707 .577 .707 r
F P
0 g
s
.53305 .73533 m .52187 .6887 L .52659 .74796 L .707 .577 .707 r
F
.5163 .74339 m .52187 .6887 L .50939 .67857 L p F P
0 g
s
.50939 .67857 m .50382 .73325 L .51101 .73909 L p .707 .577 .707 r
F P
0 g
s
.51101 .73909 m .5163 .74339 L p .5149 .7303 L .707 .577 .707 r
F P
0 g
s
.5149 .7303 m .50939 .67857 L .51101 .73909 L .707 .577 .707 r
F
.51087 .73044 m .50861 .71773 L p .50029 .76331 L F P
0 g
s
.50005 .76459 m .50089 .76194 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.50089 .76194 m .51087 .73044 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51087 .73044 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51166 .77897 m .51315 .77426 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51315 .77426 m .52248 .74482 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.53147 .79361 m .54229 .75946 L .52248 .74482 L p .707 .577 .707 r
F P
0 g
s
.62562 .82943 m .62002 .84643 L .64835 .84976 L p .707 .577 .707 r
F P
0 g
s
.64835 .84976 m .65394 .83276 L .62562 .82943 L p .707 .577 .707 r
F P
0 g
s
.65715 .79441 m .64633 .82856 L .66975 .82708 L p .707 .577 .707 r
F P
0 g
s
.66975 .82708 m .68057 .79292 L .65715 .79441 L p .707 .577 .707 r
F P
0 g
s
.53943 .79673 m .53384 .81372 L .55982 .82748 L p .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51166 .77897 L .53147 .79361 L p .707 .577 .707 r
F P
0 g
s
.53384 .81372 m .53943 .79673 L .51971 .78182 L p .707 .577 .707 r
F P
0 g
s
.65394 .83276 m .64835 .84976 L .67172 .84841 L p .707 .577 .707 r
F P
0 g
s
.67172 .84841 m .67732 .83142 L .65394 .83276 L p .707 .577 .707 r
F P
0 g
s
.51971 .78182 m .51412 .79882 L .53384 .81372 L p .707 .577 .707 r
F P
0 g
s
.68057 .79292 m .66975 .82708 L .6859 .82114 L p .707 .577 .707 r
F P
0 g
s
.6859 .82114 m .69672 .78699 L .68057 .79292 L p .707 .577 .707 r
F P
0 g
s
.70238 .70046 m .6968 .75514 L .70391 .74627 L p .707 .577 .707 r
F P
0 g
s
.70391 .74627 m .70949 .69159 L .70238 .70046 L p .707 .577 .707 r
F P
0 g
s
.51087 .73044 m .50005 .76459 L .51166 .77897 L p .707 .577 .707 r
F P
0 g
s
.51412 .79882 m .51971 .78182 L .50817 .76723 L p .707 .577 .707 r
F P
0 g
s
.50382 .73325 m .50939 .67857 L .50657 .66858 L p .707 .577 .707 r
F P
0 g
s
.67732 .83142 m .67172 .84841 L .68786 .84253 L p .707 .577 .707 r
F P
0 g
s
.68786 .84253 m .69345 .82554 L .67732 .83142 L p .707 .577 .707 r
F P
0 g
s
.50817 .76723 m .50258 .78422 L .51412 .79882 L p .707 .577 .707 r
F P
0 g
s
.50269 .72925 m .50382 .73325 L p .50432 .7215 L .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .49779 .75188 L .50005 .76459 L p .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .51591 .70793 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49779 .75188 m .49821 .75054 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49821 .75054 m .50861 .71773 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.50657 .66858 m .50099 .72326 L .50269 .72925 L p .707 .577 .707 r
F P
0 g
s
.50432 .7215 m .50657 .66858 L .50269 .72925 L .707 .577 .707 r
F
.69672 .78699 m .6859 .82114 L .6932 .81134 L p F P
0 g
s
.6932 .81134 m .70402 .77719 L .69672 .78699 L p .707 .577 .707 r
F P
0 g
s
.70949 .69159 m .70391 .74627 L .70109 .73628 L p .707 .577 .707 r
F P
0 g
s
.70109 .73628 m .70666 .6816 L .70949 .69159 L p .707 .577 .707 r
F P
0 g
s
.50258 .78422 m .50817 .76723 L .50595 .75438 L p .707 .577 .707 r
F P
0 g
s
.50595 .75438 m .50036 .77137 L .50258 .78422 L p .707 .577 .707 r
F P
0 g
s
.50036 .77137 m .50595 .75438 L .51327 .74453 L p .707 .577 .707 r
F P
0 g
s
.51591 .70793 m .50537 .74119 L p .49779 .75188 L .707 .577 .707 r
F P
0 g
s
.50537 .74119 m .50509 .74208 L .50494 .74228 L p .707 .577 .707 r
F P
0 g
s
.50494 .74228 m .49779 .75188 L p .50537 .74119 L .707 .577 .707 r
F P
0 g
s
.53002 .65284 m .52644 .68793 L p .5081 .71439 L .707 .577 .707 r
F P
0 g
s
.50509 .74208 m .51591 .70793 L .53206 .702 L p .707 .577 .707 r
F P
0 g
s
.52644 .68793 m .52445 .70753 L .51754 .71043 L p .707 .577 .707 r
F P
0 g
s
.51754 .71043 m .5081 .71439 L p .52644 .68793 L .707 .577 .707 r
F P
0 g
s
.51327 .74453 m .50768 .76153 L .50036 .77137 L p .707 .577 .707 r
F P
0 g
s
.503 .82182 m .4888 .31862 L .44481 .3172 L p .707 .577 .707 r
F P
0 g
s
.50099 .72326 m .50657 .66858 L .51368 .65971 L p .707 .577 .707 r
F P
0 g
s
.51368 .65971 m .5081 .71439 L .50099 .72326 L p .707 .577 .707 r
F P
0 g
s
.5081 .71439 m .51368 .65971 L .53002 .65284 L p .707 .577 .707 r
F P
0 g
s
.50768 .76153 m .51327 .74453 L .52941 .73865 L p .707 .577 .707 r
F P
0 g
s
.53206 .702 m .52166 .73481 L p .50509 .74208 L .707 .577 .707 r
F P
0 g
s
.52166 .73481 m .52124 .73615 L .5208 .73631 L p .707 .577 .707 r
F P
0 g
s
.5208 .73631 m .50509 .74208 L p .52166 .73481 L .707 .577 .707 r
F P
0 g
s
.554 .64864 m .55028 .68514 L p .52445 .70753 L .707 .577 .707 r
F P
0 g
s
.52124 .73615 m .53206 .702 L .55548 .70052 L p .707 .577 .707 r
F P
0 g
s
.55028 .68514 m .54843 .70332 L .53884 .705 L p .707 .577 .707 r
F P
0 g
s
.53884 .705 m .52445 .70753 L p .55028 .68514 L .707 .577 .707 r
F P
0 g
s
.52445 .70753 m .53002 .65284 L .554 .64864 L p .707 .577 .707 r
F P
0 g
s
.52941 .73865 m .52381 .75564 L .50768 .76153 L p .707 .577 .707 r
F P
0 g
s
.52381 .75564 m .52941 .73865 L .55278 .7373 L p .707 .577 .707 r
F P
0 g
s
.55548 .70052 m .5455 .73201 L p .52124 .73615 L .707 .577 .707 r
F P
0 g
s
.5455 .73201 m .54466 .73467 L .54366 .73473 L p .707 .577 .707 r
F P
0 g
s
.54366 .73473 m .52124 .73615 L p .5455 .73201 L .707 .577 .707 r
F P
0 g
s
.58327 .64752 m .57985 .68111 L p .54843 .70332 L .707 .577 .707 r
F P
0 g
s
.54466 .73467 m .55548 .70052 L .58388 .70363 L p .707 .577 .707 r
F P
0 g
s
.57985 .68111 m .5777 .7022 L .5653 .70267 L p .707 .577 .707 r
F P
0 g
s
.5653 .70267 m .54843 .70332 L p .57985 .68111 L .707 .577 .707 r
F P
0 g
s
.55278 .7373 m .54719 .7543 L .52381 .75564 L p .707 .577 .707 r
F P
0 g
s
.4888 .31862 m .503 .82182 L .54793 .81958 L p .707 .577 .707 r
F P
0 g
s
.58388 .70363 m .57739 .72412 L p .54466 .73467 L .707 .577 .707 r
F P
0 g
s
.57739 .72412 m .57305 .73778 L .56677 .7371 L p .707 .577 .707 r
F P
0 g
s
.56677 .7371 m .54466 .73467 L p .57739 .72412 L .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .4888 .31862 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54793 .81958 m .54631 .76213 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54631 .76213 m .53373 .31639 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.69345 .82554 m .68786 .84253 L .69518 .83268 L p .707 .577 .707 r
F P
0 g
s
.69518 .83268 m .70077 .81569 L .69345 .82554 L p .707 .577 .707 r
F P
0 g
s
.54843 .70332 m .554 .64864 L .58327 .64752 L p .707 .577 .707 r
F P
0 g
s
.54719 .7543 m .55278 .7373 L .58111 .74063 L p .707 .577 .707 r
F P
0 g
s
.57305 .73778 m .58388 .70363 L .61447 .71104 L p .707 .577 .707 r
F P
0 g
s
.58111 .74063 m .57551 .75763 L .54719 .7543 L p .707 .577 .707 r
F P
0 g
s
.61447 .71104 m .60365 .74519 L .57305 .73778 L p .707 .577 .707 r
F P
0 g
s
.57551 .75763 m .58111 .74063 L .61161 .74831 L p .707 .577 .707 r
F P
0 g
s
.61161 .74831 m .60602 .7653 L .57551 .75763 L p .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .54793 .81958 L .5894 .81391 L p .707 .577 .707 r
F P
0 g
s
.5777 .7022 m .58327 .64752 L .61496 .64958 L p .707 .577 .707 r
F P
0 g
s
.61496 .64958 m .60939 .70426 L .5777 .7022 L p .707 .577 .707 r
F P
0 g
s
.5894 .81391 m .5752 .31071 L .53373 .31639 L p .707 .577 .707 r
F P
0 g
s
.45901 .8204 m .44481 .3172 L .40606 .31226 L p .707 .577 .707 r
F P
0 g
s
.44481 .3172 m .45901 .8204 L .503 .82182 L p .707 .577 .707 r
F P
0 g
s
.64598 .65463 m .6404 .70931 L .60939 .70426 L p .707 .577 .707 r
F P
0 g
s
.60939 .70426 m .61496 .64958 L .64598 .65463 L p .707 .577 .707 r
F P
0 g
s
.64426 .72201 m .63344 .75616 L .60365 .74519 L p .707 .577 .707 r
F P
0 g
s
.60365 .74519 m .61447 .71104 L .64426 .72201 L p .707 .577 .707 r
F P
0 g
s
.67034 .73547 m .65952 .76962 L .63711 .75805 L p .707 .577 .707 r
F P
0 g
s
.64131 .75958 m .63572 .77657 L .63163 .77502 L p .707 .577 .707 r
F P
0 g
s
.63163 .77502 m .60602 .7653 L p .63636 .76038 L .707 .577 .707 r
F P
0 g
s
.63636 .76038 m .64131 .75958 L .63163 .77502 L .707 .577 .707 r
F
.63867 .75323 m .67034 .73547 L .63711 .75805 L F
.60602 .7653 m .61161 .74831 L .64131 .75958 L p F P
0 g
s
.63711 .75805 m .63344 .75616 L p .63867 .75323 L .707 .577 .707 r
F P
0 g
s
.5752 .31071 m .5894 .81391 L .62335 .80535 L p .707 .577 .707 r
F P
0 g
s
.62335 .80535 m .60915 .30216 L .5752 .31071 L p .707 .577 .707 r
F P
0 g
s
.70402 .77719 m .6932 .81134 L .69094 .79863 L p .707 .577 .707 r
F P
0 g
s
.69094 .79863 m .70176 .76448 L .70402 .77719 L p .707 .577 .707 r
F P
0 g
s
.70666 .6816 m .70109 .73628 L .68861 .72615 L p .707 .577 .707 r
F P
0 g
s
.68861 .72615 m .69419 .67146 L .70666 .6816 L p .707 .577 .707 r
F P
0 g
s
.25251 .70281 m .25809 .64812 L .22707 .64307 L p .707 .577 .707 r
F P
0 g
s
.25809 .64812 m .25251 .70281 L .2842 .70487 L p .707 .577 .707 r
F P
0 g
s
.2842 .70487 m .28978 .65019 L .25809 .64812 L p .707 .577 .707 r
F P
0 g
s
.28978 .65019 m .2842 .70487 L .31347 .70374 L p .707 .577 .707 r
F P
0 g
s
.31347 .70374 m .31905 .64906 L .28978 .65019 L p .707 .577 .707 r
F P
0 g
s
.2215 .69776 m .22707 .64307 L .19978 .63553 L p .707 .577 .707 r
F P
0 g
s
.22707 .64307 m .2215 .69776 L .25251 .70281 L p .707 .577 .707 r
F P
0 g
s
.42026 .81546 m .40606 .31226 L .37635 .30429 L p .707 .577 .707 r
F P
0 g
s
.40606 .31226 m .42026 .81546 L .45901 .8204 L p .707 .577 .707 r
F P
0 g
s
.70077 .81569 m .69518 .83268 L .69296 .81983 L p .707 .577 .707 r
F P
0 g
s
.69296 .81983 m .69855 .80284 L .70077 .81569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31905 .64906 m .31347 .70374 L .33745 .69954 L p .707 .577 .707 r
F P
0 g
s
.33745 .69954 m .34303 .64486 L .31905 .64906 L p .707 .577 .707 r
F P
0 g
s
.1942 .69022 m .19978 .63553 L .17886 .62624 L p .707 .577 .707 r
F P
0 g
s
.19978 .63553 m .1942 .69022 L .2215 .69776 L p .707 .577 .707 r
F P
0 g
s
.63344 .75616 m .64426 .72201 L .67034 .73547 L p .707 .577 .707 r
F P
0 g
s
.69015 .75011 m .67933 .78426 L .65952 .76962 L p .707 .577 .707 r
F P
0 g
s
.66729 .77334 m .6617 .79034 L .63572 .77657 L p .707 .577 .707 r
F P
0 g
s
.65952 .76962 m .67034 .73547 L .69015 .75011 L p .707 .577 .707 r
F P
0 g
s
.63572 .77657 m .64131 .75958 L .66729 .77334 L p .707 .577 .707 r
F P
0 g
s
.60915 .30216 m .62335 .80535 L .64645 .79475 L p .707 .577 .707 r
F P
0 g
s
.67327 .66217 m .6677 .71685 L .6404 .70931 L p .707 .577 .707 r
F P
0 g
s
.6404 .70931 m .64598 .65463 L .67327 .66217 L p .707 .577 .707 r
F P
0 g
s
.64645 .79475 m .63225 .29155 L .60915 .30216 L p .707 .577 .707 r
F P
0 g
s
.70176 .76448 m .69094 .79863 L .67933 .78426 L p .707 .577 .707 r
F P
0 g
s
.67933 .78426 m .69015 .75011 L .70176 .76448 L p .707 .577 .707 r
F P
0 g
s
.69419 .67146 m .68861 .72615 L .6677 .71685 L p .707 .577 .707 r
F P
0 g
s
.6677 .71685 m .67327 .66217 L .69419 .67146 L p .707 .577 .707 r
F P
0 g
s
.24433 .77967 m .25516 .74552 L .22536 .73455 L p .707 .577 .707 r
F P
0 g
s
.25516 .74552 m .24433 .77967 L .27492 .78707 L p .707 .577 .707 r
F P
0 g
s
.27492 .78707 m .28575 .75292 L .25516 .74552 L p .707 .577 .707 r
F P
0 g
s
.21454 .7687 m .22536 .73455 L .19928 .72109 L p .707 .577 .707 r
F P
0 g
s
.22536 .73455 m .21454 .7687 L .24433 .77967 L p .707 .577 .707 r
F P
0 g
s
.28575 .75292 m .27492 .78707 L .30332 .79019 L p .707 .577 .707 r
F P
0 g
s
.30332 .79019 m .31414 .75604 L .28575 .75292 L p .707 .577 .707 r
F P
0 g
s
.69855 .80284 m .69296 .81983 L .68142 .80524 L p .707 .577 .707 r
F P
0 g
s
.68142 .80524 m .68702 .78825 L .69855 .80284 L p .707 .577 .707 r
F P
0 g
s
.34303 .64486 m .33745 .69954 L .3538 .69267 L p .707 .577 .707 r
F P
0 g
s
.3538 .69267 m .35937 .63799 L .34303 .64486 L p .707 .577 .707 r
F P
0 g
s
.17886 .62624 m .17329 .68092 L .1942 .69022 L p .707 .577 .707 r
F P
0 g
s
.39055 .80749 m .37635 .30429 L .35859 .29406 L p .707 .577 .707 r
F P
0 g
s
.37635 .30429 m .39055 .80749 L .42026 .81546 L p .707 .577 .707 r
F P
0 g
s
.17329 .68092 m .17886 .62624 L .16638 .6161 L p .707 .577 .707 r
F P
0 g
s
.18846 .75524 m .19928 .72109 L .17947 .70645 L p .707 .577 .707 r
F P
0 g
s
.19928 .72109 m .18846 .75524 L .21454 .7687 L p .707 .577 .707 r
F P
0 g
s
.31414 .75604 m .30332 .79019 L .32674 .78871 L p .707 .577 .707 r
F P
0 g
s
.32674 .78871 m .33756 .75455 L .31414 .75604 L p .707 .577 .707 r
F P
0 g
s
.24651 .84452 m .2521 .82753 L .22241 .81626 L p .707 .577 .707 r
F P
0 g
s
.2521 .82753 m .24651 .84452 L .27701 .8522 L p .707 .577 .707 r
F P
0 g
s
.27701 .8522 m .28261 .8352 L .2521 .82753 L p .707 .577 .707 r
F P
0 g
s
.21681 .83325 m .22241 .81626 L .19642 .8025 L p .707 .577 .707 r
F P
0 g
s
.22241 .81626 m .21681 .83325 L .24651 .84452 L p .707 .577 .707 r
F P
0 g
s
.28261 .8352 m .27701 .8522 L .30534 .85553 L p .707 .577 .707 r
F P
0 g
s
.30534 .85553 m .31093 .83853 L .28261 .8352 L p .707 .577 .707 r
F P
0 g
s
.17947 .70645 m .16865 .7406 L .18846 .75524 L p .707 .577 .707 r
F P
0 g
s
.63225 .29155 m .64645 .79475 L .65645 .78314 L p .707 .577 .707 r
F P
0 g
s
.65645 .78314 m .64225 .27994 L .63225 .29155 L p .707 .577 .707 r
F P
0 g
s
.16638 .6161 m .16081 .67078 L .17329 .68092 L p .707 .577 .707 r
F P
0 g
s
.68702 .78825 m .68142 .80524 L .6617 .79034 L p .707 .577 .707 r
F P
0 g
s
.6617 .79034 m .66729 .77334 L .68702 .78825 L p .707 .577 .707 r
F P
0 g
s
.19642 .8025 m .19083 .81949 L .21681 .83325 L p .707 .577 .707 r
F P
0 g
s
.35937 .63799 m .3538 .69267 L .3609 .68381 L p .707 .577 .707 r
F P
0 g
s
.3609 .68381 m .36648 .62913 L .35937 .63799 L p .707 .577 .707 r
F P
0 g
s
.16865 .7406 m .17947 .70645 L .16786 .69207 L p .707 .577 .707 r
F P
0 g
s
.19083 .81949 m .19642 .8025 L .1767 .78759 L p .707 .577 .707 r
F P
0 g
s
.33756 .75455 m .32674 .78871 L .34289 .78277 L p .707 .577 .707 r
F P
0 g
s
.34289 .78277 m .35371 .74862 L .33756 .75455 L p .707 .577 .707 r
F P
0 g
s
.16081 .67078 m .16638 .6161 L .16356 .60611 L p .707 .577 .707 r
F P
0 g
s
.31093 .83853 m .30534 .85553 L .32872 .85418 L p .707 .577 .707 r
F P
0 g
s
.32872 .85418 m .33431 .83719 L .31093 .83853 L p .707 .577 .707 r
F P
0 g
s
.1767 .78759 m .17111 .80458 L .19083 .81949 L p .707 .577 .707 r
F P
0 g
s
.16786 .69207 m .15704 .72622 L .16865 .7406 L p .707 .577 .707 r
F P
0 g
s
.37279 .79726 m .35859 .29406 L .35451 .28258 L p .707 .577 .707 r
F P
0 g
s
.35859 .29406 m .37279 .79726 L .39055 .80749 L p .707 .577 .707 r
F P
0 g
s
.16356 .60611 m .15799 .66079 L .16081 .67078 L p .707 .577 .707 r
F P
0 g
s
.17111 .80458 m .1767 .78759 L .16516 .773 L p .707 .577 .707 r
F P
0 g
s
.15704 .72622 m .16786 .69207 L .1656 .67936 L p .707 .577 .707 r
F P
0 g
s
.36648 .62913 m .3609 .68381 L .35808 .67382 L p .707 .577 .707 r
F P
0 g
s
.35808 .67382 m .36366 .61914 L .36648 .62913 L p .707 .577 .707 r
F P
0 g
s
.33431 .83719 m .32872 .85418 L .34485 .8483 L p .707 .577 .707 r
F P
0 g
s
.34485 .8483 m .35044 .8313 L .33431 .83719 L p .707 .577 .707 r
F P
0 g
s
.16516 .773 m .15957 .78999 L .17111 .80458 L p .707 .577 .707 r
F P
0 g
s
.35371 .74862 m .34289 .78277 L .35019 .77297 L p .707 .577 .707 r
F P
0 g
s
.35019 .77297 m .36101 .73882 L .35371 .74862 L p .707 .577 .707 r
F P
0 g
s
.15799 .66079 m .16356 .60611 L .17067 .59725 L p .707 .577 .707 r
F P
0 g
s
.64225 .27994 m .65645 .78314 L .65428 .77704 L p .707 .577 .707 r
F P
0 g
s
.65428 .77704 m .65255 .77216 L p .65209 .75001 L .707 .577 .707 r
F P
0 g
s
.65209 .75001 m .64225 .27994 L .65428 .77704 L .707 .577 .707 r
F
.65228 .76689 m .64225 .27994 L .65255 .77216 L F
.65237 .77166 m .63817 .26847 L .64225 .27994 L p F P
0 g
s
.63817 .26847 m .65237 .77166 L .63461 .76144 L p .707 .577 .707 r
F P
0 g
s
.65908 .59667 m .6535 .65135 L .6638 .65592 L p .707 .577 .707 r
F P
0 g
s
.6638 .65592 m .67441 .66064 L p .67025 .64329 L .707 .577 .707 r
F P
0 g
s
.67025 .64329 m .65908 .59667 L .6638 .65592 L .707 .577 .707 r
F
.6466 .58653 m .64411 .61091 L p .6535 .65135 L F P
0 g
s
.64591 .64518 m .6535 .65135 L p .64411 .61091 L .707 .577 .707 r
F P
0 g
s
.6535 .65135 m .65908 .59667 L .6466 .58653 L p .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64808 .63841 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.64886 .68693 m .65035 .68222 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65035 .68222 m .65968 .65278 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64886 .68693 L .66867 .70157 L p .707 .577 .707 r
F P
0 g
s
.64808 .63841 m .63725 .67256 L .64886 .68693 L p .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .65691 .68978 L .64608 .67608 L p .707 .577 .707 r
F P
0 g
s
.64608 .67608 m .64538 .67519 L p .64649 .68109 L .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .64608 .67608 L .64649 .68109 L .707 .577 .707 r
F
.64411 .61091 m .64102 .64121 L .64591 .64518 L p F P
0 g
s
.65255 .77216 m .65237 .77166 L p .65228 .76689 L .707 .577 .707 r
F P
0 g
s
.1656 .67936 m .15478 .71351 L .15704 .72622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15957 .78999 m .16516 .773 L .16295 .76015 L p .707 .577 .707 r
F P
0 g
s
.17067 .59725 m .16509 .65193 L .15799 .66079 L p .707 .577 .707 r
F P
0 g
s
.15478 .71351 m .1656 .67936 L .1729 .66956 L p .707 .577 .707 r
F P
0 g
s
.35044 .8313 m .34485 .8483 L .35217 .83845 L p .707 .577 .707 r
F P
0 g
s
.35217 .83845 m .35776 .82146 L .35044 .8313 L p .707 .577 .707 r
F P
0 g
s
.16295 .76015 m .15735 .77714 L .15957 .78999 L p .707 .577 .707 r
F P
0 g
s
.35451 .28258 m .36871 .78578 L .37279 .79726 L p .707 .577 .707 r
F P
0 g
s
.36871 .78578 m .35451 .28258 L .36451 .27097 L p .707 .577 .707 r
F P
0 g
s
.36366 .61914 m .35808 .67382 L .3456 .66368 L p .707 .577 .707 r
F P
0 g
s
.3456 .66368 m .35118 .609 L .36366 .61914 L p .707 .577 .707 r
F P
0 g
s
.36101 .73882 m .35019 .77297 L .34793 .76026 L p .707 .577 .707 r
F P
0 g
s
.34793 .76026 m .35875 .72611 L .36101 .73882 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16509 .65193 m .17067 .59725 L .18701 .59038 L p .707 .577 .707 r
F P
0 g
s
.1729 .66956 m .16208 .70371 L .15478 .71351 L p .707 .577 .707 r
F P
0 g
s
.15735 .77714 m .16295 .76015 L .17026 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63461 .76144 m .62041 .25824 L .63817 .26847 L p .707 .577 .707 r
F P
0 g
s
.18701 .59038 m .18144 .64506 L .16509 .65193 L p .707 .577 .707 r
F P
0 g
s
.16208 .70371 m .1729 .66956 L .18905 .66363 L p .707 .577 .707 r
F P
0 g
s
.35776 .82146 m .35217 .83845 L .34995 .8256 L p .707 .577 .707 r
F P
0 g
s
.34995 .8256 m .35554 .80861 L .35776 .82146 L p .707 .577 .707 r
F P
0 g
s
.17026 .7503 m .16467 .76729 L .15735 .77714 L p .707 .577 .707 r
F P
0 g
s
.35118 .609 m .3456 .66368 L .32469 .65439 L p .707 .577 .707 r
F P
0 g
s
.32469 .65439 m .33027 .59971 L .35118 .609 L p .707 .577 .707 r
F P
0 g
s
.35875 .72611 m .34793 .76026 L .33632 .74589 L p .707 .577 .707 r
F P
0 g
s
.33632 .74589 m .34715 .71173 L .35875 .72611 L p .707 .577 .707 r
F P
0 g
s
.18144 .64506 m .18701 .59038 L .21099 .58618 L p .707 .577 .707 r
F P
0 g
s
.18905 .66363 m .17823 .69778 L .16208 .70371 L p .707 .577 .707 r
F P
0 g
s
.37871 .77417 m .36451 .27097 L .38762 .26037 L p .707 .577 .707 r
F P
0 g
s
.36451 .27097 m .37871 .77417 L .36871 .78578 L p .707 .577 .707 r
F P
0 g
s
.16467 .76729 m .17026 .7503 L .1864 .74442 L p .707 .577 .707 r
F P
0 g
s
.33027 .59971 m .32469 .65439 L .29739 .64685 L p .707 .577 .707 r
F P
0 g
s
.29739 .64685 m .30297 .59216 L .33027 .59971 L p .707 .577 .707 r
F P
0 g
s
.21099 .58618 m .20542 .64086 L .18144 .64506 L p .707 .577 .707 r
F P
0 g
s
.17823 .69778 m .18905 .66363 L .21247 .66215 L p .707 .577 .707 r
F P
0 g
s
.20542 .64086 m .21099 .58618 L .24026 .58505 L p .707 .577 .707 r
F P
0 g
s
.35554 .80861 m .34995 .8256 L .33841 .81101 L p .707 .577 .707 r
F P
0 g
s
.33841 .81101 m .34401 .79402 L .35554 .80861 L p .707 .577 .707 r
F P
0 g
s
.1864 .74442 m .1808 .76141 L .16467 .76729 L p .707 .577 .707 r
F P
0 g
s
.34715 .71173 m .33632 .74589 L .31651 .73125 L p .707 .577 .707 r
F P
0 g
s
.31651 .73125 m .32733 .6971 L .34715 .71173 L p .707 .577 .707 r
F P
0 g
s
.62041 .25824 m .63461 .76144 L .6049 .75346 L p .707 .577 .707 r
F P
0 g
s
.6049 .75346 m .5907 .25027 L .62041 .25824 L p .707 .577 .707 r
F P
0 g
s
.30297 .59216 m .29739 .64685 L .26638 .6418 L p .707 .577 .707 r
F P
0 g
s
.26638 .6418 m .27195 .58712 L .30297 .59216 L p .707 .577 .707 r
F P
0 g
s
.23469 .63973 m .24026 .58505 L .27195 .58712 L p .707 .577 .707 r
F P
0 g
s
.24026 .58505 m .23469 .63973 L .20542 .64086 L p .707 .577 .707 r
F P
0 g
s
.21247 .66215 m .20165 .6963 L .17823 .69778 L p .707 .577 .707 r
F P
0 g
s
.27195 .58712 m .26638 .6418 L .23469 .63973 L p .707 .577 .707 r
F P
0 g
s
.20165 .6963 m .21247 .66215 L .24087 .66526 L p .707 .577 .707 r
F P
0 g
s
.1808 .76141 m .1864 .74442 L .20977 .74307 L p .707 .577 .707 r
F P
0 g
s
.32733 .6971 m .31651 .73125 L .29043 .71779 L p .707 .577 .707 r
F P
0 g
s
.29043 .71779 m .30125 .68364 L .32733 .6971 L p .707 .577 .707 r
F P
0 g
s
.38762 .26037 m .40182 .76357 L .37871 .77417 L p .707 .577 .707 r
F P
0 g
s
.40182 .76357 m .38762 .26037 L .42157 .25182 L p .707 .577 .707 r
F P
0 g
s
.73272 .67323 m .7383 .61855 L .70729 .6135 L p .707 .577 .707 r
F P
0 g
s
.7383 .61855 m .73272 .67323 L .76442 .6753 L p .707 .577 .707 r
F P
0 g
s
.76442 .6753 m .76999 .62061 L .7383 .61855 L p .707 .577 .707 r
F P
0 g
s
.34401 .79402 m .33841 .81101 L .31869 .7961 L p .707 .577 .707 r
F P
0 g
s
.31869 .7961 m .32428 .77911 L .34401 .79402 L p .707 .577 .707 r
F P
0 g
s
.20977 .74307 m .20418 .76007 L .1808 .76141 L p .707 .577 .707 r
F P
0 g
s
.76999 .62061 m .76442 .6753 L .79368 .67417 L p .707 .577 .707 r
F P
0 g
s
.79368 .67417 m .79926 .61949 L .76999 .62061 L p .707 .577 .707 r
F P
0 g
s
.70171 .66818 m .70729 .6135 L .67999 .60596 L p .707 .577 .707 r
F P
0 g
s
.70729 .6135 m .70171 .66818 L .73272 .67323 L p .707 .577 .707 r
F P
0 g
s
.24087 .66526 m .23004 .69941 L .20165 .6963 L p .707 .577 .707 r
F P
0 g
s
.23004 .69941 m .24087 .66526 L .27146 .67267 L p .707 .577 .707 r
F P
0 g
s
.30125 .68364 m .29043 .71779 L .26064 .70682 L p .707 .577 .707 r
F P
0 g
s
.26064 .70682 m .27146 .67267 L .30125 .68364 L p .707 .577 .707 r
F P
0 g
s
.27146 .67267 m .26064 .70682 L .23004 .69941 L p .707 .577 .707 r
F P
0 g
s
.5907 .25027 m .6049 .75346 L .56615 .74852 L p .707 .577 .707 r
F P
0 g
s
.56615 .74852 m .55195 .24533 L .5907 .25027 L p .707 .577 .707 r
F P
0 g
s
.79926 .61949 m .79368 .67417 L .81766 .66997 L p .707 .577 .707 r
F P
0 g
s
.81766 .66997 m .82324 .61529 L .79926 .61949 L p .707 .577 .707 r
F P
0 g
s
.20418 .76007 m .20977 .74307 L .2381 .7464 L p .707 .577 .707 r
F P
0 g
s
.67441 .66064 m .67999 .60596 L .65908 .59667 L p .707 .577 .707 r
F P
0 g
s
.67999 .60596 m .67441 .66064 L .70171 .66818 L p .707 .577 .707 r
F P
0 g
s
.32428 .77911 m .31869 .7961 L .29271 .78234 L p .707 .577 .707 r
F P
0 g
s
.29271 .78234 m .2983 .76535 L .32428 .77911 L p .707 .577 .707 r
F P
0 g
s
.72455 .726 m .73537 .69185 L .70557 .68088 L p .707 .577 .707 r
F P
0 g
s
.73537 .69185 m .72455 .726 L .75514 .7334 L p .707 .577 .707 r
F P
0 g
s
.75514 .7334 m .76596 .69925 L .73537 .69185 L p .707 .577 .707 r
F P
0 g
s
.2381 .7464 m .2325 .7634 L .20418 .76007 L p .707 .577 .707 r
F P
0 g
s
.69475 .71503 m .70557 .68088 L .67949 .66742 L p .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .70262 .71845 L .69896 .71651 L p .707 .577 .707 r
F P
0 g
s
.70557 .68088 m .69475 .71503 L .69894 .71657 L p .707 .577 .707 r
F P
0 g
s
.70835 .68748 m .70557 .68088 L .69894 .71657 L .707 .577 .707 r
F
.67949 .66742 m .66867 .70157 L .69475 .71503 L p F P
0 g
s
.69896 .71651 m .67664 .70469 L p .69421 .7312 L .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .69896 .71651 L .69421 .7312 L .707 .577 .707 r
F
.69894 .71657 m .72455 .726 L p .70835 .68748 L F P
0 g
s
.43577 .75501 m .42157 .25182 L .46303 .24614 L p .707 .577 .707 r
F P
0 g
s
.42157 .25182 m .43577 .75501 L .40182 .76357 L p .707 .577 .707 r
F P
0 g
s
.76596 .69925 m .75514 .7334 L .78353 .73652 L p .707 .577 .707 r
F P
0 g
s
.78353 .73652 m .79436 .70237 L .76596 .69925 L p .707 .577 .707 r
F P
0 g
s
.2325 .7634 m .2381 .7464 L .2686 .75408 L p .707 .577 .707 r
F P
0 g
s
.2983 .76535 m .29271 .78234 L .26301 .77107 L p .707 .577 .707 r
F P
0 g
s
.26301 .77107 m .2686 .75408 L .2983 .76535 L p .707 .577 .707 r
F P
0 g
s
.72672 .74672 m .73232 .72972 L .70262 .71845 L p .707 .577 .707 r
F P
0 g
s
.73232 .72972 m .72672 .74672 L .75723 .75439 L p .707 .577 .707 r
F P
0 g
s
.75723 .75439 m .76282 .7374 L .73232 .72972 L p .707 .577 .707 r
F P
0 g
s
.55195 .24533 m .56615 .74852 L .52216 .7471 L p .707 .577 .707 r
F P
0 g
s
.52216 .7471 m .50796 .24391 L .55195 .24533 L p .707 .577 .707 r
F P
0 g
s
.2686 .75408 m .26301 .77107 L .2325 .7634 L p .707 .577 .707 r
F P
0 g
s
.70262 .71845 m .69703 .73545 L .72672 .74672 L p .707 .577 .707 r
F P
0 g
s
.82324 .61529 m .81766 .66997 L .83401 .6631 L p .707 .577 .707 r
F P
0 g
s
.83401 .6631 m .83958 .60842 L .82324 .61529 L p .707 .577 .707 r
F P
0 g
s
.66867 .70157 m .67949 .66742 L .65968 .65278 L p .707 .577 .707 r
F P
0 g
s
.76282 .7374 m .75723 .75439 L .78555 .75772 L p .707 .577 .707 r
F P
0 g
s
.78555 .75772 m .79115 .74072 L .76282 .7374 L p .707 .577 .707 r
F P
0 g
s
.79436 .70237 m .78353 .73652 L .80695 .73504 L p .707 .577 .707 r
F P
0 g
s
.80695 .73504 m .81777 .70089 L .79436 .70237 L p .707 .577 .707 r
F P
0 g
s
.47723 .74934 m .46303 .24614 L .50796 .24391 L p .707 .577 .707 r
F P
0 g
s
.46303 .24614 m .47723 .74934 L .43577 .75501 L p .707 .577 .707 r
F P
0 g
s
.67664 .70469 m .67104 .72168 L .69703 .73545 L p .707 .577 .707 r
F P
0 g
s
.50796 .24391 m .52216 .7471 L .47723 .74934 L p .707 .577 .707 r
F P
0 g
s
.67104 .72168 m .67664 .70469 L .65691 .68978 L p .707 .577 .707 r
F P
0 g
s
.79115 .74072 m .78555 .75772 L .80893 .75638 L p .707 .577 .707 r
F P
0 g
s
.80893 .75638 m .81452 .73938 L .79115 .74072 L p .707 .577 .707 r
F P
0 g
s
.65691 .68978 m .65132 .70678 L .67104 .72168 L p .707 .577 .707 r
F P
0 g
s
.81777 .70089 m .80695 .73504 L .8231 .72911 L p .707 .577 .707 r
F P
0 g
s
.8231 .72911 m .83393 .69496 L .81777 .70089 L p .707 .577 .707 r
F P
0 g
s
.83958 .60842 m .83401 .6631 L .84112 .65424 L p .707 .577 .707 r
F P
0 g
s
.84112 .65424 m .84669 .59955 L .83958 .60842 L p .707 .577 .707 r
F P
0 g
s
.64102 .64121 m .6466 .58653 L .64377 .57654 L p .707 .577 .707 r
F P
0 g
s
.81452 .73938 m .80893 .75638 L .82506 .75049 L p .707 .577 .707 r
F P
0 g
s
.82506 .75049 m .83066 .7335 L .81452 .73938 L p .707 .577 .707 r
F P
0 g
s
.64538 .67519 m .63978 .69219 L .65132 .70678 L p .707 .577 .707 r
F P
0 g
s
.63725 .67256 m .64808 .63841 L .64581 .62569 L p .707 .577 .707 r
F P
0 g
s
.63989 .63721 m .64102 .64121 L p .64152 .62946 L .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .63499 .65985 L .63725 .67256 L p .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .65312 .61589 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63499 .65985 m .63542 .6585 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63542 .6585 m .64581 .62569 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.64377 .57654 m .6382 .63122 L .63989 .63721 L p .707 .577 .707 r
F P
0 g
s
.64152 .62946 m .64377 .57654 L .63989 .63721 L .707 .577 .707 r
F
.83393 .69496 m .8231 .72911 L .8304 .71931 L p F P
0 g
s
.8304 .71931 m .84123 .68515 L .83393 .69496 L p .707 .577 .707 r
F P
0 g
s
.84669 .59955 m .84112 .65424 L .83829 .64425 L p .707 .577 .707 r
F P
0 g
s
.83829 .64425 m .84387 .58956 L .84669 .59955 L p .707 .577 .707 r
F P
0 g
s
.63978 .69219 m .64538 .67519 L .64316 .66234 L p .707 .577 .707 r
F P
0 g
s
.6382 .63122 m .64377 .57654 L .65088 .56767 L p .707 .577 .707 r
F P
0 g
s
.83066 .7335 m .82506 .75049 L .83238 .74064 L p .707 .577 .707 r
F P
0 g
s
.83238 .74064 m .83798 .72365 L .83066 .7335 L p .707 .577 .707 r
F P
0 g
s
.64316 .66234 m .63757 .67934 L .63978 .69219 L p .707 .577 .707 r
F P
0 g
s
.65088 .56767 m .64531 .62236 L .6382 .63122 L p .707 .577 .707 r
F P
0 g
s
.84123 .68515 m .8304 .71931 L .82814 .70659 L p .707 .577 .707 r
F P
0 g
s
.82814 .70659 m .83896 .67244 L .84123 .68515 L p .707 .577 .707 r
F P
0 g
s
.84387 .58956 m .83829 .64425 L .82582 .63411 L p .707 .577 .707 r
F P
0 g
s
.82582 .63411 m .83139 .57943 L .84387 .58956 L p .707 .577 .707 r
F P
0 g
s
.38971 .61077 m .39529 .55609 L .36428 .55104 L p .707 .577 .707 r
F P
0 g
s
.39529 .55609 m .38971 .61077 L .42141 .61283 L p .707 .577 .707 r
F P
0 g
s
.42141 .61283 m .42698 .55815 L .39529 .55609 L p .707 .577 .707 r
F P
0 g
s
.63757 .67934 m .64316 .66234 L .65048 .65249 L p .707 .577 .707 r
F P
0 g
s
.66723 .56081 m .66365 .59589 L p .64531 .62236 L .707 .577 .707 r
F P
0 g
s
.64229 .65004 m .65312 .61589 L .66927 .60996 L p .707 .577 .707 r
F P
0 g
s
.66365 .59589 m .66165 .61549 L .65475 .61839 L p .707 .577 .707 r
F P
0 g
s
.65312 .61589 m .64257 .64916 L p .63499 .65985 L .707 .577 .707 r
F P
0 g
s
.65475 .61839 m .64531 .62236 L p .66365 .59589 L .707 .577 .707 r
F P
0 g
s
.64257 .64916 m .64229 .65004 L .64214 .65025 L p .707 .577 .707 r
F P
0 g
s
.64214 .65025 m .63499 .65985 L p .64257 .64916 L .707 .577 .707 r
F P
0 g
s
.42698 .55815 m .42141 .61283 L .45067 .61171 L p .707 .577 .707 r
F P
0 g
s
.45067 .61171 m .45625 .55702 L .42698 .55815 L p .707 .577 .707 r
F P
0 g
s
.64531 .62236 m .65088 .56767 L .66723 .56081 L p .707 .577 .707 r
F P
0 g
s
.3587 .60572 m .36428 .55104 L .33698 .54349 L p .707 .577 .707 r
F P
0 g
s
.36428 .55104 m .3587 .60572 L .38971 .61077 L p .707 .577 .707 r
F P
0 g
s
.83798 .72365 m .83238 .74064 L .83016 .7278 L p .707 .577 .707 r
F P
0 g
s
.83016 .7278 m .83576 .7108 L .83798 .72365 L p .707 .577 .707 r
F P
0 g
s
.65048 .65249 m .64488 .66949 L .63757 .67934 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45625 .55702 m .45067 .61171 L .47465 .6075 L p .707 .577 .707 r
F P
0 g
s
.47465 .6075 m .48023 .55282 L .45625 .55702 L p .707 .577 .707 r
F P
0 g
s
.3314 .59818 m .33698 .54349 L .31607 .5342 L p .707 .577 .707 r
F P
0 g
s
.33698 .54349 m .3314 .59818 L .3587 .60572 L p .707 .577 .707 r
F P
0 g
s
.83896 .67244 m .82814 .70659 L .81654 .69222 L p .707 .577 .707 r
F P
0 g
s
.81654 .69222 m .82736 .65807 L .83896 .67244 L p .707 .577 .707 r
F P
0 g
s
.83139 .57943 m .82582 .63411 L .8049 .62481 L p .707 .577 .707 r
F P
0 g
s
.8049 .62481 m .81048 .57013 L .83139 .57943 L p .707 .577 .707 r
F P
0 g
s
.38154 .68763 m .39236 .65348 L .36256 .64251 L p .707 .577 .707 r
F P
0 g
s
.39236 .65348 m .38154 .68763 L .41213 .69503 L p .707 .577 .707 r
F P
0 g
s
.41213 .69503 m .42295 .66088 L .39236 .65348 L p .707 .577 .707 r
F P
0 g
s
.64488 .66949 m .65048 .65249 L .66661 .64661 L p .707 .577 .707 r
F P
0 g
s
.35174 .67666 m .36256 .64251 L .33648 .62905 L p .707 .577 .707 r
F P
0 g
s
.36256 .64251 m .35174 .67666 L .38154 .68763 L p .707 .577 .707 r
F P
0 g
s
.69121 .5566 m .68749 .5931 L p .66165 .61549 L .707 .577 .707 r
F P
0 g
s
.65844 .64411 m .66927 .60996 L .69269 .60848 L p .707 .577 .707 r
F P
0 g
s
.68749 .5931 m .68563 .61128 L .67604 .61297 L p .707 .577 .707 r
F P
0 g
s
.66927 .60996 m .65887 .64277 L p .64229 .65004 L .707 .577 .707 r
F P
0 g
s
.67604 .61297 m .66165 .61549 L p .68749 .5931 L .707 .577 .707 r
F P
0 g
s
.65887 .64277 m .65844 .64411 L .658 .64428 L p .707 .577 .707 r
F P
0 g
s
.658 .64428 m .64229 .65004 L p .65887 .64277 L .707 .577 .707 r
F P
0 g
s
.66165 .61549 m .66723 .56081 L .69121 .5566 L p .707 .577 .707 r
F P
0 g
s
.42295 .66088 m .41213 .69503 L .44052 .69815 L p .707 .577 .707 r
F P
0 g
s
.44052 .69815 m .45135 .664 L .42295 .66088 L p .707 .577 .707 r
F P
0 g
s
.83576 .7108 m .83016 .7278 L .81863 .7132 L p .707 .577 .707 r
F P
0 g
s
.81863 .7132 m .82422 .69621 L .83576 .7108 L p .707 .577 .707 r
F P
0 g
s
.66661 .64661 m .66102 .6636 L .64488 .66949 L p .707 .577 .707 r
F P
0 g
s
.48023 .55282 m .47465 .6075 L .491 .60063 L p .707 .577 .707 r
F P
0 g
s
.491 .60063 m .49657 .54595 L .48023 .55282 L p .707 .577 .707 r
F P
0 g
s
.31607 .5342 m .31049 .58888 L .3314 .59818 L p .707 .577 .707 r
F P
0 g
s
.31049 .58888 m .31607 .5342 L .30359 .52406 L p .707 .577 .707 r
F P
0 g
s
.32566 .6632 m .33648 .62905 L .31667 .61441 L p .707 .577 .707 r
F P
0 g
s
.33648 .62905 m .32566 .6632 L .35174 .67666 L p .707 .577 .707 r
F P
0 g
s
.45135 .664 m .44052 .69815 L .46394 .69667 L p .707 .577 .707 r
F P
0 g
s
.46394 .69667 m .47477 .66252 L .45135 .664 L p .707 .577 .707 r
F P
0 g
s
.81048 .57013 m .8049 .62481 L .7776 .61727 L p .707 .577 .707 r
F P
0 g
s
.7776 .61727 m .78318 .56259 L .81048 .57013 L p .707 .577 .707 r
F P
0 g
s
.82736 .65807 m .81654 .69222 L .79672 .67758 L p .707 .577 .707 r
F P
0 g
s
.79672 .67758 m .80755 .64343 L .82736 .65807 L p .707 .577 .707 r
F P
0 g
s
.38371 .75248 m .38931 .73549 L .35961 .72422 L p .707 .577 .707 r
F P
0 g
s
.38931 .73549 m .38371 .75248 L .41422 .76016 L p .707 .577 .707 r
F P
0 g
s
.41422 .76016 m .41981 .74316 L .38931 .73549 L p .707 .577 .707 r
F P
0 g
s
.68563 .61128 m .69121 .5566 L .72048 .55548 L p .707 .577 .707 r
F P
0 g
s
.35402 .74121 m .35961 .72422 L .33363 .71046 L p .707 .577 .707 r
F P
0 g
s
.35961 .72422 m .35402 .74121 L .38371 .75248 L p .707 .577 .707 r
F P
0 g
s
.66102 .6636 m .66661 .64661 L .68999 .64527 L p .707 .577 .707 r
F P
0 g
s
.41981 .74316 m .41422 .76016 L .44254 .76349 L p .707 .577 .707 r
F P
0 g
s
.44254 .76349 m .44814 .74649 L .41981 .74316 L p .707 .577 .707 r
F P
0 g
s
.31667 .61441 m .30585 .64856 L .32566 .6632 L p .707 .577 .707 r
F P
0 g
s
.72048 .55548 m .71705 .58907 L p .68563 .61128 L .707 .577 .707 r
F P
0 g
s
.68186 .64263 m .69269 .60848 L .72108 .6116 L p .707 .577 .707 r
F P
0 g
s
.71705 .58907 m .7149 .61016 L .7025 .61064 L p .707 .577 .707 r
F P
0 g
s
.69269 .60848 m .68271 .63997 L p .65844 .64411 L .707 .577 .707 r
F P
0 g
s
.7025 .61064 m .68563 .61128 L p .71705 .58907 L .707 .577 .707 r
F P
0 g
s
.68271 .63997 m .68186 .64263 L .68087 .6427 L p .707 .577 .707 r
F P
0 g
s
.68087 .6427 m .65844 .64411 L p .68271 .63997 L .707 .577 .707 r
F P
0 g
s
.30359 .52406 m .29801 .57874 L .31049 .58888 L p .707 .577 .707 r
F P
0 g
s
.82422 .69621 m .81863 .7132 L .7989 .6983 L p .707 .577 .707 r
F P
0 g
s
.7989 .6983 m .8045 .6813 L .82422 .69621 L p .707 .577 .707 r
F P
0 g
s
.33363 .71046 m .32803 .72745 L .35402 .74121 L p .707 .577 .707 r
F P
0 g
s
.68999 .64527 m .68439 .66226 L .66102 .6636 L p .707 .577 .707 r
F P
0 g
s
.78318 .56259 m .7776 .61727 L .74659 .61222 L p .707 .577 .707 r
F P
0 g
s
.74659 .61222 m .75217 .55754 L .78318 .56259 L p .707 .577 .707 r
F P
0 g
s
.49657 .54595 m .491 .60063 L .49811 .59177 L p .707 .577 .707 r
F P
0 g
s
.49811 .59177 m .50368 .53709 L .49657 .54595 L p .707 .577 .707 r
F P
0 g
s
.30585 .64856 m .31667 .61441 L .30507 .60003 L p .707 .577 .707 r
F P
0 g
s
.7149 .61016 m .72048 .55548 L .75217 .55754 L p .707 .577 .707 r
F P
0 g
s
.32803 .72745 m .33363 .71046 L .3139 .69555 L p .707 .577 .707 r
F P
0 g
s
.75217 .55754 m .74659 .61222 L .7149 .61016 L p .707 .577 .707 r
F P
0 g
s
.47477 .66252 m .46394 .69667 L .48009 .69074 L p .707 .577 .707 r
F P
0 g
s
.48009 .69074 m .49092 .65658 L .47477 .66252 L p .707 .577 .707 r
F P
0 g
s
.80755 .64343 m .79672 .67758 L .77431 .66601 L p .707 .577 .707 r
F P
0 g
s
.77851 .66754 m .77292 .68454 L .76884 .68299 L p .707 .577 .707 r
F P
0 g
s
.76884 .68299 m .74322 .67326 L p .77356 .66834 L .707 .577 .707 r
F P
0 g
s
.77356 .66834 m .77851 .66754 L .76884 .68299 L .707 .577 .707 r
F
.77587 .66119 m .80755 .64343 L .77431 .66601 L F
.74322 .67326 m .74882 .65627 L .77851 .66754 L p F P
0 g
s
.77431 .66601 m .77064 .66412 L p .77587 .66119 L .707 .577 .707 r
F P
0 g
s
.77064 .66412 m .78147 .62997 L .80755 .64343 L p .707 .577 .707 r
F P
0 g
s
.29801 .57874 m .30359 .52406 L .30076 .51407 L p .707 .577 .707 r
F P
0 g
s
.44814 .74649 m .44254 .76349 L .46592 .76214 L p .707 .577 .707 r
F P
0 g
s
.46592 .76214 m .47151 .74515 L .44814 .74649 L p .707 .577 .707 r
F P
0 g
s
.3139 .69555 m .30831 .71255 L .32803 .72745 L p .707 .577 .707 r
F P
0 g
s
.68439 .66226 m .68999 .64527 L .71831 .6486 L p .707 .577 .707 r
F P
0 g
s
.30507 .60003 m .29424 .63419 L .30585 .64856 L p .707 .577 .707 r
F P
0 g
s
.72108 .6116 m .71026 .64575 L .68186 .64263 L p .707 .577 .707 r
F P
0 g
s
.71026 .64575 m .72108 .6116 L .75167 .619 L p .707 .577 .707 r
F P
0 g
s
.8045 .6813 m .7989 .6983 L .77292 .68454 L p .707 .577 .707 r
F P
0 g
s
.77292 .68454 m .77851 .66754 L .8045 .6813 L p .707 .577 .707 r
F P
0 g
s
.78147 .62997 m .77064 .66412 L .74085 .65315 L p .707 .577 .707 r
F P
0 g
s
.74085 .65315 m .75167 .619 L .78147 .62997 L p .707 .577 .707 r
F P
0 g
s
.71831 .6486 m .71272 .66559 L .68439 .66226 L p .707 .577 .707 r
F P
0 g
s
.75167 .619 m .74085 .65315 L .71026 .64575 L p .707 .577 .707 r
F P
0 g
s
.30076 .51407 m .29519 .56875 L .29801 .57874 L p .707 .577 .707 r
F P
0 g
s
.30831 .71255 m .3139 .69555 L .30237 .68096 L p .707 .577 .707 r
F P
0 g
s
.29424 .63419 m .30507 .60003 L .3028 .58732 L p .707 .577 .707 r
F P
0 g
s
.71272 .66559 m .71831 .6486 L .74882 .65627 L p .707 .577 .707 r
F P
0 g
s
.50368 .53709 m .49811 .59177 L .49528 .58178 L p .707 .577 .707 r
F P
0 g
s
.49528 .58178 m .50086 .5271 L .50368 .53709 L p .707 .577 .707 r
F P
0 g
s
.47151 .74515 m .46592 .76214 L .48205 .75626 L p .707 .577 .707 r
F P
0 g
s
.48205 .75626 m .48765 .73927 L .47151 .74515 L p .707 .577 .707 r
F P
0 g
s
.30237 .68096 m .29677 .69795 L .30831 .71255 L p .707 .577 .707 r
F P
0 g
s
.49092 .65658 m .48009 .69074 L .48739 .68093 L p .707 .577 .707 r
F P
0 g
s
.48739 .68093 m .49822 .64678 L .49092 .65658 L p .707 .577 .707 r
F P
0 g
s
.74882 .65627 m .74322 .67326 L .71272 .66559 L p .707 .577 .707 r
F P
0 g
s
.29519 .56875 m .30076 .51407 L .30787 .50521 L p .707 .577 .707 r
F P
0 g
s
.3028 .58732 m .29198 .62147 L .29424 .63419 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29677 .69795 m .30237 .68096 L .30015 .66811 L p .707 .577 .707 r
F P
0 g
s
.30787 .50521 m .3023 .55989 L .29519 .56875 L p .707 .577 .707 r
F P
0 g
s
.29198 .62147 m .3028 .58732 L .31011 .57752 L p .707 .577 .707 r
F P
0 g
s
.48765 .73927 m .48205 .75626 L .48937 .74641 L p .707 .577 .707 r
F P
0 g
s
.48937 .74641 m .49497 .72942 L .48765 .73927 L p .707 .577 .707 r
F P
0 g
s
.30015 .66811 m .29455 .6851 L .29677 .69795 L p .707 .577 .707 r
F P
0 g
s
.50086 .5271 m .49528 .58178 L .48281 .57164 L p .707 .577 .707 r
F P
0 g
s
.48281 .57164 m .48838 .51696 L .50086 .5271 L p .707 .577 .707 r
F P
0 g
s
.49822 .64678 m .48739 .68093 L .48513 .66822 L p .707 .577 .707 r
F P
0 g
s
.48513 .66822 m .49595 .63407 L .49822 .64678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3023 .55989 m .30787 .50521 L .32422 .49834 L p .707 .577 .707 r
F P
0 g
s
.31011 .57752 m .29928 .61167 L .29198 .62147 L p .707 .577 .707 r
F P
0 g
s
.29455 .6851 m .30015 .66811 L .30747 .65826 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32422 .49834 m .31864 .55302 L .3023 .55989 L p .707 .577 .707 r
F P
0 g
s
.29928 .61167 m .31011 .57752 L .32626 .57159 L p .707 .577 .707 r
F P
0 g
s
.49497 .72942 m .48937 .74641 L .48715 .73356 L p .707 .577 .707 r
F P
0 g
s
.48715 .73356 m .49275 .71657 L .49497 .72942 L p .707 .577 .707 r
F P
0 g
s
.30747 .65826 m .30187 .67526 L .29455 .6851 L p .707 .577 .707 r
F P
0 g
s
.48838 .51696 m .48281 .57164 L .46189 .56235 L p .707 .577 .707 r
F P
0 g
s
.46189 .56235 m .46747 .50767 L .48838 .51696 L p .707 .577 .707 r
F P
0 g
s
.49595 .63407 m .48513 .66822 L .47353 .65385 L p .707 .577 .707 r
F P
0 g
s
.47353 .65385 m .48435 .6197 L .49595 .63407 L p .707 .577 .707 r
F P
0 g
s
.31864 .55302 m .32422 .49834 L .3482 .49414 L p .707 .577 .707 r
F P
0 g
s
.32626 .57159 m .31543 .60574 L .29928 .61167 L p .707 .577 .707 r
F P
0 g
s
.30187 .67526 m .30747 .65826 L .3236 .65238 L p .707 .577 .707 r
F P
0 g
s
.46747 .50767 m .46189 .56235 L .43459 .55481 L p .707 .577 .707 r
F P
0 g
s
.43459 .55481 m .44017 .50013 L .46747 .50767 L p .707 .577 .707 r
F P
0 g
s
.3482 .49414 m .34262 .54882 L .31864 .55302 L p .707 .577 .707 r
F P
0 g
s
.31543 .60574 m .32626 .57159 L .34968 .57011 L p .707 .577 .707 r
F P
0 g
s
.34262 .54882 m .3482 .49414 L .37746 .49301 L p .707 .577 .707 r
F P
0 g
s
.49275 .71657 m .48715 .73356 L .47562 .71897 L p .707 .577 .707 r
F P
0 g
s
.47562 .71897 m .48121 .70198 L .49275 .71657 L p .707 .577 .707 r
F P
0 g
s
.3236 .65238 m .31801 .66937 L .30187 .67526 L p .707 .577 .707 r
F P
0 g
s
.48435 .6197 m .47353 .65385 L .45371 .63921 L p .707 .577 .707 r
F P
0 g
s
.45371 .63921 m .46454 .60506 L .48435 .6197 L p .707 .577 .707 r
F P
0 g
s
.44017 .50013 m .43459 .55481 L .40358 .54976 L p .707 .577 .707 r
F P
0 g
s
.40358 .54976 m .40916 .49508 L .44017 .50013 L p .707 .577 .707 r
F P
0 g
s
.37189 .54769 m .37746 .49301 L .40916 .49508 L p .707 .577 .707 r
F P
0 g
s
.37746 .49301 m .37189 .54769 L .34262 .54882 L p .707 .577 .707 r
F P
0 g
s
.34968 .57011 m .33885 .60426 L .31543 .60574 L p .707 .577 .707 r
F P
0 g
s
.40916 .49508 m .40358 .54976 L .37189 .54769 L p .707 .577 .707 r
F P
0 g
s
.33885 .60426 m .34968 .57011 L .37807 .57322 L p .707 .577 .707 r
F P
0 g
s
.31801 .66937 m .3236 .65238 L .34698 .65103 L p .707 .577 .707 r
F P
0 g
s
.46454 .60506 m .45371 .63921 L .42763 .62575 L p .707 .577 .707 r
F P
0 g
s
.42763 .62575 m .43846 .5916 L .46454 .60506 L p .707 .577 .707 r
F P
0 g
s
.48121 .70198 m .47562 .71897 L .45589 .70407 L p .707 .577 .707 r
F P
0 g
s
.45589 .70407 m .46149 .68707 L .48121 .70198 L p .707 .577 .707 r
F P
0 g
s
.34698 .65103 m .34138 .66803 L .31801 .66937 L p .707 .577 .707 r
F P
0 g
s
.37807 .57322 m .36725 .60738 L .33885 .60426 L p .707 .577 .707 r
F P
0 g
s
.36725 .60738 m .37807 .57322 L .40866 .58063 L p .707 .577 .707 r
F P
0 g
s
.43846 .5916 m .42763 .62575 L .39784 .61478 L p .707 .577 .707 r
F P
0 g
s
.39784 .61478 m .40866 .58063 L .43846 .5916 L p .707 .577 .707 r
F P
0 g
s
.40866 .58063 m .39784 .61478 L .36725 .60738 L p .707 .577 .707 r
F P
0 g
s
.34138 .66803 m .34698 .65103 L .3753 .65436 L p .707 .577 .707 r
F P
0 g
s
.46149 .68707 m .45589 .70407 L .42991 .6903 L p .707 .577 .707 r
F P
0 g
s
.42991 .6903 m .4355 .67331 L .46149 .68707 L p .707 .577 .707 r
F P
0 g
s
.3753 .65436 m .36971 .67136 L .34138 .66803 L p .707 .577 .707 r
F P
0 g
s
.36971 .67136 m .3753 .65436 L .40581 .66204 L p .707 .577 .707 r
F P
0 g
s
.4355 .67331 m .42991 .6903 L .40021 .67903 L p .707 .577 .707 r
F P
0 g
s
.40021 .67903 m .40581 .66204 L .4355 .67331 L p .707 .577 .707 r
F P
0 g
s
.40581 .66204 m .40021 .67903 L .36971 .67136 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo001nOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol007Ioo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00Lgoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000Kgoo001`Ool30004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001/Ool006eoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP<006Yoo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00J7oo
001YOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVEoo`00IGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIGoo
001UOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol006Eoo`04001JEUYF
0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001T
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol0061ooaL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00Fgoo1@000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001IOol200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Moo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00EWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00EGoo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUH005YF0002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00E7oo0P0015YF00@005YFFUIJEP`000AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol005Aoo`03FUH005YF009JEPD00003FUH005YF00IJEP03001JEUYF00@0009JEP03001J
EUYF00AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000@Ool8001<Ool005=oo`04001JEP00FUH30005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUHC0002FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0027oo20000eYF
00<005YFFUH00UYF1`00AGoo001COol01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF
00EJEP<000MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool40003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040011Ool005=oo`<0009JEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005=oo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF
009JEP800007FUH005YFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00>Goo001COol00`00FUIJEP02FUH01000FUIJEUYF2`001eYF1@00
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF0P0025YF00<005YFFUH01UYF00<005YFFUH00eYF1000=Goo001DOol01P00FUIJEUYF001JEP<0
00IJEP04001JEUYFFUH7000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YF
FUH005YF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0
009JEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002000bOol005Aoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF008000EJEP03
001JEUYF00EJEP8000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00
EGoo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00;goo000iOolG0006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEP0002ioo`00=7oo1@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010000Woo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000]Ool0039oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Goo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30000
0eYF001JEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH0
1000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000_Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00@005YF000000UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP05001JEUYFFUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH60002FUH20002Ool70007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
1@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH00UYF0P00
0goo00<005YFFUH01@000UYF00<005YFFUH01UYF00<005YFFUH01eYF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEPh000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001J
EUYF0005FUH20002Ool01000FUIJEP0015YF10001eYF00<005YFFUH01UYF00<005YFFUH00P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF
00<0009JEP03001JEUYF00EJEP03001JEP0000X000AJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH2000/Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000EJEP800003FUH005YF00AJEP03001JEP000080009JEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEPH000EJEP03001JEUYF00AJEP03
001JEUYF00=JEPD000=oo`H000EJEP03001JEUYF00AJEP06001JEUYF001JEP00;7oo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP020005FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUIJEP<00003
FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEP00FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH?00000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP8000QJEP03
001JEUYF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
00<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000QJEP80
00EJEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00@005YFFUH000AJEP<000QJEP8000EJEP03001JEUYF00AJEP03001JEP0000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEP<000IJEP04001JEP000003FUH01000FUIJEUYF
0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01000FUIJEP00
0eYF1@001eYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP<000=JEP04001JEUYFFUH200000eYF001JEP02FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20002FUH20002FUH01000
FUIJEUYF1@001eYF00@005YFFUIJEP<000MJEP05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUH000020006FUH20003FUH2000]Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00
FUIJEP03FUH40002FUH01000FUIJEUYF1@001eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000P000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P001EYF00<005YF00000UYF0P00;Goo000]Ool20004FUH01000FUIJEUYF300017oo2@0015YF
00@005YFFUH000IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<000QJEP03001JEUYF00AJEP80
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool00eYF001JEP02FUH500000eYF001JEP06
FUH00`00FUIJEP040009Ool70006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000002FUHC0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH3000]Ool002aoo`04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH@0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH30004FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH0000300001EYF000005YF00001UYF00@005YFFUIJEPP0009JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000AJEP<002eoo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF009JEP80009JEP`000MJEP@000QJEP03
001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF001JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP0000D000QJ
EP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002aoo`<0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00AJEP<000IJEP04001JEUYF
FUH70002FUH00`00FUIJEP040004FUH00`00FUIJEP09FUH20002FUH00`00FUH00006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00
;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH010001EYF1P002UYF
0P000UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000AJ
EP000000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003
FUH005YF00IJEP03001JEUYF00EJEP04001JEP00000^Ool002aoo`03001JEUYF009JEP04001JEUYF
FUH;0007FUH50005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40003FUH01000FUIJEUYF3@0000=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF0P0000=JEP0000000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH00UYF
0`001eYF00<005YFFUH01EYF0`00;goo000]Ool01P00FUIJEUYF001JEP<000IJEP04001JEUYFFUH7
000015YF000000001UYF00@005YFFUIJEP8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH0
0`00FUH000020008FUH00`00FUIJEP03FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP800004FUH00000FUH20006FUH<0006FUH00`00FUIJEP06FUH20005
FUH00`00FUIJEP04FUH00`00FUH0000`Ool002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040006FUH01000FUIJEUYF0P000UYF1@0000=JEP0000000eYF1`001eYF
00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000040007FUH;00000eYF000000020002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00@005YFFUH002moo`00;Woo00@0
05YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00800005FUH00000FUH00005FUH40007FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000800003FUH005YF00EJEP04001JEUYFFUH30005Ool90007FUH01000FUIJEUYF0`001eYF
00D005YFFUIJEP0002ioo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YF00000P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH00P0025YF0`0000=JEP00
FUH025YF0`0000=JEP00FUH015YF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00=JEP8000eoo`8000EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP03001oogoo02aoo`00;goo0P000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF
00@005YFFUIJEP@000EJEP03001JEP0000<000QJEP03001JEUYF008000AJEP03001JEUYF009JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00001JEP020006FUH0
0`00FUIJEP05FUH2000=Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF0000009JEP03001JEUYF00AJEP06001JEUYFFUH005YF1@0000=JEP00FUH02000
15YF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0006FUH00`00FUIJEP08FUH3000<Ool30008
FUH30002FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00005FUH00`00FUIJEP02FUH2
000017oo001JEUYF2@000eYF0`0000=JEP00FUH01UYF0`000eYF0P002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0037oo0P001UYF00<005YFFUH00P0015YF00<005YF0000;Goo000^Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0005FUH01000FUIJEUYF0P000Woo00@005YFFUH000=JEPD0009JEP04001JEUYFFUH20008FUH20002
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH3000;Ool20003FUH00`00FUIJEP02FUH20002
FUH00`00FUH0000^Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP04001JEP000004Ool01000FUIJEP0015YF0`00
00=JEP00000010000UYF0P001EYF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP0000<000Uoo`800003FUH005YF00EJEP05001JEP00FUH0000^Ool002eoo`03001JEP00009JEQ80
00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000<000Ioo`04001JEUYF0006FUH0
0`00FUIJEP05FUH60003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000Eoo`8000IJEP<00003FUH007oo02eoo`00;Goo0P0000AJEP000000011oo`D0009J
EP03001JEUYF00IJEP03001JEP00009JEP05001JEUYF001JEP020008Ool01000FUIJEP001UYF00<0
05YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF200015YF00D005YF001JEP0002moo`00;Goo00=JEP0000000eYF00<007ooOol04Woo
0`0025YF00<005YF00000UYF00D005YFFUIJEP00009JEP8000Ioo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF008002moo`00;7oo0P001EYF0P00
5Woo0P001UYF00<005YFFUH00P001EYF00D005YFFUIJEP0000Eoo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20004FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`001EYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF0P000eYF0P00;goo000/Ool20004FUH01000FUIJEP005goo0P00
15YF00D005YFFUIJEP0000IJEP80009JEP03001oogoo009oo`04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEP<000UJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000AJEP03001oogoo02eoo`00;7oo0P0015YF00D005YF
FUIJEP0001Qoo`800003FUH005YF00AJEP8000AJEP03001JEP0000<000=oo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF0`00
1UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P00;goo
000/Ool20003FUH00`00FUIJEP03FUH00`00Oomoo`0GOol30006FUH01000FUIJEP0015YF0`000Woo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00<000QJEP<000AJEP03001JEP0000@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUH0000^Ool002aoo`03001JEUYF009JEP03001JEUYF00AJEP8000ioo`<000Uoo`80
00AJEP@000MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP80
00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0008FUH00`00FUH00002000015YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001oogoo02aoo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00@0
05YF000000]oo`D000Yoo`800003FUH005YF009JEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP8000IJEP03001JEUYF009JEPT0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001oogoo02aoo`00;Goo00@005YFFUH0
00IJEP03001JEUYF009JEP<000Qoo`D000aoo`8000AJEP8000EJEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP8000=JEP03001JEUYF00IJEPD0009JEP03001J
EUYF00IJEP03001JEUYF00AJEP08001JEUYF001oo`00FUH002moo`00;Goo00@005YFFUH000IJEP03
001JEUYF00EJEP<000Eoo`D000ioo`03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00000015YF0`0000=JEP00FUH025YF00<0
05YF00001`0015YF00<005YFFUH015YF00@005YF0000009oo`03001JEP0002moo`00;Woo0P001eYF
00<005YFFUH01UYF00@005YF000000Aoo`<0011oo`03001JEUYF009JEP03001JEP00008000QJEP@0
0003FUH005YF00MJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP<000MJEP03001J
EUYF00AJEQ40009oo`800003FUH007oo02moo`00;goo00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`005Goo0P000UYF00@005YFFUIJEP8000QJEP03001JEUYF00@000IJEP03001JEUYF
00UJEP03001JEP00008000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8000=JEP@000AJEP@000EJEP03001JEUYF00IJEP04001JEUYFFUH=0002FUH2000`Ool0
031oo`80009JEP`000MJEP<001Aoo`8000=JEP03001JEUYF00<000AJEP03001JEUYF00EJEPL000MJ
EPH00003FUH0000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00004FUH01000FUH007oo0`0000=JEP00FUH025YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00<Woo0P0000=JEP00FUH015YF00@005YFFUIJ
EPL0009JEP03001JEP000080019oo`07001JEUYFFUH005YF00000Woo00IJEP00000005YF0009FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP80009JEQD000QJEP03001JEUYF00IJEP03001JEUYF009J
EP80009JEP03001JEUYF009JEP80009JEP03001JEP0000Aoo`@000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH2000aOol0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP<0011oo`06001JEUYF001JEP000Woo0eYF10001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00IJEPH0009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00AJEP04001JEP000009Ool40002FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEQ40009JEP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF0P0035YF00<005YF0000
10001UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`003Woo1P0015YF00<005YFFUH00eYF00@0
05YF000003Aoo`00;goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP06001J
EP00001JEP001eYF00<005YFFUH00eYF00H005YF000005YF0003Ool3FUH00`00FUIJEP03FUH30000
0eYF001JEP07FUH00`00FUIJEP03FUH00`00FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUH0000EOol<
000fOol002ioo`80009JEP`000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH015YF00<005YF0000100015YF00@005YF
FUIJEPH000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@000AJEP800003FUH0
05YF00EJEP04001JEUYF001FOol002eoo`800003FUH0000000Qoo`800003FUH0000000D000MJEP03
001JEUYF00EJEP8000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH0
0eYF0`000eYF00<005YF00001`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP80009JEP<000MJEP05001JEUYFFUH0001EOol002eoo`<000aoo`<0
00EJEP@0009JEP03001JEUYF00MJEP<00003FUH005YF00AJEP04001JEUYFFUH20004Ool3FUH01000
FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF009JEP03001oogoo
05=oo`00;7oo0`0047oo0P001EYF00<005YF00000`0025YF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P0017oo0eYF00<005YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
009JEP07001JEUYFFUH005YF0000E7oo000/Ool01000FUH000004Goo0`0000=JEP00FUH0200015YF
00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<007ooOol00goo0eYF0P000UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YF0000009JEP8000=JEP07001JEUYFFUH005YF0000E7oo000/Ool0
1@00FUH005YF00004goo20000eYF0`0000=JEP00FUH01UYF0`000eYF0P001Goo0UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEP00009JEP07001JEUYF
FUH005YF0000E7oo000/Ool00`00FUIJEP02FUH00`00Oomoo`0COol50002FUH01000FUIJEUYF0P00
25YF0P000UYF0P001Woo00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH0
05YF0003FUH20003FUH00`00FUH0001EOol002eoo`03001JEUYF009JEP03001oogoo01=oo`<00003
Ool0000000@0009JEP8000EJEP03001JEUYF008000Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00H005YFFUH005YF001EOol002eoo`03001JEUYF009JEP8001io
o`H000=JEP03001JEUYF009JEP03001oogoo00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000IJEP05001JEP00FUH0001EOol002ioo`04001JEUYF0002FUH00`00Oomoo`0QOol3
0006FUH00`00Oomoo`05Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH70004FUH0
0`00FUH00002001FOol002ioo`04001JEUYF0003FUH00`00Oomoo`0ROol00`00FUIJEP04FUH20006
Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP80009JEP05
001JEP00FUH0001FOol002moo`8000EJEP03001oogoo029oo`8000AJEP03001JEP0000Ioo`8000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEUYF0004FUH00`00FUIJEP04FUH20003FUH2001FOol0031oo`03001J
EUYF00AJEP03001oogoo02=oo`04001JEUYF0003FUH00`00Oomoo`05Ool200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3
0005FUH00`00FUIJEP04FUH20004FUH00`00Oomoo`1DOol0035oo`03001JEUYF00=JEP<002Aoo`<0
00AJEP03001oogoo00Ioo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP03001JEP0000=JEP03001oogoo
05Aoo`00<Woo00<005YFFUH00UYF00<005YFFUH00P0097oo00<005YFFUH00UYF00<007ooOol02Goo
10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0005Eoo`00<goo
0P0000=JEP00FUH015YF0P008goo00<005YFFUH00P003goo1@0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF0000EGoo000eOol20007FUH3000POol00`00FUIJEP02000DOol60002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF3`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00`000UYF00<007ooOol0Dgoo000fOol20006FUH00`00FUIJEP02000OOol200000eYF001oo`0I
OolP0008FUH600000eYF001JEP07FUH00`00FUIJEP04FUH02000FUIJEP00Ool005YF001FOol003Qo
o`8000AJEP03001JEUYF009JEP<001eoo`03001JEP0003Ioo`800003FUH005YF00QJEPX000AJEP03
001JEUYF00AJEP04001JEP000002Ool00`00FUH0001FOol003Yoo`800003FUH005YF00MJEP@001Uo
o`03001JEP0003Qoo`<000MJEP03001JEUYF00AJEQ40009oo`800003FUH007oo05Ioo`00?7oo0`00
25YF00<005YFFUH010005Goo0P00?7oo0P001EYF00<005YFFUH01UYF00@005YFFUIJEPd0009JEP80
05Moo`00?goo0P001UYF00<005YFFUH015YF1P003Goo1000?Woo0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005Qoo`00@Goo0P000eYF00<005YFFUH01eYF00@0
05YFFUIJEPd0009JEP80045oo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
001HOol004=oo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0016Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001IOol004Eoo`<000MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001:Ool60004FUH00`00FUIJEP03FUH0
1000FUH00000Fgoo0018Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001A
Ool<001MOol004aoo`H000AJEP04001JEUYFFUH6002mOol0059oo`P00<=oo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59552 .76527 m .6011 .71059 L .57008 .70554 L p .707 .577 .707 r
F P
0 g
s
.6011 .71059 m .59552 .76527 L .62721 .76733 L p .707 .577 .707 r
F P
0 g
s
.62721 .76733 m .63279 .71265 L .6011 .71059 L p .707 .577 .707 r
F P
0 g
s
.63279 .71265 m .62721 .76733 L .65648 .76621 L p .707 .577 .707 r
F P
0 g
s
.65648 .76621 m .66206 .71153 L .63279 .71265 L p .707 .577 .707 r
F P
0 g
s
.56451 .76022 m .57008 .70554 L .54278 .698 L p .707 .577 .707 r
F P
0 g
s
.57008 .70554 m .56451 .76022 L .59552 .76527 L p .707 .577 .707 r
F P
0 g
s
.66206 .71153 m .65648 .76621 L .68046 .76201 L p .707 .577 .707 r
F P
0 g
s
.68046 .76201 m .68604 .70732 L .66206 .71153 L p .707 .577 .707 r
F P
0 g
s
.53721 .75268 m .54278 .698 L .52187 .6887 L p .707 .577 .707 r
F P
0 g
s
.54278 .698 m .53721 .75268 L .56451 .76022 L p .707 .577 .707 r
F P
0 g
s
.58734 .81804 m .59816 .78389 L .56837 .77292 L p .707 .577 .707 r
F P
0 g
s
.59816 .78389 m .58734 .81804 L .61793 .82544 L p .707 .577 .707 r
F P
0 g
s
.61793 .82544 m .62876 .79129 L .59816 .78389 L p .707 .577 .707 r
F P
0 g
s
.55755 .80707 m .56837 .77292 L .54229 .75946 L p .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56542 .81049 L .56176 .80855 L p .707 .577 .707 r
F P
0 g
s
.56837 .77292 m .55755 .80707 L .56174 .80861 L p .707 .577 .707 r
F P
0 g
s
.57115 .77952 m .56837 .77292 L .56174 .80861 L .707 .577 .707 r
F
.54229 .75946 m .53147 .79361 L .55755 .80707 L p F P
0 g
s
.56176 .80855 m .53943 .79673 L p .55701 .82324 L .707 .577 .707 r
F P
0 g
s
.55982 .82748 m .56176 .80855 L .55701 .82324 L .707 .577 .707 r
F
.56174 .80861 m .58734 .81804 L p .57115 .77952 L F P
0 g
s
.62876 .79129 m .61793 .82544 L .64633 .82856 L p .707 .577 .707 r
F P
0 g
s
.64633 .82856 m .65715 .79441 L .62876 .79129 L p .707 .577 .707 r
F P
0 g
s
.58952 .83875 m .59511 .82176 L .56542 .81049 L p .707 .577 .707 r
F P
0 g
s
.59511 .82176 m .58952 .83875 L .62002 .84643 L p .707 .577 .707 r
F P
0 g
s
.62002 .84643 m .62562 .82943 L .59511 .82176 L p .707 .577 .707 r
F P
0 g
s
.56542 .81049 m .55982 .82748 L .58952 .83875 L p .707 .577 .707 r
F P
0 g
s
.68604 .70732 m .68046 .76201 L .6968 .75514 L p .707 .577 .707 r
F P
0 g
s
.6968 .75514 m .70238 .70046 L .68604 .70732 L p .707 .577 .707 r
F P
0 g
s
.52187 .6887 m .5163 .74339 L .52659 .74796 L p .707 .577 .707 r
F P
0 g
s
.52659 .74796 m .53721 .75268 L p .53305 .73533 L .707 .577 .707 r
F P
0 g
s
.53305 .73533 m .52187 .6887 L .52659 .74796 L .707 .577 .707 r
F
.5163 .74339 m .52187 .6887 L .50939 .67857 L p F P
0 g
s
.50939 .67857 m .50382 .73325 L .51101 .73909 L p .707 .577 .707 r
F P
0 g
s
.51101 .73909 m .5163 .74339 L p .5149 .7303 L .707 .577 .707 r
F P
0 g
s
.5149 .7303 m .50939 .67857 L .51101 .73909 L .707 .577 .707 r
F
.51087 .73044 m .50861 .71773 L p .50029 .76331 L F P
0 g
s
.50005 .76459 m .50089 .76194 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.50089 .76194 m .51087 .73044 L p .50029 .76331 L .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51087 .73044 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51166 .77897 m .51315 .77426 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.51315 .77426 m .52248 .74482 L p .51163 .77724 L .707 .577 .707 r
F P
0 g
s
.53147 .79361 m .54229 .75946 L .52248 .74482 L p .707 .577 .707 r
F P
0 g
s
.62562 .82943 m .62002 .84643 L .64835 .84976 L p .707 .577 .707 r
F P
0 g
s
.64835 .84976 m .65394 .83276 L .62562 .82943 L p .707 .577 .707 r
F P
0 g
s
.65715 .79441 m .64633 .82856 L .66975 .82708 L p .707 .577 .707 r
F P
0 g
s
.66975 .82708 m .68057 .79292 L .65715 .79441 L p .707 .577 .707 r
F P
0 g
s
.53943 .79673 m .53384 .81372 L .55982 .82748 L p .707 .577 .707 r
F P
0 g
s
.52248 .74482 m .51166 .77897 L .53147 .79361 L p .707 .577 .707 r
F P
0 g
s
.53384 .81372 m .53943 .79673 L .51971 .78182 L p .707 .577 .707 r
F P
0 g
s
.65394 .83276 m .64835 .84976 L .67172 .84841 L p .707 .577 .707 r
F P
0 g
s
.67172 .84841 m .67732 .83142 L .65394 .83276 L p .707 .577 .707 r
F P
0 g
s
.51971 .78182 m .51412 .79882 L .53384 .81372 L p .707 .577 .707 r
F P
0 g
s
.68057 .79292 m .66975 .82708 L .6859 .82114 L p .707 .577 .707 r
F P
0 g
s
.6859 .82114 m .69672 .78699 L .68057 .79292 L p .707 .577 .707 r
F P
0 g
s
.70238 .70046 m .6968 .75514 L .70391 .74627 L p .707 .577 .707 r
F P
0 g
s
.70391 .74627 m .70949 .69159 L .70238 .70046 L p .707 .577 .707 r
F P
0 g
s
.51087 .73044 m .50005 .76459 L .51166 .77897 L p .707 .577 .707 r
F P
0 g
s
.51412 .79882 m .51971 .78182 L .50817 .76723 L p .707 .577 .707 r
F P
0 g
s
.50382 .73325 m .50939 .67857 L .50657 .66858 L p .707 .577 .707 r
F P
0 g
s
.67732 .83142 m .67172 .84841 L .68786 .84253 L p .707 .577 .707 r
F P
0 g
s
.68786 .84253 m .69345 .82554 L .67732 .83142 L p .707 .577 .707 r
F P
0 g
s
.50817 .76723 m .50258 .78422 L .51412 .79882 L p .707 .577 .707 r
F P
0 g
s
.50269 .72925 m .50382 .73325 L p .50432 .7215 L .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .49779 .75188 L .50005 .76459 L p .707 .577 .707 r
F P
0 g
s
.50861 .71773 m .51591 .70793 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49779 .75188 m .49821 .75054 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.49821 .75054 m .50861 .71773 L p .49808 .75118 L .707 .577 .707 r
F P
0 g
s
.50657 .66858 m .50099 .72326 L .50269 .72925 L p .707 .577 .707 r
F P
0 g
s
.50432 .7215 m .50657 .66858 L .50269 .72925 L .707 .577 .707 r
F
.69672 .78699 m .6859 .82114 L .6932 .81134 L p F P
0 g
s
.6932 .81134 m .70402 .77719 L .69672 .78699 L p .707 .577 .707 r
F P
0 g
s
.70949 .69159 m .70391 .74627 L .70109 .73628 L p .707 .577 .707 r
F P
0 g
s
.70109 .73628 m .70666 .6816 L .70949 .69159 L p .707 .577 .707 r
F P
0 g
s
.50258 .78422 m .50817 .76723 L .50595 .75438 L p .707 .577 .707 r
F P
0 g
s
.50595 .75438 m .50036 .77137 L .50258 .78422 L p .707 .577 .707 r
F P
0 g
s
.50036 .77137 m .50595 .75438 L .51327 .74453 L p .707 .577 .707 r
F P
0 g
s
.51591 .70793 m .50537 .74119 L p .49779 .75188 L .707 .577 .707 r
F P
0 g
s
.50537 .74119 m .50509 .74208 L .50494 .74228 L p .707 .577 .707 r
F P
0 g
s
.50494 .74228 m .49779 .75188 L p .50537 .74119 L .707 .577 .707 r
F P
0 g
s
.53002 .65284 m .52644 .68793 L p .5081 .71439 L .707 .577 .707 r
F P
0 g
s
.50509 .74208 m .51591 .70793 L .53206 .702 L p .707 .577 .707 r
F P
0 g
s
.52644 .68793 m .52445 .70753 L .51754 .71043 L p .707 .577 .707 r
F P
0 g
s
.51754 .71043 m .5081 .71439 L p .52644 .68793 L .707 .577 .707 r
F P
0 g
s
.51327 .74453 m .50768 .76153 L .50036 .77137 L p .707 .577 .707 r
F P
0 g
s
.503 .82182 m .4888 .31862 L .44481 .3172 L p .707 .577 .707 r
F P
0 g
s
.50099 .72326 m .50657 .66858 L .51368 .65971 L p .707 .577 .707 r
F P
0 g
s
.51368 .65971 m .5081 .71439 L .50099 .72326 L p .707 .577 .707 r
F P
0 g
s
.5081 .71439 m .51368 .65971 L .53002 .65284 L p .707 .577 .707 r
F P
0 g
s
.50768 .76153 m .51327 .74453 L .52941 .73865 L p .707 .577 .707 r
F P
0 g
s
.53206 .702 m .52166 .73481 L p .50509 .74208 L .707 .577 .707 r
F P
0 g
s
.52166 .73481 m .52124 .73615 L .5208 .73631 L p .707 .577 .707 r
F P
0 g
s
.5208 .73631 m .50509 .74208 L p .52166 .73481 L .707 .577 .707 r
F P
0 g
s
.554 .64864 m .55028 .68514 L p .52445 .70753 L .707 .577 .707 r
F P
0 g
s
.52124 .73615 m .53206 .702 L .55548 .70052 L p .707 .577 .707 r
F P
0 g
s
.55028 .68514 m .54843 .70332 L .53884 .705 L p .707 .577 .707 r
F P
0 g
s
.53884 .705 m .52445 .70753 L p .55028 .68514 L .707 .577 .707 r
F P
0 g
s
.52445 .70753 m .53002 .65284 L .554 .64864 L p .707 .577 .707 r
F P
0 g
s
.52941 .73865 m .52381 .75564 L .50768 .76153 L p .707 .577 .707 r
F P
0 g
s
.52381 .75564 m .52941 .73865 L .55278 .7373 L p .707 .577 .707 r
F P
0 g
s
.55548 .70052 m .5455 .73201 L p .52124 .73615 L .707 .577 .707 r
F P
0 g
s
.5455 .73201 m .54466 .73467 L .54366 .73473 L p .707 .577 .707 r
F P
0 g
s
.54366 .73473 m .52124 .73615 L p .5455 .73201 L .707 .577 .707 r
F P
0 g
s
.58327 .64752 m .57985 .68111 L p .54843 .70332 L .707 .577 .707 r
F P
0 g
s
.54466 .73467 m .55548 .70052 L .58388 .70363 L p .707 .577 .707 r
F P
0 g
s
.57985 .68111 m .5777 .7022 L .5653 .70267 L p .707 .577 .707 r
F P
0 g
s
.5653 .70267 m .54843 .70332 L p .57985 .68111 L .707 .577 .707 r
F P
0 g
s
.55278 .7373 m .54719 .7543 L .52381 .75564 L p .707 .577 .707 r
F P
0 g
s
.4888 .31862 m .503 .82182 L .54793 .81958 L p .707 .577 .707 r
F P
0 g
s
.58388 .70363 m .57739 .72412 L p .54466 .73467 L .707 .577 .707 r
F P
0 g
s
.57739 .72412 m .57305 .73778 L .56677 .7371 L p .707 .577 .707 r
F P
0 g
s
.56677 .7371 m .54466 .73467 L p .57739 .72412 L .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .4888 .31862 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54793 .81958 m .54631 .76213 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.54631 .76213 m .53373 .31639 L p .5418 .76764 L .707 .577 .707 r
F P
0 g
s
.69345 .82554 m .68786 .84253 L .69518 .83268 L p .707 .577 .707 r
F P
0 g
s
.69518 .83268 m .70077 .81569 L .69345 .82554 L p .707 .577 .707 r
F P
0 g
s
.54843 .70332 m .554 .64864 L .58327 .64752 L p .707 .577 .707 r
F P
0 g
s
.54719 .7543 m .55278 .7373 L .58111 .74063 L p .707 .577 .707 r
F P
0 g
s
.57305 .73778 m .58388 .70363 L .61447 .71104 L p .707 .577 .707 r
F P
0 g
s
.58111 .74063 m .57551 .75763 L .54719 .7543 L p .707 .577 .707 r
F P
0 g
s
.61447 .71104 m .60365 .74519 L .57305 .73778 L p .707 .577 .707 r
F P
0 g
s
.57551 .75763 m .58111 .74063 L .61161 .74831 L p .707 .577 .707 r
F P
0 g
s
.61161 .74831 m .60602 .7653 L .57551 .75763 L p .707 .577 .707 r
F P
0 g
s
.53373 .31639 m .54793 .81958 L .5894 .81391 L p .707 .577 .707 r
F P
0 g
s
.5777 .7022 m .58327 .64752 L .61496 .64958 L p .707 .577 .707 r
F P
0 g
s
.61496 .64958 m .60939 .70426 L .5777 .7022 L p .707 .577 .707 r
F P
0 g
s
.5894 .81391 m .5752 .31071 L .53373 .31639 L p .707 .577 .707 r
F P
0 g
s
.45901 .8204 m .44481 .3172 L .40606 .31226 L p .707 .577 .707 r
F P
0 g
s
.44481 .3172 m .45901 .8204 L .503 .82182 L p .707 .577 .707 r
F P
0 g
s
.64598 .65463 m .6404 .70931 L .60939 .70426 L p .707 .577 .707 r
F P
0 g
s
.60939 .70426 m .61496 .64958 L .64598 .65463 L p .707 .577 .707 r
F P
0 g
s
.64426 .72201 m .63344 .75616 L .60365 .74519 L p .707 .577 .707 r
F P
0 g
s
.60365 .74519 m .61447 .71104 L .64426 .72201 L p .707 .577 .707 r
F P
0 g
s
.67034 .73547 m .65952 .76962 L .63711 .75805 L p .707 .577 .707 r
F P
0 g
s
.64131 .75958 m .63572 .77657 L .63163 .77502 L p .707 .577 .707 r
F P
0 g
s
.63163 .77502 m .60602 .7653 L p .63636 .76038 L .707 .577 .707 r
F P
0 g
s
.63636 .76038 m .64131 .75958 L .63163 .77502 L .707 .577 .707 r
F
.63867 .75323 m .67034 .73547 L .63711 .75805 L F
.60602 .7653 m .61161 .74831 L .64131 .75958 L p F P
0 g
s
.63711 .75805 m .63344 .75616 L p .63867 .75323 L .707 .577 .707 r
F P
0 g
s
.5752 .31071 m .5894 .81391 L .62335 .80535 L p .707 .577 .707 r
F P
0 g
s
.62335 .80535 m .60915 .30216 L .5752 .31071 L p .707 .577 .707 r
F P
0 g
s
.70402 .77719 m .6932 .81134 L .69094 .79863 L p .707 .577 .707 r
F P
0 g
s
.69094 .79863 m .70176 .76448 L .70402 .77719 L p .707 .577 .707 r
F P
0 g
s
.70666 .6816 m .70109 .73628 L .68861 .72615 L p .707 .577 .707 r
F P
0 g
s
.68861 .72615 m .69419 .67146 L .70666 .6816 L p .707 .577 .707 r
F P
0 g
s
.25251 .70281 m .25809 .64812 L .22707 .64307 L p .707 .577 .707 r
F P
0 g
s
.25809 .64812 m .25251 .70281 L .2842 .70487 L p .707 .577 .707 r
F P
0 g
s
.2842 .70487 m .28978 .65019 L .25809 .64812 L p .707 .577 .707 r
F P
0 g
s
.28978 .65019 m .2842 .70487 L .31347 .70374 L p .707 .577 .707 r
F P
0 g
s
.31347 .70374 m .31905 .64906 L .28978 .65019 L p .707 .577 .707 r
F P
0 g
s
.2215 .69776 m .22707 .64307 L .19978 .63553 L p .707 .577 .707 r
F P
0 g
s
.22707 .64307 m .2215 .69776 L .25251 .70281 L p .707 .577 .707 r
F P
0 g
s
.42026 .81546 m .40606 .31226 L .37635 .30429 L p .707 .577 .707 r
F P
0 g
s
.40606 .31226 m .42026 .81546 L .45901 .8204 L p .707 .577 .707 r
F P
0 g
s
.70077 .81569 m .69518 .83268 L .69296 .81983 L p .707 .577 .707 r
F P
0 g
s
.69296 .81983 m .69855 .80284 L .70077 .81569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31905 .64906 m .31347 .70374 L .33745 .69954 L p .707 .577 .707 r
F P
0 g
s
.33745 .69954 m .34303 .64486 L .31905 .64906 L p .707 .577 .707 r
F P
0 g
s
.1942 .69022 m .19978 .63553 L .17886 .62624 L p .707 .577 .707 r
F P
0 g
s
.19978 .63553 m .1942 .69022 L .2215 .69776 L p .707 .577 .707 r
F P
0 g
s
.63344 .75616 m .64426 .72201 L .67034 .73547 L p .707 .577 .707 r
F P
0 g
s
.69015 .75011 m .67933 .78426 L .65952 .76962 L p .707 .577 .707 r
F P
0 g
s
.66729 .77334 m .6617 .79034 L .63572 .77657 L p .707 .577 .707 r
F P
0 g
s
.65952 .76962 m .67034 .73547 L .69015 .75011 L p .707 .577 .707 r
F P
0 g
s
.63572 .77657 m .64131 .75958 L .66729 .77334 L p .707 .577 .707 r
F P
0 g
s
.60915 .30216 m .62335 .80535 L .64645 .79475 L p .707 .577 .707 r
F P
0 g
s
.67327 .66217 m .6677 .71685 L .6404 .70931 L p .707 .577 .707 r
F P
0 g
s
.6404 .70931 m .64598 .65463 L .67327 .66217 L p .707 .577 .707 r
F P
0 g
s
.64645 .79475 m .63225 .29155 L .60915 .30216 L p .707 .577 .707 r
F P
0 g
s
.70176 .76448 m .69094 .79863 L .67933 .78426 L p .707 .577 .707 r
F P
0 g
s
.67933 .78426 m .69015 .75011 L .70176 .76448 L p .707 .577 .707 r
F P
0 g
s
.69419 .67146 m .68861 .72615 L .6677 .71685 L p .707 .577 .707 r
F P
0 g
s
.6677 .71685 m .67327 .66217 L .69419 .67146 L p .707 .577 .707 r
F P
0 g
s
.24433 .77967 m .25516 .74552 L .22536 .73455 L p .707 .577 .707 r
F P
0 g
s
.25516 .74552 m .24433 .77967 L .27492 .78707 L p .707 .577 .707 r
F P
0 g
s
.27492 .78707 m .28575 .75292 L .25516 .74552 L p .707 .577 .707 r
F P
0 g
s
.21454 .7687 m .22536 .73455 L .19928 .72109 L p .707 .577 .707 r
F P
0 g
s
.22536 .73455 m .21454 .7687 L .24433 .77967 L p .707 .577 .707 r
F P
0 g
s
.28575 .75292 m .27492 .78707 L .30332 .79019 L p .707 .577 .707 r
F P
0 g
s
.30332 .79019 m .31414 .75604 L .28575 .75292 L p .707 .577 .707 r
F P
0 g
s
.69855 .80284 m .69296 .81983 L .68142 .80524 L p .707 .577 .707 r
F P
0 g
s
.68142 .80524 m .68702 .78825 L .69855 .80284 L p .707 .577 .707 r
F P
0 g
s
.34303 .64486 m .33745 .69954 L .3538 .69267 L p .707 .577 .707 r
F P
0 g
s
.3538 .69267 m .35937 .63799 L .34303 .64486 L p .707 .577 .707 r
F P
0 g
s
.17886 .62624 m .17329 .68092 L .1942 .69022 L p .707 .577 .707 r
F P
0 g
s
.39055 .80749 m .37635 .30429 L .35859 .29406 L p .707 .577 .707 r
F P
0 g
s
.37635 .30429 m .39055 .80749 L .42026 .81546 L p .707 .577 .707 r
F P
0 g
s
.17329 .68092 m .17886 .62624 L .16638 .6161 L p .707 .577 .707 r
F P
0 g
s
.18846 .75524 m .19928 .72109 L .17947 .70645 L p .707 .577 .707 r
F P
0 g
s
.19928 .72109 m .18846 .75524 L .21454 .7687 L p .707 .577 .707 r
F P
0 g
s
.31414 .75604 m .30332 .79019 L .32674 .78871 L p .707 .577 .707 r
F P
0 g
s
.32674 .78871 m .33756 .75455 L .31414 .75604 L p .707 .577 .707 r
F P
0 g
s
.24651 .84452 m .2521 .82753 L .22241 .81626 L p .707 .577 .707 r
F P
0 g
s
.2521 .82753 m .24651 .84452 L .27701 .8522 L p .707 .577 .707 r
F P
0 g
s
.27701 .8522 m .28261 .8352 L .2521 .82753 L p .707 .577 .707 r
F P
0 g
s
.21681 .83325 m .22241 .81626 L .19642 .8025 L p .707 .577 .707 r
F P
0 g
s
.22241 .81626 m .21681 .83325 L .24651 .84452 L p .707 .577 .707 r
F P
0 g
s
.28261 .8352 m .27701 .8522 L .30534 .85553 L p .707 .577 .707 r
F P
0 g
s
.30534 .85553 m .31093 .83853 L .28261 .8352 L p .707 .577 .707 r
F P
0 g
s
.17947 .70645 m .16865 .7406 L .18846 .75524 L p .707 .577 .707 r
F P
0 g
s
.63225 .29155 m .64645 .79475 L .65645 .78314 L p .707 .577 .707 r
F P
0 g
s
.65645 .78314 m .64225 .27994 L .63225 .29155 L p .707 .577 .707 r
F P
0 g
s
.16638 .6161 m .16081 .67078 L .17329 .68092 L p .707 .577 .707 r
F P
0 g
s
.68702 .78825 m .68142 .80524 L .6617 .79034 L p .707 .577 .707 r
F P
0 g
s
.6617 .79034 m .66729 .77334 L .68702 .78825 L p .707 .577 .707 r
F P
0 g
s
.19642 .8025 m .19083 .81949 L .21681 .83325 L p .707 .577 .707 r
F P
0 g
s
.35937 .63799 m .3538 .69267 L .3609 .68381 L p .707 .577 .707 r
F P
0 g
s
.3609 .68381 m .36648 .62913 L .35937 .63799 L p .707 .577 .707 r
F P
0 g
s
.16865 .7406 m .17947 .70645 L .16786 .69207 L p .707 .577 .707 r
F P
0 g
s
.19083 .81949 m .19642 .8025 L .1767 .78759 L p .707 .577 .707 r
F P
0 g
s
.33756 .75455 m .32674 .78871 L .34289 .78277 L p .707 .577 .707 r
F P
0 g
s
.34289 .78277 m .35371 .74862 L .33756 .75455 L p .707 .577 .707 r
F P
0 g
s
.16081 .67078 m .16638 .6161 L .16356 .60611 L p .707 .577 .707 r
F P
0 g
s
.31093 .83853 m .30534 .85553 L .32872 .85418 L p .707 .577 .707 r
F P
0 g
s
.32872 .85418 m .33431 .83719 L .31093 .83853 L p .707 .577 .707 r
F P
0 g
s
.1767 .78759 m .17111 .80458 L .19083 .81949 L p .707 .577 .707 r
F P
0 g
s
.16786 .69207 m .15704 .72622 L .16865 .7406 L p .707 .577 .707 r
F P
0 g
s
.37279 .79726 m .35859 .29406 L .35451 .28258 L p .707 .577 .707 r
F P
0 g
s
.35859 .29406 m .37279 .79726 L .39055 .80749 L p .707 .577 .707 r
F P
0 g
s
.16356 .60611 m .15799 .66079 L .16081 .67078 L p .707 .577 .707 r
F P
0 g
s
.17111 .80458 m .1767 .78759 L .16516 .773 L p .707 .577 .707 r
F P
0 g
s
.15704 .72622 m .16786 .69207 L .1656 .67936 L p .707 .577 .707 r
F P
0 g
s
.36648 .62913 m .3609 .68381 L .35808 .67382 L p .707 .577 .707 r
F P
0 g
s
.35808 .67382 m .36366 .61914 L .36648 .62913 L p .707 .577 .707 r
F P
0 g
s
.33431 .83719 m .32872 .85418 L .34485 .8483 L p .707 .577 .707 r
F P
0 g
s
.34485 .8483 m .35044 .8313 L .33431 .83719 L p .707 .577 .707 r
F P
0 g
s
.16516 .773 m .15957 .78999 L .17111 .80458 L p .707 .577 .707 r
F P
0 g
s
.35371 .74862 m .34289 .78277 L .35019 .77297 L p .707 .577 .707 r
F P
0 g
s
.35019 .77297 m .36101 .73882 L .35371 .74862 L p .707 .577 .707 r
F P
0 g
s
.15799 .66079 m .16356 .60611 L .17067 .59725 L p .707 .577 .707 r
F P
0 g
s
.64225 .27994 m .65645 .78314 L .65428 .77704 L p .707 .577 .707 r
F P
0 g
s
.65428 .77704 m .65255 .77216 L p .65209 .75001 L .707 .577 .707 r
F P
0 g
s
.65209 .75001 m .64225 .27994 L .65428 .77704 L .707 .577 .707 r
F
.65228 .76689 m .64225 .27994 L .65255 .77216 L F
.65237 .77166 m .63817 .26847 L .64225 .27994 L p F P
0 g
s
.63817 .26847 m .65237 .77166 L .63461 .76144 L p .707 .577 .707 r
F P
0 g
s
.65908 .59667 m .6535 .65135 L .6638 .65592 L p .707 .577 .707 r
F P
0 g
s
.6638 .65592 m .67441 .66064 L p .67025 .64329 L .707 .577 .707 r
F P
0 g
s
.67025 .64329 m .65908 .59667 L .6638 .65592 L .707 .577 .707 r
F
.6466 .58653 m .64411 .61091 L p .6535 .65135 L F P
0 g
s
.64591 .64518 m .6535 .65135 L p .64411 .61091 L .707 .577 .707 r
F P
0 g
s
.6535 .65135 m .65908 .59667 L .6466 .58653 L p .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64808 .63841 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.64886 .68693 m .65035 .68222 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65035 .68222 m .65968 .65278 L p .64883 .6852 L .707 .577 .707 r
F P
0 g
s
.65968 .65278 m .64886 .68693 L .66867 .70157 L p .707 .577 .707 r
F P
0 g
s
.64808 .63841 m .63725 .67256 L .64886 .68693 L p .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .65691 .68978 L .64608 .67608 L p .707 .577 .707 r
F P
0 g
s
.64608 .67608 m .64538 .67519 L p .64649 .68109 L .707 .577 .707 r
F P
0 g
s
.65132 .70678 m .64608 .67608 L .64649 .68109 L .707 .577 .707 r
F
.64411 .61091 m .64102 .64121 L .64591 .64518 L p F P
0 g
s
.65255 .77216 m .65237 .77166 L p .65228 .76689 L .707 .577 .707 r
F P
0 g
s
.1656 .67936 m .15478 .71351 L .15704 .72622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15957 .78999 m .16516 .773 L .16295 .76015 L p .707 .577 .707 r
F P
0 g
s
.17067 .59725 m .16509 .65193 L .15799 .66079 L p .707 .577 .707 r
F P
0 g
s
.15478 .71351 m .1656 .67936 L .1729 .66956 L p .707 .577 .707 r
F P
0 g
s
.35044 .8313 m .34485 .8483 L .35217 .83845 L p .707 .577 .707 r
F P
0 g
s
.35217 .83845 m .35776 .82146 L .35044 .8313 L p .707 .577 .707 r
F P
0 g
s
.16295 .76015 m .15735 .77714 L .15957 .78999 L p .707 .577 .707 r
F P
0 g
s
.35451 .28258 m .36871 .78578 L .37279 .79726 L p .707 .577 .707 r
F P
0 g
s
.36871 .78578 m .35451 .28258 L .36451 .27097 L p .707 .577 .707 r
F P
0 g
s
.36366 .61914 m .35808 .67382 L .3456 .66368 L p .707 .577 .707 r
F P
0 g
s
.3456 .66368 m .35118 .609 L .36366 .61914 L p .707 .577 .707 r
F P
0 g
s
.36101 .73882 m .35019 .77297 L .34793 .76026 L p .707 .577 .707 r
F P
0 g
s
.34793 .76026 m .35875 .72611 L .36101 .73882 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16509 .65193 m .17067 .59725 L .18701 .59038 L p .707 .577 .707 r
F P
0 g
s
.1729 .66956 m .16208 .70371 L .15478 .71351 L p .707 .577 .707 r
F P
0 g
s
.15735 .77714 m .16295 .76015 L .17026 .7503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63461 .76144 m .62041 .25824 L .63817 .26847 L p .707 .577 .707 r
F P
0 g
s
.18701 .59038 m .18144 .64506 L .16509 .65193 L p .707 .577 .707 r
F P
0 g
s
.16208 .70371 m .1729 .66956 L .18905 .66363 L p .707 .577 .707 r
F P
0 g
s
.35776 .82146 m .35217 .83845 L .34995 .8256 L p .707 .577 .707 r
F P
0 g
s
.34995 .8256 m .35554 .80861 L .35776 .82146 L p .707 .577 .707 r
F P
0 g
s
.17026 .7503 m .16467 .76729 L .15735 .77714 L p .707 .577 .707 r
F P
0 g
s
.35118 .609 m .3456 .66368 L .32469 .65439 L p .707 .577 .707 r
F P
0 g
s
.32469 .65439 m .33027 .59971 L .35118 .609 L p .707 .577 .707 r
F P
0 g
s
.35875 .72611 m .34793 .76026 L .33632 .74589 L p .707 .577 .707 r
F P
0 g
s
.33632 .74589 m .34715 .71173 L .35875 .72611 L p .707 .577 .707 r
F P
0 g
s
.18144 .64506 m .18701 .59038 L .21099 .58618 L p .707 .577 .707 r
F P
0 g
s
.18905 .66363 m .17823 .69778 L .16208 .70371 L p .707 .577 .707 r
F P
0 g
s
.37871 .77417 m .36451 .27097 L .38762 .26037 L p .707 .577 .707 r
F P
0 g
s
.36451 .27097 m .37871 .77417 L .36871 .78578 L p .707 .577 .707 r
F P
0 g
s
.16467 .76729 m .17026 .7503 L .1864 .74442 L p .707 .577 .707 r
F P
0 g
s
.33027 .59971 m .32469 .65439 L .29739 .64685 L p .707 .577 .707 r
F P
0 g
s
.29739 .64685 m .30297 .59216 L .33027 .59971 L p .707 .577 .707 r
F P
0 g
s
.21099 .58618 m .20542 .64086 L .18144 .64506 L p .707 .577 .707 r
F P
0 g
s
.17823 .69778 m .18905 .66363 L .21247 .66215 L p .707 .577 .707 r
F P
0 g
s
.20542 .64086 m .21099 .58618 L .24026 .58505 L p .707 .577 .707 r
F P
0 g
s
.35554 .80861 m .34995 .8256 L .33841 .81101 L p .707 .577 .707 r
F P
0 g
s
.33841 .81101 m .34401 .79402 L .35554 .80861 L p .707 .577 .707 r
F P
0 g
s
.1864 .74442 m .1808 .76141 L .16467 .76729 L p .707 .577 .707 r
F P
0 g
s
.34715 .71173 m .33632 .74589 L .31651 .73125 L p .707 .577 .707 r
F P
0 g
s
.31651 .73125 m .32733 .6971 L .34715 .71173 L p .707 .577 .707 r
F P
0 g
s
.62041 .25824 m .63461 .76144 L .6049 .75346 L p .707 .577 .707 r
F P
0 g
s
.6049 .75346 m .5907 .25027 L .62041 .25824 L p .707 .577 .707 r
F P
0 g
s
.30297 .59216 m .29739 .64685 L .26638 .6418 L p .707 .577 .707 r
F P
0 g
s
.26638 .6418 m .27195 .58712 L .30297 .59216 L p .707 .577 .707 r
F P
0 g
s
.23469 .63973 m .24026 .58505 L .27195 .58712 L p .707 .577 .707 r
F P
0 g
s
.24026 .58505 m .23469 .63973 L .20542 .64086 L p .707 .577 .707 r
F P
0 g
s
.21247 .66215 m .20165 .6963 L .17823 .69778 L p .707 .577 .707 r
F P
0 g
s
.27195 .58712 m .26638 .6418 L .23469 .63973 L p .707 .577 .707 r
F P
0 g
s
.20165 .6963 m .21247 .66215 L .24087 .66526 L p .707 .577 .707 r
F P
0 g
s
.1808 .76141 m .1864 .74442 L .20977 .74307 L p .707 .577 .707 r
F P
0 g
s
.32733 .6971 m .31651 .73125 L .29043 .71779 L p .707 .577 .707 r
F P
0 g
s
.29043 .71779 m .30125 .68364 L .32733 .6971 L p .707 .577 .707 r
F P
0 g
s
.38762 .26037 m .40182 .76357 L .37871 .77417 L p .707 .577 .707 r
F P
0 g
s
.40182 .76357 m .38762 .26037 L .42157 .25182 L p .707 .577 .707 r
F P
0 g
s
.73272 .67323 m .7383 .61855 L .70729 .6135 L p .707 .577 .707 r
F P
0 g
s
.7383 .61855 m .73272 .67323 L .76442 .6753 L p .707 .577 .707 r
F P
0 g
s
.76442 .6753 m .76999 .62061 L .7383 .61855 L p .707 .577 .707 r
F P
0 g
s
.34401 .79402 m .33841 .81101 L .31869 .7961 L p .707 .577 .707 r
F P
0 g
s
.31869 .7961 m .32428 .77911 L .34401 .79402 L p .707 .577 .707 r
F P
0 g
s
.20977 .74307 m .20418 .76007 L .1808 .76141 L p .707 .577 .707 r
F P
0 g
s
.76999 .62061 m .76442 .6753 L .79368 .67417 L p .707 .577 .707 r
F P
0 g
s
.79368 .67417 m .79926 .61949 L .76999 .62061 L p .707 .577 .707 r
F P
0 g
s
.70171 .66818 m .70729 .6135 L .67999 .60596 L p .707 .577 .707 r
F P
0 g
s
.70729 .6135 m .70171 .66818 L .73272 .67323 L p .707 .577 .707 r
F P
0 g
s
.24087 .66526 m .23004 .69941 L .20165 .6963 L p .707 .577 .707 r
F P
0 g
s
.23004 .69941 m .24087 .66526 L .27146 .67267 L p .707 .577 .707 r
F P
0 g
s
.30125 .68364 m .29043 .71779 L .26064 .70682 L p .707 .577 .707 r
F P
0 g
s
.26064 .70682 m .27146 .67267 L .30125 .68364 L p .707 .577 .707 r
F P
0 g
s
.27146 .67267 m .26064 .70682 L .23004 .69941 L p .707 .577 .707 r
F P
0 g
s
.5907 .25027 m .6049 .75346 L .56615 .74852 L p .707 .577 .707 r
F P
0 g
s
.56615 .74852 m .55195 .24533 L .5907 .25027 L p .707 .577 .707 r
F P
0 g
s
.79926 .61949 m .79368 .67417 L .81766 .66997 L p .707 .577 .707 r
F P
0 g
s
.81766 .66997 m .82324 .61529 L .79926 .61949 L p .707 .577 .707 r
F P
0 g
s
.20418 .76007 m .20977 .74307 L .2381 .7464 L p .707 .577 .707 r
F P
0 g
s
.67441 .66064 m .67999 .60596 L .65908 .59667 L p .707 .577 .707 r
F P
0 g
s
.67999 .60596 m .67441 .66064 L .70171 .66818 L p .707 .577 .707 r
F P
0 g
s
.32428 .77911 m .31869 .7961 L .29271 .78234 L p .707 .577 .707 r
F P
0 g
s
.29271 .78234 m .2983 .76535 L .32428 .77911 L p .707 .577 .707 r
F P
0 g
s
.72455 .726 m .73537 .69185 L .70557 .68088 L p .707 .577 .707 r
F P
0 g
s
.73537 .69185 m .72455 .726 L .75514 .7334 L p .707 .577 .707 r
F P
0 g
s
.75514 .7334 m .76596 .69925 L .73537 .69185 L p .707 .577 .707 r
F P
0 g
s
.2381 .7464 m .2325 .7634 L .20418 .76007 L p .707 .577 .707 r
F P
0 g
s
.69475 .71503 m .70557 .68088 L .67949 .66742 L p .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .70262 .71845 L .69896 .71651 L p .707 .577 .707 r
F P
0 g
s
.70557 .68088 m .69475 .71503 L .69894 .71657 L p .707 .577 .707 r
F P
0 g
s
.70835 .68748 m .70557 .68088 L .69894 .71657 L .707 .577 .707 r
F
.67949 .66742 m .66867 .70157 L .69475 .71503 L p F P
0 g
s
.69896 .71651 m .67664 .70469 L p .69421 .7312 L .707 .577 .707 r
F P
0 g
s
.69703 .73545 m .69896 .71651 L .69421 .7312 L .707 .577 .707 r
F
.69894 .71657 m .72455 .726 L p .70835 .68748 L F P
0 g
s
.43577 .75501 m .42157 .25182 L .46303 .24614 L p .707 .577 .707 r
F P
0 g
s
.42157 .25182 m .43577 .75501 L .40182 .76357 L p .707 .577 .707 r
F P
0 g
s
.76596 .69925 m .75514 .7334 L .78353 .73652 L p .707 .577 .707 r
F P
0 g
s
.78353 .73652 m .79436 .70237 L .76596 .69925 L p .707 .577 .707 r
F P
0 g
s
.2325 .7634 m .2381 .7464 L .2686 .75408 L p .707 .577 .707 r
F P
0 g
s
.2983 .76535 m .29271 .78234 L .26301 .77107 L p .707 .577 .707 r
F P
0 g
s
.26301 .77107 m .2686 .75408 L .2983 .76535 L p .707 .577 .707 r
F P
0 g
s
.72672 .74672 m .73232 .72972 L .70262 .71845 L p .707 .577 .707 r
F P
0 g
s
.73232 .72972 m .72672 .74672 L .75723 .75439 L p .707 .577 .707 r
F P
0 g
s
.75723 .75439 m .76282 .7374 L .73232 .72972 L p .707 .577 .707 r
F P
0 g
s
.55195 .24533 m .56615 .74852 L .52216 .7471 L p .707 .577 .707 r
F P
0 g
s
.52216 .7471 m .50796 .24391 L .55195 .24533 L p .707 .577 .707 r
F P
0 g
s
.2686 .75408 m .26301 .77107 L .2325 .7634 L p .707 .577 .707 r
F P
0 g
s
.70262 .71845 m .69703 .73545 L .72672 .74672 L p .707 .577 .707 r
F P
0 g
s
.82324 .61529 m .81766 .66997 L .83401 .6631 L p .707 .577 .707 r
F P
0 g
s
.83401 .6631 m .83958 .60842 L .82324 .61529 L p .707 .577 .707 r
F P
0 g
s
.66867 .70157 m .67949 .66742 L .65968 .65278 L p .707 .577 .707 r
F P
0 g
s
.76282 .7374 m .75723 .75439 L .78555 .75772 L p .707 .577 .707 r
F P
0 g
s
.78555 .75772 m .79115 .74072 L .76282 .7374 L p .707 .577 .707 r
F P
0 g
s
.79436 .70237 m .78353 .73652 L .80695 .73504 L p .707 .577 .707 r
F P
0 g
s
.80695 .73504 m .81777 .70089 L .79436 .70237 L p .707 .577 .707 r
F P
0 g
s
.47723 .74934 m .46303 .24614 L .50796 .24391 L p .707 .577 .707 r
F P
0 g
s
.46303 .24614 m .47723 .74934 L .43577 .75501 L p .707 .577 .707 r
F P
0 g
s
.67664 .70469 m .67104 .72168 L .69703 .73545 L p .707 .577 .707 r
F P
0 g
s
.50796 .24391 m .52216 .7471 L .47723 .74934 L p .707 .577 .707 r
F P
0 g
s
.67104 .72168 m .67664 .70469 L .65691 .68978 L p .707 .577 .707 r
F P
0 g
s
.79115 .74072 m .78555 .75772 L .80893 .75638 L p .707 .577 .707 r
F P
0 g
s
.80893 .75638 m .81452 .73938 L .79115 .74072 L p .707 .577 .707 r
F P
0 g
s
.65691 .68978 m .65132 .70678 L .67104 .72168 L p .707 .577 .707 r
F P
0 g
s
.81777 .70089 m .80695 .73504 L .8231 .72911 L p .707 .577 .707 r
F P
0 g
s
.8231 .72911 m .83393 .69496 L .81777 .70089 L p .707 .577 .707 r
F P
0 g
s
.83958 .60842 m .83401 .6631 L .84112 .65424 L p .707 .577 .707 r
F P
0 g
s
.84112 .65424 m .84669 .59955 L .83958 .60842 L p .707 .577 .707 r
F P
0 g
s
.64102 .64121 m .6466 .58653 L .64377 .57654 L p .707 .577 .707 r
F P
0 g
s
.81452 .73938 m .80893 .75638 L .82506 .75049 L p .707 .577 .707 r
F P
0 g
s
.82506 .75049 m .83066 .7335 L .81452 .73938 L p .707 .577 .707 r
F P
0 g
s
.64538 .67519 m .63978 .69219 L .65132 .70678 L p .707 .577 .707 r
F P
0 g
s
.63725 .67256 m .64808 .63841 L .64581 .62569 L p .707 .577 .707 r
F P
0 g
s
.63989 .63721 m .64102 .64121 L p .64152 .62946 L .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .63499 .65985 L .63725 .67256 L p .707 .577 .707 r
F P
0 g
s
.64581 .62569 m .65312 .61589 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63499 .65985 m .63542 .6585 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.63542 .6585 m .64581 .62569 L p .63528 .65914 L .707 .577 .707 r
F P
0 g
s
.64377 .57654 m .6382 .63122 L .63989 .63721 L p .707 .577 .707 r
F P
0 g
s
.64152 .62946 m .64377 .57654 L .63989 .63721 L .707 .577 .707 r
F
.83393 .69496 m .8231 .72911 L .8304 .71931 L p F P
0 g
s
.8304 .71931 m .84123 .68515 L .83393 .69496 L p .707 .577 .707 r
F P
0 g
s
.84669 .59955 m .84112 .65424 L .83829 .64425 L p .707 .577 .707 r
F P
0 g
s
.83829 .64425 m .84387 .58956 L .84669 .59955 L p .707 .577 .707 r
F P
0 g
s
.63978 .69219 m .64538 .67519 L .64316 .66234 L p .707 .577 .707 r
F P
0 g
s
.6382 .63122 m .64377 .57654 L .65088 .56767 L p .707 .577 .707 r
F P
0 g
s
.83066 .7335 m .82506 .75049 L .83238 .74064 L p .707 .577 .707 r
F P
0 g
s
.83238 .74064 m .83798 .72365 L .83066 .7335 L p .707 .577 .707 r
F P
0 g
s
.64316 .66234 m .63757 .67934 L .63978 .69219 L p .707 .577 .707 r
F P
0 g
s
.65088 .56767 m .64531 .62236 L .6382 .63122 L p .707 .577 .707 r
F P
0 g
s
.84123 .68515 m .8304 .71931 L .82814 .70659 L p .707 .577 .707 r
F P
0 g
s
.82814 .70659 m .83896 .67244 L .84123 .68515 L p .707 .577 .707 r
F P
0 g
s
.84387 .58956 m .83829 .64425 L .82582 .63411 L p .707 .577 .707 r
F P
0 g
s
.82582 .63411 m .83139 .57943 L .84387 .58956 L p .707 .577 .707 r
F P
0 g
s
.38971 .61077 m .39529 .55609 L .36428 .55104 L p .707 .577 .707 r
F P
0 g
s
.39529 .55609 m .38971 .61077 L .42141 .61283 L p .707 .577 .707 r
F P
0 g
s
.42141 .61283 m .42698 .55815 L .39529 .55609 L p .707 .577 .707 r
F P
0 g
s
.63757 .67934 m .64316 .66234 L .65048 .65249 L p .707 .577 .707 r
F P
0 g
s
.66723 .56081 m .66365 .59589 L p .64531 .62236 L .707 .577 .707 r
F P
0 g
s
.64229 .65004 m .65312 .61589 L .66927 .60996 L p .707 .577 .707 r
F P
0 g
s
.66365 .59589 m .66165 .61549 L .65475 .61839 L p .707 .577 .707 r
F P
0 g
s
.65312 .61589 m .64257 .64916 L p .63499 .65985 L .707 .577 .707 r
F P
0 g
s
.65475 .61839 m .64531 .62236 L p .66365 .59589 L .707 .577 .707 r
F P
0 g
s
.64257 .64916 m .64229 .65004 L .64214 .65025 L p .707 .577 .707 r
F P
0 g
s
.64214 .65025 m .63499 .65985 L p .64257 .64916 L .707 .577 .707 r
F P
0 g
s
.42698 .55815 m .42141 .61283 L .45067 .61171 L p .707 .577 .707 r
F P
0 g
s
.45067 .61171 m .45625 .55702 L .42698 .55815 L p .707 .577 .707 r
F P
0 g
s
.64531 .62236 m .65088 .56767 L .66723 .56081 L p .707 .577 .707 r
F P
0 g
s
.3587 .60572 m .36428 .55104 L .33698 .54349 L p .707 .577 .707 r
F P
0 g
s
.36428 .55104 m .3587 .60572 L .38971 .61077 L p .707 .577 .707 r
F P
0 g
s
.83798 .72365 m .83238 .74064 L .83016 .7278 L p .707 .577 .707 r
F P
0 g
s
.83016 .7278 m .83576 .7108 L .83798 .72365 L p .707 .577 .707 r
F P
0 g
s
.65048 .65249 m .64488 .66949 L .63757 .67934 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45625 .55702 m .45067 .61171 L .47465 .6075 L p .707 .577 .707 r
F P
0 g
s
.47465 .6075 m .48023 .55282 L .45625 .55702 L p .707 .577 .707 r
F P
0 g
s
.3314 .59818 m .33698 .54349 L .31607 .5342 L p .707 .577 .707 r
F P
0 g
s
.33698 .54349 m .3314 .59818 L .3587 .60572 L p .707 .577 .707 r
F P
0 g
s
.83896 .67244 m .82814 .70659 L .81654 .69222 L p .707 .577 .707 r
F P
0 g
s
.81654 .69222 m .82736 .65807 L .83896 .67244 L p .707 .577 .707 r
F P
0 g
s
.83139 .57943 m .82582 .63411 L .8049 .62481 L p .707 .577 .707 r
F P
0 g
s
.8049 .62481 m .81048 .57013 L .83139 .57943 L p .707 .577 .707 r
F P
0 g
s
.38154 .68763 m .39236 .65348 L .36256 .64251 L p .707 .577 .707 r
F P
0 g
s
.39236 .65348 m .38154 .68763 L .41213 .69503 L p .707 .577 .707 r
F P
0 g
s
.41213 .69503 m .42295 .66088 L .39236 .65348 L p .707 .577 .707 r
F P
0 g
s
.64488 .66949 m .65048 .65249 L .66661 .64661 L p .707 .577 .707 r
F P
0 g
s
.35174 .67666 m .36256 .64251 L .33648 .62905 L p .707 .577 .707 r
F P
0 g
s
.36256 .64251 m .35174 .67666 L .38154 .68763 L p .707 .577 .707 r
F P
0 g
s
.69121 .5566 m .68749 .5931 L p .66165 .61549 L .707 .577 .707 r
F P
0 g
s
.65844 .64411 m .66927 .60996 L .69269 .60848 L p .707 .577 .707 r
F P
0 g
s
.68749 .5931 m .68563 .61128 L .67604 .61297 L p .707 .577 .707 r
F P
0 g
s
.66927 .60996 m .65887 .64277 L p .64229 .65004 L .707 .577 .707 r
F P
0 g
s
.67604 .61297 m .66165 .61549 L p .68749 .5931 L .707 .577 .707 r
F P
0 g
s
.65887 .64277 m .65844 .64411 L .658 .64428 L p .707 .577 .707 r
F P
0 g
s
.658 .64428 m .64229 .65004 L p .65887 .64277 L .707 .577 .707 r
F P
0 g
s
.66165 .61549 m .66723 .56081 L .69121 .5566 L p .707 .577 .707 r
F P
0 g
s
.42295 .66088 m .41213 .69503 L .44052 .69815 L p .707 .577 .707 r
F P
0 g
s
.44052 .69815 m .45135 .664 L .42295 .66088 L p .707 .577 .707 r
F P
0 g
s
.83576 .7108 m .83016 .7278 L .81863 .7132 L p .707 .577 .707 r
F P
0 g
s
.81863 .7132 m .82422 .69621 L .83576 .7108 L p .707 .577 .707 r
F P
0 g
s
.66661 .64661 m .66102 .6636 L .64488 .66949 L p .707 .577 .707 r
F P
0 g
s
.48023 .55282 m .47465 .6075 L .491 .60063 L p .707 .577 .707 r
F P
0 g
s
.491 .60063 m .49657 .54595 L .48023 .55282 L p .707 .577 .707 r
F P
0 g
s
.31607 .5342 m .31049 .58888 L .3314 .59818 L p .707 .577 .707 r
F P
0 g
s
.31049 .58888 m .31607 .5342 L .30359 .52406 L p .707 .577 .707 r
F P
0 g
s
.32566 .6632 m .33648 .62905 L .31667 .61441 L p .707 .577 .707 r
F P
0 g
s
.33648 .62905 m .32566 .6632 L .35174 .67666 L p .707 .577 .707 r
F P
0 g
s
.45135 .664 m .44052 .69815 L .46394 .69667 L p .707 .577 .707 r
F P
0 g
s
.46394 .69667 m .47477 .66252 L .45135 .664 L p .707 .577 .707 r
F P
0 g
s
.81048 .57013 m .8049 .62481 L .7776 .61727 L p .707 .577 .707 r
F P
0 g
s
.7776 .61727 m .78318 .56259 L .81048 .57013 L p .707 .577 .707 r
F P
0 g
s
.82736 .65807 m .81654 .69222 L .79672 .67758 L p .707 .577 .707 r
F P
0 g
s
.79672 .67758 m .80755 .64343 L .82736 .65807 L p .707 .577 .707 r
F P
0 g
s
.38371 .75248 m .38931 .73549 L .35961 .72422 L p .707 .577 .707 r
F P
0 g
s
.38931 .73549 m .38371 .75248 L .41422 .76016 L p .707 .577 .707 r
F P
0 g
s
.41422 .76016 m .41981 .74316 L .38931 .73549 L p .707 .577 .707 r
F P
0 g
s
.68563 .61128 m .69121 .5566 L .72048 .55548 L p .707 .577 .707 r
F P
0 g
s
.35402 .74121 m .35961 .72422 L .33363 .71046 L p .707 .577 .707 r
F P
0 g
s
.35961 .72422 m .35402 .74121 L .38371 .75248 L p .707 .577 .707 r
F P
0 g
s
.66102 .6636 m .66661 .64661 L .68999 .64527 L p .707 .577 .707 r
F P
0 g
s
.41981 .74316 m .41422 .76016 L .44254 .76349 L p .707 .577 .707 r
F P
0 g
s
.44254 .76349 m .44814 .74649 L .41981 .74316 L p .707 .577 .707 r
F P
0 g
s
.31667 .61441 m .30585 .64856 L .32566 .6632 L p .707 .577 .707 r
F P
0 g
s
.72048 .55548 m .71705 .58907 L p .68563 .61128 L .707 .577 .707 r
F P
0 g
s
.68186 .64263 m .69269 .60848 L .72108 .6116 L p .707 .577 .707 r
F P
0 g
s
.71705 .58907 m .7149 .61016 L .7025 .61064 L p .707 .577 .707 r
F P
0 g
s
.69269 .60848 m .68271 .63997 L p .65844 .64411 L .707 .577 .707 r
F P
0 g
s
.7025 .61064 m .68563 .61128 L p .71705 .58907 L .707 .577 .707 r
F P
0 g
s
.68271 .63997 m .68186 .64263 L .68087 .6427 L p .707 .577 .707 r
F P
0 g
s
.68087 .6427 m .65844 .64411 L p .68271 .63997 L .707 .577 .707 r
F P
0 g
s
.30359 .52406 m .29801 .57874 L .31049 .58888 L p .707 .577 .707 r
F P
0 g
s
.82422 .69621 m .81863 .7132 L .7989 .6983 L p .707 .577 .707 r
F P
0 g
s
.7989 .6983 m .8045 .6813 L .82422 .69621 L p .707 .577 .707 r
F P
0 g
s
.33363 .71046 m .32803 .72745 L .35402 .74121 L p .707 .577 .707 r
F P
0 g
s
.68999 .64527 m .68439 .66226 L .66102 .6636 L p .707 .577 .707 r
F P
0 g
s
.78318 .56259 m .7776 .61727 L .74659 .61222 L p .707 .577 .707 r
F P
0 g
s
.74659 .61222 m .75217 .55754 L .78318 .56259 L p .707 .577 .707 r
F P
0 g
s
.49657 .54595 m .491 .60063 L .49811 .59177 L p .707 .577 .707 r
F P
0 g
s
.49811 .59177 m .50368 .53709 L .49657 .54595 L p .707 .577 .707 r
F P
0 g
s
.30585 .64856 m .31667 .61441 L .30507 .60003 L p .707 .577 .707 r
F P
0 g
s
.7149 .61016 m .72048 .55548 L .75217 .55754 L p .707 .577 .707 r
F P
0 g
s
.32803 .72745 m .33363 .71046 L .3139 .69555 L p .707 .577 .707 r
F P
0 g
s
.75217 .55754 m .74659 .61222 L .7149 .61016 L p .707 .577 .707 r
F P
0 g
s
.47477 .66252 m .46394 .69667 L .48009 .69074 L p .707 .577 .707 r
F P
0 g
s
.48009 .69074 m .49092 .65658 L .47477 .66252 L p .707 .577 .707 r
F P
0 g
s
.80755 .64343 m .79672 .67758 L .77431 .66601 L p .707 .577 .707 r
F P
0 g
s
.77851 .66754 m .77292 .68454 L .76884 .68299 L p .707 .577 .707 r
F P
0 g
s
.76884 .68299 m .74322 .67326 L p .77356 .66834 L .707 .577 .707 r
F P
0 g
s
.77356 .66834 m .77851 .66754 L .76884 .68299 L .707 .577 .707 r
F
.77587 .66119 m .80755 .64343 L .77431 .66601 L F
.74322 .67326 m .74882 .65627 L .77851 .66754 L p F P
0 g
s
.77431 .66601 m .77064 .66412 L p .77587 .66119 L .707 .577 .707 r
F P
0 g
s
.77064 .66412 m .78147 .62997 L .80755 .64343 L p .707 .577 .707 r
F P
0 g
s
.29801 .57874 m .30359 .52406 L .30076 .51407 L p .707 .577 .707 r
F P
0 g
s
.44814 .74649 m .44254 .76349 L .46592 .76214 L p .707 .577 .707 r
F P
0 g
s
.46592 .76214 m .47151 .74515 L .44814 .74649 L p .707 .577 .707 r
F P
0 g
s
.3139 .69555 m .30831 .71255 L .32803 .72745 L p .707 .577 .707 r
F P
0 g
s
.68439 .66226 m .68999 .64527 L .71831 .6486 L p .707 .577 .707 r
F P
0 g
s
.30507 .60003 m .29424 .63419 L .30585 .64856 L p .707 .577 .707 r
F P
0 g
s
.72108 .6116 m .71026 .64575 L .68186 .64263 L p .707 .577 .707 r
F P
0 g
s
.71026 .64575 m .72108 .6116 L .75167 .619 L p .707 .577 .707 r
F P
0 g
s
.8045 .6813 m .7989 .6983 L .77292 .68454 L p .707 .577 .707 r
F P
0 g
s
.77292 .68454 m .77851 .66754 L .8045 .6813 L p .707 .577 .707 r
F P
0 g
s
.78147 .62997 m .77064 .66412 L .74085 .65315 L p .707 .577 .707 r
F P
0 g
s
.74085 .65315 m .75167 .619 L .78147 .62997 L p .707 .577 .707 r
F P
0 g
s
.71831 .6486 m .71272 .66559 L .68439 .66226 L p .707 .577 .707 r
F P
0 g
s
.75167 .619 m .74085 .65315 L .71026 .64575 L p .707 .577 .707 r
F P
0 g
s
.30076 .51407 m .29519 .56875 L .29801 .57874 L p .707 .577 .707 r
F P
0 g
s
.30831 .71255 m .3139 .69555 L .30237 .68096 L p .707 .577 .707 r
F P
0 g
s
.29424 .63419 m .30507 .60003 L .3028 .58732 L p .707 .577 .707 r
F P
0 g
s
.71272 .66559 m .71831 .6486 L .74882 .65627 L p .707 .577 .707 r
F P
0 g
s
.50368 .53709 m .49811 .59177 L .49528 .58178 L p .707 .577 .707 r
F P
0 g
s
.49528 .58178 m .50086 .5271 L .50368 .53709 L p .707 .577 .707 r
F P
0 g
s
.47151 .74515 m .46592 .76214 L .48205 .75626 L p .707 .577 .707 r
F P
0 g
s
.48205 .75626 m .48765 .73927 L .47151 .74515 L p .707 .577 .707 r
F P
0 g
s
.30237 .68096 m .29677 .69795 L .30831 .71255 L p .707 .577 .707 r
F P
0 g
s
.49092 .65658 m .48009 .69074 L .48739 .68093 L p .707 .577 .707 r
F P
0 g
s
.48739 .68093 m .49822 .64678 L .49092 .65658 L p .707 .577 .707 r
F P
0 g
s
.74882 .65627 m .74322 .67326 L .71272 .66559 L p .707 .577 .707 r
F P
0 g
s
.29519 .56875 m .30076 .51407 L .30787 .50521 L p .707 .577 .707 r
F P
0 g
s
.3028 .58732 m .29198 .62147 L .29424 .63419 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29677 .69795 m .30237 .68096 L .30015 .66811 L p .707 .577 .707 r
F P
0 g
s
.30787 .50521 m .3023 .55989 L .29519 .56875 L p .707 .577 .707 r
F P
0 g
s
.29198 .62147 m .3028 .58732 L .31011 .57752 L p .707 .577 .707 r
F P
0 g
s
.48765 .73927 m .48205 .75626 L .48937 .74641 L p .707 .577 .707 r
F P
0 g
s
.48937 .74641 m .49497 .72942 L .48765 .73927 L p .707 .577 .707 r
F P
0 g
s
.30015 .66811 m .29455 .6851 L .29677 .69795 L p .707 .577 .707 r
F P
0 g
s
.50086 .5271 m .49528 .58178 L .48281 .57164 L p .707 .577 .707 r
F P
0 g
s
.48281 .57164 m .48838 .51696 L .50086 .5271 L p .707 .577 .707 r
F P
0 g
s
.49822 .64678 m .48739 .68093 L .48513 .66822 L p .707 .577 .707 r
F P
0 g
s
.48513 .66822 m .49595 .63407 L .49822 .64678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3023 .55989 m .30787 .50521 L .32422 .49834 L p .707 .577 .707 r
F P
0 g
s
.31011 .57752 m .29928 .61167 L .29198 .62147 L p .707 .577 .707 r
F P
0 g
s
.29455 .6851 m .30015 .66811 L .30747 .65826 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32422 .49834 m .31864 .55302 L .3023 .55989 L p .707 .577 .707 r
F P
0 g
s
.29928 .61167 m .31011 .57752 L .32626 .57159 L p .707 .577 .707 r
F P
0 g
s
.49497 .72942 m .48937 .74641 L .48715 .73356 L p .707 .577 .707 r
F P
0 g
s
.48715 .73356 m .49275 .71657 L .49497 .72942 L p .707 .577 .707 r
F P
0 g
s
.30747 .65826 m .30187 .67526 L .29455 .6851 L p .707 .577 .707 r
F P
0 g
s
.48838 .51696 m .48281 .57164 L .46189 .56235 L p .707 .577 .707 r
F P
0 g
s
.46189 .56235 m .46747 .50767 L .48838 .51696 L p .707 .577 .707 r
F P
0 g
s
.49595 .63407 m .48513 .66822 L .47353 .65385 L p .707 .577 .707 r
F P
0 g
s
.47353 .65385 m .48435 .6197 L .49595 .63407 L p .707 .577 .707 r
F P
0 g
s
.31864 .55302 m .32422 .49834 L .3482 .49414 L p .707 .577 .707 r
F P
0 g
s
.32626 .57159 m .31543 .60574 L .29928 .61167 L p .707 .577 .707 r
F P
0 g
s
.30187 .67526 m .30747 .65826 L .3236 .65238 L p .707 .577 .707 r
F P
0 g
s
.46747 .50767 m .46189 .56235 L .43459 .55481 L p .707 .577 .707 r
F P
0 g
s
.43459 .55481 m .44017 .50013 L .46747 .50767 L p .707 .577 .707 r
F P
0 g
s
.3482 .49414 m .34262 .54882 L .31864 .55302 L p .707 .577 .707 r
F P
0 g
s
.31543 .60574 m .32626 .57159 L .34968 .57011 L p .707 .577 .707 r
F P
0 g
s
.34262 .54882 m .3482 .49414 L .37746 .49301 L p .707 .577 .707 r
F P
0 g
s
.49275 .71657 m .48715 .73356 L .47562 .71897 L p .707 .577 .707 r
F P
0 g
s
.47562 .71897 m .48121 .70198 L .49275 .71657 L p .707 .577 .707 r
F P
0 g
s
.3236 .65238 m .31801 .66937 L .30187 .67526 L p .707 .577 .707 r
F P
0 g
s
.48435 .6197 m .47353 .65385 L .45371 .63921 L p .707 .577 .707 r
F P
0 g
s
.45371 .63921 m .46454 .60506 L .48435 .6197 L p .707 .577 .707 r
F P
0 g
s
.44017 .50013 m .43459 .55481 L .40358 .54976 L p .707 .577 .707 r
F P
0 g
s
.40358 .54976 m .40916 .49508 L .44017 .50013 L p .707 .577 .707 r
F P
0 g
s
.37189 .54769 m .37746 .49301 L .40916 .49508 L p .707 .577 .707 r
F P
0 g
s
.37746 .49301 m .37189 .54769 L .34262 .54882 L p .707 .577 .707 r
F P
0 g
s
.34968 .57011 m .33885 .60426 L .31543 .60574 L p .707 .577 .707 r
F P
0 g
s
.40916 .49508 m .40358 .54976 L .37189 .54769 L p .707 .577 .707 r
F P
0 g
s
.33885 .60426 m .34968 .57011 L .37807 .57322 L p .707 .577 .707 r
F P
0 g
s
.31801 .66937 m .3236 .65238 L .34698 .65103 L p .707 .577 .707 r
F P
0 g
s
.46454 .60506 m .45371 .63921 L .42763 .62575 L p .707 .577 .707 r
F P
0 g
s
.42763 .62575 m .43846 .5916 L .46454 .60506 L p .707 .577 .707 r
F P
0 g
s
.48121 .70198 m .47562 .71897 L .45589 .70407 L p .707 .577 .707 r
F P
0 g
s
.45589 .70407 m .46149 .68707 L .48121 .70198 L p .707 .577 .707 r
F P
0 g
s
.34698 .65103 m .34138 .66803 L .31801 .66937 L p .707 .577 .707 r
F P
0 g
s
.37807 .57322 m .36725 .60738 L .33885 .60426 L p .707 .577 .707 r
F P
0 g
s
.36725 .60738 m .37807 .57322 L .40866 .58063 L p .707 .577 .707 r
F P
0 g
s
.43846 .5916 m .42763 .62575 L .39784 .61478 L p .707 .577 .707 r
F P
0 g
s
.39784 .61478 m .40866 .58063 L .43846 .5916 L p .707 .577 .707 r
F P
0 g
s
.40866 .58063 m .39784 .61478 L .36725 .60738 L p .707 .577 .707 r
F P
0 g
s
.34138 .66803 m .34698 .65103 L .3753 .65436 L p .707 .577 .707 r
F P
0 g
s
.46149 .68707 m .45589 .70407 L .42991 .6903 L p .707 .577 .707 r
F P
0 g
s
.42991 .6903 m .4355 .67331 L .46149 .68707 L p .707 .577 .707 r
F P
0 g
s
.3753 .65436 m .36971 .67136 L .34138 .66803 L p .707 .577 .707 r
F P
0 g
s
.36971 .67136 m .3753 .65436 L .40581 .66204 L p .707 .577 .707 r
F P
0 g
s
.4355 .67331 m .42991 .6903 L .40021 .67903 L p .707 .577 .707 r
F P
0 g
s
.40021 .67903 m .40581 .66204 L .4355 .67331 L p .707 .577 .707 r
F P
0 g
s
.40581 .66204 m .40021 .67903 L .36971 .67136 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo001nOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol007Ioo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00Lgoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000Kgoo001`Ool30004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001/Ool006eoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP<006Yoo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00J7oo
001YOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVEoo`00IGoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIGoo
001UOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol006Eoo`04001JEUYF
0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001T
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001TOol0061ooaL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00Fgoo1@000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001IOol200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Moo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00EWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00EGoo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUH005YF0002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00E7oo0P0015YF00@005YFFUIJEP`000AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol005Aoo`03FUH005YF009JEPD00003FUH005YF00IJEP03001JEUYF00@0009JEP03001J
EUYF00AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000@Ool8001<Ool005=oo`04001JEP00FUH30005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUHC0002FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0027oo20000eYF
00<005YFFUH00UYF1`00AGoo001COol01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF
00EJEP<000MJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool40003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040011Ool005=oo`<0009JEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool30006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005=oo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJEP03001JEUYF
009JEP800007FUH005YFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00>Goo001COol00`00FUIJEP02FUH01000FUIJEUYF2`001eYF1@00
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF0P0025YF00<005YFFUH01UYF00<005YFFUH00eYF1000=Goo001DOol01P00FUIJEUYF001JEP<0
00IJEP04001JEUYFFUH7000015YF000000001UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YF
FUH005YF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0
009JEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002000bOol005Aoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF008000EJEP03
001JEUYF00EJEP8000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80031oo`00
EGoo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00;goo000iOolG0006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00AJEP03001JEP0002ioo`00=7oo1@000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH010000Woo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000]Ool0039oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Goo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH30000
0eYF001JEP04FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH0
1000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000_Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJEUYF1`0015YF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00@005YF000000UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP05001JEUYFFUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20002FUH60002FUH20002Ool70007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH0
1@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH00UYF00<005YFFUH00UYF0P00
0goo00<005YFFUH01@000UYF00<005YFFUH01UYF00<005YFFUH01eYF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEPh000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002ioo`8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP04001J
EUYF0005FUH20002Ool01000FUIJEP0015YF10001eYF00<005YFFUH01UYF00<005YFFUH00P002eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF
00<0009JEP03001JEUYF00EJEP03001JEP0000X000AJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH2000/Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000EJEP800003FUH005YF00AJEP03001JEP000080009JEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEPH000EJEP03001JEUYF00AJEP03
001JEUYF00=JEPD000=oo`H000EJEP03001JEUYF00AJEP06001JEUYF001JEP00;7oo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP020005FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00@005YFFUIJEP<00003
FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEP00FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH?00000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00AJEP8000QJEP03
001JEUYF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
00<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000QJEP80
00EJEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0eYF00@005YFFUH000AJEP<000QJEP8000EJEP03001JEUYF00AJEP03001JEP0000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEP<000IJEP04001JEP000003FUH01000FUIJEUYF
0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01000FUIJEP00
0eYF1@001eYF00@005YF000000=JEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP<000=JEP04001JEUYFFUH200000eYF001JEP02FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH20002FUH20002FUH01000
FUIJEUYF1@001eYF00@005YFFUIJEP<000MJEP05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUH000020006FUH20003FUH2000]Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00
FUIJEP03FUH40002FUH01000FUIJEUYF1@001eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000P000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P001EYF00<005YF00000UYF0P00;Goo000]Ool20004FUH01000FUIJEUYF300017oo2@0015YF
00@005YFFUH000IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<000QJEP03001JEUYF00AJEP80
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool00eYF001JEP02FUH500000eYF001JEP06
FUH00`00FUIJEP040009Ool70006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000002FUHC0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
00000eYF001JEP03FUH3000]Ool002aoo`04001JEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH@0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH30004FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH0000300001EYF000005YF00001UYF00@005YFFUIJEPP0009JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF008000AJEP<002eoo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF009JEP80009JEP`000MJEP@000QJEP03
001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF001JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP0000D000QJ
EP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002aoo`<0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00AJEP<000IJEP04001JEUYF
FUH70002FUH00`00FUIJEP040004FUH00`00FUIJEP09FUH20002FUH00`00FUH00006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH002eoo`00
;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH010001EYF1P002UYF
0P000UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000AJ
EP000000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003
FUH005YF00IJEP03001JEUYF00EJEP04001JEP00000^Ool002aoo`03001JEUYF009JEP04001JEUYF
FUH;0007FUH50005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40003FUH01000FUIJEUYF3@0000=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF0P0000=JEP0000000eYF2`0015YF00<005YFFUH01eYF00<005YFFUH00UYF
0`001eYF00<005YFFUH01EYF0`00;goo000]Ool01P00FUIJEUYF001JEP<000IJEP04001JEUYFFUH7
000015YF000000001UYF00@005YFFUIJEP8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH0
0`00FUH000020008FUH00`00FUIJEP03FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP800004FUH00000FUH20006FUH<0006FUH00`00FUIJEP06FUH20005
FUH00`00FUIJEP04FUH00`00FUH0000`Ool002eoo`04001JEUYFFUH200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP040006FUH01000FUIJEUYF0P000UYF1@0000=JEP0000000eYF1`001eYF
00<005YFFUH00UYF0`001EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000040007FUH;00000eYF000000020002FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH015YF00@005YFFUH002moo`00;Woo00@0
05YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00800005FUH00000FUH00005FUH40007FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000800003FUH005YF00EJEP04001JEUYFFUH30005Ool90007FUH01000FUIJEUYF0`001eYF
00D005YFFUIJEP0002ioo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YF00000P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH00P0025YF0`0000=JEP00
FUH025YF0`0000=JEP00FUH015YF00@005YFFUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00=JEP8000eoo`8000EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP03001oogoo02aoo`00;goo0P000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF
00@005YFFUIJEP@000EJEP03001JEP0000<000QJEP03001JEUYF008000AJEP03001JEUYF009JEP80
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00001JEP020006FUH0
0`00FUIJEP05FUH2000=Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF0000009JEP03001JEUYF00AJEP06001JEUYFFUH005YF1@0000=JEP00FUH02000
15YF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF000005YF0006FUH00`00FUIJEP08FUH3000<Ool30008
FUH30002FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00005FUH00`00FUIJEP02FUH2
000017oo001JEUYF2@000eYF0`0000=JEP00FUH01UYF0`000eYF0P002UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0037oo0P001UYF00<005YFFUH00P0015YF00<005YF0000;Goo000^Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0005FUH01000FUIJEUYF0P000Woo00@005YFFUH000=JEPD0009JEP04001JEUYFFUH20008FUH20002
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH3000;Ool20003FUH00`00FUIJEP02FUH20002
FUH00`00FUH0000^Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP04001JEP000004Ool01000FUIJEP0015YF0`00
00=JEP00000010000UYF0P001EYF00<005YFFUH00`0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EP0000<000Uoo`800003FUH005YF00EJEP05001JEP00FUH0000^Ool002eoo`03001JEP00009JEQ80
00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000<000Ioo`04001JEUYF0006FUH0
0`00FUIJEP05FUH60003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00MJEP03001J
EUYF00AJEPH000Eoo`8000IJEP<00003FUH007oo02eoo`00;Goo0P0000AJEP000000011oo`D0009J
EP03001JEUYF00IJEP03001JEP00009JEP05001JEUYF001JEP020008Ool01000FUIJEP001UYF00<0
05YFFUH01eYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
1000FUIJEUYF200015YF00D005YF001JEP0002moo`00;Goo00=JEP0000000eYF00<007ooOol04Woo
0`0025YF00<005YF00000UYF00D005YFFUIJEP00009JEP8000Ioo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF008002moo`00;7oo0P001EYF0P00
5Woo0P001UYF00<005YFFUH00P001EYF00D005YFFUIJEP0000Eoo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20004FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`001EYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF0P000eYF0P00;goo000/Ool20004FUH01000FUIJEP005goo0P00
15YF00D005YFFUIJEP0000IJEP80009JEP03001oogoo009oo`04001JEUYF0007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEP<000UJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP8000AJEP03001oogoo02eoo`00;7oo0P0015YF00D005YF
FUIJEP0001Qoo`800003FUH005YF00AJEP8000AJEP03001JEP0000<000=oo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH00eYF0`00
1UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF0P00;goo
000/Ool20003FUH00`00FUIJEP03FUH00`00Oomoo`0GOol30006FUH01000FUIJEP0015YF0`000Woo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00<000QJEP<000AJEP03001JEP0000@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUH0000^Ool002aoo`03001JEUYF009JEP03001JEUYF00AJEP8000ioo`<000Uoo`80
00AJEP@000MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP80
00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0008FUH00`00FUH00002000015YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP80009JEP03001oogoo02aoo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00@0
05YF000000]oo`D000Yoo`800003FUH005YF009JEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP80009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP8000IJEP03001JEUYF009JEPT0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001oogoo02aoo`00;Goo00@005YFFUH0
00IJEP03001JEUYF009JEP<000Qoo`D000aoo`8000AJEP8000EJEP04001JEUYFFUH30006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH01P00FUH00000FUH000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP8000=JEP03001JEUYF00IJEPD0009JEP03001J
EUYF00IJEP03001JEUYF00AJEP08001JEUYF001oo`00FUH002moo`00;Goo00@005YFFUH000IJEP03
001JEUYF00EJEP<000Eoo`D000ioo`03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00000015YF0`0000=JEP00FUH025YF00<0
05YF00001`0015YF00<005YFFUH015YF00@005YF0000009oo`03001JEP0002moo`00;Woo0P001eYF
00<005YFFUH01UYF00@005YF000000Aoo`<0011oo`03001JEUYF009JEP03001JEP00008000QJEP@0
0003FUH005YF00MJEP03001JEUYF00UJEP06001JEUYF001JEP001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@005YFFUH000=JEP<000MJEP03001J
EUYF00AJEQ40009oo`800003FUH007oo02moo`00;goo00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`005Goo0P000UYF00@005YFFUIJEP8000QJEP03001JEUYF00@000IJEP03001JEUYF
00UJEP03001JEP00008000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8000=JEP@000AJEP@000EJEP03001JEUYF00IJEP04001JEUYFFUH=0002FUH2000`Ool0
031oo`80009JEP`000MJEP<001Aoo`8000=JEP03001JEUYF00<000AJEP03001JEUYF00EJEPL000MJ
EPH00003FUH0000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00004FUH01000FUH007oo0`0000=JEP00FUH025YF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00<Woo0P0000=JEP00FUH015YF00@005YFFUIJ
EPL0009JEP03001JEP000080019oo`07001JEUYFFUH005YF00000Woo00IJEP00000005YF0009FUH0
1000FUIJEUYF20000eYF00@005YFFUIJEP80009JEQD000QJEP03001JEUYF00IJEP03001JEUYF009J
EP80009JEP03001JEUYF009JEP80009JEP03001JEP0000Aoo`@000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH2000aOol0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP<0011oo`06001JEUYF001JEP000Woo0eYF10001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEPD000aJEP03001JEUYF00IJEPH0009JEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00AJEP04001JEP000009Ool40002FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00AJEP@0009JEQ40009JEP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF0P0035YF00<005YF0000
10001UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`003Woo1P0015YF00<005YFFUH00eYF00@0
05YF000003Aoo`00;goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP06001J
EP00001JEP001eYF00<005YFFUH00eYF00H005YF000005YF0003Ool3FUH00`00FUIJEP03FUH30000
0eYF001JEP07FUH00`00FUIJEP03FUH00`00FUIJEP030003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUH0000EOol<
000fOol002ioo`80009JEP`000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH015YF00<005YF0000100015YF00@005YF
FUIJEPH000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP@000AJEP800003FUH0
05YF00EJEP04001JEUYF001FOol002eoo`800003FUH0000000Qoo`800003FUH0000000D000MJEP03
001JEUYF00EJEP8000=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00000goo0eYF00<005YFFUH0
0eYF0`000eYF00<005YF00001`0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP80009JEP<000MJEP05001JEUYFFUH0001EOol002eoo`<000aoo`<0
00EJEP@0009JEP03001JEUYF00MJEP<00003FUH005YF00AJEP04001JEUYFFUH20004Ool3FUH01000
FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF009JEP03001oogoo
05=oo`00;7oo0`0047oo0P001EYF00<005YF00000`0025YF00<005YFFUH00P0015YF00<005YFFUH0
0UYF0P0017oo0eYF00<005YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
009JEP07001JEUYFFUH005YF0000E7oo000/Ool01000FUH000004Goo0`0000=JEP00FUH0200015YF
00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<007ooOol00goo0eYF0P000UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YF0000009JEP8000=JEP07001JEUYFFUH005YF0000E7oo000/Ool0
1@00FUH005YF00004goo20000eYF0`0000=JEP00FUH01UYF0`000eYF0P001Goo0UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEP00009JEP07001JEUYF
FUH005YF0000E7oo000/Ool00`00FUIJEP02FUH00`00Oomoo`0COol50002FUH01000FUIJEUYF0P00
25YF0P000UYF0P001Woo00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH0
05YF0003FUH20003FUH00`00FUH0001EOol002eoo`03001JEUYF009JEP03001oogoo01=oo`<00003
Ool0000000@0009JEP8000EJEP03001JEUYF008000Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00H005YFFUH005YF001EOol002eoo`03001JEUYF009JEP8001io
o`H000=JEP03001JEUYF009JEP03001oogoo00Eoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000IJEP05001JEP00FUH0001EOol002ioo`04001JEUYF0002FUH00`00Oomoo`0QOol3
0006FUH00`00Oomoo`05Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH70004FUH0
0`00FUH00002001FOol002ioo`04001JEUYF0003FUH00`00Oomoo`0ROol00`00FUIJEP04FUH20006
Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP80009JEP05
001JEP00FUH0001FOol002moo`8000EJEP03001oogoo029oo`8000AJEP03001JEP0000Ioo`8000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEUYF0004FUH00`00FUIJEP04FUH20003FUH2001FOol0031oo`03001J
EUYF00AJEP03001oogoo02=oo`04001JEUYF0003FUH00`00Oomoo`05Ool200000eYF001JEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3
0005FUH00`00FUIJEP04FUH20004FUH00`00Oomoo`1DOol0035oo`03001JEUYF00=JEP<002Aoo`<0
00AJEP03001oogoo00Ioo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00EJEP<000MJEP03001JEUYF00AJEP03001JEP0000=JEP03001oogoo
05Aoo`00<Woo00<005YFFUH00UYF00<005YFFUH00P0097oo00<005YFFUH00UYF00<007ooOol02Goo
10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEP0005Eoo`00<goo
0P0000=JEP00FUH015YF0P008goo00<005YFFUH00P003goo1@0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF00T005YFFUIJEP00
FUH005YF0000EGoo000eOol20007FUH3000POol00`00FUIJEP02000DOol60002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF3`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00`000UYF00<007ooOol0Dgoo000fOol20006FUH00`00FUIJEP02000OOol200000eYF001oo`0I
OolP0008FUH600000eYF001JEP07FUH00`00FUIJEP04FUH02000FUIJEP00Ool005YF001FOol003Qo
o`8000AJEP03001JEUYF009JEP<001eoo`03001JEP0003Ioo`800003FUH005YF00QJEPX000AJEP03
001JEUYF00AJEP04001JEP000002Ool00`00FUH0001FOol003Yoo`800003FUH005YF00MJEP@001Uo
o`03001JEP0003Qoo`<000MJEP03001JEUYF00AJEQ40009oo`800003FUH007oo05Ioo`00?7oo0`00
25YF00<005YFFUH010005Goo0P00?7oo0P001EYF00<005YFFUH01UYF00@005YFFUIJEPd0009JEP80
05Moo`00?goo0P001UYF00<005YFFUH015YF1P003Goo1000?Woo0`0000=JEP00FUH025YF00<005YF
FUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005Qoo`00@Goo0P000eYF00<005YFFUH01eYF00@0
05YFFUIJEPd0009JEP80045oo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
001HOol004=oo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
0016Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001IOol004Eoo`<000MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001:Ool60004FUH00`00FUIJEP03FUH0
1000FUH00000Fgoo0018Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001A
Ool<001MOol004aoo`H000AJEP04001JEUYFFUH6002mOol0059oo`P00<=oo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59579 .75929 m .59924 .70419 L .56813 .70034 L p .707 .577 .707 r
F P
0 g
s
.59924 .70419 m .59579 .75929 L .62757 .76027 L p .707 .577 .707 r
F P
0 g
s
.62757 .76027 m .63102 .70517 L .59924 .70419 L p .707 .577 .707 r
F P
0 g
s
.63102 .70517 m .62757 .76027 L .65691 .75829 L p .707 .577 .707 r
F P
0 g
s
.65691 .75829 m .66036 .70319 L .63102 .70517 L p .707 .577 .707 r
F P
0 g
s
.56468 .75543 m .56813 .70034 L .54073 .69399 L p .707 .577 .707 r
F P
0 g
s
.56813 .70034 m .56468 .75543 L .59579 .75929 L p .707 .577 .707 r
F P
0 g
s
.66036 .70319 m .65691 .75829 L .68093 .75354 L p .707 .577 .707 r
F P
0 g
s
.68093 .75354 m .68438 .69844 L .66036 .70319 L p .707 .577 .707 r
F P
0 g
s
.53728 .74909 m .54073 .69399 L .51973 .68578 L p .707 .577 .707 r
F P
0 g
s
.54073 .69399 m .53728 .74909 L .56468 .75543 L p .707 .577 .707 r
F P
0 g
s
.59099 .8152 m .59774 .77954 L .5671 .77195 L p .707 .577 .707 r
F P
0 g
s
.59774 .77954 m .59099 .8152 L .62235 .81957 L p .707 .577 .707 r
F P
0 g
s
.62235 .81957 m .6291 .78391 L .59774 .77954 L p .707 .577 .707 r
F P
0 g
s
.6291 .78391 m .62235 .81957 L .65135 .82027 L p .707 .577 .707 r
F P
0 g
s
.65135 .82027 m .6581 .7846 L .6291 .78391 L p .707 .577 .707 r
F P
0 g
s
.56034 .80761 m .5671 .77195 L .54017 .76186 L p .707 .577 .707 r
F P
0 g
s
.5671 .77195 m .56034 .80761 L .59099 .8152 L p .707 .577 .707 r
F P
0 g
s
.59237 .8439 m .59586 .82611 L .56526 .81832 L p .707 .577 .707 r
F P
0 g
s
.59586 .82611 m .59237 .8439 L .62369 .84844 L p .707 .577 .707 r
F P
0 g
s
.62369 .84844 m .62719 .83064 L .59586 .82611 L p .707 .577 .707 r
F P
0 g
s
.68438 .69844 m .68093 .75354 L .69729 .74648 L p .707 .577 .707 r
F P
0 g
s
.69729 .74648 m .70074 .69138 L .68438 .69844 L p .707 .577 .707 r
F P
0 g
s
.51973 .68578 m .51628 .74087 L .53728 .74909 L p .707 .577 .707 r
F P
0 g
s
.54017 .76186 m .53341 .79752 L .56034 .80761 L p .707 .577 .707 r
F P
0 g
s
.6581 .7846 m .65135 .82027 L .67516 .81723 L p .707 .577 .707 r
F P
0 g
s
.67516 .81723 m .68191 .78157 L .6581 .7846 L p .707 .577 .707 r
F P
0 g
s
.62719 .83064 m .62369 .84844 L .65267 .84928 L p .707 .577 .707 r
F P
0 g
s
.65267 .84928 m .65617 .83148 L .62719 .83064 L p .707 .577 .707 r
F P
0 g
s
.56176 .83611 m .56526 .81832 L .53837 .80804 L p .707 .577 .707 r
F P
0 g
s
.56526 .81832 m .56176 .83611 L .59237 .8439 L p .707 .577 .707 r
F P
0 g
s
.53341 .79752 m .54017 .76186 L .51959 .75027 L p .707 .577 .707 r
F P
0 g
s
.51628 .74087 m .51973 .68578 L .50718 .6765 L p .707 .577 .707 r
F P
0 g
s
.53837 .80804 m .53487 .82583 L .56176 .83611 L p .707 .577 .707 r
F P
0 g
s
.65617 .83148 m .65267 .84928 L .67646 .84633 L p .707 .577 .707 r
F P
0 g
s
.67646 .84633 m .67996 .82854 L .65617 .83148 L p .707 .577 .707 r
F P
0 g
s
.51959 .75027 m .51284 .78593 L .53341 .79752 L p .707 .577 .707 r
F P
0 g
s
.53487 .82583 m .53837 .80804 L .51782 .79627 L p .707 .577 .707 r
F P
0 g
s
.68191 .78157 m .67516 .81723 L .69144 .81077 L p .707 .577 .707 r
F P
0 g
s
.69144 .81077 m .6982 .77511 L .68191 .78157 L p .707 .577 .707 r
F P
0 g
s
.51782 .79627 m .51433 .81406 L .53487 .82583 L p .707 .577 .707 r
F P
0 g
s
.50718 .6765 m .50373 .73159 L .51628 .74087 L p .707 .577 .707 r
F P
0 g
s
.51284 .78593 m .51959 .75027 L .50738 .73831 L p .707 .577 .707 r
F P
0 g
s
.70074 .69138 m .69729 .74648 L .70438 .7378 L p .707 .577 .707 r
F P
0 g
s
.70438 .7378 m .70783 .68271 L .70074 .69138 L p .707 .577 .707 r
F P
0 g
s
.50373 .73159 m .50718 .6765 L .50431 .66706 L p .707 .577 .707 r
F P
0 g
s
.67996 .82854 m .67646 .84633 L .69274 .8399 L p .707 .577 .707 r
F P
0 g
s
.69274 .8399 m .69624 .8221 L .67996 .82854 L p .707 .577 .707 r
F P
0 g
s
.50738 .73831 m .50062 .77397 L .51284 .78593 L p .707 .577 .707 r
F P
0 g
s
.51433 .81406 m .51782 .79627 L .50564 .78417 L p .707 .577 .707 r
F P
0 g
s
.50564 .78417 m .50214 .80196 L .51433 .81406 L p .707 .577 .707 r
F P
0 g
s
.6982 .77511 m .69144 .81077 L .69861 .8015 L p .707 .577 .707 r
F P
0 g
s
.69861 .8015 m .70537 .76584 L .6982 .77511 L p .707 .577 .707 r
F P
0 g
s
.50431 .66706 m .50086 .72215 L .50373 .73159 L p .707 .577 .707 r
F P
0 g
s
.50062 .77397 m .50738 .73831 L .50472 .72714 L p .707 .577 .707 r
F P
0 g
s
.70783 .68271 m .70438 .7378 L .70152 .72837 L p .707 .577 .707 r
F P
0 g
s
.70152 .72837 m .70497 .67327 L .70783 .68271 L p .707 .577 .707 r
F P
0 g
s
.49821 .82185 m .48943 .3191 L .44543 .3172 L p .707 .577 .707 r
F P
0 g
s
.50472 .72714 m .49797 .76281 L .50062 .77397 L p .707 .577 .707 r
F P
0 g
s
.50086 .72215 m .50431 .66706 L .5114 .65838 L p .707 .577 .707 r
F P
0 g
s
.50214 .80196 m .50564 .78417 L .503 .77292 L p .707 .577 .707 r
F P
0 g
s
.503 .77292 m .49951 .79071 L .50214 .80196 L p .707 .577 .707 r
F P
0 g
s
.49797 .76281 m .50472 .72714 L .51189 .71788 L p .707 .577 .707 r
F P
0 g
s
.5114 .65838 m .50795 .71348 L .50086 .72215 L p .707 .577 .707 r
F P
0 g
s
.51189 .71788 m .50514 .75354 L .49797 .76281 L p .707 .577 .707 r
F P
0 g
s
.50795 .71348 m .5114 .65838 L .52776 .65132 L p .707 .577 .707 r
F P
0 g
s
.49951 .79071 m .503 .77292 L .51017 .76362 L p .707 .577 .707 r
F P
0 g
s
.51017 .76362 m .50668 .78141 L .49951 .79071 L p .707 .577 .707 r
F P
0 g
s
.50514 .75354 m .51189 .71788 L .52818 .71141 L p .707 .577 .707 r
F P
0 g
s
.52776 .65132 m .52431 .70642 L .50795 .71348 L p .707 .577 .707 r
F P
0 g
s
.52431 .70642 m .52776 .65132 L .55179 .64657 L p .707 .577 .707 r
F P
0 g
s
.52818 .71141 m .52142 .74707 L .50514 .75354 L p .707 .577 .707 r
F P
0 g
s
.50668 .78141 m .51017 .76362 L .52645 .75719 L p .707 .577 .707 r
F P
0 g
s
.52645 .75719 m .52296 .77498 L .50668 .78141 L p .707 .577 .707 r
F P
0 g
s
.52142 .74707 m .52818 .71141 L .55199 .70838 L p .707 .577 .707 r
F P
0 g
s
.55179 .64657 m .54834 .70167 L .52431 .70642 L p .707 .577 .707 r
F P
0 g
s
.55199 .70838 m .54523 .74404 L .52142 .74707 L p .707 .577 .707 r
F P
0 g
s
.52296 .77498 m .52645 .75719 L .55024 .75424 L p .707 .577 .707 r
F P
0 g
s
.55024 .75424 m .54675 .77204 L .52296 .77498 L p .707 .577 .707 r
F P
0 g
s
.48943 .3191 m .49821 .82185 L .54314 .82005 L p .707 .577 .707 r
F P
0 g
s
.54314 .82005 m .53437 .3173 L .48943 .3191 L p .707 .577 .707 r
F P
0 g
s
.69624 .8221 m .69274 .8399 L .69992 .8306 L p .707 .577 .707 r
F P
0 g
s
.69992 .8306 m .70341 .81281 L .69624 .8221 L p .707 .577 .707 r
F P
0 g
s
.54834 .70167 m .55179 .64657 L .58113 .64459 L p .707 .577 .707 r
F P
0 g
s
.58113 .64459 m .57768 .69969 L .54834 .70167 L p .707 .577 .707 r
F P
0 g
s
.54523 .74404 m .55199 .70838 L .58099 .70908 L p .707 .577 .707 r
F P
0 g
s
.58099 .70908 m .57424 .74474 L .54523 .74404 L p .707 .577 .707 r
F P
0 g
s
.57424 .74474 m .58099 .70908 L .61235 .71344 L p .707 .577 .707 r
F P
0 g
s
.54675 .77204 m .55024 .75424 L .57922 .75508 L p .707 .577 .707 r
F P
0 g
s
.61235 .71344 m .60559 .7491 L .57424 .74474 L p .707 .577 .707 r
F P
0 g
s
.57922 .75508 m .57573 .77288 L .54675 .77204 L p .707 .577 .707 r
F P
0 g
s
.57573 .77288 m .57922 .75508 L .61055 .75962 L p .707 .577 .707 r
F P
0 g
s
.61055 .75962 m .60705 .77741 L .57573 .77288 L p .707 .577 .707 r
F P
0 g
s
.53437 .3173 m .54314 .82005 L .58462 .81472 L p .707 .577 .707 r
F P
0 g
s
.57768 .69969 m .58113 .64459 L .61291 .64557 L p .707 .577 .707 r
F P
0 g
s
.61291 .64557 m .60946 .70067 L .57768 .69969 L p .707 .577 .707 r
F P
0 g
s
.58462 .81472 m .57584 .31197 L .53437 .3173 L p .707 .577 .707 r
F P
0 g
s
.4542 .81995 m .44543 .3172 L .40667 .31178 L p .707 .577 .707 r
F P
0 g
s
.44543 .3172 m .4542 .81995 L .49821 .82185 L p .707 .577 .707 r
F P
0 g
s
.70537 .76584 m .69861 .8015 L .69596 .79034 L p .707 .577 .707 r
F P
0 g
s
.69596 .79034 m .70271 .75468 L .70537 .76584 L p .707 .577 .707 r
F P
0 g
s
.64299 .72104 m .63624 .7567 L .60559 .7491 L p .707 .577 .707 r
F P
0 g
s
.60559 .7491 m .61235 .71344 L .64299 .72104 L p .707 .577 .707 r
F P
0 g
s
.64115 .76741 m .63766 .7852 L .60705 .77741 L p .707 .577 .707 r
F P
0 g
s
.60705 .77741 m .61055 .75962 L .64115 .76741 L p .707 .577 .707 r
F P
0 g
s
.57584 .31197 m .58462 .81472 L .61857 .80639 L p .707 .577 .707 r
F P
0 g
s
.64402 .64943 m .64057 .70452 L .60946 .70067 L p .707 .577 .707 r
F P
0 g
s
.60946 .70067 m .61291 .64557 L .64402 .64943 L p .707 .577 .707 r
F P
0 g
s
.61857 .80639 m .6098 .30364 L .57584 .31197 L p .707 .577 .707 r
F P
0 g
s
.70497 .67327 m .70152 .72837 L .68897 .71908 L p .707 .577 .707 r
F P
0 g
s
.68897 .71908 m .69242 .66399 L .70497 .67327 L p .707 .577 .707 r
F P
0 g
s
.25278 .70662 m .25623 .65152 L .22512 .64767 L p .707 .577 .707 r
F P
0 g
s
.25623 .65152 m .25278 .70662 L .28456 .7076 L p .707 .577 .707 r
F P
0 g
s
.28456 .7076 m .28801 .65251 L .25623 .65152 L p .707 .577 .707 r
F P
0 g
s
.70341 .81281 m .69992 .8306 L .69728 .81935 L p .707 .577 .707 r
F P
0 g
s
.69728 .81935 m .70077 .80156 L .70341 .81281 L p .707 .577 .707 r
F P
0 g
s
.28801 .65251 m .28456 .7076 L .3139 .70562 L p .707 .577 .707 r
F P
0 g
s
.3139 .70562 m .31735 .65053 L .28801 .65251 L p .707 .577 .707 r
F P
0 g
s
.41545 .81453 m .40667 .31178 L .37695 .30337 L p .707 .577 .707 r
F P
0 g
s
.40667 .31178 m .41545 .81453 L .4542 .81995 L p .707 .577 .707 r
F P
0 g
s
.22167 .70277 m .22512 .64767 L .19772 .64133 L p .707 .577 .707 r
F P
0 g
s
.22512 .64767 m .22167 .70277 L .25278 .70662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31735 .65053 m .3139 .70562 L .33792 .70087 L p .707 .577 .707 r
F P
0 g
s
.33792 .70087 m .34137 .64577 L .31735 .65053 L p .707 .577 .707 r
F P
0 g
s
.70271 .75468 m .69596 .79034 L .68374 .77838 L p .707 .577 .707 r
F P
0 g
s
.68374 .77838 m .6905 .74272 L .70271 .75468 L p .707 .577 .707 r
F P
0 g
s
.19427 .69642 m .19772 .64133 L .17672 .63311 L p .707 .577 .707 r
F P
0 g
s
.19772 .64133 m .19427 .69642 L .22167 .70277 L p .707 .577 .707 r
F P
0 g
s
.66992 .73113 m .66317 .76679 L .63624 .7567 L p .707 .577 .707 r
F P
0 g
s
.63624 .7567 m .64299 .72104 L .66992 .73113 L p .707 .577 .707 r
F P
0 g
s
.66804 .77769 m .66455 .79548 L .63766 .7852 L p .707 .577 .707 r
F P
0 g
s
.63766 .7852 m .64115 .76741 L .66804 .77769 L p .707 .577 .707 r
F P
0 g
s
.6098 .30364 m .61857 .80639 L .64168 .79586 L p .707 .577 .707 r
F P
0 g
s
.64168 .79586 m .63291 .29311 L .6098 .30364 L p .707 .577 .707 r
F P
0 g
s
.69242 .66399 m .68897 .71908 L .66797 .71087 L p .707 .577 .707 r
F P
0 g
s
.66797 .71087 m .67142 .65577 L .69242 .66399 L p .707 .577 .707 r
F P
0 g
s
.24798 .77743 m .25473 .74177 L .22409 .73417 L p .707 .577 .707 r
F P
0 g
s
.25473 .74177 m .24798 .77743 L .27934 .78179 L p .707 .577 .707 r
F P
0 g
s
.27934 .78179 m .28609 .74613 L .25473 .74177 L p .707 .577 .707 r
F P
0 g
s
.28609 .74613 m .27934 .78179 L .30834 .78249 L p .707 .577 .707 r
F P
0 g
s
.30834 .78249 m .31509 .74683 L .28609 .74613 L p .707 .577 .707 r
F P
0 g
s
.21733 .76983 m .22409 .73417 L .19716 .72408 L p .707 .577 .707 r
F P
0 g
s
.22409 .73417 m .21733 .76983 L .24798 .77743 L p .707 .577 .707 r
F P
0 g
s
.70077 .80156 m .69728 .81935 L .68509 .80725 L p .707 .577 .707 r
F P
0 g
s
.68509 .80725 m .68859 .78946 L .70077 .80156 L p .707 .577 .707 r
F P
0 g
s
.34137 .64577 m .33792 .70087 L .35428 .69381 L p .707 .577 .707 r
F P
0 g
s
.35428 .69381 m .35773 .63871 L .34137 .64577 L p .707 .577 .707 r
F P
0 g
s
.38573 .80612 m .37695 .30337 L .35918 .2928 L p .707 .577 .707 r
F P
0 g
s
.37695 .30337 m .38573 .80612 L .41545 .81453 L p .707 .577 .707 r
F P
0 g
s
.17672 .63311 m .17327 .68821 L .19427 .69642 L p .707 .577 .707 r
F P
0 g
s
.19716 .72408 m .19041 .75974 L .21733 .76983 L p .707 .577 .707 r
F P
0 g
s
.31509 .74683 m .30834 .78249 L .33215 .77946 L p .707 .577 .707 r
F P
0 g
s
.33215 .77946 m .3389 .7438 L .31509 .74683 L p .707 .577 .707 r
F P
0 g
s
.17327 .68821 m .17672 .63311 L .16417 .62383 L p .707 .577 .707 r
F P
0 g
s
.19041 .75974 m .19716 .72408 L .17658 .71249 L p .707 .577 .707 r
F P
0 g
s
.67142 .65577 m .66797 .71087 L .64057 .70452 L p .707 .577 .707 r
F P
0 g
s
.64057 .70452 m .64402 .64943 L .67142 .65577 L p .707 .577 .707 r
F P
0 g
s
.6905 .74272 m .68374 .77838 L .66317 .76679 L p .707 .577 .707 r
F P
0 g
s
.66317 .76679 m .66992 .73113 L .6905 .74272 L p .707 .577 .707 r
F P
0 g
s
.24936 .83341 m .25286 .81561 L .22225 .80782 L p .707 .577 .707 r
F P
0 g
s
.25286 .81561 m .24936 .83341 L .28069 .83794 L p .707 .577 .707 r
F P
0 g
s
.28069 .83794 m .28418 .82015 L .25286 .81561 L p .707 .577 .707 r
F P
0 g
s
.28418 .82015 m .28069 .83794 L .30966 .83878 L p .707 .577 .707 r
F P
0 g
s
.30966 .83878 m .31316 .82098 L .28418 .82015 L p .707 .577 .707 r
F P
0 g
s
.21876 .82561 m .22225 .80782 L .19536 .79754 L p .707 .577 .707 r
F P
0 g
s
.22225 .80782 m .21876 .82561 L .24936 .83341 L p .707 .577 .707 r
F P
0 g
s
.17658 .71249 m .16983 .74815 L .19041 .75974 L p .707 .577 .707 r
F P
0 g
s
.19536 .79754 m .19186 .81533 L .21876 .82561 L p .707 .577 .707 r
F P
0 g
s
.63291 .29311 m .64168 .79586 L .65168 .78418 L p .707 .577 .707 r
F P
0 g
s
.65168 .78418 m .64291 .28143 L .63291 .29311 L p .707 .577 .707 r
F P
0 g
s
.68859 .78946 m .68509 .80725 L .66455 .79548 L p .707 .577 .707 r
F P
0 g
s
.66455 .79548 m .66804 .77769 L .68859 .78946 L p .707 .577 .707 r
F P
0 g
s
.16417 .62383 m .16072 .67893 L .17327 .68821 L p .707 .577 .707 r
F P
0 g
s
.35773 .63871 m .35428 .69381 L .36138 .68514 L p .707 .577 .707 r
F P
0 g
s
.36138 .68514 m .36483 .63004 L .35773 .63871 L p .707 .577 .707 r
F P
0 g
s
.3389 .7438 m .33215 .77946 L .34843 .77299 L p .707 .577 .707 r
F P
0 g
s
.34843 .77299 m .35519 .73733 L .3389 .7438 L p .707 .577 .707 r
F P
0 g
s
.31316 .82098 m .30966 .83878 L .33346 .83584 L p .707 .577 .707 r
F P
0 g
s
.33346 .83584 m .33695 .81804 L .31316 .82098 L p .707 .577 .707 r
F P
0 g
s
.19186 .81533 m .19536 .79754 L .17481 .78577 L p .707 .577 .707 r
F P
0 g
s
.16983 .74815 m .17658 .71249 L .16437 .70053 L p .707 .577 .707 r
F P
0 g
s
.16072 .67893 m .16417 .62383 L .1613 .61439 L p .707 .577 .707 r
F P
0 g
s
.17481 .78577 m .17132 .80357 L .19186 .81533 L p .707 .577 .707 r
F P
0 g
s
.36483 .63004 m .36138 .68514 L .35851 .6757 L p .707 .577 .707 r
F P
0 g
s
.35851 .6757 m .36196 .6206 L .36483 .63004 L p .707 .577 .707 r
F P
0 g
s
.36795 .79555 m .35918 .2928 L .35509 .2811 L p .707 .577 .707 r
F P
0 g
s
.35918 .2928 m .36795 .79555 L .38573 .80612 L p .707 .577 .707 r
F P
0 g
s
.16437 .70053 m .15761 .73619 L .16983 .74815 L p .707 .577 .707 r
F P
0 g
s
.33695 .81804 m .33346 .83584 L .34973 .8294 L p .707 .577 .707 r
F P
0 g
s
.34973 .8294 m .35323 .81161 L .33695 .81804 L p .707 .577 .707 r
F P
0 g
s
.17132 .80357 m .17481 .78577 L .16263 .77367 L p .707 .577 .707 r
F P
0 g
s
.1613 .61439 m .15785 .66949 L .16072 .67893 L p .707 .577 .707 r
F P
0 g
s
.35519 .73733 m .34843 .77299 L .3556 .76373 L p .707 .577 .707 r
F P
0 g
s
.3556 .76373 m .36236 .72806 L .35519 .73733 L p .707 .577 .707 r
F P
0 g
s
.15761 .73619 m .16437 .70053 L .16172 .68937 L p .707 .577 .707 r
F P
0 g
s
.16263 .77367 m .15913 .79146 L .17132 .80357 L p .707 .577 .707 r
F P
0 g
s
.64291 .28143 m .65168 .78418 L .64789 .77331 L p .707 .577 .707 r
F P
0 g
s
.64754 .76699 m .64291 .28143 L .64789 .77331 L .707 .577 .707 r
F
.63882 .26973 m .64291 .28143 L p .64642 .64895 L F P
0 g
s
.6476 .77248 m .64539 .6458 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.64539 .6458 m .63882 .26973 L p .64642 .64895 L .707 .577 .707 r
F P
0 g
s
.63882 .26973 m .6476 .77248 L .62982 .7619 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64152 .57502 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64093 .63955 m .64132 .63339 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64132 .63339 m .64438 .58446 L p .641 .63241 L .707 .577 .707 r
F P
0 g
s
.64458 .64627 m .6418 .66095 L p .65004 .69389 L .707 .577 .707 r
F P
0 g
s
.6418 .66095 m .63783 .68193 L .64322 .68721 L p .707 .577 .707 r
F P
0 g
s
.64322 .68721 m .65004 .69389 L p .6418 .66095 L .707 .577 .707 r
F P
0 g
s
.64789 .77331 m .6476 .77248 L p .64754 .76699 L .707 .577 .707 r
F P
0 g
s
.15785 .66949 m .1613 .61439 L .16839 .60572 L p .707 .577 .707 r
F P
0 g
s
.16172 .68937 m .15496 .72503 L .15761 .73619 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35323 .81161 m .34973 .8294 L .35691 .8201 L p .707 .577 .707 r
F P
0 g
s
.35691 .8201 m .3604 .80231 L .35323 .81161 L p .707 .577 .707 r
F P
0 g
s
.15913 .79146 m .16263 .77367 L .15999 .76242 L p .707 .577 .707 r
F P
0 g
s
.16839 .60572 m .16494 .66081 L .15785 .66949 L p .707 .577 .707 r
F P
0 g
s
.15999 .76242 m .1565 .78021 L .15913 .79146 L p .707 .577 .707 r
F P
0 g
s
.36196 .6206 m .35851 .6757 L .34596 .66642 L p .707 .577 .707 r
F P
0 g
s
.34596 .66642 m .34941 .61132 L .36196 .6206 L p .707 .577 .707 r
F P
0 g
s
.35509 .2811 m .36387 .78385 L .36795 .79555 L p .707 .577 .707 r
F P
0 g
s
.36387 .78385 m .35509 .2811 L .36509 .26941 L p .707 .577 .707 r
F P
0 g
s
.36236 .72806 m .3556 .76373 L .35295 .75256 L p .707 .577 .707 r
F P
0 g
s
.35295 .75256 m .3597 .7169 L .36236 .72806 L p .707 .577 .707 r
F P
0 g
s
.15496 .72503 m .16172 .68937 L .16888 .6801 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16494 .66081 m .16839 .60572 L .18475 .59866 L p .707 .577 .707 r
F P
0 g
s
.16888 .6801 m .16213 .71576 L .15496 .72503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3604 .80231 m .35691 .8201 L .35427 .80886 L p .707 .577 .707 r
F P
0 g
s
.35427 .80886 m .35776 .79106 L .3604 .80231 L p .707 .577 .707 r
F P
0 g
s
.1565 .78021 m .15999 .76242 L .16716 .75312 L p .707 .577 .707 r
F P
0 g
s
.62982 .7619 m .62105 .25916 L .63882 .26973 L p .707 .577 .707 r
F P
0 g
s
.18475 .59866 m .1813 .65375 L .16494 .66081 L p .707 .577 .707 r
F P
0 g
s
.16716 .75312 m .16367 .77092 L .1565 .78021 L p .707 .577 .707 r
F P
0 g
s
.3597 .7169 m .35295 .75256 L .34073 .7406 L p .707 .577 .707 r
F P
0 g
s
.34073 .7406 m .34749 .70494 L .3597 .7169 L p .707 .577 .707 r
F P
0 g
s
.34941 .61132 m .34596 .66642 L .32496 .6582 L p .707 .577 .707 r
F P
0 g
s
.32496 .6582 m .32841 .6031 L .34941 .61132 L p .707 .577 .707 r
F P
0 g
s
.16213 .71576 m .16888 .6801 L .18517 .67364 L p .707 .577 .707 r
F P
0 g
s
.1813 .65375 m .18475 .59866 L .20878 .5939 L p .707 .577 .707 r
F P
0 g
s
.37387 .77216 m .36509 .26941 L .3882 .25889 L p .707 .577 .707 r
F P
0 g
s
.36509 .26941 m .37387 .77216 L .36387 .78385 L p .707 .577 .707 r
F P
0 g
s
.18517 .67364 m .17841 .7093 L .16213 .71576 L p .707 .577 .707 r
F P
0 g
s
.35776 .79106 m .35427 .80886 L .34208 .79675 L p .707 .577 .707 r
F P
0 g
s
.34208 .79675 m .34558 .77896 L .35776 .79106 L p .707 .577 .707 r
F P
0 g
s
.32841 .6031 m .32496 .6582 L .29756 .65186 L p .707 .577 .707 r
F P
0 g
s
.29756 .65186 m .30101 .59676 L .32841 .6031 L p .707 .577 .707 r
F P
0 g
s
.16367 .77092 m .16716 .75312 L .18344 .74669 L p .707 .577 .707 r
F P
0 g
s
.20878 .5939 m .20533 .649 L .1813 .65375 L p .707 .577 .707 r
F P
0 g
s
.34749 .70494 m .34073 .7406 L .32016 .72901 L p .707 .577 .707 r
F P
0 g
s
.32016 .72901 m .32691 .69335 L .34749 .70494 L p .707 .577 .707 r
F P
0 g
s
.20533 .649 m .20878 .5939 L .23812 .59192 L p .707 .577 .707 r
F P
0 g
s
.17841 .7093 m .18517 .67364 L .20898 .6706 L p .707 .577 .707 r
F P
0 g
s
.18344 .74669 m .17995 .76448 L .16367 .77092 L p .707 .577 .707 r
F P
0 g
s
.62105 .25916 m .62982 .7619 L .6001 .7535 L p .707 .577 .707 r
F P
0 g
s
.6001 .7535 m .59133 .25075 L .62105 .25916 L p .707 .577 .707 r
F P
0 g
s
.30101 .59676 m .29756 .65186 L .26645 .648 L p .707 .577 .707 r
F P
0 g
s
.26645 .648 m .2699 .59291 L .30101 .59676 L p .707 .577 .707 r
F P
0 g
s
.23467 .64702 m .23812 .59192 L .2699 .59291 L p .707 .577 .707 r
F P
0 g
s
.23812 .59192 m .23467 .64702 L .20533 .649 L p .707 .577 .707 r
F P
0 g
s
.20898 .6706 m .20222 .70627 L .17841 .7093 L p .707 .577 .707 r
F P
0 g
s
.2699 .59291 m .26645 .648 L .23467 .64702 L p .707 .577 .707 r
F P
0 g
s
.34558 .77896 m .34208 .79675 L .32154 .78499 L p .707 .577 .707 r
F P
0 g
s
.32154 .78499 m .32503 .76719 L .34558 .77896 L p .707 .577 .707 r
F P
0 g
s
.32691 .69335 m .32016 .72901 L .29323 .71892 L p .707 .577 .707 r
F P
0 g
s
.29323 .71892 m .29998 .68326 L .32691 .69335 L p .707 .577 .707 r
F P
0 g
s
.17995 .76448 m .18344 .74669 L .20723 .74375 L p .707 .577 .707 r
F P
0 g
s
.20222 .70627 m .20898 .6706 L .23798 .6713 L p .707 .577 .707 r
F P
0 g
s
.3882 .25889 m .39698 .76164 L .37387 .77216 L p .707 .577 .707 r
F P
0 g
s
.39698 .76164 m .3882 .25889 L .42216 .25055 L p .707 .577 .707 r
F P
0 g
s
.73299 .66725 m .73644 .61215 L .70533 .6083 L p .707 .577 .707 r
F P
0 g
s
.73644 .61215 m .73299 .66725 L .76477 .66823 L p .707 .577 .707 r
F P
0 g
s
.76477 .66823 m .76822 .61314 L .73644 .61215 L p .707 .577 .707 r
F P
0 g
s
.76822 .61314 m .76477 .66823 L .79411 .66625 L p .707 .577 .707 r
F P
0 g
s
.79411 .66625 m .79756 .61115 L .76822 .61314 L p .707 .577 .707 r
F P
0 g
s
.20723 .74375 m .20374 .76154 L .17995 .76448 L p .707 .577 .707 r
F P
0 g
s
.70188 .6634 m .70533 .6083 L .67793 .60195 L p .707 .577 .707 r
F P
0 g
s
.70533 .6083 m .70188 .6634 L .73299 .66725 L p .707 .577 .707 r
F P
0 g
s
.23798 .6713 m .23123 .70696 L .20222 .70627 L p .707 .577 .707 r
F P
0 g
s
.29998 .68326 m .29323 .71892 L .26258 .71133 L p .707 .577 .707 r
F P
0 g
s
.26258 .71133 m .26934 .67566 L .29998 .68326 L p .707 .577 .707 r
F P
0 g
s
.23123 .70696 m .23798 .6713 L .26934 .67566 L p .707 .577 .707 r
F P
0 g
s
.59133 .25075 m .6001 .7535 L .56135 .74808 L p .707 .577 .707 r
F P
0 g
s
.56135 .74808 m .55257 .24533 L .59133 .25075 L p .707 .577 .707 r
F P
0 g
s
.79756 .61115 m .79411 .66625 L .81814 .6615 L p .707 .577 .707 r
F P
0 g
s
.81814 .6615 m .82159 .6064 L .79756 .61115 L p .707 .577 .707 r
F P
0 g
s
.26934 .67566 m .26258 .71133 L .23123 .70696 L p .707 .577 .707 r
F P
0 g
s
.32503 .76719 m .32154 .78499 L .29465 .7747 L p .707 .577 .707 r
F P
0 g
s
.29465 .7747 m .29814 .75691 L .32503 .76719 L p .707 .577 .707 r
F P
0 g
s
.20374 .76154 m .20723 .74375 L .23621 .74458 L p .707 .577 .707 r
F P
0 g
s
.67448 .65705 m .67793 .60195 L .65693 .59374 L p .707 .577 .707 r
F P
0 g
s
.67793 .60195 m .67448 .65705 L .70188 .6634 L p .707 .577 .707 r
F P
0 g
s
.72819 .72317 m .73495 .68751 L .7043 .67991 L p .707 .577 .707 r
F P
0 g
s
.73495 .68751 m .72819 .72317 L .75955 .72753 L p .707 .577 .707 r
F P
0 g
s
.75955 .72753 m .7663 .69187 L .73495 .68751 L p .707 .577 .707 r
F P
0 g
s
.23621 .74458 m .23272 .76238 L .20374 .76154 L p .707 .577 .707 r
F P
0 g
s
.7663 .69187 m .75955 .72753 L .78855 .72823 L p .707 .577 .707 r
F P
0 g
s
.78855 .72823 m .79531 .69257 L .7663 .69187 L p .707 .577 .707 r
F P
0 g
s
.69755 .71557 m .7043 .67991 L .67737 .66982 L p .707 .577 .707 r
F P
0 g
s
.7043 .67991 m .69755 .71557 L .72819 .72317 L p .707 .577 .707 r
F P
0 g
s
.43093 .7533 m .42216 .25055 L .46363 .24522 L p .707 .577 .707 r
F P
0 g
s
.42216 .25055 m .43093 .7533 L .39698 .76164 L p .707 .577 .707 r
F P
0 g
s
.29814 .75691 m .29465 .7747 L .26404 .76691 L p .707 .577 .707 r
F P
0 g
s
.26404 .76691 m .26754 .74912 L .29814 .75691 L p .707 .577 .707 r
F P
0 g
s
.23272 .76238 m .23621 .74458 L .26754 .74912 L p .707 .577 .707 r
F P
0 g
s
.72957 .75186 m .73307 .73407 L .70246 .72628 L p .707 .577 .707 r
F P
0 g
s
.73307 .73407 m .72957 .75186 L .7609 .7564 L p .707 .577 .707 r
F P
0 g
s
.7609 .7564 m .76439 .73861 L .73307 .73407 L p .707 .577 .707 r
F P
0 g
s
.82159 .6064 m .81814 .6615 L .8345 .65444 L p .707 .577 .707 r
F P
0 g
s
.8345 .65444 m .83795 .59934 L .82159 .6064 L p .707 .577 .707 r
F P
0 g
s
.26754 .74912 m .26404 .76691 L .23272 .76238 L p .707 .577 .707 r
F P
0 g
s
.55257 .24533 m .56135 .74808 L .51735 .74617 L p .707 .577 .707 r
F P
0 g
s
.51735 .74617 m .50857 .24342 L .55257 .24533 L p .707 .577 .707 r
F P
0 g
s
.65693 .59374 m .65348 .64884 L .67448 .65705 L p .707 .577 .707 r
F P
0 g
s
.67737 .66982 m .67062 .70548 L .69755 .71557 L p .707 .577 .707 r
F P
0 g
s
.79531 .69257 m .78855 .72823 L .81236 .7252 L p .707 .577 .707 r
F P
0 g
s
.81236 .7252 m .81912 .68953 L .79531 .69257 L p .707 .577 .707 r
F P
0 g
s
.76439 .73861 m .7609 .7564 L .78988 .75724 L p .707 .577 .707 r
F P
0 g
s
.78988 .75724 m .79337 .73944 L .76439 .73861 L p .707 .577 .707 r
F P
0 g
s
.69897 .74407 m .70246 .72628 L .67557 .716 L p .707 .577 .707 r
F P
0 g
s
.70246 .72628 m .69897 .74407 L .72957 .75186 L p .707 .577 .707 r
F P
0 g
s
.67062 .70548 m .67737 .66982 L .6568 .65823 L p .707 .577 .707 r
F P
0 g
s
.47241 .74797 m .46363 .24522 L .50857 .24342 L p .707 .577 .707 r
F P
0 g
s
.46363 .24522 m .47241 .74797 L .43093 .7533 L p .707 .577 .707 r
F P
0 g
s
.65348 .64884 m .65693 .59374 L .64438 .58446 L p .707 .577 .707 r
F P
0 g
s
.67557 .716 m .67208 .73379 L .69897 .74407 L p .707 .577 .707 r
F P
0 g
s
.50857 .24342 m .51735 .74617 L .47241 .74797 L p .707 .577 .707 r
F P
0 g
s
.79337 .73944 m .78988 .75724 L .81367 .7543 L p .707 .577 .707 r
F P
0 g
s
.81367 .7543 m .81716 .7365 L .79337 .73944 L p .707 .577 .707 r
F P
0 g
s
.6568 .65823 m .65004 .69389 L .67062 .70548 L p .707 .577 .707 r
F P
0 g
s
.67208 .73379 m .67557 .716 L .65503 .70423 L p .707 .577 .707 r
F P
0 g
s
.81912 .68953 m .81236 .7252 L .82865 .71873 L p .707 .577 .707 r
F P
0 g
s
.82865 .71873 m .8354 .68307 L .81912 .68953 L p .707 .577 .707 r
F P
0 g
s
.65503 .70423 m .65153 .72202 L .67208 .73379 L p .707 .577 .707 r
F P
0 g
s
.64438 .58446 m .64093 .63955 L .65348 .64884 L p .707 .577 .707 r
F P
0 g
s
.65004 .69389 m .6568 .65823 L .64458 .64627 L p .707 .577 .707 r
F P
0 g
s
.83795 .59934 m .8345 .65444 L .84159 .64577 L p .707 .577 .707 r
F P
0 g
s
.84159 .64577 m .84504 .59067 L .83795 .59934 L p .707 .577 .707 r
F P
0 g
s
.81716 .7365 m .81367 .7543 L .82995 .74786 L p .707 .577 .707 r
F P
0 g
s
.82995 .74786 m .83344 .73007 L .81716 .7365 L p .707 .577 .707 r
F P
0 g
s
.65153 .72202 m .65503 .70423 L .64284 .69213 L p .707 .577 .707 r
F P
0 g
s
.64284 .69213 m .63935 .70992 L .65153 .72202 L p .707 .577 .707 r
F P
0 g
s
.8354 .68307 m .82865 .71873 L .83582 .70946 L p .707 .577 .707 r
F P
0 g
s
.83582 .70946 m .84257 .6738 L .8354 .68307 L p .707 .577 .707 r
F P
0 g
s
.64152 .57502 m .63807 .63011 L .64093 .63955 L p .707 .577 .707 r
F P
0 g
s
.63783 .68193 m .64458 .64627 L .64193 .63511 L p .707 .577 .707 r
F P
0 g
s
.84504 .59067 m .84159 .64577 L .83872 .63633 L p .707 .577 .707 r
F P
0 g
s
.83872 .63633 m .84217 .58123 L .84504 .59067 L p .707 .577 .707 r
F P
0 g
s
.83344 .73007 m .82995 .74786 L .83712 .73856 L p .707 .577 .707 r
F P
0 g
s
.83712 .73856 m .84061 .72077 L .83344 .73007 L p .707 .577 .707 r
F P
0 g
s
.64193 .63511 m .63517 .67077 L .63783 .68193 L p .707 .577 .707 r
F P
0 g
s
.63807 .63011 m .64152 .57502 L .64861 .56634 L p .707 .577 .707 r
F P
0 g
s
.63935 .70992 m .64284 .69213 L .6402 .68088 L p .707 .577 .707 r
F P
0 g
s
.6402 .68088 m .63671 .69867 L .63935 .70992 L p .707 .577 .707 r
F P
0 g
s
.84257 .6738 m .83582 .70946 L .83316 .6983 L p .707 .577 .707 r
F P
0 g
s
.83316 .6983 m .83992 .66264 L .84257 .6738 L p .707 .577 .707 r
F P
0 g
s
.63517 .67077 m .64193 .63511 L .6491 .62584 L p .707 .577 .707 r
F P
0 g
s
.64861 .56634 m .64516 .62144 L .63807 .63011 L p .707 .577 .707 r
F P
0 g
s
.84217 .58123 m .83872 .63633 L .82617 .62704 L p .707 .577 .707 r
F P
0 g
s
.82617 .62704 m .82962 .57195 L .84217 .58123 L p .707 .577 .707 r
F P
0 g
s
.38998 .61458 m .39343 .55948 L .36232 .55563 L p .707 .577 .707 r
F P
0 g
s
.39343 .55948 m .38998 .61458 L .42176 .61556 L p .707 .577 .707 r
F P
0 g
s
.42176 .61556 m .42521 .56047 L .39343 .55948 L p .707 .577 .707 r
F P
0 g
s
.84061 .72077 m .83712 .73856 L .83449 .72731 L p .707 .577 .707 r
F P
0 g
s
.83449 .72731 m .83798 .70952 L .84061 .72077 L p .707 .577 .707 r
F P
0 g
s
.42521 .56047 m .42176 .61556 L .4511 .61358 L p .707 .577 .707 r
F P
0 g
s
.4511 .61358 m .45455 .55849 L .42521 .56047 L p .707 .577 .707 r
F P
0 g
s
.6491 .62584 m .64234 .6615 L .63517 .67077 L p .707 .577 .707 r
F P
0 g
s
.64516 .62144 m .64861 .56634 L .66497 .55929 L p .707 .577 .707 r
F P
0 g
s
.63671 .69867 m .6402 .68088 L .64738 .67158 L p .707 .577 .707 r
F P
0 g
s
.35887 .61073 m .36232 .55563 L .33492 .54929 L p .707 .577 .707 r
F P
0 g
s
.36232 .55563 m .35887 .61073 L .38998 .61458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64738 .67158 m .64388 .68938 L .63671 .69867 L p .707 .577 .707 r
F P
0 g
s
.45455 .55849 m .4511 .61358 L .47513 .60883 L p .707 .577 .707 r
F P
0 g
s
.47513 .60883 m .47858 .55373 L .45455 .55849 L p .707 .577 .707 r
F P
0 g
s
.83992 .66264 m .83316 .6983 L .82095 .68634 L p .707 .577 .707 r
F P
0 g
s
.82095 .68634 m .8277 .65068 L .83992 .66264 L p .707 .577 .707 r
F P
0 g
s
.64234 .6615 m .6491 .62584 L .66538 .61937 L p .707 .577 .707 r
F P
0 g
s
.66497 .55929 m .66152 .61438 L .64516 .62144 L p .707 .577 .707 r
F P
0 g
s
.33147 .60438 m .33492 .54929 L .31392 .54107 L p .707 .577 .707 r
F P
0 g
s
.33492 .54929 m .33147 .60438 L .35887 .61073 L p .707 .577 .707 r
F P
0 g
s
.82962 .57195 m .82617 .62704 L .80517 .61883 L p .707 .577 .707 r
F P
0 g
s
.80517 .61883 m .80862 .56373 L .82962 .57195 L p .707 .577 .707 r
F P
0 g
s
.38518 .68539 m .39194 .64973 L .36129 .64213 L p .707 .577 .707 r
F P
0 g
s
.39194 .64973 m .38518 .68539 L .41654 .68975 L p .707 .577 .707 r
F P
0 g
s
.41654 .68975 m .42329 .65409 L .39194 .64973 L p .707 .577 .707 r
F P
0 g
s
.42329 .65409 m .41654 .68975 L .44554 .69045 L p .707 .577 .707 r
F P
0 g
s
.44554 .69045 m .4523 .65479 L .42329 .65409 L p .707 .577 .707 r
F P
0 g
s
.35454 .67779 m .36129 .64213 L .33436 .63204 L p .707 .577 .707 r
F P
0 g
s
.36129 .64213 m .35454 .67779 L .38518 .68539 L p .707 .577 .707 r
F P
0 g
s
.66152 .61438 m .66497 .55929 L .68899 .55453 L p .707 .577 .707 r
F P
0 g
s
.83798 .70952 m .83449 .72731 L .8223 .71521 L p .707 .577 .707 r
F P
0 g
s
.8223 .71521 m .82579 .69742 L .83798 .70952 L p .707 .577 .707 r
F P
0 g
s
.66538 .61937 m .65863 .65504 L .64234 .6615 L p .707 .577 .707 r
F P
0 g
s
.64388 .68938 m .64738 .67158 L .66366 .66515 L p .707 .577 .707 r
F P
0 g
s
.47858 .55373 m .47513 .60883 L .49149 .60177 L p .707 .577 .707 r
F P
0 g
s
.49149 .60177 m .49494 .54668 L .47858 .55373 L p .707 .577 .707 r
F P
0 g
s
.31392 .54107 m .31047 .59617 L .33147 .60438 L p .707 .577 .707 r
F P
0 g
s
.66366 .66515 m .66016 .68294 L .64388 .68938 L p .707 .577 .707 r
F P
0 g
s
.33436 .63204 m .32761 .66771 L .35454 .67779 L p .707 .577 .707 r
F P
0 g
s
.4523 .65479 m .44554 .69045 L .46935 .68742 L p .707 .577 .707 r
F P
0 g
s
.46935 .68742 m .47611 .65176 L .4523 .65479 L p .707 .577 .707 r
F P
0 g
s
.31047 .59617 m .31392 .54107 L .30137 .53179 L p .707 .577 .707 r
F P
0 g
s
.32761 .66771 m .33436 .63204 L .31379 .62045 L p .707 .577 .707 r
F P
0 g
s
.80862 .56373 m .80517 .61883 L .77777 .61249 L p .707 .577 .707 r
F P
0 g
s
.77777 .61249 m .78122 .55739 L .80862 .56373 L p .707 .577 .707 r
F P
0 g
s
.8277 .65068 m .82095 .68634 L .80037 .67475 L p .707 .577 .707 r
F P
0 g
s
.80037 .67475 m .80713 .63909 L .8277 .65068 L p .707 .577 .707 r
F P
0 g
s
.38656 .74137 m .39006 .72357 L .35945 .71578 L p .707 .577 .707 r
F P
0 g
s
.39006 .72357 m .38656 .74137 L .41789 .7459 L p .707 .577 .707 r
F P
0 g
s
.41789 .7459 m .42138 .72811 L .39006 .72357 L p .707 .577 .707 r
F P
0 g
s
.65863 .65504 m .66538 .61937 L .68919 .61634 L p .707 .577 .707 r
F P
0 g
s
.68899 .55453 m .68554 .60963 L .66152 .61438 L p .707 .577 .707 r
F P
0 g
s
.42138 .72811 m .41789 .7459 L .44687 .74674 L p .707 .577 .707 r
F P
0 g
s
.44687 .74674 m .45036 .72895 L .42138 .72811 L p .707 .577 .707 r
F P
0 g
s
.68554 .60963 m .68899 .55453 L .71833 .55255 L p .707 .577 .707 r
F P
0 g
s
.35596 .73358 m .35945 .71578 L .33256 .7055 L p .707 .577 .707 r
F P
0 g
s
.35945 .71578 m .35596 .73358 L .38656 .74137 L p .707 .577 .707 r
F P
0 g
s
.31379 .62045 m .30703 .65611 L .32761 .66771 L p .707 .577 .707 r
F P
0 g
s
.33256 .7055 m .32907 .72329 L .35596 .73358 L p .707 .577 .707 r
F P
0 g
s
.82579 .69742 m .8223 .71521 L .80175 .70345 L p .707 .577 .707 r
F P
0 g
s
.80175 .70345 m .80525 .68565 L .82579 .69742 L p .707 .577 .707 r
F P
0 g
s
.68919 .61634 m .68244 .652 L .65863 .65504 L p .707 .577 .707 r
F P
0 g
s
.30137 .53179 m .29792 .58689 L .31047 .59617 L p .707 .577 .707 r
F P
0 g
s
.66016 .68294 m .66366 .66515 L .68745 .6622 L p .707 .577 .707 r
F P
0 g
s
.78122 .55739 m .77777 .61249 L .74666 .60863 L p .707 .577 .707 r
F P
0 g
s
.74666 .60863 m .75011 .55354 L .78122 .55739 L p .707 .577 .707 r
F P
0 g
s
.49494 .54668 m .49149 .60177 L .49858 .5931 L p .707 .577 .707 r
F P
0 g
s
.49858 .5931 m .50203 .538 L .49494 .54668 L p .707 .577 .707 r
F P
0 g
s
.71488 .60765 m .71833 .55255 L .75011 .55354 L p .707 .577 .707 r
F P
0 g
s
.71833 .55255 m .71488 .60765 L .68554 .60963 L p .707 .577 .707 r
F P
0 g
s
.47611 .65176 m .46935 .68742 L .48564 .68095 L p .707 .577 .707 r
F P
0 g
s
.48564 .68095 m .49239 .64529 L .47611 .65176 L p .707 .577 .707 r
F P
0 g
s
.45036 .72895 m .44687 .74674 L .47066 .7438 L p .707 .577 .707 r
F P
0 g
s
.47066 .7438 m .47415 .726 L .45036 .72895 L p .707 .577 .707 r
F P
0 g
s
.32907 .72329 m .33256 .7055 L .31202 .69373 L p .707 .577 .707 r
F P
0 g
s
.30703 .65611 m .31379 .62045 L .30157 .60849 L p .707 .577 .707 r
F P
0 g
s
.75011 .55354 m .74666 .60863 L .71488 .60765 L p .707 .577 .707 r
F P
0 g
s
.68745 .6622 m .68395 .68 L .66016 .68294 L p .707 .577 .707 r
F P
0 g
s
.80713 .63909 m .80037 .67475 L .77344 .66466 L p .707 .577 .707 r
F P
0 g
s
.77344 .66466 m .7802 .629 L .80713 .63909 L p .707 .577 .707 r
F P
0 g
s
.68244 .652 m .68919 .61634 L .71819 .61704 L p .707 .577 .707 r
F P
0 g
s
.29792 .58689 m .30137 .53179 L .2985 .52235 L p .707 .577 .707 r
F P
0 g
s
.31202 .69373 m .30852 .71153 L .32907 .72329 L p .707 .577 .707 r
F P
0 g
s
.30157 .60849 m .29482 .64415 L .30703 .65611 L p .707 .577 .707 r
F P
0 g
s
.80525 .68565 m .80175 .70345 L .77486 .69316 L p .707 .577 .707 r
F P
0 g
s
.77486 .69316 m .77836 .67537 L .80525 .68565 L p .707 .577 .707 r
F P
0 g
s
.71819 .61704 m .71144 .6527 L .68244 .652 L p .707 .577 .707 r
F P
0 g
s
.7802 .629 m .77344 .66466 L .7428 .65706 L p .707 .577 .707 r
F P
0 g
s
.7428 .65706 m .74955 .6214 L .7802 .629 L p .707 .577 .707 r
F P
0 g
s
.71144 .6527 m .71819 .61704 L .74955 .6214 L p .707 .577 .707 r
F P
0 g
s
.68395 .68 m .68745 .6622 L .71643 .66304 L p .707 .577 .707 r
F P
0 g
s
.47415 .726 m .47066 .7438 L .48694 .73736 L p .707 .577 .707 r
F P
0 g
s
.48694 .73736 m .49043 .71957 L .47415 .726 L p .707 .577 .707 r
F P
0 g
s
.74955 .6214 m .7428 .65706 L .71144 .6527 L p .707 .577 .707 r
F P
0 g
s
.30852 .71153 m .31202 .69373 L .29983 .68163 L p .707 .577 .707 r
F P
0 g
s
.71643 .66304 m .71293 .68084 L .68395 .68 L p .707 .577 .707 r
F P
0 g
s
.2985 .52235 m .29505 .57745 L .29792 .58689 L p .707 .577 .707 r
F P
0 g
s
.49239 .64529 m .48564 .68095 L .49281 .67169 L p .707 .577 .707 r
F P
0 g
s
.49281 .67169 m .49956 .63603 L .49239 .64529 L p .707 .577 .707 r
F P
0 g
s
.50203 .538 m .49858 .5931 L .49571 .58366 L p .707 .577 .707 r
F P
0 g
s
.49571 .58366 m .49916 .52856 L .50203 .538 L p .707 .577 .707 r
F P
0 g
s
.29482 .64415 m .30157 .60849 L .29892 .59733 L p .707 .577 .707 r
F P
0 g
s
.29983 .68163 m .29634 .69943 L .30852 .71153 L p .707 .577 .707 r
F P
0 g
s
.77836 .67537 m .77486 .69316 L .74426 .68537 L p .707 .577 .707 r
F P
0 g
s
.74426 .68537 m .74775 .66758 L .77836 .67537 L p .707 .577 .707 r
F P
0 g
s
.71293 .68084 m .71643 .66304 L .74775 .66758 L p .707 .577 .707 r
F P
0 g
s
.74775 .66758 m .74426 .68537 L .71293 .68084 L p .707 .577 .707 r
F P
0 g
s
.29505 .57745 m .2985 .52235 L .3056 .51368 L p .707 .577 .707 r
F P
0 g
s
.29892 .59733 m .29216 .63299 L .29482 .64415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49043 .71957 m .48694 .73736 L .49411 .72807 L p .707 .577 .707 r
F P
0 g
s
.49411 .72807 m .4976 .71027 L .49043 .71957 L p .707 .577 .707 r
F P
0 g
s
.29634 .69943 m .29983 .68163 L .29719 .67038 L p .707 .577 .707 r
F P
0 g
s
.3056 .51368 m .30215 .56877 L .29505 .57745 L p .707 .577 .707 r
F P
0 g
s
.29719 .67038 m .2937 .68818 L .29634 .69943 L p .707 .577 .707 r
F P
0 g
s
.49956 .63603 m .49281 .67169 L .49015 .66053 L p .707 .577 .707 r
F P
0 g
s
.49015 .66053 m .49691 .62487 L .49956 .63603 L p .707 .577 .707 r
F P
0 g
s
.29216 .63299 m .29892 .59733 L .30609 .58806 L p .707 .577 .707 r
F P
0 g
s
.49916 .52856 m .49571 .58366 L .48316 .57438 L p .707 .577 .707 r
F P
0 g
s
.48316 .57438 m .48661 .51928 L .49916 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30215 .56877 m .3056 .51368 L .32196 .50662 L p .707 .577 .707 r
F P
0 g
s
.30609 .58806 m .29933 .62372 L .29216 .63299 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4976 .71027 m .49411 .72807 L .49147 .71682 L p .707 .577 .707 r
F P
0 g
s
.49147 .71682 m .49497 .69902 L .4976 .71027 L p .707 .577 .707 r
F P
0 g
s
.2937 .68818 m .29719 .67038 L .30437 .66108 L p .707 .577 .707 r
F P
0 g
s
.32196 .50662 m .31851 .56171 L .30215 .56877 L p .707 .577 .707 r
F P
0 g
s
.30437 .66108 m .30087 .67888 L .2937 .68818 L p .707 .577 .707 r
F P
0 g
s
.49691 .62487 m .49015 .66053 L .47794 .64856 L p .707 .577 .707 r
F P
0 g
s
.47794 .64856 m .48469 .6129 L .49691 .62487 L p .707 .577 .707 r
F P
0 g
s
.48661 .51928 m .48316 .57438 L .46216 .56616 L p .707 .577 .707 r
F P
0 g
s
.46216 .56616 m .46561 .51107 L .48661 .51928 L p .707 .577 .707 r
F P
0 g
s
.29933 .62372 m .30609 .58806 L .32237 .5816 L p .707 .577 .707 r
F P
0 g
s
.31851 .56171 m .32196 .50662 L .34598 .50187 L p .707 .577 .707 r
F P
0 g
s
.32237 .5816 m .31562 .61726 L .29933 .62372 L p .707 .577 .707 r
F P
0 g
s
.49497 .69902 m .49147 .71682 L .47929 .70472 L p .707 .577 .707 r
F P
0 g
s
.47929 .70472 m .48278 .68692 L .49497 .69902 L p .707 .577 .707 r
F P
0 g
s
.46561 .51107 m .46216 .56616 L .43476 .55982 L p .707 .577 .707 r
F P
0 g
s
.43476 .55982 m .43821 .50472 L .46561 .51107 L p .707 .577 .707 r
F P
0 g
s
.30087 .67888 m .30437 .66108 L .32065 .65465 L p .707 .577 .707 r
F P
0 g
s
.34598 .50187 m .34253 .55696 L .31851 .56171 L p .707 .577 .707 r
F P
0 g
s
.48469 .6129 m .47794 .64856 L .45736 .63697 L p .707 .577 .707 r
F P
0 g
s
.45736 .63697 m .46411 .60131 L .48469 .6129 L p .707 .577 .707 r
F P
0 g
s
.34253 .55696 m .34598 .50187 L .37532 .49988 L p .707 .577 .707 r
F P
0 g
s
.31562 .61726 m .32237 .5816 L .34618 .57857 L p .707 .577 .707 r
F P
0 g
s
.32065 .65465 m .31715 .67244 L .30087 .67888 L p .707 .577 .707 r
F P
0 g
s
.43821 .50472 m .43476 .55982 L .40365 .55596 L p .707 .577 .707 r
F P
0 g
s
.40365 .55596 m .4071 .50087 L .43821 .50472 L p .707 .577 .707 r
F P
0 g
s
.37187 .55498 m .37532 .49988 L .4071 .50087 L p .707 .577 .707 r
F P
0 g
s
.37532 .49988 m .37187 .55498 L .34253 .55696 L p .707 .577 .707 r
F P
0 g
s
.34618 .57857 m .33943 .61423 L .31562 .61726 L p .707 .577 .707 r
F P
0 g
s
.4071 .50087 m .40365 .55596 L .37187 .55498 L p .707 .577 .707 r
F P
0 g
s
.48278 .68692 m .47929 .70472 L .45874 .69295 L p .707 .577 .707 r
F P
0 g
s
.45874 .69295 m .46224 .67515 L .48278 .68692 L p .707 .577 .707 r
F P
0 g
s
.46411 .60131 m .45736 .63697 L .43043 .62688 L p .707 .577 .707 r
F P
0 g
s
.43043 .62688 m .43719 .59122 L .46411 .60131 L p .707 .577 .707 r
F P
0 g
s
.31715 .67244 m .32065 .65465 L .34444 .65171 L p .707 .577 .707 r
F P
0 g
s
.33943 .61423 m .34618 .57857 L .37518 .57926 L p .707 .577 .707 r
F P
0 g
s
.34444 .65171 m .34094 .6695 L .31715 .67244 L p .707 .577 .707 r
F P
0 g
s
.37518 .57926 m .36843 .61493 L .33943 .61423 L p .707 .577 .707 r
F P
0 g
s
.43719 .59122 m .43043 .62688 L .39979 .61929 L p .707 .577 .707 r
F P
0 g
s
.39979 .61929 m .40654 .58363 L .43719 .59122 L p .707 .577 .707 r
F P
0 g
s
.36843 .61493 m .37518 .57926 L .40654 .58363 L p .707 .577 .707 r
F P
0 g
s
.40654 .58363 m .39979 .61929 L .36843 .61493 L p .707 .577 .707 r
F P
0 g
s
.46224 .67515 m .45874 .69295 L .43185 .68267 L p .707 .577 .707 r
F P
0 g
s
.43185 .68267 m .43535 .66487 L .46224 .67515 L p .707 .577 .707 r
F P
0 g
s
.34094 .6695 m .34444 .65171 L .37341 .65255 L p .707 .577 .707 r
F P
0 g
s
.37341 .65255 m .36992 .67034 L .34094 .6695 L p .707 .577 .707 r
F P
0 g
s
.43535 .66487 m .43185 .68267 L .40125 .67488 L p .707 .577 .707 r
F P
0 g
s
.40125 .67488 m .40474 .65708 L .43535 .66487 L p .707 .577 .707 r
F P
0 g
s
.36992 .67034 m .37341 .65255 L .40474 .65708 L p .707 .577 .707 r
F P
0 g
s
.40474 .65708 m .40125 .67488 L .36992 .67034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7`00OGoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Ioo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00LGoo1@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000
0`00Kgoo001]Ool40007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH3001/Ool006]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUIVOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol0065ooaL00003FUH005YF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00GGoo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001JOol30005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030003FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qo
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001U
Ool005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP00008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol005Aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06=oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001D
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0Hgoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00E7oo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Goo6000@goo
001COol00`00FUH00004FUH01000FUIJEUYF3@000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20006Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000mOol0
05=oo`03001JEP0000=JEPD00003FUH005YF00EJEP03001JEUYF009JEQ8000IJEP03001JEUYF00=J
EP06001JEUYF001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000`00>Goo001COol01000FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001Goo000005YF00001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00=Woo001COol01P00FUH0
0000FUH000IJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP@000AJEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003=oo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01UYF00@005YFFUIJEP<00004FUH005YFFUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<7oo001COol20003
FUH00`00FUIJEP03FUHB0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000030004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEP00000^Ool005=oo`8000=JEP03001JEUYF00@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYFFUH40006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo001EOol01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool003YooaL000Aoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YF00000P001UYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000c
Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF
00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000/Ool0035oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP05001JEUYF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00;goo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEPd000=oo`T000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH60007FUH00`00
FUIJEP02FUHD0003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0eYF1@001EYF00@005YF0000009JEP03001JEP0000<0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYF001JEP00FUH00P001EYF4P0025YF00<005YFFUH015YF10001EYF00@005YFFUIJEP8002eoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF001JEP<000=JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50006
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUH005YF00<00003FUH0000000@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH000=JEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH2000]Ool0
02eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEP000002FUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P0000AJEP000000
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000MJEP03001J
EUYF009JEP800003FUH005YF009JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P001EYF00@005YF
FUH0009JEP03001JEUYF00=JEP<000IJEP@000IJEP03001JEUYF00=JEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001JEUYF
00AJEP8000=JEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF0`000UYF00@005YFFUH0009JEP03
001JEUYF009JEPD000MJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP040003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP05001J
EP00001JEP02000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEP000080009JEP04001JEUYF0004FUH5
0007FUH01000FUIJEUYF0`0000=JEP00FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00UYF0`00
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000AJEPD000MJ
EP03001JEUYF00AJEP8000EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH015YF1@001EYF0`0025YF00<005YFFUH01UYF
0P000UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00IJEP@000AJEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH025YF
0`0015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF00<005YF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF6@00
15YF00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD000QJEP03001JEUYF00QJEP03
001JEP0000AJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH500000eYF001J
EP06FUH01000FUIJEUYF50001UYF4P000UYF100015YF00<005YFFUH01eYF1@000UYF00<005YF0000
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000
FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002io
o`00;7oo00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001JEUYF
009JEP80009JEPD0009JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH0000000`000=JEP03
001JEP0000800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF008000=JEPL000IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<002moo`00;7oo00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000EJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEP00001JEP001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP<000=JEP03001JEP0000@0009JEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
02moo`00;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@001EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJ
EP<000IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P000UYF0`0000=JEP00FUH04@001UYF0`0000=J
EP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01EYF0`001UYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF00AJEP04001JEUYF
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH6
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH40006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH?0002FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUH000030005FUH01`00FUIJEUYF
001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH005YF
0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00002P000UYF00<005YF
FUH015YF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH010000eYF00<005YFFUH01EYF
00<005YFFUH010001eYF00<005YFFUH00P000eYF1@000UYF0`0000=JEP00FUH025YF1P001eYF00<0
05YFFUH00eYF0`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH30005Ool30006FUH01P00FUIJEP00FUH002eoo`00;Goo00@005YFFUIJ
EP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00800005FUH00000FUH0
0005FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP06FUH40003FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200001EYF001JEUYF
00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001Goo0P0015YF00H005YF
FUH005YF000]Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00D00003FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH70002FUH0
0`00FUH000020004FUH300000eYF001JEP07FUH01000FUIJEP000UYF0P0025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP07FUH00`00FUH000030003Ool01000FUIJEP000eYF00<005YF0000;Goo000^Ool30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP00009JEP03001JEP0000L000=JEP03001JEUYF00<000IJEP03001J
EUYF009JEP8000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH0
0003FUH50008FUH00`00FUH0000300000goo000000040008FUH00`00FUIJEP03FUH20002Ool30003
FUH2000^Ool002ioo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000@000IJEP04001JEUYFFUH30002FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000AJEP03001JEUYF00IJEP03001JEUYF
00=JEPX000AJEP03001JEUYF00EJEP<0009oo`04001JEUYFFUH2000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP04001J
EP000005FUH01000FUIJEUYF0`000eYF00@005YFFUIJEPD00003FUH0000000/00003FUH005YF00EJ
EP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF00@00004
FUH005YF000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH20003FUH01`00FUIJEUYF001oo`0000=JEP03
001JEUYF009JEP<000QJEP03001JEUYF00AJEP8000IJEP03001JEP0000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEPH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000EJEP03001JEUYF009JEP800005FUH00000FUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300001eYF00000000FUH005YF0080009oo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00`000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00D005YF001JEP0002ioo`00;Goo00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF
00<005YFFUH00P000UYF0`001Goo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF
0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0`000eYF00H005YF000005YF0008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH200000eYF001JEP05FUH4000_Ool002eoo`03001JEP00009JEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH300000eYF00000004Ool3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30003FUH20005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP030007FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30006FUH01000FUH00000;goo000/Ool00`00FUH00003FUH40007
Ool90004FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YF00000`000goo0eYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF000015YF10000UYF0P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<007ooOol0
;7oo000/Ool01000FUH005YF0`004goo1`001UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH40000
1GooFUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJ
EP020003FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00Oomoo`0/Ool002aoo`04001JEP000002FUH3000HOol40002FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP<00003FUH005YF00<000IJEP03001JEUYF00<000AJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001oogoo02aoo`00;7oo0P0015YF00<005YF
FUH00P006Woo10001EYF0P0000=JEP00FUH01eYF00<005YF00000`0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000IJEP04001JEP000003FUH50002FUH00`00FUH000040002FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00;Woo000/Ool20003FUH00`00FUIJEP03
FUH3000>Ool3000:Ool20004FUH40007FUH00`00FUIJEP03FUH50009FUH00`00FUIJEP09FUH01@00
FUH00000FUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF00@005YFFUIJEP800003FUH0000000=oo`T0009JEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEP00001oo`04000^Ool002aoo`8000=JEP03001JEUYF00AJEP04001JEP00000;Ool5
000;Ool300000eYF001JEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJ
EP07FUH40003FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH40006Ool<0004FUH01000FUIJEUYF10001Goo0P00;Woo000/
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0P002Goo1@003Woo0P001EYF0`0000=J
EP00FUH01eYF00<005YFFUH015YF3`000UYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP06FUH00`00
FUIJEP040003Ool30008Ool80008Ool2000_Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00AJEP@000Eoo`D0011oo`80009JEP04001JEUYFFUH30006FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`001UYF00<005YFFUH015YF1@005goo1000;goo
000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002Ool3000C
Ool30004FUH00`00FUH000030002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF0P00
;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH015YF1@005Goo00<005YFFUH0
0UYF0P000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP<0
0003FUH005YF00QJEP03001JEUYF00AJEPh000=JEP06001JEUYF001JEP00;goo000^Ool30006FUH?
0002FUH00`00FUIJEP04000>Ool50002FUH00`00FUH00003FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH01000FUIJEUYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF00<005YFFUH015YF1@001UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P00<7oo000`Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH0
0`00FUIJEP040005FUH>0003FUH00`00FUH0000200000eYF001JEP02FUH00`00FUIJEP03FUH01000
FUIJEUYF3`0000=JEP000000700025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF
FUH015YF0`000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00035oo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH015YF10000eYF
00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF00001Woo1@001UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000039oo`00;goo0P000eYF00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YF00000`001eYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEP0000@000IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=J
EP05001JEUYFFUH0000:Ool40002FUH00`00FUIJEP05FUH01000FUIJEUYF1@00=7oo000^Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP04FUH01000FUIJEUYF0`0000EooeYFFUIJEP0000EJEP03001JEUYF00D000UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP05001JEUYFFUH0000>Ool>000iOol002eoo`03001JEP0000=JEP04001J
EUYFFUH>0006FUH00`00FUIJEP06FUH00`00FUH000020006FUH02000FUIJEUYF001JEP00Ool3FUH0
0`00FUIJEP03FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00E7oo000]Ool20003FUH500000goo0000000200000eYF001JEP06FUH40002FUH00`00FUIJEP06
FUH01000FUIJEUYF0`0015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP<00003FUH005YF00EJEP06001JEUYF001JEP00E7oo000]Ool200000eYF0000
000:Ool30008FUH00`00FUH000030006FUH00`00FUIJEP05FUH20002FUH01000FUIJEUYF0P000Woo
0eYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH007oo008000IJEP06001JEUYF001JEP00
E7oo000/Ool01000FUH000003goo0`0015YF00<005YF00000P000UYF10000UYF00<005YFFUH01UYF
0`000eYF0P000goo0eYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=oo`8000=J
EP07001JEUYFFUH005YF0000E7oo000/Ool4000BOol300000eYF000000040003FUH00`00FUH00003
0007FUH00`00FUIJEP030005Ool2FUH01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0`000goo0P0000=JEP00FUH00UYF0P00EGoo000/Ool01000FUH000005Goo1`000eYF00<005YFFUH0
0eYF0P0015YF00<005YFFUH00eYF0P0017oo00=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00@005YFFUH0009JEP8000=oo`8000=JEP8005Eoo`00;7oo0P000UYF00<007ooOol057oo4`00
00=JEP00FUH01EYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000=J
EPL00004FUH005YF001EOol002aoo`8000=JEP03001oogoo01Aoo`<000moo`8000IJEP03001JEP00
009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF0080009J
EP800003FUH007oo05Aoo`00;Goo00@005YFFUIJEP<002Qoo`8000=JEP06001JEUYFFUH007oo0P00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00<005YFFUH00eYF0P0000AJEP00FUH005Eo
o`00;Goo00D005YFFUIJEP00009JEP8002Qoo`800003FUH005YF009JEP04001oogoo0004FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200001EYF000005YF00001UYF1000EWoo000^Ool00`00FUH00005
FUH3000WOol20003FUH01000Oomoo`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF0`00
1UYF00@005YF000005Ioo`00;goo0P001UYF00@005YF000002Moo`05001JEP00FUH00002Ool20002
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<0
07ooOol0Dgoo000`Ool00`00FUIJEP04FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool00goo0`00
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF009JEP800003FUH005YF00=JEP03001oogoo05=oo`00<Goo
0P000eYF00<005YFFUH01EYF0`008goo00<005YF00001Woo0`001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF1@0025YF00<005YFFUH00eYF
0`0015YF00<007ooOol0Dgoo000cOol200000eYF001JEP07FUH00`00FUH00003000NOol200000eYF
001oo`08Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF0P00
EGoo000eOol30007FUH00`00FUIJEP03FUH5000GOol200000eYF0000000>Ool50008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH:0002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH00000Ool01000EGoo000hOol20004FUH00`00FUIJEP06FUH00`00FUIJEP04000?Ool40003
FUH2000COol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@000UYF
00<005YFFUH01UYF00@005YFFUIJEP@000Eoo`8005Eoo`00>Woo0`0000=JEP00FUH01eYF00<005YF
FUH015YF3`000UYF00L005YFFUIJEP00FUH0000IOolO0002FUH00`00FUIJEP040002OolD0008Ool3
001EOol003eoo`<000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
FUH2000bOol30006FUH00`00FUIJEP04FUH6000FOol4001FOol0041oo`@0009JEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000fOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP04000>Ool50002FUH2001FOol004Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00000jOol200000eYF001JEP08FUH00`00FUIJEP04FUH>0003FUH01P00FUIJEP00FUH0
05Ioo`00BGoo10000UYF00<005YFFUH01UYF00@005YFFUIJEP@003ioo`@000IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Moo`00CGoo3`00AWoo10000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0005Qoo`00YWoo1@001UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Uoo`00Zgoo10000UYF00<005YFFUH01EYF
00@005YFFUIJEPD005]oo`00[goo3P00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59635 .73958 m .5929 .68374 L .56178 .6838 L p .707 .577 .707 r
F P
0 g
s
.5929 .68374 m .59635 .73958 L .62813 .73703 L p .707 .577 .707 r
F P
0 g
s
.62813 .73703 m .62468 .68119 L .5929 .68374 L p .707 .577 .707 r
F P
0 g
s
.62468 .68119 m .62813 .73703 L .65746 .73224 L p .707 .577 .707 r
F P
0 g
s
.65746 .73224 m .65401 .6764 L .62468 .68119 L p .707 .577 .707 r
F P
0 g
s
.56523 .73964 m .56178 .6838 L .53439 .68138 L p .707 .577 .707 r
F P
0 g
s
.56178 .6838 m .56523 .73964 L .59635 .73958 L p .707 .577 .707 r
F P
0 g
s
.65401 .6764 m .65746 .73224 L .68149 .72569 L p .707 .577 .707 r
F P
0 g
s
.68149 .72569 m .67804 .66985 L .65401 .6764 L p .707 .577 .707 r
F P
0 g
s
.53439 .68138 m .53784 .73721 L .56523 .73964 L p .707 .577 .707 r
F P
0 g
s
.60021 .80373 m .59345 .76662 L .56281 .77053 L p .707 .577 .707 r
F P
0 g
s
.59345 .76662 m .60021 .80373 L .63157 .79771 L p .707 .577 .707 r
F P
0 g
s
.63157 .79771 m .62481 .7606 L .59345 .76662 L p .707 .577 .707 r
F P
0 g
s
.53784 .73721 m .53439 .68138 L .51339 .6767 L p .707 .577 .707 r
F P
0 g
s
.62481 .7606 m .63157 .79771 L .66057 .79017 L p .707 .577 .707 r
F P
0 g
s
.66057 .79017 m .65382 .75306 L .62481 .7606 L p .707 .577 .707 r
F P
0 g
s
.56281 .77053 m .56957 .80764 L .60021 .80373 L p .707 .577 .707 r
F P
0 g
s
.56957 .80764 m .56281 .77053 L .53588 .77194 L p .707 .577 .707 r
F P
0 g
s
.67804 .66985 m .68149 .72569 L .69785 .71801 L p .707 .577 .707 r
F P
0 g
s
.69785 .71801 m .6944 .66217 L .67804 .66985 L p .707 .577 .707 r
F P
0 g
s
.65382 .75306 m .66057 .79017 L .68438 .78185 L p .707 .577 .707 r
F P
0 g
s
.68438 .78185 m .67763 .74474 L .65382 .75306 L p .707 .577 .707 r
F P
0 g
s
.51339 .6767 m .51684 .73253 L .53784 .73721 L p .707 .577 .707 r
F P
0 g
s
.53588 .77194 m .54264 .80905 L .56957 .80764 L p .707 .577 .707 r
F P
0 g
s
.59875 .859 m .59526 .84046 L .56465 .84457 L p .707 .577 .707 r
F P
0 g
s
.59526 .84046 m .59875 .859 L .63008 .8528 L p .707 .577 .707 r
F P
0 g
s
.63008 .8528 m .62658 .83426 L .59526 .84046 L p .707 .577 .707 r
F P
0 g
s
.62658 .83426 m .63008 .8528 L .65905 .84512 L p .707 .577 .707 r
F P
0 g
s
.65905 .84512 m .65556 .82658 L .62658 .83426 L p .707 .577 .707 r
F P
0 g
s
.56465 .84457 m .56815 .86311 L .59875 .859 L p .707 .577 .707 r
F P
0 g
s
.51684 .73253 m .51339 .6767 L .50084 .67022 L p .707 .577 .707 r
F P
0 g
s
.54264 .80905 m .53588 .77194 L .5153 .77073 L p .707 .577 .707 r
F P
0 g
s
.56815 .86311 m .56465 .84457 L .53776 .84619 L p .707 .577 .707 r
F P
0 g
s
.53776 .84619 m .54125 .86473 L .56815 .86311 L p .707 .577 .707 r
F P
0 g
s
.67763 .74474 m .68438 .78185 L .70067 .77356 L p .707 .577 .707 r
F P
0 g
s
.70067 .77356 m .69391 .73645 L .67763 .74474 L p .707 .577 .707 r
F P
0 g
s
.65556 .82658 m .65905 .84512 L .68284 .83671 L p .707 .577 .707 r
F P
0 g
s
.68284 .83671 m .67935 .81816 L .65556 .82658 L p .707 .577 .707 r
F P
0 g
s
.5153 .77073 m .52206 .80784 L .54264 .80905 L p .707 .577 .707 r
F P
0 g
s
.6944 .66217 m .69785 .71801 L .70494 .70996 L p .707 .577 .707 r
F P
0 g
s
.70494 .70996 m .70149 .65412 L .6944 .66217 L p .707 .577 .707 r
F P
0 g
s
.50084 .67022 m .50429 .72606 L .51684 .73253 L p .707 .577 .707 r
F P
0 g
s
.54125 .86473 m .53776 .84619 L .51722 .84516 L p .707 .577 .707 r
F P
0 g
s
.51722 .84516 m .52071 .8637 L .54125 .86473 L p .707 .577 .707 r
F P
0 g
s
.52206 .80784 m .5153 .77073 L .50309 .76701 L p .707 .577 .707 r
F P
0 g
s
.67935 .81816 m .68284 .83671 L .69912 .82839 L p .707 .577 .707 r
F P
0 g
s
.69912 .82839 m .69563 .80984 L .67935 .81816 L p .707 .577 .707 r
F P
0 g
s
.50429 .72606 m .50084 .67022 L .49797 .66258 L p .707 .577 .707 r
F P
0 g
s
.50309 .76701 m .50985 .80412 L .52206 .80784 L p .707 .577 .707 r
F P
0 g
s
.69391 .73645 m .70067 .77356 L .70783 .76612 L p .707 .577 .707 r
F P
0 g
s
.70783 .76612 m .70108 .72901 L .69391 .73645 L p .707 .577 .707 r
F P
0 g
s
.49797 .66258 m .50142 .71842 L .50429 .72606 L p .707 .577 .707 r
F P
0 g
s
.70149 .65412 m .70494 .70996 L .70207 .70232 L p .707 .577 .707 r
F P
0 g
s
.70207 .70232 m .69862 .64648 L .70149 .65412 L p .707 .577 .707 r
F P
0 g
s
.52071 .8637 m .51722 .84516 L .50503 .84158 L p .707 .577 .707 r
F P
0 g
s
.50503 .84158 m .50852 .86012 L .52071 .8637 L p .707 .577 .707 r
F P
0 g
s
.69563 .80984 m .69912 .82839 L .7063 .82098 L p .707 .577 .707 r
F P
0 g
s
.7063 .82098 m .7028 .80243 L .69563 .80984 L p .707 .577 .707 r
F P
0 g
s
.50985 .80412 m .50309 .76701 L .50044 .76113 L p .707 .577 .707 r
F P
0 g
s
.48265 .82174 m .49143 .32088 L .44743 .31742 L p .707 .577 .707 r
F P
0 g
s
.50142 .71842 m .49797 .66258 L .50506 .65453 L p .707 .577 .707 r
F P
0 g
s
.50044 .76113 m .50719 .79824 L .50985 .80412 L p .707 .577 .707 r
F P
0 g
s
.50506 .65453 m .50851 .71036 L .50142 .71842 L p .707 .577 .707 r
F P
0 g
s
.50719 .79824 m .50044 .76113 L .5076 .75369 L p .707 .577 .707 r
F P
0 g
s
.50851 .71036 m .50506 .65453 L .52142 .64685 L p .707 .577 .707 r
F P
0 g
s
.5076 .75369 m .51436 .7908 L .50719 .79824 L p .707 .577 .707 r
F P
0 g
s
.52142 .64685 m .52487 .70269 L .50851 .71036 L p .707 .577 .707 r
F P
0 g
s
.51436 .7908 m .5076 .75369 L .52389 .7454 L p .707 .577 .707 r
F P
0 g
s
.52389 .7454 m .53064 .78251 L .51436 .7908 L p .707 .577 .707 r
F P
0 g
s
.51306 .84693 m .50957 .82839 L .52585 .82007 L p .707 .577 .707 r
F P
0 g
s
.52585 .82007 m .52934 .83861 L .51306 .84693 L p .707 .577 .707 r
F P
0 g
s
.52934 .83861 m .52585 .82007 L .54964 .81165 L p .707 .577 .707 r
F P
0 g
s
.49143 .32088 m .48265 .82174 L .52759 .82134 L p .707 .577 .707 r
F P
0 g
s
.52487 .70269 m .52142 .64685 L .54545 .6403 L p .707 .577 .707 r
F P
0 g
s
.54545 .6403 m .5489 .69613 L .52487 .70269 L p .707 .577 .707 r
F P
0 g
s
.53064 .78251 m .52389 .7454 L .5477 .73708 L p .707 .577 .707 r
F P
0 g
s
.52759 .82134 m .53637 .32048 L .49143 .32088 L p .707 .577 .707 r
F P
0 g
s
.5489 .69613 m .54545 .6403 L .57478 .63551 L p .707 .577 .707 r
F P
0 g
s
.57478 .63551 m .57823 .69135 L .5489 .69613 L p .707 .577 .707 r
F P
0 g
s
.5477 .73708 m .55445 .77419 L .53064 .78251 L p .707 .577 .707 r
F P
0 g
s
.55445 .77419 m .5477 .73708 L .5767 .72954 L p .707 .577 .707 r
F P
0 g
s
.54964 .81165 m .55313 .8302 L .52934 .83861 L p .707 .577 .707 r
F P
0 g
s
.5767 .72954 m .58346 .76665 L .55445 .77419 L p .707 .577 .707 r
F P
0 g
s
.55313 .8302 m .54964 .81165 L .57861 .80397 L p .707 .577 .707 r
F P
0 g
s
.57861 .80397 m .58211 .82252 L .55313 .8302 L p .707 .577 .707 r
F P
0 g
s
.53637 .32048 m .52759 .82134 L .56907 .81713 L p .707 .577 .707 r
F P
0 g
s
.56907 .81713 m .57784 .31627 L .53637 .32048 L p .707 .577 .707 r
F P
0 g
s
.70108 .72901 m .70783 .76612 L .70518 .76025 L p .707 .577 .707 r
F P
0 g
s
.70518 .76025 m .69843 .72314 L .70108 .72901 L p .707 .577 .707 r
F P
0 g
s
.43865 .81828 m .44743 .31742 L .40867 .31044 L p .707 .577 .707 r
F P
0 g
s
.44743 .31742 m .43865 .81828 L .48265 .82174 L p .707 .577 .707 r
F P
0 g
s
.69862 .64648 m .70207 .70232 L .68952 .69584 L p .707 .577 .707 r
F P
0 g
s
.68952 .69584 m .68607 .64 L .69862 .64648 L p .707 .577 .707 r
F P
0 g
s
.50852 .86012 m .50503 .84158 L .50239 .8358 L p .707 .577 .707 r
F P
0 g
s
.57823 .69135 m .57478 .63551 L .60657 .63296 L p .707 .577 .707 r
F P
0 g
s
.60657 .63296 m .61002 .6888 L .57823 .69135 L p .707 .577 .707 r
F P
0 g
s
.58346 .76665 m .5767 .72954 L .60806 .72353 L p .707 .577 .707 r
F P
0 g
s
.60806 .72353 m .61482 .76064 L .58346 .76665 L p .707 .577 .707 r
F P
0 g
s
.58211 .82252 m .57861 .80397 L .60994 .79777 L p .707 .577 .707 r
F P
0 g
s
.60994 .79777 m .61343 .81632 L .58211 .82252 L p .707 .577 .707 r
F P
0 g
s
.57784 .31627 m .56907 .81713 L .60302 .80951 L p .707 .577 .707 r
F P
0 g
s
.60302 .80951 m .6118 .30865 L .57784 .31627 L p .707 .577 .707 r
F P
0 g
s
.50239 .8358 m .50589 .85434 L .50852 .86012 L p .707 .577 .707 r
F P
0 g
s
.7028 .80243 m .7063 .82098 L .70366 .8152 L p .707 .577 .707 r
F P
0 g
s
.70366 .8152 m .70017 .79665 L .7028 .80243 L p .707 .577 .707 r
F P
0 g
s
.39989 .8113 m .40867 .31044 L .37895 .30062 L p .707 .577 .707 r
F P
0 g
s
.40867 .31044 m .39989 .8113 L .43865 .81828 L p .707 .577 .707 r
F P
0 g
s
.25334 .71861 m .24989 .66278 L .21878 .66284 L p .707 .577 .707 r
F P
0 g
s
.24989 .66278 m .25334 .71861 L .28512 .71606 L p .707 .577 .707 r
F P
0 g
s
.28512 .71606 m .28167 .66023 L .24989 .66278 L p .707 .577 .707 r
F P
0 g
s
.28167 .66023 m .28512 .71606 L .31446 .71128 L p .707 .577 .707 r
F P
0 g
s
.31446 .71128 m .31101 .65544 L .28167 .66023 L p .707 .577 .707 r
F P
0 g
s
.69843 .72314 m .70518 .76025 L .69297 .75652 L p .707 .577 .707 r
F P
0 g
s
.69297 .75652 m .68621 .71941 L .69843 .72314 L p .707 .577 .707 r
F P
0 g
s
.22222 .71868 m .21878 .66284 L .19138 .66041 L p .707 .577 .707 r
F P
0 g
s
.21878 .66284 m .22222 .71868 L .25334 .71861 L p .707 .577 .707 r
F P
0 g
s
.68607 .64 m .68952 .69584 L .66852 .69116 L p .707 .577 .707 r
F P
0 g
s
.66852 .69116 m .66507 .63532 L .68607 .64 L p .707 .577 .707 r
F P
0 g
s
.31101 .65544 m .31446 .71128 L .33848 .70472 L p .707 .577 .707 r
F P
0 g
s
.33848 .70472 m .33503 .64889 L .31101 .65544 L p .707 .577 .707 r
F P
0 g
s
.63768 .63289 m .64113 .68873 L .61002 .6888 L p .707 .577 .707 r
F P
0 g
s
.61002 .6888 m .60657 .63296 L .63768 .63289 L p .707 .577 .707 r
F P
0 g
s
.6387 .71962 m .64546 .75673 L .61482 .76064 L p .707 .577 .707 r
F P
0 g
s
.61482 .76064 m .60806 .72353 L .6387 .71962 L p .707 .577 .707 r
F P
0 g
s
.61343 .81632 m .60994 .79777 L .64054 .79366 L p .707 .577 .707 r
F P
0 g
s
.6118 .30865 m .60302 .80951 L .62613 .79924 L p .707 .577 .707 r
F P
0 g
s
.62613 .79924 m .6349 .29837 L .6118 .30865 L p .707 .577 .707 r
F P
0 g
s
.50589 .85434 m .50239 .8358 L .50957 .82839 L p .707 .577 .707 r
F P
0 g
s
.2572 .76787 m .25045 .73076 L .2198 .73467 L p .707 .577 .707 r
F P
0 g
s
.25045 .73076 m .2572 .76787 L .28856 .76186 L p .707 .577 .707 r
F P
0 g
s
.28856 .76186 m .2818 .72475 L .25045 .73076 L p .707 .577 .707 r
F P
0 g
s
.2818 .72475 m .28856 .76186 L .31756 .75432 L p .707 .577 .707 r
F P
0 g
s
.31756 .75432 m .31081 .71721 L .2818 .72475 L p .707 .577 .707 r
F P
0 g
s
.50957 .82839 m .51306 .84693 L .50589 .85434 L p .707 .577 .707 r
F P
0 g
s
.19138 .66041 m .19483 .71625 L .22222 .71868 L p .707 .577 .707 r
F P
0 g
s
.19483 .71625 m .19138 .66041 L .17038 .65573 L p .707 .577 .707 r
F P
0 g
s
.70017 .79665 m .70366 .8152 L .69147 .81162 L p .707 .577 .707 r
F P
0 g
s
.69147 .81162 m .68798 .79307 L .70017 .79665 L p .707 .577 .707 r
F P
0 g
s
.2198 .73467 m .22656 .77178 L .2572 .76787 L p .707 .577 .707 r
F P
0 g
s
.22656 .77178 m .2198 .73467 L .19287 .73609 L p .707 .577 .707 r
F P
0 g
s
.37017 .80149 m .37895 .30062 L .36118 .28893 L p .707 .577 .707 r
F P
0 g
s
.37895 .30062 m .37017 .80149 L .39989 .8113 L p .707 .577 .707 r
F P
0 g
s
.25574 .79587 m .25225 .77733 L .22164 .78144 L p .707 .577 .707 r
F P
0 g
s
.25225 .77733 m .25574 .79587 L .28707 .78967 L p .707 .577 .707 r
F P
0 g
s
.28707 .78967 m .28357 .77113 L .25225 .77733 L p .707 .577 .707 r
F P
0 g
s
.31081 .71721 m .31756 .75432 L .34137 .746 L p .707 .577 .707 r
F P
0 g
s
.34137 .746 m .33462 .70889 L .31081 .71721 L p .707 .577 .707 r
F P
0 g
s
.28357 .77113 m .28707 .78967 L .31604 .78199 L p .707 .577 .707 r
F P
0 g
s
.31604 .78199 m .31255 .76344 L .28357 .77113 L p .707 .577 .707 r
F P
0 g
s
.33503 .64889 m .33848 .70472 L .35484 .69705 L p .707 .577 .707 r
F P
0 g
s
.35484 .69705 m .35139 .64121 L .33503 .64889 L p .707 .577 .707 r
F P
0 g
s
.19287 .73609 m .19963 .7732 L .22656 .77178 L p .707 .577 .707 r
F P
0 g
s
.22164 .78144 m .22514 .79998 L .25574 .79587 L p .707 .577 .707 r
F P
0 g
s
.68621 .71941 m .69297 .75652 L .67239 .75531 L p .707 .577 .707 r
F P
0 g
s
.67239 .75531 m .66563 .7182 L .68621 .71941 L p .707 .577 .707 r
F P
0 g
s
.66507 .63532 m .66852 .69116 L .64113 .68873 L p .707 .577 .707 r
F P
0 g
s
.64113 .68873 m .63768 .63289 L .66507 .63532 L p .707 .577 .707 r
F P
0 g
s
.17038 .65573 m .17383 .71157 L .19483 .71625 L p .707 .577 .707 r
F P
0 g
s
.22514 .79998 m .22164 .78144 L .19475 .78306 L p .707 .577 .707 r
F P
0 g
s
.19475 .78306 m .19825 .8016 L .22514 .79998 L p .707 .577 .707 r
F P
0 g
s
.31255 .76344 m .31604 .78199 L .33984 .77357 L p .707 .577 .707 r
F P
0 g
s
.33984 .77357 m .33634 .75503 L .31255 .76344 L p .707 .577 .707 r
F P
0 g
s
.19963 .7732 m .19287 .73609 L .1723 .73488 L p .707 .577 .707 r
F P
0 g
s
.17383 .71157 m .17038 .65573 L .15783 .64926 L p .707 .577 .707 r
F P
0 g
s
.33462 .70889 m .34137 .746 L .35766 .73771 L p .707 .577 .707 r
F P
0 g
s
.35766 .73771 m .3509 .7006 L .33462 .70889 L p .707 .577 .707 r
F P
0 g
s
.1723 .73488 m .17905 .77199 L .19963 .7732 L p .707 .577 .707 r
F P
0 g
s
.6349 .29837 m .62613 .79924 L .63613 .7873 L p .707 .577 .707 r
F P
0 g
s
.63613 .7873 m .64491 .28644 L .6349 .29837 L p .707 .577 .707 r
F P
0 g
s
.68798 .79307 m .69147 .81162 L .67093 .81059 L p .707 .577 .707 r
F P
0 g
s
.67093 .81059 m .66744 .79204 L .68798 .79307 L p .707 .577 .707 r
F P
0 g
s
.19825 .8016 m .19475 .78306 L .17421 .78203 L p .707 .577 .707 r
F P
0 g
s
.66563 .7182 m .67239 .75531 L .64546 .75673 L p .707 .577 .707 r
F P
0 g
s
.64546 .75673 m .6387 .71962 L .66563 .7182 L p .707 .577 .707 r
F P
0 g
s
.17421 .78203 m .1777 .80057 L .19825 .8016 L p .707 .577 .707 r
F P
0 g
s
.35139 .64121 m .35484 .69705 L .36162 .68934 L p .707 .577 .707 r
F P
0 g
s
.36161 .68754 m .35139 .64121 L .36162 .68934 L .707 .577 .707 r
F
.36193 .68899 m .35848 .63316 L .35139 .64121 L p F P
0 g
s
.33634 .75503 m .33984 .77357 L .35612 .76525 L p .707 .577 .707 r
F P
0 g
s
.35612 .76525 m .35262 .74671 L .33634 .75503 L p .707 .577 .707 r
F P
0 g
s
.3509 .7006 m .35766 .73771 L .36203 .73317 L p .707 .577 .707 r
F P
0 g
s
.36203 .73317 m .36482 .73027 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36165 .7235 m .3509 .7006 L .36203 .73317 L .707 .577 .707 r
F
.35464 .54447 m .35951 .38388 L .35709 .27652 L F
.35807 .69316 m .3509 .7006 L p .36165 .7235 L F P
0 g
s
.36482 .73027 m .36112 .7099 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36112 .7099 m .35807 .69316 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.35262 .74671 m .35612 .76525 L .36329 .75784 L p .707 .577 .707 r
F P
0 g
s
.36329 .75784 m .35979 .7393 L .35262 .74671 L p .707 .577 .707 r
F P
0 g
s
.35561 .62552 m .35906 .68135 L .34652 .67488 L p .707 .577 .707 r
F P
0 g
s
.34652 .67488 m .34307 .61904 L .35561 .62552 L p .707 .577 .707 r
F P
0 g
s
.35542 .68728 m .3582 .70256 L p .34996 .72067 L .707 .577 .707 r
F P
0 g
s
.3582 .70256 m .36217 .72439 L .35677 .72275 L p .707 .577 .707 r
F P
0 g
s
.35677 .72275 m .34996 .72067 L p .3582 .70256 L .707 .577 .707 r
F P
0 g
s
.34996 .72067 m .3432 .68356 L .35542 .68728 L p .707 .577 .707 r
F P
0 g
s
.35716 .73352 m .36065 .75206 L .34846 .74848 L p .707 .577 .707 r
F P
0 g
s
.34846 .74848 m .34497 .72994 L .35716 .73352 L p .707 .577 .707 r
F P
0 g
s
.3432 .68356 m .34996 .72067 L .32938 .71946 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35211 .78892 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35211 .78892 m .3524 .7898 L p .35245 .78406 L .707 .577 .707 r
F P
0 g
s
.35245 .78406 m .35464 .54447 L .35211 .78892 L .707 .577 .707 r
F
.35709 .27652 m .35309 .50482 L p .35464 .54447 L F P
0 g
s
.35309 .50482 m .34831 .77738 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.3524 .7898 m .35606 .58077 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35606 .58077 m .35951 .38388 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35951 .38388 m .36118 .28893 L .35881 .28173 L p .707 .577 .707 r
F P
0 g
s
.35881 .28173 m .35709 .27652 L p .35951 .38388 L .707 .577 .707 r
F P
0 g
s
.36162 .68934 m .36193 .68899 L p .36161 .68754 L .707 .577 .707 r
F P
0 g
s
.15783 .64926 m .16128 .70509 L .17383 .71157 L p .707 .577 .707 r
F P
0 g
s
.17905 .77199 m .1723 .73488 L .16008 .73115 L p .707 .577 .707 r
F P
0 g
s
.35848 .63316 m .36193 .68899 L .35906 .68135 L p .707 .577 .707 r
F P
0 g
s
.35906 .68135 m .35561 .62552 L .35848 .63316 L p .707 .577 .707 r
F P
0 g
s
.35807 .69316 m .36482 .73027 L .36217 .72439 L p .707 .577 .707 r
F P
0 g
s
.36217 .72439 m .35542 .68728 L .35807 .69316 L p .707 .577 .707 r
F P
0 g
s
.35979 .7393 m .36329 .75784 L .36065 .75206 L p .707 .577 .707 r
F P
0 g
s
.36065 .75206 m .35716 .73352 L .35979 .7393 L p .707 .577 .707 r
F P
0 g
s
.36118 .28893 m .3524 .7898 L .37017 .80149 L p .707 .577 .707 r
F P
0 g
s
.16128 .70509 m .15783 .64926 L .15496 .64162 L p .707 .577 .707 r
F P
0 g
s
.16008 .73115 m .16684 .76826 L .17905 .77199 L p .707 .577 .707 r
F P
0 g
s
.66744 .79204 m .67093 .81059 L .64404 .8122 L p .707 .577 .707 r
F P
0 g
s
.64404 .8122 m .64054 .79366 L .66744 .79204 L p .707 .577 .707 r
F P
0 g
s
.1777 .80057 m .17421 .78203 L .16202 .77845 L p .707 .577 .707 r
F P
0 g
s
.16202 .77845 m .16551 .79699 L .1777 .80057 L p .707 .577 .707 r
F P
0 g
s
.15496 .64162 m .15841 .69745 L .16128 .70509 L p .707 .577 .707 r
F P
0 g
s
.64491 .28644 m .63613 .7873 L .63204 .77489 L p .707 .577 .707 r
F P
0 g
s
.63204 .77489 m .64082 .27402 L .64491 .28644 L p .707 .577 .707 r
F P
0 g
s
.64054 .79366 m .64404 .8122 L .61343 .81632 L p .707 .577 .707 r
F P
0 g
s
.16684 .76826 m .16008 .73115 L .15743 .72528 L p .707 .577 .707 r
F P
0 g
s
.15743 .72528 m .16418 .76239 L .16684 .76826 L p .707 .577 .707 r
F P
0 g
s
.15841 .69745 m .15496 .64162 L .16205 .63356 L p .707 .577 .707 r
F P
0 g
s
.16551 .79699 m .16202 .77845 L .15938 .77267 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35709 .27652 L .36709 .26458 L p .707 .577 .707 r
F P
0 g
s
.15938 .77267 m .16288 .79121 L .16551 .79699 L p .707 .577 .707 r
F P
0 g
s
.16205 .63356 m .1655 .6894 L .15841 .69745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16418 .76239 m .15743 .72528 L .16459 .71784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16459 .71784 m .17135 .75495 L .16418 .76239 L p .707 .577 .707 r
F P
0 g
s
.1655 .6894 m .16205 .63356 L .17841 .62588 L p .707 .577 .707 r
F P
0 g
s
.64082 .27402 m .63204 .77489 L .61427 .7632 L p .707 .577 .707 r
F P
0 g
s
.61427 .7632 m .62305 .26233 L .64082 .27402 L p .707 .577 .707 r
F P
0 g
s
.16288 .79121 m .15938 .77267 L .16656 .76525 L p .707 .577 .707 r
F P
0 g
s
.16656 .76525 m .17005 .7838 L .16288 .79121 L p .707 .577 .707 r
F P
0 g
s
.34307 .61904 m .34652 .67488 L .32551 .6702 L p .707 .577 .707 r
F P
0 g
s
.32551 .6702 m .32206 .61436 L .34307 .61904 L p .707 .577 .707 r
F P
0 g
s
.17841 .62588 m .18186 .68172 L .1655 .6894 L p .707 .577 .707 r
F P
0 g
s
.35832 .76545 m .36709 .26458 L .3902 .25431 L p .707 .577 .707 r
F P
0 g
s
.36709 .26458 m .35832 .76545 L .34831 .77738 L p .707 .577 .707 r
F P
0 g
s
.17135 .75495 m .16459 .71784 L .18088 .70955 L p .707 .577 .707 r
F P
0 g
s
.18186 .68172 m .17841 .62588 L .20244 .61933 L p .707 .577 .707 r
F P
0 g
s
.18088 .70955 m .18764 .74666 L .17135 .75495 L p .707 .577 .707 r
F P
0 g
s
.32938 .71946 m .32262 .68235 L .3432 .68356 L p .707 .577 .707 r
F P
0 g
s
.17005 .7838 m .16656 .76525 L .18284 .75693 L p .707 .577 .707 r
F P
0 g
s
.32206 .61436 m .32551 .6702 L .29812 .66777 L p .707 .577 .707 r
F P
0 g
s
.29812 .66777 m .29467 .61193 L .32206 .61436 L p .707 .577 .707 r
F P
0 g
s
.18284 .75693 m .18633 .77548 L .17005 .7838 L p .707 .577 .707 r
F P
0 g
s
.20244 .61933 m .20589 .67517 L .18186 .68172 L p .707 .577 .707 r
F P
0 g
s
.62305 .26233 m .61427 .7632 L .58455 .75338 L p .707 .577 .707 r
F P
0 g
s
.58455 .75338 m .59333 .25252 L .62305 .26233 L p .707 .577 .707 r
F P
0 g
s
.34497 .72994 m .34846 .74848 L .32792 .74745 L p .707 .577 .707 r
F P
0 g
s
.32792 .74745 m .32443 .72891 L .34497 .72994 L p .707 .577 .707 r
F P
0 g
s
.20589 .67517 m .20244 .61933 L .23178 .61455 L p .707 .577 .707 r
F P
0 g
s
.18764 .74666 m .18088 .70955 L .20469 .70123 L p .707 .577 .707 r
F P
0 g
s
.29467 .61193 m .29812 .66777 L .26701 .66783 L p .707 .577 .707 r
F P
0 g
s
.26701 .66783 m .26356 .612 L .29467 .61193 L p .707 .577 .707 r
F P
0 g
s
.32262 .68235 m .32938 .71946 L .30245 .72087 L p .707 .577 .707 r
F P
0 g
s
.30245 .72087 m .29569 .68376 L .32262 .68235 L p .707 .577 .707 r
F P
0 g
s
.3902 .25431 m .38142 .75517 L .35832 .76545 L p .707 .577 .707 r
F P
0 g
s
.38142 .75517 m .3902 .25431 L .42415 .24669 L p .707 .577 .707 r
F P
0 g
s
.20469 .70123 m .21144 .73834 L .18764 .74666 L p .707 .577 .707 r
F P
0 g
s
.73355 .64754 m .7301 .5917 L .69899 .59177 L p .707 .577 .707 r
F P
0 g
s
.7301 .5917 m .73355 .64754 L .76533 .64499 L p .707 .577 .707 r
F P
0 g
s
.76533 .64499 m .76188 .58915 L .7301 .5917 L p .707 .577 .707 r
F P
0 g
s
.23522 .67038 m .23178 .61455 L .26356 .612 L p .707 .577 .707 r
F P
0 g
s
.23178 .61455 m .23522 .67038 L .20589 .67517 L p .707 .577 .707 r
F P
0 g
s
.76188 .58915 m .76533 .64499 L .79467 .6402 L p .707 .577 .707 r
F P
0 g
s
.79467 .6402 m .79122 .58437 L .76188 .58915 L p .707 .577 .707 r
F P
0 g
s
.26356 .612 m .26701 .66783 L .23522 .67038 L p .707 .577 .707 r
F P
0 g
s
.18633 .77548 m .18284 .75693 L .20663 .74852 L p .707 .577 .707 r
F P
0 g
s
.70244 .6476 m .69899 .59177 L .67159 .58934 L p .707 .577 .707 r
F P
0 g
s
.69899 .59177 m .70244 .6476 L .73355 .64754 L p .707 .577 .707 r
F P
0 g
s
.20663 .74852 m .21012 .76707 L .18633 .77548 L p .707 .577 .707 r
F P
0 g
s
.32443 .72891 m .32792 .74745 L .30103 .74907 L p .707 .577 .707 r
F P
0 g
s
.30103 .74907 m .29754 .73053 L .32443 .72891 L p .707 .577 .707 r
F P
0 g
s
.21144 .73834 m .20469 .70123 L .23369 .69369 L p .707 .577 .707 r
F P
0 g
s
.79122 .58437 m .79467 .6402 L .81869 .63365 L p .707 .577 .707 r
F P
0 g
s
.81869 .63365 m .81524 .57781 L .79122 .58437 L p .707 .577 .707 r
F P
0 g
s
.29569 .68376 m .30245 .72087 L .27181 .72478 L p .707 .577 .707 r
F P
0 g
s
.27181 .72478 m .26505 .68767 L .29569 .68376 L p .707 .577 .707 r
F P
0 g
s
.59333 .25252 m .58455 .75338 L .54579 .74641 L p .707 .577 .707 r
F P
0 g
s
.54579 .74641 m .55457 .24554 L .59333 .25252 L p .707 .577 .707 r
F P
0 g
s
.23369 .69369 m .24045 .7308 L .21144 .73834 L p .707 .577 .707 r
F P
0 g
s
.67159 .58934 m .67504 .64518 L .70244 .6476 L p .707 .577 .707 r
F P
0 g
s
.24045 .7308 m .23369 .69369 L .26505 .68767 L p .707 .577 .707 r
F P
0 g
s
.73741 .71169 m .73066 .67458 L .70002 .67849 L p .707 .577 .707 r
F P
0 g
s
.73066 .67458 m .73741 .71169 L .76877 .70567 L p .707 .577 .707 r
F P
0 g
s
.76877 .70567 m .76202 .66856 L .73066 .67458 L p .707 .577 .707 r
F P
0 g
s
.67504 .64518 m .67159 .58934 L .65059 .58466 L p .707 .577 .707 r
F P
0 g
s
.21012 .76707 m .20663 .74852 L .2356 .74084 L p .707 .577 .707 r
F P
0 g
s
.26505 .68767 m .27181 .72478 L .24045 .7308 L p .707 .577 .707 r
F P
0 g
s
.76202 .66856 m .76877 .70567 L .79778 .69813 L p .707 .577 .707 r
F P
0 g
s
.79778 .69813 m .79102 .66102 L .76202 .66856 L p .707 .577 .707 r
F P
0 g
s
.2356 .74084 m .2391 .75938 L .21012 .76707 L p .707 .577 .707 r
F P
0 g
s
.41538 .74755 m .42415 .24669 L .46563 .24247 L p .707 .577 .707 r
F P
0 g
s
.42415 .24669 m .41538 .74755 L .38142 .75517 L p .707 .577 .707 r
F P
0 g
s
.29754 .73053 m .30103 .74907 L .27042 .75318 L p .707 .577 .707 r
F P
0 g
s
.27042 .75318 m .26693 .73464 L .29754 .73053 L p .707 .577 .707 r
F P
0 g
s
.70002 .67849 m .70677 .7156 L .73741 .71169 L p .707 .577 .707 r
F P
0 g
s
.70677 .7156 m .70002 .67849 L .67309 .67991 L p .707 .577 .707 r
F P
0 g
s
.81524 .57781 m .81869 .63365 L .83505 .62597 L p .707 .577 .707 r
F P
0 g
s
.83505 .62597 m .8316 .57013 L .81524 .57781 L p .707 .577 .707 r
F P
0 g
s
.2391 .75938 m .2356 .74084 L .26693 .73464 L p .707 .577 .707 r
F P
0 g
s
.79102 .66102 m .79778 .69813 L .82159 .68981 L p .707 .577 .707 r
F P
0 g
s
.82159 .68981 m .81483 .6527 L .79102 .66102 L p .707 .577 .707 r
F P
0 g
s
.26693 .73464 m .27042 .75318 L .2391 .75938 L p .707 .577 .707 r
F P
0 g
s
.65059 .58466 m .65404 .64049 L .67504 .64518 L p .707 .577 .707 r
F P
0 g
s
.67309 .67991 m .67984 .71702 L .70677 .7156 L p .707 .577 .707 r
F P
0 g
s
.55457 .24554 m .54579 .74641 L .50179 .74294 L p .707 .577 .707 r
F P
0 g
s
.50179 .74294 m .51057 .24208 L .55457 .24554 L p .707 .577 .707 r
F P
0 g
s
.73596 .76697 m .73246 .74842 L .70186 .75253 L p .707 .577 .707 r
F P
0 g
s
.73246 .74842 m .73596 .76697 L .76728 .76077 L p .707 .577 .707 r
F P
0 g
s
.76728 .76077 m .76379 .74222 L .73246 .74842 L p .707 .577 .707 r
F P
0 g
s
.76379 .74222 m .76728 .76077 L .79626 .75308 L p .707 .577 .707 r
F P
0 g
s
.79626 .75308 m .79276 .73454 L .76379 .74222 L p .707 .577 .707 r
F P
0 g
s
.45685 .74334 m .46563 .24247 L .51057 .24208 L p .707 .577 .707 r
F P
0 g
s
.46563 .24247 m .45685 .74334 L .41538 .74755 L p .707 .577 .707 r
F P
0 g
s
.70186 .75253 m .70535 .77108 L .73596 .76697 L p .707 .577 .707 r
F P
0 g
s
.65404 .64049 m .65059 .58466 L .63804 .57818 L p .707 .577 .707 r
F P
0 g
s
.67984 .71702 m .67309 .67991 L .65251 .67869 L p .707 .577 .707 r
F P
0 g
s
.51057 .24208 m .50179 .74294 L .45685 .74334 L p .707 .577 .707 r
F P
0 g
s
.70535 .77108 m .70186 .75253 L .67496 .75415 L p .707 .577 .707 r
F P
0 g
s
.67496 .75415 m .67846 .7727 L .70535 .77108 L p .707 .577 .707 r
F P
0 g
s
.81483 .6527 m .82159 .68981 L .83787 .68153 L p .707 .577 .707 r
F P
0 g
s
.83787 .68153 m .83112 .64442 L .81483 .6527 L p .707 .577 .707 r
F P
0 g
s
.79276 .73454 m .79626 .75308 L .82005 .74467 L p .707 .577 .707 r
F P
0 g
s
.82005 .74467 m .81656 .72613 L .79276 .73454 L p .707 .577 .707 r
F P
0 g
s
.65251 .67869 m .65926 .7158 L .67984 .71702 L p .707 .577 .707 r
F P
0 g
s
.8316 .57013 m .83505 .62597 L .84215 .61792 L p .707 .577 .707 r
F P
0 g
s
.84215 .61792 m .8387 .56208 L .8316 .57013 L p .707 .577 .707 r
F P
0 g
s
.63804 .57818 m .64149 .63402 L .65404 .64049 L p .707 .577 .707 r
F P
0 g
s
.67846 .7727 m .67496 .75415 L .65442 .75312 L p .707 .577 .707 r
F P
0 g
s
.65442 .75312 m .65791 .77167 L .67846 .7727 L p .707 .577 .707 r
F P
0 g
s
.65926 .7158 m .65251 .67869 L .64029 .67497 L p .707 .577 .707 r
F P
0 g
s
.81656 .72613 m .82005 .74467 L .83633 .73635 L p .707 .577 .707 r
F P
0 g
s
.83633 .73635 m .83284 .71781 L .81656 .72613 L p .707 .577 .707 r
F P
0 g
s
.64149 .63402 m .63804 .57818 L .63517 .57054 L p .707 .577 .707 r
F P
0 g
s
.64029 .67497 m .64705 .71208 L .65926 .7158 L p .707 .577 .707 r
F P
0 g
s
.83112 .64442 m .83787 .68153 L .84504 .67408 L p .707 .577 .707 r
F P
0 g
s
.84504 .67408 m .83828 .63697 L .83112 .64442 L p .707 .577 .707 r
F P
0 g
s
.63517 .57054 m .63862 .62638 L .64149 .63402 L p .707 .577 .707 r
F P
0 g
s
.8387 .56208 m .84215 .61792 L .83928 .61028 L p .707 .577 .707 r
F P
0 g
s
.83928 .61028 m .83583 .55444 L .8387 .56208 L p .707 .577 .707 r
F P
0 g
s
.65791 .77167 m .65442 .75312 L .64223 .74954 L p .707 .577 .707 r
F P
0 g
s
.64223 .74954 m .64573 .76808 L .65791 .77167 L p .707 .577 .707 r
F P
0 g
s
.83284 .71781 m .83633 .73635 L .8435 .72894 L p .707 .577 .707 r
F P
0 g
s
.8435 .72894 m .84001 .71039 L .83284 .71781 L p .707 .577 .707 r
F P
0 g
s
.64705 .71208 m .64029 .67497 L .63764 .6691 L p .707 .577 .707 r
F P
0 g
s
.63862 .62638 m .63517 .57054 L .64227 .56249 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63764 .6691 m .6444 .70621 L .64705 .71208 L p .707 .577 .707 r
F P
0 g
s
.83828 .63697 m .84504 .67408 L .84238 .66821 L p .707 .577 .707 r
F P
0 g
s
.84238 .66821 m .83563 .6311 L .83828 .63697 L p .707 .577 .707 r
F P
0 g
s
.64227 .56249 m .64572 .61833 L .63862 .62638 L p .707 .577 .707 r
F P
0 g
s
.83583 .55444 m .83928 .61028 L .82673 .6038 L p .707 .577 .707 r
F P
0 g
s
.82673 .6038 m .82328 .54796 L .83583 .55444 L p .707 .577 .707 r
F P
0 g
s
.64573 .76808 m .64223 .74954 L .6396 .74376 L p .707 .577 .707 r
F P
0 g
s
.6396 .74376 m .64309 .76231 L .64573 .76808 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84001 .71039 m .8435 .72894 L .84087 .72316 L p .707 .577 .707 r
F P
0 g
s
.84087 .72316 m .83737 .70461 L .84001 .71039 L p .707 .577 .707 r
F P
0 g
s
.6444 .70621 m .63764 .6691 L .64481 .66165 L p .707 .577 .707 r
F P
0 g
s
.39054 .62658 m .38709 .57074 L .35598 .5708 L p .707 .577 .707 r
F P
0 g
s
.38709 .57074 m .39054 .62658 L .42232 .62402 L p .707 .577 .707 r
F P
0 g
s
.42232 .62402 m .41887 .56819 L .38709 .57074 L p .707 .577 .707 r
F P
0 g
s
.64572 .61833 m .64227 .56249 L .65863 .55481 L p .707 .577 .707 r
F P
0 g
s
.41887 .56819 m .42232 .62402 L .45166 .61924 L p .707 .577 .707 r
F P
0 g
s
.45166 .61924 m .44821 .5634 L .41887 .56819 L p .707 .577 .707 r
F P
0 g
s
.64481 .66165 m .65156 .69876 L .6444 .70621 L p .707 .577 .707 r
F P
0 g
s
.83563 .6311 m .84238 .66821 L .83017 .66449 L p .707 .577 .707 r
F P
0 g
s
.83017 .66449 m .82342 .62737 L .83563 .6311 L p .707 .577 .707 r
F P
0 g
s
.35943 .62664 m .35598 .5708 L .32858 .56838 L p .707 .577 .707 r
F P
0 g
s
.35598 .5708 m .35943 .62664 L .39054 .62658 L p .707 .577 .707 r
F P
0 g
s
.82328 .54796 m .82673 .6038 L .80573 .59912 L p .707 .577 .707 r
F P
0 g
s
.80573 .59912 m .80228 .54328 L .82328 .54796 L p .707 .577 .707 r
F P
0 g
s
.44821 .5634 m .45166 .61924 L .47568 .61269 L p .707 .577 .707 r
F P
0 g
s
.47568 .61269 m .47223 .55685 L .44821 .5634 L p .707 .577 .707 r
F P
0 g
s
.65863 .55481 m .66208 .61065 L .64572 .61833 L p .707 .577 .707 r
F P
0 g
s
.64309 .76231 m .6396 .74376 L .64677 .73635 L p .707 .577 .707 r
F P
0 g
s
.3944 .67584 m .38765 .63872 L .35701 .64263 L p .707 .577 .707 r
F P
0 g
s
.38765 .63872 m .3944 .67584 L .42576 .66982 L p .707 .577 .707 r
F P
0 g
s
.42576 .66982 m .41901 .63271 L .38765 .63872 L p .707 .577 .707 r
F P
0 g
s
.41901 .63271 m .42576 .66982 L .45477 .66228 L p .707 .577 .707 r
F P
0 g
s
.45477 .66228 m .44801 .62517 L .41901 .63271 L p .707 .577 .707 r
F P
0 g
s
.64677 .73635 m .65026 .75489 L .64309 .76231 L p .707 .577 .707 r
F P
0 g
s
.32858 .56838 m .33203 .62421 L .35943 .62664 L p .707 .577 .707 r
F P
0 g
s
.33203 .62421 m .32858 .56838 L .30758 .56369 L p .707 .577 .707 r
F P
0 g
s
.83737 .70461 m .84087 .72316 L .82868 .71958 L p .707 .577 .707 r
F P
0 g
s
.82868 .71958 m .82519 .70103 L .83737 .70461 L p .707 .577 .707 r
F P
0 g
s
.35701 .64263 m .36376 .67974 L .3944 .67584 L p .707 .577 .707 r
F P
0 g
s
.66208 .61065 m .65863 .55481 L .68265 .54826 L p .707 .577 .707 r
F P
0 g
s
.36376 .67974 m .35701 .64263 L .33008 .64405 L p .707 .577 .707 r
F P
0 g
s
.65156 .69876 m .64481 .66165 L .66109 .65336 L p .707 .577 .707 r
F P
0 g
s
.39295 .70383 m .38945 .68529 L .35885 .6894 L p .707 .577 .707 r
F P
0 g
s
.38945 .68529 m .39295 .70383 L .42427 .69763 L p .707 .577 .707 r
F P
0 g
s
.42427 .69763 m .42078 .67909 L .38945 .68529 L p .707 .577 .707 r
F P
0 g
s
.44801 .62517 m .45477 .66228 L .47858 .65396 L p .707 .577 .707 r
F P
0 g
s
.47858 .65396 m .47182 .61685 L .44801 .62517 L p .707 .577 .707 r
F P
0 g
s
.42078 .67909 m .42427 .69763 L .45325 .68995 L p .707 .577 .707 r
F P
0 g
s
.45325 .68995 m .44975 .6714 L .42078 .67909 L p .707 .577 .707 r
F P
0 g
s
.47223 .55685 m .47568 .61269 L .49204 .60501 L p .707 .577 .707 r
F P
0 g
s
.49204 .60501 m .48859 .54917 L .47223 .55685 L p .707 .577 .707 r
F P
0 g
s
.33008 .64405 m .33683 .68116 L .36376 .67974 L p .707 .577 .707 r
F P
0 g
s
.66109 .65336 m .66785 .69047 L .65156 .69876 L p .707 .577 .707 r
F P
0 g
s
.35885 .6894 m .36234 .70794 L .39295 .70383 L p .707 .577 .707 r
F P
0 g
s
.82342 .62737 m .83017 .66449 L .80959 .66327 L p .707 .577 .707 r
F P
0 g
s
.80959 .66327 m .80284 .62616 L .82342 .62737 L p .707 .577 .707 r
F P
0 g
s
.80228 .54328 m .80573 .59912 L .77833 .59669 L p .707 .577 .707 r
F P
0 g
s
.77833 .59669 m .77488 .54086 L .80228 .54328 L p .707 .577 .707 r
F P
0 g
s
.30758 .56369 m .31103 .61953 L .33203 .62421 L p .707 .577 .707 r
F P
0 g
s
.36234 .70794 m .35885 .6894 L .33195 .69102 L p .707 .577 .707 r
F P
0 g
s
.68265 .54826 m .6861 .60409 L .66208 .61065 L p .707 .577 .707 r
F P
0 g
s
.33195 .69102 m .33545 .70956 L .36234 .70794 L p .707 .577 .707 r
F P
0 g
s
.44975 .6714 m .45325 .68995 L .47704 .68154 L p .707 .577 .707 r
F P
0 g
s
.47704 .68154 m .47355 .66299 L .44975 .6714 L p .707 .577 .707 r
F P
0 g
s
.33683 .68116 m .33008 .64405 L .3095 .64284 L p .707 .577 .707 r
F P
0 g
s
.6861 .60409 m .68265 .54826 L .71199 .54347 L p .707 .577 .707 r
F P
0 g
s
.65026 .75489 m .64677 .73635 L .66305 .72803 L p .707 .577 .707 r
F P
0 g
s
.31103 .61953 m .30758 .56369 L .29503 .55722 L p .707 .577 .707 r
F P
0 g
s
.66305 .72803 m .66654 .74657 L .65026 .75489 L p .707 .577 .707 r
F P
0 g
s
.47182 .61685 m .47858 .65396 L .49486 .64567 L p .707 .577 .707 r
F P
0 g
s
.49486 .64567 m .48811 .60856 L .47182 .61685 L p .707 .577 .707 r
F P
0 g
s
.3095 .64284 m .31625 .67995 L .33683 .68116 L p .707 .577 .707 r
F P
0 g
s
.66785 .69047 m .66109 .65336 L .6849 .64504 L p .707 .577 .707 r
F P
0 g
s
.77488 .54086 m .77833 .59669 L .74722 .59676 L p .707 .577 .707 r
F P
0 g
s
.74722 .59676 m .74377 .54092 L .77488 .54086 L p .707 .577 .707 r
F P
0 g
s
.82519 .70103 m .82868 .71958 L .80813 .71855 L p .707 .577 .707 r
F P
0 g
s
.80813 .71855 m .80464 .7 L .82519 .70103 L p .707 .577 .707 r
F P
0 g
s
.33545 .70956 m .33195 .69102 L .31141 .68999 L p .707 .577 .707 r
F P
0 g
s
.71544 .59931 m .71199 .54347 L .74377 .54092 L p .707 .577 .707 r
F P
0 g
s
.71199 .54347 m .71544 .59931 L .6861 .60409 L p .707 .577 .707 r
F P
0 g
s
.80284 .62616 m .80959 .66327 L .78266 .66469 L p .707 .577 .707 r
F P
0 g
s
.78266 .66469 m .77591 .62758 L .80284 .62616 L p .707 .577 .707 r
F P
0 g
s
.31141 .68999 m .3149 .70853 L .33545 .70956 L p .707 .577 .707 r
F P
0 g
s
.48859 .54917 m .49204 .60501 L .49914 .59695 L p .707 .577 .707 r
F P
0 g
s
.49914 .59695 m .49569 .54112 L .48859 .54917 L p .707 .577 .707 r
F P
0 g
s
.6849 .64504 m .69166 .68215 L .66785 .69047 L p .707 .577 .707 r
F P
0 g
s
.74377 .54092 m .74722 .59676 L .71544 .59931 L p .707 .577 .707 r
F P
0 g
s
.29503 .55722 m .29848 .61305 L .31103 .61953 L p .707 .577 .707 r
F P
0 g
s
.47355 .66299 m .47704 .68154 L .49332 .67322 L p .707 .577 .707 r
F P
0 g
s
.49332 .67322 m .48983 .65467 L .47355 .66299 L p .707 .577 .707 r
F P
0 g
s
.31625 .67995 m .3095 .64284 L .29728 .63911 L p .707 .577 .707 r
F P
0 g
s
.69166 .68215 m .6849 .64504 L .71391 .6375 L p .707 .577 .707 r
F P
0 g
s
.66654 .74657 m .66305 .72803 L .68684 .71962 L p .707 .577 .707 r
F P
0 g
s
.29848 .61305 m .29503 .55722 L .29216 .54958 L p .707 .577 .707 r
F P
0 g
s
.29728 .63911 m .30404 .67622 L .31625 .67995 L p .707 .577 .707 r
F P
0 g
s
.68684 .71962 m .69034 .73816 L .66654 .74657 L p .707 .577 .707 r
F P
0 g
s
.48811 .60856 m .49486 .64567 L .50203 .63823 L p .707 .577 .707 r
F P
0 g
s
.50203 .63823 m .49527 .60112 L .48811 .60856 L p .707 .577 .707 r
F P
0 g
s
.77591 .62758 m .78266 .66469 L .75202 .6686 L p .707 .577 .707 r
F P
0 g
s
.75202 .6686 m .74527 .63149 L .77591 .62758 L p .707 .577 .707 r
F P
0 g
s
.80464 .7 m .80813 .71855 L .78124 .72017 L p .707 .577 .707 r
F P
0 g
s
.78124 .72017 m .77775 .70162 L .80464 .7 L p .707 .577 .707 r
F P
0 g
s
.71391 .6375 m .72066 .67462 L .69166 .68215 L p .707 .577 .707 r
F P
0 g
s
.3149 .70853 m .31141 .68999 L .29922 .68641 L p .707 .577 .707 r
F P
0 g
s
.72066 .67462 m .71391 .6375 L .74527 .63149 L p .707 .577 .707 r
F P
0 g
s
.29922 .68641 m .30272 .70495 L .3149 .70853 L p .707 .577 .707 r
F P
0 g
s
.74527 .63149 m .75202 .6686 L .72066 .67462 L p .707 .577 .707 r
F P
0 g
s
.48983 .65467 m .49332 .67322 L .50049 .6658 L p .707 .577 .707 r
F P
0 g
s
.50049 .6658 m .497 .64726 L .48983 .65467 L p .707 .577 .707 r
F P
0 g
s
.29216 .54958 m .29561 .60542 L .29848 .61305 L p .707 .577 .707 r
F P
0 g
s
.49569 .54112 m .49914 .59695 L .49627 .58931 L p .707 .577 .707 r
F P
0 g
s
.49627 .58931 m .49282 .53348 L .49569 .54112 L p .707 .577 .707 r
F P
0 g
s
.69034 .73816 m .68684 .71962 L .71582 .71193 L p .707 .577 .707 r
F P
0 g
s
.71582 .71193 m .71931 .73048 L .69034 .73816 L p .707 .577 .707 r
F P
0 g
s
.77775 .70162 m .78124 .72017 L .75064 .72428 L p .707 .577 .707 r
F P
0 g
s
.75064 .72428 m .74714 .70573 L .77775 .70162 L p .707 .577 .707 r
F P
0 g
s
.30404 .67622 m .29728 .63911 L .29463 .63324 L p .707 .577 .707 r
F P
0 g
s
.71931 .73048 m .71582 .71193 L .74714 .70573 L p .707 .577 .707 r
F P
0 g
s
.29463 .63324 m .30139 .67035 L .30404 .67622 L p .707 .577 .707 r
F P
0 g
s
.74714 .70573 m .75064 .72428 L .71931 .73048 L p .707 .577 .707 r
F P
0 g
s
.29561 .60542 m .29216 .54958 L .29925 .54152 L p .707 .577 .707 r
F P
0 g
s
.49527 .60112 m .50203 .63823 L .49937 .63236 L p .707 .577 .707 r
F P
0 g
s
.49937 .63236 m .49262 .59524 L .49527 .60112 L p .707 .577 .707 r
F P
0 g
s
.30272 .70495 m .29922 .68641 L .29659 .68063 L p .707 .577 .707 r
F P
0 g
s
.29659 .68063 m .30008 .69917 L .30272 .70495 L p .707 .577 .707 r
F P
0 g
s
.497 .64726 m .50049 .6658 L .49786 .66002 L p .707 .577 .707 r
F P
0 g
s
.49786 .66002 m .49436 .64148 L .497 .64726 L p .707 .577 .707 r
F P
0 g
s
.29925 .54152 m .3027 .59736 L .29561 .60542 L p .707 .577 .707 r
F P
0 g
s
.49282 .53348 m .49627 .58931 L .48372 .58284 L p .707 .577 .707 r
F P
0 g
s
.48372 .58284 m .48027 .527 L .49282 .53348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30139 .67035 m .29463 .63324 L .3018 .6258 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3018 .6258 m .30855 .66291 L .30139 .67035 L p .707 .577 .707 r
F P
0 g
s
.3027 .59736 m .29925 .54152 L .31561 .53385 L p .707 .577 .707 r
F P
0 g
s
.49262 .59524 m .49937 .63236 L .48716 .62863 L p .707 .577 .707 r
F P
0 g
s
.48716 .62863 m .48041 .59152 L .49262 .59524 L p .707 .577 .707 r
F P
0 g
s
.30008 .69917 m .29659 .68063 L .30376 .67322 L p .707 .577 .707 r
F P
0 g
s
.30376 .67322 m .30725 .69176 L .30008 .69917 L p .707 .577 .707 r
F P
0 g
s
.48027 .527 m .48372 .58284 L .46272 .57816 L p .707 .577 .707 r
F P
0 g
s
.46272 .57816 m .45927 .52232 L .48027 .527 L p .707 .577 .707 r
F P
0 g
s
.49436 .64148 m .49786 .66002 L .48567 .65644 L p .707 .577 .707 r
F P
0 g
s
.48567 .65644 m .48218 .6379 L .49436 .64148 L p .707 .577 .707 r
F P
0 g
s
.31561 .53385 m .31906 .58968 L .3027 .59736 L p .707 .577 .707 r
F P
0 g
s
.30855 .66291 m .3018 .6258 L .31808 .61751 L p .707 .577 .707 r
F P
0 g
s
.31906 .58968 m .31561 .53385 L .33964 .52729 L p .707 .577 .707 r
F P
0 g
s
.31808 .61751 m .32484 .65462 L .30855 .66291 L p .707 .577 .707 r
F P
0 g
s
.48041 .59152 m .48716 .62863 L .46658 .62742 L p .707 .577 .707 r
F P
0 g
s
.46658 .62742 m .45983 .59031 L .48041 .59152 L p .707 .577 .707 r
F P
0 g
s
.30725 .69176 m .30376 .67322 L .32004 .6649 L p .707 .577 .707 r
F P
0 g
s
.45927 .52232 m .46272 .57816 L .43532 .57573 L p .707 .577 .707 r
F P
0 g
s
.43532 .57573 m .43187 .51989 L .45927 .52232 L p .707 .577 .707 r
F P
0 g
s
.32004 .6649 m .32353 .68344 L .30725 .69176 L p .707 .577 .707 r
F P
0 g
s
.33964 .52729 m .34309 .58313 L .31906 .58968 L p .707 .577 .707 r
F P
0 g
s
.48218 .6379 m .48567 .65644 L .46512 .65541 L p .707 .577 .707 r
F P
0 g
s
.46512 .65541 m .46163 .63687 L .48218 .6379 L p .707 .577 .707 r
F P
0 g
s
.34309 .58313 m .33964 .52729 L .36898 .52251 L p .707 .577 .707 r
F P
0 g
s
.32484 .65462 m .31808 .61751 L .34189 .60919 L p .707 .577 .707 r
F P
0 g
s
.43187 .51989 m .43532 .57573 L .40421 .57579 L p .707 .577 .707 r
F P
0 g
s
.40421 .57579 m .40076 .51996 L .43187 .51989 L p .707 .577 .707 r
F P
0 g
s
.45983 .59031 m .46658 .62742 L .43965 .62883 L p .707 .577 .707 r
F P
0 g
s
.43965 .62883 m .4329 .59172 L .45983 .59031 L p .707 .577 .707 r
F P
0 g
s
.34189 .60919 m .34865 .6463 L .32484 .65462 L p .707 .577 .707 r
F P
0 g
s
.37243 .57834 m .36898 .52251 L .40076 .51996 L p .707 .577 .707 r
F P
0 g
s
.36898 .52251 m .37243 .57834 L .34309 .58313 L p .707 .577 .707 r
F P
0 g
s
.40076 .51996 m .40421 .57579 L .37243 .57834 L p .707 .577 .707 r
F P
0 g
s
.32353 .68344 m .32004 .6649 L .34383 .65648 L p .707 .577 .707 r
F P
0 g
s
.34383 .65648 m .34733 .67503 L .32353 .68344 L p .707 .577 .707 r
F P
0 g
s
.46163 .63687 m .46512 .65541 L .43823 .65703 L p .707 .577 .707 r
F P
0 g
s
.43823 .65703 m .43474 .63849 L .46163 .63687 L p .707 .577 .707 r
F P
0 g
s
.34865 .6463 m .34189 .60919 L .3709 .60165 L p .707 .577 .707 r
F P
0 g
s
.4329 .59172 m .43965 .62883 L .40901 .63274 L p .707 .577 .707 r
F P
0 g
s
.40901 .63274 m .40226 .59563 L .4329 .59172 L p .707 .577 .707 r
F P
0 g
s
.3709 .60165 m .37765 .63876 L .34865 .6463 L p .707 .577 .707 r
F P
0 g
s
.37765 .63876 m .3709 .60165 L .40226 .59563 L p .707 .577 .707 r
F P
0 g
s
.34733 .67503 m .34383 .65648 L .37281 .6488 L p .707 .577 .707 r
F P
0 g
s
.40226 .59563 m .40901 .63274 L .37765 .63876 L p .707 .577 .707 r
F P
0 g
s
.37281 .6488 m .3763 .66734 L .34733 .67503 L p .707 .577 .707 r
F P
0 g
s
.43474 .63849 m .43823 .65703 L .40763 .66114 L p .707 .577 .707 r
F P
0 g
s
.40763 .66114 m .40413 .6426 L .43474 .63849 L p .707 .577 .707 r
F P
0 g
s
.3763 .66734 m .37281 .6488 L .40413 .6426 L p .707 .577 .707 r
F P
0 g
s
.40413 .6426 m .40763 .66114 L .3763 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001UYF00<005YFFUH00eYF2@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001J
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF00AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol00`00FUH00006FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`T000AJEP03001JEUYF
00IJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Qo
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001WOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000IOolA000mOol005Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00
E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00@0039oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000_Ool005=oo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<0
05YFFUH01EYF1`000eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`800003
FUH005YF009JEP03001JEUYF00=JEPH000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@000=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00Dgoo0P0000=JEP00FUH00UYF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00003FUH2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH01000
FUIJEUYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00@005YF001JEP8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPP000=JEP03001JEUYF00D00006FUH005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000H000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPd000=JEP03001JEUYF00EJEPP0009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH2000]Ool005Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0000002eoo`00E7oo00D005YFFUIJ
EP0000EJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00@7oo5@000eYF00@005YFFUIJ
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00?7oo100000=JEP00FUH01eYF
00<005YFFUH01UYF00D005YF000005YF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00=Woo1P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000bOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000^Ool0035oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0
0004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUHF000_Ool002moo`800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPP000EJEP03001JEUYF00EJEP04001JEUYFFUH5000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00L0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF008000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUH0
00030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004
FUH00`00FUIJEP04FUH40006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF2@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00005FUH01000FUH0000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20005FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH4
00000eYF000000020005FUH00`00FUIJEP07FUH00`00FUIJEP04FUHB000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
10001eYF00@005YF000000=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH015YF0`00
0UYF0`000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEPT000=JEP03001oogoo02]oo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPh00005FUH005YF001JEP020006FUH00`00FUIJEP04FUH70009FUH00`00
FUIJEP0400000eYF0000000200000eYF001JEP04FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF0P0000=JEP000000;7oo000/Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00UYF0P0000AJEP00000000MJ
EP03001JEUYF00@000MJEP03001JEUYF00AJEPD0009JEP<000EJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00AJEP03001JEUYF009JEP@002ao
o`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01000
1EYF0P0000=JEP00FUH01UYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000/Ool002aoo`800003FUH0
05YF009JEP04001JEUYFFUH600000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00`000eYF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP040004FUH60003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH2000]Ool002eoo`03001JEP0000=JEP@000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF00003`000UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF100025YF00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<007ooOol0;7oo000]Ool00`00
FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF1@000UYF00@005YF
FUIJEPT00003FUH005YF00EJEPL000AJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000
FUIJEUYF0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00P00;goo000]Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH000060004FUH01@00FUIJEP00FUH00`001EYF00D005YF001JEP0000=JEP@00003FUH00000
00<000AJEP03001JEUYF00IJEP04001JEP00000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`00<Goo000]Ool01@00FUH005YF0000
1EYF00<005YFFUH015YF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P0000=JEP0000004000
1EYF1@001EYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP04001J
EP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000eOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH0
0`00FUIJEP05FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH000000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF0`00>Goo000]Ool01@00FUIJEUYF00001EYF00<005YF00000`001EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF4`00<Goo000]Ool01@00FUIJEUYF00000eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJ
EPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Woo0P0000=JEP00
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH05@002EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0031o
o`@000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYF000^Ool002moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000AJEQ400003FUH005YF00QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002ioo`03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ000003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEQ<000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001o
ogoo02]oo`00;Goo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01@000eYF00<005YFFUH01EYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP04FUH7000@Ool6000]Ool002ao
o`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001J
EUYF00AJEP06001JEUYF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF0`000eYF
00<005YFFUH01UYF00<005YFFUH0100057oo0`000UYF00@005YFFUH002eoo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP<000IJEP03001JEUYF00AJEP@001Aoo`@00003FUH0
05YF00=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00@0
00AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH200000eYF001JEP06FUH00`00FUIJEP04000EOol30005
FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP@000IJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP04FUH5000FOol200000eYF001J
EP06FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YF
FUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEP800004FUH005YFFUH2
000BOol30003FUH00`00FUIJEP05FUH01000FUH00000<7oo000]Ool00`00FUH00005FUH01000FUH0
000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF6@001UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00@005YF000000=JEP03001JEUYF008000aoo`H0
00IJEP03001JEUYF00AJEP<0039oo`00;Goo00@005YFFUH000=JEP@00003FUH00000008000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPX00003FUH005YF00EJEP03001JEUYF00EJ
EPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP04001J
EUYFFUH40004FUH00`00FUIJEP020003Ool90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000]Ool01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2P0000=JEP0000000P0000Ioo`00000005YF0006FUH00`00FUIJEP050008FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002
FUH01000FUH000000eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000003Moo`00;Woo0UYF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=J
EP00FUH01EYF0`000Woo0`000UYF00<005YF00001EYF10000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P0000=J
EP00FUH030000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00>Goo000^Ool0
1EYF001JEP00FUH00P001EYF00<005YFFUH01EYF1`002EYF00<005YFFUH010000goo0P0000=JEP00
FUH00UYF00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF1@000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?7oo000^Ool20000
15YF000000001eYF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@001Goo0P000eYF00P005YF
FUIJEP00FUH005YF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF0P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00@7oo000^Ool30002FUH00`00FUIJ
EP05FUH00`00FUH000030008FUH00`00FUIJEP040007Ool30006FUH01@00FUIJEP00FUH00P000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000AJEP800003FUH0000000=JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@004Eoo`00;Woo0P0015YF00<005YFFUH00eYF0`000eYF
00<005YFFUH00UYF1`001goo100000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP80009JEP80009JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
009JEPL004Uoo`00;Goo00<005YF000015YF00<005YF00003P000goo0`000goo1@001EYF00<005YF
FUH015YF0`0000=oo`00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100015YF5000D7oo000]
Ool01000FUIJEP000eYF0P004Goo1`000UYF00<005YFFUH01UYF00@005YFFUIJEP8000Aoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP02
001FOol002eoo`05001JEUYF001JEP02000@Ool80004FUH00`00FUIJEP06FUH01000FUH000001Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00EJEP<005Qo
o`00;Woo00<005YF00004`000eYF1@001EYF00<005YFFUH015YF0`0027oo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00=JEP8005Yoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH0100037oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEP0000<005aoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0047oo00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001UYF0`00H7oo000^Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000FOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHD001HOol002moo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPH001aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP00008005Eoo`00<Goo500097oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00Jgoo0P0015YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF001EOol006eoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001J
EP000008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000E7oo001`Ool40008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH400000eYF001JEP05
FUHA0002FUH00`00Oomoo`1BOol007Aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00D000EJEP03001JEUYF00@000ioo`H005Aoo`00NWoo2@001UYF00<005YF
FUH02EYF00<005YFFUH015YF200000=JEP00FUH00eYF1`003goo0`000UYF00@005YFFUH005Aoo`00
Pgoo6P001eYF1P0057oo0P0000=JEP00FUH00eYF00<005YF0000E7oo002BOol200000eYF001JEP06
FUH00`00FUIJEP02FUH2000HOol20003FUH00`00FUIJEP02FUH2001EOol0091oo`8000=JEP03001J
EUYF00EJEP03001JEP00008001Moo`<000IJEP05001JEUYFFUH0001FOol008moo`8000EJEP03001J
EUYF00=JEP<001Ioo`@00003FUH005YF00IJEP04001JEP00001GOol008ioo`03001JEP0000EJEP03
001JEP0000<0019oo`L000EJEP03001JEUYF00AJEP<005Uoo`00SWoo00@005YFFUH000=JEP<000mo
o`L000AJEP03001JEUYF00IJEP04001JEUYFFUH2001LOol008ioo`05001JEUYF001JEP02000>Ool4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002?Ool00`00FUH0000A0006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol008moo`80009JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00Sgoo0P000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00Igoo002?Ool20003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001/Ool0091oo`80
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0071oo`00TWoo5000Mgoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59642 .73339 m .59084 .67751 L .55983 .67879 L p .707 .577 .707 r
F P
0 g
s
.59084 .67751 m .59642 .73339 L .62811 .72974 L p .707 .577 .707 r
F P
0 g
s
.62811 .72974 m .62253 .67386 L .59084 .67751 L p .707 .577 .707 r
F P
0 g
s
.62253 .67386 m .62811 .72974 L .65738 .72408 L p .707 .577 .707 r
F P
0 g
s
.65738 .72408 m .6518 .6682 L .62253 .67386 L p .707 .577 .707 r
F P
0 g
s
.5654 .73467 m .55983 .67879 L .53253 .67758 L p .707 .577 .707 r
F P
0 g
s
.55983 .67879 m .5654 .73467 L .59642 .73339 L p .707 .577 .707 r
F P
0 g
s
.6518 .6682 m .65738 .72408 L .68136 .71697 L p .707 .577 .707 r
F P
0 g
s
.68136 .71697 m .67578 .66109 L .6518 .6682 L p .707 .577 .707 r
F P
0 g
s
.53253 .67758 m .5381 .73346 L .5654 .73467 L p .707 .577 .707 r
F P
0 g
s
.60216 .79964 m .59133 .76317 L .56154 .77063 L p .707 .577 .707 r
F P
0 g
s
.59133 .76317 m .60216 .79964 L .63275 .79041 L p .707 .577 .707 r
F P
0 g
s
.63275 .79041 m .62193 .75394 L .59133 .76317 L p .707 .577 .707 r
F P
0 g
s
.5381 .73346 m .53253 .67758 L .51162 .674 L p .707 .577 .707 r
F P
0 g
s
.62193 .75394 m .63275 .79041 L .66114 .78033 L p .707 .577 .707 r
F P
0 g
s
.66114 .78033 m .65032 .74386 L .62193 .75394 L p .707 .577 .707 r
F P
0 g
s
.56154 .77063 m .57236 .8071 L .60216 .79964 L p .707 .577 .707 r
F P
0 g
s
.57236 .8071 m .56154 .77063 L .53546 .7756 L p .707 .577 .707 r
F P
0 g
s
.67578 .66109 m .68136 .71697 L .6977 .70909 L p .707 .577 .707 r
F P
0 g
s
.6977 .70909 m .69212 .65322 L .67578 .66109 L p .707 .577 .707 r
F P
0 g
s
.65032 .74386 m .66114 .78033 L .68456 .77038 L p .707 .577 .707 r
F P
0 g
s
.68456 .77038 m .67374 .7339 L .65032 .74386 L p .707 .577 .707 r
F P
0 g
s
.51162 .674 m .51719 .72988 L .5381 .73346 L p .707 .577 .707 r
F P
0 g
s
.53546 .7756 m .54628 .81208 L .57236 .8071 L p .707 .577 .707 r
F P
0 g
s
.59978 .86338 m .59419 .84519 L .56449 .85297 L p .707 .577 .707 r
F P
0 g
s
.59419 .84519 m .59978 .86338 L .63029 .85387 L p .707 .577 .707 r
F P
0 g
s
.63029 .85387 m .6247 .83567 L .59419 .84519 L p .707 .577 .707 r
F P
0 g
s
.6247 .83567 m .63029 .85387 L .65861 .84355 L p .707 .577 .707 r
F P
0 g
s
.65861 .84355 m .65302 .82536 L .6247 .83567 L p .707 .577 .707 r
F P
0 g
s
.56449 .85297 m .57009 .87117 L .59978 .86338 L p .707 .577 .707 r
F P
0 g
s
.51719 .72988 m .51162 .674 L .49914 .66839 L p .707 .577 .707 r
F P
0 g
s
.54628 .81208 m .53546 .7756 L .51565 .7776 L p .707 .577 .707 r
F P
0 g
s
.57009 .87117 m .56449 .85297 L .53851 .85827 L p .707 .577 .707 r
F P
0 g
s
.67374 .7339 m .68456 .77038 L .70071 .76152 L p .707 .577 .707 r
F P
0 g
s
.70071 .76152 m .68989 .72505 L .67374 .7339 L p .707 .577 .707 r
F P
0 g
s
.51565 .7776 m .52647 .81407 L .54628 .81208 L p .707 .577 .707 r
F P
0 g
s
.65302 .82536 m .65861 .84355 L .68199 .83345 L p .707 .577 .707 r
F P
0 g
s
.68199 .83345 m .6764 .81526 L .65302 .82536 L p .707 .577 .707 r
F P
0 g
s
.53851 .85827 m .54411 .87646 L .57009 .87117 L p .707 .577 .707 r
F P
0 g
s
.69212 .65322 m .6977 .70909 L .70481 .70123 L p .707 .577 .707 r
F P
0 g
s
.70481 .70123 m .69923 .64536 L .69212 .65322 L p .707 .577 .707 r
F P
0 g
s
.49914 .66839 m .50471 .72427 L .51719 .72988 L p .707 .577 .707 r
F P
0 g
s
.54411 .87646 m .53851 .85827 L .51879 .86055 L p .707 .577 .707 r
F P
0 g
s
.51879 .86055 m .52438 .87875 L .54411 .87646 L p .707 .577 .707 r
F P
0 g
s
.52647 .81407 m .51565 .7776 L .50404 .77642 L p .707 .577 .707 r
F P
0 g
s
.6764 .81526 m .68199 .83345 L .69813 .82455 L p .707 .577 .707 r
F P
0 g
s
.69813 .82455 m .69253 .80636 L .6764 .81526 L p .707 .577 .707 r
F P
0 g
s
.50471 .72427 m .49914 .66839 L .49631 .66131 L p .707 .577 .707 r
F P
0 g
s
.68989 .72505 m .70071 .76152 L .70802 .75464 L p .707 .577 .707 r
F P
0 g
s
.70802 .75464 m .69719 .71817 L .68989 .72505 L p .707 .577 .707 r
F P
0 g
s
.50404 .77642 m .51487 .81289 L .52647 .81407 L p .707 .577 .707 r
F P
0 g
s
.69923 .64536 m .70481 .70123 L .70198 .69416 L p .707 .577 .707 r
F P
0 g
s
.70198 .69416 m .69641 .63828 L .69923 .64536 L p .707 .577 .707 r
F P
0 g
s
.49631 .66131 m .50189 .71719 L .50471 .72427 L p .707 .577 .707 r
F P
0 g
s
.52438 .87875 m .51879 .86055 L .50725 .8596 L p .707 .577 .707 r
F P
0 g
s
.50725 .8596 m .51284 .8778 L .52438 .87875 L p .707 .577 .707 r
F P
0 g
s
.69253 .80636 m .69813 .82455 L .70544 .81772 L p .707 .577 .707 r
F P
0 g
s
.70544 .81772 m .69985 .79952 L .69253 .80636 L p .707 .577 .707 r
F P
0 g
s
.47783 .82164 m .49203 .32149 L .44804 .31755 L p .707 .577 .707 r
F P
0 g
s
.51487 .81289 m .50404 .77642 L .50178 .77218 L p .707 .577 .707 r
F P
0 g
s
.50189 .71719 m .49631 .66131 L .50342 .65345 L p .707 .577 .707 r
F P
0 g
s
.50178 .77218 m .5126 .80865 L .51487 .81289 L p .707 .577 .707 r
F P
0 g
s
.50342 .65345 m .509 .70933 L .50189 .71719 L p .707 .577 .707 r
F P
0 g
s
.5126 .80865 m .50178 .77218 L .50908 .7653 L p .707 .577 .707 r
F P
0 g
s
.509 .70933 m .50342 .65345 L .51977 .64558 L p .707 .577 .707 r
F P
0 g
s
.50908 .7653 m .5199 .80177 L .5126 .80865 L p .707 .577 .707 r
F P
0 g
s
.51977 .64558 m .52534 .70146 L .509 .70933 L p .707 .577 .707 r
F P
0 g
s
.5199 .80177 m .50908 .7653 L .52523 .75645 L p .707 .577 .707 r
F P
0 g
s
.52523 .75645 m .53606 .79292 L .5199 .80177 L p .707 .577 .707 r
F P
0 g
s
.49203 .32149 m .47783 .82164 L .52276 .82168 L p .707 .577 .707 r
F P
0 g
s
.52534 .70146 m .51977 .64558 L .54375 .63847 L p .707 .577 .707 r
F P
0 g
s
.54375 .63847 m .54932 .69435 L .52534 .70146 L p .707 .577 .707 r
F P
0 g
s
.52276 .82168 m .53696 .32153 L .49203 .32149 L p .707 .577 .707 r
F P
0 g
s
.54932 .69435 m .54375 .63847 L .57301 .63281 L p .707 .577 .707 r
F P
0 g
s
.53606 .79292 m .52523 .75645 L .54865 .74649 L p .707 .577 .707 r
F P
0 g
s
.57301 .63281 m .57859 .68869 L .54932 .69435 L p .707 .577 .707 r
F P
0 g
s
.54865 .74649 m .55947 .78297 L .53606 .79292 L p .707 .577 .707 r
F P
0 g
s
.55947 .78297 m .54865 .74649 L .57705 .73641 L p .707 .577 .707 r
F P
0 g
s
.57705 .73641 m .58787 .77288 L .55947 .78297 L p .707 .577 .707 r
F P
0 g
s
.53696 .32153 m .52276 .82168 L .56423 .81781 L p .707 .577 .707 r
F P
0 g
s
.56423 .81781 m .57843 .31766 L .53696 .32153 L p .707 .577 .707 r
F P
0 g
s
.69719 .71817 m .70802 .75464 L .70575 .75041 L p .707 .577 .707 r
F P
0 g
s
.70575 .75041 m .69493 .71393 L .69719 .71817 L p .707 .577 .707 r
F P
0 g
s
.43384 .8177 m .44804 .31755 L .4093 .31009 L p .707 .577 .707 r
F P
0 g
s
.44804 .31755 m .43384 .8177 L .47783 .82164 L p .707 .577 .707 r
F P
0 g
s
.69641 .63828 m .70198 .69416 L .68951 .68855 L p .707 .577 .707 r
F P
0 g
s
.68951 .68855 m .68393 .63267 L .69641 .63828 L p .707 .577 .707 r
F P
0 g
s
.57859 .68869 m .57301 .63281 L .60471 .62916 L p .707 .577 .707 r
F P
0 g
s
.60471 .62916 m .61028 .68504 L .57859 .68869 L p .707 .577 .707 r
F P
0 g
s
.58787 .77288 m .57705 .73641 L .60764 .72718 L p .707 .577 .707 r
F P
0 g
s
.60764 .72718 m .61846 .76366 L .58787 .77288 L p .707 .577 .707 r
F P
0 g
s
.57843 .31766 m .56423 .81781 L .59818 .81041 L p .707 .577 .707 r
F P
0 g
s
.59818 .81041 m .61238 .31026 L .57843 .31766 L p .707 .577 .707 r
F P
0 g
s
.51284 .8778 m .50725 .8596 L .50503 .85551 L p .707 .577 .707 r
F P
0 g
s
.50503 .85551 m .51063 .87371 L .51284 .8778 L p .707 .577 .707 r
F P
0 g
s
.69985 .79952 m .70544 .81772 L .70322 .81363 L p .707 .577 .707 r
F P
0 g
s
.70322 .81363 m .69763 .79543 L .69985 .79952 L p .707 .577 .707 r
F P
0 g
s
.3951 .81024 m .4093 .31009 L .37959 .29984 L p .707 .577 .707 r
F P
0 g
s
.4093 .31009 m .3951 .81024 L .43384 .8177 L p .707 .577 .707 r
F P
0 g
s
.25341 .72222 m .24783 .66634 L .21682 .66762 L p .707 .577 .707 r
F P
0 g
s
.24783 .66634 m .25341 .72222 L .2851 .71857 L p .707 .577 .707 r
F P
0 g
s
.2851 .71857 m .27952 .66269 L .24783 .66634 L p .707 .577 .707 r
F P
0 g
s
.27952 .66269 m .2851 .71857 L .31437 .71291 L p .707 .577 .707 r
F P
0 g
s
.31437 .71291 m .30879 .65703 L .27952 .66269 L p .707 .577 .707 r
F P
0 g
s
.69493 .71393 m .70575 .75041 L .69415 .74923 L p .707 .577 .707 r
F P
0 g
s
.69415 .74923 m .68332 .71275 L .69493 .71393 L p .707 .577 .707 r
F P
0 g
s
.22239 .7235 m .21682 .66762 L .18952 .66641 L p .707 .577 .707 r
F P
0 g
s
.21682 .66762 m .22239 .7235 L .25341 .72222 L p .707 .577 .707 r
F P
0 g
s
.68393 .63267 m .68951 .68855 L .66859 .68497 L p .707 .577 .707 r
F P
0 g
s
.66859 .68497 m .66302 .62909 L .68393 .63267 L p .707 .577 .707 r
F P
0 g
s
.30879 .65703 m .31437 .71291 L .33835 .7058 L p .707 .577 .707 r
F P
0 g
s
.33835 .7058 m .33277 .64992 L .30879 .65703 L p .707 .577 .707 r
F P
0 g
s
.63572 .62788 m .6413 .68376 L .61028 .68504 L p .707 .577 .707 r
F P
0 g
s
.61028 .68504 m .60471 .62916 L .63572 .62788 L p .707 .577 .707 r
F P
0 g
s
.63743 .71972 m .64826 .75619 L .61846 .76366 L p .707 .577 .707 r
F P
0 g
s
.61846 .76366 m .60764 .72718 L .63743 .71972 L p .707 .577 .707 r
F P
0 g
s
.61238 .31026 m .59818 .81041 L .62129 .80021 L p .707 .577 .707 r
F P
0 g
s
.62129 .80021 m .63549 .30006 L .61238 .31026 L p .707 .577 .707 r
F P
0 g
s
.25915 .76438 m .24833 .72791 L .21853 .73537 L p .707 .577 .707 r
F P
0 g
s
.24833 .72791 m .25915 .76438 L .28974 .75515 L p .707 .577 .707 r
F P
0 g
s
.28974 .75515 m .27892 .71868 L .24833 .72791 L p .707 .577 .707 r
F P
0 g
s
.27892 .71868 m .28974 .75515 L .31814 .74507 L p .707 .577 .707 r
F P
0 g
s
.31814 .74507 m .30731 .7086 L .27892 .71868 L p .707 .577 .707 r
F P
0 g
s
.51063 .87371 m .50503 .85551 L .51235 .84868 L p .707 .577 .707 r
F P
0 g
s
.18952 .66641 m .1951 .72229 L .22239 .7235 L p .707 .577 .707 r
F P
0 g
s
.51235 .84868 m .51794 .86688 L .51063 .87371 L p .707 .577 .707 r
F P
0 g
s
.21853 .73537 m .22935 .77184 L .25915 .76438 L p .707 .577 .707 r
F P
0 g
s
.1951 .72229 m .18952 .66641 L .16861 .66283 L p .707 .577 .707 r
F P
0 g
s
.69763 .79543 m .70322 .81363 L .69169 .81268 L p .707 .577 .707 r
F P
0 g
s
.69169 .81268 m .68609 .79449 L .69763 .79543 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21853 .73537 L .21469 .7361 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21469 .7361 L .22413 .76738 L .707 .577 .707 r
F
.22566 .77248 m .22148 .77357 L p .22644 .77503 L F P
0 g
s
.19245 .74034 m .20327 .77682 L .22935 .77184 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .25118 .76579 L .22566 .77248 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .22566 .77248 L .22644 .77503 L .707 .577 .707 r
F
.21469 .7361 m .19245 .74034 L p .22413 .76738 L F P
0 g
s
.25118 .76579 m .25678 .78398 L .28728 .77447 L p .707 .577 .707 r
F P
0 g
s
.28728 .77447 m .28169 .75627 L .25118 .76579 L p .707 .577 .707 r
F P
0 g
s
.28169 .75627 m .28728 .77447 L .31561 .76416 L p .707 .577 .707 r
F P
0 g
s
.31561 .76416 m .31001 .74596 L .28169 .75627 L p .707 .577 .707 r
F P
0 g
s
.33277 .64992 m .33835 .7058 L .35469 .69793 L p .707 .577 .707 r
F P
0 g
s
.34688 .68979 m .35771 .72626 L .35957 .72451 L p .707 .577 .707 r
F P
0 g
s
.35957 .72451 m .36501 .71938 L p .35864 .70899 L .707 .577 .707 r
F P
0 g
s
.35864 .70899 m .34688 .68979 L .35957 .72451 L .707 .577 .707 r
F
.36182 .28781 m .35774 .27517 L p .35152 .59032 L F P
0 g
s
.35469 .69793 m .34911 .64205 L .33277 .64992 L p .707 .577 .707 r
F P
0 g
s
.33073 .69864 m .34155 .73512 L .35771 .72626 L p .707 .577 .707 r
F P
0 g
s
.35771 .72626 m .34688 .68979 L .33073 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .7086 m .31814 .74507 L .34155 .73512 L p .707 .577 .707 r
F P
0 g
s
.33339 .73586 m .33898 .75405 L .35512 .74515 L p .707 .577 .707 r
F P
0 g
s
.34155 .73512 m .33073 .69864 L .30731 .7086 L p .707 .577 .707 r
F P
0 g
s
.35512 .74515 m .34952 .72696 L .33339 .73586 L p .707 .577 .707 r
F P
0 g
s
.34911 .64205 m .35469 .69793 L .3618 .69007 L p .707 .577 .707 r
F P
0 g
s
.3618 .69007 m .35622 .63419 L .34911 .64205 L p .707 .577 .707 r
F P
0 g
s
.36501 .71938 m .35418 .68291 L .34688 .68979 L p .707 .577 .707 r
F P
0 g
s
.3534 .62711 m .35589 .65202 L p .3465 .67738 L .707 .577 .707 r
F P
0 g
s
.35589 .65202 m .35898 .68299 L .35409 .6808 L p .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .35418 .68291 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.36274 .71515 m .3619 .71231 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.3619 .71231 m .35192 .67867 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .36274 .71515 L .35114 .71397 L p .707 .577 .707 r
F P
0 g
s
.35114 .71397 m .34032 .67749 L .35192 .67867 L p .707 .577 .707 r
F P
0 g
s
.35409 .6808 m .35178 .67976 L p .35589 .65202 L .707 .577 .707 r
F P
0 g
s
.35178 .67976 m .3465 .67738 L p .34897 .67071 L .707 .577 .707 r
F P
0 g
s
.34897 .67071 m .35589 .65202 L .35178 .67976 L .707 .577 .707 r
F
.3465 .67738 m .34092 .62151 L .3534 .62711 L p F P
0 g
s
.34952 .72696 m .35512 .74515 L .36243 .73832 L p .707 .577 .707 r
F P
0 g
s
.36243 .73832 m .35684 .72013 L .34952 .72696 L p .707 .577 .707 r
F P
0 g
s
.35462 .71604 m .36021 .73423 L .35174 .73353 L p .707 .577 .707 r
F P
0 g
s
.35174 .73353 m .34868 .73328 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.35351 .71926 m .35462 .71604 L .35174 .73353 L .707 .577 .707 r
F
.34868 .73328 m .34308 .71509 L .35392 .71598 L p F P
0 g
s
.35392 .71598 m .35462 .71604 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.34868 .73328 m .35392 .71598 L .35351 .71926 L .707 .577 .707 r
F
.3478 .78171 m .34841 .76035 L p .34772 .78298 L F P
0 g
s
.34032 .67749 m .35114 .71397 L .33133 .71596 L p .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .35268 .60969 L p .34836 .76074 L .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .34836 .76074 L .34772 .78298 L .707 .577 .707 r
F
.34812 .76263 m .35268 .60969 L .35152 .59032 L F
.34772 .78298 m .34836 .76074 L .34812 .76263 L F
.34836 .76074 m .35268 .60969 L .34812 .76263 L F
.34762 .78796 m .3478 .78171 L p .34772 .78298 L F P
0 g
s
.35268 .60969 m .36182 .28781 L p .35152 .59032 L .707 .577 .707 r
F P
0 g
s
.35418 .68291 m .36501 .71938 L .36274 .71515 L p .707 .577 .707 r
F P
0 g
s
.36539 .79999 m .37959 .29984 L .36182 .28781 L p .707 .577 .707 r
F P
0 g
s
.37959 .29984 m .36539 .79999 L .3951 .81024 L p .707 .577 .707 r
F P
0 g
s
.22148 .77357 m .22708 .79177 L .25678 .78398 L p .707 .577 .707 r
F P
0 g
s
.68332 .71275 m .69415 .74923 L .67434 .75122 L p .707 .577 .707 r
F P
0 g
s
.67434 .75122 m .66351 .71475 L .68332 .71275 L p .707 .577 .707 r
F P
0 g
s
.66302 .62909 m .66859 .68497 L .6413 .68376 L p .707 .577 .707 r
F P
0 g
s
.6413 .68376 m .63572 .62788 L .66302 .62909 L p .707 .577 .707 r
F P
0 g
s
.22708 .79177 m .22148 .77357 L .1955 .77887 L p .707 .577 .707 r
F P
0 g
s
.16861 .66283 m .17418 .71871 L .1951 .72229 L p .707 .577 .707 r
F P
0 g
s
.31001 .74596 m .31561 .76416 L .33898 .75405 L p .707 .577 .707 r
F P
0 g
s
.33898 .75405 m .33339 .73586 L .31001 .74596 L p .707 .577 .707 r
F P
0 g
s
.1955 .77887 m .2011 .79706 L .22708 .79177 L p .707 .577 .707 r
F P
0 g
s
.20327 .77682 m .19245 .74034 L .17264 .74234 L p .707 .577 .707 r
F P
0 g
s
.17418 .71871 m .16861 .66283 L .15613 .65723 L p .707 .577 .707 r
F P
0 g
s
.17264 .74234 m .18346 .77881 L .20327 .77682 L p .707 .577 .707 r
F P
0 g
s
.51794 .86688 m .51235 .84868 L .52848 .83978 L p .707 .577 .707 r
F P
0 g
s
.63549 .30006 m .62129 .80021 L .63129 .7882 L p .707 .577 .707 r
F P
0 g
s
.63129 .7882 m .64549 .28805 L .63549 .30006 L p .707 .577 .707 r
F P
0 g
s
.52848 .83978 m .53408 .85798 L .51794 .86688 L p .707 .577 .707 r
F P
0 g
s
.2011 .79706 m .1955 .77887 L .17578 .78115 L p .707 .577 .707 r
F P
0 g
s
.68609 .79449 m .69169 .81268 L .67196 .81496 L p .707 .577 .707 r
F P
0 g
s
.67196 .81496 m .66637 .79677 L .68609 .79449 L p .707 .577 .707 r
F P
0 g
s
.17578 .78115 m .18137 .79935 L .2011 .79706 L p .707 .577 .707 r
F P
0 g
s
.66351 .71475 m .67434 .75122 L .64826 .75619 L p .707 .577 .707 r
F P
0 g
s
.64826 .75619 m .63743 .71972 L .66351 .71475 L p .707 .577 .707 r
F P
0 g
s
.15613 .65723 m .1617 .7131 L .17418 .71871 L p .707 .577 .707 r
F P
0 g
s
.35622 .63419 m .3618 .69007 L .35898 .68299 L p .707 .577 .707 r
F P
0 g
s
.35898 .68299 m .3534 .62711 L .35622 .63419 L p .707 .577 .707 r
F P
0 g
s
.35684 .72013 m .36243 .73832 L .36021 .73423 L p .707 .577 .707 r
F P
0 g
s
.36021 .73423 m .35462 .71604 L .35684 .72013 L p .707 .577 .707 r
F P
0 g
s
.36182 .28781 m .34762 .78796 L .36539 .79999 L p .707 .577 .707 r
F P
0 g
s
.18346 .77881 m .17264 .74234 L .16103 .74116 L p .707 .577 .707 r
F P
0 g
s
.16103 .74116 m .17186 .77763 L .18346 .77881 L p .707 .577 .707 r
F P
0 g
s
.53408 .85798 m .52848 .83978 L .55186 .82968 L p .707 .577 .707 r
F P
0 g
s
.1617 .7131 m .15613 .65723 L .15331 .65015 L p .707 .577 .707 r
F P
0 g
s
.18137 .79935 m .17578 .78115 L .16424 .7802 L p .707 .577 .707 r
F P
0 g
s
.55186 .82968 m .55745 .84787 L .53408 .85798 L p .707 .577 .707 r
F P
0 g
s
.66637 .79677 m .67196 .81496 L .64598 .82026 L p .707 .577 .707 r
F P
0 g
s
.64598 .82026 m .64039 .80206 L .66637 .79677 L p .707 .577 .707 r
F P
0 g
s
.16424 .7802 m .16984 .7984 L .18137 .79935 L p .707 .577 .707 r
F P
0 g
s
.15331 .65015 m .15888 .70602 L .1617 .7131 L p .707 .577 .707 r
F P
0 g
s
.64549 .28805 m .63129 .7882 L .62721 .77556 L p .707 .577 .707 r
F P
0 g
s
.62721 .77556 m .64141 .27541 L .64549 .28805 L p .707 .577 .707 r
F P
0 g
s
.55745 .84787 m .55186 .82968 L .58019 .81936 L p .707 .577 .707 r
F P
0 g
s
.64039 .80206 m .64598 .82026 L .61628 .82804 L p .707 .577 .707 r
F P
0 g
s
.61628 .82804 m .61069 .80985 L .64039 .80206 L p .707 .577 .707 r
F P
0 g
s
.58019 .81936 m .58578 .83756 L .55745 .84787 L p .707 .577 .707 r
F P
0 g
s
.17186 .77763 m .16103 .74116 L .15877 .73692 L p .707 .577 .707 r
F P
0 g
s
.15877 .73692 m .16959 .77339 L .17186 .77763 L p .707 .577 .707 r
F P
0 g
s
.58578 .83756 m .58019 .81936 L .61069 .80985 L p .707 .577 .707 r
F P
0 g
s
.61069 .80985 m .61628 .82804 L .58578 .83756 L p .707 .577 .707 r
F P
0 g
s
.16984 .7984 m .16424 .7802 L .16202 .77611 L p .707 .577 .707 r
F P
0 g
s
.15888 .70602 m .15331 .65015 L .16041 .64229 L p .707 .577 .707 r
F P
0 g
s
.16202 .77611 m .16762 .79431 L .16984 .7984 L p .707 .577 .707 r
F P
0 g
s
.34092 .62151 m .3465 .67738 L .32559 .6738 L p .707 .577 .707 r
F P
0 g
s
.34308 .71509 m .34868 .73328 L .32895 .73557 L p .707 .577 .707 r
F P
0 g
s
.35774 .27517 m .34354 .77532 L .34762 .78796 L p .707 .577 .707 r
F P
0 g
s
.34354 .77532 m .35774 .27517 L .36774 .26316 L p .707 .577 .707 r
F P
0 g
s
.16041 .64229 m .16599 .69816 L .15888 .70602 L p .707 .577 .707 r
F P
0 g
s
.16959 .77339 m .15877 .73692 L .16607 .73004 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16607 .73004 m .1769 .76651 L .16959 .77339 L p .707 .577 .707 r
F P
0 g
s
.64141 .27541 m .62721 .77556 L .60944 .76353 L p .707 .577 .707 r
F P
0 g
s
.60944 .76353 m .62364 .26338 L .64141 .27541 L p .707 .577 .707 r
F P
0 g
s
.16599 .69816 m .16041 .64229 L .17676 .63441 L p .707 .577 .707 r
F P
0 g
s
.16762 .79431 m .16202 .77611 L .16934 .76928 L p .707 .577 .707 r
F P
0 g
s
.16934 .76928 m .17493 .78748 L .16762 .79431 L p .707 .577 .707 r
F P
0 g
s
.32559 .6738 m .32001 .61792 L .34092 .62151 L p .707 .577 .707 r
F P
0 g
s
.17676 .63441 m .18233 .69029 L .16599 .69816 L p .707 .577 .707 r
F P
0 g
s
.35354 .76331 m .36774 .26316 L .39085 .25296 L p .707 .577 .707 r
F P
0 g
s
.36774 .26316 m .35354 .76331 L .34354 .77532 L p .707 .577 .707 r
F P
0 g
s
.1769 .76651 m .16607 .73004 L .18222 .72119 L p .707 .577 .707 r
F P
0 g
s
.18233 .69029 m .17676 .63441 L .20074 .6273 L p .707 .577 .707 r
F P
0 g
s
.33133 .71596 m .3205 .67949 L .34032 .67749 L p .707 .577 .707 r
F P
0 g
s
.18222 .72119 m .19305 .75766 L .1769 .76651 L p .707 .577 .707 r
F P
0 g
s
.17493 .78748 m .16934 .76928 L .18548 .76038 L p .707 .577 .707 r
F P
0 g
s
.18548 .76038 m .19107 .77858 L .17493 .78748 L p .707 .577 .707 r
F P
0 g
s
.32001 .61792 m .32559 .6738 L .29829 .67259 L p .707 .577 .707 r
F P
0 g
s
.29829 .67259 m .29271 .61671 L .32001 .61792 L p .707 .577 .707 r
F P
0 g
s
.32895 .73557 m .32336 .71737 L .34308 .71509 L p .707 .577 .707 r
F P
0 g
s
.62364 .26338 m .60944 .76353 L .57973 .75328 L p .707 .577 .707 r
F P
0 g
s
.57973 .75328 m .59393 .25313 L .62364 .26338 L p .707 .577 .707 r
F P
0 g
s
.20074 .6273 m .20631 .68318 L .18233 .69029 L p .707 .577 .707 r
F P
0 g
s
.20631 .68318 m .20074 .6273 L .23001 .62164 L p .707 .577 .707 r
F P
0 g
s
.19305 .75766 m .18222 .72119 L .20564 .71123 L p .707 .577 .707 r
F P
0 g
s
.29271 .61671 m .29829 .67259 L .26727 .67387 L p .707 .577 .707 r
F P
0 g
s
.26727 .67387 m .2617 .618 L .29271 .61671 L p .707 .577 .707 r
F P
0 g
s
.39085 .25296 m .37665 .75311 L .35354 .76331 L p .707 .577 .707 r
F P
0 g
s
.37665 .75311 m .39085 .25296 L .4248 .24556 L p .707 .577 .707 r
F P
0 g
s
.32336 .71737 m .32895 .73557 L .30297 .74086 L p .707 .577 .707 r
F P
0 g
s
.30105 .72198 m .27545 .7284 L p .29165 .69089 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .29738 .72266 L .30103 .72192 L p .707 .577 .707 r
F P
0 g
s
.30103 .72192 m .32336 .71737 L p .30578 .73762 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .30103 .72192 L .30578 .73762 L .707 .577 .707 r
F
.29442 .68446 m .30525 .72093 L .30105 .72198 L p F P
0 g
s
.29165 .69089 m .29442 .68446 L .30105 .72198 L .707 .577 .707 r
F
.3205 .67949 m .33133 .71596 L .30525 .72093 L p F P
0 g
s
.30525 .72093 m .29442 .68446 L .3205 .67949 L p .707 .577 .707 r
F P
0 g
s
.73362 .64135 m .72804 .58547 L .69703 .58675 L p .707 .577 .707 r
F P
0 g
s
.72804 .58547 m .73362 .64135 L .76531 .6377 L p .707 .577 .707 r
F P
0 g
s
.76531 .6377 m .75974 .58182 L .72804 .58547 L p .707 .577 .707 r
F P
0 g
s
.20564 .71123 m .21647 .74771 L .19305 .75766 L p .707 .577 .707 r
F P
0 g
s
.75974 .58182 m .76531 .6377 L .79458 .63204 L p .707 .577 .707 r
F P
0 g
s
.79458 .63204 m .789 .57616 L .75974 .58182 L p .707 .577 .707 r
F P
0 g
s
.23558 .67752 m .23001 .62164 L .2617 .618 L p .707 .577 .707 r
F P
0 g
s
.23001 .62164 m .23558 .67752 L .20631 .68318 L p .707 .577 .707 r
F P
0 g
s
.19107 .77858 m .18548 .76038 L .20885 .75028 L p .707 .577 .707 r
F P
0 g
s
.2617 .618 m .26727 .67387 L .23558 .67752 L p .707 .577 .707 r
F P
0 g
s
.70261 .64263 m .69703 .58675 L .66973 .58554 L p .707 .577 .707 r
F P
0 g
s
.69703 .58675 m .70261 .64263 L .73362 .64135 L p .707 .577 .707 r
F P
0 g
s
.20885 .75028 m .21444 .76847 L .19107 .77858 L p .707 .577 .707 r
F P
0 g
s
.789 .57616 m .79458 .63204 L .81856 .62493 L p .707 .577 .707 r
F P
0 g
s
.81856 .62493 m .81298 .56905 L .789 .57616 L p .707 .577 .707 r
F P
0 g
s
.21647 .74771 m .20564 .71123 L .23404 .70115 L p .707 .577 .707 r
F P
0 g
s
.27545 .7284 m .26463 .69192 L .29442 .68446 L p .707 .577 .707 r
F P
0 g
s
.59393 .25313 m .57973 .75328 L .54099 .74582 L p .707 .577 .707 r
F P
0 g
s
.54099 .74582 m .55519 .24567 L .59393 .25313 L p .707 .577 .707 r
F P
0 g
s
.23404 .70115 m .24486 .73762 L .21647 .74771 L p .707 .577 .707 r
F P
0 g
s
.66973 .58554 m .67531 .64142 L .70261 .64263 L p .707 .577 .707 r
F P
0 g
s
.73936 .7076 m .72854 .67113 L .69874 .67859 L p .707 .577 .707 r
F P
0 g
s
.72854 .67113 m .73936 .7076 L .76995 .69838 L p .707 .577 .707 r
F P
0 g
s
.76995 .69838 m .75913 .6619 L .72854 .67113 L p .707 .577 .707 r
F P
0 g
s
.67531 .64142 m .66973 .58554 L .64882 .58196 L p .707 .577 .707 r
F P
0 g
s
.21444 .76847 m .20885 .75028 L .23718 .73997 L p .707 .577 .707 r
F P
0 g
s
.75913 .6619 m .76995 .69838 L .79835 .68829 L p .707 .577 .707 r
F P
0 g
s
.79835 .68829 m .78753 .65182 L .75913 .6619 L p .707 .577 .707 r
F P
0 g
s
.24486 .73762 m .23404 .70115 L .26463 .69192 L p .707 .577 .707 r
F P
0 g
s
.26463 .69192 m .27545 .7284 L .24486 .73762 L p .707 .577 .707 r
F P
0 g
s
.29738 .72266 m .30297 .74086 L .27327 .74865 L p .707 .577 .707 r
F P
0 g
s
.27327 .74865 m .26768 .73045 L .29738 .72266 L p .707 .577 .707 r
F P
0 g
s
.23718 .73997 m .24277 .75816 L .21444 .76847 L p .707 .577 .707 r
F P
0 g
s
.4106 .74571 m .4248 .24556 L .46627 .24169 L p .707 .577 .707 r
F P
0 g
s
.4248 .24556 m .4106 .74571 L .37665 .75311 L p .707 .577 .707 r
F P
0 g
s
.69874 .67859 m .70957 .71507 L .73936 .7076 L p .707 .577 .707 r
F P
0 g
s
.70957 .71507 m .69874 .67859 L .67266 .68356 L p .707 .577 .707 r
F P
0 g
s
.81298 .56905 m .81856 .62493 L .8349 .61706 L p .707 .577 .707 r
F P
0 g
s
.8349 .61706 m .82933 .56118 L .81298 .56905 L p .707 .577 .707 r
F P
0 g
s
.24277 .75816 m .23718 .73997 L .26768 .73045 L p .707 .577 .707 r
F P
0 g
s
.78753 .65182 m .79835 .68829 L .82177 .67834 L p .707 .577 .707 r
F P
0 g
s
.82177 .67834 m .81095 .64186 L .78753 .65182 L p .707 .577 .707 r
F P
0 g
s
.26768 .73045 m .27327 .74865 L .24277 .75816 L p .707 .577 .707 r
F P
0 g
s
.64882 .58196 m .6544 .63784 L .67531 .64142 L p .707 .577 .707 r
F P
0 g
s
.67266 .68356 m .68349 .72004 L .70957 .71507 L p .707 .577 .707 r
F P
0 g
s
.55519 .24567 m .54099 .74582 L .497 .74188 L p .707 .577 .707 r
F P
0 g
s
.497 .74188 m .5112 .24173 L .55519 .24567 L p .707 .577 .707 r
F P
0 g
s
.73699 .77134 m .7314 .75315 L .7017 .76094 L p .707 .577 .707 r
F P
0 g
s
.7314 .75315 m .73699 .77134 L .76749 .76183 L p .707 .577 .707 r
F P
0 g
s
.76749 .76183 m .7619 .74363 L .7314 .75315 L p .707 .577 .707 r
F P
0 g
s
.45369 .68474 m .46627 .24169 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .45207 .74184 L .4106 .74571 L p .707 .577 .707 r
F P
0 g
s
.38503 .5743 m .39061 .63018 L .4223 .62653 L p .707 .577 .707 r
F P
0 g
s
.41612 .62664 m .42261 .64852 L p .45534 .65303 L .707 .577 .707 r
F P
0 g
s
.42261 .64852 m .42694 .66312 L .43322 .66089 L p .707 .577 .707 r
F P
0 g
s
.43322 .66089 m .45534 .65303 L p .42261 .64852 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .5112 .24173 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.45207 .74184 m .45369 .68474 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.7619 .74363 m .76749 .76183 L .79582 .75152 L p .707 .577 .707 r
F P
0 g
s
.79582 .75152 m .79023 .73332 L .7619 .74363 L p .707 .577 .707 r
F P
0 g
s
.7017 .76094 m .70729 .77913 L .73699 .77134 L p .707 .577 .707 r
F P
0 g
s
.6544 .63784 m .64882 .58196 L .63634 .57635 L p .707 .577 .707 r
F P
0 g
s
.5112 .24173 m .497 .74188 L .45207 .74184 L p .707 .577 .707 r
F P
0 g
s
.68349 .72004 m .67266 .68356 L .65285 .68556 L p .707 .577 .707 r
F P
0 g
s
.70729 .77913 m .7017 .76094 L .67572 .76623 L p .707 .577 .707 r
F P
0 g
s
.81095 .64186 m .82177 .67834 L .83792 .66949 L p .707 .577 .707 r
F P
0 g
s
.83792 .66949 m .8271 .63301 L .81095 .64186 L p .707 .577 .707 r
F P
0 g
s
.65285 .68556 m .66368 .72203 L .68349 .72004 L p .707 .577 .707 r
F P
0 g
s
.79023 .73332 m .79582 .75152 L .81919 .74141 L p .707 .577 .707 r
F P
0 g
s
.81919 .74141 m .8136 .72322 L .79023 .73332 L p .707 .577 .707 r
F P
0 g
s
.67572 .76623 m .68131 .78442 L .70729 .77913 L p .707 .577 .707 r
F P
0 g
s
.82933 .56118 m .8349 .61706 L .84201 .6092 L p .707 .577 .707 r
F P
0 g
s
.84201 .6092 m .83644 .55332 L .82933 .56118 L p .707 .577 .707 r
F P
0 g
s
.63634 .57635 m .64192 .63223 L .6544 .63784 L p .707 .577 .707 r
F P
0 g
s
.68131 .78442 m .67572 .76623 L .65599 .76851 L p .707 .577 .707 r
F P
0 g
s
.65599 .76851 m .66158 .78671 L .68131 .78442 L p .707 .577 .707 r
F P
0 g
s
.66368 .72203 m .65285 .68556 L .64125 .68438 L p .707 .577 .707 r
F P
0 g
s
.8136 .72322 m .81919 .74141 L .83533 .73251 L p .707 .577 .707 r
F P
0 g
s
.83533 .73251 m .82974 .71432 L .8136 .72322 L p .707 .577 .707 r
F P
0 g
s
.64192 .63223 m .63634 .57635 L .63352 .56927 L p .707 .577 .707 r
F P
0 g
s
.8271 .63301 m .83792 .66949 L .84522 .6626 L p .707 .577 .707 r
F P
0 g
s
.84522 .6626 m .8344 .62613 L .8271 .63301 L p .707 .577 .707 r
F P
0 g
s
.64125 .68438 m .65207 .72085 L .66368 .72203 L p .707 .577 .707 r
F P
0 g
s
.83644 .55332 m .84201 .6092 L .83919 .60212 L p .707 .577 .707 r
F P
0 g
s
.83919 .60212 m .83361 .54624 L .83644 .55332 L p .707 .577 .707 r
F P
0 g
s
.63352 .56927 m .63909 .62515 L .64192 .63223 L p .707 .577 .707 r
F P
0 g
s
.66158 .78671 m .65599 .76851 L .64445 .76756 L p .707 .577 .707 r
F P
0 g
s
.64445 .76756 m .65005 .78576 L .66158 .78671 L p .707 .577 .707 r
F P
0 g
s
.82974 .71432 m .83533 .73251 L .84265 .72568 L p .707 .577 .707 r
F P
0 g
s
.84265 .72568 m .83705 .70749 L .82974 .71432 L p .707 .577 .707 r
F P
0 g
s
.65207 .72085 m .64125 .68438 L .63898 .68014 L p .707 .577 .707 r
F P
0 g
s
.63909 .62515 m .63352 .56927 L .64063 .56141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63898 .68014 m .64981 .71662 L .65207 .72085 L p .707 .577 .707 r
F P
0 g
s
.8344 .62613 m .84522 .6626 L .84296 .65837 L p .707 .577 .707 r
F P
0 g
s
.84296 .65837 m .83213 .62189 L .8344 .62613 L p .707 .577 .707 r
F P
0 g
s
.83361 .54624 m .83919 .60212 L .82671 .59651 L p .707 .577 .707 r
F P
0 g
s
.82671 .59651 m .82114 .54063 L .83361 .54624 L p .707 .577 .707 r
F P
0 g
s
.64063 .56141 m .6462 .61729 L .63909 .62515 L p .707 .577 .707 r
F P
0 g
s
.65005 .78576 m .64445 .76756 L .64224 .76347 L p .707 .577 .707 r
F P
0 g
s
.64224 .76347 m .64783 .78167 L .65005 .78576 L p .707 .577 .707 r
F P
0 g
s
.83705 .70749 m .84265 .72568 L .84043 .72159 L p .707 .577 .707 r
F P
0 g
s
.84043 .72159 m .83483 .7034 L .83705 .70749 L p .707 .577 .707 r
F P
0 g
s
.64981 .71662 m .63898 .68014 L .64629 .67326 L p .707 .577 .707 r
F P
0 g
s
.6462 .61729 m .64063 .56141 L .65697 .55354 L p .707 .577 .707 r
F P
0 g
s
.39061 .63018 m .38503 .5743 L .35402 .57558 L p .707 .577 .707 r
F P
0 g
s
.4223 .62653 m .41673 .57065 L .38503 .5743 L p .707 .577 .707 r
F P
0 g
s
.41673 .57065 m .4223 .62653 L .45157 .62087 L p .707 .577 .707 r
F P
0 g
s
.45157 .62087 m .44599 .565 L .41673 .57065 L p .707 .577 .707 r
F P
0 g
s
.64629 .67326 m .65711 .70973 L .64981 .71662 L p .707 .577 .707 r
F P
0 g
s
.83213 .62189 m .84296 .65837 L .83135 .65719 L p .707 .577 .707 r
F P
0 g
s
.83135 .65719 m .82053 .62071 L .83213 .62189 L p .707 .577 .707 r
F P
0 g
s
.3596 .63146 m .35402 .57558 L .32672 .57437 L p .707 .577 .707 r
F P
0 g
s
.35402 .57558 m .3596 .63146 L .39061 .63018 L p .707 .577 .707 r
F P
0 g
s
.82114 .54063 m .82671 .59651 L .8058 .59293 L p .707 .577 .707 r
F P
0 g
s
.8058 .59293 m .80022 .53705 L .82114 .54063 L p .707 .577 .707 r
F P
0 g
s
.65697 .55354 m .66255 .60942 L .6462 .61729 L p .707 .577 .707 r
F P
0 g
s
.44599 .565 m .45157 .62087 L .47555 .61376 L p .707 .577 .707 r
F P
0 g
s
.47555 .61376 m .46997 .55788 L .44599 .565 L p .707 .577 .707 r
F P
0 g
s
.39635 .67234 m .38553 .63587 L .35573 .64333 L p .707 .577 .707 r
F P
0 g
s
.38553 .63587 m .39635 .67234 L .42694 .66312 L p .707 .577 .707 r
F P
0 g
s
.42694 .66312 m .41612 .62664 L .38553 .63587 L p .707 .577 .707 r
F P
0 g
s
.45534 .65303 m .44452 .61656 L .41612 .62664 L p .707 .577 .707 r
F P
0 g
s
.64783 .78167 m .64224 .76347 L .64955 .75664 L p .707 .577 .707 r
F P
0 g
s
.32672 .57437 m .3323 .63025 L .3596 .63146 L p .707 .577 .707 r
F P
0 g
s
.64955 .75664 m .65515 .77484 L .64783 .78167 L p .707 .577 .707 r
F P
0 g
s
.35573 .64333 m .36656 .67981 L .39635 .67234 L p .707 .577 .707 r
F P
0 g
s
.3323 .63025 m .32672 .57437 L .30581 .57079 L p .707 .577 .707 r
F P
0 g
s
.83483 .7034 m .84043 .72159 L .82889 .72064 L p .707 .577 .707 r
F P
0 g
s
.82889 .72064 m .8233 .70245 L .83483 .7034 L p .707 .577 .707 r
F P
0 g
s
.66255 .60942 m .65697 .55354 L .68095 .54643 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35573 .64333 L .35189 .64406 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35189 .64406 L .36133 .67534 L .707 .577 .707 r
F
.36287 .68044 m .35869 .68154 L p .36364 .683 L F P
0 g
s
.32965 .6483 m .34048 .68478 L .36656 .67981 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .38839 .67375 L .36287 .68044 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .36287 .68044 L .36364 .683 L .707 .577 .707 r
F
.35189 .64406 m .32965 .6483 L p .36133 .67534 L F P
0 g
s
.38839 .67375 m .39398 .69195 L .42448 .68243 L p .707 .577 .707 r
F P
0 g
s
.42448 .68243 m .41889 .66424 L .38839 .67375 L p .707 .577 .707 r
F P
0 g
s
.41889 .66424 m .42448 .68243 L .45281 .67212 L p .707 .577 .707 r
F P
0 g
s
.45281 .67212 m .44722 .65392 L .41889 .66424 L p .707 .577 .707 r
F P
0 g
s
.65711 .70973 m .64629 .67326 L .66244 .66441 L p .707 .577 .707 r
F P
0 g
s
.44452 .61656 m .45534 .65303 L .47876 .64308 L p .707 .577 .707 r
F P
0 g
s
.47876 .64308 m .46794 .6066 L .44452 .61656 L p .707 .577 .707 r
F P
0 g
s
.35869 .68154 m .36428 .69973 L .39398 .69195 L p .707 .577 .707 r
F P
0 g
s
.82053 .62071 m .83135 .65719 L .81154 .65918 L p .707 .577 .707 r
F P
0 g
s
.81154 .65918 m .80072 .62271 L .82053 .62071 L p .707 .577 .707 r
F P
0 g
s
.66244 .66441 m .67326 .70088 L .65711 .70973 L p .707 .577 .707 r
F P
0 g
s
.46997 .55788 m .47555 .61376 L .49189 .60589 L p .707 .577 .707 r
F P
0 g
s
.49189 .60589 m .48632 .55001 L .46997 .55788 L p .707 .577 .707 r
F P
0 g
s
.80022 .53705 m .8058 .59293 L .7785 .59172 L p .707 .577 .707 r
F P
0 g
s
.7785 .59172 m .77292 .53584 L .80022 .53705 L p .707 .577 .707 r
F P
0 g
s
.36428 .69973 m .35869 .68154 L .33271 .68683 L p .707 .577 .707 r
F P
0 g
s
.30581 .57079 m .31139 .62667 L .3323 .63025 L p .707 .577 .707 r
F P
0 g
s
.44722 .65392 m .45281 .67212 L .47618 .66201 L p .707 .577 .707 r
F P
0 g
s
.47618 .66201 m .47059 .64382 L .44722 .65392 L p .707 .577 .707 r
F P
0 g
s
.33271 .68683 m .3383 .70503 L .36428 .69973 L p .707 .577 .707 r
F P
0 g
s
.68095 .54643 m .68653 .60231 L .66255 .60942 L p .707 .577 .707 r
F P
0 g
s
.34048 .68478 m .32965 .6483 L .30984 .6503 L p .707 .577 .707 r
F P
0 g
s
.68653 .60231 m .68095 .54643 L .71022 .54077 L p .707 .577 .707 r
F P
0 g
s
.46794 .6066 m .47876 .64308 L .49491 .63423 L p .707 .577 .707 r
F P
0 g
s
.49491 .63423 m .48409 .59775 L .46794 .6066 L p .707 .577 .707 r
F P
0 g
s
.31139 .62667 m .30581 .57079 L .29333 .56519 L p .707 .577 .707 r
F P
0 g
s
.30984 .6503 m .32067 .68677 L .34048 .68478 L p .707 .577 .707 r
F P
0 g
s
.65515 .77484 m .64955 .75664 L .66569 .74774 L p .707 .577 .707 r
F P
0 g
s
.77292 .53584 m .7785 .59172 L .74749 .593 L p .707 .577 .707 r
F P
0 g
s
.74749 .593 m .74191 .53712 L .77292 .53584 L p .707 .577 .707 r
F P
0 g
s
.66569 .74774 m .67128 .76594 L .65515 .77484 L p .707 .577 .707 r
F P
0 g
s
.3383 .70503 m .33271 .68683 L .31298 .68911 L p .707 .577 .707 r
F P
0 g
s
.67326 .70088 m .66244 .66441 L .68586 .65446 L p .707 .577 .707 r
F P
0 g
s
.8233 .70245 m .82889 .72064 L .80917 .72293 L p .707 .577 .707 r
F P
0 g
s
.80917 .72293 m .80357 .70473 L .8233 .70245 L p .707 .577 .707 r
F P
0 g
s
.31298 .68911 m .31857 .70731 L .3383 .70503 L p .707 .577 .707 r
F P
0 g
s
.7158 .59665 m .71022 .54077 L .74191 .53712 L p .707 .577 .707 r
F P
0 g
s
.71022 .54077 m .7158 .59665 L .68653 .60231 L p .707 .577 .707 r
F P
0 g
s
.47059 .64382 m .47618 .66201 L .49232 .65311 L p .707 .577 .707 r
F P
0 g
s
.49232 .65311 m .48673 .63492 L .47059 .64382 L p .707 .577 .707 r
F P
0 g
s
.80072 .62271 m .81154 .65918 L .78546 .66416 L p .707 .577 .707 r
F P
0 g
s
.78546 .66416 m .77464 .62768 L .80072 .62271 L p .707 .577 .707 r
F P
0 g
s
.74191 .53712 m .74749 .593 L .7158 .59665 L p .707 .577 .707 r
F P
0 g
s
.68586 .65446 m .69668 .69093 L .67326 .70088 L p .707 .577 .707 r
F P
0 g
s
.48632 .55001 m .49189 .60589 L .499 .59803 L p .707 .577 .707 r
F P
0 g
s
.499 .59803 m .49343 .54215 L .48632 .55001 L p .707 .577 .707 r
F P
0 g
s
.29333 .56519 m .29891 .62107 L .31139 .62667 L p .707 .577 .707 r
F P
0 g
s
.32067 .68677 m .30984 .6503 L .29824 .64912 L p .707 .577 .707 r
F P
0 g
s
.69668 .69093 m .68586 .65446 L .71425 .64437 L p .707 .577 .707 r
F P
0 g
s
.48409 .59775 m .49491 .63423 L .50221 .62734 L p .707 .577 .707 r
F P
0 g
s
.50221 .62734 m .49139 .59087 L .48409 .59775 L p .707 .577 .707 r
F P
0 g
s
.29824 .64912 m .30906 .68559 L .32067 .68677 L p .707 .577 .707 r
F P
0 g
s
.67128 .76594 m .66569 .74774 L .68906 .73764 L p .707 .577 .707 r
F P
0 g
s
.77464 .62768 m .78546 .66416 L .75567 .67162 L p .707 .577 .707 r
F P
0 g
s
.75567 .67162 m .74484 .63515 L .77464 .62768 L p .707 .577 .707 r
F P
0 g
s
.29891 .62107 m .29333 .56519 L .29051 .55811 L p .707 .577 .707 r
F P
0 g
s
.31857 .70731 m .31298 .68911 L .30144 .68816 L p .707 .577 .707 r
F P
0 g
s
.68906 .73764 m .69466 .75584 L .67128 .76594 L p .707 .577 .707 r
F P
0 g
s
.71425 .64437 m .72507 .68085 L .69668 .69093 L p .707 .577 .707 r
F P
0 g
s
.80357 .70473 m .80917 .72293 L .78319 .72822 L p .707 .577 .707 r
F P
0 g
s
.78319 .72822 m .77759 .71003 L .80357 .70473 L p .707 .577 .707 r
F P
0 g
s
.30144 .68816 m .30704 .70636 L .31857 .70731 L p .707 .577 .707 r
F P
0 g
s
.48673 .63492 m .49232 .65311 L .49964 .64628 L p .707 .577 .707 r
F P
0 g
s
.49964 .64628 m .49404 .62809 L .48673 .63492 L p .707 .577 .707 r
F P
0 g
s
.72507 .68085 m .71425 .64437 L .74484 .63515 L p .707 .577 .707 r
F P
0 g
s
.74484 .63515 m .75567 .67162 L .72507 .68085 L p .707 .577 .707 r
F P
0 g
s
.49343 .54215 m .499 .59803 L .49618 .59095 L p .707 .577 .707 r
F P
0 g
s
.49618 .59095 m .4906 .53507 L .49343 .54215 L p .707 .577 .707 r
F P
0 g
s
.29051 .55811 m .29608 .61399 L .29891 .62107 L p .707 .577 .707 r
F P
0 g
s
.69466 .75584 m .68906 .73764 L .71739 .72733 L p .707 .577 .707 r
F P
0 g
s
.77759 .71003 m .78319 .72822 L .75349 .73601 L p .707 .577 .707 r
F P
0 g
s
.75349 .73601 m .74789 .71781 L .77759 .71003 L p .707 .577 .707 r
F P
0 g
s
.71739 .72733 m .72298 .74552 L .69466 .75584 L p .707 .577 .707 r
F P
0 g
s
.30906 .68559 m .29824 .64912 L .29597 .64488 L p .707 .577 .707 r
F P
0 g
s
.29597 .64488 m .3068 .68136 L .30906 .68559 L p .707 .577 .707 r
F P
0 g
s
.49139 .59087 m .50221 .62734 L .49995 .62311 L p .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49139 .59087 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.4991 .62027 m .48912 .58663 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49995 .62311 L .48834 .62193 L p .707 .577 .707 r
F P
0 g
s
.48834 .62193 m .47752 .58545 L .48912 .58663 L p .707 .577 .707 r
F P
0 g
s
.4906 .53507 m .49618 .59095 L .48899 .58772 L p .707 .577 .707 r
F P
0 g
s
.48899 .58772 m .4837 .58535 L p .48509 .5752 L .707 .577 .707 r
F P
0 g
s
.48509 .5752 m .4906 .53507 L .48899 .58772 L .707 .577 .707 r
F
.49995 .62311 m .4991 .62027 L p .49971 .62222 L F P
0 g
s
.72298 .74552 m .71739 .72733 L .74789 .71781 L p .707 .577 .707 r
F P
0 g
s
.74789 .71781 m .75349 .73601 L .72298 .74552 L p .707 .577 .707 r
F P
0 g
s
.30704 .70636 m .30144 .68816 L .29923 .68407 L p .707 .577 .707 r
F P
0 g
s
.29608 .61399 m .29051 .55811 L .29762 .55025 L p .707 .577 .707 r
F P
0 g
s
.29923 .68407 m .30482 .70227 L .30704 .70636 L p .707 .577 .707 r
F P
0 g
s
.49404 .62809 m .49964 .64628 L .49742 .64219 L p .707 .577 .707 r
F P
0 g
s
.49742 .64219 m .49182 .624 L .49404 .62809 L p .707 .577 .707 r
F P
0 g
s
.4837 .58535 m .47813 .52947 L .4906 .53507 L p .707 .577 .707 r
F P
0 g
s
.29762 .55025 m .30319 .60613 L .29608 .61399 L p .707 .577 .707 r
F P
0 g
s
.3068 .68136 m .29597 .64488 L .30328 .638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30328 .638 m .3141 .67447 L .3068 .68136 L p .707 .577 .707 r
F P
0 g
s
.30319 .60613 m .29762 .55025 L .31396 .54238 L p .707 .577 .707 r
F P
0 g
s
.30482 .70227 m .29923 .68407 L .30654 .67724 L p .707 .577 .707 r
F P
0 g
s
.30654 .67724 m .31214 .69544 L .30482 .70227 L p .707 .577 .707 r
F P
0 g
s
.49182 .624 m .49742 .64219 L .48588 .64124 L p .707 .577 .707 r
F P
0 g
s
.48588 .64124 m .48029 .62305 L .49182 .624 L p .707 .577 .707 r
F P
0 g
s
.47813 .52947 m .4837 .58535 L .46279 .58176 L p .707 .577 .707 r
F P
0 g
s
.46279 .58176 m .45721 .52588 L .47813 .52947 L p .707 .577 .707 r
F P
0 g
s
.31396 .54238 m .31954 .59825 L .30319 .60613 L p .707 .577 .707 r
F P
0 g
s
.3141 .67447 m .30328 .638 L .31943 .62915 L p .707 .577 .707 r
F P
0 g
s
.31954 .59825 m .31396 .54238 L .33794 .53526 L p .707 .577 .707 r
F P
0 g
s
.47752 .58545 m .48834 .62193 L .46853 .62392 L p .707 .577 .707 r
F P
0 g
s
.46853 .62392 m .45771 .58745 L .47752 .58545 L p .707 .577 .707 r
F P
0 g
s
.31943 .62915 m .33025 .66562 L .3141 .67447 L p .707 .577 .707 r
F P
0 g
s
.31214 .69544 m .30654 .67724 L .32268 .66834 L p .707 .577 .707 r
F P
0 g
s
.32268 .66834 m .32827 .68654 L .31214 .69544 L p .707 .577 .707 r
F P
0 g
s
.45721 .52588 m .46279 .58176 L .43549 .58055 L p .707 .577 .707 r
F P
0 g
s
.43549 .58055 m .42991 .52467 L .45721 .52588 L p .707 .577 .707 r
F P
0 g
s
.48029 .62305 m .48588 .64124 L .46616 .64353 L p .707 .577 .707 r
F P
0 g
s
.46616 .64353 m .46056 .62533 L .48029 .62305 L p .707 .577 .707 r
F P
0 g
s
.33794 .53526 m .34352 .59114 L .31954 .59825 L p .707 .577 .707 r
F P
0 g
s
.34352 .59114 m .33794 .53526 L .36721 .5296 L p .707 .577 .707 r
F P
0 g
s
.33025 .66562 m .31943 .62915 L .34285 .61919 L p .707 .577 .707 r
F P
0 g
s
.42991 .52467 m .43549 .58055 L .40448 .58184 L p .707 .577 .707 r
F P
0 g
s
.40448 .58184 m .3989 .52596 L .42991 .52467 L p .707 .577 .707 r
F P
0 g
s
.46056 .62533 m .46616 .64353 L .44017 .64882 L p .707 .577 .707 r
F P
0 g
s
.43826 .62995 m .41266 .63636 L p .42885 .59885 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43458 .63063 L .43824 .62988 L p .707 .577 .707 r
F P
0 g
s
.43824 .62988 m .46056 .62533 L p .44299 .64558 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43824 .62988 L .44299 .64558 L .707 .577 .707 r
F
.43163 .59242 m .44245 .6289 L .43826 .62995 L p F P
0 g
s
.42885 .59885 m .43163 .59242 L .43826 .62995 L .707 .577 .707 r
F
.45771 .58745 m .46853 .62392 L .44245 .6289 L p F P
0 g
s
.44245 .6289 m .43163 .59242 L .45771 .58745 L p .707 .577 .707 r
F P
0 g
s
.34285 .61919 m .35367 .65567 L .33025 .66562 L p .707 .577 .707 r
F P
0 g
s
.37278 .58548 m .36721 .5296 L .3989 .52596 L p .707 .577 .707 r
F P
0 g
s
.36721 .5296 m .37278 .58548 L .34352 .59114 L p .707 .577 .707 r
F P
0 g
s
.32827 .68654 m .32268 .66834 L .34605 .65824 L p .707 .577 .707 r
F P
0 g
s
.3989 .52596 m .40448 .58184 L .37278 .58548 L p .707 .577 .707 r
F P
0 g
s
.34605 .65824 m .35165 .67644 L .32827 .68654 L p .707 .577 .707 r
F P
0 g
s
.35367 .65567 m .34285 .61919 L .37124 .60911 L p .707 .577 .707 r
F P
0 g
s
.41266 .63636 m .40183 .59989 L .43163 .59242 L p .707 .577 .707 r
F P
0 g
s
.37124 .60911 m .38206 .64559 L .35367 .65567 L p .707 .577 .707 r
F P
0 g
s
.35165 .67644 m .34605 .65824 L .37438 .64793 L p .707 .577 .707 r
F P
0 g
s
.38206 .64559 m .37124 .60911 L .40183 .59989 L p .707 .577 .707 r
F P
0 g
s
.40183 .59989 m .41266 .63636 L .38206 .64559 L p .707 .577 .707 r
F P
0 g
s
.43458 .63063 m .44017 .64882 L .41048 .65661 L p .707 .577 .707 r
F P
0 g
s
.41048 .65661 m .40488 .63841 L .43458 .63063 L p .707 .577 .707 r
F P
0 g
s
.37438 .64793 m .37997 .66612 L .35165 .67644 L p .707 .577 .707 r
F P
0 g
s
.37997 .66612 m .37438 .64793 L .40488 .63841 L p .707 .577 .707 r
F P
0 g
s
.40488 .63841 m .41048 .65661 L .37997 .66612 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20004UYF00<005YFFUH00eYF2000OWoo001dOol300000eYF001JEP0GFUH00`00FUIJEP09
FUH00`00FUH00003001jOol0075oo`<000AJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF
00=JEP@007Ioo`00KWoo0`001eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH01eYF1000
LWoo001ZOol400000eYF001JEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04001^Ool006Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00Igoo0P001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001VOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH00000J7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001V
Ool006Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEQL000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00Hgoo00<005YFFUH01`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8001QooaP003Moo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@003=oo`00F7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00EWoo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Yoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000`Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001C
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002moo`00DWoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20002Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001BOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYF001JEP0_Ool0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P0025YF
00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH6
0002FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`03001JEP00
00AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000D000=JEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF60000UYF00D005YF
FUIJEP0002ioo`00Dgoo00@005YFFUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH015YF
1P0000AJEP00000000=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001oogoo02aoo`00
Dgoo00@005YFFUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<0
05YF000010000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP000000;Goo
001DOol2FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP03FUH50008FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF1000;Goo001DOol2FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo001DOol015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH0
0`0025YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP@000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00E7oo00@005YFFUH000EJEP03001JEUYF00EJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0
04Ioo`l000=JEP03001JEUYF009JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo0010Ool60004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF0000000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000`Ool003aoo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP06001JEP00001JEP000eYF100000=JEP00FUH01eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF3@002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF1`000UYF00@005YFFUH0031oo`00>7oo10001EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EPH000EJEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EPL000=JEP03001JEUYF00AJEP04001JEUYF000_Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04
001JEUYFFUH50005FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0000=JEP00FUH01UYF00<0
05YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000`001eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF10000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0000=JEP00FUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000MJEQ@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00AJEP04001JEUYF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH40004FUH0
0`00FUIJEP07FUH01000FUIJEUYF1`000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP03001JEUYF008000=oo`<000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH900000eYF001JEP04FUH4
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH0
1@00FUIJEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
00000eYF001JEP08FUH00`00FUIJEP040003FUH30005FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YF000002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF100015YF00<005YFFUH01EYF
100000=JEP00FUH00UYF0P0000=JEP00FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP04001JEUYFFUH30008FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00Ool0;7oo000[
Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00D005YFFUIJEP0000AJEP<000MJEP03001JEUYF00=JEP8000IJEP<000=JEP03001J
EUYF00EJEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000MJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH70003
FUH4000/Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH01P00FUH00000FUH000UJEP03001JEP000080
00EJEP<000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000IJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPH000EJEP03001JEUYF009JEP04001JEUYF000/Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00=JEP8000=J
EP03001JEUYF00IJEP<00003FUH005YF009JEP<00003FUH005YF00MJEP04001JEUYFFUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH30006FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00009JEP04001JEP000006FUH00`00FUIJEP02FUH30005FUH30004
FUH00`00FUIJEP06FUH01000FUH000002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF10001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0002FUH30007FUH00`00FUH000020005FUH3
0007FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000<7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04
FUH20003FUH500000eYF001JEP08FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000bOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP800003FUH0000000<000EJEP@000IJEP03001J
EP00008000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP@000MJEP03
001JEUYF00IJEP03001JEUYF009JEP8003Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH015YF00<005YF00001000
00=JEP00FUH01eYF1@000eYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;7oo00@005YF
FUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00004FUH005YF0002
FUH01000FUIJEUYF10001UYF00<005YFFUH01EYF20002UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00@005YF
FUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP80009JEP04001J
EP000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH500000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
1EYF00<005YFFUH015YF0`002EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00?7oo000]Ool2FUH0
1000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00@005YF001J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH000000002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
1EYF001JEUYF000015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YF00000P00?Woo000]Ool2FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00
FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP800005FUH005YFFUH00005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01EYF
0`00@Goo000]Ool015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH00`0025YF00<005YFFUH0
1EYF00H005YF000005YF0006FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
0002FUH00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000?Ool4000aOol0
02eoo`04001JEUYF0005FUH00`00FUIJEP05FUH300000eYF001JEP08FUH00`00FUIJEP06FUH01P00
FUH00000FUH000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUH00002000:Ool7
0002FUH01000FUH00000;goo000]Ool01@00FUIJEUYF000015YF00<005YFFUH00eYF0`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00Qoo`D000=JEP03001JEUYF00=JEP04001JEUYF000_Ool002eoo`05001JEUYFFUH00005FUH00`00
FUH000020007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP040009Ool300000eYF001JEP05FUH00`00FUIJEP04FUH00`00FUH0000_Ool0
02ioo`800003FUH005YF00AJEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEPD0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP800003FUH005YF00EJEP04001JEUYFFUH6000:Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool400000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00001P0000=JEP00FUH00UYF1`002goo10001eYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH007oo02eoo`00<goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF1P000eYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH50003FUH01000FUIJEP001goo10000UYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000eYF1000;Goo000aOol30007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH500000eYF001J
EP06FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF
001JEP0000IJEP03001JEUYF00=JEP03001JEUYF0080009oo`@000MJEP03001JEUYF00IJEP03001J
EP0000D00003FUH005YF00=JEP04001JEUYF000]Ool002moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP05FUH30002Ool20003FUH00`00FUIJEP03FUH2000^
Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP040002Ool30006FUH01000FUIJEUYF0P00;goo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH01EYF100015YF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03
001JEUYF00EJEPD000Aoo`800003FUH005YF00IJEP04001JEP00000aOol002eoo`04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH7000015YF000000000UYF
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00MJEQ8000UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00<000UJEP03001JEUYF
00@000Ioo`<000AJEP03001JEUYF00AJEP8003=oo`00;Goo0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH010001EYF0`000eYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000YJEP03001JEUYF00EJEPH000=JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP<000=JEP03
001JEUYF00EJEP@000Moo`<000MJEP03001JEUYF009JEP8003Eoo`00;Woo00<005YF000015YF00<0
05YFFUH015YF100015YF00<005YFFUH01EYF100000=JEP00FUH015YF0`001EYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH015YF1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF1`0025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF
0P0027oo0`0000=JEP00FUH025YF00@005YF000003Moo`00;Woo00@005YFFUH000=JEP03001JEUYF
009JEP<000MJEP03001JEUYF00=JEP8000IJEP03001JEP0000800003FUH005YF00IJEP80009JEP03
001JEUYF00AJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJ
EPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH30007FUH00`00FUH0
00020007Ool30005FUH00`00FUIJEP05FUH3000iOol002ioo`04001JEUYF0004FUH01P00FUH00000
FUH000UJEP03001JEP00008000MJEP@000=JEP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEP@0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPD000MJEP03
001JEUYF009JEP8000AJEP<0009JEP03001JEUYF00AJEP<0009JEP03001oogoo009oo`<000QJEP03
001JEUYF00=JEP8003aoo`00;Woo0P0000=JEP00FUH00eYF0P000eYF00<005YFFUH01UYF0`0000=J
EP00FUH015YF10001eYF00@005YFFUIJEP80009oo`04001JEUYF0003FUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP02FUH20002FUH30005FUH01000FUIJEUYF0P000eYF0P0000=oo`0000000P0000=JEP00FUH0
2EYF00<005YF00000P00?Woo000_Ool01@00FUIJEP00FUH00P001UYF00<005YFFUH00UYF0`001EYF
1@000UYF00<005YFFUH01UYF00@005YF000000Aoo`05001JEUYF001JEP020008FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001J
EP03FUH400000eYF00000005FUH01000FUH000000UYF1P001UYF00<005YFFUH01UYF0`00@Goo000_
Ool00`00FUIJEP030007FUH00`00FUH000020005FUH40006FUH00`00FUIJEP05FUH30006Ool00`00
FUIJEP0200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000UYF00@005YFFUH000AJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP<004Aoo`00;goo0`000eYF00<005YFFUH015YF0P000eYF1@00
00=JEP00FUH025YF00<005YFFUH00UYF0P002Goo00<005YF00000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP80009JEP04001JEUYF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
00000P00Agoo000_Ool20004FUH00`00FUIJEP02FUH200000eYF000000030006FUH30006FUH00`00
FUH00002000;Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001:Ool002ioo`03001JEP0000EJEP03001JEP0000@0
0003FUH005YF00MJEPD000AJEP<000ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEP000003FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP04001=Ool002io
o`04001JEUYF0003FUH40006FUH00`00FUIJEP05FUH9000AOol00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF00001EYF00<005YFFUH015YF1000DGoo000^
Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@005Goo00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP05001JEUYFFUH00004FUH00`00
FUIJEP04001EOol002moo`04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000GOol0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00FUH03`00FGoo000_Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUH00002000MOol00`00FUIJEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP02001XOol002moo`04001JEUYF0006FUH01000FUIJEUYF
1@008Goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00003Woo1000F7oo000_Ool2
0002FUH01000FUIJEUYF1P00:7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P002Woo1@000UYF00@005YF0000
05Ioo`00<7oo1`00<7oo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01Goo100000=JEP00FUH015YF
00@005YFFUH005Ioo`00JGoo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`@000EJEP03001JEUYF00=JEP04
001JEUYF001FOol006aoo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo001_Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo001c
Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP080002FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH<001DOol007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF
00AJEP`000MJEP03001JEUYF00IJEP03001JEP0000D00003FUH005YF00=JEP04001JEUYF001DOol0
085ooaX000Ioo`800003FUH005YF00QJEP03001JEUYF00EJEP<0009oo`8000=JEP03001JEUYF00=J
EP8005Eoo`00WWoo0`0015YF00<005YFFUH01eYF00<005YFFUH010000Woo0`001UYF00@005YFFUIJ
EP8005Ioo`00W7oo0P001eYF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF0000
05Qoo`00VWoo0`0025YF00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0P00FWoo002H
Ool20003FUH00`00FUIJEP06FUH00`00FUH000020005Ool30007FUH00`00FUIJEP02FUH2001LOol0
09Ioo`8000EJEP03001JEUYF00EJEP<000Eoo`<00003FUH005YF00QJEP04001JEP00001NOol009Ao
o`<000IJEP03001JEUYF00=JEP8000Eoo`<000EJEP03001JEUYF00EJEP<0061oo`00TWoo0P000UYF
00<005YFFUH01EYF00<005YF00000P0017oo0`0025YF00<005YFFUH00eYF0P00Hgoo002AOol00`00
FUIJEP03FUH00`00FUIJEP03FUH30003Ool400000eYF001JEP09FUH00`00FUH00002001UOol0091o
o`8000EJEP03001JEP0000<0009oo`@000IJEP03001JEUYF00IJEP<006Qoo`00Sgoo00@005YFFUH0
00AJEP80009oo`@00003FUH005YF00MJEP03001JEUYF00=JEP<006]oo`00Sgoo00@005YFFUH000=J
EPD000IJEP03001JEUYF00IJEP03001JEP00008006ioo`00T7oo00<005YFFUH00`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF0`00LGoo002@Ool00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00
FUIJEP04001dOol0095oo`04FUH005YF0005FUH00`00FUIJEP04FUH4001hOol0095oo`05001JEUYF
FUH00004FUH00`00FUIJEP04001lOol0095oo``0081oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59642 .73339 m .59084 .67751 L .55983 .67879 L p .707 .577 .707 r
F P
0 g
s
.59084 .67751 m .59642 .73339 L .62811 .72974 L p .707 .577 .707 r
F P
0 g
s
.62811 .72974 m .62253 .67386 L .59084 .67751 L p .707 .577 .707 r
F P
0 g
s
.62253 .67386 m .62811 .72974 L .65738 .72408 L p .707 .577 .707 r
F P
0 g
s
.65738 .72408 m .6518 .6682 L .62253 .67386 L p .707 .577 .707 r
F P
0 g
s
.5654 .73467 m .55983 .67879 L .53253 .67758 L p .707 .577 .707 r
F P
0 g
s
.55983 .67879 m .5654 .73467 L .59642 .73339 L p .707 .577 .707 r
F P
0 g
s
.6518 .6682 m .65738 .72408 L .68136 .71697 L p .707 .577 .707 r
F P
0 g
s
.68136 .71697 m .67578 .66109 L .6518 .6682 L p .707 .577 .707 r
F P
0 g
s
.53253 .67758 m .5381 .73346 L .5654 .73467 L p .707 .577 .707 r
F P
0 g
s
.60216 .79964 m .59133 .76317 L .56154 .77063 L p .707 .577 .707 r
F P
0 g
s
.59133 .76317 m .60216 .79964 L .63275 .79041 L p .707 .577 .707 r
F P
0 g
s
.63275 .79041 m .62193 .75394 L .59133 .76317 L p .707 .577 .707 r
F P
0 g
s
.5381 .73346 m .53253 .67758 L .51162 .674 L p .707 .577 .707 r
F P
0 g
s
.62193 .75394 m .63275 .79041 L .66114 .78033 L p .707 .577 .707 r
F P
0 g
s
.66114 .78033 m .65032 .74386 L .62193 .75394 L p .707 .577 .707 r
F P
0 g
s
.56154 .77063 m .57236 .8071 L .60216 .79964 L p .707 .577 .707 r
F P
0 g
s
.57236 .8071 m .56154 .77063 L .53546 .7756 L p .707 .577 .707 r
F P
0 g
s
.67578 .66109 m .68136 .71697 L .6977 .70909 L p .707 .577 .707 r
F P
0 g
s
.6977 .70909 m .69212 .65322 L .67578 .66109 L p .707 .577 .707 r
F P
0 g
s
.65032 .74386 m .66114 .78033 L .68456 .77038 L p .707 .577 .707 r
F P
0 g
s
.68456 .77038 m .67374 .7339 L .65032 .74386 L p .707 .577 .707 r
F P
0 g
s
.51162 .674 m .51719 .72988 L .5381 .73346 L p .707 .577 .707 r
F P
0 g
s
.53546 .7756 m .54628 .81208 L .57236 .8071 L p .707 .577 .707 r
F P
0 g
s
.59978 .86338 m .59419 .84519 L .56449 .85297 L p .707 .577 .707 r
F P
0 g
s
.59419 .84519 m .59978 .86338 L .63029 .85387 L p .707 .577 .707 r
F P
0 g
s
.63029 .85387 m .6247 .83567 L .59419 .84519 L p .707 .577 .707 r
F P
0 g
s
.6247 .83567 m .63029 .85387 L .65861 .84355 L p .707 .577 .707 r
F P
0 g
s
.65861 .84355 m .65302 .82536 L .6247 .83567 L p .707 .577 .707 r
F P
0 g
s
.56449 .85297 m .57009 .87117 L .59978 .86338 L p .707 .577 .707 r
F P
0 g
s
.51719 .72988 m .51162 .674 L .49914 .66839 L p .707 .577 .707 r
F P
0 g
s
.54628 .81208 m .53546 .7756 L .51565 .7776 L p .707 .577 .707 r
F P
0 g
s
.57009 .87117 m .56449 .85297 L .53851 .85827 L p .707 .577 .707 r
F P
0 g
s
.67374 .7339 m .68456 .77038 L .70071 .76152 L p .707 .577 .707 r
F P
0 g
s
.70071 .76152 m .68989 .72505 L .67374 .7339 L p .707 .577 .707 r
F P
0 g
s
.51565 .7776 m .52647 .81407 L .54628 .81208 L p .707 .577 .707 r
F P
0 g
s
.65302 .82536 m .65861 .84355 L .68199 .83345 L p .707 .577 .707 r
F P
0 g
s
.68199 .83345 m .6764 .81526 L .65302 .82536 L p .707 .577 .707 r
F P
0 g
s
.53851 .85827 m .54411 .87646 L .57009 .87117 L p .707 .577 .707 r
F P
0 g
s
.69212 .65322 m .6977 .70909 L .70481 .70123 L p .707 .577 .707 r
F P
0 g
s
.70481 .70123 m .69923 .64536 L .69212 .65322 L p .707 .577 .707 r
F P
0 g
s
.49914 .66839 m .50471 .72427 L .51719 .72988 L p .707 .577 .707 r
F P
0 g
s
.54411 .87646 m .53851 .85827 L .51879 .86055 L p .707 .577 .707 r
F P
0 g
s
.51879 .86055 m .52438 .87875 L .54411 .87646 L p .707 .577 .707 r
F P
0 g
s
.52647 .81407 m .51565 .7776 L .50404 .77642 L p .707 .577 .707 r
F P
0 g
s
.6764 .81526 m .68199 .83345 L .69813 .82455 L p .707 .577 .707 r
F P
0 g
s
.69813 .82455 m .69253 .80636 L .6764 .81526 L p .707 .577 .707 r
F P
0 g
s
.50471 .72427 m .49914 .66839 L .49631 .66131 L p .707 .577 .707 r
F P
0 g
s
.68989 .72505 m .70071 .76152 L .70802 .75464 L p .707 .577 .707 r
F P
0 g
s
.70802 .75464 m .69719 .71817 L .68989 .72505 L p .707 .577 .707 r
F P
0 g
s
.50404 .77642 m .51487 .81289 L .52647 .81407 L p .707 .577 .707 r
F P
0 g
s
.69923 .64536 m .70481 .70123 L .70198 .69416 L p .707 .577 .707 r
F P
0 g
s
.70198 .69416 m .69641 .63828 L .69923 .64536 L p .707 .577 .707 r
F P
0 g
s
.49631 .66131 m .50189 .71719 L .50471 .72427 L p .707 .577 .707 r
F P
0 g
s
.52438 .87875 m .51879 .86055 L .50725 .8596 L p .707 .577 .707 r
F P
0 g
s
.50725 .8596 m .51284 .8778 L .52438 .87875 L p .707 .577 .707 r
F P
0 g
s
.69253 .80636 m .69813 .82455 L .70544 .81772 L p .707 .577 .707 r
F P
0 g
s
.70544 .81772 m .69985 .79952 L .69253 .80636 L p .707 .577 .707 r
F P
0 g
s
.47783 .82164 m .49203 .32149 L .44804 .31755 L p .707 .577 .707 r
F P
0 g
s
.51487 .81289 m .50404 .77642 L .50178 .77218 L p .707 .577 .707 r
F P
0 g
s
.50189 .71719 m .49631 .66131 L .50342 .65345 L p .707 .577 .707 r
F P
0 g
s
.50178 .77218 m .5126 .80865 L .51487 .81289 L p .707 .577 .707 r
F P
0 g
s
.50342 .65345 m .509 .70933 L .50189 .71719 L p .707 .577 .707 r
F P
0 g
s
.5126 .80865 m .50178 .77218 L .50908 .7653 L p .707 .577 .707 r
F P
0 g
s
.509 .70933 m .50342 .65345 L .51977 .64558 L p .707 .577 .707 r
F P
0 g
s
.50908 .7653 m .5199 .80177 L .5126 .80865 L p .707 .577 .707 r
F P
0 g
s
.51977 .64558 m .52534 .70146 L .509 .70933 L p .707 .577 .707 r
F P
0 g
s
.5199 .80177 m .50908 .7653 L .52523 .75645 L p .707 .577 .707 r
F P
0 g
s
.52523 .75645 m .53606 .79292 L .5199 .80177 L p .707 .577 .707 r
F P
0 g
s
.49203 .32149 m .47783 .82164 L .52276 .82168 L p .707 .577 .707 r
F P
0 g
s
.52534 .70146 m .51977 .64558 L .54375 .63847 L p .707 .577 .707 r
F P
0 g
s
.54375 .63847 m .54932 .69435 L .52534 .70146 L p .707 .577 .707 r
F P
0 g
s
.52276 .82168 m .53696 .32153 L .49203 .32149 L p .707 .577 .707 r
F P
0 g
s
.54932 .69435 m .54375 .63847 L .57301 .63281 L p .707 .577 .707 r
F P
0 g
s
.53606 .79292 m .52523 .75645 L .54865 .74649 L p .707 .577 .707 r
F P
0 g
s
.57301 .63281 m .57859 .68869 L .54932 .69435 L p .707 .577 .707 r
F P
0 g
s
.54865 .74649 m .55947 .78297 L .53606 .79292 L p .707 .577 .707 r
F P
0 g
s
.55947 .78297 m .54865 .74649 L .57705 .73641 L p .707 .577 .707 r
F P
0 g
s
.57705 .73641 m .58787 .77288 L .55947 .78297 L p .707 .577 .707 r
F P
0 g
s
.53696 .32153 m .52276 .82168 L .56423 .81781 L p .707 .577 .707 r
F P
0 g
s
.56423 .81781 m .57843 .31766 L .53696 .32153 L p .707 .577 .707 r
F P
0 g
s
.69719 .71817 m .70802 .75464 L .70575 .75041 L p .707 .577 .707 r
F P
0 g
s
.70575 .75041 m .69493 .71393 L .69719 .71817 L p .707 .577 .707 r
F P
0 g
s
.43384 .8177 m .44804 .31755 L .4093 .31009 L p .707 .577 .707 r
F P
0 g
s
.44804 .31755 m .43384 .8177 L .47783 .82164 L p .707 .577 .707 r
F P
0 g
s
.69641 .63828 m .70198 .69416 L .68951 .68855 L p .707 .577 .707 r
F P
0 g
s
.68951 .68855 m .68393 .63267 L .69641 .63828 L p .707 .577 .707 r
F P
0 g
s
.57859 .68869 m .57301 .63281 L .60471 .62916 L p .707 .577 .707 r
F P
0 g
s
.60471 .62916 m .61028 .68504 L .57859 .68869 L p .707 .577 .707 r
F P
0 g
s
.58787 .77288 m .57705 .73641 L .60764 .72718 L p .707 .577 .707 r
F P
0 g
s
.60764 .72718 m .61846 .76366 L .58787 .77288 L p .707 .577 .707 r
F P
0 g
s
.57843 .31766 m .56423 .81781 L .59818 .81041 L p .707 .577 .707 r
F P
0 g
s
.59818 .81041 m .61238 .31026 L .57843 .31766 L p .707 .577 .707 r
F P
0 g
s
.51284 .8778 m .50725 .8596 L .50503 .85551 L p .707 .577 .707 r
F P
0 g
s
.50503 .85551 m .51063 .87371 L .51284 .8778 L p .707 .577 .707 r
F P
0 g
s
.69985 .79952 m .70544 .81772 L .70322 .81363 L p .707 .577 .707 r
F P
0 g
s
.70322 .81363 m .69763 .79543 L .69985 .79952 L p .707 .577 .707 r
F P
0 g
s
.3951 .81024 m .4093 .31009 L .37959 .29984 L p .707 .577 .707 r
F P
0 g
s
.4093 .31009 m .3951 .81024 L .43384 .8177 L p .707 .577 .707 r
F P
0 g
s
.25341 .72222 m .24783 .66634 L .21682 .66762 L p .707 .577 .707 r
F P
0 g
s
.24783 .66634 m .25341 .72222 L .2851 .71857 L p .707 .577 .707 r
F P
0 g
s
.2851 .71857 m .27952 .66269 L .24783 .66634 L p .707 .577 .707 r
F P
0 g
s
.27952 .66269 m .2851 .71857 L .31437 .71291 L p .707 .577 .707 r
F P
0 g
s
.31437 .71291 m .30879 .65703 L .27952 .66269 L p .707 .577 .707 r
F P
0 g
s
.69493 .71393 m .70575 .75041 L .69415 .74923 L p .707 .577 .707 r
F P
0 g
s
.69415 .74923 m .68332 .71275 L .69493 .71393 L p .707 .577 .707 r
F P
0 g
s
.22239 .7235 m .21682 .66762 L .18952 .66641 L p .707 .577 .707 r
F P
0 g
s
.21682 .66762 m .22239 .7235 L .25341 .72222 L p .707 .577 .707 r
F P
0 g
s
.68393 .63267 m .68951 .68855 L .66859 .68497 L p .707 .577 .707 r
F P
0 g
s
.66859 .68497 m .66302 .62909 L .68393 .63267 L p .707 .577 .707 r
F P
0 g
s
.30879 .65703 m .31437 .71291 L .33835 .7058 L p .707 .577 .707 r
F P
0 g
s
.33835 .7058 m .33277 .64992 L .30879 .65703 L p .707 .577 .707 r
F P
0 g
s
.63572 .62788 m .6413 .68376 L .61028 .68504 L p .707 .577 .707 r
F P
0 g
s
.61028 .68504 m .60471 .62916 L .63572 .62788 L p .707 .577 .707 r
F P
0 g
s
.63743 .71972 m .64826 .75619 L .61846 .76366 L p .707 .577 .707 r
F P
0 g
s
.61846 .76366 m .60764 .72718 L .63743 .71972 L p .707 .577 .707 r
F P
0 g
s
.61238 .31026 m .59818 .81041 L .62129 .80021 L p .707 .577 .707 r
F P
0 g
s
.62129 .80021 m .63549 .30006 L .61238 .31026 L p .707 .577 .707 r
F P
0 g
s
.25915 .76438 m .24833 .72791 L .21853 .73537 L p .707 .577 .707 r
F P
0 g
s
.24833 .72791 m .25915 .76438 L .28974 .75515 L p .707 .577 .707 r
F P
0 g
s
.28974 .75515 m .27892 .71868 L .24833 .72791 L p .707 .577 .707 r
F P
0 g
s
.27892 .71868 m .28974 .75515 L .31814 .74507 L p .707 .577 .707 r
F P
0 g
s
.31814 .74507 m .30731 .7086 L .27892 .71868 L p .707 .577 .707 r
F P
0 g
s
.51063 .87371 m .50503 .85551 L .51235 .84868 L p .707 .577 .707 r
F P
0 g
s
.18952 .66641 m .1951 .72229 L .22239 .7235 L p .707 .577 .707 r
F P
0 g
s
.51235 .84868 m .51794 .86688 L .51063 .87371 L p .707 .577 .707 r
F P
0 g
s
.21853 .73537 m .22935 .77184 L .25915 .76438 L p .707 .577 .707 r
F P
0 g
s
.1951 .72229 m .18952 .66641 L .16861 .66283 L p .707 .577 .707 r
F P
0 g
s
.69763 .79543 m .70322 .81363 L .69169 .81268 L p .707 .577 .707 r
F P
0 g
s
.69169 .81268 m .68609 .79449 L .69763 .79543 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21853 .73537 L .21469 .7361 L p .707 .577 .707 r
F P
0 g
s
.22935 .77184 m .21469 .7361 L .22413 .76738 L .707 .577 .707 r
F
.22566 .77248 m .22148 .77357 L p .22644 .77503 L F P
0 g
s
.19245 .74034 m .20327 .77682 L .22935 .77184 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .25118 .76579 L .22566 .77248 L p .707 .577 .707 r
F P
0 g
s
.25678 .78398 m .22566 .77248 L .22644 .77503 L .707 .577 .707 r
F
.21469 .7361 m .19245 .74034 L p .22413 .76738 L F P
0 g
s
.25118 .76579 m .25678 .78398 L .28728 .77447 L p .707 .577 .707 r
F P
0 g
s
.28728 .77447 m .28169 .75627 L .25118 .76579 L p .707 .577 .707 r
F P
0 g
s
.28169 .75627 m .28728 .77447 L .31561 .76416 L p .707 .577 .707 r
F P
0 g
s
.31561 .76416 m .31001 .74596 L .28169 .75627 L p .707 .577 .707 r
F P
0 g
s
.33277 .64992 m .33835 .7058 L .35469 .69793 L p .707 .577 .707 r
F P
0 g
s
.34688 .68979 m .35771 .72626 L .35957 .72451 L p .707 .577 .707 r
F P
0 g
s
.35957 .72451 m .36501 .71938 L p .35864 .70899 L .707 .577 .707 r
F P
0 g
s
.35864 .70899 m .34688 .68979 L .35957 .72451 L .707 .577 .707 r
F
.36182 .28781 m .35774 .27517 L p .35152 .59032 L F P
0 g
s
.35469 .69793 m .34911 .64205 L .33277 .64992 L p .707 .577 .707 r
F P
0 g
s
.33073 .69864 m .34155 .73512 L .35771 .72626 L p .707 .577 .707 r
F P
0 g
s
.35771 .72626 m .34688 .68979 L .33073 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .7086 m .31814 .74507 L .34155 .73512 L p .707 .577 .707 r
F P
0 g
s
.33339 .73586 m .33898 .75405 L .35512 .74515 L p .707 .577 .707 r
F P
0 g
s
.34155 .73512 m .33073 .69864 L .30731 .7086 L p .707 .577 .707 r
F P
0 g
s
.35512 .74515 m .34952 .72696 L .33339 .73586 L p .707 .577 .707 r
F P
0 g
s
.34911 .64205 m .35469 .69793 L .3618 .69007 L p .707 .577 .707 r
F P
0 g
s
.3618 .69007 m .35622 .63419 L .34911 .64205 L p .707 .577 .707 r
F P
0 g
s
.36501 .71938 m .35418 .68291 L .34688 .68979 L p .707 .577 .707 r
F P
0 g
s
.3534 .62711 m .35589 .65202 L p .3465 .67738 L .707 .577 .707 r
F P
0 g
s
.35589 .65202 m .35898 .68299 L .35409 .6808 L p .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .35418 .68291 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.36274 .71515 m .3619 .71231 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.3619 .71231 m .35192 .67867 L p .36251 .71426 L .707 .577 .707 r
F P
0 g
s
.35192 .67867 m .36274 .71515 L .35114 .71397 L p .707 .577 .707 r
F P
0 g
s
.35114 .71397 m .34032 .67749 L .35192 .67867 L p .707 .577 .707 r
F P
0 g
s
.35409 .6808 m .35178 .67976 L p .35589 .65202 L .707 .577 .707 r
F P
0 g
s
.35178 .67976 m .3465 .67738 L p .34897 .67071 L .707 .577 .707 r
F P
0 g
s
.34897 .67071 m .35589 .65202 L .35178 .67976 L .707 .577 .707 r
F
.3465 .67738 m .34092 .62151 L .3534 .62711 L p F P
0 g
s
.34952 .72696 m .35512 .74515 L .36243 .73832 L p .707 .577 .707 r
F P
0 g
s
.36243 .73832 m .35684 .72013 L .34952 .72696 L p .707 .577 .707 r
F P
0 g
s
.35462 .71604 m .36021 .73423 L .35174 .73353 L p .707 .577 .707 r
F P
0 g
s
.35174 .73353 m .34868 .73328 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.35351 .71926 m .35462 .71604 L .35174 .73353 L .707 .577 .707 r
F
.34868 .73328 m .34308 .71509 L .35392 .71598 L p F P
0 g
s
.35392 .71598 m .35462 .71604 L p .35351 .71926 L .707 .577 .707 r
F P
0 g
s
.34868 .73328 m .35392 .71598 L .35351 .71926 L .707 .577 .707 r
F
.3478 .78171 m .34841 .76035 L p .34772 .78298 L F P
0 g
s
.34032 .67749 m .35114 .71397 L .33133 .71596 L p .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .35268 .60969 L p .34836 .76074 L .707 .577 .707 r
F P
0 g
s
.34841 .76035 m .34836 .76074 L .34772 .78298 L .707 .577 .707 r
F
.34812 .76263 m .35268 .60969 L .35152 .59032 L F
.34772 .78298 m .34836 .76074 L .34812 .76263 L F
.34836 .76074 m .35268 .60969 L .34812 .76263 L F
.34762 .78796 m .3478 .78171 L p .34772 .78298 L F P
0 g
s
.35268 .60969 m .36182 .28781 L p .35152 .59032 L .707 .577 .707 r
F P
0 g
s
.35418 .68291 m .36501 .71938 L .36274 .71515 L p .707 .577 .707 r
F P
0 g
s
.36539 .79999 m .37959 .29984 L .36182 .28781 L p .707 .577 .707 r
F P
0 g
s
.37959 .29984 m .36539 .79999 L .3951 .81024 L p .707 .577 .707 r
F P
0 g
s
.22148 .77357 m .22708 .79177 L .25678 .78398 L p .707 .577 .707 r
F P
0 g
s
.68332 .71275 m .69415 .74923 L .67434 .75122 L p .707 .577 .707 r
F P
0 g
s
.67434 .75122 m .66351 .71475 L .68332 .71275 L p .707 .577 .707 r
F P
0 g
s
.66302 .62909 m .66859 .68497 L .6413 .68376 L p .707 .577 .707 r
F P
0 g
s
.6413 .68376 m .63572 .62788 L .66302 .62909 L p .707 .577 .707 r
F P
0 g
s
.22708 .79177 m .22148 .77357 L .1955 .77887 L p .707 .577 .707 r
F P
0 g
s
.16861 .66283 m .17418 .71871 L .1951 .72229 L p .707 .577 .707 r
F P
0 g
s
.31001 .74596 m .31561 .76416 L .33898 .75405 L p .707 .577 .707 r
F P
0 g
s
.33898 .75405 m .33339 .73586 L .31001 .74596 L p .707 .577 .707 r
F P
0 g
s
.1955 .77887 m .2011 .79706 L .22708 .79177 L p .707 .577 .707 r
F P
0 g
s
.20327 .77682 m .19245 .74034 L .17264 .74234 L p .707 .577 .707 r
F P
0 g
s
.17418 .71871 m .16861 .66283 L .15613 .65723 L p .707 .577 .707 r
F P
0 g
s
.17264 .74234 m .18346 .77881 L .20327 .77682 L p .707 .577 .707 r
F P
0 g
s
.51794 .86688 m .51235 .84868 L .52848 .83978 L p .707 .577 .707 r
F P
0 g
s
.63549 .30006 m .62129 .80021 L .63129 .7882 L p .707 .577 .707 r
F P
0 g
s
.63129 .7882 m .64549 .28805 L .63549 .30006 L p .707 .577 .707 r
F P
0 g
s
.52848 .83978 m .53408 .85798 L .51794 .86688 L p .707 .577 .707 r
F P
0 g
s
.2011 .79706 m .1955 .77887 L .17578 .78115 L p .707 .577 .707 r
F P
0 g
s
.68609 .79449 m .69169 .81268 L .67196 .81496 L p .707 .577 .707 r
F P
0 g
s
.67196 .81496 m .66637 .79677 L .68609 .79449 L p .707 .577 .707 r
F P
0 g
s
.17578 .78115 m .18137 .79935 L .2011 .79706 L p .707 .577 .707 r
F P
0 g
s
.66351 .71475 m .67434 .75122 L .64826 .75619 L p .707 .577 .707 r
F P
0 g
s
.64826 .75619 m .63743 .71972 L .66351 .71475 L p .707 .577 .707 r
F P
0 g
s
.15613 .65723 m .1617 .7131 L .17418 .71871 L p .707 .577 .707 r
F P
0 g
s
.35622 .63419 m .3618 .69007 L .35898 .68299 L p .707 .577 .707 r
F P
0 g
s
.35898 .68299 m .3534 .62711 L .35622 .63419 L p .707 .577 .707 r
F P
0 g
s
.35684 .72013 m .36243 .73832 L .36021 .73423 L p .707 .577 .707 r
F P
0 g
s
.36021 .73423 m .35462 .71604 L .35684 .72013 L p .707 .577 .707 r
F P
0 g
s
.36182 .28781 m .34762 .78796 L .36539 .79999 L p .707 .577 .707 r
F P
0 g
s
.18346 .77881 m .17264 .74234 L .16103 .74116 L p .707 .577 .707 r
F P
0 g
s
.16103 .74116 m .17186 .77763 L .18346 .77881 L p .707 .577 .707 r
F P
0 g
s
.53408 .85798 m .52848 .83978 L .55186 .82968 L p .707 .577 .707 r
F P
0 g
s
.1617 .7131 m .15613 .65723 L .15331 .65015 L p .707 .577 .707 r
F P
0 g
s
.18137 .79935 m .17578 .78115 L .16424 .7802 L p .707 .577 .707 r
F P
0 g
s
.55186 .82968 m .55745 .84787 L .53408 .85798 L p .707 .577 .707 r
F P
0 g
s
.66637 .79677 m .67196 .81496 L .64598 .82026 L p .707 .577 .707 r
F P
0 g
s
.64598 .82026 m .64039 .80206 L .66637 .79677 L p .707 .577 .707 r
F P
0 g
s
.16424 .7802 m .16984 .7984 L .18137 .79935 L p .707 .577 .707 r
F P
0 g
s
.15331 .65015 m .15888 .70602 L .1617 .7131 L p .707 .577 .707 r
F P
0 g
s
.64549 .28805 m .63129 .7882 L .62721 .77556 L p .707 .577 .707 r
F P
0 g
s
.62721 .77556 m .64141 .27541 L .64549 .28805 L p .707 .577 .707 r
F P
0 g
s
.55745 .84787 m .55186 .82968 L .58019 .81936 L p .707 .577 .707 r
F P
0 g
s
.64039 .80206 m .64598 .82026 L .61628 .82804 L p .707 .577 .707 r
F P
0 g
s
.61628 .82804 m .61069 .80985 L .64039 .80206 L p .707 .577 .707 r
F P
0 g
s
.58019 .81936 m .58578 .83756 L .55745 .84787 L p .707 .577 .707 r
F P
0 g
s
.17186 .77763 m .16103 .74116 L .15877 .73692 L p .707 .577 .707 r
F P
0 g
s
.15877 .73692 m .16959 .77339 L .17186 .77763 L p .707 .577 .707 r
F P
0 g
s
.58578 .83756 m .58019 .81936 L .61069 .80985 L p .707 .577 .707 r
F P
0 g
s
.61069 .80985 m .61628 .82804 L .58578 .83756 L p .707 .577 .707 r
F P
0 g
s
.16984 .7984 m .16424 .7802 L .16202 .77611 L p .707 .577 .707 r
F P
0 g
s
.15888 .70602 m .15331 .65015 L .16041 .64229 L p .707 .577 .707 r
F P
0 g
s
.16202 .77611 m .16762 .79431 L .16984 .7984 L p .707 .577 .707 r
F P
0 g
s
.34092 .62151 m .3465 .67738 L .32559 .6738 L p .707 .577 .707 r
F P
0 g
s
.34308 .71509 m .34868 .73328 L .32895 .73557 L p .707 .577 .707 r
F P
0 g
s
.35774 .27517 m .34354 .77532 L .34762 .78796 L p .707 .577 .707 r
F P
0 g
s
.34354 .77532 m .35774 .27517 L .36774 .26316 L p .707 .577 .707 r
F P
0 g
s
.16041 .64229 m .16599 .69816 L .15888 .70602 L p .707 .577 .707 r
F P
0 g
s
.16959 .77339 m .15877 .73692 L .16607 .73004 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16607 .73004 m .1769 .76651 L .16959 .77339 L p .707 .577 .707 r
F P
0 g
s
.64141 .27541 m .62721 .77556 L .60944 .76353 L p .707 .577 .707 r
F P
0 g
s
.60944 .76353 m .62364 .26338 L .64141 .27541 L p .707 .577 .707 r
F P
0 g
s
.16599 .69816 m .16041 .64229 L .17676 .63441 L p .707 .577 .707 r
F P
0 g
s
.16762 .79431 m .16202 .77611 L .16934 .76928 L p .707 .577 .707 r
F P
0 g
s
.16934 .76928 m .17493 .78748 L .16762 .79431 L p .707 .577 .707 r
F P
0 g
s
.32559 .6738 m .32001 .61792 L .34092 .62151 L p .707 .577 .707 r
F P
0 g
s
.17676 .63441 m .18233 .69029 L .16599 .69816 L p .707 .577 .707 r
F P
0 g
s
.35354 .76331 m .36774 .26316 L .39085 .25296 L p .707 .577 .707 r
F P
0 g
s
.36774 .26316 m .35354 .76331 L .34354 .77532 L p .707 .577 .707 r
F P
0 g
s
.1769 .76651 m .16607 .73004 L .18222 .72119 L p .707 .577 .707 r
F P
0 g
s
.18233 .69029 m .17676 .63441 L .20074 .6273 L p .707 .577 .707 r
F P
0 g
s
.33133 .71596 m .3205 .67949 L .34032 .67749 L p .707 .577 .707 r
F P
0 g
s
.18222 .72119 m .19305 .75766 L .1769 .76651 L p .707 .577 .707 r
F P
0 g
s
.17493 .78748 m .16934 .76928 L .18548 .76038 L p .707 .577 .707 r
F P
0 g
s
.18548 .76038 m .19107 .77858 L .17493 .78748 L p .707 .577 .707 r
F P
0 g
s
.32001 .61792 m .32559 .6738 L .29829 .67259 L p .707 .577 .707 r
F P
0 g
s
.29829 .67259 m .29271 .61671 L .32001 .61792 L p .707 .577 .707 r
F P
0 g
s
.32895 .73557 m .32336 .71737 L .34308 .71509 L p .707 .577 .707 r
F P
0 g
s
.62364 .26338 m .60944 .76353 L .57973 .75328 L p .707 .577 .707 r
F P
0 g
s
.57973 .75328 m .59393 .25313 L .62364 .26338 L p .707 .577 .707 r
F P
0 g
s
.20074 .6273 m .20631 .68318 L .18233 .69029 L p .707 .577 .707 r
F P
0 g
s
.20631 .68318 m .20074 .6273 L .23001 .62164 L p .707 .577 .707 r
F P
0 g
s
.19305 .75766 m .18222 .72119 L .20564 .71123 L p .707 .577 .707 r
F P
0 g
s
.29271 .61671 m .29829 .67259 L .26727 .67387 L p .707 .577 .707 r
F P
0 g
s
.26727 .67387 m .2617 .618 L .29271 .61671 L p .707 .577 .707 r
F P
0 g
s
.39085 .25296 m .37665 .75311 L .35354 .76331 L p .707 .577 .707 r
F P
0 g
s
.37665 .75311 m .39085 .25296 L .4248 .24556 L p .707 .577 .707 r
F P
0 g
s
.32336 .71737 m .32895 .73557 L .30297 .74086 L p .707 .577 .707 r
F P
0 g
s
.30105 .72198 m .27545 .7284 L p .29165 .69089 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .29738 .72266 L .30103 .72192 L p .707 .577 .707 r
F P
0 g
s
.30103 .72192 m .32336 .71737 L p .30578 .73762 L .707 .577 .707 r
F P
0 g
s
.30297 .74086 m .30103 .72192 L .30578 .73762 L .707 .577 .707 r
F
.29442 .68446 m .30525 .72093 L .30105 .72198 L p F P
0 g
s
.29165 .69089 m .29442 .68446 L .30105 .72198 L .707 .577 .707 r
F
.3205 .67949 m .33133 .71596 L .30525 .72093 L p F P
0 g
s
.30525 .72093 m .29442 .68446 L .3205 .67949 L p .707 .577 .707 r
F P
0 g
s
.73362 .64135 m .72804 .58547 L .69703 .58675 L p .707 .577 .707 r
F P
0 g
s
.72804 .58547 m .73362 .64135 L .76531 .6377 L p .707 .577 .707 r
F P
0 g
s
.76531 .6377 m .75974 .58182 L .72804 .58547 L p .707 .577 .707 r
F P
0 g
s
.20564 .71123 m .21647 .74771 L .19305 .75766 L p .707 .577 .707 r
F P
0 g
s
.75974 .58182 m .76531 .6377 L .79458 .63204 L p .707 .577 .707 r
F P
0 g
s
.79458 .63204 m .789 .57616 L .75974 .58182 L p .707 .577 .707 r
F P
0 g
s
.23558 .67752 m .23001 .62164 L .2617 .618 L p .707 .577 .707 r
F P
0 g
s
.23001 .62164 m .23558 .67752 L .20631 .68318 L p .707 .577 .707 r
F P
0 g
s
.19107 .77858 m .18548 .76038 L .20885 .75028 L p .707 .577 .707 r
F P
0 g
s
.2617 .618 m .26727 .67387 L .23558 .67752 L p .707 .577 .707 r
F P
0 g
s
.70261 .64263 m .69703 .58675 L .66973 .58554 L p .707 .577 .707 r
F P
0 g
s
.69703 .58675 m .70261 .64263 L .73362 .64135 L p .707 .577 .707 r
F P
0 g
s
.20885 .75028 m .21444 .76847 L .19107 .77858 L p .707 .577 .707 r
F P
0 g
s
.789 .57616 m .79458 .63204 L .81856 .62493 L p .707 .577 .707 r
F P
0 g
s
.81856 .62493 m .81298 .56905 L .789 .57616 L p .707 .577 .707 r
F P
0 g
s
.21647 .74771 m .20564 .71123 L .23404 .70115 L p .707 .577 .707 r
F P
0 g
s
.27545 .7284 m .26463 .69192 L .29442 .68446 L p .707 .577 .707 r
F P
0 g
s
.59393 .25313 m .57973 .75328 L .54099 .74582 L p .707 .577 .707 r
F P
0 g
s
.54099 .74582 m .55519 .24567 L .59393 .25313 L p .707 .577 .707 r
F P
0 g
s
.23404 .70115 m .24486 .73762 L .21647 .74771 L p .707 .577 .707 r
F P
0 g
s
.66973 .58554 m .67531 .64142 L .70261 .64263 L p .707 .577 .707 r
F P
0 g
s
.73936 .7076 m .72854 .67113 L .69874 .67859 L p .707 .577 .707 r
F P
0 g
s
.72854 .67113 m .73936 .7076 L .76995 .69838 L p .707 .577 .707 r
F P
0 g
s
.76995 .69838 m .75913 .6619 L .72854 .67113 L p .707 .577 .707 r
F P
0 g
s
.67531 .64142 m .66973 .58554 L .64882 .58196 L p .707 .577 .707 r
F P
0 g
s
.21444 .76847 m .20885 .75028 L .23718 .73997 L p .707 .577 .707 r
F P
0 g
s
.75913 .6619 m .76995 .69838 L .79835 .68829 L p .707 .577 .707 r
F P
0 g
s
.79835 .68829 m .78753 .65182 L .75913 .6619 L p .707 .577 .707 r
F P
0 g
s
.24486 .73762 m .23404 .70115 L .26463 .69192 L p .707 .577 .707 r
F P
0 g
s
.26463 .69192 m .27545 .7284 L .24486 .73762 L p .707 .577 .707 r
F P
0 g
s
.29738 .72266 m .30297 .74086 L .27327 .74865 L p .707 .577 .707 r
F P
0 g
s
.27327 .74865 m .26768 .73045 L .29738 .72266 L p .707 .577 .707 r
F P
0 g
s
.23718 .73997 m .24277 .75816 L .21444 .76847 L p .707 .577 .707 r
F P
0 g
s
.4106 .74571 m .4248 .24556 L .46627 .24169 L p .707 .577 .707 r
F P
0 g
s
.4248 .24556 m .4106 .74571 L .37665 .75311 L p .707 .577 .707 r
F P
0 g
s
.69874 .67859 m .70957 .71507 L .73936 .7076 L p .707 .577 .707 r
F P
0 g
s
.70957 .71507 m .69874 .67859 L .67266 .68356 L p .707 .577 .707 r
F P
0 g
s
.81298 .56905 m .81856 .62493 L .8349 .61706 L p .707 .577 .707 r
F P
0 g
s
.8349 .61706 m .82933 .56118 L .81298 .56905 L p .707 .577 .707 r
F P
0 g
s
.24277 .75816 m .23718 .73997 L .26768 .73045 L p .707 .577 .707 r
F P
0 g
s
.78753 .65182 m .79835 .68829 L .82177 .67834 L p .707 .577 .707 r
F P
0 g
s
.82177 .67834 m .81095 .64186 L .78753 .65182 L p .707 .577 .707 r
F P
0 g
s
.26768 .73045 m .27327 .74865 L .24277 .75816 L p .707 .577 .707 r
F P
0 g
s
.64882 .58196 m .6544 .63784 L .67531 .64142 L p .707 .577 .707 r
F P
0 g
s
.67266 .68356 m .68349 .72004 L .70957 .71507 L p .707 .577 .707 r
F P
0 g
s
.55519 .24567 m .54099 .74582 L .497 .74188 L p .707 .577 .707 r
F P
0 g
s
.497 .74188 m .5112 .24173 L .55519 .24567 L p .707 .577 .707 r
F P
0 g
s
.73699 .77134 m .7314 .75315 L .7017 .76094 L p .707 .577 .707 r
F P
0 g
s
.7314 .75315 m .73699 .77134 L .76749 .76183 L p .707 .577 .707 r
F P
0 g
s
.76749 .76183 m .7619 .74363 L .7314 .75315 L p .707 .577 .707 r
F P
0 g
s
.45369 .68474 m .46627 .24169 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .45207 .74184 L .4106 .74571 L p .707 .577 .707 r
F P
0 g
s
.38503 .5743 m .39061 .63018 L .4223 .62653 L p .707 .577 .707 r
F P
0 g
s
.41612 .62664 m .42261 .64852 L p .45534 .65303 L .707 .577 .707 r
F P
0 g
s
.42261 .64852 m .42694 .66312 L .43322 .66089 L p .707 .577 .707 r
F P
0 g
s
.43322 .66089 m .45534 .65303 L p .42261 .64852 L .707 .577 .707 r
F P
0 g
s
.46627 .24169 m .5112 .24173 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.45207 .74184 m .45369 .68474 L p .4582 .68999 L .707 .577 .707 r
F P
0 g
s
.7619 .74363 m .76749 .76183 L .79582 .75152 L p .707 .577 .707 r
F P
0 g
s
.79582 .75152 m .79023 .73332 L .7619 .74363 L p .707 .577 .707 r
F P
0 g
s
.7017 .76094 m .70729 .77913 L .73699 .77134 L p .707 .577 .707 r
F P
0 g
s
.6544 .63784 m .64882 .58196 L .63634 .57635 L p .707 .577 .707 r
F P
0 g
s
.5112 .24173 m .497 .74188 L .45207 .74184 L p .707 .577 .707 r
F P
0 g
s
.68349 .72004 m .67266 .68356 L .65285 .68556 L p .707 .577 .707 r
F P
0 g
s
.70729 .77913 m .7017 .76094 L .67572 .76623 L p .707 .577 .707 r
F P
0 g
s
.81095 .64186 m .82177 .67834 L .83792 .66949 L p .707 .577 .707 r
F P
0 g
s
.83792 .66949 m .8271 .63301 L .81095 .64186 L p .707 .577 .707 r
F P
0 g
s
.65285 .68556 m .66368 .72203 L .68349 .72004 L p .707 .577 .707 r
F P
0 g
s
.79023 .73332 m .79582 .75152 L .81919 .74141 L p .707 .577 .707 r
F P
0 g
s
.81919 .74141 m .8136 .72322 L .79023 .73332 L p .707 .577 .707 r
F P
0 g
s
.67572 .76623 m .68131 .78442 L .70729 .77913 L p .707 .577 .707 r
F P
0 g
s
.82933 .56118 m .8349 .61706 L .84201 .6092 L p .707 .577 .707 r
F P
0 g
s
.84201 .6092 m .83644 .55332 L .82933 .56118 L p .707 .577 .707 r
F P
0 g
s
.63634 .57635 m .64192 .63223 L .6544 .63784 L p .707 .577 .707 r
F P
0 g
s
.68131 .78442 m .67572 .76623 L .65599 .76851 L p .707 .577 .707 r
F P
0 g
s
.65599 .76851 m .66158 .78671 L .68131 .78442 L p .707 .577 .707 r
F P
0 g
s
.66368 .72203 m .65285 .68556 L .64125 .68438 L p .707 .577 .707 r
F P
0 g
s
.8136 .72322 m .81919 .74141 L .83533 .73251 L p .707 .577 .707 r
F P
0 g
s
.83533 .73251 m .82974 .71432 L .8136 .72322 L p .707 .577 .707 r
F P
0 g
s
.64192 .63223 m .63634 .57635 L .63352 .56927 L p .707 .577 .707 r
F P
0 g
s
.8271 .63301 m .83792 .66949 L .84522 .6626 L p .707 .577 .707 r
F P
0 g
s
.84522 .6626 m .8344 .62613 L .8271 .63301 L p .707 .577 .707 r
F P
0 g
s
.64125 .68438 m .65207 .72085 L .66368 .72203 L p .707 .577 .707 r
F P
0 g
s
.83644 .55332 m .84201 .6092 L .83919 .60212 L p .707 .577 .707 r
F P
0 g
s
.83919 .60212 m .83361 .54624 L .83644 .55332 L p .707 .577 .707 r
F P
0 g
s
.63352 .56927 m .63909 .62515 L .64192 .63223 L p .707 .577 .707 r
F P
0 g
s
.66158 .78671 m .65599 .76851 L .64445 .76756 L p .707 .577 .707 r
F P
0 g
s
.64445 .76756 m .65005 .78576 L .66158 .78671 L p .707 .577 .707 r
F P
0 g
s
.82974 .71432 m .83533 .73251 L .84265 .72568 L p .707 .577 .707 r
F P
0 g
s
.84265 .72568 m .83705 .70749 L .82974 .71432 L p .707 .577 .707 r
F P
0 g
s
.65207 .72085 m .64125 .68438 L .63898 .68014 L p .707 .577 .707 r
F P
0 g
s
.63909 .62515 m .63352 .56927 L .64063 .56141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63898 .68014 m .64981 .71662 L .65207 .72085 L p .707 .577 .707 r
F P
0 g
s
.8344 .62613 m .84522 .6626 L .84296 .65837 L p .707 .577 .707 r
F P
0 g
s
.84296 .65837 m .83213 .62189 L .8344 .62613 L p .707 .577 .707 r
F P
0 g
s
.83361 .54624 m .83919 .60212 L .82671 .59651 L p .707 .577 .707 r
F P
0 g
s
.82671 .59651 m .82114 .54063 L .83361 .54624 L p .707 .577 .707 r
F P
0 g
s
.64063 .56141 m .6462 .61729 L .63909 .62515 L p .707 .577 .707 r
F P
0 g
s
.65005 .78576 m .64445 .76756 L .64224 .76347 L p .707 .577 .707 r
F P
0 g
s
.64224 .76347 m .64783 .78167 L .65005 .78576 L p .707 .577 .707 r
F P
0 g
s
.83705 .70749 m .84265 .72568 L .84043 .72159 L p .707 .577 .707 r
F P
0 g
s
.84043 .72159 m .83483 .7034 L .83705 .70749 L p .707 .577 .707 r
F P
0 g
s
.64981 .71662 m .63898 .68014 L .64629 .67326 L p .707 .577 .707 r
F P
0 g
s
.6462 .61729 m .64063 .56141 L .65697 .55354 L p .707 .577 .707 r
F P
0 g
s
.39061 .63018 m .38503 .5743 L .35402 .57558 L p .707 .577 .707 r
F P
0 g
s
.4223 .62653 m .41673 .57065 L .38503 .5743 L p .707 .577 .707 r
F P
0 g
s
.41673 .57065 m .4223 .62653 L .45157 .62087 L p .707 .577 .707 r
F P
0 g
s
.45157 .62087 m .44599 .565 L .41673 .57065 L p .707 .577 .707 r
F P
0 g
s
.64629 .67326 m .65711 .70973 L .64981 .71662 L p .707 .577 .707 r
F P
0 g
s
.83213 .62189 m .84296 .65837 L .83135 .65719 L p .707 .577 .707 r
F P
0 g
s
.83135 .65719 m .82053 .62071 L .83213 .62189 L p .707 .577 .707 r
F P
0 g
s
.3596 .63146 m .35402 .57558 L .32672 .57437 L p .707 .577 .707 r
F P
0 g
s
.35402 .57558 m .3596 .63146 L .39061 .63018 L p .707 .577 .707 r
F P
0 g
s
.82114 .54063 m .82671 .59651 L .8058 .59293 L p .707 .577 .707 r
F P
0 g
s
.8058 .59293 m .80022 .53705 L .82114 .54063 L p .707 .577 .707 r
F P
0 g
s
.65697 .55354 m .66255 .60942 L .6462 .61729 L p .707 .577 .707 r
F P
0 g
s
.44599 .565 m .45157 .62087 L .47555 .61376 L p .707 .577 .707 r
F P
0 g
s
.47555 .61376 m .46997 .55788 L .44599 .565 L p .707 .577 .707 r
F P
0 g
s
.39635 .67234 m .38553 .63587 L .35573 .64333 L p .707 .577 .707 r
F P
0 g
s
.38553 .63587 m .39635 .67234 L .42694 .66312 L p .707 .577 .707 r
F P
0 g
s
.42694 .66312 m .41612 .62664 L .38553 .63587 L p .707 .577 .707 r
F P
0 g
s
.45534 .65303 m .44452 .61656 L .41612 .62664 L p .707 .577 .707 r
F P
0 g
s
.64783 .78167 m .64224 .76347 L .64955 .75664 L p .707 .577 .707 r
F P
0 g
s
.32672 .57437 m .3323 .63025 L .3596 .63146 L p .707 .577 .707 r
F P
0 g
s
.64955 .75664 m .65515 .77484 L .64783 .78167 L p .707 .577 .707 r
F P
0 g
s
.35573 .64333 m .36656 .67981 L .39635 .67234 L p .707 .577 .707 r
F P
0 g
s
.3323 .63025 m .32672 .57437 L .30581 .57079 L p .707 .577 .707 r
F P
0 g
s
.83483 .7034 m .84043 .72159 L .82889 .72064 L p .707 .577 .707 r
F P
0 g
s
.82889 .72064 m .8233 .70245 L .83483 .7034 L p .707 .577 .707 r
F P
0 g
s
.66255 .60942 m .65697 .55354 L .68095 .54643 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35573 .64333 L .35189 .64406 L p .707 .577 .707 r
F P
0 g
s
.36656 .67981 m .35189 .64406 L .36133 .67534 L .707 .577 .707 r
F
.36287 .68044 m .35869 .68154 L p .36364 .683 L F P
0 g
s
.32965 .6483 m .34048 .68478 L .36656 .67981 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .38839 .67375 L .36287 .68044 L p .707 .577 .707 r
F P
0 g
s
.39398 .69195 m .36287 .68044 L .36364 .683 L .707 .577 .707 r
F
.35189 .64406 m .32965 .6483 L p .36133 .67534 L F P
0 g
s
.38839 .67375 m .39398 .69195 L .42448 .68243 L p .707 .577 .707 r
F P
0 g
s
.42448 .68243 m .41889 .66424 L .38839 .67375 L p .707 .577 .707 r
F P
0 g
s
.41889 .66424 m .42448 .68243 L .45281 .67212 L p .707 .577 .707 r
F P
0 g
s
.45281 .67212 m .44722 .65392 L .41889 .66424 L p .707 .577 .707 r
F P
0 g
s
.65711 .70973 m .64629 .67326 L .66244 .66441 L p .707 .577 .707 r
F P
0 g
s
.44452 .61656 m .45534 .65303 L .47876 .64308 L p .707 .577 .707 r
F P
0 g
s
.47876 .64308 m .46794 .6066 L .44452 .61656 L p .707 .577 .707 r
F P
0 g
s
.35869 .68154 m .36428 .69973 L .39398 .69195 L p .707 .577 .707 r
F P
0 g
s
.82053 .62071 m .83135 .65719 L .81154 .65918 L p .707 .577 .707 r
F P
0 g
s
.81154 .65918 m .80072 .62271 L .82053 .62071 L p .707 .577 .707 r
F P
0 g
s
.66244 .66441 m .67326 .70088 L .65711 .70973 L p .707 .577 .707 r
F P
0 g
s
.46997 .55788 m .47555 .61376 L .49189 .60589 L p .707 .577 .707 r
F P
0 g
s
.49189 .60589 m .48632 .55001 L .46997 .55788 L p .707 .577 .707 r
F P
0 g
s
.80022 .53705 m .8058 .59293 L .7785 .59172 L p .707 .577 .707 r
F P
0 g
s
.7785 .59172 m .77292 .53584 L .80022 .53705 L p .707 .577 .707 r
F P
0 g
s
.36428 .69973 m .35869 .68154 L .33271 .68683 L p .707 .577 .707 r
F P
0 g
s
.30581 .57079 m .31139 .62667 L .3323 .63025 L p .707 .577 .707 r
F P
0 g
s
.44722 .65392 m .45281 .67212 L .47618 .66201 L p .707 .577 .707 r
F P
0 g
s
.47618 .66201 m .47059 .64382 L .44722 .65392 L p .707 .577 .707 r
F P
0 g
s
.33271 .68683 m .3383 .70503 L .36428 .69973 L p .707 .577 .707 r
F P
0 g
s
.68095 .54643 m .68653 .60231 L .66255 .60942 L p .707 .577 .707 r
F P
0 g
s
.34048 .68478 m .32965 .6483 L .30984 .6503 L p .707 .577 .707 r
F P
0 g
s
.68653 .60231 m .68095 .54643 L .71022 .54077 L p .707 .577 .707 r
F P
0 g
s
.46794 .6066 m .47876 .64308 L .49491 .63423 L p .707 .577 .707 r
F P
0 g
s
.49491 .63423 m .48409 .59775 L .46794 .6066 L p .707 .577 .707 r
F P
0 g
s
.31139 .62667 m .30581 .57079 L .29333 .56519 L p .707 .577 .707 r
F P
0 g
s
.30984 .6503 m .32067 .68677 L .34048 .68478 L p .707 .577 .707 r
F P
0 g
s
.65515 .77484 m .64955 .75664 L .66569 .74774 L p .707 .577 .707 r
F P
0 g
s
.77292 .53584 m .7785 .59172 L .74749 .593 L p .707 .577 .707 r
F P
0 g
s
.74749 .593 m .74191 .53712 L .77292 .53584 L p .707 .577 .707 r
F P
0 g
s
.66569 .74774 m .67128 .76594 L .65515 .77484 L p .707 .577 .707 r
F P
0 g
s
.3383 .70503 m .33271 .68683 L .31298 .68911 L p .707 .577 .707 r
F P
0 g
s
.67326 .70088 m .66244 .66441 L .68586 .65446 L p .707 .577 .707 r
F P
0 g
s
.8233 .70245 m .82889 .72064 L .80917 .72293 L p .707 .577 .707 r
F P
0 g
s
.80917 .72293 m .80357 .70473 L .8233 .70245 L p .707 .577 .707 r
F P
0 g
s
.31298 .68911 m .31857 .70731 L .3383 .70503 L p .707 .577 .707 r
F P
0 g
s
.7158 .59665 m .71022 .54077 L .74191 .53712 L p .707 .577 .707 r
F P
0 g
s
.71022 .54077 m .7158 .59665 L .68653 .60231 L p .707 .577 .707 r
F P
0 g
s
.47059 .64382 m .47618 .66201 L .49232 .65311 L p .707 .577 .707 r
F P
0 g
s
.49232 .65311 m .48673 .63492 L .47059 .64382 L p .707 .577 .707 r
F P
0 g
s
.80072 .62271 m .81154 .65918 L .78546 .66416 L p .707 .577 .707 r
F P
0 g
s
.78546 .66416 m .77464 .62768 L .80072 .62271 L p .707 .577 .707 r
F P
0 g
s
.74191 .53712 m .74749 .593 L .7158 .59665 L p .707 .577 .707 r
F P
0 g
s
.68586 .65446 m .69668 .69093 L .67326 .70088 L p .707 .577 .707 r
F P
0 g
s
.48632 .55001 m .49189 .60589 L .499 .59803 L p .707 .577 .707 r
F P
0 g
s
.499 .59803 m .49343 .54215 L .48632 .55001 L p .707 .577 .707 r
F P
0 g
s
.29333 .56519 m .29891 .62107 L .31139 .62667 L p .707 .577 .707 r
F P
0 g
s
.32067 .68677 m .30984 .6503 L .29824 .64912 L p .707 .577 .707 r
F P
0 g
s
.69668 .69093 m .68586 .65446 L .71425 .64437 L p .707 .577 .707 r
F P
0 g
s
.48409 .59775 m .49491 .63423 L .50221 .62734 L p .707 .577 .707 r
F P
0 g
s
.50221 .62734 m .49139 .59087 L .48409 .59775 L p .707 .577 .707 r
F P
0 g
s
.29824 .64912 m .30906 .68559 L .32067 .68677 L p .707 .577 .707 r
F P
0 g
s
.67128 .76594 m .66569 .74774 L .68906 .73764 L p .707 .577 .707 r
F P
0 g
s
.77464 .62768 m .78546 .66416 L .75567 .67162 L p .707 .577 .707 r
F P
0 g
s
.75567 .67162 m .74484 .63515 L .77464 .62768 L p .707 .577 .707 r
F P
0 g
s
.29891 .62107 m .29333 .56519 L .29051 .55811 L p .707 .577 .707 r
F P
0 g
s
.31857 .70731 m .31298 .68911 L .30144 .68816 L p .707 .577 .707 r
F P
0 g
s
.68906 .73764 m .69466 .75584 L .67128 .76594 L p .707 .577 .707 r
F P
0 g
s
.71425 .64437 m .72507 .68085 L .69668 .69093 L p .707 .577 .707 r
F P
0 g
s
.80357 .70473 m .80917 .72293 L .78319 .72822 L p .707 .577 .707 r
F P
0 g
s
.78319 .72822 m .77759 .71003 L .80357 .70473 L p .707 .577 .707 r
F P
0 g
s
.30144 .68816 m .30704 .70636 L .31857 .70731 L p .707 .577 .707 r
F P
0 g
s
.48673 .63492 m .49232 .65311 L .49964 .64628 L p .707 .577 .707 r
F P
0 g
s
.49964 .64628 m .49404 .62809 L .48673 .63492 L p .707 .577 .707 r
F P
0 g
s
.72507 .68085 m .71425 .64437 L .74484 .63515 L p .707 .577 .707 r
F P
0 g
s
.74484 .63515 m .75567 .67162 L .72507 .68085 L p .707 .577 .707 r
F P
0 g
s
.49343 .54215 m .499 .59803 L .49618 .59095 L p .707 .577 .707 r
F P
0 g
s
.49618 .59095 m .4906 .53507 L .49343 .54215 L p .707 .577 .707 r
F P
0 g
s
.29051 .55811 m .29608 .61399 L .29891 .62107 L p .707 .577 .707 r
F P
0 g
s
.69466 .75584 m .68906 .73764 L .71739 .72733 L p .707 .577 .707 r
F P
0 g
s
.77759 .71003 m .78319 .72822 L .75349 .73601 L p .707 .577 .707 r
F P
0 g
s
.75349 .73601 m .74789 .71781 L .77759 .71003 L p .707 .577 .707 r
F P
0 g
s
.71739 .72733 m .72298 .74552 L .69466 .75584 L p .707 .577 .707 r
F P
0 g
s
.30906 .68559 m .29824 .64912 L .29597 .64488 L p .707 .577 .707 r
F P
0 g
s
.29597 .64488 m .3068 .68136 L .30906 .68559 L p .707 .577 .707 r
F P
0 g
s
.49139 .59087 m .50221 .62734 L .49995 .62311 L p .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49139 .59087 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.4991 .62027 m .48912 .58663 L p .49971 .62222 L .707 .577 .707 r
F P
0 g
s
.48912 .58663 m .49995 .62311 L .48834 .62193 L p .707 .577 .707 r
F P
0 g
s
.48834 .62193 m .47752 .58545 L .48912 .58663 L p .707 .577 .707 r
F P
0 g
s
.4906 .53507 m .49618 .59095 L .48899 .58772 L p .707 .577 .707 r
F P
0 g
s
.48899 .58772 m .4837 .58535 L p .48509 .5752 L .707 .577 .707 r
F P
0 g
s
.48509 .5752 m .4906 .53507 L .48899 .58772 L .707 .577 .707 r
F
.49995 .62311 m .4991 .62027 L p .49971 .62222 L F P
0 g
s
.72298 .74552 m .71739 .72733 L .74789 .71781 L p .707 .577 .707 r
F P
0 g
s
.74789 .71781 m .75349 .73601 L .72298 .74552 L p .707 .577 .707 r
F P
0 g
s
.30704 .70636 m .30144 .68816 L .29923 .68407 L p .707 .577 .707 r
F P
0 g
s
.29608 .61399 m .29051 .55811 L .29762 .55025 L p .707 .577 .707 r
F P
0 g
s
.29923 .68407 m .30482 .70227 L .30704 .70636 L p .707 .577 .707 r
F P
0 g
s
.49404 .62809 m .49964 .64628 L .49742 .64219 L p .707 .577 .707 r
F P
0 g
s
.49742 .64219 m .49182 .624 L .49404 .62809 L p .707 .577 .707 r
F P
0 g
s
.4837 .58535 m .47813 .52947 L .4906 .53507 L p .707 .577 .707 r
F P
0 g
s
.29762 .55025 m .30319 .60613 L .29608 .61399 L p .707 .577 .707 r
F P
0 g
s
.3068 .68136 m .29597 .64488 L .30328 .638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30328 .638 m .3141 .67447 L .3068 .68136 L p .707 .577 .707 r
F P
0 g
s
.30319 .60613 m .29762 .55025 L .31396 .54238 L p .707 .577 .707 r
F P
0 g
s
.30482 .70227 m .29923 .68407 L .30654 .67724 L p .707 .577 .707 r
F P
0 g
s
.30654 .67724 m .31214 .69544 L .30482 .70227 L p .707 .577 .707 r
F P
0 g
s
.49182 .624 m .49742 .64219 L .48588 .64124 L p .707 .577 .707 r
F P
0 g
s
.48588 .64124 m .48029 .62305 L .49182 .624 L p .707 .577 .707 r
F P
0 g
s
.47813 .52947 m .4837 .58535 L .46279 .58176 L p .707 .577 .707 r
F P
0 g
s
.46279 .58176 m .45721 .52588 L .47813 .52947 L p .707 .577 .707 r
F P
0 g
s
.31396 .54238 m .31954 .59825 L .30319 .60613 L p .707 .577 .707 r
F P
0 g
s
.3141 .67447 m .30328 .638 L .31943 .62915 L p .707 .577 .707 r
F P
0 g
s
.31954 .59825 m .31396 .54238 L .33794 .53526 L p .707 .577 .707 r
F P
0 g
s
.47752 .58545 m .48834 .62193 L .46853 .62392 L p .707 .577 .707 r
F P
0 g
s
.46853 .62392 m .45771 .58745 L .47752 .58545 L p .707 .577 .707 r
F P
0 g
s
.31943 .62915 m .33025 .66562 L .3141 .67447 L p .707 .577 .707 r
F P
0 g
s
.31214 .69544 m .30654 .67724 L .32268 .66834 L p .707 .577 .707 r
F P
0 g
s
.32268 .66834 m .32827 .68654 L .31214 .69544 L p .707 .577 .707 r
F P
0 g
s
.45721 .52588 m .46279 .58176 L .43549 .58055 L p .707 .577 .707 r
F P
0 g
s
.43549 .58055 m .42991 .52467 L .45721 .52588 L p .707 .577 .707 r
F P
0 g
s
.48029 .62305 m .48588 .64124 L .46616 .64353 L p .707 .577 .707 r
F P
0 g
s
.46616 .64353 m .46056 .62533 L .48029 .62305 L p .707 .577 .707 r
F P
0 g
s
.33794 .53526 m .34352 .59114 L .31954 .59825 L p .707 .577 .707 r
F P
0 g
s
.34352 .59114 m .33794 .53526 L .36721 .5296 L p .707 .577 .707 r
F P
0 g
s
.33025 .66562 m .31943 .62915 L .34285 .61919 L p .707 .577 .707 r
F P
0 g
s
.42991 .52467 m .43549 .58055 L .40448 .58184 L p .707 .577 .707 r
F P
0 g
s
.40448 .58184 m .3989 .52596 L .42991 .52467 L p .707 .577 .707 r
F P
0 g
s
.46056 .62533 m .46616 .64353 L .44017 .64882 L p .707 .577 .707 r
F P
0 g
s
.43826 .62995 m .41266 .63636 L p .42885 .59885 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43458 .63063 L .43824 .62988 L p .707 .577 .707 r
F P
0 g
s
.43824 .62988 m .46056 .62533 L p .44299 .64558 L .707 .577 .707 r
F P
0 g
s
.44017 .64882 m .43824 .62988 L .44299 .64558 L .707 .577 .707 r
F
.43163 .59242 m .44245 .6289 L .43826 .62995 L p F P
0 g
s
.42885 .59885 m .43163 .59242 L .43826 .62995 L .707 .577 .707 r
F
.45771 .58745 m .46853 .62392 L .44245 .6289 L p F P
0 g
s
.44245 .6289 m .43163 .59242 L .45771 .58745 L p .707 .577 .707 r
F P
0 g
s
.34285 .61919 m .35367 .65567 L .33025 .66562 L p .707 .577 .707 r
F P
0 g
s
.37278 .58548 m .36721 .5296 L .3989 .52596 L p .707 .577 .707 r
F P
0 g
s
.36721 .5296 m .37278 .58548 L .34352 .59114 L p .707 .577 .707 r
F P
0 g
s
.32827 .68654 m .32268 .66834 L .34605 .65824 L p .707 .577 .707 r
F P
0 g
s
.3989 .52596 m .40448 .58184 L .37278 .58548 L p .707 .577 .707 r
F P
0 g
s
.34605 .65824 m .35165 .67644 L .32827 .68654 L p .707 .577 .707 r
F P
0 g
s
.35367 .65567 m .34285 .61919 L .37124 .60911 L p .707 .577 .707 r
F P
0 g
s
.41266 .63636 m .40183 .59989 L .43163 .59242 L p .707 .577 .707 r
F P
0 g
s
.37124 .60911 m .38206 .64559 L .35367 .65567 L p .707 .577 .707 r
F P
0 g
s
.35165 .67644 m .34605 .65824 L .37438 .64793 L p .707 .577 .707 r
F P
0 g
s
.38206 .64559 m .37124 .60911 L .40183 .59989 L p .707 .577 .707 r
F P
0 g
s
.40183 .59989 m .41266 .63636 L .38206 .64559 L p .707 .577 .707 r
F P
0 g
s
.43458 .63063 m .44017 .64882 L .41048 .65661 L p .707 .577 .707 r
F P
0 g
s
.41048 .65661 m .40488 .63841 L .43458 .63063 L p .707 .577 .707 r
F P
0 g
s
.37438 .64793 m .37997 .66612 L .35165 .67644 L p .707 .577 .707 r
F P
0 g
s
.37997 .66612 m .37438 .64793 L .40488 .63841 L p .707 .577 .707 r
F P
0 g
s
.40488 .63841 m .41048 .65661 L .37997 .66612 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00Mgoo20004UYF00<005YFFUH00eYF2000OWoo001dOol300000eYF001JEP0GFUH00`00FUIJEP09
FUH00`00FUH00003001jOol0075oo`<000AJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF
00=JEP@007Ioo`00KWoo0`001eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH01eYF1000
LWoo001ZOol400000eYF001JEP07FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP04001^Ool006Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00Igoo0P001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001VOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUH00000J7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001V
Ool006Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEQL000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00Hgoo00<005YFFUH01`0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8001QooaP003Moo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@003=oo`00F7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00EWoo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Yoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000`Ool005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool400000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001C
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002moo`00DWoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20002Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001BOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYF001JEP0_Ool0059oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DWoo00@005YFFUH000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P0025YF
00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH6
0002FUH00`00FUIJEP0200000eYF0000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`03001JEP00
00AJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000D000=JEP03
001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF60000UYF00D005YF
FUIJEP0002ioo`00Dgoo00@005YFFUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@00003FUH005YF00MJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH015YF
1P0000AJEP00000000=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001oogoo02aoo`00
Dgoo00@005YFFUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<0
05YF000010000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00P0000=JEP000000;Goo
001DOol2FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP03FUH50008FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF1000;Goo001DOol2FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo001DOol015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH0
0`0025YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP@000MJEP03001J
EUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00E7oo00@005YFFUH000EJEP03001JEUYF00EJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool0
04Ioo`l000=JEP03001JEUYF009JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<00004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo0010Ool60004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUH000020007FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF0000000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH6000`Ool003aoo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP06001JEP00001JEP000eYF100000=JEP00FUH01eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF3@002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF1`000UYF00@005YFFUH0031oo`00>7oo10001EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EPH000EJEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EPL000=JEP03001JEUYF00AJEP04001JEUYF000_Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04
001JEUYFFUH50005FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0000=JEP00FUH01UYF00<0
05YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000`001eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF10000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0000=JEP00FUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000MJEQ@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00AJEP04001JEUYF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH40004FUH0
0`00FUIJEP07FUH01000FUIJEUYF1`000eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP03001JEUYF008000=oo`<000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH900000eYF001JEP04FUH4
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH0
1@00FUIJEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUH00002
00000eYF001JEP08FUH00`00FUIJEP040003FUH30005FUH00`00FUIJEP02FUH01000FUIJEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00@0
05YF000002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF100015YF00<005YFFUH01EYF
100000=JEP00FUH00UYF0P0000=JEP00FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP04001JEUYFFUH30008FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00Ool0;7oo000[
Ool01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00D005YFFUIJEP0000AJEP<000MJEP03001JEUYF00=JEP8000IJEP<000=JEP03001J
EUYF00EJEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000MJEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH70003
FUH4000/Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH01P00FUH00000FUH000UJEP03001JEP000080
00EJEP<000IJEP03001JEUYF00AJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000IJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEPH000EJEP03001JEUYF009JEP04001JEUYF000/Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00=JEP8000=J
EP03001JEUYF00IJEP<00003FUH005YF009JEP<00003FUH005YF00MJEP04001JEUYFFUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH30006FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00009JEP04001JEP000006FUH00`00FUIJEP02FUH30005FUH30004
FUH00`00FUIJEP06FUH01000FUH000002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF10001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH@0002FUH30007FUH00`00FUH000020005FUH3
0007FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000<7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60008FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP04
FUH20003FUH500000eYF001JEP08FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
000bOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP800003FUH0000000<000EJEP@000IJEP03001J
EP00008000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP@000MJEP03
001JEUYF00IJEP03001JEUYF009JEP8003Eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH015YF00<005YF00001000
00=JEP00FUH01eYF1@000eYF10001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;7oo00@005YF
FUH000=JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@00004FUH005YF0002
FUH01000FUIJEUYF10001UYF00<005YFFUH01EYF20002UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF
00EJEP03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Uoo`00;7oo00@005YF
FUH000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP80009JEP04001J
EP000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH500000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
1EYF00<005YFFUH015YF0`002EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00?7oo000]Ool2FUH0
1000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00@005YF001J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00@00004FUH000000002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
1EYF001JEUYF000015YF00<005YFFUH00UYF0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YF00000P00?Woo000]Ool2FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00
FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP800005FUH005YFFUH00005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01EYF
0`00@Goo000]Ool015YF001JEP001EYF00<005YFFUH01EYF00<005YFFUH00`0025YF00<005YFFUH0
1EYF00H005YF000005YF0006FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
0002FUH00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000?Ool4000aOol0
02eoo`04001JEUYF0005FUH00`00FUIJEP05FUH300000eYF001JEP08FUH00`00FUIJEP06FUH01P00
FUH00000FUH000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUH00002000:Ool7
0002FUH01000FUH00000;goo000]Ool01@00FUIJEUYF000015YF00<005YFFUH00eYF0`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000IJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00Qoo`D000=JEP03001JEUYF00=JEP04001JEUYF000_Ool002eoo`05001JEUYFFUH00005FUH00`00
FUH000020007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP040009Ool300000eYF001JEP05FUH00`00FUIJEP04FUH00`00FUH0000_Ool0
02ioo`800003FUH005YF00AJEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEPD0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP800003FUH005YF00EJEP04001JEUYFFUH6000:Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;Woo000`Ool400000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00001P0000=JEP00FUH00UYF1`002goo10001eYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH007oo02eoo`00<goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF1P000eYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH50003FUH01000FUIJEP001goo10000UYF00<005YFFUH01eYF00<005YFFUH0
0eYF1@000eYF1000;Goo000aOol30007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH500000eYF001J
EP06FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF
001JEP0000IJEP03001JEUYF00=JEP03001JEUYF0080009oo`@000MJEP03001JEUYF00IJEP03001J
EP0000D00003FUH005YF00=JEP04001JEUYF000]Ool002moo`8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP05FUH30002Ool20003FUH00`00FUIJEP03FUH2000^
Ool002ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP040002Ool30006FUH01000FUIJEUYF0P00;goo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH01EYF100015YF00<005YFFUH01eYF00@005YFFUIJEPP0009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03
001JEUYF00EJEPD000Aoo`800003FUH005YF00IJEP04001JEP00000aOol002eoo`04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP04FUH7000015YF000000000UYF
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00MJEQ8000UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00<000UJEP03001JEUYF
00@000Ioo`<000AJEP03001JEUYF00AJEP8003=oo`00;Goo0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH010001EYF0`000eYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000YJEP03001JEUYF00EJEPH000=JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP<000=JEP03
001JEUYF00EJEP@000Moo`<000MJEP03001JEUYF009JEP8003Eoo`00;Woo00<005YF000015YF00<0
05YFFUH015YF100015YF00<005YFFUH01EYF100000=JEP00FUH015YF0`001EYF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH015YF1P0015YF00<005YFFUH02EYF00<005YFFUH02UYF1`0025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF
0P0027oo0`0000=JEP00FUH025YF00@005YF000003Moo`00;Woo00@005YFFUH000=JEP03001JEUYF
009JEP<000MJEP03001JEUYF00=JEP8000IJEP03001JEP0000800003FUH005YF00IJEP80009JEP03
001JEUYF00AJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJ
EPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH30007FUH00`00FUH0
00020007Ool30005FUH00`00FUIJEP05FUH3000iOol002ioo`04001JEUYF0004FUH01P00FUH00000
FUH000UJEP03001JEP00008000MJEP@000=JEP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEP@0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPD000MJEP03
001JEUYF009JEP8000AJEP<0009JEP03001JEUYF00AJEP<0009JEP03001oogoo009oo`<000QJEP03
001JEUYF00=JEP8003aoo`00;Woo0P0000=JEP00FUH00eYF0P000eYF00<005YFFUH01UYF0`0000=J
EP00FUH015YF10001eYF00@005YFFUIJEP80009oo`04001JEUYF0003FUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP02FUH20002FUH30005FUH01000FUIJEUYF0P000eYF0P0000=oo`0000000P0000=JEP00FUH0
2EYF00<005YF00000P00?Woo000_Ool01@00FUIJEP00FUH00P001UYF00<005YFFUH00UYF0`001EYF
1@000UYF00<005YFFUH01UYF00@005YF000000Aoo`05001JEUYF001JEP020008FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001J
EP03FUH400000eYF00000005FUH01000FUH000000UYF1P001UYF00<005YFFUH01UYF0`00@Goo000_
Ool00`00FUIJEP030007FUH00`00FUH000020005FUH40006FUH00`00FUIJEP05FUH30006Ool00`00
FUIJEP0200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000UYF00@005YFFUH000AJEPH000=JEP03
001JEUYF00IJEP03001JEUYF00=JEP<004Aoo`00;goo0`000eYF00<005YFFUH015YF0P000eYF1@00
00=JEP00FUH025YF00<005YFFUH00UYF0P002Goo00<005YF00000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP80009JEP04001JEUYF0003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
00000P00Agoo000_Ool20004FUH00`00FUIJEP02FUH200000eYF000000030006FUH30006FUH00`00
FUH00002000;Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP030003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001:Ool002ioo`03001JEP0000EJEP03001JEP0000@0
0003FUH005YF00MJEPD000AJEP<000ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEP000003FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP04001=Ool002io
o`04001JEUYF0003FUH40006FUH00`00FUIJEP05FUH9000AOol00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF00001EYF00<005YFFUH015YF1000DGoo000^
Ool01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF1@005Goo00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJEP05001JEUYFFUH00004FUH00`00
FUIJEP04001EOol002moo`04001JEP000005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000GOol0
0`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00FUH03`00FGoo000_Ool2
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUH00002000MOol00`00FUIJEP02FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP02001XOol002moo`04001JEUYF0006FUH01000FUIJEUYF
1@008Goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00003Woo1000F7oo000_Ool2
0002FUH01000FUIJEUYF1P00:7oo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P002Woo1@000UYF00@005YF0000
05Ioo`00<7oo1`00<7oo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol01Goo100000=JEP00FUH015YF
00@005YFFUH005Ioo`00JGoo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`@000EJEP03001JEUYF00=JEP04
001JEUYF001FOol006aoo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo001_Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo001c
Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP080002FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH<001DOol007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF
00AJEP`000MJEP03001JEUYF00IJEP03001JEP0000D00003FUH005YF00=JEP04001JEUYF001DOol0
085ooaX000Ioo`800003FUH005YF00QJEP03001JEUYF00EJEP<0009oo`8000=JEP03001JEUYF00=J
EP8005Eoo`00WWoo0`0015YF00<005YFFUH01eYF00<005YFFUH010000Woo0`001UYF00@005YFFUIJ
EP8005Ioo`00W7oo0P001eYF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF0000
05Qoo`00VWoo0`0025YF00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0P00FWoo002H
Ool20003FUH00`00FUIJEP06FUH00`00FUH000020005Ool30007FUH00`00FUIJEP02FUH2001LOol0
09Ioo`8000EJEP03001JEUYF00EJEP<000Eoo`<00003FUH005YF00QJEP04001JEP00001NOol009Ao
o`<000IJEP03001JEUYF00=JEP8000Eoo`<000EJEP03001JEUYF00EJEP<0061oo`00TWoo0P000UYF
00<005YFFUH01EYF00<005YF00000P0017oo0`0025YF00<005YFFUH00eYF0P00Hgoo002AOol00`00
FUIJEP03FUH00`00FUIJEP03FUH30003Ool400000eYF001JEP09FUH00`00FUH00002001UOol0091o
o`8000EJEP03001JEP0000<0009oo`@000IJEP03001JEUYF00IJEP<006Qoo`00Sgoo00@005YFFUH0
00AJEP80009oo`@00003FUH005YF00MJEP03001JEUYF00=JEP<006]oo`00Sgoo00@005YFFUH000=J
EPD000IJEP03001JEUYF00IJEP03001JEP00008006ioo`00T7oo00<005YFFUH00`000eYF00<005YF
FUH01EYF00<005YFFUH01EYF0`00LGoo002@Ool00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00
FUIJEP04001dOol0095oo`04FUH005YF0005FUH00`00FUIJEP04FUH4001hOol0095oo`05001JEUYF
FUH00004FUH00`00FUIJEP04001lOol0095oo``0081oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59635 .73958 m .5929 .68374 L .56178 .6838 L p .707 .577 .707 r
F P
0 g
s
.5929 .68374 m .59635 .73958 L .62813 .73703 L p .707 .577 .707 r
F P
0 g
s
.62813 .73703 m .62468 .68119 L .5929 .68374 L p .707 .577 .707 r
F P
0 g
s
.62468 .68119 m .62813 .73703 L .65746 .73224 L p .707 .577 .707 r
F P
0 g
s
.65746 .73224 m .65401 .6764 L .62468 .68119 L p .707 .577 .707 r
F P
0 g
s
.56523 .73964 m .56178 .6838 L .53439 .68138 L p .707 .577 .707 r
F P
0 g
s
.56178 .6838 m .56523 .73964 L .59635 .73958 L p .707 .577 .707 r
F P
0 g
s
.65401 .6764 m .65746 .73224 L .68149 .72569 L p .707 .577 .707 r
F P
0 g
s
.68149 .72569 m .67804 .66985 L .65401 .6764 L p .707 .577 .707 r
F P
0 g
s
.53439 .68138 m .53784 .73721 L .56523 .73964 L p .707 .577 .707 r
F P
0 g
s
.60021 .80373 m .59345 .76662 L .56281 .77053 L p .707 .577 .707 r
F P
0 g
s
.59345 .76662 m .60021 .80373 L .63157 .79771 L p .707 .577 .707 r
F P
0 g
s
.63157 .79771 m .62481 .7606 L .59345 .76662 L p .707 .577 .707 r
F P
0 g
s
.53784 .73721 m .53439 .68138 L .51339 .6767 L p .707 .577 .707 r
F P
0 g
s
.62481 .7606 m .63157 .79771 L .66057 .79017 L p .707 .577 .707 r
F P
0 g
s
.66057 .79017 m .65382 .75306 L .62481 .7606 L p .707 .577 .707 r
F P
0 g
s
.56281 .77053 m .56957 .80764 L .60021 .80373 L p .707 .577 .707 r
F P
0 g
s
.56957 .80764 m .56281 .77053 L .53588 .77194 L p .707 .577 .707 r
F P
0 g
s
.67804 .66985 m .68149 .72569 L .69785 .71801 L p .707 .577 .707 r
F P
0 g
s
.69785 .71801 m .6944 .66217 L .67804 .66985 L p .707 .577 .707 r
F P
0 g
s
.65382 .75306 m .66057 .79017 L .68438 .78185 L p .707 .577 .707 r
F P
0 g
s
.68438 .78185 m .67763 .74474 L .65382 .75306 L p .707 .577 .707 r
F P
0 g
s
.51339 .6767 m .51684 .73253 L .53784 .73721 L p .707 .577 .707 r
F P
0 g
s
.53588 .77194 m .54264 .80905 L .56957 .80764 L p .707 .577 .707 r
F P
0 g
s
.59875 .859 m .59526 .84046 L .56465 .84457 L p .707 .577 .707 r
F P
0 g
s
.59526 .84046 m .59875 .859 L .63008 .8528 L p .707 .577 .707 r
F P
0 g
s
.63008 .8528 m .62658 .83426 L .59526 .84046 L p .707 .577 .707 r
F P
0 g
s
.62658 .83426 m .63008 .8528 L .65905 .84512 L p .707 .577 .707 r
F P
0 g
s
.65905 .84512 m .65556 .82658 L .62658 .83426 L p .707 .577 .707 r
F P
0 g
s
.56465 .84457 m .56815 .86311 L .59875 .859 L p .707 .577 .707 r
F P
0 g
s
.51684 .73253 m .51339 .6767 L .50084 .67022 L p .707 .577 .707 r
F P
0 g
s
.54264 .80905 m .53588 .77194 L .5153 .77073 L p .707 .577 .707 r
F P
0 g
s
.56815 .86311 m .56465 .84457 L .53776 .84619 L p .707 .577 .707 r
F P
0 g
s
.53776 .84619 m .54125 .86473 L .56815 .86311 L p .707 .577 .707 r
F P
0 g
s
.67763 .74474 m .68438 .78185 L .70067 .77356 L p .707 .577 .707 r
F P
0 g
s
.70067 .77356 m .69391 .73645 L .67763 .74474 L p .707 .577 .707 r
F P
0 g
s
.65556 .82658 m .65905 .84512 L .68284 .83671 L p .707 .577 .707 r
F P
0 g
s
.68284 .83671 m .67935 .81816 L .65556 .82658 L p .707 .577 .707 r
F P
0 g
s
.5153 .77073 m .52206 .80784 L .54264 .80905 L p .707 .577 .707 r
F P
0 g
s
.6944 .66217 m .69785 .71801 L .70494 .70996 L p .707 .577 .707 r
F P
0 g
s
.70494 .70996 m .70149 .65412 L .6944 .66217 L p .707 .577 .707 r
F P
0 g
s
.50084 .67022 m .50429 .72606 L .51684 .73253 L p .707 .577 .707 r
F P
0 g
s
.54125 .86473 m .53776 .84619 L .51722 .84516 L p .707 .577 .707 r
F P
0 g
s
.51722 .84516 m .52071 .8637 L .54125 .86473 L p .707 .577 .707 r
F P
0 g
s
.52206 .80784 m .5153 .77073 L .50309 .76701 L p .707 .577 .707 r
F P
0 g
s
.67935 .81816 m .68284 .83671 L .69912 .82839 L p .707 .577 .707 r
F P
0 g
s
.69912 .82839 m .69563 .80984 L .67935 .81816 L p .707 .577 .707 r
F P
0 g
s
.50429 .72606 m .50084 .67022 L .49797 .66258 L p .707 .577 .707 r
F P
0 g
s
.50309 .76701 m .50985 .80412 L .52206 .80784 L p .707 .577 .707 r
F P
0 g
s
.69391 .73645 m .70067 .77356 L .70783 .76612 L p .707 .577 .707 r
F P
0 g
s
.70783 .76612 m .70108 .72901 L .69391 .73645 L p .707 .577 .707 r
F P
0 g
s
.49797 .66258 m .50142 .71842 L .50429 .72606 L p .707 .577 .707 r
F P
0 g
s
.70149 .65412 m .70494 .70996 L .70207 .70232 L p .707 .577 .707 r
F P
0 g
s
.70207 .70232 m .69862 .64648 L .70149 .65412 L p .707 .577 .707 r
F P
0 g
s
.52071 .8637 m .51722 .84516 L .50503 .84158 L p .707 .577 .707 r
F P
0 g
s
.50503 .84158 m .50852 .86012 L .52071 .8637 L p .707 .577 .707 r
F P
0 g
s
.69563 .80984 m .69912 .82839 L .7063 .82098 L p .707 .577 .707 r
F P
0 g
s
.7063 .82098 m .7028 .80243 L .69563 .80984 L p .707 .577 .707 r
F P
0 g
s
.50985 .80412 m .50309 .76701 L .50044 .76113 L p .707 .577 .707 r
F P
0 g
s
.48265 .82174 m .49143 .32088 L .44743 .31742 L p .707 .577 .707 r
F P
0 g
s
.50142 .71842 m .49797 .66258 L .50506 .65453 L p .707 .577 .707 r
F P
0 g
s
.50044 .76113 m .50719 .79824 L .50985 .80412 L p .707 .577 .707 r
F P
0 g
s
.50506 .65453 m .50851 .71036 L .50142 .71842 L p .707 .577 .707 r
F P
0 g
s
.50719 .79824 m .50044 .76113 L .5076 .75369 L p .707 .577 .707 r
F P
0 g
s
.50851 .71036 m .50506 .65453 L .52142 .64685 L p .707 .577 .707 r
F P
0 g
s
.5076 .75369 m .51436 .7908 L .50719 .79824 L p .707 .577 .707 r
F P
0 g
s
.52142 .64685 m .52487 .70269 L .50851 .71036 L p .707 .577 .707 r
F P
0 g
s
.51436 .7908 m .5076 .75369 L .52389 .7454 L p .707 .577 .707 r
F P
0 g
s
.52389 .7454 m .53064 .78251 L .51436 .7908 L p .707 .577 .707 r
F P
0 g
s
.51306 .84693 m .50957 .82839 L .52585 .82007 L p .707 .577 .707 r
F P
0 g
s
.52585 .82007 m .52934 .83861 L .51306 .84693 L p .707 .577 .707 r
F P
0 g
s
.52934 .83861 m .52585 .82007 L .54964 .81165 L p .707 .577 .707 r
F P
0 g
s
.49143 .32088 m .48265 .82174 L .52759 .82134 L p .707 .577 .707 r
F P
0 g
s
.52487 .70269 m .52142 .64685 L .54545 .6403 L p .707 .577 .707 r
F P
0 g
s
.54545 .6403 m .5489 .69613 L .52487 .70269 L p .707 .577 .707 r
F P
0 g
s
.53064 .78251 m .52389 .7454 L .5477 .73708 L p .707 .577 .707 r
F P
0 g
s
.52759 .82134 m .53637 .32048 L .49143 .32088 L p .707 .577 .707 r
F P
0 g
s
.5489 .69613 m .54545 .6403 L .57478 .63551 L p .707 .577 .707 r
F P
0 g
s
.57478 .63551 m .57823 .69135 L .5489 .69613 L p .707 .577 .707 r
F P
0 g
s
.5477 .73708 m .55445 .77419 L .53064 .78251 L p .707 .577 .707 r
F P
0 g
s
.55445 .77419 m .5477 .73708 L .5767 .72954 L p .707 .577 .707 r
F P
0 g
s
.54964 .81165 m .55313 .8302 L .52934 .83861 L p .707 .577 .707 r
F P
0 g
s
.5767 .72954 m .58346 .76665 L .55445 .77419 L p .707 .577 .707 r
F P
0 g
s
.55313 .8302 m .54964 .81165 L .57861 .80397 L p .707 .577 .707 r
F P
0 g
s
.57861 .80397 m .58211 .82252 L .55313 .8302 L p .707 .577 .707 r
F P
0 g
s
.53637 .32048 m .52759 .82134 L .56907 .81713 L p .707 .577 .707 r
F P
0 g
s
.56907 .81713 m .57784 .31627 L .53637 .32048 L p .707 .577 .707 r
F P
0 g
s
.70108 .72901 m .70783 .76612 L .70518 .76025 L p .707 .577 .707 r
F P
0 g
s
.70518 .76025 m .69843 .72314 L .70108 .72901 L p .707 .577 .707 r
F P
0 g
s
.43865 .81828 m .44743 .31742 L .40867 .31044 L p .707 .577 .707 r
F P
0 g
s
.44743 .31742 m .43865 .81828 L .48265 .82174 L p .707 .577 .707 r
F P
0 g
s
.69862 .64648 m .70207 .70232 L .68952 .69584 L p .707 .577 .707 r
F P
0 g
s
.68952 .69584 m .68607 .64 L .69862 .64648 L p .707 .577 .707 r
F P
0 g
s
.50852 .86012 m .50503 .84158 L .50239 .8358 L p .707 .577 .707 r
F P
0 g
s
.57823 .69135 m .57478 .63551 L .60657 .63296 L p .707 .577 .707 r
F P
0 g
s
.60657 .63296 m .61002 .6888 L .57823 .69135 L p .707 .577 .707 r
F P
0 g
s
.58346 .76665 m .5767 .72954 L .60806 .72353 L p .707 .577 .707 r
F P
0 g
s
.60806 .72353 m .61482 .76064 L .58346 .76665 L p .707 .577 .707 r
F P
0 g
s
.58211 .82252 m .57861 .80397 L .60994 .79777 L p .707 .577 .707 r
F P
0 g
s
.60994 .79777 m .61343 .81632 L .58211 .82252 L p .707 .577 .707 r
F P
0 g
s
.57784 .31627 m .56907 .81713 L .60302 .80951 L p .707 .577 .707 r
F P
0 g
s
.60302 .80951 m .6118 .30865 L .57784 .31627 L p .707 .577 .707 r
F P
0 g
s
.50239 .8358 m .50589 .85434 L .50852 .86012 L p .707 .577 .707 r
F P
0 g
s
.7028 .80243 m .7063 .82098 L .70366 .8152 L p .707 .577 .707 r
F P
0 g
s
.70366 .8152 m .70017 .79665 L .7028 .80243 L p .707 .577 .707 r
F P
0 g
s
.39989 .8113 m .40867 .31044 L .37895 .30062 L p .707 .577 .707 r
F P
0 g
s
.40867 .31044 m .39989 .8113 L .43865 .81828 L p .707 .577 .707 r
F P
0 g
s
.25334 .71861 m .24989 .66278 L .21878 .66284 L p .707 .577 .707 r
F P
0 g
s
.24989 .66278 m .25334 .71861 L .28512 .71606 L p .707 .577 .707 r
F P
0 g
s
.28512 .71606 m .28167 .66023 L .24989 .66278 L p .707 .577 .707 r
F P
0 g
s
.28167 .66023 m .28512 .71606 L .31446 .71128 L p .707 .577 .707 r
F P
0 g
s
.31446 .71128 m .31101 .65544 L .28167 .66023 L p .707 .577 .707 r
F P
0 g
s
.69843 .72314 m .70518 .76025 L .69297 .75652 L p .707 .577 .707 r
F P
0 g
s
.69297 .75652 m .68621 .71941 L .69843 .72314 L p .707 .577 .707 r
F P
0 g
s
.22222 .71868 m .21878 .66284 L .19138 .66041 L p .707 .577 .707 r
F P
0 g
s
.21878 .66284 m .22222 .71868 L .25334 .71861 L p .707 .577 .707 r
F P
0 g
s
.68607 .64 m .68952 .69584 L .66852 .69116 L p .707 .577 .707 r
F P
0 g
s
.66852 .69116 m .66507 .63532 L .68607 .64 L p .707 .577 .707 r
F P
0 g
s
.31101 .65544 m .31446 .71128 L .33848 .70472 L p .707 .577 .707 r
F P
0 g
s
.33848 .70472 m .33503 .64889 L .31101 .65544 L p .707 .577 .707 r
F P
0 g
s
.63768 .63289 m .64113 .68873 L .61002 .6888 L p .707 .577 .707 r
F P
0 g
s
.61002 .6888 m .60657 .63296 L .63768 .63289 L p .707 .577 .707 r
F P
0 g
s
.6387 .71962 m .64546 .75673 L .61482 .76064 L p .707 .577 .707 r
F P
0 g
s
.61482 .76064 m .60806 .72353 L .6387 .71962 L p .707 .577 .707 r
F P
0 g
s
.61343 .81632 m .60994 .79777 L .64054 .79366 L p .707 .577 .707 r
F P
0 g
s
.6118 .30865 m .60302 .80951 L .62613 .79924 L p .707 .577 .707 r
F P
0 g
s
.62613 .79924 m .6349 .29837 L .6118 .30865 L p .707 .577 .707 r
F P
0 g
s
.50589 .85434 m .50239 .8358 L .50957 .82839 L p .707 .577 .707 r
F P
0 g
s
.2572 .76787 m .25045 .73076 L .2198 .73467 L p .707 .577 .707 r
F P
0 g
s
.25045 .73076 m .2572 .76787 L .28856 .76186 L p .707 .577 .707 r
F P
0 g
s
.28856 .76186 m .2818 .72475 L .25045 .73076 L p .707 .577 .707 r
F P
0 g
s
.2818 .72475 m .28856 .76186 L .31756 .75432 L p .707 .577 .707 r
F P
0 g
s
.31756 .75432 m .31081 .71721 L .2818 .72475 L p .707 .577 .707 r
F P
0 g
s
.50957 .82839 m .51306 .84693 L .50589 .85434 L p .707 .577 .707 r
F P
0 g
s
.19138 .66041 m .19483 .71625 L .22222 .71868 L p .707 .577 .707 r
F P
0 g
s
.19483 .71625 m .19138 .66041 L .17038 .65573 L p .707 .577 .707 r
F P
0 g
s
.70017 .79665 m .70366 .8152 L .69147 .81162 L p .707 .577 .707 r
F P
0 g
s
.69147 .81162 m .68798 .79307 L .70017 .79665 L p .707 .577 .707 r
F P
0 g
s
.2198 .73467 m .22656 .77178 L .2572 .76787 L p .707 .577 .707 r
F P
0 g
s
.22656 .77178 m .2198 .73467 L .19287 .73609 L p .707 .577 .707 r
F P
0 g
s
.37017 .80149 m .37895 .30062 L .36118 .28893 L p .707 .577 .707 r
F P
0 g
s
.37895 .30062 m .37017 .80149 L .39989 .8113 L p .707 .577 .707 r
F P
0 g
s
.25574 .79587 m .25225 .77733 L .22164 .78144 L p .707 .577 .707 r
F P
0 g
s
.25225 .77733 m .25574 .79587 L .28707 .78967 L p .707 .577 .707 r
F P
0 g
s
.28707 .78967 m .28357 .77113 L .25225 .77733 L p .707 .577 .707 r
F P
0 g
s
.31081 .71721 m .31756 .75432 L .34137 .746 L p .707 .577 .707 r
F P
0 g
s
.34137 .746 m .33462 .70889 L .31081 .71721 L p .707 .577 .707 r
F P
0 g
s
.28357 .77113 m .28707 .78967 L .31604 .78199 L p .707 .577 .707 r
F P
0 g
s
.31604 .78199 m .31255 .76344 L .28357 .77113 L p .707 .577 .707 r
F P
0 g
s
.33503 .64889 m .33848 .70472 L .35484 .69705 L p .707 .577 .707 r
F P
0 g
s
.35484 .69705 m .35139 .64121 L .33503 .64889 L p .707 .577 .707 r
F P
0 g
s
.19287 .73609 m .19963 .7732 L .22656 .77178 L p .707 .577 .707 r
F P
0 g
s
.22164 .78144 m .22514 .79998 L .25574 .79587 L p .707 .577 .707 r
F P
0 g
s
.68621 .71941 m .69297 .75652 L .67239 .75531 L p .707 .577 .707 r
F P
0 g
s
.67239 .75531 m .66563 .7182 L .68621 .71941 L p .707 .577 .707 r
F P
0 g
s
.66507 .63532 m .66852 .69116 L .64113 .68873 L p .707 .577 .707 r
F P
0 g
s
.64113 .68873 m .63768 .63289 L .66507 .63532 L p .707 .577 .707 r
F P
0 g
s
.17038 .65573 m .17383 .71157 L .19483 .71625 L p .707 .577 .707 r
F P
0 g
s
.22514 .79998 m .22164 .78144 L .19475 .78306 L p .707 .577 .707 r
F P
0 g
s
.19475 .78306 m .19825 .8016 L .22514 .79998 L p .707 .577 .707 r
F P
0 g
s
.31255 .76344 m .31604 .78199 L .33984 .77357 L p .707 .577 .707 r
F P
0 g
s
.33984 .77357 m .33634 .75503 L .31255 .76344 L p .707 .577 .707 r
F P
0 g
s
.19963 .7732 m .19287 .73609 L .1723 .73488 L p .707 .577 .707 r
F P
0 g
s
.17383 .71157 m .17038 .65573 L .15783 .64926 L p .707 .577 .707 r
F P
0 g
s
.33462 .70889 m .34137 .746 L .35766 .73771 L p .707 .577 .707 r
F P
0 g
s
.35766 .73771 m .3509 .7006 L .33462 .70889 L p .707 .577 .707 r
F P
0 g
s
.1723 .73488 m .17905 .77199 L .19963 .7732 L p .707 .577 .707 r
F P
0 g
s
.6349 .29837 m .62613 .79924 L .63613 .7873 L p .707 .577 .707 r
F P
0 g
s
.63613 .7873 m .64491 .28644 L .6349 .29837 L p .707 .577 .707 r
F P
0 g
s
.68798 .79307 m .69147 .81162 L .67093 .81059 L p .707 .577 .707 r
F P
0 g
s
.67093 .81059 m .66744 .79204 L .68798 .79307 L p .707 .577 .707 r
F P
0 g
s
.19825 .8016 m .19475 .78306 L .17421 .78203 L p .707 .577 .707 r
F P
0 g
s
.66563 .7182 m .67239 .75531 L .64546 .75673 L p .707 .577 .707 r
F P
0 g
s
.64546 .75673 m .6387 .71962 L .66563 .7182 L p .707 .577 .707 r
F P
0 g
s
.17421 .78203 m .1777 .80057 L .19825 .8016 L p .707 .577 .707 r
F P
0 g
s
.35139 .64121 m .35484 .69705 L .36162 .68934 L p .707 .577 .707 r
F P
0 g
s
.36161 .68754 m .35139 .64121 L .36162 .68934 L .707 .577 .707 r
F
.36193 .68899 m .35848 .63316 L .35139 .64121 L p F P
0 g
s
.33634 .75503 m .33984 .77357 L .35612 .76525 L p .707 .577 .707 r
F P
0 g
s
.35612 .76525 m .35262 .74671 L .33634 .75503 L p .707 .577 .707 r
F P
0 g
s
.3509 .7006 m .35766 .73771 L .36203 .73317 L p .707 .577 .707 r
F P
0 g
s
.36203 .73317 m .36482 .73027 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36165 .7235 m .3509 .7006 L .36203 .73317 L .707 .577 .707 r
F
.35464 .54447 m .35951 .38388 L .35709 .27652 L F
.35807 .69316 m .3509 .7006 L p .36165 .7235 L F P
0 g
s
.36482 .73027 m .36112 .7099 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.36112 .7099 m .35807 .69316 L p .36165 .7235 L .707 .577 .707 r
F P
0 g
s
.35262 .74671 m .35612 .76525 L .36329 .75784 L p .707 .577 .707 r
F P
0 g
s
.36329 .75784 m .35979 .7393 L .35262 .74671 L p .707 .577 .707 r
F P
0 g
s
.35561 .62552 m .35906 .68135 L .34652 .67488 L p .707 .577 .707 r
F P
0 g
s
.34652 .67488 m .34307 .61904 L .35561 .62552 L p .707 .577 .707 r
F P
0 g
s
.35542 .68728 m .3582 .70256 L p .34996 .72067 L .707 .577 .707 r
F P
0 g
s
.3582 .70256 m .36217 .72439 L .35677 .72275 L p .707 .577 .707 r
F P
0 g
s
.35677 .72275 m .34996 .72067 L p .3582 .70256 L .707 .577 .707 r
F P
0 g
s
.34996 .72067 m .3432 .68356 L .35542 .68728 L p .707 .577 .707 r
F P
0 g
s
.35716 .73352 m .36065 .75206 L .34846 .74848 L p .707 .577 .707 r
F P
0 g
s
.34846 .74848 m .34497 .72994 L .35716 .73352 L p .707 .577 .707 r
F P
0 g
s
.3432 .68356 m .34996 .72067 L .32938 .71946 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35211 .78892 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35211 .78892 m .3524 .7898 L p .35245 .78406 L .707 .577 .707 r
F P
0 g
s
.35245 .78406 m .35464 .54447 L .35211 .78892 L .707 .577 .707 r
F
.35709 .27652 m .35309 .50482 L p .35464 .54447 L F P
0 g
s
.35309 .50482 m .34831 .77738 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.3524 .7898 m .35606 .58077 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35606 .58077 m .35951 .38388 L p .35464 .54447 L .707 .577 .707 r
F P
0 g
s
.35951 .38388 m .36118 .28893 L .35881 .28173 L p .707 .577 .707 r
F P
0 g
s
.35881 .28173 m .35709 .27652 L p .35951 .38388 L .707 .577 .707 r
F P
0 g
s
.36162 .68934 m .36193 .68899 L p .36161 .68754 L .707 .577 .707 r
F P
0 g
s
.15783 .64926 m .16128 .70509 L .17383 .71157 L p .707 .577 .707 r
F P
0 g
s
.17905 .77199 m .1723 .73488 L .16008 .73115 L p .707 .577 .707 r
F P
0 g
s
.35848 .63316 m .36193 .68899 L .35906 .68135 L p .707 .577 .707 r
F P
0 g
s
.35906 .68135 m .35561 .62552 L .35848 .63316 L p .707 .577 .707 r
F P
0 g
s
.35807 .69316 m .36482 .73027 L .36217 .72439 L p .707 .577 .707 r
F P
0 g
s
.36217 .72439 m .35542 .68728 L .35807 .69316 L p .707 .577 .707 r
F P
0 g
s
.35979 .7393 m .36329 .75784 L .36065 .75206 L p .707 .577 .707 r
F P
0 g
s
.36065 .75206 m .35716 .73352 L .35979 .7393 L p .707 .577 .707 r
F P
0 g
s
.36118 .28893 m .3524 .7898 L .37017 .80149 L p .707 .577 .707 r
F P
0 g
s
.16128 .70509 m .15783 .64926 L .15496 .64162 L p .707 .577 .707 r
F P
0 g
s
.16008 .73115 m .16684 .76826 L .17905 .77199 L p .707 .577 .707 r
F P
0 g
s
.66744 .79204 m .67093 .81059 L .64404 .8122 L p .707 .577 .707 r
F P
0 g
s
.64404 .8122 m .64054 .79366 L .66744 .79204 L p .707 .577 .707 r
F P
0 g
s
.1777 .80057 m .17421 .78203 L .16202 .77845 L p .707 .577 .707 r
F P
0 g
s
.16202 .77845 m .16551 .79699 L .1777 .80057 L p .707 .577 .707 r
F P
0 g
s
.15496 .64162 m .15841 .69745 L .16128 .70509 L p .707 .577 .707 r
F P
0 g
s
.64491 .28644 m .63613 .7873 L .63204 .77489 L p .707 .577 .707 r
F P
0 g
s
.63204 .77489 m .64082 .27402 L .64491 .28644 L p .707 .577 .707 r
F P
0 g
s
.64054 .79366 m .64404 .8122 L .61343 .81632 L p .707 .577 .707 r
F P
0 g
s
.16684 .76826 m .16008 .73115 L .15743 .72528 L p .707 .577 .707 r
F P
0 g
s
.15743 .72528 m .16418 .76239 L .16684 .76826 L p .707 .577 .707 r
F P
0 g
s
.15841 .69745 m .15496 .64162 L .16205 .63356 L p .707 .577 .707 r
F P
0 g
s
.16551 .79699 m .16202 .77845 L .15938 .77267 L p .707 .577 .707 r
F P
0 g
s
.34831 .77738 m .35709 .27652 L .36709 .26458 L p .707 .577 .707 r
F P
0 g
s
.15938 .77267 m .16288 .79121 L .16551 .79699 L p .707 .577 .707 r
F P
0 g
s
.16205 .63356 m .1655 .6894 L .15841 .69745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16418 .76239 m .15743 .72528 L .16459 .71784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16459 .71784 m .17135 .75495 L .16418 .76239 L p .707 .577 .707 r
F P
0 g
s
.1655 .6894 m .16205 .63356 L .17841 .62588 L p .707 .577 .707 r
F P
0 g
s
.64082 .27402 m .63204 .77489 L .61427 .7632 L p .707 .577 .707 r
F P
0 g
s
.61427 .7632 m .62305 .26233 L .64082 .27402 L p .707 .577 .707 r
F P
0 g
s
.16288 .79121 m .15938 .77267 L .16656 .76525 L p .707 .577 .707 r
F P
0 g
s
.16656 .76525 m .17005 .7838 L .16288 .79121 L p .707 .577 .707 r
F P
0 g
s
.34307 .61904 m .34652 .67488 L .32551 .6702 L p .707 .577 .707 r
F P
0 g
s
.32551 .6702 m .32206 .61436 L .34307 .61904 L p .707 .577 .707 r
F P
0 g
s
.17841 .62588 m .18186 .68172 L .1655 .6894 L p .707 .577 .707 r
F P
0 g
s
.35832 .76545 m .36709 .26458 L .3902 .25431 L p .707 .577 .707 r
F P
0 g
s
.36709 .26458 m .35832 .76545 L .34831 .77738 L p .707 .577 .707 r
F P
0 g
s
.17135 .75495 m .16459 .71784 L .18088 .70955 L p .707 .577 .707 r
F P
0 g
s
.18186 .68172 m .17841 .62588 L .20244 .61933 L p .707 .577 .707 r
F P
0 g
s
.18088 .70955 m .18764 .74666 L .17135 .75495 L p .707 .577 .707 r
F P
0 g
s
.32938 .71946 m .32262 .68235 L .3432 .68356 L p .707 .577 .707 r
F P
0 g
s
.17005 .7838 m .16656 .76525 L .18284 .75693 L p .707 .577 .707 r
F P
0 g
s
.32206 .61436 m .32551 .6702 L .29812 .66777 L p .707 .577 .707 r
F P
0 g
s
.29812 .66777 m .29467 .61193 L .32206 .61436 L p .707 .577 .707 r
F P
0 g
s
.18284 .75693 m .18633 .77548 L .17005 .7838 L p .707 .577 .707 r
F P
0 g
s
.20244 .61933 m .20589 .67517 L .18186 .68172 L p .707 .577 .707 r
F P
0 g
s
.62305 .26233 m .61427 .7632 L .58455 .75338 L p .707 .577 .707 r
F P
0 g
s
.58455 .75338 m .59333 .25252 L .62305 .26233 L p .707 .577 .707 r
F P
0 g
s
.34497 .72994 m .34846 .74848 L .32792 .74745 L p .707 .577 .707 r
F P
0 g
s
.32792 .74745 m .32443 .72891 L .34497 .72994 L p .707 .577 .707 r
F P
0 g
s
.20589 .67517 m .20244 .61933 L .23178 .61455 L p .707 .577 .707 r
F P
0 g
s
.18764 .74666 m .18088 .70955 L .20469 .70123 L p .707 .577 .707 r
F P
0 g
s
.29467 .61193 m .29812 .66777 L .26701 .66783 L p .707 .577 .707 r
F P
0 g
s
.26701 .66783 m .26356 .612 L .29467 .61193 L p .707 .577 .707 r
F P
0 g
s
.32262 .68235 m .32938 .71946 L .30245 .72087 L p .707 .577 .707 r
F P
0 g
s
.30245 .72087 m .29569 .68376 L .32262 .68235 L p .707 .577 .707 r
F P
0 g
s
.3902 .25431 m .38142 .75517 L .35832 .76545 L p .707 .577 .707 r
F P
0 g
s
.38142 .75517 m .3902 .25431 L .42415 .24669 L p .707 .577 .707 r
F P
0 g
s
.20469 .70123 m .21144 .73834 L .18764 .74666 L p .707 .577 .707 r
F P
0 g
s
.73355 .64754 m .7301 .5917 L .69899 .59177 L p .707 .577 .707 r
F P
0 g
s
.7301 .5917 m .73355 .64754 L .76533 .64499 L p .707 .577 .707 r
F P
0 g
s
.76533 .64499 m .76188 .58915 L .7301 .5917 L p .707 .577 .707 r
F P
0 g
s
.23522 .67038 m .23178 .61455 L .26356 .612 L p .707 .577 .707 r
F P
0 g
s
.23178 .61455 m .23522 .67038 L .20589 .67517 L p .707 .577 .707 r
F P
0 g
s
.76188 .58915 m .76533 .64499 L .79467 .6402 L p .707 .577 .707 r
F P
0 g
s
.79467 .6402 m .79122 .58437 L .76188 .58915 L p .707 .577 .707 r
F P
0 g
s
.26356 .612 m .26701 .66783 L .23522 .67038 L p .707 .577 .707 r
F P
0 g
s
.18633 .77548 m .18284 .75693 L .20663 .74852 L p .707 .577 .707 r
F P
0 g
s
.70244 .6476 m .69899 .59177 L .67159 .58934 L p .707 .577 .707 r
F P
0 g
s
.69899 .59177 m .70244 .6476 L .73355 .64754 L p .707 .577 .707 r
F P
0 g
s
.20663 .74852 m .21012 .76707 L .18633 .77548 L p .707 .577 .707 r
F P
0 g
s
.32443 .72891 m .32792 .74745 L .30103 .74907 L p .707 .577 .707 r
F P
0 g
s
.30103 .74907 m .29754 .73053 L .32443 .72891 L p .707 .577 .707 r
F P
0 g
s
.21144 .73834 m .20469 .70123 L .23369 .69369 L p .707 .577 .707 r
F P
0 g
s
.79122 .58437 m .79467 .6402 L .81869 .63365 L p .707 .577 .707 r
F P
0 g
s
.81869 .63365 m .81524 .57781 L .79122 .58437 L p .707 .577 .707 r
F P
0 g
s
.29569 .68376 m .30245 .72087 L .27181 .72478 L p .707 .577 .707 r
F P
0 g
s
.27181 .72478 m .26505 .68767 L .29569 .68376 L p .707 .577 .707 r
F P
0 g
s
.59333 .25252 m .58455 .75338 L .54579 .74641 L p .707 .577 .707 r
F P
0 g
s
.54579 .74641 m .55457 .24554 L .59333 .25252 L p .707 .577 .707 r
F P
0 g
s
.23369 .69369 m .24045 .7308 L .21144 .73834 L p .707 .577 .707 r
F P
0 g
s
.67159 .58934 m .67504 .64518 L .70244 .6476 L p .707 .577 .707 r
F P
0 g
s
.24045 .7308 m .23369 .69369 L .26505 .68767 L p .707 .577 .707 r
F P
0 g
s
.73741 .71169 m .73066 .67458 L .70002 .67849 L p .707 .577 .707 r
F P
0 g
s
.73066 .67458 m .73741 .71169 L .76877 .70567 L p .707 .577 .707 r
F P
0 g
s
.76877 .70567 m .76202 .66856 L .73066 .67458 L p .707 .577 .707 r
F P
0 g
s
.67504 .64518 m .67159 .58934 L .65059 .58466 L p .707 .577 .707 r
F P
0 g
s
.21012 .76707 m .20663 .74852 L .2356 .74084 L p .707 .577 .707 r
F P
0 g
s
.26505 .68767 m .27181 .72478 L .24045 .7308 L p .707 .577 .707 r
F P
0 g
s
.76202 .66856 m .76877 .70567 L .79778 .69813 L p .707 .577 .707 r
F P
0 g
s
.79778 .69813 m .79102 .66102 L .76202 .66856 L p .707 .577 .707 r
F P
0 g
s
.2356 .74084 m .2391 .75938 L .21012 .76707 L p .707 .577 .707 r
F P
0 g
s
.41538 .74755 m .42415 .24669 L .46563 .24247 L p .707 .577 .707 r
F P
0 g
s
.42415 .24669 m .41538 .74755 L .38142 .75517 L p .707 .577 .707 r
F P
0 g
s
.29754 .73053 m .30103 .74907 L .27042 .75318 L p .707 .577 .707 r
F P
0 g
s
.27042 .75318 m .26693 .73464 L .29754 .73053 L p .707 .577 .707 r
F P
0 g
s
.70002 .67849 m .70677 .7156 L .73741 .71169 L p .707 .577 .707 r
F P
0 g
s
.70677 .7156 m .70002 .67849 L .67309 .67991 L p .707 .577 .707 r
F P
0 g
s
.81524 .57781 m .81869 .63365 L .83505 .62597 L p .707 .577 .707 r
F P
0 g
s
.83505 .62597 m .8316 .57013 L .81524 .57781 L p .707 .577 .707 r
F P
0 g
s
.2391 .75938 m .2356 .74084 L .26693 .73464 L p .707 .577 .707 r
F P
0 g
s
.79102 .66102 m .79778 .69813 L .82159 .68981 L p .707 .577 .707 r
F P
0 g
s
.82159 .68981 m .81483 .6527 L .79102 .66102 L p .707 .577 .707 r
F P
0 g
s
.26693 .73464 m .27042 .75318 L .2391 .75938 L p .707 .577 .707 r
F P
0 g
s
.65059 .58466 m .65404 .64049 L .67504 .64518 L p .707 .577 .707 r
F P
0 g
s
.67309 .67991 m .67984 .71702 L .70677 .7156 L p .707 .577 .707 r
F P
0 g
s
.55457 .24554 m .54579 .74641 L .50179 .74294 L p .707 .577 .707 r
F P
0 g
s
.50179 .74294 m .51057 .24208 L .55457 .24554 L p .707 .577 .707 r
F P
0 g
s
.73596 .76697 m .73246 .74842 L .70186 .75253 L p .707 .577 .707 r
F P
0 g
s
.73246 .74842 m .73596 .76697 L .76728 .76077 L p .707 .577 .707 r
F P
0 g
s
.76728 .76077 m .76379 .74222 L .73246 .74842 L p .707 .577 .707 r
F P
0 g
s
.76379 .74222 m .76728 .76077 L .79626 .75308 L p .707 .577 .707 r
F P
0 g
s
.79626 .75308 m .79276 .73454 L .76379 .74222 L p .707 .577 .707 r
F P
0 g
s
.45685 .74334 m .46563 .24247 L .51057 .24208 L p .707 .577 .707 r
F P
0 g
s
.46563 .24247 m .45685 .74334 L .41538 .74755 L p .707 .577 .707 r
F P
0 g
s
.70186 .75253 m .70535 .77108 L .73596 .76697 L p .707 .577 .707 r
F P
0 g
s
.65404 .64049 m .65059 .58466 L .63804 .57818 L p .707 .577 .707 r
F P
0 g
s
.67984 .71702 m .67309 .67991 L .65251 .67869 L p .707 .577 .707 r
F P
0 g
s
.51057 .24208 m .50179 .74294 L .45685 .74334 L p .707 .577 .707 r
F P
0 g
s
.70535 .77108 m .70186 .75253 L .67496 .75415 L p .707 .577 .707 r
F P
0 g
s
.67496 .75415 m .67846 .7727 L .70535 .77108 L p .707 .577 .707 r
F P
0 g
s
.81483 .6527 m .82159 .68981 L .83787 .68153 L p .707 .577 .707 r
F P
0 g
s
.83787 .68153 m .83112 .64442 L .81483 .6527 L p .707 .577 .707 r
F P
0 g
s
.79276 .73454 m .79626 .75308 L .82005 .74467 L p .707 .577 .707 r
F P
0 g
s
.82005 .74467 m .81656 .72613 L .79276 .73454 L p .707 .577 .707 r
F P
0 g
s
.65251 .67869 m .65926 .7158 L .67984 .71702 L p .707 .577 .707 r
F P
0 g
s
.8316 .57013 m .83505 .62597 L .84215 .61792 L p .707 .577 .707 r
F P
0 g
s
.84215 .61792 m .8387 .56208 L .8316 .57013 L p .707 .577 .707 r
F P
0 g
s
.63804 .57818 m .64149 .63402 L .65404 .64049 L p .707 .577 .707 r
F P
0 g
s
.67846 .7727 m .67496 .75415 L .65442 .75312 L p .707 .577 .707 r
F P
0 g
s
.65442 .75312 m .65791 .77167 L .67846 .7727 L p .707 .577 .707 r
F P
0 g
s
.65926 .7158 m .65251 .67869 L .64029 .67497 L p .707 .577 .707 r
F P
0 g
s
.81656 .72613 m .82005 .74467 L .83633 .73635 L p .707 .577 .707 r
F P
0 g
s
.83633 .73635 m .83284 .71781 L .81656 .72613 L p .707 .577 .707 r
F P
0 g
s
.64149 .63402 m .63804 .57818 L .63517 .57054 L p .707 .577 .707 r
F P
0 g
s
.64029 .67497 m .64705 .71208 L .65926 .7158 L p .707 .577 .707 r
F P
0 g
s
.83112 .64442 m .83787 .68153 L .84504 .67408 L p .707 .577 .707 r
F P
0 g
s
.84504 .67408 m .83828 .63697 L .83112 .64442 L p .707 .577 .707 r
F P
0 g
s
.63517 .57054 m .63862 .62638 L .64149 .63402 L p .707 .577 .707 r
F P
0 g
s
.8387 .56208 m .84215 .61792 L .83928 .61028 L p .707 .577 .707 r
F P
0 g
s
.83928 .61028 m .83583 .55444 L .8387 .56208 L p .707 .577 .707 r
F P
0 g
s
.65791 .77167 m .65442 .75312 L .64223 .74954 L p .707 .577 .707 r
F P
0 g
s
.64223 .74954 m .64573 .76808 L .65791 .77167 L p .707 .577 .707 r
F P
0 g
s
.83284 .71781 m .83633 .73635 L .8435 .72894 L p .707 .577 .707 r
F P
0 g
s
.8435 .72894 m .84001 .71039 L .83284 .71781 L p .707 .577 .707 r
F P
0 g
s
.64705 .71208 m .64029 .67497 L .63764 .6691 L p .707 .577 .707 r
F P
0 g
s
.63862 .62638 m .63517 .57054 L .64227 .56249 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63764 .6691 m .6444 .70621 L .64705 .71208 L p .707 .577 .707 r
F P
0 g
s
.83828 .63697 m .84504 .67408 L .84238 .66821 L p .707 .577 .707 r
F P
0 g
s
.84238 .66821 m .83563 .6311 L .83828 .63697 L p .707 .577 .707 r
F P
0 g
s
.64227 .56249 m .64572 .61833 L .63862 .62638 L p .707 .577 .707 r
F P
0 g
s
.83583 .55444 m .83928 .61028 L .82673 .6038 L p .707 .577 .707 r
F P
0 g
s
.82673 .6038 m .82328 .54796 L .83583 .55444 L p .707 .577 .707 r
F P
0 g
s
.64573 .76808 m .64223 .74954 L .6396 .74376 L p .707 .577 .707 r
F P
0 g
s
.6396 .74376 m .64309 .76231 L .64573 .76808 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84001 .71039 m .8435 .72894 L .84087 .72316 L p .707 .577 .707 r
F P
0 g
s
.84087 .72316 m .83737 .70461 L .84001 .71039 L p .707 .577 .707 r
F P
0 g
s
.6444 .70621 m .63764 .6691 L .64481 .66165 L p .707 .577 .707 r
F P
0 g
s
.39054 .62658 m .38709 .57074 L .35598 .5708 L p .707 .577 .707 r
F P
0 g
s
.38709 .57074 m .39054 .62658 L .42232 .62402 L p .707 .577 .707 r
F P
0 g
s
.42232 .62402 m .41887 .56819 L .38709 .57074 L p .707 .577 .707 r
F P
0 g
s
.64572 .61833 m .64227 .56249 L .65863 .55481 L p .707 .577 .707 r
F P
0 g
s
.41887 .56819 m .42232 .62402 L .45166 .61924 L p .707 .577 .707 r
F P
0 g
s
.45166 .61924 m .44821 .5634 L .41887 .56819 L p .707 .577 .707 r
F P
0 g
s
.64481 .66165 m .65156 .69876 L .6444 .70621 L p .707 .577 .707 r
F P
0 g
s
.83563 .6311 m .84238 .66821 L .83017 .66449 L p .707 .577 .707 r
F P
0 g
s
.83017 .66449 m .82342 .62737 L .83563 .6311 L p .707 .577 .707 r
F P
0 g
s
.35943 .62664 m .35598 .5708 L .32858 .56838 L p .707 .577 .707 r
F P
0 g
s
.35598 .5708 m .35943 .62664 L .39054 .62658 L p .707 .577 .707 r
F P
0 g
s
.82328 .54796 m .82673 .6038 L .80573 .59912 L p .707 .577 .707 r
F P
0 g
s
.80573 .59912 m .80228 .54328 L .82328 .54796 L p .707 .577 .707 r
F P
0 g
s
.44821 .5634 m .45166 .61924 L .47568 .61269 L p .707 .577 .707 r
F P
0 g
s
.47568 .61269 m .47223 .55685 L .44821 .5634 L p .707 .577 .707 r
F P
0 g
s
.65863 .55481 m .66208 .61065 L .64572 .61833 L p .707 .577 .707 r
F P
0 g
s
.64309 .76231 m .6396 .74376 L .64677 .73635 L p .707 .577 .707 r
F P
0 g
s
.3944 .67584 m .38765 .63872 L .35701 .64263 L p .707 .577 .707 r
F P
0 g
s
.38765 .63872 m .3944 .67584 L .42576 .66982 L p .707 .577 .707 r
F P
0 g
s
.42576 .66982 m .41901 .63271 L .38765 .63872 L p .707 .577 .707 r
F P
0 g
s
.41901 .63271 m .42576 .66982 L .45477 .66228 L p .707 .577 .707 r
F P
0 g
s
.45477 .66228 m .44801 .62517 L .41901 .63271 L p .707 .577 .707 r
F P
0 g
s
.64677 .73635 m .65026 .75489 L .64309 .76231 L p .707 .577 .707 r
F P
0 g
s
.32858 .56838 m .33203 .62421 L .35943 .62664 L p .707 .577 .707 r
F P
0 g
s
.33203 .62421 m .32858 .56838 L .30758 .56369 L p .707 .577 .707 r
F P
0 g
s
.83737 .70461 m .84087 .72316 L .82868 .71958 L p .707 .577 .707 r
F P
0 g
s
.82868 .71958 m .82519 .70103 L .83737 .70461 L p .707 .577 .707 r
F P
0 g
s
.35701 .64263 m .36376 .67974 L .3944 .67584 L p .707 .577 .707 r
F P
0 g
s
.66208 .61065 m .65863 .55481 L .68265 .54826 L p .707 .577 .707 r
F P
0 g
s
.36376 .67974 m .35701 .64263 L .33008 .64405 L p .707 .577 .707 r
F P
0 g
s
.65156 .69876 m .64481 .66165 L .66109 .65336 L p .707 .577 .707 r
F P
0 g
s
.39295 .70383 m .38945 .68529 L .35885 .6894 L p .707 .577 .707 r
F P
0 g
s
.38945 .68529 m .39295 .70383 L .42427 .69763 L p .707 .577 .707 r
F P
0 g
s
.42427 .69763 m .42078 .67909 L .38945 .68529 L p .707 .577 .707 r
F P
0 g
s
.44801 .62517 m .45477 .66228 L .47858 .65396 L p .707 .577 .707 r
F P
0 g
s
.47858 .65396 m .47182 .61685 L .44801 .62517 L p .707 .577 .707 r
F P
0 g
s
.42078 .67909 m .42427 .69763 L .45325 .68995 L p .707 .577 .707 r
F P
0 g
s
.45325 .68995 m .44975 .6714 L .42078 .67909 L p .707 .577 .707 r
F P
0 g
s
.47223 .55685 m .47568 .61269 L .49204 .60501 L p .707 .577 .707 r
F P
0 g
s
.49204 .60501 m .48859 .54917 L .47223 .55685 L p .707 .577 .707 r
F P
0 g
s
.33008 .64405 m .33683 .68116 L .36376 .67974 L p .707 .577 .707 r
F P
0 g
s
.66109 .65336 m .66785 .69047 L .65156 .69876 L p .707 .577 .707 r
F P
0 g
s
.35885 .6894 m .36234 .70794 L .39295 .70383 L p .707 .577 .707 r
F P
0 g
s
.82342 .62737 m .83017 .66449 L .80959 .66327 L p .707 .577 .707 r
F P
0 g
s
.80959 .66327 m .80284 .62616 L .82342 .62737 L p .707 .577 .707 r
F P
0 g
s
.80228 .54328 m .80573 .59912 L .77833 .59669 L p .707 .577 .707 r
F P
0 g
s
.77833 .59669 m .77488 .54086 L .80228 .54328 L p .707 .577 .707 r
F P
0 g
s
.30758 .56369 m .31103 .61953 L .33203 .62421 L p .707 .577 .707 r
F P
0 g
s
.36234 .70794 m .35885 .6894 L .33195 .69102 L p .707 .577 .707 r
F P
0 g
s
.68265 .54826 m .6861 .60409 L .66208 .61065 L p .707 .577 .707 r
F P
0 g
s
.33195 .69102 m .33545 .70956 L .36234 .70794 L p .707 .577 .707 r
F P
0 g
s
.44975 .6714 m .45325 .68995 L .47704 .68154 L p .707 .577 .707 r
F P
0 g
s
.47704 .68154 m .47355 .66299 L .44975 .6714 L p .707 .577 .707 r
F P
0 g
s
.33683 .68116 m .33008 .64405 L .3095 .64284 L p .707 .577 .707 r
F P
0 g
s
.6861 .60409 m .68265 .54826 L .71199 .54347 L p .707 .577 .707 r
F P
0 g
s
.65026 .75489 m .64677 .73635 L .66305 .72803 L p .707 .577 .707 r
F P
0 g
s
.31103 .61953 m .30758 .56369 L .29503 .55722 L p .707 .577 .707 r
F P
0 g
s
.66305 .72803 m .66654 .74657 L .65026 .75489 L p .707 .577 .707 r
F P
0 g
s
.47182 .61685 m .47858 .65396 L .49486 .64567 L p .707 .577 .707 r
F P
0 g
s
.49486 .64567 m .48811 .60856 L .47182 .61685 L p .707 .577 .707 r
F P
0 g
s
.3095 .64284 m .31625 .67995 L .33683 .68116 L p .707 .577 .707 r
F P
0 g
s
.66785 .69047 m .66109 .65336 L .6849 .64504 L p .707 .577 .707 r
F P
0 g
s
.77488 .54086 m .77833 .59669 L .74722 .59676 L p .707 .577 .707 r
F P
0 g
s
.74722 .59676 m .74377 .54092 L .77488 .54086 L p .707 .577 .707 r
F P
0 g
s
.82519 .70103 m .82868 .71958 L .80813 .71855 L p .707 .577 .707 r
F P
0 g
s
.80813 .71855 m .80464 .7 L .82519 .70103 L p .707 .577 .707 r
F P
0 g
s
.33545 .70956 m .33195 .69102 L .31141 .68999 L p .707 .577 .707 r
F P
0 g
s
.71544 .59931 m .71199 .54347 L .74377 .54092 L p .707 .577 .707 r
F P
0 g
s
.71199 .54347 m .71544 .59931 L .6861 .60409 L p .707 .577 .707 r
F P
0 g
s
.80284 .62616 m .80959 .66327 L .78266 .66469 L p .707 .577 .707 r
F P
0 g
s
.78266 .66469 m .77591 .62758 L .80284 .62616 L p .707 .577 .707 r
F P
0 g
s
.31141 .68999 m .3149 .70853 L .33545 .70956 L p .707 .577 .707 r
F P
0 g
s
.48859 .54917 m .49204 .60501 L .49914 .59695 L p .707 .577 .707 r
F P
0 g
s
.49914 .59695 m .49569 .54112 L .48859 .54917 L p .707 .577 .707 r
F P
0 g
s
.6849 .64504 m .69166 .68215 L .66785 .69047 L p .707 .577 .707 r
F P
0 g
s
.74377 .54092 m .74722 .59676 L .71544 .59931 L p .707 .577 .707 r
F P
0 g
s
.29503 .55722 m .29848 .61305 L .31103 .61953 L p .707 .577 .707 r
F P
0 g
s
.47355 .66299 m .47704 .68154 L .49332 .67322 L p .707 .577 .707 r
F P
0 g
s
.49332 .67322 m .48983 .65467 L .47355 .66299 L p .707 .577 .707 r
F P
0 g
s
.31625 .67995 m .3095 .64284 L .29728 .63911 L p .707 .577 .707 r
F P
0 g
s
.69166 .68215 m .6849 .64504 L .71391 .6375 L p .707 .577 .707 r
F P
0 g
s
.66654 .74657 m .66305 .72803 L .68684 .71962 L p .707 .577 .707 r
F P
0 g
s
.29848 .61305 m .29503 .55722 L .29216 .54958 L p .707 .577 .707 r
F P
0 g
s
.29728 .63911 m .30404 .67622 L .31625 .67995 L p .707 .577 .707 r
F P
0 g
s
.68684 .71962 m .69034 .73816 L .66654 .74657 L p .707 .577 .707 r
F P
0 g
s
.48811 .60856 m .49486 .64567 L .50203 .63823 L p .707 .577 .707 r
F P
0 g
s
.50203 .63823 m .49527 .60112 L .48811 .60856 L p .707 .577 .707 r
F P
0 g
s
.77591 .62758 m .78266 .66469 L .75202 .6686 L p .707 .577 .707 r
F P
0 g
s
.75202 .6686 m .74527 .63149 L .77591 .62758 L p .707 .577 .707 r
F P
0 g
s
.80464 .7 m .80813 .71855 L .78124 .72017 L p .707 .577 .707 r
F P
0 g
s
.78124 .72017 m .77775 .70162 L .80464 .7 L p .707 .577 .707 r
F P
0 g
s
.71391 .6375 m .72066 .67462 L .69166 .68215 L p .707 .577 .707 r
F P
0 g
s
.3149 .70853 m .31141 .68999 L .29922 .68641 L p .707 .577 .707 r
F P
0 g
s
.72066 .67462 m .71391 .6375 L .74527 .63149 L p .707 .577 .707 r
F P
0 g
s
.29922 .68641 m .30272 .70495 L .3149 .70853 L p .707 .577 .707 r
F P
0 g
s
.74527 .63149 m .75202 .6686 L .72066 .67462 L p .707 .577 .707 r
F P
0 g
s
.48983 .65467 m .49332 .67322 L .50049 .6658 L p .707 .577 .707 r
F P
0 g
s
.50049 .6658 m .497 .64726 L .48983 .65467 L p .707 .577 .707 r
F P
0 g
s
.29216 .54958 m .29561 .60542 L .29848 .61305 L p .707 .577 .707 r
F P
0 g
s
.49569 .54112 m .49914 .59695 L .49627 .58931 L p .707 .577 .707 r
F P
0 g
s
.49627 .58931 m .49282 .53348 L .49569 .54112 L p .707 .577 .707 r
F P
0 g
s
.69034 .73816 m .68684 .71962 L .71582 .71193 L p .707 .577 .707 r
F P
0 g
s
.71582 .71193 m .71931 .73048 L .69034 .73816 L p .707 .577 .707 r
F P
0 g
s
.77775 .70162 m .78124 .72017 L .75064 .72428 L p .707 .577 .707 r
F P
0 g
s
.75064 .72428 m .74714 .70573 L .77775 .70162 L p .707 .577 .707 r
F P
0 g
s
.30404 .67622 m .29728 .63911 L .29463 .63324 L p .707 .577 .707 r
F P
0 g
s
.71931 .73048 m .71582 .71193 L .74714 .70573 L p .707 .577 .707 r
F P
0 g
s
.29463 .63324 m .30139 .67035 L .30404 .67622 L p .707 .577 .707 r
F P
0 g
s
.74714 .70573 m .75064 .72428 L .71931 .73048 L p .707 .577 .707 r
F P
0 g
s
.29561 .60542 m .29216 .54958 L .29925 .54152 L p .707 .577 .707 r
F P
0 g
s
.49527 .60112 m .50203 .63823 L .49937 .63236 L p .707 .577 .707 r
F P
0 g
s
.49937 .63236 m .49262 .59524 L .49527 .60112 L p .707 .577 .707 r
F P
0 g
s
.30272 .70495 m .29922 .68641 L .29659 .68063 L p .707 .577 .707 r
F P
0 g
s
.29659 .68063 m .30008 .69917 L .30272 .70495 L p .707 .577 .707 r
F P
0 g
s
.497 .64726 m .50049 .6658 L .49786 .66002 L p .707 .577 .707 r
F P
0 g
s
.49786 .66002 m .49436 .64148 L .497 .64726 L p .707 .577 .707 r
F P
0 g
s
.29925 .54152 m .3027 .59736 L .29561 .60542 L p .707 .577 .707 r
F P
0 g
s
.49282 .53348 m .49627 .58931 L .48372 .58284 L p .707 .577 .707 r
F P
0 g
s
.48372 .58284 m .48027 .527 L .49282 .53348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30139 .67035 m .29463 .63324 L .3018 .6258 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3018 .6258 m .30855 .66291 L .30139 .67035 L p .707 .577 .707 r
F P
0 g
s
.3027 .59736 m .29925 .54152 L .31561 .53385 L p .707 .577 .707 r
F P
0 g
s
.49262 .59524 m .49937 .63236 L .48716 .62863 L p .707 .577 .707 r
F P
0 g
s
.48716 .62863 m .48041 .59152 L .49262 .59524 L p .707 .577 .707 r
F P
0 g
s
.30008 .69917 m .29659 .68063 L .30376 .67322 L p .707 .577 .707 r
F P
0 g
s
.30376 .67322 m .30725 .69176 L .30008 .69917 L p .707 .577 .707 r
F P
0 g
s
.48027 .527 m .48372 .58284 L .46272 .57816 L p .707 .577 .707 r
F P
0 g
s
.46272 .57816 m .45927 .52232 L .48027 .527 L p .707 .577 .707 r
F P
0 g
s
.49436 .64148 m .49786 .66002 L .48567 .65644 L p .707 .577 .707 r
F P
0 g
s
.48567 .65644 m .48218 .6379 L .49436 .64148 L p .707 .577 .707 r
F P
0 g
s
.31561 .53385 m .31906 .58968 L .3027 .59736 L p .707 .577 .707 r
F P
0 g
s
.30855 .66291 m .3018 .6258 L .31808 .61751 L p .707 .577 .707 r
F P
0 g
s
.31906 .58968 m .31561 .53385 L .33964 .52729 L p .707 .577 .707 r
F P
0 g
s
.31808 .61751 m .32484 .65462 L .30855 .66291 L p .707 .577 .707 r
F P
0 g
s
.48041 .59152 m .48716 .62863 L .46658 .62742 L p .707 .577 .707 r
F P
0 g
s
.46658 .62742 m .45983 .59031 L .48041 .59152 L p .707 .577 .707 r
F P
0 g
s
.30725 .69176 m .30376 .67322 L .32004 .6649 L p .707 .577 .707 r
F P
0 g
s
.45927 .52232 m .46272 .57816 L .43532 .57573 L p .707 .577 .707 r
F P
0 g
s
.43532 .57573 m .43187 .51989 L .45927 .52232 L p .707 .577 .707 r
F P
0 g
s
.32004 .6649 m .32353 .68344 L .30725 .69176 L p .707 .577 .707 r
F P
0 g
s
.33964 .52729 m .34309 .58313 L .31906 .58968 L p .707 .577 .707 r
F P
0 g
s
.48218 .6379 m .48567 .65644 L .46512 .65541 L p .707 .577 .707 r
F P
0 g
s
.46512 .65541 m .46163 .63687 L .48218 .6379 L p .707 .577 .707 r
F P
0 g
s
.34309 .58313 m .33964 .52729 L .36898 .52251 L p .707 .577 .707 r
F P
0 g
s
.32484 .65462 m .31808 .61751 L .34189 .60919 L p .707 .577 .707 r
F P
0 g
s
.43187 .51989 m .43532 .57573 L .40421 .57579 L p .707 .577 .707 r
F P
0 g
s
.40421 .57579 m .40076 .51996 L .43187 .51989 L p .707 .577 .707 r
F P
0 g
s
.45983 .59031 m .46658 .62742 L .43965 .62883 L p .707 .577 .707 r
F P
0 g
s
.43965 .62883 m .4329 .59172 L .45983 .59031 L p .707 .577 .707 r
F P
0 g
s
.34189 .60919 m .34865 .6463 L .32484 .65462 L p .707 .577 .707 r
F P
0 g
s
.37243 .57834 m .36898 .52251 L .40076 .51996 L p .707 .577 .707 r
F P
0 g
s
.36898 .52251 m .37243 .57834 L .34309 .58313 L p .707 .577 .707 r
F P
0 g
s
.40076 .51996 m .40421 .57579 L .37243 .57834 L p .707 .577 .707 r
F P
0 g
s
.32353 .68344 m .32004 .6649 L .34383 .65648 L p .707 .577 .707 r
F P
0 g
s
.34383 .65648 m .34733 .67503 L .32353 .68344 L p .707 .577 .707 r
F P
0 g
s
.46163 .63687 m .46512 .65541 L .43823 .65703 L p .707 .577 .707 r
F P
0 g
s
.43823 .65703 m .43474 .63849 L .46163 .63687 L p .707 .577 .707 r
F P
0 g
s
.34865 .6463 m .34189 .60919 L .3709 .60165 L p .707 .577 .707 r
F P
0 g
s
.4329 .59172 m .43965 .62883 L .40901 .63274 L p .707 .577 .707 r
F P
0 g
s
.40901 .63274 m .40226 .59563 L .4329 .59172 L p .707 .577 .707 r
F P
0 g
s
.3709 .60165 m .37765 .63876 L .34865 .6463 L p .707 .577 .707 r
F P
0 g
s
.37765 .63876 m .3709 .60165 L .40226 .59563 L p .707 .577 .707 r
F P
0 g
s
.34733 .67503 m .34383 .65648 L .37281 .6488 L p .707 .577 .707 r
F P
0 g
s
.40226 .59563 m .40901 .63274 L .37765 .63876 L p .707 .577 .707 r
F P
0 g
s
.37281 .6488 m .3763 .66734 L .34733 .67503 L p .707 .577 .707 r
F P
0 g
s
.43474 .63849 m .43823 .65703 L .40763 .66114 L p .707 .577 .707 r
F P
0 g
s
.40763 .66114 m .40413 .6426 L .43474 .63849 L p .707 .577 .707 r
F P
0 g
s
.3763 .66734 m .37281 .6488 L .40413 .6426 L p .707 .577 .707 r
F P
0 g
s
.40413 .6426 m .40763 .66114 L .3763 .66734 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001UYF00<005YFFUH00eYF2@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001J
EP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF00AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol00`00FUH00006FUHA0004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`T000AJEP03001JEUYF
00IJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Qo
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001WOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000IOolA000mOol005Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P004Goo200015YF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00
E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000]oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00@0039oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0031oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000_Ool005=oo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00;Woo001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<0
05YFFUH01EYF1`000eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`800003
FUH005YF009JEP03001JEUYF00=JEPH000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP@000=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00Dgoo0P0000=JEP00FUH00UYF00<0
05YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP800004FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00003FUH2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH01000
FUIJEUYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00@005YF001JEP8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPP000=JEP03001JEUYF00D00006FUH005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000H000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000
FUIJEUYF0P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPd000=JEP03001JEUYF00EJEPP0009JEP04001JEUYFFUH2000]
Ool005Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40003FUH2000]Ool005Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF00000`0015YF00<005YFFUH01UYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH0000002eoo`00E7oo00D005YFFUIJ
EP0000EJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00@7oo5@000eYF00@005YFFUIJ
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF008000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP<002eoo`00?7oo100000=JEP00FUH01eYF
00<005YFFUH01UYF00D005YF000005YF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002eoo`00=Woo1P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000bOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2000^Ool0035oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0
0004FUH005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUHF000_Ool002moo`800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPP000EJEP03001JEUYF00EJEP04001JEUYFFUH5000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
;goo000^Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00L0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP06001JEUYFFUH005YF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00;Goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF008000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUH0
00030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004
FUH00`00FUIJEP04FUH40006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001UYF2@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00005FUH01000FUH0000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20005FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0003FUH4
00000eYF000000020005FUH00`00FUIJEP07FUH00`00FUIJEP04FUHB000015YF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
10001eYF00@005YF000000=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH015YF0`00
0UYF0`000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEPT000=JEP03001oogoo02]oo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPh00005FUH005YF001JEP020006FUH00`00FUIJEP04FUH70009FUH00`00
FUIJEP0400000eYF0000000200000eYF001JEP04FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF0P0000=JEP000000;7oo000/Ool01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH015YF1`0025YF00<005YFFUH00UYF0P0000AJEP00000000MJ
EP03001JEUYF00@000MJEP03001JEUYF00AJEPD0009JEP<000EJEP03001JEUYF00=JEP<000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00AJEP03001JEUYF009JEP@002ao
o`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH010001UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`000UYF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01000
1EYF0P0000=JEP00FUH01UYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000/Ool002aoo`800003FUH0
05YF009JEP04001JEUYFFUH600000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00`000eYF00<005YFFUH0
1EYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP040004FUH60003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH2000]Ool002eoo`03001JEP0000=JEP@000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF00003`000UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF100025YF00<005YF00000P00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<007ooOol0;7oo000]Ool00`00
FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF1@000UYF00@005YF
FUIJEPT00003FUH005YF00EJEPL000AJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000
FUIJEUYF0P000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00P00;goo000]Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH000060004FUH01@00FUIJEP00FUH00`001EYF00D005YF001JEP0000=JEP@00003FUH00000
00<000AJEP03001JEUYF00IJEP04001JEP00000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000FUH000001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`00<Goo000]Ool01@00FUH005YF0000
1EYF00<005YFFUH015YF00<005YFFUH015YF10000UYF00<005YFFUH01UYF0P0000=JEP0000004000
1EYF1@001EYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8003=oo`00;Goo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP04001J
EP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000eOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH0
0`00FUIJEP05FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH000000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF0`00>Goo000]Ool01@00FUIJEUYF00001EYF00<005YF00000`001EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF4`00<Goo000]Ool01@00FUIJEUYF00000eYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
1P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00MJ
EPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Woo0P0000=JEP00
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH05@002EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00=JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0031o
o`@000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEP0000<000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYF000^Ool002moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000AJEQ400003FUH005YF00QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002ioo`03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ000003FUH005YF00EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEQ<000EJEP03001JEUYF00MJEP03001JEUYF009JEQ<0009JEP03001o
ogoo02]oo`00;Goo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01@000eYF00<005YFFUH01EYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP04FUH7000@Ool6000]Ool002ao
o`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJEP03001J
EUYF00AJEP06001JEUYF001JEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001eYF0`000eYF
00<005YFFUH01UYF00<005YFFUH0100057oo0`000UYF00@005YFFUH002eoo`00;7oo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPT000AJEQ@00003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP<000IJEP03001JEUYF00AJEP@001Aoo`@00003FUH0
05YF00=JEP03001JEP0002eoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00@0
00AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YFFUH200000eYF001JEP06FUH00`00FUIJEP04000EOol30005
FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP@000IJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP04FUH5000FOol200000eYF001J
EP06FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YF
FUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEP800004FUH005YFFUH2
000BOol30003FUH00`00FUIJEP05FUH01000FUH00000<7oo000]Ool00`00FUH00005FUH01000FUH0
000015YF100000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF6@001UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00@005YF000000=JEP03001JEUYF008000aoo`H0
00IJEP03001JEUYF00AJEP<0039oo`00;Goo00@005YFFUH000=JEP@00003FUH00000008000EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPX00003FUH005YF00EJEP03001JEUYF00EJ
EPT000aJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP04001J
EUYFFUH40004FUH00`00FUIJEP020003Ool90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000]Ool01@00FUIJEP00FUH00P000eYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2P0000=JEP0000000P0000Ioo`00000005YF0006FUH00`00FUIJEP050008FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002
FUH01000FUH000000eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YF000003Moo`00;Woo0UYF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=J
EP00FUH01EYF0`000Woo0`000UYF00<005YF00001EYF10000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P0000=J
EP00FUH030000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00>Goo000^Ool0
1EYF001JEP00FUH00P001EYF00<005YFFUH01EYF1`002EYF00<005YFFUH010000goo0P0000=JEP00
FUH00UYF00<005YF00000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF1@000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?7oo000^Ool20000
15YF000000001eYF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@001Goo0P000eYF00P005YF
FUIJEP00FUH005YF0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF0P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00@7oo000^Ool30002FUH00`00FUIJ
EP05FUH00`00FUH000030008FUH00`00FUIJEP040007Ool30006FUH01@00FUIJEP00FUH00P000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000AJEP800003FUH0000000=JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@004Eoo`00;Woo0P0015YF00<005YFFUH00eYF0`000eYF
00<005YFFUH00UYF1`001goo100000=JEP00FUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP80009JEP80009JEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
009JEPL004Uoo`00;Goo00<005YF000015YF00<005YF00003P000goo0`000goo1@001EYF00<005YF
FUH015YF0`0000=oo`00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100015YF5000D7oo000]
Ool01000FUIJEP000eYF0P004Goo1`000UYF00<005YFFUH01UYF00@005YFFUIJEP8000Aoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP02
001FOol002eoo`05001JEUYF001JEP02000@Ool80004FUH00`00FUIJEP06FUH01000FUH000001Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00EJEP<005Qo
o`00;Woo00<005YF00004`000eYF1@001EYF00<005YFFUH015YF0`0027oo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00=JEP8005Yoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH0100037oo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEP0000<005aoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0047oo00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001UYF0`00H7oo000^Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000FOol20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUHD001HOol002moo`800003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPH001aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP00008005Eoo`00<Goo500097oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00Jgoo0P0015YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF001EOol006eoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001J
EP000008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000E7oo001`Ool40008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH400000eYF001JEP05
FUHA0002FUH00`00Oomoo`1BOol007Aoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00D000EJEP03001JEUYF00@000ioo`H005Aoo`00NWoo2@001UYF00<005YF
FUH02EYF00<005YFFUH015YF200000=JEP00FUH00eYF1`003goo0`000UYF00@005YFFUH005Aoo`00
Pgoo6P001eYF1P0057oo0P0000=JEP00FUH00eYF00<005YF0000E7oo002BOol200000eYF001JEP06
FUH00`00FUIJEP02FUH2000HOol20003FUH00`00FUIJEP02FUH2001EOol0091oo`8000=JEP03001J
EUYF00EJEP03001JEP00008001Moo`<000IJEP05001JEUYFFUH0001FOol008moo`8000EJEP03001J
EUYF00=JEP<001Ioo`@00003FUH005YF00IJEP04001JEP00001GOol008ioo`03001JEP0000EJEP03
001JEP0000<0019oo`L000EJEP03001JEUYF00AJEP<005Uoo`00SWoo00@005YFFUH000=JEP<000mo
o`L000AJEP03001JEUYF00IJEP04001JEUYFFUH2001LOol008ioo`05001JEUYF001JEP02000>Ool4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002?Ool00`00FUH0000A0006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol008moo`80009JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006=oo`00Sgoo0P000UYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00Igoo002?Ool20003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001/Ool0091oo`80
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0071oo`00TWoo5000Mgoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]29\[InvisibleSpace]"     "\
\[InvisibleSpace]9.752535240165791`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 29, "     ", 9.7525352401657912, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72157 m .59613 .66599 L .56496 .66409 L p .707 .577 .707 r
F P
0 g
s
.59613 .66599 m .59613 .72157 L .62796 .72079 L p .707 .577 .707 r
F P
0 g
s
.62796 .72079 m .62796 .66521 L .59613 .66599 L p .707 .577 .707 r
F P
0 g
s
.62796 .66521 m .62796 .72079 L .65734 .71741 L p .707 .577 .707 r
F P
0 g
s
.65734 .71741 m .65734 .66183 L .62796 .66521 L p .707 .577 .707 r
F P
0 g
s
.56496 .71967 m .56496 .66409 L .5375 .65969 L p .707 .577 .707 r
F P
0 g
s
.56496 .66409 m .56496 .71967 L .59613 .72157 L p .707 .577 .707 r
F P
0 g
s
.65734 .66183 m .65734 .71741 L .6814 .71176 L p .707 .577 .707 r
F P
0 g
s
.6814 .71176 m .6814 .65618 L .65734 .66183 L p .707 .577 .707 r
F P
0 g
s
.5375 .65969 m .5375 .71528 L .56496 .71967 L p .707 .577 .707 r
F P
0 g
s
.5375 .71528 m .5375 .65969 L .51644 .65324 L p .707 .577 .707 r
F P
0 g
s
.59613 .81518 m .59613 .77812 L .56496 .77622 L p .707 .577 .707 r
F P
0 g
s
.59613 .77812 m .59613 .81518 L .62796 .8144 L p .707 .577 .707 r
F P
0 g
s
.62796 .8144 m .62796 .77734 L .59613 .77812 L p .707 .577 .707 r
F P
0 g
s
.62796 .77734 m .62796 .8144 L .65735 .81102 L p .707 .577 .707 r
F P
0 g
s
.65735 .81102 m .65735 .77397 L .62796 .77734 L p .707 .577 .707 r
F P
0 g
s
.6814 .65618 m .6814 .71176 L .69777 .7044 L p .707 .577 .707 r
F P
0 g
s
.69777 .7044 m .69777 .64881 L .6814 .65618 L p .707 .577 .707 r
F P
0 g
s
.56496 .81328 m .56496 .77622 L .5375 .77183 L p .707 .577 .707 r
F P
0 g
s
.56496 .77622 m .56496 .81328 L .59613 .81518 L p .707 .577 .707 r
F P
0 g
s
.51644 .65324 m .51644 .70882 L .5375 .71528 L p .707 .577 .707 r
F P
0 g
s
.51644 .70882 m .51644 .65324 L .50385 .64536 L p .707 .577 .707 r
F P
0 g
s
.65735 .77397 m .65735 .81102 L .6814 .80537 L p .707 .577 .707 r
F P
0 g
s
.6814 .80537 m .6814 .76832 L .65735 .77397 L p .707 .577 .707 r
F P
0 g
s
.5375 .77183 m .5375 .80888 L .56496 .81328 L p .707 .577 .707 r
F P
0 g
s
.5375 .80888 m .5375 .77183 L .51644 .76537 L p .707 .577 .707 r
F P
0 g
s
.59613 .89745 m .59613 .87893 L .56496 .87702 L p .707 .577 .707 r
F P
0 g
s
.59613 .87893 m .59613 .89745 L .62796 .89668 L p .707 .577 .707 r
F P
0 g
s
.62796 .89668 m .62796 .87815 L .59613 .87893 L p .707 .577 .707 r
F P
0 g
s
.50385 .64536 m .50385 .70094 L .51644 .70882 L p .707 .577 .707 r
F P
0 g
s
.69777 .64881 m .69777 .7044 L .70485 .69603 L p .707 .577 .707 r
F P
0 g
s
.70485 .69603 m .70485 .64045 L .69777 .64881 L p .707 .577 .707 r
F P
0 g
s
.62796 .87815 m .62796 .89668 L .65735 .8933 L p .707 .577 .707 r
F P
0 g
s
.65735 .8933 m .65735 .87477 L .62796 .87815 L p .707 .577 .707 r
F P
0 g
s
.51644 .76537 m .51644 .80243 L .5375 .80888 L p .707 .577 .707 r
F P
0 g
s
.56496 .87702 m .56496 .89555 L .59613 .89745 L p .707 .577 .707 r
F P
0 g
s
.56496 .89555 m .56496 .87702 L .5375 .87263 L p .707 .577 .707 r
F P
0 g
s
.6814 .76832 m .6814 .80537 L .69777 .798 L p .707 .577 .707 r
F P
0 g
s
.69777 .798 m .69777 .76095 L .6814 .76832 L p .707 .577 .707 r
F P
0 g
s
.5375 .87263 m .5375 .89116 L .56496 .89555 L p .707 .577 .707 r
F P
0 g
s
.50385 .70094 m .50385 .64536 L .50095 .63681 L p .707 .577 .707 r
F P
0 g
s
.65735 .87477 m .65735 .8933 L .6814 .88765 L p .707 .577 .707 r
F P
0 g
s
.6814 .88765 m .6814 .86912 L .65735 .87477 L p .707 .577 .707 r
F P
0 g
s
.51644 .80243 m .51644 .76537 L .50385 .75749 L p .707 .577 .707 r
F P
0 g
s
.5375 .89116 m .5375 .87263 L .51644 .86618 L p .707 .577 .707 r
F P
0 g
s
.51644 .86618 m .51644 .88471 L .5375 .89116 L p .707 .577 .707 r
F P
0 g
s
.50385 .75749 m .50385 .79455 L .51644 .80243 L p .707 .577 .707 r
F P
0 g
s
.50095 .63681 m .50095 .6924 L .50385 .70094 L p .707 .577 .707 r
F P
0 g
s
.70485 .64045 m .70485 .69603 L .70195 .68749 L p .707 .577 .707 r
F P
0 g
s
.70195 .68749 m .70195 .63191 L .70485 .64045 L p .707 .577 .707 r
F P
0 g
s
.69777 .76095 m .69777 .798 L .70485 .78964 L p .707 .577 .707 r
F P
0 g
s
.70485 .78964 m .70485 .75258 L .69777 .76095 L p .707 .577 .707 r
F P
0 g
s
.6814 .86912 m .6814 .88765 L .69777 .88028 L p .707 .577 .707 r
F P
0 g
s
.69777 .88028 m .69777 .86175 L .6814 .86912 L p .707 .577 .707 r
F P
0 g
s
.50095 .6924 m .50095 .63681 L .50804 .62845 L p .707 .577 .707 r
F P
0 g
s
.49044 .80603 m .49044 .30415 L .44643 .30146 L p .707 .577 .707 r
F P
0 g
s
.50385 .79455 m .50385 .75749 L .50095 .74895 L p .707 .577 .707 r
F P
0 g
s
.50095 .74895 m .50095 .786 L .50385 .79455 L p .707 .577 .707 r
F P
0 g
s
.50804 .62845 m .50804 .68403 L .50095 .6924 L p .707 .577 .707 r
F P
0 g
s
.50804 .68403 m .50804 .62845 L .5244 .62108 L p .707 .577 .707 r
F P
0 g
s
.50095 .786 m .50095 .74895 L .50804 .74058 L p .707 .577 .707 r
F P
0 g
s
.50804 .74058 m .50804 .77764 L .50095 .786 L p .707 .577 .707 r
F P
0 g
s
.5244 .62108 m .5244 .67666 L .50804 .68403 L p .707 .577 .707 r
F P
0 g
s
.50804 .77764 m .50804 .74058 L .5244 .73322 L p .707 .577 .707 r
F P
0 g
s
.5244 .73322 m .5244 .77027 L .50804 .77764 L p .707 .577 .707 r
F P
0 g
s
.5244 .77027 m .5244 .73322 L .54846 .72757 L p .707 .577 .707 r
F P
0 g
s
.54846 .72757 m .54846 .76462 L .5244 .77027 L p .707 .577 .707 r
F P
0 g
s
.49044 .30415 m .49044 .80603 L .53538 .80494 L p .707 .577 .707 r
F P
0 g
s
.5244 .67666 m .5244 .62108 L .54846 .61543 L p .707 .577 .707 r
F P
0 g
s
.54846 .61543 m .54846 .67101 L .5244 .67666 L p .707 .577 .707 r
F P
0 g
s
.53538 .80494 m .53538 .30305 L .49044 .30415 L p .707 .577 .707 r
F P
0 g
s
.51644 .88471 m .51644 .86618 L .50385 .85829 L p .707 .577 .707 r
F P
0 g
s
.54846 .67101 m .54846 .61543 L .57784 .61205 L p .707 .577 .707 r
F P
0 g
s
.57784 .61205 m .57784 .66763 L .54846 .67101 L p .707 .577 .707 r
F P
0 g
s
.54846 .76462 m .54846 .72757 L .57784 .72419 L p .707 .577 .707 r
F P
0 g
s
.57784 .72419 m .57784 .76124 L .54846 .76462 L p .707 .577 .707 r
F P
0 g
s
.53538 .30305 m .53538 .80494 L .57686 .80017 L p .707 .577 .707 r
F P
0 g
s
.57686 .80017 m .57686 .29828 L .53538 .30305 L p .707 .577 .707 r
F P
0 g
s
.50385 .85829 m .50385 .87682 L .51644 .88471 L p .707 .577 .707 r
F P
0 g
s
.44643 .80335 m .44643 .30146 L .40766 .29526 L p .707 .577 .707 r
F P
0 g
s
.44643 .30146 m .44643 .80335 L .49044 .80603 L p .707 .577 .707 r
F P
0 g
s
.69777 .86175 m .69777 .88028 L .70485 .87191 L p .707 .577 .707 r
F P
0 g
s
.70485 .87191 m .70485 .85339 L .69777 .86175 L p .707 .577 .707 r
F P
0 g
s
.70195 .63191 m .70195 .68749 L .68936 .6796 L p .707 .577 .707 r
F P
0 g
s
.68936 .6796 m .68936 .62402 L .70195 .63191 L p .707 .577 .707 r
F P
0 g
s
.70485 .75258 m .70485 .78964 L .70195 .7811 L p .707 .577 .707 r
F P
0 g
s
.70195 .7811 m .70195 .74404 L .70485 .75258 L p .707 .577 .707 r
F P
0 g
s
.57784 .66763 m .57784 .61205 L .60968 .61128 L p .707 .577 .707 r
F P
0 g
s
.60968 .61128 m .60968 .66686 L .57784 .66763 L p .707 .577 .707 r
F P
0 g
s
.57784 .76124 m .57784 .72419 L .60968 .72341 L p .707 .577 .707 r
F P
0 g
s
.60968 .72341 m .60968 .76047 L .57784 .76124 L p .707 .577 .707 r
F P
0 g
s
.57686 .29828 m .57686 .80017 L .61082 .79219 L p .707 .577 .707 r
F P
0 g
s
.64085 .61318 m .64085 .66876 L .60968 .66686 L p .707 .577 .707 r
F P
0 g
s
.60968 .66686 m .60968 .61128 L .64085 .61318 L p .707 .577 .707 r
F P
0 g
s
.64085 .72531 m .64085 .76237 L .60968 .76047 L p .707 .577 .707 r
F P
0 g
s
.60968 .76047 m .60968 .72341 L .64085 .72531 L p .707 .577 .707 r
F P
0 g
s
.61082 .79219 m .61082 .2903 L .57686 .29828 L p .707 .577 .707 r
F P
0 g
s
.25312 .68475 m .25312 .62917 L .22195 .62727 L p .707 .577 .707 r
F P
0 g
s
.25312 .62917 m .25312 .68475 L .28495 .68398 L p .707 .577 .707 r
F P
0 g
s
.28495 .68398 m .28495 .62839 L .25312 .62917 L p .707 .577 .707 r
F P
0 g
s
.50385 .87682 m .50385 .85829 L .50095 .84975 L p .707 .577 .707 r
F P
0 g
s
.28495 .62839 m .28495 .68398 L .31434 .6806 L p .707 .577 .707 r
F P
0 g
s
.31434 .6806 m .31434 .62502 L .28495 .62839 L p .707 .577 .707 r
F P
0 g
s
.40766 .79715 m .40766 .29526 L .37794 .28615 L p .707 .577 .707 r
F P
0 g
s
.40766 .29526 m .40766 .79715 L .44643 .80335 L p .707 .577 .707 r
F P
0 g
s
.50095 .84975 m .50095 .86828 L .50385 .87682 L p .707 .577 .707 r
F P
0 g
s
.22195 .68285 m .22195 .62727 L .19449 .62288 L p .707 .577 .707 r
F P
0 g
s
.22195 .62727 m .22195 .68285 L .25312 .68475 L p .707 .577 .707 r
F P
0 g
s
.31434 .62502 m .31434 .6806 L .33839 .67495 L p .707 .577 .707 r
F P
0 g
s
.33839 .67495 m .33839 .61937 L .31434 .62502 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68936 .62402 m .68936 .6796 L .66831 .67315 L p .707 .577 .707 r
F P
0 g
s
.66831 .67315 m .66831 .61757 L .68936 .62402 L p .707 .577 .707 r
F P
0 g
s
.70485 .85339 m .70485 .87191 L .70195 .86337 L p .707 .577 .707 r
F P
0 g
s
.70195 .86337 m .70195 .84485 L .70485 .85339 L p .707 .577 .707 r
F P
0 g
s
.70195 .74404 m .70195 .7811 L .68936 .77321 L p .707 .577 .707 r
F P
0 g
s
.68936 .77321 m .68936 .73616 L .70195 .74404 L p .707 .577 .707 r
F P
0 g
s
.19449 .62288 m .19449 .67846 L .22195 .68285 L p .707 .577 .707 r
F P
0 g
s
.61082 .2903 m .61082 .79219 L .63393 .78179 L p .707 .577 .707 r
F P
0 g
s
.63393 .78179 m .63393 .2799 L .61082 .2903 L p .707 .577 .707 r
F P
0 g
s
.19449 .67846 m .19449 .62288 L .17343 .61642 L p .707 .577 .707 r
F P
0 g
s
.25312 .77836 m .25312 .74131 L .22195 .73941 L p .707 .577 .707 r
F P
0 g
s
.25312 .74131 m .25312 .77836 L .28495 .77758 L p .707 .577 .707 r
F P
0 g
s
.28495 .77758 m .28495 .74053 L .25312 .74131 L p .707 .577 .707 r
F P
0 g
s
.50095 .86828 m .50095 .84975 L .50804 .84139 L p .707 .577 .707 r
F P
0 g
s
.28495 .74053 m .28495 .77758 L .31434 .7742 L p .707 .577 .707 r
F P
0 g
s
.31434 .7742 m .31434 .73715 L .28495 .74053 L p .707 .577 .707 r
F P
0 g
s
.33839 .61937 m .33839 .67495 L .35476 .66758 L p .707 .577 .707 r
F P
0 g
s
.35476 .66758 m .35476 .612 L .33839 .61937 L p .707 .577 .707 r
F P
0 g
s
.50804 .84139 m .50804 .85992 L .50095 .86828 L p .707 .577 .707 r
F P
0 g
s
.37794 .78804 m .37794 .28615 L .36016 .27502 L p .707 .577 .707 r
F P
0 g
s
.37794 .28615 m .37794 .78804 L .40766 .79715 L p .707 .577 .707 r
F P
0 g
s
.22195 .77646 m .22195 .73941 L .19449 .73501 L p .707 .577 .707 r
F P
0 g
s
.22195 .73941 m .22195 .77646 L .25312 .77836 L p .707 .577 .707 r
F P
0 g
s
.17343 .61642 m .17343 .67201 L .19449 .67846 L p .707 .577 .707 r
F P
0 g
s
.66831 .61757 m .66831 .67315 L .64085 .66876 L p .707 .577 .707 r
F P
0 g
s
.64085 .66876 m .64085 .61318 L .66831 .61757 L p .707 .577 .707 r
F P
0 g
s
.17343 .67201 m .17343 .61642 L .16084 .60854 L p .707 .577 .707 r
F P
0 g
s
.31434 .73715 m .31434 .7742 L .33839 .76855 L p .707 .577 .707 r
F P
0 g
s
.33839 .76855 m .33839 .7315 L .31434 .73715 L p .707 .577 .707 r
F P
0 g
s
.19449 .73501 m .19449 .77207 L .22195 .77646 L p .707 .577 .707 r
F P
0 g
s
.70195 .84485 m .70195 .86337 L .68936 .85549 L p .707 .577 .707 r
F P
0 g
s
.68936 .85549 m .68936 .83696 L .70195 .84485 L p .707 .577 .707 r
F P
0 g
s
.68936 .73616 m .68936 .77321 L .66831 .76676 L p .707 .577 .707 r
F P
0 g
s
.66831 .76676 m .66831 .7297 L .68936 .73616 L p .707 .577 .707 r
F P
0 g
s
.19449 .77207 m .19449 .73501 L .17343 .72856 L p .707 .577 .707 r
F P
0 g
s
.25312 .86064 m .25312 .84211 L .22195 .84021 L p .707 .577 .707 r
F P
0 g
s
.25312 .84211 m .25312 .86064 L .28495 .85986 L p .707 .577 .707 r
F P
0 g
s
.28495 .85986 m .28495 .84133 L .25312 .84211 L p .707 .577 .707 r
F P
0 g
s
.66831 .7297 m .66831 .76676 L .64085 .76237 L p .707 .577 .707 r
F P
0 g
s
.64085 .76237 m .64085 .72531 L .66831 .7297 L p .707 .577 .707 r
F P
0 g
s
.63393 .2799 m .63393 .78179 L .64393 .76998 L p .707 .577 .707 r
F P
0 g
s
.64393 .76998 m .64393 .26809 L .63393 .2799 L p .707 .577 .707 r
F P
0 g
s
.16084 .60854 m .16084 .66412 L .17343 .67201 L p .707 .577 .707 r
F P
0 g
s
.35476 .612 m .35476 .66758 L .36184 .65922 L p .707 .577 .707 r
F P
0 g
s
.36184 .65922 m .36184 .60363 L .35476 .612 L p .707 .577 .707 r
F P
0 g
s
.50804 .85992 m .50804 .84139 L .5244 .83402 L p .707 .577 .707 r
F P
0 g
s
.28495 .84133 m .28495 .85986 L .31434 .85648 L p .707 .577 .707 r
F P
0 g
s
.31434 .85648 m .31434 .83795 L .28495 .84133 L p .707 .577 .707 r
F P
0 g
s
.17343 .72856 m .17343 .76561 L .19449 .77207 L p .707 .577 .707 r
F P
0 g
s
.22195 .84021 m .22195 .85874 L .25312 .86064 L p .707 .577 .707 r
F P
0 g
s
.22195 .85874 m .22195 .84021 L .19449 .83582 L p .707 .577 .707 r
F P
0 g
s
.33839 .7315 m .33839 .76855 L .35476 .76119 L p .707 .577 .707 r
F P
0 g
s
.35476 .76119 m .35476 .72413 L .33839 .7315 L p .707 .577 .707 r
F P
0 g
s
.5244 .83402 m .5244 .85255 L .50804 .85992 L p .707 .577 .707 r
F P
0 g
s
.19449 .83582 m .19449 .85434 L .22195 .85874 L p .707 .577 .707 r
F P
0 g
s
.16084 .66412 m .16084 .60854 L .15794 .6 L p .707 .577 .707 r
F P
0 g
s
.31434 .83795 m .31434 .85648 L .33839 .85083 L p .707 .577 .707 r
F P
0 g
s
.33839 .85083 m .33839 .8323 L .31434 .83795 L p .707 .577 .707 r
F P
0 g
s
.17343 .76561 m .17343 .72856 L .16084 .72068 L p .707 .577 .707 r
F P
0 g
s
.36184 .60363 m .36184 .65922 L .35894 .65067 L p .707 .577 .707 r
F P
0 g
s
.35894 .65067 m .35894 .59509 L .36184 .60363 L p .707 .577 .707 r
F P
0 g
s
.35476 .72413 m .35476 .76119 L .36184 .75282 L p .707 .577 .707 r
F P
0 g
s
.36184 .75282 m .36184 .71577 L .35476 .72413 L p .707 .577 .707 r
F P
0 g
s
.35894 .59509 m .35894 .65067 L .34635 .64279 L p .707 .577 .707 r
F P
0 g
s
.34635 .64279 m .34635 .58721 L .35894 .59509 L p .707 .577 .707 r
F P
0 g
s
.36184 .71577 m .36184 .75282 L .35894 .74428 L p .707 .577 .707 r
F P
0 g
s
.35894 .74428 m .35894 .70723 L .36184 .71577 L p .707 .577 .707 r
F P
0 g
s
.36016 .77691 m .36016 .27502 L .35607 .26296 L p .707 .577 .707 r
F P
0 g
s
.36016 .27502 m .36016 .77691 L .37794 .78804 L p .707 .577 .707 r
F P
0 g
s
.68936 .83696 m .68936 .85549 L .66831 .84903 L p .707 .577 .707 r
F P
0 g
s
.66831 .84903 m .66831 .83051 L .68936 .83696 L p .707 .577 .707 r
F P
0 g
s
.19449 .85434 m .19449 .83582 L .17343 .82936 L p .707 .577 .707 r
F P
0 g
s
.17343 .82936 m .17343 .84789 L .19449 .85434 L p .707 .577 .707 r
F P
0 g
s
.16084 .72068 m .16084 .75773 L .17343 .76561 L p .707 .577 .707 r
F P
0 g
s
.5244 .85255 m .5244 .83402 L .54846 .82837 L p .707 .577 .707 r
F P
0 g
s
.15794 .6 m .15794 .65558 L .16084 .66412 L p .707 .577 .707 r
F P
0 g
s
.54846 .82837 m .54846 .8469 L .5244 .85255 L p .707 .577 .707 r
F P
0 g
s
.33839 .8323 m .33839 .85083 L .35476 .84346 L p .707 .577 .707 r
F P
0 g
s
.35476 .84346 m .35476 .82494 L .33839 .8323 L p .707 .577 .707 r
F P
0 g
s
.66831 .83051 m .66831 .84903 L .64085 .84464 L p .707 .577 .707 r
F P
0 g
s
.64085 .84464 m .64085 .82611 L .66831 .83051 L p .707 .577 .707 r
F P
0 g
s
.64393 .26809 m .64393 .76998 L .63984 .75792 L p .707 .577 .707 r
F P
0 g
s
.63984 .75792 m .63984 .25603 L .64393 .26809 L p .707 .577 .707 r
F P
0 g
s
.15794 .65558 m .15794 .6 L .16503 .59163 L p .707 .577 .707 r
F P
0 g
s
.17343 .84789 m .17343 .82936 L .16084 .82148 L p .707 .577 .707 r
F P
0 g
s
.16084 .75773 m .16084 .72068 L .15794 .71213 L p .707 .577 .707 r
F P
0 g
s
.54846 .8469 m .54846 .82837 L .57784 .82499 L p .707 .577 .707 r
F P
0 g
s
.16084 .82148 m .16084 .84001 L .17343 .84789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.57784 .82499 m .57784 .84352 L .54846 .8469 L p .707 .577 .707 r
F P
0 g
s
.15794 .71213 m .15794 .74919 L .16084 .75773 L p .707 .577 .707 r
F P
0 g
s
.64085 .82611 m .64085 .84464 L .60968 .84274 L p .707 .577 .707 r
F P
0 g
s
.60968 .84274 m .60968 .82421 L .64085 .82611 L p .707 .577 .707 r
F P
0 g
s
.16503 .59163 m .16503 .64722 L .15794 .65558 L p .707 .577 .707 r
F P
0 g
s
.35894 .70723 m .35894 .74428 L .34635 .7364 L p .707 .577 .707 r
F P
0 g
s
.34635 .7364 m .34635 .69934 L .35894 .70723 L p .707 .577 .707 r
F P
0 g
s
.35607 .26296 m .35607 .76485 L .36016 .77691 L p .707 .577 .707 r
F P
0 g
s
.35607 .76485 m .35607 .26296 L .36607 .25115 L p .707 .577 .707 r
F P
0 g
s
.57784 .84352 m .57784 .82499 L .60968 .82421 L p .707 .577 .707 r
F P
0 g
s
.35476 .82494 m .35476 .84346 L .36184 .8351 L p .707 .577 .707 r
F P
0 g
s
.36184 .8351 m .36184 .81657 L .35476 .82494 L p .707 .577 .707 r
F P
0 g
s
.60968 .82421 m .60968 .84274 L .57784 .84352 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .84001 m .16084 .82148 L .15794 .81294 L p .707 .577 .707 r
F P
0 g
s
.16503 .64722 m .16503 .59163 L .1814 .58427 L p .707 .577 .707 r
F P
0 g
s
.15794 .74919 m .15794 .71213 L .16503 .70377 L p .707 .577 .707 r
F P
0 g
s
.15794 .81294 m .15794 .83146 L .16084 .84001 L p .707 .577 .707 r
F P
0 g
s
.63984 .25603 m .63984 .75792 L .62206 .74679 L p .707 .577 .707 r
F P
0 g
s
.62206 .74679 m .62206 .2449 L .63984 .25603 L p .707 .577 .707 r
F P
0 g
s
.16503 .70377 m .16503 .74082 L .15794 .74919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58427 m .1814 .63985 L .16503 .64722 L p .707 .577 .707 r
F P
0 g
s
.34635 .58721 m .34635 .64279 L .3253 .63634 L p .707 .577 .707 r
F P
0 g
s
.3253 .63634 m .3253 .58075 L .34635 .58721 L p .707 .577 .707 r
F P
0 g
s
.36184 .81657 m .36184 .8351 L .35894 .82656 L p .707 .577 .707 r
F P
0 g
s
.35894 .82656 m .35894 .80803 L .36184 .81657 L p .707 .577 .707 r
F P
0 g
s
.1814 .63985 m .1814 .58427 L .20545 .57862 L p .707 .577 .707 r
F P
0 g
s
.36607 .75304 m .36607 .25115 L .38918 .24075 L p .707 .577 .707 r
F P
0 g
s
.36607 .25115 m .36607 .75304 L .35607 .76485 L p .707 .577 .707 r
F P
0 g
s
.15794 .83146 m .15794 .81294 L .16503 .80457 L p .707 .577 .707 r
F P
0 g
s
.16503 .74082 m .16503 .70377 L .1814 .6964 L p .707 .577 .707 r
F P
0 g
s
.16503 .80457 m .16503 .8231 L .15794 .83146 L p .707 .577 .707 r
F P
0 g
s
.3253 .58075 m .3253 .63634 L .29784 .63194 L p .707 .577 .707 r
F P
0 g
s
.29784 .63194 m .29784 .57636 L .3253 .58075 L p .707 .577 .707 r
F P
0 g
s
.1814 .6964 m .1814 .73346 L .16503 .74082 L p .707 .577 .707 r
F P
0 g
s
.20545 .57862 m .20545 .6342 L .1814 .63985 L p .707 .577 .707 r
F P
0 g
s
.20545 .6342 m .20545 .57862 L .23483 .57524 L p .707 .577 .707 r
F P
0 g
s
.35894 .80803 m .35894 .82656 L .34635 .81867 L p .707 .577 .707 r
F P
0 g
s
.34635 .81867 m .34635 .80015 L .35894 .80803 L p .707 .577 .707 r
F P
0 g
s
.34635 .69934 m .34635 .7364 L .3253 .72994 L p .707 .577 .707 r
F P
0 g
s
.3253 .72994 m .3253 .69289 L .34635 .69934 L p .707 .577 .707 r
F P
0 g
s
.62206 .2449 m .62206 .74679 L .59233 .73768 L p .707 .577 .707 r
F P
0 g
s
.59233 .73768 m .59233 .23579 L .62206 .2449 L p .707 .577 .707 r
F P
0 g
s
.29784 .57636 m .29784 .63194 L .26667 .63004 L p .707 .577 .707 r
F P
0 g
s
.26667 .63004 m .26667 .57446 L .29784 .57636 L p .707 .577 .707 r
F P
0 g
s
.1814 .73346 m .1814 .6964 L .20545 .69075 L p .707 .577 .707 r
F P
0 g
s
.23483 .63082 m .23483 .57524 L .26667 .57446 L p .707 .577 .707 r
F P
0 g
s
.23483 .57524 m .23483 .63082 L .20545 .6342 L p .707 .577 .707 r
F P
0 g
s
.16503 .8231 m .16503 .80457 L .1814 .79721 L p .707 .577 .707 r
F P
0 g
s
.26667 .57446 m .26667 .63004 L .23483 .63082 L p .707 .577 .707 r
F P
0 g
s
.73333 .62953 m .73333 .57395 L .70216 .57205 L p .707 .577 .707 r
F P
0 g
s
.73333 .57395 m .73333 .62953 L .76517 .62875 L p .707 .577 .707 r
F P
0 g
s
.76517 .62875 m .76517 .57317 L .73333 .57395 L p .707 .577 .707 r
F P
0 g
s
.1814 .79721 m .1814 .81573 L .16503 .8231 L p .707 .577 .707 r
F P
0 g
s
.38918 .24075 m .38918 .74264 L .36607 .75304 L p .707 .577 .707 r
F P
0 g
s
.38918 .74264 m .38918 .24075 L .42314 .23277 L p .707 .577 .707 r
F P
0 g
s
.76517 .57317 m .76517 .62875 L .79455 .62537 L p .707 .577 .707 r
F P
0 g
s
.79455 .62537 m .79455 .56979 L .76517 .57317 L p .707 .577 .707 r
F P
0 g
s
.20545 .69075 m .20545 .72781 L .1814 .73346 L p .707 .577 .707 r
F P
0 g
s
.3253 .69289 m .3253 .72994 L .29784 .72555 L p .707 .577 .707 r
F P
0 g
s
.29784 .72555 m .29784 .6885 L .3253 .69289 L p .707 .577 .707 r
F P
0 g
s
.70216 .62763 m .70216 .57205 L .6747 .56766 L p .707 .577 .707 r
F P
0 g
s
.70216 .57205 m .70216 .62763 L .73333 .62953 L p .707 .577 .707 r
F P
0 g
s
.34635 .80015 m .34635 .81867 L .3253 .81222 L p .707 .577 .707 r
F P
0 g
s
.3253 .81222 m .3253 .79369 L .34635 .80015 L p .707 .577 .707 r
F P
0 g
s
.20545 .72781 m .20545 .69075 L .23483 .68737 L p .707 .577 .707 r
F P
0 g
s
.79455 .56979 m .79455 .62537 L .8186 .61972 L p .707 .577 .707 r
F P
0 g
s
.8186 .61972 m .8186 .56414 L .79455 .56979 L p .707 .577 .707 r
F P
0 g
s
.59233 .23579 m .59233 .73768 L .55357 .73148 L p .707 .577 .707 r
F P
0 g
s
.55357 .73148 m .55357 .22959 L .59233 .23579 L p .707 .577 .707 r
F P
0 g
s
.1814 .81573 m .1814 .79721 L .20545 .79156 L p .707 .577 .707 r
F P
0 g
s
.6747 .56766 m .6747 .62324 L .70216 .62763 L p .707 .577 .707 r
F P
0 g
s
.29784 .6885 m .29784 .72555 L .26667 .72365 L p .707 .577 .707 r
F P
0 g
s
.26667 .72365 m .26667 .68659 L .29784 .6885 L p .707 .577 .707 r
F P
0 g
s
.6747 .62324 m .6747 .56766 L .65365 .5612 L p .707 .577 .707 r
F P
0 g
s
.23483 .68737 m .23483 .72443 L .20545 .72781 L p .707 .577 .707 r
F P
0 g
s
.23483 .72443 m .23483 .68737 L .26667 .68659 L p .707 .577 .707 r
F P
0 g
s
.20545 .79156 m .20545 .81008 L .1814 .81573 L p .707 .577 .707 r
F P
0 g
s
.26667 .68659 m .26667 .72365 L .23483 .72443 L p .707 .577 .707 r
F P
0 g
s
.42314 .73466 m .42314 .23277 L .46462 .228 L p .707 .577 .707 r
F P
0 g
s
.42314 .23277 m .42314 .73466 L .38918 .74264 L p .707 .577 .707 r
F P
0 g
s
.73333 .72314 m .73333 .68608 L .70216 .68418 L p .707 .577 .707 r
F P
0 g
s
.73333 .68608 m .73333 .72314 L .76517 .72236 L p .707 .577 .707 r
F P
0 g
s
.76517 .72236 m .76517 .68531 L .73333 .68608 L p .707 .577 .707 r
F P
0 g
s
.76517 .68531 m .76517 .72236 L .79455 .71898 L p .707 .577 .707 r
F P
0 g
s
.79455 .71898 m .79455 .68193 L .76517 .68531 L p .707 .577 .707 r
F P
0 g
s
.3253 .79369 m .3253 .81222 L .29784 .80783 L p .707 .577 .707 r
F P
0 g
s
.29784 .80783 m .29784 .7893 L .3253 .79369 L p .707 .577 .707 r
F P
0 g
s
.8186 .56414 m .8186 .61972 L .83497 .61236 L p .707 .577 .707 r
F P
0 g
s
.83497 .61236 m .83497 .55677 L .8186 .56414 L p .707 .577 .707 r
F P
0 g
s
.70216 .72124 m .70216 .68418 L .6747 .67979 L p .707 .577 .707 r
F P
0 g
s
.70216 .68418 m .70216 .72124 L .73333 .72314 L p .707 .577 .707 r
F P
0 g
s
.65365 .5612 m .65365 .61678 L .6747 .62324 L p .707 .577 .707 r
F P
0 g
s
.55357 .22959 m .55357 .73148 L .50956 .72879 L p .707 .577 .707 r
F P
0 g
s
.50956 .72879 m .50956 .22691 L .55357 .22959 L p .707 .577 .707 r
F P
0 g
s
.20545 .81008 m .20545 .79156 L .23483 .78818 L p .707 .577 .707 r
F P
0 g
s
.65365 .61678 m .65365 .5612 L .64105 .55332 L p .707 .577 .707 r
F P
0 g
s
.79455 .68193 m .79455 .71898 L .8186 .71333 L p .707 .577 .707 r
F P
0 g
s
.8186 .71333 m .8186 .67628 L .79455 .68193 L p .707 .577 .707 r
F P
0 g
s
.23483 .78818 m .23483 .8067 L .20545 .81008 L p .707 .577 .707 r
F P
0 g
s
.46462 .72989 m .46462 .228 L .50956 .22691 L p .707 .577 .707 r
F P
0 g
s
.46462 .228 m .46462 .72989 L .42314 .73466 L p .707 .577 .707 r
F P
0 g
s
.6747 .67979 m .6747 .71684 L .70216 .72124 L p .707 .577 .707 r
F P
0 g
s
.29784 .7893 m .29784 .80783 L .26667 .80593 L p .707 .577 .707 r
F P
0 g
s
.26667 .80593 m .26667 .7874 L .29784 .7893 L p .707 .577 .707 r
F P
0 g
s
.50956 .22691 m .50956 .72879 L .46462 .72989 L p .707 .577 .707 r
F P
0 g
s
.6747 .71684 m .6747 .67979 L .65365 .67334 L p .707 .577 .707 r
F P
0 g
s
.23483 .8067 m .23483 .78818 L .26667 .7874 L p .707 .577 .707 r
F P
0 g
s
.26667 .7874 m .26667 .80593 L .23483 .8067 L p .707 .577 .707 r
F P
0 g
s
.73333 .80541 m .73333 .78689 L .70216 .78499 L p .707 .577 .707 r
F P
0 g
s
.73333 .78689 m .73333 .80541 L .76517 .80464 L p .707 .577 .707 r
F P
0 g
s
.76517 .80464 m .76517 .78611 L .73333 .78689 L p .707 .577 .707 r
F P
0 g
s
.64105 .55332 m .64105 .6089 L .65365 .61678 L p .707 .577 .707 r
F P
0 g
s
.83497 .55677 m .83497 .61236 L .84205 .60399 L p .707 .577 .707 r
F P
0 g
s
.84205 .60399 m .84205 .54841 L .83497 .55677 L p .707 .577 .707 r
F P
0 g
s
.76517 .78611 m .76517 .80464 L .79455 .80126 L p .707 .577 .707 r
F P
0 g
s
.79455 .80126 m .79455 .78273 L .76517 .78611 L p .707 .577 .707 r
F P
0 g
s
.65365 .67334 m .65365 .71039 L .6747 .71684 L p .707 .577 .707 r
F P
0 g
s
.70216 .78499 m .70216 .80351 L .73333 .80541 L p .707 .577 .707 r
F P
0 g
s
.70216 .80351 m .70216 .78499 L .6747 .78059 L p .707 .577 .707 r
F P
0 g
s
.8186 .67628 m .8186 .71333 L .83497 .70596 L p .707 .577 .707 r
F P
0 g
s
.83497 .70596 m .83497 .66891 L .8186 .67628 L p .707 .577 .707 r
F P
0 g
s
.6747 .78059 m .6747 .79912 L .70216 .80351 L p .707 .577 .707 r
F P
0 g
s
.64105 .6089 m .64105 .55332 L .63816 .54477 L p .707 .577 .707 r
F P
0 g
s
.79455 .78273 m .79455 .80126 L .8186 .79561 L p .707 .577 .707 r
F P
0 g
s
.8186 .79561 m .8186 .77708 L .79455 .78273 L p .707 .577 .707 r
F P
0 g
s
.65365 .71039 m .65365 .67334 L .64105 .66545 L p .707 .577 .707 r
F P
0 g
s
.6747 .79912 m .6747 .78059 L .65365 .77414 L p .707 .577 .707 r
F P
0 g
s
.65365 .77414 m .65365 .79267 L .6747 .79912 L p .707 .577 .707 r
F P
0 g
s
.64105 .66545 m .64105 .70251 L .65365 .71039 L p .707 .577 .707 r
F P
0 g
s
.63816 .54477 m .63816 .60036 L .64105 .6089 L p .707 .577 .707 r
F P
0 g
s
.84205 .54841 m .84205 .60399 L .83916 .59545 L p .707 .577 .707 r
F P
0 g
s
.83916 .59545 m .83916 .53987 L .84205 .54841 L p .707 .577 .707 r
F P
0 g
s
.83497 .66891 m .83497 .70596 L .84206 .6976 L p .707 .577 .707 r
F P
0 g
s
.84206 .6976 m .84205 .66054 L .83497 .66891 L p .707 .577 .707 r
F P
0 g
s
.8186 .77708 m .8186 .79561 L .83497 .78824 L p .707 .577 .707 r
F P
0 g
s
.83497 .78824 m .83497 .76971 L .8186 .77708 L p .707 .577 .707 r
F P
0 g
s
.63816 .60036 m .63816 .54477 L .64524 .53641 L p .707 .577 .707 r
F P
0 g
s
.65365 .79267 m .65365 .77414 L .64105 .76626 L p .707 .577 .707 r
F P
0 g
s
.64105 .70251 m .64105 .66545 L .63816 .65691 L p .707 .577 .707 r
F P
0 g
s
.64105 .76626 m .64105 .78478 L .65365 .79267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .65691 m .63816 .69396 L .64105 .70251 L p .707 .577 .707 r
F P
0 g
s
.64524 .53641 m .64524 .59199 L .63816 .60036 L p .707 .577 .707 r
F P
0 g
s
.83497 .76971 m .83497 .78824 L .84206 .77988 L p .707 .577 .707 r
F P
0 g
s
.84206 .77988 m .84206 .76135 L .83497 .76971 L p .707 .577 .707 r
F P
0 g
s
.83916 .53987 m .83916 .59545 L .82657 .58757 L p .707 .577 .707 r
F P
0 g
s
.82657 .58757 m .82657 .53198 L .83916 .53987 L p .707 .577 .707 r
F P
0 g
s
.84205 .66054 m .84206 .6976 L .83916 .68906 L p .707 .577 .707 r
F P
0 g
s
.83916 .68906 m .83916 .652 L .84205 .66054 L p .707 .577 .707 r
F P
0 g
s
.39032 .59271 m .39032 .53713 L .35915 .53523 L p .707 .577 .707 r
F P
0 g
s
.39032 .53713 m .39032 .59271 L .42216 .59194 L p .707 .577 .707 r
F P
0 g
s
.42216 .59194 m .42216 .53636 L .39032 .53713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64105 .78478 m .64105 .76626 L .63816 .75771 L p .707 .577 .707 r
F P
0 g
s
.64524 .59199 m .64524 .53641 L .66161 .52904 L p .707 .577 .707 r
F P
0 g
s
.42216 .53636 m .42216 .59194 L .45154 .58856 L p .707 .577 .707 r
F P
0 g
s
.45154 .58856 m .45154 .53298 L .42216 .53636 L p .707 .577 .707 r
F P
0 g
s
.63816 .69396 m .63816 .65691 L .64524 .64855 L p .707 .577 .707 r
F P
0 g
s
.63816 .75771 m .63816 .77624 L .64105 .78478 L p .707 .577 .707 r
F P
0 g
s
.35915 .59081 m .35915 .53523 L .33169 .53084 L p .707 .577 .707 r
F P
0 g
s
.35915 .53523 m .35915 .59081 L .39032 .59271 L p .707 .577 .707 r
F P
0 g
s
.64524 .64855 m .64524 .6856 L .63816 .69396 L p .707 .577 .707 r
F P
0 g
s
.45154 .53298 m .45154 .58856 L .47559 .58291 L p .707 .577 .707 r
F P
0 g
s
.47559 .58291 m .47559 .52733 L .45154 .53298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52904 m .66161 .58462 L .64524 .59199 L p .707 .577 .707 r
F P
0 g
s
.82657 .53198 m .82657 .58757 L .80551 .58111 L p .707 .577 .707 r
F P
0 g
s
.80551 .58111 m .80551 .52553 L .82657 .53198 L p .707 .577 .707 r
F P
0 g
s
.84206 .76135 m .84206 .77988 L .83916 .77133 L p .707 .577 .707 r
F P
0 g
s
.83916 .77133 m .83916 .75281 L .84206 .76135 L p .707 .577 .707 r
F P
0 g
s
.83916 .652 m .83916 .68906 L .82657 .68117 L p .707 .577 .707 r
F P
0 g
s
.82657 .68117 m .82657 .64412 L .83916 .652 L p .707 .577 .707 r
F P
0 g
s
.33169 .53084 m .33169 .58642 L .35915 .59081 L p .707 .577 .707 r
F P
0 g
s
.33169 .58642 m .33169 .53084 L .31064 .52439 L p .707 .577 .707 r
F P
0 g
s
.66161 .58462 m .66161 .52904 L .68566 .52339 L p .707 .577 .707 r
F P
0 g
s
.39032 .68632 m .39032 .64927 L .35915 .64737 L p .707 .577 .707 r
F P
0 g
s
.39032 .64927 m .39032 .68632 L .42216 .68555 L p .707 .577 .707 r
F P
0 g
s
.42216 .68555 m .42216 .64849 L .39032 .64927 L p .707 .577 .707 r
F P
0 g
s
.63816 .77624 m .63816 .75771 L .64524 .74935 L p .707 .577 .707 r
F P
0 g
s
.64524 .6856 m .64524 .64855 L .66161 .64118 L p .707 .577 .707 r
F P
0 g
s
.42216 .64849 m .42216 .68555 L .45154 .68217 L p .707 .577 .707 r
F P
0 g
s
.45154 .68217 m .45154 .64511 L .42216 .64849 L p .707 .577 .707 r
F P
0 g
s
.47559 .52733 m .47559 .58291 L .49196 .57554 L p .707 .577 .707 r
F P
0 g
s
.49196 .57554 m .49196 .51996 L .47559 .52733 L p .707 .577 .707 r
F P
0 g
s
.64524 .74935 m .64524 .76788 L .63816 .77624 L p .707 .577 .707 r
F P
0 g
s
.35915 .68442 m .35915 .64737 L .33169 .64297 L p .707 .577 .707 r
F P
0 g
s
.35915 .64737 m .35915 .68442 L .39032 .68632 L p .707 .577 .707 r
F P
0 g
s
.31064 .52439 m .31064 .57997 L .33169 .58642 L p .707 .577 .707 r
F P
0 g
s
.80551 .52553 m .80551 .58111 L .77805 .57672 L p .707 .577 .707 r
F P
0 g
s
.77805 .57672 m .77805 .52114 L .80551 .52553 L p .707 .577 .707 r
F P
0 g
s
.66161 .64118 m .66161 .67823 L .64524 .6856 L p .707 .577 .707 r
F P
0 g
s
.68566 .52339 m .68566 .57897 L .66161 .58462 L p .707 .577 .707 r
F P
0 g
s
.31064 .57997 m .31064 .52439 L .29804 .5165 L p .707 .577 .707 r
F P
0 g
s
.45154 .64511 m .45154 .68217 L .47559 .67652 L p .707 .577 .707 r
F P
0 g
s
.47559 .67652 m .47559 .63946 L .45154 .64511 L p .707 .577 .707 r
F P
0 g
s
.33169 .64297 m .33169 .68003 L .35915 .68442 L p .707 .577 .707 r
F P
0 g
s
.68566 .57897 m .68566 .52339 L .71504 .52001 L p .707 .577 .707 r
F P
0 g
s
.83916 .75281 m .83916 .77133 L .82657 .76345 L p .707 .577 .707 r
F P
0 g
s
.82657 .76345 m .82657 .74492 L .83916 .75281 L p .707 .577 .707 r
F P
0 g
s
.82657 .64412 m .82657 .68117 L .80551 .67472 L p .707 .577 .707 r
F P
0 g
s
.80551 .67472 m .80551 .63766 L .82657 .64412 L p .707 .577 .707 r
F P
0 g
s
.33169 .68003 m .33169 .64297 L .31064 .63652 L p .707 .577 .707 r
F P
0 g
s
.77805 .52114 m .77805 .57672 L .74688 .57482 L p .707 .577 .707 r
F P
0 g
s
.74688 .57482 m .74688 .51924 L .77805 .52114 L p .707 .577 .707 r
F P
0 g
s
.39032 .7686 m .39032 .75007 L .35915 .74817 L p .707 .577 .707 r
F P
0 g
s
.39032 .75007 m .39032 .7686 L .42216 .76782 L p .707 .577 .707 r
F P
0 g
s
.42216 .76782 m .42216 .74929 L .39032 .75007 L p .707 .577 .707 r
F P
0 g
s
.66161 .67823 m .66161 .64118 L .68566 .63553 L p .707 .577 .707 r
F P
0 g
s
.29804 .5165 m .29804 .57208 L .31064 .57997 L p .707 .577 .707 r
F P
0 g
s
.71504 .5756 m .71504 .52001 L .74688 .51924 L p .707 .577 .707 r
F P
0 g
s
.71504 .52001 m .71504 .5756 L .68566 .57897 L p .707 .577 .707 r
F P
0 g
s
.49196 .51996 m .49196 .57554 L .49904 .56718 L p .707 .577 .707 r
F P
0 g
s
.49904 .56718 m .49904 .51159 L .49196 .51996 L p .707 .577 .707 r
F P
0 g
s
.64524 .76788 m .64524 .74935 L .66161 .74198 L p .707 .577 .707 r
F P
0 g
s
.42216 .74929 m .42216 .76782 L .45154 .76444 L p .707 .577 .707 r
F P
0 g
s
.45154 .76444 m .45154 .74592 L .42216 .74929 L p .707 .577 .707 r
F P
0 g
s
.31064 .63652 m .31064 .67358 L .33169 .68003 L p .707 .577 .707 r
F P
0 g
s
.74688 .51924 m .74688 .57482 L .71504 .5756 L p .707 .577 .707 r
F P
0 g
s
.35915 .74817 m .35915 .7667 L .39032 .7686 L p .707 .577 .707 r
F P
0 g
s
.35915 .7667 m .35915 .74817 L .33169 .74378 L p .707 .577 .707 r
F P
0 g
s
.47559 .63946 m .47559 .67652 L .49196 .66915 L p .707 .577 .707 r
F P
0 g
s
.49196 .66915 m .49196 .63209 L .47559 .63946 L p .707 .577 .707 r
F P
0 g
s
.66161 .74198 m .66161 .76051 L .64524 .76788 L p .707 .577 .707 r
F P
0 g
s
.68566 .63553 m .68566 .67258 L .66161 .67823 L p .707 .577 .707 r
F P
0 g
s
.33169 .74378 m .33169 .76231 L .35915 .7667 L p .707 .577 .707 r
F P
0 g
s
.80551 .63766 m .80551 .67472 L .77805 .67033 L p .707 .577 .707 r
F P
0 g
s
.77805 .67033 m .77805 .63327 L .80551 .63766 L p .707 .577 .707 r
F P
0 g
s
.29804 .57208 m .29804 .5165 L .29515 .50796 L p .707 .577 .707 r
F P
0 g
s
.45154 .74592 m .45154 .76444 L .47559 .75879 L p .707 .577 .707 r
F P
0 g
s
.47559 .75879 m .47559 .74027 L .45154 .74592 L p .707 .577 .707 r
F P
0 g
s
.31064 .67358 m .31064 .63652 L .29804 .62864 L p .707 .577 .707 r
F P
0 g
s
.82657 .74492 m .82657 .76345 L .80551 .757 L p .707 .577 .707 r
F P
0 g
s
.80551 .757 m .80551 .73847 L .82657 .74492 L p .707 .577 .707 r
F P
0 g
s
.68566 .67258 m .68566 .63553 L .71504 .63215 L p .707 .577 .707 r
F P
0 g
s
.33169 .76231 m .33169 .74378 L .31064 .73733 L p .707 .577 .707 r
F P
0 g
s
.31064 .73733 m .31064 .75585 L .33169 .76231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62864 m .29804 .66569 L .31064 .67358 L p .707 .577 .707 r
F P
0 g
s
.66161 .76051 m .66161 .74198 L .68566 .73633 L p .707 .577 .707 r
F P
0 g
s
.77805 .63327 m .77805 .67033 L .74688 .66843 L p .707 .577 .707 r
F P
0 g
s
.74688 .66843 m .74688 .63137 L .77805 .63327 L p .707 .577 .707 r
F P
0 g
s
.29515 .50796 m .29515 .56354 L .29804 .57208 L p .707 .577 .707 r
F P
0 g
s
.71504 .63215 m .71504 .6692 L .68566 .67258 L p .707 .577 .707 r
F P
0 g
s
.49904 .51159 m .49904 .56718 L .49615 .55863 L p .707 .577 .707 r
F P
0 g
s
.49615 .55863 m .49615 .50305 L .49904 .51159 L p .707 .577 .707 r
F P
0 g
s
.71504 .6692 m .71504 .63215 L .74688 .63137 L p .707 .577 .707 r
F P
0 g
s
.49196 .63209 m .49196 .66915 L .49904 .66078 L p .707 .577 .707 r
F P
0 g
s
.49904 .66078 m .49904 .62373 L .49196 .63209 L p .707 .577 .707 r
F P
0 g
s
.68566 .73633 m .68566 .75486 L .66161 .76051 L p .707 .577 .707 r
F P
0 g
s
.47559 .74027 m .47559 .75879 L .49196 .75143 L p .707 .577 .707 r
F P
0 g
s
.49196 .75143 m .49196 .7329 L .47559 .74027 L p .707 .577 .707 r
F P
0 g
s
.74688 .63137 m .74688 .66843 L .71504 .6692 L p .707 .577 .707 r
F P
0 g
s
.80551 .73847 m .80551 .757 L .77805 .7526 L p .707 .577 .707 r
F P
0 g
s
.77805 .7526 m .77805 .73408 L .80551 .73847 L p .707 .577 .707 r
F P
0 g
s
.29515 .56354 m .29515 .50796 L .30223 .49959 L p .707 .577 .707 r
F P
0 g
s
.31064 .75585 m .31064 .73733 L .29804 .72944 L p .707 .577 .707 r
F P
0 g
s
.29804 .66569 m .29804 .62864 L .29515 .62009 L p .707 .577 .707 r
F P
0 g
s
.68566 .75486 m .68566 .73633 L .71504 .73295 L p .707 .577 .707 r
F P
0 g
s
.29804 .72944 m .29804 .74797 L .31064 .75585 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71504 .73295 m .71504 .75148 L .68566 .75486 L p .707 .577 .707 r
F P
0 g
s
.29515 .62009 m .29515 .65715 L .29804 .66569 L p .707 .577 .707 r
F P
0 g
s
.77805 .73408 m .77805 .7526 L .74688 .7507 L p .707 .577 .707 r
F P
0 g
s
.74688 .7507 m .74688 .73218 L .77805 .73408 L p .707 .577 .707 r
F P
0 g
s
.30223 .49959 m .30223 .55518 L .29515 .56354 L p .707 .577 .707 r
F P
0 g
s
.71504 .75148 m .71504 .73295 L .74688 .73218 L p .707 .577 .707 r
F P
0 g
s
.49196 .7329 m .49196 .75143 L .49904 .74306 L p .707 .577 .707 r
F P
0 g
s
.49904 .74306 m .49904 .72453 L .49196 .7329 L p .707 .577 .707 r
F P
0 g
s
.49615 .50305 m .49615 .55863 L .48356 .55075 L p .707 .577 .707 r
F P
0 g
s
.48356 .55075 m .48356 .49517 L .49615 .50305 L p .707 .577 .707 r
F P
0 g
s
.49904 .62373 m .49904 .66078 L .49615 .65224 L p .707 .577 .707 r
F P
0 g
s
.49615 .65224 m .49615 .61519 L .49904 .62373 L p .707 .577 .707 r
F P
0 g
s
.74688 .73218 m .74688 .7507 L .71504 .75148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29804 .74797 m .29804 .72944 L .29515 .7209 L p .707 .577 .707 r
F P
0 g
s
.30223 .55518 m .30223 .49959 L .3186 .49223 L p .707 .577 .707 r
F P
0 g
s
.29515 .65715 m .29515 .62009 L .30223 .61173 L p .707 .577 .707 r
F P
0 g
s
.29515 .7209 m .29515 .73943 L .29804 .74797 L p .707 .577 .707 r
F P
0 g
s
.30223 .61173 m .30223 .64878 L .29515 .65715 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49223 m .3186 .54781 L .30223 .55518 L p .707 .577 .707 r
F P
0 g
s
.48356 .49517 m .48356 .55075 L .4625 .5443 L p .707 .577 .707 r
F P
0 g
s
.4625 .5443 m .4625 .48871 L .48356 .49517 L p .707 .577 .707 r
F P
0 g
s
.49904 .72453 m .49904 .74306 L .49615 .73452 L p .707 .577 .707 r
F P
0 g
s
.49615 .73452 m .49615 .71599 L .49904 .72453 L p .707 .577 .707 r
F P
0 g
s
.49615 .61519 m .49615 .65224 L .48356 .64436 L p .707 .577 .707 r
F P
0 g
s
.48356 .64436 m .48356 .6073 L .49615 .61519 L p .707 .577 .707 r
F P
0 g
s
.3186 .54781 m .3186 .49223 L .34265 .48658 L p .707 .577 .707 r
F P
0 g
s
.29515 .73943 m .29515 .7209 L .30223 .71253 L p .707 .577 .707 r
F P
0 g
s
.30223 .64878 m .30223 .61173 L .3186 .60436 L p .707 .577 .707 r
F P
0 g
s
.30223 .71253 m .30223 .73106 L .29515 .73943 L p .707 .577 .707 r
F P
0 g
s
.4625 .48871 m .4625 .5443 L .43504 .5399 L p .707 .577 .707 r
F P
0 g
s
.43504 .5399 m .43504 .48432 L .4625 .48871 L p .707 .577 .707 r
F P
0 g
s
.3186 .60436 m .3186 .64142 L .30223 .64878 L p .707 .577 .707 r
F P
0 g
s
.34265 .48658 m .34265 .54216 L .3186 .54781 L p .707 .577 .707 r
F P
0 g
s
.34265 .54216 m .34265 .48658 L .37203 .4832 L p .707 .577 .707 r
F P
0 g
s
.49615 .71599 m .49615 .73452 L .48356 .72664 L p .707 .577 .707 r
F P
0 g
s
.48356 .72664 m .48356 .70811 L .49615 .71599 L p .707 .577 .707 r
F P
0 g
s
.48356 .6073 m .48356 .64436 L .4625 .6379 L p .707 .577 .707 r
F P
0 g
s
.4625 .6379 m .4625 .60085 L .48356 .6073 L p .707 .577 .707 r
F P
0 g
s
.43504 .48432 m .43504 .5399 L .40387 .538 L p .707 .577 .707 r
F P
0 g
s
.40387 .538 m .40387 .48242 L .43504 .48432 L p .707 .577 .707 r
F P
0 g
s
.3186 .64142 m .3186 .60436 L .34265 .59871 L p .707 .577 .707 r
F P
0 g
s
.37203 .53878 m .37203 .4832 L .40387 .48242 L p .707 .577 .707 r
F P
0 g
s
.37203 .4832 m .37203 .53878 L .34265 .54216 L p .707 .577 .707 r
F P
0 g
s
.30223 .73106 m .30223 .71253 L .3186 .70517 L p .707 .577 .707 r
F P
0 g
s
.40387 .48242 m .40387 .538 L .37203 .53878 L p .707 .577 .707 r
F P
0 g
s
.3186 .70517 m .3186 .72369 L .30223 .73106 L p .707 .577 .707 r
F P
0 g
s
.34265 .59871 m .34265 .63577 L .3186 .64142 L p .707 .577 .707 r
F P
0 g
s
.4625 .60085 m .4625 .6379 L .43504 .63351 L p .707 .577 .707 r
F P
0 g
s
.43504 .63351 m .43504 .59646 L .4625 .60085 L p .707 .577 .707 r
F P
0 g
s
.48356 .70811 m .48356 .72664 L .4625 .72018 L p .707 .577 .707 r
F P
0 g
s
.4625 .72018 m .4625 .70165 L .48356 .70811 L p .707 .577 .707 r
F P
0 g
s
.34265 .63577 m .34265 .59871 L .37203 .59533 L p .707 .577 .707 r
F P
0 g
s
.3186 .72369 m .3186 .70517 L .34265 .69952 L p .707 .577 .707 r
F P
0 g
s
.43504 .59646 m .43504 .63351 L .40387 .63161 L p .707 .577 .707 r
F P
0 g
s
.40387 .63161 m .40387 .59456 L .43504 .59646 L p .707 .577 .707 r
F P
0 g
s
.37203 .59533 m .37203 .63239 L .34265 .63577 L p .707 .577 .707 r
F P
0 g
s
.37203 .63239 m .37203 .59533 L .40387 .59456 L p .707 .577 .707 r
F P
0 g
s
.34265 .69952 m .34265 .71804 L .3186 .72369 L p .707 .577 .707 r
F P
0 g
s
.40387 .59456 m .40387 .63161 L .37203 .63239 L p .707 .577 .707 r
F P
0 g
s
.4625 .70165 m .4625 .72018 L .43504 .71579 L p .707 .577 .707 r
F P
0 g
s
.43504 .71579 m .43504 .69726 L .4625 .70165 L p .707 .577 .707 r
F P
0 g
s
.34265 .71804 m .34265 .69952 L .37203 .69614 L p .707 .577 .707 r
F P
0 g
s
.37203 .69614 m .37203 .71467 L .34265 .71804 L p .707 .577 .707 r
F P
0 g
s
.43504 .69726 m .43504 .71579 L .40387 .71389 L p .707 .577 .707 r
F P
0 g
s
.40387 .71389 m .40387 .69536 L .43504 .69726 L p .707 .577 .707 r
F P
0 g
s
.37203 .71467 m .37203 .69614 L .40387 .69536 L p .707 .577 .707 r
F P
0 g
s
.40387 .69536 m .40387 .71389 L .37203 .71467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF
00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo
001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006EooaP0
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00003goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00=JEPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001JEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003mooaP00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000iOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF
1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YF
FUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP80
02eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
00=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0J0005FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000L000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP02FUH9000oOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQD00003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP0C0014Ool002aoo`03001JEP0000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`03001JEP0000AJEPD000MJEP03001JEUYF
00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH0000400001EYF001JEUYF00000UYF
00<005YFFUH00eYF1@001EYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03001JEP00
009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00003
FUH:0002FUH01000FUIJEP001EYF10001UYF00<005YFFUH01eYF1P0000=JEP00FUH00UYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
03Aoo`00;7oo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00H005YF001JEP00FUH20005FUH00`00FUH0000300001EYF001JEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@001EYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH2
00000eYF001JEP04FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEUYFFUH90007Ool5000<Ool50004FUH01000FUIJEUYF0P00;Goo000dOol50006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1`0000=JEP00FUH00UYF
0P001goo1@0047oo100000=JEP00FUH00UYF0P00;Goo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50002Ool50004FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02
FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF1P000eYF0P0027oo0`002Woo1`000eYF0`000eYF0P00;Goo000mOolI000<Ool8
0004FUH500000eYF000000070007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000oOolG000?Ool01@00FUIJEP00FUH0
2P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000iOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000;Ool01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000eOol400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH50006OolB00000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0039oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000a
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP0000@0
00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040005Ool40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03
001JEP0000=JEPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00003Goo6@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHC0004
Ool400000eYF001JEP020003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000FOol50018Ool002aoo`03001JEP00
00AJEP03001JEP0000<000ioo`D000Moo`05001JEP00001oo`060004FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3@0000=JEP00000020001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@004Woo0`00BGoo000/Ool00`00
FUH00003FUH4000AOol50007Ool40006Ool400001EYF001JEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF200035YF0`002EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YF00000P001Goo6P00?7oo000/Ool01000FUH005YF0P0015YF1@003Goo0`0027oo0P00
0UYF1P000eYF0`000UYF00@005YFFUH000EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00QJEP<0
0003FUH005YF00UJEP03001JEUYF00QJEPL000IJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`06001J
EP00001JEP001EYF00@005YFFUIJEQX000=JEP03001JEP00008000=JEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEP0000<000YJEP03001JEUYF00EJEP<0009JEP03001JEP0000YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000AJEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000000=JEP03001JEUYF009JEPD0009JEP80009JEP03001JEUYF00=JEP8000=JEP03001JEUYF
00QJEP04001JEUYFFUH400000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00
FUIJEP03FUH01000FUIJEUYF20000UYF0P001EYF00<005YFFUH01eYF1@001EYF00@005YFFUIJEP80
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH000020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000aOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF
4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04
001JEUYFFUH20002FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50004FUH00`00FUIJEP02FUH8
000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF
00<005YF00000P000UYF00@005YFFUIJEP8001Qoo`D000AJEP05001JEUYFFUH0000^Ool002ioo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
00030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20000
0eYF001JEP02FUH30005FUH01000FUIJEUYF0P007Goo0`0000=JEP00FUH00UYF0P00;Goo000`Ool3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP0300000eYF
001JEP04FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000cOol300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002OolI00000eYF001J
EP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000003Ool40003FUH01000FUIJEUYF0P008Woo0P0000=JEP000000;Goo000fOol50004FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUH000030007Ool00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH300000eYF001oo`02Ool80003FUH2000QOol2000015YF00000000;Goo
000kOol80004FUH50005FUH00`00FUIJEP02FUH5000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30002FUH30005FUH01000FUIJEP000UYF0P007Woo0`000eYF0`00;Goo0013OolC
000AOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YFFUH01P000eYF10006Woo
100000=JEP00FUH00eYF00<005YF0000;Goo0017Ool5000LOol200000eYF001JEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH200001EYF001JEUYF00001EYF00<005YF00000`0000AJEP00000001Eoo`D000EJEP03001J
EUYF009JEP8002ioo`00Agoo2@006Woo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP04001JEUYF0005FUH0
0`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool003moo`P000AJEP03
001JEUYF009JEPP001=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001JEP0015YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000moo`@0009JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@0
00=JEP03001JEUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080011oo`D000QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000MJEP03001JEUYF00EJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<001Moo`T000IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP/000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P007Woo3@000Woo
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP@000Yoo`T004Qoo`00;Goo0P0015YF00@005YFFUIJEPP001Uoo`H000AJEP05001JEUYFFUH0000`
Ool50004FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH7001OOol002aoo`03001JEP0000AJ
EP@002Moo`<00003FUH005YF009JEP03001oogoo03=ooa/006Ioo`00;7oo00<005YF00000UYF0P00
;Woo0P000eYF00<007ooOol0@7oo1@00Kgoo000/Ool00`00FUH00002000bOol01000FUIJEP00@Woo
1@00Kgoo000/Ool01000FUH00000=7oo0`00>Goo6000IGoo000/Ool20002FUH3000_Ool300000eYF
001oo`0bOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001QOol002aoo`80
00=JEP03001JEP00008002Uoo`<0009JEP03001JEP00031oo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@005eoo`00;7oo0P000eYF00<005YFFUH00UYF1@00
87oo100000=JEP00FUH00UYF00<005YF0000;Goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000FGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000/Ool200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001HOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000[Ool20004FUH00`00
FUIJEP02FUH6000BOol80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000aOol30003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
000/Ool00`00FUH00004FUH00`00FUH00002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol5
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00
FUH00003FUH3000XOol300000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF009JEPD003=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eo
oaT003Qoo`04001JEP00000bOol200000eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P00
0UYF0P00;goo0P0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<0
05YF0000E7oo002?Ool01000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?
Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eo
o`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0
05Yoo`00Ugoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002L
Ool90004FUH00`00FUIJEP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70431 m .59613 .64873 L .56496 .64683 L p .707 .577 .707 r
F P
0 g
s
.59613 .64873 m .59613 .70431 L .62796 .70353 L p .707 .577 .707 r
F P
0 g
s
.62796 .70353 m .62796 .64795 L .59613 .64873 L p .707 .577 .707 r
F P
0 g
s
.62796 .64795 m .62796 .70353 L .65734 .70015 L p .707 .577 .707 r
F P
0 g
s
.65734 .70015 m .65734 .64457 L .62796 .64795 L p .707 .577 .707 r
F P
0 g
s
.56496 .70241 m .56496 .64683 L .5375 .64243 L p .707 .577 .707 r
F P
0 g
s
.56496 .64683 m .56496 .70241 L .59613 .70431 L p .707 .577 .707 r
F P
0 g
s
.65734 .64457 m .65734 .70015 L .6814 .6945 L p .707 .577 .707 r
F P
0 g
s
.6814 .6945 m .6814 .63892 L .65734 .64457 L p .707 .577 .707 r
F P
0 g
s
.5375 .64243 m .5375 .69802 L .56496 .70241 L p .707 .577 .707 r
F P
0 g
s
.5375 .69802 m .5375 .64243 L .51644 .63598 L p .707 .577 .707 r
F P
0 g
s
.6814 .63892 m .6814 .6945 L .69777 .68714 L p .707 .577 .707 r
F P
0 g
s
.69777 .68714 m .69777 .63155 L .6814 .63892 L p .707 .577 .707 r
F P
0 g
s
.59613 .81846 m .59613 .78141 L .56496 .77951 L p .707 .577 .707 r
F P
0 g
s
.59613 .78141 m .59613 .81846 L .62796 .81769 L p .707 .577 .707 r
F P
0 g
s
.62796 .81769 m .62796 .78063 L .59613 .78141 L p .707 .577 .707 r
F P
0 g
s
.51644 .63598 m .51644 .69156 L .5375 .69802 L p .707 .577 .707 r
F P
0 g
s
.62796 .78063 m .62796 .81769 L .65735 .81431 L p .707 .577 .707 r
F P
0 g
s
.65735 .81431 m .65735 .77725 L .62796 .78063 L p .707 .577 .707 r
F P
0 g
s
.56496 .81656 m .56496 .77951 L .5375 .77512 L p .707 .577 .707 r
F P
0 g
s
.56496 .77951 m .56496 .81656 L .59613 .81846 L p .707 .577 .707 r
F P
0 g
s
.51644 .69156 m .51644 .63598 L .50385 .6281 L p .707 .577 .707 r
F P
0 g
s
.65735 .77725 m .65735 .81431 L .6814 .80866 L p .707 .577 .707 r
F P
0 g
s
.6814 .80866 m .6814 .7716 L .65735 .77725 L p .707 .577 .707 r
F P
0 g
s
.5375 .77512 m .5375 .81217 L .56496 .81656 L p .707 .577 .707 r
F P
0 g
s
.5375 .81217 m .5375 .77512 L .51644 .76866 L p .707 .577 .707 r
F P
0 g
s
.50385 .6281 m .50385 .68368 L .51644 .69156 L p .707 .577 .707 r
F P
0 g
s
.69777 .63155 m .69777 .68714 L .70485 .67877 L p .707 .577 .707 r
F P
0 g
s
.70485 .67877 m .70485 .62319 L .69777 .63155 L p .707 .577 .707 r
F P
0 g
s
.51644 .76866 m .51644 .80572 L .5375 .81217 L p .707 .577 .707 r
F P
0 g
s
.59613 .92573 m .59613 .90721 L .56496 .90531 L p .707 .577 .707 r
F P
0 g
s
.59613 .90721 m .59613 .92573 L .62796 .92496 L p .707 .577 .707 r
F P
0 g
s
.62796 .92496 m .62796 .90643 L .59613 .90721 L p .707 .577 .707 r
F P
0 g
s
.6814 .7716 m .6814 .80866 L .69777 .80129 L p .707 .577 .707 r
F P
0 g
s
.69777 .80129 m .69777 .76423 L .6814 .7716 L p .707 .577 .707 r
F P
0 g
s
.50385 .68368 m .50385 .6281 L .50095 .61955 L p .707 .577 .707 r
F P
0 g
s
.62796 .90643 m .62796 .92496 L .65735 .92158 L p .707 .577 .707 r
F P
0 g
s
.65735 .92158 m .65735 .90305 L .62796 .90643 L p .707 .577 .707 r
F P
0 g
s
.56496 .90531 m .56496 .92383 L .59613 .92573 L p .707 .577 .707 r
F P
0 g
s
.56496 .92383 m .56496 .90531 L .5375 .90091 L p .707 .577 .707 r
F P
0 g
s
.51644 .80572 m .51644 .76866 L .50385 .76078 L p .707 .577 .707 r
F P
0 g
s
.5375 .90091 m .5375 .91944 L .56496 .92383 L p .707 .577 .707 r
F P
0 g
s
.65735 .90305 m .65735 .92158 L .6814 .91593 L p .707 .577 .707 r
F P
0 g
s
.6814 .91593 m .6814 .8974 L .65735 .90305 L p .707 .577 .707 r
F P
0 g
s
.50095 .61955 m .50095 .67514 L .50385 .68368 L p .707 .577 .707 r
F P
0 g
s
.70485 .62319 m .70485 .67877 L .70195 .67023 L p .707 .577 .707 r
F P
0 g
s
.70195 .67023 m .70195 .61465 L .70485 .62319 L p .707 .577 .707 r
F P
0 g
s
.50385 .76078 m .50385 .79783 L .51644 .80572 L p .707 .577 .707 r
F P
0 g
s
.5375 .91944 m .5375 .90091 L .51644 .89446 L p .707 .577 .707 r
F P
0 g
s
.69777 .76423 m .69777 .80129 L .70485 .79292 L p .707 .577 .707 r
F P
0 g
s
.70485 .79292 m .70485 .75587 L .69777 .76423 L p .707 .577 .707 r
F P
0 g
s
.51644 .89446 m .51644 .91299 L .5375 .91944 L p .707 .577 .707 r
F P
0 g
s
.50095 .67514 m .50095 .61955 L .50804 .61119 L p .707 .577 .707 r
F P
0 g
s
.49044 .79627 m .49044 .29438 L .44643 .2917 L p .707 .577 .707 r
F P
0 g
s
.50385 .79783 m .50385 .76078 L .50095 .75223 L p .707 .577 .707 r
F P
0 g
s
.50804 .61119 m .50804 .66677 L .50095 .67514 L p .707 .577 .707 r
F P
0 g
s
.50095 .75223 m .50095 .78929 L .50385 .79783 L p .707 .577 .707 r
F P
0 g
s
.50804 .66677 m .50804 .61119 L .5244 .60382 L p .707 .577 .707 r
F P
0 g
s
.50095 .78929 m .50095 .75223 L .50804 .74387 L p .707 .577 .707 r
F P
0 g
s
.5244 .60382 m .5244 .6594 L .50804 .66677 L p .707 .577 .707 r
F P
0 g
s
.50804 .74387 m .50804 .78093 L .50095 .78929 L p .707 .577 .707 r
F P
0 g
s
.50804 .78093 m .50804 .74387 L .5244 .7365 L p .707 .577 .707 r
F P
0 g
s
.5244 .7365 m .5244 .77356 L .50804 .78093 L p .707 .577 .707 r
F P
0 g
s
.5244 .77356 m .5244 .7365 L .54846 .73085 L p .707 .577 .707 r
F P
0 g
s
.54846 .73085 m .54846 .76791 L .5244 .77356 L p .707 .577 .707 r
F P
0 g
s
.49044 .29438 m .49044 .79627 L .53538 .79517 L p .707 .577 .707 r
F P
0 g
s
.5244 .6594 m .5244 .60382 L .54846 .59817 L p .707 .577 .707 r
F P
0 g
s
.54846 .59817 m .54846 .65375 L .5244 .6594 L p .707 .577 .707 r
F P
0 g
s
.53538 .79517 m .53538 .29328 L .49044 .29438 L p .707 .577 .707 r
F P
0 g
s
.6814 .8974 m .6814 .91593 L .69777 .90856 L p .707 .577 .707 r
F P
0 g
s
.69777 .90856 m .69777 .89003 L .6814 .8974 L p .707 .577 .707 r
F P
0 g
s
.54846 .65375 m .54846 .59817 L .57784 .59479 L p .707 .577 .707 r
F P
0 g
s
.57784 .59479 m .57784 .65037 L .54846 .65375 L p .707 .577 .707 r
F P
0 g
s
.54846 .76791 m .54846 .73085 L .57784 .72747 L p .707 .577 .707 r
F P
0 g
s
.57784 .72747 m .57784 .76453 L .54846 .76791 L p .707 .577 .707 r
F P
0 g
s
.53538 .29328 m .53538 .79517 L .57686 .7904 L p .707 .577 .707 r
F P
0 g
s
.57686 .7904 m .57686 .28851 L .53538 .29328 L p .707 .577 .707 r
F P
0 g
s
.44643 .79358 m .44643 .2917 L .40766 .28549 L p .707 .577 .707 r
F P
0 g
s
.44643 .2917 m .44643 .79358 L .49044 .79627 L p .707 .577 .707 r
F P
0 g
s
.51644 .91299 m .51644 .89446 L .50385 .88658 L p .707 .577 .707 r
F P
0 g
s
.70195 .61465 m .70195 .67023 L .68936 .66234 L p .707 .577 .707 r
F P
0 g
s
.68936 .66234 m .68936 .60676 L .70195 .61465 L p .707 .577 .707 r
F P
0 g
s
.50385 .88658 m .50385 .9051 L .51644 .91299 L p .707 .577 .707 r
F P
0 g
s
.57784 .65037 m .57784 .59479 L .60968 .59402 L p .707 .577 .707 r
F P
0 g
s
.60968 .59402 m .60968 .6496 L .57784 .65037 L p .707 .577 .707 r
F P
0 g
s
.57784 .76453 m .57784 .72747 L .60968 .7267 L p .707 .577 .707 r
F P
0 g
s
.60968 .7267 m .60968 .76375 L .57784 .76453 L p .707 .577 .707 r
F P
0 g
s
.57686 .28851 m .57686 .7904 L .61082 .78242 L p .707 .577 .707 r
F P
0 g
s
.64085 .59592 m .64085 .6515 L .60968 .6496 L p .707 .577 .707 r
F P
0 g
s
.60968 .6496 m .60968 .59402 L .64085 .59592 L p .707 .577 .707 r
F P
0 g
s
.64085 .7286 m .64085 .76565 L .60968 .76375 L p .707 .577 .707 r
F P
0 g
s
.60968 .76375 m .60968 .7267 L .64085 .7286 L p .707 .577 .707 r
F P
0 g
s
.61082 .78242 m .61082 .28053 L .57686 .28851 L p .707 .577 .707 r
F P
0 g
s
.70485 .75587 m .70485 .79292 L .70195 .78438 L p .707 .577 .707 r
F P
0 g
s
.70195 .78438 m .70195 .74733 L .70485 .75587 L p .707 .577 .707 r
F P
0 g
s
.25312 .66749 m .25312 .61191 L .22195 .61001 L p .707 .577 .707 r
F P
0 g
s
.25312 .61191 m .25312 .66749 L .28495 .66672 L p .707 .577 .707 r
F P
0 g
s
.28495 .66672 m .28495 .61113 L .25312 .61191 L p .707 .577 .707 r
F P
0 g
s
.69777 .89003 m .69777 .90856 L .70485 .9002 L p .707 .577 .707 r
F P
0 g
s
.70485 .9002 m .70485 .88167 L .69777 .89003 L p .707 .577 .707 r
F P
0 g
s
.28495 .61113 m .28495 .66672 L .31434 .66334 L p .707 .577 .707 r
F P
0 g
s
.31434 .66334 m .31434 .60776 L .28495 .61113 L p .707 .577 .707 r
F P
0 g
s
.40766 .78738 m .40766 .28549 L .37794 .27638 L p .707 .577 .707 r
F P
0 g
s
.40766 .28549 m .40766 .78738 L .44643 .79358 L p .707 .577 .707 r
F P
0 g
s
.22195 .66559 m .22195 .61001 L .19449 .60562 L p .707 .577 .707 r
F P
0 g
s
.22195 .61001 m .22195 .66559 L .25312 .66749 L p .707 .577 .707 r
F P
0 g
s
.50385 .9051 m .50385 .88658 L .50095 .87803 L p .707 .577 .707 r
F P
0 g
s
.31434 .60776 m .31434 .66334 L .33839 .65769 L p .707 .577 .707 r
F P
0 g
s
.33839 .65769 m .33839 .60211 L .31434 .60776 L p .707 .577 .707 r
F P
0 g
s
.68936 .60676 m .68936 .66234 L .66831 .65589 L p .707 .577 .707 r
F P
0 g
s
.66831 .65589 m .66831 .60031 L .68936 .60676 L p .707 .577 .707 r
F P
0 g
s
.50095 .87803 m .50095 .89656 L .50385 .9051 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19449 .60562 m .19449 .6612 L .22195 .66559 L p .707 .577 .707 r
F P
0 g
s
.19449 .6612 m .19449 .60562 L .17343 .59916 L p .707 .577 .707 r
F P
0 g
s
.61082 .28053 m .61082 .78242 L .63393 .77202 L p .707 .577 .707 r
F P
0 g
s
.63393 .77202 m .63393 .27013 L .61082 .28053 L p .707 .577 .707 r
F P
0 g
s
.70195 .74733 m .70195 .78438 L .68936 .7765 L p .707 .577 .707 r
F P
0 g
s
.68936 .7765 m .68936 .73944 L .70195 .74733 L p .707 .577 .707 r
F P
0 g
s
.70485 .88167 m .70485 .9002 L .70195 .89165 L p .707 .577 .707 r
F P
0 g
s
.70195 .89165 m .70195 .87313 L .70485 .88167 L p .707 .577 .707 r
F P
0 g
s
.33839 .60211 m .33839 .65769 L .35476 .65032 L p .707 .577 .707 r
F P
0 g
s
.35476 .65032 m .35476 .59474 L .33839 .60211 L p .707 .577 .707 r
F P
0 g
s
.25312 .78165 m .25312 .74459 L .22195 .74269 L p .707 .577 .707 r
F P
0 g
s
.25312 .74459 m .25312 .78165 L .28495 .78087 L p .707 .577 .707 r
F P
0 g
s
.28495 .78087 m .28495 .74382 L .25312 .74459 L p .707 .577 .707 r
F P
0 g
s
.17343 .59916 m .17343 .65475 L .19449 .6612 L p .707 .577 .707 r
F P
0 g
s
.37794 .77827 m .37794 .27638 L .36016 .26525 L p .707 .577 .707 r
F P
0 g
s
.37794 .27638 m .37794 .77827 L .40766 .78738 L p .707 .577 .707 r
F P
0 g
s
.28495 .74382 m .28495 .78087 L .31434 .77749 L p .707 .577 .707 r
F P
0 g
s
.31434 .77749 m .31434 .74044 L .28495 .74382 L p .707 .577 .707 r
F P
0 g
s
.66831 .60031 m .66831 .65589 L .64085 .6515 L p .707 .577 .707 r
F P
0 g
s
.64085 .6515 m .64085 .59592 L .66831 .60031 L p .707 .577 .707 r
F P
0 g
s
.22195 .77975 m .22195 .74269 L .19449 .7383 L p .707 .577 .707 r
F P
0 g
s
.22195 .74269 m .22195 .77975 L .25312 .78165 L p .707 .577 .707 r
F P
0 g
s
.50095 .89656 m .50095 .87803 L .50804 .86967 L p .707 .577 .707 r
F P
0 g
s
.17343 .65475 m .17343 .59916 L .16084 .59128 L p .707 .577 .707 r
F P
0 g
s
.50804 .86967 m .50804 .8882 L .50095 .89656 L p .707 .577 .707 r
F P
0 g
s
.31434 .74044 m .31434 .77749 L .33839 .77184 L p .707 .577 .707 r
F P
0 g
s
.33839 .77184 m .33839 .73479 L .31434 .74044 L p .707 .577 .707 r
F P
0 g
s
.19449 .7383 m .19449 .77535 L .22195 .77975 L p .707 .577 .707 r
F P
0 g
s
.68936 .73944 m .68936 .7765 L .66831 .77004 L p .707 .577 .707 r
F P
0 g
s
.66831 .77004 m .66831 .73299 L .68936 .73944 L p .707 .577 .707 r
F P
0 g
s
.19449 .77535 m .19449 .7383 L .17343 .73185 L p .707 .577 .707 r
F P
0 g
s
.16084 .59128 m .16084 .64686 L .17343 .65475 L p .707 .577 .707 r
F P
0 g
s
.35476 .59474 m .35476 .65032 L .36184 .64196 L p .707 .577 .707 r
F P
0 g
s
.36184 .64196 m .36184 .58637 L .35476 .59474 L p .707 .577 .707 r
F P
0 g
s
.64085 .76565 m .64085 .7286 L .66831 .73299 L p .707 .577 .707 r
F P
0 g
s
.63393 .27013 m .63393 .77202 L .64393 .76021 L p .707 .577 .707 r
F P
0 g
s
.64393 .76021 m .64393 .25832 L .63393 .27013 L p .707 .577 .707 r
F P
0 g
s
.70195 .87313 m .70195 .89165 L .68936 .88377 L p .707 .577 .707 r
F P
0 g
s
.68936 .88377 m .68936 .86524 L .70195 .87313 L p .707 .577 .707 r
F P
0 g
s
.17343 .73185 m .17343 .7689 L .19449 .77535 L p .707 .577 .707 r
F P
0 g
s
.25312 .88892 m .25312 .87039 L .22195 .86849 L p .707 .577 .707 r
F P
0 g
s
.25312 .87039 m .25312 .88892 L .28495 .88814 L p .707 .577 .707 r
F P
0 g
s
.28495 .88814 m .28495 .86961 L .25312 .87039 L p .707 .577 .707 r
F P
0 g
s
.33839 .73479 m .33839 .77184 L .35476 .76447 L p .707 .577 .707 r
F P
0 g
s
.35476 .76447 m .35476 .72742 L .33839 .73479 L p .707 .577 .707 r
F P
0 g
s
.16084 .64686 m .16084 .59128 L .15794 .58274 L p .707 .577 .707 r
F P
0 g
s
.50804 .8882 m .50804 .86967 L .5244 .8623 L p .707 .577 .707 r
F P
0 g
s
.28495 .86961 m .28495 .88814 L .31434 .88476 L p .707 .577 .707 r
F P
0 g
s
.31434 .88476 m .31434 .86624 L .28495 .86961 L p .707 .577 .707 r
F P
0 g
s
.22195 .86849 m .22195 .88702 L .25312 .88892 L p .707 .577 .707 r
F P
0 g
s
.66831 .73299 m .66831 .77004 L .64085 .76565 L p .707 .577 .707 r
F P
0 g
s
.22195 .88702 m .22195 .86849 L .19449 .8641 L p .707 .577 .707 r
F P
0 g
s
.36184 .58637 m .36184 .64196 L .35894 .63341 L p .707 .577 .707 r
F P
0 g
s
.35894 .63341 m .35894 .57783 L .36184 .58637 L p .707 .577 .707 r
F P
0 g
s
.35476 .72742 m .35476 .76447 L .36184 .75611 L p .707 .577 .707 r
F P
0 g
s
.36184 .75611 m .36184 .71905 L .35476 .72742 L p .707 .577 .707 r
F P
0 g
s
.35894 .57783 m .35894 .63341 L .34635 .62553 L p .707 .577 .707 r
F P
0 g
s
.34635 .62553 m .34635 .56995 L .35894 .57783 L p .707 .577 .707 r
F P
0 g
s
.36184 .71905 m .36184 .75611 L .35894 .74757 L p .707 .577 .707 r
F P
0 g
s
.35894 .74757 m .35894 .71051 L .36184 .71905 L p .707 .577 .707 r
F P
0 g
s
.36016 .76714 m .36016 .26525 L .35607 .25319 L p .707 .577 .707 r
F P
0 g
s
.36016 .26525 m .36016 .76714 L .37794 .77827 L p .707 .577 .707 r
F P
0 g
s
.5244 .8623 m .5244 .88083 L .50804 .8882 L p .707 .577 .707 r
F P
0 g
s
.17343 .7689 m .17343 .73185 L .16084 .72396 L p .707 .577 .707 r
F P
0 g
s
.19449 .8641 m .19449 .88263 L .22195 .88702 L p .707 .577 .707 r
F P
0 g
s
.31434 .86624 m .31434 .88476 L .33839 .87911 L p .707 .577 .707 r
F P
0 g
s
.33839 .87911 m .33839 .86059 L .31434 .86624 L p .707 .577 .707 r
F P
0 g
s
.15794 .58274 m .15794 .63832 L .16084 .64686 L p .707 .577 .707 r
F P
0 g
s
.68936 .86524 m .68936 .88377 L .66831 .87732 L p .707 .577 .707 r
F P
0 g
s
.66831 .87732 m .66831 .85879 L .68936 .86524 L p .707 .577 .707 r
F P
0 g
s
.16084 .72396 m .16084 .76102 L .17343 .7689 L p .707 .577 .707 r
F P
0 g
s
.19449 .88263 m .19449 .8641 L .17343 .85764 L p .707 .577 .707 r
F P
0 g
s
.17343 .85764 m .17343 .87617 L .19449 .88263 L p .707 .577 .707 r
F P
0 g
s
.5244 .88083 m .5244 .8623 L .54846 .85665 L p .707 .577 .707 r
F P
0 g
s
.64393 .25832 m .64393 .76021 L .63984 .74815 L p .707 .577 .707 r
F P
0 g
s
.63984 .74815 m .63984 .24626 L .64393 .25832 L p .707 .577 .707 r
F P
0 g
s
.15794 .63832 m .15794 .58274 L .16503 .57437 L p .707 .577 .707 r
F P
0 g
s
.54846 .85665 m .54846 .87518 L .5244 .88083 L p .707 .577 .707 r
F P
0 g
s
.33839 .86059 m .33839 .87911 L .35476 .87175 L p .707 .577 .707 r
F P
0 g
s
.35476 .87175 m .35476 .85322 L .33839 .86059 L p .707 .577 .707 r
F P
0 g
s
.16084 .76102 m .16084 .72396 L .15794 .71542 L p .707 .577 .707 r
F P
0 g
s
.66831 .85879 m .66831 .87732 L .64085 .87292 L p .707 .577 .707 r
F P
0 g
s
.64085 .87292 m .64085 .8544 L .66831 .85879 L p .707 .577 .707 r
F P
0 g
s
.17343 .87617 m .17343 .85764 L .16084 .84976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57437 m .16503 .62996 L .15794 .63832 L p .707 .577 .707 r
F P
0 g
s
.54846 .87518 m .54846 .85665 L .57784 .85327 L p .707 .577 .707 r
F P
0 g
s
.15794 .71542 m .15794 .75247 L .16084 .76102 L p .707 .577 .707 r
F P
0 g
s
.35894 .71051 m .35894 .74757 L .34635 .73968 L p .707 .577 .707 r
F P
0 g
s
.34635 .73968 m .34635 .70263 L .35894 .71051 L p .707 .577 .707 r
F P
0 g
s
.35607 .25319 m .35607 .75508 L .36016 .76714 L p .707 .577 .707 r
F P
0 g
s
.35607 .75508 m .35607 .25319 L .36607 .24138 L p .707 .577 .707 r
F P
0 g
s
.16084 .84976 m .16084 .86829 L .17343 .87617 L p .707 .577 .707 r
F P
0 g
s
.57784 .85327 m .57784 .8718 L .54846 .87518 L p .707 .577 .707 r
F P
0 g
s
.64085 .8544 m .64085 .87292 L .60968 .87102 L p .707 .577 .707 r
F P
0 g
s
.60968 .87102 m .60968 .8525 L .64085 .8544 L p .707 .577 .707 r
F P
0 g
s
.57784 .8718 m .57784 .85327 L .60968 .8525 L p .707 .577 .707 r
F P
0 g
s
.35476 .85322 m .35476 .87175 L .36184 .86338 L p .707 .577 .707 r
F P
0 g
s
.36184 .86338 m .36184 .84485 L .35476 .85322 L p .707 .577 .707 r
F P
0 g
s
.16503 .62996 m .16503 .57437 L .1814 .56701 L p .707 .577 .707 r
F P
0 g
s
.60968 .8525 m .60968 .87102 L .57784 .8718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .75247 m .15794 .71542 L .16503 .70706 L p .707 .577 .707 r
F P
0 g
s
.16084 .86829 m .16084 .84976 L .15794 .84122 L p .707 .577 .707 r
F P
0 g
s
.63984 .24626 m .63984 .74815 L .62206 .73702 L p .707 .577 .707 r
F P
0 g
s
.62206 .73702 m .62206 .23513 L .63984 .24626 L p .707 .577 .707 r
F P
0 g
s
.1814 .56701 m .1814 .62259 L .16503 .62996 L p .707 .577 .707 r
F P
0 g
s
.34635 .56995 m .34635 .62553 L .3253 .61908 L p .707 .577 .707 r
F P
0 g
s
.3253 .61908 m .3253 .56349 L .34635 .56995 L p .707 .577 .707 r
F P
0 g
s
.15794 .84122 m .15794 .85975 L .16084 .86829 L p .707 .577 .707 r
F P
0 g
s
.16503 .70706 m .16503 .74411 L .15794 .75247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .62259 m .1814 .56701 L .20545 .56136 L p .707 .577 .707 r
F P
0 g
s
.36184 .84485 m .36184 .86338 L .35894 .85484 L p .707 .577 .707 r
F P
0 g
s
.35894 .85484 m .35894 .83631 L .36184 .84485 L p .707 .577 .707 r
F P
0 g
s
.36607 .74327 m .36607 .24138 L .38918 .23098 L p .707 .577 .707 r
F P
0 g
s
.36607 .24138 m .36607 .74327 L .35607 .75508 L p .707 .577 .707 r
F P
0 g
s
.16503 .74411 m .16503 .70706 L .1814 .69969 L p .707 .577 .707 r
F P
0 g
s
.3253 .56349 m .3253 .61908 L .29784 .61468 L p .707 .577 .707 r
F P
0 g
s
.29784 .61468 m .29784 .5591 L .3253 .56349 L p .707 .577 .707 r
F P
0 g
s
.20545 .56136 m .20545 .61694 L .1814 .62259 L p .707 .577 .707 r
F P
0 g
s
.15794 .85975 m .15794 .84122 L .16503 .83285 L p .707 .577 .707 r
F P
0 g
s
.20545 .61694 m .20545 .56136 L .23483 .55798 L p .707 .577 .707 r
F P
0 g
s
.16503 .83285 m .16503 .85138 L .15794 .85975 L p .707 .577 .707 r
F P
0 g
s
.1814 .69969 m .1814 .73674 L .16503 .74411 L p .707 .577 .707 r
F P
0 g
s
.62206 .23513 m .62206 .73702 L .59233 .72791 L p .707 .577 .707 r
F P
0 g
s
.59233 .72791 m .59233 .22602 L .62206 .23513 L p .707 .577 .707 r
F P
0 g
s
.34635 .70263 m .34635 .73968 L .3253 .73323 L p .707 .577 .707 r
F P
0 g
s
.3253 .73323 m .3253 .69617 L .34635 .70263 L p .707 .577 .707 r
F P
0 g
s
.29784 .5591 m .29784 .61468 L .26667 .61278 L p .707 .577 .707 r
F P
0 g
s
.26667 .61278 m .26667 .5572 L .29784 .5591 L p .707 .577 .707 r
F P
0 g
s
.23483 .61356 m .23483 .55798 L .26667 .5572 L p .707 .577 .707 r
F P
0 g
s
.23483 .55798 m .23483 .61356 L .20545 .61694 L p .707 .577 .707 r
F P
0 g
s
.35894 .83631 m .35894 .85484 L .34635 .84695 L p .707 .577 .707 r
F P
0 g
s
.34635 .84695 m .34635 .82843 L .35894 .83631 L p .707 .577 .707 r
F P
0 g
s
.26667 .5572 m .26667 .61278 L .23483 .61356 L p .707 .577 .707 r
F P
0 g
s
.1814 .73674 m .1814 .69969 L .20545 .69404 L p .707 .577 .707 r
F P
0 g
s
.73333 .61227 m .73333 .55669 L .70216 .55479 L p .707 .577 .707 r
F P
0 g
s
.73333 .55669 m .73333 .61227 L .76517 .61149 L p .707 .577 .707 r
F P
0 g
s
.76517 .61149 m .76517 .55591 L .73333 .55669 L p .707 .577 .707 r
F P
0 g
s
.76517 .55591 m .76517 .61149 L .79455 .60811 L p .707 .577 .707 r
F P
0 g
s
.79455 .60811 m .79455 .55253 L .76517 .55591 L p .707 .577 .707 r
F P
0 g
s
.38918 .23098 m .38918 .73287 L .36607 .74327 L p .707 .577 .707 r
F P
0 g
s
.38918 .73287 m .38918 .23098 L .42314 .22301 L p .707 .577 .707 r
F P
0 g
s
.70216 .61037 m .70216 .55479 L .6747 .5504 L p .707 .577 .707 r
F P
0 g
s
.70216 .55479 m .70216 .61037 L .73333 .61227 L p .707 .577 .707 r
F P
0 g
s
.16503 .85138 m .16503 .83285 L .1814 .82549 L p .707 .577 .707 r
F P
0 g
s
.20545 .69404 m .20545 .73109 L .1814 .73674 L p .707 .577 .707 r
F P
0 g
s
.3253 .69617 m .3253 .73323 L .29784 .72884 L p .707 .577 .707 r
F P
0 g
s
.29784 .72884 m .29784 .69178 L .3253 .69617 L p .707 .577 .707 r
F P
0 g
s
.1814 .82549 m .1814 .84401 L .16503 .85138 L p .707 .577 .707 r
F P
0 g
s
.79455 .55253 m .79455 .60811 L .8186 .60246 L p .707 .577 .707 r
F P
0 g
s
.8186 .60246 m .8186 .54688 L .79455 .55253 L p .707 .577 .707 r
F P
0 g
s
.20545 .73109 m .20545 .69404 L .23483 .69066 L p .707 .577 .707 r
F P
0 g
s
.59233 .22602 m .59233 .72791 L .55357 .72171 L p .707 .577 .707 r
F P
0 g
s
.55357 .72171 m .55357 .21982 L .59233 .22602 L p .707 .577 .707 r
F P
0 g
s
.6747 .5504 m .6747 .60598 L .70216 .61037 L p .707 .577 .707 r
F P
0 g
s
.6747 .60598 m .6747 .5504 L .65365 .54394 L p .707 .577 .707 r
F P
0 g
s
.34635 .82843 m .34635 .84695 L .3253 .8405 L p .707 .577 .707 r
F P
0 g
s
.3253 .8405 m .3253 .82197 L .34635 .82843 L p .707 .577 .707 r
F P
0 g
s
.29784 .69178 m .29784 .72884 L .26667 .72694 L p .707 .577 .707 r
F P
0 g
s
.26667 .72694 m .26667 .68988 L .29784 .69178 L p .707 .577 .707 r
F P
0 g
s
.23483 .69066 m .23483 .72771 L .20545 .73109 L p .707 .577 .707 r
F P
0 g
s
.23483 .72771 m .23483 .69066 L .26667 .68988 L p .707 .577 .707 r
F P
0 g
s
.42314 .72489 m .42314 .22301 L .46462 .21824 L p .707 .577 .707 r
F P
0 g
s
.42314 .22301 m .42314 .72489 L .38918 .73287 L p .707 .577 .707 r
F P
0 g
s
.1814 .84401 m .1814 .82549 L .20545 .81984 L p .707 .577 .707 r
F P
0 g
s
.26667 .68988 m .26667 .72694 L .23483 .72771 L p .707 .577 .707 r
F P
0 g
s
.8186 .54688 m .8186 .60246 L .83497 .5951 L p .707 .577 .707 r
F P
0 g
s
.83497 .5951 m .83497 .53951 L .8186 .54688 L p .707 .577 .707 r
F P
0 g
s
.73333 .72642 m .73333 .68937 L .70216 .68747 L p .707 .577 .707 r
F P
0 g
s
.73333 .68937 m .73333 .72642 L .76517 .72565 L p .707 .577 .707 r
F P
0 g
s
.76517 .72565 m .76517 .68859 L .73333 .68937 L p .707 .577 .707 r
F P
0 g
s
.65365 .54394 m .65365 .59952 L .6747 .60598 L p .707 .577 .707 r
F P
0 g
s
.76517 .68859 m .76517 .72565 L .79455 .72227 L p .707 .577 .707 r
F P
0 g
s
.79455 .72227 m .79455 .68521 L .76517 .68859 L p .707 .577 .707 r
F P
0 g
s
.20545 .81984 m .20545 .83836 L .1814 .84401 L p .707 .577 .707 r
F P
0 g
s
.70216 .72452 m .70216 .68747 L .6747 .68308 L p .707 .577 .707 r
F P
0 g
s
.70216 .68747 m .70216 .72452 L .73333 .72642 L p .707 .577 .707 r
F P
0 g
s
.55357 .21982 m .55357 .72171 L .50956 .71903 L p .707 .577 .707 r
F P
0 g
s
.50956 .71903 m .50956 .21714 L .55357 .21982 L p .707 .577 .707 r
F P
0 g
s
.65365 .59952 m .65365 .54394 L .64105 .53606 L p .707 .577 .707 r
F P
0 g
s
.3253 .82197 m .3253 .8405 L .29784 .83611 L p .707 .577 .707 r
F P
0 g
s
.29784 .83611 m .29784 .81758 L .3253 .82197 L p .707 .577 .707 r
F P
0 g
s
.46462 .72012 m .46462 .21824 L .50956 .21714 L p .707 .577 .707 r
F P
0 g
s
.46462 .21824 m .46462 .72012 L .42314 .72489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68521 m .79455 .72227 L .8186 .71662 L p .707 .577 .707 r
F P
0 g
s
.8186 .71662 m .8186 .67956 L .79455 .68521 L p .707 .577 .707 r
F P
0 g
s
.50956 .21714 m .50956 .71903 L .46462 .72012 L p .707 .577 .707 r
F P
0 g
s
.6747 .68308 m .6747 .72013 L .70216 .72452 L p .707 .577 .707 r
F P
0 g
s
.20545 .83836 m .20545 .81984 L .23483 .81646 L p .707 .577 .707 r
F P
0 g
s
.6747 .72013 m .6747 .68308 L .65365 .67662 L p .707 .577 .707 r
F P
0 g
s
.23483 .81646 m .23483 .83499 L .20545 .83836 L p .707 .577 .707 r
F P
0 g
s
.64105 .53606 m .64105 .59164 L .65365 .59952 L p .707 .577 .707 r
F P
0 g
s
.83497 .53951 m .83497 .5951 L .84205 .58673 L p .707 .577 .707 r
F P
0 g
s
.84205 .58673 m .84205 .53115 L .83497 .53951 L p .707 .577 .707 r
F P
0 g
s
.29784 .81758 m .29784 .83611 L .26667 .83421 L p .707 .577 .707 r
F P
0 g
s
.26667 .83421 m .26667 .81568 L .29784 .81758 L p .707 .577 .707 r
F P
0 g
s
.23483 .83499 m .23483 .81646 L .26667 .81568 L p .707 .577 .707 r
F P
0 g
s
.65365 .67662 m .65365 .71368 L .6747 .72013 L p .707 .577 .707 r
F P
0 g
s
.26667 .81568 m .26667 .83421 L .23483 .83499 L p .707 .577 .707 r
F P
0 g
s
.73333 .8337 m .73333 .81517 L .70216 .81327 L p .707 .577 .707 r
F P
0 g
s
.73333 .81517 m .73333 .8337 L .76517 .83292 L p .707 .577 .707 r
F P
0 g
s
.76517 .83292 m .76517 .81439 L .73333 .81517 L p .707 .577 .707 r
F P
0 g
s
.8186 .67956 m .8186 .71662 L .83497 .70925 L p .707 .577 .707 r
F P
0 g
s
.83497 .70925 m .83497 .6722 L .8186 .67956 L p .707 .577 .707 r
F P
0 g
s
.64105 .59164 m .64105 .53606 L .63816 .52751 L p .707 .577 .707 r
F P
0 g
s
.76517 .81439 m .76517 .83292 L .79455 .82954 L p .707 .577 .707 r
F P
0 g
s
.79455 .82954 m .79455 .81101 L .76517 .81439 L p .707 .577 .707 r
F P
0 g
s
.70216 .81327 m .70216 .8318 L .73333 .8337 L p .707 .577 .707 r
F P
0 g
s
.70216 .8318 m .70216 .81327 L .6747 .80888 L p .707 .577 .707 r
F P
0 g
s
.65365 .71368 m .65365 .67662 L .64105 .66874 L p .707 .577 .707 r
F P
0 g
s
.6747 .80888 m .6747 .8274 L .70216 .8318 L p .707 .577 .707 r
F P
0 g
s
.79455 .81101 m .79455 .82954 L .8186 .82389 L p .707 .577 .707 r
F P
0 g
s
.8186 .82389 m .8186 .80536 L .79455 .81101 L p .707 .577 .707 r
F P
0 g
s
.63816 .52751 m .63816 .5831 L .64105 .59164 L p .707 .577 .707 r
F P
0 g
s
.84205 .53115 m .84205 .58673 L .83916 .57819 L p .707 .577 .707 r
F P
0 g
s
.83916 .57819 m .83916 .52261 L .84205 .53115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66874 m .64105 .70579 L .65365 .71368 L p .707 .577 .707 r
F P
0 g
s
.6747 .8274 m .6747 .80888 L .65365 .80242 L p .707 .577 .707 r
F P
0 g
s
.83497 .6722 m .83497 .70925 L .84206 .70089 L p .707 .577 .707 r
F P
0 g
s
.84206 .70089 m .84205 .66383 L .83497 .6722 L p .707 .577 .707 r
F P
0 g
s
.65365 .80242 m .65365 .82095 L .6747 .8274 L p .707 .577 .707 r
F P
0 g
s
.63816 .5831 m .63816 .52751 L .64524 .51915 L p .707 .577 .707 r
F P
0 g
s
.8186 .80536 m .8186 .82389 L .83497 .81652 L p .707 .577 .707 r
F P
0 g
s
.83497 .81652 m .83497 .798 L .8186 .80536 L p .707 .577 .707 r
F P
0 g
s
.64105 .70579 m .64105 .66874 L .63816 .6602 L p .707 .577 .707 r
F P
0 g
s
.65365 .82095 m .65365 .80242 L .64105 .79454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .51915 m .64524 .57473 L .63816 .5831 L p .707 .577 .707 r
F P
0 g
s
.63816 .6602 m .63816 .69725 L .64105 .70579 L p .707 .577 .707 r
F P
0 g
s
.83916 .52261 m .83916 .57819 L .82657 .57031 L p .707 .577 .707 r
F P
0 g
s
.82657 .57031 m .82657 .51472 L .83916 .52261 L p .707 .577 .707 r
F P
0 g
s
.64105 .79454 m .64105 .81307 L .65365 .82095 L p .707 .577 .707 r
F P
0 g
s
.84205 .66383 m .84206 .70089 L .83916 .69234 L p .707 .577 .707 r
F P
0 g
s
.83916 .69234 m .83916 .65529 L .84205 .66383 L p .707 .577 .707 r
F P
0 g
s
.39032 .57545 m .39032 .51987 L .35915 .51797 L p .707 .577 .707 r
F P
0 g
s
.39032 .51987 m .39032 .57545 L .42216 .57468 L p .707 .577 .707 r
F P
0 g
s
.42216 .57468 m .42216 .5191 L .39032 .51987 L p .707 .577 .707 r
F P
0 g
s
.83497 .798 m .83497 .81652 L .84206 .80816 L p .707 .577 .707 r
F P
0 g
s
.84206 .80816 m .84206 .78963 L .83497 .798 L p .707 .577 .707 r
F P
0 g
s
.64524 .57473 m .64524 .51915 L .66161 .51178 L p .707 .577 .707 r
F P
0 g
s
.42216 .5191 m .42216 .57468 L .45154 .5713 L p .707 .577 .707 r
F P
0 g
s
.45154 .5713 m .45154 .51572 L .42216 .5191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.35915 .57355 m .35915 .51797 L .33169 .51358 L p .707 .577 .707 r
F P
0 g
s
.35915 .51797 m .35915 .57355 L .39032 .57545 L p .707 .577 .707 r
F P
0 g
s
.63816 .69725 m .63816 .6602 L .64524 .65183 L p .707 .577 .707 r
F P
0 g
s
.64105 .81307 m .64105 .79454 L .63816 .786 L p .707 .577 .707 r
F P
0 g
s
.45154 .51572 m .45154 .5713 L .47559 .56565 L p .707 .577 .707 r
F P
0 g
s
.47559 .56565 m .47559 .51007 L .45154 .51572 L p .707 .577 .707 r
F P
0 g
s
.66161 .51178 m .66161 .56736 L .64524 .57473 L p .707 .577 .707 r
F P
0 g
s
.82657 .51472 m .82657 .57031 L .80551 .56385 L p .707 .577 .707 r
F P
0 g
s
.80551 .56385 m .80551 .50827 L .82657 .51472 L p .707 .577 .707 r
F P
0 g
s
.63816 .786 m .63816 .80452 L .64105 .81307 L p .707 .577 .707 r
F P
0 g
s
.64524 .65183 m .64524 .68889 L .63816 .69725 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.33169 .51358 m .33169 .56916 L .35915 .57355 L p .707 .577 .707 r
F P
0 g
s
.33169 .56916 m .33169 .51358 L .31064 .50713 L p .707 .577 .707 r
F P
0 g
s
.83916 .65529 m .83916 .69234 L .82657 .68446 L p .707 .577 .707 r
F P
0 g
s
.82657 .68446 m .82657 .64741 L .83916 .65529 L p .707 .577 .707 r
F P
0 g
s
.66161 .56736 m .66161 .51178 L .68566 .50613 L p .707 .577 .707 r
F P
0 g
s
.84206 .78963 m .84206 .80816 L .83916 .79962 L p .707 .577 .707 r
F P
0 g
s
.83916 .79962 m .83916 .78109 L .84206 .78963 L p .707 .577 .707 r
F P
0 g
s
.47559 .51007 m .47559 .56565 L .49196 .55828 L p .707 .577 .707 r
F P
0 g
s
.49196 .55828 m .49196 .5027 L .47559 .51007 L p .707 .577 .707 r
F P
0 g
s
.39032 .68961 m .39032 .65255 L .35915 .65065 L p .707 .577 .707 r
F P
0 g
s
.39032 .65255 m .39032 .68961 L .42216 .68883 L p .707 .577 .707 r
F P
0 g
s
.42216 .68883 m .42216 .65178 L .39032 .65255 L p .707 .577 .707 r
F P
0 g
s
.31064 .50713 m .31064 .56271 L .33169 .56916 L p .707 .577 .707 r
F P
0 g
s
.64524 .68889 m .64524 .65183 L .66161 .64446 L p .707 .577 .707 r
F P
0 g
s
.42216 .65178 m .42216 .68883 L .45154 .68545 L p .707 .577 .707 r
F P
0 g
s
.45154 .68545 m .45154 .6484 L .42216 .65178 L p .707 .577 .707 r
F P
0 g
s
.80551 .50827 m .80551 .56385 L .77805 .55946 L p .707 .577 .707 r
F P
0 g
s
.77805 .55946 m .77805 .50388 L .80551 .50827 L p .707 .577 .707 r
F P
0 g
s
.35915 .68771 m .35915 .65065 L .33169 .64626 L p .707 .577 .707 r
F P
0 g
s
.35915 .65065 m .35915 .68771 L .39032 .68961 L p .707 .577 .707 r
F P
0 g
s
.68566 .50613 m .68566 .56172 L .66161 .56736 L p .707 .577 .707 r
F P
0 g
s
.63816 .80452 m .63816 .786 L .64524 .77763 L p .707 .577 .707 r
F P
0 g
s
.31064 .56271 m .31064 .50713 L .29804 .49924 L p .707 .577 .707 r
F P
0 g
s
.68566 .56172 m .68566 .50613 L .71504 .50275 L p .707 .577 .707 r
F P
0 g
s
.64524 .77763 m .64524 .79616 L .63816 .80452 L p .707 .577 .707 r
F P
0 g
s
.66161 .64446 m .66161 .68152 L .64524 .68889 L p .707 .577 .707 r
F P
0 g
s
.45154 .6484 m .45154 .68545 L .47559 .6798 L p .707 .577 .707 r
F P
0 g
s
.47559 .6798 m .47559 .64275 L .45154 .6484 L p .707 .577 .707 r
F P
0 g
s
.33169 .64626 m .33169 .68332 L .35915 .68771 L p .707 .577 .707 r
F P
0 g
s
.82657 .64741 m .82657 .68446 L .80551 .67801 L p .707 .577 .707 r
F P
0 g
s
.80551 .67801 m .80551 .64095 L .82657 .64741 L p .707 .577 .707 r
F P
0 g
s
.77805 .50388 m .77805 .55946 L .74688 .55756 L p .707 .577 .707 r
F P
0 g
s
.74688 .55756 m .74688 .50198 L .77805 .50388 L p .707 .577 .707 r
F P
0 g
s
.33169 .68332 m .33169 .64626 L .31064 .63981 L p .707 .577 .707 r
F P
0 g
s
.29804 .49924 m .29804 .55482 L .31064 .56271 L p .707 .577 .707 r
F P
0 g
s
.71504 .55834 m .71504 .50275 L .74688 .50198 L p .707 .577 .707 r
F P
0 g
s
.71504 .50275 m .71504 .55834 L .68566 .56172 L p .707 .577 .707 r
F P
0 g
s
.49196 .5027 m .49196 .55828 L .49904 .54992 L p .707 .577 .707 r
F P
0 g
s
.49904 .54992 m .49904 .49433 L .49196 .5027 L p .707 .577 .707 r
F P
0 g
s
.83916 .78109 m .83916 .79962 L .82657 .79173 L p .707 .577 .707 r
F P
0 g
s
.82657 .79173 m .82657 .7732 L .83916 .78109 L p .707 .577 .707 r
F P
0 g
s
.74688 .50198 m .74688 .55756 L .71504 .55834 L p .707 .577 .707 r
F P
0 g
s
.66161 .68152 m .66161 .64446 L .68566 .63881 L p .707 .577 .707 r
F P
0 g
s
.31064 .63981 m .31064 .67686 L .33169 .68332 L p .707 .577 .707 r
F P
0 g
s
.39032 .79688 m .39032 .77835 L .35915 .77645 L p .707 .577 .707 r
F P
0 g
s
.39032 .77835 m .39032 .79688 L .42216 .7961 L p .707 .577 .707 r
F P
0 g
s
.42216 .7961 m .42216 .77758 L .39032 .77835 L p .707 .577 .707 r
F P
0 g
s
.47559 .64275 m .47559 .6798 L .49196 .67244 L p .707 .577 .707 r
F P
0 g
s
.49196 .67244 m .49196 .63538 L .47559 .64275 L p .707 .577 .707 r
F P
0 g
s
.29804 .55482 m .29804 .49924 L .29515 .4907 L p .707 .577 .707 r
F P
0 g
s
.64524 .79616 m .64524 .77763 L .66161 .77026 L p .707 .577 .707 r
F P
0 g
s
.42216 .77758 m .42216 .7961 L .45154 .79272 L p .707 .577 .707 r
F P
0 g
s
.45154 .79272 m .45154 .7742 L .42216 .77758 L p .707 .577 .707 r
F P
0 g
s
.68566 .63881 m .68566 .67587 L .66161 .68152 L p .707 .577 .707 r
F P
0 g
s
.35915 .77645 m .35915 .79498 L .39032 .79688 L p .707 .577 .707 r
F P
0 g
s
.80551 .64095 m .80551 .67801 L .77805 .67361 L p .707 .577 .707 r
F P
0 g
s
.77805 .67361 m .77805 .63656 L .80551 .64095 L p .707 .577 .707 r
F P
0 g
s
.35915 .79498 m .35915 .77645 L .33169 .77206 L p .707 .577 .707 r
F P
0 g
s
.66161 .77026 m .66161 .78879 L .64524 .79616 L p .707 .577 .707 r
F P
0 g
s
.31064 .67686 m .31064 .63981 L .29804 .63192 L p .707 .577 .707 r
F P
0 g
s
.33169 .77206 m .33169 .79059 L .35915 .79498 L p .707 .577 .707 r
F P
0 g
s
.68566 .67587 m .68566 .63881 L .71504 .63544 L p .707 .577 .707 r
F P
0 g
s
.45154 .7742 m .45154 .79272 L .47559 .78707 L p .707 .577 .707 r
F P
0 g
s
.47559 .78707 m .47559 .76855 L .45154 .7742 L p .707 .577 .707 r
F P
0 g
s
.29515 .4907 m .29515 .54628 L .29804 .55482 L p .707 .577 .707 r
F P
0 g
s
.82657 .7732 m .82657 .79173 L .80551 .78528 L p .707 .577 .707 r
F P
0 g
s
.80551 .78528 m .80551 .76675 L .82657 .7732 L p .707 .577 .707 r
F P
0 g
s
.49904 .49433 m .49904 .54992 L .49615 .54137 L p .707 .577 .707 r
F P
0 g
s
.49615 .54137 m .49615 .48579 L .49904 .49433 L p .707 .577 .707 r
F P
0 g
s
.29804 .63192 m .29804 .66898 L .31064 .67686 L p .707 .577 .707 r
F P
0 g
s
.77805 .63656 m .77805 .67361 L .74688 .67171 L p .707 .577 .707 r
F P
0 g
s
.74688 .67171 m .74688 .63466 L .77805 .63656 L p .707 .577 .707 r
F P
0 g
s
.33169 .79059 m .33169 .77206 L .31064 .76561 L p .707 .577 .707 r
F P
0 g
s
.71504 .63544 m .71504 .67249 L .68566 .67587 L p .707 .577 .707 r
F P
0 g
s
.71504 .67249 m .71504 .63544 L .74688 .63466 L p .707 .577 .707 r
F P
0 g
s
.49196 .63538 m .49196 .67244 L .49904 .66407 L p .707 .577 .707 r
F P
0 g
s
.49904 .66407 m .49904 .62702 L .49196 .63538 L p .707 .577 .707 r
F P
0 g
s
.31064 .76561 m .31064 .78413 L .33169 .79059 L p .707 .577 .707 r
F P
0 g
s
.66161 .78879 m .66161 .77026 L .68566 .76461 L p .707 .577 .707 r
F P
0 g
s
.74688 .63466 m .74688 .67171 L .71504 .67249 L p .707 .577 .707 r
F P
0 g
s
.29515 .54628 m .29515 .4907 L .30223 .48233 L p .707 .577 .707 r
F P
0 g
s
.68566 .76461 m .68566 .78314 L .66161 .78879 L p .707 .577 .707 r
F P
0 g
s
.47559 .76855 m .47559 .78707 L .49196 .77971 L p .707 .577 .707 r
F P
0 g
s
.49196 .77971 m .49196 .76118 L .47559 .76855 L p .707 .577 .707 r
F P
0 g
s
.29804 .66898 m .29804 .63192 L .29515 .62338 L p .707 .577 .707 r
F P
0 g
s
.80551 .76675 m .80551 .78528 L .77805 .78089 L p .707 .577 .707 r
F P
0 g
s
.77805 .78089 m .77805 .76236 L .80551 .76675 L p .707 .577 .707 r
F P
0 g
s
.31064 .78413 m .31064 .76561 L .29804 .75772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48233 m .30223 .53792 L .29515 .54628 L p .707 .577 .707 r
F P
0 g
s
.68566 .78314 m .68566 .76461 L .71504 .76123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62338 m .29515 .66044 L .29804 .66898 L p .707 .577 .707 r
F P
0 g
s
.49615 .48579 m .49615 .54137 L .48356 .53349 L p .707 .577 .707 r
F P
0 g
s
.48356 .53349 m .48356 .47791 L .49615 .48579 L p .707 .577 .707 r
F P
0 g
s
.29804 .75772 m .29804 .77625 L .31064 .78413 L p .707 .577 .707 r
F P
0 g
s
.71504 .76123 m .71504 .77976 L .68566 .78314 L p .707 .577 .707 r
F P
0 g
s
.49904 .62702 m .49904 .66407 L .49615 .65553 L p .707 .577 .707 r
F P
0 g
s
.49615 .65553 m .49615 .61847 L .49904 .62702 L p .707 .577 .707 r
F P
0 g
s
.77805 .76236 m .77805 .78089 L .74688 .77898 L p .707 .577 .707 r
F P
0 g
s
.74688 .77898 m .74688 .76046 L .77805 .76236 L p .707 .577 .707 r
F P
0 g
s
.71504 .77976 m .71504 .76123 L .74688 .76046 L p .707 .577 .707 r
F P
0 g
s
.49196 .76118 m .49196 .77971 L .49904 .77134 L p .707 .577 .707 r
F P
0 g
s
.49904 .77134 m .49904 .75282 L .49196 .76118 L p .707 .577 .707 r
F P
0 g
s
.30223 .53792 m .30223 .48233 L .3186 .47497 L p .707 .577 .707 r
F P
0 g
s
.74688 .76046 m .74688 .77898 L .71504 .77976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .66044 m .29515 .62338 L .30223 .61502 L p .707 .577 .707 r
F P
0 g
s
.29804 .77625 m .29804 .75772 L .29515 .74918 L p .707 .577 .707 r
F P
0 g
s
.3186 .47497 m .3186 .53055 L .30223 .53792 L p .707 .577 .707 r
F P
0 g
s
.48356 .47791 m .48356 .53349 L .4625 .52704 L p .707 .577 .707 r
F P
0 g
s
.4625 .52704 m .4625 .47145 L .48356 .47791 L p .707 .577 .707 r
F P
0 g
s
.29515 .74918 m .29515 .76771 L .29804 .77625 L p .707 .577 .707 r
F P
0 g
s
.30223 .61502 m .30223 .65207 L .29515 .66044 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .61847 m .49615 .65553 L .48356 .64764 L p .707 .577 .707 r
F P
0 g
s
.48356 .64764 m .48356 .61059 L .49615 .61847 L p .707 .577 .707 r
F P
0 g
s
.3186 .53055 m .3186 .47497 L .34265 .46932 L p .707 .577 .707 r
F P
0 g
s
.49904 .75282 m .49904 .77134 L .49615 .7628 L p .707 .577 .707 r
F P
0 g
s
.49615 .7628 m .49615 .74427 L .49904 .75282 L p .707 .577 .707 r
F P
0 g
s
.30223 .65207 m .30223 .61502 L .3186 .60765 L p .707 .577 .707 r
F P
0 g
s
.4625 .47145 m .4625 .52704 L .43504 .52264 L p .707 .577 .707 r
F P
0 g
s
.43504 .52264 m .43504 .46706 L .4625 .47145 L p .707 .577 .707 r
F P
0 g
s
.34265 .46932 m .34265 .5249 L .3186 .53055 L p .707 .577 .707 r
F P
0 g
s
.29515 .76771 m .29515 .74918 L .30223 .74082 L p .707 .577 .707 r
F P
0 g
s
.34265 .5249 m .34265 .46932 L .37203 .46594 L p .707 .577 .707 r
F P
0 g
s
.30223 .74082 m .30223 .75934 L .29515 .76771 L p .707 .577 .707 r
F P
0 g
s
.3186 .60765 m .3186 .6447 L .30223 .65207 L p .707 .577 .707 r
F P
0 g
s
.48356 .61059 m .48356 .64764 L .4625 .64119 L p .707 .577 .707 r
F P
0 g
s
.4625 .64119 m .4625 .60414 L .48356 .61059 L p .707 .577 .707 r
F P
0 g
s
.43504 .46706 m .43504 .52264 L .40387 .52074 L p .707 .577 .707 r
F P
0 g
s
.40387 .52074 m .40387 .46516 L .43504 .46706 L p .707 .577 .707 r
F P
0 g
s
.37203 .52152 m .37203 .46594 L .40387 .46516 L p .707 .577 .707 r
F P
0 g
s
.37203 .46594 m .37203 .52152 L .34265 .5249 L p .707 .577 .707 r
F P
0 g
s
.49615 .74427 m .49615 .7628 L .48356 .75492 L p .707 .577 .707 r
F P
0 g
s
.48356 .75492 m .48356 .73639 L .49615 .74427 L p .707 .577 .707 r
F P
0 g
s
.40387 .46516 m .40387 .52074 L .37203 .52152 L p .707 .577 .707 r
F P
0 g
s
.3186 .6447 m .3186 .60765 L .34265 .602 L p .707 .577 .707 r
F P
0 g
s
.30223 .75934 m .30223 .74082 L .3186 .73345 L p .707 .577 .707 r
F P
0 g
s
.34265 .602 m .34265 .63905 L .3186 .6447 L p .707 .577 .707 r
F P
0 g
s
.4625 .60414 m .4625 .64119 L .43504 .6368 L p .707 .577 .707 r
F P
0 g
s
.43504 .6368 m .43504 .59974 L .4625 .60414 L p .707 .577 .707 r
F P
0 g
s
.3186 .73345 m .3186 .75198 L .30223 .75934 L p .707 .577 .707 r
F P
0 g
s
.34265 .63905 m .34265 .602 L .37203 .59862 L p .707 .577 .707 r
F P
0 g
s
.48356 .73639 m .48356 .75492 L .4625 .74846 L p .707 .577 .707 r
F P
0 g
s
.4625 .74846 m .4625 .72993 L .48356 .73639 L p .707 .577 .707 r
F P
0 g
s
.43504 .59974 m .43504 .6368 L .40387 .6349 L p .707 .577 .707 r
F P
0 g
s
.40387 .6349 m .40387 .59784 L .43504 .59974 L p .707 .577 .707 r
F P
0 g
s
.37203 .59862 m .37203 .63567 L .34265 .63905 L p .707 .577 .707 r
F P
0 g
s
.37203 .63567 m .37203 .59862 L .40387 .59784 L p .707 .577 .707 r
F P
0 g
s
.3186 .75198 m .3186 .73345 L .34265 .7278 L p .707 .577 .707 r
F P
0 g
s
.40387 .59784 m .40387 .6349 L .37203 .63567 L p .707 .577 .707 r
F P
0 g
s
.34265 .7278 m .34265 .74633 L .3186 .75198 L p .707 .577 .707 r
F P
0 g
s
.4625 .72993 m .4625 .74846 L .43504 .74407 L p .707 .577 .707 r
F P
0 g
s
.43504 .74407 m .43504 .72554 L .4625 .72993 L p .707 .577 .707 r
F P
0 g
s
.34265 .74633 m .34265 .7278 L .37203 .72442 L p .707 .577 .707 r
F P
0 g
s
.37203 .72442 m .37203 .74295 L .34265 .74633 L p .707 .577 .707 r
F P
0 g
s
.43504 .72554 m .43504 .74407 L .40387 .74217 L p .707 .577 .707 r
F P
0 g
s
.40387 .74217 m .40387 .72364 L .43504 .72554 L p .707 .577 .707 r
F P
0 g
s
.37203 .74295 m .37203 .72442 L .40387 .72364 L p .707 .577 .707 r
F P
0 g
s
.40387 .72364 m .40387 .74217 L .37203 .74295 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002;Ool<
0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH2001[Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
001YOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol30005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Qoo`T004Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`l000AJEP03001JEUYF009JEPP003aoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03
001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF
001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolA0005Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009J
EPT000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF10000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH06P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH7000h
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPT000AJEP@00003
FUH0000000L003moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF60000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo2@00B7oo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool00`00FUH0
0004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF4P00A7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH000040003FUH2
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH300000eYF000000020003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP07FUH600000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P00=7oo000^Ool01000FUIJEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00FUH20005FUH00`00FUH000050002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80039oo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00@005YF001JEP80
0003FUH005YF00AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH0
05YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`00<7oo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo1@00
15YF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo6P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0000=J
EP00Ool01Woo1@0037oo1@0015YF00@005YFFUIJEP8002eoo`00FWoo0`0000=JEP00FUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD00003FUH005YF00=JEP03
001JEP0000Qoo`<0015oo`@00003FUH005YF009JEP8002eoo`00GGoo1@0015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH00UYF20002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP8000=JEPD000=JEP8001Ioo`L000=JEP<000=JEP8002eoo`00
HWoo200015YF1@0000=JEP0000001`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00@005YFFUIJEPT000Uoo`T0
00=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00?goo6@003Goo00D005YFFUH0
05YF00X000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04001JEUYF0005FUH40006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP800005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool300000eYF001JEP06FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006Ool30006
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH900000eYF001JEP02FUH60009
FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool40002
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP04001JEUYFFUH>0004FUH00`00FUIJ
EP02FUH8000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH00`00FUH0
000=OolI000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPH000Qoo`D000Aoo`P000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00002000G
Ool30019Ool002aoo`03001JEP0000AJEP03001JEP0000<000ioo`D000aoo`@000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00=JEP03001JEP00009JEPD0
05ioo`00;7oo00<005YF00000eYF1`003goo0`0037oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000EJEP03001JEP00
008005]oo`00;7oo00@005YF001JEP8000EJEP03001JEP0000<001Qoo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00005FUH0
0`00FUIJEP02FUH2001IOol002aoo`06001JEP00001JEP001EYF00<005YFFUH00eYF6@0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YFFUH00eYF0`00
Egoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP020004FUH01000FUIJEUYF200000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EPD0009JEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3
00000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF0P0000=JEP00FUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF0`002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EP000002FUH30006FUH01`00FUIJEUYF001oo`0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00QJEP<00003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000<000=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000jOol0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04
001JEP000003FUH00`00FUH000020003FUH01000FUH000000Woo00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YF00002UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0017oo1`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1000=Woo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH40006
FUH01000FUH000000eYF00<005YFFUH00UYF1@001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH0
25YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000Ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0039oo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF
00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH:0007FUH00`00FUIJEP07FUH50005FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000Ioo`800003
FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP80035oo`00>goo200015YF1@001EYF00@005YFFUIJEP800003FUH005YF00AJEP03
001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YF00002@000eYF00<005YFFUH00eYF00<005YFFUH00UYF4P00
15YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002moo`00@goo4`0000Aoo`00000000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP04001JEUYFFUH20004
FUH00`00FUIJEP02FUH8000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo0018Ool3
000?Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH01P00FUIJ
EP00FUH000AJEP03001JEP0000<000AJEP<001Qoo`D000AJEP05001JEUYFFUH0000^Ool005eoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001J
EUYF00YJEP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0`000eYF
00<005YFFUH00UYF0`007Goo0`0000=JEP00FUH00UYF0P00;Goo001POol40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80006FUH00`00FUIJEP0:FUH00`00FUIJEP060008FUH0
0`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000IJEP03001JEUYF009JEP03001JEP00021oo`80
00=JEP8002eoo`00I7oo6@0027oo5P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800003FUH005YF00EJEP03001JEUYF009JEP8002=oo`800003FUH0000002eoo`00T7oo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000AJ
EP00FUH000IJEP04001JEUYFFUH2000TOol5000]Ool0095oo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000IJEP04001JEP00000TOol20002FUH3
000]Ool0099oo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEP000080009JEP<0029oo`@000AJEP03001JEP0002eoo`00UGoo1@001UYF00<0
05YFFUH01UYF10001EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPD001]oo`L000=JEP03001J
EUYF009JEP8002ioo`00Agoo2@00BWoo10000UYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool003moo`P000AJEP03001JEUYF009JEPP004Iooa`000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6001;Ool5000;Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000<Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020019Ool3000>Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000`Ool200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001K
Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<005ioo`T000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00IGoo2@00B7oo000]
Ool20004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP000;Ioo`00;7oo00<005YF0000
15YF10009goo0`0000=JEP00FUH00UYF00<007ooOol0]7oo000/Ool00`00FUH00002FUH2000^Ool2
0003FUH00`00Oomoo`2dOol002aoo`03001JEP000080039oo`04001JEUYF002fOol002aoo`04001J
EP00000dOol3000iOolH001UOol002aoo`80009JEP<002moo`<00003FUH007oo039oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0065oo`00;7oo0P000eYF00<005YF00000P00
:Goo0`000UYF00<005YF0000<7oo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`00GWoo000/Ool20003FUH00`00FUIJEP02FUH5000POol400000eYF001JEP02
FUH00`00FUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF20004goo
1@001EYF00@005YFFUIJEP8002aoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8005Uoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00
Egoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000/Ool00`00FUH00004FUH00`00FUH0
0002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00FUH00003FUH3000XOol300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
03=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eooaT003Qoo`04001JEP00000bOol20000
0eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P000UYF0P00;goo0P0000AJEP00000005Ao
o`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJ
EQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
05Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001J
EUYF009JEPh0065oo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70431 m .59613 .64873 L .56496 .64683 L p .707 .577 .707 r
F P
0 g
s
.59613 .64873 m .59613 .70431 L .62796 .70353 L p .707 .577 .707 r
F P
0 g
s
.62796 .70353 m .62796 .64795 L .59613 .64873 L p .707 .577 .707 r
F P
0 g
s
.62796 .64795 m .62796 .70353 L .65734 .70015 L p .707 .577 .707 r
F P
0 g
s
.65734 .70015 m .65734 .64457 L .62796 .64795 L p .707 .577 .707 r
F P
0 g
s
.56496 .70241 m .56496 .64683 L .5375 .64243 L p .707 .577 .707 r
F P
0 g
s
.56496 .64683 m .56496 .70241 L .59613 .70431 L p .707 .577 .707 r
F P
0 g
s
.65734 .64457 m .65734 .70015 L .6814 .6945 L p .707 .577 .707 r
F P
0 g
s
.6814 .6945 m .6814 .63892 L .65734 .64457 L p .707 .577 .707 r
F P
0 g
s
.5375 .64243 m .5375 .69802 L .56496 .70241 L p .707 .577 .707 r
F P
0 g
s
.5375 .69802 m .5375 .64243 L .51644 .63598 L p .707 .577 .707 r
F P
0 g
s
.6814 .63892 m .6814 .6945 L .69777 .68714 L p .707 .577 .707 r
F P
0 g
s
.69777 .68714 m .69777 .63155 L .6814 .63892 L p .707 .577 .707 r
F P
0 g
s
.59613 .81846 m .59613 .78141 L .56496 .77951 L p .707 .577 .707 r
F P
0 g
s
.59613 .78141 m .59613 .81846 L .62796 .81769 L p .707 .577 .707 r
F P
0 g
s
.62796 .81769 m .62796 .78063 L .59613 .78141 L p .707 .577 .707 r
F P
0 g
s
.51644 .63598 m .51644 .69156 L .5375 .69802 L p .707 .577 .707 r
F P
0 g
s
.62796 .78063 m .62796 .81769 L .65735 .81431 L p .707 .577 .707 r
F P
0 g
s
.65735 .81431 m .65735 .77725 L .62796 .78063 L p .707 .577 .707 r
F P
0 g
s
.56496 .81656 m .56496 .77951 L .5375 .77512 L p .707 .577 .707 r
F P
0 g
s
.56496 .77951 m .56496 .81656 L .59613 .81846 L p .707 .577 .707 r
F P
0 g
s
.51644 .69156 m .51644 .63598 L .50385 .6281 L p .707 .577 .707 r
F P
0 g
s
.65735 .77725 m .65735 .81431 L .6814 .80866 L p .707 .577 .707 r
F P
0 g
s
.6814 .80866 m .6814 .7716 L .65735 .77725 L p .707 .577 .707 r
F P
0 g
s
.5375 .77512 m .5375 .81217 L .56496 .81656 L p .707 .577 .707 r
F P
0 g
s
.5375 .81217 m .5375 .77512 L .51644 .76866 L p .707 .577 .707 r
F P
0 g
s
.50385 .6281 m .50385 .68368 L .51644 .69156 L p .707 .577 .707 r
F P
0 g
s
.69777 .63155 m .69777 .68714 L .70485 .67877 L p .707 .577 .707 r
F P
0 g
s
.70485 .67877 m .70485 .62319 L .69777 .63155 L p .707 .577 .707 r
F P
0 g
s
.51644 .76866 m .51644 .80572 L .5375 .81217 L p .707 .577 .707 r
F P
0 g
s
.59613 .92573 m .59613 .90721 L .56496 .90531 L p .707 .577 .707 r
F P
0 g
s
.59613 .90721 m .59613 .92573 L .62796 .92496 L p .707 .577 .707 r
F P
0 g
s
.62796 .92496 m .62796 .90643 L .59613 .90721 L p .707 .577 .707 r
F P
0 g
s
.6814 .7716 m .6814 .80866 L .69777 .80129 L p .707 .577 .707 r
F P
0 g
s
.69777 .80129 m .69777 .76423 L .6814 .7716 L p .707 .577 .707 r
F P
0 g
s
.50385 .68368 m .50385 .6281 L .50095 .61955 L p .707 .577 .707 r
F P
0 g
s
.62796 .90643 m .62796 .92496 L .65735 .92158 L p .707 .577 .707 r
F P
0 g
s
.65735 .92158 m .65735 .90305 L .62796 .90643 L p .707 .577 .707 r
F P
0 g
s
.56496 .90531 m .56496 .92383 L .59613 .92573 L p .707 .577 .707 r
F P
0 g
s
.56496 .92383 m .56496 .90531 L .5375 .90091 L p .707 .577 .707 r
F P
0 g
s
.51644 .80572 m .51644 .76866 L .50385 .76078 L p .707 .577 .707 r
F P
0 g
s
.5375 .90091 m .5375 .91944 L .56496 .92383 L p .707 .577 .707 r
F P
0 g
s
.65735 .90305 m .65735 .92158 L .6814 .91593 L p .707 .577 .707 r
F P
0 g
s
.6814 .91593 m .6814 .8974 L .65735 .90305 L p .707 .577 .707 r
F P
0 g
s
.50095 .61955 m .50095 .67514 L .50385 .68368 L p .707 .577 .707 r
F P
0 g
s
.70485 .62319 m .70485 .67877 L .70195 .67023 L p .707 .577 .707 r
F P
0 g
s
.70195 .67023 m .70195 .61465 L .70485 .62319 L p .707 .577 .707 r
F P
0 g
s
.50385 .76078 m .50385 .79783 L .51644 .80572 L p .707 .577 .707 r
F P
0 g
s
.5375 .91944 m .5375 .90091 L .51644 .89446 L p .707 .577 .707 r
F P
0 g
s
.69777 .76423 m .69777 .80129 L .70485 .79292 L p .707 .577 .707 r
F P
0 g
s
.70485 .79292 m .70485 .75587 L .69777 .76423 L p .707 .577 .707 r
F P
0 g
s
.51644 .89446 m .51644 .91299 L .5375 .91944 L p .707 .577 .707 r
F P
0 g
s
.50095 .67514 m .50095 .61955 L .50804 .61119 L p .707 .577 .707 r
F P
0 g
s
.49044 .79627 m .49044 .29438 L .44643 .2917 L p .707 .577 .707 r
F P
0 g
s
.50385 .79783 m .50385 .76078 L .50095 .75223 L p .707 .577 .707 r
F P
0 g
s
.50804 .61119 m .50804 .66677 L .50095 .67514 L p .707 .577 .707 r
F P
0 g
s
.50095 .75223 m .50095 .78929 L .50385 .79783 L p .707 .577 .707 r
F P
0 g
s
.50804 .66677 m .50804 .61119 L .5244 .60382 L p .707 .577 .707 r
F P
0 g
s
.50095 .78929 m .50095 .75223 L .50804 .74387 L p .707 .577 .707 r
F P
0 g
s
.5244 .60382 m .5244 .6594 L .50804 .66677 L p .707 .577 .707 r
F P
0 g
s
.50804 .74387 m .50804 .78093 L .50095 .78929 L p .707 .577 .707 r
F P
0 g
s
.50804 .78093 m .50804 .74387 L .5244 .7365 L p .707 .577 .707 r
F P
0 g
s
.5244 .7365 m .5244 .77356 L .50804 .78093 L p .707 .577 .707 r
F P
0 g
s
.5244 .77356 m .5244 .7365 L .54846 .73085 L p .707 .577 .707 r
F P
0 g
s
.54846 .73085 m .54846 .76791 L .5244 .77356 L p .707 .577 .707 r
F P
0 g
s
.49044 .29438 m .49044 .79627 L .53538 .79517 L p .707 .577 .707 r
F P
0 g
s
.5244 .6594 m .5244 .60382 L .54846 .59817 L p .707 .577 .707 r
F P
0 g
s
.54846 .59817 m .54846 .65375 L .5244 .6594 L p .707 .577 .707 r
F P
0 g
s
.53538 .79517 m .53538 .29328 L .49044 .29438 L p .707 .577 .707 r
F P
0 g
s
.6814 .8974 m .6814 .91593 L .69777 .90856 L p .707 .577 .707 r
F P
0 g
s
.69777 .90856 m .69777 .89003 L .6814 .8974 L p .707 .577 .707 r
F P
0 g
s
.54846 .65375 m .54846 .59817 L .57784 .59479 L p .707 .577 .707 r
F P
0 g
s
.57784 .59479 m .57784 .65037 L .54846 .65375 L p .707 .577 .707 r
F P
0 g
s
.54846 .76791 m .54846 .73085 L .57784 .72747 L p .707 .577 .707 r
F P
0 g
s
.57784 .72747 m .57784 .76453 L .54846 .76791 L p .707 .577 .707 r
F P
0 g
s
.53538 .29328 m .53538 .79517 L .57686 .7904 L p .707 .577 .707 r
F P
0 g
s
.57686 .7904 m .57686 .28851 L .53538 .29328 L p .707 .577 .707 r
F P
0 g
s
.44643 .79358 m .44643 .2917 L .40766 .28549 L p .707 .577 .707 r
F P
0 g
s
.44643 .2917 m .44643 .79358 L .49044 .79627 L p .707 .577 .707 r
F P
0 g
s
.51644 .91299 m .51644 .89446 L .50385 .88658 L p .707 .577 .707 r
F P
0 g
s
.70195 .61465 m .70195 .67023 L .68936 .66234 L p .707 .577 .707 r
F P
0 g
s
.68936 .66234 m .68936 .60676 L .70195 .61465 L p .707 .577 .707 r
F P
0 g
s
.50385 .88658 m .50385 .9051 L .51644 .91299 L p .707 .577 .707 r
F P
0 g
s
.57784 .65037 m .57784 .59479 L .60968 .59402 L p .707 .577 .707 r
F P
0 g
s
.60968 .59402 m .60968 .6496 L .57784 .65037 L p .707 .577 .707 r
F P
0 g
s
.57784 .76453 m .57784 .72747 L .60968 .7267 L p .707 .577 .707 r
F P
0 g
s
.60968 .7267 m .60968 .76375 L .57784 .76453 L p .707 .577 .707 r
F P
0 g
s
.57686 .28851 m .57686 .7904 L .61082 .78242 L p .707 .577 .707 r
F P
0 g
s
.64085 .59592 m .64085 .6515 L .60968 .6496 L p .707 .577 .707 r
F P
0 g
s
.60968 .6496 m .60968 .59402 L .64085 .59592 L p .707 .577 .707 r
F P
0 g
s
.64085 .7286 m .64085 .76565 L .60968 .76375 L p .707 .577 .707 r
F P
0 g
s
.60968 .76375 m .60968 .7267 L .64085 .7286 L p .707 .577 .707 r
F P
0 g
s
.61082 .78242 m .61082 .28053 L .57686 .28851 L p .707 .577 .707 r
F P
0 g
s
.70485 .75587 m .70485 .79292 L .70195 .78438 L p .707 .577 .707 r
F P
0 g
s
.70195 .78438 m .70195 .74733 L .70485 .75587 L p .707 .577 .707 r
F P
0 g
s
.25312 .66749 m .25312 .61191 L .22195 .61001 L p .707 .577 .707 r
F P
0 g
s
.25312 .61191 m .25312 .66749 L .28495 .66672 L p .707 .577 .707 r
F P
0 g
s
.28495 .66672 m .28495 .61113 L .25312 .61191 L p .707 .577 .707 r
F P
0 g
s
.69777 .89003 m .69777 .90856 L .70485 .9002 L p .707 .577 .707 r
F P
0 g
s
.70485 .9002 m .70485 .88167 L .69777 .89003 L p .707 .577 .707 r
F P
0 g
s
.28495 .61113 m .28495 .66672 L .31434 .66334 L p .707 .577 .707 r
F P
0 g
s
.31434 .66334 m .31434 .60776 L .28495 .61113 L p .707 .577 .707 r
F P
0 g
s
.40766 .78738 m .40766 .28549 L .37794 .27638 L p .707 .577 .707 r
F P
0 g
s
.40766 .28549 m .40766 .78738 L .44643 .79358 L p .707 .577 .707 r
F P
0 g
s
.22195 .66559 m .22195 .61001 L .19449 .60562 L p .707 .577 .707 r
F P
0 g
s
.22195 .61001 m .22195 .66559 L .25312 .66749 L p .707 .577 .707 r
F P
0 g
s
.50385 .9051 m .50385 .88658 L .50095 .87803 L p .707 .577 .707 r
F P
0 g
s
.31434 .60776 m .31434 .66334 L .33839 .65769 L p .707 .577 .707 r
F P
0 g
s
.33839 .65769 m .33839 .60211 L .31434 .60776 L p .707 .577 .707 r
F P
0 g
s
.68936 .60676 m .68936 .66234 L .66831 .65589 L p .707 .577 .707 r
F P
0 g
s
.66831 .65589 m .66831 .60031 L .68936 .60676 L p .707 .577 .707 r
F P
0 g
s
.50095 .87803 m .50095 .89656 L .50385 .9051 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19449 .60562 m .19449 .6612 L .22195 .66559 L p .707 .577 .707 r
F P
0 g
s
.19449 .6612 m .19449 .60562 L .17343 .59916 L p .707 .577 .707 r
F P
0 g
s
.61082 .28053 m .61082 .78242 L .63393 .77202 L p .707 .577 .707 r
F P
0 g
s
.63393 .77202 m .63393 .27013 L .61082 .28053 L p .707 .577 .707 r
F P
0 g
s
.70195 .74733 m .70195 .78438 L .68936 .7765 L p .707 .577 .707 r
F P
0 g
s
.68936 .7765 m .68936 .73944 L .70195 .74733 L p .707 .577 .707 r
F P
0 g
s
.70485 .88167 m .70485 .9002 L .70195 .89165 L p .707 .577 .707 r
F P
0 g
s
.70195 .89165 m .70195 .87313 L .70485 .88167 L p .707 .577 .707 r
F P
0 g
s
.33839 .60211 m .33839 .65769 L .35476 .65032 L p .707 .577 .707 r
F P
0 g
s
.35476 .65032 m .35476 .59474 L .33839 .60211 L p .707 .577 .707 r
F P
0 g
s
.25312 .78165 m .25312 .74459 L .22195 .74269 L p .707 .577 .707 r
F P
0 g
s
.25312 .74459 m .25312 .78165 L .28495 .78087 L p .707 .577 .707 r
F P
0 g
s
.28495 .78087 m .28495 .74382 L .25312 .74459 L p .707 .577 .707 r
F P
0 g
s
.17343 .59916 m .17343 .65475 L .19449 .6612 L p .707 .577 .707 r
F P
0 g
s
.37794 .77827 m .37794 .27638 L .36016 .26525 L p .707 .577 .707 r
F P
0 g
s
.37794 .27638 m .37794 .77827 L .40766 .78738 L p .707 .577 .707 r
F P
0 g
s
.28495 .74382 m .28495 .78087 L .31434 .77749 L p .707 .577 .707 r
F P
0 g
s
.31434 .77749 m .31434 .74044 L .28495 .74382 L p .707 .577 .707 r
F P
0 g
s
.66831 .60031 m .66831 .65589 L .64085 .6515 L p .707 .577 .707 r
F P
0 g
s
.64085 .6515 m .64085 .59592 L .66831 .60031 L p .707 .577 .707 r
F P
0 g
s
.22195 .77975 m .22195 .74269 L .19449 .7383 L p .707 .577 .707 r
F P
0 g
s
.22195 .74269 m .22195 .77975 L .25312 .78165 L p .707 .577 .707 r
F P
0 g
s
.50095 .89656 m .50095 .87803 L .50804 .86967 L p .707 .577 .707 r
F P
0 g
s
.17343 .65475 m .17343 .59916 L .16084 .59128 L p .707 .577 .707 r
F P
0 g
s
.50804 .86967 m .50804 .8882 L .50095 .89656 L p .707 .577 .707 r
F P
0 g
s
.31434 .74044 m .31434 .77749 L .33839 .77184 L p .707 .577 .707 r
F P
0 g
s
.33839 .77184 m .33839 .73479 L .31434 .74044 L p .707 .577 .707 r
F P
0 g
s
.19449 .7383 m .19449 .77535 L .22195 .77975 L p .707 .577 .707 r
F P
0 g
s
.68936 .73944 m .68936 .7765 L .66831 .77004 L p .707 .577 .707 r
F P
0 g
s
.66831 .77004 m .66831 .73299 L .68936 .73944 L p .707 .577 .707 r
F P
0 g
s
.19449 .77535 m .19449 .7383 L .17343 .73185 L p .707 .577 .707 r
F P
0 g
s
.16084 .59128 m .16084 .64686 L .17343 .65475 L p .707 .577 .707 r
F P
0 g
s
.35476 .59474 m .35476 .65032 L .36184 .64196 L p .707 .577 .707 r
F P
0 g
s
.36184 .64196 m .36184 .58637 L .35476 .59474 L p .707 .577 .707 r
F P
0 g
s
.64085 .76565 m .64085 .7286 L .66831 .73299 L p .707 .577 .707 r
F P
0 g
s
.63393 .27013 m .63393 .77202 L .64393 .76021 L p .707 .577 .707 r
F P
0 g
s
.64393 .76021 m .64393 .25832 L .63393 .27013 L p .707 .577 .707 r
F P
0 g
s
.70195 .87313 m .70195 .89165 L .68936 .88377 L p .707 .577 .707 r
F P
0 g
s
.68936 .88377 m .68936 .86524 L .70195 .87313 L p .707 .577 .707 r
F P
0 g
s
.17343 .73185 m .17343 .7689 L .19449 .77535 L p .707 .577 .707 r
F P
0 g
s
.25312 .88892 m .25312 .87039 L .22195 .86849 L p .707 .577 .707 r
F P
0 g
s
.25312 .87039 m .25312 .88892 L .28495 .88814 L p .707 .577 .707 r
F P
0 g
s
.28495 .88814 m .28495 .86961 L .25312 .87039 L p .707 .577 .707 r
F P
0 g
s
.33839 .73479 m .33839 .77184 L .35476 .76447 L p .707 .577 .707 r
F P
0 g
s
.35476 .76447 m .35476 .72742 L .33839 .73479 L p .707 .577 .707 r
F P
0 g
s
.16084 .64686 m .16084 .59128 L .15794 .58274 L p .707 .577 .707 r
F P
0 g
s
.50804 .8882 m .50804 .86967 L .5244 .8623 L p .707 .577 .707 r
F P
0 g
s
.28495 .86961 m .28495 .88814 L .31434 .88476 L p .707 .577 .707 r
F P
0 g
s
.31434 .88476 m .31434 .86624 L .28495 .86961 L p .707 .577 .707 r
F P
0 g
s
.22195 .86849 m .22195 .88702 L .25312 .88892 L p .707 .577 .707 r
F P
0 g
s
.66831 .73299 m .66831 .77004 L .64085 .76565 L p .707 .577 .707 r
F P
0 g
s
.22195 .88702 m .22195 .86849 L .19449 .8641 L p .707 .577 .707 r
F P
0 g
s
.36184 .58637 m .36184 .64196 L .35894 .63341 L p .707 .577 .707 r
F P
0 g
s
.35894 .63341 m .35894 .57783 L .36184 .58637 L p .707 .577 .707 r
F P
0 g
s
.35476 .72742 m .35476 .76447 L .36184 .75611 L p .707 .577 .707 r
F P
0 g
s
.36184 .75611 m .36184 .71905 L .35476 .72742 L p .707 .577 .707 r
F P
0 g
s
.35894 .57783 m .35894 .63341 L .34635 .62553 L p .707 .577 .707 r
F P
0 g
s
.34635 .62553 m .34635 .56995 L .35894 .57783 L p .707 .577 .707 r
F P
0 g
s
.36184 .71905 m .36184 .75611 L .35894 .74757 L p .707 .577 .707 r
F P
0 g
s
.35894 .74757 m .35894 .71051 L .36184 .71905 L p .707 .577 .707 r
F P
0 g
s
.36016 .76714 m .36016 .26525 L .35607 .25319 L p .707 .577 .707 r
F P
0 g
s
.36016 .26525 m .36016 .76714 L .37794 .77827 L p .707 .577 .707 r
F P
0 g
s
.5244 .8623 m .5244 .88083 L .50804 .8882 L p .707 .577 .707 r
F P
0 g
s
.17343 .7689 m .17343 .73185 L .16084 .72396 L p .707 .577 .707 r
F P
0 g
s
.19449 .8641 m .19449 .88263 L .22195 .88702 L p .707 .577 .707 r
F P
0 g
s
.31434 .86624 m .31434 .88476 L .33839 .87911 L p .707 .577 .707 r
F P
0 g
s
.33839 .87911 m .33839 .86059 L .31434 .86624 L p .707 .577 .707 r
F P
0 g
s
.15794 .58274 m .15794 .63832 L .16084 .64686 L p .707 .577 .707 r
F P
0 g
s
.68936 .86524 m .68936 .88377 L .66831 .87732 L p .707 .577 .707 r
F P
0 g
s
.66831 .87732 m .66831 .85879 L .68936 .86524 L p .707 .577 .707 r
F P
0 g
s
.16084 .72396 m .16084 .76102 L .17343 .7689 L p .707 .577 .707 r
F P
0 g
s
.19449 .88263 m .19449 .8641 L .17343 .85764 L p .707 .577 .707 r
F P
0 g
s
.17343 .85764 m .17343 .87617 L .19449 .88263 L p .707 .577 .707 r
F P
0 g
s
.5244 .88083 m .5244 .8623 L .54846 .85665 L p .707 .577 .707 r
F P
0 g
s
.64393 .25832 m .64393 .76021 L .63984 .74815 L p .707 .577 .707 r
F P
0 g
s
.63984 .74815 m .63984 .24626 L .64393 .25832 L p .707 .577 .707 r
F P
0 g
s
.15794 .63832 m .15794 .58274 L .16503 .57437 L p .707 .577 .707 r
F P
0 g
s
.54846 .85665 m .54846 .87518 L .5244 .88083 L p .707 .577 .707 r
F P
0 g
s
.33839 .86059 m .33839 .87911 L .35476 .87175 L p .707 .577 .707 r
F P
0 g
s
.35476 .87175 m .35476 .85322 L .33839 .86059 L p .707 .577 .707 r
F P
0 g
s
.16084 .76102 m .16084 .72396 L .15794 .71542 L p .707 .577 .707 r
F P
0 g
s
.66831 .85879 m .66831 .87732 L .64085 .87292 L p .707 .577 .707 r
F P
0 g
s
.64085 .87292 m .64085 .8544 L .66831 .85879 L p .707 .577 .707 r
F P
0 g
s
.17343 .87617 m .17343 .85764 L .16084 .84976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57437 m .16503 .62996 L .15794 .63832 L p .707 .577 .707 r
F P
0 g
s
.54846 .87518 m .54846 .85665 L .57784 .85327 L p .707 .577 .707 r
F P
0 g
s
.15794 .71542 m .15794 .75247 L .16084 .76102 L p .707 .577 .707 r
F P
0 g
s
.35894 .71051 m .35894 .74757 L .34635 .73968 L p .707 .577 .707 r
F P
0 g
s
.34635 .73968 m .34635 .70263 L .35894 .71051 L p .707 .577 .707 r
F P
0 g
s
.35607 .25319 m .35607 .75508 L .36016 .76714 L p .707 .577 .707 r
F P
0 g
s
.35607 .75508 m .35607 .25319 L .36607 .24138 L p .707 .577 .707 r
F P
0 g
s
.16084 .84976 m .16084 .86829 L .17343 .87617 L p .707 .577 .707 r
F P
0 g
s
.57784 .85327 m .57784 .8718 L .54846 .87518 L p .707 .577 .707 r
F P
0 g
s
.64085 .8544 m .64085 .87292 L .60968 .87102 L p .707 .577 .707 r
F P
0 g
s
.60968 .87102 m .60968 .8525 L .64085 .8544 L p .707 .577 .707 r
F P
0 g
s
.57784 .8718 m .57784 .85327 L .60968 .8525 L p .707 .577 .707 r
F P
0 g
s
.35476 .85322 m .35476 .87175 L .36184 .86338 L p .707 .577 .707 r
F P
0 g
s
.36184 .86338 m .36184 .84485 L .35476 .85322 L p .707 .577 .707 r
F P
0 g
s
.16503 .62996 m .16503 .57437 L .1814 .56701 L p .707 .577 .707 r
F P
0 g
s
.60968 .8525 m .60968 .87102 L .57784 .8718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .75247 m .15794 .71542 L .16503 .70706 L p .707 .577 .707 r
F P
0 g
s
.16084 .86829 m .16084 .84976 L .15794 .84122 L p .707 .577 .707 r
F P
0 g
s
.63984 .24626 m .63984 .74815 L .62206 .73702 L p .707 .577 .707 r
F P
0 g
s
.62206 .73702 m .62206 .23513 L .63984 .24626 L p .707 .577 .707 r
F P
0 g
s
.1814 .56701 m .1814 .62259 L .16503 .62996 L p .707 .577 .707 r
F P
0 g
s
.34635 .56995 m .34635 .62553 L .3253 .61908 L p .707 .577 .707 r
F P
0 g
s
.3253 .61908 m .3253 .56349 L .34635 .56995 L p .707 .577 .707 r
F P
0 g
s
.15794 .84122 m .15794 .85975 L .16084 .86829 L p .707 .577 .707 r
F P
0 g
s
.16503 .70706 m .16503 .74411 L .15794 .75247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .62259 m .1814 .56701 L .20545 .56136 L p .707 .577 .707 r
F P
0 g
s
.36184 .84485 m .36184 .86338 L .35894 .85484 L p .707 .577 .707 r
F P
0 g
s
.35894 .85484 m .35894 .83631 L .36184 .84485 L p .707 .577 .707 r
F P
0 g
s
.36607 .74327 m .36607 .24138 L .38918 .23098 L p .707 .577 .707 r
F P
0 g
s
.36607 .24138 m .36607 .74327 L .35607 .75508 L p .707 .577 .707 r
F P
0 g
s
.16503 .74411 m .16503 .70706 L .1814 .69969 L p .707 .577 .707 r
F P
0 g
s
.3253 .56349 m .3253 .61908 L .29784 .61468 L p .707 .577 .707 r
F P
0 g
s
.29784 .61468 m .29784 .5591 L .3253 .56349 L p .707 .577 .707 r
F P
0 g
s
.20545 .56136 m .20545 .61694 L .1814 .62259 L p .707 .577 .707 r
F P
0 g
s
.15794 .85975 m .15794 .84122 L .16503 .83285 L p .707 .577 .707 r
F P
0 g
s
.20545 .61694 m .20545 .56136 L .23483 .55798 L p .707 .577 .707 r
F P
0 g
s
.16503 .83285 m .16503 .85138 L .15794 .85975 L p .707 .577 .707 r
F P
0 g
s
.1814 .69969 m .1814 .73674 L .16503 .74411 L p .707 .577 .707 r
F P
0 g
s
.62206 .23513 m .62206 .73702 L .59233 .72791 L p .707 .577 .707 r
F P
0 g
s
.59233 .72791 m .59233 .22602 L .62206 .23513 L p .707 .577 .707 r
F P
0 g
s
.34635 .70263 m .34635 .73968 L .3253 .73323 L p .707 .577 .707 r
F P
0 g
s
.3253 .73323 m .3253 .69617 L .34635 .70263 L p .707 .577 .707 r
F P
0 g
s
.29784 .5591 m .29784 .61468 L .26667 .61278 L p .707 .577 .707 r
F P
0 g
s
.26667 .61278 m .26667 .5572 L .29784 .5591 L p .707 .577 .707 r
F P
0 g
s
.23483 .61356 m .23483 .55798 L .26667 .5572 L p .707 .577 .707 r
F P
0 g
s
.23483 .55798 m .23483 .61356 L .20545 .61694 L p .707 .577 .707 r
F P
0 g
s
.35894 .83631 m .35894 .85484 L .34635 .84695 L p .707 .577 .707 r
F P
0 g
s
.34635 .84695 m .34635 .82843 L .35894 .83631 L p .707 .577 .707 r
F P
0 g
s
.26667 .5572 m .26667 .61278 L .23483 .61356 L p .707 .577 .707 r
F P
0 g
s
.1814 .73674 m .1814 .69969 L .20545 .69404 L p .707 .577 .707 r
F P
0 g
s
.73333 .61227 m .73333 .55669 L .70216 .55479 L p .707 .577 .707 r
F P
0 g
s
.73333 .55669 m .73333 .61227 L .76517 .61149 L p .707 .577 .707 r
F P
0 g
s
.76517 .61149 m .76517 .55591 L .73333 .55669 L p .707 .577 .707 r
F P
0 g
s
.76517 .55591 m .76517 .61149 L .79455 .60811 L p .707 .577 .707 r
F P
0 g
s
.79455 .60811 m .79455 .55253 L .76517 .55591 L p .707 .577 .707 r
F P
0 g
s
.38918 .23098 m .38918 .73287 L .36607 .74327 L p .707 .577 .707 r
F P
0 g
s
.38918 .73287 m .38918 .23098 L .42314 .22301 L p .707 .577 .707 r
F P
0 g
s
.70216 .61037 m .70216 .55479 L .6747 .5504 L p .707 .577 .707 r
F P
0 g
s
.70216 .55479 m .70216 .61037 L .73333 .61227 L p .707 .577 .707 r
F P
0 g
s
.16503 .85138 m .16503 .83285 L .1814 .82549 L p .707 .577 .707 r
F P
0 g
s
.20545 .69404 m .20545 .73109 L .1814 .73674 L p .707 .577 .707 r
F P
0 g
s
.3253 .69617 m .3253 .73323 L .29784 .72884 L p .707 .577 .707 r
F P
0 g
s
.29784 .72884 m .29784 .69178 L .3253 .69617 L p .707 .577 .707 r
F P
0 g
s
.1814 .82549 m .1814 .84401 L .16503 .85138 L p .707 .577 .707 r
F P
0 g
s
.79455 .55253 m .79455 .60811 L .8186 .60246 L p .707 .577 .707 r
F P
0 g
s
.8186 .60246 m .8186 .54688 L .79455 .55253 L p .707 .577 .707 r
F P
0 g
s
.20545 .73109 m .20545 .69404 L .23483 .69066 L p .707 .577 .707 r
F P
0 g
s
.59233 .22602 m .59233 .72791 L .55357 .72171 L p .707 .577 .707 r
F P
0 g
s
.55357 .72171 m .55357 .21982 L .59233 .22602 L p .707 .577 .707 r
F P
0 g
s
.6747 .5504 m .6747 .60598 L .70216 .61037 L p .707 .577 .707 r
F P
0 g
s
.6747 .60598 m .6747 .5504 L .65365 .54394 L p .707 .577 .707 r
F P
0 g
s
.34635 .82843 m .34635 .84695 L .3253 .8405 L p .707 .577 .707 r
F P
0 g
s
.3253 .8405 m .3253 .82197 L .34635 .82843 L p .707 .577 .707 r
F P
0 g
s
.29784 .69178 m .29784 .72884 L .26667 .72694 L p .707 .577 .707 r
F P
0 g
s
.26667 .72694 m .26667 .68988 L .29784 .69178 L p .707 .577 .707 r
F P
0 g
s
.23483 .69066 m .23483 .72771 L .20545 .73109 L p .707 .577 .707 r
F P
0 g
s
.23483 .72771 m .23483 .69066 L .26667 .68988 L p .707 .577 .707 r
F P
0 g
s
.42314 .72489 m .42314 .22301 L .46462 .21824 L p .707 .577 .707 r
F P
0 g
s
.42314 .22301 m .42314 .72489 L .38918 .73287 L p .707 .577 .707 r
F P
0 g
s
.1814 .84401 m .1814 .82549 L .20545 .81984 L p .707 .577 .707 r
F P
0 g
s
.26667 .68988 m .26667 .72694 L .23483 .72771 L p .707 .577 .707 r
F P
0 g
s
.8186 .54688 m .8186 .60246 L .83497 .5951 L p .707 .577 .707 r
F P
0 g
s
.83497 .5951 m .83497 .53951 L .8186 .54688 L p .707 .577 .707 r
F P
0 g
s
.73333 .72642 m .73333 .68937 L .70216 .68747 L p .707 .577 .707 r
F P
0 g
s
.73333 .68937 m .73333 .72642 L .76517 .72565 L p .707 .577 .707 r
F P
0 g
s
.76517 .72565 m .76517 .68859 L .73333 .68937 L p .707 .577 .707 r
F P
0 g
s
.65365 .54394 m .65365 .59952 L .6747 .60598 L p .707 .577 .707 r
F P
0 g
s
.76517 .68859 m .76517 .72565 L .79455 .72227 L p .707 .577 .707 r
F P
0 g
s
.79455 .72227 m .79455 .68521 L .76517 .68859 L p .707 .577 .707 r
F P
0 g
s
.20545 .81984 m .20545 .83836 L .1814 .84401 L p .707 .577 .707 r
F P
0 g
s
.70216 .72452 m .70216 .68747 L .6747 .68308 L p .707 .577 .707 r
F P
0 g
s
.70216 .68747 m .70216 .72452 L .73333 .72642 L p .707 .577 .707 r
F P
0 g
s
.55357 .21982 m .55357 .72171 L .50956 .71903 L p .707 .577 .707 r
F P
0 g
s
.50956 .71903 m .50956 .21714 L .55357 .21982 L p .707 .577 .707 r
F P
0 g
s
.65365 .59952 m .65365 .54394 L .64105 .53606 L p .707 .577 .707 r
F P
0 g
s
.3253 .82197 m .3253 .8405 L .29784 .83611 L p .707 .577 .707 r
F P
0 g
s
.29784 .83611 m .29784 .81758 L .3253 .82197 L p .707 .577 .707 r
F P
0 g
s
.46462 .72012 m .46462 .21824 L .50956 .21714 L p .707 .577 .707 r
F P
0 g
s
.46462 .21824 m .46462 .72012 L .42314 .72489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68521 m .79455 .72227 L .8186 .71662 L p .707 .577 .707 r
F P
0 g
s
.8186 .71662 m .8186 .67956 L .79455 .68521 L p .707 .577 .707 r
F P
0 g
s
.50956 .21714 m .50956 .71903 L .46462 .72012 L p .707 .577 .707 r
F P
0 g
s
.6747 .68308 m .6747 .72013 L .70216 .72452 L p .707 .577 .707 r
F P
0 g
s
.20545 .83836 m .20545 .81984 L .23483 .81646 L p .707 .577 .707 r
F P
0 g
s
.6747 .72013 m .6747 .68308 L .65365 .67662 L p .707 .577 .707 r
F P
0 g
s
.23483 .81646 m .23483 .83499 L .20545 .83836 L p .707 .577 .707 r
F P
0 g
s
.64105 .53606 m .64105 .59164 L .65365 .59952 L p .707 .577 .707 r
F P
0 g
s
.83497 .53951 m .83497 .5951 L .84205 .58673 L p .707 .577 .707 r
F P
0 g
s
.84205 .58673 m .84205 .53115 L .83497 .53951 L p .707 .577 .707 r
F P
0 g
s
.29784 .81758 m .29784 .83611 L .26667 .83421 L p .707 .577 .707 r
F P
0 g
s
.26667 .83421 m .26667 .81568 L .29784 .81758 L p .707 .577 .707 r
F P
0 g
s
.23483 .83499 m .23483 .81646 L .26667 .81568 L p .707 .577 .707 r
F P
0 g
s
.65365 .67662 m .65365 .71368 L .6747 .72013 L p .707 .577 .707 r
F P
0 g
s
.26667 .81568 m .26667 .83421 L .23483 .83499 L p .707 .577 .707 r
F P
0 g
s
.73333 .8337 m .73333 .81517 L .70216 .81327 L p .707 .577 .707 r
F P
0 g
s
.73333 .81517 m .73333 .8337 L .76517 .83292 L p .707 .577 .707 r
F P
0 g
s
.76517 .83292 m .76517 .81439 L .73333 .81517 L p .707 .577 .707 r
F P
0 g
s
.8186 .67956 m .8186 .71662 L .83497 .70925 L p .707 .577 .707 r
F P
0 g
s
.83497 .70925 m .83497 .6722 L .8186 .67956 L p .707 .577 .707 r
F P
0 g
s
.64105 .59164 m .64105 .53606 L .63816 .52751 L p .707 .577 .707 r
F P
0 g
s
.76517 .81439 m .76517 .83292 L .79455 .82954 L p .707 .577 .707 r
F P
0 g
s
.79455 .82954 m .79455 .81101 L .76517 .81439 L p .707 .577 .707 r
F P
0 g
s
.70216 .81327 m .70216 .8318 L .73333 .8337 L p .707 .577 .707 r
F P
0 g
s
.70216 .8318 m .70216 .81327 L .6747 .80888 L p .707 .577 .707 r
F P
0 g
s
.65365 .71368 m .65365 .67662 L .64105 .66874 L p .707 .577 .707 r
F P
0 g
s
.6747 .80888 m .6747 .8274 L .70216 .8318 L p .707 .577 .707 r
F P
0 g
s
.79455 .81101 m .79455 .82954 L .8186 .82389 L p .707 .577 .707 r
F P
0 g
s
.8186 .82389 m .8186 .80536 L .79455 .81101 L p .707 .577 .707 r
F P
0 g
s
.63816 .52751 m .63816 .5831 L .64105 .59164 L p .707 .577 .707 r
F P
0 g
s
.84205 .53115 m .84205 .58673 L .83916 .57819 L p .707 .577 .707 r
F P
0 g
s
.83916 .57819 m .83916 .52261 L .84205 .53115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66874 m .64105 .70579 L .65365 .71368 L p .707 .577 .707 r
F P
0 g
s
.6747 .8274 m .6747 .80888 L .65365 .80242 L p .707 .577 .707 r
F P
0 g
s
.83497 .6722 m .83497 .70925 L .84206 .70089 L p .707 .577 .707 r
F P
0 g
s
.84206 .70089 m .84205 .66383 L .83497 .6722 L p .707 .577 .707 r
F P
0 g
s
.65365 .80242 m .65365 .82095 L .6747 .8274 L p .707 .577 .707 r
F P
0 g
s
.63816 .5831 m .63816 .52751 L .64524 .51915 L p .707 .577 .707 r
F P
0 g
s
.8186 .80536 m .8186 .82389 L .83497 .81652 L p .707 .577 .707 r
F P
0 g
s
.83497 .81652 m .83497 .798 L .8186 .80536 L p .707 .577 .707 r
F P
0 g
s
.64105 .70579 m .64105 .66874 L .63816 .6602 L p .707 .577 .707 r
F P
0 g
s
.65365 .82095 m .65365 .80242 L .64105 .79454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .51915 m .64524 .57473 L .63816 .5831 L p .707 .577 .707 r
F P
0 g
s
.63816 .6602 m .63816 .69725 L .64105 .70579 L p .707 .577 .707 r
F P
0 g
s
.83916 .52261 m .83916 .57819 L .82657 .57031 L p .707 .577 .707 r
F P
0 g
s
.82657 .57031 m .82657 .51472 L .83916 .52261 L p .707 .577 .707 r
F P
0 g
s
.64105 .79454 m .64105 .81307 L .65365 .82095 L p .707 .577 .707 r
F P
0 g
s
.84205 .66383 m .84206 .70089 L .83916 .69234 L p .707 .577 .707 r
F P
0 g
s
.83916 .69234 m .83916 .65529 L .84205 .66383 L p .707 .577 .707 r
F P
0 g
s
.39032 .57545 m .39032 .51987 L .35915 .51797 L p .707 .577 .707 r
F P
0 g
s
.39032 .51987 m .39032 .57545 L .42216 .57468 L p .707 .577 .707 r
F P
0 g
s
.42216 .57468 m .42216 .5191 L .39032 .51987 L p .707 .577 .707 r
F P
0 g
s
.83497 .798 m .83497 .81652 L .84206 .80816 L p .707 .577 .707 r
F P
0 g
s
.84206 .80816 m .84206 .78963 L .83497 .798 L p .707 .577 .707 r
F P
0 g
s
.64524 .57473 m .64524 .51915 L .66161 .51178 L p .707 .577 .707 r
F P
0 g
s
.42216 .5191 m .42216 .57468 L .45154 .5713 L p .707 .577 .707 r
F P
0 g
s
.45154 .5713 m .45154 .51572 L .42216 .5191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.35915 .57355 m .35915 .51797 L .33169 .51358 L p .707 .577 .707 r
F P
0 g
s
.35915 .51797 m .35915 .57355 L .39032 .57545 L p .707 .577 .707 r
F P
0 g
s
.63816 .69725 m .63816 .6602 L .64524 .65183 L p .707 .577 .707 r
F P
0 g
s
.64105 .81307 m .64105 .79454 L .63816 .786 L p .707 .577 .707 r
F P
0 g
s
.45154 .51572 m .45154 .5713 L .47559 .56565 L p .707 .577 .707 r
F P
0 g
s
.47559 .56565 m .47559 .51007 L .45154 .51572 L p .707 .577 .707 r
F P
0 g
s
.66161 .51178 m .66161 .56736 L .64524 .57473 L p .707 .577 .707 r
F P
0 g
s
.82657 .51472 m .82657 .57031 L .80551 .56385 L p .707 .577 .707 r
F P
0 g
s
.80551 .56385 m .80551 .50827 L .82657 .51472 L p .707 .577 .707 r
F P
0 g
s
.63816 .786 m .63816 .80452 L .64105 .81307 L p .707 .577 .707 r
F P
0 g
s
.64524 .65183 m .64524 .68889 L .63816 .69725 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.33169 .51358 m .33169 .56916 L .35915 .57355 L p .707 .577 .707 r
F P
0 g
s
.33169 .56916 m .33169 .51358 L .31064 .50713 L p .707 .577 .707 r
F P
0 g
s
.83916 .65529 m .83916 .69234 L .82657 .68446 L p .707 .577 .707 r
F P
0 g
s
.82657 .68446 m .82657 .64741 L .83916 .65529 L p .707 .577 .707 r
F P
0 g
s
.66161 .56736 m .66161 .51178 L .68566 .50613 L p .707 .577 .707 r
F P
0 g
s
.84206 .78963 m .84206 .80816 L .83916 .79962 L p .707 .577 .707 r
F P
0 g
s
.83916 .79962 m .83916 .78109 L .84206 .78963 L p .707 .577 .707 r
F P
0 g
s
.47559 .51007 m .47559 .56565 L .49196 .55828 L p .707 .577 .707 r
F P
0 g
s
.49196 .55828 m .49196 .5027 L .47559 .51007 L p .707 .577 .707 r
F P
0 g
s
.39032 .68961 m .39032 .65255 L .35915 .65065 L p .707 .577 .707 r
F P
0 g
s
.39032 .65255 m .39032 .68961 L .42216 .68883 L p .707 .577 .707 r
F P
0 g
s
.42216 .68883 m .42216 .65178 L .39032 .65255 L p .707 .577 .707 r
F P
0 g
s
.31064 .50713 m .31064 .56271 L .33169 .56916 L p .707 .577 .707 r
F P
0 g
s
.64524 .68889 m .64524 .65183 L .66161 .64446 L p .707 .577 .707 r
F P
0 g
s
.42216 .65178 m .42216 .68883 L .45154 .68545 L p .707 .577 .707 r
F P
0 g
s
.45154 .68545 m .45154 .6484 L .42216 .65178 L p .707 .577 .707 r
F P
0 g
s
.80551 .50827 m .80551 .56385 L .77805 .55946 L p .707 .577 .707 r
F P
0 g
s
.77805 .55946 m .77805 .50388 L .80551 .50827 L p .707 .577 .707 r
F P
0 g
s
.35915 .68771 m .35915 .65065 L .33169 .64626 L p .707 .577 .707 r
F P
0 g
s
.35915 .65065 m .35915 .68771 L .39032 .68961 L p .707 .577 .707 r
F P
0 g
s
.68566 .50613 m .68566 .56172 L .66161 .56736 L p .707 .577 .707 r
F P
0 g
s
.63816 .80452 m .63816 .786 L .64524 .77763 L p .707 .577 .707 r
F P
0 g
s
.31064 .56271 m .31064 .50713 L .29804 .49924 L p .707 .577 .707 r
F P
0 g
s
.68566 .56172 m .68566 .50613 L .71504 .50275 L p .707 .577 .707 r
F P
0 g
s
.64524 .77763 m .64524 .79616 L .63816 .80452 L p .707 .577 .707 r
F P
0 g
s
.66161 .64446 m .66161 .68152 L .64524 .68889 L p .707 .577 .707 r
F P
0 g
s
.45154 .6484 m .45154 .68545 L .47559 .6798 L p .707 .577 .707 r
F P
0 g
s
.47559 .6798 m .47559 .64275 L .45154 .6484 L p .707 .577 .707 r
F P
0 g
s
.33169 .64626 m .33169 .68332 L .35915 .68771 L p .707 .577 .707 r
F P
0 g
s
.82657 .64741 m .82657 .68446 L .80551 .67801 L p .707 .577 .707 r
F P
0 g
s
.80551 .67801 m .80551 .64095 L .82657 .64741 L p .707 .577 .707 r
F P
0 g
s
.77805 .50388 m .77805 .55946 L .74688 .55756 L p .707 .577 .707 r
F P
0 g
s
.74688 .55756 m .74688 .50198 L .77805 .50388 L p .707 .577 .707 r
F P
0 g
s
.33169 .68332 m .33169 .64626 L .31064 .63981 L p .707 .577 .707 r
F P
0 g
s
.29804 .49924 m .29804 .55482 L .31064 .56271 L p .707 .577 .707 r
F P
0 g
s
.71504 .55834 m .71504 .50275 L .74688 .50198 L p .707 .577 .707 r
F P
0 g
s
.71504 .50275 m .71504 .55834 L .68566 .56172 L p .707 .577 .707 r
F P
0 g
s
.49196 .5027 m .49196 .55828 L .49904 .54992 L p .707 .577 .707 r
F P
0 g
s
.49904 .54992 m .49904 .49433 L .49196 .5027 L p .707 .577 .707 r
F P
0 g
s
.83916 .78109 m .83916 .79962 L .82657 .79173 L p .707 .577 .707 r
F P
0 g
s
.82657 .79173 m .82657 .7732 L .83916 .78109 L p .707 .577 .707 r
F P
0 g
s
.74688 .50198 m .74688 .55756 L .71504 .55834 L p .707 .577 .707 r
F P
0 g
s
.66161 .68152 m .66161 .64446 L .68566 .63881 L p .707 .577 .707 r
F P
0 g
s
.31064 .63981 m .31064 .67686 L .33169 .68332 L p .707 .577 .707 r
F P
0 g
s
.39032 .79688 m .39032 .77835 L .35915 .77645 L p .707 .577 .707 r
F P
0 g
s
.39032 .77835 m .39032 .79688 L .42216 .7961 L p .707 .577 .707 r
F P
0 g
s
.42216 .7961 m .42216 .77758 L .39032 .77835 L p .707 .577 .707 r
F P
0 g
s
.47559 .64275 m .47559 .6798 L .49196 .67244 L p .707 .577 .707 r
F P
0 g
s
.49196 .67244 m .49196 .63538 L .47559 .64275 L p .707 .577 .707 r
F P
0 g
s
.29804 .55482 m .29804 .49924 L .29515 .4907 L p .707 .577 .707 r
F P
0 g
s
.64524 .79616 m .64524 .77763 L .66161 .77026 L p .707 .577 .707 r
F P
0 g
s
.42216 .77758 m .42216 .7961 L .45154 .79272 L p .707 .577 .707 r
F P
0 g
s
.45154 .79272 m .45154 .7742 L .42216 .77758 L p .707 .577 .707 r
F P
0 g
s
.68566 .63881 m .68566 .67587 L .66161 .68152 L p .707 .577 .707 r
F P
0 g
s
.35915 .77645 m .35915 .79498 L .39032 .79688 L p .707 .577 .707 r
F P
0 g
s
.80551 .64095 m .80551 .67801 L .77805 .67361 L p .707 .577 .707 r
F P
0 g
s
.77805 .67361 m .77805 .63656 L .80551 .64095 L p .707 .577 .707 r
F P
0 g
s
.35915 .79498 m .35915 .77645 L .33169 .77206 L p .707 .577 .707 r
F P
0 g
s
.66161 .77026 m .66161 .78879 L .64524 .79616 L p .707 .577 .707 r
F P
0 g
s
.31064 .67686 m .31064 .63981 L .29804 .63192 L p .707 .577 .707 r
F P
0 g
s
.33169 .77206 m .33169 .79059 L .35915 .79498 L p .707 .577 .707 r
F P
0 g
s
.68566 .67587 m .68566 .63881 L .71504 .63544 L p .707 .577 .707 r
F P
0 g
s
.45154 .7742 m .45154 .79272 L .47559 .78707 L p .707 .577 .707 r
F P
0 g
s
.47559 .78707 m .47559 .76855 L .45154 .7742 L p .707 .577 .707 r
F P
0 g
s
.29515 .4907 m .29515 .54628 L .29804 .55482 L p .707 .577 .707 r
F P
0 g
s
.82657 .7732 m .82657 .79173 L .80551 .78528 L p .707 .577 .707 r
F P
0 g
s
.80551 .78528 m .80551 .76675 L .82657 .7732 L p .707 .577 .707 r
F P
0 g
s
.49904 .49433 m .49904 .54992 L .49615 .54137 L p .707 .577 .707 r
F P
0 g
s
.49615 .54137 m .49615 .48579 L .49904 .49433 L p .707 .577 .707 r
F P
0 g
s
.29804 .63192 m .29804 .66898 L .31064 .67686 L p .707 .577 .707 r
F P
0 g
s
.77805 .63656 m .77805 .67361 L .74688 .67171 L p .707 .577 .707 r
F P
0 g
s
.74688 .67171 m .74688 .63466 L .77805 .63656 L p .707 .577 .707 r
F P
0 g
s
.33169 .79059 m .33169 .77206 L .31064 .76561 L p .707 .577 .707 r
F P
0 g
s
.71504 .63544 m .71504 .67249 L .68566 .67587 L p .707 .577 .707 r
F P
0 g
s
.71504 .67249 m .71504 .63544 L .74688 .63466 L p .707 .577 .707 r
F P
0 g
s
.49196 .63538 m .49196 .67244 L .49904 .66407 L p .707 .577 .707 r
F P
0 g
s
.49904 .66407 m .49904 .62702 L .49196 .63538 L p .707 .577 .707 r
F P
0 g
s
.31064 .76561 m .31064 .78413 L .33169 .79059 L p .707 .577 .707 r
F P
0 g
s
.66161 .78879 m .66161 .77026 L .68566 .76461 L p .707 .577 .707 r
F P
0 g
s
.74688 .63466 m .74688 .67171 L .71504 .67249 L p .707 .577 .707 r
F P
0 g
s
.29515 .54628 m .29515 .4907 L .30223 .48233 L p .707 .577 .707 r
F P
0 g
s
.68566 .76461 m .68566 .78314 L .66161 .78879 L p .707 .577 .707 r
F P
0 g
s
.47559 .76855 m .47559 .78707 L .49196 .77971 L p .707 .577 .707 r
F P
0 g
s
.49196 .77971 m .49196 .76118 L .47559 .76855 L p .707 .577 .707 r
F P
0 g
s
.29804 .66898 m .29804 .63192 L .29515 .62338 L p .707 .577 .707 r
F P
0 g
s
.80551 .76675 m .80551 .78528 L .77805 .78089 L p .707 .577 .707 r
F P
0 g
s
.77805 .78089 m .77805 .76236 L .80551 .76675 L p .707 .577 .707 r
F P
0 g
s
.31064 .78413 m .31064 .76561 L .29804 .75772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48233 m .30223 .53792 L .29515 .54628 L p .707 .577 .707 r
F P
0 g
s
.68566 .78314 m .68566 .76461 L .71504 .76123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62338 m .29515 .66044 L .29804 .66898 L p .707 .577 .707 r
F P
0 g
s
.49615 .48579 m .49615 .54137 L .48356 .53349 L p .707 .577 .707 r
F P
0 g
s
.48356 .53349 m .48356 .47791 L .49615 .48579 L p .707 .577 .707 r
F P
0 g
s
.29804 .75772 m .29804 .77625 L .31064 .78413 L p .707 .577 .707 r
F P
0 g
s
.71504 .76123 m .71504 .77976 L .68566 .78314 L p .707 .577 .707 r
F P
0 g
s
.49904 .62702 m .49904 .66407 L .49615 .65553 L p .707 .577 .707 r
F P
0 g
s
.49615 .65553 m .49615 .61847 L .49904 .62702 L p .707 .577 .707 r
F P
0 g
s
.77805 .76236 m .77805 .78089 L .74688 .77898 L p .707 .577 .707 r
F P
0 g
s
.74688 .77898 m .74688 .76046 L .77805 .76236 L p .707 .577 .707 r
F P
0 g
s
.71504 .77976 m .71504 .76123 L .74688 .76046 L p .707 .577 .707 r
F P
0 g
s
.49196 .76118 m .49196 .77971 L .49904 .77134 L p .707 .577 .707 r
F P
0 g
s
.49904 .77134 m .49904 .75282 L .49196 .76118 L p .707 .577 .707 r
F P
0 g
s
.30223 .53792 m .30223 .48233 L .3186 .47497 L p .707 .577 .707 r
F P
0 g
s
.74688 .76046 m .74688 .77898 L .71504 .77976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .66044 m .29515 .62338 L .30223 .61502 L p .707 .577 .707 r
F P
0 g
s
.29804 .77625 m .29804 .75772 L .29515 .74918 L p .707 .577 .707 r
F P
0 g
s
.3186 .47497 m .3186 .53055 L .30223 .53792 L p .707 .577 .707 r
F P
0 g
s
.48356 .47791 m .48356 .53349 L .4625 .52704 L p .707 .577 .707 r
F P
0 g
s
.4625 .52704 m .4625 .47145 L .48356 .47791 L p .707 .577 .707 r
F P
0 g
s
.29515 .74918 m .29515 .76771 L .29804 .77625 L p .707 .577 .707 r
F P
0 g
s
.30223 .61502 m .30223 .65207 L .29515 .66044 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .61847 m .49615 .65553 L .48356 .64764 L p .707 .577 .707 r
F P
0 g
s
.48356 .64764 m .48356 .61059 L .49615 .61847 L p .707 .577 .707 r
F P
0 g
s
.3186 .53055 m .3186 .47497 L .34265 .46932 L p .707 .577 .707 r
F P
0 g
s
.49904 .75282 m .49904 .77134 L .49615 .7628 L p .707 .577 .707 r
F P
0 g
s
.49615 .7628 m .49615 .74427 L .49904 .75282 L p .707 .577 .707 r
F P
0 g
s
.30223 .65207 m .30223 .61502 L .3186 .60765 L p .707 .577 .707 r
F P
0 g
s
.4625 .47145 m .4625 .52704 L .43504 .52264 L p .707 .577 .707 r
F P
0 g
s
.43504 .52264 m .43504 .46706 L .4625 .47145 L p .707 .577 .707 r
F P
0 g
s
.34265 .46932 m .34265 .5249 L .3186 .53055 L p .707 .577 .707 r
F P
0 g
s
.29515 .76771 m .29515 .74918 L .30223 .74082 L p .707 .577 .707 r
F P
0 g
s
.34265 .5249 m .34265 .46932 L .37203 .46594 L p .707 .577 .707 r
F P
0 g
s
.30223 .74082 m .30223 .75934 L .29515 .76771 L p .707 .577 .707 r
F P
0 g
s
.3186 .60765 m .3186 .6447 L .30223 .65207 L p .707 .577 .707 r
F P
0 g
s
.48356 .61059 m .48356 .64764 L .4625 .64119 L p .707 .577 .707 r
F P
0 g
s
.4625 .64119 m .4625 .60414 L .48356 .61059 L p .707 .577 .707 r
F P
0 g
s
.43504 .46706 m .43504 .52264 L .40387 .52074 L p .707 .577 .707 r
F P
0 g
s
.40387 .52074 m .40387 .46516 L .43504 .46706 L p .707 .577 .707 r
F P
0 g
s
.37203 .52152 m .37203 .46594 L .40387 .46516 L p .707 .577 .707 r
F P
0 g
s
.37203 .46594 m .37203 .52152 L .34265 .5249 L p .707 .577 .707 r
F P
0 g
s
.49615 .74427 m .49615 .7628 L .48356 .75492 L p .707 .577 .707 r
F P
0 g
s
.48356 .75492 m .48356 .73639 L .49615 .74427 L p .707 .577 .707 r
F P
0 g
s
.40387 .46516 m .40387 .52074 L .37203 .52152 L p .707 .577 .707 r
F P
0 g
s
.3186 .6447 m .3186 .60765 L .34265 .602 L p .707 .577 .707 r
F P
0 g
s
.30223 .75934 m .30223 .74082 L .3186 .73345 L p .707 .577 .707 r
F P
0 g
s
.34265 .602 m .34265 .63905 L .3186 .6447 L p .707 .577 .707 r
F P
0 g
s
.4625 .60414 m .4625 .64119 L .43504 .6368 L p .707 .577 .707 r
F P
0 g
s
.43504 .6368 m .43504 .59974 L .4625 .60414 L p .707 .577 .707 r
F P
0 g
s
.3186 .73345 m .3186 .75198 L .30223 .75934 L p .707 .577 .707 r
F P
0 g
s
.34265 .63905 m .34265 .602 L .37203 .59862 L p .707 .577 .707 r
F P
0 g
s
.48356 .73639 m .48356 .75492 L .4625 .74846 L p .707 .577 .707 r
F P
0 g
s
.4625 .74846 m .4625 .72993 L .48356 .73639 L p .707 .577 .707 r
F P
0 g
s
.43504 .59974 m .43504 .6368 L .40387 .6349 L p .707 .577 .707 r
F P
0 g
s
.40387 .6349 m .40387 .59784 L .43504 .59974 L p .707 .577 .707 r
F P
0 g
s
.37203 .59862 m .37203 .63567 L .34265 .63905 L p .707 .577 .707 r
F P
0 g
s
.37203 .63567 m .37203 .59862 L .40387 .59784 L p .707 .577 .707 r
F P
0 g
s
.3186 .75198 m .3186 .73345 L .34265 .7278 L p .707 .577 .707 r
F P
0 g
s
.40387 .59784 m .40387 .6349 L .37203 .63567 L p .707 .577 .707 r
F P
0 g
s
.34265 .7278 m .34265 .74633 L .3186 .75198 L p .707 .577 .707 r
F P
0 g
s
.4625 .72993 m .4625 .74846 L .43504 .74407 L p .707 .577 .707 r
F P
0 g
s
.43504 .74407 m .43504 .72554 L .4625 .72993 L p .707 .577 .707 r
F P
0 g
s
.34265 .74633 m .34265 .7278 L .37203 .72442 L p .707 .577 .707 r
F P
0 g
s
.37203 .72442 m .37203 .74295 L .34265 .74633 L p .707 .577 .707 r
F P
0 g
s
.43504 .72554 m .43504 .74407 L .40387 .74217 L p .707 .577 .707 r
F P
0 g
s
.40387 .74217 m .40387 .72364 L .43504 .72554 L p .707 .577 .707 r
F P
0 g
s
.37203 .74295 m .37203 .72442 L .40387 .72364 L p .707 .577 .707 r
F P
0 g
s
.40387 .72364 m .40387 .74217 L .37203 .74295 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002;Ool<
0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH2001[Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
001YOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol30005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Qoo`T004Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`l000AJEP03001JEUYF009JEPP003aoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03
001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF
001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolA0005Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009J
EPT000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF10000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH06P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH7000h
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPT000AJEP@00003
FUH0000000L003moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF60000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo2@00B7oo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool00`00FUH0
0004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF4P00A7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH000040003FUH2
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH300000eYF000000020003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP07FUH600000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P00=7oo000^Ool01000FUIJEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00FUH20005FUH00`00FUH000050002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80039oo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00@005YF001JEP80
0003FUH005YF00AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH0
05YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`00<7oo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo1@00
15YF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo6P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0000=J
EP00Ool01Woo1@0037oo1@0015YF00@005YFFUIJEP8002eoo`00FWoo0`0000=JEP00FUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD00003FUH005YF00=JEP03
001JEP0000Qoo`<0015oo`@00003FUH005YF009JEP8002eoo`00GGoo1@0015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH00UYF20002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP8000=JEPD000=JEP8001Ioo`L000=JEP<000=JEP8002eoo`00
HWoo200015YF1@0000=JEP0000001`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00@005YFFUIJEPT000Uoo`T0
00=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00?goo6@003Goo00D005YFFUH0
05YF00X000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04001JEUYF0005FUH40006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP800005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool300000eYF001JEP06FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006Ool30006
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH900000eYF001JEP02FUH60009
FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool40002
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP04001JEUYFFUH>0004FUH00`00FUIJ
EP02FUH8000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH00`00FUH0
000=OolI000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPH000Qoo`D000Aoo`P000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00002000G
Ool30019Ool002aoo`03001JEP0000AJEP03001JEP0000<000ioo`D000aoo`@000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00=JEP03001JEP00009JEPD0
05ioo`00;7oo00<005YF00000eYF1`003goo0`0037oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000EJEP03001JEP00
008005]oo`00;7oo00@005YF001JEP8000EJEP03001JEP0000<001Qoo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00005FUH0
0`00FUIJEP02FUH2001IOol002aoo`06001JEP00001JEP001EYF00<005YFFUH00eYF6@0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YFFUH00eYF0`00
Egoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP020004FUH01000FUIJEUYF200000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EPD0009JEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3
00000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF0P0000=JEP00FUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF0`002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EP000002FUH30006FUH01`00FUIJEUYF001oo`0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00QJEP<00003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000<000=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000jOol0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04
001JEP000003FUH00`00FUH000020003FUH01000FUH000000Woo00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YF00002UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0017oo1`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1000=Woo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH40006
FUH01000FUH000000eYF00<005YFFUH00UYF1@001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH0
25YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000Ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0039oo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF
00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH:0007FUH00`00FUIJEP07FUH50005FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000Ioo`800003
FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP80035oo`00>goo200015YF1@001EYF00@005YFFUIJEP800003FUH005YF00AJEP03
001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YF00002@000eYF00<005YFFUH00eYF00<005YFFUH00UYF4P00
15YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002moo`00@goo4`0000Aoo`00000000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP04001JEUYFFUH20004
FUH00`00FUIJEP02FUH8000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo0018Ool3
000?Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH01P00FUIJ
EP00FUH000AJEP03001JEP0000<000AJEP<001Qoo`D000AJEP05001JEUYFFUH0000^Ool005eoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001J
EUYF00YJEP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0`000eYF
00<005YFFUH00UYF0`007Goo0`0000=JEP00FUH00UYF0P00;Goo001POol40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80006FUH00`00FUIJEP0:FUH00`00FUIJEP060008FUH0
0`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000IJEP03001JEUYF009JEP03001JEP00021oo`80
00=JEP8002eoo`00I7oo6@0027oo5P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800003FUH005YF00EJEP03001JEUYF009JEP8002=oo`800003FUH0000002eoo`00T7oo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000AJ
EP00FUH000IJEP04001JEUYFFUH2000TOol5000]Ool0095oo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000IJEP04001JEP00000TOol20002FUH3
000]Ool0099oo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEP000080009JEP<0029oo`@000AJEP03001JEP0002eoo`00UGoo1@001UYF00<0
05YFFUH01UYF10001EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPD001]oo`L000=JEP03001J
EUYF009JEP8002ioo`00Agoo2@00BWoo10000UYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool003moo`P000AJEP03001JEUYF009JEPP004Iooa`000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6001;Ool5000;Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000<Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020019Ool3000>Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000`Ool200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001K
Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<005ioo`T000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00IGoo2@00B7oo000]
Ool20004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP000;Ioo`00;7oo00<005YF0000
15YF10009goo0`0000=JEP00FUH00UYF00<007ooOol0]7oo000/Ool00`00FUH00002FUH2000^Ool2
0003FUH00`00Oomoo`2dOol002aoo`03001JEP000080039oo`04001JEUYF002fOol002aoo`04001J
EP00000dOol3000iOolH001UOol002aoo`80009JEP<002moo`<00003FUH007oo039oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0065oo`00;7oo0P000eYF00<005YF00000P00
:Goo0`000UYF00<005YF0000<7oo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`00GWoo000/Ool20003FUH00`00FUIJEP02FUH5000POol400000eYF001JEP02
FUH00`00FUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF20004goo
1@001EYF00@005YFFUIJEP8002aoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8005Uoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00
Egoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000/Ool00`00FUH00004FUH00`00FUH0
0002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00FUH00003FUH3000XOol300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
03=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eooaT003Qoo`04001JEP00000bOol20000
0eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P000UYF0P00;goo0P0000AJEP00000005Ao
o`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJ
EQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
05Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001J
EUYF009JEPh0065oo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72157 m .59613 .66599 L .56496 .66409 L p .707 .577 .707 r
F P
0 g
s
.59613 .66599 m .59613 .72157 L .62796 .72079 L p .707 .577 .707 r
F P
0 g
s
.62796 .72079 m .62796 .66521 L .59613 .66599 L p .707 .577 .707 r
F P
0 g
s
.62796 .66521 m .62796 .72079 L .65734 .71741 L p .707 .577 .707 r
F P
0 g
s
.65734 .71741 m .65734 .66183 L .62796 .66521 L p .707 .577 .707 r
F P
0 g
s
.56496 .71967 m .56496 .66409 L .5375 .65969 L p .707 .577 .707 r
F P
0 g
s
.56496 .66409 m .56496 .71967 L .59613 .72157 L p .707 .577 .707 r
F P
0 g
s
.65734 .66183 m .65734 .71741 L .6814 .71176 L p .707 .577 .707 r
F P
0 g
s
.6814 .71176 m .6814 .65618 L .65734 .66183 L p .707 .577 .707 r
F P
0 g
s
.5375 .65969 m .5375 .71528 L .56496 .71967 L p .707 .577 .707 r
F P
0 g
s
.5375 .71528 m .5375 .65969 L .51644 .65324 L p .707 .577 .707 r
F P
0 g
s
.59613 .81518 m .59613 .77812 L .56496 .77622 L p .707 .577 .707 r
F P
0 g
s
.59613 .77812 m .59613 .81518 L .62796 .8144 L p .707 .577 .707 r
F P
0 g
s
.62796 .8144 m .62796 .77734 L .59613 .77812 L p .707 .577 .707 r
F P
0 g
s
.62796 .77734 m .62796 .8144 L .65735 .81102 L p .707 .577 .707 r
F P
0 g
s
.65735 .81102 m .65735 .77397 L .62796 .77734 L p .707 .577 .707 r
F P
0 g
s
.6814 .65618 m .6814 .71176 L .69777 .7044 L p .707 .577 .707 r
F P
0 g
s
.69777 .7044 m .69777 .64881 L .6814 .65618 L p .707 .577 .707 r
F P
0 g
s
.56496 .81328 m .56496 .77622 L .5375 .77183 L p .707 .577 .707 r
F P
0 g
s
.56496 .77622 m .56496 .81328 L .59613 .81518 L p .707 .577 .707 r
F P
0 g
s
.51644 .65324 m .51644 .70882 L .5375 .71528 L p .707 .577 .707 r
F P
0 g
s
.51644 .70882 m .51644 .65324 L .50385 .64536 L p .707 .577 .707 r
F P
0 g
s
.65735 .77397 m .65735 .81102 L .6814 .80537 L p .707 .577 .707 r
F P
0 g
s
.6814 .80537 m .6814 .76832 L .65735 .77397 L p .707 .577 .707 r
F P
0 g
s
.5375 .77183 m .5375 .80888 L .56496 .81328 L p .707 .577 .707 r
F P
0 g
s
.5375 .80888 m .5375 .77183 L .51644 .76537 L p .707 .577 .707 r
F P
0 g
s
.59613 .89745 m .59613 .87893 L .56496 .87702 L p .707 .577 .707 r
F P
0 g
s
.59613 .87893 m .59613 .89745 L .62796 .89668 L p .707 .577 .707 r
F P
0 g
s
.62796 .89668 m .62796 .87815 L .59613 .87893 L p .707 .577 .707 r
F P
0 g
s
.50385 .64536 m .50385 .70094 L .51644 .70882 L p .707 .577 .707 r
F P
0 g
s
.69777 .64881 m .69777 .7044 L .70485 .69603 L p .707 .577 .707 r
F P
0 g
s
.70485 .69603 m .70485 .64045 L .69777 .64881 L p .707 .577 .707 r
F P
0 g
s
.62796 .87815 m .62796 .89668 L .65735 .8933 L p .707 .577 .707 r
F P
0 g
s
.65735 .8933 m .65735 .87477 L .62796 .87815 L p .707 .577 .707 r
F P
0 g
s
.51644 .76537 m .51644 .80243 L .5375 .80888 L p .707 .577 .707 r
F P
0 g
s
.56496 .87702 m .56496 .89555 L .59613 .89745 L p .707 .577 .707 r
F P
0 g
s
.56496 .89555 m .56496 .87702 L .5375 .87263 L p .707 .577 .707 r
F P
0 g
s
.6814 .76832 m .6814 .80537 L .69777 .798 L p .707 .577 .707 r
F P
0 g
s
.69777 .798 m .69777 .76095 L .6814 .76832 L p .707 .577 .707 r
F P
0 g
s
.5375 .87263 m .5375 .89116 L .56496 .89555 L p .707 .577 .707 r
F P
0 g
s
.50385 .70094 m .50385 .64536 L .50095 .63681 L p .707 .577 .707 r
F P
0 g
s
.65735 .87477 m .65735 .8933 L .6814 .88765 L p .707 .577 .707 r
F P
0 g
s
.6814 .88765 m .6814 .86912 L .65735 .87477 L p .707 .577 .707 r
F P
0 g
s
.51644 .80243 m .51644 .76537 L .50385 .75749 L p .707 .577 .707 r
F P
0 g
s
.5375 .89116 m .5375 .87263 L .51644 .86618 L p .707 .577 .707 r
F P
0 g
s
.51644 .86618 m .51644 .88471 L .5375 .89116 L p .707 .577 .707 r
F P
0 g
s
.50385 .75749 m .50385 .79455 L .51644 .80243 L p .707 .577 .707 r
F P
0 g
s
.50095 .63681 m .50095 .6924 L .50385 .70094 L p .707 .577 .707 r
F P
0 g
s
.70485 .64045 m .70485 .69603 L .70195 .68749 L p .707 .577 .707 r
F P
0 g
s
.70195 .68749 m .70195 .63191 L .70485 .64045 L p .707 .577 .707 r
F P
0 g
s
.69777 .76095 m .69777 .798 L .70485 .78964 L p .707 .577 .707 r
F P
0 g
s
.70485 .78964 m .70485 .75258 L .69777 .76095 L p .707 .577 .707 r
F P
0 g
s
.6814 .86912 m .6814 .88765 L .69777 .88028 L p .707 .577 .707 r
F P
0 g
s
.69777 .88028 m .69777 .86175 L .6814 .86912 L p .707 .577 .707 r
F P
0 g
s
.50095 .6924 m .50095 .63681 L .50804 .62845 L p .707 .577 .707 r
F P
0 g
s
.49044 .80603 m .49044 .30415 L .44643 .30146 L p .707 .577 .707 r
F P
0 g
s
.50385 .79455 m .50385 .75749 L .50095 .74895 L p .707 .577 .707 r
F P
0 g
s
.50095 .74895 m .50095 .786 L .50385 .79455 L p .707 .577 .707 r
F P
0 g
s
.50804 .62845 m .50804 .68403 L .50095 .6924 L p .707 .577 .707 r
F P
0 g
s
.50804 .68403 m .50804 .62845 L .5244 .62108 L p .707 .577 .707 r
F P
0 g
s
.50095 .786 m .50095 .74895 L .50804 .74058 L p .707 .577 .707 r
F P
0 g
s
.50804 .74058 m .50804 .77764 L .50095 .786 L p .707 .577 .707 r
F P
0 g
s
.5244 .62108 m .5244 .67666 L .50804 .68403 L p .707 .577 .707 r
F P
0 g
s
.50804 .77764 m .50804 .74058 L .5244 .73322 L p .707 .577 .707 r
F P
0 g
s
.5244 .73322 m .5244 .77027 L .50804 .77764 L p .707 .577 .707 r
F P
0 g
s
.5244 .77027 m .5244 .73322 L .54846 .72757 L p .707 .577 .707 r
F P
0 g
s
.54846 .72757 m .54846 .76462 L .5244 .77027 L p .707 .577 .707 r
F P
0 g
s
.49044 .30415 m .49044 .80603 L .53538 .80494 L p .707 .577 .707 r
F P
0 g
s
.5244 .67666 m .5244 .62108 L .54846 .61543 L p .707 .577 .707 r
F P
0 g
s
.54846 .61543 m .54846 .67101 L .5244 .67666 L p .707 .577 .707 r
F P
0 g
s
.53538 .80494 m .53538 .30305 L .49044 .30415 L p .707 .577 .707 r
F P
0 g
s
.51644 .88471 m .51644 .86618 L .50385 .85829 L p .707 .577 .707 r
F P
0 g
s
.54846 .67101 m .54846 .61543 L .57784 .61205 L p .707 .577 .707 r
F P
0 g
s
.57784 .61205 m .57784 .66763 L .54846 .67101 L p .707 .577 .707 r
F P
0 g
s
.54846 .76462 m .54846 .72757 L .57784 .72419 L p .707 .577 .707 r
F P
0 g
s
.57784 .72419 m .57784 .76124 L .54846 .76462 L p .707 .577 .707 r
F P
0 g
s
.53538 .30305 m .53538 .80494 L .57686 .80017 L p .707 .577 .707 r
F P
0 g
s
.57686 .80017 m .57686 .29828 L .53538 .30305 L p .707 .577 .707 r
F P
0 g
s
.50385 .85829 m .50385 .87682 L .51644 .88471 L p .707 .577 .707 r
F P
0 g
s
.44643 .80335 m .44643 .30146 L .40766 .29526 L p .707 .577 .707 r
F P
0 g
s
.44643 .30146 m .44643 .80335 L .49044 .80603 L p .707 .577 .707 r
F P
0 g
s
.69777 .86175 m .69777 .88028 L .70485 .87191 L p .707 .577 .707 r
F P
0 g
s
.70485 .87191 m .70485 .85339 L .69777 .86175 L p .707 .577 .707 r
F P
0 g
s
.70195 .63191 m .70195 .68749 L .68936 .6796 L p .707 .577 .707 r
F P
0 g
s
.68936 .6796 m .68936 .62402 L .70195 .63191 L p .707 .577 .707 r
F P
0 g
s
.70485 .75258 m .70485 .78964 L .70195 .7811 L p .707 .577 .707 r
F P
0 g
s
.70195 .7811 m .70195 .74404 L .70485 .75258 L p .707 .577 .707 r
F P
0 g
s
.57784 .66763 m .57784 .61205 L .60968 .61128 L p .707 .577 .707 r
F P
0 g
s
.60968 .61128 m .60968 .66686 L .57784 .66763 L p .707 .577 .707 r
F P
0 g
s
.57784 .76124 m .57784 .72419 L .60968 .72341 L p .707 .577 .707 r
F P
0 g
s
.60968 .72341 m .60968 .76047 L .57784 .76124 L p .707 .577 .707 r
F P
0 g
s
.57686 .29828 m .57686 .80017 L .61082 .79219 L p .707 .577 .707 r
F P
0 g
s
.64085 .61318 m .64085 .66876 L .60968 .66686 L p .707 .577 .707 r
F P
0 g
s
.60968 .66686 m .60968 .61128 L .64085 .61318 L p .707 .577 .707 r
F P
0 g
s
.64085 .72531 m .64085 .76237 L .60968 .76047 L p .707 .577 .707 r
F P
0 g
s
.60968 .76047 m .60968 .72341 L .64085 .72531 L p .707 .577 .707 r
F P
0 g
s
.61082 .79219 m .61082 .2903 L .57686 .29828 L p .707 .577 .707 r
F P
0 g
s
.25312 .68475 m .25312 .62917 L .22195 .62727 L p .707 .577 .707 r
F P
0 g
s
.25312 .62917 m .25312 .68475 L .28495 .68398 L p .707 .577 .707 r
F P
0 g
s
.28495 .68398 m .28495 .62839 L .25312 .62917 L p .707 .577 .707 r
F P
0 g
s
.50385 .87682 m .50385 .85829 L .50095 .84975 L p .707 .577 .707 r
F P
0 g
s
.28495 .62839 m .28495 .68398 L .31434 .6806 L p .707 .577 .707 r
F P
0 g
s
.31434 .6806 m .31434 .62502 L .28495 .62839 L p .707 .577 .707 r
F P
0 g
s
.40766 .79715 m .40766 .29526 L .37794 .28615 L p .707 .577 .707 r
F P
0 g
s
.40766 .29526 m .40766 .79715 L .44643 .80335 L p .707 .577 .707 r
F P
0 g
s
.50095 .84975 m .50095 .86828 L .50385 .87682 L p .707 .577 .707 r
F P
0 g
s
.22195 .68285 m .22195 .62727 L .19449 .62288 L p .707 .577 .707 r
F P
0 g
s
.22195 .62727 m .22195 .68285 L .25312 .68475 L p .707 .577 .707 r
F P
0 g
s
.31434 .62502 m .31434 .6806 L .33839 .67495 L p .707 .577 .707 r
F P
0 g
s
.33839 .67495 m .33839 .61937 L .31434 .62502 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68936 .62402 m .68936 .6796 L .66831 .67315 L p .707 .577 .707 r
F P
0 g
s
.66831 .67315 m .66831 .61757 L .68936 .62402 L p .707 .577 .707 r
F P
0 g
s
.70485 .85339 m .70485 .87191 L .70195 .86337 L p .707 .577 .707 r
F P
0 g
s
.70195 .86337 m .70195 .84485 L .70485 .85339 L p .707 .577 .707 r
F P
0 g
s
.70195 .74404 m .70195 .7811 L .68936 .77321 L p .707 .577 .707 r
F P
0 g
s
.68936 .77321 m .68936 .73616 L .70195 .74404 L p .707 .577 .707 r
F P
0 g
s
.19449 .62288 m .19449 .67846 L .22195 .68285 L p .707 .577 .707 r
F P
0 g
s
.61082 .2903 m .61082 .79219 L .63393 .78179 L p .707 .577 .707 r
F P
0 g
s
.63393 .78179 m .63393 .2799 L .61082 .2903 L p .707 .577 .707 r
F P
0 g
s
.19449 .67846 m .19449 .62288 L .17343 .61642 L p .707 .577 .707 r
F P
0 g
s
.25312 .77836 m .25312 .74131 L .22195 .73941 L p .707 .577 .707 r
F P
0 g
s
.25312 .74131 m .25312 .77836 L .28495 .77758 L p .707 .577 .707 r
F P
0 g
s
.28495 .77758 m .28495 .74053 L .25312 .74131 L p .707 .577 .707 r
F P
0 g
s
.50095 .86828 m .50095 .84975 L .50804 .84139 L p .707 .577 .707 r
F P
0 g
s
.28495 .74053 m .28495 .77758 L .31434 .7742 L p .707 .577 .707 r
F P
0 g
s
.31434 .7742 m .31434 .73715 L .28495 .74053 L p .707 .577 .707 r
F P
0 g
s
.33839 .61937 m .33839 .67495 L .35476 .66758 L p .707 .577 .707 r
F P
0 g
s
.35476 .66758 m .35476 .612 L .33839 .61937 L p .707 .577 .707 r
F P
0 g
s
.50804 .84139 m .50804 .85992 L .50095 .86828 L p .707 .577 .707 r
F P
0 g
s
.37794 .78804 m .37794 .28615 L .36016 .27502 L p .707 .577 .707 r
F P
0 g
s
.37794 .28615 m .37794 .78804 L .40766 .79715 L p .707 .577 .707 r
F P
0 g
s
.22195 .77646 m .22195 .73941 L .19449 .73501 L p .707 .577 .707 r
F P
0 g
s
.22195 .73941 m .22195 .77646 L .25312 .77836 L p .707 .577 .707 r
F P
0 g
s
.17343 .61642 m .17343 .67201 L .19449 .67846 L p .707 .577 .707 r
F P
0 g
s
.66831 .61757 m .66831 .67315 L .64085 .66876 L p .707 .577 .707 r
F P
0 g
s
.64085 .66876 m .64085 .61318 L .66831 .61757 L p .707 .577 .707 r
F P
0 g
s
.17343 .67201 m .17343 .61642 L .16084 .60854 L p .707 .577 .707 r
F P
0 g
s
.31434 .73715 m .31434 .7742 L .33839 .76855 L p .707 .577 .707 r
F P
0 g
s
.33839 .76855 m .33839 .7315 L .31434 .73715 L p .707 .577 .707 r
F P
0 g
s
.19449 .73501 m .19449 .77207 L .22195 .77646 L p .707 .577 .707 r
F P
0 g
s
.70195 .84485 m .70195 .86337 L .68936 .85549 L p .707 .577 .707 r
F P
0 g
s
.68936 .85549 m .68936 .83696 L .70195 .84485 L p .707 .577 .707 r
F P
0 g
s
.68936 .73616 m .68936 .77321 L .66831 .76676 L p .707 .577 .707 r
F P
0 g
s
.66831 .76676 m .66831 .7297 L .68936 .73616 L p .707 .577 .707 r
F P
0 g
s
.19449 .77207 m .19449 .73501 L .17343 .72856 L p .707 .577 .707 r
F P
0 g
s
.25312 .86064 m .25312 .84211 L .22195 .84021 L p .707 .577 .707 r
F P
0 g
s
.25312 .84211 m .25312 .86064 L .28495 .85986 L p .707 .577 .707 r
F P
0 g
s
.28495 .85986 m .28495 .84133 L .25312 .84211 L p .707 .577 .707 r
F P
0 g
s
.66831 .7297 m .66831 .76676 L .64085 .76237 L p .707 .577 .707 r
F P
0 g
s
.64085 .76237 m .64085 .72531 L .66831 .7297 L p .707 .577 .707 r
F P
0 g
s
.63393 .2799 m .63393 .78179 L .64393 .76998 L p .707 .577 .707 r
F P
0 g
s
.64393 .76998 m .64393 .26809 L .63393 .2799 L p .707 .577 .707 r
F P
0 g
s
.16084 .60854 m .16084 .66412 L .17343 .67201 L p .707 .577 .707 r
F P
0 g
s
.35476 .612 m .35476 .66758 L .36184 .65922 L p .707 .577 .707 r
F P
0 g
s
.36184 .65922 m .36184 .60363 L .35476 .612 L p .707 .577 .707 r
F P
0 g
s
.50804 .85992 m .50804 .84139 L .5244 .83402 L p .707 .577 .707 r
F P
0 g
s
.28495 .84133 m .28495 .85986 L .31434 .85648 L p .707 .577 .707 r
F P
0 g
s
.31434 .85648 m .31434 .83795 L .28495 .84133 L p .707 .577 .707 r
F P
0 g
s
.17343 .72856 m .17343 .76561 L .19449 .77207 L p .707 .577 .707 r
F P
0 g
s
.22195 .84021 m .22195 .85874 L .25312 .86064 L p .707 .577 .707 r
F P
0 g
s
.22195 .85874 m .22195 .84021 L .19449 .83582 L p .707 .577 .707 r
F P
0 g
s
.33839 .7315 m .33839 .76855 L .35476 .76119 L p .707 .577 .707 r
F P
0 g
s
.35476 .76119 m .35476 .72413 L .33839 .7315 L p .707 .577 .707 r
F P
0 g
s
.5244 .83402 m .5244 .85255 L .50804 .85992 L p .707 .577 .707 r
F P
0 g
s
.19449 .83582 m .19449 .85434 L .22195 .85874 L p .707 .577 .707 r
F P
0 g
s
.16084 .66412 m .16084 .60854 L .15794 .6 L p .707 .577 .707 r
F P
0 g
s
.31434 .83795 m .31434 .85648 L .33839 .85083 L p .707 .577 .707 r
F P
0 g
s
.33839 .85083 m .33839 .8323 L .31434 .83795 L p .707 .577 .707 r
F P
0 g
s
.17343 .76561 m .17343 .72856 L .16084 .72068 L p .707 .577 .707 r
F P
0 g
s
.36184 .60363 m .36184 .65922 L .35894 .65067 L p .707 .577 .707 r
F P
0 g
s
.35894 .65067 m .35894 .59509 L .36184 .60363 L p .707 .577 .707 r
F P
0 g
s
.35476 .72413 m .35476 .76119 L .36184 .75282 L p .707 .577 .707 r
F P
0 g
s
.36184 .75282 m .36184 .71577 L .35476 .72413 L p .707 .577 .707 r
F P
0 g
s
.35894 .59509 m .35894 .65067 L .34635 .64279 L p .707 .577 .707 r
F P
0 g
s
.34635 .64279 m .34635 .58721 L .35894 .59509 L p .707 .577 .707 r
F P
0 g
s
.36184 .71577 m .36184 .75282 L .35894 .74428 L p .707 .577 .707 r
F P
0 g
s
.35894 .74428 m .35894 .70723 L .36184 .71577 L p .707 .577 .707 r
F P
0 g
s
.36016 .77691 m .36016 .27502 L .35607 .26296 L p .707 .577 .707 r
F P
0 g
s
.36016 .27502 m .36016 .77691 L .37794 .78804 L p .707 .577 .707 r
F P
0 g
s
.68936 .83696 m .68936 .85549 L .66831 .84903 L p .707 .577 .707 r
F P
0 g
s
.66831 .84903 m .66831 .83051 L .68936 .83696 L p .707 .577 .707 r
F P
0 g
s
.19449 .85434 m .19449 .83582 L .17343 .82936 L p .707 .577 .707 r
F P
0 g
s
.17343 .82936 m .17343 .84789 L .19449 .85434 L p .707 .577 .707 r
F P
0 g
s
.16084 .72068 m .16084 .75773 L .17343 .76561 L p .707 .577 .707 r
F P
0 g
s
.5244 .85255 m .5244 .83402 L .54846 .82837 L p .707 .577 .707 r
F P
0 g
s
.15794 .6 m .15794 .65558 L .16084 .66412 L p .707 .577 .707 r
F P
0 g
s
.54846 .82837 m .54846 .8469 L .5244 .85255 L p .707 .577 .707 r
F P
0 g
s
.33839 .8323 m .33839 .85083 L .35476 .84346 L p .707 .577 .707 r
F P
0 g
s
.35476 .84346 m .35476 .82494 L .33839 .8323 L p .707 .577 .707 r
F P
0 g
s
.66831 .83051 m .66831 .84903 L .64085 .84464 L p .707 .577 .707 r
F P
0 g
s
.64085 .84464 m .64085 .82611 L .66831 .83051 L p .707 .577 .707 r
F P
0 g
s
.64393 .26809 m .64393 .76998 L .63984 .75792 L p .707 .577 .707 r
F P
0 g
s
.63984 .75792 m .63984 .25603 L .64393 .26809 L p .707 .577 .707 r
F P
0 g
s
.15794 .65558 m .15794 .6 L .16503 .59163 L p .707 .577 .707 r
F P
0 g
s
.17343 .84789 m .17343 .82936 L .16084 .82148 L p .707 .577 .707 r
F P
0 g
s
.16084 .75773 m .16084 .72068 L .15794 .71213 L p .707 .577 .707 r
F P
0 g
s
.54846 .8469 m .54846 .82837 L .57784 .82499 L p .707 .577 .707 r
F P
0 g
s
.16084 .82148 m .16084 .84001 L .17343 .84789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.57784 .82499 m .57784 .84352 L .54846 .8469 L p .707 .577 .707 r
F P
0 g
s
.15794 .71213 m .15794 .74919 L .16084 .75773 L p .707 .577 .707 r
F P
0 g
s
.64085 .82611 m .64085 .84464 L .60968 .84274 L p .707 .577 .707 r
F P
0 g
s
.60968 .84274 m .60968 .82421 L .64085 .82611 L p .707 .577 .707 r
F P
0 g
s
.16503 .59163 m .16503 .64722 L .15794 .65558 L p .707 .577 .707 r
F P
0 g
s
.35894 .70723 m .35894 .74428 L .34635 .7364 L p .707 .577 .707 r
F P
0 g
s
.34635 .7364 m .34635 .69934 L .35894 .70723 L p .707 .577 .707 r
F P
0 g
s
.35607 .26296 m .35607 .76485 L .36016 .77691 L p .707 .577 .707 r
F P
0 g
s
.35607 .76485 m .35607 .26296 L .36607 .25115 L p .707 .577 .707 r
F P
0 g
s
.57784 .84352 m .57784 .82499 L .60968 .82421 L p .707 .577 .707 r
F P
0 g
s
.35476 .82494 m .35476 .84346 L .36184 .8351 L p .707 .577 .707 r
F P
0 g
s
.36184 .8351 m .36184 .81657 L .35476 .82494 L p .707 .577 .707 r
F P
0 g
s
.60968 .82421 m .60968 .84274 L .57784 .84352 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .84001 m .16084 .82148 L .15794 .81294 L p .707 .577 .707 r
F P
0 g
s
.16503 .64722 m .16503 .59163 L .1814 .58427 L p .707 .577 .707 r
F P
0 g
s
.15794 .74919 m .15794 .71213 L .16503 .70377 L p .707 .577 .707 r
F P
0 g
s
.15794 .81294 m .15794 .83146 L .16084 .84001 L p .707 .577 .707 r
F P
0 g
s
.63984 .25603 m .63984 .75792 L .62206 .74679 L p .707 .577 .707 r
F P
0 g
s
.62206 .74679 m .62206 .2449 L .63984 .25603 L p .707 .577 .707 r
F P
0 g
s
.16503 .70377 m .16503 .74082 L .15794 .74919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58427 m .1814 .63985 L .16503 .64722 L p .707 .577 .707 r
F P
0 g
s
.34635 .58721 m .34635 .64279 L .3253 .63634 L p .707 .577 .707 r
F P
0 g
s
.3253 .63634 m .3253 .58075 L .34635 .58721 L p .707 .577 .707 r
F P
0 g
s
.36184 .81657 m .36184 .8351 L .35894 .82656 L p .707 .577 .707 r
F P
0 g
s
.35894 .82656 m .35894 .80803 L .36184 .81657 L p .707 .577 .707 r
F P
0 g
s
.1814 .63985 m .1814 .58427 L .20545 .57862 L p .707 .577 .707 r
F P
0 g
s
.36607 .75304 m .36607 .25115 L .38918 .24075 L p .707 .577 .707 r
F P
0 g
s
.36607 .25115 m .36607 .75304 L .35607 .76485 L p .707 .577 .707 r
F P
0 g
s
.15794 .83146 m .15794 .81294 L .16503 .80457 L p .707 .577 .707 r
F P
0 g
s
.16503 .74082 m .16503 .70377 L .1814 .6964 L p .707 .577 .707 r
F P
0 g
s
.16503 .80457 m .16503 .8231 L .15794 .83146 L p .707 .577 .707 r
F P
0 g
s
.3253 .58075 m .3253 .63634 L .29784 .63194 L p .707 .577 .707 r
F P
0 g
s
.29784 .63194 m .29784 .57636 L .3253 .58075 L p .707 .577 .707 r
F P
0 g
s
.1814 .6964 m .1814 .73346 L .16503 .74082 L p .707 .577 .707 r
F P
0 g
s
.20545 .57862 m .20545 .6342 L .1814 .63985 L p .707 .577 .707 r
F P
0 g
s
.20545 .6342 m .20545 .57862 L .23483 .57524 L p .707 .577 .707 r
F P
0 g
s
.35894 .80803 m .35894 .82656 L .34635 .81867 L p .707 .577 .707 r
F P
0 g
s
.34635 .81867 m .34635 .80015 L .35894 .80803 L p .707 .577 .707 r
F P
0 g
s
.34635 .69934 m .34635 .7364 L .3253 .72994 L p .707 .577 .707 r
F P
0 g
s
.3253 .72994 m .3253 .69289 L .34635 .69934 L p .707 .577 .707 r
F P
0 g
s
.62206 .2449 m .62206 .74679 L .59233 .73768 L p .707 .577 .707 r
F P
0 g
s
.59233 .73768 m .59233 .23579 L .62206 .2449 L p .707 .577 .707 r
F P
0 g
s
.29784 .57636 m .29784 .63194 L .26667 .63004 L p .707 .577 .707 r
F P
0 g
s
.26667 .63004 m .26667 .57446 L .29784 .57636 L p .707 .577 .707 r
F P
0 g
s
.1814 .73346 m .1814 .6964 L .20545 .69075 L p .707 .577 .707 r
F P
0 g
s
.23483 .63082 m .23483 .57524 L .26667 .57446 L p .707 .577 .707 r
F P
0 g
s
.23483 .57524 m .23483 .63082 L .20545 .6342 L p .707 .577 .707 r
F P
0 g
s
.16503 .8231 m .16503 .80457 L .1814 .79721 L p .707 .577 .707 r
F P
0 g
s
.26667 .57446 m .26667 .63004 L .23483 .63082 L p .707 .577 .707 r
F P
0 g
s
.73333 .62953 m .73333 .57395 L .70216 .57205 L p .707 .577 .707 r
F P
0 g
s
.73333 .57395 m .73333 .62953 L .76517 .62875 L p .707 .577 .707 r
F P
0 g
s
.76517 .62875 m .76517 .57317 L .73333 .57395 L p .707 .577 .707 r
F P
0 g
s
.1814 .79721 m .1814 .81573 L .16503 .8231 L p .707 .577 .707 r
F P
0 g
s
.38918 .24075 m .38918 .74264 L .36607 .75304 L p .707 .577 .707 r
F P
0 g
s
.38918 .74264 m .38918 .24075 L .42314 .23277 L p .707 .577 .707 r
F P
0 g
s
.76517 .57317 m .76517 .62875 L .79455 .62537 L p .707 .577 .707 r
F P
0 g
s
.79455 .62537 m .79455 .56979 L .76517 .57317 L p .707 .577 .707 r
F P
0 g
s
.20545 .69075 m .20545 .72781 L .1814 .73346 L p .707 .577 .707 r
F P
0 g
s
.3253 .69289 m .3253 .72994 L .29784 .72555 L p .707 .577 .707 r
F P
0 g
s
.29784 .72555 m .29784 .6885 L .3253 .69289 L p .707 .577 .707 r
F P
0 g
s
.70216 .62763 m .70216 .57205 L .6747 .56766 L p .707 .577 .707 r
F P
0 g
s
.70216 .57205 m .70216 .62763 L .73333 .62953 L p .707 .577 .707 r
F P
0 g
s
.34635 .80015 m .34635 .81867 L .3253 .81222 L p .707 .577 .707 r
F P
0 g
s
.3253 .81222 m .3253 .79369 L .34635 .80015 L p .707 .577 .707 r
F P
0 g
s
.20545 .72781 m .20545 .69075 L .23483 .68737 L p .707 .577 .707 r
F P
0 g
s
.79455 .56979 m .79455 .62537 L .8186 .61972 L p .707 .577 .707 r
F P
0 g
s
.8186 .61972 m .8186 .56414 L .79455 .56979 L p .707 .577 .707 r
F P
0 g
s
.59233 .23579 m .59233 .73768 L .55357 .73148 L p .707 .577 .707 r
F P
0 g
s
.55357 .73148 m .55357 .22959 L .59233 .23579 L p .707 .577 .707 r
F P
0 g
s
.1814 .81573 m .1814 .79721 L .20545 .79156 L p .707 .577 .707 r
F P
0 g
s
.6747 .56766 m .6747 .62324 L .70216 .62763 L p .707 .577 .707 r
F P
0 g
s
.29784 .6885 m .29784 .72555 L .26667 .72365 L p .707 .577 .707 r
F P
0 g
s
.26667 .72365 m .26667 .68659 L .29784 .6885 L p .707 .577 .707 r
F P
0 g
s
.6747 .62324 m .6747 .56766 L .65365 .5612 L p .707 .577 .707 r
F P
0 g
s
.23483 .68737 m .23483 .72443 L .20545 .72781 L p .707 .577 .707 r
F P
0 g
s
.23483 .72443 m .23483 .68737 L .26667 .68659 L p .707 .577 .707 r
F P
0 g
s
.20545 .79156 m .20545 .81008 L .1814 .81573 L p .707 .577 .707 r
F P
0 g
s
.26667 .68659 m .26667 .72365 L .23483 .72443 L p .707 .577 .707 r
F P
0 g
s
.42314 .73466 m .42314 .23277 L .46462 .228 L p .707 .577 .707 r
F P
0 g
s
.42314 .23277 m .42314 .73466 L .38918 .74264 L p .707 .577 .707 r
F P
0 g
s
.73333 .72314 m .73333 .68608 L .70216 .68418 L p .707 .577 .707 r
F P
0 g
s
.73333 .68608 m .73333 .72314 L .76517 .72236 L p .707 .577 .707 r
F P
0 g
s
.76517 .72236 m .76517 .68531 L .73333 .68608 L p .707 .577 .707 r
F P
0 g
s
.76517 .68531 m .76517 .72236 L .79455 .71898 L p .707 .577 .707 r
F P
0 g
s
.79455 .71898 m .79455 .68193 L .76517 .68531 L p .707 .577 .707 r
F P
0 g
s
.3253 .79369 m .3253 .81222 L .29784 .80783 L p .707 .577 .707 r
F P
0 g
s
.29784 .80783 m .29784 .7893 L .3253 .79369 L p .707 .577 .707 r
F P
0 g
s
.8186 .56414 m .8186 .61972 L .83497 .61236 L p .707 .577 .707 r
F P
0 g
s
.83497 .61236 m .83497 .55677 L .8186 .56414 L p .707 .577 .707 r
F P
0 g
s
.70216 .72124 m .70216 .68418 L .6747 .67979 L p .707 .577 .707 r
F P
0 g
s
.70216 .68418 m .70216 .72124 L .73333 .72314 L p .707 .577 .707 r
F P
0 g
s
.65365 .5612 m .65365 .61678 L .6747 .62324 L p .707 .577 .707 r
F P
0 g
s
.55357 .22959 m .55357 .73148 L .50956 .72879 L p .707 .577 .707 r
F P
0 g
s
.50956 .72879 m .50956 .22691 L .55357 .22959 L p .707 .577 .707 r
F P
0 g
s
.20545 .81008 m .20545 .79156 L .23483 .78818 L p .707 .577 .707 r
F P
0 g
s
.65365 .61678 m .65365 .5612 L .64105 .55332 L p .707 .577 .707 r
F P
0 g
s
.79455 .68193 m .79455 .71898 L .8186 .71333 L p .707 .577 .707 r
F P
0 g
s
.8186 .71333 m .8186 .67628 L .79455 .68193 L p .707 .577 .707 r
F P
0 g
s
.23483 .78818 m .23483 .8067 L .20545 .81008 L p .707 .577 .707 r
F P
0 g
s
.46462 .72989 m .46462 .228 L .50956 .22691 L p .707 .577 .707 r
F P
0 g
s
.46462 .228 m .46462 .72989 L .42314 .73466 L p .707 .577 .707 r
F P
0 g
s
.6747 .67979 m .6747 .71684 L .70216 .72124 L p .707 .577 .707 r
F P
0 g
s
.29784 .7893 m .29784 .80783 L .26667 .80593 L p .707 .577 .707 r
F P
0 g
s
.26667 .80593 m .26667 .7874 L .29784 .7893 L p .707 .577 .707 r
F P
0 g
s
.50956 .22691 m .50956 .72879 L .46462 .72989 L p .707 .577 .707 r
F P
0 g
s
.6747 .71684 m .6747 .67979 L .65365 .67334 L p .707 .577 .707 r
F P
0 g
s
.23483 .8067 m .23483 .78818 L .26667 .7874 L p .707 .577 .707 r
F P
0 g
s
.26667 .7874 m .26667 .80593 L .23483 .8067 L p .707 .577 .707 r
F P
0 g
s
.73333 .80541 m .73333 .78689 L .70216 .78499 L p .707 .577 .707 r
F P
0 g
s
.73333 .78689 m .73333 .80541 L .76517 .80464 L p .707 .577 .707 r
F P
0 g
s
.76517 .80464 m .76517 .78611 L .73333 .78689 L p .707 .577 .707 r
F P
0 g
s
.64105 .55332 m .64105 .6089 L .65365 .61678 L p .707 .577 .707 r
F P
0 g
s
.83497 .55677 m .83497 .61236 L .84205 .60399 L p .707 .577 .707 r
F P
0 g
s
.84205 .60399 m .84205 .54841 L .83497 .55677 L p .707 .577 .707 r
F P
0 g
s
.76517 .78611 m .76517 .80464 L .79455 .80126 L p .707 .577 .707 r
F P
0 g
s
.79455 .80126 m .79455 .78273 L .76517 .78611 L p .707 .577 .707 r
F P
0 g
s
.65365 .67334 m .65365 .71039 L .6747 .71684 L p .707 .577 .707 r
F P
0 g
s
.70216 .78499 m .70216 .80351 L .73333 .80541 L p .707 .577 .707 r
F P
0 g
s
.70216 .80351 m .70216 .78499 L .6747 .78059 L p .707 .577 .707 r
F P
0 g
s
.8186 .67628 m .8186 .71333 L .83497 .70596 L p .707 .577 .707 r
F P
0 g
s
.83497 .70596 m .83497 .66891 L .8186 .67628 L p .707 .577 .707 r
F P
0 g
s
.6747 .78059 m .6747 .79912 L .70216 .80351 L p .707 .577 .707 r
F P
0 g
s
.64105 .6089 m .64105 .55332 L .63816 .54477 L p .707 .577 .707 r
F P
0 g
s
.79455 .78273 m .79455 .80126 L .8186 .79561 L p .707 .577 .707 r
F P
0 g
s
.8186 .79561 m .8186 .77708 L .79455 .78273 L p .707 .577 .707 r
F P
0 g
s
.65365 .71039 m .65365 .67334 L .64105 .66545 L p .707 .577 .707 r
F P
0 g
s
.6747 .79912 m .6747 .78059 L .65365 .77414 L p .707 .577 .707 r
F P
0 g
s
.65365 .77414 m .65365 .79267 L .6747 .79912 L p .707 .577 .707 r
F P
0 g
s
.64105 .66545 m .64105 .70251 L .65365 .71039 L p .707 .577 .707 r
F P
0 g
s
.63816 .54477 m .63816 .60036 L .64105 .6089 L p .707 .577 .707 r
F P
0 g
s
.84205 .54841 m .84205 .60399 L .83916 .59545 L p .707 .577 .707 r
F P
0 g
s
.83916 .59545 m .83916 .53987 L .84205 .54841 L p .707 .577 .707 r
F P
0 g
s
.83497 .66891 m .83497 .70596 L .84206 .6976 L p .707 .577 .707 r
F P
0 g
s
.84206 .6976 m .84205 .66054 L .83497 .66891 L p .707 .577 .707 r
F P
0 g
s
.8186 .77708 m .8186 .79561 L .83497 .78824 L p .707 .577 .707 r
F P
0 g
s
.83497 .78824 m .83497 .76971 L .8186 .77708 L p .707 .577 .707 r
F P
0 g
s
.63816 .60036 m .63816 .54477 L .64524 .53641 L p .707 .577 .707 r
F P
0 g
s
.65365 .79267 m .65365 .77414 L .64105 .76626 L p .707 .577 .707 r
F P
0 g
s
.64105 .70251 m .64105 .66545 L .63816 .65691 L p .707 .577 .707 r
F P
0 g
s
.64105 .76626 m .64105 .78478 L .65365 .79267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .65691 m .63816 .69396 L .64105 .70251 L p .707 .577 .707 r
F P
0 g
s
.64524 .53641 m .64524 .59199 L .63816 .60036 L p .707 .577 .707 r
F P
0 g
s
.83497 .76971 m .83497 .78824 L .84206 .77988 L p .707 .577 .707 r
F P
0 g
s
.84206 .77988 m .84206 .76135 L .83497 .76971 L p .707 .577 .707 r
F P
0 g
s
.83916 .53987 m .83916 .59545 L .82657 .58757 L p .707 .577 .707 r
F P
0 g
s
.82657 .58757 m .82657 .53198 L .83916 .53987 L p .707 .577 .707 r
F P
0 g
s
.84205 .66054 m .84206 .6976 L .83916 .68906 L p .707 .577 .707 r
F P
0 g
s
.83916 .68906 m .83916 .652 L .84205 .66054 L p .707 .577 .707 r
F P
0 g
s
.39032 .59271 m .39032 .53713 L .35915 .53523 L p .707 .577 .707 r
F P
0 g
s
.39032 .53713 m .39032 .59271 L .42216 .59194 L p .707 .577 .707 r
F P
0 g
s
.42216 .59194 m .42216 .53636 L .39032 .53713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64105 .78478 m .64105 .76626 L .63816 .75771 L p .707 .577 .707 r
F P
0 g
s
.64524 .59199 m .64524 .53641 L .66161 .52904 L p .707 .577 .707 r
F P
0 g
s
.42216 .53636 m .42216 .59194 L .45154 .58856 L p .707 .577 .707 r
F P
0 g
s
.45154 .58856 m .45154 .53298 L .42216 .53636 L p .707 .577 .707 r
F P
0 g
s
.63816 .69396 m .63816 .65691 L .64524 .64855 L p .707 .577 .707 r
F P
0 g
s
.63816 .75771 m .63816 .77624 L .64105 .78478 L p .707 .577 .707 r
F P
0 g
s
.35915 .59081 m .35915 .53523 L .33169 .53084 L p .707 .577 .707 r
F P
0 g
s
.35915 .53523 m .35915 .59081 L .39032 .59271 L p .707 .577 .707 r
F P
0 g
s
.64524 .64855 m .64524 .6856 L .63816 .69396 L p .707 .577 .707 r
F P
0 g
s
.45154 .53298 m .45154 .58856 L .47559 .58291 L p .707 .577 .707 r
F P
0 g
s
.47559 .58291 m .47559 .52733 L .45154 .53298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52904 m .66161 .58462 L .64524 .59199 L p .707 .577 .707 r
F P
0 g
s
.82657 .53198 m .82657 .58757 L .80551 .58111 L p .707 .577 .707 r
F P
0 g
s
.80551 .58111 m .80551 .52553 L .82657 .53198 L p .707 .577 .707 r
F P
0 g
s
.84206 .76135 m .84206 .77988 L .83916 .77133 L p .707 .577 .707 r
F P
0 g
s
.83916 .77133 m .83916 .75281 L .84206 .76135 L p .707 .577 .707 r
F P
0 g
s
.83916 .652 m .83916 .68906 L .82657 .68117 L p .707 .577 .707 r
F P
0 g
s
.82657 .68117 m .82657 .64412 L .83916 .652 L p .707 .577 .707 r
F P
0 g
s
.33169 .53084 m .33169 .58642 L .35915 .59081 L p .707 .577 .707 r
F P
0 g
s
.33169 .58642 m .33169 .53084 L .31064 .52439 L p .707 .577 .707 r
F P
0 g
s
.66161 .58462 m .66161 .52904 L .68566 .52339 L p .707 .577 .707 r
F P
0 g
s
.39032 .68632 m .39032 .64927 L .35915 .64737 L p .707 .577 .707 r
F P
0 g
s
.39032 .64927 m .39032 .68632 L .42216 .68555 L p .707 .577 .707 r
F P
0 g
s
.42216 .68555 m .42216 .64849 L .39032 .64927 L p .707 .577 .707 r
F P
0 g
s
.63816 .77624 m .63816 .75771 L .64524 .74935 L p .707 .577 .707 r
F P
0 g
s
.64524 .6856 m .64524 .64855 L .66161 .64118 L p .707 .577 .707 r
F P
0 g
s
.42216 .64849 m .42216 .68555 L .45154 .68217 L p .707 .577 .707 r
F P
0 g
s
.45154 .68217 m .45154 .64511 L .42216 .64849 L p .707 .577 .707 r
F P
0 g
s
.47559 .52733 m .47559 .58291 L .49196 .57554 L p .707 .577 .707 r
F P
0 g
s
.49196 .57554 m .49196 .51996 L .47559 .52733 L p .707 .577 .707 r
F P
0 g
s
.64524 .74935 m .64524 .76788 L .63816 .77624 L p .707 .577 .707 r
F P
0 g
s
.35915 .68442 m .35915 .64737 L .33169 .64297 L p .707 .577 .707 r
F P
0 g
s
.35915 .64737 m .35915 .68442 L .39032 .68632 L p .707 .577 .707 r
F P
0 g
s
.31064 .52439 m .31064 .57997 L .33169 .58642 L p .707 .577 .707 r
F P
0 g
s
.80551 .52553 m .80551 .58111 L .77805 .57672 L p .707 .577 .707 r
F P
0 g
s
.77805 .57672 m .77805 .52114 L .80551 .52553 L p .707 .577 .707 r
F P
0 g
s
.66161 .64118 m .66161 .67823 L .64524 .6856 L p .707 .577 .707 r
F P
0 g
s
.68566 .52339 m .68566 .57897 L .66161 .58462 L p .707 .577 .707 r
F P
0 g
s
.31064 .57997 m .31064 .52439 L .29804 .5165 L p .707 .577 .707 r
F P
0 g
s
.45154 .64511 m .45154 .68217 L .47559 .67652 L p .707 .577 .707 r
F P
0 g
s
.47559 .67652 m .47559 .63946 L .45154 .64511 L p .707 .577 .707 r
F P
0 g
s
.33169 .64297 m .33169 .68003 L .35915 .68442 L p .707 .577 .707 r
F P
0 g
s
.68566 .57897 m .68566 .52339 L .71504 .52001 L p .707 .577 .707 r
F P
0 g
s
.83916 .75281 m .83916 .77133 L .82657 .76345 L p .707 .577 .707 r
F P
0 g
s
.82657 .76345 m .82657 .74492 L .83916 .75281 L p .707 .577 .707 r
F P
0 g
s
.82657 .64412 m .82657 .68117 L .80551 .67472 L p .707 .577 .707 r
F P
0 g
s
.80551 .67472 m .80551 .63766 L .82657 .64412 L p .707 .577 .707 r
F P
0 g
s
.33169 .68003 m .33169 .64297 L .31064 .63652 L p .707 .577 .707 r
F P
0 g
s
.77805 .52114 m .77805 .57672 L .74688 .57482 L p .707 .577 .707 r
F P
0 g
s
.74688 .57482 m .74688 .51924 L .77805 .52114 L p .707 .577 .707 r
F P
0 g
s
.39032 .7686 m .39032 .75007 L .35915 .74817 L p .707 .577 .707 r
F P
0 g
s
.39032 .75007 m .39032 .7686 L .42216 .76782 L p .707 .577 .707 r
F P
0 g
s
.42216 .76782 m .42216 .74929 L .39032 .75007 L p .707 .577 .707 r
F P
0 g
s
.66161 .67823 m .66161 .64118 L .68566 .63553 L p .707 .577 .707 r
F P
0 g
s
.29804 .5165 m .29804 .57208 L .31064 .57997 L p .707 .577 .707 r
F P
0 g
s
.71504 .5756 m .71504 .52001 L .74688 .51924 L p .707 .577 .707 r
F P
0 g
s
.71504 .52001 m .71504 .5756 L .68566 .57897 L p .707 .577 .707 r
F P
0 g
s
.49196 .51996 m .49196 .57554 L .49904 .56718 L p .707 .577 .707 r
F P
0 g
s
.49904 .56718 m .49904 .51159 L .49196 .51996 L p .707 .577 .707 r
F P
0 g
s
.64524 .76788 m .64524 .74935 L .66161 .74198 L p .707 .577 .707 r
F P
0 g
s
.42216 .74929 m .42216 .76782 L .45154 .76444 L p .707 .577 .707 r
F P
0 g
s
.45154 .76444 m .45154 .74592 L .42216 .74929 L p .707 .577 .707 r
F P
0 g
s
.31064 .63652 m .31064 .67358 L .33169 .68003 L p .707 .577 .707 r
F P
0 g
s
.74688 .51924 m .74688 .57482 L .71504 .5756 L p .707 .577 .707 r
F P
0 g
s
.35915 .74817 m .35915 .7667 L .39032 .7686 L p .707 .577 .707 r
F P
0 g
s
.35915 .7667 m .35915 .74817 L .33169 .74378 L p .707 .577 .707 r
F P
0 g
s
.47559 .63946 m .47559 .67652 L .49196 .66915 L p .707 .577 .707 r
F P
0 g
s
.49196 .66915 m .49196 .63209 L .47559 .63946 L p .707 .577 .707 r
F P
0 g
s
.66161 .74198 m .66161 .76051 L .64524 .76788 L p .707 .577 .707 r
F P
0 g
s
.68566 .63553 m .68566 .67258 L .66161 .67823 L p .707 .577 .707 r
F P
0 g
s
.33169 .74378 m .33169 .76231 L .35915 .7667 L p .707 .577 .707 r
F P
0 g
s
.80551 .63766 m .80551 .67472 L .77805 .67033 L p .707 .577 .707 r
F P
0 g
s
.77805 .67033 m .77805 .63327 L .80551 .63766 L p .707 .577 .707 r
F P
0 g
s
.29804 .57208 m .29804 .5165 L .29515 .50796 L p .707 .577 .707 r
F P
0 g
s
.45154 .74592 m .45154 .76444 L .47559 .75879 L p .707 .577 .707 r
F P
0 g
s
.47559 .75879 m .47559 .74027 L .45154 .74592 L p .707 .577 .707 r
F P
0 g
s
.31064 .67358 m .31064 .63652 L .29804 .62864 L p .707 .577 .707 r
F P
0 g
s
.82657 .74492 m .82657 .76345 L .80551 .757 L p .707 .577 .707 r
F P
0 g
s
.80551 .757 m .80551 .73847 L .82657 .74492 L p .707 .577 .707 r
F P
0 g
s
.68566 .67258 m .68566 .63553 L .71504 .63215 L p .707 .577 .707 r
F P
0 g
s
.33169 .76231 m .33169 .74378 L .31064 .73733 L p .707 .577 .707 r
F P
0 g
s
.31064 .73733 m .31064 .75585 L .33169 .76231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62864 m .29804 .66569 L .31064 .67358 L p .707 .577 .707 r
F P
0 g
s
.66161 .76051 m .66161 .74198 L .68566 .73633 L p .707 .577 .707 r
F P
0 g
s
.77805 .63327 m .77805 .67033 L .74688 .66843 L p .707 .577 .707 r
F P
0 g
s
.74688 .66843 m .74688 .63137 L .77805 .63327 L p .707 .577 .707 r
F P
0 g
s
.29515 .50796 m .29515 .56354 L .29804 .57208 L p .707 .577 .707 r
F P
0 g
s
.71504 .63215 m .71504 .6692 L .68566 .67258 L p .707 .577 .707 r
F P
0 g
s
.49904 .51159 m .49904 .56718 L .49615 .55863 L p .707 .577 .707 r
F P
0 g
s
.49615 .55863 m .49615 .50305 L .49904 .51159 L p .707 .577 .707 r
F P
0 g
s
.71504 .6692 m .71504 .63215 L .74688 .63137 L p .707 .577 .707 r
F P
0 g
s
.49196 .63209 m .49196 .66915 L .49904 .66078 L p .707 .577 .707 r
F P
0 g
s
.49904 .66078 m .49904 .62373 L .49196 .63209 L p .707 .577 .707 r
F P
0 g
s
.68566 .73633 m .68566 .75486 L .66161 .76051 L p .707 .577 .707 r
F P
0 g
s
.47559 .74027 m .47559 .75879 L .49196 .75143 L p .707 .577 .707 r
F P
0 g
s
.49196 .75143 m .49196 .7329 L .47559 .74027 L p .707 .577 .707 r
F P
0 g
s
.74688 .63137 m .74688 .66843 L .71504 .6692 L p .707 .577 .707 r
F P
0 g
s
.80551 .73847 m .80551 .757 L .77805 .7526 L p .707 .577 .707 r
F P
0 g
s
.77805 .7526 m .77805 .73408 L .80551 .73847 L p .707 .577 .707 r
F P
0 g
s
.29515 .56354 m .29515 .50796 L .30223 .49959 L p .707 .577 .707 r
F P
0 g
s
.31064 .75585 m .31064 .73733 L .29804 .72944 L p .707 .577 .707 r
F P
0 g
s
.29804 .66569 m .29804 .62864 L .29515 .62009 L p .707 .577 .707 r
F P
0 g
s
.68566 .75486 m .68566 .73633 L .71504 .73295 L p .707 .577 .707 r
F P
0 g
s
.29804 .72944 m .29804 .74797 L .31064 .75585 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71504 .73295 m .71504 .75148 L .68566 .75486 L p .707 .577 .707 r
F P
0 g
s
.29515 .62009 m .29515 .65715 L .29804 .66569 L p .707 .577 .707 r
F P
0 g
s
.77805 .73408 m .77805 .7526 L .74688 .7507 L p .707 .577 .707 r
F P
0 g
s
.74688 .7507 m .74688 .73218 L .77805 .73408 L p .707 .577 .707 r
F P
0 g
s
.30223 .49959 m .30223 .55518 L .29515 .56354 L p .707 .577 .707 r
F P
0 g
s
.71504 .75148 m .71504 .73295 L .74688 .73218 L p .707 .577 .707 r
F P
0 g
s
.49196 .7329 m .49196 .75143 L .49904 .74306 L p .707 .577 .707 r
F P
0 g
s
.49904 .74306 m .49904 .72453 L .49196 .7329 L p .707 .577 .707 r
F P
0 g
s
.49615 .50305 m .49615 .55863 L .48356 .55075 L p .707 .577 .707 r
F P
0 g
s
.48356 .55075 m .48356 .49517 L .49615 .50305 L p .707 .577 .707 r
F P
0 g
s
.49904 .62373 m .49904 .66078 L .49615 .65224 L p .707 .577 .707 r
F P
0 g
s
.49615 .65224 m .49615 .61519 L .49904 .62373 L p .707 .577 .707 r
F P
0 g
s
.74688 .73218 m .74688 .7507 L .71504 .75148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29804 .74797 m .29804 .72944 L .29515 .7209 L p .707 .577 .707 r
F P
0 g
s
.30223 .55518 m .30223 .49959 L .3186 .49223 L p .707 .577 .707 r
F P
0 g
s
.29515 .65715 m .29515 .62009 L .30223 .61173 L p .707 .577 .707 r
F P
0 g
s
.29515 .7209 m .29515 .73943 L .29804 .74797 L p .707 .577 .707 r
F P
0 g
s
.30223 .61173 m .30223 .64878 L .29515 .65715 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49223 m .3186 .54781 L .30223 .55518 L p .707 .577 .707 r
F P
0 g
s
.48356 .49517 m .48356 .55075 L .4625 .5443 L p .707 .577 .707 r
F P
0 g
s
.4625 .5443 m .4625 .48871 L .48356 .49517 L p .707 .577 .707 r
F P
0 g
s
.49904 .72453 m .49904 .74306 L .49615 .73452 L p .707 .577 .707 r
F P
0 g
s
.49615 .73452 m .49615 .71599 L .49904 .72453 L p .707 .577 .707 r
F P
0 g
s
.49615 .61519 m .49615 .65224 L .48356 .64436 L p .707 .577 .707 r
F P
0 g
s
.48356 .64436 m .48356 .6073 L .49615 .61519 L p .707 .577 .707 r
F P
0 g
s
.3186 .54781 m .3186 .49223 L .34265 .48658 L p .707 .577 .707 r
F P
0 g
s
.29515 .73943 m .29515 .7209 L .30223 .71253 L p .707 .577 .707 r
F P
0 g
s
.30223 .64878 m .30223 .61173 L .3186 .60436 L p .707 .577 .707 r
F P
0 g
s
.30223 .71253 m .30223 .73106 L .29515 .73943 L p .707 .577 .707 r
F P
0 g
s
.4625 .48871 m .4625 .5443 L .43504 .5399 L p .707 .577 .707 r
F P
0 g
s
.43504 .5399 m .43504 .48432 L .4625 .48871 L p .707 .577 .707 r
F P
0 g
s
.3186 .60436 m .3186 .64142 L .30223 .64878 L p .707 .577 .707 r
F P
0 g
s
.34265 .48658 m .34265 .54216 L .3186 .54781 L p .707 .577 .707 r
F P
0 g
s
.34265 .54216 m .34265 .48658 L .37203 .4832 L p .707 .577 .707 r
F P
0 g
s
.49615 .71599 m .49615 .73452 L .48356 .72664 L p .707 .577 .707 r
F P
0 g
s
.48356 .72664 m .48356 .70811 L .49615 .71599 L p .707 .577 .707 r
F P
0 g
s
.48356 .6073 m .48356 .64436 L .4625 .6379 L p .707 .577 .707 r
F P
0 g
s
.4625 .6379 m .4625 .60085 L .48356 .6073 L p .707 .577 .707 r
F P
0 g
s
.43504 .48432 m .43504 .5399 L .40387 .538 L p .707 .577 .707 r
F P
0 g
s
.40387 .538 m .40387 .48242 L .43504 .48432 L p .707 .577 .707 r
F P
0 g
s
.3186 .64142 m .3186 .60436 L .34265 .59871 L p .707 .577 .707 r
F P
0 g
s
.37203 .53878 m .37203 .4832 L .40387 .48242 L p .707 .577 .707 r
F P
0 g
s
.37203 .4832 m .37203 .53878 L .34265 .54216 L p .707 .577 .707 r
F P
0 g
s
.30223 .73106 m .30223 .71253 L .3186 .70517 L p .707 .577 .707 r
F P
0 g
s
.40387 .48242 m .40387 .538 L .37203 .53878 L p .707 .577 .707 r
F P
0 g
s
.3186 .70517 m .3186 .72369 L .30223 .73106 L p .707 .577 .707 r
F P
0 g
s
.34265 .59871 m .34265 .63577 L .3186 .64142 L p .707 .577 .707 r
F P
0 g
s
.4625 .60085 m .4625 .6379 L .43504 .63351 L p .707 .577 .707 r
F P
0 g
s
.43504 .63351 m .43504 .59646 L .4625 .60085 L p .707 .577 .707 r
F P
0 g
s
.48356 .70811 m .48356 .72664 L .4625 .72018 L p .707 .577 .707 r
F P
0 g
s
.4625 .72018 m .4625 .70165 L .48356 .70811 L p .707 .577 .707 r
F P
0 g
s
.34265 .63577 m .34265 .59871 L .37203 .59533 L p .707 .577 .707 r
F P
0 g
s
.3186 .72369 m .3186 .70517 L .34265 .69952 L p .707 .577 .707 r
F P
0 g
s
.43504 .59646 m .43504 .63351 L .40387 .63161 L p .707 .577 .707 r
F P
0 g
s
.40387 .63161 m .40387 .59456 L .43504 .59646 L p .707 .577 .707 r
F P
0 g
s
.37203 .59533 m .37203 .63239 L .34265 .63577 L p .707 .577 .707 r
F P
0 g
s
.37203 .63239 m .37203 .59533 L .40387 .59456 L p .707 .577 .707 r
F P
0 g
s
.34265 .69952 m .34265 .71804 L .3186 .72369 L p .707 .577 .707 r
F P
0 g
s
.40387 .59456 m .40387 .63161 L .37203 .63239 L p .707 .577 .707 r
F P
0 g
s
.4625 .70165 m .4625 .72018 L .43504 .71579 L p .707 .577 .707 r
F P
0 g
s
.43504 .71579 m .43504 .69726 L .4625 .70165 L p .707 .577 .707 r
F P
0 g
s
.34265 .71804 m .34265 .69952 L .37203 .69614 L p .707 .577 .707 r
F P
0 g
s
.37203 .69614 m .37203 .71467 L .34265 .71804 L p .707 .577 .707 r
F P
0 g
s
.43504 .69726 m .43504 .71579 L .40387 .71389 L p .707 .577 .707 r
F P
0 g
s
.40387 .71389 m .40387 .69536 L .43504 .69726 L p .707 .577 .707 r
F P
0 g
s
.37203 .71467 m .37203 .69614 L .40387 .69536 L p .707 .577 .707 r
F P
0 g
s
.40387 .69536 m .40387 .71389 L .37203 .71467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF
00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo
001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006EooaP0
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00003goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00=JEPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001JEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003mooaP00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000iOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF
1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YF
FUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP80
02eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
00=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0J0005FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000L000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP02FUH9000oOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQD00003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP0C0014Ool002aoo`03001JEP0000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`03001JEP0000AJEPD000MJEP03001JEUYF
00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH0000400001EYF001JEUYF00000UYF
00<005YFFUH00eYF1@001EYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03001JEP00
009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00003
FUH:0002FUH01000FUIJEP001EYF10001UYF00<005YFFUH01eYF1P0000=JEP00FUH00UYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
03Aoo`00;7oo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00H005YF001JEP00FUH20005FUH00`00FUH0000300001EYF001JEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@001EYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH2
00000eYF001JEP04FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEUYFFUH90007Ool5000<Ool50004FUH01000FUIJEUYF0P00;Goo000dOol50006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1`0000=JEP00FUH00UYF
0P001goo1@0047oo100000=JEP00FUH00UYF0P00;Goo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50002Ool50004FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02
FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF1P000eYF0P0027oo0`002Woo1`000eYF0`000eYF0P00;Goo000mOolI000<Ool8
0004FUH500000eYF000000070007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000oOolG000?Ool01@00FUIJEP00FUH0
2P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000iOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000;Ool01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000eOol400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH50006OolB00000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0039oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000a
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP0000@0
00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040005Ool40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03
001JEP0000=JEPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00003Goo6@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHC0004
Ool400000eYF001JEP020003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000FOol50018Ool002aoo`03001JEP00
00AJEP03001JEP0000<000ioo`D000Moo`05001JEP00001oo`060004FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3@0000=JEP00000020001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@004Woo0`00BGoo000/Ool00`00
FUH00003FUH4000AOol50007Ool40006Ool400001EYF001JEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF200035YF0`002EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YF00000P001Goo6P00?7oo000/Ool01000FUH005YF0P0015YF1@003Goo0`0027oo0P00
0UYF1P000eYF0`000UYF00@005YFFUH000EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00QJEP<0
0003FUH005YF00UJEP03001JEUYF00QJEPL000IJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`06001J
EP00001JEP001EYF00@005YFFUIJEQX000=JEP03001JEP00008000=JEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEP0000<000YJEP03001JEUYF00EJEP<0009JEP03001JEP0000YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000AJEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000000=JEP03001JEUYF009JEPD0009JEP80009JEP03001JEUYF00=JEP8000=JEP03001JEUYF
00QJEP04001JEUYFFUH400000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00
FUIJEP03FUH01000FUIJEUYF20000UYF0P001EYF00<005YFFUH01eYF1@001EYF00@005YFFUIJEP80
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH000020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000aOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF
4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04
001JEUYFFUH20002FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50004FUH00`00FUIJEP02FUH8
000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF
00<005YF00000P000UYF00@005YFFUIJEP8001Qoo`D000AJEP05001JEUYFFUH0000^Ool002ioo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
00030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20000
0eYF001JEP02FUH30005FUH01000FUIJEUYF0P007Goo0`0000=JEP00FUH00UYF0P00;Goo000`Ool3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP0300000eYF
001JEP04FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000cOol300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002OolI00000eYF001J
EP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000003Ool40003FUH01000FUIJEUYF0P008Woo0P0000=JEP000000;Goo000fOol50004FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUH000030007Ool00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH300000eYF001oo`02Ool80003FUH2000QOol2000015YF00000000;Goo
000kOol80004FUH50005FUH00`00FUIJEP02FUH5000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30002FUH30005FUH01000FUIJEP000UYF0P007Woo0`000eYF0`00;Goo0013OolC
000AOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YFFUH01P000eYF10006Woo
100000=JEP00FUH00eYF00<005YF0000;Goo0017Ool5000LOol200000eYF001JEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH200001EYF001JEUYF00001EYF00<005YF00000`0000AJEP00000001Eoo`D000EJEP03001J
EUYF009JEP8002ioo`00Agoo2@006Woo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP04001JEUYF0005FUH0
0`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool003moo`P000AJEP03
001JEUYF009JEPP001=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001JEP0015YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000moo`@0009JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@0
00=JEP03001JEUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080011oo`D000QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000MJEP03001JEUYF00EJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<001Moo`T000IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP/000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P007Woo3@000Woo
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP@000Yoo`T004Qoo`00;Goo0P0015YF00@005YFFUIJEPP001Uoo`H000AJEP05001JEUYFFUH0000`
Ool50004FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH7001OOol002aoo`03001JEP0000AJ
EP@002Moo`<00003FUH005YF009JEP03001oogoo03=ooa/006Ioo`00;7oo00<005YF00000UYF0P00
;Woo0P000eYF00<007ooOol0@7oo1@00Kgoo000/Ool00`00FUH00002000bOol01000FUIJEP00@Woo
1@00Kgoo000/Ool01000FUH00000=7oo0`00>Goo6000IGoo000/Ool20002FUH3000_Ool300000eYF
001oo`0bOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001QOol002aoo`80
00=JEP03001JEP00008002Uoo`<0009JEP03001JEP00031oo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@005eoo`00;7oo0P000eYF00<005YFFUH00UYF1@00
87oo100000=JEP00FUH00UYF00<005YF0000;Goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000FGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000/Ool200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001HOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000[Ool20004FUH00`00
FUIJEP02FUH6000BOol80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000aOol30003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
000/Ool00`00FUH00004FUH00`00FUH00002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol5
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00
FUH00003FUH3000XOol300000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF009JEPD003=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eo
oaT003Qoo`04001JEP00000bOol200000eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P00
0UYF0P00;goo0P0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<0
05YF0000E7oo002?Ool01000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?
Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eo
o`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0
05Yoo`00Ugoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002L
Ool90004FUH00`00FUIJEP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77742 m .59613 .72184 L .56496 .71994 L p .707 .577 .707 r
F P
0 g
s
.59613 .72184 m .59613 .77742 L .62796 .77665 L p .707 .577 .707 r
F P
0 g
s
.62796 .77665 m .62796 .72106 L .59613 .72184 L p .707 .577 .707 r
F P
0 g
s
.62796 .72106 m .62796 .77665 L .65735 .77327 L p .707 .577 .707 r
F P
0 g
s
.65735 .77327 m .65734 .71768 L .62796 .72106 L p .707 .577 .707 r
F P
0 g
s
.56496 .77552 m .56496 .71994 L .5375 .71555 L p .707 .577 .707 r
F P
0 g
s
.56496 .71994 m .56496 .77552 L .59613 .77742 L p .707 .577 .707 r
F P
0 g
s
.59613 .80454 m .59613 .76749 L .56496 .76558 L p .707 .577 .707 r
F P
0 g
s
.59613 .76749 m .59613 .80454 L .62796 .80376 L p .707 .577 .707 r
F P
0 g
s
.62796 .80376 m .62796 .76671 L .59613 .76749 L p .707 .577 .707 r
F P
0 g
s
.65734 .71768 m .65735 .77327 L .6814 .76762 L p .707 .577 .707 r
F P
0 g
s
.6814 .76762 m .6814 .71203 L .65734 .71768 L p .707 .577 .707 r
F P
0 g
s
.62796 .76671 m .62796 .80376 L .65735 .80038 L p .707 .577 .707 r
F P
0 g
s
.65735 .80038 m .65735 .76333 L .62796 .76671 L p .707 .577 .707 r
F P
0 g
s
.59613 .80593 m .59613 .78741 L .56496 .7855 L p .707 .577 .707 r
F P
0 g
s
.59613 .78741 m .59613 .80593 L .62796 .80516 L p .707 .577 .707 r
F P
0 g
s
.62796 .80516 m .62796 .78663 L .59613 .78741 L p .707 .577 .707 r
F P
0 g
s
.56496 .80264 m .56496 .76558 L .5375 .76119 L p .707 .577 .707 r
F P
0 g
s
.56496 .76558 m .56496 .80264 L .59613 .80454 L p .707 .577 .707 r
F P
0 g
s
.62796 .78663 m .62796 .80516 L .65735 .80178 L p .707 .577 .707 r
F P
0 g
s
.65735 .80178 m .65735 .78325 L .62796 .78663 L p .707 .577 .707 r
F P
0 g
s
.5375 .71555 m .5375 .77113 L .56496 .77552 L p .707 .577 .707 r
F P
0 g
s
.5375 .77113 m .5375 .71555 L .51644 .70909 L p .707 .577 .707 r
F P
0 g
s
.56496 .7855 m .56496 .80403 L .59613 .80593 L p .707 .577 .707 r
F P
0 g
s
.56496 .80403 m .56496 .7855 L .5375 .78111 L p .707 .577 .707 r
F P
0 g
s
.65735 .76333 m .65735 .80038 L .6814 .79473 L p .707 .577 .707 r
F P
0 g
s
.6814 .79473 m .6814 .75768 L .65735 .76333 L p .707 .577 .707 r
F P
0 g
s
.5375 .76119 m .5375 .79825 L .56496 .80264 L p .707 .577 .707 r
F P
0 g
s
.5375 .78111 m .5375 .79964 L .56496 .80403 L p .707 .577 .707 r
F P
0 g
s
.65735 .78325 m .65735 .80178 L .6814 .79613 L p .707 .577 .707 r
F P
0 g
s
.6814 .79613 m .6814 .7776 L .65735 .78325 L p .707 .577 .707 r
F P
0 g
s
.6814 .71203 m .6814 .76762 L .69777 .76025 L p .707 .577 .707 r
F P
0 g
s
.69777 .76025 m .69777 .70467 L .6814 .71203 L p .707 .577 .707 r
F P
0 g
s
.5375 .79825 m .5375 .76119 L .51644 .75474 L p .707 .577 .707 r
F P
0 g
s
.51644 .70909 m .51644 .76468 L .5375 .77113 L p .707 .577 .707 r
F P
0 g
s
.5375 .79964 m .5375 .78111 L .51644 .77466 L p .707 .577 .707 r
F P
0 g
s
.51644 .75474 m .51644 .79179 L .5375 .79825 L p .707 .577 .707 r
F P
0 g
s
.51644 .76468 m .51644 .70909 L .50385 .70121 L p .707 .577 .707 r
F P
0 g
s
.51644 .77466 m .51644 .79319 L .5375 .79964 L p .707 .577 .707 r
F P
0 g
s
.6814 .75768 m .6814 .79473 L .69777 .78737 L p .707 .577 .707 r
F P
0 g
s
.69777 .78737 m .69777 .75031 L .6814 .75768 L p .707 .577 .707 r
F P
0 g
s
.6814 .7776 m .6814 .79613 L .69777 .78876 L p .707 .577 .707 r
F P
0 g
s
.69777 .78876 m .69777 .77023 L .6814 .7776 L p .707 .577 .707 r
F P
0 g
s
.51644 .79179 m .51644 .75474 L .50385 .74685 L p .707 .577 .707 r
F P
0 g
s
.50385 .70121 m .50385 .75679 L .51644 .76468 L p .707 .577 .707 r
F P
0 g
s
.69777 .70467 m .69777 .76025 L .70485 .75188 L p .707 .577 .707 r
F P
0 g
s
.70485 .75188 m .70485 .6963 L .69777 .70467 L p .707 .577 .707 r
F P
0 g
s
.51644 .79319 m .51644 .77466 L .50385 .76677 L p .707 .577 .707 r
F P
0 g
s
.50385 .74685 m .50385 .78391 L .51644 .79179 L p .707 .577 .707 r
F P
0 g
s
.50385 .76677 m .50385 .7853 L .51644 .79319 L p .707 .577 .707 r
F P
0 g
s
.50385 .75679 m .50385 .70121 L .50095 .69267 L p .707 .577 .707 r
F P
0 g
s
.69777 .75031 m .69777 .78737 L .70485 .779 L p .707 .577 .707 r
F P
0 g
s
.70485 .779 m .70485 .74195 L .69777 .75031 L p .707 .577 .707 r
F P
0 g
s
.69777 .77023 m .69777 .78876 L .70485 .7804 L p .707 .577 .707 r
F P
0 g
s
.70485 .7804 m .70485 .76187 L .69777 .77023 L p .707 .577 .707 r
F P
0 g
s
.50385 .78391 m .50385 .74685 L .50095 .73831 L p .707 .577 .707 r
F P
0 g
s
.50095 .69267 m .50095 .74825 L .50385 .75679 L p .707 .577 .707 r
F P
0 g
s
.70485 .6963 m .70485 .75188 L .70195 .74334 L p .707 .577 .707 r
F P
0 g
s
.70195 .74334 m .70195 .68776 L .70485 .6963 L p .707 .577 .707 r
F P
0 g
s
.50385 .7853 m .50385 .76677 L .50095 .75823 L p .707 .577 .707 r
F P
0 g
s
.50095 .73831 m .50095 .77537 L .50385 .78391 L p .707 .577 .707 r
F P
0 g
s
.50095 .75823 m .50095 .77676 L .50385 .7853 L p .707 .577 .707 r
F P
0 g
s
.49044 .83764 m .49044 .33575 L .44643 .33307 L p .707 .577 .707 r
F P
0 g
s
.50095 .74825 m .50095 .69267 L .50804 .6843 L p .707 .577 .707 r
F P
0 g
s
.50095 .77537 m .50095 .73831 L .50804 .72995 L p .707 .577 .707 r
F P
0 g
s
.50804 .6843 m .50804 .73989 L .50095 .74825 L p .707 .577 .707 r
F P
0 g
s
.50095 .77676 m .50095 .75823 L .50804 .74987 L p .707 .577 .707 r
F P
0 g
s
.50804 .72995 m .50804 .767 L .50095 .77537 L p .707 .577 .707 r
F P
0 g
s
.50804 .74987 m .50804 .7684 L .50095 .77676 L p .707 .577 .707 r
F P
0 g
s
.50804 .73989 m .50804 .6843 L .5244 .67694 L p .707 .577 .707 r
F P
0 g
s
.50804 .767 m .50804 .72995 L .5244 .72258 L p .707 .577 .707 r
F P
0 g
s
.5244 .67694 m .5244 .73252 L .50804 .73989 L p .707 .577 .707 r
F P
0 g
s
.50804 .7684 m .50804 .74987 L .5244 .7425 L p .707 .577 .707 r
F P
0 g
s
.5244 .72258 m .5244 .75963 L .50804 .767 L p .707 .577 .707 r
F P
0 g
s
.5244 .7425 m .5244 .76103 L .50804 .7684 L p .707 .577 .707 r
F P
0 g
s
.5244 .73252 m .5244 .67694 L .54846 .67129 L p .707 .577 .707 r
F P
0 g
s
.5244 .75963 m .5244 .72258 L .54846 .71693 L p .707 .577 .707 r
F P
0 g
s
.54846 .67129 m .54846 .72687 L .5244 .73252 L p .707 .577 .707 r
F P
0 g
s
.5244 .76103 m .5244 .7425 L .54846 .73685 L p .707 .577 .707 r
F P
0 g
s
.54846 .71693 m .54846 .75399 L .5244 .75963 L p .707 .577 .707 r
F P
0 g
s
.54846 .73685 m .54846 .75538 L .5244 .76103 L p .707 .577 .707 r
F P
0 g
s
.49044 .33575 m .49044 .83764 L .53538 .83654 L p .707 .577 .707 r
F P
0 g
s
.53538 .83654 m .53538 .33466 L .49044 .33575 L p .707 .577 .707 r
F P
0 g
s
.54846 .72687 m .54846 .67129 L .57784 .66791 L p .707 .577 .707 r
F P
0 g
s
.57784 .66791 m .57784 .72349 L .54846 .72687 L p .707 .577 .707 r
F P
0 g
s
.54846 .75399 m .54846 .71693 L .57784 .71355 L p .707 .577 .707 r
F P
0 g
s
.54846 .75538 m .54846 .73685 L .57784 .73347 L p .707 .577 .707 r
F P
0 g
s
.57784 .71355 m .57784 .75061 L .54846 .75399 L p .707 .577 .707 r
F P
0 g
s
.57784 .73347 m .57784 .752 L .54846 .75538 L p .707 .577 .707 r
F P
0 g
s
.53538 .33466 m .53538 .83654 L .57686 .83177 L p .707 .577 .707 r
F P
0 g
s
.57686 .83177 m .57686 .32989 L .53538 .33466 L p .707 .577 .707 r
F P
0 g
s
.70485 .74195 m .70485 .779 L .70195 .77046 L p .707 .577 .707 r
F P
0 g
s
.70195 .77046 m .70195 .73341 L .70485 .74195 L p .707 .577 .707 r
F P
0 g
s
.44643 .83496 m .44643 .33307 L .40766 .32687 L p .707 .577 .707 r
F P
0 g
s
.44643 .33307 m .44643 .83496 L .49044 .83764 L p .707 .577 .707 r
F P
0 g
s
.70485 .76187 m .70485 .7804 L .70195 .77185 L p .707 .577 .707 r
F P
0 g
s
.70195 .77185 m .70195 .75333 L .70485 .76187 L p .707 .577 .707 r
F P
0 g
s
.57784 .72349 m .57784 .66791 L .60968 .66713 L p .707 .577 .707 r
F P
0 g
s
.60968 .66713 m .60968 .72271 L .57784 .72349 L p .707 .577 .707 r
F P
0 g
s
.57784 .75061 m .57784 .71355 L .60968 .71277 L p .707 .577 .707 r
F P
0 g
s
.60968 .71277 m .60968 .74983 L .57784 .75061 L p .707 .577 .707 r
F P
0 g
s
.57784 .752 m .57784 .73347 L .60968 .73269 L p .707 .577 .707 r
F P
0 g
s
.60968 .73269 m .60968 .75122 L .57784 .752 L p .707 .577 .707 r
F P
0 g
s
.57686 .32989 m .57686 .83177 L .61082 .8238 L p .707 .577 .707 r
F P
0 g
s
.64085 .66903 m .64085 .72461 L .60968 .72271 L p .707 .577 .707 r
F P
0 g
s
.60968 .72271 m .60968 .66713 L .64085 .66903 L p .707 .577 .707 r
F P
0 g
s
.64085 .71467 m .64085 .75173 L .60968 .74983 L p .707 .577 .707 r
F P
0 g
s
.60968 .74983 m .60968 .71277 L .64085 .71467 L p .707 .577 .707 r
F P
0 g
s
.64085 .7346 m .64085 .75312 L .60968 .75122 L p .707 .577 .707 r
F P
0 g
s
.60968 .75122 m .60968 .73269 L .64085 .7346 L p .707 .577 .707 r
F P
0 g
s
.61082 .8238 m .61082 .32191 L .57686 .32989 L p .707 .577 .707 r
F P
0 g
s
.70195 .68776 m .70195 .74334 L .68936 .73546 L p .707 .577 .707 r
F P
0 g
s
.68936 .73546 m .68936 .67988 L .70195 .68776 L p .707 .577 .707 r
F P
0 g
s
.40766 .82876 m .40766 .32687 L .37794 .31776 L p .707 .577 .707 r
F P
0 g
s
.40766 .32687 m .40766 .82876 L .44643 .83496 L p .707 .577 .707 r
F P
0 g
s
.25312 .74061 m .25312 .68503 L .22195 .68312 L p .707 .577 .707 r
F P
0 g
s
.25312 .68503 m .25312 .74061 L .28495 .73983 L p .707 .577 .707 r
F P
0 g
s
.28495 .73983 m .28495 .68425 L .25312 .68503 L p .707 .577 .707 r
F P
0 g
s
.28495 .68425 m .28495 .73983 L .31434 .73645 L p .707 .577 .707 r
F P
0 g
s
.31434 .73645 m .31434 .68087 L .28495 .68425 L p .707 .577 .707 r
F P
0 g
s
.70195 .73341 m .70195 .77046 L .68936 .76258 L p .707 .577 .707 r
F P
0 g
s
.68936 .76258 m .68936 .72552 L .70195 .73341 L p .707 .577 .707 r
F P
0 g
s
.22195 .73871 m .22195 .68312 L .19449 .67873 L p .707 .577 .707 r
F P
0 g
s
.22195 .68312 m .22195 .73871 L .25312 .74061 L p .707 .577 .707 r
F P
0 g
s
.70195 .75333 m .70195 .77185 L .68936 .76397 L p .707 .577 .707 r
F P
0 g
s
.68936 .76397 m .68936 .74544 L .70195 .75333 L p .707 .577 .707 r
F P
0 g
s
.25312 .76772 m .25312 .73067 L .22195 .72877 L p .707 .577 .707 r
F P
0 g
s
.25312 .73067 m .25312 .76772 L .28495 .76695 L p .707 .577 .707 r
F P
0 g
s
.28495 .76695 m .28495 .72989 L .25312 .73067 L p .707 .577 .707 r
F P
0 g
s
.31434 .68087 m .31434 .73645 L .33839 .7308 L p .707 .577 .707 r
F P
0 g
s
.33839 .7308 m .33839 .67522 L .31434 .68087 L p .707 .577 .707 r
F P
0 g
s
.28495 .72989 m .28495 .76695 L .31434 .76357 L p .707 .577 .707 r
F P
0 g
s
.31434 .76357 m .31434 .72651 L .28495 .72989 L p .707 .577 .707 r
F P
0 g
s
.61082 .32191 m .61082 .8238 L .63393 .8134 L p .707 .577 .707 r
F P
0 g
s
.63393 .8134 m .63393 .31151 L .61082 .32191 L p .707 .577 .707 r
F P
0 g
s
.25312 .76912 m .25312 .75059 L .22195 .74869 L p .707 .577 .707 r
F P
0 g
s
.25312 .75059 m .25312 .76912 L .28495 .76834 L p .707 .577 .707 r
F P
0 g
s
.28495 .76834 m .28495 .74981 L .25312 .75059 L p .707 .577 .707 r
F P
0 g
s
.68936 .67988 m .68936 .73546 L .66831 .729 L p .707 .577 .707 r
F P
0 g
s
.66831 .729 m .66831 .67342 L .68936 .67988 L p .707 .577 .707 r
F P
0 g
s
.22195 .76582 m .22195 .72877 L .19449 .72438 L p .707 .577 .707 r
F P
0 g
s
.22195 .72877 m .22195 .76582 L .25312 .76772 L p .707 .577 .707 r
F P
0 g
s
.28495 .74981 m .28495 .76834 L .31434 .76496 L p .707 .577 .707 r
F P
0 g
s
.31434 .76496 m .31434 .74643 L .28495 .74981 L p .707 .577 .707 r
F P
0 g
s
.19449 .67873 m .19449 .73431 L .22195 .73871 L p .707 .577 .707 r
F P
0 g
s
.19449 .73431 m .19449 .67873 L .17343 .67228 L p .707 .577 .707 r
F P
0 g
s
.22195 .74869 m .22195 .76722 L .25312 .76912 L p .707 .577 .707 r
F P
0 g
s
.22195 .76722 m .22195 .74869 L .19449 .7443 L p .707 .577 .707 r
F P
0 g
s
.31434 .72651 m .31434 .76357 L .33839 .75792 L p .707 .577 .707 r
F P
0 g
s
.33839 .75792 m .33839 .72086 L .31434 .72651 L p .707 .577 .707 r
F P
0 g
s
.19449 .72438 m .19449 .76143 L .22195 .76582 L p .707 .577 .707 r
F P
0 g
s
.19449 .7443 m .19449 .76282 L .22195 .76722 L p .707 .577 .707 r
F P
0 g
s
.37794 .81965 m .37794 .31776 L .36016 .30663 L p .707 .577 .707 r
F P
0 g
s
.37794 .31776 m .37794 .81965 L .40766 .82876 L p .707 .577 .707 r
F P
0 g
s
.68936 .72552 m .68936 .76258 L .66831 .75612 L p .707 .577 .707 r
F P
0 g
s
.66831 .75612 m .66831 .71907 L .68936 .72552 L p .707 .577 .707 r
F P
0 g
s
.31434 .74643 m .31434 .76496 L .33839 .75931 L p .707 .577 .707 r
F P
0 g
s
.33839 .75931 m .33839 .74078 L .31434 .74643 L p .707 .577 .707 r
F P
0 g
s
.33839 .67522 m .33839 .7308 L .35476 .72343 L p .707 .577 .707 r
F P
0 g
s
.35476 .72343 m .35476 .66785 L .33839 .67522 L p .707 .577 .707 r
F P
0 g
s
.19449 .76143 m .19449 .72438 L .17343 .71792 L p .707 .577 .707 r
F P
0 g
s
.68936 .74544 m .68936 .76397 L .66831 .75751 L p .707 .577 .707 r
F P
0 g
s
.66831 .75751 m .66831 .73899 L .68936 .74544 L p .707 .577 .707 r
F P
0 g
s
.17343 .67228 m .17343 .72786 L .19449 .73431 L p .707 .577 .707 r
F P
0 g
s
.19449 .76282 m .19449 .7443 L .17343 .73784 L p .707 .577 .707 r
F P
0 g
s
.66831 .67342 m .66831 .729 L .64085 .72461 L p .707 .577 .707 r
F P
0 g
s
.64085 .72461 m .64085 .66903 L .66831 .67342 L p .707 .577 .707 r
F P
0 g
s
.17343 .71792 m .17343 .75498 L .19449 .76143 L p .707 .577 .707 r
F P
0 g
s
.17343 .72786 m .17343 .67228 L .16084 .66439 L p .707 .577 .707 r
F P
0 g
s
.17343 .73784 m .17343 .75637 L .19449 .76282 L p .707 .577 .707 r
F P
0 g
s
.33839 .72086 m .33839 .75792 L .35476 .75055 L p .707 .577 .707 r
F P
0 g
s
.35476 .75055 m .35476 .7135 L .33839 .72086 L p .707 .577 .707 r
F P
0 g
s
.66831 .71907 m .66831 .75612 L .64085 .75173 L p .707 .577 .707 r
F P
0 g
s
.64085 .75173 m .64085 .71467 L .66831 .71907 L p .707 .577 .707 r
F P
0 g
s
.66831 .73899 m .66831 .75751 L .64085 .75312 L p .707 .577 .707 r
F P
0 g
s
.64085 .75312 m .64085 .7346 L .66831 .73899 L p .707 .577 .707 r
F P
0 g
s
.63393 .31151 m .63393 .8134 L .64393 .80159 L p .707 .577 .707 r
F P
0 g
s
.64393 .80159 m .64393 .2997 L .63393 .31151 L p .707 .577 .707 r
F P
0 g
s
.33839 .74078 m .33839 .75931 L .35476 .75194 L p .707 .577 .707 r
F P
0 g
s
.35476 .75194 m .35476 .73342 L .33839 .74078 L p .707 .577 .707 r
F P
0 g
s
.17343 .75498 m .17343 .71792 L .16084 .71004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66439 m .16084 .71998 L .17343 .72786 L p .707 .577 .707 r
F P
0 g
s
.35476 .66785 m .35476 .72343 L .36184 .71507 L p .707 .577 .707 r
F P
0 g
s
.36184 .71507 m .36184 .65949 L .35476 .66785 L p .707 .577 .707 r
F P
0 g
s
.17343 .75637 m .17343 .73784 L .16084 .72996 L p .707 .577 .707 r
F P
0 g
s
.16084 .71004 m .16084 .74709 L .17343 .75498 L p .707 .577 .707 r
F P
0 g
s
.16084 .72996 m .16084 .74849 L .17343 .75637 L p .707 .577 .707 r
F P
0 g
s
.35476 .7135 m .35476 .75055 L .36184 .74219 L p .707 .577 .707 r
F P
0 g
s
.36184 .74219 m .36184 .70513 L .35476 .7135 L p .707 .577 .707 r
F P
0 g
s
.35476 .73342 m .35476 .75194 L .36184 .74358 L p .707 .577 .707 r
F P
0 g
s
.36184 .74358 m .36184 .72505 L .35476 .73342 L p .707 .577 .707 r
F P
0 g
s
.36184 .65949 m .36184 .71507 L .35894 .70653 L p .707 .577 .707 r
F P
0 g
s
.35894 .70653 m .35894 .65095 L .36184 .65949 L p .707 .577 .707 r
F P
0 g
s
.36184 .70513 m .36184 .74219 L .35894 .73364 L p .707 .577 .707 r
F P
0 g
s
.35894 .73364 m .35894 .69659 L .36184 .70513 L p .707 .577 .707 r
F P
0 g
s
.36184 .72505 m .36184 .74358 L .35894 .73504 L p .707 .577 .707 r
F P
0 g
s
.35894 .73504 m .35894 .71651 L .36184 .72505 L p .707 .577 .707 r
F P
0 g
s
.35894 .65095 m .35894 .70653 L .34635 .69864 L p .707 .577 .707 r
F P
0 g
s
.34635 .69864 m .34635 .64306 L .35894 .65095 L p .707 .577 .707 r
F P
0 g
s
.36016 .80852 m .36016 .30663 L .35607 .29457 L p .707 .577 .707 r
F P
0 g
s
.36016 .30663 m .36016 .80852 L .37794 .81965 L p .707 .577 .707 r
F P
0 g
s
.16084 .71998 m .16084 .66439 L .15794 .65585 L p .707 .577 .707 r
F P
0 g
s
.16084 .74709 m .16084 .71004 L .15794 .7015 L p .707 .577 .707 r
F P
0 g
s
.15794 .65585 m .15794 .71143 L .16084 .71998 L p .707 .577 .707 r
F P
0 g
s
.16084 .74849 m .16084 .72996 L .15794 .72142 L p .707 .577 .707 r
F P
0 g
s
.64393 .2997 m .64393 .80159 L .63984 .78953 L p .707 .577 .707 r
F P
0 g
s
.63984 .78953 m .63984 .28764 L .64393 .2997 L p .707 .577 .707 r
F P
0 g
s
.15794 .7015 m .15794 .73855 L .16084 .74709 L p .707 .577 .707 r
F P
0 g
s
.15794 .72142 m .15794 .73994 L .16084 .74849 L p .707 .577 .707 r
F P
0 g
s
.15794 .71143 m .15794 .65585 L .16503 .64749 L p .707 .577 .707 r
F P
0 g
s
.35894 .69659 m .35894 .73364 L .34635 .72576 L p .707 .577 .707 r
F P
0 g
s
.34635 .72576 m .34635 .68871 L .35894 .69659 L p .707 .577 .707 r
F P
0 g
s
.35894 .71651 m .35894 .73504 L .34635 .72715 L p .707 .577 .707 r
F P
0 g
s
.34635 .72715 m .34635 .70863 L .35894 .71651 L p .707 .577 .707 r
F P
0 g
s
.35607 .29457 m .35607 .79646 L .36016 .80852 L p .707 .577 .707 r
F P
0 g
s
.35607 .79646 m .35607 .29457 L .36607 .28276 L p .707 .577 .707 r
F P
0 g
s
.15794 .73855 m .15794 .7015 L .16503 .69313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .64749 m .16503 .70307 L .15794 .71143 L p .707 .577 .707 r
F P
0 g
s
.15794 .73994 m .15794 .72142 L .16503 .71305 L p .707 .577 .707 r
F P
0 g
s
.16503 .69313 m .16503 .73019 L .15794 .73855 L p .707 .577 .707 r
F P
0 g
s
.16503 .71305 m .16503 .73158 L .15794 .73994 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70307 m .16503 .64749 L .1814 .64012 L p .707 .577 .707 r
F P
0 g
s
.63984 .28764 m .63984 .78953 L .62206 .7784 L p .707 .577 .707 r
F P
0 g
s
.62206 .7784 m .62206 .27651 L .63984 .28764 L p .707 .577 .707 r
F P
0 g
s
.16503 .73019 m .16503 .69313 L .1814 .68576 L p .707 .577 .707 r
F P
0 g
s
.1814 .64012 m .1814 .6957 L .16503 .70307 L p .707 .577 .707 r
F P
0 g
s
.34635 .64306 m .34635 .69864 L .3253 .69219 L p .707 .577 .707 r
F P
0 g
s
.3253 .69219 m .3253 .63661 L .34635 .64306 L p .707 .577 .707 r
F P
0 g
s
.16503 .73158 m .16503 .71305 L .1814 .70569 L p .707 .577 .707 r
F P
0 g
s
.36607 .78465 m .36607 .28276 L .38918 .27236 L p .707 .577 .707 r
F P
0 g
s
.36607 .28276 m .36607 .78465 L .35607 .79646 L p .707 .577 .707 r
F P
0 g
s
.1814 .68576 m .1814 .72282 L .16503 .73019 L p .707 .577 .707 r
F P
0 g
s
.1814 .70569 m .1814 .72421 L .16503 .73158 L p .707 .577 .707 r
F P
0 g
s
.1814 .6957 m .1814 .64012 L .20545 .63447 L p .707 .577 .707 r
F P
0 g
s
.34635 .68871 m .34635 .72576 L .3253 .71931 L p .707 .577 .707 r
F P
0 g
s
.3253 .71931 m .3253 .68225 L .34635 .68871 L p .707 .577 .707 r
F P
0 g
s
.34635 .70863 m .34635 .72715 L .3253 .7207 L p .707 .577 .707 r
F P
0 g
s
.3253 .7207 m .3253 .70217 L .34635 .70863 L p .707 .577 .707 r
F P
0 g
s
.3253 .63661 m .3253 .69219 L .29784 .6878 L p .707 .577 .707 r
F P
0 g
s
.29784 .6878 m .29784 .63221 L .3253 .63661 L p .707 .577 .707 r
F P
0 g
s
.1814 .72282 m .1814 .68576 L .20545 .68011 L p .707 .577 .707 r
F P
0 g
s
.20545 .63447 m .20545 .69005 L .1814 .6957 L p .707 .577 .707 r
F P
0 g
s
.62206 .27651 m .62206 .7784 L .59233 .76929 L p .707 .577 .707 r
F P
0 g
s
.59233 .76929 m .59233 .2674 L .62206 .27651 L p .707 .577 .707 r
F P
0 g
s
.1814 .72421 m .1814 .70569 L .20545 .70004 L p .707 .577 .707 r
F P
0 g
s
.20545 .69005 m .20545 .63447 L .23483 .63109 L p .707 .577 .707 r
F P
0 g
s
.20545 .68011 m .20545 .71717 L .1814 .72282 L p .707 .577 .707 r
F P
0 g
s
.20545 .70004 m .20545 .71856 L .1814 .72421 L p .707 .577 .707 r
F P
0 g
s
.3253 .68225 m .3253 .71931 L .29784 .71491 L p .707 .577 .707 r
F P
0 g
s
.29784 .71491 m .29784 .67786 L .3253 .68225 L p .707 .577 .707 r
F P
0 g
s
.29784 .63221 m .29784 .6878 L .26667 .6859 L p .707 .577 .707 r
F P
0 g
s
.26667 .6859 m .26667 .63031 L .29784 .63221 L p .707 .577 .707 r
F P
0 g
s
.3253 .70217 m .3253 .7207 L .29784 .71631 L p .707 .577 .707 r
F P
0 g
s
.29784 .71631 m .29784 .69778 L .3253 .70217 L p .707 .577 .707 r
F P
0 g
s
.38918 .27236 m .38918 .77425 L .36607 .78465 L p .707 .577 .707 r
F P
0 g
s
.38918 .77425 m .38918 .27236 L .42314 .26438 L p .707 .577 .707 r
F P
0 g
s
.23483 .68667 m .23483 .63109 L .26667 .63031 L p .707 .577 .707 r
F P
0 g
s
.23483 .63109 m .23483 .68667 L .20545 .69005 L p .707 .577 .707 r
F P
0 g
s
.20545 .71717 m .20545 .68011 L .23483 .67674 L p .707 .577 .707 r
F P
0 g
s
.26667 .63031 m .26667 .6859 L .23483 .68667 L p .707 .577 .707 r
F P
0 g
s
.73333 .68538 m .73333 .6298 L .70216 .6279 L p .707 .577 .707 r
F P
0 g
s
.73333 .6298 m .73333 .68538 L .76517 .68461 L p .707 .577 .707 r
F P
0 g
s
.76517 .68461 m .76517 .62903 L .73333 .6298 L p .707 .577 .707 r
F P
0 g
s
.20545 .71856 m .20545 .70004 L .23483 .69666 L p .707 .577 .707 r
F P
0 g
s
.76517 .62903 m .76517 .68461 L .79455 .68123 L p .707 .577 .707 r
F P
0 g
s
.79455 .68123 m .79455 .62565 L .76517 .62903 L p .707 .577 .707 r
F P
0 g
s
.29784 .67786 m .29784 .71491 L .26667 .71301 L p .707 .577 .707 r
F P
0 g
s
.26667 .71301 m .26667 .67596 L .29784 .67786 L p .707 .577 .707 r
F P
0 g
s
.23483 .67674 m .23483 .71379 L .20545 .71717 L p .707 .577 .707 r
F P
0 g
s
.23483 .69666 m .23483 .71518 L .20545 .71856 L p .707 .577 .707 r
F P
0 g
s
.70216 .68348 m .70216 .6279 L .6747 .62351 L p .707 .577 .707 r
F P
0 g
s
.70216 .6279 m .70216 .68348 L .73333 .68538 L p .707 .577 .707 r
F P
0 g
s
.23483 .71379 m .23483 .67674 L .26667 .67596 L p .707 .577 .707 r
F P
0 g
s
.29784 .69778 m .29784 .71631 L .26667 .71441 L p .707 .577 .707 r
F P
0 g
s
.26667 .71441 m .26667 .69588 L .29784 .69778 L p .707 .577 .707 r
F P
0 g
s
.26667 .67596 m .26667 .71301 L .23483 .71379 L p .707 .577 .707 r
F P
0 g
s
.73333 .7125 m .73333 .67545 L .70216 .67355 L p .707 .577 .707 r
F P
0 g
s
.73333 .67545 m .73333 .7125 L .76517 .71172 L p .707 .577 .707 r
F P
0 g
s
.76517 .71172 m .76517 .67467 L .73333 .67545 L p .707 .577 .707 r
F P
0 g
s
.59233 .2674 m .59233 .76929 L .55357 .76309 L p .707 .577 .707 r
F P
0 g
s
.55357 .76309 m .55357 .2612 L .59233 .2674 L p .707 .577 .707 r
F P
0 g
s
.23483 .71518 m .23483 .69666 L .26667 .69588 L p .707 .577 .707 r
F P
0 g
s
.79455 .62565 m .79455 .68123 L .8186 .67558 L p .707 .577 .707 r
F P
0 g
s
.8186 .67558 m .8186 .62 L .79455 .62565 L p .707 .577 .707 r
F P
0 g
s
.76517 .67467 m .76517 .71172 L .79455 .70835 L p .707 .577 .707 r
F P
0 g
s
.79455 .70835 m .79455 .67129 L .76517 .67467 L p .707 .577 .707 r
F P
0 g
s
.26667 .69588 m .26667 .71441 L .23483 .71518 L p .707 .577 .707 r
F P
0 g
s
.73333 .71389 m .73333 .69537 L .70216 .69347 L p .707 .577 .707 r
F P
0 g
s
.73333 .69537 m .73333 .71389 L .76517 .71312 L p .707 .577 .707 r
F P
0 g
s
.76517 .71312 m .76517 .69459 L .73333 .69537 L p .707 .577 .707 r
F P
0 g
s
.70216 .7106 m .70216 .67355 L .6747 .66915 L p .707 .577 .707 r
F P
0 g
s
.70216 .67355 m .70216 .7106 L .73333 .7125 L p .707 .577 .707 r
F P
0 g
s
.76517 .69459 m .76517 .71312 L .79455 .70974 L p .707 .577 .707 r
F P
0 g
s
.79455 .70974 m .79455 .69121 L .76517 .69459 L p .707 .577 .707 r
F P
0 g
s
.6747 .62351 m .6747 .67909 L .70216 .68348 L p .707 .577 .707 r
F P
0 g
s
.6747 .67909 m .6747 .62351 L .65365 .61706 L p .707 .577 .707 r
F P
0 g
s
.70216 .69347 m .70216 .71199 L .73333 .71389 L p .707 .577 .707 r
F P
0 g
s
.42314 .76627 m .42314 .26438 L .46462 .25961 L p .707 .577 .707 r
F P
0 g
s
.42314 .26438 m .42314 .76627 L .38918 .77425 L p .707 .577 .707 r
F P
0 g
s
.70216 .71199 m .70216 .69347 L .6747 .68907 L p .707 .577 .707 r
F P
0 g
s
.79455 .67129 m .79455 .70835 L .8186 .7027 L p .707 .577 .707 r
F P
0 g
s
.8186 .7027 m .8186 .66564 L .79455 .67129 L p .707 .577 .707 r
F P
0 g
s
.6747 .66915 m .6747 .70621 L .70216 .7106 L p .707 .577 .707 r
F P
0 g
s
.6747 .68907 m .6747 .7076 L .70216 .71199 L p .707 .577 .707 r
F P
0 g
s
.79455 .69121 m .79455 .70974 L .8186 .70409 L p .707 .577 .707 r
F P
0 g
s
.8186 .70409 m .8186 .68556 L .79455 .69121 L p .707 .577 .707 r
F P
0 g
s
.8186 .62 m .8186 .67558 L .83497 .66821 L p .707 .577 .707 r
F P
0 g
s
.83497 .66821 m .83497 .61263 L .8186 .62 L p .707 .577 .707 r
F P
0 g
s
.6747 .70621 m .6747 .66915 L .65365 .6627 L p .707 .577 .707 r
F P
0 g
s
.55357 .2612 m .55357 .76309 L .50956 .7604 L p .707 .577 .707 r
F P
0 g
s
.50956 .7604 m .50956 .25851 L .55357 .2612 L p .707 .577 .707 r
F P
0 g
s
.65365 .61706 m .65365 .67264 L .6747 .67909 L p .707 .577 .707 r
F P
0 g
s
.6747 .7076 m .6747 .68907 L .65365 .68262 L p .707 .577 .707 r
F P
0 g
s
.46462 .7615 m .46462 .25961 L .50956 .25851 L p .707 .577 .707 r
F P
0 g
s
.46462 .25961 m .46462 .7615 L .42314 .76627 L p .707 .577 .707 r
F P
0 g
s
.50956 .25851 m .50956 .7604 L .46462 .7615 L p .707 .577 .707 r
F P
0 g
s
.65365 .6627 m .65365 .69975 L .6747 .70621 L p .707 .577 .707 r
F P
0 g
s
.65365 .67264 m .65365 .61706 L .64105 .60917 L p .707 .577 .707 r
F P
0 g
s
.65365 .68262 m .65365 .70115 L .6747 .7076 L p .707 .577 .707 r
F P
0 g
s
.8186 .66564 m .8186 .7027 L .83497 .69533 L p .707 .577 .707 r
F P
0 g
s
.83497 .69533 m .83497 .65827 L .8186 .66564 L p .707 .577 .707 r
F P
0 g
s
.8186 .68556 m .8186 .70409 L .83497 .69672 L p .707 .577 .707 r
F P
0 g
s
.83497 .69672 m .83497 .67819 L .8186 .68556 L p .707 .577 .707 r
F P
0 g
s
.65365 .69975 m .65365 .6627 L .64105 .65482 L p .707 .577 .707 r
F P
0 g
s
.64105 .60917 m .64105 .66475 L .65365 .67264 L p .707 .577 .707 r
F P
0 g
s
.83497 .61263 m .83497 .66821 L .84205 .65985 L p .707 .577 .707 r
F P
0 g
s
.84205 .65985 m .84205 .60426 L .83497 .61263 L p .707 .577 .707 r
F P
0 g
s
.65365 .70115 m .65365 .68262 L .64105 .67474 L p .707 .577 .707 r
F P
0 g
s
.64105 .65482 m .64105 .69187 L .65365 .69975 L p .707 .577 .707 r
F P
0 g
s
.64105 .67474 m .64105 .69326 L .65365 .70115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66475 m .64105 .60917 L .63816 .60063 L p .707 .577 .707 r
F P
0 g
s
.83497 .65827 m .83497 .69533 L .84206 .68696 L p .707 .577 .707 r
F P
0 g
s
.84206 .68696 m .84205 .64991 L .83497 .65827 L p .707 .577 .707 r
F P
0 g
s
.83497 .67819 m .83497 .69672 L .84206 .68836 L p .707 .577 .707 r
F P
0 g
s
.84206 .68836 m .84206 .66983 L .83497 .67819 L p .707 .577 .707 r
F P
0 g
s
.64105 .69187 m .64105 .65482 L .63816 .64627 L p .707 .577 .707 r
F P
0 g
s
.63816 .60063 m .63816 .65621 L .64105 .66475 L p .707 .577 .707 r
F P
0 g
s
.84205 .60426 m .84205 .65985 L .83916 .6513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6513 m .83916 .59572 L .84205 .60426 L p .707 .577 .707 r
F P
0 g
s
.64105 .69326 m .64105 .67474 L .63816 .66619 L p .707 .577 .707 r
F P
0 g
s
.63816 .64627 m .63816 .68333 L .64105 .69187 L p .707 .577 .707 r
F P
0 g
s
.63816 .66619 m .63816 .68472 L .64105 .69326 L p .707 .577 .707 r
F P
0 g
s
.84205 .64991 m .84206 .68696 L .83916 .67842 L p .707 .577 .707 r
F P
0 g
s
.83916 .67842 m .83916 .64137 L .84205 .64991 L p .707 .577 .707 r
F P
0 g
s
.63816 .65621 m .63816 .60063 L .64524 .59226 L p .707 .577 .707 r
F P
0 g
s
.84206 .66983 m .84206 .68836 L .83916 .67981 L p .707 .577 .707 r
F P
0 g
s
.83916 .67981 m .83916 .66129 L .84206 .66983 L p .707 .577 .707 r
F P
0 g
s
.63816 .68333 m .63816 .64627 L .64524 .63791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .59226 m .64524 .64785 L .63816 .65621 L p .707 .577 .707 r
F P
0 g
s
.83916 .59572 m .83916 .6513 L .82657 .64342 L p .707 .577 .707 r
F P
0 g
s
.82657 .64342 m .82657 .58784 L .83916 .59572 L p .707 .577 .707 r
F P
0 g
s
.63816 .68472 m .63816 .66619 L .64524 .65783 L p .707 .577 .707 r
F P
0 g
s
.64524 .63791 m .64524 .67496 L .63816 .68333 L p .707 .577 .707 r
F P
0 g
s
.64524 .65783 m .64524 .67636 L .63816 .68472 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64857 m .39032 .59299 L .35915 .59109 L p .707 .577 .707 r
F P
0 g
s
.39032 .59299 m .39032 .64857 L .42216 .64779 L p .707 .577 .707 r
F P
0 g
s
.42216 .64779 m .42216 .59221 L .39032 .59299 L p .707 .577 .707 r
F P
0 g
s
.64524 .64785 m .64524 .59226 L .66161 .5849 L p .707 .577 .707 r
F P
0 g
s
.42216 .59221 m .42216 .64779 L .45154 .64441 L p .707 .577 .707 r
F P
0 g
s
.45154 .64441 m .45154 .58883 L .42216 .59221 L p .707 .577 .707 r
F P
0 g
s
.83916 .64137 m .83916 .67842 L .82657 .67054 L p .707 .577 .707 r
F P
0 g
s
.82657 .67054 m .82657 .63348 L .83916 .64137 L p .707 .577 .707 r
F P
0 g
s
.35915 .64667 m .35915 .59109 L .33169 .58669 L p .707 .577 .707 r
F P
0 g
s
.35915 .59109 m .35915 .64667 L .39032 .64857 L p .707 .577 .707 r
F P
0 g
s
.83916 .66129 m .83916 .67981 L .82657 .67193 L p .707 .577 .707 r
F P
0 g
s
.82657 .67193 m .82657 .6534 L .83916 .66129 L p .707 .577 .707 r
F P
0 g
s
.39032 .67569 m .39032 .63863 L .35915 .63673 L p .707 .577 .707 r
F P
0 g
s
.39032 .63863 m .39032 .67569 L .42216 .67491 L p .707 .577 .707 r
F P
0 g
s
.42216 .67491 m .42216 .63785 L .39032 .63863 L p .707 .577 .707 r
F P
0 g
s
.45154 .58883 m .45154 .64441 L .47559 .63876 L p .707 .577 .707 r
F P
0 g
s
.47559 .63876 m .47559 .58318 L .45154 .58883 L p .707 .577 .707 r
F P
0 g
s
.64524 .67496 m .64524 .63791 L .66161 .63054 L p .707 .577 .707 r
F P
0 g
s
.42216 .63785 m .42216 .67491 L .45154 .67153 L p .707 .577 .707 r
F P
0 g
s
.45154 .67153 m .45154 .63448 L .42216 .63785 L p .707 .577 .707 r
F P
0 g
s
.66161 .5849 m .66161 .64048 L .64524 .64785 L p .707 .577 .707 r
F P
0 g
s
.39032 .67708 m .39032 .65855 L .35915 .65665 L p .707 .577 .707 r
F P
0 g
s
.39032 .65855 m .39032 .67708 L .42216 .6763 L p .707 .577 .707 r
F P
0 g
s
.42216 .6763 m .42216 .65777 L .39032 .65855 L p .707 .577 .707 r
F P
0 g
s
.82657 .58784 m .82657 .64342 L .80551 .63697 L p .707 .577 .707 r
F P
0 g
s
.80551 .63697 m .80551 .58138 L .82657 .58784 L p .707 .577 .707 r
F P
0 g
s
.35915 .67379 m .35915 .63673 L .33169 .63234 L p .707 .577 .707 r
F P
0 g
s
.35915 .63673 m .35915 .67379 L .39032 .67569 L p .707 .577 .707 r
F P
0 g
s
.64524 .67636 m .64524 .65783 L .66161 .65046 L p .707 .577 .707 r
F P
0 g
s
.42216 .65777 m .42216 .6763 L .45154 .67292 L p .707 .577 .707 r
F P
0 g
s
.45154 .67292 m .45154 .6544 L .42216 .65777 L p .707 .577 .707 r
F P
0 g
s
.33169 .58669 m .33169 .64228 L .35915 .64667 L p .707 .577 .707 r
F P
0 g
s
.33169 .64228 m .33169 .58669 L .31064 .58024 L p .707 .577 .707 r
F P
0 g
s
.35915 .65665 m .35915 .67518 L .39032 .67708 L p .707 .577 .707 r
F P
0 g
s
.35915 .67518 m .35915 .65665 L .33169 .65226 L p .707 .577 .707 r
F P
0 g
s
.66161 .63054 m .66161 .6676 L .64524 .67496 L p .707 .577 .707 r
F P
0 g
s
.66161 .65046 m .66161 .66899 L .64524 .67636 L p .707 .577 .707 r
F P
0 g
s
.45154 .63448 m .45154 .67153 L .47559 .66588 L p .707 .577 .707 r
F P
0 g
s
.47559 .66588 m .47559 .62883 L .45154 .63448 L p .707 .577 .707 r
F P
0 g
s
.66161 .64048 m .66161 .5849 L .68566 .57925 L p .707 .577 .707 r
F P
0 g
s
.33169 .63234 m .33169 .66939 L .35915 .67379 L p .707 .577 .707 r
F P
0 g
s
.33169 .65226 m .33169 .67079 L .35915 .67518 L p .707 .577 .707 r
F P
0 g
s
.82657 .63348 m .82657 .67054 L .80551 .66408 L p .707 .577 .707 r
F P
0 g
s
.80551 .66408 m .80551 .62703 L .82657 .63348 L p .707 .577 .707 r
F P
0 g
s
.45154 .6544 m .45154 .67292 L .47559 .66727 L p .707 .577 .707 r
F P
0 g
s
.47559 .66727 m .47559 .64875 L .45154 .6544 L p .707 .577 .707 r
F P
0 g
s
.47559 .58318 m .47559 .63876 L .49196 .6314 L p .707 .577 .707 r
F P
0 g
s
.49196 .6314 m .49196 .57581 L .47559 .58318 L p .707 .577 .707 r
F P
0 g
s
.33169 .66939 m .33169 .63234 L .31064 .62588 L p .707 .577 .707 r
F P
0 g
s
.82657 .6534 m .82657 .67193 L .80551 .66548 L p .707 .577 .707 r
F P
0 g
s
.80551 .66548 m .80551 .64695 L .82657 .6534 L p .707 .577 .707 r
F P
0 g
s
.31064 .58024 m .31064 .63582 L .33169 .64228 L p .707 .577 .707 r
F P
0 g
s
.33169 .67079 m .33169 .65226 L .31064 .6458 L p .707 .577 .707 r
F P
0 g
s
.80551 .58138 m .80551 .63697 L .77805 .63257 L p .707 .577 .707 r
F P
0 g
s
.77805 .63257 m .77805 .57699 L .80551 .58138 L p .707 .577 .707 r
F P
0 g
s
.66161 .6676 m .66161 .63054 L .68566 .62489 L p .707 .577 .707 r
F P
0 g
s
.68566 .57925 m .68566 .63483 L .66161 .64048 L p .707 .577 .707 r
F P
0 g
s
.31064 .62588 m .31064 .66294 L .33169 .66939 L p .707 .577 .707 r
F P
0 g
s
.31064 .63582 m .31064 .58024 L .29804 .57236 L p .707 .577 .707 r
F P
0 g
s
.31064 .6458 m .31064 .66433 L .33169 .67079 L p .707 .577 .707 r
F P
0 g
s
.66161 .66899 m .66161 .65046 L .68566 .64481 L p .707 .577 .707 r
F P
0 g
s
.47559 .62883 m .47559 .66588 L .49196 .65851 L p .707 .577 .707 r
F P
0 g
s
.49196 .65851 m .49196 .62146 L .47559 .62883 L p .707 .577 .707 r
F P
0 g
s
.68566 .63483 m .68566 .57925 L .71504 .57587 L p .707 .577 .707 r
F P
0 g
s
.68566 .62489 m .68566 .66195 L .66161 .6676 L p .707 .577 .707 r
F P
0 g
s
.68566 .64481 m .68566 .66334 L .66161 .66899 L p .707 .577 .707 r
F P
0 g
s
.47559 .64875 m .47559 .66727 L .49196 .65991 L p .707 .577 .707 r
F P
0 g
s
.49196 .65991 m .49196 .64138 L .47559 .64875 L p .707 .577 .707 r
F P
0 g
s
.80551 .62703 m .80551 .66408 L .77805 .65969 L p .707 .577 .707 r
F P
0 g
s
.77805 .65969 m .77805 .62264 L .80551 .62703 L p .707 .577 .707 r
F P
0 g
s
.77805 .57699 m .77805 .63257 L .74688 .63067 L p .707 .577 .707 r
F P
0 g
s
.74688 .63067 m .74688 .57509 L .77805 .57699 L p .707 .577 .707 r
F P
0 g
s
.31064 .66294 m .31064 .62588 L .29804 .618 L p .707 .577 .707 r
F P
0 g
s
.80551 .64695 m .80551 .66548 L .77805 .66108 L p .707 .577 .707 r
F P
0 g
s
.77805 .66108 m .77805 .64256 L .80551 .64695 L p .707 .577 .707 r
F P
0 g
s
.29804 .57236 m .29804 .62794 L .31064 .63582 L p .707 .577 .707 r
F P
0 g
s
.71504 .63145 m .71504 .57587 L .74688 .57509 L p .707 .577 .707 r
F P
0 g
s
.71504 .57587 m .71504 .63145 L .68566 .63483 L p .707 .577 .707 r
F P
0 g
s
.49196 .57581 m .49196 .6314 L .49904 .62303 L p .707 .577 .707 r
F P
0 g
s
.49904 .62303 m .49904 .56745 L .49196 .57581 L p .707 .577 .707 r
F P
0 g
s
.68566 .66195 m .68566 .62489 L .71504 .62151 L p .707 .577 .707 r
F P
0 g
s
.31064 .66433 m .31064 .6458 L .29804 .63792 L p .707 .577 .707 r
F P
0 g
s
.74688 .57509 m .74688 .63067 L .71504 .63145 L p .707 .577 .707 r
F P
0 g
s
.68566 .66334 m .68566 .64481 L .71504 .64143 L p .707 .577 .707 r
F P
0 g
s
.29804 .618 m .29804 .65506 L .31064 .66294 L p .707 .577 .707 r
F P
0 g
s
.29804 .63792 m .29804 .65645 L .31064 .66433 L p .707 .577 .707 r
F P
0 g
s
.77805 .62264 m .77805 .65969 L .74688 .65779 L p .707 .577 .707 r
F P
0 g
s
.74688 .65779 m .74688 .62074 L .77805 .62264 L p .707 .577 .707 r
F P
0 g
s
.71504 .62151 m .71504 .65857 L .68566 .66195 L p .707 .577 .707 r
F P
0 g
s
.71504 .64143 m .71504 .65996 L .68566 .66334 L p .707 .577 .707 r
F P
0 g
s
.29804 .62794 m .29804 .57236 L .29515 .56381 L p .707 .577 .707 r
F P
0 g
s
.71504 .65857 m .71504 .62151 L .74688 .62074 L p .707 .577 .707 r
F P
0 g
s
.49196 .62146 m .49196 .65851 L .49904 .65015 L p .707 .577 .707 r
F P
0 g
s
.49904 .65015 m .49904 .61309 L .49196 .62146 L p .707 .577 .707 r
F P
0 g
s
.77805 .64256 m .77805 .66108 L .74688 .65918 L p .707 .577 .707 r
F P
0 g
s
.74688 .65918 m .74688 .64066 L .77805 .64256 L p .707 .577 .707 r
F P
0 g
s
.74688 .62074 m .74688 .65779 L .71504 .65857 L p .707 .577 .707 r
F P
0 g
s
.71504 .65996 m .71504 .64143 L .74688 .64066 L p .707 .577 .707 r
F P
0 g
s
.49196 .64138 m .49196 .65991 L .49904 .65154 L p .707 .577 .707 r
F P
0 g
s
.49904 .65154 m .49904 .63301 L .49196 .64138 L p .707 .577 .707 r
F P
0 g
s
.74688 .64066 m .74688 .65918 L .71504 .65996 L p .707 .577 .707 r
F P
0 g
s
.29804 .65506 m .29804 .618 L .29515 .60946 L p .707 .577 .707 r
F P
0 g
s
.29515 .56381 m .29515 .6194 L .29804 .62794 L p .707 .577 .707 r
F P
0 g
s
.49904 .56745 m .49904 .62303 L .49615 .61449 L p .707 .577 .707 r
F P
0 g
s
.49615 .61449 m .49615 .55891 L .49904 .56745 L p .707 .577 .707 r
F P
0 g
s
.29804 .65645 m .29804 .63792 L .29515 .62938 L p .707 .577 .707 r
F P
0 g
s
.29515 .60946 m .29515 .64651 L .29804 .65506 L p .707 .577 .707 r
F P
0 g
s
.29515 .62938 m .29515 .64791 L .29804 .65645 L p .707 .577 .707 r
F P
0 g
s
.49904 .61309 m .49904 .65015 L .49615 .64161 L p .707 .577 .707 r
F P
0 g
s
.49615 .64161 m .49615 .60455 L .49904 .61309 L p .707 .577 .707 r
F P
0 g
s
.29515 .6194 m .29515 .56381 L .30223 .55545 L p .707 .577 .707 r
F P
0 g
s
.49904 .63301 m .49904 .65154 L .49615 .643 L p .707 .577 .707 r
F P
0 g
s
.49615 .643 m .49615 .62447 L .49904 .63301 L p .707 .577 .707 r
F P
0 g
s
.29515 .64651 m .29515 .60946 L .30223 .60109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55545 m .30223 .61103 L .29515 .6194 L p .707 .577 .707 r
F P
0 g
s
.49615 .55891 m .49615 .61449 L .48356 .6066 L p .707 .577 .707 r
F P
0 g
s
.48356 .6066 m .48356 .55102 L .49615 .55891 L p .707 .577 .707 r
F P
0 g
s
.29515 .64791 m .29515 .62938 L .30223 .62101 L p .707 .577 .707 r
F P
0 g
s
.30223 .60109 m .30223 .63815 L .29515 .64651 L p .707 .577 .707 r
F P
0 g
s
.30223 .62101 m .30223 .63954 L .29515 .64791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61103 m .30223 .55545 L .3186 .54808 L p .707 .577 .707 r
F P
0 g
s
.49615 .60455 m .49615 .64161 L .48356 .63372 L p .707 .577 .707 r
F P
0 g
s
.48356 .63372 m .48356 .59667 L .49615 .60455 L p .707 .577 .707 r
F P
0 g
s
.49615 .62447 m .49615 .643 L .48356 .63511 L p .707 .577 .707 r
F P
0 g
s
.48356 .63511 m .48356 .61659 L .49615 .62447 L p .707 .577 .707 r
F P
0 g
s
.30223 .63815 m .30223 .60109 L .3186 .59373 L p .707 .577 .707 r
F P
0 g
s
.3186 .54808 m .3186 .60366 L .30223 .61103 L p .707 .577 .707 r
F P
0 g
s
.48356 .55102 m .48356 .6066 L .4625 .60015 L p .707 .577 .707 r
F P
0 g
s
.4625 .60015 m .4625 .54457 L .48356 .55102 L p .707 .577 .707 r
F P
0 g
s
.30223 .63954 m .30223 .62101 L .3186 .61365 L p .707 .577 .707 r
F P
0 g
s
.3186 .59373 m .3186 .63078 L .30223 .63815 L p .707 .577 .707 r
F P
0 g
s
.3186 .61365 m .3186 .63217 L .30223 .63954 L p .707 .577 .707 r
F P
0 g
s
.3186 .60366 m .3186 .54808 L .34265 .54243 L p .707 .577 .707 r
F P
0 g
s
.48356 .59667 m .48356 .63372 L .4625 .62727 L p .707 .577 .707 r
F P
0 g
s
.4625 .62727 m .4625 .59021 L .48356 .59667 L p .707 .577 .707 r
F P
0 g
s
.48356 .61659 m .48356 .63511 L .4625 .62866 L p .707 .577 .707 r
F P
0 g
s
.4625 .62866 m .4625 .61013 L .48356 .61659 L p .707 .577 .707 r
F P
0 g
s
.4625 .54457 m .4625 .60015 L .43504 .59576 L p .707 .577 .707 r
F P
0 g
s
.43504 .59576 m .43504 .54018 L .4625 .54457 L p .707 .577 .707 r
F P
0 g
s
.3186 .63078 m .3186 .59373 L .34265 .58808 L p .707 .577 .707 r
F P
0 g
s
.34265 .54243 m .34265 .59801 L .3186 .60366 L p .707 .577 .707 r
F P
0 g
s
.3186 .63217 m .3186 .61365 L .34265 .608 L p .707 .577 .707 r
F P
0 g
s
.34265 .59801 m .34265 .54243 L .37203 .53905 L p .707 .577 .707 r
F P
0 g
s
.34265 .58808 m .34265 .62513 L .3186 .63078 L p .707 .577 .707 r
F P
0 g
s
.34265 .608 m .34265 .62652 L .3186 .63217 L p .707 .577 .707 r
F P
0 g
s
.4625 .59021 m .4625 .62727 L .43504 .62288 L p .707 .577 .707 r
F P
0 g
s
.43504 .62288 m .43504 .58582 L .4625 .59021 L p .707 .577 .707 r
F P
0 g
s
.43504 .54018 m .43504 .59576 L .40387 .59386 L p .707 .577 .707 r
F P
0 g
s
.40387 .59386 m .40387 .53828 L .43504 .54018 L p .707 .577 .707 r
F P
0 g
s
.4625 .61013 m .4625 .62866 L .43504 .62427 L p .707 .577 .707 r
F P
0 g
s
.43504 .62427 m .43504 .60574 L .4625 .61013 L p .707 .577 .707 r
F P
0 g
s
.37203 .59463 m .37203 .53905 L .40387 .53828 L p .707 .577 .707 r
F P
0 g
s
.37203 .53905 m .37203 .59463 L .34265 .59801 L p .707 .577 .707 r
F P
0 g
s
.34265 .62513 m .34265 .58808 L .37203 .5847 L p .707 .577 .707 r
F P
0 g
s
.40387 .53828 m .40387 .59386 L .37203 .59463 L p .707 .577 .707 r
F P
0 g
s
.34265 .62652 m .34265 .608 L .37203 .60462 L p .707 .577 .707 r
F P
0 g
s
.43504 .58582 m .43504 .62288 L .40387 .62097 L p .707 .577 .707 r
F P
0 g
s
.40387 .62097 m .40387 .58392 L .43504 .58582 L p .707 .577 .707 r
F P
0 g
s
.37203 .5847 m .37203 .62175 L .34265 .62513 L p .707 .577 .707 r
F P
0 g
s
.37203 .60462 m .37203 .62315 L .34265 .62652 L p .707 .577 .707 r
F P
0 g
s
.37203 .62175 m .37203 .5847 L .40387 .58392 L p .707 .577 .707 r
F P
0 g
s
.43504 .60574 m .43504 .62427 L .40387 .62237 L p .707 .577 .707 r
F P
0 g
s
.40387 .62237 m .40387 .60384 L .43504 .60574 L p .707 .577 .707 r
F P
0 g
s
.40387 .58392 m .40387 .62097 L .37203 .62175 L p .707 .577 .707 r
F P
0 g
s
.37203 .62315 m .37203 .60462 L .40387 .60384 L p .707 .577 .707 r
F P
0 g
s
.40387 .60384 m .40387 .62237 L .37203 .62315 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF
00UJEP03001JEUYF00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo
0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
3goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
07oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00004FUH40003FUH00`00FUIJEP05FUH>0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF100015YF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol30004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP8000=JEPT000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH4
0006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
03mooaD00003FUH005YF009JEPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001J
EP0000D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02FUH2000]Ool003Uoo`H000=J
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo
000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUH00000FUH005YF
00<00003FUH005YF00IJEQL000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH00000
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF5P000eYF
00<005YFFUH00eYF00<005YFFUH00`00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH20005FUH01000FUIJEUYF1@001eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8002eoo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000300000eYF001JEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1@0015YF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF1@0015YF00<005YF
FUH00UYF1`0000IJEP00000005YF0003FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH015YF1P0015YF3P000eYF00<005YFFUH015YF0`000eYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUH0000H0007
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000200001UYF00000000FUH000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000AJ
EP800003FUH0000000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05
001JEP00001JEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP040002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF
FUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<00003
FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF000015YF00@005YFFUIJEP800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800005FUH0
05YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0015YF4P000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00;Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF1@00
15YF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`04
001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool30004FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200001EYF001JEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD003=oo`00;7oo
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000h
Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90003FUH20004FUH9000oOol002ao
o`<000AJEP03001JEUYF00AJEP8000=JEQT000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YF
FUH01eYF00<005YFFUH015YF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH20007Ool50018Ool002aoo`03
001JEP0000AJEPD000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEP0000D00005
FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH00`00FUH0000200000eYF001JEP02FUH20007Ool50018Ool002aoo`03001JEP00009JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEPD000EJEP<0009JEP04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003
FUH20007Ool50018Ool002aoo`03001JEP0000<00006FUH00000001JEP001UYF60000eYF00<005YF
FUH015YF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH300000eYF00000008Ool30019Ool002aoo`03001JEP00009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP03001DOol002aoo`80009JEP8000EJEP03001JEUYF00<0
009JEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000<0009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@00003FUH005YF00AJ
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00800003FUH005YF00AJEP<000MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP@000=JEP04001JEUYFFUH2001DOol002ao
o`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP0000<00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00@000=JEP8005Aoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF009JEP@000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH20002FUH2001DOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YF00000`00E7oo000_Ool30005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1P00FUH00000Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0035oo`<000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50004FUH01000FUIJEUYF0P00
E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003
0006Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH015YF8@0025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF00<005YF00001@0000=JEP00FUH00UYF0P00E7oo000iOol4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP001EYF00<0
05YFFUH01UYF200035YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000010001EYF0`000eYF0P00E7oo000mOolI000?Ool01000FUIJEP001EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo0018Ool3000JOol01000FUIJEP001EYF00<005YF00000`002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP80
00=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP<00003FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP05001JEP00001JEP03001D
Ool004Moo`D001Uoo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00000UYF00@0
05YFFUIJEPD000=JEP03001JEP0005Aoo`00Agoo1@006Goo00D005YFFUH005YF008000MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH20002FUH00`00FUH000060003FUH00`00FUIJEP02FUH2001EOol004Qoo`<001Yoo`03001J
EUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00005FUH005YFFUH00006FUH00`00FUIJEP02
FUH2001EOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF
FUH00006FUH01000FUIJEUYF0P00EWoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH015YF00@005YF000005Qoo`00IGoo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF0000009JEP04001JEUYFFUH5001JOol006Eoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00L005moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH2001WOol006Moo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001WOol006Qoo`800003
FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8006Qoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Jgoo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YF000006aoo`00KGoo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF1000KWoo001aOol50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05001bOol007Ioo`H0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00=JEPP007Moo`00O7oo2@001UYF00<005YFFUH015YF3000Ogoo
0025Ool=002;Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79468 m .59613 .7391 L .56496 .7372 L p .707 .577 .707 r
F P
0 g
s
.59613 .7391 m .59613 .79468 L .62796 .79391 L p .707 .577 .707 r
F P
0 g
s
.62796 .79391 m .62796 .73832 L .59613 .7391 L p .707 .577 .707 r
F P
0 g
s
.62796 .73832 m .62796 .79391 L .65735 .79053 L p .707 .577 .707 r
F P
0 g
s
.65735 .79053 m .65734 .73494 L .62796 .73832 L p .707 .577 .707 r
F P
0 g
s
.59613 .77765 m .59613 .75912 L .56496 .75722 L p .707 .577 .707 r
F P
0 g
s
.59613 .75912 m .59613 .77765 L .62796 .77687 L p .707 .577 .707 r
F P
0 g
s
.62796 .77687 m .62796 .75835 L .59613 .75912 L p .707 .577 .707 r
F P
0 g
s
.56496 .79278 m .56496 .7372 L .5375 .73281 L p .707 .577 .707 r
F P
0 g
s
.56496 .7372 m .56496 .79278 L .59613 .79468 L p .707 .577 .707 r
F P
0 g
s
.59613 .80125 m .59613 .7642 L .56496 .7623 L p .707 .577 .707 r
F P
0 g
s
.59613 .7642 m .59613 .80125 L .62796 .80048 L p .707 .577 .707 r
F P
0 g
s
.62796 .80048 m .62796 .76342 L .59613 .7642 L p .707 .577 .707 r
F P
0 g
s
.62796 .75835 m .62796 .77687 L .65735 .7735 L p .707 .577 .707 r
F P
0 g
s
.65735 .7735 m .65735 .75497 L .62796 .75835 L p .707 .577 .707 r
F P
0 g
s
.62796 .76342 m .62796 .80048 L .65735 .7971 L p .707 .577 .707 r
F P
0 g
s
.65735 .7971 m .65735 .76004 L .62796 .76342 L p .707 .577 .707 r
F P
0 g
s
.56496 .75722 m .56496 .77575 L .59613 .77765 L p .707 .577 .707 r
F P
0 g
s
.56496 .77575 m .56496 .75722 L .5375 .75283 L p .707 .577 .707 r
F P
0 g
s
.56496 .79935 m .56496 .7623 L .5375 .75791 L p .707 .577 .707 r
F P
0 g
s
.56496 .7623 m .56496 .79935 L .59613 .80125 L p .707 .577 .707 r
F P
0 g
s
.65734 .73494 m .65735 .79053 L .6814 .78488 L p .707 .577 .707 r
F P
0 g
s
.6814 .78488 m .6814 .72929 L .65734 .73494 L p .707 .577 .707 r
F P
0 g
s
.5375 .75283 m .5375 .77136 L .56496 .77575 L p .707 .577 .707 r
F P
0 g
s
.65735 .75497 m .65735 .7735 L .6814 .76785 L p .707 .577 .707 r
F P
0 g
s
.6814 .76785 m .6814 .74932 L .65735 .75497 L p .707 .577 .707 r
F P
0 g
s
.65735 .76004 m .65735 .7971 L .6814 .79145 L p .707 .577 .707 r
F P
0 g
s
.6814 .79145 m .6814 .75439 L .65735 .76004 L p .707 .577 .707 r
F P
0 g
s
.5375 .73281 m .5375 .78839 L .56496 .79278 L p .707 .577 .707 r
F P
0 g
s
.5375 .78839 m .5375 .73281 L .51644 .72635 L p .707 .577 .707 r
F P
0 g
s
.5375 .75791 m .5375 .79496 L .56496 .79935 L p .707 .577 .707 r
F P
0 g
s
.5375 .77136 m .5375 .75283 L .51644 .74638 L p .707 .577 .707 r
F P
0 g
s
.5375 .79496 m .5375 .75791 L .51644 .75145 L p .707 .577 .707 r
F P
0 g
s
.51644 .74638 m .51644 .7649 L .5375 .77136 L p .707 .577 .707 r
F P
0 g
s
.6814 .72929 m .6814 .78488 L .69777 .77751 L p .707 .577 .707 r
F P
0 g
s
.69777 .77751 m .69777 .72193 L .6814 .72929 L p .707 .577 .707 r
F P
0 g
s
.51644 .72635 m .51644 .78194 L .5375 .78839 L p .707 .577 .707 r
F P
0 g
s
.51644 .75145 m .51644 .78851 L .5375 .79496 L p .707 .577 .707 r
F P
0 g
s
.6814 .74932 m .6814 .76785 L .69777 .76048 L p .707 .577 .707 r
F P
0 g
s
.69777 .76048 m .69777 .74195 L .6814 .74932 L p .707 .577 .707 r
F P
0 g
s
.6814 .75439 m .6814 .79145 L .69777 .78408 L p .707 .577 .707 r
F P
0 g
s
.69777 .78408 m .69777 .74702 L .6814 .75439 L p .707 .577 .707 r
F P
0 g
s
.51644 .78194 m .51644 .72635 L .50385 .71847 L p .707 .577 .707 r
F P
0 g
s
.51644 .7649 m .51644 .74638 L .50385 .73849 L p .707 .577 .707 r
F P
0 g
s
.51644 .78851 m .51644 .75145 L .50385 .74357 L p .707 .577 .707 r
F P
0 g
s
.50385 .73849 m .50385 .75702 L .51644 .7649 L p .707 .577 .707 r
F P
0 g
s
.50385 .71847 m .50385 .77405 L .51644 .78194 L p .707 .577 .707 r
F P
0 g
s
.69777 .72193 m .69777 .77751 L .70485 .76914 L p .707 .577 .707 r
F P
0 g
s
.70485 .76914 m .70485 .71356 L .69777 .72193 L p .707 .577 .707 r
F P
0 g
s
.50385 .74357 m .50385 .78062 L .51644 .78851 L p .707 .577 .707 r
F P
0 g
s
.69777 .74195 m .69777 .76048 L .70485 .75211 L p .707 .577 .707 r
F P
0 g
s
.70485 .75211 m .70485 .73359 L .69777 .74195 L p .707 .577 .707 r
F P
0 g
s
.69777 .74702 m .69777 .78408 L .70485 .77572 L p .707 .577 .707 r
F P
0 g
s
.70485 .77572 m .70485 .73866 L .69777 .74702 L p .707 .577 .707 r
F P
0 g
s
.50385 .77405 m .50385 .71847 L .50095 .70993 L p .707 .577 .707 r
F P
0 g
s
.50385 .75702 m .50385 .73849 L .50095 .72995 L p .707 .577 .707 r
F P
0 g
s
.50385 .78062 m .50385 .74357 L .50095 .73503 L p .707 .577 .707 r
F P
0 g
s
.50095 .72995 m .50095 .74848 L .50385 .75702 L p .707 .577 .707 r
F P
0 g
s
.50095 .70993 m .50095 .76551 L .50385 .77405 L p .707 .577 .707 r
F P
0 g
s
.50095 .73503 m .50095 .77208 L .50385 .78062 L p .707 .577 .707 r
F P
0 g
s
.70485 .71356 m .70485 .76914 L .70195 .7606 L p .707 .577 .707 r
F P
0 g
s
.70195 .7606 m .70195 .70502 L .70485 .71356 L p .707 .577 .707 r
F P
0 g
s
.49044 .84741 m .49044 .34552 L .44643 .34284 L p .707 .577 .707 r
F P
0 g
s
.50095 .76551 m .50095 .70993 L .50804 .70156 L p .707 .577 .707 r
F P
0 g
s
.50095 .74848 m .50095 .72995 L .50804 .72159 L p .707 .577 .707 r
F P
0 g
s
.50095 .77208 m .50095 .73503 L .50804 .72666 L p .707 .577 .707 r
F P
0 g
s
.50804 .72159 m .50804 .74011 L .50095 .74848 L p .707 .577 .707 r
F P
0 g
s
.50804 .70156 m .50804 .75715 L .50095 .76551 L p .707 .577 .707 r
F P
0 g
s
.50804 .72666 m .50804 .76372 L .50095 .77208 L p .707 .577 .707 r
F P
0 g
s
.50804 .75715 m .50804 .70156 L .5244 .6942 L p .707 .577 .707 r
F P
0 g
s
.50804 .74011 m .50804 .72159 L .5244 .71422 L p .707 .577 .707 r
F P
0 g
s
.50804 .76372 m .50804 .72666 L .5244 .71929 L p .707 .577 .707 r
F P
0 g
s
.5244 .71422 m .5244 .73275 L .50804 .74011 L p .707 .577 .707 r
F P
0 g
s
.5244 .6942 m .5244 .74978 L .50804 .75715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71929 m .5244 .75635 L .50804 .76372 L p .707 .577 .707 r
F P
0 g
s
.5244 .74978 m .5244 .6942 L .54846 .68855 L p .707 .577 .707 r
F P
0 g
s
.5244 .73275 m .5244 .71422 L .54846 .70857 L p .707 .577 .707 r
F P
0 g
s
.5244 .75635 m .5244 .71929 L .54846 .71364 L p .707 .577 .707 r
F P
0 g
s
.54846 .70857 m .54846 .7271 L .5244 .73275 L p .707 .577 .707 r
F P
0 g
s
.54846 .68855 m .54846 .74413 L .5244 .74978 L p .707 .577 .707 r
F P
0 g
s
.54846 .71364 m .54846 .7507 L .5244 .75635 L p .707 .577 .707 r
F P
0 g
s
.49044 .34552 m .49044 .84741 L .53538 .84631 L p .707 .577 .707 r
F P
0 g
s
.53538 .84631 m .53538 .34442 L .49044 .34552 L p .707 .577 .707 r
F P
0 g
s
.70485 .73359 m .70485 .75211 L .70195 .74357 L p .707 .577 .707 r
F P
0 g
s
.70195 .74357 m .70195 .72504 L .70485 .73359 L p .707 .577 .707 r
F P
0 g
s
.70485 .73866 m .70485 .77572 L .70195 .76717 L p .707 .577 .707 r
F P
0 g
s
.70195 .76717 m .70195 .73012 L .70485 .73866 L p .707 .577 .707 r
F P
0 g
s
.54846 .74413 m .54846 .68855 L .57784 .68517 L p .707 .577 .707 r
F P
0 g
s
.54846 .7271 m .54846 .70857 L .57784 .70519 L p .707 .577 .707 r
F P
0 g
s
.54846 .7507 m .54846 .71364 L .57784 .71026 L p .707 .577 .707 r
F P
0 g
s
.57784 .70519 m .57784 .72372 L .54846 .7271 L p .707 .577 .707 r
F P
0 g
s
.57784 .68517 m .57784 .74075 L .54846 .74413 L p .707 .577 .707 r
F P
0 g
s
.57784 .71026 m .57784 .74732 L .54846 .7507 L p .707 .577 .707 r
F P
0 g
s
.53538 .34442 m .53538 .84631 L .57686 .84154 L p .707 .577 .707 r
F P
0 g
s
.57686 .84154 m .57686 .33965 L .53538 .34442 L p .707 .577 .707 r
F P
0 g
s
.44643 .84473 m .44643 .34284 L .40766 .33664 L p .707 .577 .707 r
F P
0 g
s
.44643 .34284 m .44643 .84473 L .49044 .84741 L p .707 .577 .707 r
F P
0 g
s
.57784 .74075 m .57784 .68517 L .60968 .68439 L p .707 .577 .707 r
F P
0 g
s
.60968 .68439 m .60968 .73997 L .57784 .74075 L p .707 .577 .707 r
F P
0 g
s
.57784 .72372 m .57784 .70519 L .60968 .70441 L p .707 .577 .707 r
F P
0 g
s
.57784 .74732 m .57784 .71026 L .60968 .70949 L p .707 .577 .707 r
F P
0 g
s
.60968 .70441 m .60968 .72294 L .57784 .72372 L p .707 .577 .707 r
F P
0 g
s
.60968 .70949 m .60968 .74654 L .57784 .74732 L p .707 .577 .707 r
F P
0 g
s
.57686 .33965 m .57686 .84154 L .61082 .83357 L p .707 .577 .707 r
F P
0 g
s
.64085 .68629 m .64085 .74187 L .60968 .73997 L p .707 .577 .707 r
F P
0 g
s
.60968 .73997 m .60968 .68439 L .64085 .68629 L p .707 .577 .707 r
F P
0 g
s
.64085 .70631 m .64085 .72484 L .60968 .72294 L p .707 .577 .707 r
F P
0 g
s
.60968 .72294 m .60968 .70441 L .64085 .70631 L p .707 .577 .707 r
F P
0 g
s
.64085 .71139 m .64085 .74844 L .60968 .74654 L p .707 .577 .707 r
F P
0 g
s
.60968 .74654 m .60968 .70949 L .64085 .71139 L p .707 .577 .707 r
F P
0 g
s
.61082 .83357 m .61082 .33168 L .57686 .33965 L p .707 .577 .707 r
F P
0 g
s
.70195 .70502 m .70195 .7606 L .68936 .75272 L p .707 .577 .707 r
F P
0 g
s
.68936 .75272 m .68936 .69714 L .70195 .70502 L p .707 .577 .707 r
F P
0 g
s
.70195 .72504 m .70195 .74357 L .68936 .73569 L p .707 .577 .707 r
F P
0 g
s
.68936 .73569 m .68936 .71716 L .70195 .72504 L p .707 .577 .707 r
F P
0 g
s
.40766 .83852 m .40766 .33664 L .37794 .32752 L p .707 .577 .707 r
F P
0 g
s
.40766 .33664 m .40766 .83852 L .44643 .84473 L p .707 .577 .707 r
F P
0 g
s
.70195 .73012 m .70195 .76717 L .68936 .75929 L p .707 .577 .707 r
F P
0 g
s
.68936 .75929 m .68936 .72223 L .70195 .73012 L p .707 .577 .707 r
F P
0 g
s
.25312 .75787 m .25312 .70229 L .22195 .70038 L p .707 .577 .707 r
F P
0 g
s
.25312 .70229 m .25312 .75787 L .28495 .75709 L p .707 .577 .707 r
F P
0 g
s
.28495 .75709 m .28495 .70151 L .25312 .70229 L p .707 .577 .707 r
F P
0 g
s
.28495 .70151 m .28495 .75709 L .31434 .75371 L p .707 .577 .707 r
F P
0 g
s
.31434 .75371 m .31434 .69813 L .28495 .70151 L p .707 .577 .707 r
F P
0 g
s
.25312 .74084 m .25312 .72231 L .22195 .72041 L p .707 .577 .707 r
F P
0 g
s
.25312 .72231 m .25312 .74084 L .28495 .74006 L p .707 .577 .707 r
F P
0 g
s
.28495 .74006 m .28495 .72153 L .25312 .72231 L p .707 .577 .707 r
F P
0 g
s
.22195 .75597 m .22195 .70038 L .19449 .69599 L p .707 .577 .707 r
F P
0 g
s
.22195 .70038 m .22195 .75597 L .25312 .75787 L p .707 .577 .707 r
F P
0 g
s
.25312 .76444 m .25312 .72738 L .22195 .72548 L p .707 .577 .707 r
F P
0 g
s
.25312 .72738 m .25312 .76444 L .28495 .76366 L p .707 .577 .707 r
F P
0 g
s
.28495 .76366 m .28495 .72661 L .25312 .72738 L p .707 .577 .707 r
F P
0 g
s
.28495 .72153 m .28495 .74006 L .31434 .73668 L p .707 .577 .707 r
F P
0 g
s
.31434 .73668 m .31434 .71815 L .28495 .72153 L p .707 .577 .707 r
F P
0 g
s
.28495 .72661 m .28495 .76366 L .31434 .76028 L p .707 .577 .707 r
F P
0 g
s
.31434 .76028 m .31434 .72323 L .28495 .72661 L p .707 .577 .707 r
F P
0 g
s
.22195 .72041 m .22195 .73894 L .25312 .74084 L p .707 .577 .707 r
F P
0 g
s
.22195 .73894 m .22195 .72041 L .19449 .71602 L p .707 .577 .707 r
F P
0 g
s
.61082 .33168 m .61082 .83357 L .63393 .82316 L p .707 .577 .707 r
F P
0 g
s
.63393 .82316 m .63393 .32128 L .61082 .33168 L p .707 .577 .707 r
F P
0 g
s
.22195 .76254 m .22195 .72548 L .19449 .72109 L p .707 .577 .707 r
F P
0 g
s
.22195 .72548 m .22195 .76254 L .25312 .76444 L p .707 .577 .707 r
F P
0 g
s
.31434 .69813 m .31434 .75371 L .33839 .74806 L p .707 .577 .707 r
F P
0 g
s
.33839 .74806 m .33839 .69248 L .31434 .69813 L p .707 .577 .707 r
F P
0 g
s
.19449 .71602 m .19449 .73454 L .22195 .73894 L p .707 .577 .707 r
F P
0 g
s
.68936 .69714 m .68936 .75272 L .66831 .74626 L p .707 .577 .707 r
F P
0 g
s
.66831 .74626 m .66831 .69068 L .68936 .69714 L p .707 .577 .707 r
F P
0 g
s
.31434 .71815 m .31434 .73668 L .33839 .73103 L p .707 .577 .707 r
F P
0 g
s
.33839 .73103 m .33839 .7125 L .31434 .71815 L p .707 .577 .707 r
F P
0 g
s
.31434 .72323 m .31434 .76028 L .33839 .75463 L p .707 .577 .707 r
F P
0 g
s
.33839 .75463 m .33839 .71758 L .31434 .72323 L p .707 .577 .707 r
F P
0 g
s
.19449 .69599 m .19449 .75157 L .22195 .75597 L p .707 .577 .707 r
F P
0 g
s
.19449 .75157 m .19449 .69599 L .17343 .68954 L p .707 .577 .707 r
F P
0 g
s
.68936 .71716 m .68936 .73569 L .66831 .72923 L p .707 .577 .707 r
F P
0 g
s
.66831 .72923 m .66831 .71071 L .68936 .71716 L p .707 .577 .707 r
F P
0 g
s
.19449 .72109 m .19449 .75815 L .22195 .76254 L p .707 .577 .707 r
F P
0 g
s
.68936 .72223 m .68936 .75929 L .66831 .75284 L p .707 .577 .707 r
F P
0 g
s
.66831 .75284 m .66831 .71578 L .68936 .72223 L p .707 .577 .707 r
F P
0 g
s
.19449 .73454 m .19449 .71602 L .17343 .70956 L p .707 .577 .707 r
F P
0 g
s
.37794 .82941 m .37794 .32752 L .36016 .31639 L p .707 .577 .707 r
F P
0 g
s
.37794 .32752 m .37794 .82941 L .40766 .83852 L p .707 .577 .707 r
F P
0 g
s
.19449 .75815 m .19449 .72109 L .17343 .71464 L p .707 .577 .707 r
F P
0 g
s
.17343 .70956 m .17343 .72809 L .19449 .73454 L p .707 .577 .707 r
F P
0 g
s
.33839 .69248 m .33839 .74806 L .35476 .74069 L p .707 .577 .707 r
F P
0 g
s
.35476 .74069 m .35476 .68511 L .33839 .69248 L p .707 .577 .707 r
F P
0 g
s
.17343 .68954 m .17343 .74512 L .19449 .75157 L p .707 .577 .707 r
F P
0 g
s
.17343 .71464 m .17343 .75169 L .19449 .75815 L p .707 .577 .707 r
F P
0 g
s
.33839 .7125 m .33839 .73103 L .35476 .72366 L p .707 .577 .707 r
F P
0 g
s
.35476 .72366 m .35476 .70514 L .33839 .7125 L p .707 .577 .707 r
F P
0 g
s
.66831 .69068 m .66831 .74626 L .64085 .74187 L p .707 .577 .707 r
F P
0 g
s
.64085 .74187 m .64085 .68629 L .66831 .69068 L p .707 .577 .707 r
F P
0 g
s
.33839 .71758 m .33839 .75463 L .35476 .74726 L p .707 .577 .707 r
F P
0 g
s
.35476 .74726 m .35476 .71021 L .33839 .71758 L p .707 .577 .707 r
F P
0 g
s
.17343 .74512 m .17343 .68954 L .16084 .68165 L p .707 .577 .707 r
F P
0 g
s
.66831 .71071 m .66831 .72923 L .64085 .72484 L p .707 .577 .707 r
F P
0 g
s
.64085 .72484 m .64085 .70631 L .66831 .71071 L p .707 .577 .707 r
F P
0 g
s
.66831 .71578 m .66831 .75284 L .64085 .74844 L p .707 .577 .707 r
F P
0 g
s
.64085 .74844 m .64085 .71139 L .66831 .71578 L p .707 .577 .707 r
F P
0 g
s
.63393 .32128 m .63393 .82316 L .64393 .81136 L p .707 .577 .707 r
F P
0 g
s
.64393 .81136 m .64393 .30947 L .63393 .32128 L p .707 .577 .707 r
F P
0 g
s
.17343 .72809 m .17343 .70956 L .16084 .70168 L p .707 .577 .707 r
F P
0 g
s
.17343 .75169 m .17343 .71464 L .16084 .70675 L p .707 .577 .707 r
F P
0 g
s
.16084 .70168 m .16084 .72021 L .17343 .72809 L p .707 .577 .707 r
F P
0 g
s
.16084 .68165 m .16084 .73724 L .17343 .74512 L p .707 .577 .707 r
F P
0 g
s
.35476 .68511 m .35476 .74069 L .36184 .73233 L p .707 .577 .707 r
F P
0 g
s
.36184 .73233 m .36184 .67675 L .35476 .68511 L p .707 .577 .707 r
F P
0 g
s
.16084 .70675 m .16084 .74381 L .17343 .75169 L p .707 .577 .707 r
F P
0 g
s
.35476 .70514 m .35476 .72366 L .36184 .7153 L p .707 .577 .707 r
F P
0 g
s
.36184 .7153 m .36184 .69677 L .35476 .70514 L p .707 .577 .707 r
F P
0 g
s
.35476 .71021 m .35476 .74726 L .36184 .7389 L p .707 .577 .707 r
F P
0 g
s
.36184 .7389 m .36184 .70185 L .35476 .71021 L p .707 .577 .707 r
F P
0 g
s
.36184 .67675 m .36184 .73233 L .35894 .72379 L p .707 .577 .707 r
F P
0 g
s
.35894 .72379 m .35894 .66821 L .36184 .67675 L p .707 .577 .707 r
F P
0 g
s
.36184 .69677 m .36184 .7153 L .35894 .70676 L p .707 .577 .707 r
F P
0 g
s
.35894 .70676 m .35894 .68823 L .36184 .69677 L p .707 .577 .707 r
F P
0 g
s
.36184 .70185 m .36184 .7389 L .35894 .73036 L p .707 .577 .707 r
F P
0 g
s
.35894 .73036 m .35894 .6933 L .36184 .70185 L p .707 .577 .707 r
F P
0 g
s
.36016 .81828 m .36016 .31639 L .35607 .30433 L p .707 .577 .707 r
F P
0 g
s
.36016 .31639 m .36016 .81828 L .37794 .82941 L p .707 .577 .707 r
F P
0 g
s
.16084 .73724 m .16084 .68165 L .15794 .67311 L p .707 .577 .707 r
F P
0 g
s
.16084 .72021 m .16084 .70168 L .15794 .69314 L p .707 .577 .707 r
F P
0 g
s
.16084 .74381 m .16084 .70675 L .15794 .69821 L p .707 .577 .707 r
F P
0 g
s
.15794 .69314 m .15794 .71166 L .16084 .72021 L p .707 .577 .707 r
F P
0 g
s
.15794 .67311 m .15794 .72869 L .16084 .73724 L p .707 .577 .707 r
F P
0 g
s
.15794 .69821 m .15794 .73526 L .16084 .74381 L p .707 .577 .707 r
F P
0 g
s
.64393 .30947 m .64393 .81136 L .63984 .7993 L p .707 .577 .707 r
F P
0 g
s
.63984 .7993 m .63984 .29741 L .64393 .30947 L p .707 .577 .707 r
F P
0 g
s
.15794 .72869 m .15794 .67311 L .16503 .66475 L p .707 .577 .707 r
F P
0 g
s
.15794 .71166 m .15794 .69314 L .16503 .68477 L p .707 .577 .707 r
F P
0 g
s
.15794 .73526 m .15794 .69821 L .16503 .68985 L p .707 .577 .707 r
F P
0 g
s
.35894 .66821 m .35894 .72379 L .34635 .7159 L p .707 .577 .707 r
F P
0 g
s
.34635 .7159 m .34635 .66032 L .35894 .66821 L p .707 .577 .707 r
F P
0 g
s
.35894 .68823 m .35894 .70676 L .34635 .69887 L p .707 .577 .707 r
F P
0 g
s
.34635 .69887 m .34635 .68034 L .35894 .68823 L p .707 .577 .707 r
F P
0 g
s
.35894 .6933 m .35894 .73036 L .34635 .72247 L p .707 .577 .707 r
F P
0 g
s
.34635 .72247 m .34635 .68542 L .35894 .6933 L p .707 .577 .707 r
F P
0 g
s
.35607 .30433 m .35607 .80622 L .36016 .81828 L p .707 .577 .707 r
F P
0 g
s
.35607 .80622 m .35607 .30433 L .36607 .29253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .68477 m .16503 .7033 L .15794 .71166 L p .707 .577 .707 r
F P
0 g
s
.16503 .66475 m .16503 .72033 L .15794 .72869 L p .707 .577 .707 r
F P
0 g
s
.16503 .68985 m .16503 .7269 L .15794 .73526 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72033 m .16503 .66475 L .1814 .65738 L p .707 .577 .707 r
F P
0 g
s
.63984 .29741 m .63984 .7993 L .62206 .78817 L p .707 .577 .707 r
F P
0 g
s
.62206 .78817 m .62206 .28628 L .63984 .29741 L p .707 .577 .707 r
F P
0 g
s
.16503 .7033 m .16503 .68477 L .1814 .6774 L p .707 .577 .707 r
F P
0 g
s
.16503 .7269 m .16503 .68985 L .1814 .68248 L p .707 .577 .707 r
F P
0 g
s
.1814 .6774 m .1814 .69593 L .16503 .7033 L p .707 .577 .707 r
F P
0 g
s
.1814 .65738 m .1814 .71296 L .16503 .72033 L p .707 .577 .707 r
F P
0 g
s
.34635 .66032 m .34635 .7159 L .3253 .70945 L p .707 .577 .707 r
F P
0 g
s
.3253 .70945 m .3253 .65387 L .34635 .66032 L p .707 .577 .707 r
F P
0 g
s
.1814 .68248 m .1814 .71953 L .16503 .7269 L p .707 .577 .707 r
F P
0 g
s
.36607 .79441 m .36607 .29253 L .38918 .28212 L p .707 .577 .707 r
F P
0 g
s
.36607 .29253 m .36607 .79441 L .35607 .80622 L p .707 .577 .707 r
F P
0 g
s
.34635 .68034 m .34635 .69887 L .3253 .69242 L p .707 .577 .707 r
F P
0 g
s
.3253 .69242 m .3253 .67389 L .34635 .68034 L p .707 .577 .707 r
F P
0 g
s
.34635 .68542 m .34635 .72247 L .3253 .71602 L p .707 .577 .707 r
F P
0 g
s
.3253 .71602 m .3253 .67896 L .34635 .68542 L p .707 .577 .707 r
F P
0 g
s
.1814 .71296 m .1814 .65738 L .20545 .65173 L p .707 .577 .707 r
F P
0 g
s
.1814 .69593 m .1814 .6774 L .20545 .67175 L p .707 .577 .707 r
F P
0 g
s
.1814 .71953 m .1814 .68248 L .20545 .67683 L p .707 .577 .707 r
F P
0 g
s
.20545 .67175 m .20545 .69028 L .1814 .69593 L p .707 .577 .707 r
F P
0 g
s
.3253 .65387 m .3253 .70945 L .29784 .70506 L p .707 .577 .707 r
F P
0 g
s
.29784 .70506 m .29784 .64947 L .3253 .65387 L p .707 .577 .707 r
F P
0 g
s
.62206 .28628 m .62206 .78817 L .59233 .77905 L p .707 .577 .707 r
F P
0 g
s
.59233 .77905 m .59233 .27716 L .62206 .28628 L p .707 .577 .707 r
F P
0 g
s
.20545 .65173 m .20545 .70731 L .1814 .71296 L p .707 .577 .707 r
F P
0 g
s
.20545 .67683 m .20545 .71388 L .1814 .71953 L p .707 .577 .707 r
F P
0 g
s
.3253 .67389 m .3253 .69242 L .29784 .68803 L p .707 .577 .707 r
F P
0 g
s
.29784 .68803 m .29784 .6695 L .3253 .67389 L p .707 .577 .707 r
F P
0 g
s
.3253 .67896 m .3253 .71602 L .29784 .71163 L p .707 .577 .707 r
F P
0 g
s
.29784 .71163 m .29784 .67457 L .3253 .67896 L p .707 .577 .707 r
F P
0 g
s
.20545 .70731 m .20545 .65173 L .23483 .64835 L p .707 .577 .707 r
F P
0 g
s
.20545 .69028 m .20545 .67175 L .23483 .66838 L p .707 .577 .707 r
F P
0 g
s
.20545 .71388 m .20545 .67683 L .23483 .67345 L p .707 .577 .707 r
F P
0 g
s
.29784 .64947 m .29784 .70506 L .26667 .70316 L p .707 .577 .707 r
F P
0 g
s
.26667 .70316 m .26667 .64757 L .29784 .64947 L p .707 .577 .707 r
F P
0 g
s
.38918 .28212 m .38918 .78401 L .36607 .79441 L p .707 .577 .707 r
F P
0 g
s
.38918 .78401 m .38918 .28212 L .42314 .27415 L p .707 .577 .707 r
F P
0 g
s
.23483 .66838 m .23483 .6869 L .20545 .69028 L p .707 .577 .707 r
F P
0 g
s
.23483 .70393 m .23483 .64835 L .26667 .64757 L p .707 .577 .707 r
F P
0 g
s
.23483 .64835 m .23483 .70393 L .20545 .70731 L p .707 .577 .707 r
F P
0 g
s
.29784 .6695 m .29784 .68803 L .26667 .68613 L p .707 .577 .707 r
F P
0 g
s
.26667 .68613 m .26667 .6676 L .29784 .6695 L p .707 .577 .707 r
F P
0 g
s
.26667 .64757 m .26667 .70316 L .23483 .70393 L p .707 .577 .707 r
F P
0 g
s
.29784 .67457 m .29784 .71163 L .26667 .70973 L p .707 .577 .707 r
F P
0 g
s
.26667 .70973 m .26667 .67267 L .29784 .67457 L p .707 .577 .707 r
F P
0 g
s
.73333 .70264 m .73333 .64706 L .70216 .64516 L p .707 .577 .707 r
F P
0 g
s
.73333 .64706 m .73333 .70264 L .76517 .70187 L p .707 .577 .707 r
F P
0 g
s
.76517 .70187 m .76517 .64629 L .73333 .64706 L p .707 .577 .707 r
F P
0 g
s
.23483 .67345 m .23483 .7105 L .20545 .71388 L p .707 .577 .707 r
F P
0 g
s
.23483 .6869 m .23483 .66838 L .26667 .6676 L p .707 .577 .707 r
F P
0 g
s
.23483 .7105 m .23483 .67345 L .26667 .67267 L p .707 .577 .707 r
F P
0 g
s
.76517 .64629 m .76517 .70187 L .79455 .69849 L p .707 .577 .707 r
F P
0 g
s
.79455 .69849 m .79455 .64291 L .76517 .64629 L p .707 .577 .707 r
F P
0 g
s
.26667 .6676 m .26667 .68613 L .23483 .6869 L p .707 .577 .707 r
F P
0 g
s
.26667 .67267 m .26667 .70973 L .23483 .7105 L p .707 .577 .707 r
F P
0 g
s
.73333 .68561 m .73333 .66709 L .70216 .66519 L p .707 .577 .707 r
F P
0 g
s
.73333 .66709 m .73333 .68561 L .76517 .68484 L p .707 .577 .707 r
F P
0 g
s
.76517 .68484 m .76517 .66631 L .73333 .66709 L p .707 .577 .707 r
F P
0 g
s
.70216 .70074 m .70216 .64516 L .6747 .64077 L p .707 .577 .707 r
F P
0 g
s
.70216 .64516 m .70216 .70074 L .73333 .70264 L p .707 .577 .707 r
F P
0 g
s
.73333 .70922 m .73333 .67216 L .70216 .67026 L p .707 .577 .707 r
F P
0 g
s
.73333 .67216 m .73333 .70922 L .76517 .70844 L p .707 .577 .707 r
F P
0 g
s
.76517 .70844 m .76517 .67138 L .73333 .67216 L p .707 .577 .707 r
F P
0 g
s
.76517 .66631 m .76517 .68484 L .79455 .68146 L p .707 .577 .707 r
F P
0 g
s
.79455 .68146 m .79455 .66293 L .76517 .66631 L p .707 .577 .707 r
F P
0 g
s
.76517 .67138 m .76517 .70844 L .79455 .70506 L p .707 .577 .707 r
F P
0 g
s
.79455 .70506 m .79455 .668 L .76517 .67138 L p .707 .577 .707 r
F P
0 g
s
.70216 .66519 m .70216 .68371 L .73333 .68561 L p .707 .577 .707 r
F P
0 g
s
.59233 .27716 m .59233 .77905 L .55357 .77285 L p .707 .577 .707 r
F P
0 g
s
.55357 .77285 m .55357 .27096 L .59233 .27716 L p .707 .577 .707 r
F P
0 g
s
.70216 .68371 m .70216 .66519 L .6747 .66079 L p .707 .577 .707 r
F P
0 g
s
.70216 .70731 m .70216 .67026 L .6747 .66587 L p .707 .577 .707 r
F P
0 g
s
.70216 .67026 m .70216 .70731 L .73333 .70922 L p .707 .577 .707 r
F P
0 g
s
.79455 .64291 m .79455 .69849 L .8186 .69284 L p .707 .577 .707 r
F P
0 g
s
.8186 .69284 m .8186 .63726 L .79455 .64291 L p .707 .577 .707 r
F P
0 g
s
.6747 .66079 m .6747 .67932 L .70216 .68371 L p .707 .577 .707 r
F P
0 g
s
.79455 .66293 m .79455 .68146 L .8186 .67581 L p .707 .577 .707 r
F P
0 g
s
.8186 .67581 m .8186 .65728 L .79455 .66293 L p .707 .577 .707 r
F P
0 g
s
.42314 .77604 m .42314 .27415 L .46462 .26938 L p .707 .577 .707 r
F P
0 g
s
.42314 .27415 m .42314 .77604 L .38918 .78401 L p .707 .577 .707 r
F P
0 g
s
.79455 .668 m .79455 .70506 L .8186 .69941 L p .707 .577 .707 r
F P
0 g
s
.8186 .69941 m .8186 .66235 L .79455 .668 L p .707 .577 .707 r
F P
0 g
s
.6747 .64077 m .6747 .69635 L .70216 .70074 L p .707 .577 .707 r
F P
0 g
s
.6747 .69635 m .6747 .64077 L .65365 .63432 L p .707 .577 .707 r
F P
0 g
s
.6747 .66587 m .6747 .70292 L .70216 .70731 L p .707 .577 .707 r
F P
0 g
s
.6747 .67932 m .6747 .66079 L .65365 .65434 L p .707 .577 .707 r
F P
0 g
s
.6747 .70292 m .6747 .66587 L .65365 .65941 L p .707 .577 .707 r
F P
0 g
s
.55357 .27096 m .55357 .77285 L .50956 .77017 L p .707 .577 .707 r
F P
0 g
s
.50956 .77017 m .50956 .26828 L .55357 .27096 L p .707 .577 .707 r
F P
0 g
s
.65365 .65434 m .65365 .67287 L .6747 .67932 L p .707 .577 .707 r
F P
0 g
s
.8186 .63726 m .8186 .69284 L .83497 .68547 L p .707 .577 .707 r
F P
0 g
s
.83497 .68547 m .83497 .62989 L .8186 .63726 L p .707 .577 .707 r
F P
0 g
s
.65365 .63432 m .65365 .6899 L .6747 .69635 L p .707 .577 .707 r
F P
0 g
s
.46462 .77127 m .46462 .26938 L .50956 .26828 L p .707 .577 .707 r
F P
0 g
s
.46462 .26938 m .46462 .77127 L .42314 .77604 L p .707 .577 .707 r
F P
0 g
s
.65365 .65941 m .65365 .69647 L .6747 .70292 L p .707 .577 .707 r
F P
0 g
s
.8186 .65728 m .8186 .67581 L .83497 .66844 L p .707 .577 .707 r
F P
0 g
s
.83497 .66844 m .83497 .64991 L .8186 .65728 L p .707 .577 .707 r
F P
0 g
s
.8186 .66235 m .8186 .69941 L .83497 .69204 L p .707 .577 .707 r
F P
0 g
s
.83497 .69204 m .83497 .65499 L .8186 .66235 L p .707 .577 .707 r
F P
0 g
s
.50956 .26828 m .50956 .77017 L .46462 .77127 L p .707 .577 .707 r
F P
0 g
s
.65365 .6899 m .65365 .63432 L .64105 .62643 L p .707 .577 .707 r
F P
0 g
s
.65365 .67287 m .65365 .65434 L .64105 .64646 L p .707 .577 .707 r
F P
0 g
s
.65365 .69647 m .65365 .65941 L .64105 .65153 L p .707 .577 .707 r
F P
0 g
s
.64105 .64646 m .64105 .66498 L .65365 .67287 L p .707 .577 .707 r
F P
0 g
s
.64105 .62643 m .64105 .68201 L .65365 .6899 L p .707 .577 .707 r
F P
0 g
s
.83497 .62989 m .83497 .68547 L .84206 .67711 L p .707 .577 .707 r
F P
0 g
s
.84206 .67711 m .84205 .62152 L .83497 .62989 L p .707 .577 .707 r
F P
0 g
s
.64105 .65153 m .64105 .68858 L .65365 .69647 L p .707 .577 .707 r
F P
0 g
s
.83497 .64991 m .83497 .66844 L .84205 .66008 L p .707 .577 .707 r
F P
0 g
s
.84205 .66008 m .84205 .64155 L .83497 .64991 L p .707 .577 .707 r
F P
0 g
s
.83497 .65499 m .83497 .69204 L .84206 .68368 L p .707 .577 .707 r
F P
0 g
s
.84206 .68368 m .84205 .64662 L .83497 .65499 L p .707 .577 .707 r
F P
0 g
s
.64105 .68201 m .64105 .62643 L .63816 .61789 L p .707 .577 .707 r
F P
0 g
s
.64105 .66498 m .64105 .64646 L .63816 .63791 L p .707 .577 .707 r
F P
0 g
s
.64105 .68858 m .64105 .65153 L .63816 .64299 L p .707 .577 .707 r
F P
0 g
s
.63816 .63791 m .63816 .65644 L .64105 .66498 L p .707 .577 .707 r
F P
0 g
s
.63816 .61789 m .63816 .67347 L .64105 .68201 L p .707 .577 .707 r
F P
0 g
s
.63816 .64299 m .63816 .68004 L .64105 .68858 L p .707 .577 .707 r
F P
0 g
s
.84205 .62152 m .84206 .67711 L .83916 .66856 L p .707 .577 .707 r
F P
0 g
s
.83916 .66856 m .83916 .61298 L .84205 .62152 L p .707 .577 .707 r
F P
0 g
s
.84205 .64155 m .84205 .66008 L .83916 .65153 L p .707 .577 .707 r
F P
0 g
s
.83916 .65153 m .83916 .63301 L .84205 .64155 L p .707 .577 .707 r
F P
0 g
s
.84205 .64662 m .84206 .68368 L .83916 .67513 L p .707 .577 .707 r
F P
0 g
s
.83916 .67513 m .83916 .63808 L .84205 .64662 L p .707 .577 .707 r
F P
0 g
s
.63816 .67347 m .63816 .61789 L .64524 .60952 L p .707 .577 .707 r
F P
0 g
s
.63816 .65644 m .63816 .63791 L .64524 .62955 L p .707 .577 .707 r
F P
0 g
s
.63816 .68004 m .63816 .64299 L .64524 .63462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .62955 m .64524 .64808 L .63816 .65644 L p .707 .577 .707 r
F P
0 g
s
.64524 .60952 m .64524 .66511 L .63816 .67347 L p .707 .577 .707 r
F P
0 g
s
.64524 .63462 m .64524 .67168 L .63816 .68004 L p .707 .577 .707 r
F P
0 g
s
.83916 .61298 m .83916 .66856 L .82657 .66068 L p .707 .577 .707 r
F P
0 g
s
.82657 .66068 m .82657 .6051 L .83916 .61298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63301 m .83916 .65153 L .82657 .64365 L p .707 .577 .707 r
F P
0 g
s
.82657 .64365 m .82657 .62512 L .83916 .63301 L p .707 .577 .707 r
F P
0 g
s
.83916 .63808 m .83916 .67513 L .82657 .66725 L p .707 .577 .707 r
F P
0 g
s
.82657 .66725 m .82657 .6302 L .83916 .63808 L p .707 .577 .707 r
F P
0 g
s
.39032 .66583 m .39032 .61025 L .35915 .60835 L p .707 .577 .707 r
F P
0 g
s
.39032 .61025 m .39032 .66583 L .42216 .66505 L p .707 .577 .707 r
F P
0 g
s
.42216 .66505 m .42216 .60947 L .39032 .61025 L p .707 .577 .707 r
F P
0 g
s
.64524 .66511 m .64524 .60952 L .66161 .60216 L p .707 .577 .707 r
F P
0 g
s
.42216 .60947 m .42216 .66505 L .45154 .66167 L p .707 .577 .707 r
F P
0 g
s
.45154 .66167 m .45154 .60609 L .42216 .60947 L p .707 .577 .707 r
F P
0 g
s
.39032 .6488 m .39032 .63027 L .35915 .62837 L p .707 .577 .707 r
F P
0 g
s
.39032 .63027 m .39032 .6488 L .42216 .64802 L p .707 .577 .707 r
F P
0 g
s
.42216 .64802 m .42216 .62949 L .39032 .63027 L p .707 .577 .707 r
F P
0 g
s
.35915 .66393 m .35915 .60835 L .33169 .60395 L p .707 .577 .707 r
F P
0 g
s
.35915 .60835 m .35915 .66393 L .39032 .66583 L p .707 .577 .707 r
F P
0 g
s
.39032 .6724 m .39032 .63534 L .35915 .63344 L p .707 .577 .707 r
F P
0 g
s
.39032 .63534 m .39032 .6724 L .42216 .67162 L p .707 .577 .707 r
F P
0 g
s
.42216 .67162 m .42216 .63457 L .39032 .63534 L p .707 .577 .707 r
F P
0 g
s
.64524 .64808 m .64524 .62955 L .66161 .62218 L p .707 .577 .707 r
F P
0 g
s
.42216 .62949 m .42216 .64802 L .45154 .64464 L p .707 .577 .707 r
F P
0 g
s
.45154 .64464 m .45154 .62611 L .42216 .62949 L p .707 .577 .707 r
F P
0 g
s
.64524 .67168 m .64524 .63462 L .66161 .62725 L p .707 .577 .707 r
F P
0 g
s
.42216 .63457 m .42216 .67162 L .45154 .66824 L p .707 .577 .707 r
F P
0 g
s
.45154 .66824 m .45154 .63119 L .42216 .63457 L p .707 .577 .707 r
F P
0 g
s
.35915 .62837 m .35915 .6469 L .39032 .6488 L p .707 .577 .707 r
F P
0 g
s
.35915 .6469 m .35915 .62837 L .33169 .62398 L p .707 .577 .707 r
F P
0 g
s
.66161 .62218 m .66161 .64071 L .64524 .64808 L p .707 .577 .707 r
F P
0 g
s
.35915 .6705 m .35915 .63344 L .33169 .62905 L p .707 .577 .707 r
F P
0 g
s
.35915 .63344 m .35915 .6705 L .39032 .6724 L p .707 .577 .707 r
F P
0 g
s
.45154 .60609 m .45154 .66167 L .47559 .65602 L p .707 .577 .707 r
F P
0 g
s
.47559 .65602 m .47559 .60044 L .45154 .60609 L p .707 .577 .707 r
F P
0 g
s
.33169 .62398 m .33169 .64251 L .35915 .6469 L p .707 .577 .707 r
F P
0 g
s
.66161 .60216 m .66161 .65774 L .64524 .66511 L p .707 .577 .707 r
F P
0 g
s
.82657 .6051 m .82657 .66068 L .80551 .65423 L p .707 .577 .707 r
F P
0 g
s
.80551 .65423 m .80551 .59864 L .82657 .6051 L p .707 .577 .707 r
F P
0 g
s
.66161 .62725 m .66161 .66431 L .64524 .67168 L p .707 .577 .707 r
F P
0 g
s
.45154 .62611 m .45154 .64464 L .47559 .63899 L p .707 .577 .707 r
F P
0 g
s
.47559 .63899 m .47559 .62046 L .45154 .62611 L p .707 .577 .707 r
F P
0 g
s
.45154 .63119 m .45154 .66824 L .47559 .66259 L p .707 .577 .707 r
F P
0 g
s
.47559 .66259 m .47559 .62554 L .45154 .63119 L p .707 .577 .707 r
F P
0 g
s
.33169 .60395 m .33169 .65954 L .35915 .66393 L p .707 .577 .707 r
F P
0 g
s
.33169 .65954 m .33169 .60395 L .31064 .5975 L p .707 .577 .707 r
F P
0 g
s
.82657 .62512 m .82657 .64365 L .80551 .6372 L p .707 .577 .707 r
F P
0 g
s
.80551 .6372 m .80551 .61867 L .82657 .62512 L p .707 .577 .707 r
F P
0 g
s
.33169 .62905 m .33169 .66611 L .35915 .6705 L p .707 .577 .707 r
F P
0 g
s
.82657 .6302 m .82657 .66725 L .80551 .6608 L p .707 .577 .707 r
F P
0 g
s
.80551 .6608 m .80551 .62374 L .82657 .6302 L p .707 .577 .707 r
F P
0 g
s
.33169 .64251 m .33169 .62398 L .31064 .61752 L p .707 .577 .707 r
F P
0 g
s
.66161 .65774 m .66161 .60216 L .68566 .59651 L p .707 .577 .707 r
F P
0 g
s
.33169 .66611 m .33169 .62905 L .31064 .6226 L p .707 .577 .707 r
F P
0 g
s
.31064 .61752 m .31064 .63605 L .33169 .64251 L p .707 .577 .707 r
F P
0 g
s
.66161 .64071 m .66161 .62218 L .68566 .61653 L p .707 .577 .707 r
F P
0 g
s
.47559 .60044 m .47559 .65602 L .49196 .64866 L p .707 .577 .707 r
F P
0 g
s
.49196 .64866 m .49196 .59307 L .47559 .60044 L p .707 .577 .707 r
F P
0 g
s
.66161 .66431 m .66161 .62725 L .68566 .62161 L p .707 .577 .707 r
F P
0 g
s
.31064 .5975 m .31064 .65308 L .33169 .65954 L p .707 .577 .707 r
F P
0 g
s
.68566 .61653 m .68566 .63506 L .66161 .64071 L p .707 .577 .707 r
F P
0 g
s
.31064 .6226 m .31064 .65965 L .33169 .66611 L p .707 .577 .707 r
F P
0 g
s
.47559 .62046 m .47559 .63899 L .49196 .63162 L p .707 .577 .707 r
F P
0 g
s
.49196 .63162 m .49196 .6131 L .47559 .62046 L p .707 .577 .707 r
F P
0 g
s
.80551 .59864 m .80551 .65423 L .77805 .64983 L p .707 .577 .707 r
F P
0 g
s
.77805 .64983 m .77805 .59425 L .80551 .59864 L p .707 .577 .707 r
F P
0 g
s
.47559 .62554 m .47559 .66259 L .49196 .65523 L p .707 .577 .707 r
F P
0 g
s
.49196 .65523 m .49196 .61817 L .47559 .62554 L p .707 .577 .707 r
F P
0 g
s
.68566 .59651 m .68566 .65209 L .66161 .65774 L p .707 .577 .707 r
F P
0 g
s
.31064 .65308 m .31064 .5975 L .29804 .58962 L p .707 .577 .707 r
F P
0 g
s
.68566 .62161 m .68566 .65866 L .66161 .66431 L p .707 .577 .707 r
F P
0 g
s
.80551 .61867 m .80551 .6372 L .77805 .6328 L p .707 .577 .707 r
F P
0 g
s
.77805 .6328 m .77805 .61428 L .80551 .61867 L p .707 .577 .707 r
F P
0 g
s
.80551 .62374 m .80551 .6608 L .77805 .6564 L p .707 .577 .707 r
F P
0 g
s
.77805 .6564 m .77805 .61935 L .80551 .62374 L p .707 .577 .707 r
F P
0 g
s
.68566 .65209 m .68566 .59651 L .71504 .59313 L p .707 .577 .707 r
F P
0 g
s
.31064 .63605 m .31064 .61752 L .29804 .60964 L p .707 .577 .707 r
F P
0 g
s
.31064 .65965 m .31064 .6226 L .29804 .61471 L p .707 .577 .707 r
F P
0 g
s
.68566 .63506 m .68566 .61653 L .71504 .61315 L p .707 .577 .707 r
F P
0 g
s
.68566 .65866 m .68566 .62161 L .71504 .61823 L p .707 .577 .707 r
F P
0 g
s
.29804 .60964 m .29804 .62817 L .31064 .63605 L p .707 .577 .707 r
F P
0 g
s
.77805 .59425 m .77805 .64983 L .74688 .64793 L p .707 .577 .707 r
F P
0 g
s
.74688 .64793 m .74688 .59235 L .77805 .59425 L p .707 .577 .707 r
F P
0 g
s
.71504 .61315 m .71504 .63168 L .68566 .63506 L p .707 .577 .707 r
F P
0 g
s
.29804 .58962 m .29804 .6452 L .31064 .65308 L p .707 .577 .707 r
F P
0 g
s
.71504 .64871 m .71504 .59313 L .74688 .59235 L p .707 .577 .707 r
F P
0 g
s
.71504 .59313 m .71504 .64871 L .68566 .65209 L p .707 .577 .707 r
F P
0 g
s
.49196 .59307 m .49196 .64866 L .49904 .64029 L p .707 .577 .707 r
F P
0 g
s
.49904 .64029 m .49904 .58471 L .49196 .59307 L p .707 .577 .707 r
F P
0 g
s
.77805 .61428 m .77805 .6328 L .74688 .6309 L p .707 .577 .707 r
F P
0 g
s
.74688 .6309 m .74688 .61237 L .77805 .61428 L p .707 .577 .707 r
F P
0 g
s
.29804 .61471 m .29804 .65177 L .31064 .65965 L p .707 .577 .707 r
F P
0 g
s
.74688 .59235 m .74688 .64793 L .71504 .64871 L p .707 .577 .707 r
F P
0 g
s
.77805 .61935 m .77805 .6564 L .74688 .6545 L p .707 .577 .707 r
F P
0 g
s
.74688 .6545 m .74688 .61745 L .77805 .61935 L p .707 .577 .707 r
F P
0 g
s
.71504 .61823 m .71504 .65528 L .68566 .65866 L p .707 .577 .707 r
F P
0 g
s
.71504 .63168 m .71504 .61315 L .74688 .61237 L p .707 .577 .707 r
F P
0 g
s
.49196 .6131 m .49196 .63162 L .49904 .62326 L p .707 .577 .707 r
F P
0 g
s
.49904 .62326 m .49904 .60473 L .49196 .6131 L p .707 .577 .707 r
F P
0 g
s
.71504 .65528 m .71504 .61823 L .74688 .61745 L p .707 .577 .707 r
F P
0 g
s
.49196 .61817 m .49196 .65523 L .49904 .64686 L p .707 .577 .707 r
F P
0 g
s
.49904 .64686 m .49904 .60981 L .49196 .61817 L p .707 .577 .707 r
F P
0 g
s
.74688 .61237 m .74688 .6309 L .71504 .63168 L p .707 .577 .707 r
F P
0 g
s
.74688 .61745 m .74688 .6545 L .71504 .65528 L p .707 .577 .707 r
F P
0 g
s
.29804 .6452 m .29804 .58962 L .29515 .58107 L p .707 .577 .707 r
F P
0 g
s
.29804 .62817 m .29804 .60964 L .29515 .6011 L p .707 .577 .707 r
F P
0 g
s
.29804 .65177 m .29804 .61471 L .29515 .60617 L p .707 .577 .707 r
F P
0 g
s
.29515 .6011 m .29515 .61962 L .29804 .62817 L p .707 .577 .707 r
F P
0 g
s
.29515 .58107 m .29515 .63666 L .29804 .6452 L p .707 .577 .707 r
F P
0 g
s
.29515 .60617 m .29515 .64323 L .29804 .65177 L p .707 .577 .707 r
F P
0 g
s
.49904 .58471 m .49904 .64029 L .49615 .63175 L p .707 .577 .707 r
F P
0 g
s
.49615 .63175 m .49615 .57617 L .49904 .58471 L p .707 .577 .707 r
F P
0 g
s
.49904 .60473 m .49904 .62326 L .49615 .61472 L p .707 .577 .707 r
F P
0 g
s
.49615 .61472 m .49615 .59619 L .49904 .60473 L p .707 .577 .707 r
F P
0 g
s
.49904 .60981 m .49904 .64686 L .49615 .63832 L p .707 .577 .707 r
F P
0 g
s
.49615 .63832 m .49615 .60126 L .49904 .60981 L p .707 .577 .707 r
F P
0 g
s
.29515 .63666 m .29515 .58107 L .30223 .57271 L p .707 .577 .707 r
F P
0 g
s
.29515 .61962 m .29515 .6011 L .30223 .59273 L p .707 .577 .707 r
F P
0 g
s
.29515 .64323 m .29515 .60617 L .30223 .59781 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .59273 m .30223 .61126 L .29515 .61962 L p .707 .577 .707 r
F P
0 g
s
.30223 .57271 m .30223 .62829 L .29515 .63666 L p .707 .577 .707 r
F P
0 g
s
.30223 .59781 m .30223 .63486 L .29515 .64323 L p .707 .577 .707 r
F P
0 g
s
.49615 .57617 m .49615 .63175 L .48356 .62386 L p .707 .577 .707 r
F P
0 g
s
.48356 .62386 m .48356 .56828 L .49615 .57617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .59619 m .49615 .61472 L .48356 .60683 L p .707 .577 .707 r
F P
0 g
s
.48356 .60683 m .48356 .58831 L .49615 .59619 L p .707 .577 .707 r
F P
0 g
s
.49615 .60126 m .49615 .63832 L .48356 .63044 L p .707 .577 .707 r
F P
0 g
s
.48356 .63044 m .48356 .59338 L .49615 .60126 L p .707 .577 .707 r
F P
0 g
s
.30223 .62829 m .30223 .57271 L .3186 .56534 L p .707 .577 .707 r
F P
0 g
s
.30223 .61126 m .30223 .59273 L .3186 .58537 L p .707 .577 .707 r
F P
0 g
s
.30223 .63486 m .30223 .59781 L .3186 .59044 L p .707 .577 .707 r
F P
0 g
s
.3186 .58537 m .3186 .60389 L .30223 .61126 L p .707 .577 .707 r
F P
0 g
s
.3186 .56534 m .3186 .62092 L .30223 .62829 L p .707 .577 .707 r
F P
0 g
s
.48356 .56828 m .48356 .62386 L .4625 .61741 L p .707 .577 .707 r
F P
0 g
s
.4625 .61741 m .4625 .56183 L .48356 .56828 L p .707 .577 .707 r
F P
0 g
s
.3186 .59044 m .3186 .62749 L .30223 .63486 L p .707 .577 .707 r
F P
0 g
s
.48356 .58831 m .48356 .60683 L .4625 .60038 L p .707 .577 .707 r
F P
0 g
s
.4625 .60038 m .4625 .58185 L .48356 .58831 L p .707 .577 .707 r
F P
0 g
s
.48356 .59338 m .48356 .63044 L .4625 .62398 L p .707 .577 .707 r
F P
0 g
s
.4625 .62398 m .4625 .58693 L .48356 .59338 L p .707 .577 .707 r
F P
0 g
s
.3186 .62092 m .3186 .56534 L .34265 .55969 L p .707 .577 .707 r
F P
0 g
s
.3186 .60389 m .3186 .58537 L .34265 .57972 L p .707 .577 .707 r
F P
0 g
s
.3186 .62749 m .3186 .59044 L .34265 .58479 L p .707 .577 .707 r
F P
0 g
s
.34265 .57972 m .34265 .59824 L .3186 .60389 L p .707 .577 .707 r
F P
0 g
s
.4625 .56183 m .4625 .61741 L .43504 .61302 L p .707 .577 .707 r
F P
0 g
s
.43504 .61302 m .43504 .55744 L .4625 .56183 L p .707 .577 .707 r
F P
0 g
s
.34265 .55969 m .34265 .61527 L .3186 .62092 L p .707 .577 .707 r
F P
0 g
s
.34265 .58479 m .34265 .62184 L .3186 .62749 L p .707 .577 .707 r
F P
0 g
s
.4625 .58185 m .4625 .60038 L .43504 .59599 L p .707 .577 .707 r
F P
0 g
s
.43504 .59599 m .43504 .57746 L .4625 .58185 L p .707 .577 .707 r
F P
0 g
s
.4625 .58693 m .4625 .62398 L .43504 .61959 L p .707 .577 .707 r
F P
0 g
s
.43504 .61959 m .43504 .58253 L .4625 .58693 L p .707 .577 .707 r
F P
0 g
s
.34265 .61527 m .34265 .55969 L .37203 .55631 L p .707 .577 .707 r
F P
0 g
s
.34265 .59824 m .34265 .57972 L .37203 .57634 L p .707 .577 .707 r
F P
0 g
s
.34265 .62184 m .34265 .58479 L .37203 .58141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55744 m .43504 .61302 L .40387 .61112 L p .707 .577 .707 r
F P
0 g
s
.40387 .61112 m .40387 .55554 L .43504 .55744 L p .707 .577 .707 r
F P
0 g
s
.37203 .57634 m .37203 .59486 L .34265 .59824 L p .707 .577 .707 r
F P
0 g
s
.37203 .61189 m .37203 .55631 L .40387 .55554 L p .707 .577 .707 r
F P
0 g
s
.37203 .55631 m .37203 .61189 L .34265 .61527 L p .707 .577 .707 r
F P
0 g
s
.43504 .57746 m .43504 .59599 L .40387 .59409 L p .707 .577 .707 r
F P
0 g
s
.40387 .59409 m .40387 .57556 L .43504 .57746 L p .707 .577 .707 r
F P
0 g
s
.40387 .55554 m .40387 .61112 L .37203 .61189 L p .707 .577 .707 r
F P
0 g
s
.43504 .58253 m .43504 .61959 L .40387 .61769 L p .707 .577 .707 r
F P
0 g
s
.40387 .61769 m .40387 .58063 L .43504 .58253 L p .707 .577 .707 r
F P
0 g
s
.37203 .58141 m .37203 .61847 L .34265 .62184 L p .707 .577 .707 r
F P
0 g
s
.37203 .59486 m .37203 .57634 L .40387 .57556 L p .707 .577 .707 r
F P
0 g
s
.37203 .61847 m .37203 .58141 L .40387 .58063 L p .707 .577 .707 r
F P
0 g
s
.40387 .57556 m .40387 .59409 L .37203 .59486 L p .707 .577 .707 r
F P
0 g
s
.40387 .58063 m .40387 .61769 L .37203 .61847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE
0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJEP`007Yoo`00MWoo1P0025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00Lgoo001aOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool30007
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P00
15YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo6P001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0>0004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`03001JEP0000AJEP03001JEP000080009JEP03001JEUYF00EJEPH000=JEQ<000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP80009JEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP02FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH005YF
0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000010000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000?OolB0014Ool005=oo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPP003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo0`0015YF0`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYFFUHF0003FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH60003FUH8
00000eYF000000030004FUH01000FUIJEUYF1@0015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0015YF1`001eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP@0009JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEP0000800003
FUH005YF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YF00000`0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00
0eYF0P000eYF0P00;Goo001COol00`00FUH00003FUH60003FUH50002FUH00`00FUIJEP02FUH40006
FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP0000000UYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUHH0005FUH30003FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH00000008002eoo`00Dgoo00<005YF00000`001EYF00<005YFFUH00eYF0`00
0UYF50000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00Dgoo0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEP<0009JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo5P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPD000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000cOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000_Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH40002FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH40000
0eYF001JEP02FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP80009JEP8000EJEP<000=JEQX000=JEP<000=JEP8002eo
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01@0015YF00<005YFFUH0
0UYF200015YF00<005YFFUH00eYF200015YF00<005YFFUH00eYF3P000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF
00@005YFFUIJEPD00004FUH000000004FUH>0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
0000000]Ool002aoo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH60003FUH;0002FUH6
0004FUH01000FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;7oo00<005YF000015YF10000eYF1@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`000UYF00<005YF00000P0000EJEP00FUIJEP00009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH0
1UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool01000
FUH005YF0P0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF1@000UYF0P000UYF00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00@005YF000000=JEP8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L0009JEP03001JEUYF
00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPH0
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo0`00
00EJEP00FUIJEP0000IJEP03001JEUYF00EJEPH000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
0`0015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
<goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000EJEP8000QJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000400000eYF001JEP04FUH00`00FUH0000H000oOol002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH40003FUH01000FUIJEUYF0P00
E7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPD00003FUH00000008000=JEP8000Qoo`<004Uoo`00;7oo00<005YF00000eYF1P000eYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF100000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EP0000800003FUH00000009JEP8000Moo`D004Qoo`00;7oo00@005YF001JEP8000AJEP8000MJEP04
001JEUYFFUHJ0003FUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00UYF0P0000=JEP0000000P001goo1@00B7oo000/Ool00`00FUH00003
0005FUH00`00FUIJEP02FUH40002FUHD0003FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH30000
0eYF00000007Ool50018Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP03
0008Ool30019Ool002aoo`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH015YF0P000UYF1P002EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol0031oo`<000=JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00<goo0`0000=J
EP00FUH01EYF0P001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000P000=JEP04001JEUYFFUH2
001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUH000070003FUH2001DOol003]oo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000Yoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040005FUH01000FUIJEP00
0UYF0P00E7oo0013OolC000?Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00B7oo0`006Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001J
EUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00Agoo1@006Goo
00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo05Aoo`00B7oo0`006Woo00@005YFFUH000=JEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003
FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF008005Moo`00IGoo00D005YF
FUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol006Eo
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH01000FUIJ
EUYF1000Fgoo001UOol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF0000
0005001OOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH007oo06Aoo`00
IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUH006Eoo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001W
Ool006Moo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Moo`00JGoo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P00J7oo001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001]Ool20004FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000
K7oo001_Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH4001^Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH00eYF2000Mgoo001lOolR001oOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79468 m .59613 .7391 L .56496 .7372 L p .707 .577 .707 r
F P
0 g
s
.59613 .7391 m .59613 .79468 L .62796 .79391 L p .707 .577 .707 r
F P
0 g
s
.62796 .79391 m .62796 .73832 L .59613 .7391 L p .707 .577 .707 r
F P
0 g
s
.62796 .73832 m .62796 .79391 L .65735 .79053 L p .707 .577 .707 r
F P
0 g
s
.65735 .79053 m .65734 .73494 L .62796 .73832 L p .707 .577 .707 r
F P
0 g
s
.59613 .77765 m .59613 .75912 L .56496 .75722 L p .707 .577 .707 r
F P
0 g
s
.59613 .75912 m .59613 .77765 L .62796 .77687 L p .707 .577 .707 r
F P
0 g
s
.62796 .77687 m .62796 .75835 L .59613 .75912 L p .707 .577 .707 r
F P
0 g
s
.56496 .79278 m .56496 .7372 L .5375 .73281 L p .707 .577 .707 r
F P
0 g
s
.56496 .7372 m .56496 .79278 L .59613 .79468 L p .707 .577 .707 r
F P
0 g
s
.59613 .80125 m .59613 .7642 L .56496 .7623 L p .707 .577 .707 r
F P
0 g
s
.59613 .7642 m .59613 .80125 L .62796 .80048 L p .707 .577 .707 r
F P
0 g
s
.62796 .80048 m .62796 .76342 L .59613 .7642 L p .707 .577 .707 r
F P
0 g
s
.62796 .75835 m .62796 .77687 L .65735 .7735 L p .707 .577 .707 r
F P
0 g
s
.65735 .7735 m .65735 .75497 L .62796 .75835 L p .707 .577 .707 r
F P
0 g
s
.62796 .76342 m .62796 .80048 L .65735 .7971 L p .707 .577 .707 r
F P
0 g
s
.65735 .7971 m .65735 .76004 L .62796 .76342 L p .707 .577 .707 r
F P
0 g
s
.56496 .75722 m .56496 .77575 L .59613 .77765 L p .707 .577 .707 r
F P
0 g
s
.56496 .77575 m .56496 .75722 L .5375 .75283 L p .707 .577 .707 r
F P
0 g
s
.56496 .79935 m .56496 .7623 L .5375 .75791 L p .707 .577 .707 r
F P
0 g
s
.56496 .7623 m .56496 .79935 L .59613 .80125 L p .707 .577 .707 r
F P
0 g
s
.65734 .73494 m .65735 .79053 L .6814 .78488 L p .707 .577 .707 r
F P
0 g
s
.6814 .78488 m .6814 .72929 L .65734 .73494 L p .707 .577 .707 r
F P
0 g
s
.5375 .75283 m .5375 .77136 L .56496 .77575 L p .707 .577 .707 r
F P
0 g
s
.65735 .75497 m .65735 .7735 L .6814 .76785 L p .707 .577 .707 r
F P
0 g
s
.6814 .76785 m .6814 .74932 L .65735 .75497 L p .707 .577 .707 r
F P
0 g
s
.65735 .76004 m .65735 .7971 L .6814 .79145 L p .707 .577 .707 r
F P
0 g
s
.6814 .79145 m .6814 .75439 L .65735 .76004 L p .707 .577 .707 r
F P
0 g
s
.5375 .73281 m .5375 .78839 L .56496 .79278 L p .707 .577 .707 r
F P
0 g
s
.5375 .78839 m .5375 .73281 L .51644 .72635 L p .707 .577 .707 r
F P
0 g
s
.5375 .75791 m .5375 .79496 L .56496 .79935 L p .707 .577 .707 r
F P
0 g
s
.5375 .77136 m .5375 .75283 L .51644 .74638 L p .707 .577 .707 r
F P
0 g
s
.5375 .79496 m .5375 .75791 L .51644 .75145 L p .707 .577 .707 r
F P
0 g
s
.51644 .74638 m .51644 .7649 L .5375 .77136 L p .707 .577 .707 r
F P
0 g
s
.6814 .72929 m .6814 .78488 L .69777 .77751 L p .707 .577 .707 r
F P
0 g
s
.69777 .77751 m .69777 .72193 L .6814 .72929 L p .707 .577 .707 r
F P
0 g
s
.51644 .72635 m .51644 .78194 L .5375 .78839 L p .707 .577 .707 r
F P
0 g
s
.51644 .75145 m .51644 .78851 L .5375 .79496 L p .707 .577 .707 r
F P
0 g
s
.6814 .74932 m .6814 .76785 L .69777 .76048 L p .707 .577 .707 r
F P
0 g
s
.69777 .76048 m .69777 .74195 L .6814 .74932 L p .707 .577 .707 r
F P
0 g
s
.6814 .75439 m .6814 .79145 L .69777 .78408 L p .707 .577 .707 r
F P
0 g
s
.69777 .78408 m .69777 .74702 L .6814 .75439 L p .707 .577 .707 r
F P
0 g
s
.51644 .78194 m .51644 .72635 L .50385 .71847 L p .707 .577 .707 r
F P
0 g
s
.51644 .7649 m .51644 .74638 L .50385 .73849 L p .707 .577 .707 r
F P
0 g
s
.51644 .78851 m .51644 .75145 L .50385 .74357 L p .707 .577 .707 r
F P
0 g
s
.50385 .73849 m .50385 .75702 L .51644 .7649 L p .707 .577 .707 r
F P
0 g
s
.50385 .71847 m .50385 .77405 L .51644 .78194 L p .707 .577 .707 r
F P
0 g
s
.69777 .72193 m .69777 .77751 L .70485 .76914 L p .707 .577 .707 r
F P
0 g
s
.70485 .76914 m .70485 .71356 L .69777 .72193 L p .707 .577 .707 r
F P
0 g
s
.50385 .74357 m .50385 .78062 L .51644 .78851 L p .707 .577 .707 r
F P
0 g
s
.69777 .74195 m .69777 .76048 L .70485 .75211 L p .707 .577 .707 r
F P
0 g
s
.70485 .75211 m .70485 .73359 L .69777 .74195 L p .707 .577 .707 r
F P
0 g
s
.69777 .74702 m .69777 .78408 L .70485 .77572 L p .707 .577 .707 r
F P
0 g
s
.70485 .77572 m .70485 .73866 L .69777 .74702 L p .707 .577 .707 r
F P
0 g
s
.50385 .77405 m .50385 .71847 L .50095 .70993 L p .707 .577 .707 r
F P
0 g
s
.50385 .75702 m .50385 .73849 L .50095 .72995 L p .707 .577 .707 r
F P
0 g
s
.50385 .78062 m .50385 .74357 L .50095 .73503 L p .707 .577 .707 r
F P
0 g
s
.50095 .72995 m .50095 .74848 L .50385 .75702 L p .707 .577 .707 r
F P
0 g
s
.50095 .70993 m .50095 .76551 L .50385 .77405 L p .707 .577 .707 r
F P
0 g
s
.50095 .73503 m .50095 .77208 L .50385 .78062 L p .707 .577 .707 r
F P
0 g
s
.70485 .71356 m .70485 .76914 L .70195 .7606 L p .707 .577 .707 r
F P
0 g
s
.70195 .7606 m .70195 .70502 L .70485 .71356 L p .707 .577 .707 r
F P
0 g
s
.49044 .84741 m .49044 .34552 L .44643 .34284 L p .707 .577 .707 r
F P
0 g
s
.50095 .76551 m .50095 .70993 L .50804 .70156 L p .707 .577 .707 r
F P
0 g
s
.50095 .74848 m .50095 .72995 L .50804 .72159 L p .707 .577 .707 r
F P
0 g
s
.50095 .77208 m .50095 .73503 L .50804 .72666 L p .707 .577 .707 r
F P
0 g
s
.50804 .72159 m .50804 .74011 L .50095 .74848 L p .707 .577 .707 r
F P
0 g
s
.50804 .70156 m .50804 .75715 L .50095 .76551 L p .707 .577 .707 r
F P
0 g
s
.50804 .72666 m .50804 .76372 L .50095 .77208 L p .707 .577 .707 r
F P
0 g
s
.50804 .75715 m .50804 .70156 L .5244 .6942 L p .707 .577 .707 r
F P
0 g
s
.50804 .74011 m .50804 .72159 L .5244 .71422 L p .707 .577 .707 r
F P
0 g
s
.50804 .76372 m .50804 .72666 L .5244 .71929 L p .707 .577 .707 r
F P
0 g
s
.5244 .71422 m .5244 .73275 L .50804 .74011 L p .707 .577 .707 r
F P
0 g
s
.5244 .6942 m .5244 .74978 L .50804 .75715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71929 m .5244 .75635 L .50804 .76372 L p .707 .577 .707 r
F P
0 g
s
.5244 .74978 m .5244 .6942 L .54846 .68855 L p .707 .577 .707 r
F P
0 g
s
.5244 .73275 m .5244 .71422 L .54846 .70857 L p .707 .577 .707 r
F P
0 g
s
.5244 .75635 m .5244 .71929 L .54846 .71364 L p .707 .577 .707 r
F P
0 g
s
.54846 .70857 m .54846 .7271 L .5244 .73275 L p .707 .577 .707 r
F P
0 g
s
.54846 .68855 m .54846 .74413 L .5244 .74978 L p .707 .577 .707 r
F P
0 g
s
.54846 .71364 m .54846 .7507 L .5244 .75635 L p .707 .577 .707 r
F P
0 g
s
.49044 .34552 m .49044 .84741 L .53538 .84631 L p .707 .577 .707 r
F P
0 g
s
.53538 .84631 m .53538 .34442 L .49044 .34552 L p .707 .577 .707 r
F P
0 g
s
.70485 .73359 m .70485 .75211 L .70195 .74357 L p .707 .577 .707 r
F P
0 g
s
.70195 .74357 m .70195 .72504 L .70485 .73359 L p .707 .577 .707 r
F P
0 g
s
.70485 .73866 m .70485 .77572 L .70195 .76717 L p .707 .577 .707 r
F P
0 g
s
.70195 .76717 m .70195 .73012 L .70485 .73866 L p .707 .577 .707 r
F P
0 g
s
.54846 .74413 m .54846 .68855 L .57784 .68517 L p .707 .577 .707 r
F P
0 g
s
.54846 .7271 m .54846 .70857 L .57784 .70519 L p .707 .577 .707 r
F P
0 g
s
.54846 .7507 m .54846 .71364 L .57784 .71026 L p .707 .577 .707 r
F P
0 g
s
.57784 .70519 m .57784 .72372 L .54846 .7271 L p .707 .577 .707 r
F P
0 g
s
.57784 .68517 m .57784 .74075 L .54846 .74413 L p .707 .577 .707 r
F P
0 g
s
.57784 .71026 m .57784 .74732 L .54846 .7507 L p .707 .577 .707 r
F P
0 g
s
.53538 .34442 m .53538 .84631 L .57686 .84154 L p .707 .577 .707 r
F P
0 g
s
.57686 .84154 m .57686 .33965 L .53538 .34442 L p .707 .577 .707 r
F P
0 g
s
.44643 .84473 m .44643 .34284 L .40766 .33664 L p .707 .577 .707 r
F P
0 g
s
.44643 .34284 m .44643 .84473 L .49044 .84741 L p .707 .577 .707 r
F P
0 g
s
.57784 .74075 m .57784 .68517 L .60968 .68439 L p .707 .577 .707 r
F P
0 g
s
.60968 .68439 m .60968 .73997 L .57784 .74075 L p .707 .577 .707 r
F P
0 g
s
.57784 .72372 m .57784 .70519 L .60968 .70441 L p .707 .577 .707 r
F P
0 g
s
.57784 .74732 m .57784 .71026 L .60968 .70949 L p .707 .577 .707 r
F P
0 g
s
.60968 .70441 m .60968 .72294 L .57784 .72372 L p .707 .577 .707 r
F P
0 g
s
.60968 .70949 m .60968 .74654 L .57784 .74732 L p .707 .577 .707 r
F P
0 g
s
.57686 .33965 m .57686 .84154 L .61082 .83357 L p .707 .577 .707 r
F P
0 g
s
.64085 .68629 m .64085 .74187 L .60968 .73997 L p .707 .577 .707 r
F P
0 g
s
.60968 .73997 m .60968 .68439 L .64085 .68629 L p .707 .577 .707 r
F P
0 g
s
.64085 .70631 m .64085 .72484 L .60968 .72294 L p .707 .577 .707 r
F P
0 g
s
.60968 .72294 m .60968 .70441 L .64085 .70631 L p .707 .577 .707 r
F P
0 g
s
.64085 .71139 m .64085 .74844 L .60968 .74654 L p .707 .577 .707 r
F P
0 g
s
.60968 .74654 m .60968 .70949 L .64085 .71139 L p .707 .577 .707 r
F P
0 g
s
.61082 .83357 m .61082 .33168 L .57686 .33965 L p .707 .577 .707 r
F P
0 g
s
.70195 .70502 m .70195 .7606 L .68936 .75272 L p .707 .577 .707 r
F P
0 g
s
.68936 .75272 m .68936 .69714 L .70195 .70502 L p .707 .577 .707 r
F P
0 g
s
.70195 .72504 m .70195 .74357 L .68936 .73569 L p .707 .577 .707 r
F P
0 g
s
.68936 .73569 m .68936 .71716 L .70195 .72504 L p .707 .577 .707 r
F P
0 g
s
.40766 .83852 m .40766 .33664 L .37794 .32752 L p .707 .577 .707 r
F P
0 g
s
.40766 .33664 m .40766 .83852 L .44643 .84473 L p .707 .577 .707 r
F P
0 g
s
.70195 .73012 m .70195 .76717 L .68936 .75929 L p .707 .577 .707 r
F P
0 g
s
.68936 .75929 m .68936 .72223 L .70195 .73012 L p .707 .577 .707 r
F P
0 g
s
.25312 .75787 m .25312 .70229 L .22195 .70038 L p .707 .577 .707 r
F P
0 g
s
.25312 .70229 m .25312 .75787 L .28495 .75709 L p .707 .577 .707 r
F P
0 g
s
.28495 .75709 m .28495 .70151 L .25312 .70229 L p .707 .577 .707 r
F P
0 g
s
.28495 .70151 m .28495 .75709 L .31434 .75371 L p .707 .577 .707 r
F P
0 g
s
.31434 .75371 m .31434 .69813 L .28495 .70151 L p .707 .577 .707 r
F P
0 g
s
.25312 .74084 m .25312 .72231 L .22195 .72041 L p .707 .577 .707 r
F P
0 g
s
.25312 .72231 m .25312 .74084 L .28495 .74006 L p .707 .577 .707 r
F P
0 g
s
.28495 .74006 m .28495 .72153 L .25312 .72231 L p .707 .577 .707 r
F P
0 g
s
.22195 .75597 m .22195 .70038 L .19449 .69599 L p .707 .577 .707 r
F P
0 g
s
.22195 .70038 m .22195 .75597 L .25312 .75787 L p .707 .577 .707 r
F P
0 g
s
.25312 .76444 m .25312 .72738 L .22195 .72548 L p .707 .577 .707 r
F P
0 g
s
.25312 .72738 m .25312 .76444 L .28495 .76366 L p .707 .577 .707 r
F P
0 g
s
.28495 .76366 m .28495 .72661 L .25312 .72738 L p .707 .577 .707 r
F P
0 g
s
.28495 .72153 m .28495 .74006 L .31434 .73668 L p .707 .577 .707 r
F P
0 g
s
.31434 .73668 m .31434 .71815 L .28495 .72153 L p .707 .577 .707 r
F P
0 g
s
.28495 .72661 m .28495 .76366 L .31434 .76028 L p .707 .577 .707 r
F P
0 g
s
.31434 .76028 m .31434 .72323 L .28495 .72661 L p .707 .577 .707 r
F P
0 g
s
.22195 .72041 m .22195 .73894 L .25312 .74084 L p .707 .577 .707 r
F P
0 g
s
.22195 .73894 m .22195 .72041 L .19449 .71602 L p .707 .577 .707 r
F P
0 g
s
.61082 .33168 m .61082 .83357 L .63393 .82316 L p .707 .577 .707 r
F P
0 g
s
.63393 .82316 m .63393 .32128 L .61082 .33168 L p .707 .577 .707 r
F P
0 g
s
.22195 .76254 m .22195 .72548 L .19449 .72109 L p .707 .577 .707 r
F P
0 g
s
.22195 .72548 m .22195 .76254 L .25312 .76444 L p .707 .577 .707 r
F P
0 g
s
.31434 .69813 m .31434 .75371 L .33839 .74806 L p .707 .577 .707 r
F P
0 g
s
.33839 .74806 m .33839 .69248 L .31434 .69813 L p .707 .577 .707 r
F P
0 g
s
.19449 .71602 m .19449 .73454 L .22195 .73894 L p .707 .577 .707 r
F P
0 g
s
.68936 .69714 m .68936 .75272 L .66831 .74626 L p .707 .577 .707 r
F P
0 g
s
.66831 .74626 m .66831 .69068 L .68936 .69714 L p .707 .577 .707 r
F P
0 g
s
.31434 .71815 m .31434 .73668 L .33839 .73103 L p .707 .577 .707 r
F P
0 g
s
.33839 .73103 m .33839 .7125 L .31434 .71815 L p .707 .577 .707 r
F P
0 g
s
.31434 .72323 m .31434 .76028 L .33839 .75463 L p .707 .577 .707 r
F P
0 g
s
.33839 .75463 m .33839 .71758 L .31434 .72323 L p .707 .577 .707 r
F P
0 g
s
.19449 .69599 m .19449 .75157 L .22195 .75597 L p .707 .577 .707 r
F P
0 g
s
.19449 .75157 m .19449 .69599 L .17343 .68954 L p .707 .577 .707 r
F P
0 g
s
.68936 .71716 m .68936 .73569 L .66831 .72923 L p .707 .577 .707 r
F P
0 g
s
.66831 .72923 m .66831 .71071 L .68936 .71716 L p .707 .577 .707 r
F P
0 g
s
.19449 .72109 m .19449 .75815 L .22195 .76254 L p .707 .577 .707 r
F P
0 g
s
.68936 .72223 m .68936 .75929 L .66831 .75284 L p .707 .577 .707 r
F P
0 g
s
.66831 .75284 m .66831 .71578 L .68936 .72223 L p .707 .577 .707 r
F P
0 g
s
.19449 .73454 m .19449 .71602 L .17343 .70956 L p .707 .577 .707 r
F P
0 g
s
.37794 .82941 m .37794 .32752 L .36016 .31639 L p .707 .577 .707 r
F P
0 g
s
.37794 .32752 m .37794 .82941 L .40766 .83852 L p .707 .577 .707 r
F P
0 g
s
.19449 .75815 m .19449 .72109 L .17343 .71464 L p .707 .577 .707 r
F P
0 g
s
.17343 .70956 m .17343 .72809 L .19449 .73454 L p .707 .577 .707 r
F P
0 g
s
.33839 .69248 m .33839 .74806 L .35476 .74069 L p .707 .577 .707 r
F P
0 g
s
.35476 .74069 m .35476 .68511 L .33839 .69248 L p .707 .577 .707 r
F P
0 g
s
.17343 .68954 m .17343 .74512 L .19449 .75157 L p .707 .577 .707 r
F P
0 g
s
.17343 .71464 m .17343 .75169 L .19449 .75815 L p .707 .577 .707 r
F P
0 g
s
.33839 .7125 m .33839 .73103 L .35476 .72366 L p .707 .577 .707 r
F P
0 g
s
.35476 .72366 m .35476 .70514 L .33839 .7125 L p .707 .577 .707 r
F P
0 g
s
.66831 .69068 m .66831 .74626 L .64085 .74187 L p .707 .577 .707 r
F P
0 g
s
.64085 .74187 m .64085 .68629 L .66831 .69068 L p .707 .577 .707 r
F P
0 g
s
.33839 .71758 m .33839 .75463 L .35476 .74726 L p .707 .577 .707 r
F P
0 g
s
.35476 .74726 m .35476 .71021 L .33839 .71758 L p .707 .577 .707 r
F P
0 g
s
.17343 .74512 m .17343 .68954 L .16084 .68165 L p .707 .577 .707 r
F P
0 g
s
.66831 .71071 m .66831 .72923 L .64085 .72484 L p .707 .577 .707 r
F P
0 g
s
.64085 .72484 m .64085 .70631 L .66831 .71071 L p .707 .577 .707 r
F P
0 g
s
.66831 .71578 m .66831 .75284 L .64085 .74844 L p .707 .577 .707 r
F P
0 g
s
.64085 .74844 m .64085 .71139 L .66831 .71578 L p .707 .577 .707 r
F P
0 g
s
.63393 .32128 m .63393 .82316 L .64393 .81136 L p .707 .577 .707 r
F P
0 g
s
.64393 .81136 m .64393 .30947 L .63393 .32128 L p .707 .577 .707 r
F P
0 g
s
.17343 .72809 m .17343 .70956 L .16084 .70168 L p .707 .577 .707 r
F P
0 g
s
.17343 .75169 m .17343 .71464 L .16084 .70675 L p .707 .577 .707 r
F P
0 g
s
.16084 .70168 m .16084 .72021 L .17343 .72809 L p .707 .577 .707 r
F P
0 g
s
.16084 .68165 m .16084 .73724 L .17343 .74512 L p .707 .577 .707 r
F P
0 g
s
.35476 .68511 m .35476 .74069 L .36184 .73233 L p .707 .577 .707 r
F P
0 g
s
.36184 .73233 m .36184 .67675 L .35476 .68511 L p .707 .577 .707 r
F P
0 g
s
.16084 .70675 m .16084 .74381 L .17343 .75169 L p .707 .577 .707 r
F P
0 g
s
.35476 .70514 m .35476 .72366 L .36184 .7153 L p .707 .577 .707 r
F P
0 g
s
.36184 .7153 m .36184 .69677 L .35476 .70514 L p .707 .577 .707 r
F P
0 g
s
.35476 .71021 m .35476 .74726 L .36184 .7389 L p .707 .577 .707 r
F P
0 g
s
.36184 .7389 m .36184 .70185 L .35476 .71021 L p .707 .577 .707 r
F P
0 g
s
.36184 .67675 m .36184 .73233 L .35894 .72379 L p .707 .577 .707 r
F P
0 g
s
.35894 .72379 m .35894 .66821 L .36184 .67675 L p .707 .577 .707 r
F P
0 g
s
.36184 .69677 m .36184 .7153 L .35894 .70676 L p .707 .577 .707 r
F P
0 g
s
.35894 .70676 m .35894 .68823 L .36184 .69677 L p .707 .577 .707 r
F P
0 g
s
.36184 .70185 m .36184 .7389 L .35894 .73036 L p .707 .577 .707 r
F P
0 g
s
.35894 .73036 m .35894 .6933 L .36184 .70185 L p .707 .577 .707 r
F P
0 g
s
.36016 .81828 m .36016 .31639 L .35607 .30433 L p .707 .577 .707 r
F P
0 g
s
.36016 .31639 m .36016 .81828 L .37794 .82941 L p .707 .577 .707 r
F P
0 g
s
.16084 .73724 m .16084 .68165 L .15794 .67311 L p .707 .577 .707 r
F P
0 g
s
.16084 .72021 m .16084 .70168 L .15794 .69314 L p .707 .577 .707 r
F P
0 g
s
.16084 .74381 m .16084 .70675 L .15794 .69821 L p .707 .577 .707 r
F P
0 g
s
.15794 .69314 m .15794 .71166 L .16084 .72021 L p .707 .577 .707 r
F P
0 g
s
.15794 .67311 m .15794 .72869 L .16084 .73724 L p .707 .577 .707 r
F P
0 g
s
.15794 .69821 m .15794 .73526 L .16084 .74381 L p .707 .577 .707 r
F P
0 g
s
.64393 .30947 m .64393 .81136 L .63984 .7993 L p .707 .577 .707 r
F P
0 g
s
.63984 .7993 m .63984 .29741 L .64393 .30947 L p .707 .577 .707 r
F P
0 g
s
.15794 .72869 m .15794 .67311 L .16503 .66475 L p .707 .577 .707 r
F P
0 g
s
.15794 .71166 m .15794 .69314 L .16503 .68477 L p .707 .577 .707 r
F P
0 g
s
.15794 .73526 m .15794 .69821 L .16503 .68985 L p .707 .577 .707 r
F P
0 g
s
.35894 .66821 m .35894 .72379 L .34635 .7159 L p .707 .577 .707 r
F P
0 g
s
.34635 .7159 m .34635 .66032 L .35894 .66821 L p .707 .577 .707 r
F P
0 g
s
.35894 .68823 m .35894 .70676 L .34635 .69887 L p .707 .577 .707 r
F P
0 g
s
.34635 .69887 m .34635 .68034 L .35894 .68823 L p .707 .577 .707 r
F P
0 g
s
.35894 .6933 m .35894 .73036 L .34635 .72247 L p .707 .577 .707 r
F P
0 g
s
.34635 .72247 m .34635 .68542 L .35894 .6933 L p .707 .577 .707 r
F P
0 g
s
.35607 .30433 m .35607 .80622 L .36016 .81828 L p .707 .577 .707 r
F P
0 g
s
.35607 .80622 m .35607 .30433 L .36607 .29253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .68477 m .16503 .7033 L .15794 .71166 L p .707 .577 .707 r
F P
0 g
s
.16503 .66475 m .16503 .72033 L .15794 .72869 L p .707 .577 .707 r
F P
0 g
s
.16503 .68985 m .16503 .7269 L .15794 .73526 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72033 m .16503 .66475 L .1814 .65738 L p .707 .577 .707 r
F P
0 g
s
.63984 .29741 m .63984 .7993 L .62206 .78817 L p .707 .577 .707 r
F P
0 g
s
.62206 .78817 m .62206 .28628 L .63984 .29741 L p .707 .577 .707 r
F P
0 g
s
.16503 .7033 m .16503 .68477 L .1814 .6774 L p .707 .577 .707 r
F P
0 g
s
.16503 .7269 m .16503 .68985 L .1814 .68248 L p .707 .577 .707 r
F P
0 g
s
.1814 .6774 m .1814 .69593 L .16503 .7033 L p .707 .577 .707 r
F P
0 g
s
.1814 .65738 m .1814 .71296 L .16503 .72033 L p .707 .577 .707 r
F P
0 g
s
.34635 .66032 m .34635 .7159 L .3253 .70945 L p .707 .577 .707 r
F P
0 g
s
.3253 .70945 m .3253 .65387 L .34635 .66032 L p .707 .577 .707 r
F P
0 g
s
.1814 .68248 m .1814 .71953 L .16503 .7269 L p .707 .577 .707 r
F P
0 g
s
.36607 .79441 m .36607 .29253 L .38918 .28212 L p .707 .577 .707 r
F P
0 g
s
.36607 .29253 m .36607 .79441 L .35607 .80622 L p .707 .577 .707 r
F P
0 g
s
.34635 .68034 m .34635 .69887 L .3253 .69242 L p .707 .577 .707 r
F P
0 g
s
.3253 .69242 m .3253 .67389 L .34635 .68034 L p .707 .577 .707 r
F P
0 g
s
.34635 .68542 m .34635 .72247 L .3253 .71602 L p .707 .577 .707 r
F P
0 g
s
.3253 .71602 m .3253 .67896 L .34635 .68542 L p .707 .577 .707 r
F P
0 g
s
.1814 .71296 m .1814 .65738 L .20545 .65173 L p .707 .577 .707 r
F P
0 g
s
.1814 .69593 m .1814 .6774 L .20545 .67175 L p .707 .577 .707 r
F P
0 g
s
.1814 .71953 m .1814 .68248 L .20545 .67683 L p .707 .577 .707 r
F P
0 g
s
.20545 .67175 m .20545 .69028 L .1814 .69593 L p .707 .577 .707 r
F P
0 g
s
.3253 .65387 m .3253 .70945 L .29784 .70506 L p .707 .577 .707 r
F P
0 g
s
.29784 .70506 m .29784 .64947 L .3253 .65387 L p .707 .577 .707 r
F P
0 g
s
.62206 .28628 m .62206 .78817 L .59233 .77905 L p .707 .577 .707 r
F P
0 g
s
.59233 .77905 m .59233 .27716 L .62206 .28628 L p .707 .577 .707 r
F P
0 g
s
.20545 .65173 m .20545 .70731 L .1814 .71296 L p .707 .577 .707 r
F P
0 g
s
.20545 .67683 m .20545 .71388 L .1814 .71953 L p .707 .577 .707 r
F P
0 g
s
.3253 .67389 m .3253 .69242 L .29784 .68803 L p .707 .577 .707 r
F P
0 g
s
.29784 .68803 m .29784 .6695 L .3253 .67389 L p .707 .577 .707 r
F P
0 g
s
.3253 .67896 m .3253 .71602 L .29784 .71163 L p .707 .577 .707 r
F P
0 g
s
.29784 .71163 m .29784 .67457 L .3253 .67896 L p .707 .577 .707 r
F P
0 g
s
.20545 .70731 m .20545 .65173 L .23483 .64835 L p .707 .577 .707 r
F P
0 g
s
.20545 .69028 m .20545 .67175 L .23483 .66838 L p .707 .577 .707 r
F P
0 g
s
.20545 .71388 m .20545 .67683 L .23483 .67345 L p .707 .577 .707 r
F P
0 g
s
.29784 .64947 m .29784 .70506 L .26667 .70316 L p .707 .577 .707 r
F P
0 g
s
.26667 .70316 m .26667 .64757 L .29784 .64947 L p .707 .577 .707 r
F P
0 g
s
.38918 .28212 m .38918 .78401 L .36607 .79441 L p .707 .577 .707 r
F P
0 g
s
.38918 .78401 m .38918 .28212 L .42314 .27415 L p .707 .577 .707 r
F P
0 g
s
.23483 .66838 m .23483 .6869 L .20545 .69028 L p .707 .577 .707 r
F P
0 g
s
.23483 .70393 m .23483 .64835 L .26667 .64757 L p .707 .577 .707 r
F P
0 g
s
.23483 .64835 m .23483 .70393 L .20545 .70731 L p .707 .577 .707 r
F P
0 g
s
.29784 .6695 m .29784 .68803 L .26667 .68613 L p .707 .577 .707 r
F P
0 g
s
.26667 .68613 m .26667 .6676 L .29784 .6695 L p .707 .577 .707 r
F P
0 g
s
.26667 .64757 m .26667 .70316 L .23483 .70393 L p .707 .577 .707 r
F P
0 g
s
.29784 .67457 m .29784 .71163 L .26667 .70973 L p .707 .577 .707 r
F P
0 g
s
.26667 .70973 m .26667 .67267 L .29784 .67457 L p .707 .577 .707 r
F P
0 g
s
.73333 .70264 m .73333 .64706 L .70216 .64516 L p .707 .577 .707 r
F P
0 g
s
.73333 .64706 m .73333 .70264 L .76517 .70187 L p .707 .577 .707 r
F P
0 g
s
.76517 .70187 m .76517 .64629 L .73333 .64706 L p .707 .577 .707 r
F P
0 g
s
.23483 .67345 m .23483 .7105 L .20545 .71388 L p .707 .577 .707 r
F P
0 g
s
.23483 .6869 m .23483 .66838 L .26667 .6676 L p .707 .577 .707 r
F P
0 g
s
.23483 .7105 m .23483 .67345 L .26667 .67267 L p .707 .577 .707 r
F P
0 g
s
.76517 .64629 m .76517 .70187 L .79455 .69849 L p .707 .577 .707 r
F P
0 g
s
.79455 .69849 m .79455 .64291 L .76517 .64629 L p .707 .577 .707 r
F P
0 g
s
.26667 .6676 m .26667 .68613 L .23483 .6869 L p .707 .577 .707 r
F P
0 g
s
.26667 .67267 m .26667 .70973 L .23483 .7105 L p .707 .577 .707 r
F P
0 g
s
.73333 .68561 m .73333 .66709 L .70216 .66519 L p .707 .577 .707 r
F P
0 g
s
.73333 .66709 m .73333 .68561 L .76517 .68484 L p .707 .577 .707 r
F P
0 g
s
.76517 .68484 m .76517 .66631 L .73333 .66709 L p .707 .577 .707 r
F P
0 g
s
.70216 .70074 m .70216 .64516 L .6747 .64077 L p .707 .577 .707 r
F P
0 g
s
.70216 .64516 m .70216 .70074 L .73333 .70264 L p .707 .577 .707 r
F P
0 g
s
.73333 .70922 m .73333 .67216 L .70216 .67026 L p .707 .577 .707 r
F P
0 g
s
.73333 .67216 m .73333 .70922 L .76517 .70844 L p .707 .577 .707 r
F P
0 g
s
.76517 .70844 m .76517 .67138 L .73333 .67216 L p .707 .577 .707 r
F P
0 g
s
.76517 .66631 m .76517 .68484 L .79455 .68146 L p .707 .577 .707 r
F P
0 g
s
.79455 .68146 m .79455 .66293 L .76517 .66631 L p .707 .577 .707 r
F P
0 g
s
.76517 .67138 m .76517 .70844 L .79455 .70506 L p .707 .577 .707 r
F P
0 g
s
.79455 .70506 m .79455 .668 L .76517 .67138 L p .707 .577 .707 r
F P
0 g
s
.70216 .66519 m .70216 .68371 L .73333 .68561 L p .707 .577 .707 r
F P
0 g
s
.59233 .27716 m .59233 .77905 L .55357 .77285 L p .707 .577 .707 r
F P
0 g
s
.55357 .77285 m .55357 .27096 L .59233 .27716 L p .707 .577 .707 r
F P
0 g
s
.70216 .68371 m .70216 .66519 L .6747 .66079 L p .707 .577 .707 r
F P
0 g
s
.70216 .70731 m .70216 .67026 L .6747 .66587 L p .707 .577 .707 r
F P
0 g
s
.70216 .67026 m .70216 .70731 L .73333 .70922 L p .707 .577 .707 r
F P
0 g
s
.79455 .64291 m .79455 .69849 L .8186 .69284 L p .707 .577 .707 r
F P
0 g
s
.8186 .69284 m .8186 .63726 L .79455 .64291 L p .707 .577 .707 r
F P
0 g
s
.6747 .66079 m .6747 .67932 L .70216 .68371 L p .707 .577 .707 r
F P
0 g
s
.79455 .66293 m .79455 .68146 L .8186 .67581 L p .707 .577 .707 r
F P
0 g
s
.8186 .67581 m .8186 .65728 L .79455 .66293 L p .707 .577 .707 r
F P
0 g
s
.42314 .77604 m .42314 .27415 L .46462 .26938 L p .707 .577 .707 r
F P
0 g
s
.42314 .27415 m .42314 .77604 L .38918 .78401 L p .707 .577 .707 r
F P
0 g
s
.79455 .668 m .79455 .70506 L .8186 .69941 L p .707 .577 .707 r
F P
0 g
s
.8186 .69941 m .8186 .66235 L .79455 .668 L p .707 .577 .707 r
F P
0 g
s
.6747 .64077 m .6747 .69635 L .70216 .70074 L p .707 .577 .707 r
F P
0 g
s
.6747 .69635 m .6747 .64077 L .65365 .63432 L p .707 .577 .707 r
F P
0 g
s
.6747 .66587 m .6747 .70292 L .70216 .70731 L p .707 .577 .707 r
F P
0 g
s
.6747 .67932 m .6747 .66079 L .65365 .65434 L p .707 .577 .707 r
F P
0 g
s
.6747 .70292 m .6747 .66587 L .65365 .65941 L p .707 .577 .707 r
F P
0 g
s
.55357 .27096 m .55357 .77285 L .50956 .77017 L p .707 .577 .707 r
F P
0 g
s
.50956 .77017 m .50956 .26828 L .55357 .27096 L p .707 .577 .707 r
F P
0 g
s
.65365 .65434 m .65365 .67287 L .6747 .67932 L p .707 .577 .707 r
F P
0 g
s
.8186 .63726 m .8186 .69284 L .83497 .68547 L p .707 .577 .707 r
F P
0 g
s
.83497 .68547 m .83497 .62989 L .8186 .63726 L p .707 .577 .707 r
F P
0 g
s
.65365 .63432 m .65365 .6899 L .6747 .69635 L p .707 .577 .707 r
F P
0 g
s
.46462 .77127 m .46462 .26938 L .50956 .26828 L p .707 .577 .707 r
F P
0 g
s
.46462 .26938 m .46462 .77127 L .42314 .77604 L p .707 .577 .707 r
F P
0 g
s
.65365 .65941 m .65365 .69647 L .6747 .70292 L p .707 .577 .707 r
F P
0 g
s
.8186 .65728 m .8186 .67581 L .83497 .66844 L p .707 .577 .707 r
F P
0 g
s
.83497 .66844 m .83497 .64991 L .8186 .65728 L p .707 .577 .707 r
F P
0 g
s
.8186 .66235 m .8186 .69941 L .83497 .69204 L p .707 .577 .707 r
F P
0 g
s
.83497 .69204 m .83497 .65499 L .8186 .66235 L p .707 .577 .707 r
F P
0 g
s
.50956 .26828 m .50956 .77017 L .46462 .77127 L p .707 .577 .707 r
F P
0 g
s
.65365 .6899 m .65365 .63432 L .64105 .62643 L p .707 .577 .707 r
F P
0 g
s
.65365 .67287 m .65365 .65434 L .64105 .64646 L p .707 .577 .707 r
F P
0 g
s
.65365 .69647 m .65365 .65941 L .64105 .65153 L p .707 .577 .707 r
F P
0 g
s
.64105 .64646 m .64105 .66498 L .65365 .67287 L p .707 .577 .707 r
F P
0 g
s
.64105 .62643 m .64105 .68201 L .65365 .6899 L p .707 .577 .707 r
F P
0 g
s
.83497 .62989 m .83497 .68547 L .84206 .67711 L p .707 .577 .707 r
F P
0 g
s
.84206 .67711 m .84205 .62152 L .83497 .62989 L p .707 .577 .707 r
F P
0 g
s
.64105 .65153 m .64105 .68858 L .65365 .69647 L p .707 .577 .707 r
F P
0 g
s
.83497 .64991 m .83497 .66844 L .84205 .66008 L p .707 .577 .707 r
F P
0 g
s
.84205 .66008 m .84205 .64155 L .83497 .64991 L p .707 .577 .707 r
F P
0 g
s
.83497 .65499 m .83497 .69204 L .84206 .68368 L p .707 .577 .707 r
F P
0 g
s
.84206 .68368 m .84205 .64662 L .83497 .65499 L p .707 .577 .707 r
F P
0 g
s
.64105 .68201 m .64105 .62643 L .63816 .61789 L p .707 .577 .707 r
F P
0 g
s
.64105 .66498 m .64105 .64646 L .63816 .63791 L p .707 .577 .707 r
F P
0 g
s
.64105 .68858 m .64105 .65153 L .63816 .64299 L p .707 .577 .707 r
F P
0 g
s
.63816 .63791 m .63816 .65644 L .64105 .66498 L p .707 .577 .707 r
F P
0 g
s
.63816 .61789 m .63816 .67347 L .64105 .68201 L p .707 .577 .707 r
F P
0 g
s
.63816 .64299 m .63816 .68004 L .64105 .68858 L p .707 .577 .707 r
F P
0 g
s
.84205 .62152 m .84206 .67711 L .83916 .66856 L p .707 .577 .707 r
F P
0 g
s
.83916 .66856 m .83916 .61298 L .84205 .62152 L p .707 .577 .707 r
F P
0 g
s
.84205 .64155 m .84205 .66008 L .83916 .65153 L p .707 .577 .707 r
F P
0 g
s
.83916 .65153 m .83916 .63301 L .84205 .64155 L p .707 .577 .707 r
F P
0 g
s
.84205 .64662 m .84206 .68368 L .83916 .67513 L p .707 .577 .707 r
F P
0 g
s
.83916 .67513 m .83916 .63808 L .84205 .64662 L p .707 .577 .707 r
F P
0 g
s
.63816 .67347 m .63816 .61789 L .64524 .60952 L p .707 .577 .707 r
F P
0 g
s
.63816 .65644 m .63816 .63791 L .64524 .62955 L p .707 .577 .707 r
F P
0 g
s
.63816 .68004 m .63816 .64299 L .64524 .63462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .62955 m .64524 .64808 L .63816 .65644 L p .707 .577 .707 r
F P
0 g
s
.64524 .60952 m .64524 .66511 L .63816 .67347 L p .707 .577 .707 r
F P
0 g
s
.64524 .63462 m .64524 .67168 L .63816 .68004 L p .707 .577 .707 r
F P
0 g
s
.83916 .61298 m .83916 .66856 L .82657 .66068 L p .707 .577 .707 r
F P
0 g
s
.82657 .66068 m .82657 .6051 L .83916 .61298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63301 m .83916 .65153 L .82657 .64365 L p .707 .577 .707 r
F P
0 g
s
.82657 .64365 m .82657 .62512 L .83916 .63301 L p .707 .577 .707 r
F P
0 g
s
.83916 .63808 m .83916 .67513 L .82657 .66725 L p .707 .577 .707 r
F P
0 g
s
.82657 .66725 m .82657 .6302 L .83916 .63808 L p .707 .577 .707 r
F P
0 g
s
.39032 .66583 m .39032 .61025 L .35915 .60835 L p .707 .577 .707 r
F P
0 g
s
.39032 .61025 m .39032 .66583 L .42216 .66505 L p .707 .577 .707 r
F P
0 g
s
.42216 .66505 m .42216 .60947 L .39032 .61025 L p .707 .577 .707 r
F P
0 g
s
.64524 .66511 m .64524 .60952 L .66161 .60216 L p .707 .577 .707 r
F P
0 g
s
.42216 .60947 m .42216 .66505 L .45154 .66167 L p .707 .577 .707 r
F P
0 g
s
.45154 .66167 m .45154 .60609 L .42216 .60947 L p .707 .577 .707 r
F P
0 g
s
.39032 .6488 m .39032 .63027 L .35915 .62837 L p .707 .577 .707 r
F P
0 g
s
.39032 .63027 m .39032 .6488 L .42216 .64802 L p .707 .577 .707 r
F P
0 g
s
.42216 .64802 m .42216 .62949 L .39032 .63027 L p .707 .577 .707 r
F P
0 g
s
.35915 .66393 m .35915 .60835 L .33169 .60395 L p .707 .577 .707 r
F P
0 g
s
.35915 .60835 m .35915 .66393 L .39032 .66583 L p .707 .577 .707 r
F P
0 g
s
.39032 .6724 m .39032 .63534 L .35915 .63344 L p .707 .577 .707 r
F P
0 g
s
.39032 .63534 m .39032 .6724 L .42216 .67162 L p .707 .577 .707 r
F P
0 g
s
.42216 .67162 m .42216 .63457 L .39032 .63534 L p .707 .577 .707 r
F P
0 g
s
.64524 .64808 m .64524 .62955 L .66161 .62218 L p .707 .577 .707 r
F P
0 g
s
.42216 .62949 m .42216 .64802 L .45154 .64464 L p .707 .577 .707 r
F P
0 g
s
.45154 .64464 m .45154 .62611 L .42216 .62949 L p .707 .577 .707 r
F P
0 g
s
.64524 .67168 m .64524 .63462 L .66161 .62725 L p .707 .577 .707 r
F P
0 g
s
.42216 .63457 m .42216 .67162 L .45154 .66824 L p .707 .577 .707 r
F P
0 g
s
.45154 .66824 m .45154 .63119 L .42216 .63457 L p .707 .577 .707 r
F P
0 g
s
.35915 .62837 m .35915 .6469 L .39032 .6488 L p .707 .577 .707 r
F P
0 g
s
.35915 .6469 m .35915 .62837 L .33169 .62398 L p .707 .577 .707 r
F P
0 g
s
.66161 .62218 m .66161 .64071 L .64524 .64808 L p .707 .577 .707 r
F P
0 g
s
.35915 .6705 m .35915 .63344 L .33169 .62905 L p .707 .577 .707 r
F P
0 g
s
.35915 .63344 m .35915 .6705 L .39032 .6724 L p .707 .577 .707 r
F P
0 g
s
.45154 .60609 m .45154 .66167 L .47559 .65602 L p .707 .577 .707 r
F P
0 g
s
.47559 .65602 m .47559 .60044 L .45154 .60609 L p .707 .577 .707 r
F P
0 g
s
.33169 .62398 m .33169 .64251 L .35915 .6469 L p .707 .577 .707 r
F P
0 g
s
.66161 .60216 m .66161 .65774 L .64524 .66511 L p .707 .577 .707 r
F P
0 g
s
.82657 .6051 m .82657 .66068 L .80551 .65423 L p .707 .577 .707 r
F P
0 g
s
.80551 .65423 m .80551 .59864 L .82657 .6051 L p .707 .577 .707 r
F P
0 g
s
.66161 .62725 m .66161 .66431 L .64524 .67168 L p .707 .577 .707 r
F P
0 g
s
.45154 .62611 m .45154 .64464 L .47559 .63899 L p .707 .577 .707 r
F P
0 g
s
.47559 .63899 m .47559 .62046 L .45154 .62611 L p .707 .577 .707 r
F P
0 g
s
.45154 .63119 m .45154 .66824 L .47559 .66259 L p .707 .577 .707 r
F P
0 g
s
.47559 .66259 m .47559 .62554 L .45154 .63119 L p .707 .577 .707 r
F P
0 g
s
.33169 .60395 m .33169 .65954 L .35915 .66393 L p .707 .577 .707 r
F P
0 g
s
.33169 .65954 m .33169 .60395 L .31064 .5975 L p .707 .577 .707 r
F P
0 g
s
.82657 .62512 m .82657 .64365 L .80551 .6372 L p .707 .577 .707 r
F P
0 g
s
.80551 .6372 m .80551 .61867 L .82657 .62512 L p .707 .577 .707 r
F P
0 g
s
.33169 .62905 m .33169 .66611 L .35915 .6705 L p .707 .577 .707 r
F P
0 g
s
.82657 .6302 m .82657 .66725 L .80551 .6608 L p .707 .577 .707 r
F P
0 g
s
.80551 .6608 m .80551 .62374 L .82657 .6302 L p .707 .577 .707 r
F P
0 g
s
.33169 .64251 m .33169 .62398 L .31064 .61752 L p .707 .577 .707 r
F P
0 g
s
.66161 .65774 m .66161 .60216 L .68566 .59651 L p .707 .577 .707 r
F P
0 g
s
.33169 .66611 m .33169 .62905 L .31064 .6226 L p .707 .577 .707 r
F P
0 g
s
.31064 .61752 m .31064 .63605 L .33169 .64251 L p .707 .577 .707 r
F P
0 g
s
.66161 .64071 m .66161 .62218 L .68566 .61653 L p .707 .577 .707 r
F P
0 g
s
.47559 .60044 m .47559 .65602 L .49196 .64866 L p .707 .577 .707 r
F P
0 g
s
.49196 .64866 m .49196 .59307 L .47559 .60044 L p .707 .577 .707 r
F P
0 g
s
.66161 .66431 m .66161 .62725 L .68566 .62161 L p .707 .577 .707 r
F P
0 g
s
.31064 .5975 m .31064 .65308 L .33169 .65954 L p .707 .577 .707 r
F P
0 g
s
.68566 .61653 m .68566 .63506 L .66161 .64071 L p .707 .577 .707 r
F P
0 g
s
.31064 .6226 m .31064 .65965 L .33169 .66611 L p .707 .577 .707 r
F P
0 g
s
.47559 .62046 m .47559 .63899 L .49196 .63162 L p .707 .577 .707 r
F P
0 g
s
.49196 .63162 m .49196 .6131 L .47559 .62046 L p .707 .577 .707 r
F P
0 g
s
.80551 .59864 m .80551 .65423 L .77805 .64983 L p .707 .577 .707 r
F P
0 g
s
.77805 .64983 m .77805 .59425 L .80551 .59864 L p .707 .577 .707 r
F P
0 g
s
.47559 .62554 m .47559 .66259 L .49196 .65523 L p .707 .577 .707 r
F P
0 g
s
.49196 .65523 m .49196 .61817 L .47559 .62554 L p .707 .577 .707 r
F P
0 g
s
.68566 .59651 m .68566 .65209 L .66161 .65774 L p .707 .577 .707 r
F P
0 g
s
.31064 .65308 m .31064 .5975 L .29804 .58962 L p .707 .577 .707 r
F P
0 g
s
.68566 .62161 m .68566 .65866 L .66161 .66431 L p .707 .577 .707 r
F P
0 g
s
.80551 .61867 m .80551 .6372 L .77805 .6328 L p .707 .577 .707 r
F P
0 g
s
.77805 .6328 m .77805 .61428 L .80551 .61867 L p .707 .577 .707 r
F P
0 g
s
.80551 .62374 m .80551 .6608 L .77805 .6564 L p .707 .577 .707 r
F P
0 g
s
.77805 .6564 m .77805 .61935 L .80551 .62374 L p .707 .577 .707 r
F P
0 g
s
.68566 .65209 m .68566 .59651 L .71504 .59313 L p .707 .577 .707 r
F P
0 g
s
.31064 .63605 m .31064 .61752 L .29804 .60964 L p .707 .577 .707 r
F P
0 g
s
.31064 .65965 m .31064 .6226 L .29804 .61471 L p .707 .577 .707 r
F P
0 g
s
.68566 .63506 m .68566 .61653 L .71504 .61315 L p .707 .577 .707 r
F P
0 g
s
.68566 .65866 m .68566 .62161 L .71504 .61823 L p .707 .577 .707 r
F P
0 g
s
.29804 .60964 m .29804 .62817 L .31064 .63605 L p .707 .577 .707 r
F P
0 g
s
.77805 .59425 m .77805 .64983 L .74688 .64793 L p .707 .577 .707 r
F P
0 g
s
.74688 .64793 m .74688 .59235 L .77805 .59425 L p .707 .577 .707 r
F P
0 g
s
.71504 .61315 m .71504 .63168 L .68566 .63506 L p .707 .577 .707 r
F P
0 g
s
.29804 .58962 m .29804 .6452 L .31064 .65308 L p .707 .577 .707 r
F P
0 g
s
.71504 .64871 m .71504 .59313 L .74688 .59235 L p .707 .577 .707 r
F P
0 g
s
.71504 .59313 m .71504 .64871 L .68566 .65209 L p .707 .577 .707 r
F P
0 g
s
.49196 .59307 m .49196 .64866 L .49904 .64029 L p .707 .577 .707 r
F P
0 g
s
.49904 .64029 m .49904 .58471 L .49196 .59307 L p .707 .577 .707 r
F P
0 g
s
.77805 .61428 m .77805 .6328 L .74688 .6309 L p .707 .577 .707 r
F P
0 g
s
.74688 .6309 m .74688 .61237 L .77805 .61428 L p .707 .577 .707 r
F P
0 g
s
.29804 .61471 m .29804 .65177 L .31064 .65965 L p .707 .577 .707 r
F P
0 g
s
.74688 .59235 m .74688 .64793 L .71504 .64871 L p .707 .577 .707 r
F P
0 g
s
.77805 .61935 m .77805 .6564 L .74688 .6545 L p .707 .577 .707 r
F P
0 g
s
.74688 .6545 m .74688 .61745 L .77805 .61935 L p .707 .577 .707 r
F P
0 g
s
.71504 .61823 m .71504 .65528 L .68566 .65866 L p .707 .577 .707 r
F P
0 g
s
.71504 .63168 m .71504 .61315 L .74688 .61237 L p .707 .577 .707 r
F P
0 g
s
.49196 .6131 m .49196 .63162 L .49904 .62326 L p .707 .577 .707 r
F P
0 g
s
.49904 .62326 m .49904 .60473 L .49196 .6131 L p .707 .577 .707 r
F P
0 g
s
.71504 .65528 m .71504 .61823 L .74688 .61745 L p .707 .577 .707 r
F P
0 g
s
.49196 .61817 m .49196 .65523 L .49904 .64686 L p .707 .577 .707 r
F P
0 g
s
.49904 .64686 m .49904 .60981 L .49196 .61817 L p .707 .577 .707 r
F P
0 g
s
.74688 .61237 m .74688 .6309 L .71504 .63168 L p .707 .577 .707 r
F P
0 g
s
.74688 .61745 m .74688 .6545 L .71504 .65528 L p .707 .577 .707 r
F P
0 g
s
.29804 .6452 m .29804 .58962 L .29515 .58107 L p .707 .577 .707 r
F P
0 g
s
.29804 .62817 m .29804 .60964 L .29515 .6011 L p .707 .577 .707 r
F P
0 g
s
.29804 .65177 m .29804 .61471 L .29515 .60617 L p .707 .577 .707 r
F P
0 g
s
.29515 .6011 m .29515 .61962 L .29804 .62817 L p .707 .577 .707 r
F P
0 g
s
.29515 .58107 m .29515 .63666 L .29804 .6452 L p .707 .577 .707 r
F P
0 g
s
.29515 .60617 m .29515 .64323 L .29804 .65177 L p .707 .577 .707 r
F P
0 g
s
.49904 .58471 m .49904 .64029 L .49615 .63175 L p .707 .577 .707 r
F P
0 g
s
.49615 .63175 m .49615 .57617 L .49904 .58471 L p .707 .577 .707 r
F P
0 g
s
.49904 .60473 m .49904 .62326 L .49615 .61472 L p .707 .577 .707 r
F P
0 g
s
.49615 .61472 m .49615 .59619 L .49904 .60473 L p .707 .577 .707 r
F P
0 g
s
.49904 .60981 m .49904 .64686 L .49615 .63832 L p .707 .577 .707 r
F P
0 g
s
.49615 .63832 m .49615 .60126 L .49904 .60981 L p .707 .577 .707 r
F P
0 g
s
.29515 .63666 m .29515 .58107 L .30223 .57271 L p .707 .577 .707 r
F P
0 g
s
.29515 .61962 m .29515 .6011 L .30223 .59273 L p .707 .577 .707 r
F P
0 g
s
.29515 .64323 m .29515 .60617 L .30223 .59781 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .59273 m .30223 .61126 L .29515 .61962 L p .707 .577 .707 r
F P
0 g
s
.30223 .57271 m .30223 .62829 L .29515 .63666 L p .707 .577 .707 r
F P
0 g
s
.30223 .59781 m .30223 .63486 L .29515 .64323 L p .707 .577 .707 r
F P
0 g
s
.49615 .57617 m .49615 .63175 L .48356 .62386 L p .707 .577 .707 r
F P
0 g
s
.48356 .62386 m .48356 .56828 L .49615 .57617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .59619 m .49615 .61472 L .48356 .60683 L p .707 .577 .707 r
F P
0 g
s
.48356 .60683 m .48356 .58831 L .49615 .59619 L p .707 .577 .707 r
F P
0 g
s
.49615 .60126 m .49615 .63832 L .48356 .63044 L p .707 .577 .707 r
F P
0 g
s
.48356 .63044 m .48356 .59338 L .49615 .60126 L p .707 .577 .707 r
F P
0 g
s
.30223 .62829 m .30223 .57271 L .3186 .56534 L p .707 .577 .707 r
F P
0 g
s
.30223 .61126 m .30223 .59273 L .3186 .58537 L p .707 .577 .707 r
F P
0 g
s
.30223 .63486 m .30223 .59781 L .3186 .59044 L p .707 .577 .707 r
F P
0 g
s
.3186 .58537 m .3186 .60389 L .30223 .61126 L p .707 .577 .707 r
F P
0 g
s
.3186 .56534 m .3186 .62092 L .30223 .62829 L p .707 .577 .707 r
F P
0 g
s
.48356 .56828 m .48356 .62386 L .4625 .61741 L p .707 .577 .707 r
F P
0 g
s
.4625 .61741 m .4625 .56183 L .48356 .56828 L p .707 .577 .707 r
F P
0 g
s
.3186 .59044 m .3186 .62749 L .30223 .63486 L p .707 .577 .707 r
F P
0 g
s
.48356 .58831 m .48356 .60683 L .4625 .60038 L p .707 .577 .707 r
F P
0 g
s
.4625 .60038 m .4625 .58185 L .48356 .58831 L p .707 .577 .707 r
F P
0 g
s
.48356 .59338 m .48356 .63044 L .4625 .62398 L p .707 .577 .707 r
F P
0 g
s
.4625 .62398 m .4625 .58693 L .48356 .59338 L p .707 .577 .707 r
F P
0 g
s
.3186 .62092 m .3186 .56534 L .34265 .55969 L p .707 .577 .707 r
F P
0 g
s
.3186 .60389 m .3186 .58537 L .34265 .57972 L p .707 .577 .707 r
F P
0 g
s
.3186 .62749 m .3186 .59044 L .34265 .58479 L p .707 .577 .707 r
F P
0 g
s
.34265 .57972 m .34265 .59824 L .3186 .60389 L p .707 .577 .707 r
F P
0 g
s
.4625 .56183 m .4625 .61741 L .43504 .61302 L p .707 .577 .707 r
F P
0 g
s
.43504 .61302 m .43504 .55744 L .4625 .56183 L p .707 .577 .707 r
F P
0 g
s
.34265 .55969 m .34265 .61527 L .3186 .62092 L p .707 .577 .707 r
F P
0 g
s
.34265 .58479 m .34265 .62184 L .3186 .62749 L p .707 .577 .707 r
F P
0 g
s
.4625 .58185 m .4625 .60038 L .43504 .59599 L p .707 .577 .707 r
F P
0 g
s
.43504 .59599 m .43504 .57746 L .4625 .58185 L p .707 .577 .707 r
F P
0 g
s
.4625 .58693 m .4625 .62398 L .43504 .61959 L p .707 .577 .707 r
F P
0 g
s
.43504 .61959 m .43504 .58253 L .4625 .58693 L p .707 .577 .707 r
F P
0 g
s
.34265 .61527 m .34265 .55969 L .37203 .55631 L p .707 .577 .707 r
F P
0 g
s
.34265 .59824 m .34265 .57972 L .37203 .57634 L p .707 .577 .707 r
F P
0 g
s
.34265 .62184 m .34265 .58479 L .37203 .58141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55744 m .43504 .61302 L .40387 .61112 L p .707 .577 .707 r
F P
0 g
s
.40387 .61112 m .40387 .55554 L .43504 .55744 L p .707 .577 .707 r
F P
0 g
s
.37203 .57634 m .37203 .59486 L .34265 .59824 L p .707 .577 .707 r
F P
0 g
s
.37203 .61189 m .37203 .55631 L .40387 .55554 L p .707 .577 .707 r
F P
0 g
s
.37203 .55631 m .37203 .61189 L .34265 .61527 L p .707 .577 .707 r
F P
0 g
s
.43504 .57746 m .43504 .59599 L .40387 .59409 L p .707 .577 .707 r
F P
0 g
s
.40387 .59409 m .40387 .57556 L .43504 .57746 L p .707 .577 .707 r
F P
0 g
s
.40387 .55554 m .40387 .61112 L .37203 .61189 L p .707 .577 .707 r
F P
0 g
s
.43504 .58253 m .43504 .61959 L .40387 .61769 L p .707 .577 .707 r
F P
0 g
s
.40387 .61769 m .40387 .58063 L .43504 .58253 L p .707 .577 .707 r
F P
0 g
s
.37203 .58141 m .37203 .61847 L .34265 .62184 L p .707 .577 .707 r
F P
0 g
s
.37203 .59486 m .37203 .57634 L .40387 .57556 L p .707 .577 .707 r
F P
0 g
s
.37203 .61847 m .37203 .58141 L .40387 .58063 L p .707 .577 .707 r
F P
0 g
s
.40387 .57556 m .40387 .59409 L .37203 .59486 L p .707 .577 .707 r
F P
0 g
s
.40387 .58063 m .40387 .61769 L .37203 .61847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE
0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJEP`007Yoo`00MWoo1P0025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00Lgoo001aOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool30007
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P00
15YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo6P001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0>0004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`03001JEP0000AJEP03001JEP000080009JEP03001JEUYF00EJEPH000=JEQ<000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP80009JEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP02FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH005YF
0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000010000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000?OolB0014Ool005=oo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPP003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo0`0015YF0`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYFFUHF0003FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH60003FUH8
00000eYF000000030004FUH01000FUIJEUYF1@0015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0015YF1`001eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP@0009JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEP0000800003
FUH005YF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YF00000`0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00
0eYF0P000eYF0P00;Goo001COol00`00FUH00003FUH60003FUH50002FUH00`00FUIJEP02FUH40006
FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP0000000UYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUHH0005FUH30003FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH00000008002eoo`00Dgoo00<005YF00000`001EYF00<005YFFUH00eYF0`00
0UYF50000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00Dgoo0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEP<0009JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo5P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPD000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000cOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000_Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH40002FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH40000
0eYF001JEP02FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP80009JEP8000EJEP<000=JEQX000=JEP<000=JEP8002eo
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01@0015YF00<005YFFUH0
0UYF200015YF00<005YFFUH00eYF200015YF00<005YFFUH00eYF3P000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF
00@005YFFUIJEPD00004FUH000000004FUH>0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
0000000]Ool002aoo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH60003FUH;0002FUH6
0004FUH01000FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;7oo00<005YF000015YF10000eYF1@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`000UYF00<005YF00000P0000EJEP00FUIJEP00009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH0
1UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool01000
FUH005YF0P0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF1@000UYF0P000UYF00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00@005YF000000=JEP8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L0009JEP03001JEUYF
00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPH0
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo0`00
00EJEP00FUIJEP0000IJEP03001JEUYF00EJEPH000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
0`0015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
<goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000EJEP8000QJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000400000eYF001JEP04FUH00`00FUH0000H000oOol002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH40003FUH01000FUIJEUYF0P00
E7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPD00003FUH00000008000=JEP8000Qoo`<004Uoo`00;7oo00<005YF00000eYF1P000eYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF100000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EP0000800003FUH00000009JEP8000Moo`D004Qoo`00;7oo00@005YF001JEP8000AJEP8000MJEP04
001JEUYFFUHJ0003FUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00UYF0P0000=JEP0000000P001goo1@00B7oo000/Ool00`00FUH00003
0005FUH00`00FUIJEP02FUH40002FUHD0003FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH30000
0eYF00000007Ool50018Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP03
0008Ool30019Ool002aoo`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH015YF0P000UYF1P002EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol0031oo`<000=JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00<goo0`0000=J
EP00FUH01EYF0P001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000P000=JEP04001JEUYFFUH2
001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUH000070003FUH2001DOol003]oo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000Yoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040005FUH01000FUIJEP00
0UYF0P00E7oo0013OolC000?Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00B7oo0`006Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001J
EUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00Agoo1@006Goo
00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo05Aoo`00B7oo0`006Woo00@005YFFUH000=JEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003
FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF008005Moo`00IGoo00D005YF
FUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol006Eo
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH01000FUIJ
EUYF1000Fgoo001UOol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF0000
0005001OOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH007oo06Aoo`00
IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUH006Eoo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001W
Ool006Moo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Moo`00JGoo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P00J7oo001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001]Ool20004FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000
K7oo001_Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH4001^Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH00eYF2000Mgoo001lOolR001oOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77742 m .59613 .72184 L .56496 .71994 L p .707 .577 .707 r
F P
0 g
s
.59613 .72184 m .59613 .77742 L .62796 .77665 L p .707 .577 .707 r
F P
0 g
s
.62796 .77665 m .62796 .72106 L .59613 .72184 L p .707 .577 .707 r
F P
0 g
s
.62796 .72106 m .62796 .77665 L .65735 .77327 L p .707 .577 .707 r
F P
0 g
s
.65735 .77327 m .65734 .71768 L .62796 .72106 L p .707 .577 .707 r
F P
0 g
s
.56496 .77552 m .56496 .71994 L .5375 .71555 L p .707 .577 .707 r
F P
0 g
s
.56496 .71994 m .56496 .77552 L .59613 .77742 L p .707 .577 .707 r
F P
0 g
s
.59613 .80454 m .59613 .76749 L .56496 .76558 L p .707 .577 .707 r
F P
0 g
s
.59613 .76749 m .59613 .80454 L .62796 .80376 L p .707 .577 .707 r
F P
0 g
s
.62796 .80376 m .62796 .76671 L .59613 .76749 L p .707 .577 .707 r
F P
0 g
s
.65734 .71768 m .65735 .77327 L .6814 .76762 L p .707 .577 .707 r
F P
0 g
s
.6814 .76762 m .6814 .71203 L .65734 .71768 L p .707 .577 .707 r
F P
0 g
s
.62796 .76671 m .62796 .80376 L .65735 .80038 L p .707 .577 .707 r
F P
0 g
s
.65735 .80038 m .65735 .76333 L .62796 .76671 L p .707 .577 .707 r
F P
0 g
s
.59613 .80593 m .59613 .78741 L .56496 .7855 L p .707 .577 .707 r
F P
0 g
s
.59613 .78741 m .59613 .80593 L .62796 .80516 L p .707 .577 .707 r
F P
0 g
s
.62796 .80516 m .62796 .78663 L .59613 .78741 L p .707 .577 .707 r
F P
0 g
s
.56496 .80264 m .56496 .76558 L .5375 .76119 L p .707 .577 .707 r
F P
0 g
s
.56496 .76558 m .56496 .80264 L .59613 .80454 L p .707 .577 .707 r
F P
0 g
s
.62796 .78663 m .62796 .80516 L .65735 .80178 L p .707 .577 .707 r
F P
0 g
s
.65735 .80178 m .65735 .78325 L .62796 .78663 L p .707 .577 .707 r
F P
0 g
s
.5375 .71555 m .5375 .77113 L .56496 .77552 L p .707 .577 .707 r
F P
0 g
s
.5375 .77113 m .5375 .71555 L .51644 .70909 L p .707 .577 .707 r
F P
0 g
s
.56496 .7855 m .56496 .80403 L .59613 .80593 L p .707 .577 .707 r
F P
0 g
s
.56496 .80403 m .56496 .7855 L .5375 .78111 L p .707 .577 .707 r
F P
0 g
s
.65735 .76333 m .65735 .80038 L .6814 .79473 L p .707 .577 .707 r
F P
0 g
s
.6814 .79473 m .6814 .75768 L .65735 .76333 L p .707 .577 .707 r
F P
0 g
s
.5375 .76119 m .5375 .79825 L .56496 .80264 L p .707 .577 .707 r
F P
0 g
s
.5375 .78111 m .5375 .79964 L .56496 .80403 L p .707 .577 .707 r
F P
0 g
s
.65735 .78325 m .65735 .80178 L .6814 .79613 L p .707 .577 .707 r
F P
0 g
s
.6814 .79613 m .6814 .7776 L .65735 .78325 L p .707 .577 .707 r
F P
0 g
s
.6814 .71203 m .6814 .76762 L .69777 .76025 L p .707 .577 .707 r
F P
0 g
s
.69777 .76025 m .69777 .70467 L .6814 .71203 L p .707 .577 .707 r
F P
0 g
s
.5375 .79825 m .5375 .76119 L .51644 .75474 L p .707 .577 .707 r
F P
0 g
s
.51644 .70909 m .51644 .76468 L .5375 .77113 L p .707 .577 .707 r
F P
0 g
s
.5375 .79964 m .5375 .78111 L .51644 .77466 L p .707 .577 .707 r
F P
0 g
s
.51644 .75474 m .51644 .79179 L .5375 .79825 L p .707 .577 .707 r
F P
0 g
s
.51644 .76468 m .51644 .70909 L .50385 .70121 L p .707 .577 .707 r
F P
0 g
s
.51644 .77466 m .51644 .79319 L .5375 .79964 L p .707 .577 .707 r
F P
0 g
s
.6814 .75768 m .6814 .79473 L .69777 .78737 L p .707 .577 .707 r
F P
0 g
s
.69777 .78737 m .69777 .75031 L .6814 .75768 L p .707 .577 .707 r
F P
0 g
s
.6814 .7776 m .6814 .79613 L .69777 .78876 L p .707 .577 .707 r
F P
0 g
s
.69777 .78876 m .69777 .77023 L .6814 .7776 L p .707 .577 .707 r
F P
0 g
s
.51644 .79179 m .51644 .75474 L .50385 .74685 L p .707 .577 .707 r
F P
0 g
s
.50385 .70121 m .50385 .75679 L .51644 .76468 L p .707 .577 .707 r
F P
0 g
s
.69777 .70467 m .69777 .76025 L .70485 .75188 L p .707 .577 .707 r
F P
0 g
s
.70485 .75188 m .70485 .6963 L .69777 .70467 L p .707 .577 .707 r
F P
0 g
s
.51644 .79319 m .51644 .77466 L .50385 .76677 L p .707 .577 .707 r
F P
0 g
s
.50385 .74685 m .50385 .78391 L .51644 .79179 L p .707 .577 .707 r
F P
0 g
s
.50385 .76677 m .50385 .7853 L .51644 .79319 L p .707 .577 .707 r
F P
0 g
s
.50385 .75679 m .50385 .70121 L .50095 .69267 L p .707 .577 .707 r
F P
0 g
s
.69777 .75031 m .69777 .78737 L .70485 .779 L p .707 .577 .707 r
F P
0 g
s
.70485 .779 m .70485 .74195 L .69777 .75031 L p .707 .577 .707 r
F P
0 g
s
.69777 .77023 m .69777 .78876 L .70485 .7804 L p .707 .577 .707 r
F P
0 g
s
.70485 .7804 m .70485 .76187 L .69777 .77023 L p .707 .577 .707 r
F P
0 g
s
.50385 .78391 m .50385 .74685 L .50095 .73831 L p .707 .577 .707 r
F P
0 g
s
.50095 .69267 m .50095 .74825 L .50385 .75679 L p .707 .577 .707 r
F P
0 g
s
.70485 .6963 m .70485 .75188 L .70195 .74334 L p .707 .577 .707 r
F P
0 g
s
.70195 .74334 m .70195 .68776 L .70485 .6963 L p .707 .577 .707 r
F P
0 g
s
.50385 .7853 m .50385 .76677 L .50095 .75823 L p .707 .577 .707 r
F P
0 g
s
.50095 .73831 m .50095 .77537 L .50385 .78391 L p .707 .577 .707 r
F P
0 g
s
.50095 .75823 m .50095 .77676 L .50385 .7853 L p .707 .577 .707 r
F P
0 g
s
.49044 .83764 m .49044 .33575 L .44643 .33307 L p .707 .577 .707 r
F P
0 g
s
.50095 .74825 m .50095 .69267 L .50804 .6843 L p .707 .577 .707 r
F P
0 g
s
.50095 .77537 m .50095 .73831 L .50804 .72995 L p .707 .577 .707 r
F P
0 g
s
.50804 .6843 m .50804 .73989 L .50095 .74825 L p .707 .577 .707 r
F P
0 g
s
.50095 .77676 m .50095 .75823 L .50804 .74987 L p .707 .577 .707 r
F P
0 g
s
.50804 .72995 m .50804 .767 L .50095 .77537 L p .707 .577 .707 r
F P
0 g
s
.50804 .74987 m .50804 .7684 L .50095 .77676 L p .707 .577 .707 r
F P
0 g
s
.50804 .73989 m .50804 .6843 L .5244 .67694 L p .707 .577 .707 r
F P
0 g
s
.50804 .767 m .50804 .72995 L .5244 .72258 L p .707 .577 .707 r
F P
0 g
s
.5244 .67694 m .5244 .73252 L .50804 .73989 L p .707 .577 .707 r
F P
0 g
s
.50804 .7684 m .50804 .74987 L .5244 .7425 L p .707 .577 .707 r
F P
0 g
s
.5244 .72258 m .5244 .75963 L .50804 .767 L p .707 .577 .707 r
F P
0 g
s
.5244 .7425 m .5244 .76103 L .50804 .7684 L p .707 .577 .707 r
F P
0 g
s
.5244 .73252 m .5244 .67694 L .54846 .67129 L p .707 .577 .707 r
F P
0 g
s
.5244 .75963 m .5244 .72258 L .54846 .71693 L p .707 .577 .707 r
F P
0 g
s
.54846 .67129 m .54846 .72687 L .5244 .73252 L p .707 .577 .707 r
F P
0 g
s
.5244 .76103 m .5244 .7425 L .54846 .73685 L p .707 .577 .707 r
F P
0 g
s
.54846 .71693 m .54846 .75399 L .5244 .75963 L p .707 .577 .707 r
F P
0 g
s
.54846 .73685 m .54846 .75538 L .5244 .76103 L p .707 .577 .707 r
F P
0 g
s
.49044 .33575 m .49044 .83764 L .53538 .83654 L p .707 .577 .707 r
F P
0 g
s
.53538 .83654 m .53538 .33466 L .49044 .33575 L p .707 .577 .707 r
F P
0 g
s
.54846 .72687 m .54846 .67129 L .57784 .66791 L p .707 .577 .707 r
F P
0 g
s
.57784 .66791 m .57784 .72349 L .54846 .72687 L p .707 .577 .707 r
F P
0 g
s
.54846 .75399 m .54846 .71693 L .57784 .71355 L p .707 .577 .707 r
F P
0 g
s
.54846 .75538 m .54846 .73685 L .57784 .73347 L p .707 .577 .707 r
F P
0 g
s
.57784 .71355 m .57784 .75061 L .54846 .75399 L p .707 .577 .707 r
F P
0 g
s
.57784 .73347 m .57784 .752 L .54846 .75538 L p .707 .577 .707 r
F P
0 g
s
.53538 .33466 m .53538 .83654 L .57686 .83177 L p .707 .577 .707 r
F P
0 g
s
.57686 .83177 m .57686 .32989 L .53538 .33466 L p .707 .577 .707 r
F P
0 g
s
.70485 .74195 m .70485 .779 L .70195 .77046 L p .707 .577 .707 r
F P
0 g
s
.70195 .77046 m .70195 .73341 L .70485 .74195 L p .707 .577 .707 r
F P
0 g
s
.44643 .83496 m .44643 .33307 L .40766 .32687 L p .707 .577 .707 r
F P
0 g
s
.44643 .33307 m .44643 .83496 L .49044 .83764 L p .707 .577 .707 r
F P
0 g
s
.70485 .76187 m .70485 .7804 L .70195 .77185 L p .707 .577 .707 r
F P
0 g
s
.70195 .77185 m .70195 .75333 L .70485 .76187 L p .707 .577 .707 r
F P
0 g
s
.57784 .72349 m .57784 .66791 L .60968 .66713 L p .707 .577 .707 r
F P
0 g
s
.60968 .66713 m .60968 .72271 L .57784 .72349 L p .707 .577 .707 r
F P
0 g
s
.57784 .75061 m .57784 .71355 L .60968 .71277 L p .707 .577 .707 r
F P
0 g
s
.60968 .71277 m .60968 .74983 L .57784 .75061 L p .707 .577 .707 r
F P
0 g
s
.57784 .752 m .57784 .73347 L .60968 .73269 L p .707 .577 .707 r
F P
0 g
s
.60968 .73269 m .60968 .75122 L .57784 .752 L p .707 .577 .707 r
F P
0 g
s
.57686 .32989 m .57686 .83177 L .61082 .8238 L p .707 .577 .707 r
F P
0 g
s
.64085 .66903 m .64085 .72461 L .60968 .72271 L p .707 .577 .707 r
F P
0 g
s
.60968 .72271 m .60968 .66713 L .64085 .66903 L p .707 .577 .707 r
F P
0 g
s
.64085 .71467 m .64085 .75173 L .60968 .74983 L p .707 .577 .707 r
F P
0 g
s
.60968 .74983 m .60968 .71277 L .64085 .71467 L p .707 .577 .707 r
F P
0 g
s
.64085 .7346 m .64085 .75312 L .60968 .75122 L p .707 .577 .707 r
F P
0 g
s
.60968 .75122 m .60968 .73269 L .64085 .7346 L p .707 .577 .707 r
F P
0 g
s
.61082 .8238 m .61082 .32191 L .57686 .32989 L p .707 .577 .707 r
F P
0 g
s
.70195 .68776 m .70195 .74334 L .68936 .73546 L p .707 .577 .707 r
F P
0 g
s
.68936 .73546 m .68936 .67988 L .70195 .68776 L p .707 .577 .707 r
F P
0 g
s
.40766 .82876 m .40766 .32687 L .37794 .31776 L p .707 .577 .707 r
F P
0 g
s
.40766 .32687 m .40766 .82876 L .44643 .83496 L p .707 .577 .707 r
F P
0 g
s
.25312 .74061 m .25312 .68503 L .22195 .68312 L p .707 .577 .707 r
F P
0 g
s
.25312 .68503 m .25312 .74061 L .28495 .73983 L p .707 .577 .707 r
F P
0 g
s
.28495 .73983 m .28495 .68425 L .25312 .68503 L p .707 .577 .707 r
F P
0 g
s
.28495 .68425 m .28495 .73983 L .31434 .73645 L p .707 .577 .707 r
F P
0 g
s
.31434 .73645 m .31434 .68087 L .28495 .68425 L p .707 .577 .707 r
F P
0 g
s
.70195 .73341 m .70195 .77046 L .68936 .76258 L p .707 .577 .707 r
F P
0 g
s
.68936 .76258 m .68936 .72552 L .70195 .73341 L p .707 .577 .707 r
F P
0 g
s
.22195 .73871 m .22195 .68312 L .19449 .67873 L p .707 .577 .707 r
F P
0 g
s
.22195 .68312 m .22195 .73871 L .25312 .74061 L p .707 .577 .707 r
F P
0 g
s
.70195 .75333 m .70195 .77185 L .68936 .76397 L p .707 .577 .707 r
F P
0 g
s
.68936 .76397 m .68936 .74544 L .70195 .75333 L p .707 .577 .707 r
F P
0 g
s
.25312 .76772 m .25312 .73067 L .22195 .72877 L p .707 .577 .707 r
F P
0 g
s
.25312 .73067 m .25312 .76772 L .28495 .76695 L p .707 .577 .707 r
F P
0 g
s
.28495 .76695 m .28495 .72989 L .25312 .73067 L p .707 .577 .707 r
F P
0 g
s
.31434 .68087 m .31434 .73645 L .33839 .7308 L p .707 .577 .707 r
F P
0 g
s
.33839 .7308 m .33839 .67522 L .31434 .68087 L p .707 .577 .707 r
F P
0 g
s
.28495 .72989 m .28495 .76695 L .31434 .76357 L p .707 .577 .707 r
F P
0 g
s
.31434 .76357 m .31434 .72651 L .28495 .72989 L p .707 .577 .707 r
F P
0 g
s
.61082 .32191 m .61082 .8238 L .63393 .8134 L p .707 .577 .707 r
F P
0 g
s
.63393 .8134 m .63393 .31151 L .61082 .32191 L p .707 .577 .707 r
F P
0 g
s
.25312 .76912 m .25312 .75059 L .22195 .74869 L p .707 .577 .707 r
F P
0 g
s
.25312 .75059 m .25312 .76912 L .28495 .76834 L p .707 .577 .707 r
F P
0 g
s
.28495 .76834 m .28495 .74981 L .25312 .75059 L p .707 .577 .707 r
F P
0 g
s
.68936 .67988 m .68936 .73546 L .66831 .729 L p .707 .577 .707 r
F P
0 g
s
.66831 .729 m .66831 .67342 L .68936 .67988 L p .707 .577 .707 r
F P
0 g
s
.22195 .76582 m .22195 .72877 L .19449 .72438 L p .707 .577 .707 r
F P
0 g
s
.22195 .72877 m .22195 .76582 L .25312 .76772 L p .707 .577 .707 r
F P
0 g
s
.28495 .74981 m .28495 .76834 L .31434 .76496 L p .707 .577 .707 r
F P
0 g
s
.31434 .76496 m .31434 .74643 L .28495 .74981 L p .707 .577 .707 r
F P
0 g
s
.19449 .67873 m .19449 .73431 L .22195 .73871 L p .707 .577 .707 r
F P
0 g
s
.19449 .73431 m .19449 .67873 L .17343 .67228 L p .707 .577 .707 r
F P
0 g
s
.22195 .74869 m .22195 .76722 L .25312 .76912 L p .707 .577 .707 r
F P
0 g
s
.22195 .76722 m .22195 .74869 L .19449 .7443 L p .707 .577 .707 r
F P
0 g
s
.31434 .72651 m .31434 .76357 L .33839 .75792 L p .707 .577 .707 r
F P
0 g
s
.33839 .75792 m .33839 .72086 L .31434 .72651 L p .707 .577 .707 r
F P
0 g
s
.19449 .72438 m .19449 .76143 L .22195 .76582 L p .707 .577 .707 r
F P
0 g
s
.19449 .7443 m .19449 .76282 L .22195 .76722 L p .707 .577 .707 r
F P
0 g
s
.37794 .81965 m .37794 .31776 L .36016 .30663 L p .707 .577 .707 r
F P
0 g
s
.37794 .31776 m .37794 .81965 L .40766 .82876 L p .707 .577 .707 r
F P
0 g
s
.68936 .72552 m .68936 .76258 L .66831 .75612 L p .707 .577 .707 r
F P
0 g
s
.66831 .75612 m .66831 .71907 L .68936 .72552 L p .707 .577 .707 r
F P
0 g
s
.31434 .74643 m .31434 .76496 L .33839 .75931 L p .707 .577 .707 r
F P
0 g
s
.33839 .75931 m .33839 .74078 L .31434 .74643 L p .707 .577 .707 r
F P
0 g
s
.33839 .67522 m .33839 .7308 L .35476 .72343 L p .707 .577 .707 r
F P
0 g
s
.35476 .72343 m .35476 .66785 L .33839 .67522 L p .707 .577 .707 r
F P
0 g
s
.19449 .76143 m .19449 .72438 L .17343 .71792 L p .707 .577 .707 r
F P
0 g
s
.68936 .74544 m .68936 .76397 L .66831 .75751 L p .707 .577 .707 r
F P
0 g
s
.66831 .75751 m .66831 .73899 L .68936 .74544 L p .707 .577 .707 r
F P
0 g
s
.17343 .67228 m .17343 .72786 L .19449 .73431 L p .707 .577 .707 r
F P
0 g
s
.19449 .76282 m .19449 .7443 L .17343 .73784 L p .707 .577 .707 r
F P
0 g
s
.66831 .67342 m .66831 .729 L .64085 .72461 L p .707 .577 .707 r
F P
0 g
s
.64085 .72461 m .64085 .66903 L .66831 .67342 L p .707 .577 .707 r
F P
0 g
s
.17343 .71792 m .17343 .75498 L .19449 .76143 L p .707 .577 .707 r
F P
0 g
s
.17343 .72786 m .17343 .67228 L .16084 .66439 L p .707 .577 .707 r
F P
0 g
s
.17343 .73784 m .17343 .75637 L .19449 .76282 L p .707 .577 .707 r
F P
0 g
s
.33839 .72086 m .33839 .75792 L .35476 .75055 L p .707 .577 .707 r
F P
0 g
s
.35476 .75055 m .35476 .7135 L .33839 .72086 L p .707 .577 .707 r
F P
0 g
s
.66831 .71907 m .66831 .75612 L .64085 .75173 L p .707 .577 .707 r
F P
0 g
s
.64085 .75173 m .64085 .71467 L .66831 .71907 L p .707 .577 .707 r
F P
0 g
s
.66831 .73899 m .66831 .75751 L .64085 .75312 L p .707 .577 .707 r
F P
0 g
s
.64085 .75312 m .64085 .7346 L .66831 .73899 L p .707 .577 .707 r
F P
0 g
s
.63393 .31151 m .63393 .8134 L .64393 .80159 L p .707 .577 .707 r
F P
0 g
s
.64393 .80159 m .64393 .2997 L .63393 .31151 L p .707 .577 .707 r
F P
0 g
s
.33839 .74078 m .33839 .75931 L .35476 .75194 L p .707 .577 .707 r
F P
0 g
s
.35476 .75194 m .35476 .73342 L .33839 .74078 L p .707 .577 .707 r
F P
0 g
s
.17343 .75498 m .17343 .71792 L .16084 .71004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66439 m .16084 .71998 L .17343 .72786 L p .707 .577 .707 r
F P
0 g
s
.35476 .66785 m .35476 .72343 L .36184 .71507 L p .707 .577 .707 r
F P
0 g
s
.36184 .71507 m .36184 .65949 L .35476 .66785 L p .707 .577 .707 r
F P
0 g
s
.17343 .75637 m .17343 .73784 L .16084 .72996 L p .707 .577 .707 r
F P
0 g
s
.16084 .71004 m .16084 .74709 L .17343 .75498 L p .707 .577 .707 r
F P
0 g
s
.16084 .72996 m .16084 .74849 L .17343 .75637 L p .707 .577 .707 r
F P
0 g
s
.35476 .7135 m .35476 .75055 L .36184 .74219 L p .707 .577 .707 r
F P
0 g
s
.36184 .74219 m .36184 .70513 L .35476 .7135 L p .707 .577 .707 r
F P
0 g
s
.35476 .73342 m .35476 .75194 L .36184 .74358 L p .707 .577 .707 r
F P
0 g
s
.36184 .74358 m .36184 .72505 L .35476 .73342 L p .707 .577 .707 r
F P
0 g
s
.36184 .65949 m .36184 .71507 L .35894 .70653 L p .707 .577 .707 r
F P
0 g
s
.35894 .70653 m .35894 .65095 L .36184 .65949 L p .707 .577 .707 r
F P
0 g
s
.36184 .70513 m .36184 .74219 L .35894 .73364 L p .707 .577 .707 r
F P
0 g
s
.35894 .73364 m .35894 .69659 L .36184 .70513 L p .707 .577 .707 r
F P
0 g
s
.36184 .72505 m .36184 .74358 L .35894 .73504 L p .707 .577 .707 r
F P
0 g
s
.35894 .73504 m .35894 .71651 L .36184 .72505 L p .707 .577 .707 r
F P
0 g
s
.35894 .65095 m .35894 .70653 L .34635 .69864 L p .707 .577 .707 r
F P
0 g
s
.34635 .69864 m .34635 .64306 L .35894 .65095 L p .707 .577 .707 r
F P
0 g
s
.36016 .80852 m .36016 .30663 L .35607 .29457 L p .707 .577 .707 r
F P
0 g
s
.36016 .30663 m .36016 .80852 L .37794 .81965 L p .707 .577 .707 r
F P
0 g
s
.16084 .71998 m .16084 .66439 L .15794 .65585 L p .707 .577 .707 r
F P
0 g
s
.16084 .74709 m .16084 .71004 L .15794 .7015 L p .707 .577 .707 r
F P
0 g
s
.15794 .65585 m .15794 .71143 L .16084 .71998 L p .707 .577 .707 r
F P
0 g
s
.16084 .74849 m .16084 .72996 L .15794 .72142 L p .707 .577 .707 r
F P
0 g
s
.64393 .2997 m .64393 .80159 L .63984 .78953 L p .707 .577 .707 r
F P
0 g
s
.63984 .78953 m .63984 .28764 L .64393 .2997 L p .707 .577 .707 r
F P
0 g
s
.15794 .7015 m .15794 .73855 L .16084 .74709 L p .707 .577 .707 r
F P
0 g
s
.15794 .72142 m .15794 .73994 L .16084 .74849 L p .707 .577 .707 r
F P
0 g
s
.15794 .71143 m .15794 .65585 L .16503 .64749 L p .707 .577 .707 r
F P
0 g
s
.35894 .69659 m .35894 .73364 L .34635 .72576 L p .707 .577 .707 r
F P
0 g
s
.34635 .72576 m .34635 .68871 L .35894 .69659 L p .707 .577 .707 r
F P
0 g
s
.35894 .71651 m .35894 .73504 L .34635 .72715 L p .707 .577 .707 r
F P
0 g
s
.34635 .72715 m .34635 .70863 L .35894 .71651 L p .707 .577 .707 r
F P
0 g
s
.35607 .29457 m .35607 .79646 L .36016 .80852 L p .707 .577 .707 r
F P
0 g
s
.35607 .79646 m .35607 .29457 L .36607 .28276 L p .707 .577 .707 r
F P
0 g
s
.15794 .73855 m .15794 .7015 L .16503 .69313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .64749 m .16503 .70307 L .15794 .71143 L p .707 .577 .707 r
F P
0 g
s
.15794 .73994 m .15794 .72142 L .16503 .71305 L p .707 .577 .707 r
F P
0 g
s
.16503 .69313 m .16503 .73019 L .15794 .73855 L p .707 .577 .707 r
F P
0 g
s
.16503 .71305 m .16503 .73158 L .15794 .73994 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70307 m .16503 .64749 L .1814 .64012 L p .707 .577 .707 r
F P
0 g
s
.63984 .28764 m .63984 .78953 L .62206 .7784 L p .707 .577 .707 r
F P
0 g
s
.62206 .7784 m .62206 .27651 L .63984 .28764 L p .707 .577 .707 r
F P
0 g
s
.16503 .73019 m .16503 .69313 L .1814 .68576 L p .707 .577 .707 r
F P
0 g
s
.1814 .64012 m .1814 .6957 L .16503 .70307 L p .707 .577 .707 r
F P
0 g
s
.34635 .64306 m .34635 .69864 L .3253 .69219 L p .707 .577 .707 r
F P
0 g
s
.3253 .69219 m .3253 .63661 L .34635 .64306 L p .707 .577 .707 r
F P
0 g
s
.16503 .73158 m .16503 .71305 L .1814 .70569 L p .707 .577 .707 r
F P
0 g
s
.36607 .78465 m .36607 .28276 L .38918 .27236 L p .707 .577 .707 r
F P
0 g
s
.36607 .28276 m .36607 .78465 L .35607 .79646 L p .707 .577 .707 r
F P
0 g
s
.1814 .68576 m .1814 .72282 L .16503 .73019 L p .707 .577 .707 r
F P
0 g
s
.1814 .70569 m .1814 .72421 L .16503 .73158 L p .707 .577 .707 r
F P
0 g
s
.1814 .6957 m .1814 .64012 L .20545 .63447 L p .707 .577 .707 r
F P
0 g
s
.34635 .68871 m .34635 .72576 L .3253 .71931 L p .707 .577 .707 r
F P
0 g
s
.3253 .71931 m .3253 .68225 L .34635 .68871 L p .707 .577 .707 r
F P
0 g
s
.34635 .70863 m .34635 .72715 L .3253 .7207 L p .707 .577 .707 r
F P
0 g
s
.3253 .7207 m .3253 .70217 L .34635 .70863 L p .707 .577 .707 r
F P
0 g
s
.3253 .63661 m .3253 .69219 L .29784 .6878 L p .707 .577 .707 r
F P
0 g
s
.29784 .6878 m .29784 .63221 L .3253 .63661 L p .707 .577 .707 r
F P
0 g
s
.1814 .72282 m .1814 .68576 L .20545 .68011 L p .707 .577 .707 r
F P
0 g
s
.20545 .63447 m .20545 .69005 L .1814 .6957 L p .707 .577 .707 r
F P
0 g
s
.62206 .27651 m .62206 .7784 L .59233 .76929 L p .707 .577 .707 r
F P
0 g
s
.59233 .76929 m .59233 .2674 L .62206 .27651 L p .707 .577 .707 r
F P
0 g
s
.1814 .72421 m .1814 .70569 L .20545 .70004 L p .707 .577 .707 r
F P
0 g
s
.20545 .69005 m .20545 .63447 L .23483 .63109 L p .707 .577 .707 r
F P
0 g
s
.20545 .68011 m .20545 .71717 L .1814 .72282 L p .707 .577 .707 r
F P
0 g
s
.20545 .70004 m .20545 .71856 L .1814 .72421 L p .707 .577 .707 r
F P
0 g
s
.3253 .68225 m .3253 .71931 L .29784 .71491 L p .707 .577 .707 r
F P
0 g
s
.29784 .71491 m .29784 .67786 L .3253 .68225 L p .707 .577 .707 r
F P
0 g
s
.29784 .63221 m .29784 .6878 L .26667 .6859 L p .707 .577 .707 r
F P
0 g
s
.26667 .6859 m .26667 .63031 L .29784 .63221 L p .707 .577 .707 r
F P
0 g
s
.3253 .70217 m .3253 .7207 L .29784 .71631 L p .707 .577 .707 r
F P
0 g
s
.29784 .71631 m .29784 .69778 L .3253 .70217 L p .707 .577 .707 r
F P
0 g
s
.38918 .27236 m .38918 .77425 L .36607 .78465 L p .707 .577 .707 r
F P
0 g
s
.38918 .77425 m .38918 .27236 L .42314 .26438 L p .707 .577 .707 r
F P
0 g
s
.23483 .68667 m .23483 .63109 L .26667 .63031 L p .707 .577 .707 r
F P
0 g
s
.23483 .63109 m .23483 .68667 L .20545 .69005 L p .707 .577 .707 r
F P
0 g
s
.20545 .71717 m .20545 .68011 L .23483 .67674 L p .707 .577 .707 r
F P
0 g
s
.26667 .63031 m .26667 .6859 L .23483 .68667 L p .707 .577 .707 r
F P
0 g
s
.73333 .68538 m .73333 .6298 L .70216 .6279 L p .707 .577 .707 r
F P
0 g
s
.73333 .6298 m .73333 .68538 L .76517 .68461 L p .707 .577 .707 r
F P
0 g
s
.76517 .68461 m .76517 .62903 L .73333 .6298 L p .707 .577 .707 r
F P
0 g
s
.20545 .71856 m .20545 .70004 L .23483 .69666 L p .707 .577 .707 r
F P
0 g
s
.76517 .62903 m .76517 .68461 L .79455 .68123 L p .707 .577 .707 r
F P
0 g
s
.79455 .68123 m .79455 .62565 L .76517 .62903 L p .707 .577 .707 r
F P
0 g
s
.29784 .67786 m .29784 .71491 L .26667 .71301 L p .707 .577 .707 r
F P
0 g
s
.26667 .71301 m .26667 .67596 L .29784 .67786 L p .707 .577 .707 r
F P
0 g
s
.23483 .67674 m .23483 .71379 L .20545 .71717 L p .707 .577 .707 r
F P
0 g
s
.23483 .69666 m .23483 .71518 L .20545 .71856 L p .707 .577 .707 r
F P
0 g
s
.70216 .68348 m .70216 .6279 L .6747 .62351 L p .707 .577 .707 r
F P
0 g
s
.70216 .6279 m .70216 .68348 L .73333 .68538 L p .707 .577 .707 r
F P
0 g
s
.23483 .71379 m .23483 .67674 L .26667 .67596 L p .707 .577 .707 r
F P
0 g
s
.29784 .69778 m .29784 .71631 L .26667 .71441 L p .707 .577 .707 r
F P
0 g
s
.26667 .71441 m .26667 .69588 L .29784 .69778 L p .707 .577 .707 r
F P
0 g
s
.26667 .67596 m .26667 .71301 L .23483 .71379 L p .707 .577 .707 r
F P
0 g
s
.73333 .7125 m .73333 .67545 L .70216 .67355 L p .707 .577 .707 r
F P
0 g
s
.73333 .67545 m .73333 .7125 L .76517 .71172 L p .707 .577 .707 r
F P
0 g
s
.76517 .71172 m .76517 .67467 L .73333 .67545 L p .707 .577 .707 r
F P
0 g
s
.59233 .2674 m .59233 .76929 L .55357 .76309 L p .707 .577 .707 r
F P
0 g
s
.55357 .76309 m .55357 .2612 L .59233 .2674 L p .707 .577 .707 r
F P
0 g
s
.23483 .71518 m .23483 .69666 L .26667 .69588 L p .707 .577 .707 r
F P
0 g
s
.79455 .62565 m .79455 .68123 L .8186 .67558 L p .707 .577 .707 r
F P
0 g
s
.8186 .67558 m .8186 .62 L .79455 .62565 L p .707 .577 .707 r
F P
0 g
s
.76517 .67467 m .76517 .71172 L .79455 .70835 L p .707 .577 .707 r
F P
0 g
s
.79455 .70835 m .79455 .67129 L .76517 .67467 L p .707 .577 .707 r
F P
0 g
s
.26667 .69588 m .26667 .71441 L .23483 .71518 L p .707 .577 .707 r
F P
0 g
s
.73333 .71389 m .73333 .69537 L .70216 .69347 L p .707 .577 .707 r
F P
0 g
s
.73333 .69537 m .73333 .71389 L .76517 .71312 L p .707 .577 .707 r
F P
0 g
s
.76517 .71312 m .76517 .69459 L .73333 .69537 L p .707 .577 .707 r
F P
0 g
s
.70216 .7106 m .70216 .67355 L .6747 .66915 L p .707 .577 .707 r
F P
0 g
s
.70216 .67355 m .70216 .7106 L .73333 .7125 L p .707 .577 .707 r
F P
0 g
s
.76517 .69459 m .76517 .71312 L .79455 .70974 L p .707 .577 .707 r
F P
0 g
s
.79455 .70974 m .79455 .69121 L .76517 .69459 L p .707 .577 .707 r
F P
0 g
s
.6747 .62351 m .6747 .67909 L .70216 .68348 L p .707 .577 .707 r
F P
0 g
s
.6747 .67909 m .6747 .62351 L .65365 .61706 L p .707 .577 .707 r
F P
0 g
s
.70216 .69347 m .70216 .71199 L .73333 .71389 L p .707 .577 .707 r
F P
0 g
s
.42314 .76627 m .42314 .26438 L .46462 .25961 L p .707 .577 .707 r
F P
0 g
s
.42314 .26438 m .42314 .76627 L .38918 .77425 L p .707 .577 .707 r
F P
0 g
s
.70216 .71199 m .70216 .69347 L .6747 .68907 L p .707 .577 .707 r
F P
0 g
s
.79455 .67129 m .79455 .70835 L .8186 .7027 L p .707 .577 .707 r
F P
0 g
s
.8186 .7027 m .8186 .66564 L .79455 .67129 L p .707 .577 .707 r
F P
0 g
s
.6747 .66915 m .6747 .70621 L .70216 .7106 L p .707 .577 .707 r
F P
0 g
s
.6747 .68907 m .6747 .7076 L .70216 .71199 L p .707 .577 .707 r
F P
0 g
s
.79455 .69121 m .79455 .70974 L .8186 .70409 L p .707 .577 .707 r
F P
0 g
s
.8186 .70409 m .8186 .68556 L .79455 .69121 L p .707 .577 .707 r
F P
0 g
s
.8186 .62 m .8186 .67558 L .83497 .66821 L p .707 .577 .707 r
F P
0 g
s
.83497 .66821 m .83497 .61263 L .8186 .62 L p .707 .577 .707 r
F P
0 g
s
.6747 .70621 m .6747 .66915 L .65365 .6627 L p .707 .577 .707 r
F P
0 g
s
.55357 .2612 m .55357 .76309 L .50956 .7604 L p .707 .577 .707 r
F P
0 g
s
.50956 .7604 m .50956 .25851 L .55357 .2612 L p .707 .577 .707 r
F P
0 g
s
.65365 .61706 m .65365 .67264 L .6747 .67909 L p .707 .577 .707 r
F P
0 g
s
.6747 .7076 m .6747 .68907 L .65365 .68262 L p .707 .577 .707 r
F P
0 g
s
.46462 .7615 m .46462 .25961 L .50956 .25851 L p .707 .577 .707 r
F P
0 g
s
.46462 .25961 m .46462 .7615 L .42314 .76627 L p .707 .577 .707 r
F P
0 g
s
.50956 .25851 m .50956 .7604 L .46462 .7615 L p .707 .577 .707 r
F P
0 g
s
.65365 .6627 m .65365 .69975 L .6747 .70621 L p .707 .577 .707 r
F P
0 g
s
.65365 .67264 m .65365 .61706 L .64105 .60917 L p .707 .577 .707 r
F P
0 g
s
.65365 .68262 m .65365 .70115 L .6747 .7076 L p .707 .577 .707 r
F P
0 g
s
.8186 .66564 m .8186 .7027 L .83497 .69533 L p .707 .577 .707 r
F P
0 g
s
.83497 .69533 m .83497 .65827 L .8186 .66564 L p .707 .577 .707 r
F P
0 g
s
.8186 .68556 m .8186 .70409 L .83497 .69672 L p .707 .577 .707 r
F P
0 g
s
.83497 .69672 m .83497 .67819 L .8186 .68556 L p .707 .577 .707 r
F P
0 g
s
.65365 .69975 m .65365 .6627 L .64105 .65482 L p .707 .577 .707 r
F P
0 g
s
.64105 .60917 m .64105 .66475 L .65365 .67264 L p .707 .577 .707 r
F P
0 g
s
.83497 .61263 m .83497 .66821 L .84205 .65985 L p .707 .577 .707 r
F P
0 g
s
.84205 .65985 m .84205 .60426 L .83497 .61263 L p .707 .577 .707 r
F P
0 g
s
.65365 .70115 m .65365 .68262 L .64105 .67474 L p .707 .577 .707 r
F P
0 g
s
.64105 .65482 m .64105 .69187 L .65365 .69975 L p .707 .577 .707 r
F P
0 g
s
.64105 .67474 m .64105 .69326 L .65365 .70115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66475 m .64105 .60917 L .63816 .60063 L p .707 .577 .707 r
F P
0 g
s
.83497 .65827 m .83497 .69533 L .84206 .68696 L p .707 .577 .707 r
F P
0 g
s
.84206 .68696 m .84205 .64991 L .83497 .65827 L p .707 .577 .707 r
F P
0 g
s
.83497 .67819 m .83497 .69672 L .84206 .68836 L p .707 .577 .707 r
F P
0 g
s
.84206 .68836 m .84206 .66983 L .83497 .67819 L p .707 .577 .707 r
F P
0 g
s
.64105 .69187 m .64105 .65482 L .63816 .64627 L p .707 .577 .707 r
F P
0 g
s
.63816 .60063 m .63816 .65621 L .64105 .66475 L p .707 .577 .707 r
F P
0 g
s
.84205 .60426 m .84205 .65985 L .83916 .6513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6513 m .83916 .59572 L .84205 .60426 L p .707 .577 .707 r
F P
0 g
s
.64105 .69326 m .64105 .67474 L .63816 .66619 L p .707 .577 .707 r
F P
0 g
s
.63816 .64627 m .63816 .68333 L .64105 .69187 L p .707 .577 .707 r
F P
0 g
s
.63816 .66619 m .63816 .68472 L .64105 .69326 L p .707 .577 .707 r
F P
0 g
s
.84205 .64991 m .84206 .68696 L .83916 .67842 L p .707 .577 .707 r
F P
0 g
s
.83916 .67842 m .83916 .64137 L .84205 .64991 L p .707 .577 .707 r
F P
0 g
s
.63816 .65621 m .63816 .60063 L .64524 .59226 L p .707 .577 .707 r
F P
0 g
s
.84206 .66983 m .84206 .68836 L .83916 .67981 L p .707 .577 .707 r
F P
0 g
s
.83916 .67981 m .83916 .66129 L .84206 .66983 L p .707 .577 .707 r
F P
0 g
s
.63816 .68333 m .63816 .64627 L .64524 .63791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .59226 m .64524 .64785 L .63816 .65621 L p .707 .577 .707 r
F P
0 g
s
.83916 .59572 m .83916 .6513 L .82657 .64342 L p .707 .577 .707 r
F P
0 g
s
.82657 .64342 m .82657 .58784 L .83916 .59572 L p .707 .577 .707 r
F P
0 g
s
.63816 .68472 m .63816 .66619 L .64524 .65783 L p .707 .577 .707 r
F P
0 g
s
.64524 .63791 m .64524 .67496 L .63816 .68333 L p .707 .577 .707 r
F P
0 g
s
.64524 .65783 m .64524 .67636 L .63816 .68472 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64857 m .39032 .59299 L .35915 .59109 L p .707 .577 .707 r
F P
0 g
s
.39032 .59299 m .39032 .64857 L .42216 .64779 L p .707 .577 .707 r
F P
0 g
s
.42216 .64779 m .42216 .59221 L .39032 .59299 L p .707 .577 .707 r
F P
0 g
s
.64524 .64785 m .64524 .59226 L .66161 .5849 L p .707 .577 .707 r
F P
0 g
s
.42216 .59221 m .42216 .64779 L .45154 .64441 L p .707 .577 .707 r
F P
0 g
s
.45154 .64441 m .45154 .58883 L .42216 .59221 L p .707 .577 .707 r
F P
0 g
s
.83916 .64137 m .83916 .67842 L .82657 .67054 L p .707 .577 .707 r
F P
0 g
s
.82657 .67054 m .82657 .63348 L .83916 .64137 L p .707 .577 .707 r
F P
0 g
s
.35915 .64667 m .35915 .59109 L .33169 .58669 L p .707 .577 .707 r
F P
0 g
s
.35915 .59109 m .35915 .64667 L .39032 .64857 L p .707 .577 .707 r
F P
0 g
s
.83916 .66129 m .83916 .67981 L .82657 .67193 L p .707 .577 .707 r
F P
0 g
s
.82657 .67193 m .82657 .6534 L .83916 .66129 L p .707 .577 .707 r
F P
0 g
s
.39032 .67569 m .39032 .63863 L .35915 .63673 L p .707 .577 .707 r
F P
0 g
s
.39032 .63863 m .39032 .67569 L .42216 .67491 L p .707 .577 .707 r
F P
0 g
s
.42216 .67491 m .42216 .63785 L .39032 .63863 L p .707 .577 .707 r
F P
0 g
s
.45154 .58883 m .45154 .64441 L .47559 .63876 L p .707 .577 .707 r
F P
0 g
s
.47559 .63876 m .47559 .58318 L .45154 .58883 L p .707 .577 .707 r
F P
0 g
s
.64524 .67496 m .64524 .63791 L .66161 .63054 L p .707 .577 .707 r
F P
0 g
s
.42216 .63785 m .42216 .67491 L .45154 .67153 L p .707 .577 .707 r
F P
0 g
s
.45154 .67153 m .45154 .63448 L .42216 .63785 L p .707 .577 .707 r
F P
0 g
s
.66161 .5849 m .66161 .64048 L .64524 .64785 L p .707 .577 .707 r
F P
0 g
s
.39032 .67708 m .39032 .65855 L .35915 .65665 L p .707 .577 .707 r
F P
0 g
s
.39032 .65855 m .39032 .67708 L .42216 .6763 L p .707 .577 .707 r
F P
0 g
s
.42216 .6763 m .42216 .65777 L .39032 .65855 L p .707 .577 .707 r
F P
0 g
s
.82657 .58784 m .82657 .64342 L .80551 .63697 L p .707 .577 .707 r
F P
0 g
s
.80551 .63697 m .80551 .58138 L .82657 .58784 L p .707 .577 .707 r
F P
0 g
s
.35915 .67379 m .35915 .63673 L .33169 .63234 L p .707 .577 .707 r
F P
0 g
s
.35915 .63673 m .35915 .67379 L .39032 .67569 L p .707 .577 .707 r
F P
0 g
s
.64524 .67636 m .64524 .65783 L .66161 .65046 L p .707 .577 .707 r
F P
0 g
s
.42216 .65777 m .42216 .6763 L .45154 .67292 L p .707 .577 .707 r
F P
0 g
s
.45154 .67292 m .45154 .6544 L .42216 .65777 L p .707 .577 .707 r
F P
0 g
s
.33169 .58669 m .33169 .64228 L .35915 .64667 L p .707 .577 .707 r
F P
0 g
s
.33169 .64228 m .33169 .58669 L .31064 .58024 L p .707 .577 .707 r
F P
0 g
s
.35915 .65665 m .35915 .67518 L .39032 .67708 L p .707 .577 .707 r
F P
0 g
s
.35915 .67518 m .35915 .65665 L .33169 .65226 L p .707 .577 .707 r
F P
0 g
s
.66161 .63054 m .66161 .6676 L .64524 .67496 L p .707 .577 .707 r
F P
0 g
s
.66161 .65046 m .66161 .66899 L .64524 .67636 L p .707 .577 .707 r
F P
0 g
s
.45154 .63448 m .45154 .67153 L .47559 .66588 L p .707 .577 .707 r
F P
0 g
s
.47559 .66588 m .47559 .62883 L .45154 .63448 L p .707 .577 .707 r
F P
0 g
s
.66161 .64048 m .66161 .5849 L .68566 .57925 L p .707 .577 .707 r
F P
0 g
s
.33169 .63234 m .33169 .66939 L .35915 .67379 L p .707 .577 .707 r
F P
0 g
s
.33169 .65226 m .33169 .67079 L .35915 .67518 L p .707 .577 .707 r
F P
0 g
s
.82657 .63348 m .82657 .67054 L .80551 .66408 L p .707 .577 .707 r
F P
0 g
s
.80551 .66408 m .80551 .62703 L .82657 .63348 L p .707 .577 .707 r
F P
0 g
s
.45154 .6544 m .45154 .67292 L .47559 .66727 L p .707 .577 .707 r
F P
0 g
s
.47559 .66727 m .47559 .64875 L .45154 .6544 L p .707 .577 .707 r
F P
0 g
s
.47559 .58318 m .47559 .63876 L .49196 .6314 L p .707 .577 .707 r
F P
0 g
s
.49196 .6314 m .49196 .57581 L .47559 .58318 L p .707 .577 .707 r
F P
0 g
s
.33169 .66939 m .33169 .63234 L .31064 .62588 L p .707 .577 .707 r
F P
0 g
s
.82657 .6534 m .82657 .67193 L .80551 .66548 L p .707 .577 .707 r
F P
0 g
s
.80551 .66548 m .80551 .64695 L .82657 .6534 L p .707 .577 .707 r
F P
0 g
s
.31064 .58024 m .31064 .63582 L .33169 .64228 L p .707 .577 .707 r
F P
0 g
s
.33169 .67079 m .33169 .65226 L .31064 .6458 L p .707 .577 .707 r
F P
0 g
s
.80551 .58138 m .80551 .63697 L .77805 .63257 L p .707 .577 .707 r
F P
0 g
s
.77805 .63257 m .77805 .57699 L .80551 .58138 L p .707 .577 .707 r
F P
0 g
s
.66161 .6676 m .66161 .63054 L .68566 .62489 L p .707 .577 .707 r
F P
0 g
s
.68566 .57925 m .68566 .63483 L .66161 .64048 L p .707 .577 .707 r
F P
0 g
s
.31064 .62588 m .31064 .66294 L .33169 .66939 L p .707 .577 .707 r
F P
0 g
s
.31064 .63582 m .31064 .58024 L .29804 .57236 L p .707 .577 .707 r
F P
0 g
s
.31064 .6458 m .31064 .66433 L .33169 .67079 L p .707 .577 .707 r
F P
0 g
s
.66161 .66899 m .66161 .65046 L .68566 .64481 L p .707 .577 .707 r
F P
0 g
s
.47559 .62883 m .47559 .66588 L .49196 .65851 L p .707 .577 .707 r
F P
0 g
s
.49196 .65851 m .49196 .62146 L .47559 .62883 L p .707 .577 .707 r
F P
0 g
s
.68566 .63483 m .68566 .57925 L .71504 .57587 L p .707 .577 .707 r
F P
0 g
s
.68566 .62489 m .68566 .66195 L .66161 .6676 L p .707 .577 .707 r
F P
0 g
s
.68566 .64481 m .68566 .66334 L .66161 .66899 L p .707 .577 .707 r
F P
0 g
s
.47559 .64875 m .47559 .66727 L .49196 .65991 L p .707 .577 .707 r
F P
0 g
s
.49196 .65991 m .49196 .64138 L .47559 .64875 L p .707 .577 .707 r
F P
0 g
s
.80551 .62703 m .80551 .66408 L .77805 .65969 L p .707 .577 .707 r
F P
0 g
s
.77805 .65969 m .77805 .62264 L .80551 .62703 L p .707 .577 .707 r
F P
0 g
s
.77805 .57699 m .77805 .63257 L .74688 .63067 L p .707 .577 .707 r
F P
0 g
s
.74688 .63067 m .74688 .57509 L .77805 .57699 L p .707 .577 .707 r
F P
0 g
s
.31064 .66294 m .31064 .62588 L .29804 .618 L p .707 .577 .707 r
F P
0 g
s
.80551 .64695 m .80551 .66548 L .77805 .66108 L p .707 .577 .707 r
F P
0 g
s
.77805 .66108 m .77805 .64256 L .80551 .64695 L p .707 .577 .707 r
F P
0 g
s
.29804 .57236 m .29804 .62794 L .31064 .63582 L p .707 .577 .707 r
F P
0 g
s
.71504 .63145 m .71504 .57587 L .74688 .57509 L p .707 .577 .707 r
F P
0 g
s
.71504 .57587 m .71504 .63145 L .68566 .63483 L p .707 .577 .707 r
F P
0 g
s
.49196 .57581 m .49196 .6314 L .49904 .62303 L p .707 .577 .707 r
F P
0 g
s
.49904 .62303 m .49904 .56745 L .49196 .57581 L p .707 .577 .707 r
F P
0 g
s
.68566 .66195 m .68566 .62489 L .71504 .62151 L p .707 .577 .707 r
F P
0 g
s
.31064 .66433 m .31064 .6458 L .29804 .63792 L p .707 .577 .707 r
F P
0 g
s
.74688 .57509 m .74688 .63067 L .71504 .63145 L p .707 .577 .707 r
F P
0 g
s
.68566 .66334 m .68566 .64481 L .71504 .64143 L p .707 .577 .707 r
F P
0 g
s
.29804 .618 m .29804 .65506 L .31064 .66294 L p .707 .577 .707 r
F P
0 g
s
.29804 .63792 m .29804 .65645 L .31064 .66433 L p .707 .577 .707 r
F P
0 g
s
.77805 .62264 m .77805 .65969 L .74688 .65779 L p .707 .577 .707 r
F P
0 g
s
.74688 .65779 m .74688 .62074 L .77805 .62264 L p .707 .577 .707 r
F P
0 g
s
.71504 .62151 m .71504 .65857 L .68566 .66195 L p .707 .577 .707 r
F P
0 g
s
.71504 .64143 m .71504 .65996 L .68566 .66334 L p .707 .577 .707 r
F P
0 g
s
.29804 .62794 m .29804 .57236 L .29515 .56381 L p .707 .577 .707 r
F P
0 g
s
.71504 .65857 m .71504 .62151 L .74688 .62074 L p .707 .577 .707 r
F P
0 g
s
.49196 .62146 m .49196 .65851 L .49904 .65015 L p .707 .577 .707 r
F P
0 g
s
.49904 .65015 m .49904 .61309 L .49196 .62146 L p .707 .577 .707 r
F P
0 g
s
.77805 .64256 m .77805 .66108 L .74688 .65918 L p .707 .577 .707 r
F P
0 g
s
.74688 .65918 m .74688 .64066 L .77805 .64256 L p .707 .577 .707 r
F P
0 g
s
.74688 .62074 m .74688 .65779 L .71504 .65857 L p .707 .577 .707 r
F P
0 g
s
.71504 .65996 m .71504 .64143 L .74688 .64066 L p .707 .577 .707 r
F P
0 g
s
.49196 .64138 m .49196 .65991 L .49904 .65154 L p .707 .577 .707 r
F P
0 g
s
.49904 .65154 m .49904 .63301 L .49196 .64138 L p .707 .577 .707 r
F P
0 g
s
.74688 .64066 m .74688 .65918 L .71504 .65996 L p .707 .577 .707 r
F P
0 g
s
.29804 .65506 m .29804 .618 L .29515 .60946 L p .707 .577 .707 r
F P
0 g
s
.29515 .56381 m .29515 .6194 L .29804 .62794 L p .707 .577 .707 r
F P
0 g
s
.49904 .56745 m .49904 .62303 L .49615 .61449 L p .707 .577 .707 r
F P
0 g
s
.49615 .61449 m .49615 .55891 L .49904 .56745 L p .707 .577 .707 r
F P
0 g
s
.29804 .65645 m .29804 .63792 L .29515 .62938 L p .707 .577 .707 r
F P
0 g
s
.29515 .60946 m .29515 .64651 L .29804 .65506 L p .707 .577 .707 r
F P
0 g
s
.29515 .62938 m .29515 .64791 L .29804 .65645 L p .707 .577 .707 r
F P
0 g
s
.49904 .61309 m .49904 .65015 L .49615 .64161 L p .707 .577 .707 r
F P
0 g
s
.49615 .64161 m .49615 .60455 L .49904 .61309 L p .707 .577 .707 r
F P
0 g
s
.29515 .6194 m .29515 .56381 L .30223 .55545 L p .707 .577 .707 r
F P
0 g
s
.49904 .63301 m .49904 .65154 L .49615 .643 L p .707 .577 .707 r
F P
0 g
s
.49615 .643 m .49615 .62447 L .49904 .63301 L p .707 .577 .707 r
F P
0 g
s
.29515 .64651 m .29515 .60946 L .30223 .60109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55545 m .30223 .61103 L .29515 .6194 L p .707 .577 .707 r
F P
0 g
s
.49615 .55891 m .49615 .61449 L .48356 .6066 L p .707 .577 .707 r
F P
0 g
s
.48356 .6066 m .48356 .55102 L .49615 .55891 L p .707 .577 .707 r
F P
0 g
s
.29515 .64791 m .29515 .62938 L .30223 .62101 L p .707 .577 .707 r
F P
0 g
s
.30223 .60109 m .30223 .63815 L .29515 .64651 L p .707 .577 .707 r
F P
0 g
s
.30223 .62101 m .30223 .63954 L .29515 .64791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61103 m .30223 .55545 L .3186 .54808 L p .707 .577 .707 r
F P
0 g
s
.49615 .60455 m .49615 .64161 L .48356 .63372 L p .707 .577 .707 r
F P
0 g
s
.48356 .63372 m .48356 .59667 L .49615 .60455 L p .707 .577 .707 r
F P
0 g
s
.49615 .62447 m .49615 .643 L .48356 .63511 L p .707 .577 .707 r
F P
0 g
s
.48356 .63511 m .48356 .61659 L .49615 .62447 L p .707 .577 .707 r
F P
0 g
s
.30223 .63815 m .30223 .60109 L .3186 .59373 L p .707 .577 .707 r
F P
0 g
s
.3186 .54808 m .3186 .60366 L .30223 .61103 L p .707 .577 .707 r
F P
0 g
s
.48356 .55102 m .48356 .6066 L .4625 .60015 L p .707 .577 .707 r
F P
0 g
s
.4625 .60015 m .4625 .54457 L .48356 .55102 L p .707 .577 .707 r
F P
0 g
s
.30223 .63954 m .30223 .62101 L .3186 .61365 L p .707 .577 .707 r
F P
0 g
s
.3186 .59373 m .3186 .63078 L .30223 .63815 L p .707 .577 .707 r
F P
0 g
s
.3186 .61365 m .3186 .63217 L .30223 .63954 L p .707 .577 .707 r
F P
0 g
s
.3186 .60366 m .3186 .54808 L .34265 .54243 L p .707 .577 .707 r
F P
0 g
s
.48356 .59667 m .48356 .63372 L .4625 .62727 L p .707 .577 .707 r
F P
0 g
s
.4625 .62727 m .4625 .59021 L .48356 .59667 L p .707 .577 .707 r
F P
0 g
s
.48356 .61659 m .48356 .63511 L .4625 .62866 L p .707 .577 .707 r
F P
0 g
s
.4625 .62866 m .4625 .61013 L .48356 .61659 L p .707 .577 .707 r
F P
0 g
s
.4625 .54457 m .4625 .60015 L .43504 .59576 L p .707 .577 .707 r
F P
0 g
s
.43504 .59576 m .43504 .54018 L .4625 .54457 L p .707 .577 .707 r
F P
0 g
s
.3186 .63078 m .3186 .59373 L .34265 .58808 L p .707 .577 .707 r
F P
0 g
s
.34265 .54243 m .34265 .59801 L .3186 .60366 L p .707 .577 .707 r
F P
0 g
s
.3186 .63217 m .3186 .61365 L .34265 .608 L p .707 .577 .707 r
F P
0 g
s
.34265 .59801 m .34265 .54243 L .37203 .53905 L p .707 .577 .707 r
F P
0 g
s
.34265 .58808 m .34265 .62513 L .3186 .63078 L p .707 .577 .707 r
F P
0 g
s
.34265 .608 m .34265 .62652 L .3186 .63217 L p .707 .577 .707 r
F P
0 g
s
.4625 .59021 m .4625 .62727 L .43504 .62288 L p .707 .577 .707 r
F P
0 g
s
.43504 .62288 m .43504 .58582 L .4625 .59021 L p .707 .577 .707 r
F P
0 g
s
.43504 .54018 m .43504 .59576 L .40387 .59386 L p .707 .577 .707 r
F P
0 g
s
.40387 .59386 m .40387 .53828 L .43504 .54018 L p .707 .577 .707 r
F P
0 g
s
.4625 .61013 m .4625 .62866 L .43504 .62427 L p .707 .577 .707 r
F P
0 g
s
.43504 .62427 m .43504 .60574 L .4625 .61013 L p .707 .577 .707 r
F P
0 g
s
.37203 .59463 m .37203 .53905 L .40387 .53828 L p .707 .577 .707 r
F P
0 g
s
.37203 .53905 m .37203 .59463 L .34265 .59801 L p .707 .577 .707 r
F P
0 g
s
.34265 .62513 m .34265 .58808 L .37203 .5847 L p .707 .577 .707 r
F P
0 g
s
.40387 .53828 m .40387 .59386 L .37203 .59463 L p .707 .577 .707 r
F P
0 g
s
.34265 .62652 m .34265 .608 L .37203 .60462 L p .707 .577 .707 r
F P
0 g
s
.43504 .58582 m .43504 .62288 L .40387 .62097 L p .707 .577 .707 r
F P
0 g
s
.40387 .62097 m .40387 .58392 L .43504 .58582 L p .707 .577 .707 r
F P
0 g
s
.37203 .5847 m .37203 .62175 L .34265 .62513 L p .707 .577 .707 r
F P
0 g
s
.37203 .60462 m .37203 .62315 L .34265 .62652 L p .707 .577 .707 r
F P
0 g
s
.37203 .62175 m .37203 .5847 L .40387 .58392 L p .707 .577 .707 r
F P
0 g
s
.43504 .60574 m .43504 .62427 L .40387 .62237 L p .707 .577 .707 r
F P
0 g
s
.40387 .62237 m .40387 .60384 L .43504 .60574 L p .707 .577 .707 r
F P
0 g
s
.40387 .58392 m .40387 .62097 L .37203 .62175 L p .707 .577 .707 r
F P
0 g
s
.37203 .62315 m .37203 .60462 L .40387 .60384 L p .707 .577 .707 r
F P
0 g
s
.40387 .60384 m .40387 .62237 L .37203 .62315 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF
00UJEP03001JEUYF00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo
0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
3goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
07oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00004FUH40003FUH00`00FUIJEP05FUH>0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF100015YF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol30004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP8000=JEPT000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH4
0006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
03mooaD00003FUH005YF009JEPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001J
EP0000D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02FUH2000]Ool003Uoo`H000=J
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo
000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUH00000FUH005YF
00<00003FUH005YF00IJEQL000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH00000
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF5P000eYF
00<005YFFUH00eYF00<005YFFUH00`00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH20005FUH01000FUIJEUYF1@001eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8002eoo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000300000eYF001JEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1@0015YF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF1@0015YF00<005YF
FUH00UYF1`0000IJEP00000005YF0003FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH015YF1P0015YF3P000eYF00<005YFFUH015YF0`000eYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUH0000H0007
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000200001UYF00000000FUH000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000AJ
EP800003FUH0000000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05
001JEP00001JEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP040002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF
FUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<00003
FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF000015YF00@005YFFUIJEP800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800005FUH0
05YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0015YF4P000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00;Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF1@00
15YF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`04
001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool30004FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200001EYF001JEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD003=oo`00;7oo
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000h
Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90003FUH20004FUH9000oOol002ao
o`<000AJEP03001JEUYF00AJEP8000=JEQT000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YF
FUH01eYF00<005YFFUH015YF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH20007Ool50018Ool002aoo`03
001JEP0000AJEPD000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEP0000D00005
FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH00`00FUH0000200000eYF001JEP02FUH20007Ool50018Ool002aoo`03001JEP00009JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEPD000EJEP<0009JEP04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003
FUH20007Ool50018Ool002aoo`03001JEP0000<00006FUH00000001JEP001UYF60000eYF00<005YF
FUH015YF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH300000eYF00000008Ool30019Ool002aoo`03001JEP00009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP03001DOol002aoo`80009JEP8000EJEP03001JEUYF00<0
009JEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000<0009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@00003FUH005YF00AJ
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00800003FUH005YF00AJEP<000MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP@000=JEP04001JEUYFFUH2001DOol002ao
o`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP0000<00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00@000=JEP8005Aoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF009JEP@000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH20002FUH2001DOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YF00000`00E7oo000_Ool30005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1P00FUH00000Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0035oo`<000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50004FUH01000FUIJEUYF0P00
E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003
0006Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH015YF8@0025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF00<005YF00001@0000=JEP00FUH00UYF0P00E7oo000iOol4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP001EYF00<0
05YFFUH01UYF200035YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000010001EYF0`000eYF0P00E7oo000mOolI000?Ool01000FUIJEP001EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo0018Ool3000JOol01000FUIJEP001EYF00<005YF00000`002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP80
00=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP<00003FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP05001JEP00001JEP03001D
Ool004Moo`D001Uoo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00000UYF00@0
05YFFUIJEPD000=JEP03001JEP0005Aoo`00Agoo1@006Goo00D005YFFUH005YF008000MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH20002FUH00`00FUH000060003FUH00`00FUIJEP02FUH2001EOol004Qoo`<001Yoo`03001J
EUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00005FUH005YFFUH00006FUH00`00FUIJEP02
FUH2001EOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF
FUH00006FUH01000FUIJEUYF0P00EWoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH015YF00@005YF000005Qoo`00IGoo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF0000009JEP04001JEUYFFUH5001JOol006Eoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00L005moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH2001WOol006Moo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001WOol006Qoo`800003
FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8006Qoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Jgoo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YF000006aoo`00KGoo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF1000KWoo001aOol50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05001bOol007Ioo`H0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00=JEPP007Moo`00O7oo2@001UYF00<005YFFUH015YF3000Ogoo
0025Ool=002;Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72157 m .59613 .66599 L .56496 .66409 L p .707 .577 .707 r
F P
0 g
s
.59613 .66599 m .59613 .72157 L .62796 .72079 L p .707 .577 .707 r
F P
0 g
s
.62796 .72079 m .62796 .66521 L .59613 .66599 L p .707 .577 .707 r
F P
0 g
s
.62796 .66521 m .62796 .72079 L .65734 .71741 L p .707 .577 .707 r
F P
0 g
s
.65734 .71741 m .65734 .66183 L .62796 .66521 L p .707 .577 .707 r
F P
0 g
s
.56496 .71967 m .56496 .66409 L .5375 .65969 L p .707 .577 .707 r
F P
0 g
s
.56496 .66409 m .56496 .71967 L .59613 .72157 L p .707 .577 .707 r
F P
0 g
s
.65734 .66183 m .65734 .71741 L .6814 .71176 L p .707 .577 .707 r
F P
0 g
s
.6814 .71176 m .6814 .65618 L .65734 .66183 L p .707 .577 .707 r
F P
0 g
s
.5375 .65969 m .5375 .71528 L .56496 .71967 L p .707 .577 .707 r
F P
0 g
s
.5375 .71528 m .5375 .65969 L .51644 .65324 L p .707 .577 .707 r
F P
0 g
s
.59613 .81518 m .59613 .77812 L .56496 .77622 L p .707 .577 .707 r
F P
0 g
s
.59613 .77812 m .59613 .81518 L .62796 .8144 L p .707 .577 .707 r
F P
0 g
s
.62796 .8144 m .62796 .77734 L .59613 .77812 L p .707 .577 .707 r
F P
0 g
s
.62796 .77734 m .62796 .8144 L .65735 .81102 L p .707 .577 .707 r
F P
0 g
s
.65735 .81102 m .65735 .77397 L .62796 .77734 L p .707 .577 .707 r
F P
0 g
s
.6814 .65618 m .6814 .71176 L .69777 .7044 L p .707 .577 .707 r
F P
0 g
s
.69777 .7044 m .69777 .64881 L .6814 .65618 L p .707 .577 .707 r
F P
0 g
s
.56496 .81328 m .56496 .77622 L .5375 .77183 L p .707 .577 .707 r
F P
0 g
s
.56496 .77622 m .56496 .81328 L .59613 .81518 L p .707 .577 .707 r
F P
0 g
s
.51644 .65324 m .51644 .70882 L .5375 .71528 L p .707 .577 .707 r
F P
0 g
s
.51644 .70882 m .51644 .65324 L .50385 .64536 L p .707 .577 .707 r
F P
0 g
s
.65735 .77397 m .65735 .81102 L .6814 .80537 L p .707 .577 .707 r
F P
0 g
s
.6814 .80537 m .6814 .76832 L .65735 .77397 L p .707 .577 .707 r
F P
0 g
s
.5375 .77183 m .5375 .80888 L .56496 .81328 L p .707 .577 .707 r
F P
0 g
s
.5375 .80888 m .5375 .77183 L .51644 .76537 L p .707 .577 .707 r
F P
0 g
s
.59613 .89745 m .59613 .87893 L .56496 .87702 L p .707 .577 .707 r
F P
0 g
s
.59613 .87893 m .59613 .89745 L .62796 .89668 L p .707 .577 .707 r
F P
0 g
s
.62796 .89668 m .62796 .87815 L .59613 .87893 L p .707 .577 .707 r
F P
0 g
s
.50385 .64536 m .50385 .70094 L .51644 .70882 L p .707 .577 .707 r
F P
0 g
s
.69777 .64881 m .69777 .7044 L .70485 .69603 L p .707 .577 .707 r
F P
0 g
s
.70485 .69603 m .70485 .64045 L .69777 .64881 L p .707 .577 .707 r
F P
0 g
s
.62796 .87815 m .62796 .89668 L .65735 .8933 L p .707 .577 .707 r
F P
0 g
s
.65735 .8933 m .65735 .87477 L .62796 .87815 L p .707 .577 .707 r
F P
0 g
s
.51644 .76537 m .51644 .80243 L .5375 .80888 L p .707 .577 .707 r
F P
0 g
s
.56496 .87702 m .56496 .89555 L .59613 .89745 L p .707 .577 .707 r
F P
0 g
s
.56496 .89555 m .56496 .87702 L .5375 .87263 L p .707 .577 .707 r
F P
0 g
s
.6814 .76832 m .6814 .80537 L .69777 .798 L p .707 .577 .707 r
F P
0 g
s
.69777 .798 m .69777 .76095 L .6814 .76832 L p .707 .577 .707 r
F P
0 g
s
.5375 .87263 m .5375 .89116 L .56496 .89555 L p .707 .577 .707 r
F P
0 g
s
.50385 .70094 m .50385 .64536 L .50095 .63681 L p .707 .577 .707 r
F P
0 g
s
.65735 .87477 m .65735 .8933 L .6814 .88765 L p .707 .577 .707 r
F P
0 g
s
.6814 .88765 m .6814 .86912 L .65735 .87477 L p .707 .577 .707 r
F P
0 g
s
.51644 .80243 m .51644 .76537 L .50385 .75749 L p .707 .577 .707 r
F P
0 g
s
.5375 .89116 m .5375 .87263 L .51644 .86618 L p .707 .577 .707 r
F P
0 g
s
.51644 .86618 m .51644 .88471 L .5375 .89116 L p .707 .577 .707 r
F P
0 g
s
.50385 .75749 m .50385 .79455 L .51644 .80243 L p .707 .577 .707 r
F P
0 g
s
.50095 .63681 m .50095 .6924 L .50385 .70094 L p .707 .577 .707 r
F P
0 g
s
.70485 .64045 m .70485 .69603 L .70195 .68749 L p .707 .577 .707 r
F P
0 g
s
.70195 .68749 m .70195 .63191 L .70485 .64045 L p .707 .577 .707 r
F P
0 g
s
.69777 .76095 m .69777 .798 L .70485 .78964 L p .707 .577 .707 r
F P
0 g
s
.70485 .78964 m .70485 .75258 L .69777 .76095 L p .707 .577 .707 r
F P
0 g
s
.6814 .86912 m .6814 .88765 L .69777 .88028 L p .707 .577 .707 r
F P
0 g
s
.69777 .88028 m .69777 .86175 L .6814 .86912 L p .707 .577 .707 r
F P
0 g
s
.50095 .6924 m .50095 .63681 L .50804 .62845 L p .707 .577 .707 r
F P
0 g
s
.49044 .80603 m .49044 .30415 L .44643 .30146 L p .707 .577 .707 r
F P
0 g
s
.50385 .79455 m .50385 .75749 L .50095 .74895 L p .707 .577 .707 r
F P
0 g
s
.50095 .74895 m .50095 .786 L .50385 .79455 L p .707 .577 .707 r
F P
0 g
s
.50804 .62845 m .50804 .68403 L .50095 .6924 L p .707 .577 .707 r
F P
0 g
s
.50804 .68403 m .50804 .62845 L .5244 .62108 L p .707 .577 .707 r
F P
0 g
s
.50095 .786 m .50095 .74895 L .50804 .74058 L p .707 .577 .707 r
F P
0 g
s
.50804 .74058 m .50804 .77764 L .50095 .786 L p .707 .577 .707 r
F P
0 g
s
.5244 .62108 m .5244 .67666 L .50804 .68403 L p .707 .577 .707 r
F P
0 g
s
.50804 .77764 m .50804 .74058 L .5244 .73322 L p .707 .577 .707 r
F P
0 g
s
.5244 .73322 m .5244 .77027 L .50804 .77764 L p .707 .577 .707 r
F P
0 g
s
.5244 .77027 m .5244 .73322 L .54846 .72757 L p .707 .577 .707 r
F P
0 g
s
.54846 .72757 m .54846 .76462 L .5244 .77027 L p .707 .577 .707 r
F P
0 g
s
.49044 .30415 m .49044 .80603 L .53538 .80494 L p .707 .577 .707 r
F P
0 g
s
.5244 .67666 m .5244 .62108 L .54846 .61543 L p .707 .577 .707 r
F P
0 g
s
.54846 .61543 m .54846 .67101 L .5244 .67666 L p .707 .577 .707 r
F P
0 g
s
.53538 .80494 m .53538 .30305 L .49044 .30415 L p .707 .577 .707 r
F P
0 g
s
.51644 .88471 m .51644 .86618 L .50385 .85829 L p .707 .577 .707 r
F P
0 g
s
.54846 .67101 m .54846 .61543 L .57784 .61205 L p .707 .577 .707 r
F P
0 g
s
.57784 .61205 m .57784 .66763 L .54846 .67101 L p .707 .577 .707 r
F P
0 g
s
.54846 .76462 m .54846 .72757 L .57784 .72419 L p .707 .577 .707 r
F P
0 g
s
.57784 .72419 m .57784 .76124 L .54846 .76462 L p .707 .577 .707 r
F P
0 g
s
.53538 .30305 m .53538 .80494 L .57686 .80017 L p .707 .577 .707 r
F P
0 g
s
.57686 .80017 m .57686 .29828 L .53538 .30305 L p .707 .577 .707 r
F P
0 g
s
.50385 .85829 m .50385 .87682 L .51644 .88471 L p .707 .577 .707 r
F P
0 g
s
.44643 .80335 m .44643 .30146 L .40766 .29526 L p .707 .577 .707 r
F P
0 g
s
.44643 .30146 m .44643 .80335 L .49044 .80603 L p .707 .577 .707 r
F P
0 g
s
.69777 .86175 m .69777 .88028 L .70485 .87191 L p .707 .577 .707 r
F P
0 g
s
.70485 .87191 m .70485 .85339 L .69777 .86175 L p .707 .577 .707 r
F P
0 g
s
.70195 .63191 m .70195 .68749 L .68936 .6796 L p .707 .577 .707 r
F P
0 g
s
.68936 .6796 m .68936 .62402 L .70195 .63191 L p .707 .577 .707 r
F P
0 g
s
.70485 .75258 m .70485 .78964 L .70195 .7811 L p .707 .577 .707 r
F P
0 g
s
.70195 .7811 m .70195 .74404 L .70485 .75258 L p .707 .577 .707 r
F P
0 g
s
.57784 .66763 m .57784 .61205 L .60968 .61128 L p .707 .577 .707 r
F P
0 g
s
.60968 .61128 m .60968 .66686 L .57784 .66763 L p .707 .577 .707 r
F P
0 g
s
.57784 .76124 m .57784 .72419 L .60968 .72341 L p .707 .577 .707 r
F P
0 g
s
.60968 .72341 m .60968 .76047 L .57784 .76124 L p .707 .577 .707 r
F P
0 g
s
.57686 .29828 m .57686 .80017 L .61082 .79219 L p .707 .577 .707 r
F P
0 g
s
.64085 .61318 m .64085 .66876 L .60968 .66686 L p .707 .577 .707 r
F P
0 g
s
.60968 .66686 m .60968 .61128 L .64085 .61318 L p .707 .577 .707 r
F P
0 g
s
.64085 .72531 m .64085 .76237 L .60968 .76047 L p .707 .577 .707 r
F P
0 g
s
.60968 .76047 m .60968 .72341 L .64085 .72531 L p .707 .577 .707 r
F P
0 g
s
.61082 .79219 m .61082 .2903 L .57686 .29828 L p .707 .577 .707 r
F P
0 g
s
.25312 .68475 m .25312 .62917 L .22195 .62727 L p .707 .577 .707 r
F P
0 g
s
.25312 .62917 m .25312 .68475 L .28495 .68398 L p .707 .577 .707 r
F P
0 g
s
.28495 .68398 m .28495 .62839 L .25312 .62917 L p .707 .577 .707 r
F P
0 g
s
.50385 .87682 m .50385 .85829 L .50095 .84975 L p .707 .577 .707 r
F P
0 g
s
.28495 .62839 m .28495 .68398 L .31434 .6806 L p .707 .577 .707 r
F P
0 g
s
.31434 .6806 m .31434 .62502 L .28495 .62839 L p .707 .577 .707 r
F P
0 g
s
.40766 .79715 m .40766 .29526 L .37794 .28615 L p .707 .577 .707 r
F P
0 g
s
.40766 .29526 m .40766 .79715 L .44643 .80335 L p .707 .577 .707 r
F P
0 g
s
.50095 .84975 m .50095 .86828 L .50385 .87682 L p .707 .577 .707 r
F P
0 g
s
.22195 .68285 m .22195 .62727 L .19449 .62288 L p .707 .577 .707 r
F P
0 g
s
.22195 .62727 m .22195 .68285 L .25312 .68475 L p .707 .577 .707 r
F P
0 g
s
.31434 .62502 m .31434 .6806 L .33839 .67495 L p .707 .577 .707 r
F P
0 g
s
.33839 .67495 m .33839 .61937 L .31434 .62502 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68936 .62402 m .68936 .6796 L .66831 .67315 L p .707 .577 .707 r
F P
0 g
s
.66831 .67315 m .66831 .61757 L .68936 .62402 L p .707 .577 .707 r
F P
0 g
s
.70485 .85339 m .70485 .87191 L .70195 .86337 L p .707 .577 .707 r
F P
0 g
s
.70195 .86337 m .70195 .84485 L .70485 .85339 L p .707 .577 .707 r
F P
0 g
s
.70195 .74404 m .70195 .7811 L .68936 .77321 L p .707 .577 .707 r
F P
0 g
s
.68936 .77321 m .68936 .73616 L .70195 .74404 L p .707 .577 .707 r
F P
0 g
s
.19449 .62288 m .19449 .67846 L .22195 .68285 L p .707 .577 .707 r
F P
0 g
s
.61082 .2903 m .61082 .79219 L .63393 .78179 L p .707 .577 .707 r
F P
0 g
s
.63393 .78179 m .63393 .2799 L .61082 .2903 L p .707 .577 .707 r
F P
0 g
s
.19449 .67846 m .19449 .62288 L .17343 .61642 L p .707 .577 .707 r
F P
0 g
s
.25312 .77836 m .25312 .74131 L .22195 .73941 L p .707 .577 .707 r
F P
0 g
s
.25312 .74131 m .25312 .77836 L .28495 .77758 L p .707 .577 .707 r
F P
0 g
s
.28495 .77758 m .28495 .74053 L .25312 .74131 L p .707 .577 .707 r
F P
0 g
s
.50095 .86828 m .50095 .84975 L .50804 .84139 L p .707 .577 .707 r
F P
0 g
s
.28495 .74053 m .28495 .77758 L .31434 .7742 L p .707 .577 .707 r
F P
0 g
s
.31434 .7742 m .31434 .73715 L .28495 .74053 L p .707 .577 .707 r
F P
0 g
s
.33839 .61937 m .33839 .67495 L .35476 .66758 L p .707 .577 .707 r
F P
0 g
s
.35476 .66758 m .35476 .612 L .33839 .61937 L p .707 .577 .707 r
F P
0 g
s
.50804 .84139 m .50804 .85992 L .50095 .86828 L p .707 .577 .707 r
F P
0 g
s
.37794 .78804 m .37794 .28615 L .36016 .27502 L p .707 .577 .707 r
F P
0 g
s
.37794 .28615 m .37794 .78804 L .40766 .79715 L p .707 .577 .707 r
F P
0 g
s
.22195 .77646 m .22195 .73941 L .19449 .73501 L p .707 .577 .707 r
F P
0 g
s
.22195 .73941 m .22195 .77646 L .25312 .77836 L p .707 .577 .707 r
F P
0 g
s
.17343 .61642 m .17343 .67201 L .19449 .67846 L p .707 .577 .707 r
F P
0 g
s
.66831 .61757 m .66831 .67315 L .64085 .66876 L p .707 .577 .707 r
F P
0 g
s
.64085 .66876 m .64085 .61318 L .66831 .61757 L p .707 .577 .707 r
F P
0 g
s
.17343 .67201 m .17343 .61642 L .16084 .60854 L p .707 .577 .707 r
F P
0 g
s
.31434 .73715 m .31434 .7742 L .33839 .76855 L p .707 .577 .707 r
F P
0 g
s
.33839 .76855 m .33839 .7315 L .31434 .73715 L p .707 .577 .707 r
F P
0 g
s
.19449 .73501 m .19449 .77207 L .22195 .77646 L p .707 .577 .707 r
F P
0 g
s
.70195 .84485 m .70195 .86337 L .68936 .85549 L p .707 .577 .707 r
F P
0 g
s
.68936 .85549 m .68936 .83696 L .70195 .84485 L p .707 .577 .707 r
F P
0 g
s
.68936 .73616 m .68936 .77321 L .66831 .76676 L p .707 .577 .707 r
F P
0 g
s
.66831 .76676 m .66831 .7297 L .68936 .73616 L p .707 .577 .707 r
F P
0 g
s
.19449 .77207 m .19449 .73501 L .17343 .72856 L p .707 .577 .707 r
F P
0 g
s
.25312 .86064 m .25312 .84211 L .22195 .84021 L p .707 .577 .707 r
F P
0 g
s
.25312 .84211 m .25312 .86064 L .28495 .85986 L p .707 .577 .707 r
F P
0 g
s
.28495 .85986 m .28495 .84133 L .25312 .84211 L p .707 .577 .707 r
F P
0 g
s
.66831 .7297 m .66831 .76676 L .64085 .76237 L p .707 .577 .707 r
F P
0 g
s
.64085 .76237 m .64085 .72531 L .66831 .7297 L p .707 .577 .707 r
F P
0 g
s
.63393 .2799 m .63393 .78179 L .64393 .76998 L p .707 .577 .707 r
F P
0 g
s
.64393 .76998 m .64393 .26809 L .63393 .2799 L p .707 .577 .707 r
F P
0 g
s
.16084 .60854 m .16084 .66412 L .17343 .67201 L p .707 .577 .707 r
F P
0 g
s
.35476 .612 m .35476 .66758 L .36184 .65922 L p .707 .577 .707 r
F P
0 g
s
.36184 .65922 m .36184 .60363 L .35476 .612 L p .707 .577 .707 r
F P
0 g
s
.50804 .85992 m .50804 .84139 L .5244 .83402 L p .707 .577 .707 r
F P
0 g
s
.28495 .84133 m .28495 .85986 L .31434 .85648 L p .707 .577 .707 r
F P
0 g
s
.31434 .85648 m .31434 .83795 L .28495 .84133 L p .707 .577 .707 r
F P
0 g
s
.17343 .72856 m .17343 .76561 L .19449 .77207 L p .707 .577 .707 r
F P
0 g
s
.22195 .84021 m .22195 .85874 L .25312 .86064 L p .707 .577 .707 r
F P
0 g
s
.22195 .85874 m .22195 .84021 L .19449 .83582 L p .707 .577 .707 r
F P
0 g
s
.33839 .7315 m .33839 .76855 L .35476 .76119 L p .707 .577 .707 r
F P
0 g
s
.35476 .76119 m .35476 .72413 L .33839 .7315 L p .707 .577 .707 r
F P
0 g
s
.5244 .83402 m .5244 .85255 L .50804 .85992 L p .707 .577 .707 r
F P
0 g
s
.19449 .83582 m .19449 .85434 L .22195 .85874 L p .707 .577 .707 r
F P
0 g
s
.16084 .66412 m .16084 .60854 L .15794 .6 L p .707 .577 .707 r
F P
0 g
s
.31434 .83795 m .31434 .85648 L .33839 .85083 L p .707 .577 .707 r
F P
0 g
s
.33839 .85083 m .33839 .8323 L .31434 .83795 L p .707 .577 .707 r
F P
0 g
s
.17343 .76561 m .17343 .72856 L .16084 .72068 L p .707 .577 .707 r
F P
0 g
s
.36184 .60363 m .36184 .65922 L .35894 .65067 L p .707 .577 .707 r
F P
0 g
s
.35894 .65067 m .35894 .59509 L .36184 .60363 L p .707 .577 .707 r
F P
0 g
s
.35476 .72413 m .35476 .76119 L .36184 .75282 L p .707 .577 .707 r
F P
0 g
s
.36184 .75282 m .36184 .71577 L .35476 .72413 L p .707 .577 .707 r
F P
0 g
s
.35894 .59509 m .35894 .65067 L .34635 .64279 L p .707 .577 .707 r
F P
0 g
s
.34635 .64279 m .34635 .58721 L .35894 .59509 L p .707 .577 .707 r
F P
0 g
s
.36184 .71577 m .36184 .75282 L .35894 .74428 L p .707 .577 .707 r
F P
0 g
s
.35894 .74428 m .35894 .70723 L .36184 .71577 L p .707 .577 .707 r
F P
0 g
s
.36016 .77691 m .36016 .27502 L .35607 .26296 L p .707 .577 .707 r
F P
0 g
s
.36016 .27502 m .36016 .77691 L .37794 .78804 L p .707 .577 .707 r
F P
0 g
s
.68936 .83696 m .68936 .85549 L .66831 .84903 L p .707 .577 .707 r
F P
0 g
s
.66831 .84903 m .66831 .83051 L .68936 .83696 L p .707 .577 .707 r
F P
0 g
s
.19449 .85434 m .19449 .83582 L .17343 .82936 L p .707 .577 .707 r
F P
0 g
s
.17343 .82936 m .17343 .84789 L .19449 .85434 L p .707 .577 .707 r
F P
0 g
s
.16084 .72068 m .16084 .75773 L .17343 .76561 L p .707 .577 .707 r
F P
0 g
s
.5244 .85255 m .5244 .83402 L .54846 .82837 L p .707 .577 .707 r
F P
0 g
s
.15794 .6 m .15794 .65558 L .16084 .66412 L p .707 .577 .707 r
F P
0 g
s
.54846 .82837 m .54846 .8469 L .5244 .85255 L p .707 .577 .707 r
F P
0 g
s
.33839 .8323 m .33839 .85083 L .35476 .84346 L p .707 .577 .707 r
F P
0 g
s
.35476 .84346 m .35476 .82494 L .33839 .8323 L p .707 .577 .707 r
F P
0 g
s
.66831 .83051 m .66831 .84903 L .64085 .84464 L p .707 .577 .707 r
F P
0 g
s
.64085 .84464 m .64085 .82611 L .66831 .83051 L p .707 .577 .707 r
F P
0 g
s
.64393 .26809 m .64393 .76998 L .63984 .75792 L p .707 .577 .707 r
F P
0 g
s
.63984 .75792 m .63984 .25603 L .64393 .26809 L p .707 .577 .707 r
F P
0 g
s
.15794 .65558 m .15794 .6 L .16503 .59163 L p .707 .577 .707 r
F P
0 g
s
.17343 .84789 m .17343 .82936 L .16084 .82148 L p .707 .577 .707 r
F P
0 g
s
.16084 .75773 m .16084 .72068 L .15794 .71213 L p .707 .577 .707 r
F P
0 g
s
.54846 .8469 m .54846 .82837 L .57784 .82499 L p .707 .577 .707 r
F P
0 g
s
.16084 .82148 m .16084 .84001 L .17343 .84789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.57784 .82499 m .57784 .84352 L .54846 .8469 L p .707 .577 .707 r
F P
0 g
s
.15794 .71213 m .15794 .74919 L .16084 .75773 L p .707 .577 .707 r
F P
0 g
s
.64085 .82611 m .64085 .84464 L .60968 .84274 L p .707 .577 .707 r
F P
0 g
s
.60968 .84274 m .60968 .82421 L .64085 .82611 L p .707 .577 .707 r
F P
0 g
s
.16503 .59163 m .16503 .64722 L .15794 .65558 L p .707 .577 .707 r
F P
0 g
s
.35894 .70723 m .35894 .74428 L .34635 .7364 L p .707 .577 .707 r
F P
0 g
s
.34635 .7364 m .34635 .69934 L .35894 .70723 L p .707 .577 .707 r
F P
0 g
s
.35607 .26296 m .35607 .76485 L .36016 .77691 L p .707 .577 .707 r
F P
0 g
s
.35607 .76485 m .35607 .26296 L .36607 .25115 L p .707 .577 .707 r
F P
0 g
s
.57784 .84352 m .57784 .82499 L .60968 .82421 L p .707 .577 .707 r
F P
0 g
s
.35476 .82494 m .35476 .84346 L .36184 .8351 L p .707 .577 .707 r
F P
0 g
s
.36184 .8351 m .36184 .81657 L .35476 .82494 L p .707 .577 .707 r
F P
0 g
s
.60968 .82421 m .60968 .84274 L .57784 .84352 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .84001 m .16084 .82148 L .15794 .81294 L p .707 .577 .707 r
F P
0 g
s
.16503 .64722 m .16503 .59163 L .1814 .58427 L p .707 .577 .707 r
F P
0 g
s
.15794 .74919 m .15794 .71213 L .16503 .70377 L p .707 .577 .707 r
F P
0 g
s
.15794 .81294 m .15794 .83146 L .16084 .84001 L p .707 .577 .707 r
F P
0 g
s
.63984 .25603 m .63984 .75792 L .62206 .74679 L p .707 .577 .707 r
F P
0 g
s
.62206 .74679 m .62206 .2449 L .63984 .25603 L p .707 .577 .707 r
F P
0 g
s
.16503 .70377 m .16503 .74082 L .15794 .74919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58427 m .1814 .63985 L .16503 .64722 L p .707 .577 .707 r
F P
0 g
s
.34635 .58721 m .34635 .64279 L .3253 .63634 L p .707 .577 .707 r
F P
0 g
s
.3253 .63634 m .3253 .58075 L .34635 .58721 L p .707 .577 .707 r
F P
0 g
s
.36184 .81657 m .36184 .8351 L .35894 .82656 L p .707 .577 .707 r
F P
0 g
s
.35894 .82656 m .35894 .80803 L .36184 .81657 L p .707 .577 .707 r
F P
0 g
s
.1814 .63985 m .1814 .58427 L .20545 .57862 L p .707 .577 .707 r
F P
0 g
s
.36607 .75304 m .36607 .25115 L .38918 .24075 L p .707 .577 .707 r
F P
0 g
s
.36607 .25115 m .36607 .75304 L .35607 .76485 L p .707 .577 .707 r
F P
0 g
s
.15794 .83146 m .15794 .81294 L .16503 .80457 L p .707 .577 .707 r
F P
0 g
s
.16503 .74082 m .16503 .70377 L .1814 .6964 L p .707 .577 .707 r
F P
0 g
s
.16503 .80457 m .16503 .8231 L .15794 .83146 L p .707 .577 .707 r
F P
0 g
s
.3253 .58075 m .3253 .63634 L .29784 .63194 L p .707 .577 .707 r
F P
0 g
s
.29784 .63194 m .29784 .57636 L .3253 .58075 L p .707 .577 .707 r
F P
0 g
s
.1814 .6964 m .1814 .73346 L .16503 .74082 L p .707 .577 .707 r
F P
0 g
s
.20545 .57862 m .20545 .6342 L .1814 .63985 L p .707 .577 .707 r
F P
0 g
s
.20545 .6342 m .20545 .57862 L .23483 .57524 L p .707 .577 .707 r
F P
0 g
s
.35894 .80803 m .35894 .82656 L .34635 .81867 L p .707 .577 .707 r
F P
0 g
s
.34635 .81867 m .34635 .80015 L .35894 .80803 L p .707 .577 .707 r
F P
0 g
s
.34635 .69934 m .34635 .7364 L .3253 .72994 L p .707 .577 .707 r
F P
0 g
s
.3253 .72994 m .3253 .69289 L .34635 .69934 L p .707 .577 .707 r
F P
0 g
s
.62206 .2449 m .62206 .74679 L .59233 .73768 L p .707 .577 .707 r
F P
0 g
s
.59233 .73768 m .59233 .23579 L .62206 .2449 L p .707 .577 .707 r
F P
0 g
s
.29784 .57636 m .29784 .63194 L .26667 .63004 L p .707 .577 .707 r
F P
0 g
s
.26667 .63004 m .26667 .57446 L .29784 .57636 L p .707 .577 .707 r
F P
0 g
s
.1814 .73346 m .1814 .6964 L .20545 .69075 L p .707 .577 .707 r
F P
0 g
s
.23483 .63082 m .23483 .57524 L .26667 .57446 L p .707 .577 .707 r
F P
0 g
s
.23483 .57524 m .23483 .63082 L .20545 .6342 L p .707 .577 .707 r
F P
0 g
s
.16503 .8231 m .16503 .80457 L .1814 .79721 L p .707 .577 .707 r
F P
0 g
s
.26667 .57446 m .26667 .63004 L .23483 .63082 L p .707 .577 .707 r
F P
0 g
s
.73333 .62953 m .73333 .57395 L .70216 .57205 L p .707 .577 .707 r
F P
0 g
s
.73333 .57395 m .73333 .62953 L .76517 .62875 L p .707 .577 .707 r
F P
0 g
s
.76517 .62875 m .76517 .57317 L .73333 .57395 L p .707 .577 .707 r
F P
0 g
s
.1814 .79721 m .1814 .81573 L .16503 .8231 L p .707 .577 .707 r
F P
0 g
s
.38918 .24075 m .38918 .74264 L .36607 .75304 L p .707 .577 .707 r
F P
0 g
s
.38918 .74264 m .38918 .24075 L .42314 .23277 L p .707 .577 .707 r
F P
0 g
s
.76517 .57317 m .76517 .62875 L .79455 .62537 L p .707 .577 .707 r
F P
0 g
s
.79455 .62537 m .79455 .56979 L .76517 .57317 L p .707 .577 .707 r
F P
0 g
s
.20545 .69075 m .20545 .72781 L .1814 .73346 L p .707 .577 .707 r
F P
0 g
s
.3253 .69289 m .3253 .72994 L .29784 .72555 L p .707 .577 .707 r
F P
0 g
s
.29784 .72555 m .29784 .6885 L .3253 .69289 L p .707 .577 .707 r
F P
0 g
s
.70216 .62763 m .70216 .57205 L .6747 .56766 L p .707 .577 .707 r
F P
0 g
s
.70216 .57205 m .70216 .62763 L .73333 .62953 L p .707 .577 .707 r
F P
0 g
s
.34635 .80015 m .34635 .81867 L .3253 .81222 L p .707 .577 .707 r
F P
0 g
s
.3253 .81222 m .3253 .79369 L .34635 .80015 L p .707 .577 .707 r
F P
0 g
s
.20545 .72781 m .20545 .69075 L .23483 .68737 L p .707 .577 .707 r
F P
0 g
s
.79455 .56979 m .79455 .62537 L .8186 .61972 L p .707 .577 .707 r
F P
0 g
s
.8186 .61972 m .8186 .56414 L .79455 .56979 L p .707 .577 .707 r
F P
0 g
s
.59233 .23579 m .59233 .73768 L .55357 .73148 L p .707 .577 .707 r
F P
0 g
s
.55357 .73148 m .55357 .22959 L .59233 .23579 L p .707 .577 .707 r
F P
0 g
s
.1814 .81573 m .1814 .79721 L .20545 .79156 L p .707 .577 .707 r
F P
0 g
s
.6747 .56766 m .6747 .62324 L .70216 .62763 L p .707 .577 .707 r
F P
0 g
s
.29784 .6885 m .29784 .72555 L .26667 .72365 L p .707 .577 .707 r
F P
0 g
s
.26667 .72365 m .26667 .68659 L .29784 .6885 L p .707 .577 .707 r
F P
0 g
s
.6747 .62324 m .6747 .56766 L .65365 .5612 L p .707 .577 .707 r
F P
0 g
s
.23483 .68737 m .23483 .72443 L .20545 .72781 L p .707 .577 .707 r
F P
0 g
s
.23483 .72443 m .23483 .68737 L .26667 .68659 L p .707 .577 .707 r
F P
0 g
s
.20545 .79156 m .20545 .81008 L .1814 .81573 L p .707 .577 .707 r
F P
0 g
s
.26667 .68659 m .26667 .72365 L .23483 .72443 L p .707 .577 .707 r
F P
0 g
s
.42314 .73466 m .42314 .23277 L .46462 .228 L p .707 .577 .707 r
F P
0 g
s
.42314 .23277 m .42314 .73466 L .38918 .74264 L p .707 .577 .707 r
F P
0 g
s
.73333 .72314 m .73333 .68608 L .70216 .68418 L p .707 .577 .707 r
F P
0 g
s
.73333 .68608 m .73333 .72314 L .76517 .72236 L p .707 .577 .707 r
F P
0 g
s
.76517 .72236 m .76517 .68531 L .73333 .68608 L p .707 .577 .707 r
F P
0 g
s
.76517 .68531 m .76517 .72236 L .79455 .71898 L p .707 .577 .707 r
F P
0 g
s
.79455 .71898 m .79455 .68193 L .76517 .68531 L p .707 .577 .707 r
F P
0 g
s
.3253 .79369 m .3253 .81222 L .29784 .80783 L p .707 .577 .707 r
F P
0 g
s
.29784 .80783 m .29784 .7893 L .3253 .79369 L p .707 .577 .707 r
F P
0 g
s
.8186 .56414 m .8186 .61972 L .83497 .61236 L p .707 .577 .707 r
F P
0 g
s
.83497 .61236 m .83497 .55677 L .8186 .56414 L p .707 .577 .707 r
F P
0 g
s
.70216 .72124 m .70216 .68418 L .6747 .67979 L p .707 .577 .707 r
F P
0 g
s
.70216 .68418 m .70216 .72124 L .73333 .72314 L p .707 .577 .707 r
F P
0 g
s
.65365 .5612 m .65365 .61678 L .6747 .62324 L p .707 .577 .707 r
F P
0 g
s
.55357 .22959 m .55357 .73148 L .50956 .72879 L p .707 .577 .707 r
F P
0 g
s
.50956 .72879 m .50956 .22691 L .55357 .22959 L p .707 .577 .707 r
F P
0 g
s
.20545 .81008 m .20545 .79156 L .23483 .78818 L p .707 .577 .707 r
F P
0 g
s
.65365 .61678 m .65365 .5612 L .64105 .55332 L p .707 .577 .707 r
F P
0 g
s
.79455 .68193 m .79455 .71898 L .8186 .71333 L p .707 .577 .707 r
F P
0 g
s
.8186 .71333 m .8186 .67628 L .79455 .68193 L p .707 .577 .707 r
F P
0 g
s
.23483 .78818 m .23483 .8067 L .20545 .81008 L p .707 .577 .707 r
F P
0 g
s
.46462 .72989 m .46462 .228 L .50956 .22691 L p .707 .577 .707 r
F P
0 g
s
.46462 .228 m .46462 .72989 L .42314 .73466 L p .707 .577 .707 r
F P
0 g
s
.6747 .67979 m .6747 .71684 L .70216 .72124 L p .707 .577 .707 r
F P
0 g
s
.29784 .7893 m .29784 .80783 L .26667 .80593 L p .707 .577 .707 r
F P
0 g
s
.26667 .80593 m .26667 .7874 L .29784 .7893 L p .707 .577 .707 r
F P
0 g
s
.50956 .22691 m .50956 .72879 L .46462 .72989 L p .707 .577 .707 r
F P
0 g
s
.6747 .71684 m .6747 .67979 L .65365 .67334 L p .707 .577 .707 r
F P
0 g
s
.23483 .8067 m .23483 .78818 L .26667 .7874 L p .707 .577 .707 r
F P
0 g
s
.26667 .7874 m .26667 .80593 L .23483 .8067 L p .707 .577 .707 r
F P
0 g
s
.73333 .80541 m .73333 .78689 L .70216 .78499 L p .707 .577 .707 r
F P
0 g
s
.73333 .78689 m .73333 .80541 L .76517 .80464 L p .707 .577 .707 r
F P
0 g
s
.76517 .80464 m .76517 .78611 L .73333 .78689 L p .707 .577 .707 r
F P
0 g
s
.64105 .55332 m .64105 .6089 L .65365 .61678 L p .707 .577 .707 r
F P
0 g
s
.83497 .55677 m .83497 .61236 L .84205 .60399 L p .707 .577 .707 r
F P
0 g
s
.84205 .60399 m .84205 .54841 L .83497 .55677 L p .707 .577 .707 r
F P
0 g
s
.76517 .78611 m .76517 .80464 L .79455 .80126 L p .707 .577 .707 r
F P
0 g
s
.79455 .80126 m .79455 .78273 L .76517 .78611 L p .707 .577 .707 r
F P
0 g
s
.65365 .67334 m .65365 .71039 L .6747 .71684 L p .707 .577 .707 r
F P
0 g
s
.70216 .78499 m .70216 .80351 L .73333 .80541 L p .707 .577 .707 r
F P
0 g
s
.70216 .80351 m .70216 .78499 L .6747 .78059 L p .707 .577 .707 r
F P
0 g
s
.8186 .67628 m .8186 .71333 L .83497 .70596 L p .707 .577 .707 r
F P
0 g
s
.83497 .70596 m .83497 .66891 L .8186 .67628 L p .707 .577 .707 r
F P
0 g
s
.6747 .78059 m .6747 .79912 L .70216 .80351 L p .707 .577 .707 r
F P
0 g
s
.64105 .6089 m .64105 .55332 L .63816 .54477 L p .707 .577 .707 r
F P
0 g
s
.79455 .78273 m .79455 .80126 L .8186 .79561 L p .707 .577 .707 r
F P
0 g
s
.8186 .79561 m .8186 .77708 L .79455 .78273 L p .707 .577 .707 r
F P
0 g
s
.65365 .71039 m .65365 .67334 L .64105 .66545 L p .707 .577 .707 r
F P
0 g
s
.6747 .79912 m .6747 .78059 L .65365 .77414 L p .707 .577 .707 r
F P
0 g
s
.65365 .77414 m .65365 .79267 L .6747 .79912 L p .707 .577 .707 r
F P
0 g
s
.64105 .66545 m .64105 .70251 L .65365 .71039 L p .707 .577 .707 r
F P
0 g
s
.63816 .54477 m .63816 .60036 L .64105 .6089 L p .707 .577 .707 r
F P
0 g
s
.84205 .54841 m .84205 .60399 L .83916 .59545 L p .707 .577 .707 r
F P
0 g
s
.83916 .59545 m .83916 .53987 L .84205 .54841 L p .707 .577 .707 r
F P
0 g
s
.83497 .66891 m .83497 .70596 L .84206 .6976 L p .707 .577 .707 r
F P
0 g
s
.84206 .6976 m .84205 .66054 L .83497 .66891 L p .707 .577 .707 r
F P
0 g
s
.8186 .77708 m .8186 .79561 L .83497 .78824 L p .707 .577 .707 r
F P
0 g
s
.83497 .78824 m .83497 .76971 L .8186 .77708 L p .707 .577 .707 r
F P
0 g
s
.63816 .60036 m .63816 .54477 L .64524 .53641 L p .707 .577 .707 r
F P
0 g
s
.65365 .79267 m .65365 .77414 L .64105 .76626 L p .707 .577 .707 r
F P
0 g
s
.64105 .70251 m .64105 .66545 L .63816 .65691 L p .707 .577 .707 r
F P
0 g
s
.64105 .76626 m .64105 .78478 L .65365 .79267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .65691 m .63816 .69396 L .64105 .70251 L p .707 .577 .707 r
F P
0 g
s
.64524 .53641 m .64524 .59199 L .63816 .60036 L p .707 .577 .707 r
F P
0 g
s
.83497 .76971 m .83497 .78824 L .84206 .77988 L p .707 .577 .707 r
F P
0 g
s
.84206 .77988 m .84206 .76135 L .83497 .76971 L p .707 .577 .707 r
F P
0 g
s
.83916 .53987 m .83916 .59545 L .82657 .58757 L p .707 .577 .707 r
F P
0 g
s
.82657 .58757 m .82657 .53198 L .83916 .53987 L p .707 .577 .707 r
F P
0 g
s
.84205 .66054 m .84206 .6976 L .83916 .68906 L p .707 .577 .707 r
F P
0 g
s
.83916 .68906 m .83916 .652 L .84205 .66054 L p .707 .577 .707 r
F P
0 g
s
.39032 .59271 m .39032 .53713 L .35915 .53523 L p .707 .577 .707 r
F P
0 g
s
.39032 .53713 m .39032 .59271 L .42216 .59194 L p .707 .577 .707 r
F P
0 g
s
.42216 .59194 m .42216 .53636 L .39032 .53713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64105 .78478 m .64105 .76626 L .63816 .75771 L p .707 .577 .707 r
F P
0 g
s
.64524 .59199 m .64524 .53641 L .66161 .52904 L p .707 .577 .707 r
F P
0 g
s
.42216 .53636 m .42216 .59194 L .45154 .58856 L p .707 .577 .707 r
F P
0 g
s
.45154 .58856 m .45154 .53298 L .42216 .53636 L p .707 .577 .707 r
F P
0 g
s
.63816 .69396 m .63816 .65691 L .64524 .64855 L p .707 .577 .707 r
F P
0 g
s
.63816 .75771 m .63816 .77624 L .64105 .78478 L p .707 .577 .707 r
F P
0 g
s
.35915 .59081 m .35915 .53523 L .33169 .53084 L p .707 .577 .707 r
F P
0 g
s
.35915 .53523 m .35915 .59081 L .39032 .59271 L p .707 .577 .707 r
F P
0 g
s
.64524 .64855 m .64524 .6856 L .63816 .69396 L p .707 .577 .707 r
F P
0 g
s
.45154 .53298 m .45154 .58856 L .47559 .58291 L p .707 .577 .707 r
F P
0 g
s
.47559 .58291 m .47559 .52733 L .45154 .53298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52904 m .66161 .58462 L .64524 .59199 L p .707 .577 .707 r
F P
0 g
s
.82657 .53198 m .82657 .58757 L .80551 .58111 L p .707 .577 .707 r
F P
0 g
s
.80551 .58111 m .80551 .52553 L .82657 .53198 L p .707 .577 .707 r
F P
0 g
s
.84206 .76135 m .84206 .77988 L .83916 .77133 L p .707 .577 .707 r
F P
0 g
s
.83916 .77133 m .83916 .75281 L .84206 .76135 L p .707 .577 .707 r
F P
0 g
s
.83916 .652 m .83916 .68906 L .82657 .68117 L p .707 .577 .707 r
F P
0 g
s
.82657 .68117 m .82657 .64412 L .83916 .652 L p .707 .577 .707 r
F P
0 g
s
.33169 .53084 m .33169 .58642 L .35915 .59081 L p .707 .577 .707 r
F P
0 g
s
.33169 .58642 m .33169 .53084 L .31064 .52439 L p .707 .577 .707 r
F P
0 g
s
.66161 .58462 m .66161 .52904 L .68566 .52339 L p .707 .577 .707 r
F P
0 g
s
.39032 .68632 m .39032 .64927 L .35915 .64737 L p .707 .577 .707 r
F P
0 g
s
.39032 .64927 m .39032 .68632 L .42216 .68555 L p .707 .577 .707 r
F P
0 g
s
.42216 .68555 m .42216 .64849 L .39032 .64927 L p .707 .577 .707 r
F P
0 g
s
.63816 .77624 m .63816 .75771 L .64524 .74935 L p .707 .577 .707 r
F P
0 g
s
.64524 .6856 m .64524 .64855 L .66161 .64118 L p .707 .577 .707 r
F P
0 g
s
.42216 .64849 m .42216 .68555 L .45154 .68217 L p .707 .577 .707 r
F P
0 g
s
.45154 .68217 m .45154 .64511 L .42216 .64849 L p .707 .577 .707 r
F P
0 g
s
.47559 .52733 m .47559 .58291 L .49196 .57554 L p .707 .577 .707 r
F P
0 g
s
.49196 .57554 m .49196 .51996 L .47559 .52733 L p .707 .577 .707 r
F P
0 g
s
.64524 .74935 m .64524 .76788 L .63816 .77624 L p .707 .577 .707 r
F P
0 g
s
.35915 .68442 m .35915 .64737 L .33169 .64297 L p .707 .577 .707 r
F P
0 g
s
.35915 .64737 m .35915 .68442 L .39032 .68632 L p .707 .577 .707 r
F P
0 g
s
.31064 .52439 m .31064 .57997 L .33169 .58642 L p .707 .577 .707 r
F P
0 g
s
.80551 .52553 m .80551 .58111 L .77805 .57672 L p .707 .577 .707 r
F P
0 g
s
.77805 .57672 m .77805 .52114 L .80551 .52553 L p .707 .577 .707 r
F P
0 g
s
.66161 .64118 m .66161 .67823 L .64524 .6856 L p .707 .577 .707 r
F P
0 g
s
.68566 .52339 m .68566 .57897 L .66161 .58462 L p .707 .577 .707 r
F P
0 g
s
.31064 .57997 m .31064 .52439 L .29804 .5165 L p .707 .577 .707 r
F P
0 g
s
.45154 .64511 m .45154 .68217 L .47559 .67652 L p .707 .577 .707 r
F P
0 g
s
.47559 .67652 m .47559 .63946 L .45154 .64511 L p .707 .577 .707 r
F P
0 g
s
.33169 .64297 m .33169 .68003 L .35915 .68442 L p .707 .577 .707 r
F P
0 g
s
.68566 .57897 m .68566 .52339 L .71504 .52001 L p .707 .577 .707 r
F P
0 g
s
.83916 .75281 m .83916 .77133 L .82657 .76345 L p .707 .577 .707 r
F P
0 g
s
.82657 .76345 m .82657 .74492 L .83916 .75281 L p .707 .577 .707 r
F P
0 g
s
.82657 .64412 m .82657 .68117 L .80551 .67472 L p .707 .577 .707 r
F P
0 g
s
.80551 .67472 m .80551 .63766 L .82657 .64412 L p .707 .577 .707 r
F P
0 g
s
.33169 .68003 m .33169 .64297 L .31064 .63652 L p .707 .577 .707 r
F P
0 g
s
.77805 .52114 m .77805 .57672 L .74688 .57482 L p .707 .577 .707 r
F P
0 g
s
.74688 .57482 m .74688 .51924 L .77805 .52114 L p .707 .577 .707 r
F P
0 g
s
.39032 .7686 m .39032 .75007 L .35915 .74817 L p .707 .577 .707 r
F P
0 g
s
.39032 .75007 m .39032 .7686 L .42216 .76782 L p .707 .577 .707 r
F P
0 g
s
.42216 .76782 m .42216 .74929 L .39032 .75007 L p .707 .577 .707 r
F P
0 g
s
.66161 .67823 m .66161 .64118 L .68566 .63553 L p .707 .577 .707 r
F P
0 g
s
.29804 .5165 m .29804 .57208 L .31064 .57997 L p .707 .577 .707 r
F P
0 g
s
.71504 .5756 m .71504 .52001 L .74688 .51924 L p .707 .577 .707 r
F P
0 g
s
.71504 .52001 m .71504 .5756 L .68566 .57897 L p .707 .577 .707 r
F P
0 g
s
.49196 .51996 m .49196 .57554 L .49904 .56718 L p .707 .577 .707 r
F P
0 g
s
.49904 .56718 m .49904 .51159 L .49196 .51996 L p .707 .577 .707 r
F P
0 g
s
.64524 .76788 m .64524 .74935 L .66161 .74198 L p .707 .577 .707 r
F P
0 g
s
.42216 .74929 m .42216 .76782 L .45154 .76444 L p .707 .577 .707 r
F P
0 g
s
.45154 .76444 m .45154 .74592 L .42216 .74929 L p .707 .577 .707 r
F P
0 g
s
.31064 .63652 m .31064 .67358 L .33169 .68003 L p .707 .577 .707 r
F P
0 g
s
.74688 .51924 m .74688 .57482 L .71504 .5756 L p .707 .577 .707 r
F P
0 g
s
.35915 .74817 m .35915 .7667 L .39032 .7686 L p .707 .577 .707 r
F P
0 g
s
.35915 .7667 m .35915 .74817 L .33169 .74378 L p .707 .577 .707 r
F P
0 g
s
.47559 .63946 m .47559 .67652 L .49196 .66915 L p .707 .577 .707 r
F P
0 g
s
.49196 .66915 m .49196 .63209 L .47559 .63946 L p .707 .577 .707 r
F P
0 g
s
.66161 .74198 m .66161 .76051 L .64524 .76788 L p .707 .577 .707 r
F P
0 g
s
.68566 .63553 m .68566 .67258 L .66161 .67823 L p .707 .577 .707 r
F P
0 g
s
.33169 .74378 m .33169 .76231 L .35915 .7667 L p .707 .577 .707 r
F P
0 g
s
.80551 .63766 m .80551 .67472 L .77805 .67033 L p .707 .577 .707 r
F P
0 g
s
.77805 .67033 m .77805 .63327 L .80551 .63766 L p .707 .577 .707 r
F P
0 g
s
.29804 .57208 m .29804 .5165 L .29515 .50796 L p .707 .577 .707 r
F P
0 g
s
.45154 .74592 m .45154 .76444 L .47559 .75879 L p .707 .577 .707 r
F P
0 g
s
.47559 .75879 m .47559 .74027 L .45154 .74592 L p .707 .577 .707 r
F P
0 g
s
.31064 .67358 m .31064 .63652 L .29804 .62864 L p .707 .577 .707 r
F P
0 g
s
.82657 .74492 m .82657 .76345 L .80551 .757 L p .707 .577 .707 r
F P
0 g
s
.80551 .757 m .80551 .73847 L .82657 .74492 L p .707 .577 .707 r
F P
0 g
s
.68566 .67258 m .68566 .63553 L .71504 .63215 L p .707 .577 .707 r
F P
0 g
s
.33169 .76231 m .33169 .74378 L .31064 .73733 L p .707 .577 .707 r
F P
0 g
s
.31064 .73733 m .31064 .75585 L .33169 .76231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62864 m .29804 .66569 L .31064 .67358 L p .707 .577 .707 r
F P
0 g
s
.66161 .76051 m .66161 .74198 L .68566 .73633 L p .707 .577 .707 r
F P
0 g
s
.77805 .63327 m .77805 .67033 L .74688 .66843 L p .707 .577 .707 r
F P
0 g
s
.74688 .66843 m .74688 .63137 L .77805 .63327 L p .707 .577 .707 r
F P
0 g
s
.29515 .50796 m .29515 .56354 L .29804 .57208 L p .707 .577 .707 r
F P
0 g
s
.71504 .63215 m .71504 .6692 L .68566 .67258 L p .707 .577 .707 r
F P
0 g
s
.49904 .51159 m .49904 .56718 L .49615 .55863 L p .707 .577 .707 r
F P
0 g
s
.49615 .55863 m .49615 .50305 L .49904 .51159 L p .707 .577 .707 r
F P
0 g
s
.71504 .6692 m .71504 .63215 L .74688 .63137 L p .707 .577 .707 r
F P
0 g
s
.49196 .63209 m .49196 .66915 L .49904 .66078 L p .707 .577 .707 r
F P
0 g
s
.49904 .66078 m .49904 .62373 L .49196 .63209 L p .707 .577 .707 r
F P
0 g
s
.68566 .73633 m .68566 .75486 L .66161 .76051 L p .707 .577 .707 r
F P
0 g
s
.47559 .74027 m .47559 .75879 L .49196 .75143 L p .707 .577 .707 r
F P
0 g
s
.49196 .75143 m .49196 .7329 L .47559 .74027 L p .707 .577 .707 r
F P
0 g
s
.74688 .63137 m .74688 .66843 L .71504 .6692 L p .707 .577 .707 r
F P
0 g
s
.80551 .73847 m .80551 .757 L .77805 .7526 L p .707 .577 .707 r
F P
0 g
s
.77805 .7526 m .77805 .73408 L .80551 .73847 L p .707 .577 .707 r
F P
0 g
s
.29515 .56354 m .29515 .50796 L .30223 .49959 L p .707 .577 .707 r
F P
0 g
s
.31064 .75585 m .31064 .73733 L .29804 .72944 L p .707 .577 .707 r
F P
0 g
s
.29804 .66569 m .29804 .62864 L .29515 .62009 L p .707 .577 .707 r
F P
0 g
s
.68566 .75486 m .68566 .73633 L .71504 .73295 L p .707 .577 .707 r
F P
0 g
s
.29804 .72944 m .29804 .74797 L .31064 .75585 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71504 .73295 m .71504 .75148 L .68566 .75486 L p .707 .577 .707 r
F P
0 g
s
.29515 .62009 m .29515 .65715 L .29804 .66569 L p .707 .577 .707 r
F P
0 g
s
.77805 .73408 m .77805 .7526 L .74688 .7507 L p .707 .577 .707 r
F P
0 g
s
.74688 .7507 m .74688 .73218 L .77805 .73408 L p .707 .577 .707 r
F P
0 g
s
.30223 .49959 m .30223 .55518 L .29515 .56354 L p .707 .577 .707 r
F P
0 g
s
.71504 .75148 m .71504 .73295 L .74688 .73218 L p .707 .577 .707 r
F P
0 g
s
.49196 .7329 m .49196 .75143 L .49904 .74306 L p .707 .577 .707 r
F P
0 g
s
.49904 .74306 m .49904 .72453 L .49196 .7329 L p .707 .577 .707 r
F P
0 g
s
.49615 .50305 m .49615 .55863 L .48356 .55075 L p .707 .577 .707 r
F P
0 g
s
.48356 .55075 m .48356 .49517 L .49615 .50305 L p .707 .577 .707 r
F P
0 g
s
.49904 .62373 m .49904 .66078 L .49615 .65224 L p .707 .577 .707 r
F P
0 g
s
.49615 .65224 m .49615 .61519 L .49904 .62373 L p .707 .577 .707 r
F P
0 g
s
.74688 .73218 m .74688 .7507 L .71504 .75148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29804 .74797 m .29804 .72944 L .29515 .7209 L p .707 .577 .707 r
F P
0 g
s
.30223 .55518 m .30223 .49959 L .3186 .49223 L p .707 .577 .707 r
F P
0 g
s
.29515 .65715 m .29515 .62009 L .30223 .61173 L p .707 .577 .707 r
F P
0 g
s
.29515 .7209 m .29515 .73943 L .29804 .74797 L p .707 .577 .707 r
F P
0 g
s
.30223 .61173 m .30223 .64878 L .29515 .65715 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49223 m .3186 .54781 L .30223 .55518 L p .707 .577 .707 r
F P
0 g
s
.48356 .49517 m .48356 .55075 L .4625 .5443 L p .707 .577 .707 r
F P
0 g
s
.4625 .5443 m .4625 .48871 L .48356 .49517 L p .707 .577 .707 r
F P
0 g
s
.49904 .72453 m .49904 .74306 L .49615 .73452 L p .707 .577 .707 r
F P
0 g
s
.49615 .73452 m .49615 .71599 L .49904 .72453 L p .707 .577 .707 r
F P
0 g
s
.49615 .61519 m .49615 .65224 L .48356 .64436 L p .707 .577 .707 r
F P
0 g
s
.48356 .64436 m .48356 .6073 L .49615 .61519 L p .707 .577 .707 r
F P
0 g
s
.3186 .54781 m .3186 .49223 L .34265 .48658 L p .707 .577 .707 r
F P
0 g
s
.29515 .73943 m .29515 .7209 L .30223 .71253 L p .707 .577 .707 r
F P
0 g
s
.30223 .64878 m .30223 .61173 L .3186 .60436 L p .707 .577 .707 r
F P
0 g
s
.30223 .71253 m .30223 .73106 L .29515 .73943 L p .707 .577 .707 r
F P
0 g
s
.4625 .48871 m .4625 .5443 L .43504 .5399 L p .707 .577 .707 r
F P
0 g
s
.43504 .5399 m .43504 .48432 L .4625 .48871 L p .707 .577 .707 r
F P
0 g
s
.3186 .60436 m .3186 .64142 L .30223 .64878 L p .707 .577 .707 r
F P
0 g
s
.34265 .48658 m .34265 .54216 L .3186 .54781 L p .707 .577 .707 r
F P
0 g
s
.34265 .54216 m .34265 .48658 L .37203 .4832 L p .707 .577 .707 r
F P
0 g
s
.49615 .71599 m .49615 .73452 L .48356 .72664 L p .707 .577 .707 r
F P
0 g
s
.48356 .72664 m .48356 .70811 L .49615 .71599 L p .707 .577 .707 r
F P
0 g
s
.48356 .6073 m .48356 .64436 L .4625 .6379 L p .707 .577 .707 r
F P
0 g
s
.4625 .6379 m .4625 .60085 L .48356 .6073 L p .707 .577 .707 r
F P
0 g
s
.43504 .48432 m .43504 .5399 L .40387 .538 L p .707 .577 .707 r
F P
0 g
s
.40387 .538 m .40387 .48242 L .43504 .48432 L p .707 .577 .707 r
F P
0 g
s
.3186 .64142 m .3186 .60436 L .34265 .59871 L p .707 .577 .707 r
F P
0 g
s
.37203 .53878 m .37203 .4832 L .40387 .48242 L p .707 .577 .707 r
F P
0 g
s
.37203 .4832 m .37203 .53878 L .34265 .54216 L p .707 .577 .707 r
F P
0 g
s
.30223 .73106 m .30223 .71253 L .3186 .70517 L p .707 .577 .707 r
F P
0 g
s
.40387 .48242 m .40387 .538 L .37203 .53878 L p .707 .577 .707 r
F P
0 g
s
.3186 .70517 m .3186 .72369 L .30223 .73106 L p .707 .577 .707 r
F P
0 g
s
.34265 .59871 m .34265 .63577 L .3186 .64142 L p .707 .577 .707 r
F P
0 g
s
.4625 .60085 m .4625 .6379 L .43504 .63351 L p .707 .577 .707 r
F P
0 g
s
.43504 .63351 m .43504 .59646 L .4625 .60085 L p .707 .577 .707 r
F P
0 g
s
.48356 .70811 m .48356 .72664 L .4625 .72018 L p .707 .577 .707 r
F P
0 g
s
.4625 .72018 m .4625 .70165 L .48356 .70811 L p .707 .577 .707 r
F P
0 g
s
.34265 .63577 m .34265 .59871 L .37203 .59533 L p .707 .577 .707 r
F P
0 g
s
.3186 .72369 m .3186 .70517 L .34265 .69952 L p .707 .577 .707 r
F P
0 g
s
.43504 .59646 m .43504 .63351 L .40387 .63161 L p .707 .577 .707 r
F P
0 g
s
.40387 .63161 m .40387 .59456 L .43504 .59646 L p .707 .577 .707 r
F P
0 g
s
.37203 .59533 m .37203 .63239 L .34265 .63577 L p .707 .577 .707 r
F P
0 g
s
.37203 .63239 m .37203 .59533 L .40387 .59456 L p .707 .577 .707 r
F P
0 g
s
.34265 .69952 m .34265 .71804 L .3186 .72369 L p .707 .577 .707 r
F P
0 g
s
.40387 .59456 m .40387 .63161 L .37203 .63239 L p .707 .577 .707 r
F P
0 g
s
.4625 .70165 m .4625 .72018 L .43504 .71579 L p .707 .577 .707 r
F P
0 g
s
.43504 .71579 m .43504 .69726 L .4625 .70165 L p .707 .577 .707 r
F P
0 g
s
.34265 .71804 m .34265 .69952 L .37203 .69614 L p .707 .577 .707 r
F P
0 g
s
.37203 .69614 m .37203 .71467 L .34265 .71804 L p .707 .577 .707 r
F P
0 g
s
.43504 .69726 m .43504 .71579 L .40387 .71389 L p .707 .577 .707 r
F P
0 g
s
.40387 .71389 m .40387 .69536 L .43504 .69726 L p .707 .577 .707 r
F P
0 g
s
.37203 .71467 m .37203 .69614 L .40387 .69536 L p .707 .577 .707 r
F P
0 g
s
.40387 .69536 m .40387 .71389 L .37203 .71467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF
00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo
001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006EooaP0
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00003goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00=JEPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001JEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003mooaP00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000iOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF
1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YF
FUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP80
02eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
00=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0J0005FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000L000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP02FUH9000oOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQD00003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP0C0014Ool002aoo`03001JEP0000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`03001JEP0000AJEPD000MJEP03001JEUYF
00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH0000400001EYF001JEUYF00000UYF
00<005YFFUH00eYF1@001EYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03001JEP00
009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00003
FUH:0002FUH01000FUIJEP001EYF10001UYF00<005YFFUH01eYF1P0000=JEP00FUH00UYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
03Aoo`00;7oo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00H005YF001JEP00FUH20005FUH00`00FUH0000300001EYF001JEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@001EYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH2
00000eYF001JEP04FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEUYFFUH90007Ool5000<Ool50004FUH01000FUIJEUYF0P00;Goo000dOol50006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1`0000=JEP00FUH00UYF
0P001goo1@0047oo100000=JEP00FUH00UYF0P00;Goo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50002Ool50004FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02
FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF1P000eYF0P0027oo0`002Woo1`000eYF0`000eYF0P00;Goo000mOolI000<Ool8
0004FUH500000eYF000000070007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000oOolG000?Ool01@00FUIJEP00FUH0
2P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000iOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000;Ool01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000eOol400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH50006OolB00000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0039oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000a
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP0000@0
00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040005Ool40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03
001JEP0000=JEPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00003Goo6@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHC0004
Ool400000eYF001JEP020003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000FOol50018Ool002aoo`03001JEP00
00AJEP03001JEP0000<000ioo`D000Moo`05001JEP00001oo`060004FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3@0000=JEP00000020001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@004Woo0`00BGoo000/Ool00`00
FUH00003FUH4000AOol50007Ool40006Ool400001EYF001JEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF200035YF0`002EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YF00000P001Goo6P00?7oo000/Ool01000FUH005YF0P0015YF1@003Goo0`0027oo0P00
0UYF1P000eYF0`000UYF00@005YFFUH000EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00QJEP<0
0003FUH005YF00UJEP03001JEUYF00QJEPL000IJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`06001J
EP00001JEP001EYF00@005YFFUIJEQX000=JEP03001JEP00008000=JEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEP0000<000YJEP03001JEUYF00EJEP<0009JEP03001JEP0000YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000AJEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000000=JEP03001JEUYF009JEPD0009JEP80009JEP03001JEUYF00=JEP8000=JEP03001JEUYF
00QJEP04001JEUYFFUH400000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00
FUIJEP03FUH01000FUIJEUYF20000UYF0P001EYF00<005YFFUH01eYF1@001EYF00@005YFFUIJEP80
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH000020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000aOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF
4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04
001JEUYFFUH20002FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50004FUH00`00FUIJEP02FUH8
000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF
00<005YF00000P000UYF00@005YFFUIJEP8001Qoo`D000AJEP05001JEUYFFUH0000^Ool002ioo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
00030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20000
0eYF001JEP02FUH30005FUH01000FUIJEUYF0P007Goo0`0000=JEP00FUH00UYF0P00;Goo000`Ool3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP0300000eYF
001JEP04FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000cOol300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002OolI00000eYF001J
EP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000003Ool40003FUH01000FUIJEUYF0P008Woo0P0000=JEP000000;Goo000fOol50004FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUH000030007Ool00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH300000eYF001oo`02Ool80003FUH2000QOol2000015YF00000000;Goo
000kOol80004FUH50005FUH00`00FUIJEP02FUH5000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30002FUH30005FUH01000FUIJEP000UYF0P007Woo0`000eYF0`00;Goo0013OolC
000AOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YFFUH01P000eYF10006Woo
100000=JEP00FUH00eYF00<005YF0000;Goo0017Ool5000LOol200000eYF001JEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH200001EYF001JEUYF00001EYF00<005YF00000`0000AJEP00000001Eoo`D000EJEP03001J
EUYF009JEP8002ioo`00Agoo2@006Woo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP04001JEUYF0005FUH0
0`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool003moo`P000AJEP03
001JEUYF009JEPP001=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001JEP0015YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000moo`@0009JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@0
00=JEP03001JEUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080011oo`D000QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000MJEP03001JEUYF00EJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<001Moo`T000IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP/000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P007Woo3@000Woo
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP@000Yoo`T004Qoo`00;Goo0P0015YF00@005YFFUIJEPP001Uoo`H000AJEP05001JEUYFFUH0000`
Ool50004FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH7001OOol002aoo`03001JEP0000AJ
EP@002Moo`<00003FUH005YF009JEP03001oogoo03=ooa/006Ioo`00;7oo00<005YF00000UYF0P00
;Woo0P000eYF00<007ooOol0@7oo1@00Kgoo000/Ool00`00FUH00002000bOol01000FUIJEP00@Woo
1@00Kgoo000/Ool01000FUH00000=7oo0`00>Goo6000IGoo000/Ool20002FUH3000_Ool300000eYF
001oo`0bOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001QOol002aoo`80
00=JEP03001JEP00008002Uoo`<0009JEP03001JEP00031oo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@005eoo`00;7oo0P000eYF00<005YFFUH00UYF1@00
87oo100000=JEP00FUH00UYF00<005YF0000;Goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000FGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000/Ool200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001HOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000[Ool20004FUH00`00
FUIJEP02FUH6000BOol80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000aOol30003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
000/Ool00`00FUH00004FUH00`00FUH00002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol5
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00
FUH00003FUH3000XOol300000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF009JEPD003=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eo
oaT003Qoo`04001JEP00000bOol200000eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P00
0UYF0P00;goo0P0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<0
05YF0000E7oo002?Ool01000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?
Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eo
o`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0
05Yoo`00Ugoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002L
Ool90004FUH00`00FUIJEP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70431 m .59613 .64873 L .56496 .64683 L p .707 .577 .707 r
F P
0 g
s
.59613 .64873 m .59613 .70431 L .62796 .70353 L p .707 .577 .707 r
F P
0 g
s
.62796 .70353 m .62796 .64795 L .59613 .64873 L p .707 .577 .707 r
F P
0 g
s
.62796 .64795 m .62796 .70353 L .65734 .70015 L p .707 .577 .707 r
F P
0 g
s
.65734 .70015 m .65734 .64457 L .62796 .64795 L p .707 .577 .707 r
F P
0 g
s
.56496 .70241 m .56496 .64683 L .5375 .64243 L p .707 .577 .707 r
F P
0 g
s
.56496 .64683 m .56496 .70241 L .59613 .70431 L p .707 .577 .707 r
F P
0 g
s
.65734 .64457 m .65734 .70015 L .6814 .6945 L p .707 .577 .707 r
F P
0 g
s
.6814 .6945 m .6814 .63892 L .65734 .64457 L p .707 .577 .707 r
F P
0 g
s
.5375 .64243 m .5375 .69802 L .56496 .70241 L p .707 .577 .707 r
F P
0 g
s
.5375 .69802 m .5375 .64243 L .51644 .63598 L p .707 .577 .707 r
F P
0 g
s
.6814 .63892 m .6814 .6945 L .69777 .68714 L p .707 .577 .707 r
F P
0 g
s
.69777 .68714 m .69777 .63155 L .6814 .63892 L p .707 .577 .707 r
F P
0 g
s
.59613 .81846 m .59613 .78141 L .56496 .77951 L p .707 .577 .707 r
F P
0 g
s
.59613 .78141 m .59613 .81846 L .62796 .81769 L p .707 .577 .707 r
F P
0 g
s
.62796 .81769 m .62796 .78063 L .59613 .78141 L p .707 .577 .707 r
F P
0 g
s
.51644 .63598 m .51644 .69156 L .5375 .69802 L p .707 .577 .707 r
F P
0 g
s
.62796 .78063 m .62796 .81769 L .65735 .81431 L p .707 .577 .707 r
F P
0 g
s
.65735 .81431 m .65735 .77725 L .62796 .78063 L p .707 .577 .707 r
F P
0 g
s
.56496 .81656 m .56496 .77951 L .5375 .77512 L p .707 .577 .707 r
F P
0 g
s
.56496 .77951 m .56496 .81656 L .59613 .81846 L p .707 .577 .707 r
F P
0 g
s
.51644 .69156 m .51644 .63598 L .50385 .6281 L p .707 .577 .707 r
F P
0 g
s
.65735 .77725 m .65735 .81431 L .6814 .80866 L p .707 .577 .707 r
F P
0 g
s
.6814 .80866 m .6814 .7716 L .65735 .77725 L p .707 .577 .707 r
F P
0 g
s
.5375 .77512 m .5375 .81217 L .56496 .81656 L p .707 .577 .707 r
F P
0 g
s
.5375 .81217 m .5375 .77512 L .51644 .76866 L p .707 .577 .707 r
F P
0 g
s
.50385 .6281 m .50385 .68368 L .51644 .69156 L p .707 .577 .707 r
F P
0 g
s
.69777 .63155 m .69777 .68714 L .70485 .67877 L p .707 .577 .707 r
F P
0 g
s
.70485 .67877 m .70485 .62319 L .69777 .63155 L p .707 .577 .707 r
F P
0 g
s
.51644 .76866 m .51644 .80572 L .5375 .81217 L p .707 .577 .707 r
F P
0 g
s
.59613 .92573 m .59613 .90721 L .56496 .90531 L p .707 .577 .707 r
F P
0 g
s
.59613 .90721 m .59613 .92573 L .62796 .92496 L p .707 .577 .707 r
F P
0 g
s
.62796 .92496 m .62796 .90643 L .59613 .90721 L p .707 .577 .707 r
F P
0 g
s
.6814 .7716 m .6814 .80866 L .69777 .80129 L p .707 .577 .707 r
F P
0 g
s
.69777 .80129 m .69777 .76423 L .6814 .7716 L p .707 .577 .707 r
F P
0 g
s
.50385 .68368 m .50385 .6281 L .50095 .61955 L p .707 .577 .707 r
F P
0 g
s
.62796 .90643 m .62796 .92496 L .65735 .92158 L p .707 .577 .707 r
F P
0 g
s
.65735 .92158 m .65735 .90305 L .62796 .90643 L p .707 .577 .707 r
F P
0 g
s
.56496 .90531 m .56496 .92383 L .59613 .92573 L p .707 .577 .707 r
F P
0 g
s
.56496 .92383 m .56496 .90531 L .5375 .90091 L p .707 .577 .707 r
F P
0 g
s
.51644 .80572 m .51644 .76866 L .50385 .76078 L p .707 .577 .707 r
F P
0 g
s
.5375 .90091 m .5375 .91944 L .56496 .92383 L p .707 .577 .707 r
F P
0 g
s
.65735 .90305 m .65735 .92158 L .6814 .91593 L p .707 .577 .707 r
F P
0 g
s
.6814 .91593 m .6814 .8974 L .65735 .90305 L p .707 .577 .707 r
F P
0 g
s
.50095 .61955 m .50095 .67514 L .50385 .68368 L p .707 .577 .707 r
F P
0 g
s
.70485 .62319 m .70485 .67877 L .70195 .67023 L p .707 .577 .707 r
F P
0 g
s
.70195 .67023 m .70195 .61465 L .70485 .62319 L p .707 .577 .707 r
F P
0 g
s
.50385 .76078 m .50385 .79783 L .51644 .80572 L p .707 .577 .707 r
F P
0 g
s
.5375 .91944 m .5375 .90091 L .51644 .89446 L p .707 .577 .707 r
F P
0 g
s
.69777 .76423 m .69777 .80129 L .70485 .79292 L p .707 .577 .707 r
F P
0 g
s
.70485 .79292 m .70485 .75587 L .69777 .76423 L p .707 .577 .707 r
F P
0 g
s
.51644 .89446 m .51644 .91299 L .5375 .91944 L p .707 .577 .707 r
F P
0 g
s
.50095 .67514 m .50095 .61955 L .50804 .61119 L p .707 .577 .707 r
F P
0 g
s
.49044 .79627 m .49044 .29438 L .44643 .2917 L p .707 .577 .707 r
F P
0 g
s
.50385 .79783 m .50385 .76078 L .50095 .75223 L p .707 .577 .707 r
F P
0 g
s
.50804 .61119 m .50804 .66677 L .50095 .67514 L p .707 .577 .707 r
F P
0 g
s
.50095 .75223 m .50095 .78929 L .50385 .79783 L p .707 .577 .707 r
F P
0 g
s
.50804 .66677 m .50804 .61119 L .5244 .60382 L p .707 .577 .707 r
F P
0 g
s
.50095 .78929 m .50095 .75223 L .50804 .74387 L p .707 .577 .707 r
F P
0 g
s
.5244 .60382 m .5244 .6594 L .50804 .66677 L p .707 .577 .707 r
F P
0 g
s
.50804 .74387 m .50804 .78093 L .50095 .78929 L p .707 .577 .707 r
F P
0 g
s
.50804 .78093 m .50804 .74387 L .5244 .7365 L p .707 .577 .707 r
F P
0 g
s
.5244 .7365 m .5244 .77356 L .50804 .78093 L p .707 .577 .707 r
F P
0 g
s
.5244 .77356 m .5244 .7365 L .54846 .73085 L p .707 .577 .707 r
F P
0 g
s
.54846 .73085 m .54846 .76791 L .5244 .77356 L p .707 .577 .707 r
F P
0 g
s
.49044 .29438 m .49044 .79627 L .53538 .79517 L p .707 .577 .707 r
F P
0 g
s
.5244 .6594 m .5244 .60382 L .54846 .59817 L p .707 .577 .707 r
F P
0 g
s
.54846 .59817 m .54846 .65375 L .5244 .6594 L p .707 .577 .707 r
F P
0 g
s
.53538 .79517 m .53538 .29328 L .49044 .29438 L p .707 .577 .707 r
F P
0 g
s
.6814 .8974 m .6814 .91593 L .69777 .90856 L p .707 .577 .707 r
F P
0 g
s
.69777 .90856 m .69777 .89003 L .6814 .8974 L p .707 .577 .707 r
F P
0 g
s
.54846 .65375 m .54846 .59817 L .57784 .59479 L p .707 .577 .707 r
F P
0 g
s
.57784 .59479 m .57784 .65037 L .54846 .65375 L p .707 .577 .707 r
F P
0 g
s
.54846 .76791 m .54846 .73085 L .57784 .72747 L p .707 .577 .707 r
F P
0 g
s
.57784 .72747 m .57784 .76453 L .54846 .76791 L p .707 .577 .707 r
F P
0 g
s
.53538 .29328 m .53538 .79517 L .57686 .7904 L p .707 .577 .707 r
F P
0 g
s
.57686 .7904 m .57686 .28851 L .53538 .29328 L p .707 .577 .707 r
F P
0 g
s
.44643 .79358 m .44643 .2917 L .40766 .28549 L p .707 .577 .707 r
F P
0 g
s
.44643 .2917 m .44643 .79358 L .49044 .79627 L p .707 .577 .707 r
F P
0 g
s
.51644 .91299 m .51644 .89446 L .50385 .88658 L p .707 .577 .707 r
F P
0 g
s
.70195 .61465 m .70195 .67023 L .68936 .66234 L p .707 .577 .707 r
F P
0 g
s
.68936 .66234 m .68936 .60676 L .70195 .61465 L p .707 .577 .707 r
F P
0 g
s
.50385 .88658 m .50385 .9051 L .51644 .91299 L p .707 .577 .707 r
F P
0 g
s
.57784 .65037 m .57784 .59479 L .60968 .59402 L p .707 .577 .707 r
F P
0 g
s
.60968 .59402 m .60968 .6496 L .57784 .65037 L p .707 .577 .707 r
F P
0 g
s
.57784 .76453 m .57784 .72747 L .60968 .7267 L p .707 .577 .707 r
F P
0 g
s
.60968 .7267 m .60968 .76375 L .57784 .76453 L p .707 .577 .707 r
F P
0 g
s
.57686 .28851 m .57686 .7904 L .61082 .78242 L p .707 .577 .707 r
F P
0 g
s
.64085 .59592 m .64085 .6515 L .60968 .6496 L p .707 .577 .707 r
F P
0 g
s
.60968 .6496 m .60968 .59402 L .64085 .59592 L p .707 .577 .707 r
F P
0 g
s
.64085 .7286 m .64085 .76565 L .60968 .76375 L p .707 .577 .707 r
F P
0 g
s
.60968 .76375 m .60968 .7267 L .64085 .7286 L p .707 .577 .707 r
F P
0 g
s
.61082 .78242 m .61082 .28053 L .57686 .28851 L p .707 .577 .707 r
F P
0 g
s
.70485 .75587 m .70485 .79292 L .70195 .78438 L p .707 .577 .707 r
F P
0 g
s
.70195 .78438 m .70195 .74733 L .70485 .75587 L p .707 .577 .707 r
F P
0 g
s
.25312 .66749 m .25312 .61191 L .22195 .61001 L p .707 .577 .707 r
F P
0 g
s
.25312 .61191 m .25312 .66749 L .28495 .66672 L p .707 .577 .707 r
F P
0 g
s
.28495 .66672 m .28495 .61113 L .25312 .61191 L p .707 .577 .707 r
F P
0 g
s
.69777 .89003 m .69777 .90856 L .70485 .9002 L p .707 .577 .707 r
F P
0 g
s
.70485 .9002 m .70485 .88167 L .69777 .89003 L p .707 .577 .707 r
F P
0 g
s
.28495 .61113 m .28495 .66672 L .31434 .66334 L p .707 .577 .707 r
F P
0 g
s
.31434 .66334 m .31434 .60776 L .28495 .61113 L p .707 .577 .707 r
F P
0 g
s
.40766 .78738 m .40766 .28549 L .37794 .27638 L p .707 .577 .707 r
F P
0 g
s
.40766 .28549 m .40766 .78738 L .44643 .79358 L p .707 .577 .707 r
F P
0 g
s
.22195 .66559 m .22195 .61001 L .19449 .60562 L p .707 .577 .707 r
F P
0 g
s
.22195 .61001 m .22195 .66559 L .25312 .66749 L p .707 .577 .707 r
F P
0 g
s
.50385 .9051 m .50385 .88658 L .50095 .87803 L p .707 .577 .707 r
F P
0 g
s
.31434 .60776 m .31434 .66334 L .33839 .65769 L p .707 .577 .707 r
F P
0 g
s
.33839 .65769 m .33839 .60211 L .31434 .60776 L p .707 .577 .707 r
F P
0 g
s
.68936 .60676 m .68936 .66234 L .66831 .65589 L p .707 .577 .707 r
F P
0 g
s
.66831 .65589 m .66831 .60031 L .68936 .60676 L p .707 .577 .707 r
F P
0 g
s
.50095 .87803 m .50095 .89656 L .50385 .9051 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19449 .60562 m .19449 .6612 L .22195 .66559 L p .707 .577 .707 r
F P
0 g
s
.19449 .6612 m .19449 .60562 L .17343 .59916 L p .707 .577 .707 r
F P
0 g
s
.61082 .28053 m .61082 .78242 L .63393 .77202 L p .707 .577 .707 r
F P
0 g
s
.63393 .77202 m .63393 .27013 L .61082 .28053 L p .707 .577 .707 r
F P
0 g
s
.70195 .74733 m .70195 .78438 L .68936 .7765 L p .707 .577 .707 r
F P
0 g
s
.68936 .7765 m .68936 .73944 L .70195 .74733 L p .707 .577 .707 r
F P
0 g
s
.70485 .88167 m .70485 .9002 L .70195 .89165 L p .707 .577 .707 r
F P
0 g
s
.70195 .89165 m .70195 .87313 L .70485 .88167 L p .707 .577 .707 r
F P
0 g
s
.33839 .60211 m .33839 .65769 L .35476 .65032 L p .707 .577 .707 r
F P
0 g
s
.35476 .65032 m .35476 .59474 L .33839 .60211 L p .707 .577 .707 r
F P
0 g
s
.25312 .78165 m .25312 .74459 L .22195 .74269 L p .707 .577 .707 r
F P
0 g
s
.25312 .74459 m .25312 .78165 L .28495 .78087 L p .707 .577 .707 r
F P
0 g
s
.28495 .78087 m .28495 .74382 L .25312 .74459 L p .707 .577 .707 r
F P
0 g
s
.17343 .59916 m .17343 .65475 L .19449 .6612 L p .707 .577 .707 r
F P
0 g
s
.37794 .77827 m .37794 .27638 L .36016 .26525 L p .707 .577 .707 r
F P
0 g
s
.37794 .27638 m .37794 .77827 L .40766 .78738 L p .707 .577 .707 r
F P
0 g
s
.28495 .74382 m .28495 .78087 L .31434 .77749 L p .707 .577 .707 r
F P
0 g
s
.31434 .77749 m .31434 .74044 L .28495 .74382 L p .707 .577 .707 r
F P
0 g
s
.66831 .60031 m .66831 .65589 L .64085 .6515 L p .707 .577 .707 r
F P
0 g
s
.64085 .6515 m .64085 .59592 L .66831 .60031 L p .707 .577 .707 r
F P
0 g
s
.22195 .77975 m .22195 .74269 L .19449 .7383 L p .707 .577 .707 r
F P
0 g
s
.22195 .74269 m .22195 .77975 L .25312 .78165 L p .707 .577 .707 r
F P
0 g
s
.50095 .89656 m .50095 .87803 L .50804 .86967 L p .707 .577 .707 r
F P
0 g
s
.17343 .65475 m .17343 .59916 L .16084 .59128 L p .707 .577 .707 r
F P
0 g
s
.50804 .86967 m .50804 .8882 L .50095 .89656 L p .707 .577 .707 r
F P
0 g
s
.31434 .74044 m .31434 .77749 L .33839 .77184 L p .707 .577 .707 r
F P
0 g
s
.33839 .77184 m .33839 .73479 L .31434 .74044 L p .707 .577 .707 r
F P
0 g
s
.19449 .7383 m .19449 .77535 L .22195 .77975 L p .707 .577 .707 r
F P
0 g
s
.68936 .73944 m .68936 .7765 L .66831 .77004 L p .707 .577 .707 r
F P
0 g
s
.66831 .77004 m .66831 .73299 L .68936 .73944 L p .707 .577 .707 r
F P
0 g
s
.19449 .77535 m .19449 .7383 L .17343 .73185 L p .707 .577 .707 r
F P
0 g
s
.16084 .59128 m .16084 .64686 L .17343 .65475 L p .707 .577 .707 r
F P
0 g
s
.35476 .59474 m .35476 .65032 L .36184 .64196 L p .707 .577 .707 r
F P
0 g
s
.36184 .64196 m .36184 .58637 L .35476 .59474 L p .707 .577 .707 r
F P
0 g
s
.64085 .76565 m .64085 .7286 L .66831 .73299 L p .707 .577 .707 r
F P
0 g
s
.63393 .27013 m .63393 .77202 L .64393 .76021 L p .707 .577 .707 r
F P
0 g
s
.64393 .76021 m .64393 .25832 L .63393 .27013 L p .707 .577 .707 r
F P
0 g
s
.70195 .87313 m .70195 .89165 L .68936 .88377 L p .707 .577 .707 r
F P
0 g
s
.68936 .88377 m .68936 .86524 L .70195 .87313 L p .707 .577 .707 r
F P
0 g
s
.17343 .73185 m .17343 .7689 L .19449 .77535 L p .707 .577 .707 r
F P
0 g
s
.25312 .88892 m .25312 .87039 L .22195 .86849 L p .707 .577 .707 r
F P
0 g
s
.25312 .87039 m .25312 .88892 L .28495 .88814 L p .707 .577 .707 r
F P
0 g
s
.28495 .88814 m .28495 .86961 L .25312 .87039 L p .707 .577 .707 r
F P
0 g
s
.33839 .73479 m .33839 .77184 L .35476 .76447 L p .707 .577 .707 r
F P
0 g
s
.35476 .76447 m .35476 .72742 L .33839 .73479 L p .707 .577 .707 r
F P
0 g
s
.16084 .64686 m .16084 .59128 L .15794 .58274 L p .707 .577 .707 r
F P
0 g
s
.50804 .8882 m .50804 .86967 L .5244 .8623 L p .707 .577 .707 r
F P
0 g
s
.28495 .86961 m .28495 .88814 L .31434 .88476 L p .707 .577 .707 r
F P
0 g
s
.31434 .88476 m .31434 .86624 L .28495 .86961 L p .707 .577 .707 r
F P
0 g
s
.22195 .86849 m .22195 .88702 L .25312 .88892 L p .707 .577 .707 r
F P
0 g
s
.66831 .73299 m .66831 .77004 L .64085 .76565 L p .707 .577 .707 r
F P
0 g
s
.22195 .88702 m .22195 .86849 L .19449 .8641 L p .707 .577 .707 r
F P
0 g
s
.36184 .58637 m .36184 .64196 L .35894 .63341 L p .707 .577 .707 r
F P
0 g
s
.35894 .63341 m .35894 .57783 L .36184 .58637 L p .707 .577 .707 r
F P
0 g
s
.35476 .72742 m .35476 .76447 L .36184 .75611 L p .707 .577 .707 r
F P
0 g
s
.36184 .75611 m .36184 .71905 L .35476 .72742 L p .707 .577 .707 r
F P
0 g
s
.35894 .57783 m .35894 .63341 L .34635 .62553 L p .707 .577 .707 r
F P
0 g
s
.34635 .62553 m .34635 .56995 L .35894 .57783 L p .707 .577 .707 r
F P
0 g
s
.36184 .71905 m .36184 .75611 L .35894 .74757 L p .707 .577 .707 r
F P
0 g
s
.35894 .74757 m .35894 .71051 L .36184 .71905 L p .707 .577 .707 r
F P
0 g
s
.36016 .76714 m .36016 .26525 L .35607 .25319 L p .707 .577 .707 r
F P
0 g
s
.36016 .26525 m .36016 .76714 L .37794 .77827 L p .707 .577 .707 r
F P
0 g
s
.5244 .8623 m .5244 .88083 L .50804 .8882 L p .707 .577 .707 r
F P
0 g
s
.17343 .7689 m .17343 .73185 L .16084 .72396 L p .707 .577 .707 r
F P
0 g
s
.19449 .8641 m .19449 .88263 L .22195 .88702 L p .707 .577 .707 r
F P
0 g
s
.31434 .86624 m .31434 .88476 L .33839 .87911 L p .707 .577 .707 r
F P
0 g
s
.33839 .87911 m .33839 .86059 L .31434 .86624 L p .707 .577 .707 r
F P
0 g
s
.15794 .58274 m .15794 .63832 L .16084 .64686 L p .707 .577 .707 r
F P
0 g
s
.68936 .86524 m .68936 .88377 L .66831 .87732 L p .707 .577 .707 r
F P
0 g
s
.66831 .87732 m .66831 .85879 L .68936 .86524 L p .707 .577 .707 r
F P
0 g
s
.16084 .72396 m .16084 .76102 L .17343 .7689 L p .707 .577 .707 r
F P
0 g
s
.19449 .88263 m .19449 .8641 L .17343 .85764 L p .707 .577 .707 r
F P
0 g
s
.17343 .85764 m .17343 .87617 L .19449 .88263 L p .707 .577 .707 r
F P
0 g
s
.5244 .88083 m .5244 .8623 L .54846 .85665 L p .707 .577 .707 r
F P
0 g
s
.64393 .25832 m .64393 .76021 L .63984 .74815 L p .707 .577 .707 r
F P
0 g
s
.63984 .74815 m .63984 .24626 L .64393 .25832 L p .707 .577 .707 r
F P
0 g
s
.15794 .63832 m .15794 .58274 L .16503 .57437 L p .707 .577 .707 r
F P
0 g
s
.54846 .85665 m .54846 .87518 L .5244 .88083 L p .707 .577 .707 r
F P
0 g
s
.33839 .86059 m .33839 .87911 L .35476 .87175 L p .707 .577 .707 r
F P
0 g
s
.35476 .87175 m .35476 .85322 L .33839 .86059 L p .707 .577 .707 r
F P
0 g
s
.16084 .76102 m .16084 .72396 L .15794 .71542 L p .707 .577 .707 r
F P
0 g
s
.66831 .85879 m .66831 .87732 L .64085 .87292 L p .707 .577 .707 r
F P
0 g
s
.64085 .87292 m .64085 .8544 L .66831 .85879 L p .707 .577 .707 r
F P
0 g
s
.17343 .87617 m .17343 .85764 L .16084 .84976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57437 m .16503 .62996 L .15794 .63832 L p .707 .577 .707 r
F P
0 g
s
.54846 .87518 m .54846 .85665 L .57784 .85327 L p .707 .577 .707 r
F P
0 g
s
.15794 .71542 m .15794 .75247 L .16084 .76102 L p .707 .577 .707 r
F P
0 g
s
.35894 .71051 m .35894 .74757 L .34635 .73968 L p .707 .577 .707 r
F P
0 g
s
.34635 .73968 m .34635 .70263 L .35894 .71051 L p .707 .577 .707 r
F P
0 g
s
.35607 .25319 m .35607 .75508 L .36016 .76714 L p .707 .577 .707 r
F P
0 g
s
.35607 .75508 m .35607 .25319 L .36607 .24138 L p .707 .577 .707 r
F P
0 g
s
.16084 .84976 m .16084 .86829 L .17343 .87617 L p .707 .577 .707 r
F P
0 g
s
.57784 .85327 m .57784 .8718 L .54846 .87518 L p .707 .577 .707 r
F P
0 g
s
.64085 .8544 m .64085 .87292 L .60968 .87102 L p .707 .577 .707 r
F P
0 g
s
.60968 .87102 m .60968 .8525 L .64085 .8544 L p .707 .577 .707 r
F P
0 g
s
.57784 .8718 m .57784 .85327 L .60968 .8525 L p .707 .577 .707 r
F P
0 g
s
.35476 .85322 m .35476 .87175 L .36184 .86338 L p .707 .577 .707 r
F P
0 g
s
.36184 .86338 m .36184 .84485 L .35476 .85322 L p .707 .577 .707 r
F P
0 g
s
.16503 .62996 m .16503 .57437 L .1814 .56701 L p .707 .577 .707 r
F P
0 g
s
.60968 .8525 m .60968 .87102 L .57784 .8718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .75247 m .15794 .71542 L .16503 .70706 L p .707 .577 .707 r
F P
0 g
s
.16084 .86829 m .16084 .84976 L .15794 .84122 L p .707 .577 .707 r
F P
0 g
s
.63984 .24626 m .63984 .74815 L .62206 .73702 L p .707 .577 .707 r
F P
0 g
s
.62206 .73702 m .62206 .23513 L .63984 .24626 L p .707 .577 .707 r
F P
0 g
s
.1814 .56701 m .1814 .62259 L .16503 .62996 L p .707 .577 .707 r
F P
0 g
s
.34635 .56995 m .34635 .62553 L .3253 .61908 L p .707 .577 .707 r
F P
0 g
s
.3253 .61908 m .3253 .56349 L .34635 .56995 L p .707 .577 .707 r
F P
0 g
s
.15794 .84122 m .15794 .85975 L .16084 .86829 L p .707 .577 .707 r
F P
0 g
s
.16503 .70706 m .16503 .74411 L .15794 .75247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .62259 m .1814 .56701 L .20545 .56136 L p .707 .577 .707 r
F P
0 g
s
.36184 .84485 m .36184 .86338 L .35894 .85484 L p .707 .577 .707 r
F P
0 g
s
.35894 .85484 m .35894 .83631 L .36184 .84485 L p .707 .577 .707 r
F P
0 g
s
.36607 .74327 m .36607 .24138 L .38918 .23098 L p .707 .577 .707 r
F P
0 g
s
.36607 .24138 m .36607 .74327 L .35607 .75508 L p .707 .577 .707 r
F P
0 g
s
.16503 .74411 m .16503 .70706 L .1814 .69969 L p .707 .577 .707 r
F P
0 g
s
.3253 .56349 m .3253 .61908 L .29784 .61468 L p .707 .577 .707 r
F P
0 g
s
.29784 .61468 m .29784 .5591 L .3253 .56349 L p .707 .577 .707 r
F P
0 g
s
.20545 .56136 m .20545 .61694 L .1814 .62259 L p .707 .577 .707 r
F P
0 g
s
.15794 .85975 m .15794 .84122 L .16503 .83285 L p .707 .577 .707 r
F P
0 g
s
.20545 .61694 m .20545 .56136 L .23483 .55798 L p .707 .577 .707 r
F P
0 g
s
.16503 .83285 m .16503 .85138 L .15794 .85975 L p .707 .577 .707 r
F P
0 g
s
.1814 .69969 m .1814 .73674 L .16503 .74411 L p .707 .577 .707 r
F P
0 g
s
.62206 .23513 m .62206 .73702 L .59233 .72791 L p .707 .577 .707 r
F P
0 g
s
.59233 .72791 m .59233 .22602 L .62206 .23513 L p .707 .577 .707 r
F P
0 g
s
.34635 .70263 m .34635 .73968 L .3253 .73323 L p .707 .577 .707 r
F P
0 g
s
.3253 .73323 m .3253 .69617 L .34635 .70263 L p .707 .577 .707 r
F P
0 g
s
.29784 .5591 m .29784 .61468 L .26667 .61278 L p .707 .577 .707 r
F P
0 g
s
.26667 .61278 m .26667 .5572 L .29784 .5591 L p .707 .577 .707 r
F P
0 g
s
.23483 .61356 m .23483 .55798 L .26667 .5572 L p .707 .577 .707 r
F P
0 g
s
.23483 .55798 m .23483 .61356 L .20545 .61694 L p .707 .577 .707 r
F P
0 g
s
.35894 .83631 m .35894 .85484 L .34635 .84695 L p .707 .577 .707 r
F P
0 g
s
.34635 .84695 m .34635 .82843 L .35894 .83631 L p .707 .577 .707 r
F P
0 g
s
.26667 .5572 m .26667 .61278 L .23483 .61356 L p .707 .577 .707 r
F P
0 g
s
.1814 .73674 m .1814 .69969 L .20545 .69404 L p .707 .577 .707 r
F P
0 g
s
.73333 .61227 m .73333 .55669 L .70216 .55479 L p .707 .577 .707 r
F P
0 g
s
.73333 .55669 m .73333 .61227 L .76517 .61149 L p .707 .577 .707 r
F P
0 g
s
.76517 .61149 m .76517 .55591 L .73333 .55669 L p .707 .577 .707 r
F P
0 g
s
.76517 .55591 m .76517 .61149 L .79455 .60811 L p .707 .577 .707 r
F P
0 g
s
.79455 .60811 m .79455 .55253 L .76517 .55591 L p .707 .577 .707 r
F P
0 g
s
.38918 .23098 m .38918 .73287 L .36607 .74327 L p .707 .577 .707 r
F P
0 g
s
.38918 .73287 m .38918 .23098 L .42314 .22301 L p .707 .577 .707 r
F P
0 g
s
.70216 .61037 m .70216 .55479 L .6747 .5504 L p .707 .577 .707 r
F P
0 g
s
.70216 .55479 m .70216 .61037 L .73333 .61227 L p .707 .577 .707 r
F P
0 g
s
.16503 .85138 m .16503 .83285 L .1814 .82549 L p .707 .577 .707 r
F P
0 g
s
.20545 .69404 m .20545 .73109 L .1814 .73674 L p .707 .577 .707 r
F P
0 g
s
.3253 .69617 m .3253 .73323 L .29784 .72884 L p .707 .577 .707 r
F P
0 g
s
.29784 .72884 m .29784 .69178 L .3253 .69617 L p .707 .577 .707 r
F P
0 g
s
.1814 .82549 m .1814 .84401 L .16503 .85138 L p .707 .577 .707 r
F P
0 g
s
.79455 .55253 m .79455 .60811 L .8186 .60246 L p .707 .577 .707 r
F P
0 g
s
.8186 .60246 m .8186 .54688 L .79455 .55253 L p .707 .577 .707 r
F P
0 g
s
.20545 .73109 m .20545 .69404 L .23483 .69066 L p .707 .577 .707 r
F P
0 g
s
.59233 .22602 m .59233 .72791 L .55357 .72171 L p .707 .577 .707 r
F P
0 g
s
.55357 .72171 m .55357 .21982 L .59233 .22602 L p .707 .577 .707 r
F P
0 g
s
.6747 .5504 m .6747 .60598 L .70216 .61037 L p .707 .577 .707 r
F P
0 g
s
.6747 .60598 m .6747 .5504 L .65365 .54394 L p .707 .577 .707 r
F P
0 g
s
.34635 .82843 m .34635 .84695 L .3253 .8405 L p .707 .577 .707 r
F P
0 g
s
.3253 .8405 m .3253 .82197 L .34635 .82843 L p .707 .577 .707 r
F P
0 g
s
.29784 .69178 m .29784 .72884 L .26667 .72694 L p .707 .577 .707 r
F P
0 g
s
.26667 .72694 m .26667 .68988 L .29784 .69178 L p .707 .577 .707 r
F P
0 g
s
.23483 .69066 m .23483 .72771 L .20545 .73109 L p .707 .577 .707 r
F P
0 g
s
.23483 .72771 m .23483 .69066 L .26667 .68988 L p .707 .577 .707 r
F P
0 g
s
.42314 .72489 m .42314 .22301 L .46462 .21824 L p .707 .577 .707 r
F P
0 g
s
.42314 .22301 m .42314 .72489 L .38918 .73287 L p .707 .577 .707 r
F P
0 g
s
.1814 .84401 m .1814 .82549 L .20545 .81984 L p .707 .577 .707 r
F P
0 g
s
.26667 .68988 m .26667 .72694 L .23483 .72771 L p .707 .577 .707 r
F P
0 g
s
.8186 .54688 m .8186 .60246 L .83497 .5951 L p .707 .577 .707 r
F P
0 g
s
.83497 .5951 m .83497 .53951 L .8186 .54688 L p .707 .577 .707 r
F P
0 g
s
.73333 .72642 m .73333 .68937 L .70216 .68747 L p .707 .577 .707 r
F P
0 g
s
.73333 .68937 m .73333 .72642 L .76517 .72565 L p .707 .577 .707 r
F P
0 g
s
.76517 .72565 m .76517 .68859 L .73333 .68937 L p .707 .577 .707 r
F P
0 g
s
.65365 .54394 m .65365 .59952 L .6747 .60598 L p .707 .577 .707 r
F P
0 g
s
.76517 .68859 m .76517 .72565 L .79455 .72227 L p .707 .577 .707 r
F P
0 g
s
.79455 .72227 m .79455 .68521 L .76517 .68859 L p .707 .577 .707 r
F P
0 g
s
.20545 .81984 m .20545 .83836 L .1814 .84401 L p .707 .577 .707 r
F P
0 g
s
.70216 .72452 m .70216 .68747 L .6747 .68308 L p .707 .577 .707 r
F P
0 g
s
.70216 .68747 m .70216 .72452 L .73333 .72642 L p .707 .577 .707 r
F P
0 g
s
.55357 .21982 m .55357 .72171 L .50956 .71903 L p .707 .577 .707 r
F P
0 g
s
.50956 .71903 m .50956 .21714 L .55357 .21982 L p .707 .577 .707 r
F P
0 g
s
.65365 .59952 m .65365 .54394 L .64105 .53606 L p .707 .577 .707 r
F P
0 g
s
.3253 .82197 m .3253 .8405 L .29784 .83611 L p .707 .577 .707 r
F P
0 g
s
.29784 .83611 m .29784 .81758 L .3253 .82197 L p .707 .577 .707 r
F P
0 g
s
.46462 .72012 m .46462 .21824 L .50956 .21714 L p .707 .577 .707 r
F P
0 g
s
.46462 .21824 m .46462 .72012 L .42314 .72489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68521 m .79455 .72227 L .8186 .71662 L p .707 .577 .707 r
F P
0 g
s
.8186 .71662 m .8186 .67956 L .79455 .68521 L p .707 .577 .707 r
F P
0 g
s
.50956 .21714 m .50956 .71903 L .46462 .72012 L p .707 .577 .707 r
F P
0 g
s
.6747 .68308 m .6747 .72013 L .70216 .72452 L p .707 .577 .707 r
F P
0 g
s
.20545 .83836 m .20545 .81984 L .23483 .81646 L p .707 .577 .707 r
F P
0 g
s
.6747 .72013 m .6747 .68308 L .65365 .67662 L p .707 .577 .707 r
F P
0 g
s
.23483 .81646 m .23483 .83499 L .20545 .83836 L p .707 .577 .707 r
F P
0 g
s
.64105 .53606 m .64105 .59164 L .65365 .59952 L p .707 .577 .707 r
F P
0 g
s
.83497 .53951 m .83497 .5951 L .84205 .58673 L p .707 .577 .707 r
F P
0 g
s
.84205 .58673 m .84205 .53115 L .83497 .53951 L p .707 .577 .707 r
F P
0 g
s
.29784 .81758 m .29784 .83611 L .26667 .83421 L p .707 .577 .707 r
F P
0 g
s
.26667 .83421 m .26667 .81568 L .29784 .81758 L p .707 .577 .707 r
F P
0 g
s
.23483 .83499 m .23483 .81646 L .26667 .81568 L p .707 .577 .707 r
F P
0 g
s
.65365 .67662 m .65365 .71368 L .6747 .72013 L p .707 .577 .707 r
F P
0 g
s
.26667 .81568 m .26667 .83421 L .23483 .83499 L p .707 .577 .707 r
F P
0 g
s
.73333 .8337 m .73333 .81517 L .70216 .81327 L p .707 .577 .707 r
F P
0 g
s
.73333 .81517 m .73333 .8337 L .76517 .83292 L p .707 .577 .707 r
F P
0 g
s
.76517 .83292 m .76517 .81439 L .73333 .81517 L p .707 .577 .707 r
F P
0 g
s
.8186 .67956 m .8186 .71662 L .83497 .70925 L p .707 .577 .707 r
F P
0 g
s
.83497 .70925 m .83497 .6722 L .8186 .67956 L p .707 .577 .707 r
F P
0 g
s
.64105 .59164 m .64105 .53606 L .63816 .52751 L p .707 .577 .707 r
F P
0 g
s
.76517 .81439 m .76517 .83292 L .79455 .82954 L p .707 .577 .707 r
F P
0 g
s
.79455 .82954 m .79455 .81101 L .76517 .81439 L p .707 .577 .707 r
F P
0 g
s
.70216 .81327 m .70216 .8318 L .73333 .8337 L p .707 .577 .707 r
F P
0 g
s
.70216 .8318 m .70216 .81327 L .6747 .80888 L p .707 .577 .707 r
F P
0 g
s
.65365 .71368 m .65365 .67662 L .64105 .66874 L p .707 .577 .707 r
F P
0 g
s
.6747 .80888 m .6747 .8274 L .70216 .8318 L p .707 .577 .707 r
F P
0 g
s
.79455 .81101 m .79455 .82954 L .8186 .82389 L p .707 .577 .707 r
F P
0 g
s
.8186 .82389 m .8186 .80536 L .79455 .81101 L p .707 .577 .707 r
F P
0 g
s
.63816 .52751 m .63816 .5831 L .64105 .59164 L p .707 .577 .707 r
F P
0 g
s
.84205 .53115 m .84205 .58673 L .83916 .57819 L p .707 .577 .707 r
F P
0 g
s
.83916 .57819 m .83916 .52261 L .84205 .53115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66874 m .64105 .70579 L .65365 .71368 L p .707 .577 .707 r
F P
0 g
s
.6747 .8274 m .6747 .80888 L .65365 .80242 L p .707 .577 .707 r
F P
0 g
s
.83497 .6722 m .83497 .70925 L .84206 .70089 L p .707 .577 .707 r
F P
0 g
s
.84206 .70089 m .84205 .66383 L .83497 .6722 L p .707 .577 .707 r
F P
0 g
s
.65365 .80242 m .65365 .82095 L .6747 .8274 L p .707 .577 .707 r
F P
0 g
s
.63816 .5831 m .63816 .52751 L .64524 .51915 L p .707 .577 .707 r
F P
0 g
s
.8186 .80536 m .8186 .82389 L .83497 .81652 L p .707 .577 .707 r
F P
0 g
s
.83497 .81652 m .83497 .798 L .8186 .80536 L p .707 .577 .707 r
F P
0 g
s
.64105 .70579 m .64105 .66874 L .63816 .6602 L p .707 .577 .707 r
F P
0 g
s
.65365 .82095 m .65365 .80242 L .64105 .79454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .51915 m .64524 .57473 L .63816 .5831 L p .707 .577 .707 r
F P
0 g
s
.63816 .6602 m .63816 .69725 L .64105 .70579 L p .707 .577 .707 r
F P
0 g
s
.83916 .52261 m .83916 .57819 L .82657 .57031 L p .707 .577 .707 r
F P
0 g
s
.82657 .57031 m .82657 .51472 L .83916 .52261 L p .707 .577 .707 r
F P
0 g
s
.64105 .79454 m .64105 .81307 L .65365 .82095 L p .707 .577 .707 r
F P
0 g
s
.84205 .66383 m .84206 .70089 L .83916 .69234 L p .707 .577 .707 r
F P
0 g
s
.83916 .69234 m .83916 .65529 L .84205 .66383 L p .707 .577 .707 r
F P
0 g
s
.39032 .57545 m .39032 .51987 L .35915 .51797 L p .707 .577 .707 r
F P
0 g
s
.39032 .51987 m .39032 .57545 L .42216 .57468 L p .707 .577 .707 r
F P
0 g
s
.42216 .57468 m .42216 .5191 L .39032 .51987 L p .707 .577 .707 r
F P
0 g
s
.83497 .798 m .83497 .81652 L .84206 .80816 L p .707 .577 .707 r
F P
0 g
s
.84206 .80816 m .84206 .78963 L .83497 .798 L p .707 .577 .707 r
F P
0 g
s
.64524 .57473 m .64524 .51915 L .66161 .51178 L p .707 .577 .707 r
F P
0 g
s
.42216 .5191 m .42216 .57468 L .45154 .5713 L p .707 .577 .707 r
F P
0 g
s
.45154 .5713 m .45154 .51572 L .42216 .5191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.35915 .57355 m .35915 .51797 L .33169 .51358 L p .707 .577 .707 r
F P
0 g
s
.35915 .51797 m .35915 .57355 L .39032 .57545 L p .707 .577 .707 r
F P
0 g
s
.63816 .69725 m .63816 .6602 L .64524 .65183 L p .707 .577 .707 r
F P
0 g
s
.64105 .81307 m .64105 .79454 L .63816 .786 L p .707 .577 .707 r
F P
0 g
s
.45154 .51572 m .45154 .5713 L .47559 .56565 L p .707 .577 .707 r
F P
0 g
s
.47559 .56565 m .47559 .51007 L .45154 .51572 L p .707 .577 .707 r
F P
0 g
s
.66161 .51178 m .66161 .56736 L .64524 .57473 L p .707 .577 .707 r
F P
0 g
s
.82657 .51472 m .82657 .57031 L .80551 .56385 L p .707 .577 .707 r
F P
0 g
s
.80551 .56385 m .80551 .50827 L .82657 .51472 L p .707 .577 .707 r
F P
0 g
s
.63816 .786 m .63816 .80452 L .64105 .81307 L p .707 .577 .707 r
F P
0 g
s
.64524 .65183 m .64524 .68889 L .63816 .69725 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.33169 .51358 m .33169 .56916 L .35915 .57355 L p .707 .577 .707 r
F P
0 g
s
.33169 .56916 m .33169 .51358 L .31064 .50713 L p .707 .577 .707 r
F P
0 g
s
.83916 .65529 m .83916 .69234 L .82657 .68446 L p .707 .577 .707 r
F P
0 g
s
.82657 .68446 m .82657 .64741 L .83916 .65529 L p .707 .577 .707 r
F P
0 g
s
.66161 .56736 m .66161 .51178 L .68566 .50613 L p .707 .577 .707 r
F P
0 g
s
.84206 .78963 m .84206 .80816 L .83916 .79962 L p .707 .577 .707 r
F P
0 g
s
.83916 .79962 m .83916 .78109 L .84206 .78963 L p .707 .577 .707 r
F P
0 g
s
.47559 .51007 m .47559 .56565 L .49196 .55828 L p .707 .577 .707 r
F P
0 g
s
.49196 .55828 m .49196 .5027 L .47559 .51007 L p .707 .577 .707 r
F P
0 g
s
.39032 .68961 m .39032 .65255 L .35915 .65065 L p .707 .577 .707 r
F P
0 g
s
.39032 .65255 m .39032 .68961 L .42216 .68883 L p .707 .577 .707 r
F P
0 g
s
.42216 .68883 m .42216 .65178 L .39032 .65255 L p .707 .577 .707 r
F P
0 g
s
.31064 .50713 m .31064 .56271 L .33169 .56916 L p .707 .577 .707 r
F P
0 g
s
.64524 .68889 m .64524 .65183 L .66161 .64446 L p .707 .577 .707 r
F P
0 g
s
.42216 .65178 m .42216 .68883 L .45154 .68545 L p .707 .577 .707 r
F P
0 g
s
.45154 .68545 m .45154 .6484 L .42216 .65178 L p .707 .577 .707 r
F P
0 g
s
.80551 .50827 m .80551 .56385 L .77805 .55946 L p .707 .577 .707 r
F P
0 g
s
.77805 .55946 m .77805 .50388 L .80551 .50827 L p .707 .577 .707 r
F P
0 g
s
.35915 .68771 m .35915 .65065 L .33169 .64626 L p .707 .577 .707 r
F P
0 g
s
.35915 .65065 m .35915 .68771 L .39032 .68961 L p .707 .577 .707 r
F P
0 g
s
.68566 .50613 m .68566 .56172 L .66161 .56736 L p .707 .577 .707 r
F P
0 g
s
.63816 .80452 m .63816 .786 L .64524 .77763 L p .707 .577 .707 r
F P
0 g
s
.31064 .56271 m .31064 .50713 L .29804 .49924 L p .707 .577 .707 r
F P
0 g
s
.68566 .56172 m .68566 .50613 L .71504 .50275 L p .707 .577 .707 r
F P
0 g
s
.64524 .77763 m .64524 .79616 L .63816 .80452 L p .707 .577 .707 r
F P
0 g
s
.66161 .64446 m .66161 .68152 L .64524 .68889 L p .707 .577 .707 r
F P
0 g
s
.45154 .6484 m .45154 .68545 L .47559 .6798 L p .707 .577 .707 r
F P
0 g
s
.47559 .6798 m .47559 .64275 L .45154 .6484 L p .707 .577 .707 r
F P
0 g
s
.33169 .64626 m .33169 .68332 L .35915 .68771 L p .707 .577 .707 r
F P
0 g
s
.82657 .64741 m .82657 .68446 L .80551 .67801 L p .707 .577 .707 r
F P
0 g
s
.80551 .67801 m .80551 .64095 L .82657 .64741 L p .707 .577 .707 r
F P
0 g
s
.77805 .50388 m .77805 .55946 L .74688 .55756 L p .707 .577 .707 r
F P
0 g
s
.74688 .55756 m .74688 .50198 L .77805 .50388 L p .707 .577 .707 r
F P
0 g
s
.33169 .68332 m .33169 .64626 L .31064 .63981 L p .707 .577 .707 r
F P
0 g
s
.29804 .49924 m .29804 .55482 L .31064 .56271 L p .707 .577 .707 r
F P
0 g
s
.71504 .55834 m .71504 .50275 L .74688 .50198 L p .707 .577 .707 r
F P
0 g
s
.71504 .50275 m .71504 .55834 L .68566 .56172 L p .707 .577 .707 r
F P
0 g
s
.49196 .5027 m .49196 .55828 L .49904 .54992 L p .707 .577 .707 r
F P
0 g
s
.49904 .54992 m .49904 .49433 L .49196 .5027 L p .707 .577 .707 r
F P
0 g
s
.83916 .78109 m .83916 .79962 L .82657 .79173 L p .707 .577 .707 r
F P
0 g
s
.82657 .79173 m .82657 .7732 L .83916 .78109 L p .707 .577 .707 r
F P
0 g
s
.74688 .50198 m .74688 .55756 L .71504 .55834 L p .707 .577 .707 r
F P
0 g
s
.66161 .68152 m .66161 .64446 L .68566 .63881 L p .707 .577 .707 r
F P
0 g
s
.31064 .63981 m .31064 .67686 L .33169 .68332 L p .707 .577 .707 r
F P
0 g
s
.39032 .79688 m .39032 .77835 L .35915 .77645 L p .707 .577 .707 r
F P
0 g
s
.39032 .77835 m .39032 .79688 L .42216 .7961 L p .707 .577 .707 r
F P
0 g
s
.42216 .7961 m .42216 .77758 L .39032 .77835 L p .707 .577 .707 r
F P
0 g
s
.47559 .64275 m .47559 .6798 L .49196 .67244 L p .707 .577 .707 r
F P
0 g
s
.49196 .67244 m .49196 .63538 L .47559 .64275 L p .707 .577 .707 r
F P
0 g
s
.29804 .55482 m .29804 .49924 L .29515 .4907 L p .707 .577 .707 r
F P
0 g
s
.64524 .79616 m .64524 .77763 L .66161 .77026 L p .707 .577 .707 r
F P
0 g
s
.42216 .77758 m .42216 .7961 L .45154 .79272 L p .707 .577 .707 r
F P
0 g
s
.45154 .79272 m .45154 .7742 L .42216 .77758 L p .707 .577 .707 r
F P
0 g
s
.68566 .63881 m .68566 .67587 L .66161 .68152 L p .707 .577 .707 r
F P
0 g
s
.35915 .77645 m .35915 .79498 L .39032 .79688 L p .707 .577 .707 r
F P
0 g
s
.80551 .64095 m .80551 .67801 L .77805 .67361 L p .707 .577 .707 r
F P
0 g
s
.77805 .67361 m .77805 .63656 L .80551 .64095 L p .707 .577 .707 r
F P
0 g
s
.35915 .79498 m .35915 .77645 L .33169 .77206 L p .707 .577 .707 r
F P
0 g
s
.66161 .77026 m .66161 .78879 L .64524 .79616 L p .707 .577 .707 r
F P
0 g
s
.31064 .67686 m .31064 .63981 L .29804 .63192 L p .707 .577 .707 r
F P
0 g
s
.33169 .77206 m .33169 .79059 L .35915 .79498 L p .707 .577 .707 r
F P
0 g
s
.68566 .67587 m .68566 .63881 L .71504 .63544 L p .707 .577 .707 r
F P
0 g
s
.45154 .7742 m .45154 .79272 L .47559 .78707 L p .707 .577 .707 r
F P
0 g
s
.47559 .78707 m .47559 .76855 L .45154 .7742 L p .707 .577 .707 r
F P
0 g
s
.29515 .4907 m .29515 .54628 L .29804 .55482 L p .707 .577 .707 r
F P
0 g
s
.82657 .7732 m .82657 .79173 L .80551 .78528 L p .707 .577 .707 r
F P
0 g
s
.80551 .78528 m .80551 .76675 L .82657 .7732 L p .707 .577 .707 r
F P
0 g
s
.49904 .49433 m .49904 .54992 L .49615 .54137 L p .707 .577 .707 r
F P
0 g
s
.49615 .54137 m .49615 .48579 L .49904 .49433 L p .707 .577 .707 r
F P
0 g
s
.29804 .63192 m .29804 .66898 L .31064 .67686 L p .707 .577 .707 r
F P
0 g
s
.77805 .63656 m .77805 .67361 L .74688 .67171 L p .707 .577 .707 r
F P
0 g
s
.74688 .67171 m .74688 .63466 L .77805 .63656 L p .707 .577 .707 r
F P
0 g
s
.33169 .79059 m .33169 .77206 L .31064 .76561 L p .707 .577 .707 r
F P
0 g
s
.71504 .63544 m .71504 .67249 L .68566 .67587 L p .707 .577 .707 r
F P
0 g
s
.71504 .67249 m .71504 .63544 L .74688 .63466 L p .707 .577 .707 r
F P
0 g
s
.49196 .63538 m .49196 .67244 L .49904 .66407 L p .707 .577 .707 r
F P
0 g
s
.49904 .66407 m .49904 .62702 L .49196 .63538 L p .707 .577 .707 r
F P
0 g
s
.31064 .76561 m .31064 .78413 L .33169 .79059 L p .707 .577 .707 r
F P
0 g
s
.66161 .78879 m .66161 .77026 L .68566 .76461 L p .707 .577 .707 r
F P
0 g
s
.74688 .63466 m .74688 .67171 L .71504 .67249 L p .707 .577 .707 r
F P
0 g
s
.29515 .54628 m .29515 .4907 L .30223 .48233 L p .707 .577 .707 r
F P
0 g
s
.68566 .76461 m .68566 .78314 L .66161 .78879 L p .707 .577 .707 r
F P
0 g
s
.47559 .76855 m .47559 .78707 L .49196 .77971 L p .707 .577 .707 r
F P
0 g
s
.49196 .77971 m .49196 .76118 L .47559 .76855 L p .707 .577 .707 r
F P
0 g
s
.29804 .66898 m .29804 .63192 L .29515 .62338 L p .707 .577 .707 r
F P
0 g
s
.80551 .76675 m .80551 .78528 L .77805 .78089 L p .707 .577 .707 r
F P
0 g
s
.77805 .78089 m .77805 .76236 L .80551 .76675 L p .707 .577 .707 r
F P
0 g
s
.31064 .78413 m .31064 .76561 L .29804 .75772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48233 m .30223 .53792 L .29515 .54628 L p .707 .577 .707 r
F P
0 g
s
.68566 .78314 m .68566 .76461 L .71504 .76123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62338 m .29515 .66044 L .29804 .66898 L p .707 .577 .707 r
F P
0 g
s
.49615 .48579 m .49615 .54137 L .48356 .53349 L p .707 .577 .707 r
F P
0 g
s
.48356 .53349 m .48356 .47791 L .49615 .48579 L p .707 .577 .707 r
F P
0 g
s
.29804 .75772 m .29804 .77625 L .31064 .78413 L p .707 .577 .707 r
F P
0 g
s
.71504 .76123 m .71504 .77976 L .68566 .78314 L p .707 .577 .707 r
F P
0 g
s
.49904 .62702 m .49904 .66407 L .49615 .65553 L p .707 .577 .707 r
F P
0 g
s
.49615 .65553 m .49615 .61847 L .49904 .62702 L p .707 .577 .707 r
F P
0 g
s
.77805 .76236 m .77805 .78089 L .74688 .77898 L p .707 .577 .707 r
F P
0 g
s
.74688 .77898 m .74688 .76046 L .77805 .76236 L p .707 .577 .707 r
F P
0 g
s
.71504 .77976 m .71504 .76123 L .74688 .76046 L p .707 .577 .707 r
F P
0 g
s
.49196 .76118 m .49196 .77971 L .49904 .77134 L p .707 .577 .707 r
F P
0 g
s
.49904 .77134 m .49904 .75282 L .49196 .76118 L p .707 .577 .707 r
F P
0 g
s
.30223 .53792 m .30223 .48233 L .3186 .47497 L p .707 .577 .707 r
F P
0 g
s
.74688 .76046 m .74688 .77898 L .71504 .77976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .66044 m .29515 .62338 L .30223 .61502 L p .707 .577 .707 r
F P
0 g
s
.29804 .77625 m .29804 .75772 L .29515 .74918 L p .707 .577 .707 r
F P
0 g
s
.3186 .47497 m .3186 .53055 L .30223 .53792 L p .707 .577 .707 r
F P
0 g
s
.48356 .47791 m .48356 .53349 L .4625 .52704 L p .707 .577 .707 r
F P
0 g
s
.4625 .52704 m .4625 .47145 L .48356 .47791 L p .707 .577 .707 r
F P
0 g
s
.29515 .74918 m .29515 .76771 L .29804 .77625 L p .707 .577 .707 r
F P
0 g
s
.30223 .61502 m .30223 .65207 L .29515 .66044 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .61847 m .49615 .65553 L .48356 .64764 L p .707 .577 .707 r
F P
0 g
s
.48356 .64764 m .48356 .61059 L .49615 .61847 L p .707 .577 .707 r
F P
0 g
s
.3186 .53055 m .3186 .47497 L .34265 .46932 L p .707 .577 .707 r
F P
0 g
s
.49904 .75282 m .49904 .77134 L .49615 .7628 L p .707 .577 .707 r
F P
0 g
s
.49615 .7628 m .49615 .74427 L .49904 .75282 L p .707 .577 .707 r
F P
0 g
s
.30223 .65207 m .30223 .61502 L .3186 .60765 L p .707 .577 .707 r
F P
0 g
s
.4625 .47145 m .4625 .52704 L .43504 .52264 L p .707 .577 .707 r
F P
0 g
s
.43504 .52264 m .43504 .46706 L .4625 .47145 L p .707 .577 .707 r
F P
0 g
s
.34265 .46932 m .34265 .5249 L .3186 .53055 L p .707 .577 .707 r
F P
0 g
s
.29515 .76771 m .29515 .74918 L .30223 .74082 L p .707 .577 .707 r
F P
0 g
s
.34265 .5249 m .34265 .46932 L .37203 .46594 L p .707 .577 .707 r
F P
0 g
s
.30223 .74082 m .30223 .75934 L .29515 .76771 L p .707 .577 .707 r
F P
0 g
s
.3186 .60765 m .3186 .6447 L .30223 .65207 L p .707 .577 .707 r
F P
0 g
s
.48356 .61059 m .48356 .64764 L .4625 .64119 L p .707 .577 .707 r
F P
0 g
s
.4625 .64119 m .4625 .60414 L .48356 .61059 L p .707 .577 .707 r
F P
0 g
s
.43504 .46706 m .43504 .52264 L .40387 .52074 L p .707 .577 .707 r
F P
0 g
s
.40387 .52074 m .40387 .46516 L .43504 .46706 L p .707 .577 .707 r
F P
0 g
s
.37203 .52152 m .37203 .46594 L .40387 .46516 L p .707 .577 .707 r
F P
0 g
s
.37203 .46594 m .37203 .52152 L .34265 .5249 L p .707 .577 .707 r
F P
0 g
s
.49615 .74427 m .49615 .7628 L .48356 .75492 L p .707 .577 .707 r
F P
0 g
s
.48356 .75492 m .48356 .73639 L .49615 .74427 L p .707 .577 .707 r
F P
0 g
s
.40387 .46516 m .40387 .52074 L .37203 .52152 L p .707 .577 .707 r
F P
0 g
s
.3186 .6447 m .3186 .60765 L .34265 .602 L p .707 .577 .707 r
F P
0 g
s
.30223 .75934 m .30223 .74082 L .3186 .73345 L p .707 .577 .707 r
F P
0 g
s
.34265 .602 m .34265 .63905 L .3186 .6447 L p .707 .577 .707 r
F P
0 g
s
.4625 .60414 m .4625 .64119 L .43504 .6368 L p .707 .577 .707 r
F P
0 g
s
.43504 .6368 m .43504 .59974 L .4625 .60414 L p .707 .577 .707 r
F P
0 g
s
.3186 .73345 m .3186 .75198 L .30223 .75934 L p .707 .577 .707 r
F P
0 g
s
.34265 .63905 m .34265 .602 L .37203 .59862 L p .707 .577 .707 r
F P
0 g
s
.48356 .73639 m .48356 .75492 L .4625 .74846 L p .707 .577 .707 r
F P
0 g
s
.4625 .74846 m .4625 .72993 L .48356 .73639 L p .707 .577 .707 r
F P
0 g
s
.43504 .59974 m .43504 .6368 L .40387 .6349 L p .707 .577 .707 r
F P
0 g
s
.40387 .6349 m .40387 .59784 L .43504 .59974 L p .707 .577 .707 r
F P
0 g
s
.37203 .59862 m .37203 .63567 L .34265 .63905 L p .707 .577 .707 r
F P
0 g
s
.37203 .63567 m .37203 .59862 L .40387 .59784 L p .707 .577 .707 r
F P
0 g
s
.3186 .75198 m .3186 .73345 L .34265 .7278 L p .707 .577 .707 r
F P
0 g
s
.40387 .59784 m .40387 .6349 L .37203 .63567 L p .707 .577 .707 r
F P
0 g
s
.34265 .7278 m .34265 .74633 L .3186 .75198 L p .707 .577 .707 r
F P
0 g
s
.4625 .72993 m .4625 .74846 L .43504 .74407 L p .707 .577 .707 r
F P
0 g
s
.43504 .74407 m .43504 .72554 L .4625 .72993 L p .707 .577 .707 r
F P
0 g
s
.34265 .74633 m .34265 .7278 L .37203 .72442 L p .707 .577 .707 r
F P
0 g
s
.37203 .72442 m .37203 .74295 L .34265 .74633 L p .707 .577 .707 r
F P
0 g
s
.43504 .72554 m .43504 .74407 L .40387 .74217 L p .707 .577 .707 r
F P
0 g
s
.40387 .74217 m .40387 .72364 L .43504 .72554 L p .707 .577 .707 r
F P
0 g
s
.37203 .74295 m .37203 .72442 L .40387 .72364 L p .707 .577 .707 r
F P
0 g
s
.40387 .72364 m .40387 .74217 L .37203 .74295 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002;Ool<
0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH2001[Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
001YOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol30005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Qoo`T004Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`l000AJEP03001JEUYF009JEPP003aoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03
001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF
001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolA0005Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009J
EPT000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF10000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH06P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH7000h
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPT000AJEP@00003
FUH0000000L003moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF60000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo2@00B7oo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool00`00FUH0
0004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF4P00A7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH000040003FUH2
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH300000eYF000000020003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP07FUH600000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P00=7oo000^Ool01000FUIJEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00FUH20005FUH00`00FUH000050002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80039oo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00@005YF001JEP80
0003FUH005YF00AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH0
05YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`00<7oo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo1@00
15YF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo6P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0000=J
EP00Ool01Woo1@0037oo1@0015YF00@005YFFUIJEP8002eoo`00FWoo0`0000=JEP00FUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD00003FUH005YF00=JEP03
001JEP0000Qoo`<0015oo`@00003FUH005YF009JEP8002eoo`00GGoo1@0015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH00UYF20002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP8000=JEPD000=JEP8001Ioo`L000=JEP<000=JEP8002eoo`00
HWoo200015YF1@0000=JEP0000001`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00@005YFFUIJEPT000Uoo`T0
00=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00?goo6@003Goo00D005YFFUH0
05YF00X000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04001JEUYF0005FUH40006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP800005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool300000eYF001JEP06FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006Ool30006
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH900000eYF001JEP02FUH60009
FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool40002
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP04001JEUYFFUH>0004FUH00`00FUIJ
EP02FUH8000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH00`00FUH0
000=OolI000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPH000Qoo`D000Aoo`P000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00002000G
Ool30019Ool002aoo`03001JEP0000AJEP03001JEP0000<000ioo`D000aoo`@000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00=JEP03001JEP00009JEPD0
05ioo`00;7oo00<005YF00000eYF1`003goo0`0037oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000EJEP03001JEP00
008005]oo`00;7oo00@005YF001JEP8000EJEP03001JEP0000<001Qoo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00005FUH0
0`00FUIJEP02FUH2001IOol002aoo`06001JEP00001JEP001EYF00<005YFFUH00eYF6@0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YFFUH00eYF0`00
Egoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP020004FUH01000FUIJEUYF200000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EPD0009JEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3
00000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF0P0000=JEP00FUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF0`002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EP000002FUH30006FUH01`00FUIJEUYF001oo`0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00QJEP<00003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000<000=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000jOol0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04
001JEP000003FUH00`00FUH000020003FUH01000FUH000000Woo00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YF00002UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0017oo1`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1000=Woo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH40006
FUH01000FUH000000eYF00<005YFFUH00UYF1@001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH0
25YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000Ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0039oo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF
00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH:0007FUH00`00FUIJEP07FUH50005FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000Ioo`800003
FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP80035oo`00>goo200015YF1@001EYF00@005YFFUIJEP800003FUH005YF00AJEP03
001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YF00002@000eYF00<005YFFUH00eYF00<005YFFUH00UYF4P00
15YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002moo`00@goo4`0000Aoo`00000000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP04001JEUYFFUH20004
FUH00`00FUIJEP02FUH8000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo0018Ool3
000?Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH01P00FUIJ
EP00FUH000AJEP03001JEP0000<000AJEP<001Qoo`D000AJEP05001JEUYFFUH0000^Ool005eoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001J
EUYF00YJEP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0`000eYF
00<005YFFUH00UYF0`007Goo0`0000=JEP00FUH00UYF0P00;Goo001POol40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80006FUH00`00FUIJEP0:FUH00`00FUIJEP060008FUH0
0`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000IJEP03001JEUYF009JEP03001JEP00021oo`80
00=JEP8002eoo`00I7oo6@0027oo5P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800003FUH005YF00EJEP03001JEUYF009JEP8002=oo`800003FUH0000002eoo`00T7oo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000AJ
EP00FUH000IJEP04001JEUYFFUH2000TOol5000]Ool0095oo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000IJEP04001JEP00000TOol20002FUH3
000]Ool0099oo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEP000080009JEP<0029oo`@000AJEP03001JEP0002eoo`00UGoo1@001UYF00<0
05YFFUH01UYF10001EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPD001]oo`L000=JEP03001J
EUYF009JEP8002ioo`00Agoo2@00BWoo10000UYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool003moo`P000AJEP03001JEUYF009JEPP004Iooa`000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6001;Ool5000;Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000<Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020019Ool3000>Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000`Ool200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001K
Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<005ioo`T000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00IGoo2@00B7oo000]
Ool20004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP000;Ioo`00;7oo00<005YF0000
15YF10009goo0`0000=JEP00FUH00UYF00<007ooOol0]7oo000/Ool00`00FUH00002FUH2000^Ool2
0003FUH00`00Oomoo`2dOol002aoo`03001JEP000080039oo`04001JEUYF002fOol002aoo`04001J
EP00000dOol3000iOolH001UOol002aoo`80009JEP<002moo`<00003FUH007oo039oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0065oo`00;7oo0P000eYF00<005YF00000P00
:Goo0`000UYF00<005YF0000<7oo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`00GWoo000/Ool20003FUH00`00FUIJEP02FUH5000POol400000eYF001JEP02
FUH00`00FUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF20004goo
1@001EYF00@005YFFUIJEP8002aoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8005Uoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00
Egoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000/Ool00`00FUH00004FUH00`00FUH0
0002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00FUH00003FUH3000XOol300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
03=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eooaT003Qoo`04001JEP00000bOol20000
0eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P000UYF0P00;goo0P0000AJEP00000005Ao
o`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJ
EQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
05Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001J
EUYF009JEPh0065oo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70431 m .59613 .64873 L .56496 .64683 L p .707 .577 .707 r
F P
0 g
s
.59613 .64873 m .59613 .70431 L .62796 .70353 L p .707 .577 .707 r
F P
0 g
s
.62796 .70353 m .62796 .64795 L .59613 .64873 L p .707 .577 .707 r
F P
0 g
s
.62796 .64795 m .62796 .70353 L .65734 .70015 L p .707 .577 .707 r
F P
0 g
s
.65734 .70015 m .65734 .64457 L .62796 .64795 L p .707 .577 .707 r
F P
0 g
s
.56496 .70241 m .56496 .64683 L .5375 .64243 L p .707 .577 .707 r
F P
0 g
s
.56496 .64683 m .56496 .70241 L .59613 .70431 L p .707 .577 .707 r
F P
0 g
s
.65734 .64457 m .65734 .70015 L .6814 .6945 L p .707 .577 .707 r
F P
0 g
s
.6814 .6945 m .6814 .63892 L .65734 .64457 L p .707 .577 .707 r
F P
0 g
s
.5375 .64243 m .5375 .69802 L .56496 .70241 L p .707 .577 .707 r
F P
0 g
s
.5375 .69802 m .5375 .64243 L .51644 .63598 L p .707 .577 .707 r
F P
0 g
s
.6814 .63892 m .6814 .6945 L .69777 .68714 L p .707 .577 .707 r
F P
0 g
s
.69777 .68714 m .69777 .63155 L .6814 .63892 L p .707 .577 .707 r
F P
0 g
s
.59613 .81846 m .59613 .78141 L .56496 .77951 L p .707 .577 .707 r
F P
0 g
s
.59613 .78141 m .59613 .81846 L .62796 .81769 L p .707 .577 .707 r
F P
0 g
s
.62796 .81769 m .62796 .78063 L .59613 .78141 L p .707 .577 .707 r
F P
0 g
s
.51644 .63598 m .51644 .69156 L .5375 .69802 L p .707 .577 .707 r
F P
0 g
s
.62796 .78063 m .62796 .81769 L .65735 .81431 L p .707 .577 .707 r
F P
0 g
s
.65735 .81431 m .65735 .77725 L .62796 .78063 L p .707 .577 .707 r
F P
0 g
s
.56496 .81656 m .56496 .77951 L .5375 .77512 L p .707 .577 .707 r
F P
0 g
s
.56496 .77951 m .56496 .81656 L .59613 .81846 L p .707 .577 .707 r
F P
0 g
s
.51644 .69156 m .51644 .63598 L .50385 .6281 L p .707 .577 .707 r
F P
0 g
s
.65735 .77725 m .65735 .81431 L .6814 .80866 L p .707 .577 .707 r
F P
0 g
s
.6814 .80866 m .6814 .7716 L .65735 .77725 L p .707 .577 .707 r
F P
0 g
s
.5375 .77512 m .5375 .81217 L .56496 .81656 L p .707 .577 .707 r
F P
0 g
s
.5375 .81217 m .5375 .77512 L .51644 .76866 L p .707 .577 .707 r
F P
0 g
s
.50385 .6281 m .50385 .68368 L .51644 .69156 L p .707 .577 .707 r
F P
0 g
s
.69777 .63155 m .69777 .68714 L .70485 .67877 L p .707 .577 .707 r
F P
0 g
s
.70485 .67877 m .70485 .62319 L .69777 .63155 L p .707 .577 .707 r
F P
0 g
s
.51644 .76866 m .51644 .80572 L .5375 .81217 L p .707 .577 .707 r
F P
0 g
s
.59613 .92573 m .59613 .90721 L .56496 .90531 L p .707 .577 .707 r
F P
0 g
s
.59613 .90721 m .59613 .92573 L .62796 .92496 L p .707 .577 .707 r
F P
0 g
s
.62796 .92496 m .62796 .90643 L .59613 .90721 L p .707 .577 .707 r
F P
0 g
s
.6814 .7716 m .6814 .80866 L .69777 .80129 L p .707 .577 .707 r
F P
0 g
s
.69777 .80129 m .69777 .76423 L .6814 .7716 L p .707 .577 .707 r
F P
0 g
s
.50385 .68368 m .50385 .6281 L .50095 .61955 L p .707 .577 .707 r
F P
0 g
s
.62796 .90643 m .62796 .92496 L .65735 .92158 L p .707 .577 .707 r
F P
0 g
s
.65735 .92158 m .65735 .90305 L .62796 .90643 L p .707 .577 .707 r
F P
0 g
s
.56496 .90531 m .56496 .92383 L .59613 .92573 L p .707 .577 .707 r
F P
0 g
s
.56496 .92383 m .56496 .90531 L .5375 .90091 L p .707 .577 .707 r
F P
0 g
s
.51644 .80572 m .51644 .76866 L .50385 .76078 L p .707 .577 .707 r
F P
0 g
s
.5375 .90091 m .5375 .91944 L .56496 .92383 L p .707 .577 .707 r
F P
0 g
s
.65735 .90305 m .65735 .92158 L .6814 .91593 L p .707 .577 .707 r
F P
0 g
s
.6814 .91593 m .6814 .8974 L .65735 .90305 L p .707 .577 .707 r
F P
0 g
s
.50095 .61955 m .50095 .67514 L .50385 .68368 L p .707 .577 .707 r
F P
0 g
s
.70485 .62319 m .70485 .67877 L .70195 .67023 L p .707 .577 .707 r
F P
0 g
s
.70195 .67023 m .70195 .61465 L .70485 .62319 L p .707 .577 .707 r
F P
0 g
s
.50385 .76078 m .50385 .79783 L .51644 .80572 L p .707 .577 .707 r
F P
0 g
s
.5375 .91944 m .5375 .90091 L .51644 .89446 L p .707 .577 .707 r
F P
0 g
s
.69777 .76423 m .69777 .80129 L .70485 .79292 L p .707 .577 .707 r
F P
0 g
s
.70485 .79292 m .70485 .75587 L .69777 .76423 L p .707 .577 .707 r
F P
0 g
s
.51644 .89446 m .51644 .91299 L .5375 .91944 L p .707 .577 .707 r
F P
0 g
s
.50095 .67514 m .50095 .61955 L .50804 .61119 L p .707 .577 .707 r
F P
0 g
s
.49044 .79627 m .49044 .29438 L .44643 .2917 L p .707 .577 .707 r
F P
0 g
s
.50385 .79783 m .50385 .76078 L .50095 .75223 L p .707 .577 .707 r
F P
0 g
s
.50804 .61119 m .50804 .66677 L .50095 .67514 L p .707 .577 .707 r
F P
0 g
s
.50095 .75223 m .50095 .78929 L .50385 .79783 L p .707 .577 .707 r
F P
0 g
s
.50804 .66677 m .50804 .61119 L .5244 .60382 L p .707 .577 .707 r
F P
0 g
s
.50095 .78929 m .50095 .75223 L .50804 .74387 L p .707 .577 .707 r
F P
0 g
s
.5244 .60382 m .5244 .6594 L .50804 .66677 L p .707 .577 .707 r
F P
0 g
s
.50804 .74387 m .50804 .78093 L .50095 .78929 L p .707 .577 .707 r
F P
0 g
s
.50804 .78093 m .50804 .74387 L .5244 .7365 L p .707 .577 .707 r
F P
0 g
s
.5244 .7365 m .5244 .77356 L .50804 .78093 L p .707 .577 .707 r
F P
0 g
s
.5244 .77356 m .5244 .7365 L .54846 .73085 L p .707 .577 .707 r
F P
0 g
s
.54846 .73085 m .54846 .76791 L .5244 .77356 L p .707 .577 .707 r
F P
0 g
s
.49044 .29438 m .49044 .79627 L .53538 .79517 L p .707 .577 .707 r
F P
0 g
s
.5244 .6594 m .5244 .60382 L .54846 .59817 L p .707 .577 .707 r
F P
0 g
s
.54846 .59817 m .54846 .65375 L .5244 .6594 L p .707 .577 .707 r
F P
0 g
s
.53538 .79517 m .53538 .29328 L .49044 .29438 L p .707 .577 .707 r
F P
0 g
s
.6814 .8974 m .6814 .91593 L .69777 .90856 L p .707 .577 .707 r
F P
0 g
s
.69777 .90856 m .69777 .89003 L .6814 .8974 L p .707 .577 .707 r
F P
0 g
s
.54846 .65375 m .54846 .59817 L .57784 .59479 L p .707 .577 .707 r
F P
0 g
s
.57784 .59479 m .57784 .65037 L .54846 .65375 L p .707 .577 .707 r
F P
0 g
s
.54846 .76791 m .54846 .73085 L .57784 .72747 L p .707 .577 .707 r
F P
0 g
s
.57784 .72747 m .57784 .76453 L .54846 .76791 L p .707 .577 .707 r
F P
0 g
s
.53538 .29328 m .53538 .79517 L .57686 .7904 L p .707 .577 .707 r
F P
0 g
s
.57686 .7904 m .57686 .28851 L .53538 .29328 L p .707 .577 .707 r
F P
0 g
s
.44643 .79358 m .44643 .2917 L .40766 .28549 L p .707 .577 .707 r
F P
0 g
s
.44643 .2917 m .44643 .79358 L .49044 .79627 L p .707 .577 .707 r
F P
0 g
s
.51644 .91299 m .51644 .89446 L .50385 .88658 L p .707 .577 .707 r
F P
0 g
s
.70195 .61465 m .70195 .67023 L .68936 .66234 L p .707 .577 .707 r
F P
0 g
s
.68936 .66234 m .68936 .60676 L .70195 .61465 L p .707 .577 .707 r
F P
0 g
s
.50385 .88658 m .50385 .9051 L .51644 .91299 L p .707 .577 .707 r
F P
0 g
s
.57784 .65037 m .57784 .59479 L .60968 .59402 L p .707 .577 .707 r
F P
0 g
s
.60968 .59402 m .60968 .6496 L .57784 .65037 L p .707 .577 .707 r
F P
0 g
s
.57784 .76453 m .57784 .72747 L .60968 .7267 L p .707 .577 .707 r
F P
0 g
s
.60968 .7267 m .60968 .76375 L .57784 .76453 L p .707 .577 .707 r
F P
0 g
s
.57686 .28851 m .57686 .7904 L .61082 .78242 L p .707 .577 .707 r
F P
0 g
s
.64085 .59592 m .64085 .6515 L .60968 .6496 L p .707 .577 .707 r
F P
0 g
s
.60968 .6496 m .60968 .59402 L .64085 .59592 L p .707 .577 .707 r
F P
0 g
s
.64085 .7286 m .64085 .76565 L .60968 .76375 L p .707 .577 .707 r
F P
0 g
s
.60968 .76375 m .60968 .7267 L .64085 .7286 L p .707 .577 .707 r
F P
0 g
s
.61082 .78242 m .61082 .28053 L .57686 .28851 L p .707 .577 .707 r
F P
0 g
s
.70485 .75587 m .70485 .79292 L .70195 .78438 L p .707 .577 .707 r
F P
0 g
s
.70195 .78438 m .70195 .74733 L .70485 .75587 L p .707 .577 .707 r
F P
0 g
s
.25312 .66749 m .25312 .61191 L .22195 .61001 L p .707 .577 .707 r
F P
0 g
s
.25312 .61191 m .25312 .66749 L .28495 .66672 L p .707 .577 .707 r
F P
0 g
s
.28495 .66672 m .28495 .61113 L .25312 .61191 L p .707 .577 .707 r
F P
0 g
s
.69777 .89003 m .69777 .90856 L .70485 .9002 L p .707 .577 .707 r
F P
0 g
s
.70485 .9002 m .70485 .88167 L .69777 .89003 L p .707 .577 .707 r
F P
0 g
s
.28495 .61113 m .28495 .66672 L .31434 .66334 L p .707 .577 .707 r
F P
0 g
s
.31434 .66334 m .31434 .60776 L .28495 .61113 L p .707 .577 .707 r
F P
0 g
s
.40766 .78738 m .40766 .28549 L .37794 .27638 L p .707 .577 .707 r
F P
0 g
s
.40766 .28549 m .40766 .78738 L .44643 .79358 L p .707 .577 .707 r
F P
0 g
s
.22195 .66559 m .22195 .61001 L .19449 .60562 L p .707 .577 .707 r
F P
0 g
s
.22195 .61001 m .22195 .66559 L .25312 .66749 L p .707 .577 .707 r
F P
0 g
s
.50385 .9051 m .50385 .88658 L .50095 .87803 L p .707 .577 .707 r
F P
0 g
s
.31434 .60776 m .31434 .66334 L .33839 .65769 L p .707 .577 .707 r
F P
0 g
s
.33839 .65769 m .33839 .60211 L .31434 .60776 L p .707 .577 .707 r
F P
0 g
s
.68936 .60676 m .68936 .66234 L .66831 .65589 L p .707 .577 .707 r
F P
0 g
s
.66831 .65589 m .66831 .60031 L .68936 .60676 L p .707 .577 .707 r
F P
0 g
s
.50095 .87803 m .50095 .89656 L .50385 .9051 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19449 .60562 m .19449 .6612 L .22195 .66559 L p .707 .577 .707 r
F P
0 g
s
.19449 .6612 m .19449 .60562 L .17343 .59916 L p .707 .577 .707 r
F P
0 g
s
.61082 .28053 m .61082 .78242 L .63393 .77202 L p .707 .577 .707 r
F P
0 g
s
.63393 .77202 m .63393 .27013 L .61082 .28053 L p .707 .577 .707 r
F P
0 g
s
.70195 .74733 m .70195 .78438 L .68936 .7765 L p .707 .577 .707 r
F P
0 g
s
.68936 .7765 m .68936 .73944 L .70195 .74733 L p .707 .577 .707 r
F P
0 g
s
.70485 .88167 m .70485 .9002 L .70195 .89165 L p .707 .577 .707 r
F P
0 g
s
.70195 .89165 m .70195 .87313 L .70485 .88167 L p .707 .577 .707 r
F P
0 g
s
.33839 .60211 m .33839 .65769 L .35476 .65032 L p .707 .577 .707 r
F P
0 g
s
.35476 .65032 m .35476 .59474 L .33839 .60211 L p .707 .577 .707 r
F P
0 g
s
.25312 .78165 m .25312 .74459 L .22195 .74269 L p .707 .577 .707 r
F P
0 g
s
.25312 .74459 m .25312 .78165 L .28495 .78087 L p .707 .577 .707 r
F P
0 g
s
.28495 .78087 m .28495 .74382 L .25312 .74459 L p .707 .577 .707 r
F P
0 g
s
.17343 .59916 m .17343 .65475 L .19449 .6612 L p .707 .577 .707 r
F P
0 g
s
.37794 .77827 m .37794 .27638 L .36016 .26525 L p .707 .577 .707 r
F P
0 g
s
.37794 .27638 m .37794 .77827 L .40766 .78738 L p .707 .577 .707 r
F P
0 g
s
.28495 .74382 m .28495 .78087 L .31434 .77749 L p .707 .577 .707 r
F P
0 g
s
.31434 .77749 m .31434 .74044 L .28495 .74382 L p .707 .577 .707 r
F P
0 g
s
.66831 .60031 m .66831 .65589 L .64085 .6515 L p .707 .577 .707 r
F P
0 g
s
.64085 .6515 m .64085 .59592 L .66831 .60031 L p .707 .577 .707 r
F P
0 g
s
.22195 .77975 m .22195 .74269 L .19449 .7383 L p .707 .577 .707 r
F P
0 g
s
.22195 .74269 m .22195 .77975 L .25312 .78165 L p .707 .577 .707 r
F P
0 g
s
.50095 .89656 m .50095 .87803 L .50804 .86967 L p .707 .577 .707 r
F P
0 g
s
.17343 .65475 m .17343 .59916 L .16084 .59128 L p .707 .577 .707 r
F P
0 g
s
.50804 .86967 m .50804 .8882 L .50095 .89656 L p .707 .577 .707 r
F P
0 g
s
.31434 .74044 m .31434 .77749 L .33839 .77184 L p .707 .577 .707 r
F P
0 g
s
.33839 .77184 m .33839 .73479 L .31434 .74044 L p .707 .577 .707 r
F P
0 g
s
.19449 .7383 m .19449 .77535 L .22195 .77975 L p .707 .577 .707 r
F P
0 g
s
.68936 .73944 m .68936 .7765 L .66831 .77004 L p .707 .577 .707 r
F P
0 g
s
.66831 .77004 m .66831 .73299 L .68936 .73944 L p .707 .577 .707 r
F P
0 g
s
.19449 .77535 m .19449 .7383 L .17343 .73185 L p .707 .577 .707 r
F P
0 g
s
.16084 .59128 m .16084 .64686 L .17343 .65475 L p .707 .577 .707 r
F P
0 g
s
.35476 .59474 m .35476 .65032 L .36184 .64196 L p .707 .577 .707 r
F P
0 g
s
.36184 .64196 m .36184 .58637 L .35476 .59474 L p .707 .577 .707 r
F P
0 g
s
.64085 .76565 m .64085 .7286 L .66831 .73299 L p .707 .577 .707 r
F P
0 g
s
.63393 .27013 m .63393 .77202 L .64393 .76021 L p .707 .577 .707 r
F P
0 g
s
.64393 .76021 m .64393 .25832 L .63393 .27013 L p .707 .577 .707 r
F P
0 g
s
.70195 .87313 m .70195 .89165 L .68936 .88377 L p .707 .577 .707 r
F P
0 g
s
.68936 .88377 m .68936 .86524 L .70195 .87313 L p .707 .577 .707 r
F P
0 g
s
.17343 .73185 m .17343 .7689 L .19449 .77535 L p .707 .577 .707 r
F P
0 g
s
.25312 .88892 m .25312 .87039 L .22195 .86849 L p .707 .577 .707 r
F P
0 g
s
.25312 .87039 m .25312 .88892 L .28495 .88814 L p .707 .577 .707 r
F P
0 g
s
.28495 .88814 m .28495 .86961 L .25312 .87039 L p .707 .577 .707 r
F P
0 g
s
.33839 .73479 m .33839 .77184 L .35476 .76447 L p .707 .577 .707 r
F P
0 g
s
.35476 .76447 m .35476 .72742 L .33839 .73479 L p .707 .577 .707 r
F P
0 g
s
.16084 .64686 m .16084 .59128 L .15794 .58274 L p .707 .577 .707 r
F P
0 g
s
.50804 .8882 m .50804 .86967 L .5244 .8623 L p .707 .577 .707 r
F P
0 g
s
.28495 .86961 m .28495 .88814 L .31434 .88476 L p .707 .577 .707 r
F P
0 g
s
.31434 .88476 m .31434 .86624 L .28495 .86961 L p .707 .577 .707 r
F P
0 g
s
.22195 .86849 m .22195 .88702 L .25312 .88892 L p .707 .577 .707 r
F P
0 g
s
.66831 .73299 m .66831 .77004 L .64085 .76565 L p .707 .577 .707 r
F P
0 g
s
.22195 .88702 m .22195 .86849 L .19449 .8641 L p .707 .577 .707 r
F P
0 g
s
.36184 .58637 m .36184 .64196 L .35894 .63341 L p .707 .577 .707 r
F P
0 g
s
.35894 .63341 m .35894 .57783 L .36184 .58637 L p .707 .577 .707 r
F P
0 g
s
.35476 .72742 m .35476 .76447 L .36184 .75611 L p .707 .577 .707 r
F P
0 g
s
.36184 .75611 m .36184 .71905 L .35476 .72742 L p .707 .577 .707 r
F P
0 g
s
.35894 .57783 m .35894 .63341 L .34635 .62553 L p .707 .577 .707 r
F P
0 g
s
.34635 .62553 m .34635 .56995 L .35894 .57783 L p .707 .577 .707 r
F P
0 g
s
.36184 .71905 m .36184 .75611 L .35894 .74757 L p .707 .577 .707 r
F P
0 g
s
.35894 .74757 m .35894 .71051 L .36184 .71905 L p .707 .577 .707 r
F P
0 g
s
.36016 .76714 m .36016 .26525 L .35607 .25319 L p .707 .577 .707 r
F P
0 g
s
.36016 .26525 m .36016 .76714 L .37794 .77827 L p .707 .577 .707 r
F P
0 g
s
.5244 .8623 m .5244 .88083 L .50804 .8882 L p .707 .577 .707 r
F P
0 g
s
.17343 .7689 m .17343 .73185 L .16084 .72396 L p .707 .577 .707 r
F P
0 g
s
.19449 .8641 m .19449 .88263 L .22195 .88702 L p .707 .577 .707 r
F P
0 g
s
.31434 .86624 m .31434 .88476 L .33839 .87911 L p .707 .577 .707 r
F P
0 g
s
.33839 .87911 m .33839 .86059 L .31434 .86624 L p .707 .577 .707 r
F P
0 g
s
.15794 .58274 m .15794 .63832 L .16084 .64686 L p .707 .577 .707 r
F P
0 g
s
.68936 .86524 m .68936 .88377 L .66831 .87732 L p .707 .577 .707 r
F P
0 g
s
.66831 .87732 m .66831 .85879 L .68936 .86524 L p .707 .577 .707 r
F P
0 g
s
.16084 .72396 m .16084 .76102 L .17343 .7689 L p .707 .577 .707 r
F P
0 g
s
.19449 .88263 m .19449 .8641 L .17343 .85764 L p .707 .577 .707 r
F P
0 g
s
.17343 .85764 m .17343 .87617 L .19449 .88263 L p .707 .577 .707 r
F P
0 g
s
.5244 .88083 m .5244 .8623 L .54846 .85665 L p .707 .577 .707 r
F P
0 g
s
.64393 .25832 m .64393 .76021 L .63984 .74815 L p .707 .577 .707 r
F P
0 g
s
.63984 .74815 m .63984 .24626 L .64393 .25832 L p .707 .577 .707 r
F P
0 g
s
.15794 .63832 m .15794 .58274 L .16503 .57437 L p .707 .577 .707 r
F P
0 g
s
.54846 .85665 m .54846 .87518 L .5244 .88083 L p .707 .577 .707 r
F P
0 g
s
.33839 .86059 m .33839 .87911 L .35476 .87175 L p .707 .577 .707 r
F P
0 g
s
.35476 .87175 m .35476 .85322 L .33839 .86059 L p .707 .577 .707 r
F P
0 g
s
.16084 .76102 m .16084 .72396 L .15794 .71542 L p .707 .577 .707 r
F P
0 g
s
.66831 .85879 m .66831 .87732 L .64085 .87292 L p .707 .577 .707 r
F P
0 g
s
.64085 .87292 m .64085 .8544 L .66831 .85879 L p .707 .577 .707 r
F P
0 g
s
.17343 .87617 m .17343 .85764 L .16084 .84976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57437 m .16503 .62996 L .15794 .63832 L p .707 .577 .707 r
F P
0 g
s
.54846 .87518 m .54846 .85665 L .57784 .85327 L p .707 .577 .707 r
F P
0 g
s
.15794 .71542 m .15794 .75247 L .16084 .76102 L p .707 .577 .707 r
F P
0 g
s
.35894 .71051 m .35894 .74757 L .34635 .73968 L p .707 .577 .707 r
F P
0 g
s
.34635 .73968 m .34635 .70263 L .35894 .71051 L p .707 .577 .707 r
F P
0 g
s
.35607 .25319 m .35607 .75508 L .36016 .76714 L p .707 .577 .707 r
F P
0 g
s
.35607 .75508 m .35607 .25319 L .36607 .24138 L p .707 .577 .707 r
F P
0 g
s
.16084 .84976 m .16084 .86829 L .17343 .87617 L p .707 .577 .707 r
F P
0 g
s
.57784 .85327 m .57784 .8718 L .54846 .87518 L p .707 .577 .707 r
F P
0 g
s
.64085 .8544 m .64085 .87292 L .60968 .87102 L p .707 .577 .707 r
F P
0 g
s
.60968 .87102 m .60968 .8525 L .64085 .8544 L p .707 .577 .707 r
F P
0 g
s
.57784 .8718 m .57784 .85327 L .60968 .8525 L p .707 .577 .707 r
F P
0 g
s
.35476 .85322 m .35476 .87175 L .36184 .86338 L p .707 .577 .707 r
F P
0 g
s
.36184 .86338 m .36184 .84485 L .35476 .85322 L p .707 .577 .707 r
F P
0 g
s
.16503 .62996 m .16503 .57437 L .1814 .56701 L p .707 .577 .707 r
F P
0 g
s
.60968 .8525 m .60968 .87102 L .57784 .8718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .75247 m .15794 .71542 L .16503 .70706 L p .707 .577 .707 r
F P
0 g
s
.16084 .86829 m .16084 .84976 L .15794 .84122 L p .707 .577 .707 r
F P
0 g
s
.63984 .24626 m .63984 .74815 L .62206 .73702 L p .707 .577 .707 r
F P
0 g
s
.62206 .73702 m .62206 .23513 L .63984 .24626 L p .707 .577 .707 r
F P
0 g
s
.1814 .56701 m .1814 .62259 L .16503 .62996 L p .707 .577 .707 r
F P
0 g
s
.34635 .56995 m .34635 .62553 L .3253 .61908 L p .707 .577 .707 r
F P
0 g
s
.3253 .61908 m .3253 .56349 L .34635 .56995 L p .707 .577 .707 r
F P
0 g
s
.15794 .84122 m .15794 .85975 L .16084 .86829 L p .707 .577 .707 r
F P
0 g
s
.16503 .70706 m .16503 .74411 L .15794 .75247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .62259 m .1814 .56701 L .20545 .56136 L p .707 .577 .707 r
F P
0 g
s
.36184 .84485 m .36184 .86338 L .35894 .85484 L p .707 .577 .707 r
F P
0 g
s
.35894 .85484 m .35894 .83631 L .36184 .84485 L p .707 .577 .707 r
F P
0 g
s
.36607 .74327 m .36607 .24138 L .38918 .23098 L p .707 .577 .707 r
F P
0 g
s
.36607 .24138 m .36607 .74327 L .35607 .75508 L p .707 .577 .707 r
F P
0 g
s
.16503 .74411 m .16503 .70706 L .1814 .69969 L p .707 .577 .707 r
F P
0 g
s
.3253 .56349 m .3253 .61908 L .29784 .61468 L p .707 .577 .707 r
F P
0 g
s
.29784 .61468 m .29784 .5591 L .3253 .56349 L p .707 .577 .707 r
F P
0 g
s
.20545 .56136 m .20545 .61694 L .1814 .62259 L p .707 .577 .707 r
F P
0 g
s
.15794 .85975 m .15794 .84122 L .16503 .83285 L p .707 .577 .707 r
F P
0 g
s
.20545 .61694 m .20545 .56136 L .23483 .55798 L p .707 .577 .707 r
F P
0 g
s
.16503 .83285 m .16503 .85138 L .15794 .85975 L p .707 .577 .707 r
F P
0 g
s
.1814 .69969 m .1814 .73674 L .16503 .74411 L p .707 .577 .707 r
F P
0 g
s
.62206 .23513 m .62206 .73702 L .59233 .72791 L p .707 .577 .707 r
F P
0 g
s
.59233 .72791 m .59233 .22602 L .62206 .23513 L p .707 .577 .707 r
F P
0 g
s
.34635 .70263 m .34635 .73968 L .3253 .73323 L p .707 .577 .707 r
F P
0 g
s
.3253 .73323 m .3253 .69617 L .34635 .70263 L p .707 .577 .707 r
F P
0 g
s
.29784 .5591 m .29784 .61468 L .26667 .61278 L p .707 .577 .707 r
F P
0 g
s
.26667 .61278 m .26667 .5572 L .29784 .5591 L p .707 .577 .707 r
F P
0 g
s
.23483 .61356 m .23483 .55798 L .26667 .5572 L p .707 .577 .707 r
F P
0 g
s
.23483 .55798 m .23483 .61356 L .20545 .61694 L p .707 .577 .707 r
F P
0 g
s
.35894 .83631 m .35894 .85484 L .34635 .84695 L p .707 .577 .707 r
F P
0 g
s
.34635 .84695 m .34635 .82843 L .35894 .83631 L p .707 .577 .707 r
F P
0 g
s
.26667 .5572 m .26667 .61278 L .23483 .61356 L p .707 .577 .707 r
F P
0 g
s
.1814 .73674 m .1814 .69969 L .20545 .69404 L p .707 .577 .707 r
F P
0 g
s
.73333 .61227 m .73333 .55669 L .70216 .55479 L p .707 .577 .707 r
F P
0 g
s
.73333 .55669 m .73333 .61227 L .76517 .61149 L p .707 .577 .707 r
F P
0 g
s
.76517 .61149 m .76517 .55591 L .73333 .55669 L p .707 .577 .707 r
F P
0 g
s
.76517 .55591 m .76517 .61149 L .79455 .60811 L p .707 .577 .707 r
F P
0 g
s
.79455 .60811 m .79455 .55253 L .76517 .55591 L p .707 .577 .707 r
F P
0 g
s
.38918 .23098 m .38918 .73287 L .36607 .74327 L p .707 .577 .707 r
F P
0 g
s
.38918 .73287 m .38918 .23098 L .42314 .22301 L p .707 .577 .707 r
F P
0 g
s
.70216 .61037 m .70216 .55479 L .6747 .5504 L p .707 .577 .707 r
F P
0 g
s
.70216 .55479 m .70216 .61037 L .73333 .61227 L p .707 .577 .707 r
F P
0 g
s
.16503 .85138 m .16503 .83285 L .1814 .82549 L p .707 .577 .707 r
F P
0 g
s
.20545 .69404 m .20545 .73109 L .1814 .73674 L p .707 .577 .707 r
F P
0 g
s
.3253 .69617 m .3253 .73323 L .29784 .72884 L p .707 .577 .707 r
F P
0 g
s
.29784 .72884 m .29784 .69178 L .3253 .69617 L p .707 .577 .707 r
F P
0 g
s
.1814 .82549 m .1814 .84401 L .16503 .85138 L p .707 .577 .707 r
F P
0 g
s
.79455 .55253 m .79455 .60811 L .8186 .60246 L p .707 .577 .707 r
F P
0 g
s
.8186 .60246 m .8186 .54688 L .79455 .55253 L p .707 .577 .707 r
F P
0 g
s
.20545 .73109 m .20545 .69404 L .23483 .69066 L p .707 .577 .707 r
F P
0 g
s
.59233 .22602 m .59233 .72791 L .55357 .72171 L p .707 .577 .707 r
F P
0 g
s
.55357 .72171 m .55357 .21982 L .59233 .22602 L p .707 .577 .707 r
F P
0 g
s
.6747 .5504 m .6747 .60598 L .70216 .61037 L p .707 .577 .707 r
F P
0 g
s
.6747 .60598 m .6747 .5504 L .65365 .54394 L p .707 .577 .707 r
F P
0 g
s
.34635 .82843 m .34635 .84695 L .3253 .8405 L p .707 .577 .707 r
F P
0 g
s
.3253 .8405 m .3253 .82197 L .34635 .82843 L p .707 .577 .707 r
F P
0 g
s
.29784 .69178 m .29784 .72884 L .26667 .72694 L p .707 .577 .707 r
F P
0 g
s
.26667 .72694 m .26667 .68988 L .29784 .69178 L p .707 .577 .707 r
F P
0 g
s
.23483 .69066 m .23483 .72771 L .20545 .73109 L p .707 .577 .707 r
F P
0 g
s
.23483 .72771 m .23483 .69066 L .26667 .68988 L p .707 .577 .707 r
F P
0 g
s
.42314 .72489 m .42314 .22301 L .46462 .21824 L p .707 .577 .707 r
F P
0 g
s
.42314 .22301 m .42314 .72489 L .38918 .73287 L p .707 .577 .707 r
F P
0 g
s
.1814 .84401 m .1814 .82549 L .20545 .81984 L p .707 .577 .707 r
F P
0 g
s
.26667 .68988 m .26667 .72694 L .23483 .72771 L p .707 .577 .707 r
F P
0 g
s
.8186 .54688 m .8186 .60246 L .83497 .5951 L p .707 .577 .707 r
F P
0 g
s
.83497 .5951 m .83497 .53951 L .8186 .54688 L p .707 .577 .707 r
F P
0 g
s
.73333 .72642 m .73333 .68937 L .70216 .68747 L p .707 .577 .707 r
F P
0 g
s
.73333 .68937 m .73333 .72642 L .76517 .72565 L p .707 .577 .707 r
F P
0 g
s
.76517 .72565 m .76517 .68859 L .73333 .68937 L p .707 .577 .707 r
F P
0 g
s
.65365 .54394 m .65365 .59952 L .6747 .60598 L p .707 .577 .707 r
F P
0 g
s
.76517 .68859 m .76517 .72565 L .79455 .72227 L p .707 .577 .707 r
F P
0 g
s
.79455 .72227 m .79455 .68521 L .76517 .68859 L p .707 .577 .707 r
F P
0 g
s
.20545 .81984 m .20545 .83836 L .1814 .84401 L p .707 .577 .707 r
F P
0 g
s
.70216 .72452 m .70216 .68747 L .6747 .68308 L p .707 .577 .707 r
F P
0 g
s
.70216 .68747 m .70216 .72452 L .73333 .72642 L p .707 .577 .707 r
F P
0 g
s
.55357 .21982 m .55357 .72171 L .50956 .71903 L p .707 .577 .707 r
F P
0 g
s
.50956 .71903 m .50956 .21714 L .55357 .21982 L p .707 .577 .707 r
F P
0 g
s
.65365 .59952 m .65365 .54394 L .64105 .53606 L p .707 .577 .707 r
F P
0 g
s
.3253 .82197 m .3253 .8405 L .29784 .83611 L p .707 .577 .707 r
F P
0 g
s
.29784 .83611 m .29784 .81758 L .3253 .82197 L p .707 .577 .707 r
F P
0 g
s
.46462 .72012 m .46462 .21824 L .50956 .21714 L p .707 .577 .707 r
F P
0 g
s
.46462 .21824 m .46462 .72012 L .42314 .72489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68521 m .79455 .72227 L .8186 .71662 L p .707 .577 .707 r
F P
0 g
s
.8186 .71662 m .8186 .67956 L .79455 .68521 L p .707 .577 .707 r
F P
0 g
s
.50956 .21714 m .50956 .71903 L .46462 .72012 L p .707 .577 .707 r
F P
0 g
s
.6747 .68308 m .6747 .72013 L .70216 .72452 L p .707 .577 .707 r
F P
0 g
s
.20545 .83836 m .20545 .81984 L .23483 .81646 L p .707 .577 .707 r
F P
0 g
s
.6747 .72013 m .6747 .68308 L .65365 .67662 L p .707 .577 .707 r
F P
0 g
s
.23483 .81646 m .23483 .83499 L .20545 .83836 L p .707 .577 .707 r
F P
0 g
s
.64105 .53606 m .64105 .59164 L .65365 .59952 L p .707 .577 .707 r
F P
0 g
s
.83497 .53951 m .83497 .5951 L .84205 .58673 L p .707 .577 .707 r
F P
0 g
s
.84205 .58673 m .84205 .53115 L .83497 .53951 L p .707 .577 .707 r
F P
0 g
s
.29784 .81758 m .29784 .83611 L .26667 .83421 L p .707 .577 .707 r
F P
0 g
s
.26667 .83421 m .26667 .81568 L .29784 .81758 L p .707 .577 .707 r
F P
0 g
s
.23483 .83499 m .23483 .81646 L .26667 .81568 L p .707 .577 .707 r
F P
0 g
s
.65365 .67662 m .65365 .71368 L .6747 .72013 L p .707 .577 .707 r
F P
0 g
s
.26667 .81568 m .26667 .83421 L .23483 .83499 L p .707 .577 .707 r
F P
0 g
s
.73333 .8337 m .73333 .81517 L .70216 .81327 L p .707 .577 .707 r
F P
0 g
s
.73333 .81517 m .73333 .8337 L .76517 .83292 L p .707 .577 .707 r
F P
0 g
s
.76517 .83292 m .76517 .81439 L .73333 .81517 L p .707 .577 .707 r
F P
0 g
s
.8186 .67956 m .8186 .71662 L .83497 .70925 L p .707 .577 .707 r
F P
0 g
s
.83497 .70925 m .83497 .6722 L .8186 .67956 L p .707 .577 .707 r
F P
0 g
s
.64105 .59164 m .64105 .53606 L .63816 .52751 L p .707 .577 .707 r
F P
0 g
s
.76517 .81439 m .76517 .83292 L .79455 .82954 L p .707 .577 .707 r
F P
0 g
s
.79455 .82954 m .79455 .81101 L .76517 .81439 L p .707 .577 .707 r
F P
0 g
s
.70216 .81327 m .70216 .8318 L .73333 .8337 L p .707 .577 .707 r
F P
0 g
s
.70216 .8318 m .70216 .81327 L .6747 .80888 L p .707 .577 .707 r
F P
0 g
s
.65365 .71368 m .65365 .67662 L .64105 .66874 L p .707 .577 .707 r
F P
0 g
s
.6747 .80888 m .6747 .8274 L .70216 .8318 L p .707 .577 .707 r
F P
0 g
s
.79455 .81101 m .79455 .82954 L .8186 .82389 L p .707 .577 .707 r
F P
0 g
s
.8186 .82389 m .8186 .80536 L .79455 .81101 L p .707 .577 .707 r
F P
0 g
s
.63816 .52751 m .63816 .5831 L .64105 .59164 L p .707 .577 .707 r
F P
0 g
s
.84205 .53115 m .84205 .58673 L .83916 .57819 L p .707 .577 .707 r
F P
0 g
s
.83916 .57819 m .83916 .52261 L .84205 .53115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66874 m .64105 .70579 L .65365 .71368 L p .707 .577 .707 r
F P
0 g
s
.6747 .8274 m .6747 .80888 L .65365 .80242 L p .707 .577 .707 r
F P
0 g
s
.83497 .6722 m .83497 .70925 L .84206 .70089 L p .707 .577 .707 r
F P
0 g
s
.84206 .70089 m .84205 .66383 L .83497 .6722 L p .707 .577 .707 r
F P
0 g
s
.65365 .80242 m .65365 .82095 L .6747 .8274 L p .707 .577 .707 r
F P
0 g
s
.63816 .5831 m .63816 .52751 L .64524 .51915 L p .707 .577 .707 r
F P
0 g
s
.8186 .80536 m .8186 .82389 L .83497 .81652 L p .707 .577 .707 r
F P
0 g
s
.83497 .81652 m .83497 .798 L .8186 .80536 L p .707 .577 .707 r
F P
0 g
s
.64105 .70579 m .64105 .66874 L .63816 .6602 L p .707 .577 .707 r
F P
0 g
s
.65365 .82095 m .65365 .80242 L .64105 .79454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .51915 m .64524 .57473 L .63816 .5831 L p .707 .577 .707 r
F P
0 g
s
.63816 .6602 m .63816 .69725 L .64105 .70579 L p .707 .577 .707 r
F P
0 g
s
.83916 .52261 m .83916 .57819 L .82657 .57031 L p .707 .577 .707 r
F P
0 g
s
.82657 .57031 m .82657 .51472 L .83916 .52261 L p .707 .577 .707 r
F P
0 g
s
.64105 .79454 m .64105 .81307 L .65365 .82095 L p .707 .577 .707 r
F P
0 g
s
.84205 .66383 m .84206 .70089 L .83916 .69234 L p .707 .577 .707 r
F P
0 g
s
.83916 .69234 m .83916 .65529 L .84205 .66383 L p .707 .577 .707 r
F P
0 g
s
.39032 .57545 m .39032 .51987 L .35915 .51797 L p .707 .577 .707 r
F P
0 g
s
.39032 .51987 m .39032 .57545 L .42216 .57468 L p .707 .577 .707 r
F P
0 g
s
.42216 .57468 m .42216 .5191 L .39032 .51987 L p .707 .577 .707 r
F P
0 g
s
.83497 .798 m .83497 .81652 L .84206 .80816 L p .707 .577 .707 r
F P
0 g
s
.84206 .80816 m .84206 .78963 L .83497 .798 L p .707 .577 .707 r
F P
0 g
s
.64524 .57473 m .64524 .51915 L .66161 .51178 L p .707 .577 .707 r
F P
0 g
s
.42216 .5191 m .42216 .57468 L .45154 .5713 L p .707 .577 .707 r
F P
0 g
s
.45154 .5713 m .45154 .51572 L .42216 .5191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.35915 .57355 m .35915 .51797 L .33169 .51358 L p .707 .577 .707 r
F P
0 g
s
.35915 .51797 m .35915 .57355 L .39032 .57545 L p .707 .577 .707 r
F P
0 g
s
.63816 .69725 m .63816 .6602 L .64524 .65183 L p .707 .577 .707 r
F P
0 g
s
.64105 .81307 m .64105 .79454 L .63816 .786 L p .707 .577 .707 r
F P
0 g
s
.45154 .51572 m .45154 .5713 L .47559 .56565 L p .707 .577 .707 r
F P
0 g
s
.47559 .56565 m .47559 .51007 L .45154 .51572 L p .707 .577 .707 r
F P
0 g
s
.66161 .51178 m .66161 .56736 L .64524 .57473 L p .707 .577 .707 r
F P
0 g
s
.82657 .51472 m .82657 .57031 L .80551 .56385 L p .707 .577 .707 r
F P
0 g
s
.80551 .56385 m .80551 .50827 L .82657 .51472 L p .707 .577 .707 r
F P
0 g
s
.63816 .786 m .63816 .80452 L .64105 .81307 L p .707 .577 .707 r
F P
0 g
s
.64524 .65183 m .64524 .68889 L .63816 .69725 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.33169 .51358 m .33169 .56916 L .35915 .57355 L p .707 .577 .707 r
F P
0 g
s
.33169 .56916 m .33169 .51358 L .31064 .50713 L p .707 .577 .707 r
F P
0 g
s
.83916 .65529 m .83916 .69234 L .82657 .68446 L p .707 .577 .707 r
F P
0 g
s
.82657 .68446 m .82657 .64741 L .83916 .65529 L p .707 .577 .707 r
F P
0 g
s
.66161 .56736 m .66161 .51178 L .68566 .50613 L p .707 .577 .707 r
F P
0 g
s
.84206 .78963 m .84206 .80816 L .83916 .79962 L p .707 .577 .707 r
F P
0 g
s
.83916 .79962 m .83916 .78109 L .84206 .78963 L p .707 .577 .707 r
F P
0 g
s
.47559 .51007 m .47559 .56565 L .49196 .55828 L p .707 .577 .707 r
F P
0 g
s
.49196 .55828 m .49196 .5027 L .47559 .51007 L p .707 .577 .707 r
F P
0 g
s
.39032 .68961 m .39032 .65255 L .35915 .65065 L p .707 .577 .707 r
F P
0 g
s
.39032 .65255 m .39032 .68961 L .42216 .68883 L p .707 .577 .707 r
F P
0 g
s
.42216 .68883 m .42216 .65178 L .39032 .65255 L p .707 .577 .707 r
F P
0 g
s
.31064 .50713 m .31064 .56271 L .33169 .56916 L p .707 .577 .707 r
F P
0 g
s
.64524 .68889 m .64524 .65183 L .66161 .64446 L p .707 .577 .707 r
F P
0 g
s
.42216 .65178 m .42216 .68883 L .45154 .68545 L p .707 .577 .707 r
F P
0 g
s
.45154 .68545 m .45154 .6484 L .42216 .65178 L p .707 .577 .707 r
F P
0 g
s
.80551 .50827 m .80551 .56385 L .77805 .55946 L p .707 .577 .707 r
F P
0 g
s
.77805 .55946 m .77805 .50388 L .80551 .50827 L p .707 .577 .707 r
F P
0 g
s
.35915 .68771 m .35915 .65065 L .33169 .64626 L p .707 .577 .707 r
F P
0 g
s
.35915 .65065 m .35915 .68771 L .39032 .68961 L p .707 .577 .707 r
F P
0 g
s
.68566 .50613 m .68566 .56172 L .66161 .56736 L p .707 .577 .707 r
F P
0 g
s
.63816 .80452 m .63816 .786 L .64524 .77763 L p .707 .577 .707 r
F P
0 g
s
.31064 .56271 m .31064 .50713 L .29804 .49924 L p .707 .577 .707 r
F P
0 g
s
.68566 .56172 m .68566 .50613 L .71504 .50275 L p .707 .577 .707 r
F P
0 g
s
.64524 .77763 m .64524 .79616 L .63816 .80452 L p .707 .577 .707 r
F P
0 g
s
.66161 .64446 m .66161 .68152 L .64524 .68889 L p .707 .577 .707 r
F P
0 g
s
.45154 .6484 m .45154 .68545 L .47559 .6798 L p .707 .577 .707 r
F P
0 g
s
.47559 .6798 m .47559 .64275 L .45154 .6484 L p .707 .577 .707 r
F P
0 g
s
.33169 .64626 m .33169 .68332 L .35915 .68771 L p .707 .577 .707 r
F P
0 g
s
.82657 .64741 m .82657 .68446 L .80551 .67801 L p .707 .577 .707 r
F P
0 g
s
.80551 .67801 m .80551 .64095 L .82657 .64741 L p .707 .577 .707 r
F P
0 g
s
.77805 .50388 m .77805 .55946 L .74688 .55756 L p .707 .577 .707 r
F P
0 g
s
.74688 .55756 m .74688 .50198 L .77805 .50388 L p .707 .577 .707 r
F P
0 g
s
.33169 .68332 m .33169 .64626 L .31064 .63981 L p .707 .577 .707 r
F P
0 g
s
.29804 .49924 m .29804 .55482 L .31064 .56271 L p .707 .577 .707 r
F P
0 g
s
.71504 .55834 m .71504 .50275 L .74688 .50198 L p .707 .577 .707 r
F P
0 g
s
.71504 .50275 m .71504 .55834 L .68566 .56172 L p .707 .577 .707 r
F P
0 g
s
.49196 .5027 m .49196 .55828 L .49904 .54992 L p .707 .577 .707 r
F P
0 g
s
.49904 .54992 m .49904 .49433 L .49196 .5027 L p .707 .577 .707 r
F P
0 g
s
.83916 .78109 m .83916 .79962 L .82657 .79173 L p .707 .577 .707 r
F P
0 g
s
.82657 .79173 m .82657 .7732 L .83916 .78109 L p .707 .577 .707 r
F P
0 g
s
.74688 .50198 m .74688 .55756 L .71504 .55834 L p .707 .577 .707 r
F P
0 g
s
.66161 .68152 m .66161 .64446 L .68566 .63881 L p .707 .577 .707 r
F P
0 g
s
.31064 .63981 m .31064 .67686 L .33169 .68332 L p .707 .577 .707 r
F P
0 g
s
.39032 .79688 m .39032 .77835 L .35915 .77645 L p .707 .577 .707 r
F P
0 g
s
.39032 .77835 m .39032 .79688 L .42216 .7961 L p .707 .577 .707 r
F P
0 g
s
.42216 .7961 m .42216 .77758 L .39032 .77835 L p .707 .577 .707 r
F P
0 g
s
.47559 .64275 m .47559 .6798 L .49196 .67244 L p .707 .577 .707 r
F P
0 g
s
.49196 .67244 m .49196 .63538 L .47559 .64275 L p .707 .577 .707 r
F P
0 g
s
.29804 .55482 m .29804 .49924 L .29515 .4907 L p .707 .577 .707 r
F P
0 g
s
.64524 .79616 m .64524 .77763 L .66161 .77026 L p .707 .577 .707 r
F P
0 g
s
.42216 .77758 m .42216 .7961 L .45154 .79272 L p .707 .577 .707 r
F P
0 g
s
.45154 .79272 m .45154 .7742 L .42216 .77758 L p .707 .577 .707 r
F P
0 g
s
.68566 .63881 m .68566 .67587 L .66161 .68152 L p .707 .577 .707 r
F P
0 g
s
.35915 .77645 m .35915 .79498 L .39032 .79688 L p .707 .577 .707 r
F P
0 g
s
.80551 .64095 m .80551 .67801 L .77805 .67361 L p .707 .577 .707 r
F P
0 g
s
.77805 .67361 m .77805 .63656 L .80551 .64095 L p .707 .577 .707 r
F P
0 g
s
.35915 .79498 m .35915 .77645 L .33169 .77206 L p .707 .577 .707 r
F P
0 g
s
.66161 .77026 m .66161 .78879 L .64524 .79616 L p .707 .577 .707 r
F P
0 g
s
.31064 .67686 m .31064 .63981 L .29804 .63192 L p .707 .577 .707 r
F P
0 g
s
.33169 .77206 m .33169 .79059 L .35915 .79498 L p .707 .577 .707 r
F P
0 g
s
.68566 .67587 m .68566 .63881 L .71504 .63544 L p .707 .577 .707 r
F P
0 g
s
.45154 .7742 m .45154 .79272 L .47559 .78707 L p .707 .577 .707 r
F P
0 g
s
.47559 .78707 m .47559 .76855 L .45154 .7742 L p .707 .577 .707 r
F P
0 g
s
.29515 .4907 m .29515 .54628 L .29804 .55482 L p .707 .577 .707 r
F P
0 g
s
.82657 .7732 m .82657 .79173 L .80551 .78528 L p .707 .577 .707 r
F P
0 g
s
.80551 .78528 m .80551 .76675 L .82657 .7732 L p .707 .577 .707 r
F P
0 g
s
.49904 .49433 m .49904 .54992 L .49615 .54137 L p .707 .577 .707 r
F P
0 g
s
.49615 .54137 m .49615 .48579 L .49904 .49433 L p .707 .577 .707 r
F P
0 g
s
.29804 .63192 m .29804 .66898 L .31064 .67686 L p .707 .577 .707 r
F P
0 g
s
.77805 .63656 m .77805 .67361 L .74688 .67171 L p .707 .577 .707 r
F P
0 g
s
.74688 .67171 m .74688 .63466 L .77805 .63656 L p .707 .577 .707 r
F P
0 g
s
.33169 .79059 m .33169 .77206 L .31064 .76561 L p .707 .577 .707 r
F P
0 g
s
.71504 .63544 m .71504 .67249 L .68566 .67587 L p .707 .577 .707 r
F P
0 g
s
.71504 .67249 m .71504 .63544 L .74688 .63466 L p .707 .577 .707 r
F P
0 g
s
.49196 .63538 m .49196 .67244 L .49904 .66407 L p .707 .577 .707 r
F P
0 g
s
.49904 .66407 m .49904 .62702 L .49196 .63538 L p .707 .577 .707 r
F P
0 g
s
.31064 .76561 m .31064 .78413 L .33169 .79059 L p .707 .577 .707 r
F P
0 g
s
.66161 .78879 m .66161 .77026 L .68566 .76461 L p .707 .577 .707 r
F P
0 g
s
.74688 .63466 m .74688 .67171 L .71504 .67249 L p .707 .577 .707 r
F P
0 g
s
.29515 .54628 m .29515 .4907 L .30223 .48233 L p .707 .577 .707 r
F P
0 g
s
.68566 .76461 m .68566 .78314 L .66161 .78879 L p .707 .577 .707 r
F P
0 g
s
.47559 .76855 m .47559 .78707 L .49196 .77971 L p .707 .577 .707 r
F P
0 g
s
.49196 .77971 m .49196 .76118 L .47559 .76855 L p .707 .577 .707 r
F P
0 g
s
.29804 .66898 m .29804 .63192 L .29515 .62338 L p .707 .577 .707 r
F P
0 g
s
.80551 .76675 m .80551 .78528 L .77805 .78089 L p .707 .577 .707 r
F P
0 g
s
.77805 .78089 m .77805 .76236 L .80551 .76675 L p .707 .577 .707 r
F P
0 g
s
.31064 .78413 m .31064 .76561 L .29804 .75772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48233 m .30223 .53792 L .29515 .54628 L p .707 .577 .707 r
F P
0 g
s
.68566 .78314 m .68566 .76461 L .71504 .76123 L p .707 .577 .707 r
F P
0 g
s
.29515 .62338 m .29515 .66044 L .29804 .66898 L p .707 .577 .707 r
F P
0 g
s
.49615 .48579 m .49615 .54137 L .48356 .53349 L p .707 .577 .707 r
F P
0 g
s
.48356 .53349 m .48356 .47791 L .49615 .48579 L p .707 .577 .707 r
F P
0 g
s
.29804 .75772 m .29804 .77625 L .31064 .78413 L p .707 .577 .707 r
F P
0 g
s
.71504 .76123 m .71504 .77976 L .68566 .78314 L p .707 .577 .707 r
F P
0 g
s
.49904 .62702 m .49904 .66407 L .49615 .65553 L p .707 .577 .707 r
F P
0 g
s
.49615 .65553 m .49615 .61847 L .49904 .62702 L p .707 .577 .707 r
F P
0 g
s
.77805 .76236 m .77805 .78089 L .74688 .77898 L p .707 .577 .707 r
F P
0 g
s
.74688 .77898 m .74688 .76046 L .77805 .76236 L p .707 .577 .707 r
F P
0 g
s
.71504 .77976 m .71504 .76123 L .74688 .76046 L p .707 .577 .707 r
F P
0 g
s
.49196 .76118 m .49196 .77971 L .49904 .77134 L p .707 .577 .707 r
F P
0 g
s
.49904 .77134 m .49904 .75282 L .49196 .76118 L p .707 .577 .707 r
F P
0 g
s
.30223 .53792 m .30223 .48233 L .3186 .47497 L p .707 .577 .707 r
F P
0 g
s
.74688 .76046 m .74688 .77898 L .71504 .77976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .66044 m .29515 .62338 L .30223 .61502 L p .707 .577 .707 r
F P
0 g
s
.29804 .77625 m .29804 .75772 L .29515 .74918 L p .707 .577 .707 r
F P
0 g
s
.3186 .47497 m .3186 .53055 L .30223 .53792 L p .707 .577 .707 r
F P
0 g
s
.48356 .47791 m .48356 .53349 L .4625 .52704 L p .707 .577 .707 r
F P
0 g
s
.4625 .52704 m .4625 .47145 L .48356 .47791 L p .707 .577 .707 r
F P
0 g
s
.29515 .74918 m .29515 .76771 L .29804 .77625 L p .707 .577 .707 r
F P
0 g
s
.30223 .61502 m .30223 .65207 L .29515 .66044 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .61847 m .49615 .65553 L .48356 .64764 L p .707 .577 .707 r
F P
0 g
s
.48356 .64764 m .48356 .61059 L .49615 .61847 L p .707 .577 .707 r
F P
0 g
s
.3186 .53055 m .3186 .47497 L .34265 .46932 L p .707 .577 .707 r
F P
0 g
s
.49904 .75282 m .49904 .77134 L .49615 .7628 L p .707 .577 .707 r
F P
0 g
s
.49615 .7628 m .49615 .74427 L .49904 .75282 L p .707 .577 .707 r
F P
0 g
s
.30223 .65207 m .30223 .61502 L .3186 .60765 L p .707 .577 .707 r
F P
0 g
s
.4625 .47145 m .4625 .52704 L .43504 .52264 L p .707 .577 .707 r
F P
0 g
s
.43504 .52264 m .43504 .46706 L .4625 .47145 L p .707 .577 .707 r
F P
0 g
s
.34265 .46932 m .34265 .5249 L .3186 .53055 L p .707 .577 .707 r
F P
0 g
s
.29515 .76771 m .29515 .74918 L .30223 .74082 L p .707 .577 .707 r
F P
0 g
s
.34265 .5249 m .34265 .46932 L .37203 .46594 L p .707 .577 .707 r
F P
0 g
s
.30223 .74082 m .30223 .75934 L .29515 .76771 L p .707 .577 .707 r
F P
0 g
s
.3186 .60765 m .3186 .6447 L .30223 .65207 L p .707 .577 .707 r
F P
0 g
s
.48356 .61059 m .48356 .64764 L .4625 .64119 L p .707 .577 .707 r
F P
0 g
s
.4625 .64119 m .4625 .60414 L .48356 .61059 L p .707 .577 .707 r
F P
0 g
s
.43504 .46706 m .43504 .52264 L .40387 .52074 L p .707 .577 .707 r
F P
0 g
s
.40387 .52074 m .40387 .46516 L .43504 .46706 L p .707 .577 .707 r
F P
0 g
s
.37203 .52152 m .37203 .46594 L .40387 .46516 L p .707 .577 .707 r
F P
0 g
s
.37203 .46594 m .37203 .52152 L .34265 .5249 L p .707 .577 .707 r
F P
0 g
s
.49615 .74427 m .49615 .7628 L .48356 .75492 L p .707 .577 .707 r
F P
0 g
s
.48356 .75492 m .48356 .73639 L .49615 .74427 L p .707 .577 .707 r
F P
0 g
s
.40387 .46516 m .40387 .52074 L .37203 .52152 L p .707 .577 .707 r
F P
0 g
s
.3186 .6447 m .3186 .60765 L .34265 .602 L p .707 .577 .707 r
F P
0 g
s
.30223 .75934 m .30223 .74082 L .3186 .73345 L p .707 .577 .707 r
F P
0 g
s
.34265 .602 m .34265 .63905 L .3186 .6447 L p .707 .577 .707 r
F P
0 g
s
.4625 .60414 m .4625 .64119 L .43504 .6368 L p .707 .577 .707 r
F P
0 g
s
.43504 .6368 m .43504 .59974 L .4625 .60414 L p .707 .577 .707 r
F P
0 g
s
.3186 .73345 m .3186 .75198 L .30223 .75934 L p .707 .577 .707 r
F P
0 g
s
.34265 .63905 m .34265 .602 L .37203 .59862 L p .707 .577 .707 r
F P
0 g
s
.48356 .73639 m .48356 .75492 L .4625 .74846 L p .707 .577 .707 r
F P
0 g
s
.4625 .74846 m .4625 .72993 L .48356 .73639 L p .707 .577 .707 r
F P
0 g
s
.43504 .59974 m .43504 .6368 L .40387 .6349 L p .707 .577 .707 r
F P
0 g
s
.40387 .6349 m .40387 .59784 L .43504 .59974 L p .707 .577 .707 r
F P
0 g
s
.37203 .59862 m .37203 .63567 L .34265 .63905 L p .707 .577 .707 r
F P
0 g
s
.37203 .63567 m .37203 .59862 L .40387 .59784 L p .707 .577 .707 r
F P
0 g
s
.3186 .75198 m .3186 .73345 L .34265 .7278 L p .707 .577 .707 r
F P
0 g
s
.40387 .59784 m .40387 .6349 L .37203 .63567 L p .707 .577 .707 r
F P
0 g
s
.34265 .7278 m .34265 .74633 L .3186 .75198 L p .707 .577 .707 r
F P
0 g
s
.4625 .72993 m .4625 .74846 L .43504 .74407 L p .707 .577 .707 r
F P
0 g
s
.43504 .74407 m .43504 .72554 L .4625 .72993 L p .707 .577 .707 r
F P
0 g
s
.34265 .74633 m .34265 .7278 L .37203 .72442 L p .707 .577 .707 r
F P
0 g
s
.37203 .72442 m .37203 .74295 L .34265 .74633 L p .707 .577 .707 r
F P
0 g
s
.43504 .72554 m .43504 .74407 L .40387 .74217 L p .707 .577 .707 r
F P
0 g
s
.40387 .74217 m .40387 .72364 L .43504 .72554 L p .707 .577 .707 r
F P
0 g
s
.37203 .74295 m .37203 .72442 L .40387 .72364 L p .707 .577 .707 r
F P
0 g
s
.40387 .72364 m .40387 .74217 L .37203 .74295 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002;Ool<
0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH2001[Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
001YOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOolH0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`H000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol30005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Qoo`T004Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`l000AJEP03001JEUYF009JEPP003aoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF00MJEP03
001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF
001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01P00FUH00000
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolA0005Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF009J
EPT000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF10000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0000=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH06P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH7000h
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPT000AJEP@00003
FUH0000000L003moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF60000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo2@00B7oo000/Ool00`00
FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool00`00FUH0
0004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo
00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF4P00A7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH000040003FUH2
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH300000eYF000000020003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP07FUH600000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P00=7oo000^Ool01000FUIJEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00FUH20005FUH00`00FUH000050002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80039oo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00@005YF001JEP80
0003FUH005YF00AJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH0
05YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`00<7oo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo1@00
15YF00<005YFFUH01EYF1@001EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>goo6P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF1`0000=J
EP00Ool01Woo1@0037oo1@0015YF00@005YFFUIJEP8002eoo`00FWoo0`0000=JEP00FUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD00003FUH005YF00=JEP03
001JEP0000Qoo`<0015oo`@00003FUH005YF009JEP8002eoo`00GGoo1@0015YF00<005YFFUH01EYF
1@001EYF00<005YFFUH00UYF20002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP8000=JEPD000=JEP8001Ioo`L000=JEP<000=JEP8002eoo`00
HWoo200015YF1@0000=JEP0000001`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00@005YFFUIJEPT000Uoo`T0
00=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00?goo6@003Goo00D005YFFUH0
05YF00X000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04001JEUYF0005FUH40006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool003=oo`@000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0
02moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP800005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool300000eYF001JEP06FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006Ool30006
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH900000eYF001JEP02FUH60009
FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009Ool40002
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP04001JEUYFFUH>0004FUH00`00FUIJ
EP02FUH8000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJEP02FUH00`00FUH0
000=OolI000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPH000Qoo`D000Aoo`P000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60006FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00002000G
Ool30019Ool002aoo`03001JEP0000AJEP03001JEP0000<000ioo`D000aoo`@000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003FUH005YF00=JEP03001JEP00009JEPD0
05ioo`00;7oo00<005YF00000eYF1`003goo0`0037oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03001JEP0000EJEP03001JEP00
008005]oo`00;7oo00@005YF001JEP8000EJEP03001JEP0000<001Qoo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00005FUH0
0`00FUIJEP02FUH2001IOol002aoo`06001JEP00001JEP001EYF00<005YFFUH00eYF6@0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YFFUH00eYF0`00
Egoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP020004FUH01000FUIJEUYF200000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF1`0015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EPD0009JEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3
00000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF0P0000=JEP00FUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF0`002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EP000002FUH30006FUH01`00FUIJEUYF001oo`0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00QJEP<00003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP0000<000=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003000jOol0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04
001JEP000003FUH00`00FUH000020003FUH01000FUH000000Woo00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YF00002UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0017oo1`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1000=Woo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH40006
FUH01000FUH000000eYF00<005YFFUH00UYF1@001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH0
25YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP8000Ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0039oo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF
00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH:0007FUH00`00FUIJEP07FUH50005FUH0
1000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000Ioo`800003
FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP80035oo`00>goo200015YF1@001EYF00@005YFFUIJEP800003FUH005YF00AJEP03
001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YF00002@000eYF00<005YFFUH00eYF00<005YFFUH00UYF4P00
15YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002moo`00@goo4`0000Aoo`00000000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP04001JEUYFFUH20004
FUH00`00FUIJEP02FUH8000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo0018Ool3
000?Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH01P00FUIJ
EP00FUH000AJEP03001JEP0000<000AJEP<001Qoo`D000AJEP05001JEUYFFUH0000^Ool005eoo`<0
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001J
EUYF00YJEP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP06001JEUYF001JEP000eYF0`000eYF
00<005YFFUH00UYF0`007Goo0`0000=JEP00FUH00UYF0P00;Goo001POol40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80006FUH00`00FUIJEP0:FUH00`00FUIJEP060008FUH0
0`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000IJEP03001JEUYF009JEP03001JEP00021oo`80
00=JEP8002eoo`00I7oo6@0027oo5P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800003FUH005YF00EJEP03001JEUYF009JEP8002=oo`800003FUH0000002eoo`00T7oo00<0
05YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000AJ
EP00FUH000IJEP04001JEUYFFUH2000TOol5000]Ool0095oo`8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000IJEP04001JEP00000TOol20002FUH3
000]Ool0099oo`<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEP000080009JEP<0029oo`@000AJEP03001JEP0002eoo`00UGoo1@001UYF00<0
05YFFUH01UYF10001EYF00D005YFFUIJEP00009JEP03001JEUYF009JEPD001]oo`L000=JEP03001J
EUYF009JEP8002ioo`00Agoo2@00BWoo10000UYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool003moo`P000AJEP03001JEUYF009JEPP004Iooa`000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6001;Ool5000;Ool20004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUH00000<Goo000bOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020019Ool3000>Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo000`Ool200000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001K
Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<005ioo`T000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<005YF
FUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P00IGoo2@00B7oo000]
Ool20004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP000;Ioo`00;7oo00<005YF0000
15YF10009goo0`0000=JEP00FUH00UYF00<007ooOol0]7oo000/Ool00`00FUH00002FUH2000^Ool2
0003FUH00`00Oomoo`2dOol002aoo`03001JEP000080039oo`04001JEUYF002fOol002aoo`04001J
EP00000dOol3000iOolH001UOol002aoo`80009JEP<002moo`<00003FUH007oo039oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0065oo`00;7oo0P000eYF00<005YF00000P00
:Goo0`000UYF00<005YF0000<7oo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`00GWoo000/Ool20003FUH00`00FUIJEP02FUH5000POol400000eYF001JEP02
FUH00`00FUH0000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00002001KOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF20004goo
1@001EYF00@005YFFUIJEP8002aoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8005Uoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00
Egoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF00<0
05YFFUH00eYF00<005YFFUH00P00EGoo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000/Ool00`00FUH00004FUH00`00FUH0
0002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00FUH00003FUH3000XOol300000eYF001J
EP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0
03=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eooaT003Qoo`04001JEP00000bOol20000
0eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P000UYF0P00;goo0P0000AJEP00000005Ao
o`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<005YF0000E7oo002?Ool01000FUIJEP00
15YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF00@005YFFUIJ
EQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
05Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001J
EUYF009JEPh0065oo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72157 m .59613 .66599 L .56496 .66409 L p .707 .577 .707 r
F P
0 g
s
.59613 .66599 m .59613 .72157 L .62796 .72079 L p .707 .577 .707 r
F P
0 g
s
.62796 .72079 m .62796 .66521 L .59613 .66599 L p .707 .577 .707 r
F P
0 g
s
.62796 .66521 m .62796 .72079 L .65734 .71741 L p .707 .577 .707 r
F P
0 g
s
.65734 .71741 m .65734 .66183 L .62796 .66521 L p .707 .577 .707 r
F P
0 g
s
.56496 .71967 m .56496 .66409 L .5375 .65969 L p .707 .577 .707 r
F P
0 g
s
.56496 .66409 m .56496 .71967 L .59613 .72157 L p .707 .577 .707 r
F P
0 g
s
.65734 .66183 m .65734 .71741 L .6814 .71176 L p .707 .577 .707 r
F P
0 g
s
.6814 .71176 m .6814 .65618 L .65734 .66183 L p .707 .577 .707 r
F P
0 g
s
.5375 .65969 m .5375 .71528 L .56496 .71967 L p .707 .577 .707 r
F P
0 g
s
.5375 .71528 m .5375 .65969 L .51644 .65324 L p .707 .577 .707 r
F P
0 g
s
.59613 .81518 m .59613 .77812 L .56496 .77622 L p .707 .577 .707 r
F P
0 g
s
.59613 .77812 m .59613 .81518 L .62796 .8144 L p .707 .577 .707 r
F P
0 g
s
.62796 .8144 m .62796 .77734 L .59613 .77812 L p .707 .577 .707 r
F P
0 g
s
.62796 .77734 m .62796 .8144 L .65735 .81102 L p .707 .577 .707 r
F P
0 g
s
.65735 .81102 m .65735 .77397 L .62796 .77734 L p .707 .577 .707 r
F P
0 g
s
.6814 .65618 m .6814 .71176 L .69777 .7044 L p .707 .577 .707 r
F P
0 g
s
.69777 .7044 m .69777 .64881 L .6814 .65618 L p .707 .577 .707 r
F P
0 g
s
.56496 .81328 m .56496 .77622 L .5375 .77183 L p .707 .577 .707 r
F P
0 g
s
.56496 .77622 m .56496 .81328 L .59613 .81518 L p .707 .577 .707 r
F P
0 g
s
.51644 .65324 m .51644 .70882 L .5375 .71528 L p .707 .577 .707 r
F P
0 g
s
.51644 .70882 m .51644 .65324 L .50385 .64536 L p .707 .577 .707 r
F P
0 g
s
.65735 .77397 m .65735 .81102 L .6814 .80537 L p .707 .577 .707 r
F P
0 g
s
.6814 .80537 m .6814 .76832 L .65735 .77397 L p .707 .577 .707 r
F P
0 g
s
.5375 .77183 m .5375 .80888 L .56496 .81328 L p .707 .577 .707 r
F P
0 g
s
.5375 .80888 m .5375 .77183 L .51644 .76537 L p .707 .577 .707 r
F P
0 g
s
.59613 .89745 m .59613 .87893 L .56496 .87702 L p .707 .577 .707 r
F P
0 g
s
.59613 .87893 m .59613 .89745 L .62796 .89668 L p .707 .577 .707 r
F P
0 g
s
.62796 .89668 m .62796 .87815 L .59613 .87893 L p .707 .577 .707 r
F P
0 g
s
.50385 .64536 m .50385 .70094 L .51644 .70882 L p .707 .577 .707 r
F P
0 g
s
.69777 .64881 m .69777 .7044 L .70485 .69603 L p .707 .577 .707 r
F P
0 g
s
.70485 .69603 m .70485 .64045 L .69777 .64881 L p .707 .577 .707 r
F P
0 g
s
.62796 .87815 m .62796 .89668 L .65735 .8933 L p .707 .577 .707 r
F P
0 g
s
.65735 .8933 m .65735 .87477 L .62796 .87815 L p .707 .577 .707 r
F P
0 g
s
.51644 .76537 m .51644 .80243 L .5375 .80888 L p .707 .577 .707 r
F P
0 g
s
.56496 .87702 m .56496 .89555 L .59613 .89745 L p .707 .577 .707 r
F P
0 g
s
.56496 .89555 m .56496 .87702 L .5375 .87263 L p .707 .577 .707 r
F P
0 g
s
.6814 .76832 m .6814 .80537 L .69777 .798 L p .707 .577 .707 r
F P
0 g
s
.69777 .798 m .69777 .76095 L .6814 .76832 L p .707 .577 .707 r
F P
0 g
s
.5375 .87263 m .5375 .89116 L .56496 .89555 L p .707 .577 .707 r
F P
0 g
s
.50385 .70094 m .50385 .64536 L .50095 .63681 L p .707 .577 .707 r
F P
0 g
s
.65735 .87477 m .65735 .8933 L .6814 .88765 L p .707 .577 .707 r
F P
0 g
s
.6814 .88765 m .6814 .86912 L .65735 .87477 L p .707 .577 .707 r
F P
0 g
s
.51644 .80243 m .51644 .76537 L .50385 .75749 L p .707 .577 .707 r
F P
0 g
s
.5375 .89116 m .5375 .87263 L .51644 .86618 L p .707 .577 .707 r
F P
0 g
s
.51644 .86618 m .51644 .88471 L .5375 .89116 L p .707 .577 .707 r
F P
0 g
s
.50385 .75749 m .50385 .79455 L .51644 .80243 L p .707 .577 .707 r
F P
0 g
s
.50095 .63681 m .50095 .6924 L .50385 .70094 L p .707 .577 .707 r
F P
0 g
s
.70485 .64045 m .70485 .69603 L .70195 .68749 L p .707 .577 .707 r
F P
0 g
s
.70195 .68749 m .70195 .63191 L .70485 .64045 L p .707 .577 .707 r
F P
0 g
s
.69777 .76095 m .69777 .798 L .70485 .78964 L p .707 .577 .707 r
F P
0 g
s
.70485 .78964 m .70485 .75258 L .69777 .76095 L p .707 .577 .707 r
F P
0 g
s
.6814 .86912 m .6814 .88765 L .69777 .88028 L p .707 .577 .707 r
F P
0 g
s
.69777 .88028 m .69777 .86175 L .6814 .86912 L p .707 .577 .707 r
F P
0 g
s
.50095 .6924 m .50095 .63681 L .50804 .62845 L p .707 .577 .707 r
F P
0 g
s
.49044 .80603 m .49044 .30415 L .44643 .30146 L p .707 .577 .707 r
F P
0 g
s
.50385 .79455 m .50385 .75749 L .50095 .74895 L p .707 .577 .707 r
F P
0 g
s
.50095 .74895 m .50095 .786 L .50385 .79455 L p .707 .577 .707 r
F P
0 g
s
.50804 .62845 m .50804 .68403 L .50095 .6924 L p .707 .577 .707 r
F P
0 g
s
.50804 .68403 m .50804 .62845 L .5244 .62108 L p .707 .577 .707 r
F P
0 g
s
.50095 .786 m .50095 .74895 L .50804 .74058 L p .707 .577 .707 r
F P
0 g
s
.50804 .74058 m .50804 .77764 L .50095 .786 L p .707 .577 .707 r
F P
0 g
s
.5244 .62108 m .5244 .67666 L .50804 .68403 L p .707 .577 .707 r
F P
0 g
s
.50804 .77764 m .50804 .74058 L .5244 .73322 L p .707 .577 .707 r
F P
0 g
s
.5244 .73322 m .5244 .77027 L .50804 .77764 L p .707 .577 .707 r
F P
0 g
s
.5244 .77027 m .5244 .73322 L .54846 .72757 L p .707 .577 .707 r
F P
0 g
s
.54846 .72757 m .54846 .76462 L .5244 .77027 L p .707 .577 .707 r
F P
0 g
s
.49044 .30415 m .49044 .80603 L .53538 .80494 L p .707 .577 .707 r
F P
0 g
s
.5244 .67666 m .5244 .62108 L .54846 .61543 L p .707 .577 .707 r
F P
0 g
s
.54846 .61543 m .54846 .67101 L .5244 .67666 L p .707 .577 .707 r
F P
0 g
s
.53538 .80494 m .53538 .30305 L .49044 .30415 L p .707 .577 .707 r
F P
0 g
s
.51644 .88471 m .51644 .86618 L .50385 .85829 L p .707 .577 .707 r
F P
0 g
s
.54846 .67101 m .54846 .61543 L .57784 .61205 L p .707 .577 .707 r
F P
0 g
s
.57784 .61205 m .57784 .66763 L .54846 .67101 L p .707 .577 .707 r
F P
0 g
s
.54846 .76462 m .54846 .72757 L .57784 .72419 L p .707 .577 .707 r
F P
0 g
s
.57784 .72419 m .57784 .76124 L .54846 .76462 L p .707 .577 .707 r
F P
0 g
s
.53538 .30305 m .53538 .80494 L .57686 .80017 L p .707 .577 .707 r
F P
0 g
s
.57686 .80017 m .57686 .29828 L .53538 .30305 L p .707 .577 .707 r
F P
0 g
s
.50385 .85829 m .50385 .87682 L .51644 .88471 L p .707 .577 .707 r
F P
0 g
s
.44643 .80335 m .44643 .30146 L .40766 .29526 L p .707 .577 .707 r
F P
0 g
s
.44643 .30146 m .44643 .80335 L .49044 .80603 L p .707 .577 .707 r
F P
0 g
s
.69777 .86175 m .69777 .88028 L .70485 .87191 L p .707 .577 .707 r
F P
0 g
s
.70485 .87191 m .70485 .85339 L .69777 .86175 L p .707 .577 .707 r
F P
0 g
s
.70195 .63191 m .70195 .68749 L .68936 .6796 L p .707 .577 .707 r
F P
0 g
s
.68936 .6796 m .68936 .62402 L .70195 .63191 L p .707 .577 .707 r
F P
0 g
s
.70485 .75258 m .70485 .78964 L .70195 .7811 L p .707 .577 .707 r
F P
0 g
s
.70195 .7811 m .70195 .74404 L .70485 .75258 L p .707 .577 .707 r
F P
0 g
s
.57784 .66763 m .57784 .61205 L .60968 .61128 L p .707 .577 .707 r
F P
0 g
s
.60968 .61128 m .60968 .66686 L .57784 .66763 L p .707 .577 .707 r
F P
0 g
s
.57784 .76124 m .57784 .72419 L .60968 .72341 L p .707 .577 .707 r
F P
0 g
s
.60968 .72341 m .60968 .76047 L .57784 .76124 L p .707 .577 .707 r
F P
0 g
s
.57686 .29828 m .57686 .80017 L .61082 .79219 L p .707 .577 .707 r
F P
0 g
s
.64085 .61318 m .64085 .66876 L .60968 .66686 L p .707 .577 .707 r
F P
0 g
s
.60968 .66686 m .60968 .61128 L .64085 .61318 L p .707 .577 .707 r
F P
0 g
s
.64085 .72531 m .64085 .76237 L .60968 .76047 L p .707 .577 .707 r
F P
0 g
s
.60968 .76047 m .60968 .72341 L .64085 .72531 L p .707 .577 .707 r
F P
0 g
s
.61082 .79219 m .61082 .2903 L .57686 .29828 L p .707 .577 .707 r
F P
0 g
s
.25312 .68475 m .25312 .62917 L .22195 .62727 L p .707 .577 .707 r
F P
0 g
s
.25312 .62917 m .25312 .68475 L .28495 .68398 L p .707 .577 .707 r
F P
0 g
s
.28495 .68398 m .28495 .62839 L .25312 .62917 L p .707 .577 .707 r
F P
0 g
s
.50385 .87682 m .50385 .85829 L .50095 .84975 L p .707 .577 .707 r
F P
0 g
s
.28495 .62839 m .28495 .68398 L .31434 .6806 L p .707 .577 .707 r
F P
0 g
s
.31434 .6806 m .31434 .62502 L .28495 .62839 L p .707 .577 .707 r
F P
0 g
s
.40766 .79715 m .40766 .29526 L .37794 .28615 L p .707 .577 .707 r
F P
0 g
s
.40766 .29526 m .40766 .79715 L .44643 .80335 L p .707 .577 .707 r
F P
0 g
s
.50095 .84975 m .50095 .86828 L .50385 .87682 L p .707 .577 .707 r
F P
0 g
s
.22195 .68285 m .22195 .62727 L .19449 .62288 L p .707 .577 .707 r
F P
0 g
s
.22195 .62727 m .22195 .68285 L .25312 .68475 L p .707 .577 .707 r
F P
0 g
s
.31434 .62502 m .31434 .6806 L .33839 .67495 L p .707 .577 .707 r
F P
0 g
s
.33839 .67495 m .33839 .61937 L .31434 .62502 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68936 .62402 m .68936 .6796 L .66831 .67315 L p .707 .577 .707 r
F P
0 g
s
.66831 .67315 m .66831 .61757 L .68936 .62402 L p .707 .577 .707 r
F P
0 g
s
.70485 .85339 m .70485 .87191 L .70195 .86337 L p .707 .577 .707 r
F P
0 g
s
.70195 .86337 m .70195 .84485 L .70485 .85339 L p .707 .577 .707 r
F P
0 g
s
.70195 .74404 m .70195 .7811 L .68936 .77321 L p .707 .577 .707 r
F P
0 g
s
.68936 .77321 m .68936 .73616 L .70195 .74404 L p .707 .577 .707 r
F P
0 g
s
.19449 .62288 m .19449 .67846 L .22195 .68285 L p .707 .577 .707 r
F P
0 g
s
.61082 .2903 m .61082 .79219 L .63393 .78179 L p .707 .577 .707 r
F P
0 g
s
.63393 .78179 m .63393 .2799 L .61082 .2903 L p .707 .577 .707 r
F P
0 g
s
.19449 .67846 m .19449 .62288 L .17343 .61642 L p .707 .577 .707 r
F P
0 g
s
.25312 .77836 m .25312 .74131 L .22195 .73941 L p .707 .577 .707 r
F P
0 g
s
.25312 .74131 m .25312 .77836 L .28495 .77758 L p .707 .577 .707 r
F P
0 g
s
.28495 .77758 m .28495 .74053 L .25312 .74131 L p .707 .577 .707 r
F P
0 g
s
.50095 .86828 m .50095 .84975 L .50804 .84139 L p .707 .577 .707 r
F P
0 g
s
.28495 .74053 m .28495 .77758 L .31434 .7742 L p .707 .577 .707 r
F P
0 g
s
.31434 .7742 m .31434 .73715 L .28495 .74053 L p .707 .577 .707 r
F P
0 g
s
.33839 .61937 m .33839 .67495 L .35476 .66758 L p .707 .577 .707 r
F P
0 g
s
.35476 .66758 m .35476 .612 L .33839 .61937 L p .707 .577 .707 r
F P
0 g
s
.50804 .84139 m .50804 .85992 L .50095 .86828 L p .707 .577 .707 r
F P
0 g
s
.37794 .78804 m .37794 .28615 L .36016 .27502 L p .707 .577 .707 r
F P
0 g
s
.37794 .28615 m .37794 .78804 L .40766 .79715 L p .707 .577 .707 r
F P
0 g
s
.22195 .77646 m .22195 .73941 L .19449 .73501 L p .707 .577 .707 r
F P
0 g
s
.22195 .73941 m .22195 .77646 L .25312 .77836 L p .707 .577 .707 r
F P
0 g
s
.17343 .61642 m .17343 .67201 L .19449 .67846 L p .707 .577 .707 r
F P
0 g
s
.66831 .61757 m .66831 .67315 L .64085 .66876 L p .707 .577 .707 r
F P
0 g
s
.64085 .66876 m .64085 .61318 L .66831 .61757 L p .707 .577 .707 r
F P
0 g
s
.17343 .67201 m .17343 .61642 L .16084 .60854 L p .707 .577 .707 r
F P
0 g
s
.31434 .73715 m .31434 .7742 L .33839 .76855 L p .707 .577 .707 r
F P
0 g
s
.33839 .76855 m .33839 .7315 L .31434 .73715 L p .707 .577 .707 r
F P
0 g
s
.19449 .73501 m .19449 .77207 L .22195 .77646 L p .707 .577 .707 r
F P
0 g
s
.70195 .84485 m .70195 .86337 L .68936 .85549 L p .707 .577 .707 r
F P
0 g
s
.68936 .85549 m .68936 .83696 L .70195 .84485 L p .707 .577 .707 r
F P
0 g
s
.68936 .73616 m .68936 .77321 L .66831 .76676 L p .707 .577 .707 r
F P
0 g
s
.66831 .76676 m .66831 .7297 L .68936 .73616 L p .707 .577 .707 r
F P
0 g
s
.19449 .77207 m .19449 .73501 L .17343 .72856 L p .707 .577 .707 r
F P
0 g
s
.25312 .86064 m .25312 .84211 L .22195 .84021 L p .707 .577 .707 r
F P
0 g
s
.25312 .84211 m .25312 .86064 L .28495 .85986 L p .707 .577 .707 r
F P
0 g
s
.28495 .85986 m .28495 .84133 L .25312 .84211 L p .707 .577 .707 r
F P
0 g
s
.66831 .7297 m .66831 .76676 L .64085 .76237 L p .707 .577 .707 r
F P
0 g
s
.64085 .76237 m .64085 .72531 L .66831 .7297 L p .707 .577 .707 r
F P
0 g
s
.63393 .2799 m .63393 .78179 L .64393 .76998 L p .707 .577 .707 r
F P
0 g
s
.64393 .76998 m .64393 .26809 L .63393 .2799 L p .707 .577 .707 r
F P
0 g
s
.16084 .60854 m .16084 .66412 L .17343 .67201 L p .707 .577 .707 r
F P
0 g
s
.35476 .612 m .35476 .66758 L .36184 .65922 L p .707 .577 .707 r
F P
0 g
s
.36184 .65922 m .36184 .60363 L .35476 .612 L p .707 .577 .707 r
F P
0 g
s
.50804 .85992 m .50804 .84139 L .5244 .83402 L p .707 .577 .707 r
F P
0 g
s
.28495 .84133 m .28495 .85986 L .31434 .85648 L p .707 .577 .707 r
F P
0 g
s
.31434 .85648 m .31434 .83795 L .28495 .84133 L p .707 .577 .707 r
F P
0 g
s
.17343 .72856 m .17343 .76561 L .19449 .77207 L p .707 .577 .707 r
F P
0 g
s
.22195 .84021 m .22195 .85874 L .25312 .86064 L p .707 .577 .707 r
F P
0 g
s
.22195 .85874 m .22195 .84021 L .19449 .83582 L p .707 .577 .707 r
F P
0 g
s
.33839 .7315 m .33839 .76855 L .35476 .76119 L p .707 .577 .707 r
F P
0 g
s
.35476 .76119 m .35476 .72413 L .33839 .7315 L p .707 .577 .707 r
F P
0 g
s
.5244 .83402 m .5244 .85255 L .50804 .85992 L p .707 .577 .707 r
F P
0 g
s
.19449 .83582 m .19449 .85434 L .22195 .85874 L p .707 .577 .707 r
F P
0 g
s
.16084 .66412 m .16084 .60854 L .15794 .6 L p .707 .577 .707 r
F P
0 g
s
.31434 .83795 m .31434 .85648 L .33839 .85083 L p .707 .577 .707 r
F P
0 g
s
.33839 .85083 m .33839 .8323 L .31434 .83795 L p .707 .577 .707 r
F P
0 g
s
.17343 .76561 m .17343 .72856 L .16084 .72068 L p .707 .577 .707 r
F P
0 g
s
.36184 .60363 m .36184 .65922 L .35894 .65067 L p .707 .577 .707 r
F P
0 g
s
.35894 .65067 m .35894 .59509 L .36184 .60363 L p .707 .577 .707 r
F P
0 g
s
.35476 .72413 m .35476 .76119 L .36184 .75282 L p .707 .577 .707 r
F P
0 g
s
.36184 .75282 m .36184 .71577 L .35476 .72413 L p .707 .577 .707 r
F P
0 g
s
.35894 .59509 m .35894 .65067 L .34635 .64279 L p .707 .577 .707 r
F P
0 g
s
.34635 .64279 m .34635 .58721 L .35894 .59509 L p .707 .577 .707 r
F P
0 g
s
.36184 .71577 m .36184 .75282 L .35894 .74428 L p .707 .577 .707 r
F P
0 g
s
.35894 .74428 m .35894 .70723 L .36184 .71577 L p .707 .577 .707 r
F P
0 g
s
.36016 .77691 m .36016 .27502 L .35607 .26296 L p .707 .577 .707 r
F P
0 g
s
.36016 .27502 m .36016 .77691 L .37794 .78804 L p .707 .577 .707 r
F P
0 g
s
.68936 .83696 m .68936 .85549 L .66831 .84903 L p .707 .577 .707 r
F P
0 g
s
.66831 .84903 m .66831 .83051 L .68936 .83696 L p .707 .577 .707 r
F P
0 g
s
.19449 .85434 m .19449 .83582 L .17343 .82936 L p .707 .577 .707 r
F P
0 g
s
.17343 .82936 m .17343 .84789 L .19449 .85434 L p .707 .577 .707 r
F P
0 g
s
.16084 .72068 m .16084 .75773 L .17343 .76561 L p .707 .577 .707 r
F P
0 g
s
.5244 .85255 m .5244 .83402 L .54846 .82837 L p .707 .577 .707 r
F P
0 g
s
.15794 .6 m .15794 .65558 L .16084 .66412 L p .707 .577 .707 r
F P
0 g
s
.54846 .82837 m .54846 .8469 L .5244 .85255 L p .707 .577 .707 r
F P
0 g
s
.33839 .8323 m .33839 .85083 L .35476 .84346 L p .707 .577 .707 r
F P
0 g
s
.35476 .84346 m .35476 .82494 L .33839 .8323 L p .707 .577 .707 r
F P
0 g
s
.66831 .83051 m .66831 .84903 L .64085 .84464 L p .707 .577 .707 r
F P
0 g
s
.64085 .84464 m .64085 .82611 L .66831 .83051 L p .707 .577 .707 r
F P
0 g
s
.64393 .26809 m .64393 .76998 L .63984 .75792 L p .707 .577 .707 r
F P
0 g
s
.63984 .75792 m .63984 .25603 L .64393 .26809 L p .707 .577 .707 r
F P
0 g
s
.15794 .65558 m .15794 .6 L .16503 .59163 L p .707 .577 .707 r
F P
0 g
s
.17343 .84789 m .17343 .82936 L .16084 .82148 L p .707 .577 .707 r
F P
0 g
s
.16084 .75773 m .16084 .72068 L .15794 .71213 L p .707 .577 .707 r
F P
0 g
s
.54846 .8469 m .54846 .82837 L .57784 .82499 L p .707 .577 .707 r
F P
0 g
s
.16084 .82148 m .16084 .84001 L .17343 .84789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.57784 .82499 m .57784 .84352 L .54846 .8469 L p .707 .577 .707 r
F P
0 g
s
.15794 .71213 m .15794 .74919 L .16084 .75773 L p .707 .577 .707 r
F P
0 g
s
.64085 .82611 m .64085 .84464 L .60968 .84274 L p .707 .577 .707 r
F P
0 g
s
.60968 .84274 m .60968 .82421 L .64085 .82611 L p .707 .577 .707 r
F P
0 g
s
.16503 .59163 m .16503 .64722 L .15794 .65558 L p .707 .577 .707 r
F P
0 g
s
.35894 .70723 m .35894 .74428 L .34635 .7364 L p .707 .577 .707 r
F P
0 g
s
.34635 .7364 m .34635 .69934 L .35894 .70723 L p .707 .577 .707 r
F P
0 g
s
.35607 .26296 m .35607 .76485 L .36016 .77691 L p .707 .577 .707 r
F P
0 g
s
.35607 .76485 m .35607 .26296 L .36607 .25115 L p .707 .577 .707 r
F P
0 g
s
.57784 .84352 m .57784 .82499 L .60968 .82421 L p .707 .577 .707 r
F P
0 g
s
.35476 .82494 m .35476 .84346 L .36184 .8351 L p .707 .577 .707 r
F P
0 g
s
.36184 .8351 m .36184 .81657 L .35476 .82494 L p .707 .577 .707 r
F P
0 g
s
.60968 .82421 m .60968 .84274 L .57784 .84352 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .84001 m .16084 .82148 L .15794 .81294 L p .707 .577 .707 r
F P
0 g
s
.16503 .64722 m .16503 .59163 L .1814 .58427 L p .707 .577 .707 r
F P
0 g
s
.15794 .74919 m .15794 .71213 L .16503 .70377 L p .707 .577 .707 r
F P
0 g
s
.15794 .81294 m .15794 .83146 L .16084 .84001 L p .707 .577 .707 r
F P
0 g
s
.63984 .25603 m .63984 .75792 L .62206 .74679 L p .707 .577 .707 r
F P
0 g
s
.62206 .74679 m .62206 .2449 L .63984 .25603 L p .707 .577 .707 r
F P
0 g
s
.16503 .70377 m .16503 .74082 L .15794 .74919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .58427 m .1814 .63985 L .16503 .64722 L p .707 .577 .707 r
F P
0 g
s
.34635 .58721 m .34635 .64279 L .3253 .63634 L p .707 .577 .707 r
F P
0 g
s
.3253 .63634 m .3253 .58075 L .34635 .58721 L p .707 .577 .707 r
F P
0 g
s
.36184 .81657 m .36184 .8351 L .35894 .82656 L p .707 .577 .707 r
F P
0 g
s
.35894 .82656 m .35894 .80803 L .36184 .81657 L p .707 .577 .707 r
F P
0 g
s
.1814 .63985 m .1814 .58427 L .20545 .57862 L p .707 .577 .707 r
F P
0 g
s
.36607 .75304 m .36607 .25115 L .38918 .24075 L p .707 .577 .707 r
F P
0 g
s
.36607 .25115 m .36607 .75304 L .35607 .76485 L p .707 .577 .707 r
F P
0 g
s
.15794 .83146 m .15794 .81294 L .16503 .80457 L p .707 .577 .707 r
F P
0 g
s
.16503 .74082 m .16503 .70377 L .1814 .6964 L p .707 .577 .707 r
F P
0 g
s
.16503 .80457 m .16503 .8231 L .15794 .83146 L p .707 .577 .707 r
F P
0 g
s
.3253 .58075 m .3253 .63634 L .29784 .63194 L p .707 .577 .707 r
F P
0 g
s
.29784 .63194 m .29784 .57636 L .3253 .58075 L p .707 .577 .707 r
F P
0 g
s
.1814 .6964 m .1814 .73346 L .16503 .74082 L p .707 .577 .707 r
F P
0 g
s
.20545 .57862 m .20545 .6342 L .1814 .63985 L p .707 .577 .707 r
F P
0 g
s
.20545 .6342 m .20545 .57862 L .23483 .57524 L p .707 .577 .707 r
F P
0 g
s
.35894 .80803 m .35894 .82656 L .34635 .81867 L p .707 .577 .707 r
F P
0 g
s
.34635 .81867 m .34635 .80015 L .35894 .80803 L p .707 .577 .707 r
F P
0 g
s
.34635 .69934 m .34635 .7364 L .3253 .72994 L p .707 .577 .707 r
F P
0 g
s
.3253 .72994 m .3253 .69289 L .34635 .69934 L p .707 .577 .707 r
F P
0 g
s
.62206 .2449 m .62206 .74679 L .59233 .73768 L p .707 .577 .707 r
F P
0 g
s
.59233 .73768 m .59233 .23579 L .62206 .2449 L p .707 .577 .707 r
F P
0 g
s
.29784 .57636 m .29784 .63194 L .26667 .63004 L p .707 .577 .707 r
F P
0 g
s
.26667 .63004 m .26667 .57446 L .29784 .57636 L p .707 .577 .707 r
F P
0 g
s
.1814 .73346 m .1814 .6964 L .20545 .69075 L p .707 .577 .707 r
F P
0 g
s
.23483 .63082 m .23483 .57524 L .26667 .57446 L p .707 .577 .707 r
F P
0 g
s
.23483 .57524 m .23483 .63082 L .20545 .6342 L p .707 .577 .707 r
F P
0 g
s
.16503 .8231 m .16503 .80457 L .1814 .79721 L p .707 .577 .707 r
F P
0 g
s
.26667 .57446 m .26667 .63004 L .23483 .63082 L p .707 .577 .707 r
F P
0 g
s
.73333 .62953 m .73333 .57395 L .70216 .57205 L p .707 .577 .707 r
F P
0 g
s
.73333 .57395 m .73333 .62953 L .76517 .62875 L p .707 .577 .707 r
F P
0 g
s
.76517 .62875 m .76517 .57317 L .73333 .57395 L p .707 .577 .707 r
F P
0 g
s
.1814 .79721 m .1814 .81573 L .16503 .8231 L p .707 .577 .707 r
F P
0 g
s
.38918 .24075 m .38918 .74264 L .36607 .75304 L p .707 .577 .707 r
F P
0 g
s
.38918 .74264 m .38918 .24075 L .42314 .23277 L p .707 .577 .707 r
F P
0 g
s
.76517 .57317 m .76517 .62875 L .79455 .62537 L p .707 .577 .707 r
F P
0 g
s
.79455 .62537 m .79455 .56979 L .76517 .57317 L p .707 .577 .707 r
F P
0 g
s
.20545 .69075 m .20545 .72781 L .1814 .73346 L p .707 .577 .707 r
F P
0 g
s
.3253 .69289 m .3253 .72994 L .29784 .72555 L p .707 .577 .707 r
F P
0 g
s
.29784 .72555 m .29784 .6885 L .3253 .69289 L p .707 .577 .707 r
F P
0 g
s
.70216 .62763 m .70216 .57205 L .6747 .56766 L p .707 .577 .707 r
F P
0 g
s
.70216 .57205 m .70216 .62763 L .73333 .62953 L p .707 .577 .707 r
F P
0 g
s
.34635 .80015 m .34635 .81867 L .3253 .81222 L p .707 .577 .707 r
F P
0 g
s
.3253 .81222 m .3253 .79369 L .34635 .80015 L p .707 .577 .707 r
F P
0 g
s
.20545 .72781 m .20545 .69075 L .23483 .68737 L p .707 .577 .707 r
F P
0 g
s
.79455 .56979 m .79455 .62537 L .8186 .61972 L p .707 .577 .707 r
F P
0 g
s
.8186 .61972 m .8186 .56414 L .79455 .56979 L p .707 .577 .707 r
F P
0 g
s
.59233 .23579 m .59233 .73768 L .55357 .73148 L p .707 .577 .707 r
F P
0 g
s
.55357 .73148 m .55357 .22959 L .59233 .23579 L p .707 .577 .707 r
F P
0 g
s
.1814 .81573 m .1814 .79721 L .20545 .79156 L p .707 .577 .707 r
F P
0 g
s
.6747 .56766 m .6747 .62324 L .70216 .62763 L p .707 .577 .707 r
F P
0 g
s
.29784 .6885 m .29784 .72555 L .26667 .72365 L p .707 .577 .707 r
F P
0 g
s
.26667 .72365 m .26667 .68659 L .29784 .6885 L p .707 .577 .707 r
F P
0 g
s
.6747 .62324 m .6747 .56766 L .65365 .5612 L p .707 .577 .707 r
F P
0 g
s
.23483 .68737 m .23483 .72443 L .20545 .72781 L p .707 .577 .707 r
F P
0 g
s
.23483 .72443 m .23483 .68737 L .26667 .68659 L p .707 .577 .707 r
F P
0 g
s
.20545 .79156 m .20545 .81008 L .1814 .81573 L p .707 .577 .707 r
F P
0 g
s
.26667 .68659 m .26667 .72365 L .23483 .72443 L p .707 .577 .707 r
F P
0 g
s
.42314 .73466 m .42314 .23277 L .46462 .228 L p .707 .577 .707 r
F P
0 g
s
.42314 .23277 m .42314 .73466 L .38918 .74264 L p .707 .577 .707 r
F P
0 g
s
.73333 .72314 m .73333 .68608 L .70216 .68418 L p .707 .577 .707 r
F P
0 g
s
.73333 .68608 m .73333 .72314 L .76517 .72236 L p .707 .577 .707 r
F P
0 g
s
.76517 .72236 m .76517 .68531 L .73333 .68608 L p .707 .577 .707 r
F P
0 g
s
.76517 .68531 m .76517 .72236 L .79455 .71898 L p .707 .577 .707 r
F P
0 g
s
.79455 .71898 m .79455 .68193 L .76517 .68531 L p .707 .577 .707 r
F P
0 g
s
.3253 .79369 m .3253 .81222 L .29784 .80783 L p .707 .577 .707 r
F P
0 g
s
.29784 .80783 m .29784 .7893 L .3253 .79369 L p .707 .577 .707 r
F P
0 g
s
.8186 .56414 m .8186 .61972 L .83497 .61236 L p .707 .577 .707 r
F P
0 g
s
.83497 .61236 m .83497 .55677 L .8186 .56414 L p .707 .577 .707 r
F P
0 g
s
.70216 .72124 m .70216 .68418 L .6747 .67979 L p .707 .577 .707 r
F P
0 g
s
.70216 .68418 m .70216 .72124 L .73333 .72314 L p .707 .577 .707 r
F P
0 g
s
.65365 .5612 m .65365 .61678 L .6747 .62324 L p .707 .577 .707 r
F P
0 g
s
.55357 .22959 m .55357 .73148 L .50956 .72879 L p .707 .577 .707 r
F P
0 g
s
.50956 .72879 m .50956 .22691 L .55357 .22959 L p .707 .577 .707 r
F P
0 g
s
.20545 .81008 m .20545 .79156 L .23483 .78818 L p .707 .577 .707 r
F P
0 g
s
.65365 .61678 m .65365 .5612 L .64105 .55332 L p .707 .577 .707 r
F P
0 g
s
.79455 .68193 m .79455 .71898 L .8186 .71333 L p .707 .577 .707 r
F P
0 g
s
.8186 .71333 m .8186 .67628 L .79455 .68193 L p .707 .577 .707 r
F P
0 g
s
.23483 .78818 m .23483 .8067 L .20545 .81008 L p .707 .577 .707 r
F P
0 g
s
.46462 .72989 m .46462 .228 L .50956 .22691 L p .707 .577 .707 r
F P
0 g
s
.46462 .228 m .46462 .72989 L .42314 .73466 L p .707 .577 .707 r
F P
0 g
s
.6747 .67979 m .6747 .71684 L .70216 .72124 L p .707 .577 .707 r
F P
0 g
s
.29784 .7893 m .29784 .80783 L .26667 .80593 L p .707 .577 .707 r
F P
0 g
s
.26667 .80593 m .26667 .7874 L .29784 .7893 L p .707 .577 .707 r
F P
0 g
s
.50956 .22691 m .50956 .72879 L .46462 .72989 L p .707 .577 .707 r
F P
0 g
s
.6747 .71684 m .6747 .67979 L .65365 .67334 L p .707 .577 .707 r
F P
0 g
s
.23483 .8067 m .23483 .78818 L .26667 .7874 L p .707 .577 .707 r
F P
0 g
s
.26667 .7874 m .26667 .80593 L .23483 .8067 L p .707 .577 .707 r
F P
0 g
s
.73333 .80541 m .73333 .78689 L .70216 .78499 L p .707 .577 .707 r
F P
0 g
s
.73333 .78689 m .73333 .80541 L .76517 .80464 L p .707 .577 .707 r
F P
0 g
s
.76517 .80464 m .76517 .78611 L .73333 .78689 L p .707 .577 .707 r
F P
0 g
s
.64105 .55332 m .64105 .6089 L .65365 .61678 L p .707 .577 .707 r
F P
0 g
s
.83497 .55677 m .83497 .61236 L .84205 .60399 L p .707 .577 .707 r
F P
0 g
s
.84205 .60399 m .84205 .54841 L .83497 .55677 L p .707 .577 .707 r
F P
0 g
s
.76517 .78611 m .76517 .80464 L .79455 .80126 L p .707 .577 .707 r
F P
0 g
s
.79455 .80126 m .79455 .78273 L .76517 .78611 L p .707 .577 .707 r
F P
0 g
s
.65365 .67334 m .65365 .71039 L .6747 .71684 L p .707 .577 .707 r
F P
0 g
s
.70216 .78499 m .70216 .80351 L .73333 .80541 L p .707 .577 .707 r
F P
0 g
s
.70216 .80351 m .70216 .78499 L .6747 .78059 L p .707 .577 .707 r
F P
0 g
s
.8186 .67628 m .8186 .71333 L .83497 .70596 L p .707 .577 .707 r
F P
0 g
s
.83497 .70596 m .83497 .66891 L .8186 .67628 L p .707 .577 .707 r
F P
0 g
s
.6747 .78059 m .6747 .79912 L .70216 .80351 L p .707 .577 .707 r
F P
0 g
s
.64105 .6089 m .64105 .55332 L .63816 .54477 L p .707 .577 .707 r
F P
0 g
s
.79455 .78273 m .79455 .80126 L .8186 .79561 L p .707 .577 .707 r
F P
0 g
s
.8186 .79561 m .8186 .77708 L .79455 .78273 L p .707 .577 .707 r
F P
0 g
s
.65365 .71039 m .65365 .67334 L .64105 .66545 L p .707 .577 .707 r
F P
0 g
s
.6747 .79912 m .6747 .78059 L .65365 .77414 L p .707 .577 .707 r
F P
0 g
s
.65365 .77414 m .65365 .79267 L .6747 .79912 L p .707 .577 .707 r
F P
0 g
s
.64105 .66545 m .64105 .70251 L .65365 .71039 L p .707 .577 .707 r
F P
0 g
s
.63816 .54477 m .63816 .60036 L .64105 .6089 L p .707 .577 .707 r
F P
0 g
s
.84205 .54841 m .84205 .60399 L .83916 .59545 L p .707 .577 .707 r
F P
0 g
s
.83916 .59545 m .83916 .53987 L .84205 .54841 L p .707 .577 .707 r
F P
0 g
s
.83497 .66891 m .83497 .70596 L .84206 .6976 L p .707 .577 .707 r
F P
0 g
s
.84206 .6976 m .84205 .66054 L .83497 .66891 L p .707 .577 .707 r
F P
0 g
s
.8186 .77708 m .8186 .79561 L .83497 .78824 L p .707 .577 .707 r
F P
0 g
s
.83497 .78824 m .83497 .76971 L .8186 .77708 L p .707 .577 .707 r
F P
0 g
s
.63816 .60036 m .63816 .54477 L .64524 .53641 L p .707 .577 .707 r
F P
0 g
s
.65365 .79267 m .65365 .77414 L .64105 .76626 L p .707 .577 .707 r
F P
0 g
s
.64105 .70251 m .64105 .66545 L .63816 .65691 L p .707 .577 .707 r
F P
0 g
s
.64105 .76626 m .64105 .78478 L .65365 .79267 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63816 .65691 m .63816 .69396 L .64105 .70251 L p .707 .577 .707 r
F P
0 g
s
.64524 .53641 m .64524 .59199 L .63816 .60036 L p .707 .577 .707 r
F P
0 g
s
.83497 .76971 m .83497 .78824 L .84206 .77988 L p .707 .577 .707 r
F P
0 g
s
.84206 .77988 m .84206 .76135 L .83497 .76971 L p .707 .577 .707 r
F P
0 g
s
.83916 .53987 m .83916 .59545 L .82657 .58757 L p .707 .577 .707 r
F P
0 g
s
.82657 .58757 m .82657 .53198 L .83916 .53987 L p .707 .577 .707 r
F P
0 g
s
.84205 .66054 m .84206 .6976 L .83916 .68906 L p .707 .577 .707 r
F P
0 g
s
.83916 .68906 m .83916 .652 L .84205 .66054 L p .707 .577 .707 r
F P
0 g
s
.39032 .59271 m .39032 .53713 L .35915 .53523 L p .707 .577 .707 r
F P
0 g
s
.39032 .53713 m .39032 .59271 L .42216 .59194 L p .707 .577 .707 r
F P
0 g
s
.42216 .59194 m .42216 .53636 L .39032 .53713 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64105 .78478 m .64105 .76626 L .63816 .75771 L p .707 .577 .707 r
F P
0 g
s
.64524 .59199 m .64524 .53641 L .66161 .52904 L p .707 .577 .707 r
F P
0 g
s
.42216 .53636 m .42216 .59194 L .45154 .58856 L p .707 .577 .707 r
F P
0 g
s
.45154 .58856 m .45154 .53298 L .42216 .53636 L p .707 .577 .707 r
F P
0 g
s
.63816 .69396 m .63816 .65691 L .64524 .64855 L p .707 .577 .707 r
F P
0 g
s
.63816 .75771 m .63816 .77624 L .64105 .78478 L p .707 .577 .707 r
F P
0 g
s
.35915 .59081 m .35915 .53523 L .33169 .53084 L p .707 .577 .707 r
F P
0 g
s
.35915 .53523 m .35915 .59081 L .39032 .59271 L p .707 .577 .707 r
F P
0 g
s
.64524 .64855 m .64524 .6856 L .63816 .69396 L p .707 .577 .707 r
F P
0 g
s
.45154 .53298 m .45154 .58856 L .47559 .58291 L p .707 .577 .707 r
F P
0 g
s
.47559 .58291 m .47559 .52733 L .45154 .53298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52904 m .66161 .58462 L .64524 .59199 L p .707 .577 .707 r
F P
0 g
s
.82657 .53198 m .82657 .58757 L .80551 .58111 L p .707 .577 .707 r
F P
0 g
s
.80551 .58111 m .80551 .52553 L .82657 .53198 L p .707 .577 .707 r
F P
0 g
s
.84206 .76135 m .84206 .77988 L .83916 .77133 L p .707 .577 .707 r
F P
0 g
s
.83916 .77133 m .83916 .75281 L .84206 .76135 L p .707 .577 .707 r
F P
0 g
s
.83916 .652 m .83916 .68906 L .82657 .68117 L p .707 .577 .707 r
F P
0 g
s
.82657 .68117 m .82657 .64412 L .83916 .652 L p .707 .577 .707 r
F P
0 g
s
.33169 .53084 m .33169 .58642 L .35915 .59081 L p .707 .577 .707 r
F P
0 g
s
.33169 .58642 m .33169 .53084 L .31064 .52439 L p .707 .577 .707 r
F P
0 g
s
.66161 .58462 m .66161 .52904 L .68566 .52339 L p .707 .577 .707 r
F P
0 g
s
.39032 .68632 m .39032 .64927 L .35915 .64737 L p .707 .577 .707 r
F P
0 g
s
.39032 .64927 m .39032 .68632 L .42216 .68555 L p .707 .577 .707 r
F P
0 g
s
.42216 .68555 m .42216 .64849 L .39032 .64927 L p .707 .577 .707 r
F P
0 g
s
.63816 .77624 m .63816 .75771 L .64524 .74935 L p .707 .577 .707 r
F P
0 g
s
.64524 .6856 m .64524 .64855 L .66161 .64118 L p .707 .577 .707 r
F P
0 g
s
.42216 .64849 m .42216 .68555 L .45154 .68217 L p .707 .577 .707 r
F P
0 g
s
.45154 .68217 m .45154 .64511 L .42216 .64849 L p .707 .577 .707 r
F P
0 g
s
.47559 .52733 m .47559 .58291 L .49196 .57554 L p .707 .577 .707 r
F P
0 g
s
.49196 .57554 m .49196 .51996 L .47559 .52733 L p .707 .577 .707 r
F P
0 g
s
.64524 .74935 m .64524 .76788 L .63816 .77624 L p .707 .577 .707 r
F P
0 g
s
.35915 .68442 m .35915 .64737 L .33169 .64297 L p .707 .577 .707 r
F P
0 g
s
.35915 .64737 m .35915 .68442 L .39032 .68632 L p .707 .577 .707 r
F P
0 g
s
.31064 .52439 m .31064 .57997 L .33169 .58642 L p .707 .577 .707 r
F P
0 g
s
.80551 .52553 m .80551 .58111 L .77805 .57672 L p .707 .577 .707 r
F P
0 g
s
.77805 .57672 m .77805 .52114 L .80551 .52553 L p .707 .577 .707 r
F P
0 g
s
.66161 .64118 m .66161 .67823 L .64524 .6856 L p .707 .577 .707 r
F P
0 g
s
.68566 .52339 m .68566 .57897 L .66161 .58462 L p .707 .577 .707 r
F P
0 g
s
.31064 .57997 m .31064 .52439 L .29804 .5165 L p .707 .577 .707 r
F P
0 g
s
.45154 .64511 m .45154 .68217 L .47559 .67652 L p .707 .577 .707 r
F P
0 g
s
.47559 .67652 m .47559 .63946 L .45154 .64511 L p .707 .577 .707 r
F P
0 g
s
.33169 .64297 m .33169 .68003 L .35915 .68442 L p .707 .577 .707 r
F P
0 g
s
.68566 .57897 m .68566 .52339 L .71504 .52001 L p .707 .577 .707 r
F P
0 g
s
.83916 .75281 m .83916 .77133 L .82657 .76345 L p .707 .577 .707 r
F P
0 g
s
.82657 .76345 m .82657 .74492 L .83916 .75281 L p .707 .577 .707 r
F P
0 g
s
.82657 .64412 m .82657 .68117 L .80551 .67472 L p .707 .577 .707 r
F P
0 g
s
.80551 .67472 m .80551 .63766 L .82657 .64412 L p .707 .577 .707 r
F P
0 g
s
.33169 .68003 m .33169 .64297 L .31064 .63652 L p .707 .577 .707 r
F P
0 g
s
.77805 .52114 m .77805 .57672 L .74688 .57482 L p .707 .577 .707 r
F P
0 g
s
.74688 .57482 m .74688 .51924 L .77805 .52114 L p .707 .577 .707 r
F P
0 g
s
.39032 .7686 m .39032 .75007 L .35915 .74817 L p .707 .577 .707 r
F P
0 g
s
.39032 .75007 m .39032 .7686 L .42216 .76782 L p .707 .577 .707 r
F P
0 g
s
.42216 .76782 m .42216 .74929 L .39032 .75007 L p .707 .577 .707 r
F P
0 g
s
.66161 .67823 m .66161 .64118 L .68566 .63553 L p .707 .577 .707 r
F P
0 g
s
.29804 .5165 m .29804 .57208 L .31064 .57997 L p .707 .577 .707 r
F P
0 g
s
.71504 .5756 m .71504 .52001 L .74688 .51924 L p .707 .577 .707 r
F P
0 g
s
.71504 .52001 m .71504 .5756 L .68566 .57897 L p .707 .577 .707 r
F P
0 g
s
.49196 .51996 m .49196 .57554 L .49904 .56718 L p .707 .577 .707 r
F P
0 g
s
.49904 .56718 m .49904 .51159 L .49196 .51996 L p .707 .577 .707 r
F P
0 g
s
.64524 .76788 m .64524 .74935 L .66161 .74198 L p .707 .577 .707 r
F P
0 g
s
.42216 .74929 m .42216 .76782 L .45154 .76444 L p .707 .577 .707 r
F P
0 g
s
.45154 .76444 m .45154 .74592 L .42216 .74929 L p .707 .577 .707 r
F P
0 g
s
.31064 .63652 m .31064 .67358 L .33169 .68003 L p .707 .577 .707 r
F P
0 g
s
.74688 .51924 m .74688 .57482 L .71504 .5756 L p .707 .577 .707 r
F P
0 g
s
.35915 .74817 m .35915 .7667 L .39032 .7686 L p .707 .577 .707 r
F P
0 g
s
.35915 .7667 m .35915 .74817 L .33169 .74378 L p .707 .577 .707 r
F P
0 g
s
.47559 .63946 m .47559 .67652 L .49196 .66915 L p .707 .577 .707 r
F P
0 g
s
.49196 .66915 m .49196 .63209 L .47559 .63946 L p .707 .577 .707 r
F P
0 g
s
.66161 .74198 m .66161 .76051 L .64524 .76788 L p .707 .577 .707 r
F P
0 g
s
.68566 .63553 m .68566 .67258 L .66161 .67823 L p .707 .577 .707 r
F P
0 g
s
.33169 .74378 m .33169 .76231 L .35915 .7667 L p .707 .577 .707 r
F P
0 g
s
.80551 .63766 m .80551 .67472 L .77805 .67033 L p .707 .577 .707 r
F P
0 g
s
.77805 .67033 m .77805 .63327 L .80551 .63766 L p .707 .577 .707 r
F P
0 g
s
.29804 .57208 m .29804 .5165 L .29515 .50796 L p .707 .577 .707 r
F P
0 g
s
.45154 .74592 m .45154 .76444 L .47559 .75879 L p .707 .577 .707 r
F P
0 g
s
.47559 .75879 m .47559 .74027 L .45154 .74592 L p .707 .577 .707 r
F P
0 g
s
.31064 .67358 m .31064 .63652 L .29804 .62864 L p .707 .577 .707 r
F P
0 g
s
.82657 .74492 m .82657 .76345 L .80551 .757 L p .707 .577 .707 r
F P
0 g
s
.80551 .757 m .80551 .73847 L .82657 .74492 L p .707 .577 .707 r
F P
0 g
s
.68566 .67258 m .68566 .63553 L .71504 .63215 L p .707 .577 .707 r
F P
0 g
s
.33169 .76231 m .33169 .74378 L .31064 .73733 L p .707 .577 .707 r
F P
0 g
s
.31064 .73733 m .31064 .75585 L .33169 .76231 L p .707 .577 .707 r
F P
0 g
s
.29804 .62864 m .29804 .66569 L .31064 .67358 L p .707 .577 .707 r
F P
0 g
s
.66161 .76051 m .66161 .74198 L .68566 .73633 L p .707 .577 .707 r
F P
0 g
s
.77805 .63327 m .77805 .67033 L .74688 .66843 L p .707 .577 .707 r
F P
0 g
s
.74688 .66843 m .74688 .63137 L .77805 .63327 L p .707 .577 .707 r
F P
0 g
s
.29515 .50796 m .29515 .56354 L .29804 .57208 L p .707 .577 .707 r
F P
0 g
s
.71504 .63215 m .71504 .6692 L .68566 .67258 L p .707 .577 .707 r
F P
0 g
s
.49904 .51159 m .49904 .56718 L .49615 .55863 L p .707 .577 .707 r
F P
0 g
s
.49615 .55863 m .49615 .50305 L .49904 .51159 L p .707 .577 .707 r
F P
0 g
s
.71504 .6692 m .71504 .63215 L .74688 .63137 L p .707 .577 .707 r
F P
0 g
s
.49196 .63209 m .49196 .66915 L .49904 .66078 L p .707 .577 .707 r
F P
0 g
s
.49904 .66078 m .49904 .62373 L .49196 .63209 L p .707 .577 .707 r
F P
0 g
s
.68566 .73633 m .68566 .75486 L .66161 .76051 L p .707 .577 .707 r
F P
0 g
s
.47559 .74027 m .47559 .75879 L .49196 .75143 L p .707 .577 .707 r
F P
0 g
s
.49196 .75143 m .49196 .7329 L .47559 .74027 L p .707 .577 .707 r
F P
0 g
s
.74688 .63137 m .74688 .66843 L .71504 .6692 L p .707 .577 .707 r
F P
0 g
s
.80551 .73847 m .80551 .757 L .77805 .7526 L p .707 .577 .707 r
F P
0 g
s
.77805 .7526 m .77805 .73408 L .80551 .73847 L p .707 .577 .707 r
F P
0 g
s
.29515 .56354 m .29515 .50796 L .30223 .49959 L p .707 .577 .707 r
F P
0 g
s
.31064 .75585 m .31064 .73733 L .29804 .72944 L p .707 .577 .707 r
F P
0 g
s
.29804 .66569 m .29804 .62864 L .29515 .62009 L p .707 .577 .707 r
F P
0 g
s
.68566 .75486 m .68566 .73633 L .71504 .73295 L p .707 .577 .707 r
F P
0 g
s
.29804 .72944 m .29804 .74797 L .31064 .75585 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71504 .73295 m .71504 .75148 L .68566 .75486 L p .707 .577 .707 r
F P
0 g
s
.29515 .62009 m .29515 .65715 L .29804 .66569 L p .707 .577 .707 r
F P
0 g
s
.77805 .73408 m .77805 .7526 L .74688 .7507 L p .707 .577 .707 r
F P
0 g
s
.74688 .7507 m .74688 .73218 L .77805 .73408 L p .707 .577 .707 r
F P
0 g
s
.30223 .49959 m .30223 .55518 L .29515 .56354 L p .707 .577 .707 r
F P
0 g
s
.71504 .75148 m .71504 .73295 L .74688 .73218 L p .707 .577 .707 r
F P
0 g
s
.49196 .7329 m .49196 .75143 L .49904 .74306 L p .707 .577 .707 r
F P
0 g
s
.49904 .74306 m .49904 .72453 L .49196 .7329 L p .707 .577 .707 r
F P
0 g
s
.49615 .50305 m .49615 .55863 L .48356 .55075 L p .707 .577 .707 r
F P
0 g
s
.48356 .55075 m .48356 .49517 L .49615 .50305 L p .707 .577 .707 r
F P
0 g
s
.49904 .62373 m .49904 .66078 L .49615 .65224 L p .707 .577 .707 r
F P
0 g
s
.49615 .65224 m .49615 .61519 L .49904 .62373 L p .707 .577 .707 r
F P
0 g
s
.74688 .73218 m .74688 .7507 L .71504 .75148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29804 .74797 m .29804 .72944 L .29515 .7209 L p .707 .577 .707 r
F P
0 g
s
.30223 .55518 m .30223 .49959 L .3186 .49223 L p .707 .577 .707 r
F P
0 g
s
.29515 .65715 m .29515 .62009 L .30223 .61173 L p .707 .577 .707 r
F P
0 g
s
.29515 .7209 m .29515 .73943 L .29804 .74797 L p .707 .577 .707 r
F P
0 g
s
.30223 .61173 m .30223 .64878 L .29515 .65715 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .49223 m .3186 .54781 L .30223 .55518 L p .707 .577 .707 r
F P
0 g
s
.48356 .49517 m .48356 .55075 L .4625 .5443 L p .707 .577 .707 r
F P
0 g
s
.4625 .5443 m .4625 .48871 L .48356 .49517 L p .707 .577 .707 r
F P
0 g
s
.49904 .72453 m .49904 .74306 L .49615 .73452 L p .707 .577 .707 r
F P
0 g
s
.49615 .73452 m .49615 .71599 L .49904 .72453 L p .707 .577 .707 r
F P
0 g
s
.49615 .61519 m .49615 .65224 L .48356 .64436 L p .707 .577 .707 r
F P
0 g
s
.48356 .64436 m .48356 .6073 L .49615 .61519 L p .707 .577 .707 r
F P
0 g
s
.3186 .54781 m .3186 .49223 L .34265 .48658 L p .707 .577 .707 r
F P
0 g
s
.29515 .73943 m .29515 .7209 L .30223 .71253 L p .707 .577 .707 r
F P
0 g
s
.30223 .64878 m .30223 .61173 L .3186 .60436 L p .707 .577 .707 r
F P
0 g
s
.30223 .71253 m .30223 .73106 L .29515 .73943 L p .707 .577 .707 r
F P
0 g
s
.4625 .48871 m .4625 .5443 L .43504 .5399 L p .707 .577 .707 r
F P
0 g
s
.43504 .5399 m .43504 .48432 L .4625 .48871 L p .707 .577 .707 r
F P
0 g
s
.3186 .60436 m .3186 .64142 L .30223 .64878 L p .707 .577 .707 r
F P
0 g
s
.34265 .48658 m .34265 .54216 L .3186 .54781 L p .707 .577 .707 r
F P
0 g
s
.34265 .54216 m .34265 .48658 L .37203 .4832 L p .707 .577 .707 r
F P
0 g
s
.49615 .71599 m .49615 .73452 L .48356 .72664 L p .707 .577 .707 r
F P
0 g
s
.48356 .72664 m .48356 .70811 L .49615 .71599 L p .707 .577 .707 r
F P
0 g
s
.48356 .6073 m .48356 .64436 L .4625 .6379 L p .707 .577 .707 r
F P
0 g
s
.4625 .6379 m .4625 .60085 L .48356 .6073 L p .707 .577 .707 r
F P
0 g
s
.43504 .48432 m .43504 .5399 L .40387 .538 L p .707 .577 .707 r
F P
0 g
s
.40387 .538 m .40387 .48242 L .43504 .48432 L p .707 .577 .707 r
F P
0 g
s
.3186 .64142 m .3186 .60436 L .34265 .59871 L p .707 .577 .707 r
F P
0 g
s
.37203 .53878 m .37203 .4832 L .40387 .48242 L p .707 .577 .707 r
F P
0 g
s
.37203 .4832 m .37203 .53878 L .34265 .54216 L p .707 .577 .707 r
F P
0 g
s
.30223 .73106 m .30223 .71253 L .3186 .70517 L p .707 .577 .707 r
F P
0 g
s
.40387 .48242 m .40387 .538 L .37203 .53878 L p .707 .577 .707 r
F P
0 g
s
.3186 .70517 m .3186 .72369 L .30223 .73106 L p .707 .577 .707 r
F P
0 g
s
.34265 .59871 m .34265 .63577 L .3186 .64142 L p .707 .577 .707 r
F P
0 g
s
.4625 .60085 m .4625 .6379 L .43504 .63351 L p .707 .577 .707 r
F P
0 g
s
.43504 .63351 m .43504 .59646 L .4625 .60085 L p .707 .577 .707 r
F P
0 g
s
.48356 .70811 m .48356 .72664 L .4625 .72018 L p .707 .577 .707 r
F P
0 g
s
.4625 .72018 m .4625 .70165 L .48356 .70811 L p .707 .577 .707 r
F P
0 g
s
.34265 .63577 m .34265 .59871 L .37203 .59533 L p .707 .577 .707 r
F P
0 g
s
.3186 .72369 m .3186 .70517 L .34265 .69952 L p .707 .577 .707 r
F P
0 g
s
.43504 .59646 m .43504 .63351 L .40387 .63161 L p .707 .577 .707 r
F P
0 g
s
.40387 .63161 m .40387 .59456 L .43504 .59646 L p .707 .577 .707 r
F P
0 g
s
.37203 .59533 m .37203 .63239 L .34265 .63577 L p .707 .577 .707 r
F P
0 g
s
.37203 .63239 m .37203 .59533 L .40387 .59456 L p .707 .577 .707 r
F P
0 g
s
.34265 .69952 m .34265 .71804 L .3186 .72369 L p .707 .577 .707 r
F P
0 g
s
.40387 .59456 m .40387 .63161 L .37203 .63239 L p .707 .577 .707 r
F P
0 g
s
.4625 .70165 m .4625 .72018 L .43504 .71579 L p .707 .577 .707 r
F P
0 g
s
.43504 .71579 m .43504 .69726 L .4625 .70165 L p .707 .577 .707 r
F P
0 g
s
.34265 .71804 m .34265 .69952 L .37203 .69614 L p .707 .577 .707 r
F P
0 g
s
.37203 .69614 m .37203 .71467 L .34265 .71804 L p .707 .577 .707 r
F P
0 g
s
.43504 .69726 m .43504 .71579 L .40387 .71389 L p .707 .577 .707 r
F P
0 g
s
.40387 .71389 m .40387 .69536 L .43504 .69726 L p .707 .577 .707 r
F P
0 g
s
.37203 .71467 m .37203 .69614 L .40387 .69536 L p .707 .577 .707 r
F P
0 g
s
.40387 .69536 m .40387 .71389 L .37203 .71467 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF
00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo
001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006EooaP0
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00003goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00=JEPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001JEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF
FUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003mooaP00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000iOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF
1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YF
FUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP80
02eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF6`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
00=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0J0005FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000L000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP02FUH9000oOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQD00003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP0C0014Ool002aoo`03001JEP0000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH00eYF1P000UYF00<005YFFUH0
0eYF1@0015YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol002aoo`03001JEP0000AJEPD000MJEP03001JEUYF
00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUH0000400001EYF001JEUYF00000UYF
00<005YFFUH00eYF1@001EYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03001JEP00
009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00003
FUH:0002FUH01000FUIJEP001EYF10001UYF00<005YFFUH01eYF1P0000=JEP00FUH00UYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
03Aoo`00;7oo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00H005YF001JEP00FUH20005FUH00`00FUH0000300001EYF001JEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH00UYF1@001EYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH2
00000eYF001JEP04FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF
001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEUYFFUH90007Ool5000<Ool50004FUH01000FUIJEUYF0P00;Goo000dOol50006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF1`0000=JEP00FUH00UYF
0P001goo1@0047oo100000=JEP00FUH00UYF0P00;Goo000iOol40002FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH50002Ool50004FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02
FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF1P000eYF0P0027oo0`002Woo1`000eYF0`000eYF0P00;Goo000mOolI000<Ool8
0004FUH500000eYF000000070007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF2@002Goo2@000eYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000oOolG000?Ool01@00FUIJEP00FUH0
2P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000iOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000;Ool01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000eOol400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH50006OolB00000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0039oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000=JEP03
001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2000_Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000a
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF
00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP0000@0
00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF
00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000040005Ool40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03
001JEP0000=JEPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH400000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00003Goo6@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHC0004
Ool400000eYF001JEP020003FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002000FOol50018Ool002aoo`03001JEP00
00AJEP03001JEP0000<000ioo`D000Moo`05001JEP00001oo`060004FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF3@0000=JEP00000020001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1@004Woo0`00BGoo000/Ool00`00
FUH00003FUH4000AOol50007Ool40006Ool400001EYF001JEUYF00000UYF00<005YFFUH00eYF00<0
05YFFUH01UYF200035YF0`002EYF30001EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YF00000P001Goo6P00?7oo000/Ool01000FUH005YF0P0015YF1@003Goo0`0027oo0P00
0UYF1P000eYF0`000UYF00@005YFFUH000EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00QJEP<0
0003FUH005YF00UJEP03001JEUYF00QJEPL000IJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`06001J
EP00001JEP001EYF00@005YFFUIJEQX000=JEP03001JEP00008000=JEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEP0000<000YJEP03001JEUYF00EJEP<0009JEP03001JEP0000YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000AJEP@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000000=JEP03001JEUYF009JEPD0009JEP80009JEP03001JEUYF00=JEP8000=JEP03001JEUYF
00QJEP04001JEUYFFUH400000eYF001JEP02FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00
FUIJEP03FUH01000FUIJEUYF20000UYF0P001EYF00<005YFFUH01eYF1@001EYF00@005YFFUIJEP80
00]JEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH000020002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000aOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF
4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00MJEP04
001JEUYFFUH20002FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50004FUH00`00FUIJEP02FUH8
000@Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF
00<005YF00000P000UYF00@005YFFUIJEP8001Qoo`D000AJEP05001JEUYFFUH0000^Ool002ioo`80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH30006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
00030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20000
0eYF001JEP02FUH30005FUH01000FUIJEUYF0P007Goo0`0000=JEP00FUH00UYF0P00;Goo000`Ool3
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP0300000eYF
001JEP04FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000cOol300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002OolI00000eYF001J
EP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000003Ool40003FUH01000FUIJEUYF0P008Woo0P0000=JEP000000;Goo000fOol50004FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUH000030007Ool00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH300000eYF001oo`02Ool80003FUH2000QOol2000015YF00000000;Goo
000kOol80004FUH50005FUH00`00FUIJEP02FUH5000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30002FUH30005FUH01000FUIJEP000UYF0P007Woo0`000eYF0`00;Goo0013OolC
000AOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YFFUH01P000eYF10006Woo
100000=JEP00FUH00eYF00<005YF0000;Goo0017Ool5000LOol200000eYF001JEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH200001EYF001JEUYF00001EYF00<005YF00000`0000AJEP00000001Eoo`D000EJEP03001J
EUYF009JEP8002ioo`00Agoo2@006Woo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP04001JEUYF0005FUH0
0`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool003moo`P000AJEP03
001JEUYF009JEPP001=oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001JEP0015YF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002mo
o`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000moo`@0009JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@0
00=JEP03001JEUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080011oo`D000QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000MJEP03001JEUYF00EJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<001Moo`T000IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP/000AJEP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<005YFFUH00P007Woo3@000Woo
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP@000Yoo`T004Qoo`00;Goo0P0015YF00@005YFFUIJEPP001Uoo`H000AJEP05001JEUYFFUH0000`
Ool50004FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH7001OOol002aoo`03001JEP0000AJ
EP@002Moo`<00003FUH005YF009JEP03001oogoo03=ooa/006Ioo`00;7oo00<005YF00000UYF0P00
;Woo0P000eYF00<007ooOol0@7oo1@00Kgoo000/Ool00`00FUH00002000bOol01000FUIJEP00@Woo
1@00Kgoo000/Ool01000FUH00000=7oo0`00>Goo6000IGoo000/Ool20002FUH3000_Ool300000eYF
001oo`0bOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001QOol002aoo`80
00=JEP03001JEP00008002Uoo`<0009JEP03001JEP00031oo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@005eoo`00;7oo0P000eYF00<005YFFUH00UYF1@00
87oo100000=JEP00FUH00UYF00<005YF0000;Goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000FGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000/Ool200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001HOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000[Ool20004FUH00`00
FUIJEP02FUH6000BOol80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000aOol30003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
000/Ool00`00FUH00004FUH00`00FUH00002000POol50004FUH01@00FUIJEUYF0000EGoo000dOol5
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000_Ool00`00
FUH00003FUH3000XOol300000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF009JEPD003=oo`04001JEP00FUH2000^Ool20003FUH2001DOol003eo
oaT003Qoo`04001JEP00000bOol200000eYF0000001DOol008ioo`@003=oo`@005Aoo`00SWoo0P00
0UYF0P00;goo0P0000AJEP00000005Aoo`00SWoo0P000UYF00<005YF00000P009goo1@000eYF00<0
05YF0000E7oo002?Ool01000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?
Ool01000FUIJEP001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eo
o`00T7oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0
05Yoo`00Ugoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002L
Ool90004FUH00`00FUIJEP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77742 m .59613 .72184 L .56496 .71994 L p .707 .577 .707 r
F P
0 g
s
.59613 .72184 m .59613 .77742 L .62796 .77665 L p .707 .577 .707 r
F P
0 g
s
.62796 .77665 m .62796 .72106 L .59613 .72184 L p .707 .577 .707 r
F P
0 g
s
.62796 .72106 m .62796 .77665 L .65735 .77327 L p .707 .577 .707 r
F P
0 g
s
.65735 .77327 m .65734 .71768 L .62796 .72106 L p .707 .577 .707 r
F P
0 g
s
.56496 .77552 m .56496 .71994 L .5375 .71555 L p .707 .577 .707 r
F P
0 g
s
.56496 .71994 m .56496 .77552 L .59613 .77742 L p .707 .577 .707 r
F P
0 g
s
.59613 .80454 m .59613 .76749 L .56496 .76558 L p .707 .577 .707 r
F P
0 g
s
.59613 .76749 m .59613 .80454 L .62796 .80376 L p .707 .577 .707 r
F P
0 g
s
.62796 .80376 m .62796 .76671 L .59613 .76749 L p .707 .577 .707 r
F P
0 g
s
.65734 .71768 m .65735 .77327 L .6814 .76762 L p .707 .577 .707 r
F P
0 g
s
.6814 .76762 m .6814 .71203 L .65734 .71768 L p .707 .577 .707 r
F P
0 g
s
.62796 .76671 m .62796 .80376 L .65735 .80038 L p .707 .577 .707 r
F P
0 g
s
.65735 .80038 m .65735 .76333 L .62796 .76671 L p .707 .577 .707 r
F P
0 g
s
.59613 .80593 m .59613 .78741 L .56496 .7855 L p .707 .577 .707 r
F P
0 g
s
.59613 .78741 m .59613 .80593 L .62796 .80516 L p .707 .577 .707 r
F P
0 g
s
.62796 .80516 m .62796 .78663 L .59613 .78741 L p .707 .577 .707 r
F P
0 g
s
.56496 .80264 m .56496 .76558 L .5375 .76119 L p .707 .577 .707 r
F P
0 g
s
.56496 .76558 m .56496 .80264 L .59613 .80454 L p .707 .577 .707 r
F P
0 g
s
.62796 .78663 m .62796 .80516 L .65735 .80178 L p .707 .577 .707 r
F P
0 g
s
.65735 .80178 m .65735 .78325 L .62796 .78663 L p .707 .577 .707 r
F P
0 g
s
.5375 .71555 m .5375 .77113 L .56496 .77552 L p .707 .577 .707 r
F P
0 g
s
.5375 .77113 m .5375 .71555 L .51644 .70909 L p .707 .577 .707 r
F P
0 g
s
.56496 .7855 m .56496 .80403 L .59613 .80593 L p .707 .577 .707 r
F P
0 g
s
.56496 .80403 m .56496 .7855 L .5375 .78111 L p .707 .577 .707 r
F P
0 g
s
.65735 .76333 m .65735 .80038 L .6814 .79473 L p .707 .577 .707 r
F P
0 g
s
.6814 .79473 m .6814 .75768 L .65735 .76333 L p .707 .577 .707 r
F P
0 g
s
.5375 .76119 m .5375 .79825 L .56496 .80264 L p .707 .577 .707 r
F P
0 g
s
.5375 .78111 m .5375 .79964 L .56496 .80403 L p .707 .577 .707 r
F P
0 g
s
.65735 .78325 m .65735 .80178 L .6814 .79613 L p .707 .577 .707 r
F P
0 g
s
.6814 .79613 m .6814 .7776 L .65735 .78325 L p .707 .577 .707 r
F P
0 g
s
.6814 .71203 m .6814 .76762 L .69777 .76025 L p .707 .577 .707 r
F P
0 g
s
.69777 .76025 m .69777 .70467 L .6814 .71203 L p .707 .577 .707 r
F P
0 g
s
.5375 .79825 m .5375 .76119 L .51644 .75474 L p .707 .577 .707 r
F P
0 g
s
.51644 .70909 m .51644 .76468 L .5375 .77113 L p .707 .577 .707 r
F P
0 g
s
.5375 .79964 m .5375 .78111 L .51644 .77466 L p .707 .577 .707 r
F P
0 g
s
.51644 .75474 m .51644 .79179 L .5375 .79825 L p .707 .577 .707 r
F P
0 g
s
.51644 .76468 m .51644 .70909 L .50385 .70121 L p .707 .577 .707 r
F P
0 g
s
.51644 .77466 m .51644 .79319 L .5375 .79964 L p .707 .577 .707 r
F P
0 g
s
.6814 .75768 m .6814 .79473 L .69777 .78737 L p .707 .577 .707 r
F P
0 g
s
.69777 .78737 m .69777 .75031 L .6814 .75768 L p .707 .577 .707 r
F P
0 g
s
.6814 .7776 m .6814 .79613 L .69777 .78876 L p .707 .577 .707 r
F P
0 g
s
.69777 .78876 m .69777 .77023 L .6814 .7776 L p .707 .577 .707 r
F P
0 g
s
.51644 .79179 m .51644 .75474 L .50385 .74685 L p .707 .577 .707 r
F P
0 g
s
.50385 .70121 m .50385 .75679 L .51644 .76468 L p .707 .577 .707 r
F P
0 g
s
.69777 .70467 m .69777 .76025 L .70485 .75188 L p .707 .577 .707 r
F P
0 g
s
.70485 .75188 m .70485 .6963 L .69777 .70467 L p .707 .577 .707 r
F P
0 g
s
.51644 .79319 m .51644 .77466 L .50385 .76677 L p .707 .577 .707 r
F P
0 g
s
.50385 .74685 m .50385 .78391 L .51644 .79179 L p .707 .577 .707 r
F P
0 g
s
.50385 .76677 m .50385 .7853 L .51644 .79319 L p .707 .577 .707 r
F P
0 g
s
.50385 .75679 m .50385 .70121 L .50095 .69267 L p .707 .577 .707 r
F P
0 g
s
.69777 .75031 m .69777 .78737 L .70485 .779 L p .707 .577 .707 r
F P
0 g
s
.70485 .779 m .70485 .74195 L .69777 .75031 L p .707 .577 .707 r
F P
0 g
s
.69777 .77023 m .69777 .78876 L .70485 .7804 L p .707 .577 .707 r
F P
0 g
s
.70485 .7804 m .70485 .76187 L .69777 .77023 L p .707 .577 .707 r
F P
0 g
s
.50385 .78391 m .50385 .74685 L .50095 .73831 L p .707 .577 .707 r
F P
0 g
s
.50095 .69267 m .50095 .74825 L .50385 .75679 L p .707 .577 .707 r
F P
0 g
s
.70485 .6963 m .70485 .75188 L .70195 .74334 L p .707 .577 .707 r
F P
0 g
s
.70195 .74334 m .70195 .68776 L .70485 .6963 L p .707 .577 .707 r
F P
0 g
s
.50385 .7853 m .50385 .76677 L .50095 .75823 L p .707 .577 .707 r
F P
0 g
s
.50095 .73831 m .50095 .77537 L .50385 .78391 L p .707 .577 .707 r
F P
0 g
s
.50095 .75823 m .50095 .77676 L .50385 .7853 L p .707 .577 .707 r
F P
0 g
s
.49044 .83764 m .49044 .33575 L .44643 .33307 L p .707 .577 .707 r
F P
0 g
s
.50095 .74825 m .50095 .69267 L .50804 .6843 L p .707 .577 .707 r
F P
0 g
s
.50095 .77537 m .50095 .73831 L .50804 .72995 L p .707 .577 .707 r
F P
0 g
s
.50804 .6843 m .50804 .73989 L .50095 .74825 L p .707 .577 .707 r
F P
0 g
s
.50095 .77676 m .50095 .75823 L .50804 .74987 L p .707 .577 .707 r
F P
0 g
s
.50804 .72995 m .50804 .767 L .50095 .77537 L p .707 .577 .707 r
F P
0 g
s
.50804 .74987 m .50804 .7684 L .50095 .77676 L p .707 .577 .707 r
F P
0 g
s
.50804 .73989 m .50804 .6843 L .5244 .67694 L p .707 .577 .707 r
F P
0 g
s
.50804 .767 m .50804 .72995 L .5244 .72258 L p .707 .577 .707 r
F P
0 g
s
.5244 .67694 m .5244 .73252 L .50804 .73989 L p .707 .577 .707 r
F P
0 g
s
.50804 .7684 m .50804 .74987 L .5244 .7425 L p .707 .577 .707 r
F P
0 g
s
.5244 .72258 m .5244 .75963 L .50804 .767 L p .707 .577 .707 r
F P
0 g
s
.5244 .7425 m .5244 .76103 L .50804 .7684 L p .707 .577 .707 r
F P
0 g
s
.5244 .73252 m .5244 .67694 L .54846 .67129 L p .707 .577 .707 r
F P
0 g
s
.5244 .75963 m .5244 .72258 L .54846 .71693 L p .707 .577 .707 r
F P
0 g
s
.54846 .67129 m .54846 .72687 L .5244 .73252 L p .707 .577 .707 r
F P
0 g
s
.5244 .76103 m .5244 .7425 L .54846 .73685 L p .707 .577 .707 r
F P
0 g
s
.54846 .71693 m .54846 .75399 L .5244 .75963 L p .707 .577 .707 r
F P
0 g
s
.54846 .73685 m .54846 .75538 L .5244 .76103 L p .707 .577 .707 r
F P
0 g
s
.49044 .33575 m .49044 .83764 L .53538 .83654 L p .707 .577 .707 r
F P
0 g
s
.53538 .83654 m .53538 .33466 L .49044 .33575 L p .707 .577 .707 r
F P
0 g
s
.54846 .72687 m .54846 .67129 L .57784 .66791 L p .707 .577 .707 r
F P
0 g
s
.57784 .66791 m .57784 .72349 L .54846 .72687 L p .707 .577 .707 r
F P
0 g
s
.54846 .75399 m .54846 .71693 L .57784 .71355 L p .707 .577 .707 r
F P
0 g
s
.54846 .75538 m .54846 .73685 L .57784 .73347 L p .707 .577 .707 r
F P
0 g
s
.57784 .71355 m .57784 .75061 L .54846 .75399 L p .707 .577 .707 r
F P
0 g
s
.57784 .73347 m .57784 .752 L .54846 .75538 L p .707 .577 .707 r
F P
0 g
s
.53538 .33466 m .53538 .83654 L .57686 .83177 L p .707 .577 .707 r
F P
0 g
s
.57686 .83177 m .57686 .32989 L .53538 .33466 L p .707 .577 .707 r
F P
0 g
s
.70485 .74195 m .70485 .779 L .70195 .77046 L p .707 .577 .707 r
F P
0 g
s
.70195 .77046 m .70195 .73341 L .70485 .74195 L p .707 .577 .707 r
F P
0 g
s
.44643 .83496 m .44643 .33307 L .40766 .32687 L p .707 .577 .707 r
F P
0 g
s
.44643 .33307 m .44643 .83496 L .49044 .83764 L p .707 .577 .707 r
F P
0 g
s
.70485 .76187 m .70485 .7804 L .70195 .77185 L p .707 .577 .707 r
F P
0 g
s
.70195 .77185 m .70195 .75333 L .70485 .76187 L p .707 .577 .707 r
F P
0 g
s
.57784 .72349 m .57784 .66791 L .60968 .66713 L p .707 .577 .707 r
F P
0 g
s
.60968 .66713 m .60968 .72271 L .57784 .72349 L p .707 .577 .707 r
F P
0 g
s
.57784 .75061 m .57784 .71355 L .60968 .71277 L p .707 .577 .707 r
F P
0 g
s
.60968 .71277 m .60968 .74983 L .57784 .75061 L p .707 .577 .707 r
F P
0 g
s
.57784 .752 m .57784 .73347 L .60968 .73269 L p .707 .577 .707 r
F P
0 g
s
.60968 .73269 m .60968 .75122 L .57784 .752 L p .707 .577 .707 r
F P
0 g
s
.57686 .32989 m .57686 .83177 L .61082 .8238 L p .707 .577 .707 r
F P
0 g
s
.64085 .66903 m .64085 .72461 L .60968 .72271 L p .707 .577 .707 r
F P
0 g
s
.60968 .72271 m .60968 .66713 L .64085 .66903 L p .707 .577 .707 r
F P
0 g
s
.64085 .71467 m .64085 .75173 L .60968 .74983 L p .707 .577 .707 r
F P
0 g
s
.60968 .74983 m .60968 .71277 L .64085 .71467 L p .707 .577 .707 r
F P
0 g
s
.64085 .7346 m .64085 .75312 L .60968 .75122 L p .707 .577 .707 r
F P
0 g
s
.60968 .75122 m .60968 .73269 L .64085 .7346 L p .707 .577 .707 r
F P
0 g
s
.61082 .8238 m .61082 .32191 L .57686 .32989 L p .707 .577 .707 r
F P
0 g
s
.70195 .68776 m .70195 .74334 L .68936 .73546 L p .707 .577 .707 r
F P
0 g
s
.68936 .73546 m .68936 .67988 L .70195 .68776 L p .707 .577 .707 r
F P
0 g
s
.40766 .82876 m .40766 .32687 L .37794 .31776 L p .707 .577 .707 r
F P
0 g
s
.40766 .32687 m .40766 .82876 L .44643 .83496 L p .707 .577 .707 r
F P
0 g
s
.25312 .74061 m .25312 .68503 L .22195 .68312 L p .707 .577 .707 r
F P
0 g
s
.25312 .68503 m .25312 .74061 L .28495 .73983 L p .707 .577 .707 r
F P
0 g
s
.28495 .73983 m .28495 .68425 L .25312 .68503 L p .707 .577 .707 r
F P
0 g
s
.28495 .68425 m .28495 .73983 L .31434 .73645 L p .707 .577 .707 r
F P
0 g
s
.31434 .73645 m .31434 .68087 L .28495 .68425 L p .707 .577 .707 r
F P
0 g
s
.70195 .73341 m .70195 .77046 L .68936 .76258 L p .707 .577 .707 r
F P
0 g
s
.68936 .76258 m .68936 .72552 L .70195 .73341 L p .707 .577 .707 r
F P
0 g
s
.22195 .73871 m .22195 .68312 L .19449 .67873 L p .707 .577 .707 r
F P
0 g
s
.22195 .68312 m .22195 .73871 L .25312 .74061 L p .707 .577 .707 r
F P
0 g
s
.70195 .75333 m .70195 .77185 L .68936 .76397 L p .707 .577 .707 r
F P
0 g
s
.68936 .76397 m .68936 .74544 L .70195 .75333 L p .707 .577 .707 r
F P
0 g
s
.25312 .76772 m .25312 .73067 L .22195 .72877 L p .707 .577 .707 r
F P
0 g
s
.25312 .73067 m .25312 .76772 L .28495 .76695 L p .707 .577 .707 r
F P
0 g
s
.28495 .76695 m .28495 .72989 L .25312 .73067 L p .707 .577 .707 r
F P
0 g
s
.31434 .68087 m .31434 .73645 L .33839 .7308 L p .707 .577 .707 r
F P
0 g
s
.33839 .7308 m .33839 .67522 L .31434 .68087 L p .707 .577 .707 r
F P
0 g
s
.28495 .72989 m .28495 .76695 L .31434 .76357 L p .707 .577 .707 r
F P
0 g
s
.31434 .76357 m .31434 .72651 L .28495 .72989 L p .707 .577 .707 r
F P
0 g
s
.61082 .32191 m .61082 .8238 L .63393 .8134 L p .707 .577 .707 r
F P
0 g
s
.63393 .8134 m .63393 .31151 L .61082 .32191 L p .707 .577 .707 r
F P
0 g
s
.25312 .76912 m .25312 .75059 L .22195 .74869 L p .707 .577 .707 r
F P
0 g
s
.25312 .75059 m .25312 .76912 L .28495 .76834 L p .707 .577 .707 r
F P
0 g
s
.28495 .76834 m .28495 .74981 L .25312 .75059 L p .707 .577 .707 r
F P
0 g
s
.68936 .67988 m .68936 .73546 L .66831 .729 L p .707 .577 .707 r
F P
0 g
s
.66831 .729 m .66831 .67342 L .68936 .67988 L p .707 .577 .707 r
F P
0 g
s
.22195 .76582 m .22195 .72877 L .19449 .72438 L p .707 .577 .707 r
F P
0 g
s
.22195 .72877 m .22195 .76582 L .25312 .76772 L p .707 .577 .707 r
F P
0 g
s
.28495 .74981 m .28495 .76834 L .31434 .76496 L p .707 .577 .707 r
F P
0 g
s
.31434 .76496 m .31434 .74643 L .28495 .74981 L p .707 .577 .707 r
F P
0 g
s
.19449 .67873 m .19449 .73431 L .22195 .73871 L p .707 .577 .707 r
F P
0 g
s
.19449 .73431 m .19449 .67873 L .17343 .67228 L p .707 .577 .707 r
F P
0 g
s
.22195 .74869 m .22195 .76722 L .25312 .76912 L p .707 .577 .707 r
F P
0 g
s
.22195 .76722 m .22195 .74869 L .19449 .7443 L p .707 .577 .707 r
F P
0 g
s
.31434 .72651 m .31434 .76357 L .33839 .75792 L p .707 .577 .707 r
F P
0 g
s
.33839 .75792 m .33839 .72086 L .31434 .72651 L p .707 .577 .707 r
F P
0 g
s
.19449 .72438 m .19449 .76143 L .22195 .76582 L p .707 .577 .707 r
F P
0 g
s
.19449 .7443 m .19449 .76282 L .22195 .76722 L p .707 .577 .707 r
F P
0 g
s
.37794 .81965 m .37794 .31776 L .36016 .30663 L p .707 .577 .707 r
F P
0 g
s
.37794 .31776 m .37794 .81965 L .40766 .82876 L p .707 .577 .707 r
F P
0 g
s
.68936 .72552 m .68936 .76258 L .66831 .75612 L p .707 .577 .707 r
F P
0 g
s
.66831 .75612 m .66831 .71907 L .68936 .72552 L p .707 .577 .707 r
F P
0 g
s
.31434 .74643 m .31434 .76496 L .33839 .75931 L p .707 .577 .707 r
F P
0 g
s
.33839 .75931 m .33839 .74078 L .31434 .74643 L p .707 .577 .707 r
F P
0 g
s
.33839 .67522 m .33839 .7308 L .35476 .72343 L p .707 .577 .707 r
F P
0 g
s
.35476 .72343 m .35476 .66785 L .33839 .67522 L p .707 .577 .707 r
F P
0 g
s
.19449 .76143 m .19449 .72438 L .17343 .71792 L p .707 .577 .707 r
F P
0 g
s
.68936 .74544 m .68936 .76397 L .66831 .75751 L p .707 .577 .707 r
F P
0 g
s
.66831 .75751 m .66831 .73899 L .68936 .74544 L p .707 .577 .707 r
F P
0 g
s
.17343 .67228 m .17343 .72786 L .19449 .73431 L p .707 .577 .707 r
F P
0 g
s
.19449 .76282 m .19449 .7443 L .17343 .73784 L p .707 .577 .707 r
F P
0 g
s
.66831 .67342 m .66831 .729 L .64085 .72461 L p .707 .577 .707 r
F P
0 g
s
.64085 .72461 m .64085 .66903 L .66831 .67342 L p .707 .577 .707 r
F P
0 g
s
.17343 .71792 m .17343 .75498 L .19449 .76143 L p .707 .577 .707 r
F P
0 g
s
.17343 .72786 m .17343 .67228 L .16084 .66439 L p .707 .577 .707 r
F P
0 g
s
.17343 .73784 m .17343 .75637 L .19449 .76282 L p .707 .577 .707 r
F P
0 g
s
.33839 .72086 m .33839 .75792 L .35476 .75055 L p .707 .577 .707 r
F P
0 g
s
.35476 .75055 m .35476 .7135 L .33839 .72086 L p .707 .577 .707 r
F P
0 g
s
.66831 .71907 m .66831 .75612 L .64085 .75173 L p .707 .577 .707 r
F P
0 g
s
.64085 .75173 m .64085 .71467 L .66831 .71907 L p .707 .577 .707 r
F P
0 g
s
.66831 .73899 m .66831 .75751 L .64085 .75312 L p .707 .577 .707 r
F P
0 g
s
.64085 .75312 m .64085 .7346 L .66831 .73899 L p .707 .577 .707 r
F P
0 g
s
.63393 .31151 m .63393 .8134 L .64393 .80159 L p .707 .577 .707 r
F P
0 g
s
.64393 .80159 m .64393 .2997 L .63393 .31151 L p .707 .577 .707 r
F P
0 g
s
.33839 .74078 m .33839 .75931 L .35476 .75194 L p .707 .577 .707 r
F P
0 g
s
.35476 .75194 m .35476 .73342 L .33839 .74078 L p .707 .577 .707 r
F P
0 g
s
.17343 .75498 m .17343 .71792 L .16084 .71004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66439 m .16084 .71998 L .17343 .72786 L p .707 .577 .707 r
F P
0 g
s
.35476 .66785 m .35476 .72343 L .36184 .71507 L p .707 .577 .707 r
F P
0 g
s
.36184 .71507 m .36184 .65949 L .35476 .66785 L p .707 .577 .707 r
F P
0 g
s
.17343 .75637 m .17343 .73784 L .16084 .72996 L p .707 .577 .707 r
F P
0 g
s
.16084 .71004 m .16084 .74709 L .17343 .75498 L p .707 .577 .707 r
F P
0 g
s
.16084 .72996 m .16084 .74849 L .17343 .75637 L p .707 .577 .707 r
F P
0 g
s
.35476 .7135 m .35476 .75055 L .36184 .74219 L p .707 .577 .707 r
F P
0 g
s
.36184 .74219 m .36184 .70513 L .35476 .7135 L p .707 .577 .707 r
F P
0 g
s
.35476 .73342 m .35476 .75194 L .36184 .74358 L p .707 .577 .707 r
F P
0 g
s
.36184 .74358 m .36184 .72505 L .35476 .73342 L p .707 .577 .707 r
F P
0 g
s
.36184 .65949 m .36184 .71507 L .35894 .70653 L p .707 .577 .707 r
F P
0 g
s
.35894 .70653 m .35894 .65095 L .36184 .65949 L p .707 .577 .707 r
F P
0 g
s
.36184 .70513 m .36184 .74219 L .35894 .73364 L p .707 .577 .707 r
F P
0 g
s
.35894 .73364 m .35894 .69659 L .36184 .70513 L p .707 .577 .707 r
F P
0 g
s
.36184 .72505 m .36184 .74358 L .35894 .73504 L p .707 .577 .707 r
F P
0 g
s
.35894 .73504 m .35894 .71651 L .36184 .72505 L p .707 .577 .707 r
F P
0 g
s
.35894 .65095 m .35894 .70653 L .34635 .69864 L p .707 .577 .707 r
F P
0 g
s
.34635 .69864 m .34635 .64306 L .35894 .65095 L p .707 .577 .707 r
F P
0 g
s
.36016 .80852 m .36016 .30663 L .35607 .29457 L p .707 .577 .707 r
F P
0 g
s
.36016 .30663 m .36016 .80852 L .37794 .81965 L p .707 .577 .707 r
F P
0 g
s
.16084 .71998 m .16084 .66439 L .15794 .65585 L p .707 .577 .707 r
F P
0 g
s
.16084 .74709 m .16084 .71004 L .15794 .7015 L p .707 .577 .707 r
F P
0 g
s
.15794 .65585 m .15794 .71143 L .16084 .71998 L p .707 .577 .707 r
F P
0 g
s
.16084 .74849 m .16084 .72996 L .15794 .72142 L p .707 .577 .707 r
F P
0 g
s
.64393 .2997 m .64393 .80159 L .63984 .78953 L p .707 .577 .707 r
F P
0 g
s
.63984 .78953 m .63984 .28764 L .64393 .2997 L p .707 .577 .707 r
F P
0 g
s
.15794 .7015 m .15794 .73855 L .16084 .74709 L p .707 .577 .707 r
F P
0 g
s
.15794 .72142 m .15794 .73994 L .16084 .74849 L p .707 .577 .707 r
F P
0 g
s
.15794 .71143 m .15794 .65585 L .16503 .64749 L p .707 .577 .707 r
F P
0 g
s
.35894 .69659 m .35894 .73364 L .34635 .72576 L p .707 .577 .707 r
F P
0 g
s
.34635 .72576 m .34635 .68871 L .35894 .69659 L p .707 .577 .707 r
F P
0 g
s
.35894 .71651 m .35894 .73504 L .34635 .72715 L p .707 .577 .707 r
F P
0 g
s
.34635 .72715 m .34635 .70863 L .35894 .71651 L p .707 .577 .707 r
F P
0 g
s
.35607 .29457 m .35607 .79646 L .36016 .80852 L p .707 .577 .707 r
F P
0 g
s
.35607 .79646 m .35607 .29457 L .36607 .28276 L p .707 .577 .707 r
F P
0 g
s
.15794 .73855 m .15794 .7015 L .16503 .69313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .64749 m .16503 .70307 L .15794 .71143 L p .707 .577 .707 r
F P
0 g
s
.15794 .73994 m .15794 .72142 L .16503 .71305 L p .707 .577 .707 r
F P
0 g
s
.16503 .69313 m .16503 .73019 L .15794 .73855 L p .707 .577 .707 r
F P
0 g
s
.16503 .71305 m .16503 .73158 L .15794 .73994 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70307 m .16503 .64749 L .1814 .64012 L p .707 .577 .707 r
F P
0 g
s
.63984 .28764 m .63984 .78953 L .62206 .7784 L p .707 .577 .707 r
F P
0 g
s
.62206 .7784 m .62206 .27651 L .63984 .28764 L p .707 .577 .707 r
F P
0 g
s
.16503 .73019 m .16503 .69313 L .1814 .68576 L p .707 .577 .707 r
F P
0 g
s
.1814 .64012 m .1814 .6957 L .16503 .70307 L p .707 .577 .707 r
F P
0 g
s
.34635 .64306 m .34635 .69864 L .3253 .69219 L p .707 .577 .707 r
F P
0 g
s
.3253 .69219 m .3253 .63661 L .34635 .64306 L p .707 .577 .707 r
F P
0 g
s
.16503 .73158 m .16503 .71305 L .1814 .70569 L p .707 .577 .707 r
F P
0 g
s
.36607 .78465 m .36607 .28276 L .38918 .27236 L p .707 .577 .707 r
F P
0 g
s
.36607 .28276 m .36607 .78465 L .35607 .79646 L p .707 .577 .707 r
F P
0 g
s
.1814 .68576 m .1814 .72282 L .16503 .73019 L p .707 .577 .707 r
F P
0 g
s
.1814 .70569 m .1814 .72421 L .16503 .73158 L p .707 .577 .707 r
F P
0 g
s
.1814 .6957 m .1814 .64012 L .20545 .63447 L p .707 .577 .707 r
F P
0 g
s
.34635 .68871 m .34635 .72576 L .3253 .71931 L p .707 .577 .707 r
F P
0 g
s
.3253 .71931 m .3253 .68225 L .34635 .68871 L p .707 .577 .707 r
F P
0 g
s
.34635 .70863 m .34635 .72715 L .3253 .7207 L p .707 .577 .707 r
F P
0 g
s
.3253 .7207 m .3253 .70217 L .34635 .70863 L p .707 .577 .707 r
F P
0 g
s
.3253 .63661 m .3253 .69219 L .29784 .6878 L p .707 .577 .707 r
F P
0 g
s
.29784 .6878 m .29784 .63221 L .3253 .63661 L p .707 .577 .707 r
F P
0 g
s
.1814 .72282 m .1814 .68576 L .20545 .68011 L p .707 .577 .707 r
F P
0 g
s
.20545 .63447 m .20545 .69005 L .1814 .6957 L p .707 .577 .707 r
F P
0 g
s
.62206 .27651 m .62206 .7784 L .59233 .76929 L p .707 .577 .707 r
F P
0 g
s
.59233 .76929 m .59233 .2674 L .62206 .27651 L p .707 .577 .707 r
F P
0 g
s
.1814 .72421 m .1814 .70569 L .20545 .70004 L p .707 .577 .707 r
F P
0 g
s
.20545 .69005 m .20545 .63447 L .23483 .63109 L p .707 .577 .707 r
F P
0 g
s
.20545 .68011 m .20545 .71717 L .1814 .72282 L p .707 .577 .707 r
F P
0 g
s
.20545 .70004 m .20545 .71856 L .1814 .72421 L p .707 .577 .707 r
F P
0 g
s
.3253 .68225 m .3253 .71931 L .29784 .71491 L p .707 .577 .707 r
F P
0 g
s
.29784 .71491 m .29784 .67786 L .3253 .68225 L p .707 .577 .707 r
F P
0 g
s
.29784 .63221 m .29784 .6878 L .26667 .6859 L p .707 .577 .707 r
F P
0 g
s
.26667 .6859 m .26667 .63031 L .29784 .63221 L p .707 .577 .707 r
F P
0 g
s
.3253 .70217 m .3253 .7207 L .29784 .71631 L p .707 .577 .707 r
F P
0 g
s
.29784 .71631 m .29784 .69778 L .3253 .70217 L p .707 .577 .707 r
F P
0 g
s
.38918 .27236 m .38918 .77425 L .36607 .78465 L p .707 .577 .707 r
F P
0 g
s
.38918 .77425 m .38918 .27236 L .42314 .26438 L p .707 .577 .707 r
F P
0 g
s
.23483 .68667 m .23483 .63109 L .26667 .63031 L p .707 .577 .707 r
F P
0 g
s
.23483 .63109 m .23483 .68667 L .20545 .69005 L p .707 .577 .707 r
F P
0 g
s
.20545 .71717 m .20545 .68011 L .23483 .67674 L p .707 .577 .707 r
F P
0 g
s
.26667 .63031 m .26667 .6859 L .23483 .68667 L p .707 .577 .707 r
F P
0 g
s
.73333 .68538 m .73333 .6298 L .70216 .6279 L p .707 .577 .707 r
F P
0 g
s
.73333 .6298 m .73333 .68538 L .76517 .68461 L p .707 .577 .707 r
F P
0 g
s
.76517 .68461 m .76517 .62903 L .73333 .6298 L p .707 .577 .707 r
F P
0 g
s
.20545 .71856 m .20545 .70004 L .23483 .69666 L p .707 .577 .707 r
F P
0 g
s
.76517 .62903 m .76517 .68461 L .79455 .68123 L p .707 .577 .707 r
F P
0 g
s
.79455 .68123 m .79455 .62565 L .76517 .62903 L p .707 .577 .707 r
F P
0 g
s
.29784 .67786 m .29784 .71491 L .26667 .71301 L p .707 .577 .707 r
F P
0 g
s
.26667 .71301 m .26667 .67596 L .29784 .67786 L p .707 .577 .707 r
F P
0 g
s
.23483 .67674 m .23483 .71379 L .20545 .71717 L p .707 .577 .707 r
F P
0 g
s
.23483 .69666 m .23483 .71518 L .20545 .71856 L p .707 .577 .707 r
F P
0 g
s
.70216 .68348 m .70216 .6279 L .6747 .62351 L p .707 .577 .707 r
F P
0 g
s
.70216 .6279 m .70216 .68348 L .73333 .68538 L p .707 .577 .707 r
F P
0 g
s
.23483 .71379 m .23483 .67674 L .26667 .67596 L p .707 .577 .707 r
F P
0 g
s
.29784 .69778 m .29784 .71631 L .26667 .71441 L p .707 .577 .707 r
F P
0 g
s
.26667 .71441 m .26667 .69588 L .29784 .69778 L p .707 .577 .707 r
F P
0 g
s
.26667 .67596 m .26667 .71301 L .23483 .71379 L p .707 .577 .707 r
F P
0 g
s
.73333 .7125 m .73333 .67545 L .70216 .67355 L p .707 .577 .707 r
F P
0 g
s
.73333 .67545 m .73333 .7125 L .76517 .71172 L p .707 .577 .707 r
F P
0 g
s
.76517 .71172 m .76517 .67467 L .73333 .67545 L p .707 .577 .707 r
F P
0 g
s
.59233 .2674 m .59233 .76929 L .55357 .76309 L p .707 .577 .707 r
F P
0 g
s
.55357 .76309 m .55357 .2612 L .59233 .2674 L p .707 .577 .707 r
F P
0 g
s
.23483 .71518 m .23483 .69666 L .26667 .69588 L p .707 .577 .707 r
F P
0 g
s
.79455 .62565 m .79455 .68123 L .8186 .67558 L p .707 .577 .707 r
F P
0 g
s
.8186 .67558 m .8186 .62 L .79455 .62565 L p .707 .577 .707 r
F P
0 g
s
.76517 .67467 m .76517 .71172 L .79455 .70835 L p .707 .577 .707 r
F P
0 g
s
.79455 .70835 m .79455 .67129 L .76517 .67467 L p .707 .577 .707 r
F P
0 g
s
.26667 .69588 m .26667 .71441 L .23483 .71518 L p .707 .577 .707 r
F P
0 g
s
.73333 .71389 m .73333 .69537 L .70216 .69347 L p .707 .577 .707 r
F P
0 g
s
.73333 .69537 m .73333 .71389 L .76517 .71312 L p .707 .577 .707 r
F P
0 g
s
.76517 .71312 m .76517 .69459 L .73333 .69537 L p .707 .577 .707 r
F P
0 g
s
.70216 .7106 m .70216 .67355 L .6747 .66915 L p .707 .577 .707 r
F P
0 g
s
.70216 .67355 m .70216 .7106 L .73333 .7125 L p .707 .577 .707 r
F P
0 g
s
.76517 .69459 m .76517 .71312 L .79455 .70974 L p .707 .577 .707 r
F P
0 g
s
.79455 .70974 m .79455 .69121 L .76517 .69459 L p .707 .577 .707 r
F P
0 g
s
.6747 .62351 m .6747 .67909 L .70216 .68348 L p .707 .577 .707 r
F P
0 g
s
.6747 .67909 m .6747 .62351 L .65365 .61706 L p .707 .577 .707 r
F P
0 g
s
.70216 .69347 m .70216 .71199 L .73333 .71389 L p .707 .577 .707 r
F P
0 g
s
.42314 .76627 m .42314 .26438 L .46462 .25961 L p .707 .577 .707 r
F P
0 g
s
.42314 .26438 m .42314 .76627 L .38918 .77425 L p .707 .577 .707 r
F P
0 g
s
.70216 .71199 m .70216 .69347 L .6747 .68907 L p .707 .577 .707 r
F P
0 g
s
.79455 .67129 m .79455 .70835 L .8186 .7027 L p .707 .577 .707 r
F P
0 g
s
.8186 .7027 m .8186 .66564 L .79455 .67129 L p .707 .577 .707 r
F P
0 g
s
.6747 .66915 m .6747 .70621 L .70216 .7106 L p .707 .577 .707 r
F P
0 g
s
.6747 .68907 m .6747 .7076 L .70216 .71199 L p .707 .577 .707 r
F P
0 g
s
.79455 .69121 m .79455 .70974 L .8186 .70409 L p .707 .577 .707 r
F P
0 g
s
.8186 .70409 m .8186 .68556 L .79455 .69121 L p .707 .577 .707 r
F P
0 g
s
.8186 .62 m .8186 .67558 L .83497 .66821 L p .707 .577 .707 r
F P
0 g
s
.83497 .66821 m .83497 .61263 L .8186 .62 L p .707 .577 .707 r
F P
0 g
s
.6747 .70621 m .6747 .66915 L .65365 .6627 L p .707 .577 .707 r
F P
0 g
s
.55357 .2612 m .55357 .76309 L .50956 .7604 L p .707 .577 .707 r
F P
0 g
s
.50956 .7604 m .50956 .25851 L .55357 .2612 L p .707 .577 .707 r
F P
0 g
s
.65365 .61706 m .65365 .67264 L .6747 .67909 L p .707 .577 .707 r
F P
0 g
s
.6747 .7076 m .6747 .68907 L .65365 .68262 L p .707 .577 .707 r
F P
0 g
s
.46462 .7615 m .46462 .25961 L .50956 .25851 L p .707 .577 .707 r
F P
0 g
s
.46462 .25961 m .46462 .7615 L .42314 .76627 L p .707 .577 .707 r
F P
0 g
s
.50956 .25851 m .50956 .7604 L .46462 .7615 L p .707 .577 .707 r
F P
0 g
s
.65365 .6627 m .65365 .69975 L .6747 .70621 L p .707 .577 .707 r
F P
0 g
s
.65365 .67264 m .65365 .61706 L .64105 .60917 L p .707 .577 .707 r
F P
0 g
s
.65365 .68262 m .65365 .70115 L .6747 .7076 L p .707 .577 .707 r
F P
0 g
s
.8186 .66564 m .8186 .7027 L .83497 .69533 L p .707 .577 .707 r
F P
0 g
s
.83497 .69533 m .83497 .65827 L .8186 .66564 L p .707 .577 .707 r
F P
0 g
s
.8186 .68556 m .8186 .70409 L .83497 .69672 L p .707 .577 .707 r
F P
0 g
s
.83497 .69672 m .83497 .67819 L .8186 .68556 L p .707 .577 .707 r
F P
0 g
s
.65365 .69975 m .65365 .6627 L .64105 .65482 L p .707 .577 .707 r
F P
0 g
s
.64105 .60917 m .64105 .66475 L .65365 .67264 L p .707 .577 .707 r
F P
0 g
s
.83497 .61263 m .83497 .66821 L .84205 .65985 L p .707 .577 .707 r
F P
0 g
s
.84205 .65985 m .84205 .60426 L .83497 .61263 L p .707 .577 .707 r
F P
0 g
s
.65365 .70115 m .65365 .68262 L .64105 .67474 L p .707 .577 .707 r
F P
0 g
s
.64105 .65482 m .64105 .69187 L .65365 .69975 L p .707 .577 .707 r
F P
0 g
s
.64105 .67474 m .64105 .69326 L .65365 .70115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66475 m .64105 .60917 L .63816 .60063 L p .707 .577 .707 r
F P
0 g
s
.83497 .65827 m .83497 .69533 L .84206 .68696 L p .707 .577 .707 r
F P
0 g
s
.84206 .68696 m .84205 .64991 L .83497 .65827 L p .707 .577 .707 r
F P
0 g
s
.83497 .67819 m .83497 .69672 L .84206 .68836 L p .707 .577 .707 r
F P
0 g
s
.84206 .68836 m .84206 .66983 L .83497 .67819 L p .707 .577 .707 r
F P
0 g
s
.64105 .69187 m .64105 .65482 L .63816 .64627 L p .707 .577 .707 r
F P
0 g
s
.63816 .60063 m .63816 .65621 L .64105 .66475 L p .707 .577 .707 r
F P
0 g
s
.84205 .60426 m .84205 .65985 L .83916 .6513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6513 m .83916 .59572 L .84205 .60426 L p .707 .577 .707 r
F P
0 g
s
.64105 .69326 m .64105 .67474 L .63816 .66619 L p .707 .577 .707 r
F P
0 g
s
.63816 .64627 m .63816 .68333 L .64105 .69187 L p .707 .577 .707 r
F P
0 g
s
.63816 .66619 m .63816 .68472 L .64105 .69326 L p .707 .577 .707 r
F P
0 g
s
.84205 .64991 m .84206 .68696 L .83916 .67842 L p .707 .577 .707 r
F P
0 g
s
.83916 .67842 m .83916 .64137 L .84205 .64991 L p .707 .577 .707 r
F P
0 g
s
.63816 .65621 m .63816 .60063 L .64524 .59226 L p .707 .577 .707 r
F P
0 g
s
.84206 .66983 m .84206 .68836 L .83916 .67981 L p .707 .577 .707 r
F P
0 g
s
.83916 .67981 m .83916 .66129 L .84206 .66983 L p .707 .577 .707 r
F P
0 g
s
.63816 .68333 m .63816 .64627 L .64524 .63791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .59226 m .64524 .64785 L .63816 .65621 L p .707 .577 .707 r
F P
0 g
s
.83916 .59572 m .83916 .6513 L .82657 .64342 L p .707 .577 .707 r
F P
0 g
s
.82657 .64342 m .82657 .58784 L .83916 .59572 L p .707 .577 .707 r
F P
0 g
s
.63816 .68472 m .63816 .66619 L .64524 .65783 L p .707 .577 .707 r
F P
0 g
s
.64524 .63791 m .64524 .67496 L .63816 .68333 L p .707 .577 .707 r
F P
0 g
s
.64524 .65783 m .64524 .67636 L .63816 .68472 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64857 m .39032 .59299 L .35915 .59109 L p .707 .577 .707 r
F P
0 g
s
.39032 .59299 m .39032 .64857 L .42216 .64779 L p .707 .577 .707 r
F P
0 g
s
.42216 .64779 m .42216 .59221 L .39032 .59299 L p .707 .577 .707 r
F P
0 g
s
.64524 .64785 m .64524 .59226 L .66161 .5849 L p .707 .577 .707 r
F P
0 g
s
.42216 .59221 m .42216 .64779 L .45154 .64441 L p .707 .577 .707 r
F P
0 g
s
.45154 .64441 m .45154 .58883 L .42216 .59221 L p .707 .577 .707 r
F P
0 g
s
.83916 .64137 m .83916 .67842 L .82657 .67054 L p .707 .577 .707 r
F P
0 g
s
.82657 .67054 m .82657 .63348 L .83916 .64137 L p .707 .577 .707 r
F P
0 g
s
.35915 .64667 m .35915 .59109 L .33169 .58669 L p .707 .577 .707 r
F P
0 g
s
.35915 .59109 m .35915 .64667 L .39032 .64857 L p .707 .577 .707 r
F P
0 g
s
.83916 .66129 m .83916 .67981 L .82657 .67193 L p .707 .577 .707 r
F P
0 g
s
.82657 .67193 m .82657 .6534 L .83916 .66129 L p .707 .577 .707 r
F P
0 g
s
.39032 .67569 m .39032 .63863 L .35915 .63673 L p .707 .577 .707 r
F P
0 g
s
.39032 .63863 m .39032 .67569 L .42216 .67491 L p .707 .577 .707 r
F P
0 g
s
.42216 .67491 m .42216 .63785 L .39032 .63863 L p .707 .577 .707 r
F P
0 g
s
.45154 .58883 m .45154 .64441 L .47559 .63876 L p .707 .577 .707 r
F P
0 g
s
.47559 .63876 m .47559 .58318 L .45154 .58883 L p .707 .577 .707 r
F P
0 g
s
.64524 .67496 m .64524 .63791 L .66161 .63054 L p .707 .577 .707 r
F P
0 g
s
.42216 .63785 m .42216 .67491 L .45154 .67153 L p .707 .577 .707 r
F P
0 g
s
.45154 .67153 m .45154 .63448 L .42216 .63785 L p .707 .577 .707 r
F P
0 g
s
.66161 .5849 m .66161 .64048 L .64524 .64785 L p .707 .577 .707 r
F P
0 g
s
.39032 .67708 m .39032 .65855 L .35915 .65665 L p .707 .577 .707 r
F P
0 g
s
.39032 .65855 m .39032 .67708 L .42216 .6763 L p .707 .577 .707 r
F P
0 g
s
.42216 .6763 m .42216 .65777 L .39032 .65855 L p .707 .577 .707 r
F P
0 g
s
.82657 .58784 m .82657 .64342 L .80551 .63697 L p .707 .577 .707 r
F P
0 g
s
.80551 .63697 m .80551 .58138 L .82657 .58784 L p .707 .577 .707 r
F P
0 g
s
.35915 .67379 m .35915 .63673 L .33169 .63234 L p .707 .577 .707 r
F P
0 g
s
.35915 .63673 m .35915 .67379 L .39032 .67569 L p .707 .577 .707 r
F P
0 g
s
.64524 .67636 m .64524 .65783 L .66161 .65046 L p .707 .577 .707 r
F P
0 g
s
.42216 .65777 m .42216 .6763 L .45154 .67292 L p .707 .577 .707 r
F P
0 g
s
.45154 .67292 m .45154 .6544 L .42216 .65777 L p .707 .577 .707 r
F P
0 g
s
.33169 .58669 m .33169 .64228 L .35915 .64667 L p .707 .577 .707 r
F P
0 g
s
.33169 .64228 m .33169 .58669 L .31064 .58024 L p .707 .577 .707 r
F P
0 g
s
.35915 .65665 m .35915 .67518 L .39032 .67708 L p .707 .577 .707 r
F P
0 g
s
.35915 .67518 m .35915 .65665 L .33169 .65226 L p .707 .577 .707 r
F P
0 g
s
.66161 .63054 m .66161 .6676 L .64524 .67496 L p .707 .577 .707 r
F P
0 g
s
.66161 .65046 m .66161 .66899 L .64524 .67636 L p .707 .577 .707 r
F P
0 g
s
.45154 .63448 m .45154 .67153 L .47559 .66588 L p .707 .577 .707 r
F P
0 g
s
.47559 .66588 m .47559 .62883 L .45154 .63448 L p .707 .577 .707 r
F P
0 g
s
.66161 .64048 m .66161 .5849 L .68566 .57925 L p .707 .577 .707 r
F P
0 g
s
.33169 .63234 m .33169 .66939 L .35915 .67379 L p .707 .577 .707 r
F P
0 g
s
.33169 .65226 m .33169 .67079 L .35915 .67518 L p .707 .577 .707 r
F P
0 g
s
.82657 .63348 m .82657 .67054 L .80551 .66408 L p .707 .577 .707 r
F P
0 g
s
.80551 .66408 m .80551 .62703 L .82657 .63348 L p .707 .577 .707 r
F P
0 g
s
.45154 .6544 m .45154 .67292 L .47559 .66727 L p .707 .577 .707 r
F P
0 g
s
.47559 .66727 m .47559 .64875 L .45154 .6544 L p .707 .577 .707 r
F P
0 g
s
.47559 .58318 m .47559 .63876 L .49196 .6314 L p .707 .577 .707 r
F P
0 g
s
.49196 .6314 m .49196 .57581 L .47559 .58318 L p .707 .577 .707 r
F P
0 g
s
.33169 .66939 m .33169 .63234 L .31064 .62588 L p .707 .577 .707 r
F P
0 g
s
.82657 .6534 m .82657 .67193 L .80551 .66548 L p .707 .577 .707 r
F P
0 g
s
.80551 .66548 m .80551 .64695 L .82657 .6534 L p .707 .577 .707 r
F P
0 g
s
.31064 .58024 m .31064 .63582 L .33169 .64228 L p .707 .577 .707 r
F P
0 g
s
.33169 .67079 m .33169 .65226 L .31064 .6458 L p .707 .577 .707 r
F P
0 g
s
.80551 .58138 m .80551 .63697 L .77805 .63257 L p .707 .577 .707 r
F P
0 g
s
.77805 .63257 m .77805 .57699 L .80551 .58138 L p .707 .577 .707 r
F P
0 g
s
.66161 .6676 m .66161 .63054 L .68566 .62489 L p .707 .577 .707 r
F P
0 g
s
.68566 .57925 m .68566 .63483 L .66161 .64048 L p .707 .577 .707 r
F P
0 g
s
.31064 .62588 m .31064 .66294 L .33169 .66939 L p .707 .577 .707 r
F P
0 g
s
.31064 .63582 m .31064 .58024 L .29804 .57236 L p .707 .577 .707 r
F P
0 g
s
.31064 .6458 m .31064 .66433 L .33169 .67079 L p .707 .577 .707 r
F P
0 g
s
.66161 .66899 m .66161 .65046 L .68566 .64481 L p .707 .577 .707 r
F P
0 g
s
.47559 .62883 m .47559 .66588 L .49196 .65851 L p .707 .577 .707 r
F P
0 g
s
.49196 .65851 m .49196 .62146 L .47559 .62883 L p .707 .577 .707 r
F P
0 g
s
.68566 .63483 m .68566 .57925 L .71504 .57587 L p .707 .577 .707 r
F P
0 g
s
.68566 .62489 m .68566 .66195 L .66161 .6676 L p .707 .577 .707 r
F P
0 g
s
.68566 .64481 m .68566 .66334 L .66161 .66899 L p .707 .577 .707 r
F P
0 g
s
.47559 .64875 m .47559 .66727 L .49196 .65991 L p .707 .577 .707 r
F P
0 g
s
.49196 .65991 m .49196 .64138 L .47559 .64875 L p .707 .577 .707 r
F P
0 g
s
.80551 .62703 m .80551 .66408 L .77805 .65969 L p .707 .577 .707 r
F P
0 g
s
.77805 .65969 m .77805 .62264 L .80551 .62703 L p .707 .577 .707 r
F P
0 g
s
.77805 .57699 m .77805 .63257 L .74688 .63067 L p .707 .577 .707 r
F P
0 g
s
.74688 .63067 m .74688 .57509 L .77805 .57699 L p .707 .577 .707 r
F P
0 g
s
.31064 .66294 m .31064 .62588 L .29804 .618 L p .707 .577 .707 r
F P
0 g
s
.80551 .64695 m .80551 .66548 L .77805 .66108 L p .707 .577 .707 r
F P
0 g
s
.77805 .66108 m .77805 .64256 L .80551 .64695 L p .707 .577 .707 r
F P
0 g
s
.29804 .57236 m .29804 .62794 L .31064 .63582 L p .707 .577 .707 r
F P
0 g
s
.71504 .63145 m .71504 .57587 L .74688 .57509 L p .707 .577 .707 r
F P
0 g
s
.71504 .57587 m .71504 .63145 L .68566 .63483 L p .707 .577 .707 r
F P
0 g
s
.49196 .57581 m .49196 .6314 L .49904 .62303 L p .707 .577 .707 r
F P
0 g
s
.49904 .62303 m .49904 .56745 L .49196 .57581 L p .707 .577 .707 r
F P
0 g
s
.68566 .66195 m .68566 .62489 L .71504 .62151 L p .707 .577 .707 r
F P
0 g
s
.31064 .66433 m .31064 .6458 L .29804 .63792 L p .707 .577 .707 r
F P
0 g
s
.74688 .57509 m .74688 .63067 L .71504 .63145 L p .707 .577 .707 r
F P
0 g
s
.68566 .66334 m .68566 .64481 L .71504 .64143 L p .707 .577 .707 r
F P
0 g
s
.29804 .618 m .29804 .65506 L .31064 .66294 L p .707 .577 .707 r
F P
0 g
s
.29804 .63792 m .29804 .65645 L .31064 .66433 L p .707 .577 .707 r
F P
0 g
s
.77805 .62264 m .77805 .65969 L .74688 .65779 L p .707 .577 .707 r
F P
0 g
s
.74688 .65779 m .74688 .62074 L .77805 .62264 L p .707 .577 .707 r
F P
0 g
s
.71504 .62151 m .71504 .65857 L .68566 .66195 L p .707 .577 .707 r
F P
0 g
s
.71504 .64143 m .71504 .65996 L .68566 .66334 L p .707 .577 .707 r
F P
0 g
s
.29804 .62794 m .29804 .57236 L .29515 .56381 L p .707 .577 .707 r
F P
0 g
s
.71504 .65857 m .71504 .62151 L .74688 .62074 L p .707 .577 .707 r
F P
0 g
s
.49196 .62146 m .49196 .65851 L .49904 .65015 L p .707 .577 .707 r
F P
0 g
s
.49904 .65015 m .49904 .61309 L .49196 .62146 L p .707 .577 .707 r
F P
0 g
s
.77805 .64256 m .77805 .66108 L .74688 .65918 L p .707 .577 .707 r
F P
0 g
s
.74688 .65918 m .74688 .64066 L .77805 .64256 L p .707 .577 .707 r
F P
0 g
s
.74688 .62074 m .74688 .65779 L .71504 .65857 L p .707 .577 .707 r
F P
0 g
s
.71504 .65996 m .71504 .64143 L .74688 .64066 L p .707 .577 .707 r
F P
0 g
s
.49196 .64138 m .49196 .65991 L .49904 .65154 L p .707 .577 .707 r
F P
0 g
s
.49904 .65154 m .49904 .63301 L .49196 .64138 L p .707 .577 .707 r
F P
0 g
s
.74688 .64066 m .74688 .65918 L .71504 .65996 L p .707 .577 .707 r
F P
0 g
s
.29804 .65506 m .29804 .618 L .29515 .60946 L p .707 .577 .707 r
F P
0 g
s
.29515 .56381 m .29515 .6194 L .29804 .62794 L p .707 .577 .707 r
F P
0 g
s
.49904 .56745 m .49904 .62303 L .49615 .61449 L p .707 .577 .707 r
F P
0 g
s
.49615 .61449 m .49615 .55891 L .49904 .56745 L p .707 .577 .707 r
F P
0 g
s
.29804 .65645 m .29804 .63792 L .29515 .62938 L p .707 .577 .707 r
F P
0 g
s
.29515 .60946 m .29515 .64651 L .29804 .65506 L p .707 .577 .707 r
F P
0 g
s
.29515 .62938 m .29515 .64791 L .29804 .65645 L p .707 .577 .707 r
F P
0 g
s
.49904 .61309 m .49904 .65015 L .49615 .64161 L p .707 .577 .707 r
F P
0 g
s
.49615 .64161 m .49615 .60455 L .49904 .61309 L p .707 .577 .707 r
F P
0 g
s
.29515 .6194 m .29515 .56381 L .30223 .55545 L p .707 .577 .707 r
F P
0 g
s
.49904 .63301 m .49904 .65154 L .49615 .643 L p .707 .577 .707 r
F P
0 g
s
.49615 .643 m .49615 .62447 L .49904 .63301 L p .707 .577 .707 r
F P
0 g
s
.29515 .64651 m .29515 .60946 L .30223 .60109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55545 m .30223 .61103 L .29515 .6194 L p .707 .577 .707 r
F P
0 g
s
.49615 .55891 m .49615 .61449 L .48356 .6066 L p .707 .577 .707 r
F P
0 g
s
.48356 .6066 m .48356 .55102 L .49615 .55891 L p .707 .577 .707 r
F P
0 g
s
.29515 .64791 m .29515 .62938 L .30223 .62101 L p .707 .577 .707 r
F P
0 g
s
.30223 .60109 m .30223 .63815 L .29515 .64651 L p .707 .577 .707 r
F P
0 g
s
.30223 .62101 m .30223 .63954 L .29515 .64791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61103 m .30223 .55545 L .3186 .54808 L p .707 .577 .707 r
F P
0 g
s
.49615 .60455 m .49615 .64161 L .48356 .63372 L p .707 .577 .707 r
F P
0 g
s
.48356 .63372 m .48356 .59667 L .49615 .60455 L p .707 .577 .707 r
F P
0 g
s
.49615 .62447 m .49615 .643 L .48356 .63511 L p .707 .577 .707 r
F P
0 g
s
.48356 .63511 m .48356 .61659 L .49615 .62447 L p .707 .577 .707 r
F P
0 g
s
.30223 .63815 m .30223 .60109 L .3186 .59373 L p .707 .577 .707 r
F P
0 g
s
.3186 .54808 m .3186 .60366 L .30223 .61103 L p .707 .577 .707 r
F P
0 g
s
.48356 .55102 m .48356 .6066 L .4625 .60015 L p .707 .577 .707 r
F P
0 g
s
.4625 .60015 m .4625 .54457 L .48356 .55102 L p .707 .577 .707 r
F P
0 g
s
.30223 .63954 m .30223 .62101 L .3186 .61365 L p .707 .577 .707 r
F P
0 g
s
.3186 .59373 m .3186 .63078 L .30223 .63815 L p .707 .577 .707 r
F P
0 g
s
.3186 .61365 m .3186 .63217 L .30223 .63954 L p .707 .577 .707 r
F P
0 g
s
.3186 .60366 m .3186 .54808 L .34265 .54243 L p .707 .577 .707 r
F P
0 g
s
.48356 .59667 m .48356 .63372 L .4625 .62727 L p .707 .577 .707 r
F P
0 g
s
.4625 .62727 m .4625 .59021 L .48356 .59667 L p .707 .577 .707 r
F P
0 g
s
.48356 .61659 m .48356 .63511 L .4625 .62866 L p .707 .577 .707 r
F P
0 g
s
.4625 .62866 m .4625 .61013 L .48356 .61659 L p .707 .577 .707 r
F P
0 g
s
.4625 .54457 m .4625 .60015 L .43504 .59576 L p .707 .577 .707 r
F P
0 g
s
.43504 .59576 m .43504 .54018 L .4625 .54457 L p .707 .577 .707 r
F P
0 g
s
.3186 .63078 m .3186 .59373 L .34265 .58808 L p .707 .577 .707 r
F P
0 g
s
.34265 .54243 m .34265 .59801 L .3186 .60366 L p .707 .577 .707 r
F P
0 g
s
.3186 .63217 m .3186 .61365 L .34265 .608 L p .707 .577 .707 r
F P
0 g
s
.34265 .59801 m .34265 .54243 L .37203 .53905 L p .707 .577 .707 r
F P
0 g
s
.34265 .58808 m .34265 .62513 L .3186 .63078 L p .707 .577 .707 r
F P
0 g
s
.34265 .608 m .34265 .62652 L .3186 .63217 L p .707 .577 .707 r
F P
0 g
s
.4625 .59021 m .4625 .62727 L .43504 .62288 L p .707 .577 .707 r
F P
0 g
s
.43504 .62288 m .43504 .58582 L .4625 .59021 L p .707 .577 .707 r
F P
0 g
s
.43504 .54018 m .43504 .59576 L .40387 .59386 L p .707 .577 .707 r
F P
0 g
s
.40387 .59386 m .40387 .53828 L .43504 .54018 L p .707 .577 .707 r
F P
0 g
s
.4625 .61013 m .4625 .62866 L .43504 .62427 L p .707 .577 .707 r
F P
0 g
s
.43504 .62427 m .43504 .60574 L .4625 .61013 L p .707 .577 .707 r
F P
0 g
s
.37203 .59463 m .37203 .53905 L .40387 .53828 L p .707 .577 .707 r
F P
0 g
s
.37203 .53905 m .37203 .59463 L .34265 .59801 L p .707 .577 .707 r
F P
0 g
s
.34265 .62513 m .34265 .58808 L .37203 .5847 L p .707 .577 .707 r
F P
0 g
s
.40387 .53828 m .40387 .59386 L .37203 .59463 L p .707 .577 .707 r
F P
0 g
s
.34265 .62652 m .34265 .608 L .37203 .60462 L p .707 .577 .707 r
F P
0 g
s
.43504 .58582 m .43504 .62288 L .40387 .62097 L p .707 .577 .707 r
F P
0 g
s
.40387 .62097 m .40387 .58392 L .43504 .58582 L p .707 .577 .707 r
F P
0 g
s
.37203 .5847 m .37203 .62175 L .34265 .62513 L p .707 .577 .707 r
F P
0 g
s
.37203 .60462 m .37203 .62315 L .34265 .62652 L p .707 .577 .707 r
F P
0 g
s
.37203 .62175 m .37203 .5847 L .40387 .58392 L p .707 .577 .707 r
F P
0 g
s
.43504 .60574 m .43504 .62427 L .40387 .62237 L p .707 .577 .707 r
F P
0 g
s
.40387 .62237 m .40387 .60384 L .43504 .60574 L p .707 .577 .707 r
F P
0 g
s
.40387 .58392 m .40387 .62097 L .37203 .62175 L p .707 .577 .707 r
F P
0 g
s
.37203 .62315 m .37203 .60462 L .40387 .60384 L p .707 .577 .707 r
F P
0 g
s
.40387 .60384 m .40387 .62237 L .37203 .62315 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF
00UJEP03001JEUYF00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo
0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
3goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
07oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00004FUH40003FUH00`00FUIJEP05FUH>0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF100015YF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol30004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP8000=JEPT000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH4
0006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
03mooaD00003FUH005YF009JEPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001J
EP0000D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02FUH2000]Ool003Uoo`H000=J
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo
000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUH00000FUH005YF
00<00003FUH005YF00IJEQL000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH00000
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF5P000eYF
00<005YFFUH00eYF00<005YFFUH00`00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH20005FUH01000FUIJEUYF1@001eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8002eoo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000300000eYF001JEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1@0015YF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF1@0015YF00<005YF
FUH00UYF1`0000IJEP00000005YF0003FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH015YF1P0015YF3P000eYF00<005YFFUH015YF0`000eYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUH0000H0007
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000200001UYF00000000FUH000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000AJ
EP800003FUH0000000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05
001JEP00001JEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP040002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF
FUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<00003
FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF000015YF00@005YFFUIJEP800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800005FUH0
05YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0015YF4P000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00;Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF1@00
15YF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`04
001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool30004FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200001EYF001JEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD003=oo`00;7oo
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000h
Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90003FUH20004FUH9000oOol002ao
o`<000AJEP03001JEUYF00AJEP8000=JEQT000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YF
FUH01eYF00<005YFFUH015YF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH20007Ool50018Ool002aoo`03
001JEP0000AJEPD000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEP0000D00005
FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH00`00FUH0000200000eYF001JEP02FUH20007Ool50018Ool002aoo`03001JEP00009JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEPD000EJEP<0009JEP04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003
FUH20007Ool50018Ool002aoo`03001JEP0000<00006FUH00000001JEP001UYF60000eYF00<005YF
FUH015YF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH300000eYF00000008Ool30019Ool002aoo`03001JEP00009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP03001DOol002aoo`80009JEP8000EJEP03001JEUYF00<0
009JEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000<0009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@00003FUH005YF00AJ
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00800003FUH005YF00AJEP<000MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP@000=JEP04001JEUYFFUH2001DOol002ao
o`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP0000<00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00@000=JEP8005Aoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF009JEP@000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH20002FUH2001DOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YF00000`00E7oo000_Ool30005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1P00FUH00000Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0035oo`<000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50004FUH01000FUIJEUYF0P00
E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003
0006Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH015YF8@0025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF00<005YF00001@0000=JEP00FUH00UYF0P00E7oo000iOol4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP001EYF00<0
05YFFUH01UYF200035YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000010001EYF0`000eYF0P00E7oo000mOolI000?Ool01000FUIJEP001EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo0018Ool3000JOol01000FUIJEP001EYF00<005YF00000`002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP80
00=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP<00003FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP05001JEP00001JEP03001D
Ool004Moo`D001Uoo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00000UYF00@0
05YFFUIJEPD000=JEP03001JEP0005Aoo`00Agoo1@006Goo00D005YFFUH005YF008000MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH20002FUH00`00FUH000060003FUH00`00FUIJEP02FUH2001EOol004Qoo`<001Yoo`03001J
EUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00005FUH005YFFUH00006FUH00`00FUIJEP02
FUH2001EOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF
FUH00006FUH01000FUIJEUYF0P00EWoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH015YF00@005YF000005Qoo`00IGoo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF0000009JEP04001JEUYFFUH5001JOol006Eoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00L005moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH2001WOol006Moo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001WOol006Qoo`800003
FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8006Qoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Jgoo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YF000006aoo`00KGoo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF1000KWoo001aOol50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05001bOol007Ioo`H0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00=JEPP007Moo`00O7oo2@001UYF00<005YFFUH015YF3000Ogoo
0025Ool=002;Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79468 m .59613 .7391 L .56496 .7372 L p .707 .577 .707 r
F P
0 g
s
.59613 .7391 m .59613 .79468 L .62796 .79391 L p .707 .577 .707 r
F P
0 g
s
.62796 .79391 m .62796 .73832 L .59613 .7391 L p .707 .577 .707 r
F P
0 g
s
.62796 .73832 m .62796 .79391 L .65735 .79053 L p .707 .577 .707 r
F P
0 g
s
.65735 .79053 m .65734 .73494 L .62796 .73832 L p .707 .577 .707 r
F P
0 g
s
.59613 .77765 m .59613 .75912 L .56496 .75722 L p .707 .577 .707 r
F P
0 g
s
.59613 .75912 m .59613 .77765 L .62796 .77687 L p .707 .577 .707 r
F P
0 g
s
.62796 .77687 m .62796 .75835 L .59613 .75912 L p .707 .577 .707 r
F P
0 g
s
.56496 .79278 m .56496 .7372 L .5375 .73281 L p .707 .577 .707 r
F P
0 g
s
.56496 .7372 m .56496 .79278 L .59613 .79468 L p .707 .577 .707 r
F P
0 g
s
.59613 .80125 m .59613 .7642 L .56496 .7623 L p .707 .577 .707 r
F P
0 g
s
.59613 .7642 m .59613 .80125 L .62796 .80048 L p .707 .577 .707 r
F P
0 g
s
.62796 .80048 m .62796 .76342 L .59613 .7642 L p .707 .577 .707 r
F P
0 g
s
.62796 .75835 m .62796 .77687 L .65735 .7735 L p .707 .577 .707 r
F P
0 g
s
.65735 .7735 m .65735 .75497 L .62796 .75835 L p .707 .577 .707 r
F P
0 g
s
.62796 .76342 m .62796 .80048 L .65735 .7971 L p .707 .577 .707 r
F P
0 g
s
.65735 .7971 m .65735 .76004 L .62796 .76342 L p .707 .577 .707 r
F P
0 g
s
.56496 .75722 m .56496 .77575 L .59613 .77765 L p .707 .577 .707 r
F P
0 g
s
.56496 .77575 m .56496 .75722 L .5375 .75283 L p .707 .577 .707 r
F P
0 g
s
.56496 .79935 m .56496 .7623 L .5375 .75791 L p .707 .577 .707 r
F P
0 g
s
.56496 .7623 m .56496 .79935 L .59613 .80125 L p .707 .577 .707 r
F P
0 g
s
.65734 .73494 m .65735 .79053 L .6814 .78488 L p .707 .577 .707 r
F P
0 g
s
.6814 .78488 m .6814 .72929 L .65734 .73494 L p .707 .577 .707 r
F P
0 g
s
.5375 .75283 m .5375 .77136 L .56496 .77575 L p .707 .577 .707 r
F P
0 g
s
.65735 .75497 m .65735 .7735 L .6814 .76785 L p .707 .577 .707 r
F P
0 g
s
.6814 .76785 m .6814 .74932 L .65735 .75497 L p .707 .577 .707 r
F P
0 g
s
.65735 .76004 m .65735 .7971 L .6814 .79145 L p .707 .577 .707 r
F P
0 g
s
.6814 .79145 m .6814 .75439 L .65735 .76004 L p .707 .577 .707 r
F P
0 g
s
.5375 .73281 m .5375 .78839 L .56496 .79278 L p .707 .577 .707 r
F P
0 g
s
.5375 .78839 m .5375 .73281 L .51644 .72635 L p .707 .577 .707 r
F P
0 g
s
.5375 .75791 m .5375 .79496 L .56496 .79935 L p .707 .577 .707 r
F P
0 g
s
.5375 .77136 m .5375 .75283 L .51644 .74638 L p .707 .577 .707 r
F P
0 g
s
.5375 .79496 m .5375 .75791 L .51644 .75145 L p .707 .577 .707 r
F P
0 g
s
.51644 .74638 m .51644 .7649 L .5375 .77136 L p .707 .577 .707 r
F P
0 g
s
.6814 .72929 m .6814 .78488 L .69777 .77751 L p .707 .577 .707 r
F P
0 g
s
.69777 .77751 m .69777 .72193 L .6814 .72929 L p .707 .577 .707 r
F P
0 g
s
.51644 .72635 m .51644 .78194 L .5375 .78839 L p .707 .577 .707 r
F P
0 g
s
.51644 .75145 m .51644 .78851 L .5375 .79496 L p .707 .577 .707 r
F P
0 g
s
.6814 .74932 m .6814 .76785 L .69777 .76048 L p .707 .577 .707 r
F P
0 g
s
.69777 .76048 m .69777 .74195 L .6814 .74932 L p .707 .577 .707 r
F P
0 g
s
.6814 .75439 m .6814 .79145 L .69777 .78408 L p .707 .577 .707 r
F P
0 g
s
.69777 .78408 m .69777 .74702 L .6814 .75439 L p .707 .577 .707 r
F P
0 g
s
.51644 .78194 m .51644 .72635 L .50385 .71847 L p .707 .577 .707 r
F P
0 g
s
.51644 .7649 m .51644 .74638 L .50385 .73849 L p .707 .577 .707 r
F P
0 g
s
.51644 .78851 m .51644 .75145 L .50385 .74357 L p .707 .577 .707 r
F P
0 g
s
.50385 .73849 m .50385 .75702 L .51644 .7649 L p .707 .577 .707 r
F P
0 g
s
.50385 .71847 m .50385 .77405 L .51644 .78194 L p .707 .577 .707 r
F P
0 g
s
.69777 .72193 m .69777 .77751 L .70485 .76914 L p .707 .577 .707 r
F P
0 g
s
.70485 .76914 m .70485 .71356 L .69777 .72193 L p .707 .577 .707 r
F P
0 g
s
.50385 .74357 m .50385 .78062 L .51644 .78851 L p .707 .577 .707 r
F P
0 g
s
.69777 .74195 m .69777 .76048 L .70485 .75211 L p .707 .577 .707 r
F P
0 g
s
.70485 .75211 m .70485 .73359 L .69777 .74195 L p .707 .577 .707 r
F P
0 g
s
.69777 .74702 m .69777 .78408 L .70485 .77572 L p .707 .577 .707 r
F P
0 g
s
.70485 .77572 m .70485 .73866 L .69777 .74702 L p .707 .577 .707 r
F P
0 g
s
.50385 .77405 m .50385 .71847 L .50095 .70993 L p .707 .577 .707 r
F P
0 g
s
.50385 .75702 m .50385 .73849 L .50095 .72995 L p .707 .577 .707 r
F P
0 g
s
.50385 .78062 m .50385 .74357 L .50095 .73503 L p .707 .577 .707 r
F P
0 g
s
.50095 .72995 m .50095 .74848 L .50385 .75702 L p .707 .577 .707 r
F P
0 g
s
.50095 .70993 m .50095 .76551 L .50385 .77405 L p .707 .577 .707 r
F P
0 g
s
.50095 .73503 m .50095 .77208 L .50385 .78062 L p .707 .577 .707 r
F P
0 g
s
.70485 .71356 m .70485 .76914 L .70195 .7606 L p .707 .577 .707 r
F P
0 g
s
.70195 .7606 m .70195 .70502 L .70485 .71356 L p .707 .577 .707 r
F P
0 g
s
.49044 .84741 m .49044 .34552 L .44643 .34284 L p .707 .577 .707 r
F P
0 g
s
.50095 .76551 m .50095 .70993 L .50804 .70156 L p .707 .577 .707 r
F P
0 g
s
.50095 .74848 m .50095 .72995 L .50804 .72159 L p .707 .577 .707 r
F P
0 g
s
.50095 .77208 m .50095 .73503 L .50804 .72666 L p .707 .577 .707 r
F P
0 g
s
.50804 .72159 m .50804 .74011 L .50095 .74848 L p .707 .577 .707 r
F P
0 g
s
.50804 .70156 m .50804 .75715 L .50095 .76551 L p .707 .577 .707 r
F P
0 g
s
.50804 .72666 m .50804 .76372 L .50095 .77208 L p .707 .577 .707 r
F P
0 g
s
.50804 .75715 m .50804 .70156 L .5244 .6942 L p .707 .577 .707 r
F P
0 g
s
.50804 .74011 m .50804 .72159 L .5244 .71422 L p .707 .577 .707 r
F P
0 g
s
.50804 .76372 m .50804 .72666 L .5244 .71929 L p .707 .577 .707 r
F P
0 g
s
.5244 .71422 m .5244 .73275 L .50804 .74011 L p .707 .577 .707 r
F P
0 g
s
.5244 .6942 m .5244 .74978 L .50804 .75715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71929 m .5244 .75635 L .50804 .76372 L p .707 .577 .707 r
F P
0 g
s
.5244 .74978 m .5244 .6942 L .54846 .68855 L p .707 .577 .707 r
F P
0 g
s
.5244 .73275 m .5244 .71422 L .54846 .70857 L p .707 .577 .707 r
F P
0 g
s
.5244 .75635 m .5244 .71929 L .54846 .71364 L p .707 .577 .707 r
F P
0 g
s
.54846 .70857 m .54846 .7271 L .5244 .73275 L p .707 .577 .707 r
F P
0 g
s
.54846 .68855 m .54846 .74413 L .5244 .74978 L p .707 .577 .707 r
F P
0 g
s
.54846 .71364 m .54846 .7507 L .5244 .75635 L p .707 .577 .707 r
F P
0 g
s
.49044 .34552 m .49044 .84741 L .53538 .84631 L p .707 .577 .707 r
F P
0 g
s
.53538 .84631 m .53538 .34442 L .49044 .34552 L p .707 .577 .707 r
F P
0 g
s
.70485 .73359 m .70485 .75211 L .70195 .74357 L p .707 .577 .707 r
F P
0 g
s
.70195 .74357 m .70195 .72504 L .70485 .73359 L p .707 .577 .707 r
F P
0 g
s
.70485 .73866 m .70485 .77572 L .70195 .76717 L p .707 .577 .707 r
F P
0 g
s
.70195 .76717 m .70195 .73012 L .70485 .73866 L p .707 .577 .707 r
F P
0 g
s
.54846 .74413 m .54846 .68855 L .57784 .68517 L p .707 .577 .707 r
F P
0 g
s
.54846 .7271 m .54846 .70857 L .57784 .70519 L p .707 .577 .707 r
F P
0 g
s
.54846 .7507 m .54846 .71364 L .57784 .71026 L p .707 .577 .707 r
F P
0 g
s
.57784 .70519 m .57784 .72372 L .54846 .7271 L p .707 .577 .707 r
F P
0 g
s
.57784 .68517 m .57784 .74075 L .54846 .74413 L p .707 .577 .707 r
F P
0 g
s
.57784 .71026 m .57784 .74732 L .54846 .7507 L p .707 .577 .707 r
F P
0 g
s
.53538 .34442 m .53538 .84631 L .57686 .84154 L p .707 .577 .707 r
F P
0 g
s
.57686 .84154 m .57686 .33965 L .53538 .34442 L p .707 .577 .707 r
F P
0 g
s
.44643 .84473 m .44643 .34284 L .40766 .33664 L p .707 .577 .707 r
F P
0 g
s
.44643 .34284 m .44643 .84473 L .49044 .84741 L p .707 .577 .707 r
F P
0 g
s
.57784 .74075 m .57784 .68517 L .60968 .68439 L p .707 .577 .707 r
F P
0 g
s
.60968 .68439 m .60968 .73997 L .57784 .74075 L p .707 .577 .707 r
F P
0 g
s
.57784 .72372 m .57784 .70519 L .60968 .70441 L p .707 .577 .707 r
F P
0 g
s
.57784 .74732 m .57784 .71026 L .60968 .70949 L p .707 .577 .707 r
F P
0 g
s
.60968 .70441 m .60968 .72294 L .57784 .72372 L p .707 .577 .707 r
F P
0 g
s
.60968 .70949 m .60968 .74654 L .57784 .74732 L p .707 .577 .707 r
F P
0 g
s
.57686 .33965 m .57686 .84154 L .61082 .83357 L p .707 .577 .707 r
F P
0 g
s
.64085 .68629 m .64085 .74187 L .60968 .73997 L p .707 .577 .707 r
F P
0 g
s
.60968 .73997 m .60968 .68439 L .64085 .68629 L p .707 .577 .707 r
F P
0 g
s
.64085 .70631 m .64085 .72484 L .60968 .72294 L p .707 .577 .707 r
F P
0 g
s
.60968 .72294 m .60968 .70441 L .64085 .70631 L p .707 .577 .707 r
F P
0 g
s
.64085 .71139 m .64085 .74844 L .60968 .74654 L p .707 .577 .707 r
F P
0 g
s
.60968 .74654 m .60968 .70949 L .64085 .71139 L p .707 .577 .707 r
F P
0 g
s
.61082 .83357 m .61082 .33168 L .57686 .33965 L p .707 .577 .707 r
F P
0 g
s
.70195 .70502 m .70195 .7606 L .68936 .75272 L p .707 .577 .707 r
F P
0 g
s
.68936 .75272 m .68936 .69714 L .70195 .70502 L p .707 .577 .707 r
F P
0 g
s
.70195 .72504 m .70195 .74357 L .68936 .73569 L p .707 .577 .707 r
F P
0 g
s
.68936 .73569 m .68936 .71716 L .70195 .72504 L p .707 .577 .707 r
F P
0 g
s
.40766 .83852 m .40766 .33664 L .37794 .32752 L p .707 .577 .707 r
F P
0 g
s
.40766 .33664 m .40766 .83852 L .44643 .84473 L p .707 .577 .707 r
F P
0 g
s
.70195 .73012 m .70195 .76717 L .68936 .75929 L p .707 .577 .707 r
F P
0 g
s
.68936 .75929 m .68936 .72223 L .70195 .73012 L p .707 .577 .707 r
F P
0 g
s
.25312 .75787 m .25312 .70229 L .22195 .70038 L p .707 .577 .707 r
F P
0 g
s
.25312 .70229 m .25312 .75787 L .28495 .75709 L p .707 .577 .707 r
F P
0 g
s
.28495 .75709 m .28495 .70151 L .25312 .70229 L p .707 .577 .707 r
F P
0 g
s
.28495 .70151 m .28495 .75709 L .31434 .75371 L p .707 .577 .707 r
F P
0 g
s
.31434 .75371 m .31434 .69813 L .28495 .70151 L p .707 .577 .707 r
F P
0 g
s
.25312 .74084 m .25312 .72231 L .22195 .72041 L p .707 .577 .707 r
F P
0 g
s
.25312 .72231 m .25312 .74084 L .28495 .74006 L p .707 .577 .707 r
F P
0 g
s
.28495 .74006 m .28495 .72153 L .25312 .72231 L p .707 .577 .707 r
F P
0 g
s
.22195 .75597 m .22195 .70038 L .19449 .69599 L p .707 .577 .707 r
F P
0 g
s
.22195 .70038 m .22195 .75597 L .25312 .75787 L p .707 .577 .707 r
F P
0 g
s
.25312 .76444 m .25312 .72738 L .22195 .72548 L p .707 .577 .707 r
F P
0 g
s
.25312 .72738 m .25312 .76444 L .28495 .76366 L p .707 .577 .707 r
F P
0 g
s
.28495 .76366 m .28495 .72661 L .25312 .72738 L p .707 .577 .707 r
F P
0 g
s
.28495 .72153 m .28495 .74006 L .31434 .73668 L p .707 .577 .707 r
F P
0 g
s
.31434 .73668 m .31434 .71815 L .28495 .72153 L p .707 .577 .707 r
F P
0 g
s
.28495 .72661 m .28495 .76366 L .31434 .76028 L p .707 .577 .707 r
F P
0 g
s
.31434 .76028 m .31434 .72323 L .28495 .72661 L p .707 .577 .707 r
F P
0 g
s
.22195 .72041 m .22195 .73894 L .25312 .74084 L p .707 .577 .707 r
F P
0 g
s
.22195 .73894 m .22195 .72041 L .19449 .71602 L p .707 .577 .707 r
F P
0 g
s
.61082 .33168 m .61082 .83357 L .63393 .82316 L p .707 .577 .707 r
F P
0 g
s
.63393 .82316 m .63393 .32128 L .61082 .33168 L p .707 .577 .707 r
F P
0 g
s
.22195 .76254 m .22195 .72548 L .19449 .72109 L p .707 .577 .707 r
F P
0 g
s
.22195 .72548 m .22195 .76254 L .25312 .76444 L p .707 .577 .707 r
F P
0 g
s
.31434 .69813 m .31434 .75371 L .33839 .74806 L p .707 .577 .707 r
F P
0 g
s
.33839 .74806 m .33839 .69248 L .31434 .69813 L p .707 .577 .707 r
F P
0 g
s
.19449 .71602 m .19449 .73454 L .22195 .73894 L p .707 .577 .707 r
F P
0 g
s
.68936 .69714 m .68936 .75272 L .66831 .74626 L p .707 .577 .707 r
F P
0 g
s
.66831 .74626 m .66831 .69068 L .68936 .69714 L p .707 .577 .707 r
F P
0 g
s
.31434 .71815 m .31434 .73668 L .33839 .73103 L p .707 .577 .707 r
F P
0 g
s
.33839 .73103 m .33839 .7125 L .31434 .71815 L p .707 .577 .707 r
F P
0 g
s
.31434 .72323 m .31434 .76028 L .33839 .75463 L p .707 .577 .707 r
F P
0 g
s
.33839 .75463 m .33839 .71758 L .31434 .72323 L p .707 .577 .707 r
F P
0 g
s
.19449 .69599 m .19449 .75157 L .22195 .75597 L p .707 .577 .707 r
F P
0 g
s
.19449 .75157 m .19449 .69599 L .17343 .68954 L p .707 .577 .707 r
F P
0 g
s
.68936 .71716 m .68936 .73569 L .66831 .72923 L p .707 .577 .707 r
F P
0 g
s
.66831 .72923 m .66831 .71071 L .68936 .71716 L p .707 .577 .707 r
F P
0 g
s
.19449 .72109 m .19449 .75815 L .22195 .76254 L p .707 .577 .707 r
F P
0 g
s
.68936 .72223 m .68936 .75929 L .66831 .75284 L p .707 .577 .707 r
F P
0 g
s
.66831 .75284 m .66831 .71578 L .68936 .72223 L p .707 .577 .707 r
F P
0 g
s
.19449 .73454 m .19449 .71602 L .17343 .70956 L p .707 .577 .707 r
F P
0 g
s
.37794 .82941 m .37794 .32752 L .36016 .31639 L p .707 .577 .707 r
F P
0 g
s
.37794 .32752 m .37794 .82941 L .40766 .83852 L p .707 .577 .707 r
F P
0 g
s
.19449 .75815 m .19449 .72109 L .17343 .71464 L p .707 .577 .707 r
F P
0 g
s
.17343 .70956 m .17343 .72809 L .19449 .73454 L p .707 .577 .707 r
F P
0 g
s
.33839 .69248 m .33839 .74806 L .35476 .74069 L p .707 .577 .707 r
F P
0 g
s
.35476 .74069 m .35476 .68511 L .33839 .69248 L p .707 .577 .707 r
F P
0 g
s
.17343 .68954 m .17343 .74512 L .19449 .75157 L p .707 .577 .707 r
F P
0 g
s
.17343 .71464 m .17343 .75169 L .19449 .75815 L p .707 .577 .707 r
F P
0 g
s
.33839 .7125 m .33839 .73103 L .35476 .72366 L p .707 .577 .707 r
F P
0 g
s
.35476 .72366 m .35476 .70514 L .33839 .7125 L p .707 .577 .707 r
F P
0 g
s
.66831 .69068 m .66831 .74626 L .64085 .74187 L p .707 .577 .707 r
F P
0 g
s
.64085 .74187 m .64085 .68629 L .66831 .69068 L p .707 .577 .707 r
F P
0 g
s
.33839 .71758 m .33839 .75463 L .35476 .74726 L p .707 .577 .707 r
F P
0 g
s
.35476 .74726 m .35476 .71021 L .33839 .71758 L p .707 .577 .707 r
F P
0 g
s
.17343 .74512 m .17343 .68954 L .16084 .68165 L p .707 .577 .707 r
F P
0 g
s
.66831 .71071 m .66831 .72923 L .64085 .72484 L p .707 .577 .707 r
F P
0 g
s
.64085 .72484 m .64085 .70631 L .66831 .71071 L p .707 .577 .707 r
F P
0 g
s
.66831 .71578 m .66831 .75284 L .64085 .74844 L p .707 .577 .707 r
F P
0 g
s
.64085 .74844 m .64085 .71139 L .66831 .71578 L p .707 .577 .707 r
F P
0 g
s
.63393 .32128 m .63393 .82316 L .64393 .81136 L p .707 .577 .707 r
F P
0 g
s
.64393 .81136 m .64393 .30947 L .63393 .32128 L p .707 .577 .707 r
F P
0 g
s
.17343 .72809 m .17343 .70956 L .16084 .70168 L p .707 .577 .707 r
F P
0 g
s
.17343 .75169 m .17343 .71464 L .16084 .70675 L p .707 .577 .707 r
F P
0 g
s
.16084 .70168 m .16084 .72021 L .17343 .72809 L p .707 .577 .707 r
F P
0 g
s
.16084 .68165 m .16084 .73724 L .17343 .74512 L p .707 .577 .707 r
F P
0 g
s
.35476 .68511 m .35476 .74069 L .36184 .73233 L p .707 .577 .707 r
F P
0 g
s
.36184 .73233 m .36184 .67675 L .35476 .68511 L p .707 .577 .707 r
F P
0 g
s
.16084 .70675 m .16084 .74381 L .17343 .75169 L p .707 .577 .707 r
F P
0 g
s
.35476 .70514 m .35476 .72366 L .36184 .7153 L p .707 .577 .707 r
F P
0 g
s
.36184 .7153 m .36184 .69677 L .35476 .70514 L p .707 .577 .707 r
F P
0 g
s
.35476 .71021 m .35476 .74726 L .36184 .7389 L p .707 .577 .707 r
F P
0 g
s
.36184 .7389 m .36184 .70185 L .35476 .71021 L p .707 .577 .707 r
F P
0 g
s
.36184 .67675 m .36184 .73233 L .35894 .72379 L p .707 .577 .707 r
F P
0 g
s
.35894 .72379 m .35894 .66821 L .36184 .67675 L p .707 .577 .707 r
F P
0 g
s
.36184 .69677 m .36184 .7153 L .35894 .70676 L p .707 .577 .707 r
F P
0 g
s
.35894 .70676 m .35894 .68823 L .36184 .69677 L p .707 .577 .707 r
F P
0 g
s
.36184 .70185 m .36184 .7389 L .35894 .73036 L p .707 .577 .707 r
F P
0 g
s
.35894 .73036 m .35894 .6933 L .36184 .70185 L p .707 .577 .707 r
F P
0 g
s
.36016 .81828 m .36016 .31639 L .35607 .30433 L p .707 .577 .707 r
F P
0 g
s
.36016 .31639 m .36016 .81828 L .37794 .82941 L p .707 .577 .707 r
F P
0 g
s
.16084 .73724 m .16084 .68165 L .15794 .67311 L p .707 .577 .707 r
F P
0 g
s
.16084 .72021 m .16084 .70168 L .15794 .69314 L p .707 .577 .707 r
F P
0 g
s
.16084 .74381 m .16084 .70675 L .15794 .69821 L p .707 .577 .707 r
F P
0 g
s
.15794 .69314 m .15794 .71166 L .16084 .72021 L p .707 .577 .707 r
F P
0 g
s
.15794 .67311 m .15794 .72869 L .16084 .73724 L p .707 .577 .707 r
F P
0 g
s
.15794 .69821 m .15794 .73526 L .16084 .74381 L p .707 .577 .707 r
F P
0 g
s
.64393 .30947 m .64393 .81136 L .63984 .7993 L p .707 .577 .707 r
F P
0 g
s
.63984 .7993 m .63984 .29741 L .64393 .30947 L p .707 .577 .707 r
F P
0 g
s
.15794 .72869 m .15794 .67311 L .16503 .66475 L p .707 .577 .707 r
F P
0 g
s
.15794 .71166 m .15794 .69314 L .16503 .68477 L p .707 .577 .707 r
F P
0 g
s
.15794 .73526 m .15794 .69821 L .16503 .68985 L p .707 .577 .707 r
F P
0 g
s
.35894 .66821 m .35894 .72379 L .34635 .7159 L p .707 .577 .707 r
F P
0 g
s
.34635 .7159 m .34635 .66032 L .35894 .66821 L p .707 .577 .707 r
F P
0 g
s
.35894 .68823 m .35894 .70676 L .34635 .69887 L p .707 .577 .707 r
F P
0 g
s
.34635 .69887 m .34635 .68034 L .35894 .68823 L p .707 .577 .707 r
F P
0 g
s
.35894 .6933 m .35894 .73036 L .34635 .72247 L p .707 .577 .707 r
F P
0 g
s
.34635 .72247 m .34635 .68542 L .35894 .6933 L p .707 .577 .707 r
F P
0 g
s
.35607 .30433 m .35607 .80622 L .36016 .81828 L p .707 .577 .707 r
F P
0 g
s
.35607 .80622 m .35607 .30433 L .36607 .29253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .68477 m .16503 .7033 L .15794 .71166 L p .707 .577 .707 r
F P
0 g
s
.16503 .66475 m .16503 .72033 L .15794 .72869 L p .707 .577 .707 r
F P
0 g
s
.16503 .68985 m .16503 .7269 L .15794 .73526 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72033 m .16503 .66475 L .1814 .65738 L p .707 .577 .707 r
F P
0 g
s
.63984 .29741 m .63984 .7993 L .62206 .78817 L p .707 .577 .707 r
F P
0 g
s
.62206 .78817 m .62206 .28628 L .63984 .29741 L p .707 .577 .707 r
F P
0 g
s
.16503 .7033 m .16503 .68477 L .1814 .6774 L p .707 .577 .707 r
F P
0 g
s
.16503 .7269 m .16503 .68985 L .1814 .68248 L p .707 .577 .707 r
F P
0 g
s
.1814 .6774 m .1814 .69593 L .16503 .7033 L p .707 .577 .707 r
F P
0 g
s
.1814 .65738 m .1814 .71296 L .16503 .72033 L p .707 .577 .707 r
F P
0 g
s
.34635 .66032 m .34635 .7159 L .3253 .70945 L p .707 .577 .707 r
F P
0 g
s
.3253 .70945 m .3253 .65387 L .34635 .66032 L p .707 .577 .707 r
F P
0 g
s
.1814 .68248 m .1814 .71953 L .16503 .7269 L p .707 .577 .707 r
F P
0 g
s
.36607 .79441 m .36607 .29253 L .38918 .28212 L p .707 .577 .707 r
F P
0 g
s
.36607 .29253 m .36607 .79441 L .35607 .80622 L p .707 .577 .707 r
F P
0 g
s
.34635 .68034 m .34635 .69887 L .3253 .69242 L p .707 .577 .707 r
F P
0 g
s
.3253 .69242 m .3253 .67389 L .34635 .68034 L p .707 .577 .707 r
F P
0 g
s
.34635 .68542 m .34635 .72247 L .3253 .71602 L p .707 .577 .707 r
F P
0 g
s
.3253 .71602 m .3253 .67896 L .34635 .68542 L p .707 .577 .707 r
F P
0 g
s
.1814 .71296 m .1814 .65738 L .20545 .65173 L p .707 .577 .707 r
F P
0 g
s
.1814 .69593 m .1814 .6774 L .20545 .67175 L p .707 .577 .707 r
F P
0 g
s
.1814 .71953 m .1814 .68248 L .20545 .67683 L p .707 .577 .707 r
F P
0 g
s
.20545 .67175 m .20545 .69028 L .1814 .69593 L p .707 .577 .707 r
F P
0 g
s
.3253 .65387 m .3253 .70945 L .29784 .70506 L p .707 .577 .707 r
F P
0 g
s
.29784 .70506 m .29784 .64947 L .3253 .65387 L p .707 .577 .707 r
F P
0 g
s
.62206 .28628 m .62206 .78817 L .59233 .77905 L p .707 .577 .707 r
F P
0 g
s
.59233 .77905 m .59233 .27716 L .62206 .28628 L p .707 .577 .707 r
F P
0 g
s
.20545 .65173 m .20545 .70731 L .1814 .71296 L p .707 .577 .707 r
F P
0 g
s
.20545 .67683 m .20545 .71388 L .1814 .71953 L p .707 .577 .707 r
F P
0 g
s
.3253 .67389 m .3253 .69242 L .29784 .68803 L p .707 .577 .707 r
F P
0 g
s
.29784 .68803 m .29784 .6695 L .3253 .67389 L p .707 .577 .707 r
F P
0 g
s
.3253 .67896 m .3253 .71602 L .29784 .71163 L p .707 .577 .707 r
F P
0 g
s
.29784 .71163 m .29784 .67457 L .3253 .67896 L p .707 .577 .707 r
F P
0 g
s
.20545 .70731 m .20545 .65173 L .23483 .64835 L p .707 .577 .707 r
F P
0 g
s
.20545 .69028 m .20545 .67175 L .23483 .66838 L p .707 .577 .707 r
F P
0 g
s
.20545 .71388 m .20545 .67683 L .23483 .67345 L p .707 .577 .707 r
F P
0 g
s
.29784 .64947 m .29784 .70506 L .26667 .70316 L p .707 .577 .707 r
F P
0 g
s
.26667 .70316 m .26667 .64757 L .29784 .64947 L p .707 .577 .707 r
F P
0 g
s
.38918 .28212 m .38918 .78401 L .36607 .79441 L p .707 .577 .707 r
F P
0 g
s
.38918 .78401 m .38918 .28212 L .42314 .27415 L p .707 .577 .707 r
F P
0 g
s
.23483 .66838 m .23483 .6869 L .20545 .69028 L p .707 .577 .707 r
F P
0 g
s
.23483 .70393 m .23483 .64835 L .26667 .64757 L p .707 .577 .707 r
F P
0 g
s
.23483 .64835 m .23483 .70393 L .20545 .70731 L p .707 .577 .707 r
F P
0 g
s
.29784 .6695 m .29784 .68803 L .26667 .68613 L p .707 .577 .707 r
F P
0 g
s
.26667 .68613 m .26667 .6676 L .29784 .6695 L p .707 .577 .707 r
F P
0 g
s
.26667 .64757 m .26667 .70316 L .23483 .70393 L p .707 .577 .707 r
F P
0 g
s
.29784 .67457 m .29784 .71163 L .26667 .70973 L p .707 .577 .707 r
F P
0 g
s
.26667 .70973 m .26667 .67267 L .29784 .67457 L p .707 .577 .707 r
F P
0 g
s
.73333 .70264 m .73333 .64706 L .70216 .64516 L p .707 .577 .707 r
F P
0 g
s
.73333 .64706 m .73333 .70264 L .76517 .70187 L p .707 .577 .707 r
F P
0 g
s
.76517 .70187 m .76517 .64629 L .73333 .64706 L p .707 .577 .707 r
F P
0 g
s
.23483 .67345 m .23483 .7105 L .20545 .71388 L p .707 .577 .707 r
F P
0 g
s
.23483 .6869 m .23483 .66838 L .26667 .6676 L p .707 .577 .707 r
F P
0 g
s
.23483 .7105 m .23483 .67345 L .26667 .67267 L p .707 .577 .707 r
F P
0 g
s
.76517 .64629 m .76517 .70187 L .79455 .69849 L p .707 .577 .707 r
F P
0 g
s
.79455 .69849 m .79455 .64291 L .76517 .64629 L p .707 .577 .707 r
F P
0 g
s
.26667 .6676 m .26667 .68613 L .23483 .6869 L p .707 .577 .707 r
F P
0 g
s
.26667 .67267 m .26667 .70973 L .23483 .7105 L p .707 .577 .707 r
F P
0 g
s
.73333 .68561 m .73333 .66709 L .70216 .66519 L p .707 .577 .707 r
F P
0 g
s
.73333 .66709 m .73333 .68561 L .76517 .68484 L p .707 .577 .707 r
F P
0 g
s
.76517 .68484 m .76517 .66631 L .73333 .66709 L p .707 .577 .707 r
F P
0 g
s
.70216 .70074 m .70216 .64516 L .6747 .64077 L p .707 .577 .707 r
F P
0 g
s
.70216 .64516 m .70216 .70074 L .73333 .70264 L p .707 .577 .707 r
F P
0 g
s
.73333 .70922 m .73333 .67216 L .70216 .67026 L p .707 .577 .707 r
F P
0 g
s
.73333 .67216 m .73333 .70922 L .76517 .70844 L p .707 .577 .707 r
F P
0 g
s
.76517 .70844 m .76517 .67138 L .73333 .67216 L p .707 .577 .707 r
F P
0 g
s
.76517 .66631 m .76517 .68484 L .79455 .68146 L p .707 .577 .707 r
F P
0 g
s
.79455 .68146 m .79455 .66293 L .76517 .66631 L p .707 .577 .707 r
F P
0 g
s
.76517 .67138 m .76517 .70844 L .79455 .70506 L p .707 .577 .707 r
F P
0 g
s
.79455 .70506 m .79455 .668 L .76517 .67138 L p .707 .577 .707 r
F P
0 g
s
.70216 .66519 m .70216 .68371 L .73333 .68561 L p .707 .577 .707 r
F P
0 g
s
.59233 .27716 m .59233 .77905 L .55357 .77285 L p .707 .577 .707 r
F P
0 g
s
.55357 .77285 m .55357 .27096 L .59233 .27716 L p .707 .577 .707 r
F P
0 g
s
.70216 .68371 m .70216 .66519 L .6747 .66079 L p .707 .577 .707 r
F P
0 g
s
.70216 .70731 m .70216 .67026 L .6747 .66587 L p .707 .577 .707 r
F P
0 g
s
.70216 .67026 m .70216 .70731 L .73333 .70922 L p .707 .577 .707 r
F P
0 g
s
.79455 .64291 m .79455 .69849 L .8186 .69284 L p .707 .577 .707 r
F P
0 g
s
.8186 .69284 m .8186 .63726 L .79455 .64291 L p .707 .577 .707 r
F P
0 g
s
.6747 .66079 m .6747 .67932 L .70216 .68371 L p .707 .577 .707 r
F P
0 g
s
.79455 .66293 m .79455 .68146 L .8186 .67581 L p .707 .577 .707 r
F P
0 g
s
.8186 .67581 m .8186 .65728 L .79455 .66293 L p .707 .577 .707 r
F P
0 g
s
.42314 .77604 m .42314 .27415 L .46462 .26938 L p .707 .577 .707 r
F P
0 g
s
.42314 .27415 m .42314 .77604 L .38918 .78401 L p .707 .577 .707 r
F P
0 g
s
.79455 .668 m .79455 .70506 L .8186 .69941 L p .707 .577 .707 r
F P
0 g
s
.8186 .69941 m .8186 .66235 L .79455 .668 L p .707 .577 .707 r
F P
0 g
s
.6747 .64077 m .6747 .69635 L .70216 .70074 L p .707 .577 .707 r
F P
0 g
s
.6747 .69635 m .6747 .64077 L .65365 .63432 L p .707 .577 .707 r
F P
0 g
s
.6747 .66587 m .6747 .70292 L .70216 .70731 L p .707 .577 .707 r
F P
0 g
s
.6747 .67932 m .6747 .66079 L .65365 .65434 L p .707 .577 .707 r
F P
0 g
s
.6747 .70292 m .6747 .66587 L .65365 .65941 L p .707 .577 .707 r
F P
0 g
s
.55357 .27096 m .55357 .77285 L .50956 .77017 L p .707 .577 .707 r
F P
0 g
s
.50956 .77017 m .50956 .26828 L .55357 .27096 L p .707 .577 .707 r
F P
0 g
s
.65365 .65434 m .65365 .67287 L .6747 .67932 L p .707 .577 .707 r
F P
0 g
s
.8186 .63726 m .8186 .69284 L .83497 .68547 L p .707 .577 .707 r
F P
0 g
s
.83497 .68547 m .83497 .62989 L .8186 .63726 L p .707 .577 .707 r
F P
0 g
s
.65365 .63432 m .65365 .6899 L .6747 .69635 L p .707 .577 .707 r
F P
0 g
s
.46462 .77127 m .46462 .26938 L .50956 .26828 L p .707 .577 .707 r
F P
0 g
s
.46462 .26938 m .46462 .77127 L .42314 .77604 L p .707 .577 .707 r
F P
0 g
s
.65365 .65941 m .65365 .69647 L .6747 .70292 L p .707 .577 .707 r
F P
0 g
s
.8186 .65728 m .8186 .67581 L .83497 .66844 L p .707 .577 .707 r
F P
0 g
s
.83497 .66844 m .83497 .64991 L .8186 .65728 L p .707 .577 .707 r
F P
0 g
s
.8186 .66235 m .8186 .69941 L .83497 .69204 L p .707 .577 .707 r
F P
0 g
s
.83497 .69204 m .83497 .65499 L .8186 .66235 L p .707 .577 .707 r
F P
0 g
s
.50956 .26828 m .50956 .77017 L .46462 .77127 L p .707 .577 .707 r
F P
0 g
s
.65365 .6899 m .65365 .63432 L .64105 .62643 L p .707 .577 .707 r
F P
0 g
s
.65365 .67287 m .65365 .65434 L .64105 .64646 L p .707 .577 .707 r
F P
0 g
s
.65365 .69647 m .65365 .65941 L .64105 .65153 L p .707 .577 .707 r
F P
0 g
s
.64105 .64646 m .64105 .66498 L .65365 .67287 L p .707 .577 .707 r
F P
0 g
s
.64105 .62643 m .64105 .68201 L .65365 .6899 L p .707 .577 .707 r
F P
0 g
s
.83497 .62989 m .83497 .68547 L .84206 .67711 L p .707 .577 .707 r
F P
0 g
s
.84206 .67711 m .84205 .62152 L .83497 .62989 L p .707 .577 .707 r
F P
0 g
s
.64105 .65153 m .64105 .68858 L .65365 .69647 L p .707 .577 .707 r
F P
0 g
s
.83497 .64991 m .83497 .66844 L .84205 .66008 L p .707 .577 .707 r
F P
0 g
s
.84205 .66008 m .84205 .64155 L .83497 .64991 L p .707 .577 .707 r
F P
0 g
s
.83497 .65499 m .83497 .69204 L .84206 .68368 L p .707 .577 .707 r
F P
0 g
s
.84206 .68368 m .84205 .64662 L .83497 .65499 L p .707 .577 .707 r
F P
0 g
s
.64105 .68201 m .64105 .62643 L .63816 .61789 L p .707 .577 .707 r
F P
0 g
s
.64105 .66498 m .64105 .64646 L .63816 .63791 L p .707 .577 .707 r
F P
0 g
s
.64105 .68858 m .64105 .65153 L .63816 .64299 L p .707 .577 .707 r
F P
0 g
s
.63816 .63791 m .63816 .65644 L .64105 .66498 L p .707 .577 .707 r
F P
0 g
s
.63816 .61789 m .63816 .67347 L .64105 .68201 L p .707 .577 .707 r
F P
0 g
s
.63816 .64299 m .63816 .68004 L .64105 .68858 L p .707 .577 .707 r
F P
0 g
s
.84205 .62152 m .84206 .67711 L .83916 .66856 L p .707 .577 .707 r
F P
0 g
s
.83916 .66856 m .83916 .61298 L .84205 .62152 L p .707 .577 .707 r
F P
0 g
s
.84205 .64155 m .84205 .66008 L .83916 .65153 L p .707 .577 .707 r
F P
0 g
s
.83916 .65153 m .83916 .63301 L .84205 .64155 L p .707 .577 .707 r
F P
0 g
s
.84205 .64662 m .84206 .68368 L .83916 .67513 L p .707 .577 .707 r
F P
0 g
s
.83916 .67513 m .83916 .63808 L .84205 .64662 L p .707 .577 .707 r
F P
0 g
s
.63816 .67347 m .63816 .61789 L .64524 .60952 L p .707 .577 .707 r
F P
0 g
s
.63816 .65644 m .63816 .63791 L .64524 .62955 L p .707 .577 .707 r
F P
0 g
s
.63816 .68004 m .63816 .64299 L .64524 .63462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .62955 m .64524 .64808 L .63816 .65644 L p .707 .577 .707 r
F P
0 g
s
.64524 .60952 m .64524 .66511 L .63816 .67347 L p .707 .577 .707 r
F P
0 g
s
.64524 .63462 m .64524 .67168 L .63816 .68004 L p .707 .577 .707 r
F P
0 g
s
.83916 .61298 m .83916 .66856 L .82657 .66068 L p .707 .577 .707 r
F P
0 g
s
.82657 .66068 m .82657 .6051 L .83916 .61298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63301 m .83916 .65153 L .82657 .64365 L p .707 .577 .707 r
F P
0 g
s
.82657 .64365 m .82657 .62512 L .83916 .63301 L p .707 .577 .707 r
F P
0 g
s
.83916 .63808 m .83916 .67513 L .82657 .66725 L p .707 .577 .707 r
F P
0 g
s
.82657 .66725 m .82657 .6302 L .83916 .63808 L p .707 .577 .707 r
F P
0 g
s
.39032 .66583 m .39032 .61025 L .35915 .60835 L p .707 .577 .707 r
F P
0 g
s
.39032 .61025 m .39032 .66583 L .42216 .66505 L p .707 .577 .707 r
F P
0 g
s
.42216 .66505 m .42216 .60947 L .39032 .61025 L p .707 .577 .707 r
F P
0 g
s
.64524 .66511 m .64524 .60952 L .66161 .60216 L p .707 .577 .707 r
F P
0 g
s
.42216 .60947 m .42216 .66505 L .45154 .66167 L p .707 .577 .707 r
F P
0 g
s
.45154 .66167 m .45154 .60609 L .42216 .60947 L p .707 .577 .707 r
F P
0 g
s
.39032 .6488 m .39032 .63027 L .35915 .62837 L p .707 .577 .707 r
F P
0 g
s
.39032 .63027 m .39032 .6488 L .42216 .64802 L p .707 .577 .707 r
F P
0 g
s
.42216 .64802 m .42216 .62949 L .39032 .63027 L p .707 .577 .707 r
F P
0 g
s
.35915 .66393 m .35915 .60835 L .33169 .60395 L p .707 .577 .707 r
F P
0 g
s
.35915 .60835 m .35915 .66393 L .39032 .66583 L p .707 .577 .707 r
F P
0 g
s
.39032 .6724 m .39032 .63534 L .35915 .63344 L p .707 .577 .707 r
F P
0 g
s
.39032 .63534 m .39032 .6724 L .42216 .67162 L p .707 .577 .707 r
F P
0 g
s
.42216 .67162 m .42216 .63457 L .39032 .63534 L p .707 .577 .707 r
F P
0 g
s
.64524 .64808 m .64524 .62955 L .66161 .62218 L p .707 .577 .707 r
F P
0 g
s
.42216 .62949 m .42216 .64802 L .45154 .64464 L p .707 .577 .707 r
F P
0 g
s
.45154 .64464 m .45154 .62611 L .42216 .62949 L p .707 .577 .707 r
F P
0 g
s
.64524 .67168 m .64524 .63462 L .66161 .62725 L p .707 .577 .707 r
F P
0 g
s
.42216 .63457 m .42216 .67162 L .45154 .66824 L p .707 .577 .707 r
F P
0 g
s
.45154 .66824 m .45154 .63119 L .42216 .63457 L p .707 .577 .707 r
F P
0 g
s
.35915 .62837 m .35915 .6469 L .39032 .6488 L p .707 .577 .707 r
F P
0 g
s
.35915 .6469 m .35915 .62837 L .33169 .62398 L p .707 .577 .707 r
F P
0 g
s
.66161 .62218 m .66161 .64071 L .64524 .64808 L p .707 .577 .707 r
F P
0 g
s
.35915 .6705 m .35915 .63344 L .33169 .62905 L p .707 .577 .707 r
F P
0 g
s
.35915 .63344 m .35915 .6705 L .39032 .6724 L p .707 .577 .707 r
F P
0 g
s
.45154 .60609 m .45154 .66167 L .47559 .65602 L p .707 .577 .707 r
F P
0 g
s
.47559 .65602 m .47559 .60044 L .45154 .60609 L p .707 .577 .707 r
F P
0 g
s
.33169 .62398 m .33169 .64251 L .35915 .6469 L p .707 .577 .707 r
F P
0 g
s
.66161 .60216 m .66161 .65774 L .64524 .66511 L p .707 .577 .707 r
F P
0 g
s
.82657 .6051 m .82657 .66068 L .80551 .65423 L p .707 .577 .707 r
F P
0 g
s
.80551 .65423 m .80551 .59864 L .82657 .6051 L p .707 .577 .707 r
F P
0 g
s
.66161 .62725 m .66161 .66431 L .64524 .67168 L p .707 .577 .707 r
F P
0 g
s
.45154 .62611 m .45154 .64464 L .47559 .63899 L p .707 .577 .707 r
F P
0 g
s
.47559 .63899 m .47559 .62046 L .45154 .62611 L p .707 .577 .707 r
F P
0 g
s
.45154 .63119 m .45154 .66824 L .47559 .66259 L p .707 .577 .707 r
F P
0 g
s
.47559 .66259 m .47559 .62554 L .45154 .63119 L p .707 .577 .707 r
F P
0 g
s
.33169 .60395 m .33169 .65954 L .35915 .66393 L p .707 .577 .707 r
F P
0 g
s
.33169 .65954 m .33169 .60395 L .31064 .5975 L p .707 .577 .707 r
F P
0 g
s
.82657 .62512 m .82657 .64365 L .80551 .6372 L p .707 .577 .707 r
F P
0 g
s
.80551 .6372 m .80551 .61867 L .82657 .62512 L p .707 .577 .707 r
F P
0 g
s
.33169 .62905 m .33169 .66611 L .35915 .6705 L p .707 .577 .707 r
F P
0 g
s
.82657 .6302 m .82657 .66725 L .80551 .6608 L p .707 .577 .707 r
F P
0 g
s
.80551 .6608 m .80551 .62374 L .82657 .6302 L p .707 .577 .707 r
F P
0 g
s
.33169 .64251 m .33169 .62398 L .31064 .61752 L p .707 .577 .707 r
F P
0 g
s
.66161 .65774 m .66161 .60216 L .68566 .59651 L p .707 .577 .707 r
F P
0 g
s
.33169 .66611 m .33169 .62905 L .31064 .6226 L p .707 .577 .707 r
F P
0 g
s
.31064 .61752 m .31064 .63605 L .33169 .64251 L p .707 .577 .707 r
F P
0 g
s
.66161 .64071 m .66161 .62218 L .68566 .61653 L p .707 .577 .707 r
F P
0 g
s
.47559 .60044 m .47559 .65602 L .49196 .64866 L p .707 .577 .707 r
F P
0 g
s
.49196 .64866 m .49196 .59307 L .47559 .60044 L p .707 .577 .707 r
F P
0 g
s
.66161 .66431 m .66161 .62725 L .68566 .62161 L p .707 .577 .707 r
F P
0 g
s
.31064 .5975 m .31064 .65308 L .33169 .65954 L p .707 .577 .707 r
F P
0 g
s
.68566 .61653 m .68566 .63506 L .66161 .64071 L p .707 .577 .707 r
F P
0 g
s
.31064 .6226 m .31064 .65965 L .33169 .66611 L p .707 .577 .707 r
F P
0 g
s
.47559 .62046 m .47559 .63899 L .49196 .63162 L p .707 .577 .707 r
F P
0 g
s
.49196 .63162 m .49196 .6131 L .47559 .62046 L p .707 .577 .707 r
F P
0 g
s
.80551 .59864 m .80551 .65423 L .77805 .64983 L p .707 .577 .707 r
F P
0 g
s
.77805 .64983 m .77805 .59425 L .80551 .59864 L p .707 .577 .707 r
F P
0 g
s
.47559 .62554 m .47559 .66259 L .49196 .65523 L p .707 .577 .707 r
F P
0 g
s
.49196 .65523 m .49196 .61817 L .47559 .62554 L p .707 .577 .707 r
F P
0 g
s
.68566 .59651 m .68566 .65209 L .66161 .65774 L p .707 .577 .707 r
F P
0 g
s
.31064 .65308 m .31064 .5975 L .29804 .58962 L p .707 .577 .707 r
F P
0 g
s
.68566 .62161 m .68566 .65866 L .66161 .66431 L p .707 .577 .707 r
F P
0 g
s
.80551 .61867 m .80551 .6372 L .77805 .6328 L p .707 .577 .707 r
F P
0 g
s
.77805 .6328 m .77805 .61428 L .80551 .61867 L p .707 .577 .707 r
F P
0 g
s
.80551 .62374 m .80551 .6608 L .77805 .6564 L p .707 .577 .707 r
F P
0 g
s
.77805 .6564 m .77805 .61935 L .80551 .62374 L p .707 .577 .707 r
F P
0 g
s
.68566 .65209 m .68566 .59651 L .71504 .59313 L p .707 .577 .707 r
F P
0 g
s
.31064 .63605 m .31064 .61752 L .29804 .60964 L p .707 .577 .707 r
F P
0 g
s
.31064 .65965 m .31064 .6226 L .29804 .61471 L p .707 .577 .707 r
F P
0 g
s
.68566 .63506 m .68566 .61653 L .71504 .61315 L p .707 .577 .707 r
F P
0 g
s
.68566 .65866 m .68566 .62161 L .71504 .61823 L p .707 .577 .707 r
F P
0 g
s
.29804 .60964 m .29804 .62817 L .31064 .63605 L p .707 .577 .707 r
F P
0 g
s
.77805 .59425 m .77805 .64983 L .74688 .64793 L p .707 .577 .707 r
F P
0 g
s
.74688 .64793 m .74688 .59235 L .77805 .59425 L p .707 .577 .707 r
F P
0 g
s
.71504 .61315 m .71504 .63168 L .68566 .63506 L p .707 .577 .707 r
F P
0 g
s
.29804 .58962 m .29804 .6452 L .31064 .65308 L p .707 .577 .707 r
F P
0 g
s
.71504 .64871 m .71504 .59313 L .74688 .59235 L p .707 .577 .707 r
F P
0 g
s
.71504 .59313 m .71504 .64871 L .68566 .65209 L p .707 .577 .707 r
F P
0 g
s
.49196 .59307 m .49196 .64866 L .49904 .64029 L p .707 .577 .707 r
F P
0 g
s
.49904 .64029 m .49904 .58471 L .49196 .59307 L p .707 .577 .707 r
F P
0 g
s
.77805 .61428 m .77805 .6328 L .74688 .6309 L p .707 .577 .707 r
F P
0 g
s
.74688 .6309 m .74688 .61237 L .77805 .61428 L p .707 .577 .707 r
F P
0 g
s
.29804 .61471 m .29804 .65177 L .31064 .65965 L p .707 .577 .707 r
F P
0 g
s
.74688 .59235 m .74688 .64793 L .71504 .64871 L p .707 .577 .707 r
F P
0 g
s
.77805 .61935 m .77805 .6564 L .74688 .6545 L p .707 .577 .707 r
F P
0 g
s
.74688 .6545 m .74688 .61745 L .77805 .61935 L p .707 .577 .707 r
F P
0 g
s
.71504 .61823 m .71504 .65528 L .68566 .65866 L p .707 .577 .707 r
F P
0 g
s
.71504 .63168 m .71504 .61315 L .74688 .61237 L p .707 .577 .707 r
F P
0 g
s
.49196 .6131 m .49196 .63162 L .49904 .62326 L p .707 .577 .707 r
F P
0 g
s
.49904 .62326 m .49904 .60473 L .49196 .6131 L p .707 .577 .707 r
F P
0 g
s
.71504 .65528 m .71504 .61823 L .74688 .61745 L p .707 .577 .707 r
F P
0 g
s
.49196 .61817 m .49196 .65523 L .49904 .64686 L p .707 .577 .707 r
F P
0 g
s
.49904 .64686 m .49904 .60981 L .49196 .61817 L p .707 .577 .707 r
F P
0 g
s
.74688 .61237 m .74688 .6309 L .71504 .63168 L p .707 .577 .707 r
F P
0 g
s
.74688 .61745 m .74688 .6545 L .71504 .65528 L p .707 .577 .707 r
F P
0 g
s
.29804 .6452 m .29804 .58962 L .29515 .58107 L p .707 .577 .707 r
F P
0 g
s
.29804 .62817 m .29804 .60964 L .29515 .6011 L p .707 .577 .707 r
F P
0 g
s
.29804 .65177 m .29804 .61471 L .29515 .60617 L p .707 .577 .707 r
F P
0 g
s
.29515 .6011 m .29515 .61962 L .29804 .62817 L p .707 .577 .707 r
F P
0 g
s
.29515 .58107 m .29515 .63666 L .29804 .6452 L p .707 .577 .707 r
F P
0 g
s
.29515 .60617 m .29515 .64323 L .29804 .65177 L p .707 .577 .707 r
F P
0 g
s
.49904 .58471 m .49904 .64029 L .49615 .63175 L p .707 .577 .707 r
F P
0 g
s
.49615 .63175 m .49615 .57617 L .49904 .58471 L p .707 .577 .707 r
F P
0 g
s
.49904 .60473 m .49904 .62326 L .49615 .61472 L p .707 .577 .707 r
F P
0 g
s
.49615 .61472 m .49615 .59619 L .49904 .60473 L p .707 .577 .707 r
F P
0 g
s
.49904 .60981 m .49904 .64686 L .49615 .63832 L p .707 .577 .707 r
F P
0 g
s
.49615 .63832 m .49615 .60126 L .49904 .60981 L p .707 .577 .707 r
F P
0 g
s
.29515 .63666 m .29515 .58107 L .30223 .57271 L p .707 .577 .707 r
F P
0 g
s
.29515 .61962 m .29515 .6011 L .30223 .59273 L p .707 .577 .707 r
F P
0 g
s
.29515 .64323 m .29515 .60617 L .30223 .59781 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .59273 m .30223 .61126 L .29515 .61962 L p .707 .577 .707 r
F P
0 g
s
.30223 .57271 m .30223 .62829 L .29515 .63666 L p .707 .577 .707 r
F P
0 g
s
.30223 .59781 m .30223 .63486 L .29515 .64323 L p .707 .577 .707 r
F P
0 g
s
.49615 .57617 m .49615 .63175 L .48356 .62386 L p .707 .577 .707 r
F P
0 g
s
.48356 .62386 m .48356 .56828 L .49615 .57617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .59619 m .49615 .61472 L .48356 .60683 L p .707 .577 .707 r
F P
0 g
s
.48356 .60683 m .48356 .58831 L .49615 .59619 L p .707 .577 .707 r
F P
0 g
s
.49615 .60126 m .49615 .63832 L .48356 .63044 L p .707 .577 .707 r
F P
0 g
s
.48356 .63044 m .48356 .59338 L .49615 .60126 L p .707 .577 .707 r
F P
0 g
s
.30223 .62829 m .30223 .57271 L .3186 .56534 L p .707 .577 .707 r
F P
0 g
s
.30223 .61126 m .30223 .59273 L .3186 .58537 L p .707 .577 .707 r
F P
0 g
s
.30223 .63486 m .30223 .59781 L .3186 .59044 L p .707 .577 .707 r
F P
0 g
s
.3186 .58537 m .3186 .60389 L .30223 .61126 L p .707 .577 .707 r
F P
0 g
s
.3186 .56534 m .3186 .62092 L .30223 .62829 L p .707 .577 .707 r
F P
0 g
s
.48356 .56828 m .48356 .62386 L .4625 .61741 L p .707 .577 .707 r
F P
0 g
s
.4625 .61741 m .4625 .56183 L .48356 .56828 L p .707 .577 .707 r
F P
0 g
s
.3186 .59044 m .3186 .62749 L .30223 .63486 L p .707 .577 .707 r
F P
0 g
s
.48356 .58831 m .48356 .60683 L .4625 .60038 L p .707 .577 .707 r
F P
0 g
s
.4625 .60038 m .4625 .58185 L .48356 .58831 L p .707 .577 .707 r
F P
0 g
s
.48356 .59338 m .48356 .63044 L .4625 .62398 L p .707 .577 .707 r
F P
0 g
s
.4625 .62398 m .4625 .58693 L .48356 .59338 L p .707 .577 .707 r
F P
0 g
s
.3186 .62092 m .3186 .56534 L .34265 .55969 L p .707 .577 .707 r
F P
0 g
s
.3186 .60389 m .3186 .58537 L .34265 .57972 L p .707 .577 .707 r
F P
0 g
s
.3186 .62749 m .3186 .59044 L .34265 .58479 L p .707 .577 .707 r
F P
0 g
s
.34265 .57972 m .34265 .59824 L .3186 .60389 L p .707 .577 .707 r
F P
0 g
s
.4625 .56183 m .4625 .61741 L .43504 .61302 L p .707 .577 .707 r
F P
0 g
s
.43504 .61302 m .43504 .55744 L .4625 .56183 L p .707 .577 .707 r
F P
0 g
s
.34265 .55969 m .34265 .61527 L .3186 .62092 L p .707 .577 .707 r
F P
0 g
s
.34265 .58479 m .34265 .62184 L .3186 .62749 L p .707 .577 .707 r
F P
0 g
s
.4625 .58185 m .4625 .60038 L .43504 .59599 L p .707 .577 .707 r
F P
0 g
s
.43504 .59599 m .43504 .57746 L .4625 .58185 L p .707 .577 .707 r
F P
0 g
s
.4625 .58693 m .4625 .62398 L .43504 .61959 L p .707 .577 .707 r
F P
0 g
s
.43504 .61959 m .43504 .58253 L .4625 .58693 L p .707 .577 .707 r
F P
0 g
s
.34265 .61527 m .34265 .55969 L .37203 .55631 L p .707 .577 .707 r
F P
0 g
s
.34265 .59824 m .34265 .57972 L .37203 .57634 L p .707 .577 .707 r
F P
0 g
s
.34265 .62184 m .34265 .58479 L .37203 .58141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55744 m .43504 .61302 L .40387 .61112 L p .707 .577 .707 r
F P
0 g
s
.40387 .61112 m .40387 .55554 L .43504 .55744 L p .707 .577 .707 r
F P
0 g
s
.37203 .57634 m .37203 .59486 L .34265 .59824 L p .707 .577 .707 r
F P
0 g
s
.37203 .61189 m .37203 .55631 L .40387 .55554 L p .707 .577 .707 r
F P
0 g
s
.37203 .55631 m .37203 .61189 L .34265 .61527 L p .707 .577 .707 r
F P
0 g
s
.43504 .57746 m .43504 .59599 L .40387 .59409 L p .707 .577 .707 r
F P
0 g
s
.40387 .59409 m .40387 .57556 L .43504 .57746 L p .707 .577 .707 r
F P
0 g
s
.40387 .55554 m .40387 .61112 L .37203 .61189 L p .707 .577 .707 r
F P
0 g
s
.43504 .58253 m .43504 .61959 L .40387 .61769 L p .707 .577 .707 r
F P
0 g
s
.40387 .61769 m .40387 .58063 L .43504 .58253 L p .707 .577 .707 r
F P
0 g
s
.37203 .58141 m .37203 .61847 L .34265 .62184 L p .707 .577 .707 r
F P
0 g
s
.37203 .59486 m .37203 .57634 L .40387 .57556 L p .707 .577 .707 r
F P
0 g
s
.37203 .61847 m .37203 .58141 L .40387 .58063 L p .707 .577 .707 r
F P
0 g
s
.40387 .57556 m .40387 .59409 L .37203 .59486 L p .707 .577 .707 r
F P
0 g
s
.40387 .58063 m .40387 .61769 L .37203 .61847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE
0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJEP`007Yoo`00MWoo1P0025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00Lgoo001aOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool30007
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P00
15YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo6P001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0>0004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`03001JEP0000AJEP03001JEP000080009JEP03001JEUYF00EJEPH000=JEQ<000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP80009JEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP02FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH005YF
0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000010000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000?OolB0014Ool005=oo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPP003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo0`0015YF0`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYFFUHF0003FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH60003FUH8
00000eYF000000030004FUH01000FUIJEUYF1@0015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0015YF1`001eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP@0009JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEP0000800003
FUH005YF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YF00000`0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00
0eYF0P000eYF0P00;Goo001COol00`00FUH00003FUH60003FUH50002FUH00`00FUIJEP02FUH40006
FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP0000000UYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUHH0005FUH30003FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH00000008002eoo`00Dgoo00<005YF00000`001EYF00<005YFFUH00eYF0`00
0UYF50000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00Dgoo0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEP<0009JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo5P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPD000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000cOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000_Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH40002FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH40000
0eYF001JEP02FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP80009JEP8000EJEP<000=JEQX000=JEP<000=JEP8002eo
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01@0015YF00<005YFFUH0
0UYF200015YF00<005YFFUH00eYF200015YF00<005YFFUH00eYF3P000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF
00@005YFFUIJEPD00004FUH000000004FUH>0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
0000000]Ool002aoo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH60003FUH;0002FUH6
0004FUH01000FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;7oo00<005YF000015YF10000eYF1@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`000UYF00<005YF00000P0000EJEP00FUIJEP00009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH0
1UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool01000
FUH005YF0P0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF1@000UYF0P000UYF00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00@005YF000000=JEP8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L0009JEP03001JEUYF
00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPH0
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo0`00
00EJEP00FUIJEP0000IJEP03001JEUYF00EJEPH000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
0`0015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
<goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000EJEP8000QJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000400000eYF001JEP04FUH00`00FUH0000H000oOol002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH40003FUH01000FUIJEUYF0P00
E7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPD00003FUH00000008000=JEP8000Qoo`<004Uoo`00;7oo00<005YF00000eYF1P000eYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF100000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EP0000800003FUH00000009JEP8000Moo`D004Qoo`00;7oo00@005YF001JEP8000AJEP8000MJEP04
001JEUYFFUHJ0003FUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00UYF0P0000=JEP0000000P001goo1@00B7oo000/Ool00`00FUH00003
0005FUH00`00FUIJEP02FUH40002FUHD0003FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH30000
0eYF00000007Ool50018Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP03
0008Ool30019Ool002aoo`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH015YF0P000UYF1P002EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol0031oo`<000=JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00<goo0`0000=J
EP00FUH01EYF0P001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000P000=JEP04001JEUYFFUH2
001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUH000070003FUH2001DOol003]oo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000Yoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040005FUH01000FUIJEP00
0UYF0P00E7oo0013OolC000?Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00B7oo0`006Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001J
EUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00Agoo1@006Goo
00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo05Aoo`00B7oo0`006Woo00@005YFFUH000=JEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003
FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF008005Moo`00IGoo00D005YF
FUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol006Eo
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH01000FUIJ
EUYF1000Fgoo001UOol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF0000
0005001OOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH007oo06Aoo`00
IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUH006Eoo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001W
Ool006Moo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Moo`00JGoo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P00J7oo001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001]Ool20004FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000
K7oo001_Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH4001^Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH00eYF2000Mgoo001lOolR001oOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79468 m .59613 .7391 L .56496 .7372 L p .707 .577 .707 r
F P
0 g
s
.59613 .7391 m .59613 .79468 L .62796 .79391 L p .707 .577 .707 r
F P
0 g
s
.62796 .79391 m .62796 .73832 L .59613 .7391 L p .707 .577 .707 r
F P
0 g
s
.62796 .73832 m .62796 .79391 L .65735 .79053 L p .707 .577 .707 r
F P
0 g
s
.65735 .79053 m .65734 .73494 L .62796 .73832 L p .707 .577 .707 r
F P
0 g
s
.59613 .77765 m .59613 .75912 L .56496 .75722 L p .707 .577 .707 r
F P
0 g
s
.59613 .75912 m .59613 .77765 L .62796 .77687 L p .707 .577 .707 r
F P
0 g
s
.62796 .77687 m .62796 .75835 L .59613 .75912 L p .707 .577 .707 r
F P
0 g
s
.56496 .79278 m .56496 .7372 L .5375 .73281 L p .707 .577 .707 r
F P
0 g
s
.56496 .7372 m .56496 .79278 L .59613 .79468 L p .707 .577 .707 r
F P
0 g
s
.59613 .80125 m .59613 .7642 L .56496 .7623 L p .707 .577 .707 r
F P
0 g
s
.59613 .7642 m .59613 .80125 L .62796 .80048 L p .707 .577 .707 r
F P
0 g
s
.62796 .80048 m .62796 .76342 L .59613 .7642 L p .707 .577 .707 r
F P
0 g
s
.62796 .75835 m .62796 .77687 L .65735 .7735 L p .707 .577 .707 r
F P
0 g
s
.65735 .7735 m .65735 .75497 L .62796 .75835 L p .707 .577 .707 r
F P
0 g
s
.62796 .76342 m .62796 .80048 L .65735 .7971 L p .707 .577 .707 r
F P
0 g
s
.65735 .7971 m .65735 .76004 L .62796 .76342 L p .707 .577 .707 r
F P
0 g
s
.56496 .75722 m .56496 .77575 L .59613 .77765 L p .707 .577 .707 r
F P
0 g
s
.56496 .77575 m .56496 .75722 L .5375 .75283 L p .707 .577 .707 r
F P
0 g
s
.56496 .79935 m .56496 .7623 L .5375 .75791 L p .707 .577 .707 r
F P
0 g
s
.56496 .7623 m .56496 .79935 L .59613 .80125 L p .707 .577 .707 r
F P
0 g
s
.65734 .73494 m .65735 .79053 L .6814 .78488 L p .707 .577 .707 r
F P
0 g
s
.6814 .78488 m .6814 .72929 L .65734 .73494 L p .707 .577 .707 r
F P
0 g
s
.5375 .75283 m .5375 .77136 L .56496 .77575 L p .707 .577 .707 r
F P
0 g
s
.65735 .75497 m .65735 .7735 L .6814 .76785 L p .707 .577 .707 r
F P
0 g
s
.6814 .76785 m .6814 .74932 L .65735 .75497 L p .707 .577 .707 r
F P
0 g
s
.65735 .76004 m .65735 .7971 L .6814 .79145 L p .707 .577 .707 r
F P
0 g
s
.6814 .79145 m .6814 .75439 L .65735 .76004 L p .707 .577 .707 r
F P
0 g
s
.5375 .73281 m .5375 .78839 L .56496 .79278 L p .707 .577 .707 r
F P
0 g
s
.5375 .78839 m .5375 .73281 L .51644 .72635 L p .707 .577 .707 r
F P
0 g
s
.5375 .75791 m .5375 .79496 L .56496 .79935 L p .707 .577 .707 r
F P
0 g
s
.5375 .77136 m .5375 .75283 L .51644 .74638 L p .707 .577 .707 r
F P
0 g
s
.5375 .79496 m .5375 .75791 L .51644 .75145 L p .707 .577 .707 r
F P
0 g
s
.51644 .74638 m .51644 .7649 L .5375 .77136 L p .707 .577 .707 r
F P
0 g
s
.6814 .72929 m .6814 .78488 L .69777 .77751 L p .707 .577 .707 r
F P
0 g
s
.69777 .77751 m .69777 .72193 L .6814 .72929 L p .707 .577 .707 r
F P
0 g
s
.51644 .72635 m .51644 .78194 L .5375 .78839 L p .707 .577 .707 r
F P
0 g
s
.51644 .75145 m .51644 .78851 L .5375 .79496 L p .707 .577 .707 r
F P
0 g
s
.6814 .74932 m .6814 .76785 L .69777 .76048 L p .707 .577 .707 r
F P
0 g
s
.69777 .76048 m .69777 .74195 L .6814 .74932 L p .707 .577 .707 r
F P
0 g
s
.6814 .75439 m .6814 .79145 L .69777 .78408 L p .707 .577 .707 r
F P
0 g
s
.69777 .78408 m .69777 .74702 L .6814 .75439 L p .707 .577 .707 r
F P
0 g
s
.51644 .78194 m .51644 .72635 L .50385 .71847 L p .707 .577 .707 r
F P
0 g
s
.51644 .7649 m .51644 .74638 L .50385 .73849 L p .707 .577 .707 r
F P
0 g
s
.51644 .78851 m .51644 .75145 L .50385 .74357 L p .707 .577 .707 r
F P
0 g
s
.50385 .73849 m .50385 .75702 L .51644 .7649 L p .707 .577 .707 r
F P
0 g
s
.50385 .71847 m .50385 .77405 L .51644 .78194 L p .707 .577 .707 r
F P
0 g
s
.69777 .72193 m .69777 .77751 L .70485 .76914 L p .707 .577 .707 r
F P
0 g
s
.70485 .76914 m .70485 .71356 L .69777 .72193 L p .707 .577 .707 r
F P
0 g
s
.50385 .74357 m .50385 .78062 L .51644 .78851 L p .707 .577 .707 r
F P
0 g
s
.69777 .74195 m .69777 .76048 L .70485 .75211 L p .707 .577 .707 r
F P
0 g
s
.70485 .75211 m .70485 .73359 L .69777 .74195 L p .707 .577 .707 r
F P
0 g
s
.69777 .74702 m .69777 .78408 L .70485 .77572 L p .707 .577 .707 r
F P
0 g
s
.70485 .77572 m .70485 .73866 L .69777 .74702 L p .707 .577 .707 r
F P
0 g
s
.50385 .77405 m .50385 .71847 L .50095 .70993 L p .707 .577 .707 r
F P
0 g
s
.50385 .75702 m .50385 .73849 L .50095 .72995 L p .707 .577 .707 r
F P
0 g
s
.50385 .78062 m .50385 .74357 L .50095 .73503 L p .707 .577 .707 r
F P
0 g
s
.50095 .72995 m .50095 .74848 L .50385 .75702 L p .707 .577 .707 r
F P
0 g
s
.50095 .70993 m .50095 .76551 L .50385 .77405 L p .707 .577 .707 r
F P
0 g
s
.50095 .73503 m .50095 .77208 L .50385 .78062 L p .707 .577 .707 r
F P
0 g
s
.70485 .71356 m .70485 .76914 L .70195 .7606 L p .707 .577 .707 r
F P
0 g
s
.70195 .7606 m .70195 .70502 L .70485 .71356 L p .707 .577 .707 r
F P
0 g
s
.49044 .84741 m .49044 .34552 L .44643 .34284 L p .707 .577 .707 r
F P
0 g
s
.50095 .76551 m .50095 .70993 L .50804 .70156 L p .707 .577 .707 r
F P
0 g
s
.50095 .74848 m .50095 .72995 L .50804 .72159 L p .707 .577 .707 r
F P
0 g
s
.50095 .77208 m .50095 .73503 L .50804 .72666 L p .707 .577 .707 r
F P
0 g
s
.50804 .72159 m .50804 .74011 L .50095 .74848 L p .707 .577 .707 r
F P
0 g
s
.50804 .70156 m .50804 .75715 L .50095 .76551 L p .707 .577 .707 r
F P
0 g
s
.50804 .72666 m .50804 .76372 L .50095 .77208 L p .707 .577 .707 r
F P
0 g
s
.50804 .75715 m .50804 .70156 L .5244 .6942 L p .707 .577 .707 r
F P
0 g
s
.50804 .74011 m .50804 .72159 L .5244 .71422 L p .707 .577 .707 r
F P
0 g
s
.50804 .76372 m .50804 .72666 L .5244 .71929 L p .707 .577 .707 r
F P
0 g
s
.5244 .71422 m .5244 .73275 L .50804 .74011 L p .707 .577 .707 r
F P
0 g
s
.5244 .6942 m .5244 .74978 L .50804 .75715 L p .707 .577 .707 r
F P
0 g
s
.5244 .71929 m .5244 .75635 L .50804 .76372 L p .707 .577 .707 r
F P
0 g
s
.5244 .74978 m .5244 .6942 L .54846 .68855 L p .707 .577 .707 r
F P
0 g
s
.5244 .73275 m .5244 .71422 L .54846 .70857 L p .707 .577 .707 r
F P
0 g
s
.5244 .75635 m .5244 .71929 L .54846 .71364 L p .707 .577 .707 r
F P
0 g
s
.54846 .70857 m .54846 .7271 L .5244 .73275 L p .707 .577 .707 r
F P
0 g
s
.54846 .68855 m .54846 .74413 L .5244 .74978 L p .707 .577 .707 r
F P
0 g
s
.54846 .71364 m .54846 .7507 L .5244 .75635 L p .707 .577 .707 r
F P
0 g
s
.49044 .34552 m .49044 .84741 L .53538 .84631 L p .707 .577 .707 r
F P
0 g
s
.53538 .84631 m .53538 .34442 L .49044 .34552 L p .707 .577 .707 r
F P
0 g
s
.70485 .73359 m .70485 .75211 L .70195 .74357 L p .707 .577 .707 r
F P
0 g
s
.70195 .74357 m .70195 .72504 L .70485 .73359 L p .707 .577 .707 r
F P
0 g
s
.70485 .73866 m .70485 .77572 L .70195 .76717 L p .707 .577 .707 r
F P
0 g
s
.70195 .76717 m .70195 .73012 L .70485 .73866 L p .707 .577 .707 r
F P
0 g
s
.54846 .74413 m .54846 .68855 L .57784 .68517 L p .707 .577 .707 r
F P
0 g
s
.54846 .7271 m .54846 .70857 L .57784 .70519 L p .707 .577 .707 r
F P
0 g
s
.54846 .7507 m .54846 .71364 L .57784 .71026 L p .707 .577 .707 r
F P
0 g
s
.57784 .70519 m .57784 .72372 L .54846 .7271 L p .707 .577 .707 r
F P
0 g
s
.57784 .68517 m .57784 .74075 L .54846 .74413 L p .707 .577 .707 r
F P
0 g
s
.57784 .71026 m .57784 .74732 L .54846 .7507 L p .707 .577 .707 r
F P
0 g
s
.53538 .34442 m .53538 .84631 L .57686 .84154 L p .707 .577 .707 r
F P
0 g
s
.57686 .84154 m .57686 .33965 L .53538 .34442 L p .707 .577 .707 r
F P
0 g
s
.44643 .84473 m .44643 .34284 L .40766 .33664 L p .707 .577 .707 r
F P
0 g
s
.44643 .34284 m .44643 .84473 L .49044 .84741 L p .707 .577 .707 r
F P
0 g
s
.57784 .74075 m .57784 .68517 L .60968 .68439 L p .707 .577 .707 r
F P
0 g
s
.60968 .68439 m .60968 .73997 L .57784 .74075 L p .707 .577 .707 r
F P
0 g
s
.57784 .72372 m .57784 .70519 L .60968 .70441 L p .707 .577 .707 r
F P
0 g
s
.57784 .74732 m .57784 .71026 L .60968 .70949 L p .707 .577 .707 r
F P
0 g
s
.60968 .70441 m .60968 .72294 L .57784 .72372 L p .707 .577 .707 r
F P
0 g
s
.60968 .70949 m .60968 .74654 L .57784 .74732 L p .707 .577 .707 r
F P
0 g
s
.57686 .33965 m .57686 .84154 L .61082 .83357 L p .707 .577 .707 r
F P
0 g
s
.64085 .68629 m .64085 .74187 L .60968 .73997 L p .707 .577 .707 r
F P
0 g
s
.60968 .73997 m .60968 .68439 L .64085 .68629 L p .707 .577 .707 r
F P
0 g
s
.64085 .70631 m .64085 .72484 L .60968 .72294 L p .707 .577 .707 r
F P
0 g
s
.60968 .72294 m .60968 .70441 L .64085 .70631 L p .707 .577 .707 r
F P
0 g
s
.64085 .71139 m .64085 .74844 L .60968 .74654 L p .707 .577 .707 r
F P
0 g
s
.60968 .74654 m .60968 .70949 L .64085 .71139 L p .707 .577 .707 r
F P
0 g
s
.61082 .83357 m .61082 .33168 L .57686 .33965 L p .707 .577 .707 r
F P
0 g
s
.70195 .70502 m .70195 .7606 L .68936 .75272 L p .707 .577 .707 r
F P
0 g
s
.68936 .75272 m .68936 .69714 L .70195 .70502 L p .707 .577 .707 r
F P
0 g
s
.70195 .72504 m .70195 .74357 L .68936 .73569 L p .707 .577 .707 r
F P
0 g
s
.68936 .73569 m .68936 .71716 L .70195 .72504 L p .707 .577 .707 r
F P
0 g
s
.40766 .83852 m .40766 .33664 L .37794 .32752 L p .707 .577 .707 r
F P
0 g
s
.40766 .33664 m .40766 .83852 L .44643 .84473 L p .707 .577 .707 r
F P
0 g
s
.70195 .73012 m .70195 .76717 L .68936 .75929 L p .707 .577 .707 r
F P
0 g
s
.68936 .75929 m .68936 .72223 L .70195 .73012 L p .707 .577 .707 r
F P
0 g
s
.25312 .75787 m .25312 .70229 L .22195 .70038 L p .707 .577 .707 r
F P
0 g
s
.25312 .70229 m .25312 .75787 L .28495 .75709 L p .707 .577 .707 r
F P
0 g
s
.28495 .75709 m .28495 .70151 L .25312 .70229 L p .707 .577 .707 r
F P
0 g
s
.28495 .70151 m .28495 .75709 L .31434 .75371 L p .707 .577 .707 r
F P
0 g
s
.31434 .75371 m .31434 .69813 L .28495 .70151 L p .707 .577 .707 r
F P
0 g
s
.25312 .74084 m .25312 .72231 L .22195 .72041 L p .707 .577 .707 r
F P
0 g
s
.25312 .72231 m .25312 .74084 L .28495 .74006 L p .707 .577 .707 r
F P
0 g
s
.28495 .74006 m .28495 .72153 L .25312 .72231 L p .707 .577 .707 r
F P
0 g
s
.22195 .75597 m .22195 .70038 L .19449 .69599 L p .707 .577 .707 r
F P
0 g
s
.22195 .70038 m .22195 .75597 L .25312 .75787 L p .707 .577 .707 r
F P
0 g
s
.25312 .76444 m .25312 .72738 L .22195 .72548 L p .707 .577 .707 r
F P
0 g
s
.25312 .72738 m .25312 .76444 L .28495 .76366 L p .707 .577 .707 r
F P
0 g
s
.28495 .76366 m .28495 .72661 L .25312 .72738 L p .707 .577 .707 r
F P
0 g
s
.28495 .72153 m .28495 .74006 L .31434 .73668 L p .707 .577 .707 r
F P
0 g
s
.31434 .73668 m .31434 .71815 L .28495 .72153 L p .707 .577 .707 r
F P
0 g
s
.28495 .72661 m .28495 .76366 L .31434 .76028 L p .707 .577 .707 r
F P
0 g
s
.31434 .76028 m .31434 .72323 L .28495 .72661 L p .707 .577 .707 r
F P
0 g
s
.22195 .72041 m .22195 .73894 L .25312 .74084 L p .707 .577 .707 r
F P
0 g
s
.22195 .73894 m .22195 .72041 L .19449 .71602 L p .707 .577 .707 r
F P
0 g
s
.61082 .33168 m .61082 .83357 L .63393 .82316 L p .707 .577 .707 r
F P
0 g
s
.63393 .82316 m .63393 .32128 L .61082 .33168 L p .707 .577 .707 r
F P
0 g
s
.22195 .76254 m .22195 .72548 L .19449 .72109 L p .707 .577 .707 r
F P
0 g
s
.22195 .72548 m .22195 .76254 L .25312 .76444 L p .707 .577 .707 r
F P
0 g
s
.31434 .69813 m .31434 .75371 L .33839 .74806 L p .707 .577 .707 r
F P
0 g
s
.33839 .74806 m .33839 .69248 L .31434 .69813 L p .707 .577 .707 r
F P
0 g
s
.19449 .71602 m .19449 .73454 L .22195 .73894 L p .707 .577 .707 r
F P
0 g
s
.68936 .69714 m .68936 .75272 L .66831 .74626 L p .707 .577 .707 r
F P
0 g
s
.66831 .74626 m .66831 .69068 L .68936 .69714 L p .707 .577 .707 r
F P
0 g
s
.31434 .71815 m .31434 .73668 L .33839 .73103 L p .707 .577 .707 r
F P
0 g
s
.33839 .73103 m .33839 .7125 L .31434 .71815 L p .707 .577 .707 r
F P
0 g
s
.31434 .72323 m .31434 .76028 L .33839 .75463 L p .707 .577 .707 r
F P
0 g
s
.33839 .75463 m .33839 .71758 L .31434 .72323 L p .707 .577 .707 r
F P
0 g
s
.19449 .69599 m .19449 .75157 L .22195 .75597 L p .707 .577 .707 r
F P
0 g
s
.19449 .75157 m .19449 .69599 L .17343 .68954 L p .707 .577 .707 r
F P
0 g
s
.68936 .71716 m .68936 .73569 L .66831 .72923 L p .707 .577 .707 r
F P
0 g
s
.66831 .72923 m .66831 .71071 L .68936 .71716 L p .707 .577 .707 r
F P
0 g
s
.19449 .72109 m .19449 .75815 L .22195 .76254 L p .707 .577 .707 r
F P
0 g
s
.68936 .72223 m .68936 .75929 L .66831 .75284 L p .707 .577 .707 r
F P
0 g
s
.66831 .75284 m .66831 .71578 L .68936 .72223 L p .707 .577 .707 r
F P
0 g
s
.19449 .73454 m .19449 .71602 L .17343 .70956 L p .707 .577 .707 r
F P
0 g
s
.37794 .82941 m .37794 .32752 L .36016 .31639 L p .707 .577 .707 r
F P
0 g
s
.37794 .32752 m .37794 .82941 L .40766 .83852 L p .707 .577 .707 r
F P
0 g
s
.19449 .75815 m .19449 .72109 L .17343 .71464 L p .707 .577 .707 r
F P
0 g
s
.17343 .70956 m .17343 .72809 L .19449 .73454 L p .707 .577 .707 r
F P
0 g
s
.33839 .69248 m .33839 .74806 L .35476 .74069 L p .707 .577 .707 r
F P
0 g
s
.35476 .74069 m .35476 .68511 L .33839 .69248 L p .707 .577 .707 r
F P
0 g
s
.17343 .68954 m .17343 .74512 L .19449 .75157 L p .707 .577 .707 r
F P
0 g
s
.17343 .71464 m .17343 .75169 L .19449 .75815 L p .707 .577 .707 r
F P
0 g
s
.33839 .7125 m .33839 .73103 L .35476 .72366 L p .707 .577 .707 r
F P
0 g
s
.35476 .72366 m .35476 .70514 L .33839 .7125 L p .707 .577 .707 r
F P
0 g
s
.66831 .69068 m .66831 .74626 L .64085 .74187 L p .707 .577 .707 r
F P
0 g
s
.64085 .74187 m .64085 .68629 L .66831 .69068 L p .707 .577 .707 r
F P
0 g
s
.33839 .71758 m .33839 .75463 L .35476 .74726 L p .707 .577 .707 r
F P
0 g
s
.35476 .74726 m .35476 .71021 L .33839 .71758 L p .707 .577 .707 r
F P
0 g
s
.17343 .74512 m .17343 .68954 L .16084 .68165 L p .707 .577 .707 r
F P
0 g
s
.66831 .71071 m .66831 .72923 L .64085 .72484 L p .707 .577 .707 r
F P
0 g
s
.64085 .72484 m .64085 .70631 L .66831 .71071 L p .707 .577 .707 r
F P
0 g
s
.66831 .71578 m .66831 .75284 L .64085 .74844 L p .707 .577 .707 r
F P
0 g
s
.64085 .74844 m .64085 .71139 L .66831 .71578 L p .707 .577 .707 r
F P
0 g
s
.63393 .32128 m .63393 .82316 L .64393 .81136 L p .707 .577 .707 r
F P
0 g
s
.64393 .81136 m .64393 .30947 L .63393 .32128 L p .707 .577 .707 r
F P
0 g
s
.17343 .72809 m .17343 .70956 L .16084 .70168 L p .707 .577 .707 r
F P
0 g
s
.17343 .75169 m .17343 .71464 L .16084 .70675 L p .707 .577 .707 r
F P
0 g
s
.16084 .70168 m .16084 .72021 L .17343 .72809 L p .707 .577 .707 r
F P
0 g
s
.16084 .68165 m .16084 .73724 L .17343 .74512 L p .707 .577 .707 r
F P
0 g
s
.35476 .68511 m .35476 .74069 L .36184 .73233 L p .707 .577 .707 r
F P
0 g
s
.36184 .73233 m .36184 .67675 L .35476 .68511 L p .707 .577 .707 r
F P
0 g
s
.16084 .70675 m .16084 .74381 L .17343 .75169 L p .707 .577 .707 r
F P
0 g
s
.35476 .70514 m .35476 .72366 L .36184 .7153 L p .707 .577 .707 r
F P
0 g
s
.36184 .7153 m .36184 .69677 L .35476 .70514 L p .707 .577 .707 r
F P
0 g
s
.35476 .71021 m .35476 .74726 L .36184 .7389 L p .707 .577 .707 r
F P
0 g
s
.36184 .7389 m .36184 .70185 L .35476 .71021 L p .707 .577 .707 r
F P
0 g
s
.36184 .67675 m .36184 .73233 L .35894 .72379 L p .707 .577 .707 r
F P
0 g
s
.35894 .72379 m .35894 .66821 L .36184 .67675 L p .707 .577 .707 r
F P
0 g
s
.36184 .69677 m .36184 .7153 L .35894 .70676 L p .707 .577 .707 r
F P
0 g
s
.35894 .70676 m .35894 .68823 L .36184 .69677 L p .707 .577 .707 r
F P
0 g
s
.36184 .70185 m .36184 .7389 L .35894 .73036 L p .707 .577 .707 r
F P
0 g
s
.35894 .73036 m .35894 .6933 L .36184 .70185 L p .707 .577 .707 r
F P
0 g
s
.36016 .81828 m .36016 .31639 L .35607 .30433 L p .707 .577 .707 r
F P
0 g
s
.36016 .31639 m .36016 .81828 L .37794 .82941 L p .707 .577 .707 r
F P
0 g
s
.16084 .73724 m .16084 .68165 L .15794 .67311 L p .707 .577 .707 r
F P
0 g
s
.16084 .72021 m .16084 .70168 L .15794 .69314 L p .707 .577 .707 r
F P
0 g
s
.16084 .74381 m .16084 .70675 L .15794 .69821 L p .707 .577 .707 r
F P
0 g
s
.15794 .69314 m .15794 .71166 L .16084 .72021 L p .707 .577 .707 r
F P
0 g
s
.15794 .67311 m .15794 .72869 L .16084 .73724 L p .707 .577 .707 r
F P
0 g
s
.15794 .69821 m .15794 .73526 L .16084 .74381 L p .707 .577 .707 r
F P
0 g
s
.64393 .30947 m .64393 .81136 L .63984 .7993 L p .707 .577 .707 r
F P
0 g
s
.63984 .7993 m .63984 .29741 L .64393 .30947 L p .707 .577 .707 r
F P
0 g
s
.15794 .72869 m .15794 .67311 L .16503 .66475 L p .707 .577 .707 r
F P
0 g
s
.15794 .71166 m .15794 .69314 L .16503 .68477 L p .707 .577 .707 r
F P
0 g
s
.15794 .73526 m .15794 .69821 L .16503 .68985 L p .707 .577 .707 r
F P
0 g
s
.35894 .66821 m .35894 .72379 L .34635 .7159 L p .707 .577 .707 r
F P
0 g
s
.34635 .7159 m .34635 .66032 L .35894 .66821 L p .707 .577 .707 r
F P
0 g
s
.35894 .68823 m .35894 .70676 L .34635 .69887 L p .707 .577 .707 r
F P
0 g
s
.34635 .69887 m .34635 .68034 L .35894 .68823 L p .707 .577 .707 r
F P
0 g
s
.35894 .6933 m .35894 .73036 L .34635 .72247 L p .707 .577 .707 r
F P
0 g
s
.34635 .72247 m .34635 .68542 L .35894 .6933 L p .707 .577 .707 r
F P
0 g
s
.35607 .30433 m .35607 .80622 L .36016 .81828 L p .707 .577 .707 r
F P
0 g
s
.35607 .80622 m .35607 .30433 L .36607 .29253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .68477 m .16503 .7033 L .15794 .71166 L p .707 .577 .707 r
F P
0 g
s
.16503 .66475 m .16503 .72033 L .15794 .72869 L p .707 .577 .707 r
F P
0 g
s
.16503 .68985 m .16503 .7269 L .15794 .73526 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72033 m .16503 .66475 L .1814 .65738 L p .707 .577 .707 r
F P
0 g
s
.63984 .29741 m .63984 .7993 L .62206 .78817 L p .707 .577 .707 r
F P
0 g
s
.62206 .78817 m .62206 .28628 L .63984 .29741 L p .707 .577 .707 r
F P
0 g
s
.16503 .7033 m .16503 .68477 L .1814 .6774 L p .707 .577 .707 r
F P
0 g
s
.16503 .7269 m .16503 .68985 L .1814 .68248 L p .707 .577 .707 r
F P
0 g
s
.1814 .6774 m .1814 .69593 L .16503 .7033 L p .707 .577 .707 r
F P
0 g
s
.1814 .65738 m .1814 .71296 L .16503 .72033 L p .707 .577 .707 r
F P
0 g
s
.34635 .66032 m .34635 .7159 L .3253 .70945 L p .707 .577 .707 r
F P
0 g
s
.3253 .70945 m .3253 .65387 L .34635 .66032 L p .707 .577 .707 r
F P
0 g
s
.1814 .68248 m .1814 .71953 L .16503 .7269 L p .707 .577 .707 r
F P
0 g
s
.36607 .79441 m .36607 .29253 L .38918 .28212 L p .707 .577 .707 r
F P
0 g
s
.36607 .29253 m .36607 .79441 L .35607 .80622 L p .707 .577 .707 r
F P
0 g
s
.34635 .68034 m .34635 .69887 L .3253 .69242 L p .707 .577 .707 r
F P
0 g
s
.3253 .69242 m .3253 .67389 L .34635 .68034 L p .707 .577 .707 r
F P
0 g
s
.34635 .68542 m .34635 .72247 L .3253 .71602 L p .707 .577 .707 r
F P
0 g
s
.3253 .71602 m .3253 .67896 L .34635 .68542 L p .707 .577 .707 r
F P
0 g
s
.1814 .71296 m .1814 .65738 L .20545 .65173 L p .707 .577 .707 r
F P
0 g
s
.1814 .69593 m .1814 .6774 L .20545 .67175 L p .707 .577 .707 r
F P
0 g
s
.1814 .71953 m .1814 .68248 L .20545 .67683 L p .707 .577 .707 r
F P
0 g
s
.20545 .67175 m .20545 .69028 L .1814 .69593 L p .707 .577 .707 r
F P
0 g
s
.3253 .65387 m .3253 .70945 L .29784 .70506 L p .707 .577 .707 r
F P
0 g
s
.29784 .70506 m .29784 .64947 L .3253 .65387 L p .707 .577 .707 r
F P
0 g
s
.62206 .28628 m .62206 .78817 L .59233 .77905 L p .707 .577 .707 r
F P
0 g
s
.59233 .77905 m .59233 .27716 L .62206 .28628 L p .707 .577 .707 r
F P
0 g
s
.20545 .65173 m .20545 .70731 L .1814 .71296 L p .707 .577 .707 r
F P
0 g
s
.20545 .67683 m .20545 .71388 L .1814 .71953 L p .707 .577 .707 r
F P
0 g
s
.3253 .67389 m .3253 .69242 L .29784 .68803 L p .707 .577 .707 r
F P
0 g
s
.29784 .68803 m .29784 .6695 L .3253 .67389 L p .707 .577 .707 r
F P
0 g
s
.3253 .67896 m .3253 .71602 L .29784 .71163 L p .707 .577 .707 r
F P
0 g
s
.29784 .71163 m .29784 .67457 L .3253 .67896 L p .707 .577 .707 r
F P
0 g
s
.20545 .70731 m .20545 .65173 L .23483 .64835 L p .707 .577 .707 r
F P
0 g
s
.20545 .69028 m .20545 .67175 L .23483 .66838 L p .707 .577 .707 r
F P
0 g
s
.20545 .71388 m .20545 .67683 L .23483 .67345 L p .707 .577 .707 r
F P
0 g
s
.29784 .64947 m .29784 .70506 L .26667 .70316 L p .707 .577 .707 r
F P
0 g
s
.26667 .70316 m .26667 .64757 L .29784 .64947 L p .707 .577 .707 r
F P
0 g
s
.38918 .28212 m .38918 .78401 L .36607 .79441 L p .707 .577 .707 r
F P
0 g
s
.38918 .78401 m .38918 .28212 L .42314 .27415 L p .707 .577 .707 r
F P
0 g
s
.23483 .66838 m .23483 .6869 L .20545 .69028 L p .707 .577 .707 r
F P
0 g
s
.23483 .70393 m .23483 .64835 L .26667 .64757 L p .707 .577 .707 r
F P
0 g
s
.23483 .64835 m .23483 .70393 L .20545 .70731 L p .707 .577 .707 r
F P
0 g
s
.29784 .6695 m .29784 .68803 L .26667 .68613 L p .707 .577 .707 r
F P
0 g
s
.26667 .68613 m .26667 .6676 L .29784 .6695 L p .707 .577 .707 r
F P
0 g
s
.26667 .64757 m .26667 .70316 L .23483 .70393 L p .707 .577 .707 r
F P
0 g
s
.29784 .67457 m .29784 .71163 L .26667 .70973 L p .707 .577 .707 r
F P
0 g
s
.26667 .70973 m .26667 .67267 L .29784 .67457 L p .707 .577 .707 r
F P
0 g
s
.73333 .70264 m .73333 .64706 L .70216 .64516 L p .707 .577 .707 r
F P
0 g
s
.73333 .64706 m .73333 .70264 L .76517 .70187 L p .707 .577 .707 r
F P
0 g
s
.76517 .70187 m .76517 .64629 L .73333 .64706 L p .707 .577 .707 r
F P
0 g
s
.23483 .67345 m .23483 .7105 L .20545 .71388 L p .707 .577 .707 r
F P
0 g
s
.23483 .6869 m .23483 .66838 L .26667 .6676 L p .707 .577 .707 r
F P
0 g
s
.23483 .7105 m .23483 .67345 L .26667 .67267 L p .707 .577 .707 r
F P
0 g
s
.76517 .64629 m .76517 .70187 L .79455 .69849 L p .707 .577 .707 r
F P
0 g
s
.79455 .69849 m .79455 .64291 L .76517 .64629 L p .707 .577 .707 r
F P
0 g
s
.26667 .6676 m .26667 .68613 L .23483 .6869 L p .707 .577 .707 r
F P
0 g
s
.26667 .67267 m .26667 .70973 L .23483 .7105 L p .707 .577 .707 r
F P
0 g
s
.73333 .68561 m .73333 .66709 L .70216 .66519 L p .707 .577 .707 r
F P
0 g
s
.73333 .66709 m .73333 .68561 L .76517 .68484 L p .707 .577 .707 r
F P
0 g
s
.76517 .68484 m .76517 .66631 L .73333 .66709 L p .707 .577 .707 r
F P
0 g
s
.70216 .70074 m .70216 .64516 L .6747 .64077 L p .707 .577 .707 r
F P
0 g
s
.70216 .64516 m .70216 .70074 L .73333 .70264 L p .707 .577 .707 r
F P
0 g
s
.73333 .70922 m .73333 .67216 L .70216 .67026 L p .707 .577 .707 r
F P
0 g
s
.73333 .67216 m .73333 .70922 L .76517 .70844 L p .707 .577 .707 r
F P
0 g
s
.76517 .70844 m .76517 .67138 L .73333 .67216 L p .707 .577 .707 r
F P
0 g
s
.76517 .66631 m .76517 .68484 L .79455 .68146 L p .707 .577 .707 r
F P
0 g
s
.79455 .68146 m .79455 .66293 L .76517 .66631 L p .707 .577 .707 r
F P
0 g
s
.76517 .67138 m .76517 .70844 L .79455 .70506 L p .707 .577 .707 r
F P
0 g
s
.79455 .70506 m .79455 .668 L .76517 .67138 L p .707 .577 .707 r
F P
0 g
s
.70216 .66519 m .70216 .68371 L .73333 .68561 L p .707 .577 .707 r
F P
0 g
s
.59233 .27716 m .59233 .77905 L .55357 .77285 L p .707 .577 .707 r
F P
0 g
s
.55357 .77285 m .55357 .27096 L .59233 .27716 L p .707 .577 .707 r
F P
0 g
s
.70216 .68371 m .70216 .66519 L .6747 .66079 L p .707 .577 .707 r
F P
0 g
s
.70216 .70731 m .70216 .67026 L .6747 .66587 L p .707 .577 .707 r
F P
0 g
s
.70216 .67026 m .70216 .70731 L .73333 .70922 L p .707 .577 .707 r
F P
0 g
s
.79455 .64291 m .79455 .69849 L .8186 .69284 L p .707 .577 .707 r
F P
0 g
s
.8186 .69284 m .8186 .63726 L .79455 .64291 L p .707 .577 .707 r
F P
0 g
s
.6747 .66079 m .6747 .67932 L .70216 .68371 L p .707 .577 .707 r
F P
0 g
s
.79455 .66293 m .79455 .68146 L .8186 .67581 L p .707 .577 .707 r
F P
0 g
s
.8186 .67581 m .8186 .65728 L .79455 .66293 L p .707 .577 .707 r
F P
0 g
s
.42314 .77604 m .42314 .27415 L .46462 .26938 L p .707 .577 .707 r
F P
0 g
s
.42314 .27415 m .42314 .77604 L .38918 .78401 L p .707 .577 .707 r
F P
0 g
s
.79455 .668 m .79455 .70506 L .8186 .69941 L p .707 .577 .707 r
F P
0 g
s
.8186 .69941 m .8186 .66235 L .79455 .668 L p .707 .577 .707 r
F P
0 g
s
.6747 .64077 m .6747 .69635 L .70216 .70074 L p .707 .577 .707 r
F P
0 g
s
.6747 .69635 m .6747 .64077 L .65365 .63432 L p .707 .577 .707 r
F P
0 g
s
.6747 .66587 m .6747 .70292 L .70216 .70731 L p .707 .577 .707 r
F P
0 g
s
.6747 .67932 m .6747 .66079 L .65365 .65434 L p .707 .577 .707 r
F P
0 g
s
.6747 .70292 m .6747 .66587 L .65365 .65941 L p .707 .577 .707 r
F P
0 g
s
.55357 .27096 m .55357 .77285 L .50956 .77017 L p .707 .577 .707 r
F P
0 g
s
.50956 .77017 m .50956 .26828 L .55357 .27096 L p .707 .577 .707 r
F P
0 g
s
.65365 .65434 m .65365 .67287 L .6747 .67932 L p .707 .577 .707 r
F P
0 g
s
.8186 .63726 m .8186 .69284 L .83497 .68547 L p .707 .577 .707 r
F P
0 g
s
.83497 .68547 m .83497 .62989 L .8186 .63726 L p .707 .577 .707 r
F P
0 g
s
.65365 .63432 m .65365 .6899 L .6747 .69635 L p .707 .577 .707 r
F P
0 g
s
.46462 .77127 m .46462 .26938 L .50956 .26828 L p .707 .577 .707 r
F P
0 g
s
.46462 .26938 m .46462 .77127 L .42314 .77604 L p .707 .577 .707 r
F P
0 g
s
.65365 .65941 m .65365 .69647 L .6747 .70292 L p .707 .577 .707 r
F P
0 g
s
.8186 .65728 m .8186 .67581 L .83497 .66844 L p .707 .577 .707 r
F P
0 g
s
.83497 .66844 m .83497 .64991 L .8186 .65728 L p .707 .577 .707 r
F P
0 g
s
.8186 .66235 m .8186 .69941 L .83497 .69204 L p .707 .577 .707 r
F P
0 g
s
.83497 .69204 m .83497 .65499 L .8186 .66235 L p .707 .577 .707 r
F P
0 g
s
.50956 .26828 m .50956 .77017 L .46462 .77127 L p .707 .577 .707 r
F P
0 g
s
.65365 .6899 m .65365 .63432 L .64105 .62643 L p .707 .577 .707 r
F P
0 g
s
.65365 .67287 m .65365 .65434 L .64105 .64646 L p .707 .577 .707 r
F P
0 g
s
.65365 .69647 m .65365 .65941 L .64105 .65153 L p .707 .577 .707 r
F P
0 g
s
.64105 .64646 m .64105 .66498 L .65365 .67287 L p .707 .577 .707 r
F P
0 g
s
.64105 .62643 m .64105 .68201 L .65365 .6899 L p .707 .577 .707 r
F P
0 g
s
.83497 .62989 m .83497 .68547 L .84206 .67711 L p .707 .577 .707 r
F P
0 g
s
.84206 .67711 m .84205 .62152 L .83497 .62989 L p .707 .577 .707 r
F P
0 g
s
.64105 .65153 m .64105 .68858 L .65365 .69647 L p .707 .577 .707 r
F P
0 g
s
.83497 .64991 m .83497 .66844 L .84205 .66008 L p .707 .577 .707 r
F P
0 g
s
.84205 .66008 m .84205 .64155 L .83497 .64991 L p .707 .577 .707 r
F P
0 g
s
.83497 .65499 m .83497 .69204 L .84206 .68368 L p .707 .577 .707 r
F P
0 g
s
.84206 .68368 m .84205 .64662 L .83497 .65499 L p .707 .577 .707 r
F P
0 g
s
.64105 .68201 m .64105 .62643 L .63816 .61789 L p .707 .577 .707 r
F P
0 g
s
.64105 .66498 m .64105 .64646 L .63816 .63791 L p .707 .577 .707 r
F P
0 g
s
.64105 .68858 m .64105 .65153 L .63816 .64299 L p .707 .577 .707 r
F P
0 g
s
.63816 .63791 m .63816 .65644 L .64105 .66498 L p .707 .577 .707 r
F P
0 g
s
.63816 .61789 m .63816 .67347 L .64105 .68201 L p .707 .577 .707 r
F P
0 g
s
.63816 .64299 m .63816 .68004 L .64105 .68858 L p .707 .577 .707 r
F P
0 g
s
.84205 .62152 m .84206 .67711 L .83916 .66856 L p .707 .577 .707 r
F P
0 g
s
.83916 .66856 m .83916 .61298 L .84205 .62152 L p .707 .577 .707 r
F P
0 g
s
.84205 .64155 m .84205 .66008 L .83916 .65153 L p .707 .577 .707 r
F P
0 g
s
.83916 .65153 m .83916 .63301 L .84205 .64155 L p .707 .577 .707 r
F P
0 g
s
.84205 .64662 m .84206 .68368 L .83916 .67513 L p .707 .577 .707 r
F P
0 g
s
.83916 .67513 m .83916 .63808 L .84205 .64662 L p .707 .577 .707 r
F P
0 g
s
.63816 .67347 m .63816 .61789 L .64524 .60952 L p .707 .577 .707 r
F P
0 g
s
.63816 .65644 m .63816 .63791 L .64524 .62955 L p .707 .577 .707 r
F P
0 g
s
.63816 .68004 m .63816 .64299 L .64524 .63462 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .62955 m .64524 .64808 L .63816 .65644 L p .707 .577 .707 r
F P
0 g
s
.64524 .60952 m .64524 .66511 L .63816 .67347 L p .707 .577 .707 r
F P
0 g
s
.64524 .63462 m .64524 .67168 L .63816 .68004 L p .707 .577 .707 r
F P
0 g
s
.83916 .61298 m .83916 .66856 L .82657 .66068 L p .707 .577 .707 r
F P
0 g
s
.82657 .66068 m .82657 .6051 L .83916 .61298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63301 m .83916 .65153 L .82657 .64365 L p .707 .577 .707 r
F P
0 g
s
.82657 .64365 m .82657 .62512 L .83916 .63301 L p .707 .577 .707 r
F P
0 g
s
.83916 .63808 m .83916 .67513 L .82657 .66725 L p .707 .577 .707 r
F P
0 g
s
.82657 .66725 m .82657 .6302 L .83916 .63808 L p .707 .577 .707 r
F P
0 g
s
.39032 .66583 m .39032 .61025 L .35915 .60835 L p .707 .577 .707 r
F P
0 g
s
.39032 .61025 m .39032 .66583 L .42216 .66505 L p .707 .577 .707 r
F P
0 g
s
.42216 .66505 m .42216 .60947 L .39032 .61025 L p .707 .577 .707 r
F P
0 g
s
.64524 .66511 m .64524 .60952 L .66161 .60216 L p .707 .577 .707 r
F P
0 g
s
.42216 .60947 m .42216 .66505 L .45154 .66167 L p .707 .577 .707 r
F P
0 g
s
.45154 .66167 m .45154 .60609 L .42216 .60947 L p .707 .577 .707 r
F P
0 g
s
.39032 .6488 m .39032 .63027 L .35915 .62837 L p .707 .577 .707 r
F P
0 g
s
.39032 .63027 m .39032 .6488 L .42216 .64802 L p .707 .577 .707 r
F P
0 g
s
.42216 .64802 m .42216 .62949 L .39032 .63027 L p .707 .577 .707 r
F P
0 g
s
.35915 .66393 m .35915 .60835 L .33169 .60395 L p .707 .577 .707 r
F P
0 g
s
.35915 .60835 m .35915 .66393 L .39032 .66583 L p .707 .577 .707 r
F P
0 g
s
.39032 .6724 m .39032 .63534 L .35915 .63344 L p .707 .577 .707 r
F P
0 g
s
.39032 .63534 m .39032 .6724 L .42216 .67162 L p .707 .577 .707 r
F P
0 g
s
.42216 .67162 m .42216 .63457 L .39032 .63534 L p .707 .577 .707 r
F P
0 g
s
.64524 .64808 m .64524 .62955 L .66161 .62218 L p .707 .577 .707 r
F P
0 g
s
.42216 .62949 m .42216 .64802 L .45154 .64464 L p .707 .577 .707 r
F P
0 g
s
.45154 .64464 m .45154 .62611 L .42216 .62949 L p .707 .577 .707 r
F P
0 g
s
.64524 .67168 m .64524 .63462 L .66161 .62725 L p .707 .577 .707 r
F P
0 g
s
.42216 .63457 m .42216 .67162 L .45154 .66824 L p .707 .577 .707 r
F P
0 g
s
.45154 .66824 m .45154 .63119 L .42216 .63457 L p .707 .577 .707 r
F P
0 g
s
.35915 .62837 m .35915 .6469 L .39032 .6488 L p .707 .577 .707 r
F P
0 g
s
.35915 .6469 m .35915 .62837 L .33169 .62398 L p .707 .577 .707 r
F P
0 g
s
.66161 .62218 m .66161 .64071 L .64524 .64808 L p .707 .577 .707 r
F P
0 g
s
.35915 .6705 m .35915 .63344 L .33169 .62905 L p .707 .577 .707 r
F P
0 g
s
.35915 .63344 m .35915 .6705 L .39032 .6724 L p .707 .577 .707 r
F P
0 g
s
.45154 .60609 m .45154 .66167 L .47559 .65602 L p .707 .577 .707 r
F P
0 g
s
.47559 .65602 m .47559 .60044 L .45154 .60609 L p .707 .577 .707 r
F P
0 g
s
.33169 .62398 m .33169 .64251 L .35915 .6469 L p .707 .577 .707 r
F P
0 g
s
.66161 .60216 m .66161 .65774 L .64524 .66511 L p .707 .577 .707 r
F P
0 g
s
.82657 .6051 m .82657 .66068 L .80551 .65423 L p .707 .577 .707 r
F P
0 g
s
.80551 .65423 m .80551 .59864 L .82657 .6051 L p .707 .577 .707 r
F P
0 g
s
.66161 .62725 m .66161 .66431 L .64524 .67168 L p .707 .577 .707 r
F P
0 g
s
.45154 .62611 m .45154 .64464 L .47559 .63899 L p .707 .577 .707 r
F P
0 g
s
.47559 .63899 m .47559 .62046 L .45154 .62611 L p .707 .577 .707 r
F P
0 g
s
.45154 .63119 m .45154 .66824 L .47559 .66259 L p .707 .577 .707 r
F P
0 g
s
.47559 .66259 m .47559 .62554 L .45154 .63119 L p .707 .577 .707 r
F P
0 g
s
.33169 .60395 m .33169 .65954 L .35915 .66393 L p .707 .577 .707 r
F P
0 g
s
.33169 .65954 m .33169 .60395 L .31064 .5975 L p .707 .577 .707 r
F P
0 g
s
.82657 .62512 m .82657 .64365 L .80551 .6372 L p .707 .577 .707 r
F P
0 g
s
.80551 .6372 m .80551 .61867 L .82657 .62512 L p .707 .577 .707 r
F P
0 g
s
.33169 .62905 m .33169 .66611 L .35915 .6705 L p .707 .577 .707 r
F P
0 g
s
.82657 .6302 m .82657 .66725 L .80551 .6608 L p .707 .577 .707 r
F P
0 g
s
.80551 .6608 m .80551 .62374 L .82657 .6302 L p .707 .577 .707 r
F P
0 g
s
.33169 .64251 m .33169 .62398 L .31064 .61752 L p .707 .577 .707 r
F P
0 g
s
.66161 .65774 m .66161 .60216 L .68566 .59651 L p .707 .577 .707 r
F P
0 g
s
.33169 .66611 m .33169 .62905 L .31064 .6226 L p .707 .577 .707 r
F P
0 g
s
.31064 .61752 m .31064 .63605 L .33169 .64251 L p .707 .577 .707 r
F P
0 g
s
.66161 .64071 m .66161 .62218 L .68566 .61653 L p .707 .577 .707 r
F P
0 g
s
.47559 .60044 m .47559 .65602 L .49196 .64866 L p .707 .577 .707 r
F P
0 g
s
.49196 .64866 m .49196 .59307 L .47559 .60044 L p .707 .577 .707 r
F P
0 g
s
.66161 .66431 m .66161 .62725 L .68566 .62161 L p .707 .577 .707 r
F P
0 g
s
.31064 .5975 m .31064 .65308 L .33169 .65954 L p .707 .577 .707 r
F P
0 g
s
.68566 .61653 m .68566 .63506 L .66161 .64071 L p .707 .577 .707 r
F P
0 g
s
.31064 .6226 m .31064 .65965 L .33169 .66611 L p .707 .577 .707 r
F P
0 g
s
.47559 .62046 m .47559 .63899 L .49196 .63162 L p .707 .577 .707 r
F P
0 g
s
.49196 .63162 m .49196 .6131 L .47559 .62046 L p .707 .577 .707 r
F P
0 g
s
.80551 .59864 m .80551 .65423 L .77805 .64983 L p .707 .577 .707 r
F P
0 g
s
.77805 .64983 m .77805 .59425 L .80551 .59864 L p .707 .577 .707 r
F P
0 g
s
.47559 .62554 m .47559 .66259 L .49196 .65523 L p .707 .577 .707 r
F P
0 g
s
.49196 .65523 m .49196 .61817 L .47559 .62554 L p .707 .577 .707 r
F P
0 g
s
.68566 .59651 m .68566 .65209 L .66161 .65774 L p .707 .577 .707 r
F P
0 g
s
.31064 .65308 m .31064 .5975 L .29804 .58962 L p .707 .577 .707 r
F P
0 g
s
.68566 .62161 m .68566 .65866 L .66161 .66431 L p .707 .577 .707 r
F P
0 g
s
.80551 .61867 m .80551 .6372 L .77805 .6328 L p .707 .577 .707 r
F P
0 g
s
.77805 .6328 m .77805 .61428 L .80551 .61867 L p .707 .577 .707 r
F P
0 g
s
.80551 .62374 m .80551 .6608 L .77805 .6564 L p .707 .577 .707 r
F P
0 g
s
.77805 .6564 m .77805 .61935 L .80551 .62374 L p .707 .577 .707 r
F P
0 g
s
.68566 .65209 m .68566 .59651 L .71504 .59313 L p .707 .577 .707 r
F P
0 g
s
.31064 .63605 m .31064 .61752 L .29804 .60964 L p .707 .577 .707 r
F P
0 g
s
.31064 .65965 m .31064 .6226 L .29804 .61471 L p .707 .577 .707 r
F P
0 g
s
.68566 .63506 m .68566 .61653 L .71504 .61315 L p .707 .577 .707 r
F P
0 g
s
.68566 .65866 m .68566 .62161 L .71504 .61823 L p .707 .577 .707 r
F P
0 g
s
.29804 .60964 m .29804 .62817 L .31064 .63605 L p .707 .577 .707 r
F P
0 g
s
.77805 .59425 m .77805 .64983 L .74688 .64793 L p .707 .577 .707 r
F P
0 g
s
.74688 .64793 m .74688 .59235 L .77805 .59425 L p .707 .577 .707 r
F P
0 g
s
.71504 .61315 m .71504 .63168 L .68566 .63506 L p .707 .577 .707 r
F P
0 g
s
.29804 .58962 m .29804 .6452 L .31064 .65308 L p .707 .577 .707 r
F P
0 g
s
.71504 .64871 m .71504 .59313 L .74688 .59235 L p .707 .577 .707 r
F P
0 g
s
.71504 .59313 m .71504 .64871 L .68566 .65209 L p .707 .577 .707 r
F P
0 g
s
.49196 .59307 m .49196 .64866 L .49904 .64029 L p .707 .577 .707 r
F P
0 g
s
.49904 .64029 m .49904 .58471 L .49196 .59307 L p .707 .577 .707 r
F P
0 g
s
.77805 .61428 m .77805 .6328 L .74688 .6309 L p .707 .577 .707 r
F P
0 g
s
.74688 .6309 m .74688 .61237 L .77805 .61428 L p .707 .577 .707 r
F P
0 g
s
.29804 .61471 m .29804 .65177 L .31064 .65965 L p .707 .577 .707 r
F P
0 g
s
.74688 .59235 m .74688 .64793 L .71504 .64871 L p .707 .577 .707 r
F P
0 g
s
.77805 .61935 m .77805 .6564 L .74688 .6545 L p .707 .577 .707 r
F P
0 g
s
.74688 .6545 m .74688 .61745 L .77805 .61935 L p .707 .577 .707 r
F P
0 g
s
.71504 .61823 m .71504 .65528 L .68566 .65866 L p .707 .577 .707 r
F P
0 g
s
.71504 .63168 m .71504 .61315 L .74688 .61237 L p .707 .577 .707 r
F P
0 g
s
.49196 .6131 m .49196 .63162 L .49904 .62326 L p .707 .577 .707 r
F P
0 g
s
.49904 .62326 m .49904 .60473 L .49196 .6131 L p .707 .577 .707 r
F P
0 g
s
.71504 .65528 m .71504 .61823 L .74688 .61745 L p .707 .577 .707 r
F P
0 g
s
.49196 .61817 m .49196 .65523 L .49904 .64686 L p .707 .577 .707 r
F P
0 g
s
.49904 .64686 m .49904 .60981 L .49196 .61817 L p .707 .577 .707 r
F P
0 g
s
.74688 .61237 m .74688 .6309 L .71504 .63168 L p .707 .577 .707 r
F P
0 g
s
.74688 .61745 m .74688 .6545 L .71504 .65528 L p .707 .577 .707 r
F P
0 g
s
.29804 .6452 m .29804 .58962 L .29515 .58107 L p .707 .577 .707 r
F P
0 g
s
.29804 .62817 m .29804 .60964 L .29515 .6011 L p .707 .577 .707 r
F P
0 g
s
.29804 .65177 m .29804 .61471 L .29515 .60617 L p .707 .577 .707 r
F P
0 g
s
.29515 .6011 m .29515 .61962 L .29804 .62817 L p .707 .577 .707 r
F P
0 g
s
.29515 .58107 m .29515 .63666 L .29804 .6452 L p .707 .577 .707 r
F P
0 g
s
.29515 .60617 m .29515 .64323 L .29804 .65177 L p .707 .577 .707 r
F P
0 g
s
.49904 .58471 m .49904 .64029 L .49615 .63175 L p .707 .577 .707 r
F P
0 g
s
.49615 .63175 m .49615 .57617 L .49904 .58471 L p .707 .577 .707 r
F P
0 g
s
.49904 .60473 m .49904 .62326 L .49615 .61472 L p .707 .577 .707 r
F P
0 g
s
.49615 .61472 m .49615 .59619 L .49904 .60473 L p .707 .577 .707 r
F P
0 g
s
.49904 .60981 m .49904 .64686 L .49615 .63832 L p .707 .577 .707 r
F P
0 g
s
.49615 .63832 m .49615 .60126 L .49904 .60981 L p .707 .577 .707 r
F P
0 g
s
.29515 .63666 m .29515 .58107 L .30223 .57271 L p .707 .577 .707 r
F P
0 g
s
.29515 .61962 m .29515 .6011 L .30223 .59273 L p .707 .577 .707 r
F P
0 g
s
.29515 .64323 m .29515 .60617 L .30223 .59781 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .59273 m .30223 .61126 L .29515 .61962 L p .707 .577 .707 r
F P
0 g
s
.30223 .57271 m .30223 .62829 L .29515 .63666 L p .707 .577 .707 r
F P
0 g
s
.30223 .59781 m .30223 .63486 L .29515 .64323 L p .707 .577 .707 r
F P
0 g
s
.49615 .57617 m .49615 .63175 L .48356 .62386 L p .707 .577 .707 r
F P
0 g
s
.48356 .62386 m .48356 .56828 L .49615 .57617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .59619 m .49615 .61472 L .48356 .60683 L p .707 .577 .707 r
F P
0 g
s
.48356 .60683 m .48356 .58831 L .49615 .59619 L p .707 .577 .707 r
F P
0 g
s
.49615 .60126 m .49615 .63832 L .48356 .63044 L p .707 .577 .707 r
F P
0 g
s
.48356 .63044 m .48356 .59338 L .49615 .60126 L p .707 .577 .707 r
F P
0 g
s
.30223 .62829 m .30223 .57271 L .3186 .56534 L p .707 .577 .707 r
F P
0 g
s
.30223 .61126 m .30223 .59273 L .3186 .58537 L p .707 .577 .707 r
F P
0 g
s
.30223 .63486 m .30223 .59781 L .3186 .59044 L p .707 .577 .707 r
F P
0 g
s
.3186 .58537 m .3186 .60389 L .30223 .61126 L p .707 .577 .707 r
F P
0 g
s
.3186 .56534 m .3186 .62092 L .30223 .62829 L p .707 .577 .707 r
F P
0 g
s
.48356 .56828 m .48356 .62386 L .4625 .61741 L p .707 .577 .707 r
F P
0 g
s
.4625 .61741 m .4625 .56183 L .48356 .56828 L p .707 .577 .707 r
F P
0 g
s
.3186 .59044 m .3186 .62749 L .30223 .63486 L p .707 .577 .707 r
F P
0 g
s
.48356 .58831 m .48356 .60683 L .4625 .60038 L p .707 .577 .707 r
F P
0 g
s
.4625 .60038 m .4625 .58185 L .48356 .58831 L p .707 .577 .707 r
F P
0 g
s
.48356 .59338 m .48356 .63044 L .4625 .62398 L p .707 .577 .707 r
F P
0 g
s
.4625 .62398 m .4625 .58693 L .48356 .59338 L p .707 .577 .707 r
F P
0 g
s
.3186 .62092 m .3186 .56534 L .34265 .55969 L p .707 .577 .707 r
F P
0 g
s
.3186 .60389 m .3186 .58537 L .34265 .57972 L p .707 .577 .707 r
F P
0 g
s
.3186 .62749 m .3186 .59044 L .34265 .58479 L p .707 .577 .707 r
F P
0 g
s
.34265 .57972 m .34265 .59824 L .3186 .60389 L p .707 .577 .707 r
F P
0 g
s
.4625 .56183 m .4625 .61741 L .43504 .61302 L p .707 .577 .707 r
F P
0 g
s
.43504 .61302 m .43504 .55744 L .4625 .56183 L p .707 .577 .707 r
F P
0 g
s
.34265 .55969 m .34265 .61527 L .3186 .62092 L p .707 .577 .707 r
F P
0 g
s
.34265 .58479 m .34265 .62184 L .3186 .62749 L p .707 .577 .707 r
F P
0 g
s
.4625 .58185 m .4625 .60038 L .43504 .59599 L p .707 .577 .707 r
F P
0 g
s
.43504 .59599 m .43504 .57746 L .4625 .58185 L p .707 .577 .707 r
F P
0 g
s
.4625 .58693 m .4625 .62398 L .43504 .61959 L p .707 .577 .707 r
F P
0 g
s
.43504 .61959 m .43504 .58253 L .4625 .58693 L p .707 .577 .707 r
F P
0 g
s
.34265 .61527 m .34265 .55969 L .37203 .55631 L p .707 .577 .707 r
F P
0 g
s
.34265 .59824 m .34265 .57972 L .37203 .57634 L p .707 .577 .707 r
F P
0 g
s
.34265 .62184 m .34265 .58479 L .37203 .58141 L p .707 .577 .707 r
F P
0 g
s
.43504 .55744 m .43504 .61302 L .40387 .61112 L p .707 .577 .707 r
F P
0 g
s
.40387 .61112 m .40387 .55554 L .43504 .55744 L p .707 .577 .707 r
F P
0 g
s
.37203 .57634 m .37203 .59486 L .34265 .59824 L p .707 .577 .707 r
F P
0 g
s
.37203 .61189 m .37203 .55631 L .40387 .55554 L p .707 .577 .707 r
F P
0 g
s
.37203 .55631 m .37203 .61189 L .34265 .61527 L p .707 .577 .707 r
F P
0 g
s
.43504 .57746 m .43504 .59599 L .40387 .59409 L p .707 .577 .707 r
F P
0 g
s
.40387 .59409 m .40387 .57556 L .43504 .57746 L p .707 .577 .707 r
F P
0 g
s
.40387 .55554 m .40387 .61112 L .37203 .61189 L p .707 .577 .707 r
F P
0 g
s
.43504 .58253 m .43504 .61959 L .40387 .61769 L p .707 .577 .707 r
F P
0 g
s
.40387 .61769 m .40387 .58063 L .43504 .58253 L p .707 .577 .707 r
F P
0 g
s
.37203 .58141 m .37203 .61847 L .34265 .62184 L p .707 .577 .707 r
F P
0 g
s
.37203 .59486 m .37203 .57634 L .40387 .57556 L p .707 .577 .707 r
F P
0 g
s
.37203 .61847 m .37203 .58141 L .40387 .58063 L p .707 .577 .707 r
F P
0 g
s
.40387 .57556 m .40387 .59409 L .37203 .59486 L p .707 .577 .707 r
F P
0 g
s
.40387 .58063 m .40387 .61769 L .37203 .61847 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE
0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJEP`007Yoo`00MWoo1P0025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00Lgoo001aOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool30007
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P00
15YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo6P001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0>0004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`03001JEP0000AJEP03001JEP000080009JEP03001JEUYF00EJEPH000=JEQ<000AJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP80009JEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH900000eYF001JEP02FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH005YF
0P0000=JEP0000000P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000010000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@0
0005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000?OolB0014Ool005=oo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPP003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF0P001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo0`0015YF0`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYFFUHF0003FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH60003FUH8
00000eYF000000030004FUH01000FUIJEUYF1@0015YF00D005YFFUIJEP0002ioo`00Dgoo00<005YF
000015YF0P0015YF1`001eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP@0009JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEP0000800003
FUH005YF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YF00000`0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001J
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00
0eYF0P000eYF0P00;Goo001COol00`00FUH00003FUH60003FUH50002FUH00`00FUIJEP02FUH40006
FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP0000000UYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUHH0005FUH30003FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009J
EP03001JEUYF00=JEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH00000008002eoo`00Dgoo00<005YF00000`001EYF00<005YFFUH00eYF0`00
0UYF50000eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00Dgoo0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEP<0009JEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo5P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPD000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000cOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`000eYF0P001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000_Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH40002FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH40000
0eYF001JEP02FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP80009JEP8000EJEP<000=JEQX000=JEP<000=JEP8002eo
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01@0015YF00<005YFFUH0
0UYF200015YF00<005YFFUH00eYF200015YF00<005YFFUH00eYF3P000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF
00@005YFFUIJEPD00004FUH000000004FUH>0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
0000000]Ool002aoo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH60003FUH;0002FUH6
0004FUH01000FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;7oo00<005YF000015YF10000eYF1@000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`000UYF00<005YF00000P0000EJEP00FUIJEP00009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP07001JEUYFFUH005YF00001eYF00<005YFFUH0
1UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool01000
FUH005YF0P0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF1@000UYF0P000UYF00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo00@005YF000000=JEP8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L0009JEP03001JEUYF
00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPH0
00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo0`00
00EJEP00FUIJEP0000IJEP03001JEUYF00EJEPH000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000^Ool002aoo`@000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
0`0015YF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
<goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000EJEP8000QJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001J
EUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP8000IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000400000eYF001JEP04FUH00`00FUH0000H000oOol002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF009JEPT000QJEPP000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH40003FUH01000FUIJEUYF0P00
E7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP00009JEPD00003FUH00000008000=JEP8000Qoo`<004Uoo`00;7oo00<005YF00000eYF1P000eYF
1@000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF100000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EP0000800003FUH00000009JEP8000Moo`D004Qoo`00;7oo00@005YF001JEP8000AJEP8000MJEP04
001JEUYFFUHJ0003FUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00UYF0P0000=JEP0000000P001goo1@00B7oo000/Ool00`00FUH00003
0005FUH00`00FUIJEP02FUH40002FUHD0003FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH30000
0eYF00000007Ool50018Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP03
0008Ool30019Ool002aoo`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH015YF0P000UYF1P002EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol0031oo`<000=JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJEP8005Aoo`00<goo0`0000=J
EP00FUH01EYF0P001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000P000=JEP04001JEUYFFUH2
001DOol003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUH000070003FUH2001DOol003]oo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000Yoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040005FUH01000FUIJEP00
0UYF0P00E7oo0013OolC000?Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00B7oo0`006Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Ao
o`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001J
EUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00D0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00Agoo1@006Goo
00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo05Aoo`00B7oo0`006Woo00@005YFFUH000=JEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003
FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF008005Moo`00IGoo00D005YF
FUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00002FUH00`00FUIJEP04FUH3001IOol006Eo
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH01000FUIJ
EUYF1000Fgoo001UOol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF0000
0005001OOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH007oo06Aoo`00
IGoo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YF000006Eoo`00IGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUH006Eoo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001W
Ool006Moo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Moo`00JGoo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P00J7oo001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001]Ool20004FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000
K7oo001_Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH4001^Ool0079oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH00eYF2000Mgoo001lOolR001oOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .77742 m .59613 .72184 L .56496 .71994 L p .707 .577 .707 r
F P
0 g
s
.59613 .72184 m .59613 .77742 L .62796 .77665 L p .707 .577 .707 r
F P
0 g
s
.62796 .77665 m .62796 .72106 L .59613 .72184 L p .707 .577 .707 r
F P
0 g
s
.62796 .72106 m .62796 .77665 L .65735 .77327 L p .707 .577 .707 r
F P
0 g
s
.65735 .77327 m .65734 .71768 L .62796 .72106 L p .707 .577 .707 r
F P
0 g
s
.56496 .77552 m .56496 .71994 L .5375 .71555 L p .707 .577 .707 r
F P
0 g
s
.56496 .71994 m .56496 .77552 L .59613 .77742 L p .707 .577 .707 r
F P
0 g
s
.59613 .80454 m .59613 .76749 L .56496 .76558 L p .707 .577 .707 r
F P
0 g
s
.59613 .76749 m .59613 .80454 L .62796 .80376 L p .707 .577 .707 r
F P
0 g
s
.62796 .80376 m .62796 .76671 L .59613 .76749 L p .707 .577 .707 r
F P
0 g
s
.65734 .71768 m .65735 .77327 L .6814 .76762 L p .707 .577 .707 r
F P
0 g
s
.6814 .76762 m .6814 .71203 L .65734 .71768 L p .707 .577 .707 r
F P
0 g
s
.62796 .76671 m .62796 .80376 L .65735 .80038 L p .707 .577 .707 r
F P
0 g
s
.65735 .80038 m .65735 .76333 L .62796 .76671 L p .707 .577 .707 r
F P
0 g
s
.59613 .80593 m .59613 .78741 L .56496 .7855 L p .707 .577 .707 r
F P
0 g
s
.59613 .78741 m .59613 .80593 L .62796 .80516 L p .707 .577 .707 r
F P
0 g
s
.62796 .80516 m .62796 .78663 L .59613 .78741 L p .707 .577 .707 r
F P
0 g
s
.56496 .80264 m .56496 .76558 L .5375 .76119 L p .707 .577 .707 r
F P
0 g
s
.56496 .76558 m .56496 .80264 L .59613 .80454 L p .707 .577 .707 r
F P
0 g
s
.62796 .78663 m .62796 .80516 L .65735 .80178 L p .707 .577 .707 r
F P
0 g
s
.65735 .80178 m .65735 .78325 L .62796 .78663 L p .707 .577 .707 r
F P
0 g
s
.5375 .71555 m .5375 .77113 L .56496 .77552 L p .707 .577 .707 r
F P
0 g
s
.5375 .77113 m .5375 .71555 L .51644 .70909 L p .707 .577 .707 r
F P
0 g
s
.56496 .7855 m .56496 .80403 L .59613 .80593 L p .707 .577 .707 r
F P
0 g
s
.56496 .80403 m .56496 .7855 L .5375 .78111 L p .707 .577 .707 r
F P
0 g
s
.65735 .76333 m .65735 .80038 L .6814 .79473 L p .707 .577 .707 r
F P
0 g
s
.6814 .79473 m .6814 .75768 L .65735 .76333 L p .707 .577 .707 r
F P
0 g
s
.5375 .76119 m .5375 .79825 L .56496 .80264 L p .707 .577 .707 r
F P
0 g
s
.5375 .78111 m .5375 .79964 L .56496 .80403 L p .707 .577 .707 r
F P
0 g
s
.65735 .78325 m .65735 .80178 L .6814 .79613 L p .707 .577 .707 r
F P
0 g
s
.6814 .79613 m .6814 .7776 L .65735 .78325 L p .707 .577 .707 r
F P
0 g
s
.6814 .71203 m .6814 .76762 L .69777 .76025 L p .707 .577 .707 r
F P
0 g
s
.69777 .76025 m .69777 .70467 L .6814 .71203 L p .707 .577 .707 r
F P
0 g
s
.5375 .79825 m .5375 .76119 L .51644 .75474 L p .707 .577 .707 r
F P
0 g
s
.51644 .70909 m .51644 .76468 L .5375 .77113 L p .707 .577 .707 r
F P
0 g
s
.5375 .79964 m .5375 .78111 L .51644 .77466 L p .707 .577 .707 r
F P
0 g
s
.51644 .75474 m .51644 .79179 L .5375 .79825 L p .707 .577 .707 r
F P
0 g
s
.51644 .76468 m .51644 .70909 L .50385 .70121 L p .707 .577 .707 r
F P
0 g
s
.51644 .77466 m .51644 .79319 L .5375 .79964 L p .707 .577 .707 r
F P
0 g
s
.6814 .75768 m .6814 .79473 L .69777 .78737 L p .707 .577 .707 r
F P
0 g
s
.69777 .78737 m .69777 .75031 L .6814 .75768 L p .707 .577 .707 r
F P
0 g
s
.6814 .7776 m .6814 .79613 L .69777 .78876 L p .707 .577 .707 r
F P
0 g
s
.69777 .78876 m .69777 .77023 L .6814 .7776 L p .707 .577 .707 r
F P
0 g
s
.51644 .79179 m .51644 .75474 L .50385 .74685 L p .707 .577 .707 r
F P
0 g
s
.50385 .70121 m .50385 .75679 L .51644 .76468 L p .707 .577 .707 r
F P
0 g
s
.69777 .70467 m .69777 .76025 L .70485 .75188 L p .707 .577 .707 r
F P
0 g
s
.70485 .75188 m .70485 .6963 L .69777 .70467 L p .707 .577 .707 r
F P
0 g
s
.51644 .79319 m .51644 .77466 L .50385 .76677 L p .707 .577 .707 r
F P
0 g
s
.50385 .74685 m .50385 .78391 L .51644 .79179 L p .707 .577 .707 r
F P
0 g
s
.50385 .76677 m .50385 .7853 L .51644 .79319 L p .707 .577 .707 r
F P
0 g
s
.50385 .75679 m .50385 .70121 L .50095 .69267 L p .707 .577 .707 r
F P
0 g
s
.69777 .75031 m .69777 .78737 L .70485 .779 L p .707 .577 .707 r
F P
0 g
s
.70485 .779 m .70485 .74195 L .69777 .75031 L p .707 .577 .707 r
F P
0 g
s
.69777 .77023 m .69777 .78876 L .70485 .7804 L p .707 .577 .707 r
F P
0 g
s
.70485 .7804 m .70485 .76187 L .69777 .77023 L p .707 .577 .707 r
F P
0 g
s
.50385 .78391 m .50385 .74685 L .50095 .73831 L p .707 .577 .707 r
F P
0 g
s
.50095 .69267 m .50095 .74825 L .50385 .75679 L p .707 .577 .707 r
F P
0 g
s
.70485 .6963 m .70485 .75188 L .70195 .74334 L p .707 .577 .707 r
F P
0 g
s
.70195 .74334 m .70195 .68776 L .70485 .6963 L p .707 .577 .707 r
F P
0 g
s
.50385 .7853 m .50385 .76677 L .50095 .75823 L p .707 .577 .707 r
F P
0 g
s
.50095 .73831 m .50095 .77537 L .50385 .78391 L p .707 .577 .707 r
F P
0 g
s
.50095 .75823 m .50095 .77676 L .50385 .7853 L p .707 .577 .707 r
F P
0 g
s
.49044 .83764 m .49044 .33575 L .44643 .33307 L p .707 .577 .707 r
F P
0 g
s
.50095 .74825 m .50095 .69267 L .50804 .6843 L p .707 .577 .707 r
F P
0 g
s
.50095 .77537 m .50095 .73831 L .50804 .72995 L p .707 .577 .707 r
F P
0 g
s
.50804 .6843 m .50804 .73989 L .50095 .74825 L p .707 .577 .707 r
F P
0 g
s
.50095 .77676 m .50095 .75823 L .50804 .74987 L p .707 .577 .707 r
F P
0 g
s
.50804 .72995 m .50804 .767 L .50095 .77537 L p .707 .577 .707 r
F P
0 g
s
.50804 .74987 m .50804 .7684 L .50095 .77676 L p .707 .577 .707 r
F P
0 g
s
.50804 .73989 m .50804 .6843 L .5244 .67694 L p .707 .577 .707 r
F P
0 g
s
.50804 .767 m .50804 .72995 L .5244 .72258 L p .707 .577 .707 r
F P
0 g
s
.5244 .67694 m .5244 .73252 L .50804 .73989 L p .707 .577 .707 r
F P
0 g
s
.50804 .7684 m .50804 .74987 L .5244 .7425 L p .707 .577 .707 r
F P
0 g
s
.5244 .72258 m .5244 .75963 L .50804 .767 L p .707 .577 .707 r
F P
0 g
s
.5244 .7425 m .5244 .76103 L .50804 .7684 L p .707 .577 .707 r
F P
0 g
s
.5244 .73252 m .5244 .67694 L .54846 .67129 L p .707 .577 .707 r
F P
0 g
s
.5244 .75963 m .5244 .72258 L .54846 .71693 L p .707 .577 .707 r
F P
0 g
s
.54846 .67129 m .54846 .72687 L .5244 .73252 L p .707 .577 .707 r
F P
0 g
s
.5244 .76103 m .5244 .7425 L .54846 .73685 L p .707 .577 .707 r
F P
0 g
s
.54846 .71693 m .54846 .75399 L .5244 .75963 L p .707 .577 .707 r
F P
0 g
s
.54846 .73685 m .54846 .75538 L .5244 .76103 L p .707 .577 .707 r
F P
0 g
s
.49044 .33575 m .49044 .83764 L .53538 .83654 L p .707 .577 .707 r
F P
0 g
s
.53538 .83654 m .53538 .33466 L .49044 .33575 L p .707 .577 .707 r
F P
0 g
s
.54846 .72687 m .54846 .67129 L .57784 .66791 L p .707 .577 .707 r
F P
0 g
s
.57784 .66791 m .57784 .72349 L .54846 .72687 L p .707 .577 .707 r
F P
0 g
s
.54846 .75399 m .54846 .71693 L .57784 .71355 L p .707 .577 .707 r
F P
0 g
s
.54846 .75538 m .54846 .73685 L .57784 .73347 L p .707 .577 .707 r
F P
0 g
s
.57784 .71355 m .57784 .75061 L .54846 .75399 L p .707 .577 .707 r
F P
0 g
s
.57784 .73347 m .57784 .752 L .54846 .75538 L p .707 .577 .707 r
F P
0 g
s
.53538 .33466 m .53538 .83654 L .57686 .83177 L p .707 .577 .707 r
F P
0 g
s
.57686 .83177 m .57686 .32989 L .53538 .33466 L p .707 .577 .707 r
F P
0 g
s
.70485 .74195 m .70485 .779 L .70195 .77046 L p .707 .577 .707 r
F P
0 g
s
.70195 .77046 m .70195 .73341 L .70485 .74195 L p .707 .577 .707 r
F P
0 g
s
.44643 .83496 m .44643 .33307 L .40766 .32687 L p .707 .577 .707 r
F P
0 g
s
.44643 .33307 m .44643 .83496 L .49044 .83764 L p .707 .577 .707 r
F P
0 g
s
.70485 .76187 m .70485 .7804 L .70195 .77185 L p .707 .577 .707 r
F P
0 g
s
.70195 .77185 m .70195 .75333 L .70485 .76187 L p .707 .577 .707 r
F P
0 g
s
.57784 .72349 m .57784 .66791 L .60968 .66713 L p .707 .577 .707 r
F P
0 g
s
.60968 .66713 m .60968 .72271 L .57784 .72349 L p .707 .577 .707 r
F P
0 g
s
.57784 .75061 m .57784 .71355 L .60968 .71277 L p .707 .577 .707 r
F P
0 g
s
.60968 .71277 m .60968 .74983 L .57784 .75061 L p .707 .577 .707 r
F P
0 g
s
.57784 .752 m .57784 .73347 L .60968 .73269 L p .707 .577 .707 r
F P
0 g
s
.60968 .73269 m .60968 .75122 L .57784 .752 L p .707 .577 .707 r
F P
0 g
s
.57686 .32989 m .57686 .83177 L .61082 .8238 L p .707 .577 .707 r
F P
0 g
s
.64085 .66903 m .64085 .72461 L .60968 .72271 L p .707 .577 .707 r
F P
0 g
s
.60968 .72271 m .60968 .66713 L .64085 .66903 L p .707 .577 .707 r
F P
0 g
s
.64085 .71467 m .64085 .75173 L .60968 .74983 L p .707 .577 .707 r
F P
0 g
s
.60968 .74983 m .60968 .71277 L .64085 .71467 L p .707 .577 .707 r
F P
0 g
s
.64085 .7346 m .64085 .75312 L .60968 .75122 L p .707 .577 .707 r
F P
0 g
s
.60968 .75122 m .60968 .73269 L .64085 .7346 L p .707 .577 .707 r
F P
0 g
s
.61082 .8238 m .61082 .32191 L .57686 .32989 L p .707 .577 .707 r
F P
0 g
s
.70195 .68776 m .70195 .74334 L .68936 .73546 L p .707 .577 .707 r
F P
0 g
s
.68936 .73546 m .68936 .67988 L .70195 .68776 L p .707 .577 .707 r
F P
0 g
s
.40766 .82876 m .40766 .32687 L .37794 .31776 L p .707 .577 .707 r
F P
0 g
s
.40766 .32687 m .40766 .82876 L .44643 .83496 L p .707 .577 .707 r
F P
0 g
s
.25312 .74061 m .25312 .68503 L .22195 .68312 L p .707 .577 .707 r
F P
0 g
s
.25312 .68503 m .25312 .74061 L .28495 .73983 L p .707 .577 .707 r
F P
0 g
s
.28495 .73983 m .28495 .68425 L .25312 .68503 L p .707 .577 .707 r
F P
0 g
s
.28495 .68425 m .28495 .73983 L .31434 .73645 L p .707 .577 .707 r
F P
0 g
s
.31434 .73645 m .31434 .68087 L .28495 .68425 L p .707 .577 .707 r
F P
0 g
s
.70195 .73341 m .70195 .77046 L .68936 .76258 L p .707 .577 .707 r
F P
0 g
s
.68936 .76258 m .68936 .72552 L .70195 .73341 L p .707 .577 .707 r
F P
0 g
s
.22195 .73871 m .22195 .68312 L .19449 .67873 L p .707 .577 .707 r
F P
0 g
s
.22195 .68312 m .22195 .73871 L .25312 .74061 L p .707 .577 .707 r
F P
0 g
s
.70195 .75333 m .70195 .77185 L .68936 .76397 L p .707 .577 .707 r
F P
0 g
s
.68936 .76397 m .68936 .74544 L .70195 .75333 L p .707 .577 .707 r
F P
0 g
s
.25312 .76772 m .25312 .73067 L .22195 .72877 L p .707 .577 .707 r
F P
0 g
s
.25312 .73067 m .25312 .76772 L .28495 .76695 L p .707 .577 .707 r
F P
0 g
s
.28495 .76695 m .28495 .72989 L .25312 .73067 L p .707 .577 .707 r
F P
0 g
s
.31434 .68087 m .31434 .73645 L .33839 .7308 L p .707 .577 .707 r
F P
0 g
s
.33839 .7308 m .33839 .67522 L .31434 .68087 L p .707 .577 .707 r
F P
0 g
s
.28495 .72989 m .28495 .76695 L .31434 .76357 L p .707 .577 .707 r
F P
0 g
s
.31434 .76357 m .31434 .72651 L .28495 .72989 L p .707 .577 .707 r
F P
0 g
s
.61082 .32191 m .61082 .8238 L .63393 .8134 L p .707 .577 .707 r
F P
0 g
s
.63393 .8134 m .63393 .31151 L .61082 .32191 L p .707 .577 .707 r
F P
0 g
s
.25312 .76912 m .25312 .75059 L .22195 .74869 L p .707 .577 .707 r
F P
0 g
s
.25312 .75059 m .25312 .76912 L .28495 .76834 L p .707 .577 .707 r
F P
0 g
s
.28495 .76834 m .28495 .74981 L .25312 .75059 L p .707 .577 .707 r
F P
0 g
s
.68936 .67988 m .68936 .73546 L .66831 .729 L p .707 .577 .707 r
F P
0 g
s
.66831 .729 m .66831 .67342 L .68936 .67988 L p .707 .577 .707 r
F P
0 g
s
.22195 .76582 m .22195 .72877 L .19449 .72438 L p .707 .577 .707 r
F P
0 g
s
.22195 .72877 m .22195 .76582 L .25312 .76772 L p .707 .577 .707 r
F P
0 g
s
.28495 .74981 m .28495 .76834 L .31434 .76496 L p .707 .577 .707 r
F P
0 g
s
.31434 .76496 m .31434 .74643 L .28495 .74981 L p .707 .577 .707 r
F P
0 g
s
.19449 .67873 m .19449 .73431 L .22195 .73871 L p .707 .577 .707 r
F P
0 g
s
.19449 .73431 m .19449 .67873 L .17343 .67228 L p .707 .577 .707 r
F P
0 g
s
.22195 .74869 m .22195 .76722 L .25312 .76912 L p .707 .577 .707 r
F P
0 g
s
.22195 .76722 m .22195 .74869 L .19449 .7443 L p .707 .577 .707 r
F P
0 g
s
.31434 .72651 m .31434 .76357 L .33839 .75792 L p .707 .577 .707 r
F P
0 g
s
.33839 .75792 m .33839 .72086 L .31434 .72651 L p .707 .577 .707 r
F P
0 g
s
.19449 .72438 m .19449 .76143 L .22195 .76582 L p .707 .577 .707 r
F P
0 g
s
.19449 .7443 m .19449 .76282 L .22195 .76722 L p .707 .577 .707 r
F P
0 g
s
.37794 .81965 m .37794 .31776 L .36016 .30663 L p .707 .577 .707 r
F P
0 g
s
.37794 .31776 m .37794 .81965 L .40766 .82876 L p .707 .577 .707 r
F P
0 g
s
.68936 .72552 m .68936 .76258 L .66831 .75612 L p .707 .577 .707 r
F P
0 g
s
.66831 .75612 m .66831 .71907 L .68936 .72552 L p .707 .577 .707 r
F P
0 g
s
.31434 .74643 m .31434 .76496 L .33839 .75931 L p .707 .577 .707 r
F P
0 g
s
.33839 .75931 m .33839 .74078 L .31434 .74643 L p .707 .577 .707 r
F P
0 g
s
.33839 .67522 m .33839 .7308 L .35476 .72343 L p .707 .577 .707 r
F P
0 g
s
.35476 .72343 m .35476 .66785 L .33839 .67522 L p .707 .577 .707 r
F P
0 g
s
.19449 .76143 m .19449 .72438 L .17343 .71792 L p .707 .577 .707 r
F P
0 g
s
.68936 .74544 m .68936 .76397 L .66831 .75751 L p .707 .577 .707 r
F P
0 g
s
.66831 .75751 m .66831 .73899 L .68936 .74544 L p .707 .577 .707 r
F P
0 g
s
.17343 .67228 m .17343 .72786 L .19449 .73431 L p .707 .577 .707 r
F P
0 g
s
.19449 .76282 m .19449 .7443 L .17343 .73784 L p .707 .577 .707 r
F P
0 g
s
.66831 .67342 m .66831 .729 L .64085 .72461 L p .707 .577 .707 r
F P
0 g
s
.64085 .72461 m .64085 .66903 L .66831 .67342 L p .707 .577 .707 r
F P
0 g
s
.17343 .71792 m .17343 .75498 L .19449 .76143 L p .707 .577 .707 r
F P
0 g
s
.17343 .72786 m .17343 .67228 L .16084 .66439 L p .707 .577 .707 r
F P
0 g
s
.17343 .73784 m .17343 .75637 L .19449 .76282 L p .707 .577 .707 r
F P
0 g
s
.33839 .72086 m .33839 .75792 L .35476 .75055 L p .707 .577 .707 r
F P
0 g
s
.35476 .75055 m .35476 .7135 L .33839 .72086 L p .707 .577 .707 r
F P
0 g
s
.66831 .71907 m .66831 .75612 L .64085 .75173 L p .707 .577 .707 r
F P
0 g
s
.64085 .75173 m .64085 .71467 L .66831 .71907 L p .707 .577 .707 r
F P
0 g
s
.66831 .73899 m .66831 .75751 L .64085 .75312 L p .707 .577 .707 r
F P
0 g
s
.64085 .75312 m .64085 .7346 L .66831 .73899 L p .707 .577 .707 r
F P
0 g
s
.63393 .31151 m .63393 .8134 L .64393 .80159 L p .707 .577 .707 r
F P
0 g
s
.64393 .80159 m .64393 .2997 L .63393 .31151 L p .707 .577 .707 r
F P
0 g
s
.33839 .74078 m .33839 .75931 L .35476 .75194 L p .707 .577 .707 r
F P
0 g
s
.35476 .75194 m .35476 .73342 L .33839 .74078 L p .707 .577 .707 r
F P
0 g
s
.17343 .75498 m .17343 .71792 L .16084 .71004 L p .707 .577 .707 r
F P
0 g
s
.16084 .66439 m .16084 .71998 L .17343 .72786 L p .707 .577 .707 r
F P
0 g
s
.35476 .66785 m .35476 .72343 L .36184 .71507 L p .707 .577 .707 r
F P
0 g
s
.36184 .71507 m .36184 .65949 L .35476 .66785 L p .707 .577 .707 r
F P
0 g
s
.17343 .75637 m .17343 .73784 L .16084 .72996 L p .707 .577 .707 r
F P
0 g
s
.16084 .71004 m .16084 .74709 L .17343 .75498 L p .707 .577 .707 r
F P
0 g
s
.16084 .72996 m .16084 .74849 L .17343 .75637 L p .707 .577 .707 r
F P
0 g
s
.35476 .7135 m .35476 .75055 L .36184 .74219 L p .707 .577 .707 r
F P
0 g
s
.36184 .74219 m .36184 .70513 L .35476 .7135 L p .707 .577 .707 r
F P
0 g
s
.35476 .73342 m .35476 .75194 L .36184 .74358 L p .707 .577 .707 r
F P
0 g
s
.36184 .74358 m .36184 .72505 L .35476 .73342 L p .707 .577 .707 r
F P
0 g
s
.36184 .65949 m .36184 .71507 L .35894 .70653 L p .707 .577 .707 r
F P
0 g
s
.35894 .70653 m .35894 .65095 L .36184 .65949 L p .707 .577 .707 r
F P
0 g
s
.36184 .70513 m .36184 .74219 L .35894 .73364 L p .707 .577 .707 r
F P
0 g
s
.35894 .73364 m .35894 .69659 L .36184 .70513 L p .707 .577 .707 r
F P
0 g
s
.36184 .72505 m .36184 .74358 L .35894 .73504 L p .707 .577 .707 r
F P
0 g
s
.35894 .73504 m .35894 .71651 L .36184 .72505 L p .707 .577 .707 r
F P
0 g
s
.35894 .65095 m .35894 .70653 L .34635 .69864 L p .707 .577 .707 r
F P
0 g
s
.34635 .69864 m .34635 .64306 L .35894 .65095 L p .707 .577 .707 r
F P
0 g
s
.36016 .80852 m .36016 .30663 L .35607 .29457 L p .707 .577 .707 r
F P
0 g
s
.36016 .30663 m .36016 .80852 L .37794 .81965 L p .707 .577 .707 r
F P
0 g
s
.16084 .71998 m .16084 .66439 L .15794 .65585 L p .707 .577 .707 r
F P
0 g
s
.16084 .74709 m .16084 .71004 L .15794 .7015 L p .707 .577 .707 r
F P
0 g
s
.15794 .65585 m .15794 .71143 L .16084 .71998 L p .707 .577 .707 r
F P
0 g
s
.16084 .74849 m .16084 .72996 L .15794 .72142 L p .707 .577 .707 r
F P
0 g
s
.64393 .2997 m .64393 .80159 L .63984 .78953 L p .707 .577 .707 r
F P
0 g
s
.63984 .78953 m .63984 .28764 L .64393 .2997 L p .707 .577 .707 r
F P
0 g
s
.15794 .7015 m .15794 .73855 L .16084 .74709 L p .707 .577 .707 r
F P
0 g
s
.15794 .72142 m .15794 .73994 L .16084 .74849 L p .707 .577 .707 r
F P
0 g
s
.15794 .71143 m .15794 .65585 L .16503 .64749 L p .707 .577 .707 r
F P
0 g
s
.35894 .69659 m .35894 .73364 L .34635 .72576 L p .707 .577 .707 r
F P
0 g
s
.34635 .72576 m .34635 .68871 L .35894 .69659 L p .707 .577 .707 r
F P
0 g
s
.35894 .71651 m .35894 .73504 L .34635 .72715 L p .707 .577 .707 r
F P
0 g
s
.34635 .72715 m .34635 .70863 L .35894 .71651 L p .707 .577 .707 r
F P
0 g
s
.35607 .29457 m .35607 .79646 L .36016 .80852 L p .707 .577 .707 r
F P
0 g
s
.35607 .79646 m .35607 .29457 L .36607 .28276 L p .707 .577 .707 r
F P
0 g
s
.15794 .73855 m .15794 .7015 L .16503 .69313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .64749 m .16503 .70307 L .15794 .71143 L p .707 .577 .707 r
F P
0 g
s
.15794 .73994 m .15794 .72142 L .16503 .71305 L p .707 .577 .707 r
F P
0 g
s
.16503 .69313 m .16503 .73019 L .15794 .73855 L p .707 .577 .707 r
F P
0 g
s
.16503 .71305 m .16503 .73158 L .15794 .73994 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70307 m .16503 .64749 L .1814 .64012 L p .707 .577 .707 r
F P
0 g
s
.63984 .28764 m .63984 .78953 L .62206 .7784 L p .707 .577 .707 r
F P
0 g
s
.62206 .7784 m .62206 .27651 L .63984 .28764 L p .707 .577 .707 r
F P
0 g
s
.16503 .73019 m .16503 .69313 L .1814 .68576 L p .707 .577 .707 r
F P
0 g
s
.1814 .64012 m .1814 .6957 L .16503 .70307 L p .707 .577 .707 r
F P
0 g
s
.34635 .64306 m .34635 .69864 L .3253 .69219 L p .707 .577 .707 r
F P
0 g
s
.3253 .69219 m .3253 .63661 L .34635 .64306 L p .707 .577 .707 r
F P
0 g
s
.16503 .73158 m .16503 .71305 L .1814 .70569 L p .707 .577 .707 r
F P
0 g
s
.36607 .78465 m .36607 .28276 L .38918 .27236 L p .707 .577 .707 r
F P
0 g
s
.36607 .28276 m .36607 .78465 L .35607 .79646 L p .707 .577 .707 r
F P
0 g
s
.1814 .68576 m .1814 .72282 L .16503 .73019 L p .707 .577 .707 r
F P
0 g
s
.1814 .70569 m .1814 .72421 L .16503 .73158 L p .707 .577 .707 r
F P
0 g
s
.1814 .6957 m .1814 .64012 L .20545 .63447 L p .707 .577 .707 r
F P
0 g
s
.34635 .68871 m .34635 .72576 L .3253 .71931 L p .707 .577 .707 r
F P
0 g
s
.3253 .71931 m .3253 .68225 L .34635 .68871 L p .707 .577 .707 r
F P
0 g
s
.34635 .70863 m .34635 .72715 L .3253 .7207 L p .707 .577 .707 r
F P
0 g
s
.3253 .7207 m .3253 .70217 L .34635 .70863 L p .707 .577 .707 r
F P
0 g
s
.3253 .63661 m .3253 .69219 L .29784 .6878 L p .707 .577 .707 r
F P
0 g
s
.29784 .6878 m .29784 .63221 L .3253 .63661 L p .707 .577 .707 r
F P
0 g
s
.1814 .72282 m .1814 .68576 L .20545 .68011 L p .707 .577 .707 r
F P
0 g
s
.20545 .63447 m .20545 .69005 L .1814 .6957 L p .707 .577 .707 r
F P
0 g
s
.62206 .27651 m .62206 .7784 L .59233 .76929 L p .707 .577 .707 r
F P
0 g
s
.59233 .76929 m .59233 .2674 L .62206 .27651 L p .707 .577 .707 r
F P
0 g
s
.1814 .72421 m .1814 .70569 L .20545 .70004 L p .707 .577 .707 r
F P
0 g
s
.20545 .69005 m .20545 .63447 L .23483 .63109 L p .707 .577 .707 r
F P
0 g
s
.20545 .68011 m .20545 .71717 L .1814 .72282 L p .707 .577 .707 r
F P
0 g
s
.20545 .70004 m .20545 .71856 L .1814 .72421 L p .707 .577 .707 r
F P
0 g
s
.3253 .68225 m .3253 .71931 L .29784 .71491 L p .707 .577 .707 r
F P
0 g
s
.29784 .71491 m .29784 .67786 L .3253 .68225 L p .707 .577 .707 r
F P
0 g
s
.29784 .63221 m .29784 .6878 L .26667 .6859 L p .707 .577 .707 r
F P
0 g
s
.26667 .6859 m .26667 .63031 L .29784 .63221 L p .707 .577 .707 r
F P
0 g
s
.3253 .70217 m .3253 .7207 L .29784 .71631 L p .707 .577 .707 r
F P
0 g
s
.29784 .71631 m .29784 .69778 L .3253 .70217 L p .707 .577 .707 r
F P
0 g
s
.38918 .27236 m .38918 .77425 L .36607 .78465 L p .707 .577 .707 r
F P
0 g
s
.38918 .77425 m .38918 .27236 L .42314 .26438 L p .707 .577 .707 r
F P
0 g
s
.23483 .68667 m .23483 .63109 L .26667 .63031 L p .707 .577 .707 r
F P
0 g
s
.23483 .63109 m .23483 .68667 L .20545 .69005 L p .707 .577 .707 r
F P
0 g
s
.20545 .71717 m .20545 .68011 L .23483 .67674 L p .707 .577 .707 r
F P
0 g
s
.26667 .63031 m .26667 .6859 L .23483 .68667 L p .707 .577 .707 r
F P
0 g
s
.73333 .68538 m .73333 .6298 L .70216 .6279 L p .707 .577 .707 r
F P
0 g
s
.73333 .6298 m .73333 .68538 L .76517 .68461 L p .707 .577 .707 r
F P
0 g
s
.76517 .68461 m .76517 .62903 L .73333 .6298 L p .707 .577 .707 r
F P
0 g
s
.20545 .71856 m .20545 .70004 L .23483 .69666 L p .707 .577 .707 r
F P
0 g
s
.76517 .62903 m .76517 .68461 L .79455 .68123 L p .707 .577 .707 r
F P
0 g
s
.79455 .68123 m .79455 .62565 L .76517 .62903 L p .707 .577 .707 r
F P
0 g
s
.29784 .67786 m .29784 .71491 L .26667 .71301 L p .707 .577 .707 r
F P
0 g
s
.26667 .71301 m .26667 .67596 L .29784 .67786 L p .707 .577 .707 r
F P
0 g
s
.23483 .67674 m .23483 .71379 L .20545 .71717 L p .707 .577 .707 r
F P
0 g
s
.23483 .69666 m .23483 .71518 L .20545 .71856 L p .707 .577 .707 r
F P
0 g
s
.70216 .68348 m .70216 .6279 L .6747 .62351 L p .707 .577 .707 r
F P
0 g
s
.70216 .6279 m .70216 .68348 L .73333 .68538 L p .707 .577 .707 r
F P
0 g
s
.23483 .71379 m .23483 .67674 L .26667 .67596 L p .707 .577 .707 r
F P
0 g
s
.29784 .69778 m .29784 .71631 L .26667 .71441 L p .707 .577 .707 r
F P
0 g
s
.26667 .71441 m .26667 .69588 L .29784 .69778 L p .707 .577 .707 r
F P
0 g
s
.26667 .67596 m .26667 .71301 L .23483 .71379 L p .707 .577 .707 r
F P
0 g
s
.73333 .7125 m .73333 .67545 L .70216 .67355 L p .707 .577 .707 r
F P
0 g
s
.73333 .67545 m .73333 .7125 L .76517 .71172 L p .707 .577 .707 r
F P
0 g
s
.76517 .71172 m .76517 .67467 L .73333 .67545 L p .707 .577 .707 r
F P
0 g
s
.59233 .2674 m .59233 .76929 L .55357 .76309 L p .707 .577 .707 r
F P
0 g
s
.55357 .76309 m .55357 .2612 L .59233 .2674 L p .707 .577 .707 r
F P
0 g
s
.23483 .71518 m .23483 .69666 L .26667 .69588 L p .707 .577 .707 r
F P
0 g
s
.79455 .62565 m .79455 .68123 L .8186 .67558 L p .707 .577 .707 r
F P
0 g
s
.8186 .67558 m .8186 .62 L .79455 .62565 L p .707 .577 .707 r
F P
0 g
s
.76517 .67467 m .76517 .71172 L .79455 .70835 L p .707 .577 .707 r
F P
0 g
s
.79455 .70835 m .79455 .67129 L .76517 .67467 L p .707 .577 .707 r
F P
0 g
s
.26667 .69588 m .26667 .71441 L .23483 .71518 L p .707 .577 .707 r
F P
0 g
s
.73333 .71389 m .73333 .69537 L .70216 .69347 L p .707 .577 .707 r
F P
0 g
s
.73333 .69537 m .73333 .71389 L .76517 .71312 L p .707 .577 .707 r
F P
0 g
s
.76517 .71312 m .76517 .69459 L .73333 .69537 L p .707 .577 .707 r
F P
0 g
s
.70216 .7106 m .70216 .67355 L .6747 .66915 L p .707 .577 .707 r
F P
0 g
s
.70216 .67355 m .70216 .7106 L .73333 .7125 L p .707 .577 .707 r
F P
0 g
s
.76517 .69459 m .76517 .71312 L .79455 .70974 L p .707 .577 .707 r
F P
0 g
s
.79455 .70974 m .79455 .69121 L .76517 .69459 L p .707 .577 .707 r
F P
0 g
s
.6747 .62351 m .6747 .67909 L .70216 .68348 L p .707 .577 .707 r
F P
0 g
s
.6747 .67909 m .6747 .62351 L .65365 .61706 L p .707 .577 .707 r
F P
0 g
s
.70216 .69347 m .70216 .71199 L .73333 .71389 L p .707 .577 .707 r
F P
0 g
s
.42314 .76627 m .42314 .26438 L .46462 .25961 L p .707 .577 .707 r
F P
0 g
s
.42314 .26438 m .42314 .76627 L .38918 .77425 L p .707 .577 .707 r
F P
0 g
s
.70216 .71199 m .70216 .69347 L .6747 .68907 L p .707 .577 .707 r
F P
0 g
s
.79455 .67129 m .79455 .70835 L .8186 .7027 L p .707 .577 .707 r
F P
0 g
s
.8186 .7027 m .8186 .66564 L .79455 .67129 L p .707 .577 .707 r
F P
0 g
s
.6747 .66915 m .6747 .70621 L .70216 .7106 L p .707 .577 .707 r
F P
0 g
s
.6747 .68907 m .6747 .7076 L .70216 .71199 L p .707 .577 .707 r
F P
0 g
s
.79455 .69121 m .79455 .70974 L .8186 .70409 L p .707 .577 .707 r
F P
0 g
s
.8186 .70409 m .8186 .68556 L .79455 .69121 L p .707 .577 .707 r
F P
0 g
s
.8186 .62 m .8186 .67558 L .83497 .66821 L p .707 .577 .707 r
F P
0 g
s
.83497 .66821 m .83497 .61263 L .8186 .62 L p .707 .577 .707 r
F P
0 g
s
.6747 .70621 m .6747 .66915 L .65365 .6627 L p .707 .577 .707 r
F P
0 g
s
.55357 .2612 m .55357 .76309 L .50956 .7604 L p .707 .577 .707 r
F P
0 g
s
.50956 .7604 m .50956 .25851 L .55357 .2612 L p .707 .577 .707 r
F P
0 g
s
.65365 .61706 m .65365 .67264 L .6747 .67909 L p .707 .577 .707 r
F P
0 g
s
.6747 .7076 m .6747 .68907 L .65365 .68262 L p .707 .577 .707 r
F P
0 g
s
.46462 .7615 m .46462 .25961 L .50956 .25851 L p .707 .577 .707 r
F P
0 g
s
.46462 .25961 m .46462 .7615 L .42314 .76627 L p .707 .577 .707 r
F P
0 g
s
.50956 .25851 m .50956 .7604 L .46462 .7615 L p .707 .577 .707 r
F P
0 g
s
.65365 .6627 m .65365 .69975 L .6747 .70621 L p .707 .577 .707 r
F P
0 g
s
.65365 .67264 m .65365 .61706 L .64105 .60917 L p .707 .577 .707 r
F P
0 g
s
.65365 .68262 m .65365 .70115 L .6747 .7076 L p .707 .577 .707 r
F P
0 g
s
.8186 .66564 m .8186 .7027 L .83497 .69533 L p .707 .577 .707 r
F P
0 g
s
.83497 .69533 m .83497 .65827 L .8186 .66564 L p .707 .577 .707 r
F P
0 g
s
.8186 .68556 m .8186 .70409 L .83497 .69672 L p .707 .577 .707 r
F P
0 g
s
.83497 .69672 m .83497 .67819 L .8186 .68556 L p .707 .577 .707 r
F P
0 g
s
.65365 .69975 m .65365 .6627 L .64105 .65482 L p .707 .577 .707 r
F P
0 g
s
.64105 .60917 m .64105 .66475 L .65365 .67264 L p .707 .577 .707 r
F P
0 g
s
.83497 .61263 m .83497 .66821 L .84205 .65985 L p .707 .577 .707 r
F P
0 g
s
.84205 .65985 m .84205 .60426 L .83497 .61263 L p .707 .577 .707 r
F P
0 g
s
.65365 .70115 m .65365 .68262 L .64105 .67474 L p .707 .577 .707 r
F P
0 g
s
.64105 .65482 m .64105 .69187 L .65365 .69975 L p .707 .577 .707 r
F P
0 g
s
.64105 .67474 m .64105 .69326 L .65365 .70115 L p .707 .577 .707 r
F P
0 g
s
.64105 .66475 m .64105 .60917 L .63816 .60063 L p .707 .577 .707 r
F P
0 g
s
.83497 .65827 m .83497 .69533 L .84206 .68696 L p .707 .577 .707 r
F P
0 g
s
.84206 .68696 m .84205 .64991 L .83497 .65827 L p .707 .577 .707 r
F P
0 g
s
.83497 .67819 m .83497 .69672 L .84206 .68836 L p .707 .577 .707 r
F P
0 g
s
.84206 .68836 m .84206 .66983 L .83497 .67819 L p .707 .577 .707 r
F P
0 g
s
.64105 .69187 m .64105 .65482 L .63816 .64627 L p .707 .577 .707 r
F P
0 g
s
.63816 .60063 m .63816 .65621 L .64105 .66475 L p .707 .577 .707 r
F P
0 g
s
.84205 .60426 m .84205 .65985 L .83916 .6513 L p .707 .577 .707 r
F P
0 g
s
.83916 .6513 m .83916 .59572 L .84205 .60426 L p .707 .577 .707 r
F P
0 g
s
.64105 .69326 m .64105 .67474 L .63816 .66619 L p .707 .577 .707 r
F P
0 g
s
.63816 .64627 m .63816 .68333 L .64105 .69187 L p .707 .577 .707 r
F P
0 g
s
.63816 .66619 m .63816 .68472 L .64105 .69326 L p .707 .577 .707 r
F P
0 g
s
.84205 .64991 m .84206 .68696 L .83916 .67842 L p .707 .577 .707 r
F P
0 g
s
.83916 .67842 m .83916 .64137 L .84205 .64991 L p .707 .577 .707 r
F P
0 g
s
.63816 .65621 m .63816 .60063 L .64524 .59226 L p .707 .577 .707 r
F P
0 g
s
.84206 .66983 m .84206 .68836 L .83916 .67981 L p .707 .577 .707 r
F P
0 g
s
.83916 .67981 m .83916 .66129 L .84206 .66983 L p .707 .577 .707 r
F P
0 g
s
.63816 .68333 m .63816 .64627 L .64524 .63791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .59226 m .64524 .64785 L .63816 .65621 L p .707 .577 .707 r
F P
0 g
s
.83916 .59572 m .83916 .6513 L .82657 .64342 L p .707 .577 .707 r
F P
0 g
s
.82657 .64342 m .82657 .58784 L .83916 .59572 L p .707 .577 .707 r
F P
0 g
s
.63816 .68472 m .63816 .66619 L .64524 .65783 L p .707 .577 .707 r
F P
0 g
s
.64524 .63791 m .64524 .67496 L .63816 .68333 L p .707 .577 .707 r
F P
0 g
s
.64524 .65783 m .64524 .67636 L .63816 .68472 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .64857 m .39032 .59299 L .35915 .59109 L p .707 .577 .707 r
F P
0 g
s
.39032 .59299 m .39032 .64857 L .42216 .64779 L p .707 .577 .707 r
F P
0 g
s
.42216 .64779 m .42216 .59221 L .39032 .59299 L p .707 .577 .707 r
F P
0 g
s
.64524 .64785 m .64524 .59226 L .66161 .5849 L p .707 .577 .707 r
F P
0 g
s
.42216 .59221 m .42216 .64779 L .45154 .64441 L p .707 .577 .707 r
F P
0 g
s
.45154 .64441 m .45154 .58883 L .42216 .59221 L p .707 .577 .707 r
F P
0 g
s
.83916 .64137 m .83916 .67842 L .82657 .67054 L p .707 .577 .707 r
F P
0 g
s
.82657 .67054 m .82657 .63348 L .83916 .64137 L p .707 .577 .707 r
F P
0 g
s
.35915 .64667 m .35915 .59109 L .33169 .58669 L p .707 .577 .707 r
F P
0 g
s
.35915 .59109 m .35915 .64667 L .39032 .64857 L p .707 .577 .707 r
F P
0 g
s
.83916 .66129 m .83916 .67981 L .82657 .67193 L p .707 .577 .707 r
F P
0 g
s
.82657 .67193 m .82657 .6534 L .83916 .66129 L p .707 .577 .707 r
F P
0 g
s
.39032 .67569 m .39032 .63863 L .35915 .63673 L p .707 .577 .707 r
F P
0 g
s
.39032 .63863 m .39032 .67569 L .42216 .67491 L p .707 .577 .707 r
F P
0 g
s
.42216 .67491 m .42216 .63785 L .39032 .63863 L p .707 .577 .707 r
F P
0 g
s
.45154 .58883 m .45154 .64441 L .47559 .63876 L p .707 .577 .707 r
F P
0 g
s
.47559 .63876 m .47559 .58318 L .45154 .58883 L p .707 .577 .707 r
F P
0 g
s
.64524 .67496 m .64524 .63791 L .66161 .63054 L p .707 .577 .707 r
F P
0 g
s
.42216 .63785 m .42216 .67491 L .45154 .67153 L p .707 .577 .707 r
F P
0 g
s
.45154 .67153 m .45154 .63448 L .42216 .63785 L p .707 .577 .707 r
F P
0 g
s
.66161 .5849 m .66161 .64048 L .64524 .64785 L p .707 .577 .707 r
F P
0 g
s
.39032 .67708 m .39032 .65855 L .35915 .65665 L p .707 .577 .707 r
F P
0 g
s
.39032 .65855 m .39032 .67708 L .42216 .6763 L p .707 .577 .707 r
F P
0 g
s
.42216 .6763 m .42216 .65777 L .39032 .65855 L p .707 .577 .707 r
F P
0 g
s
.82657 .58784 m .82657 .64342 L .80551 .63697 L p .707 .577 .707 r
F P
0 g
s
.80551 .63697 m .80551 .58138 L .82657 .58784 L p .707 .577 .707 r
F P
0 g
s
.35915 .67379 m .35915 .63673 L .33169 .63234 L p .707 .577 .707 r
F P
0 g
s
.35915 .63673 m .35915 .67379 L .39032 .67569 L p .707 .577 .707 r
F P
0 g
s
.64524 .67636 m .64524 .65783 L .66161 .65046 L p .707 .577 .707 r
F P
0 g
s
.42216 .65777 m .42216 .6763 L .45154 .67292 L p .707 .577 .707 r
F P
0 g
s
.45154 .67292 m .45154 .6544 L .42216 .65777 L p .707 .577 .707 r
F P
0 g
s
.33169 .58669 m .33169 .64228 L .35915 .64667 L p .707 .577 .707 r
F P
0 g
s
.33169 .64228 m .33169 .58669 L .31064 .58024 L p .707 .577 .707 r
F P
0 g
s
.35915 .65665 m .35915 .67518 L .39032 .67708 L p .707 .577 .707 r
F P
0 g
s
.35915 .67518 m .35915 .65665 L .33169 .65226 L p .707 .577 .707 r
F P
0 g
s
.66161 .63054 m .66161 .6676 L .64524 .67496 L p .707 .577 .707 r
F P
0 g
s
.66161 .65046 m .66161 .66899 L .64524 .67636 L p .707 .577 .707 r
F P
0 g
s
.45154 .63448 m .45154 .67153 L .47559 .66588 L p .707 .577 .707 r
F P
0 g
s
.47559 .66588 m .47559 .62883 L .45154 .63448 L p .707 .577 .707 r
F P
0 g
s
.66161 .64048 m .66161 .5849 L .68566 .57925 L p .707 .577 .707 r
F P
0 g
s
.33169 .63234 m .33169 .66939 L .35915 .67379 L p .707 .577 .707 r
F P
0 g
s
.33169 .65226 m .33169 .67079 L .35915 .67518 L p .707 .577 .707 r
F P
0 g
s
.82657 .63348 m .82657 .67054 L .80551 .66408 L p .707 .577 .707 r
F P
0 g
s
.80551 .66408 m .80551 .62703 L .82657 .63348 L p .707 .577 .707 r
F P
0 g
s
.45154 .6544 m .45154 .67292 L .47559 .66727 L p .707 .577 .707 r
F P
0 g
s
.47559 .66727 m .47559 .64875 L .45154 .6544 L p .707 .577 .707 r
F P
0 g
s
.47559 .58318 m .47559 .63876 L .49196 .6314 L p .707 .577 .707 r
F P
0 g
s
.49196 .6314 m .49196 .57581 L .47559 .58318 L p .707 .577 .707 r
F P
0 g
s
.33169 .66939 m .33169 .63234 L .31064 .62588 L p .707 .577 .707 r
F P
0 g
s
.82657 .6534 m .82657 .67193 L .80551 .66548 L p .707 .577 .707 r
F P
0 g
s
.80551 .66548 m .80551 .64695 L .82657 .6534 L p .707 .577 .707 r
F P
0 g
s
.31064 .58024 m .31064 .63582 L .33169 .64228 L p .707 .577 .707 r
F P
0 g
s
.33169 .67079 m .33169 .65226 L .31064 .6458 L p .707 .577 .707 r
F P
0 g
s
.80551 .58138 m .80551 .63697 L .77805 .63257 L p .707 .577 .707 r
F P
0 g
s
.77805 .63257 m .77805 .57699 L .80551 .58138 L p .707 .577 .707 r
F P
0 g
s
.66161 .6676 m .66161 .63054 L .68566 .62489 L p .707 .577 .707 r
F P
0 g
s
.68566 .57925 m .68566 .63483 L .66161 .64048 L p .707 .577 .707 r
F P
0 g
s
.31064 .62588 m .31064 .66294 L .33169 .66939 L p .707 .577 .707 r
F P
0 g
s
.31064 .63582 m .31064 .58024 L .29804 .57236 L p .707 .577 .707 r
F P
0 g
s
.31064 .6458 m .31064 .66433 L .33169 .67079 L p .707 .577 .707 r
F P
0 g
s
.66161 .66899 m .66161 .65046 L .68566 .64481 L p .707 .577 .707 r
F P
0 g
s
.47559 .62883 m .47559 .66588 L .49196 .65851 L p .707 .577 .707 r
F P
0 g
s
.49196 .65851 m .49196 .62146 L .47559 .62883 L p .707 .577 .707 r
F P
0 g
s
.68566 .63483 m .68566 .57925 L .71504 .57587 L p .707 .577 .707 r
F P
0 g
s
.68566 .62489 m .68566 .66195 L .66161 .6676 L p .707 .577 .707 r
F P
0 g
s
.68566 .64481 m .68566 .66334 L .66161 .66899 L p .707 .577 .707 r
F P
0 g
s
.47559 .64875 m .47559 .66727 L .49196 .65991 L p .707 .577 .707 r
F P
0 g
s
.49196 .65991 m .49196 .64138 L .47559 .64875 L p .707 .577 .707 r
F P
0 g
s
.80551 .62703 m .80551 .66408 L .77805 .65969 L p .707 .577 .707 r
F P
0 g
s
.77805 .65969 m .77805 .62264 L .80551 .62703 L p .707 .577 .707 r
F P
0 g
s
.77805 .57699 m .77805 .63257 L .74688 .63067 L p .707 .577 .707 r
F P
0 g
s
.74688 .63067 m .74688 .57509 L .77805 .57699 L p .707 .577 .707 r
F P
0 g
s
.31064 .66294 m .31064 .62588 L .29804 .618 L p .707 .577 .707 r
F P
0 g
s
.80551 .64695 m .80551 .66548 L .77805 .66108 L p .707 .577 .707 r
F P
0 g
s
.77805 .66108 m .77805 .64256 L .80551 .64695 L p .707 .577 .707 r
F P
0 g
s
.29804 .57236 m .29804 .62794 L .31064 .63582 L p .707 .577 .707 r
F P
0 g
s
.71504 .63145 m .71504 .57587 L .74688 .57509 L p .707 .577 .707 r
F P
0 g
s
.71504 .57587 m .71504 .63145 L .68566 .63483 L p .707 .577 .707 r
F P
0 g
s
.49196 .57581 m .49196 .6314 L .49904 .62303 L p .707 .577 .707 r
F P
0 g
s
.49904 .62303 m .49904 .56745 L .49196 .57581 L p .707 .577 .707 r
F P
0 g
s
.68566 .66195 m .68566 .62489 L .71504 .62151 L p .707 .577 .707 r
F P
0 g
s
.31064 .66433 m .31064 .6458 L .29804 .63792 L p .707 .577 .707 r
F P
0 g
s
.74688 .57509 m .74688 .63067 L .71504 .63145 L p .707 .577 .707 r
F P
0 g
s
.68566 .66334 m .68566 .64481 L .71504 .64143 L p .707 .577 .707 r
F P
0 g
s
.29804 .618 m .29804 .65506 L .31064 .66294 L p .707 .577 .707 r
F P
0 g
s
.29804 .63792 m .29804 .65645 L .31064 .66433 L p .707 .577 .707 r
F P
0 g
s
.77805 .62264 m .77805 .65969 L .74688 .65779 L p .707 .577 .707 r
F P
0 g
s
.74688 .65779 m .74688 .62074 L .77805 .62264 L p .707 .577 .707 r
F P
0 g
s
.71504 .62151 m .71504 .65857 L .68566 .66195 L p .707 .577 .707 r
F P
0 g
s
.71504 .64143 m .71504 .65996 L .68566 .66334 L p .707 .577 .707 r
F P
0 g
s
.29804 .62794 m .29804 .57236 L .29515 .56381 L p .707 .577 .707 r
F P
0 g
s
.71504 .65857 m .71504 .62151 L .74688 .62074 L p .707 .577 .707 r
F P
0 g
s
.49196 .62146 m .49196 .65851 L .49904 .65015 L p .707 .577 .707 r
F P
0 g
s
.49904 .65015 m .49904 .61309 L .49196 .62146 L p .707 .577 .707 r
F P
0 g
s
.77805 .64256 m .77805 .66108 L .74688 .65918 L p .707 .577 .707 r
F P
0 g
s
.74688 .65918 m .74688 .64066 L .77805 .64256 L p .707 .577 .707 r
F P
0 g
s
.74688 .62074 m .74688 .65779 L .71504 .65857 L p .707 .577 .707 r
F P
0 g
s
.71504 .65996 m .71504 .64143 L .74688 .64066 L p .707 .577 .707 r
F P
0 g
s
.49196 .64138 m .49196 .65991 L .49904 .65154 L p .707 .577 .707 r
F P
0 g
s
.49904 .65154 m .49904 .63301 L .49196 .64138 L p .707 .577 .707 r
F P
0 g
s
.74688 .64066 m .74688 .65918 L .71504 .65996 L p .707 .577 .707 r
F P
0 g
s
.29804 .65506 m .29804 .618 L .29515 .60946 L p .707 .577 .707 r
F P
0 g
s
.29515 .56381 m .29515 .6194 L .29804 .62794 L p .707 .577 .707 r
F P
0 g
s
.49904 .56745 m .49904 .62303 L .49615 .61449 L p .707 .577 .707 r
F P
0 g
s
.49615 .61449 m .49615 .55891 L .49904 .56745 L p .707 .577 .707 r
F P
0 g
s
.29804 .65645 m .29804 .63792 L .29515 .62938 L p .707 .577 .707 r
F P
0 g
s
.29515 .60946 m .29515 .64651 L .29804 .65506 L p .707 .577 .707 r
F P
0 g
s
.29515 .62938 m .29515 .64791 L .29804 .65645 L p .707 .577 .707 r
F P
0 g
s
.49904 .61309 m .49904 .65015 L .49615 .64161 L p .707 .577 .707 r
F P
0 g
s
.49615 .64161 m .49615 .60455 L .49904 .61309 L p .707 .577 .707 r
F P
0 g
s
.29515 .6194 m .29515 .56381 L .30223 .55545 L p .707 .577 .707 r
F P
0 g
s
.49904 .63301 m .49904 .65154 L .49615 .643 L p .707 .577 .707 r
F P
0 g
s
.49615 .643 m .49615 .62447 L .49904 .63301 L p .707 .577 .707 r
F P
0 g
s
.29515 .64651 m .29515 .60946 L .30223 .60109 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55545 m .30223 .61103 L .29515 .6194 L p .707 .577 .707 r
F P
0 g
s
.49615 .55891 m .49615 .61449 L .48356 .6066 L p .707 .577 .707 r
F P
0 g
s
.48356 .6066 m .48356 .55102 L .49615 .55891 L p .707 .577 .707 r
F P
0 g
s
.29515 .64791 m .29515 .62938 L .30223 .62101 L p .707 .577 .707 r
F P
0 g
s
.30223 .60109 m .30223 .63815 L .29515 .64651 L p .707 .577 .707 r
F P
0 g
s
.30223 .62101 m .30223 .63954 L .29515 .64791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61103 m .30223 .55545 L .3186 .54808 L p .707 .577 .707 r
F P
0 g
s
.49615 .60455 m .49615 .64161 L .48356 .63372 L p .707 .577 .707 r
F P
0 g
s
.48356 .63372 m .48356 .59667 L .49615 .60455 L p .707 .577 .707 r
F P
0 g
s
.49615 .62447 m .49615 .643 L .48356 .63511 L p .707 .577 .707 r
F P
0 g
s
.48356 .63511 m .48356 .61659 L .49615 .62447 L p .707 .577 .707 r
F P
0 g
s
.30223 .63815 m .30223 .60109 L .3186 .59373 L p .707 .577 .707 r
F P
0 g
s
.3186 .54808 m .3186 .60366 L .30223 .61103 L p .707 .577 .707 r
F P
0 g
s
.48356 .55102 m .48356 .6066 L .4625 .60015 L p .707 .577 .707 r
F P
0 g
s
.4625 .60015 m .4625 .54457 L .48356 .55102 L p .707 .577 .707 r
F P
0 g
s
.30223 .63954 m .30223 .62101 L .3186 .61365 L p .707 .577 .707 r
F P
0 g
s
.3186 .59373 m .3186 .63078 L .30223 .63815 L p .707 .577 .707 r
F P
0 g
s
.3186 .61365 m .3186 .63217 L .30223 .63954 L p .707 .577 .707 r
F P
0 g
s
.3186 .60366 m .3186 .54808 L .34265 .54243 L p .707 .577 .707 r
F P
0 g
s
.48356 .59667 m .48356 .63372 L .4625 .62727 L p .707 .577 .707 r
F P
0 g
s
.4625 .62727 m .4625 .59021 L .48356 .59667 L p .707 .577 .707 r
F P
0 g
s
.48356 .61659 m .48356 .63511 L .4625 .62866 L p .707 .577 .707 r
F P
0 g
s
.4625 .62866 m .4625 .61013 L .48356 .61659 L p .707 .577 .707 r
F P
0 g
s
.4625 .54457 m .4625 .60015 L .43504 .59576 L p .707 .577 .707 r
F P
0 g
s
.43504 .59576 m .43504 .54018 L .4625 .54457 L p .707 .577 .707 r
F P
0 g
s
.3186 .63078 m .3186 .59373 L .34265 .58808 L p .707 .577 .707 r
F P
0 g
s
.34265 .54243 m .34265 .59801 L .3186 .60366 L p .707 .577 .707 r
F P
0 g
s
.3186 .63217 m .3186 .61365 L .34265 .608 L p .707 .577 .707 r
F P
0 g
s
.34265 .59801 m .34265 .54243 L .37203 .53905 L p .707 .577 .707 r
F P
0 g
s
.34265 .58808 m .34265 .62513 L .3186 .63078 L p .707 .577 .707 r
F P
0 g
s
.34265 .608 m .34265 .62652 L .3186 .63217 L p .707 .577 .707 r
F P
0 g
s
.4625 .59021 m .4625 .62727 L .43504 .62288 L p .707 .577 .707 r
F P
0 g
s
.43504 .62288 m .43504 .58582 L .4625 .59021 L p .707 .577 .707 r
F P
0 g
s
.43504 .54018 m .43504 .59576 L .40387 .59386 L p .707 .577 .707 r
F P
0 g
s
.40387 .59386 m .40387 .53828 L .43504 .54018 L p .707 .577 .707 r
F P
0 g
s
.4625 .61013 m .4625 .62866 L .43504 .62427 L p .707 .577 .707 r
F P
0 g
s
.43504 .62427 m .43504 .60574 L .4625 .61013 L p .707 .577 .707 r
F P
0 g
s
.37203 .59463 m .37203 .53905 L .40387 .53828 L p .707 .577 .707 r
F P
0 g
s
.37203 .53905 m .37203 .59463 L .34265 .59801 L p .707 .577 .707 r
F P
0 g
s
.34265 .62513 m .34265 .58808 L .37203 .5847 L p .707 .577 .707 r
F P
0 g
s
.40387 .53828 m .40387 .59386 L .37203 .59463 L p .707 .577 .707 r
F P
0 g
s
.34265 .62652 m .34265 .608 L .37203 .60462 L p .707 .577 .707 r
F P
0 g
s
.43504 .58582 m .43504 .62288 L .40387 .62097 L p .707 .577 .707 r
F P
0 g
s
.40387 .62097 m .40387 .58392 L .43504 .58582 L p .707 .577 .707 r
F P
0 g
s
.37203 .5847 m .37203 .62175 L .34265 .62513 L p .707 .577 .707 r
F P
0 g
s
.37203 .60462 m .37203 .62315 L .34265 .62652 L p .707 .577 .707 r
F P
0 g
s
.37203 .62175 m .37203 .5847 L .40387 .58392 L p .707 .577 .707 r
F P
0 g
s
.43504 .60574 m .43504 .62427 L .40387 .62237 L p .707 .577 .707 r
F P
0 g
s
.40387 .62237 m .40387 .60384 L .43504 .60574 L p .707 .577 .707 r
F P
0 g
s
.40387 .58392 m .40387 .62097 L .37203 .62175 L p .707 .577 .707 r
F P
0 g
s
.37203 .62315 m .37203 .60462 L .40387 .60384 L p .707 .577 .707 r
F P
0 g
s
.40387 .60384 m .40387 .62237 L .37203 .62315 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0009JEP03001JEUYF
00UJEP03001JEUYF00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo001ZOol20002FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00Igoo
0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
3goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
07oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH20005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00005FUH005YFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH00004FUH40003FUH00`00FUIJEP05FUH>0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol01000FUH005YF0P0000=JEP00FUH01EYF100015YF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP000003FUH01000FUH000000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol30004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00Dgoo0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001JEUYF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP8000=JEPT000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEPD000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP04001JEUYFFUH90007FUH4
0006FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP04001JEUYFFUH2000]Ool0
03mooaD00003FUH005YF009JEPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001J
EP0000D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001JEP02FUH2000]Ool003Uoo`H000=J
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo
000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUH00000FUH005YF
00<00003FUH005YF00IJEQL000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH00000
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20003FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF5P000eYF
00<005YFFUH00eYF00<005YFFUH00`00;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH20005FUH01000FUIJEUYF1@001eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0000EJEP00FUIJEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8002eoo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
0eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000300000eYF001JEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH01000
FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1@0015YF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF1@0015YF00<005YF
FUH00UYF1`0000IJEP00000005YF0003FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH015YF1P0015YF3P000eYF00<005YFFUH015YF0`000eYF0P00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUH0000H0007
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000200001UYF00000000FUH000MJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000AJ
EP800003FUH0000000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05
001JEP00001JEP03000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000=JEP04001JEUYF0002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF1@0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP040002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF
FUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<00003
FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF000015YF00@005YFFUIJEP800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800005FUH0
05YFFUH00005FUH50005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`0015YF4P000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00;Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF1@00
15YF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`04
001JEP000003FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool30004FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200001EYF001JEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD003=oo`00;7oo
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000h
Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH90003FUH20004FUH9000oOol002ao
o`<000AJEP03001JEUYF00AJEP8000=JEQT000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P000goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YF
FUH01eYF00<005YFFUH015YF1P0015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH20007Ool50018Ool002aoo`03
001JEP0000AJEPD000MJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEP0000D00005
FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
FUH00`00FUH0000200000eYF001JEP02FUH20007Ool50018Ool002aoo`03001JEP00009JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEPD000EJEP<0009JEP04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003
FUH20007Ool50018Ool002aoo`03001JEP0000<00006FUH00000001JEP001UYF60000eYF00<005YF
FUH015YF00H005YFFUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH300000eYF00000008Ool30019Ool002aoo`03001JEP00009J
EP03001JEUYF009JEP8000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP03001DOol002aoo`80009JEP8000EJEP03001JEUYF00<0
009JEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000<0009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@00003FUH005YF00AJ
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00800003FUH005YF00AJEP<000MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP@000=JEP04001JEUYFFUH2001DOol002ao
o`8000=JEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP0000<00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00@000=JEP8005Aoo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF009JEP@000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH20002FUH2001DOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YF00000`00E7oo000_Ool30005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1P00FUH00000Ool0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0035oo`<000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50004FUH01000FUIJEUYF0P00
E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003
0006Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH015YF8@0025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF00<005YF00001@0000=JEP00FUH00UYF0P00E7oo000iOol4
00000eYF00000007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000:Ool01000FUIJEP001EYF00<0
05YFFUH01UYF200035YF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000010001EYF0`000eYF0P00E7oo000mOolI000?Ool01000FUIJEP001EYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH010001UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo0018Ool3000JOol01000FUIJEP001EYF00<005YF00000`002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF
00000UYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00Agoo1@006Goo00@005YFFUH000EJEP80
00=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP<00003FUH005YF00=JEP03001JEP00009JEP03001JEUYF00AJEP05001JEP00001JEP03001D
Ool004Moo`D001Uoo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00000UYF00@0
05YFFUIJEPD000=JEP03001JEP0005Aoo`00Agoo1@006Goo00D005YFFUH005YF008000MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH20002FUH00`00FUH000060003FUH00`00FUIJEP02FUH2001EOol004Qoo`<001Yoo`03001J
EUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00005FUH005YFFUH00006FUH00`00FUIJEP02
FUH2001EOol006Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF
FUH00006FUH01000FUIJEUYF0P00EWoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH015YF00@005YF000005Qoo`00IGoo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF0000009JEP04001JEUYFFUH5001JOol006Eoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00L005moo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF0000IWoo001VOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH2001WOol006Moo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2001WOol006Qoo`800003
FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8006Qoo`00JWoo0P001eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Jgoo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YF000006aoo`00KGoo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF1000KWoo001aOol50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05001bOol007Ioo`H0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00=JEPP007Moo`00O7oo2@001UYF00<005YFFUH015YF3000Ogoo
0025Ool=002;Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]31\[InvisibleSpace]"     "\
\[InvisibleSpace]10.224504837396527`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 31, "     ", 10.224504837396527, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59813 .75278 m .59394 .69786 L .5628 .69798 L p .707 .577 .707 r
F P
0 g
s
.59394 .69786 m .59813 .75278 L .62986 .74963 L p .707 .577 .707 r
F P
0 g
s
.62986 .74963 m .62567 .69471 L .59394 .69786 L p .707 .577 .707 r
F P
0 g
s
.62567 .69471 m .62986 .74963 L .65907 .74378 L p .707 .577 .707 r
F P
0 g
s
.65907 .74378 m .65488 .68886 L .62567 .69471 L p .707 .577 .707 r
F P
0 g
s
.56699 .7529 m .5628 .69798 L .53529 .69507 L p .707 .577 .707 r
F P
0 g
s
.5628 .69798 m .56699 .7529 L .59813 .75278 L p .707 .577 .707 r
F P
0 g
s
.65488 .68886 m .65907 .74378 L .6829 .73578 L p .707 .577 .707 r
F P
0 g
s
.6829 .73578 m .67871 .68086 L .65488 .68886 L p .707 .577 .707 r
F P
0 g
s
.53948 .74999 m .53529 .69507 L .51411 .68941 L p .707 .577 .707 r
F P
0 g
s
.53529 .69507 m .53948 .74999 L .56699 .7529 L p .707 .577 .707 r
F P
0 g
s
.60202 .81757 m .5951 .78203 L .56439 .78496 L p .707 .577 .707 r
F P
0 g
s
.5951 .78203 m .60202 .81757 L .63332 .81112 L p .707 .577 .707 r
F P
0 g
s
.63332 .81112 m .6264 .77558 L .5951 .78203 L p .707 .577 .707 r
F P
0 g
s
.6264 .77558 m .63332 .81112 L .66213 .80178 L p .707 .577 .707 r
F P
0 g
s
.66213 .80178 m .65521 .76623 L .6264 .77558 L p .707 .577 .707 r
F P
0 g
s
.57131 .8205 m .56439 .78496 L .53726 .78407 L p .707 .577 .707 r
F P
0 g
s
.56439 .78496 m .57131 .8205 L .60202 .81757 L p .707 .577 .707 r
F P
0 g
s
.67871 .68086 m .6829 .73578 L .69902 .72643 L p .707 .577 .707 r
F P
0 g
s
.69902 .72643 m .69483 .6715 L .67871 .68086 L p .707 .577 .707 r
F P
0 g
s
.65521 .76623 m .66213 .80178 L .68563 .79045 L p .707 .577 .707 r
F P
0 g
s
.68563 .79045 m .67871 .75491 L .65521 .76623 L p .707 .577 .707 r
F P
0 g
s
.51411 .68941 m .5183 .74433 L .53948 .74999 L p .707 .577 .707 r
F P
0 g
s
.59745 .86019 m .59392 .84243 L .56331 .84532 L p .707 .577 .707 r
F P
0 g
s
.59392 .84243 m .59745 .86019 L .62876 .85376 L p .707 .577 .707 r
F P
0 g
s
.62876 .85376 m .62523 .83601 L .59392 .84243 L p .707 .577 .707 r
F P
0 g
s
.62523 .83601 m .62876 .85376 L .6577 .84442 L p .707 .577 .707 r
F P
0 g
s
.6577 .84442 m .65417 .82666 L .62523 .83601 L p .707 .577 .707 r
F P
0 g
s
.53726 .78407 m .54418 .81961 L .57131 .8205 L p .707 .577 .707 r
F P
0 g
s
.5183 .74433 m .51411 .68941 L .50133 .68155 L p .707 .577 .707 r
F P
0 g
s
.56331 .84532 m .56684 .86307 L .59745 .86019 L p .707 .577 .707 r
F P
0 g
s
.54418 .81961 m .53726 .78407 L .51637 .77946 L p .707 .577 .707 r
F P
0 g
s
.56684 .86307 m .56331 .84532 L .53639 .84437 L p .707 .577 .707 r
F P
0 g
s
.65417 .82666 m .6577 .84442 L .68144 .83307 L p .707 .577 .707 r
F P
0 g
s
.68144 .83307 m .67791 .81531 L .65417 .82666 L p .707 .577 .707 r
F P
0 g
s
.67871 .75491 m .68563 .79045 L .70154 .77826 L p .707 .577 .707 r
F P
0 g
s
.70154 .77826 m .69462 .74272 L .67871 .75491 L p .707 .577 .707 r
F P
0 g
s
.53639 .84437 m .53992 .86213 L .56684 .86307 L p .707 .577 .707 r
F P
0 g
s
.69483 .6715 m .69902 .72643 L .70585 .71663 L p .707 .577 .707 r
F P
0 g
s
.70585 .71663 m .70165 .66171 L .69483 .6715 L p .707 .577 .707 r
F P
0 g
s
.51637 .77946 m .5233 .815 L .54418 .81961 L p .707 .577 .707 r
F P
0 g
s
.50133 .68155 m .50552 .73647 L .5183 .74433 L p .707 .577 .707 r
F P
0 g
s
.53992 .86213 m .53639 .84437 L .5158 .83969 L p .707 .577 .707 r
F P
0 g
s
.67791 .81531 m .68144 .83307 L .69766 .82083 L p .707 .577 .707 r
F P
0 g
s
.69766 .82083 m .69413 .80307 L .67791 .81531 L p .707 .577 .707 r
F P
0 g
s
.5233 .815 m .51637 .77946 L .50377 .77158 L p .707 .577 .707 r
F P
0 g
s
.5158 .83969 m .51933 .85745 L .53992 .86213 L p .707 .577 .707 r
F P
0 g
s
.50552 .73647 m .50133 .68155 L .4982 .67227 L p .707 .577 .707 r
F P
0 g
s
.69462 .74272 m .70154 .77826 L .70828 .76639 L p .707 .577 .707 r
F P
0 g
s
.70828 .76639 m .70136 .73085 L .69462 .74272 L p .707 .577 .707 r
F P
0 g
s
.50377 .77158 m .5107 .80712 L .5233 .815 L p .707 .577 .707 r
F P
0 g
s
.70165 .66171 m .70585 .71663 L .70272 .70735 L p .707 .577 .707 r
F P
0 g
s
.70272 .70735 m .69853 .65243 L .70165 .66171 L p .707 .577 .707 r
F P
0 g
s
.51933 .85745 m .5158 .83969 L .50356 .83173 L p .707 .577 .707 r
F P
0 g
s
.4982 .67227 m .50239 .72719 L .50552 .73647 L p .707 .577 .707 r
F P
0 g
s
.69413 .80307 m .69766 .82083 L .70476 .8089 L p .707 .577 .707 r
F P
0 g
s
.70476 .8089 m .70124 .79114 L .69413 .80307 L p .707 .577 .707 r
F P
0 g
s
.50356 .83173 m .50709 .84949 L .51933 .85745 L p .707 .577 .707 r
F P
0 g
s
.5107 .80712 m .50377 .77158 L .50069 .7612 L p .707 .577 .707 r
F P
0 g
s
.48154 .8216 m .48154 .31972 L .43824 .31631 L p .707 .577 .707 r
F P
0 g
s
.50239 .72719 m .4982 .67227 L .50503 .66247 L p .707 .577 .707 r
F P
0 g
s
.50069 .7612 m .50762 .79674 L .5107 .80712 L p .707 .577 .707 r
F P
0 g
s
.50709 .84949 m .50356 .83173 L .50086 .82127 L p .707 .578 .707 r
F P
0 g
s
.50503 .66247 m .50922 .7174 L .50239 .72719 L p .707 .577 .707 r
F P
0 g
s
.50086 .82127 m .50439 .83903 L .50709 .84949 L p .707 .578 .707 r
F P
0 g
s
.50762 .79674 m .50069 .7612 L .50744 .74933 L p .707 .577 .707 r
F P
0 g
s
.50922 .7174 m .50503 .66247 L .52115 .65312 L p .707 .577 .707 r
F P
0 g
s
.50744 .74933 m .51436 .78487 L .50762 .79674 L p .707 .577 .707 r
F P
0 g
s
.50439 .83903 m .50086 .82127 L .50796 .80934 L p .707 .577 .707 r
F P
0 g
s
.52115 .65312 m .52534 .70804 L .50922 .7174 L p .707 .577 .707 r
F P
0 g
s
.50796 .80934 m .51149 .82709 L .50439 .83903 L p .707 .577 .707 r
F P
0 g
s
.51436 .78487 m .50744 .74933 L .52334 .73713 L p .707 .577 .707 r
F P
0 g
s
.52334 .73713 m .53026 .77267 L .51436 .78487 L p .707 .577 .707 r
F P
0 g
s
.51149 .82709 m .50796 .80934 L .52418 .7971 L p .707 .577 .707 r
F P
0 g
s
.52418 .7971 m .52771 .81485 L .51149 .82709 L p .707 .577 .707 r
F P
0 g
s
.52771 .81485 m .52418 .7971 L .54792 .78575 L p .707 .577 .707 r
F P
0 g
s
.48154 .31972 m .48154 .8216 L .52666 .82126 L p .707 .577 .707 r
F P
0 g
s
.52534 .70804 m .52115 .65312 L .54498 .64512 L p .707 .577 .707 r
F P
0 g
s
.54498 .64512 m .54917 .70004 L .52534 .70804 L p .707 .577 .707 r
F P
0 g
s
.53026 .77267 m .52334 .73713 L .54684 .72581 L p .707 .577 .707 r
F P
0 g
s
.52666 .82126 m .52666 .31937 L .48154 .31972 L p .707 .577 .707 r
F P
0 g
s
.54917 .70004 m .54498 .64512 L .57419 .63927 L p .707 .577 .707 r
F P
0 g
s
.57419 .63927 m .57838 .69419 L .54917 .70004 L p .707 .577 .707 r
F P
0 g
s
.54684 .72581 m .55377 .76135 L .53026 .77267 L p .707 .577 .707 r
F P
0 g
s
.55377 .76135 m .54684 .72581 L .57565 .71647 L p .707 .577 .707 r
F P
0 g
s
.54792 .78575 m .55145 .80351 L .52771 .81485 L p .707 .577 .707 r
F P
0 g
s
.57565 .71647 m .58258 .75201 L .55377 .76135 L p .707 .577 .707 r
F P
0 g
s
.55145 .80351 m .54792 .78575 L .57687 .7764 L p .707 .577 .707 r
F P
0 g
s
.57687 .7764 m .58039 .79416 L .55145 .80351 L p .707 .577 .707 r
F P
0 g
s
.52666 .31937 m .52666 .82126 L .56916 .81718 L p .707 .577 .707 r
F P
0 g
s
.56916 .81718 m .56916 .3153 L .52666 .31937 L p .707 .577 .707 r
F P
0 g
s
.70136 .73085 m .70828 .76639 L .7052 .75601 L p .707 .577 .707 r
F P
0 g
s
.7052 .75601 m .69828 .72046 L .70136 .73085 L p .707 .577 .707 r
F P
0 g
s
.43824 .8182 m .43824 .31631 L .40098 .30947 L p .707 .577 .707 r
F P
0 g
s
.43824 .31631 m .43824 .8182 L .48154 .8216 L p .707 .577 .707 r
F P
0 g
s
.57838 .69419 m .57419 .63927 L .60592 .63612 L p .707 .577 .707 r
F P
0 g
s
.60592 .63612 m .61011 .69104 L .57838 .69419 L p .707 .577 .707 r
F P
0 g
s
.58258 .75201 m .57565 .71647 L .60695 .71001 L p .707 .577 .707 r
F P
0 g
s
.60695 .71001 m .61387 .74556 L .58258 .75201 L p .707 .577 .707 r
F P
0 g
s
.58039 .79416 m .57687 .7764 L .60817 .76998 L p .707 .577 .707 r
F P
0 g
s
.60817 .76998 m .6117 .78773 L .58039 .79416 L p .707 .577 .707 r
F P
0 g
s
.56916 .3153 m .56916 .81718 L .60489 .80979 L p .707 .577 .707 r
F P
0 g
s
.60489 .80979 m .60489 .3079 L .56916 .3153 L p .707 .577 .707 r
F P
0 g
s
.69853 .65243 m .70272 .70735 L .68994 .69949 L p .707 .577 .707 r
F P
0 g
s
.68994 .69949 m .68575 .64457 L .69853 .65243 L p .707 .577 .707 r
F P
0 g
s
.70124 .79114 m .70476 .8089 L .70206 .79844 L p .707 .578 .707 r
F P
0 g
s
.70206 .79844 m .69853 .78068 L .70124 .79114 L p .707 .578 .707 r
F P
0 g
s
.2545 .70596 m .2527 .64943 L .22148 .64904 L p .707 .577 .707 r
F P
0 g
s
.2527 .64943 m .2545 .70596 L .2863 .70436 L p .707 .577 .707 r
F P
0 g
s
.2863 .70436 m .28449 .64783 L .2527 .64943 L p .707 .577 .707 r
F P
0 g
s
.28449 .64783 m .2863 .70436 L .31556 .70091 L p .707 .577 .707 r
F P
0 g
s
.31556 .70091 m .31375 .64439 L .28449 .64783 L p .707 .577 .707 r
F P
0 g
s
.69828 .72046 m .7052 .75601 L .6926 .74812 L p .707 .577 .707 r
F P
0 g
s
.6926 .74812 m .68568 .71258 L .69828 .72046 L p .707 .577 .707 r
F P
0 g
s
.40098 .81136 m .40098 .30947 L .37341 .29989 L p .707 .577 .707 r
F P
0 g
s
.40098 .30947 m .40098 .81136 L .43824 .8182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22329 .70556 m .22148 .64904 L .1939 .64669 L p .707 .577 .707 r
F P
0 g
s
.22148 .64904 m .22329 .70556 L .2545 .70596 L p .707 .577 .707 r
F P
0 g
s
.63706 .636 m .64125 .69092 L .61011 .69104 L p .707 .577 .707 r
F P
0 g
s
.61011 .69104 m .60592 .63612 L .63706 .636 L p .707 .577 .707 r
F P
0 g
s
.63766 .70709 m .64458 .74263 L .61387 .74556 L p .707 .577 .707 r
F P
0 g
s
.61387 .74556 m .60695 .71001 L .63766 .70709 L p .707 .577 .707 r
F P
0 g
s
.63878 .76709 m .64231 .78485 L .6117 .78773 L p .707 .577 .707 r
F P
0 g
s
.6117 .78773 m .60817 .76998 L .63878 .76709 L p .707 .577 .707 r
F P
0 g
s
.60489 .3079 m .60489 .80979 L .63035 .79979 L p .707 .577 .707 r
F P
0 g
s
.63035 .79979 m .63035 .2979 L .60489 .3079 L p .707 .577 .707 r
F P
0 g
s
.68575 .64457 m .68994 .69949 L .66876 .69383 L p .707 .577 .707 r
F P
0 g
s
.66876 .69383 m .66457 .63891 L .68575 .64457 L p .707 .577 .707 r
F P
0 g
s
.31375 .64439 m .31556 .70091 L .33942 .69597 L p .707 .577 .707 r
F P
0 g
s
.33942 .69597 m .33762 .63944 L .31375 .64439 L p .707 .577 .707 r
F P
0 g
s
.1939 .64669 m .19571 .70321 L .22329 .70556 L p .707 .577 .707 r
F P
0 g
s
.2566 .75655 m .2536 .71837 L .22243 .72018 L p .707 .577 .707 r
F P
0 g
s
.2536 .71837 m .2566 .75655 L .2883 .75377 L p .707 .577 .707 r
F P
0 g
s
.2883 .75377 m .28529 .71559 L .2536 .71837 L p .707 .577 .707 r
F P
0 g
s
.69853 .78068 m .70206 .79844 L .68982 .79048 L p .707 .577 .707 r
F P
0 g
s
.68982 .79048 m .68629 .77272 L .69853 .78068 L p .707 .577 .707 r
F P
0 g
s
.28529 .71559 m .2883 .75377 L .31743 .7503 L p .707 .577 .707 r
F P
0 g
s
.31743 .7503 m .31443 .71212 L .28529 .71559 L p .707 .577 .707 r
F P
0 g
s
.19571 .70321 m .1939 .64669 L .17266 .64261 L p .707 .577 .707 r
F P
0 g
s
.22243 .72018 m .22544 .75836 L .2566 .75655 L p .707 .577 .707 r
F P
0 g
s
.22544 .75836 m .22243 .72018 L .19485 .72085 L p .707 .577 .707 r
F P
0 g
s
.19485 .72085 m .19786 .75903 L .22544 .75836 L p .707 .577 .707 r
F P
0 g
s
.68568 .71258 m .6926 .74812 L .67171 .74351 L p .707 .577 .707 r
F P
0 g
s
.67171 .74351 m .66479 .70797 L .68568 .71258 L p .707 .577 .707 r
F P
0 g
s
.17266 .64261 m .17446 .69913 L .19571 .70321 L p .707 .577 .707 r
F P
0 g
s
.31443 .71212 m .31743 .7503 L .34114 .74647 L p .707 .577 .707 r
F P
0 g
s
.34114 .74647 m .33814 .70829 L .31443 .71212 L p .707 .577 .707 r
F P
0 g
s
.33762 .63944 m .33942 .69597 L .35555 .69001 L p .707 .577 .707 r
F P
0 g
s
.35555 .69001 m .35375 .63348 L .33762 .63944 L p .707 .577 .707 r
F P
0 g
s
.25396 .79718 m .25243 .77808 L .22135 .77993 L p .707 .577 .707 r
F P
0 g
s
.25243 .77808 m .25396 .79718 L .28569 .79441 L p .707 .577 .707 r
F P
0 g
s
.28569 .79441 m .28417 .77532 L .25243 .77808 L p .707 .577 .707 r
F P
0 g
s
.66457 .63891 m .66876 .69383 L .64125 .69092 L p .707 .577 .707 r
F P
0 g
s
.64125 .69092 m .63706 .636 L .66457 .63891 L p .707 .577 .707 r
F P
0 g
s
.22135 .77993 m .22288 .79903 L .25396 .79718 L p .707 .577 .707 r
F P
0 g
s
.28417 .77532 m .28569 .79441 L .31497 .791 L p .707 .577 .707 r
F P
0 g
s
.31497 .791 m .31344 .7719 L .28417 .77532 L p .707 .577 .707 r
F P
0 g
s
.37341 .80178 m .37341 .29989 L .35824 .28848 L p .707 .577 .707 r
F P
0 g
s
.37341 .29989 m .37341 .80178 L .40098 .81136 L p .707 .577 .707 r
F P
0 g
s
.19786 .75903 m .19485 .72085 L .17356 .72031 L p .707 .577 .707 r
F P
0 g
s
.22288 .79903 m .22135 .77993 L .19397 .78068 L p .707 .577 .707 r
F P
0 g
s
.19397 .78068 m .19549 .79978 L .22288 .79903 L p .707 .577 .707 r
F P
0 g
s
.17356 .72031 m .17657 .75849 L .19786 .75903 L p .707 .577 .707 r
F P
0 g
s
.17446 .69913 m .17266 .64261 L .15982 .6372 L p .707 .577 .707 r
F P
0 g
s
.64458 .74263 m .63766 .70709 L .66479 .70797 L p .707 .577 .707 r
F P
0 g
s
.6657 .76804 m .66923 .7858 L .64231 .78485 L p .707 .577 .707 r
F P
0 g
s
.64231 .78485 m .63878 .76709 L .6657 .76804 L p .707 .577 .707 r
F P
0 g
s
.63035 .2979 m .63035 .79979 L .64306 .78817 L p .707 .577 .707 r
F P
0 g
s
.64306 .78817 m .64306 .28628 L .63035 .2979 L p .707 .577 .707 r
F P
0 g
s
.68629 .77272 m .68982 .79048 L .66923 .7858 L p .707 .577 .707 r
F P
0 g
s
.66923 .7858 m .6657 .76804 L .68629 .77272 L p .707 .577 .707 r
F P
0 g
s
.31344 .7719 m .31497 .791 L .33893 .78726 L p .707 .577 .707 r
F P
0 g
s
.33893 .78726 m .3374 .76816 L .31344 .7719 L p .707 .577 .707 r
F P
0 g
s
.33814 .70829 m .34114 .74647 L .35712 .74266 L p .707 .577 .707 r
F P
0 g
s
.35712 .74266 m .35411 .70448 L .33814 .70829 L p .707 .577 .707 r
F P
0 g
s
.66479 .70797 m .67171 .74351 L .64458 .74263 L p .707 .577 .707 r
F P
0 g
s
.15982 .6372 m .16163 .69372 L .17446 .69913 L p .707 .577 .707 r
F P
0 g
s
.19549 .79978 m .19397 .78068 L .17295 .78025 L p .707 .577 .707 r
F P
0 g
s
.17295 .78025 m .17448 .79935 L .19549 .79978 L p .707 .577 .707 r
F P
0 g
s
.35375 .63348 m .35555 .69001 L .36237 .68361 L p .707 .577 .707 r
F P
0 g
s
.36237 .68361 m .36057 .62708 L .35375 .63348 L p .707 .577 .707 r
F P
0 g
s
.17657 .75849 m .17356 .72031 L .16064 .71861 L p .707 .577 .707 r
F P
0 g
s
.16064 .71861 m .16365 .75679 L .17657 .75849 L p .707 .577 .707 r
F P
0 g
s
.3374 .76816 m .33893 .78726 L .35522 .78358 L p .707 .577 .707 r
F P
0 g
s
.35522 .78358 m .35369 .76448 L .3374 .76816 L p .707 .577 .707 r
F P
0 g
s
.16163 .69372 m .15982 .6372 L .15666 .63099 L p .707 .577 .707 r
F P
0 g
s
.35411 .70448 m .35712 .74266 L .36106 .74065 L p .707 .577 .707 r
F P
0 g
s
.36106 .74065 m .36379 .73925 L p .3609 .72887 L .707 .577 .707 r
F P
0 g
s
.3609 .72887 m .35411 .70448 L .36106 .74065 L .707 .577 .707 r
F
.35824 .28848 m .35694 .27638 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36379 .73925 m .36078 .70107 L .35411 .70448 L p .707 .577 .707 r
F P
0 g
s
.35921 .6774 m .3574 .62087 L .36057 .62708 L p .707 .577 .707 r
F P
0 g
s
.35369 .76448 m .35522 .78358 L .36081 .78098 L p .707 .577 .707 r
F P
0 g
s
.36081 .78098 m .36225 .78031 L p .36076 .77756 L .707 .577 .707 r
F P
0 g
s
.36076 .77756 m .35369 .76448 L .36081 .78098 L .707 .577 .707 r
F
.36225 .78031 m .36073 .76121 L .35369 .76448 L p F P
0 g
s
.3605 .73656 m .35974 .72693 L p .36078 .70107 L .707 .577 .707 r
F P
0 g
s
.35974 .72693 m .3575 .69838 L .36039 .70074 L p .707 .577 .707 r
F P
0 g
s
.36039 .70074 m .36078 .70107 L p .35974 .72693 L .707 .577 .707 r
F P
0 g
s
.3574 .62087 m .35921 .6774 L .34638 .67199 L p .707 .577 .707 r
F P
0 g
s
.35933 .77777 m .35781 .75867 L .36073 .76121 L p .707 .577 .707 r
F P
0 g
s
.3575 .69838 m .3605 .73656 L .34758 .73486 L p .707 .577 .707 r
F P
0 g
s
.35781 .75867 m .35933 .77777 L .34675 .77621 L p .707 .577 .707 r
F P
0 g
s
.35823 .7883 m .35824 .52952 L .35742 .46859 L .707 .578 .707 r
F
.35824 .79037 m .35824 .78808 L p .35823 .7883 L F P
0 g
s
.35824 .78808 m .35824 .52952 L p .35823 .7883 L .707 .578 .707 r
F P
0 g
s
.34638 .67199 m .34457 .61546 L .3574 .62087 L p .707 .577 .707 r
F P
0 g
s
.34758 .73486 m .34458 .69668 L .3575 .69838 L p .707 .577 .707 r
F P
0 g
s
.34675 .77621 m .34523 .75711 L .35781 .75867 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35824 .79037 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .27638 m .35694 .48851 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .48851 m .35694 .77827 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35824 .52952 m .35824 .28848 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36057 .62708 m .36237 .68361 L .35921 .6774 L p .707 .577 .707 r
F P
0 g
s
.36078 .70107 m .36379 .73925 L .3605 .73656 L p .707 .577 .707 r
F P
0 g
s
.36073 .76121 m .36225 .78031 L .35933 .77777 L p .707 .577 .707 r
F P
0 g
s
.35824 .28848 m .35824 .79037 L .37341 .80178 L p .707 .577 .707 r
F P
0 g
s
.17448 .79935 m .17295 .78025 L .16037 .77869 L p .707 .577 .707 r
F P
0 g
s
.16037 .77869 m .1619 .79779 L .17448 .79935 L p .707 .577 .707 r
F P
0 g
s
.15666 .63099 m .15847 .68752 L .16163 .69372 L p .707 .577 .707 r
F P
0 g
s
.64306 .28628 m .64306 .78817 L .64176 .77607 L p .707 .578 .707 r
F P
0 g
s
.64176 .77607 m .64176 .27418 L .64306 .28628 L p .707 .578 .707 r
F P
0 g
s
.16365 .75679 m .16064 .71861 L .15735 .71592 L p .707 .577 .707 r
F P
0 g
s
.15735 .71592 m .16036 .7541 L .16365 .75679 L p .707 .577 .707 r
F P
0 g
s
.15847 .68752 m .15666 .63099 L .16348 .62459 L p .707 .577 .707 r
F P
0 g
s
.1619 .79779 m .16037 .77869 L .15746 .77616 L p .707 .577 .707 r
F P
0 g
s
.15746 .77616 m .15898 .79526 L .1619 .79779 L p .707 .577 .707 r
F P
0 g
s
.16348 .62459 m .16528 .68112 L .15847 .68752 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35694 .27638 L .36964 .26476 L p .707 .577 .707 r
F P
0 g
s
.16036 .7541 m .15735 .71592 L .16402 .71251 L p .707 .577 .707 r
F P
0 g
s
.16402 .71251 m .16703 .75069 L .16036 .7541 L p .707 .577 .707 r
F P
0 g
s
.64176 .27418 m .64176 .77607 L .62658 .76466 L p .707 .577 .707 r
F P
0 g
s
.62658 .76466 m .62658 .26277 L .64176 .27418 L p .707 .577 .707 r
F P
0 g
s
.16528 .68112 m .16348 .62459 L .17961 .61863 L p .707 .577 .707 r
F P
0 g
s
.15898 .79526 m .15746 .77616 L .16449 .77289 L p .707 .577 .707 r
F P
0 g
s
.16449 .77289 m .16601 .79199 L .15898 .79526 L p .707 .577 .707 r
F P
0 g
s
.17961 .61863 m .18141 .67515 L .16528 .68112 L p .707 .577 .707 r
F P
0 g
s
.34457 .61546 m .34638 .67199 L .32513 .66791 L p .707 .577 .707 r
F P
0 g
s
.32513 .66791 m .32333 .61138 L .34457 .61546 L p .707 .577 .707 r
F P
0 g
s
.16703 .75069 m .16402 .71251 L .18 .7087 L p .707 .577 .707 r
F P
0 g
s
.18 .7087 m .183 .74688 L .16703 .75069 L p .707 .577 .707 r
F P
0 g
s
.18141 .67515 m .17961 .61863 L .20347 .61368 L p .707 .577 .707 r
F P
0 g
s
.36964 .76665 m .36964 .26476 L .39511 .25476 L p .707 .577 .707 r
F P
0 g
s
.36964 .26476 m .36964 .76665 L .35694 .77827 L p .707 .577 .707 r
F P
0 g
s
.62658 .26277 m .62658 .76466 L .59902 .75507 L p .707 .577 .707 r
F P
0 g
s
.59902 .75507 m .59902 .25318 L .62658 .26277 L p .707 .577 .707 r
F P
0 g
s
.20347 .61368 m .20528 .67021 L .18141 .67515 L p .707 .577 .707 r
F P
0 g
s
.34458 .69668 m .34758 .73486 L .32629 .73432 L p .707 .577 .707 r
F P
0 g
s
.32629 .73432 m .32328 .69614 L .34458 .69668 L p .707 .577 .707 r
F P
0 g
s
.16601 .79199 m .16449 .77289 L .18078 .7692 L p .707 .577 .707 r
F P
0 g
s
.32333 .61138 m .32513 .66791 L .29755 .66556 L p .707 .577 .707 r
F P
0 g
s
.29755 .66556 m .29574 .60903 L .32333 .61138 L p .707 .577 .707 r
F P
0 g
s
.18078 .7692 m .1823 .7883 L .16601 .79199 L p .707 .577 .707 r
F P
0 g
s
.20528 .67021 m .20347 .61368 L .23273 .61024 L p .707 .577 .707 r
F P
0 g
s
.183 .74688 m .18 .7087 L .20371 .70487 L p .707 .577 .707 r
F P
0 g
s
.20371 .70487 m .20672 .74305 L .183 .74688 L p .707 .577 .707 r
F P
0 g
s
.34523 .75711 m .34675 .77621 L .32574 .77579 L p .707 .577 .707 r
F P
0 g
s
.32574 .77579 m .32422 .75669 L .34523 .75711 L p .707 .577 .707 r
F P
0 g
s
.29574 .60903 m .29755 .66556 L .26633 .66516 L p .707 .577 .707 r
F P
0 g
s
.26633 .66516 m .26453 .60864 L .29574 .60903 L p .707 .577 .707 r
F P
0 g
s
.23273 .61024 m .23454 .66677 L .20528 .67021 L p .707 .577 .707 r
F P
0 g
s
.73366 .6639 m .73547 .60961 L .70425 .60639 L p .707 .577 .707 r
F P
0 g
s
.73547 .60961 m .73366 .6639 L .76546 .66377 L p .707 .577 .707 r
F P
0 g
s
.76546 .66377 m .76726 .60948 L .73547 .60961 L p .707 .577 .707 r
F P
0 g
s
.23454 .66677 m .23273 .61024 L .26453 .60864 L p .707 .577 .707 r
F P
0 g
s
.32328 .69614 m .32629 .73432 L .29871 .73499 L p .707 .577 .707 r
F P
0 g
s
.29871 .73499 m .29571 .69681 L .32328 .69614 L p .707 .577 .707 r
F P
0 g
s
.76726 .60948 m .76546 .66377 L .79472 .66031 L p .707 .577 .707 r
F P
0 g
s
.79472 .66031 m .79652 .60601 L .76726 .60948 L p .707 .577 .707 r
F P
0 g
s
.26453 .60864 m .26633 .66516 L .23454 .66677 L p .707 .577 .707 r
F P
0 g
s
.39511 .25476 m .39511 .75665 L .36964 .76665 L p .707 .577 .707 r
F P
0 g
s
.39511 .75665 m .39511 .25476 L .43084 .24736 L p .707 .577 .707 r
F P
0 g
s
.70245 .66068 m .70425 .60639 L .67667 .60013 L p .707 .577 .707 r
F P
0 g
s
.70425 .60639 m .70245 .66068 L .73366 .6639 L p .707 .577 .707 r
F P
0 g
s
.1823 .7883 m .18078 .7692 L .20474 .76547 L p .707 .577 .707 r
F P
0 g
s
.20474 .76547 m .20626 .78457 L .1823 .7883 L p .707 .577 .707 r
F P
0 g
s
.20672 .74305 m .20371 .70487 L .23284 .7014 L p .707 .577 .707 r
F P
0 g
s
.59902 .25318 m .59902 .75507 L .56176 .74824 L p .707 .577 .707 r
F P
0 g
s
.56176 .74824 m .56176 .24635 L .59902 .25318 L p .707 .577 .707 r
F P
0 g
s
.23284 .7014 m .23585 .73958 L .20672 .74305 L p .707 .577 .707 r
F P
0 g
s
.79652 .60601 m .79472 .66031 L .81858 .65384 L p .707 .577 .707 r
F P
0 g
s
.81858 .65384 m .82039 .59955 L .79652 .60601 L p .707 .577 .707 r
F P
0 g
s
.32422 .75669 m .32574 .77579 L .29835 .77654 L p .707 .577 .707 r
F P
0 g
s
.29835 .77654 m .29683 .75744 L .32422 .75669 L p .707 .577 .707 r
F P
0 g
s
.29571 .69681 m .29871 .73499 L .26755 .7368 L p .707 .577 .707 r
F P
0 g
s
.26755 .7368 m .26454 .69862 L .29571 .69681 L p .707 .577 .707 r
F P
0 g
s
.67487 .65443 m .67667 .60013 L .65543 .59146 L p .707 .577 .707 r
F P
0 g
s
.67667 .60013 m .67487 .65443 L .70245 .66068 L p .707 .577 .707 r
F P
0 g
s
.23585 .73958 m .23284 .7014 L .26454 .69862 L p .707 .577 .707 r
F P
0 g
s
.26454 .69862 m .26755 .7368 L .23585 .73958 L p .707 .577 .707 r
F P
0 g
s
.73245 .73282 m .73545 .6983 L .70429 .69319 L p .707 .577 .707 r
F P
0 g
s
.73545 .6983 m .73245 .73282 L .76415 .73362 L p .707 .577 .707 r
F P
0 g
s
.76415 .73362 m .76715 .6991 L .73545 .6983 L p .707 .577 .707 r
F P
0 g
s
.20626 .78457 m .20474 .76547 L .23401 .76205 L p .707 .577 .707 r
F P
0 g
s
.23401 .76205 m .23554 .78115 L .20626 .78457 L p .707 .577 .707 r
F P
0 g
s
.76715 .6991 m .76415 .73362 L .79328 .73003 L p .707 .577 .707 r
F P
0 g
s
.79328 .73003 m .79629 .69551 L .76715 .6991 L p .707 .577 .707 r
F P
0 g
s
.70129 .72771 m .70429 .69319 L .67671 .68426 L p .707 .577 .707 r
F P
0 g
s
.70429 .69319 m .70129 .72771 L .73245 .73282 L p .707 .577 .707 r
F P
0 g
s
.43084 .74925 m .43084 .24736 L .47334 .24329 L p .707 .577 .707 r
F P
0 g
s
.43084 .24736 m .43084 .74925 L .39511 .75665 L p .707 .577 .707 r
F P
0 g
s
.29683 .75744 m .29835 .77654 L .26727 .77838 L p .707 .577 .707 r
F P
0 g
s
.26727 .77838 m .26575 .75928 L .29683 .75744 L p .707 .577 .707 r
F P
0 g
s
.82039 .59955 m .81858 .65384 L .83471 .64502 L p .707 .577 .707 r
F P
0 g
s
.83471 .64502 m .83652 .59072 L .82039 .59955 L p .707 .577 .707 r
F P
0 g
s
.56176 .24635 m .56176 .74824 L .51845 .74483 L p .707 .577 .707 r
F P
0 g
s
.51845 .74483 m .51845 .24294 L .56176 .24635 L p .707 .577 .707 r
F P
0 g
s
.23554 .78115 m .23401 .76205 L .26575 .75928 L p .707 .577 .707 r
F P
0 g
s
.65543 .59146 m .65362 .64576 L .67487 .65443 L p .707 .577 .707 r
F P
0 g
s
.26575 .75928 m .26727 .77838 L .23554 .78115 L p .707 .577 .707 r
F P
0 g
s
.65362 .64576 m .65543 .59146 L .64259 .58121 L p .707 .577 .707 r
F P
0 g
s
.79629 .69551 m .79328 .73003 L .817 .7224 L p .707 .577 .707 r
F P
0 g
s
.817 .7224 m .82 .68788 L .79629 .69551 L p .707 .577 .707 r
F P
0 g
s
.73273 .7761 m .73425 .75889 L .70317 .75357 L p .707 .577 .707 r
F P
0 g
s
.73425 .75889 m .73273 .7761 L .76446 .77708 L p .707 .577 .707 r
F P
0 g
s
.76446 .77708 m .76598 .75987 L .73425 .75889 L p .707 .577 .707 r
F P
0 g
s
.67371 .71878 m .67671 .68426 L .65542 .6724 L p .707 .577 .707 r
F P
0 g
s
.67671 .68426 m .67371 .71878 L .70129 .72771 L p .707 .577 .707 r
F P
0 g
s
.47334 .74518 m .47334 .24329 L .51845 .24294 L p .707 .577 .707 r
F P
0 g
s
.47334 .24329 m .47334 .74518 L .43084 .74925 L p .707 .577 .707 r
F P
0 g
s
.76598 .75987 m .76446 .77708 L .79374 .77361 L p .707 .577 .707 r
F P
0 g
s
.79374 .77361 m .79526 .7564 L .76598 .75987 L p .707 .577 .707 r
F P
0 g
s
.51845 .24294 m .51845 .74483 L .47334 .74518 L p .707 .577 .707 r
F P
0 g
s
.70164 .77078 m .70317 .75357 L .67578 .74441 L p .707 .577 .707 r
F P
0 g
s
.70317 .75357 m .70164 .77078 L .73273 .7761 L p .707 .577 .707 r
F P
0 g
s
.67578 .74441 m .67426 .76162 L .70164 .77078 L p .707 .577 .707 r
F P
0 g
s
.79526 .7564 m .79374 .77361 L .81769 .76604 L p .707 .577 .707 r
F P
0 g
s
.81769 .76604 m .81922 .74882 L .79526 .7564 L p .707 .577 .707 r
F P
0 g
s
.83652 .59072 m .83471 .64502 L .84153 .63469 L p .707 .577 .707 r
F P
0 g
s
.84153 .63469 m .84334 .5804 L .83652 .59072 L p .707 .577 .707 r
F P
0 g
s
.65542 .6724 m .65242 .70692 L .67371 .71878 L p .707 .577 .707 r
F P
0 g
s
.64259 .58121 m .64079 .63551 L .65362 .64576 L p .707 .577 .707 r
F P
0 g
s
.67426 .76162 m .67578 .74441 L .65477 .73232 L p .707 .577 .707 r
F P
0 g
s
.82 .68788 m .817 .7224 L .83297 .71148 L p .707 .577 .707 r
F P
0 g
s
.83297 .71148 m .83597 .67696 L .82 .68788 L p .707 .577 .707 r
F P
0 g
s
.65242 .70692 m .65542 .6724 L .6425 .65877 L p .707 .577 .707 r
F P
0 g
s
.64079 .63551 m .64259 .58121 L .63943 .5704 L p .707 .577 .707 r
F P
0 g
s
.65477 .73232 m .65325 .74953 L .67426 .76162 L p .707 .577 .707 r
F P
0 g
s
.81922 .74882 m .81769 .76604 L .83399 .7551 L p .707 .577 .707 r
F P
0 g
s
.83399 .7551 m .83551 .73789 L .81922 .74882 L p .707 .577 .707 r
F P
0 g
s
.6425 .65877 m .6395 .69329 L .65242 .70692 L p .707 .577 .707 r
F P
0 g
s
.65325 .74953 m .65477 .73232 L .64219 .71849 L p .707 .577 .707 r
F P
0 g
s
.83597 .67696 m .83297 .71148 L .83964 .69834 L p .707 .577 .707 r
F P
0 g
s
.83964 .69834 m .84264 .66382 L .83597 .67696 L p .707 .577 .707 r
F P
0 g
s
.63943 .5704 m .63763 .62469 L .64079 .63551 L p .707 .577 .707 r
F P
0 g
s
.84334 .5804 m .84153 .63469 L .83837 .62388 L p .707 .577 .707 r
F P
0 g
s
.83837 .62388 m .84017 .56958 L .84334 .5804 L p .707 .577 .707 r
F P
0 g
s
.6395 .69329 m .6425 .65877 L .63921 .64469 L p .707 .577 .707 r
F P
0 g
s
.64219 .71849 m .64067 .7357 L .65325 .74953 L p .707 .577 .707 r
F P
0 g
s
.63763 .62469 m .63943 .5704 L .64625 .56007 L p .707 .577 .707 r
F P
0 g
s
.83551 .73789 m .83399 .7551 L .84102 .74186 L p .707 .577 .707 r
F P
0 g
s
.84102 .74186 m .84254 .72465 L .83551 .73789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63921 .64469 m .63621 .67921 L .6395 .69329 L p .707 .577 .707 r
F P
0 g
s
.64067 .7357 m .64219 .71849 L .63927 .70426 L p .707 .577 .707 r
F P
0 g
s
.84264 .66382 m .83964 .69834 L .83635 .68426 L p .707 .577 .707 r
F P
0 g
s
.83635 .68426 m .83936 .64974 L .84264 .66382 L p .707 .577 .707 r
F P
0 g
s
.63927 .70426 m .63775 .72147 L .64067 .7357 L p .707 .577 .707 r
F P
0 g
s
.64625 .56007 m .64444 .61437 L .63763 .62469 L p .707 .577 .707 r
F P
0 g
s
.63621 .67921 m .63921 .64469 L .64588 .63154 L p .707 .577 .707 r
F P
0 g
s
.84017 .56958 m .83837 .62388 L .82554 .61363 L p .707 .577 .707 r
F P
0 g
s
.82554 .61363 m .82734 .55934 L .84017 .56958 L p .707 .577 .707 r
F P
0 g
s
.64444 .61437 m .64625 .56007 L .66238 .55125 L p .707 .577 .707 r
F P
0 g
s
.38989 .61718 m .39408 .56128 L .36294 .55745 L p .707 .577 .707 r
F P
0 g
s
.39408 .56128 m .38989 .61718 L .42162 .61868 L p .707 .577 .707 r
F P
0 g
s
.42162 .61868 m .42581 .56278 L .39408 .56128 L p .707 .577 .707 r
F P
0 g
s
.84254 .72465 m .84102 .74186 L .8381 .72763 L p .707 .577 .707 r
F P
0 g
s
.8381 .72763 m .83962 .71042 L .84254 .72465 L p .707 .577 .707 r
F P
0 g
s
.42581 .56278 m .42162 .61868 L .45083 .6177 L p .707 .577 .707 r
F P
0 g
s
.45083 .6177 m .45502 .5618 L .42581 .56278 L p .707 .577 .707 r
F P
0 g
s
.64588 .63154 m .64288 .66606 L .63621 .67921 L p .707 .577 .707 r
F P
0 g
s
.63775 .72147 m .63927 .70426 L .6463 .69102 L p .707 .577 .707 r
F P
0 g
s
.35875 .61334 m .36294 .55745 L .33543 .55166 L p .707 .577 .707 r
F P
0 g
s
.36294 .55745 m .35875 .61334 L .38989 .61718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83936 .64974 m .83635 .68426 L .82343 .67062 L p .707 .577 .707 r
F P
0 g
s
.82343 .67062 m .82644 .6361 L .83936 .64974 L p .707 .577 .707 r
F P
0 g
s
.6463 .69102 m .64478 .70823 L .63775 .72147 L p .707 .577 .707 r
F P
0 g
s
.82734 .55934 m .82554 .61363 L .80429 .60496 L p .707 .577 .707 r
F P
0 g
s
.80429 .60496 m .8061 .55066 L .82734 .55934 L p .707 .577 .707 r
F P
0 g
s
.64288 .66606 m .64588 .63154 L .66186 .62062 L p .707 .577 .707 r
F P
0 g
s
.66238 .55125 m .66057 .60554 L .64444 .61437 L p .707 .577 .707 r
F P
0 g
s
.45502 .5618 m .45083 .6177 L .47466 .61433 L p .707 .577 .707 r
F P
0 g
s
.47466 .61433 m .47885 .55844 L .45502 .5618 L p .707 .577 .707 r
F P
0 g
s
.33543 .55166 m .33124 .60755 L .35875 .61334 L p .707 .577 .707 r
F P
0 g
s
.38613 .67239 m .39305 .63525 L .36233 .62842 L p .707 .577 .707 r
F P
0 g
s
.39305 .63525 m .38613 .67239 L .41742 .6774 L p .707 .577 .707 r
F P
0 g
s
.41742 .6774 m .42434 .64027 L .39305 .63525 L p .707 .577 .707 r
F P
0 g
s
.33124 .60755 m .33543 .55166 L .31425 .54448 L p .707 .577 .707 r
F P
0 g
s
.66057 .60554 m .66238 .55125 L .68624 .54479 L p .707 .577 .707 r
F P
0 g
s
.42434 .64027 m .41742 .6774 L .44623 .68012 L p .707 .577 .707 r
F P
0 g
s
.44623 .68012 m .45315 .64298 L .42434 .64027 L p .707 .577 .707 r
F P
0 g
s
.35541 .66556 m .36233 .62842 L .33521 .62045 L p .707 .577 .707 r
F P
0 g
s
.36233 .62842 m .35541 .66556 L .38613 .67239 L p .707 .577 .707 r
F P
0 g
s
.83962 .71042 m .8381 .72763 L .82552 .7138 L p .707 .577 .707 r
F P
0 g
s
.82552 .7138 m .82704 .69658 L .83962 .71042 L p .707 .577 .707 r
F P
0 g
s
.66186 .62062 m .65885 .65514 L .64288 .66606 L p .707 .577 .707 r
F P
0 g
s
.33521 .62045 m .32828 .65758 L .35541 .66556 L p .707 .577 .707 r
F P
0 g
s
.64478 .70823 m .6463 .69102 L .6626 .68008 L p .707 .577 .707 r
F P
0 g
s
.31425 .54448 m .31006 .60037 L .33124 .60755 L p .707 .577 .707 r
F P
0 g
s
.3883 .71373 m .39182 .69517 L .36121 .68818 L p .707 .577 .707 r
F P
0 g
s
.39182 .69517 m .3883 .71373 L .41961 .71893 L p .707 .577 .707 r
F P
0 g
s
.41961 .71893 m .42313 .70037 L .39182 .69517 L p .707 .577 .707 r
F P
0 g
s
.47885 .55844 m .47466 .61433 L .49077 .60891 L p .707 .577 .707 r
F P
0 g
s
.49077 .60891 m .49497 .55302 L .47885 .55844 L p .707 .577 .707 r
F P
0 g
s
.8061 .55066 m .80429 .60496 L .77671 .59871 L p .707 .577 .707 r
F P
0 g
s
.77671 .59871 m .77852 .54441 L .8061 .55066 L p .707 .577 .707 r
F P
0 g
s
.45315 .64298 m .44623 .68012 L .46974 .68026 L p .707 .577 .707 r
F P
0 g
s
.46974 .68026 m .47666 .64313 L .45315 .64298 L p .707 .577 .707 r
F P
0 g
s
.82644 .6361 m .82343 .67062 L .80214 .65876 L p .707 .577 .707 r
F P
0 g
s
.80214 .65876 m .80514 .62424 L .82644 .6361 L p .707 .577 .707 r
F P
0 g
s
.36121 .68818 m .35769 .70674 L .3883 .71373 L p .707 .577 .707 r
F P
0 g
s
.32828 .65758 m .33521 .62045 L .31432 .61211 L p .707 .577 .707 r
F P
0 g
s
.42313 .70037 m .41961 .71893 L .44855 .72184 L p .707 .577 .707 r
F P
0 g
s
.44855 .72184 m .45207 .70328 L .42313 .70037 L p .707 .577 .707 r
F P
0 g
s
.65885 .65514 m .66186 .62062 L .68557 .613 L p .707 .577 .707 r
F P
0 g
s
.6626 .68008 m .66107 .69729 L .64478 .70823 L p .707 .577 .707 r
F P
0 g
s
.68624 .54479 m .68444 .59908 L .66057 .60554 L p .707 .577 .707 r
F P
0 g
s
.35769 .70674 m .36121 .68818 L .3343 .68009 L p .707 .577 .707 r
F P
0 g
s
.68444 .59908 m .68624 .54479 L .71551 .54132 L p .707 .577 .707 r
F P
0 g
s
.31006 .60037 m .31425 .54448 L .30147 .53661 L p .707 .577 .707 r
F P
0 g
s
.3343 .68009 m .33077 .69865 L .35769 .70674 L p .707 .577 .707 r
F P
0 g
s
.31432 .61211 m .3074 .64925 L .32828 .65758 L p .707 .577 .707 r
F P
0 g
s
.77852 .54441 m .77671 .59871 L .74549 .59549 L p .707 .577 .707 r
F P
0 g
s
.74549 .59549 m .7473 .54119 L .77852 .54441 L p .707 .577 .707 r
F P
0 g
s
.45207 .70328 m .44855 .72184 L .47229 .72217 L p .707 .577 .707 r
F P
0 g
s
.47229 .72217 m .47582 .70361 L .45207 .70328 L p .707 .577 .707 r
F P
0 g
s
.82704 .69658 m .82552 .7138 L .80451 .70171 L p .707 .577 .707 r
F P
0 g
s
.80451 .70171 m .80603 .6845 L .82704 .69658 L p .707 .577 .707 r
F P
0 g
s
.7137 .59562 m .71551 .54132 L .7473 .54119 L p .707 .577 .707 r
F P
0 g
s
.71551 .54132 m .7137 .59562 L .68444 .59908 L p .707 .577 .707 r
F P
0 g
s
.30147 .53661 m .29728 .5925 L .31006 .60037 L p .707 .577 .707 r
F P
0 g
s
.68557 .613 m .68257 .64752 L .65885 .65514 L p .707 .577 .707 r
F P
0 g
s
.33077 .69865 m .3343 .68009 L .31371 .67169 L p .707 .577 .707 r
F P
0 g
s
.66107 .69729 m .6626 .68008 L .68655 .67251 L p .707 .577 .707 r
F P
0 g
s
.7473 .54119 m .74549 .59549 L .7137 .59562 L p .707 .577 .707 r
F P
0 g
s
.80514 .62424 m .80214 .65876 L .77456 .64984 L p .707 .577 .707 r
F P
0 g
s
.77456 .64984 m .77757 .61532 L .80514 .62424 L p .707 .577 .707 r
F P
0 g
s
.47666 .64313 m .46974 .68026 L .48564 .67782 L p .707 .577 .707 r
F P
0 g
s
.48564 .67782 m .49256 .64069 L .47666 .64313 L p .707 .577 .707 r
F P
0 g
s
.68257 .64752 m .68557 .613 L .7147 .60941 L p .707 .577 .707 r
F P
0 g
s
.31371 .67169 m .31018 .69025 L .33077 .69865 L p .707 .577 .707 r
F P
0 g
s
.3074 .64925 m .31432 .61211 L .30172 .60423 L p .707 .577 .707 r
F P
0 g
s
.49497 .55302 m .49077 .60891 L .4976 .60197 L p .707 .577 .707 r
F P
0 g
s
.4976 .60197 m .5018 .54607 L .49497 .55302 L p .707 .577 .707 r
F P
0 g
s
.68655 .67251 m .68503 .68972 L .66107 .69729 L p .707 .577 .707 r
F P
0 g
s
.30172 .60423 m .2948 .64136 L .3074 .64925 L p .707 .577 .707 r
F P
0 g
s
.29728 .5925 m .30147 .53661 L .29834 .52882 L p .707 .577 .707 r
F P
0 g
s
.77757 .61532 m .77456 .64984 L .7434 .64473 L p .707 .577 .707 r
F P
0 g
s
.7434 .64473 m .7464 .61021 L .77757 .61532 L p .707 .577 .707 r
F P
0 g
s
.7117 .64393 m .7147 .60941 L .7464 .61021 L p .707 .577 .707 r
F P
0 g
s
.7147 .60941 m .7117 .64393 L .68257 .64752 L p .707 .577 .707 r
F P
0 g
s
.80603 .6845 m .80451 .70171 L .77712 .69255 L p .707 .577 .707 r
F P
0 g
s
.77712 .69255 m .77865 .67534 L .80603 .6845 L p .707 .577 .707 r
F P
0 g
s
.47582 .70361 m .47229 .72217 L .48851 .71989 L p .707 .577 .707 r
F P
0 g
s
.48851 .71989 m .49203 .70133 L .47582 .70361 L p .707 .577 .707 r
F P
0 g
s
.7464 .61021 m .7434 .64473 L .7117 .64393 L p .707 .577 .707 r
F P
0 g
s
.68503 .68972 m .68655 .67251 L .71583 .66904 L p .707 .577 .707 r
F P
0 g
s
.31018 .69025 m .31371 .67169 L .30146 .6638 L p .707 .577 .707 r
F P
0 g
s
.30146 .6638 m .29794 .68236 L .31018 .69025 L p .707 .577 .707 r
F P
0 g
s
.29834 .52882 m .29415 .58471 L .29728 .5925 L p .707 .577 .707 r
F P
0 g
s
.71583 .66904 m .71431 .68625 L .68503 .68972 L p .707 .577 .707 r
F P
0 g
s
.49256 .64069 m .48564 .67782 L .49238 .67304 L p .707 .577 .707 r
F P
0 g
s
.49238 .67304 m .4993 .6359 L .49256 .64069 L p .707 .577 .707 r
F P
0 g
s
.77865 .67534 m .77712 .69255 L .74604 .68723 L p .707 .577 .707 r
F P
0 g
s
.74604 .68723 m .74756 .67002 L .77865 .67534 L p .707 .577 .707 r
F P
0 g
s
.71431 .68625 m .71583 .66904 L .74756 .67002 L p .707 .577 .707 r
F P
0 g
s
.2948 .64136 m .30172 .60423 L .29864 .59757 L p .707 .577 .707 r
F P
0 g
s
.74756 .67002 m .74604 .68723 L .71431 .68625 L p .707 .577 .707 r
F P
0 g
s
.5018 .54607 m .4976 .60197 L .49448 .59418 L p .707 .577 .707 r
F P
0 g
s
.49448 .59418 m .49867 .53829 L .5018 .54607 L p .707 .577 .707 r
F P
0 g
s
.29864 .59757 m .29172 .6347 L .2948 .64136 L p .707 .577 .707 r
F P
0 g
s
.49203 .70133 m .48851 .71989 L .49561 .71522 L p .707 .577 .707 r
F P
0 g
s
.49561 .71522 m .49914 .69666 L .49203 .70133 L p .707 .577 .707 r
F P
0 g
s
.29415 .58471 m .29834 .52882 L .30517 .52188 L p .707 .577 .707 r
F P
0 g
s
.29794 .68236 m .30146 .6638 L .29876 .6572 L p .707 .577 .707 r
F P
0 g
s
.29876 .6572 m .29523 .67576 L .29794 .68236 L p .707 .577 .707 r
F P
0 g
s
.30517 .52188 m .30098 .57777 L .29415 .58471 L p .707 .577 .707 r
F P
0 g
s
.4993 .6359 m .49238 .67304 L .4893 .66638 L p .707 .577 .707 r
F P
0 g
s
.4893 .66638 m .49622 .62924 L .4993 .6359 L p .707 .577 .707 r
F P
0 g
s
.29172 .6347 m .29864 .59757 L .30538 .59279 L p .707 .577 .707 r
F P
0 g
s
.49867 .53829 m .49448 .59418 L .4817 .58631 L p .707 .577 .707 r
F P
0 g
s
.4817 .58631 m .48589 .53042 L .49867 .53829 L p .707 .577 .707 r
F P
0 g
s
.30538 .59279 m .29846 .62992 L .29172 .6347 L p .707 .577 .707 r
F P
0 g
s
.30098 .57777 m .30517 .52188 L .32129 .51646 L p .707 .577 .707 r
F P
0 g
s
.49914 .69666 m .49561 .71522 L .49291 .70862 L p .707 .577 .707 r
F P
0 g
s
.49291 .70862 m .49644 .69006 L .49914 .69666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29523 .67576 m .29876 .6572 L .30587 .65253 L p .707 .577 .707 r
F P
0 g
s
.30587 .65253 m .30234 .67109 L .29523 .67576 L p .707 .577 .707 r
F P
0 g
s
.32129 .51646 m .3171 .57235 L .30098 .57777 L p .707 .577 .707 r
F P
0 g
s
.49622 .62924 m .4893 .66638 L .4767 .65849 L p .707 .577 .707 r
F P
0 g
s
.4767 .65849 m .48362 .62136 L .49622 .62924 L p .707 .577 .707 r
F P
0 g
s
.29846 .62992 m .30538 .59279 L .32128 .59035 L p .707 .577 .707 r
F P
0 g
s
.48589 .53042 m .4817 .58631 L .46051 .57913 L p .707 .577 .707 r
F P
0 g
s
.46051 .57913 m .46471 .52323 L .48589 .53042 L p .707 .577 .707 r
F P
0 g
s
.3171 .57235 m .32129 .51646 L .34512 .51309 L p .707 .577 .707 r
F P
0 g
s
.32128 .59035 m .31436 .62748 L .29846 .62992 L p .707 .577 .707 r
F P
0 g
s
.49644 .69006 m .49291 .70862 L .48067 .70073 L p .707 .577 .707 r
F P
0 g
s
.48067 .70073 m .48419 .68217 L .49644 .69006 L p .707 .577 .707 r
F P
0 g
s
.30234 .67109 m .30587 .65253 L .32208 .65025 L p .707 .577 .707 r
F P
0 g
s
.34512 .51309 m .34093 .56899 L .3171 .57235 L p .707 .577 .707 r
F P
0 g
s
.32208 .65025 m .31856 .6688 L .30234 .67109 L p .707 .577 .707 r
F P
0 g
s
.46471 .52323 m .46051 .57913 L .43301 .57334 L p .707 .577 .707 r
F P
0 g
s
.43301 .57334 m .4372 .51744 L .46471 .52323 L p .707 .577 .707 r
F P
0 g
s
.48362 .62136 m .4767 .65849 L .45582 .65016 L p .707 .577 .707 r
F P
0 g
s
.45582 .65016 m .46274 .61302 L .48362 .62136 L p .707 .577 .707 r
F P
0 g
s
.31436 .62748 m .32128 .59035 L .34479 .59049 L p .707 .577 .707 r
F P
0 g
s
.34093 .56899 m .34512 .51309 L .37433 .51211 L p .707 .577 .707 r
F P
0 g
s
.34479 .59049 m .33787 .62763 L .31436 .62748 L p .707 .577 .707 r
F P
0 g
s
.4372 .51744 m .43301 .57334 L .40186 .56951 L p .707 .577 .707 r
F P
0 g
s
.40186 .56951 m .40606 .51361 L .4372 .51744 L p .707 .577 .707 r
F P
0 g
s
.48419 .68217 m .48067 .70073 L .46008 .69233 L p .707 .577 .707 r
F P
0 g
s
.46008 .69233 m .4636 .67377 L .48419 .68217 L p .707 .577 .707 r
F P
0 g
s
.37014 .56801 m .37433 .51211 L .40606 .51361 L p .707 .577 .707 r
F P
0 g
s
.37433 .51211 m .37014 .56801 L .34093 .56899 L p .707 .577 .707 r
F P
0 g
s
.40606 .51361 m .40186 .56951 L .37014 .56801 L p .707 .577 .707 r
F P
0 g
s
.31856 .6688 m .32208 .65025 L .34583 .65058 L p .707 .577 .707 r
F P
0 g
s
.46274 .61302 m .45582 .65016 L .42869 .64218 L p .707 .577 .707 r
F P
0 g
s
.42869 .64218 m .43561 .60505 L .46274 .61302 L p .707 .577 .707 r
F P
0 g
s
.34583 .65058 m .3423 .66913 L .31856 .6688 L p .707 .577 .707 r
F P
0 g
s
.33787 .62763 m .34479 .59049 L .3736 .5932 L p .707 .577 .707 r
F P
0 g
s
.3736 .5932 m .36668 .63034 L .33787 .62763 L p .707 .577 .707 r
F P
0 g
s
.43561 .60505 m .42869 .64218 L .39797 .63536 L p .707 .577 .707 r
F P
0 g
s
.39797 .63536 m .4049 .59822 L .43561 .60505 L p .707 .577 .707 r
F P
0 g
s
.4636 .67377 m .46008 .69233 L .43316 .68424 L p .707 .577 .707 r
F P
0 g
s
.43316 .68424 m .43669 .66568 L .4636 .67377 L p .707 .577 .707 r
F P
0 g
s
.36668 .63034 m .3736 .5932 L .4049 .59822 L p .707 .577 .707 r
F P
0 g
s
.3423 .66913 m .34583 .65058 L .37477 .65349 L p .707 .577 .707 r
F P
0 g
s
.4049 .59822 m .39797 .63536 L .36668 .63034 L p .707 .577 .707 r
F P
0 g
s
.37477 .65349 m .37124 .67204 L .3423 .66913 L p .707 .577 .707 r
F P
0 g
s
.43669 .66568 m .43316 .68424 L .40255 .67725 L p .707 .577 .707 r
F P
0 g
s
.40255 .67725 m .40608 .65869 L .43669 .66568 L p .707 .577 .707 r
F P
0 g
s
.37124 .67204 m .37477 .65349 L .40608 .65869 L p .707 .577 .707 r
F P
0 g
s
.40608 .65869 m .40255 .67725 L .37124 .67204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001OOol@00000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001J
Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001HOol2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80006FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00001UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0000AOolA0014Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003Yoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000gOol005Aoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`00=Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000cOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
02moo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP06001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`03001JEP0000=JEPD00003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H0
05YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol01000FUH005YF0P001UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF1P000eYF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF0P001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF009JEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002eoo`00Dgoo0P000eYF3`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF
00000P000UYF00<005YFFUH015YF00@005YFFUIJEPL0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00AJEP@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
0eYF00<005YFFUH00eYF1P002Goo1@000goo1P001UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000`00
1eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUH0000300000eYF00000002000:Ool5
0009Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP8000=JEP03001JEUYF00=JEPL000=oo`D000Yoo`L000AJEP04001JEUYFFUH2
000]Ool003iooaH00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH015YF60000eYF
00@005YFFUIJEP<00003FUH005YF009JEP8002eoo`00=goo1`0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF20002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUH005YF00800003FUH005YF00AJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEPH0
00=JEP03001JEUYF00AJEP8000=JEP8002eoo`00<Woo1@000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP<00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YF00000UYF0P00;Goo000`
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P001UYF00<005YFFUH01000;Goo000^Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000
FUIJEUYF0`00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH3000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000800003FUH005YF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPH000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00D0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF1@001UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000P00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP040002FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH01P00
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00D005YFFUIJEP0000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF
00=JEPL000QJEP03001JEUYF00EJEPH000EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP000080009JEP04001JEUYFFUH>00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000/Ool01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH01EYF00D005YFFUIJEP0002ioo`00;7oo00@005YFFUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00AJEP8000=J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP80
009JEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP04001JEUYF
FUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00@000EJEP03001JEUYF00AJEP05001JEP00001JEP020006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH005YF0`0015YF00<005YFFUH00eYF00<005YFFUH00P0017oo
4P001goo0P000eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF5@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF100000=JEP00FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEP00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0P007goo0P0000MJEP00FUIJEP00FUH0000]Ool002eoo`03001JEP0000=JEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0400015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000`0015YF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP000080009JEP05001JEUYFFUH00005FUH00`00FUIJEP0A000BOol20002FUH00`00
FUH0000]Ool002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000AJEP8000EJEP@00003FUH0000000L000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=J
EP04001JEUYF0004FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04000@Ool01@00FUH005YF0000
;Goo000]Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00<005YF00000P000UYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPL0
00IJEP03001JEUYF00EJEP03001JEP0000D000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000004FUH800000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
000<Ool01@00FUH005YF0000;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP00
00EJEP<000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP8000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH01000FUH000001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0`00;Woo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YF000010000eYF00<005YFFUH00UYF1@001UYF10001EYF00<005YFFUH015YF
0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`800003
FUH0000002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP03FUH50004FUH50007FUH00`00
FUIJEP0400000eYF001JEP05FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03
001JEUYF00IJEPD000=JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
0eYF20003goo1P001eYF00<005YFFUH00P000eYF0P00;Woo000]Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500000eYF001JEP06
FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH0
00030006FUH6000AOol20004FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo000_Ool50003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUHA0003FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00
FUIJEP040004FUH00`00FUIJEP08FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF0P000eYF00<005YFFUH01EYF
00<005YFFUH00UYF4P0000IJEP00000005YF0006FUH200000eYF001oo`0]Ool003Aoo`L000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@00003FUH005YF00QJEP03001J
EUYF00AJEPh0009JEP<000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYF001JEP000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001UYF0`00;goo000gOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP040006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1`0000=JEP0000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUH005YF00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000_Ool0035oo`H0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800005FUH005YFFUH0000_Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003
FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP<000=J
EP03001oogoo02aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF
00AJEPD0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P001EYF0P0000=JEP00FUH01UYF
00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001o
ogoo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00AJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000IJEP@000IJEP03001JEUYF00IJEPD000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<00004Ool005YF000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH?000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P0017oo0`00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF000010001UYF1@0015YF00<0
05YFFUH01EYF00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00D005YFFUIJ
EP0000EJEP05001JEUYFFUH00002Ool40002FUH40005FUH00`00FUIJEP02FUH5000;Ool2000]Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000eYF00@005YFFUH000EJEP05001JEUYFFUH00006Ool@000@Ool2000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ400003FUH005YF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`00
00=JEP00FUH00eYF00D005YFFUIJEP0002Eoo`03001JEP0002eoo`00;Goo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP020005
FUH00`00FUIJEP02000ROol300000eYF001oo`0/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03
0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF0`000UYF00<005YFFUH00P0087oo0P00
0UYF0P00;Woo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1@000Woo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEP00008000=JEP03001oogoo01eoo`03001JEUYF009JEP8002ioo`00;Goo00<005YF
00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEPH000YJEP03001JEUYF00YJEP03001JEUYF00UJ
EPL0009JEP03001JEUYF00EJEP05001JEUYFFUH00002Ool00`00FUIJEP04FUH01000FUIJEUYF0`00
00=JEP00Ool077oo0`0015YF00<007ooOol0;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000?Ool01@00FUIJEUYF00001UYF00<005YFFUH0
1@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10001UYF
00D005YFFUIJEP0000=oo`8000=JEP03001JEUYF00AJEPH001Qoo`80009JEP03001JEUYF009JEP03
001oogoo02eoo`00;Woo>0000eYF00<005YFFUH00eYF10002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000Eoo`800003FUH005YF
00IJEP03001JEUYF009JEPT000Uoo`H000AJEP03001JEUYF0080031oo`00?goo200015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP04001JEUYFFUH20002FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`03Ool50006FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP03FUH3000bOol003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH01000FUH0000015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000eYF00<007ooOol00`001EYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00=7oo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH02P0000=JEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000`00=Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF1P0015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1@00>Woo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUHD000015YF000000000UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH000IJEP03001JEUYF00=JEP<00003FUH007oo00=ooa8003moo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2P0025YF00<005YFFUH015YF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP02
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT0
00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0007FUH00`00FUIJEP03FUH00`00FUH0001FOol002aoo`04001JEUYF0003
FUH01000FUIJEUYF200025YF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPH0009oo`03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00/000=JEP04001JEP00001E
Ool002eoo`03001JEP00009JEPH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Qoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP03FUH400000eYF0000001EOol002eoo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPT0011oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000IJEP04001JEUYFFUH20003Ool00`00FUH0001EOol002eoo`<00003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT001]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8000MJEP04001JEP000006
Ool2001EOol0031ooa@002Ioo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000MJEP<000Moo`03001JEP0005Eo
o`00K7oo0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0P002Woo00@005YF000005Ao
o`00KWoo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YF00000P0015YF00<005YF00000P002Woo0`000UYF00<007ooOol0DWoo001`
Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40005
FUH4000;Ool20002FUH01000FUIJEP00E7oo001dOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0>000>Ool00`00FUIJEP03FUH2001EOol007Yoo`P000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPP000=JEPL0011oo`<000EJEP8005Eoo`00PWoo9@000Woo1@00
3Woo0P000UYF00<005YFFUH00eYF00<007ooOol0E7oo002>Ool00`00FUIJEP02000GOol3000=Ool2
0005FUH00`00FUIJEP02001GOol008ioo`04001JEUYF000VOol20007FUH3001IOol008moo`8002=o
o`@00003FUH005YF00IJEP03001oogoo05Uoo`00Sgoo0`007Goo1@001EYF00<005YFFUH00eYF0P00
G7oo002?Ool00`00FUIJEP02000GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02001NOol008mo
o`800003FUH005YF00<000ioo`H000IJEP03001JEUYF00IJEP<0061oo`00T7oo00<005YF000015YF
3P000eYF00<005YFFUH01eYF00<005YFFUH015YF0P00HWoo002@Ool01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002AOol30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001XOol009=oo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00@006eoo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH00UYF
1P00LGoo002HOol>001gOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59934 .75469 m .59256 .70035 L .56152 .7017 L p .707 .577 .707 r
F P
0 g
s
.59256 .70035 m .59934 .75469 L .63092 .7501 L p .707 .577 .707 r
F P
0 g
s
.63092 .7501 m .62414 .69577 L .59256 .70035 L p .707 .577 .707 r
F P
0 g
s
.62414 .69577 m .63092 .7501 L .65995 .74274 L p .707 .577 .707 r
F P
0 g
s
.65995 .74274 m .65317 .6884 L .62414 .69577 L p .707 .577 .707 r
F P
0 g
s
.56831 .75604 m .56152 .7017 L .53407 .69969 L p .707 .577 .707 r
F P
0 g
s
.56152 .7017 m .56831 .75604 L .59934 .75469 L p .707 .577 .707 r
F P
0 g
s
.65317 .6884 m .65995 .74274 L .68359 .73331 L p .707 .577 .707 r
F P
0 g
s
.68359 .73331 m .67681 .67897 L .65317 .6884 L p .707 .577 .707 r
F P
0 g
s
.54085 .75403 m .53407 .69969 L .51288 .69452 L p .707 .577 .707 r
F P
0 g
s
.53407 .69969 m .54085 .75403 L .56831 .75604 L p .707 .577 .707 r
F P
0 g
s
.63591 .81217 m .6248 .77824 L .59435 .78795 L p .707 .577 .707 r
F P
0 g
s
.6248 .77824 m .63591 .81217 L .66393 .79937 L p .707 .577 .707 r
F P
0 g
s
.66393 .79937 m .65282 .76545 L .6248 .77824 L p .707 .577 .707 r
F P
0 g
s
.60546 .82187 m .59435 .78795 L .56445 .79362 L p .707 .577 .707 r
F P
0 g
s
.59435 .78795 m .60546 .82187 L .63591 .81217 L p .707 .577 .707 r
F P
0 g
s
.67681 .67897 m .68359 .73331 L .69952 .72274 L p .707 .577 .707 r
F P
0 g
s
.69952 .72274 m .69274 .66841 L .67681 .67897 L p .707 .577 .707 r
F P
0 g
s
.65282 .76545 m .66393 .79937 L .68676 .78475 L p .707 .577 .707 r
F P
0 g
s
.68676 .78475 m .67565 .75082 L .65282 .76545 L p .707 .577 .707 r
F P
0 g
s
.57556 .82755 m .56445 .79362 L .53801 .7947 L p .707 .577 .707 r
F P
0 g
s
.56445 .79362 m .57556 .82755 L .60546 .82187 L p .707 .577 .707 r
F P
0 g
s
.62853 .85558 m .62289 .83863 L .59243 .84825 L p .707 .577 .707 r
F P
0 g
s
.62289 .83863 m .62853 .85558 L .65675 .84283 L p .707 .577 .707 r
F P
0 g
s
.65675 .84283 m .6511 .82588 L .62289 .83863 L p .707 .577 .707 r
F P
0 g
s
.51288 .69452 m .51966 .74885 L .54085 .75403 L p .707 .577 .707 r
F P
0 g
s
.59807 .8652 m .59243 .84825 L .5627 .85379 L p .707 .577 .707 r
F P
0 g
s
.59243 .84825 m .59807 .8652 L .62853 .85558 L p .707 .577 .707 r
F P
0 g
s
.51966 .74885 m .51288 .69452 L .50003 .68668 L p .707 .577 .707 r
F P
0 g
s
.6511 .82588 m .65675 .84283 L .67995 .82819 L p .707 .577 .707 r
F P
0 g
s
.67995 .82819 m .6743 .81125 L .6511 .82588 L p .707 .577 .707 r
F P
0 g
s
.53801 .7947 m .54912 .82863 L .57556 .82755 L p .707 .577 .707 r
F P
0 g
s
.5627 .85379 m .56835 .87074 L .59807 .8652 L p .707 .577 .707 r
F P
0 g
s
.67565 .75082 m .68676 .78475 L .70218 .76972 L p .707 .577 .707 r
F P
0 g
s
.70218 .76972 m .69107 .7358 L .67565 .75082 L p .707 .577 .707 r
F P
0 g
s
.56835 .87074 m .5627 .85379 L .53662 .85471 L p .707 .577 .707 r
F P
0 g
s
.54912 .82863 m .53801 .7947 L .51763 .79108 L p .707 .577 .707 r
F P
0 g
s
.69274 .66841 m .69952 .72274 L .70619 .71207 L p .707 .577 .707 r
F P
0 g
s
.70619 .71207 m .6994 .65774 L .69274 .66841 L p .707 .577 .707 r
F P
0 g
s
.53662 .85471 m .54227 .87166 L .56835 .87074 L p .707 .577 .707 r
F P
0 g
s
.50003 .68668 m .50681 .74102 L .51966 .74885 L p .707 .577 .707 r
F P
0 g
s
.6743 .81125 m .67995 .82819 L .69587 .8131 L p .707 .577 .707 r
F P
0 g
s
.69587 .8131 m .69023 .79616 L .6743 .81125 L p .707 .577 .707 r
F P
0 g
s
.51763 .79108 m .52874 .82501 L .54912 .82863 L p .707 .577 .707 r
F P
0 g
s
.54227 .87166 m .53662 .85471 L .51674 .85093 L p .707 .577 .707 r
F P
0 g
s
.69107 .7358 m .70218 .76972 L .70868 .75576 L p .707 .577 .707 r
F P
0 g
s
.70868 .75576 m .69757 .72184 L .69107 .7358 L p .707 .577 .707 r
F P
0 g
s
.50681 .74102 m .50003 .68668 L .49678 .67695 L p .707 .577 .707 r
F P
0 g
s
.52874 .82501 m .51763 .79108 L .50531 .78312 L p .707 .577 .707 r
F P
0 g
s
.51674 .85093 m .52238 .86788 L .54227 .87166 L p .707 .577 .707 r
F P
0 g
s
.6994 .65774 m .70619 .71207 L .70294 .70234 L p .707 .577 .707 r
F P
0 g
s
.70294 .70234 m .69615 .64801 L .6994 .65774 L p .707 .577 .707 r
F P
0 g
s
.69023 .79616 m .69587 .8131 L .70296 .79904 L p .707 .577 .707 r
F P
0 g
s
.70296 .79904 m .69731 .78209 L .69023 .79616 L p .707 .577 .707 r
F P
0 g
s
.50531 .78312 m .51642 .81705 L .52874 .82501 L p .707 .577 .707 r
F P
0 g
s
.49678 .67695 m .50356 .73129 L .50681 .74102 L p .707 .577 .707 r
F P
0 g
s
.52238 .86788 m .51674 .85093 L .505 .84281 L p .707 .577 .707 r
F P
0 g
s
.69757 .72184 m .70868 .75576 L .70562 .74424 L p .707 .577 .707 r
F P
0 g
s
.70562 .74424 m .69451 .71031 L .69757 .72184 L p .707 .577 .707 r
F P
0 g
s
.51023 .72062 m .50344 .66628 L .51938 .65572 L p .707 .577 .707 r
F P
0 g
s
.50875 .75764 m .51986 .79157 L .51336 .80552 L p .707 .577 .707 r
F P
0 g
s
.51938 .65572 m .52616 .71005 L .51023 .72062 L p .707 .577 .707 r
F P
0 g
s
.52616 .71005 m .51938 .65572 L .54301 .64629 L p .707 .577 .707 r
F P
0 g
s
.51986 .79157 m .50875 .75764 L .52417 .74261 L p .707 .577 .707 r
F P
0 g
s
.52417 .74261 m .53528 .77654 L .51986 .79157 L p .707 .577 .707 r
F P
0 g
s
.51642 .81705 m .50531 .78312 L .50225 .7716 L p .707 .577 .707 r
F P
0 g
s
.50225 .7716 m .51336 .80552 L .51642 .81705 L p .707 .577 .707 r
F P
0 g
s
.51528 .83402 m .50963 .81708 L .52556 .80199 L p .707 .577 .707 r
F P
0 g
s
.52556 .80199 m .5312 .81893 L .51528 .83402 L p .707 .577 .707 r
F P
0 g
s
.52121 .8215 m .52121 .31961 L .47608 .3195 L p .707 .577 .707 r
F P
0 g
s
.54301 .64629 m .5498 .70062 L .52616 .71005 L p .707 .577 .707 r
F P
0 g
s
.5498 .70062 m .54301 .64629 L .57204 .63892 L p .707 .577 .707 r
F P
0 g
s
.53528 .77654 m .52417 .74261 L .547 .72799 L p .707 .577 .707 r
F P
0 g
s
.57204 .63892 m .57882 .69326 L .5498 .70062 L p .707 .577 .707 r
F P
0 g
s
.547 .72799 m .55811 .76191 L .53528 .77654 L p .707 .577 .707 r
F P
0 g
s
.55811 .76191 m .547 .72799 L .57502 .71519 L p .707 .577 .707 r
F P
0 g
s
.5312 .81893 m .52556 .80199 L .54876 .78735 L p .707 .577 .707 r
F P
0 g
s
.54876 .78735 m .55441 .8043 L .5312 .81893 L p .707 .577 .707 r
F P
0 g
s
.57502 .71519 m .58613 .74912 L .55811 .76191 L p .707 .577 .707 r
F P
0 g
s
.55441 .8043 m .54876 .78735 L .57697 .7746 L p .707 .577 .707 r
F P
0 g
s
.57697 .7746 m .58262 .79155 L .55441 .8043 L p .707 .577 .707 r
F P
0 g
s
.52121 .31961 m .52121 .8215 L .56426 .81787 L p .707 .577 .707 r
F P
0 g
s
.56426 .81787 m .56426 .31598 L .52121 .31961 L p .707 .577 .707 r
F P
0 g
s
.47608 .82139 m .47608 .3195 L .4333 .31565 L p .707 .577 .707 r
F P
0 g
s
.50356 .73129 m .49678 .67695 L .50344 .66628 L p .707 .577 .707 r
F P
0 g
s
.50344 .66628 m .51023 .72062 L .50356 .73129 L p .707 .577 .707 r
F P
0 g
s
.51336 .80552 m .50225 .7716 L .50875 .75764 L p .707 .577 .707 r
F P
0 g
s
.505 .84281 m .51064 .85975 L .52238 .86788 L p .707 .577 .707 r
F P
0 g
s
.5082 .84809 m .50255 .83114 L .50963 .81708 L p .707 .577 .707 r
F P
0 g
s
.50963 .81708 m .51528 .83402 L .5082 .84809 L p .707 .577 .707 r
F P
0 g
s
.47608 .3195 m .47608 .82139 L .52121 .8215 L p .707 .577 .707 r
F P
0 g
s
.57882 .69326 m .57204 .63892 L .60362 .63434 L p .707 .577 .707 r
F P
0 g
s
.60362 .63434 m .6104 .68867 L .57882 .69326 L p .707 .577 .707 r
F P
0 g
s
.60547 .70549 m .61658 .73941 L .58613 .74912 L p .707 .577 .707 r
F P
0 g
s
.58613 .74912 m .57502 .71519 L .60547 .70549 L p .707 .577 .707 r
F P
0 g
s
.60743 .76498 m .61308 .78193 L .58262 .79155 L p .707 .577 .707 r
F P
0 g
s
.58262 .79155 m .57697 .7746 L .60743 .76498 L p .707 .577 .707 r
F P
0 g
s
.56426 .31598 m .56426 .81787 L .60102 .81084 L p .707 .577 .707 r
F P
0 g
s
.60102 .81084 m .60102 .30896 L .56426 .31598 L p .707 .577 .707 r
F P
0 g
s
.4333 .81754 m .4333 .31565 L .39704 .30844 L p .707 .577 .707 r
F P
0 g
s
.4333 .31565 m .4333 .81754 L .47608 .82139 L p .707 .577 .707 r
F P
0 g
s
.69731 .78209 m .70296 .79904 L .70051 .78737 L p .707 .577 .707 r
F P
0 g
s
.70051 .78737 m .69486 .77043 L .69731 .78209 L p .707 .577 .707 r
F P
0 g
s
.69615 .64801 m .70294 .70234 L .69009 .69451 L p .707 .577 .707 r
F P
0 g
s
.69009 .69451 m .68331 .64017 L .69615 .64801 L p .707 .577 .707 r
F P
0 g
s
.51064 .85975 m .505 .84281 L .50255 .83114 L p .707 .577 .707 r
F P
0 g
s
.69451 .71031 m .70562 .74424 L .6933 .73628 L p .707 .577 .707 r
F P
0 g
s
.6933 .73628 m .68219 .70235 L .69451 .71031 L p .707 .577 .707 r
F P
0 g
s
.50255 .83114 m .5082 .84809 L .51064 .85975 L p .707 .577 .707 r
F P
0 g
s
.25541 .70168 m .25248 .64475 L .22125 .64529 L p .707 .577 .707 r
F P
0 g
s
.25248 .64475 m .25541 .70168 L .28716 .69956 L p .707 .577 .707 r
F P
0 g
s
.28716 .69956 m .28423 .64263 L .25248 .64475 L p .707 .577 .707 r
F P
0 g
s
.28423 .64263 m .28716 .69956 L .31633 .69609 L p .707 .577 .707 r
F P
0 g
s
.31633 .69609 m .3134 .63916 L .28423 .64263 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63466 .63299 m .64144 .68732 L .6104 .68867 L p .707 .577 .707 r
F P
0 g
s
.6104 .68867 m .60362 .63434 L .63466 .63299 L p .707 .577 .707 r
F P
0 g
s
.63537 .69981 m .64648 .73374 L .61658 .73941 L p .707 .577 .707 r
F P
0 g
s
.61658 .73941 m .60547 .70549 L .63537 .69981 L p .707 .577 .707 r
F P
0 g
s
.63716 .75944 m .64281 .77639 L .61308 .78193 L p .707 .577 .707 r
F P
0 g
s
.61308 .78193 m .60743 .76498 L .63716 .75944 L p .707 .577 .707 r
F P
0 g
s
.60102 .30896 m .60102 .81084 L .6279 .80112 L p .707 .577 .707 r
F P
0 g
s
.6279 .80112 m .6279 .29923 L .60102 .30896 L p .707 .577 .707 r
F P
0 g
s
.22418 .70222 m .22125 .64529 L .1936 .64421 L p .707 .577 .707 r
F P
0 g
s
.22125 .64529 m .22418 .70222 L .25541 .70168 L p .707 .577 .707 r
F P
0 g
s
.39704 .81033 m .39704 .30844 L .37086 .29857 L p .707 .577 .707 r
F P
0 g
s
.39704 .30844 m .39704 .81033 L .4333 .81754 L p .707 .577 .707 r
F P
0 g
s
.68331 .64017 m .69009 .69451 L .6689 .68933 L p .707 .577 .707 r
F P
0 g
s
.6689 .68933 m .66211 .635 L .68331 .64017 L p .707 .577 .707 r
F P
0 g
s
.69486 .77043 m .70051 .78737 L .68877 .77925 L p .707 .577 .707 r
F P
0 g
s
.68877 .77925 m .68312 .7623 L .69486 .77043 L p .707 .577 .707 r
F P
0 g
s
.3134 .63916 m .31633 .69609 L .34005 .69158 L p .707 .577 .707 r
F P
0 g
s
.34005 .69158 m .33712 .63465 L .3134 .63916 L p .707 .577 .707 r
F P
0 g
s
.1936 .64421 m .19654 .70113 L .22418 .70222 L p .707 .577 .707 r
F P
0 g
s
.22308 .71182 m .22798 .74997 L .25905 .74588 L p .707 .577 .707 r
F P
0 g
s
.25905 .74588 m .25415 .70773 L .22308 .71182 L p .707 .577 .707 r
F P
0 g
s
.25415 .70773 m .25905 .74588 L .29055 .74188 L p .707 .577 .707 r
F P
0 g
s
.29055 .74188 m .28565 .70374 L .25415 .70773 L p .707 .577 .707 r
F P
0 g
s
.28565 .70374 m .29055 .74188 L .3194 .73839 L p .707 .577 .707 r
F P
0 g
s
.3194 .73839 m .3145 .70024 L .28565 .70374 L p .707 .577 .707 r
F P
0 g
s
.19654 .70113 m .1936 .64421 L .17224 .6416 L p .707 .577 .707 r
F P
0 g
s
.19548 .71562 m .20038 .75376 L .22798 .74997 L p .707 .577 .707 r
F P
0 g
s
.22798 .74997 m .22308 .71182 L .19548 .71562 L p .707 .577 .707 r
F P
0 g
s
.68219 .70235 m .6933 .73628 L .67292 .73266 L p .707 .577 .707 r
F P
0 g
s
.67292 .73266 m .66181 .69874 L .68219 .70235 L p .707 .577 .707 r
F P
0 g
s
.17224 .6416 m .17517 .69853 L .19654 .70113 L p .707 .577 .707 r
F P
0 g
s
.66211 .635 m .6689 .68933 L .64144 .68732 L p .707 .577 .707 r
F P
0 g
s
.64144 .68732 m .63466 .63299 L .66211 .635 L p .707 .577 .707 r
F P
0 g
s
.22136 .77102 m .22384 .79009 L .25478 .78589 L p .707 .577 .707 r
F P
0 g
s
.25478 .78589 m .2523 .76682 L .22136 .77102 L p .707 .577 .707 r
F P
0 g
s
.2523 .76682 m .25478 .78589 L .28634 .78187 L p .707 .577 .707 r
F P
0 g
s
.3145 .70024 m .3194 .73839 L .34277 .73572 L p .707 .577 .707 r
F P
0 g
s
.28634 .78187 m .28386 .7628 L .2523 .76682 L p .707 .577 .707 r
F P
0 g
s
.34277 .73572 m .33787 .69758 L .3145 .70024 L p .707 .577 .707 r
F P
0 g
s
.33712 .63465 m .34005 .69158 L .35602 .68649 L p .707 .577 .707 r
F P
0 g
s
.35602 .68649 m .35308 .62957 L .33712 .63465 L p .707 .577 .707 r
F P
0 g
s
.28386 .7628 m .28634 .78187 L .31542 .77842 L p .707 .577 .707 r
F P
0 g
s
.31542 .77842 m .31294 .75936 L .28386 .7628 L p .707 .577 .707 r
F P
0 g
s
.17405 .71874 m .17895 .75689 L .20038 .75376 L p .707 .577 .707 r
F P
0 g
s
.20038 .75376 m .19548 .71562 L .17405 .71874 L p .707 .577 .707 r
F P
0 g
s
.68312 .7623 m .68877 .77925 L .66889 .77547 L p .707 .577 .707 r
F P
0 g
s
.66889 .77547 m .66324 .75852 L .68312 .7623 L p .707 .577 .707 r
F P
0 g
s
.64648 .73374 m .63537 .69981 L .66181 .69874 L p .707 .577 .707 r
F P
0 g
s
.64281 .77639 m .63716 .75944 L .66324 .75852 L p .707 .577 .707 r
F P
0 g
s
.6279 .29923 m .6279 .80112 L .64225 .78964 L p .707 .577 .707 r
F P
0 g
s
.64225 .78964 m .64225 .28775 L .6279 .29923 L p .707 .577 .707 r
F P
0 g
s
.19406 .775 m .19654 .79406 L .22384 .79009 L p .707 .577 .707 r
F P
0 g
s
.22384 .79009 m .22136 .77102 L .19406 .775 L p .707 .577 .707 r
F P
0 g
s
.37086 .80046 m .37086 .29857 L .35732 .28702 L p .707 .577 .707 r
F P
0 g
s
.37086 .29857 m .37086 .80046 L .39704 .81033 L p .707 .577 .707 r
F P
0 g
s
.17517 .69853 m .17224 .6416 L .15925 .63774 L p .707 .577 .707 r
F P
0 g
s
.66181 .69874 m .67292 .73266 L .64648 .73374 L p .707 .577 .707 r
F P
0 g
s
.31294 .75936 m .31542 .77842 L .33919 .77589 L p .707 .577 .707 r
F P
0 g
s
.33919 .77589 m .33671 .75683 L .31294 .75936 L p .707 .577 .707 r
F P
0 g
s
.15925 .63774 m .16219 .69467 L .17517 .69853 L p .707 .577 .707 r
F P
0 g
s
.33787 .69758 m .34277 .73572 L .35837 .73416 L p .707 .577 .707 r
F P
0 g
s
.35837 .73416 m .35622 .71742 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35308 .62957 m .35602 .68649 L .36265 .68132 L p .707 .577 .707 r
F P
0 g
s
.36265 .68132 m .35972 .62439 L .35308 .62957 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .35837 .73416 L .36469 .73384 L p .707 .577 .707 r
F P
0 g
s
.36469 .73384 m .35978 .69569 L .35347 .69601 L p .707 .577 .707 r
F P
0 g
s
.35972 .62439 m .36265 .68132 L .35931 .67657 L p .707 .577 .707 r
F P
0 g
s
.35931 .67657 m .35684 .62847 L p .35972 .62439 L .707 .577 .707 r
F P
0 g
s
.35684 .62847 m .35638 .61964 L .35681 .62025 L p .707 .577 .707 r
F P
0 g
s
.35681 .62025 m .35972 .62439 L p .35684 .62847 L .707 .577 .707 r
F P
0 g
s
.35282 .75546 m .3553 .77452 L .35625 .77451 L p .707 .577 .707 r
F P
0 g
s
.35625 .77451 m .36219 .77445 L p .35636 .76261 L .707 .577 .707 r
F P
0 g
s
.35636 .76261 m .35282 .75546 L .35625 .77451 L .707 .577 .707 r
F
.36219 .77445 m .35972 .75538 L .35282 .75546 L p F P
0 g
s
.35978 .69569 m .36469 .73384 L .36109 .7348 L p .707 .577 .707 r
F P
0 g
s
.36109 .7348 m .35684 .70176 L p .35978 .69569 L .707 .577 .707 r
F P
0 g
s
.35684 .70176 m .35619 .69666 L .35681 .69649 L p .707 .577 .707 r
F P
0 g
s
.35681 .69649 m .35978 .69569 L p .35684 .70176 L .707 .577 .707 r
F P
0 g
s
.35638 .61964 m .35931 .67657 L .34633 .6727 L p .707 .577 .707 r
F P
0 g
s
.35972 .75538 m .36219 .77445 L .35919 .77568 L p .707 .577 .707 r
F P
0 g
s
.35919 .77568 m .35671 .75661 L .35972 .75538 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .33787 .69758 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35622 .71742 m .35347 .69601 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35619 .69666 m .36109 .7348 L .34793 .73695 L p .707 .577 .707 r
F P
0 g
s
.33671 .75683 m .33919 .77589 L .3553 .77452 L p .707 .577 .707 r
F P
0 g
s
.3553 .77452 m .35282 .75546 L .33671 .75683 L p .707 .577 .707 r
F P
0 g
s
.35671 .75661 m .35919 .77568 L .34658 .77809 L p .707 .577 .707 r
F P
0 g
s
.35732 .28702 m .35732 .78891 L .37086 .80046 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35742 .78621 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35742 .78621 m .35738 .78712 L p .35739 .78201 L .706 .577 .707 r
F P
0 g
s
.35739 .78201 m .35773 .30251 L .35742 .78621 L .706 .577 .707 r
F
.35734 .77274 m .35745 .63396 L .35738 .78712 L F
.35745 .63396 m .35775 .27491 L .3575 .62842 L F
.35745 .63396 m .3575 .62842 L .35738 .78712 L F
.35775 .27491 m .35775 .30326 L p .35773 .30251 L F P
0 g
s
.35775 .30326 m .35775 .7768 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35738 .78712 m .35732 .78891 L p .35734 .77274 L .706 .577 .707 r
F P
0 g
s
.35732 .28702 m .35775 .27491 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .78891 m .35732 .49035 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .49035 m .35732 .28702 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.17308 .77835 m .17556 .79742 L .19654 .79406 L p .707 .577 .707 r
F P
0 g
s
.19654 .79406 m .19406 .775 L .17308 .77835 L p .707 .577 .707 r
F P
0 g
s
.16089 .72089 m .1658 .75904 L .17895 .75689 L p .707 .577 .707 r
F P
0 g
s
.17895 .75689 m .17405 .71874 L .16089 .72089 L p .707 .577 .707 r
F P
0 g
s
.66324 .75852 m .66889 .77547 L .64281 .77639 L p .707 .577 .707 r
F P
0 g
s
.16219 .69467 m .15925 .63774 L .15592 .63298 L p .707 .577 .707 r
F P
0 g
s
.16047 .78076 m .16295 .79983 L .17556 .79742 L p .707 .577 .707 r
F P
0 g
s
.17556 .79742 m .17308 .77835 L .16047 .78076 L p .707 .577 .707 r
F P
0 g
s
.64225 .28775 m .64225 .78964 L .64261 .77931 L p .706 .577 .707 r
F P
0 g
s
.64266 .76212 m .64225 .28775 L .64261 .77931 L .706 .577 .707 r
F
.64268 .77753 m .64268 .27564 L .64225 .28775 L p F P
0 g
s
.64261 .77931 m .64268 .77753 L p .64266 .76212 L .706 .577 .707 r
F P
0 g
s
.64268 .27564 m .64268 .77753 L .62914 .76597 L p .707 .577 .707 r
F P
0 g
s
.64068 .63472 m .64316 .58966 L p .64028 .5692 L .707 .577 .707 r
F P
0 g
s
.64316 .58966 m .64362 .58138 L .64319 .57982 L p .707 .577 .707 r
F P
0 g
s
.64319 .57982 m .64028 .5692 L p .64316 .58966 L .707 .577 .707 r
F P
0 g
s
.15592 .63298 m .15885 .68991 L .16219 .69467 L p .707 .577 .707 r
F P
0 g
s
.15729 .72185 m .1622 .76 L .1658 .75904 L p .707 .577 .707 r
F P
0 g
s
.1658 .75904 m .16089 .72089 L .15729 .72185 L p .707 .577 .707 r
F P
0 g
s
.15885 .68991 m .15592 .63298 L .16255 .62781 L p .707 .577 .707 r
F P
0 g
s
.15746 .78199 m .15994 .80106 L .16295 .79983 L p .707 .577 .707 r
F P
0 g
s
.16295 .79983 m .16047 .78076 L .15746 .78199 L p .707 .577 .707 r
F P
0 g
s
.16255 .62781 m .16548 .68474 L .15885 .68991 L p .707 .577 .707 r
F P
0 g
s
.16361 .72154 m .16851 .75968 L .1622 .76 L p .707 .577 .707 r
F P
0 g
s
.1622 .76 m .15729 .72185 L .16361 .72154 L p .707 .577 .707 r
F P
0 g
s
.34633 .6727 m .3434 .61577 L .35638 .61964 L p .707 .577 .707 r
F P
0 g
s
.62914 .76597 m .62914 .26409 L .64268 .27564 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35775 .27491 L .3721 .26343 L p .707 .577 .707 r
F P
0 g
s
.16548 .68474 m .16255 .62781 L .17851 .62272 L p .707 .577 .707 r
F P
0 g
s
.16436 .78192 m .16683 .80098 L .15994 .80106 L p .707 .577 .707 r
F P
0 g
s
.15994 .80106 m .15746 .78199 L .16436 .78192 L p .707 .577 .707 r
F P
0 g
s
.17851 .62272 m .18145 .67965 L .16548 .68474 L p .707 .577 .707 r
F P
0 g
s
.34793 .73695 m .34303 .69881 L .35619 .69666 L p .707 .577 .707 r
F P
0 g
s
.3434 .61577 m .34633 .6727 L .32496 .6701 L p .707 .577 .707 r
F P
0 g
s
.32496 .6701 m .32203 .61317 L .3434 .61577 L p .707 .577 .707 r
F P
0 g
s
.17921 .71997 m .18412 .75812 L .16851 .75968 L p .707 .577 .707 r
F P
0 g
s
.16851 .75968 m .16361 .72154 L .17921 .71997 L p .707 .577 .707 r
F P
0 g
s
.34658 .77809 m .3441 .75902 L .35671 .75661 L p .707 .577 .707 r
F P
0 g
s
.18145 .67965 m .17851 .62272 L .20224 .61822 L p .707 .577 .707 r
F P
0 g
s
.62914 .26409 m .62914 .76597 L .60296 .75611 L p .707 .577 .707 r
F P
0 g
s
.60296 .75611 m .60296 .25422 L .62914 .26409 L p .707 .577 .707 r
F P
0 g
s
.3721 .76532 m .3721 .26343 L .39897 .2537 L p .707 .577 .707 r
F P
0 g
s
.3721 .26343 m .3721 .76532 L .35775 .7768 L p .707 .577 .707 r
F P
0 g
s
.20224 .61822 m .20517 .67515 L .18145 .67965 L p .707 .577 .707 r
F P
0 g
s
.18047 .78055 m .18295 .79961 L .16683 .80098 L p .707 .577 .707 r
F P
0 g
s
.16683 .80098 m .16436 .78192 L .18047 .78055 L p .707 .577 .707 r
F P
0 g
s
.34303 .69881 m .34793 .73695 L .32651 .74008 L p .707 .577 .707 r
F P
0 g
s
.32651 .74008 m .3216 .70193 L .34303 .69881 L p .707 .577 .707 r
F P
0 g
s
.32203 .61317 m .32496 .6701 L .29732 .66902 L p .707 .577 .707 r
F P
0 g
s
.29732 .66902 m .29438 .61209 L .32203 .61317 L p .707 .577 .707 r
F P
0 g
s
.20258 .71731 m .20749 .75546 L .18412 .75812 L p .707 .577 .707 r
F P
0 g
s
.18412 .75812 m .17921 .71997 L .20258 .71731 L p .707 .577 .707 r
F P
0 g
s
.20517 .67515 m .20224 .61822 L .2314 .61474 L p .707 .577 .707 r
F P
0 g
s
.3441 .75902 m .34658 .77809 L .3256 .78144 L p .707 .577 .707 r
F P
0 g
s
.3256 .78144 m .32312 .76238 L .3441 .75902 L p .707 .577 .707 r
F P
0 g
s
.29438 .61209 m .29732 .66902 L .26609 .66956 L p .707 .577 .707 r
F P
0 g
s
.26609 .66956 m .26316 .61263 L .29438 .61209 L p .707 .577 .707 r
F P
0 g
s
.2314 .61474 m .23434 .67167 L .20517 .67515 L p .707 .577 .707 r
F P
0 g
s
.73391 .66771 m .73684 .61437 L .70561 .61038 L p .707 .577 .707 r
F P
0 g
s
.73684 .61437 m .73391 .66771 L .76566 .66794 L p .707 .577 .707 r
F P
0 g
s
.76566 .66794 m .76859 .6146 L .73684 .61437 L p .707 .577 .707 r
F P
0 g
s
.23434 .67167 m .2314 .61474 L .26316 .61263 L p .707 .577 .707 r
F P
0 g
s
.76859 .6146 m .76566 .66794 L .79483 .66439 L p .707 .577 .707 r
F P
0 g
s
.79483 .66439 m .79776 .61105 L .76859 .6146 L p .707 .577 .707 r
F P
0 g
s
.3216 .70193 m .32651 .74008 L .29891 .74387 L p .707 .577 .707 r
F P
0 g
s
.70268 .66372 m .70561 .61038 L .67797 .60303 L p .707 .577 .707 r
F P
0 g
s
.70561 .61038 m .70268 .66372 L .73391 .66771 L p .707 .577 .707 r
F P
0 g
s
.29891 .74387 m .294 .70573 L .3216 .70193 L p .707 .577 .707 r
F P
0 g
s
.26316 .61263 m .26609 .66956 L .23434 .67167 L p .707 .577 .707 r
F P
0 g
s
.20424 .77802 m .20671 .79708 L .18295 .79961 L p .707 .577 .707 r
F P
0 g
s
.18295 .79961 m .18047 .78055 L .20424 .77802 L p .707 .577 .707 r
F P
0 g
s
.60296 .25422 m .60296 .75611 L .5667 .7489 L p .707 .577 .707 r
F P
0 g
s
.5667 .7489 m .5667 .24701 L .60296 .25422 L p .707 .577 .707 r
F P
0 g
s
.39897 .2537 m .39897 .75559 L .3721 .76532 L p .707 .577 .707 r
F P
0 g
s
.39897 .75559 m .39897 .2537 L .43573 .24668 L p .707 .577 .707 r
F P
0 g
s
.23143 .71381 m .23633 .75196 L .20749 .75546 L p .707 .577 .707 r
F P
0 g
s
.20749 .75546 m .20258 .71731 L .23143 .71381 L p .707 .577 .707 r
F P
0 g
s
.79776 .61105 m .79483 .66439 L .81855 .65742 L p .707 .577 .707 r
F P
0 g
s
.81855 .65742 m .82148 .60408 L .79776 .61105 L p .707 .577 .707 r
F P
0 g
s
.67503 .65637 m .67797 .60303 L .6566 .59304 L p .707 .577 .707 r
F P
0 g
s
.67797 .60303 m .67503 .65637 L .70268 .66372 L p .707 .577 .707 r
F P
0 g
s
.294 .70573 m .29891 .74387 L .26784 .74797 L p .707 .577 .707 r
F P
0 g
s
.32312 .76238 m .3256 .78144 L .2983 .78542 L p .707 .577 .707 r
F P
0 g
s
.2983 .78542 m .29582 .76635 L .32312 .76238 L p .707 .577 .707 r
F P
0 g
s
.26784 .74797 m .26293 .70982 L .294 .70573 L p .707 .577 .707 r
F P
0 g
s
.26293 .70982 m .26784 .74797 L .23633 .75196 L p .707 .577 .707 r
F P
0 g
s
.23633 .75196 m .23143 .71381 L .26293 .70982 L p .707 .577 .707 r
F P
0 g
s
.23332 .77457 m .2358 .79364 L .20671 .79708 L p .707 .577 .707 r
F P
0 g
s
.20671 .79708 m .20424 .77802 L .23332 .77457 L p .707 .577 .707 r
F P
0 g
s
.73216 .74108 m .73707 .70874 L .70599 .70198 L p .707 .577 .707 r
F P
0 g
s
.73707 .70874 m .73216 .74108 L .76366 .74259 L p .707 .577 .707 r
F P
0 g
s
.76366 .74259 m .76857 .71025 L .73707 .70874 L p .707 .577 .707 r
F P
0 g
s
.5667 .24701 m .5667 .7489 L .52391 .74505 L p .707 .577 .707 r
F P
0 g
s
.52391 .74505 m .52391 .24316 L .5667 .24701 L p .707 .577 .707 r
F P
0 g
s
.43573 .74857 m .43573 .24668 L .47879 .24304 L p .707 .577 .707 r
F P
0 g
s
.43573 .24668 m .43573 .74857 L .39897 .75559 L p .707 .577 .707 r
F P
0 g
s
.70109 .73432 m .70599 .70198 L .67839 .69063 L p .707 .577 .707 r
F P
0 g
s
.70599 .70198 m .70109 .73432 L .73216 .74108 L p .707 .577 .707 r
F P
0 g
s
.82148 .60408 m .81855 .65742 L .83451 .6477 L p .707 .577 .707 r
F P
0 g
s
.83451 .6477 m .83745 .59436 L .82148 .60408 L p .707 .577 .707 r
F P
0 g
s
.76857 .71025 m .76366 .74259 L .79251 .7387 L p .707 .577 .707 r
F P
0 g
s
.79251 .7387 m .79742 .70636 L .76857 .71025 L p .707 .577 .707 r
F P
0 g
s
.29582 .76635 m .2983 .78542 L .26736 .78962 L p .707 .577 .707 r
F P
0 g
s
.26736 .78962 m .26488 .77055 L .29582 .76635 L p .707 .577 .707 r
F P
0 g
s
.26488 .77055 m .26736 .78962 L .2358 .79364 L p .707 .577 .707 r
F P
0 g
s
.2358 .79364 m .23332 .77457 L .26488 .77055 L p .707 .577 .707 r
F P
0 g
s
.65367 .64638 m .6566 .59304 L .64362 .58138 L p .707 .577 .707 r
F P
0 g
s
.6566 .59304 m .65367 .64638 L .67503 .65637 L p .707 .577 .707 r
F P
0 g
s
.67349 .72297 m .67839 .69063 L .65697 .6758 L p .707 .577 .707 r
F P
0 g
s
.67839 .69063 m .67349 .72297 L .70109 .73432 L p .707 .577 .707 r
F P
0 g
s
.52391 .24316 m .52391 .74505 L .47879 .74493 L p .707 .577 .707 r
F P
0 g
s
.47879 .74493 m .47879 .24304 L .52391 .24316 L p .707 .577 .707 r
F P
0 g
s
.47879 .24304 m .47879 .74493 L .43573 .74857 L p .707 .577 .707 r
F P
0 g
s
.73264 .78541 m .73512 .76935 L .70418 .76222 L p .707 .577 .707 r
F P
0 g
s
.73512 .76935 m .73264 .78541 L .7642 .78723 L p .707 .577 .707 r
F P
0 g
s
.7642 .78723 m .76668 .77117 L .73512 .76935 L p .707 .577 .707 r
F P
0 g
s
.79742 .70636 m .79251 .7387 L .81588 .72979 L p .707 .577 .707 r
F P
0 g
s
.81588 .72979 m .82079 .69745 L .79742 .70636 L p .707 .577 .707 r
F P
0 g
s
.7017 .77828 m .70418 .76222 L .67688 .75047 L p .707 .577 .707 r
F P
0 g
s
.70418 .76222 m .7017 .77828 L .73264 .78541 L p .707 .577 .707 r
F P
0 g
s
.76668 .77117 m .7642 .78723 L .79328 .78356 L p .707 .577 .707 r
F P
0 g
s
.79328 .78356 m .79576 .7675 L .76668 .77117 L p .707 .577 .707 r
F P
0 g
s
.83745 .59436 m .83451 .6477 L .84115 .63618 L p .707 .577 .707 r
F P
0 g
s
.84115 .63618 m .84408 .58284 L .83745 .59436 L p .707 .577 .707 r
F P
0 g
s
.67688 .75047 m .6744 .76653 L .7017 .77828 L p .707 .577 .707 r
F P
0 g
s
.64362 .58138 m .64068 .63472 L .65367 .64638 L p .707 .577 .707 r
F P
0 g
s
.6744 .76653 m .67688 .75047 L .6559 .73525 L p .707 .577 .707 r
F P
0 g
s
.65206 .70814 m .65697 .6758 L .64381 .65894 L p .707 .577 .707 r
F P
0 g
s
.65697 .6758 m .65206 .70814 L .67349 .72297 L p .707 .577 .707 r
F P
0 g
s
.79576 .7675 m .79328 .78356 L .81705 .77475 L p .707 .577 .707 r
F P
0 g
s
.81705 .77475 m .81953 .75869 L .79576 .7675 L p .707 .577 .707 r
F P
0 g
s
.82079 .69745 m .81588 .72979 L .83149 .71673 L p .707 .577 .707 r
F P
0 g
s
.83149 .71673 m .83639 .68439 L .82079 .69745 L p .707 .577 .707 r
F P
0 g
s
.6559 .73525 m .65342 .75131 L .6744 .76653 L p .707 .577 .707 r
F P
0 g
s
.65342 .75131 m .6559 .73525 L .64329 .71805 L p .707 .577 .707 r
F P
0 g
s
.64381 .65894 m .63891 .69128 L .65206 .70814 L p .707 .577 .707 r
F P
0 g
s
.81953 .75869 m .81705 .77475 L .83316 .76166 L p .707 .577 .707 r
F P
0 g
s
.83316 .76166 m .83564 .7456 L .81953 .75869 L p .707 .577 .707 r
F P
0 g
s
.63891 .69128 m .64381 .65894 L .64021 .6417 L p .707 .577 .707 r
F P
0 g
s
.64028 .5692 m .63735 .62254 L .64068 .63472 L p .707 .577 .707 r
F P
0 g
s
.84408 .58284 m .84115 .63618 L .83781 .624 L p .707 .577 .707 r
F P
0 g
s
.83781 .624 m .84074 .57066 L .84408 .58284 L p .707 .577 .707 r
F P
0 g
s
.64329 .71805 m .64081 .73411 L .65342 .75131 L p .707 .577 .707 r
F P
0 g
s
.83639 .68439 m .83149 .71673 L .8378 .7008 L p .707 .577 .707 r
F P
0 g
s
.8378 .7008 m .8427 .66846 L .83639 .68439 L p .707 .577 .707 r
F P
0 g
s
.63735 .62254 m .64028 .5692 L .64692 .55768 L p .707 .577 .707 r
F P
0 g
s
.64081 .73411 m .64329 .71805 L .64028 .70056 L p .707 .577 .707 r
F P
0 g
s
.64021 .6417 m .63531 .67404 L .63891 .69128 L p .707 .577 .707 r
F P
0 g
s
.83564 .7456 m .83316 .76166 L .84006 .74559 L p .707 .577 .707 r
F P
0 g
s
.84006 .74559 m .84254 .72953 L .83564 .7456 L p .707 .577 .707 r
F P
0 g
s
.63531 .67404 m .64021 .6417 L .64653 .62577 L p .707 .577 .707 r
F P
0 g
s
.64028 .70056 m .6378 .71662 L .64081 .73411 L p .707 .577 .707 r
F P
0 g
s
.64692 .55768 m .64398 .61103 L .63735 .62254 L p .707 .577 .707 r
F P
0 g
s
.84074 .57066 m .83781 .624 L .82483 .61234 L p .707 .577 .707 r
F P
0 g
s
.82483 .61234 m .82776 .559 L .84074 .57066 L p .707 .577 .707 r
F P
0 g
s
.8427 .66846 m .8378 .7008 L .8342 .68356 L p .707 .577 .707 r
F P
0 g
s
.8342 .68356 m .83911 .65122 L .8427 .66846 L p .707 .577 .707 r
F P
0 g
s
.64398 .61103 m .64692 .55768 L .66288 .54796 L p .707 .577 .707 r
F P
0 g
s
.6378 .71662 m .64028 .70056 L .64717 .68449 L p .707 .577 .707 r
F P
0 g
s
.38959 .61494 m .39638 .55903 L .36534 .55398 L p .707 .577 .707 r
F P
0 g
s
.39638 .55903 m .38959 .61494 L .42117 .61788 L p .707 .577 .707 r
F P
0 g
s
.42117 .61788 m .42796 .56196 L .39638 .55903 L p .707 .577 .707 r
F P
0 g
s
.64653 .62577 m .64162 .65811 L .63531 .67404 L p .707 .577 .707 r
F P
0 g
s
.84254 .72953 m .84006 .74559 L .83705 .7281 L p .707 .577 .707 r
F P
0 g
s
.83705 .7281 m .83953 .71204 L .84254 .72953 L p .707 .577 .707 r
F P
0 g
s
.42796 .56196 m .42117 .61788 L .4502 .6184 L p .707 .577 .707 r
F P
0 g
s
.4502 .6184 m .45699 .56249 L .42796 .56196 L p .707 .577 .707 r
F P
0 g
s
.35856 .60989 m .36534 .55398 L .33788 .5473 L p .707 .577 .707 r
F P
0 g
s
.36534 .55398 m .35856 .60989 L .38959 .61494 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64162 .65811 m .64653 .62577 L .66213 .61271 L p .707 .577 .707 r
F P
0 g
s
.64717 .68449 m .6447 .70055 L .6378 .71662 L p .707 .577 .707 r
F P
0 g
s
.82776 .559 m .82483 .61234 L .80346 .60235 L p .707 .577 .707 r
F P
0 g
s
.80346 .60235 m .8064 .54901 L .82776 .559 L p .707 .577 .707 r
F P
0 g
s
.83911 .65122 m .8342 .68356 L .82105 .6667 L p .707 .577 .707 r
F P
0 g
s
.82105 .6667 m .82595 .63436 L .83911 .65122 L p .707 .577 .707 r
F P
0 g
s
.66288 .54796 m .65995 .60131 L .64398 .61103 L p .707 .577 .707 r
F P
0 g
s
.45699 .56249 m .4502 .6184 L .47384 .61647 L p .707 .577 .707 r
F P
0 g
s
.47384 .61647 m .48062 .56056 L .45699 .56249 L p .707 .577 .707 r
F P
0 g
s
.33788 .5473 m .3311 .60321 L .35856 .60989 L p .707 .577 .707 r
F P
0 g
s
.65995 .60131 m .66288 .54796 L .6866 .54099 L p .707 .577 .707 r
F P
0 g
s
.38342 .66659 m .39453 .63014 L .36462 .62024 L p .707 .577 .707 r
F P
0 g
s
.39453 .63014 m .38342 .66659 L .41387 .67522 L p .707 .577 .707 r
F P
0 g
s
.41387 .67522 m .42498 .63877 L .39453 .63014 L p .707 .577 .707 r
F P
0 g
s
.3311 .60321 m .33788 .5473 L .31669 .53965 L p .707 .577 .707 r
F P
0 g
s
.42498 .63877 m .41387 .67522 L .44189 .68174 L p .707 .577 .707 r
F P
0 g
s
.44189 .68174 m .45299 .6453 L .42498 .63877 L p .707 .577 .707 r
F P
0 g
s
.36462 .62024 m .35351 .65669 L .38342 .66659 L p .707 .577 .707 r
F P
0 g
s
.35351 .65669 m .36462 .62024 L .33819 .61004 L p .707 .577 .707 r
F P
0 g
s
.6447 .70055 m .64717 .68449 L .66329 .6714 L p .707 .577 .707 r
F P
0 g
s
.66213 .61271 m .65723 .64505 L .64162 .65811 L p .707 .577 .707 r
F P
0 g
s
.83953 .71204 m .83705 .7281 L .82444 .7109 L p .707 .577 .707 r
F P
0 g
s
.82444 .7109 m .82692 .69484 L .83953 .71204 L p .707 .577 .707 r
F P
0 g
s
.33819 .61004 m .32708 .64649 L .35351 .65669 L p .707 .577 .707 r
F P
0 g
s
.31669 .53965 m .30991 .59556 L .3311 .60321 L p .707 .577 .707 r
F P
0 g
s
.65723 .64505 m .66213 .61271 L .6855 .6038 L p .707 .577 .707 r
F P
0 g
s
.8064 .54901 m .80346 .60235 L .77581 .595 L p .707 .577 .707 r
F P
0 g
s
.77581 .595 m .77875 .54166 L .8064 .54901 L p .707 .577 .707 r
F P
0 g
s
.38692 .70774 m .39256 .68955 L .36284 .67944 L p .707 .577 .707 r
F P
0 g
s
.39256 .68955 m .38692 .70774 L .41738 .71663 L p .707 .577 .707 r
F P
0 g
s
.41738 .71663 m .42302 .69844 L .39256 .68955 L p .707 .577 .707 r
F P
0 g
s
.66329 .6714 m .66081 .68746 L .6447 .70055 L p .707 .577 .707 r
F P
0 g
s
.45299 .6453 m .44189 .68174 L .46472 .68551 L p .707 .577 .707 r
F P
0 g
s
.46472 .68551 m .47583 .64907 L .45299 .6453 L p .707 .577 .707 r
F P
0 g
s
.82595 .63436 m .82105 .6667 L .79962 .65187 L p .707 .577 .707 r
F P
0 g
s
.79962 .65187 m .80452 .61953 L .82595 .63436 L p .707 .577 .707 r
F P
0 g
s
.48062 .56056 m .47384 .61647 L .48977 .61227 L p .707 .577 .707 r
F P
0 g
s
.48977 .61227 m .49655 .55635 L .48062 .56056 L p .707 .577 .707 r
F P
0 g
s
.68367 .59433 m .6866 .54099 L .71577 .53744 L p .707 .577 .707 r
F P
0 g
s
.6866 .54099 m .68367 .59433 L .65995 .60131 L p .707 .577 .707 r
F P
0 g
s
.36284 .67944 m .35719 .69764 L .38692 .70774 L p .707 .577 .707 r
F P
0 g
s
.32708 .64649 m .33819 .61004 L .31781 .60054 L p .707 .577 .707 r
F P
0 g
s
.42302 .69844 m .41738 .71663 L .44559 .72343 L p .707 .577 .707 r
F P
0 g
s
.44559 .72343 m .45124 .70524 L .42302 .69844 L p .707 .577 .707 r
F P
0 g
s
.35719 .69764 m .36284 .67944 L .33676 .66911 L p .707 .577 .707 r
F P
0 g
s
.30991 .59556 m .31669 .53965 L .30384 .53178 L p .707 .577 .707 r
F P
0 g
s
.33676 .66911 m .33111 .6873 L .35719 .69764 L p .707 .577 .707 r
F P
0 g
s
.31781 .60054 m .3067 .63699 L .32708 .64649 L p .707 .577 .707 r
F P
0 g
s
.77875 .54166 m .77581 .595 L .74459 .59102 L p .707 .577 .707 r
F P
0 g
s
.74459 .59102 m .74752 .53768 L .77875 .54166 L p .707 .577 .707 r
F P
0 g
s
.66081 .68746 m .66329 .6714 L .68705 .66259 L p .707 .577 .707 r
F P
0 g
s
.71284 .59079 m .71577 .53744 L .74752 .53768 L p .707 .577 .707 r
F P
0 g
s
.71577 .53744 m .71284 .59079 L .68367 .59433 L p .707 .577 .707 r
F P
0 g
s
.6806 .63614 m .6855 .6038 L .71435 .5999 L p .707 .577 .707 r
F P
0 g
s
.6855 .6038 m .6806 .63614 L .65723 .64505 L p .707 .577 .707 r
F P
0 g
s
.82692 .69484 m .82444 .7109 L .80346 .69568 L p .707 .577 .707 r
F P
0 g
s
.80346 .69568 m .80594 .67962 L .82692 .69484 L p .707 .577 .707 r
F P
0 g
s
.45124 .70524 m .44559 .72343 L .46879 .72747 L p .707 .577 .707 r
F P
0 g
s
.46879 .72747 m .47444 .70928 L .45124 .70524 L p .707 .577 .707 r
F P
0 g
s
.74752 .53768 m .74459 .59102 L .71284 .59079 L p .707 .577 .707 r
F P
0 g
s
.30384 .53178 m .29706 .58769 L .30991 .59556 L p .707 .577 .707 r
F P
0 g
s
.80452 .61953 m .79962 .65187 L .77202 .64052 L p .707 .577 .707 r
F P
0 g
s
.77202 .64052 m .77692 .60817 L .80452 .61953 L p .707 .577 .707 r
F P
0 g
s
.33111 .6873 m .33676 .66911 L .31687 .65956 L p .707 .577 .707 r
F P
0 g
s
.47583 .64907 m .46472 .68551 L .48014 .68616 L p .707 .577 .707 r
F P
0 g
s
.48014 .68616 m .49125 .64972 L .47583 .64907 L p .707 .577 .707 r
F P
0 g
s
.31687 .65956 m .31123 .67775 L .33111 .6873 L p .707 .577 .707 r
F P
0 g
s
.68705 .66259 m .68458 .67865 L .66081 .68746 L p .707 .577 .707 r
F P
0 g
s
.3067 .63699 m .31781 .60054 L .30549 .59267 L p .707 .577 .707 r
F P
0 g
s
.49655 .55635 m .48977 .61227 L .49644 .60621 L p .707 .577 .707 r
F P
0 g
s
.49644 .60621 m .50322 .5503 L .49655 .55635 L p .707 .577 .707 r
F P
0 g
s
.70945 .63225 m .71435 .5999 L .74585 .60141 L p .707 .577 .707 r
F P
0 g
s
.71435 .5999 m .70945 .63225 L .6806 .63614 L p .707 .577 .707 r
F P
0 g
s
.30549 .59267 m .29438 .62912 L .3067 .63699 L p .707 .577 .707 r
F P
0 g
s
.77692 .60817 m .77202 .64052 L .74095 .63376 L p .707 .577 .707 r
F P
0 g
s
.74095 .63376 m .74585 .60141 L .77692 .60817 L p .707 .577 .707 r
F P
0 g
s
.68458 .67865 m .68705 .66259 L .71614 .65892 L p .707 .577 .707 r
F P
0 g
s
.29706 .58769 m .30384 .53178 L .30059 .52445 L p .707 .577 .707 r
F P
0 g
s
.74585 .60141 m .74095 .63376 L .70945 .63225 L p .707 .577 .707 r
F P
0 g
s
.80594 .67962 m .80346 .69568 L .77616 .68393 L p .707 .577 .707 r
F P
0 g
s
.77616 .68393 m .77864 .66787 L .80594 .67962 L p .707 .577 .707 r
F P
0 g
s
.47444 .70928 m .46879 .72747 L .48472 .72837 L p .707 .577 .707 r
F P
0 g
s
.48472 .72837 m .49036 .71018 L .47444 .70928 L p .707 .577 .707 r
F P
0 g
s
.71614 .65892 m .71366 .67498 L .68458 .67865 L p .707 .577 .707 r
F P
0 g
s
.31123 .67775 m .31687 .65956 L .30513 .65173 L p .707 .577 .707 r
F P
0 g
s
.71366 .67498 m .71614 .65892 L .7477 .66074 L p .707 .577 .707 r
F P
0 g
s
.30513 .65173 m .29948 .66992 L .31123 .67775 L p .707 .577 .707 r
F P
0 g
s
.30059 .52445 m .29381 .58037 L .29706 .58769 L p .707 .577 .707 r
F P
0 g
s
.77864 .66787 m .77616 .68393 L .74522 .6768 L p .707 .577 .707 r
F P
0 g
s
.74522 .6768 m .7477 .66074 L .77864 .66787 L p .707 .577 .707 r
F P
0 g
s
.7477 .66074 m .74522 .6768 L .71366 .67498 L p .707 .577 .707 r
F P
0 g
s
.49125 .64972 m .48014 .68616 L .48664 .68363 L p .707 .577 .707 r
F P
0 g
s
.48664 .68363 m .49775 .64718 L .49125 .64972 L p .707 .577 .707 r
F P
0 g
s
.29438 .62912 m .30549 .59267 L .30242 .5872 L p .707 .577 .707 r
F P
0 g
s
.30242 .5872 m .29132 .62365 L .29438 .62912 L p .707 .577 .707 r
F P
0 g
s
.50322 .5503 m .49644 .60621 L .49319 .59889 L p .707 .577 .707 r
F P
0 g
s
.49319 .59889 m .49997 .54297 L .50322 .5503 L p .707 .577 .707 r
F P
0 g
s
.29381 .58037 m .30059 .52445 L .30726 .5184 L p .707 .577 .707 r
F P
0 g
s
.49036 .71018 m .48472 .72837 L .4918 .72603 L p .707 .577 .707 r
F P
0 g
s
.4918 .72603 m .49745 .70784 L .49036 .71018 L p .707 .577 .707 r
F P
0 g
s
.29948 .66992 m .30513 .65173 L .30268 .64638 L p .707 .577 .707 r
F P
0 g
s
.30268 .64638 m .29704 .66457 L .29948 .66992 L p .707 .577 .707 r
F P
0 g
s
.30726 .5184 m .30048 .57431 L .29381 .58037 L p .707 .577 .707 r
F P
0 g
s
.49775 .64718 m .48664 .68363 L .48358 .67816 L p .707 .577 .707 r
F P
0 g
s
.48358 .67816 m .49469 .64171 L .49775 .64718 L p .707 .577 .707 r
F P
0 g
s
.29132 .62365 m .30242 .5872 L .30892 .58467 L p .707 .577 .707 r
F P
0 g
s
.49997 .54297 m .49319 .59889 L .48034 .59101 L p .707 .577 .707 r
F P
0 g
s
.48034 .59101 m .48712 .5351 L .49997 .54297 L p .707 .577 .707 r
F P
0 g
s
.30892 .58467 m .29781 .62112 L .29132 .62365 L p .707 .577 .707 r
F P
0 g
s
.30048 .57431 m .30726 .5184 L .32319 .51419 L p .707 .577 .707 r
F P
0 g
s
.49745 .70784 m .4918 .72603 L .48935 .72068 L p .707 .577 .707 r
F P
0 g
s
.48935 .72068 m .495 .70249 L .49745 .70784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29704 .66457 m .30268 .64638 L .30977 .64404 L p .707 .577 .707 r
F P
0 g
s
.30977 .64404 m .30412 .66223 L .29704 .66457 L p .707 .577 .707 r
F P
0 g
s
.32319 .51419 m .31641 .57011 L .30048 .57431 L p .707 .577 .707 r
F P
0 g
s
.49469 .64171 m .48358 .67816 L .47125 .67029 L p .707 .577 .707 r
F P
0 g
s
.47125 .67029 m .48236 .63384 L .49469 .64171 L p .707 .577 .707 r
F P
0 g
s
.29781 .62112 m .30892 .58467 L .32434 .58532 L p .707 .577 .707 r
F P
0 g
s
.48712 .5351 m .48034 .59101 L .45915 .58337 L p .707 .577 .707 r
F P
0 g
s
.45915 .58337 m .46593 .52745 L .48712 .5351 L p .707 .577 .707 r
F P
0 g
s
.32434 .58532 m .31323 .62177 L .29781 .62112 L p .707 .577 .707 r
F P
0 g
s
.31641 .57011 m .32319 .51419 L .34683 .51226 L p .707 .577 .707 r
F P
0 g
s
.495 .70249 m .48935 .72068 L .47761 .71285 L p .707 .577 .707 r
F P
0 g
s
.47761 .71285 m .48326 .69466 L .495 .70249 L p .707 .577 .707 r
F P
0 g
s
.30412 .66223 m .30977 .64404 L .32569 .64493 L p .707 .577 .707 r
F P
0 g
s
.34683 .51226 m .34004 .56818 L .31641 .57011 L p .707 .577 .707 r
F P
0 g
s
.32569 .64493 m .32005 .66312 L .30412 .66223 L p .707 .577 .707 r
F P
0 g
s
.46593 .52745 m .45915 .58337 L .43169 .57669 L p .707 .577 .707 r
F P
0 g
s
.43169 .57669 m .43847 .52077 L .46593 .52745 L p .707 .577 .707 r
F P
0 g
s
.48236 .63384 m .47125 .67029 L .45088 .66079 L p .707 .577 .707 r
F P
0 g
s
.45088 .66079 m .46199 .62434 L .48236 .63384 L p .707 .577 .707 r
F P
0 g
s
.31323 .62177 m .32434 .58532 L .34718 .58909 L p .707 .577 .707 r
F P
0 g
s
.34004 .56818 m .34683 .51226 L .37586 .51279 L p .707 .577 .707 r
F P
0 g
s
.34718 .58909 m .33607 .62554 L .31323 .62177 L p .707 .577 .707 r
F P
0 g
s
.43847 .52077 m .43169 .57669 L .40065 .57164 L p .707 .577 .707 r
F P
0 g
s
.40065 .57164 m .40744 .51572 L .43847 .52077 L p .707 .577 .707 r
F P
0 g
s
.48326 .69466 m .47761 .71285 L .45773 .7033 L p .707 .577 .707 r
F P
0 g
s
.45773 .7033 m .46338 .6851 L .48326 .69466 L p .707 .577 .707 r
F P
0 g
s
.37586 .51279 m .36907 .5687 L .34004 .56818 L p .707 .577 .707 r
F P
0 g
s
.36907 .5687 m .37586 .51279 L .40744 .51572 L p .707 .577 .707 r
F P
0 g
s
.40744 .51572 m .40065 .57164 L .36907 .5687 L p .707 .577 .707 r
F P
0 g
s
.32005 .66312 m .32569 .64493 L .3489 .64898 L p .707 .577 .707 r
F P
0 g
s
.46199 .62434 m .45088 .66079 L .42444 .65059 L p .707 .577 .707 r
F P
0 g
s
.42444 .65059 m .43555 .61414 L .46199 .62434 L p .707 .577 .707 r
F P
0 g
s
.3489 .64898 m .34325 .66717 L .32005 .66312 L p .707 .577 .707 r
F P
0 g
s
.33607 .62554 m .34718 .58909 L .37519 .59561 L p .707 .577 .707 r
F P
0 g
s
.37519 .59561 m .36408 .63206 L .33607 .62554 L p .707 .577 .707 r
F P
0 g
s
.43555 .61414 m .42444 .65059 L .39453 .64069 L p .707 .577 .707 r
F P
0 g
s
.39453 .64069 m .40564 .60424 L .43555 .61414 L p .707 .577 .707 r
F P
0 g
s
.46338 .6851 m .45773 .7033 L .43165 .69296 L p .707 .577 .707 r
F P
0 g
s
.43165 .69296 m .4373 .67477 L .46338 .6851 L p .707 .577 .707 r
F P
0 g
s
.36408 .63206 m .37519 .59561 L .40564 .60424 L p .707 .577 .707 r
F P
0 g
s
.34325 .66717 m .3489 .64898 L .37711 .65578 L p .707 .577 .707 r
F P
0 g
s
.40564 .60424 m .39453 .64069 L .36408 .63206 L p .707 .577 .707 r
F P
0 g
s
.37711 .65578 m .37146 .67397 L .34325 .66717 L p .707 .577 .707 r
F P
0 g
s
.4373 .67477 m .43165 .69296 L .40192 .68286 L p .707 .577 .707 r
F P
0 g
s
.40192 .68286 m .40757 .66466 L .4373 .67477 L p .707 .577 .707 r
F P
0 g
s
.37146 .67397 m .37711 .65578 L .40757 .66466 L p .707 .577 .707 r
F P
0 g
s
.40757 .66466 m .40192 .68286 L .37146 .67397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6@00PWoo001iOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001iOol007Aoo`D0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00D007Aoo`00L7oo1000
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001OOol@0002FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001JOol5
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001GOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001EOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00004Goo3`00AWoo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH01000@Woo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF00001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF1000?Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000Eoo`8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0000=oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@003Ioo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002000cOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80035oo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00<7oo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP80031o
o`00Dgoo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0002moo`00Dgoo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF
001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0015YF00<005YFFUH00eYF
00<005YFFUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YF
FUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000EJ
EP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001COol01000FUIJEUYF2@001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00L005YFFUIJ
EP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`@000AJEP03001JEUYF00D0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0015YF00<005YFFUH015YF00<0
05YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00P001UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000AOol60006
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0`001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH0
0`00FUH000030006Ool8000?Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP80009JEPP000AJEP04001JEUYFFUH9000:Ool30005FUH01000
FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH000020007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF008000EJEP<000QJ
EP03001JEUYF00EJEP03001JEUYF009JEPD000Moo`<000=JEP04001JEUYFFUH2000]Ool005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYF001JEP0200000eYF001JEP02FUH20002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH80003FUH200000eYF001JEP02FUH2000]Ool003iooaH00003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009J
EP03001JEUYF00AJEP03001JEUYF00<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF008000=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH20003FUH2000]Ool003Qoo`H000=JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000/000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000IJEP03001JEP00009JEP8002eoo`00=7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`001UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YF
FUH01000;Goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004
FUH01000FUIJEUYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000UYF00@005YFFUIJEP<002eoo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH010000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003
FUH3000]Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001EYF00<0
05YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF009JEPH0009JEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0002FUH01000FUIJEUYF0P001eYF00<005YF
FUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH0000002io
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF0`001eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF008000=JEP06001JEP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF10001UYF00<005YFFUH015YF00<005YF00000P00;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000090005FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000=JEP8000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH01000FUH00000;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPH000QJEP03001J
EUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YF
FUH002moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF00000`001EYF00<005YF
FUH01UYF0`001eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH00`00Oomo
o`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000UJEP03001J
EUYF00@0009JEP03001JEUYF00AJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001J
EUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF0`00
1EYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUH005YF00001UYF00@005YFFUIJEP@0009JEQ00009JEP03001JEUYF00EJEP03001JEP0000<0
009JEP03001JEUYF009JEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF008000=JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@0017oo0`0015YF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEUYF1P001eYF00<005YFFUH01EYF1@001eYF00<005YFFUH00UYF0`0015YF
0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=JEP00
FUH00eYF1@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`002goo00<005YFFUH0
0UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH?0003FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00FUIJEP07FUH00`00FUIJEP04
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01`00FUH005YF001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000Yoo`06001JEUYF001JEP00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP03FUH?0009FUH00`00FUIJEP02FUH30006FUH00`00FUH0000200000eYF001JEP040008FUH00`00
FUIJEP04FUH50006FUH3000015YF001JEP0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YF001JEP00009JEP04001JEP000005FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP07FUH00`00FUIJEP020009Ool01@00FUH005YF0000;Goo000]Ool00`00FUH00003FUH00`00FUH0
00030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0`000eYF00<005YF00000P0015YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF
00800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0003FUH200000eYF001JEP03FUH70007Ool70006FUH00`00FUIJEP03FUH20007Ool01@00FUH005YF
0000;Goo000]Ool00`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP05FUH40004FUH300000eYF001JEP07FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000UYF00@005YFFUH000=JEP80009JEP03001JEUYF008000ioo`@0009J
EP03001JEUYF00EJEP8000Ioo`800003FUH007oo02aoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0008FUH0
1000FUH000000eYF1P001eYF00<005YFFUH015YF10000UYF00<005YF00002EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH01000FUH000001EYF00@005YF
0000019oo`@000MJEP<000Eoo`03001JEP0002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<000IJEP03
001JEUYF009JEPP00003FUH0000000EJEP03001JEUYF00EJEPL000YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP000eYF0P0000=JEP00000015YF00@005YF0000
01Ioo`8000AJEP05001JEUYFFUH00003Ool3000^Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP05FUH50003FUH300000eYF001JEP07FUH00`00FUIJEP03000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP03FUH20002FUH01000
FUIJEP0067oo0`0000=JEP00FUH00eYF0`0000=JEP000000;Woo000^Ool200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005Ool200000eYF
001JEP08FUH70003FUH30006FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YF00000P000UYF00<007oo
Ool06Goo0P001UYF00@005YF000002ioo`00<7oo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001goo2P001eYF00<005YFFUH01EYF100000=JEP0000000`000UYF00<005YF
FUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF
00<000IJEP04001JEUYFFUH4000MOol00`00FUIJEP03FUH4000^Ool003AooaT000Uoo`T0009JEP06
001JEUYFFUH005YF0P001EYF00<005YFFUH01eYF00<005YF00000`000UYF0`001EYF00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH0
00IJEP03001JEUYF00AJEP@001Uoo`<000AJEP800003FUH007oo02eoo`00CGoo2`000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP<00003FUH005YF00QJEP03001JEUYF00AJEPL000=JEP05001J
EUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020000
0eYF00000006FUH00`00FUIJEP05FUH00`00FUIJEP04000@Ool50003FUH200001EYF001JEUYF0000
;goo0014Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH010001eYF00<005YFFUH01UYF00<005YFFUH01@0015YF0P001UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF40000eYF00<005YFFUH00eYF0`000UYF00<007ooOol0;Goo000lOol:0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF
10000UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF00001UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000eYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000eYF00<0
07ooOol0;7oo000eOol90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH0
15YF00D005YF000005YF008000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000EJEP04001JEUYF0008FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<007ooOol0;7oo000]Ool90003FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P001UYF0`001eYF00<005YF
FUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo02ao
o`00;7oo1@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00=JEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00<000IJEP<000IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEP00001oo`0200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50002FUH00`00FUH0
0008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF008000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP80
00=oo`800003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00@005YFFUIJEP<00003FUH005YF
00MJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`03001JEP0002eoo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH90003FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001Woo00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUIJEP80009JEP8000=JEP800003Ool0000000800004FUH007ooOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0000027oo00<005YF0000;Goo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70005Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEPD000Aoo`80
0004FUH000000005Ool70004FUH00`00FUIJEP02FUH5000;Ool00`00Oomoo`0/Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP04FUHI0006FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03001oogoo009oo`04001JEUYF0002FUH00`00
Oomoo`0:Ool9000?Ool2000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF009JEPT001Aoo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH90005FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH80008FUH00`00FUIJEP04FUH01000FUIJEUYF100015YF0P0000=oo`00
FUH00UYF00@005YFFUH002Aoo`8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF2@007Goo00D005YFFUIJEP0000MJEP03001JEUYF00D0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00<000EJEP03001JEUYF00AJEP05001JEUYFFUH00002
Ool00`00FUIJEP04FUH20003FUH01@00FUIJEUYF00008Goo0`00;goo000^Ool20004FUH01000FUIJ
EUYF1`008goo10000eYF00<005YFFUH015YF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF100000=JEP00FUH01EYF00D005YFFUIJEP0000=oo`8000AJEP04
001JEP000002FUH01000FUIJEP007goo0P0000=JEP000000;goo000^Ool20002FUH6000MOolA0003
FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH30005FUH01000FUIJEUYF1`000UYF00<005YFFUH00UYF0`0000=JEP00Ool07Woo00D0
05YFFUIJEP00031oo`00;Woo100077oo1`000eYF1`000UYF00D005YFFUIJEP0000=JEP03001JEP00
0080009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00@00003FUH005YF009JEP03001JEUYF00=JEP@000MJEP<001aoo`<000=J
EP03001oogoo02ioo`00BWoo10000UYF00<005YF00001@000eYF00<005YFFUH00eYF00D005YFFUIJ
EP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP03001JEP0000QJEP03001J
EP0000<001Ioo`80009JEP04001JEUYF000aOol004=oo`L000AJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH70009Ool60004FUH00`00FUH0000bOol003]oo`P0
00AJEPL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEP00FUH00007FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0015YF00<005YFFUH00eYF0P00<goo000eOol60003FUH90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH030000UYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00=7oo000`Ool?0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EUYF00AJEP<0009JEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
;7oo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`001Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH0
0`00FUIJEP06FUH40003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF
00<007oo00000P001Woo4000?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH9000DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP80009oo`<005Eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH00UYF2@007Woo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0005FUH01000FUIJ
EUYF0P000goo00@005YFFUH005Eoo`00;Goo00<005YF000015YF00@005YFFUIJEPL002Qoo`<000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000MJEP<000Eoo`04001JEUYF001EOol002eoo`/0035oo`8000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP<000MJEP8000Ioo`80009JEP03001oogoo05=oo`00Jgoo0P000eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF0P001Woo0P0000AJEP00FUH005Ioo`00KGoo0P0000=JEP00FUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00000P001goo00<005YFFUH00UYF0P00EWoo001_Ool40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH50006FUH30009Ool00`00FUIJEP03FUH0
0`00Oomoo`1EOol007=oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00D00003FUH0000000<000=JEP8000Yoo`<000EJEP03001oogoo05Eoo`00NGoo20001UYF
00<005YFFUH02UYF00<005YFFUH015YF20001UYF20002goo00D005YFFUIJEP0000=JEP03001oogoo
05Ioo`00PGoo6`001UYF00<005YFFUH015YF1@0037oo0P0015YF00@005YFFUH005Uoo`00Sgoo00<0
05YF00000UYF1@000eYF00<005YFFUH015YF00<005YFFUH01`0037oo00<005YFFUH01EYF0P00FWoo
002>Ool01000FUIJEP000UYF00<007ooOol00Woo3@004Goo0`001eYF00<007ooOol0FGoo002>Ool0
1000FUIJEUYF0P008Goo0P000UYF00<005YFFUH00eYF0P00G7oo002>Ool01@00FUIJEUYF000087oo
0P001EYF00<005YFFUH00P00GWoo002?Ool00`00FUH0000NOol30007FUH3001POol008moo`03001J
EP0001]oo`<00003FUH005YF00MJEP03001oogoo061oo`00Sgoo0`0067oo0`0015YF00<005YFFUH0
15YF0P00Hgoo002@Ool01000FUH0000047oo1P0025YF00@005YFFUIJEP8006Eoo`00T7oo00@005YF
001JEP<000Eoo`P000AJEP03001JEUYF00MJEP04001JEP00001WOol0095oo`03001JEP0000=JEPD0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP<006Uoo`00TGoo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00K7oo002BOol30004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUH00002001_Ool009Aoo`<0009JEP03001JEUYF00EJEP03001JEUYF009JEPD0
079oo`00Ugoo3`00Mgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59934 .75469 m .59256 .70035 L .56152 .7017 L p .707 .577 .707 r
F P
0 g
s
.59256 .70035 m .59934 .75469 L .63092 .7501 L p .707 .577 .707 r
F P
0 g
s
.63092 .7501 m .62414 .69577 L .59256 .70035 L p .707 .577 .707 r
F P
0 g
s
.62414 .69577 m .63092 .7501 L .65995 .74274 L p .707 .577 .707 r
F P
0 g
s
.65995 .74274 m .65317 .6884 L .62414 .69577 L p .707 .577 .707 r
F P
0 g
s
.56831 .75604 m .56152 .7017 L .53407 .69969 L p .707 .577 .707 r
F P
0 g
s
.56152 .7017 m .56831 .75604 L .59934 .75469 L p .707 .577 .707 r
F P
0 g
s
.65317 .6884 m .65995 .74274 L .68359 .73331 L p .707 .577 .707 r
F P
0 g
s
.68359 .73331 m .67681 .67897 L .65317 .6884 L p .707 .577 .707 r
F P
0 g
s
.54085 .75403 m .53407 .69969 L .51288 .69452 L p .707 .577 .707 r
F P
0 g
s
.53407 .69969 m .54085 .75403 L .56831 .75604 L p .707 .577 .707 r
F P
0 g
s
.63591 .81217 m .6248 .77824 L .59435 .78795 L p .707 .577 .707 r
F P
0 g
s
.6248 .77824 m .63591 .81217 L .66393 .79937 L p .707 .577 .707 r
F P
0 g
s
.66393 .79937 m .65282 .76545 L .6248 .77824 L p .707 .577 .707 r
F P
0 g
s
.60546 .82187 m .59435 .78795 L .56445 .79362 L p .707 .577 .707 r
F P
0 g
s
.59435 .78795 m .60546 .82187 L .63591 .81217 L p .707 .577 .707 r
F P
0 g
s
.67681 .67897 m .68359 .73331 L .69952 .72274 L p .707 .577 .707 r
F P
0 g
s
.69952 .72274 m .69274 .66841 L .67681 .67897 L p .707 .577 .707 r
F P
0 g
s
.65282 .76545 m .66393 .79937 L .68676 .78475 L p .707 .577 .707 r
F P
0 g
s
.68676 .78475 m .67565 .75082 L .65282 .76545 L p .707 .577 .707 r
F P
0 g
s
.57556 .82755 m .56445 .79362 L .53801 .7947 L p .707 .577 .707 r
F P
0 g
s
.56445 .79362 m .57556 .82755 L .60546 .82187 L p .707 .577 .707 r
F P
0 g
s
.62853 .85558 m .62289 .83863 L .59243 .84825 L p .707 .577 .707 r
F P
0 g
s
.62289 .83863 m .62853 .85558 L .65675 .84283 L p .707 .577 .707 r
F P
0 g
s
.65675 .84283 m .6511 .82588 L .62289 .83863 L p .707 .577 .707 r
F P
0 g
s
.51288 .69452 m .51966 .74885 L .54085 .75403 L p .707 .577 .707 r
F P
0 g
s
.59807 .8652 m .59243 .84825 L .5627 .85379 L p .707 .577 .707 r
F P
0 g
s
.59243 .84825 m .59807 .8652 L .62853 .85558 L p .707 .577 .707 r
F P
0 g
s
.51966 .74885 m .51288 .69452 L .50003 .68668 L p .707 .577 .707 r
F P
0 g
s
.6511 .82588 m .65675 .84283 L .67995 .82819 L p .707 .577 .707 r
F P
0 g
s
.67995 .82819 m .6743 .81125 L .6511 .82588 L p .707 .577 .707 r
F P
0 g
s
.53801 .7947 m .54912 .82863 L .57556 .82755 L p .707 .577 .707 r
F P
0 g
s
.5627 .85379 m .56835 .87074 L .59807 .8652 L p .707 .577 .707 r
F P
0 g
s
.67565 .75082 m .68676 .78475 L .70218 .76972 L p .707 .577 .707 r
F P
0 g
s
.70218 .76972 m .69107 .7358 L .67565 .75082 L p .707 .577 .707 r
F P
0 g
s
.56835 .87074 m .5627 .85379 L .53662 .85471 L p .707 .577 .707 r
F P
0 g
s
.54912 .82863 m .53801 .7947 L .51763 .79108 L p .707 .577 .707 r
F P
0 g
s
.69274 .66841 m .69952 .72274 L .70619 .71207 L p .707 .577 .707 r
F P
0 g
s
.70619 .71207 m .6994 .65774 L .69274 .66841 L p .707 .577 .707 r
F P
0 g
s
.53662 .85471 m .54227 .87166 L .56835 .87074 L p .707 .577 .707 r
F P
0 g
s
.50003 .68668 m .50681 .74102 L .51966 .74885 L p .707 .577 .707 r
F P
0 g
s
.6743 .81125 m .67995 .82819 L .69587 .8131 L p .707 .577 .707 r
F P
0 g
s
.69587 .8131 m .69023 .79616 L .6743 .81125 L p .707 .577 .707 r
F P
0 g
s
.51763 .79108 m .52874 .82501 L .54912 .82863 L p .707 .577 .707 r
F P
0 g
s
.54227 .87166 m .53662 .85471 L .51674 .85093 L p .707 .577 .707 r
F P
0 g
s
.69107 .7358 m .70218 .76972 L .70868 .75576 L p .707 .577 .707 r
F P
0 g
s
.70868 .75576 m .69757 .72184 L .69107 .7358 L p .707 .577 .707 r
F P
0 g
s
.50681 .74102 m .50003 .68668 L .49678 .67695 L p .707 .577 .707 r
F P
0 g
s
.52874 .82501 m .51763 .79108 L .50531 .78312 L p .707 .577 .707 r
F P
0 g
s
.51674 .85093 m .52238 .86788 L .54227 .87166 L p .707 .577 .707 r
F P
0 g
s
.6994 .65774 m .70619 .71207 L .70294 .70234 L p .707 .577 .707 r
F P
0 g
s
.70294 .70234 m .69615 .64801 L .6994 .65774 L p .707 .577 .707 r
F P
0 g
s
.69023 .79616 m .69587 .8131 L .70296 .79904 L p .707 .577 .707 r
F P
0 g
s
.70296 .79904 m .69731 .78209 L .69023 .79616 L p .707 .577 .707 r
F P
0 g
s
.50531 .78312 m .51642 .81705 L .52874 .82501 L p .707 .577 .707 r
F P
0 g
s
.49678 .67695 m .50356 .73129 L .50681 .74102 L p .707 .577 .707 r
F P
0 g
s
.52238 .86788 m .51674 .85093 L .505 .84281 L p .707 .577 .707 r
F P
0 g
s
.69757 .72184 m .70868 .75576 L .70562 .74424 L p .707 .577 .707 r
F P
0 g
s
.70562 .74424 m .69451 .71031 L .69757 .72184 L p .707 .577 .707 r
F P
0 g
s
.51023 .72062 m .50344 .66628 L .51938 .65572 L p .707 .577 .707 r
F P
0 g
s
.50875 .75764 m .51986 .79157 L .51336 .80552 L p .707 .577 .707 r
F P
0 g
s
.51938 .65572 m .52616 .71005 L .51023 .72062 L p .707 .577 .707 r
F P
0 g
s
.52616 .71005 m .51938 .65572 L .54301 .64629 L p .707 .577 .707 r
F P
0 g
s
.51986 .79157 m .50875 .75764 L .52417 .74261 L p .707 .577 .707 r
F P
0 g
s
.52417 .74261 m .53528 .77654 L .51986 .79157 L p .707 .577 .707 r
F P
0 g
s
.51642 .81705 m .50531 .78312 L .50225 .7716 L p .707 .577 .707 r
F P
0 g
s
.50225 .7716 m .51336 .80552 L .51642 .81705 L p .707 .577 .707 r
F P
0 g
s
.51528 .83402 m .50963 .81708 L .52556 .80199 L p .707 .577 .707 r
F P
0 g
s
.52556 .80199 m .5312 .81893 L .51528 .83402 L p .707 .577 .707 r
F P
0 g
s
.52121 .8215 m .52121 .31961 L .47608 .3195 L p .707 .577 .707 r
F P
0 g
s
.54301 .64629 m .5498 .70062 L .52616 .71005 L p .707 .577 .707 r
F P
0 g
s
.5498 .70062 m .54301 .64629 L .57204 .63892 L p .707 .577 .707 r
F P
0 g
s
.53528 .77654 m .52417 .74261 L .547 .72799 L p .707 .577 .707 r
F P
0 g
s
.57204 .63892 m .57882 .69326 L .5498 .70062 L p .707 .577 .707 r
F P
0 g
s
.547 .72799 m .55811 .76191 L .53528 .77654 L p .707 .577 .707 r
F P
0 g
s
.55811 .76191 m .547 .72799 L .57502 .71519 L p .707 .577 .707 r
F P
0 g
s
.5312 .81893 m .52556 .80199 L .54876 .78735 L p .707 .577 .707 r
F P
0 g
s
.54876 .78735 m .55441 .8043 L .5312 .81893 L p .707 .577 .707 r
F P
0 g
s
.57502 .71519 m .58613 .74912 L .55811 .76191 L p .707 .577 .707 r
F P
0 g
s
.55441 .8043 m .54876 .78735 L .57697 .7746 L p .707 .577 .707 r
F P
0 g
s
.57697 .7746 m .58262 .79155 L .55441 .8043 L p .707 .577 .707 r
F P
0 g
s
.52121 .31961 m .52121 .8215 L .56426 .81787 L p .707 .577 .707 r
F P
0 g
s
.56426 .81787 m .56426 .31598 L .52121 .31961 L p .707 .577 .707 r
F P
0 g
s
.47608 .82139 m .47608 .3195 L .4333 .31565 L p .707 .577 .707 r
F P
0 g
s
.50356 .73129 m .49678 .67695 L .50344 .66628 L p .707 .577 .707 r
F P
0 g
s
.50344 .66628 m .51023 .72062 L .50356 .73129 L p .707 .577 .707 r
F P
0 g
s
.51336 .80552 m .50225 .7716 L .50875 .75764 L p .707 .577 .707 r
F P
0 g
s
.505 .84281 m .51064 .85975 L .52238 .86788 L p .707 .577 .707 r
F P
0 g
s
.5082 .84809 m .50255 .83114 L .50963 .81708 L p .707 .577 .707 r
F P
0 g
s
.50963 .81708 m .51528 .83402 L .5082 .84809 L p .707 .577 .707 r
F P
0 g
s
.47608 .3195 m .47608 .82139 L .52121 .8215 L p .707 .577 .707 r
F P
0 g
s
.57882 .69326 m .57204 .63892 L .60362 .63434 L p .707 .577 .707 r
F P
0 g
s
.60362 .63434 m .6104 .68867 L .57882 .69326 L p .707 .577 .707 r
F P
0 g
s
.60547 .70549 m .61658 .73941 L .58613 .74912 L p .707 .577 .707 r
F P
0 g
s
.58613 .74912 m .57502 .71519 L .60547 .70549 L p .707 .577 .707 r
F P
0 g
s
.60743 .76498 m .61308 .78193 L .58262 .79155 L p .707 .577 .707 r
F P
0 g
s
.58262 .79155 m .57697 .7746 L .60743 .76498 L p .707 .577 .707 r
F P
0 g
s
.56426 .31598 m .56426 .81787 L .60102 .81084 L p .707 .577 .707 r
F P
0 g
s
.60102 .81084 m .60102 .30896 L .56426 .31598 L p .707 .577 .707 r
F P
0 g
s
.4333 .81754 m .4333 .31565 L .39704 .30844 L p .707 .577 .707 r
F P
0 g
s
.4333 .31565 m .4333 .81754 L .47608 .82139 L p .707 .577 .707 r
F P
0 g
s
.69731 .78209 m .70296 .79904 L .70051 .78737 L p .707 .577 .707 r
F P
0 g
s
.70051 .78737 m .69486 .77043 L .69731 .78209 L p .707 .577 .707 r
F P
0 g
s
.69615 .64801 m .70294 .70234 L .69009 .69451 L p .707 .577 .707 r
F P
0 g
s
.69009 .69451 m .68331 .64017 L .69615 .64801 L p .707 .577 .707 r
F P
0 g
s
.51064 .85975 m .505 .84281 L .50255 .83114 L p .707 .577 .707 r
F P
0 g
s
.69451 .71031 m .70562 .74424 L .6933 .73628 L p .707 .577 .707 r
F P
0 g
s
.6933 .73628 m .68219 .70235 L .69451 .71031 L p .707 .577 .707 r
F P
0 g
s
.50255 .83114 m .5082 .84809 L .51064 .85975 L p .707 .577 .707 r
F P
0 g
s
.25541 .70168 m .25248 .64475 L .22125 .64529 L p .707 .577 .707 r
F P
0 g
s
.25248 .64475 m .25541 .70168 L .28716 .69956 L p .707 .577 .707 r
F P
0 g
s
.28716 .69956 m .28423 .64263 L .25248 .64475 L p .707 .577 .707 r
F P
0 g
s
.28423 .64263 m .28716 .69956 L .31633 .69609 L p .707 .577 .707 r
F P
0 g
s
.31633 .69609 m .3134 .63916 L .28423 .64263 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63466 .63299 m .64144 .68732 L .6104 .68867 L p .707 .577 .707 r
F P
0 g
s
.6104 .68867 m .60362 .63434 L .63466 .63299 L p .707 .577 .707 r
F P
0 g
s
.63537 .69981 m .64648 .73374 L .61658 .73941 L p .707 .577 .707 r
F P
0 g
s
.61658 .73941 m .60547 .70549 L .63537 .69981 L p .707 .577 .707 r
F P
0 g
s
.63716 .75944 m .64281 .77639 L .61308 .78193 L p .707 .577 .707 r
F P
0 g
s
.61308 .78193 m .60743 .76498 L .63716 .75944 L p .707 .577 .707 r
F P
0 g
s
.60102 .30896 m .60102 .81084 L .6279 .80112 L p .707 .577 .707 r
F P
0 g
s
.6279 .80112 m .6279 .29923 L .60102 .30896 L p .707 .577 .707 r
F P
0 g
s
.22418 .70222 m .22125 .64529 L .1936 .64421 L p .707 .577 .707 r
F P
0 g
s
.22125 .64529 m .22418 .70222 L .25541 .70168 L p .707 .577 .707 r
F P
0 g
s
.39704 .81033 m .39704 .30844 L .37086 .29857 L p .707 .577 .707 r
F P
0 g
s
.39704 .30844 m .39704 .81033 L .4333 .81754 L p .707 .577 .707 r
F P
0 g
s
.68331 .64017 m .69009 .69451 L .6689 .68933 L p .707 .577 .707 r
F P
0 g
s
.6689 .68933 m .66211 .635 L .68331 .64017 L p .707 .577 .707 r
F P
0 g
s
.69486 .77043 m .70051 .78737 L .68877 .77925 L p .707 .577 .707 r
F P
0 g
s
.68877 .77925 m .68312 .7623 L .69486 .77043 L p .707 .577 .707 r
F P
0 g
s
.3134 .63916 m .31633 .69609 L .34005 .69158 L p .707 .577 .707 r
F P
0 g
s
.34005 .69158 m .33712 .63465 L .3134 .63916 L p .707 .577 .707 r
F P
0 g
s
.1936 .64421 m .19654 .70113 L .22418 .70222 L p .707 .577 .707 r
F P
0 g
s
.22308 .71182 m .22798 .74997 L .25905 .74588 L p .707 .577 .707 r
F P
0 g
s
.25905 .74588 m .25415 .70773 L .22308 .71182 L p .707 .577 .707 r
F P
0 g
s
.25415 .70773 m .25905 .74588 L .29055 .74188 L p .707 .577 .707 r
F P
0 g
s
.29055 .74188 m .28565 .70374 L .25415 .70773 L p .707 .577 .707 r
F P
0 g
s
.28565 .70374 m .29055 .74188 L .3194 .73839 L p .707 .577 .707 r
F P
0 g
s
.3194 .73839 m .3145 .70024 L .28565 .70374 L p .707 .577 .707 r
F P
0 g
s
.19654 .70113 m .1936 .64421 L .17224 .6416 L p .707 .577 .707 r
F P
0 g
s
.19548 .71562 m .20038 .75376 L .22798 .74997 L p .707 .577 .707 r
F P
0 g
s
.22798 .74997 m .22308 .71182 L .19548 .71562 L p .707 .577 .707 r
F P
0 g
s
.68219 .70235 m .6933 .73628 L .67292 .73266 L p .707 .577 .707 r
F P
0 g
s
.67292 .73266 m .66181 .69874 L .68219 .70235 L p .707 .577 .707 r
F P
0 g
s
.17224 .6416 m .17517 .69853 L .19654 .70113 L p .707 .577 .707 r
F P
0 g
s
.66211 .635 m .6689 .68933 L .64144 .68732 L p .707 .577 .707 r
F P
0 g
s
.64144 .68732 m .63466 .63299 L .66211 .635 L p .707 .577 .707 r
F P
0 g
s
.22136 .77102 m .22384 .79009 L .25478 .78589 L p .707 .577 .707 r
F P
0 g
s
.25478 .78589 m .2523 .76682 L .22136 .77102 L p .707 .577 .707 r
F P
0 g
s
.2523 .76682 m .25478 .78589 L .28634 .78187 L p .707 .577 .707 r
F P
0 g
s
.3145 .70024 m .3194 .73839 L .34277 .73572 L p .707 .577 .707 r
F P
0 g
s
.28634 .78187 m .28386 .7628 L .2523 .76682 L p .707 .577 .707 r
F P
0 g
s
.34277 .73572 m .33787 .69758 L .3145 .70024 L p .707 .577 .707 r
F P
0 g
s
.33712 .63465 m .34005 .69158 L .35602 .68649 L p .707 .577 .707 r
F P
0 g
s
.35602 .68649 m .35308 .62957 L .33712 .63465 L p .707 .577 .707 r
F P
0 g
s
.28386 .7628 m .28634 .78187 L .31542 .77842 L p .707 .577 .707 r
F P
0 g
s
.31542 .77842 m .31294 .75936 L .28386 .7628 L p .707 .577 .707 r
F P
0 g
s
.17405 .71874 m .17895 .75689 L .20038 .75376 L p .707 .577 .707 r
F P
0 g
s
.20038 .75376 m .19548 .71562 L .17405 .71874 L p .707 .577 .707 r
F P
0 g
s
.68312 .7623 m .68877 .77925 L .66889 .77547 L p .707 .577 .707 r
F P
0 g
s
.66889 .77547 m .66324 .75852 L .68312 .7623 L p .707 .577 .707 r
F P
0 g
s
.64648 .73374 m .63537 .69981 L .66181 .69874 L p .707 .577 .707 r
F P
0 g
s
.64281 .77639 m .63716 .75944 L .66324 .75852 L p .707 .577 .707 r
F P
0 g
s
.6279 .29923 m .6279 .80112 L .64225 .78964 L p .707 .577 .707 r
F P
0 g
s
.64225 .78964 m .64225 .28775 L .6279 .29923 L p .707 .577 .707 r
F P
0 g
s
.19406 .775 m .19654 .79406 L .22384 .79009 L p .707 .577 .707 r
F P
0 g
s
.22384 .79009 m .22136 .77102 L .19406 .775 L p .707 .577 .707 r
F P
0 g
s
.37086 .80046 m .37086 .29857 L .35732 .28702 L p .707 .577 .707 r
F P
0 g
s
.37086 .29857 m .37086 .80046 L .39704 .81033 L p .707 .577 .707 r
F P
0 g
s
.17517 .69853 m .17224 .6416 L .15925 .63774 L p .707 .577 .707 r
F P
0 g
s
.66181 .69874 m .67292 .73266 L .64648 .73374 L p .707 .577 .707 r
F P
0 g
s
.31294 .75936 m .31542 .77842 L .33919 .77589 L p .707 .577 .707 r
F P
0 g
s
.33919 .77589 m .33671 .75683 L .31294 .75936 L p .707 .577 .707 r
F P
0 g
s
.15925 .63774 m .16219 .69467 L .17517 .69853 L p .707 .577 .707 r
F P
0 g
s
.33787 .69758 m .34277 .73572 L .35837 .73416 L p .707 .577 .707 r
F P
0 g
s
.35837 .73416 m .35622 .71742 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35308 .62957 m .35602 .68649 L .36265 .68132 L p .707 .577 .707 r
F P
0 g
s
.36265 .68132 m .35972 .62439 L .35308 .62957 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .35837 .73416 L .36469 .73384 L p .707 .577 .707 r
F P
0 g
s
.36469 .73384 m .35978 .69569 L .35347 .69601 L p .707 .577 .707 r
F P
0 g
s
.35972 .62439 m .36265 .68132 L .35931 .67657 L p .707 .577 .707 r
F P
0 g
s
.35931 .67657 m .35684 .62847 L p .35972 .62439 L .707 .577 .707 r
F P
0 g
s
.35684 .62847 m .35638 .61964 L .35681 .62025 L p .707 .577 .707 r
F P
0 g
s
.35681 .62025 m .35972 .62439 L p .35684 .62847 L .707 .577 .707 r
F P
0 g
s
.35282 .75546 m .3553 .77452 L .35625 .77451 L p .707 .577 .707 r
F P
0 g
s
.35625 .77451 m .36219 .77445 L p .35636 .76261 L .707 .577 .707 r
F P
0 g
s
.35636 .76261 m .35282 .75546 L .35625 .77451 L .707 .577 .707 r
F
.36219 .77445 m .35972 .75538 L .35282 .75546 L p F P
0 g
s
.35978 .69569 m .36469 .73384 L .36109 .7348 L p .707 .577 .707 r
F P
0 g
s
.36109 .7348 m .35684 .70176 L p .35978 .69569 L .707 .577 .707 r
F P
0 g
s
.35684 .70176 m .35619 .69666 L .35681 .69649 L p .707 .577 .707 r
F P
0 g
s
.35681 .69649 m .35978 .69569 L p .35684 .70176 L .707 .577 .707 r
F P
0 g
s
.35638 .61964 m .35931 .67657 L .34633 .6727 L p .707 .577 .707 r
F P
0 g
s
.35972 .75538 m .36219 .77445 L .35919 .77568 L p .707 .577 .707 r
F P
0 g
s
.35919 .77568 m .35671 .75661 L .35972 .75538 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .33787 .69758 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35622 .71742 m .35347 .69601 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35619 .69666 m .36109 .7348 L .34793 .73695 L p .707 .577 .707 r
F P
0 g
s
.33671 .75683 m .33919 .77589 L .3553 .77452 L p .707 .577 .707 r
F P
0 g
s
.3553 .77452 m .35282 .75546 L .33671 .75683 L p .707 .577 .707 r
F P
0 g
s
.35671 .75661 m .35919 .77568 L .34658 .77809 L p .707 .577 .707 r
F P
0 g
s
.35732 .28702 m .35732 .78891 L .37086 .80046 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35742 .78621 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35742 .78621 m .35738 .78712 L p .35739 .78201 L .706 .577 .707 r
F P
0 g
s
.35739 .78201 m .35773 .30251 L .35742 .78621 L .706 .577 .707 r
F
.35734 .77274 m .35745 .63396 L .35738 .78712 L F
.35745 .63396 m .35775 .27491 L .3575 .62842 L F
.35745 .63396 m .3575 .62842 L .35738 .78712 L F
.35775 .27491 m .35775 .30326 L p .35773 .30251 L F P
0 g
s
.35775 .30326 m .35775 .7768 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35738 .78712 m .35732 .78891 L p .35734 .77274 L .706 .577 .707 r
F P
0 g
s
.35732 .28702 m .35775 .27491 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .78891 m .35732 .49035 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .49035 m .35732 .28702 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.17308 .77835 m .17556 .79742 L .19654 .79406 L p .707 .577 .707 r
F P
0 g
s
.19654 .79406 m .19406 .775 L .17308 .77835 L p .707 .577 .707 r
F P
0 g
s
.16089 .72089 m .1658 .75904 L .17895 .75689 L p .707 .577 .707 r
F P
0 g
s
.17895 .75689 m .17405 .71874 L .16089 .72089 L p .707 .577 .707 r
F P
0 g
s
.66324 .75852 m .66889 .77547 L .64281 .77639 L p .707 .577 .707 r
F P
0 g
s
.16219 .69467 m .15925 .63774 L .15592 .63298 L p .707 .577 .707 r
F P
0 g
s
.16047 .78076 m .16295 .79983 L .17556 .79742 L p .707 .577 .707 r
F P
0 g
s
.17556 .79742 m .17308 .77835 L .16047 .78076 L p .707 .577 .707 r
F P
0 g
s
.64225 .28775 m .64225 .78964 L .64261 .77931 L p .706 .577 .707 r
F P
0 g
s
.64266 .76212 m .64225 .28775 L .64261 .77931 L .706 .577 .707 r
F
.64268 .77753 m .64268 .27564 L .64225 .28775 L p F P
0 g
s
.64261 .77931 m .64268 .77753 L p .64266 .76212 L .706 .577 .707 r
F P
0 g
s
.64268 .27564 m .64268 .77753 L .62914 .76597 L p .707 .577 .707 r
F P
0 g
s
.64068 .63472 m .64316 .58966 L p .64028 .5692 L .707 .577 .707 r
F P
0 g
s
.64316 .58966 m .64362 .58138 L .64319 .57982 L p .707 .577 .707 r
F P
0 g
s
.64319 .57982 m .64028 .5692 L p .64316 .58966 L .707 .577 .707 r
F P
0 g
s
.15592 .63298 m .15885 .68991 L .16219 .69467 L p .707 .577 .707 r
F P
0 g
s
.15729 .72185 m .1622 .76 L .1658 .75904 L p .707 .577 .707 r
F P
0 g
s
.1658 .75904 m .16089 .72089 L .15729 .72185 L p .707 .577 .707 r
F P
0 g
s
.15885 .68991 m .15592 .63298 L .16255 .62781 L p .707 .577 .707 r
F P
0 g
s
.15746 .78199 m .15994 .80106 L .16295 .79983 L p .707 .577 .707 r
F P
0 g
s
.16295 .79983 m .16047 .78076 L .15746 .78199 L p .707 .577 .707 r
F P
0 g
s
.16255 .62781 m .16548 .68474 L .15885 .68991 L p .707 .577 .707 r
F P
0 g
s
.16361 .72154 m .16851 .75968 L .1622 .76 L p .707 .577 .707 r
F P
0 g
s
.1622 .76 m .15729 .72185 L .16361 .72154 L p .707 .577 .707 r
F P
0 g
s
.34633 .6727 m .3434 .61577 L .35638 .61964 L p .707 .577 .707 r
F P
0 g
s
.62914 .76597 m .62914 .26409 L .64268 .27564 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35775 .27491 L .3721 .26343 L p .707 .577 .707 r
F P
0 g
s
.16548 .68474 m .16255 .62781 L .17851 .62272 L p .707 .577 .707 r
F P
0 g
s
.16436 .78192 m .16683 .80098 L .15994 .80106 L p .707 .577 .707 r
F P
0 g
s
.15994 .80106 m .15746 .78199 L .16436 .78192 L p .707 .577 .707 r
F P
0 g
s
.17851 .62272 m .18145 .67965 L .16548 .68474 L p .707 .577 .707 r
F P
0 g
s
.34793 .73695 m .34303 .69881 L .35619 .69666 L p .707 .577 .707 r
F P
0 g
s
.3434 .61577 m .34633 .6727 L .32496 .6701 L p .707 .577 .707 r
F P
0 g
s
.32496 .6701 m .32203 .61317 L .3434 .61577 L p .707 .577 .707 r
F P
0 g
s
.17921 .71997 m .18412 .75812 L .16851 .75968 L p .707 .577 .707 r
F P
0 g
s
.16851 .75968 m .16361 .72154 L .17921 .71997 L p .707 .577 .707 r
F P
0 g
s
.34658 .77809 m .3441 .75902 L .35671 .75661 L p .707 .577 .707 r
F P
0 g
s
.18145 .67965 m .17851 .62272 L .20224 .61822 L p .707 .577 .707 r
F P
0 g
s
.62914 .26409 m .62914 .76597 L .60296 .75611 L p .707 .577 .707 r
F P
0 g
s
.60296 .75611 m .60296 .25422 L .62914 .26409 L p .707 .577 .707 r
F P
0 g
s
.3721 .76532 m .3721 .26343 L .39897 .2537 L p .707 .577 .707 r
F P
0 g
s
.3721 .26343 m .3721 .76532 L .35775 .7768 L p .707 .577 .707 r
F P
0 g
s
.20224 .61822 m .20517 .67515 L .18145 .67965 L p .707 .577 .707 r
F P
0 g
s
.18047 .78055 m .18295 .79961 L .16683 .80098 L p .707 .577 .707 r
F P
0 g
s
.16683 .80098 m .16436 .78192 L .18047 .78055 L p .707 .577 .707 r
F P
0 g
s
.34303 .69881 m .34793 .73695 L .32651 .74008 L p .707 .577 .707 r
F P
0 g
s
.32651 .74008 m .3216 .70193 L .34303 .69881 L p .707 .577 .707 r
F P
0 g
s
.32203 .61317 m .32496 .6701 L .29732 .66902 L p .707 .577 .707 r
F P
0 g
s
.29732 .66902 m .29438 .61209 L .32203 .61317 L p .707 .577 .707 r
F P
0 g
s
.20258 .71731 m .20749 .75546 L .18412 .75812 L p .707 .577 .707 r
F P
0 g
s
.18412 .75812 m .17921 .71997 L .20258 .71731 L p .707 .577 .707 r
F P
0 g
s
.20517 .67515 m .20224 .61822 L .2314 .61474 L p .707 .577 .707 r
F P
0 g
s
.3441 .75902 m .34658 .77809 L .3256 .78144 L p .707 .577 .707 r
F P
0 g
s
.3256 .78144 m .32312 .76238 L .3441 .75902 L p .707 .577 .707 r
F P
0 g
s
.29438 .61209 m .29732 .66902 L .26609 .66956 L p .707 .577 .707 r
F P
0 g
s
.26609 .66956 m .26316 .61263 L .29438 .61209 L p .707 .577 .707 r
F P
0 g
s
.2314 .61474 m .23434 .67167 L .20517 .67515 L p .707 .577 .707 r
F P
0 g
s
.73391 .66771 m .73684 .61437 L .70561 .61038 L p .707 .577 .707 r
F P
0 g
s
.73684 .61437 m .73391 .66771 L .76566 .66794 L p .707 .577 .707 r
F P
0 g
s
.76566 .66794 m .76859 .6146 L .73684 .61437 L p .707 .577 .707 r
F P
0 g
s
.23434 .67167 m .2314 .61474 L .26316 .61263 L p .707 .577 .707 r
F P
0 g
s
.76859 .6146 m .76566 .66794 L .79483 .66439 L p .707 .577 .707 r
F P
0 g
s
.79483 .66439 m .79776 .61105 L .76859 .6146 L p .707 .577 .707 r
F P
0 g
s
.3216 .70193 m .32651 .74008 L .29891 .74387 L p .707 .577 .707 r
F P
0 g
s
.70268 .66372 m .70561 .61038 L .67797 .60303 L p .707 .577 .707 r
F P
0 g
s
.70561 .61038 m .70268 .66372 L .73391 .66771 L p .707 .577 .707 r
F P
0 g
s
.29891 .74387 m .294 .70573 L .3216 .70193 L p .707 .577 .707 r
F P
0 g
s
.26316 .61263 m .26609 .66956 L .23434 .67167 L p .707 .577 .707 r
F P
0 g
s
.20424 .77802 m .20671 .79708 L .18295 .79961 L p .707 .577 .707 r
F P
0 g
s
.18295 .79961 m .18047 .78055 L .20424 .77802 L p .707 .577 .707 r
F P
0 g
s
.60296 .25422 m .60296 .75611 L .5667 .7489 L p .707 .577 .707 r
F P
0 g
s
.5667 .7489 m .5667 .24701 L .60296 .25422 L p .707 .577 .707 r
F P
0 g
s
.39897 .2537 m .39897 .75559 L .3721 .76532 L p .707 .577 .707 r
F P
0 g
s
.39897 .75559 m .39897 .2537 L .43573 .24668 L p .707 .577 .707 r
F P
0 g
s
.23143 .71381 m .23633 .75196 L .20749 .75546 L p .707 .577 .707 r
F P
0 g
s
.20749 .75546 m .20258 .71731 L .23143 .71381 L p .707 .577 .707 r
F P
0 g
s
.79776 .61105 m .79483 .66439 L .81855 .65742 L p .707 .577 .707 r
F P
0 g
s
.81855 .65742 m .82148 .60408 L .79776 .61105 L p .707 .577 .707 r
F P
0 g
s
.67503 .65637 m .67797 .60303 L .6566 .59304 L p .707 .577 .707 r
F P
0 g
s
.67797 .60303 m .67503 .65637 L .70268 .66372 L p .707 .577 .707 r
F P
0 g
s
.294 .70573 m .29891 .74387 L .26784 .74797 L p .707 .577 .707 r
F P
0 g
s
.32312 .76238 m .3256 .78144 L .2983 .78542 L p .707 .577 .707 r
F P
0 g
s
.2983 .78542 m .29582 .76635 L .32312 .76238 L p .707 .577 .707 r
F P
0 g
s
.26784 .74797 m .26293 .70982 L .294 .70573 L p .707 .577 .707 r
F P
0 g
s
.26293 .70982 m .26784 .74797 L .23633 .75196 L p .707 .577 .707 r
F P
0 g
s
.23633 .75196 m .23143 .71381 L .26293 .70982 L p .707 .577 .707 r
F P
0 g
s
.23332 .77457 m .2358 .79364 L .20671 .79708 L p .707 .577 .707 r
F P
0 g
s
.20671 .79708 m .20424 .77802 L .23332 .77457 L p .707 .577 .707 r
F P
0 g
s
.73216 .74108 m .73707 .70874 L .70599 .70198 L p .707 .577 .707 r
F P
0 g
s
.73707 .70874 m .73216 .74108 L .76366 .74259 L p .707 .577 .707 r
F P
0 g
s
.76366 .74259 m .76857 .71025 L .73707 .70874 L p .707 .577 .707 r
F P
0 g
s
.5667 .24701 m .5667 .7489 L .52391 .74505 L p .707 .577 .707 r
F P
0 g
s
.52391 .74505 m .52391 .24316 L .5667 .24701 L p .707 .577 .707 r
F P
0 g
s
.43573 .74857 m .43573 .24668 L .47879 .24304 L p .707 .577 .707 r
F P
0 g
s
.43573 .24668 m .43573 .74857 L .39897 .75559 L p .707 .577 .707 r
F P
0 g
s
.70109 .73432 m .70599 .70198 L .67839 .69063 L p .707 .577 .707 r
F P
0 g
s
.70599 .70198 m .70109 .73432 L .73216 .74108 L p .707 .577 .707 r
F P
0 g
s
.82148 .60408 m .81855 .65742 L .83451 .6477 L p .707 .577 .707 r
F P
0 g
s
.83451 .6477 m .83745 .59436 L .82148 .60408 L p .707 .577 .707 r
F P
0 g
s
.76857 .71025 m .76366 .74259 L .79251 .7387 L p .707 .577 .707 r
F P
0 g
s
.79251 .7387 m .79742 .70636 L .76857 .71025 L p .707 .577 .707 r
F P
0 g
s
.29582 .76635 m .2983 .78542 L .26736 .78962 L p .707 .577 .707 r
F P
0 g
s
.26736 .78962 m .26488 .77055 L .29582 .76635 L p .707 .577 .707 r
F P
0 g
s
.26488 .77055 m .26736 .78962 L .2358 .79364 L p .707 .577 .707 r
F P
0 g
s
.2358 .79364 m .23332 .77457 L .26488 .77055 L p .707 .577 .707 r
F P
0 g
s
.65367 .64638 m .6566 .59304 L .64362 .58138 L p .707 .577 .707 r
F P
0 g
s
.6566 .59304 m .65367 .64638 L .67503 .65637 L p .707 .577 .707 r
F P
0 g
s
.67349 .72297 m .67839 .69063 L .65697 .6758 L p .707 .577 .707 r
F P
0 g
s
.67839 .69063 m .67349 .72297 L .70109 .73432 L p .707 .577 .707 r
F P
0 g
s
.52391 .24316 m .52391 .74505 L .47879 .74493 L p .707 .577 .707 r
F P
0 g
s
.47879 .74493 m .47879 .24304 L .52391 .24316 L p .707 .577 .707 r
F P
0 g
s
.47879 .24304 m .47879 .74493 L .43573 .74857 L p .707 .577 .707 r
F P
0 g
s
.73264 .78541 m .73512 .76935 L .70418 .76222 L p .707 .577 .707 r
F P
0 g
s
.73512 .76935 m .73264 .78541 L .7642 .78723 L p .707 .577 .707 r
F P
0 g
s
.7642 .78723 m .76668 .77117 L .73512 .76935 L p .707 .577 .707 r
F P
0 g
s
.79742 .70636 m .79251 .7387 L .81588 .72979 L p .707 .577 .707 r
F P
0 g
s
.81588 .72979 m .82079 .69745 L .79742 .70636 L p .707 .577 .707 r
F P
0 g
s
.7017 .77828 m .70418 .76222 L .67688 .75047 L p .707 .577 .707 r
F P
0 g
s
.70418 .76222 m .7017 .77828 L .73264 .78541 L p .707 .577 .707 r
F P
0 g
s
.76668 .77117 m .7642 .78723 L .79328 .78356 L p .707 .577 .707 r
F P
0 g
s
.79328 .78356 m .79576 .7675 L .76668 .77117 L p .707 .577 .707 r
F P
0 g
s
.83745 .59436 m .83451 .6477 L .84115 .63618 L p .707 .577 .707 r
F P
0 g
s
.84115 .63618 m .84408 .58284 L .83745 .59436 L p .707 .577 .707 r
F P
0 g
s
.67688 .75047 m .6744 .76653 L .7017 .77828 L p .707 .577 .707 r
F P
0 g
s
.64362 .58138 m .64068 .63472 L .65367 .64638 L p .707 .577 .707 r
F P
0 g
s
.6744 .76653 m .67688 .75047 L .6559 .73525 L p .707 .577 .707 r
F P
0 g
s
.65206 .70814 m .65697 .6758 L .64381 .65894 L p .707 .577 .707 r
F P
0 g
s
.65697 .6758 m .65206 .70814 L .67349 .72297 L p .707 .577 .707 r
F P
0 g
s
.79576 .7675 m .79328 .78356 L .81705 .77475 L p .707 .577 .707 r
F P
0 g
s
.81705 .77475 m .81953 .75869 L .79576 .7675 L p .707 .577 .707 r
F P
0 g
s
.82079 .69745 m .81588 .72979 L .83149 .71673 L p .707 .577 .707 r
F P
0 g
s
.83149 .71673 m .83639 .68439 L .82079 .69745 L p .707 .577 .707 r
F P
0 g
s
.6559 .73525 m .65342 .75131 L .6744 .76653 L p .707 .577 .707 r
F P
0 g
s
.65342 .75131 m .6559 .73525 L .64329 .71805 L p .707 .577 .707 r
F P
0 g
s
.64381 .65894 m .63891 .69128 L .65206 .70814 L p .707 .577 .707 r
F P
0 g
s
.81953 .75869 m .81705 .77475 L .83316 .76166 L p .707 .577 .707 r
F P
0 g
s
.83316 .76166 m .83564 .7456 L .81953 .75869 L p .707 .577 .707 r
F P
0 g
s
.63891 .69128 m .64381 .65894 L .64021 .6417 L p .707 .577 .707 r
F P
0 g
s
.64028 .5692 m .63735 .62254 L .64068 .63472 L p .707 .577 .707 r
F P
0 g
s
.84408 .58284 m .84115 .63618 L .83781 .624 L p .707 .577 .707 r
F P
0 g
s
.83781 .624 m .84074 .57066 L .84408 .58284 L p .707 .577 .707 r
F P
0 g
s
.64329 .71805 m .64081 .73411 L .65342 .75131 L p .707 .577 .707 r
F P
0 g
s
.83639 .68439 m .83149 .71673 L .8378 .7008 L p .707 .577 .707 r
F P
0 g
s
.8378 .7008 m .8427 .66846 L .83639 .68439 L p .707 .577 .707 r
F P
0 g
s
.63735 .62254 m .64028 .5692 L .64692 .55768 L p .707 .577 .707 r
F P
0 g
s
.64081 .73411 m .64329 .71805 L .64028 .70056 L p .707 .577 .707 r
F P
0 g
s
.64021 .6417 m .63531 .67404 L .63891 .69128 L p .707 .577 .707 r
F P
0 g
s
.83564 .7456 m .83316 .76166 L .84006 .74559 L p .707 .577 .707 r
F P
0 g
s
.84006 .74559 m .84254 .72953 L .83564 .7456 L p .707 .577 .707 r
F P
0 g
s
.63531 .67404 m .64021 .6417 L .64653 .62577 L p .707 .577 .707 r
F P
0 g
s
.64028 .70056 m .6378 .71662 L .64081 .73411 L p .707 .577 .707 r
F P
0 g
s
.64692 .55768 m .64398 .61103 L .63735 .62254 L p .707 .577 .707 r
F P
0 g
s
.84074 .57066 m .83781 .624 L .82483 .61234 L p .707 .577 .707 r
F P
0 g
s
.82483 .61234 m .82776 .559 L .84074 .57066 L p .707 .577 .707 r
F P
0 g
s
.8427 .66846 m .8378 .7008 L .8342 .68356 L p .707 .577 .707 r
F P
0 g
s
.8342 .68356 m .83911 .65122 L .8427 .66846 L p .707 .577 .707 r
F P
0 g
s
.64398 .61103 m .64692 .55768 L .66288 .54796 L p .707 .577 .707 r
F P
0 g
s
.6378 .71662 m .64028 .70056 L .64717 .68449 L p .707 .577 .707 r
F P
0 g
s
.38959 .61494 m .39638 .55903 L .36534 .55398 L p .707 .577 .707 r
F P
0 g
s
.39638 .55903 m .38959 .61494 L .42117 .61788 L p .707 .577 .707 r
F P
0 g
s
.42117 .61788 m .42796 .56196 L .39638 .55903 L p .707 .577 .707 r
F P
0 g
s
.64653 .62577 m .64162 .65811 L .63531 .67404 L p .707 .577 .707 r
F P
0 g
s
.84254 .72953 m .84006 .74559 L .83705 .7281 L p .707 .577 .707 r
F P
0 g
s
.83705 .7281 m .83953 .71204 L .84254 .72953 L p .707 .577 .707 r
F P
0 g
s
.42796 .56196 m .42117 .61788 L .4502 .6184 L p .707 .577 .707 r
F P
0 g
s
.4502 .6184 m .45699 .56249 L .42796 .56196 L p .707 .577 .707 r
F P
0 g
s
.35856 .60989 m .36534 .55398 L .33788 .5473 L p .707 .577 .707 r
F P
0 g
s
.36534 .55398 m .35856 .60989 L .38959 .61494 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64162 .65811 m .64653 .62577 L .66213 .61271 L p .707 .577 .707 r
F P
0 g
s
.64717 .68449 m .6447 .70055 L .6378 .71662 L p .707 .577 .707 r
F P
0 g
s
.82776 .559 m .82483 .61234 L .80346 .60235 L p .707 .577 .707 r
F P
0 g
s
.80346 .60235 m .8064 .54901 L .82776 .559 L p .707 .577 .707 r
F P
0 g
s
.83911 .65122 m .8342 .68356 L .82105 .6667 L p .707 .577 .707 r
F P
0 g
s
.82105 .6667 m .82595 .63436 L .83911 .65122 L p .707 .577 .707 r
F P
0 g
s
.66288 .54796 m .65995 .60131 L .64398 .61103 L p .707 .577 .707 r
F P
0 g
s
.45699 .56249 m .4502 .6184 L .47384 .61647 L p .707 .577 .707 r
F P
0 g
s
.47384 .61647 m .48062 .56056 L .45699 .56249 L p .707 .577 .707 r
F P
0 g
s
.33788 .5473 m .3311 .60321 L .35856 .60989 L p .707 .577 .707 r
F P
0 g
s
.65995 .60131 m .66288 .54796 L .6866 .54099 L p .707 .577 .707 r
F P
0 g
s
.38342 .66659 m .39453 .63014 L .36462 .62024 L p .707 .577 .707 r
F P
0 g
s
.39453 .63014 m .38342 .66659 L .41387 .67522 L p .707 .577 .707 r
F P
0 g
s
.41387 .67522 m .42498 .63877 L .39453 .63014 L p .707 .577 .707 r
F P
0 g
s
.3311 .60321 m .33788 .5473 L .31669 .53965 L p .707 .577 .707 r
F P
0 g
s
.42498 .63877 m .41387 .67522 L .44189 .68174 L p .707 .577 .707 r
F P
0 g
s
.44189 .68174 m .45299 .6453 L .42498 .63877 L p .707 .577 .707 r
F P
0 g
s
.36462 .62024 m .35351 .65669 L .38342 .66659 L p .707 .577 .707 r
F P
0 g
s
.35351 .65669 m .36462 .62024 L .33819 .61004 L p .707 .577 .707 r
F P
0 g
s
.6447 .70055 m .64717 .68449 L .66329 .6714 L p .707 .577 .707 r
F P
0 g
s
.66213 .61271 m .65723 .64505 L .64162 .65811 L p .707 .577 .707 r
F P
0 g
s
.83953 .71204 m .83705 .7281 L .82444 .7109 L p .707 .577 .707 r
F P
0 g
s
.82444 .7109 m .82692 .69484 L .83953 .71204 L p .707 .577 .707 r
F P
0 g
s
.33819 .61004 m .32708 .64649 L .35351 .65669 L p .707 .577 .707 r
F P
0 g
s
.31669 .53965 m .30991 .59556 L .3311 .60321 L p .707 .577 .707 r
F P
0 g
s
.65723 .64505 m .66213 .61271 L .6855 .6038 L p .707 .577 .707 r
F P
0 g
s
.8064 .54901 m .80346 .60235 L .77581 .595 L p .707 .577 .707 r
F P
0 g
s
.77581 .595 m .77875 .54166 L .8064 .54901 L p .707 .577 .707 r
F P
0 g
s
.38692 .70774 m .39256 .68955 L .36284 .67944 L p .707 .577 .707 r
F P
0 g
s
.39256 .68955 m .38692 .70774 L .41738 .71663 L p .707 .577 .707 r
F P
0 g
s
.41738 .71663 m .42302 .69844 L .39256 .68955 L p .707 .577 .707 r
F P
0 g
s
.66329 .6714 m .66081 .68746 L .6447 .70055 L p .707 .577 .707 r
F P
0 g
s
.45299 .6453 m .44189 .68174 L .46472 .68551 L p .707 .577 .707 r
F P
0 g
s
.46472 .68551 m .47583 .64907 L .45299 .6453 L p .707 .577 .707 r
F P
0 g
s
.82595 .63436 m .82105 .6667 L .79962 .65187 L p .707 .577 .707 r
F P
0 g
s
.79962 .65187 m .80452 .61953 L .82595 .63436 L p .707 .577 .707 r
F P
0 g
s
.48062 .56056 m .47384 .61647 L .48977 .61227 L p .707 .577 .707 r
F P
0 g
s
.48977 .61227 m .49655 .55635 L .48062 .56056 L p .707 .577 .707 r
F P
0 g
s
.68367 .59433 m .6866 .54099 L .71577 .53744 L p .707 .577 .707 r
F P
0 g
s
.6866 .54099 m .68367 .59433 L .65995 .60131 L p .707 .577 .707 r
F P
0 g
s
.36284 .67944 m .35719 .69764 L .38692 .70774 L p .707 .577 .707 r
F P
0 g
s
.32708 .64649 m .33819 .61004 L .31781 .60054 L p .707 .577 .707 r
F P
0 g
s
.42302 .69844 m .41738 .71663 L .44559 .72343 L p .707 .577 .707 r
F P
0 g
s
.44559 .72343 m .45124 .70524 L .42302 .69844 L p .707 .577 .707 r
F P
0 g
s
.35719 .69764 m .36284 .67944 L .33676 .66911 L p .707 .577 .707 r
F P
0 g
s
.30991 .59556 m .31669 .53965 L .30384 .53178 L p .707 .577 .707 r
F P
0 g
s
.33676 .66911 m .33111 .6873 L .35719 .69764 L p .707 .577 .707 r
F P
0 g
s
.31781 .60054 m .3067 .63699 L .32708 .64649 L p .707 .577 .707 r
F P
0 g
s
.77875 .54166 m .77581 .595 L .74459 .59102 L p .707 .577 .707 r
F P
0 g
s
.74459 .59102 m .74752 .53768 L .77875 .54166 L p .707 .577 .707 r
F P
0 g
s
.66081 .68746 m .66329 .6714 L .68705 .66259 L p .707 .577 .707 r
F P
0 g
s
.71284 .59079 m .71577 .53744 L .74752 .53768 L p .707 .577 .707 r
F P
0 g
s
.71577 .53744 m .71284 .59079 L .68367 .59433 L p .707 .577 .707 r
F P
0 g
s
.6806 .63614 m .6855 .6038 L .71435 .5999 L p .707 .577 .707 r
F P
0 g
s
.6855 .6038 m .6806 .63614 L .65723 .64505 L p .707 .577 .707 r
F P
0 g
s
.82692 .69484 m .82444 .7109 L .80346 .69568 L p .707 .577 .707 r
F P
0 g
s
.80346 .69568 m .80594 .67962 L .82692 .69484 L p .707 .577 .707 r
F P
0 g
s
.45124 .70524 m .44559 .72343 L .46879 .72747 L p .707 .577 .707 r
F P
0 g
s
.46879 .72747 m .47444 .70928 L .45124 .70524 L p .707 .577 .707 r
F P
0 g
s
.74752 .53768 m .74459 .59102 L .71284 .59079 L p .707 .577 .707 r
F P
0 g
s
.30384 .53178 m .29706 .58769 L .30991 .59556 L p .707 .577 .707 r
F P
0 g
s
.80452 .61953 m .79962 .65187 L .77202 .64052 L p .707 .577 .707 r
F P
0 g
s
.77202 .64052 m .77692 .60817 L .80452 .61953 L p .707 .577 .707 r
F P
0 g
s
.33111 .6873 m .33676 .66911 L .31687 .65956 L p .707 .577 .707 r
F P
0 g
s
.47583 .64907 m .46472 .68551 L .48014 .68616 L p .707 .577 .707 r
F P
0 g
s
.48014 .68616 m .49125 .64972 L .47583 .64907 L p .707 .577 .707 r
F P
0 g
s
.31687 .65956 m .31123 .67775 L .33111 .6873 L p .707 .577 .707 r
F P
0 g
s
.68705 .66259 m .68458 .67865 L .66081 .68746 L p .707 .577 .707 r
F P
0 g
s
.3067 .63699 m .31781 .60054 L .30549 .59267 L p .707 .577 .707 r
F P
0 g
s
.49655 .55635 m .48977 .61227 L .49644 .60621 L p .707 .577 .707 r
F P
0 g
s
.49644 .60621 m .50322 .5503 L .49655 .55635 L p .707 .577 .707 r
F P
0 g
s
.70945 .63225 m .71435 .5999 L .74585 .60141 L p .707 .577 .707 r
F P
0 g
s
.71435 .5999 m .70945 .63225 L .6806 .63614 L p .707 .577 .707 r
F P
0 g
s
.30549 .59267 m .29438 .62912 L .3067 .63699 L p .707 .577 .707 r
F P
0 g
s
.77692 .60817 m .77202 .64052 L .74095 .63376 L p .707 .577 .707 r
F P
0 g
s
.74095 .63376 m .74585 .60141 L .77692 .60817 L p .707 .577 .707 r
F P
0 g
s
.68458 .67865 m .68705 .66259 L .71614 .65892 L p .707 .577 .707 r
F P
0 g
s
.29706 .58769 m .30384 .53178 L .30059 .52445 L p .707 .577 .707 r
F P
0 g
s
.74585 .60141 m .74095 .63376 L .70945 .63225 L p .707 .577 .707 r
F P
0 g
s
.80594 .67962 m .80346 .69568 L .77616 .68393 L p .707 .577 .707 r
F P
0 g
s
.77616 .68393 m .77864 .66787 L .80594 .67962 L p .707 .577 .707 r
F P
0 g
s
.47444 .70928 m .46879 .72747 L .48472 .72837 L p .707 .577 .707 r
F P
0 g
s
.48472 .72837 m .49036 .71018 L .47444 .70928 L p .707 .577 .707 r
F P
0 g
s
.71614 .65892 m .71366 .67498 L .68458 .67865 L p .707 .577 .707 r
F P
0 g
s
.31123 .67775 m .31687 .65956 L .30513 .65173 L p .707 .577 .707 r
F P
0 g
s
.71366 .67498 m .71614 .65892 L .7477 .66074 L p .707 .577 .707 r
F P
0 g
s
.30513 .65173 m .29948 .66992 L .31123 .67775 L p .707 .577 .707 r
F P
0 g
s
.30059 .52445 m .29381 .58037 L .29706 .58769 L p .707 .577 .707 r
F P
0 g
s
.77864 .66787 m .77616 .68393 L .74522 .6768 L p .707 .577 .707 r
F P
0 g
s
.74522 .6768 m .7477 .66074 L .77864 .66787 L p .707 .577 .707 r
F P
0 g
s
.7477 .66074 m .74522 .6768 L .71366 .67498 L p .707 .577 .707 r
F P
0 g
s
.49125 .64972 m .48014 .68616 L .48664 .68363 L p .707 .577 .707 r
F P
0 g
s
.48664 .68363 m .49775 .64718 L .49125 .64972 L p .707 .577 .707 r
F P
0 g
s
.29438 .62912 m .30549 .59267 L .30242 .5872 L p .707 .577 .707 r
F P
0 g
s
.30242 .5872 m .29132 .62365 L .29438 .62912 L p .707 .577 .707 r
F P
0 g
s
.50322 .5503 m .49644 .60621 L .49319 .59889 L p .707 .577 .707 r
F P
0 g
s
.49319 .59889 m .49997 .54297 L .50322 .5503 L p .707 .577 .707 r
F P
0 g
s
.29381 .58037 m .30059 .52445 L .30726 .5184 L p .707 .577 .707 r
F P
0 g
s
.49036 .71018 m .48472 .72837 L .4918 .72603 L p .707 .577 .707 r
F P
0 g
s
.4918 .72603 m .49745 .70784 L .49036 .71018 L p .707 .577 .707 r
F P
0 g
s
.29948 .66992 m .30513 .65173 L .30268 .64638 L p .707 .577 .707 r
F P
0 g
s
.30268 .64638 m .29704 .66457 L .29948 .66992 L p .707 .577 .707 r
F P
0 g
s
.30726 .5184 m .30048 .57431 L .29381 .58037 L p .707 .577 .707 r
F P
0 g
s
.49775 .64718 m .48664 .68363 L .48358 .67816 L p .707 .577 .707 r
F P
0 g
s
.48358 .67816 m .49469 .64171 L .49775 .64718 L p .707 .577 .707 r
F P
0 g
s
.29132 .62365 m .30242 .5872 L .30892 .58467 L p .707 .577 .707 r
F P
0 g
s
.49997 .54297 m .49319 .59889 L .48034 .59101 L p .707 .577 .707 r
F P
0 g
s
.48034 .59101 m .48712 .5351 L .49997 .54297 L p .707 .577 .707 r
F P
0 g
s
.30892 .58467 m .29781 .62112 L .29132 .62365 L p .707 .577 .707 r
F P
0 g
s
.30048 .57431 m .30726 .5184 L .32319 .51419 L p .707 .577 .707 r
F P
0 g
s
.49745 .70784 m .4918 .72603 L .48935 .72068 L p .707 .577 .707 r
F P
0 g
s
.48935 .72068 m .495 .70249 L .49745 .70784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29704 .66457 m .30268 .64638 L .30977 .64404 L p .707 .577 .707 r
F P
0 g
s
.30977 .64404 m .30412 .66223 L .29704 .66457 L p .707 .577 .707 r
F P
0 g
s
.32319 .51419 m .31641 .57011 L .30048 .57431 L p .707 .577 .707 r
F P
0 g
s
.49469 .64171 m .48358 .67816 L .47125 .67029 L p .707 .577 .707 r
F P
0 g
s
.47125 .67029 m .48236 .63384 L .49469 .64171 L p .707 .577 .707 r
F P
0 g
s
.29781 .62112 m .30892 .58467 L .32434 .58532 L p .707 .577 .707 r
F P
0 g
s
.48712 .5351 m .48034 .59101 L .45915 .58337 L p .707 .577 .707 r
F P
0 g
s
.45915 .58337 m .46593 .52745 L .48712 .5351 L p .707 .577 .707 r
F P
0 g
s
.32434 .58532 m .31323 .62177 L .29781 .62112 L p .707 .577 .707 r
F P
0 g
s
.31641 .57011 m .32319 .51419 L .34683 .51226 L p .707 .577 .707 r
F P
0 g
s
.495 .70249 m .48935 .72068 L .47761 .71285 L p .707 .577 .707 r
F P
0 g
s
.47761 .71285 m .48326 .69466 L .495 .70249 L p .707 .577 .707 r
F P
0 g
s
.30412 .66223 m .30977 .64404 L .32569 .64493 L p .707 .577 .707 r
F P
0 g
s
.34683 .51226 m .34004 .56818 L .31641 .57011 L p .707 .577 .707 r
F P
0 g
s
.32569 .64493 m .32005 .66312 L .30412 .66223 L p .707 .577 .707 r
F P
0 g
s
.46593 .52745 m .45915 .58337 L .43169 .57669 L p .707 .577 .707 r
F P
0 g
s
.43169 .57669 m .43847 .52077 L .46593 .52745 L p .707 .577 .707 r
F P
0 g
s
.48236 .63384 m .47125 .67029 L .45088 .66079 L p .707 .577 .707 r
F P
0 g
s
.45088 .66079 m .46199 .62434 L .48236 .63384 L p .707 .577 .707 r
F P
0 g
s
.31323 .62177 m .32434 .58532 L .34718 .58909 L p .707 .577 .707 r
F P
0 g
s
.34004 .56818 m .34683 .51226 L .37586 .51279 L p .707 .577 .707 r
F P
0 g
s
.34718 .58909 m .33607 .62554 L .31323 .62177 L p .707 .577 .707 r
F P
0 g
s
.43847 .52077 m .43169 .57669 L .40065 .57164 L p .707 .577 .707 r
F P
0 g
s
.40065 .57164 m .40744 .51572 L .43847 .52077 L p .707 .577 .707 r
F P
0 g
s
.48326 .69466 m .47761 .71285 L .45773 .7033 L p .707 .577 .707 r
F P
0 g
s
.45773 .7033 m .46338 .6851 L .48326 .69466 L p .707 .577 .707 r
F P
0 g
s
.37586 .51279 m .36907 .5687 L .34004 .56818 L p .707 .577 .707 r
F P
0 g
s
.36907 .5687 m .37586 .51279 L .40744 .51572 L p .707 .577 .707 r
F P
0 g
s
.40744 .51572 m .40065 .57164 L .36907 .5687 L p .707 .577 .707 r
F P
0 g
s
.32005 .66312 m .32569 .64493 L .3489 .64898 L p .707 .577 .707 r
F P
0 g
s
.46199 .62434 m .45088 .66079 L .42444 .65059 L p .707 .577 .707 r
F P
0 g
s
.42444 .65059 m .43555 .61414 L .46199 .62434 L p .707 .577 .707 r
F P
0 g
s
.3489 .64898 m .34325 .66717 L .32005 .66312 L p .707 .577 .707 r
F P
0 g
s
.33607 .62554 m .34718 .58909 L .37519 .59561 L p .707 .577 .707 r
F P
0 g
s
.37519 .59561 m .36408 .63206 L .33607 .62554 L p .707 .577 .707 r
F P
0 g
s
.43555 .61414 m .42444 .65059 L .39453 .64069 L p .707 .577 .707 r
F P
0 g
s
.39453 .64069 m .40564 .60424 L .43555 .61414 L p .707 .577 .707 r
F P
0 g
s
.46338 .6851 m .45773 .7033 L .43165 .69296 L p .707 .577 .707 r
F P
0 g
s
.43165 .69296 m .4373 .67477 L .46338 .6851 L p .707 .577 .707 r
F P
0 g
s
.36408 .63206 m .37519 .59561 L .40564 .60424 L p .707 .577 .707 r
F P
0 g
s
.34325 .66717 m .3489 .64898 L .37711 .65578 L p .707 .577 .707 r
F P
0 g
s
.40564 .60424 m .39453 .64069 L .36408 .63206 L p .707 .577 .707 r
F P
0 g
s
.37711 .65578 m .37146 .67397 L .34325 .66717 L p .707 .577 .707 r
F P
0 g
s
.4373 .67477 m .43165 .69296 L .40192 .68286 L p .707 .577 .707 r
F P
0 g
s
.40192 .68286 m .40757 .66466 L .4373 .67477 L p .707 .577 .707 r
F P
0 g
s
.37146 .67397 m .37711 .65578 L .40757 .66466 L p .707 .577 .707 r
F P
0 g
s
.40757 .66466 m .40192 .68286 L .37146 .67397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6@00PWoo001iOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001iOol007Aoo`D0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00D007Aoo`00L7oo1000
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001OOol@0002FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001JOol5
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001GOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001EOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00004Goo3`00AWoo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH01000@Woo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF00001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF1000?Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000Eoo`8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0000=oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@003Ioo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002000cOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80035oo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00<7oo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP80031o
o`00Dgoo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0002moo`00Dgoo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF
001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0015YF00<005YFFUH00eYF
00<005YFFUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YF
FUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000EJ
EP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001COol01000FUIJEUYF2@001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00L005YFFUIJ
EP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`@000AJEP03001JEUYF00D0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0015YF00<005YFFUH015YF00<0
05YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00P001UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000AOol60006
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0`001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH0
0`00FUH000030006Ool8000?Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP80009JEPP000AJEP04001JEUYFFUH9000:Ool30005FUH01000
FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH000020007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF008000EJEP<000QJ
EP03001JEUYF00EJEP03001JEUYF009JEPD000Moo`<000=JEP04001JEUYFFUH2000]Ool005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYF001JEP0200000eYF001JEP02FUH20002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH80003FUH200000eYF001JEP02FUH2000]Ool003iooaH00003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009J
EP03001JEUYF00AJEP03001JEUYF00<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF008000=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH20003FUH2000]Ool003Qoo`H000=JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000/000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000IJEP03001JEP00009JEP8002eoo`00=7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`001UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YF
FUH01000;Goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004
FUH01000FUIJEUYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000UYF00@005YFFUIJEP<002eoo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH010000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003
FUH3000]Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001EYF00<0
05YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF009JEPH0009JEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0002FUH01000FUIJEUYF0P001eYF00<005YF
FUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH0000002io
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF0`001eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF008000=JEP06001JEP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF10001UYF00<005YFFUH015YF00<005YF00000P00;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000090005FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000=JEP8000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH01000FUH00000;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPH000QJEP03001J
EUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YF
FUH002moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF00000`001EYF00<005YF
FUH01UYF0`001eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH00`00Oomo
o`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000UJEP03001J
EUYF00@0009JEP03001JEUYF00AJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001J
EUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF0`00
1EYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUH005YF00001UYF00@005YFFUIJEP@0009JEQ00009JEP03001JEUYF00EJEP03001JEP0000<0
009JEP03001JEUYF009JEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF008000=JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@0017oo0`0015YF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEUYF1P001eYF00<005YFFUH01EYF1@001eYF00<005YFFUH00UYF0`0015YF
0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=JEP00
FUH00eYF1@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`002goo00<005YFFUH0
0UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH?0003FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00FUIJEP07FUH00`00FUIJEP04
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01`00FUH005YF001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000Yoo`06001JEUYF001JEP00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP03FUH?0009FUH00`00FUIJEP02FUH30006FUH00`00FUH0000200000eYF001JEP040008FUH00`00
FUIJEP04FUH50006FUH3000015YF001JEP0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YF001JEP00009JEP04001JEP000005FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP07FUH00`00FUIJEP020009Ool01@00FUH005YF0000;Goo000]Ool00`00FUH00003FUH00`00FUH0
00030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0`000eYF00<005YF00000P0015YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF
00800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0003FUH200000eYF001JEP03FUH70007Ool70006FUH00`00FUIJEP03FUH20007Ool01@00FUH005YF
0000;Goo000]Ool00`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP05FUH40004FUH300000eYF001JEP07FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000UYF00@005YFFUH000=JEP80009JEP03001JEUYF008000ioo`@0009J
EP03001JEUYF00EJEP8000Ioo`800003FUH007oo02aoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0008FUH0
1000FUH000000eYF1P001eYF00<005YFFUH015YF10000UYF00<005YF00002EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH01000FUH000001EYF00@005YF
0000019oo`@000MJEP<000Eoo`03001JEP0002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<000IJEP03
001JEUYF009JEPP00003FUH0000000EJEP03001JEUYF00EJEPL000YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP000eYF0P0000=JEP00000015YF00@005YF0000
01Ioo`8000AJEP05001JEUYFFUH00003Ool3000^Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP05FUH50003FUH300000eYF001JEP07FUH00`00FUIJEP03000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP03FUH20002FUH01000
FUIJEP0067oo0`0000=JEP00FUH00eYF0`0000=JEP000000;Woo000^Ool200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005Ool200000eYF
001JEP08FUH70003FUH30006FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YF00000P000UYF00<007oo
Ool06Goo0P001UYF00@005YF000002ioo`00<7oo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001goo2P001eYF00<005YFFUH01EYF100000=JEP0000000`000UYF00<005YF
FUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF
00<000IJEP04001JEUYFFUH4000MOol00`00FUIJEP03FUH4000^Ool003AooaT000Uoo`T0009JEP06
001JEUYFFUH005YF0P001EYF00<005YFFUH01eYF00<005YF00000`000UYF0`001EYF00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH0
00IJEP03001JEUYF00AJEP@001Uoo`<000AJEP800003FUH007oo02eoo`00CGoo2`000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP<00003FUH005YF00QJEP03001JEUYF00AJEPL000=JEP05001J
EUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020000
0eYF00000006FUH00`00FUIJEP05FUH00`00FUIJEP04000@Ool50003FUH200001EYF001JEUYF0000
;goo0014Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH010001eYF00<005YFFUH01UYF00<005YFFUH01@0015YF0P001UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF40000eYF00<005YFFUH00eYF0`000UYF00<007ooOol0;Goo000lOol:0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF
10000UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF00001UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000eYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000eYF00<0
07ooOol0;7oo000eOol90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH0
15YF00D005YF000005YF008000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000EJEP04001JEUYF0008FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<007ooOol0;7oo000]Ool90003FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P001UYF0`001eYF00<005YF
FUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo02ao
o`00;7oo1@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00=JEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00<000IJEP<000IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEP00001oo`0200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50002FUH00`00FUH0
0008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF008000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP80
00=oo`800003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00@005YFFUIJEP<00003FUH005YF
00MJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`03001JEP0002eoo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH90003FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001Woo00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUIJEP80009JEP8000=JEP800003Ool0000000800004FUH007ooOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0000027oo00<005YF0000;Goo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70005Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEPD000Aoo`80
0004FUH000000005Ool70004FUH00`00FUIJEP02FUH5000;Ool00`00Oomoo`0/Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP04FUHI0006FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03001oogoo009oo`04001JEUYF0002FUH00`00
Oomoo`0:Ool9000?Ool2000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF009JEPT001Aoo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH90005FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH80008FUH00`00FUIJEP04FUH01000FUIJEUYF100015YF0P0000=oo`00
FUH00UYF00@005YFFUH002Aoo`8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF2@007Goo00D005YFFUIJEP0000MJEP03001JEUYF00D0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00<000EJEP03001JEUYF00AJEP05001JEUYFFUH00002
Ool00`00FUIJEP04FUH20003FUH01@00FUIJEUYF00008Goo0`00;goo000^Ool20004FUH01000FUIJ
EUYF1`008goo10000eYF00<005YFFUH015YF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF100000=JEP00FUH01EYF00D005YFFUIJEP0000=oo`8000AJEP04
001JEP000002FUH01000FUIJEP007goo0P0000=JEP000000;goo000^Ool20002FUH6000MOolA0003
FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH30005FUH01000FUIJEUYF1`000UYF00<005YFFUH00UYF0`0000=JEP00Ool07Woo00D0
05YFFUIJEP00031oo`00;Woo100077oo1`000eYF1`000UYF00D005YFFUIJEP0000=JEP03001JEP00
0080009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00@00003FUH005YF009JEP03001JEUYF00=JEP@000MJEP<001aoo`<000=J
EP03001oogoo02ioo`00BWoo10000UYF00<005YF00001@000eYF00<005YFFUH00eYF00D005YFFUIJ
EP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP03001JEP0000QJEP03001J
EP0000<001Ioo`80009JEP04001JEUYF000aOol004=oo`L000AJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH70009Ool60004FUH00`00FUH0000bOol003]oo`P0
00AJEPL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEP00FUH00007FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0015YF00<005YFFUH00eYF0P00<goo000eOol60003FUH90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH030000UYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00=7oo000`Ool?0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EUYF00AJEP<0009JEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
;7oo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`001Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH0
0`00FUIJEP06FUH40003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF
00<007oo00000P001Woo4000?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH9000DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP80009oo`<005Eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH00UYF2@007Woo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0005FUH01000FUIJ
EUYF0P000goo00@005YFFUH005Eoo`00;Goo00<005YF000015YF00@005YFFUIJEPL002Qoo`<000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000MJEP<000Eoo`04001JEUYF001EOol002eoo`/0035oo`8000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP<000MJEP8000Ioo`80009JEP03001oogoo05=oo`00Jgoo0P000eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF0P001Woo0P0000AJEP00FUH005Ioo`00KGoo0P0000=JEP00FUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00000P001goo00<005YFFUH00UYF0P00EWoo001_Ool40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH50006FUH30009Ool00`00FUIJEP03FUH0
0`00Oomoo`1EOol007=oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00D00003FUH0000000<000=JEP8000Yoo`<000EJEP03001oogoo05Eoo`00NGoo20001UYF
00<005YFFUH02UYF00<005YFFUH015YF20001UYF20002goo00D005YFFUIJEP0000=JEP03001oogoo
05Ioo`00PGoo6`001UYF00<005YFFUH015YF1@0037oo0P0015YF00@005YFFUH005Uoo`00Sgoo00<0
05YF00000UYF1@000eYF00<005YFFUH015YF00<005YFFUH01`0037oo00<005YFFUH01EYF0P00FWoo
002>Ool01000FUIJEP000UYF00<007ooOol00Woo3@004Goo0`001eYF00<007ooOol0FGoo002>Ool0
1000FUIJEUYF0P008Goo0P000UYF00<005YFFUH00eYF0P00G7oo002>Ool01@00FUIJEUYF000087oo
0P001EYF00<005YFFUH00P00GWoo002?Ool00`00FUH0000NOol30007FUH3001POol008moo`03001J
EP0001]oo`<00003FUH005YF00MJEP03001oogoo061oo`00Sgoo0`0067oo0`0015YF00<005YFFUH0
15YF0P00Hgoo002@Ool01000FUH0000047oo1P0025YF00@005YFFUIJEP8006Eoo`00T7oo00@005YF
001JEP<000Eoo`P000AJEP03001JEUYF00MJEP04001JEP00001WOol0095oo`03001JEP0000=JEPD0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP<006Uoo`00TGoo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00K7oo002BOol30004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUH00002001_Ool009Aoo`<0009JEP03001JEUYF00EJEP03001JEUYF009JEPD0
079oo`00Ugoo3`00Mgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59813 .75278 m .59394 .69786 L .5628 .69798 L p .707 .577 .707 r
F P
0 g
s
.59394 .69786 m .59813 .75278 L .62986 .74963 L p .707 .577 .707 r
F P
0 g
s
.62986 .74963 m .62567 .69471 L .59394 .69786 L p .707 .577 .707 r
F P
0 g
s
.62567 .69471 m .62986 .74963 L .65907 .74378 L p .707 .577 .707 r
F P
0 g
s
.65907 .74378 m .65488 .68886 L .62567 .69471 L p .707 .577 .707 r
F P
0 g
s
.56699 .7529 m .5628 .69798 L .53529 .69507 L p .707 .577 .707 r
F P
0 g
s
.5628 .69798 m .56699 .7529 L .59813 .75278 L p .707 .577 .707 r
F P
0 g
s
.65488 .68886 m .65907 .74378 L .6829 .73578 L p .707 .577 .707 r
F P
0 g
s
.6829 .73578 m .67871 .68086 L .65488 .68886 L p .707 .577 .707 r
F P
0 g
s
.53948 .74999 m .53529 .69507 L .51411 .68941 L p .707 .577 .707 r
F P
0 g
s
.53529 .69507 m .53948 .74999 L .56699 .7529 L p .707 .577 .707 r
F P
0 g
s
.60202 .81757 m .5951 .78203 L .56439 .78496 L p .707 .577 .707 r
F P
0 g
s
.5951 .78203 m .60202 .81757 L .63332 .81112 L p .707 .577 .707 r
F P
0 g
s
.63332 .81112 m .6264 .77558 L .5951 .78203 L p .707 .577 .707 r
F P
0 g
s
.6264 .77558 m .63332 .81112 L .66213 .80178 L p .707 .577 .707 r
F P
0 g
s
.66213 .80178 m .65521 .76623 L .6264 .77558 L p .707 .577 .707 r
F P
0 g
s
.57131 .8205 m .56439 .78496 L .53726 .78407 L p .707 .577 .707 r
F P
0 g
s
.56439 .78496 m .57131 .8205 L .60202 .81757 L p .707 .577 .707 r
F P
0 g
s
.67871 .68086 m .6829 .73578 L .69902 .72643 L p .707 .577 .707 r
F P
0 g
s
.69902 .72643 m .69483 .6715 L .67871 .68086 L p .707 .577 .707 r
F P
0 g
s
.65521 .76623 m .66213 .80178 L .68563 .79045 L p .707 .577 .707 r
F P
0 g
s
.68563 .79045 m .67871 .75491 L .65521 .76623 L p .707 .577 .707 r
F P
0 g
s
.51411 .68941 m .5183 .74433 L .53948 .74999 L p .707 .577 .707 r
F P
0 g
s
.59745 .86019 m .59392 .84243 L .56331 .84532 L p .707 .577 .707 r
F P
0 g
s
.59392 .84243 m .59745 .86019 L .62876 .85376 L p .707 .577 .707 r
F P
0 g
s
.62876 .85376 m .62523 .83601 L .59392 .84243 L p .707 .577 .707 r
F P
0 g
s
.62523 .83601 m .62876 .85376 L .6577 .84442 L p .707 .577 .707 r
F P
0 g
s
.6577 .84442 m .65417 .82666 L .62523 .83601 L p .707 .577 .707 r
F P
0 g
s
.53726 .78407 m .54418 .81961 L .57131 .8205 L p .707 .577 .707 r
F P
0 g
s
.5183 .74433 m .51411 .68941 L .50133 .68155 L p .707 .577 .707 r
F P
0 g
s
.56331 .84532 m .56684 .86307 L .59745 .86019 L p .707 .577 .707 r
F P
0 g
s
.54418 .81961 m .53726 .78407 L .51637 .77946 L p .707 .577 .707 r
F P
0 g
s
.56684 .86307 m .56331 .84532 L .53639 .84437 L p .707 .577 .707 r
F P
0 g
s
.65417 .82666 m .6577 .84442 L .68144 .83307 L p .707 .577 .707 r
F P
0 g
s
.68144 .83307 m .67791 .81531 L .65417 .82666 L p .707 .577 .707 r
F P
0 g
s
.67871 .75491 m .68563 .79045 L .70154 .77826 L p .707 .577 .707 r
F P
0 g
s
.70154 .77826 m .69462 .74272 L .67871 .75491 L p .707 .577 .707 r
F P
0 g
s
.53639 .84437 m .53992 .86213 L .56684 .86307 L p .707 .577 .707 r
F P
0 g
s
.69483 .6715 m .69902 .72643 L .70585 .71663 L p .707 .577 .707 r
F P
0 g
s
.70585 .71663 m .70165 .66171 L .69483 .6715 L p .707 .577 .707 r
F P
0 g
s
.51637 .77946 m .5233 .815 L .54418 .81961 L p .707 .577 .707 r
F P
0 g
s
.50133 .68155 m .50552 .73647 L .5183 .74433 L p .707 .577 .707 r
F P
0 g
s
.53992 .86213 m .53639 .84437 L .5158 .83969 L p .707 .577 .707 r
F P
0 g
s
.67791 .81531 m .68144 .83307 L .69766 .82083 L p .707 .577 .707 r
F P
0 g
s
.69766 .82083 m .69413 .80307 L .67791 .81531 L p .707 .577 .707 r
F P
0 g
s
.5233 .815 m .51637 .77946 L .50377 .77158 L p .707 .577 .707 r
F P
0 g
s
.5158 .83969 m .51933 .85745 L .53992 .86213 L p .707 .577 .707 r
F P
0 g
s
.50552 .73647 m .50133 .68155 L .4982 .67227 L p .707 .577 .707 r
F P
0 g
s
.69462 .74272 m .70154 .77826 L .70828 .76639 L p .707 .577 .707 r
F P
0 g
s
.70828 .76639 m .70136 .73085 L .69462 .74272 L p .707 .577 .707 r
F P
0 g
s
.50377 .77158 m .5107 .80712 L .5233 .815 L p .707 .577 .707 r
F P
0 g
s
.70165 .66171 m .70585 .71663 L .70272 .70735 L p .707 .577 .707 r
F P
0 g
s
.70272 .70735 m .69853 .65243 L .70165 .66171 L p .707 .577 .707 r
F P
0 g
s
.51933 .85745 m .5158 .83969 L .50356 .83173 L p .707 .577 .707 r
F P
0 g
s
.4982 .67227 m .50239 .72719 L .50552 .73647 L p .707 .577 .707 r
F P
0 g
s
.69413 .80307 m .69766 .82083 L .70476 .8089 L p .707 .577 .707 r
F P
0 g
s
.70476 .8089 m .70124 .79114 L .69413 .80307 L p .707 .577 .707 r
F P
0 g
s
.50356 .83173 m .50709 .84949 L .51933 .85745 L p .707 .577 .707 r
F P
0 g
s
.5107 .80712 m .50377 .77158 L .50069 .7612 L p .707 .577 .707 r
F P
0 g
s
.48154 .8216 m .48154 .31972 L .43824 .31631 L p .707 .577 .707 r
F P
0 g
s
.50239 .72719 m .4982 .67227 L .50503 .66247 L p .707 .577 .707 r
F P
0 g
s
.50069 .7612 m .50762 .79674 L .5107 .80712 L p .707 .577 .707 r
F P
0 g
s
.50709 .84949 m .50356 .83173 L .50086 .82127 L p .707 .578 .707 r
F P
0 g
s
.50503 .66247 m .50922 .7174 L .50239 .72719 L p .707 .577 .707 r
F P
0 g
s
.50086 .82127 m .50439 .83903 L .50709 .84949 L p .707 .578 .707 r
F P
0 g
s
.50762 .79674 m .50069 .7612 L .50744 .74933 L p .707 .577 .707 r
F P
0 g
s
.50922 .7174 m .50503 .66247 L .52115 .65312 L p .707 .577 .707 r
F P
0 g
s
.50744 .74933 m .51436 .78487 L .50762 .79674 L p .707 .577 .707 r
F P
0 g
s
.50439 .83903 m .50086 .82127 L .50796 .80934 L p .707 .577 .707 r
F P
0 g
s
.52115 .65312 m .52534 .70804 L .50922 .7174 L p .707 .577 .707 r
F P
0 g
s
.50796 .80934 m .51149 .82709 L .50439 .83903 L p .707 .577 .707 r
F P
0 g
s
.51436 .78487 m .50744 .74933 L .52334 .73713 L p .707 .577 .707 r
F P
0 g
s
.52334 .73713 m .53026 .77267 L .51436 .78487 L p .707 .577 .707 r
F P
0 g
s
.51149 .82709 m .50796 .80934 L .52418 .7971 L p .707 .577 .707 r
F P
0 g
s
.52418 .7971 m .52771 .81485 L .51149 .82709 L p .707 .577 .707 r
F P
0 g
s
.52771 .81485 m .52418 .7971 L .54792 .78575 L p .707 .577 .707 r
F P
0 g
s
.48154 .31972 m .48154 .8216 L .52666 .82126 L p .707 .577 .707 r
F P
0 g
s
.52534 .70804 m .52115 .65312 L .54498 .64512 L p .707 .577 .707 r
F P
0 g
s
.54498 .64512 m .54917 .70004 L .52534 .70804 L p .707 .577 .707 r
F P
0 g
s
.53026 .77267 m .52334 .73713 L .54684 .72581 L p .707 .577 .707 r
F P
0 g
s
.52666 .82126 m .52666 .31937 L .48154 .31972 L p .707 .577 .707 r
F P
0 g
s
.54917 .70004 m .54498 .64512 L .57419 .63927 L p .707 .577 .707 r
F P
0 g
s
.57419 .63927 m .57838 .69419 L .54917 .70004 L p .707 .577 .707 r
F P
0 g
s
.54684 .72581 m .55377 .76135 L .53026 .77267 L p .707 .577 .707 r
F P
0 g
s
.55377 .76135 m .54684 .72581 L .57565 .71647 L p .707 .577 .707 r
F P
0 g
s
.54792 .78575 m .55145 .80351 L .52771 .81485 L p .707 .577 .707 r
F P
0 g
s
.57565 .71647 m .58258 .75201 L .55377 .76135 L p .707 .577 .707 r
F P
0 g
s
.55145 .80351 m .54792 .78575 L .57687 .7764 L p .707 .577 .707 r
F P
0 g
s
.57687 .7764 m .58039 .79416 L .55145 .80351 L p .707 .577 .707 r
F P
0 g
s
.52666 .31937 m .52666 .82126 L .56916 .81718 L p .707 .577 .707 r
F P
0 g
s
.56916 .81718 m .56916 .3153 L .52666 .31937 L p .707 .577 .707 r
F P
0 g
s
.70136 .73085 m .70828 .76639 L .7052 .75601 L p .707 .577 .707 r
F P
0 g
s
.7052 .75601 m .69828 .72046 L .70136 .73085 L p .707 .577 .707 r
F P
0 g
s
.43824 .8182 m .43824 .31631 L .40098 .30947 L p .707 .577 .707 r
F P
0 g
s
.43824 .31631 m .43824 .8182 L .48154 .8216 L p .707 .577 .707 r
F P
0 g
s
.57838 .69419 m .57419 .63927 L .60592 .63612 L p .707 .577 .707 r
F P
0 g
s
.60592 .63612 m .61011 .69104 L .57838 .69419 L p .707 .577 .707 r
F P
0 g
s
.58258 .75201 m .57565 .71647 L .60695 .71001 L p .707 .577 .707 r
F P
0 g
s
.60695 .71001 m .61387 .74556 L .58258 .75201 L p .707 .577 .707 r
F P
0 g
s
.58039 .79416 m .57687 .7764 L .60817 .76998 L p .707 .577 .707 r
F P
0 g
s
.60817 .76998 m .6117 .78773 L .58039 .79416 L p .707 .577 .707 r
F P
0 g
s
.56916 .3153 m .56916 .81718 L .60489 .80979 L p .707 .577 .707 r
F P
0 g
s
.60489 .80979 m .60489 .3079 L .56916 .3153 L p .707 .577 .707 r
F P
0 g
s
.69853 .65243 m .70272 .70735 L .68994 .69949 L p .707 .577 .707 r
F P
0 g
s
.68994 .69949 m .68575 .64457 L .69853 .65243 L p .707 .577 .707 r
F P
0 g
s
.70124 .79114 m .70476 .8089 L .70206 .79844 L p .707 .578 .707 r
F P
0 g
s
.70206 .79844 m .69853 .78068 L .70124 .79114 L p .707 .578 .707 r
F P
0 g
s
.2545 .70596 m .2527 .64943 L .22148 .64904 L p .707 .577 .707 r
F P
0 g
s
.2527 .64943 m .2545 .70596 L .2863 .70436 L p .707 .577 .707 r
F P
0 g
s
.2863 .70436 m .28449 .64783 L .2527 .64943 L p .707 .577 .707 r
F P
0 g
s
.28449 .64783 m .2863 .70436 L .31556 .70091 L p .707 .577 .707 r
F P
0 g
s
.31556 .70091 m .31375 .64439 L .28449 .64783 L p .707 .577 .707 r
F P
0 g
s
.69828 .72046 m .7052 .75601 L .6926 .74812 L p .707 .577 .707 r
F P
0 g
s
.6926 .74812 m .68568 .71258 L .69828 .72046 L p .707 .577 .707 r
F P
0 g
s
.40098 .81136 m .40098 .30947 L .37341 .29989 L p .707 .577 .707 r
F P
0 g
s
.40098 .30947 m .40098 .81136 L .43824 .8182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22329 .70556 m .22148 .64904 L .1939 .64669 L p .707 .577 .707 r
F P
0 g
s
.22148 .64904 m .22329 .70556 L .2545 .70596 L p .707 .577 .707 r
F P
0 g
s
.63706 .636 m .64125 .69092 L .61011 .69104 L p .707 .577 .707 r
F P
0 g
s
.61011 .69104 m .60592 .63612 L .63706 .636 L p .707 .577 .707 r
F P
0 g
s
.63766 .70709 m .64458 .74263 L .61387 .74556 L p .707 .577 .707 r
F P
0 g
s
.61387 .74556 m .60695 .71001 L .63766 .70709 L p .707 .577 .707 r
F P
0 g
s
.63878 .76709 m .64231 .78485 L .6117 .78773 L p .707 .577 .707 r
F P
0 g
s
.6117 .78773 m .60817 .76998 L .63878 .76709 L p .707 .577 .707 r
F P
0 g
s
.60489 .3079 m .60489 .80979 L .63035 .79979 L p .707 .577 .707 r
F P
0 g
s
.63035 .79979 m .63035 .2979 L .60489 .3079 L p .707 .577 .707 r
F P
0 g
s
.68575 .64457 m .68994 .69949 L .66876 .69383 L p .707 .577 .707 r
F P
0 g
s
.66876 .69383 m .66457 .63891 L .68575 .64457 L p .707 .577 .707 r
F P
0 g
s
.31375 .64439 m .31556 .70091 L .33942 .69597 L p .707 .577 .707 r
F P
0 g
s
.33942 .69597 m .33762 .63944 L .31375 .64439 L p .707 .577 .707 r
F P
0 g
s
.1939 .64669 m .19571 .70321 L .22329 .70556 L p .707 .577 .707 r
F P
0 g
s
.2566 .75655 m .2536 .71837 L .22243 .72018 L p .707 .577 .707 r
F P
0 g
s
.2536 .71837 m .2566 .75655 L .2883 .75377 L p .707 .577 .707 r
F P
0 g
s
.2883 .75377 m .28529 .71559 L .2536 .71837 L p .707 .577 .707 r
F P
0 g
s
.69853 .78068 m .70206 .79844 L .68982 .79048 L p .707 .577 .707 r
F P
0 g
s
.68982 .79048 m .68629 .77272 L .69853 .78068 L p .707 .577 .707 r
F P
0 g
s
.28529 .71559 m .2883 .75377 L .31743 .7503 L p .707 .577 .707 r
F P
0 g
s
.31743 .7503 m .31443 .71212 L .28529 .71559 L p .707 .577 .707 r
F P
0 g
s
.19571 .70321 m .1939 .64669 L .17266 .64261 L p .707 .577 .707 r
F P
0 g
s
.22243 .72018 m .22544 .75836 L .2566 .75655 L p .707 .577 .707 r
F P
0 g
s
.22544 .75836 m .22243 .72018 L .19485 .72085 L p .707 .577 .707 r
F P
0 g
s
.19485 .72085 m .19786 .75903 L .22544 .75836 L p .707 .577 .707 r
F P
0 g
s
.68568 .71258 m .6926 .74812 L .67171 .74351 L p .707 .577 .707 r
F P
0 g
s
.67171 .74351 m .66479 .70797 L .68568 .71258 L p .707 .577 .707 r
F P
0 g
s
.17266 .64261 m .17446 .69913 L .19571 .70321 L p .707 .577 .707 r
F P
0 g
s
.31443 .71212 m .31743 .7503 L .34114 .74647 L p .707 .577 .707 r
F P
0 g
s
.34114 .74647 m .33814 .70829 L .31443 .71212 L p .707 .577 .707 r
F P
0 g
s
.33762 .63944 m .33942 .69597 L .35555 .69001 L p .707 .577 .707 r
F P
0 g
s
.35555 .69001 m .35375 .63348 L .33762 .63944 L p .707 .577 .707 r
F P
0 g
s
.25396 .79718 m .25243 .77808 L .22135 .77993 L p .707 .577 .707 r
F P
0 g
s
.25243 .77808 m .25396 .79718 L .28569 .79441 L p .707 .577 .707 r
F P
0 g
s
.28569 .79441 m .28417 .77532 L .25243 .77808 L p .707 .577 .707 r
F P
0 g
s
.66457 .63891 m .66876 .69383 L .64125 .69092 L p .707 .577 .707 r
F P
0 g
s
.64125 .69092 m .63706 .636 L .66457 .63891 L p .707 .577 .707 r
F P
0 g
s
.22135 .77993 m .22288 .79903 L .25396 .79718 L p .707 .577 .707 r
F P
0 g
s
.28417 .77532 m .28569 .79441 L .31497 .791 L p .707 .577 .707 r
F P
0 g
s
.31497 .791 m .31344 .7719 L .28417 .77532 L p .707 .577 .707 r
F P
0 g
s
.37341 .80178 m .37341 .29989 L .35824 .28848 L p .707 .577 .707 r
F P
0 g
s
.37341 .29989 m .37341 .80178 L .40098 .81136 L p .707 .577 .707 r
F P
0 g
s
.19786 .75903 m .19485 .72085 L .17356 .72031 L p .707 .577 .707 r
F P
0 g
s
.22288 .79903 m .22135 .77993 L .19397 .78068 L p .707 .577 .707 r
F P
0 g
s
.19397 .78068 m .19549 .79978 L .22288 .79903 L p .707 .577 .707 r
F P
0 g
s
.17356 .72031 m .17657 .75849 L .19786 .75903 L p .707 .577 .707 r
F P
0 g
s
.17446 .69913 m .17266 .64261 L .15982 .6372 L p .707 .577 .707 r
F P
0 g
s
.64458 .74263 m .63766 .70709 L .66479 .70797 L p .707 .577 .707 r
F P
0 g
s
.6657 .76804 m .66923 .7858 L .64231 .78485 L p .707 .577 .707 r
F P
0 g
s
.64231 .78485 m .63878 .76709 L .6657 .76804 L p .707 .577 .707 r
F P
0 g
s
.63035 .2979 m .63035 .79979 L .64306 .78817 L p .707 .577 .707 r
F P
0 g
s
.64306 .78817 m .64306 .28628 L .63035 .2979 L p .707 .577 .707 r
F P
0 g
s
.68629 .77272 m .68982 .79048 L .66923 .7858 L p .707 .577 .707 r
F P
0 g
s
.66923 .7858 m .6657 .76804 L .68629 .77272 L p .707 .577 .707 r
F P
0 g
s
.31344 .7719 m .31497 .791 L .33893 .78726 L p .707 .577 .707 r
F P
0 g
s
.33893 .78726 m .3374 .76816 L .31344 .7719 L p .707 .577 .707 r
F P
0 g
s
.33814 .70829 m .34114 .74647 L .35712 .74266 L p .707 .577 .707 r
F P
0 g
s
.35712 .74266 m .35411 .70448 L .33814 .70829 L p .707 .577 .707 r
F P
0 g
s
.66479 .70797 m .67171 .74351 L .64458 .74263 L p .707 .577 .707 r
F P
0 g
s
.15982 .6372 m .16163 .69372 L .17446 .69913 L p .707 .577 .707 r
F P
0 g
s
.19549 .79978 m .19397 .78068 L .17295 .78025 L p .707 .577 .707 r
F P
0 g
s
.17295 .78025 m .17448 .79935 L .19549 .79978 L p .707 .577 .707 r
F P
0 g
s
.35375 .63348 m .35555 .69001 L .36237 .68361 L p .707 .577 .707 r
F P
0 g
s
.36237 .68361 m .36057 .62708 L .35375 .63348 L p .707 .577 .707 r
F P
0 g
s
.17657 .75849 m .17356 .72031 L .16064 .71861 L p .707 .577 .707 r
F P
0 g
s
.16064 .71861 m .16365 .75679 L .17657 .75849 L p .707 .577 .707 r
F P
0 g
s
.3374 .76816 m .33893 .78726 L .35522 .78358 L p .707 .577 .707 r
F P
0 g
s
.35522 .78358 m .35369 .76448 L .3374 .76816 L p .707 .577 .707 r
F P
0 g
s
.16163 .69372 m .15982 .6372 L .15666 .63099 L p .707 .577 .707 r
F P
0 g
s
.35411 .70448 m .35712 .74266 L .36106 .74065 L p .707 .577 .707 r
F P
0 g
s
.36106 .74065 m .36379 .73925 L p .3609 .72887 L .707 .577 .707 r
F P
0 g
s
.3609 .72887 m .35411 .70448 L .36106 .74065 L .707 .577 .707 r
F
.35824 .28848 m .35694 .27638 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36379 .73925 m .36078 .70107 L .35411 .70448 L p .707 .577 .707 r
F P
0 g
s
.35921 .6774 m .3574 .62087 L .36057 .62708 L p .707 .577 .707 r
F P
0 g
s
.35369 .76448 m .35522 .78358 L .36081 .78098 L p .707 .577 .707 r
F P
0 g
s
.36081 .78098 m .36225 .78031 L p .36076 .77756 L .707 .577 .707 r
F P
0 g
s
.36076 .77756 m .35369 .76448 L .36081 .78098 L .707 .577 .707 r
F
.36225 .78031 m .36073 .76121 L .35369 .76448 L p F P
0 g
s
.3605 .73656 m .35974 .72693 L p .36078 .70107 L .707 .577 .707 r
F P
0 g
s
.35974 .72693 m .3575 .69838 L .36039 .70074 L p .707 .577 .707 r
F P
0 g
s
.36039 .70074 m .36078 .70107 L p .35974 .72693 L .707 .577 .707 r
F P
0 g
s
.3574 .62087 m .35921 .6774 L .34638 .67199 L p .707 .577 .707 r
F P
0 g
s
.35933 .77777 m .35781 .75867 L .36073 .76121 L p .707 .577 .707 r
F P
0 g
s
.3575 .69838 m .3605 .73656 L .34758 .73486 L p .707 .577 .707 r
F P
0 g
s
.35781 .75867 m .35933 .77777 L .34675 .77621 L p .707 .577 .707 r
F P
0 g
s
.35823 .7883 m .35824 .52952 L .35742 .46859 L .707 .578 .707 r
F
.35824 .79037 m .35824 .78808 L p .35823 .7883 L F P
0 g
s
.35824 .78808 m .35824 .52952 L p .35823 .7883 L .707 .578 .707 r
F P
0 g
s
.34638 .67199 m .34457 .61546 L .3574 .62087 L p .707 .577 .707 r
F P
0 g
s
.34758 .73486 m .34458 .69668 L .3575 .69838 L p .707 .577 .707 r
F P
0 g
s
.34675 .77621 m .34523 .75711 L .35781 .75867 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35824 .79037 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .27638 m .35694 .48851 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .48851 m .35694 .77827 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35824 .52952 m .35824 .28848 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36057 .62708 m .36237 .68361 L .35921 .6774 L p .707 .577 .707 r
F P
0 g
s
.36078 .70107 m .36379 .73925 L .3605 .73656 L p .707 .577 .707 r
F P
0 g
s
.36073 .76121 m .36225 .78031 L .35933 .77777 L p .707 .577 .707 r
F P
0 g
s
.35824 .28848 m .35824 .79037 L .37341 .80178 L p .707 .577 .707 r
F P
0 g
s
.17448 .79935 m .17295 .78025 L .16037 .77869 L p .707 .577 .707 r
F P
0 g
s
.16037 .77869 m .1619 .79779 L .17448 .79935 L p .707 .577 .707 r
F P
0 g
s
.15666 .63099 m .15847 .68752 L .16163 .69372 L p .707 .577 .707 r
F P
0 g
s
.64306 .28628 m .64306 .78817 L .64176 .77607 L p .707 .578 .707 r
F P
0 g
s
.64176 .77607 m .64176 .27418 L .64306 .28628 L p .707 .578 .707 r
F P
0 g
s
.16365 .75679 m .16064 .71861 L .15735 .71592 L p .707 .577 .707 r
F P
0 g
s
.15735 .71592 m .16036 .7541 L .16365 .75679 L p .707 .577 .707 r
F P
0 g
s
.15847 .68752 m .15666 .63099 L .16348 .62459 L p .707 .577 .707 r
F P
0 g
s
.1619 .79779 m .16037 .77869 L .15746 .77616 L p .707 .577 .707 r
F P
0 g
s
.15746 .77616 m .15898 .79526 L .1619 .79779 L p .707 .577 .707 r
F P
0 g
s
.16348 .62459 m .16528 .68112 L .15847 .68752 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35694 .27638 L .36964 .26476 L p .707 .577 .707 r
F P
0 g
s
.16036 .7541 m .15735 .71592 L .16402 .71251 L p .707 .577 .707 r
F P
0 g
s
.16402 .71251 m .16703 .75069 L .16036 .7541 L p .707 .577 .707 r
F P
0 g
s
.64176 .27418 m .64176 .77607 L .62658 .76466 L p .707 .577 .707 r
F P
0 g
s
.62658 .76466 m .62658 .26277 L .64176 .27418 L p .707 .577 .707 r
F P
0 g
s
.16528 .68112 m .16348 .62459 L .17961 .61863 L p .707 .577 .707 r
F P
0 g
s
.15898 .79526 m .15746 .77616 L .16449 .77289 L p .707 .577 .707 r
F P
0 g
s
.16449 .77289 m .16601 .79199 L .15898 .79526 L p .707 .577 .707 r
F P
0 g
s
.17961 .61863 m .18141 .67515 L .16528 .68112 L p .707 .577 .707 r
F P
0 g
s
.34457 .61546 m .34638 .67199 L .32513 .66791 L p .707 .577 .707 r
F P
0 g
s
.32513 .66791 m .32333 .61138 L .34457 .61546 L p .707 .577 .707 r
F P
0 g
s
.16703 .75069 m .16402 .71251 L .18 .7087 L p .707 .577 .707 r
F P
0 g
s
.18 .7087 m .183 .74688 L .16703 .75069 L p .707 .577 .707 r
F P
0 g
s
.18141 .67515 m .17961 .61863 L .20347 .61368 L p .707 .577 .707 r
F P
0 g
s
.36964 .76665 m .36964 .26476 L .39511 .25476 L p .707 .577 .707 r
F P
0 g
s
.36964 .26476 m .36964 .76665 L .35694 .77827 L p .707 .577 .707 r
F P
0 g
s
.62658 .26277 m .62658 .76466 L .59902 .75507 L p .707 .577 .707 r
F P
0 g
s
.59902 .75507 m .59902 .25318 L .62658 .26277 L p .707 .577 .707 r
F P
0 g
s
.20347 .61368 m .20528 .67021 L .18141 .67515 L p .707 .577 .707 r
F P
0 g
s
.34458 .69668 m .34758 .73486 L .32629 .73432 L p .707 .577 .707 r
F P
0 g
s
.32629 .73432 m .32328 .69614 L .34458 .69668 L p .707 .577 .707 r
F P
0 g
s
.16601 .79199 m .16449 .77289 L .18078 .7692 L p .707 .577 .707 r
F P
0 g
s
.32333 .61138 m .32513 .66791 L .29755 .66556 L p .707 .577 .707 r
F P
0 g
s
.29755 .66556 m .29574 .60903 L .32333 .61138 L p .707 .577 .707 r
F P
0 g
s
.18078 .7692 m .1823 .7883 L .16601 .79199 L p .707 .577 .707 r
F P
0 g
s
.20528 .67021 m .20347 .61368 L .23273 .61024 L p .707 .577 .707 r
F P
0 g
s
.183 .74688 m .18 .7087 L .20371 .70487 L p .707 .577 .707 r
F P
0 g
s
.20371 .70487 m .20672 .74305 L .183 .74688 L p .707 .577 .707 r
F P
0 g
s
.34523 .75711 m .34675 .77621 L .32574 .77579 L p .707 .577 .707 r
F P
0 g
s
.32574 .77579 m .32422 .75669 L .34523 .75711 L p .707 .577 .707 r
F P
0 g
s
.29574 .60903 m .29755 .66556 L .26633 .66516 L p .707 .577 .707 r
F P
0 g
s
.26633 .66516 m .26453 .60864 L .29574 .60903 L p .707 .577 .707 r
F P
0 g
s
.23273 .61024 m .23454 .66677 L .20528 .67021 L p .707 .577 .707 r
F P
0 g
s
.73366 .6639 m .73547 .60961 L .70425 .60639 L p .707 .577 .707 r
F P
0 g
s
.73547 .60961 m .73366 .6639 L .76546 .66377 L p .707 .577 .707 r
F P
0 g
s
.76546 .66377 m .76726 .60948 L .73547 .60961 L p .707 .577 .707 r
F P
0 g
s
.23454 .66677 m .23273 .61024 L .26453 .60864 L p .707 .577 .707 r
F P
0 g
s
.32328 .69614 m .32629 .73432 L .29871 .73499 L p .707 .577 .707 r
F P
0 g
s
.29871 .73499 m .29571 .69681 L .32328 .69614 L p .707 .577 .707 r
F P
0 g
s
.76726 .60948 m .76546 .66377 L .79472 .66031 L p .707 .577 .707 r
F P
0 g
s
.79472 .66031 m .79652 .60601 L .76726 .60948 L p .707 .577 .707 r
F P
0 g
s
.26453 .60864 m .26633 .66516 L .23454 .66677 L p .707 .577 .707 r
F P
0 g
s
.39511 .25476 m .39511 .75665 L .36964 .76665 L p .707 .577 .707 r
F P
0 g
s
.39511 .75665 m .39511 .25476 L .43084 .24736 L p .707 .577 .707 r
F P
0 g
s
.70245 .66068 m .70425 .60639 L .67667 .60013 L p .707 .577 .707 r
F P
0 g
s
.70425 .60639 m .70245 .66068 L .73366 .6639 L p .707 .577 .707 r
F P
0 g
s
.1823 .7883 m .18078 .7692 L .20474 .76547 L p .707 .577 .707 r
F P
0 g
s
.20474 .76547 m .20626 .78457 L .1823 .7883 L p .707 .577 .707 r
F P
0 g
s
.20672 .74305 m .20371 .70487 L .23284 .7014 L p .707 .577 .707 r
F P
0 g
s
.59902 .25318 m .59902 .75507 L .56176 .74824 L p .707 .577 .707 r
F P
0 g
s
.56176 .74824 m .56176 .24635 L .59902 .25318 L p .707 .577 .707 r
F P
0 g
s
.23284 .7014 m .23585 .73958 L .20672 .74305 L p .707 .577 .707 r
F P
0 g
s
.79652 .60601 m .79472 .66031 L .81858 .65384 L p .707 .577 .707 r
F P
0 g
s
.81858 .65384 m .82039 .59955 L .79652 .60601 L p .707 .577 .707 r
F P
0 g
s
.32422 .75669 m .32574 .77579 L .29835 .77654 L p .707 .577 .707 r
F P
0 g
s
.29835 .77654 m .29683 .75744 L .32422 .75669 L p .707 .577 .707 r
F P
0 g
s
.29571 .69681 m .29871 .73499 L .26755 .7368 L p .707 .577 .707 r
F P
0 g
s
.26755 .7368 m .26454 .69862 L .29571 .69681 L p .707 .577 .707 r
F P
0 g
s
.67487 .65443 m .67667 .60013 L .65543 .59146 L p .707 .577 .707 r
F P
0 g
s
.67667 .60013 m .67487 .65443 L .70245 .66068 L p .707 .577 .707 r
F P
0 g
s
.23585 .73958 m .23284 .7014 L .26454 .69862 L p .707 .577 .707 r
F P
0 g
s
.26454 .69862 m .26755 .7368 L .23585 .73958 L p .707 .577 .707 r
F P
0 g
s
.73245 .73282 m .73545 .6983 L .70429 .69319 L p .707 .577 .707 r
F P
0 g
s
.73545 .6983 m .73245 .73282 L .76415 .73362 L p .707 .577 .707 r
F P
0 g
s
.76415 .73362 m .76715 .6991 L .73545 .6983 L p .707 .577 .707 r
F P
0 g
s
.20626 .78457 m .20474 .76547 L .23401 .76205 L p .707 .577 .707 r
F P
0 g
s
.23401 .76205 m .23554 .78115 L .20626 .78457 L p .707 .577 .707 r
F P
0 g
s
.76715 .6991 m .76415 .73362 L .79328 .73003 L p .707 .577 .707 r
F P
0 g
s
.79328 .73003 m .79629 .69551 L .76715 .6991 L p .707 .577 .707 r
F P
0 g
s
.70129 .72771 m .70429 .69319 L .67671 .68426 L p .707 .577 .707 r
F P
0 g
s
.70429 .69319 m .70129 .72771 L .73245 .73282 L p .707 .577 .707 r
F P
0 g
s
.43084 .74925 m .43084 .24736 L .47334 .24329 L p .707 .577 .707 r
F P
0 g
s
.43084 .24736 m .43084 .74925 L .39511 .75665 L p .707 .577 .707 r
F P
0 g
s
.29683 .75744 m .29835 .77654 L .26727 .77838 L p .707 .577 .707 r
F P
0 g
s
.26727 .77838 m .26575 .75928 L .29683 .75744 L p .707 .577 .707 r
F P
0 g
s
.82039 .59955 m .81858 .65384 L .83471 .64502 L p .707 .577 .707 r
F P
0 g
s
.83471 .64502 m .83652 .59072 L .82039 .59955 L p .707 .577 .707 r
F P
0 g
s
.56176 .24635 m .56176 .74824 L .51845 .74483 L p .707 .577 .707 r
F P
0 g
s
.51845 .74483 m .51845 .24294 L .56176 .24635 L p .707 .577 .707 r
F P
0 g
s
.23554 .78115 m .23401 .76205 L .26575 .75928 L p .707 .577 .707 r
F P
0 g
s
.65543 .59146 m .65362 .64576 L .67487 .65443 L p .707 .577 .707 r
F P
0 g
s
.26575 .75928 m .26727 .77838 L .23554 .78115 L p .707 .577 .707 r
F P
0 g
s
.65362 .64576 m .65543 .59146 L .64259 .58121 L p .707 .577 .707 r
F P
0 g
s
.79629 .69551 m .79328 .73003 L .817 .7224 L p .707 .577 .707 r
F P
0 g
s
.817 .7224 m .82 .68788 L .79629 .69551 L p .707 .577 .707 r
F P
0 g
s
.73273 .7761 m .73425 .75889 L .70317 .75357 L p .707 .577 .707 r
F P
0 g
s
.73425 .75889 m .73273 .7761 L .76446 .77708 L p .707 .577 .707 r
F P
0 g
s
.76446 .77708 m .76598 .75987 L .73425 .75889 L p .707 .577 .707 r
F P
0 g
s
.67371 .71878 m .67671 .68426 L .65542 .6724 L p .707 .577 .707 r
F P
0 g
s
.67671 .68426 m .67371 .71878 L .70129 .72771 L p .707 .577 .707 r
F P
0 g
s
.47334 .74518 m .47334 .24329 L .51845 .24294 L p .707 .577 .707 r
F P
0 g
s
.47334 .24329 m .47334 .74518 L .43084 .74925 L p .707 .577 .707 r
F P
0 g
s
.76598 .75987 m .76446 .77708 L .79374 .77361 L p .707 .577 .707 r
F P
0 g
s
.79374 .77361 m .79526 .7564 L .76598 .75987 L p .707 .577 .707 r
F P
0 g
s
.51845 .24294 m .51845 .74483 L .47334 .74518 L p .707 .577 .707 r
F P
0 g
s
.70164 .77078 m .70317 .75357 L .67578 .74441 L p .707 .577 .707 r
F P
0 g
s
.70317 .75357 m .70164 .77078 L .73273 .7761 L p .707 .577 .707 r
F P
0 g
s
.67578 .74441 m .67426 .76162 L .70164 .77078 L p .707 .577 .707 r
F P
0 g
s
.79526 .7564 m .79374 .77361 L .81769 .76604 L p .707 .577 .707 r
F P
0 g
s
.81769 .76604 m .81922 .74882 L .79526 .7564 L p .707 .577 .707 r
F P
0 g
s
.83652 .59072 m .83471 .64502 L .84153 .63469 L p .707 .577 .707 r
F P
0 g
s
.84153 .63469 m .84334 .5804 L .83652 .59072 L p .707 .577 .707 r
F P
0 g
s
.65542 .6724 m .65242 .70692 L .67371 .71878 L p .707 .577 .707 r
F P
0 g
s
.64259 .58121 m .64079 .63551 L .65362 .64576 L p .707 .577 .707 r
F P
0 g
s
.67426 .76162 m .67578 .74441 L .65477 .73232 L p .707 .577 .707 r
F P
0 g
s
.82 .68788 m .817 .7224 L .83297 .71148 L p .707 .577 .707 r
F P
0 g
s
.83297 .71148 m .83597 .67696 L .82 .68788 L p .707 .577 .707 r
F P
0 g
s
.65242 .70692 m .65542 .6724 L .6425 .65877 L p .707 .577 .707 r
F P
0 g
s
.64079 .63551 m .64259 .58121 L .63943 .5704 L p .707 .577 .707 r
F P
0 g
s
.65477 .73232 m .65325 .74953 L .67426 .76162 L p .707 .577 .707 r
F P
0 g
s
.81922 .74882 m .81769 .76604 L .83399 .7551 L p .707 .577 .707 r
F P
0 g
s
.83399 .7551 m .83551 .73789 L .81922 .74882 L p .707 .577 .707 r
F P
0 g
s
.6425 .65877 m .6395 .69329 L .65242 .70692 L p .707 .577 .707 r
F P
0 g
s
.65325 .74953 m .65477 .73232 L .64219 .71849 L p .707 .577 .707 r
F P
0 g
s
.83597 .67696 m .83297 .71148 L .83964 .69834 L p .707 .577 .707 r
F P
0 g
s
.83964 .69834 m .84264 .66382 L .83597 .67696 L p .707 .577 .707 r
F P
0 g
s
.63943 .5704 m .63763 .62469 L .64079 .63551 L p .707 .577 .707 r
F P
0 g
s
.84334 .5804 m .84153 .63469 L .83837 .62388 L p .707 .577 .707 r
F P
0 g
s
.83837 .62388 m .84017 .56958 L .84334 .5804 L p .707 .577 .707 r
F P
0 g
s
.6395 .69329 m .6425 .65877 L .63921 .64469 L p .707 .577 .707 r
F P
0 g
s
.64219 .71849 m .64067 .7357 L .65325 .74953 L p .707 .577 .707 r
F P
0 g
s
.63763 .62469 m .63943 .5704 L .64625 .56007 L p .707 .577 .707 r
F P
0 g
s
.83551 .73789 m .83399 .7551 L .84102 .74186 L p .707 .577 .707 r
F P
0 g
s
.84102 .74186 m .84254 .72465 L .83551 .73789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63921 .64469 m .63621 .67921 L .6395 .69329 L p .707 .577 .707 r
F P
0 g
s
.64067 .7357 m .64219 .71849 L .63927 .70426 L p .707 .577 .707 r
F P
0 g
s
.84264 .66382 m .83964 .69834 L .83635 .68426 L p .707 .577 .707 r
F P
0 g
s
.83635 .68426 m .83936 .64974 L .84264 .66382 L p .707 .577 .707 r
F P
0 g
s
.63927 .70426 m .63775 .72147 L .64067 .7357 L p .707 .577 .707 r
F P
0 g
s
.64625 .56007 m .64444 .61437 L .63763 .62469 L p .707 .577 .707 r
F P
0 g
s
.63621 .67921 m .63921 .64469 L .64588 .63154 L p .707 .577 .707 r
F P
0 g
s
.84017 .56958 m .83837 .62388 L .82554 .61363 L p .707 .577 .707 r
F P
0 g
s
.82554 .61363 m .82734 .55934 L .84017 .56958 L p .707 .577 .707 r
F P
0 g
s
.64444 .61437 m .64625 .56007 L .66238 .55125 L p .707 .577 .707 r
F P
0 g
s
.38989 .61718 m .39408 .56128 L .36294 .55745 L p .707 .577 .707 r
F P
0 g
s
.39408 .56128 m .38989 .61718 L .42162 .61868 L p .707 .577 .707 r
F P
0 g
s
.42162 .61868 m .42581 .56278 L .39408 .56128 L p .707 .577 .707 r
F P
0 g
s
.84254 .72465 m .84102 .74186 L .8381 .72763 L p .707 .577 .707 r
F P
0 g
s
.8381 .72763 m .83962 .71042 L .84254 .72465 L p .707 .577 .707 r
F P
0 g
s
.42581 .56278 m .42162 .61868 L .45083 .6177 L p .707 .577 .707 r
F P
0 g
s
.45083 .6177 m .45502 .5618 L .42581 .56278 L p .707 .577 .707 r
F P
0 g
s
.64588 .63154 m .64288 .66606 L .63621 .67921 L p .707 .577 .707 r
F P
0 g
s
.63775 .72147 m .63927 .70426 L .6463 .69102 L p .707 .577 .707 r
F P
0 g
s
.35875 .61334 m .36294 .55745 L .33543 .55166 L p .707 .577 .707 r
F P
0 g
s
.36294 .55745 m .35875 .61334 L .38989 .61718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83936 .64974 m .83635 .68426 L .82343 .67062 L p .707 .577 .707 r
F P
0 g
s
.82343 .67062 m .82644 .6361 L .83936 .64974 L p .707 .577 .707 r
F P
0 g
s
.6463 .69102 m .64478 .70823 L .63775 .72147 L p .707 .577 .707 r
F P
0 g
s
.82734 .55934 m .82554 .61363 L .80429 .60496 L p .707 .577 .707 r
F P
0 g
s
.80429 .60496 m .8061 .55066 L .82734 .55934 L p .707 .577 .707 r
F P
0 g
s
.64288 .66606 m .64588 .63154 L .66186 .62062 L p .707 .577 .707 r
F P
0 g
s
.66238 .55125 m .66057 .60554 L .64444 .61437 L p .707 .577 .707 r
F P
0 g
s
.45502 .5618 m .45083 .6177 L .47466 .61433 L p .707 .577 .707 r
F P
0 g
s
.47466 .61433 m .47885 .55844 L .45502 .5618 L p .707 .577 .707 r
F P
0 g
s
.33543 .55166 m .33124 .60755 L .35875 .61334 L p .707 .577 .707 r
F P
0 g
s
.38613 .67239 m .39305 .63525 L .36233 .62842 L p .707 .577 .707 r
F P
0 g
s
.39305 .63525 m .38613 .67239 L .41742 .6774 L p .707 .577 .707 r
F P
0 g
s
.41742 .6774 m .42434 .64027 L .39305 .63525 L p .707 .577 .707 r
F P
0 g
s
.33124 .60755 m .33543 .55166 L .31425 .54448 L p .707 .577 .707 r
F P
0 g
s
.66057 .60554 m .66238 .55125 L .68624 .54479 L p .707 .577 .707 r
F P
0 g
s
.42434 .64027 m .41742 .6774 L .44623 .68012 L p .707 .577 .707 r
F P
0 g
s
.44623 .68012 m .45315 .64298 L .42434 .64027 L p .707 .577 .707 r
F P
0 g
s
.35541 .66556 m .36233 .62842 L .33521 .62045 L p .707 .577 .707 r
F P
0 g
s
.36233 .62842 m .35541 .66556 L .38613 .67239 L p .707 .577 .707 r
F P
0 g
s
.83962 .71042 m .8381 .72763 L .82552 .7138 L p .707 .577 .707 r
F P
0 g
s
.82552 .7138 m .82704 .69658 L .83962 .71042 L p .707 .577 .707 r
F P
0 g
s
.66186 .62062 m .65885 .65514 L .64288 .66606 L p .707 .577 .707 r
F P
0 g
s
.33521 .62045 m .32828 .65758 L .35541 .66556 L p .707 .577 .707 r
F P
0 g
s
.64478 .70823 m .6463 .69102 L .6626 .68008 L p .707 .577 .707 r
F P
0 g
s
.31425 .54448 m .31006 .60037 L .33124 .60755 L p .707 .577 .707 r
F P
0 g
s
.3883 .71373 m .39182 .69517 L .36121 .68818 L p .707 .577 .707 r
F P
0 g
s
.39182 .69517 m .3883 .71373 L .41961 .71893 L p .707 .577 .707 r
F P
0 g
s
.41961 .71893 m .42313 .70037 L .39182 .69517 L p .707 .577 .707 r
F P
0 g
s
.47885 .55844 m .47466 .61433 L .49077 .60891 L p .707 .577 .707 r
F P
0 g
s
.49077 .60891 m .49497 .55302 L .47885 .55844 L p .707 .577 .707 r
F P
0 g
s
.8061 .55066 m .80429 .60496 L .77671 .59871 L p .707 .577 .707 r
F P
0 g
s
.77671 .59871 m .77852 .54441 L .8061 .55066 L p .707 .577 .707 r
F P
0 g
s
.45315 .64298 m .44623 .68012 L .46974 .68026 L p .707 .577 .707 r
F P
0 g
s
.46974 .68026 m .47666 .64313 L .45315 .64298 L p .707 .577 .707 r
F P
0 g
s
.82644 .6361 m .82343 .67062 L .80214 .65876 L p .707 .577 .707 r
F P
0 g
s
.80214 .65876 m .80514 .62424 L .82644 .6361 L p .707 .577 .707 r
F P
0 g
s
.36121 .68818 m .35769 .70674 L .3883 .71373 L p .707 .577 .707 r
F P
0 g
s
.32828 .65758 m .33521 .62045 L .31432 .61211 L p .707 .577 .707 r
F P
0 g
s
.42313 .70037 m .41961 .71893 L .44855 .72184 L p .707 .577 .707 r
F P
0 g
s
.44855 .72184 m .45207 .70328 L .42313 .70037 L p .707 .577 .707 r
F P
0 g
s
.65885 .65514 m .66186 .62062 L .68557 .613 L p .707 .577 .707 r
F P
0 g
s
.6626 .68008 m .66107 .69729 L .64478 .70823 L p .707 .577 .707 r
F P
0 g
s
.68624 .54479 m .68444 .59908 L .66057 .60554 L p .707 .577 .707 r
F P
0 g
s
.35769 .70674 m .36121 .68818 L .3343 .68009 L p .707 .577 .707 r
F P
0 g
s
.68444 .59908 m .68624 .54479 L .71551 .54132 L p .707 .577 .707 r
F P
0 g
s
.31006 .60037 m .31425 .54448 L .30147 .53661 L p .707 .577 .707 r
F P
0 g
s
.3343 .68009 m .33077 .69865 L .35769 .70674 L p .707 .577 .707 r
F P
0 g
s
.31432 .61211 m .3074 .64925 L .32828 .65758 L p .707 .577 .707 r
F P
0 g
s
.77852 .54441 m .77671 .59871 L .74549 .59549 L p .707 .577 .707 r
F P
0 g
s
.74549 .59549 m .7473 .54119 L .77852 .54441 L p .707 .577 .707 r
F P
0 g
s
.45207 .70328 m .44855 .72184 L .47229 .72217 L p .707 .577 .707 r
F P
0 g
s
.47229 .72217 m .47582 .70361 L .45207 .70328 L p .707 .577 .707 r
F P
0 g
s
.82704 .69658 m .82552 .7138 L .80451 .70171 L p .707 .577 .707 r
F P
0 g
s
.80451 .70171 m .80603 .6845 L .82704 .69658 L p .707 .577 .707 r
F P
0 g
s
.7137 .59562 m .71551 .54132 L .7473 .54119 L p .707 .577 .707 r
F P
0 g
s
.71551 .54132 m .7137 .59562 L .68444 .59908 L p .707 .577 .707 r
F P
0 g
s
.30147 .53661 m .29728 .5925 L .31006 .60037 L p .707 .577 .707 r
F P
0 g
s
.68557 .613 m .68257 .64752 L .65885 .65514 L p .707 .577 .707 r
F P
0 g
s
.33077 .69865 m .3343 .68009 L .31371 .67169 L p .707 .577 .707 r
F P
0 g
s
.66107 .69729 m .6626 .68008 L .68655 .67251 L p .707 .577 .707 r
F P
0 g
s
.7473 .54119 m .74549 .59549 L .7137 .59562 L p .707 .577 .707 r
F P
0 g
s
.80514 .62424 m .80214 .65876 L .77456 .64984 L p .707 .577 .707 r
F P
0 g
s
.77456 .64984 m .77757 .61532 L .80514 .62424 L p .707 .577 .707 r
F P
0 g
s
.47666 .64313 m .46974 .68026 L .48564 .67782 L p .707 .577 .707 r
F P
0 g
s
.48564 .67782 m .49256 .64069 L .47666 .64313 L p .707 .577 .707 r
F P
0 g
s
.68257 .64752 m .68557 .613 L .7147 .60941 L p .707 .577 .707 r
F P
0 g
s
.31371 .67169 m .31018 .69025 L .33077 .69865 L p .707 .577 .707 r
F P
0 g
s
.3074 .64925 m .31432 .61211 L .30172 .60423 L p .707 .577 .707 r
F P
0 g
s
.49497 .55302 m .49077 .60891 L .4976 .60197 L p .707 .577 .707 r
F P
0 g
s
.4976 .60197 m .5018 .54607 L .49497 .55302 L p .707 .577 .707 r
F P
0 g
s
.68655 .67251 m .68503 .68972 L .66107 .69729 L p .707 .577 .707 r
F P
0 g
s
.30172 .60423 m .2948 .64136 L .3074 .64925 L p .707 .577 .707 r
F P
0 g
s
.29728 .5925 m .30147 .53661 L .29834 .52882 L p .707 .577 .707 r
F P
0 g
s
.77757 .61532 m .77456 .64984 L .7434 .64473 L p .707 .577 .707 r
F P
0 g
s
.7434 .64473 m .7464 .61021 L .77757 .61532 L p .707 .577 .707 r
F P
0 g
s
.7117 .64393 m .7147 .60941 L .7464 .61021 L p .707 .577 .707 r
F P
0 g
s
.7147 .60941 m .7117 .64393 L .68257 .64752 L p .707 .577 .707 r
F P
0 g
s
.80603 .6845 m .80451 .70171 L .77712 .69255 L p .707 .577 .707 r
F P
0 g
s
.77712 .69255 m .77865 .67534 L .80603 .6845 L p .707 .577 .707 r
F P
0 g
s
.47582 .70361 m .47229 .72217 L .48851 .71989 L p .707 .577 .707 r
F P
0 g
s
.48851 .71989 m .49203 .70133 L .47582 .70361 L p .707 .577 .707 r
F P
0 g
s
.7464 .61021 m .7434 .64473 L .7117 .64393 L p .707 .577 .707 r
F P
0 g
s
.68503 .68972 m .68655 .67251 L .71583 .66904 L p .707 .577 .707 r
F P
0 g
s
.31018 .69025 m .31371 .67169 L .30146 .6638 L p .707 .577 .707 r
F P
0 g
s
.30146 .6638 m .29794 .68236 L .31018 .69025 L p .707 .577 .707 r
F P
0 g
s
.29834 .52882 m .29415 .58471 L .29728 .5925 L p .707 .577 .707 r
F P
0 g
s
.71583 .66904 m .71431 .68625 L .68503 .68972 L p .707 .577 .707 r
F P
0 g
s
.49256 .64069 m .48564 .67782 L .49238 .67304 L p .707 .577 .707 r
F P
0 g
s
.49238 .67304 m .4993 .6359 L .49256 .64069 L p .707 .577 .707 r
F P
0 g
s
.77865 .67534 m .77712 .69255 L .74604 .68723 L p .707 .577 .707 r
F P
0 g
s
.74604 .68723 m .74756 .67002 L .77865 .67534 L p .707 .577 .707 r
F P
0 g
s
.71431 .68625 m .71583 .66904 L .74756 .67002 L p .707 .577 .707 r
F P
0 g
s
.2948 .64136 m .30172 .60423 L .29864 .59757 L p .707 .577 .707 r
F P
0 g
s
.74756 .67002 m .74604 .68723 L .71431 .68625 L p .707 .577 .707 r
F P
0 g
s
.5018 .54607 m .4976 .60197 L .49448 .59418 L p .707 .577 .707 r
F P
0 g
s
.49448 .59418 m .49867 .53829 L .5018 .54607 L p .707 .577 .707 r
F P
0 g
s
.29864 .59757 m .29172 .6347 L .2948 .64136 L p .707 .577 .707 r
F P
0 g
s
.49203 .70133 m .48851 .71989 L .49561 .71522 L p .707 .577 .707 r
F P
0 g
s
.49561 .71522 m .49914 .69666 L .49203 .70133 L p .707 .577 .707 r
F P
0 g
s
.29415 .58471 m .29834 .52882 L .30517 .52188 L p .707 .577 .707 r
F P
0 g
s
.29794 .68236 m .30146 .6638 L .29876 .6572 L p .707 .577 .707 r
F P
0 g
s
.29876 .6572 m .29523 .67576 L .29794 .68236 L p .707 .577 .707 r
F P
0 g
s
.30517 .52188 m .30098 .57777 L .29415 .58471 L p .707 .577 .707 r
F P
0 g
s
.4993 .6359 m .49238 .67304 L .4893 .66638 L p .707 .577 .707 r
F P
0 g
s
.4893 .66638 m .49622 .62924 L .4993 .6359 L p .707 .577 .707 r
F P
0 g
s
.29172 .6347 m .29864 .59757 L .30538 .59279 L p .707 .577 .707 r
F P
0 g
s
.49867 .53829 m .49448 .59418 L .4817 .58631 L p .707 .577 .707 r
F P
0 g
s
.4817 .58631 m .48589 .53042 L .49867 .53829 L p .707 .577 .707 r
F P
0 g
s
.30538 .59279 m .29846 .62992 L .29172 .6347 L p .707 .577 .707 r
F P
0 g
s
.30098 .57777 m .30517 .52188 L .32129 .51646 L p .707 .577 .707 r
F P
0 g
s
.49914 .69666 m .49561 .71522 L .49291 .70862 L p .707 .577 .707 r
F P
0 g
s
.49291 .70862 m .49644 .69006 L .49914 .69666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29523 .67576 m .29876 .6572 L .30587 .65253 L p .707 .577 .707 r
F P
0 g
s
.30587 .65253 m .30234 .67109 L .29523 .67576 L p .707 .577 .707 r
F P
0 g
s
.32129 .51646 m .3171 .57235 L .30098 .57777 L p .707 .577 .707 r
F P
0 g
s
.49622 .62924 m .4893 .66638 L .4767 .65849 L p .707 .577 .707 r
F P
0 g
s
.4767 .65849 m .48362 .62136 L .49622 .62924 L p .707 .577 .707 r
F P
0 g
s
.29846 .62992 m .30538 .59279 L .32128 .59035 L p .707 .577 .707 r
F P
0 g
s
.48589 .53042 m .4817 .58631 L .46051 .57913 L p .707 .577 .707 r
F P
0 g
s
.46051 .57913 m .46471 .52323 L .48589 .53042 L p .707 .577 .707 r
F P
0 g
s
.3171 .57235 m .32129 .51646 L .34512 .51309 L p .707 .577 .707 r
F P
0 g
s
.32128 .59035 m .31436 .62748 L .29846 .62992 L p .707 .577 .707 r
F P
0 g
s
.49644 .69006 m .49291 .70862 L .48067 .70073 L p .707 .577 .707 r
F P
0 g
s
.48067 .70073 m .48419 .68217 L .49644 .69006 L p .707 .577 .707 r
F P
0 g
s
.30234 .67109 m .30587 .65253 L .32208 .65025 L p .707 .577 .707 r
F P
0 g
s
.34512 .51309 m .34093 .56899 L .3171 .57235 L p .707 .577 .707 r
F P
0 g
s
.32208 .65025 m .31856 .6688 L .30234 .67109 L p .707 .577 .707 r
F P
0 g
s
.46471 .52323 m .46051 .57913 L .43301 .57334 L p .707 .577 .707 r
F P
0 g
s
.43301 .57334 m .4372 .51744 L .46471 .52323 L p .707 .577 .707 r
F P
0 g
s
.48362 .62136 m .4767 .65849 L .45582 .65016 L p .707 .577 .707 r
F P
0 g
s
.45582 .65016 m .46274 .61302 L .48362 .62136 L p .707 .577 .707 r
F P
0 g
s
.31436 .62748 m .32128 .59035 L .34479 .59049 L p .707 .577 .707 r
F P
0 g
s
.34093 .56899 m .34512 .51309 L .37433 .51211 L p .707 .577 .707 r
F P
0 g
s
.34479 .59049 m .33787 .62763 L .31436 .62748 L p .707 .577 .707 r
F P
0 g
s
.4372 .51744 m .43301 .57334 L .40186 .56951 L p .707 .577 .707 r
F P
0 g
s
.40186 .56951 m .40606 .51361 L .4372 .51744 L p .707 .577 .707 r
F P
0 g
s
.48419 .68217 m .48067 .70073 L .46008 .69233 L p .707 .577 .707 r
F P
0 g
s
.46008 .69233 m .4636 .67377 L .48419 .68217 L p .707 .577 .707 r
F P
0 g
s
.37014 .56801 m .37433 .51211 L .40606 .51361 L p .707 .577 .707 r
F P
0 g
s
.37433 .51211 m .37014 .56801 L .34093 .56899 L p .707 .577 .707 r
F P
0 g
s
.40606 .51361 m .40186 .56951 L .37014 .56801 L p .707 .577 .707 r
F P
0 g
s
.31856 .6688 m .32208 .65025 L .34583 .65058 L p .707 .577 .707 r
F P
0 g
s
.46274 .61302 m .45582 .65016 L .42869 .64218 L p .707 .577 .707 r
F P
0 g
s
.42869 .64218 m .43561 .60505 L .46274 .61302 L p .707 .577 .707 r
F P
0 g
s
.34583 .65058 m .3423 .66913 L .31856 .6688 L p .707 .577 .707 r
F P
0 g
s
.33787 .62763 m .34479 .59049 L .3736 .5932 L p .707 .577 .707 r
F P
0 g
s
.3736 .5932 m .36668 .63034 L .33787 .62763 L p .707 .577 .707 r
F P
0 g
s
.43561 .60505 m .42869 .64218 L .39797 .63536 L p .707 .577 .707 r
F P
0 g
s
.39797 .63536 m .4049 .59822 L .43561 .60505 L p .707 .577 .707 r
F P
0 g
s
.4636 .67377 m .46008 .69233 L .43316 .68424 L p .707 .577 .707 r
F P
0 g
s
.43316 .68424 m .43669 .66568 L .4636 .67377 L p .707 .577 .707 r
F P
0 g
s
.36668 .63034 m .3736 .5932 L .4049 .59822 L p .707 .577 .707 r
F P
0 g
s
.3423 .66913 m .34583 .65058 L .37477 .65349 L p .707 .577 .707 r
F P
0 g
s
.4049 .59822 m .39797 .63536 L .36668 .63034 L p .707 .577 .707 r
F P
0 g
s
.37477 .65349 m .37124 .67204 L .3423 .66913 L p .707 .577 .707 r
F P
0 g
s
.43669 .66568 m .43316 .68424 L .40255 .67725 L p .707 .577 .707 r
F P
0 g
s
.40255 .67725 m .40608 .65869 L .43669 .66568 L p .707 .577 .707 r
F P
0 g
s
.37124 .67204 m .37477 .65349 L .40608 .65869 L p .707 .577 .707 r
F P
0 g
s
.40608 .65869 m .40255 .67725 L .37124 .67204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001OOol@00000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001J
Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001HOol2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80006FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00001UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0000AOolA0014Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003Yoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000gOol005Aoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`00=Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000cOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
02moo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP06001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`03001JEP0000=JEPD00003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H0
05YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol01000FUH005YF0P001UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF1P000eYF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF0P001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF009JEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002eoo`00Dgoo0P000eYF3`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF
00000P000UYF00<005YFFUH015YF00@005YFFUIJEPL0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00AJEP@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
0eYF00<005YFFUH00eYF1P002Goo1@000goo1P001UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000`00
1eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUH0000300000eYF00000002000:Ool5
0009Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP8000=JEP03001JEUYF00=JEPL000=oo`D000Yoo`L000AJEP04001JEUYFFUH2
000]Ool003iooaH00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH015YF60000eYF
00@005YFFUIJEP<00003FUH005YF009JEP8002eoo`00=goo1`0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF20002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUH005YF00800003FUH005YF00AJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEPH0
00=JEP03001JEUYF00AJEP8000=JEP8002eoo`00<Woo1@000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP<00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YF00000UYF0P00;Goo000`
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P001UYF00<005YFFUH01000;Goo000^Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000
FUIJEUYF0`00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH3000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000800003FUH005YF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPH000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00D0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF1@001UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000P00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP040002FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH01P00
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00D005YFFUIJEP0000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF
00=JEPL000QJEP03001JEUYF00EJEPH000EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP000080009JEP04001JEUYFFUH>00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000/Ool01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH01EYF00D005YFFUIJEP0002ioo`00;7oo00@005YFFUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00AJEP8000=J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP80
009JEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP04001JEUYF
FUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00@000EJEP03001JEUYF00AJEP05001JEP00001JEP020006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH005YF0`0015YF00<005YFFUH00eYF00<005YFFUH00P0017oo
4P001goo0P000eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF5@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF100000=JEP00FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEP00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0P007goo0P0000MJEP00FUIJEP00FUH0000]Ool002eoo`03001JEP0000=JEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0400015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000`0015YF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP000080009JEP05001JEUYFFUH00005FUH00`00FUIJEP0A000BOol20002FUH00`00
FUH0000]Ool002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000AJEP8000EJEP@00003FUH0000000L000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=J
EP04001JEUYF0004FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04000@Ool01@00FUH005YF0000
;Goo000]Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00<005YF00000P000UYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPL0
00IJEP03001JEUYF00EJEP03001JEP0000D000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000004FUH800000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
000<Ool01@00FUH005YF0000;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP00
00EJEP<000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP8000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH01000FUH000001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0`00;Woo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YF000010000eYF00<005YFFUH00UYF1@001UYF10001EYF00<005YFFUH015YF
0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`800003
FUH0000002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP03FUH50004FUH50007FUH00`00
FUIJEP0400000eYF001JEP05FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03
001JEUYF00IJEPD000=JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
0eYF20003goo1P001eYF00<005YFFUH00P000eYF0P00;Woo000]Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500000eYF001JEP06
FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH0
00030006FUH6000AOol20004FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo000_Ool50003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUHA0003FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00
FUIJEP040004FUH00`00FUIJEP08FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF0P000eYF00<005YFFUH01EYF
00<005YFFUH00UYF4P0000IJEP00000005YF0006FUH200000eYF001oo`0]Ool003Aoo`L000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@00003FUH005YF00QJEP03001J
EUYF00AJEPh0009JEP<000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYF001JEP000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001UYF0`00;goo000gOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP040006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1`0000=JEP0000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUH005YF00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000_Ool0035oo`H0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800005FUH005YFFUH0000_Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003
FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP<000=J
EP03001oogoo02aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF
00AJEPD0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P001EYF0P0000=JEP00FUH01UYF
00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001o
ogoo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00AJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000IJEP@000IJEP03001JEUYF00IJEPD000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<00004Ool005YF000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH?000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P0017oo0`00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF000010001UYF1@0015YF00<0
05YFFUH01EYF00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00D005YFFUIJ
EP0000EJEP05001JEUYFFUH00002Ool40002FUH40005FUH00`00FUIJEP02FUH5000;Ool2000]Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000eYF00@005YFFUH000EJEP05001JEUYFFUH00006Ool@000@Ool2000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ400003FUH005YF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`00
00=JEP00FUH00eYF00D005YFFUIJEP0002Eoo`03001JEP0002eoo`00;Goo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP020005
FUH00`00FUIJEP02000ROol300000eYF001oo`0/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03
0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF0`000UYF00<005YFFUH00P0087oo0P00
0UYF0P00;Woo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1@000Woo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEP00008000=JEP03001oogoo01eoo`03001JEUYF009JEP8002ioo`00;Goo00<005YF
00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEPH000YJEP03001JEUYF00YJEP03001JEUYF00UJ
EPL0009JEP03001JEUYF00EJEP05001JEUYFFUH00002Ool00`00FUIJEP04FUH01000FUIJEUYF0`00
00=JEP00Ool077oo0`0015YF00<007ooOol0;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000?Ool01@00FUIJEUYF00001UYF00<005YFFUH0
1@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10001UYF
00D005YFFUIJEP0000=oo`8000=JEP03001JEUYF00AJEPH001Qoo`80009JEP03001JEUYF009JEP03
001oogoo02eoo`00;Woo>0000eYF00<005YFFUH00eYF10002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000Eoo`800003FUH005YF
00IJEP03001JEUYF009JEPT000Uoo`H000AJEP03001JEUYF0080031oo`00?goo200015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP04001JEUYFFUH20002FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`03Ool50006FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP03FUH3000bOol003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH01000FUH0000015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000eYF00<007ooOol00`001EYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00=7oo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH02P0000=JEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000`00=Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF1P0015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1@00>Woo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUHD000015YF000000000UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH000IJEP03001JEUYF00=JEP<00003FUH007oo00=ooa8003moo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2P0025YF00<005YFFUH015YF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP02
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT0
00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0007FUH00`00FUIJEP03FUH00`00FUH0001FOol002aoo`04001JEUYF0003
FUH01000FUIJEUYF200025YF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPH0009oo`03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00/000=JEP04001JEP00001E
Ool002eoo`03001JEP00009JEPH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Qoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP03FUH400000eYF0000001EOol002eoo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPT0011oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000IJEP04001JEUYFFUH20003Ool00`00FUH0001EOol002eoo`<00003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT001]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8000MJEP04001JEP000006
Ool2001EOol0031ooa@002Ioo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000MJEP<000Moo`03001JEP0005Eo
o`00K7oo0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0P002Woo00@005YF000005Ao
o`00KWoo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YF00000P0015YF00<005YF00000P002Woo0`000UYF00<007ooOol0DWoo001`
Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40005
FUH4000;Ool20002FUH01000FUIJEP00E7oo001dOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0>000>Ool00`00FUIJEP03FUH2001EOol007Yoo`P000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPP000=JEPL0011oo`<000EJEP8005Eoo`00PWoo9@000Woo1@00
3Woo0P000UYF00<005YFFUH00eYF00<007ooOol0E7oo002>Ool00`00FUIJEP02000GOol3000=Ool2
0005FUH00`00FUIJEP02001GOol008ioo`04001JEUYF000VOol20007FUH3001IOol008moo`8002=o
o`@00003FUH005YF00IJEP03001oogoo05Uoo`00Sgoo0`007Goo1@001EYF00<005YFFUH00eYF0P00
G7oo002?Ool00`00FUIJEP02000GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02001NOol008mo
o`800003FUH005YF00<000ioo`H000IJEP03001JEUYF00IJEP<0061oo`00T7oo00<005YF000015YF
3P000eYF00<005YFFUH01eYF00<005YFFUH015YF0P00HWoo002@Ool01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002AOol30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001XOol009=oo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00@006eoo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH00UYF
1P00LGoo002HOol>001gOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59408 .74597 m .59825 .69009 L .56722 .68615 L p .707 .577 .707 r
F P
0 g
s
.59825 .69009 m .59408 .74597 L .62586 .74758 L p .707 .577 .707 r
F P
0 g
s
.62586 .74758 m .63003 .6917 L .59825 .69009 L p .707 .577 .707 r
F P
0 g
s
.63003 .6917 m .62586 .74758 L .65527 .74671 L p .707 .577 .707 r
F P
0 g
s
.65527 .74671 m .65944 .69082 L .63003 .6917 L p .707 .577 .707 r
F P
0 g
s
.56305 .74203 m .56722 .68615 L .53998 .68027 L p .707 .577 .707 r
F P
0 g
s
.56722 .68615 m .56305 .74203 L .59408 .74597 L p .707 .577 .707 r
F P
0 g
s
.65944 .69082 m .65527 .74671 L .67943 .74343 L p .707 .577 .707 r
F P
0 g
s
.67943 .74343 m .6836 .68755 L .65944 .69082 L p .707 .577 .707 r
F P
0 g
s
.53998 .68027 m .5358 .73615 L .56305 .74203 L p .707 .577 .707 r
F P
0 g
s
.58993 .80111 m .59682 .76399 L .56624 .75708 L p .707 .577 .707 r
F P
0 g
s
.59682 .76399 m .58993 .80111 L .62129 .80622 L p .707 .577 .707 r
F P
0 g
s
.62129 .80622 m .62817 .7691 L .59682 .76399 L p .707 .577 .707 r
F P
0 g
s
.5358 .73615 m .53998 .68027 L .51918 .67302 L p .707 .577 .707 r
F P
0 g
s
.62817 .7691 m .62129 .80622 L .65035 .80903 L p .707 .577 .707 r
F P
0 g
s
.65035 .80903 m .65723 .77191 L .62817 .7691 L p .707 .577 .707 r
F P
0 g
s
.55935 .7942 m .56624 .75708 L .53943 .74905 L p .707 .577 .707 r
F P
0 g
s
.56624 .75708 m .55935 .7942 L .58993 .80111 L p .707 .577 .707 r
F P
0 g
s
.53943 .74905 m .53255 .78617 L .55935 .7942 L p .707 .577 .707 r
F P
0 g
s
.51918 .67302 m .515 .7289 L .5358 .73615 L p .707 .577 .707 r
F P
0 g
s
.6836 .68755 m .67943 .74343 L .69599 .73808 L p .707 .577 .707 r
F P
0 g
s
.69599 .73808 m .70016 .68219 L .6836 .68755 L p .707 .577 .707 r
F P
0 g
s
.65723 .77191 m .65035 .80903 L .67428 .80926 L p .707 .577 .707 r
F P
0 g
s
.67428 .80926 m .68116 .77214 L .65723 .77191 L p .707 .577 .707 r
F P
0 g
s
.59447 .8426 m .598 .82405 L .56737 .81707 L p .707 .577 .707 r
F P
0 g
s
.598 .82405 m .59447 .8426 L .62577 .84779 L p .707 .577 .707 r
F P
0 g
s
.62577 .84779 m .6293 .82923 L .598 .82405 L p .707 .577 .707 r
F P
0 g
s
.56737 .81707 m .56384 .83563 L .59447 .8426 L p .707 .577 .707 r
F P
0 g
s
.6293 .82923 m .62577 .84779 L .65466 .85068 L p .707 .577 .707 r
F P
0 g
s
.65466 .85068 m .65819 .83213 L .6293 .82923 L p .707 .577 .707 r
F P
0 g
s
.53255 .78617 m .53943 .74905 L .51902 .74067 L p .707 .577 .707 r
F P
0 g
s
.56384 .83563 m .56737 .81707 L .54039 .80899 L p .707 .577 .707 r
F P
0 g
s
.515 .7289 m .51918 .67302 L .50687 .66511 L p .707 .577 .707 r
F P
0 g
s
.54039 .80899 m .53686 .82755 L .56384 .83563 L p .707 .577 .707 r
F P
0 g
s
.51902 .74067 m .51214 .7778 L .53255 .78617 L p .707 .577 .707 r
F P
0 g
s
.65819 .83213 m .65466 .85068 L .67833 .851 L p .707 .577 .707 r
F P
0 g
s
.67833 .851 m .68186 .83244 L .65819 .83213 L p .707 .577 .707 r
F P
0 g
s
.53686 .82755 m .54039 .80899 L .51972 .8006 L p .707 .577 .707 r
F P
0 g
s
.68116 .77214 m .67428 .80926 L .69073 .8069 L p .707 .577 .707 r
F P
0 g
s
.69073 .8069 m .69761 .76977 L .68116 .77214 L p .707 .577 .707 r
F P
0 g
s
.50687 .66511 m .50269 .721 L .515 .7289 L p .707 .577 .707 r
F P
0 g
s
.51972 .8006 m .51619 .81915 L .53686 .82755 L p .707 .577 .707 r
F P
0 g
s
.70016 .68219 m .69599 .73808 L .70331 .73117 L p .707 .577 .707 r
F P
0 g
s
.70331 .73117 m .70749 .67529 L .70016 .68219 L p .707 .577 .707 r
F P
0 g
s
.51214 .7778 m .51902 .74067 L .507 .73279 L p .707 .577 .707 r
F P
0 g
s
.507 .73279 m .50012 .76991 L .51214 .7778 L p .707 .577 .707 r
F P
0 g
s
.50269 .721 m .50687 .66511 L .50424 .65733 L p .707 .577 .707 r
F P
0 g
s
.68186 .83244 m .67833 .851 L .69445 .8487 L p .707 .577 .707 r
F P
0 g
s
.69445 .8487 m .69798 .83014 L .68186 .83244 L p .707 .577 .707 r
F P
0 g
s
.51619 .81915 m .51972 .8006 L .50736 .79271 L p .707 .577 .707 r
F P
0 g
s
.50736 .79271 m .50383 .81127 L .51619 .81915 L p .707 .577 .707 r
F P
0 g
s
.69761 .76977 m .69073 .8069 L .69809 .80216 L p .707 .577 .707 r
F P
0 g
s
.69809 .80216 m .70497 .76504 L .69761 .76977 L p .707 .577 .707 r
F P
0 g
s
.50424 .65733 m .50007 .71321 L .50269 .721 L p .707 .577 .707 r
F P
0 g
s
.70749 .67529 m .70331 .73117 L .70069 .72338 L p .707 .577 .707 r
F P
0 g
s
.70069 .72338 m .70487 .6675 L .70749 .67529 L p .707 .577 .707 r
F P
0 g
s
.50012 .76991 m .507 .73279 L .50455 .72615 L p .707 .577 .707 r
F P
0 g
s
.50455 .72615 m .49767 .76327 L .50012 .76991 L p .707 .577 .707 r
F P
0 g
s
.49767 .76327 m .50455 .72615 L .51191 .72142 L p .707 .577 .707 r
F P
0 g
s
.51191 .72142 m .50502 .75854 L .49767 .76327 L p .707 .577 .707 r
F P
0 g
s
.49936 .82192 m .49936 .32003 L .45482 .31809 L p .707 .577 .707 r
F P
0 g
s
.50007 .71321 m .50424 .65733 L .51157 .65042 L p .707 .577 .707 r
F P
0 g
s
.50383 .81127 m .50736 .79271 L .50455 .7861 L p .707 .577 .707 r
F P
0 g
s
.50455 .7861 m .50102 .80466 L .50383 .81127 L p .707 .577 .707 r
F P
0 g
s
.51157 .65042 m .5074 .7063 L .50007 .71321 L p .707 .577 .707 r
F P
0 g
s
.5074 .7063 m .51157 .65042 L .52813 .64507 L p .707 .577 .707 r
F P
0 g
s
.50102 .80466 m .50455 .7861 L .51154 .78142 L p .707 .577 .707 r
F P
0 g
s
.51154 .78142 m .50801 .79998 L .50102 .80466 L p .707 .577 .707 r
F P
0 g
s
.52813 .64507 m .52395 .70095 L .5074 .7063 L p .707 .577 .707 r
F P
0 g
s
.50502 .75854 m .51191 .72142 L .52835 .71905 L p .707 .577 .707 r
F P
0 g
s
.52395 .70095 m .52813 .64507 L .55229 .64179 L p .707 .577 .707 r
F P
0 g
s
.52835 .71905 m .52147 .75617 L .50502 .75854 L p .707 .577 .707 r
F P
0 g
s
.50801 .79998 m .51154 .78142 L .52766 .77913 L p .707 .577 .707 r
F P
0 g
s
.52766 .77913 m .52413 .79769 L .50801 .79998 L p .707 .577 .707 r
F P
0 g
s
.55229 .64179 m .54812 .69767 L .52395 .70095 L p .707 .577 .707 r
F P
0 g
s
.52147 .75617 m .52835 .71905 L .55228 .71929 L p .707 .577 .707 r
F P
0 g
s
.55228 .71929 m .5454 .75641 L .52147 .75617 L p .707 .577 .707 r
F P
0 g
s
.52413 .79769 m .52766 .77913 L .55132 .77944 L p .707 .577 .707 r
F P
0 g
s
.55132 .77944 m .54779 .798 L .52413 .79769 L p .707 .577 .707 r
F P
0 g
s
.49936 .32003 m .49936 .82192 L .54397 .82008 L p .707 .577 .707 r
F P
0 g
s
.54397 .82008 m .54397 .31819 L .49936 .32003 L p .707 .577 .707 r
F P
0 g
s
.69798 .83014 m .69445 .8487 L .70144 .84402 L p .707 .577 .707 r
F P
0 g
s
.70144 .84402 m .70497 .82547 L .69798 .83014 L p .707 .577 .707 r
F P
0 g
s
.54812 .69767 m .55229 .64179 L .5817 .64092 L p .707 .577 .707 r
F P
0 g
s
.5817 .64092 m .57753 .6968 L .54812 .69767 L p .707 .577 .707 r
F P
0 g
s
.5454 .75641 m .55228 .71929 L .58135 .72209 L p .707 .577 .707 r
F P
0 g
s
.58135 .72209 m .57446 .75922 L .5454 .75641 L p .707 .577 .707 r
F P
0 g
s
.57446 .75922 m .58135 .72209 L .6127 .7272 L p .707 .577 .707 r
F P
0 g
s
.54779 .798 m .55132 .77944 L .58022 .78234 L p .707 .577 .707 r
F P
0 g
s
.6127 .7272 m .60582 .76433 L .57446 .75922 L p .707 .577 .707 r
F P
0 g
s
.58022 .78234 m .57669 .80089 L .54779 .798 L p .707 .577 .707 r
F P
0 g
s
.57669 .80089 m .58022 .78234 L .61151 .78752 L p .707 .577 .707 r
F P
0 g
s
.61151 .78752 m .60798 .80608 L .57669 .80089 L p .707 .577 .707 r
F P
0 g
s
.54397 .31819 m .54397 .82008 L .58427 .81463 L p .707 .577 .707 r
F P
0 g
s
.57753 .6968 m .5817 .64092 L .61348 .64253 L p .707 .577 .707 r
F P
0 g
s
.61348 .64253 m .6093 .69841 L .57753 .6968 L p .707 .577 .707 r
F P
0 g
s
.58427 .81463 m .58427 .31274 L .54397 .31819 L p .707 .577 .707 r
F P
0 g
s
.45482 .81998 m .45482 .31809 L .4147 .31254 L p .707 .577 .707 r
F P
0 g
s
.45482 .31809 m .45482 .81998 L .49936 .82192 L p .707 .577 .707 r
F P
0 g
s
.70497 .76504 m .69809 .80216 L .69564 .79553 L p .707 .577 .707 r
F P
0 g
s
.69564 .79553 m .70252 .75841 L .70497 .76504 L p .707 .577 .707 r
F P
0 g
s
.70487 .6675 m .70069 .72338 L .68838 .71548 L p .707 .577 .707 r
F P
0 g
s
.68838 .71548 m .69255 .65959 L .70487 .6675 L p .707 .577 .707 r
F P
0 g
s
.64451 .64647 m .64033 .70235 L .6093 .69841 L p .707 .577 .707 r
F P
0 g
s
.6093 .69841 m .61348 .64253 L .64451 .64647 L p .707 .577 .707 r
F P
0 g
s
.64328 .73411 m .6364 .77123 L .60582 .76433 L p .707 .577 .707 r
F P
0 g
s
.60582 .76433 m .6127 .7272 L .64328 .73411 L p .707 .577 .707 r
F P
0 g
s
.64215 .7945 m .63862 .81306 L .60798 .80608 L p .707 .577 .707 r
F P
0 g
s
.60798 .80608 m .61151 .78752 L .64215 .7945 L p .707 .577 .707 r
F P
0 g
s
.58427 .31274 m .58427 .81463 L .61632 .80611 L p .707 .577 .707 r
F P
0 g
s
.61632 .80611 m .61632 .30422 L .58427 .31274 L p .707 .577 .707 r
F P
0 g
s
.4147 .81443 m .4147 .31254 L .38293 .30394 L p .707 .577 .707 r
F P
0 g
s
.4147 .31254 m .4147 .81443 L .45482 .81998 L p .707 .577 .707 r
F P
0 g
s
.25184 .71911 m .25362 .66483 L .22252 .66146 L p .707 .577 .707 r
F P
0 g
s
.25362 .66483 m .25184 .71911 L .28368 .71914 L p .707 .577 .707 r
F P
0 g
s
.28368 .71914 m .28546 .66487 L .25362 .66483 L p .707 .577 .707 r
F P
0 g
s
.28546 .66487 m .28368 .71914 L .31314 .71582 L p .707 .577 .707 r
F P
0 g
s
.31314 .71582 m .31493 .66154 L .28546 .66487 L p .707 .577 .707 r
F P
0 g
s
.70497 .82547 m .70144 .84402 L .69862 .83742 L p .707 .577 .707 r
F P
0 g
s
.69862 .83742 m .70215 .81886 L .70497 .82547 L p .707 .577 .707 r
F P
0 g
s
.22073 .71574 m .22252 .66146 L .1952 .65506 L p .707 .577 .707 r
F P
0 g
s
.22252 .66146 m .22073 .71574 L .25184 .71911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31493 .66154 m .31314 .71582 L .33734 .70948 L p .707 .577 .707 r
F P
0 g
s
.33734 .70948 m .33913 .6552 L .31493 .66154 L p .707 .577 .707 r
F P
0 g
s
.70252 .75841 m .69564 .79553 L .68362 .78764 L p .707 .577 .707 r
F P
0 g
s
.68362 .78764 m .6905 .75052 L .70252 .75841 L p .707 .577 .707 r
F P
0 g
s
.69255 .65959 m .68838 .71548 L .66758 .70823 L p .707 .577 .707 r
F P
0 g
s
.66758 .70823 m .67175 .65235 L .69255 .65959 L p .707 .577 .707 r
F P
0 g
s
.19341 .70934 m .1952 .65506 L .17434 .64627 L p .707 .577 .707 r
F P
0 g
s
.1952 .65506 m .19341 .70934 L .22073 .71574 L p .707 .577 .707 r
F P
0 g
s
.61632 .30422 m .61632 .80611 L .63699 .79534 L p .707 .577 .707 r
F P
0 g
s
.67009 .74215 m .6632 .77927 L .6364 .77123 L p .707 .577 .707 r
F P
0 g
s
.6364 .77123 m .64328 .73411 L .67009 .74215 L p .707 .577 .707 r
F P
0 g
s
.63699 .79534 m .63699 .29345 L .61632 .30422 L p .707 .577 .707 r
F P
0 g
s
.25024 .78806 m .2532 .75358 L .22218 .74823 L p .707 .577 .707 r
F P
0 g
s
.2532 .75358 m .25024 .78806 L .282 .78911 L p .707 .577 .707 r
F P
0 g
s
.282 .78911 m .28496 .75462 L .2532 .75358 L p .707 .577 .707 r
F P
0 g
s
.38293 .80583 m .38293 .30394 L .36262 .29313 L p .707 .577 .707 r
F P
0 g
s
.38293 .30394 m .38293 .80583 L .4147 .81443 L p .707 .577 .707 r
F P
0 g
s
.28496 .75462 m .282 .78911 L .31138 .78573 L p .707 .577 .707 r
F P
0 g
s
.31138 .78573 m .31435 .75125 L .28496 .75462 L p .707 .577 .707 r
F P
0 g
s
.21921 .78271 m .22218 .74823 L .19492 .73908 L p .707 .577 .707 r
F P
0 g
s
.22218 .74823 m .21921 .78271 L .25024 .78806 L p .707 .577 .707 r
F P
0 g
s
.70215 .81886 m .69862 .83742 L .68627 .82953 L p .707 .577 .707 r
F P
0 g
s
.68627 .82953 m .6898 .81097 L .70215 .81886 L p .707 .577 .707 r
F P
0 g
s
.33913 .6552 m .33734 .70948 L .35391 .70073 L p .707 .577 .707 r
F P
0 g
s
.35391 .70073 m .35569 .64645 L .33913 .6552 L p .707 .577 .707 r
F P
0 g
s
.17434 .64627 m .17255 .70055 L .19341 .70934 L p .707 .577 .707 r
F P
0 g
s
.31435 .75125 m .31138 .78573 L .33552 .77827 L p .707 .577 .707 r
F P
0 g
s
.33552 .77827 m .33848 .74379 L .31435 .75125 L p .707 .577 .707 r
F P
0 g
s
.25288 .83132 m .25441 .8141 L .2233 .80882 L p .707 .577 .707 r
F P
0 g
s
.25441 .8141 m .25288 .83132 L .2846 .83225 L p .707 .577 .707 r
F P
0 g
s
.2846 .83225 m .28613 .81504 L .25441 .8141 L p .707 .577 .707 r
F P
0 g
s
.17255 .70055 m .17434 .64627 L .16197 .63595 L p .707 .577 .707 r
F P
0 g
s
.67175 .65235 m .66758 .70823 L .64033 .70235 L p .707 .577 .707 r
F P
0 g
s
.64033 .70235 m .64451 .64647 L .67175 .65235 L p .707 .577 .707 r
F P
0 g
s
.6905 .75052 m .68362 .78764 L .6632 .77927 L p .707 .577 .707 r
F P
0 g
s
.6632 .77927 m .67009 .74215 L .6905 .75052 L p .707 .577 .707 r
F P
0 g
s
.19195 .77356 m .19492 .73908 L .1741 .72703 L p .707 .577 .707 r
F P
0 g
s
.19492 .73908 m .19195 .77356 L .21921 .78271 L p .707 .577 .707 r
F P
0 g
s
.28613 .81504 m .2846 .83225 L .31383 .82874 L p .707 .577 .707 r
F P
0 g
s
.31383 .82874 m .31536 .81153 L .28613 .81504 L p .707 .577 .707 r
F P
0 g
s
.22178 .82604 m .2233 .80882 L .19586 .79971 L p .707 .577 .707 r
F P
0 g
s
.2233 .80882 m .22178 .82604 L .25288 .83132 L p .707 .577 .707 r
F P
0 g
s
.19586 .79971 m .19433 .81693 L .22178 .82604 L p .707 .577 .707 r
F P
0 g
s
.31536 .81153 m .31383 .82874 L .33771 .82114 L p .707 .577 .707 r
F P
0 g
s
.33771 .82114 m .33924 .80392 L .31536 .81153 L p .707 .577 .707 r
F P
0 g
s
.35569 .64645 m .35391 .70073 L .36122 .69043 L p .707 .577 .707 r
F P
0 g
s
.36122 .69043 m .36301 .63615 L .35569 .64645 L p .707 .577 .707 r
F P
0 g
s
.33848 .74379 m .33552 .77827 L .35204 .76745 L p .707 .577 .707 r
F P
0 g
s
.35204 .76745 m .355 .73297 L .33848 .74379 L p .707 .577 .707 r
F P
0 g
s
.6898 .81097 m .68627 .82953 L .66559 .82114 L p .707 .577 .707 r
F P
0 g
s
.66559 .82114 m .66912 .80258 L .6898 .81097 L p .707 .577 .707 r
F P
0 g
s
.19433 .81693 m .19586 .79971 L .17476 .78766 L p .707 .577 .707 r
F P
0 g
s
.1741 .72703 m .17114 .76151 L .19195 .77356 L p .707 .577 .707 r
F P
0 g
s
.16197 .63595 m .16018 .69023 L .17255 .70055 L p .707 .577 .707 r
F P
0 g
s
.63699 .29345 m .63699 .79534 L .64424 .78339 L p .707 .577 .707 r
F P
0 g
s
.64424 .78339 m .64424 .2815 L .63699 .29345 L p .707 .577 .707 r
F P
0 g
s
.35932 .75433 m .36229 .71985 L .355 .73297 L p .707 .577 .707 r
F P
0 g
s
.36301 .63615 m .36122 .69043 L .35857 .67959 L p .707 .577 .707 r
F P
0 g
s
.35857 .67959 m .36035 .62531 L .36301 .63615 L p .707 .577 .707 r
F P
0 g
s
.36229 .71985 m .35932 .75433 L .35667 .7402 L p .707 .577 .707 r
F P
0 g
s
.35667 .7402 m .35963 .70572 L .36229 .71985 L p .707 .577 .707 r
F P
0 g
s
.36035 .62531 m .35857 .67959 L .3462 .66927 L p .707 .577 .707 r
F P
0 g
s
.3462 .66927 m .34799 .61499 L .36035 .62531 L p .707 .577 .707 r
F P
0 g
s
.36262 .79502 m .36262 .29313 L .35575 .28116 L p .707 .577 .707 r
F P
0 g
s
.36262 .29313 m .36262 .79502 L .38293 .80583 L p .707 .577 .707 r
F P
0 g
s
.17114 .76151 m .1741 .72703 L .16176 .71327 L p .707 .577 .707 r
F P
0 g
s
.17476 .78766 m .17323 .80487 L .19433 .81693 L p .707 .577 .707 r
F P
0 g
s
.16018 .69023 m .16197 .63595 L .15932 .62511 L p .707 .577 .707 r
F P
0 g
s
.33924 .80392 m .33771 .82114 L .35391 .81018 L p .707 .577 .707 r
F P
0 g
s
.35391 .81018 m .35543 .79297 L .33924 .80392 L p .707 .577 .707 r
F P
0 g
s
.17323 .80487 m .17476 .78766 L .16207 .77384 L p .707 .577 .707 r
F P
0 g
s
.16176 .71327 m .15879 .74775 L .17114 .76151 L p .707 .577 .707 r
F P
0 g
s
.66912 .80258 m .66559 .82114 L .63862 .81306 L p .707 .577 .707 r
F P
0 g
s
.63862 .81306 m .64215 .7945 L .66912 .80258 L p .707 .577 .707 r
F P
0 g
s
.355 .73297 m .35204 .76745 L .35932 .75433 L p .707 .577 .707 r
F P
0 g
s
.15932 .62511 m .15753 .67939 L .16018 .69023 L p .707 .577 .707 r
F P
0 g
s
.16207 .77384 m .16054 .79106 L .17323 .80487 L p .707 .577 .707 r
F P
0 g
s
.15879 .74775 m .16176 .71327 L .1591 .69914 L p .707 .577 .707 r
F P
0 g
s
.15753 .67939 m .15932 .62511 L .16663 .61481 L p .707 .577 .707 r
F P
0 g
s
.35543 .79297 m .35391 .81018 L .36082 .79694 L p .707 .577 .707 r
F P
0 g
s
.36082 .79694 m .36235 .77973 L .35543 .79297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64424 .2815 m .64424 .78339 L .63738 .77142 L p .707 .577 .707 r
F P
0 g
s
.63738 .77142 m .63738 .26953 L .64424 .2815 L p .707 .577 .707 r
F P
0 g
s
.36235 .77973 m .36082 .79694 L .35779 .78272 L p .707 .577 .707 r
F P
0 g
s
.35779 .78272 m .35932 .76551 L .36235 .77973 L p .707 .577 .707 r
F P
0 g
s
.35963 .70572 m .35667 .7402 L .34433 .72644 L p .707 .577 .707 r
F P
0 g
s
.34433 .72644 m .34729 .69196 L .35963 .70572 L p .707 .577 .707 r
F P
0 g
s
.35932 .76551 m .35779 .78272 L .3451 .76891 L p .707 .577 .707 r
F P
0 g
s
.3451 .76891 m .34663 .75169 L .35932 .76551 L p .707 .577 .707 r
F P
0 g
s
.35575 .28116 m .35575 .78305 L .36262 .79502 L p .707 .577 .707 r
F P
0 g
s
.35575 .78305 m .35575 .28116 L .36301 .26921 L p .707 .577 .707 r
F P
0 g
s
.16054 .79106 m .16207 .77384 L .15904 .75962 L p .707 .577 .707 r
F P
0 g
s
.1591 .69914 m .15614 .73362 L .15879 .74775 L p .707 .577 .707 r
F P
0 g
s
.15904 .75962 m .15751 .77684 L .16054 .79106 L p .707 .577 .707 r
F P
0 g
s
.16663 .61481 m .16484 .66909 L .15753 .67939 L p .707 .577 .707 r
F P
0 g
s
.15614 .73362 m .1591 .69914 L .16639 .68602 L p .707 .577 .707 r
F P
0 g
s
.16484 .66909 m .16663 .61481 L .1832 .60606 L p .707 .577 .707 r
F P
0 g
s
.15751 .77684 m .15904 .75962 L .16596 .74639 L p .707 .577 .707 r
F P
0 g
s
.16639 .68602 m .16342 .7205 L .15614 .73362 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16596 .74639 m .16443 .7636 L .15751 .77684 L p .707 .577 .707 r
F P
0 g
s
.34799 .61499 m .3462 .66927 L .32534 .66048 L p .707 .577 .707 r
F P
0 g
s
.32534 .66048 m .32712 .6062 L .34799 .61499 L p .707 .577 .707 r
F P
0 g
s
.16342 .7205 m .16639 .68602 L .18291 .6752 L p .707 .577 .707 r
F P
0 g
s
.1832 .60606 m .18141 .66034 L .16484 .66909 L p .707 .577 .707 r
F P
0 g
s
.63738 .26953 m .63738 .77142 L .61707 .76061 L p .707 .577 .707 r
F P
0 g
s
.61707 .76061 m .61707 .25872 L .63738 .26953 L p .707 .577 .707 r
F P
0 g
s
.36301 .7711 m .36301 .26921 L .38368 .25844 L p .707 .577 .707 r
F P
0 g
s
.36301 .26921 m .36301 .7711 L .35575 .78305 L p .707 .577 .707 r
F P
0 g
s
.18141 .66034 m .1832 .60606 L .2074 .59971 L p .707 .577 .707 r
F P
0 g
s
.16443 .7636 m .16596 .74639 L .18215 .73543 L p .707 .577 .707 r
F P
0 g
s
.18291 .6752 m .17994 .70968 L .16342 .7205 L p .707 .577 .707 r
F P
0 g
s
.32712 .6062 m .32534 .66048 L .29802 .65408 L p .707 .577 .707 r
F P
0 g
s
.29802 .65408 m .2998 .5998 L .32712 .6062 L p .707 .577 .707 r
F P
0 g
s
.34729 .69196 m .34433 .72644 L .32351 .71439 L p .707 .577 .707 r
F P
0 g
s
.32351 .71439 m .32647 .67991 L .34729 .69196 L p .707 .577 .707 r
F P
0 g
s
.18215 .73543 m .18062 .75264 L .16443 .7636 L p .707 .577 .707 r
F P
0 g
s
.17994 .70968 m .18291 .6752 L .20704 .66774 L p .707 .577 .707 r
F P
0 g
s
.2074 .59971 m .20561 .65399 L .18141 .66034 L p .707 .577 .707 r
F P
0 g
s
.20561 .65399 m .2074 .59971 L .23686 .59639 L p .707 .577 .707 r
F P
0 g
s
.2998 .5998 m .29802 .65408 L .26691 .6507 L p .707 .577 .707 r
F P
0 g
s
.26691 .6507 m .2687 .59642 L .2998 .5998 L p .707 .577 .707 r
F P
0 g
s
.34663 .75169 m .3451 .76891 L .324 .75686 L p .707 .577 .707 r
F P
0 g
s
.324 .75686 m .32553 .73964 L .34663 .75169 L p .707 .577 .707 r
F P
0 g
s
.23507 .65067 m .23686 .59639 L .2687 .59642 L p .707 .577 .707 r
F P
0 g
s
.23686 .59639 m .23507 .65067 L .20561 .65399 L p .707 .577 .707 r
F P
0 g
s
.61707 .25872 m .61707 .76061 L .5853 .75201 L p .707 .577 .707 r
F P
0 g
s
.5853 .75201 m .5853 .25012 L .61707 .25872 L p .707 .577 .707 r
F P
0 g
s
.38368 .25844 m .38368 .76033 L .36301 .7711 L p .707 .577 .707 r
F P
0 g
s
.38368 .76033 m .38368 .25844 L .41573 .24992 L p .707 .577 .707 r
F P
0 g
s
.32647 .67991 m .32351 .71439 L .29625 .70524 L p .707 .577 .707 r
F P
0 g
s
.29625 .70524 m .29922 .67076 L .32647 .67991 L p .707 .577 .707 r
F P
0 g
s
.18062 .75264 m .18215 .73543 L .20603 .72782 L p .707 .577 .707 r
F P
0 g
s
.2687 .59642 m .26691 .6507 L .23507 .65067 L p .707 .577 .707 r
F P
0 g
s
.20704 .66774 m .20408 .70222 L .17994 .70968 L p .707 .577 .707 r
F P
0 g
s
.20408 .70222 m .20704 .66774 L .23643 .66436 L p .707 .577 .707 r
F P
0 g
s
.20603 .72782 m .2045 .74504 L .18062 .75264 L p .707 .577 .707 r
F P
0 g
s
.73308 .65068 m .7313 .59415 L .7002 .59365 L p .707 .577 .707 r
F P
0 g
s
.7313 .59415 m .73308 .65068 L .76493 .64919 L p .707 .577 .707 r
F P
0 g
s
.76493 .64919 m .76314 .59266 L .7313 .59415 L p .707 .577 .707 r
F P
0 g
s
.76314 .59266 m .76493 .64919 L .79439 .64586 L p .707 .577 .707 r
F P
0 g
s
.79439 .64586 m .7926 .58932 L .76314 .59266 L p .707 .577 .707 r
F P
0 g
s
.29922 .67076 m .29625 .70524 L .26522 .69989 L p .707 .577 .707 r
F P
0 g
s
.26522 .69989 m .26819 .66541 L .29922 .67076 L p .707 .577 .707 r
F P
0 g
s
.23346 .69884 m .23643 .66436 L .26819 .66541 L p .707 .577 .707 r
F P
0 g
s
.23643 .66436 m .23346 .69884 L .20408 .70222 L p .707 .577 .707 r
F P
0 g
s
.70198 .65018 m .7002 .59365 L .67287 .59121 L p .707 .577 .707 r
F P
0 g
s
.7002 .59365 m .70198 .65018 L .73308 .65068 L p .707 .577 .707 r
F P
0 g
s
.32553 .73964 m .324 .75686 L .29656 .74774 L p .707 .577 .707 r
F P
0 g
s
.29656 .74774 m .29809 .73053 L .32553 .73964 L p .707 .577 .707 r
F P
0 g
s
.26819 .66541 m .26522 .69989 L .23346 .69884 L p .707 .577 .707 r
F P
0 g
s
.2045 .74504 m .20603 .72782 L .23526 .72431 L p .707 .577 .707 r
F P
0 g
s
.7926 .58932 m .79439 .64586 L .81859 .641 L p .707 .577 .707 r
F P
0 g
s
.81859 .641 m .8168 .58447 L .7926 .58932 L p .707 .577 .707 r
F P
0 g
s
.67287 .59121 m .67466 .64774 L .70198 .65018 L p .707 .577 .707 r
F P
0 g
s
.73477 .70121 m .73181 .66302 L .70078 .66475 L p .707 .577 .707 r
F P
0 g
s
.73181 .66302 m .73477 .70121 L .76654 .69853 L p .707 .577 .707 r
F P
0 g
s
.76654 .69853 m .76357 .66033 L .73181 .66302 L p .707 .577 .707 r
F P
0 g
s
.23526 .72431 m .23373 .74153 L .2045 .74504 L p .707 .577 .707 r
F P
0 g
s
.5853 .25012 m .5853 .75201 L .54518 .74646 L p .707 .577 .707 r
F P
0 g
s
.54518 .74646 m .54518 .24457 L .5853 .25012 L p .707 .577 .707 r
F P
0 g
s
.41573 .75181 m .41573 .24992 L .45603 .24447 L p .707 .577 .707 r
F P
0 g
s
.41573 .24992 m .41573 .75181 L .38368 .76033 L p .707 .577 .707 r
F P
0 g
s
.76357 .66033 m .76654 .69853 L .79592 .69515 L p .707 .577 .707 r
F P
0 g
s
.79592 .69515 m .79295 .65695 L .76357 .66033 L p .707 .577 .707 r
F P
0 g
s
.29809 .73053 m .29656 .74774 L .26545 .74246 L p .707 .577 .707 r
F P
0 g
s
.26545 .74246 m .26698 .72525 L .29809 .73053 L p .707 .577 .707 r
F P
0 g
s
.70078 .66475 m .70375 .70294 L .73477 .70121 L p .707 .577 .707 r
F P
0 g
s
.23373 .74153 m .23526 .72431 L .26698 .72525 L p .707 .577 .707 r
F P
0 g
s
.67466 .64774 m .67287 .59121 L .65201 .58706 L p .707 .577 .707 r
F P
0 g
s
.70375 .70294 m .70078 .66475 L .67352 .66536 L p .707 .577 .707 r
F P
0 g
s
.26698 .72525 m .26545 .74246 L .23373 .74153 L p .707 .577 .707 r
F P
0 g
s
.67352 .66536 m .67649 .70355 L .70375 .70294 L p .707 .577 .707 r
F P
0 g
s
.79295 .65695 m .79592 .69515 L .82005 .69141 L p .707 .577 .707 r
F P
0 g
s
.82005 .69141 m .81709 .65321 L .79295 .65695 L p .707 .577 .707 r
F P
0 g
s
.8168 .58447 m .81859 .641 L .83515 .6351 L p .707 .577 .707 r
F P
0 g
s
.83515 .6351 m .83337 .57857 L .8168 .58447 L p .707 .577 .707 r
F P
0 g
s
.65201 .58706 m .6538 .6436 L .67466 .64774 L p .707 .577 .707 r
F P
0 g
s
.73455 .74198 m .73302 .72288 L .70191 .72475 L p .707 .577 .707 r
F P
0 g
s
.73302 .72288 m .73455 .74198 L .76627 .7392 L p .707 .577 .707 r
F P
0 g
s
.76627 .7392 m .76474 .7201 L .73302 .72288 L p .707 .577 .707 r
F P
0 g
s
.70191 .72475 m .70344 .74385 L .73455 .74198 L p .707 .577 .707 r
F P
0 g
s
.76474 .7201 m .76627 .7392 L .7955 .73576 L p .707 .577 .707 r
F P
0 g
s
.7955 .73576 m .79397 .71666 L .76474 .7201 L p .707 .577 .707 r
F P
0 g
s
.54518 .24457 m .54518 .74646 L .50063 .74451 L p .707 .577 .707 r
F P
0 g
s
.50063 .74451 m .50063 .24262 L .54518 .24457 L p .707 .577 .707 r
F P
0 g
s
.45603 .74636 m .45603 .24447 L .50063 .24262 L p .707 .577 .707 r
F P
0 g
s
.45603 .24447 m .45603 .74636 L .41573 .75181 L p .707 .577 .707 r
F P
0 g
s
.70344 .74385 m .70191 .72475 L .67447 .72551 L p .707 .577 .707 r
F P
0 g
s
.67649 .70355 m .67352 .66536 L .65271 .66478 L p .707 .577 .707 r
F P
0 g
s
.67447 .72551 m .67599 .7446 L .70344 .74385 L p .707 .577 .707 r
F P
0 g
s
.65271 .66478 m .65567 .70297 L .67649 .70355 L p .707 .577 .707 r
F P
0 g
s
.50063 .24262 m .50063 .74451 L .45603 .74636 L p .707 .577 .707 r
F P
0 g
s
.6538 .6436 m .65201 .58706 L .63965 .58162 L p .707 .577 .707 r
F P
0 g
s
.79397 .71666 m .7955 .73576 L .81938 .73201 L p .707 .577 .707 r
F P
0 g
s
.81938 .73201 m .81785 .71291 L .79397 .71666 L p .707 .577 .707 r
F P
0 g
s
.81709 .65321 m .82005 .69141 L .83657 .68768 L p .707 .577 .707 r
F P
0 g
s
.83657 .68768 m .83361 .64948 L .81709 .65321 L p .707 .577 .707 r
F P
0 g
s
.63965 .58162 m .64143 .63815 L .6538 .6436 L p .707 .577 .707 r
F P
0 g
s
.67599 .7446 m .67447 .72551 L .65337 .72509 L p .707 .577 .707 r
F P
0 g
s
.65337 .72509 m .65489 .74418 L .67599 .7446 L p .707 .577 .707 r
F P
0 g
s
.83337 .57857 m .83515 .6351 L .84247 .62874 L p .707 .577 .707 r
F P
0 g
s
.84247 .62874 m .84068 .5722 L .83337 .57857 L p .707 .577 .707 r
F P
0 g
s
.65567 .70297 m .65271 .66478 L .64037 .66308 L p .707 .577 .707 r
F P
0 g
s
.64037 .66308 m .64333 .70127 L .65567 .70297 L p .707 .577 .707 r
F P
0 g
s
.81785 .71291 m .81938 .73201 L .83557 .72832 L p .707 .577 .707 r
F P
0 g
s
.83557 .72832 m .83404 .70922 L .81785 .71291 L p .707 .577 .707 r
F P
0 g
s
.64143 .63815 m .63965 .58162 L .63699 .57541 L p .707 .577 .707 r
F P
0 g
s
.83361 .64948 m .83657 .68768 L .84386 .68431 L p .707 .577 .707 r
F P
0 g
s
.84386 .68431 m .8409 .64612 L .83361 .64948 L p .707 .577 .707 r
F P
0 g
s
.65489 .74418 m .65337 .72509 L .64068 .72353 L p .707 .577 .707 r
F P
0 g
s
.64068 .72353 m .64221 .74263 L .65489 .74418 L p .707 .577 .707 r
F P
0 g
s
.63699 .57541 m .63878 .63195 L .64143 .63815 L p .707 .577 .707 r
F P
0 g
s
.84068 .5722 m .84247 .62874 L .83981 .62253 L p .707 .577 .707 r
F P
0 g
s
.83981 .62253 m .83803 .566 L .84068 .5722 L p .707 .577 .707 r
F P
0 g
s
.64333 .70127 m .64037 .66308 L .63771 .66041 L p .707 .577 .707 r
F P
0 g
s
.83404 .70922 m .83557 .72832 L .84249 .72504 L p .707 .577 .707 r
F P
0 g
s
.84249 .72504 m .84096 .70594 L .83404 .70922 L p .707 .577 .707 r
F P
0 g
s
.63771 .66041 m .64067 .69861 L .64333 .70127 L p .707 .577 .707 r
F P
0 g
s
.63878 .63195 m .63699 .57541 L .6443 .56905 L p .707 .577 .707 r
F P
0 g
s
.8409 .64612 m .84386 .68431 L .8412 .68165 L p .707 .577 .707 r
F P
0 g
s
.8412 .68165 m .83824 .64345 L .8409 .64612 L p .707 .577 .707 r
F P
0 g
s
.64221 .74263 m .64068 .72353 L .63765 .72098 L p .707 .577 .707 r
F P
0 g
s
.63765 .72098 m .63917 .74008 L .64221 .74263 L p .707 .577 .707 r
F P
0 g
s
.6443 .56905 m .64609 .62558 L .63878 .63195 L p .707 .577 .707 r
F P
0 g
s
.83803 .566 m .83981 .62253 L .82745 .61709 L p .707 .577 .707 r
F P
0 g
s
.82745 .61709 m .82566 .56055 L .83803 .566 L p .707 .577 .707 r
F P
0 g
s
.64067 .69861 m .63771 .66041 L .645 .65705 L p .707 .577 .707 r
F P
0 g
s
.84096 .70594 m .84249 .72504 L .83945 .72249 L p .707 .577 .707 r
F P
0 g
s
.83945 .72249 m .83793 .7034 L .84096 .70594 L p .707 .577 .707 r
F P
0 g
s
.39069 .62393 m .38652 .56899 L .35549 .56895 L p .707 .577 .707 r
F P
0 g
s
.38652 .56899 m .39069 .62393 L .42247 .62095 L p .707 .577 .707 r
F P
0 g
s
.42247 .62095 m .4183 .56601 L .38652 .56899 L p .707 .577 .707 r
F P
0 g
s
.645 .65705 m .64796 .69524 L .64067 .69861 L p .707 .577 .707 r
F P
0 g
s
.4183 .56601 m .42247 .62095 L .45188 .61523 L p .707 .577 .707 r
F P
0 g
s
.45188 .61523 m .44771 .5603 L .4183 .56601 L p .707 .577 .707 r
F P
0 g
s
.64609 .62558 m .6443 .56905 L .66087 .56315 L p .707 .577 .707 r
F P
0 g
s
.35966 .62389 m .35549 .56895 L .32824 .5659 L p .707 .577 .707 r
F P
0 g
s
.35549 .56895 m .35966 .62389 L .39069 .62393 L p .707 .577 .707 r
F P
0 g
s
.44771 .5603 m .45188 .61523 L .47605 .60735 L p .707 .577 .707 r
F P
0 g
s
.47605 .60735 m .47187 .55241 L .44771 .5603 L p .707 .577 .707 r
F P
0 g
s
.83824 .64345 m .8412 .68165 L .82886 .67994 L p .707 .577 .707 r
F P
0 g
s
.82886 .67994 m .8259 .64175 L .83824 .64345 L p .707 .577 .707 r
F P
0 g
s
.63917 .74008 m .63765 .72098 L .64456 .7177 L p .707 .577 .707 r
F P
0 g
s
.64456 .7177 m .64609 .7368 L .63917 .74008 L p .707 .577 .707 r
F P
0 g
s
.66087 .56315 m .66266 .61968 L .64609 .62558 L p .707 .577 .707 r
F P
0 g
s
.82566 .56055 m .82745 .61709 L .80659 .61294 L p .707 .577 .707 r
F P
0 g
s
.80659 .61294 m .8048 .55641 L .82566 .56055 L p .707 .577 .707 r
F P
0 g
s
.33242 .62083 m .32824 .5659 L .30744 .56012 L p .707 .577 .707 r
F P
0 g
s
.32824 .5659 m .33242 .62083 L .35966 .62389 L p .707 .577 .707 r
F P
0 g
s
.39418 .68878 m .3873 .6532 L .35672 .65588 L p .707 .577 .707 r
F P
0 g
s
.3873 .6532 m .39418 .68878 L .42553 .68257 L p .707 .577 .707 r
F P
0 g
s
.42553 .68257 m .41865 .64699 L .3873 .6532 L p .707 .577 .707 r
F P
0 g
s
.41865 .64699 m .42553 .68257 L .4546 .67344 L p .707 .577 .707 r
F P
0 g
s
.4546 .67344 m .44772 .63786 L .41865 .64699 L p .707 .577 .707 r
F P
0 g
s
.64796 .69524 m .645 .65705 L .66152 .65331 L p .707 .577 .707 r
F P
0 g
s
.83793 .7034 m .83945 .72249 L .82677 .72094 L p .707 .577 .707 r
F P
0 g
s
.82677 .72094 m .82524 .70184 L .83793 .7034 L p .707 .577 .707 r
F P
0 g
s
.47187 .55241 m .47605 .60735 L .4926 .59807 L p .707 .577 .707 r
F P
0 g
s
.4926 .59807 m .48843 .54313 L .47187 .55241 L p .707 .577 .707 r
F P
0 g
s
.66152 .65331 m .66448 .69151 L .64796 .69524 L p .707 .577 .707 r
F P
0 g
s
.3636 .69146 m .35672 .65588 L .32991 .65477 L p .707 .577 .707 r
F P
0 g
s
.35672 .65588 m .3636 .69146 L .39418 .68878 L p .707 .577 .707 r
F P
0 g
s
.66266 .61968 m .66087 .56315 L .68507 .55829 L p .707 .577 .707 r
F P
0 g
s
.44772 .63786 m .4546 .67344 L .47853 .66228 L p .707 .577 .707 r
F P
0 g
s
.47853 .66228 m .47164 .6267 L .44772 .63786 L p .707 .577 .707 r
F P
0 g
s
.39201 .73133 m .38848 .71357 L .35785 .7165 L p .707 .577 .707 r
F P
0 g
s
.38848 .71357 m .39201 .73133 L .42331 .72486 L p .707 .577 .707 r
F P
0 g
s
.42331 .72486 m .41978 .7071 L .38848 .71357 L p .707 .577 .707 r
F P
0 g
s
.30744 .56012 m .31162 .61506 L .33242 .62083 L p .707 .577 .707 r
F P
0 g
s
.41978 .7071 m .42331 .72486 L .45221 .71547 L p .707 .577 .707 r
F P
0 g
s
.45221 .71547 m .44868 .69772 L .41978 .7071 L p .707 .577 .707 r
F P
0 g
s
.8259 .64175 m .82886 .67994 L .80805 .67937 L p .707 .577 .707 r
F P
0 g
s
.80805 .67937 m .80508 .64117 L .8259 .64175 L p .707 .577 .707 r
F P
0 g
s
.64609 .7368 m .64456 .7177 L .66076 .71401 L p .707 .577 .707 r
F P
0 g
s
.8048 .55641 m .80659 .61294 L .77926 .6105 L p .707 .577 .707 r
F P
0 g
s
.77926 .6105 m .77748 .55397 L .8048 .55641 L p .707 .577 .707 r
F P
0 g
s
.68507 .55829 m .68686 .61483 L .66266 .61968 L p .707 .577 .707 r
F P
0 g
s
.32991 .65477 m .33679 .69035 L .3636 .69146 L p .707 .577 .707 r
F P
0 g
s
.66076 .71401 m .66228 .73311 L .64609 .7368 L p .707 .577 .707 r
F P
0 g
s
.35785 .7165 m .36138 .73426 L .39201 .73133 L p .707 .577 .707 r
F P
0 g
s
.31162 .61506 m .30744 .56012 L .29513 .5522 L p .707 .577 .707 r
F P
0 g
s
.36138 .73426 m .35785 .7165 L .33087 .7156 L p .707 .577 .707 r
F P
0 g
s
.33679 .69035 m .32991 .65477 L .3095 .64998 L p .707 .577 .707 r
F P
0 g
s
.44868 .69772 m .45221 .71547 L .47587 .70409 L p .707 .577 .707 r
F P
0 g
s
.47587 .70409 m .47234 .68634 L .44868 .69772 L p .707 .577 .707 r
F P
0 g
s
.47164 .6267 m .47853 .66228 L .49497 .65019 L p .707 .577 .707 r
F P
0 g
s
.49497 .65019 m .48809 .61461 L .47164 .6267 L p .707 .577 .707 r
F P
0 g
s
.68686 .61483 m .68507 .55829 L .71453 .55496 L p .707 .577 .707 r
F P
0 g
s
.33087 .7156 m .3344 .73335 L .36138 .73426 L p .707 .577 .707 r
F P
0 g
s
.66448 .69151 m .66152 .65331 L .68565 .64958 L p .707 .577 .707 r
F P
0 g
s
.48843 .54313 m .4926 .59807 L .49993 .5883 L p .707 .577 .707 r
F P
0 g
s
.49993 .5883 m .49575 .53336 L .48843 .54313 L p .707 .577 .707 r
F P
0 g
s
.68565 .64958 m .68861 .68777 L .66448 .69151 L p .707 .577 .707 r
F P
0 g
s
.82524 .70184 m .82677 .72094 L .80567 .72052 L p .707 .577 .707 r
F P
0 g
s
.80567 .72052 m .80414 .70142 L .82524 .70184 L p .707 .577 .707 r
F P
0 g
s
.77748 .55397 m .77926 .6105 L .74816 .61 L p .707 .577 .707 r
F P
0 g
s
.74816 .61 m .74638 .55347 L .77748 .55397 L p .707 .577 .707 r
F P
0 g
s
.3095 .64998 m .31638 .68556 L .33679 .69035 L p .707 .577 .707 r
F P
0 g
s
.29513 .5522 m .29931 .60713 L .31162 .61506 L p .707 .577 .707 r
F P
0 g
s
.71453 .55496 m .71632 .61149 L .68686 .61483 L p .707 .577 .707 r
F P
0 g
s
.71632 .61149 m .71453 .55496 L .74638 .55347 L p .707 .577 .707 r
F P
0 g
s
.3344 .73335 m .33087 .7156 L .3102 .71095 L p .707 .577 .707 r
F P
0 g
s
.80508 .64117 m .80805 .67937 L .78079 .67998 L p .707 .577 .707 r
F P
0 g
s
.78079 .67998 m .77782 .64178 L .80508 .64117 L p .707 .577 .707 r
F P
0 g
s
.74638 .55347 m .74816 .61 L .71632 .61149 L p .707 .577 .707 r
F P
0 g
s
.47234 .68634 m .47587 .70409 L .49199 .69184 L p .707 .577 .707 r
F P
0 g
s
.49199 .69184 m .48846 .67408 L .47234 .68634 L p .707 .577 .707 r
F P
0 g
s
.66228 .73311 m .66076 .71401 L .68464 .71026 L p .707 .577 .707 r
F P
0 g
s
.3102 .71095 m .31373 .7287 L .3344 .73335 L p .707 .577 .707 r
F P
0 g
s
.68464 .71026 m .68616 .72936 L .66228 .73311 L p .707 .577 .707 r
F P
0 g
s
.31638 .68556 m .3095 .64998 L .29748 .64197 L p .707 .577 .707 r
F P
0 g
s
.29931 .60713 m .29513 .5522 L .29251 .54289 L p .707 .577 .707 r
F P
0 g
s
.68861 .68777 m .68565 .64958 L .71503 .6462 L p .707 .577 .707 r
F P
0 g
s
.48809 .61461 m .49497 .65019 L .50233 .63835 L p .707 .577 .707 r
F P
0 g
s
.50233 .63835 m .49545 .60276 L .48809 .61461 L p .707 .577 .707 r
F P
0 g
s
.71503 .6462 m .718 .68439 L .68861 .68777 L p .707 .577 .707 r
F P
0 g
s
.77782 .64178 m .78079 .67998 L .74976 .68171 L p .707 .577 .707 r
F P
0 g
s
.74976 .68171 m .7468 .64351 L .77782 .64178 L p .707 .577 .707 r
F P
0 g
s
.80414 .70142 m .80567 .72052 L .77822 .72127 L p .707 .577 .707 r
F P
0 g
s
.77822 .72127 m .77669 .70218 L .80414 .70142 L p .707 .577 .707 r
F P
0 g
s
.49575 .53336 m .49993 .5883 L .49731 .579 L p .707 .577 .707 r
F P
0 g
s
.49731 .579 m .49313 .52406 L .49575 .53336 L p .707 .577 .707 r
F P
0 g
s
.29748 .64197 m .30436 .67755 L .31638 .68556 L p .707 .577 .707 r
F P
0 g
s
.718 .68439 m .71503 .6462 L .7468 .64351 L p .707 .577 .707 r
F P
0 g
s
.31373 .7287 m .3102 .71095 L .29785 .70301 L p .707 .577 .707 r
F P
0 g
s
.7468 .64351 m .74976 .68171 L .718 .68439 L p .707 .577 .707 r
F P
0 g
s
.68616 .72936 m .68464 .71026 L .71387 .70682 L p .707 .577 .707 r
F P
0 g
s
.29251 .54289 m .29668 .59783 L .29931 .60713 L p .707 .577 .707 r
F P
0 g
s
.48846 .67408 m .49199 .69184 L .49898 .6799 L p .707 .577 .707 r
F P
0 g
s
.49898 .6799 m .49545 .66214 L .48846 .67408 L p .707 .577 .707 r
F P
0 g
s
.71387 .70682 m .7154 .72592 L .68616 .72936 L p .707 .577 .707 r
F P
0 g
s
.29785 .70301 m .30138 .72077 L .31373 .7287 L p .707 .577 .707 r
F P
0 g
s
.77669 .70218 m .77822 .72127 L .74712 .72314 L p .707 .577 .707 r
F P
0 g
s
.74712 .72314 m .74559 .70404 L .77669 .70218 L p .707 .577 .707 r
F P
0 g
s
.30436 .67755 m .29748 .64197 L .29503 .63153 L p .708 .578 .707 r
F P
0 g
s
.7154 .72592 m .71387 .70682 L .74559 .70404 L p .707 .577 .707 r
F P
0 g
s
.49545 .60276 m .50233 .63835 L .49988 .62791 L p .708 .578 .707 r
F P
0 g
s
.49988 .62791 m .493 .59233 L .49545 .60276 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29668 .59783 m .29251 .54289 L .29984 .53312 L p .707 .577 .707 r
F P
0 g
s
.74559 .70404 m .74712 .72314 L .7154 .72592 L p .707 .577 .707 r
F P
0 g
s
.29503 .63153 m .30191 .66711 L .30436 .67755 L p .708 .578 .707 r
F P
0 g
s
.49313 .52406 m .49731 .579 L .48499 .57107 L p .707 .577 .707 r
F P
0 g
s
.48499 .57107 m .48082 .51613 L .49313 .52406 L p .707 .577 .707 r
F P
0 g
s
.30138 .72077 m .29785 .70301 L .29503 .69256 L p .707 .578 .707 r
F P
0 g
s
.49545 .66214 m .49898 .6799 L .49616 .66945 L p .707 .578 .707 r
F P
0 g
s
.49616 .66945 m .49263 .65169 L .49545 .66214 L p .707 .578 .707 r
F P
0 g
s
.29984 .53312 m .30401 .58806 L .29668 .59783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29503 .69256 m .29856 .71032 L .30138 .72077 L p .707 .578 .707 r
F P
0 g
s
.30191 .66711 m .29503 .63153 L .30239 .61969 L p .707 .577 .707 r
F P
0 g
s
.493 .59233 m .49988 .62791 L .48786 .6199 L p .707 .577 .707 r
F P
0 g
s
.48786 .6199 m .48098 .58432 L .493 .59233 L p .707 .577 .707 r
F P
0 g
s
.30401 .58806 m .29984 .53312 L .31639 .52384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30239 .61969 m .30927 .65527 L .30191 .66711 L p .707 .577 .707 r
F P
0 g
s
.48082 .51613 m .48499 .57107 L .46419 .56529 L p .707 .577 .707 r
F P
0 g
s
.46419 .56529 m .46002 .51036 L .48082 .51613 L p .707 .577 .707 r
F P
0 g
s
.29856 .71032 m .29503 .69256 L .30202 .68063 L p .707 .577 .707 r
F P
0 g
s
.31639 .52384 m .32057 .57878 L .30401 .58806 L p .707 .577 .707 r
F P
0 g
s
.49263 .65169 m .49616 .66945 L .48381 .66151 L p .707 .577 .707 r
F P
0 g
s
.48381 .66151 m .48028 .64376 L .49263 .65169 L p .707 .577 .707 r
F P
0 g
s
.30202 .68063 m .30555 .69838 L .29856 .71032 L p .707 .577 .707 r
F P
0 g
s
.32057 .57878 m .31639 .52384 L .34056 .51596 L p .707 .577 .707 r
F P
0 g
s
.30927 .65527 m .30239 .61969 L .31884 .6076 L p .707 .577 .707 r
F P
0 g
s
.48098 .58432 m .48786 .6199 L .46745 .61511 L p .707 .577 .707 r
F P
0 g
s
.46745 .61511 m .46057 .57953 L .48098 .58432 L p .707 .577 .707 r
F P
0 g
s
.46002 .51036 m .46419 .56529 L .43695 .56224 L p .707 .577 .707 r
F P
0 g
s
.43695 .56224 m .43277 .5073 L .46002 .51036 L p .707 .577 .707 r
F P
0 g
s
.31884 .6076 m .32572 .64318 L .30927 .65527 L p .707 .577 .707 r
F P
0 g
s
.30555 .69838 m .30202 .68063 L .31814 .66837 L p .707 .577 .707 r
F P
0 g
s
.34056 .51596 m .34473 .57089 L .32057 .57878 L p .707 .577 .707 r
F P
0 g
s
.34473 .57089 m .34056 .51596 L .36997 .51025 L p .707 .577 .707 r
F P
0 g
s
.48028 .64376 m .48381 .66151 L .46314 .65686 L p .707 .577 .707 r
F P
0 g
s
.46314 .65686 m .45961 .63911 L .48028 .64376 L p .707 .577 .707 r
F P
0 g
s
.31814 .66837 m .32167 .68612 L .30555 .69838 L p .707 .577 .707 r
F P
0 g
s
.43277 .5073 m .43695 .56224 L .40592 .5622 L p .707 .577 .707 r
F P
0 g
s
.40592 .5622 m .40174 .50726 L .43277 .5073 L p .707 .577 .707 r
F P
0 g
s
.32572 .64318 m .31884 .6076 L .34276 .59644 L p .707 .577 .707 r
F P
0 g
s
.46057 .57953 m .46745 .61511 L .44064 .614 L p .707 .577 .707 r
F P
0 g
s
.44064 .614 m .43376 .57842 L .46057 .57953 L p .707 .577 .707 r
F P
0 g
s
.37414 .56518 m .36997 .51025 L .40174 .50726 L p .707 .577 .707 r
F P
0 g
s
.36997 .51025 m .37414 .56518 L .34473 .57089 L p .707 .577 .707 r
F P
0 g
s
.40174 .50726 m .40592 .5622 L .37414 .56518 L p .707 .577 .707 r
F P
0 g
s
.34276 .59644 m .34964 .63202 L .32572 .64318 L p .707 .577 .707 r
F P
0 g
s
.32167 .68612 m .31814 .66837 L .3418 .65699 L p .707 .577 .707 r
F P
0 g
s
.34964 .63202 m .34276 .59644 L .37183 .58731 L p .707 .577 .707 r
F P
0 g
s
.45961 .63911 m .46314 .65686 L .43616 .65596 L p .707 .577 .707 r
F P
0 g
s
.43616 .65596 m .43263 .6382 L .45961 .63911 L p .707 .577 .707 r
F P
0 g
s
.43376 .57842 m .44064 .614 L .41006 .61668 L p .707 .577 .707 r
F P
0 g
s
.41006 .61668 m .40318 .5811 L .43376 .57842 L p .707 .577 .707 r
F P
0 g
s
.3418 .65699 m .34533 .67474 L .32167 .68612 L p .707 .577 .707 r
F P
0 g
s
.37871 .62289 m .37183 .58731 L .40318 .5811 L p .707 .577 .707 r
F P
0 g
s
.37183 .58731 m .37871 .62289 L .34964 .63202 L p .707 .577 .707 r
F P
0 g
s
.40318 .5811 m .41006 .61668 L .37871 .62289 L p .707 .577 .707 r
F P
0 g
s
.34533 .67474 m .3418 .65699 L .3707 .6476 L p .707 .577 .707 r
F P
0 g
s
.43263 .6382 m .43616 .65596 L .40552 .65889 L p .707 .577 .707 r
F P
0 g
s
.40552 .65889 m .40199 .64113 L .43263 .6382 L p .707 .577 .707 r
F P
0 g
s
.3707 .6476 m .37423 .66536 L .34533 .67474 L p .707 .577 .707 r
F P
0 g
s
.37423 .66536 m .3707 .6476 L .40199 .64113 L p .707 .577 .707 r
F P
0 g
s
.40199 .64113 m .40552 .65889 L .37423 .66536 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00L7oo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF4P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol90004FUH00`00FUIJEP06FUH01000FUIJEUYF1P002EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001OOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040005
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool005]oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00F7oo0P001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJ
EP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
05Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ao
o`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEUYF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0000?OolI000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00009Ool60004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@00<Goo
001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH015YF4`0015YF1P0015YF00@005YF
FUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00l0
00=JEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF009JEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP02FUH400000eYF001JEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF
000015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP800003FUH0000000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03
001JEP0000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEPh0009JEP03001JEUYF009JEP@0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP04001JEP00000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUIJEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00E7oo00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<00004FUH005YF000;FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001J
EP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000oOolB0003Ool20002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03
FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool003Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Goo000cOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUIJEP00FUH00P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00<Goo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF0000
05YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP02
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJ
EP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000]Ool002io
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL0009JEP@0009JEP03001JEUYF009J
EP<00004FUH005YFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40002FUH2000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@0009JEPL000IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPX0009JEP03001JEUYF00QJEP03001JEUYF00=J
EP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP03001JEP00008000AJEP03001JEUYF00QJEP04001JEUYFFUH20004FUH01000
FUH000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF1000
00=JEP00FUH015YF1P000eYF00<005YFFUH025YF00H005YF000005YF0004FUH01000FUIJEP002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00@005YFFUIJEP<0009JEP03001JEP0000EJEPH0
00=JEP03001JEUYF00QJEP8000=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP001EYF00@005YF0000009JEP06001JEUYF001JEP001EYF1P000eYF3P000eYF00D0
05YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP8000AJEP06001JEUYF001J
EP001EYF00<005YF00001`000eYF00<005YFFUH01EYF00<005YF00000`0015YF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF5P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH20005FUH01P00FUIJEP00FUH000AJ
EP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00EJEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP04FUH01@00FUIJEP00FUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`0000AJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEP00FUH>0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJ
EP060005FUH00`00FUH0000300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUH00003000>Ool50004Ool50002FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH=0004FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001J
EP0000AJEP80009JEP03001JEP0000<000Yoo`D000Uoo`04FUH005YF0004FUH00`00FUH000020008
FUH00`00FUIJEP04FUH70008FUH00`00FUIJEP02FUH300001eYF001JEUYF001JEP0000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP00009JEP8000AJEP03001JEUYF00=JEPl000Uoo`04FUH005YF0004FUH2
0002FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005FUH00`00FUIJEP050004FUH0
0`00FUIJEP02FUH>0002FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF0P0000=JEP0000002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00;7oo00<005YF00000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000AJEP00FUH000MJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP000006FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000001eYF0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002eoo`00;7oo0P000eYF00<005YFFUH00P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0000=JEP00FUH01UYF0P000UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP<000IJEP03001JEP00008000AJEP03001JEUYF00AJEP03
001JEP00009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQl002eoo`00;7oo0P000UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0`0000=JEP00FUH01UYF00<005YFFUH015YF1@000UYF1@001eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH300000eYF001JEP06FUH00`00FUIJEP02FUH9
00000eYF001JEP09FUH01000FUIJEUYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPT000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<002ioo`00;Goo0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP800003
FUH005YF00h00003FUH0000000@000=JEP03001JEUYF00QJEP06001JEP00001JEP0015YF00@005YF
FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH60007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000^Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUH000020004FUH00`00FUIJEP08
FUH20003FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPP003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
0UYF200015YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP06001JEP00001JEP00
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@00?goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH60008FUH90004FUH20005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH005YF00IJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEQ0000=ooa@0035oo`00;Goo0P00
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF1P001EYF00<005YFFUH015YF
00H005YFFUH005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
00000eYF000000060002FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000]
Ool002eoo`8000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P00
0eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH60007FUH01000FUIJ
EUYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF00000eYF10000UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF0P001Goo10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80009JEP@000EJEP07001JEUYFFUH005YF00000UYF2@0015YF
00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP00008000]oo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH?0004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
1000FUH000004goo4`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH2000]Ool002ao
o`<00003FUH007oo00eoo`P000moo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0005FUH9000]Ool002aoo`<0009JEP03001oogoo00Eoo`H000=JEP03001JEUYF009J
EPT000Moo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF0`000goo0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000goo0`000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;7oo0P000eYF00<005YFFUH00`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000Aoo`l0009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00009JEPH000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH5000bOol002aoo`8000=JEP04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0027oo0`0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2000=goo000/Ool20003FUH30006FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004Ool200001EYF000005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
0UYF4P00?goo000]Ool00`00FUIJEP0200000eYF001JEP04FUH60008Ool90004FUH00`00FUIJEP05
FUH50003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP04FUH<
0006FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUHG001AOol002eoo`03001JEP00
00=JEP04001JEUYFFUH20004FUH4000?Ool60006FUH00`00FUIJEP020003FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH<0005FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUH00002001JOol002ioo`8000=JEP03001JEP00
008000MJEP03001JEP0000<0015oo`8000AJEP03001JEUYF009JEP800005FUH00000FUH00005FUH0
0`00FUIJEP05FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80007FUH0
0`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2001HOol002ioo`8000=JEP80009JEP03
001JEUYF00EJEP03001JEUYF00=JEQ40009JEP<00003FUH005YF00AJEP@00003FUH005YF00AJEP03
001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP<005Ioo`00;Goo0P000UYF
0P000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
000000EJEP06001JEP00001JEP001EYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YF
00001EYF00<005YFFUH015YF00@005YFFUH005Eoo`00;Goo10001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP00
1EYF0P001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF0P001EYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;Goo
0P000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF0P0000MJEP00FUIJEP00FUH00003FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30003FUH00`00FUH00005FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20005Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000000UYF00@005YF
001JEP800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0005FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH005Aoo`00;7oo0`001Woo0`001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00H005YFFUH005YF001DOol002aoo`03001JEP00
00Uoo`8000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003Ool0
05YF00<000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03001JEUYF00AJEP03001JEUYF
008005Eoo`00;7oo00@005YF000000Yoo`<00003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000Aoo`@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@000AJEP04
001JEUYFFUH2001EOol002aoo`80009JEP03001oogoo00Yoo`@000IJEPD000AJEP03001JEUYF00EJ
EP03001JEP0000<000Moo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00004FUH300000eYF001JEP02FUH2001EOol002eoo`05001JEUYFFUH0000?Ool40002FUH40005
FUH00`00FUIJEP02FUH5000;Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP04FUH30003FUH2001EOol002eoo`04001JEUYFFUH3000AOol@000@Ool30004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH02000FUIJEP00FUH005YF001E
Ool002ioo`04001JEUYF0002FUH00`00Oomoo`0^Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH300000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00Ool0E7oo000_Ool00`00FUH00003FUH2
000/Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000006FUH00`00FUIJEP02
FUH2001FOol0031oo`8000EJEP8002Qoo`80009JEP03001oogoo0080009JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP02FUH30003FUH01000FUIJEUYF0`00EWoo000aOol00`00FUIJEP03
FUH00`00FUH00003000ROol20003FUH20004Ool30008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01EYF
0`0015YF00<005YF0000EWoo000bOol20003FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02
FUH00`00Oomoo`05Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP06FUH00`00FUH00005001GOol003Aoo`04
001JEUYF0007FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF00002Woo10000UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH010000Woo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00F7oo000eOol30007FUH00`00FUIJEP04FUH@0003
FUH00`00FUIJEP04FUH01000FUIJEP003goo1@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2P001Goo10001UYF00<005YFFUH015YF0`00EWoo000gOol20006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000EOol60003FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@002Goo10000UYF00<005YFFUH015YF00@005YF
FUH005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P007Goo80000eYF00<005YF00000`000Woo1@003Goo100015YF00D005YFFUIJEP0005Eo
o`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH00eYF1`004Goo0`0000=JEP00FUH00UYF0P00E7oo0011Ool40002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH6000lOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000;
Ool20002FUH00`00FUH0001DOol004Eooa0004Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPh00004FUH005YF001DOol009ioo`@000IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH3001EOol00:9oo`@0009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00YWoo1@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000EGoo002[Ool40002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2001FOol00:mooaL005Moo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5928 .74367 m .59953 .68777 L .56868 .68258 L p .707 .577 .707 r
F P
0 g
s
.59953 .68777 m .5928 .74367 L .62446 .74675 L p .707 .577 .707 r
F P
0 g
s
.62446 .74675 m .63119 .69086 L .59953 .68777 L p .707 .577 .707 r
F P
0 g
s
.63119 .69086 m .62446 .74675 L .65381 .74743 L p .707 .577 .707 r
F P
0 g
s
.65381 .74743 m .66054 .69154 L .63119 .69086 L p .707 .577 .707 r
F P
0 g
s
.56194 .73847 m .56868 .68258 L .54164 .67578 L p .707 .577 .707 r
F P
0 g
s
.56868 .68258 m .56194 .73847 L .5928 .74367 L p .707 .577 .707 r
F P
0 g
s
.66054 .69154 m .65381 .74743 L .67799 .74563 L p .707 .577 .707 r
F P
0 g
s
.67799 .74563 m .68472 .68974 L .66054 .69154 L p .707 .577 .707 r
F P
0 g
s
.54164 .67578 m .5349 .73168 L .56194 .73847 L p .707 .577 .707 r
F P
0 g
s
.58602 .79515 m .59703 .75872 L .56733 .74877 L p .707 .577 .707 r
F P
0 g
s
.59703 .75872 m .58602 .79515 L .61658 .80386 L p .707 .577 .707 r
F P
0 g
s
.61658 .80386 m .62759 .76742 L .59703 .75872 L p .707 .577 .707 r
F P
0 g
s
.5349 .73168 m .54164 .67578 L .52107 .66805 L p .707 .577 .707 r
F P
0 g
s
.62759 .76742 m .61658 .80386 L .64501 .81047 L p .707 .577 .707 r
F P
0 g
s
.64501 .81047 m .65602 .77403 L .62759 .76742 L p .707 .577 .707 r
F P
0 g
s
.56733 .74877 m .55632 .78521 L .58602 .79515 L p .707 .577 .707 r
F P
0 g
s
.55632 .78521 m .56733 .74877 L .5414 .73856 L p .707 .577 .707 r
F P
0 g
s
.5414 .73856 m .53039 .775 L .55632 .78521 L p .707 .577 .707 r
F P
0 g
s
.52107 .66805 m .51433 .72395 L .5349 .73168 L p .707 .577 .707 r
F P
0 g
s
.65602 .77403 m .64501 .81047 L .66853 .81435 L p .707 .577 .707 r
F P
0 g
s
.66853 .81435 m .67954 .77791 L .65602 .77403 L p .707 .577 .707 r
F P
0 g
s
.59332 .83665 m .59897 .81846 L .56921 .80836 L p .707 .577 .707 r
F P
0 g
s
.59897 .81846 m .59332 .83665 L .62376 .84552 L p .707 .577 .707 r
F P
0 g
s
.62376 .84552 m .62941 .82733 L .59897 .81846 L p .707 .577 .707 r
F P
0 g
s
.68472 .68974 m .67799 .74563 L .69463 .74153 L p .707 .577 .707 r
F P
0 g
s
.69463 .74153 m .70136 .68564 L .68472 .68974 L p .707 .577 .707 r
F P
0 g
s
.56921 .80836 m .56355 .82655 L .59332 .83665 L p .707 .577 .707 r
F P
0 g
s
.62941 .82733 m .62376 .84552 L .65189 .85231 L p .707 .577 .707 r
F P
0 g
s
.65189 .85231 m .65755 .83411 L .62941 .82733 L p .707 .577 .707 r
F P
0 g
s
.53039 .775 m .5414 .73856 L .52178 .72908 L p .707 .577 .707 r
F P
0 g
s
.56355 .82655 m .56921 .80836 L .54303 .79802 L p .707 .577 .707 r
F P
0 g
s
.54303 .79802 m .53738 .81622 L .56355 .82655 L p .707 .577 .707 r
F P
0 g
s
.51433 .72395 m .52107 .66805 L .50897 .66015 L p .707 .577 .707 r
F P
0 g
s
.52178 .72908 m .51077 .76552 L .53039 .775 L p .707 .577 .707 r
F P
0 g
s
.65755 .83411 m .65189 .85231 L .67497 .85633 L p .707 .577 .707 r
F P
0 g
s
.67497 .85633 m .68063 .83814 L .65755 .83411 L p .707 .577 .707 r
F P
0 g
s
.53738 .81622 m .54303 .79802 L .52301 .78847 L p .707 .577 .707 r
F P
0 g
s
.67954 .77791 m .66853 .81435 L .68484 .8151 L p .707 .577 .707 r
F P
0 g
s
.68484 .8151 m .69585 .77866 L .67954 .77791 L p .707 .577 .707 r
F P
0 g
s
.50897 .66015 m .50224 .71604 L .51433 .72395 L p .707 .577 .707 r
F P
0 g
s
.52301 .78847 m .51736 .80666 L .53738 .81622 L p .707 .577 .707 r
F P
0 g
s
.70136 .68564 m .69463 .74153 L .7021 .73554 L p .707 .577 .707 r
F P
0 g
s
.7021 .73554 m .70883 .67964 L .70136 .68564 L p .707 .577 .707 r
F P
0 g
s
.51077 .76552 m .52178 .72908 L .51039 .72127 L p .707 .577 .707 r
F P
0 g
s
.51039 .72127 m .49938 .7577 L .51077 .76552 L p .707 .577 .707 r
F P
0 g
s
.50224 .71604 m .50897 .66015 L .50654 .65284 L p .707 .577 .707 r
F P
0 g
s
.68063 .83814 m .67497 .85633 L .69073 .85721 L p .707 .577 .707 r
F P
0 g
s
.69073 .85721 m .69639 .83902 L .68063 .83814 L p .707 .577 .707 r
F P
0 g
s
.51736 .80666 m .52301 .78847 L .5111 .78062 L p .707 .577 .707 r
F P
0 g
s
.5111 .78062 m .50544 .79882 L .51736 .80666 L p .707 .577 .707 r
F P
0 g
s
.69585 .77866 m .68484 .8151 L .69233 .81267 L p .707 .577 .707 r
F P
0 g
s
.69233 .81267 m .70334 .77623 L .69585 .77866 L p .707 .577 .707 r
F P
0 g
s
.50654 .65284 m .49981 .70873 L .50224 .71604 L p .707 .577 .707 r
F P
0 g
s
.49938 .7577 m .51039 .72127 L .50834 .71587 L p .707 .577 .707 r
F P
0 g
s
.70883 .67964 m .7021 .73554 L .69967 .72822 L p .707 .577 .707 r
F P
0 g
s
.69967 .72822 m .7064 .67233 L .70883 .67964 L p .707 .577 .707 r
F P
0 g
s
.50834 .71587 m .49733 .75231 L .49938 .7577 L p .707 .577 .707 r
F P
0 g
s
.49981 .70873 m .50654 .65284 L .51401 .64684 L p .707 .577 .707 r
F P
0 g
s
.50847 .77526 m .50281 .79345 L .50544 .79882 L p .707 .577 .707 r
F P
0 g
s
.51401 .64684 m .50728 .70273 L .49981 .70873 L p .707 .577 .707 r
F P
0 g
s
.49733 .75231 m .50834 .71587 L .51584 .71344 L p .707 .577 .707 r
F P
0 g
s
.51584 .71344 m .50483 .74988 L .49733 .75231 L p .707 .577 .707 r
F P
0 g
s
.50544 .79882 m .5111 .78062 L .50847 .77526 L p .707 .577 .707 r
F P
0 g
s
.50281 .79345 m .50847 .77526 L .51537 .7729 L p .707 .577 .707 r
F P
0 g
s
.51537 .7729 m .50971 .7911 L .50281 .79345 L p .707 .577 .707 r
F P
0 g
s
.50483 .74988 m .51584 .71344 L .53214 .71419 L p .707 .577 .707 r
F P
0 g
s
.53214 .71419 m .52113 .75063 L .50483 .74988 L p .707 .577 .707 r
F P
0 g
s
.50488 .8219 m .50488 .32001 L .4601 .31852 L p .707 .577 .707 r
F P
0 g
s
.50728 .70273 m .51401 .64684 L .53065 .64274 L p .707 .577 .707 r
F P
0 g
s
.53065 .64274 m .52392 .69863 L .50728 .70273 L p .707 .577 .707 r
F P
0 g
s
.52392 .69863 m .53065 .64274 L .55483 .64094 L p .707 .577 .707 r
F P
0 g
s
.50971 .7911 m .51537 .7729 L .53113 .77378 L p .707 .577 .707 r
F P
0 g
s
.53113 .77378 m .52547 .79197 L .50971 .7911 L p .707 .577 .707 r
F P
0 g
s
.55483 .64094 m .5481 .69683 L .52392 .69863 L p .707 .577 .707 r
F P
0 g
s
.52113 .75063 m .53214 .71419 L .55566 .71807 L p .707 .577 .707 r
F P
0 g
s
.55566 .71807 m .54465 .75451 L .52113 .75063 L p .707 .577 .707 r
F P
0 g
s
.52547 .79197 m .53113 .77378 L .55421 .77781 L p .707 .577 .707 r
F P
0 g
s
.55421 .77781 m .54855 .796 L .52547 .79197 L p .707 .577 .707 r
F P
0 g
s
.50488 .32001 m .50488 .8219 L .54919 .8196 L p .707 .577 .707 r
F P
0 g
s
.5481 .69683 m .55483 .64094 L .58419 .64162 L p .707 .577 .707 r
F P
0 g
s
.58419 .64162 m .57745 .69751 L .5481 .69683 L p .707 .577 .707 r
F P
0 g
s
.54465 .75451 m .55566 .71807 L .58409 .72468 L p .707 .577 .707 r
F P
0 g
s
.58409 .72468 m .57308 .76112 L .54465 .75451 L p .707 .577 .707 r
F P
0 g
s
.54855 .796 m .55421 .77781 L .58234 .78459 L p .707 .577 .707 r
F P
0 g
s
.58234 .78459 m .57669 .80278 L .54855 .796 L p .707 .577 .707 r
F P
0 g
s
.54919 .8196 m .54919 .31771 L .50488 .32001 L p .707 .577 .707 r
F P
0 g
s
.69639 .83902 m .69073 .85721 L .69763 .85485 L p .707 .577 .707 r
F P
0 g
s
.69763 .85485 m .70329 .83666 L .69639 .83902 L p .707 .577 .707 r
F P
0 g
s
.4601 .82041 m .4601 .31852 L .41921 .3134 L p .707 .577 .707 r
F P
0 g
s
.4601 .31852 m .4601 .82041 L .50488 .8219 L p .707 .577 .707 r
F P
0 g
s
.57745 .69751 m .58419 .64162 L .61584 .64471 L p .707 .577 .707 r
F P
0 g
s
.61584 .64471 m .60911 .7006 L .57745 .69751 L p .707 .577 .707 r
F P
0 g
s
.57308 .76112 m .58409 .72468 L .61466 .73339 L p .707 .577 .707 r
F P
0 g
s
.61466 .73339 m .60365 .76982 L .57308 .76112 L p .707 .577 .707 r
F P
0 g
s
.57669 .80278 m .58234 .78459 L .61278 .79347 L p .707 .577 .707 r
F P
0 g
s
.61278 .79347 m .60713 .81166 L .57669 .80278 L p .707 .577 .707 r
F P
0 g
s
.54919 .31771 m .54919 .8196 L .58869 .81374 L p .707 .577 .707 r
F P
0 g
s
.58869 .81374 m .58869 .31185 L .54919 .31771 L p .707 .577 .707 r
F P
0 g
s
.70334 .77623 m .69233 .81267 L .69029 .80727 L p .707 .577 .707 r
F P
0 g
s
.69029 .80727 m .7013 .77084 L .70334 .77623 L p .707 .577 .707 r
F P
0 g
s
.41921 .81528 m .41921 .3134 L .38624 .30513 L p .707 .577 .707 r
F P
0 g
s
.41921 .3134 m .41921 .81528 L .4601 .82041 L p .707 .577 .707 r
F P
0 g
s
.7064 .67233 m .69967 .72822 L .68758 .72032 L p .707 .577 .707 r
F P
0 g
s
.68758 .72032 m .69431 .66443 L .7064 .67233 L p .707 .577 .707 r
F P
0 g
s
.6467 .6499 m .63997 .70579 L .60911 .7006 L p .707 .577 .707 r
F P
0 g
s
.60911 .7006 m .61584 .64471 L .6467 .6499 L p .707 .577 .707 r
F P
0 g
s
.64435 .74333 m .63334 .77977 L .60365 .76982 L p .707 .577 .707 r
F P
0 g
s
.60365 .76982 m .61466 .73339 L .64435 .74333 L p .707 .577 .707 r
F P
0 g
s
.60713 .81166 m .61278 .79347 L .64255 .80356 L p .707 .577 .707 r
F P
0 g
s
.58869 .31185 m .58869 .81374 L .6195 .80489 L p .707 .577 .707 r
F P
0 g
s
.6195 .80489 m .6195 .30301 L .58869 .31185 L p .707 .577 .707 r
F P
0 g
s
.2511 .72293 m .25398 .66963 L .22293 .66536 L p .707 .577 .707 r
F P
0 g
s
.25398 .66963 m .2511 .72293 L .28292 .72344 L p .707 .577 .707 r
F P
0 g
s
.28292 .72344 m .28581 .67015 L .25398 .66963 L p .707 .577 .707 r
F P
0 g
s
.28581 .67015 m .28292 .72344 L .31242 .72015 L p .707 .577 .707 r
F P
0 g
s
.31242 .72015 m .3153 .66685 L .28581 .67015 L p .707 .577 .707 r
F P
0 g
s
.70329 .83666 m .69763 .85485 L .695 .84949 L p .707 .577 .707 r
F P
0 g
s
.695 .84949 m .70065 .8313 L .70329 .83666 L p .707 .577 .707 r
F P
0 g
s
.22005 .71866 m .22293 .66536 L .1957 .65776 L p .707 .577 .707 r
F P
0 g
s
.22293 .66536 m .22005 .71866 L .2511 .72293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3153 .66685 m .31242 .72015 L .33668 .71337 L p .707 .577 .707 r
F P
0 g
s
.33668 .71337 m .33957 .66008 L .3153 .66685 L p .707 .577 .707 r
F P
0 g
s
.7013 .77084 m .69029 .80727 L .67889 .79946 L p .707 .577 .707 r
F P
0 g
s
.67889 .79946 m .6899 .76302 L .7013 .77084 L p .707 .577 .707 r
F P
0 g
s
.19282 .71105 m .1957 .65776 L .17496 .64756 L p .707 .577 .707 r
F P
0 g
s
.1957 .65776 m .19282 .71105 L .22005 .71866 L p .707 .577 .707 r
F P
0 g
s
.69431 .66443 m .68758 .72032 L .667 .71259 L p .707 .577 .707 r
F P
0 g
s
.667 .71259 m .67374 .6567 L .69431 .66443 L p .707 .577 .707 r
F P
0 g
s
.38624 .80702 m .38624 .30513 L .3644 .29453 L p .707 .577 .707 r
F P
0 g
s
.38624 .30513 m .38624 .80702 L .41921 .81528 L p .707 .577 .707 r
F P
0 g
s
.67028 .75354 m .65927 .78998 L .63334 .77977 L p .707 .577 .707 r
F P
0 g
s
.63334 .77977 m .64435 .74333 L .67028 .75354 L p .707 .577 .707 r
F P
0 g
s
.6195 .30301 m .6195 .80489 L .63862 .79393 L p .707 .577 .707 r
F P
0 g
s
.63862 .79393 m .63861 .29204 L .6195 .30301 L p .707 .577 .707 r
F P
0 g
s
.24874 .79639 m .25355 .76417 L .22268 .75694 L p .707 .577 .707 r
F P
0 g
s
.25355 .76417 m .24874 .79639 L .28035 .79835 L p .707 .577 .707 r
F P
0 g
s
.28035 .79835 m .28516 .76613 L .25355 .76417 L p .707 .577 .707 r
F P
0 g
s
.33957 .66008 m .33668 .71337 L .35335 .70378 L p .707 .577 .707 r
F P
0 g
s
.35335 .70378 m .35624 .65048 L .33957 .66008 L p .707 .577 .707 r
F P
0 g
s
.70065 .8313 m .695 .84949 L .68309 .84164 L p .707 .577 .707 r
F P
0 g
s
.68309 .84164 m .68874 .82345 L .70065 .8313 L p .707 .577 .707 r
F P
0 g
s
.21788 .78916 m .22268 .75694 L .19559 .74515 L p .707 .577 .707 r
F P
0 g
s
.22268 .75694 m .21788 .78916 L .24874 .79639 L p .707 .577 .707 r
F P
0 g
s
.28516 .76613 m .28035 .79835 L .30962 .79485 L p .707 .577 .707 r
F P
0 g
s
.30962 .79485 m .31442 .76264 L .28516 .76613 L p .707 .577 .707 r
F P
0 g
s
.17496 .64756 m .17207 .70085 L .19282 .71105 L p .707 .577 .707 r
F P
0 g
s
.17207 .70085 m .17496 .64756 L .16273 .63576 L p .707 .577 .707 r
F P
0 g
s
.6899 .76302 m .67889 .79946 L .65927 .78998 L p .707 .577 .707 r
F P
0 g
s
.65927 .78998 m .67028 .75354 L .6899 .76302 L p .707 .577 .707 r
F P
0 g
s
.67374 .6567 m .667 .71259 L .63997 .70579 L p .707 .577 .707 r
F P
0 g
s
.63997 .70579 m .6467 .6499 L .67374 .6567 L p .707 .577 .707 r
F P
0 g
s
.19079 .77737 m .19559 .74515 L .17492 .72996 L p .707 .577 .707 r
F P
0 g
s
.19559 .74515 m .19079 .77737 L .21788 .78916 L p .707 .577 .707 r
F P
0 g
s
.31442 .76264 m .30962 .79485 L .33368 .78624 L p .707 .577 .707 r
F P
0 g
s
.33368 .78624 m .33848 .75402 L .31442 .76264 L p .707 .577 .707 r
F P
0 g
s
.25302 .84062 m .25551 .82454 L .22453 .8175 L p .707 .577 .707 r
F P
0 g
s
.25551 .82454 m .25302 .84062 L .28456 .84235 L p .707 .577 .707 r
F P
0 g
s
.28456 .84235 m .28705 .82628 L .25551 .82454 L p .707 .577 .707 r
F P
0 g
s
.22204 .83357 m .22453 .8175 L .19714 .80582 L p .707 .577 .707 r
F P
0 g
s
.22453 .8175 m .22204 .83357 L .25302 .84062 L p .707 .577 .707 r
F P
0 g
s
.28705 .82628 m .28456 .84235 L .31357 .8386 L p .707 .577 .707 r
F P
0 g
s
.31357 .8386 m .31606 .82253 L .28705 .82628 L p .707 .577 .707 r
F P
0 g
s
.35624 .65048 m .35335 .70378 L .36079 .6923 L p .707 .577 .707 r
F P
0 g
s
.36079 .6923 m .36368 .639 L .35624 .65048 L p .707 .577 .707 r
F P
0 g
s
.36368 .639 m .36079 .6923 L .35828 .68007 L p .707 .577 .707 r
F P
0 g
s
.35828 .68007 m .36116 .62677 L .36368 .639 L p .707 .577 .707 r
F P
0 g
s
.3644 .79642 m .3644 .29453 L .35584 .28264 L p .707 .577 .707 r
F P
0 g
s
.3644 .29453 m .3644 .79642 L .38624 .80702 L p .707 .577 .707 r
F P
0 g
s
.19714 .80582 m .19465 .8219 L .22204 .83357 L p .707 .577 .707 r
F P
0 g
s
.19465 .8219 m .19714 .80582 L .17602 .79067 L p .707 .577 .707 r
F P
0 g
s
.68874 .82345 m .68309 .84164 L .66306 .83209 L p .707 .577 .707 r
F P
0 g
s
.66306 .83209 m .66872 .8139 L .68874 .82345 L p .707 .577 .707 r
F P
0 g
s
.16273 .63576 m .15984 .68906 L .17207 .70085 L p .707 .577 .707 r
F P
0 g
s
.31606 .82253 m .31357 .8386 L .3372 .82974 L p .707 .577 .707 r
F P
0 g
s
.3372 .82974 m .33969 .81366 L .31606 .82253 L p .707 .577 .707 r
F P
0 g
s
.17012 .76217 m .17492 .72996 L .16269 .71285 L p .707 .577 .707 r
F P
0 g
s
.17492 .72996 m .17012 .76217 L .19079 .77737 L p .707 .577 .707 r
F P
0 g
s
.33848 .75402 m .33368 .78624 L .35017 .77335 L p .707 .577 .707 r
F P
0 g
s
.35017 .77335 m .35497 .74114 L .33848 .75402 L p .707 .577 .707 r
F P
0 g
s
.63861 .29204 m .63862 .79393 L .64416 .78191 L p .707 .577 .707 r
F P
0 g
s
.64416 .78191 m .64416 .28002 L .63861 .29204 L p .707 .577 .707 r
F P
0 g
s
.15984 .68906 m .16273 .63576 L .16021 .62353 L p .707 .577 .707 r
F P
0 g
s
.17602 .79067 m .17353 .80675 L .19465 .8219 L p .707 .577 .707 r
F P
0 g
s
.17353 .80675 m .17602 .79067 L .16324 .77352 L p .707 .577 .707 r
F P
0 g
s
.33969 .81366 m .3372 .82974 L .35316 .81662 L p .707 .577 .707 r
F P
0 g
s
.35316 .81662 m .35565 .80055 L .33969 .81366 L p .707 .577 .707 r
F P
0 g
s
.66872 .8139 m .66306 .83209 L .63689 .82176 L p .707 .577 .707 r
F P
0 g
s
.63689 .82176 m .64255 .80356 L .66872 .8139 L p .707 .577 .707 r
F P
0 g
s
.16269 .71285 m .15789 .74506 L .17012 .76217 L p .707 .577 .707 r
F P
0 g
s
.15789 .74506 m .16269 .71285 L .16011 .69549 L p .707 .577 .707 r
F P
0 g
s
.35497 .74114 m .35017 .77335 L .35748 .75745 L p .707 .577 .707 r
F P
0 g
s
.35748 .75745 m .36228 .72524 L .35497 .74114 L p .707 .577 .707 r
F P
0 g
s
.16021 .62353 m .15732 .67682 L .15984 .68906 L p .707 .577 .707 r
F P
0 g
s
.16324 .77352 m .16075 .7896 L .17353 .80675 L p .707 .577 .707 r
F P
0 g
s
.15732 .67682 m .16021 .62353 L .16765 .61205 L p .707 .577 .707 r
F P
0 g
s
.64255 .80356 m .63689 .82176 L .60713 .81166 L p .707 .577 .707 r
F P
0 g
s
.35987 .80054 m .36235 .78447 L .35565 .80055 L p .707 .577 .707 r
F P
0 g
s
.36116 .62677 m .35828 .68007 L .34604 .66827 L p .707 .577 .707 r
F P
0 g
s
.34604 .66827 m .34893 .61498 L .36116 .62677 L p .707 .577 .707 r
F P
0 g
s
.36228 .72524 m .35748 .75745 L .35489 .7401 L p .707 .577 .707 r
F P
0 g
s
.35489 .7401 m .3597 .70788 L .36228 .72524 L p .707 .577 .707 r
F P
0 g
s
.36235 .78447 m .35987 .80054 L .35667 .78307 L p .707 .577 .707 r
F P
0 g
s
.35667 .78307 m .35916 .767 L .36235 .78447 L p .707 .577 .707 r
F P
0 g
s
.3597 .70788 m .35489 .7401 L .34267 .72299 L p .707 .577 .707 r
F P
0 g
s
.34267 .72299 m .34747 .69077 L .3597 .70788 L p .707 .577 .707 r
F P
0 g
s
.35916 .767 m .35667 .78307 L .34389 .76592 L p .707 .577 .707 r
F P
0 g
s
.34389 .76592 m .34638 .74985 L .35916 .767 L p .707 .577 .707 r
F P
0 g
s
.35584 .28264 m .35584 .78453 L .3644 .79642 L p .707 .577 .707 r
F P
0 g
s
.35584 .78453 m .35584 .28264 L .36138 .27062 L p .707 .577 .707 r
F P
0 g
s
.16075 .7896 m .16324 .77352 L .16004 .75605 L p .707 .577 .707 r
F P
0 g
s
.35565 .80055 m .35316 .81662 L .35987 .80054 L p .707 .577 .707 r
F P
0 g
s
.16011 .69549 m .15531 .72771 L .15789 .74506 L p .707 .577 .707 r
F P
0 g
s
.64416 .28002 m .64416 .78191 L .6356 .77002 L p .707 .577 .707 r
F P
0 g
s
.6356 .77002 m .6356 .26813 L .64416 .28002 L p .707 .577 .707 r
F P
0 g
s
.16004 .75605 m .15756 .77213 L .16075 .7896 L p .707 .577 .707 r
F P
0 g
s
.15531 .72771 m .16011 .69549 L .16742 .67959 L p .707 .577 .707 r
F P
0 g
s
.16765 .61205 m .16476 .66535 L .15732 .67682 L p .707 .577 .707 r
F P
0 g
s
.16476 .66535 m .16765 .61205 L .18432 .60245 L p .707 .577 .707 r
F P
0 g
s
.15756 .77213 m .16004 .75605 L .16675 .73997 L p .707 .577 .707 r
F P
0 g
s
.16742 .67959 m .16262 .71181 L .15531 .72771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16675 .73997 m .16426 .75605 L .15756 .77213 L p .707 .577 .707 r
F P
0 g
s
.16262 .71181 m .16742 .67959 L .18391 .6667 L p .707 .577 .707 r
F P
0 g
s
.34893 .61498 m .34604 .66827 L .3253 .65807 L p .707 .577 .707 r
F P
0 g
s
.3253 .65807 m .32818 .60478 L .34893 .61498 L p .707 .577 .707 r
F P
0 g
s
.36138 .77251 m .36138 .27062 L .3805 .25965 L p .707 .577 .707 r
F P
0 g
s
.36138 .27062 m .36138 .77251 L .35584 .78453 L p .707 .577 .707 r
F P
0 g
s
.18432 .60245 m .18143 .65575 L .16476 .66535 L p .707 .577 .707 r
F P
0 g
s
.18143 .65575 m .18432 .60245 L .20859 .59568 L p .707 .577 .707 r
F P
0 g
s
.6356 .26813 m .6356 .77002 L .61376 .75942 L p .707 .577 .707 r
F P
0 g
s
.61376 .75942 m .61376 .25753 L .6356 .26813 L p .707 .577 .707 r
F P
0 g
s
.16426 .75605 m .16675 .73997 L .18271 .72686 L p .707 .577 .707 r
F P
0 g
s
.18391 .6667 m .17911 .69892 L .16262 .71181 L p .707 .577 .707 r
F P
0 g
s
.32818 .60478 m .3253 .65807 L .29807 .65047 L p .707 .577 .707 r
F P
0 g
s
.29807 .65047 m .30095 .59717 L .32818 .60478 L p .707 .577 .707 r
F P
0 g
s
.17911 .69892 m .18391 .6667 L .20797 .65809 L p .707 .577 .707 r
F P
0 g
s
.34747 .69077 m .34267 .72299 L .322 .70779 L p .707 .577 .707 r
F P
0 g
s
.322 .70779 m .3268 .67558 L .34747 .69077 L p .707 .577 .707 r
F P
0 g
s
.18271 .72686 m .18022 .74293 L .16426 .75605 L p .707 .577 .707 r
F P
0 g
s
.2057 .64898 m .20859 .59568 L .23808 .59239 L p .707 .577 .707 r
F P
0 g
s
.20859 .59568 m .2057 .64898 L .18143 .65575 L p .707 .577 .707 r
F P
0 g
s
.30095 .59717 m .29807 .65047 L .26702 .6462 L p .707 .577 .707 r
F P
0 g
s
.26702 .6462 m .2699 .5929 L .30095 .59717 L p .707 .577 .707 r
F P
0 g
s
.18022 .74293 m .18271 .72686 L .20634 .71799 L p .707 .577 .707 r
F P
0 g
s
.23519 .64568 m .23808 .59239 L .2699 .5929 L p .707 .577 .707 r
F P
0 g
s
.23808 .59239 m .23519 .64568 L .2057 .64898 L p .707 .577 .707 r
F P
0 g
s
.3805 .25965 m .3805 .76154 L .36138 .77251 L p .707 .577 .707 r
F P
0 g
s
.3805 .76154 m .3805 .25965 L .41131 .2508 L p .707 .577 .707 r
F P
0 g
s
.34638 .74985 m .34389 .76592 L .32277 .75077 L p .707 .577 .707 r
F P
0 g
s
.32277 .75077 m .32526 .7347 L .34638 .74985 L p .707 .577 .707 r
F P
0 g
s
.20316 .69031 m .20797 .65809 L .23723 .6546 L p .707 .577 .707 r
F P
0 g
s
.20797 .65809 m .20316 .69031 L .17911 .69892 L p .707 .577 .707 r
F P
0 g
s
.3268 .67558 m .322 .70779 L .2949 .696 L p .707 .577 .707 r
F P
0 g
s
.2949 .696 m .29971 .66379 L .3268 .67558 L p .707 .577 .707 r
F P
0 g
s
.2699 .5929 m .26702 .6462 L .23519 .64568 L p .707 .577 .707 r
F P
0 g
s
.61376 .25753 m .61376 .75942 L .58078 .75115 L p .707 .577 .707 r
F P
0 g
s
.58078 .75115 m .58078 .24926 L .61376 .25753 L p .707 .577 .707 r
F P
0 g
s
.20634 .71799 m .20386 .73407 L .18022 .74293 L p .707 .577 .707 r
F P
0 g
s
.23243 .68681 m .23723 .6546 L .26884 .65656 L p .707 .577 .707 r
F P
0 g
s
.23723 .6546 m .23243 .68681 L .20316 .69031 L p .707 .577 .707 r
F P
0 g
s
.29971 .66379 m .2949 .696 L .26404 .68877 L p .707 .577 .707 r
F P
0 g
s
.26404 .68877 m .26884 .65656 L .29971 .66379 L p .707 .577 .707 r
F P
0 g
s
.73298 .64635 m .73009 .5894 L .69905 .58979 L p .707 .577 .707 r
F P
0 g
s
.73009 .5894 m .73298 .64635 L .7648 .64439 L p .707 .577 .707 r
F P
0 g
s
.7648 .64439 m .76192 .58744 L .73009 .5894 L p .707 .577 .707 r
F P
0 g
s
.76192 .58744 m .7648 .64439 L .79429 .64106 L p .707 .577 .707 r
F P
0 g
s
.79429 .64106 m .79141 .58411 L .76192 .58744 L p .707 .577 .707 r
F P
0 g
s
.20386 .73407 m .20634 .71799 L .23535 .71425 L p .707 .577 .707 r
F P
0 g
s
.26884 .65656 m .26404 .68877 L .23243 .68681 L p .707 .577 .707 r
F P
0 g
s
.32526 .7347 m .32277 .75077 L .29538 .7391 L p .707 .577 .707 r
F P
0 g
s
.29538 .7391 m .29787 .72303 L .32526 .7347 L p .707 .577 .707 r
F P
0 g
s
.70193 .64674 m .69905 .58979 L .67182 .58859 L p .707 .577 .707 r
F P
0 g
s
.69905 .58979 m .70193 .64674 L .73298 .64635 L p .707 .577 .707 r
F P
0 g
s
.23535 .71425 m .23286 .73032 L .20386 .73407 L p .707 .577 .707 r
F P
0 g
s
.79141 .58411 m .79429 .64106 L .81856 .63669 L p .707 .577 .707 r
F P
0 g
s
.81856 .63669 m .81568 .57974 L .79141 .58411 L p .707 .577 .707 r
F P
0 g
s
.23286 .73032 m .23535 .71425 L .26689 .71598 L p .707 .577 .707 r
F P
0 g
s
.67182 .58859 m .6747 .64554 L .70193 .64674 L p .707 .577 .707 r
F P
0 g
s
.29787 .72303 m .29538 .7391 L .2644 .73205 L p .707 .577 .707 r
F P
0 g
s
.2644 .73205 m .26689 .71598 L .29787 .72303 L p .707 .577 .707 r
F P
0 g
s
.41131 .75269 m .41131 .2508 L .4508 .24494 L p .707 .577 .707 r
F P
0 g
s
.41131 .2508 m .41131 .75269 L .3805 .76154 L p .707 .577 .707 r
F P
0 g
s
.70029 .65627 m .7051 .69442 L .73596 .69037 L p .707 .577 .707 r
F P
0 g
s
.73596 .69037 m .73115 .65222 L .70029 .65627 L p .707 .577 .707 r
F P
0 g
s
.73115 .65222 m .73596 .69037 L .76757 .68645 L p .707 .577 .707 r
F P
0 g
s
.76757 .68645 m .76277 .6483 L .73115 .65222 L p .707 .577 .707 r
F P
0 g
s
.26689 .71598 m .2644 .73205 L .23286 .73032 L p .707 .577 .707 r
F P
0 g
s
.76277 .6483 m .76757 .68645 L .79683 .68305 L p .707 .577 .707 r
F P
0 g
s
.79683 .68305 m .79203 .64489 L .76277 .6483 L p .707 .577 .707 r
F P
0 g
s
.58078 .24926 m .58078 .75115 L .5399 .74602 L p .707 .577 .707 r
F P
0 g
s
.5399 .74602 m .5399 .24413 L .58078 .24926 L p .707 .577 .707 r
F P
0 g
s
.6747 .64554 m .67182 .58859 L .65107 .58591 L p .707 .577 .707 r
F P
0 g
s
.6732 .66005 m .678 .69821 L .7051 .69442 L p .707 .577 .707 r
F P
0 g
s
.7051 .69442 m .70029 .65627 L .6732 .66005 L p .707 .577 .707 r
F P
0 g
s
.65107 .58591 m .65395 .64286 L .6747 .64554 L p .707 .577 .707 r
F P
0 g
s
.79203 .64489 m .79683 .68305 L .82089 .68049 L p .707 .577 .707 r
F P
0 g
s
.82089 .68049 m .81609 .64234 L .79203 .64489 L p .707 .577 .707 r
F P
0 g
s
.81568 .57974 m .81856 .63669 L .83523 .63171 L p .707 .577 .707 r
F P
0 g
s
.83523 .63171 m .83235 .57475 L .81568 .57974 L p .707 .577 .707 r
F P
0 g
s
.70213 .71586 m .70462 .73493 L .7356 .73072 L p .707 .577 .707 r
F P
0 g
s
.7356 .73072 m .73311 .71165 L .70213 .71586 L p .707 .577 .707 r
F P
0 g
s
.73311 .71165 m .7356 .73072 L .76714 .72668 L p .707 .577 .707 r
F P
0 g
s
.76714 .72668 m .76465 .70762 L .73311 .71165 L p .707 .577 .707 r
F P
0 g
s
.4508 .74683 m .4508 .24494 L .49511 .24265 L p .707 .577 .707 r
F P
0 g
s
.4508 .24494 m .4508 .74683 L .41131 .75269 L p .707 .577 .707 r
F P
0 g
s
.76465 .70762 m .76714 .72668 L .79614 .72322 L p .707 .577 .707 r
F P
0 g
s
.79614 .72322 m .79365 .70416 L .76465 .70762 L p .707 .577 .707 r
F P
0 g
s
.5399 .24413 m .5399 .74602 L .49511 .74454 L p .707 .577 .707 r
F P
0 g
s
.49511 .74454 m .49511 .24265 L .5399 .24413 L p .707 .577 .707 r
F P
0 g
s
.67474 .71984 m .67723 .7389 L .70462 .73493 L p .707 .577 .707 r
F P
0 g
s
.70462 .73493 m .70213 .71586 L .67474 .71984 L p .707 .577 .707 r
F P
0 g
s
.65253 .6632 m .65733 .70135 L .678 .69821 L p .707 .577 .707 r
F P
0 g
s
.678 .69821 m .6732 .66005 L .65253 .6632 L p .707 .577 .707 r
F P
0 g
s
.49511 .24265 m .49511 .74454 L .4508 .74683 L p .707 .577 .707 r
F P
0 g
s
.65395 .64286 m .65107 .58591 L .63884 .58201 L p .707 .577 .707 r
F P
0 g
s
.79365 .70416 m .79614 .72322 L .81978 .72067 L p .707 .577 .707 r
F P
0 g
s
.81978 .72067 m .81729 .70161 L .79365 .70416 L p .707 .577 .707 r
F P
0 g
s
.81609 .64234 m .82089 .68049 L .83738 .67903 L p .707 .577 .707 r
F P
0 g
s
.83738 .67903 m .83258 .64087 L .81609 .64234 L p .707 .577 .707 r
F P
0 g
s
.63884 .58201 m .64172 .63896 L .65395 .64286 L p .707 .577 .707 r
F P
0 g
s
.65362 .72319 m .65611 .74225 L .67723 .7389 L p .707 .577 .707 r
F P
0 g
s
.67723 .7389 m .67474 .71984 L .65362 .72319 L p .707 .577 .707 r
F P
0 g
s
.83235 .57475 m .83523 .63171 L .84267 .62659 L p .707 .577 .707 r
F P
0 g
s
.84267 .62659 m .83979 .56964 L .83235 .57475 L p .707 .577 .707 r
F P
0 g
s
.6403 .6654 m .64511 .70355 L .65733 .70135 L p .707 .577 .707 r
F P
0 g
s
.65733 .70135 m .65253 .6632 L .6403 .6654 L p .707 .577 .707 r
F P
0 g
s
.81729 .70161 m .81978 .72067 L .83573 .71929 L p .707 .577 .707 r
F P
0 g
s
.83573 .71929 m .83325 .70022 L .81729 .70161 L p .707 .577 .707 r
F P
0 g
s
.64172 .63896 m .63884 .58201 L .63632 .57727 L p .707 .577 .707 r
F P
0 g
s
.64084 .72559 m .64332 .74465 L .65611 .74225 L p .707 .577 .707 r
F P
0 g
s
.65611 .74225 m .65362 .72319 L .64084 .72559 L p .707 .577 .707 r
F P
0 g
s
.83258 .64087 m .83738 .67903 L .84469 .67881 L p .707 .577 .707 r
F P
0 g
s
.84469 .67881 m .83989 .64065 L .83258 .64087 L p .707 .577 .707 r
F P
0 g
s
.63632 .57727 m .6392 .63422 L .64172 .63896 L p .707 .577 .707 r
F P
0 g
s
.83979 .56964 m .84267 .62659 L .84016 .62185 L p .707 .577 .707 r
F P
0 g
s
.84016 .62185 m .83727 .5649 L .83979 .56964 L p .707 .577 .707 r
F P
0 g
s
.63772 .66644 m .64252 .7046 L .64511 .70355 L p .707 .577 .707 r
F P
0 g
s
.64511 .70355 m .6403 .6654 L .63772 .66644 L p .707 .577 .707 r
F P
0 g
s
.83325 .70022 m .83573 .71929 L .84244 .71919 L p .707 .577 .707 r
F P
0 g
s
.84244 .71919 m .83995 .70013 L .83325 .70022 L p .707 .577 .707 r
F P
0 g
s
.6392 .63422 m .63632 .57727 L .64376 .57215 L p .707 .577 .707 r
F P
0 g
s
.63764 .7268 m .64013 .74586 L .64332 .74465 L p .707 .577 .707 r
F P
0 g
s
.64332 .74465 m .64084 .72559 L .63764 .7268 L p .707 .577 .707 r
F P
0 g
s
.83989 .64065 m .84469 .67881 L .84211 .67985 L p .707 .577 .707 r
F P
0 g
s
.84211 .67985 m .8373 .6417 L .83989 .64065 L p .707 .577 .707 r
F P
0 g
s
.64376 .57215 m .64664 .62911 L .6392 .63422 L p .707 .577 .707 r
F P
0 g
s
.83727 .5649 m .84016 .62185 L .82792 .61795 L p .707 .577 .707 r
F P
0 g
s
.82792 .61795 m .82504 .561 L .83727 .5649 L p .707 .577 .707 r
F P
0 g
s
.64503 .66622 m .64983 .70438 L .64252 .7046 L p .707 .577 .707 r
F P
0 g
s
.64252 .7046 m .63772 .66644 L .64503 .66622 L p .707 .577 .707 r
F P
0 g
s
.39089 .62588 m .38416 .5715 L .3533 .57257 L p .707 .577 .707 r
F P
0 g
s
.38416 .5715 m .39089 .62588 L .42254 .62158 L p .707 .577 .707 r
F P
0 g
s
.42254 .62158 m .41581 .5672 L .38416 .5715 L p .707 .577 .707 r
F P
0 g
s
.41581 .5672 m .42254 .62158 L .4519 .61446 L p .707 .577 .707 r
F P
0 g
s
.4519 .61446 m .44517 .56008 L .41581 .5672 L p .707 .577 .707 r
F P
0 g
s
.83995 .70013 m .84244 .71919 L .83925 .72041 L p .707 .577 .707 r
F P
0 g
s
.83925 .72041 m .83676 .70134 L .83995 .70013 L p .707 .577 .707 r
F P
0 g
s
.36003 .62695 m .3533 .57257 L .32626 .5703 L p .707 .577 .707 r
F P
0 g
s
.3533 .57257 m .36003 .62695 L .39089 .62588 L p .707 .577 .707 r
F P
0 g
s
.64664 .62911 m .64376 .57215 L .66043 .56717 L p .707 .577 .707 r
F P
0 g
s
.44517 .56008 m .4519 .61446 L .47608 .60523 L p .707 .577 .707 r
F P
0 g
s
.47608 .60523 m .46935 .55085 L .44517 .56008 L p .707 .577 .707 r
F P
0 g
s
.64435 .72671 m .64684 .74577 L .64013 .74586 L p .707 .577 .707 r
F P
0 g
s
.64013 .74586 m .63764 .7268 L .64435 .72671 L p .707 .577 .707 r
F P
0 g
s
.8373 .6417 m .84211 .67985 L .82988 .68205 L p .707 .577 .707 r
F P
0 g
s
.82988 .68205 m .82508 .6439 L .8373 .6417 L p .707 .577 .707 r
F P
0 g
s
.66043 .56717 m .66331 .62412 L .64664 .62911 L p .707 .577 .707 r
F P
0 g
s
.82504 .561 m .82792 .61795 L .80718 .61527 L p .707 .577 .707 r
F P
0 g
s
.80718 .61527 m .8043 .55832 L .82504 .561 L p .707 .577 .707 r
F P
0 g
s
.42691 .68397 m .4159 .64992 L .38534 .65917 L p .707 .577 .707 r
F P
0 g
s
.4159 .64992 m .42691 .68397 L .45534 .67158 L p .707 .577 .707 r
F P
0 g
s
.45534 .67158 m .44434 .63753 L .4159 .64992 L p .707 .577 .707 r
F P
0 g
s
.33299 .62468 m .32626 .5703 L .30569 .56491 L p .707 .577 .707 r
F P
0 g
s
.32626 .5703 m .33299 .62468 L .36003 .62695 L p .707 .577 .707 r
F P
0 g
s
.39635 .69323 m .38534 .65917 L .35564 .66438 L p .707 .577 .707 r
F P
0 g
s
.38534 .65917 m .39635 .69323 L .42691 .68397 L p .707 .577 .707 r
F P
0 g
s
.66152 .66476 m .66632 .70291 L .64983 .70438 L p .707 .577 .707 r
F P
0 g
s
.64983 .70438 m .64503 .66622 L .66152 .66476 L p .707 .577 .707 r
F P
0 g
s
.46935 .55085 m .47608 .60523 L .49272 .59479 L p .707 .577 .707 r
F P
0 g
s
.49272 .59479 m .48599 .54041 L .46935 .55085 L p .707 .577 .707 r
F P
0 g
s
.44434 .63753 m .45534 .67158 L .47887 .65725 L p .707 .577 .707 r
F P
0 g
s
.47887 .65725 m .46786 .6232 L .44434 .63753 L p .707 .577 .707 r
F P
0 g
s
.83676 .70134 m .83925 .72041 L .82647 .72281 L p .707 .577 .707 r
F P
0 g
s
.82647 .72281 m .82398 .70374 L .83676 .70134 L p .707 .577 .707 r
F P
0 g
s
.66331 .62412 m .66043 .56717 L .6847 .5628 L p .707 .577 .707 r
F P
0 g
s
.36665 .69843 m .35564 .66438 L .32971 .66502 L p .707 .577 .707 r
F P
0 g
s
.35564 .66438 m .36665 .69843 L .39635 .69323 L p .707 .577 .707 r
F P
0 g
s
.42331 .72661 m .41766 .70968 L .38722 .71938 L p .707 .577 .707 r
F P
0 g
s
.41766 .70968 m .42331 .72661 L .45145 .71379 L p .707 .577 .707 r
F P
0 g
s
.45145 .71379 m .44579 .69685 L .41766 .70968 L p .707 .577 .707 r
F P
0 g
s
.39287 .73631 m .38722 .71938 L .35745 .725 L p .707 .577 .707 r
F P
0 g
s
.38722 .71938 m .39287 .73631 L .42331 .72661 L p .707 .577 .707 r
F P
0 g
s
.30569 .56491 m .31242 .61929 L .33299 .62468 L p .707 .577 .707 r
F P
0 g
s
.66031 .72532 m .66279 .74438 L .64684 .74577 L p .707 .577 .707 r
F P
0 g
s
.64684 .74577 m .64435 .72671 L .66031 .72532 L p .707 .577 .707 r
F P
0 g
s
.82508 .6439 m .82988 .68205 L .80921 .6852 L p .707 .577 .707 r
F P
0 g
s
.80921 .6852 m .80441 .64704 L .82508 .6439 L p .707 .577 .707 r
F P
0 g
s
.6847 .5628 m .68758 .61975 L .66331 .62412 L p .707 .577 .707 r
F P
0 g
s
.8043 .55832 m .80718 .61527 L .77995 .61407 L p .707 .577 .707 r
F P
0 g
s
.77995 .61407 m .77707 .55712 L .8043 .55832 L p .707 .577 .707 r
F P
0 g
s
.46786 .6232 m .47887 .65725 L .49517 .64239 L p .707 .577 .707 r
F P
0 g
s
.49517 .64239 m .48416 .60834 L .46786 .6232 L p .707 .577 .707 r
F P
0 g
s
.31242 .61929 m .30569 .56491 L .29359 .55694 L p .707 .577 .707 r
F P
0 g
s
.44579 .69685 m .45145 .71379 L .47453 .6991 L p .707 .577 .707 r
F P
0 g
s
.47453 .6991 m .46887 .68216 L .44579 .69685 L p .707 .577 .707 r
F P
0 g
s
.35745 .725 m .36311 .74194 L .39287 .73631 L p .707 .577 .707 r
F P
0 g
s
.32971 .66502 m .34072 .69907 L .36665 .69843 L p .707 .577 .707 r
F P
0 g
s
.36311 .74194 m .35745 .725 L .33128 .72601 L p .707 .577 .707 r
F P
0 g
s
.48599 .54041 m .49272 .59479 L .50019 .58416 L p .707 .577 .707 r
F P
0 g
s
.50019 .58416 m .49346 .52978 L .48599 .54041 L p .707 .577 .707 r
F P
0 g
s
.34072 .69907 m .32971 .66502 L .31009 .66104 L p .707 .577 .707 r
F P
0 g
s
.68557 .6622 m .69038 .70036 L .66632 .70291 L p .707 .577 .707 r
F P
0 g
s
.66632 .70291 m .66152 .66476 L .68557 .6622 L p .707 .577 .707 r
F P
0 g
s
.68758 .61975 m .6847 .5628 L .71419 .55947 L p .707 .577 .707 r
F P
0 g
s
.33128 .72601 m .33693 .74294 L .36311 .74194 L p .707 .577 .707 r
F P
0 g
s
.82398 .70374 m .82647 .72281 L .80535 .72616 L p .707 .577 .707 r
F P
0 g
s
.80535 .72616 m .80286 .70709 L .82398 .70374 L p .707 .577 .707 r
F P
0 g
s
.77707 .55712 m .77995 .61407 L .7489 .61446 L p .707 .577 .707 r
F P
0 g
s
.7489 .61446 m .74602 .55751 L .77707 .55712 L p .707 .577 .707 r
F P
0 g
s
.71419 .55947 m .71707 .61642 L .68758 .61975 L p .707 .577 .707 r
F P
0 g
s
.46887 .68216 m .47453 .6991 L .49029 .68397 L p .707 .577 .707 r
F P
0 g
s
.49029 .68397 m .48463 .66704 L .46887 .68216 L p .707 .577 .707 r
F P
0 g
s
.29359 .55694 m .30033 .61132 L .31242 .61929 L p .707 .577 .707 r
F P
0 g
s
.80441 .64704 m .80921 .6852 L .78212 .68898 L p .707 .577 .707 r
F P
0 g
s
.71707 .61642 m .71419 .55947 L .74602 .55751 L p .707 .577 .707 r
F P
0 g
s
.78212 .68898 m .77731 .65083 L .80441 .64704 L p .707 .577 .707 r
F P
0 g
s
.31009 .66104 m .3211 .69509 L .34072 .69907 L p .707 .577 .707 r
F P
0 g
s
.74602 .55751 m .7489 .61446 L .71707 .61642 L p .707 .577 .707 r
F P
0 g
s
.33693 .74294 m .33128 .72601 L .31125 .72229 L p .707 .577 .707 r
F P
0 g
s
.68394 .72277 m .68643 .74183 L .66279 .74438 L p .707 .577 .707 r
F P
0 g
s
.66279 .74438 m .66031 .72532 L .68394 .72277 L p .707 .577 .707 r
F P
0 g
s
.48416 .60834 m .49517 .64239 L .50267 .62846 L p .707 .577 .707 r
F P
0 g
s
.50267 .62846 m .49166 .59441 L .48416 .60834 L p .707 .577 .707 r
F P
0 g
s
.71484 .6588 m .71964 .69695 L .69038 .70036 L p .707 .577 .707 r
F P
0 g
s
.69038 .70036 m .68557 .6622 L .71484 .6588 L p .707 .577 .707 r
F P
0 g
s
.30033 .61132 m .29359 .55694 L .29116 .54716 L p .707 .577 .707 r
F P
0 g
s
.31125 .72229 m .31691 .73923 L .33693 .74294 L p .707 .577 .707 r
F P
0 g
s
.3211 .69509 m .31009 .66104 L .2987 .65283 L p .707 .577 .707 r
F P
0 g
s
.49346 .52978 m .50019 .58416 L .49776 .57438 L p .707 .577 .707 r
F P
0 g
s
.49776 .57438 m .49103 .52 L .49346 .52978 L p .707 .577 .707 r
F P
0 g
s
.77731 .65083 m .78212 .68898 L .75126 .69303 L p .707 .577 .707 r
F P
0 g
s
.75126 .69303 m .74645 .65488 L .77731 .65083 L p .707 .577 .707 r
F P
0 g
s
.80286 .70709 m .80535 .72616 L .77796 .73013 L p .707 .577 .707 r
F P
0 g
s
.77796 .73013 m .77547 .71107 L .80286 .70709 L p .707 .577 .707 r
F P
0 g
s
.74645 .65488 m .75126 .69303 L .71964 .69695 L p .707 .577 .707 r
F P
0 g
s
.71964 .69695 m .71484 .6588 L .74645 .65488 L p .707 .577 .707 r
F P
0 g
s
.48463 .66704 m .49029 .68397 L .49719 .6699 L p .707 .577 .707 r
F P
0 g
s
.49719 .6699 m .49153 .65297 L .48463 .66704 L p .707 .577 .707 r
F P
0 g
s
.71295 .71931 m .71544 .73837 L .68643 .74183 L p .707 .577 .707 r
F P
0 g
s
.68643 .74183 m .68394 .72277 L .71295 .71931 L p .707 .577 .707 r
F P
0 g
s
.2987 .65283 m .30971 .68688 L .3211 .69509 L p .707 .577 .707 r
F P
0 g
s
.29116 .54716 m .2979 .60154 L .30033 .61132 L p .707 .577 .707 r
F P
0 g
s
.31691 .73923 m .31125 .72229 L .29934 .71422 L p .707 .577 .707 r
F P
0 g
s
.49166 .59441 m .50267 .62846 L .50062 .61682 L p .707 .577 .707 r
F P
0 g
s
.50062 .61682 m .48961 .58277 L .49166 .59441 L p .707 .577 .707 r
F P
0 g
s
.77547 .71107 m .77796 .73013 L .74698 .73434 L p .707 .577 .707 r
F P
0 g
s
.74698 .73434 m .74449 .71528 L .77547 .71107 L p .707 .577 .707 r
F P
0 g
s
.29934 .71422 m .305 .73115 L .31691 .73923 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74449 .71528 m .74698 .73434 L .71544 .73837 L p .707 .577 .707 r
F P
0 g
s
.71544 .73837 m .71295 .71931 L .74449 .71528 L p .707 .577 .707 r
F P
0 g
s
.2979 .60154 m .29116 .54716 L .29863 .53653 L p .707 .577 .707 r
F P
0 g
s
.30971 .68688 m .2987 .65283 L .29665 .64119 L p .707 .577 .707 r
F P
0 g
s
.49103 .52 m .49776 .57438 L .48567 .5664 L p .707 .577 .707 r
F P
0 g
s
.48567 .5664 m .47893 .51202 L .49103 .52 L p .707 .577 .707 r
F P
0 g
s
.49153 .65297 m .49719 .6699 L .49455 .65826 L p .707 .577 .707 r
F P
0 g
s
.49455 .65826 m .4889 .64132 L .49153 .65297 L p .707 .577 .707 r
F P
0 g
s
.29665 .64119 m .30766 .67524 L .30971 .68688 L p .707 .577 .707 r
F P
0 g
s
.305 .73115 m .29934 .71422 L .29671 .70257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29863 .53653 m .30537 .59091 L .2979 .60154 L p .707 .577 .707 r
F P
0 g
s
.48961 .58277 m .50062 .61682 L .48923 .60861 L p .707 .577 .707 r
F P
0 g
s
.48923 .60861 m .47822 .57456 L .48961 .58277 L p .707 .577 .707 r
F P
0 g
s
.29671 .70257 m .30237 .71951 L .305 .73115 L p .707 .577 .707 r
F P
0 g
s
.30537 .59091 m .29863 .53653 L .31527 .52608 L p .707 .577 .707 r
F P
0 g
s
.30766 .67524 m .29665 .64119 L .30415 .62726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47893 .51202 m .48567 .5664 L .46509 .56102 L p .707 .577 .707 r
F P
0 g
s
.46509 .56102 m .45836 .50664 L .47893 .51202 L p .707 .577 .707 r
F P
0 g
s
.4889 .64132 m .49455 .65826 L .48264 .65018 L p .707 .577 .707 r
F P
0 g
s
.48264 .65018 m .47699 .63325 L .4889 .64132 L p .707 .577 .707 r
F P
0 g
s
.30415 .62726 m .31516 .66131 L .30766 .67524 L p .707 .577 .707 r
F P
0 g
s
.30237 .71951 m .29671 .70257 L .30361 .6885 L p .707 .577 .707 r
F P
0 g
s
.31527 .52608 m .32201 .58046 L .30537 .59091 L p .707 .577 .707 r
F P
0 g
s
.47822 .57456 m .48923 .60861 L .4696 .60463 L p .707 .577 .707 r
F P
0 g
s
.4696 .60463 m .45859 .57058 L .47822 .57456 L p .707 .577 .707 r
F P
0 g
s
.30361 .6885 m .30927 .70543 L .30237 .71951 L p .707 .577 .707 r
F P
0 g
s
.32201 .58046 m .31527 .52608 L .33945 .51686 L p .707 .577 .707 r
F P
0 g
s
.31516 .66131 m .30415 .62726 L .32045 .6124 L p .707 .577 .707 r
F P
0 g
s
.45836 .50664 m .46509 .56102 L .43805 .55875 L p .707 .577 .707 r
F P
0 g
s
.43805 .55875 m .43132 .50437 L .45836 .50664 L p .707 .577 .707 r
F P
0 g
s
.47699 .63325 m .48264 .65018 L .46262 .64646 L p .707 .577 .707 r
F P
0 g
s
.46262 .64646 m .45696 .62953 L .47699 .63325 L p .707 .577 .707 r
F P
0 g
s
.33945 .51686 m .34619 .57123 L .32201 .58046 L p .707 .577 .707 r
F P
0 g
s
.32045 .6124 m .33146 .64645 L .31516 .66131 L p .707 .577 .707 r
F P
0 g
s
.34619 .57123 m .33945 .51686 L .36881 .50974 L p .707 .577 .707 r
F P
0 g
s
.30927 .70543 m .30361 .6885 L .31937 .67338 L p .707 .577 .707 r
F P
0 g
s
.45859 .57058 m .4696 .60463 L .44368 .60528 L p .707 .577 .707 r
F P
0 g
s
.44368 .60528 m .43267 .57122 L .45859 .57058 L p .707 .577 .707 r
F P
0 g
s
.43132 .50437 m .43805 .55875 L .4072 .55982 L p .707 .577 .707 r
F P
0 g
s
.4072 .55982 m .40046 .50544 L .43132 .50437 L p .707 .577 .707 r
F P
0 g
s
.31937 .67338 m .32503 .69031 L .30927 .70543 L p .707 .577 .707 r
F P
0 g
s
.33146 .64645 m .32045 .6124 L .34397 .59808 L p .707 .577 .707 r
F P
0 g
s
.37554 .56412 m .36881 .50974 L .40046 .50544 L p .707 .577 .707 r
F P
0 g
s
.36881 .50974 m .37554 .56412 L .34619 .57123 L p .707 .577 .707 r
F P
0 g
s
.40046 .50544 m .4072 .55982 L .37554 .56412 L p .707 .577 .707 r
F P
0 g
s
.45696 .62953 m .46262 .64646 L .43644 .64747 L p .707 .577 .707 r
F P
0 g
s
.43644 .64747 m .43079 .63053 L .45696 .62953 L p .707 .577 .707 r
F P
0 g
s
.43267 .57122 m .44368 .60528 L .41398 .61048 L p .707 .577 .707 r
F P
0 g
s
.41398 .61048 m .40297 .57643 L .43267 .57122 L p .707 .577 .707 r
F P
0 g
s
.34397 .59808 m .35498 .63213 L .33146 .64645 L p .707 .577 .707 r
F P
0 g
s
.32503 .69031 m .31937 .67338 L .34245 .65869 L p .707 .577 .707 r
F P
0 g
s
.35498 .63213 m .34397 .59808 L .37241 .58568 L p .707 .577 .707 r
F P
0 g
s
.40297 .57643 m .41398 .61048 L .38342 .61973 L p .707 .577 .707 r
F P
0 g
s
.38342 .61973 m .37241 .58568 L .40297 .57643 L p .707 .577 .707 r
F P
0 g
s
.34245 .65869 m .34811 .67562 L .32503 .69031 L p .707 .577 .707 r
F P
0 g
s
.37241 .58568 m .38342 .61973 L .35498 .63213 L p .707 .577 .707 r
F P
0 g
s
.43079 .63053 m .43644 .64747 L .40668 .6531 L p .707 .577 .707 r
F P
0 g
s
.40668 .6531 m .40102 .63616 L .43079 .63053 L p .707 .577 .707 r
F P
0 g
s
.34811 .67562 m .34245 .65869 L .37059 .64586 L p .707 .577 .707 r
F P
0 g
s
.40102 .63616 m .40668 .6531 L .37624 .6628 L p .707 .577 .707 r
F P
0 g
s
.37624 .6628 m .37059 .64586 L .40102 .63616 L p .707 .577 .707 r
F P
0 g
s
.37059 .64586 m .37624 .6628 L .34811 .67562 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001hOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH8001f
Ool007=oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP000080
07=oo`00Kgoo100000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF0`00L7oo001/Ool30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001^Ool006Yoo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<006aoo`00JGoo00@0
05YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF008006Yoo`00Igoo0P000eYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00J7oo001VOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001WOol006Ioo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Ioo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF4P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo200015YF00<005YFFUH01UYF00@005YFFUIJ
EPL000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol006Eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00@000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005moo`<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005]oo`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Uoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001EOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUIJEP00IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0035YF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Dgoo0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP04001JEP00000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0067oo5`00=Woo001BOol01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF2@0015YF00@0
05YF000000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000?Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol005=oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPX00003FUH005YF00=JEP@00003FUH005YF00EJEP@00005
FUH005YFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
1goo20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YF
00002P001EYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH007oo00H000=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=o
o`03001JEP0000EJEP03001JEUYF00=JEQ8000=JEPl00003FUH005YF00=JEP<000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF00IJEP03001J
EP0000L000=JEP03001JEUYF00EJEP03001JEUYF00<000=JEP04001JEP00000:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05=oo`03001JEP0000EJEP04001JEP000005FUH00`00FUIJEP06FUH400000eYF001JEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00P002UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000
FUIJEP0015YF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF0000009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YF
FUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8000QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo0010OolA0003
Ool2FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000jOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000015YF001JEP001EYF00<005YFFUH00eYF0P001EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00EJEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000dOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH000020008FUH00`00FUIJEP07
FUH00`00FUIJEP07FUH01000FUIJEUYF1@000eYF00@005YFFUH000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
039oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPP000AJEP@00004FUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Goo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF1P001UYF00<005YF00000`000eYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0
15YF0`001UYF0P000UYF0`002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YF
FUH00P00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUH00000FUH00P001eYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YF
FUH0100000=JEP00FUH015YF0P000UYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF200025YF
00<005YFFUH01UYF00<005YFFUH015YF1@0000=JEP000000;Goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH300000eYF001JEP03FUH70005FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
001JEP03FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00eYF
30002eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000015YF001JEUYF1P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUH00004000015YF001JEUYF0`000UYF00<005YFFUH02EYF00<005YF00000P00
1UYF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH0
00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00AJEP<000EJ
EP03001JEP0000@00003FUH005YF00h00003FUH005YF00AJEP03001JEP0000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF00AJEP03001JEUYF009JEP800003FUH0000000EJEP03001JEP0000L000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
0005FUH02000FUIJEUYF001JEP00FUH20005FUH01P00FUH00000FUH000UJEP03001JEUYF00AJEP03
001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD003=oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP<00004FUH005YFFUH20004FUH30004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF000035YF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4@00;Woo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH01000FUIJEP001UYF00D005YFFUIJEP00009JEP80009JEP8000MJ
EP03001JEUYF00MJEP04001JEUYFFUH60002FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0017oo:@000UYF1@0000=JEP00FUH0;Woo000]Ool2
0004FUH00`00FUIJEP03FUH6000AOol60002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJ
EP050009FUH00`00FUIJEP02FUH80006FUH400000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02000KOol90004FUH70002FUH01@00FUIJEP00FUH0;Woo
000/Ool00`00FUH00004FUH00`00FUH00003000KOol20002FUH01@00FUIJEUYF00001EYF00<005YF
FUH00P000UYF00<005YFFUH01UYF1P001eYF00<005YFFUH01UYF1@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF00@000moo`P000AJEPT000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP<000Yoo`l000Eoo`80009JEP03001J
EUYF008000EJEP<000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005
FUH40003Ool80003FUH:0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00002FUH20003FUH300000goo000000040003FUH00`00FUIJEP06FUH00`00FUIJ
EP040002Ool01000FUIJEUYF100015YF0P001eYF00<005YF00000P0025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YF000035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000EJEPL000=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000AJEP@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0009JEPT000QJEP800003FUH005YF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH01P000UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF00<005YFFUH00P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP0000000UYF0`000UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF0`001EYF00D005YFFUIJEP0000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP`0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
;7oo0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80
0004FUH00000FUH20005FUH01000FUIJEUYF0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool20003FUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
0P001eYF00<005YF00000P001eYF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00H005YFFUH0
05YF000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000/Ool20002FUH01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000MJEP80009JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF00AJEP07001JEUYFFUH005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEP8002aoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH01UYF0`001eYF00@005YF000000=JEP03001JEUYF009JEP03001JEUYF00=JEP80
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00P002aoo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH50005FUH30005
FUH00`00FUIJEP030005FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH6000dOol002eoo`<000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJ
EP04001JEUYF0005FUH40007FUH00`00FUIJEP04FUH50002FUH30008FUH00`00FUH00002FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
1`00>Woo000]Ool00`00FUH00002FUH00`00FUIJEP03FUH600000eYF001JEP07FUH00`00FUIJEP02
FUH40002FUH01000FUH000001EYF00@005YFFUH000MJEP03001JEUYF00AJEPL000]JEP8000AJEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1000@Goo000]Ool00`00FUH00002FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH300000eYF00000004FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00FUIJ
EP08FUH20005FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`00
AGoo000]Ool20003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YF00000P000UYF3`001eYF00<005YFFUH01UYF0P001eYF00<005YFFUH0
0eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP004aoo`00;Goo0P000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP80009JEP03
001JEUYF00AJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00002FUH>000LOol:000^Ool002eoo`800004FUH000000003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`0000=JEP00FUH01EYF00<005YF
FUH00P001EYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP05001JEUYFFUH00008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000040002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P005Goo1`000eYF100000=JEP000000;Woo000]Ool30003Ool20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH02P00FUIJEUYF001JEP00FUH005YF0P00
1EYF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP@000MJEP04001JEP000009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP040002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0037oo2@000eYF1`000UYF00<005YFFUH00P00;Woo000/Ool00`00FUH0
0006Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH20003FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF0P0000=JEP00FUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEPD000AJEP04001JEUYFFUH20003Ool90003FUH90003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool40008Ool40002FUH@0002FUH00`00FUIJEP02FUH01@00FUIJEP00FUH01@000UYF
00@005YFFUIJEP8000EJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0UYF0`0000=JEP0000001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo10002Goo1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@001Goo0`00
0eYF0P001EYF10001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00L000=J
EPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00
;7oo0P000UYF00<007ooOol00Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF0`001Woo00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF00MJEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP060002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEUYF1@00<7oo000/Ool20002FUH00`00Oomoo`020004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000UYF3@001UYF00<005YFFUH01UYF0`001UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
2`000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPL003Eoo`00
;7oo0P000eYF0`001EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000UYF00<0
05YFFUH00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
000/Ool20003FUH00`00FUH00005FUH50009Ool60006FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT004Aoo`00;7oo00D005YFFUIJEP00009JEP04001JEUYF
FUH2000DOol40002FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50003
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8001=Ool0
02aoo`04001JEUYF0003FUH01000FUH000006Woo10001EYF0`000UYF00<005YFFUH00UYF2@001eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000=JEP00FUH00eYF00@005YFFUIJEPP005Eoo`00;7oo00@005YF000000=J
EP80009JEP03001oogoo01]oo`8000AJEP03001JEP0000T000EJEP03001JEUYF00EJEP03001JEUYF
00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0004FUH005YFFUH700000eYF0000001IOol002eoo`80009JEP8000AJEP<001eoo`<00003FUH005YF
00AJEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH90008FUH01000FUIJEUYF
30001UYF00<005YFFUH01UYF00<005YFFUH00eYF3P00Fgoo000]Ool40006FUH00`00FUIJEP02000N
Ool20006FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YF00000UYF2@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP80
061oo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P007Woo0P0015YF1@001EYF00<005YF
FUH015YF1@002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002UYF1@000UYF00<005YF
FUH00eYF00@005YFFUH000EJEP<005eoo`00;Goo10001UYF00<005YFFUH015YF10006Goo10000UYF
00<005YFFUH00`001EYF00<005YFFUH0100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00@005YFFUH000IJEP03001JEP000080
05Yoo`00;Goo00@007ooOol000EJEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP<0009J
EP<000EJEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP04001JEUYF0005FUH00`00FUIJEP03FUH2001HOol002aoo`<0009o
o`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEQ0000=JEP03001JEUYF00=JEP03001J
EP0000=JEP8000=JEP800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00005FUH005YFFUH00005FUH00`00FUIJEP04FUH2
001GOol002aoo`03001JEP0000=oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=JEP0000000eYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH005Ioo`00
;7oo00<005YF000017oo0P0000=JEP00FUH01UYF00<005YFFUH01eYF0`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH30005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000EGoo000/Ool01000FUH000001Goo0P001eYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0000AJEP00
000000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP05001J
EUYFFUH0001EOol002aoo`05001JEP00FUH00005Ool20006FUH00`00FUIJEP06FUH50004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00@005YFFUH0
00Moo`8000=JEP03001JEUYF00MJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001FOol002eoo`05001JEUYFFUH00008Ool200000eYF001JEP08FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`04Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200001EYF000005YF00001EYF00<005YFFUH00UYF00<007ooOol0E7oo000]Ool00`00
FUIJEP02FUH00`00Oomoo`07Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001goo0`001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001EYF00@005YFFUIJEP80
05Ioo`00;Woo00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000:Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P000eYF00@005YFFUIJ
EP8005Ioo`00;goo00H005YFFUH005YF000?Ool70004FUH00`00FUIJEP02FUH6000;Ool30005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30004FUH00`00Oomoo`1EOol002moo`03001J
EP0000=JEP8001Aoo`T0015oo`800003Ool0000000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEPD000=JEP03001JEUYF
00AJEP8000AJEP03001oogoo05Eoo`00<7oo0P001EYF00<007ooOol0:Woo0`000goo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF10001UYF00D005YF000005YF008005Moo`00<Goo00<005YFFUH015YF0P00:7oo
0P0000=JEP00Ool01Goo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH00UYF0`001eYF00@005YF000000EJEP04001JEUYFFUH3001GOol0039o
o`8000AJEP04001JEP00000UOol00`00FUIJEP02000:Ool50002FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040008FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF0000F7oo000dOol01000FUIJEP0015YF0P008Goo0P000eYF00<007ooOol0
3Woo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF300015YF00<005YFFUH0
1EYF2000F7oo000eOol30006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0COol60002FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060004FUH50003Ool300000eYF001JEP07FUH3
001LOol003Moo`03001JEUYF00EJEP03001JEUYF00@0011oo`D000AJEP03001JEUYF008001aooal0
0003FUH005YF00MJEPD000Ioo`<000IJEP04001JEUYFFUH2001JOol003Qoo`8000EJEP03001JEUYF
00AJEQ0000=JEP03001JEUYF00=JEP<003Yoo`<00003FUH005YF00MJEP@00004FUH000000006Ool2
0004FUH00`00FUIJEP03FUH00`00Oomoo`1GOol003Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo03eoo`<000MJEP03001JEUYF00EJEP<0
00Eoo`800003FUH005YF00EJEP<005Moo`00?7oo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8004=oo`@0009JEP03001JEUYF00MJEP03001JEP0000<000=oo`80
00IJEP03001JEUYF008005Eoo`00?Woo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000004Uoo`@000QJEP03001JEUYF00=JEPL000=JEP03001JEUYF009JEP03001oogoo05=oo`00@Goo
10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Cgoo0`0015YF00<005YFFUH01UYF00@005YF
FUIJEP<00003FUH005YF009JEP8005Eoo`00AGoo4000F7oo0`0000=JEP00FUH01eYF00<005YFFUH0
15YF0P000eYF0P00EGoo002`Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP04001FOol00;=oo`@0
009JEP03001JEUYF00AJEP04001JEUYFFUH3001FOol00;Moo`D000=JEP03001JEUYF009JEP<005Io
o`00_7oo2`00EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5928 .74367 m .59953 .68777 L .56868 .68258 L p .707 .577 .707 r
F P
0 g
s
.59953 .68777 m .5928 .74367 L .62446 .74675 L p .707 .577 .707 r
F P
0 g
s
.62446 .74675 m .63119 .69086 L .59953 .68777 L p .707 .577 .707 r
F P
0 g
s
.63119 .69086 m .62446 .74675 L .65381 .74743 L p .707 .577 .707 r
F P
0 g
s
.65381 .74743 m .66054 .69154 L .63119 .69086 L p .707 .577 .707 r
F P
0 g
s
.56194 .73847 m .56868 .68258 L .54164 .67578 L p .707 .577 .707 r
F P
0 g
s
.56868 .68258 m .56194 .73847 L .5928 .74367 L p .707 .577 .707 r
F P
0 g
s
.66054 .69154 m .65381 .74743 L .67799 .74563 L p .707 .577 .707 r
F P
0 g
s
.67799 .74563 m .68472 .68974 L .66054 .69154 L p .707 .577 .707 r
F P
0 g
s
.54164 .67578 m .5349 .73168 L .56194 .73847 L p .707 .577 .707 r
F P
0 g
s
.58602 .79515 m .59703 .75872 L .56733 .74877 L p .707 .577 .707 r
F P
0 g
s
.59703 .75872 m .58602 .79515 L .61658 .80386 L p .707 .577 .707 r
F P
0 g
s
.61658 .80386 m .62759 .76742 L .59703 .75872 L p .707 .577 .707 r
F P
0 g
s
.5349 .73168 m .54164 .67578 L .52107 .66805 L p .707 .577 .707 r
F P
0 g
s
.62759 .76742 m .61658 .80386 L .64501 .81047 L p .707 .577 .707 r
F P
0 g
s
.64501 .81047 m .65602 .77403 L .62759 .76742 L p .707 .577 .707 r
F P
0 g
s
.56733 .74877 m .55632 .78521 L .58602 .79515 L p .707 .577 .707 r
F P
0 g
s
.55632 .78521 m .56733 .74877 L .5414 .73856 L p .707 .577 .707 r
F P
0 g
s
.5414 .73856 m .53039 .775 L .55632 .78521 L p .707 .577 .707 r
F P
0 g
s
.52107 .66805 m .51433 .72395 L .5349 .73168 L p .707 .577 .707 r
F P
0 g
s
.65602 .77403 m .64501 .81047 L .66853 .81435 L p .707 .577 .707 r
F P
0 g
s
.66853 .81435 m .67954 .77791 L .65602 .77403 L p .707 .577 .707 r
F P
0 g
s
.59332 .83665 m .59897 .81846 L .56921 .80836 L p .707 .577 .707 r
F P
0 g
s
.59897 .81846 m .59332 .83665 L .62376 .84552 L p .707 .577 .707 r
F P
0 g
s
.62376 .84552 m .62941 .82733 L .59897 .81846 L p .707 .577 .707 r
F P
0 g
s
.68472 .68974 m .67799 .74563 L .69463 .74153 L p .707 .577 .707 r
F P
0 g
s
.69463 .74153 m .70136 .68564 L .68472 .68974 L p .707 .577 .707 r
F P
0 g
s
.56921 .80836 m .56355 .82655 L .59332 .83665 L p .707 .577 .707 r
F P
0 g
s
.62941 .82733 m .62376 .84552 L .65189 .85231 L p .707 .577 .707 r
F P
0 g
s
.65189 .85231 m .65755 .83411 L .62941 .82733 L p .707 .577 .707 r
F P
0 g
s
.53039 .775 m .5414 .73856 L .52178 .72908 L p .707 .577 .707 r
F P
0 g
s
.56355 .82655 m .56921 .80836 L .54303 .79802 L p .707 .577 .707 r
F P
0 g
s
.54303 .79802 m .53738 .81622 L .56355 .82655 L p .707 .577 .707 r
F P
0 g
s
.51433 .72395 m .52107 .66805 L .50897 .66015 L p .707 .577 .707 r
F P
0 g
s
.52178 .72908 m .51077 .76552 L .53039 .775 L p .707 .577 .707 r
F P
0 g
s
.65755 .83411 m .65189 .85231 L .67497 .85633 L p .707 .577 .707 r
F P
0 g
s
.67497 .85633 m .68063 .83814 L .65755 .83411 L p .707 .577 .707 r
F P
0 g
s
.53738 .81622 m .54303 .79802 L .52301 .78847 L p .707 .577 .707 r
F P
0 g
s
.67954 .77791 m .66853 .81435 L .68484 .8151 L p .707 .577 .707 r
F P
0 g
s
.68484 .8151 m .69585 .77866 L .67954 .77791 L p .707 .577 .707 r
F P
0 g
s
.50897 .66015 m .50224 .71604 L .51433 .72395 L p .707 .577 .707 r
F P
0 g
s
.52301 .78847 m .51736 .80666 L .53738 .81622 L p .707 .577 .707 r
F P
0 g
s
.70136 .68564 m .69463 .74153 L .7021 .73554 L p .707 .577 .707 r
F P
0 g
s
.7021 .73554 m .70883 .67964 L .70136 .68564 L p .707 .577 .707 r
F P
0 g
s
.51077 .76552 m .52178 .72908 L .51039 .72127 L p .707 .577 .707 r
F P
0 g
s
.51039 .72127 m .49938 .7577 L .51077 .76552 L p .707 .577 .707 r
F P
0 g
s
.50224 .71604 m .50897 .66015 L .50654 .65284 L p .707 .577 .707 r
F P
0 g
s
.68063 .83814 m .67497 .85633 L .69073 .85721 L p .707 .577 .707 r
F P
0 g
s
.69073 .85721 m .69639 .83902 L .68063 .83814 L p .707 .577 .707 r
F P
0 g
s
.51736 .80666 m .52301 .78847 L .5111 .78062 L p .707 .577 .707 r
F P
0 g
s
.5111 .78062 m .50544 .79882 L .51736 .80666 L p .707 .577 .707 r
F P
0 g
s
.69585 .77866 m .68484 .8151 L .69233 .81267 L p .707 .577 .707 r
F P
0 g
s
.69233 .81267 m .70334 .77623 L .69585 .77866 L p .707 .577 .707 r
F P
0 g
s
.50654 .65284 m .49981 .70873 L .50224 .71604 L p .707 .577 .707 r
F P
0 g
s
.49938 .7577 m .51039 .72127 L .50834 .71587 L p .707 .577 .707 r
F P
0 g
s
.70883 .67964 m .7021 .73554 L .69967 .72822 L p .707 .577 .707 r
F P
0 g
s
.69967 .72822 m .7064 .67233 L .70883 .67964 L p .707 .577 .707 r
F P
0 g
s
.50834 .71587 m .49733 .75231 L .49938 .7577 L p .707 .577 .707 r
F P
0 g
s
.49981 .70873 m .50654 .65284 L .51401 .64684 L p .707 .577 .707 r
F P
0 g
s
.50847 .77526 m .50281 .79345 L .50544 .79882 L p .707 .577 .707 r
F P
0 g
s
.51401 .64684 m .50728 .70273 L .49981 .70873 L p .707 .577 .707 r
F P
0 g
s
.49733 .75231 m .50834 .71587 L .51584 .71344 L p .707 .577 .707 r
F P
0 g
s
.51584 .71344 m .50483 .74988 L .49733 .75231 L p .707 .577 .707 r
F P
0 g
s
.50544 .79882 m .5111 .78062 L .50847 .77526 L p .707 .577 .707 r
F P
0 g
s
.50281 .79345 m .50847 .77526 L .51537 .7729 L p .707 .577 .707 r
F P
0 g
s
.51537 .7729 m .50971 .7911 L .50281 .79345 L p .707 .577 .707 r
F P
0 g
s
.50483 .74988 m .51584 .71344 L .53214 .71419 L p .707 .577 .707 r
F P
0 g
s
.53214 .71419 m .52113 .75063 L .50483 .74988 L p .707 .577 .707 r
F P
0 g
s
.50488 .8219 m .50488 .32001 L .4601 .31852 L p .707 .577 .707 r
F P
0 g
s
.50728 .70273 m .51401 .64684 L .53065 .64274 L p .707 .577 .707 r
F P
0 g
s
.53065 .64274 m .52392 .69863 L .50728 .70273 L p .707 .577 .707 r
F P
0 g
s
.52392 .69863 m .53065 .64274 L .55483 .64094 L p .707 .577 .707 r
F P
0 g
s
.50971 .7911 m .51537 .7729 L .53113 .77378 L p .707 .577 .707 r
F P
0 g
s
.53113 .77378 m .52547 .79197 L .50971 .7911 L p .707 .577 .707 r
F P
0 g
s
.55483 .64094 m .5481 .69683 L .52392 .69863 L p .707 .577 .707 r
F P
0 g
s
.52113 .75063 m .53214 .71419 L .55566 .71807 L p .707 .577 .707 r
F P
0 g
s
.55566 .71807 m .54465 .75451 L .52113 .75063 L p .707 .577 .707 r
F P
0 g
s
.52547 .79197 m .53113 .77378 L .55421 .77781 L p .707 .577 .707 r
F P
0 g
s
.55421 .77781 m .54855 .796 L .52547 .79197 L p .707 .577 .707 r
F P
0 g
s
.50488 .32001 m .50488 .8219 L .54919 .8196 L p .707 .577 .707 r
F P
0 g
s
.5481 .69683 m .55483 .64094 L .58419 .64162 L p .707 .577 .707 r
F P
0 g
s
.58419 .64162 m .57745 .69751 L .5481 .69683 L p .707 .577 .707 r
F P
0 g
s
.54465 .75451 m .55566 .71807 L .58409 .72468 L p .707 .577 .707 r
F P
0 g
s
.58409 .72468 m .57308 .76112 L .54465 .75451 L p .707 .577 .707 r
F P
0 g
s
.54855 .796 m .55421 .77781 L .58234 .78459 L p .707 .577 .707 r
F P
0 g
s
.58234 .78459 m .57669 .80278 L .54855 .796 L p .707 .577 .707 r
F P
0 g
s
.54919 .8196 m .54919 .31771 L .50488 .32001 L p .707 .577 .707 r
F P
0 g
s
.69639 .83902 m .69073 .85721 L .69763 .85485 L p .707 .577 .707 r
F P
0 g
s
.69763 .85485 m .70329 .83666 L .69639 .83902 L p .707 .577 .707 r
F P
0 g
s
.4601 .82041 m .4601 .31852 L .41921 .3134 L p .707 .577 .707 r
F P
0 g
s
.4601 .31852 m .4601 .82041 L .50488 .8219 L p .707 .577 .707 r
F P
0 g
s
.57745 .69751 m .58419 .64162 L .61584 .64471 L p .707 .577 .707 r
F P
0 g
s
.61584 .64471 m .60911 .7006 L .57745 .69751 L p .707 .577 .707 r
F P
0 g
s
.57308 .76112 m .58409 .72468 L .61466 .73339 L p .707 .577 .707 r
F P
0 g
s
.61466 .73339 m .60365 .76982 L .57308 .76112 L p .707 .577 .707 r
F P
0 g
s
.57669 .80278 m .58234 .78459 L .61278 .79347 L p .707 .577 .707 r
F P
0 g
s
.61278 .79347 m .60713 .81166 L .57669 .80278 L p .707 .577 .707 r
F P
0 g
s
.54919 .31771 m .54919 .8196 L .58869 .81374 L p .707 .577 .707 r
F P
0 g
s
.58869 .81374 m .58869 .31185 L .54919 .31771 L p .707 .577 .707 r
F P
0 g
s
.70334 .77623 m .69233 .81267 L .69029 .80727 L p .707 .577 .707 r
F P
0 g
s
.69029 .80727 m .7013 .77084 L .70334 .77623 L p .707 .577 .707 r
F P
0 g
s
.41921 .81528 m .41921 .3134 L .38624 .30513 L p .707 .577 .707 r
F P
0 g
s
.41921 .3134 m .41921 .81528 L .4601 .82041 L p .707 .577 .707 r
F P
0 g
s
.7064 .67233 m .69967 .72822 L .68758 .72032 L p .707 .577 .707 r
F P
0 g
s
.68758 .72032 m .69431 .66443 L .7064 .67233 L p .707 .577 .707 r
F P
0 g
s
.6467 .6499 m .63997 .70579 L .60911 .7006 L p .707 .577 .707 r
F P
0 g
s
.60911 .7006 m .61584 .64471 L .6467 .6499 L p .707 .577 .707 r
F P
0 g
s
.64435 .74333 m .63334 .77977 L .60365 .76982 L p .707 .577 .707 r
F P
0 g
s
.60365 .76982 m .61466 .73339 L .64435 .74333 L p .707 .577 .707 r
F P
0 g
s
.60713 .81166 m .61278 .79347 L .64255 .80356 L p .707 .577 .707 r
F P
0 g
s
.58869 .31185 m .58869 .81374 L .6195 .80489 L p .707 .577 .707 r
F P
0 g
s
.6195 .80489 m .6195 .30301 L .58869 .31185 L p .707 .577 .707 r
F P
0 g
s
.2511 .72293 m .25398 .66963 L .22293 .66536 L p .707 .577 .707 r
F P
0 g
s
.25398 .66963 m .2511 .72293 L .28292 .72344 L p .707 .577 .707 r
F P
0 g
s
.28292 .72344 m .28581 .67015 L .25398 .66963 L p .707 .577 .707 r
F P
0 g
s
.28581 .67015 m .28292 .72344 L .31242 .72015 L p .707 .577 .707 r
F P
0 g
s
.31242 .72015 m .3153 .66685 L .28581 .67015 L p .707 .577 .707 r
F P
0 g
s
.70329 .83666 m .69763 .85485 L .695 .84949 L p .707 .577 .707 r
F P
0 g
s
.695 .84949 m .70065 .8313 L .70329 .83666 L p .707 .577 .707 r
F P
0 g
s
.22005 .71866 m .22293 .66536 L .1957 .65776 L p .707 .577 .707 r
F P
0 g
s
.22293 .66536 m .22005 .71866 L .2511 .72293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3153 .66685 m .31242 .72015 L .33668 .71337 L p .707 .577 .707 r
F P
0 g
s
.33668 .71337 m .33957 .66008 L .3153 .66685 L p .707 .577 .707 r
F P
0 g
s
.7013 .77084 m .69029 .80727 L .67889 .79946 L p .707 .577 .707 r
F P
0 g
s
.67889 .79946 m .6899 .76302 L .7013 .77084 L p .707 .577 .707 r
F P
0 g
s
.19282 .71105 m .1957 .65776 L .17496 .64756 L p .707 .577 .707 r
F P
0 g
s
.1957 .65776 m .19282 .71105 L .22005 .71866 L p .707 .577 .707 r
F P
0 g
s
.69431 .66443 m .68758 .72032 L .667 .71259 L p .707 .577 .707 r
F P
0 g
s
.667 .71259 m .67374 .6567 L .69431 .66443 L p .707 .577 .707 r
F P
0 g
s
.38624 .80702 m .38624 .30513 L .3644 .29453 L p .707 .577 .707 r
F P
0 g
s
.38624 .30513 m .38624 .80702 L .41921 .81528 L p .707 .577 .707 r
F P
0 g
s
.67028 .75354 m .65927 .78998 L .63334 .77977 L p .707 .577 .707 r
F P
0 g
s
.63334 .77977 m .64435 .74333 L .67028 .75354 L p .707 .577 .707 r
F P
0 g
s
.6195 .30301 m .6195 .80489 L .63862 .79393 L p .707 .577 .707 r
F P
0 g
s
.63862 .79393 m .63861 .29204 L .6195 .30301 L p .707 .577 .707 r
F P
0 g
s
.24874 .79639 m .25355 .76417 L .22268 .75694 L p .707 .577 .707 r
F P
0 g
s
.25355 .76417 m .24874 .79639 L .28035 .79835 L p .707 .577 .707 r
F P
0 g
s
.28035 .79835 m .28516 .76613 L .25355 .76417 L p .707 .577 .707 r
F P
0 g
s
.33957 .66008 m .33668 .71337 L .35335 .70378 L p .707 .577 .707 r
F P
0 g
s
.35335 .70378 m .35624 .65048 L .33957 .66008 L p .707 .577 .707 r
F P
0 g
s
.70065 .8313 m .695 .84949 L .68309 .84164 L p .707 .577 .707 r
F P
0 g
s
.68309 .84164 m .68874 .82345 L .70065 .8313 L p .707 .577 .707 r
F P
0 g
s
.21788 .78916 m .22268 .75694 L .19559 .74515 L p .707 .577 .707 r
F P
0 g
s
.22268 .75694 m .21788 .78916 L .24874 .79639 L p .707 .577 .707 r
F P
0 g
s
.28516 .76613 m .28035 .79835 L .30962 .79485 L p .707 .577 .707 r
F P
0 g
s
.30962 .79485 m .31442 .76264 L .28516 .76613 L p .707 .577 .707 r
F P
0 g
s
.17496 .64756 m .17207 .70085 L .19282 .71105 L p .707 .577 .707 r
F P
0 g
s
.17207 .70085 m .17496 .64756 L .16273 .63576 L p .707 .577 .707 r
F P
0 g
s
.6899 .76302 m .67889 .79946 L .65927 .78998 L p .707 .577 .707 r
F P
0 g
s
.65927 .78998 m .67028 .75354 L .6899 .76302 L p .707 .577 .707 r
F P
0 g
s
.67374 .6567 m .667 .71259 L .63997 .70579 L p .707 .577 .707 r
F P
0 g
s
.63997 .70579 m .6467 .6499 L .67374 .6567 L p .707 .577 .707 r
F P
0 g
s
.19079 .77737 m .19559 .74515 L .17492 .72996 L p .707 .577 .707 r
F P
0 g
s
.19559 .74515 m .19079 .77737 L .21788 .78916 L p .707 .577 .707 r
F P
0 g
s
.31442 .76264 m .30962 .79485 L .33368 .78624 L p .707 .577 .707 r
F P
0 g
s
.33368 .78624 m .33848 .75402 L .31442 .76264 L p .707 .577 .707 r
F P
0 g
s
.25302 .84062 m .25551 .82454 L .22453 .8175 L p .707 .577 .707 r
F P
0 g
s
.25551 .82454 m .25302 .84062 L .28456 .84235 L p .707 .577 .707 r
F P
0 g
s
.28456 .84235 m .28705 .82628 L .25551 .82454 L p .707 .577 .707 r
F P
0 g
s
.22204 .83357 m .22453 .8175 L .19714 .80582 L p .707 .577 .707 r
F P
0 g
s
.22453 .8175 m .22204 .83357 L .25302 .84062 L p .707 .577 .707 r
F P
0 g
s
.28705 .82628 m .28456 .84235 L .31357 .8386 L p .707 .577 .707 r
F P
0 g
s
.31357 .8386 m .31606 .82253 L .28705 .82628 L p .707 .577 .707 r
F P
0 g
s
.35624 .65048 m .35335 .70378 L .36079 .6923 L p .707 .577 .707 r
F P
0 g
s
.36079 .6923 m .36368 .639 L .35624 .65048 L p .707 .577 .707 r
F P
0 g
s
.36368 .639 m .36079 .6923 L .35828 .68007 L p .707 .577 .707 r
F P
0 g
s
.35828 .68007 m .36116 .62677 L .36368 .639 L p .707 .577 .707 r
F P
0 g
s
.3644 .79642 m .3644 .29453 L .35584 .28264 L p .707 .577 .707 r
F P
0 g
s
.3644 .29453 m .3644 .79642 L .38624 .80702 L p .707 .577 .707 r
F P
0 g
s
.19714 .80582 m .19465 .8219 L .22204 .83357 L p .707 .577 .707 r
F P
0 g
s
.19465 .8219 m .19714 .80582 L .17602 .79067 L p .707 .577 .707 r
F P
0 g
s
.68874 .82345 m .68309 .84164 L .66306 .83209 L p .707 .577 .707 r
F P
0 g
s
.66306 .83209 m .66872 .8139 L .68874 .82345 L p .707 .577 .707 r
F P
0 g
s
.16273 .63576 m .15984 .68906 L .17207 .70085 L p .707 .577 .707 r
F P
0 g
s
.31606 .82253 m .31357 .8386 L .3372 .82974 L p .707 .577 .707 r
F P
0 g
s
.3372 .82974 m .33969 .81366 L .31606 .82253 L p .707 .577 .707 r
F P
0 g
s
.17012 .76217 m .17492 .72996 L .16269 .71285 L p .707 .577 .707 r
F P
0 g
s
.17492 .72996 m .17012 .76217 L .19079 .77737 L p .707 .577 .707 r
F P
0 g
s
.33848 .75402 m .33368 .78624 L .35017 .77335 L p .707 .577 .707 r
F P
0 g
s
.35017 .77335 m .35497 .74114 L .33848 .75402 L p .707 .577 .707 r
F P
0 g
s
.63861 .29204 m .63862 .79393 L .64416 .78191 L p .707 .577 .707 r
F P
0 g
s
.64416 .78191 m .64416 .28002 L .63861 .29204 L p .707 .577 .707 r
F P
0 g
s
.15984 .68906 m .16273 .63576 L .16021 .62353 L p .707 .577 .707 r
F P
0 g
s
.17602 .79067 m .17353 .80675 L .19465 .8219 L p .707 .577 .707 r
F P
0 g
s
.17353 .80675 m .17602 .79067 L .16324 .77352 L p .707 .577 .707 r
F P
0 g
s
.33969 .81366 m .3372 .82974 L .35316 .81662 L p .707 .577 .707 r
F P
0 g
s
.35316 .81662 m .35565 .80055 L .33969 .81366 L p .707 .577 .707 r
F P
0 g
s
.66872 .8139 m .66306 .83209 L .63689 .82176 L p .707 .577 .707 r
F P
0 g
s
.63689 .82176 m .64255 .80356 L .66872 .8139 L p .707 .577 .707 r
F P
0 g
s
.16269 .71285 m .15789 .74506 L .17012 .76217 L p .707 .577 .707 r
F P
0 g
s
.15789 .74506 m .16269 .71285 L .16011 .69549 L p .707 .577 .707 r
F P
0 g
s
.35497 .74114 m .35017 .77335 L .35748 .75745 L p .707 .577 .707 r
F P
0 g
s
.35748 .75745 m .36228 .72524 L .35497 .74114 L p .707 .577 .707 r
F P
0 g
s
.16021 .62353 m .15732 .67682 L .15984 .68906 L p .707 .577 .707 r
F P
0 g
s
.16324 .77352 m .16075 .7896 L .17353 .80675 L p .707 .577 .707 r
F P
0 g
s
.15732 .67682 m .16021 .62353 L .16765 .61205 L p .707 .577 .707 r
F P
0 g
s
.64255 .80356 m .63689 .82176 L .60713 .81166 L p .707 .577 .707 r
F P
0 g
s
.35987 .80054 m .36235 .78447 L .35565 .80055 L p .707 .577 .707 r
F P
0 g
s
.36116 .62677 m .35828 .68007 L .34604 .66827 L p .707 .577 .707 r
F P
0 g
s
.34604 .66827 m .34893 .61498 L .36116 .62677 L p .707 .577 .707 r
F P
0 g
s
.36228 .72524 m .35748 .75745 L .35489 .7401 L p .707 .577 .707 r
F P
0 g
s
.35489 .7401 m .3597 .70788 L .36228 .72524 L p .707 .577 .707 r
F P
0 g
s
.36235 .78447 m .35987 .80054 L .35667 .78307 L p .707 .577 .707 r
F P
0 g
s
.35667 .78307 m .35916 .767 L .36235 .78447 L p .707 .577 .707 r
F P
0 g
s
.3597 .70788 m .35489 .7401 L .34267 .72299 L p .707 .577 .707 r
F P
0 g
s
.34267 .72299 m .34747 .69077 L .3597 .70788 L p .707 .577 .707 r
F P
0 g
s
.35916 .767 m .35667 .78307 L .34389 .76592 L p .707 .577 .707 r
F P
0 g
s
.34389 .76592 m .34638 .74985 L .35916 .767 L p .707 .577 .707 r
F P
0 g
s
.35584 .28264 m .35584 .78453 L .3644 .79642 L p .707 .577 .707 r
F P
0 g
s
.35584 .78453 m .35584 .28264 L .36138 .27062 L p .707 .577 .707 r
F P
0 g
s
.16075 .7896 m .16324 .77352 L .16004 .75605 L p .707 .577 .707 r
F P
0 g
s
.35565 .80055 m .35316 .81662 L .35987 .80054 L p .707 .577 .707 r
F P
0 g
s
.16011 .69549 m .15531 .72771 L .15789 .74506 L p .707 .577 .707 r
F P
0 g
s
.64416 .28002 m .64416 .78191 L .6356 .77002 L p .707 .577 .707 r
F P
0 g
s
.6356 .77002 m .6356 .26813 L .64416 .28002 L p .707 .577 .707 r
F P
0 g
s
.16004 .75605 m .15756 .77213 L .16075 .7896 L p .707 .577 .707 r
F P
0 g
s
.15531 .72771 m .16011 .69549 L .16742 .67959 L p .707 .577 .707 r
F P
0 g
s
.16765 .61205 m .16476 .66535 L .15732 .67682 L p .707 .577 .707 r
F P
0 g
s
.16476 .66535 m .16765 .61205 L .18432 .60245 L p .707 .577 .707 r
F P
0 g
s
.15756 .77213 m .16004 .75605 L .16675 .73997 L p .707 .577 .707 r
F P
0 g
s
.16742 .67959 m .16262 .71181 L .15531 .72771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16675 .73997 m .16426 .75605 L .15756 .77213 L p .707 .577 .707 r
F P
0 g
s
.16262 .71181 m .16742 .67959 L .18391 .6667 L p .707 .577 .707 r
F P
0 g
s
.34893 .61498 m .34604 .66827 L .3253 .65807 L p .707 .577 .707 r
F P
0 g
s
.3253 .65807 m .32818 .60478 L .34893 .61498 L p .707 .577 .707 r
F P
0 g
s
.36138 .77251 m .36138 .27062 L .3805 .25965 L p .707 .577 .707 r
F P
0 g
s
.36138 .27062 m .36138 .77251 L .35584 .78453 L p .707 .577 .707 r
F P
0 g
s
.18432 .60245 m .18143 .65575 L .16476 .66535 L p .707 .577 .707 r
F P
0 g
s
.18143 .65575 m .18432 .60245 L .20859 .59568 L p .707 .577 .707 r
F P
0 g
s
.6356 .26813 m .6356 .77002 L .61376 .75942 L p .707 .577 .707 r
F P
0 g
s
.61376 .75942 m .61376 .25753 L .6356 .26813 L p .707 .577 .707 r
F P
0 g
s
.16426 .75605 m .16675 .73997 L .18271 .72686 L p .707 .577 .707 r
F P
0 g
s
.18391 .6667 m .17911 .69892 L .16262 .71181 L p .707 .577 .707 r
F P
0 g
s
.32818 .60478 m .3253 .65807 L .29807 .65047 L p .707 .577 .707 r
F P
0 g
s
.29807 .65047 m .30095 .59717 L .32818 .60478 L p .707 .577 .707 r
F P
0 g
s
.17911 .69892 m .18391 .6667 L .20797 .65809 L p .707 .577 .707 r
F P
0 g
s
.34747 .69077 m .34267 .72299 L .322 .70779 L p .707 .577 .707 r
F P
0 g
s
.322 .70779 m .3268 .67558 L .34747 .69077 L p .707 .577 .707 r
F P
0 g
s
.18271 .72686 m .18022 .74293 L .16426 .75605 L p .707 .577 .707 r
F P
0 g
s
.2057 .64898 m .20859 .59568 L .23808 .59239 L p .707 .577 .707 r
F P
0 g
s
.20859 .59568 m .2057 .64898 L .18143 .65575 L p .707 .577 .707 r
F P
0 g
s
.30095 .59717 m .29807 .65047 L .26702 .6462 L p .707 .577 .707 r
F P
0 g
s
.26702 .6462 m .2699 .5929 L .30095 .59717 L p .707 .577 .707 r
F P
0 g
s
.18022 .74293 m .18271 .72686 L .20634 .71799 L p .707 .577 .707 r
F P
0 g
s
.23519 .64568 m .23808 .59239 L .2699 .5929 L p .707 .577 .707 r
F P
0 g
s
.23808 .59239 m .23519 .64568 L .2057 .64898 L p .707 .577 .707 r
F P
0 g
s
.3805 .25965 m .3805 .76154 L .36138 .77251 L p .707 .577 .707 r
F P
0 g
s
.3805 .76154 m .3805 .25965 L .41131 .2508 L p .707 .577 .707 r
F P
0 g
s
.34638 .74985 m .34389 .76592 L .32277 .75077 L p .707 .577 .707 r
F P
0 g
s
.32277 .75077 m .32526 .7347 L .34638 .74985 L p .707 .577 .707 r
F P
0 g
s
.20316 .69031 m .20797 .65809 L .23723 .6546 L p .707 .577 .707 r
F P
0 g
s
.20797 .65809 m .20316 .69031 L .17911 .69892 L p .707 .577 .707 r
F P
0 g
s
.3268 .67558 m .322 .70779 L .2949 .696 L p .707 .577 .707 r
F P
0 g
s
.2949 .696 m .29971 .66379 L .3268 .67558 L p .707 .577 .707 r
F P
0 g
s
.2699 .5929 m .26702 .6462 L .23519 .64568 L p .707 .577 .707 r
F P
0 g
s
.61376 .25753 m .61376 .75942 L .58078 .75115 L p .707 .577 .707 r
F P
0 g
s
.58078 .75115 m .58078 .24926 L .61376 .25753 L p .707 .577 .707 r
F P
0 g
s
.20634 .71799 m .20386 .73407 L .18022 .74293 L p .707 .577 .707 r
F P
0 g
s
.23243 .68681 m .23723 .6546 L .26884 .65656 L p .707 .577 .707 r
F P
0 g
s
.23723 .6546 m .23243 .68681 L .20316 .69031 L p .707 .577 .707 r
F P
0 g
s
.29971 .66379 m .2949 .696 L .26404 .68877 L p .707 .577 .707 r
F P
0 g
s
.26404 .68877 m .26884 .65656 L .29971 .66379 L p .707 .577 .707 r
F P
0 g
s
.73298 .64635 m .73009 .5894 L .69905 .58979 L p .707 .577 .707 r
F P
0 g
s
.73009 .5894 m .73298 .64635 L .7648 .64439 L p .707 .577 .707 r
F P
0 g
s
.7648 .64439 m .76192 .58744 L .73009 .5894 L p .707 .577 .707 r
F P
0 g
s
.76192 .58744 m .7648 .64439 L .79429 .64106 L p .707 .577 .707 r
F P
0 g
s
.79429 .64106 m .79141 .58411 L .76192 .58744 L p .707 .577 .707 r
F P
0 g
s
.20386 .73407 m .20634 .71799 L .23535 .71425 L p .707 .577 .707 r
F P
0 g
s
.26884 .65656 m .26404 .68877 L .23243 .68681 L p .707 .577 .707 r
F P
0 g
s
.32526 .7347 m .32277 .75077 L .29538 .7391 L p .707 .577 .707 r
F P
0 g
s
.29538 .7391 m .29787 .72303 L .32526 .7347 L p .707 .577 .707 r
F P
0 g
s
.70193 .64674 m .69905 .58979 L .67182 .58859 L p .707 .577 .707 r
F P
0 g
s
.69905 .58979 m .70193 .64674 L .73298 .64635 L p .707 .577 .707 r
F P
0 g
s
.23535 .71425 m .23286 .73032 L .20386 .73407 L p .707 .577 .707 r
F P
0 g
s
.79141 .58411 m .79429 .64106 L .81856 .63669 L p .707 .577 .707 r
F P
0 g
s
.81856 .63669 m .81568 .57974 L .79141 .58411 L p .707 .577 .707 r
F P
0 g
s
.23286 .73032 m .23535 .71425 L .26689 .71598 L p .707 .577 .707 r
F P
0 g
s
.67182 .58859 m .6747 .64554 L .70193 .64674 L p .707 .577 .707 r
F P
0 g
s
.29787 .72303 m .29538 .7391 L .2644 .73205 L p .707 .577 .707 r
F P
0 g
s
.2644 .73205 m .26689 .71598 L .29787 .72303 L p .707 .577 .707 r
F P
0 g
s
.41131 .75269 m .41131 .2508 L .4508 .24494 L p .707 .577 .707 r
F P
0 g
s
.41131 .2508 m .41131 .75269 L .3805 .76154 L p .707 .577 .707 r
F P
0 g
s
.70029 .65627 m .7051 .69442 L .73596 .69037 L p .707 .577 .707 r
F P
0 g
s
.73596 .69037 m .73115 .65222 L .70029 .65627 L p .707 .577 .707 r
F P
0 g
s
.73115 .65222 m .73596 .69037 L .76757 .68645 L p .707 .577 .707 r
F P
0 g
s
.76757 .68645 m .76277 .6483 L .73115 .65222 L p .707 .577 .707 r
F P
0 g
s
.26689 .71598 m .2644 .73205 L .23286 .73032 L p .707 .577 .707 r
F P
0 g
s
.76277 .6483 m .76757 .68645 L .79683 .68305 L p .707 .577 .707 r
F P
0 g
s
.79683 .68305 m .79203 .64489 L .76277 .6483 L p .707 .577 .707 r
F P
0 g
s
.58078 .24926 m .58078 .75115 L .5399 .74602 L p .707 .577 .707 r
F P
0 g
s
.5399 .74602 m .5399 .24413 L .58078 .24926 L p .707 .577 .707 r
F P
0 g
s
.6747 .64554 m .67182 .58859 L .65107 .58591 L p .707 .577 .707 r
F P
0 g
s
.6732 .66005 m .678 .69821 L .7051 .69442 L p .707 .577 .707 r
F P
0 g
s
.7051 .69442 m .70029 .65627 L .6732 .66005 L p .707 .577 .707 r
F P
0 g
s
.65107 .58591 m .65395 .64286 L .6747 .64554 L p .707 .577 .707 r
F P
0 g
s
.79203 .64489 m .79683 .68305 L .82089 .68049 L p .707 .577 .707 r
F P
0 g
s
.82089 .68049 m .81609 .64234 L .79203 .64489 L p .707 .577 .707 r
F P
0 g
s
.81568 .57974 m .81856 .63669 L .83523 .63171 L p .707 .577 .707 r
F P
0 g
s
.83523 .63171 m .83235 .57475 L .81568 .57974 L p .707 .577 .707 r
F P
0 g
s
.70213 .71586 m .70462 .73493 L .7356 .73072 L p .707 .577 .707 r
F P
0 g
s
.7356 .73072 m .73311 .71165 L .70213 .71586 L p .707 .577 .707 r
F P
0 g
s
.73311 .71165 m .7356 .73072 L .76714 .72668 L p .707 .577 .707 r
F P
0 g
s
.76714 .72668 m .76465 .70762 L .73311 .71165 L p .707 .577 .707 r
F P
0 g
s
.4508 .74683 m .4508 .24494 L .49511 .24265 L p .707 .577 .707 r
F P
0 g
s
.4508 .24494 m .4508 .74683 L .41131 .75269 L p .707 .577 .707 r
F P
0 g
s
.76465 .70762 m .76714 .72668 L .79614 .72322 L p .707 .577 .707 r
F P
0 g
s
.79614 .72322 m .79365 .70416 L .76465 .70762 L p .707 .577 .707 r
F P
0 g
s
.5399 .24413 m .5399 .74602 L .49511 .74454 L p .707 .577 .707 r
F P
0 g
s
.49511 .74454 m .49511 .24265 L .5399 .24413 L p .707 .577 .707 r
F P
0 g
s
.67474 .71984 m .67723 .7389 L .70462 .73493 L p .707 .577 .707 r
F P
0 g
s
.70462 .73493 m .70213 .71586 L .67474 .71984 L p .707 .577 .707 r
F P
0 g
s
.65253 .6632 m .65733 .70135 L .678 .69821 L p .707 .577 .707 r
F P
0 g
s
.678 .69821 m .6732 .66005 L .65253 .6632 L p .707 .577 .707 r
F P
0 g
s
.49511 .24265 m .49511 .74454 L .4508 .74683 L p .707 .577 .707 r
F P
0 g
s
.65395 .64286 m .65107 .58591 L .63884 .58201 L p .707 .577 .707 r
F P
0 g
s
.79365 .70416 m .79614 .72322 L .81978 .72067 L p .707 .577 .707 r
F P
0 g
s
.81978 .72067 m .81729 .70161 L .79365 .70416 L p .707 .577 .707 r
F P
0 g
s
.81609 .64234 m .82089 .68049 L .83738 .67903 L p .707 .577 .707 r
F P
0 g
s
.83738 .67903 m .83258 .64087 L .81609 .64234 L p .707 .577 .707 r
F P
0 g
s
.63884 .58201 m .64172 .63896 L .65395 .64286 L p .707 .577 .707 r
F P
0 g
s
.65362 .72319 m .65611 .74225 L .67723 .7389 L p .707 .577 .707 r
F P
0 g
s
.67723 .7389 m .67474 .71984 L .65362 .72319 L p .707 .577 .707 r
F P
0 g
s
.83235 .57475 m .83523 .63171 L .84267 .62659 L p .707 .577 .707 r
F P
0 g
s
.84267 .62659 m .83979 .56964 L .83235 .57475 L p .707 .577 .707 r
F P
0 g
s
.6403 .6654 m .64511 .70355 L .65733 .70135 L p .707 .577 .707 r
F P
0 g
s
.65733 .70135 m .65253 .6632 L .6403 .6654 L p .707 .577 .707 r
F P
0 g
s
.81729 .70161 m .81978 .72067 L .83573 .71929 L p .707 .577 .707 r
F P
0 g
s
.83573 .71929 m .83325 .70022 L .81729 .70161 L p .707 .577 .707 r
F P
0 g
s
.64172 .63896 m .63884 .58201 L .63632 .57727 L p .707 .577 .707 r
F P
0 g
s
.64084 .72559 m .64332 .74465 L .65611 .74225 L p .707 .577 .707 r
F P
0 g
s
.65611 .74225 m .65362 .72319 L .64084 .72559 L p .707 .577 .707 r
F P
0 g
s
.83258 .64087 m .83738 .67903 L .84469 .67881 L p .707 .577 .707 r
F P
0 g
s
.84469 .67881 m .83989 .64065 L .83258 .64087 L p .707 .577 .707 r
F P
0 g
s
.63632 .57727 m .6392 .63422 L .64172 .63896 L p .707 .577 .707 r
F P
0 g
s
.83979 .56964 m .84267 .62659 L .84016 .62185 L p .707 .577 .707 r
F P
0 g
s
.84016 .62185 m .83727 .5649 L .83979 .56964 L p .707 .577 .707 r
F P
0 g
s
.63772 .66644 m .64252 .7046 L .64511 .70355 L p .707 .577 .707 r
F P
0 g
s
.64511 .70355 m .6403 .6654 L .63772 .66644 L p .707 .577 .707 r
F P
0 g
s
.83325 .70022 m .83573 .71929 L .84244 .71919 L p .707 .577 .707 r
F P
0 g
s
.84244 .71919 m .83995 .70013 L .83325 .70022 L p .707 .577 .707 r
F P
0 g
s
.6392 .63422 m .63632 .57727 L .64376 .57215 L p .707 .577 .707 r
F P
0 g
s
.63764 .7268 m .64013 .74586 L .64332 .74465 L p .707 .577 .707 r
F P
0 g
s
.64332 .74465 m .64084 .72559 L .63764 .7268 L p .707 .577 .707 r
F P
0 g
s
.83989 .64065 m .84469 .67881 L .84211 .67985 L p .707 .577 .707 r
F P
0 g
s
.84211 .67985 m .8373 .6417 L .83989 .64065 L p .707 .577 .707 r
F P
0 g
s
.64376 .57215 m .64664 .62911 L .6392 .63422 L p .707 .577 .707 r
F P
0 g
s
.83727 .5649 m .84016 .62185 L .82792 .61795 L p .707 .577 .707 r
F P
0 g
s
.82792 .61795 m .82504 .561 L .83727 .5649 L p .707 .577 .707 r
F P
0 g
s
.64503 .66622 m .64983 .70438 L .64252 .7046 L p .707 .577 .707 r
F P
0 g
s
.64252 .7046 m .63772 .66644 L .64503 .66622 L p .707 .577 .707 r
F P
0 g
s
.39089 .62588 m .38416 .5715 L .3533 .57257 L p .707 .577 .707 r
F P
0 g
s
.38416 .5715 m .39089 .62588 L .42254 .62158 L p .707 .577 .707 r
F P
0 g
s
.42254 .62158 m .41581 .5672 L .38416 .5715 L p .707 .577 .707 r
F P
0 g
s
.41581 .5672 m .42254 .62158 L .4519 .61446 L p .707 .577 .707 r
F P
0 g
s
.4519 .61446 m .44517 .56008 L .41581 .5672 L p .707 .577 .707 r
F P
0 g
s
.83995 .70013 m .84244 .71919 L .83925 .72041 L p .707 .577 .707 r
F P
0 g
s
.83925 .72041 m .83676 .70134 L .83995 .70013 L p .707 .577 .707 r
F P
0 g
s
.36003 .62695 m .3533 .57257 L .32626 .5703 L p .707 .577 .707 r
F P
0 g
s
.3533 .57257 m .36003 .62695 L .39089 .62588 L p .707 .577 .707 r
F P
0 g
s
.64664 .62911 m .64376 .57215 L .66043 .56717 L p .707 .577 .707 r
F P
0 g
s
.44517 .56008 m .4519 .61446 L .47608 .60523 L p .707 .577 .707 r
F P
0 g
s
.47608 .60523 m .46935 .55085 L .44517 .56008 L p .707 .577 .707 r
F P
0 g
s
.64435 .72671 m .64684 .74577 L .64013 .74586 L p .707 .577 .707 r
F P
0 g
s
.64013 .74586 m .63764 .7268 L .64435 .72671 L p .707 .577 .707 r
F P
0 g
s
.8373 .6417 m .84211 .67985 L .82988 .68205 L p .707 .577 .707 r
F P
0 g
s
.82988 .68205 m .82508 .6439 L .8373 .6417 L p .707 .577 .707 r
F P
0 g
s
.66043 .56717 m .66331 .62412 L .64664 .62911 L p .707 .577 .707 r
F P
0 g
s
.82504 .561 m .82792 .61795 L .80718 .61527 L p .707 .577 .707 r
F P
0 g
s
.80718 .61527 m .8043 .55832 L .82504 .561 L p .707 .577 .707 r
F P
0 g
s
.42691 .68397 m .4159 .64992 L .38534 .65917 L p .707 .577 .707 r
F P
0 g
s
.4159 .64992 m .42691 .68397 L .45534 .67158 L p .707 .577 .707 r
F P
0 g
s
.45534 .67158 m .44434 .63753 L .4159 .64992 L p .707 .577 .707 r
F P
0 g
s
.33299 .62468 m .32626 .5703 L .30569 .56491 L p .707 .577 .707 r
F P
0 g
s
.32626 .5703 m .33299 .62468 L .36003 .62695 L p .707 .577 .707 r
F P
0 g
s
.39635 .69323 m .38534 .65917 L .35564 .66438 L p .707 .577 .707 r
F P
0 g
s
.38534 .65917 m .39635 .69323 L .42691 .68397 L p .707 .577 .707 r
F P
0 g
s
.66152 .66476 m .66632 .70291 L .64983 .70438 L p .707 .577 .707 r
F P
0 g
s
.64983 .70438 m .64503 .66622 L .66152 .66476 L p .707 .577 .707 r
F P
0 g
s
.46935 .55085 m .47608 .60523 L .49272 .59479 L p .707 .577 .707 r
F P
0 g
s
.49272 .59479 m .48599 .54041 L .46935 .55085 L p .707 .577 .707 r
F P
0 g
s
.44434 .63753 m .45534 .67158 L .47887 .65725 L p .707 .577 .707 r
F P
0 g
s
.47887 .65725 m .46786 .6232 L .44434 .63753 L p .707 .577 .707 r
F P
0 g
s
.83676 .70134 m .83925 .72041 L .82647 .72281 L p .707 .577 .707 r
F P
0 g
s
.82647 .72281 m .82398 .70374 L .83676 .70134 L p .707 .577 .707 r
F P
0 g
s
.66331 .62412 m .66043 .56717 L .6847 .5628 L p .707 .577 .707 r
F P
0 g
s
.36665 .69843 m .35564 .66438 L .32971 .66502 L p .707 .577 .707 r
F P
0 g
s
.35564 .66438 m .36665 .69843 L .39635 .69323 L p .707 .577 .707 r
F P
0 g
s
.42331 .72661 m .41766 .70968 L .38722 .71938 L p .707 .577 .707 r
F P
0 g
s
.41766 .70968 m .42331 .72661 L .45145 .71379 L p .707 .577 .707 r
F P
0 g
s
.45145 .71379 m .44579 .69685 L .41766 .70968 L p .707 .577 .707 r
F P
0 g
s
.39287 .73631 m .38722 .71938 L .35745 .725 L p .707 .577 .707 r
F P
0 g
s
.38722 .71938 m .39287 .73631 L .42331 .72661 L p .707 .577 .707 r
F P
0 g
s
.30569 .56491 m .31242 .61929 L .33299 .62468 L p .707 .577 .707 r
F P
0 g
s
.66031 .72532 m .66279 .74438 L .64684 .74577 L p .707 .577 .707 r
F P
0 g
s
.64684 .74577 m .64435 .72671 L .66031 .72532 L p .707 .577 .707 r
F P
0 g
s
.82508 .6439 m .82988 .68205 L .80921 .6852 L p .707 .577 .707 r
F P
0 g
s
.80921 .6852 m .80441 .64704 L .82508 .6439 L p .707 .577 .707 r
F P
0 g
s
.6847 .5628 m .68758 .61975 L .66331 .62412 L p .707 .577 .707 r
F P
0 g
s
.8043 .55832 m .80718 .61527 L .77995 .61407 L p .707 .577 .707 r
F P
0 g
s
.77995 .61407 m .77707 .55712 L .8043 .55832 L p .707 .577 .707 r
F P
0 g
s
.46786 .6232 m .47887 .65725 L .49517 .64239 L p .707 .577 .707 r
F P
0 g
s
.49517 .64239 m .48416 .60834 L .46786 .6232 L p .707 .577 .707 r
F P
0 g
s
.31242 .61929 m .30569 .56491 L .29359 .55694 L p .707 .577 .707 r
F P
0 g
s
.44579 .69685 m .45145 .71379 L .47453 .6991 L p .707 .577 .707 r
F P
0 g
s
.47453 .6991 m .46887 .68216 L .44579 .69685 L p .707 .577 .707 r
F P
0 g
s
.35745 .725 m .36311 .74194 L .39287 .73631 L p .707 .577 .707 r
F P
0 g
s
.32971 .66502 m .34072 .69907 L .36665 .69843 L p .707 .577 .707 r
F P
0 g
s
.36311 .74194 m .35745 .725 L .33128 .72601 L p .707 .577 .707 r
F P
0 g
s
.48599 .54041 m .49272 .59479 L .50019 .58416 L p .707 .577 .707 r
F P
0 g
s
.50019 .58416 m .49346 .52978 L .48599 .54041 L p .707 .577 .707 r
F P
0 g
s
.34072 .69907 m .32971 .66502 L .31009 .66104 L p .707 .577 .707 r
F P
0 g
s
.68557 .6622 m .69038 .70036 L .66632 .70291 L p .707 .577 .707 r
F P
0 g
s
.66632 .70291 m .66152 .66476 L .68557 .6622 L p .707 .577 .707 r
F P
0 g
s
.68758 .61975 m .6847 .5628 L .71419 .55947 L p .707 .577 .707 r
F P
0 g
s
.33128 .72601 m .33693 .74294 L .36311 .74194 L p .707 .577 .707 r
F P
0 g
s
.82398 .70374 m .82647 .72281 L .80535 .72616 L p .707 .577 .707 r
F P
0 g
s
.80535 .72616 m .80286 .70709 L .82398 .70374 L p .707 .577 .707 r
F P
0 g
s
.77707 .55712 m .77995 .61407 L .7489 .61446 L p .707 .577 .707 r
F P
0 g
s
.7489 .61446 m .74602 .55751 L .77707 .55712 L p .707 .577 .707 r
F P
0 g
s
.71419 .55947 m .71707 .61642 L .68758 .61975 L p .707 .577 .707 r
F P
0 g
s
.46887 .68216 m .47453 .6991 L .49029 .68397 L p .707 .577 .707 r
F P
0 g
s
.49029 .68397 m .48463 .66704 L .46887 .68216 L p .707 .577 .707 r
F P
0 g
s
.29359 .55694 m .30033 .61132 L .31242 .61929 L p .707 .577 .707 r
F P
0 g
s
.80441 .64704 m .80921 .6852 L .78212 .68898 L p .707 .577 .707 r
F P
0 g
s
.71707 .61642 m .71419 .55947 L .74602 .55751 L p .707 .577 .707 r
F P
0 g
s
.78212 .68898 m .77731 .65083 L .80441 .64704 L p .707 .577 .707 r
F P
0 g
s
.31009 .66104 m .3211 .69509 L .34072 .69907 L p .707 .577 .707 r
F P
0 g
s
.74602 .55751 m .7489 .61446 L .71707 .61642 L p .707 .577 .707 r
F P
0 g
s
.33693 .74294 m .33128 .72601 L .31125 .72229 L p .707 .577 .707 r
F P
0 g
s
.68394 .72277 m .68643 .74183 L .66279 .74438 L p .707 .577 .707 r
F P
0 g
s
.66279 .74438 m .66031 .72532 L .68394 .72277 L p .707 .577 .707 r
F P
0 g
s
.48416 .60834 m .49517 .64239 L .50267 .62846 L p .707 .577 .707 r
F P
0 g
s
.50267 .62846 m .49166 .59441 L .48416 .60834 L p .707 .577 .707 r
F P
0 g
s
.71484 .6588 m .71964 .69695 L .69038 .70036 L p .707 .577 .707 r
F P
0 g
s
.69038 .70036 m .68557 .6622 L .71484 .6588 L p .707 .577 .707 r
F P
0 g
s
.30033 .61132 m .29359 .55694 L .29116 .54716 L p .707 .577 .707 r
F P
0 g
s
.31125 .72229 m .31691 .73923 L .33693 .74294 L p .707 .577 .707 r
F P
0 g
s
.3211 .69509 m .31009 .66104 L .2987 .65283 L p .707 .577 .707 r
F P
0 g
s
.49346 .52978 m .50019 .58416 L .49776 .57438 L p .707 .577 .707 r
F P
0 g
s
.49776 .57438 m .49103 .52 L .49346 .52978 L p .707 .577 .707 r
F P
0 g
s
.77731 .65083 m .78212 .68898 L .75126 .69303 L p .707 .577 .707 r
F P
0 g
s
.75126 .69303 m .74645 .65488 L .77731 .65083 L p .707 .577 .707 r
F P
0 g
s
.80286 .70709 m .80535 .72616 L .77796 .73013 L p .707 .577 .707 r
F P
0 g
s
.77796 .73013 m .77547 .71107 L .80286 .70709 L p .707 .577 .707 r
F P
0 g
s
.74645 .65488 m .75126 .69303 L .71964 .69695 L p .707 .577 .707 r
F P
0 g
s
.71964 .69695 m .71484 .6588 L .74645 .65488 L p .707 .577 .707 r
F P
0 g
s
.48463 .66704 m .49029 .68397 L .49719 .6699 L p .707 .577 .707 r
F P
0 g
s
.49719 .6699 m .49153 .65297 L .48463 .66704 L p .707 .577 .707 r
F P
0 g
s
.71295 .71931 m .71544 .73837 L .68643 .74183 L p .707 .577 .707 r
F P
0 g
s
.68643 .74183 m .68394 .72277 L .71295 .71931 L p .707 .577 .707 r
F P
0 g
s
.2987 .65283 m .30971 .68688 L .3211 .69509 L p .707 .577 .707 r
F P
0 g
s
.29116 .54716 m .2979 .60154 L .30033 .61132 L p .707 .577 .707 r
F P
0 g
s
.31691 .73923 m .31125 .72229 L .29934 .71422 L p .707 .577 .707 r
F P
0 g
s
.49166 .59441 m .50267 .62846 L .50062 .61682 L p .707 .577 .707 r
F P
0 g
s
.50062 .61682 m .48961 .58277 L .49166 .59441 L p .707 .577 .707 r
F P
0 g
s
.77547 .71107 m .77796 .73013 L .74698 .73434 L p .707 .577 .707 r
F P
0 g
s
.74698 .73434 m .74449 .71528 L .77547 .71107 L p .707 .577 .707 r
F P
0 g
s
.29934 .71422 m .305 .73115 L .31691 .73923 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74449 .71528 m .74698 .73434 L .71544 .73837 L p .707 .577 .707 r
F P
0 g
s
.71544 .73837 m .71295 .71931 L .74449 .71528 L p .707 .577 .707 r
F P
0 g
s
.2979 .60154 m .29116 .54716 L .29863 .53653 L p .707 .577 .707 r
F P
0 g
s
.30971 .68688 m .2987 .65283 L .29665 .64119 L p .707 .577 .707 r
F P
0 g
s
.49103 .52 m .49776 .57438 L .48567 .5664 L p .707 .577 .707 r
F P
0 g
s
.48567 .5664 m .47893 .51202 L .49103 .52 L p .707 .577 .707 r
F P
0 g
s
.49153 .65297 m .49719 .6699 L .49455 .65826 L p .707 .577 .707 r
F P
0 g
s
.49455 .65826 m .4889 .64132 L .49153 .65297 L p .707 .577 .707 r
F P
0 g
s
.29665 .64119 m .30766 .67524 L .30971 .68688 L p .707 .577 .707 r
F P
0 g
s
.305 .73115 m .29934 .71422 L .29671 .70257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29863 .53653 m .30537 .59091 L .2979 .60154 L p .707 .577 .707 r
F P
0 g
s
.48961 .58277 m .50062 .61682 L .48923 .60861 L p .707 .577 .707 r
F P
0 g
s
.48923 .60861 m .47822 .57456 L .48961 .58277 L p .707 .577 .707 r
F P
0 g
s
.29671 .70257 m .30237 .71951 L .305 .73115 L p .707 .577 .707 r
F P
0 g
s
.30537 .59091 m .29863 .53653 L .31527 .52608 L p .707 .577 .707 r
F P
0 g
s
.30766 .67524 m .29665 .64119 L .30415 .62726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47893 .51202 m .48567 .5664 L .46509 .56102 L p .707 .577 .707 r
F P
0 g
s
.46509 .56102 m .45836 .50664 L .47893 .51202 L p .707 .577 .707 r
F P
0 g
s
.4889 .64132 m .49455 .65826 L .48264 .65018 L p .707 .577 .707 r
F P
0 g
s
.48264 .65018 m .47699 .63325 L .4889 .64132 L p .707 .577 .707 r
F P
0 g
s
.30415 .62726 m .31516 .66131 L .30766 .67524 L p .707 .577 .707 r
F P
0 g
s
.30237 .71951 m .29671 .70257 L .30361 .6885 L p .707 .577 .707 r
F P
0 g
s
.31527 .52608 m .32201 .58046 L .30537 .59091 L p .707 .577 .707 r
F P
0 g
s
.47822 .57456 m .48923 .60861 L .4696 .60463 L p .707 .577 .707 r
F P
0 g
s
.4696 .60463 m .45859 .57058 L .47822 .57456 L p .707 .577 .707 r
F P
0 g
s
.30361 .6885 m .30927 .70543 L .30237 .71951 L p .707 .577 .707 r
F P
0 g
s
.32201 .58046 m .31527 .52608 L .33945 .51686 L p .707 .577 .707 r
F P
0 g
s
.31516 .66131 m .30415 .62726 L .32045 .6124 L p .707 .577 .707 r
F P
0 g
s
.45836 .50664 m .46509 .56102 L .43805 .55875 L p .707 .577 .707 r
F P
0 g
s
.43805 .55875 m .43132 .50437 L .45836 .50664 L p .707 .577 .707 r
F P
0 g
s
.47699 .63325 m .48264 .65018 L .46262 .64646 L p .707 .577 .707 r
F P
0 g
s
.46262 .64646 m .45696 .62953 L .47699 .63325 L p .707 .577 .707 r
F P
0 g
s
.33945 .51686 m .34619 .57123 L .32201 .58046 L p .707 .577 .707 r
F P
0 g
s
.32045 .6124 m .33146 .64645 L .31516 .66131 L p .707 .577 .707 r
F P
0 g
s
.34619 .57123 m .33945 .51686 L .36881 .50974 L p .707 .577 .707 r
F P
0 g
s
.30927 .70543 m .30361 .6885 L .31937 .67338 L p .707 .577 .707 r
F P
0 g
s
.45859 .57058 m .4696 .60463 L .44368 .60528 L p .707 .577 .707 r
F P
0 g
s
.44368 .60528 m .43267 .57122 L .45859 .57058 L p .707 .577 .707 r
F P
0 g
s
.43132 .50437 m .43805 .55875 L .4072 .55982 L p .707 .577 .707 r
F P
0 g
s
.4072 .55982 m .40046 .50544 L .43132 .50437 L p .707 .577 .707 r
F P
0 g
s
.31937 .67338 m .32503 .69031 L .30927 .70543 L p .707 .577 .707 r
F P
0 g
s
.33146 .64645 m .32045 .6124 L .34397 .59808 L p .707 .577 .707 r
F P
0 g
s
.37554 .56412 m .36881 .50974 L .40046 .50544 L p .707 .577 .707 r
F P
0 g
s
.36881 .50974 m .37554 .56412 L .34619 .57123 L p .707 .577 .707 r
F P
0 g
s
.40046 .50544 m .4072 .55982 L .37554 .56412 L p .707 .577 .707 r
F P
0 g
s
.45696 .62953 m .46262 .64646 L .43644 .64747 L p .707 .577 .707 r
F P
0 g
s
.43644 .64747 m .43079 .63053 L .45696 .62953 L p .707 .577 .707 r
F P
0 g
s
.43267 .57122 m .44368 .60528 L .41398 .61048 L p .707 .577 .707 r
F P
0 g
s
.41398 .61048 m .40297 .57643 L .43267 .57122 L p .707 .577 .707 r
F P
0 g
s
.34397 .59808 m .35498 .63213 L .33146 .64645 L p .707 .577 .707 r
F P
0 g
s
.32503 .69031 m .31937 .67338 L .34245 .65869 L p .707 .577 .707 r
F P
0 g
s
.35498 .63213 m .34397 .59808 L .37241 .58568 L p .707 .577 .707 r
F P
0 g
s
.40297 .57643 m .41398 .61048 L .38342 .61973 L p .707 .577 .707 r
F P
0 g
s
.38342 .61973 m .37241 .58568 L .40297 .57643 L p .707 .577 .707 r
F P
0 g
s
.34245 .65869 m .34811 .67562 L .32503 .69031 L p .707 .577 .707 r
F P
0 g
s
.37241 .58568 m .38342 .61973 L .35498 .63213 L p .707 .577 .707 r
F P
0 g
s
.43079 .63053 m .43644 .64747 L .40668 .6531 L p .707 .577 .707 r
F P
0 g
s
.40668 .6531 m .40102 .63616 L .43079 .63053 L p .707 .577 .707 r
F P
0 g
s
.34811 .67562 m .34245 .65869 L .37059 .64586 L p .707 .577 .707 r
F P
0 g
s
.40102 .63616 m .40668 .6531 L .37624 .6628 L p .707 .577 .707 r
F P
0 g
s
.37624 .6628 m .37059 .64586 L .40102 .63616 L p .707 .577 .707 r
F P
0 g
s
.37059 .64586 m .37624 .6628 L .34811 .67562 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001hOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH8001f
Ool007=oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP000080
07=oo`00Kgoo100000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF0`00L7oo001/Ool30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001^Ool006Yoo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<006aoo`00JGoo00@0
05YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF008006Yoo`00Igoo0P000eYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00J7oo001VOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001WOol006Ioo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Ioo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF4P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo200015YF00<005YFFUH01UYF00@005YFFUIJ
EPL000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol006Eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00@000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005moo`<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005]oo`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Uoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001EOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUIJEP00IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0035YF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Dgoo0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP04001JEP00000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0067oo5`00=Woo001BOol01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF2@0015YF00@0
05YF000000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000?Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol005=oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPX00003FUH005YF00=JEP@00003FUH005YF00EJEP@00005
FUH005YFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
1goo20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YF
00002P001EYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH007oo00H000=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=o
o`03001JEP0000EJEP03001JEUYF00=JEQ8000=JEPl00003FUH005YF00=JEP<000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF00IJEP03001J
EP0000L000=JEP03001JEUYF00EJEP03001JEUYF00<000=JEP04001JEP00000:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05=oo`03001JEP0000EJEP04001JEP000005FUH00`00FUIJEP06FUH400000eYF001JEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00P002UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000
FUIJEP0015YF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF0000009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YF
FUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8000QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo0010OolA0003
Ool2FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000jOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000015YF001JEP001EYF00<005YFFUH00eYF0P001EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00EJEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000dOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH000020008FUH00`00FUIJEP07
FUH00`00FUIJEP07FUH01000FUIJEUYF1@000eYF00@005YFFUH000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
039oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPP000AJEP@00004FUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Goo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF1P001UYF00<005YF00000`000eYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0
15YF0`001UYF0P000UYF0`002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YF
FUH00P00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUH00000FUH00P001eYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YF
FUH0100000=JEP00FUH015YF0P000UYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF200025YF
00<005YFFUH01UYF00<005YFFUH015YF1@0000=JEP000000;Goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH300000eYF001JEP03FUH70005FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
001JEP03FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00eYF
30002eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000015YF001JEUYF1P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUH00004000015YF001JEUYF0`000UYF00<005YFFUH02EYF00<005YF00000P00
1UYF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH0
00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00AJEP<000EJ
EP03001JEP0000@00003FUH005YF00h00003FUH005YF00AJEP03001JEP0000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF00AJEP03001JEUYF009JEP800003FUH0000000EJEP03001JEP0000L000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
0005FUH02000FUIJEUYF001JEP00FUH20005FUH01P00FUH00000FUH000UJEP03001JEUYF00AJEP03
001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD003=oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP<00004FUH005YFFUH20004FUH30004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF000035YF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4@00;Woo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH01000FUIJEP001UYF00D005YFFUIJEP00009JEP80009JEP8000MJ
EP03001JEUYF00MJEP04001JEUYFFUH60002FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0017oo:@000UYF1@0000=JEP00FUH0;Woo000]Ool2
0004FUH00`00FUIJEP03FUH6000AOol60002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJ
EP050009FUH00`00FUIJEP02FUH80006FUH400000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02000KOol90004FUH70002FUH01@00FUIJEP00FUH0;Woo
000/Ool00`00FUH00004FUH00`00FUH00003000KOol20002FUH01@00FUIJEUYF00001EYF00<005YF
FUH00P000UYF00<005YFFUH01UYF1P001eYF00<005YFFUH01UYF1@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF00@000moo`P000AJEPT000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP<000Yoo`l000Eoo`80009JEP03001J
EUYF008000EJEP<000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005
FUH40003Ool80003FUH:0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00002FUH20003FUH300000goo000000040003FUH00`00FUIJEP06FUH00`00FUIJ
EP040002Ool01000FUIJEUYF100015YF0P001eYF00<005YF00000P0025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YF000035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000EJEPL000=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000AJEP@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0009JEPT000QJEP800003FUH005YF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH01P000UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF00<005YFFUH00P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP0000000UYF0`000UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF0`001EYF00D005YFFUIJEP0000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP`0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
;7oo0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80
0004FUH00000FUH20005FUH01000FUIJEUYF0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool20003FUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
0P001eYF00<005YF00000P001eYF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00H005YFFUH0
05YF000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000/Ool20002FUH01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000MJEP80009JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF00AJEP07001JEUYFFUH005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEP8002aoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH01UYF0`001eYF00@005YF000000=JEP03001JEUYF009JEP03001JEUYF00=JEP80
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00P002aoo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH50005FUH30005
FUH00`00FUIJEP030005FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH6000dOol002eoo`<000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJ
EP04001JEUYF0005FUH40007FUH00`00FUIJEP04FUH50002FUH30008FUH00`00FUH00002FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
1`00>Woo000]Ool00`00FUH00002FUH00`00FUIJEP03FUH600000eYF001JEP07FUH00`00FUIJEP02
FUH40002FUH01000FUH000001EYF00@005YFFUH000MJEP03001JEUYF00AJEPL000]JEP8000AJEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1000@Goo000]Ool00`00FUH00002FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH300000eYF00000004FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00FUIJ
EP08FUH20005FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`00
AGoo000]Ool20003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YF00000P000UYF3`001eYF00<005YFFUH01UYF0P001eYF00<005YFFUH0
0eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP004aoo`00;Goo0P000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP80009JEP03
001JEUYF00AJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00002FUH>000LOol:000^Ool002eoo`800004FUH000000003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`0000=JEP00FUH01EYF00<005YF
FUH00P001EYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP05001JEUYFFUH00008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000040002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P005Goo1`000eYF100000=JEP000000;Woo000]Ool30003Ool20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH02P00FUIJEUYF001JEP00FUH005YF0P00
1EYF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP@000MJEP04001JEP000009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP040002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0037oo2@000eYF1`000UYF00<005YFFUH00P00;Woo000/Ool00`00FUH0
0006Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH20003FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF0P0000=JEP00FUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEPD000AJEP04001JEUYFFUH20003Ool90003FUH90003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool40008Ool40002FUH@0002FUH00`00FUIJEP02FUH01@00FUIJEP00FUH01@000UYF
00@005YFFUIJEP8000EJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0UYF0`0000=JEP0000001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo10002Goo1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@001Goo0`00
0eYF0P001EYF10001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00L000=J
EPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00
;7oo0P000UYF00<007ooOol00Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF0`001Woo00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF00MJEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP060002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEUYF1@00<7oo000/Ool20002FUH00`00Oomoo`020004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000UYF3@001UYF00<005YFFUH01UYF0`001UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
2`000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPL003Eoo`00
;7oo0P000eYF0`001EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000UYF00<0
05YFFUH00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
000/Ool20003FUH00`00FUH00005FUH50009Ool60006FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT004Aoo`00;7oo00D005YFFUIJEP00009JEP04001JEUYF
FUH2000DOol40002FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50003
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8001=Ool0
02aoo`04001JEUYF0003FUH01000FUH000006Woo10001EYF0`000UYF00<005YFFUH00UYF2@001eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000=JEP00FUH00eYF00@005YFFUIJEPP005Eoo`00;7oo00@005YF000000=J
EP80009JEP03001oogoo01]oo`8000AJEP03001JEP0000T000EJEP03001JEUYF00EJEP03001JEUYF
00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0004FUH005YFFUH700000eYF0000001IOol002eoo`80009JEP8000AJEP<001eoo`<00003FUH005YF
00AJEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH90008FUH01000FUIJEUYF
30001UYF00<005YFFUH01UYF00<005YFFUH00eYF3P00Fgoo000]Ool40006FUH00`00FUIJEP02000N
Ool20006FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YF00000UYF2@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP80
061oo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P007Woo0P0015YF1@001EYF00<005YF
FUH015YF1@002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002UYF1@000UYF00<005YF
FUH00eYF00@005YFFUH000EJEP<005eoo`00;Goo10001UYF00<005YFFUH015YF10006Goo10000UYF
00<005YFFUH00`001EYF00<005YFFUH0100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00@005YFFUH000IJEP03001JEP000080
05Yoo`00;Goo00@007ooOol000EJEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP<0009J
EP<000EJEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP04001JEUYF0005FUH00`00FUIJEP03FUH2001HOol002aoo`<0009o
o`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEQ0000=JEP03001JEUYF00=JEP03001J
EP0000=JEP8000=JEP800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00005FUH005YFFUH00005FUH00`00FUIJEP04FUH2
001GOol002aoo`03001JEP0000=oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=JEP0000000eYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH005Ioo`00
;7oo00<005YF000017oo0P0000=JEP00FUH01UYF00<005YFFUH01eYF0`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH30005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000EGoo000/Ool01000FUH000001Goo0P001eYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0000AJEP00
000000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP05001J
EUYFFUH0001EOol002aoo`05001JEP00FUH00005Ool20006FUH00`00FUIJEP06FUH50004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00@005YFFUH0
00Moo`8000=JEP03001JEUYF00MJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001FOol002eoo`05001JEUYFFUH00008Ool200000eYF001JEP08FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`04Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200001EYF000005YF00001EYF00<005YFFUH00UYF00<007ooOol0E7oo000]Ool00`00
FUIJEP02FUH00`00Oomoo`07Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001goo0`001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001EYF00@005YFFUIJEP80
05Ioo`00;Woo00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000:Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P000eYF00@005YFFUIJ
EP8005Ioo`00;goo00H005YFFUH005YF000?Ool70004FUH00`00FUIJEP02FUH6000;Ool30005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30004FUH00`00Oomoo`1EOol002moo`03001J
EP0000=JEP8001Aoo`T0015oo`800003Ool0000000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEPD000=JEP03001JEUYF
00AJEP8000AJEP03001oogoo05Eoo`00<7oo0P001EYF00<007ooOol0:Woo0`000goo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF10001UYF00D005YF000005YF008005Moo`00<Goo00<005YFFUH015YF0P00:7oo
0P0000=JEP00Ool01Goo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH00UYF0`001eYF00@005YF000000EJEP04001JEUYFFUH3001GOol0039o
o`8000AJEP04001JEP00000UOol00`00FUIJEP02000:Ool50002FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040008FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF0000F7oo000dOol01000FUIJEP0015YF0P008Goo0P000eYF00<007ooOol0
3Woo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF300015YF00<005YFFUH0
1EYF2000F7oo000eOol30006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0COol60002FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060004FUH50003Ool300000eYF001JEP07FUH3
001LOol003Moo`03001JEUYF00EJEP03001JEUYF00@0011oo`D000AJEP03001JEUYF008001aooal0
0003FUH005YF00MJEPD000Ioo`<000IJEP04001JEUYFFUH2001JOol003Qoo`8000EJEP03001JEUYF
00AJEQ0000=JEP03001JEUYF00=JEP<003Yoo`<00003FUH005YF00MJEP@00004FUH000000006Ool2
0004FUH00`00FUIJEP03FUH00`00Oomoo`1GOol003Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo03eoo`<000MJEP03001JEUYF00EJEP<0
00Eoo`800003FUH005YF00EJEP<005Moo`00?7oo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8004=oo`@0009JEP03001JEUYF00MJEP03001JEP0000<000=oo`80
00IJEP03001JEUYF008005Eoo`00?Woo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000004Uoo`@000QJEP03001JEUYF00=JEPL000=JEP03001JEUYF009JEP03001oogoo05=oo`00@Goo
10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Cgoo0`0015YF00<005YFFUH01UYF00@005YF
FUIJEP<00003FUH005YF009JEP8005Eoo`00AGoo4000F7oo0`0000=JEP00FUH01eYF00<005YFFUH0
15YF0P000eYF0P00EGoo002`Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP04001FOol00;=oo`@0
009JEP03001JEUYF00AJEP04001JEUYFFUH3001FOol00;Moo`D000=JEP03001JEUYF009JEP<005Io
o`00_7oo2`00EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59408 .74597 m .59825 .69009 L .56722 .68615 L p .707 .577 .707 r
F P
0 g
s
.59825 .69009 m .59408 .74597 L .62586 .74758 L p .707 .577 .707 r
F P
0 g
s
.62586 .74758 m .63003 .6917 L .59825 .69009 L p .707 .577 .707 r
F P
0 g
s
.63003 .6917 m .62586 .74758 L .65527 .74671 L p .707 .577 .707 r
F P
0 g
s
.65527 .74671 m .65944 .69082 L .63003 .6917 L p .707 .577 .707 r
F P
0 g
s
.56305 .74203 m .56722 .68615 L .53998 .68027 L p .707 .577 .707 r
F P
0 g
s
.56722 .68615 m .56305 .74203 L .59408 .74597 L p .707 .577 .707 r
F P
0 g
s
.65944 .69082 m .65527 .74671 L .67943 .74343 L p .707 .577 .707 r
F P
0 g
s
.67943 .74343 m .6836 .68755 L .65944 .69082 L p .707 .577 .707 r
F P
0 g
s
.53998 .68027 m .5358 .73615 L .56305 .74203 L p .707 .577 .707 r
F P
0 g
s
.58993 .80111 m .59682 .76399 L .56624 .75708 L p .707 .577 .707 r
F P
0 g
s
.59682 .76399 m .58993 .80111 L .62129 .80622 L p .707 .577 .707 r
F P
0 g
s
.62129 .80622 m .62817 .7691 L .59682 .76399 L p .707 .577 .707 r
F P
0 g
s
.5358 .73615 m .53998 .68027 L .51918 .67302 L p .707 .577 .707 r
F P
0 g
s
.62817 .7691 m .62129 .80622 L .65035 .80903 L p .707 .577 .707 r
F P
0 g
s
.65035 .80903 m .65723 .77191 L .62817 .7691 L p .707 .577 .707 r
F P
0 g
s
.55935 .7942 m .56624 .75708 L .53943 .74905 L p .707 .577 .707 r
F P
0 g
s
.56624 .75708 m .55935 .7942 L .58993 .80111 L p .707 .577 .707 r
F P
0 g
s
.53943 .74905 m .53255 .78617 L .55935 .7942 L p .707 .577 .707 r
F P
0 g
s
.51918 .67302 m .515 .7289 L .5358 .73615 L p .707 .577 .707 r
F P
0 g
s
.6836 .68755 m .67943 .74343 L .69599 .73808 L p .707 .577 .707 r
F P
0 g
s
.69599 .73808 m .70016 .68219 L .6836 .68755 L p .707 .577 .707 r
F P
0 g
s
.65723 .77191 m .65035 .80903 L .67428 .80926 L p .707 .577 .707 r
F P
0 g
s
.67428 .80926 m .68116 .77214 L .65723 .77191 L p .707 .577 .707 r
F P
0 g
s
.59447 .8426 m .598 .82405 L .56737 .81707 L p .707 .577 .707 r
F P
0 g
s
.598 .82405 m .59447 .8426 L .62577 .84779 L p .707 .577 .707 r
F P
0 g
s
.62577 .84779 m .6293 .82923 L .598 .82405 L p .707 .577 .707 r
F P
0 g
s
.56737 .81707 m .56384 .83563 L .59447 .8426 L p .707 .577 .707 r
F P
0 g
s
.6293 .82923 m .62577 .84779 L .65466 .85068 L p .707 .577 .707 r
F P
0 g
s
.65466 .85068 m .65819 .83213 L .6293 .82923 L p .707 .577 .707 r
F P
0 g
s
.53255 .78617 m .53943 .74905 L .51902 .74067 L p .707 .577 .707 r
F P
0 g
s
.56384 .83563 m .56737 .81707 L .54039 .80899 L p .707 .577 .707 r
F P
0 g
s
.515 .7289 m .51918 .67302 L .50687 .66511 L p .707 .577 .707 r
F P
0 g
s
.54039 .80899 m .53686 .82755 L .56384 .83563 L p .707 .577 .707 r
F P
0 g
s
.51902 .74067 m .51214 .7778 L .53255 .78617 L p .707 .577 .707 r
F P
0 g
s
.65819 .83213 m .65466 .85068 L .67833 .851 L p .707 .577 .707 r
F P
0 g
s
.67833 .851 m .68186 .83244 L .65819 .83213 L p .707 .577 .707 r
F P
0 g
s
.53686 .82755 m .54039 .80899 L .51972 .8006 L p .707 .577 .707 r
F P
0 g
s
.68116 .77214 m .67428 .80926 L .69073 .8069 L p .707 .577 .707 r
F P
0 g
s
.69073 .8069 m .69761 .76977 L .68116 .77214 L p .707 .577 .707 r
F P
0 g
s
.50687 .66511 m .50269 .721 L .515 .7289 L p .707 .577 .707 r
F P
0 g
s
.51972 .8006 m .51619 .81915 L .53686 .82755 L p .707 .577 .707 r
F P
0 g
s
.70016 .68219 m .69599 .73808 L .70331 .73117 L p .707 .577 .707 r
F P
0 g
s
.70331 .73117 m .70749 .67529 L .70016 .68219 L p .707 .577 .707 r
F P
0 g
s
.51214 .7778 m .51902 .74067 L .507 .73279 L p .707 .577 .707 r
F P
0 g
s
.507 .73279 m .50012 .76991 L .51214 .7778 L p .707 .577 .707 r
F P
0 g
s
.50269 .721 m .50687 .66511 L .50424 .65733 L p .707 .577 .707 r
F P
0 g
s
.68186 .83244 m .67833 .851 L .69445 .8487 L p .707 .577 .707 r
F P
0 g
s
.69445 .8487 m .69798 .83014 L .68186 .83244 L p .707 .577 .707 r
F P
0 g
s
.51619 .81915 m .51972 .8006 L .50736 .79271 L p .707 .577 .707 r
F P
0 g
s
.50736 .79271 m .50383 .81127 L .51619 .81915 L p .707 .577 .707 r
F P
0 g
s
.69761 .76977 m .69073 .8069 L .69809 .80216 L p .707 .577 .707 r
F P
0 g
s
.69809 .80216 m .70497 .76504 L .69761 .76977 L p .707 .577 .707 r
F P
0 g
s
.50424 .65733 m .50007 .71321 L .50269 .721 L p .707 .577 .707 r
F P
0 g
s
.70749 .67529 m .70331 .73117 L .70069 .72338 L p .707 .577 .707 r
F P
0 g
s
.70069 .72338 m .70487 .6675 L .70749 .67529 L p .707 .577 .707 r
F P
0 g
s
.50012 .76991 m .507 .73279 L .50455 .72615 L p .707 .577 .707 r
F P
0 g
s
.50455 .72615 m .49767 .76327 L .50012 .76991 L p .707 .577 .707 r
F P
0 g
s
.49767 .76327 m .50455 .72615 L .51191 .72142 L p .707 .577 .707 r
F P
0 g
s
.51191 .72142 m .50502 .75854 L .49767 .76327 L p .707 .577 .707 r
F P
0 g
s
.49936 .82192 m .49936 .32003 L .45482 .31809 L p .707 .577 .707 r
F P
0 g
s
.50007 .71321 m .50424 .65733 L .51157 .65042 L p .707 .577 .707 r
F P
0 g
s
.50383 .81127 m .50736 .79271 L .50455 .7861 L p .707 .577 .707 r
F P
0 g
s
.50455 .7861 m .50102 .80466 L .50383 .81127 L p .707 .577 .707 r
F P
0 g
s
.51157 .65042 m .5074 .7063 L .50007 .71321 L p .707 .577 .707 r
F P
0 g
s
.5074 .7063 m .51157 .65042 L .52813 .64507 L p .707 .577 .707 r
F P
0 g
s
.50102 .80466 m .50455 .7861 L .51154 .78142 L p .707 .577 .707 r
F P
0 g
s
.51154 .78142 m .50801 .79998 L .50102 .80466 L p .707 .577 .707 r
F P
0 g
s
.52813 .64507 m .52395 .70095 L .5074 .7063 L p .707 .577 .707 r
F P
0 g
s
.50502 .75854 m .51191 .72142 L .52835 .71905 L p .707 .577 .707 r
F P
0 g
s
.52395 .70095 m .52813 .64507 L .55229 .64179 L p .707 .577 .707 r
F P
0 g
s
.52835 .71905 m .52147 .75617 L .50502 .75854 L p .707 .577 .707 r
F P
0 g
s
.50801 .79998 m .51154 .78142 L .52766 .77913 L p .707 .577 .707 r
F P
0 g
s
.52766 .77913 m .52413 .79769 L .50801 .79998 L p .707 .577 .707 r
F P
0 g
s
.55229 .64179 m .54812 .69767 L .52395 .70095 L p .707 .577 .707 r
F P
0 g
s
.52147 .75617 m .52835 .71905 L .55228 .71929 L p .707 .577 .707 r
F P
0 g
s
.55228 .71929 m .5454 .75641 L .52147 .75617 L p .707 .577 .707 r
F P
0 g
s
.52413 .79769 m .52766 .77913 L .55132 .77944 L p .707 .577 .707 r
F P
0 g
s
.55132 .77944 m .54779 .798 L .52413 .79769 L p .707 .577 .707 r
F P
0 g
s
.49936 .32003 m .49936 .82192 L .54397 .82008 L p .707 .577 .707 r
F P
0 g
s
.54397 .82008 m .54397 .31819 L .49936 .32003 L p .707 .577 .707 r
F P
0 g
s
.69798 .83014 m .69445 .8487 L .70144 .84402 L p .707 .577 .707 r
F P
0 g
s
.70144 .84402 m .70497 .82547 L .69798 .83014 L p .707 .577 .707 r
F P
0 g
s
.54812 .69767 m .55229 .64179 L .5817 .64092 L p .707 .577 .707 r
F P
0 g
s
.5817 .64092 m .57753 .6968 L .54812 .69767 L p .707 .577 .707 r
F P
0 g
s
.5454 .75641 m .55228 .71929 L .58135 .72209 L p .707 .577 .707 r
F P
0 g
s
.58135 .72209 m .57446 .75922 L .5454 .75641 L p .707 .577 .707 r
F P
0 g
s
.57446 .75922 m .58135 .72209 L .6127 .7272 L p .707 .577 .707 r
F P
0 g
s
.54779 .798 m .55132 .77944 L .58022 .78234 L p .707 .577 .707 r
F P
0 g
s
.6127 .7272 m .60582 .76433 L .57446 .75922 L p .707 .577 .707 r
F P
0 g
s
.58022 .78234 m .57669 .80089 L .54779 .798 L p .707 .577 .707 r
F P
0 g
s
.57669 .80089 m .58022 .78234 L .61151 .78752 L p .707 .577 .707 r
F P
0 g
s
.61151 .78752 m .60798 .80608 L .57669 .80089 L p .707 .577 .707 r
F P
0 g
s
.54397 .31819 m .54397 .82008 L .58427 .81463 L p .707 .577 .707 r
F P
0 g
s
.57753 .6968 m .5817 .64092 L .61348 .64253 L p .707 .577 .707 r
F P
0 g
s
.61348 .64253 m .6093 .69841 L .57753 .6968 L p .707 .577 .707 r
F P
0 g
s
.58427 .81463 m .58427 .31274 L .54397 .31819 L p .707 .577 .707 r
F P
0 g
s
.45482 .81998 m .45482 .31809 L .4147 .31254 L p .707 .577 .707 r
F P
0 g
s
.45482 .31809 m .45482 .81998 L .49936 .82192 L p .707 .577 .707 r
F P
0 g
s
.70497 .76504 m .69809 .80216 L .69564 .79553 L p .707 .577 .707 r
F P
0 g
s
.69564 .79553 m .70252 .75841 L .70497 .76504 L p .707 .577 .707 r
F P
0 g
s
.70487 .6675 m .70069 .72338 L .68838 .71548 L p .707 .577 .707 r
F P
0 g
s
.68838 .71548 m .69255 .65959 L .70487 .6675 L p .707 .577 .707 r
F P
0 g
s
.64451 .64647 m .64033 .70235 L .6093 .69841 L p .707 .577 .707 r
F P
0 g
s
.6093 .69841 m .61348 .64253 L .64451 .64647 L p .707 .577 .707 r
F P
0 g
s
.64328 .73411 m .6364 .77123 L .60582 .76433 L p .707 .577 .707 r
F P
0 g
s
.60582 .76433 m .6127 .7272 L .64328 .73411 L p .707 .577 .707 r
F P
0 g
s
.64215 .7945 m .63862 .81306 L .60798 .80608 L p .707 .577 .707 r
F P
0 g
s
.60798 .80608 m .61151 .78752 L .64215 .7945 L p .707 .577 .707 r
F P
0 g
s
.58427 .31274 m .58427 .81463 L .61632 .80611 L p .707 .577 .707 r
F P
0 g
s
.61632 .80611 m .61632 .30422 L .58427 .31274 L p .707 .577 .707 r
F P
0 g
s
.4147 .81443 m .4147 .31254 L .38293 .30394 L p .707 .577 .707 r
F P
0 g
s
.4147 .31254 m .4147 .81443 L .45482 .81998 L p .707 .577 .707 r
F P
0 g
s
.25184 .71911 m .25362 .66483 L .22252 .66146 L p .707 .577 .707 r
F P
0 g
s
.25362 .66483 m .25184 .71911 L .28368 .71914 L p .707 .577 .707 r
F P
0 g
s
.28368 .71914 m .28546 .66487 L .25362 .66483 L p .707 .577 .707 r
F P
0 g
s
.28546 .66487 m .28368 .71914 L .31314 .71582 L p .707 .577 .707 r
F P
0 g
s
.31314 .71582 m .31493 .66154 L .28546 .66487 L p .707 .577 .707 r
F P
0 g
s
.70497 .82547 m .70144 .84402 L .69862 .83742 L p .707 .577 .707 r
F P
0 g
s
.69862 .83742 m .70215 .81886 L .70497 .82547 L p .707 .577 .707 r
F P
0 g
s
.22073 .71574 m .22252 .66146 L .1952 .65506 L p .707 .577 .707 r
F P
0 g
s
.22252 .66146 m .22073 .71574 L .25184 .71911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31493 .66154 m .31314 .71582 L .33734 .70948 L p .707 .577 .707 r
F P
0 g
s
.33734 .70948 m .33913 .6552 L .31493 .66154 L p .707 .577 .707 r
F P
0 g
s
.70252 .75841 m .69564 .79553 L .68362 .78764 L p .707 .577 .707 r
F P
0 g
s
.68362 .78764 m .6905 .75052 L .70252 .75841 L p .707 .577 .707 r
F P
0 g
s
.69255 .65959 m .68838 .71548 L .66758 .70823 L p .707 .577 .707 r
F P
0 g
s
.66758 .70823 m .67175 .65235 L .69255 .65959 L p .707 .577 .707 r
F P
0 g
s
.19341 .70934 m .1952 .65506 L .17434 .64627 L p .707 .577 .707 r
F P
0 g
s
.1952 .65506 m .19341 .70934 L .22073 .71574 L p .707 .577 .707 r
F P
0 g
s
.61632 .30422 m .61632 .80611 L .63699 .79534 L p .707 .577 .707 r
F P
0 g
s
.67009 .74215 m .6632 .77927 L .6364 .77123 L p .707 .577 .707 r
F P
0 g
s
.6364 .77123 m .64328 .73411 L .67009 .74215 L p .707 .577 .707 r
F P
0 g
s
.63699 .79534 m .63699 .29345 L .61632 .30422 L p .707 .577 .707 r
F P
0 g
s
.25024 .78806 m .2532 .75358 L .22218 .74823 L p .707 .577 .707 r
F P
0 g
s
.2532 .75358 m .25024 .78806 L .282 .78911 L p .707 .577 .707 r
F P
0 g
s
.282 .78911 m .28496 .75462 L .2532 .75358 L p .707 .577 .707 r
F P
0 g
s
.38293 .80583 m .38293 .30394 L .36262 .29313 L p .707 .577 .707 r
F P
0 g
s
.38293 .30394 m .38293 .80583 L .4147 .81443 L p .707 .577 .707 r
F P
0 g
s
.28496 .75462 m .282 .78911 L .31138 .78573 L p .707 .577 .707 r
F P
0 g
s
.31138 .78573 m .31435 .75125 L .28496 .75462 L p .707 .577 .707 r
F P
0 g
s
.21921 .78271 m .22218 .74823 L .19492 .73908 L p .707 .577 .707 r
F P
0 g
s
.22218 .74823 m .21921 .78271 L .25024 .78806 L p .707 .577 .707 r
F P
0 g
s
.70215 .81886 m .69862 .83742 L .68627 .82953 L p .707 .577 .707 r
F P
0 g
s
.68627 .82953 m .6898 .81097 L .70215 .81886 L p .707 .577 .707 r
F P
0 g
s
.33913 .6552 m .33734 .70948 L .35391 .70073 L p .707 .577 .707 r
F P
0 g
s
.35391 .70073 m .35569 .64645 L .33913 .6552 L p .707 .577 .707 r
F P
0 g
s
.17434 .64627 m .17255 .70055 L .19341 .70934 L p .707 .577 .707 r
F P
0 g
s
.31435 .75125 m .31138 .78573 L .33552 .77827 L p .707 .577 .707 r
F P
0 g
s
.33552 .77827 m .33848 .74379 L .31435 .75125 L p .707 .577 .707 r
F P
0 g
s
.25288 .83132 m .25441 .8141 L .2233 .80882 L p .707 .577 .707 r
F P
0 g
s
.25441 .8141 m .25288 .83132 L .2846 .83225 L p .707 .577 .707 r
F P
0 g
s
.2846 .83225 m .28613 .81504 L .25441 .8141 L p .707 .577 .707 r
F P
0 g
s
.17255 .70055 m .17434 .64627 L .16197 .63595 L p .707 .577 .707 r
F P
0 g
s
.67175 .65235 m .66758 .70823 L .64033 .70235 L p .707 .577 .707 r
F P
0 g
s
.64033 .70235 m .64451 .64647 L .67175 .65235 L p .707 .577 .707 r
F P
0 g
s
.6905 .75052 m .68362 .78764 L .6632 .77927 L p .707 .577 .707 r
F P
0 g
s
.6632 .77927 m .67009 .74215 L .6905 .75052 L p .707 .577 .707 r
F P
0 g
s
.19195 .77356 m .19492 .73908 L .1741 .72703 L p .707 .577 .707 r
F P
0 g
s
.19492 .73908 m .19195 .77356 L .21921 .78271 L p .707 .577 .707 r
F P
0 g
s
.28613 .81504 m .2846 .83225 L .31383 .82874 L p .707 .577 .707 r
F P
0 g
s
.31383 .82874 m .31536 .81153 L .28613 .81504 L p .707 .577 .707 r
F P
0 g
s
.22178 .82604 m .2233 .80882 L .19586 .79971 L p .707 .577 .707 r
F P
0 g
s
.2233 .80882 m .22178 .82604 L .25288 .83132 L p .707 .577 .707 r
F P
0 g
s
.19586 .79971 m .19433 .81693 L .22178 .82604 L p .707 .577 .707 r
F P
0 g
s
.31536 .81153 m .31383 .82874 L .33771 .82114 L p .707 .577 .707 r
F P
0 g
s
.33771 .82114 m .33924 .80392 L .31536 .81153 L p .707 .577 .707 r
F P
0 g
s
.35569 .64645 m .35391 .70073 L .36122 .69043 L p .707 .577 .707 r
F P
0 g
s
.36122 .69043 m .36301 .63615 L .35569 .64645 L p .707 .577 .707 r
F P
0 g
s
.33848 .74379 m .33552 .77827 L .35204 .76745 L p .707 .577 .707 r
F P
0 g
s
.35204 .76745 m .355 .73297 L .33848 .74379 L p .707 .577 .707 r
F P
0 g
s
.6898 .81097 m .68627 .82953 L .66559 .82114 L p .707 .577 .707 r
F P
0 g
s
.66559 .82114 m .66912 .80258 L .6898 .81097 L p .707 .577 .707 r
F P
0 g
s
.19433 .81693 m .19586 .79971 L .17476 .78766 L p .707 .577 .707 r
F P
0 g
s
.1741 .72703 m .17114 .76151 L .19195 .77356 L p .707 .577 .707 r
F P
0 g
s
.16197 .63595 m .16018 .69023 L .17255 .70055 L p .707 .577 .707 r
F P
0 g
s
.63699 .29345 m .63699 .79534 L .64424 .78339 L p .707 .577 .707 r
F P
0 g
s
.64424 .78339 m .64424 .2815 L .63699 .29345 L p .707 .577 .707 r
F P
0 g
s
.35932 .75433 m .36229 .71985 L .355 .73297 L p .707 .577 .707 r
F P
0 g
s
.36301 .63615 m .36122 .69043 L .35857 .67959 L p .707 .577 .707 r
F P
0 g
s
.35857 .67959 m .36035 .62531 L .36301 .63615 L p .707 .577 .707 r
F P
0 g
s
.36229 .71985 m .35932 .75433 L .35667 .7402 L p .707 .577 .707 r
F P
0 g
s
.35667 .7402 m .35963 .70572 L .36229 .71985 L p .707 .577 .707 r
F P
0 g
s
.36035 .62531 m .35857 .67959 L .3462 .66927 L p .707 .577 .707 r
F P
0 g
s
.3462 .66927 m .34799 .61499 L .36035 .62531 L p .707 .577 .707 r
F P
0 g
s
.36262 .79502 m .36262 .29313 L .35575 .28116 L p .707 .577 .707 r
F P
0 g
s
.36262 .29313 m .36262 .79502 L .38293 .80583 L p .707 .577 .707 r
F P
0 g
s
.17114 .76151 m .1741 .72703 L .16176 .71327 L p .707 .577 .707 r
F P
0 g
s
.17476 .78766 m .17323 .80487 L .19433 .81693 L p .707 .577 .707 r
F P
0 g
s
.16018 .69023 m .16197 .63595 L .15932 .62511 L p .707 .577 .707 r
F P
0 g
s
.33924 .80392 m .33771 .82114 L .35391 .81018 L p .707 .577 .707 r
F P
0 g
s
.35391 .81018 m .35543 .79297 L .33924 .80392 L p .707 .577 .707 r
F P
0 g
s
.17323 .80487 m .17476 .78766 L .16207 .77384 L p .707 .577 .707 r
F P
0 g
s
.16176 .71327 m .15879 .74775 L .17114 .76151 L p .707 .577 .707 r
F P
0 g
s
.66912 .80258 m .66559 .82114 L .63862 .81306 L p .707 .577 .707 r
F P
0 g
s
.63862 .81306 m .64215 .7945 L .66912 .80258 L p .707 .577 .707 r
F P
0 g
s
.355 .73297 m .35204 .76745 L .35932 .75433 L p .707 .577 .707 r
F P
0 g
s
.15932 .62511 m .15753 .67939 L .16018 .69023 L p .707 .577 .707 r
F P
0 g
s
.16207 .77384 m .16054 .79106 L .17323 .80487 L p .707 .577 .707 r
F P
0 g
s
.15879 .74775 m .16176 .71327 L .1591 .69914 L p .707 .577 .707 r
F P
0 g
s
.15753 .67939 m .15932 .62511 L .16663 .61481 L p .707 .577 .707 r
F P
0 g
s
.35543 .79297 m .35391 .81018 L .36082 .79694 L p .707 .577 .707 r
F P
0 g
s
.36082 .79694 m .36235 .77973 L .35543 .79297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64424 .2815 m .64424 .78339 L .63738 .77142 L p .707 .577 .707 r
F P
0 g
s
.63738 .77142 m .63738 .26953 L .64424 .2815 L p .707 .577 .707 r
F P
0 g
s
.36235 .77973 m .36082 .79694 L .35779 .78272 L p .707 .577 .707 r
F P
0 g
s
.35779 .78272 m .35932 .76551 L .36235 .77973 L p .707 .577 .707 r
F P
0 g
s
.35963 .70572 m .35667 .7402 L .34433 .72644 L p .707 .577 .707 r
F P
0 g
s
.34433 .72644 m .34729 .69196 L .35963 .70572 L p .707 .577 .707 r
F P
0 g
s
.35932 .76551 m .35779 .78272 L .3451 .76891 L p .707 .577 .707 r
F P
0 g
s
.3451 .76891 m .34663 .75169 L .35932 .76551 L p .707 .577 .707 r
F P
0 g
s
.35575 .28116 m .35575 .78305 L .36262 .79502 L p .707 .577 .707 r
F P
0 g
s
.35575 .78305 m .35575 .28116 L .36301 .26921 L p .707 .577 .707 r
F P
0 g
s
.16054 .79106 m .16207 .77384 L .15904 .75962 L p .707 .577 .707 r
F P
0 g
s
.1591 .69914 m .15614 .73362 L .15879 .74775 L p .707 .577 .707 r
F P
0 g
s
.15904 .75962 m .15751 .77684 L .16054 .79106 L p .707 .577 .707 r
F P
0 g
s
.16663 .61481 m .16484 .66909 L .15753 .67939 L p .707 .577 .707 r
F P
0 g
s
.15614 .73362 m .1591 .69914 L .16639 .68602 L p .707 .577 .707 r
F P
0 g
s
.16484 .66909 m .16663 .61481 L .1832 .60606 L p .707 .577 .707 r
F P
0 g
s
.15751 .77684 m .15904 .75962 L .16596 .74639 L p .707 .577 .707 r
F P
0 g
s
.16639 .68602 m .16342 .7205 L .15614 .73362 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16596 .74639 m .16443 .7636 L .15751 .77684 L p .707 .577 .707 r
F P
0 g
s
.34799 .61499 m .3462 .66927 L .32534 .66048 L p .707 .577 .707 r
F P
0 g
s
.32534 .66048 m .32712 .6062 L .34799 .61499 L p .707 .577 .707 r
F P
0 g
s
.16342 .7205 m .16639 .68602 L .18291 .6752 L p .707 .577 .707 r
F P
0 g
s
.1832 .60606 m .18141 .66034 L .16484 .66909 L p .707 .577 .707 r
F P
0 g
s
.63738 .26953 m .63738 .77142 L .61707 .76061 L p .707 .577 .707 r
F P
0 g
s
.61707 .76061 m .61707 .25872 L .63738 .26953 L p .707 .577 .707 r
F P
0 g
s
.36301 .7711 m .36301 .26921 L .38368 .25844 L p .707 .577 .707 r
F P
0 g
s
.36301 .26921 m .36301 .7711 L .35575 .78305 L p .707 .577 .707 r
F P
0 g
s
.18141 .66034 m .1832 .60606 L .2074 .59971 L p .707 .577 .707 r
F P
0 g
s
.16443 .7636 m .16596 .74639 L .18215 .73543 L p .707 .577 .707 r
F P
0 g
s
.18291 .6752 m .17994 .70968 L .16342 .7205 L p .707 .577 .707 r
F P
0 g
s
.32712 .6062 m .32534 .66048 L .29802 .65408 L p .707 .577 .707 r
F P
0 g
s
.29802 .65408 m .2998 .5998 L .32712 .6062 L p .707 .577 .707 r
F P
0 g
s
.34729 .69196 m .34433 .72644 L .32351 .71439 L p .707 .577 .707 r
F P
0 g
s
.32351 .71439 m .32647 .67991 L .34729 .69196 L p .707 .577 .707 r
F P
0 g
s
.18215 .73543 m .18062 .75264 L .16443 .7636 L p .707 .577 .707 r
F P
0 g
s
.17994 .70968 m .18291 .6752 L .20704 .66774 L p .707 .577 .707 r
F P
0 g
s
.2074 .59971 m .20561 .65399 L .18141 .66034 L p .707 .577 .707 r
F P
0 g
s
.20561 .65399 m .2074 .59971 L .23686 .59639 L p .707 .577 .707 r
F P
0 g
s
.2998 .5998 m .29802 .65408 L .26691 .6507 L p .707 .577 .707 r
F P
0 g
s
.26691 .6507 m .2687 .59642 L .2998 .5998 L p .707 .577 .707 r
F P
0 g
s
.34663 .75169 m .3451 .76891 L .324 .75686 L p .707 .577 .707 r
F P
0 g
s
.324 .75686 m .32553 .73964 L .34663 .75169 L p .707 .577 .707 r
F P
0 g
s
.23507 .65067 m .23686 .59639 L .2687 .59642 L p .707 .577 .707 r
F P
0 g
s
.23686 .59639 m .23507 .65067 L .20561 .65399 L p .707 .577 .707 r
F P
0 g
s
.61707 .25872 m .61707 .76061 L .5853 .75201 L p .707 .577 .707 r
F P
0 g
s
.5853 .75201 m .5853 .25012 L .61707 .25872 L p .707 .577 .707 r
F P
0 g
s
.38368 .25844 m .38368 .76033 L .36301 .7711 L p .707 .577 .707 r
F P
0 g
s
.38368 .76033 m .38368 .25844 L .41573 .24992 L p .707 .577 .707 r
F P
0 g
s
.32647 .67991 m .32351 .71439 L .29625 .70524 L p .707 .577 .707 r
F P
0 g
s
.29625 .70524 m .29922 .67076 L .32647 .67991 L p .707 .577 .707 r
F P
0 g
s
.18062 .75264 m .18215 .73543 L .20603 .72782 L p .707 .577 .707 r
F P
0 g
s
.2687 .59642 m .26691 .6507 L .23507 .65067 L p .707 .577 .707 r
F P
0 g
s
.20704 .66774 m .20408 .70222 L .17994 .70968 L p .707 .577 .707 r
F P
0 g
s
.20408 .70222 m .20704 .66774 L .23643 .66436 L p .707 .577 .707 r
F P
0 g
s
.20603 .72782 m .2045 .74504 L .18062 .75264 L p .707 .577 .707 r
F P
0 g
s
.73308 .65068 m .7313 .59415 L .7002 .59365 L p .707 .577 .707 r
F P
0 g
s
.7313 .59415 m .73308 .65068 L .76493 .64919 L p .707 .577 .707 r
F P
0 g
s
.76493 .64919 m .76314 .59266 L .7313 .59415 L p .707 .577 .707 r
F P
0 g
s
.76314 .59266 m .76493 .64919 L .79439 .64586 L p .707 .577 .707 r
F P
0 g
s
.79439 .64586 m .7926 .58932 L .76314 .59266 L p .707 .577 .707 r
F P
0 g
s
.29922 .67076 m .29625 .70524 L .26522 .69989 L p .707 .577 .707 r
F P
0 g
s
.26522 .69989 m .26819 .66541 L .29922 .67076 L p .707 .577 .707 r
F P
0 g
s
.23346 .69884 m .23643 .66436 L .26819 .66541 L p .707 .577 .707 r
F P
0 g
s
.23643 .66436 m .23346 .69884 L .20408 .70222 L p .707 .577 .707 r
F P
0 g
s
.70198 .65018 m .7002 .59365 L .67287 .59121 L p .707 .577 .707 r
F P
0 g
s
.7002 .59365 m .70198 .65018 L .73308 .65068 L p .707 .577 .707 r
F P
0 g
s
.32553 .73964 m .324 .75686 L .29656 .74774 L p .707 .577 .707 r
F P
0 g
s
.29656 .74774 m .29809 .73053 L .32553 .73964 L p .707 .577 .707 r
F P
0 g
s
.26819 .66541 m .26522 .69989 L .23346 .69884 L p .707 .577 .707 r
F P
0 g
s
.2045 .74504 m .20603 .72782 L .23526 .72431 L p .707 .577 .707 r
F P
0 g
s
.7926 .58932 m .79439 .64586 L .81859 .641 L p .707 .577 .707 r
F P
0 g
s
.81859 .641 m .8168 .58447 L .7926 .58932 L p .707 .577 .707 r
F P
0 g
s
.67287 .59121 m .67466 .64774 L .70198 .65018 L p .707 .577 .707 r
F P
0 g
s
.73477 .70121 m .73181 .66302 L .70078 .66475 L p .707 .577 .707 r
F P
0 g
s
.73181 .66302 m .73477 .70121 L .76654 .69853 L p .707 .577 .707 r
F P
0 g
s
.76654 .69853 m .76357 .66033 L .73181 .66302 L p .707 .577 .707 r
F P
0 g
s
.23526 .72431 m .23373 .74153 L .2045 .74504 L p .707 .577 .707 r
F P
0 g
s
.5853 .25012 m .5853 .75201 L .54518 .74646 L p .707 .577 .707 r
F P
0 g
s
.54518 .74646 m .54518 .24457 L .5853 .25012 L p .707 .577 .707 r
F P
0 g
s
.41573 .75181 m .41573 .24992 L .45603 .24447 L p .707 .577 .707 r
F P
0 g
s
.41573 .24992 m .41573 .75181 L .38368 .76033 L p .707 .577 .707 r
F P
0 g
s
.76357 .66033 m .76654 .69853 L .79592 .69515 L p .707 .577 .707 r
F P
0 g
s
.79592 .69515 m .79295 .65695 L .76357 .66033 L p .707 .577 .707 r
F P
0 g
s
.29809 .73053 m .29656 .74774 L .26545 .74246 L p .707 .577 .707 r
F P
0 g
s
.26545 .74246 m .26698 .72525 L .29809 .73053 L p .707 .577 .707 r
F P
0 g
s
.70078 .66475 m .70375 .70294 L .73477 .70121 L p .707 .577 .707 r
F P
0 g
s
.23373 .74153 m .23526 .72431 L .26698 .72525 L p .707 .577 .707 r
F P
0 g
s
.67466 .64774 m .67287 .59121 L .65201 .58706 L p .707 .577 .707 r
F P
0 g
s
.70375 .70294 m .70078 .66475 L .67352 .66536 L p .707 .577 .707 r
F P
0 g
s
.26698 .72525 m .26545 .74246 L .23373 .74153 L p .707 .577 .707 r
F P
0 g
s
.67352 .66536 m .67649 .70355 L .70375 .70294 L p .707 .577 .707 r
F P
0 g
s
.79295 .65695 m .79592 .69515 L .82005 .69141 L p .707 .577 .707 r
F P
0 g
s
.82005 .69141 m .81709 .65321 L .79295 .65695 L p .707 .577 .707 r
F P
0 g
s
.8168 .58447 m .81859 .641 L .83515 .6351 L p .707 .577 .707 r
F P
0 g
s
.83515 .6351 m .83337 .57857 L .8168 .58447 L p .707 .577 .707 r
F P
0 g
s
.65201 .58706 m .6538 .6436 L .67466 .64774 L p .707 .577 .707 r
F P
0 g
s
.73455 .74198 m .73302 .72288 L .70191 .72475 L p .707 .577 .707 r
F P
0 g
s
.73302 .72288 m .73455 .74198 L .76627 .7392 L p .707 .577 .707 r
F P
0 g
s
.76627 .7392 m .76474 .7201 L .73302 .72288 L p .707 .577 .707 r
F P
0 g
s
.70191 .72475 m .70344 .74385 L .73455 .74198 L p .707 .577 .707 r
F P
0 g
s
.76474 .7201 m .76627 .7392 L .7955 .73576 L p .707 .577 .707 r
F P
0 g
s
.7955 .73576 m .79397 .71666 L .76474 .7201 L p .707 .577 .707 r
F P
0 g
s
.54518 .24457 m .54518 .74646 L .50063 .74451 L p .707 .577 .707 r
F P
0 g
s
.50063 .74451 m .50063 .24262 L .54518 .24457 L p .707 .577 .707 r
F P
0 g
s
.45603 .74636 m .45603 .24447 L .50063 .24262 L p .707 .577 .707 r
F P
0 g
s
.45603 .24447 m .45603 .74636 L .41573 .75181 L p .707 .577 .707 r
F P
0 g
s
.70344 .74385 m .70191 .72475 L .67447 .72551 L p .707 .577 .707 r
F P
0 g
s
.67649 .70355 m .67352 .66536 L .65271 .66478 L p .707 .577 .707 r
F P
0 g
s
.67447 .72551 m .67599 .7446 L .70344 .74385 L p .707 .577 .707 r
F P
0 g
s
.65271 .66478 m .65567 .70297 L .67649 .70355 L p .707 .577 .707 r
F P
0 g
s
.50063 .24262 m .50063 .74451 L .45603 .74636 L p .707 .577 .707 r
F P
0 g
s
.6538 .6436 m .65201 .58706 L .63965 .58162 L p .707 .577 .707 r
F P
0 g
s
.79397 .71666 m .7955 .73576 L .81938 .73201 L p .707 .577 .707 r
F P
0 g
s
.81938 .73201 m .81785 .71291 L .79397 .71666 L p .707 .577 .707 r
F P
0 g
s
.81709 .65321 m .82005 .69141 L .83657 .68768 L p .707 .577 .707 r
F P
0 g
s
.83657 .68768 m .83361 .64948 L .81709 .65321 L p .707 .577 .707 r
F P
0 g
s
.63965 .58162 m .64143 .63815 L .6538 .6436 L p .707 .577 .707 r
F P
0 g
s
.67599 .7446 m .67447 .72551 L .65337 .72509 L p .707 .577 .707 r
F P
0 g
s
.65337 .72509 m .65489 .74418 L .67599 .7446 L p .707 .577 .707 r
F P
0 g
s
.83337 .57857 m .83515 .6351 L .84247 .62874 L p .707 .577 .707 r
F P
0 g
s
.84247 .62874 m .84068 .5722 L .83337 .57857 L p .707 .577 .707 r
F P
0 g
s
.65567 .70297 m .65271 .66478 L .64037 .66308 L p .707 .577 .707 r
F P
0 g
s
.64037 .66308 m .64333 .70127 L .65567 .70297 L p .707 .577 .707 r
F P
0 g
s
.81785 .71291 m .81938 .73201 L .83557 .72832 L p .707 .577 .707 r
F P
0 g
s
.83557 .72832 m .83404 .70922 L .81785 .71291 L p .707 .577 .707 r
F P
0 g
s
.64143 .63815 m .63965 .58162 L .63699 .57541 L p .707 .577 .707 r
F P
0 g
s
.83361 .64948 m .83657 .68768 L .84386 .68431 L p .707 .577 .707 r
F P
0 g
s
.84386 .68431 m .8409 .64612 L .83361 .64948 L p .707 .577 .707 r
F P
0 g
s
.65489 .74418 m .65337 .72509 L .64068 .72353 L p .707 .577 .707 r
F P
0 g
s
.64068 .72353 m .64221 .74263 L .65489 .74418 L p .707 .577 .707 r
F P
0 g
s
.63699 .57541 m .63878 .63195 L .64143 .63815 L p .707 .577 .707 r
F P
0 g
s
.84068 .5722 m .84247 .62874 L .83981 .62253 L p .707 .577 .707 r
F P
0 g
s
.83981 .62253 m .83803 .566 L .84068 .5722 L p .707 .577 .707 r
F P
0 g
s
.64333 .70127 m .64037 .66308 L .63771 .66041 L p .707 .577 .707 r
F P
0 g
s
.83404 .70922 m .83557 .72832 L .84249 .72504 L p .707 .577 .707 r
F P
0 g
s
.84249 .72504 m .84096 .70594 L .83404 .70922 L p .707 .577 .707 r
F P
0 g
s
.63771 .66041 m .64067 .69861 L .64333 .70127 L p .707 .577 .707 r
F P
0 g
s
.63878 .63195 m .63699 .57541 L .6443 .56905 L p .707 .577 .707 r
F P
0 g
s
.8409 .64612 m .84386 .68431 L .8412 .68165 L p .707 .577 .707 r
F P
0 g
s
.8412 .68165 m .83824 .64345 L .8409 .64612 L p .707 .577 .707 r
F P
0 g
s
.64221 .74263 m .64068 .72353 L .63765 .72098 L p .707 .577 .707 r
F P
0 g
s
.63765 .72098 m .63917 .74008 L .64221 .74263 L p .707 .577 .707 r
F P
0 g
s
.6443 .56905 m .64609 .62558 L .63878 .63195 L p .707 .577 .707 r
F P
0 g
s
.83803 .566 m .83981 .62253 L .82745 .61709 L p .707 .577 .707 r
F P
0 g
s
.82745 .61709 m .82566 .56055 L .83803 .566 L p .707 .577 .707 r
F P
0 g
s
.64067 .69861 m .63771 .66041 L .645 .65705 L p .707 .577 .707 r
F P
0 g
s
.84096 .70594 m .84249 .72504 L .83945 .72249 L p .707 .577 .707 r
F P
0 g
s
.83945 .72249 m .83793 .7034 L .84096 .70594 L p .707 .577 .707 r
F P
0 g
s
.39069 .62393 m .38652 .56899 L .35549 .56895 L p .707 .577 .707 r
F P
0 g
s
.38652 .56899 m .39069 .62393 L .42247 .62095 L p .707 .577 .707 r
F P
0 g
s
.42247 .62095 m .4183 .56601 L .38652 .56899 L p .707 .577 .707 r
F P
0 g
s
.645 .65705 m .64796 .69524 L .64067 .69861 L p .707 .577 .707 r
F P
0 g
s
.4183 .56601 m .42247 .62095 L .45188 .61523 L p .707 .577 .707 r
F P
0 g
s
.45188 .61523 m .44771 .5603 L .4183 .56601 L p .707 .577 .707 r
F P
0 g
s
.64609 .62558 m .6443 .56905 L .66087 .56315 L p .707 .577 .707 r
F P
0 g
s
.35966 .62389 m .35549 .56895 L .32824 .5659 L p .707 .577 .707 r
F P
0 g
s
.35549 .56895 m .35966 .62389 L .39069 .62393 L p .707 .577 .707 r
F P
0 g
s
.44771 .5603 m .45188 .61523 L .47605 .60735 L p .707 .577 .707 r
F P
0 g
s
.47605 .60735 m .47187 .55241 L .44771 .5603 L p .707 .577 .707 r
F P
0 g
s
.83824 .64345 m .8412 .68165 L .82886 .67994 L p .707 .577 .707 r
F P
0 g
s
.82886 .67994 m .8259 .64175 L .83824 .64345 L p .707 .577 .707 r
F P
0 g
s
.63917 .74008 m .63765 .72098 L .64456 .7177 L p .707 .577 .707 r
F P
0 g
s
.64456 .7177 m .64609 .7368 L .63917 .74008 L p .707 .577 .707 r
F P
0 g
s
.66087 .56315 m .66266 .61968 L .64609 .62558 L p .707 .577 .707 r
F P
0 g
s
.82566 .56055 m .82745 .61709 L .80659 .61294 L p .707 .577 .707 r
F P
0 g
s
.80659 .61294 m .8048 .55641 L .82566 .56055 L p .707 .577 .707 r
F P
0 g
s
.33242 .62083 m .32824 .5659 L .30744 .56012 L p .707 .577 .707 r
F P
0 g
s
.32824 .5659 m .33242 .62083 L .35966 .62389 L p .707 .577 .707 r
F P
0 g
s
.39418 .68878 m .3873 .6532 L .35672 .65588 L p .707 .577 .707 r
F P
0 g
s
.3873 .6532 m .39418 .68878 L .42553 .68257 L p .707 .577 .707 r
F P
0 g
s
.42553 .68257 m .41865 .64699 L .3873 .6532 L p .707 .577 .707 r
F P
0 g
s
.41865 .64699 m .42553 .68257 L .4546 .67344 L p .707 .577 .707 r
F P
0 g
s
.4546 .67344 m .44772 .63786 L .41865 .64699 L p .707 .577 .707 r
F P
0 g
s
.64796 .69524 m .645 .65705 L .66152 .65331 L p .707 .577 .707 r
F P
0 g
s
.83793 .7034 m .83945 .72249 L .82677 .72094 L p .707 .577 .707 r
F P
0 g
s
.82677 .72094 m .82524 .70184 L .83793 .7034 L p .707 .577 .707 r
F P
0 g
s
.47187 .55241 m .47605 .60735 L .4926 .59807 L p .707 .577 .707 r
F P
0 g
s
.4926 .59807 m .48843 .54313 L .47187 .55241 L p .707 .577 .707 r
F P
0 g
s
.66152 .65331 m .66448 .69151 L .64796 .69524 L p .707 .577 .707 r
F P
0 g
s
.3636 .69146 m .35672 .65588 L .32991 .65477 L p .707 .577 .707 r
F P
0 g
s
.35672 .65588 m .3636 .69146 L .39418 .68878 L p .707 .577 .707 r
F P
0 g
s
.66266 .61968 m .66087 .56315 L .68507 .55829 L p .707 .577 .707 r
F P
0 g
s
.44772 .63786 m .4546 .67344 L .47853 .66228 L p .707 .577 .707 r
F P
0 g
s
.47853 .66228 m .47164 .6267 L .44772 .63786 L p .707 .577 .707 r
F P
0 g
s
.39201 .73133 m .38848 .71357 L .35785 .7165 L p .707 .577 .707 r
F P
0 g
s
.38848 .71357 m .39201 .73133 L .42331 .72486 L p .707 .577 .707 r
F P
0 g
s
.42331 .72486 m .41978 .7071 L .38848 .71357 L p .707 .577 .707 r
F P
0 g
s
.30744 .56012 m .31162 .61506 L .33242 .62083 L p .707 .577 .707 r
F P
0 g
s
.41978 .7071 m .42331 .72486 L .45221 .71547 L p .707 .577 .707 r
F P
0 g
s
.45221 .71547 m .44868 .69772 L .41978 .7071 L p .707 .577 .707 r
F P
0 g
s
.8259 .64175 m .82886 .67994 L .80805 .67937 L p .707 .577 .707 r
F P
0 g
s
.80805 .67937 m .80508 .64117 L .8259 .64175 L p .707 .577 .707 r
F P
0 g
s
.64609 .7368 m .64456 .7177 L .66076 .71401 L p .707 .577 .707 r
F P
0 g
s
.8048 .55641 m .80659 .61294 L .77926 .6105 L p .707 .577 .707 r
F P
0 g
s
.77926 .6105 m .77748 .55397 L .8048 .55641 L p .707 .577 .707 r
F P
0 g
s
.68507 .55829 m .68686 .61483 L .66266 .61968 L p .707 .577 .707 r
F P
0 g
s
.32991 .65477 m .33679 .69035 L .3636 .69146 L p .707 .577 .707 r
F P
0 g
s
.66076 .71401 m .66228 .73311 L .64609 .7368 L p .707 .577 .707 r
F P
0 g
s
.35785 .7165 m .36138 .73426 L .39201 .73133 L p .707 .577 .707 r
F P
0 g
s
.31162 .61506 m .30744 .56012 L .29513 .5522 L p .707 .577 .707 r
F P
0 g
s
.36138 .73426 m .35785 .7165 L .33087 .7156 L p .707 .577 .707 r
F P
0 g
s
.33679 .69035 m .32991 .65477 L .3095 .64998 L p .707 .577 .707 r
F P
0 g
s
.44868 .69772 m .45221 .71547 L .47587 .70409 L p .707 .577 .707 r
F P
0 g
s
.47587 .70409 m .47234 .68634 L .44868 .69772 L p .707 .577 .707 r
F P
0 g
s
.47164 .6267 m .47853 .66228 L .49497 .65019 L p .707 .577 .707 r
F P
0 g
s
.49497 .65019 m .48809 .61461 L .47164 .6267 L p .707 .577 .707 r
F P
0 g
s
.68686 .61483 m .68507 .55829 L .71453 .55496 L p .707 .577 .707 r
F P
0 g
s
.33087 .7156 m .3344 .73335 L .36138 .73426 L p .707 .577 .707 r
F P
0 g
s
.66448 .69151 m .66152 .65331 L .68565 .64958 L p .707 .577 .707 r
F P
0 g
s
.48843 .54313 m .4926 .59807 L .49993 .5883 L p .707 .577 .707 r
F P
0 g
s
.49993 .5883 m .49575 .53336 L .48843 .54313 L p .707 .577 .707 r
F P
0 g
s
.68565 .64958 m .68861 .68777 L .66448 .69151 L p .707 .577 .707 r
F P
0 g
s
.82524 .70184 m .82677 .72094 L .80567 .72052 L p .707 .577 .707 r
F P
0 g
s
.80567 .72052 m .80414 .70142 L .82524 .70184 L p .707 .577 .707 r
F P
0 g
s
.77748 .55397 m .77926 .6105 L .74816 .61 L p .707 .577 .707 r
F P
0 g
s
.74816 .61 m .74638 .55347 L .77748 .55397 L p .707 .577 .707 r
F P
0 g
s
.3095 .64998 m .31638 .68556 L .33679 .69035 L p .707 .577 .707 r
F P
0 g
s
.29513 .5522 m .29931 .60713 L .31162 .61506 L p .707 .577 .707 r
F P
0 g
s
.71453 .55496 m .71632 .61149 L .68686 .61483 L p .707 .577 .707 r
F P
0 g
s
.71632 .61149 m .71453 .55496 L .74638 .55347 L p .707 .577 .707 r
F P
0 g
s
.3344 .73335 m .33087 .7156 L .3102 .71095 L p .707 .577 .707 r
F P
0 g
s
.80508 .64117 m .80805 .67937 L .78079 .67998 L p .707 .577 .707 r
F P
0 g
s
.78079 .67998 m .77782 .64178 L .80508 .64117 L p .707 .577 .707 r
F P
0 g
s
.74638 .55347 m .74816 .61 L .71632 .61149 L p .707 .577 .707 r
F P
0 g
s
.47234 .68634 m .47587 .70409 L .49199 .69184 L p .707 .577 .707 r
F P
0 g
s
.49199 .69184 m .48846 .67408 L .47234 .68634 L p .707 .577 .707 r
F P
0 g
s
.66228 .73311 m .66076 .71401 L .68464 .71026 L p .707 .577 .707 r
F P
0 g
s
.3102 .71095 m .31373 .7287 L .3344 .73335 L p .707 .577 .707 r
F P
0 g
s
.68464 .71026 m .68616 .72936 L .66228 .73311 L p .707 .577 .707 r
F P
0 g
s
.31638 .68556 m .3095 .64998 L .29748 .64197 L p .707 .577 .707 r
F P
0 g
s
.29931 .60713 m .29513 .5522 L .29251 .54289 L p .707 .577 .707 r
F P
0 g
s
.68861 .68777 m .68565 .64958 L .71503 .6462 L p .707 .577 .707 r
F P
0 g
s
.48809 .61461 m .49497 .65019 L .50233 .63835 L p .707 .577 .707 r
F P
0 g
s
.50233 .63835 m .49545 .60276 L .48809 .61461 L p .707 .577 .707 r
F P
0 g
s
.71503 .6462 m .718 .68439 L .68861 .68777 L p .707 .577 .707 r
F P
0 g
s
.77782 .64178 m .78079 .67998 L .74976 .68171 L p .707 .577 .707 r
F P
0 g
s
.74976 .68171 m .7468 .64351 L .77782 .64178 L p .707 .577 .707 r
F P
0 g
s
.80414 .70142 m .80567 .72052 L .77822 .72127 L p .707 .577 .707 r
F P
0 g
s
.77822 .72127 m .77669 .70218 L .80414 .70142 L p .707 .577 .707 r
F P
0 g
s
.49575 .53336 m .49993 .5883 L .49731 .579 L p .707 .577 .707 r
F P
0 g
s
.49731 .579 m .49313 .52406 L .49575 .53336 L p .707 .577 .707 r
F P
0 g
s
.29748 .64197 m .30436 .67755 L .31638 .68556 L p .707 .577 .707 r
F P
0 g
s
.718 .68439 m .71503 .6462 L .7468 .64351 L p .707 .577 .707 r
F P
0 g
s
.31373 .7287 m .3102 .71095 L .29785 .70301 L p .707 .577 .707 r
F P
0 g
s
.7468 .64351 m .74976 .68171 L .718 .68439 L p .707 .577 .707 r
F P
0 g
s
.68616 .72936 m .68464 .71026 L .71387 .70682 L p .707 .577 .707 r
F P
0 g
s
.29251 .54289 m .29668 .59783 L .29931 .60713 L p .707 .577 .707 r
F P
0 g
s
.48846 .67408 m .49199 .69184 L .49898 .6799 L p .707 .577 .707 r
F P
0 g
s
.49898 .6799 m .49545 .66214 L .48846 .67408 L p .707 .577 .707 r
F P
0 g
s
.71387 .70682 m .7154 .72592 L .68616 .72936 L p .707 .577 .707 r
F P
0 g
s
.29785 .70301 m .30138 .72077 L .31373 .7287 L p .707 .577 .707 r
F P
0 g
s
.77669 .70218 m .77822 .72127 L .74712 .72314 L p .707 .577 .707 r
F P
0 g
s
.74712 .72314 m .74559 .70404 L .77669 .70218 L p .707 .577 .707 r
F P
0 g
s
.30436 .67755 m .29748 .64197 L .29503 .63153 L p .708 .578 .707 r
F P
0 g
s
.7154 .72592 m .71387 .70682 L .74559 .70404 L p .707 .577 .707 r
F P
0 g
s
.49545 .60276 m .50233 .63835 L .49988 .62791 L p .708 .578 .707 r
F P
0 g
s
.49988 .62791 m .493 .59233 L .49545 .60276 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29668 .59783 m .29251 .54289 L .29984 .53312 L p .707 .577 .707 r
F P
0 g
s
.74559 .70404 m .74712 .72314 L .7154 .72592 L p .707 .577 .707 r
F P
0 g
s
.29503 .63153 m .30191 .66711 L .30436 .67755 L p .708 .578 .707 r
F P
0 g
s
.49313 .52406 m .49731 .579 L .48499 .57107 L p .707 .577 .707 r
F P
0 g
s
.48499 .57107 m .48082 .51613 L .49313 .52406 L p .707 .577 .707 r
F P
0 g
s
.30138 .72077 m .29785 .70301 L .29503 .69256 L p .707 .578 .707 r
F P
0 g
s
.49545 .66214 m .49898 .6799 L .49616 .66945 L p .707 .578 .707 r
F P
0 g
s
.49616 .66945 m .49263 .65169 L .49545 .66214 L p .707 .578 .707 r
F P
0 g
s
.29984 .53312 m .30401 .58806 L .29668 .59783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29503 .69256 m .29856 .71032 L .30138 .72077 L p .707 .578 .707 r
F P
0 g
s
.30191 .66711 m .29503 .63153 L .30239 .61969 L p .707 .577 .707 r
F P
0 g
s
.493 .59233 m .49988 .62791 L .48786 .6199 L p .707 .577 .707 r
F P
0 g
s
.48786 .6199 m .48098 .58432 L .493 .59233 L p .707 .577 .707 r
F P
0 g
s
.30401 .58806 m .29984 .53312 L .31639 .52384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30239 .61969 m .30927 .65527 L .30191 .66711 L p .707 .577 .707 r
F P
0 g
s
.48082 .51613 m .48499 .57107 L .46419 .56529 L p .707 .577 .707 r
F P
0 g
s
.46419 .56529 m .46002 .51036 L .48082 .51613 L p .707 .577 .707 r
F P
0 g
s
.29856 .71032 m .29503 .69256 L .30202 .68063 L p .707 .577 .707 r
F P
0 g
s
.31639 .52384 m .32057 .57878 L .30401 .58806 L p .707 .577 .707 r
F P
0 g
s
.49263 .65169 m .49616 .66945 L .48381 .66151 L p .707 .577 .707 r
F P
0 g
s
.48381 .66151 m .48028 .64376 L .49263 .65169 L p .707 .577 .707 r
F P
0 g
s
.30202 .68063 m .30555 .69838 L .29856 .71032 L p .707 .577 .707 r
F P
0 g
s
.32057 .57878 m .31639 .52384 L .34056 .51596 L p .707 .577 .707 r
F P
0 g
s
.30927 .65527 m .30239 .61969 L .31884 .6076 L p .707 .577 .707 r
F P
0 g
s
.48098 .58432 m .48786 .6199 L .46745 .61511 L p .707 .577 .707 r
F P
0 g
s
.46745 .61511 m .46057 .57953 L .48098 .58432 L p .707 .577 .707 r
F P
0 g
s
.46002 .51036 m .46419 .56529 L .43695 .56224 L p .707 .577 .707 r
F P
0 g
s
.43695 .56224 m .43277 .5073 L .46002 .51036 L p .707 .577 .707 r
F P
0 g
s
.31884 .6076 m .32572 .64318 L .30927 .65527 L p .707 .577 .707 r
F P
0 g
s
.30555 .69838 m .30202 .68063 L .31814 .66837 L p .707 .577 .707 r
F P
0 g
s
.34056 .51596 m .34473 .57089 L .32057 .57878 L p .707 .577 .707 r
F P
0 g
s
.34473 .57089 m .34056 .51596 L .36997 .51025 L p .707 .577 .707 r
F P
0 g
s
.48028 .64376 m .48381 .66151 L .46314 .65686 L p .707 .577 .707 r
F P
0 g
s
.46314 .65686 m .45961 .63911 L .48028 .64376 L p .707 .577 .707 r
F P
0 g
s
.31814 .66837 m .32167 .68612 L .30555 .69838 L p .707 .577 .707 r
F P
0 g
s
.43277 .5073 m .43695 .56224 L .40592 .5622 L p .707 .577 .707 r
F P
0 g
s
.40592 .5622 m .40174 .50726 L .43277 .5073 L p .707 .577 .707 r
F P
0 g
s
.32572 .64318 m .31884 .6076 L .34276 .59644 L p .707 .577 .707 r
F P
0 g
s
.46057 .57953 m .46745 .61511 L .44064 .614 L p .707 .577 .707 r
F P
0 g
s
.44064 .614 m .43376 .57842 L .46057 .57953 L p .707 .577 .707 r
F P
0 g
s
.37414 .56518 m .36997 .51025 L .40174 .50726 L p .707 .577 .707 r
F P
0 g
s
.36997 .51025 m .37414 .56518 L .34473 .57089 L p .707 .577 .707 r
F P
0 g
s
.40174 .50726 m .40592 .5622 L .37414 .56518 L p .707 .577 .707 r
F P
0 g
s
.34276 .59644 m .34964 .63202 L .32572 .64318 L p .707 .577 .707 r
F P
0 g
s
.32167 .68612 m .31814 .66837 L .3418 .65699 L p .707 .577 .707 r
F P
0 g
s
.34964 .63202 m .34276 .59644 L .37183 .58731 L p .707 .577 .707 r
F P
0 g
s
.45961 .63911 m .46314 .65686 L .43616 .65596 L p .707 .577 .707 r
F P
0 g
s
.43616 .65596 m .43263 .6382 L .45961 .63911 L p .707 .577 .707 r
F P
0 g
s
.43376 .57842 m .44064 .614 L .41006 .61668 L p .707 .577 .707 r
F P
0 g
s
.41006 .61668 m .40318 .5811 L .43376 .57842 L p .707 .577 .707 r
F P
0 g
s
.3418 .65699 m .34533 .67474 L .32167 .68612 L p .707 .577 .707 r
F P
0 g
s
.37871 .62289 m .37183 .58731 L .40318 .5811 L p .707 .577 .707 r
F P
0 g
s
.37183 .58731 m .37871 .62289 L .34964 .63202 L p .707 .577 .707 r
F P
0 g
s
.40318 .5811 m .41006 .61668 L .37871 .62289 L p .707 .577 .707 r
F P
0 g
s
.34533 .67474 m .3418 .65699 L .3707 .6476 L p .707 .577 .707 r
F P
0 g
s
.43263 .6382 m .43616 .65596 L .40552 .65889 L p .707 .577 .707 r
F P
0 g
s
.40552 .65889 m .40199 .64113 L .43263 .6382 L p .707 .577 .707 r
F P
0 g
s
.3707 .6476 m .37423 .66536 L .34533 .67474 L p .707 .577 .707 r
F P
0 g
s
.37423 .66536 m .3707 .6476 L .40199 .64113 L p .707 .577 .707 r
F P
0 g
s
.40199 .64113 m .40552 .65889 L .37423 .66536 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00L7oo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF4P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol90004FUH00`00FUIJEP06FUH01000FUIJEUYF1P002EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001OOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040005
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool005]oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00F7oo0P001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJ
EP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
05Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ao
o`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEUYF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0000?OolI000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00009Ool60004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@00<Goo
001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH015YF4`0015YF1P0015YF00@005YF
FUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00l0
00=JEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF009JEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP02FUH400000eYF001JEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF
000015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP800003FUH0000000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03
001JEP0000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEPh0009JEP03001JEUYF009JEP@0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP04001JEP00000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUIJEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00E7oo00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<00004FUH005YF000;FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001J
EP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000oOolB0003Ool20002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03
FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool003Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Goo000cOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUIJEP00FUH00P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00<Goo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF0000
05YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP02
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJ
EP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000]Ool002io
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL0009JEP@0009JEP03001JEUYF009J
EP<00004FUH005YFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40002FUH2000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@0009JEPL000IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPX0009JEP03001JEUYF00QJEP03001JEUYF00=J
EP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP03001JEP00008000AJEP03001JEUYF00QJEP04001JEUYFFUH20004FUH01000
FUH000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF1000
00=JEP00FUH015YF1P000eYF00<005YFFUH025YF00H005YF000005YF0004FUH01000FUIJEP002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00@005YFFUIJEP<0009JEP03001JEP0000EJEPH0
00=JEP03001JEUYF00QJEP8000=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP001EYF00@005YF0000009JEP06001JEUYF001JEP001EYF1P000eYF3P000eYF00D0
05YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP8000AJEP06001JEUYF001J
EP001EYF00<005YF00001`000eYF00<005YFFUH01EYF00<005YF00000`0015YF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF5P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH20005FUH01P00FUIJEP00FUH000AJ
EP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00EJEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP04FUH01@00FUIJEP00FUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`0000AJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEP00FUH>0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJ
EP060005FUH00`00FUH0000300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUH00003000>Ool50004Ool50002FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH=0004FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001J
EP0000AJEP80009JEP03001JEP0000<000Yoo`D000Uoo`04FUH005YF0004FUH00`00FUH000020008
FUH00`00FUIJEP04FUH70008FUH00`00FUIJEP02FUH300001eYF001JEUYF001JEP0000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP00009JEP8000AJEP03001JEUYF00=JEPl000Uoo`04FUH005YF0004FUH2
0002FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005FUH00`00FUIJEP050004FUH0
0`00FUIJEP02FUH>0002FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF0P0000=JEP0000002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00;7oo00<005YF00000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000AJEP00FUH000MJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP000006FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000001eYF0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002eoo`00;7oo0P000eYF00<005YFFUH00P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0000=JEP00FUH01UYF0P000UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP<000IJEP03001JEP00008000AJEP03001JEUYF00AJEP03
001JEP00009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQl002eoo`00;7oo0P000UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0`0000=JEP00FUH01UYF00<005YFFUH015YF1@000UYF1@001eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH300000eYF001JEP06FUH00`00FUIJEP02FUH9
00000eYF001JEP09FUH01000FUIJEUYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPT000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<002ioo`00;Goo0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP800003
FUH005YF00h00003FUH0000000@000=JEP03001JEUYF00QJEP06001JEP00001JEP0015YF00@005YF
FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH60007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000^Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUH000020004FUH00`00FUIJEP08
FUH20003FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPP003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
0UYF200015YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP06001JEP00001JEP00
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@00?goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH60008FUH90004FUH20005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH005YF00IJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEQ0000=ooa@0035oo`00;Goo0P00
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF1P001EYF00<005YFFUH015YF
00H005YFFUH005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
00000eYF000000060002FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000]
Ool002eoo`8000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P00
0eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH60007FUH01000FUIJ
EUYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF00000eYF10000UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF0P001Goo10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80009JEP@000EJEP07001JEUYFFUH005YF00000UYF2@0015YF
00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP00008000]oo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH?0004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
1000FUH000004goo4`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH2000]Ool002ao
o`<00003FUH007oo00eoo`P000moo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0005FUH9000]Ool002aoo`<0009JEP03001oogoo00Eoo`H000=JEP03001JEUYF009J
EPT000Moo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF0`000goo0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000goo0`000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;7oo0P000eYF00<005YFFUH00`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000Aoo`l0009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00009JEPH000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH5000bOol002aoo`8000=JEP04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0027oo0`0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2000=goo000/Ool20003FUH30006FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004Ool200001EYF000005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
0UYF4P00?goo000]Ool00`00FUIJEP0200000eYF001JEP04FUH60008Ool90004FUH00`00FUIJEP05
FUH50003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP04FUH<
0006FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUHG001AOol002eoo`03001JEP00
00=JEP04001JEUYFFUH20004FUH4000?Ool60006FUH00`00FUIJEP020003FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH<0005FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUH00002001JOol002ioo`8000=JEP03001JEP00
008000MJEP03001JEP0000<0015oo`8000AJEP03001JEUYF009JEP800005FUH00000FUH00005FUH0
0`00FUIJEP05FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80007FUH0
0`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2001HOol002ioo`8000=JEP80009JEP03
001JEUYF00EJEP03001JEUYF00=JEQ40009JEP<00003FUH005YF00AJEP@00003FUH005YF00AJEP03
001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP<005Ioo`00;Goo0P000UYF
0P000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
000000EJEP06001JEP00001JEP001EYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YF
00001EYF00<005YFFUH015YF00@005YFFUH005Eoo`00;Goo10001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP00
1EYF0P001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF0P001EYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;Goo
0P000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF0P0000MJEP00FUIJEP00FUH00003FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30003FUH00`00FUH00005FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20005Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000000UYF00@005YF
001JEP800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0005FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH005Aoo`00;7oo0`001Woo0`001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00H005YFFUH005YF001DOol002aoo`03001JEP00
00Uoo`8000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003Ool0
05YF00<000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03001JEUYF00AJEP03001JEUYF
008005Eoo`00;7oo00@005YF000000Yoo`<00003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000Aoo`@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@000AJEP04
001JEUYFFUH2001EOol002aoo`80009JEP03001oogoo00Yoo`@000IJEPD000AJEP03001JEUYF00EJ
EP03001JEP0000<000Moo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00004FUH300000eYF001JEP02FUH2001EOol002eoo`05001JEUYFFUH0000?Ool40002FUH40005
FUH00`00FUIJEP02FUH5000;Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP04FUH30003FUH2001EOol002eoo`04001JEUYFFUH3000AOol@000@Ool30004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH02000FUIJEP00FUH005YF001E
Ool002ioo`04001JEUYF0002FUH00`00Oomoo`0^Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH300000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00Ool0E7oo000_Ool00`00FUH00003FUH2
000/Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000006FUH00`00FUIJEP02
FUH2001FOol0031oo`8000EJEP8002Qoo`80009JEP03001oogoo0080009JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP02FUH30003FUH01000FUIJEUYF0`00EWoo000aOol00`00FUIJEP03
FUH00`00FUH00003000ROol20003FUH20004Ool30008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01EYF
0`0015YF00<005YF0000EWoo000bOol20003FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02
FUH00`00Oomoo`05Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP06FUH00`00FUH00005001GOol003Aoo`04
001JEUYF0007FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF00002Woo10000UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH010000Woo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00F7oo000eOol30007FUH00`00FUIJEP04FUH@0003
FUH00`00FUIJEP04FUH01000FUIJEP003goo1@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2P001Goo10001UYF00<005YFFUH015YF0`00EWoo000gOol20006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000EOol60003FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@002Goo10000UYF00<005YFFUH015YF00@005YF
FUH005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P007Goo80000eYF00<005YF00000`000Woo1@003Goo100015YF00D005YFFUIJEP0005Eo
o`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH00eYF1`004Goo0`0000=JEP00FUH00UYF0P00E7oo0011Ool40002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH6000lOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000;
Ool20002FUH00`00FUH0001DOol004Eooa0004Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPh00004FUH005YF001DOol009ioo`@000IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH3001EOol00:9oo`@0009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00YWoo1@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000EGoo002[Ool40002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2001FOol00:mooaL005Moo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59813 .75278 m .59394 .69786 L .5628 .69798 L p .707 .577 .707 r
F P
0 g
s
.59394 .69786 m .59813 .75278 L .62986 .74963 L p .707 .577 .707 r
F P
0 g
s
.62986 .74963 m .62567 .69471 L .59394 .69786 L p .707 .577 .707 r
F P
0 g
s
.62567 .69471 m .62986 .74963 L .65907 .74378 L p .707 .577 .707 r
F P
0 g
s
.65907 .74378 m .65488 .68886 L .62567 .69471 L p .707 .577 .707 r
F P
0 g
s
.56699 .7529 m .5628 .69798 L .53529 .69507 L p .707 .577 .707 r
F P
0 g
s
.5628 .69798 m .56699 .7529 L .59813 .75278 L p .707 .577 .707 r
F P
0 g
s
.65488 .68886 m .65907 .74378 L .6829 .73578 L p .707 .577 .707 r
F P
0 g
s
.6829 .73578 m .67871 .68086 L .65488 .68886 L p .707 .577 .707 r
F P
0 g
s
.53948 .74999 m .53529 .69507 L .51411 .68941 L p .707 .577 .707 r
F P
0 g
s
.53529 .69507 m .53948 .74999 L .56699 .7529 L p .707 .577 .707 r
F P
0 g
s
.60202 .81757 m .5951 .78203 L .56439 .78496 L p .707 .577 .707 r
F P
0 g
s
.5951 .78203 m .60202 .81757 L .63332 .81112 L p .707 .577 .707 r
F P
0 g
s
.63332 .81112 m .6264 .77558 L .5951 .78203 L p .707 .577 .707 r
F P
0 g
s
.6264 .77558 m .63332 .81112 L .66213 .80178 L p .707 .577 .707 r
F P
0 g
s
.66213 .80178 m .65521 .76623 L .6264 .77558 L p .707 .577 .707 r
F P
0 g
s
.57131 .8205 m .56439 .78496 L .53726 .78407 L p .707 .577 .707 r
F P
0 g
s
.56439 .78496 m .57131 .8205 L .60202 .81757 L p .707 .577 .707 r
F P
0 g
s
.67871 .68086 m .6829 .73578 L .69902 .72643 L p .707 .577 .707 r
F P
0 g
s
.69902 .72643 m .69483 .6715 L .67871 .68086 L p .707 .577 .707 r
F P
0 g
s
.65521 .76623 m .66213 .80178 L .68563 .79045 L p .707 .577 .707 r
F P
0 g
s
.68563 .79045 m .67871 .75491 L .65521 .76623 L p .707 .577 .707 r
F P
0 g
s
.51411 .68941 m .5183 .74433 L .53948 .74999 L p .707 .577 .707 r
F P
0 g
s
.59745 .86019 m .59392 .84243 L .56331 .84532 L p .707 .577 .707 r
F P
0 g
s
.59392 .84243 m .59745 .86019 L .62876 .85376 L p .707 .577 .707 r
F P
0 g
s
.62876 .85376 m .62523 .83601 L .59392 .84243 L p .707 .577 .707 r
F P
0 g
s
.62523 .83601 m .62876 .85376 L .6577 .84442 L p .707 .577 .707 r
F P
0 g
s
.6577 .84442 m .65417 .82666 L .62523 .83601 L p .707 .577 .707 r
F P
0 g
s
.53726 .78407 m .54418 .81961 L .57131 .8205 L p .707 .577 .707 r
F P
0 g
s
.5183 .74433 m .51411 .68941 L .50133 .68155 L p .707 .577 .707 r
F P
0 g
s
.56331 .84532 m .56684 .86307 L .59745 .86019 L p .707 .577 .707 r
F P
0 g
s
.54418 .81961 m .53726 .78407 L .51637 .77946 L p .707 .577 .707 r
F P
0 g
s
.56684 .86307 m .56331 .84532 L .53639 .84437 L p .707 .577 .707 r
F P
0 g
s
.65417 .82666 m .6577 .84442 L .68144 .83307 L p .707 .577 .707 r
F P
0 g
s
.68144 .83307 m .67791 .81531 L .65417 .82666 L p .707 .577 .707 r
F P
0 g
s
.67871 .75491 m .68563 .79045 L .70154 .77826 L p .707 .577 .707 r
F P
0 g
s
.70154 .77826 m .69462 .74272 L .67871 .75491 L p .707 .577 .707 r
F P
0 g
s
.53639 .84437 m .53992 .86213 L .56684 .86307 L p .707 .577 .707 r
F P
0 g
s
.69483 .6715 m .69902 .72643 L .70585 .71663 L p .707 .577 .707 r
F P
0 g
s
.70585 .71663 m .70165 .66171 L .69483 .6715 L p .707 .577 .707 r
F P
0 g
s
.51637 .77946 m .5233 .815 L .54418 .81961 L p .707 .577 .707 r
F P
0 g
s
.50133 .68155 m .50552 .73647 L .5183 .74433 L p .707 .577 .707 r
F P
0 g
s
.53992 .86213 m .53639 .84437 L .5158 .83969 L p .707 .577 .707 r
F P
0 g
s
.67791 .81531 m .68144 .83307 L .69766 .82083 L p .707 .577 .707 r
F P
0 g
s
.69766 .82083 m .69413 .80307 L .67791 .81531 L p .707 .577 .707 r
F P
0 g
s
.5233 .815 m .51637 .77946 L .50377 .77158 L p .707 .577 .707 r
F P
0 g
s
.5158 .83969 m .51933 .85745 L .53992 .86213 L p .707 .577 .707 r
F P
0 g
s
.50552 .73647 m .50133 .68155 L .4982 .67227 L p .707 .577 .707 r
F P
0 g
s
.69462 .74272 m .70154 .77826 L .70828 .76639 L p .707 .577 .707 r
F P
0 g
s
.70828 .76639 m .70136 .73085 L .69462 .74272 L p .707 .577 .707 r
F P
0 g
s
.50377 .77158 m .5107 .80712 L .5233 .815 L p .707 .577 .707 r
F P
0 g
s
.70165 .66171 m .70585 .71663 L .70272 .70735 L p .707 .577 .707 r
F P
0 g
s
.70272 .70735 m .69853 .65243 L .70165 .66171 L p .707 .577 .707 r
F P
0 g
s
.51933 .85745 m .5158 .83969 L .50356 .83173 L p .707 .577 .707 r
F P
0 g
s
.4982 .67227 m .50239 .72719 L .50552 .73647 L p .707 .577 .707 r
F P
0 g
s
.69413 .80307 m .69766 .82083 L .70476 .8089 L p .707 .577 .707 r
F P
0 g
s
.70476 .8089 m .70124 .79114 L .69413 .80307 L p .707 .577 .707 r
F P
0 g
s
.50356 .83173 m .50709 .84949 L .51933 .85745 L p .707 .577 .707 r
F P
0 g
s
.5107 .80712 m .50377 .77158 L .50069 .7612 L p .707 .577 .707 r
F P
0 g
s
.48154 .8216 m .48154 .31972 L .43824 .31631 L p .707 .577 .707 r
F P
0 g
s
.50239 .72719 m .4982 .67227 L .50503 .66247 L p .707 .577 .707 r
F P
0 g
s
.50069 .7612 m .50762 .79674 L .5107 .80712 L p .707 .577 .707 r
F P
0 g
s
.50709 .84949 m .50356 .83173 L .50086 .82127 L p .707 .578 .707 r
F P
0 g
s
.50503 .66247 m .50922 .7174 L .50239 .72719 L p .707 .577 .707 r
F P
0 g
s
.50086 .82127 m .50439 .83903 L .50709 .84949 L p .707 .578 .707 r
F P
0 g
s
.50762 .79674 m .50069 .7612 L .50744 .74933 L p .707 .577 .707 r
F P
0 g
s
.50922 .7174 m .50503 .66247 L .52115 .65312 L p .707 .577 .707 r
F P
0 g
s
.50744 .74933 m .51436 .78487 L .50762 .79674 L p .707 .577 .707 r
F P
0 g
s
.50439 .83903 m .50086 .82127 L .50796 .80934 L p .707 .577 .707 r
F P
0 g
s
.52115 .65312 m .52534 .70804 L .50922 .7174 L p .707 .577 .707 r
F P
0 g
s
.50796 .80934 m .51149 .82709 L .50439 .83903 L p .707 .577 .707 r
F P
0 g
s
.51436 .78487 m .50744 .74933 L .52334 .73713 L p .707 .577 .707 r
F P
0 g
s
.52334 .73713 m .53026 .77267 L .51436 .78487 L p .707 .577 .707 r
F P
0 g
s
.51149 .82709 m .50796 .80934 L .52418 .7971 L p .707 .577 .707 r
F P
0 g
s
.52418 .7971 m .52771 .81485 L .51149 .82709 L p .707 .577 .707 r
F P
0 g
s
.52771 .81485 m .52418 .7971 L .54792 .78575 L p .707 .577 .707 r
F P
0 g
s
.48154 .31972 m .48154 .8216 L .52666 .82126 L p .707 .577 .707 r
F P
0 g
s
.52534 .70804 m .52115 .65312 L .54498 .64512 L p .707 .577 .707 r
F P
0 g
s
.54498 .64512 m .54917 .70004 L .52534 .70804 L p .707 .577 .707 r
F P
0 g
s
.53026 .77267 m .52334 .73713 L .54684 .72581 L p .707 .577 .707 r
F P
0 g
s
.52666 .82126 m .52666 .31937 L .48154 .31972 L p .707 .577 .707 r
F P
0 g
s
.54917 .70004 m .54498 .64512 L .57419 .63927 L p .707 .577 .707 r
F P
0 g
s
.57419 .63927 m .57838 .69419 L .54917 .70004 L p .707 .577 .707 r
F P
0 g
s
.54684 .72581 m .55377 .76135 L .53026 .77267 L p .707 .577 .707 r
F P
0 g
s
.55377 .76135 m .54684 .72581 L .57565 .71647 L p .707 .577 .707 r
F P
0 g
s
.54792 .78575 m .55145 .80351 L .52771 .81485 L p .707 .577 .707 r
F P
0 g
s
.57565 .71647 m .58258 .75201 L .55377 .76135 L p .707 .577 .707 r
F P
0 g
s
.55145 .80351 m .54792 .78575 L .57687 .7764 L p .707 .577 .707 r
F P
0 g
s
.57687 .7764 m .58039 .79416 L .55145 .80351 L p .707 .577 .707 r
F P
0 g
s
.52666 .31937 m .52666 .82126 L .56916 .81718 L p .707 .577 .707 r
F P
0 g
s
.56916 .81718 m .56916 .3153 L .52666 .31937 L p .707 .577 .707 r
F P
0 g
s
.70136 .73085 m .70828 .76639 L .7052 .75601 L p .707 .577 .707 r
F P
0 g
s
.7052 .75601 m .69828 .72046 L .70136 .73085 L p .707 .577 .707 r
F P
0 g
s
.43824 .8182 m .43824 .31631 L .40098 .30947 L p .707 .577 .707 r
F P
0 g
s
.43824 .31631 m .43824 .8182 L .48154 .8216 L p .707 .577 .707 r
F P
0 g
s
.57838 .69419 m .57419 .63927 L .60592 .63612 L p .707 .577 .707 r
F P
0 g
s
.60592 .63612 m .61011 .69104 L .57838 .69419 L p .707 .577 .707 r
F P
0 g
s
.58258 .75201 m .57565 .71647 L .60695 .71001 L p .707 .577 .707 r
F P
0 g
s
.60695 .71001 m .61387 .74556 L .58258 .75201 L p .707 .577 .707 r
F P
0 g
s
.58039 .79416 m .57687 .7764 L .60817 .76998 L p .707 .577 .707 r
F P
0 g
s
.60817 .76998 m .6117 .78773 L .58039 .79416 L p .707 .577 .707 r
F P
0 g
s
.56916 .3153 m .56916 .81718 L .60489 .80979 L p .707 .577 .707 r
F P
0 g
s
.60489 .80979 m .60489 .3079 L .56916 .3153 L p .707 .577 .707 r
F P
0 g
s
.69853 .65243 m .70272 .70735 L .68994 .69949 L p .707 .577 .707 r
F P
0 g
s
.68994 .69949 m .68575 .64457 L .69853 .65243 L p .707 .577 .707 r
F P
0 g
s
.70124 .79114 m .70476 .8089 L .70206 .79844 L p .707 .578 .707 r
F P
0 g
s
.70206 .79844 m .69853 .78068 L .70124 .79114 L p .707 .578 .707 r
F P
0 g
s
.2545 .70596 m .2527 .64943 L .22148 .64904 L p .707 .577 .707 r
F P
0 g
s
.2527 .64943 m .2545 .70596 L .2863 .70436 L p .707 .577 .707 r
F P
0 g
s
.2863 .70436 m .28449 .64783 L .2527 .64943 L p .707 .577 .707 r
F P
0 g
s
.28449 .64783 m .2863 .70436 L .31556 .70091 L p .707 .577 .707 r
F P
0 g
s
.31556 .70091 m .31375 .64439 L .28449 .64783 L p .707 .577 .707 r
F P
0 g
s
.69828 .72046 m .7052 .75601 L .6926 .74812 L p .707 .577 .707 r
F P
0 g
s
.6926 .74812 m .68568 .71258 L .69828 .72046 L p .707 .577 .707 r
F P
0 g
s
.40098 .81136 m .40098 .30947 L .37341 .29989 L p .707 .577 .707 r
F P
0 g
s
.40098 .30947 m .40098 .81136 L .43824 .8182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22329 .70556 m .22148 .64904 L .1939 .64669 L p .707 .577 .707 r
F P
0 g
s
.22148 .64904 m .22329 .70556 L .2545 .70596 L p .707 .577 .707 r
F P
0 g
s
.63706 .636 m .64125 .69092 L .61011 .69104 L p .707 .577 .707 r
F P
0 g
s
.61011 .69104 m .60592 .63612 L .63706 .636 L p .707 .577 .707 r
F P
0 g
s
.63766 .70709 m .64458 .74263 L .61387 .74556 L p .707 .577 .707 r
F P
0 g
s
.61387 .74556 m .60695 .71001 L .63766 .70709 L p .707 .577 .707 r
F P
0 g
s
.63878 .76709 m .64231 .78485 L .6117 .78773 L p .707 .577 .707 r
F P
0 g
s
.6117 .78773 m .60817 .76998 L .63878 .76709 L p .707 .577 .707 r
F P
0 g
s
.60489 .3079 m .60489 .80979 L .63035 .79979 L p .707 .577 .707 r
F P
0 g
s
.63035 .79979 m .63035 .2979 L .60489 .3079 L p .707 .577 .707 r
F P
0 g
s
.68575 .64457 m .68994 .69949 L .66876 .69383 L p .707 .577 .707 r
F P
0 g
s
.66876 .69383 m .66457 .63891 L .68575 .64457 L p .707 .577 .707 r
F P
0 g
s
.31375 .64439 m .31556 .70091 L .33942 .69597 L p .707 .577 .707 r
F P
0 g
s
.33942 .69597 m .33762 .63944 L .31375 .64439 L p .707 .577 .707 r
F P
0 g
s
.1939 .64669 m .19571 .70321 L .22329 .70556 L p .707 .577 .707 r
F P
0 g
s
.2566 .75655 m .2536 .71837 L .22243 .72018 L p .707 .577 .707 r
F P
0 g
s
.2536 .71837 m .2566 .75655 L .2883 .75377 L p .707 .577 .707 r
F P
0 g
s
.2883 .75377 m .28529 .71559 L .2536 .71837 L p .707 .577 .707 r
F P
0 g
s
.69853 .78068 m .70206 .79844 L .68982 .79048 L p .707 .577 .707 r
F P
0 g
s
.68982 .79048 m .68629 .77272 L .69853 .78068 L p .707 .577 .707 r
F P
0 g
s
.28529 .71559 m .2883 .75377 L .31743 .7503 L p .707 .577 .707 r
F P
0 g
s
.31743 .7503 m .31443 .71212 L .28529 .71559 L p .707 .577 .707 r
F P
0 g
s
.19571 .70321 m .1939 .64669 L .17266 .64261 L p .707 .577 .707 r
F P
0 g
s
.22243 .72018 m .22544 .75836 L .2566 .75655 L p .707 .577 .707 r
F P
0 g
s
.22544 .75836 m .22243 .72018 L .19485 .72085 L p .707 .577 .707 r
F P
0 g
s
.19485 .72085 m .19786 .75903 L .22544 .75836 L p .707 .577 .707 r
F P
0 g
s
.68568 .71258 m .6926 .74812 L .67171 .74351 L p .707 .577 .707 r
F P
0 g
s
.67171 .74351 m .66479 .70797 L .68568 .71258 L p .707 .577 .707 r
F P
0 g
s
.17266 .64261 m .17446 .69913 L .19571 .70321 L p .707 .577 .707 r
F P
0 g
s
.31443 .71212 m .31743 .7503 L .34114 .74647 L p .707 .577 .707 r
F P
0 g
s
.34114 .74647 m .33814 .70829 L .31443 .71212 L p .707 .577 .707 r
F P
0 g
s
.33762 .63944 m .33942 .69597 L .35555 .69001 L p .707 .577 .707 r
F P
0 g
s
.35555 .69001 m .35375 .63348 L .33762 .63944 L p .707 .577 .707 r
F P
0 g
s
.25396 .79718 m .25243 .77808 L .22135 .77993 L p .707 .577 .707 r
F P
0 g
s
.25243 .77808 m .25396 .79718 L .28569 .79441 L p .707 .577 .707 r
F P
0 g
s
.28569 .79441 m .28417 .77532 L .25243 .77808 L p .707 .577 .707 r
F P
0 g
s
.66457 .63891 m .66876 .69383 L .64125 .69092 L p .707 .577 .707 r
F P
0 g
s
.64125 .69092 m .63706 .636 L .66457 .63891 L p .707 .577 .707 r
F P
0 g
s
.22135 .77993 m .22288 .79903 L .25396 .79718 L p .707 .577 .707 r
F P
0 g
s
.28417 .77532 m .28569 .79441 L .31497 .791 L p .707 .577 .707 r
F P
0 g
s
.31497 .791 m .31344 .7719 L .28417 .77532 L p .707 .577 .707 r
F P
0 g
s
.37341 .80178 m .37341 .29989 L .35824 .28848 L p .707 .577 .707 r
F P
0 g
s
.37341 .29989 m .37341 .80178 L .40098 .81136 L p .707 .577 .707 r
F P
0 g
s
.19786 .75903 m .19485 .72085 L .17356 .72031 L p .707 .577 .707 r
F P
0 g
s
.22288 .79903 m .22135 .77993 L .19397 .78068 L p .707 .577 .707 r
F P
0 g
s
.19397 .78068 m .19549 .79978 L .22288 .79903 L p .707 .577 .707 r
F P
0 g
s
.17356 .72031 m .17657 .75849 L .19786 .75903 L p .707 .577 .707 r
F P
0 g
s
.17446 .69913 m .17266 .64261 L .15982 .6372 L p .707 .577 .707 r
F P
0 g
s
.64458 .74263 m .63766 .70709 L .66479 .70797 L p .707 .577 .707 r
F P
0 g
s
.6657 .76804 m .66923 .7858 L .64231 .78485 L p .707 .577 .707 r
F P
0 g
s
.64231 .78485 m .63878 .76709 L .6657 .76804 L p .707 .577 .707 r
F P
0 g
s
.63035 .2979 m .63035 .79979 L .64306 .78817 L p .707 .577 .707 r
F P
0 g
s
.64306 .78817 m .64306 .28628 L .63035 .2979 L p .707 .577 .707 r
F P
0 g
s
.68629 .77272 m .68982 .79048 L .66923 .7858 L p .707 .577 .707 r
F P
0 g
s
.66923 .7858 m .6657 .76804 L .68629 .77272 L p .707 .577 .707 r
F P
0 g
s
.31344 .7719 m .31497 .791 L .33893 .78726 L p .707 .577 .707 r
F P
0 g
s
.33893 .78726 m .3374 .76816 L .31344 .7719 L p .707 .577 .707 r
F P
0 g
s
.33814 .70829 m .34114 .74647 L .35712 .74266 L p .707 .577 .707 r
F P
0 g
s
.35712 .74266 m .35411 .70448 L .33814 .70829 L p .707 .577 .707 r
F P
0 g
s
.66479 .70797 m .67171 .74351 L .64458 .74263 L p .707 .577 .707 r
F P
0 g
s
.15982 .6372 m .16163 .69372 L .17446 .69913 L p .707 .577 .707 r
F P
0 g
s
.19549 .79978 m .19397 .78068 L .17295 .78025 L p .707 .577 .707 r
F P
0 g
s
.17295 .78025 m .17448 .79935 L .19549 .79978 L p .707 .577 .707 r
F P
0 g
s
.35375 .63348 m .35555 .69001 L .36237 .68361 L p .707 .577 .707 r
F P
0 g
s
.36237 .68361 m .36057 .62708 L .35375 .63348 L p .707 .577 .707 r
F P
0 g
s
.17657 .75849 m .17356 .72031 L .16064 .71861 L p .707 .577 .707 r
F P
0 g
s
.16064 .71861 m .16365 .75679 L .17657 .75849 L p .707 .577 .707 r
F P
0 g
s
.3374 .76816 m .33893 .78726 L .35522 .78358 L p .707 .577 .707 r
F P
0 g
s
.35522 .78358 m .35369 .76448 L .3374 .76816 L p .707 .577 .707 r
F P
0 g
s
.16163 .69372 m .15982 .6372 L .15666 .63099 L p .707 .577 .707 r
F P
0 g
s
.35411 .70448 m .35712 .74266 L .36106 .74065 L p .707 .577 .707 r
F P
0 g
s
.36106 .74065 m .36379 .73925 L p .3609 .72887 L .707 .577 .707 r
F P
0 g
s
.3609 .72887 m .35411 .70448 L .36106 .74065 L .707 .577 .707 r
F
.35824 .28848 m .35694 .27638 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36379 .73925 m .36078 .70107 L .35411 .70448 L p .707 .577 .707 r
F P
0 g
s
.35921 .6774 m .3574 .62087 L .36057 .62708 L p .707 .577 .707 r
F P
0 g
s
.35369 .76448 m .35522 .78358 L .36081 .78098 L p .707 .577 .707 r
F P
0 g
s
.36081 .78098 m .36225 .78031 L p .36076 .77756 L .707 .577 .707 r
F P
0 g
s
.36076 .77756 m .35369 .76448 L .36081 .78098 L .707 .577 .707 r
F
.36225 .78031 m .36073 .76121 L .35369 .76448 L p F P
0 g
s
.3605 .73656 m .35974 .72693 L p .36078 .70107 L .707 .577 .707 r
F P
0 g
s
.35974 .72693 m .3575 .69838 L .36039 .70074 L p .707 .577 .707 r
F P
0 g
s
.36039 .70074 m .36078 .70107 L p .35974 .72693 L .707 .577 .707 r
F P
0 g
s
.3574 .62087 m .35921 .6774 L .34638 .67199 L p .707 .577 .707 r
F P
0 g
s
.35933 .77777 m .35781 .75867 L .36073 .76121 L p .707 .577 .707 r
F P
0 g
s
.3575 .69838 m .3605 .73656 L .34758 .73486 L p .707 .577 .707 r
F P
0 g
s
.35781 .75867 m .35933 .77777 L .34675 .77621 L p .707 .577 .707 r
F P
0 g
s
.35823 .7883 m .35824 .52952 L .35742 .46859 L .707 .578 .707 r
F
.35824 .79037 m .35824 .78808 L p .35823 .7883 L F P
0 g
s
.35824 .78808 m .35824 .52952 L p .35823 .7883 L .707 .578 .707 r
F P
0 g
s
.34638 .67199 m .34457 .61546 L .3574 .62087 L p .707 .577 .707 r
F P
0 g
s
.34758 .73486 m .34458 .69668 L .3575 .69838 L p .707 .577 .707 r
F P
0 g
s
.34675 .77621 m .34523 .75711 L .35781 .75867 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35824 .79037 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .27638 m .35694 .48851 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .48851 m .35694 .77827 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35824 .52952 m .35824 .28848 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36057 .62708 m .36237 .68361 L .35921 .6774 L p .707 .577 .707 r
F P
0 g
s
.36078 .70107 m .36379 .73925 L .3605 .73656 L p .707 .577 .707 r
F P
0 g
s
.36073 .76121 m .36225 .78031 L .35933 .77777 L p .707 .577 .707 r
F P
0 g
s
.35824 .28848 m .35824 .79037 L .37341 .80178 L p .707 .577 .707 r
F P
0 g
s
.17448 .79935 m .17295 .78025 L .16037 .77869 L p .707 .577 .707 r
F P
0 g
s
.16037 .77869 m .1619 .79779 L .17448 .79935 L p .707 .577 .707 r
F P
0 g
s
.15666 .63099 m .15847 .68752 L .16163 .69372 L p .707 .577 .707 r
F P
0 g
s
.64306 .28628 m .64306 .78817 L .64176 .77607 L p .707 .578 .707 r
F P
0 g
s
.64176 .77607 m .64176 .27418 L .64306 .28628 L p .707 .578 .707 r
F P
0 g
s
.16365 .75679 m .16064 .71861 L .15735 .71592 L p .707 .577 .707 r
F P
0 g
s
.15735 .71592 m .16036 .7541 L .16365 .75679 L p .707 .577 .707 r
F P
0 g
s
.15847 .68752 m .15666 .63099 L .16348 .62459 L p .707 .577 .707 r
F P
0 g
s
.1619 .79779 m .16037 .77869 L .15746 .77616 L p .707 .577 .707 r
F P
0 g
s
.15746 .77616 m .15898 .79526 L .1619 .79779 L p .707 .577 .707 r
F P
0 g
s
.16348 .62459 m .16528 .68112 L .15847 .68752 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35694 .27638 L .36964 .26476 L p .707 .577 .707 r
F P
0 g
s
.16036 .7541 m .15735 .71592 L .16402 .71251 L p .707 .577 .707 r
F P
0 g
s
.16402 .71251 m .16703 .75069 L .16036 .7541 L p .707 .577 .707 r
F P
0 g
s
.64176 .27418 m .64176 .77607 L .62658 .76466 L p .707 .577 .707 r
F P
0 g
s
.62658 .76466 m .62658 .26277 L .64176 .27418 L p .707 .577 .707 r
F P
0 g
s
.16528 .68112 m .16348 .62459 L .17961 .61863 L p .707 .577 .707 r
F P
0 g
s
.15898 .79526 m .15746 .77616 L .16449 .77289 L p .707 .577 .707 r
F P
0 g
s
.16449 .77289 m .16601 .79199 L .15898 .79526 L p .707 .577 .707 r
F P
0 g
s
.17961 .61863 m .18141 .67515 L .16528 .68112 L p .707 .577 .707 r
F P
0 g
s
.34457 .61546 m .34638 .67199 L .32513 .66791 L p .707 .577 .707 r
F P
0 g
s
.32513 .66791 m .32333 .61138 L .34457 .61546 L p .707 .577 .707 r
F P
0 g
s
.16703 .75069 m .16402 .71251 L .18 .7087 L p .707 .577 .707 r
F P
0 g
s
.18 .7087 m .183 .74688 L .16703 .75069 L p .707 .577 .707 r
F P
0 g
s
.18141 .67515 m .17961 .61863 L .20347 .61368 L p .707 .577 .707 r
F P
0 g
s
.36964 .76665 m .36964 .26476 L .39511 .25476 L p .707 .577 .707 r
F P
0 g
s
.36964 .26476 m .36964 .76665 L .35694 .77827 L p .707 .577 .707 r
F P
0 g
s
.62658 .26277 m .62658 .76466 L .59902 .75507 L p .707 .577 .707 r
F P
0 g
s
.59902 .75507 m .59902 .25318 L .62658 .26277 L p .707 .577 .707 r
F P
0 g
s
.20347 .61368 m .20528 .67021 L .18141 .67515 L p .707 .577 .707 r
F P
0 g
s
.34458 .69668 m .34758 .73486 L .32629 .73432 L p .707 .577 .707 r
F P
0 g
s
.32629 .73432 m .32328 .69614 L .34458 .69668 L p .707 .577 .707 r
F P
0 g
s
.16601 .79199 m .16449 .77289 L .18078 .7692 L p .707 .577 .707 r
F P
0 g
s
.32333 .61138 m .32513 .66791 L .29755 .66556 L p .707 .577 .707 r
F P
0 g
s
.29755 .66556 m .29574 .60903 L .32333 .61138 L p .707 .577 .707 r
F P
0 g
s
.18078 .7692 m .1823 .7883 L .16601 .79199 L p .707 .577 .707 r
F P
0 g
s
.20528 .67021 m .20347 .61368 L .23273 .61024 L p .707 .577 .707 r
F P
0 g
s
.183 .74688 m .18 .7087 L .20371 .70487 L p .707 .577 .707 r
F P
0 g
s
.20371 .70487 m .20672 .74305 L .183 .74688 L p .707 .577 .707 r
F P
0 g
s
.34523 .75711 m .34675 .77621 L .32574 .77579 L p .707 .577 .707 r
F P
0 g
s
.32574 .77579 m .32422 .75669 L .34523 .75711 L p .707 .577 .707 r
F P
0 g
s
.29574 .60903 m .29755 .66556 L .26633 .66516 L p .707 .577 .707 r
F P
0 g
s
.26633 .66516 m .26453 .60864 L .29574 .60903 L p .707 .577 .707 r
F P
0 g
s
.23273 .61024 m .23454 .66677 L .20528 .67021 L p .707 .577 .707 r
F P
0 g
s
.73366 .6639 m .73547 .60961 L .70425 .60639 L p .707 .577 .707 r
F P
0 g
s
.73547 .60961 m .73366 .6639 L .76546 .66377 L p .707 .577 .707 r
F P
0 g
s
.76546 .66377 m .76726 .60948 L .73547 .60961 L p .707 .577 .707 r
F P
0 g
s
.23454 .66677 m .23273 .61024 L .26453 .60864 L p .707 .577 .707 r
F P
0 g
s
.32328 .69614 m .32629 .73432 L .29871 .73499 L p .707 .577 .707 r
F P
0 g
s
.29871 .73499 m .29571 .69681 L .32328 .69614 L p .707 .577 .707 r
F P
0 g
s
.76726 .60948 m .76546 .66377 L .79472 .66031 L p .707 .577 .707 r
F P
0 g
s
.79472 .66031 m .79652 .60601 L .76726 .60948 L p .707 .577 .707 r
F P
0 g
s
.26453 .60864 m .26633 .66516 L .23454 .66677 L p .707 .577 .707 r
F P
0 g
s
.39511 .25476 m .39511 .75665 L .36964 .76665 L p .707 .577 .707 r
F P
0 g
s
.39511 .75665 m .39511 .25476 L .43084 .24736 L p .707 .577 .707 r
F P
0 g
s
.70245 .66068 m .70425 .60639 L .67667 .60013 L p .707 .577 .707 r
F P
0 g
s
.70425 .60639 m .70245 .66068 L .73366 .6639 L p .707 .577 .707 r
F P
0 g
s
.1823 .7883 m .18078 .7692 L .20474 .76547 L p .707 .577 .707 r
F P
0 g
s
.20474 .76547 m .20626 .78457 L .1823 .7883 L p .707 .577 .707 r
F P
0 g
s
.20672 .74305 m .20371 .70487 L .23284 .7014 L p .707 .577 .707 r
F P
0 g
s
.59902 .25318 m .59902 .75507 L .56176 .74824 L p .707 .577 .707 r
F P
0 g
s
.56176 .74824 m .56176 .24635 L .59902 .25318 L p .707 .577 .707 r
F P
0 g
s
.23284 .7014 m .23585 .73958 L .20672 .74305 L p .707 .577 .707 r
F P
0 g
s
.79652 .60601 m .79472 .66031 L .81858 .65384 L p .707 .577 .707 r
F P
0 g
s
.81858 .65384 m .82039 .59955 L .79652 .60601 L p .707 .577 .707 r
F P
0 g
s
.32422 .75669 m .32574 .77579 L .29835 .77654 L p .707 .577 .707 r
F P
0 g
s
.29835 .77654 m .29683 .75744 L .32422 .75669 L p .707 .577 .707 r
F P
0 g
s
.29571 .69681 m .29871 .73499 L .26755 .7368 L p .707 .577 .707 r
F P
0 g
s
.26755 .7368 m .26454 .69862 L .29571 .69681 L p .707 .577 .707 r
F P
0 g
s
.67487 .65443 m .67667 .60013 L .65543 .59146 L p .707 .577 .707 r
F P
0 g
s
.67667 .60013 m .67487 .65443 L .70245 .66068 L p .707 .577 .707 r
F P
0 g
s
.23585 .73958 m .23284 .7014 L .26454 .69862 L p .707 .577 .707 r
F P
0 g
s
.26454 .69862 m .26755 .7368 L .23585 .73958 L p .707 .577 .707 r
F P
0 g
s
.73245 .73282 m .73545 .6983 L .70429 .69319 L p .707 .577 .707 r
F P
0 g
s
.73545 .6983 m .73245 .73282 L .76415 .73362 L p .707 .577 .707 r
F P
0 g
s
.76415 .73362 m .76715 .6991 L .73545 .6983 L p .707 .577 .707 r
F P
0 g
s
.20626 .78457 m .20474 .76547 L .23401 .76205 L p .707 .577 .707 r
F P
0 g
s
.23401 .76205 m .23554 .78115 L .20626 .78457 L p .707 .577 .707 r
F P
0 g
s
.76715 .6991 m .76415 .73362 L .79328 .73003 L p .707 .577 .707 r
F P
0 g
s
.79328 .73003 m .79629 .69551 L .76715 .6991 L p .707 .577 .707 r
F P
0 g
s
.70129 .72771 m .70429 .69319 L .67671 .68426 L p .707 .577 .707 r
F P
0 g
s
.70429 .69319 m .70129 .72771 L .73245 .73282 L p .707 .577 .707 r
F P
0 g
s
.43084 .74925 m .43084 .24736 L .47334 .24329 L p .707 .577 .707 r
F P
0 g
s
.43084 .24736 m .43084 .74925 L .39511 .75665 L p .707 .577 .707 r
F P
0 g
s
.29683 .75744 m .29835 .77654 L .26727 .77838 L p .707 .577 .707 r
F P
0 g
s
.26727 .77838 m .26575 .75928 L .29683 .75744 L p .707 .577 .707 r
F P
0 g
s
.82039 .59955 m .81858 .65384 L .83471 .64502 L p .707 .577 .707 r
F P
0 g
s
.83471 .64502 m .83652 .59072 L .82039 .59955 L p .707 .577 .707 r
F P
0 g
s
.56176 .24635 m .56176 .74824 L .51845 .74483 L p .707 .577 .707 r
F P
0 g
s
.51845 .74483 m .51845 .24294 L .56176 .24635 L p .707 .577 .707 r
F P
0 g
s
.23554 .78115 m .23401 .76205 L .26575 .75928 L p .707 .577 .707 r
F P
0 g
s
.65543 .59146 m .65362 .64576 L .67487 .65443 L p .707 .577 .707 r
F P
0 g
s
.26575 .75928 m .26727 .77838 L .23554 .78115 L p .707 .577 .707 r
F P
0 g
s
.65362 .64576 m .65543 .59146 L .64259 .58121 L p .707 .577 .707 r
F P
0 g
s
.79629 .69551 m .79328 .73003 L .817 .7224 L p .707 .577 .707 r
F P
0 g
s
.817 .7224 m .82 .68788 L .79629 .69551 L p .707 .577 .707 r
F P
0 g
s
.73273 .7761 m .73425 .75889 L .70317 .75357 L p .707 .577 .707 r
F P
0 g
s
.73425 .75889 m .73273 .7761 L .76446 .77708 L p .707 .577 .707 r
F P
0 g
s
.76446 .77708 m .76598 .75987 L .73425 .75889 L p .707 .577 .707 r
F P
0 g
s
.67371 .71878 m .67671 .68426 L .65542 .6724 L p .707 .577 .707 r
F P
0 g
s
.67671 .68426 m .67371 .71878 L .70129 .72771 L p .707 .577 .707 r
F P
0 g
s
.47334 .74518 m .47334 .24329 L .51845 .24294 L p .707 .577 .707 r
F P
0 g
s
.47334 .24329 m .47334 .74518 L .43084 .74925 L p .707 .577 .707 r
F P
0 g
s
.76598 .75987 m .76446 .77708 L .79374 .77361 L p .707 .577 .707 r
F P
0 g
s
.79374 .77361 m .79526 .7564 L .76598 .75987 L p .707 .577 .707 r
F P
0 g
s
.51845 .24294 m .51845 .74483 L .47334 .74518 L p .707 .577 .707 r
F P
0 g
s
.70164 .77078 m .70317 .75357 L .67578 .74441 L p .707 .577 .707 r
F P
0 g
s
.70317 .75357 m .70164 .77078 L .73273 .7761 L p .707 .577 .707 r
F P
0 g
s
.67578 .74441 m .67426 .76162 L .70164 .77078 L p .707 .577 .707 r
F P
0 g
s
.79526 .7564 m .79374 .77361 L .81769 .76604 L p .707 .577 .707 r
F P
0 g
s
.81769 .76604 m .81922 .74882 L .79526 .7564 L p .707 .577 .707 r
F P
0 g
s
.83652 .59072 m .83471 .64502 L .84153 .63469 L p .707 .577 .707 r
F P
0 g
s
.84153 .63469 m .84334 .5804 L .83652 .59072 L p .707 .577 .707 r
F P
0 g
s
.65542 .6724 m .65242 .70692 L .67371 .71878 L p .707 .577 .707 r
F P
0 g
s
.64259 .58121 m .64079 .63551 L .65362 .64576 L p .707 .577 .707 r
F P
0 g
s
.67426 .76162 m .67578 .74441 L .65477 .73232 L p .707 .577 .707 r
F P
0 g
s
.82 .68788 m .817 .7224 L .83297 .71148 L p .707 .577 .707 r
F P
0 g
s
.83297 .71148 m .83597 .67696 L .82 .68788 L p .707 .577 .707 r
F P
0 g
s
.65242 .70692 m .65542 .6724 L .6425 .65877 L p .707 .577 .707 r
F P
0 g
s
.64079 .63551 m .64259 .58121 L .63943 .5704 L p .707 .577 .707 r
F P
0 g
s
.65477 .73232 m .65325 .74953 L .67426 .76162 L p .707 .577 .707 r
F P
0 g
s
.81922 .74882 m .81769 .76604 L .83399 .7551 L p .707 .577 .707 r
F P
0 g
s
.83399 .7551 m .83551 .73789 L .81922 .74882 L p .707 .577 .707 r
F P
0 g
s
.6425 .65877 m .6395 .69329 L .65242 .70692 L p .707 .577 .707 r
F P
0 g
s
.65325 .74953 m .65477 .73232 L .64219 .71849 L p .707 .577 .707 r
F P
0 g
s
.83597 .67696 m .83297 .71148 L .83964 .69834 L p .707 .577 .707 r
F P
0 g
s
.83964 .69834 m .84264 .66382 L .83597 .67696 L p .707 .577 .707 r
F P
0 g
s
.63943 .5704 m .63763 .62469 L .64079 .63551 L p .707 .577 .707 r
F P
0 g
s
.84334 .5804 m .84153 .63469 L .83837 .62388 L p .707 .577 .707 r
F P
0 g
s
.83837 .62388 m .84017 .56958 L .84334 .5804 L p .707 .577 .707 r
F P
0 g
s
.6395 .69329 m .6425 .65877 L .63921 .64469 L p .707 .577 .707 r
F P
0 g
s
.64219 .71849 m .64067 .7357 L .65325 .74953 L p .707 .577 .707 r
F P
0 g
s
.63763 .62469 m .63943 .5704 L .64625 .56007 L p .707 .577 .707 r
F P
0 g
s
.83551 .73789 m .83399 .7551 L .84102 .74186 L p .707 .577 .707 r
F P
0 g
s
.84102 .74186 m .84254 .72465 L .83551 .73789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63921 .64469 m .63621 .67921 L .6395 .69329 L p .707 .577 .707 r
F P
0 g
s
.64067 .7357 m .64219 .71849 L .63927 .70426 L p .707 .577 .707 r
F P
0 g
s
.84264 .66382 m .83964 .69834 L .83635 .68426 L p .707 .577 .707 r
F P
0 g
s
.83635 .68426 m .83936 .64974 L .84264 .66382 L p .707 .577 .707 r
F P
0 g
s
.63927 .70426 m .63775 .72147 L .64067 .7357 L p .707 .577 .707 r
F P
0 g
s
.64625 .56007 m .64444 .61437 L .63763 .62469 L p .707 .577 .707 r
F P
0 g
s
.63621 .67921 m .63921 .64469 L .64588 .63154 L p .707 .577 .707 r
F P
0 g
s
.84017 .56958 m .83837 .62388 L .82554 .61363 L p .707 .577 .707 r
F P
0 g
s
.82554 .61363 m .82734 .55934 L .84017 .56958 L p .707 .577 .707 r
F P
0 g
s
.64444 .61437 m .64625 .56007 L .66238 .55125 L p .707 .577 .707 r
F P
0 g
s
.38989 .61718 m .39408 .56128 L .36294 .55745 L p .707 .577 .707 r
F P
0 g
s
.39408 .56128 m .38989 .61718 L .42162 .61868 L p .707 .577 .707 r
F P
0 g
s
.42162 .61868 m .42581 .56278 L .39408 .56128 L p .707 .577 .707 r
F P
0 g
s
.84254 .72465 m .84102 .74186 L .8381 .72763 L p .707 .577 .707 r
F P
0 g
s
.8381 .72763 m .83962 .71042 L .84254 .72465 L p .707 .577 .707 r
F P
0 g
s
.42581 .56278 m .42162 .61868 L .45083 .6177 L p .707 .577 .707 r
F P
0 g
s
.45083 .6177 m .45502 .5618 L .42581 .56278 L p .707 .577 .707 r
F P
0 g
s
.64588 .63154 m .64288 .66606 L .63621 .67921 L p .707 .577 .707 r
F P
0 g
s
.63775 .72147 m .63927 .70426 L .6463 .69102 L p .707 .577 .707 r
F P
0 g
s
.35875 .61334 m .36294 .55745 L .33543 .55166 L p .707 .577 .707 r
F P
0 g
s
.36294 .55745 m .35875 .61334 L .38989 .61718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83936 .64974 m .83635 .68426 L .82343 .67062 L p .707 .577 .707 r
F P
0 g
s
.82343 .67062 m .82644 .6361 L .83936 .64974 L p .707 .577 .707 r
F P
0 g
s
.6463 .69102 m .64478 .70823 L .63775 .72147 L p .707 .577 .707 r
F P
0 g
s
.82734 .55934 m .82554 .61363 L .80429 .60496 L p .707 .577 .707 r
F P
0 g
s
.80429 .60496 m .8061 .55066 L .82734 .55934 L p .707 .577 .707 r
F P
0 g
s
.64288 .66606 m .64588 .63154 L .66186 .62062 L p .707 .577 .707 r
F P
0 g
s
.66238 .55125 m .66057 .60554 L .64444 .61437 L p .707 .577 .707 r
F P
0 g
s
.45502 .5618 m .45083 .6177 L .47466 .61433 L p .707 .577 .707 r
F P
0 g
s
.47466 .61433 m .47885 .55844 L .45502 .5618 L p .707 .577 .707 r
F P
0 g
s
.33543 .55166 m .33124 .60755 L .35875 .61334 L p .707 .577 .707 r
F P
0 g
s
.38613 .67239 m .39305 .63525 L .36233 .62842 L p .707 .577 .707 r
F P
0 g
s
.39305 .63525 m .38613 .67239 L .41742 .6774 L p .707 .577 .707 r
F P
0 g
s
.41742 .6774 m .42434 .64027 L .39305 .63525 L p .707 .577 .707 r
F P
0 g
s
.33124 .60755 m .33543 .55166 L .31425 .54448 L p .707 .577 .707 r
F P
0 g
s
.66057 .60554 m .66238 .55125 L .68624 .54479 L p .707 .577 .707 r
F P
0 g
s
.42434 .64027 m .41742 .6774 L .44623 .68012 L p .707 .577 .707 r
F P
0 g
s
.44623 .68012 m .45315 .64298 L .42434 .64027 L p .707 .577 .707 r
F P
0 g
s
.35541 .66556 m .36233 .62842 L .33521 .62045 L p .707 .577 .707 r
F P
0 g
s
.36233 .62842 m .35541 .66556 L .38613 .67239 L p .707 .577 .707 r
F P
0 g
s
.83962 .71042 m .8381 .72763 L .82552 .7138 L p .707 .577 .707 r
F P
0 g
s
.82552 .7138 m .82704 .69658 L .83962 .71042 L p .707 .577 .707 r
F P
0 g
s
.66186 .62062 m .65885 .65514 L .64288 .66606 L p .707 .577 .707 r
F P
0 g
s
.33521 .62045 m .32828 .65758 L .35541 .66556 L p .707 .577 .707 r
F P
0 g
s
.64478 .70823 m .6463 .69102 L .6626 .68008 L p .707 .577 .707 r
F P
0 g
s
.31425 .54448 m .31006 .60037 L .33124 .60755 L p .707 .577 .707 r
F P
0 g
s
.3883 .71373 m .39182 .69517 L .36121 .68818 L p .707 .577 .707 r
F P
0 g
s
.39182 .69517 m .3883 .71373 L .41961 .71893 L p .707 .577 .707 r
F P
0 g
s
.41961 .71893 m .42313 .70037 L .39182 .69517 L p .707 .577 .707 r
F P
0 g
s
.47885 .55844 m .47466 .61433 L .49077 .60891 L p .707 .577 .707 r
F P
0 g
s
.49077 .60891 m .49497 .55302 L .47885 .55844 L p .707 .577 .707 r
F P
0 g
s
.8061 .55066 m .80429 .60496 L .77671 .59871 L p .707 .577 .707 r
F P
0 g
s
.77671 .59871 m .77852 .54441 L .8061 .55066 L p .707 .577 .707 r
F P
0 g
s
.45315 .64298 m .44623 .68012 L .46974 .68026 L p .707 .577 .707 r
F P
0 g
s
.46974 .68026 m .47666 .64313 L .45315 .64298 L p .707 .577 .707 r
F P
0 g
s
.82644 .6361 m .82343 .67062 L .80214 .65876 L p .707 .577 .707 r
F P
0 g
s
.80214 .65876 m .80514 .62424 L .82644 .6361 L p .707 .577 .707 r
F P
0 g
s
.36121 .68818 m .35769 .70674 L .3883 .71373 L p .707 .577 .707 r
F P
0 g
s
.32828 .65758 m .33521 .62045 L .31432 .61211 L p .707 .577 .707 r
F P
0 g
s
.42313 .70037 m .41961 .71893 L .44855 .72184 L p .707 .577 .707 r
F P
0 g
s
.44855 .72184 m .45207 .70328 L .42313 .70037 L p .707 .577 .707 r
F P
0 g
s
.65885 .65514 m .66186 .62062 L .68557 .613 L p .707 .577 .707 r
F P
0 g
s
.6626 .68008 m .66107 .69729 L .64478 .70823 L p .707 .577 .707 r
F P
0 g
s
.68624 .54479 m .68444 .59908 L .66057 .60554 L p .707 .577 .707 r
F P
0 g
s
.35769 .70674 m .36121 .68818 L .3343 .68009 L p .707 .577 .707 r
F P
0 g
s
.68444 .59908 m .68624 .54479 L .71551 .54132 L p .707 .577 .707 r
F P
0 g
s
.31006 .60037 m .31425 .54448 L .30147 .53661 L p .707 .577 .707 r
F P
0 g
s
.3343 .68009 m .33077 .69865 L .35769 .70674 L p .707 .577 .707 r
F P
0 g
s
.31432 .61211 m .3074 .64925 L .32828 .65758 L p .707 .577 .707 r
F P
0 g
s
.77852 .54441 m .77671 .59871 L .74549 .59549 L p .707 .577 .707 r
F P
0 g
s
.74549 .59549 m .7473 .54119 L .77852 .54441 L p .707 .577 .707 r
F P
0 g
s
.45207 .70328 m .44855 .72184 L .47229 .72217 L p .707 .577 .707 r
F P
0 g
s
.47229 .72217 m .47582 .70361 L .45207 .70328 L p .707 .577 .707 r
F P
0 g
s
.82704 .69658 m .82552 .7138 L .80451 .70171 L p .707 .577 .707 r
F P
0 g
s
.80451 .70171 m .80603 .6845 L .82704 .69658 L p .707 .577 .707 r
F P
0 g
s
.7137 .59562 m .71551 .54132 L .7473 .54119 L p .707 .577 .707 r
F P
0 g
s
.71551 .54132 m .7137 .59562 L .68444 .59908 L p .707 .577 .707 r
F P
0 g
s
.30147 .53661 m .29728 .5925 L .31006 .60037 L p .707 .577 .707 r
F P
0 g
s
.68557 .613 m .68257 .64752 L .65885 .65514 L p .707 .577 .707 r
F P
0 g
s
.33077 .69865 m .3343 .68009 L .31371 .67169 L p .707 .577 .707 r
F P
0 g
s
.66107 .69729 m .6626 .68008 L .68655 .67251 L p .707 .577 .707 r
F P
0 g
s
.7473 .54119 m .74549 .59549 L .7137 .59562 L p .707 .577 .707 r
F P
0 g
s
.80514 .62424 m .80214 .65876 L .77456 .64984 L p .707 .577 .707 r
F P
0 g
s
.77456 .64984 m .77757 .61532 L .80514 .62424 L p .707 .577 .707 r
F P
0 g
s
.47666 .64313 m .46974 .68026 L .48564 .67782 L p .707 .577 .707 r
F P
0 g
s
.48564 .67782 m .49256 .64069 L .47666 .64313 L p .707 .577 .707 r
F P
0 g
s
.68257 .64752 m .68557 .613 L .7147 .60941 L p .707 .577 .707 r
F P
0 g
s
.31371 .67169 m .31018 .69025 L .33077 .69865 L p .707 .577 .707 r
F P
0 g
s
.3074 .64925 m .31432 .61211 L .30172 .60423 L p .707 .577 .707 r
F P
0 g
s
.49497 .55302 m .49077 .60891 L .4976 .60197 L p .707 .577 .707 r
F P
0 g
s
.4976 .60197 m .5018 .54607 L .49497 .55302 L p .707 .577 .707 r
F P
0 g
s
.68655 .67251 m .68503 .68972 L .66107 .69729 L p .707 .577 .707 r
F P
0 g
s
.30172 .60423 m .2948 .64136 L .3074 .64925 L p .707 .577 .707 r
F P
0 g
s
.29728 .5925 m .30147 .53661 L .29834 .52882 L p .707 .577 .707 r
F P
0 g
s
.77757 .61532 m .77456 .64984 L .7434 .64473 L p .707 .577 .707 r
F P
0 g
s
.7434 .64473 m .7464 .61021 L .77757 .61532 L p .707 .577 .707 r
F P
0 g
s
.7117 .64393 m .7147 .60941 L .7464 .61021 L p .707 .577 .707 r
F P
0 g
s
.7147 .60941 m .7117 .64393 L .68257 .64752 L p .707 .577 .707 r
F P
0 g
s
.80603 .6845 m .80451 .70171 L .77712 .69255 L p .707 .577 .707 r
F P
0 g
s
.77712 .69255 m .77865 .67534 L .80603 .6845 L p .707 .577 .707 r
F P
0 g
s
.47582 .70361 m .47229 .72217 L .48851 .71989 L p .707 .577 .707 r
F P
0 g
s
.48851 .71989 m .49203 .70133 L .47582 .70361 L p .707 .577 .707 r
F P
0 g
s
.7464 .61021 m .7434 .64473 L .7117 .64393 L p .707 .577 .707 r
F P
0 g
s
.68503 .68972 m .68655 .67251 L .71583 .66904 L p .707 .577 .707 r
F P
0 g
s
.31018 .69025 m .31371 .67169 L .30146 .6638 L p .707 .577 .707 r
F P
0 g
s
.30146 .6638 m .29794 .68236 L .31018 .69025 L p .707 .577 .707 r
F P
0 g
s
.29834 .52882 m .29415 .58471 L .29728 .5925 L p .707 .577 .707 r
F P
0 g
s
.71583 .66904 m .71431 .68625 L .68503 .68972 L p .707 .577 .707 r
F P
0 g
s
.49256 .64069 m .48564 .67782 L .49238 .67304 L p .707 .577 .707 r
F P
0 g
s
.49238 .67304 m .4993 .6359 L .49256 .64069 L p .707 .577 .707 r
F P
0 g
s
.77865 .67534 m .77712 .69255 L .74604 .68723 L p .707 .577 .707 r
F P
0 g
s
.74604 .68723 m .74756 .67002 L .77865 .67534 L p .707 .577 .707 r
F P
0 g
s
.71431 .68625 m .71583 .66904 L .74756 .67002 L p .707 .577 .707 r
F P
0 g
s
.2948 .64136 m .30172 .60423 L .29864 .59757 L p .707 .577 .707 r
F P
0 g
s
.74756 .67002 m .74604 .68723 L .71431 .68625 L p .707 .577 .707 r
F P
0 g
s
.5018 .54607 m .4976 .60197 L .49448 .59418 L p .707 .577 .707 r
F P
0 g
s
.49448 .59418 m .49867 .53829 L .5018 .54607 L p .707 .577 .707 r
F P
0 g
s
.29864 .59757 m .29172 .6347 L .2948 .64136 L p .707 .577 .707 r
F P
0 g
s
.49203 .70133 m .48851 .71989 L .49561 .71522 L p .707 .577 .707 r
F P
0 g
s
.49561 .71522 m .49914 .69666 L .49203 .70133 L p .707 .577 .707 r
F P
0 g
s
.29415 .58471 m .29834 .52882 L .30517 .52188 L p .707 .577 .707 r
F P
0 g
s
.29794 .68236 m .30146 .6638 L .29876 .6572 L p .707 .577 .707 r
F P
0 g
s
.29876 .6572 m .29523 .67576 L .29794 .68236 L p .707 .577 .707 r
F P
0 g
s
.30517 .52188 m .30098 .57777 L .29415 .58471 L p .707 .577 .707 r
F P
0 g
s
.4993 .6359 m .49238 .67304 L .4893 .66638 L p .707 .577 .707 r
F P
0 g
s
.4893 .66638 m .49622 .62924 L .4993 .6359 L p .707 .577 .707 r
F P
0 g
s
.29172 .6347 m .29864 .59757 L .30538 .59279 L p .707 .577 .707 r
F P
0 g
s
.49867 .53829 m .49448 .59418 L .4817 .58631 L p .707 .577 .707 r
F P
0 g
s
.4817 .58631 m .48589 .53042 L .49867 .53829 L p .707 .577 .707 r
F P
0 g
s
.30538 .59279 m .29846 .62992 L .29172 .6347 L p .707 .577 .707 r
F P
0 g
s
.30098 .57777 m .30517 .52188 L .32129 .51646 L p .707 .577 .707 r
F P
0 g
s
.49914 .69666 m .49561 .71522 L .49291 .70862 L p .707 .577 .707 r
F P
0 g
s
.49291 .70862 m .49644 .69006 L .49914 .69666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29523 .67576 m .29876 .6572 L .30587 .65253 L p .707 .577 .707 r
F P
0 g
s
.30587 .65253 m .30234 .67109 L .29523 .67576 L p .707 .577 .707 r
F P
0 g
s
.32129 .51646 m .3171 .57235 L .30098 .57777 L p .707 .577 .707 r
F P
0 g
s
.49622 .62924 m .4893 .66638 L .4767 .65849 L p .707 .577 .707 r
F P
0 g
s
.4767 .65849 m .48362 .62136 L .49622 .62924 L p .707 .577 .707 r
F P
0 g
s
.29846 .62992 m .30538 .59279 L .32128 .59035 L p .707 .577 .707 r
F P
0 g
s
.48589 .53042 m .4817 .58631 L .46051 .57913 L p .707 .577 .707 r
F P
0 g
s
.46051 .57913 m .46471 .52323 L .48589 .53042 L p .707 .577 .707 r
F P
0 g
s
.3171 .57235 m .32129 .51646 L .34512 .51309 L p .707 .577 .707 r
F P
0 g
s
.32128 .59035 m .31436 .62748 L .29846 .62992 L p .707 .577 .707 r
F P
0 g
s
.49644 .69006 m .49291 .70862 L .48067 .70073 L p .707 .577 .707 r
F P
0 g
s
.48067 .70073 m .48419 .68217 L .49644 .69006 L p .707 .577 .707 r
F P
0 g
s
.30234 .67109 m .30587 .65253 L .32208 .65025 L p .707 .577 .707 r
F P
0 g
s
.34512 .51309 m .34093 .56899 L .3171 .57235 L p .707 .577 .707 r
F P
0 g
s
.32208 .65025 m .31856 .6688 L .30234 .67109 L p .707 .577 .707 r
F P
0 g
s
.46471 .52323 m .46051 .57913 L .43301 .57334 L p .707 .577 .707 r
F P
0 g
s
.43301 .57334 m .4372 .51744 L .46471 .52323 L p .707 .577 .707 r
F P
0 g
s
.48362 .62136 m .4767 .65849 L .45582 .65016 L p .707 .577 .707 r
F P
0 g
s
.45582 .65016 m .46274 .61302 L .48362 .62136 L p .707 .577 .707 r
F P
0 g
s
.31436 .62748 m .32128 .59035 L .34479 .59049 L p .707 .577 .707 r
F P
0 g
s
.34093 .56899 m .34512 .51309 L .37433 .51211 L p .707 .577 .707 r
F P
0 g
s
.34479 .59049 m .33787 .62763 L .31436 .62748 L p .707 .577 .707 r
F P
0 g
s
.4372 .51744 m .43301 .57334 L .40186 .56951 L p .707 .577 .707 r
F P
0 g
s
.40186 .56951 m .40606 .51361 L .4372 .51744 L p .707 .577 .707 r
F P
0 g
s
.48419 .68217 m .48067 .70073 L .46008 .69233 L p .707 .577 .707 r
F P
0 g
s
.46008 .69233 m .4636 .67377 L .48419 .68217 L p .707 .577 .707 r
F P
0 g
s
.37014 .56801 m .37433 .51211 L .40606 .51361 L p .707 .577 .707 r
F P
0 g
s
.37433 .51211 m .37014 .56801 L .34093 .56899 L p .707 .577 .707 r
F P
0 g
s
.40606 .51361 m .40186 .56951 L .37014 .56801 L p .707 .577 .707 r
F P
0 g
s
.31856 .6688 m .32208 .65025 L .34583 .65058 L p .707 .577 .707 r
F P
0 g
s
.46274 .61302 m .45582 .65016 L .42869 .64218 L p .707 .577 .707 r
F P
0 g
s
.42869 .64218 m .43561 .60505 L .46274 .61302 L p .707 .577 .707 r
F P
0 g
s
.34583 .65058 m .3423 .66913 L .31856 .6688 L p .707 .577 .707 r
F P
0 g
s
.33787 .62763 m .34479 .59049 L .3736 .5932 L p .707 .577 .707 r
F P
0 g
s
.3736 .5932 m .36668 .63034 L .33787 .62763 L p .707 .577 .707 r
F P
0 g
s
.43561 .60505 m .42869 .64218 L .39797 .63536 L p .707 .577 .707 r
F P
0 g
s
.39797 .63536 m .4049 .59822 L .43561 .60505 L p .707 .577 .707 r
F P
0 g
s
.4636 .67377 m .46008 .69233 L .43316 .68424 L p .707 .577 .707 r
F P
0 g
s
.43316 .68424 m .43669 .66568 L .4636 .67377 L p .707 .577 .707 r
F P
0 g
s
.36668 .63034 m .3736 .5932 L .4049 .59822 L p .707 .577 .707 r
F P
0 g
s
.3423 .66913 m .34583 .65058 L .37477 .65349 L p .707 .577 .707 r
F P
0 g
s
.4049 .59822 m .39797 .63536 L .36668 .63034 L p .707 .577 .707 r
F P
0 g
s
.37477 .65349 m .37124 .67204 L .3423 .66913 L p .707 .577 .707 r
F P
0 g
s
.43669 .66568 m .43316 .68424 L .40255 .67725 L p .707 .577 .707 r
F P
0 g
s
.40255 .67725 m .40608 .65869 L .43669 .66568 L p .707 .577 .707 r
F P
0 g
s
.37124 .67204 m .37477 .65349 L .40608 .65869 L p .707 .577 .707 r
F P
0 g
s
.40608 .65869 m .40255 .67725 L .37124 .67204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001OOol@00000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001J
Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001HOol2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80006FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00001UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0000AOolA0014Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003Yoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000gOol005Aoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`00=Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000cOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
02moo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP06001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`03001JEP0000=JEPD00003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H0
05YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol01000FUH005YF0P001UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF1P000eYF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF0P001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF009JEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002eoo`00Dgoo0P000eYF3`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF
00000P000UYF00<005YFFUH015YF00@005YFFUIJEPL0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00AJEP@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
0eYF00<005YFFUH00eYF1P002Goo1@000goo1P001UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000`00
1eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUH0000300000eYF00000002000:Ool5
0009Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP8000=JEP03001JEUYF00=JEPL000=oo`D000Yoo`L000AJEP04001JEUYFFUH2
000]Ool003iooaH00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH015YF60000eYF
00@005YFFUIJEP<00003FUH005YF009JEP8002eoo`00=goo1`0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF20002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUH005YF00800003FUH005YF00AJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEPH0
00=JEP03001JEUYF00AJEP8000=JEP8002eoo`00<Woo1@000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP<00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YF00000UYF0P00;Goo000`
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P001UYF00<005YFFUH01000;Goo000^Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000
FUIJEUYF0`00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH3000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000800003FUH005YF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPH000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00D0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF1@001UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000P00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP040002FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH01P00
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00D005YFFUIJEP0000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF
00=JEPL000QJEP03001JEUYF00EJEPH000EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP000080009JEP04001JEUYFFUH>00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000/Ool01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH01EYF00D005YFFUIJEP0002ioo`00;7oo00@005YFFUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00AJEP8000=J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP80
009JEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP04001JEUYF
FUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00@000EJEP03001JEUYF00AJEP05001JEP00001JEP020006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH005YF0`0015YF00<005YFFUH00eYF00<005YFFUH00P0017oo
4P001goo0P000eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF5@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF100000=JEP00FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEP00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0P007goo0P0000MJEP00FUIJEP00FUH0000]Ool002eoo`03001JEP0000=JEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0400015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000`0015YF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP000080009JEP05001JEUYFFUH00005FUH00`00FUIJEP0A000BOol20002FUH00`00
FUH0000]Ool002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000AJEP8000EJEP@00003FUH0000000L000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=J
EP04001JEUYF0004FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04000@Ool01@00FUH005YF0000
;Goo000]Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00<005YF00000P000UYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPL0
00IJEP03001JEUYF00EJEP03001JEP0000D000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000004FUH800000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
000<Ool01@00FUH005YF0000;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP00
00EJEP<000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP8000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH01000FUH000001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0`00;Woo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YF000010000eYF00<005YFFUH00UYF1@001UYF10001EYF00<005YFFUH015YF
0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`800003
FUH0000002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP03FUH50004FUH50007FUH00`00
FUIJEP0400000eYF001JEP05FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03
001JEUYF00IJEPD000=JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
0eYF20003goo1P001eYF00<005YFFUH00P000eYF0P00;Woo000]Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500000eYF001JEP06
FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH0
00030006FUH6000AOol20004FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo000_Ool50003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUHA0003FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00
FUIJEP040004FUH00`00FUIJEP08FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF0P000eYF00<005YFFUH01EYF
00<005YFFUH00UYF4P0000IJEP00000005YF0006FUH200000eYF001oo`0]Ool003Aoo`L000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@00003FUH005YF00QJEP03001J
EUYF00AJEPh0009JEP<000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYF001JEP000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001UYF0`00;goo000gOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP040006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1`0000=JEP0000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUH005YF00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000_Ool0035oo`H0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800005FUH005YFFUH0000_Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003
FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP<000=J
EP03001oogoo02aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF
00AJEPD0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P001EYF0P0000=JEP00FUH01UYF
00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001o
ogoo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00AJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000IJEP@000IJEP03001JEUYF00IJEPD000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<00004Ool005YF000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH?000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P0017oo0`00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF000010001UYF1@0015YF00<0
05YFFUH01EYF00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00D005YFFUIJ
EP0000EJEP05001JEUYFFUH00002Ool40002FUH40005FUH00`00FUIJEP02FUH5000;Ool2000]Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000eYF00@005YFFUH000EJEP05001JEUYFFUH00006Ool@000@Ool2000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ400003FUH005YF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`00
00=JEP00FUH00eYF00D005YFFUIJEP0002Eoo`03001JEP0002eoo`00;Goo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP020005
FUH00`00FUIJEP02000ROol300000eYF001oo`0/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03
0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF0`000UYF00<005YFFUH00P0087oo0P00
0UYF0P00;Woo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1@000Woo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEP00008000=JEP03001oogoo01eoo`03001JEUYF009JEP8002ioo`00;Goo00<005YF
00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEPH000YJEP03001JEUYF00YJEP03001JEUYF00UJ
EPL0009JEP03001JEUYF00EJEP05001JEUYFFUH00002Ool00`00FUIJEP04FUH01000FUIJEUYF0`00
00=JEP00Ool077oo0`0015YF00<007ooOol0;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000?Ool01@00FUIJEUYF00001UYF00<005YFFUH0
1@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10001UYF
00D005YFFUIJEP0000=oo`8000=JEP03001JEUYF00AJEPH001Qoo`80009JEP03001JEUYF009JEP03
001oogoo02eoo`00;Woo>0000eYF00<005YFFUH00eYF10002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000Eoo`800003FUH005YF
00IJEP03001JEUYF009JEPT000Uoo`H000AJEP03001JEUYF0080031oo`00?goo200015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP04001JEUYFFUH20002FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`03Ool50006FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP03FUH3000bOol003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH01000FUH0000015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000eYF00<007ooOol00`001EYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00=7oo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH02P0000=JEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000`00=Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF1P0015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1@00>Woo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUHD000015YF000000000UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH000IJEP03001JEUYF00=JEP<00003FUH007oo00=ooa8003moo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2P0025YF00<005YFFUH015YF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP02
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT0
00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0007FUH00`00FUIJEP03FUH00`00FUH0001FOol002aoo`04001JEUYF0003
FUH01000FUIJEUYF200025YF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPH0009oo`03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00/000=JEP04001JEP00001E
Ool002eoo`03001JEP00009JEPH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Qoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP03FUH400000eYF0000001EOol002eoo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPT0011oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000IJEP04001JEUYFFUH20003Ool00`00FUH0001EOol002eoo`<00003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT001]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8000MJEP04001JEP000006
Ool2001EOol0031ooa@002Ioo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000MJEP<000Moo`03001JEP0005Eo
o`00K7oo0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0P002Woo00@005YF000005Ao
o`00KWoo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YF00000P0015YF00<005YF00000P002Woo0`000UYF00<007ooOol0DWoo001`
Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40005
FUH4000;Ool20002FUH01000FUIJEP00E7oo001dOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0>000>Ool00`00FUIJEP03FUH2001EOol007Yoo`P000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPP000=JEPL0011oo`<000EJEP8005Eoo`00PWoo9@000Woo1@00
3Woo0P000UYF00<005YFFUH00eYF00<007ooOol0E7oo002>Ool00`00FUIJEP02000GOol3000=Ool2
0005FUH00`00FUIJEP02001GOol008ioo`04001JEUYF000VOol20007FUH3001IOol008moo`8002=o
o`@00003FUH005YF00IJEP03001oogoo05Uoo`00Sgoo0`007Goo1@001EYF00<005YFFUH00eYF0P00
G7oo002?Ool00`00FUIJEP02000GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02001NOol008mo
o`800003FUH005YF00<000ioo`H000IJEP03001JEUYF00IJEP<0061oo`00T7oo00<005YF000015YF
3P000eYF00<005YFFUH01eYF00<005YFFUH015YF0P00HWoo002@Ool01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002AOol30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001XOol009=oo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00@006eoo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH00UYF
1P00LGoo002HOol>001gOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59934 .75469 m .59256 .70035 L .56152 .7017 L p .707 .577 .707 r
F P
0 g
s
.59256 .70035 m .59934 .75469 L .63092 .7501 L p .707 .577 .707 r
F P
0 g
s
.63092 .7501 m .62414 .69577 L .59256 .70035 L p .707 .577 .707 r
F P
0 g
s
.62414 .69577 m .63092 .7501 L .65995 .74274 L p .707 .577 .707 r
F P
0 g
s
.65995 .74274 m .65317 .6884 L .62414 .69577 L p .707 .577 .707 r
F P
0 g
s
.56831 .75604 m .56152 .7017 L .53407 .69969 L p .707 .577 .707 r
F P
0 g
s
.56152 .7017 m .56831 .75604 L .59934 .75469 L p .707 .577 .707 r
F P
0 g
s
.65317 .6884 m .65995 .74274 L .68359 .73331 L p .707 .577 .707 r
F P
0 g
s
.68359 .73331 m .67681 .67897 L .65317 .6884 L p .707 .577 .707 r
F P
0 g
s
.54085 .75403 m .53407 .69969 L .51288 .69452 L p .707 .577 .707 r
F P
0 g
s
.53407 .69969 m .54085 .75403 L .56831 .75604 L p .707 .577 .707 r
F P
0 g
s
.63591 .81217 m .6248 .77824 L .59435 .78795 L p .707 .577 .707 r
F P
0 g
s
.6248 .77824 m .63591 .81217 L .66393 .79937 L p .707 .577 .707 r
F P
0 g
s
.66393 .79937 m .65282 .76545 L .6248 .77824 L p .707 .577 .707 r
F P
0 g
s
.60546 .82187 m .59435 .78795 L .56445 .79362 L p .707 .577 .707 r
F P
0 g
s
.59435 .78795 m .60546 .82187 L .63591 .81217 L p .707 .577 .707 r
F P
0 g
s
.67681 .67897 m .68359 .73331 L .69952 .72274 L p .707 .577 .707 r
F P
0 g
s
.69952 .72274 m .69274 .66841 L .67681 .67897 L p .707 .577 .707 r
F P
0 g
s
.65282 .76545 m .66393 .79937 L .68676 .78475 L p .707 .577 .707 r
F P
0 g
s
.68676 .78475 m .67565 .75082 L .65282 .76545 L p .707 .577 .707 r
F P
0 g
s
.57556 .82755 m .56445 .79362 L .53801 .7947 L p .707 .577 .707 r
F P
0 g
s
.56445 .79362 m .57556 .82755 L .60546 .82187 L p .707 .577 .707 r
F P
0 g
s
.62853 .85558 m .62289 .83863 L .59243 .84825 L p .707 .577 .707 r
F P
0 g
s
.62289 .83863 m .62853 .85558 L .65675 .84283 L p .707 .577 .707 r
F P
0 g
s
.65675 .84283 m .6511 .82588 L .62289 .83863 L p .707 .577 .707 r
F P
0 g
s
.51288 .69452 m .51966 .74885 L .54085 .75403 L p .707 .577 .707 r
F P
0 g
s
.59807 .8652 m .59243 .84825 L .5627 .85379 L p .707 .577 .707 r
F P
0 g
s
.59243 .84825 m .59807 .8652 L .62853 .85558 L p .707 .577 .707 r
F P
0 g
s
.51966 .74885 m .51288 .69452 L .50003 .68668 L p .707 .577 .707 r
F P
0 g
s
.6511 .82588 m .65675 .84283 L .67995 .82819 L p .707 .577 .707 r
F P
0 g
s
.67995 .82819 m .6743 .81125 L .6511 .82588 L p .707 .577 .707 r
F P
0 g
s
.53801 .7947 m .54912 .82863 L .57556 .82755 L p .707 .577 .707 r
F P
0 g
s
.5627 .85379 m .56835 .87074 L .59807 .8652 L p .707 .577 .707 r
F P
0 g
s
.67565 .75082 m .68676 .78475 L .70218 .76972 L p .707 .577 .707 r
F P
0 g
s
.70218 .76972 m .69107 .7358 L .67565 .75082 L p .707 .577 .707 r
F P
0 g
s
.56835 .87074 m .5627 .85379 L .53662 .85471 L p .707 .577 .707 r
F P
0 g
s
.54912 .82863 m .53801 .7947 L .51763 .79108 L p .707 .577 .707 r
F P
0 g
s
.69274 .66841 m .69952 .72274 L .70619 .71207 L p .707 .577 .707 r
F P
0 g
s
.70619 .71207 m .6994 .65774 L .69274 .66841 L p .707 .577 .707 r
F P
0 g
s
.53662 .85471 m .54227 .87166 L .56835 .87074 L p .707 .577 .707 r
F P
0 g
s
.50003 .68668 m .50681 .74102 L .51966 .74885 L p .707 .577 .707 r
F P
0 g
s
.6743 .81125 m .67995 .82819 L .69587 .8131 L p .707 .577 .707 r
F P
0 g
s
.69587 .8131 m .69023 .79616 L .6743 .81125 L p .707 .577 .707 r
F P
0 g
s
.51763 .79108 m .52874 .82501 L .54912 .82863 L p .707 .577 .707 r
F P
0 g
s
.54227 .87166 m .53662 .85471 L .51674 .85093 L p .707 .577 .707 r
F P
0 g
s
.69107 .7358 m .70218 .76972 L .70868 .75576 L p .707 .577 .707 r
F P
0 g
s
.70868 .75576 m .69757 .72184 L .69107 .7358 L p .707 .577 .707 r
F P
0 g
s
.50681 .74102 m .50003 .68668 L .49678 .67695 L p .707 .577 .707 r
F P
0 g
s
.52874 .82501 m .51763 .79108 L .50531 .78312 L p .707 .577 .707 r
F P
0 g
s
.51674 .85093 m .52238 .86788 L .54227 .87166 L p .707 .577 .707 r
F P
0 g
s
.6994 .65774 m .70619 .71207 L .70294 .70234 L p .707 .577 .707 r
F P
0 g
s
.70294 .70234 m .69615 .64801 L .6994 .65774 L p .707 .577 .707 r
F P
0 g
s
.69023 .79616 m .69587 .8131 L .70296 .79904 L p .707 .577 .707 r
F P
0 g
s
.70296 .79904 m .69731 .78209 L .69023 .79616 L p .707 .577 .707 r
F P
0 g
s
.50531 .78312 m .51642 .81705 L .52874 .82501 L p .707 .577 .707 r
F P
0 g
s
.49678 .67695 m .50356 .73129 L .50681 .74102 L p .707 .577 .707 r
F P
0 g
s
.52238 .86788 m .51674 .85093 L .505 .84281 L p .707 .577 .707 r
F P
0 g
s
.69757 .72184 m .70868 .75576 L .70562 .74424 L p .707 .577 .707 r
F P
0 g
s
.70562 .74424 m .69451 .71031 L .69757 .72184 L p .707 .577 .707 r
F P
0 g
s
.51023 .72062 m .50344 .66628 L .51938 .65572 L p .707 .577 .707 r
F P
0 g
s
.50875 .75764 m .51986 .79157 L .51336 .80552 L p .707 .577 .707 r
F P
0 g
s
.51938 .65572 m .52616 .71005 L .51023 .72062 L p .707 .577 .707 r
F P
0 g
s
.52616 .71005 m .51938 .65572 L .54301 .64629 L p .707 .577 .707 r
F P
0 g
s
.51986 .79157 m .50875 .75764 L .52417 .74261 L p .707 .577 .707 r
F P
0 g
s
.52417 .74261 m .53528 .77654 L .51986 .79157 L p .707 .577 .707 r
F P
0 g
s
.51642 .81705 m .50531 .78312 L .50225 .7716 L p .707 .577 .707 r
F P
0 g
s
.50225 .7716 m .51336 .80552 L .51642 .81705 L p .707 .577 .707 r
F P
0 g
s
.51528 .83402 m .50963 .81708 L .52556 .80199 L p .707 .577 .707 r
F P
0 g
s
.52556 .80199 m .5312 .81893 L .51528 .83402 L p .707 .577 .707 r
F P
0 g
s
.52121 .8215 m .52121 .31961 L .47608 .3195 L p .707 .577 .707 r
F P
0 g
s
.54301 .64629 m .5498 .70062 L .52616 .71005 L p .707 .577 .707 r
F P
0 g
s
.5498 .70062 m .54301 .64629 L .57204 .63892 L p .707 .577 .707 r
F P
0 g
s
.53528 .77654 m .52417 .74261 L .547 .72799 L p .707 .577 .707 r
F P
0 g
s
.57204 .63892 m .57882 .69326 L .5498 .70062 L p .707 .577 .707 r
F P
0 g
s
.547 .72799 m .55811 .76191 L .53528 .77654 L p .707 .577 .707 r
F P
0 g
s
.55811 .76191 m .547 .72799 L .57502 .71519 L p .707 .577 .707 r
F P
0 g
s
.5312 .81893 m .52556 .80199 L .54876 .78735 L p .707 .577 .707 r
F P
0 g
s
.54876 .78735 m .55441 .8043 L .5312 .81893 L p .707 .577 .707 r
F P
0 g
s
.57502 .71519 m .58613 .74912 L .55811 .76191 L p .707 .577 .707 r
F P
0 g
s
.55441 .8043 m .54876 .78735 L .57697 .7746 L p .707 .577 .707 r
F P
0 g
s
.57697 .7746 m .58262 .79155 L .55441 .8043 L p .707 .577 .707 r
F P
0 g
s
.52121 .31961 m .52121 .8215 L .56426 .81787 L p .707 .577 .707 r
F P
0 g
s
.56426 .81787 m .56426 .31598 L .52121 .31961 L p .707 .577 .707 r
F P
0 g
s
.47608 .82139 m .47608 .3195 L .4333 .31565 L p .707 .577 .707 r
F P
0 g
s
.50356 .73129 m .49678 .67695 L .50344 .66628 L p .707 .577 .707 r
F P
0 g
s
.50344 .66628 m .51023 .72062 L .50356 .73129 L p .707 .577 .707 r
F P
0 g
s
.51336 .80552 m .50225 .7716 L .50875 .75764 L p .707 .577 .707 r
F P
0 g
s
.505 .84281 m .51064 .85975 L .52238 .86788 L p .707 .577 .707 r
F P
0 g
s
.5082 .84809 m .50255 .83114 L .50963 .81708 L p .707 .577 .707 r
F P
0 g
s
.50963 .81708 m .51528 .83402 L .5082 .84809 L p .707 .577 .707 r
F P
0 g
s
.47608 .3195 m .47608 .82139 L .52121 .8215 L p .707 .577 .707 r
F P
0 g
s
.57882 .69326 m .57204 .63892 L .60362 .63434 L p .707 .577 .707 r
F P
0 g
s
.60362 .63434 m .6104 .68867 L .57882 .69326 L p .707 .577 .707 r
F P
0 g
s
.60547 .70549 m .61658 .73941 L .58613 .74912 L p .707 .577 .707 r
F P
0 g
s
.58613 .74912 m .57502 .71519 L .60547 .70549 L p .707 .577 .707 r
F P
0 g
s
.60743 .76498 m .61308 .78193 L .58262 .79155 L p .707 .577 .707 r
F P
0 g
s
.58262 .79155 m .57697 .7746 L .60743 .76498 L p .707 .577 .707 r
F P
0 g
s
.56426 .31598 m .56426 .81787 L .60102 .81084 L p .707 .577 .707 r
F P
0 g
s
.60102 .81084 m .60102 .30896 L .56426 .31598 L p .707 .577 .707 r
F P
0 g
s
.4333 .81754 m .4333 .31565 L .39704 .30844 L p .707 .577 .707 r
F P
0 g
s
.4333 .31565 m .4333 .81754 L .47608 .82139 L p .707 .577 .707 r
F P
0 g
s
.69731 .78209 m .70296 .79904 L .70051 .78737 L p .707 .577 .707 r
F P
0 g
s
.70051 .78737 m .69486 .77043 L .69731 .78209 L p .707 .577 .707 r
F P
0 g
s
.69615 .64801 m .70294 .70234 L .69009 .69451 L p .707 .577 .707 r
F P
0 g
s
.69009 .69451 m .68331 .64017 L .69615 .64801 L p .707 .577 .707 r
F P
0 g
s
.51064 .85975 m .505 .84281 L .50255 .83114 L p .707 .577 .707 r
F P
0 g
s
.69451 .71031 m .70562 .74424 L .6933 .73628 L p .707 .577 .707 r
F P
0 g
s
.6933 .73628 m .68219 .70235 L .69451 .71031 L p .707 .577 .707 r
F P
0 g
s
.50255 .83114 m .5082 .84809 L .51064 .85975 L p .707 .577 .707 r
F P
0 g
s
.25541 .70168 m .25248 .64475 L .22125 .64529 L p .707 .577 .707 r
F P
0 g
s
.25248 .64475 m .25541 .70168 L .28716 .69956 L p .707 .577 .707 r
F P
0 g
s
.28716 .69956 m .28423 .64263 L .25248 .64475 L p .707 .577 .707 r
F P
0 g
s
.28423 .64263 m .28716 .69956 L .31633 .69609 L p .707 .577 .707 r
F P
0 g
s
.31633 .69609 m .3134 .63916 L .28423 .64263 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63466 .63299 m .64144 .68732 L .6104 .68867 L p .707 .577 .707 r
F P
0 g
s
.6104 .68867 m .60362 .63434 L .63466 .63299 L p .707 .577 .707 r
F P
0 g
s
.63537 .69981 m .64648 .73374 L .61658 .73941 L p .707 .577 .707 r
F P
0 g
s
.61658 .73941 m .60547 .70549 L .63537 .69981 L p .707 .577 .707 r
F P
0 g
s
.63716 .75944 m .64281 .77639 L .61308 .78193 L p .707 .577 .707 r
F P
0 g
s
.61308 .78193 m .60743 .76498 L .63716 .75944 L p .707 .577 .707 r
F P
0 g
s
.60102 .30896 m .60102 .81084 L .6279 .80112 L p .707 .577 .707 r
F P
0 g
s
.6279 .80112 m .6279 .29923 L .60102 .30896 L p .707 .577 .707 r
F P
0 g
s
.22418 .70222 m .22125 .64529 L .1936 .64421 L p .707 .577 .707 r
F P
0 g
s
.22125 .64529 m .22418 .70222 L .25541 .70168 L p .707 .577 .707 r
F P
0 g
s
.39704 .81033 m .39704 .30844 L .37086 .29857 L p .707 .577 .707 r
F P
0 g
s
.39704 .30844 m .39704 .81033 L .4333 .81754 L p .707 .577 .707 r
F P
0 g
s
.68331 .64017 m .69009 .69451 L .6689 .68933 L p .707 .577 .707 r
F P
0 g
s
.6689 .68933 m .66211 .635 L .68331 .64017 L p .707 .577 .707 r
F P
0 g
s
.69486 .77043 m .70051 .78737 L .68877 .77925 L p .707 .577 .707 r
F P
0 g
s
.68877 .77925 m .68312 .7623 L .69486 .77043 L p .707 .577 .707 r
F P
0 g
s
.3134 .63916 m .31633 .69609 L .34005 .69158 L p .707 .577 .707 r
F P
0 g
s
.34005 .69158 m .33712 .63465 L .3134 .63916 L p .707 .577 .707 r
F P
0 g
s
.1936 .64421 m .19654 .70113 L .22418 .70222 L p .707 .577 .707 r
F P
0 g
s
.22308 .71182 m .22798 .74997 L .25905 .74588 L p .707 .577 .707 r
F P
0 g
s
.25905 .74588 m .25415 .70773 L .22308 .71182 L p .707 .577 .707 r
F P
0 g
s
.25415 .70773 m .25905 .74588 L .29055 .74188 L p .707 .577 .707 r
F P
0 g
s
.29055 .74188 m .28565 .70374 L .25415 .70773 L p .707 .577 .707 r
F P
0 g
s
.28565 .70374 m .29055 .74188 L .3194 .73839 L p .707 .577 .707 r
F P
0 g
s
.3194 .73839 m .3145 .70024 L .28565 .70374 L p .707 .577 .707 r
F P
0 g
s
.19654 .70113 m .1936 .64421 L .17224 .6416 L p .707 .577 .707 r
F P
0 g
s
.19548 .71562 m .20038 .75376 L .22798 .74997 L p .707 .577 .707 r
F P
0 g
s
.22798 .74997 m .22308 .71182 L .19548 .71562 L p .707 .577 .707 r
F P
0 g
s
.68219 .70235 m .6933 .73628 L .67292 .73266 L p .707 .577 .707 r
F P
0 g
s
.67292 .73266 m .66181 .69874 L .68219 .70235 L p .707 .577 .707 r
F P
0 g
s
.17224 .6416 m .17517 .69853 L .19654 .70113 L p .707 .577 .707 r
F P
0 g
s
.66211 .635 m .6689 .68933 L .64144 .68732 L p .707 .577 .707 r
F P
0 g
s
.64144 .68732 m .63466 .63299 L .66211 .635 L p .707 .577 .707 r
F P
0 g
s
.22136 .77102 m .22384 .79009 L .25478 .78589 L p .707 .577 .707 r
F P
0 g
s
.25478 .78589 m .2523 .76682 L .22136 .77102 L p .707 .577 .707 r
F P
0 g
s
.2523 .76682 m .25478 .78589 L .28634 .78187 L p .707 .577 .707 r
F P
0 g
s
.3145 .70024 m .3194 .73839 L .34277 .73572 L p .707 .577 .707 r
F P
0 g
s
.28634 .78187 m .28386 .7628 L .2523 .76682 L p .707 .577 .707 r
F P
0 g
s
.34277 .73572 m .33787 .69758 L .3145 .70024 L p .707 .577 .707 r
F P
0 g
s
.33712 .63465 m .34005 .69158 L .35602 .68649 L p .707 .577 .707 r
F P
0 g
s
.35602 .68649 m .35308 .62957 L .33712 .63465 L p .707 .577 .707 r
F P
0 g
s
.28386 .7628 m .28634 .78187 L .31542 .77842 L p .707 .577 .707 r
F P
0 g
s
.31542 .77842 m .31294 .75936 L .28386 .7628 L p .707 .577 .707 r
F P
0 g
s
.17405 .71874 m .17895 .75689 L .20038 .75376 L p .707 .577 .707 r
F P
0 g
s
.20038 .75376 m .19548 .71562 L .17405 .71874 L p .707 .577 .707 r
F P
0 g
s
.68312 .7623 m .68877 .77925 L .66889 .77547 L p .707 .577 .707 r
F P
0 g
s
.66889 .77547 m .66324 .75852 L .68312 .7623 L p .707 .577 .707 r
F P
0 g
s
.64648 .73374 m .63537 .69981 L .66181 .69874 L p .707 .577 .707 r
F P
0 g
s
.64281 .77639 m .63716 .75944 L .66324 .75852 L p .707 .577 .707 r
F P
0 g
s
.6279 .29923 m .6279 .80112 L .64225 .78964 L p .707 .577 .707 r
F P
0 g
s
.64225 .78964 m .64225 .28775 L .6279 .29923 L p .707 .577 .707 r
F P
0 g
s
.19406 .775 m .19654 .79406 L .22384 .79009 L p .707 .577 .707 r
F P
0 g
s
.22384 .79009 m .22136 .77102 L .19406 .775 L p .707 .577 .707 r
F P
0 g
s
.37086 .80046 m .37086 .29857 L .35732 .28702 L p .707 .577 .707 r
F P
0 g
s
.37086 .29857 m .37086 .80046 L .39704 .81033 L p .707 .577 .707 r
F P
0 g
s
.17517 .69853 m .17224 .6416 L .15925 .63774 L p .707 .577 .707 r
F P
0 g
s
.66181 .69874 m .67292 .73266 L .64648 .73374 L p .707 .577 .707 r
F P
0 g
s
.31294 .75936 m .31542 .77842 L .33919 .77589 L p .707 .577 .707 r
F P
0 g
s
.33919 .77589 m .33671 .75683 L .31294 .75936 L p .707 .577 .707 r
F P
0 g
s
.15925 .63774 m .16219 .69467 L .17517 .69853 L p .707 .577 .707 r
F P
0 g
s
.33787 .69758 m .34277 .73572 L .35837 .73416 L p .707 .577 .707 r
F P
0 g
s
.35837 .73416 m .35622 .71742 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35308 .62957 m .35602 .68649 L .36265 .68132 L p .707 .577 .707 r
F P
0 g
s
.36265 .68132 m .35972 .62439 L .35308 .62957 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .35837 .73416 L .36469 .73384 L p .707 .577 .707 r
F P
0 g
s
.36469 .73384 m .35978 .69569 L .35347 .69601 L p .707 .577 .707 r
F P
0 g
s
.35972 .62439 m .36265 .68132 L .35931 .67657 L p .707 .577 .707 r
F P
0 g
s
.35931 .67657 m .35684 .62847 L p .35972 .62439 L .707 .577 .707 r
F P
0 g
s
.35684 .62847 m .35638 .61964 L .35681 .62025 L p .707 .577 .707 r
F P
0 g
s
.35681 .62025 m .35972 .62439 L p .35684 .62847 L .707 .577 .707 r
F P
0 g
s
.35282 .75546 m .3553 .77452 L .35625 .77451 L p .707 .577 .707 r
F P
0 g
s
.35625 .77451 m .36219 .77445 L p .35636 .76261 L .707 .577 .707 r
F P
0 g
s
.35636 .76261 m .35282 .75546 L .35625 .77451 L .707 .577 .707 r
F
.36219 .77445 m .35972 .75538 L .35282 .75546 L p F P
0 g
s
.35978 .69569 m .36469 .73384 L .36109 .7348 L p .707 .577 .707 r
F P
0 g
s
.36109 .7348 m .35684 .70176 L p .35978 .69569 L .707 .577 .707 r
F P
0 g
s
.35684 .70176 m .35619 .69666 L .35681 .69649 L p .707 .577 .707 r
F P
0 g
s
.35681 .69649 m .35978 .69569 L p .35684 .70176 L .707 .577 .707 r
F P
0 g
s
.35638 .61964 m .35931 .67657 L .34633 .6727 L p .707 .577 .707 r
F P
0 g
s
.35972 .75538 m .36219 .77445 L .35919 .77568 L p .707 .577 .707 r
F P
0 g
s
.35919 .77568 m .35671 .75661 L .35972 .75538 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .33787 .69758 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35622 .71742 m .35347 .69601 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35619 .69666 m .36109 .7348 L .34793 .73695 L p .707 .577 .707 r
F P
0 g
s
.33671 .75683 m .33919 .77589 L .3553 .77452 L p .707 .577 .707 r
F P
0 g
s
.3553 .77452 m .35282 .75546 L .33671 .75683 L p .707 .577 .707 r
F P
0 g
s
.35671 .75661 m .35919 .77568 L .34658 .77809 L p .707 .577 .707 r
F P
0 g
s
.35732 .28702 m .35732 .78891 L .37086 .80046 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35742 .78621 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35742 .78621 m .35738 .78712 L p .35739 .78201 L .706 .577 .707 r
F P
0 g
s
.35739 .78201 m .35773 .30251 L .35742 .78621 L .706 .577 .707 r
F
.35734 .77274 m .35745 .63396 L .35738 .78712 L F
.35745 .63396 m .35775 .27491 L .3575 .62842 L F
.35745 .63396 m .3575 .62842 L .35738 .78712 L F
.35775 .27491 m .35775 .30326 L p .35773 .30251 L F P
0 g
s
.35775 .30326 m .35775 .7768 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35738 .78712 m .35732 .78891 L p .35734 .77274 L .706 .577 .707 r
F P
0 g
s
.35732 .28702 m .35775 .27491 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .78891 m .35732 .49035 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .49035 m .35732 .28702 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.17308 .77835 m .17556 .79742 L .19654 .79406 L p .707 .577 .707 r
F P
0 g
s
.19654 .79406 m .19406 .775 L .17308 .77835 L p .707 .577 .707 r
F P
0 g
s
.16089 .72089 m .1658 .75904 L .17895 .75689 L p .707 .577 .707 r
F P
0 g
s
.17895 .75689 m .17405 .71874 L .16089 .72089 L p .707 .577 .707 r
F P
0 g
s
.66324 .75852 m .66889 .77547 L .64281 .77639 L p .707 .577 .707 r
F P
0 g
s
.16219 .69467 m .15925 .63774 L .15592 .63298 L p .707 .577 .707 r
F P
0 g
s
.16047 .78076 m .16295 .79983 L .17556 .79742 L p .707 .577 .707 r
F P
0 g
s
.17556 .79742 m .17308 .77835 L .16047 .78076 L p .707 .577 .707 r
F P
0 g
s
.64225 .28775 m .64225 .78964 L .64261 .77931 L p .706 .577 .707 r
F P
0 g
s
.64266 .76212 m .64225 .28775 L .64261 .77931 L .706 .577 .707 r
F
.64268 .77753 m .64268 .27564 L .64225 .28775 L p F P
0 g
s
.64261 .77931 m .64268 .77753 L p .64266 .76212 L .706 .577 .707 r
F P
0 g
s
.64268 .27564 m .64268 .77753 L .62914 .76597 L p .707 .577 .707 r
F P
0 g
s
.64068 .63472 m .64316 .58966 L p .64028 .5692 L .707 .577 .707 r
F P
0 g
s
.64316 .58966 m .64362 .58138 L .64319 .57982 L p .707 .577 .707 r
F P
0 g
s
.64319 .57982 m .64028 .5692 L p .64316 .58966 L .707 .577 .707 r
F P
0 g
s
.15592 .63298 m .15885 .68991 L .16219 .69467 L p .707 .577 .707 r
F P
0 g
s
.15729 .72185 m .1622 .76 L .1658 .75904 L p .707 .577 .707 r
F P
0 g
s
.1658 .75904 m .16089 .72089 L .15729 .72185 L p .707 .577 .707 r
F P
0 g
s
.15885 .68991 m .15592 .63298 L .16255 .62781 L p .707 .577 .707 r
F P
0 g
s
.15746 .78199 m .15994 .80106 L .16295 .79983 L p .707 .577 .707 r
F P
0 g
s
.16295 .79983 m .16047 .78076 L .15746 .78199 L p .707 .577 .707 r
F P
0 g
s
.16255 .62781 m .16548 .68474 L .15885 .68991 L p .707 .577 .707 r
F P
0 g
s
.16361 .72154 m .16851 .75968 L .1622 .76 L p .707 .577 .707 r
F P
0 g
s
.1622 .76 m .15729 .72185 L .16361 .72154 L p .707 .577 .707 r
F P
0 g
s
.34633 .6727 m .3434 .61577 L .35638 .61964 L p .707 .577 .707 r
F P
0 g
s
.62914 .76597 m .62914 .26409 L .64268 .27564 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35775 .27491 L .3721 .26343 L p .707 .577 .707 r
F P
0 g
s
.16548 .68474 m .16255 .62781 L .17851 .62272 L p .707 .577 .707 r
F P
0 g
s
.16436 .78192 m .16683 .80098 L .15994 .80106 L p .707 .577 .707 r
F P
0 g
s
.15994 .80106 m .15746 .78199 L .16436 .78192 L p .707 .577 .707 r
F P
0 g
s
.17851 .62272 m .18145 .67965 L .16548 .68474 L p .707 .577 .707 r
F P
0 g
s
.34793 .73695 m .34303 .69881 L .35619 .69666 L p .707 .577 .707 r
F P
0 g
s
.3434 .61577 m .34633 .6727 L .32496 .6701 L p .707 .577 .707 r
F P
0 g
s
.32496 .6701 m .32203 .61317 L .3434 .61577 L p .707 .577 .707 r
F P
0 g
s
.17921 .71997 m .18412 .75812 L .16851 .75968 L p .707 .577 .707 r
F P
0 g
s
.16851 .75968 m .16361 .72154 L .17921 .71997 L p .707 .577 .707 r
F P
0 g
s
.34658 .77809 m .3441 .75902 L .35671 .75661 L p .707 .577 .707 r
F P
0 g
s
.18145 .67965 m .17851 .62272 L .20224 .61822 L p .707 .577 .707 r
F P
0 g
s
.62914 .26409 m .62914 .76597 L .60296 .75611 L p .707 .577 .707 r
F P
0 g
s
.60296 .75611 m .60296 .25422 L .62914 .26409 L p .707 .577 .707 r
F P
0 g
s
.3721 .76532 m .3721 .26343 L .39897 .2537 L p .707 .577 .707 r
F P
0 g
s
.3721 .26343 m .3721 .76532 L .35775 .7768 L p .707 .577 .707 r
F P
0 g
s
.20224 .61822 m .20517 .67515 L .18145 .67965 L p .707 .577 .707 r
F P
0 g
s
.18047 .78055 m .18295 .79961 L .16683 .80098 L p .707 .577 .707 r
F P
0 g
s
.16683 .80098 m .16436 .78192 L .18047 .78055 L p .707 .577 .707 r
F P
0 g
s
.34303 .69881 m .34793 .73695 L .32651 .74008 L p .707 .577 .707 r
F P
0 g
s
.32651 .74008 m .3216 .70193 L .34303 .69881 L p .707 .577 .707 r
F P
0 g
s
.32203 .61317 m .32496 .6701 L .29732 .66902 L p .707 .577 .707 r
F P
0 g
s
.29732 .66902 m .29438 .61209 L .32203 .61317 L p .707 .577 .707 r
F P
0 g
s
.20258 .71731 m .20749 .75546 L .18412 .75812 L p .707 .577 .707 r
F P
0 g
s
.18412 .75812 m .17921 .71997 L .20258 .71731 L p .707 .577 .707 r
F P
0 g
s
.20517 .67515 m .20224 .61822 L .2314 .61474 L p .707 .577 .707 r
F P
0 g
s
.3441 .75902 m .34658 .77809 L .3256 .78144 L p .707 .577 .707 r
F P
0 g
s
.3256 .78144 m .32312 .76238 L .3441 .75902 L p .707 .577 .707 r
F P
0 g
s
.29438 .61209 m .29732 .66902 L .26609 .66956 L p .707 .577 .707 r
F P
0 g
s
.26609 .66956 m .26316 .61263 L .29438 .61209 L p .707 .577 .707 r
F P
0 g
s
.2314 .61474 m .23434 .67167 L .20517 .67515 L p .707 .577 .707 r
F P
0 g
s
.73391 .66771 m .73684 .61437 L .70561 .61038 L p .707 .577 .707 r
F P
0 g
s
.73684 .61437 m .73391 .66771 L .76566 .66794 L p .707 .577 .707 r
F P
0 g
s
.76566 .66794 m .76859 .6146 L .73684 .61437 L p .707 .577 .707 r
F P
0 g
s
.23434 .67167 m .2314 .61474 L .26316 .61263 L p .707 .577 .707 r
F P
0 g
s
.76859 .6146 m .76566 .66794 L .79483 .66439 L p .707 .577 .707 r
F P
0 g
s
.79483 .66439 m .79776 .61105 L .76859 .6146 L p .707 .577 .707 r
F P
0 g
s
.3216 .70193 m .32651 .74008 L .29891 .74387 L p .707 .577 .707 r
F P
0 g
s
.70268 .66372 m .70561 .61038 L .67797 .60303 L p .707 .577 .707 r
F P
0 g
s
.70561 .61038 m .70268 .66372 L .73391 .66771 L p .707 .577 .707 r
F P
0 g
s
.29891 .74387 m .294 .70573 L .3216 .70193 L p .707 .577 .707 r
F P
0 g
s
.26316 .61263 m .26609 .66956 L .23434 .67167 L p .707 .577 .707 r
F P
0 g
s
.20424 .77802 m .20671 .79708 L .18295 .79961 L p .707 .577 .707 r
F P
0 g
s
.18295 .79961 m .18047 .78055 L .20424 .77802 L p .707 .577 .707 r
F P
0 g
s
.60296 .25422 m .60296 .75611 L .5667 .7489 L p .707 .577 .707 r
F P
0 g
s
.5667 .7489 m .5667 .24701 L .60296 .25422 L p .707 .577 .707 r
F P
0 g
s
.39897 .2537 m .39897 .75559 L .3721 .76532 L p .707 .577 .707 r
F P
0 g
s
.39897 .75559 m .39897 .2537 L .43573 .24668 L p .707 .577 .707 r
F P
0 g
s
.23143 .71381 m .23633 .75196 L .20749 .75546 L p .707 .577 .707 r
F P
0 g
s
.20749 .75546 m .20258 .71731 L .23143 .71381 L p .707 .577 .707 r
F P
0 g
s
.79776 .61105 m .79483 .66439 L .81855 .65742 L p .707 .577 .707 r
F P
0 g
s
.81855 .65742 m .82148 .60408 L .79776 .61105 L p .707 .577 .707 r
F P
0 g
s
.67503 .65637 m .67797 .60303 L .6566 .59304 L p .707 .577 .707 r
F P
0 g
s
.67797 .60303 m .67503 .65637 L .70268 .66372 L p .707 .577 .707 r
F P
0 g
s
.294 .70573 m .29891 .74387 L .26784 .74797 L p .707 .577 .707 r
F P
0 g
s
.32312 .76238 m .3256 .78144 L .2983 .78542 L p .707 .577 .707 r
F P
0 g
s
.2983 .78542 m .29582 .76635 L .32312 .76238 L p .707 .577 .707 r
F P
0 g
s
.26784 .74797 m .26293 .70982 L .294 .70573 L p .707 .577 .707 r
F P
0 g
s
.26293 .70982 m .26784 .74797 L .23633 .75196 L p .707 .577 .707 r
F P
0 g
s
.23633 .75196 m .23143 .71381 L .26293 .70982 L p .707 .577 .707 r
F P
0 g
s
.23332 .77457 m .2358 .79364 L .20671 .79708 L p .707 .577 .707 r
F P
0 g
s
.20671 .79708 m .20424 .77802 L .23332 .77457 L p .707 .577 .707 r
F P
0 g
s
.73216 .74108 m .73707 .70874 L .70599 .70198 L p .707 .577 .707 r
F P
0 g
s
.73707 .70874 m .73216 .74108 L .76366 .74259 L p .707 .577 .707 r
F P
0 g
s
.76366 .74259 m .76857 .71025 L .73707 .70874 L p .707 .577 .707 r
F P
0 g
s
.5667 .24701 m .5667 .7489 L .52391 .74505 L p .707 .577 .707 r
F P
0 g
s
.52391 .74505 m .52391 .24316 L .5667 .24701 L p .707 .577 .707 r
F P
0 g
s
.43573 .74857 m .43573 .24668 L .47879 .24304 L p .707 .577 .707 r
F P
0 g
s
.43573 .24668 m .43573 .74857 L .39897 .75559 L p .707 .577 .707 r
F P
0 g
s
.70109 .73432 m .70599 .70198 L .67839 .69063 L p .707 .577 .707 r
F P
0 g
s
.70599 .70198 m .70109 .73432 L .73216 .74108 L p .707 .577 .707 r
F P
0 g
s
.82148 .60408 m .81855 .65742 L .83451 .6477 L p .707 .577 .707 r
F P
0 g
s
.83451 .6477 m .83745 .59436 L .82148 .60408 L p .707 .577 .707 r
F P
0 g
s
.76857 .71025 m .76366 .74259 L .79251 .7387 L p .707 .577 .707 r
F P
0 g
s
.79251 .7387 m .79742 .70636 L .76857 .71025 L p .707 .577 .707 r
F P
0 g
s
.29582 .76635 m .2983 .78542 L .26736 .78962 L p .707 .577 .707 r
F P
0 g
s
.26736 .78962 m .26488 .77055 L .29582 .76635 L p .707 .577 .707 r
F P
0 g
s
.26488 .77055 m .26736 .78962 L .2358 .79364 L p .707 .577 .707 r
F P
0 g
s
.2358 .79364 m .23332 .77457 L .26488 .77055 L p .707 .577 .707 r
F P
0 g
s
.65367 .64638 m .6566 .59304 L .64362 .58138 L p .707 .577 .707 r
F P
0 g
s
.6566 .59304 m .65367 .64638 L .67503 .65637 L p .707 .577 .707 r
F P
0 g
s
.67349 .72297 m .67839 .69063 L .65697 .6758 L p .707 .577 .707 r
F P
0 g
s
.67839 .69063 m .67349 .72297 L .70109 .73432 L p .707 .577 .707 r
F P
0 g
s
.52391 .24316 m .52391 .74505 L .47879 .74493 L p .707 .577 .707 r
F P
0 g
s
.47879 .74493 m .47879 .24304 L .52391 .24316 L p .707 .577 .707 r
F P
0 g
s
.47879 .24304 m .47879 .74493 L .43573 .74857 L p .707 .577 .707 r
F P
0 g
s
.73264 .78541 m .73512 .76935 L .70418 .76222 L p .707 .577 .707 r
F P
0 g
s
.73512 .76935 m .73264 .78541 L .7642 .78723 L p .707 .577 .707 r
F P
0 g
s
.7642 .78723 m .76668 .77117 L .73512 .76935 L p .707 .577 .707 r
F P
0 g
s
.79742 .70636 m .79251 .7387 L .81588 .72979 L p .707 .577 .707 r
F P
0 g
s
.81588 .72979 m .82079 .69745 L .79742 .70636 L p .707 .577 .707 r
F P
0 g
s
.7017 .77828 m .70418 .76222 L .67688 .75047 L p .707 .577 .707 r
F P
0 g
s
.70418 .76222 m .7017 .77828 L .73264 .78541 L p .707 .577 .707 r
F P
0 g
s
.76668 .77117 m .7642 .78723 L .79328 .78356 L p .707 .577 .707 r
F P
0 g
s
.79328 .78356 m .79576 .7675 L .76668 .77117 L p .707 .577 .707 r
F P
0 g
s
.83745 .59436 m .83451 .6477 L .84115 .63618 L p .707 .577 .707 r
F P
0 g
s
.84115 .63618 m .84408 .58284 L .83745 .59436 L p .707 .577 .707 r
F P
0 g
s
.67688 .75047 m .6744 .76653 L .7017 .77828 L p .707 .577 .707 r
F P
0 g
s
.64362 .58138 m .64068 .63472 L .65367 .64638 L p .707 .577 .707 r
F P
0 g
s
.6744 .76653 m .67688 .75047 L .6559 .73525 L p .707 .577 .707 r
F P
0 g
s
.65206 .70814 m .65697 .6758 L .64381 .65894 L p .707 .577 .707 r
F P
0 g
s
.65697 .6758 m .65206 .70814 L .67349 .72297 L p .707 .577 .707 r
F P
0 g
s
.79576 .7675 m .79328 .78356 L .81705 .77475 L p .707 .577 .707 r
F P
0 g
s
.81705 .77475 m .81953 .75869 L .79576 .7675 L p .707 .577 .707 r
F P
0 g
s
.82079 .69745 m .81588 .72979 L .83149 .71673 L p .707 .577 .707 r
F P
0 g
s
.83149 .71673 m .83639 .68439 L .82079 .69745 L p .707 .577 .707 r
F P
0 g
s
.6559 .73525 m .65342 .75131 L .6744 .76653 L p .707 .577 .707 r
F P
0 g
s
.65342 .75131 m .6559 .73525 L .64329 .71805 L p .707 .577 .707 r
F P
0 g
s
.64381 .65894 m .63891 .69128 L .65206 .70814 L p .707 .577 .707 r
F P
0 g
s
.81953 .75869 m .81705 .77475 L .83316 .76166 L p .707 .577 .707 r
F P
0 g
s
.83316 .76166 m .83564 .7456 L .81953 .75869 L p .707 .577 .707 r
F P
0 g
s
.63891 .69128 m .64381 .65894 L .64021 .6417 L p .707 .577 .707 r
F P
0 g
s
.64028 .5692 m .63735 .62254 L .64068 .63472 L p .707 .577 .707 r
F P
0 g
s
.84408 .58284 m .84115 .63618 L .83781 .624 L p .707 .577 .707 r
F P
0 g
s
.83781 .624 m .84074 .57066 L .84408 .58284 L p .707 .577 .707 r
F P
0 g
s
.64329 .71805 m .64081 .73411 L .65342 .75131 L p .707 .577 .707 r
F P
0 g
s
.83639 .68439 m .83149 .71673 L .8378 .7008 L p .707 .577 .707 r
F P
0 g
s
.8378 .7008 m .8427 .66846 L .83639 .68439 L p .707 .577 .707 r
F P
0 g
s
.63735 .62254 m .64028 .5692 L .64692 .55768 L p .707 .577 .707 r
F P
0 g
s
.64081 .73411 m .64329 .71805 L .64028 .70056 L p .707 .577 .707 r
F P
0 g
s
.64021 .6417 m .63531 .67404 L .63891 .69128 L p .707 .577 .707 r
F P
0 g
s
.83564 .7456 m .83316 .76166 L .84006 .74559 L p .707 .577 .707 r
F P
0 g
s
.84006 .74559 m .84254 .72953 L .83564 .7456 L p .707 .577 .707 r
F P
0 g
s
.63531 .67404 m .64021 .6417 L .64653 .62577 L p .707 .577 .707 r
F P
0 g
s
.64028 .70056 m .6378 .71662 L .64081 .73411 L p .707 .577 .707 r
F P
0 g
s
.64692 .55768 m .64398 .61103 L .63735 .62254 L p .707 .577 .707 r
F P
0 g
s
.84074 .57066 m .83781 .624 L .82483 .61234 L p .707 .577 .707 r
F P
0 g
s
.82483 .61234 m .82776 .559 L .84074 .57066 L p .707 .577 .707 r
F P
0 g
s
.8427 .66846 m .8378 .7008 L .8342 .68356 L p .707 .577 .707 r
F P
0 g
s
.8342 .68356 m .83911 .65122 L .8427 .66846 L p .707 .577 .707 r
F P
0 g
s
.64398 .61103 m .64692 .55768 L .66288 .54796 L p .707 .577 .707 r
F P
0 g
s
.6378 .71662 m .64028 .70056 L .64717 .68449 L p .707 .577 .707 r
F P
0 g
s
.38959 .61494 m .39638 .55903 L .36534 .55398 L p .707 .577 .707 r
F P
0 g
s
.39638 .55903 m .38959 .61494 L .42117 .61788 L p .707 .577 .707 r
F P
0 g
s
.42117 .61788 m .42796 .56196 L .39638 .55903 L p .707 .577 .707 r
F P
0 g
s
.64653 .62577 m .64162 .65811 L .63531 .67404 L p .707 .577 .707 r
F P
0 g
s
.84254 .72953 m .84006 .74559 L .83705 .7281 L p .707 .577 .707 r
F P
0 g
s
.83705 .7281 m .83953 .71204 L .84254 .72953 L p .707 .577 .707 r
F P
0 g
s
.42796 .56196 m .42117 .61788 L .4502 .6184 L p .707 .577 .707 r
F P
0 g
s
.4502 .6184 m .45699 .56249 L .42796 .56196 L p .707 .577 .707 r
F P
0 g
s
.35856 .60989 m .36534 .55398 L .33788 .5473 L p .707 .577 .707 r
F P
0 g
s
.36534 .55398 m .35856 .60989 L .38959 .61494 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64162 .65811 m .64653 .62577 L .66213 .61271 L p .707 .577 .707 r
F P
0 g
s
.64717 .68449 m .6447 .70055 L .6378 .71662 L p .707 .577 .707 r
F P
0 g
s
.82776 .559 m .82483 .61234 L .80346 .60235 L p .707 .577 .707 r
F P
0 g
s
.80346 .60235 m .8064 .54901 L .82776 .559 L p .707 .577 .707 r
F P
0 g
s
.83911 .65122 m .8342 .68356 L .82105 .6667 L p .707 .577 .707 r
F P
0 g
s
.82105 .6667 m .82595 .63436 L .83911 .65122 L p .707 .577 .707 r
F P
0 g
s
.66288 .54796 m .65995 .60131 L .64398 .61103 L p .707 .577 .707 r
F P
0 g
s
.45699 .56249 m .4502 .6184 L .47384 .61647 L p .707 .577 .707 r
F P
0 g
s
.47384 .61647 m .48062 .56056 L .45699 .56249 L p .707 .577 .707 r
F P
0 g
s
.33788 .5473 m .3311 .60321 L .35856 .60989 L p .707 .577 .707 r
F P
0 g
s
.65995 .60131 m .66288 .54796 L .6866 .54099 L p .707 .577 .707 r
F P
0 g
s
.38342 .66659 m .39453 .63014 L .36462 .62024 L p .707 .577 .707 r
F P
0 g
s
.39453 .63014 m .38342 .66659 L .41387 .67522 L p .707 .577 .707 r
F P
0 g
s
.41387 .67522 m .42498 .63877 L .39453 .63014 L p .707 .577 .707 r
F P
0 g
s
.3311 .60321 m .33788 .5473 L .31669 .53965 L p .707 .577 .707 r
F P
0 g
s
.42498 .63877 m .41387 .67522 L .44189 .68174 L p .707 .577 .707 r
F P
0 g
s
.44189 .68174 m .45299 .6453 L .42498 .63877 L p .707 .577 .707 r
F P
0 g
s
.36462 .62024 m .35351 .65669 L .38342 .66659 L p .707 .577 .707 r
F P
0 g
s
.35351 .65669 m .36462 .62024 L .33819 .61004 L p .707 .577 .707 r
F P
0 g
s
.6447 .70055 m .64717 .68449 L .66329 .6714 L p .707 .577 .707 r
F P
0 g
s
.66213 .61271 m .65723 .64505 L .64162 .65811 L p .707 .577 .707 r
F P
0 g
s
.83953 .71204 m .83705 .7281 L .82444 .7109 L p .707 .577 .707 r
F P
0 g
s
.82444 .7109 m .82692 .69484 L .83953 .71204 L p .707 .577 .707 r
F P
0 g
s
.33819 .61004 m .32708 .64649 L .35351 .65669 L p .707 .577 .707 r
F P
0 g
s
.31669 .53965 m .30991 .59556 L .3311 .60321 L p .707 .577 .707 r
F P
0 g
s
.65723 .64505 m .66213 .61271 L .6855 .6038 L p .707 .577 .707 r
F P
0 g
s
.8064 .54901 m .80346 .60235 L .77581 .595 L p .707 .577 .707 r
F P
0 g
s
.77581 .595 m .77875 .54166 L .8064 .54901 L p .707 .577 .707 r
F P
0 g
s
.38692 .70774 m .39256 .68955 L .36284 .67944 L p .707 .577 .707 r
F P
0 g
s
.39256 .68955 m .38692 .70774 L .41738 .71663 L p .707 .577 .707 r
F P
0 g
s
.41738 .71663 m .42302 .69844 L .39256 .68955 L p .707 .577 .707 r
F P
0 g
s
.66329 .6714 m .66081 .68746 L .6447 .70055 L p .707 .577 .707 r
F P
0 g
s
.45299 .6453 m .44189 .68174 L .46472 .68551 L p .707 .577 .707 r
F P
0 g
s
.46472 .68551 m .47583 .64907 L .45299 .6453 L p .707 .577 .707 r
F P
0 g
s
.82595 .63436 m .82105 .6667 L .79962 .65187 L p .707 .577 .707 r
F P
0 g
s
.79962 .65187 m .80452 .61953 L .82595 .63436 L p .707 .577 .707 r
F P
0 g
s
.48062 .56056 m .47384 .61647 L .48977 .61227 L p .707 .577 .707 r
F P
0 g
s
.48977 .61227 m .49655 .55635 L .48062 .56056 L p .707 .577 .707 r
F P
0 g
s
.68367 .59433 m .6866 .54099 L .71577 .53744 L p .707 .577 .707 r
F P
0 g
s
.6866 .54099 m .68367 .59433 L .65995 .60131 L p .707 .577 .707 r
F P
0 g
s
.36284 .67944 m .35719 .69764 L .38692 .70774 L p .707 .577 .707 r
F P
0 g
s
.32708 .64649 m .33819 .61004 L .31781 .60054 L p .707 .577 .707 r
F P
0 g
s
.42302 .69844 m .41738 .71663 L .44559 .72343 L p .707 .577 .707 r
F P
0 g
s
.44559 .72343 m .45124 .70524 L .42302 .69844 L p .707 .577 .707 r
F P
0 g
s
.35719 .69764 m .36284 .67944 L .33676 .66911 L p .707 .577 .707 r
F P
0 g
s
.30991 .59556 m .31669 .53965 L .30384 .53178 L p .707 .577 .707 r
F P
0 g
s
.33676 .66911 m .33111 .6873 L .35719 .69764 L p .707 .577 .707 r
F P
0 g
s
.31781 .60054 m .3067 .63699 L .32708 .64649 L p .707 .577 .707 r
F P
0 g
s
.77875 .54166 m .77581 .595 L .74459 .59102 L p .707 .577 .707 r
F P
0 g
s
.74459 .59102 m .74752 .53768 L .77875 .54166 L p .707 .577 .707 r
F P
0 g
s
.66081 .68746 m .66329 .6714 L .68705 .66259 L p .707 .577 .707 r
F P
0 g
s
.71284 .59079 m .71577 .53744 L .74752 .53768 L p .707 .577 .707 r
F P
0 g
s
.71577 .53744 m .71284 .59079 L .68367 .59433 L p .707 .577 .707 r
F P
0 g
s
.6806 .63614 m .6855 .6038 L .71435 .5999 L p .707 .577 .707 r
F P
0 g
s
.6855 .6038 m .6806 .63614 L .65723 .64505 L p .707 .577 .707 r
F P
0 g
s
.82692 .69484 m .82444 .7109 L .80346 .69568 L p .707 .577 .707 r
F P
0 g
s
.80346 .69568 m .80594 .67962 L .82692 .69484 L p .707 .577 .707 r
F P
0 g
s
.45124 .70524 m .44559 .72343 L .46879 .72747 L p .707 .577 .707 r
F P
0 g
s
.46879 .72747 m .47444 .70928 L .45124 .70524 L p .707 .577 .707 r
F P
0 g
s
.74752 .53768 m .74459 .59102 L .71284 .59079 L p .707 .577 .707 r
F P
0 g
s
.30384 .53178 m .29706 .58769 L .30991 .59556 L p .707 .577 .707 r
F P
0 g
s
.80452 .61953 m .79962 .65187 L .77202 .64052 L p .707 .577 .707 r
F P
0 g
s
.77202 .64052 m .77692 .60817 L .80452 .61953 L p .707 .577 .707 r
F P
0 g
s
.33111 .6873 m .33676 .66911 L .31687 .65956 L p .707 .577 .707 r
F P
0 g
s
.47583 .64907 m .46472 .68551 L .48014 .68616 L p .707 .577 .707 r
F P
0 g
s
.48014 .68616 m .49125 .64972 L .47583 .64907 L p .707 .577 .707 r
F P
0 g
s
.31687 .65956 m .31123 .67775 L .33111 .6873 L p .707 .577 .707 r
F P
0 g
s
.68705 .66259 m .68458 .67865 L .66081 .68746 L p .707 .577 .707 r
F P
0 g
s
.3067 .63699 m .31781 .60054 L .30549 .59267 L p .707 .577 .707 r
F P
0 g
s
.49655 .55635 m .48977 .61227 L .49644 .60621 L p .707 .577 .707 r
F P
0 g
s
.49644 .60621 m .50322 .5503 L .49655 .55635 L p .707 .577 .707 r
F P
0 g
s
.70945 .63225 m .71435 .5999 L .74585 .60141 L p .707 .577 .707 r
F P
0 g
s
.71435 .5999 m .70945 .63225 L .6806 .63614 L p .707 .577 .707 r
F P
0 g
s
.30549 .59267 m .29438 .62912 L .3067 .63699 L p .707 .577 .707 r
F P
0 g
s
.77692 .60817 m .77202 .64052 L .74095 .63376 L p .707 .577 .707 r
F P
0 g
s
.74095 .63376 m .74585 .60141 L .77692 .60817 L p .707 .577 .707 r
F P
0 g
s
.68458 .67865 m .68705 .66259 L .71614 .65892 L p .707 .577 .707 r
F P
0 g
s
.29706 .58769 m .30384 .53178 L .30059 .52445 L p .707 .577 .707 r
F P
0 g
s
.74585 .60141 m .74095 .63376 L .70945 .63225 L p .707 .577 .707 r
F P
0 g
s
.80594 .67962 m .80346 .69568 L .77616 .68393 L p .707 .577 .707 r
F P
0 g
s
.77616 .68393 m .77864 .66787 L .80594 .67962 L p .707 .577 .707 r
F P
0 g
s
.47444 .70928 m .46879 .72747 L .48472 .72837 L p .707 .577 .707 r
F P
0 g
s
.48472 .72837 m .49036 .71018 L .47444 .70928 L p .707 .577 .707 r
F P
0 g
s
.71614 .65892 m .71366 .67498 L .68458 .67865 L p .707 .577 .707 r
F P
0 g
s
.31123 .67775 m .31687 .65956 L .30513 .65173 L p .707 .577 .707 r
F P
0 g
s
.71366 .67498 m .71614 .65892 L .7477 .66074 L p .707 .577 .707 r
F P
0 g
s
.30513 .65173 m .29948 .66992 L .31123 .67775 L p .707 .577 .707 r
F P
0 g
s
.30059 .52445 m .29381 .58037 L .29706 .58769 L p .707 .577 .707 r
F P
0 g
s
.77864 .66787 m .77616 .68393 L .74522 .6768 L p .707 .577 .707 r
F P
0 g
s
.74522 .6768 m .7477 .66074 L .77864 .66787 L p .707 .577 .707 r
F P
0 g
s
.7477 .66074 m .74522 .6768 L .71366 .67498 L p .707 .577 .707 r
F P
0 g
s
.49125 .64972 m .48014 .68616 L .48664 .68363 L p .707 .577 .707 r
F P
0 g
s
.48664 .68363 m .49775 .64718 L .49125 .64972 L p .707 .577 .707 r
F P
0 g
s
.29438 .62912 m .30549 .59267 L .30242 .5872 L p .707 .577 .707 r
F P
0 g
s
.30242 .5872 m .29132 .62365 L .29438 .62912 L p .707 .577 .707 r
F P
0 g
s
.50322 .5503 m .49644 .60621 L .49319 .59889 L p .707 .577 .707 r
F P
0 g
s
.49319 .59889 m .49997 .54297 L .50322 .5503 L p .707 .577 .707 r
F P
0 g
s
.29381 .58037 m .30059 .52445 L .30726 .5184 L p .707 .577 .707 r
F P
0 g
s
.49036 .71018 m .48472 .72837 L .4918 .72603 L p .707 .577 .707 r
F P
0 g
s
.4918 .72603 m .49745 .70784 L .49036 .71018 L p .707 .577 .707 r
F P
0 g
s
.29948 .66992 m .30513 .65173 L .30268 .64638 L p .707 .577 .707 r
F P
0 g
s
.30268 .64638 m .29704 .66457 L .29948 .66992 L p .707 .577 .707 r
F P
0 g
s
.30726 .5184 m .30048 .57431 L .29381 .58037 L p .707 .577 .707 r
F P
0 g
s
.49775 .64718 m .48664 .68363 L .48358 .67816 L p .707 .577 .707 r
F P
0 g
s
.48358 .67816 m .49469 .64171 L .49775 .64718 L p .707 .577 .707 r
F P
0 g
s
.29132 .62365 m .30242 .5872 L .30892 .58467 L p .707 .577 .707 r
F P
0 g
s
.49997 .54297 m .49319 .59889 L .48034 .59101 L p .707 .577 .707 r
F P
0 g
s
.48034 .59101 m .48712 .5351 L .49997 .54297 L p .707 .577 .707 r
F P
0 g
s
.30892 .58467 m .29781 .62112 L .29132 .62365 L p .707 .577 .707 r
F P
0 g
s
.30048 .57431 m .30726 .5184 L .32319 .51419 L p .707 .577 .707 r
F P
0 g
s
.49745 .70784 m .4918 .72603 L .48935 .72068 L p .707 .577 .707 r
F P
0 g
s
.48935 .72068 m .495 .70249 L .49745 .70784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29704 .66457 m .30268 .64638 L .30977 .64404 L p .707 .577 .707 r
F P
0 g
s
.30977 .64404 m .30412 .66223 L .29704 .66457 L p .707 .577 .707 r
F P
0 g
s
.32319 .51419 m .31641 .57011 L .30048 .57431 L p .707 .577 .707 r
F P
0 g
s
.49469 .64171 m .48358 .67816 L .47125 .67029 L p .707 .577 .707 r
F P
0 g
s
.47125 .67029 m .48236 .63384 L .49469 .64171 L p .707 .577 .707 r
F P
0 g
s
.29781 .62112 m .30892 .58467 L .32434 .58532 L p .707 .577 .707 r
F P
0 g
s
.48712 .5351 m .48034 .59101 L .45915 .58337 L p .707 .577 .707 r
F P
0 g
s
.45915 .58337 m .46593 .52745 L .48712 .5351 L p .707 .577 .707 r
F P
0 g
s
.32434 .58532 m .31323 .62177 L .29781 .62112 L p .707 .577 .707 r
F P
0 g
s
.31641 .57011 m .32319 .51419 L .34683 .51226 L p .707 .577 .707 r
F P
0 g
s
.495 .70249 m .48935 .72068 L .47761 .71285 L p .707 .577 .707 r
F P
0 g
s
.47761 .71285 m .48326 .69466 L .495 .70249 L p .707 .577 .707 r
F P
0 g
s
.30412 .66223 m .30977 .64404 L .32569 .64493 L p .707 .577 .707 r
F P
0 g
s
.34683 .51226 m .34004 .56818 L .31641 .57011 L p .707 .577 .707 r
F P
0 g
s
.32569 .64493 m .32005 .66312 L .30412 .66223 L p .707 .577 .707 r
F P
0 g
s
.46593 .52745 m .45915 .58337 L .43169 .57669 L p .707 .577 .707 r
F P
0 g
s
.43169 .57669 m .43847 .52077 L .46593 .52745 L p .707 .577 .707 r
F P
0 g
s
.48236 .63384 m .47125 .67029 L .45088 .66079 L p .707 .577 .707 r
F P
0 g
s
.45088 .66079 m .46199 .62434 L .48236 .63384 L p .707 .577 .707 r
F P
0 g
s
.31323 .62177 m .32434 .58532 L .34718 .58909 L p .707 .577 .707 r
F P
0 g
s
.34004 .56818 m .34683 .51226 L .37586 .51279 L p .707 .577 .707 r
F P
0 g
s
.34718 .58909 m .33607 .62554 L .31323 .62177 L p .707 .577 .707 r
F P
0 g
s
.43847 .52077 m .43169 .57669 L .40065 .57164 L p .707 .577 .707 r
F P
0 g
s
.40065 .57164 m .40744 .51572 L .43847 .52077 L p .707 .577 .707 r
F P
0 g
s
.48326 .69466 m .47761 .71285 L .45773 .7033 L p .707 .577 .707 r
F P
0 g
s
.45773 .7033 m .46338 .6851 L .48326 .69466 L p .707 .577 .707 r
F P
0 g
s
.37586 .51279 m .36907 .5687 L .34004 .56818 L p .707 .577 .707 r
F P
0 g
s
.36907 .5687 m .37586 .51279 L .40744 .51572 L p .707 .577 .707 r
F P
0 g
s
.40744 .51572 m .40065 .57164 L .36907 .5687 L p .707 .577 .707 r
F P
0 g
s
.32005 .66312 m .32569 .64493 L .3489 .64898 L p .707 .577 .707 r
F P
0 g
s
.46199 .62434 m .45088 .66079 L .42444 .65059 L p .707 .577 .707 r
F P
0 g
s
.42444 .65059 m .43555 .61414 L .46199 .62434 L p .707 .577 .707 r
F P
0 g
s
.3489 .64898 m .34325 .66717 L .32005 .66312 L p .707 .577 .707 r
F P
0 g
s
.33607 .62554 m .34718 .58909 L .37519 .59561 L p .707 .577 .707 r
F P
0 g
s
.37519 .59561 m .36408 .63206 L .33607 .62554 L p .707 .577 .707 r
F P
0 g
s
.43555 .61414 m .42444 .65059 L .39453 .64069 L p .707 .577 .707 r
F P
0 g
s
.39453 .64069 m .40564 .60424 L .43555 .61414 L p .707 .577 .707 r
F P
0 g
s
.46338 .6851 m .45773 .7033 L .43165 .69296 L p .707 .577 .707 r
F P
0 g
s
.43165 .69296 m .4373 .67477 L .46338 .6851 L p .707 .577 .707 r
F P
0 g
s
.36408 .63206 m .37519 .59561 L .40564 .60424 L p .707 .577 .707 r
F P
0 g
s
.34325 .66717 m .3489 .64898 L .37711 .65578 L p .707 .577 .707 r
F P
0 g
s
.40564 .60424 m .39453 .64069 L .36408 .63206 L p .707 .577 .707 r
F P
0 g
s
.37711 .65578 m .37146 .67397 L .34325 .66717 L p .707 .577 .707 r
F P
0 g
s
.4373 .67477 m .43165 .69296 L .40192 .68286 L p .707 .577 .707 r
F P
0 g
s
.40192 .68286 m .40757 .66466 L .4373 .67477 L p .707 .577 .707 r
F P
0 g
s
.37146 .67397 m .37711 .65578 L .40757 .66466 L p .707 .577 .707 r
F P
0 g
s
.40757 .66466 m .40192 .68286 L .37146 .67397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6@00PWoo001iOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001iOol007Aoo`D0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00D007Aoo`00L7oo1000
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001OOol@0002FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001JOol5
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001GOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001EOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00004Goo3`00AWoo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH01000@Woo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF00001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF1000?Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000Eoo`8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0000=oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@003Ioo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002000cOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80035oo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00<7oo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP80031o
o`00Dgoo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0002moo`00Dgoo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF
001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0015YF00<005YFFUH00eYF
00<005YFFUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YF
FUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000EJ
EP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001COol01000FUIJEUYF2@001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00L005YFFUIJ
EP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`@000AJEP03001JEUYF00D0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0015YF00<005YFFUH015YF00<0
05YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00P001UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000AOol60006
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0`001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH0
0`00FUH000030006Ool8000?Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP80009JEPP000AJEP04001JEUYFFUH9000:Ool30005FUH01000
FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH000020007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF008000EJEP<000QJ
EP03001JEUYF00EJEP03001JEUYF009JEPD000Moo`<000=JEP04001JEUYFFUH2000]Ool005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYF001JEP0200000eYF001JEP02FUH20002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH80003FUH200000eYF001JEP02FUH2000]Ool003iooaH00003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009J
EP03001JEUYF00AJEP03001JEUYF00<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF008000=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH20003FUH2000]Ool003Qoo`H000=JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000/000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000IJEP03001JEP00009JEP8002eoo`00=7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`001UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YF
FUH01000;Goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004
FUH01000FUIJEUYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000UYF00@005YFFUIJEP<002eoo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH010000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003
FUH3000]Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001EYF00<0
05YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF009JEPH0009JEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0002FUH01000FUIJEUYF0P001eYF00<005YF
FUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH0000002io
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF0`001eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF008000=JEP06001JEP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF10001UYF00<005YFFUH015YF00<005YF00000P00;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000090005FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000=JEP8000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH01000FUH00000;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPH000QJEP03001J
EUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YF
FUH002moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF00000`001EYF00<005YF
FUH01UYF0`001eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH00`00Oomo
o`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000UJEP03001J
EUYF00@0009JEP03001JEUYF00AJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001J
EUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF0`00
1EYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUH005YF00001UYF00@005YFFUIJEP@0009JEQ00009JEP03001JEUYF00EJEP03001JEP0000<0
009JEP03001JEUYF009JEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF008000=JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@0017oo0`0015YF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEUYF1P001eYF00<005YFFUH01EYF1@001eYF00<005YFFUH00UYF0`0015YF
0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=JEP00
FUH00eYF1@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`002goo00<005YFFUH0
0UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH?0003FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00FUIJEP07FUH00`00FUIJEP04
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01`00FUH005YF001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000Yoo`06001JEUYF001JEP00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP03FUH?0009FUH00`00FUIJEP02FUH30006FUH00`00FUH0000200000eYF001JEP040008FUH00`00
FUIJEP04FUH50006FUH3000015YF001JEP0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YF001JEP00009JEP04001JEP000005FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP07FUH00`00FUIJEP020009Ool01@00FUH005YF0000;Goo000]Ool00`00FUH00003FUH00`00FUH0
00030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0`000eYF00<005YF00000P0015YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF
00800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0003FUH200000eYF001JEP03FUH70007Ool70006FUH00`00FUIJEP03FUH20007Ool01@00FUH005YF
0000;Goo000]Ool00`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP05FUH40004FUH300000eYF001JEP07FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000UYF00@005YFFUH000=JEP80009JEP03001JEUYF008000ioo`@0009J
EP03001JEUYF00EJEP8000Ioo`800003FUH007oo02aoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0008FUH0
1000FUH000000eYF1P001eYF00<005YFFUH015YF10000UYF00<005YF00002EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH01000FUH000001EYF00@005YF
0000019oo`@000MJEP<000Eoo`03001JEP0002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<000IJEP03
001JEUYF009JEPP00003FUH0000000EJEP03001JEUYF00EJEPL000YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP000eYF0P0000=JEP00000015YF00@005YF0000
01Ioo`8000AJEP05001JEUYFFUH00003Ool3000^Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP05FUH50003FUH300000eYF001JEP07FUH00`00FUIJEP03000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP03FUH20002FUH01000
FUIJEP0067oo0`0000=JEP00FUH00eYF0`0000=JEP000000;Woo000^Ool200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005Ool200000eYF
001JEP08FUH70003FUH30006FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YF00000P000UYF00<007oo
Ool06Goo0P001UYF00@005YF000002ioo`00<7oo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001goo2P001eYF00<005YFFUH01EYF100000=JEP0000000`000UYF00<005YF
FUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF
00<000IJEP04001JEUYFFUH4000MOol00`00FUIJEP03FUH4000^Ool003AooaT000Uoo`T0009JEP06
001JEUYFFUH005YF0P001EYF00<005YFFUH01eYF00<005YF00000`000UYF0`001EYF00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH0
00IJEP03001JEUYF00AJEP@001Uoo`<000AJEP800003FUH007oo02eoo`00CGoo2`000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP<00003FUH005YF00QJEP03001JEUYF00AJEPL000=JEP05001J
EUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020000
0eYF00000006FUH00`00FUIJEP05FUH00`00FUIJEP04000@Ool50003FUH200001EYF001JEUYF0000
;goo0014Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH010001eYF00<005YFFUH01UYF00<005YFFUH01@0015YF0P001UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF40000eYF00<005YFFUH00eYF0`000UYF00<007ooOol0;Goo000lOol:0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF
10000UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF00001UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000eYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000eYF00<0
07ooOol0;7oo000eOol90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH0
15YF00D005YF000005YF008000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000EJEP04001JEUYF0008FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<007ooOol0;7oo000]Ool90003FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P001UYF0`001eYF00<005YF
FUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo02ao
o`00;7oo1@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00=JEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00<000IJEP<000IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEP00001oo`0200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50002FUH00`00FUH0
0008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF008000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP80
00=oo`800003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00@005YFFUIJEP<00003FUH005YF
00MJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`03001JEP0002eoo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH90003FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001Woo00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUIJEP80009JEP8000=JEP800003Ool0000000800004FUH007ooOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0000027oo00<005YF0000;Goo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70005Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEPD000Aoo`80
0004FUH000000005Ool70004FUH00`00FUIJEP02FUH5000;Ool00`00Oomoo`0/Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP04FUHI0006FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03001oogoo009oo`04001JEUYF0002FUH00`00
Oomoo`0:Ool9000?Ool2000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF009JEPT001Aoo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH90005FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH80008FUH00`00FUIJEP04FUH01000FUIJEUYF100015YF0P0000=oo`00
FUH00UYF00@005YFFUH002Aoo`8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF2@007Goo00D005YFFUIJEP0000MJEP03001JEUYF00D0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00<000EJEP03001JEUYF00AJEP05001JEUYFFUH00002
Ool00`00FUIJEP04FUH20003FUH01@00FUIJEUYF00008Goo0`00;goo000^Ool20004FUH01000FUIJ
EUYF1`008goo10000eYF00<005YFFUH015YF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF100000=JEP00FUH01EYF00D005YFFUIJEP0000=oo`8000AJEP04
001JEP000002FUH01000FUIJEP007goo0P0000=JEP000000;goo000^Ool20002FUH6000MOolA0003
FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH30005FUH01000FUIJEUYF1`000UYF00<005YFFUH00UYF0`0000=JEP00Ool07Woo00D0
05YFFUIJEP00031oo`00;Woo100077oo1`000eYF1`000UYF00D005YFFUIJEP0000=JEP03001JEP00
0080009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00@00003FUH005YF009JEP03001JEUYF00=JEP@000MJEP<001aoo`<000=J
EP03001oogoo02ioo`00BWoo10000UYF00<005YF00001@000eYF00<005YFFUH00eYF00D005YFFUIJ
EP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP03001JEP0000QJEP03001J
EP0000<001Ioo`80009JEP04001JEUYF000aOol004=oo`L000AJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH70009Ool60004FUH00`00FUH0000bOol003]oo`P0
00AJEPL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEP00FUH00007FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0015YF00<005YFFUH00eYF0P00<goo000eOol60003FUH90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH030000UYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00=7oo000`Ool?0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EUYF00AJEP<0009JEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
;7oo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`001Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH0
0`00FUIJEP06FUH40003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF
00<007oo00000P001Woo4000?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH9000DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP80009oo`<005Eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH00UYF2@007Woo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0005FUH01000FUIJ
EUYF0P000goo00@005YFFUH005Eoo`00;Goo00<005YF000015YF00@005YFFUIJEPL002Qoo`<000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000MJEP<000Eoo`04001JEUYF001EOol002eoo`/0035oo`8000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP<000MJEP8000Ioo`80009JEP03001oogoo05=oo`00Jgoo0P000eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF0P001Woo0P0000AJEP00FUH005Ioo`00KGoo0P0000=JEP00FUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00000P001goo00<005YFFUH00UYF0P00EWoo001_Ool40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH50006FUH30009Ool00`00FUIJEP03FUH0
0`00Oomoo`1EOol007=oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00D00003FUH0000000<000=JEP8000Yoo`<000EJEP03001oogoo05Eoo`00NGoo20001UYF
00<005YFFUH02UYF00<005YFFUH015YF20001UYF20002goo00D005YFFUIJEP0000=JEP03001oogoo
05Ioo`00PGoo6`001UYF00<005YFFUH015YF1@0037oo0P0015YF00@005YFFUH005Uoo`00Sgoo00<0
05YF00000UYF1@000eYF00<005YFFUH015YF00<005YFFUH01`0037oo00<005YFFUH01EYF0P00FWoo
002>Ool01000FUIJEP000UYF00<007ooOol00Woo3@004Goo0`001eYF00<007ooOol0FGoo002>Ool0
1000FUIJEUYF0P008Goo0P000UYF00<005YFFUH00eYF0P00G7oo002>Ool01@00FUIJEUYF000087oo
0P001EYF00<005YFFUH00P00GWoo002?Ool00`00FUH0000NOol30007FUH3001POol008moo`03001J
EP0001]oo`<00003FUH005YF00MJEP03001oogoo061oo`00Sgoo0`0067oo0`0015YF00<005YFFUH0
15YF0P00Hgoo002@Ool01000FUH0000047oo1P0025YF00@005YFFUIJEP8006Eoo`00T7oo00@005YF
001JEP<000Eoo`P000AJEP03001JEUYF00MJEP04001JEP00001WOol0095oo`03001JEP0000=JEPD0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP<006Uoo`00TGoo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00K7oo002BOol30004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUH00002001_Ool009Aoo`<0009JEP03001JEUYF00EJEP03001JEUYF009JEPD0
079oo`00Ugoo3`00Mgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59934 .75469 m .59256 .70035 L .56152 .7017 L p .707 .577 .707 r
F P
0 g
s
.59256 .70035 m .59934 .75469 L .63092 .7501 L p .707 .577 .707 r
F P
0 g
s
.63092 .7501 m .62414 .69577 L .59256 .70035 L p .707 .577 .707 r
F P
0 g
s
.62414 .69577 m .63092 .7501 L .65995 .74274 L p .707 .577 .707 r
F P
0 g
s
.65995 .74274 m .65317 .6884 L .62414 .69577 L p .707 .577 .707 r
F P
0 g
s
.56831 .75604 m .56152 .7017 L .53407 .69969 L p .707 .577 .707 r
F P
0 g
s
.56152 .7017 m .56831 .75604 L .59934 .75469 L p .707 .577 .707 r
F P
0 g
s
.65317 .6884 m .65995 .74274 L .68359 .73331 L p .707 .577 .707 r
F P
0 g
s
.68359 .73331 m .67681 .67897 L .65317 .6884 L p .707 .577 .707 r
F P
0 g
s
.54085 .75403 m .53407 .69969 L .51288 .69452 L p .707 .577 .707 r
F P
0 g
s
.53407 .69969 m .54085 .75403 L .56831 .75604 L p .707 .577 .707 r
F P
0 g
s
.63591 .81217 m .6248 .77824 L .59435 .78795 L p .707 .577 .707 r
F P
0 g
s
.6248 .77824 m .63591 .81217 L .66393 .79937 L p .707 .577 .707 r
F P
0 g
s
.66393 .79937 m .65282 .76545 L .6248 .77824 L p .707 .577 .707 r
F P
0 g
s
.60546 .82187 m .59435 .78795 L .56445 .79362 L p .707 .577 .707 r
F P
0 g
s
.59435 .78795 m .60546 .82187 L .63591 .81217 L p .707 .577 .707 r
F P
0 g
s
.67681 .67897 m .68359 .73331 L .69952 .72274 L p .707 .577 .707 r
F P
0 g
s
.69952 .72274 m .69274 .66841 L .67681 .67897 L p .707 .577 .707 r
F P
0 g
s
.65282 .76545 m .66393 .79937 L .68676 .78475 L p .707 .577 .707 r
F P
0 g
s
.68676 .78475 m .67565 .75082 L .65282 .76545 L p .707 .577 .707 r
F P
0 g
s
.57556 .82755 m .56445 .79362 L .53801 .7947 L p .707 .577 .707 r
F P
0 g
s
.56445 .79362 m .57556 .82755 L .60546 .82187 L p .707 .577 .707 r
F P
0 g
s
.62853 .85558 m .62289 .83863 L .59243 .84825 L p .707 .577 .707 r
F P
0 g
s
.62289 .83863 m .62853 .85558 L .65675 .84283 L p .707 .577 .707 r
F P
0 g
s
.65675 .84283 m .6511 .82588 L .62289 .83863 L p .707 .577 .707 r
F P
0 g
s
.51288 .69452 m .51966 .74885 L .54085 .75403 L p .707 .577 .707 r
F P
0 g
s
.59807 .8652 m .59243 .84825 L .5627 .85379 L p .707 .577 .707 r
F P
0 g
s
.59243 .84825 m .59807 .8652 L .62853 .85558 L p .707 .577 .707 r
F P
0 g
s
.51966 .74885 m .51288 .69452 L .50003 .68668 L p .707 .577 .707 r
F P
0 g
s
.6511 .82588 m .65675 .84283 L .67995 .82819 L p .707 .577 .707 r
F P
0 g
s
.67995 .82819 m .6743 .81125 L .6511 .82588 L p .707 .577 .707 r
F P
0 g
s
.53801 .7947 m .54912 .82863 L .57556 .82755 L p .707 .577 .707 r
F P
0 g
s
.5627 .85379 m .56835 .87074 L .59807 .8652 L p .707 .577 .707 r
F P
0 g
s
.67565 .75082 m .68676 .78475 L .70218 .76972 L p .707 .577 .707 r
F P
0 g
s
.70218 .76972 m .69107 .7358 L .67565 .75082 L p .707 .577 .707 r
F P
0 g
s
.56835 .87074 m .5627 .85379 L .53662 .85471 L p .707 .577 .707 r
F P
0 g
s
.54912 .82863 m .53801 .7947 L .51763 .79108 L p .707 .577 .707 r
F P
0 g
s
.69274 .66841 m .69952 .72274 L .70619 .71207 L p .707 .577 .707 r
F P
0 g
s
.70619 .71207 m .6994 .65774 L .69274 .66841 L p .707 .577 .707 r
F P
0 g
s
.53662 .85471 m .54227 .87166 L .56835 .87074 L p .707 .577 .707 r
F P
0 g
s
.50003 .68668 m .50681 .74102 L .51966 .74885 L p .707 .577 .707 r
F P
0 g
s
.6743 .81125 m .67995 .82819 L .69587 .8131 L p .707 .577 .707 r
F P
0 g
s
.69587 .8131 m .69023 .79616 L .6743 .81125 L p .707 .577 .707 r
F P
0 g
s
.51763 .79108 m .52874 .82501 L .54912 .82863 L p .707 .577 .707 r
F P
0 g
s
.54227 .87166 m .53662 .85471 L .51674 .85093 L p .707 .577 .707 r
F P
0 g
s
.69107 .7358 m .70218 .76972 L .70868 .75576 L p .707 .577 .707 r
F P
0 g
s
.70868 .75576 m .69757 .72184 L .69107 .7358 L p .707 .577 .707 r
F P
0 g
s
.50681 .74102 m .50003 .68668 L .49678 .67695 L p .707 .577 .707 r
F P
0 g
s
.52874 .82501 m .51763 .79108 L .50531 .78312 L p .707 .577 .707 r
F P
0 g
s
.51674 .85093 m .52238 .86788 L .54227 .87166 L p .707 .577 .707 r
F P
0 g
s
.6994 .65774 m .70619 .71207 L .70294 .70234 L p .707 .577 .707 r
F P
0 g
s
.70294 .70234 m .69615 .64801 L .6994 .65774 L p .707 .577 .707 r
F P
0 g
s
.69023 .79616 m .69587 .8131 L .70296 .79904 L p .707 .577 .707 r
F P
0 g
s
.70296 .79904 m .69731 .78209 L .69023 .79616 L p .707 .577 .707 r
F P
0 g
s
.50531 .78312 m .51642 .81705 L .52874 .82501 L p .707 .577 .707 r
F P
0 g
s
.49678 .67695 m .50356 .73129 L .50681 .74102 L p .707 .577 .707 r
F P
0 g
s
.52238 .86788 m .51674 .85093 L .505 .84281 L p .707 .577 .707 r
F P
0 g
s
.69757 .72184 m .70868 .75576 L .70562 .74424 L p .707 .577 .707 r
F P
0 g
s
.70562 .74424 m .69451 .71031 L .69757 .72184 L p .707 .577 .707 r
F P
0 g
s
.51023 .72062 m .50344 .66628 L .51938 .65572 L p .707 .577 .707 r
F P
0 g
s
.50875 .75764 m .51986 .79157 L .51336 .80552 L p .707 .577 .707 r
F P
0 g
s
.51938 .65572 m .52616 .71005 L .51023 .72062 L p .707 .577 .707 r
F P
0 g
s
.52616 .71005 m .51938 .65572 L .54301 .64629 L p .707 .577 .707 r
F P
0 g
s
.51986 .79157 m .50875 .75764 L .52417 .74261 L p .707 .577 .707 r
F P
0 g
s
.52417 .74261 m .53528 .77654 L .51986 .79157 L p .707 .577 .707 r
F P
0 g
s
.51642 .81705 m .50531 .78312 L .50225 .7716 L p .707 .577 .707 r
F P
0 g
s
.50225 .7716 m .51336 .80552 L .51642 .81705 L p .707 .577 .707 r
F P
0 g
s
.51528 .83402 m .50963 .81708 L .52556 .80199 L p .707 .577 .707 r
F P
0 g
s
.52556 .80199 m .5312 .81893 L .51528 .83402 L p .707 .577 .707 r
F P
0 g
s
.52121 .8215 m .52121 .31961 L .47608 .3195 L p .707 .577 .707 r
F P
0 g
s
.54301 .64629 m .5498 .70062 L .52616 .71005 L p .707 .577 .707 r
F P
0 g
s
.5498 .70062 m .54301 .64629 L .57204 .63892 L p .707 .577 .707 r
F P
0 g
s
.53528 .77654 m .52417 .74261 L .547 .72799 L p .707 .577 .707 r
F P
0 g
s
.57204 .63892 m .57882 .69326 L .5498 .70062 L p .707 .577 .707 r
F P
0 g
s
.547 .72799 m .55811 .76191 L .53528 .77654 L p .707 .577 .707 r
F P
0 g
s
.55811 .76191 m .547 .72799 L .57502 .71519 L p .707 .577 .707 r
F P
0 g
s
.5312 .81893 m .52556 .80199 L .54876 .78735 L p .707 .577 .707 r
F P
0 g
s
.54876 .78735 m .55441 .8043 L .5312 .81893 L p .707 .577 .707 r
F P
0 g
s
.57502 .71519 m .58613 .74912 L .55811 .76191 L p .707 .577 .707 r
F P
0 g
s
.55441 .8043 m .54876 .78735 L .57697 .7746 L p .707 .577 .707 r
F P
0 g
s
.57697 .7746 m .58262 .79155 L .55441 .8043 L p .707 .577 .707 r
F P
0 g
s
.52121 .31961 m .52121 .8215 L .56426 .81787 L p .707 .577 .707 r
F P
0 g
s
.56426 .81787 m .56426 .31598 L .52121 .31961 L p .707 .577 .707 r
F P
0 g
s
.47608 .82139 m .47608 .3195 L .4333 .31565 L p .707 .577 .707 r
F P
0 g
s
.50356 .73129 m .49678 .67695 L .50344 .66628 L p .707 .577 .707 r
F P
0 g
s
.50344 .66628 m .51023 .72062 L .50356 .73129 L p .707 .577 .707 r
F P
0 g
s
.51336 .80552 m .50225 .7716 L .50875 .75764 L p .707 .577 .707 r
F P
0 g
s
.505 .84281 m .51064 .85975 L .52238 .86788 L p .707 .577 .707 r
F P
0 g
s
.5082 .84809 m .50255 .83114 L .50963 .81708 L p .707 .577 .707 r
F P
0 g
s
.50963 .81708 m .51528 .83402 L .5082 .84809 L p .707 .577 .707 r
F P
0 g
s
.47608 .3195 m .47608 .82139 L .52121 .8215 L p .707 .577 .707 r
F P
0 g
s
.57882 .69326 m .57204 .63892 L .60362 .63434 L p .707 .577 .707 r
F P
0 g
s
.60362 .63434 m .6104 .68867 L .57882 .69326 L p .707 .577 .707 r
F P
0 g
s
.60547 .70549 m .61658 .73941 L .58613 .74912 L p .707 .577 .707 r
F P
0 g
s
.58613 .74912 m .57502 .71519 L .60547 .70549 L p .707 .577 .707 r
F P
0 g
s
.60743 .76498 m .61308 .78193 L .58262 .79155 L p .707 .577 .707 r
F P
0 g
s
.58262 .79155 m .57697 .7746 L .60743 .76498 L p .707 .577 .707 r
F P
0 g
s
.56426 .31598 m .56426 .81787 L .60102 .81084 L p .707 .577 .707 r
F P
0 g
s
.60102 .81084 m .60102 .30896 L .56426 .31598 L p .707 .577 .707 r
F P
0 g
s
.4333 .81754 m .4333 .31565 L .39704 .30844 L p .707 .577 .707 r
F P
0 g
s
.4333 .31565 m .4333 .81754 L .47608 .82139 L p .707 .577 .707 r
F P
0 g
s
.69731 .78209 m .70296 .79904 L .70051 .78737 L p .707 .577 .707 r
F P
0 g
s
.70051 .78737 m .69486 .77043 L .69731 .78209 L p .707 .577 .707 r
F P
0 g
s
.69615 .64801 m .70294 .70234 L .69009 .69451 L p .707 .577 .707 r
F P
0 g
s
.69009 .69451 m .68331 .64017 L .69615 .64801 L p .707 .577 .707 r
F P
0 g
s
.51064 .85975 m .505 .84281 L .50255 .83114 L p .707 .577 .707 r
F P
0 g
s
.69451 .71031 m .70562 .74424 L .6933 .73628 L p .707 .577 .707 r
F P
0 g
s
.6933 .73628 m .68219 .70235 L .69451 .71031 L p .707 .577 .707 r
F P
0 g
s
.50255 .83114 m .5082 .84809 L .51064 .85975 L p .707 .577 .707 r
F P
0 g
s
.25541 .70168 m .25248 .64475 L .22125 .64529 L p .707 .577 .707 r
F P
0 g
s
.25248 .64475 m .25541 .70168 L .28716 .69956 L p .707 .577 .707 r
F P
0 g
s
.28716 .69956 m .28423 .64263 L .25248 .64475 L p .707 .577 .707 r
F P
0 g
s
.28423 .64263 m .28716 .69956 L .31633 .69609 L p .707 .577 .707 r
F P
0 g
s
.31633 .69609 m .3134 .63916 L .28423 .64263 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63466 .63299 m .64144 .68732 L .6104 .68867 L p .707 .577 .707 r
F P
0 g
s
.6104 .68867 m .60362 .63434 L .63466 .63299 L p .707 .577 .707 r
F P
0 g
s
.63537 .69981 m .64648 .73374 L .61658 .73941 L p .707 .577 .707 r
F P
0 g
s
.61658 .73941 m .60547 .70549 L .63537 .69981 L p .707 .577 .707 r
F P
0 g
s
.63716 .75944 m .64281 .77639 L .61308 .78193 L p .707 .577 .707 r
F P
0 g
s
.61308 .78193 m .60743 .76498 L .63716 .75944 L p .707 .577 .707 r
F P
0 g
s
.60102 .30896 m .60102 .81084 L .6279 .80112 L p .707 .577 .707 r
F P
0 g
s
.6279 .80112 m .6279 .29923 L .60102 .30896 L p .707 .577 .707 r
F P
0 g
s
.22418 .70222 m .22125 .64529 L .1936 .64421 L p .707 .577 .707 r
F P
0 g
s
.22125 .64529 m .22418 .70222 L .25541 .70168 L p .707 .577 .707 r
F P
0 g
s
.39704 .81033 m .39704 .30844 L .37086 .29857 L p .707 .577 .707 r
F P
0 g
s
.39704 .30844 m .39704 .81033 L .4333 .81754 L p .707 .577 .707 r
F P
0 g
s
.68331 .64017 m .69009 .69451 L .6689 .68933 L p .707 .577 .707 r
F P
0 g
s
.6689 .68933 m .66211 .635 L .68331 .64017 L p .707 .577 .707 r
F P
0 g
s
.69486 .77043 m .70051 .78737 L .68877 .77925 L p .707 .577 .707 r
F P
0 g
s
.68877 .77925 m .68312 .7623 L .69486 .77043 L p .707 .577 .707 r
F P
0 g
s
.3134 .63916 m .31633 .69609 L .34005 .69158 L p .707 .577 .707 r
F P
0 g
s
.34005 .69158 m .33712 .63465 L .3134 .63916 L p .707 .577 .707 r
F P
0 g
s
.1936 .64421 m .19654 .70113 L .22418 .70222 L p .707 .577 .707 r
F P
0 g
s
.22308 .71182 m .22798 .74997 L .25905 .74588 L p .707 .577 .707 r
F P
0 g
s
.25905 .74588 m .25415 .70773 L .22308 .71182 L p .707 .577 .707 r
F P
0 g
s
.25415 .70773 m .25905 .74588 L .29055 .74188 L p .707 .577 .707 r
F P
0 g
s
.29055 .74188 m .28565 .70374 L .25415 .70773 L p .707 .577 .707 r
F P
0 g
s
.28565 .70374 m .29055 .74188 L .3194 .73839 L p .707 .577 .707 r
F P
0 g
s
.3194 .73839 m .3145 .70024 L .28565 .70374 L p .707 .577 .707 r
F P
0 g
s
.19654 .70113 m .1936 .64421 L .17224 .6416 L p .707 .577 .707 r
F P
0 g
s
.19548 .71562 m .20038 .75376 L .22798 .74997 L p .707 .577 .707 r
F P
0 g
s
.22798 .74997 m .22308 .71182 L .19548 .71562 L p .707 .577 .707 r
F P
0 g
s
.68219 .70235 m .6933 .73628 L .67292 .73266 L p .707 .577 .707 r
F P
0 g
s
.67292 .73266 m .66181 .69874 L .68219 .70235 L p .707 .577 .707 r
F P
0 g
s
.17224 .6416 m .17517 .69853 L .19654 .70113 L p .707 .577 .707 r
F P
0 g
s
.66211 .635 m .6689 .68933 L .64144 .68732 L p .707 .577 .707 r
F P
0 g
s
.64144 .68732 m .63466 .63299 L .66211 .635 L p .707 .577 .707 r
F P
0 g
s
.22136 .77102 m .22384 .79009 L .25478 .78589 L p .707 .577 .707 r
F P
0 g
s
.25478 .78589 m .2523 .76682 L .22136 .77102 L p .707 .577 .707 r
F P
0 g
s
.2523 .76682 m .25478 .78589 L .28634 .78187 L p .707 .577 .707 r
F P
0 g
s
.3145 .70024 m .3194 .73839 L .34277 .73572 L p .707 .577 .707 r
F P
0 g
s
.28634 .78187 m .28386 .7628 L .2523 .76682 L p .707 .577 .707 r
F P
0 g
s
.34277 .73572 m .33787 .69758 L .3145 .70024 L p .707 .577 .707 r
F P
0 g
s
.33712 .63465 m .34005 .69158 L .35602 .68649 L p .707 .577 .707 r
F P
0 g
s
.35602 .68649 m .35308 .62957 L .33712 .63465 L p .707 .577 .707 r
F P
0 g
s
.28386 .7628 m .28634 .78187 L .31542 .77842 L p .707 .577 .707 r
F P
0 g
s
.31542 .77842 m .31294 .75936 L .28386 .7628 L p .707 .577 .707 r
F P
0 g
s
.17405 .71874 m .17895 .75689 L .20038 .75376 L p .707 .577 .707 r
F P
0 g
s
.20038 .75376 m .19548 .71562 L .17405 .71874 L p .707 .577 .707 r
F P
0 g
s
.68312 .7623 m .68877 .77925 L .66889 .77547 L p .707 .577 .707 r
F P
0 g
s
.66889 .77547 m .66324 .75852 L .68312 .7623 L p .707 .577 .707 r
F P
0 g
s
.64648 .73374 m .63537 .69981 L .66181 .69874 L p .707 .577 .707 r
F P
0 g
s
.64281 .77639 m .63716 .75944 L .66324 .75852 L p .707 .577 .707 r
F P
0 g
s
.6279 .29923 m .6279 .80112 L .64225 .78964 L p .707 .577 .707 r
F P
0 g
s
.64225 .78964 m .64225 .28775 L .6279 .29923 L p .707 .577 .707 r
F P
0 g
s
.19406 .775 m .19654 .79406 L .22384 .79009 L p .707 .577 .707 r
F P
0 g
s
.22384 .79009 m .22136 .77102 L .19406 .775 L p .707 .577 .707 r
F P
0 g
s
.37086 .80046 m .37086 .29857 L .35732 .28702 L p .707 .577 .707 r
F P
0 g
s
.37086 .29857 m .37086 .80046 L .39704 .81033 L p .707 .577 .707 r
F P
0 g
s
.17517 .69853 m .17224 .6416 L .15925 .63774 L p .707 .577 .707 r
F P
0 g
s
.66181 .69874 m .67292 .73266 L .64648 .73374 L p .707 .577 .707 r
F P
0 g
s
.31294 .75936 m .31542 .77842 L .33919 .77589 L p .707 .577 .707 r
F P
0 g
s
.33919 .77589 m .33671 .75683 L .31294 .75936 L p .707 .577 .707 r
F P
0 g
s
.15925 .63774 m .16219 .69467 L .17517 .69853 L p .707 .577 .707 r
F P
0 g
s
.33787 .69758 m .34277 .73572 L .35837 .73416 L p .707 .577 .707 r
F P
0 g
s
.35837 .73416 m .35622 .71742 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35308 .62957 m .35602 .68649 L .36265 .68132 L p .707 .577 .707 r
F P
0 g
s
.36265 .68132 m .35972 .62439 L .35308 .62957 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .35837 .73416 L .36469 .73384 L p .707 .577 .707 r
F P
0 g
s
.36469 .73384 m .35978 .69569 L .35347 .69601 L p .707 .577 .707 r
F P
0 g
s
.35972 .62439 m .36265 .68132 L .35931 .67657 L p .707 .577 .707 r
F P
0 g
s
.35931 .67657 m .35684 .62847 L p .35972 .62439 L .707 .577 .707 r
F P
0 g
s
.35684 .62847 m .35638 .61964 L .35681 .62025 L p .707 .577 .707 r
F P
0 g
s
.35681 .62025 m .35972 .62439 L p .35684 .62847 L .707 .577 .707 r
F P
0 g
s
.35282 .75546 m .3553 .77452 L .35625 .77451 L p .707 .577 .707 r
F P
0 g
s
.35625 .77451 m .36219 .77445 L p .35636 .76261 L .707 .577 .707 r
F P
0 g
s
.35636 .76261 m .35282 .75546 L .35625 .77451 L .707 .577 .707 r
F
.36219 .77445 m .35972 .75538 L .35282 .75546 L p F P
0 g
s
.35978 .69569 m .36469 .73384 L .36109 .7348 L p .707 .577 .707 r
F P
0 g
s
.36109 .7348 m .35684 .70176 L p .35978 .69569 L .707 .577 .707 r
F P
0 g
s
.35684 .70176 m .35619 .69666 L .35681 .69649 L p .707 .577 .707 r
F P
0 g
s
.35681 .69649 m .35978 .69569 L p .35684 .70176 L .707 .577 .707 r
F P
0 g
s
.35638 .61964 m .35931 .67657 L .34633 .6727 L p .707 .577 .707 r
F P
0 g
s
.35972 .75538 m .36219 .77445 L .35919 .77568 L p .707 .577 .707 r
F P
0 g
s
.35919 .77568 m .35671 .75661 L .35972 .75538 L p .707 .577 .707 r
F P
0 g
s
.35347 .69601 m .33787 .69758 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35622 .71742 m .35347 .69601 L p .35616 .73021 L .707 .577 .707 r
F P
0 g
s
.35619 .69666 m .36109 .7348 L .34793 .73695 L p .707 .577 .707 r
F P
0 g
s
.33671 .75683 m .33919 .77589 L .3553 .77452 L p .707 .577 .707 r
F P
0 g
s
.3553 .77452 m .35282 .75546 L .33671 .75683 L p .707 .577 .707 r
F P
0 g
s
.35671 .75661 m .35919 .77568 L .34658 .77809 L p .707 .577 .707 r
F P
0 g
s
.35732 .28702 m .35732 .78891 L .37086 .80046 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35742 .78621 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35742 .78621 m .35738 .78712 L p .35739 .78201 L .706 .577 .707 r
F P
0 g
s
.35739 .78201 m .35773 .30251 L .35742 .78621 L .706 .577 .707 r
F
.35734 .77274 m .35745 .63396 L .35738 .78712 L F
.35745 .63396 m .35775 .27491 L .3575 .62842 L F
.35745 .63396 m .3575 .62842 L .35738 .78712 L F
.35775 .27491 m .35775 .30326 L p .35773 .30251 L F P
0 g
s
.35775 .30326 m .35775 .7768 L p .35773 .30251 L .706 .577 .707 r
F P
0 g
s
.35738 .78712 m .35732 .78891 L p .35734 .77274 L .706 .577 .707 r
F P
0 g
s
.35732 .28702 m .35775 .27491 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .78891 m .35732 .49035 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.35732 .49035 m .35732 .28702 L p .35762 .42823 L .706 .577 .707 r
F P
0 g
s
.17308 .77835 m .17556 .79742 L .19654 .79406 L p .707 .577 .707 r
F P
0 g
s
.19654 .79406 m .19406 .775 L .17308 .77835 L p .707 .577 .707 r
F P
0 g
s
.16089 .72089 m .1658 .75904 L .17895 .75689 L p .707 .577 .707 r
F P
0 g
s
.17895 .75689 m .17405 .71874 L .16089 .72089 L p .707 .577 .707 r
F P
0 g
s
.66324 .75852 m .66889 .77547 L .64281 .77639 L p .707 .577 .707 r
F P
0 g
s
.16219 .69467 m .15925 .63774 L .15592 .63298 L p .707 .577 .707 r
F P
0 g
s
.16047 .78076 m .16295 .79983 L .17556 .79742 L p .707 .577 .707 r
F P
0 g
s
.17556 .79742 m .17308 .77835 L .16047 .78076 L p .707 .577 .707 r
F P
0 g
s
.64225 .28775 m .64225 .78964 L .64261 .77931 L p .706 .577 .707 r
F P
0 g
s
.64266 .76212 m .64225 .28775 L .64261 .77931 L .706 .577 .707 r
F
.64268 .77753 m .64268 .27564 L .64225 .28775 L p F P
0 g
s
.64261 .77931 m .64268 .77753 L p .64266 .76212 L .706 .577 .707 r
F P
0 g
s
.64268 .27564 m .64268 .77753 L .62914 .76597 L p .707 .577 .707 r
F P
0 g
s
.64068 .63472 m .64316 .58966 L p .64028 .5692 L .707 .577 .707 r
F P
0 g
s
.64316 .58966 m .64362 .58138 L .64319 .57982 L p .707 .577 .707 r
F P
0 g
s
.64319 .57982 m .64028 .5692 L p .64316 .58966 L .707 .577 .707 r
F P
0 g
s
.15592 .63298 m .15885 .68991 L .16219 .69467 L p .707 .577 .707 r
F P
0 g
s
.15729 .72185 m .1622 .76 L .1658 .75904 L p .707 .577 .707 r
F P
0 g
s
.1658 .75904 m .16089 .72089 L .15729 .72185 L p .707 .577 .707 r
F P
0 g
s
.15885 .68991 m .15592 .63298 L .16255 .62781 L p .707 .577 .707 r
F P
0 g
s
.15746 .78199 m .15994 .80106 L .16295 .79983 L p .707 .577 .707 r
F P
0 g
s
.16295 .79983 m .16047 .78076 L .15746 .78199 L p .707 .577 .707 r
F P
0 g
s
.16255 .62781 m .16548 .68474 L .15885 .68991 L p .707 .577 .707 r
F P
0 g
s
.16361 .72154 m .16851 .75968 L .1622 .76 L p .707 .577 .707 r
F P
0 g
s
.1622 .76 m .15729 .72185 L .16361 .72154 L p .707 .577 .707 r
F P
0 g
s
.34633 .6727 m .3434 .61577 L .35638 .61964 L p .707 .577 .707 r
F P
0 g
s
.62914 .76597 m .62914 .26409 L .64268 .27564 L p .707 .577 .707 r
F P
0 g
s
.35775 .7768 m .35775 .27491 L .3721 .26343 L p .707 .577 .707 r
F P
0 g
s
.16548 .68474 m .16255 .62781 L .17851 .62272 L p .707 .577 .707 r
F P
0 g
s
.16436 .78192 m .16683 .80098 L .15994 .80106 L p .707 .577 .707 r
F P
0 g
s
.15994 .80106 m .15746 .78199 L .16436 .78192 L p .707 .577 .707 r
F P
0 g
s
.17851 .62272 m .18145 .67965 L .16548 .68474 L p .707 .577 .707 r
F P
0 g
s
.34793 .73695 m .34303 .69881 L .35619 .69666 L p .707 .577 .707 r
F P
0 g
s
.3434 .61577 m .34633 .6727 L .32496 .6701 L p .707 .577 .707 r
F P
0 g
s
.32496 .6701 m .32203 .61317 L .3434 .61577 L p .707 .577 .707 r
F P
0 g
s
.17921 .71997 m .18412 .75812 L .16851 .75968 L p .707 .577 .707 r
F P
0 g
s
.16851 .75968 m .16361 .72154 L .17921 .71997 L p .707 .577 .707 r
F P
0 g
s
.34658 .77809 m .3441 .75902 L .35671 .75661 L p .707 .577 .707 r
F P
0 g
s
.18145 .67965 m .17851 .62272 L .20224 .61822 L p .707 .577 .707 r
F P
0 g
s
.62914 .26409 m .62914 .76597 L .60296 .75611 L p .707 .577 .707 r
F P
0 g
s
.60296 .75611 m .60296 .25422 L .62914 .26409 L p .707 .577 .707 r
F P
0 g
s
.3721 .76532 m .3721 .26343 L .39897 .2537 L p .707 .577 .707 r
F P
0 g
s
.3721 .26343 m .3721 .76532 L .35775 .7768 L p .707 .577 .707 r
F P
0 g
s
.20224 .61822 m .20517 .67515 L .18145 .67965 L p .707 .577 .707 r
F P
0 g
s
.18047 .78055 m .18295 .79961 L .16683 .80098 L p .707 .577 .707 r
F P
0 g
s
.16683 .80098 m .16436 .78192 L .18047 .78055 L p .707 .577 .707 r
F P
0 g
s
.34303 .69881 m .34793 .73695 L .32651 .74008 L p .707 .577 .707 r
F P
0 g
s
.32651 .74008 m .3216 .70193 L .34303 .69881 L p .707 .577 .707 r
F P
0 g
s
.32203 .61317 m .32496 .6701 L .29732 .66902 L p .707 .577 .707 r
F P
0 g
s
.29732 .66902 m .29438 .61209 L .32203 .61317 L p .707 .577 .707 r
F P
0 g
s
.20258 .71731 m .20749 .75546 L .18412 .75812 L p .707 .577 .707 r
F P
0 g
s
.18412 .75812 m .17921 .71997 L .20258 .71731 L p .707 .577 .707 r
F P
0 g
s
.20517 .67515 m .20224 .61822 L .2314 .61474 L p .707 .577 .707 r
F P
0 g
s
.3441 .75902 m .34658 .77809 L .3256 .78144 L p .707 .577 .707 r
F P
0 g
s
.3256 .78144 m .32312 .76238 L .3441 .75902 L p .707 .577 .707 r
F P
0 g
s
.29438 .61209 m .29732 .66902 L .26609 .66956 L p .707 .577 .707 r
F P
0 g
s
.26609 .66956 m .26316 .61263 L .29438 .61209 L p .707 .577 .707 r
F P
0 g
s
.2314 .61474 m .23434 .67167 L .20517 .67515 L p .707 .577 .707 r
F P
0 g
s
.73391 .66771 m .73684 .61437 L .70561 .61038 L p .707 .577 .707 r
F P
0 g
s
.73684 .61437 m .73391 .66771 L .76566 .66794 L p .707 .577 .707 r
F P
0 g
s
.76566 .66794 m .76859 .6146 L .73684 .61437 L p .707 .577 .707 r
F P
0 g
s
.23434 .67167 m .2314 .61474 L .26316 .61263 L p .707 .577 .707 r
F P
0 g
s
.76859 .6146 m .76566 .66794 L .79483 .66439 L p .707 .577 .707 r
F P
0 g
s
.79483 .66439 m .79776 .61105 L .76859 .6146 L p .707 .577 .707 r
F P
0 g
s
.3216 .70193 m .32651 .74008 L .29891 .74387 L p .707 .577 .707 r
F P
0 g
s
.70268 .66372 m .70561 .61038 L .67797 .60303 L p .707 .577 .707 r
F P
0 g
s
.70561 .61038 m .70268 .66372 L .73391 .66771 L p .707 .577 .707 r
F P
0 g
s
.29891 .74387 m .294 .70573 L .3216 .70193 L p .707 .577 .707 r
F P
0 g
s
.26316 .61263 m .26609 .66956 L .23434 .67167 L p .707 .577 .707 r
F P
0 g
s
.20424 .77802 m .20671 .79708 L .18295 .79961 L p .707 .577 .707 r
F P
0 g
s
.18295 .79961 m .18047 .78055 L .20424 .77802 L p .707 .577 .707 r
F P
0 g
s
.60296 .25422 m .60296 .75611 L .5667 .7489 L p .707 .577 .707 r
F P
0 g
s
.5667 .7489 m .5667 .24701 L .60296 .25422 L p .707 .577 .707 r
F P
0 g
s
.39897 .2537 m .39897 .75559 L .3721 .76532 L p .707 .577 .707 r
F P
0 g
s
.39897 .75559 m .39897 .2537 L .43573 .24668 L p .707 .577 .707 r
F P
0 g
s
.23143 .71381 m .23633 .75196 L .20749 .75546 L p .707 .577 .707 r
F P
0 g
s
.20749 .75546 m .20258 .71731 L .23143 .71381 L p .707 .577 .707 r
F P
0 g
s
.79776 .61105 m .79483 .66439 L .81855 .65742 L p .707 .577 .707 r
F P
0 g
s
.81855 .65742 m .82148 .60408 L .79776 .61105 L p .707 .577 .707 r
F P
0 g
s
.67503 .65637 m .67797 .60303 L .6566 .59304 L p .707 .577 .707 r
F P
0 g
s
.67797 .60303 m .67503 .65637 L .70268 .66372 L p .707 .577 .707 r
F P
0 g
s
.294 .70573 m .29891 .74387 L .26784 .74797 L p .707 .577 .707 r
F P
0 g
s
.32312 .76238 m .3256 .78144 L .2983 .78542 L p .707 .577 .707 r
F P
0 g
s
.2983 .78542 m .29582 .76635 L .32312 .76238 L p .707 .577 .707 r
F P
0 g
s
.26784 .74797 m .26293 .70982 L .294 .70573 L p .707 .577 .707 r
F P
0 g
s
.26293 .70982 m .26784 .74797 L .23633 .75196 L p .707 .577 .707 r
F P
0 g
s
.23633 .75196 m .23143 .71381 L .26293 .70982 L p .707 .577 .707 r
F P
0 g
s
.23332 .77457 m .2358 .79364 L .20671 .79708 L p .707 .577 .707 r
F P
0 g
s
.20671 .79708 m .20424 .77802 L .23332 .77457 L p .707 .577 .707 r
F P
0 g
s
.73216 .74108 m .73707 .70874 L .70599 .70198 L p .707 .577 .707 r
F P
0 g
s
.73707 .70874 m .73216 .74108 L .76366 .74259 L p .707 .577 .707 r
F P
0 g
s
.76366 .74259 m .76857 .71025 L .73707 .70874 L p .707 .577 .707 r
F P
0 g
s
.5667 .24701 m .5667 .7489 L .52391 .74505 L p .707 .577 .707 r
F P
0 g
s
.52391 .74505 m .52391 .24316 L .5667 .24701 L p .707 .577 .707 r
F P
0 g
s
.43573 .74857 m .43573 .24668 L .47879 .24304 L p .707 .577 .707 r
F P
0 g
s
.43573 .24668 m .43573 .74857 L .39897 .75559 L p .707 .577 .707 r
F P
0 g
s
.70109 .73432 m .70599 .70198 L .67839 .69063 L p .707 .577 .707 r
F P
0 g
s
.70599 .70198 m .70109 .73432 L .73216 .74108 L p .707 .577 .707 r
F P
0 g
s
.82148 .60408 m .81855 .65742 L .83451 .6477 L p .707 .577 .707 r
F P
0 g
s
.83451 .6477 m .83745 .59436 L .82148 .60408 L p .707 .577 .707 r
F P
0 g
s
.76857 .71025 m .76366 .74259 L .79251 .7387 L p .707 .577 .707 r
F P
0 g
s
.79251 .7387 m .79742 .70636 L .76857 .71025 L p .707 .577 .707 r
F P
0 g
s
.29582 .76635 m .2983 .78542 L .26736 .78962 L p .707 .577 .707 r
F P
0 g
s
.26736 .78962 m .26488 .77055 L .29582 .76635 L p .707 .577 .707 r
F P
0 g
s
.26488 .77055 m .26736 .78962 L .2358 .79364 L p .707 .577 .707 r
F P
0 g
s
.2358 .79364 m .23332 .77457 L .26488 .77055 L p .707 .577 .707 r
F P
0 g
s
.65367 .64638 m .6566 .59304 L .64362 .58138 L p .707 .577 .707 r
F P
0 g
s
.6566 .59304 m .65367 .64638 L .67503 .65637 L p .707 .577 .707 r
F P
0 g
s
.67349 .72297 m .67839 .69063 L .65697 .6758 L p .707 .577 .707 r
F P
0 g
s
.67839 .69063 m .67349 .72297 L .70109 .73432 L p .707 .577 .707 r
F P
0 g
s
.52391 .24316 m .52391 .74505 L .47879 .74493 L p .707 .577 .707 r
F P
0 g
s
.47879 .74493 m .47879 .24304 L .52391 .24316 L p .707 .577 .707 r
F P
0 g
s
.47879 .24304 m .47879 .74493 L .43573 .74857 L p .707 .577 .707 r
F P
0 g
s
.73264 .78541 m .73512 .76935 L .70418 .76222 L p .707 .577 .707 r
F P
0 g
s
.73512 .76935 m .73264 .78541 L .7642 .78723 L p .707 .577 .707 r
F P
0 g
s
.7642 .78723 m .76668 .77117 L .73512 .76935 L p .707 .577 .707 r
F P
0 g
s
.79742 .70636 m .79251 .7387 L .81588 .72979 L p .707 .577 .707 r
F P
0 g
s
.81588 .72979 m .82079 .69745 L .79742 .70636 L p .707 .577 .707 r
F P
0 g
s
.7017 .77828 m .70418 .76222 L .67688 .75047 L p .707 .577 .707 r
F P
0 g
s
.70418 .76222 m .7017 .77828 L .73264 .78541 L p .707 .577 .707 r
F P
0 g
s
.76668 .77117 m .7642 .78723 L .79328 .78356 L p .707 .577 .707 r
F P
0 g
s
.79328 .78356 m .79576 .7675 L .76668 .77117 L p .707 .577 .707 r
F P
0 g
s
.83745 .59436 m .83451 .6477 L .84115 .63618 L p .707 .577 .707 r
F P
0 g
s
.84115 .63618 m .84408 .58284 L .83745 .59436 L p .707 .577 .707 r
F P
0 g
s
.67688 .75047 m .6744 .76653 L .7017 .77828 L p .707 .577 .707 r
F P
0 g
s
.64362 .58138 m .64068 .63472 L .65367 .64638 L p .707 .577 .707 r
F P
0 g
s
.6744 .76653 m .67688 .75047 L .6559 .73525 L p .707 .577 .707 r
F P
0 g
s
.65206 .70814 m .65697 .6758 L .64381 .65894 L p .707 .577 .707 r
F P
0 g
s
.65697 .6758 m .65206 .70814 L .67349 .72297 L p .707 .577 .707 r
F P
0 g
s
.79576 .7675 m .79328 .78356 L .81705 .77475 L p .707 .577 .707 r
F P
0 g
s
.81705 .77475 m .81953 .75869 L .79576 .7675 L p .707 .577 .707 r
F P
0 g
s
.82079 .69745 m .81588 .72979 L .83149 .71673 L p .707 .577 .707 r
F P
0 g
s
.83149 .71673 m .83639 .68439 L .82079 .69745 L p .707 .577 .707 r
F P
0 g
s
.6559 .73525 m .65342 .75131 L .6744 .76653 L p .707 .577 .707 r
F P
0 g
s
.65342 .75131 m .6559 .73525 L .64329 .71805 L p .707 .577 .707 r
F P
0 g
s
.64381 .65894 m .63891 .69128 L .65206 .70814 L p .707 .577 .707 r
F P
0 g
s
.81953 .75869 m .81705 .77475 L .83316 .76166 L p .707 .577 .707 r
F P
0 g
s
.83316 .76166 m .83564 .7456 L .81953 .75869 L p .707 .577 .707 r
F P
0 g
s
.63891 .69128 m .64381 .65894 L .64021 .6417 L p .707 .577 .707 r
F P
0 g
s
.64028 .5692 m .63735 .62254 L .64068 .63472 L p .707 .577 .707 r
F P
0 g
s
.84408 .58284 m .84115 .63618 L .83781 .624 L p .707 .577 .707 r
F P
0 g
s
.83781 .624 m .84074 .57066 L .84408 .58284 L p .707 .577 .707 r
F P
0 g
s
.64329 .71805 m .64081 .73411 L .65342 .75131 L p .707 .577 .707 r
F P
0 g
s
.83639 .68439 m .83149 .71673 L .8378 .7008 L p .707 .577 .707 r
F P
0 g
s
.8378 .7008 m .8427 .66846 L .83639 .68439 L p .707 .577 .707 r
F P
0 g
s
.63735 .62254 m .64028 .5692 L .64692 .55768 L p .707 .577 .707 r
F P
0 g
s
.64081 .73411 m .64329 .71805 L .64028 .70056 L p .707 .577 .707 r
F P
0 g
s
.64021 .6417 m .63531 .67404 L .63891 .69128 L p .707 .577 .707 r
F P
0 g
s
.83564 .7456 m .83316 .76166 L .84006 .74559 L p .707 .577 .707 r
F P
0 g
s
.84006 .74559 m .84254 .72953 L .83564 .7456 L p .707 .577 .707 r
F P
0 g
s
.63531 .67404 m .64021 .6417 L .64653 .62577 L p .707 .577 .707 r
F P
0 g
s
.64028 .70056 m .6378 .71662 L .64081 .73411 L p .707 .577 .707 r
F P
0 g
s
.64692 .55768 m .64398 .61103 L .63735 .62254 L p .707 .577 .707 r
F P
0 g
s
.84074 .57066 m .83781 .624 L .82483 .61234 L p .707 .577 .707 r
F P
0 g
s
.82483 .61234 m .82776 .559 L .84074 .57066 L p .707 .577 .707 r
F P
0 g
s
.8427 .66846 m .8378 .7008 L .8342 .68356 L p .707 .577 .707 r
F P
0 g
s
.8342 .68356 m .83911 .65122 L .8427 .66846 L p .707 .577 .707 r
F P
0 g
s
.64398 .61103 m .64692 .55768 L .66288 .54796 L p .707 .577 .707 r
F P
0 g
s
.6378 .71662 m .64028 .70056 L .64717 .68449 L p .707 .577 .707 r
F P
0 g
s
.38959 .61494 m .39638 .55903 L .36534 .55398 L p .707 .577 .707 r
F P
0 g
s
.39638 .55903 m .38959 .61494 L .42117 .61788 L p .707 .577 .707 r
F P
0 g
s
.42117 .61788 m .42796 .56196 L .39638 .55903 L p .707 .577 .707 r
F P
0 g
s
.64653 .62577 m .64162 .65811 L .63531 .67404 L p .707 .577 .707 r
F P
0 g
s
.84254 .72953 m .84006 .74559 L .83705 .7281 L p .707 .577 .707 r
F P
0 g
s
.83705 .7281 m .83953 .71204 L .84254 .72953 L p .707 .577 .707 r
F P
0 g
s
.42796 .56196 m .42117 .61788 L .4502 .6184 L p .707 .577 .707 r
F P
0 g
s
.4502 .6184 m .45699 .56249 L .42796 .56196 L p .707 .577 .707 r
F P
0 g
s
.35856 .60989 m .36534 .55398 L .33788 .5473 L p .707 .577 .707 r
F P
0 g
s
.36534 .55398 m .35856 .60989 L .38959 .61494 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64162 .65811 m .64653 .62577 L .66213 .61271 L p .707 .577 .707 r
F P
0 g
s
.64717 .68449 m .6447 .70055 L .6378 .71662 L p .707 .577 .707 r
F P
0 g
s
.82776 .559 m .82483 .61234 L .80346 .60235 L p .707 .577 .707 r
F P
0 g
s
.80346 .60235 m .8064 .54901 L .82776 .559 L p .707 .577 .707 r
F P
0 g
s
.83911 .65122 m .8342 .68356 L .82105 .6667 L p .707 .577 .707 r
F P
0 g
s
.82105 .6667 m .82595 .63436 L .83911 .65122 L p .707 .577 .707 r
F P
0 g
s
.66288 .54796 m .65995 .60131 L .64398 .61103 L p .707 .577 .707 r
F P
0 g
s
.45699 .56249 m .4502 .6184 L .47384 .61647 L p .707 .577 .707 r
F P
0 g
s
.47384 .61647 m .48062 .56056 L .45699 .56249 L p .707 .577 .707 r
F P
0 g
s
.33788 .5473 m .3311 .60321 L .35856 .60989 L p .707 .577 .707 r
F P
0 g
s
.65995 .60131 m .66288 .54796 L .6866 .54099 L p .707 .577 .707 r
F P
0 g
s
.38342 .66659 m .39453 .63014 L .36462 .62024 L p .707 .577 .707 r
F P
0 g
s
.39453 .63014 m .38342 .66659 L .41387 .67522 L p .707 .577 .707 r
F P
0 g
s
.41387 .67522 m .42498 .63877 L .39453 .63014 L p .707 .577 .707 r
F P
0 g
s
.3311 .60321 m .33788 .5473 L .31669 .53965 L p .707 .577 .707 r
F P
0 g
s
.42498 .63877 m .41387 .67522 L .44189 .68174 L p .707 .577 .707 r
F P
0 g
s
.44189 .68174 m .45299 .6453 L .42498 .63877 L p .707 .577 .707 r
F P
0 g
s
.36462 .62024 m .35351 .65669 L .38342 .66659 L p .707 .577 .707 r
F P
0 g
s
.35351 .65669 m .36462 .62024 L .33819 .61004 L p .707 .577 .707 r
F P
0 g
s
.6447 .70055 m .64717 .68449 L .66329 .6714 L p .707 .577 .707 r
F P
0 g
s
.66213 .61271 m .65723 .64505 L .64162 .65811 L p .707 .577 .707 r
F P
0 g
s
.83953 .71204 m .83705 .7281 L .82444 .7109 L p .707 .577 .707 r
F P
0 g
s
.82444 .7109 m .82692 .69484 L .83953 .71204 L p .707 .577 .707 r
F P
0 g
s
.33819 .61004 m .32708 .64649 L .35351 .65669 L p .707 .577 .707 r
F P
0 g
s
.31669 .53965 m .30991 .59556 L .3311 .60321 L p .707 .577 .707 r
F P
0 g
s
.65723 .64505 m .66213 .61271 L .6855 .6038 L p .707 .577 .707 r
F P
0 g
s
.8064 .54901 m .80346 .60235 L .77581 .595 L p .707 .577 .707 r
F P
0 g
s
.77581 .595 m .77875 .54166 L .8064 .54901 L p .707 .577 .707 r
F P
0 g
s
.38692 .70774 m .39256 .68955 L .36284 .67944 L p .707 .577 .707 r
F P
0 g
s
.39256 .68955 m .38692 .70774 L .41738 .71663 L p .707 .577 .707 r
F P
0 g
s
.41738 .71663 m .42302 .69844 L .39256 .68955 L p .707 .577 .707 r
F P
0 g
s
.66329 .6714 m .66081 .68746 L .6447 .70055 L p .707 .577 .707 r
F P
0 g
s
.45299 .6453 m .44189 .68174 L .46472 .68551 L p .707 .577 .707 r
F P
0 g
s
.46472 .68551 m .47583 .64907 L .45299 .6453 L p .707 .577 .707 r
F P
0 g
s
.82595 .63436 m .82105 .6667 L .79962 .65187 L p .707 .577 .707 r
F P
0 g
s
.79962 .65187 m .80452 .61953 L .82595 .63436 L p .707 .577 .707 r
F P
0 g
s
.48062 .56056 m .47384 .61647 L .48977 .61227 L p .707 .577 .707 r
F P
0 g
s
.48977 .61227 m .49655 .55635 L .48062 .56056 L p .707 .577 .707 r
F P
0 g
s
.68367 .59433 m .6866 .54099 L .71577 .53744 L p .707 .577 .707 r
F P
0 g
s
.6866 .54099 m .68367 .59433 L .65995 .60131 L p .707 .577 .707 r
F P
0 g
s
.36284 .67944 m .35719 .69764 L .38692 .70774 L p .707 .577 .707 r
F P
0 g
s
.32708 .64649 m .33819 .61004 L .31781 .60054 L p .707 .577 .707 r
F P
0 g
s
.42302 .69844 m .41738 .71663 L .44559 .72343 L p .707 .577 .707 r
F P
0 g
s
.44559 .72343 m .45124 .70524 L .42302 .69844 L p .707 .577 .707 r
F P
0 g
s
.35719 .69764 m .36284 .67944 L .33676 .66911 L p .707 .577 .707 r
F P
0 g
s
.30991 .59556 m .31669 .53965 L .30384 .53178 L p .707 .577 .707 r
F P
0 g
s
.33676 .66911 m .33111 .6873 L .35719 .69764 L p .707 .577 .707 r
F P
0 g
s
.31781 .60054 m .3067 .63699 L .32708 .64649 L p .707 .577 .707 r
F P
0 g
s
.77875 .54166 m .77581 .595 L .74459 .59102 L p .707 .577 .707 r
F P
0 g
s
.74459 .59102 m .74752 .53768 L .77875 .54166 L p .707 .577 .707 r
F P
0 g
s
.66081 .68746 m .66329 .6714 L .68705 .66259 L p .707 .577 .707 r
F P
0 g
s
.71284 .59079 m .71577 .53744 L .74752 .53768 L p .707 .577 .707 r
F P
0 g
s
.71577 .53744 m .71284 .59079 L .68367 .59433 L p .707 .577 .707 r
F P
0 g
s
.6806 .63614 m .6855 .6038 L .71435 .5999 L p .707 .577 .707 r
F P
0 g
s
.6855 .6038 m .6806 .63614 L .65723 .64505 L p .707 .577 .707 r
F P
0 g
s
.82692 .69484 m .82444 .7109 L .80346 .69568 L p .707 .577 .707 r
F P
0 g
s
.80346 .69568 m .80594 .67962 L .82692 .69484 L p .707 .577 .707 r
F P
0 g
s
.45124 .70524 m .44559 .72343 L .46879 .72747 L p .707 .577 .707 r
F P
0 g
s
.46879 .72747 m .47444 .70928 L .45124 .70524 L p .707 .577 .707 r
F P
0 g
s
.74752 .53768 m .74459 .59102 L .71284 .59079 L p .707 .577 .707 r
F P
0 g
s
.30384 .53178 m .29706 .58769 L .30991 .59556 L p .707 .577 .707 r
F P
0 g
s
.80452 .61953 m .79962 .65187 L .77202 .64052 L p .707 .577 .707 r
F P
0 g
s
.77202 .64052 m .77692 .60817 L .80452 .61953 L p .707 .577 .707 r
F P
0 g
s
.33111 .6873 m .33676 .66911 L .31687 .65956 L p .707 .577 .707 r
F P
0 g
s
.47583 .64907 m .46472 .68551 L .48014 .68616 L p .707 .577 .707 r
F P
0 g
s
.48014 .68616 m .49125 .64972 L .47583 .64907 L p .707 .577 .707 r
F P
0 g
s
.31687 .65956 m .31123 .67775 L .33111 .6873 L p .707 .577 .707 r
F P
0 g
s
.68705 .66259 m .68458 .67865 L .66081 .68746 L p .707 .577 .707 r
F P
0 g
s
.3067 .63699 m .31781 .60054 L .30549 .59267 L p .707 .577 .707 r
F P
0 g
s
.49655 .55635 m .48977 .61227 L .49644 .60621 L p .707 .577 .707 r
F P
0 g
s
.49644 .60621 m .50322 .5503 L .49655 .55635 L p .707 .577 .707 r
F P
0 g
s
.70945 .63225 m .71435 .5999 L .74585 .60141 L p .707 .577 .707 r
F P
0 g
s
.71435 .5999 m .70945 .63225 L .6806 .63614 L p .707 .577 .707 r
F P
0 g
s
.30549 .59267 m .29438 .62912 L .3067 .63699 L p .707 .577 .707 r
F P
0 g
s
.77692 .60817 m .77202 .64052 L .74095 .63376 L p .707 .577 .707 r
F P
0 g
s
.74095 .63376 m .74585 .60141 L .77692 .60817 L p .707 .577 .707 r
F P
0 g
s
.68458 .67865 m .68705 .66259 L .71614 .65892 L p .707 .577 .707 r
F P
0 g
s
.29706 .58769 m .30384 .53178 L .30059 .52445 L p .707 .577 .707 r
F P
0 g
s
.74585 .60141 m .74095 .63376 L .70945 .63225 L p .707 .577 .707 r
F P
0 g
s
.80594 .67962 m .80346 .69568 L .77616 .68393 L p .707 .577 .707 r
F P
0 g
s
.77616 .68393 m .77864 .66787 L .80594 .67962 L p .707 .577 .707 r
F P
0 g
s
.47444 .70928 m .46879 .72747 L .48472 .72837 L p .707 .577 .707 r
F P
0 g
s
.48472 .72837 m .49036 .71018 L .47444 .70928 L p .707 .577 .707 r
F P
0 g
s
.71614 .65892 m .71366 .67498 L .68458 .67865 L p .707 .577 .707 r
F P
0 g
s
.31123 .67775 m .31687 .65956 L .30513 .65173 L p .707 .577 .707 r
F P
0 g
s
.71366 .67498 m .71614 .65892 L .7477 .66074 L p .707 .577 .707 r
F P
0 g
s
.30513 .65173 m .29948 .66992 L .31123 .67775 L p .707 .577 .707 r
F P
0 g
s
.30059 .52445 m .29381 .58037 L .29706 .58769 L p .707 .577 .707 r
F P
0 g
s
.77864 .66787 m .77616 .68393 L .74522 .6768 L p .707 .577 .707 r
F P
0 g
s
.74522 .6768 m .7477 .66074 L .77864 .66787 L p .707 .577 .707 r
F P
0 g
s
.7477 .66074 m .74522 .6768 L .71366 .67498 L p .707 .577 .707 r
F P
0 g
s
.49125 .64972 m .48014 .68616 L .48664 .68363 L p .707 .577 .707 r
F P
0 g
s
.48664 .68363 m .49775 .64718 L .49125 .64972 L p .707 .577 .707 r
F P
0 g
s
.29438 .62912 m .30549 .59267 L .30242 .5872 L p .707 .577 .707 r
F P
0 g
s
.30242 .5872 m .29132 .62365 L .29438 .62912 L p .707 .577 .707 r
F P
0 g
s
.50322 .5503 m .49644 .60621 L .49319 .59889 L p .707 .577 .707 r
F P
0 g
s
.49319 .59889 m .49997 .54297 L .50322 .5503 L p .707 .577 .707 r
F P
0 g
s
.29381 .58037 m .30059 .52445 L .30726 .5184 L p .707 .577 .707 r
F P
0 g
s
.49036 .71018 m .48472 .72837 L .4918 .72603 L p .707 .577 .707 r
F P
0 g
s
.4918 .72603 m .49745 .70784 L .49036 .71018 L p .707 .577 .707 r
F P
0 g
s
.29948 .66992 m .30513 .65173 L .30268 .64638 L p .707 .577 .707 r
F P
0 g
s
.30268 .64638 m .29704 .66457 L .29948 .66992 L p .707 .577 .707 r
F P
0 g
s
.30726 .5184 m .30048 .57431 L .29381 .58037 L p .707 .577 .707 r
F P
0 g
s
.49775 .64718 m .48664 .68363 L .48358 .67816 L p .707 .577 .707 r
F P
0 g
s
.48358 .67816 m .49469 .64171 L .49775 .64718 L p .707 .577 .707 r
F P
0 g
s
.29132 .62365 m .30242 .5872 L .30892 .58467 L p .707 .577 .707 r
F P
0 g
s
.49997 .54297 m .49319 .59889 L .48034 .59101 L p .707 .577 .707 r
F P
0 g
s
.48034 .59101 m .48712 .5351 L .49997 .54297 L p .707 .577 .707 r
F P
0 g
s
.30892 .58467 m .29781 .62112 L .29132 .62365 L p .707 .577 .707 r
F P
0 g
s
.30048 .57431 m .30726 .5184 L .32319 .51419 L p .707 .577 .707 r
F P
0 g
s
.49745 .70784 m .4918 .72603 L .48935 .72068 L p .707 .577 .707 r
F P
0 g
s
.48935 .72068 m .495 .70249 L .49745 .70784 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29704 .66457 m .30268 .64638 L .30977 .64404 L p .707 .577 .707 r
F P
0 g
s
.30977 .64404 m .30412 .66223 L .29704 .66457 L p .707 .577 .707 r
F P
0 g
s
.32319 .51419 m .31641 .57011 L .30048 .57431 L p .707 .577 .707 r
F P
0 g
s
.49469 .64171 m .48358 .67816 L .47125 .67029 L p .707 .577 .707 r
F P
0 g
s
.47125 .67029 m .48236 .63384 L .49469 .64171 L p .707 .577 .707 r
F P
0 g
s
.29781 .62112 m .30892 .58467 L .32434 .58532 L p .707 .577 .707 r
F P
0 g
s
.48712 .5351 m .48034 .59101 L .45915 .58337 L p .707 .577 .707 r
F P
0 g
s
.45915 .58337 m .46593 .52745 L .48712 .5351 L p .707 .577 .707 r
F P
0 g
s
.32434 .58532 m .31323 .62177 L .29781 .62112 L p .707 .577 .707 r
F P
0 g
s
.31641 .57011 m .32319 .51419 L .34683 .51226 L p .707 .577 .707 r
F P
0 g
s
.495 .70249 m .48935 .72068 L .47761 .71285 L p .707 .577 .707 r
F P
0 g
s
.47761 .71285 m .48326 .69466 L .495 .70249 L p .707 .577 .707 r
F P
0 g
s
.30412 .66223 m .30977 .64404 L .32569 .64493 L p .707 .577 .707 r
F P
0 g
s
.34683 .51226 m .34004 .56818 L .31641 .57011 L p .707 .577 .707 r
F P
0 g
s
.32569 .64493 m .32005 .66312 L .30412 .66223 L p .707 .577 .707 r
F P
0 g
s
.46593 .52745 m .45915 .58337 L .43169 .57669 L p .707 .577 .707 r
F P
0 g
s
.43169 .57669 m .43847 .52077 L .46593 .52745 L p .707 .577 .707 r
F P
0 g
s
.48236 .63384 m .47125 .67029 L .45088 .66079 L p .707 .577 .707 r
F P
0 g
s
.45088 .66079 m .46199 .62434 L .48236 .63384 L p .707 .577 .707 r
F P
0 g
s
.31323 .62177 m .32434 .58532 L .34718 .58909 L p .707 .577 .707 r
F P
0 g
s
.34004 .56818 m .34683 .51226 L .37586 .51279 L p .707 .577 .707 r
F P
0 g
s
.34718 .58909 m .33607 .62554 L .31323 .62177 L p .707 .577 .707 r
F P
0 g
s
.43847 .52077 m .43169 .57669 L .40065 .57164 L p .707 .577 .707 r
F P
0 g
s
.40065 .57164 m .40744 .51572 L .43847 .52077 L p .707 .577 .707 r
F P
0 g
s
.48326 .69466 m .47761 .71285 L .45773 .7033 L p .707 .577 .707 r
F P
0 g
s
.45773 .7033 m .46338 .6851 L .48326 .69466 L p .707 .577 .707 r
F P
0 g
s
.37586 .51279 m .36907 .5687 L .34004 .56818 L p .707 .577 .707 r
F P
0 g
s
.36907 .5687 m .37586 .51279 L .40744 .51572 L p .707 .577 .707 r
F P
0 g
s
.40744 .51572 m .40065 .57164 L .36907 .5687 L p .707 .577 .707 r
F P
0 g
s
.32005 .66312 m .32569 .64493 L .3489 .64898 L p .707 .577 .707 r
F P
0 g
s
.46199 .62434 m .45088 .66079 L .42444 .65059 L p .707 .577 .707 r
F P
0 g
s
.42444 .65059 m .43555 .61414 L .46199 .62434 L p .707 .577 .707 r
F P
0 g
s
.3489 .64898 m .34325 .66717 L .32005 .66312 L p .707 .577 .707 r
F P
0 g
s
.33607 .62554 m .34718 .58909 L .37519 .59561 L p .707 .577 .707 r
F P
0 g
s
.37519 .59561 m .36408 .63206 L .33607 .62554 L p .707 .577 .707 r
F P
0 g
s
.43555 .61414 m .42444 .65059 L .39453 .64069 L p .707 .577 .707 r
F P
0 g
s
.39453 .64069 m .40564 .60424 L .43555 .61414 L p .707 .577 .707 r
F P
0 g
s
.46338 .6851 m .45773 .7033 L .43165 .69296 L p .707 .577 .707 r
F P
0 g
s
.43165 .69296 m .4373 .67477 L .46338 .6851 L p .707 .577 .707 r
F P
0 g
s
.36408 .63206 m .37519 .59561 L .40564 .60424 L p .707 .577 .707 r
F P
0 g
s
.34325 .66717 m .3489 .64898 L .37711 .65578 L p .707 .577 .707 r
F P
0 g
s
.40564 .60424 m .39453 .64069 L .36408 .63206 L p .707 .577 .707 r
F P
0 g
s
.37711 .65578 m .37146 .67397 L .34325 .66717 L p .707 .577 .707 r
F P
0 g
s
.4373 .67477 m .43165 .69296 L .40192 .68286 L p .707 .577 .707 r
F P
0 g
s
.40192 .68286 m .40757 .66466 L .4373 .67477 L p .707 .577 .707 r
F P
0 g
s
.37146 .67397 m .37711 .65578 L .40757 .66466 L p .707 .577 .707 r
F P
0 g
s
.40757 .66466 m .40192 .68286 L .37146 .67397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6@00PWoo001iOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001iOol007Aoo`D0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00D007Aoo`00L7oo1000
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001OOol@0002FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001JOol5
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001GOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001EOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00004Goo3`00AWoo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH01000@Woo001DOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF00001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF1000?Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000Eoo`8000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Yoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0000=oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@003Ioo`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUIJEP00Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002000cOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF000015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80035oo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00<7oo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP80031o
o`00Dgoo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0002moo`00Dgoo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH015YF1`001UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF
001JEP0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P0015YF00<005YFFUH00eYF
00<005YFFUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YF
FUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005=oo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000EJ
EP03001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001J
EUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001COol01000FUIJEUYF2@001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00L005YFFUIJ
EP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`@000AJEP03001JEUYF00D0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo0P0015YF00<005YFFUH015YF00<0
05YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P001UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00P001UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH6000AOol60006
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0`001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH0
0`00FUH000030006Ool8000?Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP80009JEPP000AJEP04001JEUYFFUH9000:Ool30005FUH01000
FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH000020007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF008000EJEP<000QJ
EP03001JEUYF00EJEP03001JEUYF009JEPD000Moo`<000=JEP04001JEUYFFUH2000]Ool005=oo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYF001JEP0200000eYF001JEP02FUH20002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH80003FUH200000eYF001JEP02FUH2000]Ool003iooaH00003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009J
EP03001JEUYF00AJEP03001JEUYF00<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF008000=JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH20003FUH2000]Ool003Qoo`H000=JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000/000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF008000=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000IJEP03001JEP00009JEP8002eoo`00=7oo100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`001UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP0000000UYF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YF
FUH01000;Goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004
FUH01000FUIJEUYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`000UYF00@005YFFUIJEP<002eoo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH010000UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003
FUH3000]Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP@000QJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001EYF00<0
05YFFUH01UYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF
0P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03
001JEUYF009JEPH0009JEP03001JEUYF00=JEPL000IJEP03001JEUYF00IJEP03001JEUYF00=JEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0002FUH01000FUIJEUYF0P001eYF00<005YF
FUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH0000002io
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF0`001eYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF008000=JEP06001JEP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF10001UYF00<005YFFUH015YF00<005YF00000P00;Woo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000090005FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF008000=JEP8000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH01000FUH00000;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPH000QJEP03001J
EUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YF
FUH002moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YF00000`001EYF00<005YF
FUH01UYF0`001eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH00`00Oomo
o`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000UJEP03001J
EUYF00@0009JEP03001JEUYF00AJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001J
EUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF0`00
1EYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUH005YF00001UYF00@005YFFUIJEP@0009JEQ00009JEP03001JEUYF00EJEP03001JEP0000<0
009JEP03001JEUYF009JEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPX000=JEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF008000=JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@0017oo0`0015YF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEUYF1P001eYF00<005YFFUH01EYF1@001eYF00<005YFFUH00UYF0`0015YF
0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=JEP00
FUH00eYF1@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`002goo00<005YFFUH0
0UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH?0003FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00FUIJEP07FUH00`00FUIJEP04
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01`00FUH005YF001JEP0000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000Yoo`06001JEUYF001JEP00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP03FUH?0009FUH00`00FUIJEP02FUH30006FUH00`00FUH0000200000eYF001JEP040008FUH00`00
FUIJEP04FUH50006FUH3000015YF001JEP0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YF001JEP00009JEP04001JEP000005FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP07FUH00`00FUIJEP020009Ool01@00FUH005YF0000;Goo000]Ool00`00FUH00003FUH00`00FUH0
00030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0`000eYF00<005YF00000P0015YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF
00800003FUH005YF00MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0003FUH200000eYF001JEP03FUH70007Ool70006FUH00`00FUIJEP03FUH20007Ool01@00FUH005YF
0000;Goo000]Ool00`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP05FUH40004FUH300000eYF001JEP07FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUH000000UYF00@005YFFUH000=JEP80009JEP03001JEUYF008000ioo`@0009J
EP03001JEUYF00EJEP8000Ioo`800003FUH007oo02aoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0008FUH0
1000FUH000000eYF1P001eYF00<005YFFUH015YF10000UYF00<005YF00002EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH01000FUH000001EYF00@005YF
0000019oo`@000MJEP<000Eoo`03001JEP0002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<000IJEP03
001JEUYF009JEPP00003FUH0000000EJEP03001JEUYF00EJEPL000YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP000eYF0P0000=JEP00000015YF00@005YF0000
01Ioo`8000AJEP05001JEUYFFUH00003Ool3000^Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH50004FUH0
0`00FUIJEP05FUH50003FUH300000eYF001JEP07FUH00`00FUIJEP03000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030002FUH00`00FUIJEP03FUH20002FUH01000
FUIJEP0067oo0`0000=JEP00FUH00eYF0`0000=JEP000000;Woo000^Ool200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70005Ool200000eYF
001JEP08FUH70003FUH30006FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YF00000P000UYF00<007oo
Ool06Goo0P001UYF00@005YF000002ioo`00<7oo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001goo2P001eYF00<005YFFUH01EYF100000=JEP0000000`000UYF00<005YF
FUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF
00<000IJEP04001JEUYFFUH4000MOol00`00FUIJEP03FUH4000^Ool003AooaT000Uoo`T0009JEP06
001JEUYFFUH005YF0P001EYF00<005YFFUH01eYF00<005YF00000`000UYF0`001EYF00D005YFFUIJ
EP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH0
00IJEP03001JEUYF00AJEP@001Uoo`<000AJEP800003FUH007oo02eoo`00CGoo2`000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP<00003FUH005YF00QJEP03001JEUYF00AJEPL000=JEP05001J
EUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP020000
0eYF00000006FUH00`00FUIJEP05FUH00`00FUIJEP04000@Ool50003FUH200001EYF001JEUYF0000
;goo0014Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YF
FUH010001eYF00<005YFFUH01UYF00<005YFFUH01@0015YF0P001UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH015YF40000eYF00<005YFFUH00eYF0`000UYF00<007ooOol0;Goo000lOol:0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF
10000UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF00001UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000eYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000eYF00<0
07ooOol0;7oo000eOol90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH0
15YF00D005YF000005YF008000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000EJEP04001JEUYF0008FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<007ooOol0;7oo000]Ool90003FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P001UYF0`001eYF00<005YF
FUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo02ao
o`00;7oo1@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEPL0
00=JEP03001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00<000IJEP<000IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEP00001oo`0200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50002FUH00`00FUH0
0008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF008000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP80
00=oo`800003FUH007oo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00@005YFFUIJEP<00003FUH005YF
00MJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`03001JEP0002eoo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH90003FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001Woo00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YFFUIJEP80009JEP8000=JEP800003Ool0000000800004FUH007ooOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0000027oo00<005YF0000;Goo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70005Ool01@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEPD000Aoo`80
0004FUH000000005Ool70004FUH00`00FUIJEP02FUH5000;Ool00`00Oomoo`0/Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000ao
o`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP04FUHI0006FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03001oogoo009oo`04001JEUYF0002FUH00`00
Oomoo`0:Ool9000?Ool2000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF009JEPT001Aoo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH90005FUH00`00FUIJ
EP0:FUH00`00FUIJEP04FUH80008FUH00`00FUIJEP04FUH01000FUIJEUYF100015YF0P0000=oo`00
FUH00UYF00@005YFFUH002Aoo`8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF2@007Goo00D005YFFUIJEP0000MJEP03001JEUYF00D0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00<000EJEP03001JEUYF00AJEP05001JEUYFFUH00002
Ool00`00FUIJEP04FUH20003FUH01@00FUIJEUYF00008Goo0`00;goo000^Ool20004FUH01000FUIJ
EUYF1`008goo10000eYF00<005YFFUH015YF10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF100000=JEP00FUH01EYF00D005YFFUIJEP0000=oo`8000AJEP04
001JEP000002FUH01000FUIJEP007goo0P0000=JEP000000;goo000^Ool20002FUH6000MOolA0003
FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH30005FUH01000FUIJEUYF1`000UYF00<005YFFUH00UYF0`0000=JEP00Ool07Woo00D0
05YFFUIJEP00031oo`00;Woo100077oo1`000eYF1`000UYF00D005YFFUIJEP0000=JEP03001JEP00
0080009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00@00003FUH005YF009JEP03001JEUYF00=JEP@000MJEP<001aoo`<000=J
EP03001oogoo02ioo`00BWoo10000UYF00<005YF00001@000eYF00<005YFFUH00eYF00D005YFFUIJ
EP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP03001JEP0000QJEP03001J
EP0000<001Ioo`80009JEP04001JEUYF000aOol004=oo`L000AJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP020006FUH00`00FUIJEP03FUH70009Ool60004FUH00`00FUH0000bOol003]oo`P0
00AJEPL000IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF00EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEP00FUH00007FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0015YF00<005YFFUH00eYF0P00<goo000eOol60003FUH90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH030000UYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00=7oo000`Ool?0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1P000eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EUYF00AJEP<0009JEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00
;7oo1@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1`001Goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH0
0`00FUIJEP06FUH40003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0
00aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF
00<007oo00000P001Woo4000?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH9000DOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP80009oo`<005Eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH00UYF2@007Woo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0005FUH01000FUIJ
EUYF0P000goo00@005YFFUH005Eoo`00;Goo00<005YF000015YF00@005YFFUIJEPL002Qoo`<000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000MJEP<000Eoo`04001JEUYF001EOol002eoo`/0035oo`8000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP<000MJEP8000Ioo`80009JEP03001oogoo05=oo`00Jgoo0P000eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF0P001Woo0P0000AJEP00FUH005Ioo`00KGoo0P0000=JEP00FUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00000P001goo00<005YFFUH00UYF0P00EWoo001_Ool40008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH50006FUH30009Ool00`00FUIJEP03FUH0
0`00Oomoo`1EOol007=oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00D00003FUH0000000<000=JEP8000Yoo`<000EJEP03001oogoo05Eoo`00NGoo20001UYF
00<005YFFUH02UYF00<005YFFUH015YF20001UYF20002goo00D005YFFUIJEP0000=JEP03001oogoo
05Ioo`00PGoo6`001UYF00<005YFFUH015YF1@0037oo0P0015YF00@005YFFUH005Uoo`00Sgoo00<0
05YF00000UYF1@000eYF00<005YFFUH015YF00<005YFFUH01`0037oo00<005YFFUH01EYF0P00FWoo
002>Ool01000FUIJEP000UYF00<007ooOol00Woo3@004Goo0`001eYF00<007ooOol0FGoo002>Ool0
1000FUIJEUYF0P008Goo0P000UYF00<005YFFUH00eYF0P00G7oo002>Ool01@00FUIJEUYF000087oo
0P001EYF00<005YFFUH00P00GWoo002?Ool00`00FUH0000NOol30007FUH3001POol008moo`03001J
EP0001]oo`<00003FUH005YF00MJEP03001oogoo061oo`00Sgoo0`0067oo0`0015YF00<005YFFUH0
15YF0P00Hgoo002@Ool01000FUH0000047oo1P0025YF00@005YFFUIJEP8006Eoo`00T7oo00@005YF
001JEP<000Eoo`P000AJEP03001JEUYF00MJEP04001JEP00001WOol0095oo`03001JEP0000=JEPD0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP<006Uoo`00TGoo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00K7oo002BOol30004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUH00002001_Ool009Aoo`<0009JEP03001JEUYF00EJEP03001JEUYF009JEPD0
079oo`00Ugoo3`00Mgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59813 .75278 m .59394 .69786 L .5628 .69798 L p .707 .577 .707 r
F P
0 g
s
.59394 .69786 m .59813 .75278 L .62986 .74963 L p .707 .577 .707 r
F P
0 g
s
.62986 .74963 m .62567 .69471 L .59394 .69786 L p .707 .577 .707 r
F P
0 g
s
.62567 .69471 m .62986 .74963 L .65907 .74378 L p .707 .577 .707 r
F P
0 g
s
.65907 .74378 m .65488 .68886 L .62567 .69471 L p .707 .577 .707 r
F P
0 g
s
.56699 .7529 m .5628 .69798 L .53529 .69507 L p .707 .577 .707 r
F P
0 g
s
.5628 .69798 m .56699 .7529 L .59813 .75278 L p .707 .577 .707 r
F P
0 g
s
.65488 .68886 m .65907 .74378 L .6829 .73578 L p .707 .577 .707 r
F P
0 g
s
.6829 .73578 m .67871 .68086 L .65488 .68886 L p .707 .577 .707 r
F P
0 g
s
.53948 .74999 m .53529 .69507 L .51411 .68941 L p .707 .577 .707 r
F P
0 g
s
.53529 .69507 m .53948 .74999 L .56699 .7529 L p .707 .577 .707 r
F P
0 g
s
.60202 .81757 m .5951 .78203 L .56439 .78496 L p .707 .577 .707 r
F P
0 g
s
.5951 .78203 m .60202 .81757 L .63332 .81112 L p .707 .577 .707 r
F P
0 g
s
.63332 .81112 m .6264 .77558 L .5951 .78203 L p .707 .577 .707 r
F P
0 g
s
.6264 .77558 m .63332 .81112 L .66213 .80178 L p .707 .577 .707 r
F P
0 g
s
.66213 .80178 m .65521 .76623 L .6264 .77558 L p .707 .577 .707 r
F P
0 g
s
.57131 .8205 m .56439 .78496 L .53726 .78407 L p .707 .577 .707 r
F P
0 g
s
.56439 .78496 m .57131 .8205 L .60202 .81757 L p .707 .577 .707 r
F P
0 g
s
.67871 .68086 m .6829 .73578 L .69902 .72643 L p .707 .577 .707 r
F P
0 g
s
.69902 .72643 m .69483 .6715 L .67871 .68086 L p .707 .577 .707 r
F P
0 g
s
.65521 .76623 m .66213 .80178 L .68563 .79045 L p .707 .577 .707 r
F P
0 g
s
.68563 .79045 m .67871 .75491 L .65521 .76623 L p .707 .577 .707 r
F P
0 g
s
.51411 .68941 m .5183 .74433 L .53948 .74999 L p .707 .577 .707 r
F P
0 g
s
.59745 .86019 m .59392 .84243 L .56331 .84532 L p .707 .577 .707 r
F P
0 g
s
.59392 .84243 m .59745 .86019 L .62876 .85376 L p .707 .577 .707 r
F P
0 g
s
.62876 .85376 m .62523 .83601 L .59392 .84243 L p .707 .577 .707 r
F P
0 g
s
.62523 .83601 m .62876 .85376 L .6577 .84442 L p .707 .577 .707 r
F P
0 g
s
.6577 .84442 m .65417 .82666 L .62523 .83601 L p .707 .577 .707 r
F P
0 g
s
.53726 .78407 m .54418 .81961 L .57131 .8205 L p .707 .577 .707 r
F P
0 g
s
.5183 .74433 m .51411 .68941 L .50133 .68155 L p .707 .577 .707 r
F P
0 g
s
.56331 .84532 m .56684 .86307 L .59745 .86019 L p .707 .577 .707 r
F P
0 g
s
.54418 .81961 m .53726 .78407 L .51637 .77946 L p .707 .577 .707 r
F P
0 g
s
.56684 .86307 m .56331 .84532 L .53639 .84437 L p .707 .577 .707 r
F P
0 g
s
.65417 .82666 m .6577 .84442 L .68144 .83307 L p .707 .577 .707 r
F P
0 g
s
.68144 .83307 m .67791 .81531 L .65417 .82666 L p .707 .577 .707 r
F P
0 g
s
.67871 .75491 m .68563 .79045 L .70154 .77826 L p .707 .577 .707 r
F P
0 g
s
.70154 .77826 m .69462 .74272 L .67871 .75491 L p .707 .577 .707 r
F P
0 g
s
.53639 .84437 m .53992 .86213 L .56684 .86307 L p .707 .577 .707 r
F P
0 g
s
.69483 .6715 m .69902 .72643 L .70585 .71663 L p .707 .577 .707 r
F P
0 g
s
.70585 .71663 m .70165 .66171 L .69483 .6715 L p .707 .577 .707 r
F P
0 g
s
.51637 .77946 m .5233 .815 L .54418 .81961 L p .707 .577 .707 r
F P
0 g
s
.50133 .68155 m .50552 .73647 L .5183 .74433 L p .707 .577 .707 r
F P
0 g
s
.53992 .86213 m .53639 .84437 L .5158 .83969 L p .707 .577 .707 r
F P
0 g
s
.67791 .81531 m .68144 .83307 L .69766 .82083 L p .707 .577 .707 r
F P
0 g
s
.69766 .82083 m .69413 .80307 L .67791 .81531 L p .707 .577 .707 r
F P
0 g
s
.5233 .815 m .51637 .77946 L .50377 .77158 L p .707 .577 .707 r
F P
0 g
s
.5158 .83969 m .51933 .85745 L .53992 .86213 L p .707 .577 .707 r
F P
0 g
s
.50552 .73647 m .50133 .68155 L .4982 .67227 L p .707 .577 .707 r
F P
0 g
s
.69462 .74272 m .70154 .77826 L .70828 .76639 L p .707 .577 .707 r
F P
0 g
s
.70828 .76639 m .70136 .73085 L .69462 .74272 L p .707 .577 .707 r
F P
0 g
s
.50377 .77158 m .5107 .80712 L .5233 .815 L p .707 .577 .707 r
F P
0 g
s
.70165 .66171 m .70585 .71663 L .70272 .70735 L p .707 .577 .707 r
F P
0 g
s
.70272 .70735 m .69853 .65243 L .70165 .66171 L p .707 .577 .707 r
F P
0 g
s
.51933 .85745 m .5158 .83969 L .50356 .83173 L p .707 .577 .707 r
F P
0 g
s
.4982 .67227 m .50239 .72719 L .50552 .73647 L p .707 .577 .707 r
F P
0 g
s
.69413 .80307 m .69766 .82083 L .70476 .8089 L p .707 .577 .707 r
F P
0 g
s
.70476 .8089 m .70124 .79114 L .69413 .80307 L p .707 .577 .707 r
F P
0 g
s
.50356 .83173 m .50709 .84949 L .51933 .85745 L p .707 .577 .707 r
F P
0 g
s
.5107 .80712 m .50377 .77158 L .50069 .7612 L p .707 .577 .707 r
F P
0 g
s
.48154 .8216 m .48154 .31972 L .43824 .31631 L p .707 .577 .707 r
F P
0 g
s
.50239 .72719 m .4982 .67227 L .50503 .66247 L p .707 .577 .707 r
F P
0 g
s
.50069 .7612 m .50762 .79674 L .5107 .80712 L p .707 .577 .707 r
F P
0 g
s
.50709 .84949 m .50356 .83173 L .50086 .82127 L p .707 .578 .707 r
F P
0 g
s
.50503 .66247 m .50922 .7174 L .50239 .72719 L p .707 .577 .707 r
F P
0 g
s
.50086 .82127 m .50439 .83903 L .50709 .84949 L p .707 .578 .707 r
F P
0 g
s
.50762 .79674 m .50069 .7612 L .50744 .74933 L p .707 .577 .707 r
F P
0 g
s
.50922 .7174 m .50503 .66247 L .52115 .65312 L p .707 .577 .707 r
F P
0 g
s
.50744 .74933 m .51436 .78487 L .50762 .79674 L p .707 .577 .707 r
F P
0 g
s
.50439 .83903 m .50086 .82127 L .50796 .80934 L p .707 .577 .707 r
F P
0 g
s
.52115 .65312 m .52534 .70804 L .50922 .7174 L p .707 .577 .707 r
F P
0 g
s
.50796 .80934 m .51149 .82709 L .50439 .83903 L p .707 .577 .707 r
F P
0 g
s
.51436 .78487 m .50744 .74933 L .52334 .73713 L p .707 .577 .707 r
F P
0 g
s
.52334 .73713 m .53026 .77267 L .51436 .78487 L p .707 .577 .707 r
F P
0 g
s
.51149 .82709 m .50796 .80934 L .52418 .7971 L p .707 .577 .707 r
F P
0 g
s
.52418 .7971 m .52771 .81485 L .51149 .82709 L p .707 .577 .707 r
F P
0 g
s
.52771 .81485 m .52418 .7971 L .54792 .78575 L p .707 .577 .707 r
F P
0 g
s
.48154 .31972 m .48154 .8216 L .52666 .82126 L p .707 .577 .707 r
F P
0 g
s
.52534 .70804 m .52115 .65312 L .54498 .64512 L p .707 .577 .707 r
F P
0 g
s
.54498 .64512 m .54917 .70004 L .52534 .70804 L p .707 .577 .707 r
F P
0 g
s
.53026 .77267 m .52334 .73713 L .54684 .72581 L p .707 .577 .707 r
F P
0 g
s
.52666 .82126 m .52666 .31937 L .48154 .31972 L p .707 .577 .707 r
F P
0 g
s
.54917 .70004 m .54498 .64512 L .57419 .63927 L p .707 .577 .707 r
F P
0 g
s
.57419 .63927 m .57838 .69419 L .54917 .70004 L p .707 .577 .707 r
F P
0 g
s
.54684 .72581 m .55377 .76135 L .53026 .77267 L p .707 .577 .707 r
F P
0 g
s
.55377 .76135 m .54684 .72581 L .57565 .71647 L p .707 .577 .707 r
F P
0 g
s
.54792 .78575 m .55145 .80351 L .52771 .81485 L p .707 .577 .707 r
F P
0 g
s
.57565 .71647 m .58258 .75201 L .55377 .76135 L p .707 .577 .707 r
F P
0 g
s
.55145 .80351 m .54792 .78575 L .57687 .7764 L p .707 .577 .707 r
F P
0 g
s
.57687 .7764 m .58039 .79416 L .55145 .80351 L p .707 .577 .707 r
F P
0 g
s
.52666 .31937 m .52666 .82126 L .56916 .81718 L p .707 .577 .707 r
F P
0 g
s
.56916 .81718 m .56916 .3153 L .52666 .31937 L p .707 .577 .707 r
F P
0 g
s
.70136 .73085 m .70828 .76639 L .7052 .75601 L p .707 .577 .707 r
F P
0 g
s
.7052 .75601 m .69828 .72046 L .70136 .73085 L p .707 .577 .707 r
F P
0 g
s
.43824 .8182 m .43824 .31631 L .40098 .30947 L p .707 .577 .707 r
F P
0 g
s
.43824 .31631 m .43824 .8182 L .48154 .8216 L p .707 .577 .707 r
F P
0 g
s
.57838 .69419 m .57419 .63927 L .60592 .63612 L p .707 .577 .707 r
F P
0 g
s
.60592 .63612 m .61011 .69104 L .57838 .69419 L p .707 .577 .707 r
F P
0 g
s
.58258 .75201 m .57565 .71647 L .60695 .71001 L p .707 .577 .707 r
F P
0 g
s
.60695 .71001 m .61387 .74556 L .58258 .75201 L p .707 .577 .707 r
F P
0 g
s
.58039 .79416 m .57687 .7764 L .60817 .76998 L p .707 .577 .707 r
F P
0 g
s
.60817 .76998 m .6117 .78773 L .58039 .79416 L p .707 .577 .707 r
F P
0 g
s
.56916 .3153 m .56916 .81718 L .60489 .80979 L p .707 .577 .707 r
F P
0 g
s
.60489 .80979 m .60489 .3079 L .56916 .3153 L p .707 .577 .707 r
F P
0 g
s
.69853 .65243 m .70272 .70735 L .68994 .69949 L p .707 .577 .707 r
F P
0 g
s
.68994 .69949 m .68575 .64457 L .69853 .65243 L p .707 .577 .707 r
F P
0 g
s
.70124 .79114 m .70476 .8089 L .70206 .79844 L p .707 .578 .707 r
F P
0 g
s
.70206 .79844 m .69853 .78068 L .70124 .79114 L p .707 .578 .707 r
F P
0 g
s
.2545 .70596 m .2527 .64943 L .22148 .64904 L p .707 .577 .707 r
F P
0 g
s
.2527 .64943 m .2545 .70596 L .2863 .70436 L p .707 .577 .707 r
F P
0 g
s
.2863 .70436 m .28449 .64783 L .2527 .64943 L p .707 .577 .707 r
F P
0 g
s
.28449 .64783 m .2863 .70436 L .31556 .70091 L p .707 .577 .707 r
F P
0 g
s
.31556 .70091 m .31375 .64439 L .28449 .64783 L p .707 .577 .707 r
F P
0 g
s
.69828 .72046 m .7052 .75601 L .6926 .74812 L p .707 .577 .707 r
F P
0 g
s
.6926 .74812 m .68568 .71258 L .69828 .72046 L p .707 .577 .707 r
F P
0 g
s
.40098 .81136 m .40098 .30947 L .37341 .29989 L p .707 .577 .707 r
F P
0 g
s
.40098 .30947 m .40098 .81136 L .43824 .8182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22329 .70556 m .22148 .64904 L .1939 .64669 L p .707 .577 .707 r
F P
0 g
s
.22148 .64904 m .22329 .70556 L .2545 .70596 L p .707 .577 .707 r
F P
0 g
s
.63706 .636 m .64125 .69092 L .61011 .69104 L p .707 .577 .707 r
F P
0 g
s
.61011 .69104 m .60592 .63612 L .63706 .636 L p .707 .577 .707 r
F P
0 g
s
.63766 .70709 m .64458 .74263 L .61387 .74556 L p .707 .577 .707 r
F P
0 g
s
.61387 .74556 m .60695 .71001 L .63766 .70709 L p .707 .577 .707 r
F P
0 g
s
.63878 .76709 m .64231 .78485 L .6117 .78773 L p .707 .577 .707 r
F P
0 g
s
.6117 .78773 m .60817 .76998 L .63878 .76709 L p .707 .577 .707 r
F P
0 g
s
.60489 .3079 m .60489 .80979 L .63035 .79979 L p .707 .577 .707 r
F P
0 g
s
.63035 .79979 m .63035 .2979 L .60489 .3079 L p .707 .577 .707 r
F P
0 g
s
.68575 .64457 m .68994 .69949 L .66876 .69383 L p .707 .577 .707 r
F P
0 g
s
.66876 .69383 m .66457 .63891 L .68575 .64457 L p .707 .577 .707 r
F P
0 g
s
.31375 .64439 m .31556 .70091 L .33942 .69597 L p .707 .577 .707 r
F P
0 g
s
.33942 .69597 m .33762 .63944 L .31375 .64439 L p .707 .577 .707 r
F P
0 g
s
.1939 .64669 m .19571 .70321 L .22329 .70556 L p .707 .577 .707 r
F P
0 g
s
.2566 .75655 m .2536 .71837 L .22243 .72018 L p .707 .577 .707 r
F P
0 g
s
.2536 .71837 m .2566 .75655 L .2883 .75377 L p .707 .577 .707 r
F P
0 g
s
.2883 .75377 m .28529 .71559 L .2536 .71837 L p .707 .577 .707 r
F P
0 g
s
.69853 .78068 m .70206 .79844 L .68982 .79048 L p .707 .577 .707 r
F P
0 g
s
.68982 .79048 m .68629 .77272 L .69853 .78068 L p .707 .577 .707 r
F P
0 g
s
.28529 .71559 m .2883 .75377 L .31743 .7503 L p .707 .577 .707 r
F P
0 g
s
.31743 .7503 m .31443 .71212 L .28529 .71559 L p .707 .577 .707 r
F P
0 g
s
.19571 .70321 m .1939 .64669 L .17266 .64261 L p .707 .577 .707 r
F P
0 g
s
.22243 .72018 m .22544 .75836 L .2566 .75655 L p .707 .577 .707 r
F P
0 g
s
.22544 .75836 m .22243 .72018 L .19485 .72085 L p .707 .577 .707 r
F P
0 g
s
.19485 .72085 m .19786 .75903 L .22544 .75836 L p .707 .577 .707 r
F P
0 g
s
.68568 .71258 m .6926 .74812 L .67171 .74351 L p .707 .577 .707 r
F P
0 g
s
.67171 .74351 m .66479 .70797 L .68568 .71258 L p .707 .577 .707 r
F P
0 g
s
.17266 .64261 m .17446 .69913 L .19571 .70321 L p .707 .577 .707 r
F P
0 g
s
.31443 .71212 m .31743 .7503 L .34114 .74647 L p .707 .577 .707 r
F P
0 g
s
.34114 .74647 m .33814 .70829 L .31443 .71212 L p .707 .577 .707 r
F P
0 g
s
.33762 .63944 m .33942 .69597 L .35555 .69001 L p .707 .577 .707 r
F P
0 g
s
.35555 .69001 m .35375 .63348 L .33762 .63944 L p .707 .577 .707 r
F P
0 g
s
.25396 .79718 m .25243 .77808 L .22135 .77993 L p .707 .577 .707 r
F P
0 g
s
.25243 .77808 m .25396 .79718 L .28569 .79441 L p .707 .577 .707 r
F P
0 g
s
.28569 .79441 m .28417 .77532 L .25243 .77808 L p .707 .577 .707 r
F P
0 g
s
.66457 .63891 m .66876 .69383 L .64125 .69092 L p .707 .577 .707 r
F P
0 g
s
.64125 .69092 m .63706 .636 L .66457 .63891 L p .707 .577 .707 r
F P
0 g
s
.22135 .77993 m .22288 .79903 L .25396 .79718 L p .707 .577 .707 r
F P
0 g
s
.28417 .77532 m .28569 .79441 L .31497 .791 L p .707 .577 .707 r
F P
0 g
s
.31497 .791 m .31344 .7719 L .28417 .77532 L p .707 .577 .707 r
F P
0 g
s
.37341 .80178 m .37341 .29989 L .35824 .28848 L p .707 .577 .707 r
F P
0 g
s
.37341 .29989 m .37341 .80178 L .40098 .81136 L p .707 .577 .707 r
F P
0 g
s
.19786 .75903 m .19485 .72085 L .17356 .72031 L p .707 .577 .707 r
F P
0 g
s
.22288 .79903 m .22135 .77993 L .19397 .78068 L p .707 .577 .707 r
F P
0 g
s
.19397 .78068 m .19549 .79978 L .22288 .79903 L p .707 .577 .707 r
F P
0 g
s
.17356 .72031 m .17657 .75849 L .19786 .75903 L p .707 .577 .707 r
F P
0 g
s
.17446 .69913 m .17266 .64261 L .15982 .6372 L p .707 .577 .707 r
F P
0 g
s
.64458 .74263 m .63766 .70709 L .66479 .70797 L p .707 .577 .707 r
F P
0 g
s
.6657 .76804 m .66923 .7858 L .64231 .78485 L p .707 .577 .707 r
F P
0 g
s
.64231 .78485 m .63878 .76709 L .6657 .76804 L p .707 .577 .707 r
F P
0 g
s
.63035 .2979 m .63035 .79979 L .64306 .78817 L p .707 .577 .707 r
F P
0 g
s
.64306 .78817 m .64306 .28628 L .63035 .2979 L p .707 .577 .707 r
F P
0 g
s
.68629 .77272 m .68982 .79048 L .66923 .7858 L p .707 .577 .707 r
F P
0 g
s
.66923 .7858 m .6657 .76804 L .68629 .77272 L p .707 .577 .707 r
F P
0 g
s
.31344 .7719 m .31497 .791 L .33893 .78726 L p .707 .577 .707 r
F P
0 g
s
.33893 .78726 m .3374 .76816 L .31344 .7719 L p .707 .577 .707 r
F P
0 g
s
.33814 .70829 m .34114 .74647 L .35712 .74266 L p .707 .577 .707 r
F P
0 g
s
.35712 .74266 m .35411 .70448 L .33814 .70829 L p .707 .577 .707 r
F P
0 g
s
.66479 .70797 m .67171 .74351 L .64458 .74263 L p .707 .577 .707 r
F P
0 g
s
.15982 .6372 m .16163 .69372 L .17446 .69913 L p .707 .577 .707 r
F P
0 g
s
.19549 .79978 m .19397 .78068 L .17295 .78025 L p .707 .577 .707 r
F P
0 g
s
.17295 .78025 m .17448 .79935 L .19549 .79978 L p .707 .577 .707 r
F P
0 g
s
.35375 .63348 m .35555 .69001 L .36237 .68361 L p .707 .577 .707 r
F P
0 g
s
.36237 .68361 m .36057 .62708 L .35375 .63348 L p .707 .577 .707 r
F P
0 g
s
.17657 .75849 m .17356 .72031 L .16064 .71861 L p .707 .577 .707 r
F P
0 g
s
.16064 .71861 m .16365 .75679 L .17657 .75849 L p .707 .577 .707 r
F P
0 g
s
.3374 .76816 m .33893 .78726 L .35522 .78358 L p .707 .577 .707 r
F P
0 g
s
.35522 .78358 m .35369 .76448 L .3374 .76816 L p .707 .577 .707 r
F P
0 g
s
.16163 .69372 m .15982 .6372 L .15666 .63099 L p .707 .577 .707 r
F P
0 g
s
.35411 .70448 m .35712 .74266 L .36106 .74065 L p .707 .577 .707 r
F P
0 g
s
.36106 .74065 m .36379 .73925 L p .3609 .72887 L .707 .577 .707 r
F P
0 g
s
.3609 .72887 m .35411 .70448 L .36106 .74065 L .707 .577 .707 r
F
.35824 .28848 m .35694 .27638 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36379 .73925 m .36078 .70107 L .35411 .70448 L p .707 .577 .707 r
F P
0 g
s
.35921 .6774 m .3574 .62087 L .36057 .62708 L p .707 .577 .707 r
F P
0 g
s
.35369 .76448 m .35522 .78358 L .36081 .78098 L p .707 .577 .707 r
F P
0 g
s
.36081 .78098 m .36225 .78031 L p .36076 .77756 L .707 .577 .707 r
F P
0 g
s
.36076 .77756 m .35369 .76448 L .36081 .78098 L .707 .577 .707 r
F
.36225 .78031 m .36073 .76121 L .35369 .76448 L p F P
0 g
s
.3605 .73656 m .35974 .72693 L p .36078 .70107 L .707 .577 .707 r
F P
0 g
s
.35974 .72693 m .3575 .69838 L .36039 .70074 L p .707 .577 .707 r
F P
0 g
s
.36039 .70074 m .36078 .70107 L p .35974 .72693 L .707 .577 .707 r
F P
0 g
s
.3574 .62087 m .35921 .6774 L .34638 .67199 L p .707 .577 .707 r
F P
0 g
s
.35933 .77777 m .35781 .75867 L .36073 .76121 L p .707 .577 .707 r
F P
0 g
s
.3575 .69838 m .3605 .73656 L .34758 .73486 L p .707 .577 .707 r
F P
0 g
s
.35781 .75867 m .35933 .77777 L .34675 .77621 L p .707 .577 .707 r
F P
0 g
s
.35823 .7883 m .35824 .52952 L .35742 .46859 L .707 .578 .707 r
F
.35824 .79037 m .35824 .78808 L p .35823 .7883 L F P
0 g
s
.35824 .78808 m .35824 .52952 L p .35823 .7883 L .707 .578 .707 r
F P
0 g
s
.34638 .67199 m .34457 .61546 L .3574 .62087 L p .707 .577 .707 r
F P
0 g
s
.34758 .73486 m .34458 .69668 L .3575 .69838 L p .707 .577 .707 r
F P
0 g
s
.34675 .77621 m .34523 .75711 L .35781 .75867 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35824 .79037 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .27638 m .35694 .48851 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35694 .48851 m .35694 .77827 L p .3576 .53858 L .707 .578 .707 r
F P
0 g
s
.35824 .52952 m .35824 .28848 L p .35742 .46859 L .707 .578 .707 r
F P
0 g
s
.36057 .62708 m .36237 .68361 L .35921 .6774 L p .707 .577 .707 r
F P
0 g
s
.36078 .70107 m .36379 .73925 L .3605 .73656 L p .707 .577 .707 r
F P
0 g
s
.36073 .76121 m .36225 .78031 L .35933 .77777 L p .707 .577 .707 r
F P
0 g
s
.35824 .28848 m .35824 .79037 L .37341 .80178 L p .707 .577 .707 r
F P
0 g
s
.17448 .79935 m .17295 .78025 L .16037 .77869 L p .707 .577 .707 r
F P
0 g
s
.16037 .77869 m .1619 .79779 L .17448 .79935 L p .707 .577 .707 r
F P
0 g
s
.15666 .63099 m .15847 .68752 L .16163 .69372 L p .707 .577 .707 r
F P
0 g
s
.64306 .28628 m .64306 .78817 L .64176 .77607 L p .707 .578 .707 r
F P
0 g
s
.64176 .77607 m .64176 .27418 L .64306 .28628 L p .707 .578 .707 r
F P
0 g
s
.16365 .75679 m .16064 .71861 L .15735 .71592 L p .707 .577 .707 r
F P
0 g
s
.15735 .71592 m .16036 .7541 L .16365 .75679 L p .707 .577 .707 r
F P
0 g
s
.15847 .68752 m .15666 .63099 L .16348 .62459 L p .707 .577 .707 r
F P
0 g
s
.1619 .79779 m .16037 .77869 L .15746 .77616 L p .707 .577 .707 r
F P
0 g
s
.15746 .77616 m .15898 .79526 L .1619 .79779 L p .707 .577 .707 r
F P
0 g
s
.16348 .62459 m .16528 .68112 L .15847 .68752 L p .707 .577 .707 r
F P
0 g
s
.35694 .77827 m .35694 .27638 L .36964 .26476 L p .707 .577 .707 r
F P
0 g
s
.16036 .7541 m .15735 .71592 L .16402 .71251 L p .707 .577 .707 r
F P
0 g
s
.16402 .71251 m .16703 .75069 L .16036 .7541 L p .707 .577 .707 r
F P
0 g
s
.64176 .27418 m .64176 .77607 L .62658 .76466 L p .707 .577 .707 r
F P
0 g
s
.62658 .76466 m .62658 .26277 L .64176 .27418 L p .707 .577 .707 r
F P
0 g
s
.16528 .68112 m .16348 .62459 L .17961 .61863 L p .707 .577 .707 r
F P
0 g
s
.15898 .79526 m .15746 .77616 L .16449 .77289 L p .707 .577 .707 r
F P
0 g
s
.16449 .77289 m .16601 .79199 L .15898 .79526 L p .707 .577 .707 r
F P
0 g
s
.17961 .61863 m .18141 .67515 L .16528 .68112 L p .707 .577 .707 r
F P
0 g
s
.34457 .61546 m .34638 .67199 L .32513 .66791 L p .707 .577 .707 r
F P
0 g
s
.32513 .66791 m .32333 .61138 L .34457 .61546 L p .707 .577 .707 r
F P
0 g
s
.16703 .75069 m .16402 .71251 L .18 .7087 L p .707 .577 .707 r
F P
0 g
s
.18 .7087 m .183 .74688 L .16703 .75069 L p .707 .577 .707 r
F P
0 g
s
.18141 .67515 m .17961 .61863 L .20347 .61368 L p .707 .577 .707 r
F P
0 g
s
.36964 .76665 m .36964 .26476 L .39511 .25476 L p .707 .577 .707 r
F P
0 g
s
.36964 .26476 m .36964 .76665 L .35694 .77827 L p .707 .577 .707 r
F P
0 g
s
.62658 .26277 m .62658 .76466 L .59902 .75507 L p .707 .577 .707 r
F P
0 g
s
.59902 .75507 m .59902 .25318 L .62658 .26277 L p .707 .577 .707 r
F P
0 g
s
.20347 .61368 m .20528 .67021 L .18141 .67515 L p .707 .577 .707 r
F P
0 g
s
.34458 .69668 m .34758 .73486 L .32629 .73432 L p .707 .577 .707 r
F P
0 g
s
.32629 .73432 m .32328 .69614 L .34458 .69668 L p .707 .577 .707 r
F P
0 g
s
.16601 .79199 m .16449 .77289 L .18078 .7692 L p .707 .577 .707 r
F P
0 g
s
.32333 .61138 m .32513 .66791 L .29755 .66556 L p .707 .577 .707 r
F P
0 g
s
.29755 .66556 m .29574 .60903 L .32333 .61138 L p .707 .577 .707 r
F P
0 g
s
.18078 .7692 m .1823 .7883 L .16601 .79199 L p .707 .577 .707 r
F P
0 g
s
.20528 .67021 m .20347 .61368 L .23273 .61024 L p .707 .577 .707 r
F P
0 g
s
.183 .74688 m .18 .7087 L .20371 .70487 L p .707 .577 .707 r
F P
0 g
s
.20371 .70487 m .20672 .74305 L .183 .74688 L p .707 .577 .707 r
F P
0 g
s
.34523 .75711 m .34675 .77621 L .32574 .77579 L p .707 .577 .707 r
F P
0 g
s
.32574 .77579 m .32422 .75669 L .34523 .75711 L p .707 .577 .707 r
F P
0 g
s
.29574 .60903 m .29755 .66556 L .26633 .66516 L p .707 .577 .707 r
F P
0 g
s
.26633 .66516 m .26453 .60864 L .29574 .60903 L p .707 .577 .707 r
F P
0 g
s
.23273 .61024 m .23454 .66677 L .20528 .67021 L p .707 .577 .707 r
F P
0 g
s
.73366 .6639 m .73547 .60961 L .70425 .60639 L p .707 .577 .707 r
F P
0 g
s
.73547 .60961 m .73366 .6639 L .76546 .66377 L p .707 .577 .707 r
F P
0 g
s
.76546 .66377 m .76726 .60948 L .73547 .60961 L p .707 .577 .707 r
F P
0 g
s
.23454 .66677 m .23273 .61024 L .26453 .60864 L p .707 .577 .707 r
F P
0 g
s
.32328 .69614 m .32629 .73432 L .29871 .73499 L p .707 .577 .707 r
F P
0 g
s
.29871 .73499 m .29571 .69681 L .32328 .69614 L p .707 .577 .707 r
F P
0 g
s
.76726 .60948 m .76546 .66377 L .79472 .66031 L p .707 .577 .707 r
F P
0 g
s
.79472 .66031 m .79652 .60601 L .76726 .60948 L p .707 .577 .707 r
F P
0 g
s
.26453 .60864 m .26633 .66516 L .23454 .66677 L p .707 .577 .707 r
F P
0 g
s
.39511 .25476 m .39511 .75665 L .36964 .76665 L p .707 .577 .707 r
F P
0 g
s
.39511 .75665 m .39511 .25476 L .43084 .24736 L p .707 .577 .707 r
F P
0 g
s
.70245 .66068 m .70425 .60639 L .67667 .60013 L p .707 .577 .707 r
F P
0 g
s
.70425 .60639 m .70245 .66068 L .73366 .6639 L p .707 .577 .707 r
F P
0 g
s
.1823 .7883 m .18078 .7692 L .20474 .76547 L p .707 .577 .707 r
F P
0 g
s
.20474 .76547 m .20626 .78457 L .1823 .7883 L p .707 .577 .707 r
F P
0 g
s
.20672 .74305 m .20371 .70487 L .23284 .7014 L p .707 .577 .707 r
F P
0 g
s
.59902 .25318 m .59902 .75507 L .56176 .74824 L p .707 .577 .707 r
F P
0 g
s
.56176 .74824 m .56176 .24635 L .59902 .25318 L p .707 .577 .707 r
F P
0 g
s
.23284 .7014 m .23585 .73958 L .20672 .74305 L p .707 .577 .707 r
F P
0 g
s
.79652 .60601 m .79472 .66031 L .81858 .65384 L p .707 .577 .707 r
F P
0 g
s
.81858 .65384 m .82039 .59955 L .79652 .60601 L p .707 .577 .707 r
F P
0 g
s
.32422 .75669 m .32574 .77579 L .29835 .77654 L p .707 .577 .707 r
F P
0 g
s
.29835 .77654 m .29683 .75744 L .32422 .75669 L p .707 .577 .707 r
F P
0 g
s
.29571 .69681 m .29871 .73499 L .26755 .7368 L p .707 .577 .707 r
F P
0 g
s
.26755 .7368 m .26454 .69862 L .29571 .69681 L p .707 .577 .707 r
F P
0 g
s
.67487 .65443 m .67667 .60013 L .65543 .59146 L p .707 .577 .707 r
F P
0 g
s
.67667 .60013 m .67487 .65443 L .70245 .66068 L p .707 .577 .707 r
F P
0 g
s
.23585 .73958 m .23284 .7014 L .26454 .69862 L p .707 .577 .707 r
F P
0 g
s
.26454 .69862 m .26755 .7368 L .23585 .73958 L p .707 .577 .707 r
F P
0 g
s
.73245 .73282 m .73545 .6983 L .70429 .69319 L p .707 .577 .707 r
F P
0 g
s
.73545 .6983 m .73245 .73282 L .76415 .73362 L p .707 .577 .707 r
F P
0 g
s
.76415 .73362 m .76715 .6991 L .73545 .6983 L p .707 .577 .707 r
F P
0 g
s
.20626 .78457 m .20474 .76547 L .23401 .76205 L p .707 .577 .707 r
F P
0 g
s
.23401 .76205 m .23554 .78115 L .20626 .78457 L p .707 .577 .707 r
F P
0 g
s
.76715 .6991 m .76415 .73362 L .79328 .73003 L p .707 .577 .707 r
F P
0 g
s
.79328 .73003 m .79629 .69551 L .76715 .6991 L p .707 .577 .707 r
F P
0 g
s
.70129 .72771 m .70429 .69319 L .67671 .68426 L p .707 .577 .707 r
F P
0 g
s
.70429 .69319 m .70129 .72771 L .73245 .73282 L p .707 .577 .707 r
F P
0 g
s
.43084 .74925 m .43084 .24736 L .47334 .24329 L p .707 .577 .707 r
F P
0 g
s
.43084 .24736 m .43084 .74925 L .39511 .75665 L p .707 .577 .707 r
F P
0 g
s
.29683 .75744 m .29835 .77654 L .26727 .77838 L p .707 .577 .707 r
F P
0 g
s
.26727 .77838 m .26575 .75928 L .29683 .75744 L p .707 .577 .707 r
F P
0 g
s
.82039 .59955 m .81858 .65384 L .83471 .64502 L p .707 .577 .707 r
F P
0 g
s
.83471 .64502 m .83652 .59072 L .82039 .59955 L p .707 .577 .707 r
F P
0 g
s
.56176 .24635 m .56176 .74824 L .51845 .74483 L p .707 .577 .707 r
F P
0 g
s
.51845 .74483 m .51845 .24294 L .56176 .24635 L p .707 .577 .707 r
F P
0 g
s
.23554 .78115 m .23401 .76205 L .26575 .75928 L p .707 .577 .707 r
F P
0 g
s
.65543 .59146 m .65362 .64576 L .67487 .65443 L p .707 .577 .707 r
F P
0 g
s
.26575 .75928 m .26727 .77838 L .23554 .78115 L p .707 .577 .707 r
F P
0 g
s
.65362 .64576 m .65543 .59146 L .64259 .58121 L p .707 .577 .707 r
F P
0 g
s
.79629 .69551 m .79328 .73003 L .817 .7224 L p .707 .577 .707 r
F P
0 g
s
.817 .7224 m .82 .68788 L .79629 .69551 L p .707 .577 .707 r
F P
0 g
s
.73273 .7761 m .73425 .75889 L .70317 .75357 L p .707 .577 .707 r
F P
0 g
s
.73425 .75889 m .73273 .7761 L .76446 .77708 L p .707 .577 .707 r
F P
0 g
s
.76446 .77708 m .76598 .75987 L .73425 .75889 L p .707 .577 .707 r
F P
0 g
s
.67371 .71878 m .67671 .68426 L .65542 .6724 L p .707 .577 .707 r
F P
0 g
s
.67671 .68426 m .67371 .71878 L .70129 .72771 L p .707 .577 .707 r
F P
0 g
s
.47334 .74518 m .47334 .24329 L .51845 .24294 L p .707 .577 .707 r
F P
0 g
s
.47334 .24329 m .47334 .74518 L .43084 .74925 L p .707 .577 .707 r
F P
0 g
s
.76598 .75987 m .76446 .77708 L .79374 .77361 L p .707 .577 .707 r
F P
0 g
s
.79374 .77361 m .79526 .7564 L .76598 .75987 L p .707 .577 .707 r
F P
0 g
s
.51845 .24294 m .51845 .74483 L .47334 .74518 L p .707 .577 .707 r
F P
0 g
s
.70164 .77078 m .70317 .75357 L .67578 .74441 L p .707 .577 .707 r
F P
0 g
s
.70317 .75357 m .70164 .77078 L .73273 .7761 L p .707 .577 .707 r
F P
0 g
s
.67578 .74441 m .67426 .76162 L .70164 .77078 L p .707 .577 .707 r
F P
0 g
s
.79526 .7564 m .79374 .77361 L .81769 .76604 L p .707 .577 .707 r
F P
0 g
s
.81769 .76604 m .81922 .74882 L .79526 .7564 L p .707 .577 .707 r
F P
0 g
s
.83652 .59072 m .83471 .64502 L .84153 .63469 L p .707 .577 .707 r
F P
0 g
s
.84153 .63469 m .84334 .5804 L .83652 .59072 L p .707 .577 .707 r
F P
0 g
s
.65542 .6724 m .65242 .70692 L .67371 .71878 L p .707 .577 .707 r
F P
0 g
s
.64259 .58121 m .64079 .63551 L .65362 .64576 L p .707 .577 .707 r
F P
0 g
s
.67426 .76162 m .67578 .74441 L .65477 .73232 L p .707 .577 .707 r
F P
0 g
s
.82 .68788 m .817 .7224 L .83297 .71148 L p .707 .577 .707 r
F P
0 g
s
.83297 .71148 m .83597 .67696 L .82 .68788 L p .707 .577 .707 r
F P
0 g
s
.65242 .70692 m .65542 .6724 L .6425 .65877 L p .707 .577 .707 r
F P
0 g
s
.64079 .63551 m .64259 .58121 L .63943 .5704 L p .707 .577 .707 r
F P
0 g
s
.65477 .73232 m .65325 .74953 L .67426 .76162 L p .707 .577 .707 r
F P
0 g
s
.81922 .74882 m .81769 .76604 L .83399 .7551 L p .707 .577 .707 r
F P
0 g
s
.83399 .7551 m .83551 .73789 L .81922 .74882 L p .707 .577 .707 r
F P
0 g
s
.6425 .65877 m .6395 .69329 L .65242 .70692 L p .707 .577 .707 r
F P
0 g
s
.65325 .74953 m .65477 .73232 L .64219 .71849 L p .707 .577 .707 r
F P
0 g
s
.83597 .67696 m .83297 .71148 L .83964 .69834 L p .707 .577 .707 r
F P
0 g
s
.83964 .69834 m .84264 .66382 L .83597 .67696 L p .707 .577 .707 r
F P
0 g
s
.63943 .5704 m .63763 .62469 L .64079 .63551 L p .707 .577 .707 r
F P
0 g
s
.84334 .5804 m .84153 .63469 L .83837 .62388 L p .707 .577 .707 r
F P
0 g
s
.83837 .62388 m .84017 .56958 L .84334 .5804 L p .707 .577 .707 r
F P
0 g
s
.6395 .69329 m .6425 .65877 L .63921 .64469 L p .707 .577 .707 r
F P
0 g
s
.64219 .71849 m .64067 .7357 L .65325 .74953 L p .707 .577 .707 r
F P
0 g
s
.63763 .62469 m .63943 .5704 L .64625 .56007 L p .707 .577 .707 r
F P
0 g
s
.83551 .73789 m .83399 .7551 L .84102 .74186 L p .707 .577 .707 r
F P
0 g
s
.84102 .74186 m .84254 .72465 L .83551 .73789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63921 .64469 m .63621 .67921 L .6395 .69329 L p .707 .577 .707 r
F P
0 g
s
.64067 .7357 m .64219 .71849 L .63927 .70426 L p .707 .577 .707 r
F P
0 g
s
.84264 .66382 m .83964 .69834 L .83635 .68426 L p .707 .577 .707 r
F P
0 g
s
.83635 .68426 m .83936 .64974 L .84264 .66382 L p .707 .577 .707 r
F P
0 g
s
.63927 .70426 m .63775 .72147 L .64067 .7357 L p .707 .577 .707 r
F P
0 g
s
.64625 .56007 m .64444 .61437 L .63763 .62469 L p .707 .577 .707 r
F P
0 g
s
.63621 .67921 m .63921 .64469 L .64588 .63154 L p .707 .577 .707 r
F P
0 g
s
.84017 .56958 m .83837 .62388 L .82554 .61363 L p .707 .577 .707 r
F P
0 g
s
.82554 .61363 m .82734 .55934 L .84017 .56958 L p .707 .577 .707 r
F P
0 g
s
.64444 .61437 m .64625 .56007 L .66238 .55125 L p .707 .577 .707 r
F P
0 g
s
.38989 .61718 m .39408 .56128 L .36294 .55745 L p .707 .577 .707 r
F P
0 g
s
.39408 .56128 m .38989 .61718 L .42162 .61868 L p .707 .577 .707 r
F P
0 g
s
.42162 .61868 m .42581 .56278 L .39408 .56128 L p .707 .577 .707 r
F P
0 g
s
.84254 .72465 m .84102 .74186 L .8381 .72763 L p .707 .577 .707 r
F P
0 g
s
.8381 .72763 m .83962 .71042 L .84254 .72465 L p .707 .577 .707 r
F P
0 g
s
.42581 .56278 m .42162 .61868 L .45083 .6177 L p .707 .577 .707 r
F P
0 g
s
.45083 .6177 m .45502 .5618 L .42581 .56278 L p .707 .577 .707 r
F P
0 g
s
.64588 .63154 m .64288 .66606 L .63621 .67921 L p .707 .577 .707 r
F P
0 g
s
.63775 .72147 m .63927 .70426 L .6463 .69102 L p .707 .577 .707 r
F P
0 g
s
.35875 .61334 m .36294 .55745 L .33543 .55166 L p .707 .577 .707 r
F P
0 g
s
.36294 .55745 m .35875 .61334 L .38989 .61718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83936 .64974 m .83635 .68426 L .82343 .67062 L p .707 .577 .707 r
F P
0 g
s
.82343 .67062 m .82644 .6361 L .83936 .64974 L p .707 .577 .707 r
F P
0 g
s
.6463 .69102 m .64478 .70823 L .63775 .72147 L p .707 .577 .707 r
F P
0 g
s
.82734 .55934 m .82554 .61363 L .80429 .60496 L p .707 .577 .707 r
F P
0 g
s
.80429 .60496 m .8061 .55066 L .82734 .55934 L p .707 .577 .707 r
F P
0 g
s
.64288 .66606 m .64588 .63154 L .66186 .62062 L p .707 .577 .707 r
F P
0 g
s
.66238 .55125 m .66057 .60554 L .64444 .61437 L p .707 .577 .707 r
F P
0 g
s
.45502 .5618 m .45083 .6177 L .47466 .61433 L p .707 .577 .707 r
F P
0 g
s
.47466 .61433 m .47885 .55844 L .45502 .5618 L p .707 .577 .707 r
F P
0 g
s
.33543 .55166 m .33124 .60755 L .35875 .61334 L p .707 .577 .707 r
F P
0 g
s
.38613 .67239 m .39305 .63525 L .36233 .62842 L p .707 .577 .707 r
F P
0 g
s
.39305 .63525 m .38613 .67239 L .41742 .6774 L p .707 .577 .707 r
F P
0 g
s
.41742 .6774 m .42434 .64027 L .39305 .63525 L p .707 .577 .707 r
F P
0 g
s
.33124 .60755 m .33543 .55166 L .31425 .54448 L p .707 .577 .707 r
F P
0 g
s
.66057 .60554 m .66238 .55125 L .68624 .54479 L p .707 .577 .707 r
F P
0 g
s
.42434 .64027 m .41742 .6774 L .44623 .68012 L p .707 .577 .707 r
F P
0 g
s
.44623 .68012 m .45315 .64298 L .42434 .64027 L p .707 .577 .707 r
F P
0 g
s
.35541 .66556 m .36233 .62842 L .33521 .62045 L p .707 .577 .707 r
F P
0 g
s
.36233 .62842 m .35541 .66556 L .38613 .67239 L p .707 .577 .707 r
F P
0 g
s
.83962 .71042 m .8381 .72763 L .82552 .7138 L p .707 .577 .707 r
F P
0 g
s
.82552 .7138 m .82704 .69658 L .83962 .71042 L p .707 .577 .707 r
F P
0 g
s
.66186 .62062 m .65885 .65514 L .64288 .66606 L p .707 .577 .707 r
F P
0 g
s
.33521 .62045 m .32828 .65758 L .35541 .66556 L p .707 .577 .707 r
F P
0 g
s
.64478 .70823 m .6463 .69102 L .6626 .68008 L p .707 .577 .707 r
F P
0 g
s
.31425 .54448 m .31006 .60037 L .33124 .60755 L p .707 .577 .707 r
F P
0 g
s
.3883 .71373 m .39182 .69517 L .36121 .68818 L p .707 .577 .707 r
F P
0 g
s
.39182 .69517 m .3883 .71373 L .41961 .71893 L p .707 .577 .707 r
F P
0 g
s
.41961 .71893 m .42313 .70037 L .39182 .69517 L p .707 .577 .707 r
F P
0 g
s
.47885 .55844 m .47466 .61433 L .49077 .60891 L p .707 .577 .707 r
F P
0 g
s
.49077 .60891 m .49497 .55302 L .47885 .55844 L p .707 .577 .707 r
F P
0 g
s
.8061 .55066 m .80429 .60496 L .77671 .59871 L p .707 .577 .707 r
F P
0 g
s
.77671 .59871 m .77852 .54441 L .8061 .55066 L p .707 .577 .707 r
F P
0 g
s
.45315 .64298 m .44623 .68012 L .46974 .68026 L p .707 .577 .707 r
F P
0 g
s
.46974 .68026 m .47666 .64313 L .45315 .64298 L p .707 .577 .707 r
F P
0 g
s
.82644 .6361 m .82343 .67062 L .80214 .65876 L p .707 .577 .707 r
F P
0 g
s
.80214 .65876 m .80514 .62424 L .82644 .6361 L p .707 .577 .707 r
F P
0 g
s
.36121 .68818 m .35769 .70674 L .3883 .71373 L p .707 .577 .707 r
F P
0 g
s
.32828 .65758 m .33521 .62045 L .31432 .61211 L p .707 .577 .707 r
F P
0 g
s
.42313 .70037 m .41961 .71893 L .44855 .72184 L p .707 .577 .707 r
F P
0 g
s
.44855 .72184 m .45207 .70328 L .42313 .70037 L p .707 .577 .707 r
F P
0 g
s
.65885 .65514 m .66186 .62062 L .68557 .613 L p .707 .577 .707 r
F P
0 g
s
.6626 .68008 m .66107 .69729 L .64478 .70823 L p .707 .577 .707 r
F P
0 g
s
.68624 .54479 m .68444 .59908 L .66057 .60554 L p .707 .577 .707 r
F P
0 g
s
.35769 .70674 m .36121 .68818 L .3343 .68009 L p .707 .577 .707 r
F P
0 g
s
.68444 .59908 m .68624 .54479 L .71551 .54132 L p .707 .577 .707 r
F P
0 g
s
.31006 .60037 m .31425 .54448 L .30147 .53661 L p .707 .577 .707 r
F P
0 g
s
.3343 .68009 m .33077 .69865 L .35769 .70674 L p .707 .577 .707 r
F P
0 g
s
.31432 .61211 m .3074 .64925 L .32828 .65758 L p .707 .577 .707 r
F P
0 g
s
.77852 .54441 m .77671 .59871 L .74549 .59549 L p .707 .577 .707 r
F P
0 g
s
.74549 .59549 m .7473 .54119 L .77852 .54441 L p .707 .577 .707 r
F P
0 g
s
.45207 .70328 m .44855 .72184 L .47229 .72217 L p .707 .577 .707 r
F P
0 g
s
.47229 .72217 m .47582 .70361 L .45207 .70328 L p .707 .577 .707 r
F P
0 g
s
.82704 .69658 m .82552 .7138 L .80451 .70171 L p .707 .577 .707 r
F P
0 g
s
.80451 .70171 m .80603 .6845 L .82704 .69658 L p .707 .577 .707 r
F P
0 g
s
.7137 .59562 m .71551 .54132 L .7473 .54119 L p .707 .577 .707 r
F P
0 g
s
.71551 .54132 m .7137 .59562 L .68444 .59908 L p .707 .577 .707 r
F P
0 g
s
.30147 .53661 m .29728 .5925 L .31006 .60037 L p .707 .577 .707 r
F P
0 g
s
.68557 .613 m .68257 .64752 L .65885 .65514 L p .707 .577 .707 r
F P
0 g
s
.33077 .69865 m .3343 .68009 L .31371 .67169 L p .707 .577 .707 r
F P
0 g
s
.66107 .69729 m .6626 .68008 L .68655 .67251 L p .707 .577 .707 r
F P
0 g
s
.7473 .54119 m .74549 .59549 L .7137 .59562 L p .707 .577 .707 r
F P
0 g
s
.80514 .62424 m .80214 .65876 L .77456 .64984 L p .707 .577 .707 r
F P
0 g
s
.77456 .64984 m .77757 .61532 L .80514 .62424 L p .707 .577 .707 r
F P
0 g
s
.47666 .64313 m .46974 .68026 L .48564 .67782 L p .707 .577 .707 r
F P
0 g
s
.48564 .67782 m .49256 .64069 L .47666 .64313 L p .707 .577 .707 r
F P
0 g
s
.68257 .64752 m .68557 .613 L .7147 .60941 L p .707 .577 .707 r
F P
0 g
s
.31371 .67169 m .31018 .69025 L .33077 .69865 L p .707 .577 .707 r
F P
0 g
s
.3074 .64925 m .31432 .61211 L .30172 .60423 L p .707 .577 .707 r
F P
0 g
s
.49497 .55302 m .49077 .60891 L .4976 .60197 L p .707 .577 .707 r
F P
0 g
s
.4976 .60197 m .5018 .54607 L .49497 .55302 L p .707 .577 .707 r
F P
0 g
s
.68655 .67251 m .68503 .68972 L .66107 .69729 L p .707 .577 .707 r
F P
0 g
s
.30172 .60423 m .2948 .64136 L .3074 .64925 L p .707 .577 .707 r
F P
0 g
s
.29728 .5925 m .30147 .53661 L .29834 .52882 L p .707 .577 .707 r
F P
0 g
s
.77757 .61532 m .77456 .64984 L .7434 .64473 L p .707 .577 .707 r
F P
0 g
s
.7434 .64473 m .7464 .61021 L .77757 .61532 L p .707 .577 .707 r
F P
0 g
s
.7117 .64393 m .7147 .60941 L .7464 .61021 L p .707 .577 .707 r
F P
0 g
s
.7147 .60941 m .7117 .64393 L .68257 .64752 L p .707 .577 .707 r
F P
0 g
s
.80603 .6845 m .80451 .70171 L .77712 .69255 L p .707 .577 .707 r
F P
0 g
s
.77712 .69255 m .77865 .67534 L .80603 .6845 L p .707 .577 .707 r
F P
0 g
s
.47582 .70361 m .47229 .72217 L .48851 .71989 L p .707 .577 .707 r
F P
0 g
s
.48851 .71989 m .49203 .70133 L .47582 .70361 L p .707 .577 .707 r
F P
0 g
s
.7464 .61021 m .7434 .64473 L .7117 .64393 L p .707 .577 .707 r
F P
0 g
s
.68503 .68972 m .68655 .67251 L .71583 .66904 L p .707 .577 .707 r
F P
0 g
s
.31018 .69025 m .31371 .67169 L .30146 .6638 L p .707 .577 .707 r
F P
0 g
s
.30146 .6638 m .29794 .68236 L .31018 .69025 L p .707 .577 .707 r
F P
0 g
s
.29834 .52882 m .29415 .58471 L .29728 .5925 L p .707 .577 .707 r
F P
0 g
s
.71583 .66904 m .71431 .68625 L .68503 .68972 L p .707 .577 .707 r
F P
0 g
s
.49256 .64069 m .48564 .67782 L .49238 .67304 L p .707 .577 .707 r
F P
0 g
s
.49238 .67304 m .4993 .6359 L .49256 .64069 L p .707 .577 .707 r
F P
0 g
s
.77865 .67534 m .77712 .69255 L .74604 .68723 L p .707 .577 .707 r
F P
0 g
s
.74604 .68723 m .74756 .67002 L .77865 .67534 L p .707 .577 .707 r
F P
0 g
s
.71431 .68625 m .71583 .66904 L .74756 .67002 L p .707 .577 .707 r
F P
0 g
s
.2948 .64136 m .30172 .60423 L .29864 .59757 L p .707 .577 .707 r
F P
0 g
s
.74756 .67002 m .74604 .68723 L .71431 .68625 L p .707 .577 .707 r
F P
0 g
s
.5018 .54607 m .4976 .60197 L .49448 .59418 L p .707 .577 .707 r
F P
0 g
s
.49448 .59418 m .49867 .53829 L .5018 .54607 L p .707 .577 .707 r
F P
0 g
s
.29864 .59757 m .29172 .6347 L .2948 .64136 L p .707 .577 .707 r
F P
0 g
s
.49203 .70133 m .48851 .71989 L .49561 .71522 L p .707 .577 .707 r
F P
0 g
s
.49561 .71522 m .49914 .69666 L .49203 .70133 L p .707 .577 .707 r
F P
0 g
s
.29415 .58471 m .29834 .52882 L .30517 .52188 L p .707 .577 .707 r
F P
0 g
s
.29794 .68236 m .30146 .6638 L .29876 .6572 L p .707 .577 .707 r
F P
0 g
s
.29876 .6572 m .29523 .67576 L .29794 .68236 L p .707 .577 .707 r
F P
0 g
s
.30517 .52188 m .30098 .57777 L .29415 .58471 L p .707 .577 .707 r
F P
0 g
s
.4993 .6359 m .49238 .67304 L .4893 .66638 L p .707 .577 .707 r
F P
0 g
s
.4893 .66638 m .49622 .62924 L .4993 .6359 L p .707 .577 .707 r
F P
0 g
s
.29172 .6347 m .29864 .59757 L .30538 .59279 L p .707 .577 .707 r
F P
0 g
s
.49867 .53829 m .49448 .59418 L .4817 .58631 L p .707 .577 .707 r
F P
0 g
s
.4817 .58631 m .48589 .53042 L .49867 .53829 L p .707 .577 .707 r
F P
0 g
s
.30538 .59279 m .29846 .62992 L .29172 .6347 L p .707 .577 .707 r
F P
0 g
s
.30098 .57777 m .30517 .52188 L .32129 .51646 L p .707 .577 .707 r
F P
0 g
s
.49914 .69666 m .49561 .71522 L .49291 .70862 L p .707 .577 .707 r
F P
0 g
s
.49291 .70862 m .49644 .69006 L .49914 .69666 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29523 .67576 m .29876 .6572 L .30587 .65253 L p .707 .577 .707 r
F P
0 g
s
.30587 .65253 m .30234 .67109 L .29523 .67576 L p .707 .577 .707 r
F P
0 g
s
.32129 .51646 m .3171 .57235 L .30098 .57777 L p .707 .577 .707 r
F P
0 g
s
.49622 .62924 m .4893 .66638 L .4767 .65849 L p .707 .577 .707 r
F P
0 g
s
.4767 .65849 m .48362 .62136 L .49622 .62924 L p .707 .577 .707 r
F P
0 g
s
.29846 .62992 m .30538 .59279 L .32128 .59035 L p .707 .577 .707 r
F P
0 g
s
.48589 .53042 m .4817 .58631 L .46051 .57913 L p .707 .577 .707 r
F P
0 g
s
.46051 .57913 m .46471 .52323 L .48589 .53042 L p .707 .577 .707 r
F P
0 g
s
.3171 .57235 m .32129 .51646 L .34512 .51309 L p .707 .577 .707 r
F P
0 g
s
.32128 .59035 m .31436 .62748 L .29846 .62992 L p .707 .577 .707 r
F P
0 g
s
.49644 .69006 m .49291 .70862 L .48067 .70073 L p .707 .577 .707 r
F P
0 g
s
.48067 .70073 m .48419 .68217 L .49644 .69006 L p .707 .577 .707 r
F P
0 g
s
.30234 .67109 m .30587 .65253 L .32208 .65025 L p .707 .577 .707 r
F P
0 g
s
.34512 .51309 m .34093 .56899 L .3171 .57235 L p .707 .577 .707 r
F P
0 g
s
.32208 .65025 m .31856 .6688 L .30234 .67109 L p .707 .577 .707 r
F P
0 g
s
.46471 .52323 m .46051 .57913 L .43301 .57334 L p .707 .577 .707 r
F P
0 g
s
.43301 .57334 m .4372 .51744 L .46471 .52323 L p .707 .577 .707 r
F P
0 g
s
.48362 .62136 m .4767 .65849 L .45582 .65016 L p .707 .577 .707 r
F P
0 g
s
.45582 .65016 m .46274 .61302 L .48362 .62136 L p .707 .577 .707 r
F P
0 g
s
.31436 .62748 m .32128 .59035 L .34479 .59049 L p .707 .577 .707 r
F P
0 g
s
.34093 .56899 m .34512 .51309 L .37433 .51211 L p .707 .577 .707 r
F P
0 g
s
.34479 .59049 m .33787 .62763 L .31436 .62748 L p .707 .577 .707 r
F P
0 g
s
.4372 .51744 m .43301 .57334 L .40186 .56951 L p .707 .577 .707 r
F P
0 g
s
.40186 .56951 m .40606 .51361 L .4372 .51744 L p .707 .577 .707 r
F P
0 g
s
.48419 .68217 m .48067 .70073 L .46008 .69233 L p .707 .577 .707 r
F P
0 g
s
.46008 .69233 m .4636 .67377 L .48419 .68217 L p .707 .577 .707 r
F P
0 g
s
.37014 .56801 m .37433 .51211 L .40606 .51361 L p .707 .577 .707 r
F P
0 g
s
.37433 .51211 m .37014 .56801 L .34093 .56899 L p .707 .577 .707 r
F P
0 g
s
.40606 .51361 m .40186 .56951 L .37014 .56801 L p .707 .577 .707 r
F P
0 g
s
.31856 .6688 m .32208 .65025 L .34583 .65058 L p .707 .577 .707 r
F P
0 g
s
.46274 .61302 m .45582 .65016 L .42869 .64218 L p .707 .577 .707 r
F P
0 g
s
.42869 .64218 m .43561 .60505 L .46274 .61302 L p .707 .577 .707 r
F P
0 g
s
.34583 .65058 m .3423 .66913 L .31856 .6688 L p .707 .577 .707 r
F P
0 g
s
.33787 .62763 m .34479 .59049 L .3736 .5932 L p .707 .577 .707 r
F P
0 g
s
.3736 .5932 m .36668 .63034 L .33787 .62763 L p .707 .577 .707 r
F P
0 g
s
.43561 .60505 m .42869 .64218 L .39797 .63536 L p .707 .577 .707 r
F P
0 g
s
.39797 .63536 m .4049 .59822 L .43561 .60505 L p .707 .577 .707 r
F P
0 g
s
.4636 .67377 m .46008 .69233 L .43316 .68424 L p .707 .577 .707 r
F P
0 g
s
.43316 .68424 m .43669 .66568 L .4636 .67377 L p .707 .577 .707 r
F P
0 g
s
.36668 .63034 m .3736 .5932 L .4049 .59822 L p .707 .577 .707 r
F P
0 g
s
.3423 .66913 m .34583 .65058 L .37477 .65349 L p .707 .577 .707 r
F P
0 g
s
.4049 .59822 m .39797 .63536 L .36668 .63034 L p .707 .577 .707 r
F P
0 g
s
.37477 .65349 m .37124 .67204 L .3423 .66913 L p .707 .577 .707 r
F P
0 g
s
.43669 .66568 m .43316 .68424 L .40255 .67725 L p .707 .577 .707 r
F P
0 g
s
.40255 .67725 m .40608 .65869 L .43669 .66568 L p .707 .577 .707 r
F P
0 g
s
.37124 .67204 m .37477 .65349 L .40608 .65869 L p .707 .577 .707 r
F P
0 g
s
.40608 .65869 m .40255 .67725 L .37124 .67204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001OOol@00000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001J
Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001HOol2
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80006FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0025YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00001UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0000AOolA0014Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000Moo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000<003Yoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000gOol005Aoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`00=Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02000cOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
02moo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP06001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`03001JEP0000=JEPD00003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H0
05YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol01000FUH005YF0P001UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF1P000eYF00<005YFFUH00eYF00@005YF
FUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50004FUH01000FUIJEUYF0P001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<00003FUH005YF009JEP8000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008002eoo`00Dgoo0P000eYF3`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00<005YF
00000P000UYF00<005YFFUH015YF00@005YFFUIJEPL0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00AJEP@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
0eYF00<005YFFUH00eYF1P002Goo1@000goo1P001UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000`00
1eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUH0000300000eYF00000002000:Ool5
0009Ool40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP8000=JEP03001JEUYF00=JEPL000=oo`D000Yoo`L000AJEP04001JEUYFFUH2
000]Ool003iooaH00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH015YF60000eYF
00@005YFFUIJEP<00003FUH005YF009JEP8002eoo`00=goo1`0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF20002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUH005YF00800003FUH005YF00AJEPL000AJEP03001JEUYF00IJEP03001JEUYF009JEPH0
00=JEP03001JEUYF00AJEP8000=JEP8002eoo`00<Woo1@000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP<00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YF00000UYF0P00;Goo000`
Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P001UYF00<005YFFUH01000;Goo000^Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH40005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000
FUIJEUYF0`00;Goo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP0200000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH3000]Ool002aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000800003FUH005YF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPH000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH0000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00D0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=J
EP000000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF1@001UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF00000P00;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP040002FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH01P00
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00D005YFFUIJEP0000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF
00=JEPL000QJEP03001JEUYF00EJEPH000EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP000080009JEP04001JEUYFFUH>00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000/Ool01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0P0000=JEP00FUH01EYF00D005YFFUIJEP0002ioo`00;7oo00@005YFFUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00AJEP8000=J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP80
009JEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP04001JEUYF
FUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00@000EJEP03001JEUYF00AJEP05001JEP00001JEP020006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUH005YF0`0015YF00<005YFFUH00eYF00<005YFFUH00P0017oo
4P001goo0P000eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF5@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF100000=JEP00FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEP00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0P007goo0P0000MJEP00FUIJEP00FUH0000]Ool002eoo`03001JEP0000=JEP04001JEUYFFUH80008
FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0400015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000`0015YF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP000080009JEP05001JEUYFFUH00005FUH00`00FUIJEP0A000BOol20002FUH00`00
FUH0000]Ool002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000AJEP8000EJEP@00003FUH0000000L000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=J
EP04001JEUYF0004FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04000@Ool01@00FUH005YF0000
;Goo000]Ool01000FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF00<005YF00000P000UYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPL0
00IJEP03001JEUYF00EJEP03001JEP0000D000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEP000004FUH800000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4
000<Ool01@00FUH005YF0000;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP00
00EJEP<000=JEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP8000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP000004FUH01000FUH000001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`002Goo0`00;Woo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YF000010000eYF00<005YFFUH00UYF1@001UYF10001EYF00<005YFFUH015YF
0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`800003
FUH0000002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP03FUH50004FUH50007FUH00`00
FUIJEP0400000eYF001JEP05FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEQ4000AJEP03
001JEUYF00IJEPD000=JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH0000000<000MJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
0eYF20003goo1P001eYF00<005YFFUH00P000eYF0P00;Woo000]Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500000eYF001JEP06
FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH0
00030006FUH6000AOol20004FUH00`00FUIJEP02FUH2000015YF001JEP00;Woo000_Ool50003FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUHA0003FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00
FUIJEP040004FUH00`00FUIJEP08FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF0P000eYF00<005YFFUH01EYF
00<005YFFUH00UYF4P0000IJEP00000005YF0006FUH200000eYF001oo`0]Ool003Aoo`L000=JEPT0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@00003FUH005YF00QJEP03001J
EUYF00AJEPh0009JEP<000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYF001JEP000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`001UYF0`00;goo000gOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP040006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1`0000=JEP0000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUH005YF00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000_Ool0035oo`H0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP800005FUH005YFFUH0000_Ool002ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003
FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP<000=J
EP03001oogoo02aoo`00;7oo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF
00AJEPD0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P001EYF0P0000=JEP00FUH01UYF
00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP03001o
ogoo02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00AJEP03001JEUYF00<000MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000IJEP@000IJEP03001JEUYF00IJEPD000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP<00004Ool005YF000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH?000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P0017oo0`00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF000010001UYF1@0015YF00<0
05YFFUH01EYF00<005YF00000`001goo0P00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00D005YFFUIJ
EP0000EJEP05001JEUYFFUH00002Ool40002FUH40005FUH00`00FUIJEP02FUH5000;Ool2000]Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH;00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000eYF00@005YFFUH000EJEP05001JEUYFFUH00006Ool@000@Ool2000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEQ400003FUH005YF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0`00
00=JEP00FUH00eYF00D005YFFUIJEP0002Eoo`03001JEP0002eoo`00;Goo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF2P0025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP020005
FUH00`00FUIJEP02000ROol300000eYF001oo`0/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03
0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF0`000UYF00<005YFFUH00P0087oo0P00
0UYF0P00;Woo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1@000Woo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP04001JEUYF
FUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEP00008000=JEP03001oogoo01eoo`03001JEUYF009JEP8002ioo`00;Goo00<005YF
00000`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEPH000YJEP03001JEUYF00YJEP03001JEUYF00UJ
EPL0009JEP03001JEUYF00EJEP05001JEUYFFUH00002Ool00`00FUIJEP04FUH01000FUIJEUYF0`00
00=JEP00Ool077oo0`0015YF00<007ooOol0;Goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000?Ool01@00FUIJEUYF00001UYF00<005YFFUH0
1@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10001UYF
00D005YFFUIJEP0000=oo`8000=JEP03001JEUYF00AJEPH001Qoo`80009JEP03001JEUYF009JEP03
001oogoo02eoo`00;Woo>0000eYF00<005YFFUH00eYF10002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0015YF00D005YFFUIJEP0000Eoo`800003FUH005YF
00IJEP03001JEUYF009JEPT000Uoo`H000AJEP03001JEUYF0080031oo`00?goo200015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP04001JEUYFFUH20002FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP0300000eYF001JEP02FUH00`00Oomoo`03Ool50006FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP03FUH3000bOol003Moo`P000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH01000FUH0000015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000eYF00<007ooOol00`001EYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00=7oo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH02P0000=JEP00FUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000`00=Woo000^Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF10001UYF00<005YFFUH010000UYF1P0015YF00<005YFFUH0
1UYF00<005YFFUH00UYF1@00>Woo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUHD000015YF000000000UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH000IJEP03001JEUYF00=JEP<00003FUH007oo00=ooa8003moo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2P0025YF00<005YFFUH015YF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP02
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT0
00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0007FUH00`00FUIJEP03FUH00`00FUH0001FOol002aoo`04001JEUYF0003
FUH01000FUIJEUYF200025YF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPH0009oo`03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00/000=JEP04001JEP00001E
Ool002eoo`03001JEP00009JEPH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPL000Qoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP03FUH400000eYF0000001EOol002eoo`03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPT0011oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000IJEP04001JEUYFFUH20003Ool00`00FUH0001EOol002eoo`<00003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT001]oo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8000MJEP04001JEP000006
Ool2001EOol0031ooa@002Ioo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8000MJEP<000Moo`03001JEP0005Eo
o`00K7oo0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0P002Woo00@005YF000005Ao
o`00KWoo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YF00000P0015YF00<005YF00000P002Woo0`000UYF00<007ooOol0DWoo001`
Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40005
FUH4000;Ool20002FUH01000FUIJEP00E7oo001dOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0>000>Ool00`00FUIJEP03FUH2001EOol007Yoo`P000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPP000=JEPL0011oo`<000EJEP8005Eoo`00PWoo9@000Woo1@00
3Woo0P000UYF00<005YFFUH00eYF00<007ooOol0E7oo002>Ool00`00FUIJEP02000GOol3000=Ool2
0005FUH00`00FUIJEP02001GOol008ioo`04001JEUYF000VOol20007FUH3001IOol008moo`8002=o
o`@00003FUH005YF00IJEP03001oogoo05Uoo`00Sgoo0`007Goo1@001EYF00<005YFFUH00eYF0P00
G7oo002?Ool00`00FUIJEP02000GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP02001NOol008mo
o`800003FUH005YF00<000ioo`H000IJEP03001JEUYF00IJEP<0061oo`00T7oo00<005YF000015YF
3P000eYF00<005YFFUH01eYF00<005YFFUH015YF0P00HWoo002@Ool01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000I7oo002AOol30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001XOol009=oo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00@006eoo`00UGoo0`0000=JEP00FUH01UYF00<005YFFUH00UYF
1P00LGoo002HOol>001gOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59408 .74597 m .59825 .69009 L .56722 .68615 L p .707 .577 .707 r
F P
0 g
s
.59825 .69009 m .59408 .74597 L .62586 .74758 L p .707 .577 .707 r
F P
0 g
s
.62586 .74758 m .63003 .6917 L .59825 .69009 L p .707 .577 .707 r
F P
0 g
s
.63003 .6917 m .62586 .74758 L .65527 .74671 L p .707 .577 .707 r
F P
0 g
s
.65527 .74671 m .65944 .69082 L .63003 .6917 L p .707 .577 .707 r
F P
0 g
s
.56305 .74203 m .56722 .68615 L .53998 .68027 L p .707 .577 .707 r
F P
0 g
s
.56722 .68615 m .56305 .74203 L .59408 .74597 L p .707 .577 .707 r
F P
0 g
s
.65944 .69082 m .65527 .74671 L .67943 .74343 L p .707 .577 .707 r
F P
0 g
s
.67943 .74343 m .6836 .68755 L .65944 .69082 L p .707 .577 .707 r
F P
0 g
s
.53998 .68027 m .5358 .73615 L .56305 .74203 L p .707 .577 .707 r
F P
0 g
s
.58993 .80111 m .59682 .76399 L .56624 .75708 L p .707 .577 .707 r
F P
0 g
s
.59682 .76399 m .58993 .80111 L .62129 .80622 L p .707 .577 .707 r
F P
0 g
s
.62129 .80622 m .62817 .7691 L .59682 .76399 L p .707 .577 .707 r
F P
0 g
s
.5358 .73615 m .53998 .68027 L .51918 .67302 L p .707 .577 .707 r
F P
0 g
s
.62817 .7691 m .62129 .80622 L .65035 .80903 L p .707 .577 .707 r
F P
0 g
s
.65035 .80903 m .65723 .77191 L .62817 .7691 L p .707 .577 .707 r
F P
0 g
s
.55935 .7942 m .56624 .75708 L .53943 .74905 L p .707 .577 .707 r
F P
0 g
s
.56624 .75708 m .55935 .7942 L .58993 .80111 L p .707 .577 .707 r
F P
0 g
s
.53943 .74905 m .53255 .78617 L .55935 .7942 L p .707 .577 .707 r
F P
0 g
s
.51918 .67302 m .515 .7289 L .5358 .73615 L p .707 .577 .707 r
F P
0 g
s
.6836 .68755 m .67943 .74343 L .69599 .73808 L p .707 .577 .707 r
F P
0 g
s
.69599 .73808 m .70016 .68219 L .6836 .68755 L p .707 .577 .707 r
F P
0 g
s
.65723 .77191 m .65035 .80903 L .67428 .80926 L p .707 .577 .707 r
F P
0 g
s
.67428 .80926 m .68116 .77214 L .65723 .77191 L p .707 .577 .707 r
F P
0 g
s
.59447 .8426 m .598 .82405 L .56737 .81707 L p .707 .577 .707 r
F P
0 g
s
.598 .82405 m .59447 .8426 L .62577 .84779 L p .707 .577 .707 r
F P
0 g
s
.62577 .84779 m .6293 .82923 L .598 .82405 L p .707 .577 .707 r
F P
0 g
s
.56737 .81707 m .56384 .83563 L .59447 .8426 L p .707 .577 .707 r
F P
0 g
s
.6293 .82923 m .62577 .84779 L .65466 .85068 L p .707 .577 .707 r
F P
0 g
s
.65466 .85068 m .65819 .83213 L .6293 .82923 L p .707 .577 .707 r
F P
0 g
s
.53255 .78617 m .53943 .74905 L .51902 .74067 L p .707 .577 .707 r
F P
0 g
s
.56384 .83563 m .56737 .81707 L .54039 .80899 L p .707 .577 .707 r
F P
0 g
s
.515 .7289 m .51918 .67302 L .50687 .66511 L p .707 .577 .707 r
F P
0 g
s
.54039 .80899 m .53686 .82755 L .56384 .83563 L p .707 .577 .707 r
F P
0 g
s
.51902 .74067 m .51214 .7778 L .53255 .78617 L p .707 .577 .707 r
F P
0 g
s
.65819 .83213 m .65466 .85068 L .67833 .851 L p .707 .577 .707 r
F P
0 g
s
.67833 .851 m .68186 .83244 L .65819 .83213 L p .707 .577 .707 r
F P
0 g
s
.53686 .82755 m .54039 .80899 L .51972 .8006 L p .707 .577 .707 r
F P
0 g
s
.68116 .77214 m .67428 .80926 L .69073 .8069 L p .707 .577 .707 r
F P
0 g
s
.69073 .8069 m .69761 .76977 L .68116 .77214 L p .707 .577 .707 r
F P
0 g
s
.50687 .66511 m .50269 .721 L .515 .7289 L p .707 .577 .707 r
F P
0 g
s
.51972 .8006 m .51619 .81915 L .53686 .82755 L p .707 .577 .707 r
F P
0 g
s
.70016 .68219 m .69599 .73808 L .70331 .73117 L p .707 .577 .707 r
F P
0 g
s
.70331 .73117 m .70749 .67529 L .70016 .68219 L p .707 .577 .707 r
F P
0 g
s
.51214 .7778 m .51902 .74067 L .507 .73279 L p .707 .577 .707 r
F P
0 g
s
.507 .73279 m .50012 .76991 L .51214 .7778 L p .707 .577 .707 r
F P
0 g
s
.50269 .721 m .50687 .66511 L .50424 .65733 L p .707 .577 .707 r
F P
0 g
s
.68186 .83244 m .67833 .851 L .69445 .8487 L p .707 .577 .707 r
F P
0 g
s
.69445 .8487 m .69798 .83014 L .68186 .83244 L p .707 .577 .707 r
F P
0 g
s
.51619 .81915 m .51972 .8006 L .50736 .79271 L p .707 .577 .707 r
F P
0 g
s
.50736 .79271 m .50383 .81127 L .51619 .81915 L p .707 .577 .707 r
F P
0 g
s
.69761 .76977 m .69073 .8069 L .69809 .80216 L p .707 .577 .707 r
F P
0 g
s
.69809 .80216 m .70497 .76504 L .69761 .76977 L p .707 .577 .707 r
F P
0 g
s
.50424 .65733 m .50007 .71321 L .50269 .721 L p .707 .577 .707 r
F P
0 g
s
.70749 .67529 m .70331 .73117 L .70069 .72338 L p .707 .577 .707 r
F P
0 g
s
.70069 .72338 m .70487 .6675 L .70749 .67529 L p .707 .577 .707 r
F P
0 g
s
.50012 .76991 m .507 .73279 L .50455 .72615 L p .707 .577 .707 r
F P
0 g
s
.50455 .72615 m .49767 .76327 L .50012 .76991 L p .707 .577 .707 r
F P
0 g
s
.49767 .76327 m .50455 .72615 L .51191 .72142 L p .707 .577 .707 r
F P
0 g
s
.51191 .72142 m .50502 .75854 L .49767 .76327 L p .707 .577 .707 r
F P
0 g
s
.49936 .82192 m .49936 .32003 L .45482 .31809 L p .707 .577 .707 r
F P
0 g
s
.50007 .71321 m .50424 .65733 L .51157 .65042 L p .707 .577 .707 r
F P
0 g
s
.50383 .81127 m .50736 .79271 L .50455 .7861 L p .707 .577 .707 r
F P
0 g
s
.50455 .7861 m .50102 .80466 L .50383 .81127 L p .707 .577 .707 r
F P
0 g
s
.51157 .65042 m .5074 .7063 L .50007 .71321 L p .707 .577 .707 r
F P
0 g
s
.5074 .7063 m .51157 .65042 L .52813 .64507 L p .707 .577 .707 r
F P
0 g
s
.50102 .80466 m .50455 .7861 L .51154 .78142 L p .707 .577 .707 r
F P
0 g
s
.51154 .78142 m .50801 .79998 L .50102 .80466 L p .707 .577 .707 r
F P
0 g
s
.52813 .64507 m .52395 .70095 L .5074 .7063 L p .707 .577 .707 r
F P
0 g
s
.50502 .75854 m .51191 .72142 L .52835 .71905 L p .707 .577 .707 r
F P
0 g
s
.52395 .70095 m .52813 .64507 L .55229 .64179 L p .707 .577 .707 r
F P
0 g
s
.52835 .71905 m .52147 .75617 L .50502 .75854 L p .707 .577 .707 r
F P
0 g
s
.50801 .79998 m .51154 .78142 L .52766 .77913 L p .707 .577 .707 r
F P
0 g
s
.52766 .77913 m .52413 .79769 L .50801 .79998 L p .707 .577 .707 r
F P
0 g
s
.55229 .64179 m .54812 .69767 L .52395 .70095 L p .707 .577 .707 r
F P
0 g
s
.52147 .75617 m .52835 .71905 L .55228 .71929 L p .707 .577 .707 r
F P
0 g
s
.55228 .71929 m .5454 .75641 L .52147 .75617 L p .707 .577 .707 r
F P
0 g
s
.52413 .79769 m .52766 .77913 L .55132 .77944 L p .707 .577 .707 r
F P
0 g
s
.55132 .77944 m .54779 .798 L .52413 .79769 L p .707 .577 .707 r
F P
0 g
s
.49936 .32003 m .49936 .82192 L .54397 .82008 L p .707 .577 .707 r
F P
0 g
s
.54397 .82008 m .54397 .31819 L .49936 .32003 L p .707 .577 .707 r
F P
0 g
s
.69798 .83014 m .69445 .8487 L .70144 .84402 L p .707 .577 .707 r
F P
0 g
s
.70144 .84402 m .70497 .82547 L .69798 .83014 L p .707 .577 .707 r
F P
0 g
s
.54812 .69767 m .55229 .64179 L .5817 .64092 L p .707 .577 .707 r
F P
0 g
s
.5817 .64092 m .57753 .6968 L .54812 .69767 L p .707 .577 .707 r
F P
0 g
s
.5454 .75641 m .55228 .71929 L .58135 .72209 L p .707 .577 .707 r
F P
0 g
s
.58135 .72209 m .57446 .75922 L .5454 .75641 L p .707 .577 .707 r
F P
0 g
s
.57446 .75922 m .58135 .72209 L .6127 .7272 L p .707 .577 .707 r
F P
0 g
s
.54779 .798 m .55132 .77944 L .58022 .78234 L p .707 .577 .707 r
F P
0 g
s
.6127 .7272 m .60582 .76433 L .57446 .75922 L p .707 .577 .707 r
F P
0 g
s
.58022 .78234 m .57669 .80089 L .54779 .798 L p .707 .577 .707 r
F P
0 g
s
.57669 .80089 m .58022 .78234 L .61151 .78752 L p .707 .577 .707 r
F P
0 g
s
.61151 .78752 m .60798 .80608 L .57669 .80089 L p .707 .577 .707 r
F P
0 g
s
.54397 .31819 m .54397 .82008 L .58427 .81463 L p .707 .577 .707 r
F P
0 g
s
.57753 .6968 m .5817 .64092 L .61348 .64253 L p .707 .577 .707 r
F P
0 g
s
.61348 .64253 m .6093 .69841 L .57753 .6968 L p .707 .577 .707 r
F P
0 g
s
.58427 .81463 m .58427 .31274 L .54397 .31819 L p .707 .577 .707 r
F P
0 g
s
.45482 .81998 m .45482 .31809 L .4147 .31254 L p .707 .577 .707 r
F P
0 g
s
.45482 .31809 m .45482 .81998 L .49936 .82192 L p .707 .577 .707 r
F P
0 g
s
.70497 .76504 m .69809 .80216 L .69564 .79553 L p .707 .577 .707 r
F P
0 g
s
.69564 .79553 m .70252 .75841 L .70497 .76504 L p .707 .577 .707 r
F P
0 g
s
.70487 .6675 m .70069 .72338 L .68838 .71548 L p .707 .577 .707 r
F P
0 g
s
.68838 .71548 m .69255 .65959 L .70487 .6675 L p .707 .577 .707 r
F P
0 g
s
.64451 .64647 m .64033 .70235 L .6093 .69841 L p .707 .577 .707 r
F P
0 g
s
.6093 .69841 m .61348 .64253 L .64451 .64647 L p .707 .577 .707 r
F P
0 g
s
.64328 .73411 m .6364 .77123 L .60582 .76433 L p .707 .577 .707 r
F P
0 g
s
.60582 .76433 m .6127 .7272 L .64328 .73411 L p .707 .577 .707 r
F P
0 g
s
.64215 .7945 m .63862 .81306 L .60798 .80608 L p .707 .577 .707 r
F P
0 g
s
.60798 .80608 m .61151 .78752 L .64215 .7945 L p .707 .577 .707 r
F P
0 g
s
.58427 .31274 m .58427 .81463 L .61632 .80611 L p .707 .577 .707 r
F P
0 g
s
.61632 .80611 m .61632 .30422 L .58427 .31274 L p .707 .577 .707 r
F P
0 g
s
.4147 .81443 m .4147 .31254 L .38293 .30394 L p .707 .577 .707 r
F P
0 g
s
.4147 .31254 m .4147 .81443 L .45482 .81998 L p .707 .577 .707 r
F P
0 g
s
.25184 .71911 m .25362 .66483 L .22252 .66146 L p .707 .577 .707 r
F P
0 g
s
.25362 .66483 m .25184 .71911 L .28368 .71914 L p .707 .577 .707 r
F P
0 g
s
.28368 .71914 m .28546 .66487 L .25362 .66483 L p .707 .577 .707 r
F P
0 g
s
.28546 .66487 m .28368 .71914 L .31314 .71582 L p .707 .577 .707 r
F P
0 g
s
.31314 .71582 m .31493 .66154 L .28546 .66487 L p .707 .577 .707 r
F P
0 g
s
.70497 .82547 m .70144 .84402 L .69862 .83742 L p .707 .577 .707 r
F P
0 g
s
.69862 .83742 m .70215 .81886 L .70497 .82547 L p .707 .577 .707 r
F P
0 g
s
.22073 .71574 m .22252 .66146 L .1952 .65506 L p .707 .577 .707 r
F P
0 g
s
.22252 .66146 m .22073 .71574 L .25184 .71911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31493 .66154 m .31314 .71582 L .33734 .70948 L p .707 .577 .707 r
F P
0 g
s
.33734 .70948 m .33913 .6552 L .31493 .66154 L p .707 .577 .707 r
F P
0 g
s
.70252 .75841 m .69564 .79553 L .68362 .78764 L p .707 .577 .707 r
F P
0 g
s
.68362 .78764 m .6905 .75052 L .70252 .75841 L p .707 .577 .707 r
F P
0 g
s
.69255 .65959 m .68838 .71548 L .66758 .70823 L p .707 .577 .707 r
F P
0 g
s
.66758 .70823 m .67175 .65235 L .69255 .65959 L p .707 .577 .707 r
F P
0 g
s
.19341 .70934 m .1952 .65506 L .17434 .64627 L p .707 .577 .707 r
F P
0 g
s
.1952 .65506 m .19341 .70934 L .22073 .71574 L p .707 .577 .707 r
F P
0 g
s
.61632 .30422 m .61632 .80611 L .63699 .79534 L p .707 .577 .707 r
F P
0 g
s
.67009 .74215 m .6632 .77927 L .6364 .77123 L p .707 .577 .707 r
F P
0 g
s
.6364 .77123 m .64328 .73411 L .67009 .74215 L p .707 .577 .707 r
F P
0 g
s
.63699 .79534 m .63699 .29345 L .61632 .30422 L p .707 .577 .707 r
F P
0 g
s
.25024 .78806 m .2532 .75358 L .22218 .74823 L p .707 .577 .707 r
F P
0 g
s
.2532 .75358 m .25024 .78806 L .282 .78911 L p .707 .577 .707 r
F P
0 g
s
.282 .78911 m .28496 .75462 L .2532 .75358 L p .707 .577 .707 r
F P
0 g
s
.38293 .80583 m .38293 .30394 L .36262 .29313 L p .707 .577 .707 r
F P
0 g
s
.38293 .30394 m .38293 .80583 L .4147 .81443 L p .707 .577 .707 r
F P
0 g
s
.28496 .75462 m .282 .78911 L .31138 .78573 L p .707 .577 .707 r
F P
0 g
s
.31138 .78573 m .31435 .75125 L .28496 .75462 L p .707 .577 .707 r
F P
0 g
s
.21921 .78271 m .22218 .74823 L .19492 .73908 L p .707 .577 .707 r
F P
0 g
s
.22218 .74823 m .21921 .78271 L .25024 .78806 L p .707 .577 .707 r
F P
0 g
s
.70215 .81886 m .69862 .83742 L .68627 .82953 L p .707 .577 .707 r
F P
0 g
s
.68627 .82953 m .6898 .81097 L .70215 .81886 L p .707 .577 .707 r
F P
0 g
s
.33913 .6552 m .33734 .70948 L .35391 .70073 L p .707 .577 .707 r
F P
0 g
s
.35391 .70073 m .35569 .64645 L .33913 .6552 L p .707 .577 .707 r
F P
0 g
s
.17434 .64627 m .17255 .70055 L .19341 .70934 L p .707 .577 .707 r
F P
0 g
s
.31435 .75125 m .31138 .78573 L .33552 .77827 L p .707 .577 .707 r
F P
0 g
s
.33552 .77827 m .33848 .74379 L .31435 .75125 L p .707 .577 .707 r
F P
0 g
s
.25288 .83132 m .25441 .8141 L .2233 .80882 L p .707 .577 .707 r
F P
0 g
s
.25441 .8141 m .25288 .83132 L .2846 .83225 L p .707 .577 .707 r
F P
0 g
s
.2846 .83225 m .28613 .81504 L .25441 .8141 L p .707 .577 .707 r
F P
0 g
s
.17255 .70055 m .17434 .64627 L .16197 .63595 L p .707 .577 .707 r
F P
0 g
s
.67175 .65235 m .66758 .70823 L .64033 .70235 L p .707 .577 .707 r
F P
0 g
s
.64033 .70235 m .64451 .64647 L .67175 .65235 L p .707 .577 .707 r
F P
0 g
s
.6905 .75052 m .68362 .78764 L .6632 .77927 L p .707 .577 .707 r
F P
0 g
s
.6632 .77927 m .67009 .74215 L .6905 .75052 L p .707 .577 .707 r
F P
0 g
s
.19195 .77356 m .19492 .73908 L .1741 .72703 L p .707 .577 .707 r
F P
0 g
s
.19492 .73908 m .19195 .77356 L .21921 .78271 L p .707 .577 .707 r
F P
0 g
s
.28613 .81504 m .2846 .83225 L .31383 .82874 L p .707 .577 .707 r
F P
0 g
s
.31383 .82874 m .31536 .81153 L .28613 .81504 L p .707 .577 .707 r
F P
0 g
s
.22178 .82604 m .2233 .80882 L .19586 .79971 L p .707 .577 .707 r
F P
0 g
s
.2233 .80882 m .22178 .82604 L .25288 .83132 L p .707 .577 .707 r
F P
0 g
s
.19586 .79971 m .19433 .81693 L .22178 .82604 L p .707 .577 .707 r
F P
0 g
s
.31536 .81153 m .31383 .82874 L .33771 .82114 L p .707 .577 .707 r
F P
0 g
s
.33771 .82114 m .33924 .80392 L .31536 .81153 L p .707 .577 .707 r
F P
0 g
s
.35569 .64645 m .35391 .70073 L .36122 .69043 L p .707 .577 .707 r
F P
0 g
s
.36122 .69043 m .36301 .63615 L .35569 .64645 L p .707 .577 .707 r
F P
0 g
s
.33848 .74379 m .33552 .77827 L .35204 .76745 L p .707 .577 .707 r
F P
0 g
s
.35204 .76745 m .355 .73297 L .33848 .74379 L p .707 .577 .707 r
F P
0 g
s
.6898 .81097 m .68627 .82953 L .66559 .82114 L p .707 .577 .707 r
F P
0 g
s
.66559 .82114 m .66912 .80258 L .6898 .81097 L p .707 .577 .707 r
F P
0 g
s
.19433 .81693 m .19586 .79971 L .17476 .78766 L p .707 .577 .707 r
F P
0 g
s
.1741 .72703 m .17114 .76151 L .19195 .77356 L p .707 .577 .707 r
F P
0 g
s
.16197 .63595 m .16018 .69023 L .17255 .70055 L p .707 .577 .707 r
F P
0 g
s
.63699 .29345 m .63699 .79534 L .64424 .78339 L p .707 .577 .707 r
F P
0 g
s
.64424 .78339 m .64424 .2815 L .63699 .29345 L p .707 .577 .707 r
F P
0 g
s
.35932 .75433 m .36229 .71985 L .355 .73297 L p .707 .577 .707 r
F P
0 g
s
.36301 .63615 m .36122 .69043 L .35857 .67959 L p .707 .577 .707 r
F P
0 g
s
.35857 .67959 m .36035 .62531 L .36301 .63615 L p .707 .577 .707 r
F P
0 g
s
.36229 .71985 m .35932 .75433 L .35667 .7402 L p .707 .577 .707 r
F P
0 g
s
.35667 .7402 m .35963 .70572 L .36229 .71985 L p .707 .577 .707 r
F P
0 g
s
.36035 .62531 m .35857 .67959 L .3462 .66927 L p .707 .577 .707 r
F P
0 g
s
.3462 .66927 m .34799 .61499 L .36035 .62531 L p .707 .577 .707 r
F P
0 g
s
.36262 .79502 m .36262 .29313 L .35575 .28116 L p .707 .577 .707 r
F P
0 g
s
.36262 .29313 m .36262 .79502 L .38293 .80583 L p .707 .577 .707 r
F P
0 g
s
.17114 .76151 m .1741 .72703 L .16176 .71327 L p .707 .577 .707 r
F P
0 g
s
.17476 .78766 m .17323 .80487 L .19433 .81693 L p .707 .577 .707 r
F P
0 g
s
.16018 .69023 m .16197 .63595 L .15932 .62511 L p .707 .577 .707 r
F P
0 g
s
.33924 .80392 m .33771 .82114 L .35391 .81018 L p .707 .577 .707 r
F P
0 g
s
.35391 .81018 m .35543 .79297 L .33924 .80392 L p .707 .577 .707 r
F P
0 g
s
.17323 .80487 m .17476 .78766 L .16207 .77384 L p .707 .577 .707 r
F P
0 g
s
.16176 .71327 m .15879 .74775 L .17114 .76151 L p .707 .577 .707 r
F P
0 g
s
.66912 .80258 m .66559 .82114 L .63862 .81306 L p .707 .577 .707 r
F P
0 g
s
.63862 .81306 m .64215 .7945 L .66912 .80258 L p .707 .577 .707 r
F P
0 g
s
.355 .73297 m .35204 .76745 L .35932 .75433 L p .707 .577 .707 r
F P
0 g
s
.15932 .62511 m .15753 .67939 L .16018 .69023 L p .707 .577 .707 r
F P
0 g
s
.16207 .77384 m .16054 .79106 L .17323 .80487 L p .707 .577 .707 r
F P
0 g
s
.15879 .74775 m .16176 .71327 L .1591 .69914 L p .707 .577 .707 r
F P
0 g
s
.15753 .67939 m .15932 .62511 L .16663 .61481 L p .707 .577 .707 r
F P
0 g
s
.35543 .79297 m .35391 .81018 L .36082 .79694 L p .707 .577 .707 r
F P
0 g
s
.36082 .79694 m .36235 .77973 L .35543 .79297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64424 .2815 m .64424 .78339 L .63738 .77142 L p .707 .577 .707 r
F P
0 g
s
.63738 .77142 m .63738 .26953 L .64424 .2815 L p .707 .577 .707 r
F P
0 g
s
.36235 .77973 m .36082 .79694 L .35779 .78272 L p .707 .577 .707 r
F P
0 g
s
.35779 .78272 m .35932 .76551 L .36235 .77973 L p .707 .577 .707 r
F P
0 g
s
.35963 .70572 m .35667 .7402 L .34433 .72644 L p .707 .577 .707 r
F P
0 g
s
.34433 .72644 m .34729 .69196 L .35963 .70572 L p .707 .577 .707 r
F P
0 g
s
.35932 .76551 m .35779 .78272 L .3451 .76891 L p .707 .577 .707 r
F P
0 g
s
.3451 .76891 m .34663 .75169 L .35932 .76551 L p .707 .577 .707 r
F P
0 g
s
.35575 .28116 m .35575 .78305 L .36262 .79502 L p .707 .577 .707 r
F P
0 g
s
.35575 .78305 m .35575 .28116 L .36301 .26921 L p .707 .577 .707 r
F P
0 g
s
.16054 .79106 m .16207 .77384 L .15904 .75962 L p .707 .577 .707 r
F P
0 g
s
.1591 .69914 m .15614 .73362 L .15879 .74775 L p .707 .577 .707 r
F P
0 g
s
.15904 .75962 m .15751 .77684 L .16054 .79106 L p .707 .577 .707 r
F P
0 g
s
.16663 .61481 m .16484 .66909 L .15753 .67939 L p .707 .577 .707 r
F P
0 g
s
.15614 .73362 m .1591 .69914 L .16639 .68602 L p .707 .577 .707 r
F P
0 g
s
.16484 .66909 m .16663 .61481 L .1832 .60606 L p .707 .577 .707 r
F P
0 g
s
.15751 .77684 m .15904 .75962 L .16596 .74639 L p .707 .577 .707 r
F P
0 g
s
.16639 .68602 m .16342 .7205 L .15614 .73362 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16596 .74639 m .16443 .7636 L .15751 .77684 L p .707 .577 .707 r
F P
0 g
s
.34799 .61499 m .3462 .66927 L .32534 .66048 L p .707 .577 .707 r
F P
0 g
s
.32534 .66048 m .32712 .6062 L .34799 .61499 L p .707 .577 .707 r
F P
0 g
s
.16342 .7205 m .16639 .68602 L .18291 .6752 L p .707 .577 .707 r
F P
0 g
s
.1832 .60606 m .18141 .66034 L .16484 .66909 L p .707 .577 .707 r
F P
0 g
s
.63738 .26953 m .63738 .77142 L .61707 .76061 L p .707 .577 .707 r
F P
0 g
s
.61707 .76061 m .61707 .25872 L .63738 .26953 L p .707 .577 .707 r
F P
0 g
s
.36301 .7711 m .36301 .26921 L .38368 .25844 L p .707 .577 .707 r
F P
0 g
s
.36301 .26921 m .36301 .7711 L .35575 .78305 L p .707 .577 .707 r
F P
0 g
s
.18141 .66034 m .1832 .60606 L .2074 .59971 L p .707 .577 .707 r
F P
0 g
s
.16443 .7636 m .16596 .74639 L .18215 .73543 L p .707 .577 .707 r
F P
0 g
s
.18291 .6752 m .17994 .70968 L .16342 .7205 L p .707 .577 .707 r
F P
0 g
s
.32712 .6062 m .32534 .66048 L .29802 .65408 L p .707 .577 .707 r
F P
0 g
s
.29802 .65408 m .2998 .5998 L .32712 .6062 L p .707 .577 .707 r
F P
0 g
s
.34729 .69196 m .34433 .72644 L .32351 .71439 L p .707 .577 .707 r
F P
0 g
s
.32351 .71439 m .32647 .67991 L .34729 .69196 L p .707 .577 .707 r
F P
0 g
s
.18215 .73543 m .18062 .75264 L .16443 .7636 L p .707 .577 .707 r
F P
0 g
s
.17994 .70968 m .18291 .6752 L .20704 .66774 L p .707 .577 .707 r
F P
0 g
s
.2074 .59971 m .20561 .65399 L .18141 .66034 L p .707 .577 .707 r
F P
0 g
s
.20561 .65399 m .2074 .59971 L .23686 .59639 L p .707 .577 .707 r
F P
0 g
s
.2998 .5998 m .29802 .65408 L .26691 .6507 L p .707 .577 .707 r
F P
0 g
s
.26691 .6507 m .2687 .59642 L .2998 .5998 L p .707 .577 .707 r
F P
0 g
s
.34663 .75169 m .3451 .76891 L .324 .75686 L p .707 .577 .707 r
F P
0 g
s
.324 .75686 m .32553 .73964 L .34663 .75169 L p .707 .577 .707 r
F P
0 g
s
.23507 .65067 m .23686 .59639 L .2687 .59642 L p .707 .577 .707 r
F P
0 g
s
.23686 .59639 m .23507 .65067 L .20561 .65399 L p .707 .577 .707 r
F P
0 g
s
.61707 .25872 m .61707 .76061 L .5853 .75201 L p .707 .577 .707 r
F P
0 g
s
.5853 .75201 m .5853 .25012 L .61707 .25872 L p .707 .577 .707 r
F P
0 g
s
.38368 .25844 m .38368 .76033 L .36301 .7711 L p .707 .577 .707 r
F P
0 g
s
.38368 .76033 m .38368 .25844 L .41573 .24992 L p .707 .577 .707 r
F P
0 g
s
.32647 .67991 m .32351 .71439 L .29625 .70524 L p .707 .577 .707 r
F P
0 g
s
.29625 .70524 m .29922 .67076 L .32647 .67991 L p .707 .577 .707 r
F P
0 g
s
.18062 .75264 m .18215 .73543 L .20603 .72782 L p .707 .577 .707 r
F P
0 g
s
.2687 .59642 m .26691 .6507 L .23507 .65067 L p .707 .577 .707 r
F P
0 g
s
.20704 .66774 m .20408 .70222 L .17994 .70968 L p .707 .577 .707 r
F P
0 g
s
.20408 .70222 m .20704 .66774 L .23643 .66436 L p .707 .577 .707 r
F P
0 g
s
.20603 .72782 m .2045 .74504 L .18062 .75264 L p .707 .577 .707 r
F P
0 g
s
.73308 .65068 m .7313 .59415 L .7002 .59365 L p .707 .577 .707 r
F P
0 g
s
.7313 .59415 m .73308 .65068 L .76493 .64919 L p .707 .577 .707 r
F P
0 g
s
.76493 .64919 m .76314 .59266 L .7313 .59415 L p .707 .577 .707 r
F P
0 g
s
.76314 .59266 m .76493 .64919 L .79439 .64586 L p .707 .577 .707 r
F P
0 g
s
.79439 .64586 m .7926 .58932 L .76314 .59266 L p .707 .577 .707 r
F P
0 g
s
.29922 .67076 m .29625 .70524 L .26522 .69989 L p .707 .577 .707 r
F P
0 g
s
.26522 .69989 m .26819 .66541 L .29922 .67076 L p .707 .577 .707 r
F P
0 g
s
.23346 .69884 m .23643 .66436 L .26819 .66541 L p .707 .577 .707 r
F P
0 g
s
.23643 .66436 m .23346 .69884 L .20408 .70222 L p .707 .577 .707 r
F P
0 g
s
.70198 .65018 m .7002 .59365 L .67287 .59121 L p .707 .577 .707 r
F P
0 g
s
.7002 .59365 m .70198 .65018 L .73308 .65068 L p .707 .577 .707 r
F P
0 g
s
.32553 .73964 m .324 .75686 L .29656 .74774 L p .707 .577 .707 r
F P
0 g
s
.29656 .74774 m .29809 .73053 L .32553 .73964 L p .707 .577 .707 r
F P
0 g
s
.26819 .66541 m .26522 .69989 L .23346 .69884 L p .707 .577 .707 r
F P
0 g
s
.2045 .74504 m .20603 .72782 L .23526 .72431 L p .707 .577 .707 r
F P
0 g
s
.7926 .58932 m .79439 .64586 L .81859 .641 L p .707 .577 .707 r
F P
0 g
s
.81859 .641 m .8168 .58447 L .7926 .58932 L p .707 .577 .707 r
F P
0 g
s
.67287 .59121 m .67466 .64774 L .70198 .65018 L p .707 .577 .707 r
F P
0 g
s
.73477 .70121 m .73181 .66302 L .70078 .66475 L p .707 .577 .707 r
F P
0 g
s
.73181 .66302 m .73477 .70121 L .76654 .69853 L p .707 .577 .707 r
F P
0 g
s
.76654 .69853 m .76357 .66033 L .73181 .66302 L p .707 .577 .707 r
F P
0 g
s
.23526 .72431 m .23373 .74153 L .2045 .74504 L p .707 .577 .707 r
F P
0 g
s
.5853 .25012 m .5853 .75201 L .54518 .74646 L p .707 .577 .707 r
F P
0 g
s
.54518 .74646 m .54518 .24457 L .5853 .25012 L p .707 .577 .707 r
F P
0 g
s
.41573 .75181 m .41573 .24992 L .45603 .24447 L p .707 .577 .707 r
F P
0 g
s
.41573 .24992 m .41573 .75181 L .38368 .76033 L p .707 .577 .707 r
F P
0 g
s
.76357 .66033 m .76654 .69853 L .79592 .69515 L p .707 .577 .707 r
F P
0 g
s
.79592 .69515 m .79295 .65695 L .76357 .66033 L p .707 .577 .707 r
F P
0 g
s
.29809 .73053 m .29656 .74774 L .26545 .74246 L p .707 .577 .707 r
F P
0 g
s
.26545 .74246 m .26698 .72525 L .29809 .73053 L p .707 .577 .707 r
F P
0 g
s
.70078 .66475 m .70375 .70294 L .73477 .70121 L p .707 .577 .707 r
F P
0 g
s
.23373 .74153 m .23526 .72431 L .26698 .72525 L p .707 .577 .707 r
F P
0 g
s
.67466 .64774 m .67287 .59121 L .65201 .58706 L p .707 .577 .707 r
F P
0 g
s
.70375 .70294 m .70078 .66475 L .67352 .66536 L p .707 .577 .707 r
F P
0 g
s
.26698 .72525 m .26545 .74246 L .23373 .74153 L p .707 .577 .707 r
F P
0 g
s
.67352 .66536 m .67649 .70355 L .70375 .70294 L p .707 .577 .707 r
F P
0 g
s
.79295 .65695 m .79592 .69515 L .82005 .69141 L p .707 .577 .707 r
F P
0 g
s
.82005 .69141 m .81709 .65321 L .79295 .65695 L p .707 .577 .707 r
F P
0 g
s
.8168 .58447 m .81859 .641 L .83515 .6351 L p .707 .577 .707 r
F P
0 g
s
.83515 .6351 m .83337 .57857 L .8168 .58447 L p .707 .577 .707 r
F P
0 g
s
.65201 .58706 m .6538 .6436 L .67466 .64774 L p .707 .577 .707 r
F P
0 g
s
.73455 .74198 m .73302 .72288 L .70191 .72475 L p .707 .577 .707 r
F P
0 g
s
.73302 .72288 m .73455 .74198 L .76627 .7392 L p .707 .577 .707 r
F P
0 g
s
.76627 .7392 m .76474 .7201 L .73302 .72288 L p .707 .577 .707 r
F P
0 g
s
.70191 .72475 m .70344 .74385 L .73455 .74198 L p .707 .577 .707 r
F P
0 g
s
.76474 .7201 m .76627 .7392 L .7955 .73576 L p .707 .577 .707 r
F P
0 g
s
.7955 .73576 m .79397 .71666 L .76474 .7201 L p .707 .577 .707 r
F P
0 g
s
.54518 .24457 m .54518 .74646 L .50063 .74451 L p .707 .577 .707 r
F P
0 g
s
.50063 .74451 m .50063 .24262 L .54518 .24457 L p .707 .577 .707 r
F P
0 g
s
.45603 .74636 m .45603 .24447 L .50063 .24262 L p .707 .577 .707 r
F P
0 g
s
.45603 .24447 m .45603 .74636 L .41573 .75181 L p .707 .577 .707 r
F P
0 g
s
.70344 .74385 m .70191 .72475 L .67447 .72551 L p .707 .577 .707 r
F P
0 g
s
.67649 .70355 m .67352 .66536 L .65271 .66478 L p .707 .577 .707 r
F P
0 g
s
.67447 .72551 m .67599 .7446 L .70344 .74385 L p .707 .577 .707 r
F P
0 g
s
.65271 .66478 m .65567 .70297 L .67649 .70355 L p .707 .577 .707 r
F P
0 g
s
.50063 .24262 m .50063 .74451 L .45603 .74636 L p .707 .577 .707 r
F P
0 g
s
.6538 .6436 m .65201 .58706 L .63965 .58162 L p .707 .577 .707 r
F P
0 g
s
.79397 .71666 m .7955 .73576 L .81938 .73201 L p .707 .577 .707 r
F P
0 g
s
.81938 .73201 m .81785 .71291 L .79397 .71666 L p .707 .577 .707 r
F P
0 g
s
.81709 .65321 m .82005 .69141 L .83657 .68768 L p .707 .577 .707 r
F P
0 g
s
.83657 .68768 m .83361 .64948 L .81709 .65321 L p .707 .577 .707 r
F P
0 g
s
.63965 .58162 m .64143 .63815 L .6538 .6436 L p .707 .577 .707 r
F P
0 g
s
.67599 .7446 m .67447 .72551 L .65337 .72509 L p .707 .577 .707 r
F P
0 g
s
.65337 .72509 m .65489 .74418 L .67599 .7446 L p .707 .577 .707 r
F P
0 g
s
.83337 .57857 m .83515 .6351 L .84247 .62874 L p .707 .577 .707 r
F P
0 g
s
.84247 .62874 m .84068 .5722 L .83337 .57857 L p .707 .577 .707 r
F P
0 g
s
.65567 .70297 m .65271 .66478 L .64037 .66308 L p .707 .577 .707 r
F P
0 g
s
.64037 .66308 m .64333 .70127 L .65567 .70297 L p .707 .577 .707 r
F P
0 g
s
.81785 .71291 m .81938 .73201 L .83557 .72832 L p .707 .577 .707 r
F P
0 g
s
.83557 .72832 m .83404 .70922 L .81785 .71291 L p .707 .577 .707 r
F P
0 g
s
.64143 .63815 m .63965 .58162 L .63699 .57541 L p .707 .577 .707 r
F P
0 g
s
.83361 .64948 m .83657 .68768 L .84386 .68431 L p .707 .577 .707 r
F P
0 g
s
.84386 .68431 m .8409 .64612 L .83361 .64948 L p .707 .577 .707 r
F P
0 g
s
.65489 .74418 m .65337 .72509 L .64068 .72353 L p .707 .577 .707 r
F P
0 g
s
.64068 .72353 m .64221 .74263 L .65489 .74418 L p .707 .577 .707 r
F P
0 g
s
.63699 .57541 m .63878 .63195 L .64143 .63815 L p .707 .577 .707 r
F P
0 g
s
.84068 .5722 m .84247 .62874 L .83981 .62253 L p .707 .577 .707 r
F P
0 g
s
.83981 .62253 m .83803 .566 L .84068 .5722 L p .707 .577 .707 r
F P
0 g
s
.64333 .70127 m .64037 .66308 L .63771 .66041 L p .707 .577 .707 r
F P
0 g
s
.83404 .70922 m .83557 .72832 L .84249 .72504 L p .707 .577 .707 r
F P
0 g
s
.84249 .72504 m .84096 .70594 L .83404 .70922 L p .707 .577 .707 r
F P
0 g
s
.63771 .66041 m .64067 .69861 L .64333 .70127 L p .707 .577 .707 r
F P
0 g
s
.63878 .63195 m .63699 .57541 L .6443 .56905 L p .707 .577 .707 r
F P
0 g
s
.8409 .64612 m .84386 .68431 L .8412 .68165 L p .707 .577 .707 r
F P
0 g
s
.8412 .68165 m .83824 .64345 L .8409 .64612 L p .707 .577 .707 r
F P
0 g
s
.64221 .74263 m .64068 .72353 L .63765 .72098 L p .707 .577 .707 r
F P
0 g
s
.63765 .72098 m .63917 .74008 L .64221 .74263 L p .707 .577 .707 r
F P
0 g
s
.6443 .56905 m .64609 .62558 L .63878 .63195 L p .707 .577 .707 r
F P
0 g
s
.83803 .566 m .83981 .62253 L .82745 .61709 L p .707 .577 .707 r
F P
0 g
s
.82745 .61709 m .82566 .56055 L .83803 .566 L p .707 .577 .707 r
F P
0 g
s
.64067 .69861 m .63771 .66041 L .645 .65705 L p .707 .577 .707 r
F P
0 g
s
.84096 .70594 m .84249 .72504 L .83945 .72249 L p .707 .577 .707 r
F P
0 g
s
.83945 .72249 m .83793 .7034 L .84096 .70594 L p .707 .577 .707 r
F P
0 g
s
.39069 .62393 m .38652 .56899 L .35549 .56895 L p .707 .577 .707 r
F P
0 g
s
.38652 .56899 m .39069 .62393 L .42247 .62095 L p .707 .577 .707 r
F P
0 g
s
.42247 .62095 m .4183 .56601 L .38652 .56899 L p .707 .577 .707 r
F P
0 g
s
.645 .65705 m .64796 .69524 L .64067 .69861 L p .707 .577 .707 r
F P
0 g
s
.4183 .56601 m .42247 .62095 L .45188 .61523 L p .707 .577 .707 r
F P
0 g
s
.45188 .61523 m .44771 .5603 L .4183 .56601 L p .707 .577 .707 r
F P
0 g
s
.64609 .62558 m .6443 .56905 L .66087 .56315 L p .707 .577 .707 r
F P
0 g
s
.35966 .62389 m .35549 .56895 L .32824 .5659 L p .707 .577 .707 r
F P
0 g
s
.35549 .56895 m .35966 .62389 L .39069 .62393 L p .707 .577 .707 r
F P
0 g
s
.44771 .5603 m .45188 .61523 L .47605 .60735 L p .707 .577 .707 r
F P
0 g
s
.47605 .60735 m .47187 .55241 L .44771 .5603 L p .707 .577 .707 r
F P
0 g
s
.83824 .64345 m .8412 .68165 L .82886 .67994 L p .707 .577 .707 r
F P
0 g
s
.82886 .67994 m .8259 .64175 L .83824 .64345 L p .707 .577 .707 r
F P
0 g
s
.63917 .74008 m .63765 .72098 L .64456 .7177 L p .707 .577 .707 r
F P
0 g
s
.64456 .7177 m .64609 .7368 L .63917 .74008 L p .707 .577 .707 r
F P
0 g
s
.66087 .56315 m .66266 .61968 L .64609 .62558 L p .707 .577 .707 r
F P
0 g
s
.82566 .56055 m .82745 .61709 L .80659 .61294 L p .707 .577 .707 r
F P
0 g
s
.80659 .61294 m .8048 .55641 L .82566 .56055 L p .707 .577 .707 r
F P
0 g
s
.33242 .62083 m .32824 .5659 L .30744 .56012 L p .707 .577 .707 r
F P
0 g
s
.32824 .5659 m .33242 .62083 L .35966 .62389 L p .707 .577 .707 r
F P
0 g
s
.39418 .68878 m .3873 .6532 L .35672 .65588 L p .707 .577 .707 r
F P
0 g
s
.3873 .6532 m .39418 .68878 L .42553 .68257 L p .707 .577 .707 r
F P
0 g
s
.42553 .68257 m .41865 .64699 L .3873 .6532 L p .707 .577 .707 r
F P
0 g
s
.41865 .64699 m .42553 .68257 L .4546 .67344 L p .707 .577 .707 r
F P
0 g
s
.4546 .67344 m .44772 .63786 L .41865 .64699 L p .707 .577 .707 r
F P
0 g
s
.64796 .69524 m .645 .65705 L .66152 .65331 L p .707 .577 .707 r
F P
0 g
s
.83793 .7034 m .83945 .72249 L .82677 .72094 L p .707 .577 .707 r
F P
0 g
s
.82677 .72094 m .82524 .70184 L .83793 .7034 L p .707 .577 .707 r
F P
0 g
s
.47187 .55241 m .47605 .60735 L .4926 .59807 L p .707 .577 .707 r
F P
0 g
s
.4926 .59807 m .48843 .54313 L .47187 .55241 L p .707 .577 .707 r
F P
0 g
s
.66152 .65331 m .66448 .69151 L .64796 .69524 L p .707 .577 .707 r
F P
0 g
s
.3636 .69146 m .35672 .65588 L .32991 .65477 L p .707 .577 .707 r
F P
0 g
s
.35672 .65588 m .3636 .69146 L .39418 .68878 L p .707 .577 .707 r
F P
0 g
s
.66266 .61968 m .66087 .56315 L .68507 .55829 L p .707 .577 .707 r
F P
0 g
s
.44772 .63786 m .4546 .67344 L .47853 .66228 L p .707 .577 .707 r
F P
0 g
s
.47853 .66228 m .47164 .6267 L .44772 .63786 L p .707 .577 .707 r
F P
0 g
s
.39201 .73133 m .38848 .71357 L .35785 .7165 L p .707 .577 .707 r
F P
0 g
s
.38848 .71357 m .39201 .73133 L .42331 .72486 L p .707 .577 .707 r
F P
0 g
s
.42331 .72486 m .41978 .7071 L .38848 .71357 L p .707 .577 .707 r
F P
0 g
s
.30744 .56012 m .31162 .61506 L .33242 .62083 L p .707 .577 .707 r
F P
0 g
s
.41978 .7071 m .42331 .72486 L .45221 .71547 L p .707 .577 .707 r
F P
0 g
s
.45221 .71547 m .44868 .69772 L .41978 .7071 L p .707 .577 .707 r
F P
0 g
s
.8259 .64175 m .82886 .67994 L .80805 .67937 L p .707 .577 .707 r
F P
0 g
s
.80805 .67937 m .80508 .64117 L .8259 .64175 L p .707 .577 .707 r
F P
0 g
s
.64609 .7368 m .64456 .7177 L .66076 .71401 L p .707 .577 .707 r
F P
0 g
s
.8048 .55641 m .80659 .61294 L .77926 .6105 L p .707 .577 .707 r
F P
0 g
s
.77926 .6105 m .77748 .55397 L .8048 .55641 L p .707 .577 .707 r
F P
0 g
s
.68507 .55829 m .68686 .61483 L .66266 .61968 L p .707 .577 .707 r
F P
0 g
s
.32991 .65477 m .33679 .69035 L .3636 .69146 L p .707 .577 .707 r
F P
0 g
s
.66076 .71401 m .66228 .73311 L .64609 .7368 L p .707 .577 .707 r
F P
0 g
s
.35785 .7165 m .36138 .73426 L .39201 .73133 L p .707 .577 .707 r
F P
0 g
s
.31162 .61506 m .30744 .56012 L .29513 .5522 L p .707 .577 .707 r
F P
0 g
s
.36138 .73426 m .35785 .7165 L .33087 .7156 L p .707 .577 .707 r
F P
0 g
s
.33679 .69035 m .32991 .65477 L .3095 .64998 L p .707 .577 .707 r
F P
0 g
s
.44868 .69772 m .45221 .71547 L .47587 .70409 L p .707 .577 .707 r
F P
0 g
s
.47587 .70409 m .47234 .68634 L .44868 .69772 L p .707 .577 .707 r
F P
0 g
s
.47164 .6267 m .47853 .66228 L .49497 .65019 L p .707 .577 .707 r
F P
0 g
s
.49497 .65019 m .48809 .61461 L .47164 .6267 L p .707 .577 .707 r
F P
0 g
s
.68686 .61483 m .68507 .55829 L .71453 .55496 L p .707 .577 .707 r
F P
0 g
s
.33087 .7156 m .3344 .73335 L .36138 .73426 L p .707 .577 .707 r
F P
0 g
s
.66448 .69151 m .66152 .65331 L .68565 .64958 L p .707 .577 .707 r
F P
0 g
s
.48843 .54313 m .4926 .59807 L .49993 .5883 L p .707 .577 .707 r
F P
0 g
s
.49993 .5883 m .49575 .53336 L .48843 .54313 L p .707 .577 .707 r
F P
0 g
s
.68565 .64958 m .68861 .68777 L .66448 .69151 L p .707 .577 .707 r
F P
0 g
s
.82524 .70184 m .82677 .72094 L .80567 .72052 L p .707 .577 .707 r
F P
0 g
s
.80567 .72052 m .80414 .70142 L .82524 .70184 L p .707 .577 .707 r
F P
0 g
s
.77748 .55397 m .77926 .6105 L .74816 .61 L p .707 .577 .707 r
F P
0 g
s
.74816 .61 m .74638 .55347 L .77748 .55397 L p .707 .577 .707 r
F P
0 g
s
.3095 .64998 m .31638 .68556 L .33679 .69035 L p .707 .577 .707 r
F P
0 g
s
.29513 .5522 m .29931 .60713 L .31162 .61506 L p .707 .577 .707 r
F P
0 g
s
.71453 .55496 m .71632 .61149 L .68686 .61483 L p .707 .577 .707 r
F P
0 g
s
.71632 .61149 m .71453 .55496 L .74638 .55347 L p .707 .577 .707 r
F P
0 g
s
.3344 .73335 m .33087 .7156 L .3102 .71095 L p .707 .577 .707 r
F P
0 g
s
.80508 .64117 m .80805 .67937 L .78079 .67998 L p .707 .577 .707 r
F P
0 g
s
.78079 .67998 m .77782 .64178 L .80508 .64117 L p .707 .577 .707 r
F P
0 g
s
.74638 .55347 m .74816 .61 L .71632 .61149 L p .707 .577 .707 r
F P
0 g
s
.47234 .68634 m .47587 .70409 L .49199 .69184 L p .707 .577 .707 r
F P
0 g
s
.49199 .69184 m .48846 .67408 L .47234 .68634 L p .707 .577 .707 r
F P
0 g
s
.66228 .73311 m .66076 .71401 L .68464 .71026 L p .707 .577 .707 r
F P
0 g
s
.3102 .71095 m .31373 .7287 L .3344 .73335 L p .707 .577 .707 r
F P
0 g
s
.68464 .71026 m .68616 .72936 L .66228 .73311 L p .707 .577 .707 r
F P
0 g
s
.31638 .68556 m .3095 .64998 L .29748 .64197 L p .707 .577 .707 r
F P
0 g
s
.29931 .60713 m .29513 .5522 L .29251 .54289 L p .707 .577 .707 r
F P
0 g
s
.68861 .68777 m .68565 .64958 L .71503 .6462 L p .707 .577 .707 r
F P
0 g
s
.48809 .61461 m .49497 .65019 L .50233 .63835 L p .707 .577 .707 r
F P
0 g
s
.50233 .63835 m .49545 .60276 L .48809 .61461 L p .707 .577 .707 r
F P
0 g
s
.71503 .6462 m .718 .68439 L .68861 .68777 L p .707 .577 .707 r
F P
0 g
s
.77782 .64178 m .78079 .67998 L .74976 .68171 L p .707 .577 .707 r
F P
0 g
s
.74976 .68171 m .7468 .64351 L .77782 .64178 L p .707 .577 .707 r
F P
0 g
s
.80414 .70142 m .80567 .72052 L .77822 .72127 L p .707 .577 .707 r
F P
0 g
s
.77822 .72127 m .77669 .70218 L .80414 .70142 L p .707 .577 .707 r
F P
0 g
s
.49575 .53336 m .49993 .5883 L .49731 .579 L p .707 .577 .707 r
F P
0 g
s
.49731 .579 m .49313 .52406 L .49575 .53336 L p .707 .577 .707 r
F P
0 g
s
.29748 .64197 m .30436 .67755 L .31638 .68556 L p .707 .577 .707 r
F P
0 g
s
.718 .68439 m .71503 .6462 L .7468 .64351 L p .707 .577 .707 r
F P
0 g
s
.31373 .7287 m .3102 .71095 L .29785 .70301 L p .707 .577 .707 r
F P
0 g
s
.7468 .64351 m .74976 .68171 L .718 .68439 L p .707 .577 .707 r
F P
0 g
s
.68616 .72936 m .68464 .71026 L .71387 .70682 L p .707 .577 .707 r
F P
0 g
s
.29251 .54289 m .29668 .59783 L .29931 .60713 L p .707 .577 .707 r
F P
0 g
s
.48846 .67408 m .49199 .69184 L .49898 .6799 L p .707 .577 .707 r
F P
0 g
s
.49898 .6799 m .49545 .66214 L .48846 .67408 L p .707 .577 .707 r
F P
0 g
s
.71387 .70682 m .7154 .72592 L .68616 .72936 L p .707 .577 .707 r
F P
0 g
s
.29785 .70301 m .30138 .72077 L .31373 .7287 L p .707 .577 .707 r
F P
0 g
s
.77669 .70218 m .77822 .72127 L .74712 .72314 L p .707 .577 .707 r
F P
0 g
s
.74712 .72314 m .74559 .70404 L .77669 .70218 L p .707 .577 .707 r
F P
0 g
s
.30436 .67755 m .29748 .64197 L .29503 .63153 L p .708 .578 .707 r
F P
0 g
s
.7154 .72592 m .71387 .70682 L .74559 .70404 L p .707 .577 .707 r
F P
0 g
s
.49545 .60276 m .50233 .63835 L .49988 .62791 L p .708 .578 .707 r
F P
0 g
s
.49988 .62791 m .493 .59233 L .49545 .60276 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29668 .59783 m .29251 .54289 L .29984 .53312 L p .707 .577 .707 r
F P
0 g
s
.74559 .70404 m .74712 .72314 L .7154 .72592 L p .707 .577 .707 r
F P
0 g
s
.29503 .63153 m .30191 .66711 L .30436 .67755 L p .708 .578 .707 r
F P
0 g
s
.49313 .52406 m .49731 .579 L .48499 .57107 L p .707 .577 .707 r
F P
0 g
s
.48499 .57107 m .48082 .51613 L .49313 .52406 L p .707 .577 .707 r
F P
0 g
s
.30138 .72077 m .29785 .70301 L .29503 .69256 L p .707 .578 .707 r
F P
0 g
s
.49545 .66214 m .49898 .6799 L .49616 .66945 L p .707 .578 .707 r
F P
0 g
s
.49616 .66945 m .49263 .65169 L .49545 .66214 L p .707 .578 .707 r
F P
0 g
s
.29984 .53312 m .30401 .58806 L .29668 .59783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29503 .69256 m .29856 .71032 L .30138 .72077 L p .707 .578 .707 r
F P
0 g
s
.30191 .66711 m .29503 .63153 L .30239 .61969 L p .707 .577 .707 r
F P
0 g
s
.493 .59233 m .49988 .62791 L .48786 .6199 L p .707 .577 .707 r
F P
0 g
s
.48786 .6199 m .48098 .58432 L .493 .59233 L p .707 .577 .707 r
F P
0 g
s
.30401 .58806 m .29984 .53312 L .31639 .52384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30239 .61969 m .30927 .65527 L .30191 .66711 L p .707 .577 .707 r
F P
0 g
s
.48082 .51613 m .48499 .57107 L .46419 .56529 L p .707 .577 .707 r
F P
0 g
s
.46419 .56529 m .46002 .51036 L .48082 .51613 L p .707 .577 .707 r
F P
0 g
s
.29856 .71032 m .29503 .69256 L .30202 .68063 L p .707 .577 .707 r
F P
0 g
s
.31639 .52384 m .32057 .57878 L .30401 .58806 L p .707 .577 .707 r
F P
0 g
s
.49263 .65169 m .49616 .66945 L .48381 .66151 L p .707 .577 .707 r
F P
0 g
s
.48381 .66151 m .48028 .64376 L .49263 .65169 L p .707 .577 .707 r
F P
0 g
s
.30202 .68063 m .30555 .69838 L .29856 .71032 L p .707 .577 .707 r
F P
0 g
s
.32057 .57878 m .31639 .52384 L .34056 .51596 L p .707 .577 .707 r
F P
0 g
s
.30927 .65527 m .30239 .61969 L .31884 .6076 L p .707 .577 .707 r
F P
0 g
s
.48098 .58432 m .48786 .6199 L .46745 .61511 L p .707 .577 .707 r
F P
0 g
s
.46745 .61511 m .46057 .57953 L .48098 .58432 L p .707 .577 .707 r
F P
0 g
s
.46002 .51036 m .46419 .56529 L .43695 .56224 L p .707 .577 .707 r
F P
0 g
s
.43695 .56224 m .43277 .5073 L .46002 .51036 L p .707 .577 .707 r
F P
0 g
s
.31884 .6076 m .32572 .64318 L .30927 .65527 L p .707 .577 .707 r
F P
0 g
s
.30555 .69838 m .30202 .68063 L .31814 .66837 L p .707 .577 .707 r
F P
0 g
s
.34056 .51596 m .34473 .57089 L .32057 .57878 L p .707 .577 .707 r
F P
0 g
s
.34473 .57089 m .34056 .51596 L .36997 .51025 L p .707 .577 .707 r
F P
0 g
s
.48028 .64376 m .48381 .66151 L .46314 .65686 L p .707 .577 .707 r
F P
0 g
s
.46314 .65686 m .45961 .63911 L .48028 .64376 L p .707 .577 .707 r
F P
0 g
s
.31814 .66837 m .32167 .68612 L .30555 .69838 L p .707 .577 .707 r
F P
0 g
s
.43277 .5073 m .43695 .56224 L .40592 .5622 L p .707 .577 .707 r
F P
0 g
s
.40592 .5622 m .40174 .50726 L .43277 .5073 L p .707 .577 .707 r
F P
0 g
s
.32572 .64318 m .31884 .6076 L .34276 .59644 L p .707 .577 .707 r
F P
0 g
s
.46057 .57953 m .46745 .61511 L .44064 .614 L p .707 .577 .707 r
F P
0 g
s
.44064 .614 m .43376 .57842 L .46057 .57953 L p .707 .577 .707 r
F P
0 g
s
.37414 .56518 m .36997 .51025 L .40174 .50726 L p .707 .577 .707 r
F P
0 g
s
.36997 .51025 m .37414 .56518 L .34473 .57089 L p .707 .577 .707 r
F P
0 g
s
.40174 .50726 m .40592 .5622 L .37414 .56518 L p .707 .577 .707 r
F P
0 g
s
.34276 .59644 m .34964 .63202 L .32572 .64318 L p .707 .577 .707 r
F P
0 g
s
.32167 .68612 m .31814 .66837 L .3418 .65699 L p .707 .577 .707 r
F P
0 g
s
.34964 .63202 m .34276 .59644 L .37183 .58731 L p .707 .577 .707 r
F P
0 g
s
.45961 .63911 m .46314 .65686 L .43616 .65596 L p .707 .577 .707 r
F P
0 g
s
.43616 .65596 m .43263 .6382 L .45961 .63911 L p .707 .577 .707 r
F P
0 g
s
.43376 .57842 m .44064 .614 L .41006 .61668 L p .707 .577 .707 r
F P
0 g
s
.41006 .61668 m .40318 .5811 L .43376 .57842 L p .707 .577 .707 r
F P
0 g
s
.3418 .65699 m .34533 .67474 L .32167 .68612 L p .707 .577 .707 r
F P
0 g
s
.37871 .62289 m .37183 .58731 L .40318 .5811 L p .707 .577 .707 r
F P
0 g
s
.37183 .58731 m .37871 .62289 L .34964 .63202 L p .707 .577 .707 r
F P
0 g
s
.40318 .5811 m .41006 .61668 L .37871 .62289 L p .707 .577 .707 r
F P
0 g
s
.34533 .67474 m .3418 .65699 L .3707 .6476 L p .707 .577 .707 r
F P
0 g
s
.43263 .6382 m .43616 .65596 L .40552 .65889 L p .707 .577 .707 r
F P
0 g
s
.40552 .65889 m .40199 .64113 L .43263 .6382 L p .707 .577 .707 r
F P
0 g
s
.3707 .6476 m .37423 .66536 L .34533 .67474 L p .707 .577 .707 r
F P
0 g
s
.37423 .66536 m .3707 .6476 L .40199 .64113 L p .707 .577 .707 r
F P
0 g
s
.40199 .64113 m .40552 .65889 L .37423 .66536 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00L7oo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF4P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol90004FUH00`00FUIJEP06FUH01000FUIJEUYF1P002EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001OOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040005
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool005]oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00F7oo0P001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJ
EP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
05Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ao
o`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEUYF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0000?OolI000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00009Ool60004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@00<Goo
001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH015YF4`0015YF1P0015YF00@005YF
FUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00l0
00=JEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF009JEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP02FUH400000eYF001JEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF
000015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP800003FUH0000000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03
001JEP0000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEPh0009JEP03001JEUYF009JEP@0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP04001JEP00000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUIJEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00E7oo00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<00004FUH005YF000;FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001J
EP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000oOolB0003Ool20002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03
FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool003Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Goo000cOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUIJEP00FUH00P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00<Goo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF0000
05YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP02
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJ
EP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000]Ool002io
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL0009JEP@0009JEP03001JEUYF009J
EP<00004FUH005YFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40002FUH2000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@0009JEPL000IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPX0009JEP03001JEUYF00QJEP03001JEUYF00=J
EP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP03001JEP00008000AJEP03001JEUYF00QJEP04001JEUYFFUH20004FUH01000
FUH000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF1000
00=JEP00FUH015YF1P000eYF00<005YFFUH025YF00H005YF000005YF0004FUH01000FUIJEP002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00@005YFFUIJEP<0009JEP03001JEP0000EJEPH0
00=JEP03001JEUYF00QJEP8000=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP001EYF00@005YF0000009JEP06001JEUYF001JEP001EYF1P000eYF3P000eYF00D0
05YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP8000AJEP06001JEUYF001J
EP001EYF00<005YF00001`000eYF00<005YFFUH01EYF00<005YF00000`0015YF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF5P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH20005FUH01P00FUIJEP00FUH000AJ
EP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00EJEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP04FUH01@00FUIJEP00FUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`0000AJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEP00FUH>0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJ
EP060005FUH00`00FUH0000300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUH00003000>Ool50004Ool50002FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH=0004FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001J
EP0000AJEP80009JEP03001JEP0000<000Yoo`D000Uoo`04FUH005YF0004FUH00`00FUH000020008
FUH00`00FUIJEP04FUH70008FUH00`00FUIJEP02FUH300001eYF001JEUYF001JEP0000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP00009JEP8000AJEP03001JEUYF00=JEPl000Uoo`04FUH005YF0004FUH2
0002FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005FUH00`00FUIJEP050004FUH0
0`00FUIJEP02FUH>0002FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF0P0000=JEP0000002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00;7oo00<005YF00000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000AJEP00FUH000MJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP000006FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000001eYF0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002eoo`00;7oo0P000eYF00<005YFFUH00P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0000=JEP00FUH01UYF0P000UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP<000IJEP03001JEP00008000AJEP03001JEUYF00AJEP03
001JEP00009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQl002eoo`00;7oo0P000UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0`0000=JEP00FUH01UYF00<005YFFUH015YF1@000UYF1@001eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH300000eYF001JEP06FUH00`00FUIJEP02FUH9
00000eYF001JEP09FUH01000FUIJEUYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPT000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<002ioo`00;Goo0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP800003
FUH005YF00h00003FUH0000000@000=JEP03001JEUYF00QJEP06001JEP00001JEP0015YF00@005YF
FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH60007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000^Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUH000020004FUH00`00FUIJEP08
FUH20003FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPP003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
0UYF200015YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP06001JEP00001JEP00
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@00?goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH60008FUH90004FUH20005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH005YF00IJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEQ0000=ooa@0035oo`00;Goo0P00
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF1P001EYF00<005YFFUH015YF
00H005YFFUH005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
00000eYF000000060002FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000]
Ool002eoo`8000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P00
0eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH60007FUH01000FUIJ
EUYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF00000eYF10000UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF0P001Goo10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80009JEP@000EJEP07001JEUYFFUH005YF00000UYF2@0015YF
00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP00008000]oo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH?0004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
1000FUH000004goo4`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH2000]Ool002ao
o`<00003FUH007oo00eoo`P000moo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0005FUH9000]Ool002aoo`<0009JEP03001oogoo00Eoo`H000=JEP03001JEUYF009J
EPT000Moo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF0`000goo0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000goo0`000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;7oo0P000eYF00<005YFFUH00`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000Aoo`l0009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00009JEPH000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH5000bOol002aoo`8000=JEP04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0027oo0`0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2000=goo000/Ool20003FUH30006FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004Ool200001EYF000005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
0UYF4P00?goo000]Ool00`00FUIJEP0200000eYF001JEP04FUH60008Ool90004FUH00`00FUIJEP05
FUH50003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP04FUH<
0006FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUHG001AOol002eoo`03001JEP00
00=JEP04001JEUYFFUH20004FUH4000?Ool60006FUH00`00FUIJEP020003FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH<0005FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUH00002001JOol002ioo`8000=JEP03001JEP00
008000MJEP03001JEP0000<0015oo`8000AJEP03001JEUYF009JEP800005FUH00000FUH00005FUH0
0`00FUIJEP05FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80007FUH0
0`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2001HOol002ioo`8000=JEP80009JEP03
001JEUYF00EJEP03001JEUYF00=JEQ40009JEP<00003FUH005YF00AJEP@00003FUH005YF00AJEP03
001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP<005Ioo`00;Goo0P000UYF
0P000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
000000EJEP06001JEP00001JEP001EYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YF
00001EYF00<005YFFUH015YF00@005YFFUH005Eoo`00;Goo10001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP00
1EYF0P001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF0P001EYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;Goo
0P000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF0P0000MJEP00FUIJEP00FUH00003FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30003FUH00`00FUH00005FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20005Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000000UYF00@005YF
001JEP800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0005FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH005Aoo`00;7oo0`001Woo0`001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00H005YFFUH005YF001DOol002aoo`03001JEP00
00Uoo`8000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003Ool0
05YF00<000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03001JEUYF00AJEP03001JEUYF
008005Eoo`00;7oo00@005YF000000Yoo`<00003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000Aoo`@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@000AJEP04
001JEUYFFUH2001EOol002aoo`80009JEP03001oogoo00Yoo`@000IJEPD000AJEP03001JEUYF00EJ
EP03001JEP0000<000Moo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00004FUH300000eYF001JEP02FUH2001EOol002eoo`05001JEUYFFUH0000?Ool40002FUH40005
FUH00`00FUIJEP02FUH5000;Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP04FUH30003FUH2001EOol002eoo`04001JEUYFFUH3000AOol@000@Ool30004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH02000FUIJEP00FUH005YF001E
Ool002ioo`04001JEUYF0002FUH00`00Oomoo`0^Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH300000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00Ool0E7oo000_Ool00`00FUH00003FUH2
000/Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000006FUH00`00FUIJEP02
FUH2001FOol0031oo`8000EJEP8002Qoo`80009JEP03001oogoo0080009JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP02FUH30003FUH01000FUIJEUYF0`00EWoo000aOol00`00FUIJEP03
FUH00`00FUH00003000ROol20003FUH20004Ool30008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01EYF
0`0015YF00<005YF0000EWoo000bOol20003FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02
FUH00`00Oomoo`05Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP06FUH00`00FUH00005001GOol003Aoo`04
001JEUYF0007FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF00002Woo10000UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH010000Woo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00F7oo000eOol30007FUH00`00FUIJEP04FUH@0003
FUH00`00FUIJEP04FUH01000FUIJEP003goo1@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2P001Goo10001UYF00<005YFFUH015YF0`00EWoo000gOol20006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000EOol60003FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@002Goo10000UYF00<005YFFUH015YF00@005YF
FUH005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P007Goo80000eYF00<005YF00000`000Woo1@003Goo100015YF00D005YFFUIJEP0005Eo
o`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH00eYF1`004Goo0`0000=JEP00FUH00UYF0P00E7oo0011Ool40002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH6000lOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000;
Ool20002FUH00`00FUH0001DOol004Eooa0004Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPh00004FUH005YF001DOol009ioo`@000IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH3001EOol00:9oo`@0009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00YWoo1@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000EGoo002[Ool40002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2001FOol00:mooaL005Moo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5928 .74367 m .59953 .68777 L .56868 .68258 L p .707 .577 .707 r
F P
0 g
s
.59953 .68777 m .5928 .74367 L .62446 .74675 L p .707 .577 .707 r
F P
0 g
s
.62446 .74675 m .63119 .69086 L .59953 .68777 L p .707 .577 .707 r
F P
0 g
s
.63119 .69086 m .62446 .74675 L .65381 .74743 L p .707 .577 .707 r
F P
0 g
s
.65381 .74743 m .66054 .69154 L .63119 .69086 L p .707 .577 .707 r
F P
0 g
s
.56194 .73847 m .56868 .68258 L .54164 .67578 L p .707 .577 .707 r
F P
0 g
s
.56868 .68258 m .56194 .73847 L .5928 .74367 L p .707 .577 .707 r
F P
0 g
s
.66054 .69154 m .65381 .74743 L .67799 .74563 L p .707 .577 .707 r
F P
0 g
s
.67799 .74563 m .68472 .68974 L .66054 .69154 L p .707 .577 .707 r
F P
0 g
s
.54164 .67578 m .5349 .73168 L .56194 .73847 L p .707 .577 .707 r
F P
0 g
s
.58602 .79515 m .59703 .75872 L .56733 .74877 L p .707 .577 .707 r
F P
0 g
s
.59703 .75872 m .58602 .79515 L .61658 .80386 L p .707 .577 .707 r
F P
0 g
s
.61658 .80386 m .62759 .76742 L .59703 .75872 L p .707 .577 .707 r
F P
0 g
s
.5349 .73168 m .54164 .67578 L .52107 .66805 L p .707 .577 .707 r
F P
0 g
s
.62759 .76742 m .61658 .80386 L .64501 .81047 L p .707 .577 .707 r
F P
0 g
s
.64501 .81047 m .65602 .77403 L .62759 .76742 L p .707 .577 .707 r
F P
0 g
s
.56733 .74877 m .55632 .78521 L .58602 .79515 L p .707 .577 .707 r
F P
0 g
s
.55632 .78521 m .56733 .74877 L .5414 .73856 L p .707 .577 .707 r
F P
0 g
s
.5414 .73856 m .53039 .775 L .55632 .78521 L p .707 .577 .707 r
F P
0 g
s
.52107 .66805 m .51433 .72395 L .5349 .73168 L p .707 .577 .707 r
F P
0 g
s
.65602 .77403 m .64501 .81047 L .66853 .81435 L p .707 .577 .707 r
F P
0 g
s
.66853 .81435 m .67954 .77791 L .65602 .77403 L p .707 .577 .707 r
F P
0 g
s
.59332 .83665 m .59897 .81846 L .56921 .80836 L p .707 .577 .707 r
F P
0 g
s
.59897 .81846 m .59332 .83665 L .62376 .84552 L p .707 .577 .707 r
F P
0 g
s
.62376 .84552 m .62941 .82733 L .59897 .81846 L p .707 .577 .707 r
F P
0 g
s
.68472 .68974 m .67799 .74563 L .69463 .74153 L p .707 .577 .707 r
F P
0 g
s
.69463 .74153 m .70136 .68564 L .68472 .68974 L p .707 .577 .707 r
F P
0 g
s
.56921 .80836 m .56355 .82655 L .59332 .83665 L p .707 .577 .707 r
F P
0 g
s
.62941 .82733 m .62376 .84552 L .65189 .85231 L p .707 .577 .707 r
F P
0 g
s
.65189 .85231 m .65755 .83411 L .62941 .82733 L p .707 .577 .707 r
F P
0 g
s
.53039 .775 m .5414 .73856 L .52178 .72908 L p .707 .577 .707 r
F P
0 g
s
.56355 .82655 m .56921 .80836 L .54303 .79802 L p .707 .577 .707 r
F P
0 g
s
.54303 .79802 m .53738 .81622 L .56355 .82655 L p .707 .577 .707 r
F P
0 g
s
.51433 .72395 m .52107 .66805 L .50897 .66015 L p .707 .577 .707 r
F P
0 g
s
.52178 .72908 m .51077 .76552 L .53039 .775 L p .707 .577 .707 r
F P
0 g
s
.65755 .83411 m .65189 .85231 L .67497 .85633 L p .707 .577 .707 r
F P
0 g
s
.67497 .85633 m .68063 .83814 L .65755 .83411 L p .707 .577 .707 r
F P
0 g
s
.53738 .81622 m .54303 .79802 L .52301 .78847 L p .707 .577 .707 r
F P
0 g
s
.67954 .77791 m .66853 .81435 L .68484 .8151 L p .707 .577 .707 r
F P
0 g
s
.68484 .8151 m .69585 .77866 L .67954 .77791 L p .707 .577 .707 r
F P
0 g
s
.50897 .66015 m .50224 .71604 L .51433 .72395 L p .707 .577 .707 r
F P
0 g
s
.52301 .78847 m .51736 .80666 L .53738 .81622 L p .707 .577 .707 r
F P
0 g
s
.70136 .68564 m .69463 .74153 L .7021 .73554 L p .707 .577 .707 r
F P
0 g
s
.7021 .73554 m .70883 .67964 L .70136 .68564 L p .707 .577 .707 r
F P
0 g
s
.51077 .76552 m .52178 .72908 L .51039 .72127 L p .707 .577 .707 r
F P
0 g
s
.51039 .72127 m .49938 .7577 L .51077 .76552 L p .707 .577 .707 r
F P
0 g
s
.50224 .71604 m .50897 .66015 L .50654 .65284 L p .707 .577 .707 r
F P
0 g
s
.68063 .83814 m .67497 .85633 L .69073 .85721 L p .707 .577 .707 r
F P
0 g
s
.69073 .85721 m .69639 .83902 L .68063 .83814 L p .707 .577 .707 r
F P
0 g
s
.51736 .80666 m .52301 .78847 L .5111 .78062 L p .707 .577 .707 r
F P
0 g
s
.5111 .78062 m .50544 .79882 L .51736 .80666 L p .707 .577 .707 r
F P
0 g
s
.69585 .77866 m .68484 .8151 L .69233 .81267 L p .707 .577 .707 r
F P
0 g
s
.69233 .81267 m .70334 .77623 L .69585 .77866 L p .707 .577 .707 r
F P
0 g
s
.50654 .65284 m .49981 .70873 L .50224 .71604 L p .707 .577 .707 r
F P
0 g
s
.49938 .7577 m .51039 .72127 L .50834 .71587 L p .707 .577 .707 r
F P
0 g
s
.70883 .67964 m .7021 .73554 L .69967 .72822 L p .707 .577 .707 r
F P
0 g
s
.69967 .72822 m .7064 .67233 L .70883 .67964 L p .707 .577 .707 r
F P
0 g
s
.50834 .71587 m .49733 .75231 L .49938 .7577 L p .707 .577 .707 r
F P
0 g
s
.49981 .70873 m .50654 .65284 L .51401 .64684 L p .707 .577 .707 r
F P
0 g
s
.50847 .77526 m .50281 .79345 L .50544 .79882 L p .707 .577 .707 r
F P
0 g
s
.51401 .64684 m .50728 .70273 L .49981 .70873 L p .707 .577 .707 r
F P
0 g
s
.49733 .75231 m .50834 .71587 L .51584 .71344 L p .707 .577 .707 r
F P
0 g
s
.51584 .71344 m .50483 .74988 L .49733 .75231 L p .707 .577 .707 r
F P
0 g
s
.50544 .79882 m .5111 .78062 L .50847 .77526 L p .707 .577 .707 r
F P
0 g
s
.50281 .79345 m .50847 .77526 L .51537 .7729 L p .707 .577 .707 r
F P
0 g
s
.51537 .7729 m .50971 .7911 L .50281 .79345 L p .707 .577 .707 r
F P
0 g
s
.50483 .74988 m .51584 .71344 L .53214 .71419 L p .707 .577 .707 r
F P
0 g
s
.53214 .71419 m .52113 .75063 L .50483 .74988 L p .707 .577 .707 r
F P
0 g
s
.50488 .8219 m .50488 .32001 L .4601 .31852 L p .707 .577 .707 r
F P
0 g
s
.50728 .70273 m .51401 .64684 L .53065 .64274 L p .707 .577 .707 r
F P
0 g
s
.53065 .64274 m .52392 .69863 L .50728 .70273 L p .707 .577 .707 r
F P
0 g
s
.52392 .69863 m .53065 .64274 L .55483 .64094 L p .707 .577 .707 r
F P
0 g
s
.50971 .7911 m .51537 .7729 L .53113 .77378 L p .707 .577 .707 r
F P
0 g
s
.53113 .77378 m .52547 .79197 L .50971 .7911 L p .707 .577 .707 r
F P
0 g
s
.55483 .64094 m .5481 .69683 L .52392 .69863 L p .707 .577 .707 r
F P
0 g
s
.52113 .75063 m .53214 .71419 L .55566 .71807 L p .707 .577 .707 r
F P
0 g
s
.55566 .71807 m .54465 .75451 L .52113 .75063 L p .707 .577 .707 r
F P
0 g
s
.52547 .79197 m .53113 .77378 L .55421 .77781 L p .707 .577 .707 r
F P
0 g
s
.55421 .77781 m .54855 .796 L .52547 .79197 L p .707 .577 .707 r
F P
0 g
s
.50488 .32001 m .50488 .8219 L .54919 .8196 L p .707 .577 .707 r
F P
0 g
s
.5481 .69683 m .55483 .64094 L .58419 .64162 L p .707 .577 .707 r
F P
0 g
s
.58419 .64162 m .57745 .69751 L .5481 .69683 L p .707 .577 .707 r
F P
0 g
s
.54465 .75451 m .55566 .71807 L .58409 .72468 L p .707 .577 .707 r
F P
0 g
s
.58409 .72468 m .57308 .76112 L .54465 .75451 L p .707 .577 .707 r
F P
0 g
s
.54855 .796 m .55421 .77781 L .58234 .78459 L p .707 .577 .707 r
F P
0 g
s
.58234 .78459 m .57669 .80278 L .54855 .796 L p .707 .577 .707 r
F P
0 g
s
.54919 .8196 m .54919 .31771 L .50488 .32001 L p .707 .577 .707 r
F P
0 g
s
.69639 .83902 m .69073 .85721 L .69763 .85485 L p .707 .577 .707 r
F P
0 g
s
.69763 .85485 m .70329 .83666 L .69639 .83902 L p .707 .577 .707 r
F P
0 g
s
.4601 .82041 m .4601 .31852 L .41921 .3134 L p .707 .577 .707 r
F P
0 g
s
.4601 .31852 m .4601 .82041 L .50488 .8219 L p .707 .577 .707 r
F P
0 g
s
.57745 .69751 m .58419 .64162 L .61584 .64471 L p .707 .577 .707 r
F P
0 g
s
.61584 .64471 m .60911 .7006 L .57745 .69751 L p .707 .577 .707 r
F P
0 g
s
.57308 .76112 m .58409 .72468 L .61466 .73339 L p .707 .577 .707 r
F P
0 g
s
.61466 .73339 m .60365 .76982 L .57308 .76112 L p .707 .577 .707 r
F P
0 g
s
.57669 .80278 m .58234 .78459 L .61278 .79347 L p .707 .577 .707 r
F P
0 g
s
.61278 .79347 m .60713 .81166 L .57669 .80278 L p .707 .577 .707 r
F P
0 g
s
.54919 .31771 m .54919 .8196 L .58869 .81374 L p .707 .577 .707 r
F P
0 g
s
.58869 .81374 m .58869 .31185 L .54919 .31771 L p .707 .577 .707 r
F P
0 g
s
.70334 .77623 m .69233 .81267 L .69029 .80727 L p .707 .577 .707 r
F P
0 g
s
.69029 .80727 m .7013 .77084 L .70334 .77623 L p .707 .577 .707 r
F P
0 g
s
.41921 .81528 m .41921 .3134 L .38624 .30513 L p .707 .577 .707 r
F P
0 g
s
.41921 .3134 m .41921 .81528 L .4601 .82041 L p .707 .577 .707 r
F P
0 g
s
.7064 .67233 m .69967 .72822 L .68758 .72032 L p .707 .577 .707 r
F P
0 g
s
.68758 .72032 m .69431 .66443 L .7064 .67233 L p .707 .577 .707 r
F P
0 g
s
.6467 .6499 m .63997 .70579 L .60911 .7006 L p .707 .577 .707 r
F P
0 g
s
.60911 .7006 m .61584 .64471 L .6467 .6499 L p .707 .577 .707 r
F P
0 g
s
.64435 .74333 m .63334 .77977 L .60365 .76982 L p .707 .577 .707 r
F P
0 g
s
.60365 .76982 m .61466 .73339 L .64435 .74333 L p .707 .577 .707 r
F P
0 g
s
.60713 .81166 m .61278 .79347 L .64255 .80356 L p .707 .577 .707 r
F P
0 g
s
.58869 .31185 m .58869 .81374 L .6195 .80489 L p .707 .577 .707 r
F P
0 g
s
.6195 .80489 m .6195 .30301 L .58869 .31185 L p .707 .577 .707 r
F P
0 g
s
.2511 .72293 m .25398 .66963 L .22293 .66536 L p .707 .577 .707 r
F P
0 g
s
.25398 .66963 m .2511 .72293 L .28292 .72344 L p .707 .577 .707 r
F P
0 g
s
.28292 .72344 m .28581 .67015 L .25398 .66963 L p .707 .577 .707 r
F P
0 g
s
.28581 .67015 m .28292 .72344 L .31242 .72015 L p .707 .577 .707 r
F P
0 g
s
.31242 .72015 m .3153 .66685 L .28581 .67015 L p .707 .577 .707 r
F P
0 g
s
.70329 .83666 m .69763 .85485 L .695 .84949 L p .707 .577 .707 r
F P
0 g
s
.695 .84949 m .70065 .8313 L .70329 .83666 L p .707 .577 .707 r
F P
0 g
s
.22005 .71866 m .22293 .66536 L .1957 .65776 L p .707 .577 .707 r
F P
0 g
s
.22293 .66536 m .22005 .71866 L .2511 .72293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3153 .66685 m .31242 .72015 L .33668 .71337 L p .707 .577 .707 r
F P
0 g
s
.33668 .71337 m .33957 .66008 L .3153 .66685 L p .707 .577 .707 r
F P
0 g
s
.7013 .77084 m .69029 .80727 L .67889 .79946 L p .707 .577 .707 r
F P
0 g
s
.67889 .79946 m .6899 .76302 L .7013 .77084 L p .707 .577 .707 r
F P
0 g
s
.19282 .71105 m .1957 .65776 L .17496 .64756 L p .707 .577 .707 r
F P
0 g
s
.1957 .65776 m .19282 .71105 L .22005 .71866 L p .707 .577 .707 r
F P
0 g
s
.69431 .66443 m .68758 .72032 L .667 .71259 L p .707 .577 .707 r
F P
0 g
s
.667 .71259 m .67374 .6567 L .69431 .66443 L p .707 .577 .707 r
F P
0 g
s
.38624 .80702 m .38624 .30513 L .3644 .29453 L p .707 .577 .707 r
F P
0 g
s
.38624 .30513 m .38624 .80702 L .41921 .81528 L p .707 .577 .707 r
F P
0 g
s
.67028 .75354 m .65927 .78998 L .63334 .77977 L p .707 .577 .707 r
F P
0 g
s
.63334 .77977 m .64435 .74333 L .67028 .75354 L p .707 .577 .707 r
F P
0 g
s
.6195 .30301 m .6195 .80489 L .63862 .79393 L p .707 .577 .707 r
F P
0 g
s
.63862 .79393 m .63861 .29204 L .6195 .30301 L p .707 .577 .707 r
F P
0 g
s
.24874 .79639 m .25355 .76417 L .22268 .75694 L p .707 .577 .707 r
F P
0 g
s
.25355 .76417 m .24874 .79639 L .28035 .79835 L p .707 .577 .707 r
F P
0 g
s
.28035 .79835 m .28516 .76613 L .25355 .76417 L p .707 .577 .707 r
F P
0 g
s
.33957 .66008 m .33668 .71337 L .35335 .70378 L p .707 .577 .707 r
F P
0 g
s
.35335 .70378 m .35624 .65048 L .33957 .66008 L p .707 .577 .707 r
F P
0 g
s
.70065 .8313 m .695 .84949 L .68309 .84164 L p .707 .577 .707 r
F P
0 g
s
.68309 .84164 m .68874 .82345 L .70065 .8313 L p .707 .577 .707 r
F P
0 g
s
.21788 .78916 m .22268 .75694 L .19559 .74515 L p .707 .577 .707 r
F P
0 g
s
.22268 .75694 m .21788 .78916 L .24874 .79639 L p .707 .577 .707 r
F P
0 g
s
.28516 .76613 m .28035 .79835 L .30962 .79485 L p .707 .577 .707 r
F P
0 g
s
.30962 .79485 m .31442 .76264 L .28516 .76613 L p .707 .577 .707 r
F P
0 g
s
.17496 .64756 m .17207 .70085 L .19282 .71105 L p .707 .577 .707 r
F P
0 g
s
.17207 .70085 m .17496 .64756 L .16273 .63576 L p .707 .577 .707 r
F P
0 g
s
.6899 .76302 m .67889 .79946 L .65927 .78998 L p .707 .577 .707 r
F P
0 g
s
.65927 .78998 m .67028 .75354 L .6899 .76302 L p .707 .577 .707 r
F P
0 g
s
.67374 .6567 m .667 .71259 L .63997 .70579 L p .707 .577 .707 r
F P
0 g
s
.63997 .70579 m .6467 .6499 L .67374 .6567 L p .707 .577 .707 r
F P
0 g
s
.19079 .77737 m .19559 .74515 L .17492 .72996 L p .707 .577 .707 r
F P
0 g
s
.19559 .74515 m .19079 .77737 L .21788 .78916 L p .707 .577 .707 r
F P
0 g
s
.31442 .76264 m .30962 .79485 L .33368 .78624 L p .707 .577 .707 r
F P
0 g
s
.33368 .78624 m .33848 .75402 L .31442 .76264 L p .707 .577 .707 r
F P
0 g
s
.25302 .84062 m .25551 .82454 L .22453 .8175 L p .707 .577 .707 r
F P
0 g
s
.25551 .82454 m .25302 .84062 L .28456 .84235 L p .707 .577 .707 r
F P
0 g
s
.28456 .84235 m .28705 .82628 L .25551 .82454 L p .707 .577 .707 r
F P
0 g
s
.22204 .83357 m .22453 .8175 L .19714 .80582 L p .707 .577 .707 r
F P
0 g
s
.22453 .8175 m .22204 .83357 L .25302 .84062 L p .707 .577 .707 r
F P
0 g
s
.28705 .82628 m .28456 .84235 L .31357 .8386 L p .707 .577 .707 r
F P
0 g
s
.31357 .8386 m .31606 .82253 L .28705 .82628 L p .707 .577 .707 r
F P
0 g
s
.35624 .65048 m .35335 .70378 L .36079 .6923 L p .707 .577 .707 r
F P
0 g
s
.36079 .6923 m .36368 .639 L .35624 .65048 L p .707 .577 .707 r
F P
0 g
s
.36368 .639 m .36079 .6923 L .35828 .68007 L p .707 .577 .707 r
F P
0 g
s
.35828 .68007 m .36116 .62677 L .36368 .639 L p .707 .577 .707 r
F P
0 g
s
.3644 .79642 m .3644 .29453 L .35584 .28264 L p .707 .577 .707 r
F P
0 g
s
.3644 .29453 m .3644 .79642 L .38624 .80702 L p .707 .577 .707 r
F P
0 g
s
.19714 .80582 m .19465 .8219 L .22204 .83357 L p .707 .577 .707 r
F P
0 g
s
.19465 .8219 m .19714 .80582 L .17602 .79067 L p .707 .577 .707 r
F P
0 g
s
.68874 .82345 m .68309 .84164 L .66306 .83209 L p .707 .577 .707 r
F P
0 g
s
.66306 .83209 m .66872 .8139 L .68874 .82345 L p .707 .577 .707 r
F P
0 g
s
.16273 .63576 m .15984 .68906 L .17207 .70085 L p .707 .577 .707 r
F P
0 g
s
.31606 .82253 m .31357 .8386 L .3372 .82974 L p .707 .577 .707 r
F P
0 g
s
.3372 .82974 m .33969 .81366 L .31606 .82253 L p .707 .577 .707 r
F P
0 g
s
.17012 .76217 m .17492 .72996 L .16269 .71285 L p .707 .577 .707 r
F P
0 g
s
.17492 .72996 m .17012 .76217 L .19079 .77737 L p .707 .577 .707 r
F P
0 g
s
.33848 .75402 m .33368 .78624 L .35017 .77335 L p .707 .577 .707 r
F P
0 g
s
.35017 .77335 m .35497 .74114 L .33848 .75402 L p .707 .577 .707 r
F P
0 g
s
.63861 .29204 m .63862 .79393 L .64416 .78191 L p .707 .577 .707 r
F P
0 g
s
.64416 .78191 m .64416 .28002 L .63861 .29204 L p .707 .577 .707 r
F P
0 g
s
.15984 .68906 m .16273 .63576 L .16021 .62353 L p .707 .577 .707 r
F P
0 g
s
.17602 .79067 m .17353 .80675 L .19465 .8219 L p .707 .577 .707 r
F P
0 g
s
.17353 .80675 m .17602 .79067 L .16324 .77352 L p .707 .577 .707 r
F P
0 g
s
.33969 .81366 m .3372 .82974 L .35316 .81662 L p .707 .577 .707 r
F P
0 g
s
.35316 .81662 m .35565 .80055 L .33969 .81366 L p .707 .577 .707 r
F P
0 g
s
.66872 .8139 m .66306 .83209 L .63689 .82176 L p .707 .577 .707 r
F P
0 g
s
.63689 .82176 m .64255 .80356 L .66872 .8139 L p .707 .577 .707 r
F P
0 g
s
.16269 .71285 m .15789 .74506 L .17012 .76217 L p .707 .577 .707 r
F P
0 g
s
.15789 .74506 m .16269 .71285 L .16011 .69549 L p .707 .577 .707 r
F P
0 g
s
.35497 .74114 m .35017 .77335 L .35748 .75745 L p .707 .577 .707 r
F P
0 g
s
.35748 .75745 m .36228 .72524 L .35497 .74114 L p .707 .577 .707 r
F P
0 g
s
.16021 .62353 m .15732 .67682 L .15984 .68906 L p .707 .577 .707 r
F P
0 g
s
.16324 .77352 m .16075 .7896 L .17353 .80675 L p .707 .577 .707 r
F P
0 g
s
.15732 .67682 m .16021 .62353 L .16765 .61205 L p .707 .577 .707 r
F P
0 g
s
.64255 .80356 m .63689 .82176 L .60713 .81166 L p .707 .577 .707 r
F P
0 g
s
.35987 .80054 m .36235 .78447 L .35565 .80055 L p .707 .577 .707 r
F P
0 g
s
.36116 .62677 m .35828 .68007 L .34604 .66827 L p .707 .577 .707 r
F P
0 g
s
.34604 .66827 m .34893 .61498 L .36116 .62677 L p .707 .577 .707 r
F P
0 g
s
.36228 .72524 m .35748 .75745 L .35489 .7401 L p .707 .577 .707 r
F P
0 g
s
.35489 .7401 m .3597 .70788 L .36228 .72524 L p .707 .577 .707 r
F P
0 g
s
.36235 .78447 m .35987 .80054 L .35667 .78307 L p .707 .577 .707 r
F P
0 g
s
.35667 .78307 m .35916 .767 L .36235 .78447 L p .707 .577 .707 r
F P
0 g
s
.3597 .70788 m .35489 .7401 L .34267 .72299 L p .707 .577 .707 r
F P
0 g
s
.34267 .72299 m .34747 .69077 L .3597 .70788 L p .707 .577 .707 r
F P
0 g
s
.35916 .767 m .35667 .78307 L .34389 .76592 L p .707 .577 .707 r
F P
0 g
s
.34389 .76592 m .34638 .74985 L .35916 .767 L p .707 .577 .707 r
F P
0 g
s
.35584 .28264 m .35584 .78453 L .3644 .79642 L p .707 .577 .707 r
F P
0 g
s
.35584 .78453 m .35584 .28264 L .36138 .27062 L p .707 .577 .707 r
F P
0 g
s
.16075 .7896 m .16324 .77352 L .16004 .75605 L p .707 .577 .707 r
F P
0 g
s
.35565 .80055 m .35316 .81662 L .35987 .80054 L p .707 .577 .707 r
F P
0 g
s
.16011 .69549 m .15531 .72771 L .15789 .74506 L p .707 .577 .707 r
F P
0 g
s
.64416 .28002 m .64416 .78191 L .6356 .77002 L p .707 .577 .707 r
F P
0 g
s
.6356 .77002 m .6356 .26813 L .64416 .28002 L p .707 .577 .707 r
F P
0 g
s
.16004 .75605 m .15756 .77213 L .16075 .7896 L p .707 .577 .707 r
F P
0 g
s
.15531 .72771 m .16011 .69549 L .16742 .67959 L p .707 .577 .707 r
F P
0 g
s
.16765 .61205 m .16476 .66535 L .15732 .67682 L p .707 .577 .707 r
F P
0 g
s
.16476 .66535 m .16765 .61205 L .18432 .60245 L p .707 .577 .707 r
F P
0 g
s
.15756 .77213 m .16004 .75605 L .16675 .73997 L p .707 .577 .707 r
F P
0 g
s
.16742 .67959 m .16262 .71181 L .15531 .72771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16675 .73997 m .16426 .75605 L .15756 .77213 L p .707 .577 .707 r
F P
0 g
s
.16262 .71181 m .16742 .67959 L .18391 .6667 L p .707 .577 .707 r
F P
0 g
s
.34893 .61498 m .34604 .66827 L .3253 .65807 L p .707 .577 .707 r
F P
0 g
s
.3253 .65807 m .32818 .60478 L .34893 .61498 L p .707 .577 .707 r
F P
0 g
s
.36138 .77251 m .36138 .27062 L .3805 .25965 L p .707 .577 .707 r
F P
0 g
s
.36138 .27062 m .36138 .77251 L .35584 .78453 L p .707 .577 .707 r
F P
0 g
s
.18432 .60245 m .18143 .65575 L .16476 .66535 L p .707 .577 .707 r
F P
0 g
s
.18143 .65575 m .18432 .60245 L .20859 .59568 L p .707 .577 .707 r
F P
0 g
s
.6356 .26813 m .6356 .77002 L .61376 .75942 L p .707 .577 .707 r
F P
0 g
s
.61376 .75942 m .61376 .25753 L .6356 .26813 L p .707 .577 .707 r
F P
0 g
s
.16426 .75605 m .16675 .73997 L .18271 .72686 L p .707 .577 .707 r
F P
0 g
s
.18391 .6667 m .17911 .69892 L .16262 .71181 L p .707 .577 .707 r
F P
0 g
s
.32818 .60478 m .3253 .65807 L .29807 .65047 L p .707 .577 .707 r
F P
0 g
s
.29807 .65047 m .30095 .59717 L .32818 .60478 L p .707 .577 .707 r
F P
0 g
s
.17911 .69892 m .18391 .6667 L .20797 .65809 L p .707 .577 .707 r
F P
0 g
s
.34747 .69077 m .34267 .72299 L .322 .70779 L p .707 .577 .707 r
F P
0 g
s
.322 .70779 m .3268 .67558 L .34747 .69077 L p .707 .577 .707 r
F P
0 g
s
.18271 .72686 m .18022 .74293 L .16426 .75605 L p .707 .577 .707 r
F P
0 g
s
.2057 .64898 m .20859 .59568 L .23808 .59239 L p .707 .577 .707 r
F P
0 g
s
.20859 .59568 m .2057 .64898 L .18143 .65575 L p .707 .577 .707 r
F P
0 g
s
.30095 .59717 m .29807 .65047 L .26702 .6462 L p .707 .577 .707 r
F P
0 g
s
.26702 .6462 m .2699 .5929 L .30095 .59717 L p .707 .577 .707 r
F P
0 g
s
.18022 .74293 m .18271 .72686 L .20634 .71799 L p .707 .577 .707 r
F P
0 g
s
.23519 .64568 m .23808 .59239 L .2699 .5929 L p .707 .577 .707 r
F P
0 g
s
.23808 .59239 m .23519 .64568 L .2057 .64898 L p .707 .577 .707 r
F P
0 g
s
.3805 .25965 m .3805 .76154 L .36138 .77251 L p .707 .577 .707 r
F P
0 g
s
.3805 .76154 m .3805 .25965 L .41131 .2508 L p .707 .577 .707 r
F P
0 g
s
.34638 .74985 m .34389 .76592 L .32277 .75077 L p .707 .577 .707 r
F P
0 g
s
.32277 .75077 m .32526 .7347 L .34638 .74985 L p .707 .577 .707 r
F P
0 g
s
.20316 .69031 m .20797 .65809 L .23723 .6546 L p .707 .577 .707 r
F P
0 g
s
.20797 .65809 m .20316 .69031 L .17911 .69892 L p .707 .577 .707 r
F P
0 g
s
.3268 .67558 m .322 .70779 L .2949 .696 L p .707 .577 .707 r
F P
0 g
s
.2949 .696 m .29971 .66379 L .3268 .67558 L p .707 .577 .707 r
F P
0 g
s
.2699 .5929 m .26702 .6462 L .23519 .64568 L p .707 .577 .707 r
F P
0 g
s
.61376 .25753 m .61376 .75942 L .58078 .75115 L p .707 .577 .707 r
F P
0 g
s
.58078 .75115 m .58078 .24926 L .61376 .25753 L p .707 .577 .707 r
F P
0 g
s
.20634 .71799 m .20386 .73407 L .18022 .74293 L p .707 .577 .707 r
F P
0 g
s
.23243 .68681 m .23723 .6546 L .26884 .65656 L p .707 .577 .707 r
F P
0 g
s
.23723 .6546 m .23243 .68681 L .20316 .69031 L p .707 .577 .707 r
F P
0 g
s
.29971 .66379 m .2949 .696 L .26404 .68877 L p .707 .577 .707 r
F P
0 g
s
.26404 .68877 m .26884 .65656 L .29971 .66379 L p .707 .577 .707 r
F P
0 g
s
.73298 .64635 m .73009 .5894 L .69905 .58979 L p .707 .577 .707 r
F P
0 g
s
.73009 .5894 m .73298 .64635 L .7648 .64439 L p .707 .577 .707 r
F P
0 g
s
.7648 .64439 m .76192 .58744 L .73009 .5894 L p .707 .577 .707 r
F P
0 g
s
.76192 .58744 m .7648 .64439 L .79429 .64106 L p .707 .577 .707 r
F P
0 g
s
.79429 .64106 m .79141 .58411 L .76192 .58744 L p .707 .577 .707 r
F P
0 g
s
.20386 .73407 m .20634 .71799 L .23535 .71425 L p .707 .577 .707 r
F P
0 g
s
.26884 .65656 m .26404 .68877 L .23243 .68681 L p .707 .577 .707 r
F P
0 g
s
.32526 .7347 m .32277 .75077 L .29538 .7391 L p .707 .577 .707 r
F P
0 g
s
.29538 .7391 m .29787 .72303 L .32526 .7347 L p .707 .577 .707 r
F P
0 g
s
.70193 .64674 m .69905 .58979 L .67182 .58859 L p .707 .577 .707 r
F P
0 g
s
.69905 .58979 m .70193 .64674 L .73298 .64635 L p .707 .577 .707 r
F P
0 g
s
.23535 .71425 m .23286 .73032 L .20386 .73407 L p .707 .577 .707 r
F P
0 g
s
.79141 .58411 m .79429 .64106 L .81856 .63669 L p .707 .577 .707 r
F P
0 g
s
.81856 .63669 m .81568 .57974 L .79141 .58411 L p .707 .577 .707 r
F P
0 g
s
.23286 .73032 m .23535 .71425 L .26689 .71598 L p .707 .577 .707 r
F P
0 g
s
.67182 .58859 m .6747 .64554 L .70193 .64674 L p .707 .577 .707 r
F P
0 g
s
.29787 .72303 m .29538 .7391 L .2644 .73205 L p .707 .577 .707 r
F P
0 g
s
.2644 .73205 m .26689 .71598 L .29787 .72303 L p .707 .577 .707 r
F P
0 g
s
.41131 .75269 m .41131 .2508 L .4508 .24494 L p .707 .577 .707 r
F P
0 g
s
.41131 .2508 m .41131 .75269 L .3805 .76154 L p .707 .577 .707 r
F P
0 g
s
.70029 .65627 m .7051 .69442 L .73596 .69037 L p .707 .577 .707 r
F P
0 g
s
.73596 .69037 m .73115 .65222 L .70029 .65627 L p .707 .577 .707 r
F P
0 g
s
.73115 .65222 m .73596 .69037 L .76757 .68645 L p .707 .577 .707 r
F P
0 g
s
.76757 .68645 m .76277 .6483 L .73115 .65222 L p .707 .577 .707 r
F P
0 g
s
.26689 .71598 m .2644 .73205 L .23286 .73032 L p .707 .577 .707 r
F P
0 g
s
.76277 .6483 m .76757 .68645 L .79683 .68305 L p .707 .577 .707 r
F P
0 g
s
.79683 .68305 m .79203 .64489 L .76277 .6483 L p .707 .577 .707 r
F P
0 g
s
.58078 .24926 m .58078 .75115 L .5399 .74602 L p .707 .577 .707 r
F P
0 g
s
.5399 .74602 m .5399 .24413 L .58078 .24926 L p .707 .577 .707 r
F P
0 g
s
.6747 .64554 m .67182 .58859 L .65107 .58591 L p .707 .577 .707 r
F P
0 g
s
.6732 .66005 m .678 .69821 L .7051 .69442 L p .707 .577 .707 r
F P
0 g
s
.7051 .69442 m .70029 .65627 L .6732 .66005 L p .707 .577 .707 r
F P
0 g
s
.65107 .58591 m .65395 .64286 L .6747 .64554 L p .707 .577 .707 r
F P
0 g
s
.79203 .64489 m .79683 .68305 L .82089 .68049 L p .707 .577 .707 r
F P
0 g
s
.82089 .68049 m .81609 .64234 L .79203 .64489 L p .707 .577 .707 r
F P
0 g
s
.81568 .57974 m .81856 .63669 L .83523 .63171 L p .707 .577 .707 r
F P
0 g
s
.83523 .63171 m .83235 .57475 L .81568 .57974 L p .707 .577 .707 r
F P
0 g
s
.70213 .71586 m .70462 .73493 L .7356 .73072 L p .707 .577 .707 r
F P
0 g
s
.7356 .73072 m .73311 .71165 L .70213 .71586 L p .707 .577 .707 r
F P
0 g
s
.73311 .71165 m .7356 .73072 L .76714 .72668 L p .707 .577 .707 r
F P
0 g
s
.76714 .72668 m .76465 .70762 L .73311 .71165 L p .707 .577 .707 r
F P
0 g
s
.4508 .74683 m .4508 .24494 L .49511 .24265 L p .707 .577 .707 r
F P
0 g
s
.4508 .24494 m .4508 .74683 L .41131 .75269 L p .707 .577 .707 r
F P
0 g
s
.76465 .70762 m .76714 .72668 L .79614 .72322 L p .707 .577 .707 r
F P
0 g
s
.79614 .72322 m .79365 .70416 L .76465 .70762 L p .707 .577 .707 r
F P
0 g
s
.5399 .24413 m .5399 .74602 L .49511 .74454 L p .707 .577 .707 r
F P
0 g
s
.49511 .74454 m .49511 .24265 L .5399 .24413 L p .707 .577 .707 r
F P
0 g
s
.67474 .71984 m .67723 .7389 L .70462 .73493 L p .707 .577 .707 r
F P
0 g
s
.70462 .73493 m .70213 .71586 L .67474 .71984 L p .707 .577 .707 r
F P
0 g
s
.65253 .6632 m .65733 .70135 L .678 .69821 L p .707 .577 .707 r
F P
0 g
s
.678 .69821 m .6732 .66005 L .65253 .6632 L p .707 .577 .707 r
F P
0 g
s
.49511 .24265 m .49511 .74454 L .4508 .74683 L p .707 .577 .707 r
F P
0 g
s
.65395 .64286 m .65107 .58591 L .63884 .58201 L p .707 .577 .707 r
F P
0 g
s
.79365 .70416 m .79614 .72322 L .81978 .72067 L p .707 .577 .707 r
F P
0 g
s
.81978 .72067 m .81729 .70161 L .79365 .70416 L p .707 .577 .707 r
F P
0 g
s
.81609 .64234 m .82089 .68049 L .83738 .67903 L p .707 .577 .707 r
F P
0 g
s
.83738 .67903 m .83258 .64087 L .81609 .64234 L p .707 .577 .707 r
F P
0 g
s
.63884 .58201 m .64172 .63896 L .65395 .64286 L p .707 .577 .707 r
F P
0 g
s
.65362 .72319 m .65611 .74225 L .67723 .7389 L p .707 .577 .707 r
F P
0 g
s
.67723 .7389 m .67474 .71984 L .65362 .72319 L p .707 .577 .707 r
F P
0 g
s
.83235 .57475 m .83523 .63171 L .84267 .62659 L p .707 .577 .707 r
F P
0 g
s
.84267 .62659 m .83979 .56964 L .83235 .57475 L p .707 .577 .707 r
F P
0 g
s
.6403 .6654 m .64511 .70355 L .65733 .70135 L p .707 .577 .707 r
F P
0 g
s
.65733 .70135 m .65253 .6632 L .6403 .6654 L p .707 .577 .707 r
F P
0 g
s
.81729 .70161 m .81978 .72067 L .83573 .71929 L p .707 .577 .707 r
F P
0 g
s
.83573 .71929 m .83325 .70022 L .81729 .70161 L p .707 .577 .707 r
F P
0 g
s
.64172 .63896 m .63884 .58201 L .63632 .57727 L p .707 .577 .707 r
F P
0 g
s
.64084 .72559 m .64332 .74465 L .65611 .74225 L p .707 .577 .707 r
F P
0 g
s
.65611 .74225 m .65362 .72319 L .64084 .72559 L p .707 .577 .707 r
F P
0 g
s
.83258 .64087 m .83738 .67903 L .84469 .67881 L p .707 .577 .707 r
F P
0 g
s
.84469 .67881 m .83989 .64065 L .83258 .64087 L p .707 .577 .707 r
F P
0 g
s
.63632 .57727 m .6392 .63422 L .64172 .63896 L p .707 .577 .707 r
F P
0 g
s
.83979 .56964 m .84267 .62659 L .84016 .62185 L p .707 .577 .707 r
F P
0 g
s
.84016 .62185 m .83727 .5649 L .83979 .56964 L p .707 .577 .707 r
F P
0 g
s
.63772 .66644 m .64252 .7046 L .64511 .70355 L p .707 .577 .707 r
F P
0 g
s
.64511 .70355 m .6403 .6654 L .63772 .66644 L p .707 .577 .707 r
F P
0 g
s
.83325 .70022 m .83573 .71929 L .84244 .71919 L p .707 .577 .707 r
F P
0 g
s
.84244 .71919 m .83995 .70013 L .83325 .70022 L p .707 .577 .707 r
F P
0 g
s
.6392 .63422 m .63632 .57727 L .64376 .57215 L p .707 .577 .707 r
F P
0 g
s
.63764 .7268 m .64013 .74586 L .64332 .74465 L p .707 .577 .707 r
F P
0 g
s
.64332 .74465 m .64084 .72559 L .63764 .7268 L p .707 .577 .707 r
F P
0 g
s
.83989 .64065 m .84469 .67881 L .84211 .67985 L p .707 .577 .707 r
F P
0 g
s
.84211 .67985 m .8373 .6417 L .83989 .64065 L p .707 .577 .707 r
F P
0 g
s
.64376 .57215 m .64664 .62911 L .6392 .63422 L p .707 .577 .707 r
F P
0 g
s
.83727 .5649 m .84016 .62185 L .82792 .61795 L p .707 .577 .707 r
F P
0 g
s
.82792 .61795 m .82504 .561 L .83727 .5649 L p .707 .577 .707 r
F P
0 g
s
.64503 .66622 m .64983 .70438 L .64252 .7046 L p .707 .577 .707 r
F P
0 g
s
.64252 .7046 m .63772 .66644 L .64503 .66622 L p .707 .577 .707 r
F P
0 g
s
.39089 .62588 m .38416 .5715 L .3533 .57257 L p .707 .577 .707 r
F P
0 g
s
.38416 .5715 m .39089 .62588 L .42254 .62158 L p .707 .577 .707 r
F P
0 g
s
.42254 .62158 m .41581 .5672 L .38416 .5715 L p .707 .577 .707 r
F P
0 g
s
.41581 .5672 m .42254 .62158 L .4519 .61446 L p .707 .577 .707 r
F P
0 g
s
.4519 .61446 m .44517 .56008 L .41581 .5672 L p .707 .577 .707 r
F P
0 g
s
.83995 .70013 m .84244 .71919 L .83925 .72041 L p .707 .577 .707 r
F P
0 g
s
.83925 .72041 m .83676 .70134 L .83995 .70013 L p .707 .577 .707 r
F P
0 g
s
.36003 .62695 m .3533 .57257 L .32626 .5703 L p .707 .577 .707 r
F P
0 g
s
.3533 .57257 m .36003 .62695 L .39089 .62588 L p .707 .577 .707 r
F P
0 g
s
.64664 .62911 m .64376 .57215 L .66043 .56717 L p .707 .577 .707 r
F P
0 g
s
.44517 .56008 m .4519 .61446 L .47608 .60523 L p .707 .577 .707 r
F P
0 g
s
.47608 .60523 m .46935 .55085 L .44517 .56008 L p .707 .577 .707 r
F P
0 g
s
.64435 .72671 m .64684 .74577 L .64013 .74586 L p .707 .577 .707 r
F P
0 g
s
.64013 .74586 m .63764 .7268 L .64435 .72671 L p .707 .577 .707 r
F P
0 g
s
.8373 .6417 m .84211 .67985 L .82988 .68205 L p .707 .577 .707 r
F P
0 g
s
.82988 .68205 m .82508 .6439 L .8373 .6417 L p .707 .577 .707 r
F P
0 g
s
.66043 .56717 m .66331 .62412 L .64664 .62911 L p .707 .577 .707 r
F P
0 g
s
.82504 .561 m .82792 .61795 L .80718 .61527 L p .707 .577 .707 r
F P
0 g
s
.80718 .61527 m .8043 .55832 L .82504 .561 L p .707 .577 .707 r
F P
0 g
s
.42691 .68397 m .4159 .64992 L .38534 .65917 L p .707 .577 .707 r
F P
0 g
s
.4159 .64992 m .42691 .68397 L .45534 .67158 L p .707 .577 .707 r
F P
0 g
s
.45534 .67158 m .44434 .63753 L .4159 .64992 L p .707 .577 .707 r
F P
0 g
s
.33299 .62468 m .32626 .5703 L .30569 .56491 L p .707 .577 .707 r
F P
0 g
s
.32626 .5703 m .33299 .62468 L .36003 .62695 L p .707 .577 .707 r
F P
0 g
s
.39635 .69323 m .38534 .65917 L .35564 .66438 L p .707 .577 .707 r
F P
0 g
s
.38534 .65917 m .39635 .69323 L .42691 .68397 L p .707 .577 .707 r
F P
0 g
s
.66152 .66476 m .66632 .70291 L .64983 .70438 L p .707 .577 .707 r
F P
0 g
s
.64983 .70438 m .64503 .66622 L .66152 .66476 L p .707 .577 .707 r
F P
0 g
s
.46935 .55085 m .47608 .60523 L .49272 .59479 L p .707 .577 .707 r
F P
0 g
s
.49272 .59479 m .48599 .54041 L .46935 .55085 L p .707 .577 .707 r
F P
0 g
s
.44434 .63753 m .45534 .67158 L .47887 .65725 L p .707 .577 .707 r
F P
0 g
s
.47887 .65725 m .46786 .6232 L .44434 .63753 L p .707 .577 .707 r
F P
0 g
s
.83676 .70134 m .83925 .72041 L .82647 .72281 L p .707 .577 .707 r
F P
0 g
s
.82647 .72281 m .82398 .70374 L .83676 .70134 L p .707 .577 .707 r
F P
0 g
s
.66331 .62412 m .66043 .56717 L .6847 .5628 L p .707 .577 .707 r
F P
0 g
s
.36665 .69843 m .35564 .66438 L .32971 .66502 L p .707 .577 .707 r
F P
0 g
s
.35564 .66438 m .36665 .69843 L .39635 .69323 L p .707 .577 .707 r
F P
0 g
s
.42331 .72661 m .41766 .70968 L .38722 .71938 L p .707 .577 .707 r
F P
0 g
s
.41766 .70968 m .42331 .72661 L .45145 .71379 L p .707 .577 .707 r
F P
0 g
s
.45145 .71379 m .44579 .69685 L .41766 .70968 L p .707 .577 .707 r
F P
0 g
s
.39287 .73631 m .38722 .71938 L .35745 .725 L p .707 .577 .707 r
F P
0 g
s
.38722 .71938 m .39287 .73631 L .42331 .72661 L p .707 .577 .707 r
F P
0 g
s
.30569 .56491 m .31242 .61929 L .33299 .62468 L p .707 .577 .707 r
F P
0 g
s
.66031 .72532 m .66279 .74438 L .64684 .74577 L p .707 .577 .707 r
F P
0 g
s
.64684 .74577 m .64435 .72671 L .66031 .72532 L p .707 .577 .707 r
F P
0 g
s
.82508 .6439 m .82988 .68205 L .80921 .6852 L p .707 .577 .707 r
F P
0 g
s
.80921 .6852 m .80441 .64704 L .82508 .6439 L p .707 .577 .707 r
F P
0 g
s
.6847 .5628 m .68758 .61975 L .66331 .62412 L p .707 .577 .707 r
F P
0 g
s
.8043 .55832 m .80718 .61527 L .77995 .61407 L p .707 .577 .707 r
F P
0 g
s
.77995 .61407 m .77707 .55712 L .8043 .55832 L p .707 .577 .707 r
F P
0 g
s
.46786 .6232 m .47887 .65725 L .49517 .64239 L p .707 .577 .707 r
F P
0 g
s
.49517 .64239 m .48416 .60834 L .46786 .6232 L p .707 .577 .707 r
F P
0 g
s
.31242 .61929 m .30569 .56491 L .29359 .55694 L p .707 .577 .707 r
F P
0 g
s
.44579 .69685 m .45145 .71379 L .47453 .6991 L p .707 .577 .707 r
F P
0 g
s
.47453 .6991 m .46887 .68216 L .44579 .69685 L p .707 .577 .707 r
F P
0 g
s
.35745 .725 m .36311 .74194 L .39287 .73631 L p .707 .577 .707 r
F P
0 g
s
.32971 .66502 m .34072 .69907 L .36665 .69843 L p .707 .577 .707 r
F P
0 g
s
.36311 .74194 m .35745 .725 L .33128 .72601 L p .707 .577 .707 r
F P
0 g
s
.48599 .54041 m .49272 .59479 L .50019 .58416 L p .707 .577 .707 r
F P
0 g
s
.50019 .58416 m .49346 .52978 L .48599 .54041 L p .707 .577 .707 r
F P
0 g
s
.34072 .69907 m .32971 .66502 L .31009 .66104 L p .707 .577 .707 r
F P
0 g
s
.68557 .6622 m .69038 .70036 L .66632 .70291 L p .707 .577 .707 r
F P
0 g
s
.66632 .70291 m .66152 .66476 L .68557 .6622 L p .707 .577 .707 r
F P
0 g
s
.68758 .61975 m .6847 .5628 L .71419 .55947 L p .707 .577 .707 r
F P
0 g
s
.33128 .72601 m .33693 .74294 L .36311 .74194 L p .707 .577 .707 r
F P
0 g
s
.82398 .70374 m .82647 .72281 L .80535 .72616 L p .707 .577 .707 r
F P
0 g
s
.80535 .72616 m .80286 .70709 L .82398 .70374 L p .707 .577 .707 r
F P
0 g
s
.77707 .55712 m .77995 .61407 L .7489 .61446 L p .707 .577 .707 r
F P
0 g
s
.7489 .61446 m .74602 .55751 L .77707 .55712 L p .707 .577 .707 r
F P
0 g
s
.71419 .55947 m .71707 .61642 L .68758 .61975 L p .707 .577 .707 r
F P
0 g
s
.46887 .68216 m .47453 .6991 L .49029 .68397 L p .707 .577 .707 r
F P
0 g
s
.49029 .68397 m .48463 .66704 L .46887 .68216 L p .707 .577 .707 r
F P
0 g
s
.29359 .55694 m .30033 .61132 L .31242 .61929 L p .707 .577 .707 r
F P
0 g
s
.80441 .64704 m .80921 .6852 L .78212 .68898 L p .707 .577 .707 r
F P
0 g
s
.71707 .61642 m .71419 .55947 L .74602 .55751 L p .707 .577 .707 r
F P
0 g
s
.78212 .68898 m .77731 .65083 L .80441 .64704 L p .707 .577 .707 r
F P
0 g
s
.31009 .66104 m .3211 .69509 L .34072 .69907 L p .707 .577 .707 r
F P
0 g
s
.74602 .55751 m .7489 .61446 L .71707 .61642 L p .707 .577 .707 r
F P
0 g
s
.33693 .74294 m .33128 .72601 L .31125 .72229 L p .707 .577 .707 r
F P
0 g
s
.68394 .72277 m .68643 .74183 L .66279 .74438 L p .707 .577 .707 r
F P
0 g
s
.66279 .74438 m .66031 .72532 L .68394 .72277 L p .707 .577 .707 r
F P
0 g
s
.48416 .60834 m .49517 .64239 L .50267 .62846 L p .707 .577 .707 r
F P
0 g
s
.50267 .62846 m .49166 .59441 L .48416 .60834 L p .707 .577 .707 r
F P
0 g
s
.71484 .6588 m .71964 .69695 L .69038 .70036 L p .707 .577 .707 r
F P
0 g
s
.69038 .70036 m .68557 .6622 L .71484 .6588 L p .707 .577 .707 r
F P
0 g
s
.30033 .61132 m .29359 .55694 L .29116 .54716 L p .707 .577 .707 r
F P
0 g
s
.31125 .72229 m .31691 .73923 L .33693 .74294 L p .707 .577 .707 r
F P
0 g
s
.3211 .69509 m .31009 .66104 L .2987 .65283 L p .707 .577 .707 r
F P
0 g
s
.49346 .52978 m .50019 .58416 L .49776 .57438 L p .707 .577 .707 r
F P
0 g
s
.49776 .57438 m .49103 .52 L .49346 .52978 L p .707 .577 .707 r
F P
0 g
s
.77731 .65083 m .78212 .68898 L .75126 .69303 L p .707 .577 .707 r
F P
0 g
s
.75126 .69303 m .74645 .65488 L .77731 .65083 L p .707 .577 .707 r
F P
0 g
s
.80286 .70709 m .80535 .72616 L .77796 .73013 L p .707 .577 .707 r
F P
0 g
s
.77796 .73013 m .77547 .71107 L .80286 .70709 L p .707 .577 .707 r
F P
0 g
s
.74645 .65488 m .75126 .69303 L .71964 .69695 L p .707 .577 .707 r
F P
0 g
s
.71964 .69695 m .71484 .6588 L .74645 .65488 L p .707 .577 .707 r
F P
0 g
s
.48463 .66704 m .49029 .68397 L .49719 .6699 L p .707 .577 .707 r
F P
0 g
s
.49719 .6699 m .49153 .65297 L .48463 .66704 L p .707 .577 .707 r
F P
0 g
s
.71295 .71931 m .71544 .73837 L .68643 .74183 L p .707 .577 .707 r
F P
0 g
s
.68643 .74183 m .68394 .72277 L .71295 .71931 L p .707 .577 .707 r
F P
0 g
s
.2987 .65283 m .30971 .68688 L .3211 .69509 L p .707 .577 .707 r
F P
0 g
s
.29116 .54716 m .2979 .60154 L .30033 .61132 L p .707 .577 .707 r
F P
0 g
s
.31691 .73923 m .31125 .72229 L .29934 .71422 L p .707 .577 .707 r
F P
0 g
s
.49166 .59441 m .50267 .62846 L .50062 .61682 L p .707 .577 .707 r
F P
0 g
s
.50062 .61682 m .48961 .58277 L .49166 .59441 L p .707 .577 .707 r
F P
0 g
s
.77547 .71107 m .77796 .73013 L .74698 .73434 L p .707 .577 .707 r
F P
0 g
s
.74698 .73434 m .74449 .71528 L .77547 .71107 L p .707 .577 .707 r
F P
0 g
s
.29934 .71422 m .305 .73115 L .31691 .73923 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74449 .71528 m .74698 .73434 L .71544 .73837 L p .707 .577 .707 r
F P
0 g
s
.71544 .73837 m .71295 .71931 L .74449 .71528 L p .707 .577 .707 r
F P
0 g
s
.2979 .60154 m .29116 .54716 L .29863 .53653 L p .707 .577 .707 r
F P
0 g
s
.30971 .68688 m .2987 .65283 L .29665 .64119 L p .707 .577 .707 r
F P
0 g
s
.49103 .52 m .49776 .57438 L .48567 .5664 L p .707 .577 .707 r
F P
0 g
s
.48567 .5664 m .47893 .51202 L .49103 .52 L p .707 .577 .707 r
F P
0 g
s
.49153 .65297 m .49719 .6699 L .49455 .65826 L p .707 .577 .707 r
F P
0 g
s
.49455 .65826 m .4889 .64132 L .49153 .65297 L p .707 .577 .707 r
F P
0 g
s
.29665 .64119 m .30766 .67524 L .30971 .68688 L p .707 .577 .707 r
F P
0 g
s
.305 .73115 m .29934 .71422 L .29671 .70257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29863 .53653 m .30537 .59091 L .2979 .60154 L p .707 .577 .707 r
F P
0 g
s
.48961 .58277 m .50062 .61682 L .48923 .60861 L p .707 .577 .707 r
F P
0 g
s
.48923 .60861 m .47822 .57456 L .48961 .58277 L p .707 .577 .707 r
F P
0 g
s
.29671 .70257 m .30237 .71951 L .305 .73115 L p .707 .577 .707 r
F P
0 g
s
.30537 .59091 m .29863 .53653 L .31527 .52608 L p .707 .577 .707 r
F P
0 g
s
.30766 .67524 m .29665 .64119 L .30415 .62726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47893 .51202 m .48567 .5664 L .46509 .56102 L p .707 .577 .707 r
F P
0 g
s
.46509 .56102 m .45836 .50664 L .47893 .51202 L p .707 .577 .707 r
F P
0 g
s
.4889 .64132 m .49455 .65826 L .48264 .65018 L p .707 .577 .707 r
F P
0 g
s
.48264 .65018 m .47699 .63325 L .4889 .64132 L p .707 .577 .707 r
F P
0 g
s
.30415 .62726 m .31516 .66131 L .30766 .67524 L p .707 .577 .707 r
F P
0 g
s
.30237 .71951 m .29671 .70257 L .30361 .6885 L p .707 .577 .707 r
F P
0 g
s
.31527 .52608 m .32201 .58046 L .30537 .59091 L p .707 .577 .707 r
F P
0 g
s
.47822 .57456 m .48923 .60861 L .4696 .60463 L p .707 .577 .707 r
F P
0 g
s
.4696 .60463 m .45859 .57058 L .47822 .57456 L p .707 .577 .707 r
F P
0 g
s
.30361 .6885 m .30927 .70543 L .30237 .71951 L p .707 .577 .707 r
F P
0 g
s
.32201 .58046 m .31527 .52608 L .33945 .51686 L p .707 .577 .707 r
F P
0 g
s
.31516 .66131 m .30415 .62726 L .32045 .6124 L p .707 .577 .707 r
F P
0 g
s
.45836 .50664 m .46509 .56102 L .43805 .55875 L p .707 .577 .707 r
F P
0 g
s
.43805 .55875 m .43132 .50437 L .45836 .50664 L p .707 .577 .707 r
F P
0 g
s
.47699 .63325 m .48264 .65018 L .46262 .64646 L p .707 .577 .707 r
F P
0 g
s
.46262 .64646 m .45696 .62953 L .47699 .63325 L p .707 .577 .707 r
F P
0 g
s
.33945 .51686 m .34619 .57123 L .32201 .58046 L p .707 .577 .707 r
F P
0 g
s
.32045 .6124 m .33146 .64645 L .31516 .66131 L p .707 .577 .707 r
F P
0 g
s
.34619 .57123 m .33945 .51686 L .36881 .50974 L p .707 .577 .707 r
F P
0 g
s
.30927 .70543 m .30361 .6885 L .31937 .67338 L p .707 .577 .707 r
F P
0 g
s
.45859 .57058 m .4696 .60463 L .44368 .60528 L p .707 .577 .707 r
F P
0 g
s
.44368 .60528 m .43267 .57122 L .45859 .57058 L p .707 .577 .707 r
F P
0 g
s
.43132 .50437 m .43805 .55875 L .4072 .55982 L p .707 .577 .707 r
F P
0 g
s
.4072 .55982 m .40046 .50544 L .43132 .50437 L p .707 .577 .707 r
F P
0 g
s
.31937 .67338 m .32503 .69031 L .30927 .70543 L p .707 .577 .707 r
F P
0 g
s
.33146 .64645 m .32045 .6124 L .34397 .59808 L p .707 .577 .707 r
F P
0 g
s
.37554 .56412 m .36881 .50974 L .40046 .50544 L p .707 .577 .707 r
F P
0 g
s
.36881 .50974 m .37554 .56412 L .34619 .57123 L p .707 .577 .707 r
F P
0 g
s
.40046 .50544 m .4072 .55982 L .37554 .56412 L p .707 .577 .707 r
F P
0 g
s
.45696 .62953 m .46262 .64646 L .43644 .64747 L p .707 .577 .707 r
F P
0 g
s
.43644 .64747 m .43079 .63053 L .45696 .62953 L p .707 .577 .707 r
F P
0 g
s
.43267 .57122 m .44368 .60528 L .41398 .61048 L p .707 .577 .707 r
F P
0 g
s
.41398 .61048 m .40297 .57643 L .43267 .57122 L p .707 .577 .707 r
F P
0 g
s
.34397 .59808 m .35498 .63213 L .33146 .64645 L p .707 .577 .707 r
F P
0 g
s
.32503 .69031 m .31937 .67338 L .34245 .65869 L p .707 .577 .707 r
F P
0 g
s
.35498 .63213 m .34397 .59808 L .37241 .58568 L p .707 .577 .707 r
F P
0 g
s
.40297 .57643 m .41398 .61048 L .38342 .61973 L p .707 .577 .707 r
F P
0 g
s
.38342 .61973 m .37241 .58568 L .40297 .57643 L p .707 .577 .707 r
F P
0 g
s
.34245 .65869 m .34811 .67562 L .32503 .69031 L p .707 .577 .707 r
F P
0 g
s
.37241 .58568 m .38342 .61973 L .35498 .63213 L p .707 .577 .707 r
F P
0 g
s
.43079 .63053 m .43644 .64747 L .40668 .6531 L p .707 .577 .707 r
F P
0 g
s
.40668 .6531 m .40102 .63616 L .43079 .63053 L p .707 .577 .707 r
F P
0 g
s
.34811 .67562 m .34245 .65869 L .37059 .64586 L p .707 .577 .707 r
F P
0 g
s
.40102 .63616 m .40668 .6531 L .37624 .6628 L p .707 .577 .707 r
F P
0 g
s
.37624 .6628 m .37059 .64586 L .40102 .63616 L p .707 .577 .707 r
F P
0 g
s
.37059 .64586 m .37624 .6628 L .34811 .67562 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001hOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH8001f
Ool007=oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP000080
07=oo`00Kgoo100000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF0`00L7oo001/Ool30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001^Ool006Yoo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<006aoo`00JGoo00@0
05YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF008006Yoo`00Igoo0P000eYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00J7oo001VOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001WOol006Ioo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Ioo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF4P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo200015YF00<005YFFUH01UYF00@005YFFUIJ
EPL000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol006Eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00@000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005moo`<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005]oo`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Uoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001EOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUIJEP00IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0035YF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Dgoo0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP04001JEP00000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0067oo5`00=Woo001BOol01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF2@0015YF00@0
05YF000000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000?Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol005=oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPX00003FUH005YF00=JEP@00003FUH005YF00EJEP@00005
FUH005YFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
1goo20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YF
00002P001EYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH007oo00H000=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=o
o`03001JEP0000EJEP03001JEUYF00=JEQ8000=JEPl00003FUH005YF00=JEP<000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF00IJEP03001J
EP0000L000=JEP03001JEUYF00EJEP03001JEUYF00<000=JEP04001JEP00000:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05=oo`03001JEP0000EJEP04001JEP000005FUH00`00FUIJEP06FUH400000eYF001JEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00P002UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000
FUIJEP0015YF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF0000009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YF
FUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8000QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo0010OolA0003
Ool2FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000jOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000015YF001JEP001EYF00<005YFFUH00eYF0P001EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00EJEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000dOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH000020008FUH00`00FUIJEP07
FUH00`00FUIJEP07FUH01000FUIJEUYF1@000eYF00@005YFFUH000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
039oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPP000AJEP@00004FUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Goo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF1P001UYF00<005YF00000`000eYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0
15YF0`001UYF0P000UYF0`002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YF
FUH00P00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUH00000FUH00P001eYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YF
FUH0100000=JEP00FUH015YF0P000UYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF200025YF
00<005YFFUH01UYF00<005YFFUH015YF1@0000=JEP000000;Goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH300000eYF001JEP03FUH70005FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
001JEP03FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00eYF
30002eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000015YF001JEUYF1P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUH00004000015YF001JEUYF0`000UYF00<005YFFUH02EYF00<005YF00000P00
1UYF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH0
00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00AJEP<000EJ
EP03001JEP0000@00003FUH005YF00h00003FUH005YF00AJEP03001JEP0000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF00AJEP03001JEUYF009JEP800003FUH0000000EJEP03001JEP0000L000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
0005FUH02000FUIJEUYF001JEP00FUH20005FUH01P00FUH00000FUH000UJEP03001JEUYF00AJEP03
001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD003=oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP<00004FUH005YFFUH20004FUH30004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF000035YF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4@00;Woo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH01000FUIJEP001UYF00D005YFFUIJEP00009JEP80009JEP8000MJ
EP03001JEUYF00MJEP04001JEUYFFUH60002FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0017oo:@000UYF1@0000=JEP00FUH0;Woo000]Ool2
0004FUH00`00FUIJEP03FUH6000AOol60002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJ
EP050009FUH00`00FUIJEP02FUH80006FUH400000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02000KOol90004FUH70002FUH01@00FUIJEP00FUH0;Woo
000/Ool00`00FUH00004FUH00`00FUH00003000KOol20002FUH01@00FUIJEUYF00001EYF00<005YF
FUH00P000UYF00<005YFFUH01UYF1P001eYF00<005YFFUH01UYF1@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF00@000moo`P000AJEPT000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP<000Yoo`l000Eoo`80009JEP03001J
EUYF008000EJEP<000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005
FUH40003Ool80003FUH:0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00002FUH20003FUH300000goo000000040003FUH00`00FUIJEP06FUH00`00FUIJ
EP040002Ool01000FUIJEUYF100015YF0P001eYF00<005YF00000P0025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YF000035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000EJEPL000=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000AJEP@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0009JEPT000QJEP800003FUH005YF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH01P000UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF00<005YFFUH00P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP0000000UYF0`000UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF0`001EYF00D005YFFUIJEP0000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP`0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
;7oo0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80
0004FUH00000FUH20005FUH01000FUIJEUYF0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool20003FUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
0P001eYF00<005YF00000P001eYF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00H005YFFUH0
05YF000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000/Ool20002FUH01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000MJEP80009JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF00AJEP07001JEUYFFUH005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEP8002aoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH01UYF0`001eYF00@005YF000000=JEP03001JEUYF009JEP03001JEUYF00=JEP80
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00P002aoo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH50005FUH30005
FUH00`00FUIJEP030005FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH6000dOol002eoo`<000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJ
EP04001JEUYF0005FUH40007FUH00`00FUIJEP04FUH50002FUH30008FUH00`00FUH00002FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
1`00>Woo000]Ool00`00FUH00002FUH00`00FUIJEP03FUH600000eYF001JEP07FUH00`00FUIJEP02
FUH40002FUH01000FUH000001EYF00@005YFFUH000MJEP03001JEUYF00AJEPL000]JEP8000AJEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1000@Goo000]Ool00`00FUH00002FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH300000eYF00000004FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00FUIJ
EP08FUH20005FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`00
AGoo000]Ool20003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YF00000P000UYF3`001eYF00<005YFFUH01UYF0P001eYF00<005YFFUH0
0eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP004aoo`00;Goo0P000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP80009JEP03
001JEUYF00AJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00002FUH>000LOol:000^Ool002eoo`800004FUH000000003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`0000=JEP00FUH01EYF00<005YF
FUH00P001EYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP05001JEUYFFUH00008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000040002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P005Goo1`000eYF100000=JEP000000;Woo000]Ool30003Ool20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH02P00FUIJEUYF001JEP00FUH005YF0P00
1EYF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP@000MJEP04001JEP000009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP040002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0037oo2@000eYF1`000UYF00<005YFFUH00P00;Woo000/Ool00`00FUH0
0006Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH20003FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF0P0000=JEP00FUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEPD000AJEP04001JEUYFFUH20003Ool90003FUH90003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool40008Ool40002FUH@0002FUH00`00FUIJEP02FUH01@00FUIJEP00FUH01@000UYF
00@005YFFUIJEP8000EJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0UYF0`0000=JEP0000001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo10002Goo1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@001Goo0`00
0eYF0P001EYF10001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00L000=J
EPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00
;7oo0P000UYF00<007ooOol00Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF0`001Woo00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF00MJEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP060002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEUYF1@00<7oo000/Ool20002FUH00`00Oomoo`020004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000UYF3@001UYF00<005YFFUH01UYF0`001UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
2`000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPL003Eoo`00
;7oo0P000eYF0`001EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000UYF00<0
05YFFUH00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
000/Ool20003FUH00`00FUH00005FUH50009Ool60006FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT004Aoo`00;7oo00D005YFFUIJEP00009JEP04001JEUYF
FUH2000DOol40002FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50003
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8001=Ool0
02aoo`04001JEUYF0003FUH01000FUH000006Woo10001EYF0`000UYF00<005YFFUH00UYF2@001eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000=JEP00FUH00eYF00@005YFFUIJEPP005Eoo`00;7oo00@005YF000000=J
EP80009JEP03001oogoo01]oo`8000AJEP03001JEP0000T000EJEP03001JEUYF00EJEP03001JEUYF
00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0004FUH005YFFUH700000eYF0000001IOol002eoo`80009JEP8000AJEP<001eoo`<00003FUH005YF
00AJEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH90008FUH01000FUIJEUYF
30001UYF00<005YFFUH01UYF00<005YFFUH00eYF3P00Fgoo000]Ool40006FUH00`00FUIJEP02000N
Ool20006FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YF00000UYF2@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP80
061oo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P007Woo0P0015YF1@001EYF00<005YF
FUH015YF1@002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002UYF1@000UYF00<005YF
FUH00eYF00@005YFFUH000EJEP<005eoo`00;Goo10001UYF00<005YFFUH015YF10006Goo10000UYF
00<005YFFUH00`001EYF00<005YFFUH0100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00@005YFFUH000IJEP03001JEP000080
05Yoo`00;Goo00@007ooOol000EJEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP<0009J
EP<000EJEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP04001JEUYF0005FUH00`00FUIJEP03FUH2001HOol002aoo`<0009o
o`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEQ0000=JEP03001JEUYF00=JEP03001J
EP0000=JEP8000=JEP800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00005FUH005YFFUH00005FUH00`00FUIJEP04FUH2
001GOol002aoo`03001JEP0000=oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=JEP0000000eYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH005Ioo`00
;7oo00<005YF000017oo0P0000=JEP00FUH01UYF00<005YFFUH01eYF0`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH30005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000EGoo000/Ool01000FUH000001Goo0P001eYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0000AJEP00
000000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP05001J
EUYFFUH0001EOol002aoo`05001JEP00FUH00005Ool20006FUH00`00FUIJEP06FUH50004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00@005YFFUH0
00Moo`8000=JEP03001JEUYF00MJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001FOol002eoo`05001JEUYFFUH00008Ool200000eYF001JEP08FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`04Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200001EYF000005YF00001EYF00<005YFFUH00UYF00<007ooOol0E7oo000]Ool00`00
FUIJEP02FUH00`00Oomoo`07Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001goo0`001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001EYF00@005YFFUIJEP80
05Ioo`00;Woo00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000:Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P000eYF00@005YFFUIJ
EP8005Ioo`00;goo00H005YFFUH005YF000?Ool70004FUH00`00FUIJEP02FUH6000;Ool30005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30004FUH00`00Oomoo`1EOol002moo`03001J
EP0000=JEP8001Aoo`T0015oo`800003Ool0000000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEPD000=JEP03001JEUYF
00AJEP8000AJEP03001oogoo05Eoo`00<7oo0P001EYF00<007ooOol0:Woo0`000goo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF10001UYF00D005YF000005YF008005Moo`00<Goo00<005YFFUH015YF0P00:7oo
0P0000=JEP00Ool01Goo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH00UYF0`001eYF00@005YF000000EJEP04001JEUYFFUH3001GOol0039o
o`8000AJEP04001JEP00000UOol00`00FUIJEP02000:Ool50002FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040008FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF0000F7oo000dOol01000FUIJEP0015YF0P008Goo0P000eYF00<007ooOol0
3Woo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF300015YF00<005YFFUH0
1EYF2000F7oo000eOol30006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0COol60002FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060004FUH50003Ool300000eYF001JEP07FUH3
001LOol003Moo`03001JEUYF00EJEP03001JEUYF00@0011oo`D000AJEP03001JEUYF008001aooal0
0003FUH005YF00MJEPD000Ioo`<000IJEP04001JEUYFFUH2001JOol003Qoo`8000EJEP03001JEUYF
00AJEQ0000=JEP03001JEUYF00=JEP<003Yoo`<00003FUH005YF00MJEP@00004FUH000000006Ool2
0004FUH00`00FUIJEP03FUH00`00Oomoo`1GOol003Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo03eoo`<000MJEP03001JEUYF00EJEP<0
00Eoo`800003FUH005YF00EJEP<005Moo`00?7oo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8004=oo`@0009JEP03001JEUYF00MJEP03001JEP0000<000=oo`80
00IJEP03001JEUYF008005Eoo`00?Woo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000004Uoo`@000QJEP03001JEUYF00=JEPL000=JEP03001JEUYF009JEP03001oogoo05=oo`00@Goo
10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Cgoo0`0015YF00<005YFFUH01UYF00@005YF
FUIJEP<00003FUH005YF009JEP8005Eoo`00AGoo4000F7oo0`0000=JEP00FUH01eYF00<005YFFUH0
15YF0P000eYF0P00EGoo002`Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP04001FOol00;=oo`@0
009JEP03001JEUYF00AJEP04001JEUYFFUH3001FOol00;Moo`D000=JEP03001JEUYF009JEP<005Io
o`00_7oo2`00EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5928 .74367 m .59953 .68777 L .56868 .68258 L p .707 .577 .707 r
F P
0 g
s
.59953 .68777 m .5928 .74367 L .62446 .74675 L p .707 .577 .707 r
F P
0 g
s
.62446 .74675 m .63119 .69086 L .59953 .68777 L p .707 .577 .707 r
F P
0 g
s
.63119 .69086 m .62446 .74675 L .65381 .74743 L p .707 .577 .707 r
F P
0 g
s
.65381 .74743 m .66054 .69154 L .63119 .69086 L p .707 .577 .707 r
F P
0 g
s
.56194 .73847 m .56868 .68258 L .54164 .67578 L p .707 .577 .707 r
F P
0 g
s
.56868 .68258 m .56194 .73847 L .5928 .74367 L p .707 .577 .707 r
F P
0 g
s
.66054 .69154 m .65381 .74743 L .67799 .74563 L p .707 .577 .707 r
F P
0 g
s
.67799 .74563 m .68472 .68974 L .66054 .69154 L p .707 .577 .707 r
F P
0 g
s
.54164 .67578 m .5349 .73168 L .56194 .73847 L p .707 .577 .707 r
F P
0 g
s
.58602 .79515 m .59703 .75872 L .56733 .74877 L p .707 .577 .707 r
F P
0 g
s
.59703 .75872 m .58602 .79515 L .61658 .80386 L p .707 .577 .707 r
F P
0 g
s
.61658 .80386 m .62759 .76742 L .59703 .75872 L p .707 .577 .707 r
F P
0 g
s
.5349 .73168 m .54164 .67578 L .52107 .66805 L p .707 .577 .707 r
F P
0 g
s
.62759 .76742 m .61658 .80386 L .64501 .81047 L p .707 .577 .707 r
F P
0 g
s
.64501 .81047 m .65602 .77403 L .62759 .76742 L p .707 .577 .707 r
F P
0 g
s
.56733 .74877 m .55632 .78521 L .58602 .79515 L p .707 .577 .707 r
F P
0 g
s
.55632 .78521 m .56733 .74877 L .5414 .73856 L p .707 .577 .707 r
F P
0 g
s
.5414 .73856 m .53039 .775 L .55632 .78521 L p .707 .577 .707 r
F P
0 g
s
.52107 .66805 m .51433 .72395 L .5349 .73168 L p .707 .577 .707 r
F P
0 g
s
.65602 .77403 m .64501 .81047 L .66853 .81435 L p .707 .577 .707 r
F P
0 g
s
.66853 .81435 m .67954 .77791 L .65602 .77403 L p .707 .577 .707 r
F P
0 g
s
.59332 .83665 m .59897 .81846 L .56921 .80836 L p .707 .577 .707 r
F P
0 g
s
.59897 .81846 m .59332 .83665 L .62376 .84552 L p .707 .577 .707 r
F P
0 g
s
.62376 .84552 m .62941 .82733 L .59897 .81846 L p .707 .577 .707 r
F P
0 g
s
.68472 .68974 m .67799 .74563 L .69463 .74153 L p .707 .577 .707 r
F P
0 g
s
.69463 .74153 m .70136 .68564 L .68472 .68974 L p .707 .577 .707 r
F P
0 g
s
.56921 .80836 m .56355 .82655 L .59332 .83665 L p .707 .577 .707 r
F P
0 g
s
.62941 .82733 m .62376 .84552 L .65189 .85231 L p .707 .577 .707 r
F P
0 g
s
.65189 .85231 m .65755 .83411 L .62941 .82733 L p .707 .577 .707 r
F P
0 g
s
.53039 .775 m .5414 .73856 L .52178 .72908 L p .707 .577 .707 r
F P
0 g
s
.56355 .82655 m .56921 .80836 L .54303 .79802 L p .707 .577 .707 r
F P
0 g
s
.54303 .79802 m .53738 .81622 L .56355 .82655 L p .707 .577 .707 r
F P
0 g
s
.51433 .72395 m .52107 .66805 L .50897 .66015 L p .707 .577 .707 r
F P
0 g
s
.52178 .72908 m .51077 .76552 L .53039 .775 L p .707 .577 .707 r
F P
0 g
s
.65755 .83411 m .65189 .85231 L .67497 .85633 L p .707 .577 .707 r
F P
0 g
s
.67497 .85633 m .68063 .83814 L .65755 .83411 L p .707 .577 .707 r
F P
0 g
s
.53738 .81622 m .54303 .79802 L .52301 .78847 L p .707 .577 .707 r
F P
0 g
s
.67954 .77791 m .66853 .81435 L .68484 .8151 L p .707 .577 .707 r
F P
0 g
s
.68484 .8151 m .69585 .77866 L .67954 .77791 L p .707 .577 .707 r
F P
0 g
s
.50897 .66015 m .50224 .71604 L .51433 .72395 L p .707 .577 .707 r
F P
0 g
s
.52301 .78847 m .51736 .80666 L .53738 .81622 L p .707 .577 .707 r
F P
0 g
s
.70136 .68564 m .69463 .74153 L .7021 .73554 L p .707 .577 .707 r
F P
0 g
s
.7021 .73554 m .70883 .67964 L .70136 .68564 L p .707 .577 .707 r
F P
0 g
s
.51077 .76552 m .52178 .72908 L .51039 .72127 L p .707 .577 .707 r
F P
0 g
s
.51039 .72127 m .49938 .7577 L .51077 .76552 L p .707 .577 .707 r
F P
0 g
s
.50224 .71604 m .50897 .66015 L .50654 .65284 L p .707 .577 .707 r
F P
0 g
s
.68063 .83814 m .67497 .85633 L .69073 .85721 L p .707 .577 .707 r
F P
0 g
s
.69073 .85721 m .69639 .83902 L .68063 .83814 L p .707 .577 .707 r
F P
0 g
s
.51736 .80666 m .52301 .78847 L .5111 .78062 L p .707 .577 .707 r
F P
0 g
s
.5111 .78062 m .50544 .79882 L .51736 .80666 L p .707 .577 .707 r
F P
0 g
s
.69585 .77866 m .68484 .8151 L .69233 .81267 L p .707 .577 .707 r
F P
0 g
s
.69233 .81267 m .70334 .77623 L .69585 .77866 L p .707 .577 .707 r
F P
0 g
s
.50654 .65284 m .49981 .70873 L .50224 .71604 L p .707 .577 .707 r
F P
0 g
s
.49938 .7577 m .51039 .72127 L .50834 .71587 L p .707 .577 .707 r
F P
0 g
s
.70883 .67964 m .7021 .73554 L .69967 .72822 L p .707 .577 .707 r
F P
0 g
s
.69967 .72822 m .7064 .67233 L .70883 .67964 L p .707 .577 .707 r
F P
0 g
s
.50834 .71587 m .49733 .75231 L .49938 .7577 L p .707 .577 .707 r
F P
0 g
s
.49981 .70873 m .50654 .65284 L .51401 .64684 L p .707 .577 .707 r
F P
0 g
s
.50847 .77526 m .50281 .79345 L .50544 .79882 L p .707 .577 .707 r
F P
0 g
s
.51401 .64684 m .50728 .70273 L .49981 .70873 L p .707 .577 .707 r
F P
0 g
s
.49733 .75231 m .50834 .71587 L .51584 .71344 L p .707 .577 .707 r
F P
0 g
s
.51584 .71344 m .50483 .74988 L .49733 .75231 L p .707 .577 .707 r
F P
0 g
s
.50544 .79882 m .5111 .78062 L .50847 .77526 L p .707 .577 .707 r
F P
0 g
s
.50281 .79345 m .50847 .77526 L .51537 .7729 L p .707 .577 .707 r
F P
0 g
s
.51537 .7729 m .50971 .7911 L .50281 .79345 L p .707 .577 .707 r
F P
0 g
s
.50483 .74988 m .51584 .71344 L .53214 .71419 L p .707 .577 .707 r
F P
0 g
s
.53214 .71419 m .52113 .75063 L .50483 .74988 L p .707 .577 .707 r
F P
0 g
s
.50488 .8219 m .50488 .32001 L .4601 .31852 L p .707 .577 .707 r
F P
0 g
s
.50728 .70273 m .51401 .64684 L .53065 .64274 L p .707 .577 .707 r
F P
0 g
s
.53065 .64274 m .52392 .69863 L .50728 .70273 L p .707 .577 .707 r
F P
0 g
s
.52392 .69863 m .53065 .64274 L .55483 .64094 L p .707 .577 .707 r
F P
0 g
s
.50971 .7911 m .51537 .7729 L .53113 .77378 L p .707 .577 .707 r
F P
0 g
s
.53113 .77378 m .52547 .79197 L .50971 .7911 L p .707 .577 .707 r
F P
0 g
s
.55483 .64094 m .5481 .69683 L .52392 .69863 L p .707 .577 .707 r
F P
0 g
s
.52113 .75063 m .53214 .71419 L .55566 .71807 L p .707 .577 .707 r
F P
0 g
s
.55566 .71807 m .54465 .75451 L .52113 .75063 L p .707 .577 .707 r
F P
0 g
s
.52547 .79197 m .53113 .77378 L .55421 .77781 L p .707 .577 .707 r
F P
0 g
s
.55421 .77781 m .54855 .796 L .52547 .79197 L p .707 .577 .707 r
F P
0 g
s
.50488 .32001 m .50488 .8219 L .54919 .8196 L p .707 .577 .707 r
F P
0 g
s
.5481 .69683 m .55483 .64094 L .58419 .64162 L p .707 .577 .707 r
F P
0 g
s
.58419 .64162 m .57745 .69751 L .5481 .69683 L p .707 .577 .707 r
F P
0 g
s
.54465 .75451 m .55566 .71807 L .58409 .72468 L p .707 .577 .707 r
F P
0 g
s
.58409 .72468 m .57308 .76112 L .54465 .75451 L p .707 .577 .707 r
F P
0 g
s
.54855 .796 m .55421 .77781 L .58234 .78459 L p .707 .577 .707 r
F P
0 g
s
.58234 .78459 m .57669 .80278 L .54855 .796 L p .707 .577 .707 r
F P
0 g
s
.54919 .8196 m .54919 .31771 L .50488 .32001 L p .707 .577 .707 r
F P
0 g
s
.69639 .83902 m .69073 .85721 L .69763 .85485 L p .707 .577 .707 r
F P
0 g
s
.69763 .85485 m .70329 .83666 L .69639 .83902 L p .707 .577 .707 r
F P
0 g
s
.4601 .82041 m .4601 .31852 L .41921 .3134 L p .707 .577 .707 r
F P
0 g
s
.4601 .31852 m .4601 .82041 L .50488 .8219 L p .707 .577 .707 r
F P
0 g
s
.57745 .69751 m .58419 .64162 L .61584 .64471 L p .707 .577 .707 r
F P
0 g
s
.61584 .64471 m .60911 .7006 L .57745 .69751 L p .707 .577 .707 r
F P
0 g
s
.57308 .76112 m .58409 .72468 L .61466 .73339 L p .707 .577 .707 r
F P
0 g
s
.61466 .73339 m .60365 .76982 L .57308 .76112 L p .707 .577 .707 r
F P
0 g
s
.57669 .80278 m .58234 .78459 L .61278 .79347 L p .707 .577 .707 r
F P
0 g
s
.61278 .79347 m .60713 .81166 L .57669 .80278 L p .707 .577 .707 r
F P
0 g
s
.54919 .31771 m .54919 .8196 L .58869 .81374 L p .707 .577 .707 r
F P
0 g
s
.58869 .81374 m .58869 .31185 L .54919 .31771 L p .707 .577 .707 r
F P
0 g
s
.70334 .77623 m .69233 .81267 L .69029 .80727 L p .707 .577 .707 r
F P
0 g
s
.69029 .80727 m .7013 .77084 L .70334 .77623 L p .707 .577 .707 r
F P
0 g
s
.41921 .81528 m .41921 .3134 L .38624 .30513 L p .707 .577 .707 r
F P
0 g
s
.41921 .3134 m .41921 .81528 L .4601 .82041 L p .707 .577 .707 r
F P
0 g
s
.7064 .67233 m .69967 .72822 L .68758 .72032 L p .707 .577 .707 r
F P
0 g
s
.68758 .72032 m .69431 .66443 L .7064 .67233 L p .707 .577 .707 r
F P
0 g
s
.6467 .6499 m .63997 .70579 L .60911 .7006 L p .707 .577 .707 r
F P
0 g
s
.60911 .7006 m .61584 .64471 L .6467 .6499 L p .707 .577 .707 r
F P
0 g
s
.64435 .74333 m .63334 .77977 L .60365 .76982 L p .707 .577 .707 r
F P
0 g
s
.60365 .76982 m .61466 .73339 L .64435 .74333 L p .707 .577 .707 r
F P
0 g
s
.60713 .81166 m .61278 .79347 L .64255 .80356 L p .707 .577 .707 r
F P
0 g
s
.58869 .31185 m .58869 .81374 L .6195 .80489 L p .707 .577 .707 r
F P
0 g
s
.6195 .80489 m .6195 .30301 L .58869 .31185 L p .707 .577 .707 r
F P
0 g
s
.2511 .72293 m .25398 .66963 L .22293 .66536 L p .707 .577 .707 r
F P
0 g
s
.25398 .66963 m .2511 .72293 L .28292 .72344 L p .707 .577 .707 r
F P
0 g
s
.28292 .72344 m .28581 .67015 L .25398 .66963 L p .707 .577 .707 r
F P
0 g
s
.28581 .67015 m .28292 .72344 L .31242 .72015 L p .707 .577 .707 r
F P
0 g
s
.31242 .72015 m .3153 .66685 L .28581 .67015 L p .707 .577 .707 r
F P
0 g
s
.70329 .83666 m .69763 .85485 L .695 .84949 L p .707 .577 .707 r
F P
0 g
s
.695 .84949 m .70065 .8313 L .70329 .83666 L p .707 .577 .707 r
F P
0 g
s
.22005 .71866 m .22293 .66536 L .1957 .65776 L p .707 .577 .707 r
F P
0 g
s
.22293 .66536 m .22005 .71866 L .2511 .72293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3153 .66685 m .31242 .72015 L .33668 .71337 L p .707 .577 .707 r
F P
0 g
s
.33668 .71337 m .33957 .66008 L .3153 .66685 L p .707 .577 .707 r
F P
0 g
s
.7013 .77084 m .69029 .80727 L .67889 .79946 L p .707 .577 .707 r
F P
0 g
s
.67889 .79946 m .6899 .76302 L .7013 .77084 L p .707 .577 .707 r
F P
0 g
s
.19282 .71105 m .1957 .65776 L .17496 .64756 L p .707 .577 .707 r
F P
0 g
s
.1957 .65776 m .19282 .71105 L .22005 .71866 L p .707 .577 .707 r
F P
0 g
s
.69431 .66443 m .68758 .72032 L .667 .71259 L p .707 .577 .707 r
F P
0 g
s
.667 .71259 m .67374 .6567 L .69431 .66443 L p .707 .577 .707 r
F P
0 g
s
.38624 .80702 m .38624 .30513 L .3644 .29453 L p .707 .577 .707 r
F P
0 g
s
.38624 .30513 m .38624 .80702 L .41921 .81528 L p .707 .577 .707 r
F P
0 g
s
.67028 .75354 m .65927 .78998 L .63334 .77977 L p .707 .577 .707 r
F P
0 g
s
.63334 .77977 m .64435 .74333 L .67028 .75354 L p .707 .577 .707 r
F P
0 g
s
.6195 .30301 m .6195 .80489 L .63862 .79393 L p .707 .577 .707 r
F P
0 g
s
.63862 .79393 m .63861 .29204 L .6195 .30301 L p .707 .577 .707 r
F P
0 g
s
.24874 .79639 m .25355 .76417 L .22268 .75694 L p .707 .577 .707 r
F P
0 g
s
.25355 .76417 m .24874 .79639 L .28035 .79835 L p .707 .577 .707 r
F P
0 g
s
.28035 .79835 m .28516 .76613 L .25355 .76417 L p .707 .577 .707 r
F P
0 g
s
.33957 .66008 m .33668 .71337 L .35335 .70378 L p .707 .577 .707 r
F P
0 g
s
.35335 .70378 m .35624 .65048 L .33957 .66008 L p .707 .577 .707 r
F P
0 g
s
.70065 .8313 m .695 .84949 L .68309 .84164 L p .707 .577 .707 r
F P
0 g
s
.68309 .84164 m .68874 .82345 L .70065 .8313 L p .707 .577 .707 r
F P
0 g
s
.21788 .78916 m .22268 .75694 L .19559 .74515 L p .707 .577 .707 r
F P
0 g
s
.22268 .75694 m .21788 .78916 L .24874 .79639 L p .707 .577 .707 r
F P
0 g
s
.28516 .76613 m .28035 .79835 L .30962 .79485 L p .707 .577 .707 r
F P
0 g
s
.30962 .79485 m .31442 .76264 L .28516 .76613 L p .707 .577 .707 r
F P
0 g
s
.17496 .64756 m .17207 .70085 L .19282 .71105 L p .707 .577 .707 r
F P
0 g
s
.17207 .70085 m .17496 .64756 L .16273 .63576 L p .707 .577 .707 r
F P
0 g
s
.6899 .76302 m .67889 .79946 L .65927 .78998 L p .707 .577 .707 r
F P
0 g
s
.65927 .78998 m .67028 .75354 L .6899 .76302 L p .707 .577 .707 r
F P
0 g
s
.67374 .6567 m .667 .71259 L .63997 .70579 L p .707 .577 .707 r
F P
0 g
s
.63997 .70579 m .6467 .6499 L .67374 .6567 L p .707 .577 .707 r
F P
0 g
s
.19079 .77737 m .19559 .74515 L .17492 .72996 L p .707 .577 .707 r
F P
0 g
s
.19559 .74515 m .19079 .77737 L .21788 .78916 L p .707 .577 .707 r
F P
0 g
s
.31442 .76264 m .30962 .79485 L .33368 .78624 L p .707 .577 .707 r
F P
0 g
s
.33368 .78624 m .33848 .75402 L .31442 .76264 L p .707 .577 .707 r
F P
0 g
s
.25302 .84062 m .25551 .82454 L .22453 .8175 L p .707 .577 .707 r
F P
0 g
s
.25551 .82454 m .25302 .84062 L .28456 .84235 L p .707 .577 .707 r
F P
0 g
s
.28456 .84235 m .28705 .82628 L .25551 .82454 L p .707 .577 .707 r
F P
0 g
s
.22204 .83357 m .22453 .8175 L .19714 .80582 L p .707 .577 .707 r
F P
0 g
s
.22453 .8175 m .22204 .83357 L .25302 .84062 L p .707 .577 .707 r
F P
0 g
s
.28705 .82628 m .28456 .84235 L .31357 .8386 L p .707 .577 .707 r
F P
0 g
s
.31357 .8386 m .31606 .82253 L .28705 .82628 L p .707 .577 .707 r
F P
0 g
s
.35624 .65048 m .35335 .70378 L .36079 .6923 L p .707 .577 .707 r
F P
0 g
s
.36079 .6923 m .36368 .639 L .35624 .65048 L p .707 .577 .707 r
F P
0 g
s
.36368 .639 m .36079 .6923 L .35828 .68007 L p .707 .577 .707 r
F P
0 g
s
.35828 .68007 m .36116 .62677 L .36368 .639 L p .707 .577 .707 r
F P
0 g
s
.3644 .79642 m .3644 .29453 L .35584 .28264 L p .707 .577 .707 r
F P
0 g
s
.3644 .29453 m .3644 .79642 L .38624 .80702 L p .707 .577 .707 r
F P
0 g
s
.19714 .80582 m .19465 .8219 L .22204 .83357 L p .707 .577 .707 r
F P
0 g
s
.19465 .8219 m .19714 .80582 L .17602 .79067 L p .707 .577 .707 r
F P
0 g
s
.68874 .82345 m .68309 .84164 L .66306 .83209 L p .707 .577 .707 r
F P
0 g
s
.66306 .83209 m .66872 .8139 L .68874 .82345 L p .707 .577 .707 r
F P
0 g
s
.16273 .63576 m .15984 .68906 L .17207 .70085 L p .707 .577 .707 r
F P
0 g
s
.31606 .82253 m .31357 .8386 L .3372 .82974 L p .707 .577 .707 r
F P
0 g
s
.3372 .82974 m .33969 .81366 L .31606 .82253 L p .707 .577 .707 r
F P
0 g
s
.17012 .76217 m .17492 .72996 L .16269 .71285 L p .707 .577 .707 r
F P
0 g
s
.17492 .72996 m .17012 .76217 L .19079 .77737 L p .707 .577 .707 r
F P
0 g
s
.33848 .75402 m .33368 .78624 L .35017 .77335 L p .707 .577 .707 r
F P
0 g
s
.35017 .77335 m .35497 .74114 L .33848 .75402 L p .707 .577 .707 r
F P
0 g
s
.63861 .29204 m .63862 .79393 L .64416 .78191 L p .707 .577 .707 r
F P
0 g
s
.64416 .78191 m .64416 .28002 L .63861 .29204 L p .707 .577 .707 r
F P
0 g
s
.15984 .68906 m .16273 .63576 L .16021 .62353 L p .707 .577 .707 r
F P
0 g
s
.17602 .79067 m .17353 .80675 L .19465 .8219 L p .707 .577 .707 r
F P
0 g
s
.17353 .80675 m .17602 .79067 L .16324 .77352 L p .707 .577 .707 r
F P
0 g
s
.33969 .81366 m .3372 .82974 L .35316 .81662 L p .707 .577 .707 r
F P
0 g
s
.35316 .81662 m .35565 .80055 L .33969 .81366 L p .707 .577 .707 r
F P
0 g
s
.66872 .8139 m .66306 .83209 L .63689 .82176 L p .707 .577 .707 r
F P
0 g
s
.63689 .82176 m .64255 .80356 L .66872 .8139 L p .707 .577 .707 r
F P
0 g
s
.16269 .71285 m .15789 .74506 L .17012 .76217 L p .707 .577 .707 r
F P
0 g
s
.15789 .74506 m .16269 .71285 L .16011 .69549 L p .707 .577 .707 r
F P
0 g
s
.35497 .74114 m .35017 .77335 L .35748 .75745 L p .707 .577 .707 r
F P
0 g
s
.35748 .75745 m .36228 .72524 L .35497 .74114 L p .707 .577 .707 r
F P
0 g
s
.16021 .62353 m .15732 .67682 L .15984 .68906 L p .707 .577 .707 r
F P
0 g
s
.16324 .77352 m .16075 .7896 L .17353 .80675 L p .707 .577 .707 r
F P
0 g
s
.15732 .67682 m .16021 .62353 L .16765 .61205 L p .707 .577 .707 r
F P
0 g
s
.64255 .80356 m .63689 .82176 L .60713 .81166 L p .707 .577 .707 r
F P
0 g
s
.35987 .80054 m .36235 .78447 L .35565 .80055 L p .707 .577 .707 r
F P
0 g
s
.36116 .62677 m .35828 .68007 L .34604 .66827 L p .707 .577 .707 r
F P
0 g
s
.34604 .66827 m .34893 .61498 L .36116 .62677 L p .707 .577 .707 r
F P
0 g
s
.36228 .72524 m .35748 .75745 L .35489 .7401 L p .707 .577 .707 r
F P
0 g
s
.35489 .7401 m .3597 .70788 L .36228 .72524 L p .707 .577 .707 r
F P
0 g
s
.36235 .78447 m .35987 .80054 L .35667 .78307 L p .707 .577 .707 r
F P
0 g
s
.35667 .78307 m .35916 .767 L .36235 .78447 L p .707 .577 .707 r
F P
0 g
s
.3597 .70788 m .35489 .7401 L .34267 .72299 L p .707 .577 .707 r
F P
0 g
s
.34267 .72299 m .34747 .69077 L .3597 .70788 L p .707 .577 .707 r
F P
0 g
s
.35916 .767 m .35667 .78307 L .34389 .76592 L p .707 .577 .707 r
F P
0 g
s
.34389 .76592 m .34638 .74985 L .35916 .767 L p .707 .577 .707 r
F P
0 g
s
.35584 .28264 m .35584 .78453 L .3644 .79642 L p .707 .577 .707 r
F P
0 g
s
.35584 .78453 m .35584 .28264 L .36138 .27062 L p .707 .577 .707 r
F P
0 g
s
.16075 .7896 m .16324 .77352 L .16004 .75605 L p .707 .577 .707 r
F P
0 g
s
.35565 .80055 m .35316 .81662 L .35987 .80054 L p .707 .577 .707 r
F P
0 g
s
.16011 .69549 m .15531 .72771 L .15789 .74506 L p .707 .577 .707 r
F P
0 g
s
.64416 .28002 m .64416 .78191 L .6356 .77002 L p .707 .577 .707 r
F P
0 g
s
.6356 .77002 m .6356 .26813 L .64416 .28002 L p .707 .577 .707 r
F P
0 g
s
.16004 .75605 m .15756 .77213 L .16075 .7896 L p .707 .577 .707 r
F P
0 g
s
.15531 .72771 m .16011 .69549 L .16742 .67959 L p .707 .577 .707 r
F P
0 g
s
.16765 .61205 m .16476 .66535 L .15732 .67682 L p .707 .577 .707 r
F P
0 g
s
.16476 .66535 m .16765 .61205 L .18432 .60245 L p .707 .577 .707 r
F P
0 g
s
.15756 .77213 m .16004 .75605 L .16675 .73997 L p .707 .577 .707 r
F P
0 g
s
.16742 .67959 m .16262 .71181 L .15531 .72771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16675 .73997 m .16426 .75605 L .15756 .77213 L p .707 .577 .707 r
F P
0 g
s
.16262 .71181 m .16742 .67959 L .18391 .6667 L p .707 .577 .707 r
F P
0 g
s
.34893 .61498 m .34604 .66827 L .3253 .65807 L p .707 .577 .707 r
F P
0 g
s
.3253 .65807 m .32818 .60478 L .34893 .61498 L p .707 .577 .707 r
F P
0 g
s
.36138 .77251 m .36138 .27062 L .3805 .25965 L p .707 .577 .707 r
F P
0 g
s
.36138 .27062 m .36138 .77251 L .35584 .78453 L p .707 .577 .707 r
F P
0 g
s
.18432 .60245 m .18143 .65575 L .16476 .66535 L p .707 .577 .707 r
F P
0 g
s
.18143 .65575 m .18432 .60245 L .20859 .59568 L p .707 .577 .707 r
F P
0 g
s
.6356 .26813 m .6356 .77002 L .61376 .75942 L p .707 .577 .707 r
F P
0 g
s
.61376 .75942 m .61376 .25753 L .6356 .26813 L p .707 .577 .707 r
F P
0 g
s
.16426 .75605 m .16675 .73997 L .18271 .72686 L p .707 .577 .707 r
F P
0 g
s
.18391 .6667 m .17911 .69892 L .16262 .71181 L p .707 .577 .707 r
F P
0 g
s
.32818 .60478 m .3253 .65807 L .29807 .65047 L p .707 .577 .707 r
F P
0 g
s
.29807 .65047 m .30095 .59717 L .32818 .60478 L p .707 .577 .707 r
F P
0 g
s
.17911 .69892 m .18391 .6667 L .20797 .65809 L p .707 .577 .707 r
F P
0 g
s
.34747 .69077 m .34267 .72299 L .322 .70779 L p .707 .577 .707 r
F P
0 g
s
.322 .70779 m .3268 .67558 L .34747 .69077 L p .707 .577 .707 r
F P
0 g
s
.18271 .72686 m .18022 .74293 L .16426 .75605 L p .707 .577 .707 r
F P
0 g
s
.2057 .64898 m .20859 .59568 L .23808 .59239 L p .707 .577 .707 r
F P
0 g
s
.20859 .59568 m .2057 .64898 L .18143 .65575 L p .707 .577 .707 r
F P
0 g
s
.30095 .59717 m .29807 .65047 L .26702 .6462 L p .707 .577 .707 r
F P
0 g
s
.26702 .6462 m .2699 .5929 L .30095 .59717 L p .707 .577 .707 r
F P
0 g
s
.18022 .74293 m .18271 .72686 L .20634 .71799 L p .707 .577 .707 r
F P
0 g
s
.23519 .64568 m .23808 .59239 L .2699 .5929 L p .707 .577 .707 r
F P
0 g
s
.23808 .59239 m .23519 .64568 L .2057 .64898 L p .707 .577 .707 r
F P
0 g
s
.3805 .25965 m .3805 .76154 L .36138 .77251 L p .707 .577 .707 r
F P
0 g
s
.3805 .76154 m .3805 .25965 L .41131 .2508 L p .707 .577 .707 r
F P
0 g
s
.34638 .74985 m .34389 .76592 L .32277 .75077 L p .707 .577 .707 r
F P
0 g
s
.32277 .75077 m .32526 .7347 L .34638 .74985 L p .707 .577 .707 r
F P
0 g
s
.20316 .69031 m .20797 .65809 L .23723 .6546 L p .707 .577 .707 r
F P
0 g
s
.20797 .65809 m .20316 .69031 L .17911 .69892 L p .707 .577 .707 r
F P
0 g
s
.3268 .67558 m .322 .70779 L .2949 .696 L p .707 .577 .707 r
F P
0 g
s
.2949 .696 m .29971 .66379 L .3268 .67558 L p .707 .577 .707 r
F P
0 g
s
.2699 .5929 m .26702 .6462 L .23519 .64568 L p .707 .577 .707 r
F P
0 g
s
.61376 .25753 m .61376 .75942 L .58078 .75115 L p .707 .577 .707 r
F P
0 g
s
.58078 .75115 m .58078 .24926 L .61376 .25753 L p .707 .577 .707 r
F P
0 g
s
.20634 .71799 m .20386 .73407 L .18022 .74293 L p .707 .577 .707 r
F P
0 g
s
.23243 .68681 m .23723 .6546 L .26884 .65656 L p .707 .577 .707 r
F P
0 g
s
.23723 .6546 m .23243 .68681 L .20316 .69031 L p .707 .577 .707 r
F P
0 g
s
.29971 .66379 m .2949 .696 L .26404 .68877 L p .707 .577 .707 r
F P
0 g
s
.26404 .68877 m .26884 .65656 L .29971 .66379 L p .707 .577 .707 r
F P
0 g
s
.73298 .64635 m .73009 .5894 L .69905 .58979 L p .707 .577 .707 r
F P
0 g
s
.73009 .5894 m .73298 .64635 L .7648 .64439 L p .707 .577 .707 r
F P
0 g
s
.7648 .64439 m .76192 .58744 L .73009 .5894 L p .707 .577 .707 r
F P
0 g
s
.76192 .58744 m .7648 .64439 L .79429 .64106 L p .707 .577 .707 r
F P
0 g
s
.79429 .64106 m .79141 .58411 L .76192 .58744 L p .707 .577 .707 r
F P
0 g
s
.20386 .73407 m .20634 .71799 L .23535 .71425 L p .707 .577 .707 r
F P
0 g
s
.26884 .65656 m .26404 .68877 L .23243 .68681 L p .707 .577 .707 r
F P
0 g
s
.32526 .7347 m .32277 .75077 L .29538 .7391 L p .707 .577 .707 r
F P
0 g
s
.29538 .7391 m .29787 .72303 L .32526 .7347 L p .707 .577 .707 r
F P
0 g
s
.70193 .64674 m .69905 .58979 L .67182 .58859 L p .707 .577 .707 r
F P
0 g
s
.69905 .58979 m .70193 .64674 L .73298 .64635 L p .707 .577 .707 r
F P
0 g
s
.23535 .71425 m .23286 .73032 L .20386 .73407 L p .707 .577 .707 r
F P
0 g
s
.79141 .58411 m .79429 .64106 L .81856 .63669 L p .707 .577 .707 r
F P
0 g
s
.81856 .63669 m .81568 .57974 L .79141 .58411 L p .707 .577 .707 r
F P
0 g
s
.23286 .73032 m .23535 .71425 L .26689 .71598 L p .707 .577 .707 r
F P
0 g
s
.67182 .58859 m .6747 .64554 L .70193 .64674 L p .707 .577 .707 r
F P
0 g
s
.29787 .72303 m .29538 .7391 L .2644 .73205 L p .707 .577 .707 r
F P
0 g
s
.2644 .73205 m .26689 .71598 L .29787 .72303 L p .707 .577 .707 r
F P
0 g
s
.41131 .75269 m .41131 .2508 L .4508 .24494 L p .707 .577 .707 r
F P
0 g
s
.41131 .2508 m .41131 .75269 L .3805 .76154 L p .707 .577 .707 r
F P
0 g
s
.70029 .65627 m .7051 .69442 L .73596 .69037 L p .707 .577 .707 r
F P
0 g
s
.73596 .69037 m .73115 .65222 L .70029 .65627 L p .707 .577 .707 r
F P
0 g
s
.73115 .65222 m .73596 .69037 L .76757 .68645 L p .707 .577 .707 r
F P
0 g
s
.76757 .68645 m .76277 .6483 L .73115 .65222 L p .707 .577 .707 r
F P
0 g
s
.26689 .71598 m .2644 .73205 L .23286 .73032 L p .707 .577 .707 r
F P
0 g
s
.76277 .6483 m .76757 .68645 L .79683 .68305 L p .707 .577 .707 r
F P
0 g
s
.79683 .68305 m .79203 .64489 L .76277 .6483 L p .707 .577 .707 r
F P
0 g
s
.58078 .24926 m .58078 .75115 L .5399 .74602 L p .707 .577 .707 r
F P
0 g
s
.5399 .74602 m .5399 .24413 L .58078 .24926 L p .707 .577 .707 r
F P
0 g
s
.6747 .64554 m .67182 .58859 L .65107 .58591 L p .707 .577 .707 r
F P
0 g
s
.6732 .66005 m .678 .69821 L .7051 .69442 L p .707 .577 .707 r
F P
0 g
s
.7051 .69442 m .70029 .65627 L .6732 .66005 L p .707 .577 .707 r
F P
0 g
s
.65107 .58591 m .65395 .64286 L .6747 .64554 L p .707 .577 .707 r
F P
0 g
s
.79203 .64489 m .79683 .68305 L .82089 .68049 L p .707 .577 .707 r
F P
0 g
s
.82089 .68049 m .81609 .64234 L .79203 .64489 L p .707 .577 .707 r
F P
0 g
s
.81568 .57974 m .81856 .63669 L .83523 .63171 L p .707 .577 .707 r
F P
0 g
s
.83523 .63171 m .83235 .57475 L .81568 .57974 L p .707 .577 .707 r
F P
0 g
s
.70213 .71586 m .70462 .73493 L .7356 .73072 L p .707 .577 .707 r
F P
0 g
s
.7356 .73072 m .73311 .71165 L .70213 .71586 L p .707 .577 .707 r
F P
0 g
s
.73311 .71165 m .7356 .73072 L .76714 .72668 L p .707 .577 .707 r
F P
0 g
s
.76714 .72668 m .76465 .70762 L .73311 .71165 L p .707 .577 .707 r
F P
0 g
s
.4508 .74683 m .4508 .24494 L .49511 .24265 L p .707 .577 .707 r
F P
0 g
s
.4508 .24494 m .4508 .74683 L .41131 .75269 L p .707 .577 .707 r
F P
0 g
s
.76465 .70762 m .76714 .72668 L .79614 .72322 L p .707 .577 .707 r
F P
0 g
s
.79614 .72322 m .79365 .70416 L .76465 .70762 L p .707 .577 .707 r
F P
0 g
s
.5399 .24413 m .5399 .74602 L .49511 .74454 L p .707 .577 .707 r
F P
0 g
s
.49511 .74454 m .49511 .24265 L .5399 .24413 L p .707 .577 .707 r
F P
0 g
s
.67474 .71984 m .67723 .7389 L .70462 .73493 L p .707 .577 .707 r
F P
0 g
s
.70462 .73493 m .70213 .71586 L .67474 .71984 L p .707 .577 .707 r
F P
0 g
s
.65253 .6632 m .65733 .70135 L .678 .69821 L p .707 .577 .707 r
F P
0 g
s
.678 .69821 m .6732 .66005 L .65253 .6632 L p .707 .577 .707 r
F P
0 g
s
.49511 .24265 m .49511 .74454 L .4508 .74683 L p .707 .577 .707 r
F P
0 g
s
.65395 .64286 m .65107 .58591 L .63884 .58201 L p .707 .577 .707 r
F P
0 g
s
.79365 .70416 m .79614 .72322 L .81978 .72067 L p .707 .577 .707 r
F P
0 g
s
.81978 .72067 m .81729 .70161 L .79365 .70416 L p .707 .577 .707 r
F P
0 g
s
.81609 .64234 m .82089 .68049 L .83738 .67903 L p .707 .577 .707 r
F P
0 g
s
.83738 .67903 m .83258 .64087 L .81609 .64234 L p .707 .577 .707 r
F P
0 g
s
.63884 .58201 m .64172 .63896 L .65395 .64286 L p .707 .577 .707 r
F P
0 g
s
.65362 .72319 m .65611 .74225 L .67723 .7389 L p .707 .577 .707 r
F P
0 g
s
.67723 .7389 m .67474 .71984 L .65362 .72319 L p .707 .577 .707 r
F P
0 g
s
.83235 .57475 m .83523 .63171 L .84267 .62659 L p .707 .577 .707 r
F P
0 g
s
.84267 .62659 m .83979 .56964 L .83235 .57475 L p .707 .577 .707 r
F P
0 g
s
.6403 .6654 m .64511 .70355 L .65733 .70135 L p .707 .577 .707 r
F P
0 g
s
.65733 .70135 m .65253 .6632 L .6403 .6654 L p .707 .577 .707 r
F P
0 g
s
.81729 .70161 m .81978 .72067 L .83573 .71929 L p .707 .577 .707 r
F P
0 g
s
.83573 .71929 m .83325 .70022 L .81729 .70161 L p .707 .577 .707 r
F P
0 g
s
.64172 .63896 m .63884 .58201 L .63632 .57727 L p .707 .577 .707 r
F P
0 g
s
.64084 .72559 m .64332 .74465 L .65611 .74225 L p .707 .577 .707 r
F P
0 g
s
.65611 .74225 m .65362 .72319 L .64084 .72559 L p .707 .577 .707 r
F P
0 g
s
.83258 .64087 m .83738 .67903 L .84469 .67881 L p .707 .577 .707 r
F P
0 g
s
.84469 .67881 m .83989 .64065 L .83258 .64087 L p .707 .577 .707 r
F P
0 g
s
.63632 .57727 m .6392 .63422 L .64172 .63896 L p .707 .577 .707 r
F P
0 g
s
.83979 .56964 m .84267 .62659 L .84016 .62185 L p .707 .577 .707 r
F P
0 g
s
.84016 .62185 m .83727 .5649 L .83979 .56964 L p .707 .577 .707 r
F P
0 g
s
.63772 .66644 m .64252 .7046 L .64511 .70355 L p .707 .577 .707 r
F P
0 g
s
.64511 .70355 m .6403 .6654 L .63772 .66644 L p .707 .577 .707 r
F P
0 g
s
.83325 .70022 m .83573 .71929 L .84244 .71919 L p .707 .577 .707 r
F P
0 g
s
.84244 .71919 m .83995 .70013 L .83325 .70022 L p .707 .577 .707 r
F P
0 g
s
.6392 .63422 m .63632 .57727 L .64376 .57215 L p .707 .577 .707 r
F P
0 g
s
.63764 .7268 m .64013 .74586 L .64332 .74465 L p .707 .577 .707 r
F P
0 g
s
.64332 .74465 m .64084 .72559 L .63764 .7268 L p .707 .577 .707 r
F P
0 g
s
.83989 .64065 m .84469 .67881 L .84211 .67985 L p .707 .577 .707 r
F P
0 g
s
.84211 .67985 m .8373 .6417 L .83989 .64065 L p .707 .577 .707 r
F P
0 g
s
.64376 .57215 m .64664 .62911 L .6392 .63422 L p .707 .577 .707 r
F P
0 g
s
.83727 .5649 m .84016 .62185 L .82792 .61795 L p .707 .577 .707 r
F P
0 g
s
.82792 .61795 m .82504 .561 L .83727 .5649 L p .707 .577 .707 r
F P
0 g
s
.64503 .66622 m .64983 .70438 L .64252 .7046 L p .707 .577 .707 r
F P
0 g
s
.64252 .7046 m .63772 .66644 L .64503 .66622 L p .707 .577 .707 r
F P
0 g
s
.39089 .62588 m .38416 .5715 L .3533 .57257 L p .707 .577 .707 r
F P
0 g
s
.38416 .5715 m .39089 .62588 L .42254 .62158 L p .707 .577 .707 r
F P
0 g
s
.42254 .62158 m .41581 .5672 L .38416 .5715 L p .707 .577 .707 r
F P
0 g
s
.41581 .5672 m .42254 .62158 L .4519 .61446 L p .707 .577 .707 r
F P
0 g
s
.4519 .61446 m .44517 .56008 L .41581 .5672 L p .707 .577 .707 r
F P
0 g
s
.83995 .70013 m .84244 .71919 L .83925 .72041 L p .707 .577 .707 r
F P
0 g
s
.83925 .72041 m .83676 .70134 L .83995 .70013 L p .707 .577 .707 r
F P
0 g
s
.36003 .62695 m .3533 .57257 L .32626 .5703 L p .707 .577 .707 r
F P
0 g
s
.3533 .57257 m .36003 .62695 L .39089 .62588 L p .707 .577 .707 r
F P
0 g
s
.64664 .62911 m .64376 .57215 L .66043 .56717 L p .707 .577 .707 r
F P
0 g
s
.44517 .56008 m .4519 .61446 L .47608 .60523 L p .707 .577 .707 r
F P
0 g
s
.47608 .60523 m .46935 .55085 L .44517 .56008 L p .707 .577 .707 r
F P
0 g
s
.64435 .72671 m .64684 .74577 L .64013 .74586 L p .707 .577 .707 r
F P
0 g
s
.64013 .74586 m .63764 .7268 L .64435 .72671 L p .707 .577 .707 r
F P
0 g
s
.8373 .6417 m .84211 .67985 L .82988 .68205 L p .707 .577 .707 r
F P
0 g
s
.82988 .68205 m .82508 .6439 L .8373 .6417 L p .707 .577 .707 r
F P
0 g
s
.66043 .56717 m .66331 .62412 L .64664 .62911 L p .707 .577 .707 r
F P
0 g
s
.82504 .561 m .82792 .61795 L .80718 .61527 L p .707 .577 .707 r
F P
0 g
s
.80718 .61527 m .8043 .55832 L .82504 .561 L p .707 .577 .707 r
F P
0 g
s
.42691 .68397 m .4159 .64992 L .38534 .65917 L p .707 .577 .707 r
F P
0 g
s
.4159 .64992 m .42691 .68397 L .45534 .67158 L p .707 .577 .707 r
F P
0 g
s
.45534 .67158 m .44434 .63753 L .4159 .64992 L p .707 .577 .707 r
F P
0 g
s
.33299 .62468 m .32626 .5703 L .30569 .56491 L p .707 .577 .707 r
F P
0 g
s
.32626 .5703 m .33299 .62468 L .36003 .62695 L p .707 .577 .707 r
F P
0 g
s
.39635 .69323 m .38534 .65917 L .35564 .66438 L p .707 .577 .707 r
F P
0 g
s
.38534 .65917 m .39635 .69323 L .42691 .68397 L p .707 .577 .707 r
F P
0 g
s
.66152 .66476 m .66632 .70291 L .64983 .70438 L p .707 .577 .707 r
F P
0 g
s
.64983 .70438 m .64503 .66622 L .66152 .66476 L p .707 .577 .707 r
F P
0 g
s
.46935 .55085 m .47608 .60523 L .49272 .59479 L p .707 .577 .707 r
F P
0 g
s
.49272 .59479 m .48599 .54041 L .46935 .55085 L p .707 .577 .707 r
F P
0 g
s
.44434 .63753 m .45534 .67158 L .47887 .65725 L p .707 .577 .707 r
F P
0 g
s
.47887 .65725 m .46786 .6232 L .44434 .63753 L p .707 .577 .707 r
F P
0 g
s
.83676 .70134 m .83925 .72041 L .82647 .72281 L p .707 .577 .707 r
F P
0 g
s
.82647 .72281 m .82398 .70374 L .83676 .70134 L p .707 .577 .707 r
F P
0 g
s
.66331 .62412 m .66043 .56717 L .6847 .5628 L p .707 .577 .707 r
F P
0 g
s
.36665 .69843 m .35564 .66438 L .32971 .66502 L p .707 .577 .707 r
F P
0 g
s
.35564 .66438 m .36665 .69843 L .39635 .69323 L p .707 .577 .707 r
F P
0 g
s
.42331 .72661 m .41766 .70968 L .38722 .71938 L p .707 .577 .707 r
F P
0 g
s
.41766 .70968 m .42331 .72661 L .45145 .71379 L p .707 .577 .707 r
F P
0 g
s
.45145 .71379 m .44579 .69685 L .41766 .70968 L p .707 .577 .707 r
F P
0 g
s
.39287 .73631 m .38722 .71938 L .35745 .725 L p .707 .577 .707 r
F P
0 g
s
.38722 .71938 m .39287 .73631 L .42331 .72661 L p .707 .577 .707 r
F P
0 g
s
.30569 .56491 m .31242 .61929 L .33299 .62468 L p .707 .577 .707 r
F P
0 g
s
.66031 .72532 m .66279 .74438 L .64684 .74577 L p .707 .577 .707 r
F P
0 g
s
.64684 .74577 m .64435 .72671 L .66031 .72532 L p .707 .577 .707 r
F P
0 g
s
.82508 .6439 m .82988 .68205 L .80921 .6852 L p .707 .577 .707 r
F P
0 g
s
.80921 .6852 m .80441 .64704 L .82508 .6439 L p .707 .577 .707 r
F P
0 g
s
.6847 .5628 m .68758 .61975 L .66331 .62412 L p .707 .577 .707 r
F P
0 g
s
.8043 .55832 m .80718 .61527 L .77995 .61407 L p .707 .577 .707 r
F P
0 g
s
.77995 .61407 m .77707 .55712 L .8043 .55832 L p .707 .577 .707 r
F P
0 g
s
.46786 .6232 m .47887 .65725 L .49517 .64239 L p .707 .577 .707 r
F P
0 g
s
.49517 .64239 m .48416 .60834 L .46786 .6232 L p .707 .577 .707 r
F P
0 g
s
.31242 .61929 m .30569 .56491 L .29359 .55694 L p .707 .577 .707 r
F P
0 g
s
.44579 .69685 m .45145 .71379 L .47453 .6991 L p .707 .577 .707 r
F P
0 g
s
.47453 .6991 m .46887 .68216 L .44579 .69685 L p .707 .577 .707 r
F P
0 g
s
.35745 .725 m .36311 .74194 L .39287 .73631 L p .707 .577 .707 r
F P
0 g
s
.32971 .66502 m .34072 .69907 L .36665 .69843 L p .707 .577 .707 r
F P
0 g
s
.36311 .74194 m .35745 .725 L .33128 .72601 L p .707 .577 .707 r
F P
0 g
s
.48599 .54041 m .49272 .59479 L .50019 .58416 L p .707 .577 .707 r
F P
0 g
s
.50019 .58416 m .49346 .52978 L .48599 .54041 L p .707 .577 .707 r
F P
0 g
s
.34072 .69907 m .32971 .66502 L .31009 .66104 L p .707 .577 .707 r
F P
0 g
s
.68557 .6622 m .69038 .70036 L .66632 .70291 L p .707 .577 .707 r
F P
0 g
s
.66632 .70291 m .66152 .66476 L .68557 .6622 L p .707 .577 .707 r
F P
0 g
s
.68758 .61975 m .6847 .5628 L .71419 .55947 L p .707 .577 .707 r
F P
0 g
s
.33128 .72601 m .33693 .74294 L .36311 .74194 L p .707 .577 .707 r
F P
0 g
s
.82398 .70374 m .82647 .72281 L .80535 .72616 L p .707 .577 .707 r
F P
0 g
s
.80535 .72616 m .80286 .70709 L .82398 .70374 L p .707 .577 .707 r
F P
0 g
s
.77707 .55712 m .77995 .61407 L .7489 .61446 L p .707 .577 .707 r
F P
0 g
s
.7489 .61446 m .74602 .55751 L .77707 .55712 L p .707 .577 .707 r
F P
0 g
s
.71419 .55947 m .71707 .61642 L .68758 .61975 L p .707 .577 .707 r
F P
0 g
s
.46887 .68216 m .47453 .6991 L .49029 .68397 L p .707 .577 .707 r
F P
0 g
s
.49029 .68397 m .48463 .66704 L .46887 .68216 L p .707 .577 .707 r
F P
0 g
s
.29359 .55694 m .30033 .61132 L .31242 .61929 L p .707 .577 .707 r
F P
0 g
s
.80441 .64704 m .80921 .6852 L .78212 .68898 L p .707 .577 .707 r
F P
0 g
s
.71707 .61642 m .71419 .55947 L .74602 .55751 L p .707 .577 .707 r
F P
0 g
s
.78212 .68898 m .77731 .65083 L .80441 .64704 L p .707 .577 .707 r
F P
0 g
s
.31009 .66104 m .3211 .69509 L .34072 .69907 L p .707 .577 .707 r
F P
0 g
s
.74602 .55751 m .7489 .61446 L .71707 .61642 L p .707 .577 .707 r
F P
0 g
s
.33693 .74294 m .33128 .72601 L .31125 .72229 L p .707 .577 .707 r
F P
0 g
s
.68394 .72277 m .68643 .74183 L .66279 .74438 L p .707 .577 .707 r
F P
0 g
s
.66279 .74438 m .66031 .72532 L .68394 .72277 L p .707 .577 .707 r
F P
0 g
s
.48416 .60834 m .49517 .64239 L .50267 .62846 L p .707 .577 .707 r
F P
0 g
s
.50267 .62846 m .49166 .59441 L .48416 .60834 L p .707 .577 .707 r
F P
0 g
s
.71484 .6588 m .71964 .69695 L .69038 .70036 L p .707 .577 .707 r
F P
0 g
s
.69038 .70036 m .68557 .6622 L .71484 .6588 L p .707 .577 .707 r
F P
0 g
s
.30033 .61132 m .29359 .55694 L .29116 .54716 L p .707 .577 .707 r
F P
0 g
s
.31125 .72229 m .31691 .73923 L .33693 .74294 L p .707 .577 .707 r
F P
0 g
s
.3211 .69509 m .31009 .66104 L .2987 .65283 L p .707 .577 .707 r
F P
0 g
s
.49346 .52978 m .50019 .58416 L .49776 .57438 L p .707 .577 .707 r
F P
0 g
s
.49776 .57438 m .49103 .52 L .49346 .52978 L p .707 .577 .707 r
F P
0 g
s
.77731 .65083 m .78212 .68898 L .75126 .69303 L p .707 .577 .707 r
F P
0 g
s
.75126 .69303 m .74645 .65488 L .77731 .65083 L p .707 .577 .707 r
F P
0 g
s
.80286 .70709 m .80535 .72616 L .77796 .73013 L p .707 .577 .707 r
F P
0 g
s
.77796 .73013 m .77547 .71107 L .80286 .70709 L p .707 .577 .707 r
F P
0 g
s
.74645 .65488 m .75126 .69303 L .71964 .69695 L p .707 .577 .707 r
F P
0 g
s
.71964 .69695 m .71484 .6588 L .74645 .65488 L p .707 .577 .707 r
F P
0 g
s
.48463 .66704 m .49029 .68397 L .49719 .6699 L p .707 .577 .707 r
F P
0 g
s
.49719 .6699 m .49153 .65297 L .48463 .66704 L p .707 .577 .707 r
F P
0 g
s
.71295 .71931 m .71544 .73837 L .68643 .74183 L p .707 .577 .707 r
F P
0 g
s
.68643 .74183 m .68394 .72277 L .71295 .71931 L p .707 .577 .707 r
F P
0 g
s
.2987 .65283 m .30971 .68688 L .3211 .69509 L p .707 .577 .707 r
F P
0 g
s
.29116 .54716 m .2979 .60154 L .30033 .61132 L p .707 .577 .707 r
F P
0 g
s
.31691 .73923 m .31125 .72229 L .29934 .71422 L p .707 .577 .707 r
F P
0 g
s
.49166 .59441 m .50267 .62846 L .50062 .61682 L p .707 .577 .707 r
F P
0 g
s
.50062 .61682 m .48961 .58277 L .49166 .59441 L p .707 .577 .707 r
F P
0 g
s
.77547 .71107 m .77796 .73013 L .74698 .73434 L p .707 .577 .707 r
F P
0 g
s
.74698 .73434 m .74449 .71528 L .77547 .71107 L p .707 .577 .707 r
F P
0 g
s
.29934 .71422 m .305 .73115 L .31691 .73923 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74449 .71528 m .74698 .73434 L .71544 .73837 L p .707 .577 .707 r
F P
0 g
s
.71544 .73837 m .71295 .71931 L .74449 .71528 L p .707 .577 .707 r
F P
0 g
s
.2979 .60154 m .29116 .54716 L .29863 .53653 L p .707 .577 .707 r
F P
0 g
s
.30971 .68688 m .2987 .65283 L .29665 .64119 L p .707 .577 .707 r
F P
0 g
s
.49103 .52 m .49776 .57438 L .48567 .5664 L p .707 .577 .707 r
F P
0 g
s
.48567 .5664 m .47893 .51202 L .49103 .52 L p .707 .577 .707 r
F P
0 g
s
.49153 .65297 m .49719 .6699 L .49455 .65826 L p .707 .577 .707 r
F P
0 g
s
.49455 .65826 m .4889 .64132 L .49153 .65297 L p .707 .577 .707 r
F P
0 g
s
.29665 .64119 m .30766 .67524 L .30971 .68688 L p .707 .577 .707 r
F P
0 g
s
.305 .73115 m .29934 .71422 L .29671 .70257 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29863 .53653 m .30537 .59091 L .2979 .60154 L p .707 .577 .707 r
F P
0 g
s
.48961 .58277 m .50062 .61682 L .48923 .60861 L p .707 .577 .707 r
F P
0 g
s
.48923 .60861 m .47822 .57456 L .48961 .58277 L p .707 .577 .707 r
F P
0 g
s
.29671 .70257 m .30237 .71951 L .305 .73115 L p .707 .577 .707 r
F P
0 g
s
.30537 .59091 m .29863 .53653 L .31527 .52608 L p .707 .577 .707 r
F P
0 g
s
.30766 .67524 m .29665 .64119 L .30415 .62726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47893 .51202 m .48567 .5664 L .46509 .56102 L p .707 .577 .707 r
F P
0 g
s
.46509 .56102 m .45836 .50664 L .47893 .51202 L p .707 .577 .707 r
F P
0 g
s
.4889 .64132 m .49455 .65826 L .48264 .65018 L p .707 .577 .707 r
F P
0 g
s
.48264 .65018 m .47699 .63325 L .4889 .64132 L p .707 .577 .707 r
F P
0 g
s
.30415 .62726 m .31516 .66131 L .30766 .67524 L p .707 .577 .707 r
F P
0 g
s
.30237 .71951 m .29671 .70257 L .30361 .6885 L p .707 .577 .707 r
F P
0 g
s
.31527 .52608 m .32201 .58046 L .30537 .59091 L p .707 .577 .707 r
F P
0 g
s
.47822 .57456 m .48923 .60861 L .4696 .60463 L p .707 .577 .707 r
F P
0 g
s
.4696 .60463 m .45859 .57058 L .47822 .57456 L p .707 .577 .707 r
F P
0 g
s
.30361 .6885 m .30927 .70543 L .30237 .71951 L p .707 .577 .707 r
F P
0 g
s
.32201 .58046 m .31527 .52608 L .33945 .51686 L p .707 .577 .707 r
F P
0 g
s
.31516 .66131 m .30415 .62726 L .32045 .6124 L p .707 .577 .707 r
F P
0 g
s
.45836 .50664 m .46509 .56102 L .43805 .55875 L p .707 .577 .707 r
F P
0 g
s
.43805 .55875 m .43132 .50437 L .45836 .50664 L p .707 .577 .707 r
F P
0 g
s
.47699 .63325 m .48264 .65018 L .46262 .64646 L p .707 .577 .707 r
F P
0 g
s
.46262 .64646 m .45696 .62953 L .47699 .63325 L p .707 .577 .707 r
F P
0 g
s
.33945 .51686 m .34619 .57123 L .32201 .58046 L p .707 .577 .707 r
F P
0 g
s
.32045 .6124 m .33146 .64645 L .31516 .66131 L p .707 .577 .707 r
F P
0 g
s
.34619 .57123 m .33945 .51686 L .36881 .50974 L p .707 .577 .707 r
F P
0 g
s
.30927 .70543 m .30361 .6885 L .31937 .67338 L p .707 .577 .707 r
F P
0 g
s
.45859 .57058 m .4696 .60463 L .44368 .60528 L p .707 .577 .707 r
F P
0 g
s
.44368 .60528 m .43267 .57122 L .45859 .57058 L p .707 .577 .707 r
F P
0 g
s
.43132 .50437 m .43805 .55875 L .4072 .55982 L p .707 .577 .707 r
F P
0 g
s
.4072 .55982 m .40046 .50544 L .43132 .50437 L p .707 .577 .707 r
F P
0 g
s
.31937 .67338 m .32503 .69031 L .30927 .70543 L p .707 .577 .707 r
F P
0 g
s
.33146 .64645 m .32045 .6124 L .34397 .59808 L p .707 .577 .707 r
F P
0 g
s
.37554 .56412 m .36881 .50974 L .40046 .50544 L p .707 .577 .707 r
F P
0 g
s
.36881 .50974 m .37554 .56412 L .34619 .57123 L p .707 .577 .707 r
F P
0 g
s
.40046 .50544 m .4072 .55982 L .37554 .56412 L p .707 .577 .707 r
F P
0 g
s
.45696 .62953 m .46262 .64646 L .43644 .64747 L p .707 .577 .707 r
F P
0 g
s
.43644 .64747 m .43079 .63053 L .45696 .62953 L p .707 .577 .707 r
F P
0 g
s
.43267 .57122 m .44368 .60528 L .41398 .61048 L p .707 .577 .707 r
F P
0 g
s
.41398 .61048 m .40297 .57643 L .43267 .57122 L p .707 .577 .707 r
F P
0 g
s
.34397 .59808 m .35498 .63213 L .33146 .64645 L p .707 .577 .707 r
F P
0 g
s
.32503 .69031 m .31937 .67338 L .34245 .65869 L p .707 .577 .707 r
F P
0 g
s
.35498 .63213 m .34397 .59808 L .37241 .58568 L p .707 .577 .707 r
F P
0 g
s
.40297 .57643 m .41398 .61048 L .38342 .61973 L p .707 .577 .707 r
F P
0 g
s
.38342 .61973 m .37241 .58568 L .40297 .57643 L p .707 .577 .707 r
F P
0 g
s
.34245 .65869 m .34811 .67562 L .32503 .69031 L p .707 .577 .707 r
F P
0 g
s
.37241 .58568 m .38342 .61973 L .35498 .63213 L p .707 .577 .707 r
F P
0 g
s
.43079 .63053 m .43644 .64747 L .40668 .6531 L p .707 .577 .707 r
F P
0 g
s
.40668 .6531 m .40102 .63616 L .43079 .63053 L p .707 .577 .707 r
F P
0 g
s
.34811 .67562 m .34245 .65869 L .37059 .64586 L p .707 .577 .707 r
F P
0 g
s
.40102 .63616 m .40668 .6531 L .37624 .6628 L p .707 .577 .707 r
F P
0 g
s
.37624 .6628 m .37059 .64586 L .40102 .63616 L p .707 .577 .707 r
F P
0 g
s
.37059 .64586 m .37624 .6628 L .34811 .67562 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001hOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH8001f
Ool007=oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP000080
07=oo`00Kgoo100000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF0`00L7oo001/Ool30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2001^Ool006Yoo`<000MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<006aoo`00JGoo00@0
05YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF008006Yoo`00Igoo0P000eYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00J7oo001VOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001WOol006Ioo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Ioo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF4P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo200015YF00<005YFFUH01UYF00@005YFFUIJ
EPL000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol006Eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00@000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF001UOol005moo`<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005]oo`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Uoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000aJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001EOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0000=FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUIJEP00IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0035YF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Dgoo0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF001UOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000<FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEP00IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP04001JEP00000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0067oo5`00=Woo001BOol01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF2@0015YF00@0
05YF000000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000?Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol005=oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPX00003FUH005YF00=JEP@00003FUH005YF00EJEP@00005
FUH005YFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
1goo20000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH010000eYF00<005YF
00002P001EYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH007oo00H000=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=o
o`03001JEP0000EJEP03001JEUYF00=JEQ8000=JEPl00003FUH005YF00=JEP<000]JEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002ioo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000=JEP03001JEUYF00IJEP03001J
EP0000L000=JEP03001JEUYF00EJEP03001JEUYF00<000=JEP04001JEP00000:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05=oo`03001JEP0000EJEP04001JEP000005FUH00`00FUIJEP06FUH400000eYF001JEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00P002UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000
FUIJEP0015YF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YF0000009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YF
FUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8000QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo0010OolA0003
Ool2FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000jOol60003FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000015YF001JEP001EYF00<005YFFUH00eYF0P001EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool003Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00EJEP04001JEUYFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000dOol20005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH000020008FUH00`00FUIJEP07
FUH00`00FUIJEP07FUH01000FUIJEUYF1@000eYF00@005YFFUH000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
039oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPP000AJEP@00004FUH005YF
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Goo000`Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF1P001UYF00<005YF00000`000eYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH0
15YF0`001UYF0P000UYF0`002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YF
FUH00P00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUH00000FUH00P001eYF00<005YFFUH01UYF00<005YF00000P001eYF00<005YF
FUH0100000=JEP00FUH015YF0P000UYF00<005YFFUH00P002UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF200025YF
00<005YFFUH01UYF00<005YFFUH015YF1@0000=JEP000000;Goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH300000eYF001JEP03FUH70005FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
001JEP03FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00eYF
30002eYF00D005YFFUIJEP0000EJEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000015YF001JEUYF1P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000]Ool00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00
FUIJEP05FUH00`00FUH00004000015YF001JEUYF0`000UYF00<005YFFUH02EYF00<005YF00000P00
1UYF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH0
00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00AJEP<000EJ
EP03001JEP0000@00003FUH005YF00h00003FUH005YF00AJEP03001JEP0000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF00AJEP03001JEUYF009JEP800003FUH0000000EJEP03001JEP0000L000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
0005FUH02000FUIJEUYF001JEP00FUH20005FUH01P00FUH00000FUH000UJEP03001JEUYF00AJEP03
001JEUYF009JEP<0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD003=oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP<00004FUH005YFFUH20004FUH30004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF000035YF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF4@00;Woo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH01000FUIJEP001UYF00D005YFFUIJEP00009JEP80009JEP8000MJ
EP03001JEUYF00MJEP04001JEUYFFUH60002FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0017oo:@000UYF1@0000=JEP00FUH0;Woo000]Ool2
0004FUH00`00FUIJEP03FUH6000AOol60002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJ
EP050009FUH00`00FUIJEP02FUH80006FUH400000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02000KOol90004FUH70002FUH01@00FUIJEP00FUH0;Woo
000/Ool00`00FUH00004FUH00`00FUH00003000KOol20002FUH01@00FUIJEUYF00001EYF00<005YF
FUH00P000UYF00<005YFFUH01UYF1P001eYF00<005YFFUH01UYF1@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF00@000moo`P000AJEPT000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP<000Yoo`l000Eoo`80009JEP03001J
EUYF008000EJEP<000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00008000aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0005
FUH40003Ool80003FUH:0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000/Ool00`00FUH00002FUH20003FUH300000goo000000040003FUH00`00FUIJEP06FUH00`00FUIJ
EP040002Ool01000FUIJEUYF100015YF0P001eYF00<005YF00000P0025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF00<005YF000035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000EJEPL000=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000AJEP@00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0009JEPT000QJEP800003FUH005YF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH01P000UYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF00<005YFFUH00P001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP0000000UYF0`000UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF0`001EYF00D005YFFUIJEP0000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP`0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
;7oo0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80
0004FUH00000FUH20005FUH01000FUIJEUYF0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF0P000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool20003FUH20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
0P001eYF00<005YF00000P001eYF00<005YFFUH01eYF00<005YFFUH015YF0P001UYF00H005YFFUH0
05YF000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000/Ool20002FUH01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF008000MJEP80009JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEP800003FUH005YF00AJEP07001JEUYFFUH005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YFFUIJEP8002aoo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P00
15YF00<005YFFUH01UYF0`001eYF00@005YF000000=JEP03001JEUYF009JEP03001JEUYF00=JEP80
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00P002aoo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUH000=JEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH50005FUH30005
FUH00`00FUIJEP030005FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH6000dOol002eoo`<000=JEP03001JEUYF00=JEP03001JEUYF009JEPl000IJ
EP04001JEUYF0005FUH40007FUH00`00FUIJEP04FUH50002FUH30008FUH00`00FUH00002FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
1`00>Woo000]Ool00`00FUH00002FUH00`00FUIJEP03FUH600000eYF001JEP07FUH00`00FUIJEP02
FUH40002FUH01000FUH000001EYF00@005YFFUH000MJEP03001JEUYF00AJEPL000]JEP8000AJEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1000@Goo000]Ool00`00FUH00002FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH300000eYF00000004FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00FUIJ
EP08FUH20005FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`00
AGoo000]Ool20003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUIJEUYF00000UYF00<005YF00000P000UYF3`001eYF00<005YFFUH01UYF0P001eYF00<005YFFUH0
0eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP004aoo`00;Goo0P000UYF00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP80009JEP03
001JEUYF00AJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF
00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05
001JEP00FUH00002FUH>000LOol:000^Ool002eoo`800004FUH000000003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`0000=JEP00FUH01EYF00<005YF
FUH00P001EYF00<005YFFUH01EYF00@005YFFUIJEP<000AJEP05001JEUYFFUH00008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000040002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P005Goo1`000eYF100000=JEP000000;Woo000]Ool30003Ool20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH02P00FUIJEUYF001JEP00FUH005YF0P00
1EYF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP@000MJEP04001JEP000009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP040002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0037oo2@000eYF1`000UYF00<005YFFUH00P00;Woo000/Ool00`00FUH0
0006Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH20003FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF0P0000=JEP00FUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0
009JEPD000AJEP04001JEUYFFUH20003Ool90003FUH90003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool40008Ool40002FUH@0002FUH00`00FUIJEP02FUH01@00FUIJEP00FUH01@000UYF
00@005YFFUIJEP8000EJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH0
0UYF0`0000=JEP0000001`000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo10002Goo1P000eYF00<005YFFUH01UYF00<005YFFUH010000eYF1@001Goo0`00
0eYF0P001EYF10001eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00L000=J
EPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00
;7oo0P000UYF00<007ooOol00Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
10000UYF0`001Woo00@005YFFUIJEP800003FUH000000080009JEP03001JEUYF00MJEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP060002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01000FUIJEUYF1@00<7oo000/Ool20002FUH00`00Oomoo`020004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000UYF3@001UYF00<005YFFUH01UYF0`001UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
2`000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEPL003Eoo`00
;7oo0P000eYF0`001EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF00000UYF00<0
05YFFUH00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
000/Ool20003FUH00`00FUH00005FUH50009Ool60006FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEP0000<000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT004Aoo`00;7oo00D005YFFUIJEP00009JEP04001JEUYF
FUH2000DOol40002FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50003
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8001=Ool0
02aoo`04001JEUYF0003FUH01000FUH000006Woo10001EYF0`000UYF00<005YFFUH00UYF2@001eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000=JEP00FUH00eYF00@005YFFUIJEPP005Eoo`00;7oo00@005YF000000=J
EP80009JEP03001oogoo01]oo`8000AJEP03001JEP0000T000EJEP03001JEUYF00EJEP03001JEUYF
00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0004FUH005YFFUH700000eYF0000001IOol002eoo`80009JEP8000AJEP<001eoo`<00003FUH005YF
00AJEP800004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH90008FUH01000FUIJEUYF
30001UYF00<005YFFUH01UYF00<005YFFUH00eYF3P00Fgoo000]Ool40006FUH00`00FUIJEP02000N
Ool20006FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YF00000UYF2@001UYF00<005YFFUH00eYF00@005YFFUH000=JEP80
061oo`00;Goo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P007Woo0P0015YF1@001EYF00<005YF
FUH015YF1@002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002UYF1@000UYF00<005YF
FUH00eYF00@005YFFUH000EJEP<005eoo`00;Goo10001UYF00<005YFFUH015YF10006Goo10000UYF
00<005YFFUH00`001EYF00<005YFFUH0100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`001EYF00@005YFFUH000IJEP03001JEP000080
05Yoo`00;Goo00@007ooOol000EJEP03001JEUYF00IJEP03001JEUYF00@0011oo`D000AJEP<0009J
EP<000EJEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP04001JEUYF0005FUH00`00FUIJEP03FUH2001HOol002aoo`<0009o
o`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEQ0000=JEP03001JEUYF00=JEP03001J
EP0000=JEP8000=JEP800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00005FUH005YFFUH00005FUH00`00FUIJEP04FUH2
001GOol002aoo`03001JEP0000=oo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=JEP0000000eYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH005Ioo`00
;7oo00<005YF000017oo0P0000=JEP00FUH01UYF00<005YFFUH01eYF0`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH30005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000EGoo000/Ool01000FUH000001Goo0P001eYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0000AJEP00
000000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP05001J
EUYFFUH0001EOol002aoo`05001JEP00FUH00005Ool20006FUH00`00FUIJEP06FUH50004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00@005YFFUH0
00Moo`8000=JEP03001JEUYF00MJEPD000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP05
001JEUYFFUH0001FOol002eoo`05001JEUYFFUH00008Ool200000eYF001JEP08FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`04Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200001EYF000005YF00001EYF00<005YFFUH00UYF00<007ooOol0E7oo000]Ool00`00
FUIJEP02FUH00`00Oomoo`07Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0P001goo0`001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`001EYF00@005YFFUIJEP80
05Ioo`00;Woo00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000:Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF0P000eYF00@005YFFUIJ
EP8005Ioo`00;goo00H005YFFUH005YF000?Ool70004FUH00`00FUIJEP02FUH6000;Ool30005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30004FUH00`00Oomoo`1EOol002moo`03001J
EP0000=JEP8001Aoo`T0015oo`800003Ool0000000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEPD000=JEP03001JEUYF
00AJEP8000AJEP03001oogoo05Eoo`00<7oo0P001EYF00<007ooOol0:Woo0`000goo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0P0015YF10001UYF00D005YF000005YF008005Moo`00<Goo00<005YFFUH015YF0P00:7oo
0P0000=JEP00Ool01Goo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH00UYF0`001eYF00@005YF000000EJEP04001JEUYFFUH3001GOol0039o
o`8000AJEP04001JEP00000UOol00`00FUIJEP02000:Ool50002FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000040008FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF0000F7oo000dOol01000FUIJEP0015YF0P008Goo0P000eYF00<007ooOol0
3Woo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF300015YF00<005YFFUH0
1EYF2000F7oo000eOol30006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0COol60002FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060004FUH50003Ool300000eYF001JEP07FUH3
001LOol003Moo`03001JEUYF00EJEP03001JEUYF00@0011oo`D000AJEP03001JEUYF008001aooal0
0003FUH005YF00MJEPD000Ioo`<000IJEP04001JEUYFFUH2001JOol003Qoo`8000EJEP03001JEUYF
00AJEQ0000=JEP03001JEUYF00=JEP<003Yoo`<00003FUH005YF00MJEP@00004FUH000000006Ool2
0004FUH00`00FUIJEP03FUH00`00Oomoo`1GOol003Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo03eoo`<000MJEP03001JEUYF00EJEP<0
00Eoo`800003FUH005YF00EJEP<005Moo`00?7oo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8004=oo`@0009JEP03001JEUYF00MJEP03001JEP0000<000=oo`80
00IJEP03001JEUYF008005Eoo`00?Woo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000004Uoo`@000QJEP03001JEUYF00=JEPL000=JEP03001JEUYF009JEP03001oogoo05=oo`00@Goo
10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Cgoo0`0015YF00<005YFFUH01UYF00@005YF
FUIJEP<00003FUH005YF009JEP8005Eoo`00AGoo4000F7oo0`0000=JEP00FUH01eYF00<005YFFUH0
15YF0P000eYF0P00EGoo002`Ool30006FUH00`00FUIJEP04FUH00`00FUIJEP04001FOol00;=oo`@0
009JEP03001JEUYF00AJEP04001JEUYFFUH3001FOol00;Moo`D000=JEP03001JEUYF009JEP<005Io
o`00_7oo2`00EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59408 .74597 m .59825 .69009 L .56722 .68615 L p .707 .577 .707 r
F P
0 g
s
.59825 .69009 m .59408 .74597 L .62586 .74758 L p .707 .577 .707 r
F P
0 g
s
.62586 .74758 m .63003 .6917 L .59825 .69009 L p .707 .577 .707 r
F P
0 g
s
.63003 .6917 m .62586 .74758 L .65527 .74671 L p .707 .577 .707 r
F P
0 g
s
.65527 .74671 m .65944 .69082 L .63003 .6917 L p .707 .577 .707 r
F P
0 g
s
.56305 .74203 m .56722 .68615 L .53998 .68027 L p .707 .577 .707 r
F P
0 g
s
.56722 .68615 m .56305 .74203 L .59408 .74597 L p .707 .577 .707 r
F P
0 g
s
.65944 .69082 m .65527 .74671 L .67943 .74343 L p .707 .577 .707 r
F P
0 g
s
.67943 .74343 m .6836 .68755 L .65944 .69082 L p .707 .577 .707 r
F P
0 g
s
.53998 .68027 m .5358 .73615 L .56305 .74203 L p .707 .577 .707 r
F P
0 g
s
.58993 .80111 m .59682 .76399 L .56624 .75708 L p .707 .577 .707 r
F P
0 g
s
.59682 .76399 m .58993 .80111 L .62129 .80622 L p .707 .577 .707 r
F P
0 g
s
.62129 .80622 m .62817 .7691 L .59682 .76399 L p .707 .577 .707 r
F P
0 g
s
.5358 .73615 m .53998 .68027 L .51918 .67302 L p .707 .577 .707 r
F P
0 g
s
.62817 .7691 m .62129 .80622 L .65035 .80903 L p .707 .577 .707 r
F P
0 g
s
.65035 .80903 m .65723 .77191 L .62817 .7691 L p .707 .577 .707 r
F P
0 g
s
.55935 .7942 m .56624 .75708 L .53943 .74905 L p .707 .577 .707 r
F P
0 g
s
.56624 .75708 m .55935 .7942 L .58993 .80111 L p .707 .577 .707 r
F P
0 g
s
.53943 .74905 m .53255 .78617 L .55935 .7942 L p .707 .577 .707 r
F P
0 g
s
.51918 .67302 m .515 .7289 L .5358 .73615 L p .707 .577 .707 r
F P
0 g
s
.6836 .68755 m .67943 .74343 L .69599 .73808 L p .707 .577 .707 r
F P
0 g
s
.69599 .73808 m .70016 .68219 L .6836 .68755 L p .707 .577 .707 r
F P
0 g
s
.65723 .77191 m .65035 .80903 L .67428 .80926 L p .707 .577 .707 r
F P
0 g
s
.67428 .80926 m .68116 .77214 L .65723 .77191 L p .707 .577 .707 r
F P
0 g
s
.59447 .8426 m .598 .82405 L .56737 .81707 L p .707 .577 .707 r
F P
0 g
s
.598 .82405 m .59447 .8426 L .62577 .84779 L p .707 .577 .707 r
F P
0 g
s
.62577 .84779 m .6293 .82923 L .598 .82405 L p .707 .577 .707 r
F P
0 g
s
.56737 .81707 m .56384 .83563 L .59447 .8426 L p .707 .577 .707 r
F P
0 g
s
.6293 .82923 m .62577 .84779 L .65466 .85068 L p .707 .577 .707 r
F P
0 g
s
.65466 .85068 m .65819 .83213 L .6293 .82923 L p .707 .577 .707 r
F P
0 g
s
.53255 .78617 m .53943 .74905 L .51902 .74067 L p .707 .577 .707 r
F P
0 g
s
.56384 .83563 m .56737 .81707 L .54039 .80899 L p .707 .577 .707 r
F P
0 g
s
.515 .7289 m .51918 .67302 L .50687 .66511 L p .707 .577 .707 r
F P
0 g
s
.54039 .80899 m .53686 .82755 L .56384 .83563 L p .707 .577 .707 r
F P
0 g
s
.51902 .74067 m .51214 .7778 L .53255 .78617 L p .707 .577 .707 r
F P
0 g
s
.65819 .83213 m .65466 .85068 L .67833 .851 L p .707 .577 .707 r
F P
0 g
s
.67833 .851 m .68186 .83244 L .65819 .83213 L p .707 .577 .707 r
F P
0 g
s
.53686 .82755 m .54039 .80899 L .51972 .8006 L p .707 .577 .707 r
F P
0 g
s
.68116 .77214 m .67428 .80926 L .69073 .8069 L p .707 .577 .707 r
F P
0 g
s
.69073 .8069 m .69761 .76977 L .68116 .77214 L p .707 .577 .707 r
F P
0 g
s
.50687 .66511 m .50269 .721 L .515 .7289 L p .707 .577 .707 r
F P
0 g
s
.51972 .8006 m .51619 .81915 L .53686 .82755 L p .707 .577 .707 r
F P
0 g
s
.70016 .68219 m .69599 .73808 L .70331 .73117 L p .707 .577 .707 r
F P
0 g
s
.70331 .73117 m .70749 .67529 L .70016 .68219 L p .707 .577 .707 r
F P
0 g
s
.51214 .7778 m .51902 .74067 L .507 .73279 L p .707 .577 .707 r
F P
0 g
s
.507 .73279 m .50012 .76991 L .51214 .7778 L p .707 .577 .707 r
F P
0 g
s
.50269 .721 m .50687 .66511 L .50424 .65733 L p .707 .577 .707 r
F P
0 g
s
.68186 .83244 m .67833 .851 L .69445 .8487 L p .707 .577 .707 r
F P
0 g
s
.69445 .8487 m .69798 .83014 L .68186 .83244 L p .707 .577 .707 r
F P
0 g
s
.51619 .81915 m .51972 .8006 L .50736 .79271 L p .707 .577 .707 r
F P
0 g
s
.50736 .79271 m .50383 .81127 L .51619 .81915 L p .707 .577 .707 r
F P
0 g
s
.69761 .76977 m .69073 .8069 L .69809 .80216 L p .707 .577 .707 r
F P
0 g
s
.69809 .80216 m .70497 .76504 L .69761 .76977 L p .707 .577 .707 r
F P
0 g
s
.50424 .65733 m .50007 .71321 L .50269 .721 L p .707 .577 .707 r
F P
0 g
s
.70749 .67529 m .70331 .73117 L .70069 .72338 L p .707 .577 .707 r
F P
0 g
s
.70069 .72338 m .70487 .6675 L .70749 .67529 L p .707 .577 .707 r
F P
0 g
s
.50012 .76991 m .507 .73279 L .50455 .72615 L p .707 .577 .707 r
F P
0 g
s
.50455 .72615 m .49767 .76327 L .50012 .76991 L p .707 .577 .707 r
F P
0 g
s
.49767 .76327 m .50455 .72615 L .51191 .72142 L p .707 .577 .707 r
F P
0 g
s
.51191 .72142 m .50502 .75854 L .49767 .76327 L p .707 .577 .707 r
F P
0 g
s
.49936 .82192 m .49936 .32003 L .45482 .31809 L p .707 .577 .707 r
F P
0 g
s
.50007 .71321 m .50424 .65733 L .51157 .65042 L p .707 .577 .707 r
F P
0 g
s
.50383 .81127 m .50736 .79271 L .50455 .7861 L p .707 .577 .707 r
F P
0 g
s
.50455 .7861 m .50102 .80466 L .50383 .81127 L p .707 .577 .707 r
F P
0 g
s
.51157 .65042 m .5074 .7063 L .50007 .71321 L p .707 .577 .707 r
F P
0 g
s
.5074 .7063 m .51157 .65042 L .52813 .64507 L p .707 .577 .707 r
F P
0 g
s
.50102 .80466 m .50455 .7861 L .51154 .78142 L p .707 .577 .707 r
F P
0 g
s
.51154 .78142 m .50801 .79998 L .50102 .80466 L p .707 .577 .707 r
F P
0 g
s
.52813 .64507 m .52395 .70095 L .5074 .7063 L p .707 .577 .707 r
F P
0 g
s
.50502 .75854 m .51191 .72142 L .52835 .71905 L p .707 .577 .707 r
F P
0 g
s
.52395 .70095 m .52813 .64507 L .55229 .64179 L p .707 .577 .707 r
F P
0 g
s
.52835 .71905 m .52147 .75617 L .50502 .75854 L p .707 .577 .707 r
F P
0 g
s
.50801 .79998 m .51154 .78142 L .52766 .77913 L p .707 .577 .707 r
F P
0 g
s
.52766 .77913 m .52413 .79769 L .50801 .79998 L p .707 .577 .707 r
F P
0 g
s
.55229 .64179 m .54812 .69767 L .52395 .70095 L p .707 .577 .707 r
F P
0 g
s
.52147 .75617 m .52835 .71905 L .55228 .71929 L p .707 .577 .707 r
F P
0 g
s
.55228 .71929 m .5454 .75641 L .52147 .75617 L p .707 .577 .707 r
F P
0 g
s
.52413 .79769 m .52766 .77913 L .55132 .77944 L p .707 .577 .707 r
F P
0 g
s
.55132 .77944 m .54779 .798 L .52413 .79769 L p .707 .577 .707 r
F P
0 g
s
.49936 .32003 m .49936 .82192 L .54397 .82008 L p .707 .577 .707 r
F P
0 g
s
.54397 .82008 m .54397 .31819 L .49936 .32003 L p .707 .577 .707 r
F P
0 g
s
.69798 .83014 m .69445 .8487 L .70144 .84402 L p .707 .577 .707 r
F P
0 g
s
.70144 .84402 m .70497 .82547 L .69798 .83014 L p .707 .577 .707 r
F P
0 g
s
.54812 .69767 m .55229 .64179 L .5817 .64092 L p .707 .577 .707 r
F P
0 g
s
.5817 .64092 m .57753 .6968 L .54812 .69767 L p .707 .577 .707 r
F P
0 g
s
.5454 .75641 m .55228 .71929 L .58135 .72209 L p .707 .577 .707 r
F P
0 g
s
.58135 .72209 m .57446 .75922 L .5454 .75641 L p .707 .577 .707 r
F P
0 g
s
.57446 .75922 m .58135 .72209 L .6127 .7272 L p .707 .577 .707 r
F P
0 g
s
.54779 .798 m .55132 .77944 L .58022 .78234 L p .707 .577 .707 r
F P
0 g
s
.6127 .7272 m .60582 .76433 L .57446 .75922 L p .707 .577 .707 r
F P
0 g
s
.58022 .78234 m .57669 .80089 L .54779 .798 L p .707 .577 .707 r
F P
0 g
s
.57669 .80089 m .58022 .78234 L .61151 .78752 L p .707 .577 .707 r
F P
0 g
s
.61151 .78752 m .60798 .80608 L .57669 .80089 L p .707 .577 .707 r
F P
0 g
s
.54397 .31819 m .54397 .82008 L .58427 .81463 L p .707 .577 .707 r
F P
0 g
s
.57753 .6968 m .5817 .64092 L .61348 .64253 L p .707 .577 .707 r
F P
0 g
s
.61348 .64253 m .6093 .69841 L .57753 .6968 L p .707 .577 .707 r
F P
0 g
s
.58427 .81463 m .58427 .31274 L .54397 .31819 L p .707 .577 .707 r
F P
0 g
s
.45482 .81998 m .45482 .31809 L .4147 .31254 L p .707 .577 .707 r
F P
0 g
s
.45482 .31809 m .45482 .81998 L .49936 .82192 L p .707 .577 .707 r
F P
0 g
s
.70497 .76504 m .69809 .80216 L .69564 .79553 L p .707 .577 .707 r
F P
0 g
s
.69564 .79553 m .70252 .75841 L .70497 .76504 L p .707 .577 .707 r
F P
0 g
s
.70487 .6675 m .70069 .72338 L .68838 .71548 L p .707 .577 .707 r
F P
0 g
s
.68838 .71548 m .69255 .65959 L .70487 .6675 L p .707 .577 .707 r
F P
0 g
s
.64451 .64647 m .64033 .70235 L .6093 .69841 L p .707 .577 .707 r
F P
0 g
s
.6093 .69841 m .61348 .64253 L .64451 .64647 L p .707 .577 .707 r
F P
0 g
s
.64328 .73411 m .6364 .77123 L .60582 .76433 L p .707 .577 .707 r
F P
0 g
s
.60582 .76433 m .6127 .7272 L .64328 .73411 L p .707 .577 .707 r
F P
0 g
s
.64215 .7945 m .63862 .81306 L .60798 .80608 L p .707 .577 .707 r
F P
0 g
s
.60798 .80608 m .61151 .78752 L .64215 .7945 L p .707 .577 .707 r
F P
0 g
s
.58427 .31274 m .58427 .81463 L .61632 .80611 L p .707 .577 .707 r
F P
0 g
s
.61632 .80611 m .61632 .30422 L .58427 .31274 L p .707 .577 .707 r
F P
0 g
s
.4147 .81443 m .4147 .31254 L .38293 .30394 L p .707 .577 .707 r
F P
0 g
s
.4147 .31254 m .4147 .81443 L .45482 .81998 L p .707 .577 .707 r
F P
0 g
s
.25184 .71911 m .25362 .66483 L .22252 .66146 L p .707 .577 .707 r
F P
0 g
s
.25362 .66483 m .25184 .71911 L .28368 .71914 L p .707 .577 .707 r
F P
0 g
s
.28368 .71914 m .28546 .66487 L .25362 .66483 L p .707 .577 .707 r
F P
0 g
s
.28546 .66487 m .28368 .71914 L .31314 .71582 L p .707 .577 .707 r
F P
0 g
s
.31314 .71582 m .31493 .66154 L .28546 .66487 L p .707 .577 .707 r
F P
0 g
s
.70497 .82547 m .70144 .84402 L .69862 .83742 L p .707 .577 .707 r
F P
0 g
s
.69862 .83742 m .70215 .81886 L .70497 .82547 L p .707 .577 .707 r
F P
0 g
s
.22073 .71574 m .22252 .66146 L .1952 .65506 L p .707 .577 .707 r
F P
0 g
s
.22252 .66146 m .22073 .71574 L .25184 .71911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31493 .66154 m .31314 .71582 L .33734 .70948 L p .707 .577 .707 r
F P
0 g
s
.33734 .70948 m .33913 .6552 L .31493 .66154 L p .707 .577 .707 r
F P
0 g
s
.70252 .75841 m .69564 .79553 L .68362 .78764 L p .707 .577 .707 r
F P
0 g
s
.68362 .78764 m .6905 .75052 L .70252 .75841 L p .707 .577 .707 r
F P
0 g
s
.69255 .65959 m .68838 .71548 L .66758 .70823 L p .707 .577 .707 r
F P
0 g
s
.66758 .70823 m .67175 .65235 L .69255 .65959 L p .707 .577 .707 r
F P
0 g
s
.19341 .70934 m .1952 .65506 L .17434 .64627 L p .707 .577 .707 r
F P
0 g
s
.1952 .65506 m .19341 .70934 L .22073 .71574 L p .707 .577 .707 r
F P
0 g
s
.61632 .30422 m .61632 .80611 L .63699 .79534 L p .707 .577 .707 r
F P
0 g
s
.67009 .74215 m .6632 .77927 L .6364 .77123 L p .707 .577 .707 r
F P
0 g
s
.6364 .77123 m .64328 .73411 L .67009 .74215 L p .707 .577 .707 r
F P
0 g
s
.63699 .79534 m .63699 .29345 L .61632 .30422 L p .707 .577 .707 r
F P
0 g
s
.25024 .78806 m .2532 .75358 L .22218 .74823 L p .707 .577 .707 r
F P
0 g
s
.2532 .75358 m .25024 .78806 L .282 .78911 L p .707 .577 .707 r
F P
0 g
s
.282 .78911 m .28496 .75462 L .2532 .75358 L p .707 .577 .707 r
F P
0 g
s
.38293 .80583 m .38293 .30394 L .36262 .29313 L p .707 .577 .707 r
F P
0 g
s
.38293 .30394 m .38293 .80583 L .4147 .81443 L p .707 .577 .707 r
F P
0 g
s
.28496 .75462 m .282 .78911 L .31138 .78573 L p .707 .577 .707 r
F P
0 g
s
.31138 .78573 m .31435 .75125 L .28496 .75462 L p .707 .577 .707 r
F P
0 g
s
.21921 .78271 m .22218 .74823 L .19492 .73908 L p .707 .577 .707 r
F P
0 g
s
.22218 .74823 m .21921 .78271 L .25024 .78806 L p .707 .577 .707 r
F P
0 g
s
.70215 .81886 m .69862 .83742 L .68627 .82953 L p .707 .577 .707 r
F P
0 g
s
.68627 .82953 m .6898 .81097 L .70215 .81886 L p .707 .577 .707 r
F P
0 g
s
.33913 .6552 m .33734 .70948 L .35391 .70073 L p .707 .577 .707 r
F P
0 g
s
.35391 .70073 m .35569 .64645 L .33913 .6552 L p .707 .577 .707 r
F P
0 g
s
.17434 .64627 m .17255 .70055 L .19341 .70934 L p .707 .577 .707 r
F P
0 g
s
.31435 .75125 m .31138 .78573 L .33552 .77827 L p .707 .577 .707 r
F P
0 g
s
.33552 .77827 m .33848 .74379 L .31435 .75125 L p .707 .577 .707 r
F P
0 g
s
.25288 .83132 m .25441 .8141 L .2233 .80882 L p .707 .577 .707 r
F P
0 g
s
.25441 .8141 m .25288 .83132 L .2846 .83225 L p .707 .577 .707 r
F P
0 g
s
.2846 .83225 m .28613 .81504 L .25441 .8141 L p .707 .577 .707 r
F P
0 g
s
.17255 .70055 m .17434 .64627 L .16197 .63595 L p .707 .577 .707 r
F P
0 g
s
.67175 .65235 m .66758 .70823 L .64033 .70235 L p .707 .577 .707 r
F P
0 g
s
.64033 .70235 m .64451 .64647 L .67175 .65235 L p .707 .577 .707 r
F P
0 g
s
.6905 .75052 m .68362 .78764 L .6632 .77927 L p .707 .577 .707 r
F P
0 g
s
.6632 .77927 m .67009 .74215 L .6905 .75052 L p .707 .577 .707 r
F P
0 g
s
.19195 .77356 m .19492 .73908 L .1741 .72703 L p .707 .577 .707 r
F P
0 g
s
.19492 .73908 m .19195 .77356 L .21921 .78271 L p .707 .577 .707 r
F P
0 g
s
.28613 .81504 m .2846 .83225 L .31383 .82874 L p .707 .577 .707 r
F P
0 g
s
.31383 .82874 m .31536 .81153 L .28613 .81504 L p .707 .577 .707 r
F P
0 g
s
.22178 .82604 m .2233 .80882 L .19586 .79971 L p .707 .577 .707 r
F P
0 g
s
.2233 .80882 m .22178 .82604 L .25288 .83132 L p .707 .577 .707 r
F P
0 g
s
.19586 .79971 m .19433 .81693 L .22178 .82604 L p .707 .577 .707 r
F P
0 g
s
.31536 .81153 m .31383 .82874 L .33771 .82114 L p .707 .577 .707 r
F P
0 g
s
.33771 .82114 m .33924 .80392 L .31536 .81153 L p .707 .577 .707 r
F P
0 g
s
.35569 .64645 m .35391 .70073 L .36122 .69043 L p .707 .577 .707 r
F P
0 g
s
.36122 .69043 m .36301 .63615 L .35569 .64645 L p .707 .577 .707 r
F P
0 g
s
.33848 .74379 m .33552 .77827 L .35204 .76745 L p .707 .577 .707 r
F P
0 g
s
.35204 .76745 m .355 .73297 L .33848 .74379 L p .707 .577 .707 r
F P
0 g
s
.6898 .81097 m .68627 .82953 L .66559 .82114 L p .707 .577 .707 r
F P
0 g
s
.66559 .82114 m .66912 .80258 L .6898 .81097 L p .707 .577 .707 r
F P
0 g
s
.19433 .81693 m .19586 .79971 L .17476 .78766 L p .707 .577 .707 r
F P
0 g
s
.1741 .72703 m .17114 .76151 L .19195 .77356 L p .707 .577 .707 r
F P
0 g
s
.16197 .63595 m .16018 .69023 L .17255 .70055 L p .707 .577 .707 r
F P
0 g
s
.63699 .29345 m .63699 .79534 L .64424 .78339 L p .707 .577 .707 r
F P
0 g
s
.64424 .78339 m .64424 .2815 L .63699 .29345 L p .707 .577 .707 r
F P
0 g
s
.35932 .75433 m .36229 .71985 L .355 .73297 L p .707 .577 .707 r
F P
0 g
s
.36301 .63615 m .36122 .69043 L .35857 .67959 L p .707 .577 .707 r
F P
0 g
s
.35857 .67959 m .36035 .62531 L .36301 .63615 L p .707 .577 .707 r
F P
0 g
s
.36229 .71985 m .35932 .75433 L .35667 .7402 L p .707 .577 .707 r
F P
0 g
s
.35667 .7402 m .35963 .70572 L .36229 .71985 L p .707 .577 .707 r
F P
0 g
s
.36035 .62531 m .35857 .67959 L .3462 .66927 L p .707 .577 .707 r
F P
0 g
s
.3462 .66927 m .34799 .61499 L .36035 .62531 L p .707 .577 .707 r
F P
0 g
s
.36262 .79502 m .36262 .29313 L .35575 .28116 L p .707 .577 .707 r
F P
0 g
s
.36262 .29313 m .36262 .79502 L .38293 .80583 L p .707 .577 .707 r
F P
0 g
s
.17114 .76151 m .1741 .72703 L .16176 .71327 L p .707 .577 .707 r
F P
0 g
s
.17476 .78766 m .17323 .80487 L .19433 .81693 L p .707 .577 .707 r
F P
0 g
s
.16018 .69023 m .16197 .63595 L .15932 .62511 L p .707 .577 .707 r
F P
0 g
s
.33924 .80392 m .33771 .82114 L .35391 .81018 L p .707 .577 .707 r
F P
0 g
s
.35391 .81018 m .35543 .79297 L .33924 .80392 L p .707 .577 .707 r
F P
0 g
s
.17323 .80487 m .17476 .78766 L .16207 .77384 L p .707 .577 .707 r
F P
0 g
s
.16176 .71327 m .15879 .74775 L .17114 .76151 L p .707 .577 .707 r
F P
0 g
s
.66912 .80258 m .66559 .82114 L .63862 .81306 L p .707 .577 .707 r
F P
0 g
s
.63862 .81306 m .64215 .7945 L .66912 .80258 L p .707 .577 .707 r
F P
0 g
s
.355 .73297 m .35204 .76745 L .35932 .75433 L p .707 .577 .707 r
F P
0 g
s
.15932 .62511 m .15753 .67939 L .16018 .69023 L p .707 .577 .707 r
F P
0 g
s
.16207 .77384 m .16054 .79106 L .17323 .80487 L p .707 .577 .707 r
F P
0 g
s
.15879 .74775 m .16176 .71327 L .1591 .69914 L p .707 .577 .707 r
F P
0 g
s
.15753 .67939 m .15932 .62511 L .16663 .61481 L p .707 .577 .707 r
F P
0 g
s
.35543 .79297 m .35391 .81018 L .36082 .79694 L p .707 .577 .707 r
F P
0 g
s
.36082 .79694 m .36235 .77973 L .35543 .79297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64424 .2815 m .64424 .78339 L .63738 .77142 L p .707 .577 .707 r
F P
0 g
s
.63738 .77142 m .63738 .26953 L .64424 .2815 L p .707 .577 .707 r
F P
0 g
s
.36235 .77973 m .36082 .79694 L .35779 .78272 L p .707 .577 .707 r
F P
0 g
s
.35779 .78272 m .35932 .76551 L .36235 .77973 L p .707 .577 .707 r
F P
0 g
s
.35963 .70572 m .35667 .7402 L .34433 .72644 L p .707 .577 .707 r
F P
0 g
s
.34433 .72644 m .34729 .69196 L .35963 .70572 L p .707 .577 .707 r
F P
0 g
s
.35932 .76551 m .35779 .78272 L .3451 .76891 L p .707 .577 .707 r
F P
0 g
s
.3451 .76891 m .34663 .75169 L .35932 .76551 L p .707 .577 .707 r
F P
0 g
s
.35575 .28116 m .35575 .78305 L .36262 .79502 L p .707 .577 .707 r
F P
0 g
s
.35575 .78305 m .35575 .28116 L .36301 .26921 L p .707 .577 .707 r
F P
0 g
s
.16054 .79106 m .16207 .77384 L .15904 .75962 L p .707 .577 .707 r
F P
0 g
s
.1591 .69914 m .15614 .73362 L .15879 .74775 L p .707 .577 .707 r
F P
0 g
s
.15904 .75962 m .15751 .77684 L .16054 .79106 L p .707 .577 .707 r
F P
0 g
s
.16663 .61481 m .16484 .66909 L .15753 .67939 L p .707 .577 .707 r
F P
0 g
s
.15614 .73362 m .1591 .69914 L .16639 .68602 L p .707 .577 .707 r
F P
0 g
s
.16484 .66909 m .16663 .61481 L .1832 .60606 L p .707 .577 .707 r
F P
0 g
s
.15751 .77684 m .15904 .75962 L .16596 .74639 L p .707 .577 .707 r
F P
0 g
s
.16639 .68602 m .16342 .7205 L .15614 .73362 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16596 .74639 m .16443 .7636 L .15751 .77684 L p .707 .577 .707 r
F P
0 g
s
.34799 .61499 m .3462 .66927 L .32534 .66048 L p .707 .577 .707 r
F P
0 g
s
.32534 .66048 m .32712 .6062 L .34799 .61499 L p .707 .577 .707 r
F P
0 g
s
.16342 .7205 m .16639 .68602 L .18291 .6752 L p .707 .577 .707 r
F P
0 g
s
.1832 .60606 m .18141 .66034 L .16484 .66909 L p .707 .577 .707 r
F P
0 g
s
.63738 .26953 m .63738 .77142 L .61707 .76061 L p .707 .577 .707 r
F P
0 g
s
.61707 .76061 m .61707 .25872 L .63738 .26953 L p .707 .577 .707 r
F P
0 g
s
.36301 .7711 m .36301 .26921 L .38368 .25844 L p .707 .577 .707 r
F P
0 g
s
.36301 .26921 m .36301 .7711 L .35575 .78305 L p .707 .577 .707 r
F P
0 g
s
.18141 .66034 m .1832 .60606 L .2074 .59971 L p .707 .577 .707 r
F P
0 g
s
.16443 .7636 m .16596 .74639 L .18215 .73543 L p .707 .577 .707 r
F P
0 g
s
.18291 .6752 m .17994 .70968 L .16342 .7205 L p .707 .577 .707 r
F P
0 g
s
.32712 .6062 m .32534 .66048 L .29802 .65408 L p .707 .577 .707 r
F P
0 g
s
.29802 .65408 m .2998 .5998 L .32712 .6062 L p .707 .577 .707 r
F P
0 g
s
.34729 .69196 m .34433 .72644 L .32351 .71439 L p .707 .577 .707 r
F P
0 g
s
.32351 .71439 m .32647 .67991 L .34729 .69196 L p .707 .577 .707 r
F P
0 g
s
.18215 .73543 m .18062 .75264 L .16443 .7636 L p .707 .577 .707 r
F P
0 g
s
.17994 .70968 m .18291 .6752 L .20704 .66774 L p .707 .577 .707 r
F P
0 g
s
.2074 .59971 m .20561 .65399 L .18141 .66034 L p .707 .577 .707 r
F P
0 g
s
.20561 .65399 m .2074 .59971 L .23686 .59639 L p .707 .577 .707 r
F P
0 g
s
.2998 .5998 m .29802 .65408 L .26691 .6507 L p .707 .577 .707 r
F P
0 g
s
.26691 .6507 m .2687 .59642 L .2998 .5998 L p .707 .577 .707 r
F P
0 g
s
.34663 .75169 m .3451 .76891 L .324 .75686 L p .707 .577 .707 r
F P
0 g
s
.324 .75686 m .32553 .73964 L .34663 .75169 L p .707 .577 .707 r
F P
0 g
s
.23507 .65067 m .23686 .59639 L .2687 .59642 L p .707 .577 .707 r
F P
0 g
s
.23686 .59639 m .23507 .65067 L .20561 .65399 L p .707 .577 .707 r
F P
0 g
s
.61707 .25872 m .61707 .76061 L .5853 .75201 L p .707 .577 .707 r
F P
0 g
s
.5853 .75201 m .5853 .25012 L .61707 .25872 L p .707 .577 .707 r
F P
0 g
s
.38368 .25844 m .38368 .76033 L .36301 .7711 L p .707 .577 .707 r
F P
0 g
s
.38368 .76033 m .38368 .25844 L .41573 .24992 L p .707 .577 .707 r
F P
0 g
s
.32647 .67991 m .32351 .71439 L .29625 .70524 L p .707 .577 .707 r
F P
0 g
s
.29625 .70524 m .29922 .67076 L .32647 .67991 L p .707 .577 .707 r
F P
0 g
s
.18062 .75264 m .18215 .73543 L .20603 .72782 L p .707 .577 .707 r
F P
0 g
s
.2687 .59642 m .26691 .6507 L .23507 .65067 L p .707 .577 .707 r
F P
0 g
s
.20704 .66774 m .20408 .70222 L .17994 .70968 L p .707 .577 .707 r
F P
0 g
s
.20408 .70222 m .20704 .66774 L .23643 .66436 L p .707 .577 .707 r
F P
0 g
s
.20603 .72782 m .2045 .74504 L .18062 .75264 L p .707 .577 .707 r
F P
0 g
s
.73308 .65068 m .7313 .59415 L .7002 .59365 L p .707 .577 .707 r
F P
0 g
s
.7313 .59415 m .73308 .65068 L .76493 .64919 L p .707 .577 .707 r
F P
0 g
s
.76493 .64919 m .76314 .59266 L .7313 .59415 L p .707 .577 .707 r
F P
0 g
s
.76314 .59266 m .76493 .64919 L .79439 .64586 L p .707 .577 .707 r
F P
0 g
s
.79439 .64586 m .7926 .58932 L .76314 .59266 L p .707 .577 .707 r
F P
0 g
s
.29922 .67076 m .29625 .70524 L .26522 .69989 L p .707 .577 .707 r
F P
0 g
s
.26522 .69989 m .26819 .66541 L .29922 .67076 L p .707 .577 .707 r
F P
0 g
s
.23346 .69884 m .23643 .66436 L .26819 .66541 L p .707 .577 .707 r
F P
0 g
s
.23643 .66436 m .23346 .69884 L .20408 .70222 L p .707 .577 .707 r
F P
0 g
s
.70198 .65018 m .7002 .59365 L .67287 .59121 L p .707 .577 .707 r
F P
0 g
s
.7002 .59365 m .70198 .65018 L .73308 .65068 L p .707 .577 .707 r
F P
0 g
s
.32553 .73964 m .324 .75686 L .29656 .74774 L p .707 .577 .707 r
F P
0 g
s
.29656 .74774 m .29809 .73053 L .32553 .73964 L p .707 .577 .707 r
F P
0 g
s
.26819 .66541 m .26522 .69989 L .23346 .69884 L p .707 .577 .707 r
F P
0 g
s
.2045 .74504 m .20603 .72782 L .23526 .72431 L p .707 .577 .707 r
F P
0 g
s
.7926 .58932 m .79439 .64586 L .81859 .641 L p .707 .577 .707 r
F P
0 g
s
.81859 .641 m .8168 .58447 L .7926 .58932 L p .707 .577 .707 r
F P
0 g
s
.67287 .59121 m .67466 .64774 L .70198 .65018 L p .707 .577 .707 r
F P
0 g
s
.73477 .70121 m .73181 .66302 L .70078 .66475 L p .707 .577 .707 r
F P
0 g
s
.73181 .66302 m .73477 .70121 L .76654 .69853 L p .707 .577 .707 r
F P
0 g
s
.76654 .69853 m .76357 .66033 L .73181 .66302 L p .707 .577 .707 r
F P
0 g
s
.23526 .72431 m .23373 .74153 L .2045 .74504 L p .707 .577 .707 r
F P
0 g
s
.5853 .25012 m .5853 .75201 L .54518 .74646 L p .707 .577 .707 r
F P
0 g
s
.54518 .74646 m .54518 .24457 L .5853 .25012 L p .707 .577 .707 r
F P
0 g
s
.41573 .75181 m .41573 .24992 L .45603 .24447 L p .707 .577 .707 r
F P
0 g
s
.41573 .24992 m .41573 .75181 L .38368 .76033 L p .707 .577 .707 r
F P
0 g
s
.76357 .66033 m .76654 .69853 L .79592 .69515 L p .707 .577 .707 r
F P
0 g
s
.79592 .69515 m .79295 .65695 L .76357 .66033 L p .707 .577 .707 r
F P
0 g
s
.29809 .73053 m .29656 .74774 L .26545 .74246 L p .707 .577 .707 r
F P
0 g
s
.26545 .74246 m .26698 .72525 L .29809 .73053 L p .707 .577 .707 r
F P
0 g
s
.70078 .66475 m .70375 .70294 L .73477 .70121 L p .707 .577 .707 r
F P
0 g
s
.23373 .74153 m .23526 .72431 L .26698 .72525 L p .707 .577 .707 r
F P
0 g
s
.67466 .64774 m .67287 .59121 L .65201 .58706 L p .707 .577 .707 r
F P
0 g
s
.70375 .70294 m .70078 .66475 L .67352 .66536 L p .707 .577 .707 r
F P
0 g
s
.26698 .72525 m .26545 .74246 L .23373 .74153 L p .707 .577 .707 r
F P
0 g
s
.67352 .66536 m .67649 .70355 L .70375 .70294 L p .707 .577 .707 r
F P
0 g
s
.79295 .65695 m .79592 .69515 L .82005 .69141 L p .707 .577 .707 r
F P
0 g
s
.82005 .69141 m .81709 .65321 L .79295 .65695 L p .707 .577 .707 r
F P
0 g
s
.8168 .58447 m .81859 .641 L .83515 .6351 L p .707 .577 .707 r
F P
0 g
s
.83515 .6351 m .83337 .57857 L .8168 .58447 L p .707 .577 .707 r
F P
0 g
s
.65201 .58706 m .6538 .6436 L .67466 .64774 L p .707 .577 .707 r
F P
0 g
s
.73455 .74198 m .73302 .72288 L .70191 .72475 L p .707 .577 .707 r
F P
0 g
s
.73302 .72288 m .73455 .74198 L .76627 .7392 L p .707 .577 .707 r
F P
0 g
s
.76627 .7392 m .76474 .7201 L .73302 .72288 L p .707 .577 .707 r
F P
0 g
s
.70191 .72475 m .70344 .74385 L .73455 .74198 L p .707 .577 .707 r
F P
0 g
s
.76474 .7201 m .76627 .7392 L .7955 .73576 L p .707 .577 .707 r
F P
0 g
s
.7955 .73576 m .79397 .71666 L .76474 .7201 L p .707 .577 .707 r
F P
0 g
s
.54518 .24457 m .54518 .74646 L .50063 .74451 L p .707 .577 .707 r
F P
0 g
s
.50063 .74451 m .50063 .24262 L .54518 .24457 L p .707 .577 .707 r
F P
0 g
s
.45603 .74636 m .45603 .24447 L .50063 .24262 L p .707 .577 .707 r
F P
0 g
s
.45603 .24447 m .45603 .74636 L .41573 .75181 L p .707 .577 .707 r
F P
0 g
s
.70344 .74385 m .70191 .72475 L .67447 .72551 L p .707 .577 .707 r
F P
0 g
s
.67649 .70355 m .67352 .66536 L .65271 .66478 L p .707 .577 .707 r
F P
0 g
s
.67447 .72551 m .67599 .7446 L .70344 .74385 L p .707 .577 .707 r
F P
0 g
s
.65271 .66478 m .65567 .70297 L .67649 .70355 L p .707 .577 .707 r
F P
0 g
s
.50063 .24262 m .50063 .74451 L .45603 .74636 L p .707 .577 .707 r
F P
0 g
s
.6538 .6436 m .65201 .58706 L .63965 .58162 L p .707 .577 .707 r
F P
0 g
s
.79397 .71666 m .7955 .73576 L .81938 .73201 L p .707 .577 .707 r
F P
0 g
s
.81938 .73201 m .81785 .71291 L .79397 .71666 L p .707 .577 .707 r
F P
0 g
s
.81709 .65321 m .82005 .69141 L .83657 .68768 L p .707 .577 .707 r
F P
0 g
s
.83657 .68768 m .83361 .64948 L .81709 .65321 L p .707 .577 .707 r
F P
0 g
s
.63965 .58162 m .64143 .63815 L .6538 .6436 L p .707 .577 .707 r
F P
0 g
s
.67599 .7446 m .67447 .72551 L .65337 .72509 L p .707 .577 .707 r
F P
0 g
s
.65337 .72509 m .65489 .74418 L .67599 .7446 L p .707 .577 .707 r
F P
0 g
s
.83337 .57857 m .83515 .6351 L .84247 .62874 L p .707 .577 .707 r
F P
0 g
s
.84247 .62874 m .84068 .5722 L .83337 .57857 L p .707 .577 .707 r
F P
0 g
s
.65567 .70297 m .65271 .66478 L .64037 .66308 L p .707 .577 .707 r
F P
0 g
s
.64037 .66308 m .64333 .70127 L .65567 .70297 L p .707 .577 .707 r
F P
0 g
s
.81785 .71291 m .81938 .73201 L .83557 .72832 L p .707 .577 .707 r
F P
0 g
s
.83557 .72832 m .83404 .70922 L .81785 .71291 L p .707 .577 .707 r
F P
0 g
s
.64143 .63815 m .63965 .58162 L .63699 .57541 L p .707 .577 .707 r
F P
0 g
s
.83361 .64948 m .83657 .68768 L .84386 .68431 L p .707 .577 .707 r
F P
0 g
s
.84386 .68431 m .8409 .64612 L .83361 .64948 L p .707 .577 .707 r
F P
0 g
s
.65489 .74418 m .65337 .72509 L .64068 .72353 L p .707 .577 .707 r
F P
0 g
s
.64068 .72353 m .64221 .74263 L .65489 .74418 L p .707 .577 .707 r
F P
0 g
s
.63699 .57541 m .63878 .63195 L .64143 .63815 L p .707 .577 .707 r
F P
0 g
s
.84068 .5722 m .84247 .62874 L .83981 .62253 L p .707 .577 .707 r
F P
0 g
s
.83981 .62253 m .83803 .566 L .84068 .5722 L p .707 .577 .707 r
F P
0 g
s
.64333 .70127 m .64037 .66308 L .63771 .66041 L p .707 .577 .707 r
F P
0 g
s
.83404 .70922 m .83557 .72832 L .84249 .72504 L p .707 .577 .707 r
F P
0 g
s
.84249 .72504 m .84096 .70594 L .83404 .70922 L p .707 .577 .707 r
F P
0 g
s
.63771 .66041 m .64067 .69861 L .64333 .70127 L p .707 .577 .707 r
F P
0 g
s
.63878 .63195 m .63699 .57541 L .6443 .56905 L p .707 .577 .707 r
F P
0 g
s
.8409 .64612 m .84386 .68431 L .8412 .68165 L p .707 .577 .707 r
F P
0 g
s
.8412 .68165 m .83824 .64345 L .8409 .64612 L p .707 .577 .707 r
F P
0 g
s
.64221 .74263 m .64068 .72353 L .63765 .72098 L p .707 .577 .707 r
F P
0 g
s
.63765 .72098 m .63917 .74008 L .64221 .74263 L p .707 .577 .707 r
F P
0 g
s
.6443 .56905 m .64609 .62558 L .63878 .63195 L p .707 .577 .707 r
F P
0 g
s
.83803 .566 m .83981 .62253 L .82745 .61709 L p .707 .577 .707 r
F P
0 g
s
.82745 .61709 m .82566 .56055 L .83803 .566 L p .707 .577 .707 r
F P
0 g
s
.64067 .69861 m .63771 .66041 L .645 .65705 L p .707 .577 .707 r
F P
0 g
s
.84096 .70594 m .84249 .72504 L .83945 .72249 L p .707 .577 .707 r
F P
0 g
s
.83945 .72249 m .83793 .7034 L .84096 .70594 L p .707 .577 .707 r
F P
0 g
s
.39069 .62393 m .38652 .56899 L .35549 .56895 L p .707 .577 .707 r
F P
0 g
s
.38652 .56899 m .39069 .62393 L .42247 .62095 L p .707 .577 .707 r
F P
0 g
s
.42247 .62095 m .4183 .56601 L .38652 .56899 L p .707 .577 .707 r
F P
0 g
s
.645 .65705 m .64796 .69524 L .64067 .69861 L p .707 .577 .707 r
F P
0 g
s
.4183 .56601 m .42247 .62095 L .45188 .61523 L p .707 .577 .707 r
F P
0 g
s
.45188 .61523 m .44771 .5603 L .4183 .56601 L p .707 .577 .707 r
F P
0 g
s
.64609 .62558 m .6443 .56905 L .66087 .56315 L p .707 .577 .707 r
F P
0 g
s
.35966 .62389 m .35549 .56895 L .32824 .5659 L p .707 .577 .707 r
F P
0 g
s
.35549 .56895 m .35966 .62389 L .39069 .62393 L p .707 .577 .707 r
F P
0 g
s
.44771 .5603 m .45188 .61523 L .47605 .60735 L p .707 .577 .707 r
F P
0 g
s
.47605 .60735 m .47187 .55241 L .44771 .5603 L p .707 .577 .707 r
F P
0 g
s
.83824 .64345 m .8412 .68165 L .82886 .67994 L p .707 .577 .707 r
F P
0 g
s
.82886 .67994 m .8259 .64175 L .83824 .64345 L p .707 .577 .707 r
F P
0 g
s
.63917 .74008 m .63765 .72098 L .64456 .7177 L p .707 .577 .707 r
F P
0 g
s
.64456 .7177 m .64609 .7368 L .63917 .74008 L p .707 .577 .707 r
F P
0 g
s
.66087 .56315 m .66266 .61968 L .64609 .62558 L p .707 .577 .707 r
F P
0 g
s
.82566 .56055 m .82745 .61709 L .80659 .61294 L p .707 .577 .707 r
F P
0 g
s
.80659 .61294 m .8048 .55641 L .82566 .56055 L p .707 .577 .707 r
F P
0 g
s
.33242 .62083 m .32824 .5659 L .30744 .56012 L p .707 .577 .707 r
F P
0 g
s
.32824 .5659 m .33242 .62083 L .35966 .62389 L p .707 .577 .707 r
F P
0 g
s
.39418 .68878 m .3873 .6532 L .35672 .65588 L p .707 .577 .707 r
F P
0 g
s
.3873 .6532 m .39418 .68878 L .42553 .68257 L p .707 .577 .707 r
F P
0 g
s
.42553 .68257 m .41865 .64699 L .3873 .6532 L p .707 .577 .707 r
F P
0 g
s
.41865 .64699 m .42553 .68257 L .4546 .67344 L p .707 .577 .707 r
F P
0 g
s
.4546 .67344 m .44772 .63786 L .41865 .64699 L p .707 .577 .707 r
F P
0 g
s
.64796 .69524 m .645 .65705 L .66152 .65331 L p .707 .577 .707 r
F P
0 g
s
.83793 .7034 m .83945 .72249 L .82677 .72094 L p .707 .577 .707 r
F P
0 g
s
.82677 .72094 m .82524 .70184 L .83793 .7034 L p .707 .577 .707 r
F P
0 g
s
.47187 .55241 m .47605 .60735 L .4926 .59807 L p .707 .577 .707 r
F P
0 g
s
.4926 .59807 m .48843 .54313 L .47187 .55241 L p .707 .577 .707 r
F P
0 g
s
.66152 .65331 m .66448 .69151 L .64796 .69524 L p .707 .577 .707 r
F P
0 g
s
.3636 .69146 m .35672 .65588 L .32991 .65477 L p .707 .577 .707 r
F P
0 g
s
.35672 .65588 m .3636 .69146 L .39418 .68878 L p .707 .577 .707 r
F P
0 g
s
.66266 .61968 m .66087 .56315 L .68507 .55829 L p .707 .577 .707 r
F P
0 g
s
.44772 .63786 m .4546 .67344 L .47853 .66228 L p .707 .577 .707 r
F P
0 g
s
.47853 .66228 m .47164 .6267 L .44772 .63786 L p .707 .577 .707 r
F P
0 g
s
.39201 .73133 m .38848 .71357 L .35785 .7165 L p .707 .577 .707 r
F P
0 g
s
.38848 .71357 m .39201 .73133 L .42331 .72486 L p .707 .577 .707 r
F P
0 g
s
.42331 .72486 m .41978 .7071 L .38848 .71357 L p .707 .577 .707 r
F P
0 g
s
.30744 .56012 m .31162 .61506 L .33242 .62083 L p .707 .577 .707 r
F P
0 g
s
.41978 .7071 m .42331 .72486 L .45221 .71547 L p .707 .577 .707 r
F P
0 g
s
.45221 .71547 m .44868 .69772 L .41978 .7071 L p .707 .577 .707 r
F P
0 g
s
.8259 .64175 m .82886 .67994 L .80805 .67937 L p .707 .577 .707 r
F P
0 g
s
.80805 .67937 m .80508 .64117 L .8259 .64175 L p .707 .577 .707 r
F P
0 g
s
.64609 .7368 m .64456 .7177 L .66076 .71401 L p .707 .577 .707 r
F P
0 g
s
.8048 .55641 m .80659 .61294 L .77926 .6105 L p .707 .577 .707 r
F P
0 g
s
.77926 .6105 m .77748 .55397 L .8048 .55641 L p .707 .577 .707 r
F P
0 g
s
.68507 .55829 m .68686 .61483 L .66266 .61968 L p .707 .577 .707 r
F P
0 g
s
.32991 .65477 m .33679 .69035 L .3636 .69146 L p .707 .577 .707 r
F P
0 g
s
.66076 .71401 m .66228 .73311 L .64609 .7368 L p .707 .577 .707 r
F P
0 g
s
.35785 .7165 m .36138 .73426 L .39201 .73133 L p .707 .577 .707 r
F P
0 g
s
.31162 .61506 m .30744 .56012 L .29513 .5522 L p .707 .577 .707 r
F P
0 g
s
.36138 .73426 m .35785 .7165 L .33087 .7156 L p .707 .577 .707 r
F P
0 g
s
.33679 .69035 m .32991 .65477 L .3095 .64998 L p .707 .577 .707 r
F P
0 g
s
.44868 .69772 m .45221 .71547 L .47587 .70409 L p .707 .577 .707 r
F P
0 g
s
.47587 .70409 m .47234 .68634 L .44868 .69772 L p .707 .577 .707 r
F P
0 g
s
.47164 .6267 m .47853 .66228 L .49497 .65019 L p .707 .577 .707 r
F P
0 g
s
.49497 .65019 m .48809 .61461 L .47164 .6267 L p .707 .577 .707 r
F P
0 g
s
.68686 .61483 m .68507 .55829 L .71453 .55496 L p .707 .577 .707 r
F P
0 g
s
.33087 .7156 m .3344 .73335 L .36138 .73426 L p .707 .577 .707 r
F P
0 g
s
.66448 .69151 m .66152 .65331 L .68565 .64958 L p .707 .577 .707 r
F P
0 g
s
.48843 .54313 m .4926 .59807 L .49993 .5883 L p .707 .577 .707 r
F P
0 g
s
.49993 .5883 m .49575 .53336 L .48843 .54313 L p .707 .577 .707 r
F P
0 g
s
.68565 .64958 m .68861 .68777 L .66448 .69151 L p .707 .577 .707 r
F P
0 g
s
.82524 .70184 m .82677 .72094 L .80567 .72052 L p .707 .577 .707 r
F P
0 g
s
.80567 .72052 m .80414 .70142 L .82524 .70184 L p .707 .577 .707 r
F P
0 g
s
.77748 .55397 m .77926 .6105 L .74816 .61 L p .707 .577 .707 r
F P
0 g
s
.74816 .61 m .74638 .55347 L .77748 .55397 L p .707 .577 .707 r
F P
0 g
s
.3095 .64998 m .31638 .68556 L .33679 .69035 L p .707 .577 .707 r
F P
0 g
s
.29513 .5522 m .29931 .60713 L .31162 .61506 L p .707 .577 .707 r
F P
0 g
s
.71453 .55496 m .71632 .61149 L .68686 .61483 L p .707 .577 .707 r
F P
0 g
s
.71632 .61149 m .71453 .55496 L .74638 .55347 L p .707 .577 .707 r
F P
0 g
s
.3344 .73335 m .33087 .7156 L .3102 .71095 L p .707 .577 .707 r
F P
0 g
s
.80508 .64117 m .80805 .67937 L .78079 .67998 L p .707 .577 .707 r
F P
0 g
s
.78079 .67998 m .77782 .64178 L .80508 .64117 L p .707 .577 .707 r
F P
0 g
s
.74638 .55347 m .74816 .61 L .71632 .61149 L p .707 .577 .707 r
F P
0 g
s
.47234 .68634 m .47587 .70409 L .49199 .69184 L p .707 .577 .707 r
F P
0 g
s
.49199 .69184 m .48846 .67408 L .47234 .68634 L p .707 .577 .707 r
F P
0 g
s
.66228 .73311 m .66076 .71401 L .68464 .71026 L p .707 .577 .707 r
F P
0 g
s
.3102 .71095 m .31373 .7287 L .3344 .73335 L p .707 .577 .707 r
F P
0 g
s
.68464 .71026 m .68616 .72936 L .66228 .73311 L p .707 .577 .707 r
F P
0 g
s
.31638 .68556 m .3095 .64998 L .29748 .64197 L p .707 .577 .707 r
F P
0 g
s
.29931 .60713 m .29513 .5522 L .29251 .54289 L p .707 .577 .707 r
F P
0 g
s
.68861 .68777 m .68565 .64958 L .71503 .6462 L p .707 .577 .707 r
F P
0 g
s
.48809 .61461 m .49497 .65019 L .50233 .63835 L p .707 .577 .707 r
F P
0 g
s
.50233 .63835 m .49545 .60276 L .48809 .61461 L p .707 .577 .707 r
F P
0 g
s
.71503 .6462 m .718 .68439 L .68861 .68777 L p .707 .577 .707 r
F P
0 g
s
.77782 .64178 m .78079 .67998 L .74976 .68171 L p .707 .577 .707 r
F P
0 g
s
.74976 .68171 m .7468 .64351 L .77782 .64178 L p .707 .577 .707 r
F P
0 g
s
.80414 .70142 m .80567 .72052 L .77822 .72127 L p .707 .577 .707 r
F P
0 g
s
.77822 .72127 m .77669 .70218 L .80414 .70142 L p .707 .577 .707 r
F P
0 g
s
.49575 .53336 m .49993 .5883 L .49731 .579 L p .707 .577 .707 r
F P
0 g
s
.49731 .579 m .49313 .52406 L .49575 .53336 L p .707 .577 .707 r
F P
0 g
s
.29748 .64197 m .30436 .67755 L .31638 .68556 L p .707 .577 .707 r
F P
0 g
s
.718 .68439 m .71503 .6462 L .7468 .64351 L p .707 .577 .707 r
F P
0 g
s
.31373 .7287 m .3102 .71095 L .29785 .70301 L p .707 .577 .707 r
F P
0 g
s
.7468 .64351 m .74976 .68171 L .718 .68439 L p .707 .577 .707 r
F P
0 g
s
.68616 .72936 m .68464 .71026 L .71387 .70682 L p .707 .577 .707 r
F P
0 g
s
.29251 .54289 m .29668 .59783 L .29931 .60713 L p .707 .577 .707 r
F P
0 g
s
.48846 .67408 m .49199 .69184 L .49898 .6799 L p .707 .577 .707 r
F P
0 g
s
.49898 .6799 m .49545 .66214 L .48846 .67408 L p .707 .577 .707 r
F P
0 g
s
.71387 .70682 m .7154 .72592 L .68616 .72936 L p .707 .577 .707 r
F P
0 g
s
.29785 .70301 m .30138 .72077 L .31373 .7287 L p .707 .577 .707 r
F P
0 g
s
.77669 .70218 m .77822 .72127 L .74712 .72314 L p .707 .577 .707 r
F P
0 g
s
.74712 .72314 m .74559 .70404 L .77669 .70218 L p .707 .577 .707 r
F P
0 g
s
.30436 .67755 m .29748 .64197 L .29503 .63153 L p .708 .578 .707 r
F P
0 g
s
.7154 .72592 m .71387 .70682 L .74559 .70404 L p .707 .577 .707 r
F P
0 g
s
.49545 .60276 m .50233 .63835 L .49988 .62791 L p .708 .578 .707 r
F P
0 g
s
.49988 .62791 m .493 .59233 L .49545 .60276 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29668 .59783 m .29251 .54289 L .29984 .53312 L p .707 .577 .707 r
F P
0 g
s
.74559 .70404 m .74712 .72314 L .7154 .72592 L p .707 .577 .707 r
F P
0 g
s
.29503 .63153 m .30191 .66711 L .30436 .67755 L p .708 .578 .707 r
F P
0 g
s
.49313 .52406 m .49731 .579 L .48499 .57107 L p .707 .577 .707 r
F P
0 g
s
.48499 .57107 m .48082 .51613 L .49313 .52406 L p .707 .577 .707 r
F P
0 g
s
.30138 .72077 m .29785 .70301 L .29503 .69256 L p .707 .578 .707 r
F P
0 g
s
.49545 .66214 m .49898 .6799 L .49616 .66945 L p .707 .578 .707 r
F P
0 g
s
.49616 .66945 m .49263 .65169 L .49545 .66214 L p .707 .578 .707 r
F P
0 g
s
.29984 .53312 m .30401 .58806 L .29668 .59783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29503 .69256 m .29856 .71032 L .30138 .72077 L p .707 .578 .707 r
F P
0 g
s
.30191 .66711 m .29503 .63153 L .30239 .61969 L p .707 .577 .707 r
F P
0 g
s
.493 .59233 m .49988 .62791 L .48786 .6199 L p .707 .577 .707 r
F P
0 g
s
.48786 .6199 m .48098 .58432 L .493 .59233 L p .707 .577 .707 r
F P
0 g
s
.30401 .58806 m .29984 .53312 L .31639 .52384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30239 .61969 m .30927 .65527 L .30191 .66711 L p .707 .577 .707 r
F P
0 g
s
.48082 .51613 m .48499 .57107 L .46419 .56529 L p .707 .577 .707 r
F P
0 g
s
.46419 .56529 m .46002 .51036 L .48082 .51613 L p .707 .577 .707 r
F P
0 g
s
.29856 .71032 m .29503 .69256 L .30202 .68063 L p .707 .577 .707 r
F P
0 g
s
.31639 .52384 m .32057 .57878 L .30401 .58806 L p .707 .577 .707 r
F P
0 g
s
.49263 .65169 m .49616 .66945 L .48381 .66151 L p .707 .577 .707 r
F P
0 g
s
.48381 .66151 m .48028 .64376 L .49263 .65169 L p .707 .577 .707 r
F P
0 g
s
.30202 .68063 m .30555 .69838 L .29856 .71032 L p .707 .577 .707 r
F P
0 g
s
.32057 .57878 m .31639 .52384 L .34056 .51596 L p .707 .577 .707 r
F P
0 g
s
.30927 .65527 m .30239 .61969 L .31884 .6076 L p .707 .577 .707 r
F P
0 g
s
.48098 .58432 m .48786 .6199 L .46745 .61511 L p .707 .577 .707 r
F P
0 g
s
.46745 .61511 m .46057 .57953 L .48098 .58432 L p .707 .577 .707 r
F P
0 g
s
.46002 .51036 m .46419 .56529 L .43695 .56224 L p .707 .577 .707 r
F P
0 g
s
.43695 .56224 m .43277 .5073 L .46002 .51036 L p .707 .577 .707 r
F P
0 g
s
.31884 .6076 m .32572 .64318 L .30927 .65527 L p .707 .577 .707 r
F P
0 g
s
.30555 .69838 m .30202 .68063 L .31814 .66837 L p .707 .577 .707 r
F P
0 g
s
.34056 .51596 m .34473 .57089 L .32057 .57878 L p .707 .577 .707 r
F P
0 g
s
.34473 .57089 m .34056 .51596 L .36997 .51025 L p .707 .577 .707 r
F P
0 g
s
.48028 .64376 m .48381 .66151 L .46314 .65686 L p .707 .577 .707 r
F P
0 g
s
.46314 .65686 m .45961 .63911 L .48028 .64376 L p .707 .577 .707 r
F P
0 g
s
.31814 .66837 m .32167 .68612 L .30555 .69838 L p .707 .577 .707 r
F P
0 g
s
.43277 .5073 m .43695 .56224 L .40592 .5622 L p .707 .577 .707 r
F P
0 g
s
.40592 .5622 m .40174 .50726 L .43277 .5073 L p .707 .577 .707 r
F P
0 g
s
.32572 .64318 m .31884 .6076 L .34276 .59644 L p .707 .577 .707 r
F P
0 g
s
.46057 .57953 m .46745 .61511 L .44064 .614 L p .707 .577 .707 r
F P
0 g
s
.44064 .614 m .43376 .57842 L .46057 .57953 L p .707 .577 .707 r
F P
0 g
s
.37414 .56518 m .36997 .51025 L .40174 .50726 L p .707 .577 .707 r
F P
0 g
s
.36997 .51025 m .37414 .56518 L .34473 .57089 L p .707 .577 .707 r
F P
0 g
s
.40174 .50726 m .40592 .5622 L .37414 .56518 L p .707 .577 .707 r
F P
0 g
s
.34276 .59644 m .34964 .63202 L .32572 .64318 L p .707 .577 .707 r
F P
0 g
s
.32167 .68612 m .31814 .66837 L .3418 .65699 L p .707 .577 .707 r
F P
0 g
s
.34964 .63202 m .34276 .59644 L .37183 .58731 L p .707 .577 .707 r
F P
0 g
s
.45961 .63911 m .46314 .65686 L .43616 .65596 L p .707 .577 .707 r
F P
0 g
s
.43616 .65596 m .43263 .6382 L .45961 .63911 L p .707 .577 .707 r
F P
0 g
s
.43376 .57842 m .44064 .614 L .41006 .61668 L p .707 .577 .707 r
F P
0 g
s
.41006 .61668 m .40318 .5811 L .43376 .57842 L p .707 .577 .707 r
F P
0 g
s
.3418 .65699 m .34533 .67474 L .32167 .68612 L p .707 .577 .707 r
F P
0 g
s
.37871 .62289 m .37183 .58731 L .40318 .5811 L p .707 .577 .707 r
F P
0 g
s
.37183 .58731 m .37871 .62289 L .34964 .63202 L p .707 .577 .707 r
F P
0 g
s
.40318 .5811 m .41006 .61668 L .37871 .62289 L p .707 .577 .707 r
F P
0 g
s
.34533 .67474 m .3418 .65699 L .3707 .6476 L p .707 .577 .707 r
F P
0 g
s
.43263 .6382 m .43616 .65596 L .40552 .65889 L p .707 .577 .707 r
F P
0 g
s
.40552 .65889 m .40199 .64113 L .43263 .6382 L p .707 .577 .707 r
F P
0 g
s
.3707 .6476 m .37423 .66536 L .34533 .67474 L p .707 .577 .707 r
F P
0 g
s
.37423 .66536 m .3707 .6476 L .40199 .64113 L p .707 .577 .707 r
F P
0 g
s
.40199 .64113 m .40552 .65889 L .37423 .66536 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00L7oo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF4P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol90004FUH00`00FUIJEP06FUH01000FUIJEUYF1P002EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001OOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040005
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool005]oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00F7oo0P001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJ
EP00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
05Ioo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001EOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ao
o`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP06001JEUYF001JEP002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0000?OolI000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00009Ool60004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03FUH01000FUIJEUYF
0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001Goo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@00<Goo
001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH015YF4`0015YF1P0015YF00@005YF
FUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00l0
00=JEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF009JEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP02FUH400000eYF001JEP06FUH60003FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo00<005YF
000015YF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP800003FUH0000000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03
001JEP0000AJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEPh0009JEP03001JEUYF009JEP@0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00AJEP03001JEP0000<000=JEP04001JEP00000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH01000FUIJEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00E7oo00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<00004FUH005YF000;FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001J
EP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP04000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000oOolB0003Ool20002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo000iOol60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP03
FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool003Ioo`<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP80009JEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Goo000cOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1@00FUIJEP00FUH00P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00<Goo0P0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1P001eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJ
EP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF0000
05YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP02
000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJ
EP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000]Ool002io
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL0009JEP@0009JEP03001JEUYF009J
EP<00004FUH005YFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40002FUH2000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@0009JEPL000IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP@00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPX0009JEP03001JEUYF00QJEP03001JEUYF00=J
EP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00@000=JEP03001JEP00008000AJEP03001JEUYF00QJEP04001JEUYFFUH20004FUH01000
FUH000002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF1000
00=JEP00FUH015YF1P000eYF00<005YFFUH025YF00H005YF000005YF0004FUH01000FUIJEP002eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00@005YFFUIJEP<0009JEP03001JEP0000EJEPH0
00=JEP03001JEUYF00QJEP8000=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP001EYF00@005YF0000009JEP06001JEUYF001JEP001EYF1P000eYF3P000eYF00D0
05YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP8000AJEP06001JEUYF001J
EP001EYF00<005YF00001`000eYF00<005YFFUH01EYF00<005YF00000`0015YF0`002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF5P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH20005FUH01P00FUIJEP00FUH000AJ
EP@0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00EJEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP04FUH01@00FUIJEP00FUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`0000AJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEP00FUH>0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJ
EP060005FUH00`00FUH0000300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUH00003000>Ool50004Ool50002FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH=0004FUH01P00FUIJEP00FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001J
EP0000AJEP80009JEP03001JEP0000<000Yoo`D000Uoo`04FUH005YF0004FUH00`00FUH000020008
FUH00`00FUIJEP04FUH70008FUH00`00FUIJEP02FUH300001eYF001JEUYF001JEP0000]JEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP00009JEP8000AJEP03001JEUYF00=JEPl000Uoo`04FUH005YF0004FUH2
0002FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH000030005FUH00`00FUIJEP050004FUH0
0`00FUIJEP02FUH>0002FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF0P0000=JEP0000002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00;7oo00<005YF00000UYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000AJEP00FUH000MJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP000006FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000001eYF0`0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP0002eoo`00;7oo0P000eYF00<005YFFUH00P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000UYF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0000=JEP00FUH01UYF0P000UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`80
00=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF008000IJEP03001JEUYF00IJEP<000IJEP03001JEP00008000AJEP03001JEUYF00AJEP03
001JEP00009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQl002eoo`00;7oo0P000UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF
0`0000=JEP00FUH01UYF00<005YFFUH015YF1@000UYF1@001eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH300000eYF001JEP06FUH00`00FUIJEP02FUH9
00000eYF001JEP09FUH01000FUIJEUYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPT000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<002ioo`00;Goo0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP800003
FUH005YF00h00003FUH0000000@000=JEP03001JEUYF00QJEP06001JEP00001JEP0015YF00@005YF
FUH000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH60007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000^Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP030003FUH00`00FUIJEP03FUH400000eYF001JEP04FUH00`00FUH000020004FUH00`00FUIJEP08
FUH20003FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPP003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
0UYF200015YF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF00AJEP06001JEP00001JEP00
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@00?goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH60008FUH90004FUH20005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP800003FUH005YF00IJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEPP000=JEP03001JEUYF009JEQ0000=ooa@0035oo`00;Goo0P00
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF1P001EYF00<005YFFUH015YF
00H005YFFUH005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
00000eYF000000060002FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000]
Ool002eoo`8000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P00
0eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP03FUH60007FUH01000FUIJ
EUYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF00000eYF10000UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF0P001Goo10000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEP80009JEP@000EJEP07001JEUYFFUH005YF00000UYF2@0015YF
00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP00008000]oo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH?0004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
1000FUH000004goo4`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH2000]Ool002ao
o`<00003FUH007oo00eoo`P000moo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0005FUH9000]Ool002aoo`<0009JEP03001oogoo00Eoo`H000=JEP03001JEUYF009J
EPT000Moo`<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPH000MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0002eoo`00;7oo0P000eYF0`000goo0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000goo0`000eYF00<005YFFUH015YF00<005YFFUH00UYF2@00
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;7oo0P000eYF00<005YFFUH00`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000Aoo`l0009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00009JEPH000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH5000bOol002aoo`8000=JEP04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0027oo0`0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`001EYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2000=goo000/Ool20003FUH30006FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004Ool200001EYF000005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
0UYF4P00?goo000]Ool00`00FUIJEP0200000eYF001JEP04FUH60008Ool90004FUH00`00FUIJEP05
FUH50003FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP04FUH<
0006FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUHG001AOol002eoo`03001JEP00
00=JEP04001JEUYFFUH20004FUH4000?Ool60006FUH00`00FUIJEP020003FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH<0005FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUH00002001JOol002ioo`8000=JEP03001JEP00
008000MJEP03001JEP0000<0015oo`8000AJEP03001JEUYF009JEP800005FUH00000FUH00005FUH0
0`00FUIJEP05FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80007FUH0
0`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP02FUH2001HOol002ioo`8000=JEP80009JEP03
001JEUYF00EJEP03001JEUYF00=JEQ40009JEP<00003FUH005YF00AJEP@00003FUH005YF00AJEP03
001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP00
008000AJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP<005Ioo`00;Goo0P000UYF
0P000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
000000EJEP06001JEP00001JEP001EYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YF
00001EYF00<005YFFUH015YF00@005YFFUH005Eoo`00;Goo10001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP00
1EYF0P001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF0P001EYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00;Goo
0P000Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF0P0000MJEP00FUIJEP00FUH00003FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30003FUH00`00FUH00005FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20005Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000000UYF00@005YF
001JEP800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0005FUH00`00FUIJEP03FUH01P00
FUIJEP00FUH005Aoo`00;7oo0`001Woo0`001UYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00P000eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00H005YFFUH005YF001DOol002aoo`03001JEP00
00Uoo`8000AJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003Ool0
05YF00<000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03001JEUYF00AJEP03001JEUYF
008005Eoo`00;7oo00@005YF000000Yoo`<00003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000Aoo`@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP@000AJEP04
001JEUYFFUH2001EOol002aoo`80009JEP03001oogoo00Yoo`@000IJEPD000AJEP03001JEUYF00EJ
EP03001JEP0000<000Moo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00
FUH00004FUH300000eYF001JEP02FUH2001EOol002eoo`05001JEUYFFUH0000?Ool40002FUH40005
FUH00`00FUIJEP02FUH5000;Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP04FUH30003FUH2001EOol002eoo`04001JEUYFFUH3000AOol@000@Ool30004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH02000FUIJEP00FUH005YF001E
Ool002ioo`04001JEUYF0002FUH00`00Oomoo`0^Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH300000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00Ool0E7oo000_Ool00`00FUH00003FUH2
000/Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000006FUH00`00FUIJEP02
FUH2001FOol0031oo`8000EJEP8002Qoo`80009JEP03001oogoo0080009JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP02FUH30003FUH01000FUIJEUYF0`00EWoo000aOol00`00FUIJEP03
FUH00`00FUH00003000ROol20003FUH20004Ool30008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01EYF
0`0015YF00<005YF0000EWoo000bOol20003FUH00`00FUIJEP03FUH5000IOol400000eYF001JEP02
FUH00`00Oomoo`05Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP06FUH00`00FUH00005001GOol003Aoo`04
001JEUYF0007FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF00002Woo10000UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH010000Woo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00F7oo000eOol30007FUH00`00FUIJEP04FUH@0003
FUH00`00FUIJEP04FUH01000FUIJEP003goo1@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2P001Goo10001UYF00<005YFFUH015YF0`00EWoo000gOol20006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000EOol60003FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Goo1@002Goo10000UYF00<005YFFUH015YF00@005YF
FUH005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P007Goo80000eYF00<005YF00000`000Woo1@003Goo100015YF00D005YFFUIJEP0005Eo
o`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Woo0P0000=JEP00
FUH01eYF00<005YFFUH00eYF1`004Goo0`0000=JEP00FUH00UYF0P00E7oo0011Ool40002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH6000lOol30006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000;
Ool20002FUH00`00FUH0001DOol004Eooa0004Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPh00004FUH005YF001DOol009ioo`@000IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH3001EOol00:9oo`@0009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00YWoo1@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000EGoo002[Ool40002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2001FOol00:mooaL005Moo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]32\[InvisibleSpace]"     "\
\[InvisibleSpace]10.246105061388016`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 32, "     ", 10.246105061388016, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59595 .74008 m .59897 .68303 L .56781 .68044 L p .707 .577 .707 r
F P
0 g
s
.59897 .68303 m .59595 .74008 L .62774 .7413 L p .707 .577 .707 r
F P
0 g
s
.62774 .7413 m .63075 .68425 L .59897 .68303 L p .707 .577 .707 r
F P
0 g
s
.63075 .68425 m .62774 .7413 L .65703 .74104 L p .707 .577 .707 r
F P
0 g
s
.65703 .74104 m .66005 .68399 L .63075 .68425 L p .707 .577 .707 r
F P
0 g
s
.5648 .73749 m .56781 .68044 L .54034 .67673 L p .707 .577 .707 r
F P
0 g
s
.56781 .68044 m .5648 .73749 L .59595 .74008 L p .707 .577 .707 r
F P
0 g
s
.59412 .7871 m .59749 .74883 L .56636 .74576 L p .707 .577 .707 r
F P
0 g
s
.59749 .74883 m .59412 .7871 L .62581 .78972 L p .707 .577 .707 r
F P
0 g
s
.62581 .78972 m .62917 .75145 L .59749 .74883 L p .707 .577 .707 r
F P
0 g
s
.54034 .67673 m .53732 .73378 L .5648 .73749 L p .707 .577 .707 r
F P
0 g
s
.66005 .68399 m .65703 .74104 L .68098 .73932 L p .707 .577 .707 r
F P
0 g
s
.68098 .73932 m .68399 .68227 L .66005 .68399 L p .707 .577 .707 r
F P
0 g
s
.56636 .74576 m .563 .78403 L .59412 .7871 L p .707 .577 .707 r
F P
0 g
s
.62917 .75145 m .62581 .78972 L .65495 .79162 L p .707 .577 .707 r
F P
0 g
s
.65495 .79162 m .65832 .75335 L .62917 .75145 L p .707 .577 .707 r
F P
0 g
s
.563 .78403 m .56636 .74576 L .53885 .74254 L p .707 .577 .707 r
F P
0 g
s
.53732 .73378 m .54034 .67673 L .51923 .67228 L p .707 .577 .707 r
F P
0 g
s
.53885 .74254 m .53549 .78081 L .563 .78403 L p .707 .577 .707 r
F P
0 g
s
.51923 .67228 m .51621 .72933 L .53732 .73378 L p .707 .577 .707 r
F P
0 g
s
.65832 .75335 m .65495 .79162 L .67871 .79263 L p .707 .577 .707 r
F P
0 g
s
.67871 .79263 m .68207 .75436 L .65832 .75335 L p .707 .577 .707 r
F P
0 g
s
.59635 .83763 m .59695 .81877 L .56579 .81645 L p .707 .577 .707 r
F P
0 g
s
.59695 .81877 m .59635 .83763 L .62816 .83805 L p .707 .577 .707 r
F P
0 g
s
.62816 .83805 m .62877 .81919 L .59695 .81877 L p .707 .577 .707 r
F P
0 g
s
.62877 .81919 m .62816 .83805 L .65752 .83654 L p .707 .577 .707 r
F P
0 g
s
.65752 .83654 m .65812 .81767 L .62877 .81919 L p .707 .577 .707 r
F P
0 g
s
.56579 .81645 m .56518 .83532 L .59635 .83763 L p .707 .577 .707 r
F P
0 g
s
.53549 .78081 m .53885 .74254 L .51765 .73948 L p .707 .577 .707 r
F P
0 g
s
.68399 .68227 m .68098 .73932 L .69724 .7363 L p .707 .577 .707 r
F P
0 g
s
.69724 .7363 m .70025 .67925 L .68399 .68227 L p .707 .577 .707 r
F P
0 g
s
.51765 .73948 m .51429 .77775 L .53549 .78081 L p .707 .577 .707 r
F P
0 g
s
.56518 .83532 m .56579 .81645 L .53832 .81247 L p .707 .577 .707 r
F P
0 g
s
.53832 .81247 m .53772 .83134 L .56518 .83532 L p .707 .577 .707 r
F P
0 g
s
.51621 .72933 m .51923 .67228 L .50655 .66751 L p .707 .577 .707 r
F P
0 g
s
.65812 .81767 m .65752 .83654 L .68153 .83324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83324 m .68214 .81437 L .65812 .81767 L p .707 .577 .707 r
F P
0 g
s
.68207 .75436 m .67871 .79263 L .69475 .79264 L p .707 .577 .707 r
F P
0 g
s
.69475 .79264 m .69811 .75437 L .68207 .75436 L p .707 .577 .707 r
F P
0 g
s
.50655 .66751 m .50354 .72456 L .51621 .72933 L p .707 .577 .707 r
F P
0 g
s
.53772 .83134 m .53832 .81247 L .51725 .80722 L p .707 .577 .707 r
F P
0 g
s
.51725 .80722 m .51664 .82608 L .53772 .83134 L p .707 .577 .707 r
F P
0 g
s
.51429 .77775 m .51765 .73948 L .50482 .73688 L p .707 .577 .707 r
F P
0 g
s
.50482 .73688 m .50146 .77515 L .51429 .77775 L p .707 .577 .707 r
F P
0 g
s
.70025 .67925 m .69724 .7363 L .7042 .73229 L p .707 .577 .707 r
F P
0 g
s
.7042 .73229 m .70721 .67524 L .70025 .67925 L p .707 .577 .707 r
F P
0 g
s
.68214 .81437 m .68153 .83324 L .69786 .82847 L p .707 .577 .707 r
F P
0 g
s
.69786 .82847 m .69846 .80961 L .68214 .81437 L p .707 .577 .707 r
F P
0 g
s
.50354 .72456 m .50655 .66751 L .50355 .6629 L p .707 .577 .707 r
F P
0 g
s
.51664 .82608 m .51725 .80722 L .50462 .8012 L p .707 .577 .707 r
F P
0 g
s
.69811 .75437 m .69475 .79264 L .7015 .79166 L p .707 .577 .707 r
F P
0 g
s
.7015 .79166 m .70486 .75339 L .69811 .75437 L p .707 .577 .707 r
F P
0 g
s
.50462 .8012 m .50402 .82006 L .51664 .82608 L p .707 .577 .707 r
F P
0 g
s
.50355 .6629 m .50054 .71995 L .50354 .72456 L p .707 .577 .707 r
F P
0 g
s
.50146 .77515 m .50482 .73688 L .50163 .73499 L p .707 .577 .707 r
F P
0 g
s
.49657 .82399 m .48694 .32918 L .44293 .32683 L p .707 .577 .707 r
F P
0 g
s
.50163 .73499 m .49826 .77326 L .50146 .77515 L p .707 .577 .707 r
F P
0 g
s
.50054 .71995 m .50355 .6629 L .51052 .65889 L p .707 .577 .707 r
F P
0 g
s
.50402 .82006 m .50462 .8012 L .50169 .795 L p .707 .577 .707 r
F P
0 g
s
.50169 .795 m .50109 .81387 L .50402 .82006 L p .707 .577 .707 r
F P
0 g
s
.51052 .65889 m .5075 .71594 L .50054 .71995 L p .707 .577 .707 r
F P
0 g
s
.49826 .77326 m .50163 .73499 L .50838 .73401 L p .707 .577 .707 r
F P
0 g
s
.50838 .73401 m .50502 .77228 L .49826 .77326 L p .707 .577 .707 r
F P
0 g
s
.5075 .71594 m .51052 .65889 L .52677 .65587 L p .707 .577 .707 r
F P
0 g
s
.50109 .81387 m .50169 .795 L .50873 .78924 L p .707 .577 .707 r
F P
0 g
s
.50873 .78924 m .50813 .80811 L .50109 .81387 L p .707 .577 .707 r
F P
0 g
s
.52677 .65587 m .52376 .71292 L .5075 .71594 L p .707 .577 .707 r
F P
0 g
s
.50502 .77228 m .50838 .73401 L .52442 .73402 L p .707 .577 .707 r
F P
0 g
s
.52442 .73402 m .52106 .77229 L .50502 .77228 L p .707 .577 .707 r
F P
0 g
s
.52376 .71292 m .52677 .65587 L .55072 .65415 L p .707 .577 .707 r
F P
0 g
s
.50813 .80811 m .50873 .78924 L .52506 .78448 L p .707 .577 .707 r
F P
0 g
s
.52506 .78448 m .52445 .80335 L .50813 .80811 L p .707 .577 .707 r
F P
0 g
s
.55072 .65415 m .5477 .7112 L .52376 .71292 L p .707 .577 .707 r
F P
0 g
s
.52106 .77229 m .52442 .73402 L .54817 .73503 L p .707 .577 .707 r
F P
0 g
s
.54817 .73503 m .54481 .7733 L .52106 .77229 L p .707 .577 .707 r
F P
0 g
s
.52445 .80335 m .52506 .78448 L .54907 .78118 L p .707 .577 .707 r
F P
0 g
s
.54907 .78118 m .54847 .80005 L .52445 .80335 L p .707 .577 .707 r
F P
0 g
s
.48694 .32918 m .49657 .82399 L .5415 .82192 L p .707 .577 .707 r
F P
0 g
s
.5415 .82192 m .53187 .32711 L .48694 .32918 L p .707 .577 .707 r
F P
0 g
s
.5477 .7112 m .55072 .65415 L .58002 .65389 L p .707 .577 .707 r
F P
0 g
s
.58002 .65389 m .577 .71094 L .5477 .7112 L p .707 .577 .707 r
F P
0 g
s
.54481 .7733 m .54817 .73503 L .57732 .73693 L p .707 .577 .707 r
F P
0 g
s
.57732 .73693 m .57396 .7752 L .54481 .7733 L p .707 .577 .707 r
F P
0 g
s
.57396 .7752 m .57732 .73693 L .60901 .73955 L p .707 .577 .707 r
F P
0 g
s
.60901 .73955 m .60564 .77782 L .57396 .7752 L p .707 .577 .707 r
F P
0 g
s
.54847 .80005 m .54907 .78118 L .57842 .77967 L p .707 .577 .707 r
F P
0 g
s
.57842 .77967 m .57782 .79853 L .54847 .80005 L p .707 .577 .707 r
F P
0 g
s
.57782 .79853 m .57842 .77967 L .61024 .78008 L p .707 .577 .707 r
F P
0 g
s
.61024 .78008 m .60964 .79895 L .57782 .79853 L p .707 .577 .707 r
F P
0 g
s
.53187 .32711 m .5415 .82192 L .58297 .81563 L p .707 .577 .707 r
F P
0 g
s
.577 .71094 m .58002 .65389 L .6118 .65511 L p .707 .577 .707 r
F P
0 g
s
.6118 .65511 m .60879 .71216 L .577 .71094 L p .707 .577 .707 r
F P
0 g
s
.58297 .81563 m .57334 .32082 L .53187 .32711 L p .707 .577 .707 r
F P
0 g
s
.70721 .67524 m .7042 .73229 L .7012 .72768 L p .707 .577 .707 r
F P
0 g
s
.7012 .72768 m .70421 .67062 L .70721 .67524 L p .707 .577 .707 r
F P
0 g
s
.69846 .80961 m .69786 .82847 L .7049 .82271 L p .707 .577 .707 r
F P
0 g
s
.7049 .82271 m .7055 .80385 L .69846 .80961 L p .707 .577 .707 r
F P
0 g
s
.45256 .82164 m .44293 .32683 L .40417 .3203 L p .707 .577 .707 r
F P
0 g
s
.44293 .32683 m .45256 .82164 L .49657 .82399 L p .707 .577 .707 r
F P
0 g
s
.64013 .74262 m .63676 .78089 L .61419 .77866 L p .707 .577 .707 r
F P
0 g
s
.61419 .77866 m .60564 .77782 L p .61464 .76864 L .707 .577 .707 r
F P
0 g
s
.61464 .76864 m .64013 .74262 L .61419 .77866 L .707 .577 .707 r
F
.67043 .6614 m .66742 .71845 L .63994 .71475 L p F P
0 g
s
.63994 .71475 m .64295 .6577 L .67043 .6614 L p .707 .577 .707 r
F P
0 g
s
.64295 .6577 m .63994 .71475 L .60879 .71216 L p .707 .577 .707 r
F P
0 g
s
.60879 .71216 m .6118 .65511 L .64295 .6577 L p .707 .577 .707 r
F P
0 g
s
.66764 .74584 m .66427 .78411 L .63676 .78089 L p .707 .577 .707 r
F P
0 g
s
.63676 .78089 m .64013 .74262 L .66764 .74584 L p .707 .577 .707 r
F P
0 g
s
.6408 .80126 m .64141 .7824 L .66887 .78638 L p .707 .577 .707 r
F P
0 g
s
.60564 .77782 m .60901 .73955 L .64013 .74262 L p .707 .577 .707 r
F P
0 g
s
.64141 .7824 m .6408 .80126 L .60964 .79895 L p .707 .577 .707 r
F P
0 g
s
.60964 .79895 m .61024 .78008 L .64141 .7824 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .64997 .77928 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63037 .2984 m .63192 .37812 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63192 .37812 m .63999 .79321 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.57334 .32082 m .58297 .81563 L .61691 .80574 L p .707 .577 .707 r
F P
0 g
s
.61691 .80574 m .60728 .31093 L .57334 .32082 L p .707 .577 .707 r
F P
0 g
s
.70486 .75339 m .7015 .79166 L .69831 .78977 L p .707 .577 .707 r
F P
0 g
s
.69831 .78977 m .70167 .7515 L .70486 .75339 L p .707 .577 .707 r
F P
0 g
s
.41379 .81511 m .40417 .3203 L .37443 .31021 L p .707 .577 .707 r
F P
0 g
s
.40417 .3203 m .41379 .81511 L .45256 .82164 L p .707 .577 .707 r
F P
0 g
s
.7055 .80385 m .7049 .82271 L .70196 .81652 L p .707 .577 .707 r
F P
0 g
s
.70196 .81652 m .70257 .79765 L .7055 .80385 L p .707 .577 .707 r
F P
0 g
s
.70421 .67062 m .7012 .72768 L .68852 .72291 L p .707 .577 .707 r
F P
0 g
s
.68852 .72291 m .69154 .66586 L .70421 .67062 L p .707 .577 .707 r
F P
0 g
s
.25295 .70326 m .25596 .64621 L .2248 .64362 L p .707 .577 .707 r
F P
0 g
s
.25596 .64621 m .25295 .70326 L .28473 .70449 L p .707 .577 .707 r
F P
0 g
s
.28473 .70449 m .28774 .64744 L .25596 .64621 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28774 .64744 m .28473 .70449 L .31403 .70422 L p .707 .577 .707 r
F P
0 g
s
.31403 .70422 m .31704 .64717 L .28774 .64744 L p .707 .577 .707 r
F P
0 g
s
.22179 .70067 m .2248 .64362 L .19733 .63992 L p .707 .577 .707 r
F P
0 g
s
.2248 .64362 m .22179 .70067 L .25295 .70326 L p .707 .577 .707 r
F P
0 g
s
.60728 .31093 m .61691 .80574 L .63999 .79321 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .63037 .2984 L .60728 .31093 L p .707 .577 .707 r
F P
0 g
s
.70167 .7515 m .69831 .78977 L .68548 .78717 L p .707 .577 .707 r
F P
0 g
s
.68548 .78717 m .68884 .7489 L .70167 .7515 L p .707 .577 .707 r
F P
0 g
s
.25111 .75029 m .25448 .71202 L .22336 .70895 L p .707 .577 .707 r
F P
0 g
s
.25448 .71202 m .25111 .75029 L .2828 .7529 L p .707 .577 .707 r
F P
0 g
s
.2828 .7529 m .28616 .71463 L .25448 .71202 L p .707 .577 .707 r
F P
0 g
s
.19733 .63992 m .19431 .69697 L .22179 .70067 L p .707 .577 .707 r
F P
0 g
s
.31704 .64717 m .31403 .70422 L .33797 .7025 L p .707 .577 .707 r
F P
0 g
s
.33797 .7025 m .34099 .64545 L .31704 .64717 L p .707 .577 .707 r
F P
0 g
s
.22336 .70895 m .21999 .74722 L .25111 .75029 L p .707 .577 .707 r
F P
0 g
s
.28616 .71463 m .2828 .7529 L .31194 .75481 L p .707 .577 .707 r
F P
0 g
s
.31194 .75481 m .31531 .71654 L .28616 .71463 L p .707 .577 .707 r
F P
0 g
s
.21999 .74722 m .22336 .70895 L .19585 .70572 L p .707 .577 .707 r
F P
0 g
s
.19431 .69697 m .19733 .63992 L .17622 .63547 L p .707 .577 .707 r
F P
0 g
s
.38406 .80502 m .37443 .31021 L .35664 .29756 L p .707 .577 .707 r
F P
0 g
s
.37443 .31021 m .38406 .80502 L .41379 .81511 L p .707 .577 .707 r
F P
0 g
s
.19585 .70572 m .19248 .74399 L .21999 .74722 L p .707 .577 .707 r
F P
0 g
s
.69154 .66586 m .68852 .72291 L .66742 .71845 L p .707 .577 .707 r
F P
0 g
s
.66742 .71845 m .67043 .6614 L .69154 .66586 L p .707 .577 .707 r
F P
0 g
s
.70257 .79765 m .70196 .81652 L .68934 .8105 L p .707 .577 .707 r
F P
0 g
s
.68934 .8105 m .68995 .79163 L .70257 .79765 L p .707 .577 .707 r
F P
0 g
s
.17622 .63547 m .17321 .69252 L .19431 .69697 L p .707 .577 .707 r
F P
0 g
s
.31531 .71654 m .31194 .75481 L .3357 .75581 L p .707 .577 .707 r
F P
0 g
s
.3357 .75581 m .33906 .71754 L .31531 .71654 L p .707 .577 .707 r
F P
0 g
s
.25334 .80082 m .25394 .78195 L .22278 .77964 L p .707 .577 .707 r
F P
0 g
s
.25394 .78195 m .25334 .80082 L .28515 .80124 L p .707 .577 .707 r
F P
0 g
s
.28515 .80124 m .28576 .78237 L .25394 .78195 L p .707 .577 .707 r
F P
0 g
s
.28576 .78237 m .28515 .80124 L .31451 .79972 L p .707 .577 .707 r
F P
0 g
s
.31451 .79972 m .31511 .78086 L .28576 .78237 L p .707 .577 .707 r
F P
0 g
s
.22278 .77964 m .22217 .7985 L .25334 .80082 L p .707 .577 .707 r
F P
0 g
s
.19248 .74399 m .19585 .70572 L .17464 .70266 L p .707 .577 .707 r
F P
0 g
s
.34099 .64545 m .33797 .7025 L .35423 .69949 L p .707 .577 .707 r
F P
0 g
s
.35423 .69949 m .35724 .64244 L .34099 .64545 L p .707 .577 .707 r
F P
0 g
s
.17464 .70266 m .17128 .74093 L .19248 .74399 L p .707 .577 .707 r
F P
0 g
s
.22217 .7985 m .22278 .77964 L .19531 .77566 L p .707 .577 .707 r
F P
0 g
s
.68884 .7489 m .68548 .78717 L .66427 .78411 L p .707 .577 .707 r
F P
0 g
s
.66427 .78411 m .66764 .74584 L .68884 .7489 L p .707 .577 .707 r
F P
0 g
s
.19531 .77566 m .19471 .79452 L .22217 .7985 L p .707 .577 .707 r
F P
0 g
s
.64997 .77928 m .64035 .28447 L .63037 .2984 L p .707 .577 .707 r
F P
0 g
s
.17321 .69252 m .17622 .63547 L .16354 .6307 L p .707 .577 .707 r
F P
0 g
s
.31511 .78086 m .31451 .79972 L .33852 .79642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79642 m .33913 .77756 L .31511 .78086 L p .707 .577 .707 r
F P
0 g
s
.33906 .71754 m .3357 .75581 L .35174 .75583 L p .707 .577 .707 r
F P
0 g
s
.35174 .75583 m .3551 .71756 L .33906 .71754 L p .707 .577 .707 r
F P
0 g
s
.16354 .6307 m .16053 .68775 L .17321 .69252 L p .707 .577 .707 r
F P
0 g
s
.68995 .79163 m .68934 .8105 L .66827 .80524 L p .707 .577 .707 r
F P
0 g
s
.66827 .80524 m .66887 .78638 L .68995 .79163 L p .707 .577 .707 r
F P
0 g
s
.19471 .79452 m .19531 .77566 L .17424 .7704 L p .707 .577 .707 r
F P
0 g
s
.17424 .7704 m .17363 .78927 L .19471 .79452 L p .707 .577 .707 r
F P
0 g
s
.17128 .74093 m .17464 .70266 L .16181 .70006 L p .707 .577 .707 r
F P
0 g
s
.36119 .69548 m .3642 .63842 L .35724 .64244 L p .707 .577 .707 r
F P
0 g
s
.35724 .64244 m .35423 .69949 L .36119 .69548 L p .707 .577 .707 r
F P
0 g
s
.3642 .63842 m .36119 .69548 L .35819 .69086 L p .707 .577 .707 r
F P
0 g
s
.35819 .69086 m .3612 .63381 L .3642 .63842 L p .707 .577 .707 r
F P
0 g
s
.36627 .79237 m .35664 .29756 L .35253 .28359 L p .707 .577 .707 r
F P
0 g
s
.35664 .29756 m .36627 .79237 L .38406 .80502 L p .707 .577 .707 r
F P
0 g
s
.16181 .70006 m .15845 .73833 L .17128 .74093 L p .707 .577 .707 r
F P
0 g
s
.33913 .77756 m .33852 .79642 L .35485 .79166 L p .707 .577 .707 r
F P
0 g
s
.35485 .79166 m .35545 .77279 L .33913 .77756 L p .707 .577 .707 r
F P
0 g
s
.16053 .68775 m .16354 .6307 L .16054 .62608 L p .707 .577 .707 r
F P
0 g
s
.66887 .78638 m .66827 .80524 L .6408 .80126 L p .707 .577 .707 r
F P
0 g
s
.17363 .78927 m .17424 .7704 L .16162 .76438 L p .707 .577 .707 r
F P
0 g
s
.3551 .71756 m .35174 .75583 L .35849 .75484 L p .707 .577 .707 r
F P
0 g
s
.35849 .75484 m .36186 .71657 L .3551 .71756 L p .707 .577 .707 r
F P
0 g
s
.16162 .76438 m .16101 .78325 L .17363 .78927 L p .707 .577 .707 r
F P
0 g
s
.16054 .62608 m .15753 .68313 L .16053 .68775 L p .707 .577 .707 r
F P
0 g
s
.64035 .28447 m .64997 .77928 L .64947 .77756 L p .707 .577 .707 r
F P
0 g
s
.64534 .71934 m .64035 .28447 L .64947 .77756 L .707 .577 .707 r
F
.64587 .76531 m .63624 .2705 L .64035 .28447 L p F P
0 g
s
.63624 .2705 m .64587 .76531 L .62807 .75266 L p .707 .577 .707 r
F P
0 g
s
.64202 .64793 m .64106 .65895 L p .65149 .6888 L .707 .577 .707 r
F P
0 g
s
.64106 .65895 m .63866 .6862 L .64305 .68709 L p .707 .577 .707 r
F P
0 g
s
.64305 .68709 m .65149 .6888 L p .64106 .65895 L .707 .577 .707 r
F P
0 g
s
.64947 .77756 m .64587 .76531 L p .64534 .71934 L .707 .577 .707 r
F P
0 g
s
.15845 .73833 m .16181 .70006 L .15862 .69818 L p .707 .577 .707 r
F P
0 g
s
.15862 .69818 m .15525 .73645 L .15845 .73833 L p .707 .577 .707 r
F P
0 g
s
.35545 .77279 m .35485 .79166 L .36189 .7859 L p .707 .577 .707 r
F P
0 g
s
.36189 .7859 m .36249 .76703 L .35545 .77279 L p .707 .577 .707 r
F P
0 g
s
.36186 .71657 m .35849 .75484 L .3553 .75296 L p .707 .577 .707 r
F P
0 g
s
.3553 .75296 m .35866 .71469 L .36186 .71657 L p .707 .577 .707 r
F P
0 g
s
.36249 .76703 m .36189 .7859 L .35895 .77971 L p .707 .577 .707 r
F P
0 g
s
.35895 .77971 m .35956 .76084 L .36249 .76703 L p .707 .577 .707 r
F P
0 g
s
.3612 .63381 m .35819 .69086 L .34552 .68609 L p .707 .577 .707 r
F P
0 g
s
.34552 .68609 m .34853 .62904 L .3612 .63381 L p .707 .577 .707 r
F P
0 g
s
.35253 .28359 m .36216 .77839 L .36627 .79237 L p .707 .577 .707 r
F P
0 g
s
.36216 .77839 m .35253 .28359 L .36251 .26965 L p .707 .577 .707 r
F P
0 g
s
.15753 .68313 m .16054 .62608 L .16751 .62207 L p .707 .577 .707 r
F P
0 g
s
.16101 .78325 m .16162 .76438 L .15868 .75819 L p .707 .577 .707 r
F P
0 g
s
.15868 .75819 m .15808 .77706 L .16101 .78325 L p .707 .577 .707 r
F P
0 g
s
.16751 .62207 m .16449 .67912 L .15753 .68313 L p .707 .577 .707 r
F P
0 g
s
.15525 .73645 m .15862 .69818 L .16537 .69719 L p .707 .577 .707 r
F P
0 g
s
.16537 .69719 m .16201 .73546 L .15525 .73645 L p .707 .577 .707 r
F P
0 g
s
.62807 .75266 m .61845 .25785 L .63624 .2705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16449 .67912 m .16751 .62207 L .18376 .61906 L p .707 .577 .707 r
F P
0 g
s
.15808 .77706 m .15868 .75819 L .16572 .75243 L p .707 .577 .707 r
F P
0 g
s
.16572 .75243 m .16512 .7713 L .15808 .77706 L p .707 .577 .707 r
F P
0 g
s
.35866 .71469 m .3553 .75296 L .34247 .75036 L p .707 .577 .707 r
F P
0 g
s
.34247 .75036 m .34583 .71209 L .35866 .71469 L p .707 .577 .707 r
F P
0 g
s
.18376 .61906 m .18075 .67611 L .16449 .67912 L p .707 .577 .707 r
F P
0 g
s
.37214 .76446 m .36251 .26965 L .3856 .25713 L p .707 .577 .707 r
F P
0 g
s
.36251 .26965 m .37214 .76446 L .36216 .77839 L p .707 .577 .707 r
F P
0 g
s
.16201 .73546 m .16537 .69719 L .18141 .69721 L p .707 .577 .707 r
F P
0 g
s
.18141 .69721 m .17805 .73548 L .16201 .73546 L p .707 .577 .707 r
F P
0 g
s
.34853 .62904 m .34552 .68609 L .32441 .68164 L p .707 .577 .707 r
F P
0 g
s
.32441 .68164 m .32742 .62459 L .34853 .62904 L p .707 .577 .707 r
F P
0 g
s
.35956 .76084 m .35895 .77971 L .34633 .77369 L p .707 .577 .707 r
F P
0 g
s
.34633 .77369 m .34694 .75482 L .35956 .76084 L p .707 .577 .707 r
F P
0 g
s
.18075 .67611 m .18376 .61906 L .20771 .61733 L p .707 .577 .707 r
F P
0 g
s
.61845 .25785 m .62807 .75266 L .59834 .74257 L p .707 .577 .707 r
F P
0 g
s
.59834 .74257 m .58871 .24776 L .61845 .25785 L p .707 .577 .707 r
F P
0 g
s
.16512 .7713 m .16572 .75243 L .18205 .74766 L p .707 .577 .707 r
F P
0 g
s
.34583 .71209 m .34247 .75036 L .32126 .7473 L p .707 .577 .707 r
F P
0 g
s
.32126 .7473 m .32463 .70903 L .34583 .71209 L p .707 .577 .707 r
F P
0 g
s
.18205 .74766 m .18144 .76653 L .16512 .7713 L p .707 .577 .707 r
F P
0 g
s
.20771 .61733 m .20469 .67439 L .18075 .67611 L p .707 .577 .707 r
F P
0 g
s
.32742 .62459 m .32441 .68164 L .29693 .67794 L p .707 .577 .707 r
F P
0 g
s
.29693 .67794 m .29994 .62089 L .32742 .62459 L p .707 .577 .707 r
F P
0 g
s
.17805 .73548 m .18141 .69721 L .20517 .69821 L p .707 .577 .707 r
F P
0 g
s
.20517 .69821 m .2018 .73648 L .17805 .73548 L p .707 .577 .707 r
F P
0 g
s
.3856 .25713 m .39523 .75194 L .37214 .76446 L p .707 .577 .707 r
F P
0 g
s
.39523 .75194 m .3856 .25713 L .41954 .24724 L p .707 .577 .707 r
F P
0 g
s
.20469 .67439 m .20771 .61733 L .23701 .61707 L p .707 .577 .707 r
F P
0 g
s
.34694 .75482 m .34633 .77369 L .32526 .76843 L p .707 .577 .707 r
F P
0 g
s
.32526 .76843 m .32586 .74956 L .34694 .75482 L p .707 .577 .707 r
F P
0 g
s
.23701 .61707 m .23399 .67412 L .20469 .67439 L p .707 .577 .707 r
F P
0 g
s
.29994 .62089 m .29693 .67794 L .26578 .67535 L p .707 .577 .707 r
F P
0 g
s
.26578 .67535 m .26879 .6183 L .29994 .62089 L p .707 .577 .707 r
F P
0 g
s
.32463 .70903 m .32126 .7473 L .29375 .74407 L p .707 .577 .707 r
F P
0 g
s
.29375 .74407 m .29712 .7058 L .32463 .70903 L p .707 .577 .707 r
F P
0 g
s
.73316 .64024 m .73617 .58319 L .70502 .5806 L p .707 .577 .707 r
F P
0 g
s
.73617 .58319 m .73316 .64024 L .76494 .64147 L p .707 .577 .707 r
F P
0 g
s
.76494 .64147 m .76795 .58441 L .73617 .58319 L p .707 .577 .707 r
F P
0 g
s
.18144 .76653 m .18205 .74766 L .20606 .74436 L p .707 .577 .707 r
F P
0 g
s
.23399 .67412 m .23701 .61707 L .26879 .6183 L p .707 .577 .707 r
F P
0 g
s
.76795 .58441 m .76494 .64147 L .79424 .6412 L p .707 .577 .707 r
F P
0 g
s
.79424 .6412 m .79725 .58415 L .76795 .58441 L p .707 .577 .707 r
F P
0 g
s
.58871 .24776 m .59834 .74257 L .55957 .73603 L p .707 .577 .707 r
F P
0 g
s
.55957 .73603 m .54994 .24122 L .58871 .24776 L p .707 .577 .707 r
F P
0 g
s
.20606 .74436 m .20546 .76323 L .18144 .76653 L p .707 .577 .707 r
F P
0 g
s
.2018 .73648 m .20517 .69821 L .23431 .70012 L p .707 .577 .707 r
F P
0 g
s
.26879 .6183 m .26578 .67535 L .23399 .67412 L p .707 .577 .707 r
F P
0 g
s
.702 .63765 m .70502 .5806 L .67754 .5769 L p .707 .577 .707 r
F P
0 g
s
.70502 .5806 m .702 .63765 L .73316 .64024 L p .707 .577 .707 r
F P
0 g
s
.23431 .70012 m .23095 .73839 L .2018 .73648 L p .707 .577 .707 r
F P
0 g
s
.32586 .74956 m .32526 .76843 L .29779 .76445 L p .707 .577 .707 r
F P
0 g
s
.29779 .76445 m .2984 .74558 L .32586 .74956 L p .707 .577 .707 r
F P
0 g
s
.67754 .5769 m .67453 .63395 L .702 .63765 L p .707 .577 .707 r
F P
0 g
s
.42916 .74205 m .41954 .24724 L .461 .24095 L p .707 .577 .707 r
F P
0 g
s
.41954 .24724 m .42813 .68895 L p .39523 .75194 L .707 .577 .707 r
F P
0 g
s
.461 .24095 m .47063 .73576 L .42916 .74205 L p .707 .577 .707 r
F P
0 g
s
.42336 .62569 m .42 .66396 L .43917 .66521 L p .707 .577 .707 r
F P
0 g
s
.43917 .66521 m .44915 .66586 L p .44319 .65658 L .707 .577 .707 r
F P
0 g
s
.44319 .65658 m .42336 .62569 L .43917 .66521 L .707 .577 .707 r
F
.42813 .68895 m .42916 .74205 L .39941 .75072 L p F P
0 g
s
.39941 .75072 m .39523 .75194 L p .42813 .68895 L .707 .577 .707 r
F P
0 g
s
.29712 .7058 m .29375 .74407 L .26263 .741 L p .707 .577 .707 r
F P
0 g
s
.26263 .741 m .266 .70273 L .29712 .7058 L p .707 .577 .707 r
F P
0 g
s
.79725 .58415 m .79424 .6412 L .81819 .63948 L p .707 .577 .707 r
F P
0 g
s
.81819 .63948 m .8212 .58243 L .79725 .58415 L p .707 .577 .707 r
F P
0 g
s
.73133 .69816 m .73469 .65989 L .70357 .65682 L p .707 .577 .707 r
F P
0 g
s
.73469 .65989 m .73133 .69816 L .76301 .70077 L p .707 .577 .707 r
F P
0 g
s
.76301 .70077 m .76637 .6625 L .73469 .65989 L p .707 .577 .707 r
F P
0 g
s
.23095 .73839 m .23431 .70012 L .266 .70273 L p .707 .577 .707 r
F P
0 g
s
.70357 .65682 m .70021 .69509 L .73133 .69816 L p .707 .577 .707 r
F P
0 g
s
.266 .70273 m .26263 .741 L .23095 .73839 L p .707 .577 .707 r
F P
0 g
s
.76637 .6625 m .76301 .70077 L .79216 .70268 L p .707 .577 .707 r
F P
0 g
s
.79216 .70268 m .79552 .66441 L .76637 .6625 L p .707 .577 .707 r
F P
0 g
s
.20546 .76323 m .20606 .74436 L .23542 .74285 L p .707 .577 .707 r
F P
0 g
s
.67453 .63395 m .67754 .5769 L .65643 .57245 L p .707 .577 .707 r
F P
0 g
s
.70021 .69509 m .70357 .65682 L .67606 .65359 L p .707 .577 .707 r
F P
0 g
s
.23542 .74285 m .23481 .76172 L .20546 .76323 L p .707 .577 .707 r
F P
0 g
s
.54994 .24122 m .55957 .73603 L .51557 .73369 L p .707 .577 .707 r
F P
0 g
s
.51557 .73369 m .50594 .23888 L .54994 .24122 L p .707 .577 .707 r
F P
0 g
s
.67606 .65359 m .6727 .69186 L .70021 .69509 L p .707 .577 .707 r
F P
0 g
s
.2984 .74558 m .29779 .76445 L .26663 .76214 L p .707 .577 .707 r
F P
0 g
s
.26663 .76214 m .26723 .74327 L .2984 .74558 L p .707 .577 .707 r
F P
0 g
s
.65643 .57245 m .65342 .6295 L .67453 .63395 L p .707 .577 .707 r
F P
0 g
s
.47063 .73576 m .461 .24095 L .50594 .23888 L p .707 .577 .707 r
F P
0 g
s
.23481 .76172 m .23542 .74285 L .26723 .74327 L p .707 .577 .707 r
F P
0 g
s
.79552 .66441 m .79216 .70268 L .81591 .70369 L p .707 .577 .707 r
F P
0 g
s
.81591 .70369 m .81928 .66542 L .79552 .66441 L p .707 .577 .707 r
F P
0 g
s
.50594 .23888 m .51557 .73369 L .47063 .73576 L p .707 .577 .707 r
F P
0 g
s
.26723 .74327 m .26663 .76214 L .23481 .76172 L p .707 .577 .707 r
F P
0 g
s
.8212 .58243 m .81819 .63948 L .83444 .63647 L p .707 .577 .707 r
F P
0 g
s
.83444 .63647 m .83745 .57942 L .8212 .58243 L p .707 .577 .707 r
F P
0 g
s
.73355 .7575 m .73416 .73863 L .70299 .73632 L p .707 .577 .707 r
F P
0 g
s
.73416 .73863 m .73355 .7575 L .76537 .75792 L p .707 .577 .707 r
F P
0 g
s
.76537 .75792 m .76597 .73905 L .73416 .73863 L p .707 .577 .707 r
F P
0 g
s
.6727 .69186 m .67606 .65359 L .65485 .65053 L p .707 .577 .707 r
F P
0 g
s
.76597 .73905 m .76537 .75792 L .79472 .7564 L p .707 .577 .707 r
F P
0 g
s
.79472 .7564 m .79532 .73754 L .76597 .73905 L p .707 .577 .707 r
F P
0 g
s
.70299 .73632 m .70239 .75518 L .73355 .7575 L p .707 .577 .707 r
F P
0 g
s
.65485 .65053 m .65149 .6888 L .6727 .69186 L p .707 .577 .707 r
F P
0 g
s
.70239 .75518 m .70299 .73632 L .67553 .73234 L p .707 .577 .707 r
F P
0 g
s
.65342 .6295 m .65643 .57245 L .64375 .56768 L p .707 .577 .707 r
F P
0 g
s
.67553 .73234 m .67492 .7512 L .70239 .75518 L p .707 .577 .707 r
F P
0 g
s
.79532 .73754 m .79472 .7564 L .81874 .7531 L p .707 .577 .707 r
F P
0 g
s
.81874 .7531 m .81934 .73424 L .79532 .73754 L p .707 .577 .707 r
F P
0 g
s
.64375 .56768 m .64074 .62473 L .65342 .6295 L p .707 .577 .707 r
F P
0 g
s
.81928 .66542 m .81591 .70369 L .83195 .7037 L p .707 .577 .707 r
F P
0 g
s
.83195 .7037 m .83532 .66543 L .81928 .66542 L p .707 .577 .707 r
F P
0 g
s
.67492 .7512 m .67553 .73234 L .65445 .72708 L p .707 .577 .707 r
F P
0 g
s
.65149 .6888 m .65485 .65053 L .64202 .64793 L p .707 .577 .707 r
F P
0 g
s
.65445 .72708 m .65385 .74595 L .67492 .7512 L p .707 .577 .707 r
F P
0 g
s
.83745 .57942 m .83444 .63647 L .84141 .63245 L p .707 .577 .707 r
F P
0 g
s
.84141 .63245 m .84442 .5754 L .83745 .57942 L p .707 .577 .707 r
F P
0 g
s
.81934 .73424 m .81874 .7531 L .83506 .74834 L p .707 .577 .707 r
F P
0 g
s
.83506 .74834 m .83567 .72947 L .81934 .73424 L p .707 .577 .707 r
F P
0 g
s
.64074 .62473 m .64375 .56768 L .64075 .56306 L p .707 .577 .707 r
F P
0 g
s
.83532 .66543 m .83195 .7037 L .83871 .70271 L p .707 .577 .707 r
F P
0 g
s
.83871 .70271 m .84207 .66444 L .83532 .66543 L p .707 .577 .707 r
F P
0 g
s
.64075 .56306 m .63774 .62011 L .64074 .62473 L p .707 .577 .707 r
F P
0 g
s
.65385 .74595 m .65445 .72708 L .64183 .72106 L p .707 .577 .707 r
F P
0 g
s
.64183 .72106 m .64122 .73993 L .65385 .74595 L p .707 .577 .707 r
F P
0 g
s
.63866 .6862 m .64202 .64793 L .63883 .64605 L p .707 .577 .707 r
F P
0 g
s
.63883 .64605 m .63547 .68432 L .63866 .6862 L p .707 .577 .707 r
F P
0 g
s
.84442 .5754 m .84141 .63245 L .83841 .62784 L p .707 .577 .707 r
F P
0 g
s
.83841 .62784 m .84142 .57079 L .84442 .5754 L p .707 .577 .707 r
F P
0 g
s
.83567 .72947 m .83506 .74834 L .8421 .74258 L p .707 .577 .707 r
F P
0 g
s
.8421 .74258 m .84271 .72371 L .83567 .72947 L p .707 .577 .707 r
F P
0 g
s
.63774 .62011 m .64075 .56306 L .64772 .55905 L p .707 .577 .707 r
F P
0 g
s
.64122 .73993 m .64183 .72106 L .63889 .71487 L p .707 .577 .707 r
F P
0 g
s
.84207 .66444 m .83871 .70271 L .83551 .70083 L p .707 .577 .707 r
F P
0 g
s
.83551 .70083 m .83888 .66256 L .84207 .66444 L p .707 .577 .707 r
F P
0 g
s
.64772 .55905 m .64471 .6161 L .63774 .62011 L p .707 .577 .707 r
F P
0 g
s
.63889 .71487 m .63829 .73373 L .64122 .73993 L p .707 .577 .707 r
F P
0 g
s
.63547 .68432 m .63883 .64605 L .64558 .64506 L p .707 .577 .707 r
F P
0 g
s
.64558 .64506 m .64222 .68333 L .63547 .68432 L p .707 .577 .707 r
F P
0 g
s
.84142 .57079 m .83841 .62784 L .82573 .62307 L p .707 .577 .707 r
F P
0 g
s
.82573 .62307 m .82874 .56602 L .84142 .57079 L p .707 .577 .707 r
F P
0 g
s
.39015 .60343 m .39316 .54638 L .36201 .54379 L p .707 .577 .707 r
F P
0 g
s
.39316 .54638 m .39015 .60343 L .42193 .60465 L p .707 .577 .707 r
F P
0 g
s
.42193 .60465 m .42494 .5476 L .39316 .54638 L p .707 .577 .707 r
F P
0 g
s
.84271 .72371 m .8421 .74258 L .83917 .73639 L p .707 .577 .707 r
F P
0 g
s
.83917 .73639 m .83977 .71752 L .84271 .72371 L p .707 .577 .707 r
F P
0 g
s
.42494 .5476 m .42193 .60465 L .45123 .60439 L p .707 .577 .707 r
F P
0 g
s
.45123 .60439 m .45424 .54734 L .42494 .5476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64471 .6161 m .64772 .55905 L .66397 .55604 L p .707 .577 .707 r
F P
0 g
s
.35899 .60084 m .36201 .54379 L .33453 .54008 L p .707 .577 .707 r
F P
0 g
s
.36201 .54379 m .35899 .60084 L .39015 .60343 L p .707 .577 .707 r
F P
0 g
s
.63829 .73373 m .63889 .71487 L .64594 .70911 L p .707 .577 .707 r
F P
0 g
s
.66397 .55604 m .66096 .61309 L .64471 .6161 L p .707 .577 .707 r
F P
0 g
s
.83888 .66256 m .83551 .70083 L .82268 .69823 L p .707 .577 .707 r
F P
0 g
s
.82268 .69823 m .82605 .65996 L .83888 .66256 L p .707 .577 .707 r
F P
0 g
s
.33453 .54008 m .33152 .59713 L .35899 .60084 L p .707 .577 .707 r
F P
0 g
s
.64594 .70911 m .64533 .72797 L .63829 .73373 L p .707 .577 .707 r
F P
0 g
s
.45424 .54734 m .45123 .60439 L .47518 .60267 L p .707 .577 .707 r
F P
0 g
s
.47518 .60267 m .47819 .54561 L .45424 .54734 L p .707 .577 .707 r
F P
0 g
s
.38832 .66134 m .39168 .62307 L .36056 .62 L p .707 .577 .707 r
F P
0 g
s
.39168 .62307 m .38832 .66134 L .42 .66396 L p .707 .577 .707 r
F P
0 g
s
.42 .66396 m .42336 .62569 L .39168 .62307 L p .707 .577 .707 r
F P
0 g
s
.36056 .62 m .3572 .65827 L .38832 .66134 L p .707 .577 .707 r
F P
0 g
s
.44915 .66586 m .45251 .62759 L .42336 .62569 L p .707 .577 .707 r
F P
0 g
s
.33152 .59713 m .33453 .54008 L .31342 .53563 L p .707 .577 .707 r
F P
0 g
s
.82874 .56602 m .82573 .62307 L .80462 .61862 L p .707 .577 .707 r
F P
0 g
s
.80462 .61862 m .80763 .56157 L .82874 .56602 L p .707 .577 .707 r
F P
0 g
s
.64222 .68333 m .64558 .64506 L .66162 .64508 L p .707 .577 .707 r
F P
0 g
s
.3572 .65827 m .36056 .62 L .33305 .61678 L p .707 .577 .707 r
F P
0 g
s
.66162 .64508 m .65826 .68335 L .64222 .68333 L p .707 .577 .707 r
F P
0 g
s
.33305 .61678 m .32969 .65505 L .3572 .65827 L p .707 .577 .707 r
F P
0 g
s
.31342 .53563 m .31041 .59268 L .33152 .59713 L p .707 .577 .707 r
F P
0 g
s
.83977 .71752 m .83917 .73639 L .82655 .73037 L p .707 .577 .707 r
F P
0 g
s
.82655 .73037 m .82715 .7115 L .83977 .71752 L p .707 .577 .707 r
F P
0 g
s
.66096 .61309 m .66397 .55604 L .68792 .55431 L p .707 .577 .707 r
F P
0 g
s
.45251 .62759 m .44915 .66586 L .4729 .66687 L p .707 .577 .707 r
F P
0 g
s
.4729 .66687 m .47627 .6286 L .45251 .62759 L p .707 .577 .707 r
F P
0 g
s
.47819 .54561 m .47518 .60267 L .49143 .59965 L p .707 .577 .707 r
F P
0 g
s
.49143 .59965 m .49444 .5426 L .47819 .54561 L p .707 .577 .707 r
F P
0 g
s
.39054 .72068 m .39115 .70182 L .35998 .6995 L p .707 .577 .707 r
F P
0 g
s
.39115 .70182 m .39054 .72068 L .42236 .7211 L p .707 .577 .707 r
F P
0 g
s
.42236 .7211 m .42296 .70224 L .39115 .70182 L p .707 .577 .707 r
F P
0 g
s
.32969 .65505 m .33305 .61678 L .31184 .61372 L p .707 .577 .707 r
F P
0 g
s
.68792 .55431 m .68491 .61136 L .66096 .61309 L p .707 .577 .707 r
F P
0 g
s
.42296 .70224 m .42236 .7211 L .45171 .71959 L p .707 .577 .707 r
F P
0 g
s
.45171 .71959 m .45232 .70072 L .42296 .70224 L p .707 .577 .707 r
F P
0 g
s
.35998 .6995 m .35938 .71837 L .39054 .72068 L p .707 .577 .707 r
F P
0 g
s
.31184 .61372 m .30848 .65199 L .32969 .65505 L p .707 .577 .707 r
F P
0 g
s
.64533 .72797 m .64594 .70911 L .66226 .70434 L p .707 .577 .707 r
F P
0 g
s
.82605 .65996 m .82268 .69823 L .80148 .69517 L p .707 .577 .707 r
F P
0 g
s
.80148 .69517 m .80484 .6569 L .82605 .65996 L p .707 .577 .707 r
F P
0 g
s
.35938 .71837 m .35998 .6995 L .33252 .69552 L p .707 .577 .707 r
F P
0 g
s
.31041 .59268 m .31342 .53563 L .30074 .53086 L p .707 .577 .707 r
F P
0 g
s
.66226 .70434 m .66166 .72321 L .64533 .72797 L p .707 .577 .707 r
F P
0 g
s
.80763 .56157 m .80462 .61862 L .77714 .61492 L p .707 .577 .707 r
F P
0 g
s
.77714 .61492 m .78016 .55787 L .80763 .56157 L p .707 .577 .707 r
F P
0 g
s
.33252 .69552 m .33191 .71439 L .35938 .71837 L p .707 .577 .707 r
F P
0 g
s
.65826 .68335 m .66162 .64508 L .68538 .64609 L p .707 .577 .707 r
F P
0 g
s
.68538 .64609 m .68202 .68436 L .65826 .68335 L p .707 .577 .707 r
F P
0 g
s
.45232 .70072 m .45171 .71959 L .47573 .71629 L p .707 .577 .707 r
F P
0 g
s
.47573 .71629 m .47633 .69742 L .45232 .70072 L p .707 .577 .707 r
F P
0 g
s
.68491 .61136 m .68792 .55431 L .71722 .55405 L p .707 .577 .707 r
F P
0 g
s
.30074 .53086 m .29773 .58791 L .31041 .59268 L p .707 .577 .707 r
F P
0 g
s
.47627 .6286 m .4729 .66687 L .48894 .66688 L p .707 .577 .707 r
F P
0 g
s
.48894 .66688 m .49231 .62861 L .47627 .6286 L p .707 .577 .707 r
F P
0 g
s
.82715 .7115 m .82655 .73037 L .80547 .72511 L p .707 .577 .707 r
F P
0 g
s
.80547 .72511 m .80608 .70624 L .82715 .7115 L p .707 .577 .707 r
F P
0 g
s
.33191 .71439 m .33252 .69552 L .31144 .69027 L p .707 .577 .707 r
F P
0 g
s
.71722 .55405 m .71421 .6111 L .68491 .61136 L p .707 .577 .707 r
F P
0 g
s
.78016 .55787 m .77714 .61492 L .74599 .61233 L p .707 .577 .707 r
F P
0 g
s
.74599 .61233 m .749 .55528 L .78016 .55787 L p .707 .577 .707 r
F P
0 g
s
.30848 .65199 m .31184 .61372 L .29901 .61112 L p .707 .577 .707 r
F P
0 g
s
.31144 .69027 m .31084 .70913 L .33191 .71439 L p .707 .577 .707 r
F P
0 g
s
.49444 .5426 m .49143 .59965 L .4984 .59564 L p .707 .577 .707 r
F P
0 g
s
.4984 .59564 m .50141 .53859 L .49444 .5426 L p .707 .577 .707 r
F P
0 g
s
.29901 .61112 m .29565 .64939 L .30848 .65199 L p .707 .577 .707 r
F P
0 g
s
.80484 .6569 m .80148 .69517 L .77397 .69194 L p .707 .577 .707 r
F P
0 g
s
.77397 .69194 m .77733 .65368 L .80484 .6569 L p .707 .577 .707 r
F P
0 g
s
.71421 .6111 m .71722 .55405 L .749 .55528 L p .707 .577 .707 r
F P
0 g
s
.66166 .72321 m .66226 .70434 L .68628 .70104 L p .707 .577 .707 r
F P
0 g
s
.749 .55528 m .74599 .61233 L .71421 .6111 L p .707 .577 .707 r
F P
0 g
s
.68202 .68436 m .68538 .64609 L .71453 .64799 L p .707 .577 .707 r
F P
0 g
s
.68628 .70104 m .68567 .71991 L .66166 .72321 L p .707 .577 .707 r
F P
0 g
s
.47633 .69742 m .47573 .71629 L .49205 .71152 L p .707 .577 .707 r
F P
0 g
s
.49205 .71152 m .49266 .69266 L .47633 .69742 L p .707 .577 .707 r
F P
0 g
s
.71453 .64799 m .71116 .68626 L .68202 .68436 L p .707 .577 .707 r
F P
0 g
s
.29773 .58791 m .30074 .53086 L .29774 .52625 L p .707 .577 .707 r
F P
0 g
s
.77733 .65368 m .77397 .69194 L .74285 .68888 L p .707 .577 .707 r
F P
0 g
s
.74285 .68888 m .74621 .65061 L .77733 .65368 L p .707 .577 .707 r
F P
0 g
s
.49231 .62861 m .48894 .66688 L .4957 .6659 L p .707 .577 .707 r
F P
0 g
s
.4957 .6659 m .49906 .62763 L .49231 .62861 L p .707 .577 .707 r
F P
0 g
s
.29774 .52625 m .29473 .5833 L .29773 .58791 L p .707 .577 .707 r
F P
0 g
s
.80608 .70624 m .80547 .72511 L .77801 .72113 L p .707 .577 .707 r
F P
0 g
s
.77801 .72113 m .77861 .70226 L .80608 .70624 L p .707 .577 .707 r
F P
0 g
s
.31084 .70913 m .31144 .69027 L .29882 .68425 L p .707 .577 .707 r
F P
0 g
s
.71116 .68626 m .71453 .64799 L .74621 .65061 L p .707 .577 .707 r
F P
0 g
s
.74621 .65061 m .74285 .68888 L .71116 .68626 L p .707 .577 .707 r
F P
0 g
s
.29882 .68425 m .29821 .70311 L .31084 .70913 L p .707 .577 .707 r
F P
0 g
s
.68567 .71991 m .68628 .70104 L .71563 .69953 L p .707 .577 .707 r
F P
0 g
s
.29565 .64939 m .29901 .61112 L .29582 .60923 L p .707 .577 .707 r
F P
0 g
s
.71563 .69953 m .71502 .7184 L .68567 .71991 L p .707 .577 .707 r
F P
0 g
s
.29582 .60923 m .29246 .6475 L .29565 .64939 L p .707 .577 .707 r
F P
0 g
s
.50141 .53859 m .4984 .59564 L .4954 .59102 L p .707 .577 .707 r
F P
0 g
s
.4954 .59102 m .49841 .53397 L .50141 .53859 L p .707 .577 .707 r
F P
0 g
s
.77861 .70226 m .77801 .72113 L .74684 .71882 L p .707 .577 .707 r
F P
0 g
s
.74684 .71882 m .74745 .69995 L .77861 .70226 L p .707 .577 .707 r
F P
0 g
s
.49266 .69266 m .49205 .71152 L .49909 .70576 L p .707 .577 .707 r
F P
0 g
s
.49909 .70576 m .4997 .6869 L .49266 .69266 L p .707 .577 .707 r
F P
0 g
s
.71502 .7184 m .71563 .69953 L .74745 .69995 L p .707 .577 .707 r
F P
0 g
s
.74745 .69995 m .74684 .71882 L .71502 .7184 L p .707 .577 .707 r
F P
0 g
s
.29473 .5833 m .29774 .52625 L .30471 .52224 L p .707 .577 .707 r
F P
0 g
s
.29821 .70311 m .29882 .68425 L .29588 .67805 L p .707 .577 .707 r
F P
0 g
s
.49906 .62763 m .4957 .6659 L .4925 .66401 L p .707 .577 .707 r
F P
0 g
s
.4925 .66401 m .49587 .62575 L .49906 .62763 L p .707 .577 .707 r
F P
0 g
s
.30471 .52224 m .3017 .57929 L .29473 .5833 L p .707 .577 .707 r
F P
0 g
s
.29588 .67805 m .29528 .69692 L .29821 .70311 L p .707 .577 .707 r
F P
0 g
s
.29246 .6475 m .29582 .60923 L .30257 .60825 L p .707 .577 .707 r
F P
0 g
s
.30257 .60825 m .29921 .64652 L .29246 .6475 L p .707 .577 .707 r
F P
0 g
s
.49841 .53397 m .4954 .59102 L .48272 .58626 L p .707 .577 .707 r
F P
0 g
s
.48272 .58626 m .48573 .52921 L .49841 .53397 L p .707 .577 .707 r
F P
0 g
s
.4997 .6869 m .49909 .70576 L .49616 .69957 L p .707 .577 .707 r
F P
0 g
s
.49616 .69957 m .49676 .6807 L .4997 .6869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3017 .57929 m .30471 .52224 L .32096 .51922 L p .707 .577 .707 r
F P
0 g
s
.29528 .69692 m .29588 .67805 L .30292 .67229 L p .707 .577 .707 r
F P
0 g
s
.32096 .51922 m .31795 .57627 L .3017 .57929 L p .707 .577 .707 r
F P
0 g
s
.49587 .62575 m .4925 .66401 L .47967 .66141 L p .707 .577 .707 r
F P
0 g
s
.47967 .66141 m .48304 .62314 L .49587 .62575 L p .707 .577 .707 r
F P
0 g
s
.30292 .67229 m .30232 .69116 L .29528 .69692 L p .707 .577 .707 r
F P
0 g
s
.48573 .52921 m .48272 .58626 L .46161 .5818 L p .707 .577 .707 r
F P
0 g
s
.46161 .5818 m .46462 .52475 L .48573 .52921 L p .707 .577 .707 r
F P
0 g
s
.29921 .64652 m .30257 .60825 L .31861 .60826 L p .707 .577 .707 r
F P
0 g
s
.31861 .60826 m .31525 .64653 L .29921 .64652 L p .707 .577 .707 r
F P
0 g
s
.49676 .6807 m .49616 .69957 L .48354 .69355 L p .707 .577 .707 r
F P
0 g
s
.48354 .69355 m .48414 .67468 L .49676 .6807 L p .707 .577 .707 r
F P
0 g
s
.31795 .57627 m .32096 .51922 L .34491 .5175 L p .707 .577 .707 r
F P
0 g
s
.34491 .5175 m .3419 .57455 L .31795 .57627 L p .707 .577 .707 r
F P
0 g
s
.30232 .69116 m .30292 .67229 L .31925 .66753 L p .707 .577 .707 r
F P
0 g
s
.48304 .62314 m .47967 .66141 L .45847 .65835 L p .707 .577 .707 r
F P
0 g
s
.45847 .65835 m .46183 .62008 L .48304 .62314 L p .707 .577 .707 r
F P
0 g
s
.31925 .66753 m .31865 .6864 L .30232 .69116 L p .707 .577 .707 r
F P
0 g
s
.46462 .52475 m .46161 .5818 L .43413 .5781 L p .707 .577 .707 r
F P
0 g
s
.43413 .5781 m .43715 .52105 L .46462 .52475 L p .707 .577 .707 r
F P
0 g
s
.31525 .64653 m .31861 .60826 L .34237 .60927 L p .707 .577 .707 r
F P
0 g
s
.34237 .60927 m .33901 .64754 L .31525 .64653 L p .707 .577 .707 r
F P
0 g
s
.3419 .57455 m .34491 .5175 L .37421 .51724 L p .707 .577 .707 r
F P
0 g
s
.48414 .67468 m .48354 .69355 L .46246 .68829 L p .707 .577 .707 r
F P
0 g
s
.46246 .68829 m .46307 .66943 L .48414 .67468 L p .707 .577 .707 r
F P
0 g
s
.37421 .51724 m .3712 .57429 L .3419 .57455 L p .707 .577 .707 r
F P
0 g
s
.43715 .52105 m .43413 .5781 L .40298 .57551 L p .707 .577 .707 r
F P
0 g
s
.40298 .57551 m .40599 .51846 L .43715 .52105 L p .707 .577 .707 r
F P
0 g
s
.46183 .62008 m .45847 .65835 L .43096 .65513 L p .707 .577 .707 r
F P
0 g
s
.43096 .65513 m .43432 .61686 L .46183 .62008 L p .707 .577 .707 r
F P
0 g
s
.3712 .57429 m .37421 .51724 L .40599 .51846 L p .707 .577 .707 r
F P
0 g
s
.31865 .6864 m .31925 .66753 L .34327 .66423 L p .707 .577 .707 r
F P
0 g
s
.40599 .51846 m .40298 .57551 L .3712 .57429 L p .707 .577 .707 r
F P
0 g
s
.33901 .64754 m .34237 .60927 L .37151 .61118 L p .707 .577 .707 r
F P
0 g
s
.34327 .66423 m .34266 .68309 L .31865 .6864 L p .707 .577 .707 r
F P
0 g
s
.37151 .61118 m .36815 .64944 L .33901 .64754 L p .707 .577 .707 r
F P
0 g
s
.43432 .61686 m .43096 .65513 L .39984 .65206 L p .707 .577 .707 r
F P
0 g
s
.39984 .65206 m .4032 .61379 L .43432 .61686 L p .707 .577 .707 r
F P
0 g
s
.46307 .66943 m .46246 .68829 L .435 .68431 L p .707 .577 .707 r
F P
0 g
s
.435 .68431 m .4356 .66545 L .46307 .66943 L p .707 .577 .707 r
F P
0 g
s
.36815 .64944 m .37151 .61118 L .4032 .61379 L p .707 .577 .707 r
F P
0 g
s
.4032 .61379 m .39984 .65206 L .36815 .64944 L p .707 .577 .707 r
F P
0 g
s
.34266 .68309 m .34327 .66423 L .37262 .66271 L p .707 .577 .707 r
F P
0 g
s
.37262 .66271 m .37201 .68158 L .34266 .68309 L p .707 .577 .707 r
F P
0 g
s
.4356 .66545 m .435 .68431 L .40383 .682 L p .707 .577 .707 r
F P
0 g
s
.40383 .682 m .40444 .66313 L .4356 .66545 L p .707 .577 .707 r
F P
0 g
s
.37201 .68158 m .37262 .66271 L .40444 .66313 L p .707 .577 .707 r
F P
0 g
s
.40444 .66313 m .40383 .682 L .37201 .68158 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooah007io
o`00Ngoo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00N7oo001fOol50008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001dOol007=oo`<00003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001bOol006moo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001_Ool006eoo`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8006eoo`00Jgoo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00Jgoo001YOol20002FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001YOol006Moo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Ioo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP00009JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00FGoo80002eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001FOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolI0014Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`02Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool005=oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0
009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Ioo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005]oo`L000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2000/Ool0069oo`P000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool006Eoo`05001JEUYF001J
EP0P0007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`P000Moo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`<000=JEP04001JEUYFFUH@00000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP04001JEUYF
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool003QooaT000=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPP000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8002eoo`00;goo2@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF001JEP02FUH2000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol00goo1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`0:Ool90004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF2@00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`0COolI000hOol002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0000L000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEQ8005Ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH9001=Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH00UYF4000?Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000K0005FUH00`00FUIJEP03FUH8
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF5P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPL000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00@005YFFUIJEQ0000AJ
EP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF00000UYF1`001eYF00<005YFFUH01EYF40000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH90002FUH00`00FUIJEP02FUH50004FUH80004
FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00004@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0002FUH60002FUH400000eYF00000002
FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01`000eYF00<005YFFUH015YF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;goo100015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00D005YFFUH005YF00H000EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP09FUH300000eYF001JEP02FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJ
EP070002FUH00`00FUH00002FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP03
0002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJ
EUYF0P00;Woo000]OolA00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@001EYF00<005YFFUH01UYF00<005YFFUH025YF1@000UYF0`0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00@005YFFUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEQ<000=JEP05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0003FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00P000=JEP03
001JEUYF009JEQ@000=JEP04001JEUYFFUH4000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00000010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd002moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP02FUH700000eYF
001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJ
EP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH01000FUIJEUYF
2@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH:0002FUH20007Ool50004Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEP00FUH005YF00<000EJEP04001JEUYFFUH40007Ool5000<Ool60003
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P0000=JEP00FUH00`000UYF00<0
05YFFUH00UYF0`0027oo0`004goo10000eYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH0
0UYF1@000UYF00<005YF00007Goo1`0000=JEP000000;Goo000/OolJ0004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF2P0035YF2@0025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF
FUH015YF00@005YFFUIJEPP0019oo`P0009JEP03001JEUYF009JEP<002eoo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000c
OolT0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
1@000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<0
05YFFUH00UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0003FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF
00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002moo`<00003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH20002
FUH00`00FUIJEP04FUH400000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH020000UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF009JEP03
001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<00005Ool005YFFUH00002FUH20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8000=ooaT003Qoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P000UYF0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00@005YFFUIJEP8005Aoo`00;Goo0P000eYF3@004Goo200015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YF
FUH015YF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8002Ioo`H000AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03
001JEUYF009JEP8005Aoo`00;7oo00<005YF00001@0057oo0`004goo0`0000=JEP00FUH00UYF0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000E7oo000/Ool20003FUH00`00FUIJEP07000<Ool5000EOol30002FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eo
o`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT000=oo`D0015oo`D0009JEP<00003FUH0
05YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF6@00
0eYF00T005YFFUIJEP00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1`000eYF00@005YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH20003FUH:0002FUH2001EOol0031oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
00000goo00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUH0000200000eYF
00000002001EOol003Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF008000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000MJEP03001JEUYF009JEPD005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEPH000Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP05FUH00`00FUIJEP04FUH01000FUH00000EGoo000mOolP000>Ool30007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP080003FUH00`00FUIJEP04FUH01000FUIJEP00EGoo001]Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH30008Ool50004FUH01000
FUIJEUYF0P00E7oo001_Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH3000?Ool300000eYF001JEP02FUH2001DOol0075oo`<00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D001Eo
o`8000=JEP8005Aoo`00M7oo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
1@0000=oo`0000000`004Goo1`0000=JEP000000E7oo001hOol60002FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH01000FUIJEUYF8P000UYF00<005YFFUH00UYF0`00E7oo001nOol90006FUH00`00FUIJ
EP04FUH90003FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUH0001DOol008Moo`d000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00U7oo0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00
EWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
1P00FGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001OOol00:Eooa8006Ioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59622 .73385 m .60106 .67646 L .56994 .67343 L p .707 .577 .707 r
F P
0 g
s
.60106 .67646 m .59622 .73385 L .62791 .73633 L p .707 .577 .707 r
F P
0 g
s
.62791 .73633 m .63276 .67894 L .60106 .67646 L p .707 .577 .707 r
F P
0 g
s
.63276 .67894 m .62791 .73633 L .65708 .73802 L p .707 .577 .707 r
F P
0 g
s
.65708 .73802 m .66192 .68063 L .63276 .67894 L p .707 .577 .707 r
F P
0 g
s
.56994 .67343 m .56509 .73083 L .59622 .73385 L p .707 .577 .707 r
F P
0 g
s
.56509 .73083 m .56994 .67343 L .54243 .67016 L p .707 .577 .707 r
F P
0 g
s
.56824 .73063 m .56288 .76857 L .59392 .77237 L p .707 .577 .707 r
F P
0 g
s
.59392 .77237 m .59928 .73443 L .56824 .73063 L p .707 .577 .707 r
F P
0 g
s
.59928 .73443 m .59392 .77237 L .62536 .7771 L p .707 .577 .707 r
F P
0 g
s
.54243 .67016 m .53759 .72756 L .56509 .73083 L p .707 .577 .707 r
F P
0 g
s
.62536 .7771 m .63072 .73916 L .59928 .73443 L p .707 .577 .707 r
F P
0 g
s
.63072 .73916 m .62536 .7771 L .65413 .7823 L p .707 .577 .707 r
F P
0 g
s
.65413 .7823 m .65949 .74436 L .63072 .73916 L p .707 .577 .707 r
F P
0 g
s
.54065 .72814 m .53529 .76608 L .56288 .76857 L p .707 .577 .707 r
F P
0 g
s
.56288 .76857 m .56824 .73063 L .54065 .72814 L p .707 .577 .707 r
F P
0 g
s
.66192 .68063 m .65708 .73802 L .68085 .73876 L p .707 .577 .707 r
F P
0 g
s
.68085 .73876 m .6857 .68137 L .66192 .68063 L p .707 .577 .707 r
F P
0 g
s
.53759 .72756 m .54243 .67016 L .52124 .66697 L p .707 .577 .707 r
F P
0 g
s
.65949 .74436 m .65413 .7823 L .67741 .78746 L p .707 .577 .707 r
F P
0 g
s
.52124 .66697 m .51639 .72436 L .53759 .72756 L p .707 .577 .707 r
F P
0 g
s
.67741 .78746 m .68277 .74952 L .65949 .74436 L p .707 .577 .707 r
F P
0 g
s
.59661 .82885 m .59759 .80984 L .56644 .80727 L p .707 .577 .707 r
F P
0 g
s
.59759 .80984 m .59661 .82885 L .6284 .83002 L p .707 .577 .707 r
F P
0 g
s
.6284 .83002 m .62938 .81101 L .59759 .80984 L p .707 .577 .707 r
F P
0 g
s
.5192 .72719 m .51384 .76513 L .53529 .76608 L p .707 .577 .707 r
F P
0 g
s
.53529 .76608 m .54065 .72814 L .5192 .72719 L p .707 .577 .707 r
F P
0 g
s
.56644 .80727 m .56546 .82628 L .59661 .82885 L p .707 .577 .707 r
F P
0 g
s
.62938 .81101 m .6284 .83002 L .6577 .82967 L p .707 .577 .707 r
F P
0 g
s
.6577 .82967 m .65868 .81066 L .62938 .81101 L p .707 .577 .707 r
F P
0 g
s
.56546 .82628 m .56644 .80727 L .53896 .80355 L p .707 .577 .707 r
F P
0 g
s
.53896 .80355 m .53798 .82255 L .56546 .82628 L p .707 .577 .707 r
F P
0 g
s
.6857 .68137 m .68085 .73876 L .69692 .73848 L p .707 .577 .707 r
F P
0 g
s
.69692 .73848 m .70177 .68109 L .6857 .68137 L p .707 .577 .707 r
F P
0 g
s
.65868 .81066 m .6577 .82967 L .68166 .82784 L p .707 .577 .707 r
F P
0 g
s
.68166 .82784 m .68263 .80883 L .65868 .81066 L p .707 .577 .707 r
F P
0 g
s
.68277 .74952 m .67741 .78746 L .69292 .79208 L p .707 .577 .707 r
F P
0 g
s
.51639 .72436 m .52124 .66697 L .50843 .66415 L p .707 .577 .707 r
F P
0 g
s
.69292 .79208 m .69828 .75413 L .68277 .74952 L p .707 .577 .707 r
F P
0 g
s
.50843 .66415 m .50358 .72155 L .51639 .72436 L p .707 .577 .707 r
F P
0 g
s
.53798 .82255 m .53896 .80355 L .51785 .79904 L p .707 .577 .707 r
F P
0 g
s
.51785 .79904 m .51688 .81805 L .53798 .82255 L p .707 .577 .707 r
F P
0 g
s
.50599 .72788 m .50063 .76583 L .51384 .76513 L p .707 .577 .707 r
F P
0 g
s
.51384 .76513 m .5192 .72719 L .50599 .72788 L p .707 .577 .707 r
F P
0 g
s
.68263 .80883 m .68166 .82784 L .69791 .8247 L p .707 .577 .707 r
F P
0 g
s
.69791 .8247 m .69889 .8057 L .68263 .80883 L p .707 .577 .707 r
F P
0 g
s
.70177 .68109 m .69692 .73848 L .7037 .7372 L p .707 .577 .707 r
F P
0 g
s
.7037 .7372 m .70855 .67981 L .70177 .68109 L p .707 .577 .707 r
F P
0 g
s
.69828 .75413 m .69292 .79208 L .69915 .7957 L p .707 .577 .707 r
F P
0 g
s
.51688 .81805 m .51785 .79904 L .50518 .79419 L p .707 .577 .707 r
F P
0 g
s
.50358 .72155 m .50843 .66415 L .50526 .662 L p .707 .577 .707 r
F P
0 g
s
.69915 .7957 m .70451 .75775 L .69828 .75413 L p .707 .577 .707 r
F P
0 g
s
.50518 .79419 m .50421 .81319 L .51688 .81805 L p .707 .577 .707 r
F P
0 g
s
.50526 .662 m .50041 .71939 L .50358 .72155 L p .707 .577 .707 r
F P
0 g
s
.50232 .73015 m .49697 .7681 L .50063 .76583 L p .707 .577 .707 r
F P
0 g
s
.50063 .76583 m .50599 .72788 L .50232 .73015 L p .707 .577 .707 r
F P
0 g
s
.50855 .73377 m .50319 .77171 L .49697 .7681 L p .707 .577 .707 r
F P
0 g
s
.49697 .7681 m .50232 .73015 L .50855 .73377 L p .707 .577 .707 r
F P
0 g
s
.50041 .82496 m .48485 .33515 L .44085 .333 L p .707 .577 .707 r
F P
0 g
s
.50421 .81319 m .50518 .79419 L .50219 .78946 L p .707 .577 .707 r
F P
0 g
s
.50219 .78946 m .50121 .80847 L .50421 .81319 L p .707 .577 .707 r
F P
0 g
s
.50041 .71939 m .50526 .662 L .51204 .66072 L p .707 .577 .707 r
F P
0 g
s
.51204 .66072 m .50719 .71811 L .50041 .71939 L p .707 .577 .707 r
F P
0 g
s
.50121 .80847 m .50219 .78946 L .50916 .78533 L p .707 .577 .707 r
F P
0 g
s
.50916 .78533 m .50818 .80434 L .50121 .80847 L p .707 .577 .707 r
F P
0 g
s
.50719 .71811 m .51204 .66072 L .5281 .66044 L p .707 .577 .707 r
F P
0 g
s
.5281 .66044 m .52325 .71783 L .50719 .71811 L p .707 .577 .707 r
F P
0 g
s
.52406 .73838 m .51871 .77633 L .50319 .77171 L p .707 .577 .707 r
F P
0 g
s
.50319 .77171 m .50855 .73377 L .52406 .73838 L p .707 .577 .707 r
F P
0 g
s
.50818 .80434 m .50916 .78533 L .52542 .7822 L p .707 .577 .707 r
F P
0 g
s
.52325 .71783 m .5281 .66044 L .55188 .66118 L p .707 .577 .707 r
F P
0 g
s
.52542 .7822 m .52444 .80121 L .50818 .80434 L p .707 .577 .707 r
F P
0 g
s
.55188 .66118 m .54703 .71857 L .52325 .71783 L p .707 .577 .707 r
F P
0 g
s
.54734 .74354 m .54199 .78149 L .51871 .77633 L p .707 .577 .707 r
F P
0 g
s
.51871 .77633 m .52406 .73838 L .54734 .74354 L p .707 .577 .707 r
F P
0 g
s
.57611 .74874 m .57076 .78669 L .54199 .78149 L p .707 .577 .707 r
F P
0 g
s
.54199 .78149 m .54734 .74354 L .57611 .74874 L p .707 .577 .707 r
F P
0 g
s
.52444 .80121 m .52542 .7822 L .54937 .78037 L p .707 .577 .707 r
F P
0 g
s
.54937 .78037 m .5484 .79938 L .52444 .80121 L p .707 .577 .707 r
F P
0 g
s
.48485 .33515 m .50041 .82496 L .54533 .8223 L p .707 .577 .707 r
F P
0 g
s
.54533 .8223 m .52976 .33248 L .48485 .33515 L p .707 .577 .707 r
F P
0 g
s
.54703 .71857 m .55188 .66118 L .58104 .66287 L p .707 .577 .707 r
F P
0 g
s
.58104 .66287 m .5762 .72026 L .54703 .71857 L p .707 .577 .707 r
F P
0 g
s
.60756 .75347 m .6022 .79142 L .57076 .78669 L p .707 .577 .707 r
F P
0 g
s
.57076 .78669 m .57611 .74874 L .60756 .75347 L p .707 .577 .707 r
F P
0 g
s
.5484 .79938 m .54937 .78037 L .57868 .78002 L p .707 .577 .707 r
F P
0 g
s
.57868 .78002 m .5777 .79903 L .5484 .79938 L p .707 .577 .707 r
F P
0 g
s
.6022 .79142 m .60756 .75347 L .63859 .75727 L p .707 .577 .707 r
F P
0 g
s
.5777 .79903 m .57868 .78002 L .61046 .78119 L p .707 .577 .707 r
F P
0 g
s
.63859 .75727 m .63323 .79522 L .6022 .79142 L p .707 .577 .707 r
F P
0 g
s
.61046 .78119 m .60948 .8002 L .5777 .79903 L p .707 .577 .707 r
F P
0 g
s
.52976 .33248 m .54533 .8223 L .58677 .81508 L p .707 .577 .707 r
F P
0 g
s
.5762 .72026 m .58104 .66287 L .61274 .66535 L p .707 .577 .707 r
F P
0 g
s
.61274 .66535 m .60789 .72274 L .5762 .72026 L p .707 .577 .707 r
F P
0 g
s
.58677 .81508 m .57121 .32526 L .52976 .33248 L p .707 .577 .707 r
F P
0 g
s
.69889 .8057 m .69791 .8247 L .70489 .82057 L p .707 .577 .707 r
F P
0 g
s
.70489 .82057 m .70586 .80157 L .69889 .8057 L p .707 .577 .707 r
F P
0 g
s
.45641 .82282 m .44085 .333 L .40207 .32626 L p .707 .577 .707 r
F P
0 g
s
.44085 .333 m .45641 .82282 L .50041 .82496 L p .707 .577 .707 r
F P
0 g
s
.70855 .67981 m .7037 .7372 L .70053 .73505 L p .707 .577 .707 r
F P
0 g
s
.70053 .73505 m .70538 .67765 L .70855 .67981 L p .707 .577 .707 r
F P
0 g
s
.64386 .66837 m .63902 .72577 L .61613 .72354 L p .707 .577 .707 r
F P
0 g
s
.61613 .72354 m .60789 .72274 L p .61666 .70949 L .707 .577 .707 r
F P
0 g
s
.61666 .70949 m .64386 .66837 L .61613 .72354 L .707 .577 .707 r
F
.67137 .67164 m .66652 .72904 L .63902 .72577 L p F P
0 g
s
.63902 .72577 m .64386 .66837 L .67137 .67164 L p .707 .577 .707 r
F P
0 g
s
.66619 .75977 m .66083 .79771 L .63323 .79522 L p .707 .577 .707 r
F P
0 g
s
.63323 .79522 m .63859 .75727 L .66619 .75977 L p .707 .577 .707 r
F P
0 g
s
.60789 .72274 m .61274 .66535 L .64386 .66837 L p .707 .577 .707 r
F P
0 g
s
.68763 .76071 m .68228 .79866 L .66083 .79771 L p .707 .577 .707 r
F P
0 g
s
.66083 .79771 m .66619 .75977 L .68763 .76071 L p .707 .577 .707 r
F P
0 g
s
.64064 .80277 m .64162 .78376 L .66909 .78748 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .65368 .77497 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62817 .30038 m .62996 .35672 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62996 .35672 m .64374 .7902 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.64162 .78376 m .64064 .80277 L .60948 .8002 L p .707 .577 .707 r
F P
0 g
s
.60948 .8002 m .61046 .78119 L .64162 .78376 L p .707 .577 .707 r
F P
0 g
s
.57121 .32526 m .58677 .81508 L .62068 .80402 L p .707 .577 .707 r
F P
0 g
s
.62068 .80402 m .60512 .3142 L .57121 .32526 L p .707 .577 .707 r
F P
0 g
s
.70451 .75775 m .69915 .7957 L .69548 .79796 L p .707 .577 .707 r
F P
0 g
s
.69548 .79796 m .70084 .76002 L .70451 .75775 L p .707 .577 .707 r
F P
0 g
s
.41764 .81608 m .40207 .32626 L .37232 .31558 L p .707 .577 .707 r
F P
0 g
s
.40207 .32626 m .41764 .81608 L .45641 .82282 L p .707 .577 .707 r
F P
0 g
s
.70586 .80157 m .70489 .82057 L .70189 .81585 L p .707 .577 .707 r
F P
0 g
s
.70189 .81585 m .70287 .79684 L .70586 .80157 L p .707 .577 .707 r
F P
0 g
s
.70538 .67765 m .70053 .73505 L .68772 .73223 L p .707 .577 .707 r
F P
0 g
s
.68772 .73223 m .69257 .67484 L .70538 .67765 L p .707 .577 .707 r
F P
0 g
s
.60512 .3142 m .62068 .80402 L .64374 .7902 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .62817 .30038 L .60512 .3142 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25321 .69703 m .25805 .63964 L .22693 .63662 L p .707 .577 .707 r
F P
0 g
s
.25805 .63964 m .25321 .69703 L .2849 .69951 L p .707 .577 .707 r
F P
0 g
s
.2849 .69951 m .28975 .64212 L .25805 .63964 L p .707 .577 .707 r
F P
0 g
s
.28975 .64212 m .2849 .69951 L .31407 .70121 L p .707 .577 .707 r
F P
0 g
s
.31407 .70121 m .31891 .64381 L .28975 .64212 L p .707 .577 .707 r
F P
0 g
s
.22693 .63662 m .22208 .69401 L .25321 .69703 L p .707 .577 .707 r
F P
0 g
s
.70084 .76002 m .69548 .79796 L .68228 .79866 L p .707 .577 .707 r
F P
0 g
s
.22208 .69401 m .22693 .63662 L .19942 .63335 L p .707 .577 .707 r
F P
0 g
s
.68228 .79866 m .68763 .76071 L .70084 .76002 L p .707 .577 .707 r
F P
0 g
s
.22523 .69382 m .21987 .73176 L .25091 .73556 L p .707 .577 .707 r
F P
0 g
s
.25091 .73556 m .25627 .69761 L .22523 .69382 L p .707 .577 .707 r
F P
0 g
s
.25627 .69761 m .25091 .73556 L .28235 .74029 L p .707 .577 .707 r
F P
0 g
s
.19942 .63335 m .19458 .69074 L .22208 .69401 L p .707 .577 .707 r
F P
0 g
s
.28235 .74029 m .28771 .70234 L .25627 .69761 L p .707 .577 .707 r
F P
0 g
s
.28771 .70234 m .28235 .74029 L .31112 .74549 L p .707 .577 .707 r
F P
0 g
s
.31112 .74549 m .31648 .70754 L .28771 .70234 L p .707 .577 .707 r
F P
0 g
s
.19764 .69132 m .19228 .72927 L .21987 .73176 L p .707 .577 .707 r
F P
0 g
s
.21987 .73176 m .22523 .69382 L .19764 .69132 L p .707 .577 .707 r
F P
0 g
s
.38789 .8054 m .37232 .31558 L .35451 .302 L p .707 .577 .707 r
F P
0 g
s
.37232 .31558 m .38789 .8054 L .41764 .81608 L p .707 .577 .707 r
F P
0 g
s
.31891 .64381 m .31407 .70121 L .33785 .70195 L p .707 .577 .707 r
F P
0 g
s
.33785 .70195 m .34269 .64455 L .31891 .64381 L p .707 .577 .707 r
F P
0 g
s
.19458 .69074 m .19942 .63335 L .17823 .63015 L p .707 .577 .707 r
F P
0 g
s
.70287 .79684 m .70189 .81585 L .68922 .811 L p .707 .577 .707 r
F P
0 g
s
.68922 .811 m .6902 .79199 L .70287 .79684 L p .707 .577 .707 r
F P
0 g
s
.31648 .70754 m .31112 .74549 L .3344 .75065 L p .707 .577 .707 r
F P
0 g
s
.69257 .67484 m .68772 .73223 L .66652 .72904 L p .707 .577 .707 r
F P
0 g
s
.66652 .72904 m .67137 .67164 L .69257 .67484 L p .707 .577 .707 r
F P
0 g
s
.17823 .63015 m .17338 .68754 L .19458 .69074 L p .707 .577 .707 r
F P
0 g
s
.3344 .75065 m .33976 .7127 L .31648 .70754 L p .707 .577 .707 r
F P
0 g
s
.2536 .79203 m .25458 .77302 L .22343 .77045 L p .707 .577 .707 r
F P
0 g
s
.25458 .77302 m .2536 .79203 L .28539 .7932 L p .707 .577 .707 r
F P
0 g
s
.28539 .7932 m .28637 .77419 L .25458 .77302 L p .707 .577 .707 r
F P
0 g
s
.17619 .69037 m .17083 .72832 L .19228 .72927 L p .707 .577 .707 r
F P
0 g
s
.19228 .72927 m .19764 .69132 L .17619 .69037 L p .707 .577 .707 r
F P
0 g
s
.22343 .77045 m .22245 .78946 L .2536 .79203 L p .707 .577 .707 r
F P
0 g
s
.28637 .77419 m .28539 .7932 L .31469 .79285 L p .707 .577 .707 r
F P
0 g
s
.31469 .79285 m .31567 .77384 L .28637 .77419 L p .707 .577 .707 r
F P
0 g
s
.65368 .77497 m .63812 .28515 L .62817 .30038 L p .707 .577 .707 r
F P
0 g
s
.22245 .78946 m .22343 .77045 L .19595 .76673 L p .707 .577 .707 r
F P
0 g
s
.19595 .76673 m .19497 .78574 L .22245 .78946 L p .707 .577 .707 r
F P
0 g
s
.34269 .64455 m .33785 .70195 L .35391 .70166 L p .707 .577 .707 r
F P
0 g
s
.35391 .70166 m .35876 .64427 L .34269 .64455 L p .707 .577 .707 r
F P
0 g
s
.31567 .77384 m .31469 .79285 L .33865 .79102 L p .707 .577 .707 r
F P
0 g
s
.33865 .79102 m .33962 .77201 L .31567 .77384 L p .707 .577 .707 r
F P
0 g
s
.33976 .7127 m .3344 .75065 L .34991 .75526 L p .707 .577 .707 r
F P
0 g
s
.17338 .68754 m .17823 .63015 L .16542 .62734 L p .707 .577 .707 r
F P
0 g
s
.34991 .75526 m .35527 .71732 L .33976 .7127 L p .707 .577 .707 r
F P
0 g
s
.16542 .62734 m .16057 .68473 L .17338 .68754 L p .707 .577 .707 r
F P
0 g
s
.19497 .78574 m .19595 .76673 L .17484 .76222 L p .707 .577 .707 r
F P
0 g
s
.6902 .79199 m .68922 .811 L .66811 .80649 L p .707 .577 .707 r
F P
0 g
s
.66811 .80649 m .66909 .78748 L .6902 .79199 L p .707 .577 .707 r
F P
0 g
s
.17484 .76222 m .17387 .78123 L .19497 .78574 L p .707 .577 .707 r
F P
0 g
s
.36069 .70038 m .36554 .64299 L .35876 .64427 L p .707 .577 .707 r
F P
0 g
s
.35876 .64427 m .35391 .70166 L .36069 .70038 L p .707 .577 .707 r
F P
0 g
s
.36554 .64299 m .36069 .70038 L .35752 .69823 L p .707 .577 .707 r
F P
0 g
s
.35752 .69823 m .36237 .64084 L .36554 .64299 L p .707 .577 .707 r
F P
0 g
s
.37007 .79182 m .35451 .302 L .35037 .28686 L p .707 .577 .707 r
F P
0 g
s
.35451 .302 m .37007 .79182 L .38789 .8054 L p .707 .577 .707 r
F P
0 g
s
.16298 .69107 m .15762 .72901 L .17083 .72832 L p .707 .577 .707 r
F P
0 g
s
.17083 .72832 m .17619 .69037 L .16298 .69107 L p .707 .577 .707 r
F P
0 g
s
.33962 .77201 m .33865 .79102 L .35491 .78789 L p .707 .577 .707 r
F P
0 g
s
.35491 .78789 m .35588 .76888 L .33962 .77201 L p .707 .577 .707 r
F P
0 g
s
.35527 .71732 m .34991 .75526 L .35614 .75888 L p .707 .577 .707 r
F P
0 g
s
.17387 .78123 m .17484 .76222 L .16217 .75737 L p .707 .577 .707 r
F P
0 g
s
.66909 .78748 m .66811 .80649 L .64064 .80277 L p .707 .577 .707 r
F P
0 g
s
.16057 .68473 m .16542 .62734 L .16225 .62519 L p .707 .577 .707 r
F P
0 g
s
.63812 .28515 m .65205 .72358 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .63812 .28515 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.63784 .6788 m .6472 .67831 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .64591 .64553 L p .63209 .66964 L .707 .577 .707 r
F P
0 g
s
.64591 .64553 m .64685 .67507 L p .63878 .6721 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .64591 .64553 L .63878 .6721 L .707 .577 .707 r
F
.64955 .75983 m .63173 .74625 L p .63209 .66964 L F P
0 g
s
.63682 .67943 m .63784 .6788 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63878 .6721 m .63784 .6788 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.64685 .67507 m .64955 .75983 L p .63517 .68556 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .63878 .6721 L .63517 .68556 L .707 .577 .707 r
F
.63784 .6788 m .63878 .6721 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .64685 .67507 L .63517 .68556 L .707 .577 .707 r
F
.6432 .64085 m .63953 .64312 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .6432 .64085 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63953 .64312 m .63417 .68106 L .63682 .67943 L p .707 .577 .707 r
F P
0 g
s
.63802 .67495 m .63953 .64312 L .63682 .67943 L .707 .577 .707 r
F
.64316 .6411 m .63878 .6721 L p .64685 .67507 L F P
0 g
s
.64936 .75218 m .64685 .67507 L .64769 .68279 L .707 .577 .707 r
F
.64925 .75062 m .64685 .67507 L p .64936 .75218 L F P
0 g
s
.65368 .77497 m .65001 .76153 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.65001 .76153 m .64955 .75983 L p .64936 .75218 L .707 .577 .707 r
F P
0 g
s
.64936 .75218 m .64731 .66703 L .65001 .76153 L .707 .577 .707 r
F
.64239 .72141 m .64141 .74041 L .64874 .74322 L p F P
0 g
s
.65205 .72358 m .65368 .77497 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.64874 .74322 m .65408 .74527 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.64802 .73291 m .64239 .72141 L .64874 .74322 L .707 .577 .707 r
F
.65408 .74527 m .65506 .72626 L .64736 .72331 L p F P
0 g
s
.64736 .72331 m .64239 .72141 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.65408 .74527 m .64736 .72331 L .64802 .73291 L .707 .577 .707 r
F
.64955 .75983 m .64925 .75062 L p .64936 .75218 L F P
0 g
s
.64685 .67507 m .63398 .27001 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.6432 .64085 m .64316 .6411 L p .65104 .6781 L .707 .577 .707 r
F P
0 g
s
.6472 .67831 m .65104 .6781 L p .64316 .6411 L .707 .577 .707 r
F P
0 g
s
.64563 .5595 m .64195 .60306 L p .65359 .6197 L .707 .577 .707 r
F P
0 g
s
.64195 .60306 m .64078 .61689 L .64315 .61741 L p .707 .577 .707 r
F P
0 g
s
.64315 .61741 m .65359 .6197 L p .64195 .60306 L .707 .577 .707 r
F P
0 g
s
.35614 .75888 m .3615 .72094 L .35527 .71732 L p .707 .577 .707 r
F P
0 g
s
.16217 .75737 m .1612 .77638 L .17387 .78123 L p .707 .577 .707 r
F P
0 g
s
.16225 .62519 m .1574 .68258 L .16057 .68473 L p .707 .577 .707 r
F P
0 g
s
.15931 .69334 m .15396 .73128 L .15762 .72901 L p .707 .577 .707 r
F P
0 g
s
.15762 .72901 m .16298 .69107 L .15931 .69334 L p .707 .577 .707 r
F P
0 g
s
.35588 .76888 m .35491 .78789 L .36188 .78376 L p .707 .577 .707 r
F P
0 g
s
.36188 .78376 m .36285 .76475 L .35588 .76888 L p .707 .577 .707 r
F P
0 g
s
.36237 .64084 m .35752 .69823 L .34475 .69543 L p .707 .577 .707 r
F P
0 g
s
.34475 .69543 m .34471 .69542 L p .34476 .69527 L .707 .577 .707 r
F P
0 g
s
.34476 .69527 m .36237 .64084 L .34475 .69543 L .707 .577 .707 r
F
.35037 .28686 m .36032 .27163 L p .36144 .3731 L F P
0 g
s
.36452 .64952 m .36594 .77668 L .37007 .79182 L p .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35705 .45799 L p .35037 .28686 L .707 .577 .707 r
F P
0 g
s
.34471 .69542 m .34956 .63803 L .36237 .64084 L p .707 .577 .707 r
F P
0 g
s
.36594 .77668 m .35628 .47282 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35037 .28686 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.1612 .77638 m .16217 .75737 L .15918 .75265 L p .707 .577 .707 r
F P
0 g
s
.3615 .72094 m .35614 .75888 L .35247 .76115 L p .707 .577 .707 r
F P
0 g
s
.15918 .75265 m .1582 .77166 L .1612 .77638 L p .707 .577 .707 r
F P
0 g
s
.1574 .68258 m .16225 .62519 L .16903 .62391 L p .707 .577 .707 r
F P
0 g
s
.35247 .76115 m .35783 .7232 L .3615 .72094 L p .707 .577 .707 r
F P
0 g
s
.16903 .62391 m .16418 .6813 L .1574 .68258 L p .707 .577 .707 r
F P
0 g
s
.16554 .69695 m .16018 .7349 L .15396 .73128 L p .707 .577 .707 r
F P
0 g
s
.15396 .73128 m .15931 .69334 L .16554 .69695 L p .707 .577 .707 r
F P
0 g
s
.63173 .74625 m .61616 .25643 L .63398 .27001 L p .707 .577 .707 r
F P
0 g
s
.36285 .76475 m .36188 .78376 L .35888 .77904 L p .707 .577 .707 r
F P
0 g
s
.35888 .77904 m .35986 .76003 L .36285 .76475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1582 .77166 m .15918 .75265 L .16615 .74852 L p .707 .577 .707 r
F P
0 g
s
.35783 .7232 m .35247 .76115 L .33927 .76184 L p .707 .577 .707 r
F P
0 g
s
.16615 .74852 m .16517 .76753 L .1582 .77166 L p .707 .577 .707 r
F P
0 g
s
.37588 .76145 m .36032 .27163 L .38337 .25781 L p .707 .577 .707 r
F P
0 g
s
.36032 .27163 m .37588 .76145 L .36594 .77668 L p .707 .577 .707 r
F P
0 g
s
.16418 .6813 m .16903 .62391 L .18509 .62362 L p .707 .577 .707 r
F P
0 g
s
.33927 .76184 m .34463 .7239 L .35783 .7232 L p .707 .577 .707 r
F P
0 g
s
.18509 .62362 m .18024 .68102 L .16418 .6813 L p .707 .577 .707 r
F P
0 g
s
.18105 .70157 m .1757 .73951 L .16018 .7349 L p .707 .577 .707 r
F P
0 g
s
.16018 .7349 m .16554 .69695 L .18105 .70157 L p .707 .577 .707 r
F P
0 g
s
.35986 .76003 m .35888 .77904 L .34621 .77418 L p .707 .577 .707 r
F P
0 g
s
.34621 .77418 m .34719 .75517 L .35986 .76003 L p .707 .577 .707 r
F P
0 g
s
.34956 .63803 m .34471 .69542 L .32351 .69222 L p .707 .577 .707 r
F P
0 g
s
.32351 .69222 m .32836 .63483 L .34956 .63803 L p .707 .577 .707 r
F P
0 g
s
.61616 .25643 m .63173 .74625 L .60198 .73557 L p .707 .577 .707 r
F P
0 g
s
.60198 .73557 m .58641 .24575 L .61616 .25643 L p .707 .577 .707 r
F P
0 g
s
.34463 .7239 m .33927 .76184 L .31782 .7609 L p .707 .577 .707 r
F P
0 g
s
.16517 .76753 m .16615 .74852 L .18241 .74538 L p .707 .577 .707 r
F P
0 g
s
.18024 .68102 m .18509 .62362 L .20887 .62436 L p .707 .577 .707 r
F P
0 g
s
.18241 .74538 m .18143 .76439 L .16517 .76753 L p .707 .577 .707 r
F P
0 g
s
.31782 .7609 m .32318 .72295 L .34463 .7239 L p .707 .577 .707 r
F P
0 g
s
.20887 .62436 m .20402 .68176 L .18024 .68102 L p .707 .577 .707 r
F P
0 g
s
.20433 .70673 m .19898 .74467 L .1757 .73951 L p .707 .577 .707 r
F P
0 g
s
.1757 .73951 m .18105 .70157 L .20433 .70673 L p .707 .577 .707 r
F P
0 g
s
.38337 .25781 m .39791 .71524 L p .37588 .76145 L .707 .577 .707 r
F P
0 g
s
.39894 .74763 m .38337 .25781 L .41728 .24675 L p .707 .577 .707 r
F P
0 g
s
.43285 .73657 m .39894 .74763 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.41728 .24675 m .42946 .63003 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.42946 .63003 m .43015 .65181 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.40111 .68841 m .43015 .65181 L .40174 .68937 L .707 .577 .707 r
F
.42491 .61531 m .41955 .65326 L .42792 .65477 L p F P
0 g
s
.41728 .24675 m .45872 .23953 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.42792 .65477 m .44832 .65846 L p .4447 .65178 L .707 .577 .707 r
F P
0 g
s
.4447 .65178 m .43015 .65181 L .42792 .65477 L .707 .577 .707 r
F
.43285 .73657 m .43015 .65181 L p .43726 .6518 L F P
0 g
s
.43015 .65181 m .41728 .24675 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .43285 .73657 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45872 .23953 m .47182 .6517 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.44927 .65176 m .44832 .65846 L .4548 .65989 L p .707 .577 .707 r
F P
0 g
s
.43726 .6518 m .43811 .63536 L .44927 .65176 L .707 .577 .707 r
F
.43811 .63536 m .45872 .23953 L .44927 .65176 L F
.44832 .65846 m .45368 .62051 L .42491 .61531 L p F P
0 g
s
.47182 .6517 m .47429 .72935 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45368 .62051 m .44927 .65176 L p .47161 .66362 L .707 .577 .707 r
F P
0 g
s
.4548 .65989 m .47161 .66362 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.43864 .6406 m .42491 .61531 L .42769 .65182 L .707 .577 .707 r
F
.43015 .65181 m .42769 .65182 L .42792 .65477 L F
.43864 .6406 m .42769 .65182 L .43015 .65181 L F
.4447 .65178 m .43864 .6406 L .43015 .65181 L F
.43015 .65181 m .43255 .72736 L p .40174 .68937 L F P
0 g
s
.40174 .68937 m .43255 .72736 L .4306 .73316 L .707 .577 .707 r
F
.42357 .70141 m .42259 .72042 L .43494 .72028 L p F P
0 g
s
.43494 .72028 m .4519 .72007 L p .43808 .71097 L .707 .577 .707 r
F P
0 g
s
.43808 .71097 m .42357 .70141 L .43494 .72028 L .707 .577 .707 r
F
.43255 .72736 m .43285 .73657 L p .4306 .73316 L F P
0 g
s
.42695 .53747 m .42211 .59486 L .44587 .59624 L p .707 .577 .707 r
F P
0 g
s
.44587 .59624 m .45127 .59655 L p .44872 .59037 L .707 .577 .707 r
F P
0 g
s
.44872 .59037 m .42695 .53747 L .44587 .59624 L .707 .577 .707 r
F
.39526 .53499 m .39041 .59238 L .41525 .59432 L p F P
0 g
s
.41525 .59432 m .42211 .59486 L p .41685 .58315 L .707 .577 .707 r
F P
0 g
s
.41685 .58315 m .39526 .53499 L .41525 .59432 L .707 .577 .707 r
F
.39791 .71524 m .39894 .74763 L .39273 .75135 L p F P
0 g
s
.39273 .75135 m .37588 .76145 L p .39791 .71524 L .707 .577 .707 r
F P
0 g
s
.32836 .63483 m .32351 .69222 L .29601 .68895 L p .707 .577 .707 r
F P
0 g
s
.29601 .68895 m .30085 .63156 L .32836 .63483 L p .707 .577 .707 r
F P
0 g
s
.34719 .75517 m .34621 .77418 L .3251 .76967 L p .707 .577 .707 r
F P
0 g
s
.3251 .76967 m .32608 .75067 L .34719 .75517 L p .707 .577 .707 r
F P
0 g
s
.20402 .68176 m .20887 .62436 L .23803 .62606 L p .707 .577 .707 r
F P
0 g
s
.32318 .72295 m .31782 .7609 L .29022 .7584 L p .707 .577 .707 r
F P
0 g
s
.58641 .24575 m .60198 .73557 L .56321 .72882 L p .707 .577 .707 r
F P
0 g
s
.56321 .72882 m .54764 .239 L .58641 .24575 L p .707 .577 .707 r
F P
0 g
s
.23803 .62606 m .23319 .68345 L .20402 .68176 L p .707 .577 .707 r
F P
0 g
s
.29022 .7584 m .29558 .72046 L .32318 .72295 L p .707 .577 .707 r
F P
0 g
s
.2331 .71193 m .22775 .74987 L .19898 .74467 L p .707 .577 .707 r
F P
0 g
s
.19898 .74467 m .20433 .70673 L .2331 .71193 L p .707 .577 .707 r
F P
0 g
s
.18143 .76439 m .18241 .74538 L .20636 .74355 L p .707 .577 .707 r
F P
0 g
s
.73342 .6292 m .73827 .5718 L .70714 .56878 L p .707 .577 .707 r
F P
0 g
s
.73827 .5718 m .73342 .6292 L .76512 .63167 L p .707 .577 .707 r
F P
0 g
s
.76512 .63167 m .76996 .57428 L .73827 .5718 L p .707 .577 .707 r
F P
0 g
s
.20636 .74355 m .20539 .76256 L .18143 .76439 L p .707 .577 .707 r
F P
0 g
s
.30085 .63156 m .29601 .68895 L .26488 .68593 L p .707 .577 .707 r
F P
0 g
s
.26488 .68593 m .26973 .62853 L .30085 .63156 L p .707 .577 .707 r
F P
0 g
s
.76996 .57428 m .76512 .63167 L .79428 .63337 L p .707 .577 .707 r
F P
0 g
s
.79428 .63337 m .79913 .57597 L .76996 .57428 L p .707 .577 .707 r
F P
0 g
s
.70714 .56878 m .7023 .62617 L .73342 .6292 L p .707 .577 .707 r
F P
0 g
s
.23319 .68345 m .23803 .62606 L .26973 .62853 L p .707 .577 .707 r
F P
0 g
s
.7023 .62617 m .70714 .56878 L .67964 .56551 L p .707 .577 .707 r
F P
0 g
s
.26973 .62853 m .26488 .68593 L .23319 .68345 L p .707 .577 .707 r
F P
0 g
s
.67964 .56551 m .67479 .6229 L .7023 .62617 L p .707 .577 .707 r
F P
0 g
s
.29558 .72046 m .29022 .7584 L .25919 .7546 L p .707 .577 .707 r
F P
0 g
s
.32608 .75067 m .3251 .76967 L .29763 .76595 L p .707 .577 .707 r
F P
0 g
s
.29763 .76595 m .29861 .74694 L .32608 .75067 L p .707 .577 .707 r
F P
0 g
s
.70544 .6436 m .70009 .68154 L .73112 .68534 L p .707 .577 .707 r
F P
0 g
s
.73112 .68534 m .73648 .6474 L .70544 .6436 L p .707 .577 .707 r
F P
0 g
s
.73648 .6474 m .73112 .68534 L .76256 .69007 L p .707 .577 .707 r
F P
0 g
s
.25919 .7546 m .26455 .71666 L .29558 .72046 L p .707 .577 .707 r
F P
0 g
s
.26455 .71666 m .25919 .7546 L .22775 .74987 L p .707 .577 .707 r
F P
0 g
s
.22775 .74987 m .2331 .71193 L .26455 .71666 L p .707 .577 .707 r
F P
0 g
s
.79913 .57597 m .79428 .63337 L .81806 .63411 L p .707 .577 .707 r
F P
0 g
s
.81806 .63411 m .82291 .57671 L .79913 .57597 L p .707 .577 .707 r
F P
0 g
s
.76256 .69007 m .76792 .65213 L .73648 .6474 L p .707 .577 .707 r
F P
0 g
s
.76792 .65213 m .76256 .69007 L .79133 .69527 L p .707 .577 .707 r
F P
0 g
s
.54764 .239 m .56321 .72882 L .51921 .72668 L p .707 .577 .707 r
F P
0 g
s
.51921 .72668 m .50364 .23686 L .54764 .239 L p .707 .577 .707 r
F P
0 g
s
.20539 .76256 m .20636 .74355 L .23567 .7432 L p .707 .577 .707 r
F P
0 g
s
.79133 .69527 m .79669 .65733 L .76792 .65213 L p .707 .577 .707 r
F P
0 g
s
.67785 .64111 m .67249 .67905 L .70009 .68154 L p .707 .577 .707 r
F P
0 g
s
.70009 .68154 m .70544 .6436 L .67785 .64111 L p .707 .577 .707 r
F P
0 g
s
.23567 .7432 m .23469 .76221 L .20539 .76256 L p .707 .577 .707 r
F P
0 g
s
.67479 .6229 m .67964 .56551 L .65844 .56231 L p .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .45872 .23953 L .50364 .23686 L p .707 .577 .707 r
F P
0 g
s
.65844 .56231 m .65359 .6197 L .67479 .6229 L p .707 .577 .707 r
F P
0 g
s
.50364 .23686 m .51921 .72668 L .47429 .72935 L p .707 .577 .707 r
F P
0 g
s
.29861 .74694 m .29763 .76595 L .26647 .76338 L p .707 .577 .707 r
F P
0 g
s
.26647 .76338 m .26745 .74437 L .29861 .74694 L p .707 .577 .707 r
F P
0 g
s
.79669 .65733 m .79133 .69527 L .81462 .70043 L p .707 .577 .707 r
F P
0 g
s
.23469 .76221 m .23567 .7432 L .26745 .74437 L p .707 .577 .707 r
F P
0 g
s
.81462 .70043 m .81997 .66249 L .79669 .65733 L p .707 .577 .707 r
F P
0 g
s
.26745 .74437 m .26647 .76338 L .23469 .76221 L p .707 .577 .707 r
F P
0 g
s
.6564 .64016 m .65104 .6781 L .67249 .67905 L p .707 .577 .707 r
F P
0 g
s
.67249 .67905 m .67785 .64111 L .6564 .64016 L p .707 .577 .707 r
F P
0 g
s
.73382 .75607 m .73479 .73706 L .70364 .73449 L p .707 .577 .707 r
F P
0 g
s
.73479 .73706 m .73382 .75607 L .7656 .75724 L p .707 .577 .707 r
F P
0 g
s
.7656 .75724 m .76658 .73823 L .73479 .73706 L p .707 .577 .707 r
F P
0 g
s
.82291 .57671 m .81806 .63411 L .83412 .63382 L p .707 .577 .707 r
F P
0 g
s
.83412 .63382 m .83897 .57643 L .82291 .57671 L p .707 .577 .707 r
F P
0 g
s
.70364 .73449 m .70266 .7535 L .73382 .75607 L p .707 .577 .707 r
F P
0 g
s
.76658 .73823 m .7656 .75724 L .79491 .75689 L p .707 .577 .707 r
F P
0 g
s
.79491 .75689 m .79588 .73788 L .76658 .73823 L p .707 .577 .707 r
F P
0 g
s
.70266 .7535 m .70364 .73449 L .67616 .73077 L p .707 .577 .707 r
F P
0 g
s
.65359 .6197 m .65844 .56231 L .64563 .5595 L p .707 .577 .707 r
F P
0 g
s
.67616 .73077 m .67519 .74978 L .70266 .7535 L p .707 .577 .707 r
F P
0 g
s
.81997 .66249 m .81462 .70043 L .83013 .70505 L p .707 .577 .707 r
F P
0 g
s
.79588 .73788 m .79491 .75689 L .81886 .75506 L p .707 .577 .707 r
F P
0 g
s
.81886 .75506 m .81984 .73605 L .79588 .73788 L p .707 .577 .707 r
F P
0 g
s
.83013 .70505 m .83549 .6671 L .81997 .66249 L p .707 .577 .707 r
F P
0 g
s
.65104 .6781 m .6564 .64016 L .6432 .64085 L p .707 .577 .707 r
F P
0 g
s
.67519 .74978 m .67616 .73077 L .65506 .72626 L p .707 .577 .707 r
F P
0 g
s
.65506 .72626 m .65408 .74527 L .67519 .74978 L p .707 .577 .707 r
F P
0 g
s
.83897 .57643 m .83412 .63382 L .8409 .63254 L p .707 .577 .707 r
F P
0 g
s
.8409 .63254 m .84575 .57515 L .83897 .57643 L p .707 .577 .707 r
F P
0 g
s
.81984 .73605 m .81886 .75506 L .83512 .75192 L p .707 .577 .707 r
F P
0 g
s
.83512 .75192 m .8361 .73292 L .81984 .73605 L p .707 .577 .707 r
F P
0 g
s
.64078 .61689 m .64563 .5595 L .64246 .55735 L p .707 .577 .707 r
F P
0 g
s
.83549 .6671 m .83013 .70505 L .83636 .70866 L p .707 .577 .707 r
F P
0 g
s
.64246 .55735 m .63761 .61474 L .64078 .61689 L p .707 .577 .707 r
F P
0 g
s
.83636 .70866 m .84171 .67072 L .83549 .6671 L p .707 .577 .707 r
F P
0 g
s
.84575 .57515 m .8409 .63254 L .83773 .63039 L p .707 .577 .707 r
F P
0 g
s
.83773 .63039 m .84258 .573 L .84575 .57515 L p .707 .577 .707 r
F P
0 g
s
.8361 .73292 m .83512 .75192 L .84209 .74779 L p .707 .577 .707 r
F P
0 g
s
.84209 .74779 m .84307 .72879 L .8361 .73292 L p .707 .577 .707 r
F P
0 g
s
.63761 .61474 m .64246 .55735 L .64924 .55607 L p .707 .577 .707 r
F P
0 g
s
.84171 .67072 m .83636 .70866 L .83269 .71093 L p .707 .577 .707 r
F P
0 g
s
.64924 .55607 m .64439 .61346 L .63761 .61474 L p .707 .577 .707 r
F P
0 g
s
.64141 .74041 m .64239 .72141 L .63939 .71668 L p .707 .577 .707 r
F P
0 g
s
.83269 .71093 m .83804 .67299 L .84171 .67072 L p .707 .577 .707 r
F P
0 g
s
.63939 .71668 m .63841 .73569 L .64141 .74041 L p .707 .577 .707 r
F P
0 g
s
.64575 .64674 m .6404 .68468 L .63417 .68106 L p .707 .577 .707 r
F P
0 g
s
.63417 .68106 m .63953 .64312 L .64575 .64674 L p .707 .577 .707 r
F P
0 g
s
.84258 .573 m .83773 .63039 L .82492 .62758 L p .707 .577 .707 r
F P
0 g
s
.82492 .62758 m .82977 .57019 L .84258 .573 L p .707 .577 .707 r
F P
0 g
s
.39041 .59238 m .39526 .53499 L .36413 .53196 L p .707 .577 .707 r
F P
0 g
s
.42211 .59486 m .42695 .53747 L .39526 .53499 L p .707 .577 .707 r
F P
0 g
s
.84307 .72879 m .84209 .74779 L .8391 .74307 L p .707 .577 .707 r
F P
0 g
s
.8391 .74307 m .84007 .72406 L .84307 .72879 L p .707 .577 .707 r
F P
0 g
s
.45127 .59655 m .45612 .53916 L .42695 .53747 L p .707 .577 .707 r
F P
0 g
s
.36413 .53196 m .35929 .58936 L .39041 .59238 L p .707 .577 .707 r
F P
0 g
s
.64439 .61346 m .64924 .55607 L .6653 .55578 L p .707 .577 .707 r
F P
0 g
s
.35929 .58936 m .36413 .53196 L .33663 .52869 L p .707 .577 .707 r
F P
0 g
s
.83804 .67299 m .83269 .71093 L .81948 .71163 L p .707 .577 .707 r
F P
0 g
s
.6653 .55578 m .66046 .61318 L .64439 .61346 L p .707 .577 .707 r
F P
0 g
s
.33663 .52869 m .33178 .58609 L .35929 .58936 L p .707 .577 .707 r
F P
0 g
s
.63841 .73569 m .63939 .71668 L .64636 .71255 L p .707 .577 .707 r
F P
0 g
s
.81948 .71163 m .82484 .67368 L .83804 .67299 L p .707 .577 .707 r
F P
0 g
s
.36243 .60678 m .35708 .64473 L .38811 .64853 L p .707 .577 .707 r
F P
0 g
s
.38811 .64853 m .39347 .61058 L .36243 .60678 L p .707 .577 .707 r
F P
0 g
s
.39347 .61058 m .38811 .64853 L .41955 .65326 L p .707 .577 .707 r
F P
0 g
s
.64636 .71255 m .64539 .73156 L .63841 .73569 L p .707 .577 .707 r
F P
0 g
s
.45612 .53916 m .45127 .59655 L .47505 .59729 L p .707 .577 .707 r
F P
0 g
s
.47505 .59729 m .4799 .5399 L .45612 .53916 L p .707 .577 .707 r
F P
0 g
s
.41955 .65326 m .42491 .61531 L .39347 .61058 L p .707 .577 .707 r
F P
0 g
s
.66127 .65135 m .65591 .6893 L .6404 .68468 L p .707 .577 .707 r
F P
0 g
s
.6404 .68468 m .64575 .64674 L .66127 .65135 L p .707 .577 .707 r
F P
0 g
s
.33484 .60429 m .32948 .64223 L .35708 .64473 L p .707 .577 .707 r
F P
0 g
s
.35708 .64473 m .36243 .60678 L .33484 .60429 L p .707 .577 .707 r
F P
0 g
s
.33178 .58609 m .33663 .52869 L .31543 .5255 L p .707 .577 .707 r
F P
0 g
s
.82977 .57019 m .82492 .62758 L .80373 .62438 L p .707 .577 .707 r
F P
0 g
s
.80373 .62438 m .80857 .56699 L .82977 .57019 L p .707 .577 .707 r
F P
0 g
s
.31543 .5255 m .31058 .58289 L .33178 .58609 L p .707 .577 .707 r
F P
0 g
s
.84007 .72406 m .8391 .74307 L .82642 .73822 L p .707 .577 .707 r
F P
0 g
s
.82642 .73822 m .8274 .71921 L .84007 .72406 L p .707 .577 .707 r
F P
0 g
s
.47161 .66362 m .47696 .62567 L .45368 .62051 L p .707 .577 .707 r
F P
0 g
s
.66046 .61318 m .6653 .55578 L .68908 .55652 L p .707 .577 .707 r
F P
0 g
s
.31339 .60334 m .30803 .64129 L .32948 .64223 L p .707 .577 .707 r
F P
0 g
s
.32948 .64223 m .33484 .60429 L .31339 .60334 L p .707 .577 .707 r
F P
0 g
s
.39081 .71925 m .39178 .70024 L .36063 .69767 L p .707 .577 .707 r
F P
0 g
s
.39178 .70024 m .39081 .71925 L .42259 .72042 L p .707 .577 .707 r
F P
0 g
s
.42259 .72042 m .42357 .70141 L .39178 .70024 L p .707 .577 .707 r
F P
0 g
s
.68908 .55652 m .68424 .61392 L .66046 .61318 L p .707 .577 .707 r
F P
0 g
s
.4799 .5399 m .47505 .59729 L .49111 .59701 L p .707 .577 .707 r
F P
0 g
s
.49111 .59701 m .49596 .53962 L .4799 .5399 L p .707 .577 .707 r
F P
0 g
s
.82484 .67368 m .81948 .71163 L .79803 .71068 L p .707 .577 .707 r
F P
0 g
s
.36063 .69767 m .35965 .71668 L .39081 .71925 L p .707 .577 .707 r
F P
0 g
s
.4519 .72007 m .45287 .70107 L .42357 .70141 L p .707 .577 .707 r
F P
0 g
s
.79803 .71068 m .80339 .67274 L .82484 .67368 L p .707 .577 .707 r
F P
0 g
s
.64539 .73156 m .64636 .71255 L .66262 .70942 L p .707 .577 .707 r
F P
0 g
s
.35965 .71668 m .36063 .69767 L .33315 .69395 L p .707 .577 .707 r
F P
0 g
s
.66262 .70942 m .66165 .72843 L .64539 .73156 L p .707 .577 .707 r
F P
0 g
s
.31058 .58289 m .31543 .5255 L .30262 .52268 L p .707 .577 .707 r
F P
0 g
s
.33315 .69395 m .33218 .71296 L .35965 .71668 L p .707 .577 .707 r
F P
0 g
s
.68455 .65651 m .67919 .69446 L .65591 .6893 L p .707 .577 .707 r
F P
0 g
s
.65591 .6893 m .66127 .65135 L .68455 .65651 L p .707 .577 .707 r
F P
0 g
s
.80857 .56699 m .80373 .62438 L .77622 .62111 L p .707 .577 .707 r
F P
0 g
s
.77622 .62111 m .78107 .56372 L .80857 .56699 L p .707 .577 .707 r
F P
0 g
s
.30262 .52268 m .29777 .58008 L .31058 .58289 L p .707 .577 .707 r
F P
0 g
s
.47696 .62567 m .47161 .66362 L .48712 .66823 L p .707 .577 .707 r
F P
0 g
s
.45287 .70107 m .4519 .72007 L .47585 .71824 L p .707 .577 .707 r
F P
0 g
s
.47585 .71824 m .47683 .69923 L .45287 .70107 L p .707 .577 .707 r
F P
0 g
s
.48712 .66823 m .49248 .63029 L .47696 .62567 L p .707 .577 .707 r
F P
0 g
s
.68424 .61392 m .68908 .55652 L .71825 .55822 L p .707 .577 .707 r
F P
0 g
s
.71825 .55822 m .7134 .61561 L .68424 .61392 L p .707 .577 .707 r
F P
0 g
s
.30019 .60404 m .29483 .64198 L .30803 .64129 L p .707 .577 .707 r
F P
0 g
s
.30803 .64129 m .31339 .60334 L .30019 .60404 L p .707 .577 .707 r
F P
0 g
s
.33218 .71296 m .33315 .69395 L .31205 .68944 L p .707 .577 .707 r
F P
0 g
s
.8274 .71921 m .82642 .73822 L .80532 .73371 L p .707 .577 .707 r
F P
0 g
s
.80532 .73371 m .8063 .7147 L .8274 .71921 L p .707 .577 .707 r
F P
0 g
s
.80339 .67274 m .79803 .71068 L .77044 .70818 L p .707 .577 .707 r
F P
0 g
s
.31205 .68944 m .31107 .70845 L .33218 .71296 L p .707 .577 .707 r
F P
0 g
s
.78107 .56372 m .77622 .62111 L .7451 .61809 L p .707 .577 .707 r
F P
0 g
s
.7451 .61809 m .74994 .5607 L .78107 .56372 L p .707 .577 .707 r
F P
0 g
s
.77044 .70818 m .7758 .67024 L .80339 .67274 L p .707 .577 .707 r
F P
0 g
s
.49596 .53962 m .49111 .59701 L .49789 .59573 L p .707 .577 .707 r
F P
0 g
s
.49789 .59573 m .50274 .53833 L .49596 .53962 L p .707 .577 .707 r
F P
0 g
s
.71332 .66171 m .70796 .69966 L .67919 .69446 L p .707 .577 .707 r
F P
0 g
s
.67919 .69446 m .68455 .65651 L .71332 .66171 L p .707 .577 .707 r
F P
0 g
s
.7134 .61561 m .71825 .55822 L .74994 .5607 L p .707 .577 .707 r
F P
0 g
s
.66165 .72843 m .66262 .70942 L .68658 .70759 L p .707 .577 .707 r
F P
0 g
s
.74994 .5607 m .7451 .61809 L .7134 .61561 L p .707 .577 .707 r
F P
0 g
s
.68658 .70759 m .6856 .7266 L .66165 .72843 L p .707 .577 .707 r
F P
0 g
s
.47683 .69923 m .47585 .71824 L .49211 .71511 L p .707 .577 .707 r
F P
0 g
s
.49211 .71511 m .49309 .6961 L .47683 .69923 L p .707 .577 .707 r
F P
0 g
s
.29777 .58008 m .30262 .52268 L .29945 .52053 L p .707 .577 .707 r
F P
0 g
s
.7758 .67024 m .77044 .70818 L .7394 .70439 L p .707 .577 .707 r
F P
0 g
s
.49248 .63029 m .48712 .66823 L .49335 .67185 L p .707 .577 .707 r
F P
0 g
s
.29945 .52053 m .2946 .57792 L .29777 .58008 L p .707 .577 .707 r
F P
0 g
s
.7394 .70439 m .74476 .66644 L .7758 .67024 L p .707 .577 .707 r
F P
0 g
s
.74476 .66644 m .7394 .70439 L .70796 .69966 L p .707 .577 .707 r
F P
0 g
s
.70796 .69966 m .71332 .66171 L .74476 .66644 L p .707 .577 .707 r
F P
0 g
s
.49335 .67185 m .4987 .6339 L .49248 .63029 L p .707 .577 .707 r
F P
0 g
s
.31107 .70845 m .31205 .68944 L .29938 .68459 L p .707 .577 .707 r
F P
0 g
s
.8063 .7147 m .80532 .73371 L .77784 .72999 L p .707 .577 .707 r
F P
0 g
s
.77784 .72999 m .77882 .71098 L .8063 .7147 L p .707 .577 .707 r
F P
0 g
s
.29938 .68459 m .2984 .7036 L .31107 .70845 L p .707 .577 .707 r
F P
0 g
s
.29652 .6063 m .29116 .64425 L .29483 .64198 L p .707 .577 .707 r
F P
0 g
s
.29483 .64198 m .30019 .60404 L .29652 .6063 L p .707 .577 .707 r
F P
0 g
s
.6856 .7266 m .68658 .70759 L .71588 .70724 L p .707 .577 .707 r
F P
0 g
s
.71588 .70724 m .7149 .72625 L .6856 .7266 L p .707 .577 .707 r
F P
0 g
s
.50274 .53833 m .49789 .59573 L .49472 .59358 L p .707 .577 .707 r
F P
0 g
s
.49472 .59358 m .49957 .53618 L .50274 .53833 L p .707 .577 .707 r
F P
0 g
s
.77882 .71098 m .77784 .72999 L .74669 .72742 L p .707 .577 .707 r
F P
0 g
s
.74669 .72742 m .74767 .70841 L .77882 .71098 L p .707 .577 .707 r
F P
0 g
s
.49309 .6961 m .49211 .71511 L .49908 .71098 L p .707 .577 .707 r
F P
0 g
s
.49908 .71098 m .50006 .69197 L .49309 .6961 L p .707 .577 .707 r
F P
0 g
s
.7149 .72625 m .71588 .70724 L .74767 .70841 L p .707 .577 .707 r
F P
0 g
s
.74767 .70841 m .74669 .72742 L .7149 .72625 L p .707 .577 .707 r
F P
0 g
s
.2946 .57792 m .29945 .52053 L .30623 .51925 L p .707 .577 .707 r
F P
0 g
s
.4987 .6339 m .49335 .67185 L .48968 .67412 L p .707 .577 .707 r
F P
0 g
s
.30623 .51925 m .30138 .57664 L .2946 .57792 L p .707 .577 .707 r
F P
0 g
s
.2984 .7036 m .29938 .68459 L .29638 .67987 L p .707 .577 .707 r
F P
0 g
s
.48968 .67412 m .49503 .63617 L .4987 .6339 L p .707 .577 .707 r
F P
0 g
s
.29638 .67987 m .2954 .69888 L .2984 .7036 L p .707 .577 .707 r
F P
0 g
s
.30274 .60992 m .29739 .64787 L .29116 .64425 L p .707 .577 .707 r
F P
0 g
s
.29116 .64425 m .29652 .6063 L .30274 .60992 L p .707 .577 .707 r
F P
0 g
s
.49957 .53618 m .49472 .59358 L .48191 .59076 L p .707 .577 .707 r
F P
0 g
s
.48191 .59076 m .48676 .53337 L .49957 .53618 L p .707 .577 .707 r
F P
0 g
s
.50006 .69197 m .49908 .71098 L .49609 .70626 L p .707 .577 .707 r
F P
0 g
s
.49609 .70626 m .49706 .68725 L .50006 .69197 L p .707 .577 .707 r
F P
0 g
s
.30138 .57664 m .30623 .51925 L .32229 .51897 L p .707 .577 .707 r
F P
0 g
s
.49503 .63617 m .48968 .67412 L .47647 .67481 L p .707 .577 .707 r
F P
0 g
s
.32229 .51897 m .31745 .57636 L .30138 .57664 L p .707 .577 .707 r
F P
0 g
s
.2954 .69888 m .29638 .67987 L .30335 .67574 L p .707 .577 .707 r
F P
0 g
s
.47647 .67481 m .48183 .63687 L .49503 .63617 L p .707 .577 .707 r
F P
0 g
s
.30335 .67574 m .30238 .69475 L .2954 .69888 L p .707 .577 .707 r
F P
0 g
s
.31826 .61454 m .3129 .65248 L .29739 .64787 L p .707 .577 .707 r
F P
0 g
s
.29739 .64787 m .30274 .60992 L .31826 .61454 L p .707 .577 .707 r
F P
0 g
s
.48676 .53337 m .48191 .59076 L .46072 .58757 L p .707 .577 .707 r
F P
0 g
s
.46072 .58757 m .46556 .53017 L .48676 .53337 L p .707 .577 .707 r
F P
0 g
s
.49706 .68725 m .49609 .70626 L .48341 .7014 L p .707 .577 .707 r
F P
0 g
s
.48341 .7014 m .48439 .68239 L .49706 .68725 L p .707 .577 .707 r
F P
0 g
s
.31745 .57636 m .32229 .51897 L .34607 .51971 L p .707 .577 .707 r
F P
0 g
s
.34607 .51971 m .34123 .5771 L .31745 .57636 L p .707 .577 .707 r
F P
0 g
s
.48183 .63687 m .47647 .67481 L .45502 .67386 L p .707 .577 .707 r
F P
0 g
s
.45502 .67386 m .46038 .63592 L .48183 .63687 L p .707 .577 .707 r
F P
0 g
s
.30238 .69475 m .30335 .67574 L .31961 .6726 L p .707 .577 .707 r
F P
0 g
s
.31961 .6726 m .31864 .69161 L .30238 .69475 L p .707 .577 .707 r
F P
0 g
s
.34154 .6197 m .33618 .65764 L .3129 .65248 L p .707 .577 .707 r
F P
0 g
s
.3129 .65248 m .31826 .61454 L .34154 .6197 L p .707 .577 .707 r
F P
0 g
s
.46556 .53017 m .46072 .58757 L .43321 .5843 L p .707 .577 .707 r
F P
0 g
s
.43321 .5843 m .43806 .5269 L .46556 .53017 L p .707 .577 .707 r
F P
0 g
s
.34123 .5771 m .34607 .51971 L .37524 .5214 L p .707 .577 .707 r
F P
0 g
s
.37524 .5214 m .37039 .57879 L .34123 .5771 L p .707 .577 .707 r
F P
0 g
s
.48439 .68239 m .48341 .7014 L .46231 .69689 L p .707 .577 .707 r
F P
0 g
s
.46231 .69689 m .46328 .67789 L .48439 .68239 L p .707 .577 .707 r
F P
0 g
s
.46038 .63592 m .45502 .67386 L .42743 .67137 L p .707 .577 .707 r
F P
0 g
s
.43806 .5269 m .43321 .5843 L .40209 .58127 L p .707 .577 .707 r
F P
0 g
s
.40209 .58127 m .40693 .52388 L .43806 .5269 L p .707 .577 .707 r
F P
0 g
s
.42743 .67137 m .43279 .63343 L .46038 .63592 L p .707 .577 .707 r
F P
0 g
s
.37031 .6249 m .36495 .66284 L .33618 .65764 L p .707 .577 .707 r
F P
0 g
s
.33618 .65764 m .34154 .6197 L .37031 .6249 L p .707 .577 .707 r
F P
0 g
s
.37039 .57879 m .37524 .5214 L .40693 .52388 L p .707 .577 .707 r
F P
0 g
s
.31864 .69161 m .31961 .6726 L .34357 .67077 L p .707 .577 .707 r
F P
0 g
s
.40693 .52388 m .40209 .58127 L .37039 .57879 L p .707 .577 .707 r
F P
0 g
s
.34357 .67077 m .34259 .68978 L .31864 .69161 L p .707 .577 .707 r
F P
0 g
s
.43279 .63343 m .42743 .67137 L .39639 .66757 L p .707 .577 .707 r
F P
0 g
s
.39639 .66757 m .40175 .62963 L .43279 .63343 L p .707 .577 .707 r
F P
0 g
s
.40175 .62963 m .39639 .66757 L .36495 .66284 L p .707 .577 .707 r
F P
0 g
s
.36495 .66284 m .37031 .6249 L .40175 .62963 L p .707 .577 .707 r
F P
0 g
s
.46328 .67789 m .46231 .69689 L .43483 .69317 L p .707 .577 .707 r
F P
0 g
s
.43483 .69317 m .43581 .67416 L .46328 .67789 L p .707 .577 .707 r
F P
0 g
s
.34259 .68978 m .34357 .67077 L .37287 .67042 L p .707 .577 .707 r
F P
0 g
s
.37287 .67042 m .37189 .68943 L .34259 .68978 L p .707 .577 .707 r
F P
0 g
s
.43581 .67416 m .43483 .69317 L .40368 .6906 L p .707 .577 .707 r
F P
0 g
s
.40368 .6906 m .40465 .67159 L .43581 .67416 L p .707 .577 .707 r
F P
0 g
s
.37189 .68943 m .37287 .67042 L .40465 .67159 L p .707 .577 .707 r
F P
0 g
s
.40465 .67159 m .40368 .6906 L .37189 .68943 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool<0028Ool0081oo`T0
00IJEP03001JEUYF00=JEP`007aoo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MGoo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000Lgoo001bOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LGoo001^Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001_Ool006aoo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eo
o`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0`00Jgoo001YOol01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001WOol20003
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0IWoo001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001GOol?0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<0
00=JEP03001JEUYF00AJEP04001JEUYFFUH:0009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK001<Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90013Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPP003]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Eo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Goo001C
Ool00`00FUH00002FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo
001COol60005FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001KOol70004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001ROol80004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo001VOol00`00FUIJEP090005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP0L0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP8002aoo`00EGoo3P000goo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo0P000eYF
00<005YFFUH00eYF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo100000=JEP00FUH015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
E7oo00@005YF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0140
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`04001JEUYF0003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH015YF4P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF
1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH02eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
;Woo4@0057oo00<005YF00000eYF00<005YFFUH01EYF00@005YFFUIJEPL000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH70003FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH01000
FUIJEUYF4P000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000
25YF00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P002Woo4P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@00
0UYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH700000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000LOol80004FUH00`00FUIJEP04FUH0
1000FUIJEUYF1000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH>0002FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0097oo4P00;Woo000^Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00I7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH03`00FGoo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00@005YFFUIJEPT0051oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYF001JEP040005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90017Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EPD000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH0009JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003mo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03
001JEUYF00IJEP04001JEUYFFUH6000iOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000@000AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEP0000<000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH700000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000bOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000015YF001JEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0001h000AJEP03001JEUYF00=JEP04001J
EUYFFUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00
FUH01UYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF5P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH@000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF001JEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00;7oo00<005YF00003`0015YF00<005YFFUH01UYF00<005YFFUH01UYF0`00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`<0009JEP03001JEUYF00=J
EP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002moo`D000=JEP03001JEUYF00EJEP03001JEUYF00EJEPl000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool>0003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEQl000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80003FUH00`00FUIJEP06FUH01@00FUIJEP00FUH010000UYF2@0000IJEP00000005YF
0006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool400000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH00eYF00@0
05YFFUIJEPT000EJEP03001JEUYF00MJEP8000=JEPL000=JEP04001JEUYFFUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=J
EPP000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02eoo`04001JEP00FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0002FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP04
001JEUYFFUH20002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000/Ool01000FUIJEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF009JEP8000Ioo`H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000<000QJEP03001JEUYF00IJ
EP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0004FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF9@0015YF00<005YFFUH00eYF00@005YFFUIJEP80
02moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YF00001P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF5000<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUH000080004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05
FUH01000FUIJEUYF0P0000Aoo`00FUIJER0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002]oo`04001JEUYF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF40000UYF
00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000017ooFUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03
001JEUYF00IJEP8000QJEPX000aJEPT000QJEP03001JEUYF00EJEP05001JEP00FUH00002FUH:0003
FUH2000@Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00H000UJEP03
001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP04001JEP00FUH40005FUH01000
FUIJEUYF20005Goo1P000eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800004OomJEUYF0006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00EJEP04001JEUYFFUHO0003FUH2000]Ool0031oo`D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002Ool2FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF
008002eoo`00<Woo7P000eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009oo`9J
EP03001JEUYF00AJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<00003FUH005YF009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002moo`<0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000Woo0UYF00<005YFFUH015YF0P000UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00@005YF000000EJEP03001J
EP0000800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF009JEP80009o
o`9JEP03001JEUYF009JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00QJEP05001JEUYFFUH00003FUH2000015YF001JEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000002Ool2FUH00`00FUIJEP020006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH2000015YF000000001eYF4`0015YF00<005YFFUH01EYF00@005YFFUIJEPH0039o
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000Woo0UYF0`002EYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@001eYF00<0
05YFFUH00UYF0P0037oo4000>7oo000]Ool20004FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000AooeYFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP00010005Aoo`00;7oo00<005YF00000UYF1P0047oo4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEP000003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH000030004FUH5
000MOol60004FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF
00=JEP04001JEUYFFUHB000@Ool400000eYF001JEP02FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD00003FUH0000000h000=JEP@0009JEP04001o
o`000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@0
05YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1@00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003Ool0000000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0031o
o`@000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP08001JEUYFFUH005YF001oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol003Aoo`L000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH20003Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH60002FUH01000FUIJEUYF0P00EGoo000kOol90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF200017oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000P000UYF0P00EWoo0014OolI000<Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`001eYF00<005YFFUH00UYF1000EWoo001ZOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00001EOol006]o
o`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008005Ao
o`00KGoo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF0P0000=oo`0000001P000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
KWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH00eYF0`002goo1P000eYF00@005YFFUIJEP8005Aoo`00L7oo0P0015YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00005P0000=JEP0000000`00
0UYF0P00E7oo001bOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04001D
Ool007Eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000EJEPD000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00O7oo30001UYF00<005YFFUH0
15YF2@000UYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000E7oo0028Ool=0007Ool90004FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP04001EOol00:Eoo`T000AJEP03001JEUYF009JEPd005Uoo`00[Woo2@00IWoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59622 .73385 m .60106 .67646 L .56994 .67343 L p .707 .577 .707 r
F P
0 g
s
.60106 .67646 m .59622 .73385 L .62791 .73633 L p .707 .577 .707 r
F P
0 g
s
.62791 .73633 m .63276 .67894 L .60106 .67646 L p .707 .577 .707 r
F P
0 g
s
.63276 .67894 m .62791 .73633 L .65708 .73802 L p .707 .577 .707 r
F P
0 g
s
.65708 .73802 m .66192 .68063 L .63276 .67894 L p .707 .577 .707 r
F P
0 g
s
.56994 .67343 m .56509 .73083 L .59622 .73385 L p .707 .577 .707 r
F P
0 g
s
.56509 .73083 m .56994 .67343 L .54243 .67016 L p .707 .577 .707 r
F P
0 g
s
.56824 .73063 m .56288 .76857 L .59392 .77237 L p .707 .577 .707 r
F P
0 g
s
.59392 .77237 m .59928 .73443 L .56824 .73063 L p .707 .577 .707 r
F P
0 g
s
.59928 .73443 m .59392 .77237 L .62536 .7771 L p .707 .577 .707 r
F P
0 g
s
.54243 .67016 m .53759 .72756 L .56509 .73083 L p .707 .577 .707 r
F P
0 g
s
.62536 .7771 m .63072 .73916 L .59928 .73443 L p .707 .577 .707 r
F P
0 g
s
.63072 .73916 m .62536 .7771 L .65413 .7823 L p .707 .577 .707 r
F P
0 g
s
.65413 .7823 m .65949 .74436 L .63072 .73916 L p .707 .577 .707 r
F P
0 g
s
.54065 .72814 m .53529 .76608 L .56288 .76857 L p .707 .577 .707 r
F P
0 g
s
.56288 .76857 m .56824 .73063 L .54065 .72814 L p .707 .577 .707 r
F P
0 g
s
.66192 .68063 m .65708 .73802 L .68085 .73876 L p .707 .577 .707 r
F P
0 g
s
.68085 .73876 m .6857 .68137 L .66192 .68063 L p .707 .577 .707 r
F P
0 g
s
.53759 .72756 m .54243 .67016 L .52124 .66697 L p .707 .577 .707 r
F P
0 g
s
.65949 .74436 m .65413 .7823 L .67741 .78746 L p .707 .577 .707 r
F P
0 g
s
.52124 .66697 m .51639 .72436 L .53759 .72756 L p .707 .577 .707 r
F P
0 g
s
.67741 .78746 m .68277 .74952 L .65949 .74436 L p .707 .577 .707 r
F P
0 g
s
.59661 .82885 m .59759 .80984 L .56644 .80727 L p .707 .577 .707 r
F P
0 g
s
.59759 .80984 m .59661 .82885 L .6284 .83002 L p .707 .577 .707 r
F P
0 g
s
.6284 .83002 m .62938 .81101 L .59759 .80984 L p .707 .577 .707 r
F P
0 g
s
.5192 .72719 m .51384 .76513 L .53529 .76608 L p .707 .577 .707 r
F P
0 g
s
.53529 .76608 m .54065 .72814 L .5192 .72719 L p .707 .577 .707 r
F P
0 g
s
.56644 .80727 m .56546 .82628 L .59661 .82885 L p .707 .577 .707 r
F P
0 g
s
.62938 .81101 m .6284 .83002 L .6577 .82967 L p .707 .577 .707 r
F P
0 g
s
.6577 .82967 m .65868 .81066 L .62938 .81101 L p .707 .577 .707 r
F P
0 g
s
.56546 .82628 m .56644 .80727 L .53896 .80355 L p .707 .577 .707 r
F P
0 g
s
.53896 .80355 m .53798 .82255 L .56546 .82628 L p .707 .577 .707 r
F P
0 g
s
.6857 .68137 m .68085 .73876 L .69692 .73848 L p .707 .577 .707 r
F P
0 g
s
.69692 .73848 m .70177 .68109 L .6857 .68137 L p .707 .577 .707 r
F P
0 g
s
.65868 .81066 m .6577 .82967 L .68166 .82784 L p .707 .577 .707 r
F P
0 g
s
.68166 .82784 m .68263 .80883 L .65868 .81066 L p .707 .577 .707 r
F P
0 g
s
.68277 .74952 m .67741 .78746 L .69292 .79208 L p .707 .577 .707 r
F P
0 g
s
.51639 .72436 m .52124 .66697 L .50843 .66415 L p .707 .577 .707 r
F P
0 g
s
.69292 .79208 m .69828 .75413 L .68277 .74952 L p .707 .577 .707 r
F P
0 g
s
.50843 .66415 m .50358 .72155 L .51639 .72436 L p .707 .577 .707 r
F P
0 g
s
.53798 .82255 m .53896 .80355 L .51785 .79904 L p .707 .577 .707 r
F P
0 g
s
.51785 .79904 m .51688 .81805 L .53798 .82255 L p .707 .577 .707 r
F P
0 g
s
.50599 .72788 m .50063 .76583 L .51384 .76513 L p .707 .577 .707 r
F P
0 g
s
.51384 .76513 m .5192 .72719 L .50599 .72788 L p .707 .577 .707 r
F P
0 g
s
.68263 .80883 m .68166 .82784 L .69791 .8247 L p .707 .577 .707 r
F P
0 g
s
.69791 .8247 m .69889 .8057 L .68263 .80883 L p .707 .577 .707 r
F P
0 g
s
.70177 .68109 m .69692 .73848 L .7037 .7372 L p .707 .577 .707 r
F P
0 g
s
.7037 .7372 m .70855 .67981 L .70177 .68109 L p .707 .577 .707 r
F P
0 g
s
.69828 .75413 m .69292 .79208 L .69915 .7957 L p .707 .577 .707 r
F P
0 g
s
.51688 .81805 m .51785 .79904 L .50518 .79419 L p .707 .577 .707 r
F P
0 g
s
.50358 .72155 m .50843 .66415 L .50526 .662 L p .707 .577 .707 r
F P
0 g
s
.69915 .7957 m .70451 .75775 L .69828 .75413 L p .707 .577 .707 r
F P
0 g
s
.50518 .79419 m .50421 .81319 L .51688 .81805 L p .707 .577 .707 r
F P
0 g
s
.50526 .662 m .50041 .71939 L .50358 .72155 L p .707 .577 .707 r
F P
0 g
s
.50232 .73015 m .49697 .7681 L .50063 .76583 L p .707 .577 .707 r
F P
0 g
s
.50063 .76583 m .50599 .72788 L .50232 .73015 L p .707 .577 .707 r
F P
0 g
s
.50855 .73377 m .50319 .77171 L .49697 .7681 L p .707 .577 .707 r
F P
0 g
s
.49697 .7681 m .50232 .73015 L .50855 .73377 L p .707 .577 .707 r
F P
0 g
s
.50041 .82496 m .48485 .33515 L .44085 .333 L p .707 .577 .707 r
F P
0 g
s
.50421 .81319 m .50518 .79419 L .50219 .78946 L p .707 .577 .707 r
F P
0 g
s
.50219 .78946 m .50121 .80847 L .50421 .81319 L p .707 .577 .707 r
F P
0 g
s
.50041 .71939 m .50526 .662 L .51204 .66072 L p .707 .577 .707 r
F P
0 g
s
.51204 .66072 m .50719 .71811 L .50041 .71939 L p .707 .577 .707 r
F P
0 g
s
.50121 .80847 m .50219 .78946 L .50916 .78533 L p .707 .577 .707 r
F P
0 g
s
.50916 .78533 m .50818 .80434 L .50121 .80847 L p .707 .577 .707 r
F P
0 g
s
.50719 .71811 m .51204 .66072 L .5281 .66044 L p .707 .577 .707 r
F P
0 g
s
.5281 .66044 m .52325 .71783 L .50719 .71811 L p .707 .577 .707 r
F P
0 g
s
.52406 .73838 m .51871 .77633 L .50319 .77171 L p .707 .577 .707 r
F P
0 g
s
.50319 .77171 m .50855 .73377 L .52406 .73838 L p .707 .577 .707 r
F P
0 g
s
.50818 .80434 m .50916 .78533 L .52542 .7822 L p .707 .577 .707 r
F P
0 g
s
.52325 .71783 m .5281 .66044 L .55188 .66118 L p .707 .577 .707 r
F P
0 g
s
.52542 .7822 m .52444 .80121 L .50818 .80434 L p .707 .577 .707 r
F P
0 g
s
.55188 .66118 m .54703 .71857 L .52325 .71783 L p .707 .577 .707 r
F P
0 g
s
.54734 .74354 m .54199 .78149 L .51871 .77633 L p .707 .577 .707 r
F P
0 g
s
.51871 .77633 m .52406 .73838 L .54734 .74354 L p .707 .577 .707 r
F P
0 g
s
.57611 .74874 m .57076 .78669 L .54199 .78149 L p .707 .577 .707 r
F P
0 g
s
.54199 .78149 m .54734 .74354 L .57611 .74874 L p .707 .577 .707 r
F P
0 g
s
.52444 .80121 m .52542 .7822 L .54937 .78037 L p .707 .577 .707 r
F P
0 g
s
.54937 .78037 m .5484 .79938 L .52444 .80121 L p .707 .577 .707 r
F P
0 g
s
.48485 .33515 m .50041 .82496 L .54533 .8223 L p .707 .577 .707 r
F P
0 g
s
.54533 .8223 m .52976 .33248 L .48485 .33515 L p .707 .577 .707 r
F P
0 g
s
.54703 .71857 m .55188 .66118 L .58104 .66287 L p .707 .577 .707 r
F P
0 g
s
.58104 .66287 m .5762 .72026 L .54703 .71857 L p .707 .577 .707 r
F P
0 g
s
.60756 .75347 m .6022 .79142 L .57076 .78669 L p .707 .577 .707 r
F P
0 g
s
.57076 .78669 m .57611 .74874 L .60756 .75347 L p .707 .577 .707 r
F P
0 g
s
.5484 .79938 m .54937 .78037 L .57868 .78002 L p .707 .577 .707 r
F P
0 g
s
.57868 .78002 m .5777 .79903 L .5484 .79938 L p .707 .577 .707 r
F P
0 g
s
.6022 .79142 m .60756 .75347 L .63859 .75727 L p .707 .577 .707 r
F P
0 g
s
.5777 .79903 m .57868 .78002 L .61046 .78119 L p .707 .577 .707 r
F P
0 g
s
.63859 .75727 m .63323 .79522 L .6022 .79142 L p .707 .577 .707 r
F P
0 g
s
.61046 .78119 m .60948 .8002 L .5777 .79903 L p .707 .577 .707 r
F P
0 g
s
.52976 .33248 m .54533 .8223 L .58677 .81508 L p .707 .577 .707 r
F P
0 g
s
.5762 .72026 m .58104 .66287 L .61274 .66535 L p .707 .577 .707 r
F P
0 g
s
.61274 .66535 m .60789 .72274 L .5762 .72026 L p .707 .577 .707 r
F P
0 g
s
.58677 .81508 m .57121 .32526 L .52976 .33248 L p .707 .577 .707 r
F P
0 g
s
.69889 .8057 m .69791 .8247 L .70489 .82057 L p .707 .577 .707 r
F P
0 g
s
.70489 .82057 m .70586 .80157 L .69889 .8057 L p .707 .577 .707 r
F P
0 g
s
.45641 .82282 m .44085 .333 L .40207 .32626 L p .707 .577 .707 r
F P
0 g
s
.44085 .333 m .45641 .82282 L .50041 .82496 L p .707 .577 .707 r
F P
0 g
s
.70855 .67981 m .7037 .7372 L .70053 .73505 L p .707 .577 .707 r
F P
0 g
s
.70053 .73505 m .70538 .67765 L .70855 .67981 L p .707 .577 .707 r
F P
0 g
s
.64386 .66837 m .63902 .72577 L .61613 .72354 L p .707 .577 .707 r
F P
0 g
s
.61613 .72354 m .60789 .72274 L p .61666 .70949 L .707 .577 .707 r
F P
0 g
s
.61666 .70949 m .64386 .66837 L .61613 .72354 L .707 .577 .707 r
F
.67137 .67164 m .66652 .72904 L .63902 .72577 L p F P
0 g
s
.63902 .72577 m .64386 .66837 L .67137 .67164 L p .707 .577 .707 r
F P
0 g
s
.66619 .75977 m .66083 .79771 L .63323 .79522 L p .707 .577 .707 r
F P
0 g
s
.63323 .79522 m .63859 .75727 L .66619 .75977 L p .707 .577 .707 r
F P
0 g
s
.60789 .72274 m .61274 .66535 L .64386 .66837 L p .707 .577 .707 r
F P
0 g
s
.68763 .76071 m .68228 .79866 L .66083 .79771 L p .707 .577 .707 r
F P
0 g
s
.66083 .79771 m .66619 .75977 L .68763 .76071 L p .707 .577 .707 r
F P
0 g
s
.64064 .80277 m .64162 .78376 L .66909 .78748 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .65368 .77497 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62817 .30038 m .62996 .35672 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62996 .35672 m .64374 .7902 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.64162 .78376 m .64064 .80277 L .60948 .8002 L p .707 .577 .707 r
F P
0 g
s
.60948 .8002 m .61046 .78119 L .64162 .78376 L p .707 .577 .707 r
F P
0 g
s
.57121 .32526 m .58677 .81508 L .62068 .80402 L p .707 .577 .707 r
F P
0 g
s
.62068 .80402 m .60512 .3142 L .57121 .32526 L p .707 .577 .707 r
F P
0 g
s
.70451 .75775 m .69915 .7957 L .69548 .79796 L p .707 .577 .707 r
F P
0 g
s
.69548 .79796 m .70084 .76002 L .70451 .75775 L p .707 .577 .707 r
F P
0 g
s
.41764 .81608 m .40207 .32626 L .37232 .31558 L p .707 .577 .707 r
F P
0 g
s
.40207 .32626 m .41764 .81608 L .45641 .82282 L p .707 .577 .707 r
F P
0 g
s
.70586 .80157 m .70489 .82057 L .70189 .81585 L p .707 .577 .707 r
F P
0 g
s
.70189 .81585 m .70287 .79684 L .70586 .80157 L p .707 .577 .707 r
F P
0 g
s
.70538 .67765 m .70053 .73505 L .68772 .73223 L p .707 .577 .707 r
F P
0 g
s
.68772 .73223 m .69257 .67484 L .70538 .67765 L p .707 .577 .707 r
F P
0 g
s
.60512 .3142 m .62068 .80402 L .64374 .7902 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .62817 .30038 L .60512 .3142 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25321 .69703 m .25805 .63964 L .22693 .63662 L p .707 .577 .707 r
F P
0 g
s
.25805 .63964 m .25321 .69703 L .2849 .69951 L p .707 .577 .707 r
F P
0 g
s
.2849 .69951 m .28975 .64212 L .25805 .63964 L p .707 .577 .707 r
F P
0 g
s
.28975 .64212 m .2849 .69951 L .31407 .70121 L p .707 .577 .707 r
F P
0 g
s
.31407 .70121 m .31891 .64381 L .28975 .64212 L p .707 .577 .707 r
F P
0 g
s
.22693 .63662 m .22208 .69401 L .25321 .69703 L p .707 .577 .707 r
F P
0 g
s
.70084 .76002 m .69548 .79796 L .68228 .79866 L p .707 .577 .707 r
F P
0 g
s
.22208 .69401 m .22693 .63662 L .19942 .63335 L p .707 .577 .707 r
F P
0 g
s
.68228 .79866 m .68763 .76071 L .70084 .76002 L p .707 .577 .707 r
F P
0 g
s
.22523 .69382 m .21987 .73176 L .25091 .73556 L p .707 .577 .707 r
F P
0 g
s
.25091 .73556 m .25627 .69761 L .22523 .69382 L p .707 .577 .707 r
F P
0 g
s
.25627 .69761 m .25091 .73556 L .28235 .74029 L p .707 .577 .707 r
F P
0 g
s
.19942 .63335 m .19458 .69074 L .22208 .69401 L p .707 .577 .707 r
F P
0 g
s
.28235 .74029 m .28771 .70234 L .25627 .69761 L p .707 .577 .707 r
F P
0 g
s
.28771 .70234 m .28235 .74029 L .31112 .74549 L p .707 .577 .707 r
F P
0 g
s
.31112 .74549 m .31648 .70754 L .28771 .70234 L p .707 .577 .707 r
F P
0 g
s
.19764 .69132 m .19228 .72927 L .21987 .73176 L p .707 .577 .707 r
F P
0 g
s
.21987 .73176 m .22523 .69382 L .19764 .69132 L p .707 .577 .707 r
F P
0 g
s
.38789 .8054 m .37232 .31558 L .35451 .302 L p .707 .577 .707 r
F P
0 g
s
.37232 .31558 m .38789 .8054 L .41764 .81608 L p .707 .577 .707 r
F P
0 g
s
.31891 .64381 m .31407 .70121 L .33785 .70195 L p .707 .577 .707 r
F P
0 g
s
.33785 .70195 m .34269 .64455 L .31891 .64381 L p .707 .577 .707 r
F P
0 g
s
.19458 .69074 m .19942 .63335 L .17823 .63015 L p .707 .577 .707 r
F P
0 g
s
.70287 .79684 m .70189 .81585 L .68922 .811 L p .707 .577 .707 r
F P
0 g
s
.68922 .811 m .6902 .79199 L .70287 .79684 L p .707 .577 .707 r
F P
0 g
s
.31648 .70754 m .31112 .74549 L .3344 .75065 L p .707 .577 .707 r
F P
0 g
s
.69257 .67484 m .68772 .73223 L .66652 .72904 L p .707 .577 .707 r
F P
0 g
s
.66652 .72904 m .67137 .67164 L .69257 .67484 L p .707 .577 .707 r
F P
0 g
s
.17823 .63015 m .17338 .68754 L .19458 .69074 L p .707 .577 .707 r
F P
0 g
s
.3344 .75065 m .33976 .7127 L .31648 .70754 L p .707 .577 .707 r
F P
0 g
s
.2536 .79203 m .25458 .77302 L .22343 .77045 L p .707 .577 .707 r
F P
0 g
s
.25458 .77302 m .2536 .79203 L .28539 .7932 L p .707 .577 .707 r
F P
0 g
s
.28539 .7932 m .28637 .77419 L .25458 .77302 L p .707 .577 .707 r
F P
0 g
s
.17619 .69037 m .17083 .72832 L .19228 .72927 L p .707 .577 .707 r
F P
0 g
s
.19228 .72927 m .19764 .69132 L .17619 .69037 L p .707 .577 .707 r
F P
0 g
s
.22343 .77045 m .22245 .78946 L .2536 .79203 L p .707 .577 .707 r
F P
0 g
s
.28637 .77419 m .28539 .7932 L .31469 .79285 L p .707 .577 .707 r
F P
0 g
s
.31469 .79285 m .31567 .77384 L .28637 .77419 L p .707 .577 .707 r
F P
0 g
s
.65368 .77497 m .63812 .28515 L .62817 .30038 L p .707 .577 .707 r
F P
0 g
s
.22245 .78946 m .22343 .77045 L .19595 .76673 L p .707 .577 .707 r
F P
0 g
s
.19595 .76673 m .19497 .78574 L .22245 .78946 L p .707 .577 .707 r
F P
0 g
s
.34269 .64455 m .33785 .70195 L .35391 .70166 L p .707 .577 .707 r
F P
0 g
s
.35391 .70166 m .35876 .64427 L .34269 .64455 L p .707 .577 .707 r
F P
0 g
s
.31567 .77384 m .31469 .79285 L .33865 .79102 L p .707 .577 .707 r
F P
0 g
s
.33865 .79102 m .33962 .77201 L .31567 .77384 L p .707 .577 .707 r
F P
0 g
s
.33976 .7127 m .3344 .75065 L .34991 .75526 L p .707 .577 .707 r
F P
0 g
s
.17338 .68754 m .17823 .63015 L .16542 .62734 L p .707 .577 .707 r
F P
0 g
s
.34991 .75526 m .35527 .71732 L .33976 .7127 L p .707 .577 .707 r
F P
0 g
s
.16542 .62734 m .16057 .68473 L .17338 .68754 L p .707 .577 .707 r
F P
0 g
s
.19497 .78574 m .19595 .76673 L .17484 .76222 L p .707 .577 .707 r
F P
0 g
s
.6902 .79199 m .68922 .811 L .66811 .80649 L p .707 .577 .707 r
F P
0 g
s
.66811 .80649 m .66909 .78748 L .6902 .79199 L p .707 .577 .707 r
F P
0 g
s
.17484 .76222 m .17387 .78123 L .19497 .78574 L p .707 .577 .707 r
F P
0 g
s
.36069 .70038 m .36554 .64299 L .35876 .64427 L p .707 .577 .707 r
F P
0 g
s
.35876 .64427 m .35391 .70166 L .36069 .70038 L p .707 .577 .707 r
F P
0 g
s
.36554 .64299 m .36069 .70038 L .35752 .69823 L p .707 .577 .707 r
F P
0 g
s
.35752 .69823 m .36237 .64084 L .36554 .64299 L p .707 .577 .707 r
F P
0 g
s
.37007 .79182 m .35451 .302 L .35037 .28686 L p .707 .577 .707 r
F P
0 g
s
.35451 .302 m .37007 .79182 L .38789 .8054 L p .707 .577 .707 r
F P
0 g
s
.16298 .69107 m .15762 .72901 L .17083 .72832 L p .707 .577 .707 r
F P
0 g
s
.17083 .72832 m .17619 .69037 L .16298 .69107 L p .707 .577 .707 r
F P
0 g
s
.33962 .77201 m .33865 .79102 L .35491 .78789 L p .707 .577 .707 r
F P
0 g
s
.35491 .78789 m .35588 .76888 L .33962 .77201 L p .707 .577 .707 r
F P
0 g
s
.35527 .71732 m .34991 .75526 L .35614 .75888 L p .707 .577 .707 r
F P
0 g
s
.17387 .78123 m .17484 .76222 L .16217 .75737 L p .707 .577 .707 r
F P
0 g
s
.66909 .78748 m .66811 .80649 L .64064 .80277 L p .707 .577 .707 r
F P
0 g
s
.16057 .68473 m .16542 .62734 L .16225 .62519 L p .707 .577 .707 r
F P
0 g
s
.63812 .28515 m .65205 .72358 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .63812 .28515 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.63784 .6788 m .6472 .67831 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .64591 .64553 L p .63209 .66964 L .707 .577 .707 r
F P
0 g
s
.64591 .64553 m .64685 .67507 L p .63878 .6721 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .64591 .64553 L .63878 .6721 L .707 .577 .707 r
F
.64955 .75983 m .63173 .74625 L p .63209 .66964 L F P
0 g
s
.63682 .67943 m .63784 .6788 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63878 .6721 m .63784 .6788 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.64685 .67507 m .64955 .75983 L p .63517 .68556 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .63878 .6721 L .63517 .68556 L .707 .577 .707 r
F
.63784 .6788 m .63878 .6721 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .64685 .67507 L .63517 .68556 L .707 .577 .707 r
F
.6432 .64085 m .63953 .64312 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .6432 .64085 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63953 .64312 m .63417 .68106 L .63682 .67943 L p .707 .577 .707 r
F P
0 g
s
.63802 .67495 m .63953 .64312 L .63682 .67943 L .707 .577 .707 r
F
.64316 .6411 m .63878 .6721 L p .64685 .67507 L F P
0 g
s
.64936 .75218 m .64685 .67507 L .64769 .68279 L .707 .577 .707 r
F
.64925 .75062 m .64685 .67507 L p .64936 .75218 L F P
0 g
s
.65368 .77497 m .65001 .76153 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.65001 .76153 m .64955 .75983 L p .64936 .75218 L .707 .577 .707 r
F P
0 g
s
.64936 .75218 m .64731 .66703 L .65001 .76153 L .707 .577 .707 r
F
.64239 .72141 m .64141 .74041 L .64874 .74322 L p F P
0 g
s
.65205 .72358 m .65368 .77497 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.64874 .74322 m .65408 .74527 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.64802 .73291 m .64239 .72141 L .64874 .74322 L .707 .577 .707 r
F
.65408 .74527 m .65506 .72626 L .64736 .72331 L p F P
0 g
s
.64736 .72331 m .64239 .72141 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.65408 .74527 m .64736 .72331 L .64802 .73291 L .707 .577 .707 r
F
.64955 .75983 m .64925 .75062 L p .64936 .75218 L F P
0 g
s
.64685 .67507 m .63398 .27001 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.6432 .64085 m .64316 .6411 L p .65104 .6781 L .707 .577 .707 r
F P
0 g
s
.6472 .67831 m .65104 .6781 L p .64316 .6411 L .707 .577 .707 r
F P
0 g
s
.64563 .5595 m .64195 .60306 L p .65359 .6197 L .707 .577 .707 r
F P
0 g
s
.64195 .60306 m .64078 .61689 L .64315 .61741 L p .707 .577 .707 r
F P
0 g
s
.64315 .61741 m .65359 .6197 L p .64195 .60306 L .707 .577 .707 r
F P
0 g
s
.35614 .75888 m .3615 .72094 L .35527 .71732 L p .707 .577 .707 r
F P
0 g
s
.16217 .75737 m .1612 .77638 L .17387 .78123 L p .707 .577 .707 r
F P
0 g
s
.16225 .62519 m .1574 .68258 L .16057 .68473 L p .707 .577 .707 r
F P
0 g
s
.15931 .69334 m .15396 .73128 L .15762 .72901 L p .707 .577 .707 r
F P
0 g
s
.15762 .72901 m .16298 .69107 L .15931 .69334 L p .707 .577 .707 r
F P
0 g
s
.35588 .76888 m .35491 .78789 L .36188 .78376 L p .707 .577 .707 r
F P
0 g
s
.36188 .78376 m .36285 .76475 L .35588 .76888 L p .707 .577 .707 r
F P
0 g
s
.36237 .64084 m .35752 .69823 L .34475 .69543 L p .707 .577 .707 r
F P
0 g
s
.34475 .69543 m .34471 .69542 L p .34476 .69527 L .707 .577 .707 r
F P
0 g
s
.34476 .69527 m .36237 .64084 L .34475 .69543 L .707 .577 .707 r
F
.35037 .28686 m .36032 .27163 L p .36144 .3731 L F P
0 g
s
.36452 .64952 m .36594 .77668 L .37007 .79182 L p .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35705 .45799 L p .35037 .28686 L .707 .577 .707 r
F P
0 g
s
.34471 .69542 m .34956 .63803 L .36237 .64084 L p .707 .577 .707 r
F P
0 g
s
.36594 .77668 m .35628 .47282 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35037 .28686 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.1612 .77638 m .16217 .75737 L .15918 .75265 L p .707 .577 .707 r
F P
0 g
s
.3615 .72094 m .35614 .75888 L .35247 .76115 L p .707 .577 .707 r
F P
0 g
s
.15918 .75265 m .1582 .77166 L .1612 .77638 L p .707 .577 .707 r
F P
0 g
s
.1574 .68258 m .16225 .62519 L .16903 .62391 L p .707 .577 .707 r
F P
0 g
s
.35247 .76115 m .35783 .7232 L .3615 .72094 L p .707 .577 .707 r
F P
0 g
s
.16903 .62391 m .16418 .6813 L .1574 .68258 L p .707 .577 .707 r
F P
0 g
s
.16554 .69695 m .16018 .7349 L .15396 .73128 L p .707 .577 .707 r
F P
0 g
s
.15396 .73128 m .15931 .69334 L .16554 .69695 L p .707 .577 .707 r
F P
0 g
s
.63173 .74625 m .61616 .25643 L .63398 .27001 L p .707 .577 .707 r
F P
0 g
s
.36285 .76475 m .36188 .78376 L .35888 .77904 L p .707 .577 .707 r
F P
0 g
s
.35888 .77904 m .35986 .76003 L .36285 .76475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1582 .77166 m .15918 .75265 L .16615 .74852 L p .707 .577 .707 r
F P
0 g
s
.35783 .7232 m .35247 .76115 L .33927 .76184 L p .707 .577 .707 r
F P
0 g
s
.16615 .74852 m .16517 .76753 L .1582 .77166 L p .707 .577 .707 r
F P
0 g
s
.37588 .76145 m .36032 .27163 L .38337 .25781 L p .707 .577 .707 r
F P
0 g
s
.36032 .27163 m .37588 .76145 L .36594 .77668 L p .707 .577 .707 r
F P
0 g
s
.16418 .6813 m .16903 .62391 L .18509 .62362 L p .707 .577 .707 r
F P
0 g
s
.33927 .76184 m .34463 .7239 L .35783 .7232 L p .707 .577 .707 r
F P
0 g
s
.18509 .62362 m .18024 .68102 L .16418 .6813 L p .707 .577 .707 r
F P
0 g
s
.18105 .70157 m .1757 .73951 L .16018 .7349 L p .707 .577 .707 r
F P
0 g
s
.16018 .7349 m .16554 .69695 L .18105 .70157 L p .707 .577 .707 r
F P
0 g
s
.35986 .76003 m .35888 .77904 L .34621 .77418 L p .707 .577 .707 r
F P
0 g
s
.34621 .77418 m .34719 .75517 L .35986 .76003 L p .707 .577 .707 r
F P
0 g
s
.34956 .63803 m .34471 .69542 L .32351 .69222 L p .707 .577 .707 r
F P
0 g
s
.32351 .69222 m .32836 .63483 L .34956 .63803 L p .707 .577 .707 r
F P
0 g
s
.61616 .25643 m .63173 .74625 L .60198 .73557 L p .707 .577 .707 r
F P
0 g
s
.60198 .73557 m .58641 .24575 L .61616 .25643 L p .707 .577 .707 r
F P
0 g
s
.34463 .7239 m .33927 .76184 L .31782 .7609 L p .707 .577 .707 r
F P
0 g
s
.16517 .76753 m .16615 .74852 L .18241 .74538 L p .707 .577 .707 r
F P
0 g
s
.18024 .68102 m .18509 .62362 L .20887 .62436 L p .707 .577 .707 r
F P
0 g
s
.18241 .74538 m .18143 .76439 L .16517 .76753 L p .707 .577 .707 r
F P
0 g
s
.31782 .7609 m .32318 .72295 L .34463 .7239 L p .707 .577 .707 r
F P
0 g
s
.20887 .62436 m .20402 .68176 L .18024 .68102 L p .707 .577 .707 r
F P
0 g
s
.20433 .70673 m .19898 .74467 L .1757 .73951 L p .707 .577 .707 r
F P
0 g
s
.1757 .73951 m .18105 .70157 L .20433 .70673 L p .707 .577 .707 r
F P
0 g
s
.38337 .25781 m .39791 .71524 L p .37588 .76145 L .707 .577 .707 r
F P
0 g
s
.39894 .74763 m .38337 .25781 L .41728 .24675 L p .707 .577 .707 r
F P
0 g
s
.43285 .73657 m .39894 .74763 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.41728 .24675 m .42946 .63003 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.42946 .63003 m .43015 .65181 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.40111 .68841 m .43015 .65181 L .40174 .68937 L .707 .577 .707 r
F
.42491 .61531 m .41955 .65326 L .42792 .65477 L p F P
0 g
s
.41728 .24675 m .45872 .23953 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.42792 .65477 m .44832 .65846 L p .4447 .65178 L .707 .577 .707 r
F P
0 g
s
.4447 .65178 m .43015 .65181 L .42792 .65477 L .707 .577 .707 r
F
.43285 .73657 m .43015 .65181 L p .43726 .6518 L F P
0 g
s
.43015 .65181 m .41728 .24675 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .43285 .73657 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45872 .23953 m .47182 .6517 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.44927 .65176 m .44832 .65846 L .4548 .65989 L p .707 .577 .707 r
F P
0 g
s
.43726 .6518 m .43811 .63536 L .44927 .65176 L .707 .577 .707 r
F
.43811 .63536 m .45872 .23953 L .44927 .65176 L F
.44832 .65846 m .45368 .62051 L .42491 .61531 L p F P
0 g
s
.47182 .6517 m .47429 .72935 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45368 .62051 m .44927 .65176 L p .47161 .66362 L .707 .577 .707 r
F P
0 g
s
.4548 .65989 m .47161 .66362 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.43864 .6406 m .42491 .61531 L .42769 .65182 L .707 .577 .707 r
F
.43015 .65181 m .42769 .65182 L .42792 .65477 L F
.43864 .6406 m .42769 .65182 L .43015 .65181 L F
.4447 .65178 m .43864 .6406 L .43015 .65181 L F
.43015 .65181 m .43255 .72736 L p .40174 .68937 L F P
0 g
s
.40174 .68937 m .43255 .72736 L .4306 .73316 L .707 .577 .707 r
F
.42357 .70141 m .42259 .72042 L .43494 .72028 L p F P
0 g
s
.43494 .72028 m .4519 .72007 L p .43808 .71097 L .707 .577 .707 r
F P
0 g
s
.43808 .71097 m .42357 .70141 L .43494 .72028 L .707 .577 .707 r
F
.43255 .72736 m .43285 .73657 L p .4306 .73316 L F P
0 g
s
.42695 .53747 m .42211 .59486 L .44587 .59624 L p .707 .577 .707 r
F P
0 g
s
.44587 .59624 m .45127 .59655 L p .44872 .59037 L .707 .577 .707 r
F P
0 g
s
.44872 .59037 m .42695 .53747 L .44587 .59624 L .707 .577 .707 r
F
.39526 .53499 m .39041 .59238 L .41525 .59432 L p F P
0 g
s
.41525 .59432 m .42211 .59486 L p .41685 .58315 L .707 .577 .707 r
F P
0 g
s
.41685 .58315 m .39526 .53499 L .41525 .59432 L .707 .577 .707 r
F
.39791 .71524 m .39894 .74763 L .39273 .75135 L p F P
0 g
s
.39273 .75135 m .37588 .76145 L p .39791 .71524 L .707 .577 .707 r
F P
0 g
s
.32836 .63483 m .32351 .69222 L .29601 .68895 L p .707 .577 .707 r
F P
0 g
s
.29601 .68895 m .30085 .63156 L .32836 .63483 L p .707 .577 .707 r
F P
0 g
s
.34719 .75517 m .34621 .77418 L .3251 .76967 L p .707 .577 .707 r
F P
0 g
s
.3251 .76967 m .32608 .75067 L .34719 .75517 L p .707 .577 .707 r
F P
0 g
s
.20402 .68176 m .20887 .62436 L .23803 .62606 L p .707 .577 .707 r
F P
0 g
s
.32318 .72295 m .31782 .7609 L .29022 .7584 L p .707 .577 .707 r
F P
0 g
s
.58641 .24575 m .60198 .73557 L .56321 .72882 L p .707 .577 .707 r
F P
0 g
s
.56321 .72882 m .54764 .239 L .58641 .24575 L p .707 .577 .707 r
F P
0 g
s
.23803 .62606 m .23319 .68345 L .20402 .68176 L p .707 .577 .707 r
F P
0 g
s
.29022 .7584 m .29558 .72046 L .32318 .72295 L p .707 .577 .707 r
F P
0 g
s
.2331 .71193 m .22775 .74987 L .19898 .74467 L p .707 .577 .707 r
F P
0 g
s
.19898 .74467 m .20433 .70673 L .2331 .71193 L p .707 .577 .707 r
F P
0 g
s
.18143 .76439 m .18241 .74538 L .20636 .74355 L p .707 .577 .707 r
F P
0 g
s
.73342 .6292 m .73827 .5718 L .70714 .56878 L p .707 .577 .707 r
F P
0 g
s
.73827 .5718 m .73342 .6292 L .76512 .63167 L p .707 .577 .707 r
F P
0 g
s
.76512 .63167 m .76996 .57428 L .73827 .5718 L p .707 .577 .707 r
F P
0 g
s
.20636 .74355 m .20539 .76256 L .18143 .76439 L p .707 .577 .707 r
F P
0 g
s
.30085 .63156 m .29601 .68895 L .26488 .68593 L p .707 .577 .707 r
F P
0 g
s
.26488 .68593 m .26973 .62853 L .30085 .63156 L p .707 .577 .707 r
F P
0 g
s
.76996 .57428 m .76512 .63167 L .79428 .63337 L p .707 .577 .707 r
F P
0 g
s
.79428 .63337 m .79913 .57597 L .76996 .57428 L p .707 .577 .707 r
F P
0 g
s
.70714 .56878 m .7023 .62617 L .73342 .6292 L p .707 .577 .707 r
F P
0 g
s
.23319 .68345 m .23803 .62606 L .26973 .62853 L p .707 .577 .707 r
F P
0 g
s
.7023 .62617 m .70714 .56878 L .67964 .56551 L p .707 .577 .707 r
F P
0 g
s
.26973 .62853 m .26488 .68593 L .23319 .68345 L p .707 .577 .707 r
F P
0 g
s
.67964 .56551 m .67479 .6229 L .7023 .62617 L p .707 .577 .707 r
F P
0 g
s
.29558 .72046 m .29022 .7584 L .25919 .7546 L p .707 .577 .707 r
F P
0 g
s
.32608 .75067 m .3251 .76967 L .29763 .76595 L p .707 .577 .707 r
F P
0 g
s
.29763 .76595 m .29861 .74694 L .32608 .75067 L p .707 .577 .707 r
F P
0 g
s
.70544 .6436 m .70009 .68154 L .73112 .68534 L p .707 .577 .707 r
F P
0 g
s
.73112 .68534 m .73648 .6474 L .70544 .6436 L p .707 .577 .707 r
F P
0 g
s
.73648 .6474 m .73112 .68534 L .76256 .69007 L p .707 .577 .707 r
F P
0 g
s
.25919 .7546 m .26455 .71666 L .29558 .72046 L p .707 .577 .707 r
F P
0 g
s
.26455 .71666 m .25919 .7546 L .22775 .74987 L p .707 .577 .707 r
F P
0 g
s
.22775 .74987 m .2331 .71193 L .26455 .71666 L p .707 .577 .707 r
F P
0 g
s
.79913 .57597 m .79428 .63337 L .81806 .63411 L p .707 .577 .707 r
F P
0 g
s
.81806 .63411 m .82291 .57671 L .79913 .57597 L p .707 .577 .707 r
F P
0 g
s
.76256 .69007 m .76792 .65213 L .73648 .6474 L p .707 .577 .707 r
F P
0 g
s
.76792 .65213 m .76256 .69007 L .79133 .69527 L p .707 .577 .707 r
F P
0 g
s
.54764 .239 m .56321 .72882 L .51921 .72668 L p .707 .577 .707 r
F P
0 g
s
.51921 .72668 m .50364 .23686 L .54764 .239 L p .707 .577 .707 r
F P
0 g
s
.20539 .76256 m .20636 .74355 L .23567 .7432 L p .707 .577 .707 r
F P
0 g
s
.79133 .69527 m .79669 .65733 L .76792 .65213 L p .707 .577 .707 r
F P
0 g
s
.67785 .64111 m .67249 .67905 L .70009 .68154 L p .707 .577 .707 r
F P
0 g
s
.70009 .68154 m .70544 .6436 L .67785 .64111 L p .707 .577 .707 r
F P
0 g
s
.23567 .7432 m .23469 .76221 L .20539 .76256 L p .707 .577 .707 r
F P
0 g
s
.67479 .6229 m .67964 .56551 L .65844 .56231 L p .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .45872 .23953 L .50364 .23686 L p .707 .577 .707 r
F P
0 g
s
.65844 .56231 m .65359 .6197 L .67479 .6229 L p .707 .577 .707 r
F P
0 g
s
.50364 .23686 m .51921 .72668 L .47429 .72935 L p .707 .577 .707 r
F P
0 g
s
.29861 .74694 m .29763 .76595 L .26647 .76338 L p .707 .577 .707 r
F P
0 g
s
.26647 .76338 m .26745 .74437 L .29861 .74694 L p .707 .577 .707 r
F P
0 g
s
.79669 .65733 m .79133 .69527 L .81462 .70043 L p .707 .577 .707 r
F P
0 g
s
.23469 .76221 m .23567 .7432 L .26745 .74437 L p .707 .577 .707 r
F P
0 g
s
.81462 .70043 m .81997 .66249 L .79669 .65733 L p .707 .577 .707 r
F P
0 g
s
.26745 .74437 m .26647 .76338 L .23469 .76221 L p .707 .577 .707 r
F P
0 g
s
.6564 .64016 m .65104 .6781 L .67249 .67905 L p .707 .577 .707 r
F P
0 g
s
.67249 .67905 m .67785 .64111 L .6564 .64016 L p .707 .577 .707 r
F P
0 g
s
.73382 .75607 m .73479 .73706 L .70364 .73449 L p .707 .577 .707 r
F P
0 g
s
.73479 .73706 m .73382 .75607 L .7656 .75724 L p .707 .577 .707 r
F P
0 g
s
.7656 .75724 m .76658 .73823 L .73479 .73706 L p .707 .577 .707 r
F P
0 g
s
.82291 .57671 m .81806 .63411 L .83412 .63382 L p .707 .577 .707 r
F P
0 g
s
.83412 .63382 m .83897 .57643 L .82291 .57671 L p .707 .577 .707 r
F P
0 g
s
.70364 .73449 m .70266 .7535 L .73382 .75607 L p .707 .577 .707 r
F P
0 g
s
.76658 .73823 m .7656 .75724 L .79491 .75689 L p .707 .577 .707 r
F P
0 g
s
.79491 .75689 m .79588 .73788 L .76658 .73823 L p .707 .577 .707 r
F P
0 g
s
.70266 .7535 m .70364 .73449 L .67616 .73077 L p .707 .577 .707 r
F P
0 g
s
.65359 .6197 m .65844 .56231 L .64563 .5595 L p .707 .577 .707 r
F P
0 g
s
.67616 .73077 m .67519 .74978 L .70266 .7535 L p .707 .577 .707 r
F P
0 g
s
.81997 .66249 m .81462 .70043 L .83013 .70505 L p .707 .577 .707 r
F P
0 g
s
.79588 .73788 m .79491 .75689 L .81886 .75506 L p .707 .577 .707 r
F P
0 g
s
.81886 .75506 m .81984 .73605 L .79588 .73788 L p .707 .577 .707 r
F P
0 g
s
.83013 .70505 m .83549 .6671 L .81997 .66249 L p .707 .577 .707 r
F P
0 g
s
.65104 .6781 m .6564 .64016 L .6432 .64085 L p .707 .577 .707 r
F P
0 g
s
.67519 .74978 m .67616 .73077 L .65506 .72626 L p .707 .577 .707 r
F P
0 g
s
.65506 .72626 m .65408 .74527 L .67519 .74978 L p .707 .577 .707 r
F P
0 g
s
.83897 .57643 m .83412 .63382 L .8409 .63254 L p .707 .577 .707 r
F P
0 g
s
.8409 .63254 m .84575 .57515 L .83897 .57643 L p .707 .577 .707 r
F P
0 g
s
.81984 .73605 m .81886 .75506 L .83512 .75192 L p .707 .577 .707 r
F P
0 g
s
.83512 .75192 m .8361 .73292 L .81984 .73605 L p .707 .577 .707 r
F P
0 g
s
.64078 .61689 m .64563 .5595 L .64246 .55735 L p .707 .577 .707 r
F P
0 g
s
.83549 .6671 m .83013 .70505 L .83636 .70866 L p .707 .577 .707 r
F P
0 g
s
.64246 .55735 m .63761 .61474 L .64078 .61689 L p .707 .577 .707 r
F P
0 g
s
.83636 .70866 m .84171 .67072 L .83549 .6671 L p .707 .577 .707 r
F P
0 g
s
.84575 .57515 m .8409 .63254 L .83773 .63039 L p .707 .577 .707 r
F P
0 g
s
.83773 .63039 m .84258 .573 L .84575 .57515 L p .707 .577 .707 r
F P
0 g
s
.8361 .73292 m .83512 .75192 L .84209 .74779 L p .707 .577 .707 r
F P
0 g
s
.84209 .74779 m .84307 .72879 L .8361 .73292 L p .707 .577 .707 r
F P
0 g
s
.63761 .61474 m .64246 .55735 L .64924 .55607 L p .707 .577 .707 r
F P
0 g
s
.84171 .67072 m .83636 .70866 L .83269 .71093 L p .707 .577 .707 r
F P
0 g
s
.64924 .55607 m .64439 .61346 L .63761 .61474 L p .707 .577 .707 r
F P
0 g
s
.64141 .74041 m .64239 .72141 L .63939 .71668 L p .707 .577 .707 r
F P
0 g
s
.83269 .71093 m .83804 .67299 L .84171 .67072 L p .707 .577 .707 r
F P
0 g
s
.63939 .71668 m .63841 .73569 L .64141 .74041 L p .707 .577 .707 r
F P
0 g
s
.64575 .64674 m .6404 .68468 L .63417 .68106 L p .707 .577 .707 r
F P
0 g
s
.63417 .68106 m .63953 .64312 L .64575 .64674 L p .707 .577 .707 r
F P
0 g
s
.84258 .573 m .83773 .63039 L .82492 .62758 L p .707 .577 .707 r
F P
0 g
s
.82492 .62758 m .82977 .57019 L .84258 .573 L p .707 .577 .707 r
F P
0 g
s
.39041 .59238 m .39526 .53499 L .36413 .53196 L p .707 .577 .707 r
F P
0 g
s
.42211 .59486 m .42695 .53747 L .39526 .53499 L p .707 .577 .707 r
F P
0 g
s
.84307 .72879 m .84209 .74779 L .8391 .74307 L p .707 .577 .707 r
F P
0 g
s
.8391 .74307 m .84007 .72406 L .84307 .72879 L p .707 .577 .707 r
F P
0 g
s
.45127 .59655 m .45612 .53916 L .42695 .53747 L p .707 .577 .707 r
F P
0 g
s
.36413 .53196 m .35929 .58936 L .39041 .59238 L p .707 .577 .707 r
F P
0 g
s
.64439 .61346 m .64924 .55607 L .6653 .55578 L p .707 .577 .707 r
F P
0 g
s
.35929 .58936 m .36413 .53196 L .33663 .52869 L p .707 .577 .707 r
F P
0 g
s
.83804 .67299 m .83269 .71093 L .81948 .71163 L p .707 .577 .707 r
F P
0 g
s
.6653 .55578 m .66046 .61318 L .64439 .61346 L p .707 .577 .707 r
F P
0 g
s
.33663 .52869 m .33178 .58609 L .35929 .58936 L p .707 .577 .707 r
F P
0 g
s
.63841 .73569 m .63939 .71668 L .64636 .71255 L p .707 .577 .707 r
F P
0 g
s
.81948 .71163 m .82484 .67368 L .83804 .67299 L p .707 .577 .707 r
F P
0 g
s
.36243 .60678 m .35708 .64473 L .38811 .64853 L p .707 .577 .707 r
F P
0 g
s
.38811 .64853 m .39347 .61058 L .36243 .60678 L p .707 .577 .707 r
F P
0 g
s
.39347 .61058 m .38811 .64853 L .41955 .65326 L p .707 .577 .707 r
F P
0 g
s
.64636 .71255 m .64539 .73156 L .63841 .73569 L p .707 .577 .707 r
F P
0 g
s
.45612 .53916 m .45127 .59655 L .47505 .59729 L p .707 .577 .707 r
F P
0 g
s
.47505 .59729 m .4799 .5399 L .45612 .53916 L p .707 .577 .707 r
F P
0 g
s
.41955 .65326 m .42491 .61531 L .39347 .61058 L p .707 .577 .707 r
F P
0 g
s
.66127 .65135 m .65591 .6893 L .6404 .68468 L p .707 .577 .707 r
F P
0 g
s
.6404 .68468 m .64575 .64674 L .66127 .65135 L p .707 .577 .707 r
F P
0 g
s
.33484 .60429 m .32948 .64223 L .35708 .64473 L p .707 .577 .707 r
F P
0 g
s
.35708 .64473 m .36243 .60678 L .33484 .60429 L p .707 .577 .707 r
F P
0 g
s
.33178 .58609 m .33663 .52869 L .31543 .5255 L p .707 .577 .707 r
F P
0 g
s
.82977 .57019 m .82492 .62758 L .80373 .62438 L p .707 .577 .707 r
F P
0 g
s
.80373 .62438 m .80857 .56699 L .82977 .57019 L p .707 .577 .707 r
F P
0 g
s
.31543 .5255 m .31058 .58289 L .33178 .58609 L p .707 .577 .707 r
F P
0 g
s
.84007 .72406 m .8391 .74307 L .82642 .73822 L p .707 .577 .707 r
F P
0 g
s
.82642 .73822 m .8274 .71921 L .84007 .72406 L p .707 .577 .707 r
F P
0 g
s
.47161 .66362 m .47696 .62567 L .45368 .62051 L p .707 .577 .707 r
F P
0 g
s
.66046 .61318 m .6653 .55578 L .68908 .55652 L p .707 .577 .707 r
F P
0 g
s
.31339 .60334 m .30803 .64129 L .32948 .64223 L p .707 .577 .707 r
F P
0 g
s
.32948 .64223 m .33484 .60429 L .31339 .60334 L p .707 .577 .707 r
F P
0 g
s
.39081 .71925 m .39178 .70024 L .36063 .69767 L p .707 .577 .707 r
F P
0 g
s
.39178 .70024 m .39081 .71925 L .42259 .72042 L p .707 .577 .707 r
F P
0 g
s
.42259 .72042 m .42357 .70141 L .39178 .70024 L p .707 .577 .707 r
F P
0 g
s
.68908 .55652 m .68424 .61392 L .66046 .61318 L p .707 .577 .707 r
F P
0 g
s
.4799 .5399 m .47505 .59729 L .49111 .59701 L p .707 .577 .707 r
F P
0 g
s
.49111 .59701 m .49596 .53962 L .4799 .5399 L p .707 .577 .707 r
F P
0 g
s
.82484 .67368 m .81948 .71163 L .79803 .71068 L p .707 .577 .707 r
F P
0 g
s
.36063 .69767 m .35965 .71668 L .39081 .71925 L p .707 .577 .707 r
F P
0 g
s
.4519 .72007 m .45287 .70107 L .42357 .70141 L p .707 .577 .707 r
F P
0 g
s
.79803 .71068 m .80339 .67274 L .82484 .67368 L p .707 .577 .707 r
F P
0 g
s
.64539 .73156 m .64636 .71255 L .66262 .70942 L p .707 .577 .707 r
F P
0 g
s
.35965 .71668 m .36063 .69767 L .33315 .69395 L p .707 .577 .707 r
F P
0 g
s
.66262 .70942 m .66165 .72843 L .64539 .73156 L p .707 .577 .707 r
F P
0 g
s
.31058 .58289 m .31543 .5255 L .30262 .52268 L p .707 .577 .707 r
F P
0 g
s
.33315 .69395 m .33218 .71296 L .35965 .71668 L p .707 .577 .707 r
F P
0 g
s
.68455 .65651 m .67919 .69446 L .65591 .6893 L p .707 .577 .707 r
F P
0 g
s
.65591 .6893 m .66127 .65135 L .68455 .65651 L p .707 .577 .707 r
F P
0 g
s
.80857 .56699 m .80373 .62438 L .77622 .62111 L p .707 .577 .707 r
F P
0 g
s
.77622 .62111 m .78107 .56372 L .80857 .56699 L p .707 .577 .707 r
F P
0 g
s
.30262 .52268 m .29777 .58008 L .31058 .58289 L p .707 .577 .707 r
F P
0 g
s
.47696 .62567 m .47161 .66362 L .48712 .66823 L p .707 .577 .707 r
F P
0 g
s
.45287 .70107 m .4519 .72007 L .47585 .71824 L p .707 .577 .707 r
F P
0 g
s
.47585 .71824 m .47683 .69923 L .45287 .70107 L p .707 .577 .707 r
F P
0 g
s
.48712 .66823 m .49248 .63029 L .47696 .62567 L p .707 .577 .707 r
F P
0 g
s
.68424 .61392 m .68908 .55652 L .71825 .55822 L p .707 .577 .707 r
F P
0 g
s
.71825 .55822 m .7134 .61561 L .68424 .61392 L p .707 .577 .707 r
F P
0 g
s
.30019 .60404 m .29483 .64198 L .30803 .64129 L p .707 .577 .707 r
F P
0 g
s
.30803 .64129 m .31339 .60334 L .30019 .60404 L p .707 .577 .707 r
F P
0 g
s
.33218 .71296 m .33315 .69395 L .31205 .68944 L p .707 .577 .707 r
F P
0 g
s
.8274 .71921 m .82642 .73822 L .80532 .73371 L p .707 .577 .707 r
F P
0 g
s
.80532 .73371 m .8063 .7147 L .8274 .71921 L p .707 .577 .707 r
F P
0 g
s
.80339 .67274 m .79803 .71068 L .77044 .70818 L p .707 .577 .707 r
F P
0 g
s
.31205 .68944 m .31107 .70845 L .33218 .71296 L p .707 .577 .707 r
F P
0 g
s
.78107 .56372 m .77622 .62111 L .7451 .61809 L p .707 .577 .707 r
F P
0 g
s
.7451 .61809 m .74994 .5607 L .78107 .56372 L p .707 .577 .707 r
F P
0 g
s
.77044 .70818 m .7758 .67024 L .80339 .67274 L p .707 .577 .707 r
F P
0 g
s
.49596 .53962 m .49111 .59701 L .49789 .59573 L p .707 .577 .707 r
F P
0 g
s
.49789 .59573 m .50274 .53833 L .49596 .53962 L p .707 .577 .707 r
F P
0 g
s
.71332 .66171 m .70796 .69966 L .67919 .69446 L p .707 .577 .707 r
F P
0 g
s
.67919 .69446 m .68455 .65651 L .71332 .66171 L p .707 .577 .707 r
F P
0 g
s
.7134 .61561 m .71825 .55822 L .74994 .5607 L p .707 .577 .707 r
F P
0 g
s
.66165 .72843 m .66262 .70942 L .68658 .70759 L p .707 .577 .707 r
F P
0 g
s
.74994 .5607 m .7451 .61809 L .7134 .61561 L p .707 .577 .707 r
F P
0 g
s
.68658 .70759 m .6856 .7266 L .66165 .72843 L p .707 .577 .707 r
F P
0 g
s
.47683 .69923 m .47585 .71824 L .49211 .71511 L p .707 .577 .707 r
F P
0 g
s
.49211 .71511 m .49309 .6961 L .47683 .69923 L p .707 .577 .707 r
F P
0 g
s
.29777 .58008 m .30262 .52268 L .29945 .52053 L p .707 .577 .707 r
F P
0 g
s
.7758 .67024 m .77044 .70818 L .7394 .70439 L p .707 .577 .707 r
F P
0 g
s
.49248 .63029 m .48712 .66823 L .49335 .67185 L p .707 .577 .707 r
F P
0 g
s
.29945 .52053 m .2946 .57792 L .29777 .58008 L p .707 .577 .707 r
F P
0 g
s
.7394 .70439 m .74476 .66644 L .7758 .67024 L p .707 .577 .707 r
F P
0 g
s
.74476 .66644 m .7394 .70439 L .70796 .69966 L p .707 .577 .707 r
F P
0 g
s
.70796 .69966 m .71332 .66171 L .74476 .66644 L p .707 .577 .707 r
F P
0 g
s
.49335 .67185 m .4987 .6339 L .49248 .63029 L p .707 .577 .707 r
F P
0 g
s
.31107 .70845 m .31205 .68944 L .29938 .68459 L p .707 .577 .707 r
F P
0 g
s
.8063 .7147 m .80532 .73371 L .77784 .72999 L p .707 .577 .707 r
F P
0 g
s
.77784 .72999 m .77882 .71098 L .8063 .7147 L p .707 .577 .707 r
F P
0 g
s
.29938 .68459 m .2984 .7036 L .31107 .70845 L p .707 .577 .707 r
F P
0 g
s
.29652 .6063 m .29116 .64425 L .29483 .64198 L p .707 .577 .707 r
F P
0 g
s
.29483 .64198 m .30019 .60404 L .29652 .6063 L p .707 .577 .707 r
F P
0 g
s
.6856 .7266 m .68658 .70759 L .71588 .70724 L p .707 .577 .707 r
F P
0 g
s
.71588 .70724 m .7149 .72625 L .6856 .7266 L p .707 .577 .707 r
F P
0 g
s
.50274 .53833 m .49789 .59573 L .49472 .59358 L p .707 .577 .707 r
F P
0 g
s
.49472 .59358 m .49957 .53618 L .50274 .53833 L p .707 .577 .707 r
F P
0 g
s
.77882 .71098 m .77784 .72999 L .74669 .72742 L p .707 .577 .707 r
F P
0 g
s
.74669 .72742 m .74767 .70841 L .77882 .71098 L p .707 .577 .707 r
F P
0 g
s
.49309 .6961 m .49211 .71511 L .49908 .71098 L p .707 .577 .707 r
F P
0 g
s
.49908 .71098 m .50006 .69197 L .49309 .6961 L p .707 .577 .707 r
F P
0 g
s
.7149 .72625 m .71588 .70724 L .74767 .70841 L p .707 .577 .707 r
F P
0 g
s
.74767 .70841 m .74669 .72742 L .7149 .72625 L p .707 .577 .707 r
F P
0 g
s
.2946 .57792 m .29945 .52053 L .30623 .51925 L p .707 .577 .707 r
F P
0 g
s
.4987 .6339 m .49335 .67185 L .48968 .67412 L p .707 .577 .707 r
F P
0 g
s
.30623 .51925 m .30138 .57664 L .2946 .57792 L p .707 .577 .707 r
F P
0 g
s
.2984 .7036 m .29938 .68459 L .29638 .67987 L p .707 .577 .707 r
F P
0 g
s
.48968 .67412 m .49503 .63617 L .4987 .6339 L p .707 .577 .707 r
F P
0 g
s
.29638 .67987 m .2954 .69888 L .2984 .7036 L p .707 .577 .707 r
F P
0 g
s
.30274 .60992 m .29739 .64787 L .29116 .64425 L p .707 .577 .707 r
F P
0 g
s
.29116 .64425 m .29652 .6063 L .30274 .60992 L p .707 .577 .707 r
F P
0 g
s
.49957 .53618 m .49472 .59358 L .48191 .59076 L p .707 .577 .707 r
F P
0 g
s
.48191 .59076 m .48676 .53337 L .49957 .53618 L p .707 .577 .707 r
F P
0 g
s
.50006 .69197 m .49908 .71098 L .49609 .70626 L p .707 .577 .707 r
F P
0 g
s
.49609 .70626 m .49706 .68725 L .50006 .69197 L p .707 .577 .707 r
F P
0 g
s
.30138 .57664 m .30623 .51925 L .32229 .51897 L p .707 .577 .707 r
F P
0 g
s
.49503 .63617 m .48968 .67412 L .47647 .67481 L p .707 .577 .707 r
F P
0 g
s
.32229 .51897 m .31745 .57636 L .30138 .57664 L p .707 .577 .707 r
F P
0 g
s
.2954 .69888 m .29638 .67987 L .30335 .67574 L p .707 .577 .707 r
F P
0 g
s
.47647 .67481 m .48183 .63687 L .49503 .63617 L p .707 .577 .707 r
F P
0 g
s
.30335 .67574 m .30238 .69475 L .2954 .69888 L p .707 .577 .707 r
F P
0 g
s
.31826 .61454 m .3129 .65248 L .29739 .64787 L p .707 .577 .707 r
F P
0 g
s
.29739 .64787 m .30274 .60992 L .31826 .61454 L p .707 .577 .707 r
F P
0 g
s
.48676 .53337 m .48191 .59076 L .46072 .58757 L p .707 .577 .707 r
F P
0 g
s
.46072 .58757 m .46556 .53017 L .48676 .53337 L p .707 .577 .707 r
F P
0 g
s
.49706 .68725 m .49609 .70626 L .48341 .7014 L p .707 .577 .707 r
F P
0 g
s
.48341 .7014 m .48439 .68239 L .49706 .68725 L p .707 .577 .707 r
F P
0 g
s
.31745 .57636 m .32229 .51897 L .34607 .51971 L p .707 .577 .707 r
F P
0 g
s
.34607 .51971 m .34123 .5771 L .31745 .57636 L p .707 .577 .707 r
F P
0 g
s
.48183 .63687 m .47647 .67481 L .45502 .67386 L p .707 .577 .707 r
F P
0 g
s
.45502 .67386 m .46038 .63592 L .48183 .63687 L p .707 .577 .707 r
F P
0 g
s
.30238 .69475 m .30335 .67574 L .31961 .6726 L p .707 .577 .707 r
F P
0 g
s
.31961 .6726 m .31864 .69161 L .30238 .69475 L p .707 .577 .707 r
F P
0 g
s
.34154 .6197 m .33618 .65764 L .3129 .65248 L p .707 .577 .707 r
F P
0 g
s
.3129 .65248 m .31826 .61454 L .34154 .6197 L p .707 .577 .707 r
F P
0 g
s
.46556 .53017 m .46072 .58757 L .43321 .5843 L p .707 .577 .707 r
F P
0 g
s
.43321 .5843 m .43806 .5269 L .46556 .53017 L p .707 .577 .707 r
F P
0 g
s
.34123 .5771 m .34607 .51971 L .37524 .5214 L p .707 .577 .707 r
F P
0 g
s
.37524 .5214 m .37039 .57879 L .34123 .5771 L p .707 .577 .707 r
F P
0 g
s
.48439 .68239 m .48341 .7014 L .46231 .69689 L p .707 .577 .707 r
F P
0 g
s
.46231 .69689 m .46328 .67789 L .48439 .68239 L p .707 .577 .707 r
F P
0 g
s
.46038 .63592 m .45502 .67386 L .42743 .67137 L p .707 .577 .707 r
F P
0 g
s
.43806 .5269 m .43321 .5843 L .40209 .58127 L p .707 .577 .707 r
F P
0 g
s
.40209 .58127 m .40693 .52388 L .43806 .5269 L p .707 .577 .707 r
F P
0 g
s
.42743 .67137 m .43279 .63343 L .46038 .63592 L p .707 .577 .707 r
F P
0 g
s
.37031 .6249 m .36495 .66284 L .33618 .65764 L p .707 .577 .707 r
F P
0 g
s
.33618 .65764 m .34154 .6197 L .37031 .6249 L p .707 .577 .707 r
F P
0 g
s
.37039 .57879 m .37524 .5214 L .40693 .52388 L p .707 .577 .707 r
F P
0 g
s
.31864 .69161 m .31961 .6726 L .34357 .67077 L p .707 .577 .707 r
F P
0 g
s
.40693 .52388 m .40209 .58127 L .37039 .57879 L p .707 .577 .707 r
F P
0 g
s
.34357 .67077 m .34259 .68978 L .31864 .69161 L p .707 .577 .707 r
F P
0 g
s
.43279 .63343 m .42743 .67137 L .39639 .66757 L p .707 .577 .707 r
F P
0 g
s
.39639 .66757 m .40175 .62963 L .43279 .63343 L p .707 .577 .707 r
F P
0 g
s
.40175 .62963 m .39639 .66757 L .36495 .66284 L p .707 .577 .707 r
F P
0 g
s
.36495 .66284 m .37031 .6249 L .40175 .62963 L p .707 .577 .707 r
F P
0 g
s
.46328 .67789 m .46231 .69689 L .43483 .69317 L p .707 .577 .707 r
F P
0 g
s
.43483 .69317 m .43581 .67416 L .46328 .67789 L p .707 .577 .707 r
F P
0 g
s
.34259 .68978 m .34357 .67077 L .37287 .67042 L p .707 .577 .707 r
F P
0 g
s
.37287 .67042 m .37189 .68943 L .34259 .68978 L p .707 .577 .707 r
F P
0 g
s
.43581 .67416 m .43483 .69317 L .40368 .6906 L p .707 .577 .707 r
F P
0 g
s
.40368 .6906 m .40465 .67159 L .43581 .67416 L p .707 .577 .707 r
F P
0 g
s
.37189 .68943 m .37287 .67042 L .40465 .67159 L p .707 .577 .707 r
F P
0 g
s
.40465 .67159 m .40368 .6906 L .37189 .68943 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool<0028Ool0081oo`T0
00IJEP03001JEUYF00=JEP`007aoo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MGoo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000Lgoo001bOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LGoo001^Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001_Ool006aoo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eo
o`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0`00Jgoo001YOol01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001WOol20003
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0IWoo001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001GOol?0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<0
00=JEP03001JEUYF00AJEP04001JEUYFFUH:0009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK001<Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90013Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPP003]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Eo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Goo001C
Ool00`00FUH00002FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo
001COol60005FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001KOol70004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001ROol80004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo001VOol00`00FUIJEP090005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP0L0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP8002aoo`00EGoo3P000goo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo0P000eYF
00<005YFFUH00eYF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo100000=JEP00FUH015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
E7oo00@005YF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0140
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`04001JEUYF0003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH015YF4P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF
1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH02eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
;Woo4@0057oo00<005YF00000eYF00<005YFFUH01EYF00@005YFFUIJEPL000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH70003FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH01000
FUIJEUYF4P000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000
25YF00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P002Woo4P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@00
0UYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH700000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000LOol80004FUH00`00FUIJEP04FUH0
1000FUIJEUYF1000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH>0002FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0097oo4P00;Woo000^Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00I7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH03`00FGoo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00@005YFFUIJEPT0051oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYF001JEP040005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90017Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EPD000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH0009JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003mo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03
001JEUYF00IJEP04001JEUYFFUH6000iOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000@000AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEP0000<000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH700000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000bOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000015YF001JEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0001h000AJEP03001JEUYF00=JEP04001J
EUYFFUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00
FUH01UYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF5P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH@000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF001JEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00;7oo00<005YF00003`0015YF00<005YFFUH01UYF00<005YFFUH01UYF0`00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`<0009JEP03001JEUYF00=J
EP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002moo`D000=JEP03001JEUYF00EJEP03001JEUYF00EJEPl000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool>0003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEQl000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80003FUH00`00FUIJEP06FUH01@00FUIJEP00FUH010000UYF2@0000IJEP00000005YF
0006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool400000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH00eYF00@0
05YFFUIJEPT000EJEP03001JEUYF00MJEP8000=JEPL000=JEP04001JEUYFFUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=J
EPP000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02eoo`04001JEP00FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0002FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP04
001JEUYFFUH20002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000/Ool01000FUIJEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF009JEP8000Ioo`H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000<000QJEP03001JEUYF00IJ
EP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0004FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF9@0015YF00<005YFFUH00eYF00@005YFFUIJEP80
02moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YF00001P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF5000<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUH000080004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05
FUH01000FUIJEUYF0P0000Aoo`00FUIJER0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002]oo`04001JEUYF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF40000UYF
00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000017ooFUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03
001JEUYF00IJEP8000QJEPX000aJEPT000QJEP03001JEUYF00EJEP05001JEP00FUH00002FUH:0003
FUH2000@Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00H000UJEP03
001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP04001JEP00FUH40005FUH01000
FUIJEUYF20005Goo1P000eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800004OomJEUYF0006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00EJEP04001JEUYFFUHO0003FUH2000]Ool0031oo`D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002Ool2FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF
008002eoo`00<Woo7P000eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009oo`9J
EP03001JEUYF00AJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<00003FUH005YF009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002moo`<0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000Woo0UYF00<005YFFUH015YF0P000UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00@005YF000000EJEP03001J
EP0000800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF009JEP80009o
o`9JEP03001JEUYF009JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00QJEP05001JEUYFFUH00003FUH2000015YF001JEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000002Ool2FUH00`00FUIJEP020006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH2000015YF000000001eYF4`0015YF00<005YFFUH01EYF00@005YFFUIJEPH0039o
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000Woo0UYF0`002EYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@001eYF00<0
05YFFUH00UYF0P0037oo4000>7oo000]Ool20004FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000AooeYFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP00010005Aoo`00;7oo00<005YF00000UYF1P0047oo4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEP000003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH000030004FUH5
000MOol60004FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF
00=JEP04001JEUYFFUHB000@Ool400000eYF001JEP02FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD00003FUH0000000h000=JEP@0009JEP04001o
o`000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@0
05YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1@00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003Ool0000000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0031o
o`@000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP08001JEUYFFUH005YF001oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol003Aoo`L000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH20003Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH60002FUH01000FUIJEUYF0P00EGoo000kOol90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF200017oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000P000UYF0P00EWoo0014OolI000<Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`001eYF00<005YFFUH00UYF1000EWoo001ZOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00001EOol006]o
o`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008005Ao
o`00KGoo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF0P0000=oo`0000001P000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
KWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH00eYF0`002goo1P000eYF00@005YFFUIJEP8005Aoo`00L7oo0P0015YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00005P0000=JEP0000000`00
0UYF0P00E7oo001bOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04001D
Ool007Eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000EJEPD000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00O7oo30001UYF00<005YFFUH0
15YF2@000UYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000E7oo0028Ool=0007Ool90004FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP04001EOol00:Eoo`T000AJEP03001JEUYF009JEPd005Uoo`00[Woo2@00IWoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59595 .74008 m .59897 .68303 L .56781 .68044 L p .707 .577 .707 r
F P
0 g
s
.59897 .68303 m .59595 .74008 L .62774 .7413 L p .707 .577 .707 r
F P
0 g
s
.62774 .7413 m .63075 .68425 L .59897 .68303 L p .707 .577 .707 r
F P
0 g
s
.63075 .68425 m .62774 .7413 L .65703 .74104 L p .707 .577 .707 r
F P
0 g
s
.65703 .74104 m .66005 .68399 L .63075 .68425 L p .707 .577 .707 r
F P
0 g
s
.5648 .73749 m .56781 .68044 L .54034 .67673 L p .707 .577 .707 r
F P
0 g
s
.56781 .68044 m .5648 .73749 L .59595 .74008 L p .707 .577 .707 r
F P
0 g
s
.59412 .7871 m .59749 .74883 L .56636 .74576 L p .707 .577 .707 r
F P
0 g
s
.59749 .74883 m .59412 .7871 L .62581 .78972 L p .707 .577 .707 r
F P
0 g
s
.62581 .78972 m .62917 .75145 L .59749 .74883 L p .707 .577 .707 r
F P
0 g
s
.54034 .67673 m .53732 .73378 L .5648 .73749 L p .707 .577 .707 r
F P
0 g
s
.66005 .68399 m .65703 .74104 L .68098 .73932 L p .707 .577 .707 r
F P
0 g
s
.68098 .73932 m .68399 .68227 L .66005 .68399 L p .707 .577 .707 r
F P
0 g
s
.56636 .74576 m .563 .78403 L .59412 .7871 L p .707 .577 .707 r
F P
0 g
s
.62917 .75145 m .62581 .78972 L .65495 .79162 L p .707 .577 .707 r
F P
0 g
s
.65495 .79162 m .65832 .75335 L .62917 .75145 L p .707 .577 .707 r
F P
0 g
s
.563 .78403 m .56636 .74576 L .53885 .74254 L p .707 .577 .707 r
F P
0 g
s
.53732 .73378 m .54034 .67673 L .51923 .67228 L p .707 .577 .707 r
F P
0 g
s
.53885 .74254 m .53549 .78081 L .563 .78403 L p .707 .577 .707 r
F P
0 g
s
.51923 .67228 m .51621 .72933 L .53732 .73378 L p .707 .577 .707 r
F P
0 g
s
.65832 .75335 m .65495 .79162 L .67871 .79263 L p .707 .577 .707 r
F P
0 g
s
.67871 .79263 m .68207 .75436 L .65832 .75335 L p .707 .577 .707 r
F P
0 g
s
.59635 .83763 m .59695 .81877 L .56579 .81645 L p .707 .577 .707 r
F P
0 g
s
.59695 .81877 m .59635 .83763 L .62816 .83805 L p .707 .577 .707 r
F P
0 g
s
.62816 .83805 m .62877 .81919 L .59695 .81877 L p .707 .577 .707 r
F P
0 g
s
.62877 .81919 m .62816 .83805 L .65752 .83654 L p .707 .577 .707 r
F P
0 g
s
.65752 .83654 m .65812 .81767 L .62877 .81919 L p .707 .577 .707 r
F P
0 g
s
.56579 .81645 m .56518 .83532 L .59635 .83763 L p .707 .577 .707 r
F P
0 g
s
.53549 .78081 m .53885 .74254 L .51765 .73948 L p .707 .577 .707 r
F P
0 g
s
.68399 .68227 m .68098 .73932 L .69724 .7363 L p .707 .577 .707 r
F P
0 g
s
.69724 .7363 m .70025 .67925 L .68399 .68227 L p .707 .577 .707 r
F P
0 g
s
.51765 .73948 m .51429 .77775 L .53549 .78081 L p .707 .577 .707 r
F P
0 g
s
.56518 .83532 m .56579 .81645 L .53832 .81247 L p .707 .577 .707 r
F P
0 g
s
.53832 .81247 m .53772 .83134 L .56518 .83532 L p .707 .577 .707 r
F P
0 g
s
.51621 .72933 m .51923 .67228 L .50655 .66751 L p .707 .577 .707 r
F P
0 g
s
.65812 .81767 m .65752 .83654 L .68153 .83324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83324 m .68214 .81437 L .65812 .81767 L p .707 .577 .707 r
F P
0 g
s
.68207 .75436 m .67871 .79263 L .69475 .79264 L p .707 .577 .707 r
F P
0 g
s
.69475 .79264 m .69811 .75437 L .68207 .75436 L p .707 .577 .707 r
F P
0 g
s
.50655 .66751 m .50354 .72456 L .51621 .72933 L p .707 .577 .707 r
F P
0 g
s
.53772 .83134 m .53832 .81247 L .51725 .80722 L p .707 .577 .707 r
F P
0 g
s
.51725 .80722 m .51664 .82608 L .53772 .83134 L p .707 .577 .707 r
F P
0 g
s
.51429 .77775 m .51765 .73948 L .50482 .73688 L p .707 .577 .707 r
F P
0 g
s
.50482 .73688 m .50146 .77515 L .51429 .77775 L p .707 .577 .707 r
F P
0 g
s
.70025 .67925 m .69724 .7363 L .7042 .73229 L p .707 .577 .707 r
F P
0 g
s
.7042 .73229 m .70721 .67524 L .70025 .67925 L p .707 .577 .707 r
F P
0 g
s
.68214 .81437 m .68153 .83324 L .69786 .82847 L p .707 .577 .707 r
F P
0 g
s
.69786 .82847 m .69846 .80961 L .68214 .81437 L p .707 .577 .707 r
F P
0 g
s
.50354 .72456 m .50655 .66751 L .50355 .6629 L p .707 .577 .707 r
F P
0 g
s
.51664 .82608 m .51725 .80722 L .50462 .8012 L p .707 .577 .707 r
F P
0 g
s
.69811 .75437 m .69475 .79264 L .7015 .79166 L p .707 .577 .707 r
F P
0 g
s
.7015 .79166 m .70486 .75339 L .69811 .75437 L p .707 .577 .707 r
F P
0 g
s
.50462 .8012 m .50402 .82006 L .51664 .82608 L p .707 .577 .707 r
F P
0 g
s
.50355 .6629 m .50054 .71995 L .50354 .72456 L p .707 .577 .707 r
F P
0 g
s
.50146 .77515 m .50482 .73688 L .50163 .73499 L p .707 .577 .707 r
F P
0 g
s
.49657 .82399 m .48694 .32918 L .44293 .32683 L p .707 .577 .707 r
F P
0 g
s
.50163 .73499 m .49826 .77326 L .50146 .77515 L p .707 .577 .707 r
F P
0 g
s
.50054 .71995 m .50355 .6629 L .51052 .65889 L p .707 .577 .707 r
F P
0 g
s
.50402 .82006 m .50462 .8012 L .50169 .795 L p .707 .577 .707 r
F P
0 g
s
.50169 .795 m .50109 .81387 L .50402 .82006 L p .707 .577 .707 r
F P
0 g
s
.51052 .65889 m .5075 .71594 L .50054 .71995 L p .707 .577 .707 r
F P
0 g
s
.49826 .77326 m .50163 .73499 L .50838 .73401 L p .707 .577 .707 r
F P
0 g
s
.50838 .73401 m .50502 .77228 L .49826 .77326 L p .707 .577 .707 r
F P
0 g
s
.5075 .71594 m .51052 .65889 L .52677 .65587 L p .707 .577 .707 r
F P
0 g
s
.50109 .81387 m .50169 .795 L .50873 .78924 L p .707 .577 .707 r
F P
0 g
s
.50873 .78924 m .50813 .80811 L .50109 .81387 L p .707 .577 .707 r
F P
0 g
s
.52677 .65587 m .52376 .71292 L .5075 .71594 L p .707 .577 .707 r
F P
0 g
s
.50502 .77228 m .50838 .73401 L .52442 .73402 L p .707 .577 .707 r
F P
0 g
s
.52442 .73402 m .52106 .77229 L .50502 .77228 L p .707 .577 .707 r
F P
0 g
s
.52376 .71292 m .52677 .65587 L .55072 .65415 L p .707 .577 .707 r
F P
0 g
s
.50813 .80811 m .50873 .78924 L .52506 .78448 L p .707 .577 .707 r
F P
0 g
s
.52506 .78448 m .52445 .80335 L .50813 .80811 L p .707 .577 .707 r
F P
0 g
s
.55072 .65415 m .5477 .7112 L .52376 .71292 L p .707 .577 .707 r
F P
0 g
s
.52106 .77229 m .52442 .73402 L .54817 .73503 L p .707 .577 .707 r
F P
0 g
s
.54817 .73503 m .54481 .7733 L .52106 .77229 L p .707 .577 .707 r
F P
0 g
s
.52445 .80335 m .52506 .78448 L .54907 .78118 L p .707 .577 .707 r
F P
0 g
s
.54907 .78118 m .54847 .80005 L .52445 .80335 L p .707 .577 .707 r
F P
0 g
s
.48694 .32918 m .49657 .82399 L .5415 .82192 L p .707 .577 .707 r
F P
0 g
s
.5415 .82192 m .53187 .32711 L .48694 .32918 L p .707 .577 .707 r
F P
0 g
s
.5477 .7112 m .55072 .65415 L .58002 .65389 L p .707 .577 .707 r
F P
0 g
s
.58002 .65389 m .577 .71094 L .5477 .7112 L p .707 .577 .707 r
F P
0 g
s
.54481 .7733 m .54817 .73503 L .57732 .73693 L p .707 .577 .707 r
F P
0 g
s
.57732 .73693 m .57396 .7752 L .54481 .7733 L p .707 .577 .707 r
F P
0 g
s
.57396 .7752 m .57732 .73693 L .60901 .73955 L p .707 .577 .707 r
F P
0 g
s
.60901 .73955 m .60564 .77782 L .57396 .7752 L p .707 .577 .707 r
F P
0 g
s
.54847 .80005 m .54907 .78118 L .57842 .77967 L p .707 .577 .707 r
F P
0 g
s
.57842 .77967 m .57782 .79853 L .54847 .80005 L p .707 .577 .707 r
F P
0 g
s
.57782 .79853 m .57842 .77967 L .61024 .78008 L p .707 .577 .707 r
F P
0 g
s
.61024 .78008 m .60964 .79895 L .57782 .79853 L p .707 .577 .707 r
F P
0 g
s
.53187 .32711 m .5415 .82192 L .58297 .81563 L p .707 .577 .707 r
F P
0 g
s
.577 .71094 m .58002 .65389 L .6118 .65511 L p .707 .577 .707 r
F P
0 g
s
.6118 .65511 m .60879 .71216 L .577 .71094 L p .707 .577 .707 r
F P
0 g
s
.58297 .81563 m .57334 .32082 L .53187 .32711 L p .707 .577 .707 r
F P
0 g
s
.70721 .67524 m .7042 .73229 L .7012 .72768 L p .707 .577 .707 r
F P
0 g
s
.7012 .72768 m .70421 .67062 L .70721 .67524 L p .707 .577 .707 r
F P
0 g
s
.69846 .80961 m .69786 .82847 L .7049 .82271 L p .707 .577 .707 r
F P
0 g
s
.7049 .82271 m .7055 .80385 L .69846 .80961 L p .707 .577 .707 r
F P
0 g
s
.45256 .82164 m .44293 .32683 L .40417 .3203 L p .707 .577 .707 r
F P
0 g
s
.44293 .32683 m .45256 .82164 L .49657 .82399 L p .707 .577 .707 r
F P
0 g
s
.64013 .74262 m .63676 .78089 L .61419 .77866 L p .707 .577 .707 r
F P
0 g
s
.61419 .77866 m .60564 .77782 L p .61464 .76864 L .707 .577 .707 r
F P
0 g
s
.61464 .76864 m .64013 .74262 L .61419 .77866 L .707 .577 .707 r
F
.67043 .6614 m .66742 .71845 L .63994 .71475 L p F P
0 g
s
.63994 .71475 m .64295 .6577 L .67043 .6614 L p .707 .577 .707 r
F P
0 g
s
.64295 .6577 m .63994 .71475 L .60879 .71216 L p .707 .577 .707 r
F P
0 g
s
.60879 .71216 m .6118 .65511 L .64295 .6577 L p .707 .577 .707 r
F P
0 g
s
.66764 .74584 m .66427 .78411 L .63676 .78089 L p .707 .577 .707 r
F P
0 g
s
.63676 .78089 m .64013 .74262 L .66764 .74584 L p .707 .577 .707 r
F P
0 g
s
.6408 .80126 m .64141 .7824 L .66887 .78638 L p .707 .577 .707 r
F P
0 g
s
.60564 .77782 m .60901 .73955 L .64013 .74262 L p .707 .577 .707 r
F P
0 g
s
.64141 .7824 m .6408 .80126 L .60964 .79895 L p .707 .577 .707 r
F P
0 g
s
.60964 .79895 m .61024 .78008 L .64141 .7824 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .64997 .77928 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63037 .2984 m .63192 .37812 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63192 .37812 m .63999 .79321 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.57334 .32082 m .58297 .81563 L .61691 .80574 L p .707 .577 .707 r
F P
0 g
s
.61691 .80574 m .60728 .31093 L .57334 .32082 L p .707 .577 .707 r
F P
0 g
s
.70486 .75339 m .7015 .79166 L .69831 .78977 L p .707 .577 .707 r
F P
0 g
s
.69831 .78977 m .70167 .7515 L .70486 .75339 L p .707 .577 .707 r
F P
0 g
s
.41379 .81511 m .40417 .3203 L .37443 .31021 L p .707 .577 .707 r
F P
0 g
s
.40417 .3203 m .41379 .81511 L .45256 .82164 L p .707 .577 .707 r
F P
0 g
s
.7055 .80385 m .7049 .82271 L .70196 .81652 L p .707 .577 .707 r
F P
0 g
s
.70196 .81652 m .70257 .79765 L .7055 .80385 L p .707 .577 .707 r
F P
0 g
s
.70421 .67062 m .7012 .72768 L .68852 .72291 L p .707 .577 .707 r
F P
0 g
s
.68852 .72291 m .69154 .66586 L .70421 .67062 L p .707 .577 .707 r
F P
0 g
s
.25295 .70326 m .25596 .64621 L .2248 .64362 L p .707 .577 .707 r
F P
0 g
s
.25596 .64621 m .25295 .70326 L .28473 .70449 L p .707 .577 .707 r
F P
0 g
s
.28473 .70449 m .28774 .64744 L .25596 .64621 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28774 .64744 m .28473 .70449 L .31403 .70422 L p .707 .577 .707 r
F P
0 g
s
.31403 .70422 m .31704 .64717 L .28774 .64744 L p .707 .577 .707 r
F P
0 g
s
.22179 .70067 m .2248 .64362 L .19733 .63992 L p .707 .577 .707 r
F P
0 g
s
.2248 .64362 m .22179 .70067 L .25295 .70326 L p .707 .577 .707 r
F P
0 g
s
.60728 .31093 m .61691 .80574 L .63999 .79321 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .63037 .2984 L .60728 .31093 L p .707 .577 .707 r
F P
0 g
s
.70167 .7515 m .69831 .78977 L .68548 .78717 L p .707 .577 .707 r
F P
0 g
s
.68548 .78717 m .68884 .7489 L .70167 .7515 L p .707 .577 .707 r
F P
0 g
s
.25111 .75029 m .25448 .71202 L .22336 .70895 L p .707 .577 .707 r
F P
0 g
s
.25448 .71202 m .25111 .75029 L .2828 .7529 L p .707 .577 .707 r
F P
0 g
s
.2828 .7529 m .28616 .71463 L .25448 .71202 L p .707 .577 .707 r
F P
0 g
s
.19733 .63992 m .19431 .69697 L .22179 .70067 L p .707 .577 .707 r
F P
0 g
s
.31704 .64717 m .31403 .70422 L .33797 .7025 L p .707 .577 .707 r
F P
0 g
s
.33797 .7025 m .34099 .64545 L .31704 .64717 L p .707 .577 .707 r
F P
0 g
s
.22336 .70895 m .21999 .74722 L .25111 .75029 L p .707 .577 .707 r
F P
0 g
s
.28616 .71463 m .2828 .7529 L .31194 .75481 L p .707 .577 .707 r
F P
0 g
s
.31194 .75481 m .31531 .71654 L .28616 .71463 L p .707 .577 .707 r
F P
0 g
s
.21999 .74722 m .22336 .70895 L .19585 .70572 L p .707 .577 .707 r
F P
0 g
s
.19431 .69697 m .19733 .63992 L .17622 .63547 L p .707 .577 .707 r
F P
0 g
s
.38406 .80502 m .37443 .31021 L .35664 .29756 L p .707 .577 .707 r
F P
0 g
s
.37443 .31021 m .38406 .80502 L .41379 .81511 L p .707 .577 .707 r
F P
0 g
s
.19585 .70572 m .19248 .74399 L .21999 .74722 L p .707 .577 .707 r
F P
0 g
s
.69154 .66586 m .68852 .72291 L .66742 .71845 L p .707 .577 .707 r
F P
0 g
s
.66742 .71845 m .67043 .6614 L .69154 .66586 L p .707 .577 .707 r
F P
0 g
s
.70257 .79765 m .70196 .81652 L .68934 .8105 L p .707 .577 .707 r
F P
0 g
s
.68934 .8105 m .68995 .79163 L .70257 .79765 L p .707 .577 .707 r
F P
0 g
s
.17622 .63547 m .17321 .69252 L .19431 .69697 L p .707 .577 .707 r
F P
0 g
s
.31531 .71654 m .31194 .75481 L .3357 .75581 L p .707 .577 .707 r
F P
0 g
s
.3357 .75581 m .33906 .71754 L .31531 .71654 L p .707 .577 .707 r
F P
0 g
s
.25334 .80082 m .25394 .78195 L .22278 .77964 L p .707 .577 .707 r
F P
0 g
s
.25394 .78195 m .25334 .80082 L .28515 .80124 L p .707 .577 .707 r
F P
0 g
s
.28515 .80124 m .28576 .78237 L .25394 .78195 L p .707 .577 .707 r
F P
0 g
s
.28576 .78237 m .28515 .80124 L .31451 .79972 L p .707 .577 .707 r
F P
0 g
s
.31451 .79972 m .31511 .78086 L .28576 .78237 L p .707 .577 .707 r
F P
0 g
s
.22278 .77964 m .22217 .7985 L .25334 .80082 L p .707 .577 .707 r
F P
0 g
s
.19248 .74399 m .19585 .70572 L .17464 .70266 L p .707 .577 .707 r
F P
0 g
s
.34099 .64545 m .33797 .7025 L .35423 .69949 L p .707 .577 .707 r
F P
0 g
s
.35423 .69949 m .35724 .64244 L .34099 .64545 L p .707 .577 .707 r
F P
0 g
s
.17464 .70266 m .17128 .74093 L .19248 .74399 L p .707 .577 .707 r
F P
0 g
s
.22217 .7985 m .22278 .77964 L .19531 .77566 L p .707 .577 .707 r
F P
0 g
s
.68884 .7489 m .68548 .78717 L .66427 .78411 L p .707 .577 .707 r
F P
0 g
s
.66427 .78411 m .66764 .74584 L .68884 .7489 L p .707 .577 .707 r
F P
0 g
s
.19531 .77566 m .19471 .79452 L .22217 .7985 L p .707 .577 .707 r
F P
0 g
s
.64997 .77928 m .64035 .28447 L .63037 .2984 L p .707 .577 .707 r
F P
0 g
s
.17321 .69252 m .17622 .63547 L .16354 .6307 L p .707 .577 .707 r
F P
0 g
s
.31511 .78086 m .31451 .79972 L .33852 .79642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79642 m .33913 .77756 L .31511 .78086 L p .707 .577 .707 r
F P
0 g
s
.33906 .71754 m .3357 .75581 L .35174 .75583 L p .707 .577 .707 r
F P
0 g
s
.35174 .75583 m .3551 .71756 L .33906 .71754 L p .707 .577 .707 r
F P
0 g
s
.16354 .6307 m .16053 .68775 L .17321 .69252 L p .707 .577 .707 r
F P
0 g
s
.68995 .79163 m .68934 .8105 L .66827 .80524 L p .707 .577 .707 r
F P
0 g
s
.66827 .80524 m .66887 .78638 L .68995 .79163 L p .707 .577 .707 r
F P
0 g
s
.19471 .79452 m .19531 .77566 L .17424 .7704 L p .707 .577 .707 r
F P
0 g
s
.17424 .7704 m .17363 .78927 L .19471 .79452 L p .707 .577 .707 r
F P
0 g
s
.17128 .74093 m .17464 .70266 L .16181 .70006 L p .707 .577 .707 r
F P
0 g
s
.36119 .69548 m .3642 .63842 L .35724 .64244 L p .707 .577 .707 r
F P
0 g
s
.35724 .64244 m .35423 .69949 L .36119 .69548 L p .707 .577 .707 r
F P
0 g
s
.3642 .63842 m .36119 .69548 L .35819 .69086 L p .707 .577 .707 r
F P
0 g
s
.35819 .69086 m .3612 .63381 L .3642 .63842 L p .707 .577 .707 r
F P
0 g
s
.36627 .79237 m .35664 .29756 L .35253 .28359 L p .707 .577 .707 r
F P
0 g
s
.35664 .29756 m .36627 .79237 L .38406 .80502 L p .707 .577 .707 r
F P
0 g
s
.16181 .70006 m .15845 .73833 L .17128 .74093 L p .707 .577 .707 r
F P
0 g
s
.33913 .77756 m .33852 .79642 L .35485 .79166 L p .707 .577 .707 r
F P
0 g
s
.35485 .79166 m .35545 .77279 L .33913 .77756 L p .707 .577 .707 r
F P
0 g
s
.16053 .68775 m .16354 .6307 L .16054 .62608 L p .707 .577 .707 r
F P
0 g
s
.66887 .78638 m .66827 .80524 L .6408 .80126 L p .707 .577 .707 r
F P
0 g
s
.17363 .78927 m .17424 .7704 L .16162 .76438 L p .707 .577 .707 r
F P
0 g
s
.3551 .71756 m .35174 .75583 L .35849 .75484 L p .707 .577 .707 r
F P
0 g
s
.35849 .75484 m .36186 .71657 L .3551 .71756 L p .707 .577 .707 r
F P
0 g
s
.16162 .76438 m .16101 .78325 L .17363 .78927 L p .707 .577 .707 r
F P
0 g
s
.16054 .62608 m .15753 .68313 L .16053 .68775 L p .707 .577 .707 r
F P
0 g
s
.64035 .28447 m .64997 .77928 L .64947 .77756 L p .707 .577 .707 r
F P
0 g
s
.64534 .71934 m .64035 .28447 L .64947 .77756 L .707 .577 .707 r
F
.64587 .76531 m .63624 .2705 L .64035 .28447 L p F P
0 g
s
.63624 .2705 m .64587 .76531 L .62807 .75266 L p .707 .577 .707 r
F P
0 g
s
.64202 .64793 m .64106 .65895 L p .65149 .6888 L .707 .577 .707 r
F P
0 g
s
.64106 .65895 m .63866 .6862 L .64305 .68709 L p .707 .577 .707 r
F P
0 g
s
.64305 .68709 m .65149 .6888 L p .64106 .65895 L .707 .577 .707 r
F P
0 g
s
.64947 .77756 m .64587 .76531 L p .64534 .71934 L .707 .577 .707 r
F P
0 g
s
.15845 .73833 m .16181 .70006 L .15862 .69818 L p .707 .577 .707 r
F P
0 g
s
.15862 .69818 m .15525 .73645 L .15845 .73833 L p .707 .577 .707 r
F P
0 g
s
.35545 .77279 m .35485 .79166 L .36189 .7859 L p .707 .577 .707 r
F P
0 g
s
.36189 .7859 m .36249 .76703 L .35545 .77279 L p .707 .577 .707 r
F P
0 g
s
.36186 .71657 m .35849 .75484 L .3553 .75296 L p .707 .577 .707 r
F P
0 g
s
.3553 .75296 m .35866 .71469 L .36186 .71657 L p .707 .577 .707 r
F P
0 g
s
.36249 .76703 m .36189 .7859 L .35895 .77971 L p .707 .577 .707 r
F P
0 g
s
.35895 .77971 m .35956 .76084 L .36249 .76703 L p .707 .577 .707 r
F P
0 g
s
.3612 .63381 m .35819 .69086 L .34552 .68609 L p .707 .577 .707 r
F P
0 g
s
.34552 .68609 m .34853 .62904 L .3612 .63381 L p .707 .577 .707 r
F P
0 g
s
.35253 .28359 m .36216 .77839 L .36627 .79237 L p .707 .577 .707 r
F P
0 g
s
.36216 .77839 m .35253 .28359 L .36251 .26965 L p .707 .577 .707 r
F P
0 g
s
.15753 .68313 m .16054 .62608 L .16751 .62207 L p .707 .577 .707 r
F P
0 g
s
.16101 .78325 m .16162 .76438 L .15868 .75819 L p .707 .577 .707 r
F P
0 g
s
.15868 .75819 m .15808 .77706 L .16101 .78325 L p .707 .577 .707 r
F P
0 g
s
.16751 .62207 m .16449 .67912 L .15753 .68313 L p .707 .577 .707 r
F P
0 g
s
.15525 .73645 m .15862 .69818 L .16537 .69719 L p .707 .577 .707 r
F P
0 g
s
.16537 .69719 m .16201 .73546 L .15525 .73645 L p .707 .577 .707 r
F P
0 g
s
.62807 .75266 m .61845 .25785 L .63624 .2705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16449 .67912 m .16751 .62207 L .18376 .61906 L p .707 .577 .707 r
F P
0 g
s
.15808 .77706 m .15868 .75819 L .16572 .75243 L p .707 .577 .707 r
F P
0 g
s
.16572 .75243 m .16512 .7713 L .15808 .77706 L p .707 .577 .707 r
F P
0 g
s
.35866 .71469 m .3553 .75296 L .34247 .75036 L p .707 .577 .707 r
F P
0 g
s
.34247 .75036 m .34583 .71209 L .35866 .71469 L p .707 .577 .707 r
F P
0 g
s
.18376 .61906 m .18075 .67611 L .16449 .67912 L p .707 .577 .707 r
F P
0 g
s
.37214 .76446 m .36251 .26965 L .3856 .25713 L p .707 .577 .707 r
F P
0 g
s
.36251 .26965 m .37214 .76446 L .36216 .77839 L p .707 .577 .707 r
F P
0 g
s
.16201 .73546 m .16537 .69719 L .18141 .69721 L p .707 .577 .707 r
F P
0 g
s
.18141 .69721 m .17805 .73548 L .16201 .73546 L p .707 .577 .707 r
F P
0 g
s
.34853 .62904 m .34552 .68609 L .32441 .68164 L p .707 .577 .707 r
F P
0 g
s
.32441 .68164 m .32742 .62459 L .34853 .62904 L p .707 .577 .707 r
F P
0 g
s
.35956 .76084 m .35895 .77971 L .34633 .77369 L p .707 .577 .707 r
F P
0 g
s
.34633 .77369 m .34694 .75482 L .35956 .76084 L p .707 .577 .707 r
F P
0 g
s
.18075 .67611 m .18376 .61906 L .20771 .61733 L p .707 .577 .707 r
F P
0 g
s
.61845 .25785 m .62807 .75266 L .59834 .74257 L p .707 .577 .707 r
F P
0 g
s
.59834 .74257 m .58871 .24776 L .61845 .25785 L p .707 .577 .707 r
F P
0 g
s
.16512 .7713 m .16572 .75243 L .18205 .74766 L p .707 .577 .707 r
F P
0 g
s
.34583 .71209 m .34247 .75036 L .32126 .7473 L p .707 .577 .707 r
F P
0 g
s
.32126 .7473 m .32463 .70903 L .34583 .71209 L p .707 .577 .707 r
F P
0 g
s
.18205 .74766 m .18144 .76653 L .16512 .7713 L p .707 .577 .707 r
F P
0 g
s
.20771 .61733 m .20469 .67439 L .18075 .67611 L p .707 .577 .707 r
F P
0 g
s
.32742 .62459 m .32441 .68164 L .29693 .67794 L p .707 .577 .707 r
F P
0 g
s
.29693 .67794 m .29994 .62089 L .32742 .62459 L p .707 .577 .707 r
F P
0 g
s
.17805 .73548 m .18141 .69721 L .20517 .69821 L p .707 .577 .707 r
F P
0 g
s
.20517 .69821 m .2018 .73648 L .17805 .73548 L p .707 .577 .707 r
F P
0 g
s
.3856 .25713 m .39523 .75194 L .37214 .76446 L p .707 .577 .707 r
F P
0 g
s
.39523 .75194 m .3856 .25713 L .41954 .24724 L p .707 .577 .707 r
F P
0 g
s
.20469 .67439 m .20771 .61733 L .23701 .61707 L p .707 .577 .707 r
F P
0 g
s
.34694 .75482 m .34633 .77369 L .32526 .76843 L p .707 .577 .707 r
F P
0 g
s
.32526 .76843 m .32586 .74956 L .34694 .75482 L p .707 .577 .707 r
F P
0 g
s
.23701 .61707 m .23399 .67412 L .20469 .67439 L p .707 .577 .707 r
F P
0 g
s
.29994 .62089 m .29693 .67794 L .26578 .67535 L p .707 .577 .707 r
F P
0 g
s
.26578 .67535 m .26879 .6183 L .29994 .62089 L p .707 .577 .707 r
F P
0 g
s
.32463 .70903 m .32126 .7473 L .29375 .74407 L p .707 .577 .707 r
F P
0 g
s
.29375 .74407 m .29712 .7058 L .32463 .70903 L p .707 .577 .707 r
F P
0 g
s
.73316 .64024 m .73617 .58319 L .70502 .5806 L p .707 .577 .707 r
F P
0 g
s
.73617 .58319 m .73316 .64024 L .76494 .64147 L p .707 .577 .707 r
F P
0 g
s
.76494 .64147 m .76795 .58441 L .73617 .58319 L p .707 .577 .707 r
F P
0 g
s
.18144 .76653 m .18205 .74766 L .20606 .74436 L p .707 .577 .707 r
F P
0 g
s
.23399 .67412 m .23701 .61707 L .26879 .6183 L p .707 .577 .707 r
F P
0 g
s
.76795 .58441 m .76494 .64147 L .79424 .6412 L p .707 .577 .707 r
F P
0 g
s
.79424 .6412 m .79725 .58415 L .76795 .58441 L p .707 .577 .707 r
F P
0 g
s
.58871 .24776 m .59834 .74257 L .55957 .73603 L p .707 .577 .707 r
F P
0 g
s
.55957 .73603 m .54994 .24122 L .58871 .24776 L p .707 .577 .707 r
F P
0 g
s
.20606 .74436 m .20546 .76323 L .18144 .76653 L p .707 .577 .707 r
F P
0 g
s
.2018 .73648 m .20517 .69821 L .23431 .70012 L p .707 .577 .707 r
F P
0 g
s
.26879 .6183 m .26578 .67535 L .23399 .67412 L p .707 .577 .707 r
F P
0 g
s
.702 .63765 m .70502 .5806 L .67754 .5769 L p .707 .577 .707 r
F P
0 g
s
.70502 .5806 m .702 .63765 L .73316 .64024 L p .707 .577 .707 r
F P
0 g
s
.23431 .70012 m .23095 .73839 L .2018 .73648 L p .707 .577 .707 r
F P
0 g
s
.32586 .74956 m .32526 .76843 L .29779 .76445 L p .707 .577 .707 r
F P
0 g
s
.29779 .76445 m .2984 .74558 L .32586 .74956 L p .707 .577 .707 r
F P
0 g
s
.67754 .5769 m .67453 .63395 L .702 .63765 L p .707 .577 .707 r
F P
0 g
s
.42916 .74205 m .41954 .24724 L .461 .24095 L p .707 .577 .707 r
F P
0 g
s
.41954 .24724 m .42813 .68895 L p .39523 .75194 L .707 .577 .707 r
F P
0 g
s
.461 .24095 m .47063 .73576 L .42916 .74205 L p .707 .577 .707 r
F P
0 g
s
.42336 .62569 m .42 .66396 L .43917 .66521 L p .707 .577 .707 r
F P
0 g
s
.43917 .66521 m .44915 .66586 L p .44319 .65658 L .707 .577 .707 r
F P
0 g
s
.44319 .65658 m .42336 .62569 L .43917 .66521 L .707 .577 .707 r
F
.42813 .68895 m .42916 .74205 L .39941 .75072 L p F P
0 g
s
.39941 .75072 m .39523 .75194 L p .42813 .68895 L .707 .577 .707 r
F P
0 g
s
.29712 .7058 m .29375 .74407 L .26263 .741 L p .707 .577 .707 r
F P
0 g
s
.26263 .741 m .266 .70273 L .29712 .7058 L p .707 .577 .707 r
F P
0 g
s
.79725 .58415 m .79424 .6412 L .81819 .63948 L p .707 .577 .707 r
F P
0 g
s
.81819 .63948 m .8212 .58243 L .79725 .58415 L p .707 .577 .707 r
F P
0 g
s
.73133 .69816 m .73469 .65989 L .70357 .65682 L p .707 .577 .707 r
F P
0 g
s
.73469 .65989 m .73133 .69816 L .76301 .70077 L p .707 .577 .707 r
F P
0 g
s
.76301 .70077 m .76637 .6625 L .73469 .65989 L p .707 .577 .707 r
F P
0 g
s
.23095 .73839 m .23431 .70012 L .266 .70273 L p .707 .577 .707 r
F P
0 g
s
.70357 .65682 m .70021 .69509 L .73133 .69816 L p .707 .577 .707 r
F P
0 g
s
.266 .70273 m .26263 .741 L .23095 .73839 L p .707 .577 .707 r
F P
0 g
s
.76637 .6625 m .76301 .70077 L .79216 .70268 L p .707 .577 .707 r
F P
0 g
s
.79216 .70268 m .79552 .66441 L .76637 .6625 L p .707 .577 .707 r
F P
0 g
s
.20546 .76323 m .20606 .74436 L .23542 .74285 L p .707 .577 .707 r
F P
0 g
s
.67453 .63395 m .67754 .5769 L .65643 .57245 L p .707 .577 .707 r
F P
0 g
s
.70021 .69509 m .70357 .65682 L .67606 .65359 L p .707 .577 .707 r
F P
0 g
s
.23542 .74285 m .23481 .76172 L .20546 .76323 L p .707 .577 .707 r
F P
0 g
s
.54994 .24122 m .55957 .73603 L .51557 .73369 L p .707 .577 .707 r
F P
0 g
s
.51557 .73369 m .50594 .23888 L .54994 .24122 L p .707 .577 .707 r
F P
0 g
s
.67606 .65359 m .6727 .69186 L .70021 .69509 L p .707 .577 .707 r
F P
0 g
s
.2984 .74558 m .29779 .76445 L .26663 .76214 L p .707 .577 .707 r
F P
0 g
s
.26663 .76214 m .26723 .74327 L .2984 .74558 L p .707 .577 .707 r
F P
0 g
s
.65643 .57245 m .65342 .6295 L .67453 .63395 L p .707 .577 .707 r
F P
0 g
s
.47063 .73576 m .461 .24095 L .50594 .23888 L p .707 .577 .707 r
F P
0 g
s
.23481 .76172 m .23542 .74285 L .26723 .74327 L p .707 .577 .707 r
F P
0 g
s
.79552 .66441 m .79216 .70268 L .81591 .70369 L p .707 .577 .707 r
F P
0 g
s
.81591 .70369 m .81928 .66542 L .79552 .66441 L p .707 .577 .707 r
F P
0 g
s
.50594 .23888 m .51557 .73369 L .47063 .73576 L p .707 .577 .707 r
F P
0 g
s
.26723 .74327 m .26663 .76214 L .23481 .76172 L p .707 .577 .707 r
F P
0 g
s
.8212 .58243 m .81819 .63948 L .83444 .63647 L p .707 .577 .707 r
F P
0 g
s
.83444 .63647 m .83745 .57942 L .8212 .58243 L p .707 .577 .707 r
F P
0 g
s
.73355 .7575 m .73416 .73863 L .70299 .73632 L p .707 .577 .707 r
F P
0 g
s
.73416 .73863 m .73355 .7575 L .76537 .75792 L p .707 .577 .707 r
F P
0 g
s
.76537 .75792 m .76597 .73905 L .73416 .73863 L p .707 .577 .707 r
F P
0 g
s
.6727 .69186 m .67606 .65359 L .65485 .65053 L p .707 .577 .707 r
F P
0 g
s
.76597 .73905 m .76537 .75792 L .79472 .7564 L p .707 .577 .707 r
F P
0 g
s
.79472 .7564 m .79532 .73754 L .76597 .73905 L p .707 .577 .707 r
F P
0 g
s
.70299 .73632 m .70239 .75518 L .73355 .7575 L p .707 .577 .707 r
F P
0 g
s
.65485 .65053 m .65149 .6888 L .6727 .69186 L p .707 .577 .707 r
F P
0 g
s
.70239 .75518 m .70299 .73632 L .67553 .73234 L p .707 .577 .707 r
F P
0 g
s
.65342 .6295 m .65643 .57245 L .64375 .56768 L p .707 .577 .707 r
F P
0 g
s
.67553 .73234 m .67492 .7512 L .70239 .75518 L p .707 .577 .707 r
F P
0 g
s
.79532 .73754 m .79472 .7564 L .81874 .7531 L p .707 .577 .707 r
F P
0 g
s
.81874 .7531 m .81934 .73424 L .79532 .73754 L p .707 .577 .707 r
F P
0 g
s
.64375 .56768 m .64074 .62473 L .65342 .6295 L p .707 .577 .707 r
F P
0 g
s
.81928 .66542 m .81591 .70369 L .83195 .7037 L p .707 .577 .707 r
F P
0 g
s
.83195 .7037 m .83532 .66543 L .81928 .66542 L p .707 .577 .707 r
F P
0 g
s
.67492 .7512 m .67553 .73234 L .65445 .72708 L p .707 .577 .707 r
F P
0 g
s
.65149 .6888 m .65485 .65053 L .64202 .64793 L p .707 .577 .707 r
F P
0 g
s
.65445 .72708 m .65385 .74595 L .67492 .7512 L p .707 .577 .707 r
F P
0 g
s
.83745 .57942 m .83444 .63647 L .84141 .63245 L p .707 .577 .707 r
F P
0 g
s
.84141 .63245 m .84442 .5754 L .83745 .57942 L p .707 .577 .707 r
F P
0 g
s
.81934 .73424 m .81874 .7531 L .83506 .74834 L p .707 .577 .707 r
F P
0 g
s
.83506 .74834 m .83567 .72947 L .81934 .73424 L p .707 .577 .707 r
F P
0 g
s
.64074 .62473 m .64375 .56768 L .64075 .56306 L p .707 .577 .707 r
F P
0 g
s
.83532 .66543 m .83195 .7037 L .83871 .70271 L p .707 .577 .707 r
F P
0 g
s
.83871 .70271 m .84207 .66444 L .83532 .66543 L p .707 .577 .707 r
F P
0 g
s
.64075 .56306 m .63774 .62011 L .64074 .62473 L p .707 .577 .707 r
F P
0 g
s
.65385 .74595 m .65445 .72708 L .64183 .72106 L p .707 .577 .707 r
F P
0 g
s
.64183 .72106 m .64122 .73993 L .65385 .74595 L p .707 .577 .707 r
F P
0 g
s
.63866 .6862 m .64202 .64793 L .63883 .64605 L p .707 .577 .707 r
F P
0 g
s
.63883 .64605 m .63547 .68432 L .63866 .6862 L p .707 .577 .707 r
F P
0 g
s
.84442 .5754 m .84141 .63245 L .83841 .62784 L p .707 .577 .707 r
F P
0 g
s
.83841 .62784 m .84142 .57079 L .84442 .5754 L p .707 .577 .707 r
F P
0 g
s
.83567 .72947 m .83506 .74834 L .8421 .74258 L p .707 .577 .707 r
F P
0 g
s
.8421 .74258 m .84271 .72371 L .83567 .72947 L p .707 .577 .707 r
F P
0 g
s
.63774 .62011 m .64075 .56306 L .64772 .55905 L p .707 .577 .707 r
F P
0 g
s
.64122 .73993 m .64183 .72106 L .63889 .71487 L p .707 .577 .707 r
F P
0 g
s
.84207 .66444 m .83871 .70271 L .83551 .70083 L p .707 .577 .707 r
F P
0 g
s
.83551 .70083 m .83888 .66256 L .84207 .66444 L p .707 .577 .707 r
F P
0 g
s
.64772 .55905 m .64471 .6161 L .63774 .62011 L p .707 .577 .707 r
F P
0 g
s
.63889 .71487 m .63829 .73373 L .64122 .73993 L p .707 .577 .707 r
F P
0 g
s
.63547 .68432 m .63883 .64605 L .64558 .64506 L p .707 .577 .707 r
F P
0 g
s
.64558 .64506 m .64222 .68333 L .63547 .68432 L p .707 .577 .707 r
F P
0 g
s
.84142 .57079 m .83841 .62784 L .82573 .62307 L p .707 .577 .707 r
F P
0 g
s
.82573 .62307 m .82874 .56602 L .84142 .57079 L p .707 .577 .707 r
F P
0 g
s
.39015 .60343 m .39316 .54638 L .36201 .54379 L p .707 .577 .707 r
F P
0 g
s
.39316 .54638 m .39015 .60343 L .42193 .60465 L p .707 .577 .707 r
F P
0 g
s
.42193 .60465 m .42494 .5476 L .39316 .54638 L p .707 .577 .707 r
F P
0 g
s
.84271 .72371 m .8421 .74258 L .83917 .73639 L p .707 .577 .707 r
F P
0 g
s
.83917 .73639 m .83977 .71752 L .84271 .72371 L p .707 .577 .707 r
F P
0 g
s
.42494 .5476 m .42193 .60465 L .45123 .60439 L p .707 .577 .707 r
F P
0 g
s
.45123 .60439 m .45424 .54734 L .42494 .5476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64471 .6161 m .64772 .55905 L .66397 .55604 L p .707 .577 .707 r
F P
0 g
s
.35899 .60084 m .36201 .54379 L .33453 .54008 L p .707 .577 .707 r
F P
0 g
s
.36201 .54379 m .35899 .60084 L .39015 .60343 L p .707 .577 .707 r
F P
0 g
s
.63829 .73373 m .63889 .71487 L .64594 .70911 L p .707 .577 .707 r
F P
0 g
s
.66397 .55604 m .66096 .61309 L .64471 .6161 L p .707 .577 .707 r
F P
0 g
s
.83888 .66256 m .83551 .70083 L .82268 .69823 L p .707 .577 .707 r
F P
0 g
s
.82268 .69823 m .82605 .65996 L .83888 .66256 L p .707 .577 .707 r
F P
0 g
s
.33453 .54008 m .33152 .59713 L .35899 .60084 L p .707 .577 .707 r
F P
0 g
s
.64594 .70911 m .64533 .72797 L .63829 .73373 L p .707 .577 .707 r
F P
0 g
s
.45424 .54734 m .45123 .60439 L .47518 .60267 L p .707 .577 .707 r
F P
0 g
s
.47518 .60267 m .47819 .54561 L .45424 .54734 L p .707 .577 .707 r
F P
0 g
s
.38832 .66134 m .39168 .62307 L .36056 .62 L p .707 .577 .707 r
F P
0 g
s
.39168 .62307 m .38832 .66134 L .42 .66396 L p .707 .577 .707 r
F P
0 g
s
.42 .66396 m .42336 .62569 L .39168 .62307 L p .707 .577 .707 r
F P
0 g
s
.36056 .62 m .3572 .65827 L .38832 .66134 L p .707 .577 .707 r
F P
0 g
s
.44915 .66586 m .45251 .62759 L .42336 .62569 L p .707 .577 .707 r
F P
0 g
s
.33152 .59713 m .33453 .54008 L .31342 .53563 L p .707 .577 .707 r
F P
0 g
s
.82874 .56602 m .82573 .62307 L .80462 .61862 L p .707 .577 .707 r
F P
0 g
s
.80462 .61862 m .80763 .56157 L .82874 .56602 L p .707 .577 .707 r
F P
0 g
s
.64222 .68333 m .64558 .64506 L .66162 .64508 L p .707 .577 .707 r
F P
0 g
s
.3572 .65827 m .36056 .62 L .33305 .61678 L p .707 .577 .707 r
F P
0 g
s
.66162 .64508 m .65826 .68335 L .64222 .68333 L p .707 .577 .707 r
F P
0 g
s
.33305 .61678 m .32969 .65505 L .3572 .65827 L p .707 .577 .707 r
F P
0 g
s
.31342 .53563 m .31041 .59268 L .33152 .59713 L p .707 .577 .707 r
F P
0 g
s
.83977 .71752 m .83917 .73639 L .82655 .73037 L p .707 .577 .707 r
F P
0 g
s
.82655 .73037 m .82715 .7115 L .83977 .71752 L p .707 .577 .707 r
F P
0 g
s
.66096 .61309 m .66397 .55604 L .68792 .55431 L p .707 .577 .707 r
F P
0 g
s
.45251 .62759 m .44915 .66586 L .4729 .66687 L p .707 .577 .707 r
F P
0 g
s
.4729 .66687 m .47627 .6286 L .45251 .62759 L p .707 .577 .707 r
F P
0 g
s
.47819 .54561 m .47518 .60267 L .49143 .59965 L p .707 .577 .707 r
F P
0 g
s
.49143 .59965 m .49444 .5426 L .47819 .54561 L p .707 .577 .707 r
F P
0 g
s
.39054 .72068 m .39115 .70182 L .35998 .6995 L p .707 .577 .707 r
F P
0 g
s
.39115 .70182 m .39054 .72068 L .42236 .7211 L p .707 .577 .707 r
F P
0 g
s
.42236 .7211 m .42296 .70224 L .39115 .70182 L p .707 .577 .707 r
F P
0 g
s
.32969 .65505 m .33305 .61678 L .31184 .61372 L p .707 .577 .707 r
F P
0 g
s
.68792 .55431 m .68491 .61136 L .66096 .61309 L p .707 .577 .707 r
F P
0 g
s
.42296 .70224 m .42236 .7211 L .45171 .71959 L p .707 .577 .707 r
F P
0 g
s
.45171 .71959 m .45232 .70072 L .42296 .70224 L p .707 .577 .707 r
F P
0 g
s
.35998 .6995 m .35938 .71837 L .39054 .72068 L p .707 .577 .707 r
F P
0 g
s
.31184 .61372 m .30848 .65199 L .32969 .65505 L p .707 .577 .707 r
F P
0 g
s
.64533 .72797 m .64594 .70911 L .66226 .70434 L p .707 .577 .707 r
F P
0 g
s
.82605 .65996 m .82268 .69823 L .80148 .69517 L p .707 .577 .707 r
F P
0 g
s
.80148 .69517 m .80484 .6569 L .82605 .65996 L p .707 .577 .707 r
F P
0 g
s
.35938 .71837 m .35998 .6995 L .33252 .69552 L p .707 .577 .707 r
F P
0 g
s
.31041 .59268 m .31342 .53563 L .30074 .53086 L p .707 .577 .707 r
F P
0 g
s
.66226 .70434 m .66166 .72321 L .64533 .72797 L p .707 .577 .707 r
F P
0 g
s
.80763 .56157 m .80462 .61862 L .77714 .61492 L p .707 .577 .707 r
F P
0 g
s
.77714 .61492 m .78016 .55787 L .80763 .56157 L p .707 .577 .707 r
F P
0 g
s
.33252 .69552 m .33191 .71439 L .35938 .71837 L p .707 .577 .707 r
F P
0 g
s
.65826 .68335 m .66162 .64508 L .68538 .64609 L p .707 .577 .707 r
F P
0 g
s
.68538 .64609 m .68202 .68436 L .65826 .68335 L p .707 .577 .707 r
F P
0 g
s
.45232 .70072 m .45171 .71959 L .47573 .71629 L p .707 .577 .707 r
F P
0 g
s
.47573 .71629 m .47633 .69742 L .45232 .70072 L p .707 .577 .707 r
F P
0 g
s
.68491 .61136 m .68792 .55431 L .71722 .55405 L p .707 .577 .707 r
F P
0 g
s
.30074 .53086 m .29773 .58791 L .31041 .59268 L p .707 .577 .707 r
F P
0 g
s
.47627 .6286 m .4729 .66687 L .48894 .66688 L p .707 .577 .707 r
F P
0 g
s
.48894 .66688 m .49231 .62861 L .47627 .6286 L p .707 .577 .707 r
F P
0 g
s
.82715 .7115 m .82655 .73037 L .80547 .72511 L p .707 .577 .707 r
F P
0 g
s
.80547 .72511 m .80608 .70624 L .82715 .7115 L p .707 .577 .707 r
F P
0 g
s
.33191 .71439 m .33252 .69552 L .31144 .69027 L p .707 .577 .707 r
F P
0 g
s
.71722 .55405 m .71421 .6111 L .68491 .61136 L p .707 .577 .707 r
F P
0 g
s
.78016 .55787 m .77714 .61492 L .74599 .61233 L p .707 .577 .707 r
F P
0 g
s
.74599 .61233 m .749 .55528 L .78016 .55787 L p .707 .577 .707 r
F P
0 g
s
.30848 .65199 m .31184 .61372 L .29901 .61112 L p .707 .577 .707 r
F P
0 g
s
.31144 .69027 m .31084 .70913 L .33191 .71439 L p .707 .577 .707 r
F P
0 g
s
.49444 .5426 m .49143 .59965 L .4984 .59564 L p .707 .577 .707 r
F P
0 g
s
.4984 .59564 m .50141 .53859 L .49444 .5426 L p .707 .577 .707 r
F P
0 g
s
.29901 .61112 m .29565 .64939 L .30848 .65199 L p .707 .577 .707 r
F P
0 g
s
.80484 .6569 m .80148 .69517 L .77397 .69194 L p .707 .577 .707 r
F P
0 g
s
.77397 .69194 m .77733 .65368 L .80484 .6569 L p .707 .577 .707 r
F P
0 g
s
.71421 .6111 m .71722 .55405 L .749 .55528 L p .707 .577 .707 r
F P
0 g
s
.66166 .72321 m .66226 .70434 L .68628 .70104 L p .707 .577 .707 r
F P
0 g
s
.749 .55528 m .74599 .61233 L .71421 .6111 L p .707 .577 .707 r
F P
0 g
s
.68202 .68436 m .68538 .64609 L .71453 .64799 L p .707 .577 .707 r
F P
0 g
s
.68628 .70104 m .68567 .71991 L .66166 .72321 L p .707 .577 .707 r
F P
0 g
s
.47633 .69742 m .47573 .71629 L .49205 .71152 L p .707 .577 .707 r
F P
0 g
s
.49205 .71152 m .49266 .69266 L .47633 .69742 L p .707 .577 .707 r
F P
0 g
s
.71453 .64799 m .71116 .68626 L .68202 .68436 L p .707 .577 .707 r
F P
0 g
s
.29773 .58791 m .30074 .53086 L .29774 .52625 L p .707 .577 .707 r
F P
0 g
s
.77733 .65368 m .77397 .69194 L .74285 .68888 L p .707 .577 .707 r
F P
0 g
s
.74285 .68888 m .74621 .65061 L .77733 .65368 L p .707 .577 .707 r
F P
0 g
s
.49231 .62861 m .48894 .66688 L .4957 .6659 L p .707 .577 .707 r
F P
0 g
s
.4957 .6659 m .49906 .62763 L .49231 .62861 L p .707 .577 .707 r
F P
0 g
s
.29774 .52625 m .29473 .5833 L .29773 .58791 L p .707 .577 .707 r
F P
0 g
s
.80608 .70624 m .80547 .72511 L .77801 .72113 L p .707 .577 .707 r
F P
0 g
s
.77801 .72113 m .77861 .70226 L .80608 .70624 L p .707 .577 .707 r
F P
0 g
s
.31084 .70913 m .31144 .69027 L .29882 .68425 L p .707 .577 .707 r
F P
0 g
s
.71116 .68626 m .71453 .64799 L .74621 .65061 L p .707 .577 .707 r
F P
0 g
s
.74621 .65061 m .74285 .68888 L .71116 .68626 L p .707 .577 .707 r
F P
0 g
s
.29882 .68425 m .29821 .70311 L .31084 .70913 L p .707 .577 .707 r
F P
0 g
s
.68567 .71991 m .68628 .70104 L .71563 .69953 L p .707 .577 .707 r
F P
0 g
s
.29565 .64939 m .29901 .61112 L .29582 .60923 L p .707 .577 .707 r
F P
0 g
s
.71563 .69953 m .71502 .7184 L .68567 .71991 L p .707 .577 .707 r
F P
0 g
s
.29582 .60923 m .29246 .6475 L .29565 .64939 L p .707 .577 .707 r
F P
0 g
s
.50141 .53859 m .4984 .59564 L .4954 .59102 L p .707 .577 .707 r
F P
0 g
s
.4954 .59102 m .49841 .53397 L .50141 .53859 L p .707 .577 .707 r
F P
0 g
s
.77861 .70226 m .77801 .72113 L .74684 .71882 L p .707 .577 .707 r
F P
0 g
s
.74684 .71882 m .74745 .69995 L .77861 .70226 L p .707 .577 .707 r
F P
0 g
s
.49266 .69266 m .49205 .71152 L .49909 .70576 L p .707 .577 .707 r
F P
0 g
s
.49909 .70576 m .4997 .6869 L .49266 .69266 L p .707 .577 .707 r
F P
0 g
s
.71502 .7184 m .71563 .69953 L .74745 .69995 L p .707 .577 .707 r
F P
0 g
s
.74745 .69995 m .74684 .71882 L .71502 .7184 L p .707 .577 .707 r
F P
0 g
s
.29473 .5833 m .29774 .52625 L .30471 .52224 L p .707 .577 .707 r
F P
0 g
s
.29821 .70311 m .29882 .68425 L .29588 .67805 L p .707 .577 .707 r
F P
0 g
s
.49906 .62763 m .4957 .6659 L .4925 .66401 L p .707 .577 .707 r
F P
0 g
s
.4925 .66401 m .49587 .62575 L .49906 .62763 L p .707 .577 .707 r
F P
0 g
s
.30471 .52224 m .3017 .57929 L .29473 .5833 L p .707 .577 .707 r
F P
0 g
s
.29588 .67805 m .29528 .69692 L .29821 .70311 L p .707 .577 .707 r
F P
0 g
s
.29246 .6475 m .29582 .60923 L .30257 .60825 L p .707 .577 .707 r
F P
0 g
s
.30257 .60825 m .29921 .64652 L .29246 .6475 L p .707 .577 .707 r
F P
0 g
s
.49841 .53397 m .4954 .59102 L .48272 .58626 L p .707 .577 .707 r
F P
0 g
s
.48272 .58626 m .48573 .52921 L .49841 .53397 L p .707 .577 .707 r
F P
0 g
s
.4997 .6869 m .49909 .70576 L .49616 .69957 L p .707 .577 .707 r
F P
0 g
s
.49616 .69957 m .49676 .6807 L .4997 .6869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3017 .57929 m .30471 .52224 L .32096 .51922 L p .707 .577 .707 r
F P
0 g
s
.29528 .69692 m .29588 .67805 L .30292 .67229 L p .707 .577 .707 r
F P
0 g
s
.32096 .51922 m .31795 .57627 L .3017 .57929 L p .707 .577 .707 r
F P
0 g
s
.49587 .62575 m .4925 .66401 L .47967 .66141 L p .707 .577 .707 r
F P
0 g
s
.47967 .66141 m .48304 .62314 L .49587 .62575 L p .707 .577 .707 r
F P
0 g
s
.30292 .67229 m .30232 .69116 L .29528 .69692 L p .707 .577 .707 r
F P
0 g
s
.48573 .52921 m .48272 .58626 L .46161 .5818 L p .707 .577 .707 r
F P
0 g
s
.46161 .5818 m .46462 .52475 L .48573 .52921 L p .707 .577 .707 r
F P
0 g
s
.29921 .64652 m .30257 .60825 L .31861 .60826 L p .707 .577 .707 r
F P
0 g
s
.31861 .60826 m .31525 .64653 L .29921 .64652 L p .707 .577 .707 r
F P
0 g
s
.49676 .6807 m .49616 .69957 L .48354 .69355 L p .707 .577 .707 r
F P
0 g
s
.48354 .69355 m .48414 .67468 L .49676 .6807 L p .707 .577 .707 r
F P
0 g
s
.31795 .57627 m .32096 .51922 L .34491 .5175 L p .707 .577 .707 r
F P
0 g
s
.34491 .5175 m .3419 .57455 L .31795 .57627 L p .707 .577 .707 r
F P
0 g
s
.30232 .69116 m .30292 .67229 L .31925 .66753 L p .707 .577 .707 r
F P
0 g
s
.48304 .62314 m .47967 .66141 L .45847 .65835 L p .707 .577 .707 r
F P
0 g
s
.45847 .65835 m .46183 .62008 L .48304 .62314 L p .707 .577 .707 r
F P
0 g
s
.31925 .66753 m .31865 .6864 L .30232 .69116 L p .707 .577 .707 r
F P
0 g
s
.46462 .52475 m .46161 .5818 L .43413 .5781 L p .707 .577 .707 r
F P
0 g
s
.43413 .5781 m .43715 .52105 L .46462 .52475 L p .707 .577 .707 r
F P
0 g
s
.31525 .64653 m .31861 .60826 L .34237 .60927 L p .707 .577 .707 r
F P
0 g
s
.34237 .60927 m .33901 .64754 L .31525 .64653 L p .707 .577 .707 r
F P
0 g
s
.3419 .57455 m .34491 .5175 L .37421 .51724 L p .707 .577 .707 r
F P
0 g
s
.48414 .67468 m .48354 .69355 L .46246 .68829 L p .707 .577 .707 r
F P
0 g
s
.46246 .68829 m .46307 .66943 L .48414 .67468 L p .707 .577 .707 r
F P
0 g
s
.37421 .51724 m .3712 .57429 L .3419 .57455 L p .707 .577 .707 r
F P
0 g
s
.43715 .52105 m .43413 .5781 L .40298 .57551 L p .707 .577 .707 r
F P
0 g
s
.40298 .57551 m .40599 .51846 L .43715 .52105 L p .707 .577 .707 r
F P
0 g
s
.46183 .62008 m .45847 .65835 L .43096 .65513 L p .707 .577 .707 r
F P
0 g
s
.43096 .65513 m .43432 .61686 L .46183 .62008 L p .707 .577 .707 r
F P
0 g
s
.3712 .57429 m .37421 .51724 L .40599 .51846 L p .707 .577 .707 r
F P
0 g
s
.31865 .6864 m .31925 .66753 L .34327 .66423 L p .707 .577 .707 r
F P
0 g
s
.40599 .51846 m .40298 .57551 L .3712 .57429 L p .707 .577 .707 r
F P
0 g
s
.33901 .64754 m .34237 .60927 L .37151 .61118 L p .707 .577 .707 r
F P
0 g
s
.34327 .66423 m .34266 .68309 L .31865 .6864 L p .707 .577 .707 r
F P
0 g
s
.37151 .61118 m .36815 .64944 L .33901 .64754 L p .707 .577 .707 r
F P
0 g
s
.43432 .61686 m .43096 .65513 L .39984 .65206 L p .707 .577 .707 r
F P
0 g
s
.39984 .65206 m .4032 .61379 L .43432 .61686 L p .707 .577 .707 r
F P
0 g
s
.46307 .66943 m .46246 .68829 L .435 .68431 L p .707 .577 .707 r
F P
0 g
s
.435 .68431 m .4356 .66545 L .46307 .66943 L p .707 .577 .707 r
F P
0 g
s
.36815 .64944 m .37151 .61118 L .4032 .61379 L p .707 .577 .707 r
F P
0 g
s
.4032 .61379 m .39984 .65206 L .36815 .64944 L p .707 .577 .707 r
F P
0 g
s
.34266 .68309 m .34327 .66423 L .37262 .66271 L p .707 .577 .707 r
F P
0 g
s
.37262 .66271 m .37201 .68158 L .34266 .68309 L p .707 .577 .707 r
F P
0 g
s
.4356 .66545 m .435 .68431 L .40383 .682 L p .707 .577 .707 r
F P
0 g
s
.40383 .682 m .40444 .66313 L .4356 .66545 L p .707 .577 .707 r
F P
0 g
s
.37201 .68158 m .37262 .66271 L .40444 .66313 L p .707 .577 .707 r
F P
0 g
s
.40444 .66313 m .40383 .682 L .37201 .68158 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooah007io
o`00Ngoo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00N7oo001fOol50008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001dOol007=oo`<00003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001bOol006moo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001_Ool006eoo`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8006eoo`00Jgoo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00Jgoo001YOol20002FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001YOol006Moo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Ioo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP00009JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00FGoo80002eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001FOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolI0014Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`02Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool005=oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0
009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Ioo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005]oo`L000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2000/Ool0069oo`P000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool006Eoo`05001JEUYF001J
EP0P0007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`P000Moo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`<000=JEP04001JEUYFFUH@00000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP04001JEUYF
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool003QooaT000=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPP000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8002eoo`00;goo2@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF001JEP02FUH2000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol00goo1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`0:Ool90004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF2@00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`0COolI000hOol002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0000L000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEQ8005Ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH9001=Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH00UYF4000?Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000K0005FUH00`00FUIJEP03FUH8
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF5P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPL000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00@005YFFUIJEQ0000AJ
EP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF00000UYF1`001eYF00<005YFFUH01EYF40000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH90002FUH00`00FUIJEP02FUH50004FUH80004
FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00004@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0002FUH60002FUH400000eYF00000002
FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01`000eYF00<005YFFUH015YF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;goo100015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00D005YFFUH005YF00H000EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP09FUH300000eYF001JEP02FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJ
EP070002FUH00`00FUH00002FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP03
0002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJ
EUYF0P00;Woo000]OolA00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@001EYF00<005YFFUH01UYF00<005YFFUH025YF1@000UYF0`0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00@005YFFUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEQ<000=JEP05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0003FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00P000=JEP03
001JEUYF009JEQ@000=JEP04001JEUYFFUH4000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00000010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd002moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP02FUH700000eYF
001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJ
EP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH01000FUIJEUYF
2@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH:0002FUH20007Ool50004Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEP00FUH005YF00<000EJEP04001JEUYFFUH40007Ool5000<Ool60003
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P0000=JEP00FUH00`000UYF00<0
05YFFUH00UYF0`0027oo0`004goo10000eYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH0
0UYF1@000UYF00<005YF00007Goo1`0000=JEP000000;Goo000/OolJ0004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF2P0035YF2@0025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF
FUH015YF00@005YFFUIJEPP0019oo`P0009JEP03001JEUYF009JEP<002eoo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000c
OolT0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
1@000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<0
05YFFUH00UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0003FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF
00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002moo`<00003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH20002
FUH00`00FUIJEP04FUH400000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH020000UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF009JEP03
001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<00005Ool005YFFUH00002FUH20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8000=ooaT003Qoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P000UYF0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00@005YFFUIJEP8005Aoo`00;Goo0P000eYF3@004Goo200015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YF
FUH015YF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8002Ioo`H000AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03
001JEUYF009JEP8005Aoo`00;7oo00<005YF00001@0057oo0`004goo0`0000=JEP00FUH00UYF0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000E7oo000/Ool20003FUH00`00FUIJEP07000<Ool5000EOol30002FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eo
o`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT000=oo`D0015oo`D0009JEP<00003FUH0
05YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF6@00
0eYF00T005YFFUIJEP00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1`000eYF00@005YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH20003FUH:0002FUH2001EOol0031oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
00000goo00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUH0000200000eYF
00000002001EOol003Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF008000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000MJEP03001JEUYF009JEPD005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEPH000Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP05FUH00`00FUIJEP04FUH01000FUH00000EGoo000mOolP000>Ool30007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP080003FUH00`00FUIJEP04FUH01000FUIJEP00EGoo001]Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH30008Ool50004FUH01000
FUIJEUYF0P00E7oo001_Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH3000?Ool300000eYF001JEP02FUH2001DOol0075oo`<00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D001Eo
o`8000=JEP8005Aoo`00M7oo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
1@0000=oo`0000000`004Goo1`0000=JEP000000E7oo001hOol60002FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH01000FUIJEUYF8P000UYF00<005YFFUH00UYF0`00E7oo001nOol90006FUH00`00FUIJ
EP04FUH90003FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUH0001DOol008Moo`d000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00U7oo0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00
EWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
1P00FGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001OOol00:Eooa8006Ioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59702 .75788 m .59401 .70487 L .56285 .70364 L p .707 .577 .707 r
F P
0 g
s
.59401 .70487 m .59702 .75788 L .6288 .75518 L p .707 .577 .707 r
F P
0 g
s
.6288 .75518 m .62579 .70217 L .59401 .70487 L p .707 .577 .707 r
F P
0 g
s
.62579 .70217 m .6288 .75518 L .6581 .74879 L p .707 .577 .707 r
F P
0 g
s
.6581 .74879 m .65509 .69578 L .62579 .70217 L p .707 .577 .707 r
F P
0 g
s
.56586 .75665 m .56285 .70364 L .53538 .69858 L p .707 .577 .707 r
F P
0 g
s
.56285 .70364 m .56586 .75665 L .59702 .75788 L p .707 .577 .707 r
F P
0 g
s
.65509 .69578 m .6581 .74879 L .68205 .73936 L p .707 .577 .707 r
F P
0 g
s
.68205 .73936 m .67903 .68635 L .65509 .69578 L p .707 .577 .707 r
F P
0 g
s
.53839 .75159 m .53538 .69858 L .51427 .6902 L p .707 .577 .707 r
F P
0 g
s
.53538 .69858 m .53839 .75159 L .56586 .75665 L p .707 .577 .707 r
F P
0 g
s
.67903 .68635 m .68205 .73936 L .6983 .72779 L p .707 .577 .707 r
F P
0 g
s
.6983 .72779 m .69529 .67478 L .67903 .68635 L p .707 .577 .707 r
F P
0 g
s
.60016 .83021 m .5968 .79646 L .56568 .79565 L p .707 .577 .707 r
F P
0 g
s
.5968 .79646 m .60016 .83021 L .63184 .82625 L p .707 .577 .707 r
F P
0 g
s
.63184 .82625 m .62848 .79249 L .5968 .79646 L p .707 .577 .707 r
F P
0 g
s
.62848 .79249 m .63184 .82625 L .66099 .8179 L p .707 .577 .707 r
F P
0 g
s
.66099 .8179 m .65763 .78414 L .62848 .79249 L p .707 .577 .707 r
F P
0 g
s
.56904 .82941 m .56568 .79565 L .53817 .79016 L p .707 .577 .707 r
F P
0 g
s
.56568 .79565 m .56904 .82941 L .60016 .83021 L p .707 .577 .707 r
F P
0 g
s
.59617 .86551 m .59556 .84746 L .5644 .84596 L p .707 .577 .707 r
F P
0 g
s
.59556 .84746 m .59617 .86551 L .62798 .86356 L p .707 .577 .707 r
F P
0 g
s
.62798 .86356 m .62738 .84551 L .59556 .84746 L p .707 .577 .707 r
F P
0 g
s
.65763 .78414 m .66099 .8179 L .68475 .80599 L p .707 .577 .707 r
F P
0 g
s
.68475 .80599 m .68138 .77223 L .65763 .78414 L p .707 .577 .707 r
F P
0 g
s
.51728 .74321 m .51427 .6902 L .50159 .67931 L p .707 .577 .707 r
F P
0 g
s
.51427 .6902 m .51728 .74321 L .53839 .75159 L p .707 .577 .707 r
F P
0 g
s
.62738 .84551 m .62798 .86356 L .65733 .85836 L p .707 .577 .707 r
F P
0 g
s
.65733 .85836 m .65673 .84031 L .62738 .84551 L p .707 .577 .707 r
F P
0 g
s
.5644 .84596 m .565 .86401 L .59617 .86551 L p .707 .577 .707 r
F P
0 g
s
.565 .86401 m .5644 .84596 L .53693 .84116 L p .707 .577 .707 r
F P
0 g
s
.54153 .82392 m .53817 .79016 L .51696 .78052 L p .707 .577 .707 r
F P
0 g
s
.53817 .79016 m .54153 .82392 L .56904 .82941 L p .707 .577 .707 r
F P
0 g
s
.69529 .67478 m .6983 .72779 L .70527 .71523 L p .707 .577 .707 r
F P
0 g
s
.70527 .71523 m .70225 .66222 L .69529 .67478 L p .707 .577 .707 r
F P
0 g
s
.53693 .84116 m .53754 .85922 L .565 .86401 L p .707 .577 .707 r
F P
0 g
s
.65673 .84031 m .65733 .85836 L .68135 .85041 L p .707 .577 .707 r
F P
0 g
s
.68135 .85041 m .68074 .83236 L .65673 .84031 L p .707 .577 .707 r
F P
0 g
s
.68138 .77223 m .68475 .80599 L .70079 .79169 L p .707 .577 .707 r
F P
0 g
s
.70079 .79169 m .69742 .75793 L .68138 .77223 L p .707 .577 .707 r
F P
0 g
s
.53754 .85922 m .53693 .84116 L .51586 .83354 L p .707 .577 .707 r
F P
0 g
s
.50159 .67931 m .5046 .73232 L .51728 .74321 L p .707 .577 .707 r
F P
0 g
s
.5046 .73232 m .50159 .67931 L .49859 .66698 L p .707 .577 .707 r
F P
0 g
s
.51586 .83354 m .51646 .85159 L .53754 .85922 L p .707 .577 .707 r
F P
0 g
s
.51696 .78052 m .52032 .81428 L .54153 .82392 L p .707 .577 .707 r
F P
0 g
s
.52032 .81428 m .51696 .78052 L .50413 .76767 L p .707 .577 .707 r
F P
0 g
s
.68074 .83236 m .68135 .85041 L .69768 .8405 L p .707 .577 .707 r
F P
0 g
s
.69768 .8405 m .69707 .82244 L .68074 .83236 L p .707 .577 .707 r
F P
0 g
s
.70225 .66222 m .70527 .71523 L .70226 .7029 L p .707 .577 .707 r
F P
0 g
s
.70226 .7029 m .69925 .64989 L .70225 .66222 L p .707 .577 .707 r
F P
0 g
s
.69742 .75793 m .70079 .79169 L .70754 .77638 L p .707 .577 .707 r
F P
0 g
s
.70754 .77638 m .70418 .74263 L .69742 .75793 L p .707 .577 .707 r
F P
0 g
s
.51646 .85159 m .51586 .83354 L .50323 .82383 L p .707 .577 .707 r
F P
0 g
s
.49859 .66698 m .5016 .71999 L .5046 .73232 L p .707 .577 .707 r
F P
0 g
s
.50413 .76767 m .50749 .80143 L .52032 .81428 L p .707 .577 .707 r
F P
0 g
s
.50323 .82383 m .50384 .84189 L .51646 .85159 L p .707 .577 .707 r
F P
0 g
s
.5016 .71999 m .49859 .66698 L .50556 .65442 L p .707 .577 .707 r
F P
0 g
s
.69707 .82244 m .69768 .8405 L .70472 .82959 L p .707 .577 .707 r
F P
0 g
s
.70472 .82959 m .70411 .81153 L .69707 .82244 L p .707 .577 .707 r
F P
0 g
s
.50749 .80143 m .50413 .76767 L .50094 .75287 L p .707 .577 .707 r
F P
0 g
s
.48443 .81898 m .49406 .31125 L .45005 .30823 L p .707 .577 .707 r
F P
0 g
s
.50384 .84189 m .50323 .82383 L .5003 .81299 L p .707 .577 .707 r
F P
0 g
s
.50094 .75287 m .5043 .78662 L .50749 .80143 L p .707 .577 .707 r
F P
0 g
s
.5003 .81299 m .5009 .83105 L .50384 .84189 L p .707 .577 .707 r
F P
0 g
s
.50556 .65442 m .50857 .70743 L .5016 .71999 L p .707 .577 .707 r
F P
0 g
s
.50857 .70743 m .50556 .65442 L .52181 .64285 L p .707 .577 .707 r
F P
0 g
s
.5043 .78662 m .50094 .75287 L .50769 .73756 L p .707 .577 .707 r
F P
0 g
s
.5009 .83105 m .5003 .81299 L .50734 .80208 L p .707 .577 .707 r
F P
0 g
s
.50769 .73756 m .51105 .77132 L .5043 .78662 L p .707 .577 .707 r
F P
0 g
s
.52181 .64285 m .52482 .69586 L .50857 .70743 L p .707 .577 .707 r
F P
0 g
s
.50734 .80208 m .50795 .82013 L .5009 .83105 L p .707 .577 .707 r
F P
0 g
s
.51105 .77132 m .50769 .73756 L .52373 .72326 L p .707 .577 .707 r
F P
0 g
s
.50795 .82013 m .50734 .80208 L .52367 .79216 L p .707 .577 .707 r
F P
0 g
s
.52373 .72326 m .52709 .75702 L .51105 .77132 L p .707 .577 .707 r
F P
0 g
s
.52367 .79216 m .52427 .81022 L .50795 .82013 L p .707 .577 .707 r
F P
0 g
s
.52427 .81022 m .52367 .79216 L .54768 .78422 L p .707 .577 .707 r
F P
0 g
s
.54768 .78422 m .54829 .80227 L .52427 .81022 L p .707 .577 .707 r
F P
0 g
s
.49406 .31125 m .48443 .81898 L .52937 .81887 L p .707 .577 .707 r
F P
0 g
s
.52482 .69586 m .52181 .64285 L .54576 .63342 L p .707 .577 .707 r
F P
0 g
s
.54576 .63342 m .54877 .68643 L .52482 .69586 L p .707 .577 .707 r
F P
0 g
s
.52709 .75702 m .52373 .72326 L .54749 .71135 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .55085 .74511 L .52709 .75702 L p .707 .577 .707 r
F P
0 g
s
.52937 .81887 m .53899 .31115 L .49406 .31125 L p .707 .577 .707 r
F P
0 g
s
.70418 .74263 m .70754 .77638 L .70435 .76158 L p .707 .577 .707 r
F P
0 g
s
.70435 .76158 m .70098 .72782 L .70418 .74263 L p .707 .577 .707 r
F P
0 g
s
.69925 .64989 m .70226 .7029 L .68959 .69201 L p .707 .577 .707 r
F P
0 g
s
.68959 .69201 m .68658 .639 L .69925 .64989 L p .707 .577 .707 r
F P
0 g
s
.54877 .68643 m .54576 .63342 L .57506 .62703 L p .707 .577 .707 r
F P
0 g
s
.57506 .62703 m .57807 .68004 L .54877 .68643 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .57663 .703 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.55085 .74511 m .54846 .72107 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.54846 .72107 m .54749 .71135 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.57807 .68004 m .57506 .62703 L .60684 .62433 L p .707 .577 .707 r
F P
0 g
s
.60684 .62433 m .60985 .67734 L .57807 .68004 L p .707 .577 .707 r
F P
0 g
s
.58 .73676 m .57663 .703 L .60832 .69904 L p .707 .577 .707 r
F P
0 g
s
.57663 .703 m .58 .73676 L .55085 .74511 L p .707 .577 .707 r
F P
0 g
s
.60832 .69904 m .61168 .73279 L .58 .73676 L p .707 .577 .707 r
F P
0 g
s
.57764 .79707 m .57703 .77901 L .60885 .77706 L p .707 .577 .707 r
F P
0 g
s
.60885 .77706 m .60946 .79512 L .57764 .79707 L p .707 .577 .707 r
F P
0 g
s
.58046 .30791 m .57187 .76116 L p .60477 .8096 L .707 .577 .707 r
F P
0 g
s
.54829 .80227 m .54768 .78422 L .57703 .77901 L p .707 .577 .707 r
F P
0 g
s
.57703 .77901 m .57764 .79707 L .54829 .80227 L p .707 .577 .707 r
F P
0 g
s
.57187 .76116 m .57083 .81564 L .60059 .81035 L p .707 .577 .707 r
F P
0 g
s
.60059 .81035 m .60477 .8096 L p .57187 .76116 L .707 .577 .707 r
F P
0 g
s
.53899 .31115 m .52937 .81887 L .57083 .81564 L p .707 .577 .707 r
F P
0 g
s
.57083 .81564 m .58046 .30791 L .53899 .31115 L p .707 .577 .707 r
F P
0 g
s
.44043 .81596 m .45005 .30823 L .41129 .30237 L p .707 .577 .707 r
F P
0 g
s
.45005 .30823 m .44043 .81596 L .48443 .81898 L p .707 .577 .707 r
F P
0 g
s
.70411 .81153 m .70472 .82959 L .70178 .81875 L p .707 .577 .707 r
F P
0 g
s
.70178 .81875 m .70118 .80069 L .70411 .81153 L p .707 .577 .707 r
F P
0 g
s
.25401 .72107 m .251 .66806 L .21984 .66682 L p .707 .577 .707 r
F P
0 g
s
.251 .66806 m .25401 .72107 L .28579 .71836 L p .707 .577 .707 r
F P
0 g
s
.28579 .71836 m .28278 .66535 L .251 .66806 L p .707 .577 .707 r
F P
0 g
s
.60985 .67734 m .60684 .62433 L .63799 .62556 L p .707 .577 .707 r
F P
0 g
s
.60477 .8096 m .6144 .30188 L .58046 .30791 L p .707 .577 .707 r
F P
0 g
s
.28278 .66535 m .28579 .71836 L .31509 .71198 L p .707 .577 .707 r
F P
0 g
s
.31509 .71198 m .31208 .65897 L .28278 .66535 L p .707 .577 .707 r
F P
0 g
s
.22285 .71983 m .21984 .66682 L .19237 .66176 L p .707 .577 .707 r
F P
0 g
s
.21984 .66682 m .22285 .71983 L .25401 .72107 L p .707 .577 .707 r
F P
0 g
s
.70098 .72782 m .70435 .76158 L .69152 .74873 L p .707 .577 .707 r
F P
0 g
s
.69152 .74873 m .68816 .71497 L .70098 .72782 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68658 .639 m .68959 .69201 L .66848 .68363 L p .707 .577 .707 r
F P
0 g
s
.66848 .68363 m .66547 .63062 L .68658 .639 L p .707 .577 .707 r
F P
0 g
s
.40166 .8101 m .41129 .30237 L .38155 .29425 L p .707 .577 .707 r
F P
0 g
s
.41129 .30237 m .40166 .8101 L .44043 .81596 L p .707 .577 .707 r
F P
0 g
s
.31208 .65897 m .31509 .71198 L .33904 .70254 L p .707 .577 .707 r
F P
0 g
s
.33904 .70254 m .33603 .64953 L .31208 .65897 L p .707 .577 .707 r
F P
0 g
s
.19538 .71477 m .19237 .66176 L .17126 .65338 L p .707 .577 .707 r
F P
0 g
s
.19237 .66176 m .19538 .71477 L .22285 .71983 L p .707 .577 .707 r
F P
0 g
s
.63799 .62556 m .641 .67857 L .60985 .67734 L p .707 .577 .707 r
F P
0 g
s
.63944 .69984 m .6428 .7336 L .61168 .73279 L p .707 .577 .707 r
F P
0 g
s
.61168 .73279 m .60832 .69904 L .63944 .69984 L p .707 .577 .707 r
F P
0 g
s
.64002 .77856 m .64062 .79662 L .60946 .79512 L p .707 .577 .707 r
F P
0 g
s
.60946 .79512 m .60885 .77706 L .64002 .77856 L p .707 .577 .707 r
F P
0 g
s
.6144 .30188 m .60477 .8096 L .62786 .80135 L p .707 .577 .707 r
F P
0 g
s
.62786 .80135 m .63749 .29363 L .6144 .30188 L p .707 .577 .707 r
F P
0 g
s
.70118 .80069 m .70178 .81875 L .68916 .80904 L p .707 .577 .707 r
F P
0 g
s
.68916 .80904 m .68856 .79098 L .70118 .80069 L p .707 .577 .707 r
F P
0 g
s
.33603 .64953 m .33904 .70254 L .35529 .69098 L p .707 .577 .707 r
F P
0 g
s
.35529 .69098 m .35228 .63797 L .33603 .64953 L p .707 .577 .707 r
F P
0 g
s
.66547 .63062 m .66848 .68363 L .641 .67857 L p .707 .577 .707 r
F P
0 g
s
.641 .67857 m .63799 .62556 L .66547 .63062 L p .707 .577 .707 r
F P
0 g
s
.25715 .7934 m .25379 .75964 L .22267 .75884 L p .707 .577 .707 r
F P
0 g
s
.25379 .75964 m .25715 .7934 L .28884 .78943 L p .707 .577 .707 r
F P
0 g
s
.28884 .78943 m .28547 .75567 L .25379 .75964 L p .707 .577 .707 r
F P
0 g
s
.28547 .75567 m .28884 .78943 L .31798 .78109 L p .707 .577 .707 r
F P
0 g
s
.31798 .78109 m .31462 .74733 L .28547 .75567 L p .707 .577 .707 r
F P
0 g
s
.68816 .71497 m .69152 .74873 L .67031 .73909 L p .707 .577 .707 r
F P
0 g
s
.67031 .73909 m .66695 .70533 L .68816 .71497 L p .707 .577 .707 r
F P
0 g
s
.22603 .7926 m .22267 .75884 L .19516 .75335 L p .707 .577 .707 r
F P
0 g
s
.22267 .75884 m .22603 .7926 L .25715 .7934 L p .707 .577 .707 r
F P
0 g
s
.37192 .80197 m .38155 .29425 L .36376 .28466 L p .707 .577 .707 r
F P
0 g
s
.38155 .29425 m .37192 .80197 L .40166 .8101 L p .707 .577 .707 r
F P
0 g
s
.25316 .8287 m .25255 .81064 L .22139 .80914 L p .707 .577 .707 r
F P
0 g
s
.25255 .81064 m .25316 .8287 L .28497 .82675 L p .707 .577 .707 r
F P
0 g
s
.28497 .82675 m .28437 .80869 L .25255 .81064 L p .707 .577 .707 r
F P
0 g
s
.31462 .74733 m .31798 .78109 L .34174 .76918 L p .707 .577 .707 r
F P
0 g
s
.34174 .76918 m .33838 .73542 L .31462 .74733 L p .707 .577 .707 r
F P
0 g
s
.17427 .70639 m .17126 .65338 L .15858 .64249 L p .707 .577 .707 r
F P
0 g
s
.17126 .65338 m .17427 .70639 L .19538 .71477 L p .707 .577 .707 r
F P
0 g
s
.28437 .80869 m .28497 .82675 L .31433 .82155 L p .707 .577 .707 r
F P
0 g
s
.31433 .82155 m .31372 .80349 L .28437 .80869 L p .707 .577 .707 r
F P
0 g
s
.22139 .80914 m .22199 .8272 L .25316 .8287 L p .707 .577 .707 r
F P
0 g
s
.22199 .8272 m .22139 .80914 L .19392 .80435 L p .707 .577 .707 r
F P
0 g
s
.19852 .78711 m .19516 .75335 L .17395 .7437 L p .707 .577 .707 r
F P
0 g
s
.19516 .75335 m .19852 .78711 L .22603 .7926 L p .707 .577 .707 r
F P
0 g
s
.35228 .63797 m .35529 .69098 L .36226 .67841 L p .707 .577 .707 r
F P
0 g
s
.36226 .67841 m .35924 .6254 L .35228 .63797 L p .707 .577 .707 r
F P
0 g
s
.66695 .70533 m .67031 .73909 L .6428 .7336 L p .707 .577 .707 r
F P
0 g
s
.6428 .7336 m .63944 .69984 L .66695 .70533 L p .707 .577 .707 r
F P
0 g
s
.19392 .80435 m .19453 .8224 L .22199 .8272 L p .707 .577 .707 r
F P
0 g
s
.68856 .79098 m .68916 .80904 L .66809 .80141 L p .707 .577 .707 r
F P
0 g
s
.66809 .80141 m .66748 .78336 L .68856 .79098 L p .707 .577 .707 r
F P
0 g
s
.31372 .80349 m .31433 .82155 L .33834 .8136 L p .707 .577 .707 r
F P
0 g
s
.33834 .8136 m .33774 .79554 L .31372 .80349 L p .707 .577 .707 r
F P
0 g
s
.33838 .73542 m .34174 .76918 L .35778 .75487 L p .707 .577 .707 r
F P
0 g
s
.35778 .75487 m .35441 .72111 L .33838 .73542 L p .707 .577 .707 r
F P
0 g
s
.19453 .8224 m .19392 .80435 L .17285 .79672 L p .707 .577 .707 r
F P
0 g
s
.63749 .29363 m .62786 .80135 L .63784 .79169 L p .707 .577 .707 r
F P
0 g
s
.63784 .79169 m .64747 .28397 L .63749 .29363 L p .707 .577 .707 r
F P
0 g
s
.15858 .64249 m .16159 .6955 L .17427 .70639 L p .707 .577 .707 r
F P
0 g
s
.16159 .6955 m .15858 .64249 L .15558 .63016 L p .707 .577 .707 r
F P
0 g
s
.17285 .79672 m .17345 .81478 L .19453 .8224 L p .707 .577 .707 r
F P
0 g
s
.17395 .7437 m .17731 .77746 L .19852 .78711 L p .707 .577 .707 r
F P
0 g
s
.17731 .77746 m .17395 .7437 L .16112 .73085 L p .707 .577 .707 r
F P
0 g
s
.33774 .79554 m .33834 .8136 L .35467 .80368 L p .707 .577 .707 r
F P
0 g
s
.35467 .80368 m .35406 .78563 L .33774 .79554 L p .707 .577 .707 r
F P
0 g
s
.66748 .78336 m .66809 .80141 L .64062 .79662 L p .707 .577 .707 r
F P
0 g
s
.64062 .79662 m .64002 .77856 L .66748 .78336 L p .707 .577 .707 r
F P
0 g
s
.35926 .66609 m .35624 .61308 L .35924 .6254 L p .707 .577 .707 r
F P
0 g
s
.35441 .72111 m .35778 .75487 L .36453 .73957 L p .707 .577 .707 r
F P
0 g
s
.36453 .73957 m .36117 .70581 L .35441 .72111 L p .707 .577 .707 r
F P
0 g
s
.35406 .78563 m .35467 .80368 L .36171 .79277 L p .707 .577 .707 r
F P
0 g
s
.36171 .79277 m .3611 .77472 L .35406 .78563 L p .707 .577 .707 r
F P
0 g
s
.35624 .61308 m .35926 .66609 L .34658 .6552 L p .707 .577 .707 r
F P
0 g
s
.34658 .6552 m .34357 .60219 L .35624 .61308 L p .707 .577 .707 r
F P
0 g
s
.35797 .69101 m .35894 .70073 L p .34851 .71192 L .707 .577 .707 r
F P
0 g
s
.35894 .70073 m .36134 .72477 L .35695 .72037 L p .707 .577 .707 r
F P
0 g
s
.35695 .72037 m .34851 .71192 L p .35894 .70073 L .707 .577 .707 r
F P
0 g
s
.34851 .71192 m .34515 .67816 L .35797 .69101 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35965 .27454 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35817 .76388 m .35877 .78193 L .34615 .77222 L p .707 .577 .707 r
F P
0 g
s
.34615 .77222 m .34555 .75417 L .35817 .76388 L p .707 .577 .707 r
F P
0 g
s
.35413 .79238 m .35517 .7379 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35517 .7379 m .36376 .28466 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35924 .6254 m .36226 .67841 L .35926 .66609 L p .707 .577 .707 r
F P
0 g
s
.36117 .70581 m .36453 .73957 L .36134 .72477 L p .707 .577 .707 r
F P
0 g
s
.36134 .72477 m .35797 .69101 L .36117 .70581 L p .707 .577 .707 r
F P
0 g
s
.3611 .77472 m .36171 .79277 L .35877 .78193 L p .707 .577 .707 r
F P
0 g
s
.35877 .78193 m .35817 .76388 L .3611 .77472 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35413 .79238 L .37192 .80197 L p .707 .577 .707 r
F P
0 g
s
.17345 .81478 m .17285 .79672 L .16022 .78702 L p .707 .577 .707 r
F P
0 g
s
.15558 .63016 m .15859 .68317 L .16159 .6955 L p .707 .577 .707 r
F P
0 g
s
.16112 .73085 m .16449 .76461 L .17731 .77746 L p .707 .577 .707 r
F P
0 g
s
.16022 .78702 m .16083 .80507 L .17345 .81478 L p .707 .577 .707 r
F P
0 g
s
.15859 .68317 m .15558 .63016 L .16255 .6176 L p .707 .577 .707 r
F P
0 g
s
.16449 .76461 m .16112 .73085 L .15793 .71605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64747 .28397 m .63784 .79169 L .63373 .78157 L p .707 .577 .707 r
F P
0 g
s
.63373 .78157 m .64336 .27385 L .64747 .28397 L p .707 .577 .707 r
F P
0 g
s
.16083 .80507 m .16022 .78702 L .15729 .77618 L p .707 .577 .707 r
F P
0 g
s
.15793 .71605 m .16129 .74981 L .16449 .76461 L p .707 .577 .707 r
F P
0 g
s
.15729 .77618 m .1579 .79423 L .16083 .80507 L p .707 .577 .707 r
F P
0 g
s
.16255 .6176 m .16556 .67061 L .15859 .68317 L p .707 .577 .707 r
F P
0 g
s
.35965 .27454 m .35002 .78226 L .35413 .79238 L p .707 .577 .707 r
F P
0 g
s
.35002 .78226 m .35965 .27454 L .36963 .26488 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16556 .67061 m .16255 .6176 L .1788 .60604 L p .707 .577 .707 r
F P
0 g
s
.16129 .74981 m .15793 .71605 L .16468 .70075 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34357 .60219 m .34658 .6552 L .32547 .64681 L p .707 .577 .707 r
F P
0 g
s
.32547 .64681 m .32246 .5938 L .34357 .60219 L p .707 .577 .707 r
F P
0 g
s
.1579 .79423 m .15729 .77618 L .16433 .76526 L p .707 .577 .707 r
F P
0 g
s
.16468 .70075 m .16805 .73451 L .16129 .74981 L p .707 .577 .707 r
F P
0 g
s
.1788 .60604 m .18181 .65905 L .16556 .67061 L p .707 .577 .707 r
F P
0 g
s
.16433 .76526 m .16494 .78332 L .1579 .79423 L p .707 .577 .707 r
F P
0 g
s
.64336 .27385 m .63373 .78157 L .61594 .77198 L p .707 .577 .707 r
F P
0 g
s
.61594 .77198 m .62557 .26426 L .64336 .27385 L p .707 .577 .707 r
F P
0 g
s
.18181 .65905 m .1788 .60604 L .20275 .5966 L p .707 .577 .707 r
F P
0 g
s
.16805 .73451 m .16468 .70075 L .18072 .68644 L p .707 .577 .707 r
F P
0 g
s
.32246 .5938 m .32547 .64681 L .29799 .64176 L p .707 .577 .707 r
F P
0 g
s
.29799 .64176 m .29498 .58875 L .32246 .5938 L p .707 .577 .707 r
F P
0 g
s
.34515 .67816 m .34851 .71192 L .3273 .70227 L p .707 .577 .707 r
F P
0 g
s
.3273 .70227 m .32394 .66851 L .34515 .67816 L p .707 .577 .707 r
F P
0 g
s
.36 .7726 m .36963 .26488 L .39272 .25663 L p .707 .577 .707 r
F P
0 g
s
.36963 .26488 m .36 .7726 L .35002 .78226 L p .707 .577 .707 r
F P
0 g
s
.20576 .64961 m .20275 .5966 L .23205 .59022 L p .707 .577 .707 r
F P
0 g
s
.20275 .5966 m .20576 .64961 L .18181 .65905 L p .707 .577 .707 r
F P
0 g
s
.16494 .78332 m .16433 .76526 L .18066 .75535 L p .707 .577 .707 r
F P
0 g
s
.18072 .68644 m .18408 .7202 L .16805 .73451 L p .707 .577 .707 r
F P
0 g
s
.29498 .58875 m .29799 .64176 L .26684 .64052 L p .707 .577 .707 r
F P
0 g
s
.26684 .64052 m .26383 .58751 L .29498 .58875 L p .707 .577 .707 r
F P
0 g
s
.18066 .75535 m .18126 .7734 L .16494 .78332 L p .707 .577 .707 r
F P
0 g
s
.18408 .7202 m .18072 .68644 L .20448 .67453 L p .707 .577 .707 r
F P
0 g
s
.23506 .64323 m .23205 .59022 L .26383 .58751 L p .707 .577 .707 r
F P
0 g
s
.23205 .59022 m .23506 .64323 L .20576 .64961 L p .707 .577 .707 r
F P
0 g
s
.26383 .58751 m .26684 .64052 L .23506 .64323 L p .707 .577 .707 r
F P
0 g
s
.32394 .66851 m .3273 .70227 L .29979 .69678 L p .707 .577 .707 r
F P
0 g
s
.29979 .69678 m .29643 .66302 L .32394 .66851 L p .707 .577 .707 r
F P
0 g
s
.34555 .75417 m .34615 .77222 L .32508 .7646 L p .707 .577 .707 r
F P
0 g
s
.32508 .7646 m .32447 .74654 L .34555 .75417 L p .707 .577 .707 r
F P
0 g
s
.62557 .26426 m .61594 .77198 L .5862 .76386 L p .707 .577 .707 r
F P
0 g
s
.5862 .76386 m .59583 .25613 L .62557 .26426 L p .707 .577 .707 r
F P
0 g
s
.20784 .70829 m .20448 .67453 L .23362 .66619 L p .707 .577 .707 r
F P
0 g
s
.20448 .67453 m .20784 .70829 L .18408 .7202 L p .707 .577 .707 r
F P
0 g
s
.73422 .67364 m .73121 .62063 L .70006 .61939 L p .707 .577 .707 r
F P
0 g
s
.73121 .62063 m .73422 .67364 L .766 .67093 L p .707 .577 .707 r
F P
0 g
s
.766 .67093 m .76299 .61792 L .73121 .62063 L p .707 .577 .707 r
F P
0 g
s
.18126 .7734 m .18066 .75535 L .20467 .7474 L p .707 .577 .707 r
F P
0 g
s
.76299 .61792 m .766 .67093 L .7953 .66455 L p .707 .577 .707 r
F P
0 g
s
.7953 .66455 m .79229 .61154 L .76299 .61792 L p .707 .577 .707 r
F P
0 g
s
.29643 .66302 m .29979 .69678 L .26867 .69598 L p .707 .577 .707 r
F P
0 g
s
.26867 .69598 m .26531 .66222 L .29643 .66302 L p .707 .577 .707 r
F P
0 g
s
.70307 .6724 m .70006 .61939 L .67258 .61434 L p .707 .577 .707 r
F P
0 g
s
.70006 .61939 m .70307 .6724 L .73422 .67364 L p .707 .577 .707 r
F P
0 g
s
.20467 .7474 m .20528 .76546 L .18126 .7734 L p .707 .577 .707 r
F P
0 g
s
.39272 .25663 m .38309 .76435 L .36 .7726 L p .707 .577 .707 r
F P
0 g
s
.38309 .76435 m .39272 .25663 L .42666 .25059 L p .707 .577 .707 r
F P
0 g
s
.23699 .69995 m .23362 .66619 L .26531 .66222 L p .707 .577 .707 r
F P
0 g
s
.23362 .66619 m .23699 .69995 L .20784 .70829 L p .707 .577 .707 r
F P
0 g
s
.26531 .66222 m .26867 .69598 L .23699 .69995 L p .707 .577 .707 r
F P
0 g
s
.32447 .74654 m .32508 .7646 L .29761 .7598 L p .707 .577 .707 r
F P
0 g
s
.29761 .7598 m .29701 .74175 L .32447 .74654 L p .707 .577 .707 r
F P
0 g
s
.79229 .61154 m .7953 .66455 L .81925 .65511 L p .707 .577 .707 r
F P
0 g
s
.81925 .65511 m .81624 .6021 L .79229 .61154 L p .707 .577 .707 r
F P
0 g
s
.20528 .76546 m .20467 .7474 L .23402 .7422 L p .707 .577 .707 r
F P
0 g
s
.67559 .66735 m .67258 .61434 L .65147 .60595 L p .707 .577 .707 r
F P
0 g
s
.67258 .61434 m .67559 .66735 L .70307 .6724 L p .707 .577 .707 r
F P
0 g
s
.59583 .25613 m .5862 .76386 L .54744 .758 L p .707 .577 .707 r
F P
0 g
s
.54744 .758 m .55706 .25027 L .59583 .25613 L p .707 .577 .707 r
F P
0 g
s
.23402 .7422 m .23463 .76025 L .20528 .76546 L p .707 .577 .707 r
F P
0 g
s
.29701 .74175 m .29761 .7598 L .26645 .7583 L p .707 .577 .707 r
F P
0 g
s
.26645 .7583 m .26584 .74025 L .29701 .74175 L p .707 .577 .707 r
F P
0 g
s
.73736 .73508 m .734 .70132 L .70288 .70052 L p .707 .577 .707 r
F P
0 g
s
.734 .70132 m .73736 .73508 L .76905 .73111 L p .707 .577 .707 r
F P
0 g
s
.76905 .73111 m .76569 .69736 L .734 .70132 L p .707 .577 .707 r
F P
0 g
s
.76569 .69736 m .76905 .73111 L .7982 .72277 L p .707 .577 .707 r
F P
0 g
s
.7982 .72277 m .79483 .68901 L .76569 .69736 L p .707 .577 .707 r
F P
0 g
s
.81624 .6021 m .81925 .65511 L .8355 .64355 L p .707 .577 .707 r
F P
0 g
s
.8355 .64355 m .83249 .59054 L .81624 .6021 L p .707 .577 .707 r
F P
0 g
s
.23463 .76025 m .23402 .7422 L .26584 .74025 L p .707 .577 .707 r
F P
0 g
s
.26584 .74025 m .26645 .7583 L .23463 .76025 L p .707 .577 .707 r
F P
0 g
s
.70624 .73428 m .70288 .70052 L .67537 .69503 L p .707 .577 .707 r
F P
0 g
s
.70288 .70052 m .70624 .73428 L .73736 .73508 L p .707 .577 .707 r
F P
0 g
s
.41703 .75831 m .42666 .25059 L .46812 .24736 L p .707 .577 .707 r
F P
0 g
s
.42666 .25059 m .41703 .75831 L .38309 .76435 L p .707 .577 .707 r
F P
0 g
s
.73337 .76157 m .73277 .74352 L .7016 .74202 L p .707 .577 .707 r
F P
0 g
s
.73277 .74352 m .73337 .76157 L .76519 .75962 L p .707 .577 .707 r
F P
0 g
s
.76519 .75962 m .76458 .74157 L .73277 .74352 L p .707 .577 .707 r
F P
0 g
s
.76458 .74157 m .76519 .75962 L .79454 .75442 L p .707 .577 .707 r
F P
0 g
s
.79454 .75442 m .79393 .73637 L .76458 .74157 L p .707 .577 .707 r
F P
0 g
s
.79483 .68901 m .7982 .72277 L .82195 .71086 L p .707 .577 .707 r
F P
0 g
s
.82195 .71086 m .81859 .6771 L .79483 .68901 L p .707 .577 .707 r
F P
0 g
s
.7016 .74202 m .70221 .76007 L .73337 .76157 L p .707 .577 .707 r
F P
0 g
s
.65448 .65896 m .65147 .60595 L .63879 .59507 L p .707 .577 .707 r
F P
0 g
s
.65147 .60595 m .65448 .65896 L .67559 .66735 L p .707 .577 .707 r
F P
0 g
s
.70221 .76007 m .7016 .74202 L .67414 .73722 L p .707 .577 .707 r
F P
0 g
s
.55706 .25027 m .54744 .758 L .50343 .75498 L p .707 .577 .707 r
F P
0 g
s
.50343 .75498 m .51306 .24725 L .55706 .25027 L p .707 .577 .707 r
F P
0 g
s
.67414 .73722 m .67474 .75528 L .70221 .76007 L p .707 .577 .707 r
F P
0 g
s
.79393 .73637 m .79454 .75442 L .81855 .74647 L p .707 .577 .707 r
F P
0 g
s
.81855 .74647 m .81795 .72842 L .79393 .73637 L p .707 .577 .707 r
F P
0 g
s
.67873 .72879 m .67537 .69503 L .65416 .68539 L p .707 .577 .707 r
F P
0 g
s
.67537 .69503 m .67873 .72879 L .70624 .73428 L p .707 .577 .707 r
F P
0 g
s
.4585 .75508 m .46812 .24736 L .51306 .24725 L p .707 .577 .707 r
F P
0 g
s
.46812 .24736 m .4585 .75508 L .41703 .75831 L p .707 .577 .707 r
F P
0 g
s
.83249 .59054 m .8355 .64355 L .84247 .63099 L p .707 .577 .707 r
F P
0 g
s
.84247 .63099 m .83946 .57798 L .83249 .59054 L p .707 .577 .707 r
F P
0 g
s
.51306 .24725 m .50343 .75498 L .4585 .75508 L p .707 .577 .707 r
F P
0 g
s
.81859 .6771 m .82195 .71086 L .83799 .69655 L p .707 .577 .707 r
F P
0 g
s
.83799 .69655 m .83463 .6628 L .81859 .6771 L p .707 .577 .707 r
F P
0 g
s
.67474 .75528 m .67414 .73722 L .65306 .7296 L p .707 .577 .707 r
F P
0 g
s
.65306 .7296 m .65367 .74765 L .67474 .75528 L p .707 .577 .707 r
F P
0 g
s
.63879 .59507 m .64181 .64808 L .65448 .65896 L p .707 .577 .707 r
F P
0 g
s
.65416 .68539 m .65753 .71914 L .67873 .72879 L p .707 .577 .707 r
F P
0 g
s
.81795 .72842 m .81855 .74647 L .83488 .73656 L p .707 .577 .707 r
F P
0 g
s
.83488 .73656 m .83428 .7185 L .81795 .72842 L p .707 .577 .707 r
F P
0 g
s
.64181 .64808 m .63879 .59507 L .63579 .58274 L p .707 .577 .707 r
F P
0 g
s
.65753 .71914 m .65416 .68539 L .64134 .67254 L p .707 .577 .707 r
F P
0 g
s
.83463 .6628 m .83799 .69655 L .84474 .68125 L p .707 .577 .707 r
F P
0 g
s
.84474 .68125 m .84138 .64749 L .83463 .6628 L p .707 .577 .707 r
F P
0 g
s
.65367 .74765 m .65306 .7296 L .64044 .71989 L p .707 .577 .707 r
F P
0 g
s
.83946 .57798 m .84247 .63099 L .83947 .61866 L p .707 .577 .707 r
F P
0 g
s
.83947 .61866 m .83646 .56565 L .83946 .57798 L p .707 .577 .707 r
F P
0 g
s
.64044 .71989 m .64104 .73795 L .65367 .74765 L p .707 .577 .707 r
F P
0 g
s
.64134 .67254 m .6447 .70629 L .65753 .71914 L p .707 .577 .707 r
F P
0 g
s
.63579 .58274 m .6388 .63575 L .64181 .64808 L p .707 .577 .707 r
F P
0 g
s
.83428 .7185 m .83488 .73656 L .84192 .72565 L p .707 .577 .707 r
F P
0 g
s
.84192 .72565 m .84132 .70759 L .83428 .7185 L p .707 .577 .707 r
F P
0 g
s
.6447 .70629 m .64134 .67254 L .63814 .65773 L p .707 .577 .707 r
F P
0 g
s
.6388 .63575 m .63579 .58274 L .64276 .57018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84138 .64749 m .84474 .68125 L .84155 .66645 L p .707 .577 .707 r
F P
0 g
s
.84155 .66645 m .83819 .63269 L .84138 .64749 L p .707 .577 .707 r
F P
0 g
s
.64104 .73795 m .64044 .71989 L .6375 .70905 L p .707 .577 .707 r
F P
0 g
s
.83646 .56565 m .83947 .61866 L .82679 .60777 L p .707 .577 .707 r
F P
0 g
s
.82679 .60777 m .82378 .55476 L .83646 .56565 L p .707 .577 .707 r
F P
0 g
s
.6375 .70905 m .63811 .72711 L .64104 .73795 L p .707 .577 .707 r
F P
0 g
s
.63814 .65773 m .64151 .69149 L .6447 .70629 L p .707 .577 .707 r
F P
0 g
s
.64276 .57018 m .64577 .62319 L .6388 .63575 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84132 .70759 m .84192 .72565 L .83899 .7148 L p .707 .577 .707 r
F P
0 g
s
.83899 .7148 m .83838 .69675 L .84132 .70759 L p .707 .577 .707 r
F P
0 g
s
.64151 .69149 m .63814 .65773 L .6449 .64243 L p .707 .577 .707 r
F P
0 g
s
.64577 .62319 m .64276 .57018 L .65901 .55861 L p .707 .577 .707 r
F P
0 g
s
.39121 .63682 m .3882 .58381 L .35705 .58258 L p .707 .577 .707 r
F P
0 g
s
.3882 .58381 m .39121 .63682 L .42299 .63412 L p .707 .577 .707 r
F P
0 g
s
.42299 .63412 m .41998 .58111 L .3882 .58381 L p .707 .577 .707 r
F P
0 g
s
.41998 .58111 m .42299 .63412 L .45229 .62773 L p .707 .577 .707 r
F P
0 g
s
.45229 .62773 m .44928 .57472 L .41998 .58111 L p .707 .577 .707 r
F P
0 g
s
.83819 .63269 m .84155 .66645 L .82872 .6536 L p .707 .577 .707 r
F P
0 g
s
.82872 .6536 m .82536 .61984 L .83819 .63269 L p .707 .577 .707 r
F P
0 g
s
.36006 .63559 m .35705 .58258 L .32957 .57752 L p .707 .577 .707 r
F P
0 g
s
.35705 .58258 m .36006 .63559 L .39121 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63811 .72711 m .6375 .70905 L .64454 .69814 L p .707 .577 .707 r
F P
0 g
s
.82378 .55476 m .82679 .60777 L .80568 .59939 L p .707 .577 .707 r
F P
0 g
s
.80568 .59939 m .80267 .54638 L .82378 .55476 L p .707 .577 .707 r
F P
0 g
s
.44928 .57472 m .45229 .62773 L .47624 .6183 L p .707 .577 .707 r
F P
0 g
s
.47624 .6183 m .47323 .56529 L .44928 .57472 L p .707 .577 .707 r
F P
0 g
s
.6449 .64243 m .64826 .67619 L .64151 .69149 L p .707 .577 .707 r
F P
0 g
s
.64454 .69814 m .64515 .71619 L .63811 .72711 L p .707 .577 .707 r
F P
0 g
s
.65901 .55861 m .66202 .61162 L .64577 .62319 L p .707 .577 .707 r
F P
0 g
s
.33258 .63053 m .32957 .57752 L .30846 .56914 L p .707 .577 .707 r
F P
0 g
s
.32957 .57752 m .33258 .63053 L .36006 .63559 L p .707 .577 .707 r
F P
0 g
s
.66202 .61162 m .65901 .55861 L .68296 .54917 L p .707 .577 .707 r
F P
0 g
s
.64826 .67619 m .6449 .64243 L .66094 .62812 L p .707 .577 .707 r
F P
0 g
s
.83838 .69675 m .83899 .7148 L .82637 .7051 L p .707 .577 .707 r
F P
0 g
s
.82637 .7051 m .82576 .68704 L .83838 .69675 L p .707 .577 .707 r
F P
0 g
s
.39435 .69827 m .39099 .66451 L .35987 .66371 L p .707 .577 .707 r
F P
0 g
s
.39099 .66451 m .39435 .69827 L .42604 .6943 L p .707 .577 .707 r
F P
0 g
s
.42604 .6943 m .42268 .66054 L .39099 .66451 L p .707 .577 .707 r
F P
0 g
s
.42268 .66054 m .42604 .6943 L .45519 .68595 L p .707 .577 .707 r
F P
0 g
s
.45519 .68595 m .45182 .65219 L .42268 .66054 L p .707 .577 .707 r
F P
0 g
s
.47323 .56529 m .47624 .6183 L .49249 .60673 L p .707 .577 .707 r
F P
0 g
s
.49249 .60673 m .48948 .55372 L .47323 .56529 L p .707 .577 .707 r
F P
0 g
s
.82536 .61984 m .82872 .6536 L .80752 .64395 L p .707 .577 .707 r
F P
0 g
s
.80752 .64395 m .80415 .6102 L .82536 .61984 L p .707 .577 .707 r
F P
0 g
s
.80267 .54638 m .80568 .59939 L .77821 .59433 L p .707 .577 .707 r
F P
0 g
s
.77821 .59433 m .7752 .54132 L .80267 .54638 L p .707 .577 .707 r
F P
0 g
s
.36323 .69746 m .35987 .66371 L .33236 .65821 L p .707 .577 .707 r
F P
0 g
s
.35987 .66371 m .36323 .69746 L .39435 .69827 L p .707 .577 .707 r
F P
0 g
s
.39036 .72476 m .38976 .7067 L .35859 .7052 L p .707 .577 .707 r
F P
0 g
s
.38976 .7067 m .39036 .72476 L .42218 .72281 L p .707 .577 .707 r
F P
0 g
s
.42218 .72281 m .42157 .70475 L .38976 .7067 L p .707 .577 .707 r
F P
0 g
s
.64515 .71619 m .64454 .69814 L .66087 .68822 L p .707 .577 .707 r
F P
0 g
s
.42157 .70475 m .42218 .72281 L .45153 .71761 L p .707 .577 .707 r
F P
0 g
s
.45153 .71761 m .45092 .69955 L .42157 .70475 L p .707 .577 .707 r
F P
0 g
s
.45182 .65219 m .45519 .68595 L .47894 .67404 L p .707 .577 .707 r
F P
0 g
s
.47894 .67404 m .47558 .64029 L .45182 .65219 L p .707 .577 .707 r
F P
0 g
s
.66094 .62812 m .6643 .66188 L .64826 .67619 L p .707 .577 .707 r
F P
0 g
s
.68597 .60219 m .68296 .54917 L .71226 .54279 L p .707 .577 .707 r
F P
0 g
s
.68296 .54917 m .68597 .60219 L .66202 .61162 L p .707 .577 .707 r
F P
0 g
s
.35859 .7052 m .3592 .72326 L .39036 .72476 L p .707 .577 .707 r
F P
0 g
s
.66087 .68822 m .66148 .70628 L .64515 .71619 L p .707 .577 .707 r
F P
0 g
s
.31147 .62215 m .30846 .56914 L .29578 .55825 L p .707 .577 .707 r
F P
0 g
s
.30846 .56914 m .31147 .62215 L .33258 .63053 L p .707 .577 .707 r
F P
0 g
s
.3592 .72326 m .35859 .7052 L .33113 .70041 L p .707 .577 .707 r
F P
0 g
s
.6643 .66188 m .66094 .62812 L .68469 .61622 L p .707 .577 .707 r
F P
0 g
s
.7752 .54132 m .77821 .59433 L .74705 .5931 L p .707 .577 .707 r
F P
0 g
s
.74705 .5931 m .74404 .54008 L .7752 .54132 L p .707 .577 .707 r
F P
0 g
s
.33113 .70041 m .33173 .71846 L .3592 .72326 L p .707 .577 .707 r
F P
0 g
s
.82576 .68704 m .82637 .7051 L .80529 .69747 L p .707 .577 .707 r
F P
0 g
s
.80529 .69747 m .80469 .67942 L .82576 .68704 L p .707 .577 .707 r
F P
0 g
s
.45092 .69955 m .45153 .71761 L .47554 .70966 L p .707 .577 .707 r
F P
0 g
s
.47554 .70966 m .47494 .6916 L .45092 .69955 L p .707 .577 .707 r
F P
0 g
s
.33572 .69197 m .33236 .65821 L .31115 .64857 L p .707 .577 .707 r
F P
0 g
s
.33236 .65821 m .33572 .69197 L .36323 .69746 L p .707 .577 .707 r
F P
0 g
s
.71527 .5958 m .71226 .54279 L .74404 .54008 L p .707 .577 .707 r
F P
0 g
s
.71226 .54279 m .71527 .5958 L .68597 .60219 L p .707 .577 .707 r
F P
0 g
s
.80415 .6102 m .80752 .64395 L .78001 .63846 L p .707 .577 .707 r
F P
0 g
s
.78001 .63846 m .77664 .6047 L .80415 .6102 L p .707 .577 .707 r
F P
0 g
s
.74404 .54008 m .74705 .5931 L .71527 .5958 L p .707 .577 .707 r
F P
0 g
s
.48948 .55372 m .49249 .60673 L .49946 .59417 L p .707 .577 .707 r
F P
0 g
s
.49946 .59417 m .49645 .54116 L .48948 .55372 L p .707 .577 .707 r
F P
0 g
s
.47558 .64029 m .47894 .67404 L .49498 .65974 L p .707 .577 .707 r
F P
0 g
s
.49498 .65974 m .49162 .62598 L .47558 .64029 L p .707 .577 .707 r
F P
0 g
s
.33173 .71846 m .33113 .70041 L .31005 .69278 L p .707 .577 .707 r
F P
0 g
s
.66148 .70628 m .66087 .68822 L .68489 .68027 L p .707 .577 .707 r
F P
0 g
s
.68805 .64997 m .68469 .61622 L .71384 .60787 L p .707 .577 .707 r
F P
0 g
s
.68469 .61622 m .68805 .64997 L .6643 .66188 L p .707 .577 .707 r
F P
0 g
s
.31005 .69278 m .31066 .71084 L .33173 .71846 L p .707 .577 .707 r
F P
0 g
s
.29578 .55825 m .2988 .61126 L .31147 .62215 L p .707 .577 .707 r
F P
0 g
s
.77664 .6047 m .78001 .63846 L .74889 .63766 L p .707 .577 .707 r
F P
0 g
s
.74889 .63766 m .74552 .6039 L .77664 .6047 L p .707 .577 .707 r
F P
0 g
s
.31115 .64857 m .31452 .68233 L .33572 .69197 L p .707 .577 .707 r
F P
0 g
s
.68489 .68027 m .68549 .69833 L .66148 .70628 L p .707 .577 .707 r
F P
0 g
s
.47494 .6916 m .47554 .70966 L .49187 .69974 L p .707 .577 .707 r
F P
0 g
s
.49187 .69974 m .49127 .68169 L .47494 .6916 L p .707 .577 .707 r
F P
0 g
s
.2988 .61126 m .29578 .55825 L .29278 .54592 L p .707 .577 .707 r
F P
0 g
s
.31452 .68233 m .31115 .64857 L .29833 .63572 L p .707 .577 .707 r
F P
0 g
s
.80469 .67942 m .80529 .69747 L .77783 .69268 L p .707 .577 .707 r
F P
0 g
s
.77783 .69268 m .77722 .67462 L .80469 .67942 L p .707 .577 .707 r
F P
0 g
s
.7172 .64163 m .71384 .60787 L .74552 .6039 L p .707 .577 .707 r
F P
0 g
s
.71384 .60787 m .7172 .64163 L .68805 .64997 L p .707 .577 .707 r
F P
0 g
s
.74552 .6039 m .74889 .63766 L .7172 .64163 L p .707 .577 .707 r
F P
0 g
s
.49162 .62598 m .49498 .65974 L .50173 .64443 L p .707 .577 .707 r
F P
0 g
s
.50173 .64443 m .49837 .61068 L .49162 .62598 L p .707 .577 .707 r
F P
0 g
s
.68549 .69833 m .68489 .68027 L .71424 .67507 L p .707 .577 .707 r
F P
0 g
s
.31066 .71084 m .31005 .69278 L .29743 .68308 L p .707 .577 .707 r
F P
0 g
s
.49645 .54116 m .49946 .59417 L .49646 .58184 L p .707 .577 .707 r
F P
0 g
s
.49646 .58184 m .49345 .52883 L .49645 .54116 L p .707 .577 .707 r
F P
0 g
s
.71424 .67507 m .71484 .69313 L .68549 .69833 L p .707 .577 .707 r
F P
0 g
s
.29743 .68308 m .29803 .70113 L .31066 .71084 L p .707 .577 .707 r
F P
0 g
s
.77722 .67462 m .77783 .69268 L .74666 .69118 L p .707 .577 .707 r
F P
0 g
s
.74666 .69118 m .74606 .67312 L .77722 .67462 L p .707 .577 .707 r
F P
0 g
s
.29833 .63572 m .30169 .66948 L .31452 .68233 L p .707 .577 .707 r
F P
0 g
s
.29278 .54592 m .29579 .59893 L .2988 .61126 L p .707 .577 .707 r
F P
0 g
s
.71484 .69313 m .71424 .67507 L .74606 .67312 L p .707 .577 .707 r
F P
0 g
s
.49127 .68169 m .49187 .69974 L .49891 .68883 L p .707 .577 .707 r
F P
0 g
s
.49891 .68883 m .49831 .67077 L .49127 .68169 L p .707 .577 .707 r
F P
0 g
s
.74606 .67312 m .74666 .69118 L .71484 .69313 L p .707 .577 .707 r
F P
0 g
s
.30169 .66948 m .29833 .63572 L .29513 .62092 L p .707 .577 .707 r
F P
0 g
s
.29579 .59893 m .29278 .54592 L .29975 .53336 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49837 .61068 m .50173 .64443 L .49854 .62963 L p .707 .577 .707 r
F P
0 g
s
.49854 .62963 m .49518 .59588 L .49837 .61068 L p .707 .577 .707 r
F P
0 g
s
.29803 .70113 m .29743 .68308 L .29449 .67223 L p .707 .577 .707 r
F P
0 g
s
.49345 .52883 m .49646 .58184 L .48378 .57096 L p .707 .577 .707 r
F P
0 g
s
.48378 .57096 m .48077 .51795 L .49345 .52883 L p .707 .577 .707 r
F P
0 g
s
.29449 .67223 m .2951 .69029 L .29803 .70113 L p .707 .577 .707 r
F P
0 g
s
.29513 .62092 m .29849 .65468 L .30169 .66948 L p .707 .577 .707 r
F P
0 g
s
.29975 .53336 m .30276 .58637 L .29579 .59893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49831 .67077 m .49891 .68883 L .49598 .67799 L p .707 .577 .707 r
F P
0 g
s
.49598 .67799 m .49537 .65993 L .49831 .67077 L p .707 .577 .707 r
F P
0 g
s
.29849 .65468 m .29513 .62092 L .30189 .60562 L p .707 .577 .707 r
F P
0 g
s
.30276 .58637 m .29975 .53336 L .316 .5218 L p .707 .577 .707 r
F P
0 g
s
.49518 .59588 m .49854 .62963 L .48571 .61678 L p .707 .577 .707 r
F P
0 g
s
.48571 .61678 m .48235 .58302 L .49518 .59588 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2951 .69029 m .29449 .67223 L .30153 .66132 L p .707 .577 .707 r
F P
0 g
s
.48077 .51795 m .48378 .57096 L .46267 .56257 L p .707 .577 .707 r
F P
0 g
s
.46267 .56257 m .45966 .50956 L .48077 .51795 L p .707 .577 .707 r
F P
0 g
s
.30189 .60562 m .30525 .63937 L .29849 .65468 L p .707 .577 .707 r
F P
0 g
s
.30153 .66132 m .30214 .67938 L .2951 .69029 L p .707 .577 .707 r
F P
0 g
s
.316 .5218 m .31901 .57481 L .30276 .58637 L p .707 .577 .707 r
F P
0 g
s
.31901 .57481 m .316 .5218 L .33995 .51236 L p .707 .577 .707 r
F P
0 g
s
.30525 .63937 m .30189 .60562 L .31793 .59131 L p .707 .577 .707 r
F P
0 g
s
.49537 .65993 m .49598 .67799 L .48336 .66828 L p .707 .577 .707 r
F P
0 g
s
.48336 .66828 m .48275 .65023 L .49537 .65993 L p .707 .577 .707 r
F P
0 g
s
.48235 .58302 m .48571 .61678 L .46451 .60714 L p .707 .577 .707 r
F P
0 g
s
.46451 .60714 m .46114 .57338 L .48235 .58302 L p .707 .577 .707 r
F P
0 g
s
.45966 .50956 m .46267 .56257 L .4352 .55752 L p .707 .577 .707 r
F P
0 g
s
.4352 .55752 m .43219 .50451 L .45966 .50956 L p .707 .577 .707 r
F P
0 g
s
.30214 .67938 m .30153 .66132 L .31786 .65141 L p .707 .577 .707 r
F P
0 g
s
.31793 .59131 m .32129 .62507 L .30525 .63937 L p .707 .577 .707 r
F P
0 g
s
.34296 .56537 m .33995 .51236 L .36925 .50598 L p .707 .577 .707 r
F P
0 g
s
.33995 .51236 m .34296 .56537 L .31901 .57481 L p .707 .577 .707 r
F P
0 g
s
.31786 .65141 m .31847 .66946 L .30214 .67938 L p .707 .577 .707 r
F P
0 g
s
.32129 .62507 m .31793 .59131 L .34168 .5794 L p .707 .577 .707 r
F P
0 g
s
.43219 .50451 m .4352 .55752 L .40404 .55628 L p .707 .577 .707 r
F P
0 g
s
.40404 .55628 m .40103 .50327 L .43219 .50451 L p .707 .577 .707 r
F P
0 g
s
.48275 .65023 m .48336 .66828 L .46228 .66066 L p .707 .577 .707 r
F P
0 g
s
.46228 .66066 m .46168 .6426 L .48275 .65023 L p .707 .577 .707 r
F P
0 g
s
.37226 .55899 m .36925 .50598 L .40103 .50327 L p .707 .577 .707 r
F P
0 g
s
.36925 .50598 m .37226 .55899 L .34296 .56537 L p .707 .577 .707 r
F P
0 g
s
.46114 .57338 m .46451 .60714 L .43699 .60165 L p .707 .577 .707 r
F P
0 g
s
.43699 .60165 m .43363 .56789 L .46114 .57338 L p .707 .577 .707 r
F P
0 g
s
.40103 .50327 m .40404 .55628 L .37226 .55899 L p .707 .577 .707 r
F P
0 g
s
.31847 .66946 m .31786 .65141 L .34188 .64346 L p .707 .577 .707 r
F P
0 g
s
.34504 .61316 m .34168 .5794 L .37083 .57105 L p .707 .577 .707 r
F P
0 g
s
.34168 .5794 m .34504 .61316 L .32129 .62507 L p .707 .577 .707 r
F P
0 g
s
.43363 .56789 m .43699 .60165 L .40587 .60085 L p .707 .577 .707 r
F P
0 g
s
.40587 .60085 m .40251 .56709 L .43363 .56789 L p .707 .577 .707 r
F P
0 g
s
.34188 .64346 m .34248 .66151 L .31847 .66946 L p .707 .577 .707 r
F P
0 g
s
.46168 .6426 m .46228 .66066 L .43482 .65586 L p .707 .577 .707 r
F P
0 g
s
.43482 .65586 m .43421 .63781 L .46168 .6426 L p .707 .577 .707 r
F P
0 g
s
.37419 .60481 m .37083 .57105 L .40251 .56709 L p .707 .577 .707 r
F P
0 g
s
.37083 .57105 m .37419 .60481 L .34504 .61316 L p .707 .577 .707 r
F P
0 g
s
.40251 .56709 m .40587 .60085 L .37419 .60481 L p .707 .577 .707 r
F P
0 g
s
.34248 .66151 m .34188 .64346 L .37123 .63826 L p .707 .577 .707 r
F P
0 g
s
.37123 .63826 m .37183 .65631 L .34248 .66151 L p .707 .577 .707 r
F P
0 g
s
.43421 .63781 m .43482 .65586 L .40365 .65436 L p .707 .577 .707 r
F P
0 g
s
.40365 .65436 m .40304 .63631 L .43421 .63781 L p .707 .577 .707 r
F P
0 g
s
.37183 .65631 m .37123 .63826 L .40304 .63631 L p .707 .577 .707 r
F P
0 g
s
.40304 .63631 m .40365 .65436 L .37183 .65631 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEP`007Uoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00
LWoo001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH01000FUH00000L7oo001[Ool300000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KGoo001YOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001ZOol006Qoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0001H0
00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00Hgoo100000=JEP00FUH025YF00<005YFFUH01EYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Ggoo10001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001M
Ool200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`l003moo`00Dgoo00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEP00008000EJEP03001J
EUYF00=JEP@0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=oo`04
001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP07FUH4
0004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`04001JEUYF0003FUH0
1000FUIJEUYF0P0017oo00@005YFFUH000EJEQ0000IJEPD00003FUH005YF009JEP04001JEUYF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;goo001COol01000FUIJEP000eYF00@005YF000000Ioo`03001JEUYF00L000AJEP03001J
EUYF00IJEP03001JEP0000D000=JEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00E7oo
00<005YF00000eYF0P0027oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1000
00=JEP00FUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF0000
0UYF00<005YFFUH020001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH000020004FUH00`00
FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000015YF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`04001JEP000005FUH20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH300001EYF001JEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaH00003FUH005YF009JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00?7oo100000=JEP00FUH025YF00<005YFFUH01EYF
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool003Qoo`@0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=J
EP03001JEUYF00AJEPL00004Ool000000005Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000fOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH200000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00@000Moo`D000aoo`D000AJEP05
001JEUYFFUH0000^Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEPT000AJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH4000:Ool?0008Ool300000eYF
001JEP02FUH00`00Oomoo`0/Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00IJEPD000EJEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YF00000P0027oo1P0015YF00<005YFFUH01UYF
00<005YF00000`0000=oo`0000000P0000AJEP00000000=JEP8002eoo`00<Goo0P001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH015YF00<005YFFUH01000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF0000009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP80
00Uoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP04001JEUYF0002
FUH2000]Ool002moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP<000EJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP800003FUH005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00<000=oo`<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF009JEP@002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF00000002FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<0
05YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0`00;Goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2000015YF00000000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH015YF0`0000=JEP00FUH01UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF000000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001J
EP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF1P0015YF00<005YFFUH01EYF1@001EYF00<005YF
FUH0100015YF00<005YFFUH015YF0P0000AJEP00000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF00=JEPT000=JEPd000QJEP03001JEUYF00=JEP04001JEP00FUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00007FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF00@005YF001JEPP000AJEP03001JEUYF009J
EPP000AJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200001EYF001JEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF3`00
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF500000=JEP00000015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH600000eYF00000003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008FUH00`00
FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP04000COol200000eYF0000000400001EYF000005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEPD000AJEP03001JEUYF008002eoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEP@001Moo`80009JEP04001oogooOol20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000015YF001JEUYF0P00;Goo000/Ool01000FUIJEP000eYF00@005YFFUIJEP8000moo`<000Uoo`04
001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF10000eYF00<007ooOol0:goo000/Ool01000FUIJEP000eYF00@0
05YF0000011oo`D000Qoo`80009JEP<000IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;Goo000]Ool00`00FUH00003FUH2000BOol5
0008Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH70004FUH50005
FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P001Woo00<005YF0000;Goo000]Ool00`00FUH00002FUH00`00FUIJ
EP05000=Ool?0004FUH00`00FUIJEP03FUHD0004FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40009Ool3000]Ool002eoo`03001JEP00008000AJEP04001JEUYFFUH=0004FUH00`00
FUIJEP06FUH20004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH0009JEP@000EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00@000aoo`800003FUH0000002aoo`00;Goo00@005YF000000EJEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000=JEP04
001JEUYFFUH400000eYF001JEP07FUH<000>Ool200000eYF001JEP02000/Ool002eoo`800003FUH0
05YF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH20004FUH00`00FUIJEP03FUH00`00FUH0000G000;Ool01P00FUIJEUYF001JEP80
02aoo`00;Goo0P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000Eoo`8000AJEP04001JEUYF000/Ool002eo
o`05001JEUYFFUH00004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUH00002FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP05FUH0
0`00FUIJEP020005FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000050002FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH500000eYF001JEP03FUH01000FUIJEP00;7oo000]Ool01@00FUIJEUYF00000UYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P0015YF00<005YF
FUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF0`001UYF0P0000AJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP000Woo1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001EYF00<0
05YF0000;7oo000]Ool01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP<00003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJ
EP<000EJEP800006FUH005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001EYF10001UYF00<005YFFUH0
15YF1@001UYF00<005YFFUH010000UYF00@005YFFUIJEP8000=JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP030006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001JEUYF
00800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPL0009JEP8000=JEP8000=JEP04
001JEUYFFUH40002FUH00`00FUIJEP05FUH30003FUH70006FUH400000eYF001JEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH9000;Ool300000eYF0000000200000eYF001JEP04FUH00`00
FUH00002000^Ool002ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000MJ
EP@000=JEP03001JEP0000<000EJEP03001JEP0000l00003FUH005YF00IJEP@000EJEP05001JEUYF
FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00UYF200037oo1P001UYF00<005YF00000P0015YF00D005YFFUIJEP00
02ioo`00;Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH0
1UYF00@005YFFUH000=JEP03001JEUYF009JEPD00005FUH005YFFUH00005FUH00`00FUIJEP07FUH0
1000FUIJEUYF10000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH00`00FUH000020004FUH@0004
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomoo`0/Ool002eoo`80
00EJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH01000FUIJEUYF60001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000AJEP800003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP8000=JEP8002eo
o`00;Goo0P001EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<0009JEP8002eoo`00;7oo00<005YF00001EYF00@005YFFUIJ
EP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF000000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002Ool4000]Ool002aoo`03001JEP0000EJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@0009oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200000eYF001JEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH40006
FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Woo0P00;Goo000/Ool01000FUIJEP0015YF0P001Goo
2@0015YF00<005YFFUH00UYF1`002Goo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00@005YF000000Moo`<002eoo`00;7oo00@005YFFUH000=JEP03001oogoo00ioo`T001Eoo`P000AJ
EP03001JEUYF00=JEPT000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP@000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00AJEP<000Moo`<00003FUH007oo02aoo`00;7oo00D005YFFUH005YF008001Aoo`D0
01Moo`04001JEUYF0003FUH:0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH200000eYF001J
EP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040008Ool20002FUH00`00FUH0000]Ool002ao
o`03001JEUYF008001Ioo`D001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEP8000=JEPH000AJEP03001JEUYF00IJEP<000AJEPD000Yoo`8000AJEP8002ioo`00
;7oo00@005YFFUH001Moo`D001Eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEP0000<000EJEPT000AJEP03001JEUYF00@000]oo`@00003FUH0
05YF00=JEP8002ioo`00;Goo00<005YF000067oo0`0057oo0P000UYF00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP<000=JEP03001JEUYF008000Aoo`L0
00Yoo`D000EJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P0000=JEP00Ool05Goo3`001goo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH005YF0005FUH00`00FUH000030002FUH2000<Ool90003FUH00`00FUIJEP04FUH00`00FUIJEP02
000`Ool002eoo`80009JEP03001oogoo00]oo`P000AJEP03001JEUYF00IJEP03001JEP0000<00003
Ool0000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol0
02eoo`04001JEUYFFUH30005Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH40002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00=7oo000]Ool20002FUH00`00FUIJEP0500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF1@000Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`00=Woo000]Ool20002FUH01000FUH000001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF60001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0027oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`00>Woo000]Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH:000;FUH0
0`00FUIJEP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000mOol002ioo`<0009JEP03001JEUYF00AJEP03001J
EUYF009JEP`000EJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00D0
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJEP03
001JEUYF009JEP8000mooaL0045oo`00;Woo00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF0P000UYF00<005YFFUH00UYF10000eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YF
FUH00UYF0P003Goo0P0000=JEP00FUH00P00Dgoo000]Ool20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP0000000UYF00<0
05YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF0P0037oo00H005YFFUIJEP00FUH2001COol002eo
o`8000AJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEPD0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJEP8000Yoo`8000AJEP04001J
EUYF001COol002aoo`03001JEP00009JEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP03001JEUYF008000Aoo`03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP8000Qoo`800003FUH005YF00=JEP04001JEUYF001COol002aoo`03001JEP000080
0003Ool0000000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP<000Io
o`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=oo`8000=JEP03001JEUYF00=JEP03001J
EP0005=oo`00;7oo00<005YF00001Goo0`0000=JEP00FUH01UYF00<005YFFUH015YF1@001UYF00<0
05YFFUH015YF0P0027oo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000
00=JEPH0009JEP03001JEUYF00=JEP8005Aoo`00;7oo0P002Goo0`001UYF00<005YFFUH01EYF0`00
1eYF00<005YFFUH010002Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000MJEP03001JEP00008000EJEP8005Aoo`00;7oo0`002goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`003Woo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF
00<005YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool200000eYF0000000=Ool@000COol20000
0eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03
FUH20002FUH00`00Oomoo`1COol002aoo`8000=JEP8002aoo`8000=JEP<0009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEPP000=JEP03001JEUYF00=JEP04001JEP00001FOol002eoo`06001JEUYFFUH0
05YF0`009Goo100000=JEP00FUH00UYF0P0000Aoo`00000000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP@0
00EJEP05001JEUYFFUH0001EOol002eoo`05001JEUYFFUH00004FUH3000LOol60005FUH01@00FUIJ
EUYF000017oo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF008000=JEP05001J
EUYFFUH0001EOol002ioo`04001JEUYF0005FUH00`00FUH00003000?Ool90004FUH00`00FUIJEP04
FUH01000FUIJEP0027oo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF009JEP8005Aoo`00;goo0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH015YF0`003Goo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF1P001UYF00<005YFFUH01EYF00@005YFFUIJEP800003Ool0000000=JEP8005Ao
o`00<Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0057oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF
2P000UYF1@001EYF00<005YFFUH01EYF00@005YF000000Eoo`800003FUH0000005Aoo`00<goo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
77oo8P0015YF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`002Goo0`00E7oo000fOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000cOol00`00FUH00005Ool20000
0eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04000<Ool3001DOol003Uoo`@0009J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Ioo`8000Qoo`D000AJEP03001JEUYF
00IJEP<000AJEPD000ioo`<00003FUH007oo05=oo`00?Goo5`00>Woo0`0037oo2@0015YF00<005YF
FUH010004Goo0P000UYF00<005YF0000E7oo002>Ool200000eYF001oo`0COol7000COol20004FUH2
001EOol008ioo`80009JEP8002Qoo`@00003FUH005YF00=JEP8005Eoo`00Sgoo00D005YFFUH005YF
00<0029oo`<000EJEP03001JEUYF009JEP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEPD001Uo
o`@00003FUH005YF00EJEP03001JEUYF008005Moo`00T7oo00<005YF00001EYF00@005YFFUIJEQT0
00EJEP03001JEUYF00AJEP<005Uoo`00TGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo002BOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00GGoo002DOol3
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000
Ggoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5001QOol009ao
o`T000AJEP03001JEUYF009JEPT006Ioo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59791 .76245 m .59306 .71156 L .56194 .71071 L p .707 .577 .707 r
F P
0 g
s
.59306 .71156 m .59791 .76245 L .62961 .7586 L p .707 .577 .707 r
F P
0 g
s
.62961 .7586 m .62476 .70771 L .59306 .71156 L p .707 .577 .707 r
F P
0 g
s
.62476 .70771 m .62961 .7586 L .65877 .75044 L p .707 .577 .707 r
F P
0 g
s
.65877 .75044 m .65392 .69955 L .62476 .70771 L p .707 .577 .707 r
F P
0 g
s
.56679 .7616 m .56194 .71071 L .53443 .70526 L p .707 .577 .707 r
F P
0 g
s
.56194 .71071 m .56679 .7616 L .59791 .76245 L p .707 .577 .707 r
F P
0 g
s
.65392 .69955 m .65877 .75044 L .68255 .73877 L p .707 .577 .707 r
F P
0 g
s
.68255 .73877 m .6777 .68788 L .65392 .69955 L p .707 .577 .707 r
F P
0 g
s
.53928 .75615 m .53443 .70526 L .51324 .69574 L p .707 .577 .707 r
F P
0 g
s
.53443 .70526 m .53928 .75615 L .56679 .7616 L p .707 .577 .707 r
F P
0 g
s
.6777 .68788 m .68255 .73877 L .69861 .72473 L p .707 .577 .707 r
F P
0 g
s
.69861 .72473 m .69377 .67384 L .6777 .68788 L p .707 .577 .707 r
F P
0 g
s
.60361 .8411 m .59825 .81035 L .56721 .81016 L p .707 .577 .707 r
F P
0 g
s
.59825 .81035 m .60361 .8411 L .63505 .83535 L p .707 .577 .707 r
F P
0 g
s
.63505 .83535 m .62969 .80459 L .59825 .81035 L p .707 .577 .707 r
F P
0 g
s
.62969 .80459 m .63505 .83535 L .66382 .82421 L p .707 .577 .707 r
F P
0 g
s
.66382 .82421 m .65846 .79346 L .62969 .80459 L p .707 .577 .707 r
F P
0 g
s
.51808 .74663 m .51324 .69574 L .50043 .68308 L p .707 .577 .707 r
F P
0 g
s
.51324 .69574 m .51808 .74663 L .53928 .75615 L p .707 .577 .707 r
F P
0 g
s
.59632 .87391 m .59534 .85621 L .56419 .85496 L p .707 .577 .707 r
F P
0 g
s
.59534 .85621 m .59632 .87391 L .6281 .87125 L p .707 .577 .707 r
F P
0 g
s
.6281 .87125 m .62713 .85356 L .59534 .85621 L p .707 .577 .707 r
F P
0 g
s
.62713 .85356 m .6281 .87125 L .65741 .86495 L p .707 .577 .707 r
F P
0 g
s
.65741 .86495 m .65643 .84725 L .62713 .85356 L p .707 .577 .707 r
F P
0 g
s
.57257 .84092 m .56721 .81016 L .53962 .80405 L p .707 .577 .707 r
F P
0 g
s
.56721 .81016 m .57257 .84092 L .60361 .8411 L p .707 .577 .707 r
F P
0 g
s
.65846 .79346 m .66382 .82421 L .6871 .80879 L p .707 .577 .707 r
F P
0 g
s
.6871 .80879 m .68174 .77803 L .65846 .79346 L p .707 .577 .707 r
F P
0 g
s
.56516 .87266 m .56419 .85496 L .53671 .84992 L p .707 .577 .707 r
F P
0 g
s
.56419 .85496 m .56516 .87266 L .59632 .87391 L p .707 .577 .707 r
F P
0 g
s
.69377 .67384 m .69861 .72473 L .70539 .70968 L p .707 .577 .707 r
F P
0 g
s
.70539 .70968 m .70055 .6588 L .69377 .67384 L p .707 .577 .707 r
F P
0 g
s
.65643 .84725 m .65741 .86495 L .68136 .85561 L p .707 .577 .707 r
F P
0 g
s
.68136 .85561 m .68038 .83792 L .65643 .84725 L p .707 .577 .707 r
F P
0 g
s
.53671 .84992 m .53769 .86762 L .56516 .87266 L p .707 .577 .707 r
F P
0 g
s
.54498 .83481 m .53962 .80405 L .51817 .79262 L p .707 .577 .707 r
F P
0 g
s
.53962 .80405 m .54498 .83481 L .57257 .84092 L p .707 .577 .707 r
F P
0 g
s
.68174 .77803 m .6871 .80879 L .70261 .79059 L p .707 .577 .707 r
F P
0 g
s
.70261 .79059 m .69725 .75983 L .68174 .77803 L p .707 .577 .707 r
F P
0 g
s
.53769 .86762 m .53671 .84992 L .51561 .84159 L p .707 .577 .707 r
F P
0 g
s
.50527 .73397 m .50043 .68308 L .49726 .66851 L p .707 .577 .707 r
F P
0 g
s
.50043 .68308 m .50527 .73397 L .51808 .74663 L p .707 .577 .707 r
F P
0 g
s
.51561 .84159 m .51658 .85928 L .53769 .86762 L p .707 .577 .707 r
F P
0 g
s
.68038 .83792 m .68136 .85561 L .69762 .84416 L p .707 .577 .707 r
F P
0 g
s
.69762 .84416 m .69664 .82646 L .68038 .83792 L p .707 .577 .707 r
F P
0 g
s
.70055 .6588 m .70539 .70968 L .70222 .69512 L p .707 .577 .707 r
F P
0 g
s
.70222 .69512 m .69738 .64423 L .70055 .6588 L p .707 .577 .707 r
F P
0 g
s
.52353 .82338 m .51817 .79262 L .50496 .77698 L p .707 .577 .707 r
F P
0 g
s
.51817 .79262 m .52353 .82338 L .54498 .83481 L p .707 .577 .707 r
F P
0 g
s
.69725 .75983 m .70261 .79059 L .70884 .77139 L p .707 .577 .707 r
F P
0 g
s
.70884 .77139 m .70348 .74063 L .69725 .75983 L p .707 .577 .707 r
F P
0 g
s
.51658 .85928 m .51561 .84159 L .50293 .83078 L p .707 .577 .707 r
F P
0 g
s
.49726 .66851 m .5021 .7194 L .50527 .73397 L p .707 .577 .707 r
F P
0 g
s
.50293 .83078 m .50391 .84847 L .51658 .85928 L p .707 .577 .707 r
F P
0 g
s
.5021 .7194 m .49726 .66851 L .50404 .65347 L p .707 .577 .707 r
F P
0 g
s
.69664 .82646 m .69762 .84416 L .70459 .83171 L p .707 .577 .707 r
F P
0 g
s
.70459 .83171 m .70362 .81401 L .69664 .82646 L p .707 .577 .707 r
F P
0 g
s
.50496 .77698 m .51032 .80774 L .52353 .82338 L p .707 .577 .707 r
F P
0 g
s
.51032 .80774 m .50496 .77698 L .50129 .75867 L p .708 .578 .707 r
F P
0 g
s
.69738 .64423 m .70222 .69512 L .68941 .68246 L p .707 .577 .707 r
F P
0 g
s
.68941 .68246 m .68457 .63157 L .69738 .64423 L p .707 .577 .707 r
F P
0 g
s
.70348 .74063 m .70884 .77139 L .70517 .75307 L p .708 .578 .707 r
F P
0 g
s
.70517 .75307 m .69981 .72232 L .70348 .74063 L p .708 .578 .707 r
F P
0 g
s
.48079 .81686 m .49636 .30616 L .45236 .30292 L p .707 .577 .707 r
F P
0 g
s
.50404 .65347 m .50888 .70436 L .5021 .7194 L p .707 .577 .707 r
F P
0 g
s
.50888 .70436 m .50404 .65347 L .5201 .63943 L p .707 .577 .707 r
F P
0 g
s
.50129 .75867 m .50665 .78942 L .51032 .80774 L p .708 .578 .707 r
F P
0 g
s
.50665 .78942 m .50129 .75867 L .50752 .73947 L p .707 .577 .707 r
F P
0 g
s
.50391 .84847 m .50293 .83078 L .49994 .81855 L p .707 .577 .707 r
F P
0 g
s
.49994 .81855 m .50092 .83625 L .50391 .84847 L p .707 .577 .707 r
F P
0 g
s
.50092 .83625 m .49994 .81855 L .50691 .8061 L p .707 .577 .707 r
F P
0 g
s
.5201 .63943 m .52495 .69032 L .50888 .70436 L p .707 .577 .707 r
F P
0 g
s
.50691 .8061 m .50789 .8238 L .50092 .83625 L p .707 .577 .707 r
F P
0 g
s
.50752 .73947 m .51288 .77022 L .50665 .78942 L p .707 .577 .707 r
F P
0 g
s
.51288 .77022 m .50752 .73947 L .52303 .72127 L p .707 .577 .707 r
F P
0 g
s
.50789 .8238 m .50691 .8061 L .52317 .79464 L p .707 .577 .707 r
F P
0 g
s
.52303 .72127 m .52839 .75202 L .51288 .77022 L p .707 .577 .707 r
F P
0 g
s
.52317 .79464 m .52415 .81234 L .50789 .8238 L p .707 .577 .707 r
F P
0 g
s
.52415 .81234 m .52317 .79464 L .54712 .78531 L p .707 .577 .707 r
F P
0 g
s
.54712 .78531 m .5481 .80301 L .52415 .81234 L p .707 .577 .707 r
F P
0 g
s
.49636 .30616 m .48079 .81686 L .52571 .81737 L p .707 .577 .707 r
F P
0 g
s
.52495 .69032 m .5201 .63943 L .54388 .62776 L p .707 .577 .707 r
F P
0 g
s
.54388 .62776 m .54873 .67865 L .52495 .69032 L p .707 .577 .707 r
F P
0 g
s
.52839 .75202 m .52303 .72127 L .54631 .70584 L p .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .54128 .30667 L .49636 .30616 L p .707 .577 .707 r
F P
0 g
s
.54873 .67865 m .54388 .62776 L .57304 .6196 L p .707 .577 .707 r
F P
0 g
s
.57304 .6196 m .57789 .67049 L .55413 .67713 L p .707 .577 .707 r
F P
0 g
s
.55413 .67713 m .54873 .67865 L p .55127 .67246 L .707 .577 .707 r
F P
0 g
s
.55127 .67246 m .57304 .6196 L .55413 .67713 L .707 .577 .707 r
F
.57643 .779 m .5774 .7967 L .56505 .79936 L p F P
0 g
s
.56505 .79936 m .5481 .80301 L p .56191 .7913 L .707 .577 .707 r
F P
0 g
s
.56191 .7913 m .57643 .779 L .56505 .79936 L .707 .577 .707 r
F
.58044 .72546 m .57508 .69471 L .58078 .69366 L p F P
0 g
s
.58078 .69366 m .60653 .68895 L p .58717 .71605 L .707 .577 .707 r
F P
0 g
s
.58044 .72546 m .58078 .69366 L .58717 .71605 L .707 .577 .707 r
F
.63586 .61659 m .64071 .66748 L .60959 .66664 L p F P
0 g
s
.60959 .66664 m .60474 .61575 L .63586 .61659 L p .707 .577 .707 r
F P
0 g
s
.60474 .61575 m .60959 .66664 L .57789 .67049 L p .707 .577 .707 r
F P
0 g
s
.63756 .68914 m .64292 .71989 L .61188 .71971 L p .707 .577 .707 r
F P
0 g
s
.61188 .71971 m .60653 .68895 L .63756 .68914 L p .707 .577 .707 r
F P
0 g
s
.60653 .68895 m .61188 .71971 L .58044 .72546 L p .707 .577 .707 r
F P
0 g
s
.63937 .7776 m .64034 .7953 L .60919 .79405 L p .707 .577 .707 r
F P
0 g
s
.60919 .79405 m .60821 .77635 L .63937 .7776 L p .707 .577 .707 r
F P
0 g
s
.5774 .7967 m .57643 .779 L .60821 .77635 L p .707 .577 .707 r
F P
0 g
s
.60821 .77635 m .60919 .79405 L .5774 .7967 L p .707 .577 .707 r
F P
0 g
s
.61663 .29957 m .60231 .76911 L p .62412 .80336 L .707 .577 .707 r
F P
0 g
s
.60231 .76911 m .60106 .81027 L .61304 .80668 L p .707 .577 .707 r
F P
0 g
s
.61304 .80668 m .62412 .80336 L p .60231 .76911 L .707 .577 .707 r
F P
0 g
s
.57508 .69471 m .58044 .72546 L .57208 .7287 L p .707 .577 .707 r
F P
0 g
s
.5481 .80301 m .54712 .78531 L .57643 .779 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .56744 .8055 L p .59819 .75169 L .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .56715 .8151 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56136 .71926 L .56984 .72673 L .707 .577 .707 r
F
.56136 .71926 m .57508 .69471 L .5723 .72616 L F
.56984 .72673 m .5723 .72616 L .57208 .7287 L F
.56136 .71926 m .5723 .72616 L .56984 .72673 L F
.56274 .72838 m .55073 .73117 L .52571 .81737 L F
.54631 .70584 m .55073 .73117 L p .52839 .75202 L F P
0 g
s
.5452 .74089 m .52839 .75202 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52818 .73641 m .52707 .77275 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52707 .77275 m .52571 .81737 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.55073 .73117 m .55167 .7366 L .5452 .74089 L p .707 .577 .707 r
F P
0 g
s
.55167 .7366 m .54631 .70584 L .57508 .69471 L p .707 .577 .707 r
F P
0 g
s
.58272 .3044 m .54128 .30667 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.56715 .8151 m .56984 .72673 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57789 .67049 m .57304 .6196 L .60474 .61575 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .58272 .3044 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.54128 .30667 m .52818 .73641 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57208 .7287 m .55167 .7366 L p .5553 .73011 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56984 .72673 L .57208 .7287 L .707 .577 .707 r
F
.57054 .70402 m .56984 .72673 L p .59889 .75046 L F P
0 g
s
.59889 .75046 m .56984 .72673 L .59819 .75169 L .707 .577 .707 r
F
.56744 .8055 m .56715 .8151 L p .5694 .81052 L F P
0 g
s
.59889 .75046 m .56744 .8055 L .5694 .81052 L .707 .577 .707 r
F
.56715 .8151 m .60106 .81027 L p .59889 .75046 L F P
0 g
s
.58272 .3044 m .57054 .70402 L p .59889 .75046 L .707 .577 .707 r
F P
0 g
s
.43679 .81363 m .45236 .30292 L .41358 .29728 L p .707 .577 .707 r
F P
0 g
s
.45236 .30292 m .43679 .81363 L .48079 .81686 L p .707 .577 .707 r
F P
0 g
s
.70362 .81401 m .70459 .83171 L .7016 .81948 L p .707 .577 .707 r
F P
0 g
s
.7016 .81948 m .70062 .80178 L .70362 .81401 L p .707 .577 .707 r
F P
0 g
s
.2549 .72563 m .25005 .67474 L .21893 .6739 L p .707 .577 .707 r
F P
0 g
s
.25005 .67474 m .2549 .72563 L .2866 .72179 L p .707 .577 .707 r
F P
0 g
s
.2866 .72179 m .28175 .6709 L .25005 .67474 L p .707 .577 .707 r
F P
0 g
s
.28175 .6709 m .2866 .72179 L .31576 .71363 L p .707 .577 .707 r
F P
0 g
s
.31576 .71363 m .31091 .66274 L .28175 .6709 L p .707 .577 .707 r
F P
0 g
s
.68457 .63157 m .68941 .68246 L .66822 .67293 L p .707 .577 .707 r
F P
0 g
s
.66822 .67293 m .66337 .62204 L .68457 .63157 L p .707 .577 .707 r
F P
0 g
s
.69981 .72232 m .70517 .75307 L .69196 .73743 L p .707 .577 .707 r
F P
0 g
s
.69196 .73743 m .68661 .70668 L .69981 .72232 L p .707 .577 .707 r
F P
0 g
s
.60106 .81027 m .61663 .29957 L .58272 .3044 L p .707 .577 .707 r
F P
0 g
s
.22378 .72479 m .21893 .6739 L .19142 .66845 L p .707 .577 .707 r
F P
0 g
s
.21893 .6739 m .22378 .72479 L .2549 .72563 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31091 .66274 m .31576 .71363 L .33954 .70195 L p .707 .577 .707 r
F P
0 g
s
.33954 .70195 m .33469 .65106 L .31091 .66274 L p .707 .577 .707 r
F P
0 g
s
.39802 .80798 m .41358 .29728 L .38383 .28977 L p .707 .577 .707 r
F P
0 g
s
.41358 .29728 m .39802 .80798 L .43679 .81363 L p .707 .577 .707 r
F P
0 g
s
.19627 .71934 m .19142 .66845 L .17023 .65893 L p .707 .577 .707 r
F P
0 g
s
.19142 .66845 m .19627 .71934 L .22378 .72479 L p .707 .577 .707 r
F P
0 g
s
.66337 .62204 m .66822 .67293 L .64071 .66748 L p .707 .577 .707 r
F P
0 g
s
.64071 .66748 m .63586 .61659 L .66337 .62204 L p .707 .577 .707 r
F P
0 g
s
.70062 .80178 m .7016 .81948 L .68893 .80867 L p .707 .577 .707 r
F P
0 g
s
.68893 .80867 m .68795 .79097 L .70062 .80178 L p .707 .577 .707 r
F P
0 g
s
.68661 .70668 m .69196 .73743 L .67051 .726 L p .707 .577 .707 r
F P
0 g
s
.67051 .726 m .66516 .69524 L .68661 .70668 L p .707 .577 .707 r
F P
0 g
s
.33469 .65106 m .33954 .70195 L .35561 .68791 L p .707 .577 .707 r
F P
0 g
s
.35561 .68791 m .35076 .63702 L .33469 .65106 L p .707 .577 .707 r
F P
0 g
s
.62412 .80336 m .63968 .29266 L .61663 .29957 L p .707 .577 .707 r
F P
0 g
s
.2606 .80429 m .25524 .77353 L .2242 .77335 L p .707 .577 .707 r
F P
0 g
s
.25524 .77353 m .2606 .80429 L .29204 .79853 L p .707 .577 .707 r
F P
0 g
s
.29204 .79853 m .28668 .76778 L .25524 .77353 L p .707 .577 .707 r
F P
0 g
s
.28668 .76778 m .29204 .79853 L .32081 .7874 L p .707 .577 .707 r
F P
0 g
s
.32081 .7874 m .31545 .75664 L .28668 .76778 L p .707 .577 .707 r
F P
0 g
s
.17508 .70982 m .17023 .65893 L .15742 .64626 L p .707 .577 .707 r
F P
0 g
s
.17023 .65893 m .17508 .70982 L .19627 .71934 L p .707 .577 .707 r
F P
0 g
s
.25331 .83709 m .25233 .8194 L .22118 .81814 L p .707 .577 .707 r
F P
0 g
s
.25233 .8194 m .25331 .83709 L .2851 .83444 L p .707 .577 .707 r
F P
0 g
s
.2851 .83444 m .28412 .81674 L .25233 .8194 L p .707 .577 .707 r
F P
0 g
s
.28412 .81674 m .2851 .83444 L .3144 .82813 L p .707 .577 .707 r
F P
0 g
s
.3144 .82813 m .31342 .81044 L .28412 .81674 L p .707 .577 .707 r
F P
0 g
s
.22956 .8041 m .2242 .77335 L .19661 .76724 L p .707 .577 .707 r
F P
0 g
s
.2242 .77335 m .22956 .8041 L .2606 .80429 L p .707 .577 .707 r
F P
0 g
s
.36827 .80047 m .38383 .28977 L .36602 .28114 L p .707 .577 .707 r
F P
0 g
s
.38383 .28977 m .36827 .80047 L .39802 .80798 L p .707 .577 .707 r
F P
0 g
s
.31545 .75664 m .32081 .7874 L .34409 .77197 L p .707 .577 .707 r
F P
0 g
s
.34409 .77197 m .33873 .74122 L .31545 .75664 L p .707 .577 .707 r
F P
0 g
s
.66516 .69524 m .67051 .726 L .64292 .71989 L p .707 .577 .707 r
F P
0 g
s
.64292 .71989 m .63756 .68914 L .66516 .69524 L p .707 .577 .707 r
F P
0 g
s
.22216 .83584 m .22118 .81814 L .1937 .8131 L p .707 .577 .707 r
F P
0 g
s
.22118 .81814 m .22216 .83584 L .25331 .83709 L p .707 .577 .707 r
F P
0 g
s
.35076 .63702 m .35561 .68791 L .36238 .67287 L p .707 .577 .707 r
F P
0 g
s
.36238 .67287 m .35754 .62198 L .35076 .63702 L p .707 .577 .707 r
F P
0 g
s
.68795 .79097 m .68893 .80867 L .66782 .80034 L p .707 .577 .707 r
F P
0 g
s
.66782 .80034 m .66684 .78264 L .68795 .79097 L p .707 .577 .707 r
F P
0 g
s
.31342 .81044 m .3144 .82813 L .33835 .8188 L p .707 .577 .707 r
F P
0 g
s
.33835 .8188 m .33738 .8011 L .31342 .81044 L p .707 .577 .707 r
F P
0 g
s
.1937 .8131 m .19468 .8308 L .22216 .83584 L p .707 .577 .707 r
F P
0 g
s
.20197 .79799 m .19661 .76724 L .17516 .75581 L p .707 .577 .707 r
F P
0 g
s
.19661 .76724 m .20197 .79799 L .22956 .8041 L p .707 .577 .707 r
F P
0 g
s
.33873 .74122 m .34409 .77197 L .3596 .75377 L p .707 .577 .707 r
F P
0 g
s
.3596 .75377 m .35424 .72302 L .33873 .74122 L p .707 .577 .707 r
F P
0 g
s
.19468 .8308 m .1937 .8131 L .1726 .80477 L p .707 .577 .707 r
F P
0 g
s
.16227 .69715 m .15742 .64626 L .15425 .6317 L p .707 .577 .707 r
F P
0 g
s
.15742 .64626 m .16227 .69715 L .17508 .70982 L p .707 .577 .707 r
F P
0 g
s
.63968 .29266 m .62412 .80336 L .63406 .79504 L p .707 .577 .707 r
F P
0 g
s
.63406 .79504 m .64963 .28434 L .63968 .29266 L p .707 .577 .707 r
F P
0 g
s
.1726 .80477 m .17357 .82247 L .19468 .8308 L p .707 .577 .707 r
F P
0 g
s
.33738 .8011 m .33835 .8188 L .35461 .80734 L p .707 .577 .707 r
F P
0 g
s
.35461 .80734 m .35363 .78965 L .33738 .8011 L p .707 .577 .707 r
F P
0 g
s
.66684 .78264 m .66782 .80034 L .64034 .7953 L p .707 .577 .707 r
F P
0 g
s
.64034 .7953 m .63937 .7776 L .66684 .78264 L p .707 .577 .707 r
F P
0 g
s
.35754 .62198 m .36238 .67287 L .35921 .6583 L p .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35754 .62198 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35437 .60741 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35805 .64604 L p .3464 .64564 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35921 .6583 L .35684 .65596 L p .707 .577 .707 r
F P
0 g
s
.35684 .65596 m .3464 .64564 L p .35805 .64604 L .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .3568 .6855 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34895 .70062 m .34875 .69947 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34875 .69947 m .3436 .66986 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.35424 .72302 m .3596 .75377 L .36583 .73457 L p .707 .577 .707 r
F P
0 g
s
.36583 .73457 m .36047 .70382 L .35424 .72302 L p .707 .577 .707 r
F P
0 g
s
.35363 .78965 m .35461 .80734 L .36158 .79489 L p .707 .577 .707 r
F P
0 g
s
.36158 .79489 m .36061 .7772 L .35363 .78965 L p .707 .577 .707 r
F P
0 g
s
.36047 .70382 m .36583 .73457 L .36318 .72135 L p .708 .578 .707 r
F P
0 g
s
.36198 .71491 m .36047 .70382 L .36318 .72135 L .708 .578 .707 r
F
.35761 .76497 m .35859 .78267 L .35126 .77641 L p .707 .577 .707 r
F P
0 g
s
.35126 .77641 m .34592 .77186 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.35198 .76829 m .35761 .76497 L .35126 .77641 L .707 .577 .707 r
F
.3568 .6855 m .35684 .6857 L p .34895 .70062 L F P
0 g
s
.34592 .77186 m .34494 .75416 L .35264 .76073 L p .707 .577 .707 r
F P
0 g
s
.35264 .76073 m .35761 .76497 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.34592 .77186 m .35264 .76073 L .35198 .76829 L .707 .577 .707 r
F
.35279 .70516 m .34895 .70062 L p .35684 .6857 L F P
0 g
s
.3464 .64564 m .34156 .59475 L .35437 .60741 L p .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .34895 .70062 L .34285 .69736 L p .707 .577 .707 r
F P
0 g
s
.34285 .69736 m .32751 .68918 L p .34035 .67377 L .707 .577 .707 r
F P
0 g
s
.34035 .67377 m .3436 .66986 L .34285 .69736 L .707 .577 .707 r
F
.36188 .27223 m .34631 .78293 L .34998 .79084 L p F P
0 g
s
.35063 .78347 m .36188 .27223 L .34998 .79084 L .707 .577 .707 r
F
.35063 .78347 m .35313 .70356 L .35231 .70751 L F
.35074 .78224 m .35384 .68076 L p .35063 .78347 L F P
0 g
s
.35314 .70347 m .35045 .79184 L p .36482 .73015 L .707 .577 .707 r
F P
0 g
s
.36121 .71083 m .35314 .70347 L .36482 .73015 L .707 .577 .707 r
F
.35684 .6857 m .36216 .71626 L .35279 .70516 L p F P
0 g
s
.3568 .6855 m .36047 .70382 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36121 .71083 m .3568 .6855 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.35921 .6583 m .35805 .64604 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .35314 .70347 L p .3679 .71693 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .36188 .27223 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.35522 .63529 m .36602 .28114 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.36188 .27223 m .37183 .26391 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34631 .78293 m .34757 .74177 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34757 .74177 m .36188 .27223 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34998 .79084 m .35045 .79184 L p .35063 .78347 L .707 .577 .707 r
F P
0 g
s
.35231 .70751 m .35384 .68076 L .35269 .69026 L .707 .577 .707 r
F
.35313 .70356 m .35384 .68076 L .35231 .70751 L F
.35045 .79184 m .35074 .78224 L p .35063 .78347 L F P
0 g
s
.3679 .71693 m .36121 .71083 L .36482 .73015 L .707 .577 .707 r
F
.36216 .71626 m .36121 .71083 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36318 .72135 m .36216 .71626 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36061 .7772 m .36158 .79489 L .35859 .78267 L p .707 .577 .707 r
F P
0 g
s
.35859 .78267 m .35761 .76497 L .36061 .7772 L p .707 .577 .707 r
F P
0 g
s
.35045 .79184 m .36827 .80047 L p .36804 .74734 L .707 .577 .707 r
F P
0 g
s
.36804 .74734 m .3679 .71693 L .36482 .73015 L .707 .577 .707 r
F
.36804 .74734 m .36482 .73015 L .35045 .79184 L F
.35269 .69026 m .35522 .63529 L .354 .63062 L F
.35384 .68076 m .35522 .63529 L p .35269 .69026 L F P
0 g
s
.18052 .78656 m .17516 .75581 L .16195 .74017 L p .707 .577 .707 r
F P
0 g
s
.17516 .75581 m .18052 .78656 L .20197 .79799 L p .707 .577 .707 r
F P
0 g
s
.17357 .82247 m .1726 .80477 L .15993 .79396 L p .707 .577 .707 r
F P
0 g
s
.15425 .6317 m .15909 .68259 L .16227 .69715 L p .707 .577 .707 r
F P
0 g
s
.15993 .79396 m .1609 .81166 L .17357 .82247 L p .707 .577 .707 r
F P
0 g
s
.15909 .68259 m .15425 .6317 L .16103 .61666 L p .707 .577 .707 r
F P
0 g
s
.16195 .74017 m .16731 .77092 L .18052 .78656 L p .707 .577 .707 r
F P
0 g
s
.16731 .77092 m .16195 .74017 L .15828 .72185 L p .708 .578 .707 r
F P
0 g
s
.64963 .28434 m .63406 .79504 L .62992 .78613 L p .707 .577 .707 r
F P
0 g
s
.62992 .78613 m .64549 .27543 L .64963 .28434 L p .707 .577 .707 r
F P
0 g
s
.1609 .81166 m .15993 .79396 L .15693 .78173 L p .707 .577 .707 r
F P
0 g
s
.16103 .61666 m .16587 .66755 L .15909 .68259 L p .707 .577 .707 r
F P
0 g
s
.15693 .78173 m .15791 .79943 L .1609 .81166 L p .707 .577 .707 r
F P
0 g
s
.16587 .66755 m .16103 .61666 L .17709 .60261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15828 .72185 m .16364 .75261 L .16731 .77092 L p .708 .578 .707 r
F P
0 g
s
.16364 .75261 m .15828 .72185 L .16451 .70265 L p .707 .577 .707 r
F P
0 g
s
.34156 .59475 m .3464 .64564 L .32521 .63612 L p .707 .577 .707 r
F P
0 g
s
.32521 .63612 m .32036 .58523 L .34156 .59475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15791 .79943 m .15693 .78173 L .1639 .76928 L p .707 .577 .707 r
F P
0 g
s
.17709 .60261 m .18194 .6535 L .16587 .66755 L p .707 .577 .707 r
F P
0 g
s
.18194 .6535 m .17709 .60261 L .20087 .59094 L p .707 .577 .707 r
F P
0 g
s
.1639 .76928 m .16488 .78698 L .15791 .79943 L p .707 .577 .707 r
F P
0 g
s
.16451 .70265 m .16987 .73341 L .16364 .75261 L p .707 .577 .707 r
F P
0 g
s
.32036 .58523 m .32521 .63612 L .2977 .63067 L p .707 .577 .707 r
F P
0 g
s
.2977 .63067 m .29286 .57978 L .32036 .58523 L p .707 .577 .707 r
F P
0 g
s
.16987 .73341 m .16451 .70265 L .18002 .68445 L p .707 .577 .707 r
F P
0 g
s
.64549 .27543 m .62992 .78613 L .61211 .7775 L p .707 .577 .707 r
F P
0 g
s
.61211 .7775 m .62768 .2668 L .64549 .27543 L p .707 .577 .707 r
F P
0 g
s
.32751 .68918 m .32215 .65843 L .3436 .66986 L p .707 .577 .707 r
F P
0 g
s
.20572 .64183 m .20087 .59094 L .23004 .58278 L p .707 .577 .707 r
F P
0 g
s
.20087 .59094 m .20572 .64183 L .18194 .6535 L p .707 .577 .707 r
F P
0 g
s
.29286 .57978 m .2977 .63067 L .26658 .62983 L p .707 .577 .707 r
F P
0 g
s
.26658 .62983 m .26173 .57894 L .29286 .57978 L p .707 .577 .707 r
F P
0 g
s
.16488 .78698 m .1639 .76928 L .18016 .75783 L p .707 .577 .707 r
F P
0 g
s
.35626 .77461 m .37183 .26391 L .39488 .257 L p .707 .577 .707 r
F P
0 g
s
.37183 .26391 m .35626 .77461 L .34631 .78293 L p .707 .577 .707 r
F P
0 g
s
.23488 .63367 m .23004 .58278 L .26173 .57894 L p .707 .577 .707 r
F P
0 g
s
.23004 .58278 m .23488 .63367 L .20572 .64183 L p .707 .577 .707 r
F P
0 g
s
.26173 .57894 m .26658 .62983 L .23488 .63367 L p .707 .577 .707 r
F P
0 g
s
.18002 .68445 m .18538 .71521 L .16987 .73341 L p .707 .577 .707 r
F P
0 g
s
.18538 .71521 m .18002 .68445 L .20331 .66903 L p .707 .577 .707 r
F P
0 g
s
.32215 .65843 m .32751 .68918 L .29991 .68308 L p .707 .577 .707 r
F P
0 g
s
.29991 .68308 m .29455 .65232 L .32215 .65843 L p .707 .577 .707 r
F P
0 g
s
.18016 .75783 m .18114 .77553 L .16488 .78698 L p .707 .577 .707 r
F P
0 g
s
.34494 .75416 m .34592 .77186 L .32481 .76353 L p .707 .577 .707 r
F P
0 g
s
.32481 .76353 m .32383 .74583 L .34494 .75416 L p .707 .577 .707 r
F P
0 g
s
.20866 .69978 m .20331 .66903 L .23207 .65789 L p .707 .577 .707 r
F P
0 g
s
.20331 .66903 m .20866 .69978 L .18538 .71521 L p .707 .577 .707 r
F P
0 g
s
.29455 .65232 m .29991 .68308 L .26887 .68289 L p .707 .577 .707 r
F P
0 g
s
.26887 .68289 m .26352 .65214 L .29455 .65232 L p .707 .577 .707 r
F P
0 g
s
.62768 .2668 m .61211 .7775 L .58236 .76999 L p .707 .577 .707 r
F P
0 g
s
.58236 .76999 m .59792 .25929 L .62768 .2668 L p .707 .577 .707 r
F P
0 g
s
.18114 .77553 m .18016 .75783 L .20411 .74849 L p .707 .577 .707 r
F P
0 g
s
.73511 .68302 m .73027 .63213 L .69914 .63129 L p .707 .577 .707 r
F P
0 g
s
.73027 .63213 m .73511 .68302 L .76681 .67918 L p .707 .577 .707 r
F P
0 g
s
.76681 .67918 m .76196 .62829 L .73027 .63213 L p .707 .577 .707 r
F P
0 g
s
.76196 .62829 m .76681 .67918 L .79598 .67102 L p .707 .577 .707 r
F P
0 g
s
.79598 .67102 m .79113 .62013 L .76196 .62829 L p .707 .577 .707 r
F P
0 g
s
.23743 .68865 m .23207 .65789 L .26352 .65214 L p .707 .577 .707 r
F P
0 g
s
.23207 .65789 m .23743 .68865 L .20866 .69978 L p .707 .577 .707 r
F P
0 g
s
.26352 .65214 m .26887 .68289 L .23743 .68865 L p .707 .577 .707 r
F P
0 g
s
.70399 .68218 m .69914 .63129 L .67164 .62584 L p .707 .577 .707 r
F P
0 g
s
.69914 .63129 m .70399 .68218 L .73511 .68302 L p .707 .577 .707 r
F P
0 g
s
.20411 .74849 m .20509 .76619 L .18114 .77553 L p .707 .577 .707 r
F P
0 g
s
.32383 .74583 m .32481 .76353 L .29733 .75849 L p .707 .577 .707 r
F P
0 g
s
.29733 .75849 m .29636 .74079 L .32383 .74583 L p .707 .577 .707 r
F P
0 g
s
.79113 .62013 m .79598 .67102 L .81975 .65935 L p .707 .577 .707 r
F P
0 g
s
.81975 .65935 m .81491 .60846 L .79113 .62013 L p .707 .577 .707 r
F P
0 g
s
.39488 .257 m .37931 .7677 L .35626 .77461 L p .707 .577 .707 r
F P
0 g
s
.37931 .7677 m .39488 .257 L .42879 .25217 L p .707 .577 .707 r
F P
0 g
s
.20509 .76619 m .20411 .74849 L .23342 .74219 L p .707 .577 .707 r
F P
0 g
s
.67648 .67673 m .67164 .62584 L .65044 .61632 L p .707 .577 .707 r
F P
0 g
s
.67164 .62584 m .67648 .67673 L .70399 .68218 L p .707 .577 .707 r
F P
0 g
s
.29636 .74079 m .29733 .75849 L .26618 .75723 L p .707 .577 .707 r
F P
0 g
s
.26618 .75723 m .2652 .73953 L .29636 .74079 L p .707 .577 .707 r
F P
0 g
s
.23342 .74219 m .23439 .75989 L .20509 .76619 L p .707 .577 .707 r
F P
0 g
s
.81491 .60846 m .81975 .65935 L .83582 .6453 L p .707 .577 .707 r
F P
0 g
s
.83582 .6453 m .83097 .59441 L .81491 .60846 L p .707 .577 .707 r
F P
0 g
s
.23439 .75989 m .23342 .74219 L .2652 .73953 L p .707 .577 .707 r
F P
0 g
s
.2652 .73953 m .26618 .75723 L .23439 .75989 L p .707 .577 .707 r
F P
0 g
s
.59792 .25929 m .58236 .76999 L .54359 .76435 L p .707 .577 .707 r
F P
0 g
s
.54359 .76435 m .55915 .25364 L .59792 .25929 L p .707 .577 .707 r
F P
0 g
s
.74081 .74406 m .73545 .7133 L .70441 .71312 L p .707 .577 .707 r
F P
0 g
s
.73545 .7133 m .74081 .74406 L .77225 .7383 L p .707 .577 .707 r
F P
0 g
s
.77225 .7383 m .76689 .70754 L .73545 .7133 L p .707 .577 .707 r
F P
0 g
s
.76689 .70754 m .77225 .7383 L .80102 .72717 L p .707 .577 .707 r
F P
0 g
s
.80102 .72717 m .79566 .69641 L .76689 .70754 L p .707 .577 .707 r
F P
0 g
s
.73352 .76261 m .73255 .74491 L .70139 .74366 L p .707 .577 .707 r
F P
0 g
s
.73255 .74491 m .73352 .76261 L .76531 .75996 L p .707 .577 .707 r
F P
0 g
s
.76531 .75996 m .76433 .74226 L .73255 .74491 L p .707 .577 .707 r
F P
0 g
s
.76433 .74226 m .76531 .75996 L .79461 .75365 L p .707 .577 .707 r
F P
0 g
s
.79461 .75365 m .79364 .73595 L .76433 .74226 L p .707 .577 .707 r
F P
0 g
s
.41322 .76287 m .42879 .25217 L .47023 .2499 L p .707 .577 .707 r
F P
0 g
s
.42879 .25217 m .41322 .76287 L .37931 .7677 L p .707 .577 .707 r
F P
0 g
s
.70977 .74387 m .70441 .71312 L .67682 .70701 L p .707 .577 .707 r
F P
0 g
s
.70441 .71312 m .70977 .74387 L .74081 .74406 L p .707 .577 .707 r
F P
0 g
s
.70237 .76136 m .70139 .74366 L .67392 .73862 L p .707 .577 .707 r
F P
0 g
s
.70139 .74366 m .70237 .76136 L .73352 .76261 L p .707 .577 .707 r
F P
0 g
s
.65529 .66721 m .65044 .61632 L .63763 .60365 L p .707 .577 .707 r
F P
0 g
s
.65044 .61632 m .65529 .66721 L .67648 .67673 L p .707 .577 .707 r
F P
0 g
s
.79566 .69641 m .80102 .72717 L .8243 .71174 L p .707 .577 .707 r
F P
0 g
s
.8243 .71174 m .81894 .68099 L .79566 .69641 L p .707 .577 .707 r
F P
0 g
s
.79364 .73595 m .79461 .75365 L .81857 .74432 L p .707 .577 .707 r
F P
0 g
s
.81857 .74432 m .81759 .72662 L .79364 .73595 L p .707 .577 .707 r
F P
0 g
s
.67392 .73862 m .67489 .75632 L .70237 .76136 L p .707 .577 .707 r
F P
0 g
s
.83097 .59441 m .83582 .6453 L .8426 .63026 L p .707 .577 .707 r
F P
0 g
s
.8426 .63026 m .83775 .57937 L .83097 .59441 L p .707 .577 .707 r
F P
0 g
s
.55915 .25364 m .54359 .76435 L .49959 .76111 L p .707 .577 .707 r
F P
0 g
s
.49959 .76111 m .51515 .2504 L .55915 .25364 L p .707 .577 .707 r
F P
0 g
s
.68218 .73776 m .67682 .70701 L .65537 .69558 L p .707 .577 .707 r
F P
0 g
s
.67682 .70701 m .68218 .73776 L .70977 .74387 L p .707 .577 .707 r
F P
0 g
s
.67489 .75632 m .67392 .73862 L .65281 .73029 L p .707 .577 .707 r
F P
0 g
s
.45467 .7606 m .47023 .2499 L .51515 .2504 L p .707 .577 .707 r
F P
0 g
s
.47023 .2499 m .45467 .7606 L .41322 .76287 L p .707 .577 .707 r
F P
0 g
s
.81894 .68099 m .8243 .71174 L .83982 .69354 L p .707 .577 .707 r
F P
0 g
s
.83982 .69354 m .83446 .66279 L .81894 .68099 L p .707 .577 .707 r
F P
0 g
s
.51515 .2504 m .49959 .76111 L .45467 .7606 L p .707 .577 .707 r
F P
0 g
s
.65281 .73029 m .65379 .74799 L .67489 .75632 L p .707 .577 .707 r
F P
0 g
s
.81759 .72662 m .81857 .74432 L .83482 .73286 L p .707 .577 .707 r
F P
0 g
s
.83482 .73286 m .83385 .71517 L .81759 .72662 L p .707 .577 .707 r
F P
0 g
s
.64248 .65454 m .63763 .60365 L .63446 .58909 L p .707 .577 .707 r
F P
0 g
s
.63763 .60365 m .64248 .65454 L .65529 .66721 L p .707 .577 .707 r
F P
0 g
s
.66073 .72633 m .65537 .69558 L .64217 .67994 L p .707 .577 .707 r
F P
0 g
s
.65537 .69558 m .66073 .72633 L .68218 .73776 L p .707 .577 .707 r
F P
0 g
s
.83775 .57937 m .8426 .63026 L .83943 .6157 L p .707 .577 .707 r
F P
0 g
s
.83943 .6157 m .83458 .56481 L .83775 .57937 L p .707 .577 .707 r
F P
0 g
s
.83446 .66279 m .83982 .69354 L .84604 .67434 L p .707 .577 .707 r
F P
0 g
s
.84604 .67434 m .84068 .64359 L .83446 .66279 L p .707 .577 .707 r
F P
0 g
s
.65379 .74799 m .65281 .73029 L .64014 .71948 L p .707 .577 .707 r
F P
0 g
s
.64014 .71948 m .64112 .73718 L .65379 .74799 L p .707 .577 .707 r
F P
0 g
s
.83385 .71517 m .83482 .73286 L .8418 .72041 L p .707 .577 .707 r
F P
0 g
s
.8418 .72041 m .84082 .70272 L .83385 .71517 L p .707 .577 .707 r
F P
0 g
s
.63446 .58909 m .63931 .63998 L .64248 .65454 L p .707 .577 .707 r
F P
0 g
s
.63931 .63998 m .63446 .58909 L .64124 .57405 L p .707 .577 .707 r
F P
0 g
s
.64217 .67994 m .64753 .71069 L .66073 .72633 L p .707 .577 .707 r
F P
0 g
s
.64753 .71069 m .64217 .67994 L .6385 .66162 L p .708 .578 .707 r
F P
0 g
s
.84068 .64359 m .84604 .67434 L .84237 .65603 L p .708 .578 .707 r
F P
0 g
s
.84237 .65603 m .83702 .62527 L .84068 .64359 L p .708 .578 .707 r
F P
0 g
s
.83458 .56481 m .83943 .6157 L .82662 .60303 L p .707 .577 .707 r
F P
0 g
s
.82662 .60303 m .82177 .55214 L .83458 .56481 L p .707 .577 .707 r
F P
0 g
s
.64112 .73718 m .64014 .71948 L .63714 .70725 L p .707 .577 .707 r
F P
0 g
s
.63714 .70725 m .63812 .72495 L .64112 .73718 L p .707 .577 .707 r
F P
0 g
s
.84082 .70272 m .8418 .72041 L .8388 .70819 L p .707 .577 .707 r
F P
0 g
s
.8388 .70819 m .83783 .69049 L .84082 .70272 L p .707 .577 .707 r
F P
0 g
s
.64124 .57405 m .64609 .62494 L .63931 .63998 L p .707 .577 .707 r
F P
0 g
s
.6385 .66162 m .64386 .69237 L .64753 .71069 L p .708 .578 .707 r
F P
0 g
s
.64609 .62494 m .64124 .57405 L .65731 .56 L p .707 .577 .707 r
F P
0 g
s
.64386 .69237 m .6385 .66162 L .64473 .64242 L p .707 .577 .707 r
F P
0 g
s
.3921 .64621 m .38726 .59532 L .35613 .59448 L p .707 .577 .707 r
F P
0 g
s
.38726 .59532 m .3921 .64621 L .4238 .64236 L p .707 .577 .707 r
F P
0 g
s
.4238 .64236 m .41895 .59147 L .38726 .59532 L p .707 .577 .707 r
F P
0 g
s
.83702 .62527 m .84237 .65603 L .82917 .64039 L p .707 .577 .707 r
F P
0 g
s
.82917 .64039 m .82381 .60963 L .83702 .62527 L p .707 .577 .707 r
F P
0 g
s
.41895 .59147 m .4238 .64236 L .45297 .6342 L p .707 .577 .707 r
F P
0 g
s
.45297 .6342 m .44812 .58331 L .41895 .59147 L p .707 .577 .707 r
F P
0 g
s
.82177 .55214 m .82662 .60303 L .80542 .59351 L p .707 .577 .707 r
F P
0 g
s
.80542 .59351 m .80058 .54262 L .82177 .55214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63812 .72495 m .63714 .70725 L .64412 .6948 L p .707 .577 .707 r
F P
0 g
s
.36098 .64537 m .35613 .59448 L .32863 .58903 L p .707 .577 .707 r
F P
0 g
s
.35613 .59448 m .36098 .64537 L .3921 .64621 L p .707 .577 .707 r
F P
0 g
s
.44812 .58331 m .45297 .6342 L .47674 .62253 L p .707 .577 .707 r
F P
0 g
s
.47674 .62253 m .4719 .57164 L .44812 .58331 L p .707 .577 .707 r
F P
0 g
s
.64412 .6948 m .64509 .7125 L .63812 .72495 L p .707 .577 .707 r
F P
0 g
s
.65731 .56 m .66215 .6109 L .64609 .62494 L p .707 .577 .707 r
F P
0 g
s
.66215 .6109 m .65731 .56 L .68108 .54833 L p .707 .577 .707 r
F P
0 g
s
.64473 .64242 m .65008 .67318 L .64386 .69237 L p .707 .577 .707 r
F P
0 g
s
.83783 .69049 m .8388 .70819 L .82613 .69738 L p .707 .577 .707 r
F P
0 g
s
.82613 .69738 m .82515 .67968 L .83783 .69049 L p .707 .577 .707 r
F P
0 g
s
.65008 .67318 m .64473 .64242 L .66024 .62422 L p .707 .577 .707 r
F P
0 g
s
.33347 .63992 m .32863 .58903 L .30743 .5795 L p .707 .577 .707 r
F P
0 g
s
.32863 .58903 m .33347 .63992 L .36098 .64537 L p .707 .577 .707 r
F P
0 g
s
.82381 .60963 m .82917 .64039 L .80772 .62895 L p .707 .577 .707 r
F P
0 g
s
.80772 .62895 m .80236 .5982 L .82381 .60963 L p .707 .577 .707 r
F P
0 g
s
.80058 .54262 m .80542 .59351 L .77792 .58806 L p .707 .577 .707 r
F P
0 g
s
.77792 .58806 m .77307 .53717 L .80058 .54262 L p .707 .577 .707 r
F P
0 g
s
.4719 .57164 m .47674 .62253 L .49281 .60849 L p .707 .577 .707 r
F P
0 g
s
.49281 .60849 m .48796 .5576 L .4719 .57164 L p .707 .577 .707 r
F P
0 g
s
.64509 .7125 m .64412 .6948 L .66037 .68335 L p .707 .577 .707 r
F P
0 g
s
.3978 .70724 m .39244 .67649 L .3614 .6763 L p .707 .577 .707 r
F P
0 g
s
.39244 .67649 m .3978 .70724 L .42924 .70148 L p .707 .577 .707 r
F P
0 g
s
.42924 .70148 m .42388 .67073 L .39244 .67649 L p .707 .577 .707 r
F P
0 g
s
.68593 .59922 m .68108 .54833 L .71025 .54017 L p .707 .577 .707 r
F P
0 g
s
.68108 .54833 m .68593 .59922 L .66215 .6109 L p .707 .577 .707 r
F P
0 g
s
.42388 .67073 m .42924 .70148 L .45801 .69035 L p .707 .577 .707 r
F P
0 g
s
.45801 .69035 m .45265 .65959 L .42388 .67073 L p .707 .577 .707 r
F P
0 g
s
.39051 .7258 m .38954 .7081 L .35838 .70685 L p .707 .577 .707 r
F P
0 g
s
.38954 .7081 m .39051 .7258 L .4223 .72314 L p .707 .577 .707 r
F P
0 g
s
.4223 .72314 m .42132 .70544 L .38954 .7081 L p .707 .577 .707 r
F P
0 g
s
.42132 .70544 m .4223 .72314 L .4516 .71684 L p .707 .577 .707 r
F P
0 g
s
.4516 .71684 m .45063 .69914 L .42132 .70544 L p .707 .577 .707 r
F P
0 g
s
.77307 .53717 m .77792 .58806 L .74679 .58722 L p .707 .577 .707 r
F P
0 g
s
.74679 .58722 m .74194 .53633 L .77307 .53717 L p .707 .577 .707 r
F P
0 g
s
.66037 .68335 m .66135 .70105 L .64509 .7125 L p .707 .577 .707 r
F P
0 g
s
.36676 .70706 m .3614 .6763 L .33381 .67019 L p .707 .577 .707 r
F P
0 g
s
.3614 .6763 m .36676 .70706 L .3978 .70724 L p .707 .577 .707 r
F P
0 g
s
.66024 .62422 m .6656 .65498 L .65008 .67318 L p .707 .577 .707 r
F P
0 g
s
.6656 .65498 m .66024 .62422 L .68352 .6088 L p .707 .577 .707 r
F P
0 g
s
.35936 .72454 m .35838 .70685 L .33091 .70181 L p .707 .577 .707 r
F P
0 g
s
.35838 .70685 m .35936 .72454 L .39051 .7258 L p .707 .577 .707 r
F P
0 g
s
.31228 .63039 m .30743 .5795 L .29462 .56684 L p .707 .577 .707 r
F P
0 g
s
.30743 .5795 m .31228 .63039 L .33347 .63992 L p .707 .577 .707 r
F P
0 g
s
.45265 .65959 m .45801 .69035 L .48129 .67493 L p .707 .577 .707 r
F P
0 g
s
.48129 .67493 m .47593 .64417 L .45265 .65959 L p .707 .577 .707 r
F P
0 g
s
.80236 .5982 m .80772 .62895 L .78013 .62284 L p .707 .577 .707 r
F P
0 g
s
.78013 .62284 m .77477 .59209 L .80236 .5982 L p .707 .577 .707 r
F P
0 g
s
.7151 .59106 m .71025 .54017 L .74194 .53633 L p .707 .577 .707 r
F P
0 g
s
.71025 .54017 m .7151 .59106 L .68593 .59922 L p .707 .577 .707 r
F P
0 g
s
.82515 .67968 m .82613 .69738 L .80502 .68904 L p .707 .577 .707 r
F P
0 g
s
.80502 .68904 m .80405 .67135 L .82515 .67968 L p .707 .577 .707 r
F P
0 g
s
.74194 .53633 m .74679 .58722 L .7151 .59106 L p .707 .577 .707 r
F P
0 g
s
.45063 .69914 m .4516 .71684 L .47556 .7075 L p .707 .577 .707 r
F P
0 g
s
.47556 .7075 m .47458 .6898 L .45063 .69914 L p .707 .577 .707 r
F P
0 g
s
.33091 .70181 m .33188 .7195 L .35936 .72454 L p .707 .577 .707 r
F P
0 g
s
.48796 .5576 m .49281 .60849 L .49959 .59345 L p .707 .577 .707 r
F P
0 g
s
.49959 .59345 m .49474 .54256 L .48796 .5576 L p .707 .577 .707 r
F P
0 g
s
.33917 .70095 m .33381 .67019 L .31236 .65876 L p .707 .577 .707 r
F P
0 g
s
.33381 .67019 m .33917 .70095 L .36676 .70706 L p .707 .577 .707 r
F P
0 g
s
.68888 .63955 m .68352 .6088 L .71229 .59766 L p .707 .577 .707 r
F P
0 g
s
.68352 .6088 m .68888 .63955 L .6656 .65498 L p .707 .577 .707 r
F P
0 g
s
.33188 .7195 m .33091 .70181 L .3098 .69347 L p .707 .577 .707 r
F P
0 g
s
.47593 .64417 m .48129 .67493 L .49681 .65673 L p .707 .577 .707 r
F P
0 g
s
.49681 .65673 m .49145 .62597 L .47593 .64417 L p .707 .577 .707 r
F P
0 g
s
.77477 .59209 m .78013 .62284 L .74909 .62266 L p .707 .577 .707 r
F P
0 g
s
.74909 .62266 m .74373 .5919 L .77477 .59209 L p .707 .577 .707 r
F P
0 g
s
.66135 .70105 m .66037 .68335 L .68433 .67401 L p .707 .577 .707 r
F P
0 g
s
.3098 .69347 m .31078 .71117 L .33188 .7195 L p .707 .577 .707 r
F P
0 g
s
.71765 .62842 m .71229 .59766 L .74373 .5919 L p .707 .577 .707 r
F P
0 g
s
.71229 .59766 m .71765 .62842 L .68888 .63955 L p .707 .577 .707 r
F P
0 g
s
.68433 .67401 m .68531 .69171 L .66135 .70105 L p .707 .577 .707 r
F P
0 g
s
.74373 .5919 m .74909 .62266 L .71765 .62842 L p .707 .577 .707 r
F P
0 g
s
.47458 .6898 m .47556 .7075 L .49181 .69605 L p .707 .577 .707 r
F P
0 g
s
.49181 .69605 m .49084 .67835 L .47458 .6898 L p .707 .577 .707 r
F P
0 g
s
.80405 .67135 m .80502 .68904 L .77755 .684 L p .707 .577 .707 r
F P
0 g
s
.77755 .684 m .77657 .66631 L .80405 .67135 L p .707 .577 .707 r
F P
0 g
s
.29947 .61773 m .29462 .56684 L .29145 .55227 L p .707 .577 .707 r
F P
0 g
s
.29462 .56684 m .29947 .61773 L .31228 .63039 L p .707 .577 .707 r
F P
0 g
s
.31772 .68952 m .31236 .65876 L .29916 .64312 L p .707 .577 .707 r
F P
0 g
s
.31236 .65876 m .31772 .68952 L .33917 .70095 L p .707 .577 .707 r
F P
0 g
s
.68531 .69171 m .68433 .67401 L .71363 .66771 L p .707 .577 .707 r
F P
0 g
s
.49474 .54256 m .49959 .59345 L .49642 .57888 L p .707 .577 .707 r
F P
0 g
s
.49642 .57888 m .49157 .52799 L .49474 .54256 L p .707 .577 .707 r
F P
0 g
s
.49145 .62597 m .49681 .65673 L .50303 .63753 L p .707 .577 .707 r
F P
0 g
s
.50303 .63753 m .49767 .60677 L .49145 .62597 L p .707 .577 .707 r
F P
0 g
s
.31078 .71117 m .3098 .69347 L .29713 .68266 L p .707 .577 .707 r
F P
0 g
s
.77657 .66631 m .77755 .684 L .74639 .68275 L p .707 .577 .707 r
F P
0 g
s
.74639 .68275 m .74542 .66505 L .77657 .66631 L p .707 .577 .707 r
F P
0 g
s
.71363 .66771 m .71461 .68541 L .68531 .69171 L p .707 .577 .707 r
F P
0 g
s
.29713 .68266 m .29811 .70036 L .31078 .71117 L p .707 .577 .707 r
F P
0 g
s
.71461 .68541 m .71363 .66771 L .74542 .66505 L p .707 .577 .707 r
F P
0 g
s
.74542 .66505 m .74639 .68275 L .71461 .68541 L p .707 .577 .707 r
F P
0 g
s
.49084 .67835 m .49181 .69605 L .49879 .6836 L p .707 .577 .707 r
F P
0 g
s
.49879 .6836 m .49781 .6659 L .49084 .67835 L p .707 .577 .707 r
F P
0 g
s
.29145 .55227 m .2963 .60316 L .29947 .61773 L p .707 .577 .707 r
F P
0 g
s
.2963 .60316 m .29145 .55227 L .29823 .53723 L p .707 .577 .707 r
F P
0 g
s
.29916 .64312 m .30451 .67388 L .31772 .68952 L p .707 .577 .707 r
F P
0 g
s
.30451 .67388 m .29916 .64312 L .29549 .6248 L p .708 .578 .707 r
F P
0 g
s
.49767 .60677 m .50303 .63753 L .49936 .61921 L p .708 .578 .707 r
F P
0 g
s
.49936 .61921 m .49401 .58846 L .49767 .60677 L p .708 .578 .707 r
F P
0 g
s
.49157 .52799 m .49642 .57888 L .48361 .56622 L p .707 .577 .707 r
F P
0 g
s
.48361 .56622 m .47876 .51533 L .49157 .52799 L p .707 .577 .707 r
F P
0 g
s
.29811 .70036 m .29713 .68266 L .29413 .67044 L p .707 .577 .707 r
F P
0 g
s
.29413 .67044 m .29511 .68813 L .29811 .70036 L p .707 .577 .707 r
F P
0 g
s
.49781 .6659 m .49879 .6836 L .49579 .67137 L p .707 .577 .707 r
F P
0 g
s
.49579 .67137 m .49481 .65367 L .49781 .6659 L p .707 .577 .707 r
F P
0 g
s
.29823 .53723 m .30308 .58812 L .2963 .60316 L p .707 .577 .707 r
F P
0 g
s
.29549 .6248 m .30085 .65556 L .30451 .67388 L p .708 .578 .707 r
F P
0 g
s
.30308 .58812 m .29823 .53723 L .31429 .52319 L p .707 .577 .707 r
F P
0 g
s
.30085 .65556 m .29549 .6248 L .30171 .60561 L p .707 .577 .707 r
F P
0 g
s
.49401 .58846 m .49936 .61921 L .48616 .60357 L p .707 .577 .707 r
F P
0 g
s
.48616 .60357 m .4808 .57282 L .49401 .58846 L p .707 .577 .707 r
F P
0 g
s
.47876 .51533 m .48361 .56622 L .46241 .5567 L p .707 .577 .707 r
F P
0 g
s
.46241 .5567 m .45756 .50581 L .47876 .51533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29511 .68813 m .29413 .67044 L .30111 .65799 L p .707 .577 .707 r
F P
0 g
s
.30111 .65799 m .30208 .67568 L .29511 .68813 L p .707 .577 .707 r
F P
0 g
s
.31429 .52319 m .31914 .57408 L .30308 .58812 L p .707 .577 .707 r
F P
0 g
s
.31914 .57408 m .31429 .52319 L .33807 .51152 L p .707 .577 .707 r
F P
0 g
s
.30171 .60561 m .30707 .63636 L .30085 .65556 L p .707 .577 .707 r
F P
0 g
s
.49481 .65367 m .49579 .67137 L .48312 .66056 L p .707 .577 .707 r
F P
0 g
s
.48312 .66056 m .48214 .64286 L .49481 .65367 L p .707 .577 .707 r
F P
0 g
s
.30707 .63636 m .30171 .60561 L .31723 .5874 L p .707 .577 .707 r
F P
0 g
s
.4808 .57282 m .48616 .60357 L .46471 .59214 L p .707 .577 .707 r
F P
0 g
s
.46471 .59214 m .45935 .56138 L .4808 .57282 L p .707 .577 .707 r
F P
0 g
s
.45756 .50581 m .46241 .5567 L .43491 .55125 L p .707 .577 .707 r
F P
0 g
s
.43491 .55125 m .43006 .50036 L .45756 .50581 L p .707 .577 .707 r
F P
0 g
s
.30208 .67568 m .30111 .65799 L .31736 .64653 L p .707 .577 .707 r
F P
0 g
s
.34292 .56241 m .33807 .51152 L .36724 .50336 L p .707 .577 .707 r
F P
0 g
s
.33807 .51152 m .34292 .56241 L .31914 .57408 L p .707 .577 .707 r
F P
0 g
s
.43006 .50036 m .43491 .55125 L .40378 .5504 L p .707 .577 .707 r
F P
0 g
s
.40378 .5504 m .39893 .49951 L .43006 .50036 L p .707 .577 .707 r
F P
0 g
s
.31736 .64653 m .31834 .66423 L .30208 .67568 L p .707 .577 .707 r
F P
0 g
s
.31723 .5874 m .32259 .61816 L .30707 .63636 L p .707 .577 .707 r
F P
0 g
s
.32259 .61816 m .31723 .5874 L .34051 .57198 L p .707 .577 .707 r
F P
0 g
s
.45935 .56138 m .46471 .59214 L .43712 .58603 L p .707 .577 .707 r
F P
0 g
s
.43712 .58603 m .43176 .55527 L .45935 .56138 L p .707 .577 .707 r
F P
0 g
s
.37209 .55425 m .36724 .50336 L .39893 .49951 L p .707 .577 .707 r
F P
0 g
s
.36724 .50336 m .37209 .55425 L .34292 .56241 L p .707 .577 .707 r
F P
0 g
s
.48214 .64286 m .48312 .66056 L .46201 .65223 L p .707 .577 .707 r
F P
0 g
s
.46201 .65223 m .46104 .63453 L .48214 .64286 L p .707 .577 .707 r
F P
0 g
s
.39893 .49951 m .40378 .5504 L .37209 .55425 L p .707 .577 .707 r
F P
0 g
s
.34587 .60274 m .34051 .57198 L .36928 .56085 L p .707 .577 .707 r
F P
0 g
s
.34051 .57198 m .34587 .60274 L .32259 .61816 L p .707 .577 .707 r
F P
0 g
s
.43176 .55527 m .43712 .58603 L .40608 .58584 L p .707 .577 .707 r
F P
0 g
s
.40608 .58584 m .40072 .55509 L .43176 .55527 L p .707 .577 .707 r
F P
0 g
s
.31834 .66423 m .31736 .64653 L .34132 .6372 L p .707 .577 .707 r
F P
0 g
s
.37464 .5916 m .36928 .56085 L .40072 .55509 L p .707 .577 .707 r
F P
0 g
s
.36928 .56085 m .37464 .5916 L .34587 .60274 L p .707 .577 .707 r
F P
0 g
s
.34132 .6372 m .34229 .65489 L .31834 .66423 L p .707 .577 .707 r
F P
0 g
s
.40072 .55509 m .40608 .58584 L .37464 .5916 L p .707 .577 .707 r
F P
0 g
s
.46104 .63453 m .46201 .65223 L .43454 .64719 L p .707 .577 .707 r
F P
0 g
s
.43454 .64719 m .43356 .62949 L .46104 .63453 L p .707 .577 .707 r
F P
0 g
s
.34229 .65489 m .34132 .6372 L .37062 .63089 L p .707 .577 .707 r
F P
0 g
s
.43356 .62949 m .43454 .64719 L .40338 .64594 L p .707 .577 .707 r
F P
0 g
s
.40338 .64594 m .40241 .62824 L .43356 .62949 L p .707 .577 .707 r
F P
0 g
s
.37062 .63089 m .3716 .64859 L .34229 .65489 L p .707 .577 .707 r
F P
0 g
s
.3716 .64859 m .37062 .63089 L .40241 .62824 L p .707 .577 .707 r
F P
0 g
s
.40241 .62824 m .40338 .64594 L .3716 .64859 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Moob4008Eoo`00Lgoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF3000NGoo001_Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH8001aOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH015YF0`00JWoo001WOol30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02001VOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001J
EP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUHA0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`03001JEUYF00H000AJEP03001JEUYF00IJEP04001JEUYFFUH6000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006=o
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Ggoo10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001MOol200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005]oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FGoo
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001HOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P005goo3`00@7oo
001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000AOol60004FUH00`00FUIJEP06FUH00`00
FUH00003000lOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000=Ool400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3000iOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000:Ool30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000gOol0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000
FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
27oo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00=Goo
001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=JEP0000002`0000=J
EP0000000P000UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<00004
FUH000000005FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000bOol0059oo`04001JEUYF0004FUH00`00FUIJEP04
FUH40002FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUH00000<7oo001BOol01000FUIJEP0015YF00<005YFFUH00UYF0P000goo0`0000=J
EP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0000EJEP00001JEP00009JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP03001JEUYF008000=oo`<000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00D000=JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00Dgoo00<005YF000015YF0`000goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP800007FUH005YFFUH005YF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00Dgoo00<0
05YF000015YF00<007ooOol00Woo0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000IJEP00000005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Woo0016Ool>0002FUH01000
FUIJEP0017oo00<005YF000025YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00P005YF000005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00@7oo1P0015YF00<005YFFUH0
1UYF00D005YFFUH005YF0080009oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00004FUH00000000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00AJEPd000IJEP03001JEUYF009JEP04001JEP00FUH3000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
03]oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00<0009JEP@0009JEP03001JEUYF009J
EP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00
FUH005YF0P001UYF00<005YFFUH01EYF1@001EYF1P001UYF00<005YFFUH00`0015YF00D005YFFUH0
05YF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00AJEQD000=oo`@000EJEP05001JEUYFFUH0000^Ool003Ioo`800003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH01000FUH005YF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH0100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YF00000`000goo0P00
0eYF00D005YFFUIJEP0002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000UYF00@005YFFUH000MJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP800003FUH005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP<000=oo`<000QJEP03001J
EUYF00IJEP03001JEUYF00=JEP<0009oo`800003FUH005YF009JEP03001oogoo02aoo`00<Woo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF
FUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YF000005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0004FUH01000FUIJEUYF0P0017oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`000Woo0P000eYF00<007ooOol0;7oo000aOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YF000000Ao
o`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080009JEP03
001JEUYF008002eoo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP8000Aoo`8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF008002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP<000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<007ooOol00Woo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF1P00;Goo000]Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF00800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF008000=oo`80009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH0000002eoo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00;Goo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH00`00FUIJEP03000]Ool002]oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP04001JEUYF
FUH20005FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000015YF000005YF0P001eYF00<005YFFUH015YF1P0017oo1`001EYF1P001EYF00D005YF001JEP00
02eoo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPh0
009JEP<000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH005YF
008000IJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009J
EP03001JEP0000MJEP03001JEUYF009JEP`000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP05001JEP00FUH0000]Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH6
000=Ool00`00FUIJEP0600000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000IJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP04000COol01000FUIJEP001Goo1`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0000IJEP00FUIJEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04FUH200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00Oomoo`0/Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH4000HOol00eYF001oo`04Ool400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000
FUH000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP04001JEUYFFUH2000LOol00eYF001o
o`02Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF000015YF00@005YF
000001ioo`04FUH007ooOol20006FUH00`00FUIJEP04FUH60008FUH90004FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0005FUH01000FUH000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH007oo02aoo`00;7oo00<005YF000015YF0P004goo3P0000EJ
EP00001JEP0000IJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00EJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000002Ool2000]Ool002aoo`04001JEUYF0002FUH00`00Oomoo`0?Ool40002FUH00`00FUIJ
EP06FUH01000FUH000000eYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH025YF0P000UYF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=oo`03001JEP0002eoo`00;7oo00H005YFFUH0
05YF000>Ool40006FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH000030003FUH01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0`000UYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool00`00FUH0000]Ool002aoo`03001JEUYF00@000]oo`800003FUH005YF00QJEP03001JEUYF
00IJEP8000AJEP@00003FUH005YF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP06FUH01000FUH005YF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool00`00FUH0000]Ool002aoo`03
001JEUYF0080009JEP8000Ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP8000=JEP05001J
EP00001JEP020003FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001J
EUYF00EJEP03001JEP0000<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP80009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEP0001H0009JEP04001JEP00
0006Ool200000eYF0000000/Ool002aoo`03001JEUYF008000AJEPH000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEP00FUH30003FUH500001EYF001JEUYF00001EYF00<005YFFUH01eYF1000
1eYF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000UYF1@000eYF00<005YFFUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD000Ioo`03001JEP00009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH000EJ
EP@000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP02FUH00`00
FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`0000=JEP00Ool00Woo0`0000=JEP0000000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`000goo00@005YFFUH0009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH0
00EJEP04001JEUYF0008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0000AJ
EP03001JEUYF00=JEPh000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`04Ool3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
0003FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF0`000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF0`001eYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800004FUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`03Ool20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool0
02eoo`04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA00000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH01000FUH00000
0UYF0P0000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0003Ool20005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`80
009JEP<000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF00<0009JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP8000=JEP04001JEUYFFUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000goo00000006FUH00`00
FUIJEP04000HOol40005FUH00`00FUH00003000]Ool002eoo`80009JEP03001JEP0000IJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00800004FUH00000FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20002FUH20004FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001UYF00000000FUH000EJ
EPP001]oo`<000=JEP05001JEUYFFUH0000^Ool002ioo`03001JEP00009JEP03001JEUYF00EJEP03
001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP800003FUH0000000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP<000QJEP03001JEUYF009JEP800006FUH00000001JEP0015YF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
009JEP04001JEUYFFUH20004FUH01000FUH000006Woo00@005YFFUIJEP800003FUH005YF009JEP03
001oogoo02aoo`00;Woo0P000eYF00<005YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF
00@005YFFUH000=JEP03001JEP0000@00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP0000D000AJEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUH000030004FUH01000FUH0000067oo0P001UYF
0P000eYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00UYF1@001UYF00<005YFFUH01UYF
00<005YFFUH015YF1P000UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0`000UYF0P0015YF0`005Goo0`0000=J
EP00FUH01EYF00<005YF00000UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03
001JEP0000D0009JEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00AJEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH005YFFUH0
0003FUH20002FUH20002FUH00`00FUH0000BOol30004FUH00`00FUIJEP05FUH00`00FUH00002000^
Ool002ioo`03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF0000
00020005FUH5000015YF001JEP003Goo1@001eYF00<005YFFUH01EYF0P0000=oo`000000;Woo000]
Ool00`00FUH00004FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
00000002FUH00`00FUIJEP02FUH01000FUIJEUYF4P000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<007ooOol00`00;Goo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30005
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20003Ool00`00FUH0000]Ool002eoo`03001JEP0000=J
EP03001oogoo00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP020003Ool300000eYF
001oo`0/Ool002eoo`03001JEP00009JEP03001oogoo00Aoo`@0009JEP03001JEUYF00IJEP<0009J
EPH000eoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP040004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30003Ool20002FUH2000^
Ool002eoo`06001JEUYF001JEP002Woo40005Goo00<005YF00003`0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
001JEP800003FUH0000000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP8000=oo`8000AJEP8002ioo`00;Goo00<005YFFUH00P005Goo1@005Woo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH200000eYF00000003FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP03FUH00`00Oomo
o`0]Ool002eoo`04001JEUYF000FOol5000FOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000AJEP00FUIJEP<0009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000=oo`8000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH001Moo`<001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800005
FUH005YFFUH00002FUH20002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003Ool30005
FUH00`00FUIJEP02000`Ool002ioo`03FUH007oo01Ioo`l000Yoo`03001JEP00009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP0000AJEPT0009JEP03001JEUYF
00IJEP03001JEUYF00@000=oo`@00003FUH005YF00EJEP<0039oo`00;Woo00=JEP00Ool03Woo2000
15YF00<005YFFUH01UYF00<005YF00000`0017oo0`0015YF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000eYF0P001EYF00@005YFFUIJEQT000EJEP03001JEUYF00=JEP8003Aoo`00
;Woo00=JEP00Ool027oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Ioo`00;Woo00<005YF00001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00000hOol002ioo`04001JEUYF0003Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60003Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000jOol002ioo`800003FUH00000008000EJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20009Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04000mOol002ioo`800004FUH000000006FUH00`00FUIJEP02FUH8000?Ool40002FUH00`00FUIJ
EP03FUH01000FUIJEP001EYF00<005YFFUH01EYF8@001UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P003Woo6@00@Goo000_Ool20002FUH00`00FUIJEP03FUH6000DOol30003FUH5
0004FUH01000FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0P0047oo0P000UYF00<007ooOol0DGoo000^Ool00`00
FUIJEP02FUH01000FUIJEUYF10004Woo1P001eYF00@005YFFUIJEP<00005FUH005YFFUH00004FUH4
0003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH0
0`00FUIJEP03FUH2000?Ool00`00FUH00002FUH00`00Oomoo`1AOol002eoo`8000AJEP03001JEP00
008000=JEQ8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEP00008000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00=JEP8000ioo`04001JEUYF0002FUH00`00Oomoo`1AOol002eoo`8000AJEP80
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF009JEP80
0004Ool005YFFUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP04FUH2000=Ool01@00FUIJEUYF0000
0UYF00<007ooOol0DGoo000/Ool00`00FUH00002FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50006FUH00`00FUIJEP05FUH01@00FUIJEUYF00000goo0`000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@0015YF
1P0027oo00<005YFFUH00eYF0P00E7oo000/Ool00`00FUH0000200000goo00000004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP06FUH30004Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH2
0003FUH3000015YF000000000eYF2@001EYF0P00E7oo000/Ool00`00FUH00004Ool00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP06FUH00`00Oomoo`04Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH20005FUH50007FUH00`00FUH000020005FUH00`00Oomoo`1COol002aoo`80
00Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00Qoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001UYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool20008Ool200000eYF001JEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P002Goo0`000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0006FUH00`00FUIJEP03FUH200000eYF001oo`1EOol002aoo`<000Uoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000009Ool20002FUH300000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP060003FUH00`00FUIJEP03FUH01000FUH00000EWoo000/Ool2
00000eYF0000000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000:Ool00`00FUIJEP02
FUH200000goo000000020006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60003FUH50004FUH01@00FUIJEUYF0000EGoo
000/Ool20003FUH00`00Oomoo`0;Ool@000>Ool30004FUH20005Ool40002FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0007FUH01000FUIJEUYF0`0000=JEP00FUH00UYF00<007ooOol0Dgoo000]Ool01000FUIJEUYF0`00
9goo0P000UYF00<005YFFUH00UYF00<007ooOol027oo1@0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH04UYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF00<0
07ooOol0Dgoo000]Ool01@00FUIJEUYF00000UYF0P008Goo10001EYF00@005YFFUH0011oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPL000EJEP03001J
EUYF00MJEP03001JEUYF009JEP800005Ool005YFFUH0001EOol002ioo`04001JEUYF0004FUH5000H
Ool40002FUH00`00FUIJEP04FUH3000GOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH:0003
FUH50005FUH00`00FUIJEP06FUH01@00FUIJEUYF000017oo00<005YF0000EGoo000_Ool30005FUH0
1000FUIJEUYF60001UYF00<005YFFUH00eYF0P008Goo6P001EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01UYF00@005YFFUH000Ioo`8005Eoo`00<Goo00<005YFFUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8002moo`05001JEP00001o
o`020005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30007Ool2001E
Ool0039oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEP00000aOol00`00FUH00003Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH20009Ool3001DOol003Aoo`800003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<003=oo`8000Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000]oo`03001JEP0005Aoo`00=Woo1@00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P001goo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002goo0`0000=JEP00Ool0Dgoo000k
Ool90004FUH00`00FUIJEP02FUH7000jOol20009Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000<Ool20002FUH2001EOol004Aoo`T0045oo`04001JEP00000:Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP04000>Ool20004FUH2001EOol008ioo`80009JEP8000aoo`h000ioo`@00003FUH0
05YF00=JEP03001oogoo05Aoo`00Sgoo00D005YFFUH005YF00<0029oo`<000EJEP03001JEUYF009J
EP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEP<001]oo`@00003FUH005YF00EJEP03001JEUYF
008005Moo`00T7oo00<005YF00001EYF00<005YF00000`0047oo1`001EYF00<005YFFUH015YF0`00
FGoo002AOol20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001K
Ool0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<005eoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0`00HGoo002GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04001TOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL006Qoo`00WWoo4000Kgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59791 .76245 m .59306 .71156 L .56194 .71071 L p .707 .577 .707 r
F P
0 g
s
.59306 .71156 m .59791 .76245 L .62961 .7586 L p .707 .577 .707 r
F P
0 g
s
.62961 .7586 m .62476 .70771 L .59306 .71156 L p .707 .577 .707 r
F P
0 g
s
.62476 .70771 m .62961 .7586 L .65877 .75044 L p .707 .577 .707 r
F P
0 g
s
.65877 .75044 m .65392 .69955 L .62476 .70771 L p .707 .577 .707 r
F P
0 g
s
.56679 .7616 m .56194 .71071 L .53443 .70526 L p .707 .577 .707 r
F P
0 g
s
.56194 .71071 m .56679 .7616 L .59791 .76245 L p .707 .577 .707 r
F P
0 g
s
.65392 .69955 m .65877 .75044 L .68255 .73877 L p .707 .577 .707 r
F P
0 g
s
.68255 .73877 m .6777 .68788 L .65392 .69955 L p .707 .577 .707 r
F P
0 g
s
.53928 .75615 m .53443 .70526 L .51324 .69574 L p .707 .577 .707 r
F P
0 g
s
.53443 .70526 m .53928 .75615 L .56679 .7616 L p .707 .577 .707 r
F P
0 g
s
.6777 .68788 m .68255 .73877 L .69861 .72473 L p .707 .577 .707 r
F P
0 g
s
.69861 .72473 m .69377 .67384 L .6777 .68788 L p .707 .577 .707 r
F P
0 g
s
.60361 .8411 m .59825 .81035 L .56721 .81016 L p .707 .577 .707 r
F P
0 g
s
.59825 .81035 m .60361 .8411 L .63505 .83535 L p .707 .577 .707 r
F P
0 g
s
.63505 .83535 m .62969 .80459 L .59825 .81035 L p .707 .577 .707 r
F P
0 g
s
.62969 .80459 m .63505 .83535 L .66382 .82421 L p .707 .577 .707 r
F P
0 g
s
.66382 .82421 m .65846 .79346 L .62969 .80459 L p .707 .577 .707 r
F P
0 g
s
.51808 .74663 m .51324 .69574 L .50043 .68308 L p .707 .577 .707 r
F P
0 g
s
.51324 .69574 m .51808 .74663 L .53928 .75615 L p .707 .577 .707 r
F P
0 g
s
.59632 .87391 m .59534 .85621 L .56419 .85496 L p .707 .577 .707 r
F P
0 g
s
.59534 .85621 m .59632 .87391 L .6281 .87125 L p .707 .577 .707 r
F P
0 g
s
.6281 .87125 m .62713 .85356 L .59534 .85621 L p .707 .577 .707 r
F P
0 g
s
.62713 .85356 m .6281 .87125 L .65741 .86495 L p .707 .577 .707 r
F P
0 g
s
.65741 .86495 m .65643 .84725 L .62713 .85356 L p .707 .577 .707 r
F P
0 g
s
.57257 .84092 m .56721 .81016 L .53962 .80405 L p .707 .577 .707 r
F P
0 g
s
.56721 .81016 m .57257 .84092 L .60361 .8411 L p .707 .577 .707 r
F P
0 g
s
.65846 .79346 m .66382 .82421 L .6871 .80879 L p .707 .577 .707 r
F P
0 g
s
.6871 .80879 m .68174 .77803 L .65846 .79346 L p .707 .577 .707 r
F P
0 g
s
.56516 .87266 m .56419 .85496 L .53671 .84992 L p .707 .577 .707 r
F P
0 g
s
.56419 .85496 m .56516 .87266 L .59632 .87391 L p .707 .577 .707 r
F P
0 g
s
.69377 .67384 m .69861 .72473 L .70539 .70968 L p .707 .577 .707 r
F P
0 g
s
.70539 .70968 m .70055 .6588 L .69377 .67384 L p .707 .577 .707 r
F P
0 g
s
.65643 .84725 m .65741 .86495 L .68136 .85561 L p .707 .577 .707 r
F P
0 g
s
.68136 .85561 m .68038 .83792 L .65643 .84725 L p .707 .577 .707 r
F P
0 g
s
.53671 .84992 m .53769 .86762 L .56516 .87266 L p .707 .577 .707 r
F P
0 g
s
.54498 .83481 m .53962 .80405 L .51817 .79262 L p .707 .577 .707 r
F P
0 g
s
.53962 .80405 m .54498 .83481 L .57257 .84092 L p .707 .577 .707 r
F P
0 g
s
.68174 .77803 m .6871 .80879 L .70261 .79059 L p .707 .577 .707 r
F P
0 g
s
.70261 .79059 m .69725 .75983 L .68174 .77803 L p .707 .577 .707 r
F P
0 g
s
.53769 .86762 m .53671 .84992 L .51561 .84159 L p .707 .577 .707 r
F P
0 g
s
.50527 .73397 m .50043 .68308 L .49726 .66851 L p .707 .577 .707 r
F P
0 g
s
.50043 .68308 m .50527 .73397 L .51808 .74663 L p .707 .577 .707 r
F P
0 g
s
.51561 .84159 m .51658 .85928 L .53769 .86762 L p .707 .577 .707 r
F P
0 g
s
.68038 .83792 m .68136 .85561 L .69762 .84416 L p .707 .577 .707 r
F P
0 g
s
.69762 .84416 m .69664 .82646 L .68038 .83792 L p .707 .577 .707 r
F P
0 g
s
.70055 .6588 m .70539 .70968 L .70222 .69512 L p .707 .577 .707 r
F P
0 g
s
.70222 .69512 m .69738 .64423 L .70055 .6588 L p .707 .577 .707 r
F P
0 g
s
.52353 .82338 m .51817 .79262 L .50496 .77698 L p .707 .577 .707 r
F P
0 g
s
.51817 .79262 m .52353 .82338 L .54498 .83481 L p .707 .577 .707 r
F P
0 g
s
.69725 .75983 m .70261 .79059 L .70884 .77139 L p .707 .577 .707 r
F P
0 g
s
.70884 .77139 m .70348 .74063 L .69725 .75983 L p .707 .577 .707 r
F P
0 g
s
.51658 .85928 m .51561 .84159 L .50293 .83078 L p .707 .577 .707 r
F P
0 g
s
.49726 .66851 m .5021 .7194 L .50527 .73397 L p .707 .577 .707 r
F P
0 g
s
.50293 .83078 m .50391 .84847 L .51658 .85928 L p .707 .577 .707 r
F P
0 g
s
.5021 .7194 m .49726 .66851 L .50404 .65347 L p .707 .577 .707 r
F P
0 g
s
.69664 .82646 m .69762 .84416 L .70459 .83171 L p .707 .577 .707 r
F P
0 g
s
.70459 .83171 m .70362 .81401 L .69664 .82646 L p .707 .577 .707 r
F P
0 g
s
.50496 .77698 m .51032 .80774 L .52353 .82338 L p .707 .577 .707 r
F P
0 g
s
.51032 .80774 m .50496 .77698 L .50129 .75867 L p .708 .578 .707 r
F P
0 g
s
.69738 .64423 m .70222 .69512 L .68941 .68246 L p .707 .577 .707 r
F P
0 g
s
.68941 .68246 m .68457 .63157 L .69738 .64423 L p .707 .577 .707 r
F P
0 g
s
.70348 .74063 m .70884 .77139 L .70517 .75307 L p .708 .578 .707 r
F P
0 g
s
.70517 .75307 m .69981 .72232 L .70348 .74063 L p .708 .578 .707 r
F P
0 g
s
.48079 .81686 m .49636 .30616 L .45236 .30292 L p .707 .577 .707 r
F P
0 g
s
.50404 .65347 m .50888 .70436 L .5021 .7194 L p .707 .577 .707 r
F P
0 g
s
.50888 .70436 m .50404 .65347 L .5201 .63943 L p .707 .577 .707 r
F P
0 g
s
.50129 .75867 m .50665 .78942 L .51032 .80774 L p .708 .578 .707 r
F P
0 g
s
.50665 .78942 m .50129 .75867 L .50752 .73947 L p .707 .577 .707 r
F P
0 g
s
.50391 .84847 m .50293 .83078 L .49994 .81855 L p .707 .577 .707 r
F P
0 g
s
.49994 .81855 m .50092 .83625 L .50391 .84847 L p .707 .577 .707 r
F P
0 g
s
.50092 .83625 m .49994 .81855 L .50691 .8061 L p .707 .577 .707 r
F P
0 g
s
.5201 .63943 m .52495 .69032 L .50888 .70436 L p .707 .577 .707 r
F P
0 g
s
.50691 .8061 m .50789 .8238 L .50092 .83625 L p .707 .577 .707 r
F P
0 g
s
.50752 .73947 m .51288 .77022 L .50665 .78942 L p .707 .577 .707 r
F P
0 g
s
.51288 .77022 m .50752 .73947 L .52303 .72127 L p .707 .577 .707 r
F P
0 g
s
.50789 .8238 m .50691 .8061 L .52317 .79464 L p .707 .577 .707 r
F P
0 g
s
.52303 .72127 m .52839 .75202 L .51288 .77022 L p .707 .577 .707 r
F P
0 g
s
.52317 .79464 m .52415 .81234 L .50789 .8238 L p .707 .577 .707 r
F P
0 g
s
.52415 .81234 m .52317 .79464 L .54712 .78531 L p .707 .577 .707 r
F P
0 g
s
.54712 .78531 m .5481 .80301 L .52415 .81234 L p .707 .577 .707 r
F P
0 g
s
.49636 .30616 m .48079 .81686 L .52571 .81737 L p .707 .577 .707 r
F P
0 g
s
.52495 .69032 m .5201 .63943 L .54388 .62776 L p .707 .577 .707 r
F P
0 g
s
.54388 .62776 m .54873 .67865 L .52495 .69032 L p .707 .577 .707 r
F P
0 g
s
.52839 .75202 m .52303 .72127 L .54631 .70584 L p .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .54128 .30667 L .49636 .30616 L p .707 .577 .707 r
F P
0 g
s
.54873 .67865 m .54388 .62776 L .57304 .6196 L p .707 .577 .707 r
F P
0 g
s
.57304 .6196 m .57789 .67049 L .55413 .67713 L p .707 .577 .707 r
F P
0 g
s
.55413 .67713 m .54873 .67865 L p .55127 .67246 L .707 .577 .707 r
F P
0 g
s
.55127 .67246 m .57304 .6196 L .55413 .67713 L .707 .577 .707 r
F
.57643 .779 m .5774 .7967 L .56505 .79936 L p F P
0 g
s
.56505 .79936 m .5481 .80301 L p .56191 .7913 L .707 .577 .707 r
F P
0 g
s
.56191 .7913 m .57643 .779 L .56505 .79936 L .707 .577 .707 r
F
.58044 .72546 m .57508 .69471 L .58078 .69366 L p F P
0 g
s
.58078 .69366 m .60653 .68895 L p .58717 .71605 L .707 .577 .707 r
F P
0 g
s
.58044 .72546 m .58078 .69366 L .58717 .71605 L .707 .577 .707 r
F
.63586 .61659 m .64071 .66748 L .60959 .66664 L p F P
0 g
s
.60959 .66664 m .60474 .61575 L .63586 .61659 L p .707 .577 .707 r
F P
0 g
s
.60474 .61575 m .60959 .66664 L .57789 .67049 L p .707 .577 .707 r
F P
0 g
s
.63756 .68914 m .64292 .71989 L .61188 .71971 L p .707 .577 .707 r
F P
0 g
s
.61188 .71971 m .60653 .68895 L .63756 .68914 L p .707 .577 .707 r
F P
0 g
s
.60653 .68895 m .61188 .71971 L .58044 .72546 L p .707 .577 .707 r
F P
0 g
s
.63937 .7776 m .64034 .7953 L .60919 .79405 L p .707 .577 .707 r
F P
0 g
s
.60919 .79405 m .60821 .77635 L .63937 .7776 L p .707 .577 .707 r
F P
0 g
s
.5774 .7967 m .57643 .779 L .60821 .77635 L p .707 .577 .707 r
F P
0 g
s
.60821 .77635 m .60919 .79405 L .5774 .7967 L p .707 .577 .707 r
F P
0 g
s
.61663 .29957 m .60231 .76911 L p .62412 .80336 L .707 .577 .707 r
F P
0 g
s
.60231 .76911 m .60106 .81027 L .61304 .80668 L p .707 .577 .707 r
F P
0 g
s
.61304 .80668 m .62412 .80336 L p .60231 .76911 L .707 .577 .707 r
F P
0 g
s
.57508 .69471 m .58044 .72546 L .57208 .7287 L p .707 .577 .707 r
F P
0 g
s
.5481 .80301 m .54712 .78531 L .57643 .779 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .56744 .8055 L p .59819 .75169 L .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .56715 .8151 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56136 .71926 L .56984 .72673 L .707 .577 .707 r
F
.56136 .71926 m .57508 .69471 L .5723 .72616 L F
.56984 .72673 m .5723 .72616 L .57208 .7287 L F
.56136 .71926 m .5723 .72616 L .56984 .72673 L F
.56274 .72838 m .55073 .73117 L .52571 .81737 L F
.54631 .70584 m .55073 .73117 L p .52839 .75202 L F P
0 g
s
.5452 .74089 m .52839 .75202 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52818 .73641 m .52707 .77275 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52707 .77275 m .52571 .81737 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.55073 .73117 m .55167 .7366 L .5452 .74089 L p .707 .577 .707 r
F P
0 g
s
.55167 .7366 m .54631 .70584 L .57508 .69471 L p .707 .577 .707 r
F P
0 g
s
.58272 .3044 m .54128 .30667 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.56715 .8151 m .56984 .72673 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57789 .67049 m .57304 .6196 L .60474 .61575 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .58272 .3044 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.54128 .30667 m .52818 .73641 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57208 .7287 m .55167 .7366 L p .5553 .73011 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56984 .72673 L .57208 .7287 L .707 .577 .707 r
F
.57054 .70402 m .56984 .72673 L p .59889 .75046 L F P
0 g
s
.59889 .75046 m .56984 .72673 L .59819 .75169 L .707 .577 .707 r
F
.56744 .8055 m .56715 .8151 L p .5694 .81052 L F P
0 g
s
.59889 .75046 m .56744 .8055 L .5694 .81052 L .707 .577 .707 r
F
.56715 .8151 m .60106 .81027 L p .59889 .75046 L F P
0 g
s
.58272 .3044 m .57054 .70402 L p .59889 .75046 L .707 .577 .707 r
F P
0 g
s
.43679 .81363 m .45236 .30292 L .41358 .29728 L p .707 .577 .707 r
F P
0 g
s
.45236 .30292 m .43679 .81363 L .48079 .81686 L p .707 .577 .707 r
F P
0 g
s
.70362 .81401 m .70459 .83171 L .7016 .81948 L p .707 .577 .707 r
F P
0 g
s
.7016 .81948 m .70062 .80178 L .70362 .81401 L p .707 .577 .707 r
F P
0 g
s
.2549 .72563 m .25005 .67474 L .21893 .6739 L p .707 .577 .707 r
F P
0 g
s
.25005 .67474 m .2549 .72563 L .2866 .72179 L p .707 .577 .707 r
F P
0 g
s
.2866 .72179 m .28175 .6709 L .25005 .67474 L p .707 .577 .707 r
F P
0 g
s
.28175 .6709 m .2866 .72179 L .31576 .71363 L p .707 .577 .707 r
F P
0 g
s
.31576 .71363 m .31091 .66274 L .28175 .6709 L p .707 .577 .707 r
F P
0 g
s
.68457 .63157 m .68941 .68246 L .66822 .67293 L p .707 .577 .707 r
F P
0 g
s
.66822 .67293 m .66337 .62204 L .68457 .63157 L p .707 .577 .707 r
F P
0 g
s
.69981 .72232 m .70517 .75307 L .69196 .73743 L p .707 .577 .707 r
F P
0 g
s
.69196 .73743 m .68661 .70668 L .69981 .72232 L p .707 .577 .707 r
F P
0 g
s
.60106 .81027 m .61663 .29957 L .58272 .3044 L p .707 .577 .707 r
F P
0 g
s
.22378 .72479 m .21893 .6739 L .19142 .66845 L p .707 .577 .707 r
F P
0 g
s
.21893 .6739 m .22378 .72479 L .2549 .72563 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31091 .66274 m .31576 .71363 L .33954 .70195 L p .707 .577 .707 r
F P
0 g
s
.33954 .70195 m .33469 .65106 L .31091 .66274 L p .707 .577 .707 r
F P
0 g
s
.39802 .80798 m .41358 .29728 L .38383 .28977 L p .707 .577 .707 r
F P
0 g
s
.41358 .29728 m .39802 .80798 L .43679 .81363 L p .707 .577 .707 r
F P
0 g
s
.19627 .71934 m .19142 .66845 L .17023 .65893 L p .707 .577 .707 r
F P
0 g
s
.19142 .66845 m .19627 .71934 L .22378 .72479 L p .707 .577 .707 r
F P
0 g
s
.66337 .62204 m .66822 .67293 L .64071 .66748 L p .707 .577 .707 r
F P
0 g
s
.64071 .66748 m .63586 .61659 L .66337 .62204 L p .707 .577 .707 r
F P
0 g
s
.70062 .80178 m .7016 .81948 L .68893 .80867 L p .707 .577 .707 r
F P
0 g
s
.68893 .80867 m .68795 .79097 L .70062 .80178 L p .707 .577 .707 r
F P
0 g
s
.68661 .70668 m .69196 .73743 L .67051 .726 L p .707 .577 .707 r
F P
0 g
s
.67051 .726 m .66516 .69524 L .68661 .70668 L p .707 .577 .707 r
F P
0 g
s
.33469 .65106 m .33954 .70195 L .35561 .68791 L p .707 .577 .707 r
F P
0 g
s
.35561 .68791 m .35076 .63702 L .33469 .65106 L p .707 .577 .707 r
F P
0 g
s
.62412 .80336 m .63968 .29266 L .61663 .29957 L p .707 .577 .707 r
F P
0 g
s
.2606 .80429 m .25524 .77353 L .2242 .77335 L p .707 .577 .707 r
F P
0 g
s
.25524 .77353 m .2606 .80429 L .29204 .79853 L p .707 .577 .707 r
F P
0 g
s
.29204 .79853 m .28668 .76778 L .25524 .77353 L p .707 .577 .707 r
F P
0 g
s
.28668 .76778 m .29204 .79853 L .32081 .7874 L p .707 .577 .707 r
F P
0 g
s
.32081 .7874 m .31545 .75664 L .28668 .76778 L p .707 .577 .707 r
F P
0 g
s
.17508 .70982 m .17023 .65893 L .15742 .64626 L p .707 .577 .707 r
F P
0 g
s
.17023 .65893 m .17508 .70982 L .19627 .71934 L p .707 .577 .707 r
F P
0 g
s
.25331 .83709 m .25233 .8194 L .22118 .81814 L p .707 .577 .707 r
F P
0 g
s
.25233 .8194 m .25331 .83709 L .2851 .83444 L p .707 .577 .707 r
F P
0 g
s
.2851 .83444 m .28412 .81674 L .25233 .8194 L p .707 .577 .707 r
F P
0 g
s
.28412 .81674 m .2851 .83444 L .3144 .82813 L p .707 .577 .707 r
F P
0 g
s
.3144 .82813 m .31342 .81044 L .28412 .81674 L p .707 .577 .707 r
F P
0 g
s
.22956 .8041 m .2242 .77335 L .19661 .76724 L p .707 .577 .707 r
F P
0 g
s
.2242 .77335 m .22956 .8041 L .2606 .80429 L p .707 .577 .707 r
F P
0 g
s
.36827 .80047 m .38383 .28977 L .36602 .28114 L p .707 .577 .707 r
F P
0 g
s
.38383 .28977 m .36827 .80047 L .39802 .80798 L p .707 .577 .707 r
F P
0 g
s
.31545 .75664 m .32081 .7874 L .34409 .77197 L p .707 .577 .707 r
F P
0 g
s
.34409 .77197 m .33873 .74122 L .31545 .75664 L p .707 .577 .707 r
F P
0 g
s
.66516 .69524 m .67051 .726 L .64292 .71989 L p .707 .577 .707 r
F P
0 g
s
.64292 .71989 m .63756 .68914 L .66516 .69524 L p .707 .577 .707 r
F P
0 g
s
.22216 .83584 m .22118 .81814 L .1937 .8131 L p .707 .577 .707 r
F P
0 g
s
.22118 .81814 m .22216 .83584 L .25331 .83709 L p .707 .577 .707 r
F P
0 g
s
.35076 .63702 m .35561 .68791 L .36238 .67287 L p .707 .577 .707 r
F P
0 g
s
.36238 .67287 m .35754 .62198 L .35076 .63702 L p .707 .577 .707 r
F P
0 g
s
.68795 .79097 m .68893 .80867 L .66782 .80034 L p .707 .577 .707 r
F P
0 g
s
.66782 .80034 m .66684 .78264 L .68795 .79097 L p .707 .577 .707 r
F P
0 g
s
.31342 .81044 m .3144 .82813 L .33835 .8188 L p .707 .577 .707 r
F P
0 g
s
.33835 .8188 m .33738 .8011 L .31342 .81044 L p .707 .577 .707 r
F P
0 g
s
.1937 .8131 m .19468 .8308 L .22216 .83584 L p .707 .577 .707 r
F P
0 g
s
.20197 .79799 m .19661 .76724 L .17516 .75581 L p .707 .577 .707 r
F P
0 g
s
.19661 .76724 m .20197 .79799 L .22956 .8041 L p .707 .577 .707 r
F P
0 g
s
.33873 .74122 m .34409 .77197 L .3596 .75377 L p .707 .577 .707 r
F P
0 g
s
.3596 .75377 m .35424 .72302 L .33873 .74122 L p .707 .577 .707 r
F P
0 g
s
.19468 .8308 m .1937 .8131 L .1726 .80477 L p .707 .577 .707 r
F P
0 g
s
.16227 .69715 m .15742 .64626 L .15425 .6317 L p .707 .577 .707 r
F P
0 g
s
.15742 .64626 m .16227 .69715 L .17508 .70982 L p .707 .577 .707 r
F P
0 g
s
.63968 .29266 m .62412 .80336 L .63406 .79504 L p .707 .577 .707 r
F P
0 g
s
.63406 .79504 m .64963 .28434 L .63968 .29266 L p .707 .577 .707 r
F P
0 g
s
.1726 .80477 m .17357 .82247 L .19468 .8308 L p .707 .577 .707 r
F P
0 g
s
.33738 .8011 m .33835 .8188 L .35461 .80734 L p .707 .577 .707 r
F P
0 g
s
.35461 .80734 m .35363 .78965 L .33738 .8011 L p .707 .577 .707 r
F P
0 g
s
.66684 .78264 m .66782 .80034 L .64034 .7953 L p .707 .577 .707 r
F P
0 g
s
.64034 .7953 m .63937 .7776 L .66684 .78264 L p .707 .577 .707 r
F P
0 g
s
.35754 .62198 m .36238 .67287 L .35921 .6583 L p .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35754 .62198 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35437 .60741 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35805 .64604 L p .3464 .64564 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35921 .6583 L .35684 .65596 L p .707 .577 .707 r
F P
0 g
s
.35684 .65596 m .3464 .64564 L p .35805 .64604 L .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .3568 .6855 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34895 .70062 m .34875 .69947 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34875 .69947 m .3436 .66986 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.35424 .72302 m .3596 .75377 L .36583 .73457 L p .707 .577 .707 r
F P
0 g
s
.36583 .73457 m .36047 .70382 L .35424 .72302 L p .707 .577 .707 r
F P
0 g
s
.35363 .78965 m .35461 .80734 L .36158 .79489 L p .707 .577 .707 r
F P
0 g
s
.36158 .79489 m .36061 .7772 L .35363 .78965 L p .707 .577 .707 r
F P
0 g
s
.36047 .70382 m .36583 .73457 L .36318 .72135 L p .708 .578 .707 r
F P
0 g
s
.36198 .71491 m .36047 .70382 L .36318 .72135 L .708 .578 .707 r
F
.35761 .76497 m .35859 .78267 L .35126 .77641 L p .707 .577 .707 r
F P
0 g
s
.35126 .77641 m .34592 .77186 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.35198 .76829 m .35761 .76497 L .35126 .77641 L .707 .577 .707 r
F
.3568 .6855 m .35684 .6857 L p .34895 .70062 L F P
0 g
s
.34592 .77186 m .34494 .75416 L .35264 .76073 L p .707 .577 .707 r
F P
0 g
s
.35264 .76073 m .35761 .76497 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.34592 .77186 m .35264 .76073 L .35198 .76829 L .707 .577 .707 r
F
.35279 .70516 m .34895 .70062 L p .35684 .6857 L F P
0 g
s
.3464 .64564 m .34156 .59475 L .35437 .60741 L p .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .34895 .70062 L .34285 .69736 L p .707 .577 .707 r
F P
0 g
s
.34285 .69736 m .32751 .68918 L p .34035 .67377 L .707 .577 .707 r
F P
0 g
s
.34035 .67377 m .3436 .66986 L .34285 .69736 L .707 .577 .707 r
F
.36188 .27223 m .34631 .78293 L .34998 .79084 L p F P
0 g
s
.35063 .78347 m .36188 .27223 L .34998 .79084 L .707 .577 .707 r
F
.35063 .78347 m .35313 .70356 L .35231 .70751 L F
.35074 .78224 m .35384 .68076 L p .35063 .78347 L F P
0 g
s
.35314 .70347 m .35045 .79184 L p .36482 .73015 L .707 .577 .707 r
F P
0 g
s
.36121 .71083 m .35314 .70347 L .36482 .73015 L .707 .577 .707 r
F
.35684 .6857 m .36216 .71626 L .35279 .70516 L p F P
0 g
s
.3568 .6855 m .36047 .70382 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36121 .71083 m .3568 .6855 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.35921 .6583 m .35805 .64604 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .35314 .70347 L p .3679 .71693 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .36188 .27223 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.35522 .63529 m .36602 .28114 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.36188 .27223 m .37183 .26391 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34631 .78293 m .34757 .74177 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34757 .74177 m .36188 .27223 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34998 .79084 m .35045 .79184 L p .35063 .78347 L .707 .577 .707 r
F P
0 g
s
.35231 .70751 m .35384 .68076 L .35269 .69026 L .707 .577 .707 r
F
.35313 .70356 m .35384 .68076 L .35231 .70751 L F
.35045 .79184 m .35074 .78224 L p .35063 .78347 L F P
0 g
s
.3679 .71693 m .36121 .71083 L .36482 .73015 L .707 .577 .707 r
F
.36216 .71626 m .36121 .71083 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36318 .72135 m .36216 .71626 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36061 .7772 m .36158 .79489 L .35859 .78267 L p .707 .577 .707 r
F P
0 g
s
.35859 .78267 m .35761 .76497 L .36061 .7772 L p .707 .577 .707 r
F P
0 g
s
.35045 .79184 m .36827 .80047 L p .36804 .74734 L .707 .577 .707 r
F P
0 g
s
.36804 .74734 m .3679 .71693 L .36482 .73015 L .707 .577 .707 r
F
.36804 .74734 m .36482 .73015 L .35045 .79184 L F
.35269 .69026 m .35522 .63529 L .354 .63062 L F
.35384 .68076 m .35522 .63529 L p .35269 .69026 L F P
0 g
s
.18052 .78656 m .17516 .75581 L .16195 .74017 L p .707 .577 .707 r
F P
0 g
s
.17516 .75581 m .18052 .78656 L .20197 .79799 L p .707 .577 .707 r
F P
0 g
s
.17357 .82247 m .1726 .80477 L .15993 .79396 L p .707 .577 .707 r
F P
0 g
s
.15425 .6317 m .15909 .68259 L .16227 .69715 L p .707 .577 .707 r
F P
0 g
s
.15993 .79396 m .1609 .81166 L .17357 .82247 L p .707 .577 .707 r
F P
0 g
s
.15909 .68259 m .15425 .6317 L .16103 .61666 L p .707 .577 .707 r
F P
0 g
s
.16195 .74017 m .16731 .77092 L .18052 .78656 L p .707 .577 .707 r
F P
0 g
s
.16731 .77092 m .16195 .74017 L .15828 .72185 L p .708 .578 .707 r
F P
0 g
s
.64963 .28434 m .63406 .79504 L .62992 .78613 L p .707 .577 .707 r
F P
0 g
s
.62992 .78613 m .64549 .27543 L .64963 .28434 L p .707 .577 .707 r
F P
0 g
s
.1609 .81166 m .15993 .79396 L .15693 .78173 L p .707 .577 .707 r
F P
0 g
s
.16103 .61666 m .16587 .66755 L .15909 .68259 L p .707 .577 .707 r
F P
0 g
s
.15693 .78173 m .15791 .79943 L .1609 .81166 L p .707 .577 .707 r
F P
0 g
s
.16587 .66755 m .16103 .61666 L .17709 .60261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15828 .72185 m .16364 .75261 L .16731 .77092 L p .708 .578 .707 r
F P
0 g
s
.16364 .75261 m .15828 .72185 L .16451 .70265 L p .707 .577 .707 r
F P
0 g
s
.34156 .59475 m .3464 .64564 L .32521 .63612 L p .707 .577 .707 r
F P
0 g
s
.32521 .63612 m .32036 .58523 L .34156 .59475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15791 .79943 m .15693 .78173 L .1639 .76928 L p .707 .577 .707 r
F P
0 g
s
.17709 .60261 m .18194 .6535 L .16587 .66755 L p .707 .577 .707 r
F P
0 g
s
.18194 .6535 m .17709 .60261 L .20087 .59094 L p .707 .577 .707 r
F P
0 g
s
.1639 .76928 m .16488 .78698 L .15791 .79943 L p .707 .577 .707 r
F P
0 g
s
.16451 .70265 m .16987 .73341 L .16364 .75261 L p .707 .577 .707 r
F P
0 g
s
.32036 .58523 m .32521 .63612 L .2977 .63067 L p .707 .577 .707 r
F P
0 g
s
.2977 .63067 m .29286 .57978 L .32036 .58523 L p .707 .577 .707 r
F P
0 g
s
.16987 .73341 m .16451 .70265 L .18002 .68445 L p .707 .577 .707 r
F P
0 g
s
.64549 .27543 m .62992 .78613 L .61211 .7775 L p .707 .577 .707 r
F P
0 g
s
.61211 .7775 m .62768 .2668 L .64549 .27543 L p .707 .577 .707 r
F P
0 g
s
.32751 .68918 m .32215 .65843 L .3436 .66986 L p .707 .577 .707 r
F P
0 g
s
.20572 .64183 m .20087 .59094 L .23004 .58278 L p .707 .577 .707 r
F P
0 g
s
.20087 .59094 m .20572 .64183 L .18194 .6535 L p .707 .577 .707 r
F P
0 g
s
.29286 .57978 m .2977 .63067 L .26658 .62983 L p .707 .577 .707 r
F P
0 g
s
.26658 .62983 m .26173 .57894 L .29286 .57978 L p .707 .577 .707 r
F P
0 g
s
.16488 .78698 m .1639 .76928 L .18016 .75783 L p .707 .577 .707 r
F P
0 g
s
.35626 .77461 m .37183 .26391 L .39488 .257 L p .707 .577 .707 r
F P
0 g
s
.37183 .26391 m .35626 .77461 L .34631 .78293 L p .707 .577 .707 r
F P
0 g
s
.23488 .63367 m .23004 .58278 L .26173 .57894 L p .707 .577 .707 r
F P
0 g
s
.23004 .58278 m .23488 .63367 L .20572 .64183 L p .707 .577 .707 r
F P
0 g
s
.26173 .57894 m .26658 .62983 L .23488 .63367 L p .707 .577 .707 r
F P
0 g
s
.18002 .68445 m .18538 .71521 L .16987 .73341 L p .707 .577 .707 r
F P
0 g
s
.18538 .71521 m .18002 .68445 L .20331 .66903 L p .707 .577 .707 r
F P
0 g
s
.32215 .65843 m .32751 .68918 L .29991 .68308 L p .707 .577 .707 r
F P
0 g
s
.29991 .68308 m .29455 .65232 L .32215 .65843 L p .707 .577 .707 r
F P
0 g
s
.18016 .75783 m .18114 .77553 L .16488 .78698 L p .707 .577 .707 r
F P
0 g
s
.34494 .75416 m .34592 .77186 L .32481 .76353 L p .707 .577 .707 r
F P
0 g
s
.32481 .76353 m .32383 .74583 L .34494 .75416 L p .707 .577 .707 r
F P
0 g
s
.20866 .69978 m .20331 .66903 L .23207 .65789 L p .707 .577 .707 r
F P
0 g
s
.20331 .66903 m .20866 .69978 L .18538 .71521 L p .707 .577 .707 r
F P
0 g
s
.29455 .65232 m .29991 .68308 L .26887 .68289 L p .707 .577 .707 r
F P
0 g
s
.26887 .68289 m .26352 .65214 L .29455 .65232 L p .707 .577 .707 r
F P
0 g
s
.62768 .2668 m .61211 .7775 L .58236 .76999 L p .707 .577 .707 r
F P
0 g
s
.58236 .76999 m .59792 .25929 L .62768 .2668 L p .707 .577 .707 r
F P
0 g
s
.18114 .77553 m .18016 .75783 L .20411 .74849 L p .707 .577 .707 r
F P
0 g
s
.73511 .68302 m .73027 .63213 L .69914 .63129 L p .707 .577 .707 r
F P
0 g
s
.73027 .63213 m .73511 .68302 L .76681 .67918 L p .707 .577 .707 r
F P
0 g
s
.76681 .67918 m .76196 .62829 L .73027 .63213 L p .707 .577 .707 r
F P
0 g
s
.76196 .62829 m .76681 .67918 L .79598 .67102 L p .707 .577 .707 r
F P
0 g
s
.79598 .67102 m .79113 .62013 L .76196 .62829 L p .707 .577 .707 r
F P
0 g
s
.23743 .68865 m .23207 .65789 L .26352 .65214 L p .707 .577 .707 r
F P
0 g
s
.23207 .65789 m .23743 .68865 L .20866 .69978 L p .707 .577 .707 r
F P
0 g
s
.26352 .65214 m .26887 .68289 L .23743 .68865 L p .707 .577 .707 r
F P
0 g
s
.70399 .68218 m .69914 .63129 L .67164 .62584 L p .707 .577 .707 r
F P
0 g
s
.69914 .63129 m .70399 .68218 L .73511 .68302 L p .707 .577 .707 r
F P
0 g
s
.20411 .74849 m .20509 .76619 L .18114 .77553 L p .707 .577 .707 r
F P
0 g
s
.32383 .74583 m .32481 .76353 L .29733 .75849 L p .707 .577 .707 r
F P
0 g
s
.29733 .75849 m .29636 .74079 L .32383 .74583 L p .707 .577 .707 r
F P
0 g
s
.79113 .62013 m .79598 .67102 L .81975 .65935 L p .707 .577 .707 r
F P
0 g
s
.81975 .65935 m .81491 .60846 L .79113 .62013 L p .707 .577 .707 r
F P
0 g
s
.39488 .257 m .37931 .7677 L .35626 .77461 L p .707 .577 .707 r
F P
0 g
s
.37931 .7677 m .39488 .257 L .42879 .25217 L p .707 .577 .707 r
F P
0 g
s
.20509 .76619 m .20411 .74849 L .23342 .74219 L p .707 .577 .707 r
F P
0 g
s
.67648 .67673 m .67164 .62584 L .65044 .61632 L p .707 .577 .707 r
F P
0 g
s
.67164 .62584 m .67648 .67673 L .70399 .68218 L p .707 .577 .707 r
F P
0 g
s
.29636 .74079 m .29733 .75849 L .26618 .75723 L p .707 .577 .707 r
F P
0 g
s
.26618 .75723 m .2652 .73953 L .29636 .74079 L p .707 .577 .707 r
F P
0 g
s
.23342 .74219 m .23439 .75989 L .20509 .76619 L p .707 .577 .707 r
F P
0 g
s
.81491 .60846 m .81975 .65935 L .83582 .6453 L p .707 .577 .707 r
F P
0 g
s
.83582 .6453 m .83097 .59441 L .81491 .60846 L p .707 .577 .707 r
F P
0 g
s
.23439 .75989 m .23342 .74219 L .2652 .73953 L p .707 .577 .707 r
F P
0 g
s
.2652 .73953 m .26618 .75723 L .23439 .75989 L p .707 .577 .707 r
F P
0 g
s
.59792 .25929 m .58236 .76999 L .54359 .76435 L p .707 .577 .707 r
F P
0 g
s
.54359 .76435 m .55915 .25364 L .59792 .25929 L p .707 .577 .707 r
F P
0 g
s
.74081 .74406 m .73545 .7133 L .70441 .71312 L p .707 .577 .707 r
F P
0 g
s
.73545 .7133 m .74081 .74406 L .77225 .7383 L p .707 .577 .707 r
F P
0 g
s
.77225 .7383 m .76689 .70754 L .73545 .7133 L p .707 .577 .707 r
F P
0 g
s
.76689 .70754 m .77225 .7383 L .80102 .72717 L p .707 .577 .707 r
F P
0 g
s
.80102 .72717 m .79566 .69641 L .76689 .70754 L p .707 .577 .707 r
F P
0 g
s
.73352 .76261 m .73255 .74491 L .70139 .74366 L p .707 .577 .707 r
F P
0 g
s
.73255 .74491 m .73352 .76261 L .76531 .75996 L p .707 .577 .707 r
F P
0 g
s
.76531 .75996 m .76433 .74226 L .73255 .74491 L p .707 .577 .707 r
F P
0 g
s
.76433 .74226 m .76531 .75996 L .79461 .75365 L p .707 .577 .707 r
F P
0 g
s
.79461 .75365 m .79364 .73595 L .76433 .74226 L p .707 .577 .707 r
F P
0 g
s
.41322 .76287 m .42879 .25217 L .47023 .2499 L p .707 .577 .707 r
F P
0 g
s
.42879 .25217 m .41322 .76287 L .37931 .7677 L p .707 .577 .707 r
F P
0 g
s
.70977 .74387 m .70441 .71312 L .67682 .70701 L p .707 .577 .707 r
F P
0 g
s
.70441 .71312 m .70977 .74387 L .74081 .74406 L p .707 .577 .707 r
F P
0 g
s
.70237 .76136 m .70139 .74366 L .67392 .73862 L p .707 .577 .707 r
F P
0 g
s
.70139 .74366 m .70237 .76136 L .73352 .76261 L p .707 .577 .707 r
F P
0 g
s
.65529 .66721 m .65044 .61632 L .63763 .60365 L p .707 .577 .707 r
F P
0 g
s
.65044 .61632 m .65529 .66721 L .67648 .67673 L p .707 .577 .707 r
F P
0 g
s
.79566 .69641 m .80102 .72717 L .8243 .71174 L p .707 .577 .707 r
F P
0 g
s
.8243 .71174 m .81894 .68099 L .79566 .69641 L p .707 .577 .707 r
F P
0 g
s
.79364 .73595 m .79461 .75365 L .81857 .74432 L p .707 .577 .707 r
F P
0 g
s
.81857 .74432 m .81759 .72662 L .79364 .73595 L p .707 .577 .707 r
F P
0 g
s
.67392 .73862 m .67489 .75632 L .70237 .76136 L p .707 .577 .707 r
F P
0 g
s
.83097 .59441 m .83582 .6453 L .8426 .63026 L p .707 .577 .707 r
F P
0 g
s
.8426 .63026 m .83775 .57937 L .83097 .59441 L p .707 .577 .707 r
F P
0 g
s
.55915 .25364 m .54359 .76435 L .49959 .76111 L p .707 .577 .707 r
F P
0 g
s
.49959 .76111 m .51515 .2504 L .55915 .25364 L p .707 .577 .707 r
F P
0 g
s
.68218 .73776 m .67682 .70701 L .65537 .69558 L p .707 .577 .707 r
F P
0 g
s
.67682 .70701 m .68218 .73776 L .70977 .74387 L p .707 .577 .707 r
F P
0 g
s
.67489 .75632 m .67392 .73862 L .65281 .73029 L p .707 .577 .707 r
F P
0 g
s
.45467 .7606 m .47023 .2499 L .51515 .2504 L p .707 .577 .707 r
F P
0 g
s
.47023 .2499 m .45467 .7606 L .41322 .76287 L p .707 .577 .707 r
F P
0 g
s
.81894 .68099 m .8243 .71174 L .83982 .69354 L p .707 .577 .707 r
F P
0 g
s
.83982 .69354 m .83446 .66279 L .81894 .68099 L p .707 .577 .707 r
F P
0 g
s
.51515 .2504 m .49959 .76111 L .45467 .7606 L p .707 .577 .707 r
F P
0 g
s
.65281 .73029 m .65379 .74799 L .67489 .75632 L p .707 .577 .707 r
F P
0 g
s
.81759 .72662 m .81857 .74432 L .83482 .73286 L p .707 .577 .707 r
F P
0 g
s
.83482 .73286 m .83385 .71517 L .81759 .72662 L p .707 .577 .707 r
F P
0 g
s
.64248 .65454 m .63763 .60365 L .63446 .58909 L p .707 .577 .707 r
F P
0 g
s
.63763 .60365 m .64248 .65454 L .65529 .66721 L p .707 .577 .707 r
F P
0 g
s
.66073 .72633 m .65537 .69558 L .64217 .67994 L p .707 .577 .707 r
F P
0 g
s
.65537 .69558 m .66073 .72633 L .68218 .73776 L p .707 .577 .707 r
F P
0 g
s
.83775 .57937 m .8426 .63026 L .83943 .6157 L p .707 .577 .707 r
F P
0 g
s
.83943 .6157 m .83458 .56481 L .83775 .57937 L p .707 .577 .707 r
F P
0 g
s
.83446 .66279 m .83982 .69354 L .84604 .67434 L p .707 .577 .707 r
F P
0 g
s
.84604 .67434 m .84068 .64359 L .83446 .66279 L p .707 .577 .707 r
F P
0 g
s
.65379 .74799 m .65281 .73029 L .64014 .71948 L p .707 .577 .707 r
F P
0 g
s
.64014 .71948 m .64112 .73718 L .65379 .74799 L p .707 .577 .707 r
F P
0 g
s
.83385 .71517 m .83482 .73286 L .8418 .72041 L p .707 .577 .707 r
F P
0 g
s
.8418 .72041 m .84082 .70272 L .83385 .71517 L p .707 .577 .707 r
F P
0 g
s
.63446 .58909 m .63931 .63998 L .64248 .65454 L p .707 .577 .707 r
F P
0 g
s
.63931 .63998 m .63446 .58909 L .64124 .57405 L p .707 .577 .707 r
F P
0 g
s
.64217 .67994 m .64753 .71069 L .66073 .72633 L p .707 .577 .707 r
F P
0 g
s
.64753 .71069 m .64217 .67994 L .6385 .66162 L p .708 .578 .707 r
F P
0 g
s
.84068 .64359 m .84604 .67434 L .84237 .65603 L p .708 .578 .707 r
F P
0 g
s
.84237 .65603 m .83702 .62527 L .84068 .64359 L p .708 .578 .707 r
F P
0 g
s
.83458 .56481 m .83943 .6157 L .82662 .60303 L p .707 .577 .707 r
F P
0 g
s
.82662 .60303 m .82177 .55214 L .83458 .56481 L p .707 .577 .707 r
F P
0 g
s
.64112 .73718 m .64014 .71948 L .63714 .70725 L p .707 .577 .707 r
F P
0 g
s
.63714 .70725 m .63812 .72495 L .64112 .73718 L p .707 .577 .707 r
F P
0 g
s
.84082 .70272 m .8418 .72041 L .8388 .70819 L p .707 .577 .707 r
F P
0 g
s
.8388 .70819 m .83783 .69049 L .84082 .70272 L p .707 .577 .707 r
F P
0 g
s
.64124 .57405 m .64609 .62494 L .63931 .63998 L p .707 .577 .707 r
F P
0 g
s
.6385 .66162 m .64386 .69237 L .64753 .71069 L p .708 .578 .707 r
F P
0 g
s
.64609 .62494 m .64124 .57405 L .65731 .56 L p .707 .577 .707 r
F P
0 g
s
.64386 .69237 m .6385 .66162 L .64473 .64242 L p .707 .577 .707 r
F P
0 g
s
.3921 .64621 m .38726 .59532 L .35613 .59448 L p .707 .577 .707 r
F P
0 g
s
.38726 .59532 m .3921 .64621 L .4238 .64236 L p .707 .577 .707 r
F P
0 g
s
.4238 .64236 m .41895 .59147 L .38726 .59532 L p .707 .577 .707 r
F P
0 g
s
.83702 .62527 m .84237 .65603 L .82917 .64039 L p .707 .577 .707 r
F P
0 g
s
.82917 .64039 m .82381 .60963 L .83702 .62527 L p .707 .577 .707 r
F P
0 g
s
.41895 .59147 m .4238 .64236 L .45297 .6342 L p .707 .577 .707 r
F P
0 g
s
.45297 .6342 m .44812 .58331 L .41895 .59147 L p .707 .577 .707 r
F P
0 g
s
.82177 .55214 m .82662 .60303 L .80542 .59351 L p .707 .577 .707 r
F P
0 g
s
.80542 .59351 m .80058 .54262 L .82177 .55214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63812 .72495 m .63714 .70725 L .64412 .6948 L p .707 .577 .707 r
F P
0 g
s
.36098 .64537 m .35613 .59448 L .32863 .58903 L p .707 .577 .707 r
F P
0 g
s
.35613 .59448 m .36098 .64537 L .3921 .64621 L p .707 .577 .707 r
F P
0 g
s
.44812 .58331 m .45297 .6342 L .47674 .62253 L p .707 .577 .707 r
F P
0 g
s
.47674 .62253 m .4719 .57164 L .44812 .58331 L p .707 .577 .707 r
F P
0 g
s
.64412 .6948 m .64509 .7125 L .63812 .72495 L p .707 .577 .707 r
F P
0 g
s
.65731 .56 m .66215 .6109 L .64609 .62494 L p .707 .577 .707 r
F P
0 g
s
.66215 .6109 m .65731 .56 L .68108 .54833 L p .707 .577 .707 r
F P
0 g
s
.64473 .64242 m .65008 .67318 L .64386 .69237 L p .707 .577 .707 r
F P
0 g
s
.83783 .69049 m .8388 .70819 L .82613 .69738 L p .707 .577 .707 r
F P
0 g
s
.82613 .69738 m .82515 .67968 L .83783 .69049 L p .707 .577 .707 r
F P
0 g
s
.65008 .67318 m .64473 .64242 L .66024 .62422 L p .707 .577 .707 r
F P
0 g
s
.33347 .63992 m .32863 .58903 L .30743 .5795 L p .707 .577 .707 r
F P
0 g
s
.32863 .58903 m .33347 .63992 L .36098 .64537 L p .707 .577 .707 r
F P
0 g
s
.82381 .60963 m .82917 .64039 L .80772 .62895 L p .707 .577 .707 r
F P
0 g
s
.80772 .62895 m .80236 .5982 L .82381 .60963 L p .707 .577 .707 r
F P
0 g
s
.80058 .54262 m .80542 .59351 L .77792 .58806 L p .707 .577 .707 r
F P
0 g
s
.77792 .58806 m .77307 .53717 L .80058 .54262 L p .707 .577 .707 r
F P
0 g
s
.4719 .57164 m .47674 .62253 L .49281 .60849 L p .707 .577 .707 r
F P
0 g
s
.49281 .60849 m .48796 .5576 L .4719 .57164 L p .707 .577 .707 r
F P
0 g
s
.64509 .7125 m .64412 .6948 L .66037 .68335 L p .707 .577 .707 r
F P
0 g
s
.3978 .70724 m .39244 .67649 L .3614 .6763 L p .707 .577 .707 r
F P
0 g
s
.39244 .67649 m .3978 .70724 L .42924 .70148 L p .707 .577 .707 r
F P
0 g
s
.42924 .70148 m .42388 .67073 L .39244 .67649 L p .707 .577 .707 r
F P
0 g
s
.68593 .59922 m .68108 .54833 L .71025 .54017 L p .707 .577 .707 r
F P
0 g
s
.68108 .54833 m .68593 .59922 L .66215 .6109 L p .707 .577 .707 r
F P
0 g
s
.42388 .67073 m .42924 .70148 L .45801 .69035 L p .707 .577 .707 r
F P
0 g
s
.45801 .69035 m .45265 .65959 L .42388 .67073 L p .707 .577 .707 r
F P
0 g
s
.39051 .7258 m .38954 .7081 L .35838 .70685 L p .707 .577 .707 r
F P
0 g
s
.38954 .7081 m .39051 .7258 L .4223 .72314 L p .707 .577 .707 r
F P
0 g
s
.4223 .72314 m .42132 .70544 L .38954 .7081 L p .707 .577 .707 r
F P
0 g
s
.42132 .70544 m .4223 .72314 L .4516 .71684 L p .707 .577 .707 r
F P
0 g
s
.4516 .71684 m .45063 .69914 L .42132 .70544 L p .707 .577 .707 r
F P
0 g
s
.77307 .53717 m .77792 .58806 L .74679 .58722 L p .707 .577 .707 r
F P
0 g
s
.74679 .58722 m .74194 .53633 L .77307 .53717 L p .707 .577 .707 r
F P
0 g
s
.66037 .68335 m .66135 .70105 L .64509 .7125 L p .707 .577 .707 r
F P
0 g
s
.36676 .70706 m .3614 .6763 L .33381 .67019 L p .707 .577 .707 r
F P
0 g
s
.3614 .6763 m .36676 .70706 L .3978 .70724 L p .707 .577 .707 r
F P
0 g
s
.66024 .62422 m .6656 .65498 L .65008 .67318 L p .707 .577 .707 r
F P
0 g
s
.6656 .65498 m .66024 .62422 L .68352 .6088 L p .707 .577 .707 r
F P
0 g
s
.35936 .72454 m .35838 .70685 L .33091 .70181 L p .707 .577 .707 r
F P
0 g
s
.35838 .70685 m .35936 .72454 L .39051 .7258 L p .707 .577 .707 r
F P
0 g
s
.31228 .63039 m .30743 .5795 L .29462 .56684 L p .707 .577 .707 r
F P
0 g
s
.30743 .5795 m .31228 .63039 L .33347 .63992 L p .707 .577 .707 r
F P
0 g
s
.45265 .65959 m .45801 .69035 L .48129 .67493 L p .707 .577 .707 r
F P
0 g
s
.48129 .67493 m .47593 .64417 L .45265 .65959 L p .707 .577 .707 r
F P
0 g
s
.80236 .5982 m .80772 .62895 L .78013 .62284 L p .707 .577 .707 r
F P
0 g
s
.78013 .62284 m .77477 .59209 L .80236 .5982 L p .707 .577 .707 r
F P
0 g
s
.7151 .59106 m .71025 .54017 L .74194 .53633 L p .707 .577 .707 r
F P
0 g
s
.71025 .54017 m .7151 .59106 L .68593 .59922 L p .707 .577 .707 r
F P
0 g
s
.82515 .67968 m .82613 .69738 L .80502 .68904 L p .707 .577 .707 r
F P
0 g
s
.80502 .68904 m .80405 .67135 L .82515 .67968 L p .707 .577 .707 r
F P
0 g
s
.74194 .53633 m .74679 .58722 L .7151 .59106 L p .707 .577 .707 r
F P
0 g
s
.45063 .69914 m .4516 .71684 L .47556 .7075 L p .707 .577 .707 r
F P
0 g
s
.47556 .7075 m .47458 .6898 L .45063 .69914 L p .707 .577 .707 r
F P
0 g
s
.33091 .70181 m .33188 .7195 L .35936 .72454 L p .707 .577 .707 r
F P
0 g
s
.48796 .5576 m .49281 .60849 L .49959 .59345 L p .707 .577 .707 r
F P
0 g
s
.49959 .59345 m .49474 .54256 L .48796 .5576 L p .707 .577 .707 r
F P
0 g
s
.33917 .70095 m .33381 .67019 L .31236 .65876 L p .707 .577 .707 r
F P
0 g
s
.33381 .67019 m .33917 .70095 L .36676 .70706 L p .707 .577 .707 r
F P
0 g
s
.68888 .63955 m .68352 .6088 L .71229 .59766 L p .707 .577 .707 r
F P
0 g
s
.68352 .6088 m .68888 .63955 L .6656 .65498 L p .707 .577 .707 r
F P
0 g
s
.33188 .7195 m .33091 .70181 L .3098 .69347 L p .707 .577 .707 r
F P
0 g
s
.47593 .64417 m .48129 .67493 L .49681 .65673 L p .707 .577 .707 r
F P
0 g
s
.49681 .65673 m .49145 .62597 L .47593 .64417 L p .707 .577 .707 r
F P
0 g
s
.77477 .59209 m .78013 .62284 L .74909 .62266 L p .707 .577 .707 r
F P
0 g
s
.74909 .62266 m .74373 .5919 L .77477 .59209 L p .707 .577 .707 r
F P
0 g
s
.66135 .70105 m .66037 .68335 L .68433 .67401 L p .707 .577 .707 r
F P
0 g
s
.3098 .69347 m .31078 .71117 L .33188 .7195 L p .707 .577 .707 r
F P
0 g
s
.71765 .62842 m .71229 .59766 L .74373 .5919 L p .707 .577 .707 r
F P
0 g
s
.71229 .59766 m .71765 .62842 L .68888 .63955 L p .707 .577 .707 r
F P
0 g
s
.68433 .67401 m .68531 .69171 L .66135 .70105 L p .707 .577 .707 r
F P
0 g
s
.74373 .5919 m .74909 .62266 L .71765 .62842 L p .707 .577 .707 r
F P
0 g
s
.47458 .6898 m .47556 .7075 L .49181 .69605 L p .707 .577 .707 r
F P
0 g
s
.49181 .69605 m .49084 .67835 L .47458 .6898 L p .707 .577 .707 r
F P
0 g
s
.80405 .67135 m .80502 .68904 L .77755 .684 L p .707 .577 .707 r
F P
0 g
s
.77755 .684 m .77657 .66631 L .80405 .67135 L p .707 .577 .707 r
F P
0 g
s
.29947 .61773 m .29462 .56684 L .29145 .55227 L p .707 .577 .707 r
F P
0 g
s
.29462 .56684 m .29947 .61773 L .31228 .63039 L p .707 .577 .707 r
F P
0 g
s
.31772 .68952 m .31236 .65876 L .29916 .64312 L p .707 .577 .707 r
F P
0 g
s
.31236 .65876 m .31772 .68952 L .33917 .70095 L p .707 .577 .707 r
F P
0 g
s
.68531 .69171 m .68433 .67401 L .71363 .66771 L p .707 .577 .707 r
F P
0 g
s
.49474 .54256 m .49959 .59345 L .49642 .57888 L p .707 .577 .707 r
F P
0 g
s
.49642 .57888 m .49157 .52799 L .49474 .54256 L p .707 .577 .707 r
F P
0 g
s
.49145 .62597 m .49681 .65673 L .50303 .63753 L p .707 .577 .707 r
F P
0 g
s
.50303 .63753 m .49767 .60677 L .49145 .62597 L p .707 .577 .707 r
F P
0 g
s
.31078 .71117 m .3098 .69347 L .29713 .68266 L p .707 .577 .707 r
F P
0 g
s
.77657 .66631 m .77755 .684 L .74639 .68275 L p .707 .577 .707 r
F P
0 g
s
.74639 .68275 m .74542 .66505 L .77657 .66631 L p .707 .577 .707 r
F P
0 g
s
.71363 .66771 m .71461 .68541 L .68531 .69171 L p .707 .577 .707 r
F P
0 g
s
.29713 .68266 m .29811 .70036 L .31078 .71117 L p .707 .577 .707 r
F P
0 g
s
.71461 .68541 m .71363 .66771 L .74542 .66505 L p .707 .577 .707 r
F P
0 g
s
.74542 .66505 m .74639 .68275 L .71461 .68541 L p .707 .577 .707 r
F P
0 g
s
.49084 .67835 m .49181 .69605 L .49879 .6836 L p .707 .577 .707 r
F P
0 g
s
.49879 .6836 m .49781 .6659 L .49084 .67835 L p .707 .577 .707 r
F P
0 g
s
.29145 .55227 m .2963 .60316 L .29947 .61773 L p .707 .577 .707 r
F P
0 g
s
.2963 .60316 m .29145 .55227 L .29823 .53723 L p .707 .577 .707 r
F P
0 g
s
.29916 .64312 m .30451 .67388 L .31772 .68952 L p .707 .577 .707 r
F P
0 g
s
.30451 .67388 m .29916 .64312 L .29549 .6248 L p .708 .578 .707 r
F P
0 g
s
.49767 .60677 m .50303 .63753 L .49936 .61921 L p .708 .578 .707 r
F P
0 g
s
.49936 .61921 m .49401 .58846 L .49767 .60677 L p .708 .578 .707 r
F P
0 g
s
.49157 .52799 m .49642 .57888 L .48361 .56622 L p .707 .577 .707 r
F P
0 g
s
.48361 .56622 m .47876 .51533 L .49157 .52799 L p .707 .577 .707 r
F P
0 g
s
.29811 .70036 m .29713 .68266 L .29413 .67044 L p .707 .577 .707 r
F P
0 g
s
.29413 .67044 m .29511 .68813 L .29811 .70036 L p .707 .577 .707 r
F P
0 g
s
.49781 .6659 m .49879 .6836 L .49579 .67137 L p .707 .577 .707 r
F P
0 g
s
.49579 .67137 m .49481 .65367 L .49781 .6659 L p .707 .577 .707 r
F P
0 g
s
.29823 .53723 m .30308 .58812 L .2963 .60316 L p .707 .577 .707 r
F P
0 g
s
.29549 .6248 m .30085 .65556 L .30451 .67388 L p .708 .578 .707 r
F P
0 g
s
.30308 .58812 m .29823 .53723 L .31429 .52319 L p .707 .577 .707 r
F P
0 g
s
.30085 .65556 m .29549 .6248 L .30171 .60561 L p .707 .577 .707 r
F P
0 g
s
.49401 .58846 m .49936 .61921 L .48616 .60357 L p .707 .577 .707 r
F P
0 g
s
.48616 .60357 m .4808 .57282 L .49401 .58846 L p .707 .577 .707 r
F P
0 g
s
.47876 .51533 m .48361 .56622 L .46241 .5567 L p .707 .577 .707 r
F P
0 g
s
.46241 .5567 m .45756 .50581 L .47876 .51533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29511 .68813 m .29413 .67044 L .30111 .65799 L p .707 .577 .707 r
F P
0 g
s
.30111 .65799 m .30208 .67568 L .29511 .68813 L p .707 .577 .707 r
F P
0 g
s
.31429 .52319 m .31914 .57408 L .30308 .58812 L p .707 .577 .707 r
F P
0 g
s
.31914 .57408 m .31429 .52319 L .33807 .51152 L p .707 .577 .707 r
F P
0 g
s
.30171 .60561 m .30707 .63636 L .30085 .65556 L p .707 .577 .707 r
F P
0 g
s
.49481 .65367 m .49579 .67137 L .48312 .66056 L p .707 .577 .707 r
F P
0 g
s
.48312 .66056 m .48214 .64286 L .49481 .65367 L p .707 .577 .707 r
F P
0 g
s
.30707 .63636 m .30171 .60561 L .31723 .5874 L p .707 .577 .707 r
F P
0 g
s
.4808 .57282 m .48616 .60357 L .46471 .59214 L p .707 .577 .707 r
F P
0 g
s
.46471 .59214 m .45935 .56138 L .4808 .57282 L p .707 .577 .707 r
F P
0 g
s
.45756 .50581 m .46241 .5567 L .43491 .55125 L p .707 .577 .707 r
F P
0 g
s
.43491 .55125 m .43006 .50036 L .45756 .50581 L p .707 .577 .707 r
F P
0 g
s
.30208 .67568 m .30111 .65799 L .31736 .64653 L p .707 .577 .707 r
F P
0 g
s
.34292 .56241 m .33807 .51152 L .36724 .50336 L p .707 .577 .707 r
F P
0 g
s
.33807 .51152 m .34292 .56241 L .31914 .57408 L p .707 .577 .707 r
F P
0 g
s
.43006 .50036 m .43491 .55125 L .40378 .5504 L p .707 .577 .707 r
F P
0 g
s
.40378 .5504 m .39893 .49951 L .43006 .50036 L p .707 .577 .707 r
F P
0 g
s
.31736 .64653 m .31834 .66423 L .30208 .67568 L p .707 .577 .707 r
F P
0 g
s
.31723 .5874 m .32259 .61816 L .30707 .63636 L p .707 .577 .707 r
F P
0 g
s
.32259 .61816 m .31723 .5874 L .34051 .57198 L p .707 .577 .707 r
F P
0 g
s
.45935 .56138 m .46471 .59214 L .43712 .58603 L p .707 .577 .707 r
F P
0 g
s
.43712 .58603 m .43176 .55527 L .45935 .56138 L p .707 .577 .707 r
F P
0 g
s
.37209 .55425 m .36724 .50336 L .39893 .49951 L p .707 .577 .707 r
F P
0 g
s
.36724 .50336 m .37209 .55425 L .34292 .56241 L p .707 .577 .707 r
F P
0 g
s
.48214 .64286 m .48312 .66056 L .46201 .65223 L p .707 .577 .707 r
F P
0 g
s
.46201 .65223 m .46104 .63453 L .48214 .64286 L p .707 .577 .707 r
F P
0 g
s
.39893 .49951 m .40378 .5504 L .37209 .55425 L p .707 .577 .707 r
F P
0 g
s
.34587 .60274 m .34051 .57198 L .36928 .56085 L p .707 .577 .707 r
F P
0 g
s
.34051 .57198 m .34587 .60274 L .32259 .61816 L p .707 .577 .707 r
F P
0 g
s
.43176 .55527 m .43712 .58603 L .40608 .58584 L p .707 .577 .707 r
F P
0 g
s
.40608 .58584 m .40072 .55509 L .43176 .55527 L p .707 .577 .707 r
F P
0 g
s
.31834 .66423 m .31736 .64653 L .34132 .6372 L p .707 .577 .707 r
F P
0 g
s
.37464 .5916 m .36928 .56085 L .40072 .55509 L p .707 .577 .707 r
F P
0 g
s
.36928 .56085 m .37464 .5916 L .34587 .60274 L p .707 .577 .707 r
F P
0 g
s
.34132 .6372 m .34229 .65489 L .31834 .66423 L p .707 .577 .707 r
F P
0 g
s
.40072 .55509 m .40608 .58584 L .37464 .5916 L p .707 .577 .707 r
F P
0 g
s
.46104 .63453 m .46201 .65223 L .43454 .64719 L p .707 .577 .707 r
F P
0 g
s
.43454 .64719 m .43356 .62949 L .46104 .63453 L p .707 .577 .707 r
F P
0 g
s
.34229 .65489 m .34132 .6372 L .37062 .63089 L p .707 .577 .707 r
F P
0 g
s
.43356 .62949 m .43454 .64719 L .40338 .64594 L p .707 .577 .707 r
F P
0 g
s
.40338 .64594 m .40241 .62824 L .43356 .62949 L p .707 .577 .707 r
F P
0 g
s
.37062 .63089 m .3716 .64859 L .34229 .65489 L p .707 .577 .707 r
F P
0 g
s
.3716 .64859 m .37062 .63089 L .40241 .62824 L p .707 .577 .707 r
F P
0 g
s
.40241 .62824 m .40338 .64594 L .3716 .64859 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Moob4008Eoo`00Lgoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF3000NGoo001_Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH8001aOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH015YF0`00JWoo001WOol30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02001VOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001J
EP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUHA0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`03001JEUYF00H000AJEP03001JEUYF00IJEP04001JEUYFFUH6000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006=o
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Ggoo10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001MOol200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005]oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FGoo
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001HOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P005goo3`00@7oo
001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000AOol60004FUH00`00FUIJEP06FUH00`00
FUH00003000lOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000=Ool400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3000iOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000:Ool30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000gOol0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000
FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
27oo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00=Goo
001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=JEP0000002`0000=J
EP0000000P000UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<00004
FUH000000005FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000bOol0059oo`04001JEUYF0004FUH00`00FUIJEP04
FUH40002FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUH00000<7oo001BOol01000FUIJEP0015YF00<005YFFUH00UYF0P000goo0`0000=J
EP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0000EJEP00001JEP00009JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP03001JEUYF008000=oo`<000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00D000=JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00Dgoo00<005YF000015YF0`000goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP800007FUH005YFFUH005YF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00Dgoo00<0
05YF000015YF00<007ooOol00Woo0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000IJEP00000005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Woo0016Ool>0002FUH01000
FUIJEP0017oo00<005YF000025YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00P005YF000005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00@7oo1P0015YF00<005YFFUH0
1UYF00D005YFFUH005YF0080009oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00004FUH00000000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00AJEPd000IJEP03001JEUYF009JEP04001JEP00FUH3000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
03]oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00<0009JEP@0009JEP03001JEUYF009J
EP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00
FUH005YF0P001UYF00<005YFFUH01EYF1@001EYF1P001UYF00<005YFFUH00`0015YF00D005YFFUH0
05YF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00AJEQD000=oo`@000EJEP05001JEUYFFUH0000^Ool003Ioo`800003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH01000FUH005YF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH0100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YF00000`000goo0P00
0eYF00D005YFFUIJEP0002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000UYF00@005YFFUH000MJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP800003FUH005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP<000=oo`<000QJEP03001J
EUYF00IJEP03001JEUYF00=JEP<0009oo`800003FUH005YF009JEP03001oogoo02aoo`00<Woo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF
FUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YF000005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0004FUH01000FUIJEUYF0P0017oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`000Woo0P000eYF00<007ooOol0;7oo000aOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YF000000Ao
o`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080009JEP03
001JEUYF008002eoo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP8000Aoo`8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF008002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP<000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<007ooOol00Woo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF1P00;Goo000]Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF00800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF008000=oo`80009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH0000002eoo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00;Goo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH00`00FUIJEP03000]Ool002]oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP04001JEUYF
FUH20005FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000015YF000005YF0P001eYF00<005YFFUH015YF1P0017oo1`001EYF1P001EYF00D005YF001JEP00
02eoo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPh0
009JEP<000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH005YF
008000IJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009J
EP03001JEP0000MJEP03001JEUYF009JEP`000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP05001JEP00FUH0000]Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH6
000=Ool00`00FUIJEP0600000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000IJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP04000COol01000FUIJEP001Goo1`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0000IJEP00FUIJEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04FUH200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00Oomoo`0/Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH4000HOol00eYF001oo`04Ool400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000
FUH000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP04001JEUYFFUH2000LOol00eYF001o
o`02Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF000015YF00@005YF
000001ioo`04FUH007ooOol20006FUH00`00FUIJEP04FUH60008FUH90004FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0005FUH01000FUH000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH007oo02aoo`00;7oo00<005YF000015YF0P004goo3P0000EJ
EP00001JEP0000IJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00EJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000002Ool2000]Ool002aoo`04001JEUYF0002FUH00`00Oomoo`0?Ool40002FUH00`00FUIJ
EP06FUH01000FUH000000eYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH025YF0P000UYF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=oo`03001JEP0002eoo`00;7oo00H005YFFUH0
05YF000>Ool40006FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH000030003FUH01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0`000UYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool00`00FUH0000]Ool002aoo`03001JEUYF00@000]oo`800003FUH005YF00QJEP03001JEUYF
00IJEP8000AJEP@00003FUH005YF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP06FUH01000FUH005YF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool00`00FUH0000]Ool002aoo`03
001JEUYF0080009JEP8000Ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP8000=JEP05001J
EP00001JEP020003FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001J
EUYF00EJEP03001JEP0000<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP80009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEP0001H0009JEP04001JEP00
0006Ool200000eYF0000000/Ool002aoo`03001JEUYF008000AJEPH000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEP00FUH30003FUH500001EYF001JEUYF00001EYF00<005YFFUH01eYF1000
1eYF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000UYF1@000eYF00<005YFFUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD000Ioo`03001JEP00009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH000EJ
EP@000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP02FUH00`00
FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`0000=JEP00Ool00Woo0`0000=JEP0000000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`000goo00@005YFFUH0009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH0
00EJEP04001JEUYF0008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0000AJ
EP03001JEUYF00=JEPh000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`04Ool3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
0003FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF0`000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF0`001eYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800004FUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`03Ool20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool0
02eoo`04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA00000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH01000FUH00000
0UYF0P0000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0003Ool20005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`80
009JEP<000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF00<0009JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP8000=JEP04001JEUYFFUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000goo00000006FUH00`00
FUIJEP04000HOol40005FUH00`00FUH00003000]Ool002eoo`80009JEP03001JEP0000IJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00800004FUH00000FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20002FUH20004FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001UYF00000000FUH000EJ
EPP001]oo`<000=JEP05001JEUYFFUH0000^Ool002ioo`03001JEP00009JEP03001JEUYF00EJEP03
001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP800003FUH0000000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP<000QJEP03001JEUYF009JEP800006FUH00000001JEP0015YF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
009JEP04001JEUYFFUH20004FUH01000FUH000006Woo00@005YFFUIJEP800003FUH005YF009JEP03
001oogoo02aoo`00;Woo0P000eYF00<005YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF
00@005YFFUH000=JEP03001JEP0000@00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP0000D000AJEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUH000030004FUH01000FUH0000067oo0P001UYF
0P000eYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00UYF1@001UYF00<005YFFUH01UYF
00<005YFFUH015YF1P000UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0`000UYF0P0015YF0`005Goo0`0000=J
EP00FUH01EYF00<005YF00000UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03
001JEP0000D0009JEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00AJEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH005YFFUH0
0003FUH20002FUH20002FUH00`00FUH0000BOol30004FUH00`00FUIJEP05FUH00`00FUH00002000^
Ool002ioo`03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF0000
00020005FUH5000015YF001JEP003Goo1@001eYF00<005YFFUH01EYF0P0000=oo`000000;Woo000]
Ool00`00FUH00004FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
00000002FUH00`00FUIJEP02FUH01000FUIJEUYF4P000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<007ooOol00`00;Goo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30005
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20003Ool00`00FUH0000]Ool002eoo`03001JEP0000=J
EP03001oogoo00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP020003Ool300000eYF
001oo`0/Ool002eoo`03001JEP00009JEP03001oogoo00Aoo`@0009JEP03001JEUYF00IJEP<0009J
EPH000eoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP040004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30003Ool20002FUH2000^
Ool002eoo`06001JEUYF001JEP002Woo40005Goo00<005YF00003`0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
001JEP800003FUH0000000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP8000=oo`8000AJEP8002ioo`00;Goo00<005YFFUH00P005Goo1@005Woo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH200000eYF00000003FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP03FUH00`00Oomo
o`0]Ool002eoo`04001JEUYF000FOol5000FOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000AJEP00FUIJEP<0009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000=oo`8000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH001Moo`<001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800005
FUH005YFFUH00002FUH20002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003Ool30005
FUH00`00FUIJEP02000`Ool002ioo`03FUH007oo01Ioo`l000Yoo`03001JEP00009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP0000AJEPT0009JEP03001JEUYF
00IJEP03001JEUYF00@000=oo`@00003FUH005YF00EJEP<0039oo`00;Woo00=JEP00Ool03Woo2000
15YF00<005YFFUH01UYF00<005YF00000`0017oo0`0015YF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000eYF0P001EYF00@005YFFUIJEQT000EJEP03001JEUYF00=JEP8003Aoo`00
;Woo00=JEP00Ool027oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Ioo`00;Woo00<005YF00001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00000hOol002ioo`04001JEUYF0003Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60003Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000jOol002ioo`800003FUH00000008000EJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20009Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04000mOol002ioo`800004FUH000000006FUH00`00FUIJEP02FUH8000?Ool40002FUH00`00FUIJ
EP03FUH01000FUIJEP001EYF00<005YFFUH01EYF8@001UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P003Woo6@00@Goo000_Ool20002FUH00`00FUIJEP03FUH6000DOol30003FUH5
0004FUH01000FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0P0047oo0P000UYF00<007ooOol0DGoo000^Ool00`00
FUIJEP02FUH01000FUIJEUYF10004Woo1P001eYF00@005YFFUIJEP<00005FUH005YFFUH00004FUH4
0003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH0
0`00FUIJEP03FUH2000?Ool00`00FUH00002FUH00`00Oomoo`1AOol002eoo`8000AJEP03001JEP00
008000=JEQ8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEP00008000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00=JEP8000ioo`04001JEUYF0002FUH00`00Oomoo`1AOol002eoo`8000AJEP80
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF009JEP80
0004Ool005YFFUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP04FUH2000=Ool01@00FUIJEUYF0000
0UYF00<007ooOol0DGoo000/Ool00`00FUH00002FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50006FUH00`00FUIJEP05FUH01@00FUIJEUYF00000goo0`000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@0015YF
1P0027oo00<005YFFUH00eYF0P00E7oo000/Ool00`00FUH0000200000goo00000004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP06FUH30004Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH2
0003FUH3000015YF000000000eYF2@001EYF0P00E7oo000/Ool00`00FUH00004Ool00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP06FUH00`00Oomoo`04Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH20005FUH50007FUH00`00FUH000020005FUH00`00Oomoo`1COol002aoo`80
00Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00Qoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001UYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool20008Ool200000eYF001JEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P002Goo0`000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0006FUH00`00FUIJEP03FUH200000eYF001oo`1EOol002aoo`<000Uoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000009Ool20002FUH300000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP060003FUH00`00FUIJEP03FUH01000FUH00000EWoo000/Ool2
00000eYF0000000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000:Ool00`00FUIJEP02
FUH200000goo000000020006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60003FUH50004FUH01@00FUIJEUYF0000EGoo
000/Ool20003FUH00`00Oomoo`0;Ool@000>Ool30004FUH20005Ool40002FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0007FUH01000FUIJEUYF0`0000=JEP00FUH00UYF00<007ooOol0Dgoo000]Ool01000FUIJEUYF0`00
9goo0P000UYF00<005YFFUH00UYF00<007ooOol027oo1@0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH04UYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF00<0
07ooOol0Dgoo000]Ool01@00FUIJEUYF00000UYF0P008Goo10001EYF00@005YFFUH0011oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPL000EJEP03001J
EUYF00MJEP03001JEUYF009JEP800005Ool005YFFUH0001EOol002ioo`04001JEUYF0004FUH5000H
Ool40002FUH00`00FUIJEP04FUH3000GOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH:0003
FUH50005FUH00`00FUIJEP06FUH01@00FUIJEUYF000017oo00<005YF0000EGoo000_Ool30005FUH0
1000FUIJEUYF60001UYF00<005YFFUH00eYF0P008Goo6P001EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01UYF00@005YFFUH000Ioo`8005Eoo`00<Goo00<005YFFUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8002moo`05001JEP00001o
o`020005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30007Ool2001E
Ool0039oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEP00000aOol00`00FUH00003Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH20009Ool3001DOol003Aoo`800003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<003=oo`8000Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000]oo`03001JEP0005Aoo`00=Woo1@00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P001goo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002goo0`0000=JEP00Ool0Dgoo000k
Ool90004FUH00`00FUIJEP02FUH7000jOol20009Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000<Ool20002FUH2001EOol004Aoo`T0045oo`04001JEP00000:Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP04000>Ool20004FUH2001EOol008ioo`80009JEP8000aoo`h000ioo`@00003FUH0
05YF00=JEP03001oogoo05Aoo`00Sgoo00D005YFFUH005YF00<0029oo`<000EJEP03001JEUYF009J
EP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEP<001]oo`@00003FUH005YF00EJEP03001JEUYF
008005Moo`00T7oo00<005YF00001EYF00<005YF00000`0047oo1`001EYF00<005YFFUH015YF0`00
FGoo002AOol20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001K
Ool0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<005eoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0`00HGoo002GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04001TOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL006Qoo`00WWoo4000Kgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59702 .75788 m .59401 .70487 L .56285 .70364 L p .707 .577 .707 r
F P
0 g
s
.59401 .70487 m .59702 .75788 L .6288 .75518 L p .707 .577 .707 r
F P
0 g
s
.6288 .75518 m .62579 .70217 L .59401 .70487 L p .707 .577 .707 r
F P
0 g
s
.62579 .70217 m .6288 .75518 L .6581 .74879 L p .707 .577 .707 r
F P
0 g
s
.6581 .74879 m .65509 .69578 L .62579 .70217 L p .707 .577 .707 r
F P
0 g
s
.56586 .75665 m .56285 .70364 L .53538 .69858 L p .707 .577 .707 r
F P
0 g
s
.56285 .70364 m .56586 .75665 L .59702 .75788 L p .707 .577 .707 r
F P
0 g
s
.65509 .69578 m .6581 .74879 L .68205 .73936 L p .707 .577 .707 r
F P
0 g
s
.68205 .73936 m .67903 .68635 L .65509 .69578 L p .707 .577 .707 r
F P
0 g
s
.53839 .75159 m .53538 .69858 L .51427 .6902 L p .707 .577 .707 r
F P
0 g
s
.53538 .69858 m .53839 .75159 L .56586 .75665 L p .707 .577 .707 r
F P
0 g
s
.67903 .68635 m .68205 .73936 L .6983 .72779 L p .707 .577 .707 r
F P
0 g
s
.6983 .72779 m .69529 .67478 L .67903 .68635 L p .707 .577 .707 r
F P
0 g
s
.60016 .83021 m .5968 .79646 L .56568 .79565 L p .707 .577 .707 r
F P
0 g
s
.5968 .79646 m .60016 .83021 L .63184 .82625 L p .707 .577 .707 r
F P
0 g
s
.63184 .82625 m .62848 .79249 L .5968 .79646 L p .707 .577 .707 r
F P
0 g
s
.62848 .79249 m .63184 .82625 L .66099 .8179 L p .707 .577 .707 r
F P
0 g
s
.66099 .8179 m .65763 .78414 L .62848 .79249 L p .707 .577 .707 r
F P
0 g
s
.56904 .82941 m .56568 .79565 L .53817 .79016 L p .707 .577 .707 r
F P
0 g
s
.56568 .79565 m .56904 .82941 L .60016 .83021 L p .707 .577 .707 r
F P
0 g
s
.59617 .86551 m .59556 .84746 L .5644 .84596 L p .707 .577 .707 r
F P
0 g
s
.59556 .84746 m .59617 .86551 L .62798 .86356 L p .707 .577 .707 r
F P
0 g
s
.62798 .86356 m .62738 .84551 L .59556 .84746 L p .707 .577 .707 r
F P
0 g
s
.65763 .78414 m .66099 .8179 L .68475 .80599 L p .707 .577 .707 r
F P
0 g
s
.68475 .80599 m .68138 .77223 L .65763 .78414 L p .707 .577 .707 r
F P
0 g
s
.51728 .74321 m .51427 .6902 L .50159 .67931 L p .707 .577 .707 r
F P
0 g
s
.51427 .6902 m .51728 .74321 L .53839 .75159 L p .707 .577 .707 r
F P
0 g
s
.62738 .84551 m .62798 .86356 L .65733 .85836 L p .707 .577 .707 r
F P
0 g
s
.65733 .85836 m .65673 .84031 L .62738 .84551 L p .707 .577 .707 r
F P
0 g
s
.5644 .84596 m .565 .86401 L .59617 .86551 L p .707 .577 .707 r
F P
0 g
s
.565 .86401 m .5644 .84596 L .53693 .84116 L p .707 .577 .707 r
F P
0 g
s
.54153 .82392 m .53817 .79016 L .51696 .78052 L p .707 .577 .707 r
F P
0 g
s
.53817 .79016 m .54153 .82392 L .56904 .82941 L p .707 .577 .707 r
F P
0 g
s
.69529 .67478 m .6983 .72779 L .70527 .71523 L p .707 .577 .707 r
F P
0 g
s
.70527 .71523 m .70225 .66222 L .69529 .67478 L p .707 .577 .707 r
F P
0 g
s
.53693 .84116 m .53754 .85922 L .565 .86401 L p .707 .577 .707 r
F P
0 g
s
.65673 .84031 m .65733 .85836 L .68135 .85041 L p .707 .577 .707 r
F P
0 g
s
.68135 .85041 m .68074 .83236 L .65673 .84031 L p .707 .577 .707 r
F P
0 g
s
.68138 .77223 m .68475 .80599 L .70079 .79169 L p .707 .577 .707 r
F P
0 g
s
.70079 .79169 m .69742 .75793 L .68138 .77223 L p .707 .577 .707 r
F P
0 g
s
.53754 .85922 m .53693 .84116 L .51586 .83354 L p .707 .577 .707 r
F P
0 g
s
.50159 .67931 m .5046 .73232 L .51728 .74321 L p .707 .577 .707 r
F P
0 g
s
.5046 .73232 m .50159 .67931 L .49859 .66698 L p .707 .577 .707 r
F P
0 g
s
.51586 .83354 m .51646 .85159 L .53754 .85922 L p .707 .577 .707 r
F P
0 g
s
.51696 .78052 m .52032 .81428 L .54153 .82392 L p .707 .577 .707 r
F P
0 g
s
.52032 .81428 m .51696 .78052 L .50413 .76767 L p .707 .577 .707 r
F P
0 g
s
.68074 .83236 m .68135 .85041 L .69768 .8405 L p .707 .577 .707 r
F P
0 g
s
.69768 .8405 m .69707 .82244 L .68074 .83236 L p .707 .577 .707 r
F P
0 g
s
.70225 .66222 m .70527 .71523 L .70226 .7029 L p .707 .577 .707 r
F P
0 g
s
.70226 .7029 m .69925 .64989 L .70225 .66222 L p .707 .577 .707 r
F P
0 g
s
.69742 .75793 m .70079 .79169 L .70754 .77638 L p .707 .577 .707 r
F P
0 g
s
.70754 .77638 m .70418 .74263 L .69742 .75793 L p .707 .577 .707 r
F P
0 g
s
.51646 .85159 m .51586 .83354 L .50323 .82383 L p .707 .577 .707 r
F P
0 g
s
.49859 .66698 m .5016 .71999 L .5046 .73232 L p .707 .577 .707 r
F P
0 g
s
.50413 .76767 m .50749 .80143 L .52032 .81428 L p .707 .577 .707 r
F P
0 g
s
.50323 .82383 m .50384 .84189 L .51646 .85159 L p .707 .577 .707 r
F P
0 g
s
.5016 .71999 m .49859 .66698 L .50556 .65442 L p .707 .577 .707 r
F P
0 g
s
.69707 .82244 m .69768 .8405 L .70472 .82959 L p .707 .577 .707 r
F P
0 g
s
.70472 .82959 m .70411 .81153 L .69707 .82244 L p .707 .577 .707 r
F P
0 g
s
.50749 .80143 m .50413 .76767 L .50094 .75287 L p .707 .577 .707 r
F P
0 g
s
.48443 .81898 m .49406 .31125 L .45005 .30823 L p .707 .577 .707 r
F P
0 g
s
.50384 .84189 m .50323 .82383 L .5003 .81299 L p .707 .577 .707 r
F P
0 g
s
.50094 .75287 m .5043 .78662 L .50749 .80143 L p .707 .577 .707 r
F P
0 g
s
.5003 .81299 m .5009 .83105 L .50384 .84189 L p .707 .577 .707 r
F P
0 g
s
.50556 .65442 m .50857 .70743 L .5016 .71999 L p .707 .577 .707 r
F P
0 g
s
.50857 .70743 m .50556 .65442 L .52181 .64285 L p .707 .577 .707 r
F P
0 g
s
.5043 .78662 m .50094 .75287 L .50769 .73756 L p .707 .577 .707 r
F P
0 g
s
.5009 .83105 m .5003 .81299 L .50734 .80208 L p .707 .577 .707 r
F P
0 g
s
.50769 .73756 m .51105 .77132 L .5043 .78662 L p .707 .577 .707 r
F P
0 g
s
.52181 .64285 m .52482 .69586 L .50857 .70743 L p .707 .577 .707 r
F P
0 g
s
.50734 .80208 m .50795 .82013 L .5009 .83105 L p .707 .577 .707 r
F P
0 g
s
.51105 .77132 m .50769 .73756 L .52373 .72326 L p .707 .577 .707 r
F P
0 g
s
.50795 .82013 m .50734 .80208 L .52367 .79216 L p .707 .577 .707 r
F P
0 g
s
.52373 .72326 m .52709 .75702 L .51105 .77132 L p .707 .577 .707 r
F P
0 g
s
.52367 .79216 m .52427 .81022 L .50795 .82013 L p .707 .577 .707 r
F P
0 g
s
.52427 .81022 m .52367 .79216 L .54768 .78422 L p .707 .577 .707 r
F P
0 g
s
.54768 .78422 m .54829 .80227 L .52427 .81022 L p .707 .577 .707 r
F P
0 g
s
.49406 .31125 m .48443 .81898 L .52937 .81887 L p .707 .577 .707 r
F P
0 g
s
.52482 .69586 m .52181 .64285 L .54576 .63342 L p .707 .577 .707 r
F P
0 g
s
.54576 .63342 m .54877 .68643 L .52482 .69586 L p .707 .577 .707 r
F P
0 g
s
.52709 .75702 m .52373 .72326 L .54749 .71135 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .55085 .74511 L .52709 .75702 L p .707 .577 .707 r
F P
0 g
s
.52937 .81887 m .53899 .31115 L .49406 .31125 L p .707 .577 .707 r
F P
0 g
s
.70418 .74263 m .70754 .77638 L .70435 .76158 L p .707 .577 .707 r
F P
0 g
s
.70435 .76158 m .70098 .72782 L .70418 .74263 L p .707 .577 .707 r
F P
0 g
s
.69925 .64989 m .70226 .7029 L .68959 .69201 L p .707 .577 .707 r
F P
0 g
s
.68959 .69201 m .68658 .639 L .69925 .64989 L p .707 .577 .707 r
F P
0 g
s
.54877 .68643 m .54576 .63342 L .57506 .62703 L p .707 .577 .707 r
F P
0 g
s
.57506 .62703 m .57807 .68004 L .54877 .68643 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .57663 .703 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.55085 .74511 m .54846 .72107 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.54846 .72107 m .54749 .71135 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.57807 .68004 m .57506 .62703 L .60684 .62433 L p .707 .577 .707 r
F P
0 g
s
.60684 .62433 m .60985 .67734 L .57807 .68004 L p .707 .577 .707 r
F P
0 g
s
.58 .73676 m .57663 .703 L .60832 .69904 L p .707 .577 .707 r
F P
0 g
s
.57663 .703 m .58 .73676 L .55085 .74511 L p .707 .577 .707 r
F P
0 g
s
.60832 .69904 m .61168 .73279 L .58 .73676 L p .707 .577 .707 r
F P
0 g
s
.57764 .79707 m .57703 .77901 L .60885 .77706 L p .707 .577 .707 r
F P
0 g
s
.60885 .77706 m .60946 .79512 L .57764 .79707 L p .707 .577 .707 r
F P
0 g
s
.58046 .30791 m .57187 .76116 L p .60477 .8096 L .707 .577 .707 r
F P
0 g
s
.54829 .80227 m .54768 .78422 L .57703 .77901 L p .707 .577 .707 r
F P
0 g
s
.57703 .77901 m .57764 .79707 L .54829 .80227 L p .707 .577 .707 r
F P
0 g
s
.57187 .76116 m .57083 .81564 L .60059 .81035 L p .707 .577 .707 r
F P
0 g
s
.60059 .81035 m .60477 .8096 L p .57187 .76116 L .707 .577 .707 r
F P
0 g
s
.53899 .31115 m .52937 .81887 L .57083 .81564 L p .707 .577 .707 r
F P
0 g
s
.57083 .81564 m .58046 .30791 L .53899 .31115 L p .707 .577 .707 r
F P
0 g
s
.44043 .81596 m .45005 .30823 L .41129 .30237 L p .707 .577 .707 r
F P
0 g
s
.45005 .30823 m .44043 .81596 L .48443 .81898 L p .707 .577 .707 r
F P
0 g
s
.70411 .81153 m .70472 .82959 L .70178 .81875 L p .707 .577 .707 r
F P
0 g
s
.70178 .81875 m .70118 .80069 L .70411 .81153 L p .707 .577 .707 r
F P
0 g
s
.25401 .72107 m .251 .66806 L .21984 .66682 L p .707 .577 .707 r
F P
0 g
s
.251 .66806 m .25401 .72107 L .28579 .71836 L p .707 .577 .707 r
F P
0 g
s
.28579 .71836 m .28278 .66535 L .251 .66806 L p .707 .577 .707 r
F P
0 g
s
.60985 .67734 m .60684 .62433 L .63799 .62556 L p .707 .577 .707 r
F P
0 g
s
.60477 .8096 m .6144 .30188 L .58046 .30791 L p .707 .577 .707 r
F P
0 g
s
.28278 .66535 m .28579 .71836 L .31509 .71198 L p .707 .577 .707 r
F P
0 g
s
.31509 .71198 m .31208 .65897 L .28278 .66535 L p .707 .577 .707 r
F P
0 g
s
.22285 .71983 m .21984 .66682 L .19237 .66176 L p .707 .577 .707 r
F P
0 g
s
.21984 .66682 m .22285 .71983 L .25401 .72107 L p .707 .577 .707 r
F P
0 g
s
.70098 .72782 m .70435 .76158 L .69152 .74873 L p .707 .577 .707 r
F P
0 g
s
.69152 .74873 m .68816 .71497 L .70098 .72782 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68658 .639 m .68959 .69201 L .66848 .68363 L p .707 .577 .707 r
F P
0 g
s
.66848 .68363 m .66547 .63062 L .68658 .639 L p .707 .577 .707 r
F P
0 g
s
.40166 .8101 m .41129 .30237 L .38155 .29425 L p .707 .577 .707 r
F P
0 g
s
.41129 .30237 m .40166 .8101 L .44043 .81596 L p .707 .577 .707 r
F P
0 g
s
.31208 .65897 m .31509 .71198 L .33904 .70254 L p .707 .577 .707 r
F P
0 g
s
.33904 .70254 m .33603 .64953 L .31208 .65897 L p .707 .577 .707 r
F P
0 g
s
.19538 .71477 m .19237 .66176 L .17126 .65338 L p .707 .577 .707 r
F P
0 g
s
.19237 .66176 m .19538 .71477 L .22285 .71983 L p .707 .577 .707 r
F P
0 g
s
.63799 .62556 m .641 .67857 L .60985 .67734 L p .707 .577 .707 r
F P
0 g
s
.63944 .69984 m .6428 .7336 L .61168 .73279 L p .707 .577 .707 r
F P
0 g
s
.61168 .73279 m .60832 .69904 L .63944 .69984 L p .707 .577 .707 r
F P
0 g
s
.64002 .77856 m .64062 .79662 L .60946 .79512 L p .707 .577 .707 r
F P
0 g
s
.60946 .79512 m .60885 .77706 L .64002 .77856 L p .707 .577 .707 r
F P
0 g
s
.6144 .30188 m .60477 .8096 L .62786 .80135 L p .707 .577 .707 r
F P
0 g
s
.62786 .80135 m .63749 .29363 L .6144 .30188 L p .707 .577 .707 r
F P
0 g
s
.70118 .80069 m .70178 .81875 L .68916 .80904 L p .707 .577 .707 r
F P
0 g
s
.68916 .80904 m .68856 .79098 L .70118 .80069 L p .707 .577 .707 r
F P
0 g
s
.33603 .64953 m .33904 .70254 L .35529 .69098 L p .707 .577 .707 r
F P
0 g
s
.35529 .69098 m .35228 .63797 L .33603 .64953 L p .707 .577 .707 r
F P
0 g
s
.66547 .63062 m .66848 .68363 L .641 .67857 L p .707 .577 .707 r
F P
0 g
s
.641 .67857 m .63799 .62556 L .66547 .63062 L p .707 .577 .707 r
F P
0 g
s
.25715 .7934 m .25379 .75964 L .22267 .75884 L p .707 .577 .707 r
F P
0 g
s
.25379 .75964 m .25715 .7934 L .28884 .78943 L p .707 .577 .707 r
F P
0 g
s
.28884 .78943 m .28547 .75567 L .25379 .75964 L p .707 .577 .707 r
F P
0 g
s
.28547 .75567 m .28884 .78943 L .31798 .78109 L p .707 .577 .707 r
F P
0 g
s
.31798 .78109 m .31462 .74733 L .28547 .75567 L p .707 .577 .707 r
F P
0 g
s
.68816 .71497 m .69152 .74873 L .67031 .73909 L p .707 .577 .707 r
F P
0 g
s
.67031 .73909 m .66695 .70533 L .68816 .71497 L p .707 .577 .707 r
F P
0 g
s
.22603 .7926 m .22267 .75884 L .19516 .75335 L p .707 .577 .707 r
F P
0 g
s
.22267 .75884 m .22603 .7926 L .25715 .7934 L p .707 .577 .707 r
F P
0 g
s
.37192 .80197 m .38155 .29425 L .36376 .28466 L p .707 .577 .707 r
F P
0 g
s
.38155 .29425 m .37192 .80197 L .40166 .8101 L p .707 .577 .707 r
F P
0 g
s
.25316 .8287 m .25255 .81064 L .22139 .80914 L p .707 .577 .707 r
F P
0 g
s
.25255 .81064 m .25316 .8287 L .28497 .82675 L p .707 .577 .707 r
F P
0 g
s
.28497 .82675 m .28437 .80869 L .25255 .81064 L p .707 .577 .707 r
F P
0 g
s
.31462 .74733 m .31798 .78109 L .34174 .76918 L p .707 .577 .707 r
F P
0 g
s
.34174 .76918 m .33838 .73542 L .31462 .74733 L p .707 .577 .707 r
F P
0 g
s
.17427 .70639 m .17126 .65338 L .15858 .64249 L p .707 .577 .707 r
F P
0 g
s
.17126 .65338 m .17427 .70639 L .19538 .71477 L p .707 .577 .707 r
F P
0 g
s
.28437 .80869 m .28497 .82675 L .31433 .82155 L p .707 .577 .707 r
F P
0 g
s
.31433 .82155 m .31372 .80349 L .28437 .80869 L p .707 .577 .707 r
F P
0 g
s
.22139 .80914 m .22199 .8272 L .25316 .8287 L p .707 .577 .707 r
F P
0 g
s
.22199 .8272 m .22139 .80914 L .19392 .80435 L p .707 .577 .707 r
F P
0 g
s
.19852 .78711 m .19516 .75335 L .17395 .7437 L p .707 .577 .707 r
F P
0 g
s
.19516 .75335 m .19852 .78711 L .22603 .7926 L p .707 .577 .707 r
F P
0 g
s
.35228 .63797 m .35529 .69098 L .36226 .67841 L p .707 .577 .707 r
F P
0 g
s
.36226 .67841 m .35924 .6254 L .35228 .63797 L p .707 .577 .707 r
F P
0 g
s
.66695 .70533 m .67031 .73909 L .6428 .7336 L p .707 .577 .707 r
F P
0 g
s
.6428 .7336 m .63944 .69984 L .66695 .70533 L p .707 .577 .707 r
F P
0 g
s
.19392 .80435 m .19453 .8224 L .22199 .8272 L p .707 .577 .707 r
F P
0 g
s
.68856 .79098 m .68916 .80904 L .66809 .80141 L p .707 .577 .707 r
F P
0 g
s
.66809 .80141 m .66748 .78336 L .68856 .79098 L p .707 .577 .707 r
F P
0 g
s
.31372 .80349 m .31433 .82155 L .33834 .8136 L p .707 .577 .707 r
F P
0 g
s
.33834 .8136 m .33774 .79554 L .31372 .80349 L p .707 .577 .707 r
F P
0 g
s
.33838 .73542 m .34174 .76918 L .35778 .75487 L p .707 .577 .707 r
F P
0 g
s
.35778 .75487 m .35441 .72111 L .33838 .73542 L p .707 .577 .707 r
F P
0 g
s
.19453 .8224 m .19392 .80435 L .17285 .79672 L p .707 .577 .707 r
F P
0 g
s
.63749 .29363 m .62786 .80135 L .63784 .79169 L p .707 .577 .707 r
F P
0 g
s
.63784 .79169 m .64747 .28397 L .63749 .29363 L p .707 .577 .707 r
F P
0 g
s
.15858 .64249 m .16159 .6955 L .17427 .70639 L p .707 .577 .707 r
F P
0 g
s
.16159 .6955 m .15858 .64249 L .15558 .63016 L p .707 .577 .707 r
F P
0 g
s
.17285 .79672 m .17345 .81478 L .19453 .8224 L p .707 .577 .707 r
F P
0 g
s
.17395 .7437 m .17731 .77746 L .19852 .78711 L p .707 .577 .707 r
F P
0 g
s
.17731 .77746 m .17395 .7437 L .16112 .73085 L p .707 .577 .707 r
F P
0 g
s
.33774 .79554 m .33834 .8136 L .35467 .80368 L p .707 .577 .707 r
F P
0 g
s
.35467 .80368 m .35406 .78563 L .33774 .79554 L p .707 .577 .707 r
F P
0 g
s
.66748 .78336 m .66809 .80141 L .64062 .79662 L p .707 .577 .707 r
F P
0 g
s
.64062 .79662 m .64002 .77856 L .66748 .78336 L p .707 .577 .707 r
F P
0 g
s
.35926 .66609 m .35624 .61308 L .35924 .6254 L p .707 .577 .707 r
F P
0 g
s
.35441 .72111 m .35778 .75487 L .36453 .73957 L p .707 .577 .707 r
F P
0 g
s
.36453 .73957 m .36117 .70581 L .35441 .72111 L p .707 .577 .707 r
F P
0 g
s
.35406 .78563 m .35467 .80368 L .36171 .79277 L p .707 .577 .707 r
F P
0 g
s
.36171 .79277 m .3611 .77472 L .35406 .78563 L p .707 .577 .707 r
F P
0 g
s
.35624 .61308 m .35926 .66609 L .34658 .6552 L p .707 .577 .707 r
F P
0 g
s
.34658 .6552 m .34357 .60219 L .35624 .61308 L p .707 .577 .707 r
F P
0 g
s
.35797 .69101 m .35894 .70073 L p .34851 .71192 L .707 .577 .707 r
F P
0 g
s
.35894 .70073 m .36134 .72477 L .35695 .72037 L p .707 .577 .707 r
F P
0 g
s
.35695 .72037 m .34851 .71192 L p .35894 .70073 L .707 .577 .707 r
F P
0 g
s
.34851 .71192 m .34515 .67816 L .35797 .69101 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35965 .27454 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35817 .76388 m .35877 .78193 L .34615 .77222 L p .707 .577 .707 r
F P
0 g
s
.34615 .77222 m .34555 .75417 L .35817 .76388 L p .707 .577 .707 r
F P
0 g
s
.35413 .79238 m .35517 .7379 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35517 .7379 m .36376 .28466 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35924 .6254 m .36226 .67841 L .35926 .66609 L p .707 .577 .707 r
F P
0 g
s
.36117 .70581 m .36453 .73957 L .36134 .72477 L p .707 .577 .707 r
F P
0 g
s
.36134 .72477 m .35797 .69101 L .36117 .70581 L p .707 .577 .707 r
F P
0 g
s
.3611 .77472 m .36171 .79277 L .35877 .78193 L p .707 .577 .707 r
F P
0 g
s
.35877 .78193 m .35817 .76388 L .3611 .77472 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35413 .79238 L .37192 .80197 L p .707 .577 .707 r
F P
0 g
s
.17345 .81478 m .17285 .79672 L .16022 .78702 L p .707 .577 .707 r
F P
0 g
s
.15558 .63016 m .15859 .68317 L .16159 .6955 L p .707 .577 .707 r
F P
0 g
s
.16112 .73085 m .16449 .76461 L .17731 .77746 L p .707 .577 .707 r
F P
0 g
s
.16022 .78702 m .16083 .80507 L .17345 .81478 L p .707 .577 .707 r
F P
0 g
s
.15859 .68317 m .15558 .63016 L .16255 .6176 L p .707 .577 .707 r
F P
0 g
s
.16449 .76461 m .16112 .73085 L .15793 .71605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64747 .28397 m .63784 .79169 L .63373 .78157 L p .707 .577 .707 r
F P
0 g
s
.63373 .78157 m .64336 .27385 L .64747 .28397 L p .707 .577 .707 r
F P
0 g
s
.16083 .80507 m .16022 .78702 L .15729 .77618 L p .707 .577 .707 r
F P
0 g
s
.15793 .71605 m .16129 .74981 L .16449 .76461 L p .707 .577 .707 r
F P
0 g
s
.15729 .77618 m .1579 .79423 L .16083 .80507 L p .707 .577 .707 r
F P
0 g
s
.16255 .6176 m .16556 .67061 L .15859 .68317 L p .707 .577 .707 r
F P
0 g
s
.35965 .27454 m .35002 .78226 L .35413 .79238 L p .707 .577 .707 r
F P
0 g
s
.35002 .78226 m .35965 .27454 L .36963 .26488 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16556 .67061 m .16255 .6176 L .1788 .60604 L p .707 .577 .707 r
F P
0 g
s
.16129 .74981 m .15793 .71605 L .16468 .70075 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34357 .60219 m .34658 .6552 L .32547 .64681 L p .707 .577 .707 r
F P
0 g
s
.32547 .64681 m .32246 .5938 L .34357 .60219 L p .707 .577 .707 r
F P
0 g
s
.1579 .79423 m .15729 .77618 L .16433 .76526 L p .707 .577 .707 r
F P
0 g
s
.16468 .70075 m .16805 .73451 L .16129 .74981 L p .707 .577 .707 r
F P
0 g
s
.1788 .60604 m .18181 .65905 L .16556 .67061 L p .707 .577 .707 r
F P
0 g
s
.16433 .76526 m .16494 .78332 L .1579 .79423 L p .707 .577 .707 r
F P
0 g
s
.64336 .27385 m .63373 .78157 L .61594 .77198 L p .707 .577 .707 r
F P
0 g
s
.61594 .77198 m .62557 .26426 L .64336 .27385 L p .707 .577 .707 r
F P
0 g
s
.18181 .65905 m .1788 .60604 L .20275 .5966 L p .707 .577 .707 r
F P
0 g
s
.16805 .73451 m .16468 .70075 L .18072 .68644 L p .707 .577 .707 r
F P
0 g
s
.32246 .5938 m .32547 .64681 L .29799 .64176 L p .707 .577 .707 r
F P
0 g
s
.29799 .64176 m .29498 .58875 L .32246 .5938 L p .707 .577 .707 r
F P
0 g
s
.34515 .67816 m .34851 .71192 L .3273 .70227 L p .707 .577 .707 r
F P
0 g
s
.3273 .70227 m .32394 .66851 L .34515 .67816 L p .707 .577 .707 r
F P
0 g
s
.36 .7726 m .36963 .26488 L .39272 .25663 L p .707 .577 .707 r
F P
0 g
s
.36963 .26488 m .36 .7726 L .35002 .78226 L p .707 .577 .707 r
F P
0 g
s
.20576 .64961 m .20275 .5966 L .23205 .59022 L p .707 .577 .707 r
F P
0 g
s
.20275 .5966 m .20576 .64961 L .18181 .65905 L p .707 .577 .707 r
F P
0 g
s
.16494 .78332 m .16433 .76526 L .18066 .75535 L p .707 .577 .707 r
F P
0 g
s
.18072 .68644 m .18408 .7202 L .16805 .73451 L p .707 .577 .707 r
F P
0 g
s
.29498 .58875 m .29799 .64176 L .26684 .64052 L p .707 .577 .707 r
F P
0 g
s
.26684 .64052 m .26383 .58751 L .29498 .58875 L p .707 .577 .707 r
F P
0 g
s
.18066 .75535 m .18126 .7734 L .16494 .78332 L p .707 .577 .707 r
F P
0 g
s
.18408 .7202 m .18072 .68644 L .20448 .67453 L p .707 .577 .707 r
F P
0 g
s
.23506 .64323 m .23205 .59022 L .26383 .58751 L p .707 .577 .707 r
F P
0 g
s
.23205 .59022 m .23506 .64323 L .20576 .64961 L p .707 .577 .707 r
F P
0 g
s
.26383 .58751 m .26684 .64052 L .23506 .64323 L p .707 .577 .707 r
F P
0 g
s
.32394 .66851 m .3273 .70227 L .29979 .69678 L p .707 .577 .707 r
F P
0 g
s
.29979 .69678 m .29643 .66302 L .32394 .66851 L p .707 .577 .707 r
F P
0 g
s
.34555 .75417 m .34615 .77222 L .32508 .7646 L p .707 .577 .707 r
F P
0 g
s
.32508 .7646 m .32447 .74654 L .34555 .75417 L p .707 .577 .707 r
F P
0 g
s
.62557 .26426 m .61594 .77198 L .5862 .76386 L p .707 .577 .707 r
F P
0 g
s
.5862 .76386 m .59583 .25613 L .62557 .26426 L p .707 .577 .707 r
F P
0 g
s
.20784 .70829 m .20448 .67453 L .23362 .66619 L p .707 .577 .707 r
F P
0 g
s
.20448 .67453 m .20784 .70829 L .18408 .7202 L p .707 .577 .707 r
F P
0 g
s
.73422 .67364 m .73121 .62063 L .70006 .61939 L p .707 .577 .707 r
F P
0 g
s
.73121 .62063 m .73422 .67364 L .766 .67093 L p .707 .577 .707 r
F P
0 g
s
.766 .67093 m .76299 .61792 L .73121 .62063 L p .707 .577 .707 r
F P
0 g
s
.18126 .7734 m .18066 .75535 L .20467 .7474 L p .707 .577 .707 r
F P
0 g
s
.76299 .61792 m .766 .67093 L .7953 .66455 L p .707 .577 .707 r
F P
0 g
s
.7953 .66455 m .79229 .61154 L .76299 .61792 L p .707 .577 .707 r
F P
0 g
s
.29643 .66302 m .29979 .69678 L .26867 .69598 L p .707 .577 .707 r
F P
0 g
s
.26867 .69598 m .26531 .66222 L .29643 .66302 L p .707 .577 .707 r
F P
0 g
s
.70307 .6724 m .70006 .61939 L .67258 .61434 L p .707 .577 .707 r
F P
0 g
s
.70006 .61939 m .70307 .6724 L .73422 .67364 L p .707 .577 .707 r
F P
0 g
s
.20467 .7474 m .20528 .76546 L .18126 .7734 L p .707 .577 .707 r
F P
0 g
s
.39272 .25663 m .38309 .76435 L .36 .7726 L p .707 .577 .707 r
F P
0 g
s
.38309 .76435 m .39272 .25663 L .42666 .25059 L p .707 .577 .707 r
F P
0 g
s
.23699 .69995 m .23362 .66619 L .26531 .66222 L p .707 .577 .707 r
F P
0 g
s
.23362 .66619 m .23699 .69995 L .20784 .70829 L p .707 .577 .707 r
F P
0 g
s
.26531 .66222 m .26867 .69598 L .23699 .69995 L p .707 .577 .707 r
F P
0 g
s
.32447 .74654 m .32508 .7646 L .29761 .7598 L p .707 .577 .707 r
F P
0 g
s
.29761 .7598 m .29701 .74175 L .32447 .74654 L p .707 .577 .707 r
F P
0 g
s
.79229 .61154 m .7953 .66455 L .81925 .65511 L p .707 .577 .707 r
F P
0 g
s
.81925 .65511 m .81624 .6021 L .79229 .61154 L p .707 .577 .707 r
F P
0 g
s
.20528 .76546 m .20467 .7474 L .23402 .7422 L p .707 .577 .707 r
F P
0 g
s
.67559 .66735 m .67258 .61434 L .65147 .60595 L p .707 .577 .707 r
F P
0 g
s
.67258 .61434 m .67559 .66735 L .70307 .6724 L p .707 .577 .707 r
F P
0 g
s
.59583 .25613 m .5862 .76386 L .54744 .758 L p .707 .577 .707 r
F P
0 g
s
.54744 .758 m .55706 .25027 L .59583 .25613 L p .707 .577 .707 r
F P
0 g
s
.23402 .7422 m .23463 .76025 L .20528 .76546 L p .707 .577 .707 r
F P
0 g
s
.29701 .74175 m .29761 .7598 L .26645 .7583 L p .707 .577 .707 r
F P
0 g
s
.26645 .7583 m .26584 .74025 L .29701 .74175 L p .707 .577 .707 r
F P
0 g
s
.73736 .73508 m .734 .70132 L .70288 .70052 L p .707 .577 .707 r
F P
0 g
s
.734 .70132 m .73736 .73508 L .76905 .73111 L p .707 .577 .707 r
F P
0 g
s
.76905 .73111 m .76569 .69736 L .734 .70132 L p .707 .577 .707 r
F P
0 g
s
.76569 .69736 m .76905 .73111 L .7982 .72277 L p .707 .577 .707 r
F P
0 g
s
.7982 .72277 m .79483 .68901 L .76569 .69736 L p .707 .577 .707 r
F P
0 g
s
.81624 .6021 m .81925 .65511 L .8355 .64355 L p .707 .577 .707 r
F P
0 g
s
.8355 .64355 m .83249 .59054 L .81624 .6021 L p .707 .577 .707 r
F P
0 g
s
.23463 .76025 m .23402 .7422 L .26584 .74025 L p .707 .577 .707 r
F P
0 g
s
.26584 .74025 m .26645 .7583 L .23463 .76025 L p .707 .577 .707 r
F P
0 g
s
.70624 .73428 m .70288 .70052 L .67537 .69503 L p .707 .577 .707 r
F P
0 g
s
.70288 .70052 m .70624 .73428 L .73736 .73508 L p .707 .577 .707 r
F P
0 g
s
.41703 .75831 m .42666 .25059 L .46812 .24736 L p .707 .577 .707 r
F P
0 g
s
.42666 .25059 m .41703 .75831 L .38309 .76435 L p .707 .577 .707 r
F P
0 g
s
.73337 .76157 m .73277 .74352 L .7016 .74202 L p .707 .577 .707 r
F P
0 g
s
.73277 .74352 m .73337 .76157 L .76519 .75962 L p .707 .577 .707 r
F P
0 g
s
.76519 .75962 m .76458 .74157 L .73277 .74352 L p .707 .577 .707 r
F P
0 g
s
.76458 .74157 m .76519 .75962 L .79454 .75442 L p .707 .577 .707 r
F P
0 g
s
.79454 .75442 m .79393 .73637 L .76458 .74157 L p .707 .577 .707 r
F P
0 g
s
.79483 .68901 m .7982 .72277 L .82195 .71086 L p .707 .577 .707 r
F P
0 g
s
.82195 .71086 m .81859 .6771 L .79483 .68901 L p .707 .577 .707 r
F P
0 g
s
.7016 .74202 m .70221 .76007 L .73337 .76157 L p .707 .577 .707 r
F P
0 g
s
.65448 .65896 m .65147 .60595 L .63879 .59507 L p .707 .577 .707 r
F P
0 g
s
.65147 .60595 m .65448 .65896 L .67559 .66735 L p .707 .577 .707 r
F P
0 g
s
.70221 .76007 m .7016 .74202 L .67414 .73722 L p .707 .577 .707 r
F P
0 g
s
.55706 .25027 m .54744 .758 L .50343 .75498 L p .707 .577 .707 r
F P
0 g
s
.50343 .75498 m .51306 .24725 L .55706 .25027 L p .707 .577 .707 r
F P
0 g
s
.67414 .73722 m .67474 .75528 L .70221 .76007 L p .707 .577 .707 r
F P
0 g
s
.79393 .73637 m .79454 .75442 L .81855 .74647 L p .707 .577 .707 r
F P
0 g
s
.81855 .74647 m .81795 .72842 L .79393 .73637 L p .707 .577 .707 r
F P
0 g
s
.67873 .72879 m .67537 .69503 L .65416 .68539 L p .707 .577 .707 r
F P
0 g
s
.67537 .69503 m .67873 .72879 L .70624 .73428 L p .707 .577 .707 r
F P
0 g
s
.4585 .75508 m .46812 .24736 L .51306 .24725 L p .707 .577 .707 r
F P
0 g
s
.46812 .24736 m .4585 .75508 L .41703 .75831 L p .707 .577 .707 r
F P
0 g
s
.83249 .59054 m .8355 .64355 L .84247 .63099 L p .707 .577 .707 r
F P
0 g
s
.84247 .63099 m .83946 .57798 L .83249 .59054 L p .707 .577 .707 r
F P
0 g
s
.51306 .24725 m .50343 .75498 L .4585 .75508 L p .707 .577 .707 r
F P
0 g
s
.81859 .6771 m .82195 .71086 L .83799 .69655 L p .707 .577 .707 r
F P
0 g
s
.83799 .69655 m .83463 .6628 L .81859 .6771 L p .707 .577 .707 r
F P
0 g
s
.67474 .75528 m .67414 .73722 L .65306 .7296 L p .707 .577 .707 r
F P
0 g
s
.65306 .7296 m .65367 .74765 L .67474 .75528 L p .707 .577 .707 r
F P
0 g
s
.63879 .59507 m .64181 .64808 L .65448 .65896 L p .707 .577 .707 r
F P
0 g
s
.65416 .68539 m .65753 .71914 L .67873 .72879 L p .707 .577 .707 r
F P
0 g
s
.81795 .72842 m .81855 .74647 L .83488 .73656 L p .707 .577 .707 r
F P
0 g
s
.83488 .73656 m .83428 .7185 L .81795 .72842 L p .707 .577 .707 r
F P
0 g
s
.64181 .64808 m .63879 .59507 L .63579 .58274 L p .707 .577 .707 r
F P
0 g
s
.65753 .71914 m .65416 .68539 L .64134 .67254 L p .707 .577 .707 r
F P
0 g
s
.83463 .6628 m .83799 .69655 L .84474 .68125 L p .707 .577 .707 r
F P
0 g
s
.84474 .68125 m .84138 .64749 L .83463 .6628 L p .707 .577 .707 r
F P
0 g
s
.65367 .74765 m .65306 .7296 L .64044 .71989 L p .707 .577 .707 r
F P
0 g
s
.83946 .57798 m .84247 .63099 L .83947 .61866 L p .707 .577 .707 r
F P
0 g
s
.83947 .61866 m .83646 .56565 L .83946 .57798 L p .707 .577 .707 r
F P
0 g
s
.64044 .71989 m .64104 .73795 L .65367 .74765 L p .707 .577 .707 r
F P
0 g
s
.64134 .67254 m .6447 .70629 L .65753 .71914 L p .707 .577 .707 r
F P
0 g
s
.63579 .58274 m .6388 .63575 L .64181 .64808 L p .707 .577 .707 r
F P
0 g
s
.83428 .7185 m .83488 .73656 L .84192 .72565 L p .707 .577 .707 r
F P
0 g
s
.84192 .72565 m .84132 .70759 L .83428 .7185 L p .707 .577 .707 r
F P
0 g
s
.6447 .70629 m .64134 .67254 L .63814 .65773 L p .707 .577 .707 r
F P
0 g
s
.6388 .63575 m .63579 .58274 L .64276 .57018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84138 .64749 m .84474 .68125 L .84155 .66645 L p .707 .577 .707 r
F P
0 g
s
.84155 .66645 m .83819 .63269 L .84138 .64749 L p .707 .577 .707 r
F P
0 g
s
.64104 .73795 m .64044 .71989 L .6375 .70905 L p .707 .577 .707 r
F P
0 g
s
.83646 .56565 m .83947 .61866 L .82679 .60777 L p .707 .577 .707 r
F P
0 g
s
.82679 .60777 m .82378 .55476 L .83646 .56565 L p .707 .577 .707 r
F P
0 g
s
.6375 .70905 m .63811 .72711 L .64104 .73795 L p .707 .577 .707 r
F P
0 g
s
.63814 .65773 m .64151 .69149 L .6447 .70629 L p .707 .577 .707 r
F P
0 g
s
.64276 .57018 m .64577 .62319 L .6388 .63575 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84132 .70759 m .84192 .72565 L .83899 .7148 L p .707 .577 .707 r
F P
0 g
s
.83899 .7148 m .83838 .69675 L .84132 .70759 L p .707 .577 .707 r
F P
0 g
s
.64151 .69149 m .63814 .65773 L .6449 .64243 L p .707 .577 .707 r
F P
0 g
s
.64577 .62319 m .64276 .57018 L .65901 .55861 L p .707 .577 .707 r
F P
0 g
s
.39121 .63682 m .3882 .58381 L .35705 .58258 L p .707 .577 .707 r
F P
0 g
s
.3882 .58381 m .39121 .63682 L .42299 .63412 L p .707 .577 .707 r
F P
0 g
s
.42299 .63412 m .41998 .58111 L .3882 .58381 L p .707 .577 .707 r
F P
0 g
s
.41998 .58111 m .42299 .63412 L .45229 .62773 L p .707 .577 .707 r
F P
0 g
s
.45229 .62773 m .44928 .57472 L .41998 .58111 L p .707 .577 .707 r
F P
0 g
s
.83819 .63269 m .84155 .66645 L .82872 .6536 L p .707 .577 .707 r
F P
0 g
s
.82872 .6536 m .82536 .61984 L .83819 .63269 L p .707 .577 .707 r
F P
0 g
s
.36006 .63559 m .35705 .58258 L .32957 .57752 L p .707 .577 .707 r
F P
0 g
s
.35705 .58258 m .36006 .63559 L .39121 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63811 .72711 m .6375 .70905 L .64454 .69814 L p .707 .577 .707 r
F P
0 g
s
.82378 .55476 m .82679 .60777 L .80568 .59939 L p .707 .577 .707 r
F P
0 g
s
.80568 .59939 m .80267 .54638 L .82378 .55476 L p .707 .577 .707 r
F P
0 g
s
.44928 .57472 m .45229 .62773 L .47624 .6183 L p .707 .577 .707 r
F P
0 g
s
.47624 .6183 m .47323 .56529 L .44928 .57472 L p .707 .577 .707 r
F P
0 g
s
.6449 .64243 m .64826 .67619 L .64151 .69149 L p .707 .577 .707 r
F P
0 g
s
.64454 .69814 m .64515 .71619 L .63811 .72711 L p .707 .577 .707 r
F P
0 g
s
.65901 .55861 m .66202 .61162 L .64577 .62319 L p .707 .577 .707 r
F P
0 g
s
.33258 .63053 m .32957 .57752 L .30846 .56914 L p .707 .577 .707 r
F P
0 g
s
.32957 .57752 m .33258 .63053 L .36006 .63559 L p .707 .577 .707 r
F P
0 g
s
.66202 .61162 m .65901 .55861 L .68296 .54917 L p .707 .577 .707 r
F P
0 g
s
.64826 .67619 m .6449 .64243 L .66094 .62812 L p .707 .577 .707 r
F P
0 g
s
.83838 .69675 m .83899 .7148 L .82637 .7051 L p .707 .577 .707 r
F P
0 g
s
.82637 .7051 m .82576 .68704 L .83838 .69675 L p .707 .577 .707 r
F P
0 g
s
.39435 .69827 m .39099 .66451 L .35987 .66371 L p .707 .577 .707 r
F P
0 g
s
.39099 .66451 m .39435 .69827 L .42604 .6943 L p .707 .577 .707 r
F P
0 g
s
.42604 .6943 m .42268 .66054 L .39099 .66451 L p .707 .577 .707 r
F P
0 g
s
.42268 .66054 m .42604 .6943 L .45519 .68595 L p .707 .577 .707 r
F P
0 g
s
.45519 .68595 m .45182 .65219 L .42268 .66054 L p .707 .577 .707 r
F P
0 g
s
.47323 .56529 m .47624 .6183 L .49249 .60673 L p .707 .577 .707 r
F P
0 g
s
.49249 .60673 m .48948 .55372 L .47323 .56529 L p .707 .577 .707 r
F P
0 g
s
.82536 .61984 m .82872 .6536 L .80752 .64395 L p .707 .577 .707 r
F P
0 g
s
.80752 .64395 m .80415 .6102 L .82536 .61984 L p .707 .577 .707 r
F P
0 g
s
.80267 .54638 m .80568 .59939 L .77821 .59433 L p .707 .577 .707 r
F P
0 g
s
.77821 .59433 m .7752 .54132 L .80267 .54638 L p .707 .577 .707 r
F P
0 g
s
.36323 .69746 m .35987 .66371 L .33236 .65821 L p .707 .577 .707 r
F P
0 g
s
.35987 .66371 m .36323 .69746 L .39435 .69827 L p .707 .577 .707 r
F P
0 g
s
.39036 .72476 m .38976 .7067 L .35859 .7052 L p .707 .577 .707 r
F P
0 g
s
.38976 .7067 m .39036 .72476 L .42218 .72281 L p .707 .577 .707 r
F P
0 g
s
.42218 .72281 m .42157 .70475 L .38976 .7067 L p .707 .577 .707 r
F P
0 g
s
.64515 .71619 m .64454 .69814 L .66087 .68822 L p .707 .577 .707 r
F P
0 g
s
.42157 .70475 m .42218 .72281 L .45153 .71761 L p .707 .577 .707 r
F P
0 g
s
.45153 .71761 m .45092 .69955 L .42157 .70475 L p .707 .577 .707 r
F P
0 g
s
.45182 .65219 m .45519 .68595 L .47894 .67404 L p .707 .577 .707 r
F P
0 g
s
.47894 .67404 m .47558 .64029 L .45182 .65219 L p .707 .577 .707 r
F P
0 g
s
.66094 .62812 m .6643 .66188 L .64826 .67619 L p .707 .577 .707 r
F P
0 g
s
.68597 .60219 m .68296 .54917 L .71226 .54279 L p .707 .577 .707 r
F P
0 g
s
.68296 .54917 m .68597 .60219 L .66202 .61162 L p .707 .577 .707 r
F P
0 g
s
.35859 .7052 m .3592 .72326 L .39036 .72476 L p .707 .577 .707 r
F P
0 g
s
.66087 .68822 m .66148 .70628 L .64515 .71619 L p .707 .577 .707 r
F P
0 g
s
.31147 .62215 m .30846 .56914 L .29578 .55825 L p .707 .577 .707 r
F P
0 g
s
.30846 .56914 m .31147 .62215 L .33258 .63053 L p .707 .577 .707 r
F P
0 g
s
.3592 .72326 m .35859 .7052 L .33113 .70041 L p .707 .577 .707 r
F P
0 g
s
.6643 .66188 m .66094 .62812 L .68469 .61622 L p .707 .577 .707 r
F P
0 g
s
.7752 .54132 m .77821 .59433 L .74705 .5931 L p .707 .577 .707 r
F P
0 g
s
.74705 .5931 m .74404 .54008 L .7752 .54132 L p .707 .577 .707 r
F P
0 g
s
.33113 .70041 m .33173 .71846 L .3592 .72326 L p .707 .577 .707 r
F P
0 g
s
.82576 .68704 m .82637 .7051 L .80529 .69747 L p .707 .577 .707 r
F P
0 g
s
.80529 .69747 m .80469 .67942 L .82576 .68704 L p .707 .577 .707 r
F P
0 g
s
.45092 .69955 m .45153 .71761 L .47554 .70966 L p .707 .577 .707 r
F P
0 g
s
.47554 .70966 m .47494 .6916 L .45092 .69955 L p .707 .577 .707 r
F P
0 g
s
.33572 .69197 m .33236 .65821 L .31115 .64857 L p .707 .577 .707 r
F P
0 g
s
.33236 .65821 m .33572 .69197 L .36323 .69746 L p .707 .577 .707 r
F P
0 g
s
.71527 .5958 m .71226 .54279 L .74404 .54008 L p .707 .577 .707 r
F P
0 g
s
.71226 .54279 m .71527 .5958 L .68597 .60219 L p .707 .577 .707 r
F P
0 g
s
.80415 .6102 m .80752 .64395 L .78001 .63846 L p .707 .577 .707 r
F P
0 g
s
.78001 .63846 m .77664 .6047 L .80415 .6102 L p .707 .577 .707 r
F P
0 g
s
.74404 .54008 m .74705 .5931 L .71527 .5958 L p .707 .577 .707 r
F P
0 g
s
.48948 .55372 m .49249 .60673 L .49946 .59417 L p .707 .577 .707 r
F P
0 g
s
.49946 .59417 m .49645 .54116 L .48948 .55372 L p .707 .577 .707 r
F P
0 g
s
.47558 .64029 m .47894 .67404 L .49498 .65974 L p .707 .577 .707 r
F P
0 g
s
.49498 .65974 m .49162 .62598 L .47558 .64029 L p .707 .577 .707 r
F P
0 g
s
.33173 .71846 m .33113 .70041 L .31005 .69278 L p .707 .577 .707 r
F P
0 g
s
.66148 .70628 m .66087 .68822 L .68489 .68027 L p .707 .577 .707 r
F P
0 g
s
.68805 .64997 m .68469 .61622 L .71384 .60787 L p .707 .577 .707 r
F P
0 g
s
.68469 .61622 m .68805 .64997 L .6643 .66188 L p .707 .577 .707 r
F P
0 g
s
.31005 .69278 m .31066 .71084 L .33173 .71846 L p .707 .577 .707 r
F P
0 g
s
.29578 .55825 m .2988 .61126 L .31147 .62215 L p .707 .577 .707 r
F P
0 g
s
.77664 .6047 m .78001 .63846 L .74889 .63766 L p .707 .577 .707 r
F P
0 g
s
.74889 .63766 m .74552 .6039 L .77664 .6047 L p .707 .577 .707 r
F P
0 g
s
.31115 .64857 m .31452 .68233 L .33572 .69197 L p .707 .577 .707 r
F P
0 g
s
.68489 .68027 m .68549 .69833 L .66148 .70628 L p .707 .577 .707 r
F P
0 g
s
.47494 .6916 m .47554 .70966 L .49187 .69974 L p .707 .577 .707 r
F P
0 g
s
.49187 .69974 m .49127 .68169 L .47494 .6916 L p .707 .577 .707 r
F P
0 g
s
.2988 .61126 m .29578 .55825 L .29278 .54592 L p .707 .577 .707 r
F P
0 g
s
.31452 .68233 m .31115 .64857 L .29833 .63572 L p .707 .577 .707 r
F P
0 g
s
.80469 .67942 m .80529 .69747 L .77783 .69268 L p .707 .577 .707 r
F P
0 g
s
.77783 .69268 m .77722 .67462 L .80469 .67942 L p .707 .577 .707 r
F P
0 g
s
.7172 .64163 m .71384 .60787 L .74552 .6039 L p .707 .577 .707 r
F P
0 g
s
.71384 .60787 m .7172 .64163 L .68805 .64997 L p .707 .577 .707 r
F P
0 g
s
.74552 .6039 m .74889 .63766 L .7172 .64163 L p .707 .577 .707 r
F P
0 g
s
.49162 .62598 m .49498 .65974 L .50173 .64443 L p .707 .577 .707 r
F P
0 g
s
.50173 .64443 m .49837 .61068 L .49162 .62598 L p .707 .577 .707 r
F P
0 g
s
.68549 .69833 m .68489 .68027 L .71424 .67507 L p .707 .577 .707 r
F P
0 g
s
.31066 .71084 m .31005 .69278 L .29743 .68308 L p .707 .577 .707 r
F P
0 g
s
.49645 .54116 m .49946 .59417 L .49646 .58184 L p .707 .577 .707 r
F P
0 g
s
.49646 .58184 m .49345 .52883 L .49645 .54116 L p .707 .577 .707 r
F P
0 g
s
.71424 .67507 m .71484 .69313 L .68549 .69833 L p .707 .577 .707 r
F P
0 g
s
.29743 .68308 m .29803 .70113 L .31066 .71084 L p .707 .577 .707 r
F P
0 g
s
.77722 .67462 m .77783 .69268 L .74666 .69118 L p .707 .577 .707 r
F P
0 g
s
.74666 .69118 m .74606 .67312 L .77722 .67462 L p .707 .577 .707 r
F P
0 g
s
.29833 .63572 m .30169 .66948 L .31452 .68233 L p .707 .577 .707 r
F P
0 g
s
.29278 .54592 m .29579 .59893 L .2988 .61126 L p .707 .577 .707 r
F P
0 g
s
.71484 .69313 m .71424 .67507 L .74606 .67312 L p .707 .577 .707 r
F P
0 g
s
.49127 .68169 m .49187 .69974 L .49891 .68883 L p .707 .577 .707 r
F P
0 g
s
.49891 .68883 m .49831 .67077 L .49127 .68169 L p .707 .577 .707 r
F P
0 g
s
.74606 .67312 m .74666 .69118 L .71484 .69313 L p .707 .577 .707 r
F P
0 g
s
.30169 .66948 m .29833 .63572 L .29513 .62092 L p .707 .577 .707 r
F P
0 g
s
.29579 .59893 m .29278 .54592 L .29975 .53336 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49837 .61068 m .50173 .64443 L .49854 .62963 L p .707 .577 .707 r
F P
0 g
s
.49854 .62963 m .49518 .59588 L .49837 .61068 L p .707 .577 .707 r
F P
0 g
s
.29803 .70113 m .29743 .68308 L .29449 .67223 L p .707 .577 .707 r
F P
0 g
s
.49345 .52883 m .49646 .58184 L .48378 .57096 L p .707 .577 .707 r
F P
0 g
s
.48378 .57096 m .48077 .51795 L .49345 .52883 L p .707 .577 .707 r
F P
0 g
s
.29449 .67223 m .2951 .69029 L .29803 .70113 L p .707 .577 .707 r
F P
0 g
s
.29513 .62092 m .29849 .65468 L .30169 .66948 L p .707 .577 .707 r
F P
0 g
s
.29975 .53336 m .30276 .58637 L .29579 .59893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49831 .67077 m .49891 .68883 L .49598 .67799 L p .707 .577 .707 r
F P
0 g
s
.49598 .67799 m .49537 .65993 L .49831 .67077 L p .707 .577 .707 r
F P
0 g
s
.29849 .65468 m .29513 .62092 L .30189 .60562 L p .707 .577 .707 r
F P
0 g
s
.30276 .58637 m .29975 .53336 L .316 .5218 L p .707 .577 .707 r
F P
0 g
s
.49518 .59588 m .49854 .62963 L .48571 .61678 L p .707 .577 .707 r
F P
0 g
s
.48571 .61678 m .48235 .58302 L .49518 .59588 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2951 .69029 m .29449 .67223 L .30153 .66132 L p .707 .577 .707 r
F P
0 g
s
.48077 .51795 m .48378 .57096 L .46267 .56257 L p .707 .577 .707 r
F P
0 g
s
.46267 .56257 m .45966 .50956 L .48077 .51795 L p .707 .577 .707 r
F P
0 g
s
.30189 .60562 m .30525 .63937 L .29849 .65468 L p .707 .577 .707 r
F P
0 g
s
.30153 .66132 m .30214 .67938 L .2951 .69029 L p .707 .577 .707 r
F P
0 g
s
.316 .5218 m .31901 .57481 L .30276 .58637 L p .707 .577 .707 r
F P
0 g
s
.31901 .57481 m .316 .5218 L .33995 .51236 L p .707 .577 .707 r
F P
0 g
s
.30525 .63937 m .30189 .60562 L .31793 .59131 L p .707 .577 .707 r
F P
0 g
s
.49537 .65993 m .49598 .67799 L .48336 .66828 L p .707 .577 .707 r
F P
0 g
s
.48336 .66828 m .48275 .65023 L .49537 .65993 L p .707 .577 .707 r
F P
0 g
s
.48235 .58302 m .48571 .61678 L .46451 .60714 L p .707 .577 .707 r
F P
0 g
s
.46451 .60714 m .46114 .57338 L .48235 .58302 L p .707 .577 .707 r
F P
0 g
s
.45966 .50956 m .46267 .56257 L .4352 .55752 L p .707 .577 .707 r
F P
0 g
s
.4352 .55752 m .43219 .50451 L .45966 .50956 L p .707 .577 .707 r
F P
0 g
s
.30214 .67938 m .30153 .66132 L .31786 .65141 L p .707 .577 .707 r
F P
0 g
s
.31793 .59131 m .32129 .62507 L .30525 .63937 L p .707 .577 .707 r
F P
0 g
s
.34296 .56537 m .33995 .51236 L .36925 .50598 L p .707 .577 .707 r
F P
0 g
s
.33995 .51236 m .34296 .56537 L .31901 .57481 L p .707 .577 .707 r
F P
0 g
s
.31786 .65141 m .31847 .66946 L .30214 .67938 L p .707 .577 .707 r
F P
0 g
s
.32129 .62507 m .31793 .59131 L .34168 .5794 L p .707 .577 .707 r
F P
0 g
s
.43219 .50451 m .4352 .55752 L .40404 .55628 L p .707 .577 .707 r
F P
0 g
s
.40404 .55628 m .40103 .50327 L .43219 .50451 L p .707 .577 .707 r
F P
0 g
s
.48275 .65023 m .48336 .66828 L .46228 .66066 L p .707 .577 .707 r
F P
0 g
s
.46228 .66066 m .46168 .6426 L .48275 .65023 L p .707 .577 .707 r
F P
0 g
s
.37226 .55899 m .36925 .50598 L .40103 .50327 L p .707 .577 .707 r
F P
0 g
s
.36925 .50598 m .37226 .55899 L .34296 .56537 L p .707 .577 .707 r
F P
0 g
s
.46114 .57338 m .46451 .60714 L .43699 .60165 L p .707 .577 .707 r
F P
0 g
s
.43699 .60165 m .43363 .56789 L .46114 .57338 L p .707 .577 .707 r
F P
0 g
s
.40103 .50327 m .40404 .55628 L .37226 .55899 L p .707 .577 .707 r
F P
0 g
s
.31847 .66946 m .31786 .65141 L .34188 .64346 L p .707 .577 .707 r
F P
0 g
s
.34504 .61316 m .34168 .5794 L .37083 .57105 L p .707 .577 .707 r
F P
0 g
s
.34168 .5794 m .34504 .61316 L .32129 .62507 L p .707 .577 .707 r
F P
0 g
s
.43363 .56789 m .43699 .60165 L .40587 .60085 L p .707 .577 .707 r
F P
0 g
s
.40587 .60085 m .40251 .56709 L .43363 .56789 L p .707 .577 .707 r
F P
0 g
s
.34188 .64346 m .34248 .66151 L .31847 .66946 L p .707 .577 .707 r
F P
0 g
s
.46168 .6426 m .46228 .66066 L .43482 .65586 L p .707 .577 .707 r
F P
0 g
s
.43482 .65586 m .43421 .63781 L .46168 .6426 L p .707 .577 .707 r
F P
0 g
s
.37419 .60481 m .37083 .57105 L .40251 .56709 L p .707 .577 .707 r
F P
0 g
s
.37083 .57105 m .37419 .60481 L .34504 .61316 L p .707 .577 .707 r
F P
0 g
s
.40251 .56709 m .40587 .60085 L .37419 .60481 L p .707 .577 .707 r
F P
0 g
s
.34248 .66151 m .34188 .64346 L .37123 .63826 L p .707 .577 .707 r
F P
0 g
s
.37123 .63826 m .37183 .65631 L .34248 .66151 L p .707 .577 .707 r
F P
0 g
s
.43421 .63781 m .43482 .65586 L .40365 .65436 L p .707 .577 .707 r
F P
0 g
s
.40365 .65436 m .40304 .63631 L .43421 .63781 L p .707 .577 .707 r
F P
0 g
s
.37183 .65631 m .37123 .63826 L .40304 .63631 L p .707 .577 .707 r
F P
0 g
s
.40304 .63631 m .40365 .65436 L .37183 .65631 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEP`007Uoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00
LWoo001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH01000FUH00000L7oo001[Ool300000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KGoo001YOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001ZOol006Qoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0001H0
00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00Hgoo100000=JEP00FUH025YF00<005YFFUH01EYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Ggoo10001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001M
Ool200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`l003moo`00Dgoo00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEP00008000EJEP03001J
EUYF00=JEP@0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=oo`04
001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP07FUH4
0004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`04001JEUYF0003FUH0
1000FUIJEUYF0P0017oo00@005YFFUH000EJEQ0000IJEPD00003FUH005YF009JEP04001JEUYF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;goo001COol01000FUIJEP000eYF00@005YF000000Ioo`03001JEUYF00L000AJEP03001J
EUYF00IJEP03001JEP0000D000=JEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00E7oo
00<005YF00000eYF0P0027oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1000
00=JEP00FUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF0000
0UYF00<005YFFUH020001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH000020004FUH00`00
FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000015YF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`04001JEP000005FUH20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH300001EYF001JEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaH00003FUH005YF009JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00?7oo100000=JEP00FUH025YF00<005YFFUH01EYF
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool003Qoo`@0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=J
EP03001JEUYF00AJEPL00004Ool000000005Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000fOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH200000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00@000Moo`D000aoo`D000AJEP05
001JEUYFFUH0000^Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEPT000AJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH4000:Ool?0008Ool300000eYF
001JEP02FUH00`00Oomoo`0/Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00IJEPD000EJEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YF00000P0027oo1P0015YF00<005YFFUH01UYF
00<005YF00000`0000=oo`0000000P0000AJEP00000000=JEP8002eoo`00<Goo0P001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH015YF00<005YFFUH01000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF0000009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP80
00Uoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP04001JEUYF0002
FUH2000]Ool002moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP<000EJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP800003FUH005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00<000=oo`<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF009JEP@002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF00000002FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<0
05YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0`00;Goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2000015YF00000000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH015YF0`0000=JEP00FUH01UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF000000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001J
EP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF1P0015YF00<005YFFUH01EYF1@001EYF00<005YF
FUH0100015YF00<005YFFUH015YF0P0000AJEP00000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF00=JEPT000=JEPd000QJEP03001JEUYF00=JEP04001JEP00FUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00007FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF00@005YF001JEPP000AJEP03001JEUYF009J
EPP000AJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200001EYF001JEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF3`00
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF500000=JEP00000015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH600000eYF00000003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008FUH00`00
FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP04000COol200000eYF0000000400001EYF000005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEPD000AJEP03001JEUYF008002eoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEP@001Moo`80009JEP04001oogooOol20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000015YF001JEUYF0P00;Goo000/Ool01000FUIJEP000eYF00@005YFFUIJEP8000moo`<000Uoo`04
001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF10000eYF00<007ooOol0:goo000/Ool01000FUIJEP000eYF00@0
05YF0000011oo`D000Qoo`80009JEP<000IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;Goo000]Ool00`00FUH00003FUH2000BOol5
0008Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH70004FUH50005
FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P001Woo00<005YF0000;Goo000]Ool00`00FUH00002FUH00`00FUIJ
EP05000=Ool?0004FUH00`00FUIJEP03FUHD0004FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40009Ool3000]Ool002eoo`03001JEP00008000AJEP04001JEUYFFUH=0004FUH00`00
FUIJEP06FUH20004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH0009JEP@000EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00@000aoo`800003FUH0000002aoo`00;Goo00@005YF000000EJEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000=JEP04
001JEUYFFUH400000eYF001JEP07FUH<000>Ool200000eYF001JEP02000/Ool002eoo`800003FUH0
05YF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH20004FUH00`00FUIJEP03FUH00`00FUH0000G000;Ool01P00FUIJEUYF001JEP80
02aoo`00;Goo0P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000Eoo`8000AJEP04001JEUYF000/Ool002eo
o`05001JEUYFFUH00004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUH00002FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP05FUH0
0`00FUIJEP020005FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000050002FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH500000eYF001JEP03FUH01000FUIJEP00;7oo000]Ool01@00FUIJEUYF00000UYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P0015YF00<005YF
FUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF0`001UYF0P0000AJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP000Woo1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001EYF00<0
05YF0000;7oo000]Ool01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP<00003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJ
EP<000EJEP800006FUH005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001EYF10001UYF00<005YFFUH0
15YF1@001UYF00<005YFFUH010000UYF00@005YFFUIJEP8000=JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP030006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001JEUYF
00800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPL0009JEP8000=JEP8000=JEP04
001JEUYFFUH40002FUH00`00FUIJEP05FUH30003FUH70006FUH400000eYF001JEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH9000;Ool300000eYF0000000200000eYF001JEP04FUH00`00
FUH00002000^Ool002ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000MJ
EP@000=JEP03001JEP0000<000EJEP03001JEP0000l00003FUH005YF00IJEP@000EJEP05001JEUYF
FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00UYF200037oo1P001UYF00<005YF00000P0015YF00D005YFFUIJEP00
02ioo`00;Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH0
1UYF00@005YFFUH000=JEP03001JEUYF009JEPD00005FUH005YFFUH00005FUH00`00FUIJEP07FUH0
1000FUIJEUYF10000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH00`00FUH000020004FUH@0004
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomoo`0/Ool002eoo`80
00EJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH01000FUIJEUYF60001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000AJEP800003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP8000=JEP8002eo
o`00;Goo0P001EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<0009JEP8002eoo`00;7oo00<005YF00001EYF00@005YFFUIJ
EP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF000000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002Ool4000]Ool002aoo`03001JEP0000EJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@0009oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200000eYF001JEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH40006
FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Woo0P00;Goo000/Ool01000FUIJEP0015YF0P001Goo
2@0015YF00<005YFFUH00UYF1`002Goo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00@005YF000000Moo`<002eoo`00;7oo00@005YFFUH000=JEP03001oogoo00ioo`T001Eoo`P000AJ
EP03001JEUYF00=JEPT000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP@000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00AJEP<000Moo`<00003FUH007oo02aoo`00;7oo00D005YFFUH005YF008001Aoo`D0
01Moo`04001JEUYF0003FUH:0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH200000eYF001J
EP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040008Ool20002FUH00`00FUH0000]Ool002ao
o`03001JEUYF008001Ioo`D001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEP8000=JEPH000AJEP03001JEUYF00IJEP<000AJEPD000Yoo`8000AJEP8002ioo`00
;7oo00@005YFFUH001Moo`D001Eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEP0000<000EJEPT000AJEP03001JEUYF00@000]oo`@00003FUH0
05YF00=JEP8002ioo`00;Goo00<005YF000067oo0`0057oo0P000UYF00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP<000=JEP03001JEUYF008000Aoo`L0
00Yoo`D000EJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P0000=JEP00Ool05Goo3`001goo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH005YF0005FUH00`00FUH000030002FUH2000<Ool90003FUH00`00FUIJEP04FUH00`00FUIJEP02
000`Ool002eoo`80009JEP03001oogoo00]oo`P000AJEP03001JEUYF00IJEP03001JEP0000<00003
Ool0000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol0
02eoo`04001JEUYFFUH30005Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH40002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00=7oo000]Ool20002FUH00`00FUIJEP0500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF1@000Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`00=Woo000]Ool20002FUH01000FUH000001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF60001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0027oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`00>Woo000]Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH:000;FUH0
0`00FUIJEP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000mOol002ioo`<0009JEP03001JEUYF00AJEP03001J
EUYF009JEP`000EJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00D0
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJEP03
001JEUYF009JEP8000mooaL0045oo`00;Woo00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF0P000UYF00<005YFFUH00UYF10000eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YF
FUH00UYF0P003Goo0P0000=JEP00FUH00P00Dgoo000]Ool20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP0000000UYF00<0
05YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF0P0037oo00H005YFFUIJEP00FUH2001COol002eo
o`8000AJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEPD0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJEP8000Yoo`8000AJEP04001J
EUYF001COol002aoo`03001JEP00009JEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP03001JEUYF008000Aoo`03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP8000Qoo`800003FUH005YF00=JEP04001JEUYF001COol002aoo`03001JEP000080
0003Ool0000000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP<000Io
o`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=oo`8000=JEP03001JEUYF00=JEP03001J
EP0005=oo`00;7oo00<005YF00001Goo0`0000=JEP00FUH01UYF00<005YFFUH015YF1@001UYF00<0
05YFFUH015YF0P0027oo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000
00=JEPH0009JEP03001JEUYF00=JEP8005Aoo`00;7oo0P002Goo0`001UYF00<005YFFUH01EYF0`00
1eYF00<005YFFUH010002Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000MJEP03001JEP00008000EJEP8005Aoo`00;7oo0`002goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`003Woo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF
00<005YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool200000eYF0000000=Ool@000COol20000
0eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03
FUH20002FUH00`00Oomoo`1COol002aoo`8000=JEP8002aoo`8000=JEP<0009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEPP000=JEP03001JEUYF00=JEP04001JEP00001FOol002eoo`06001JEUYFFUH0
05YF0`009Goo100000=JEP00FUH00UYF0P0000Aoo`00000000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP@0
00EJEP05001JEUYFFUH0001EOol002eoo`05001JEUYFFUH00004FUH3000LOol60005FUH01@00FUIJ
EUYF000017oo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF008000=JEP05001J
EUYFFUH0001EOol002ioo`04001JEUYF0005FUH00`00FUH00003000?Ool90004FUH00`00FUIJEP04
FUH01000FUIJEP0027oo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF009JEP8005Aoo`00;goo0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH015YF0`003Goo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF1P001UYF00<005YFFUH01EYF00@005YFFUIJEP800003Ool0000000=JEP8005Ao
o`00<Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0057oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF
2P000UYF1@001EYF00<005YFFUH01EYF00@005YF000000Eoo`800003FUH0000005Aoo`00<goo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
77oo8P0015YF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`002Goo0`00E7oo000fOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000cOol00`00FUH00005Ool20000
0eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04000<Ool3001DOol003Uoo`@0009J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Ioo`8000Qoo`D000AJEP03001JEUYF
00IJEP<000AJEPD000ioo`<00003FUH007oo05=oo`00?Goo5`00>Woo0`0037oo2@0015YF00<005YF
FUH010004Goo0P000UYF00<005YF0000E7oo002>Ool200000eYF001oo`0COol7000COol20004FUH2
001EOol008ioo`80009JEP8002Qoo`@00003FUH005YF00=JEP8005Eoo`00Sgoo00D005YFFUH005YF
00<0029oo`<000EJEP03001JEUYF009JEP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEPD001Uo
o`@00003FUH005YF00EJEP03001JEUYF008005Moo`00T7oo00<005YF00001EYF00@005YFFUIJEQT0
00EJEP03001JEUYF00AJEP<005Uoo`00TGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo002BOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00GGoo002DOol3
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000
Ggoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5001QOol009ao
o`T000AJEP03001JEUYF009JEPT006Ioo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59595 .74008 m .59897 .68303 L .56781 .68044 L p .707 .577 .707 r
F P
0 g
s
.59897 .68303 m .59595 .74008 L .62774 .7413 L p .707 .577 .707 r
F P
0 g
s
.62774 .7413 m .63075 .68425 L .59897 .68303 L p .707 .577 .707 r
F P
0 g
s
.63075 .68425 m .62774 .7413 L .65703 .74104 L p .707 .577 .707 r
F P
0 g
s
.65703 .74104 m .66005 .68399 L .63075 .68425 L p .707 .577 .707 r
F P
0 g
s
.5648 .73749 m .56781 .68044 L .54034 .67673 L p .707 .577 .707 r
F P
0 g
s
.56781 .68044 m .5648 .73749 L .59595 .74008 L p .707 .577 .707 r
F P
0 g
s
.59412 .7871 m .59749 .74883 L .56636 .74576 L p .707 .577 .707 r
F P
0 g
s
.59749 .74883 m .59412 .7871 L .62581 .78972 L p .707 .577 .707 r
F P
0 g
s
.62581 .78972 m .62917 .75145 L .59749 .74883 L p .707 .577 .707 r
F P
0 g
s
.54034 .67673 m .53732 .73378 L .5648 .73749 L p .707 .577 .707 r
F P
0 g
s
.66005 .68399 m .65703 .74104 L .68098 .73932 L p .707 .577 .707 r
F P
0 g
s
.68098 .73932 m .68399 .68227 L .66005 .68399 L p .707 .577 .707 r
F P
0 g
s
.56636 .74576 m .563 .78403 L .59412 .7871 L p .707 .577 .707 r
F P
0 g
s
.62917 .75145 m .62581 .78972 L .65495 .79162 L p .707 .577 .707 r
F P
0 g
s
.65495 .79162 m .65832 .75335 L .62917 .75145 L p .707 .577 .707 r
F P
0 g
s
.563 .78403 m .56636 .74576 L .53885 .74254 L p .707 .577 .707 r
F P
0 g
s
.53732 .73378 m .54034 .67673 L .51923 .67228 L p .707 .577 .707 r
F P
0 g
s
.53885 .74254 m .53549 .78081 L .563 .78403 L p .707 .577 .707 r
F P
0 g
s
.51923 .67228 m .51621 .72933 L .53732 .73378 L p .707 .577 .707 r
F P
0 g
s
.65832 .75335 m .65495 .79162 L .67871 .79263 L p .707 .577 .707 r
F P
0 g
s
.67871 .79263 m .68207 .75436 L .65832 .75335 L p .707 .577 .707 r
F P
0 g
s
.59635 .83763 m .59695 .81877 L .56579 .81645 L p .707 .577 .707 r
F P
0 g
s
.59695 .81877 m .59635 .83763 L .62816 .83805 L p .707 .577 .707 r
F P
0 g
s
.62816 .83805 m .62877 .81919 L .59695 .81877 L p .707 .577 .707 r
F P
0 g
s
.62877 .81919 m .62816 .83805 L .65752 .83654 L p .707 .577 .707 r
F P
0 g
s
.65752 .83654 m .65812 .81767 L .62877 .81919 L p .707 .577 .707 r
F P
0 g
s
.56579 .81645 m .56518 .83532 L .59635 .83763 L p .707 .577 .707 r
F P
0 g
s
.53549 .78081 m .53885 .74254 L .51765 .73948 L p .707 .577 .707 r
F P
0 g
s
.68399 .68227 m .68098 .73932 L .69724 .7363 L p .707 .577 .707 r
F P
0 g
s
.69724 .7363 m .70025 .67925 L .68399 .68227 L p .707 .577 .707 r
F P
0 g
s
.51765 .73948 m .51429 .77775 L .53549 .78081 L p .707 .577 .707 r
F P
0 g
s
.56518 .83532 m .56579 .81645 L .53832 .81247 L p .707 .577 .707 r
F P
0 g
s
.53832 .81247 m .53772 .83134 L .56518 .83532 L p .707 .577 .707 r
F P
0 g
s
.51621 .72933 m .51923 .67228 L .50655 .66751 L p .707 .577 .707 r
F P
0 g
s
.65812 .81767 m .65752 .83654 L .68153 .83324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83324 m .68214 .81437 L .65812 .81767 L p .707 .577 .707 r
F P
0 g
s
.68207 .75436 m .67871 .79263 L .69475 .79264 L p .707 .577 .707 r
F P
0 g
s
.69475 .79264 m .69811 .75437 L .68207 .75436 L p .707 .577 .707 r
F P
0 g
s
.50655 .66751 m .50354 .72456 L .51621 .72933 L p .707 .577 .707 r
F P
0 g
s
.53772 .83134 m .53832 .81247 L .51725 .80722 L p .707 .577 .707 r
F P
0 g
s
.51725 .80722 m .51664 .82608 L .53772 .83134 L p .707 .577 .707 r
F P
0 g
s
.51429 .77775 m .51765 .73948 L .50482 .73688 L p .707 .577 .707 r
F P
0 g
s
.50482 .73688 m .50146 .77515 L .51429 .77775 L p .707 .577 .707 r
F P
0 g
s
.70025 .67925 m .69724 .7363 L .7042 .73229 L p .707 .577 .707 r
F P
0 g
s
.7042 .73229 m .70721 .67524 L .70025 .67925 L p .707 .577 .707 r
F P
0 g
s
.68214 .81437 m .68153 .83324 L .69786 .82847 L p .707 .577 .707 r
F P
0 g
s
.69786 .82847 m .69846 .80961 L .68214 .81437 L p .707 .577 .707 r
F P
0 g
s
.50354 .72456 m .50655 .66751 L .50355 .6629 L p .707 .577 .707 r
F P
0 g
s
.51664 .82608 m .51725 .80722 L .50462 .8012 L p .707 .577 .707 r
F P
0 g
s
.69811 .75437 m .69475 .79264 L .7015 .79166 L p .707 .577 .707 r
F P
0 g
s
.7015 .79166 m .70486 .75339 L .69811 .75437 L p .707 .577 .707 r
F P
0 g
s
.50462 .8012 m .50402 .82006 L .51664 .82608 L p .707 .577 .707 r
F P
0 g
s
.50355 .6629 m .50054 .71995 L .50354 .72456 L p .707 .577 .707 r
F P
0 g
s
.50146 .77515 m .50482 .73688 L .50163 .73499 L p .707 .577 .707 r
F P
0 g
s
.49657 .82399 m .48694 .32918 L .44293 .32683 L p .707 .577 .707 r
F P
0 g
s
.50163 .73499 m .49826 .77326 L .50146 .77515 L p .707 .577 .707 r
F P
0 g
s
.50054 .71995 m .50355 .6629 L .51052 .65889 L p .707 .577 .707 r
F P
0 g
s
.50402 .82006 m .50462 .8012 L .50169 .795 L p .707 .577 .707 r
F P
0 g
s
.50169 .795 m .50109 .81387 L .50402 .82006 L p .707 .577 .707 r
F P
0 g
s
.51052 .65889 m .5075 .71594 L .50054 .71995 L p .707 .577 .707 r
F P
0 g
s
.49826 .77326 m .50163 .73499 L .50838 .73401 L p .707 .577 .707 r
F P
0 g
s
.50838 .73401 m .50502 .77228 L .49826 .77326 L p .707 .577 .707 r
F P
0 g
s
.5075 .71594 m .51052 .65889 L .52677 .65587 L p .707 .577 .707 r
F P
0 g
s
.50109 .81387 m .50169 .795 L .50873 .78924 L p .707 .577 .707 r
F P
0 g
s
.50873 .78924 m .50813 .80811 L .50109 .81387 L p .707 .577 .707 r
F P
0 g
s
.52677 .65587 m .52376 .71292 L .5075 .71594 L p .707 .577 .707 r
F P
0 g
s
.50502 .77228 m .50838 .73401 L .52442 .73402 L p .707 .577 .707 r
F P
0 g
s
.52442 .73402 m .52106 .77229 L .50502 .77228 L p .707 .577 .707 r
F P
0 g
s
.52376 .71292 m .52677 .65587 L .55072 .65415 L p .707 .577 .707 r
F P
0 g
s
.50813 .80811 m .50873 .78924 L .52506 .78448 L p .707 .577 .707 r
F P
0 g
s
.52506 .78448 m .52445 .80335 L .50813 .80811 L p .707 .577 .707 r
F P
0 g
s
.55072 .65415 m .5477 .7112 L .52376 .71292 L p .707 .577 .707 r
F P
0 g
s
.52106 .77229 m .52442 .73402 L .54817 .73503 L p .707 .577 .707 r
F P
0 g
s
.54817 .73503 m .54481 .7733 L .52106 .77229 L p .707 .577 .707 r
F P
0 g
s
.52445 .80335 m .52506 .78448 L .54907 .78118 L p .707 .577 .707 r
F P
0 g
s
.54907 .78118 m .54847 .80005 L .52445 .80335 L p .707 .577 .707 r
F P
0 g
s
.48694 .32918 m .49657 .82399 L .5415 .82192 L p .707 .577 .707 r
F P
0 g
s
.5415 .82192 m .53187 .32711 L .48694 .32918 L p .707 .577 .707 r
F P
0 g
s
.5477 .7112 m .55072 .65415 L .58002 .65389 L p .707 .577 .707 r
F P
0 g
s
.58002 .65389 m .577 .71094 L .5477 .7112 L p .707 .577 .707 r
F P
0 g
s
.54481 .7733 m .54817 .73503 L .57732 .73693 L p .707 .577 .707 r
F P
0 g
s
.57732 .73693 m .57396 .7752 L .54481 .7733 L p .707 .577 .707 r
F P
0 g
s
.57396 .7752 m .57732 .73693 L .60901 .73955 L p .707 .577 .707 r
F P
0 g
s
.60901 .73955 m .60564 .77782 L .57396 .7752 L p .707 .577 .707 r
F P
0 g
s
.54847 .80005 m .54907 .78118 L .57842 .77967 L p .707 .577 .707 r
F P
0 g
s
.57842 .77967 m .57782 .79853 L .54847 .80005 L p .707 .577 .707 r
F P
0 g
s
.57782 .79853 m .57842 .77967 L .61024 .78008 L p .707 .577 .707 r
F P
0 g
s
.61024 .78008 m .60964 .79895 L .57782 .79853 L p .707 .577 .707 r
F P
0 g
s
.53187 .32711 m .5415 .82192 L .58297 .81563 L p .707 .577 .707 r
F P
0 g
s
.577 .71094 m .58002 .65389 L .6118 .65511 L p .707 .577 .707 r
F P
0 g
s
.6118 .65511 m .60879 .71216 L .577 .71094 L p .707 .577 .707 r
F P
0 g
s
.58297 .81563 m .57334 .32082 L .53187 .32711 L p .707 .577 .707 r
F P
0 g
s
.70721 .67524 m .7042 .73229 L .7012 .72768 L p .707 .577 .707 r
F P
0 g
s
.7012 .72768 m .70421 .67062 L .70721 .67524 L p .707 .577 .707 r
F P
0 g
s
.69846 .80961 m .69786 .82847 L .7049 .82271 L p .707 .577 .707 r
F P
0 g
s
.7049 .82271 m .7055 .80385 L .69846 .80961 L p .707 .577 .707 r
F P
0 g
s
.45256 .82164 m .44293 .32683 L .40417 .3203 L p .707 .577 .707 r
F P
0 g
s
.44293 .32683 m .45256 .82164 L .49657 .82399 L p .707 .577 .707 r
F P
0 g
s
.64013 .74262 m .63676 .78089 L .61419 .77866 L p .707 .577 .707 r
F P
0 g
s
.61419 .77866 m .60564 .77782 L p .61464 .76864 L .707 .577 .707 r
F P
0 g
s
.61464 .76864 m .64013 .74262 L .61419 .77866 L .707 .577 .707 r
F
.67043 .6614 m .66742 .71845 L .63994 .71475 L p F P
0 g
s
.63994 .71475 m .64295 .6577 L .67043 .6614 L p .707 .577 .707 r
F P
0 g
s
.64295 .6577 m .63994 .71475 L .60879 .71216 L p .707 .577 .707 r
F P
0 g
s
.60879 .71216 m .6118 .65511 L .64295 .6577 L p .707 .577 .707 r
F P
0 g
s
.66764 .74584 m .66427 .78411 L .63676 .78089 L p .707 .577 .707 r
F P
0 g
s
.63676 .78089 m .64013 .74262 L .66764 .74584 L p .707 .577 .707 r
F P
0 g
s
.6408 .80126 m .64141 .7824 L .66887 .78638 L p .707 .577 .707 r
F P
0 g
s
.60564 .77782 m .60901 .73955 L .64013 .74262 L p .707 .577 .707 r
F P
0 g
s
.64141 .7824 m .6408 .80126 L .60964 .79895 L p .707 .577 .707 r
F P
0 g
s
.60964 .79895 m .61024 .78008 L .64141 .7824 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .64997 .77928 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63037 .2984 m .63192 .37812 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63192 .37812 m .63999 .79321 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.57334 .32082 m .58297 .81563 L .61691 .80574 L p .707 .577 .707 r
F P
0 g
s
.61691 .80574 m .60728 .31093 L .57334 .32082 L p .707 .577 .707 r
F P
0 g
s
.70486 .75339 m .7015 .79166 L .69831 .78977 L p .707 .577 .707 r
F P
0 g
s
.69831 .78977 m .70167 .7515 L .70486 .75339 L p .707 .577 .707 r
F P
0 g
s
.41379 .81511 m .40417 .3203 L .37443 .31021 L p .707 .577 .707 r
F P
0 g
s
.40417 .3203 m .41379 .81511 L .45256 .82164 L p .707 .577 .707 r
F P
0 g
s
.7055 .80385 m .7049 .82271 L .70196 .81652 L p .707 .577 .707 r
F P
0 g
s
.70196 .81652 m .70257 .79765 L .7055 .80385 L p .707 .577 .707 r
F P
0 g
s
.70421 .67062 m .7012 .72768 L .68852 .72291 L p .707 .577 .707 r
F P
0 g
s
.68852 .72291 m .69154 .66586 L .70421 .67062 L p .707 .577 .707 r
F P
0 g
s
.25295 .70326 m .25596 .64621 L .2248 .64362 L p .707 .577 .707 r
F P
0 g
s
.25596 .64621 m .25295 .70326 L .28473 .70449 L p .707 .577 .707 r
F P
0 g
s
.28473 .70449 m .28774 .64744 L .25596 .64621 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28774 .64744 m .28473 .70449 L .31403 .70422 L p .707 .577 .707 r
F P
0 g
s
.31403 .70422 m .31704 .64717 L .28774 .64744 L p .707 .577 .707 r
F P
0 g
s
.22179 .70067 m .2248 .64362 L .19733 .63992 L p .707 .577 .707 r
F P
0 g
s
.2248 .64362 m .22179 .70067 L .25295 .70326 L p .707 .577 .707 r
F P
0 g
s
.60728 .31093 m .61691 .80574 L .63999 .79321 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .63037 .2984 L .60728 .31093 L p .707 .577 .707 r
F P
0 g
s
.70167 .7515 m .69831 .78977 L .68548 .78717 L p .707 .577 .707 r
F P
0 g
s
.68548 .78717 m .68884 .7489 L .70167 .7515 L p .707 .577 .707 r
F P
0 g
s
.25111 .75029 m .25448 .71202 L .22336 .70895 L p .707 .577 .707 r
F P
0 g
s
.25448 .71202 m .25111 .75029 L .2828 .7529 L p .707 .577 .707 r
F P
0 g
s
.2828 .7529 m .28616 .71463 L .25448 .71202 L p .707 .577 .707 r
F P
0 g
s
.19733 .63992 m .19431 .69697 L .22179 .70067 L p .707 .577 .707 r
F P
0 g
s
.31704 .64717 m .31403 .70422 L .33797 .7025 L p .707 .577 .707 r
F P
0 g
s
.33797 .7025 m .34099 .64545 L .31704 .64717 L p .707 .577 .707 r
F P
0 g
s
.22336 .70895 m .21999 .74722 L .25111 .75029 L p .707 .577 .707 r
F P
0 g
s
.28616 .71463 m .2828 .7529 L .31194 .75481 L p .707 .577 .707 r
F P
0 g
s
.31194 .75481 m .31531 .71654 L .28616 .71463 L p .707 .577 .707 r
F P
0 g
s
.21999 .74722 m .22336 .70895 L .19585 .70572 L p .707 .577 .707 r
F P
0 g
s
.19431 .69697 m .19733 .63992 L .17622 .63547 L p .707 .577 .707 r
F P
0 g
s
.38406 .80502 m .37443 .31021 L .35664 .29756 L p .707 .577 .707 r
F P
0 g
s
.37443 .31021 m .38406 .80502 L .41379 .81511 L p .707 .577 .707 r
F P
0 g
s
.19585 .70572 m .19248 .74399 L .21999 .74722 L p .707 .577 .707 r
F P
0 g
s
.69154 .66586 m .68852 .72291 L .66742 .71845 L p .707 .577 .707 r
F P
0 g
s
.66742 .71845 m .67043 .6614 L .69154 .66586 L p .707 .577 .707 r
F P
0 g
s
.70257 .79765 m .70196 .81652 L .68934 .8105 L p .707 .577 .707 r
F P
0 g
s
.68934 .8105 m .68995 .79163 L .70257 .79765 L p .707 .577 .707 r
F P
0 g
s
.17622 .63547 m .17321 .69252 L .19431 .69697 L p .707 .577 .707 r
F P
0 g
s
.31531 .71654 m .31194 .75481 L .3357 .75581 L p .707 .577 .707 r
F P
0 g
s
.3357 .75581 m .33906 .71754 L .31531 .71654 L p .707 .577 .707 r
F P
0 g
s
.25334 .80082 m .25394 .78195 L .22278 .77964 L p .707 .577 .707 r
F P
0 g
s
.25394 .78195 m .25334 .80082 L .28515 .80124 L p .707 .577 .707 r
F P
0 g
s
.28515 .80124 m .28576 .78237 L .25394 .78195 L p .707 .577 .707 r
F P
0 g
s
.28576 .78237 m .28515 .80124 L .31451 .79972 L p .707 .577 .707 r
F P
0 g
s
.31451 .79972 m .31511 .78086 L .28576 .78237 L p .707 .577 .707 r
F P
0 g
s
.22278 .77964 m .22217 .7985 L .25334 .80082 L p .707 .577 .707 r
F P
0 g
s
.19248 .74399 m .19585 .70572 L .17464 .70266 L p .707 .577 .707 r
F P
0 g
s
.34099 .64545 m .33797 .7025 L .35423 .69949 L p .707 .577 .707 r
F P
0 g
s
.35423 .69949 m .35724 .64244 L .34099 .64545 L p .707 .577 .707 r
F P
0 g
s
.17464 .70266 m .17128 .74093 L .19248 .74399 L p .707 .577 .707 r
F P
0 g
s
.22217 .7985 m .22278 .77964 L .19531 .77566 L p .707 .577 .707 r
F P
0 g
s
.68884 .7489 m .68548 .78717 L .66427 .78411 L p .707 .577 .707 r
F P
0 g
s
.66427 .78411 m .66764 .74584 L .68884 .7489 L p .707 .577 .707 r
F P
0 g
s
.19531 .77566 m .19471 .79452 L .22217 .7985 L p .707 .577 .707 r
F P
0 g
s
.64997 .77928 m .64035 .28447 L .63037 .2984 L p .707 .577 .707 r
F P
0 g
s
.17321 .69252 m .17622 .63547 L .16354 .6307 L p .707 .577 .707 r
F P
0 g
s
.31511 .78086 m .31451 .79972 L .33852 .79642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79642 m .33913 .77756 L .31511 .78086 L p .707 .577 .707 r
F P
0 g
s
.33906 .71754 m .3357 .75581 L .35174 .75583 L p .707 .577 .707 r
F P
0 g
s
.35174 .75583 m .3551 .71756 L .33906 .71754 L p .707 .577 .707 r
F P
0 g
s
.16354 .6307 m .16053 .68775 L .17321 .69252 L p .707 .577 .707 r
F P
0 g
s
.68995 .79163 m .68934 .8105 L .66827 .80524 L p .707 .577 .707 r
F P
0 g
s
.66827 .80524 m .66887 .78638 L .68995 .79163 L p .707 .577 .707 r
F P
0 g
s
.19471 .79452 m .19531 .77566 L .17424 .7704 L p .707 .577 .707 r
F P
0 g
s
.17424 .7704 m .17363 .78927 L .19471 .79452 L p .707 .577 .707 r
F P
0 g
s
.17128 .74093 m .17464 .70266 L .16181 .70006 L p .707 .577 .707 r
F P
0 g
s
.36119 .69548 m .3642 .63842 L .35724 .64244 L p .707 .577 .707 r
F P
0 g
s
.35724 .64244 m .35423 .69949 L .36119 .69548 L p .707 .577 .707 r
F P
0 g
s
.3642 .63842 m .36119 .69548 L .35819 .69086 L p .707 .577 .707 r
F P
0 g
s
.35819 .69086 m .3612 .63381 L .3642 .63842 L p .707 .577 .707 r
F P
0 g
s
.36627 .79237 m .35664 .29756 L .35253 .28359 L p .707 .577 .707 r
F P
0 g
s
.35664 .29756 m .36627 .79237 L .38406 .80502 L p .707 .577 .707 r
F P
0 g
s
.16181 .70006 m .15845 .73833 L .17128 .74093 L p .707 .577 .707 r
F P
0 g
s
.33913 .77756 m .33852 .79642 L .35485 .79166 L p .707 .577 .707 r
F P
0 g
s
.35485 .79166 m .35545 .77279 L .33913 .77756 L p .707 .577 .707 r
F P
0 g
s
.16053 .68775 m .16354 .6307 L .16054 .62608 L p .707 .577 .707 r
F P
0 g
s
.66887 .78638 m .66827 .80524 L .6408 .80126 L p .707 .577 .707 r
F P
0 g
s
.17363 .78927 m .17424 .7704 L .16162 .76438 L p .707 .577 .707 r
F P
0 g
s
.3551 .71756 m .35174 .75583 L .35849 .75484 L p .707 .577 .707 r
F P
0 g
s
.35849 .75484 m .36186 .71657 L .3551 .71756 L p .707 .577 .707 r
F P
0 g
s
.16162 .76438 m .16101 .78325 L .17363 .78927 L p .707 .577 .707 r
F P
0 g
s
.16054 .62608 m .15753 .68313 L .16053 .68775 L p .707 .577 .707 r
F P
0 g
s
.64035 .28447 m .64997 .77928 L .64947 .77756 L p .707 .577 .707 r
F P
0 g
s
.64534 .71934 m .64035 .28447 L .64947 .77756 L .707 .577 .707 r
F
.64587 .76531 m .63624 .2705 L .64035 .28447 L p F P
0 g
s
.63624 .2705 m .64587 .76531 L .62807 .75266 L p .707 .577 .707 r
F P
0 g
s
.64202 .64793 m .64106 .65895 L p .65149 .6888 L .707 .577 .707 r
F P
0 g
s
.64106 .65895 m .63866 .6862 L .64305 .68709 L p .707 .577 .707 r
F P
0 g
s
.64305 .68709 m .65149 .6888 L p .64106 .65895 L .707 .577 .707 r
F P
0 g
s
.64947 .77756 m .64587 .76531 L p .64534 .71934 L .707 .577 .707 r
F P
0 g
s
.15845 .73833 m .16181 .70006 L .15862 .69818 L p .707 .577 .707 r
F P
0 g
s
.15862 .69818 m .15525 .73645 L .15845 .73833 L p .707 .577 .707 r
F P
0 g
s
.35545 .77279 m .35485 .79166 L .36189 .7859 L p .707 .577 .707 r
F P
0 g
s
.36189 .7859 m .36249 .76703 L .35545 .77279 L p .707 .577 .707 r
F P
0 g
s
.36186 .71657 m .35849 .75484 L .3553 .75296 L p .707 .577 .707 r
F P
0 g
s
.3553 .75296 m .35866 .71469 L .36186 .71657 L p .707 .577 .707 r
F P
0 g
s
.36249 .76703 m .36189 .7859 L .35895 .77971 L p .707 .577 .707 r
F P
0 g
s
.35895 .77971 m .35956 .76084 L .36249 .76703 L p .707 .577 .707 r
F P
0 g
s
.3612 .63381 m .35819 .69086 L .34552 .68609 L p .707 .577 .707 r
F P
0 g
s
.34552 .68609 m .34853 .62904 L .3612 .63381 L p .707 .577 .707 r
F P
0 g
s
.35253 .28359 m .36216 .77839 L .36627 .79237 L p .707 .577 .707 r
F P
0 g
s
.36216 .77839 m .35253 .28359 L .36251 .26965 L p .707 .577 .707 r
F P
0 g
s
.15753 .68313 m .16054 .62608 L .16751 .62207 L p .707 .577 .707 r
F P
0 g
s
.16101 .78325 m .16162 .76438 L .15868 .75819 L p .707 .577 .707 r
F P
0 g
s
.15868 .75819 m .15808 .77706 L .16101 .78325 L p .707 .577 .707 r
F P
0 g
s
.16751 .62207 m .16449 .67912 L .15753 .68313 L p .707 .577 .707 r
F P
0 g
s
.15525 .73645 m .15862 .69818 L .16537 .69719 L p .707 .577 .707 r
F P
0 g
s
.16537 .69719 m .16201 .73546 L .15525 .73645 L p .707 .577 .707 r
F P
0 g
s
.62807 .75266 m .61845 .25785 L .63624 .2705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16449 .67912 m .16751 .62207 L .18376 .61906 L p .707 .577 .707 r
F P
0 g
s
.15808 .77706 m .15868 .75819 L .16572 .75243 L p .707 .577 .707 r
F P
0 g
s
.16572 .75243 m .16512 .7713 L .15808 .77706 L p .707 .577 .707 r
F P
0 g
s
.35866 .71469 m .3553 .75296 L .34247 .75036 L p .707 .577 .707 r
F P
0 g
s
.34247 .75036 m .34583 .71209 L .35866 .71469 L p .707 .577 .707 r
F P
0 g
s
.18376 .61906 m .18075 .67611 L .16449 .67912 L p .707 .577 .707 r
F P
0 g
s
.37214 .76446 m .36251 .26965 L .3856 .25713 L p .707 .577 .707 r
F P
0 g
s
.36251 .26965 m .37214 .76446 L .36216 .77839 L p .707 .577 .707 r
F P
0 g
s
.16201 .73546 m .16537 .69719 L .18141 .69721 L p .707 .577 .707 r
F P
0 g
s
.18141 .69721 m .17805 .73548 L .16201 .73546 L p .707 .577 .707 r
F P
0 g
s
.34853 .62904 m .34552 .68609 L .32441 .68164 L p .707 .577 .707 r
F P
0 g
s
.32441 .68164 m .32742 .62459 L .34853 .62904 L p .707 .577 .707 r
F P
0 g
s
.35956 .76084 m .35895 .77971 L .34633 .77369 L p .707 .577 .707 r
F P
0 g
s
.34633 .77369 m .34694 .75482 L .35956 .76084 L p .707 .577 .707 r
F P
0 g
s
.18075 .67611 m .18376 .61906 L .20771 .61733 L p .707 .577 .707 r
F P
0 g
s
.61845 .25785 m .62807 .75266 L .59834 .74257 L p .707 .577 .707 r
F P
0 g
s
.59834 .74257 m .58871 .24776 L .61845 .25785 L p .707 .577 .707 r
F P
0 g
s
.16512 .7713 m .16572 .75243 L .18205 .74766 L p .707 .577 .707 r
F P
0 g
s
.34583 .71209 m .34247 .75036 L .32126 .7473 L p .707 .577 .707 r
F P
0 g
s
.32126 .7473 m .32463 .70903 L .34583 .71209 L p .707 .577 .707 r
F P
0 g
s
.18205 .74766 m .18144 .76653 L .16512 .7713 L p .707 .577 .707 r
F P
0 g
s
.20771 .61733 m .20469 .67439 L .18075 .67611 L p .707 .577 .707 r
F P
0 g
s
.32742 .62459 m .32441 .68164 L .29693 .67794 L p .707 .577 .707 r
F P
0 g
s
.29693 .67794 m .29994 .62089 L .32742 .62459 L p .707 .577 .707 r
F P
0 g
s
.17805 .73548 m .18141 .69721 L .20517 .69821 L p .707 .577 .707 r
F P
0 g
s
.20517 .69821 m .2018 .73648 L .17805 .73548 L p .707 .577 .707 r
F P
0 g
s
.3856 .25713 m .39523 .75194 L .37214 .76446 L p .707 .577 .707 r
F P
0 g
s
.39523 .75194 m .3856 .25713 L .41954 .24724 L p .707 .577 .707 r
F P
0 g
s
.20469 .67439 m .20771 .61733 L .23701 .61707 L p .707 .577 .707 r
F P
0 g
s
.34694 .75482 m .34633 .77369 L .32526 .76843 L p .707 .577 .707 r
F P
0 g
s
.32526 .76843 m .32586 .74956 L .34694 .75482 L p .707 .577 .707 r
F P
0 g
s
.23701 .61707 m .23399 .67412 L .20469 .67439 L p .707 .577 .707 r
F P
0 g
s
.29994 .62089 m .29693 .67794 L .26578 .67535 L p .707 .577 .707 r
F P
0 g
s
.26578 .67535 m .26879 .6183 L .29994 .62089 L p .707 .577 .707 r
F P
0 g
s
.32463 .70903 m .32126 .7473 L .29375 .74407 L p .707 .577 .707 r
F P
0 g
s
.29375 .74407 m .29712 .7058 L .32463 .70903 L p .707 .577 .707 r
F P
0 g
s
.73316 .64024 m .73617 .58319 L .70502 .5806 L p .707 .577 .707 r
F P
0 g
s
.73617 .58319 m .73316 .64024 L .76494 .64147 L p .707 .577 .707 r
F P
0 g
s
.76494 .64147 m .76795 .58441 L .73617 .58319 L p .707 .577 .707 r
F P
0 g
s
.18144 .76653 m .18205 .74766 L .20606 .74436 L p .707 .577 .707 r
F P
0 g
s
.23399 .67412 m .23701 .61707 L .26879 .6183 L p .707 .577 .707 r
F P
0 g
s
.76795 .58441 m .76494 .64147 L .79424 .6412 L p .707 .577 .707 r
F P
0 g
s
.79424 .6412 m .79725 .58415 L .76795 .58441 L p .707 .577 .707 r
F P
0 g
s
.58871 .24776 m .59834 .74257 L .55957 .73603 L p .707 .577 .707 r
F P
0 g
s
.55957 .73603 m .54994 .24122 L .58871 .24776 L p .707 .577 .707 r
F P
0 g
s
.20606 .74436 m .20546 .76323 L .18144 .76653 L p .707 .577 .707 r
F P
0 g
s
.2018 .73648 m .20517 .69821 L .23431 .70012 L p .707 .577 .707 r
F P
0 g
s
.26879 .6183 m .26578 .67535 L .23399 .67412 L p .707 .577 .707 r
F P
0 g
s
.702 .63765 m .70502 .5806 L .67754 .5769 L p .707 .577 .707 r
F P
0 g
s
.70502 .5806 m .702 .63765 L .73316 .64024 L p .707 .577 .707 r
F P
0 g
s
.23431 .70012 m .23095 .73839 L .2018 .73648 L p .707 .577 .707 r
F P
0 g
s
.32586 .74956 m .32526 .76843 L .29779 .76445 L p .707 .577 .707 r
F P
0 g
s
.29779 .76445 m .2984 .74558 L .32586 .74956 L p .707 .577 .707 r
F P
0 g
s
.67754 .5769 m .67453 .63395 L .702 .63765 L p .707 .577 .707 r
F P
0 g
s
.42916 .74205 m .41954 .24724 L .461 .24095 L p .707 .577 .707 r
F P
0 g
s
.41954 .24724 m .42813 .68895 L p .39523 .75194 L .707 .577 .707 r
F P
0 g
s
.461 .24095 m .47063 .73576 L .42916 .74205 L p .707 .577 .707 r
F P
0 g
s
.42336 .62569 m .42 .66396 L .43917 .66521 L p .707 .577 .707 r
F P
0 g
s
.43917 .66521 m .44915 .66586 L p .44319 .65658 L .707 .577 .707 r
F P
0 g
s
.44319 .65658 m .42336 .62569 L .43917 .66521 L .707 .577 .707 r
F
.42813 .68895 m .42916 .74205 L .39941 .75072 L p F P
0 g
s
.39941 .75072 m .39523 .75194 L p .42813 .68895 L .707 .577 .707 r
F P
0 g
s
.29712 .7058 m .29375 .74407 L .26263 .741 L p .707 .577 .707 r
F P
0 g
s
.26263 .741 m .266 .70273 L .29712 .7058 L p .707 .577 .707 r
F P
0 g
s
.79725 .58415 m .79424 .6412 L .81819 .63948 L p .707 .577 .707 r
F P
0 g
s
.81819 .63948 m .8212 .58243 L .79725 .58415 L p .707 .577 .707 r
F P
0 g
s
.73133 .69816 m .73469 .65989 L .70357 .65682 L p .707 .577 .707 r
F P
0 g
s
.73469 .65989 m .73133 .69816 L .76301 .70077 L p .707 .577 .707 r
F P
0 g
s
.76301 .70077 m .76637 .6625 L .73469 .65989 L p .707 .577 .707 r
F P
0 g
s
.23095 .73839 m .23431 .70012 L .266 .70273 L p .707 .577 .707 r
F P
0 g
s
.70357 .65682 m .70021 .69509 L .73133 .69816 L p .707 .577 .707 r
F P
0 g
s
.266 .70273 m .26263 .741 L .23095 .73839 L p .707 .577 .707 r
F P
0 g
s
.76637 .6625 m .76301 .70077 L .79216 .70268 L p .707 .577 .707 r
F P
0 g
s
.79216 .70268 m .79552 .66441 L .76637 .6625 L p .707 .577 .707 r
F P
0 g
s
.20546 .76323 m .20606 .74436 L .23542 .74285 L p .707 .577 .707 r
F P
0 g
s
.67453 .63395 m .67754 .5769 L .65643 .57245 L p .707 .577 .707 r
F P
0 g
s
.70021 .69509 m .70357 .65682 L .67606 .65359 L p .707 .577 .707 r
F P
0 g
s
.23542 .74285 m .23481 .76172 L .20546 .76323 L p .707 .577 .707 r
F P
0 g
s
.54994 .24122 m .55957 .73603 L .51557 .73369 L p .707 .577 .707 r
F P
0 g
s
.51557 .73369 m .50594 .23888 L .54994 .24122 L p .707 .577 .707 r
F P
0 g
s
.67606 .65359 m .6727 .69186 L .70021 .69509 L p .707 .577 .707 r
F P
0 g
s
.2984 .74558 m .29779 .76445 L .26663 .76214 L p .707 .577 .707 r
F P
0 g
s
.26663 .76214 m .26723 .74327 L .2984 .74558 L p .707 .577 .707 r
F P
0 g
s
.65643 .57245 m .65342 .6295 L .67453 .63395 L p .707 .577 .707 r
F P
0 g
s
.47063 .73576 m .461 .24095 L .50594 .23888 L p .707 .577 .707 r
F P
0 g
s
.23481 .76172 m .23542 .74285 L .26723 .74327 L p .707 .577 .707 r
F P
0 g
s
.79552 .66441 m .79216 .70268 L .81591 .70369 L p .707 .577 .707 r
F P
0 g
s
.81591 .70369 m .81928 .66542 L .79552 .66441 L p .707 .577 .707 r
F P
0 g
s
.50594 .23888 m .51557 .73369 L .47063 .73576 L p .707 .577 .707 r
F P
0 g
s
.26723 .74327 m .26663 .76214 L .23481 .76172 L p .707 .577 .707 r
F P
0 g
s
.8212 .58243 m .81819 .63948 L .83444 .63647 L p .707 .577 .707 r
F P
0 g
s
.83444 .63647 m .83745 .57942 L .8212 .58243 L p .707 .577 .707 r
F P
0 g
s
.73355 .7575 m .73416 .73863 L .70299 .73632 L p .707 .577 .707 r
F P
0 g
s
.73416 .73863 m .73355 .7575 L .76537 .75792 L p .707 .577 .707 r
F P
0 g
s
.76537 .75792 m .76597 .73905 L .73416 .73863 L p .707 .577 .707 r
F P
0 g
s
.6727 .69186 m .67606 .65359 L .65485 .65053 L p .707 .577 .707 r
F P
0 g
s
.76597 .73905 m .76537 .75792 L .79472 .7564 L p .707 .577 .707 r
F P
0 g
s
.79472 .7564 m .79532 .73754 L .76597 .73905 L p .707 .577 .707 r
F P
0 g
s
.70299 .73632 m .70239 .75518 L .73355 .7575 L p .707 .577 .707 r
F P
0 g
s
.65485 .65053 m .65149 .6888 L .6727 .69186 L p .707 .577 .707 r
F P
0 g
s
.70239 .75518 m .70299 .73632 L .67553 .73234 L p .707 .577 .707 r
F P
0 g
s
.65342 .6295 m .65643 .57245 L .64375 .56768 L p .707 .577 .707 r
F P
0 g
s
.67553 .73234 m .67492 .7512 L .70239 .75518 L p .707 .577 .707 r
F P
0 g
s
.79532 .73754 m .79472 .7564 L .81874 .7531 L p .707 .577 .707 r
F P
0 g
s
.81874 .7531 m .81934 .73424 L .79532 .73754 L p .707 .577 .707 r
F P
0 g
s
.64375 .56768 m .64074 .62473 L .65342 .6295 L p .707 .577 .707 r
F P
0 g
s
.81928 .66542 m .81591 .70369 L .83195 .7037 L p .707 .577 .707 r
F P
0 g
s
.83195 .7037 m .83532 .66543 L .81928 .66542 L p .707 .577 .707 r
F P
0 g
s
.67492 .7512 m .67553 .73234 L .65445 .72708 L p .707 .577 .707 r
F P
0 g
s
.65149 .6888 m .65485 .65053 L .64202 .64793 L p .707 .577 .707 r
F P
0 g
s
.65445 .72708 m .65385 .74595 L .67492 .7512 L p .707 .577 .707 r
F P
0 g
s
.83745 .57942 m .83444 .63647 L .84141 .63245 L p .707 .577 .707 r
F P
0 g
s
.84141 .63245 m .84442 .5754 L .83745 .57942 L p .707 .577 .707 r
F P
0 g
s
.81934 .73424 m .81874 .7531 L .83506 .74834 L p .707 .577 .707 r
F P
0 g
s
.83506 .74834 m .83567 .72947 L .81934 .73424 L p .707 .577 .707 r
F P
0 g
s
.64074 .62473 m .64375 .56768 L .64075 .56306 L p .707 .577 .707 r
F P
0 g
s
.83532 .66543 m .83195 .7037 L .83871 .70271 L p .707 .577 .707 r
F P
0 g
s
.83871 .70271 m .84207 .66444 L .83532 .66543 L p .707 .577 .707 r
F P
0 g
s
.64075 .56306 m .63774 .62011 L .64074 .62473 L p .707 .577 .707 r
F P
0 g
s
.65385 .74595 m .65445 .72708 L .64183 .72106 L p .707 .577 .707 r
F P
0 g
s
.64183 .72106 m .64122 .73993 L .65385 .74595 L p .707 .577 .707 r
F P
0 g
s
.63866 .6862 m .64202 .64793 L .63883 .64605 L p .707 .577 .707 r
F P
0 g
s
.63883 .64605 m .63547 .68432 L .63866 .6862 L p .707 .577 .707 r
F P
0 g
s
.84442 .5754 m .84141 .63245 L .83841 .62784 L p .707 .577 .707 r
F P
0 g
s
.83841 .62784 m .84142 .57079 L .84442 .5754 L p .707 .577 .707 r
F P
0 g
s
.83567 .72947 m .83506 .74834 L .8421 .74258 L p .707 .577 .707 r
F P
0 g
s
.8421 .74258 m .84271 .72371 L .83567 .72947 L p .707 .577 .707 r
F P
0 g
s
.63774 .62011 m .64075 .56306 L .64772 .55905 L p .707 .577 .707 r
F P
0 g
s
.64122 .73993 m .64183 .72106 L .63889 .71487 L p .707 .577 .707 r
F P
0 g
s
.84207 .66444 m .83871 .70271 L .83551 .70083 L p .707 .577 .707 r
F P
0 g
s
.83551 .70083 m .83888 .66256 L .84207 .66444 L p .707 .577 .707 r
F P
0 g
s
.64772 .55905 m .64471 .6161 L .63774 .62011 L p .707 .577 .707 r
F P
0 g
s
.63889 .71487 m .63829 .73373 L .64122 .73993 L p .707 .577 .707 r
F P
0 g
s
.63547 .68432 m .63883 .64605 L .64558 .64506 L p .707 .577 .707 r
F P
0 g
s
.64558 .64506 m .64222 .68333 L .63547 .68432 L p .707 .577 .707 r
F P
0 g
s
.84142 .57079 m .83841 .62784 L .82573 .62307 L p .707 .577 .707 r
F P
0 g
s
.82573 .62307 m .82874 .56602 L .84142 .57079 L p .707 .577 .707 r
F P
0 g
s
.39015 .60343 m .39316 .54638 L .36201 .54379 L p .707 .577 .707 r
F P
0 g
s
.39316 .54638 m .39015 .60343 L .42193 .60465 L p .707 .577 .707 r
F P
0 g
s
.42193 .60465 m .42494 .5476 L .39316 .54638 L p .707 .577 .707 r
F P
0 g
s
.84271 .72371 m .8421 .74258 L .83917 .73639 L p .707 .577 .707 r
F P
0 g
s
.83917 .73639 m .83977 .71752 L .84271 .72371 L p .707 .577 .707 r
F P
0 g
s
.42494 .5476 m .42193 .60465 L .45123 .60439 L p .707 .577 .707 r
F P
0 g
s
.45123 .60439 m .45424 .54734 L .42494 .5476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64471 .6161 m .64772 .55905 L .66397 .55604 L p .707 .577 .707 r
F P
0 g
s
.35899 .60084 m .36201 .54379 L .33453 .54008 L p .707 .577 .707 r
F P
0 g
s
.36201 .54379 m .35899 .60084 L .39015 .60343 L p .707 .577 .707 r
F P
0 g
s
.63829 .73373 m .63889 .71487 L .64594 .70911 L p .707 .577 .707 r
F P
0 g
s
.66397 .55604 m .66096 .61309 L .64471 .6161 L p .707 .577 .707 r
F P
0 g
s
.83888 .66256 m .83551 .70083 L .82268 .69823 L p .707 .577 .707 r
F P
0 g
s
.82268 .69823 m .82605 .65996 L .83888 .66256 L p .707 .577 .707 r
F P
0 g
s
.33453 .54008 m .33152 .59713 L .35899 .60084 L p .707 .577 .707 r
F P
0 g
s
.64594 .70911 m .64533 .72797 L .63829 .73373 L p .707 .577 .707 r
F P
0 g
s
.45424 .54734 m .45123 .60439 L .47518 .60267 L p .707 .577 .707 r
F P
0 g
s
.47518 .60267 m .47819 .54561 L .45424 .54734 L p .707 .577 .707 r
F P
0 g
s
.38832 .66134 m .39168 .62307 L .36056 .62 L p .707 .577 .707 r
F P
0 g
s
.39168 .62307 m .38832 .66134 L .42 .66396 L p .707 .577 .707 r
F P
0 g
s
.42 .66396 m .42336 .62569 L .39168 .62307 L p .707 .577 .707 r
F P
0 g
s
.36056 .62 m .3572 .65827 L .38832 .66134 L p .707 .577 .707 r
F P
0 g
s
.44915 .66586 m .45251 .62759 L .42336 .62569 L p .707 .577 .707 r
F P
0 g
s
.33152 .59713 m .33453 .54008 L .31342 .53563 L p .707 .577 .707 r
F P
0 g
s
.82874 .56602 m .82573 .62307 L .80462 .61862 L p .707 .577 .707 r
F P
0 g
s
.80462 .61862 m .80763 .56157 L .82874 .56602 L p .707 .577 .707 r
F P
0 g
s
.64222 .68333 m .64558 .64506 L .66162 .64508 L p .707 .577 .707 r
F P
0 g
s
.3572 .65827 m .36056 .62 L .33305 .61678 L p .707 .577 .707 r
F P
0 g
s
.66162 .64508 m .65826 .68335 L .64222 .68333 L p .707 .577 .707 r
F P
0 g
s
.33305 .61678 m .32969 .65505 L .3572 .65827 L p .707 .577 .707 r
F P
0 g
s
.31342 .53563 m .31041 .59268 L .33152 .59713 L p .707 .577 .707 r
F P
0 g
s
.83977 .71752 m .83917 .73639 L .82655 .73037 L p .707 .577 .707 r
F P
0 g
s
.82655 .73037 m .82715 .7115 L .83977 .71752 L p .707 .577 .707 r
F P
0 g
s
.66096 .61309 m .66397 .55604 L .68792 .55431 L p .707 .577 .707 r
F P
0 g
s
.45251 .62759 m .44915 .66586 L .4729 .66687 L p .707 .577 .707 r
F P
0 g
s
.4729 .66687 m .47627 .6286 L .45251 .62759 L p .707 .577 .707 r
F P
0 g
s
.47819 .54561 m .47518 .60267 L .49143 .59965 L p .707 .577 .707 r
F P
0 g
s
.49143 .59965 m .49444 .5426 L .47819 .54561 L p .707 .577 .707 r
F P
0 g
s
.39054 .72068 m .39115 .70182 L .35998 .6995 L p .707 .577 .707 r
F P
0 g
s
.39115 .70182 m .39054 .72068 L .42236 .7211 L p .707 .577 .707 r
F P
0 g
s
.42236 .7211 m .42296 .70224 L .39115 .70182 L p .707 .577 .707 r
F P
0 g
s
.32969 .65505 m .33305 .61678 L .31184 .61372 L p .707 .577 .707 r
F P
0 g
s
.68792 .55431 m .68491 .61136 L .66096 .61309 L p .707 .577 .707 r
F P
0 g
s
.42296 .70224 m .42236 .7211 L .45171 .71959 L p .707 .577 .707 r
F P
0 g
s
.45171 .71959 m .45232 .70072 L .42296 .70224 L p .707 .577 .707 r
F P
0 g
s
.35998 .6995 m .35938 .71837 L .39054 .72068 L p .707 .577 .707 r
F P
0 g
s
.31184 .61372 m .30848 .65199 L .32969 .65505 L p .707 .577 .707 r
F P
0 g
s
.64533 .72797 m .64594 .70911 L .66226 .70434 L p .707 .577 .707 r
F P
0 g
s
.82605 .65996 m .82268 .69823 L .80148 .69517 L p .707 .577 .707 r
F P
0 g
s
.80148 .69517 m .80484 .6569 L .82605 .65996 L p .707 .577 .707 r
F P
0 g
s
.35938 .71837 m .35998 .6995 L .33252 .69552 L p .707 .577 .707 r
F P
0 g
s
.31041 .59268 m .31342 .53563 L .30074 .53086 L p .707 .577 .707 r
F P
0 g
s
.66226 .70434 m .66166 .72321 L .64533 .72797 L p .707 .577 .707 r
F P
0 g
s
.80763 .56157 m .80462 .61862 L .77714 .61492 L p .707 .577 .707 r
F P
0 g
s
.77714 .61492 m .78016 .55787 L .80763 .56157 L p .707 .577 .707 r
F P
0 g
s
.33252 .69552 m .33191 .71439 L .35938 .71837 L p .707 .577 .707 r
F P
0 g
s
.65826 .68335 m .66162 .64508 L .68538 .64609 L p .707 .577 .707 r
F P
0 g
s
.68538 .64609 m .68202 .68436 L .65826 .68335 L p .707 .577 .707 r
F P
0 g
s
.45232 .70072 m .45171 .71959 L .47573 .71629 L p .707 .577 .707 r
F P
0 g
s
.47573 .71629 m .47633 .69742 L .45232 .70072 L p .707 .577 .707 r
F P
0 g
s
.68491 .61136 m .68792 .55431 L .71722 .55405 L p .707 .577 .707 r
F P
0 g
s
.30074 .53086 m .29773 .58791 L .31041 .59268 L p .707 .577 .707 r
F P
0 g
s
.47627 .6286 m .4729 .66687 L .48894 .66688 L p .707 .577 .707 r
F P
0 g
s
.48894 .66688 m .49231 .62861 L .47627 .6286 L p .707 .577 .707 r
F P
0 g
s
.82715 .7115 m .82655 .73037 L .80547 .72511 L p .707 .577 .707 r
F P
0 g
s
.80547 .72511 m .80608 .70624 L .82715 .7115 L p .707 .577 .707 r
F P
0 g
s
.33191 .71439 m .33252 .69552 L .31144 .69027 L p .707 .577 .707 r
F P
0 g
s
.71722 .55405 m .71421 .6111 L .68491 .61136 L p .707 .577 .707 r
F P
0 g
s
.78016 .55787 m .77714 .61492 L .74599 .61233 L p .707 .577 .707 r
F P
0 g
s
.74599 .61233 m .749 .55528 L .78016 .55787 L p .707 .577 .707 r
F P
0 g
s
.30848 .65199 m .31184 .61372 L .29901 .61112 L p .707 .577 .707 r
F P
0 g
s
.31144 .69027 m .31084 .70913 L .33191 .71439 L p .707 .577 .707 r
F P
0 g
s
.49444 .5426 m .49143 .59965 L .4984 .59564 L p .707 .577 .707 r
F P
0 g
s
.4984 .59564 m .50141 .53859 L .49444 .5426 L p .707 .577 .707 r
F P
0 g
s
.29901 .61112 m .29565 .64939 L .30848 .65199 L p .707 .577 .707 r
F P
0 g
s
.80484 .6569 m .80148 .69517 L .77397 .69194 L p .707 .577 .707 r
F P
0 g
s
.77397 .69194 m .77733 .65368 L .80484 .6569 L p .707 .577 .707 r
F P
0 g
s
.71421 .6111 m .71722 .55405 L .749 .55528 L p .707 .577 .707 r
F P
0 g
s
.66166 .72321 m .66226 .70434 L .68628 .70104 L p .707 .577 .707 r
F P
0 g
s
.749 .55528 m .74599 .61233 L .71421 .6111 L p .707 .577 .707 r
F P
0 g
s
.68202 .68436 m .68538 .64609 L .71453 .64799 L p .707 .577 .707 r
F P
0 g
s
.68628 .70104 m .68567 .71991 L .66166 .72321 L p .707 .577 .707 r
F P
0 g
s
.47633 .69742 m .47573 .71629 L .49205 .71152 L p .707 .577 .707 r
F P
0 g
s
.49205 .71152 m .49266 .69266 L .47633 .69742 L p .707 .577 .707 r
F P
0 g
s
.71453 .64799 m .71116 .68626 L .68202 .68436 L p .707 .577 .707 r
F P
0 g
s
.29773 .58791 m .30074 .53086 L .29774 .52625 L p .707 .577 .707 r
F P
0 g
s
.77733 .65368 m .77397 .69194 L .74285 .68888 L p .707 .577 .707 r
F P
0 g
s
.74285 .68888 m .74621 .65061 L .77733 .65368 L p .707 .577 .707 r
F P
0 g
s
.49231 .62861 m .48894 .66688 L .4957 .6659 L p .707 .577 .707 r
F P
0 g
s
.4957 .6659 m .49906 .62763 L .49231 .62861 L p .707 .577 .707 r
F P
0 g
s
.29774 .52625 m .29473 .5833 L .29773 .58791 L p .707 .577 .707 r
F P
0 g
s
.80608 .70624 m .80547 .72511 L .77801 .72113 L p .707 .577 .707 r
F P
0 g
s
.77801 .72113 m .77861 .70226 L .80608 .70624 L p .707 .577 .707 r
F P
0 g
s
.31084 .70913 m .31144 .69027 L .29882 .68425 L p .707 .577 .707 r
F P
0 g
s
.71116 .68626 m .71453 .64799 L .74621 .65061 L p .707 .577 .707 r
F P
0 g
s
.74621 .65061 m .74285 .68888 L .71116 .68626 L p .707 .577 .707 r
F P
0 g
s
.29882 .68425 m .29821 .70311 L .31084 .70913 L p .707 .577 .707 r
F P
0 g
s
.68567 .71991 m .68628 .70104 L .71563 .69953 L p .707 .577 .707 r
F P
0 g
s
.29565 .64939 m .29901 .61112 L .29582 .60923 L p .707 .577 .707 r
F P
0 g
s
.71563 .69953 m .71502 .7184 L .68567 .71991 L p .707 .577 .707 r
F P
0 g
s
.29582 .60923 m .29246 .6475 L .29565 .64939 L p .707 .577 .707 r
F P
0 g
s
.50141 .53859 m .4984 .59564 L .4954 .59102 L p .707 .577 .707 r
F P
0 g
s
.4954 .59102 m .49841 .53397 L .50141 .53859 L p .707 .577 .707 r
F P
0 g
s
.77861 .70226 m .77801 .72113 L .74684 .71882 L p .707 .577 .707 r
F P
0 g
s
.74684 .71882 m .74745 .69995 L .77861 .70226 L p .707 .577 .707 r
F P
0 g
s
.49266 .69266 m .49205 .71152 L .49909 .70576 L p .707 .577 .707 r
F P
0 g
s
.49909 .70576 m .4997 .6869 L .49266 .69266 L p .707 .577 .707 r
F P
0 g
s
.71502 .7184 m .71563 .69953 L .74745 .69995 L p .707 .577 .707 r
F P
0 g
s
.74745 .69995 m .74684 .71882 L .71502 .7184 L p .707 .577 .707 r
F P
0 g
s
.29473 .5833 m .29774 .52625 L .30471 .52224 L p .707 .577 .707 r
F P
0 g
s
.29821 .70311 m .29882 .68425 L .29588 .67805 L p .707 .577 .707 r
F P
0 g
s
.49906 .62763 m .4957 .6659 L .4925 .66401 L p .707 .577 .707 r
F P
0 g
s
.4925 .66401 m .49587 .62575 L .49906 .62763 L p .707 .577 .707 r
F P
0 g
s
.30471 .52224 m .3017 .57929 L .29473 .5833 L p .707 .577 .707 r
F P
0 g
s
.29588 .67805 m .29528 .69692 L .29821 .70311 L p .707 .577 .707 r
F P
0 g
s
.29246 .6475 m .29582 .60923 L .30257 .60825 L p .707 .577 .707 r
F P
0 g
s
.30257 .60825 m .29921 .64652 L .29246 .6475 L p .707 .577 .707 r
F P
0 g
s
.49841 .53397 m .4954 .59102 L .48272 .58626 L p .707 .577 .707 r
F P
0 g
s
.48272 .58626 m .48573 .52921 L .49841 .53397 L p .707 .577 .707 r
F P
0 g
s
.4997 .6869 m .49909 .70576 L .49616 .69957 L p .707 .577 .707 r
F P
0 g
s
.49616 .69957 m .49676 .6807 L .4997 .6869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3017 .57929 m .30471 .52224 L .32096 .51922 L p .707 .577 .707 r
F P
0 g
s
.29528 .69692 m .29588 .67805 L .30292 .67229 L p .707 .577 .707 r
F P
0 g
s
.32096 .51922 m .31795 .57627 L .3017 .57929 L p .707 .577 .707 r
F P
0 g
s
.49587 .62575 m .4925 .66401 L .47967 .66141 L p .707 .577 .707 r
F P
0 g
s
.47967 .66141 m .48304 .62314 L .49587 .62575 L p .707 .577 .707 r
F P
0 g
s
.30292 .67229 m .30232 .69116 L .29528 .69692 L p .707 .577 .707 r
F P
0 g
s
.48573 .52921 m .48272 .58626 L .46161 .5818 L p .707 .577 .707 r
F P
0 g
s
.46161 .5818 m .46462 .52475 L .48573 .52921 L p .707 .577 .707 r
F P
0 g
s
.29921 .64652 m .30257 .60825 L .31861 .60826 L p .707 .577 .707 r
F P
0 g
s
.31861 .60826 m .31525 .64653 L .29921 .64652 L p .707 .577 .707 r
F P
0 g
s
.49676 .6807 m .49616 .69957 L .48354 .69355 L p .707 .577 .707 r
F P
0 g
s
.48354 .69355 m .48414 .67468 L .49676 .6807 L p .707 .577 .707 r
F P
0 g
s
.31795 .57627 m .32096 .51922 L .34491 .5175 L p .707 .577 .707 r
F P
0 g
s
.34491 .5175 m .3419 .57455 L .31795 .57627 L p .707 .577 .707 r
F P
0 g
s
.30232 .69116 m .30292 .67229 L .31925 .66753 L p .707 .577 .707 r
F P
0 g
s
.48304 .62314 m .47967 .66141 L .45847 .65835 L p .707 .577 .707 r
F P
0 g
s
.45847 .65835 m .46183 .62008 L .48304 .62314 L p .707 .577 .707 r
F P
0 g
s
.31925 .66753 m .31865 .6864 L .30232 .69116 L p .707 .577 .707 r
F P
0 g
s
.46462 .52475 m .46161 .5818 L .43413 .5781 L p .707 .577 .707 r
F P
0 g
s
.43413 .5781 m .43715 .52105 L .46462 .52475 L p .707 .577 .707 r
F P
0 g
s
.31525 .64653 m .31861 .60826 L .34237 .60927 L p .707 .577 .707 r
F P
0 g
s
.34237 .60927 m .33901 .64754 L .31525 .64653 L p .707 .577 .707 r
F P
0 g
s
.3419 .57455 m .34491 .5175 L .37421 .51724 L p .707 .577 .707 r
F P
0 g
s
.48414 .67468 m .48354 .69355 L .46246 .68829 L p .707 .577 .707 r
F P
0 g
s
.46246 .68829 m .46307 .66943 L .48414 .67468 L p .707 .577 .707 r
F P
0 g
s
.37421 .51724 m .3712 .57429 L .3419 .57455 L p .707 .577 .707 r
F P
0 g
s
.43715 .52105 m .43413 .5781 L .40298 .57551 L p .707 .577 .707 r
F P
0 g
s
.40298 .57551 m .40599 .51846 L .43715 .52105 L p .707 .577 .707 r
F P
0 g
s
.46183 .62008 m .45847 .65835 L .43096 .65513 L p .707 .577 .707 r
F P
0 g
s
.43096 .65513 m .43432 .61686 L .46183 .62008 L p .707 .577 .707 r
F P
0 g
s
.3712 .57429 m .37421 .51724 L .40599 .51846 L p .707 .577 .707 r
F P
0 g
s
.31865 .6864 m .31925 .66753 L .34327 .66423 L p .707 .577 .707 r
F P
0 g
s
.40599 .51846 m .40298 .57551 L .3712 .57429 L p .707 .577 .707 r
F P
0 g
s
.33901 .64754 m .34237 .60927 L .37151 .61118 L p .707 .577 .707 r
F P
0 g
s
.34327 .66423 m .34266 .68309 L .31865 .6864 L p .707 .577 .707 r
F P
0 g
s
.37151 .61118 m .36815 .64944 L .33901 .64754 L p .707 .577 .707 r
F P
0 g
s
.43432 .61686 m .43096 .65513 L .39984 .65206 L p .707 .577 .707 r
F P
0 g
s
.39984 .65206 m .4032 .61379 L .43432 .61686 L p .707 .577 .707 r
F P
0 g
s
.46307 .66943 m .46246 .68829 L .435 .68431 L p .707 .577 .707 r
F P
0 g
s
.435 .68431 m .4356 .66545 L .46307 .66943 L p .707 .577 .707 r
F P
0 g
s
.36815 .64944 m .37151 .61118 L .4032 .61379 L p .707 .577 .707 r
F P
0 g
s
.4032 .61379 m .39984 .65206 L .36815 .64944 L p .707 .577 .707 r
F P
0 g
s
.34266 .68309 m .34327 .66423 L .37262 .66271 L p .707 .577 .707 r
F P
0 g
s
.37262 .66271 m .37201 .68158 L .34266 .68309 L p .707 .577 .707 r
F P
0 g
s
.4356 .66545 m .435 .68431 L .40383 .682 L p .707 .577 .707 r
F P
0 g
s
.40383 .682 m .40444 .66313 L .4356 .66545 L p .707 .577 .707 r
F P
0 g
s
.37201 .68158 m .37262 .66271 L .40444 .66313 L p .707 .577 .707 r
F P
0 g
s
.40444 .66313 m .40383 .682 L .37201 .68158 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooah007io
o`00Ngoo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00N7oo001fOol50008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001dOol007=oo`<00003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001bOol006moo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001_Ool006eoo`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8006eoo`00Jgoo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00Jgoo001YOol20002FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001YOol006Moo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Ioo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP00009JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00FGoo80002eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001FOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolI0014Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`02Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool005=oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0
009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Ioo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005]oo`L000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2000/Ool0069oo`P000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool006Eoo`05001JEUYF001J
EP0P0007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`P000Moo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`<000=JEP04001JEUYFFUH@00000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP04001JEUYF
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool003QooaT000=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPP000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8002eoo`00;goo2@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF001JEP02FUH2000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol00goo1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`0:Ool90004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF2@00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`0COolI000hOol002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0000L000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEQ8005Ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH9001=Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH00UYF4000?Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000K0005FUH00`00FUIJEP03FUH8
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF5P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPL000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00@005YFFUIJEQ0000AJ
EP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF00000UYF1`001eYF00<005YFFUH01EYF40000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH90002FUH00`00FUIJEP02FUH50004FUH80004
FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00004@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0002FUH60002FUH400000eYF00000002
FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01`000eYF00<005YFFUH015YF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;goo100015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00D005YFFUH005YF00H000EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP09FUH300000eYF001JEP02FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJ
EP070002FUH00`00FUH00002FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP03
0002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJ
EUYF0P00;Woo000]OolA00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@001EYF00<005YFFUH01UYF00<005YFFUH025YF1@000UYF0`0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00@005YFFUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEQ<000=JEP05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0003FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00P000=JEP03
001JEUYF009JEQ@000=JEP04001JEUYFFUH4000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00000010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd002moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP02FUH700000eYF
001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJ
EP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH01000FUIJEUYF
2@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH:0002FUH20007Ool50004Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEP00FUH005YF00<000EJEP04001JEUYFFUH40007Ool5000<Ool60003
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P0000=JEP00FUH00`000UYF00<0
05YFFUH00UYF0`0027oo0`004goo10000eYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH0
0UYF1@000UYF00<005YF00007Goo1`0000=JEP000000;Goo000/OolJ0004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF2P0035YF2@0025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF
FUH015YF00@005YFFUIJEPP0019oo`P0009JEP03001JEUYF009JEP<002eoo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000c
OolT0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
1@000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<0
05YFFUH00UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0003FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF
00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002moo`<00003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH20002
FUH00`00FUIJEP04FUH400000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH020000UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF009JEP03
001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<00005Ool005YFFUH00002FUH20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8000=ooaT003Qoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P000UYF0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00@005YFFUIJEP8005Aoo`00;Goo0P000eYF3@004Goo200015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YF
FUH015YF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8002Ioo`H000AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03
001JEUYF009JEP8005Aoo`00;7oo00<005YF00001@0057oo0`004goo0`0000=JEP00FUH00UYF0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000E7oo000/Ool20003FUH00`00FUIJEP07000<Ool5000EOol30002FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eo
o`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT000=oo`D0015oo`D0009JEP<00003FUH0
05YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF6@00
0eYF00T005YFFUIJEP00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1`000eYF00@005YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH20003FUH:0002FUH2001EOol0031oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
00000goo00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUH0000200000eYF
00000002001EOol003Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF008000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000MJEP03001JEUYF009JEPD005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEPH000Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP05FUH00`00FUIJEP04FUH01000FUH00000EGoo000mOolP000>Ool30007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP080003FUH00`00FUIJEP04FUH01000FUIJEP00EGoo001]Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH30008Ool50004FUH01000
FUIJEUYF0P00E7oo001_Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH3000?Ool300000eYF001JEP02FUH2001DOol0075oo`<00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D001Eo
o`8000=JEP8005Aoo`00M7oo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
1@0000=oo`0000000`004Goo1`0000=JEP000000E7oo001hOol60002FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH01000FUIJEUYF8P000UYF00<005YFFUH00UYF0`00E7oo001nOol90006FUH00`00FUIJ
EP04FUH90003FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUH0001DOol008Moo`d000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00U7oo0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00
EWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
1P00FGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001OOol00:Eooa8006Ioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59622 .73385 m .60106 .67646 L .56994 .67343 L p .707 .577 .707 r
F P
0 g
s
.60106 .67646 m .59622 .73385 L .62791 .73633 L p .707 .577 .707 r
F P
0 g
s
.62791 .73633 m .63276 .67894 L .60106 .67646 L p .707 .577 .707 r
F P
0 g
s
.63276 .67894 m .62791 .73633 L .65708 .73802 L p .707 .577 .707 r
F P
0 g
s
.65708 .73802 m .66192 .68063 L .63276 .67894 L p .707 .577 .707 r
F P
0 g
s
.56994 .67343 m .56509 .73083 L .59622 .73385 L p .707 .577 .707 r
F P
0 g
s
.56509 .73083 m .56994 .67343 L .54243 .67016 L p .707 .577 .707 r
F P
0 g
s
.56824 .73063 m .56288 .76857 L .59392 .77237 L p .707 .577 .707 r
F P
0 g
s
.59392 .77237 m .59928 .73443 L .56824 .73063 L p .707 .577 .707 r
F P
0 g
s
.59928 .73443 m .59392 .77237 L .62536 .7771 L p .707 .577 .707 r
F P
0 g
s
.54243 .67016 m .53759 .72756 L .56509 .73083 L p .707 .577 .707 r
F P
0 g
s
.62536 .7771 m .63072 .73916 L .59928 .73443 L p .707 .577 .707 r
F P
0 g
s
.63072 .73916 m .62536 .7771 L .65413 .7823 L p .707 .577 .707 r
F P
0 g
s
.65413 .7823 m .65949 .74436 L .63072 .73916 L p .707 .577 .707 r
F P
0 g
s
.54065 .72814 m .53529 .76608 L .56288 .76857 L p .707 .577 .707 r
F P
0 g
s
.56288 .76857 m .56824 .73063 L .54065 .72814 L p .707 .577 .707 r
F P
0 g
s
.66192 .68063 m .65708 .73802 L .68085 .73876 L p .707 .577 .707 r
F P
0 g
s
.68085 .73876 m .6857 .68137 L .66192 .68063 L p .707 .577 .707 r
F P
0 g
s
.53759 .72756 m .54243 .67016 L .52124 .66697 L p .707 .577 .707 r
F P
0 g
s
.65949 .74436 m .65413 .7823 L .67741 .78746 L p .707 .577 .707 r
F P
0 g
s
.52124 .66697 m .51639 .72436 L .53759 .72756 L p .707 .577 .707 r
F P
0 g
s
.67741 .78746 m .68277 .74952 L .65949 .74436 L p .707 .577 .707 r
F P
0 g
s
.59661 .82885 m .59759 .80984 L .56644 .80727 L p .707 .577 .707 r
F P
0 g
s
.59759 .80984 m .59661 .82885 L .6284 .83002 L p .707 .577 .707 r
F P
0 g
s
.6284 .83002 m .62938 .81101 L .59759 .80984 L p .707 .577 .707 r
F P
0 g
s
.5192 .72719 m .51384 .76513 L .53529 .76608 L p .707 .577 .707 r
F P
0 g
s
.53529 .76608 m .54065 .72814 L .5192 .72719 L p .707 .577 .707 r
F P
0 g
s
.56644 .80727 m .56546 .82628 L .59661 .82885 L p .707 .577 .707 r
F P
0 g
s
.62938 .81101 m .6284 .83002 L .6577 .82967 L p .707 .577 .707 r
F P
0 g
s
.6577 .82967 m .65868 .81066 L .62938 .81101 L p .707 .577 .707 r
F P
0 g
s
.56546 .82628 m .56644 .80727 L .53896 .80355 L p .707 .577 .707 r
F P
0 g
s
.53896 .80355 m .53798 .82255 L .56546 .82628 L p .707 .577 .707 r
F P
0 g
s
.6857 .68137 m .68085 .73876 L .69692 .73848 L p .707 .577 .707 r
F P
0 g
s
.69692 .73848 m .70177 .68109 L .6857 .68137 L p .707 .577 .707 r
F P
0 g
s
.65868 .81066 m .6577 .82967 L .68166 .82784 L p .707 .577 .707 r
F P
0 g
s
.68166 .82784 m .68263 .80883 L .65868 .81066 L p .707 .577 .707 r
F P
0 g
s
.68277 .74952 m .67741 .78746 L .69292 .79208 L p .707 .577 .707 r
F P
0 g
s
.51639 .72436 m .52124 .66697 L .50843 .66415 L p .707 .577 .707 r
F P
0 g
s
.69292 .79208 m .69828 .75413 L .68277 .74952 L p .707 .577 .707 r
F P
0 g
s
.50843 .66415 m .50358 .72155 L .51639 .72436 L p .707 .577 .707 r
F P
0 g
s
.53798 .82255 m .53896 .80355 L .51785 .79904 L p .707 .577 .707 r
F P
0 g
s
.51785 .79904 m .51688 .81805 L .53798 .82255 L p .707 .577 .707 r
F P
0 g
s
.50599 .72788 m .50063 .76583 L .51384 .76513 L p .707 .577 .707 r
F P
0 g
s
.51384 .76513 m .5192 .72719 L .50599 .72788 L p .707 .577 .707 r
F P
0 g
s
.68263 .80883 m .68166 .82784 L .69791 .8247 L p .707 .577 .707 r
F P
0 g
s
.69791 .8247 m .69889 .8057 L .68263 .80883 L p .707 .577 .707 r
F P
0 g
s
.70177 .68109 m .69692 .73848 L .7037 .7372 L p .707 .577 .707 r
F P
0 g
s
.7037 .7372 m .70855 .67981 L .70177 .68109 L p .707 .577 .707 r
F P
0 g
s
.69828 .75413 m .69292 .79208 L .69915 .7957 L p .707 .577 .707 r
F P
0 g
s
.51688 .81805 m .51785 .79904 L .50518 .79419 L p .707 .577 .707 r
F P
0 g
s
.50358 .72155 m .50843 .66415 L .50526 .662 L p .707 .577 .707 r
F P
0 g
s
.69915 .7957 m .70451 .75775 L .69828 .75413 L p .707 .577 .707 r
F P
0 g
s
.50518 .79419 m .50421 .81319 L .51688 .81805 L p .707 .577 .707 r
F P
0 g
s
.50526 .662 m .50041 .71939 L .50358 .72155 L p .707 .577 .707 r
F P
0 g
s
.50232 .73015 m .49697 .7681 L .50063 .76583 L p .707 .577 .707 r
F P
0 g
s
.50063 .76583 m .50599 .72788 L .50232 .73015 L p .707 .577 .707 r
F P
0 g
s
.50855 .73377 m .50319 .77171 L .49697 .7681 L p .707 .577 .707 r
F P
0 g
s
.49697 .7681 m .50232 .73015 L .50855 .73377 L p .707 .577 .707 r
F P
0 g
s
.50041 .82496 m .48485 .33515 L .44085 .333 L p .707 .577 .707 r
F P
0 g
s
.50421 .81319 m .50518 .79419 L .50219 .78946 L p .707 .577 .707 r
F P
0 g
s
.50219 .78946 m .50121 .80847 L .50421 .81319 L p .707 .577 .707 r
F P
0 g
s
.50041 .71939 m .50526 .662 L .51204 .66072 L p .707 .577 .707 r
F P
0 g
s
.51204 .66072 m .50719 .71811 L .50041 .71939 L p .707 .577 .707 r
F P
0 g
s
.50121 .80847 m .50219 .78946 L .50916 .78533 L p .707 .577 .707 r
F P
0 g
s
.50916 .78533 m .50818 .80434 L .50121 .80847 L p .707 .577 .707 r
F P
0 g
s
.50719 .71811 m .51204 .66072 L .5281 .66044 L p .707 .577 .707 r
F P
0 g
s
.5281 .66044 m .52325 .71783 L .50719 .71811 L p .707 .577 .707 r
F P
0 g
s
.52406 .73838 m .51871 .77633 L .50319 .77171 L p .707 .577 .707 r
F P
0 g
s
.50319 .77171 m .50855 .73377 L .52406 .73838 L p .707 .577 .707 r
F P
0 g
s
.50818 .80434 m .50916 .78533 L .52542 .7822 L p .707 .577 .707 r
F P
0 g
s
.52325 .71783 m .5281 .66044 L .55188 .66118 L p .707 .577 .707 r
F P
0 g
s
.52542 .7822 m .52444 .80121 L .50818 .80434 L p .707 .577 .707 r
F P
0 g
s
.55188 .66118 m .54703 .71857 L .52325 .71783 L p .707 .577 .707 r
F P
0 g
s
.54734 .74354 m .54199 .78149 L .51871 .77633 L p .707 .577 .707 r
F P
0 g
s
.51871 .77633 m .52406 .73838 L .54734 .74354 L p .707 .577 .707 r
F P
0 g
s
.57611 .74874 m .57076 .78669 L .54199 .78149 L p .707 .577 .707 r
F P
0 g
s
.54199 .78149 m .54734 .74354 L .57611 .74874 L p .707 .577 .707 r
F P
0 g
s
.52444 .80121 m .52542 .7822 L .54937 .78037 L p .707 .577 .707 r
F P
0 g
s
.54937 .78037 m .5484 .79938 L .52444 .80121 L p .707 .577 .707 r
F P
0 g
s
.48485 .33515 m .50041 .82496 L .54533 .8223 L p .707 .577 .707 r
F P
0 g
s
.54533 .8223 m .52976 .33248 L .48485 .33515 L p .707 .577 .707 r
F P
0 g
s
.54703 .71857 m .55188 .66118 L .58104 .66287 L p .707 .577 .707 r
F P
0 g
s
.58104 .66287 m .5762 .72026 L .54703 .71857 L p .707 .577 .707 r
F P
0 g
s
.60756 .75347 m .6022 .79142 L .57076 .78669 L p .707 .577 .707 r
F P
0 g
s
.57076 .78669 m .57611 .74874 L .60756 .75347 L p .707 .577 .707 r
F P
0 g
s
.5484 .79938 m .54937 .78037 L .57868 .78002 L p .707 .577 .707 r
F P
0 g
s
.57868 .78002 m .5777 .79903 L .5484 .79938 L p .707 .577 .707 r
F P
0 g
s
.6022 .79142 m .60756 .75347 L .63859 .75727 L p .707 .577 .707 r
F P
0 g
s
.5777 .79903 m .57868 .78002 L .61046 .78119 L p .707 .577 .707 r
F P
0 g
s
.63859 .75727 m .63323 .79522 L .6022 .79142 L p .707 .577 .707 r
F P
0 g
s
.61046 .78119 m .60948 .8002 L .5777 .79903 L p .707 .577 .707 r
F P
0 g
s
.52976 .33248 m .54533 .8223 L .58677 .81508 L p .707 .577 .707 r
F P
0 g
s
.5762 .72026 m .58104 .66287 L .61274 .66535 L p .707 .577 .707 r
F P
0 g
s
.61274 .66535 m .60789 .72274 L .5762 .72026 L p .707 .577 .707 r
F P
0 g
s
.58677 .81508 m .57121 .32526 L .52976 .33248 L p .707 .577 .707 r
F P
0 g
s
.69889 .8057 m .69791 .8247 L .70489 .82057 L p .707 .577 .707 r
F P
0 g
s
.70489 .82057 m .70586 .80157 L .69889 .8057 L p .707 .577 .707 r
F P
0 g
s
.45641 .82282 m .44085 .333 L .40207 .32626 L p .707 .577 .707 r
F P
0 g
s
.44085 .333 m .45641 .82282 L .50041 .82496 L p .707 .577 .707 r
F P
0 g
s
.70855 .67981 m .7037 .7372 L .70053 .73505 L p .707 .577 .707 r
F P
0 g
s
.70053 .73505 m .70538 .67765 L .70855 .67981 L p .707 .577 .707 r
F P
0 g
s
.64386 .66837 m .63902 .72577 L .61613 .72354 L p .707 .577 .707 r
F P
0 g
s
.61613 .72354 m .60789 .72274 L p .61666 .70949 L .707 .577 .707 r
F P
0 g
s
.61666 .70949 m .64386 .66837 L .61613 .72354 L .707 .577 .707 r
F
.67137 .67164 m .66652 .72904 L .63902 .72577 L p F P
0 g
s
.63902 .72577 m .64386 .66837 L .67137 .67164 L p .707 .577 .707 r
F P
0 g
s
.66619 .75977 m .66083 .79771 L .63323 .79522 L p .707 .577 .707 r
F P
0 g
s
.63323 .79522 m .63859 .75727 L .66619 .75977 L p .707 .577 .707 r
F P
0 g
s
.60789 .72274 m .61274 .66535 L .64386 .66837 L p .707 .577 .707 r
F P
0 g
s
.68763 .76071 m .68228 .79866 L .66083 .79771 L p .707 .577 .707 r
F P
0 g
s
.66083 .79771 m .66619 .75977 L .68763 .76071 L p .707 .577 .707 r
F P
0 g
s
.64064 .80277 m .64162 .78376 L .66909 .78748 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .65368 .77497 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62817 .30038 m .62996 .35672 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62996 .35672 m .64374 .7902 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.64162 .78376 m .64064 .80277 L .60948 .8002 L p .707 .577 .707 r
F P
0 g
s
.60948 .8002 m .61046 .78119 L .64162 .78376 L p .707 .577 .707 r
F P
0 g
s
.57121 .32526 m .58677 .81508 L .62068 .80402 L p .707 .577 .707 r
F P
0 g
s
.62068 .80402 m .60512 .3142 L .57121 .32526 L p .707 .577 .707 r
F P
0 g
s
.70451 .75775 m .69915 .7957 L .69548 .79796 L p .707 .577 .707 r
F P
0 g
s
.69548 .79796 m .70084 .76002 L .70451 .75775 L p .707 .577 .707 r
F P
0 g
s
.41764 .81608 m .40207 .32626 L .37232 .31558 L p .707 .577 .707 r
F P
0 g
s
.40207 .32626 m .41764 .81608 L .45641 .82282 L p .707 .577 .707 r
F P
0 g
s
.70586 .80157 m .70489 .82057 L .70189 .81585 L p .707 .577 .707 r
F P
0 g
s
.70189 .81585 m .70287 .79684 L .70586 .80157 L p .707 .577 .707 r
F P
0 g
s
.70538 .67765 m .70053 .73505 L .68772 .73223 L p .707 .577 .707 r
F P
0 g
s
.68772 .73223 m .69257 .67484 L .70538 .67765 L p .707 .577 .707 r
F P
0 g
s
.60512 .3142 m .62068 .80402 L .64374 .7902 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .62817 .30038 L .60512 .3142 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25321 .69703 m .25805 .63964 L .22693 .63662 L p .707 .577 .707 r
F P
0 g
s
.25805 .63964 m .25321 .69703 L .2849 .69951 L p .707 .577 .707 r
F P
0 g
s
.2849 .69951 m .28975 .64212 L .25805 .63964 L p .707 .577 .707 r
F P
0 g
s
.28975 .64212 m .2849 .69951 L .31407 .70121 L p .707 .577 .707 r
F P
0 g
s
.31407 .70121 m .31891 .64381 L .28975 .64212 L p .707 .577 .707 r
F P
0 g
s
.22693 .63662 m .22208 .69401 L .25321 .69703 L p .707 .577 .707 r
F P
0 g
s
.70084 .76002 m .69548 .79796 L .68228 .79866 L p .707 .577 .707 r
F P
0 g
s
.22208 .69401 m .22693 .63662 L .19942 .63335 L p .707 .577 .707 r
F P
0 g
s
.68228 .79866 m .68763 .76071 L .70084 .76002 L p .707 .577 .707 r
F P
0 g
s
.22523 .69382 m .21987 .73176 L .25091 .73556 L p .707 .577 .707 r
F P
0 g
s
.25091 .73556 m .25627 .69761 L .22523 .69382 L p .707 .577 .707 r
F P
0 g
s
.25627 .69761 m .25091 .73556 L .28235 .74029 L p .707 .577 .707 r
F P
0 g
s
.19942 .63335 m .19458 .69074 L .22208 .69401 L p .707 .577 .707 r
F P
0 g
s
.28235 .74029 m .28771 .70234 L .25627 .69761 L p .707 .577 .707 r
F P
0 g
s
.28771 .70234 m .28235 .74029 L .31112 .74549 L p .707 .577 .707 r
F P
0 g
s
.31112 .74549 m .31648 .70754 L .28771 .70234 L p .707 .577 .707 r
F P
0 g
s
.19764 .69132 m .19228 .72927 L .21987 .73176 L p .707 .577 .707 r
F P
0 g
s
.21987 .73176 m .22523 .69382 L .19764 .69132 L p .707 .577 .707 r
F P
0 g
s
.38789 .8054 m .37232 .31558 L .35451 .302 L p .707 .577 .707 r
F P
0 g
s
.37232 .31558 m .38789 .8054 L .41764 .81608 L p .707 .577 .707 r
F P
0 g
s
.31891 .64381 m .31407 .70121 L .33785 .70195 L p .707 .577 .707 r
F P
0 g
s
.33785 .70195 m .34269 .64455 L .31891 .64381 L p .707 .577 .707 r
F P
0 g
s
.19458 .69074 m .19942 .63335 L .17823 .63015 L p .707 .577 .707 r
F P
0 g
s
.70287 .79684 m .70189 .81585 L .68922 .811 L p .707 .577 .707 r
F P
0 g
s
.68922 .811 m .6902 .79199 L .70287 .79684 L p .707 .577 .707 r
F P
0 g
s
.31648 .70754 m .31112 .74549 L .3344 .75065 L p .707 .577 .707 r
F P
0 g
s
.69257 .67484 m .68772 .73223 L .66652 .72904 L p .707 .577 .707 r
F P
0 g
s
.66652 .72904 m .67137 .67164 L .69257 .67484 L p .707 .577 .707 r
F P
0 g
s
.17823 .63015 m .17338 .68754 L .19458 .69074 L p .707 .577 .707 r
F P
0 g
s
.3344 .75065 m .33976 .7127 L .31648 .70754 L p .707 .577 .707 r
F P
0 g
s
.2536 .79203 m .25458 .77302 L .22343 .77045 L p .707 .577 .707 r
F P
0 g
s
.25458 .77302 m .2536 .79203 L .28539 .7932 L p .707 .577 .707 r
F P
0 g
s
.28539 .7932 m .28637 .77419 L .25458 .77302 L p .707 .577 .707 r
F P
0 g
s
.17619 .69037 m .17083 .72832 L .19228 .72927 L p .707 .577 .707 r
F P
0 g
s
.19228 .72927 m .19764 .69132 L .17619 .69037 L p .707 .577 .707 r
F P
0 g
s
.22343 .77045 m .22245 .78946 L .2536 .79203 L p .707 .577 .707 r
F P
0 g
s
.28637 .77419 m .28539 .7932 L .31469 .79285 L p .707 .577 .707 r
F P
0 g
s
.31469 .79285 m .31567 .77384 L .28637 .77419 L p .707 .577 .707 r
F P
0 g
s
.65368 .77497 m .63812 .28515 L .62817 .30038 L p .707 .577 .707 r
F P
0 g
s
.22245 .78946 m .22343 .77045 L .19595 .76673 L p .707 .577 .707 r
F P
0 g
s
.19595 .76673 m .19497 .78574 L .22245 .78946 L p .707 .577 .707 r
F P
0 g
s
.34269 .64455 m .33785 .70195 L .35391 .70166 L p .707 .577 .707 r
F P
0 g
s
.35391 .70166 m .35876 .64427 L .34269 .64455 L p .707 .577 .707 r
F P
0 g
s
.31567 .77384 m .31469 .79285 L .33865 .79102 L p .707 .577 .707 r
F P
0 g
s
.33865 .79102 m .33962 .77201 L .31567 .77384 L p .707 .577 .707 r
F P
0 g
s
.33976 .7127 m .3344 .75065 L .34991 .75526 L p .707 .577 .707 r
F P
0 g
s
.17338 .68754 m .17823 .63015 L .16542 .62734 L p .707 .577 .707 r
F P
0 g
s
.34991 .75526 m .35527 .71732 L .33976 .7127 L p .707 .577 .707 r
F P
0 g
s
.16542 .62734 m .16057 .68473 L .17338 .68754 L p .707 .577 .707 r
F P
0 g
s
.19497 .78574 m .19595 .76673 L .17484 .76222 L p .707 .577 .707 r
F P
0 g
s
.6902 .79199 m .68922 .811 L .66811 .80649 L p .707 .577 .707 r
F P
0 g
s
.66811 .80649 m .66909 .78748 L .6902 .79199 L p .707 .577 .707 r
F P
0 g
s
.17484 .76222 m .17387 .78123 L .19497 .78574 L p .707 .577 .707 r
F P
0 g
s
.36069 .70038 m .36554 .64299 L .35876 .64427 L p .707 .577 .707 r
F P
0 g
s
.35876 .64427 m .35391 .70166 L .36069 .70038 L p .707 .577 .707 r
F P
0 g
s
.36554 .64299 m .36069 .70038 L .35752 .69823 L p .707 .577 .707 r
F P
0 g
s
.35752 .69823 m .36237 .64084 L .36554 .64299 L p .707 .577 .707 r
F P
0 g
s
.37007 .79182 m .35451 .302 L .35037 .28686 L p .707 .577 .707 r
F P
0 g
s
.35451 .302 m .37007 .79182 L .38789 .8054 L p .707 .577 .707 r
F P
0 g
s
.16298 .69107 m .15762 .72901 L .17083 .72832 L p .707 .577 .707 r
F P
0 g
s
.17083 .72832 m .17619 .69037 L .16298 .69107 L p .707 .577 .707 r
F P
0 g
s
.33962 .77201 m .33865 .79102 L .35491 .78789 L p .707 .577 .707 r
F P
0 g
s
.35491 .78789 m .35588 .76888 L .33962 .77201 L p .707 .577 .707 r
F P
0 g
s
.35527 .71732 m .34991 .75526 L .35614 .75888 L p .707 .577 .707 r
F P
0 g
s
.17387 .78123 m .17484 .76222 L .16217 .75737 L p .707 .577 .707 r
F P
0 g
s
.66909 .78748 m .66811 .80649 L .64064 .80277 L p .707 .577 .707 r
F P
0 g
s
.16057 .68473 m .16542 .62734 L .16225 .62519 L p .707 .577 .707 r
F P
0 g
s
.63812 .28515 m .65205 .72358 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .63812 .28515 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.63784 .6788 m .6472 .67831 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .64591 .64553 L p .63209 .66964 L .707 .577 .707 r
F P
0 g
s
.64591 .64553 m .64685 .67507 L p .63878 .6721 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .64591 .64553 L .63878 .6721 L .707 .577 .707 r
F
.64955 .75983 m .63173 .74625 L p .63209 .66964 L F P
0 g
s
.63682 .67943 m .63784 .6788 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63878 .6721 m .63784 .6788 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.64685 .67507 m .64955 .75983 L p .63517 .68556 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .63878 .6721 L .63517 .68556 L .707 .577 .707 r
F
.63784 .6788 m .63878 .6721 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .64685 .67507 L .63517 .68556 L .707 .577 .707 r
F
.6432 .64085 m .63953 .64312 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .6432 .64085 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63953 .64312 m .63417 .68106 L .63682 .67943 L p .707 .577 .707 r
F P
0 g
s
.63802 .67495 m .63953 .64312 L .63682 .67943 L .707 .577 .707 r
F
.64316 .6411 m .63878 .6721 L p .64685 .67507 L F P
0 g
s
.64936 .75218 m .64685 .67507 L .64769 .68279 L .707 .577 .707 r
F
.64925 .75062 m .64685 .67507 L p .64936 .75218 L F P
0 g
s
.65368 .77497 m .65001 .76153 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.65001 .76153 m .64955 .75983 L p .64936 .75218 L .707 .577 .707 r
F P
0 g
s
.64936 .75218 m .64731 .66703 L .65001 .76153 L .707 .577 .707 r
F
.64239 .72141 m .64141 .74041 L .64874 .74322 L p F P
0 g
s
.65205 .72358 m .65368 .77497 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.64874 .74322 m .65408 .74527 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.64802 .73291 m .64239 .72141 L .64874 .74322 L .707 .577 .707 r
F
.65408 .74527 m .65506 .72626 L .64736 .72331 L p F P
0 g
s
.64736 .72331 m .64239 .72141 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.65408 .74527 m .64736 .72331 L .64802 .73291 L .707 .577 .707 r
F
.64955 .75983 m .64925 .75062 L p .64936 .75218 L F P
0 g
s
.64685 .67507 m .63398 .27001 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.6432 .64085 m .64316 .6411 L p .65104 .6781 L .707 .577 .707 r
F P
0 g
s
.6472 .67831 m .65104 .6781 L p .64316 .6411 L .707 .577 .707 r
F P
0 g
s
.64563 .5595 m .64195 .60306 L p .65359 .6197 L .707 .577 .707 r
F P
0 g
s
.64195 .60306 m .64078 .61689 L .64315 .61741 L p .707 .577 .707 r
F P
0 g
s
.64315 .61741 m .65359 .6197 L p .64195 .60306 L .707 .577 .707 r
F P
0 g
s
.35614 .75888 m .3615 .72094 L .35527 .71732 L p .707 .577 .707 r
F P
0 g
s
.16217 .75737 m .1612 .77638 L .17387 .78123 L p .707 .577 .707 r
F P
0 g
s
.16225 .62519 m .1574 .68258 L .16057 .68473 L p .707 .577 .707 r
F P
0 g
s
.15931 .69334 m .15396 .73128 L .15762 .72901 L p .707 .577 .707 r
F P
0 g
s
.15762 .72901 m .16298 .69107 L .15931 .69334 L p .707 .577 .707 r
F P
0 g
s
.35588 .76888 m .35491 .78789 L .36188 .78376 L p .707 .577 .707 r
F P
0 g
s
.36188 .78376 m .36285 .76475 L .35588 .76888 L p .707 .577 .707 r
F P
0 g
s
.36237 .64084 m .35752 .69823 L .34475 .69543 L p .707 .577 .707 r
F P
0 g
s
.34475 .69543 m .34471 .69542 L p .34476 .69527 L .707 .577 .707 r
F P
0 g
s
.34476 .69527 m .36237 .64084 L .34475 .69543 L .707 .577 .707 r
F
.35037 .28686 m .36032 .27163 L p .36144 .3731 L F P
0 g
s
.36452 .64952 m .36594 .77668 L .37007 .79182 L p .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35705 .45799 L p .35037 .28686 L .707 .577 .707 r
F P
0 g
s
.34471 .69542 m .34956 .63803 L .36237 .64084 L p .707 .577 .707 r
F P
0 g
s
.36594 .77668 m .35628 .47282 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35037 .28686 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.1612 .77638 m .16217 .75737 L .15918 .75265 L p .707 .577 .707 r
F P
0 g
s
.3615 .72094 m .35614 .75888 L .35247 .76115 L p .707 .577 .707 r
F P
0 g
s
.15918 .75265 m .1582 .77166 L .1612 .77638 L p .707 .577 .707 r
F P
0 g
s
.1574 .68258 m .16225 .62519 L .16903 .62391 L p .707 .577 .707 r
F P
0 g
s
.35247 .76115 m .35783 .7232 L .3615 .72094 L p .707 .577 .707 r
F P
0 g
s
.16903 .62391 m .16418 .6813 L .1574 .68258 L p .707 .577 .707 r
F P
0 g
s
.16554 .69695 m .16018 .7349 L .15396 .73128 L p .707 .577 .707 r
F P
0 g
s
.15396 .73128 m .15931 .69334 L .16554 .69695 L p .707 .577 .707 r
F P
0 g
s
.63173 .74625 m .61616 .25643 L .63398 .27001 L p .707 .577 .707 r
F P
0 g
s
.36285 .76475 m .36188 .78376 L .35888 .77904 L p .707 .577 .707 r
F P
0 g
s
.35888 .77904 m .35986 .76003 L .36285 .76475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1582 .77166 m .15918 .75265 L .16615 .74852 L p .707 .577 .707 r
F P
0 g
s
.35783 .7232 m .35247 .76115 L .33927 .76184 L p .707 .577 .707 r
F P
0 g
s
.16615 .74852 m .16517 .76753 L .1582 .77166 L p .707 .577 .707 r
F P
0 g
s
.37588 .76145 m .36032 .27163 L .38337 .25781 L p .707 .577 .707 r
F P
0 g
s
.36032 .27163 m .37588 .76145 L .36594 .77668 L p .707 .577 .707 r
F P
0 g
s
.16418 .6813 m .16903 .62391 L .18509 .62362 L p .707 .577 .707 r
F P
0 g
s
.33927 .76184 m .34463 .7239 L .35783 .7232 L p .707 .577 .707 r
F P
0 g
s
.18509 .62362 m .18024 .68102 L .16418 .6813 L p .707 .577 .707 r
F P
0 g
s
.18105 .70157 m .1757 .73951 L .16018 .7349 L p .707 .577 .707 r
F P
0 g
s
.16018 .7349 m .16554 .69695 L .18105 .70157 L p .707 .577 .707 r
F P
0 g
s
.35986 .76003 m .35888 .77904 L .34621 .77418 L p .707 .577 .707 r
F P
0 g
s
.34621 .77418 m .34719 .75517 L .35986 .76003 L p .707 .577 .707 r
F P
0 g
s
.34956 .63803 m .34471 .69542 L .32351 .69222 L p .707 .577 .707 r
F P
0 g
s
.32351 .69222 m .32836 .63483 L .34956 .63803 L p .707 .577 .707 r
F P
0 g
s
.61616 .25643 m .63173 .74625 L .60198 .73557 L p .707 .577 .707 r
F P
0 g
s
.60198 .73557 m .58641 .24575 L .61616 .25643 L p .707 .577 .707 r
F P
0 g
s
.34463 .7239 m .33927 .76184 L .31782 .7609 L p .707 .577 .707 r
F P
0 g
s
.16517 .76753 m .16615 .74852 L .18241 .74538 L p .707 .577 .707 r
F P
0 g
s
.18024 .68102 m .18509 .62362 L .20887 .62436 L p .707 .577 .707 r
F P
0 g
s
.18241 .74538 m .18143 .76439 L .16517 .76753 L p .707 .577 .707 r
F P
0 g
s
.31782 .7609 m .32318 .72295 L .34463 .7239 L p .707 .577 .707 r
F P
0 g
s
.20887 .62436 m .20402 .68176 L .18024 .68102 L p .707 .577 .707 r
F P
0 g
s
.20433 .70673 m .19898 .74467 L .1757 .73951 L p .707 .577 .707 r
F P
0 g
s
.1757 .73951 m .18105 .70157 L .20433 .70673 L p .707 .577 .707 r
F P
0 g
s
.38337 .25781 m .39791 .71524 L p .37588 .76145 L .707 .577 .707 r
F P
0 g
s
.39894 .74763 m .38337 .25781 L .41728 .24675 L p .707 .577 .707 r
F P
0 g
s
.43285 .73657 m .39894 .74763 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.41728 .24675 m .42946 .63003 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.42946 .63003 m .43015 .65181 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.40111 .68841 m .43015 .65181 L .40174 .68937 L .707 .577 .707 r
F
.42491 .61531 m .41955 .65326 L .42792 .65477 L p F P
0 g
s
.41728 .24675 m .45872 .23953 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.42792 .65477 m .44832 .65846 L p .4447 .65178 L .707 .577 .707 r
F P
0 g
s
.4447 .65178 m .43015 .65181 L .42792 .65477 L .707 .577 .707 r
F
.43285 .73657 m .43015 .65181 L p .43726 .6518 L F P
0 g
s
.43015 .65181 m .41728 .24675 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .43285 .73657 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45872 .23953 m .47182 .6517 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.44927 .65176 m .44832 .65846 L .4548 .65989 L p .707 .577 .707 r
F P
0 g
s
.43726 .6518 m .43811 .63536 L .44927 .65176 L .707 .577 .707 r
F
.43811 .63536 m .45872 .23953 L .44927 .65176 L F
.44832 .65846 m .45368 .62051 L .42491 .61531 L p F P
0 g
s
.47182 .6517 m .47429 .72935 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45368 .62051 m .44927 .65176 L p .47161 .66362 L .707 .577 .707 r
F P
0 g
s
.4548 .65989 m .47161 .66362 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.43864 .6406 m .42491 .61531 L .42769 .65182 L .707 .577 .707 r
F
.43015 .65181 m .42769 .65182 L .42792 .65477 L F
.43864 .6406 m .42769 .65182 L .43015 .65181 L F
.4447 .65178 m .43864 .6406 L .43015 .65181 L F
.43015 .65181 m .43255 .72736 L p .40174 .68937 L F P
0 g
s
.40174 .68937 m .43255 .72736 L .4306 .73316 L .707 .577 .707 r
F
.42357 .70141 m .42259 .72042 L .43494 .72028 L p F P
0 g
s
.43494 .72028 m .4519 .72007 L p .43808 .71097 L .707 .577 .707 r
F P
0 g
s
.43808 .71097 m .42357 .70141 L .43494 .72028 L .707 .577 .707 r
F
.43255 .72736 m .43285 .73657 L p .4306 .73316 L F P
0 g
s
.42695 .53747 m .42211 .59486 L .44587 .59624 L p .707 .577 .707 r
F P
0 g
s
.44587 .59624 m .45127 .59655 L p .44872 .59037 L .707 .577 .707 r
F P
0 g
s
.44872 .59037 m .42695 .53747 L .44587 .59624 L .707 .577 .707 r
F
.39526 .53499 m .39041 .59238 L .41525 .59432 L p F P
0 g
s
.41525 .59432 m .42211 .59486 L p .41685 .58315 L .707 .577 .707 r
F P
0 g
s
.41685 .58315 m .39526 .53499 L .41525 .59432 L .707 .577 .707 r
F
.39791 .71524 m .39894 .74763 L .39273 .75135 L p F P
0 g
s
.39273 .75135 m .37588 .76145 L p .39791 .71524 L .707 .577 .707 r
F P
0 g
s
.32836 .63483 m .32351 .69222 L .29601 .68895 L p .707 .577 .707 r
F P
0 g
s
.29601 .68895 m .30085 .63156 L .32836 .63483 L p .707 .577 .707 r
F P
0 g
s
.34719 .75517 m .34621 .77418 L .3251 .76967 L p .707 .577 .707 r
F P
0 g
s
.3251 .76967 m .32608 .75067 L .34719 .75517 L p .707 .577 .707 r
F P
0 g
s
.20402 .68176 m .20887 .62436 L .23803 .62606 L p .707 .577 .707 r
F P
0 g
s
.32318 .72295 m .31782 .7609 L .29022 .7584 L p .707 .577 .707 r
F P
0 g
s
.58641 .24575 m .60198 .73557 L .56321 .72882 L p .707 .577 .707 r
F P
0 g
s
.56321 .72882 m .54764 .239 L .58641 .24575 L p .707 .577 .707 r
F P
0 g
s
.23803 .62606 m .23319 .68345 L .20402 .68176 L p .707 .577 .707 r
F P
0 g
s
.29022 .7584 m .29558 .72046 L .32318 .72295 L p .707 .577 .707 r
F P
0 g
s
.2331 .71193 m .22775 .74987 L .19898 .74467 L p .707 .577 .707 r
F P
0 g
s
.19898 .74467 m .20433 .70673 L .2331 .71193 L p .707 .577 .707 r
F P
0 g
s
.18143 .76439 m .18241 .74538 L .20636 .74355 L p .707 .577 .707 r
F P
0 g
s
.73342 .6292 m .73827 .5718 L .70714 .56878 L p .707 .577 .707 r
F P
0 g
s
.73827 .5718 m .73342 .6292 L .76512 .63167 L p .707 .577 .707 r
F P
0 g
s
.76512 .63167 m .76996 .57428 L .73827 .5718 L p .707 .577 .707 r
F P
0 g
s
.20636 .74355 m .20539 .76256 L .18143 .76439 L p .707 .577 .707 r
F P
0 g
s
.30085 .63156 m .29601 .68895 L .26488 .68593 L p .707 .577 .707 r
F P
0 g
s
.26488 .68593 m .26973 .62853 L .30085 .63156 L p .707 .577 .707 r
F P
0 g
s
.76996 .57428 m .76512 .63167 L .79428 .63337 L p .707 .577 .707 r
F P
0 g
s
.79428 .63337 m .79913 .57597 L .76996 .57428 L p .707 .577 .707 r
F P
0 g
s
.70714 .56878 m .7023 .62617 L .73342 .6292 L p .707 .577 .707 r
F P
0 g
s
.23319 .68345 m .23803 .62606 L .26973 .62853 L p .707 .577 .707 r
F P
0 g
s
.7023 .62617 m .70714 .56878 L .67964 .56551 L p .707 .577 .707 r
F P
0 g
s
.26973 .62853 m .26488 .68593 L .23319 .68345 L p .707 .577 .707 r
F P
0 g
s
.67964 .56551 m .67479 .6229 L .7023 .62617 L p .707 .577 .707 r
F P
0 g
s
.29558 .72046 m .29022 .7584 L .25919 .7546 L p .707 .577 .707 r
F P
0 g
s
.32608 .75067 m .3251 .76967 L .29763 .76595 L p .707 .577 .707 r
F P
0 g
s
.29763 .76595 m .29861 .74694 L .32608 .75067 L p .707 .577 .707 r
F P
0 g
s
.70544 .6436 m .70009 .68154 L .73112 .68534 L p .707 .577 .707 r
F P
0 g
s
.73112 .68534 m .73648 .6474 L .70544 .6436 L p .707 .577 .707 r
F P
0 g
s
.73648 .6474 m .73112 .68534 L .76256 .69007 L p .707 .577 .707 r
F P
0 g
s
.25919 .7546 m .26455 .71666 L .29558 .72046 L p .707 .577 .707 r
F P
0 g
s
.26455 .71666 m .25919 .7546 L .22775 .74987 L p .707 .577 .707 r
F P
0 g
s
.22775 .74987 m .2331 .71193 L .26455 .71666 L p .707 .577 .707 r
F P
0 g
s
.79913 .57597 m .79428 .63337 L .81806 .63411 L p .707 .577 .707 r
F P
0 g
s
.81806 .63411 m .82291 .57671 L .79913 .57597 L p .707 .577 .707 r
F P
0 g
s
.76256 .69007 m .76792 .65213 L .73648 .6474 L p .707 .577 .707 r
F P
0 g
s
.76792 .65213 m .76256 .69007 L .79133 .69527 L p .707 .577 .707 r
F P
0 g
s
.54764 .239 m .56321 .72882 L .51921 .72668 L p .707 .577 .707 r
F P
0 g
s
.51921 .72668 m .50364 .23686 L .54764 .239 L p .707 .577 .707 r
F P
0 g
s
.20539 .76256 m .20636 .74355 L .23567 .7432 L p .707 .577 .707 r
F P
0 g
s
.79133 .69527 m .79669 .65733 L .76792 .65213 L p .707 .577 .707 r
F P
0 g
s
.67785 .64111 m .67249 .67905 L .70009 .68154 L p .707 .577 .707 r
F P
0 g
s
.70009 .68154 m .70544 .6436 L .67785 .64111 L p .707 .577 .707 r
F P
0 g
s
.23567 .7432 m .23469 .76221 L .20539 .76256 L p .707 .577 .707 r
F P
0 g
s
.67479 .6229 m .67964 .56551 L .65844 .56231 L p .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .45872 .23953 L .50364 .23686 L p .707 .577 .707 r
F P
0 g
s
.65844 .56231 m .65359 .6197 L .67479 .6229 L p .707 .577 .707 r
F P
0 g
s
.50364 .23686 m .51921 .72668 L .47429 .72935 L p .707 .577 .707 r
F P
0 g
s
.29861 .74694 m .29763 .76595 L .26647 .76338 L p .707 .577 .707 r
F P
0 g
s
.26647 .76338 m .26745 .74437 L .29861 .74694 L p .707 .577 .707 r
F P
0 g
s
.79669 .65733 m .79133 .69527 L .81462 .70043 L p .707 .577 .707 r
F P
0 g
s
.23469 .76221 m .23567 .7432 L .26745 .74437 L p .707 .577 .707 r
F P
0 g
s
.81462 .70043 m .81997 .66249 L .79669 .65733 L p .707 .577 .707 r
F P
0 g
s
.26745 .74437 m .26647 .76338 L .23469 .76221 L p .707 .577 .707 r
F P
0 g
s
.6564 .64016 m .65104 .6781 L .67249 .67905 L p .707 .577 .707 r
F P
0 g
s
.67249 .67905 m .67785 .64111 L .6564 .64016 L p .707 .577 .707 r
F P
0 g
s
.73382 .75607 m .73479 .73706 L .70364 .73449 L p .707 .577 .707 r
F P
0 g
s
.73479 .73706 m .73382 .75607 L .7656 .75724 L p .707 .577 .707 r
F P
0 g
s
.7656 .75724 m .76658 .73823 L .73479 .73706 L p .707 .577 .707 r
F P
0 g
s
.82291 .57671 m .81806 .63411 L .83412 .63382 L p .707 .577 .707 r
F P
0 g
s
.83412 .63382 m .83897 .57643 L .82291 .57671 L p .707 .577 .707 r
F P
0 g
s
.70364 .73449 m .70266 .7535 L .73382 .75607 L p .707 .577 .707 r
F P
0 g
s
.76658 .73823 m .7656 .75724 L .79491 .75689 L p .707 .577 .707 r
F P
0 g
s
.79491 .75689 m .79588 .73788 L .76658 .73823 L p .707 .577 .707 r
F P
0 g
s
.70266 .7535 m .70364 .73449 L .67616 .73077 L p .707 .577 .707 r
F P
0 g
s
.65359 .6197 m .65844 .56231 L .64563 .5595 L p .707 .577 .707 r
F P
0 g
s
.67616 .73077 m .67519 .74978 L .70266 .7535 L p .707 .577 .707 r
F P
0 g
s
.81997 .66249 m .81462 .70043 L .83013 .70505 L p .707 .577 .707 r
F P
0 g
s
.79588 .73788 m .79491 .75689 L .81886 .75506 L p .707 .577 .707 r
F P
0 g
s
.81886 .75506 m .81984 .73605 L .79588 .73788 L p .707 .577 .707 r
F P
0 g
s
.83013 .70505 m .83549 .6671 L .81997 .66249 L p .707 .577 .707 r
F P
0 g
s
.65104 .6781 m .6564 .64016 L .6432 .64085 L p .707 .577 .707 r
F P
0 g
s
.67519 .74978 m .67616 .73077 L .65506 .72626 L p .707 .577 .707 r
F P
0 g
s
.65506 .72626 m .65408 .74527 L .67519 .74978 L p .707 .577 .707 r
F P
0 g
s
.83897 .57643 m .83412 .63382 L .8409 .63254 L p .707 .577 .707 r
F P
0 g
s
.8409 .63254 m .84575 .57515 L .83897 .57643 L p .707 .577 .707 r
F P
0 g
s
.81984 .73605 m .81886 .75506 L .83512 .75192 L p .707 .577 .707 r
F P
0 g
s
.83512 .75192 m .8361 .73292 L .81984 .73605 L p .707 .577 .707 r
F P
0 g
s
.64078 .61689 m .64563 .5595 L .64246 .55735 L p .707 .577 .707 r
F P
0 g
s
.83549 .6671 m .83013 .70505 L .83636 .70866 L p .707 .577 .707 r
F P
0 g
s
.64246 .55735 m .63761 .61474 L .64078 .61689 L p .707 .577 .707 r
F P
0 g
s
.83636 .70866 m .84171 .67072 L .83549 .6671 L p .707 .577 .707 r
F P
0 g
s
.84575 .57515 m .8409 .63254 L .83773 .63039 L p .707 .577 .707 r
F P
0 g
s
.83773 .63039 m .84258 .573 L .84575 .57515 L p .707 .577 .707 r
F P
0 g
s
.8361 .73292 m .83512 .75192 L .84209 .74779 L p .707 .577 .707 r
F P
0 g
s
.84209 .74779 m .84307 .72879 L .8361 .73292 L p .707 .577 .707 r
F P
0 g
s
.63761 .61474 m .64246 .55735 L .64924 .55607 L p .707 .577 .707 r
F P
0 g
s
.84171 .67072 m .83636 .70866 L .83269 .71093 L p .707 .577 .707 r
F P
0 g
s
.64924 .55607 m .64439 .61346 L .63761 .61474 L p .707 .577 .707 r
F P
0 g
s
.64141 .74041 m .64239 .72141 L .63939 .71668 L p .707 .577 .707 r
F P
0 g
s
.83269 .71093 m .83804 .67299 L .84171 .67072 L p .707 .577 .707 r
F P
0 g
s
.63939 .71668 m .63841 .73569 L .64141 .74041 L p .707 .577 .707 r
F P
0 g
s
.64575 .64674 m .6404 .68468 L .63417 .68106 L p .707 .577 .707 r
F P
0 g
s
.63417 .68106 m .63953 .64312 L .64575 .64674 L p .707 .577 .707 r
F P
0 g
s
.84258 .573 m .83773 .63039 L .82492 .62758 L p .707 .577 .707 r
F P
0 g
s
.82492 .62758 m .82977 .57019 L .84258 .573 L p .707 .577 .707 r
F P
0 g
s
.39041 .59238 m .39526 .53499 L .36413 .53196 L p .707 .577 .707 r
F P
0 g
s
.42211 .59486 m .42695 .53747 L .39526 .53499 L p .707 .577 .707 r
F P
0 g
s
.84307 .72879 m .84209 .74779 L .8391 .74307 L p .707 .577 .707 r
F P
0 g
s
.8391 .74307 m .84007 .72406 L .84307 .72879 L p .707 .577 .707 r
F P
0 g
s
.45127 .59655 m .45612 .53916 L .42695 .53747 L p .707 .577 .707 r
F P
0 g
s
.36413 .53196 m .35929 .58936 L .39041 .59238 L p .707 .577 .707 r
F P
0 g
s
.64439 .61346 m .64924 .55607 L .6653 .55578 L p .707 .577 .707 r
F P
0 g
s
.35929 .58936 m .36413 .53196 L .33663 .52869 L p .707 .577 .707 r
F P
0 g
s
.83804 .67299 m .83269 .71093 L .81948 .71163 L p .707 .577 .707 r
F P
0 g
s
.6653 .55578 m .66046 .61318 L .64439 .61346 L p .707 .577 .707 r
F P
0 g
s
.33663 .52869 m .33178 .58609 L .35929 .58936 L p .707 .577 .707 r
F P
0 g
s
.63841 .73569 m .63939 .71668 L .64636 .71255 L p .707 .577 .707 r
F P
0 g
s
.81948 .71163 m .82484 .67368 L .83804 .67299 L p .707 .577 .707 r
F P
0 g
s
.36243 .60678 m .35708 .64473 L .38811 .64853 L p .707 .577 .707 r
F P
0 g
s
.38811 .64853 m .39347 .61058 L .36243 .60678 L p .707 .577 .707 r
F P
0 g
s
.39347 .61058 m .38811 .64853 L .41955 .65326 L p .707 .577 .707 r
F P
0 g
s
.64636 .71255 m .64539 .73156 L .63841 .73569 L p .707 .577 .707 r
F P
0 g
s
.45612 .53916 m .45127 .59655 L .47505 .59729 L p .707 .577 .707 r
F P
0 g
s
.47505 .59729 m .4799 .5399 L .45612 .53916 L p .707 .577 .707 r
F P
0 g
s
.41955 .65326 m .42491 .61531 L .39347 .61058 L p .707 .577 .707 r
F P
0 g
s
.66127 .65135 m .65591 .6893 L .6404 .68468 L p .707 .577 .707 r
F P
0 g
s
.6404 .68468 m .64575 .64674 L .66127 .65135 L p .707 .577 .707 r
F P
0 g
s
.33484 .60429 m .32948 .64223 L .35708 .64473 L p .707 .577 .707 r
F P
0 g
s
.35708 .64473 m .36243 .60678 L .33484 .60429 L p .707 .577 .707 r
F P
0 g
s
.33178 .58609 m .33663 .52869 L .31543 .5255 L p .707 .577 .707 r
F P
0 g
s
.82977 .57019 m .82492 .62758 L .80373 .62438 L p .707 .577 .707 r
F P
0 g
s
.80373 .62438 m .80857 .56699 L .82977 .57019 L p .707 .577 .707 r
F P
0 g
s
.31543 .5255 m .31058 .58289 L .33178 .58609 L p .707 .577 .707 r
F P
0 g
s
.84007 .72406 m .8391 .74307 L .82642 .73822 L p .707 .577 .707 r
F P
0 g
s
.82642 .73822 m .8274 .71921 L .84007 .72406 L p .707 .577 .707 r
F P
0 g
s
.47161 .66362 m .47696 .62567 L .45368 .62051 L p .707 .577 .707 r
F P
0 g
s
.66046 .61318 m .6653 .55578 L .68908 .55652 L p .707 .577 .707 r
F P
0 g
s
.31339 .60334 m .30803 .64129 L .32948 .64223 L p .707 .577 .707 r
F P
0 g
s
.32948 .64223 m .33484 .60429 L .31339 .60334 L p .707 .577 .707 r
F P
0 g
s
.39081 .71925 m .39178 .70024 L .36063 .69767 L p .707 .577 .707 r
F P
0 g
s
.39178 .70024 m .39081 .71925 L .42259 .72042 L p .707 .577 .707 r
F P
0 g
s
.42259 .72042 m .42357 .70141 L .39178 .70024 L p .707 .577 .707 r
F P
0 g
s
.68908 .55652 m .68424 .61392 L .66046 .61318 L p .707 .577 .707 r
F P
0 g
s
.4799 .5399 m .47505 .59729 L .49111 .59701 L p .707 .577 .707 r
F P
0 g
s
.49111 .59701 m .49596 .53962 L .4799 .5399 L p .707 .577 .707 r
F P
0 g
s
.82484 .67368 m .81948 .71163 L .79803 .71068 L p .707 .577 .707 r
F P
0 g
s
.36063 .69767 m .35965 .71668 L .39081 .71925 L p .707 .577 .707 r
F P
0 g
s
.4519 .72007 m .45287 .70107 L .42357 .70141 L p .707 .577 .707 r
F P
0 g
s
.79803 .71068 m .80339 .67274 L .82484 .67368 L p .707 .577 .707 r
F P
0 g
s
.64539 .73156 m .64636 .71255 L .66262 .70942 L p .707 .577 .707 r
F P
0 g
s
.35965 .71668 m .36063 .69767 L .33315 .69395 L p .707 .577 .707 r
F P
0 g
s
.66262 .70942 m .66165 .72843 L .64539 .73156 L p .707 .577 .707 r
F P
0 g
s
.31058 .58289 m .31543 .5255 L .30262 .52268 L p .707 .577 .707 r
F P
0 g
s
.33315 .69395 m .33218 .71296 L .35965 .71668 L p .707 .577 .707 r
F P
0 g
s
.68455 .65651 m .67919 .69446 L .65591 .6893 L p .707 .577 .707 r
F P
0 g
s
.65591 .6893 m .66127 .65135 L .68455 .65651 L p .707 .577 .707 r
F P
0 g
s
.80857 .56699 m .80373 .62438 L .77622 .62111 L p .707 .577 .707 r
F P
0 g
s
.77622 .62111 m .78107 .56372 L .80857 .56699 L p .707 .577 .707 r
F P
0 g
s
.30262 .52268 m .29777 .58008 L .31058 .58289 L p .707 .577 .707 r
F P
0 g
s
.47696 .62567 m .47161 .66362 L .48712 .66823 L p .707 .577 .707 r
F P
0 g
s
.45287 .70107 m .4519 .72007 L .47585 .71824 L p .707 .577 .707 r
F P
0 g
s
.47585 .71824 m .47683 .69923 L .45287 .70107 L p .707 .577 .707 r
F P
0 g
s
.48712 .66823 m .49248 .63029 L .47696 .62567 L p .707 .577 .707 r
F P
0 g
s
.68424 .61392 m .68908 .55652 L .71825 .55822 L p .707 .577 .707 r
F P
0 g
s
.71825 .55822 m .7134 .61561 L .68424 .61392 L p .707 .577 .707 r
F P
0 g
s
.30019 .60404 m .29483 .64198 L .30803 .64129 L p .707 .577 .707 r
F P
0 g
s
.30803 .64129 m .31339 .60334 L .30019 .60404 L p .707 .577 .707 r
F P
0 g
s
.33218 .71296 m .33315 .69395 L .31205 .68944 L p .707 .577 .707 r
F P
0 g
s
.8274 .71921 m .82642 .73822 L .80532 .73371 L p .707 .577 .707 r
F P
0 g
s
.80532 .73371 m .8063 .7147 L .8274 .71921 L p .707 .577 .707 r
F P
0 g
s
.80339 .67274 m .79803 .71068 L .77044 .70818 L p .707 .577 .707 r
F P
0 g
s
.31205 .68944 m .31107 .70845 L .33218 .71296 L p .707 .577 .707 r
F P
0 g
s
.78107 .56372 m .77622 .62111 L .7451 .61809 L p .707 .577 .707 r
F P
0 g
s
.7451 .61809 m .74994 .5607 L .78107 .56372 L p .707 .577 .707 r
F P
0 g
s
.77044 .70818 m .7758 .67024 L .80339 .67274 L p .707 .577 .707 r
F P
0 g
s
.49596 .53962 m .49111 .59701 L .49789 .59573 L p .707 .577 .707 r
F P
0 g
s
.49789 .59573 m .50274 .53833 L .49596 .53962 L p .707 .577 .707 r
F P
0 g
s
.71332 .66171 m .70796 .69966 L .67919 .69446 L p .707 .577 .707 r
F P
0 g
s
.67919 .69446 m .68455 .65651 L .71332 .66171 L p .707 .577 .707 r
F P
0 g
s
.7134 .61561 m .71825 .55822 L .74994 .5607 L p .707 .577 .707 r
F P
0 g
s
.66165 .72843 m .66262 .70942 L .68658 .70759 L p .707 .577 .707 r
F P
0 g
s
.74994 .5607 m .7451 .61809 L .7134 .61561 L p .707 .577 .707 r
F P
0 g
s
.68658 .70759 m .6856 .7266 L .66165 .72843 L p .707 .577 .707 r
F P
0 g
s
.47683 .69923 m .47585 .71824 L .49211 .71511 L p .707 .577 .707 r
F P
0 g
s
.49211 .71511 m .49309 .6961 L .47683 .69923 L p .707 .577 .707 r
F P
0 g
s
.29777 .58008 m .30262 .52268 L .29945 .52053 L p .707 .577 .707 r
F P
0 g
s
.7758 .67024 m .77044 .70818 L .7394 .70439 L p .707 .577 .707 r
F P
0 g
s
.49248 .63029 m .48712 .66823 L .49335 .67185 L p .707 .577 .707 r
F P
0 g
s
.29945 .52053 m .2946 .57792 L .29777 .58008 L p .707 .577 .707 r
F P
0 g
s
.7394 .70439 m .74476 .66644 L .7758 .67024 L p .707 .577 .707 r
F P
0 g
s
.74476 .66644 m .7394 .70439 L .70796 .69966 L p .707 .577 .707 r
F P
0 g
s
.70796 .69966 m .71332 .66171 L .74476 .66644 L p .707 .577 .707 r
F P
0 g
s
.49335 .67185 m .4987 .6339 L .49248 .63029 L p .707 .577 .707 r
F P
0 g
s
.31107 .70845 m .31205 .68944 L .29938 .68459 L p .707 .577 .707 r
F P
0 g
s
.8063 .7147 m .80532 .73371 L .77784 .72999 L p .707 .577 .707 r
F P
0 g
s
.77784 .72999 m .77882 .71098 L .8063 .7147 L p .707 .577 .707 r
F P
0 g
s
.29938 .68459 m .2984 .7036 L .31107 .70845 L p .707 .577 .707 r
F P
0 g
s
.29652 .6063 m .29116 .64425 L .29483 .64198 L p .707 .577 .707 r
F P
0 g
s
.29483 .64198 m .30019 .60404 L .29652 .6063 L p .707 .577 .707 r
F P
0 g
s
.6856 .7266 m .68658 .70759 L .71588 .70724 L p .707 .577 .707 r
F P
0 g
s
.71588 .70724 m .7149 .72625 L .6856 .7266 L p .707 .577 .707 r
F P
0 g
s
.50274 .53833 m .49789 .59573 L .49472 .59358 L p .707 .577 .707 r
F P
0 g
s
.49472 .59358 m .49957 .53618 L .50274 .53833 L p .707 .577 .707 r
F P
0 g
s
.77882 .71098 m .77784 .72999 L .74669 .72742 L p .707 .577 .707 r
F P
0 g
s
.74669 .72742 m .74767 .70841 L .77882 .71098 L p .707 .577 .707 r
F P
0 g
s
.49309 .6961 m .49211 .71511 L .49908 .71098 L p .707 .577 .707 r
F P
0 g
s
.49908 .71098 m .50006 .69197 L .49309 .6961 L p .707 .577 .707 r
F P
0 g
s
.7149 .72625 m .71588 .70724 L .74767 .70841 L p .707 .577 .707 r
F P
0 g
s
.74767 .70841 m .74669 .72742 L .7149 .72625 L p .707 .577 .707 r
F P
0 g
s
.2946 .57792 m .29945 .52053 L .30623 .51925 L p .707 .577 .707 r
F P
0 g
s
.4987 .6339 m .49335 .67185 L .48968 .67412 L p .707 .577 .707 r
F P
0 g
s
.30623 .51925 m .30138 .57664 L .2946 .57792 L p .707 .577 .707 r
F P
0 g
s
.2984 .7036 m .29938 .68459 L .29638 .67987 L p .707 .577 .707 r
F P
0 g
s
.48968 .67412 m .49503 .63617 L .4987 .6339 L p .707 .577 .707 r
F P
0 g
s
.29638 .67987 m .2954 .69888 L .2984 .7036 L p .707 .577 .707 r
F P
0 g
s
.30274 .60992 m .29739 .64787 L .29116 .64425 L p .707 .577 .707 r
F P
0 g
s
.29116 .64425 m .29652 .6063 L .30274 .60992 L p .707 .577 .707 r
F P
0 g
s
.49957 .53618 m .49472 .59358 L .48191 .59076 L p .707 .577 .707 r
F P
0 g
s
.48191 .59076 m .48676 .53337 L .49957 .53618 L p .707 .577 .707 r
F P
0 g
s
.50006 .69197 m .49908 .71098 L .49609 .70626 L p .707 .577 .707 r
F P
0 g
s
.49609 .70626 m .49706 .68725 L .50006 .69197 L p .707 .577 .707 r
F P
0 g
s
.30138 .57664 m .30623 .51925 L .32229 .51897 L p .707 .577 .707 r
F P
0 g
s
.49503 .63617 m .48968 .67412 L .47647 .67481 L p .707 .577 .707 r
F P
0 g
s
.32229 .51897 m .31745 .57636 L .30138 .57664 L p .707 .577 .707 r
F P
0 g
s
.2954 .69888 m .29638 .67987 L .30335 .67574 L p .707 .577 .707 r
F P
0 g
s
.47647 .67481 m .48183 .63687 L .49503 .63617 L p .707 .577 .707 r
F P
0 g
s
.30335 .67574 m .30238 .69475 L .2954 .69888 L p .707 .577 .707 r
F P
0 g
s
.31826 .61454 m .3129 .65248 L .29739 .64787 L p .707 .577 .707 r
F P
0 g
s
.29739 .64787 m .30274 .60992 L .31826 .61454 L p .707 .577 .707 r
F P
0 g
s
.48676 .53337 m .48191 .59076 L .46072 .58757 L p .707 .577 .707 r
F P
0 g
s
.46072 .58757 m .46556 .53017 L .48676 .53337 L p .707 .577 .707 r
F P
0 g
s
.49706 .68725 m .49609 .70626 L .48341 .7014 L p .707 .577 .707 r
F P
0 g
s
.48341 .7014 m .48439 .68239 L .49706 .68725 L p .707 .577 .707 r
F P
0 g
s
.31745 .57636 m .32229 .51897 L .34607 .51971 L p .707 .577 .707 r
F P
0 g
s
.34607 .51971 m .34123 .5771 L .31745 .57636 L p .707 .577 .707 r
F P
0 g
s
.48183 .63687 m .47647 .67481 L .45502 .67386 L p .707 .577 .707 r
F P
0 g
s
.45502 .67386 m .46038 .63592 L .48183 .63687 L p .707 .577 .707 r
F P
0 g
s
.30238 .69475 m .30335 .67574 L .31961 .6726 L p .707 .577 .707 r
F P
0 g
s
.31961 .6726 m .31864 .69161 L .30238 .69475 L p .707 .577 .707 r
F P
0 g
s
.34154 .6197 m .33618 .65764 L .3129 .65248 L p .707 .577 .707 r
F P
0 g
s
.3129 .65248 m .31826 .61454 L .34154 .6197 L p .707 .577 .707 r
F P
0 g
s
.46556 .53017 m .46072 .58757 L .43321 .5843 L p .707 .577 .707 r
F P
0 g
s
.43321 .5843 m .43806 .5269 L .46556 .53017 L p .707 .577 .707 r
F P
0 g
s
.34123 .5771 m .34607 .51971 L .37524 .5214 L p .707 .577 .707 r
F P
0 g
s
.37524 .5214 m .37039 .57879 L .34123 .5771 L p .707 .577 .707 r
F P
0 g
s
.48439 .68239 m .48341 .7014 L .46231 .69689 L p .707 .577 .707 r
F P
0 g
s
.46231 .69689 m .46328 .67789 L .48439 .68239 L p .707 .577 .707 r
F P
0 g
s
.46038 .63592 m .45502 .67386 L .42743 .67137 L p .707 .577 .707 r
F P
0 g
s
.43806 .5269 m .43321 .5843 L .40209 .58127 L p .707 .577 .707 r
F P
0 g
s
.40209 .58127 m .40693 .52388 L .43806 .5269 L p .707 .577 .707 r
F P
0 g
s
.42743 .67137 m .43279 .63343 L .46038 .63592 L p .707 .577 .707 r
F P
0 g
s
.37031 .6249 m .36495 .66284 L .33618 .65764 L p .707 .577 .707 r
F P
0 g
s
.33618 .65764 m .34154 .6197 L .37031 .6249 L p .707 .577 .707 r
F P
0 g
s
.37039 .57879 m .37524 .5214 L .40693 .52388 L p .707 .577 .707 r
F P
0 g
s
.31864 .69161 m .31961 .6726 L .34357 .67077 L p .707 .577 .707 r
F P
0 g
s
.40693 .52388 m .40209 .58127 L .37039 .57879 L p .707 .577 .707 r
F P
0 g
s
.34357 .67077 m .34259 .68978 L .31864 .69161 L p .707 .577 .707 r
F P
0 g
s
.43279 .63343 m .42743 .67137 L .39639 .66757 L p .707 .577 .707 r
F P
0 g
s
.39639 .66757 m .40175 .62963 L .43279 .63343 L p .707 .577 .707 r
F P
0 g
s
.40175 .62963 m .39639 .66757 L .36495 .66284 L p .707 .577 .707 r
F P
0 g
s
.36495 .66284 m .37031 .6249 L .40175 .62963 L p .707 .577 .707 r
F P
0 g
s
.46328 .67789 m .46231 .69689 L .43483 .69317 L p .707 .577 .707 r
F P
0 g
s
.43483 .69317 m .43581 .67416 L .46328 .67789 L p .707 .577 .707 r
F P
0 g
s
.34259 .68978 m .34357 .67077 L .37287 .67042 L p .707 .577 .707 r
F P
0 g
s
.37287 .67042 m .37189 .68943 L .34259 .68978 L p .707 .577 .707 r
F P
0 g
s
.43581 .67416 m .43483 .69317 L .40368 .6906 L p .707 .577 .707 r
F P
0 g
s
.40368 .6906 m .40465 .67159 L .43581 .67416 L p .707 .577 .707 r
F P
0 g
s
.37189 .68943 m .37287 .67042 L .40465 .67159 L p .707 .577 .707 r
F P
0 g
s
.40465 .67159 m .40368 .6906 L .37189 .68943 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool<0028Ool0081oo`T0
00IJEP03001JEUYF00=JEP`007aoo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MGoo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000Lgoo001bOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LGoo001^Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001_Ool006aoo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eo
o`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0`00Jgoo001YOol01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001WOol20003
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0IWoo001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001GOol?0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<0
00=JEP03001JEUYF00AJEP04001JEUYFFUH:0009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK001<Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90013Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPP003]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Eo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Goo001C
Ool00`00FUH00002FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo
001COol60005FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001KOol70004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001ROol80004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo001VOol00`00FUIJEP090005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP0L0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP8002aoo`00EGoo3P000goo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo0P000eYF
00<005YFFUH00eYF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo100000=JEP00FUH015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
E7oo00@005YF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0140
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`04001JEUYF0003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH015YF4P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF
1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH02eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
;Woo4@0057oo00<005YF00000eYF00<005YFFUH01EYF00@005YFFUIJEPL000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH70003FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH01000
FUIJEUYF4P000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000
25YF00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P002Woo4P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@00
0UYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH700000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000LOol80004FUH00`00FUIJEP04FUH0
1000FUIJEUYF1000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH>0002FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0097oo4P00;Woo000^Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00I7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH03`00FGoo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00@005YFFUIJEPT0051oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYF001JEP040005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90017Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EPD000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH0009JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003mo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03
001JEUYF00IJEP04001JEUYFFUH6000iOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000@000AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEP0000<000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH700000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000bOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000015YF001JEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0001h000AJEP03001JEUYF00=JEP04001J
EUYFFUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00
FUH01UYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF5P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH@000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF001JEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00;7oo00<005YF00003`0015YF00<005YFFUH01UYF00<005YFFUH01UYF0`00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`<0009JEP03001JEUYF00=J
EP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002moo`D000=JEP03001JEUYF00EJEP03001JEUYF00EJEPl000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool>0003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEQl000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80003FUH00`00FUIJEP06FUH01@00FUIJEP00FUH010000UYF2@0000IJEP00000005YF
0006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool400000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH00eYF00@0
05YFFUIJEPT000EJEP03001JEUYF00MJEP8000=JEPL000=JEP04001JEUYFFUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=J
EPP000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02eoo`04001JEP00FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0002FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP04
001JEUYFFUH20002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000/Ool01000FUIJEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF009JEP8000Ioo`H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000<000QJEP03001JEUYF00IJ
EP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0004FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF9@0015YF00<005YFFUH00eYF00@005YFFUIJEP80
02moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YF00001P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF5000<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUH000080004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05
FUH01000FUIJEUYF0P0000Aoo`00FUIJER0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002]oo`04001JEUYF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF40000UYF
00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000017ooFUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03
001JEUYF00IJEP8000QJEPX000aJEPT000QJEP03001JEUYF00EJEP05001JEP00FUH00002FUH:0003
FUH2000@Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00H000UJEP03
001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP04001JEP00FUH40005FUH01000
FUIJEUYF20005Goo1P000eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800004OomJEUYF0006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00EJEP04001JEUYFFUHO0003FUH2000]Ool0031oo`D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002Ool2FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF
008002eoo`00<Woo7P000eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009oo`9J
EP03001JEUYF00AJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<00003FUH005YF009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002moo`<0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000Woo0UYF00<005YFFUH015YF0P000UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00@005YF000000EJEP03001J
EP0000800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF009JEP80009o
o`9JEP03001JEUYF009JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00QJEP05001JEUYFFUH00003FUH2000015YF001JEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000002Ool2FUH00`00FUIJEP020006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH2000015YF000000001eYF4`0015YF00<005YFFUH01EYF00@005YFFUIJEPH0039o
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000Woo0UYF0`002EYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@001eYF00<0
05YFFUH00UYF0P0037oo4000>7oo000]Ool20004FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000AooeYFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP00010005Aoo`00;7oo00<005YF00000UYF1P0047oo4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEP000003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH000030004FUH5
000MOol60004FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF
00=JEP04001JEUYFFUHB000@Ool400000eYF001JEP02FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD00003FUH0000000h000=JEP@0009JEP04001o
o`000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@0
05YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1@00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003Ool0000000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0031o
o`@000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP08001JEUYFFUH005YF001oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol003Aoo`L000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH20003Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH60002FUH01000FUIJEUYF0P00EGoo000kOol90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF200017oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000P000UYF0P00EWoo0014OolI000<Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`001eYF00<005YFFUH00UYF1000EWoo001ZOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00001EOol006]o
o`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008005Ao
o`00KGoo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF0P0000=oo`0000001P000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
KWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH00eYF0`002goo1P000eYF00@005YFFUIJEP8005Aoo`00L7oo0P0015YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00005P0000=JEP0000000`00
0UYF0P00E7oo001bOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04001D
Ool007Eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000EJEPD000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00O7oo30001UYF00<005YFFUH0
15YF2@000UYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000E7oo0028Ool=0007Ool90004FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP04001EOol00:Eoo`T000AJEP03001JEUYF009JEPd005Uoo`00[Woo2@00IWoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59622 .73385 m .60106 .67646 L .56994 .67343 L p .707 .577 .707 r
F P
0 g
s
.60106 .67646 m .59622 .73385 L .62791 .73633 L p .707 .577 .707 r
F P
0 g
s
.62791 .73633 m .63276 .67894 L .60106 .67646 L p .707 .577 .707 r
F P
0 g
s
.63276 .67894 m .62791 .73633 L .65708 .73802 L p .707 .577 .707 r
F P
0 g
s
.65708 .73802 m .66192 .68063 L .63276 .67894 L p .707 .577 .707 r
F P
0 g
s
.56994 .67343 m .56509 .73083 L .59622 .73385 L p .707 .577 .707 r
F P
0 g
s
.56509 .73083 m .56994 .67343 L .54243 .67016 L p .707 .577 .707 r
F P
0 g
s
.56824 .73063 m .56288 .76857 L .59392 .77237 L p .707 .577 .707 r
F P
0 g
s
.59392 .77237 m .59928 .73443 L .56824 .73063 L p .707 .577 .707 r
F P
0 g
s
.59928 .73443 m .59392 .77237 L .62536 .7771 L p .707 .577 .707 r
F P
0 g
s
.54243 .67016 m .53759 .72756 L .56509 .73083 L p .707 .577 .707 r
F P
0 g
s
.62536 .7771 m .63072 .73916 L .59928 .73443 L p .707 .577 .707 r
F P
0 g
s
.63072 .73916 m .62536 .7771 L .65413 .7823 L p .707 .577 .707 r
F P
0 g
s
.65413 .7823 m .65949 .74436 L .63072 .73916 L p .707 .577 .707 r
F P
0 g
s
.54065 .72814 m .53529 .76608 L .56288 .76857 L p .707 .577 .707 r
F P
0 g
s
.56288 .76857 m .56824 .73063 L .54065 .72814 L p .707 .577 .707 r
F P
0 g
s
.66192 .68063 m .65708 .73802 L .68085 .73876 L p .707 .577 .707 r
F P
0 g
s
.68085 .73876 m .6857 .68137 L .66192 .68063 L p .707 .577 .707 r
F P
0 g
s
.53759 .72756 m .54243 .67016 L .52124 .66697 L p .707 .577 .707 r
F P
0 g
s
.65949 .74436 m .65413 .7823 L .67741 .78746 L p .707 .577 .707 r
F P
0 g
s
.52124 .66697 m .51639 .72436 L .53759 .72756 L p .707 .577 .707 r
F P
0 g
s
.67741 .78746 m .68277 .74952 L .65949 .74436 L p .707 .577 .707 r
F P
0 g
s
.59661 .82885 m .59759 .80984 L .56644 .80727 L p .707 .577 .707 r
F P
0 g
s
.59759 .80984 m .59661 .82885 L .6284 .83002 L p .707 .577 .707 r
F P
0 g
s
.6284 .83002 m .62938 .81101 L .59759 .80984 L p .707 .577 .707 r
F P
0 g
s
.5192 .72719 m .51384 .76513 L .53529 .76608 L p .707 .577 .707 r
F P
0 g
s
.53529 .76608 m .54065 .72814 L .5192 .72719 L p .707 .577 .707 r
F P
0 g
s
.56644 .80727 m .56546 .82628 L .59661 .82885 L p .707 .577 .707 r
F P
0 g
s
.62938 .81101 m .6284 .83002 L .6577 .82967 L p .707 .577 .707 r
F P
0 g
s
.6577 .82967 m .65868 .81066 L .62938 .81101 L p .707 .577 .707 r
F P
0 g
s
.56546 .82628 m .56644 .80727 L .53896 .80355 L p .707 .577 .707 r
F P
0 g
s
.53896 .80355 m .53798 .82255 L .56546 .82628 L p .707 .577 .707 r
F P
0 g
s
.6857 .68137 m .68085 .73876 L .69692 .73848 L p .707 .577 .707 r
F P
0 g
s
.69692 .73848 m .70177 .68109 L .6857 .68137 L p .707 .577 .707 r
F P
0 g
s
.65868 .81066 m .6577 .82967 L .68166 .82784 L p .707 .577 .707 r
F P
0 g
s
.68166 .82784 m .68263 .80883 L .65868 .81066 L p .707 .577 .707 r
F P
0 g
s
.68277 .74952 m .67741 .78746 L .69292 .79208 L p .707 .577 .707 r
F P
0 g
s
.51639 .72436 m .52124 .66697 L .50843 .66415 L p .707 .577 .707 r
F P
0 g
s
.69292 .79208 m .69828 .75413 L .68277 .74952 L p .707 .577 .707 r
F P
0 g
s
.50843 .66415 m .50358 .72155 L .51639 .72436 L p .707 .577 .707 r
F P
0 g
s
.53798 .82255 m .53896 .80355 L .51785 .79904 L p .707 .577 .707 r
F P
0 g
s
.51785 .79904 m .51688 .81805 L .53798 .82255 L p .707 .577 .707 r
F P
0 g
s
.50599 .72788 m .50063 .76583 L .51384 .76513 L p .707 .577 .707 r
F P
0 g
s
.51384 .76513 m .5192 .72719 L .50599 .72788 L p .707 .577 .707 r
F P
0 g
s
.68263 .80883 m .68166 .82784 L .69791 .8247 L p .707 .577 .707 r
F P
0 g
s
.69791 .8247 m .69889 .8057 L .68263 .80883 L p .707 .577 .707 r
F P
0 g
s
.70177 .68109 m .69692 .73848 L .7037 .7372 L p .707 .577 .707 r
F P
0 g
s
.7037 .7372 m .70855 .67981 L .70177 .68109 L p .707 .577 .707 r
F P
0 g
s
.69828 .75413 m .69292 .79208 L .69915 .7957 L p .707 .577 .707 r
F P
0 g
s
.51688 .81805 m .51785 .79904 L .50518 .79419 L p .707 .577 .707 r
F P
0 g
s
.50358 .72155 m .50843 .66415 L .50526 .662 L p .707 .577 .707 r
F P
0 g
s
.69915 .7957 m .70451 .75775 L .69828 .75413 L p .707 .577 .707 r
F P
0 g
s
.50518 .79419 m .50421 .81319 L .51688 .81805 L p .707 .577 .707 r
F P
0 g
s
.50526 .662 m .50041 .71939 L .50358 .72155 L p .707 .577 .707 r
F P
0 g
s
.50232 .73015 m .49697 .7681 L .50063 .76583 L p .707 .577 .707 r
F P
0 g
s
.50063 .76583 m .50599 .72788 L .50232 .73015 L p .707 .577 .707 r
F P
0 g
s
.50855 .73377 m .50319 .77171 L .49697 .7681 L p .707 .577 .707 r
F P
0 g
s
.49697 .7681 m .50232 .73015 L .50855 .73377 L p .707 .577 .707 r
F P
0 g
s
.50041 .82496 m .48485 .33515 L .44085 .333 L p .707 .577 .707 r
F P
0 g
s
.50421 .81319 m .50518 .79419 L .50219 .78946 L p .707 .577 .707 r
F P
0 g
s
.50219 .78946 m .50121 .80847 L .50421 .81319 L p .707 .577 .707 r
F P
0 g
s
.50041 .71939 m .50526 .662 L .51204 .66072 L p .707 .577 .707 r
F P
0 g
s
.51204 .66072 m .50719 .71811 L .50041 .71939 L p .707 .577 .707 r
F P
0 g
s
.50121 .80847 m .50219 .78946 L .50916 .78533 L p .707 .577 .707 r
F P
0 g
s
.50916 .78533 m .50818 .80434 L .50121 .80847 L p .707 .577 .707 r
F P
0 g
s
.50719 .71811 m .51204 .66072 L .5281 .66044 L p .707 .577 .707 r
F P
0 g
s
.5281 .66044 m .52325 .71783 L .50719 .71811 L p .707 .577 .707 r
F P
0 g
s
.52406 .73838 m .51871 .77633 L .50319 .77171 L p .707 .577 .707 r
F P
0 g
s
.50319 .77171 m .50855 .73377 L .52406 .73838 L p .707 .577 .707 r
F P
0 g
s
.50818 .80434 m .50916 .78533 L .52542 .7822 L p .707 .577 .707 r
F P
0 g
s
.52325 .71783 m .5281 .66044 L .55188 .66118 L p .707 .577 .707 r
F P
0 g
s
.52542 .7822 m .52444 .80121 L .50818 .80434 L p .707 .577 .707 r
F P
0 g
s
.55188 .66118 m .54703 .71857 L .52325 .71783 L p .707 .577 .707 r
F P
0 g
s
.54734 .74354 m .54199 .78149 L .51871 .77633 L p .707 .577 .707 r
F P
0 g
s
.51871 .77633 m .52406 .73838 L .54734 .74354 L p .707 .577 .707 r
F P
0 g
s
.57611 .74874 m .57076 .78669 L .54199 .78149 L p .707 .577 .707 r
F P
0 g
s
.54199 .78149 m .54734 .74354 L .57611 .74874 L p .707 .577 .707 r
F P
0 g
s
.52444 .80121 m .52542 .7822 L .54937 .78037 L p .707 .577 .707 r
F P
0 g
s
.54937 .78037 m .5484 .79938 L .52444 .80121 L p .707 .577 .707 r
F P
0 g
s
.48485 .33515 m .50041 .82496 L .54533 .8223 L p .707 .577 .707 r
F P
0 g
s
.54533 .8223 m .52976 .33248 L .48485 .33515 L p .707 .577 .707 r
F P
0 g
s
.54703 .71857 m .55188 .66118 L .58104 .66287 L p .707 .577 .707 r
F P
0 g
s
.58104 .66287 m .5762 .72026 L .54703 .71857 L p .707 .577 .707 r
F P
0 g
s
.60756 .75347 m .6022 .79142 L .57076 .78669 L p .707 .577 .707 r
F P
0 g
s
.57076 .78669 m .57611 .74874 L .60756 .75347 L p .707 .577 .707 r
F P
0 g
s
.5484 .79938 m .54937 .78037 L .57868 .78002 L p .707 .577 .707 r
F P
0 g
s
.57868 .78002 m .5777 .79903 L .5484 .79938 L p .707 .577 .707 r
F P
0 g
s
.6022 .79142 m .60756 .75347 L .63859 .75727 L p .707 .577 .707 r
F P
0 g
s
.5777 .79903 m .57868 .78002 L .61046 .78119 L p .707 .577 .707 r
F P
0 g
s
.63859 .75727 m .63323 .79522 L .6022 .79142 L p .707 .577 .707 r
F P
0 g
s
.61046 .78119 m .60948 .8002 L .5777 .79903 L p .707 .577 .707 r
F P
0 g
s
.52976 .33248 m .54533 .8223 L .58677 .81508 L p .707 .577 .707 r
F P
0 g
s
.5762 .72026 m .58104 .66287 L .61274 .66535 L p .707 .577 .707 r
F P
0 g
s
.61274 .66535 m .60789 .72274 L .5762 .72026 L p .707 .577 .707 r
F P
0 g
s
.58677 .81508 m .57121 .32526 L .52976 .33248 L p .707 .577 .707 r
F P
0 g
s
.69889 .8057 m .69791 .8247 L .70489 .82057 L p .707 .577 .707 r
F P
0 g
s
.70489 .82057 m .70586 .80157 L .69889 .8057 L p .707 .577 .707 r
F P
0 g
s
.45641 .82282 m .44085 .333 L .40207 .32626 L p .707 .577 .707 r
F P
0 g
s
.44085 .333 m .45641 .82282 L .50041 .82496 L p .707 .577 .707 r
F P
0 g
s
.70855 .67981 m .7037 .7372 L .70053 .73505 L p .707 .577 .707 r
F P
0 g
s
.70053 .73505 m .70538 .67765 L .70855 .67981 L p .707 .577 .707 r
F P
0 g
s
.64386 .66837 m .63902 .72577 L .61613 .72354 L p .707 .577 .707 r
F P
0 g
s
.61613 .72354 m .60789 .72274 L p .61666 .70949 L .707 .577 .707 r
F P
0 g
s
.61666 .70949 m .64386 .66837 L .61613 .72354 L .707 .577 .707 r
F
.67137 .67164 m .66652 .72904 L .63902 .72577 L p F P
0 g
s
.63902 .72577 m .64386 .66837 L .67137 .67164 L p .707 .577 .707 r
F P
0 g
s
.66619 .75977 m .66083 .79771 L .63323 .79522 L p .707 .577 .707 r
F P
0 g
s
.63323 .79522 m .63859 .75727 L .66619 .75977 L p .707 .577 .707 r
F P
0 g
s
.60789 .72274 m .61274 .66535 L .64386 .66837 L p .707 .577 .707 r
F P
0 g
s
.68763 .76071 m .68228 .79866 L .66083 .79771 L p .707 .577 .707 r
F P
0 g
s
.66083 .79771 m .66619 .75977 L .68763 .76071 L p .707 .577 .707 r
F P
0 g
s
.64064 .80277 m .64162 .78376 L .66909 .78748 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .65368 .77497 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62817 .30038 m .62996 .35672 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.62996 .35672 m .64374 .7902 L p .63047 .34319 L .707 .577 .707 r
F P
0 g
s
.64162 .78376 m .64064 .80277 L .60948 .8002 L p .707 .577 .707 r
F P
0 g
s
.60948 .8002 m .61046 .78119 L .64162 .78376 L p .707 .577 .707 r
F P
0 g
s
.57121 .32526 m .58677 .81508 L .62068 .80402 L p .707 .577 .707 r
F P
0 g
s
.62068 .80402 m .60512 .3142 L .57121 .32526 L p .707 .577 .707 r
F P
0 g
s
.70451 .75775 m .69915 .7957 L .69548 .79796 L p .707 .577 .707 r
F P
0 g
s
.69548 .79796 m .70084 .76002 L .70451 .75775 L p .707 .577 .707 r
F P
0 g
s
.41764 .81608 m .40207 .32626 L .37232 .31558 L p .707 .577 .707 r
F P
0 g
s
.40207 .32626 m .41764 .81608 L .45641 .82282 L p .707 .577 .707 r
F P
0 g
s
.70586 .80157 m .70489 .82057 L .70189 .81585 L p .707 .577 .707 r
F P
0 g
s
.70189 .81585 m .70287 .79684 L .70586 .80157 L p .707 .577 .707 r
F P
0 g
s
.70538 .67765 m .70053 .73505 L .68772 .73223 L p .707 .577 .707 r
F P
0 g
s
.68772 .73223 m .69257 .67484 L .70538 .67765 L p .707 .577 .707 r
F P
0 g
s
.60512 .3142 m .62068 .80402 L .64374 .7902 L p .707 .577 .707 r
F P
0 g
s
.64374 .7902 m .62817 .30038 L .60512 .3142 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25321 .69703 m .25805 .63964 L .22693 .63662 L p .707 .577 .707 r
F P
0 g
s
.25805 .63964 m .25321 .69703 L .2849 .69951 L p .707 .577 .707 r
F P
0 g
s
.2849 .69951 m .28975 .64212 L .25805 .63964 L p .707 .577 .707 r
F P
0 g
s
.28975 .64212 m .2849 .69951 L .31407 .70121 L p .707 .577 .707 r
F P
0 g
s
.31407 .70121 m .31891 .64381 L .28975 .64212 L p .707 .577 .707 r
F P
0 g
s
.22693 .63662 m .22208 .69401 L .25321 .69703 L p .707 .577 .707 r
F P
0 g
s
.70084 .76002 m .69548 .79796 L .68228 .79866 L p .707 .577 .707 r
F P
0 g
s
.22208 .69401 m .22693 .63662 L .19942 .63335 L p .707 .577 .707 r
F P
0 g
s
.68228 .79866 m .68763 .76071 L .70084 .76002 L p .707 .577 .707 r
F P
0 g
s
.22523 .69382 m .21987 .73176 L .25091 .73556 L p .707 .577 .707 r
F P
0 g
s
.25091 .73556 m .25627 .69761 L .22523 .69382 L p .707 .577 .707 r
F P
0 g
s
.25627 .69761 m .25091 .73556 L .28235 .74029 L p .707 .577 .707 r
F P
0 g
s
.19942 .63335 m .19458 .69074 L .22208 .69401 L p .707 .577 .707 r
F P
0 g
s
.28235 .74029 m .28771 .70234 L .25627 .69761 L p .707 .577 .707 r
F P
0 g
s
.28771 .70234 m .28235 .74029 L .31112 .74549 L p .707 .577 .707 r
F P
0 g
s
.31112 .74549 m .31648 .70754 L .28771 .70234 L p .707 .577 .707 r
F P
0 g
s
.19764 .69132 m .19228 .72927 L .21987 .73176 L p .707 .577 .707 r
F P
0 g
s
.21987 .73176 m .22523 .69382 L .19764 .69132 L p .707 .577 .707 r
F P
0 g
s
.38789 .8054 m .37232 .31558 L .35451 .302 L p .707 .577 .707 r
F P
0 g
s
.37232 .31558 m .38789 .8054 L .41764 .81608 L p .707 .577 .707 r
F P
0 g
s
.31891 .64381 m .31407 .70121 L .33785 .70195 L p .707 .577 .707 r
F P
0 g
s
.33785 .70195 m .34269 .64455 L .31891 .64381 L p .707 .577 .707 r
F P
0 g
s
.19458 .69074 m .19942 .63335 L .17823 .63015 L p .707 .577 .707 r
F P
0 g
s
.70287 .79684 m .70189 .81585 L .68922 .811 L p .707 .577 .707 r
F P
0 g
s
.68922 .811 m .6902 .79199 L .70287 .79684 L p .707 .577 .707 r
F P
0 g
s
.31648 .70754 m .31112 .74549 L .3344 .75065 L p .707 .577 .707 r
F P
0 g
s
.69257 .67484 m .68772 .73223 L .66652 .72904 L p .707 .577 .707 r
F P
0 g
s
.66652 .72904 m .67137 .67164 L .69257 .67484 L p .707 .577 .707 r
F P
0 g
s
.17823 .63015 m .17338 .68754 L .19458 .69074 L p .707 .577 .707 r
F P
0 g
s
.3344 .75065 m .33976 .7127 L .31648 .70754 L p .707 .577 .707 r
F P
0 g
s
.2536 .79203 m .25458 .77302 L .22343 .77045 L p .707 .577 .707 r
F P
0 g
s
.25458 .77302 m .2536 .79203 L .28539 .7932 L p .707 .577 .707 r
F P
0 g
s
.28539 .7932 m .28637 .77419 L .25458 .77302 L p .707 .577 .707 r
F P
0 g
s
.17619 .69037 m .17083 .72832 L .19228 .72927 L p .707 .577 .707 r
F P
0 g
s
.19228 .72927 m .19764 .69132 L .17619 .69037 L p .707 .577 .707 r
F P
0 g
s
.22343 .77045 m .22245 .78946 L .2536 .79203 L p .707 .577 .707 r
F P
0 g
s
.28637 .77419 m .28539 .7932 L .31469 .79285 L p .707 .577 .707 r
F P
0 g
s
.31469 .79285 m .31567 .77384 L .28637 .77419 L p .707 .577 .707 r
F P
0 g
s
.65368 .77497 m .63812 .28515 L .62817 .30038 L p .707 .577 .707 r
F P
0 g
s
.22245 .78946 m .22343 .77045 L .19595 .76673 L p .707 .577 .707 r
F P
0 g
s
.19595 .76673 m .19497 .78574 L .22245 .78946 L p .707 .577 .707 r
F P
0 g
s
.34269 .64455 m .33785 .70195 L .35391 .70166 L p .707 .577 .707 r
F P
0 g
s
.35391 .70166 m .35876 .64427 L .34269 .64455 L p .707 .577 .707 r
F P
0 g
s
.31567 .77384 m .31469 .79285 L .33865 .79102 L p .707 .577 .707 r
F P
0 g
s
.33865 .79102 m .33962 .77201 L .31567 .77384 L p .707 .577 .707 r
F P
0 g
s
.33976 .7127 m .3344 .75065 L .34991 .75526 L p .707 .577 .707 r
F P
0 g
s
.17338 .68754 m .17823 .63015 L .16542 .62734 L p .707 .577 .707 r
F P
0 g
s
.34991 .75526 m .35527 .71732 L .33976 .7127 L p .707 .577 .707 r
F P
0 g
s
.16542 .62734 m .16057 .68473 L .17338 .68754 L p .707 .577 .707 r
F P
0 g
s
.19497 .78574 m .19595 .76673 L .17484 .76222 L p .707 .577 .707 r
F P
0 g
s
.6902 .79199 m .68922 .811 L .66811 .80649 L p .707 .577 .707 r
F P
0 g
s
.66811 .80649 m .66909 .78748 L .6902 .79199 L p .707 .577 .707 r
F P
0 g
s
.17484 .76222 m .17387 .78123 L .19497 .78574 L p .707 .577 .707 r
F P
0 g
s
.36069 .70038 m .36554 .64299 L .35876 .64427 L p .707 .577 .707 r
F P
0 g
s
.35876 .64427 m .35391 .70166 L .36069 .70038 L p .707 .577 .707 r
F P
0 g
s
.36554 .64299 m .36069 .70038 L .35752 .69823 L p .707 .577 .707 r
F P
0 g
s
.35752 .69823 m .36237 .64084 L .36554 .64299 L p .707 .577 .707 r
F P
0 g
s
.37007 .79182 m .35451 .302 L .35037 .28686 L p .707 .577 .707 r
F P
0 g
s
.35451 .302 m .37007 .79182 L .38789 .8054 L p .707 .577 .707 r
F P
0 g
s
.16298 .69107 m .15762 .72901 L .17083 .72832 L p .707 .577 .707 r
F P
0 g
s
.17083 .72832 m .17619 .69037 L .16298 .69107 L p .707 .577 .707 r
F P
0 g
s
.33962 .77201 m .33865 .79102 L .35491 .78789 L p .707 .577 .707 r
F P
0 g
s
.35491 .78789 m .35588 .76888 L .33962 .77201 L p .707 .577 .707 r
F P
0 g
s
.35527 .71732 m .34991 .75526 L .35614 .75888 L p .707 .577 .707 r
F P
0 g
s
.17387 .78123 m .17484 .76222 L .16217 .75737 L p .707 .577 .707 r
F P
0 g
s
.66909 .78748 m .66811 .80649 L .64064 .80277 L p .707 .577 .707 r
F P
0 g
s
.16057 .68473 m .16542 .62734 L .16225 .62519 L p .707 .577 .707 r
F P
0 g
s
.63812 .28515 m .65205 .72358 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .63812 .28515 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.63784 .6788 m .6472 .67831 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.63398 .27001 m .64591 .64553 L p .63209 .66964 L .707 .577 .707 r
F P
0 g
s
.64591 .64553 m .64685 .67507 L p .63878 .6721 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .64591 .64553 L .63878 .6721 L .707 .577 .707 r
F
.64955 .75983 m .63173 .74625 L p .63209 .66964 L F P
0 g
s
.63682 .67943 m .63784 .6788 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63878 .6721 m .63784 .6788 L p .64685 .67507 L .707 .577 .707 r
F P
0 g
s
.64685 .67507 m .64955 .75983 L p .63517 .68556 L .707 .577 .707 r
F P
0 g
s
.63209 .66964 m .63878 .6721 L .63517 .68556 L .707 .577 .707 r
F
.63784 .6788 m .63878 .6721 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .64685 .67507 L .63517 .68556 L .707 .577 .707 r
F
.6432 .64085 m .63953 .64312 L p .63802 .67495 L F P
0 g
s
.63878 .6721 m .6432 .64085 L p .63802 .67495 L .707 .577 .707 r
F P
0 g
s
.63953 .64312 m .63417 .68106 L .63682 .67943 L p .707 .577 .707 r
F P
0 g
s
.63802 .67495 m .63953 .64312 L .63682 .67943 L .707 .577 .707 r
F
.64316 .6411 m .63878 .6721 L p .64685 .67507 L F P
0 g
s
.64936 .75218 m .64685 .67507 L .64769 .68279 L .707 .577 .707 r
F
.64925 .75062 m .64685 .67507 L p .64936 .75218 L F P
0 g
s
.65368 .77497 m .65001 .76153 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.65001 .76153 m .64955 .75983 L p .64936 .75218 L .707 .577 .707 r
F P
0 g
s
.64936 .75218 m .64731 .66703 L .65001 .76153 L .707 .577 .707 r
F
.64239 .72141 m .64141 .74041 L .64874 .74322 L p F P
0 g
s
.65205 .72358 m .65368 .77497 L p .64731 .66703 L .707 .577 .707 r
F P
0 g
s
.64874 .74322 m .65408 .74527 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.64802 .73291 m .64239 .72141 L .64874 .74322 L .707 .577 .707 r
F
.65408 .74527 m .65506 .72626 L .64736 .72331 L p F P
0 g
s
.64736 .72331 m .64239 .72141 L p .64802 .73291 L .707 .577 .707 r
F P
0 g
s
.65408 .74527 m .64736 .72331 L .64802 .73291 L .707 .577 .707 r
F
.64955 .75983 m .64925 .75062 L p .64936 .75218 L F P
0 g
s
.64685 .67507 m .63398 .27001 L p .64769 .68279 L .707 .577 .707 r
F P
0 g
s
.6432 .64085 m .64316 .6411 L p .65104 .6781 L .707 .577 .707 r
F P
0 g
s
.6472 .67831 m .65104 .6781 L p .64316 .6411 L .707 .577 .707 r
F P
0 g
s
.64563 .5595 m .64195 .60306 L p .65359 .6197 L .707 .577 .707 r
F P
0 g
s
.64195 .60306 m .64078 .61689 L .64315 .61741 L p .707 .577 .707 r
F P
0 g
s
.64315 .61741 m .65359 .6197 L p .64195 .60306 L .707 .577 .707 r
F P
0 g
s
.35614 .75888 m .3615 .72094 L .35527 .71732 L p .707 .577 .707 r
F P
0 g
s
.16217 .75737 m .1612 .77638 L .17387 .78123 L p .707 .577 .707 r
F P
0 g
s
.16225 .62519 m .1574 .68258 L .16057 .68473 L p .707 .577 .707 r
F P
0 g
s
.15931 .69334 m .15396 .73128 L .15762 .72901 L p .707 .577 .707 r
F P
0 g
s
.15762 .72901 m .16298 .69107 L .15931 .69334 L p .707 .577 .707 r
F P
0 g
s
.35588 .76888 m .35491 .78789 L .36188 .78376 L p .707 .577 .707 r
F P
0 g
s
.36188 .78376 m .36285 .76475 L .35588 .76888 L p .707 .577 .707 r
F P
0 g
s
.36237 .64084 m .35752 .69823 L .34475 .69543 L p .707 .577 .707 r
F P
0 g
s
.34475 .69543 m .34471 .69542 L p .34476 .69527 L .707 .577 .707 r
F P
0 g
s
.34476 .69527 m .36237 .64084 L .34475 .69543 L .707 .577 .707 r
F
.35037 .28686 m .36032 .27163 L p .36144 .3731 L F P
0 g
s
.36452 .64952 m .36594 .77668 L .37007 .79182 L p .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35705 .45799 L p .35037 .28686 L .707 .577 .707 r
F P
0 g
s
.34471 .69542 m .34956 .63803 L .36237 .64084 L p .707 .577 .707 r
F P
0 g
s
.36594 .77668 m .35628 .47282 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.35628 .47282 m .35037 .28686 L p .36144 .3731 L .707 .577 .707 r
F P
0 g
s
.1612 .77638 m .16217 .75737 L .15918 .75265 L p .707 .577 .707 r
F P
0 g
s
.3615 .72094 m .35614 .75888 L .35247 .76115 L p .707 .577 .707 r
F P
0 g
s
.15918 .75265 m .1582 .77166 L .1612 .77638 L p .707 .577 .707 r
F P
0 g
s
.1574 .68258 m .16225 .62519 L .16903 .62391 L p .707 .577 .707 r
F P
0 g
s
.35247 .76115 m .35783 .7232 L .3615 .72094 L p .707 .577 .707 r
F P
0 g
s
.16903 .62391 m .16418 .6813 L .1574 .68258 L p .707 .577 .707 r
F P
0 g
s
.16554 .69695 m .16018 .7349 L .15396 .73128 L p .707 .577 .707 r
F P
0 g
s
.15396 .73128 m .15931 .69334 L .16554 .69695 L p .707 .577 .707 r
F P
0 g
s
.63173 .74625 m .61616 .25643 L .63398 .27001 L p .707 .577 .707 r
F P
0 g
s
.36285 .76475 m .36188 .78376 L .35888 .77904 L p .707 .577 .707 r
F P
0 g
s
.35888 .77904 m .35986 .76003 L .36285 .76475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1582 .77166 m .15918 .75265 L .16615 .74852 L p .707 .577 .707 r
F P
0 g
s
.35783 .7232 m .35247 .76115 L .33927 .76184 L p .707 .577 .707 r
F P
0 g
s
.16615 .74852 m .16517 .76753 L .1582 .77166 L p .707 .577 .707 r
F P
0 g
s
.37588 .76145 m .36032 .27163 L .38337 .25781 L p .707 .577 .707 r
F P
0 g
s
.36032 .27163 m .37588 .76145 L .36594 .77668 L p .707 .577 .707 r
F P
0 g
s
.16418 .6813 m .16903 .62391 L .18509 .62362 L p .707 .577 .707 r
F P
0 g
s
.33927 .76184 m .34463 .7239 L .35783 .7232 L p .707 .577 .707 r
F P
0 g
s
.18509 .62362 m .18024 .68102 L .16418 .6813 L p .707 .577 .707 r
F P
0 g
s
.18105 .70157 m .1757 .73951 L .16018 .7349 L p .707 .577 .707 r
F P
0 g
s
.16018 .7349 m .16554 .69695 L .18105 .70157 L p .707 .577 .707 r
F P
0 g
s
.35986 .76003 m .35888 .77904 L .34621 .77418 L p .707 .577 .707 r
F P
0 g
s
.34621 .77418 m .34719 .75517 L .35986 .76003 L p .707 .577 .707 r
F P
0 g
s
.34956 .63803 m .34471 .69542 L .32351 .69222 L p .707 .577 .707 r
F P
0 g
s
.32351 .69222 m .32836 .63483 L .34956 .63803 L p .707 .577 .707 r
F P
0 g
s
.61616 .25643 m .63173 .74625 L .60198 .73557 L p .707 .577 .707 r
F P
0 g
s
.60198 .73557 m .58641 .24575 L .61616 .25643 L p .707 .577 .707 r
F P
0 g
s
.34463 .7239 m .33927 .76184 L .31782 .7609 L p .707 .577 .707 r
F P
0 g
s
.16517 .76753 m .16615 .74852 L .18241 .74538 L p .707 .577 .707 r
F P
0 g
s
.18024 .68102 m .18509 .62362 L .20887 .62436 L p .707 .577 .707 r
F P
0 g
s
.18241 .74538 m .18143 .76439 L .16517 .76753 L p .707 .577 .707 r
F P
0 g
s
.31782 .7609 m .32318 .72295 L .34463 .7239 L p .707 .577 .707 r
F P
0 g
s
.20887 .62436 m .20402 .68176 L .18024 .68102 L p .707 .577 .707 r
F P
0 g
s
.20433 .70673 m .19898 .74467 L .1757 .73951 L p .707 .577 .707 r
F P
0 g
s
.1757 .73951 m .18105 .70157 L .20433 .70673 L p .707 .577 .707 r
F P
0 g
s
.38337 .25781 m .39791 .71524 L p .37588 .76145 L .707 .577 .707 r
F P
0 g
s
.39894 .74763 m .38337 .25781 L .41728 .24675 L p .707 .577 .707 r
F P
0 g
s
.43285 .73657 m .39894 .74763 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.41728 .24675 m .42946 .63003 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.42946 .63003 m .43015 .65181 L p .40111 .68841 L .707 .577 .707 r
F P
0 g
s
.40111 .68841 m .43015 .65181 L .40174 .68937 L .707 .577 .707 r
F
.42491 .61531 m .41955 .65326 L .42792 .65477 L p F P
0 g
s
.41728 .24675 m .45872 .23953 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.42792 .65477 m .44832 .65846 L p .4447 .65178 L .707 .577 .707 r
F P
0 g
s
.4447 .65178 m .43015 .65181 L .42792 .65477 L .707 .577 .707 r
F
.43285 .73657 m .43015 .65181 L p .43726 .6518 L F P
0 g
s
.43015 .65181 m .41728 .24675 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .43285 .73657 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45872 .23953 m .47182 .6517 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.44927 .65176 m .44832 .65846 L .4548 .65989 L p .707 .577 .707 r
F P
0 g
s
.43726 .6518 m .43811 .63536 L .44927 .65176 L .707 .577 .707 r
F
.43811 .63536 m .45872 .23953 L .44927 .65176 L F
.44832 .65846 m .45368 .62051 L .42491 .61531 L p F P
0 g
s
.47182 .6517 m .47429 .72935 L p .43726 .6518 L .707 .577 .707 r
F P
0 g
s
.45368 .62051 m .44927 .65176 L p .47161 .66362 L .707 .577 .707 r
F P
0 g
s
.4548 .65989 m .47161 .66362 L p .44927 .65176 L .707 .577 .707 r
F P
0 g
s
.43864 .6406 m .42491 .61531 L .42769 .65182 L .707 .577 .707 r
F
.43015 .65181 m .42769 .65182 L .42792 .65477 L F
.43864 .6406 m .42769 .65182 L .43015 .65181 L F
.4447 .65178 m .43864 .6406 L .43015 .65181 L F
.43015 .65181 m .43255 .72736 L p .40174 .68937 L F P
0 g
s
.40174 .68937 m .43255 .72736 L .4306 .73316 L .707 .577 .707 r
F
.42357 .70141 m .42259 .72042 L .43494 .72028 L p F P
0 g
s
.43494 .72028 m .4519 .72007 L p .43808 .71097 L .707 .577 .707 r
F P
0 g
s
.43808 .71097 m .42357 .70141 L .43494 .72028 L .707 .577 .707 r
F
.43255 .72736 m .43285 .73657 L p .4306 .73316 L F P
0 g
s
.42695 .53747 m .42211 .59486 L .44587 .59624 L p .707 .577 .707 r
F P
0 g
s
.44587 .59624 m .45127 .59655 L p .44872 .59037 L .707 .577 .707 r
F P
0 g
s
.44872 .59037 m .42695 .53747 L .44587 .59624 L .707 .577 .707 r
F
.39526 .53499 m .39041 .59238 L .41525 .59432 L p F P
0 g
s
.41525 .59432 m .42211 .59486 L p .41685 .58315 L .707 .577 .707 r
F P
0 g
s
.41685 .58315 m .39526 .53499 L .41525 .59432 L .707 .577 .707 r
F
.39791 .71524 m .39894 .74763 L .39273 .75135 L p F P
0 g
s
.39273 .75135 m .37588 .76145 L p .39791 .71524 L .707 .577 .707 r
F P
0 g
s
.32836 .63483 m .32351 .69222 L .29601 .68895 L p .707 .577 .707 r
F P
0 g
s
.29601 .68895 m .30085 .63156 L .32836 .63483 L p .707 .577 .707 r
F P
0 g
s
.34719 .75517 m .34621 .77418 L .3251 .76967 L p .707 .577 .707 r
F P
0 g
s
.3251 .76967 m .32608 .75067 L .34719 .75517 L p .707 .577 .707 r
F P
0 g
s
.20402 .68176 m .20887 .62436 L .23803 .62606 L p .707 .577 .707 r
F P
0 g
s
.32318 .72295 m .31782 .7609 L .29022 .7584 L p .707 .577 .707 r
F P
0 g
s
.58641 .24575 m .60198 .73557 L .56321 .72882 L p .707 .577 .707 r
F P
0 g
s
.56321 .72882 m .54764 .239 L .58641 .24575 L p .707 .577 .707 r
F P
0 g
s
.23803 .62606 m .23319 .68345 L .20402 .68176 L p .707 .577 .707 r
F P
0 g
s
.29022 .7584 m .29558 .72046 L .32318 .72295 L p .707 .577 .707 r
F P
0 g
s
.2331 .71193 m .22775 .74987 L .19898 .74467 L p .707 .577 .707 r
F P
0 g
s
.19898 .74467 m .20433 .70673 L .2331 .71193 L p .707 .577 .707 r
F P
0 g
s
.18143 .76439 m .18241 .74538 L .20636 .74355 L p .707 .577 .707 r
F P
0 g
s
.73342 .6292 m .73827 .5718 L .70714 .56878 L p .707 .577 .707 r
F P
0 g
s
.73827 .5718 m .73342 .6292 L .76512 .63167 L p .707 .577 .707 r
F P
0 g
s
.76512 .63167 m .76996 .57428 L .73827 .5718 L p .707 .577 .707 r
F P
0 g
s
.20636 .74355 m .20539 .76256 L .18143 .76439 L p .707 .577 .707 r
F P
0 g
s
.30085 .63156 m .29601 .68895 L .26488 .68593 L p .707 .577 .707 r
F P
0 g
s
.26488 .68593 m .26973 .62853 L .30085 .63156 L p .707 .577 .707 r
F P
0 g
s
.76996 .57428 m .76512 .63167 L .79428 .63337 L p .707 .577 .707 r
F P
0 g
s
.79428 .63337 m .79913 .57597 L .76996 .57428 L p .707 .577 .707 r
F P
0 g
s
.70714 .56878 m .7023 .62617 L .73342 .6292 L p .707 .577 .707 r
F P
0 g
s
.23319 .68345 m .23803 .62606 L .26973 .62853 L p .707 .577 .707 r
F P
0 g
s
.7023 .62617 m .70714 .56878 L .67964 .56551 L p .707 .577 .707 r
F P
0 g
s
.26973 .62853 m .26488 .68593 L .23319 .68345 L p .707 .577 .707 r
F P
0 g
s
.67964 .56551 m .67479 .6229 L .7023 .62617 L p .707 .577 .707 r
F P
0 g
s
.29558 .72046 m .29022 .7584 L .25919 .7546 L p .707 .577 .707 r
F P
0 g
s
.32608 .75067 m .3251 .76967 L .29763 .76595 L p .707 .577 .707 r
F P
0 g
s
.29763 .76595 m .29861 .74694 L .32608 .75067 L p .707 .577 .707 r
F P
0 g
s
.70544 .6436 m .70009 .68154 L .73112 .68534 L p .707 .577 .707 r
F P
0 g
s
.73112 .68534 m .73648 .6474 L .70544 .6436 L p .707 .577 .707 r
F P
0 g
s
.73648 .6474 m .73112 .68534 L .76256 .69007 L p .707 .577 .707 r
F P
0 g
s
.25919 .7546 m .26455 .71666 L .29558 .72046 L p .707 .577 .707 r
F P
0 g
s
.26455 .71666 m .25919 .7546 L .22775 .74987 L p .707 .577 .707 r
F P
0 g
s
.22775 .74987 m .2331 .71193 L .26455 .71666 L p .707 .577 .707 r
F P
0 g
s
.79913 .57597 m .79428 .63337 L .81806 .63411 L p .707 .577 .707 r
F P
0 g
s
.81806 .63411 m .82291 .57671 L .79913 .57597 L p .707 .577 .707 r
F P
0 g
s
.76256 .69007 m .76792 .65213 L .73648 .6474 L p .707 .577 .707 r
F P
0 g
s
.76792 .65213 m .76256 .69007 L .79133 .69527 L p .707 .577 .707 r
F P
0 g
s
.54764 .239 m .56321 .72882 L .51921 .72668 L p .707 .577 .707 r
F P
0 g
s
.51921 .72668 m .50364 .23686 L .54764 .239 L p .707 .577 .707 r
F P
0 g
s
.20539 .76256 m .20636 .74355 L .23567 .7432 L p .707 .577 .707 r
F P
0 g
s
.79133 .69527 m .79669 .65733 L .76792 .65213 L p .707 .577 .707 r
F P
0 g
s
.67785 .64111 m .67249 .67905 L .70009 .68154 L p .707 .577 .707 r
F P
0 g
s
.70009 .68154 m .70544 .6436 L .67785 .64111 L p .707 .577 .707 r
F P
0 g
s
.23567 .7432 m .23469 .76221 L .20539 .76256 L p .707 .577 .707 r
F P
0 g
s
.67479 .6229 m .67964 .56551 L .65844 .56231 L p .707 .577 .707 r
F P
0 g
s
.47429 .72935 m .45872 .23953 L .50364 .23686 L p .707 .577 .707 r
F P
0 g
s
.65844 .56231 m .65359 .6197 L .67479 .6229 L p .707 .577 .707 r
F P
0 g
s
.50364 .23686 m .51921 .72668 L .47429 .72935 L p .707 .577 .707 r
F P
0 g
s
.29861 .74694 m .29763 .76595 L .26647 .76338 L p .707 .577 .707 r
F P
0 g
s
.26647 .76338 m .26745 .74437 L .29861 .74694 L p .707 .577 .707 r
F P
0 g
s
.79669 .65733 m .79133 .69527 L .81462 .70043 L p .707 .577 .707 r
F P
0 g
s
.23469 .76221 m .23567 .7432 L .26745 .74437 L p .707 .577 .707 r
F P
0 g
s
.81462 .70043 m .81997 .66249 L .79669 .65733 L p .707 .577 .707 r
F P
0 g
s
.26745 .74437 m .26647 .76338 L .23469 .76221 L p .707 .577 .707 r
F P
0 g
s
.6564 .64016 m .65104 .6781 L .67249 .67905 L p .707 .577 .707 r
F P
0 g
s
.67249 .67905 m .67785 .64111 L .6564 .64016 L p .707 .577 .707 r
F P
0 g
s
.73382 .75607 m .73479 .73706 L .70364 .73449 L p .707 .577 .707 r
F P
0 g
s
.73479 .73706 m .73382 .75607 L .7656 .75724 L p .707 .577 .707 r
F P
0 g
s
.7656 .75724 m .76658 .73823 L .73479 .73706 L p .707 .577 .707 r
F P
0 g
s
.82291 .57671 m .81806 .63411 L .83412 .63382 L p .707 .577 .707 r
F P
0 g
s
.83412 .63382 m .83897 .57643 L .82291 .57671 L p .707 .577 .707 r
F P
0 g
s
.70364 .73449 m .70266 .7535 L .73382 .75607 L p .707 .577 .707 r
F P
0 g
s
.76658 .73823 m .7656 .75724 L .79491 .75689 L p .707 .577 .707 r
F P
0 g
s
.79491 .75689 m .79588 .73788 L .76658 .73823 L p .707 .577 .707 r
F P
0 g
s
.70266 .7535 m .70364 .73449 L .67616 .73077 L p .707 .577 .707 r
F P
0 g
s
.65359 .6197 m .65844 .56231 L .64563 .5595 L p .707 .577 .707 r
F P
0 g
s
.67616 .73077 m .67519 .74978 L .70266 .7535 L p .707 .577 .707 r
F P
0 g
s
.81997 .66249 m .81462 .70043 L .83013 .70505 L p .707 .577 .707 r
F P
0 g
s
.79588 .73788 m .79491 .75689 L .81886 .75506 L p .707 .577 .707 r
F P
0 g
s
.81886 .75506 m .81984 .73605 L .79588 .73788 L p .707 .577 .707 r
F P
0 g
s
.83013 .70505 m .83549 .6671 L .81997 .66249 L p .707 .577 .707 r
F P
0 g
s
.65104 .6781 m .6564 .64016 L .6432 .64085 L p .707 .577 .707 r
F P
0 g
s
.67519 .74978 m .67616 .73077 L .65506 .72626 L p .707 .577 .707 r
F P
0 g
s
.65506 .72626 m .65408 .74527 L .67519 .74978 L p .707 .577 .707 r
F P
0 g
s
.83897 .57643 m .83412 .63382 L .8409 .63254 L p .707 .577 .707 r
F P
0 g
s
.8409 .63254 m .84575 .57515 L .83897 .57643 L p .707 .577 .707 r
F P
0 g
s
.81984 .73605 m .81886 .75506 L .83512 .75192 L p .707 .577 .707 r
F P
0 g
s
.83512 .75192 m .8361 .73292 L .81984 .73605 L p .707 .577 .707 r
F P
0 g
s
.64078 .61689 m .64563 .5595 L .64246 .55735 L p .707 .577 .707 r
F P
0 g
s
.83549 .6671 m .83013 .70505 L .83636 .70866 L p .707 .577 .707 r
F P
0 g
s
.64246 .55735 m .63761 .61474 L .64078 .61689 L p .707 .577 .707 r
F P
0 g
s
.83636 .70866 m .84171 .67072 L .83549 .6671 L p .707 .577 .707 r
F P
0 g
s
.84575 .57515 m .8409 .63254 L .83773 .63039 L p .707 .577 .707 r
F P
0 g
s
.83773 .63039 m .84258 .573 L .84575 .57515 L p .707 .577 .707 r
F P
0 g
s
.8361 .73292 m .83512 .75192 L .84209 .74779 L p .707 .577 .707 r
F P
0 g
s
.84209 .74779 m .84307 .72879 L .8361 .73292 L p .707 .577 .707 r
F P
0 g
s
.63761 .61474 m .64246 .55735 L .64924 .55607 L p .707 .577 .707 r
F P
0 g
s
.84171 .67072 m .83636 .70866 L .83269 .71093 L p .707 .577 .707 r
F P
0 g
s
.64924 .55607 m .64439 .61346 L .63761 .61474 L p .707 .577 .707 r
F P
0 g
s
.64141 .74041 m .64239 .72141 L .63939 .71668 L p .707 .577 .707 r
F P
0 g
s
.83269 .71093 m .83804 .67299 L .84171 .67072 L p .707 .577 .707 r
F P
0 g
s
.63939 .71668 m .63841 .73569 L .64141 .74041 L p .707 .577 .707 r
F P
0 g
s
.64575 .64674 m .6404 .68468 L .63417 .68106 L p .707 .577 .707 r
F P
0 g
s
.63417 .68106 m .63953 .64312 L .64575 .64674 L p .707 .577 .707 r
F P
0 g
s
.84258 .573 m .83773 .63039 L .82492 .62758 L p .707 .577 .707 r
F P
0 g
s
.82492 .62758 m .82977 .57019 L .84258 .573 L p .707 .577 .707 r
F P
0 g
s
.39041 .59238 m .39526 .53499 L .36413 .53196 L p .707 .577 .707 r
F P
0 g
s
.42211 .59486 m .42695 .53747 L .39526 .53499 L p .707 .577 .707 r
F P
0 g
s
.84307 .72879 m .84209 .74779 L .8391 .74307 L p .707 .577 .707 r
F P
0 g
s
.8391 .74307 m .84007 .72406 L .84307 .72879 L p .707 .577 .707 r
F P
0 g
s
.45127 .59655 m .45612 .53916 L .42695 .53747 L p .707 .577 .707 r
F P
0 g
s
.36413 .53196 m .35929 .58936 L .39041 .59238 L p .707 .577 .707 r
F P
0 g
s
.64439 .61346 m .64924 .55607 L .6653 .55578 L p .707 .577 .707 r
F P
0 g
s
.35929 .58936 m .36413 .53196 L .33663 .52869 L p .707 .577 .707 r
F P
0 g
s
.83804 .67299 m .83269 .71093 L .81948 .71163 L p .707 .577 .707 r
F P
0 g
s
.6653 .55578 m .66046 .61318 L .64439 .61346 L p .707 .577 .707 r
F P
0 g
s
.33663 .52869 m .33178 .58609 L .35929 .58936 L p .707 .577 .707 r
F P
0 g
s
.63841 .73569 m .63939 .71668 L .64636 .71255 L p .707 .577 .707 r
F P
0 g
s
.81948 .71163 m .82484 .67368 L .83804 .67299 L p .707 .577 .707 r
F P
0 g
s
.36243 .60678 m .35708 .64473 L .38811 .64853 L p .707 .577 .707 r
F P
0 g
s
.38811 .64853 m .39347 .61058 L .36243 .60678 L p .707 .577 .707 r
F P
0 g
s
.39347 .61058 m .38811 .64853 L .41955 .65326 L p .707 .577 .707 r
F P
0 g
s
.64636 .71255 m .64539 .73156 L .63841 .73569 L p .707 .577 .707 r
F P
0 g
s
.45612 .53916 m .45127 .59655 L .47505 .59729 L p .707 .577 .707 r
F P
0 g
s
.47505 .59729 m .4799 .5399 L .45612 .53916 L p .707 .577 .707 r
F P
0 g
s
.41955 .65326 m .42491 .61531 L .39347 .61058 L p .707 .577 .707 r
F P
0 g
s
.66127 .65135 m .65591 .6893 L .6404 .68468 L p .707 .577 .707 r
F P
0 g
s
.6404 .68468 m .64575 .64674 L .66127 .65135 L p .707 .577 .707 r
F P
0 g
s
.33484 .60429 m .32948 .64223 L .35708 .64473 L p .707 .577 .707 r
F P
0 g
s
.35708 .64473 m .36243 .60678 L .33484 .60429 L p .707 .577 .707 r
F P
0 g
s
.33178 .58609 m .33663 .52869 L .31543 .5255 L p .707 .577 .707 r
F P
0 g
s
.82977 .57019 m .82492 .62758 L .80373 .62438 L p .707 .577 .707 r
F P
0 g
s
.80373 .62438 m .80857 .56699 L .82977 .57019 L p .707 .577 .707 r
F P
0 g
s
.31543 .5255 m .31058 .58289 L .33178 .58609 L p .707 .577 .707 r
F P
0 g
s
.84007 .72406 m .8391 .74307 L .82642 .73822 L p .707 .577 .707 r
F P
0 g
s
.82642 .73822 m .8274 .71921 L .84007 .72406 L p .707 .577 .707 r
F P
0 g
s
.47161 .66362 m .47696 .62567 L .45368 .62051 L p .707 .577 .707 r
F P
0 g
s
.66046 .61318 m .6653 .55578 L .68908 .55652 L p .707 .577 .707 r
F P
0 g
s
.31339 .60334 m .30803 .64129 L .32948 .64223 L p .707 .577 .707 r
F P
0 g
s
.32948 .64223 m .33484 .60429 L .31339 .60334 L p .707 .577 .707 r
F P
0 g
s
.39081 .71925 m .39178 .70024 L .36063 .69767 L p .707 .577 .707 r
F P
0 g
s
.39178 .70024 m .39081 .71925 L .42259 .72042 L p .707 .577 .707 r
F P
0 g
s
.42259 .72042 m .42357 .70141 L .39178 .70024 L p .707 .577 .707 r
F P
0 g
s
.68908 .55652 m .68424 .61392 L .66046 .61318 L p .707 .577 .707 r
F P
0 g
s
.4799 .5399 m .47505 .59729 L .49111 .59701 L p .707 .577 .707 r
F P
0 g
s
.49111 .59701 m .49596 .53962 L .4799 .5399 L p .707 .577 .707 r
F P
0 g
s
.82484 .67368 m .81948 .71163 L .79803 .71068 L p .707 .577 .707 r
F P
0 g
s
.36063 .69767 m .35965 .71668 L .39081 .71925 L p .707 .577 .707 r
F P
0 g
s
.4519 .72007 m .45287 .70107 L .42357 .70141 L p .707 .577 .707 r
F P
0 g
s
.79803 .71068 m .80339 .67274 L .82484 .67368 L p .707 .577 .707 r
F P
0 g
s
.64539 .73156 m .64636 .71255 L .66262 .70942 L p .707 .577 .707 r
F P
0 g
s
.35965 .71668 m .36063 .69767 L .33315 .69395 L p .707 .577 .707 r
F P
0 g
s
.66262 .70942 m .66165 .72843 L .64539 .73156 L p .707 .577 .707 r
F P
0 g
s
.31058 .58289 m .31543 .5255 L .30262 .52268 L p .707 .577 .707 r
F P
0 g
s
.33315 .69395 m .33218 .71296 L .35965 .71668 L p .707 .577 .707 r
F P
0 g
s
.68455 .65651 m .67919 .69446 L .65591 .6893 L p .707 .577 .707 r
F P
0 g
s
.65591 .6893 m .66127 .65135 L .68455 .65651 L p .707 .577 .707 r
F P
0 g
s
.80857 .56699 m .80373 .62438 L .77622 .62111 L p .707 .577 .707 r
F P
0 g
s
.77622 .62111 m .78107 .56372 L .80857 .56699 L p .707 .577 .707 r
F P
0 g
s
.30262 .52268 m .29777 .58008 L .31058 .58289 L p .707 .577 .707 r
F P
0 g
s
.47696 .62567 m .47161 .66362 L .48712 .66823 L p .707 .577 .707 r
F P
0 g
s
.45287 .70107 m .4519 .72007 L .47585 .71824 L p .707 .577 .707 r
F P
0 g
s
.47585 .71824 m .47683 .69923 L .45287 .70107 L p .707 .577 .707 r
F P
0 g
s
.48712 .66823 m .49248 .63029 L .47696 .62567 L p .707 .577 .707 r
F P
0 g
s
.68424 .61392 m .68908 .55652 L .71825 .55822 L p .707 .577 .707 r
F P
0 g
s
.71825 .55822 m .7134 .61561 L .68424 .61392 L p .707 .577 .707 r
F P
0 g
s
.30019 .60404 m .29483 .64198 L .30803 .64129 L p .707 .577 .707 r
F P
0 g
s
.30803 .64129 m .31339 .60334 L .30019 .60404 L p .707 .577 .707 r
F P
0 g
s
.33218 .71296 m .33315 .69395 L .31205 .68944 L p .707 .577 .707 r
F P
0 g
s
.8274 .71921 m .82642 .73822 L .80532 .73371 L p .707 .577 .707 r
F P
0 g
s
.80532 .73371 m .8063 .7147 L .8274 .71921 L p .707 .577 .707 r
F P
0 g
s
.80339 .67274 m .79803 .71068 L .77044 .70818 L p .707 .577 .707 r
F P
0 g
s
.31205 .68944 m .31107 .70845 L .33218 .71296 L p .707 .577 .707 r
F P
0 g
s
.78107 .56372 m .77622 .62111 L .7451 .61809 L p .707 .577 .707 r
F P
0 g
s
.7451 .61809 m .74994 .5607 L .78107 .56372 L p .707 .577 .707 r
F P
0 g
s
.77044 .70818 m .7758 .67024 L .80339 .67274 L p .707 .577 .707 r
F P
0 g
s
.49596 .53962 m .49111 .59701 L .49789 .59573 L p .707 .577 .707 r
F P
0 g
s
.49789 .59573 m .50274 .53833 L .49596 .53962 L p .707 .577 .707 r
F P
0 g
s
.71332 .66171 m .70796 .69966 L .67919 .69446 L p .707 .577 .707 r
F P
0 g
s
.67919 .69446 m .68455 .65651 L .71332 .66171 L p .707 .577 .707 r
F P
0 g
s
.7134 .61561 m .71825 .55822 L .74994 .5607 L p .707 .577 .707 r
F P
0 g
s
.66165 .72843 m .66262 .70942 L .68658 .70759 L p .707 .577 .707 r
F P
0 g
s
.74994 .5607 m .7451 .61809 L .7134 .61561 L p .707 .577 .707 r
F P
0 g
s
.68658 .70759 m .6856 .7266 L .66165 .72843 L p .707 .577 .707 r
F P
0 g
s
.47683 .69923 m .47585 .71824 L .49211 .71511 L p .707 .577 .707 r
F P
0 g
s
.49211 .71511 m .49309 .6961 L .47683 .69923 L p .707 .577 .707 r
F P
0 g
s
.29777 .58008 m .30262 .52268 L .29945 .52053 L p .707 .577 .707 r
F P
0 g
s
.7758 .67024 m .77044 .70818 L .7394 .70439 L p .707 .577 .707 r
F P
0 g
s
.49248 .63029 m .48712 .66823 L .49335 .67185 L p .707 .577 .707 r
F P
0 g
s
.29945 .52053 m .2946 .57792 L .29777 .58008 L p .707 .577 .707 r
F P
0 g
s
.7394 .70439 m .74476 .66644 L .7758 .67024 L p .707 .577 .707 r
F P
0 g
s
.74476 .66644 m .7394 .70439 L .70796 .69966 L p .707 .577 .707 r
F P
0 g
s
.70796 .69966 m .71332 .66171 L .74476 .66644 L p .707 .577 .707 r
F P
0 g
s
.49335 .67185 m .4987 .6339 L .49248 .63029 L p .707 .577 .707 r
F P
0 g
s
.31107 .70845 m .31205 .68944 L .29938 .68459 L p .707 .577 .707 r
F P
0 g
s
.8063 .7147 m .80532 .73371 L .77784 .72999 L p .707 .577 .707 r
F P
0 g
s
.77784 .72999 m .77882 .71098 L .8063 .7147 L p .707 .577 .707 r
F P
0 g
s
.29938 .68459 m .2984 .7036 L .31107 .70845 L p .707 .577 .707 r
F P
0 g
s
.29652 .6063 m .29116 .64425 L .29483 .64198 L p .707 .577 .707 r
F P
0 g
s
.29483 .64198 m .30019 .60404 L .29652 .6063 L p .707 .577 .707 r
F P
0 g
s
.6856 .7266 m .68658 .70759 L .71588 .70724 L p .707 .577 .707 r
F P
0 g
s
.71588 .70724 m .7149 .72625 L .6856 .7266 L p .707 .577 .707 r
F P
0 g
s
.50274 .53833 m .49789 .59573 L .49472 .59358 L p .707 .577 .707 r
F P
0 g
s
.49472 .59358 m .49957 .53618 L .50274 .53833 L p .707 .577 .707 r
F P
0 g
s
.77882 .71098 m .77784 .72999 L .74669 .72742 L p .707 .577 .707 r
F P
0 g
s
.74669 .72742 m .74767 .70841 L .77882 .71098 L p .707 .577 .707 r
F P
0 g
s
.49309 .6961 m .49211 .71511 L .49908 .71098 L p .707 .577 .707 r
F P
0 g
s
.49908 .71098 m .50006 .69197 L .49309 .6961 L p .707 .577 .707 r
F P
0 g
s
.7149 .72625 m .71588 .70724 L .74767 .70841 L p .707 .577 .707 r
F P
0 g
s
.74767 .70841 m .74669 .72742 L .7149 .72625 L p .707 .577 .707 r
F P
0 g
s
.2946 .57792 m .29945 .52053 L .30623 .51925 L p .707 .577 .707 r
F P
0 g
s
.4987 .6339 m .49335 .67185 L .48968 .67412 L p .707 .577 .707 r
F P
0 g
s
.30623 .51925 m .30138 .57664 L .2946 .57792 L p .707 .577 .707 r
F P
0 g
s
.2984 .7036 m .29938 .68459 L .29638 .67987 L p .707 .577 .707 r
F P
0 g
s
.48968 .67412 m .49503 .63617 L .4987 .6339 L p .707 .577 .707 r
F P
0 g
s
.29638 .67987 m .2954 .69888 L .2984 .7036 L p .707 .577 .707 r
F P
0 g
s
.30274 .60992 m .29739 .64787 L .29116 .64425 L p .707 .577 .707 r
F P
0 g
s
.29116 .64425 m .29652 .6063 L .30274 .60992 L p .707 .577 .707 r
F P
0 g
s
.49957 .53618 m .49472 .59358 L .48191 .59076 L p .707 .577 .707 r
F P
0 g
s
.48191 .59076 m .48676 .53337 L .49957 .53618 L p .707 .577 .707 r
F P
0 g
s
.50006 .69197 m .49908 .71098 L .49609 .70626 L p .707 .577 .707 r
F P
0 g
s
.49609 .70626 m .49706 .68725 L .50006 .69197 L p .707 .577 .707 r
F P
0 g
s
.30138 .57664 m .30623 .51925 L .32229 .51897 L p .707 .577 .707 r
F P
0 g
s
.49503 .63617 m .48968 .67412 L .47647 .67481 L p .707 .577 .707 r
F P
0 g
s
.32229 .51897 m .31745 .57636 L .30138 .57664 L p .707 .577 .707 r
F P
0 g
s
.2954 .69888 m .29638 .67987 L .30335 .67574 L p .707 .577 .707 r
F P
0 g
s
.47647 .67481 m .48183 .63687 L .49503 .63617 L p .707 .577 .707 r
F P
0 g
s
.30335 .67574 m .30238 .69475 L .2954 .69888 L p .707 .577 .707 r
F P
0 g
s
.31826 .61454 m .3129 .65248 L .29739 .64787 L p .707 .577 .707 r
F P
0 g
s
.29739 .64787 m .30274 .60992 L .31826 .61454 L p .707 .577 .707 r
F P
0 g
s
.48676 .53337 m .48191 .59076 L .46072 .58757 L p .707 .577 .707 r
F P
0 g
s
.46072 .58757 m .46556 .53017 L .48676 .53337 L p .707 .577 .707 r
F P
0 g
s
.49706 .68725 m .49609 .70626 L .48341 .7014 L p .707 .577 .707 r
F P
0 g
s
.48341 .7014 m .48439 .68239 L .49706 .68725 L p .707 .577 .707 r
F P
0 g
s
.31745 .57636 m .32229 .51897 L .34607 .51971 L p .707 .577 .707 r
F P
0 g
s
.34607 .51971 m .34123 .5771 L .31745 .57636 L p .707 .577 .707 r
F P
0 g
s
.48183 .63687 m .47647 .67481 L .45502 .67386 L p .707 .577 .707 r
F P
0 g
s
.45502 .67386 m .46038 .63592 L .48183 .63687 L p .707 .577 .707 r
F P
0 g
s
.30238 .69475 m .30335 .67574 L .31961 .6726 L p .707 .577 .707 r
F P
0 g
s
.31961 .6726 m .31864 .69161 L .30238 .69475 L p .707 .577 .707 r
F P
0 g
s
.34154 .6197 m .33618 .65764 L .3129 .65248 L p .707 .577 .707 r
F P
0 g
s
.3129 .65248 m .31826 .61454 L .34154 .6197 L p .707 .577 .707 r
F P
0 g
s
.46556 .53017 m .46072 .58757 L .43321 .5843 L p .707 .577 .707 r
F P
0 g
s
.43321 .5843 m .43806 .5269 L .46556 .53017 L p .707 .577 .707 r
F P
0 g
s
.34123 .5771 m .34607 .51971 L .37524 .5214 L p .707 .577 .707 r
F P
0 g
s
.37524 .5214 m .37039 .57879 L .34123 .5771 L p .707 .577 .707 r
F P
0 g
s
.48439 .68239 m .48341 .7014 L .46231 .69689 L p .707 .577 .707 r
F P
0 g
s
.46231 .69689 m .46328 .67789 L .48439 .68239 L p .707 .577 .707 r
F P
0 g
s
.46038 .63592 m .45502 .67386 L .42743 .67137 L p .707 .577 .707 r
F P
0 g
s
.43806 .5269 m .43321 .5843 L .40209 .58127 L p .707 .577 .707 r
F P
0 g
s
.40209 .58127 m .40693 .52388 L .43806 .5269 L p .707 .577 .707 r
F P
0 g
s
.42743 .67137 m .43279 .63343 L .46038 .63592 L p .707 .577 .707 r
F P
0 g
s
.37031 .6249 m .36495 .66284 L .33618 .65764 L p .707 .577 .707 r
F P
0 g
s
.33618 .65764 m .34154 .6197 L .37031 .6249 L p .707 .577 .707 r
F P
0 g
s
.37039 .57879 m .37524 .5214 L .40693 .52388 L p .707 .577 .707 r
F P
0 g
s
.31864 .69161 m .31961 .6726 L .34357 .67077 L p .707 .577 .707 r
F P
0 g
s
.40693 .52388 m .40209 .58127 L .37039 .57879 L p .707 .577 .707 r
F P
0 g
s
.34357 .67077 m .34259 .68978 L .31864 .69161 L p .707 .577 .707 r
F P
0 g
s
.43279 .63343 m .42743 .67137 L .39639 .66757 L p .707 .577 .707 r
F P
0 g
s
.39639 .66757 m .40175 .62963 L .43279 .63343 L p .707 .577 .707 r
F P
0 g
s
.40175 .62963 m .39639 .66757 L .36495 .66284 L p .707 .577 .707 r
F P
0 g
s
.36495 .66284 m .37031 .6249 L .40175 .62963 L p .707 .577 .707 r
F P
0 g
s
.46328 .67789 m .46231 .69689 L .43483 .69317 L p .707 .577 .707 r
F P
0 g
s
.43483 .69317 m .43581 .67416 L .46328 .67789 L p .707 .577 .707 r
F P
0 g
s
.34259 .68978 m .34357 .67077 L .37287 .67042 L p .707 .577 .707 r
F P
0 g
s
.37287 .67042 m .37189 .68943 L .34259 .68978 L p .707 .577 .707 r
F P
0 g
s
.43581 .67416 m .43483 .69317 L .40368 .6906 L p .707 .577 .707 r
F P
0 g
s
.40368 .6906 m .40465 .67159 L .43581 .67416 L p .707 .577 .707 r
F P
0 g
s
.37189 .68943 m .37287 .67042 L .40465 .67159 L p .707 .577 .707 r
F P
0 g
s
.40465 .67159 m .40368 .6906 L .37189 .68943 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool<0028Ool0081oo`T0
00IJEP03001JEUYF00=JEP`007aoo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH00eYF1`00MGoo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUH00000Lgoo001bOol300000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00LGoo001^Ool40004FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001_Ool006aoo`8000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006eo
o`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF0`00Jgoo001YOol01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001WOol20003
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0IWoo001TOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00
Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001GOol?0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`<0
00=JEP03001JEUYF00AJEP04001JEUYFFUH:0009FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK001<Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90013Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPP003]oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Eo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Goo001C
Ool00`00FUH00002FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo
001COol60005FUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001KOol70004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001ROol80004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo001VOol00`00FUIJEP090005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP0L0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EUYFFUH2000/Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP8002aoo`00EGoo3P000goo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo0P000eYF
00<005YFFUH00eYF00@005YFFUIJEPP000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo100000=JEP00FUH015YF00<005YFFUH01EYF00@0
05YFFUIJEPT000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
E7oo00@005YF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0140
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`04001JEUYF0003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH015YF4P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF
1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1P0000=JEP00FUH02eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
;Woo4@0057oo00<005YF00000eYF00<005YFFUH01EYF00@005YFFUIJEPL000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH70003FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH01000
FUIJEUYF4P000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000
25YF00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P002Woo4P0015YF00<005YFFUH01EYF00<005YFFUH00eYF1@00
0UYF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH700000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000LOol80004FUH00`00FUIJEP04FUH0
1000FUIJEUYF1000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH>0002FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0097oo4P00;Woo000^Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00I7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH03`00FGoo000]Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00@005YFFUIJEPT0051oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`00
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYF001JEP040005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90017Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EPD000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH0009JEPD00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003mo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00MJEP03
001JEUYF00IJEP04001JEUYFFUH6000iOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000@000AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00AJEP03001JEP0000<000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2P0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP03FUH700000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH3000bOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000015YF001JEUYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUH00002000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0001h000AJEP03001JEUYF00=JEP04001J
EUYFFUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00
FUH01UYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF5P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH@000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH600000eYF001JEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00;7oo00<005YF00003`0015YF00<005YFFUH01UYF00<005YFFUH01UYF0`00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`<0009JEP03001JEUYF00=J
EP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002moo`D000=JEP03001JEUYF00EJEP03001JEUYF00EJEPl000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool>0003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEQl000AJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80003FUH00`00FUIJEP06FUH01@00FUIJEP00FUH010000UYF2@0000IJEP00000005YF
0006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool400000eYF001JEP04FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH00eYF00@0
05YFFUIJEPT000EJEP03001JEUYF00MJEP8000=JEPL000=JEP04001JEUYFFUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=J
EPP000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02eoo`04001JEP00FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHI0002FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP04
001JEUYFFUH20002Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000/Ool01000FUIJEP000eYF00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUH005YF001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF009JEP8000Ioo`H000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000<000QJEP03001JEUYF00IJ
EP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYF0004FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF9@0015YF00<005YFFUH00eYF00@005YFFUIJEP80
02moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0000=JEP00FUH01eYF
00<005YFFUH01EYF00<005YF00001P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF5000<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUH000080004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05
FUH01000FUIJEUYF0P0000Aoo`00FUIJER0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002]oo`04001JEUYF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF40000UYF
00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000017ooFUIJEP001UYF00<005YF
FUH01UYF0P002UYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03
001JEUYF00IJEP8000QJEPX000aJEPT000QJEP03001JEUYF00EJEP05001JEP00FUH00002FUH:0003
FUH2000@Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03001JEUYF00MJEP03001JEUYF00H000UJEP03
001JEUYF00YJEP03001JEUYF00IJEPH0009JEP03001JEUYF00EJEP04001JEP00FUH40005FUH01000
FUIJEUYF20005Goo1P000eYF00@005YFFUIJEP8002eoo`00;Woo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP800004OomJEUYF0006FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH01000FUIJEUYF10001UYF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00EJEP04001JEUYFFUHO0003FUH2000]Ool0031oo`D000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002Ool2FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF
008002eoo`00<Woo7P000eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009oo`9J
EP03001JEUYF00AJEP03001JEP0000<000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<00003FUH005YF009JEP@000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000]Ool002moo`<0
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P000Woo0UYF00<005YFFUH015YF0P000UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH025YF00@005YF000000EJEP03001J
EP0000800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF009JEP80009o
o`9JEP03001JEUYF009JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00QJEP05001JEUYFFUH00003FUH2000015YF001JEUYF1@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF00000002Ool2FUH00`00FUIJEP020006FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH2000015YF000000001eYF4`0015YF00<005YFFUH01EYF00@005YFFUIJEPH0039o
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF10000Woo0UYF0`002EYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@001eYF00<0
05YFFUH00UYF0P0037oo4000>7oo000]Ool20004FUH01000FUIJEUYF400015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000AooeYFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP00010005Aoo`00;7oo00<005YF00000UYF1P0047oo4@0015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEP000003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH000030004FUH5
000MOol60004FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF
00=JEP04001JEUYFFUHB000@Ool400000eYF001JEP02FUH40004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;Goo00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD00003FUH0000000h000=JEP@0009JEP04001o
o`000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00@0
05YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1@00
1EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003Ool0000000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol0031o
o`@000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP08001JEUYFFUH005YF001oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol003Aoo`L000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH20003Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH60002FUH01000FUIJEUYF0P00EGoo000kOol90004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF200017oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YF00000P000UYF0P00EWoo0014OolI000<Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF0`001eYF00<005YFFUH00UYF1000EWoo001ZOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00001EOol006]o
o`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF008005Ao
o`00KGoo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF0P0000=oo`0000001P000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
KWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH00eYF0`002goo1P000eYF00@005YFFUIJEP8005Aoo`00L7oo0P0015YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00005P0000=JEP0000000`00
0UYF0P00E7oo001bOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH400000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04001D
Ool007Eoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000EJEPD000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00O7oo30001UYF00<005YFFUH0
15YF2@000UYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000E7oo0028Ool=0007Ool90004FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP04001EOol00:Eoo`T000AJEP03001JEUYF009JEPd005Uoo`00[Woo2@00IWoo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59595 .74008 m .59897 .68303 L .56781 .68044 L p .707 .577 .707 r
F P
0 g
s
.59897 .68303 m .59595 .74008 L .62774 .7413 L p .707 .577 .707 r
F P
0 g
s
.62774 .7413 m .63075 .68425 L .59897 .68303 L p .707 .577 .707 r
F P
0 g
s
.63075 .68425 m .62774 .7413 L .65703 .74104 L p .707 .577 .707 r
F P
0 g
s
.65703 .74104 m .66005 .68399 L .63075 .68425 L p .707 .577 .707 r
F P
0 g
s
.5648 .73749 m .56781 .68044 L .54034 .67673 L p .707 .577 .707 r
F P
0 g
s
.56781 .68044 m .5648 .73749 L .59595 .74008 L p .707 .577 .707 r
F P
0 g
s
.59412 .7871 m .59749 .74883 L .56636 .74576 L p .707 .577 .707 r
F P
0 g
s
.59749 .74883 m .59412 .7871 L .62581 .78972 L p .707 .577 .707 r
F P
0 g
s
.62581 .78972 m .62917 .75145 L .59749 .74883 L p .707 .577 .707 r
F P
0 g
s
.54034 .67673 m .53732 .73378 L .5648 .73749 L p .707 .577 .707 r
F P
0 g
s
.66005 .68399 m .65703 .74104 L .68098 .73932 L p .707 .577 .707 r
F P
0 g
s
.68098 .73932 m .68399 .68227 L .66005 .68399 L p .707 .577 .707 r
F P
0 g
s
.56636 .74576 m .563 .78403 L .59412 .7871 L p .707 .577 .707 r
F P
0 g
s
.62917 .75145 m .62581 .78972 L .65495 .79162 L p .707 .577 .707 r
F P
0 g
s
.65495 .79162 m .65832 .75335 L .62917 .75145 L p .707 .577 .707 r
F P
0 g
s
.563 .78403 m .56636 .74576 L .53885 .74254 L p .707 .577 .707 r
F P
0 g
s
.53732 .73378 m .54034 .67673 L .51923 .67228 L p .707 .577 .707 r
F P
0 g
s
.53885 .74254 m .53549 .78081 L .563 .78403 L p .707 .577 .707 r
F P
0 g
s
.51923 .67228 m .51621 .72933 L .53732 .73378 L p .707 .577 .707 r
F P
0 g
s
.65832 .75335 m .65495 .79162 L .67871 .79263 L p .707 .577 .707 r
F P
0 g
s
.67871 .79263 m .68207 .75436 L .65832 .75335 L p .707 .577 .707 r
F P
0 g
s
.59635 .83763 m .59695 .81877 L .56579 .81645 L p .707 .577 .707 r
F P
0 g
s
.59695 .81877 m .59635 .83763 L .62816 .83805 L p .707 .577 .707 r
F P
0 g
s
.62816 .83805 m .62877 .81919 L .59695 .81877 L p .707 .577 .707 r
F P
0 g
s
.62877 .81919 m .62816 .83805 L .65752 .83654 L p .707 .577 .707 r
F P
0 g
s
.65752 .83654 m .65812 .81767 L .62877 .81919 L p .707 .577 .707 r
F P
0 g
s
.56579 .81645 m .56518 .83532 L .59635 .83763 L p .707 .577 .707 r
F P
0 g
s
.53549 .78081 m .53885 .74254 L .51765 .73948 L p .707 .577 .707 r
F P
0 g
s
.68399 .68227 m .68098 .73932 L .69724 .7363 L p .707 .577 .707 r
F P
0 g
s
.69724 .7363 m .70025 .67925 L .68399 .68227 L p .707 .577 .707 r
F P
0 g
s
.51765 .73948 m .51429 .77775 L .53549 .78081 L p .707 .577 .707 r
F P
0 g
s
.56518 .83532 m .56579 .81645 L .53832 .81247 L p .707 .577 .707 r
F P
0 g
s
.53832 .81247 m .53772 .83134 L .56518 .83532 L p .707 .577 .707 r
F P
0 g
s
.51621 .72933 m .51923 .67228 L .50655 .66751 L p .707 .577 .707 r
F P
0 g
s
.65812 .81767 m .65752 .83654 L .68153 .83324 L p .707 .577 .707 r
F P
0 g
s
.68153 .83324 m .68214 .81437 L .65812 .81767 L p .707 .577 .707 r
F P
0 g
s
.68207 .75436 m .67871 .79263 L .69475 .79264 L p .707 .577 .707 r
F P
0 g
s
.69475 .79264 m .69811 .75437 L .68207 .75436 L p .707 .577 .707 r
F P
0 g
s
.50655 .66751 m .50354 .72456 L .51621 .72933 L p .707 .577 .707 r
F P
0 g
s
.53772 .83134 m .53832 .81247 L .51725 .80722 L p .707 .577 .707 r
F P
0 g
s
.51725 .80722 m .51664 .82608 L .53772 .83134 L p .707 .577 .707 r
F P
0 g
s
.51429 .77775 m .51765 .73948 L .50482 .73688 L p .707 .577 .707 r
F P
0 g
s
.50482 .73688 m .50146 .77515 L .51429 .77775 L p .707 .577 .707 r
F P
0 g
s
.70025 .67925 m .69724 .7363 L .7042 .73229 L p .707 .577 .707 r
F P
0 g
s
.7042 .73229 m .70721 .67524 L .70025 .67925 L p .707 .577 .707 r
F P
0 g
s
.68214 .81437 m .68153 .83324 L .69786 .82847 L p .707 .577 .707 r
F P
0 g
s
.69786 .82847 m .69846 .80961 L .68214 .81437 L p .707 .577 .707 r
F P
0 g
s
.50354 .72456 m .50655 .66751 L .50355 .6629 L p .707 .577 .707 r
F P
0 g
s
.51664 .82608 m .51725 .80722 L .50462 .8012 L p .707 .577 .707 r
F P
0 g
s
.69811 .75437 m .69475 .79264 L .7015 .79166 L p .707 .577 .707 r
F P
0 g
s
.7015 .79166 m .70486 .75339 L .69811 .75437 L p .707 .577 .707 r
F P
0 g
s
.50462 .8012 m .50402 .82006 L .51664 .82608 L p .707 .577 .707 r
F P
0 g
s
.50355 .6629 m .50054 .71995 L .50354 .72456 L p .707 .577 .707 r
F P
0 g
s
.50146 .77515 m .50482 .73688 L .50163 .73499 L p .707 .577 .707 r
F P
0 g
s
.49657 .82399 m .48694 .32918 L .44293 .32683 L p .707 .577 .707 r
F P
0 g
s
.50163 .73499 m .49826 .77326 L .50146 .77515 L p .707 .577 .707 r
F P
0 g
s
.50054 .71995 m .50355 .6629 L .51052 .65889 L p .707 .577 .707 r
F P
0 g
s
.50402 .82006 m .50462 .8012 L .50169 .795 L p .707 .577 .707 r
F P
0 g
s
.50169 .795 m .50109 .81387 L .50402 .82006 L p .707 .577 .707 r
F P
0 g
s
.51052 .65889 m .5075 .71594 L .50054 .71995 L p .707 .577 .707 r
F P
0 g
s
.49826 .77326 m .50163 .73499 L .50838 .73401 L p .707 .577 .707 r
F P
0 g
s
.50838 .73401 m .50502 .77228 L .49826 .77326 L p .707 .577 .707 r
F P
0 g
s
.5075 .71594 m .51052 .65889 L .52677 .65587 L p .707 .577 .707 r
F P
0 g
s
.50109 .81387 m .50169 .795 L .50873 .78924 L p .707 .577 .707 r
F P
0 g
s
.50873 .78924 m .50813 .80811 L .50109 .81387 L p .707 .577 .707 r
F P
0 g
s
.52677 .65587 m .52376 .71292 L .5075 .71594 L p .707 .577 .707 r
F P
0 g
s
.50502 .77228 m .50838 .73401 L .52442 .73402 L p .707 .577 .707 r
F P
0 g
s
.52442 .73402 m .52106 .77229 L .50502 .77228 L p .707 .577 .707 r
F P
0 g
s
.52376 .71292 m .52677 .65587 L .55072 .65415 L p .707 .577 .707 r
F P
0 g
s
.50813 .80811 m .50873 .78924 L .52506 .78448 L p .707 .577 .707 r
F P
0 g
s
.52506 .78448 m .52445 .80335 L .50813 .80811 L p .707 .577 .707 r
F P
0 g
s
.55072 .65415 m .5477 .7112 L .52376 .71292 L p .707 .577 .707 r
F P
0 g
s
.52106 .77229 m .52442 .73402 L .54817 .73503 L p .707 .577 .707 r
F P
0 g
s
.54817 .73503 m .54481 .7733 L .52106 .77229 L p .707 .577 .707 r
F P
0 g
s
.52445 .80335 m .52506 .78448 L .54907 .78118 L p .707 .577 .707 r
F P
0 g
s
.54907 .78118 m .54847 .80005 L .52445 .80335 L p .707 .577 .707 r
F P
0 g
s
.48694 .32918 m .49657 .82399 L .5415 .82192 L p .707 .577 .707 r
F P
0 g
s
.5415 .82192 m .53187 .32711 L .48694 .32918 L p .707 .577 .707 r
F P
0 g
s
.5477 .7112 m .55072 .65415 L .58002 .65389 L p .707 .577 .707 r
F P
0 g
s
.58002 .65389 m .577 .71094 L .5477 .7112 L p .707 .577 .707 r
F P
0 g
s
.54481 .7733 m .54817 .73503 L .57732 .73693 L p .707 .577 .707 r
F P
0 g
s
.57732 .73693 m .57396 .7752 L .54481 .7733 L p .707 .577 .707 r
F P
0 g
s
.57396 .7752 m .57732 .73693 L .60901 .73955 L p .707 .577 .707 r
F P
0 g
s
.60901 .73955 m .60564 .77782 L .57396 .7752 L p .707 .577 .707 r
F P
0 g
s
.54847 .80005 m .54907 .78118 L .57842 .77967 L p .707 .577 .707 r
F P
0 g
s
.57842 .77967 m .57782 .79853 L .54847 .80005 L p .707 .577 .707 r
F P
0 g
s
.57782 .79853 m .57842 .77967 L .61024 .78008 L p .707 .577 .707 r
F P
0 g
s
.61024 .78008 m .60964 .79895 L .57782 .79853 L p .707 .577 .707 r
F P
0 g
s
.53187 .32711 m .5415 .82192 L .58297 .81563 L p .707 .577 .707 r
F P
0 g
s
.577 .71094 m .58002 .65389 L .6118 .65511 L p .707 .577 .707 r
F P
0 g
s
.6118 .65511 m .60879 .71216 L .577 .71094 L p .707 .577 .707 r
F P
0 g
s
.58297 .81563 m .57334 .32082 L .53187 .32711 L p .707 .577 .707 r
F P
0 g
s
.70721 .67524 m .7042 .73229 L .7012 .72768 L p .707 .577 .707 r
F P
0 g
s
.7012 .72768 m .70421 .67062 L .70721 .67524 L p .707 .577 .707 r
F P
0 g
s
.69846 .80961 m .69786 .82847 L .7049 .82271 L p .707 .577 .707 r
F P
0 g
s
.7049 .82271 m .7055 .80385 L .69846 .80961 L p .707 .577 .707 r
F P
0 g
s
.45256 .82164 m .44293 .32683 L .40417 .3203 L p .707 .577 .707 r
F P
0 g
s
.44293 .32683 m .45256 .82164 L .49657 .82399 L p .707 .577 .707 r
F P
0 g
s
.64013 .74262 m .63676 .78089 L .61419 .77866 L p .707 .577 .707 r
F P
0 g
s
.61419 .77866 m .60564 .77782 L p .61464 .76864 L .707 .577 .707 r
F P
0 g
s
.61464 .76864 m .64013 .74262 L .61419 .77866 L .707 .577 .707 r
F
.67043 .6614 m .66742 .71845 L .63994 .71475 L p F P
0 g
s
.63994 .71475 m .64295 .6577 L .67043 .6614 L p .707 .577 .707 r
F P
0 g
s
.64295 .6577 m .63994 .71475 L .60879 .71216 L p .707 .577 .707 r
F P
0 g
s
.60879 .71216 m .6118 .65511 L .64295 .6577 L p .707 .577 .707 r
F P
0 g
s
.66764 .74584 m .66427 .78411 L .63676 .78089 L p .707 .577 .707 r
F P
0 g
s
.63676 .78089 m .64013 .74262 L .66764 .74584 L p .707 .577 .707 r
F P
0 g
s
.6408 .80126 m .64141 .7824 L .66887 .78638 L p .707 .577 .707 r
F P
0 g
s
.60564 .77782 m .60901 .73955 L .64013 .74262 L p .707 .577 .707 r
F P
0 g
s
.64141 .7824 m .6408 .80126 L .60964 .79895 L p .707 .577 .707 r
F P
0 g
s
.60964 .79895 m .61024 .78008 L .64141 .7824 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .64997 .77928 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63037 .2984 m .63192 .37812 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.63192 .37812 m .63999 .79321 L p .6328 .35813 L .707 .577 .707 r
F P
0 g
s
.57334 .32082 m .58297 .81563 L .61691 .80574 L p .707 .577 .707 r
F P
0 g
s
.61691 .80574 m .60728 .31093 L .57334 .32082 L p .707 .577 .707 r
F P
0 g
s
.70486 .75339 m .7015 .79166 L .69831 .78977 L p .707 .577 .707 r
F P
0 g
s
.69831 .78977 m .70167 .7515 L .70486 .75339 L p .707 .577 .707 r
F P
0 g
s
.41379 .81511 m .40417 .3203 L .37443 .31021 L p .707 .577 .707 r
F P
0 g
s
.40417 .3203 m .41379 .81511 L .45256 .82164 L p .707 .577 .707 r
F P
0 g
s
.7055 .80385 m .7049 .82271 L .70196 .81652 L p .707 .577 .707 r
F P
0 g
s
.70196 .81652 m .70257 .79765 L .7055 .80385 L p .707 .577 .707 r
F P
0 g
s
.70421 .67062 m .7012 .72768 L .68852 .72291 L p .707 .577 .707 r
F P
0 g
s
.68852 .72291 m .69154 .66586 L .70421 .67062 L p .707 .577 .707 r
F P
0 g
s
.25295 .70326 m .25596 .64621 L .2248 .64362 L p .707 .577 .707 r
F P
0 g
s
.25596 .64621 m .25295 .70326 L .28473 .70449 L p .707 .577 .707 r
F P
0 g
s
.28473 .70449 m .28774 .64744 L .25596 .64621 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28774 .64744 m .28473 .70449 L .31403 .70422 L p .707 .577 .707 r
F P
0 g
s
.31403 .70422 m .31704 .64717 L .28774 .64744 L p .707 .577 .707 r
F P
0 g
s
.22179 .70067 m .2248 .64362 L .19733 .63992 L p .707 .577 .707 r
F P
0 g
s
.2248 .64362 m .22179 .70067 L .25295 .70326 L p .707 .577 .707 r
F P
0 g
s
.60728 .31093 m .61691 .80574 L .63999 .79321 L p .707 .577 .707 r
F P
0 g
s
.63999 .79321 m .63037 .2984 L .60728 .31093 L p .707 .577 .707 r
F P
0 g
s
.70167 .7515 m .69831 .78977 L .68548 .78717 L p .707 .577 .707 r
F P
0 g
s
.68548 .78717 m .68884 .7489 L .70167 .7515 L p .707 .577 .707 r
F P
0 g
s
.25111 .75029 m .25448 .71202 L .22336 .70895 L p .707 .577 .707 r
F P
0 g
s
.25448 .71202 m .25111 .75029 L .2828 .7529 L p .707 .577 .707 r
F P
0 g
s
.2828 .7529 m .28616 .71463 L .25448 .71202 L p .707 .577 .707 r
F P
0 g
s
.19733 .63992 m .19431 .69697 L .22179 .70067 L p .707 .577 .707 r
F P
0 g
s
.31704 .64717 m .31403 .70422 L .33797 .7025 L p .707 .577 .707 r
F P
0 g
s
.33797 .7025 m .34099 .64545 L .31704 .64717 L p .707 .577 .707 r
F P
0 g
s
.22336 .70895 m .21999 .74722 L .25111 .75029 L p .707 .577 .707 r
F P
0 g
s
.28616 .71463 m .2828 .7529 L .31194 .75481 L p .707 .577 .707 r
F P
0 g
s
.31194 .75481 m .31531 .71654 L .28616 .71463 L p .707 .577 .707 r
F P
0 g
s
.21999 .74722 m .22336 .70895 L .19585 .70572 L p .707 .577 .707 r
F P
0 g
s
.19431 .69697 m .19733 .63992 L .17622 .63547 L p .707 .577 .707 r
F P
0 g
s
.38406 .80502 m .37443 .31021 L .35664 .29756 L p .707 .577 .707 r
F P
0 g
s
.37443 .31021 m .38406 .80502 L .41379 .81511 L p .707 .577 .707 r
F P
0 g
s
.19585 .70572 m .19248 .74399 L .21999 .74722 L p .707 .577 .707 r
F P
0 g
s
.69154 .66586 m .68852 .72291 L .66742 .71845 L p .707 .577 .707 r
F P
0 g
s
.66742 .71845 m .67043 .6614 L .69154 .66586 L p .707 .577 .707 r
F P
0 g
s
.70257 .79765 m .70196 .81652 L .68934 .8105 L p .707 .577 .707 r
F P
0 g
s
.68934 .8105 m .68995 .79163 L .70257 .79765 L p .707 .577 .707 r
F P
0 g
s
.17622 .63547 m .17321 .69252 L .19431 .69697 L p .707 .577 .707 r
F P
0 g
s
.31531 .71654 m .31194 .75481 L .3357 .75581 L p .707 .577 .707 r
F P
0 g
s
.3357 .75581 m .33906 .71754 L .31531 .71654 L p .707 .577 .707 r
F P
0 g
s
.25334 .80082 m .25394 .78195 L .22278 .77964 L p .707 .577 .707 r
F P
0 g
s
.25394 .78195 m .25334 .80082 L .28515 .80124 L p .707 .577 .707 r
F P
0 g
s
.28515 .80124 m .28576 .78237 L .25394 .78195 L p .707 .577 .707 r
F P
0 g
s
.28576 .78237 m .28515 .80124 L .31451 .79972 L p .707 .577 .707 r
F P
0 g
s
.31451 .79972 m .31511 .78086 L .28576 .78237 L p .707 .577 .707 r
F P
0 g
s
.22278 .77964 m .22217 .7985 L .25334 .80082 L p .707 .577 .707 r
F P
0 g
s
.19248 .74399 m .19585 .70572 L .17464 .70266 L p .707 .577 .707 r
F P
0 g
s
.34099 .64545 m .33797 .7025 L .35423 .69949 L p .707 .577 .707 r
F P
0 g
s
.35423 .69949 m .35724 .64244 L .34099 .64545 L p .707 .577 .707 r
F P
0 g
s
.17464 .70266 m .17128 .74093 L .19248 .74399 L p .707 .577 .707 r
F P
0 g
s
.22217 .7985 m .22278 .77964 L .19531 .77566 L p .707 .577 .707 r
F P
0 g
s
.68884 .7489 m .68548 .78717 L .66427 .78411 L p .707 .577 .707 r
F P
0 g
s
.66427 .78411 m .66764 .74584 L .68884 .7489 L p .707 .577 .707 r
F P
0 g
s
.19531 .77566 m .19471 .79452 L .22217 .7985 L p .707 .577 .707 r
F P
0 g
s
.64997 .77928 m .64035 .28447 L .63037 .2984 L p .707 .577 .707 r
F P
0 g
s
.17321 .69252 m .17622 .63547 L .16354 .6307 L p .707 .577 .707 r
F P
0 g
s
.31511 .78086 m .31451 .79972 L .33852 .79642 L p .707 .577 .707 r
F P
0 g
s
.33852 .79642 m .33913 .77756 L .31511 .78086 L p .707 .577 .707 r
F P
0 g
s
.33906 .71754 m .3357 .75581 L .35174 .75583 L p .707 .577 .707 r
F P
0 g
s
.35174 .75583 m .3551 .71756 L .33906 .71754 L p .707 .577 .707 r
F P
0 g
s
.16354 .6307 m .16053 .68775 L .17321 .69252 L p .707 .577 .707 r
F P
0 g
s
.68995 .79163 m .68934 .8105 L .66827 .80524 L p .707 .577 .707 r
F P
0 g
s
.66827 .80524 m .66887 .78638 L .68995 .79163 L p .707 .577 .707 r
F P
0 g
s
.19471 .79452 m .19531 .77566 L .17424 .7704 L p .707 .577 .707 r
F P
0 g
s
.17424 .7704 m .17363 .78927 L .19471 .79452 L p .707 .577 .707 r
F P
0 g
s
.17128 .74093 m .17464 .70266 L .16181 .70006 L p .707 .577 .707 r
F P
0 g
s
.36119 .69548 m .3642 .63842 L .35724 .64244 L p .707 .577 .707 r
F P
0 g
s
.35724 .64244 m .35423 .69949 L .36119 .69548 L p .707 .577 .707 r
F P
0 g
s
.3642 .63842 m .36119 .69548 L .35819 .69086 L p .707 .577 .707 r
F P
0 g
s
.35819 .69086 m .3612 .63381 L .3642 .63842 L p .707 .577 .707 r
F P
0 g
s
.36627 .79237 m .35664 .29756 L .35253 .28359 L p .707 .577 .707 r
F P
0 g
s
.35664 .29756 m .36627 .79237 L .38406 .80502 L p .707 .577 .707 r
F P
0 g
s
.16181 .70006 m .15845 .73833 L .17128 .74093 L p .707 .577 .707 r
F P
0 g
s
.33913 .77756 m .33852 .79642 L .35485 .79166 L p .707 .577 .707 r
F P
0 g
s
.35485 .79166 m .35545 .77279 L .33913 .77756 L p .707 .577 .707 r
F P
0 g
s
.16053 .68775 m .16354 .6307 L .16054 .62608 L p .707 .577 .707 r
F P
0 g
s
.66887 .78638 m .66827 .80524 L .6408 .80126 L p .707 .577 .707 r
F P
0 g
s
.17363 .78927 m .17424 .7704 L .16162 .76438 L p .707 .577 .707 r
F P
0 g
s
.3551 .71756 m .35174 .75583 L .35849 .75484 L p .707 .577 .707 r
F P
0 g
s
.35849 .75484 m .36186 .71657 L .3551 .71756 L p .707 .577 .707 r
F P
0 g
s
.16162 .76438 m .16101 .78325 L .17363 .78927 L p .707 .577 .707 r
F P
0 g
s
.16054 .62608 m .15753 .68313 L .16053 .68775 L p .707 .577 .707 r
F P
0 g
s
.64035 .28447 m .64997 .77928 L .64947 .77756 L p .707 .577 .707 r
F P
0 g
s
.64534 .71934 m .64035 .28447 L .64947 .77756 L .707 .577 .707 r
F
.64587 .76531 m .63624 .2705 L .64035 .28447 L p F P
0 g
s
.63624 .2705 m .64587 .76531 L .62807 .75266 L p .707 .577 .707 r
F P
0 g
s
.64202 .64793 m .64106 .65895 L p .65149 .6888 L .707 .577 .707 r
F P
0 g
s
.64106 .65895 m .63866 .6862 L .64305 .68709 L p .707 .577 .707 r
F P
0 g
s
.64305 .68709 m .65149 .6888 L p .64106 .65895 L .707 .577 .707 r
F P
0 g
s
.64947 .77756 m .64587 .76531 L p .64534 .71934 L .707 .577 .707 r
F P
0 g
s
.15845 .73833 m .16181 .70006 L .15862 .69818 L p .707 .577 .707 r
F P
0 g
s
.15862 .69818 m .15525 .73645 L .15845 .73833 L p .707 .577 .707 r
F P
0 g
s
.35545 .77279 m .35485 .79166 L .36189 .7859 L p .707 .577 .707 r
F P
0 g
s
.36189 .7859 m .36249 .76703 L .35545 .77279 L p .707 .577 .707 r
F P
0 g
s
.36186 .71657 m .35849 .75484 L .3553 .75296 L p .707 .577 .707 r
F P
0 g
s
.3553 .75296 m .35866 .71469 L .36186 .71657 L p .707 .577 .707 r
F P
0 g
s
.36249 .76703 m .36189 .7859 L .35895 .77971 L p .707 .577 .707 r
F P
0 g
s
.35895 .77971 m .35956 .76084 L .36249 .76703 L p .707 .577 .707 r
F P
0 g
s
.3612 .63381 m .35819 .69086 L .34552 .68609 L p .707 .577 .707 r
F P
0 g
s
.34552 .68609 m .34853 .62904 L .3612 .63381 L p .707 .577 .707 r
F P
0 g
s
.35253 .28359 m .36216 .77839 L .36627 .79237 L p .707 .577 .707 r
F P
0 g
s
.36216 .77839 m .35253 .28359 L .36251 .26965 L p .707 .577 .707 r
F P
0 g
s
.15753 .68313 m .16054 .62608 L .16751 .62207 L p .707 .577 .707 r
F P
0 g
s
.16101 .78325 m .16162 .76438 L .15868 .75819 L p .707 .577 .707 r
F P
0 g
s
.15868 .75819 m .15808 .77706 L .16101 .78325 L p .707 .577 .707 r
F P
0 g
s
.16751 .62207 m .16449 .67912 L .15753 .68313 L p .707 .577 .707 r
F P
0 g
s
.15525 .73645 m .15862 .69818 L .16537 .69719 L p .707 .577 .707 r
F P
0 g
s
.16537 .69719 m .16201 .73546 L .15525 .73645 L p .707 .577 .707 r
F P
0 g
s
.62807 .75266 m .61845 .25785 L .63624 .2705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16449 .67912 m .16751 .62207 L .18376 .61906 L p .707 .577 .707 r
F P
0 g
s
.15808 .77706 m .15868 .75819 L .16572 .75243 L p .707 .577 .707 r
F P
0 g
s
.16572 .75243 m .16512 .7713 L .15808 .77706 L p .707 .577 .707 r
F P
0 g
s
.35866 .71469 m .3553 .75296 L .34247 .75036 L p .707 .577 .707 r
F P
0 g
s
.34247 .75036 m .34583 .71209 L .35866 .71469 L p .707 .577 .707 r
F P
0 g
s
.18376 .61906 m .18075 .67611 L .16449 .67912 L p .707 .577 .707 r
F P
0 g
s
.37214 .76446 m .36251 .26965 L .3856 .25713 L p .707 .577 .707 r
F P
0 g
s
.36251 .26965 m .37214 .76446 L .36216 .77839 L p .707 .577 .707 r
F P
0 g
s
.16201 .73546 m .16537 .69719 L .18141 .69721 L p .707 .577 .707 r
F P
0 g
s
.18141 .69721 m .17805 .73548 L .16201 .73546 L p .707 .577 .707 r
F P
0 g
s
.34853 .62904 m .34552 .68609 L .32441 .68164 L p .707 .577 .707 r
F P
0 g
s
.32441 .68164 m .32742 .62459 L .34853 .62904 L p .707 .577 .707 r
F P
0 g
s
.35956 .76084 m .35895 .77971 L .34633 .77369 L p .707 .577 .707 r
F P
0 g
s
.34633 .77369 m .34694 .75482 L .35956 .76084 L p .707 .577 .707 r
F P
0 g
s
.18075 .67611 m .18376 .61906 L .20771 .61733 L p .707 .577 .707 r
F P
0 g
s
.61845 .25785 m .62807 .75266 L .59834 .74257 L p .707 .577 .707 r
F P
0 g
s
.59834 .74257 m .58871 .24776 L .61845 .25785 L p .707 .577 .707 r
F P
0 g
s
.16512 .7713 m .16572 .75243 L .18205 .74766 L p .707 .577 .707 r
F P
0 g
s
.34583 .71209 m .34247 .75036 L .32126 .7473 L p .707 .577 .707 r
F P
0 g
s
.32126 .7473 m .32463 .70903 L .34583 .71209 L p .707 .577 .707 r
F P
0 g
s
.18205 .74766 m .18144 .76653 L .16512 .7713 L p .707 .577 .707 r
F P
0 g
s
.20771 .61733 m .20469 .67439 L .18075 .67611 L p .707 .577 .707 r
F P
0 g
s
.32742 .62459 m .32441 .68164 L .29693 .67794 L p .707 .577 .707 r
F P
0 g
s
.29693 .67794 m .29994 .62089 L .32742 .62459 L p .707 .577 .707 r
F P
0 g
s
.17805 .73548 m .18141 .69721 L .20517 .69821 L p .707 .577 .707 r
F P
0 g
s
.20517 .69821 m .2018 .73648 L .17805 .73548 L p .707 .577 .707 r
F P
0 g
s
.3856 .25713 m .39523 .75194 L .37214 .76446 L p .707 .577 .707 r
F P
0 g
s
.39523 .75194 m .3856 .25713 L .41954 .24724 L p .707 .577 .707 r
F P
0 g
s
.20469 .67439 m .20771 .61733 L .23701 .61707 L p .707 .577 .707 r
F P
0 g
s
.34694 .75482 m .34633 .77369 L .32526 .76843 L p .707 .577 .707 r
F P
0 g
s
.32526 .76843 m .32586 .74956 L .34694 .75482 L p .707 .577 .707 r
F P
0 g
s
.23701 .61707 m .23399 .67412 L .20469 .67439 L p .707 .577 .707 r
F P
0 g
s
.29994 .62089 m .29693 .67794 L .26578 .67535 L p .707 .577 .707 r
F P
0 g
s
.26578 .67535 m .26879 .6183 L .29994 .62089 L p .707 .577 .707 r
F P
0 g
s
.32463 .70903 m .32126 .7473 L .29375 .74407 L p .707 .577 .707 r
F P
0 g
s
.29375 .74407 m .29712 .7058 L .32463 .70903 L p .707 .577 .707 r
F P
0 g
s
.73316 .64024 m .73617 .58319 L .70502 .5806 L p .707 .577 .707 r
F P
0 g
s
.73617 .58319 m .73316 .64024 L .76494 .64147 L p .707 .577 .707 r
F P
0 g
s
.76494 .64147 m .76795 .58441 L .73617 .58319 L p .707 .577 .707 r
F P
0 g
s
.18144 .76653 m .18205 .74766 L .20606 .74436 L p .707 .577 .707 r
F P
0 g
s
.23399 .67412 m .23701 .61707 L .26879 .6183 L p .707 .577 .707 r
F P
0 g
s
.76795 .58441 m .76494 .64147 L .79424 .6412 L p .707 .577 .707 r
F P
0 g
s
.79424 .6412 m .79725 .58415 L .76795 .58441 L p .707 .577 .707 r
F P
0 g
s
.58871 .24776 m .59834 .74257 L .55957 .73603 L p .707 .577 .707 r
F P
0 g
s
.55957 .73603 m .54994 .24122 L .58871 .24776 L p .707 .577 .707 r
F P
0 g
s
.20606 .74436 m .20546 .76323 L .18144 .76653 L p .707 .577 .707 r
F P
0 g
s
.2018 .73648 m .20517 .69821 L .23431 .70012 L p .707 .577 .707 r
F P
0 g
s
.26879 .6183 m .26578 .67535 L .23399 .67412 L p .707 .577 .707 r
F P
0 g
s
.702 .63765 m .70502 .5806 L .67754 .5769 L p .707 .577 .707 r
F P
0 g
s
.70502 .5806 m .702 .63765 L .73316 .64024 L p .707 .577 .707 r
F P
0 g
s
.23431 .70012 m .23095 .73839 L .2018 .73648 L p .707 .577 .707 r
F P
0 g
s
.32586 .74956 m .32526 .76843 L .29779 .76445 L p .707 .577 .707 r
F P
0 g
s
.29779 .76445 m .2984 .74558 L .32586 .74956 L p .707 .577 .707 r
F P
0 g
s
.67754 .5769 m .67453 .63395 L .702 .63765 L p .707 .577 .707 r
F P
0 g
s
.42916 .74205 m .41954 .24724 L .461 .24095 L p .707 .577 .707 r
F P
0 g
s
.41954 .24724 m .42813 .68895 L p .39523 .75194 L .707 .577 .707 r
F P
0 g
s
.461 .24095 m .47063 .73576 L .42916 .74205 L p .707 .577 .707 r
F P
0 g
s
.42336 .62569 m .42 .66396 L .43917 .66521 L p .707 .577 .707 r
F P
0 g
s
.43917 .66521 m .44915 .66586 L p .44319 .65658 L .707 .577 .707 r
F P
0 g
s
.44319 .65658 m .42336 .62569 L .43917 .66521 L .707 .577 .707 r
F
.42813 .68895 m .42916 .74205 L .39941 .75072 L p F P
0 g
s
.39941 .75072 m .39523 .75194 L p .42813 .68895 L .707 .577 .707 r
F P
0 g
s
.29712 .7058 m .29375 .74407 L .26263 .741 L p .707 .577 .707 r
F P
0 g
s
.26263 .741 m .266 .70273 L .29712 .7058 L p .707 .577 .707 r
F P
0 g
s
.79725 .58415 m .79424 .6412 L .81819 .63948 L p .707 .577 .707 r
F P
0 g
s
.81819 .63948 m .8212 .58243 L .79725 .58415 L p .707 .577 .707 r
F P
0 g
s
.73133 .69816 m .73469 .65989 L .70357 .65682 L p .707 .577 .707 r
F P
0 g
s
.73469 .65989 m .73133 .69816 L .76301 .70077 L p .707 .577 .707 r
F P
0 g
s
.76301 .70077 m .76637 .6625 L .73469 .65989 L p .707 .577 .707 r
F P
0 g
s
.23095 .73839 m .23431 .70012 L .266 .70273 L p .707 .577 .707 r
F P
0 g
s
.70357 .65682 m .70021 .69509 L .73133 .69816 L p .707 .577 .707 r
F P
0 g
s
.266 .70273 m .26263 .741 L .23095 .73839 L p .707 .577 .707 r
F P
0 g
s
.76637 .6625 m .76301 .70077 L .79216 .70268 L p .707 .577 .707 r
F P
0 g
s
.79216 .70268 m .79552 .66441 L .76637 .6625 L p .707 .577 .707 r
F P
0 g
s
.20546 .76323 m .20606 .74436 L .23542 .74285 L p .707 .577 .707 r
F P
0 g
s
.67453 .63395 m .67754 .5769 L .65643 .57245 L p .707 .577 .707 r
F P
0 g
s
.70021 .69509 m .70357 .65682 L .67606 .65359 L p .707 .577 .707 r
F P
0 g
s
.23542 .74285 m .23481 .76172 L .20546 .76323 L p .707 .577 .707 r
F P
0 g
s
.54994 .24122 m .55957 .73603 L .51557 .73369 L p .707 .577 .707 r
F P
0 g
s
.51557 .73369 m .50594 .23888 L .54994 .24122 L p .707 .577 .707 r
F P
0 g
s
.67606 .65359 m .6727 .69186 L .70021 .69509 L p .707 .577 .707 r
F P
0 g
s
.2984 .74558 m .29779 .76445 L .26663 .76214 L p .707 .577 .707 r
F P
0 g
s
.26663 .76214 m .26723 .74327 L .2984 .74558 L p .707 .577 .707 r
F P
0 g
s
.65643 .57245 m .65342 .6295 L .67453 .63395 L p .707 .577 .707 r
F P
0 g
s
.47063 .73576 m .461 .24095 L .50594 .23888 L p .707 .577 .707 r
F P
0 g
s
.23481 .76172 m .23542 .74285 L .26723 .74327 L p .707 .577 .707 r
F P
0 g
s
.79552 .66441 m .79216 .70268 L .81591 .70369 L p .707 .577 .707 r
F P
0 g
s
.81591 .70369 m .81928 .66542 L .79552 .66441 L p .707 .577 .707 r
F P
0 g
s
.50594 .23888 m .51557 .73369 L .47063 .73576 L p .707 .577 .707 r
F P
0 g
s
.26723 .74327 m .26663 .76214 L .23481 .76172 L p .707 .577 .707 r
F P
0 g
s
.8212 .58243 m .81819 .63948 L .83444 .63647 L p .707 .577 .707 r
F P
0 g
s
.83444 .63647 m .83745 .57942 L .8212 .58243 L p .707 .577 .707 r
F P
0 g
s
.73355 .7575 m .73416 .73863 L .70299 .73632 L p .707 .577 .707 r
F P
0 g
s
.73416 .73863 m .73355 .7575 L .76537 .75792 L p .707 .577 .707 r
F P
0 g
s
.76537 .75792 m .76597 .73905 L .73416 .73863 L p .707 .577 .707 r
F P
0 g
s
.6727 .69186 m .67606 .65359 L .65485 .65053 L p .707 .577 .707 r
F P
0 g
s
.76597 .73905 m .76537 .75792 L .79472 .7564 L p .707 .577 .707 r
F P
0 g
s
.79472 .7564 m .79532 .73754 L .76597 .73905 L p .707 .577 .707 r
F P
0 g
s
.70299 .73632 m .70239 .75518 L .73355 .7575 L p .707 .577 .707 r
F P
0 g
s
.65485 .65053 m .65149 .6888 L .6727 .69186 L p .707 .577 .707 r
F P
0 g
s
.70239 .75518 m .70299 .73632 L .67553 .73234 L p .707 .577 .707 r
F P
0 g
s
.65342 .6295 m .65643 .57245 L .64375 .56768 L p .707 .577 .707 r
F P
0 g
s
.67553 .73234 m .67492 .7512 L .70239 .75518 L p .707 .577 .707 r
F P
0 g
s
.79532 .73754 m .79472 .7564 L .81874 .7531 L p .707 .577 .707 r
F P
0 g
s
.81874 .7531 m .81934 .73424 L .79532 .73754 L p .707 .577 .707 r
F P
0 g
s
.64375 .56768 m .64074 .62473 L .65342 .6295 L p .707 .577 .707 r
F P
0 g
s
.81928 .66542 m .81591 .70369 L .83195 .7037 L p .707 .577 .707 r
F P
0 g
s
.83195 .7037 m .83532 .66543 L .81928 .66542 L p .707 .577 .707 r
F P
0 g
s
.67492 .7512 m .67553 .73234 L .65445 .72708 L p .707 .577 .707 r
F P
0 g
s
.65149 .6888 m .65485 .65053 L .64202 .64793 L p .707 .577 .707 r
F P
0 g
s
.65445 .72708 m .65385 .74595 L .67492 .7512 L p .707 .577 .707 r
F P
0 g
s
.83745 .57942 m .83444 .63647 L .84141 .63245 L p .707 .577 .707 r
F P
0 g
s
.84141 .63245 m .84442 .5754 L .83745 .57942 L p .707 .577 .707 r
F P
0 g
s
.81934 .73424 m .81874 .7531 L .83506 .74834 L p .707 .577 .707 r
F P
0 g
s
.83506 .74834 m .83567 .72947 L .81934 .73424 L p .707 .577 .707 r
F P
0 g
s
.64074 .62473 m .64375 .56768 L .64075 .56306 L p .707 .577 .707 r
F P
0 g
s
.83532 .66543 m .83195 .7037 L .83871 .70271 L p .707 .577 .707 r
F P
0 g
s
.83871 .70271 m .84207 .66444 L .83532 .66543 L p .707 .577 .707 r
F P
0 g
s
.64075 .56306 m .63774 .62011 L .64074 .62473 L p .707 .577 .707 r
F P
0 g
s
.65385 .74595 m .65445 .72708 L .64183 .72106 L p .707 .577 .707 r
F P
0 g
s
.64183 .72106 m .64122 .73993 L .65385 .74595 L p .707 .577 .707 r
F P
0 g
s
.63866 .6862 m .64202 .64793 L .63883 .64605 L p .707 .577 .707 r
F P
0 g
s
.63883 .64605 m .63547 .68432 L .63866 .6862 L p .707 .577 .707 r
F P
0 g
s
.84442 .5754 m .84141 .63245 L .83841 .62784 L p .707 .577 .707 r
F P
0 g
s
.83841 .62784 m .84142 .57079 L .84442 .5754 L p .707 .577 .707 r
F P
0 g
s
.83567 .72947 m .83506 .74834 L .8421 .74258 L p .707 .577 .707 r
F P
0 g
s
.8421 .74258 m .84271 .72371 L .83567 .72947 L p .707 .577 .707 r
F P
0 g
s
.63774 .62011 m .64075 .56306 L .64772 .55905 L p .707 .577 .707 r
F P
0 g
s
.64122 .73993 m .64183 .72106 L .63889 .71487 L p .707 .577 .707 r
F P
0 g
s
.84207 .66444 m .83871 .70271 L .83551 .70083 L p .707 .577 .707 r
F P
0 g
s
.83551 .70083 m .83888 .66256 L .84207 .66444 L p .707 .577 .707 r
F P
0 g
s
.64772 .55905 m .64471 .6161 L .63774 .62011 L p .707 .577 .707 r
F P
0 g
s
.63889 .71487 m .63829 .73373 L .64122 .73993 L p .707 .577 .707 r
F P
0 g
s
.63547 .68432 m .63883 .64605 L .64558 .64506 L p .707 .577 .707 r
F P
0 g
s
.64558 .64506 m .64222 .68333 L .63547 .68432 L p .707 .577 .707 r
F P
0 g
s
.84142 .57079 m .83841 .62784 L .82573 .62307 L p .707 .577 .707 r
F P
0 g
s
.82573 .62307 m .82874 .56602 L .84142 .57079 L p .707 .577 .707 r
F P
0 g
s
.39015 .60343 m .39316 .54638 L .36201 .54379 L p .707 .577 .707 r
F P
0 g
s
.39316 .54638 m .39015 .60343 L .42193 .60465 L p .707 .577 .707 r
F P
0 g
s
.42193 .60465 m .42494 .5476 L .39316 .54638 L p .707 .577 .707 r
F P
0 g
s
.84271 .72371 m .8421 .74258 L .83917 .73639 L p .707 .577 .707 r
F P
0 g
s
.83917 .73639 m .83977 .71752 L .84271 .72371 L p .707 .577 .707 r
F P
0 g
s
.42494 .5476 m .42193 .60465 L .45123 .60439 L p .707 .577 .707 r
F P
0 g
s
.45123 .60439 m .45424 .54734 L .42494 .5476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64471 .6161 m .64772 .55905 L .66397 .55604 L p .707 .577 .707 r
F P
0 g
s
.35899 .60084 m .36201 .54379 L .33453 .54008 L p .707 .577 .707 r
F P
0 g
s
.36201 .54379 m .35899 .60084 L .39015 .60343 L p .707 .577 .707 r
F P
0 g
s
.63829 .73373 m .63889 .71487 L .64594 .70911 L p .707 .577 .707 r
F P
0 g
s
.66397 .55604 m .66096 .61309 L .64471 .6161 L p .707 .577 .707 r
F P
0 g
s
.83888 .66256 m .83551 .70083 L .82268 .69823 L p .707 .577 .707 r
F P
0 g
s
.82268 .69823 m .82605 .65996 L .83888 .66256 L p .707 .577 .707 r
F P
0 g
s
.33453 .54008 m .33152 .59713 L .35899 .60084 L p .707 .577 .707 r
F P
0 g
s
.64594 .70911 m .64533 .72797 L .63829 .73373 L p .707 .577 .707 r
F P
0 g
s
.45424 .54734 m .45123 .60439 L .47518 .60267 L p .707 .577 .707 r
F P
0 g
s
.47518 .60267 m .47819 .54561 L .45424 .54734 L p .707 .577 .707 r
F P
0 g
s
.38832 .66134 m .39168 .62307 L .36056 .62 L p .707 .577 .707 r
F P
0 g
s
.39168 .62307 m .38832 .66134 L .42 .66396 L p .707 .577 .707 r
F P
0 g
s
.42 .66396 m .42336 .62569 L .39168 .62307 L p .707 .577 .707 r
F P
0 g
s
.36056 .62 m .3572 .65827 L .38832 .66134 L p .707 .577 .707 r
F P
0 g
s
.44915 .66586 m .45251 .62759 L .42336 .62569 L p .707 .577 .707 r
F P
0 g
s
.33152 .59713 m .33453 .54008 L .31342 .53563 L p .707 .577 .707 r
F P
0 g
s
.82874 .56602 m .82573 .62307 L .80462 .61862 L p .707 .577 .707 r
F P
0 g
s
.80462 .61862 m .80763 .56157 L .82874 .56602 L p .707 .577 .707 r
F P
0 g
s
.64222 .68333 m .64558 .64506 L .66162 .64508 L p .707 .577 .707 r
F P
0 g
s
.3572 .65827 m .36056 .62 L .33305 .61678 L p .707 .577 .707 r
F P
0 g
s
.66162 .64508 m .65826 .68335 L .64222 .68333 L p .707 .577 .707 r
F P
0 g
s
.33305 .61678 m .32969 .65505 L .3572 .65827 L p .707 .577 .707 r
F P
0 g
s
.31342 .53563 m .31041 .59268 L .33152 .59713 L p .707 .577 .707 r
F P
0 g
s
.83977 .71752 m .83917 .73639 L .82655 .73037 L p .707 .577 .707 r
F P
0 g
s
.82655 .73037 m .82715 .7115 L .83977 .71752 L p .707 .577 .707 r
F P
0 g
s
.66096 .61309 m .66397 .55604 L .68792 .55431 L p .707 .577 .707 r
F P
0 g
s
.45251 .62759 m .44915 .66586 L .4729 .66687 L p .707 .577 .707 r
F P
0 g
s
.4729 .66687 m .47627 .6286 L .45251 .62759 L p .707 .577 .707 r
F P
0 g
s
.47819 .54561 m .47518 .60267 L .49143 .59965 L p .707 .577 .707 r
F P
0 g
s
.49143 .59965 m .49444 .5426 L .47819 .54561 L p .707 .577 .707 r
F P
0 g
s
.39054 .72068 m .39115 .70182 L .35998 .6995 L p .707 .577 .707 r
F P
0 g
s
.39115 .70182 m .39054 .72068 L .42236 .7211 L p .707 .577 .707 r
F P
0 g
s
.42236 .7211 m .42296 .70224 L .39115 .70182 L p .707 .577 .707 r
F P
0 g
s
.32969 .65505 m .33305 .61678 L .31184 .61372 L p .707 .577 .707 r
F P
0 g
s
.68792 .55431 m .68491 .61136 L .66096 .61309 L p .707 .577 .707 r
F P
0 g
s
.42296 .70224 m .42236 .7211 L .45171 .71959 L p .707 .577 .707 r
F P
0 g
s
.45171 .71959 m .45232 .70072 L .42296 .70224 L p .707 .577 .707 r
F P
0 g
s
.35998 .6995 m .35938 .71837 L .39054 .72068 L p .707 .577 .707 r
F P
0 g
s
.31184 .61372 m .30848 .65199 L .32969 .65505 L p .707 .577 .707 r
F P
0 g
s
.64533 .72797 m .64594 .70911 L .66226 .70434 L p .707 .577 .707 r
F P
0 g
s
.82605 .65996 m .82268 .69823 L .80148 .69517 L p .707 .577 .707 r
F P
0 g
s
.80148 .69517 m .80484 .6569 L .82605 .65996 L p .707 .577 .707 r
F P
0 g
s
.35938 .71837 m .35998 .6995 L .33252 .69552 L p .707 .577 .707 r
F P
0 g
s
.31041 .59268 m .31342 .53563 L .30074 .53086 L p .707 .577 .707 r
F P
0 g
s
.66226 .70434 m .66166 .72321 L .64533 .72797 L p .707 .577 .707 r
F P
0 g
s
.80763 .56157 m .80462 .61862 L .77714 .61492 L p .707 .577 .707 r
F P
0 g
s
.77714 .61492 m .78016 .55787 L .80763 .56157 L p .707 .577 .707 r
F P
0 g
s
.33252 .69552 m .33191 .71439 L .35938 .71837 L p .707 .577 .707 r
F P
0 g
s
.65826 .68335 m .66162 .64508 L .68538 .64609 L p .707 .577 .707 r
F P
0 g
s
.68538 .64609 m .68202 .68436 L .65826 .68335 L p .707 .577 .707 r
F P
0 g
s
.45232 .70072 m .45171 .71959 L .47573 .71629 L p .707 .577 .707 r
F P
0 g
s
.47573 .71629 m .47633 .69742 L .45232 .70072 L p .707 .577 .707 r
F P
0 g
s
.68491 .61136 m .68792 .55431 L .71722 .55405 L p .707 .577 .707 r
F P
0 g
s
.30074 .53086 m .29773 .58791 L .31041 .59268 L p .707 .577 .707 r
F P
0 g
s
.47627 .6286 m .4729 .66687 L .48894 .66688 L p .707 .577 .707 r
F P
0 g
s
.48894 .66688 m .49231 .62861 L .47627 .6286 L p .707 .577 .707 r
F P
0 g
s
.82715 .7115 m .82655 .73037 L .80547 .72511 L p .707 .577 .707 r
F P
0 g
s
.80547 .72511 m .80608 .70624 L .82715 .7115 L p .707 .577 .707 r
F P
0 g
s
.33191 .71439 m .33252 .69552 L .31144 .69027 L p .707 .577 .707 r
F P
0 g
s
.71722 .55405 m .71421 .6111 L .68491 .61136 L p .707 .577 .707 r
F P
0 g
s
.78016 .55787 m .77714 .61492 L .74599 .61233 L p .707 .577 .707 r
F P
0 g
s
.74599 .61233 m .749 .55528 L .78016 .55787 L p .707 .577 .707 r
F P
0 g
s
.30848 .65199 m .31184 .61372 L .29901 .61112 L p .707 .577 .707 r
F P
0 g
s
.31144 .69027 m .31084 .70913 L .33191 .71439 L p .707 .577 .707 r
F P
0 g
s
.49444 .5426 m .49143 .59965 L .4984 .59564 L p .707 .577 .707 r
F P
0 g
s
.4984 .59564 m .50141 .53859 L .49444 .5426 L p .707 .577 .707 r
F P
0 g
s
.29901 .61112 m .29565 .64939 L .30848 .65199 L p .707 .577 .707 r
F P
0 g
s
.80484 .6569 m .80148 .69517 L .77397 .69194 L p .707 .577 .707 r
F P
0 g
s
.77397 .69194 m .77733 .65368 L .80484 .6569 L p .707 .577 .707 r
F P
0 g
s
.71421 .6111 m .71722 .55405 L .749 .55528 L p .707 .577 .707 r
F P
0 g
s
.66166 .72321 m .66226 .70434 L .68628 .70104 L p .707 .577 .707 r
F P
0 g
s
.749 .55528 m .74599 .61233 L .71421 .6111 L p .707 .577 .707 r
F P
0 g
s
.68202 .68436 m .68538 .64609 L .71453 .64799 L p .707 .577 .707 r
F P
0 g
s
.68628 .70104 m .68567 .71991 L .66166 .72321 L p .707 .577 .707 r
F P
0 g
s
.47633 .69742 m .47573 .71629 L .49205 .71152 L p .707 .577 .707 r
F P
0 g
s
.49205 .71152 m .49266 .69266 L .47633 .69742 L p .707 .577 .707 r
F P
0 g
s
.71453 .64799 m .71116 .68626 L .68202 .68436 L p .707 .577 .707 r
F P
0 g
s
.29773 .58791 m .30074 .53086 L .29774 .52625 L p .707 .577 .707 r
F P
0 g
s
.77733 .65368 m .77397 .69194 L .74285 .68888 L p .707 .577 .707 r
F P
0 g
s
.74285 .68888 m .74621 .65061 L .77733 .65368 L p .707 .577 .707 r
F P
0 g
s
.49231 .62861 m .48894 .66688 L .4957 .6659 L p .707 .577 .707 r
F P
0 g
s
.4957 .6659 m .49906 .62763 L .49231 .62861 L p .707 .577 .707 r
F P
0 g
s
.29774 .52625 m .29473 .5833 L .29773 .58791 L p .707 .577 .707 r
F P
0 g
s
.80608 .70624 m .80547 .72511 L .77801 .72113 L p .707 .577 .707 r
F P
0 g
s
.77801 .72113 m .77861 .70226 L .80608 .70624 L p .707 .577 .707 r
F P
0 g
s
.31084 .70913 m .31144 .69027 L .29882 .68425 L p .707 .577 .707 r
F P
0 g
s
.71116 .68626 m .71453 .64799 L .74621 .65061 L p .707 .577 .707 r
F P
0 g
s
.74621 .65061 m .74285 .68888 L .71116 .68626 L p .707 .577 .707 r
F P
0 g
s
.29882 .68425 m .29821 .70311 L .31084 .70913 L p .707 .577 .707 r
F P
0 g
s
.68567 .71991 m .68628 .70104 L .71563 .69953 L p .707 .577 .707 r
F P
0 g
s
.29565 .64939 m .29901 .61112 L .29582 .60923 L p .707 .577 .707 r
F P
0 g
s
.71563 .69953 m .71502 .7184 L .68567 .71991 L p .707 .577 .707 r
F P
0 g
s
.29582 .60923 m .29246 .6475 L .29565 .64939 L p .707 .577 .707 r
F P
0 g
s
.50141 .53859 m .4984 .59564 L .4954 .59102 L p .707 .577 .707 r
F P
0 g
s
.4954 .59102 m .49841 .53397 L .50141 .53859 L p .707 .577 .707 r
F P
0 g
s
.77861 .70226 m .77801 .72113 L .74684 .71882 L p .707 .577 .707 r
F P
0 g
s
.74684 .71882 m .74745 .69995 L .77861 .70226 L p .707 .577 .707 r
F P
0 g
s
.49266 .69266 m .49205 .71152 L .49909 .70576 L p .707 .577 .707 r
F P
0 g
s
.49909 .70576 m .4997 .6869 L .49266 .69266 L p .707 .577 .707 r
F P
0 g
s
.71502 .7184 m .71563 .69953 L .74745 .69995 L p .707 .577 .707 r
F P
0 g
s
.74745 .69995 m .74684 .71882 L .71502 .7184 L p .707 .577 .707 r
F P
0 g
s
.29473 .5833 m .29774 .52625 L .30471 .52224 L p .707 .577 .707 r
F P
0 g
s
.29821 .70311 m .29882 .68425 L .29588 .67805 L p .707 .577 .707 r
F P
0 g
s
.49906 .62763 m .4957 .6659 L .4925 .66401 L p .707 .577 .707 r
F P
0 g
s
.4925 .66401 m .49587 .62575 L .49906 .62763 L p .707 .577 .707 r
F P
0 g
s
.30471 .52224 m .3017 .57929 L .29473 .5833 L p .707 .577 .707 r
F P
0 g
s
.29588 .67805 m .29528 .69692 L .29821 .70311 L p .707 .577 .707 r
F P
0 g
s
.29246 .6475 m .29582 .60923 L .30257 .60825 L p .707 .577 .707 r
F P
0 g
s
.30257 .60825 m .29921 .64652 L .29246 .6475 L p .707 .577 .707 r
F P
0 g
s
.49841 .53397 m .4954 .59102 L .48272 .58626 L p .707 .577 .707 r
F P
0 g
s
.48272 .58626 m .48573 .52921 L .49841 .53397 L p .707 .577 .707 r
F P
0 g
s
.4997 .6869 m .49909 .70576 L .49616 .69957 L p .707 .577 .707 r
F P
0 g
s
.49616 .69957 m .49676 .6807 L .4997 .6869 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3017 .57929 m .30471 .52224 L .32096 .51922 L p .707 .577 .707 r
F P
0 g
s
.29528 .69692 m .29588 .67805 L .30292 .67229 L p .707 .577 .707 r
F P
0 g
s
.32096 .51922 m .31795 .57627 L .3017 .57929 L p .707 .577 .707 r
F P
0 g
s
.49587 .62575 m .4925 .66401 L .47967 .66141 L p .707 .577 .707 r
F P
0 g
s
.47967 .66141 m .48304 .62314 L .49587 .62575 L p .707 .577 .707 r
F P
0 g
s
.30292 .67229 m .30232 .69116 L .29528 .69692 L p .707 .577 .707 r
F P
0 g
s
.48573 .52921 m .48272 .58626 L .46161 .5818 L p .707 .577 .707 r
F P
0 g
s
.46161 .5818 m .46462 .52475 L .48573 .52921 L p .707 .577 .707 r
F P
0 g
s
.29921 .64652 m .30257 .60825 L .31861 .60826 L p .707 .577 .707 r
F P
0 g
s
.31861 .60826 m .31525 .64653 L .29921 .64652 L p .707 .577 .707 r
F P
0 g
s
.49676 .6807 m .49616 .69957 L .48354 .69355 L p .707 .577 .707 r
F P
0 g
s
.48354 .69355 m .48414 .67468 L .49676 .6807 L p .707 .577 .707 r
F P
0 g
s
.31795 .57627 m .32096 .51922 L .34491 .5175 L p .707 .577 .707 r
F P
0 g
s
.34491 .5175 m .3419 .57455 L .31795 .57627 L p .707 .577 .707 r
F P
0 g
s
.30232 .69116 m .30292 .67229 L .31925 .66753 L p .707 .577 .707 r
F P
0 g
s
.48304 .62314 m .47967 .66141 L .45847 .65835 L p .707 .577 .707 r
F P
0 g
s
.45847 .65835 m .46183 .62008 L .48304 .62314 L p .707 .577 .707 r
F P
0 g
s
.31925 .66753 m .31865 .6864 L .30232 .69116 L p .707 .577 .707 r
F P
0 g
s
.46462 .52475 m .46161 .5818 L .43413 .5781 L p .707 .577 .707 r
F P
0 g
s
.43413 .5781 m .43715 .52105 L .46462 .52475 L p .707 .577 .707 r
F P
0 g
s
.31525 .64653 m .31861 .60826 L .34237 .60927 L p .707 .577 .707 r
F P
0 g
s
.34237 .60927 m .33901 .64754 L .31525 .64653 L p .707 .577 .707 r
F P
0 g
s
.3419 .57455 m .34491 .5175 L .37421 .51724 L p .707 .577 .707 r
F P
0 g
s
.48414 .67468 m .48354 .69355 L .46246 .68829 L p .707 .577 .707 r
F P
0 g
s
.46246 .68829 m .46307 .66943 L .48414 .67468 L p .707 .577 .707 r
F P
0 g
s
.37421 .51724 m .3712 .57429 L .3419 .57455 L p .707 .577 .707 r
F P
0 g
s
.43715 .52105 m .43413 .5781 L .40298 .57551 L p .707 .577 .707 r
F P
0 g
s
.40298 .57551 m .40599 .51846 L .43715 .52105 L p .707 .577 .707 r
F P
0 g
s
.46183 .62008 m .45847 .65835 L .43096 .65513 L p .707 .577 .707 r
F P
0 g
s
.43096 .65513 m .43432 .61686 L .46183 .62008 L p .707 .577 .707 r
F P
0 g
s
.3712 .57429 m .37421 .51724 L .40599 .51846 L p .707 .577 .707 r
F P
0 g
s
.31865 .6864 m .31925 .66753 L .34327 .66423 L p .707 .577 .707 r
F P
0 g
s
.40599 .51846 m .40298 .57551 L .3712 .57429 L p .707 .577 .707 r
F P
0 g
s
.33901 .64754 m .34237 .60927 L .37151 .61118 L p .707 .577 .707 r
F P
0 g
s
.34327 .66423 m .34266 .68309 L .31865 .6864 L p .707 .577 .707 r
F P
0 g
s
.37151 .61118 m .36815 .64944 L .33901 .64754 L p .707 .577 .707 r
F P
0 g
s
.43432 .61686 m .43096 .65513 L .39984 .65206 L p .707 .577 .707 r
F P
0 g
s
.39984 .65206 m .4032 .61379 L .43432 .61686 L p .707 .577 .707 r
F P
0 g
s
.46307 .66943 m .46246 .68829 L .435 .68431 L p .707 .577 .707 r
F P
0 g
s
.435 .68431 m .4356 .66545 L .46307 .66943 L p .707 .577 .707 r
F P
0 g
s
.36815 .64944 m .37151 .61118 L .4032 .61379 L p .707 .577 .707 r
F P
0 g
s
.4032 .61379 m .39984 .65206 L .36815 .64944 L p .707 .577 .707 r
F P
0 g
s
.34266 .68309 m .34327 .66423 L .37262 .66271 L p .707 .577 .707 r
F P
0 g
s
.37262 .66271 m .37201 .68158 L .34266 .68309 L p .707 .577 .707 r
F P
0 g
s
.4356 .66545 m .435 .68431 L .40383 .682 L p .707 .577 .707 r
F P
0 g
s
.40383 .682 m .40444 .66313 L .4356 .66545 L p .707 .577 .707 r
F P
0 g
s
.37201 .68158 m .37262 .66271 L .40444 .66313 L p .707 .577 .707 r
F P
0 g
s
.40444 .66313 m .40383 .682 L .37201 .68158 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooah007io
o`00Ngoo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00N7oo001fOol50008
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001dOol007=oo`<00003FUH005YF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001bOol006moo`@0
00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001_Ool006eoo`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8006eoo`00Jgoo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00Jgoo001YOol20002FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02001YOol006Moo`8000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Ioo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF06Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYFIWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP00009JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00FGoo80002eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001FOol30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05Aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00
E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolI0014Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`02Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH8000lOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`00=Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool005=oo`03001JEP00009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPL000=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005=oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0
009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Ioo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005]oo`L000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2000/Ool0069oo`P000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool006Eoo`05001JEUYF001J
EP0P0007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`P000Moo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`<000=JEP04001JEUYFFUH@00000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP04001JEUYF
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90002FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEQ0000AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool003QooaT000=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPP000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF1P0015YF00@005YFFUIJEP8002eoo`00;goo2@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30000
0eYF001JEP02FUH2000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH2000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo00<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol00goo1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`0:Ool90004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF2@00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`0COolI000hOol002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0000L000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEQ8005Ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH9001=Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH00UYF4000?Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000fOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01@00<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000K0005FUH00`00FUIJEP03FUH8
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000<002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF5P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPL000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00@005YFFUIJEQ0000AJ
EP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF00000UYF1`001eYF00<005YFFUH01EYF40000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000AJEP04001JEUYFFUH90002FUH00`00FUIJEP02FUH50004FUH80004
FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00004@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00H005YFFUH005YF0002FUH60002FUH400000eYF00000002
FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01`000eYF00<005YFFUH015YF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;goo100015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00D005YFFUH005YF00H000EJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP09FUH300000eYF001JEP02FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJ
EP070002FUH00`00FUH00002FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP03
0002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJ
EUYF0P00;Woo000]OolA00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@001EYF00<005YFFUH01UYF00<005YFFUH025YF1@000UYF0`0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00eYF00@005YFFUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEQ<000=JEP05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUHI0003FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00P000=JEP03
001JEUYF009JEQ@000=JEP04001JEUYFFUH4000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL00003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00000010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd002moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF
0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0004FUH00`00FUIJEP02FUH700000eYF
001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJ
EP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH01000FUIJEUYF
2@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0003FUH:0002FUH20007Ool50004Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEP00FUH005YF00<000EJEP04001JEUYFFUH40007Ool5000<Ool60003
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P0000=JEP00FUH00`000UYF00<0
05YFFUH00UYF0`0027oo0`004goo10000eYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH0
0UYF1@000UYF00<005YF00007Goo1`0000=JEP000000;Goo000/OolJ0004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF2P0035YF2@0025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF
FUH015YF00@005YFFUIJEPP0019oo`P0009JEP03001JEUYF009JEP<002eoo`00;goo10000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJEP0:FUH0
0`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000c
OolT0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
1@000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00<0
05YFFUH00UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000bOol50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>0003FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF
00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00AJEP8000AJEP03001JEUYF00=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002moo`<00003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH;0002FUH20002
FUH00`00FUIJEP04FUH400000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH020000UYF00<005YFFUH00UYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF009JEP03
001JEUYF00=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP<00005Ool005YFFUH00002FUH20007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJEP8000=ooaT003Qoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P000UYF0`0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00@005YFFUIJEP8005Aoo`00;Goo0P000eYF3@004Goo200015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YF
FUH015YF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8002Ioo`H000AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03
001JEUYF009JEP8005Aoo`00;7oo00<005YF00001@0057oo0`004goo0`0000=JEP00FUH00UYF0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000E7oo000/Ool20003FUH00`00FUIJEP07000<Ool5000EOol30002FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eo
o`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT000=oo`D0015oo`D0009JEP<00003FUH0
05YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF6@00
0eYF00T005YFFUIJEP00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1`000eYF00@005YFFUIJEP8005Eoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH20003FUH:0002FUH2001EOol0031oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
00000goo00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUH0000200000eYF
00000002001EOol003Aoo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF008000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000MJEP03001JEUYF009JEPD005Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEPH000Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20000
0eYF001JEP05FUH00`00FUIJEP04FUH01000FUH00000EGoo000mOolP000>Ool30007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP080003FUH00`00FUIJEP04FUH01000FUIJEP00EGoo001]Ool20006FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH30008Ool50004FUH01000
FUIJEUYF0P00E7oo001_Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH3000?Ool300000eYF001JEP02FUH2001DOol0075oo`<00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D001Eo
o`8000=JEP8005Aoo`00M7oo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
1@0000=oo`0000000`004Goo1`0000=JEP000000E7oo001hOol60002FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH01000FUIJEUYF8P000UYF00<005YFFUH00UYF0`00E7oo001nOol90006FUH00`00FUIJ
EP04FUH90003FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUH0001DOol008Moo`d000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00U7oo0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`00
EWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
1P00FGoo002LOol90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001OOol00:Eooa8006Ioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59702 .75788 m .59401 .70487 L .56285 .70364 L p .707 .577 .707 r
F P
0 g
s
.59401 .70487 m .59702 .75788 L .6288 .75518 L p .707 .577 .707 r
F P
0 g
s
.6288 .75518 m .62579 .70217 L .59401 .70487 L p .707 .577 .707 r
F P
0 g
s
.62579 .70217 m .6288 .75518 L .6581 .74879 L p .707 .577 .707 r
F P
0 g
s
.6581 .74879 m .65509 .69578 L .62579 .70217 L p .707 .577 .707 r
F P
0 g
s
.56586 .75665 m .56285 .70364 L .53538 .69858 L p .707 .577 .707 r
F P
0 g
s
.56285 .70364 m .56586 .75665 L .59702 .75788 L p .707 .577 .707 r
F P
0 g
s
.65509 .69578 m .6581 .74879 L .68205 .73936 L p .707 .577 .707 r
F P
0 g
s
.68205 .73936 m .67903 .68635 L .65509 .69578 L p .707 .577 .707 r
F P
0 g
s
.53839 .75159 m .53538 .69858 L .51427 .6902 L p .707 .577 .707 r
F P
0 g
s
.53538 .69858 m .53839 .75159 L .56586 .75665 L p .707 .577 .707 r
F P
0 g
s
.67903 .68635 m .68205 .73936 L .6983 .72779 L p .707 .577 .707 r
F P
0 g
s
.6983 .72779 m .69529 .67478 L .67903 .68635 L p .707 .577 .707 r
F P
0 g
s
.60016 .83021 m .5968 .79646 L .56568 .79565 L p .707 .577 .707 r
F P
0 g
s
.5968 .79646 m .60016 .83021 L .63184 .82625 L p .707 .577 .707 r
F P
0 g
s
.63184 .82625 m .62848 .79249 L .5968 .79646 L p .707 .577 .707 r
F P
0 g
s
.62848 .79249 m .63184 .82625 L .66099 .8179 L p .707 .577 .707 r
F P
0 g
s
.66099 .8179 m .65763 .78414 L .62848 .79249 L p .707 .577 .707 r
F P
0 g
s
.56904 .82941 m .56568 .79565 L .53817 .79016 L p .707 .577 .707 r
F P
0 g
s
.56568 .79565 m .56904 .82941 L .60016 .83021 L p .707 .577 .707 r
F P
0 g
s
.59617 .86551 m .59556 .84746 L .5644 .84596 L p .707 .577 .707 r
F P
0 g
s
.59556 .84746 m .59617 .86551 L .62798 .86356 L p .707 .577 .707 r
F P
0 g
s
.62798 .86356 m .62738 .84551 L .59556 .84746 L p .707 .577 .707 r
F P
0 g
s
.65763 .78414 m .66099 .8179 L .68475 .80599 L p .707 .577 .707 r
F P
0 g
s
.68475 .80599 m .68138 .77223 L .65763 .78414 L p .707 .577 .707 r
F P
0 g
s
.51728 .74321 m .51427 .6902 L .50159 .67931 L p .707 .577 .707 r
F P
0 g
s
.51427 .6902 m .51728 .74321 L .53839 .75159 L p .707 .577 .707 r
F P
0 g
s
.62738 .84551 m .62798 .86356 L .65733 .85836 L p .707 .577 .707 r
F P
0 g
s
.65733 .85836 m .65673 .84031 L .62738 .84551 L p .707 .577 .707 r
F P
0 g
s
.5644 .84596 m .565 .86401 L .59617 .86551 L p .707 .577 .707 r
F P
0 g
s
.565 .86401 m .5644 .84596 L .53693 .84116 L p .707 .577 .707 r
F P
0 g
s
.54153 .82392 m .53817 .79016 L .51696 .78052 L p .707 .577 .707 r
F P
0 g
s
.53817 .79016 m .54153 .82392 L .56904 .82941 L p .707 .577 .707 r
F P
0 g
s
.69529 .67478 m .6983 .72779 L .70527 .71523 L p .707 .577 .707 r
F P
0 g
s
.70527 .71523 m .70225 .66222 L .69529 .67478 L p .707 .577 .707 r
F P
0 g
s
.53693 .84116 m .53754 .85922 L .565 .86401 L p .707 .577 .707 r
F P
0 g
s
.65673 .84031 m .65733 .85836 L .68135 .85041 L p .707 .577 .707 r
F P
0 g
s
.68135 .85041 m .68074 .83236 L .65673 .84031 L p .707 .577 .707 r
F P
0 g
s
.68138 .77223 m .68475 .80599 L .70079 .79169 L p .707 .577 .707 r
F P
0 g
s
.70079 .79169 m .69742 .75793 L .68138 .77223 L p .707 .577 .707 r
F P
0 g
s
.53754 .85922 m .53693 .84116 L .51586 .83354 L p .707 .577 .707 r
F P
0 g
s
.50159 .67931 m .5046 .73232 L .51728 .74321 L p .707 .577 .707 r
F P
0 g
s
.5046 .73232 m .50159 .67931 L .49859 .66698 L p .707 .577 .707 r
F P
0 g
s
.51586 .83354 m .51646 .85159 L .53754 .85922 L p .707 .577 .707 r
F P
0 g
s
.51696 .78052 m .52032 .81428 L .54153 .82392 L p .707 .577 .707 r
F P
0 g
s
.52032 .81428 m .51696 .78052 L .50413 .76767 L p .707 .577 .707 r
F P
0 g
s
.68074 .83236 m .68135 .85041 L .69768 .8405 L p .707 .577 .707 r
F P
0 g
s
.69768 .8405 m .69707 .82244 L .68074 .83236 L p .707 .577 .707 r
F P
0 g
s
.70225 .66222 m .70527 .71523 L .70226 .7029 L p .707 .577 .707 r
F P
0 g
s
.70226 .7029 m .69925 .64989 L .70225 .66222 L p .707 .577 .707 r
F P
0 g
s
.69742 .75793 m .70079 .79169 L .70754 .77638 L p .707 .577 .707 r
F P
0 g
s
.70754 .77638 m .70418 .74263 L .69742 .75793 L p .707 .577 .707 r
F P
0 g
s
.51646 .85159 m .51586 .83354 L .50323 .82383 L p .707 .577 .707 r
F P
0 g
s
.49859 .66698 m .5016 .71999 L .5046 .73232 L p .707 .577 .707 r
F P
0 g
s
.50413 .76767 m .50749 .80143 L .52032 .81428 L p .707 .577 .707 r
F P
0 g
s
.50323 .82383 m .50384 .84189 L .51646 .85159 L p .707 .577 .707 r
F P
0 g
s
.5016 .71999 m .49859 .66698 L .50556 .65442 L p .707 .577 .707 r
F P
0 g
s
.69707 .82244 m .69768 .8405 L .70472 .82959 L p .707 .577 .707 r
F P
0 g
s
.70472 .82959 m .70411 .81153 L .69707 .82244 L p .707 .577 .707 r
F P
0 g
s
.50749 .80143 m .50413 .76767 L .50094 .75287 L p .707 .577 .707 r
F P
0 g
s
.48443 .81898 m .49406 .31125 L .45005 .30823 L p .707 .577 .707 r
F P
0 g
s
.50384 .84189 m .50323 .82383 L .5003 .81299 L p .707 .577 .707 r
F P
0 g
s
.50094 .75287 m .5043 .78662 L .50749 .80143 L p .707 .577 .707 r
F P
0 g
s
.5003 .81299 m .5009 .83105 L .50384 .84189 L p .707 .577 .707 r
F P
0 g
s
.50556 .65442 m .50857 .70743 L .5016 .71999 L p .707 .577 .707 r
F P
0 g
s
.50857 .70743 m .50556 .65442 L .52181 .64285 L p .707 .577 .707 r
F P
0 g
s
.5043 .78662 m .50094 .75287 L .50769 .73756 L p .707 .577 .707 r
F P
0 g
s
.5009 .83105 m .5003 .81299 L .50734 .80208 L p .707 .577 .707 r
F P
0 g
s
.50769 .73756 m .51105 .77132 L .5043 .78662 L p .707 .577 .707 r
F P
0 g
s
.52181 .64285 m .52482 .69586 L .50857 .70743 L p .707 .577 .707 r
F P
0 g
s
.50734 .80208 m .50795 .82013 L .5009 .83105 L p .707 .577 .707 r
F P
0 g
s
.51105 .77132 m .50769 .73756 L .52373 .72326 L p .707 .577 .707 r
F P
0 g
s
.50795 .82013 m .50734 .80208 L .52367 .79216 L p .707 .577 .707 r
F P
0 g
s
.52373 .72326 m .52709 .75702 L .51105 .77132 L p .707 .577 .707 r
F P
0 g
s
.52367 .79216 m .52427 .81022 L .50795 .82013 L p .707 .577 .707 r
F P
0 g
s
.52427 .81022 m .52367 .79216 L .54768 .78422 L p .707 .577 .707 r
F P
0 g
s
.54768 .78422 m .54829 .80227 L .52427 .81022 L p .707 .577 .707 r
F P
0 g
s
.49406 .31125 m .48443 .81898 L .52937 .81887 L p .707 .577 .707 r
F P
0 g
s
.52482 .69586 m .52181 .64285 L .54576 .63342 L p .707 .577 .707 r
F P
0 g
s
.54576 .63342 m .54877 .68643 L .52482 .69586 L p .707 .577 .707 r
F P
0 g
s
.52709 .75702 m .52373 .72326 L .54749 .71135 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .55085 .74511 L .52709 .75702 L p .707 .577 .707 r
F P
0 g
s
.52937 .81887 m .53899 .31115 L .49406 .31125 L p .707 .577 .707 r
F P
0 g
s
.70418 .74263 m .70754 .77638 L .70435 .76158 L p .707 .577 .707 r
F P
0 g
s
.70435 .76158 m .70098 .72782 L .70418 .74263 L p .707 .577 .707 r
F P
0 g
s
.69925 .64989 m .70226 .7029 L .68959 .69201 L p .707 .577 .707 r
F P
0 g
s
.68959 .69201 m .68658 .639 L .69925 .64989 L p .707 .577 .707 r
F P
0 g
s
.54877 .68643 m .54576 .63342 L .57506 .62703 L p .707 .577 .707 r
F P
0 g
s
.57506 .62703 m .57807 .68004 L .54877 .68643 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .57663 .703 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.55085 .74511 m .54846 .72107 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.54846 .72107 m .54749 .71135 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.57807 .68004 m .57506 .62703 L .60684 .62433 L p .707 .577 .707 r
F P
0 g
s
.60684 .62433 m .60985 .67734 L .57807 .68004 L p .707 .577 .707 r
F P
0 g
s
.58 .73676 m .57663 .703 L .60832 .69904 L p .707 .577 .707 r
F P
0 g
s
.57663 .703 m .58 .73676 L .55085 .74511 L p .707 .577 .707 r
F P
0 g
s
.60832 .69904 m .61168 .73279 L .58 .73676 L p .707 .577 .707 r
F P
0 g
s
.57764 .79707 m .57703 .77901 L .60885 .77706 L p .707 .577 .707 r
F P
0 g
s
.60885 .77706 m .60946 .79512 L .57764 .79707 L p .707 .577 .707 r
F P
0 g
s
.58046 .30791 m .57187 .76116 L p .60477 .8096 L .707 .577 .707 r
F P
0 g
s
.54829 .80227 m .54768 .78422 L .57703 .77901 L p .707 .577 .707 r
F P
0 g
s
.57703 .77901 m .57764 .79707 L .54829 .80227 L p .707 .577 .707 r
F P
0 g
s
.57187 .76116 m .57083 .81564 L .60059 .81035 L p .707 .577 .707 r
F P
0 g
s
.60059 .81035 m .60477 .8096 L p .57187 .76116 L .707 .577 .707 r
F P
0 g
s
.53899 .31115 m .52937 .81887 L .57083 .81564 L p .707 .577 .707 r
F P
0 g
s
.57083 .81564 m .58046 .30791 L .53899 .31115 L p .707 .577 .707 r
F P
0 g
s
.44043 .81596 m .45005 .30823 L .41129 .30237 L p .707 .577 .707 r
F P
0 g
s
.45005 .30823 m .44043 .81596 L .48443 .81898 L p .707 .577 .707 r
F P
0 g
s
.70411 .81153 m .70472 .82959 L .70178 .81875 L p .707 .577 .707 r
F P
0 g
s
.70178 .81875 m .70118 .80069 L .70411 .81153 L p .707 .577 .707 r
F P
0 g
s
.25401 .72107 m .251 .66806 L .21984 .66682 L p .707 .577 .707 r
F P
0 g
s
.251 .66806 m .25401 .72107 L .28579 .71836 L p .707 .577 .707 r
F P
0 g
s
.28579 .71836 m .28278 .66535 L .251 .66806 L p .707 .577 .707 r
F P
0 g
s
.60985 .67734 m .60684 .62433 L .63799 .62556 L p .707 .577 .707 r
F P
0 g
s
.60477 .8096 m .6144 .30188 L .58046 .30791 L p .707 .577 .707 r
F P
0 g
s
.28278 .66535 m .28579 .71836 L .31509 .71198 L p .707 .577 .707 r
F P
0 g
s
.31509 .71198 m .31208 .65897 L .28278 .66535 L p .707 .577 .707 r
F P
0 g
s
.22285 .71983 m .21984 .66682 L .19237 .66176 L p .707 .577 .707 r
F P
0 g
s
.21984 .66682 m .22285 .71983 L .25401 .72107 L p .707 .577 .707 r
F P
0 g
s
.70098 .72782 m .70435 .76158 L .69152 .74873 L p .707 .577 .707 r
F P
0 g
s
.69152 .74873 m .68816 .71497 L .70098 .72782 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68658 .639 m .68959 .69201 L .66848 .68363 L p .707 .577 .707 r
F P
0 g
s
.66848 .68363 m .66547 .63062 L .68658 .639 L p .707 .577 .707 r
F P
0 g
s
.40166 .8101 m .41129 .30237 L .38155 .29425 L p .707 .577 .707 r
F P
0 g
s
.41129 .30237 m .40166 .8101 L .44043 .81596 L p .707 .577 .707 r
F P
0 g
s
.31208 .65897 m .31509 .71198 L .33904 .70254 L p .707 .577 .707 r
F P
0 g
s
.33904 .70254 m .33603 .64953 L .31208 .65897 L p .707 .577 .707 r
F P
0 g
s
.19538 .71477 m .19237 .66176 L .17126 .65338 L p .707 .577 .707 r
F P
0 g
s
.19237 .66176 m .19538 .71477 L .22285 .71983 L p .707 .577 .707 r
F P
0 g
s
.63799 .62556 m .641 .67857 L .60985 .67734 L p .707 .577 .707 r
F P
0 g
s
.63944 .69984 m .6428 .7336 L .61168 .73279 L p .707 .577 .707 r
F P
0 g
s
.61168 .73279 m .60832 .69904 L .63944 .69984 L p .707 .577 .707 r
F P
0 g
s
.64002 .77856 m .64062 .79662 L .60946 .79512 L p .707 .577 .707 r
F P
0 g
s
.60946 .79512 m .60885 .77706 L .64002 .77856 L p .707 .577 .707 r
F P
0 g
s
.6144 .30188 m .60477 .8096 L .62786 .80135 L p .707 .577 .707 r
F P
0 g
s
.62786 .80135 m .63749 .29363 L .6144 .30188 L p .707 .577 .707 r
F P
0 g
s
.70118 .80069 m .70178 .81875 L .68916 .80904 L p .707 .577 .707 r
F P
0 g
s
.68916 .80904 m .68856 .79098 L .70118 .80069 L p .707 .577 .707 r
F P
0 g
s
.33603 .64953 m .33904 .70254 L .35529 .69098 L p .707 .577 .707 r
F P
0 g
s
.35529 .69098 m .35228 .63797 L .33603 .64953 L p .707 .577 .707 r
F P
0 g
s
.66547 .63062 m .66848 .68363 L .641 .67857 L p .707 .577 .707 r
F P
0 g
s
.641 .67857 m .63799 .62556 L .66547 .63062 L p .707 .577 .707 r
F P
0 g
s
.25715 .7934 m .25379 .75964 L .22267 .75884 L p .707 .577 .707 r
F P
0 g
s
.25379 .75964 m .25715 .7934 L .28884 .78943 L p .707 .577 .707 r
F P
0 g
s
.28884 .78943 m .28547 .75567 L .25379 .75964 L p .707 .577 .707 r
F P
0 g
s
.28547 .75567 m .28884 .78943 L .31798 .78109 L p .707 .577 .707 r
F P
0 g
s
.31798 .78109 m .31462 .74733 L .28547 .75567 L p .707 .577 .707 r
F P
0 g
s
.68816 .71497 m .69152 .74873 L .67031 .73909 L p .707 .577 .707 r
F P
0 g
s
.67031 .73909 m .66695 .70533 L .68816 .71497 L p .707 .577 .707 r
F P
0 g
s
.22603 .7926 m .22267 .75884 L .19516 .75335 L p .707 .577 .707 r
F P
0 g
s
.22267 .75884 m .22603 .7926 L .25715 .7934 L p .707 .577 .707 r
F P
0 g
s
.37192 .80197 m .38155 .29425 L .36376 .28466 L p .707 .577 .707 r
F P
0 g
s
.38155 .29425 m .37192 .80197 L .40166 .8101 L p .707 .577 .707 r
F P
0 g
s
.25316 .8287 m .25255 .81064 L .22139 .80914 L p .707 .577 .707 r
F P
0 g
s
.25255 .81064 m .25316 .8287 L .28497 .82675 L p .707 .577 .707 r
F P
0 g
s
.28497 .82675 m .28437 .80869 L .25255 .81064 L p .707 .577 .707 r
F P
0 g
s
.31462 .74733 m .31798 .78109 L .34174 .76918 L p .707 .577 .707 r
F P
0 g
s
.34174 .76918 m .33838 .73542 L .31462 .74733 L p .707 .577 .707 r
F P
0 g
s
.17427 .70639 m .17126 .65338 L .15858 .64249 L p .707 .577 .707 r
F P
0 g
s
.17126 .65338 m .17427 .70639 L .19538 .71477 L p .707 .577 .707 r
F P
0 g
s
.28437 .80869 m .28497 .82675 L .31433 .82155 L p .707 .577 .707 r
F P
0 g
s
.31433 .82155 m .31372 .80349 L .28437 .80869 L p .707 .577 .707 r
F P
0 g
s
.22139 .80914 m .22199 .8272 L .25316 .8287 L p .707 .577 .707 r
F P
0 g
s
.22199 .8272 m .22139 .80914 L .19392 .80435 L p .707 .577 .707 r
F P
0 g
s
.19852 .78711 m .19516 .75335 L .17395 .7437 L p .707 .577 .707 r
F P
0 g
s
.19516 .75335 m .19852 .78711 L .22603 .7926 L p .707 .577 .707 r
F P
0 g
s
.35228 .63797 m .35529 .69098 L .36226 .67841 L p .707 .577 .707 r
F P
0 g
s
.36226 .67841 m .35924 .6254 L .35228 .63797 L p .707 .577 .707 r
F P
0 g
s
.66695 .70533 m .67031 .73909 L .6428 .7336 L p .707 .577 .707 r
F P
0 g
s
.6428 .7336 m .63944 .69984 L .66695 .70533 L p .707 .577 .707 r
F P
0 g
s
.19392 .80435 m .19453 .8224 L .22199 .8272 L p .707 .577 .707 r
F P
0 g
s
.68856 .79098 m .68916 .80904 L .66809 .80141 L p .707 .577 .707 r
F P
0 g
s
.66809 .80141 m .66748 .78336 L .68856 .79098 L p .707 .577 .707 r
F P
0 g
s
.31372 .80349 m .31433 .82155 L .33834 .8136 L p .707 .577 .707 r
F P
0 g
s
.33834 .8136 m .33774 .79554 L .31372 .80349 L p .707 .577 .707 r
F P
0 g
s
.33838 .73542 m .34174 .76918 L .35778 .75487 L p .707 .577 .707 r
F P
0 g
s
.35778 .75487 m .35441 .72111 L .33838 .73542 L p .707 .577 .707 r
F P
0 g
s
.19453 .8224 m .19392 .80435 L .17285 .79672 L p .707 .577 .707 r
F P
0 g
s
.63749 .29363 m .62786 .80135 L .63784 .79169 L p .707 .577 .707 r
F P
0 g
s
.63784 .79169 m .64747 .28397 L .63749 .29363 L p .707 .577 .707 r
F P
0 g
s
.15858 .64249 m .16159 .6955 L .17427 .70639 L p .707 .577 .707 r
F P
0 g
s
.16159 .6955 m .15858 .64249 L .15558 .63016 L p .707 .577 .707 r
F P
0 g
s
.17285 .79672 m .17345 .81478 L .19453 .8224 L p .707 .577 .707 r
F P
0 g
s
.17395 .7437 m .17731 .77746 L .19852 .78711 L p .707 .577 .707 r
F P
0 g
s
.17731 .77746 m .17395 .7437 L .16112 .73085 L p .707 .577 .707 r
F P
0 g
s
.33774 .79554 m .33834 .8136 L .35467 .80368 L p .707 .577 .707 r
F P
0 g
s
.35467 .80368 m .35406 .78563 L .33774 .79554 L p .707 .577 .707 r
F P
0 g
s
.66748 .78336 m .66809 .80141 L .64062 .79662 L p .707 .577 .707 r
F P
0 g
s
.64062 .79662 m .64002 .77856 L .66748 .78336 L p .707 .577 .707 r
F P
0 g
s
.35926 .66609 m .35624 .61308 L .35924 .6254 L p .707 .577 .707 r
F P
0 g
s
.35441 .72111 m .35778 .75487 L .36453 .73957 L p .707 .577 .707 r
F P
0 g
s
.36453 .73957 m .36117 .70581 L .35441 .72111 L p .707 .577 .707 r
F P
0 g
s
.35406 .78563 m .35467 .80368 L .36171 .79277 L p .707 .577 .707 r
F P
0 g
s
.36171 .79277 m .3611 .77472 L .35406 .78563 L p .707 .577 .707 r
F P
0 g
s
.35624 .61308 m .35926 .66609 L .34658 .6552 L p .707 .577 .707 r
F P
0 g
s
.34658 .6552 m .34357 .60219 L .35624 .61308 L p .707 .577 .707 r
F P
0 g
s
.35797 .69101 m .35894 .70073 L p .34851 .71192 L .707 .577 .707 r
F P
0 g
s
.35894 .70073 m .36134 .72477 L .35695 .72037 L p .707 .577 .707 r
F P
0 g
s
.35695 .72037 m .34851 .71192 L p .35894 .70073 L .707 .577 .707 r
F P
0 g
s
.34851 .71192 m .34515 .67816 L .35797 .69101 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35965 .27454 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35817 .76388 m .35877 .78193 L .34615 .77222 L p .707 .577 .707 r
F P
0 g
s
.34615 .77222 m .34555 .75417 L .35817 .76388 L p .707 .577 .707 r
F P
0 g
s
.35413 .79238 m .35517 .7379 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35517 .7379 m .36376 .28466 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35924 .6254 m .36226 .67841 L .35926 .66609 L p .707 .577 .707 r
F P
0 g
s
.36117 .70581 m .36453 .73957 L .36134 .72477 L p .707 .577 .707 r
F P
0 g
s
.36134 .72477 m .35797 .69101 L .36117 .70581 L p .707 .577 .707 r
F P
0 g
s
.3611 .77472 m .36171 .79277 L .35877 .78193 L p .707 .577 .707 r
F P
0 g
s
.35877 .78193 m .35817 .76388 L .3611 .77472 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35413 .79238 L .37192 .80197 L p .707 .577 .707 r
F P
0 g
s
.17345 .81478 m .17285 .79672 L .16022 .78702 L p .707 .577 .707 r
F P
0 g
s
.15558 .63016 m .15859 .68317 L .16159 .6955 L p .707 .577 .707 r
F P
0 g
s
.16112 .73085 m .16449 .76461 L .17731 .77746 L p .707 .577 .707 r
F P
0 g
s
.16022 .78702 m .16083 .80507 L .17345 .81478 L p .707 .577 .707 r
F P
0 g
s
.15859 .68317 m .15558 .63016 L .16255 .6176 L p .707 .577 .707 r
F P
0 g
s
.16449 .76461 m .16112 .73085 L .15793 .71605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64747 .28397 m .63784 .79169 L .63373 .78157 L p .707 .577 .707 r
F P
0 g
s
.63373 .78157 m .64336 .27385 L .64747 .28397 L p .707 .577 .707 r
F P
0 g
s
.16083 .80507 m .16022 .78702 L .15729 .77618 L p .707 .577 .707 r
F P
0 g
s
.15793 .71605 m .16129 .74981 L .16449 .76461 L p .707 .577 .707 r
F P
0 g
s
.15729 .77618 m .1579 .79423 L .16083 .80507 L p .707 .577 .707 r
F P
0 g
s
.16255 .6176 m .16556 .67061 L .15859 .68317 L p .707 .577 .707 r
F P
0 g
s
.35965 .27454 m .35002 .78226 L .35413 .79238 L p .707 .577 .707 r
F P
0 g
s
.35002 .78226 m .35965 .27454 L .36963 .26488 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16556 .67061 m .16255 .6176 L .1788 .60604 L p .707 .577 .707 r
F P
0 g
s
.16129 .74981 m .15793 .71605 L .16468 .70075 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34357 .60219 m .34658 .6552 L .32547 .64681 L p .707 .577 .707 r
F P
0 g
s
.32547 .64681 m .32246 .5938 L .34357 .60219 L p .707 .577 .707 r
F P
0 g
s
.1579 .79423 m .15729 .77618 L .16433 .76526 L p .707 .577 .707 r
F P
0 g
s
.16468 .70075 m .16805 .73451 L .16129 .74981 L p .707 .577 .707 r
F P
0 g
s
.1788 .60604 m .18181 .65905 L .16556 .67061 L p .707 .577 .707 r
F P
0 g
s
.16433 .76526 m .16494 .78332 L .1579 .79423 L p .707 .577 .707 r
F P
0 g
s
.64336 .27385 m .63373 .78157 L .61594 .77198 L p .707 .577 .707 r
F P
0 g
s
.61594 .77198 m .62557 .26426 L .64336 .27385 L p .707 .577 .707 r
F P
0 g
s
.18181 .65905 m .1788 .60604 L .20275 .5966 L p .707 .577 .707 r
F P
0 g
s
.16805 .73451 m .16468 .70075 L .18072 .68644 L p .707 .577 .707 r
F P
0 g
s
.32246 .5938 m .32547 .64681 L .29799 .64176 L p .707 .577 .707 r
F P
0 g
s
.29799 .64176 m .29498 .58875 L .32246 .5938 L p .707 .577 .707 r
F P
0 g
s
.34515 .67816 m .34851 .71192 L .3273 .70227 L p .707 .577 .707 r
F P
0 g
s
.3273 .70227 m .32394 .66851 L .34515 .67816 L p .707 .577 .707 r
F P
0 g
s
.36 .7726 m .36963 .26488 L .39272 .25663 L p .707 .577 .707 r
F P
0 g
s
.36963 .26488 m .36 .7726 L .35002 .78226 L p .707 .577 .707 r
F P
0 g
s
.20576 .64961 m .20275 .5966 L .23205 .59022 L p .707 .577 .707 r
F P
0 g
s
.20275 .5966 m .20576 .64961 L .18181 .65905 L p .707 .577 .707 r
F P
0 g
s
.16494 .78332 m .16433 .76526 L .18066 .75535 L p .707 .577 .707 r
F P
0 g
s
.18072 .68644 m .18408 .7202 L .16805 .73451 L p .707 .577 .707 r
F P
0 g
s
.29498 .58875 m .29799 .64176 L .26684 .64052 L p .707 .577 .707 r
F P
0 g
s
.26684 .64052 m .26383 .58751 L .29498 .58875 L p .707 .577 .707 r
F P
0 g
s
.18066 .75535 m .18126 .7734 L .16494 .78332 L p .707 .577 .707 r
F P
0 g
s
.18408 .7202 m .18072 .68644 L .20448 .67453 L p .707 .577 .707 r
F P
0 g
s
.23506 .64323 m .23205 .59022 L .26383 .58751 L p .707 .577 .707 r
F P
0 g
s
.23205 .59022 m .23506 .64323 L .20576 .64961 L p .707 .577 .707 r
F P
0 g
s
.26383 .58751 m .26684 .64052 L .23506 .64323 L p .707 .577 .707 r
F P
0 g
s
.32394 .66851 m .3273 .70227 L .29979 .69678 L p .707 .577 .707 r
F P
0 g
s
.29979 .69678 m .29643 .66302 L .32394 .66851 L p .707 .577 .707 r
F P
0 g
s
.34555 .75417 m .34615 .77222 L .32508 .7646 L p .707 .577 .707 r
F P
0 g
s
.32508 .7646 m .32447 .74654 L .34555 .75417 L p .707 .577 .707 r
F P
0 g
s
.62557 .26426 m .61594 .77198 L .5862 .76386 L p .707 .577 .707 r
F P
0 g
s
.5862 .76386 m .59583 .25613 L .62557 .26426 L p .707 .577 .707 r
F P
0 g
s
.20784 .70829 m .20448 .67453 L .23362 .66619 L p .707 .577 .707 r
F P
0 g
s
.20448 .67453 m .20784 .70829 L .18408 .7202 L p .707 .577 .707 r
F P
0 g
s
.73422 .67364 m .73121 .62063 L .70006 .61939 L p .707 .577 .707 r
F P
0 g
s
.73121 .62063 m .73422 .67364 L .766 .67093 L p .707 .577 .707 r
F P
0 g
s
.766 .67093 m .76299 .61792 L .73121 .62063 L p .707 .577 .707 r
F P
0 g
s
.18126 .7734 m .18066 .75535 L .20467 .7474 L p .707 .577 .707 r
F P
0 g
s
.76299 .61792 m .766 .67093 L .7953 .66455 L p .707 .577 .707 r
F P
0 g
s
.7953 .66455 m .79229 .61154 L .76299 .61792 L p .707 .577 .707 r
F P
0 g
s
.29643 .66302 m .29979 .69678 L .26867 .69598 L p .707 .577 .707 r
F P
0 g
s
.26867 .69598 m .26531 .66222 L .29643 .66302 L p .707 .577 .707 r
F P
0 g
s
.70307 .6724 m .70006 .61939 L .67258 .61434 L p .707 .577 .707 r
F P
0 g
s
.70006 .61939 m .70307 .6724 L .73422 .67364 L p .707 .577 .707 r
F P
0 g
s
.20467 .7474 m .20528 .76546 L .18126 .7734 L p .707 .577 .707 r
F P
0 g
s
.39272 .25663 m .38309 .76435 L .36 .7726 L p .707 .577 .707 r
F P
0 g
s
.38309 .76435 m .39272 .25663 L .42666 .25059 L p .707 .577 .707 r
F P
0 g
s
.23699 .69995 m .23362 .66619 L .26531 .66222 L p .707 .577 .707 r
F P
0 g
s
.23362 .66619 m .23699 .69995 L .20784 .70829 L p .707 .577 .707 r
F P
0 g
s
.26531 .66222 m .26867 .69598 L .23699 .69995 L p .707 .577 .707 r
F P
0 g
s
.32447 .74654 m .32508 .7646 L .29761 .7598 L p .707 .577 .707 r
F P
0 g
s
.29761 .7598 m .29701 .74175 L .32447 .74654 L p .707 .577 .707 r
F P
0 g
s
.79229 .61154 m .7953 .66455 L .81925 .65511 L p .707 .577 .707 r
F P
0 g
s
.81925 .65511 m .81624 .6021 L .79229 .61154 L p .707 .577 .707 r
F P
0 g
s
.20528 .76546 m .20467 .7474 L .23402 .7422 L p .707 .577 .707 r
F P
0 g
s
.67559 .66735 m .67258 .61434 L .65147 .60595 L p .707 .577 .707 r
F P
0 g
s
.67258 .61434 m .67559 .66735 L .70307 .6724 L p .707 .577 .707 r
F P
0 g
s
.59583 .25613 m .5862 .76386 L .54744 .758 L p .707 .577 .707 r
F P
0 g
s
.54744 .758 m .55706 .25027 L .59583 .25613 L p .707 .577 .707 r
F P
0 g
s
.23402 .7422 m .23463 .76025 L .20528 .76546 L p .707 .577 .707 r
F P
0 g
s
.29701 .74175 m .29761 .7598 L .26645 .7583 L p .707 .577 .707 r
F P
0 g
s
.26645 .7583 m .26584 .74025 L .29701 .74175 L p .707 .577 .707 r
F P
0 g
s
.73736 .73508 m .734 .70132 L .70288 .70052 L p .707 .577 .707 r
F P
0 g
s
.734 .70132 m .73736 .73508 L .76905 .73111 L p .707 .577 .707 r
F P
0 g
s
.76905 .73111 m .76569 .69736 L .734 .70132 L p .707 .577 .707 r
F P
0 g
s
.76569 .69736 m .76905 .73111 L .7982 .72277 L p .707 .577 .707 r
F P
0 g
s
.7982 .72277 m .79483 .68901 L .76569 .69736 L p .707 .577 .707 r
F P
0 g
s
.81624 .6021 m .81925 .65511 L .8355 .64355 L p .707 .577 .707 r
F P
0 g
s
.8355 .64355 m .83249 .59054 L .81624 .6021 L p .707 .577 .707 r
F P
0 g
s
.23463 .76025 m .23402 .7422 L .26584 .74025 L p .707 .577 .707 r
F P
0 g
s
.26584 .74025 m .26645 .7583 L .23463 .76025 L p .707 .577 .707 r
F P
0 g
s
.70624 .73428 m .70288 .70052 L .67537 .69503 L p .707 .577 .707 r
F P
0 g
s
.70288 .70052 m .70624 .73428 L .73736 .73508 L p .707 .577 .707 r
F P
0 g
s
.41703 .75831 m .42666 .25059 L .46812 .24736 L p .707 .577 .707 r
F P
0 g
s
.42666 .25059 m .41703 .75831 L .38309 .76435 L p .707 .577 .707 r
F P
0 g
s
.73337 .76157 m .73277 .74352 L .7016 .74202 L p .707 .577 .707 r
F P
0 g
s
.73277 .74352 m .73337 .76157 L .76519 .75962 L p .707 .577 .707 r
F P
0 g
s
.76519 .75962 m .76458 .74157 L .73277 .74352 L p .707 .577 .707 r
F P
0 g
s
.76458 .74157 m .76519 .75962 L .79454 .75442 L p .707 .577 .707 r
F P
0 g
s
.79454 .75442 m .79393 .73637 L .76458 .74157 L p .707 .577 .707 r
F P
0 g
s
.79483 .68901 m .7982 .72277 L .82195 .71086 L p .707 .577 .707 r
F P
0 g
s
.82195 .71086 m .81859 .6771 L .79483 .68901 L p .707 .577 .707 r
F P
0 g
s
.7016 .74202 m .70221 .76007 L .73337 .76157 L p .707 .577 .707 r
F P
0 g
s
.65448 .65896 m .65147 .60595 L .63879 .59507 L p .707 .577 .707 r
F P
0 g
s
.65147 .60595 m .65448 .65896 L .67559 .66735 L p .707 .577 .707 r
F P
0 g
s
.70221 .76007 m .7016 .74202 L .67414 .73722 L p .707 .577 .707 r
F P
0 g
s
.55706 .25027 m .54744 .758 L .50343 .75498 L p .707 .577 .707 r
F P
0 g
s
.50343 .75498 m .51306 .24725 L .55706 .25027 L p .707 .577 .707 r
F P
0 g
s
.67414 .73722 m .67474 .75528 L .70221 .76007 L p .707 .577 .707 r
F P
0 g
s
.79393 .73637 m .79454 .75442 L .81855 .74647 L p .707 .577 .707 r
F P
0 g
s
.81855 .74647 m .81795 .72842 L .79393 .73637 L p .707 .577 .707 r
F P
0 g
s
.67873 .72879 m .67537 .69503 L .65416 .68539 L p .707 .577 .707 r
F P
0 g
s
.67537 .69503 m .67873 .72879 L .70624 .73428 L p .707 .577 .707 r
F P
0 g
s
.4585 .75508 m .46812 .24736 L .51306 .24725 L p .707 .577 .707 r
F P
0 g
s
.46812 .24736 m .4585 .75508 L .41703 .75831 L p .707 .577 .707 r
F P
0 g
s
.83249 .59054 m .8355 .64355 L .84247 .63099 L p .707 .577 .707 r
F P
0 g
s
.84247 .63099 m .83946 .57798 L .83249 .59054 L p .707 .577 .707 r
F P
0 g
s
.51306 .24725 m .50343 .75498 L .4585 .75508 L p .707 .577 .707 r
F P
0 g
s
.81859 .6771 m .82195 .71086 L .83799 .69655 L p .707 .577 .707 r
F P
0 g
s
.83799 .69655 m .83463 .6628 L .81859 .6771 L p .707 .577 .707 r
F P
0 g
s
.67474 .75528 m .67414 .73722 L .65306 .7296 L p .707 .577 .707 r
F P
0 g
s
.65306 .7296 m .65367 .74765 L .67474 .75528 L p .707 .577 .707 r
F P
0 g
s
.63879 .59507 m .64181 .64808 L .65448 .65896 L p .707 .577 .707 r
F P
0 g
s
.65416 .68539 m .65753 .71914 L .67873 .72879 L p .707 .577 .707 r
F P
0 g
s
.81795 .72842 m .81855 .74647 L .83488 .73656 L p .707 .577 .707 r
F P
0 g
s
.83488 .73656 m .83428 .7185 L .81795 .72842 L p .707 .577 .707 r
F P
0 g
s
.64181 .64808 m .63879 .59507 L .63579 .58274 L p .707 .577 .707 r
F P
0 g
s
.65753 .71914 m .65416 .68539 L .64134 .67254 L p .707 .577 .707 r
F P
0 g
s
.83463 .6628 m .83799 .69655 L .84474 .68125 L p .707 .577 .707 r
F P
0 g
s
.84474 .68125 m .84138 .64749 L .83463 .6628 L p .707 .577 .707 r
F P
0 g
s
.65367 .74765 m .65306 .7296 L .64044 .71989 L p .707 .577 .707 r
F P
0 g
s
.83946 .57798 m .84247 .63099 L .83947 .61866 L p .707 .577 .707 r
F P
0 g
s
.83947 .61866 m .83646 .56565 L .83946 .57798 L p .707 .577 .707 r
F P
0 g
s
.64044 .71989 m .64104 .73795 L .65367 .74765 L p .707 .577 .707 r
F P
0 g
s
.64134 .67254 m .6447 .70629 L .65753 .71914 L p .707 .577 .707 r
F P
0 g
s
.63579 .58274 m .6388 .63575 L .64181 .64808 L p .707 .577 .707 r
F P
0 g
s
.83428 .7185 m .83488 .73656 L .84192 .72565 L p .707 .577 .707 r
F P
0 g
s
.84192 .72565 m .84132 .70759 L .83428 .7185 L p .707 .577 .707 r
F P
0 g
s
.6447 .70629 m .64134 .67254 L .63814 .65773 L p .707 .577 .707 r
F P
0 g
s
.6388 .63575 m .63579 .58274 L .64276 .57018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84138 .64749 m .84474 .68125 L .84155 .66645 L p .707 .577 .707 r
F P
0 g
s
.84155 .66645 m .83819 .63269 L .84138 .64749 L p .707 .577 .707 r
F P
0 g
s
.64104 .73795 m .64044 .71989 L .6375 .70905 L p .707 .577 .707 r
F P
0 g
s
.83646 .56565 m .83947 .61866 L .82679 .60777 L p .707 .577 .707 r
F P
0 g
s
.82679 .60777 m .82378 .55476 L .83646 .56565 L p .707 .577 .707 r
F P
0 g
s
.6375 .70905 m .63811 .72711 L .64104 .73795 L p .707 .577 .707 r
F P
0 g
s
.63814 .65773 m .64151 .69149 L .6447 .70629 L p .707 .577 .707 r
F P
0 g
s
.64276 .57018 m .64577 .62319 L .6388 .63575 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84132 .70759 m .84192 .72565 L .83899 .7148 L p .707 .577 .707 r
F P
0 g
s
.83899 .7148 m .83838 .69675 L .84132 .70759 L p .707 .577 .707 r
F P
0 g
s
.64151 .69149 m .63814 .65773 L .6449 .64243 L p .707 .577 .707 r
F P
0 g
s
.64577 .62319 m .64276 .57018 L .65901 .55861 L p .707 .577 .707 r
F P
0 g
s
.39121 .63682 m .3882 .58381 L .35705 .58258 L p .707 .577 .707 r
F P
0 g
s
.3882 .58381 m .39121 .63682 L .42299 .63412 L p .707 .577 .707 r
F P
0 g
s
.42299 .63412 m .41998 .58111 L .3882 .58381 L p .707 .577 .707 r
F P
0 g
s
.41998 .58111 m .42299 .63412 L .45229 .62773 L p .707 .577 .707 r
F P
0 g
s
.45229 .62773 m .44928 .57472 L .41998 .58111 L p .707 .577 .707 r
F P
0 g
s
.83819 .63269 m .84155 .66645 L .82872 .6536 L p .707 .577 .707 r
F P
0 g
s
.82872 .6536 m .82536 .61984 L .83819 .63269 L p .707 .577 .707 r
F P
0 g
s
.36006 .63559 m .35705 .58258 L .32957 .57752 L p .707 .577 .707 r
F P
0 g
s
.35705 .58258 m .36006 .63559 L .39121 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63811 .72711 m .6375 .70905 L .64454 .69814 L p .707 .577 .707 r
F P
0 g
s
.82378 .55476 m .82679 .60777 L .80568 .59939 L p .707 .577 .707 r
F P
0 g
s
.80568 .59939 m .80267 .54638 L .82378 .55476 L p .707 .577 .707 r
F P
0 g
s
.44928 .57472 m .45229 .62773 L .47624 .6183 L p .707 .577 .707 r
F P
0 g
s
.47624 .6183 m .47323 .56529 L .44928 .57472 L p .707 .577 .707 r
F P
0 g
s
.6449 .64243 m .64826 .67619 L .64151 .69149 L p .707 .577 .707 r
F P
0 g
s
.64454 .69814 m .64515 .71619 L .63811 .72711 L p .707 .577 .707 r
F P
0 g
s
.65901 .55861 m .66202 .61162 L .64577 .62319 L p .707 .577 .707 r
F P
0 g
s
.33258 .63053 m .32957 .57752 L .30846 .56914 L p .707 .577 .707 r
F P
0 g
s
.32957 .57752 m .33258 .63053 L .36006 .63559 L p .707 .577 .707 r
F P
0 g
s
.66202 .61162 m .65901 .55861 L .68296 .54917 L p .707 .577 .707 r
F P
0 g
s
.64826 .67619 m .6449 .64243 L .66094 .62812 L p .707 .577 .707 r
F P
0 g
s
.83838 .69675 m .83899 .7148 L .82637 .7051 L p .707 .577 .707 r
F P
0 g
s
.82637 .7051 m .82576 .68704 L .83838 .69675 L p .707 .577 .707 r
F P
0 g
s
.39435 .69827 m .39099 .66451 L .35987 .66371 L p .707 .577 .707 r
F P
0 g
s
.39099 .66451 m .39435 .69827 L .42604 .6943 L p .707 .577 .707 r
F P
0 g
s
.42604 .6943 m .42268 .66054 L .39099 .66451 L p .707 .577 .707 r
F P
0 g
s
.42268 .66054 m .42604 .6943 L .45519 .68595 L p .707 .577 .707 r
F P
0 g
s
.45519 .68595 m .45182 .65219 L .42268 .66054 L p .707 .577 .707 r
F P
0 g
s
.47323 .56529 m .47624 .6183 L .49249 .60673 L p .707 .577 .707 r
F P
0 g
s
.49249 .60673 m .48948 .55372 L .47323 .56529 L p .707 .577 .707 r
F P
0 g
s
.82536 .61984 m .82872 .6536 L .80752 .64395 L p .707 .577 .707 r
F P
0 g
s
.80752 .64395 m .80415 .6102 L .82536 .61984 L p .707 .577 .707 r
F P
0 g
s
.80267 .54638 m .80568 .59939 L .77821 .59433 L p .707 .577 .707 r
F P
0 g
s
.77821 .59433 m .7752 .54132 L .80267 .54638 L p .707 .577 .707 r
F P
0 g
s
.36323 .69746 m .35987 .66371 L .33236 .65821 L p .707 .577 .707 r
F P
0 g
s
.35987 .66371 m .36323 .69746 L .39435 .69827 L p .707 .577 .707 r
F P
0 g
s
.39036 .72476 m .38976 .7067 L .35859 .7052 L p .707 .577 .707 r
F P
0 g
s
.38976 .7067 m .39036 .72476 L .42218 .72281 L p .707 .577 .707 r
F P
0 g
s
.42218 .72281 m .42157 .70475 L .38976 .7067 L p .707 .577 .707 r
F P
0 g
s
.64515 .71619 m .64454 .69814 L .66087 .68822 L p .707 .577 .707 r
F P
0 g
s
.42157 .70475 m .42218 .72281 L .45153 .71761 L p .707 .577 .707 r
F P
0 g
s
.45153 .71761 m .45092 .69955 L .42157 .70475 L p .707 .577 .707 r
F P
0 g
s
.45182 .65219 m .45519 .68595 L .47894 .67404 L p .707 .577 .707 r
F P
0 g
s
.47894 .67404 m .47558 .64029 L .45182 .65219 L p .707 .577 .707 r
F P
0 g
s
.66094 .62812 m .6643 .66188 L .64826 .67619 L p .707 .577 .707 r
F P
0 g
s
.68597 .60219 m .68296 .54917 L .71226 .54279 L p .707 .577 .707 r
F P
0 g
s
.68296 .54917 m .68597 .60219 L .66202 .61162 L p .707 .577 .707 r
F P
0 g
s
.35859 .7052 m .3592 .72326 L .39036 .72476 L p .707 .577 .707 r
F P
0 g
s
.66087 .68822 m .66148 .70628 L .64515 .71619 L p .707 .577 .707 r
F P
0 g
s
.31147 .62215 m .30846 .56914 L .29578 .55825 L p .707 .577 .707 r
F P
0 g
s
.30846 .56914 m .31147 .62215 L .33258 .63053 L p .707 .577 .707 r
F P
0 g
s
.3592 .72326 m .35859 .7052 L .33113 .70041 L p .707 .577 .707 r
F P
0 g
s
.6643 .66188 m .66094 .62812 L .68469 .61622 L p .707 .577 .707 r
F P
0 g
s
.7752 .54132 m .77821 .59433 L .74705 .5931 L p .707 .577 .707 r
F P
0 g
s
.74705 .5931 m .74404 .54008 L .7752 .54132 L p .707 .577 .707 r
F P
0 g
s
.33113 .70041 m .33173 .71846 L .3592 .72326 L p .707 .577 .707 r
F P
0 g
s
.82576 .68704 m .82637 .7051 L .80529 .69747 L p .707 .577 .707 r
F P
0 g
s
.80529 .69747 m .80469 .67942 L .82576 .68704 L p .707 .577 .707 r
F P
0 g
s
.45092 .69955 m .45153 .71761 L .47554 .70966 L p .707 .577 .707 r
F P
0 g
s
.47554 .70966 m .47494 .6916 L .45092 .69955 L p .707 .577 .707 r
F P
0 g
s
.33572 .69197 m .33236 .65821 L .31115 .64857 L p .707 .577 .707 r
F P
0 g
s
.33236 .65821 m .33572 .69197 L .36323 .69746 L p .707 .577 .707 r
F P
0 g
s
.71527 .5958 m .71226 .54279 L .74404 .54008 L p .707 .577 .707 r
F P
0 g
s
.71226 .54279 m .71527 .5958 L .68597 .60219 L p .707 .577 .707 r
F P
0 g
s
.80415 .6102 m .80752 .64395 L .78001 .63846 L p .707 .577 .707 r
F P
0 g
s
.78001 .63846 m .77664 .6047 L .80415 .6102 L p .707 .577 .707 r
F P
0 g
s
.74404 .54008 m .74705 .5931 L .71527 .5958 L p .707 .577 .707 r
F P
0 g
s
.48948 .55372 m .49249 .60673 L .49946 .59417 L p .707 .577 .707 r
F P
0 g
s
.49946 .59417 m .49645 .54116 L .48948 .55372 L p .707 .577 .707 r
F P
0 g
s
.47558 .64029 m .47894 .67404 L .49498 .65974 L p .707 .577 .707 r
F P
0 g
s
.49498 .65974 m .49162 .62598 L .47558 .64029 L p .707 .577 .707 r
F P
0 g
s
.33173 .71846 m .33113 .70041 L .31005 .69278 L p .707 .577 .707 r
F P
0 g
s
.66148 .70628 m .66087 .68822 L .68489 .68027 L p .707 .577 .707 r
F P
0 g
s
.68805 .64997 m .68469 .61622 L .71384 .60787 L p .707 .577 .707 r
F P
0 g
s
.68469 .61622 m .68805 .64997 L .6643 .66188 L p .707 .577 .707 r
F P
0 g
s
.31005 .69278 m .31066 .71084 L .33173 .71846 L p .707 .577 .707 r
F P
0 g
s
.29578 .55825 m .2988 .61126 L .31147 .62215 L p .707 .577 .707 r
F P
0 g
s
.77664 .6047 m .78001 .63846 L .74889 .63766 L p .707 .577 .707 r
F P
0 g
s
.74889 .63766 m .74552 .6039 L .77664 .6047 L p .707 .577 .707 r
F P
0 g
s
.31115 .64857 m .31452 .68233 L .33572 .69197 L p .707 .577 .707 r
F P
0 g
s
.68489 .68027 m .68549 .69833 L .66148 .70628 L p .707 .577 .707 r
F P
0 g
s
.47494 .6916 m .47554 .70966 L .49187 .69974 L p .707 .577 .707 r
F P
0 g
s
.49187 .69974 m .49127 .68169 L .47494 .6916 L p .707 .577 .707 r
F P
0 g
s
.2988 .61126 m .29578 .55825 L .29278 .54592 L p .707 .577 .707 r
F P
0 g
s
.31452 .68233 m .31115 .64857 L .29833 .63572 L p .707 .577 .707 r
F P
0 g
s
.80469 .67942 m .80529 .69747 L .77783 .69268 L p .707 .577 .707 r
F P
0 g
s
.77783 .69268 m .77722 .67462 L .80469 .67942 L p .707 .577 .707 r
F P
0 g
s
.7172 .64163 m .71384 .60787 L .74552 .6039 L p .707 .577 .707 r
F P
0 g
s
.71384 .60787 m .7172 .64163 L .68805 .64997 L p .707 .577 .707 r
F P
0 g
s
.74552 .6039 m .74889 .63766 L .7172 .64163 L p .707 .577 .707 r
F P
0 g
s
.49162 .62598 m .49498 .65974 L .50173 .64443 L p .707 .577 .707 r
F P
0 g
s
.50173 .64443 m .49837 .61068 L .49162 .62598 L p .707 .577 .707 r
F P
0 g
s
.68549 .69833 m .68489 .68027 L .71424 .67507 L p .707 .577 .707 r
F P
0 g
s
.31066 .71084 m .31005 .69278 L .29743 .68308 L p .707 .577 .707 r
F P
0 g
s
.49645 .54116 m .49946 .59417 L .49646 .58184 L p .707 .577 .707 r
F P
0 g
s
.49646 .58184 m .49345 .52883 L .49645 .54116 L p .707 .577 .707 r
F P
0 g
s
.71424 .67507 m .71484 .69313 L .68549 .69833 L p .707 .577 .707 r
F P
0 g
s
.29743 .68308 m .29803 .70113 L .31066 .71084 L p .707 .577 .707 r
F P
0 g
s
.77722 .67462 m .77783 .69268 L .74666 .69118 L p .707 .577 .707 r
F P
0 g
s
.74666 .69118 m .74606 .67312 L .77722 .67462 L p .707 .577 .707 r
F P
0 g
s
.29833 .63572 m .30169 .66948 L .31452 .68233 L p .707 .577 .707 r
F P
0 g
s
.29278 .54592 m .29579 .59893 L .2988 .61126 L p .707 .577 .707 r
F P
0 g
s
.71484 .69313 m .71424 .67507 L .74606 .67312 L p .707 .577 .707 r
F P
0 g
s
.49127 .68169 m .49187 .69974 L .49891 .68883 L p .707 .577 .707 r
F P
0 g
s
.49891 .68883 m .49831 .67077 L .49127 .68169 L p .707 .577 .707 r
F P
0 g
s
.74606 .67312 m .74666 .69118 L .71484 .69313 L p .707 .577 .707 r
F P
0 g
s
.30169 .66948 m .29833 .63572 L .29513 .62092 L p .707 .577 .707 r
F P
0 g
s
.29579 .59893 m .29278 .54592 L .29975 .53336 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49837 .61068 m .50173 .64443 L .49854 .62963 L p .707 .577 .707 r
F P
0 g
s
.49854 .62963 m .49518 .59588 L .49837 .61068 L p .707 .577 .707 r
F P
0 g
s
.29803 .70113 m .29743 .68308 L .29449 .67223 L p .707 .577 .707 r
F P
0 g
s
.49345 .52883 m .49646 .58184 L .48378 .57096 L p .707 .577 .707 r
F P
0 g
s
.48378 .57096 m .48077 .51795 L .49345 .52883 L p .707 .577 .707 r
F P
0 g
s
.29449 .67223 m .2951 .69029 L .29803 .70113 L p .707 .577 .707 r
F P
0 g
s
.29513 .62092 m .29849 .65468 L .30169 .66948 L p .707 .577 .707 r
F P
0 g
s
.29975 .53336 m .30276 .58637 L .29579 .59893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49831 .67077 m .49891 .68883 L .49598 .67799 L p .707 .577 .707 r
F P
0 g
s
.49598 .67799 m .49537 .65993 L .49831 .67077 L p .707 .577 .707 r
F P
0 g
s
.29849 .65468 m .29513 .62092 L .30189 .60562 L p .707 .577 .707 r
F P
0 g
s
.30276 .58637 m .29975 .53336 L .316 .5218 L p .707 .577 .707 r
F P
0 g
s
.49518 .59588 m .49854 .62963 L .48571 .61678 L p .707 .577 .707 r
F P
0 g
s
.48571 .61678 m .48235 .58302 L .49518 .59588 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2951 .69029 m .29449 .67223 L .30153 .66132 L p .707 .577 .707 r
F P
0 g
s
.48077 .51795 m .48378 .57096 L .46267 .56257 L p .707 .577 .707 r
F P
0 g
s
.46267 .56257 m .45966 .50956 L .48077 .51795 L p .707 .577 .707 r
F P
0 g
s
.30189 .60562 m .30525 .63937 L .29849 .65468 L p .707 .577 .707 r
F P
0 g
s
.30153 .66132 m .30214 .67938 L .2951 .69029 L p .707 .577 .707 r
F P
0 g
s
.316 .5218 m .31901 .57481 L .30276 .58637 L p .707 .577 .707 r
F P
0 g
s
.31901 .57481 m .316 .5218 L .33995 .51236 L p .707 .577 .707 r
F P
0 g
s
.30525 .63937 m .30189 .60562 L .31793 .59131 L p .707 .577 .707 r
F P
0 g
s
.49537 .65993 m .49598 .67799 L .48336 .66828 L p .707 .577 .707 r
F P
0 g
s
.48336 .66828 m .48275 .65023 L .49537 .65993 L p .707 .577 .707 r
F P
0 g
s
.48235 .58302 m .48571 .61678 L .46451 .60714 L p .707 .577 .707 r
F P
0 g
s
.46451 .60714 m .46114 .57338 L .48235 .58302 L p .707 .577 .707 r
F P
0 g
s
.45966 .50956 m .46267 .56257 L .4352 .55752 L p .707 .577 .707 r
F P
0 g
s
.4352 .55752 m .43219 .50451 L .45966 .50956 L p .707 .577 .707 r
F P
0 g
s
.30214 .67938 m .30153 .66132 L .31786 .65141 L p .707 .577 .707 r
F P
0 g
s
.31793 .59131 m .32129 .62507 L .30525 .63937 L p .707 .577 .707 r
F P
0 g
s
.34296 .56537 m .33995 .51236 L .36925 .50598 L p .707 .577 .707 r
F P
0 g
s
.33995 .51236 m .34296 .56537 L .31901 .57481 L p .707 .577 .707 r
F P
0 g
s
.31786 .65141 m .31847 .66946 L .30214 .67938 L p .707 .577 .707 r
F P
0 g
s
.32129 .62507 m .31793 .59131 L .34168 .5794 L p .707 .577 .707 r
F P
0 g
s
.43219 .50451 m .4352 .55752 L .40404 .55628 L p .707 .577 .707 r
F P
0 g
s
.40404 .55628 m .40103 .50327 L .43219 .50451 L p .707 .577 .707 r
F P
0 g
s
.48275 .65023 m .48336 .66828 L .46228 .66066 L p .707 .577 .707 r
F P
0 g
s
.46228 .66066 m .46168 .6426 L .48275 .65023 L p .707 .577 .707 r
F P
0 g
s
.37226 .55899 m .36925 .50598 L .40103 .50327 L p .707 .577 .707 r
F P
0 g
s
.36925 .50598 m .37226 .55899 L .34296 .56537 L p .707 .577 .707 r
F P
0 g
s
.46114 .57338 m .46451 .60714 L .43699 .60165 L p .707 .577 .707 r
F P
0 g
s
.43699 .60165 m .43363 .56789 L .46114 .57338 L p .707 .577 .707 r
F P
0 g
s
.40103 .50327 m .40404 .55628 L .37226 .55899 L p .707 .577 .707 r
F P
0 g
s
.31847 .66946 m .31786 .65141 L .34188 .64346 L p .707 .577 .707 r
F P
0 g
s
.34504 .61316 m .34168 .5794 L .37083 .57105 L p .707 .577 .707 r
F P
0 g
s
.34168 .5794 m .34504 .61316 L .32129 .62507 L p .707 .577 .707 r
F P
0 g
s
.43363 .56789 m .43699 .60165 L .40587 .60085 L p .707 .577 .707 r
F P
0 g
s
.40587 .60085 m .40251 .56709 L .43363 .56789 L p .707 .577 .707 r
F P
0 g
s
.34188 .64346 m .34248 .66151 L .31847 .66946 L p .707 .577 .707 r
F P
0 g
s
.46168 .6426 m .46228 .66066 L .43482 .65586 L p .707 .577 .707 r
F P
0 g
s
.43482 .65586 m .43421 .63781 L .46168 .6426 L p .707 .577 .707 r
F P
0 g
s
.37419 .60481 m .37083 .57105 L .40251 .56709 L p .707 .577 .707 r
F P
0 g
s
.37083 .57105 m .37419 .60481 L .34504 .61316 L p .707 .577 .707 r
F P
0 g
s
.40251 .56709 m .40587 .60085 L .37419 .60481 L p .707 .577 .707 r
F P
0 g
s
.34248 .66151 m .34188 .64346 L .37123 .63826 L p .707 .577 .707 r
F P
0 g
s
.37123 .63826 m .37183 .65631 L .34248 .66151 L p .707 .577 .707 r
F P
0 g
s
.43421 .63781 m .43482 .65586 L .40365 .65436 L p .707 .577 .707 r
F P
0 g
s
.40365 .65436 m .40304 .63631 L .43421 .63781 L p .707 .577 .707 r
F P
0 g
s
.37183 .65631 m .37123 .63826 L .40304 .63631 L p .707 .577 .707 r
F P
0 g
s
.40304 .63631 m .40365 .65436 L .37183 .65631 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEP`007Uoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00
LWoo001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH01000FUH00000L7oo001[Ool300000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KGoo001YOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001ZOol006Qoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0001H0
00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00Hgoo100000=JEP00FUH025YF00<005YFFUH01EYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Ggoo10001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001M
Ool200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`l003moo`00Dgoo00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEP00008000EJEP03001J
EUYF00=JEP@0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=oo`04
001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP07FUH4
0004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`04001JEUYF0003FUH0
1000FUIJEUYF0P0017oo00@005YFFUH000EJEQ0000IJEPD00003FUH005YF009JEP04001JEUYF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;goo001COol01000FUIJEP000eYF00@005YF000000Ioo`03001JEUYF00L000AJEP03001J
EUYF00IJEP03001JEP0000D000=JEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00E7oo
00<005YF00000eYF0P0027oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1000
00=JEP00FUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF0000
0UYF00<005YFFUH020001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH000020004FUH00`00
FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000015YF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`04001JEP000005FUH20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH300001EYF001JEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaH00003FUH005YF009JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00?7oo100000=JEP00FUH025YF00<005YFFUH01EYF
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool003Qoo`@0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=J
EP03001JEUYF00AJEPL00004Ool000000005Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000fOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH200000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00@000Moo`D000aoo`D000AJEP05
001JEUYFFUH0000^Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEPT000AJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH4000:Ool?0008Ool300000eYF
001JEP02FUH00`00Oomoo`0/Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00IJEPD000EJEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YF00000P0027oo1P0015YF00<005YFFUH01UYF
00<005YF00000`0000=oo`0000000P0000AJEP00000000=JEP8002eoo`00<Goo0P001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH015YF00<005YFFUH01000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF0000009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP80
00Uoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP04001JEUYF0002
FUH2000]Ool002moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP<000EJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP800003FUH005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00<000=oo`<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF009JEP@002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF00000002FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<0
05YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0`00;Goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2000015YF00000000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH015YF0`0000=JEP00FUH01UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF000000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001J
EP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF1P0015YF00<005YFFUH01EYF1@001EYF00<005YF
FUH0100015YF00<005YFFUH015YF0P0000AJEP00000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF00=JEPT000=JEPd000QJEP03001JEUYF00=JEP04001JEP00FUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00007FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF00@005YF001JEPP000AJEP03001JEUYF009J
EPP000AJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200001EYF001JEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF3`00
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF500000=JEP00000015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH600000eYF00000003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008FUH00`00
FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP04000COol200000eYF0000000400001EYF000005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEPD000AJEP03001JEUYF008002eoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEP@001Moo`80009JEP04001oogooOol20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000015YF001JEUYF0P00;Goo000/Ool01000FUIJEP000eYF00@005YFFUIJEP8000moo`<000Uoo`04
001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF10000eYF00<007ooOol0:goo000/Ool01000FUIJEP000eYF00@0
05YF0000011oo`D000Qoo`80009JEP<000IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;Goo000]Ool00`00FUH00003FUH2000BOol5
0008Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH70004FUH50005
FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P001Woo00<005YF0000;Goo000]Ool00`00FUH00002FUH00`00FUIJ
EP05000=Ool?0004FUH00`00FUIJEP03FUHD0004FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40009Ool3000]Ool002eoo`03001JEP00008000AJEP04001JEUYFFUH=0004FUH00`00
FUIJEP06FUH20004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH0009JEP@000EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00@000aoo`800003FUH0000002aoo`00;Goo00@005YF000000EJEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000=JEP04
001JEUYFFUH400000eYF001JEP07FUH<000>Ool200000eYF001JEP02000/Ool002eoo`800003FUH0
05YF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH20004FUH00`00FUIJEP03FUH00`00FUH0000G000;Ool01P00FUIJEUYF001JEP80
02aoo`00;Goo0P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000Eoo`8000AJEP04001JEUYF000/Ool002eo
o`05001JEUYFFUH00004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUH00002FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP05FUH0
0`00FUIJEP020005FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000050002FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH500000eYF001JEP03FUH01000FUIJEP00;7oo000]Ool01@00FUIJEUYF00000UYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P0015YF00<005YF
FUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF0`001UYF0P0000AJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP000Woo1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001EYF00<0
05YF0000;7oo000]Ool01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP<00003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJ
EP<000EJEP800006FUH005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001EYF10001UYF00<005YFFUH0
15YF1@001UYF00<005YFFUH010000UYF00@005YFFUIJEP8000=JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP030006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001JEUYF
00800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPL0009JEP8000=JEP8000=JEP04
001JEUYFFUH40002FUH00`00FUIJEP05FUH30003FUH70006FUH400000eYF001JEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH9000;Ool300000eYF0000000200000eYF001JEP04FUH00`00
FUH00002000^Ool002ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000MJ
EP@000=JEP03001JEP0000<000EJEP03001JEP0000l00003FUH005YF00IJEP@000EJEP05001JEUYF
FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00UYF200037oo1P001UYF00<005YF00000P0015YF00D005YFFUIJEP00
02ioo`00;Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH0
1UYF00@005YFFUH000=JEP03001JEUYF009JEPD00005FUH005YFFUH00005FUH00`00FUIJEP07FUH0
1000FUIJEUYF10000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH00`00FUH000020004FUH@0004
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomoo`0/Ool002eoo`80
00EJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH01000FUIJEUYF60001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000AJEP800003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP8000=JEP8002eo
o`00;Goo0P001EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<0009JEP8002eoo`00;7oo00<005YF00001EYF00@005YFFUIJ
EP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF000000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002Ool4000]Ool002aoo`03001JEP0000EJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@0009oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200000eYF001JEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH40006
FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Woo0P00;Goo000/Ool01000FUIJEP0015YF0P001Goo
2@0015YF00<005YFFUH00UYF1`002Goo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00@005YF000000Moo`<002eoo`00;7oo00@005YFFUH000=JEP03001oogoo00ioo`T001Eoo`P000AJ
EP03001JEUYF00=JEPT000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP@000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00AJEP<000Moo`<00003FUH007oo02aoo`00;7oo00D005YFFUH005YF008001Aoo`D0
01Moo`04001JEUYF0003FUH:0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH200000eYF001J
EP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040008Ool20002FUH00`00FUH0000]Ool002ao
o`03001JEUYF008001Ioo`D001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEP8000=JEPH000AJEP03001JEUYF00IJEP<000AJEPD000Yoo`8000AJEP8002ioo`00
;7oo00@005YFFUH001Moo`D001Eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEP0000<000EJEPT000AJEP03001JEUYF00@000]oo`@00003FUH0
05YF00=JEP8002ioo`00;Goo00<005YF000067oo0`0057oo0P000UYF00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP<000=JEP03001JEUYF008000Aoo`L0
00Yoo`D000EJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P0000=JEP00Ool05Goo3`001goo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH005YF0005FUH00`00FUH000030002FUH2000<Ool90003FUH00`00FUIJEP04FUH00`00FUIJEP02
000`Ool002eoo`80009JEP03001oogoo00]oo`P000AJEP03001JEUYF00IJEP03001JEP0000<00003
Ool0000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol0
02eoo`04001JEUYFFUH30005Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH40002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00=7oo000]Ool20002FUH00`00FUIJEP0500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF1@000Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`00=Woo000]Ool20002FUH01000FUH000001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF60001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0027oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`00>Woo000]Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH:000;FUH0
0`00FUIJEP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000mOol002ioo`<0009JEP03001JEUYF00AJEP03001J
EUYF009JEP`000EJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00D0
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJEP03
001JEUYF009JEP8000mooaL0045oo`00;Woo00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF0P000UYF00<005YFFUH00UYF10000eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YF
FUH00UYF0P003Goo0P0000=JEP00FUH00P00Dgoo000]Ool20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP0000000UYF00<0
05YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF0P0037oo00H005YFFUIJEP00FUH2001COol002eo
o`8000AJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEPD0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJEP8000Yoo`8000AJEP04001J
EUYF001COol002aoo`03001JEP00009JEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP03001JEUYF008000Aoo`03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP8000Qoo`800003FUH005YF00=JEP04001JEUYF001COol002aoo`03001JEP000080
0003Ool0000000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP<000Io
o`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=oo`8000=JEP03001JEUYF00=JEP03001J
EP0005=oo`00;7oo00<005YF00001Goo0`0000=JEP00FUH01UYF00<005YFFUH015YF1@001UYF00<0
05YFFUH015YF0P0027oo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000
00=JEPH0009JEP03001JEUYF00=JEP8005Aoo`00;7oo0P002Goo0`001UYF00<005YFFUH01EYF0`00
1eYF00<005YFFUH010002Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000MJEP03001JEP00008000EJEP8005Aoo`00;7oo0`002goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`003Woo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF
00<005YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool200000eYF0000000=Ool@000COol20000
0eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03
FUH20002FUH00`00Oomoo`1COol002aoo`8000=JEP8002aoo`8000=JEP<0009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEPP000=JEP03001JEUYF00=JEP04001JEP00001FOol002eoo`06001JEUYFFUH0
05YF0`009Goo100000=JEP00FUH00UYF0P0000Aoo`00000000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP@0
00EJEP05001JEUYFFUH0001EOol002eoo`05001JEUYFFUH00004FUH3000LOol60005FUH01@00FUIJ
EUYF000017oo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF008000=JEP05001J
EUYFFUH0001EOol002ioo`04001JEUYF0005FUH00`00FUH00003000?Ool90004FUH00`00FUIJEP04
FUH01000FUIJEP0027oo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF009JEP8005Aoo`00;goo0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH015YF0`003Goo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF1P001UYF00<005YFFUH01EYF00@005YFFUIJEP800003Ool0000000=JEP8005Ao
o`00<Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0057oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF
2P000UYF1@001EYF00<005YFFUH01EYF00@005YF000000Eoo`800003FUH0000005Aoo`00<goo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
77oo8P0015YF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`002Goo0`00E7oo000fOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000cOol00`00FUH00005Ool20000
0eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04000<Ool3001DOol003Uoo`@0009J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Ioo`8000Qoo`D000AJEP03001JEUYF
00IJEP<000AJEPD000ioo`<00003FUH007oo05=oo`00?Goo5`00>Woo0`0037oo2@0015YF00<005YF
FUH010004Goo0P000UYF00<005YF0000E7oo002>Ool200000eYF001oo`0COol7000COol20004FUH2
001EOol008ioo`80009JEP8002Qoo`@00003FUH005YF00=JEP8005Eoo`00Sgoo00D005YFFUH005YF
00<0029oo`<000EJEP03001JEUYF009JEP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEPD001Uo
o`@00003FUH005YF00EJEP03001JEUYF008005Moo`00T7oo00<005YF00001EYF00@005YFFUIJEQT0
00EJEP03001JEUYF00AJEP<005Uoo`00TGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo002BOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00GGoo002DOol3
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000
Ggoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5001QOol009ao
o`T000AJEP03001JEUYF009JEPT006Ioo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59791 .76245 m .59306 .71156 L .56194 .71071 L p .707 .577 .707 r
F P
0 g
s
.59306 .71156 m .59791 .76245 L .62961 .7586 L p .707 .577 .707 r
F P
0 g
s
.62961 .7586 m .62476 .70771 L .59306 .71156 L p .707 .577 .707 r
F P
0 g
s
.62476 .70771 m .62961 .7586 L .65877 .75044 L p .707 .577 .707 r
F P
0 g
s
.65877 .75044 m .65392 .69955 L .62476 .70771 L p .707 .577 .707 r
F P
0 g
s
.56679 .7616 m .56194 .71071 L .53443 .70526 L p .707 .577 .707 r
F P
0 g
s
.56194 .71071 m .56679 .7616 L .59791 .76245 L p .707 .577 .707 r
F P
0 g
s
.65392 .69955 m .65877 .75044 L .68255 .73877 L p .707 .577 .707 r
F P
0 g
s
.68255 .73877 m .6777 .68788 L .65392 .69955 L p .707 .577 .707 r
F P
0 g
s
.53928 .75615 m .53443 .70526 L .51324 .69574 L p .707 .577 .707 r
F P
0 g
s
.53443 .70526 m .53928 .75615 L .56679 .7616 L p .707 .577 .707 r
F P
0 g
s
.6777 .68788 m .68255 .73877 L .69861 .72473 L p .707 .577 .707 r
F P
0 g
s
.69861 .72473 m .69377 .67384 L .6777 .68788 L p .707 .577 .707 r
F P
0 g
s
.60361 .8411 m .59825 .81035 L .56721 .81016 L p .707 .577 .707 r
F P
0 g
s
.59825 .81035 m .60361 .8411 L .63505 .83535 L p .707 .577 .707 r
F P
0 g
s
.63505 .83535 m .62969 .80459 L .59825 .81035 L p .707 .577 .707 r
F P
0 g
s
.62969 .80459 m .63505 .83535 L .66382 .82421 L p .707 .577 .707 r
F P
0 g
s
.66382 .82421 m .65846 .79346 L .62969 .80459 L p .707 .577 .707 r
F P
0 g
s
.51808 .74663 m .51324 .69574 L .50043 .68308 L p .707 .577 .707 r
F P
0 g
s
.51324 .69574 m .51808 .74663 L .53928 .75615 L p .707 .577 .707 r
F P
0 g
s
.59632 .87391 m .59534 .85621 L .56419 .85496 L p .707 .577 .707 r
F P
0 g
s
.59534 .85621 m .59632 .87391 L .6281 .87125 L p .707 .577 .707 r
F P
0 g
s
.6281 .87125 m .62713 .85356 L .59534 .85621 L p .707 .577 .707 r
F P
0 g
s
.62713 .85356 m .6281 .87125 L .65741 .86495 L p .707 .577 .707 r
F P
0 g
s
.65741 .86495 m .65643 .84725 L .62713 .85356 L p .707 .577 .707 r
F P
0 g
s
.57257 .84092 m .56721 .81016 L .53962 .80405 L p .707 .577 .707 r
F P
0 g
s
.56721 .81016 m .57257 .84092 L .60361 .8411 L p .707 .577 .707 r
F P
0 g
s
.65846 .79346 m .66382 .82421 L .6871 .80879 L p .707 .577 .707 r
F P
0 g
s
.6871 .80879 m .68174 .77803 L .65846 .79346 L p .707 .577 .707 r
F P
0 g
s
.56516 .87266 m .56419 .85496 L .53671 .84992 L p .707 .577 .707 r
F P
0 g
s
.56419 .85496 m .56516 .87266 L .59632 .87391 L p .707 .577 .707 r
F P
0 g
s
.69377 .67384 m .69861 .72473 L .70539 .70968 L p .707 .577 .707 r
F P
0 g
s
.70539 .70968 m .70055 .6588 L .69377 .67384 L p .707 .577 .707 r
F P
0 g
s
.65643 .84725 m .65741 .86495 L .68136 .85561 L p .707 .577 .707 r
F P
0 g
s
.68136 .85561 m .68038 .83792 L .65643 .84725 L p .707 .577 .707 r
F P
0 g
s
.53671 .84992 m .53769 .86762 L .56516 .87266 L p .707 .577 .707 r
F P
0 g
s
.54498 .83481 m .53962 .80405 L .51817 .79262 L p .707 .577 .707 r
F P
0 g
s
.53962 .80405 m .54498 .83481 L .57257 .84092 L p .707 .577 .707 r
F P
0 g
s
.68174 .77803 m .6871 .80879 L .70261 .79059 L p .707 .577 .707 r
F P
0 g
s
.70261 .79059 m .69725 .75983 L .68174 .77803 L p .707 .577 .707 r
F P
0 g
s
.53769 .86762 m .53671 .84992 L .51561 .84159 L p .707 .577 .707 r
F P
0 g
s
.50527 .73397 m .50043 .68308 L .49726 .66851 L p .707 .577 .707 r
F P
0 g
s
.50043 .68308 m .50527 .73397 L .51808 .74663 L p .707 .577 .707 r
F P
0 g
s
.51561 .84159 m .51658 .85928 L .53769 .86762 L p .707 .577 .707 r
F P
0 g
s
.68038 .83792 m .68136 .85561 L .69762 .84416 L p .707 .577 .707 r
F P
0 g
s
.69762 .84416 m .69664 .82646 L .68038 .83792 L p .707 .577 .707 r
F P
0 g
s
.70055 .6588 m .70539 .70968 L .70222 .69512 L p .707 .577 .707 r
F P
0 g
s
.70222 .69512 m .69738 .64423 L .70055 .6588 L p .707 .577 .707 r
F P
0 g
s
.52353 .82338 m .51817 .79262 L .50496 .77698 L p .707 .577 .707 r
F P
0 g
s
.51817 .79262 m .52353 .82338 L .54498 .83481 L p .707 .577 .707 r
F P
0 g
s
.69725 .75983 m .70261 .79059 L .70884 .77139 L p .707 .577 .707 r
F P
0 g
s
.70884 .77139 m .70348 .74063 L .69725 .75983 L p .707 .577 .707 r
F P
0 g
s
.51658 .85928 m .51561 .84159 L .50293 .83078 L p .707 .577 .707 r
F P
0 g
s
.49726 .66851 m .5021 .7194 L .50527 .73397 L p .707 .577 .707 r
F P
0 g
s
.50293 .83078 m .50391 .84847 L .51658 .85928 L p .707 .577 .707 r
F P
0 g
s
.5021 .7194 m .49726 .66851 L .50404 .65347 L p .707 .577 .707 r
F P
0 g
s
.69664 .82646 m .69762 .84416 L .70459 .83171 L p .707 .577 .707 r
F P
0 g
s
.70459 .83171 m .70362 .81401 L .69664 .82646 L p .707 .577 .707 r
F P
0 g
s
.50496 .77698 m .51032 .80774 L .52353 .82338 L p .707 .577 .707 r
F P
0 g
s
.51032 .80774 m .50496 .77698 L .50129 .75867 L p .708 .578 .707 r
F P
0 g
s
.69738 .64423 m .70222 .69512 L .68941 .68246 L p .707 .577 .707 r
F P
0 g
s
.68941 .68246 m .68457 .63157 L .69738 .64423 L p .707 .577 .707 r
F P
0 g
s
.70348 .74063 m .70884 .77139 L .70517 .75307 L p .708 .578 .707 r
F P
0 g
s
.70517 .75307 m .69981 .72232 L .70348 .74063 L p .708 .578 .707 r
F P
0 g
s
.48079 .81686 m .49636 .30616 L .45236 .30292 L p .707 .577 .707 r
F P
0 g
s
.50404 .65347 m .50888 .70436 L .5021 .7194 L p .707 .577 .707 r
F P
0 g
s
.50888 .70436 m .50404 .65347 L .5201 .63943 L p .707 .577 .707 r
F P
0 g
s
.50129 .75867 m .50665 .78942 L .51032 .80774 L p .708 .578 .707 r
F P
0 g
s
.50665 .78942 m .50129 .75867 L .50752 .73947 L p .707 .577 .707 r
F P
0 g
s
.50391 .84847 m .50293 .83078 L .49994 .81855 L p .707 .577 .707 r
F P
0 g
s
.49994 .81855 m .50092 .83625 L .50391 .84847 L p .707 .577 .707 r
F P
0 g
s
.50092 .83625 m .49994 .81855 L .50691 .8061 L p .707 .577 .707 r
F P
0 g
s
.5201 .63943 m .52495 .69032 L .50888 .70436 L p .707 .577 .707 r
F P
0 g
s
.50691 .8061 m .50789 .8238 L .50092 .83625 L p .707 .577 .707 r
F P
0 g
s
.50752 .73947 m .51288 .77022 L .50665 .78942 L p .707 .577 .707 r
F P
0 g
s
.51288 .77022 m .50752 .73947 L .52303 .72127 L p .707 .577 .707 r
F P
0 g
s
.50789 .8238 m .50691 .8061 L .52317 .79464 L p .707 .577 .707 r
F P
0 g
s
.52303 .72127 m .52839 .75202 L .51288 .77022 L p .707 .577 .707 r
F P
0 g
s
.52317 .79464 m .52415 .81234 L .50789 .8238 L p .707 .577 .707 r
F P
0 g
s
.52415 .81234 m .52317 .79464 L .54712 .78531 L p .707 .577 .707 r
F P
0 g
s
.54712 .78531 m .5481 .80301 L .52415 .81234 L p .707 .577 .707 r
F P
0 g
s
.49636 .30616 m .48079 .81686 L .52571 .81737 L p .707 .577 .707 r
F P
0 g
s
.52495 .69032 m .5201 .63943 L .54388 .62776 L p .707 .577 .707 r
F P
0 g
s
.54388 .62776 m .54873 .67865 L .52495 .69032 L p .707 .577 .707 r
F P
0 g
s
.52839 .75202 m .52303 .72127 L .54631 .70584 L p .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .54128 .30667 L .49636 .30616 L p .707 .577 .707 r
F P
0 g
s
.54873 .67865 m .54388 .62776 L .57304 .6196 L p .707 .577 .707 r
F P
0 g
s
.57304 .6196 m .57789 .67049 L .55413 .67713 L p .707 .577 .707 r
F P
0 g
s
.55413 .67713 m .54873 .67865 L p .55127 .67246 L .707 .577 .707 r
F P
0 g
s
.55127 .67246 m .57304 .6196 L .55413 .67713 L .707 .577 .707 r
F
.57643 .779 m .5774 .7967 L .56505 .79936 L p F P
0 g
s
.56505 .79936 m .5481 .80301 L p .56191 .7913 L .707 .577 .707 r
F P
0 g
s
.56191 .7913 m .57643 .779 L .56505 .79936 L .707 .577 .707 r
F
.58044 .72546 m .57508 .69471 L .58078 .69366 L p F P
0 g
s
.58078 .69366 m .60653 .68895 L p .58717 .71605 L .707 .577 .707 r
F P
0 g
s
.58044 .72546 m .58078 .69366 L .58717 .71605 L .707 .577 .707 r
F
.63586 .61659 m .64071 .66748 L .60959 .66664 L p F P
0 g
s
.60959 .66664 m .60474 .61575 L .63586 .61659 L p .707 .577 .707 r
F P
0 g
s
.60474 .61575 m .60959 .66664 L .57789 .67049 L p .707 .577 .707 r
F P
0 g
s
.63756 .68914 m .64292 .71989 L .61188 .71971 L p .707 .577 .707 r
F P
0 g
s
.61188 .71971 m .60653 .68895 L .63756 .68914 L p .707 .577 .707 r
F P
0 g
s
.60653 .68895 m .61188 .71971 L .58044 .72546 L p .707 .577 .707 r
F P
0 g
s
.63937 .7776 m .64034 .7953 L .60919 .79405 L p .707 .577 .707 r
F P
0 g
s
.60919 .79405 m .60821 .77635 L .63937 .7776 L p .707 .577 .707 r
F P
0 g
s
.5774 .7967 m .57643 .779 L .60821 .77635 L p .707 .577 .707 r
F P
0 g
s
.60821 .77635 m .60919 .79405 L .5774 .7967 L p .707 .577 .707 r
F P
0 g
s
.61663 .29957 m .60231 .76911 L p .62412 .80336 L .707 .577 .707 r
F P
0 g
s
.60231 .76911 m .60106 .81027 L .61304 .80668 L p .707 .577 .707 r
F P
0 g
s
.61304 .80668 m .62412 .80336 L p .60231 .76911 L .707 .577 .707 r
F P
0 g
s
.57508 .69471 m .58044 .72546 L .57208 .7287 L p .707 .577 .707 r
F P
0 g
s
.5481 .80301 m .54712 .78531 L .57643 .779 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .56744 .8055 L p .59819 .75169 L .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .56715 .8151 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56136 .71926 L .56984 .72673 L .707 .577 .707 r
F
.56136 .71926 m .57508 .69471 L .5723 .72616 L F
.56984 .72673 m .5723 .72616 L .57208 .7287 L F
.56136 .71926 m .5723 .72616 L .56984 .72673 L F
.56274 .72838 m .55073 .73117 L .52571 .81737 L F
.54631 .70584 m .55073 .73117 L p .52839 .75202 L F P
0 g
s
.5452 .74089 m .52839 .75202 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52818 .73641 m .52707 .77275 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52707 .77275 m .52571 .81737 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.55073 .73117 m .55167 .7366 L .5452 .74089 L p .707 .577 .707 r
F P
0 g
s
.55167 .7366 m .54631 .70584 L .57508 .69471 L p .707 .577 .707 r
F P
0 g
s
.58272 .3044 m .54128 .30667 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.56715 .8151 m .56984 .72673 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57789 .67049 m .57304 .6196 L .60474 .61575 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .58272 .3044 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.54128 .30667 m .52818 .73641 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57208 .7287 m .55167 .7366 L p .5553 .73011 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56984 .72673 L .57208 .7287 L .707 .577 .707 r
F
.57054 .70402 m .56984 .72673 L p .59889 .75046 L F P
0 g
s
.59889 .75046 m .56984 .72673 L .59819 .75169 L .707 .577 .707 r
F
.56744 .8055 m .56715 .8151 L p .5694 .81052 L F P
0 g
s
.59889 .75046 m .56744 .8055 L .5694 .81052 L .707 .577 .707 r
F
.56715 .8151 m .60106 .81027 L p .59889 .75046 L F P
0 g
s
.58272 .3044 m .57054 .70402 L p .59889 .75046 L .707 .577 .707 r
F P
0 g
s
.43679 .81363 m .45236 .30292 L .41358 .29728 L p .707 .577 .707 r
F P
0 g
s
.45236 .30292 m .43679 .81363 L .48079 .81686 L p .707 .577 .707 r
F P
0 g
s
.70362 .81401 m .70459 .83171 L .7016 .81948 L p .707 .577 .707 r
F P
0 g
s
.7016 .81948 m .70062 .80178 L .70362 .81401 L p .707 .577 .707 r
F P
0 g
s
.2549 .72563 m .25005 .67474 L .21893 .6739 L p .707 .577 .707 r
F P
0 g
s
.25005 .67474 m .2549 .72563 L .2866 .72179 L p .707 .577 .707 r
F P
0 g
s
.2866 .72179 m .28175 .6709 L .25005 .67474 L p .707 .577 .707 r
F P
0 g
s
.28175 .6709 m .2866 .72179 L .31576 .71363 L p .707 .577 .707 r
F P
0 g
s
.31576 .71363 m .31091 .66274 L .28175 .6709 L p .707 .577 .707 r
F P
0 g
s
.68457 .63157 m .68941 .68246 L .66822 .67293 L p .707 .577 .707 r
F P
0 g
s
.66822 .67293 m .66337 .62204 L .68457 .63157 L p .707 .577 .707 r
F P
0 g
s
.69981 .72232 m .70517 .75307 L .69196 .73743 L p .707 .577 .707 r
F P
0 g
s
.69196 .73743 m .68661 .70668 L .69981 .72232 L p .707 .577 .707 r
F P
0 g
s
.60106 .81027 m .61663 .29957 L .58272 .3044 L p .707 .577 .707 r
F P
0 g
s
.22378 .72479 m .21893 .6739 L .19142 .66845 L p .707 .577 .707 r
F P
0 g
s
.21893 .6739 m .22378 .72479 L .2549 .72563 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31091 .66274 m .31576 .71363 L .33954 .70195 L p .707 .577 .707 r
F P
0 g
s
.33954 .70195 m .33469 .65106 L .31091 .66274 L p .707 .577 .707 r
F P
0 g
s
.39802 .80798 m .41358 .29728 L .38383 .28977 L p .707 .577 .707 r
F P
0 g
s
.41358 .29728 m .39802 .80798 L .43679 .81363 L p .707 .577 .707 r
F P
0 g
s
.19627 .71934 m .19142 .66845 L .17023 .65893 L p .707 .577 .707 r
F P
0 g
s
.19142 .66845 m .19627 .71934 L .22378 .72479 L p .707 .577 .707 r
F P
0 g
s
.66337 .62204 m .66822 .67293 L .64071 .66748 L p .707 .577 .707 r
F P
0 g
s
.64071 .66748 m .63586 .61659 L .66337 .62204 L p .707 .577 .707 r
F P
0 g
s
.70062 .80178 m .7016 .81948 L .68893 .80867 L p .707 .577 .707 r
F P
0 g
s
.68893 .80867 m .68795 .79097 L .70062 .80178 L p .707 .577 .707 r
F P
0 g
s
.68661 .70668 m .69196 .73743 L .67051 .726 L p .707 .577 .707 r
F P
0 g
s
.67051 .726 m .66516 .69524 L .68661 .70668 L p .707 .577 .707 r
F P
0 g
s
.33469 .65106 m .33954 .70195 L .35561 .68791 L p .707 .577 .707 r
F P
0 g
s
.35561 .68791 m .35076 .63702 L .33469 .65106 L p .707 .577 .707 r
F P
0 g
s
.62412 .80336 m .63968 .29266 L .61663 .29957 L p .707 .577 .707 r
F P
0 g
s
.2606 .80429 m .25524 .77353 L .2242 .77335 L p .707 .577 .707 r
F P
0 g
s
.25524 .77353 m .2606 .80429 L .29204 .79853 L p .707 .577 .707 r
F P
0 g
s
.29204 .79853 m .28668 .76778 L .25524 .77353 L p .707 .577 .707 r
F P
0 g
s
.28668 .76778 m .29204 .79853 L .32081 .7874 L p .707 .577 .707 r
F P
0 g
s
.32081 .7874 m .31545 .75664 L .28668 .76778 L p .707 .577 .707 r
F P
0 g
s
.17508 .70982 m .17023 .65893 L .15742 .64626 L p .707 .577 .707 r
F P
0 g
s
.17023 .65893 m .17508 .70982 L .19627 .71934 L p .707 .577 .707 r
F P
0 g
s
.25331 .83709 m .25233 .8194 L .22118 .81814 L p .707 .577 .707 r
F P
0 g
s
.25233 .8194 m .25331 .83709 L .2851 .83444 L p .707 .577 .707 r
F P
0 g
s
.2851 .83444 m .28412 .81674 L .25233 .8194 L p .707 .577 .707 r
F P
0 g
s
.28412 .81674 m .2851 .83444 L .3144 .82813 L p .707 .577 .707 r
F P
0 g
s
.3144 .82813 m .31342 .81044 L .28412 .81674 L p .707 .577 .707 r
F P
0 g
s
.22956 .8041 m .2242 .77335 L .19661 .76724 L p .707 .577 .707 r
F P
0 g
s
.2242 .77335 m .22956 .8041 L .2606 .80429 L p .707 .577 .707 r
F P
0 g
s
.36827 .80047 m .38383 .28977 L .36602 .28114 L p .707 .577 .707 r
F P
0 g
s
.38383 .28977 m .36827 .80047 L .39802 .80798 L p .707 .577 .707 r
F P
0 g
s
.31545 .75664 m .32081 .7874 L .34409 .77197 L p .707 .577 .707 r
F P
0 g
s
.34409 .77197 m .33873 .74122 L .31545 .75664 L p .707 .577 .707 r
F P
0 g
s
.66516 .69524 m .67051 .726 L .64292 .71989 L p .707 .577 .707 r
F P
0 g
s
.64292 .71989 m .63756 .68914 L .66516 .69524 L p .707 .577 .707 r
F P
0 g
s
.22216 .83584 m .22118 .81814 L .1937 .8131 L p .707 .577 .707 r
F P
0 g
s
.22118 .81814 m .22216 .83584 L .25331 .83709 L p .707 .577 .707 r
F P
0 g
s
.35076 .63702 m .35561 .68791 L .36238 .67287 L p .707 .577 .707 r
F P
0 g
s
.36238 .67287 m .35754 .62198 L .35076 .63702 L p .707 .577 .707 r
F P
0 g
s
.68795 .79097 m .68893 .80867 L .66782 .80034 L p .707 .577 .707 r
F P
0 g
s
.66782 .80034 m .66684 .78264 L .68795 .79097 L p .707 .577 .707 r
F P
0 g
s
.31342 .81044 m .3144 .82813 L .33835 .8188 L p .707 .577 .707 r
F P
0 g
s
.33835 .8188 m .33738 .8011 L .31342 .81044 L p .707 .577 .707 r
F P
0 g
s
.1937 .8131 m .19468 .8308 L .22216 .83584 L p .707 .577 .707 r
F P
0 g
s
.20197 .79799 m .19661 .76724 L .17516 .75581 L p .707 .577 .707 r
F P
0 g
s
.19661 .76724 m .20197 .79799 L .22956 .8041 L p .707 .577 .707 r
F P
0 g
s
.33873 .74122 m .34409 .77197 L .3596 .75377 L p .707 .577 .707 r
F P
0 g
s
.3596 .75377 m .35424 .72302 L .33873 .74122 L p .707 .577 .707 r
F P
0 g
s
.19468 .8308 m .1937 .8131 L .1726 .80477 L p .707 .577 .707 r
F P
0 g
s
.16227 .69715 m .15742 .64626 L .15425 .6317 L p .707 .577 .707 r
F P
0 g
s
.15742 .64626 m .16227 .69715 L .17508 .70982 L p .707 .577 .707 r
F P
0 g
s
.63968 .29266 m .62412 .80336 L .63406 .79504 L p .707 .577 .707 r
F P
0 g
s
.63406 .79504 m .64963 .28434 L .63968 .29266 L p .707 .577 .707 r
F P
0 g
s
.1726 .80477 m .17357 .82247 L .19468 .8308 L p .707 .577 .707 r
F P
0 g
s
.33738 .8011 m .33835 .8188 L .35461 .80734 L p .707 .577 .707 r
F P
0 g
s
.35461 .80734 m .35363 .78965 L .33738 .8011 L p .707 .577 .707 r
F P
0 g
s
.66684 .78264 m .66782 .80034 L .64034 .7953 L p .707 .577 .707 r
F P
0 g
s
.64034 .7953 m .63937 .7776 L .66684 .78264 L p .707 .577 .707 r
F P
0 g
s
.35754 .62198 m .36238 .67287 L .35921 .6583 L p .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35754 .62198 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35437 .60741 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35805 .64604 L p .3464 .64564 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35921 .6583 L .35684 .65596 L p .707 .577 .707 r
F P
0 g
s
.35684 .65596 m .3464 .64564 L p .35805 .64604 L .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .3568 .6855 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34895 .70062 m .34875 .69947 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34875 .69947 m .3436 .66986 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.35424 .72302 m .3596 .75377 L .36583 .73457 L p .707 .577 .707 r
F P
0 g
s
.36583 .73457 m .36047 .70382 L .35424 .72302 L p .707 .577 .707 r
F P
0 g
s
.35363 .78965 m .35461 .80734 L .36158 .79489 L p .707 .577 .707 r
F P
0 g
s
.36158 .79489 m .36061 .7772 L .35363 .78965 L p .707 .577 .707 r
F P
0 g
s
.36047 .70382 m .36583 .73457 L .36318 .72135 L p .708 .578 .707 r
F P
0 g
s
.36198 .71491 m .36047 .70382 L .36318 .72135 L .708 .578 .707 r
F
.35761 .76497 m .35859 .78267 L .35126 .77641 L p .707 .577 .707 r
F P
0 g
s
.35126 .77641 m .34592 .77186 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.35198 .76829 m .35761 .76497 L .35126 .77641 L .707 .577 .707 r
F
.3568 .6855 m .35684 .6857 L p .34895 .70062 L F P
0 g
s
.34592 .77186 m .34494 .75416 L .35264 .76073 L p .707 .577 .707 r
F P
0 g
s
.35264 .76073 m .35761 .76497 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.34592 .77186 m .35264 .76073 L .35198 .76829 L .707 .577 .707 r
F
.35279 .70516 m .34895 .70062 L p .35684 .6857 L F P
0 g
s
.3464 .64564 m .34156 .59475 L .35437 .60741 L p .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .34895 .70062 L .34285 .69736 L p .707 .577 .707 r
F P
0 g
s
.34285 .69736 m .32751 .68918 L p .34035 .67377 L .707 .577 .707 r
F P
0 g
s
.34035 .67377 m .3436 .66986 L .34285 .69736 L .707 .577 .707 r
F
.36188 .27223 m .34631 .78293 L .34998 .79084 L p F P
0 g
s
.35063 .78347 m .36188 .27223 L .34998 .79084 L .707 .577 .707 r
F
.35063 .78347 m .35313 .70356 L .35231 .70751 L F
.35074 .78224 m .35384 .68076 L p .35063 .78347 L F P
0 g
s
.35314 .70347 m .35045 .79184 L p .36482 .73015 L .707 .577 .707 r
F P
0 g
s
.36121 .71083 m .35314 .70347 L .36482 .73015 L .707 .577 .707 r
F
.35684 .6857 m .36216 .71626 L .35279 .70516 L p F P
0 g
s
.3568 .6855 m .36047 .70382 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36121 .71083 m .3568 .6855 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.35921 .6583 m .35805 .64604 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .35314 .70347 L p .3679 .71693 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .36188 .27223 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.35522 .63529 m .36602 .28114 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.36188 .27223 m .37183 .26391 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34631 .78293 m .34757 .74177 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34757 .74177 m .36188 .27223 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34998 .79084 m .35045 .79184 L p .35063 .78347 L .707 .577 .707 r
F P
0 g
s
.35231 .70751 m .35384 .68076 L .35269 .69026 L .707 .577 .707 r
F
.35313 .70356 m .35384 .68076 L .35231 .70751 L F
.35045 .79184 m .35074 .78224 L p .35063 .78347 L F P
0 g
s
.3679 .71693 m .36121 .71083 L .36482 .73015 L .707 .577 .707 r
F
.36216 .71626 m .36121 .71083 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36318 .72135 m .36216 .71626 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36061 .7772 m .36158 .79489 L .35859 .78267 L p .707 .577 .707 r
F P
0 g
s
.35859 .78267 m .35761 .76497 L .36061 .7772 L p .707 .577 .707 r
F P
0 g
s
.35045 .79184 m .36827 .80047 L p .36804 .74734 L .707 .577 .707 r
F P
0 g
s
.36804 .74734 m .3679 .71693 L .36482 .73015 L .707 .577 .707 r
F
.36804 .74734 m .36482 .73015 L .35045 .79184 L F
.35269 .69026 m .35522 .63529 L .354 .63062 L F
.35384 .68076 m .35522 .63529 L p .35269 .69026 L F P
0 g
s
.18052 .78656 m .17516 .75581 L .16195 .74017 L p .707 .577 .707 r
F P
0 g
s
.17516 .75581 m .18052 .78656 L .20197 .79799 L p .707 .577 .707 r
F P
0 g
s
.17357 .82247 m .1726 .80477 L .15993 .79396 L p .707 .577 .707 r
F P
0 g
s
.15425 .6317 m .15909 .68259 L .16227 .69715 L p .707 .577 .707 r
F P
0 g
s
.15993 .79396 m .1609 .81166 L .17357 .82247 L p .707 .577 .707 r
F P
0 g
s
.15909 .68259 m .15425 .6317 L .16103 .61666 L p .707 .577 .707 r
F P
0 g
s
.16195 .74017 m .16731 .77092 L .18052 .78656 L p .707 .577 .707 r
F P
0 g
s
.16731 .77092 m .16195 .74017 L .15828 .72185 L p .708 .578 .707 r
F P
0 g
s
.64963 .28434 m .63406 .79504 L .62992 .78613 L p .707 .577 .707 r
F P
0 g
s
.62992 .78613 m .64549 .27543 L .64963 .28434 L p .707 .577 .707 r
F P
0 g
s
.1609 .81166 m .15993 .79396 L .15693 .78173 L p .707 .577 .707 r
F P
0 g
s
.16103 .61666 m .16587 .66755 L .15909 .68259 L p .707 .577 .707 r
F P
0 g
s
.15693 .78173 m .15791 .79943 L .1609 .81166 L p .707 .577 .707 r
F P
0 g
s
.16587 .66755 m .16103 .61666 L .17709 .60261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15828 .72185 m .16364 .75261 L .16731 .77092 L p .708 .578 .707 r
F P
0 g
s
.16364 .75261 m .15828 .72185 L .16451 .70265 L p .707 .577 .707 r
F P
0 g
s
.34156 .59475 m .3464 .64564 L .32521 .63612 L p .707 .577 .707 r
F P
0 g
s
.32521 .63612 m .32036 .58523 L .34156 .59475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15791 .79943 m .15693 .78173 L .1639 .76928 L p .707 .577 .707 r
F P
0 g
s
.17709 .60261 m .18194 .6535 L .16587 .66755 L p .707 .577 .707 r
F P
0 g
s
.18194 .6535 m .17709 .60261 L .20087 .59094 L p .707 .577 .707 r
F P
0 g
s
.1639 .76928 m .16488 .78698 L .15791 .79943 L p .707 .577 .707 r
F P
0 g
s
.16451 .70265 m .16987 .73341 L .16364 .75261 L p .707 .577 .707 r
F P
0 g
s
.32036 .58523 m .32521 .63612 L .2977 .63067 L p .707 .577 .707 r
F P
0 g
s
.2977 .63067 m .29286 .57978 L .32036 .58523 L p .707 .577 .707 r
F P
0 g
s
.16987 .73341 m .16451 .70265 L .18002 .68445 L p .707 .577 .707 r
F P
0 g
s
.64549 .27543 m .62992 .78613 L .61211 .7775 L p .707 .577 .707 r
F P
0 g
s
.61211 .7775 m .62768 .2668 L .64549 .27543 L p .707 .577 .707 r
F P
0 g
s
.32751 .68918 m .32215 .65843 L .3436 .66986 L p .707 .577 .707 r
F P
0 g
s
.20572 .64183 m .20087 .59094 L .23004 .58278 L p .707 .577 .707 r
F P
0 g
s
.20087 .59094 m .20572 .64183 L .18194 .6535 L p .707 .577 .707 r
F P
0 g
s
.29286 .57978 m .2977 .63067 L .26658 .62983 L p .707 .577 .707 r
F P
0 g
s
.26658 .62983 m .26173 .57894 L .29286 .57978 L p .707 .577 .707 r
F P
0 g
s
.16488 .78698 m .1639 .76928 L .18016 .75783 L p .707 .577 .707 r
F P
0 g
s
.35626 .77461 m .37183 .26391 L .39488 .257 L p .707 .577 .707 r
F P
0 g
s
.37183 .26391 m .35626 .77461 L .34631 .78293 L p .707 .577 .707 r
F P
0 g
s
.23488 .63367 m .23004 .58278 L .26173 .57894 L p .707 .577 .707 r
F P
0 g
s
.23004 .58278 m .23488 .63367 L .20572 .64183 L p .707 .577 .707 r
F P
0 g
s
.26173 .57894 m .26658 .62983 L .23488 .63367 L p .707 .577 .707 r
F P
0 g
s
.18002 .68445 m .18538 .71521 L .16987 .73341 L p .707 .577 .707 r
F P
0 g
s
.18538 .71521 m .18002 .68445 L .20331 .66903 L p .707 .577 .707 r
F P
0 g
s
.32215 .65843 m .32751 .68918 L .29991 .68308 L p .707 .577 .707 r
F P
0 g
s
.29991 .68308 m .29455 .65232 L .32215 .65843 L p .707 .577 .707 r
F P
0 g
s
.18016 .75783 m .18114 .77553 L .16488 .78698 L p .707 .577 .707 r
F P
0 g
s
.34494 .75416 m .34592 .77186 L .32481 .76353 L p .707 .577 .707 r
F P
0 g
s
.32481 .76353 m .32383 .74583 L .34494 .75416 L p .707 .577 .707 r
F P
0 g
s
.20866 .69978 m .20331 .66903 L .23207 .65789 L p .707 .577 .707 r
F P
0 g
s
.20331 .66903 m .20866 .69978 L .18538 .71521 L p .707 .577 .707 r
F P
0 g
s
.29455 .65232 m .29991 .68308 L .26887 .68289 L p .707 .577 .707 r
F P
0 g
s
.26887 .68289 m .26352 .65214 L .29455 .65232 L p .707 .577 .707 r
F P
0 g
s
.62768 .2668 m .61211 .7775 L .58236 .76999 L p .707 .577 .707 r
F P
0 g
s
.58236 .76999 m .59792 .25929 L .62768 .2668 L p .707 .577 .707 r
F P
0 g
s
.18114 .77553 m .18016 .75783 L .20411 .74849 L p .707 .577 .707 r
F P
0 g
s
.73511 .68302 m .73027 .63213 L .69914 .63129 L p .707 .577 .707 r
F P
0 g
s
.73027 .63213 m .73511 .68302 L .76681 .67918 L p .707 .577 .707 r
F P
0 g
s
.76681 .67918 m .76196 .62829 L .73027 .63213 L p .707 .577 .707 r
F P
0 g
s
.76196 .62829 m .76681 .67918 L .79598 .67102 L p .707 .577 .707 r
F P
0 g
s
.79598 .67102 m .79113 .62013 L .76196 .62829 L p .707 .577 .707 r
F P
0 g
s
.23743 .68865 m .23207 .65789 L .26352 .65214 L p .707 .577 .707 r
F P
0 g
s
.23207 .65789 m .23743 .68865 L .20866 .69978 L p .707 .577 .707 r
F P
0 g
s
.26352 .65214 m .26887 .68289 L .23743 .68865 L p .707 .577 .707 r
F P
0 g
s
.70399 .68218 m .69914 .63129 L .67164 .62584 L p .707 .577 .707 r
F P
0 g
s
.69914 .63129 m .70399 .68218 L .73511 .68302 L p .707 .577 .707 r
F P
0 g
s
.20411 .74849 m .20509 .76619 L .18114 .77553 L p .707 .577 .707 r
F P
0 g
s
.32383 .74583 m .32481 .76353 L .29733 .75849 L p .707 .577 .707 r
F P
0 g
s
.29733 .75849 m .29636 .74079 L .32383 .74583 L p .707 .577 .707 r
F P
0 g
s
.79113 .62013 m .79598 .67102 L .81975 .65935 L p .707 .577 .707 r
F P
0 g
s
.81975 .65935 m .81491 .60846 L .79113 .62013 L p .707 .577 .707 r
F P
0 g
s
.39488 .257 m .37931 .7677 L .35626 .77461 L p .707 .577 .707 r
F P
0 g
s
.37931 .7677 m .39488 .257 L .42879 .25217 L p .707 .577 .707 r
F P
0 g
s
.20509 .76619 m .20411 .74849 L .23342 .74219 L p .707 .577 .707 r
F P
0 g
s
.67648 .67673 m .67164 .62584 L .65044 .61632 L p .707 .577 .707 r
F P
0 g
s
.67164 .62584 m .67648 .67673 L .70399 .68218 L p .707 .577 .707 r
F P
0 g
s
.29636 .74079 m .29733 .75849 L .26618 .75723 L p .707 .577 .707 r
F P
0 g
s
.26618 .75723 m .2652 .73953 L .29636 .74079 L p .707 .577 .707 r
F P
0 g
s
.23342 .74219 m .23439 .75989 L .20509 .76619 L p .707 .577 .707 r
F P
0 g
s
.81491 .60846 m .81975 .65935 L .83582 .6453 L p .707 .577 .707 r
F P
0 g
s
.83582 .6453 m .83097 .59441 L .81491 .60846 L p .707 .577 .707 r
F P
0 g
s
.23439 .75989 m .23342 .74219 L .2652 .73953 L p .707 .577 .707 r
F P
0 g
s
.2652 .73953 m .26618 .75723 L .23439 .75989 L p .707 .577 .707 r
F P
0 g
s
.59792 .25929 m .58236 .76999 L .54359 .76435 L p .707 .577 .707 r
F P
0 g
s
.54359 .76435 m .55915 .25364 L .59792 .25929 L p .707 .577 .707 r
F P
0 g
s
.74081 .74406 m .73545 .7133 L .70441 .71312 L p .707 .577 .707 r
F P
0 g
s
.73545 .7133 m .74081 .74406 L .77225 .7383 L p .707 .577 .707 r
F P
0 g
s
.77225 .7383 m .76689 .70754 L .73545 .7133 L p .707 .577 .707 r
F P
0 g
s
.76689 .70754 m .77225 .7383 L .80102 .72717 L p .707 .577 .707 r
F P
0 g
s
.80102 .72717 m .79566 .69641 L .76689 .70754 L p .707 .577 .707 r
F P
0 g
s
.73352 .76261 m .73255 .74491 L .70139 .74366 L p .707 .577 .707 r
F P
0 g
s
.73255 .74491 m .73352 .76261 L .76531 .75996 L p .707 .577 .707 r
F P
0 g
s
.76531 .75996 m .76433 .74226 L .73255 .74491 L p .707 .577 .707 r
F P
0 g
s
.76433 .74226 m .76531 .75996 L .79461 .75365 L p .707 .577 .707 r
F P
0 g
s
.79461 .75365 m .79364 .73595 L .76433 .74226 L p .707 .577 .707 r
F P
0 g
s
.41322 .76287 m .42879 .25217 L .47023 .2499 L p .707 .577 .707 r
F P
0 g
s
.42879 .25217 m .41322 .76287 L .37931 .7677 L p .707 .577 .707 r
F P
0 g
s
.70977 .74387 m .70441 .71312 L .67682 .70701 L p .707 .577 .707 r
F P
0 g
s
.70441 .71312 m .70977 .74387 L .74081 .74406 L p .707 .577 .707 r
F P
0 g
s
.70237 .76136 m .70139 .74366 L .67392 .73862 L p .707 .577 .707 r
F P
0 g
s
.70139 .74366 m .70237 .76136 L .73352 .76261 L p .707 .577 .707 r
F P
0 g
s
.65529 .66721 m .65044 .61632 L .63763 .60365 L p .707 .577 .707 r
F P
0 g
s
.65044 .61632 m .65529 .66721 L .67648 .67673 L p .707 .577 .707 r
F P
0 g
s
.79566 .69641 m .80102 .72717 L .8243 .71174 L p .707 .577 .707 r
F P
0 g
s
.8243 .71174 m .81894 .68099 L .79566 .69641 L p .707 .577 .707 r
F P
0 g
s
.79364 .73595 m .79461 .75365 L .81857 .74432 L p .707 .577 .707 r
F P
0 g
s
.81857 .74432 m .81759 .72662 L .79364 .73595 L p .707 .577 .707 r
F P
0 g
s
.67392 .73862 m .67489 .75632 L .70237 .76136 L p .707 .577 .707 r
F P
0 g
s
.83097 .59441 m .83582 .6453 L .8426 .63026 L p .707 .577 .707 r
F P
0 g
s
.8426 .63026 m .83775 .57937 L .83097 .59441 L p .707 .577 .707 r
F P
0 g
s
.55915 .25364 m .54359 .76435 L .49959 .76111 L p .707 .577 .707 r
F P
0 g
s
.49959 .76111 m .51515 .2504 L .55915 .25364 L p .707 .577 .707 r
F P
0 g
s
.68218 .73776 m .67682 .70701 L .65537 .69558 L p .707 .577 .707 r
F P
0 g
s
.67682 .70701 m .68218 .73776 L .70977 .74387 L p .707 .577 .707 r
F P
0 g
s
.67489 .75632 m .67392 .73862 L .65281 .73029 L p .707 .577 .707 r
F P
0 g
s
.45467 .7606 m .47023 .2499 L .51515 .2504 L p .707 .577 .707 r
F P
0 g
s
.47023 .2499 m .45467 .7606 L .41322 .76287 L p .707 .577 .707 r
F P
0 g
s
.81894 .68099 m .8243 .71174 L .83982 .69354 L p .707 .577 .707 r
F P
0 g
s
.83982 .69354 m .83446 .66279 L .81894 .68099 L p .707 .577 .707 r
F P
0 g
s
.51515 .2504 m .49959 .76111 L .45467 .7606 L p .707 .577 .707 r
F P
0 g
s
.65281 .73029 m .65379 .74799 L .67489 .75632 L p .707 .577 .707 r
F P
0 g
s
.81759 .72662 m .81857 .74432 L .83482 .73286 L p .707 .577 .707 r
F P
0 g
s
.83482 .73286 m .83385 .71517 L .81759 .72662 L p .707 .577 .707 r
F P
0 g
s
.64248 .65454 m .63763 .60365 L .63446 .58909 L p .707 .577 .707 r
F P
0 g
s
.63763 .60365 m .64248 .65454 L .65529 .66721 L p .707 .577 .707 r
F P
0 g
s
.66073 .72633 m .65537 .69558 L .64217 .67994 L p .707 .577 .707 r
F P
0 g
s
.65537 .69558 m .66073 .72633 L .68218 .73776 L p .707 .577 .707 r
F P
0 g
s
.83775 .57937 m .8426 .63026 L .83943 .6157 L p .707 .577 .707 r
F P
0 g
s
.83943 .6157 m .83458 .56481 L .83775 .57937 L p .707 .577 .707 r
F P
0 g
s
.83446 .66279 m .83982 .69354 L .84604 .67434 L p .707 .577 .707 r
F P
0 g
s
.84604 .67434 m .84068 .64359 L .83446 .66279 L p .707 .577 .707 r
F P
0 g
s
.65379 .74799 m .65281 .73029 L .64014 .71948 L p .707 .577 .707 r
F P
0 g
s
.64014 .71948 m .64112 .73718 L .65379 .74799 L p .707 .577 .707 r
F P
0 g
s
.83385 .71517 m .83482 .73286 L .8418 .72041 L p .707 .577 .707 r
F P
0 g
s
.8418 .72041 m .84082 .70272 L .83385 .71517 L p .707 .577 .707 r
F P
0 g
s
.63446 .58909 m .63931 .63998 L .64248 .65454 L p .707 .577 .707 r
F P
0 g
s
.63931 .63998 m .63446 .58909 L .64124 .57405 L p .707 .577 .707 r
F P
0 g
s
.64217 .67994 m .64753 .71069 L .66073 .72633 L p .707 .577 .707 r
F P
0 g
s
.64753 .71069 m .64217 .67994 L .6385 .66162 L p .708 .578 .707 r
F P
0 g
s
.84068 .64359 m .84604 .67434 L .84237 .65603 L p .708 .578 .707 r
F P
0 g
s
.84237 .65603 m .83702 .62527 L .84068 .64359 L p .708 .578 .707 r
F P
0 g
s
.83458 .56481 m .83943 .6157 L .82662 .60303 L p .707 .577 .707 r
F P
0 g
s
.82662 .60303 m .82177 .55214 L .83458 .56481 L p .707 .577 .707 r
F P
0 g
s
.64112 .73718 m .64014 .71948 L .63714 .70725 L p .707 .577 .707 r
F P
0 g
s
.63714 .70725 m .63812 .72495 L .64112 .73718 L p .707 .577 .707 r
F P
0 g
s
.84082 .70272 m .8418 .72041 L .8388 .70819 L p .707 .577 .707 r
F P
0 g
s
.8388 .70819 m .83783 .69049 L .84082 .70272 L p .707 .577 .707 r
F P
0 g
s
.64124 .57405 m .64609 .62494 L .63931 .63998 L p .707 .577 .707 r
F P
0 g
s
.6385 .66162 m .64386 .69237 L .64753 .71069 L p .708 .578 .707 r
F P
0 g
s
.64609 .62494 m .64124 .57405 L .65731 .56 L p .707 .577 .707 r
F P
0 g
s
.64386 .69237 m .6385 .66162 L .64473 .64242 L p .707 .577 .707 r
F P
0 g
s
.3921 .64621 m .38726 .59532 L .35613 .59448 L p .707 .577 .707 r
F P
0 g
s
.38726 .59532 m .3921 .64621 L .4238 .64236 L p .707 .577 .707 r
F P
0 g
s
.4238 .64236 m .41895 .59147 L .38726 .59532 L p .707 .577 .707 r
F P
0 g
s
.83702 .62527 m .84237 .65603 L .82917 .64039 L p .707 .577 .707 r
F P
0 g
s
.82917 .64039 m .82381 .60963 L .83702 .62527 L p .707 .577 .707 r
F P
0 g
s
.41895 .59147 m .4238 .64236 L .45297 .6342 L p .707 .577 .707 r
F P
0 g
s
.45297 .6342 m .44812 .58331 L .41895 .59147 L p .707 .577 .707 r
F P
0 g
s
.82177 .55214 m .82662 .60303 L .80542 .59351 L p .707 .577 .707 r
F P
0 g
s
.80542 .59351 m .80058 .54262 L .82177 .55214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63812 .72495 m .63714 .70725 L .64412 .6948 L p .707 .577 .707 r
F P
0 g
s
.36098 .64537 m .35613 .59448 L .32863 .58903 L p .707 .577 .707 r
F P
0 g
s
.35613 .59448 m .36098 .64537 L .3921 .64621 L p .707 .577 .707 r
F P
0 g
s
.44812 .58331 m .45297 .6342 L .47674 .62253 L p .707 .577 .707 r
F P
0 g
s
.47674 .62253 m .4719 .57164 L .44812 .58331 L p .707 .577 .707 r
F P
0 g
s
.64412 .6948 m .64509 .7125 L .63812 .72495 L p .707 .577 .707 r
F P
0 g
s
.65731 .56 m .66215 .6109 L .64609 .62494 L p .707 .577 .707 r
F P
0 g
s
.66215 .6109 m .65731 .56 L .68108 .54833 L p .707 .577 .707 r
F P
0 g
s
.64473 .64242 m .65008 .67318 L .64386 .69237 L p .707 .577 .707 r
F P
0 g
s
.83783 .69049 m .8388 .70819 L .82613 .69738 L p .707 .577 .707 r
F P
0 g
s
.82613 .69738 m .82515 .67968 L .83783 .69049 L p .707 .577 .707 r
F P
0 g
s
.65008 .67318 m .64473 .64242 L .66024 .62422 L p .707 .577 .707 r
F P
0 g
s
.33347 .63992 m .32863 .58903 L .30743 .5795 L p .707 .577 .707 r
F P
0 g
s
.32863 .58903 m .33347 .63992 L .36098 .64537 L p .707 .577 .707 r
F P
0 g
s
.82381 .60963 m .82917 .64039 L .80772 .62895 L p .707 .577 .707 r
F P
0 g
s
.80772 .62895 m .80236 .5982 L .82381 .60963 L p .707 .577 .707 r
F P
0 g
s
.80058 .54262 m .80542 .59351 L .77792 .58806 L p .707 .577 .707 r
F P
0 g
s
.77792 .58806 m .77307 .53717 L .80058 .54262 L p .707 .577 .707 r
F P
0 g
s
.4719 .57164 m .47674 .62253 L .49281 .60849 L p .707 .577 .707 r
F P
0 g
s
.49281 .60849 m .48796 .5576 L .4719 .57164 L p .707 .577 .707 r
F P
0 g
s
.64509 .7125 m .64412 .6948 L .66037 .68335 L p .707 .577 .707 r
F P
0 g
s
.3978 .70724 m .39244 .67649 L .3614 .6763 L p .707 .577 .707 r
F P
0 g
s
.39244 .67649 m .3978 .70724 L .42924 .70148 L p .707 .577 .707 r
F P
0 g
s
.42924 .70148 m .42388 .67073 L .39244 .67649 L p .707 .577 .707 r
F P
0 g
s
.68593 .59922 m .68108 .54833 L .71025 .54017 L p .707 .577 .707 r
F P
0 g
s
.68108 .54833 m .68593 .59922 L .66215 .6109 L p .707 .577 .707 r
F P
0 g
s
.42388 .67073 m .42924 .70148 L .45801 .69035 L p .707 .577 .707 r
F P
0 g
s
.45801 .69035 m .45265 .65959 L .42388 .67073 L p .707 .577 .707 r
F P
0 g
s
.39051 .7258 m .38954 .7081 L .35838 .70685 L p .707 .577 .707 r
F P
0 g
s
.38954 .7081 m .39051 .7258 L .4223 .72314 L p .707 .577 .707 r
F P
0 g
s
.4223 .72314 m .42132 .70544 L .38954 .7081 L p .707 .577 .707 r
F P
0 g
s
.42132 .70544 m .4223 .72314 L .4516 .71684 L p .707 .577 .707 r
F P
0 g
s
.4516 .71684 m .45063 .69914 L .42132 .70544 L p .707 .577 .707 r
F P
0 g
s
.77307 .53717 m .77792 .58806 L .74679 .58722 L p .707 .577 .707 r
F P
0 g
s
.74679 .58722 m .74194 .53633 L .77307 .53717 L p .707 .577 .707 r
F P
0 g
s
.66037 .68335 m .66135 .70105 L .64509 .7125 L p .707 .577 .707 r
F P
0 g
s
.36676 .70706 m .3614 .6763 L .33381 .67019 L p .707 .577 .707 r
F P
0 g
s
.3614 .6763 m .36676 .70706 L .3978 .70724 L p .707 .577 .707 r
F P
0 g
s
.66024 .62422 m .6656 .65498 L .65008 .67318 L p .707 .577 .707 r
F P
0 g
s
.6656 .65498 m .66024 .62422 L .68352 .6088 L p .707 .577 .707 r
F P
0 g
s
.35936 .72454 m .35838 .70685 L .33091 .70181 L p .707 .577 .707 r
F P
0 g
s
.35838 .70685 m .35936 .72454 L .39051 .7258 L p .707 .577 .707 r
F P
0 g
s
.31228 .63039 m .30743 .5795 L .29462 .56684 L p .707 .577 .707 r
F P
0 g
s
.30743 .5795 m .31228 .63039 L .33347 .63992 L p .707 .577 .707 r
F P
0 g
s
.45265 .65959 m .45801 .69035 L .48129 .67493 L p .707 .577 .707 r
F P
0 g
s
.48129 .67493 m .47593 .64417 L .45265 .65959 L p .707 .577 .707 r
F P
0 g
s
.80236 .5982 m .80772 .62895 L .78013 .62284 L p .707 .577 .707 r
F P
0 g
s
.78013 .62284 m .77477 .59209 L .80236 .5982 L p .707 .577 .707 r
F P
0 g
s
.7151 .59106 m .71025 .54017 L .74194 .53633 L p .707 .577 .707 r
F P
0 g
s
.71025 .54017 m .7151 .59106 L .68593 .59922 L p .707 .577 .707 r
F P
0 g
s
.82515 .67968 m .82613 .69738 L .80502 .68904 L p .707 .577 .707 r
F P
0 g
s
.80502 .68904 m .80405 .67135 L .82515 .67968 L p .707 .577 .707 r
F P
0 g
s
.74194 .53633 m .74679 .58722 L .7151 .59106 L p .707 .577 .707 r
F P
0 g
s
.45063 .69914 m .4516 .71684 L .47556 .7075 L p .707 .577 .707 r
F P
0 g
s
.47556 .7075 m .47458 .6898 L .45063 .69914 L p .707 .577 .707 r
F P
0 g
s
.33091 .70181 m .33188 .7195 L .35936 .72454 L p .707 .577 .707 r
F P
0 g
s
.48796 .5576 m .49281 .60849 L .49959 .59345 L p .707 .577 .707 r
F P
0 g
s
.49959 .59345 m .49474 .54256 L .48796 .5576 L p .707 .577 .707 r
F P
0 g
s
.33917 .70095 m .33381 .67019 L .31236 .65876 L p .707 .577 .707 r
F P
0 g
s
.33381 .67019 m .33917 .70095 L .36676 .70706 L p .707 .577 .707 r
F P
0 g
s
.68888 .63955 m .68352 .6088 L .71229 .59766 L p .707 .577 .707 r
F P
0 g
s
.68352 .6088 m .68888 .63955 L .6656 .65498 L p .707 .577 .707 r
F P
0 g
s
.33188 .7195 m .33091 .70181 L .3098 .69347 L p .707 .577 .707 r
F P
0 g
s
.47593 .64417 m .48129 .67493 L .49681 .65673 L p .707 .577 .707 r
F P
0 g
s
.49681 .65673 m .49145 .62597 L .47593 .64417 L p .707 .577 .707 r
F P
0 g
s
.77477 .59209 m .78013 .62284 L .74909 .62266 L p .707 .577 .707 r
F P
0 g
s
.74909 .62266 m .74373 .5919 L .77477 .59209 L p .707 .577 .707 r
F P
0 g
s
.66135 .70105 m .66037 .68335 L .68433 .67401 L p .707 .577 .707 r
F P
0 g
s
.3098 .69347 m .31078 .71117 L .33188 .7195 L p .707 .577 .707 r
F P
0 g
s
.71765 .62842 m .71229 .59766 L .74373 .5919 L p .707 .577 .707 r
F P
0 g
s
.71229 .59766 m .71765 .62842 L .68888 .63955 L p .707 .577 .707 r
F P
0 g
s
.68433 .67401 m .68531 .69171 L .66135 .70105 L p .707 .577 .707 r
F P
0 g
s
.74373 .5919 m .74909 .62266 L .71765 .62842 L p .707 .577 .707 r
F P
0 g
s
.47458 .6898 m .47556 .7075 L .49181 .69605 L p .707 .577 .707 r
F P
0 g
s
.49181 .69605 m .49084 .67835 L .47458 .6898 L p .707 .577 .707 r
F P
0 g
s
.80405 .67135 m .80502 .68904 L .77755 .684 L p .707 .577 .707 r
F P
0 g
s
.77755 .684 m .77657 .66631 L .80405 .67135 L p .707 .577 .707 r
F P
0 g
s
.29947 .61773 m .29462 .56684 L .29145 .55227 L p .707 .577 .707 r
F P
0 g
s
.29462 .56684 m .29947 .61773 L .31228 .63039 L p .707 .577 .707 r
F P
0 g
s
.31772 .68952 m .31236 .65876 L .29916 .64312 L p .707 .577 .707 r
F P
0 g
s
.31236 .65876 m .31772 .68952 L .33917 .70095 L p .707 .577 .707 r
F P
0 g
s
.68531 .69171 m .68433 .67401 L .71363 .66771 L p .707 .577 .707 r
F P
0 g
s
.49474 .54256 m .49959 .59345 L .49642 .57888 L p .707 .577 .707 r
F P
0 g
s
.49642 .57888 m .49157 .52799 L .49474 .54256 L p .707 .577 .707 r
F P
0 g
s
.49145 .62597 m .49681 .65673 L .50303 .63753 L p .707 .577 .707 r
F P
0 g
s
.50303 .63753 m .49767 .60677 L .49145 .62597 L p .707 .577 .707 r
F P
0 g
s
.31078 .71117 m .3098 .69347 L .29713 .68266 L p .707 .577 .707 r
F P
0 g
s
.77657 .66631 m .77755 .684 L .74639 .68275 L p .707 .577 .707 r
F P
0 g
s
.74639 .68275 m .74542 .66505 L .77657 .66631 L p .707 .577 .707 r
F P
0 g
s
.71363 .66771 m .71461 .68541 L .68531 .69171 L p .707 .577 .707 r
F P
0 g
s
.29713 .68266 m .29811 .70036 L .31078 .71117 L p .707 .577 .707 r
F P
0 g
s
.71461 .68541 m .71363 .66771 L .74542 .66505 L p .707 .577 .707 r
F P
0 g
s
.74542 .66505 m .74639 .68275 L .71461 .68541 L p .707 .577 .707 r
F P
0 g
s
.49084 .67835 m .49181 .69605 L .49879 .6836 L p .707 .577 .707 r
F P
0 g
s
.49879 .6836 m .49781 .6659 L .49084 .67835 L p .707 .577 .707 r
F P
0 g
s
.29145 .55227 m .2963 .60316 L .29947 .61773 L p .707 .577 .707 r
F P
0 g
s
.2963 .60316 m .29145 .55227 L .29823 .53723 L p .707 .577 .707 r
F P
0 g
s
.29916 .64312 m .30451 .67388 L .31772 .68952 L p .707 .577 .707 r
F P
0 g
s
.30451 .67388 m .29916 .64312 L .29549 .6248 L p .708 .578 .707 r
F P
0 g
s
.49767 .60677 m .50303 .63753 L .49936 .61921 L p .708 .578 .707 r
F P
0 g
s
.49936 .61921 m .49401 .58846 L .49767 .60677 L p .708 .578 .707 r
F P
0 g
s
.49157 .52799 m .49642 .57888 L .48361 .56622 L p .707 .577 .707 r
F P
0 g
s
.48361 .56622 m .47876 .51533 L .49157 .52799 L p .707 .577 .707 r
F P
0 g
s
.29811 .70036 m .29713 .68266 L .29413 .67044 L p .707 .577 .707 r
F P
0 g
s
.29413 .67044 m .29511 .68813 L .29811 .70036 L p .707 .577 .707 r
F P
0 g
s
.49781 .6659 m .49879 .6836 L .49579 .67137 L p .707 .577 .707 r
F P
0 g
s
.49579 .67137 m .49481 .65367 L .49781 .6659 L p .707 .577 .707 r
F P
0 g
s
.29823 .53723 m .30308 .58812 L .2963 .60316 L p .707 .577 .707 r
F P
0 g
s
.29549 .6248 m .30085 .65556 L .30451 .67388 L p .708 .578 .707 r
F P
0 g
s
.30308 .58812 m .29823 .53723 L .31429 .52319 L p .707 .577 .707 r
F P
0 g
s
.30085 .65556 m .29549 .6248 L .30171 .60561 L p .707 .577 .707 r
F P
0 g
s
.49401 .58846 m .49936 .61921 L .48616 .60357 L p .707 .577 .707 r
F P
0 g
s
.48616 .60357 m .4808 .57282 L .49401 .58846 L p .707 .577 .707 r
F P
0 g
s
.47876 .51533 m .48361 .56622 L .46241 .5567 L p .707 .577 .707 r
F P
0 g
s
.46241 .5567 m .45756 .50581 L .47876 .51533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29511 .68813 m .29413 .67044 L .30111 .65799 L p .707 .577 .707 r
F P
0 g
s
.30111 .65799 m .30208 .67568 L .29511 .68813 L p .707 .577 .707 r
F P
0 g
s
.31429 .52319 m .31914 .57408 L .30308 .58812 L p .707 .577 .707 r
F P
0 g
s
.31914 .57408 m .31429 .52319 L .33807 .51152 L p .707 .577 .707 r
F P
0 g
s
.30171 .60561 m .30707 .63636 L .30085 .65556 L p .707 .577 .707 r
F P
0 g
s
.49481 .65367 m .49579 .67137 L .48312 .66056 L p .707 .577 .707 r
F P
0 g
s
.48312 .66056 m .48214 .64286 L .49481 .65367 L p .707 .577 .707 r
F P
0 g
s
.30707 .63636 m .30171 .60561 L .31723 .5874 L p .707 .577 .707 r
F P
0 g
s
.4808 .57282 m .48616 .60357 L .46471 .59214 L p .707 .577 .707 r
F P
0 g
s
.46471 .59214 m .45935 .56138 L .4808 .57282 L p .707 .577 .707 r
F P
0 g
s
.45756 .50581 m .46241 .5567 L .43491 .55125 L p .707 .577 .707 r
F P
0 g
s
.43491 .55125 m .43006 .50036 L .45756 .50581 L p .707 .577 .707 r
F P
0 g
s
.30208 .67568 m .30111 .65799 L .31736 .64653 L p .707 .577 .707 r
F P
0 g
s
.34292 .56241 m .33807 .51152 L .36724 .50336 L p .707 .577 .707 r
F P
0 g
s
.33807 .51152 m .34292 .56241 L .31914 .57408 L p .707 .577 .707 r
F P
0 g
s
.43006 .50036 m .43491 .55125 L .40378 .5504 L p .707 .577 .707 r
F P
0 g
s
.40378 .5504 m .39893 .49951 L .43006 .50036 L p .707 .577 .707 r
F P
0 g
s
.31736 .64653 m .31834 .66423 L .30208 .67568 L p .707 .577 .707 r
F P
0 g
s
.31723 .5874 m .32259 .61816 L .30707 .63636 L p .707 .577 .707 r
F P
0 g
s
.32259 .61816 m .31723 .5874 L .34051 .57198 L p .707 .577 .707 r
F P
0 g
s
.45935 .56138 m .46471 .59214 L .43712 .58603 L p .707 .577 .707 r
F P
0 g
s
.43712 .58603 m .43176 .55527 L .45935 .56138 L p .707 .577 .707 r
F P
0 g
s
.37209 .55425 m .36724 .50336 L .39893 .49951 L p .707 .577 .707 r
F P
0 g
s
.36724 .50336 m .37209 .55425 L .34292 .56241 L p .707 .577 .707 r
F P
0 g
s
.48214 .64286 m .48312 .66056 L .46201 .65223 L p .707 .577 .707 r
F P
0 g
s
.46201 .65223 m .46104 .63453 L .48214 .64286 L p .707 .577 .707 r
F P
0 g
s
.39893 .49951 m .40378 .5504 L .37209 .55425 L p .707 .577 .707 r
F P
0 g
s
.34587 .60274 m .34051 .57198 L .36928 .56085 L p .707 .577 .707 r
F P
0 g
s
.34051 .57198 m .34587 .60274 L .32259 .61816 L p .707 .577 .707 r
F P
0 g
s
.43176 .55527 m .43712 .58603 L .40608 .58584 L p .707 .577 .707 r
F P
0 g
s
.40608 .58584 m .40072 .55509 L .43176 .55527 L p .707 .577 .707 r
F P
0 g
s
.31834 .66423 m .31736 .64653 L .34132 .6372 L p .707 .577 .707 r
F P
0 g
s
.37464 .5916 m .36928 .56085 L .40072 .55509 L p .707 .577 .707 r
F P
0 g
s
.36928 .56085 m .37464 .5916 L .34587 .60274 L p .707 .577 .707 r
F P
0 g
s
.34132 .6372 m .34229 .65489 L .31834 .66423 L p .707 .577 .707 r
F P
0 g
s
.40072 .55509 m .40608 .58584 L .37464 .5916 L p .707 .577 .707 r
F P
0 g
s
.46104 .63453 m .46201 .65223 L .43454 .64719 L p .707 .577 .707 r
F P
0 g
s
.43454 .64719 m .43356 .62949 L .46104 .63453 L p .707 .577 .707 r
F P
0 g
s
.34229 .65489 m .34132 .6372 L .37062 .63089 L p .707 .577 .707 r
F P
0 g
s
.43356 .62949 m .43454 .64719 L .40338 .64594 L p .707 .577 .707 r
F P
0 g
s
.40338 .64594 m .40241 .62824 L .43356 .62949 L p .707 .577 .707 r
F P
0 g
s
.37062 .63089 m .3716 .64859 L .34229 .65489 L p .707 .577 .707 r
F P
0 g
s
.3716 .64859 m .37062 .63089 L .40241 .62824 L p .707 .577 .707 r
F P
0 g
s
.40241 .62824 m .40338 .64594 L .3716 .64859 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Moob4008Eoo`00Lgoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF3000NGoo001_Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH8001aOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH015YF0`00JWoo001WOol30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02001VOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001J
EP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUHA0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`03001JEUYF00H000AJEP03001JEUYF00IJEP04001JEUYFFUH6000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006=o
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Ggoo10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001MOol200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005]oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FGoo
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001HOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P005goo3`00@7oo
001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000AOol60004FUH00`00FUIJEP06FUH00`00
FUH00003000lOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000=Ool400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3000iOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000:Ool30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000gOol0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000
FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
27oo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00=Goo
001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=JEP0000002`0000=J
EP0000000P000UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<00004
FUH000000005FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000bOol0059oo`04001JEUYF0004FUH00`00FUIJEP04
FUH40002FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUH00000<7oo001BOol01000FUIJEP0015YF00<005YFFUH00UYF0P000goo0`0000=J
EP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0000EJEP00001JEP00009JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP03001JEUYF008000=oo`<000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00D000=JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00Dgoo00<005YF000015YF0`000goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP800007FUH005YFFUH005YF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00Dgoo00<0
05YF000015YF00<007ooOol00Woo0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000IJEP00000005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Woo0016Ool>0002FUH01000
FUIJEP0017oo00<005YF000025YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00P005YF000005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00@7oo1P0015YF00<005YFFUH0
1UYF00D005YFFUH005YF0080009oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00004FUH00000000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00AJEPd000IJEP03001JEUYF009JEP04001JEP00FUH3000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
03]oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00<0009JEP@0009JEP03001JEUYF009J
EP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00
FUH005YF0P001UYF00<005YFFUH01EYF1@001EYF1P001UYF00<005YFFUH00`0015YF00D005YFFUH0
05YF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00AJEQD000=oo`@000EJEP05001JEUYFFUH0000^Ool003Ioo`800003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH01000FUH005YF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH0100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YF00000`000goo0P00
0eYF00D005YFFUIJEP0002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000UYF00@005YFFUH000MJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP800003FUH005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP<000=oo`<000QJEP03001J
EUYF00IJEP03001JEUYF00=JEP<0009oo`800003FUH005YF009JEP03001oogoo02aoo`00<Woo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF
FUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YF000005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0004FUH01000FUIJEUYF0P0017oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`000Woo0P000eYF00<007ooOol0;7oo000aOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YF000000Ao
o`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080009JEP03
001JEUYF008002eoo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP8000Aoo`8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF008002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP<000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<007ooOol00Woo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF1P00;Goo000]Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF00800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF008000=oo`80009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH0000002eoo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00;Goo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH00`00FUIJEP03000]Ool002]oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP04001JEUYF
FUH20005FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000015YF000005YF0P001eYF00<005YFFUH015YF1P0017oo1`001EYF1P001EYF00D005YF001JEP00
02eoo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPh0
009JEP<000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH005YF
008000IJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009J
EP03001JEP0000MJEP03001JEUYF009JEP`000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP05001JEP00FUH0000]Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH6
000=Ool00`00FUIJEP0600000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000IJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP04000COol01000FUIJEP001Goo1`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0000IJEP00FUIJEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04FUH200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00Oomoo`0/Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH4000HOol00eYF001oo`04Ool400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000
FUH000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP04001JEUYFFUH2000LOol00eYF001o
o`02Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF000015YF00@005YF
000001ioo`04FUH007ooOol20006FUH00`00FUIJEP04FUH60008FUH90004FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0005FUH01000FUH000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH007oo02aoo`00;7oo00<005YF000015YF0P004goo3P0000EJ
EP00001JEP0000IJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00EJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000002Ool2000]Ool002aoo`04001JEUYF0002FUH00`00Oomoo`0?Ool40002FUH00`00FUIJ
EP06FUH01000FUH000000eYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH025YF0P000UYF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=oo`03001JEP0002eoo`00;7oo00H005YFFUH0
05YF000>Ool40006FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH000030003FUH01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0`000UYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool00`00FUH0000]Ool002aoo`03001JEUYF00@000]oo`800003FUH005YF00QJEP03001JEUYF
00IJEP8000AJEP@00003FUH005YF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP06FUH01000FUH005YF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool00`00FUH0000]Ool002aoo`03
001JEUYF0080009JEP8000Ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP8000=JEP05001J
EP00001JEP020003FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001J
EUYF00EJEP03001JEP0000<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP80009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEP0001H0009JEP04001JEP00
0006Ool200000eYF0000000/Ool002aoo`03001JEUYF008000AJEPH000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEP00FUH30003FUH500001EYF001JEUYF00001EYF00<005YFFUH01eYF1000
1eYF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000UYF1@000eYF00<005YFFUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD000Ioo`03001JEP00009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH000EJ
EP@000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP02FUH00`00
FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`0000=JEP00Ool00Woo0`0000=JEP0000000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`000goo00@005YFFUH0009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH0
00EJEP04001JEUYF0008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0000AJ
EP03001JEUYF00=JEPh000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`04Ool3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
0003FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF0`000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF0`001eYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800004FUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`03Ool20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool0
02eoo`04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA00000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH01000FUH00000
0UYF0P0000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0003Ool20005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`80
009JEP<000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF00<0009JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP8000=JEP04001JEUYFFUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000goo00000006FUH00`00
FUIJEP04000HOol40005FUH00`00FUH00003000]Ool002eoo`80009JEP03001JEP0000IJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00800004FUH00000FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20002FUH20004FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001UYF00000000FUH000EJ
EPP001]oo`<000=JEP05001JEUYFFUH0000^Ool002ioo`03001JEP00009JEP03001JEUYF00EJEP03
001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP800003FUH0000000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP<000QJEP03001JEUYF009JEP800006FUH00000001JEP0015YF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
009JEP04001JEUYFFUH20004FUH01000FUH000006Woo00@005YFFUIJEP800003FUH005YF009JEP03
001oogoo02aoo`00;Woo0P000eYF00<005YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF
00@005YFFUH000=JEP03001JEP0000@00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP0000D000AJEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUH000030004FUH01000FUH0000067oo0P001UYF
0P000eYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00UYF1@001UYF00<005YFFUH01UYF
00<005YFFUH015YF1P000UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0`000UYF0P0015YF0`005Goo0`0000=J
EP00FUH01EYF00<005YF00000UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03
001JEP0000D0009JEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00AJEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH005YFFUH0
0003FUH20002FUH20002FUH00`00FUH0000BOol30004FUH00`00FUIJEP05FUH00`00FUH00002000^
Ool002ioo`03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF0000
00020005FUH5000015YF001JEP003Goo1@001eYF00<005YFFUH01EYF0P0000=oo`000000;Woo000]
Ool00`00FUH00004FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
00000002FUH00`00FUIJEP02FUH01000FUIJEUYF4P000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<007ooOol00`00;Goo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30005
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20003Ool00`00FUH0000]Ool002eoo`03001JEP0000=J
EP03001oogoo00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP020003Ool300000eYF
001oo`0/Ool002eoo`03001JEP00009JEP03001oogoo00Aoo`@0009JEP03001JEUYF00IJEP<0009J
EPH000eoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP040004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30003Ool20002FUH2000^
Ool002eoo`06001JEUYF001JEP002Woo40005Goo00<005YF00003`0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
001JEP800003FUH0000000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP8000=oo`8000AJEP8002ioo`00;Goo00<005YFFUH00P005Goo1@005Woo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH200000eYF00000003FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP03FUH00`00Oomo
o`0]Ool002eoo`04001JEUYF000FOol5000FOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000AJEP00FUIJEP<0009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000=oo`8000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH001Moo`<001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800005
FUH005YFFUH00002FUH20002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003Ool30005
FUH00`00FUIJEP02000`Ool002ioo`03FUH007oo01Ioo`l000Yoo`03001JEP00009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP0000AJEPT0009JEP03001JEUYF
00IJEP03001JEUYF00@000=oo`@00003FUH005YF00EJEP<0039oo`00;Woo00=JEP00Ool03Woo2000
15YF00<005YFFUH01UYF00<005YF00000`0017oo0`0015YF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000eYF0P001EYF00@005YFFUIJEQT000EJEP03001JEUYF00=JEP8003Aoo`00
;Woo00=JEP00Ool027oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Ioo`00;Woo00<005YF00001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00000hOol002ioo`04001JEUYF0003Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60003Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000jOol002ioo`800003FUH00000008000EJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20009Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04000mOol002ioo`800004FUH000000006FUH00`00FUIJEP02FUH8000?Ool40002FUH00`00FUIJ
EP03FUH01000FUIJEP001EYF00<005YFFUH01EYF8@001UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P003Woo6@00@Goo000_Ool20002FUH00`00FUIJEP03FUH6000DOol30003FUH5
0004FUH01000FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0P0047oo0P000UYF00<007ooOol0DGoo000^Ool00`00
FUIJEP02FUH01000FUIJEUYF10004Woo1P001eYF00@005YFFUIJEP<00005FUH005YFFUH00004FUH4
0003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH0
0`00FUIJEP03FUH2000?Ool00`00FUH00002FUH00`00Oomoo`1AOol002eoo`8000AJEP03001JEP00
008000=JEQ8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEP00008000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00=JEP8000ioo`04001JEUYF0002FUH00`00Oomoo`1AOol002eoo`8000AJEP80
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF009JEP80
0004Ool005YFFUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP04FUH2000=Ool01@00FUIJEUYF0000
0UYF00<007ooOol0DGoo000/Ool00`00FUH00002FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50006FUH00`00FUIJEP05FUH01@00FUIJEUYF00000goo0`000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@0015YF
1P0027oo00<005YFFUH00eYF0P00E7oo000/Ool00`00FUH0000200000goo00000004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP06FUH30004Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH2
0003FUH3000015YF000000000eYF2@001EYF0P00E7oo000/Ool00`00FUH00004Ool00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP06FUH00`00Oomoo`04Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH20005FUH50007FUH00`00FUH000020005FUH00`00Oomoo`1COol002aoo`80
00Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00Qoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001UYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool20008Ool200000eYF001JEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P002Goo0`000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0006FUH00`00FUIJEP03FUH200000eYF001oo`1EOol002aoo`<000Uoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000009Ool20002FUH300000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP060003FUH00`00FUIJEP03FUH01000FUH00000EWoo000/Ool2
00000eYF0000000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000:Ool00`00FUIJEP02
FUH200000goo000000020006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60003FUH50004FUH01@00FUIJEUYF0000EGoo
000/Ool20003FUH00`00Oomoo`0;Ool@000>Ool30004FUH20005Ool40002FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0007FUH01000FUIJEUYF0`0000=JEP00FUH00UYF00<007ooOol0Dgoo000]Ool01000FUIJEUYF0`00
9goo0P000UYF00<005YFFUH00UYF00<007ooOol027oo1@0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH04UYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF00<0
07ooOol0Dgoo000]Ool01@00FUIJEUYF00000UYF0P008Goo10001EYF00@005YFFUH0011oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPL000EJEP03001J
EUYF00MJEP03001JEUYF009JEP800005Ool005YFFUH0001EOol002ioo`04001JEUYF0004FUH5000H
Ool40002FUH00`00FUIJEP04FUH3000GOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH:0003
FUH50005FUH00`00FUIJEP06FUH01@00FUIJEUYF000017oo00<005YF0000EGoo000_Ool30005FUH0
1000FUIJEUYF60001UYF00<005YFFUH00eYF0P008Goo6P001EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01UYF00@005YFFUH000Ioo`8005Eoo`00<Goo00<005YFFUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8002moo`05001JEP00001o
o`020005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30007Ool2001E
Ool0039oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEP00000aOol00`00FUH00003Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH20009Ool3001DOol003Aoo`800003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<003=oo`8000Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000]oo`03001JEP0005Aoo`00=Woo1@00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P001goo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002goo0`0000=JEP00Ool0Dgoo000k
Ool90004FUH00`00FUIJEP02FUH7000jOol20009Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000<Ool20002FUH2001EOol004Aoo`T0045oo`04001JEP00000:Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP04000>Ool20004FUH2001EOol008ioo`80009JEP8000aoo`h000ioo`@00003FUH0
05YF00=JEP03001oogoo05Aoo`00Sgoo00D005YFFUH005YF00<0029oo`<000EJEP03001JEUYF009J
EP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEP<001]oo`@00003FUH005YF00EJEP03001JEUYF
008005Moo`00T7oo00<005YF00001EYF00<005YF00000`0047oo1`001EYF00<005YFFUH015YF0`00
FGoo002AOol20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001K
Ool0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<005eoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0`00HGoo002GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04001TOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL006Qoo`00WWoo4000Kgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59791 .76245 m .59306 .71156 L .56194 .71071 L p .707 .577 .707 r
F P
0 g
s
.59306 .71156 m .59791 .76245 L .62961 .7586 L p .707 .577 .707 r
F P
0 g
s
.62961 .7586 m .62476 .70771 L .59306 .71156 L p .707 .577 .707 r
F P
0 g
s
.62476 .70771 m .62961 .7586 L .65877 .75044 L p .707 .577 .707 r
F P
0 g
s
.65877 .75044 m .65392 .69955 L .62476 .70771 L p .707 .577 .707 r
F P
0 g
s
.56679 .7616 m .56194 .71071 L .53443 .70526 L p .707 .577 .707 r
F P
0 g
s
.56194 .71071 m .56679 .7616 L .59791 .76245 L p .707 .577 .707 r
F P
0 g
s
.65392 .69955 m .65877 .75044 L .68255 .73877 L p .707 .577 .707 r
F P
0 g
s
.68255 .73877 m .6777 .68788 L .65392 .69955 L p .707 .577 .707 r
F P
0 g
s
.53928 .75615 m .53443 .70526 L .51324 .69574 L p .707 .577 .707 r
F P
0 g
s
.53443 .70526 m .53928 .75615 L .56679 .7616 L p .707 .577 .707 r
F P
0 g
s
.6777 .68788 m .68255 .73877 L .69861 .72473 L p .707 .577 .707 r
F P
0 g
s
.69861 .72473 m .69377 .67384 L .6777 .68788 L p .707 .577 .707 r
F P
0 g
s
.60361 .8411 m .59825 .81035 L .56721 .81016 L p .707 .577 .707 r
F P
0 g
s
.59825 .81035 m .60361 .8411 L .63505 .83535 L p .707 .577 .707 r
F P
0 g
s
.63505 .83535 m .62969 .80459 L .59825 .81035 L p .707 .577 .707 r
F P
0 g
s
.62969 .80459 m .63505 .83535 L .66382 .82421 L p .707 .577 .707 r
F P
0 g
s
.66382 .82421 m .65846 .79346 L .62969 .80459 L p .707 .577 .707 r
F P
0 g
s
.51808 .74663 m .51324 .69574 L .50043 .68308 L p .707 .577 .707 r
F P
0 g
s
.51324 .69574 m .51808 .74663 L .53928 .75615 L p .707 .577 .707 r
F P
0 g
s
.59632 .87391 m .59534 .85621 L .56419 .85496 L p .707 .577 .707 r
F P
0 g
s
.59534 .85621 m .59632 .87391 L .6281 .87125 L p .707 .577 .707 r
F P
0 g
s
.6281 .87125 m .62713 .85356 L .59534 .85621 L p .707 .577 .707 r
F P
0 g
s
.62713 .85356 m .6281 .87125 L .65741 .86495 L p .707 .577 .707 r
F P
0 g
s
.65741 .86495 m .65643 .84725 L .62713 .85356 L p .707 .577 .707 r
F P
0 g
s
.57257 .84092 m .56721 .81016 L .53962 .80405 L p .707 .577 .707 r
F P
0 g
s
.56721 .81016 m .57257 .84092 L .60361 .8411 L p .707 .577 .707 r
F P
0 g
s
.65846 .79346 m .66382 .82421 L .6871 .80879 L p .707 .577 .707 r
F P
0 g
s
.6871 .80879 m .68174 .77803 L .65846 .79346 L p .707 .577 .707 r
F P
0 g
s
.56516 .87266 m .56419 .85496 L .53671 .84992 L p .707 .577 .707 r
F P
0 g
s
.56419 .85496 m .56516 .87266 L .59632 .87391 L p .707 .577 .707 r
F P
0 g
s
.69377 .67384 m .69861 .72473 L .70539 .70968 L p .707 .577 .707 r
F P
0 g
s
.70539 .70968 m .70055 .6588 L .69377 .67384 L p .707 .577 .707 r
F P
0 g
s
.65643 .84725 m .65741 .86495 L .68136 .85561 L p .707 .577 .707 r
F P
0 g
s
.68136 .85561 m .68038 .83792 L .65643 .84725 L p .707 .577 .707 r
F P
0 g
s
.53671 .84992 m .53769 .86762 L .56516 .87266 L p .707 .577 .707 r
F P
0 g
s
.54498 .83481 m .53962 .80405 L .51817 .79262 L p .707 .577 .707 r
F P
0 g
s
.53962 .80405 m .54498 .83481 L .57257 .84092 L p .707 .577 .707 r
F P
0 g
s
.68174 .77803 m .6871 .80879 L .70261 .79059 L p .707 .577 .707 r
F P
0 g
s
.70261 .79059 m .69725 .75983 L .68174 .77803 L p .707 .577 .707 r
F P
0 g
s
.53769 .86762 m .53671 .84992 L .51561 .84159 L p .707 .577 .707 r
F P
0 g
s
.50527 .73397 m .50043 .68308 L .49726 .66851 L p .707 .577 .707 r
F P
0 g
s
.50043 .68308 m .50527 .73397 L .51808 .74663 L p .707 .577 .707 r
F P
0 g
s
.51561 .84159 m .51658 .85928 L .53769 .86762 L p .707 .577 .707 r
F P
0 g
s
.68038 .83792 m .68136 .85561 L .69762 .84416 L p .707 .577 .707 r
F P
0 g
s
.69762 .84416 m .69664 .82646 L .68038 .83792 L p .707 .577 .707 r
F P
0 g
s
.70055 .6588 m .70539 .70968 L .70222 .69512 L p .707 .577 .707 r
F P
0 g
s
.70222 .69512 m .69738 .64423 L .70055 .6588 L p .707 .577 .707 r
F P
0 g
s
.52353 .82338 m .51817 .79262 L .50496 .77698 L p .707 .577 .707 r
F P
0 g
s
.51817 .79262 m .52353 .82338 L .54498 .83481 L p .707 .577 .707 r
F P
0 g
s
.69725 .75983 m .70261 .79059 L .70884 .77139 L p .707 .577 .707 r
F P
0 g
s
.70884 .77139 m .70348 .74063 L .69725 .75983 L p .707 .577 .707 r
F P
0 g
s
.51658 .85928 m .51561 .84159 L .50293 .83078 L p .707 .577 .707 r
F P
0 g
s
.49726 .66851 m .5021 .7194 L .50527 .73397 L p .707 .577 .707 r
F P
0 g
s
.50293 .83078 m .50391 .84847 L .51658 .85928 L p .707 .577 .707 r
F P
0 g
s
.5021 .7194 m .49726 .66851 L .50404 .65347 L p .707 .577 .707 r
F P
0 g
s
.69664 .82646 m .69762 .84416 L .70459 .83171 L p .707 .577 .707 r
F P
0 g
s
.70459 .83171 m .70362 .81401 L .69664 .82646 L p .707 .577 .707 r
F P
0 g
s
.50496 .77698 m .51032 .80774 L .52353 .82338 L p .707 .577 .707 r
F P
0 g
s
.51032 .80774 m .50496 .77698 L .50129 .75867 L p .708 .578 .707 r
F P
0 g
s
.69738 .64423 m .70222 .69512 L .68941 .68246 L p .707 .577 .707 r
F P
0 g
s
.68941 .68246 m .68457 .63157 L .69738 .64423 L p .707 .577 .707 r
F P
0 g
s
.70348 .74063 m .70884 .77139 L .70517 .75307 L p .708 .578 .707 r
F P
0 g
s
.70517 .75307 m .69981 .72232 L .70348 .74063 L p .708 .578 .707 r
F P
0 g
s
.48079 .81686 m .49636 .30616 L .45236 .30292 L p .707 .577 .707 r
F P
0 g
s
.50404 .65347 m .50888 .70436 L .5021 .7194 L p .707 .577 .707 r
F P
0 g
s
.50888 .70436 m .50404 .65347 L .5201 .63943 L p .707 .577 .707 r
F P
0 g
s
.50129 .75867 m .50665 .78942 L .51032 .80774 L p .708 .578 .707 r
F P
0 g
s
.50665 .78942 m .50129 .75867 L .50752 .73947 L p .707 .577 .707 r
F P
0 g
s
.50391 .84847 m .50293 .83078 L .49994 .81855 L p .707 .577 .707 r
F P
0 g
s
.49994 .81855 m .50092 .83625 L .50391 .84847 L p .707 .577 .707 r
F P
0 g
s
.50092 .83625 m .49994 .81855 L .50691 .8061 L p .707 .577 .707 r
F P
0 g
s
.5201 .63943 m .52495 .69032 L .50888 .70436 L p .707 .577 .707 r
F P
0 g
s
.50691 .8061 m .50789 .8238 L .50092 .83625 L p .707 .577 .707 r
F P
0 g
s
.50752 .73947 m .51288 .77022 L .50665 .78942 L p .707 .577 .707 r
F P
0 g
s
.51288 .77022 m .50752 .73947 L .52303 .72127 L p .707 .577 .707 r
F P
0 g
s
.50789 .8238 m .50691 .8061 L .52317 .79464 L p .707 .577 .707 r
F P
0 g
s
.52303 .72127 m .52839 .75202 L .51288 .77022 L p .707 .577 .707 r
F P
0 g
s
.52317 .79464 m .52415 .81234 L .50789 .8238 L p .707 .577 .707 r
F P
0 g
s
.52415 .81234 m .52317 .79464 L .54712 .78531 L p .707 .577 .707 r
F P
0 g
s
.54712 .78531 m .5481 .80301 L .52415 .81234 L p .707 .577 .707 r
F P
0 g
s
.49636 .30616 m .48079 .81686 L .52571 .81737 L p .707 .577 .707 r
F P
0 g
s
.52495 .69032 m .5201 .63943 L .54388 .62776 L p .707 .577 .707 r
F P
0 g
s
.54388 .62776 m .54873 .67865 L .52495 .69032 L p .707 .577 .707 r
F P
0 g
s
.52839 .75202 m .52303 .72127 L .54631 .70584 L p .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .54128 .30667 L .49636 .30616 L p .707 .577 .707 r
F P
0 g
s
.54873 .67865 m .54388 .62776 L .57304 .6196 L p .707 .577 .707 r
F P
0 g
s
.57304 .6196 m .57789 .67049 L .55413 .67713 L p .707 .577 .707 r
F P
0 g
s
.55413 .67713 m .54873 .67865 L p .55127 .67246 L .707 .577 .707 r
F P
0 g
s
.55127 .67246 m .57304 .6196 L .55413 .67713 L .707 .577 .707 r
F
.57643 .779 m .5774 .7967 L .56505 .79936 L p F P
0 g
s
.56505 .79936 m .5481 .80301 L p .56191 .7913 L .707 .577 .707 r
F P
0 g
s
.56191 .7913 m .57643 .779 L .56505 .79936 L .707 .577 .707 r
F
.58044 .72546 m .57508 .69471 L .58078 .69366 L p F P
0 g
s
.58078 .69366 m .60653 .68895 L p .58717 .71605 L .707 .577 .707 r
F P
0 g
s
.58044 .72546 m .58078 .69366 L .58717 .71605 L .707 .577 .707 r
F
.63586 .61659 m .64071 .66748 L .60959 .66664 L p F P
0 g
s
.60959 .66664 m .60474 .61575 L .63586 .61659 L p .707 .577 .707 r
F P
0 g
s
.60474 .61575 m .60959 .66664 L .57789 .67049 L p .707 .577 .707 r
F P
0 g
s
.63756 .68914 m .64292 .71989 L .61188 .71971 L p .707 .577 .707 r
F P
0 g
s
.61188 .71971 m .60653 .68895 L .63756 .68914 L p .707 .577 .707 r
F P
0 g
s
.60653 .68895 m .61188 .71971 L .58044 .72546 L p .707 .577 .707 r
F P
0 g
s
.63937 .7776 m .64034 .7953 L .60919 .79405 L p .707 .577 .707 r
F P
0 g
s
.60919 .79405 m .60821 .77635 L .63937 .7776 L p .707 .577 .707 r
F P
0 g
s
.5774 .7967 m .57643 .779 L .60821 .77635 L p .707 .577 .707 r
F P
0 g
s
.60821 .77635 m .60919 .79405 L .5774 .7967 L p .707 .577 .707 r
F P
0 g
s
.61663 .29957 m .60231 .76911 L p .62412 .80336 L .707 .577 .707 r
F P
0 g
s
.60231 .76911 m .60106 .81027 L .61304 .80668 L p .707 .577 .707 r
F P
0 g
s
.61304 .80668 m .62412 .80336 L p .60231 .76911 L .707 .577 .707 r
F P
0 g
s
.57508 .69471 m .58044 .72546 L .57208 .7287 L p .707 .577 .707 r
F P
0 g
s
.5481 .80301 m .54712 .78531 L .57643 .779 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .56744 .8055 L p .59819 .75169 L .707 .577 .707 r
F P
0 g
s
.52571 .81737 m .56715 .8151 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56136 .71926 L .56984 .72673 L .707 .577 .707 r
F
.56136 .71926 m .57508 .69471 L .5723 .72616 L F
.56984 .72673 m .5723 .72616 L .57208 .7287 L F
.56136 .71926 m .5723 .72616 L .56984 .72673 L F
.56274 .72838 m .55073 .73117 L .52571 .81737 L F
.54631 .70584 m .55073 .73117 L p .52839 .75202 L F P
0 g
s
.5452 .74089 m .52839 .75202 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52818 .73641 m .52707 .77275 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.52707 .77275 m .52571 .81737 L p .55073 .73117 L .707 .577 .707 r
F P
0 g
s
.55073 .73117 m .55167 .7366 L .5452 .74089 L p .707 .577 .707 r
F P
0 g
s
.55167 .7366 m .54631 .70584 L .57508 .69471 L p .707 .577 .707 r
F P
0 g
s
.58272 .3044 m .54128 .30667 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.56715 .8151 m .56984 .72673 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57789 .67049 m .57304 .6196 L .60474 .61575 L p .707 .577 .707 r
F P
0 g
s
.56984 .72673 m .58272 .3044 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.54128 .30667 m .52818 .73641 L p .56274 .72838 L .707 .577 .707 r
F P
0 g
s
.57208 .7287 m .55167 .7366 L p .5553 .73011 L .707 .577 .707 r
F P
0 g
s
.5553 .73011 m .56984 .72673 L .57208 .7287 L .707 .577 .707 r
F
.57054 .70402 m .56984 .72673 L p .59889 .75046 L F P
0 g
s
.59889 .75046 m .56984 .72673 L .59819 .75169 L .707 .577 .707 r
F
.56744 .8055 m .56715 .8151 L p .5694 .81052 L F P
0 g
s
.59889 .75046 m .56744 .8055 L .5694 .81052 L .707 .577 .707 r
F
.56715 .8151 m .60106 .81027 L p .59889 .75046 L F P
0 g
s
.58272 .3044 m .57054 .70402 L p .59889 .75046 L .707 .577 .707 r
F P
0 g
s
.43679 .81363 m .45236 .30292 L .41358 .29728 L p .707 .577 .707 r
F P
0 g
s
.45236 .30292 m .43679 .81363 L .48079 .81686 L p .707 .577 .707 r
F P
0 g
s
.70362 .81401 m .70459 .83171 L .7016 .81948 L p .707 .577 .707 r
F P
0 g
s
.7016 .81948 m .70062 .80178 L .70362 .81401 L p .707 .577 .707 r
F P
0 g
s
.2549 .72563 m .25005 .67474 L .21893 .6739 L p .707 .577 .707 r
F P
0 g
s
.25005 .67474 m .2549 .72563 L .2866 .72179 L p .707 .577 .707 r
F P
0 g
s
.2866 .72179 m .28175 .6709 L .25005 .67474 L p .707 .577 .707 r
F P
0 g
s
.28175 .6709 m .2866 .72179 L .31576 .71363 L p .707 .577 .707 r
F P
0 g
s
.31576 .71363 m .31091 .66274 L .28175 .6709 L p .707 .577 .707 r
F P
0 g
s
.68457 .63157 m .68941 .68246 L .66822 .67293 L p .707 .577 .707 r
F P
0 g
s
.66822 .67293 m .66337 .62204 L .68457 .63157 L p .707 .577 .707 r
F P
0 g
s
.69981 .72232 m .70517 .75307 L .69196 .73743 L p .707 .577 .707 r
F P
0 g
s
.69196 .73743 m .68661 .70668 L .69981 .72232 L p .707 .577 .707 r
F P
0 g
s
.60106 .81027 m .61663 .29957 L .58272 .3044 L p .707 .577 .707 r
F P
0 g
s
.22378 .72479 m .21893 .6739 L .19142 .66845 L p .707 .577 .707 r
F P
0 g
s
.21893 .6739 m .22378 .72479 L .2549 .72563 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31091 .66274 m .31576 .71363 L .33954 .70195 L p .707 .577 .707 r
F P
0 g
s
.33954 .70195 m .33469 .65106 L .31091 .66274 L p .707 .577 .707 r
F P
0 g
s
.39802 .80798 m .41358 .29728 L .38383 .28977 L p .707 .577 .707 r
F P
0 g
s
.41358 .29728 m .39802 .80798 L .43679 .81363 L p .707 .577 .707 r
F P
0 g
s
.19627 .71934 m .19142 .66845 L .17023 .65893 L p .707 .577 .707 r
F P
0 g
s
.19142 .66845 m .19627 .71934 L .22378 .72479 L p .707 .577 .707 r
F P
0 g
s
.66337 .62204 m .66822 .67293 L .64071 .66748 L p .707 .577 .707 r
F P
0 g
s
.64071 .66748 m .63586 .61659 L .66337 .62204 L p .707 .577 .707 r
F P
0 g
s
.70062 .80178 m .7016 .81948 L .68893 .80867 L p .707 .577 .707 r
F P
0 g
s
.68893 .80867 m .68795 .79097 L .70062 .80178 L p .707 .577 .707 r
F P
0 g
s
.68661 .70668 m .69196 .73743 L .67051 .726 L p .707 .577 .707 r
F P
0 g
s
.67051 .726 m .66516 .69524 L .68661 .70668 L p .707 .577 .707 r
F P
0 g
s
.33469 .65106 m .33954 .70195 L .35561 .68791 L p .707 .577 .707 r
F P
0 g
s
.35561 .68791 m .35076 .63702 L .33469 .65106 L p .707 .577 .707 r
F P
0 g
s
.62412 .80336 m .63968 .29266 L .61663 .29957 L p .707 .577 .707 r
F P
0 g
s
.2606 .80429 m .25524 .77353 L .2242 .77335 L p .707 .577 .707 r
F P
0 g
s
.25524 .77353 m .2606 .80429 L .29204 .79853 L p .707 .577 .707 r
F P
0 g
s
.29204 .79853 m .28668 .76778 L .25524 .77353 L p .707 .577 .707 r
F P
0 g
s
.28668 .76778 m .29204 .79853 L .32081 .7874 L p .707 .577 .707 r
F P
0 g
s
.32081 .7874 m .31545 .75664 L .28668 .76778 L p .707 .577 .707 r
F P
0 g
s
.17508 .70982 m .17023 .65893 L .15742 .64626 L p .707 .577 .707 r
F P
0 g
s
.17023 .65893 m .17508 .70982 L .19627 .71934 L p .707 .577 .707 r
F P
0 g
s
.25331 .83709 m .25233 .8194 L .22118 .81814 L p .707 .577 .707 r
F P
0 g
s
.25233 .8194 m .25331 .83709 L .2851 .83444 L p .707 .577 .707 r
F P
0 g
s
.2851 .83444 m .28412 .81674 L .25233 .8194 L p .707 .577 .707 r
F P
0 g
s
.28412 .81674 m .2851 .83444 L .3144 .82813 L p .707 .577 .707 r
F P
0 g
s
.3144 .82813 m .31342 .81044 L .28412 .81674 L p .707 .577 .707 r
F P
0 g
s
.22956 .8041 m .2242 .77335 L .19661 .76724 L p .707 .577 .707 r
F P
0 g
s
.2242 .77335 m .22956 .8041 L .2606 .80429 L p .707 .577 .707 r
F P
0 g
s
.36827 .80047 m .38383 .28977 L .36602 .28114 L p .707 .577 .707 r
F P
0 g
s
.38383 .28977 m .36827 .80047 L .39802 .80798 L p .707 .577 .707 r
F P
0 g
s
.31545 .75664 m .32081 .7874 L .34409 .77197 L p .707 .577 .707 r
F P
0 g
s
.34409 .77197 m .33873 .74122 L .31545 .75664 L p .707 .577 .707 r
F P
0 g
s
.66516 .69524 m .67051 .726 L .64292 .71989 L p .707 .577 .707 r
F P
0 g
s
.64292 .71989 m .63756 .68914 L .66516 .69524 L p .707 .577 .707 r
F P
0 g
s
.22216 .83584 m .22118 .81814 L .1937 .8131 L p .707 .577 .707 r
F P
0 g
s
.22118 .81814 m .22216 .83584 L .25331 .83709 L p .707 .577 .707 r
F P
0 g
s
.35076 .63702 m .35561 .68791 L .36238 .67287 L p .707 .577 .707 r
F P
0 g
s
.36238 .67287 m .35754 .62198 L .35076 .63702 L p .707 .577 .707 r
F P
0 g
s
.68795 .79097 m .68893 .80867 L .66782 .80034 L p .707 .577 .707 r
F P
0 g
s
.66782 .80034 m .66684 .78264 L .68795 .79097 L p .707 .577 .707 r
F P
0 g
s
.31342 .81044 m .3144 .82813 L .33835 .8188 L p .707 .577 .707 r
F P
0 g
s
.33835 .8188 m .33738 .8011 L .31342 .81044 L p .707 .577 .707 r
F P
0 g
s
.1937 .8131 m .19468 .8308 L .22216 .83584 L p .707 .577 .707 r
F P
0 g
s
.20197 .79799 m .19661 .76724 L .17516 .75581 L p .707 .577 .707 r
F P
0 g
s
.19661 .76724 m .20197 .79799 L .22956 .8041 L p .707 .577 .707 r
F P
0 g
s
.33873 .74122 m .34409 .77197 L .3596 .75377 L p .707 .577 .707 r
F P
0 g
s
.3596 .75377 m .35424 .72302 L .33873 .74122 L p .707 .577 .707 r
F P
0 g
s
.19468 .8308 m .1937 .8131 L .1726 .80477 L p .707 .577 .707 r
F P
0 g
s
.16227 .69715 m .15742 .64626 L .15425 .6317 L p .707 .577 .707 r
F P
0 g
s
.15742 .64626 m .16227 .69715 L .17508 .70982 L p .707 .577 .707 r
F P
0 g
s
.63968 .29266 m .62412 .80336 L .63406 .79504 L p .707 .577 .707 r
F P
0 g
s
.63406 .79504 m .64963 .28434 L .63968 .29266 L p .707 .577 .707 r
F P
0 g
s
.1726 .80477 m .17357 .82247 L .19468 .8308 L p .707 .577 .707 r
F P
0 g
s
.33738 .8011 m .33835 .8188 L .35461 .80734 L p .707 .577 .707 r
F P
0 g
s
.35461 .80734 m .35363 .78965 L .33738 .8011 L p .707 .577 .707 r
F P
0 g
s
.66684 .78264 m .66782 .80034 L .64034 .7953 L p .707 .577 .707 r
F P
0 g
s
.64034 .7953 m .63937 .7776 L .66684 .78264 L p .707 .577 .707 r
F P
0 g
s
.35754 .62198 m .36238 .67287 L .35921 .6583 L p .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35754 .62198 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35437 .60741 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.35437 .60741 m .35805 .64604 L p .3464 .64564 L .707 .577 .707 r
F P
0 g
s
.35805 .64604 m .35921 .6583 L .35684 .65596 L p .707 .577 .707 r
F P
0 g
s
.35684 .65596 m .3464 .64564 L p .35805 .64604 L .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .3568 .6855 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34895 .70062 m .34875 .69947 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.34875 .69947 m .3436 .66986 L p .34929 .69996 L .707 .577 .707 r
F P
0 g
s
.35424 .72302 m .3596 .75377 L .36583 .73457 L p .707 .577 .707 r
F P
0 g
s
.36583 .73457 m .36047 .70382 L .35424 .72302 L p .707 .577 .707 r
F P
0 g
s
.35363 .78965 m .35461 .80734 L .36158 .79489 L p .707 .577 .707 r
F P
0 g
s
.36158 .79489 m .36061 .7772 L .35363 .78965 L p .707 .577 .707 r
F P
0 g
s
.36047 .70382 m .36583 .73457 L .36318 .72135 L p .708 .578 .707 r
F P
0 g
s
.36198 .71491 m .36047 .70382 L .36318 .72135 L .708 .578 .707 r
F
.35761 .76497 m .35859 .78267 L .35126 .77641 L p .707 .577 .707 r
F P
0 g
s
.35126 .77641 m .34592 .77186 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.35198 .76829 m .35761 .76497 L .35126 .77641 L .707 .577 .707 r
F
.3568 .6855 m .35684 .6857 L p .34895 .70062 L F P
0 g
s
.34592 .77186 m .34494 .75416 L .35264 .76073 L p .707 .577 .707 r
F P
0 g
s
.35264 .76073 m .35761 .76497 L p .35198 .76829 L .707 .577 .707 r
F P
0 g
s
.34592 .77186 m .35264 .76073 L .35198 .76829 L .707 .577 .707 r
F
.35279 .70516 m .34895 .70062 L p .35684 .6857 L F P
0 g
s
.3464 .64564 m .34156 .59475 L .35437 .60741 L p .707 .577 .707 r
F P
0 g
s
.3436 .66986 m .34895 .70062 L .34285 .69736 L p .707 .577 .707 r
F P
0 g
s
.34285 .69736 m .32751 .68918 L p .34035 .67377 L .707 .577 .707 r
F P
0 g
s
.34035 .67377 m .3436 .66986 L .34285 .69736 L .707 .577 .707 r
F
.36188 .27223 m .34631 .78293 L .34998 .79084 L p F P
0 g
s
.35063 .78347 m .36188 .27223 L .34998 .79084 L .707 .577 .707 r
F
.35063 .78347 m .35313 .70356 L .35231 .70751 L F
.35074 .78224 m .35384 .68076 L p .35063 .78347 L F P
0 g
s
.35314 .70347 m .35045 .79184 L p .36482 .73015 L .707 .577 .707 r
F P
0 g
s
.36121 .71083 m .35314 .70347 L .36482 .73015 L .707 .577 .707 r
F
.35684 .6857 m .36216 .71626 L .35279 .70516 L p F P
0 g
s
.3568 .6855 m .36047 .70382 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36121 .71083 m .3568 .6855 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.35921 .6583 m .35805 .64604 L p .35878 .64882 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .35314 .70347 L p .3679 .71693 L .707 .577 .707 r
F P
0 g
s
.36602 .28114 m .36188 .27223 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.35522 .63529 m .36602 .28114 L p .354 .63062 L .707 .577 .707 r
F P
0 g
s
.36188 .27223 m .37183 .26391 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34631 .78293 m .34757 .74177 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34757 .74177 m .36188 .27223 L p .34809 .74672 L .707 .577 .707 r
F P
0 g
s
.34998 .79084 m .35045 .79184 L p .35063 .78347 L .707 .577 .707 r
F P
0 g
s
.35231 .70751 m .35384 .68076 L .35269 .69026 L .707 .577 .707 r
F
.35313 .70356 m .35384 .68076 L .35231 .70751 L F
.35045 .79184 m .35074 .78224 L p .35063 .78347 L F P
0 g
s
.3679 .71693 m .36121 .71083 L .36482 .73015 L .707 .577 .707 r
F
.36216 .71626 m .36121 .71083 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36318 .72135 m .36216 .71626 L p .36198 .71491 L .708 .578 .707 r
F P
0 g
s
.36061 .7772 m .36158 .79489 L .35859 .78267 L p .707 .577 .707 r
F P
0 g
s
.35859 .78267 m .35761 .76497 L .36061 .7772 L p .707 .577 .707 r
F P
0 g
s
.35045 .79184 m .36827 .80047 L p .36804 .74734 L .707 .577 .707 r
F P
0 g
s
.36804 .74734 m .3679 .71693 L .36482 .73015 L .707 .577 .707 r
F
.36804 .74734 m .36482 .73015 L .35045 .79184 L F
.35269 .69026 m .35522 .63529 L .354 .63062 L F
.35384 .68076 m .35522 .63529 L p .35269 .69026 L F P
0 g
s
.18052 .78656 m .17516 .75581 L .16195 .74017 L p .707 .577 .707 r
F P
0 g
s
.17516 .75581 m .18052 .78656 L .20197 .79799 L p .707 .577 .707 r
F P
0 g
s
.17357 .82247 m .1726 .80477 L .15993 .79396 L p .707 .577 .707 r
F P
0 g
s
.15425 .6317 m .15909 .68259 L .16227 .69715 L p .707 .577 .707 r
F P
0 g
s
.15993 .79396 m .1609 .81166 L .17357 .82247 L p .707 .577 .707 r
F P
0 g
s
.15909 .68259 m .15425 .6317 L .16103 .61666 L p .707 .577 .707 r
F P
0 g
s
.16195 .74017 m .16731 .77092 L .18052 .78656 L p .707 .577 .707 r
F P
0 g
s
.16731 .77092 m .16195 .74017 L .15828 .72185 L p .708 .578 .707 r
F P
0 g
s
.64963 .28434 m .63406 .79504 L .62992 .78613 L p .707 .577 .707 r
F P
0 g
s
.62992 .78613 m .64549 .27543 L .64963 .28434 L p .707 .577 .707 r
F P
0 g
s
.1609 .81166 m .15993 .79396 L .15693 .78173 L p .707 .577 .707 r
F P
0 g
s
.16103 .61666 m .16587 .66755 L .15909 .68259 L p .707 .577 .707 r
F P
0 g
s
.15693 .78173 m .15791 .79943 L .1609 .81166 L p .707 .577 .707 r
F P
0 g
s
.16587 .66755 m .16103 .61666 L .17709 .60261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15828 .72185 m .16364 .75261 L .16731 .77092 L p .708 .578 .707 r
F P
0 g
s
.16364 .75261 m .15828 .72185 L .16451 .70265 L p .707 .577 .707 r
F P
0 g
s
.34156 .59475 m .3464 .64564 L .32521 .63612 L p .707 .577 .707 r
F P
0 g
s
.32521 .63612 m .32036 .58523 L .34156 .59475 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15791 .79943 m .15693 .78173 L .1639 .76928 L p .707 .577 .707 r
F P
0 g
s
.17709 .60261 m .18194 .6535 L .16587 .66755 L p .707 .577 .707 r
F P
0 g
s
.18194 .6535 m .17709 .60261 L .20087 .59094 L p .707 .577 .707 r
F P
0 g
s
.1639 .76928 m .16488 .78698 L .15791 .79943 L p .707 .577 .707 r
F P
0 g
s
.16451 .70265 m .16987 .73341 L .16364 .75261 L p .707 .577 .707 r
F P
0 g
s
.32036 .58523 m .32521 .63612 L .2977 .63067 L p .707 .577 .707 r
F P
0 g
s
.2977 .63067 m .29286 .57978 L .32036 .58523 L p .707 .577 .707 r
F P
0 g
s
.16987 .73341 m .16451 .70265 L .18002 .68445 L p .707 .577 .707 r
F P
0 g
s
.64549 .27543 m .62992 .78613 L .61211 .7775 L p .707 .577 .707 r
F P
0 g
s
.61211 .7775 m .62768 .2668 L .64549 .27543 L p .707 .577 .707 r
F P
0 g
s
.32751 .68918 m .32215 .65843 L .3436 .66986 L p .707 .577 .707 r
F P
0 g
s
.20572 .64183 m .20087 .59094 L .23004 .58278 L p .707 .577 .707 r
F P
0 g
s
.20087 .59094 m .20572 .64183 L .18194 .6535 L p .707 .577 .707 r
F P
0 g
s
.29286 .57978 m .2977 .63067 L .26658 .62983 L p .707 .577 .707 r
F P
0 g
s
.26658 .62983 m .26173 .57894 L .29286 .57978 L p .707 .577 .707 r
F P
0 g
s
.16488 .78698 m .1639 .76928 L .18016 .75783 L p .707 .577 .707 r
F P
0 g
s
.35626 .77461 m .37183 .26391 L .39488 .257 L p .707 .577 .707 r
F P
0 g
s
.37183 .26391 m .35626 .77461 L .34631 .78293 L p .707 .577 .707 r
F P
0 g
s
.23488 .63367 m .23004 .58278 L .26173 .57894 L p .707 .577 .707 r
F P
0 g
s
.23004 .58278 m .23488 .63367 L .20572 .64183 L p .707 .577 .707 r
F P
0 g
s
.26173 .57894 m .26658 .62983 L .23488 .63367 L p .707 .577 .707 r
F P
0 g
s
.18002 .68445 m .18538 .71521 L .16987 .73341 L p .707 .577 .707 r
F P
0 g
s
.18538 .71521 m .18002 .68445 L .20331 .66903 L p .707 .577 .707 r
F P
0 g
s
.32215 .65843 m .32751 .68918 L .29991 .68308 L p .707 .577 .707 r
F P
0 g
s
.29991 .68308 m .29455 .65232 L .32215 .65843 L p .707 .577 .707 r
F P
0 g
s
.18016 .75783 m .18114 .77553 L .16488 .78698 L p .707 .577 .707 r
F P
0 g
s
.34494 .75416 m .34592 .77186 L .32481 .76353 L p .707 .577 .707 r
F P
0 g
s
.32481 .76353 m .32383 .74583 L .34494 .75416 L p .707 .577 .707 r
F P
0 g
s
.20866 .69978 m .20331 .66903 L .23207 .65789 L p .707 .577 .707 r
F P
0 g
s
.20331 .66903 m .20866 .69978 L .18538 .71521 L p .707 .577 .707 r
F P
0 g
s
.29455 .65232 m .29991 .68308 L .26887 .68289 L p .707 .577 .707 r
F P
0 g
s
.26887 .68289 m .26352 .65214 L .29455 .65232 L p .707 .577 .707 r
F P
0 g
s
.62768 .2668 m .61211 .7775 L .58236 .76999 L p .707 .577 .707 r
F P
0 g
s
.58236 .76999 m .59792 .25929 L .62768 .2668 L p .707 .577 .707 r
F P
0 g
s
.18114 .77553 m .18016 .75783 L .20411 .74849 L p .707 .577 .707 r
F P
0 g
s
.73511 .68302 m .73027 .63213 L .69914 .63129 L p .707 .577 .707 r
F P
0 g
s
.73027 .63213 m .73511 .68302 L .76681 .67918 L p .707 .577 .707 r
F P
0 g
s
.76681 .67918 m .76196 .62829 L .73027 .63213 L p .707 .577 .707 r
F P
0 g
s
.76196 .62829 m .76681 .67918 L .79598 .67102 L p .707 .577 .707 r
F P
0 g
s
.79598 .67102 m .79113 .62013 L .76196 .62829 L p .707 .577 .707 r
F P
0 g
s
.23743 .68865 m .23207 .65789 L .26352 .65214 L p .707 .577 .707 r
F P
0 g
s
.23207 .65789 m .23743 .68865 L .20866 .69978 L p .707 .577 .707 r
F P
0 g
s
.26352 .65214 m .26887 .68289 L .23743 .68865 L p .707 .577 .707 r
F P
0 g
s
.70399 .68218 m .69914 .63129 L .67164 .62584 L p .707 .577 .707 r
F P
0 g
s
.69914 .63129 m .70399 .68218 L .73511 .68302 L p .707 .577 .707 r
F P
0 g
s
.20411 .74849 m .20509 .76619 L .18114 .77553 L p .707 .577 .707 r
F P
0 g
s
.32383 .74583 m .32481 .76353 L .29733 .75849 L p .707 .577 .707 r
F P
0 g
s
.29733 .75849 m .29636 .74079 L .32383 .74583 L p .707 .577 .707 r
F P
0 g
s
.79113 .62013 m .79598 .67102 L .81975 .65935 L p .707 .577 .707 r
F P
0 g
s
.81975 .65935 m .81491 .60846 L .79113 .62013 L p .707 .577 .707 r
F P
0 g
s
.39488 .257 m .37931 .7677 L .35626 .77461 L p .707 .577 .707 r
F P
0 g
s
.37931 .7677 m .39488 .257 L .42879 .25217 L p .707 .577 .707 r
F P
0 g
s
.20509 .76619 m .20411 .74849 L .23342 .74219 L p .707 .577 .707 r
F P
0 g
s
.67648 .67673 m .67164 .62584 L .65044 .61632 L p .707 .577 .707 r
F P
0 g
s
.67164 .62584 m .67648 .67673 L .70399 .68218 L p .707 .577 .707 r
F P
0 g
s
.29636 .74079 m .29733 .75849 L .26618 .75723 L p .707 .577 .707 r
F P
0 g
s
.26618 .75723 m .2652 .73953 L .29636 .74079 L p .707 .577 .707 r
F P
0 g
s
.23342 .74219 m .23439 .75989 L .20509 .76619 L p .707 .577 .707 r
F P
0 g
s
.81491 .60846 m .81975 .65935 L .83582 .6453 L p .707 .577 .707 r
F P
0 g
s
.83582 .6453 m .83097 .59441 L .81491 .60846 L p .707 .577 .707 r
F P
0 g
s
.23439 .75989 m .23342 .74219 L .2652 .73953 L p .707 .577 .707 r
F P
0 g
s
.2652 .73953 m .26618 .75723 L .23439 .75989 L p .707 .577 .707 r
F P
0 g
s
.59792 .25929 m .58236 .76999 L .54359 .76435 L p .707 .577 .707 r
F P
0 g
s
.54359 .76435 m .55915 .25364 L .59792 .25929 L p .707 .577 .707 r
F P
0 g
s
.74081 .74406 m .73545 .7133 L .70441 .71312 L p .707 .577 .707 r
F P
0 g
s
.73545 .7133 m .74081 .74406 L .77225 .7383 L p .707 .577 .707 r
F P
0 g
s
.77225 .7383 m .76689 .70754 L .73545 .7133 L p .707 .577 .707 r
F P
0 g
s
.76689 .70754 m .77225 .7383 L .80102 .72717 L p .707 .577 .707 r
F P
0 g
s
.80102 .72717 m .79566 .69641 L .76689 .70754 L p .707 .577 .707 r
F P
0 g
s
.73352 .76261 m .73255 .74491 L .70139 .74366 L p .707 .577 .707 r
F P
0 g
s
.73255 .74491 m .73352 .76261 L .76531 .75996 L p .707 .577 .707 r
F P
0 g
s
.76531 .75996 m .76433 .74226 L .73255 .74491 L p .707 .577 .707 r
F P
0 g
s
.76433 .74226 m .76531 .75996 L .79461 .75365 L p .707 .577 .707 r
F P
0 g
s
.79461 .75365 m .79364 .73595 L .76433 .74226 L p .707 .577 .707 r
F P
0 g
s
.41322 .76287 m .42879 .25217 L .47023 .2499 L p .707 .577 .707 r
F P
0 g
s
.42879 .25217 m .41322 .76287 L .37931 .7677 L p .707 .577 .707 r
F P
0 g
s
.70977 .74387 m .70441 .71312 L .67682 .70701 L p .707 .577 .707 r
F P
0 g
s
.70441 .71312 m .70977 .74387 L .74081 .74406 L p .707 .577 .707 r
F P
0 g
s
.70237 .76136 m .70139 .74366 L .67392 .73862 L p .707 .577 .707 r
F P
0 g
s
.70139 .74366 m .70237 .76136 L .73352 .76261 L p .707 .577 .707 r
F P
0 g
s
.65529 .66721 m .65044 .61632 L .63763 .60365 L p .707 .577 .707 r
F P
0 g
s
.65044 .61632 m .65529 .66721 L .67648 .67673 L p .707 .577 .707 r
F P
0 g
s
.79566 .69641 m .80102 .72717 L .8243 .71174 L p .707 .577 .707 r
F P
0 g
s
.8243 .71174 m .81894 .68099 L .79566 .69641 L p .707 .577 .707 r
F P
0 g
s
.79364 .73595 m .79461 .75365 L .81857 .74432 L p .707 .577 .707 r
F P
0 g
s
.81857 .74432 m .81759 .72662 L .79364 .73595 L p .707 .577 .707 r
F P
0 g
s
.67392 .73862 m .67489 .75632 L .70237 .76136 L p .707 .577 .707 r
F P
0 g
s
.83097 .59441 m .83582 .6453 L .8426 .63026 L p .707 .577 .707 r
F P
0 g
s
.8426 .63026 m .83775 .57937 L .83097 .59441 L p .707 .577 .707 r
F P
0 g
s
.55915 .25364 m .54359 .76435 L .49959 .76111 L p .707 .577 .707 r
F P
0 g
s
.49959 .76111 m .51515 .2504 L .55915 .25364 L p .707 .577 .707 r
F P
0 g
s
.68218 .73776 m .67682 .70701 L .65537 .69558 L p .707 .577 .707 r
F P
0 g
s
.67682 .70701 m .68218 .73776 L .70977 .74387 L p .707 .577 .707 r
F P
0 g
s
.67489 .75632 m .67392 .73862 L .65281 .73029 L p .707 .577 .707 r
F P
0 g
s
.45467 .7606 m .47023 .2499 L .51515 .2504 L p .707 .577 .707 r
F P
0 g
s
.47023 .2499 m .45467 .7606 L .41322 .76287 L p .707 .577 .707 r
F P
0 g
s
.81894 .68099 m .8243 .71174 L .83982 .69354 L p .707 .577 .707 r
F P
0 g
s
.83982 .69354 m .83446 .66279 L .81894 .68099 L p .707 .577 .707 r
F P
0 g
s
.51515 .2504 m .49959 .76111 L .45467 .7606 L p .707 .577 .707 r
F P
0 g
s
.65281 .73029 m .65379 .74799 L .67489 .75632 L p .707 .577 .707 r
F P
0 g
s
.81759 .72662 m .81857 .74432 L .83482 .73286 L p .707 .577 .707 r
F P
0 g
s
.83482 .73286 m .83385 .71517 L .81759 .72662 L p .707 .577 .707 r
F P
0 g
s
.64248 .65454 m .63763 .60365 L .63446 .58909 L p .707 .577 .707 r
F P
0 g
s
.63763 .60365 m .64248 .65454 L .65529 .66721 L p .707 .577 .707 r
F P
0 g
s
.66073 .72633 m .65537 .69558 L .64217 .67994 L p .707 .577 .707 r
F P
0 g
s
.65537 .69558 m .66073 .72633 L .68218 .73776 L p .707 .577 .707 r
F P
0 g
s
.83775 .57937 m .8426 .63026 L .83943 .6157 L p .707 .577 .707 r
F P
0 g
s
.83943 .6157 m .83458 .56481 L .83775 .57937 L p .707 .577 .707 r
F P
0 g
s
.83446 .66279 m .83982 .69354 L .84604 .67434 L p .707 .577 .707 r
F P
0 g
s
.84604 .67434 m .84068 .64359 L .83446 .66279 L p .707 .577 .707 r
F P
0 g
s
.65379 .74799 m .65281 .73029 L .64014 .71948 L p .707 .577 .707 r
F P
0 g
s
.64014 .71948 m .64112 .73718 L .65379 .74799 L p .707 .577 .707 r
F P
0 g
s
.83385 .71517 m .83482 .73286 L .8418 .72041 L p .707 .577 .707 r
F P
0 g
s
.8418 .72041 m .84082 .70272 L .83385 .71517 L p .707 .577 .707 r
F P
0 g
s
.63446 .58909 m .63931 .63998 L .64248 .65454 L p .707 .577 .707 r
F P
0 g
s
.63931 .63998 m .63446 .58909 L .64124 .57405 L p .707 .577 .707 r
F P
0 g
s
.64217 .67994 m .64753 .71069 L .66073 .72633 L p .707 .577 .707 r
F P
0 g
s
.64753 .71069 m .64217 .67994 L .6385 .66162 L p .708 .578 .707 r
F P
0 g
s
.84068 .64359 m .84604 .67434 L .84237 .65603 L p .708 .578 .707 r
F P
0 g
s
.84237 .65603 m .83702 .62527 L .84068 .64359 L p .708 .578 .707 r
F P
0 g
s
.83458 .56481 m .83943 .6157 L .82662 .60303 L p .707 .577 .707 r
F P
0 g
s
.82662 .60303 m .82177 .55214 L .83458 .56481 L p .707 .577 .707 r
F P
0 g
s
.64112 .73718 m .64014 .71948 L .63714 .70725 L p .707 .577 .707 r
F P
0 g
s
.63714 .70725 m .63812 .72495 L .64112 .73718 L p .707 .577 .707 r
F P
0 g
s
.84082 .70272 m .8418 .72041 L .8388 .70819 L p .707 .577 .707 r
F P
0 g
s
.8388 .70819 m .83783 .69049 L .84082 .70272 L p .707 .577 .707 r
F P
0 g
s
.64124 .57405 m .64609 .62494 L .63931 .63998 L p .707 .577 .707 r
F P
0 g
s
.6385 .66162 m .64386 .69237 L .64753 .71069 L p .708 .578 .707 r
F P
0 g
s
.64609 .62494 m .64124 .57405 L .65731 .56 L p .707 .577 .707 r
F P
0 g
s
.64386 .69237 m .6385 .66162 L .64473 .64242 L p .707 .577 .707 r
F P
0 g
s
.3921 .64621 m .38726 .59532 L .35613 .59448 L p .707 .577 .707 r
F P
0 g
s
.38726 .59532 m .3921 .64621 L .4238 .64236 L p .707 .577 .707 r
F P
0 g
s
.4238 .64236 m .41895 .59147 L .38726 .59532 L p .707 .577 .707 r
F P
0 g
s
.83702 .62527 m .84237 .65603 L .82917 .64039 L p .707 .577 .707 r
F P
0 g
s
.82917 .64039 m .82381 .60963 L .83702 .62527 L p .707 .577 .707 r
F P
0 g
s
.41895 .59147 m .4238 .64236 L .45297 .6342 L p .707 .577 .707 r
F P
0 g
s
.45297 .6342 m .44812 .58331 L .41895 .59147 L p .707 .577 .707 r
F P
0 g
s
.82177 .55214 m .82662 .60303 L .80542 .59351 L p .707 .577 .707 r
F P
0 g
s
.80542 .59351 m .80058 .54262 L .82177 .55214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63812 .72495 m .63714 .70725 L .64412 .6948 L p .707 .577 .707 r
F P
0 g
s
.36098 .64537 m .35613 .59448 L .32863 .58903 L p .707 .577 .707 r
F P
0 g
s
.35613 .59448 m .36098 .64537 L .3921 .64621 L p .707 .577 .707 r
F P
0 g
s
.44812 .58331 m .45297 .6342 L .47674 .62253 L p .707 .577 .707 r
F P
0 g
s
.47674 .62253 m .4719 .57164 L .44812 .58331 L p .707 .577 .707 r
F P
0 g
s
.64412 .6948 m .64509 .7125 L .63812 .72495 L p .707 .577 .707 r
F P
0 g
s
.65731 .56 m .66215 .6109 L .64609 .62494 L p .707 .577 .707 r
F P
0 g
s
.66215 .6109 m .65731 .56 L .68108 .54833 L p .707 .577 .707 r
F P
0 g
s
.64473 .64242 m .65008 .67318 L .64386 .69237 L p .707 .577 .707 r
F P
0 g
s
.83783 .69049 m .8388 .70819 L .82613 .69738 L p .707 .577 .707 r
F P
0 g
s
.82613 .69738 m .82515 .67968 L .83783 .69049 L p .707 .577 .707 r
F P
0 g
s
.65008 .67318 m .64473 .64242 L .66024 .62422 L p .707 .577 .707 r
F P
0 g
s
.33347 .63992 m .32863 .58903 L .30743 .5795 L p .707 .577 .707 r
F P
0 g
s
.32863 .58903 m .33347 .63992 L .36098 .64537 L p .707 .577 .707 r
F P
0 g
s
.82381 .60963 m .82917 .64039 L .80772 .62895 L p .707 .577 .707 r
F P
0 g
s
.80772 .62895 m .80236 .5982 L .82381 .60963 L p .707 .577 .707 r
F P
0 g
s
.80058 .54262 m .80542 .59351 L .77792 .58806 L p .707 .577 .707 r
F P
0 g
s
.77792 .58806 m .77307 .53717 L .80058 .54262 L p .707 .577 .707 r
F P
0 g
s
.4719 .57164 m .47674 .62253 L .49281 .60849 L p .707 .577 .707 r
F P
0 g
s
.49281 .60849 m .48796 .5576 L .4719 .57164 L p .707 .577 .707 r
F P
0 g
s
.64509 .7125 m .64412 .6948 L .66037 .68335 L p .707 .577 .707 r
F P
0 g
s
.3978 .70724 m .39244 .67649 L .3614 .6763 L p .707 .577 .707 r
F P
0 g
s
.39244 .67649 m .3978 .70724 L .42924 .70148 L p .707 .577 .707 r
F P
0 g
s
.42924 .70148 m .42388 .67073 L .39244 .67649 L p .707 .577 .707 r
F P
0 g
s
.68593 .59922 m .68108 .54833 L .71025 .54017 L p .707 .577 .707 r
F P
0 g
s
.68108 .54833 m .68593 .59922 L .66215 .6109 L p .707 .577 .707 r
F P
0 g
s
.42388 .67073 m .42924 .70148 L .45801 .69035 L p .707 .577 .707 r
F P
0 g
s
.45801 .69035 m .45265 .65959 L .42388 .67073 L p .707 .577 .707 r
F P
0 g
s
.39051 .7258 m .38954 .7081 L .35838 .70685 L p .707 .577 .707 r
F P
0 g
s
.38954 .7081 m .39051 .7258 L .4223 .72314 L p .707 .577 .707 r
F P
0 g
s
.4223 .72314 m .42132 .70544 L .38954 .7081 L p .707 .577 .707 r
F P
0 g
s
.42132 .70544 m .4223 .72314 L .4516 .71684 L p .707 .577 .707 r
F P
0 g
s
.4516 .71684 m .45063 .69914 L .42132 .70544 L p .707 .577 .707 r
F P
0 g
s
.77307 .53717 m .77792 .58806 L .74679 .58722 L p .707 .577 .707 r
F P
0 g
s
.74679 .58722 m .74194 .53633 L .77307 .53717 L p .707 .577 .707 r
F P
0 g
s
.66037 .68335 m .66135 .70105 L .64509 .7125 L p .707 .577 .707 r
F P
0 g
s
.36676 .70706 m .3614 .6763 L .33381 .67019 L p .707 .577 .707 r
F P
0 g
s
.3614 .6763 m .36676 .70706 L .3978 .70724 L p .707 .577 .707 r
F P
0 g
s
.66024 .62422 m .6656 .65498 L .65008 .67318 L p .707 .577 .707 r
F P
0 g
s
.6656 .65498 m .66024 .62422 L .68352 .6088 L p .707 .577 .707 r
F P
0 g
s
.35936 .72454 m .35838 .70685 L .33091 .70181 L p .707 .577 .707 r
F P
0 g
s
.35838 .70685 m .35936 .72454 L .39051 .7258 L p .707 .577 .707 r
F P
0 g
s
.31228 .63039 m .30743 .5795 L .29462 .56684 L p .707 .577 .707 r
F P
0 g
s
.30743 .5795 m .31228 .63039 L .33347 .63992 L p .707 .577 .707 r
F P
0 g
s
.45265 .65959 m .45801 .69035 L .48129 .67493 L p .707 .577 .707 r
F P
0 g
s
.48129 .67493 m .47593 .64417 L .45265 .65959 L p .707 .577 .707 r
F P
0 g
s
.80236 .5982 m .80772 .62895 L .78013 .62284 L p .707 .577 .707 r
F P
0 g
s
.78013 .62284 m .77477 .59209 L .80236 .5982 L p .707 .577 .707 r
F P
0 g
s
.7151 .59106 m .71025 .54017 L .74194 .53633 L p .707 .577 .707 r
F P
0 g
s
.71025 .54017 m .7151 .59106 L .68593 .59922 L p .707 .577 .707 r
F P
0 g
s
.82515 .67968 m .82613 .69738 L .80502 .68904 L p .707 .577 .707 r
F P
0 g
s
.80502 .68904 m .80405 .67135 L .82515 .67968 L p .707 .577 .707 r
F P
0 g
s
.74194 .53633 m .74679 .58722 L .7151 .59106 L p .707 .577 .707 r
F P
0 g
s
.45063 .69914 m .4516 .71684 L .47556 .7075 L p .707 .577 .707 r
F P
0 g
s
.47556 .7075 m .47458 .6898 L .45063 .69914 L p .707 .577 .707 r
F P
0 g
s
.33091 .70181 m .33188 .7195 L .35936 .72454 L p .707 .577 .707 r
F P
0 g
s
.48796 .5576 m .49281 .60849 L .49959 .59345 L p .707 .577 .707 r
F P
0 g
s
.49959 .59345 m .49474 .54256 L .48796 .5576 L p .707 .577 .707 r
F P
0 g
s
.33917 .70095 m .33381 .67019 L .31236 .65876 L p .707 .577 .707 r
F P
0 g
s
.33381 .67019 m .33917 .70095 L .36676 .70706 L p .707 .577 .707 r
F P
0 g
s
.68888 .63955 m .68352 .6088 L .71229 .59766 L p .707 .577 .707 r
F P
0 g
s
.68352 .6088 m .68888 .63955 L .6656 .65498 L p .707 .577 .707 r
F P
0 g
s
.33188 .7195 m .33091 .70181 L .3098 .69347 L p .707 .577 .707 r
F P
0 g
s
.47593 .64417 m .48129 .67493 L .49681 .65673 L p .707 .577 .707 r
F P
0 g
s
.49681 .65673 m .49145 .62597 L .47593 .64417 L p .707 .577 .707 r
F P
0 g
s
.77477 .59209 m .78013 .62284 L .74909 .62266 L p .707 .577 .707 r
F P
0 g
s
.74909 .62266 m .74373 .5919 L .77477 .59209 L p .707 .577 .707 r
F P
0 g
s
.66135 .70105 m .66037 .68335 L .68433 .67401 L p .707 .577 .707 r
F P
0 g
s
.3098 .69347 m .31078 .71117 L .33188 .7195 L p .707 .577 .707 r
F P
0 g
s
.71765 .62842 m .71229 .59766 L .74373 .5919 L p .707 .577 .707 r
F P
0 g
s
.71229 .59766 m .71765 .62842 L .68888 .63955 L p .707 .577 .707 r
F P
0 g
s
.68433 .67401 m .68531 .69171 L .66135 .70105 L p .707 .577 .707 r
F P
0 g
s
.74373 .5919 m .74909 .62266 L .71765 .62842 L p .707 .577 .707 r
F P
0 g
s
.47458 .6898 m .47556 .7075 L .49181 .69605 L p .707 .577 .707 r
F P
0 g
s
.49181 .69605 m .49084 .67835 L .47458 .6898 L p .707 .577 .707 r
F P
0 g
s
.80405 .67135 m .80502 .68904 L .77755 .684 L p .707 .577 .707 r
F P
0 g
s
.77755 .684 m .77657 .66631 L .80405 .67135 L p .707 .577 .707 r
F P
0 g
s
.29947 .61773 m .29462 .56684 L .29145 .55227 L p .707 .577 .707 r
F P
0 g
s
.29462 .56684 m .29947 .61773 L .31228 .63039 L p .707 .577 .707 r
F P
0 g
s
.31772 .68952 m .31236 .65876 L .29916 .64312 L p .707 .577 .707 r
F P
0 g
s
.31236 .65876 m .31772 .68952 L .33917 .70095 L p .707 .577 .707 r
F P
0 g
s
.68531 .69171 m .68433 .67401 L .71363 .66771 L p .707 .577 .707 r
F P
0 g
s
.49474 .54256 m .49959 .59345 L .49642 .57888 L p .707 .577 .707 r
F P
0 g
s
.49642 .57888 m .49157 .52799 L .49474 .54256 L p .707 .577 .707 r
F P
0 g
s
.49145 .62597 m .49681 .65673 L .50303 .63753 L p .707 .577 .707 r
F P
0 g
s
.50303 .63753 m .49767 .60677 L .49145 .62597 L p .707 .577 .707 r
F P
0 g
s
.31078 .71117 m .3098 .69347 L .29713 .68266 L p .707 .577 .707 r
F P
0 g
s
.77657 .66631 m .77755 .684 L .74639 .68275 L p .707 .577 .707 r
F P
0 g
s
.74639 .68275 m .74542 .66505 L .77657 .66631 L p .707 .577 .707 r
F P
0 g
s
.71363 .66771 m .71461 .68541 L .68531 .69171 L p .707 .577 .707 r
F P
0 g
s
.29713 .68266 m .29811 .70036 L .31078 .71117 L p .707 .577 .707 r
F P
0 g
s
.71461 .68541 m .71363 .66771 L .74542 .66505 L p .707 .577 .707 r
F P
0 g
s
.74542 .66505 m .74639 .68275 L .71461 .68541 L p .707 .577 .707 r
F P
0 g
s
.49084 .67835 m .49181 .69605 L .49879 .6836 L p .707 .577 .707 r
F P
0 g
s
.49879 .6836 m .49781 .6659 L .49084 .67835 L p .707 .577 .707 r
F P
0 g
s
.29145 .55227 m .2963 .60316 L .29947 .61773 L p .707 .577 .707 r
F P
0 g
s
.2963 .60316 m .29145 .55227 L .29823 .53723 L p .707 .577 .707 r
F P
0 g
s
.29916 .64312 m .30451 .67388 L .31772 .68952 L p .707 .577 .707 r
F P
0 g
s
.30451 .67388 m .29916 .64312 L .29549 .6248 L p .708 .578 .707 r
F P
0 g
s
.49767 .60677 m .50303 .63753 L .49936 .61921 L p .708 .578 .707 r
F P
0 g
s
.49936 .61921 m .49401 .58846 L .49767 .60677 L p .708 .578 .707 r
F P
0 g
s
.49157 .52799 m .49642 .57888 L .48361 .56622 L p .707 .577 .707 r
F P
0 g
s
.48361 .56622 m .47876 .51533 L .49157 .52799 L p .707 .577 .707 r
F P
0 g
s
.29811 .70036 m .29713 .68266 L .29413 .67044 L p .707 .577 .707 r
F P
0 g
s
.29413 .67044 m .29511 .68813 L .29811 .70036 L p .707 .577 .707 r
F P
0 g
s
.49781 .6659 m .49879 .6836 L .49579 .67137 L p .707 .577 .707 r
F P
0 g
s
.49579 .67137 m .49481 .65367 L .49781 .6659 L p .707 .577 .707 r
F P
0 g
s
.29823 .53723 m .30308 .58812 L .2963 .60316 L p .707 .577 .707 r
F P
0 g
s
.29549 .6248 m .30085 .65556 L .30451 .67388 L p .708 .578 .707 r
F P
0 g
s
.30308 .58812 m .29823 .53723 L .31429 .52319 L p .707 .577 .707 r
F P
0 g
s
.30085 .65556 m .29549 .6248 L .30171 .60561 L p .707 .577 .707 r
F P
0 g
s
.49401 .58846 m .49936 .61921 L .48616 .60357 L p .707 .577 .707 r
F P
0 g
s
.48616 .60357 m .4808 .57282 L .49401 .58846 L p .707 .577 .707 r
F P
0 g
s
.47876 .51533 m .48361 .56622 L .46241 .5567 L p .707 .577 .707 r
F P
0 g
s
.46241 .5567 m .45756 .50581 L .47876 .51533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29511 .68813 m .29413 .67044 L .30111 .65799 L p .707 .577 .707 r
F P
0 g
s
.30111 .65799 m .30208 .67568 L .29511 .68813 L p .707 .577 .707 r
F P
0 g
s
.31429 .52319 m .31914 .57408 L .30308 .58812 L p .707 .577 .707 r
F P
0 g
s
.31914 .57408 m .31429 .52319 L .33807 .51152 L p .707 .577 .707 r
F P
0 g
s
.30171 .60561 m .30707 .63636 L .30085 .65556 L p .707 .577 .707 r
F P
0 g
s
.49481 .65367 m .49579 .67137 L .48312 .66056 L p .707 .577 .707 r
F P
0 g
s
.48312 .66056 m .48214 .64286 L .49481 .65367 L p .707 .577 .707 r
F P
0 g
s
.30707 .63636 m .30171 .60561 L .31723 .5874 L p .707 .577 .707 r
F P
0 g
s
.4808 .57282 m .48616 .60357 L .46471 .59214 L p .707 .577 .707 r
F P
0 g
s
.46471 .59214 m .45935 .56138 L .4808 .57282 L p .707 .577 .707 r
F P
0 g
s
.45756 .50581 m .46241 .5567 L .43491 .55125 L p .707 .577 .707 r
F P
0 g
s
.43491 .55125 m .43006 .50036 L .45756 .50581 L p .707 .577 .707 r
F P
0 g
s
.30208 .67568 m .30111 .65799 L .31736 .64653 L p .707 .577 .707 r
F P
0 g
s
.34292 .56241 m .33807 .51152 L .36724 .50336 L p .707 .577 .707 r
F P
0 g
s
.33807 .51152 m .34292 .56241 L .31914 .57408 L p .707 .577 .707 r
F P
0 g
s
.43006 .50036 m .43491 .55125 L .40378 .5504 L p .707 .577 .707 r
F P
0 g
s
.40378 .5504 m .39893 .49951 L .43006 .50036 L p .707 .577 .707 r
F P
0 g
s
.31736 .64653 m .31834 .66423 L .30208 .67568 L p .707 .577 .707 r
F P
0 g
s
.31723 .5874 m .32259 .61816 L .30707 .63636 L p .707 .577 .707 r
F P
0 g
s
.32259 .61816 m .31723 .5874 L .34051 .57198 L p .707 .577 .707 r
F P
0 g
s
.45935 .56138 m .46471 .59214 L .43712 .58603 L p .707 .577 .707 r
F P
0 g
s
.43712 .58603 m .43176 .55527 L .45935 .56138 L p .707 .577 .707 r
F P
0 g
s
.37209 .55425 m .36724 .50336 L .39893 .49951 L p .707 .577 .707 r
F P
0 g
s
.36724 .50336 m .37209 .55425 L .34292 .56241 L p .707 .577 .707 r
F P
0 g
s
.48214 .64286 m .48312 .66056 L .46201 .65223 L p .707 .577 .707 r
F P
0 g
s
.46201 .65223 m .46104 .63453 L .48214 .64286 L p .707 .577 .707 r
F P
0 g
s
.39893 .49951 m .40378 .5504 L .37209 .55425 L p .707 .577 .707 r
F P
0 g
s
.34587 .60274 m .34051 .57198 L .36928 .56085 L p .707 .577 .707 r
F P
0 g
s
.34051 .57198 m .34587 .60274 L .32259 .61816 L p .707 .577 .707 r
F P
0 g
s
.43176 .55527 m .43712 .58603 L .40608 .58584 L p .707 .577 .707 r
F P
0 g
s
.40608 .58584 m .40072 .55509 L .43176 .55527 L p .707 .577 .707 r
F P
0 g
s
.31834 .66423 m .31736 .64653 L .34132 .6372 L p .707 .577 .707 r
F P
0 g
s
.37464 .5916 m .36928 .56085 L .40072 .55509 L p .707 .577 .707 r
F P
0 g
s
.36928 .56085 m .37464 .5916 L .34587 .60274 L p .707 .577 .707 r
F P
0 g
s
.34132 .6372 m .34229 .65489 L .31834 .66423 L p .707 .577 .707 r
F P
0 g
s
.40072 .55509 m .40608 .58584 L .37464 .5916 L p .707 .577 .707 r
F P
0 g
s
.46104 .63453 m .46201 .65223 L .43454 .64719 L p .707 .577 .707 r
F P
0 g
s
.43454 .64719 m .43356 .62949 L .46104 .63453 L p .707 .577 .707 r
F P
0 g
s
.34229 .65489 m .34132 .6372 L .37062 .63089 L p .707 .577 .707 r
F P
0 g
s
.43356 .62949 m .43454 .64719 L .40338 .64594 L p .707 .577 .707 r
F P
0 g
s
.40338 .64594 m .40241 .62824 L .43356 .62949 L p .707 .577 .707 r
F P
0 g
s
.37062 .63089 m .3716 .64859 L .34229 .65489 L p .707 .577 .707 r
F P
0 g
s
.3716 .64859 m .37062 .63089 L .40241 .62824 L p .707 .577 .707 r
F P
0 g
s
.40241 .62824 m .40338 .64594 L .3716 .64859 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Moob4008Eoo`00Lgoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH00eYF3000NGoo001_Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP03FUH8001aOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@006eoo`00JGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH015YF0`00JWoo001WOol30006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02001VOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`1SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Ao
o`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001J
EP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEP000006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUHA0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`03001JEUYF00H000AJEP03001JEUYF00IJEP04001JEUYFFUH6000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006=o
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Ggoo10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001MOol200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005]oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FGoo
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001HOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P005goo3`00@7oo
001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000AOol60004FUH00`00FUIJEP06FUH00`00
FUH00003000lOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000=Ool400000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH3000iOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000:Ool30005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000gOol0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000
FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
27oo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00=Goo
001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=JEP0000002`0000=J
EP0000000P000UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@000=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<00004
FUH000000005FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000bOol0059oo`04001JEUYF0004FUH00`00FUIJEP04
FUH40002FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003Ool00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUH00000<7oo001BOol01000FUIJEP0015YF00<005YFFUH00UYF0P000goo0`0000=J
EP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0000EJEP00001JEP00009JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP03001JEUYF008000=oo`<000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00D000=JEP04001JEUYF000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000017oo001JEP001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00Dgoo00<005YF000015YF0`000goo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP800007FUH005YFFUH005YF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00Dgoo00<0
05YF000015YF00<007ooOol00Woo0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000IJEP00000005YF000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Woo0016Ool>0002FUH01000
FUIJEP0017oo00<005YF000025YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00P005YF000005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00@7oo1P0015YF00<005YFFUH0
1UYF00D005YFFUH005YF0080009oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00004FUH00000000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF0080009JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00AJEPd000IJEP03001JEUYF009JEP04001JEP00FUH3000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
03]oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00<0009JEP@0009JEP03001JEUYF009J
EP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00
FUH005YF0P001UYF00<005YFFUH01EYF1@001EYF1P001UYF00<005YFFUH00`0015YF00D005YFFUH0
05YF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00AJEQD000=oo`@000EJEP05001JEUYFFUH0000^Ool003Ioo`800003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH<0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH01000FUH005YF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH0100000=oo`0000000`0015YF00<005YFFUH01UYF00<005YF00000`000goo0P00
0eYF00D005YFFUIJEP0002ioo`00=7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000UYF00@005YFFUH000MJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP800003FUH005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP<000=oo`<000QJEP03001J
EUYF00IJEP03001JEUYF00=JEP<0009oo`800003FUH005YF009JEP03001oogoo02aoo`00<Woo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF
FUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YF000005YF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0004FUH01000FUIJEUYF0P0017oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF0`000Woo0P000eYF00<007ooOol0;7oo000aOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH02@00FUIJEUYF001JEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YF000000Ao
o`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF0080009JEP03
001JEUYF008002eoo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP8000Aoo`8000IJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF008002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP<000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF
00<007ooOol00Woo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF1P00;Goo000]Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00004FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF00800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF008000=oo`80009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH0000002eoo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00;Goo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH00`00FUIJEP03000]Ool002]oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00IJEP04001JEUYF
FUH20005FUH00`00FUH00002000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000015YF000005YF0P001eYF00<005YFFUH015YF1P0017oo1`001EYF1P001EYF00D005YF001JEP00
02eoo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPh0
009JEP<000AJEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF009JEPP00003FUH005YF
008000IJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009J
EP03001JEP0000MJEP03001JEUYF009JEP`000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=J
EP05001JEP00FUH0000]Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH6
000=Ool00`00FUIJEP0600000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0015YF00<005YF00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000IJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP80009JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP04000COol01000FUIJEP001Goo1`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P0000IJEP00FUIJEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04FUH200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00Oomoo`0/Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH4000HOol00eYF001oo`04Ool400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000
FUH000002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF0002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP04001JEUYFFUH2000LOol00eYF001o
o`02Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF000015YF00@005YF
000001ioo`04FUH007ooOol20006FUH00`00FUIJEP04FUH60008FUH90004FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0005FUH01000FUH000001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH007oo02aoo`00;7oo00<005YF000015YF0P004goo3P0000EJ
EP00001JEP0000IJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00EJEP<000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000002Ool2000]Ool002aoo`04001JEUYF0002FUH00`00Oomoo`0?Ool40002FUH00`00FUIJ
EP06FUH01000FUH000000eYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH025YF0P000UYF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=oo`03001JEP0002eoo`00;7oo00H005YFFUH0
05YF000>Ool40006FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUH000030003FUH01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001UYF0`000UYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool00`00FUH0000]Ool002aoo`03001JEUYF00@000]oo`800003FUH005YF00QJEP03001JEUYF
00IJEP8000AJEP@00003FUH005YF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH200000eYF001JEP06FUH01000FUH005YF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005Ool00`00FUH0000]Ool002aoo`03
001JEUYF0080009JEP8000Ioo`<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP8000=JEP05001J
EP00001JEP020003FUH01000FUIJEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<000=JEP03001J
EUYF00EJEP03001JEP0000<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP80009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEP0001H0009JEP04001JEP00
0006Ool200000eYF0000000/Ool002aoo`03001JEUYF008000AJEPH000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEP00FUH30003FUH500001EYF001JEUYF00001EYF00<005YFFUH01eYF1000
1eYF00<005YFFUH015YF0P000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000UYF1@000eYF00<005YFFUH00UYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD000Ioo`03001JEP00009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH000EJ
EP@000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP02FUH00`00
FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0`0000=JEP00Ool00Woo0`0000=JEP0000000`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`000goo00@005YFFUH0009JEP03001oogoo02Yoo`00;Goo00AJEP00FUH0
00EJEP04001JEUYF0008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUH005YF001JEP0000AJ
EP03001JEUYF00=JEPh000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`04Ool3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
0003FUH01000FUIJEP00;7oo000]Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF0`000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF0`001eYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800004FUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001oo`03Ool20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool0
02eoo`04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA00000eYF
001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH01000FUH00000
0UYF0P0000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0003Ool20005FUH00`00FUIJEP04FUHH0003FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`80
009JEP<000IJEP03001JEUYF00EJEPH000QJEP03001JEUYF00<0009JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP8000=JEP04001JEUYFFUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH500000goo00000006FUH00`00
FUIJEP04000HOol40005FUH00`00FUH00003000]Ool002eoo`80009JEP03001JEP0000IJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00800004FUH00000FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20002FUH20004FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001UYF00000000FUH000EJ
EPP001]oo`<000=JEP05001JEUYFFUH0000^Ool002ioo`03001JEP00009JEP03001JEUYF00EJEP03
001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF008000=JEP800003FUH0000000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP<000QJEP03001JEUYF009JEP800006FUH00000001JEP0015YF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF
009JEP04001JEUYFFUH20004FUH01000FUH000006Woo00@005YFFUIJEP800003FUH005YF009JEP03
001oogoo02aoo`00;Woo0P000eYF00<005YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH01eYF
00@005YFFUH000=JEP03001JEP0000@00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP0000D000AJEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUH000030004FUH01000FUH0000067oo0P001UYF
0P000eYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00UYF1@001UYF00<005YFFUH01UYF
00<005YFFUH015YF1P000UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0`000UYF0P0015YF0`005Goo0`0000=J
EP00FUH01EYF00<005YF00000UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03
001JEP0000D0009JEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00AJEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH005YFFUH0
0003FUH20002FUH20002FUH00`00FUH0000BOol30004FUH00`00FUIJEP05FUH00`00FUH00002000^
Ool002ioo`03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF0000
00020005FUH5000015YF001JEP003Goo1@001eYF00<005YFFUH01EYF0P0000=oo`000000;Woo000]
Ool00`00FUH00004FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
00000002FUH00`00FUIJEP02FUH01000FUIJEUYF4P000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<007ooOol00`00;Goo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30005
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20003Ool00`00FUH0000]Ool002eoo`03001JEP0000=J
EP03001oogoo00<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`<000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP020003Ool300000eYF
001oo`0/Ool002eoo`03001JEP00009JEP03001oogoo00Aoo`@0009JEP03001JEUYF00IJEP<0009J
EPH000eoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000IJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP040004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30003Ool20002FUH2000^
Ool002eoo`06001JEUYF001JEP002Woo40005Goo00<005YF00003`0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
001JEP800003FUH0000000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJ
EP8000=oo`8000AJEP8002ioo`00;Goo00<005YFFUH00P005Goo1@005Woo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH200000eYF00000003FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP03FUH20003Ool200000eYF001JEP03FUH00`00Oomo
o`0]Ool002eoo`04001JEUYF000FOol5000FOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000AJEP00FUIJEP<0009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000=oo`8000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH001Moo`<001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800005
FUH005YFFUH00002FUH20002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003Ool30005
FUH00`00FUIJEP02000`Ool002ioo`03FUH007oo01Ioo`l000Yoo`03001JEP00009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEP0000AJEPT0009JEP03001JEUYF
00IJEP03001JEUYF00@000=oo`@00003FUH005YF00EJEP<0039oo`00;Woo00=JEP00Ool03Woo2000
15YF00<005YFFUH01UYF00<005YF00000`0017oo0`0015YF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P000eYF0P001EYF00@005YFFUIJEQT000EJEP03001JEUYF00=JEP8003Aoo`00
;Woo00=JEP00Ool027oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000
0UYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Ioo`00;Woo00<005YF00001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00000hOol002ioo`04001JEUYF0003Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60003Ool200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000jOol002ioo`800003FUH00000008000EJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20009Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04000mOol002ioo`800004FUH000000006FUH00`00FUIJEP02FUH8000?Ool40002FUH00`00FUIJ
EP03FUH01000FUIJEP001EYF00<005YFFUH01EYF8@001UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P003Woo6@00@Goo000_Ool20002FUH00`00FUIJEP03FUH6000DOol30003FUH5
0004FUH01000FUIJEP001EYF00<005YFFUH01@002EYF00<005YFFUH02UYF00<005YFFUH025YF3000
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0P0047oo0P000UYF00<007ooOol0DGoo000^Ool00`00
FUIJEP02FUH01000FUIJEUYF10004Woo1P001eYF00@005YFFUIJEP<00005FUH005YFFUH00004FUH4
0003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH0
0`00FUIJEP03FUH2000?Ool00`00FUH00002FUH00`00Oomoo`1AOol002eoo`8000AJEP03001JEP00
008000=JEQ8000AJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEP00008000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00=JEP8000ioo`04001JEUYF0002FUH00`00Oomoo`1AOol002eoo`8000AJEP80
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF009JEP80
0004Ool005YFFUH200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH300000eYF001JEP04FUH2000=Ool01@00FUIJEUYF0000
0UYF00<007ooOol0DGoo000/Ool00`00FUH00002FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50006FUH00`00FUIJEP05FUH01@00FUIJEUYF00000goo0`000eYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@0015YF
1P0027oo00<005YFFUH00eYF0P00E7oo000/Ool00`00FUH0000200000goo00000004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP06FUH30004Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH2
0003FUH3000015YF000000000eYF2@001EYF0P00E7oo000/Ool00`00FUH00004Ool00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP06FUH00`00Oomoo`04Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH20005FUH50007FUH00`00FUH000020005FUH00`00Oomoo`1COol002aoo`80
00Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00Qoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001UYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool20008Ool200000eYF001JEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P002Goo0`000eYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00H005YFFUH005YF0006FUH00`00FUIJEP03FUH200000eYF001oo`1EOol002aoo`<000Uoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000009Ool20002FUH300000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP060003FUH00`00FUIJEP03FUH01000FUH00000EWoo000/Ool2
00000eYF0000000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000:Ool00`00FUIJEP02
FUH200000goo000000020006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60003FUH50004FUH01@00FUIJEUYF0000EGoo
000/Ool20003FUH00`00Oomoo`0;Ool@000>Ool30004FUH20005Ool40002FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0007FUH01000FUIJEUYF0`0000=JEP00FUH00UYF00<007ooOol0Dgoo000]Ool01000FUIJEUYF0`00
9goo0P000UYF00<005YFFUH00UYF00<007ooOol027oo1@0025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH04UYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF00<0
07ooOol0Dgoo000]Ool01@00FUIJEUYF00000UYF0P008Goo10001EYF00@005YFFUH0011oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF009JEPL000EJEP03001J
EUYF00MJEP03001JEUYF009JEP800005Ool005YFFUH0001EOol002ioo`04001JEUYF0004FUH5000H
Ool40002FUH00`00FUIJEP04FUH3000GOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH:0003
FUH50005FUH00`00FUIJEP06FUH01@00FUIJEUYF000017oo00<005YF0000EGoo000_Ool30005FUH0
1000FUIJEUYF60001UYF00<005YFFUH00eYF0P008Goo6P001EYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01UYF00@005YFFUH000Ioo`8005Eoo`00<Goo00<005YFFUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8002moo`05001JEP00001o
o`020005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH30007Ool2001E
Ool0039oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEP00000aOol00`00FUH00003Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH20009Ool3001DOol003Aoo`800003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<003=oo`8000Eoo`8000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000]oo`03001JEP0005Aoo`00=Woo1@00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P001goo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002goo0`0000=JEP00Ool0Dgoo000k
Ool90004FUH00`00FUIJEP02FUH7000jOol20009Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH4000<Ool20002FUH2001EOol004Aoo`T0045oo`04001JEP00000:Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP04000>Ool20004FUH2001EOol008ioo`80009JEP8000aoo`h000ioo`@00003FUH0
05YF00=JEP03001oogoo05Aoo`00Sgoo00D005YFFUH005YF00<0029oo`<000EJEP03001JEUYF009J
EP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEP<001]oo`@00003FUH005YF00EJEP03001JEUYF
008005Moo`00T7oo00<005YF00001EYF00<005YF00000`0047oo1`001EYF00<005YFFUH015YF0`00
FGoo002AOol20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001K
Ool0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<005eoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0`00HGoo002GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04001TOol009Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPL006Qoo`00WWoo4000Kgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59702 .75788 m .59401 .70487 L .56285 .70364 L p .707 .577 .707 r
F P
0 g
s
.59401 .70487 m .59702 .75788 L .6288 .75518 L p .707 .577 .707 r
F P
0 g
s
.6288 .75518 m .62579 .70217 L .59401 .70487 L p .707 .577 .707 r
F P
0 g
s
.62579 .70217 m .6288 .75518 L .6581 .74879 L p .707 .577 .707 r
F P
0 g
s
.6581 .74879 m .65509 .69578 L .62579 .70217 L p .707 .577 .707 r
F P
0 g
s
.56586 .75665 m .56285 .70364 L .53538 .69858 L p .707 .577 .707 r
F P
0 g
s
.56285 .70364 m .56586 .75665 L .59702 .75788 L p .707 .577 .707 r
F P
0 g
s
.65509 .69578 m .6581 .74879 L .68205 .73936 L p .707 .577 .707 r
F P
0 g
s
.68205 .73936 m .67903 .68635 L .65509 .69578 L p .707 .577 .707 r
F P
0 g
s
.53839 .75159 m .53538 .69858 L .51427 .6902 L p .707 .577 .707 r
F P
0 g
s
.53538 .69858 m .53839 .75159 L .56586 .75665 L p .707 .577 .707 r
F P
0 g
s
.67903 .68635 m .68205 .73936 L .6983 .72779 L p .707 .577 .707 r
F P
0 g
s
.6983 .72779 m .69529 .67478 L .67903 .68635 L p .707 .577 .707 r
F P
0 g
s
.60016 .83021 m .5968 .79646 L .56568 .79565 L p .707 .577 .707 r
F P
0 g
s
.5968 .79646 m .60016 .83021 L .63184 .82625 L p .707 .577 .707 r
F P
0 g
s
.63184 .82625 m .62848 .79249 L .5968 .79646 L p .707 .577 .707 r
F P
0 g
s
.62848 .79249 m .63184 .82625 L .66099 .8179 L p .707 .577 .707 r
F P
0 g
s
.66099 .8179 m .65763 .78414 L .62848 .79249 L p .707 .577 .707 r
F P
0 g
s
.56904 .82941 m .56568 .79565 L .53817 .79016 L p .707 .577 .707 r
F P
0 g
s
.56568 .79565 m .56904 .82941 L .60016 .83021 L p .707 .577 .707 r
F P
0 g
s
.59617 .86551 m .59556 .84746 L .5644 .84596 L p .707 .577 .707 r
F P
0 g
s
.59556 .84746 m .59617 .86551 L .62798 .86356 L p .707 .577 .707 r
F P
0 g
s
.62798 .86356 m .62738 .84551 L .59556 .84746 L p .707 .577 .707 r
F P
0 g
s
.65763 .78414 m .66099 .8179 L .68475 .80599 L p .707 .577 .707 r
F P
0 g
s
.68475 .80599 m .68138 .77223 L .65763 .78414 L p .707 .577 .707 r
F P
0 g
s
.51728 .74321 m .51427 .6902 L .50159 .67931 L p .707 .577 .707 r
F P
0 g
s
.51427 .6902 m .51728 .74321 L .53839 .75159 L p .707 .577 .707 r
F P
0 g
s
.62738 .84551 m .62798 .86356 L .65733 .85836 L p .707 .577 .707 r
F P
0 g
s
.65733 .85836 m .65673 .84031 L .62738 .84551 L p .707 .577 .707 r
F P
0 g
s
.5644 .84596 m .565 .86401 L .59617 .86551 L p .707 .577 .707 r
F P
0 g
s
.565 .86401 m .5644 .84596 L .53693 .84116 L p .707 .577 .707 r
F P
0 g
s
.54153 .82392 m .53817 .79016 L .51696 .78052 L p .707 .577 .707 r
F P
0 g
s
.53817 .79016 m .54153 .82392 L .56904 .82941 L p .707 .577 .707 r
F P
0 g
s
.69529 .67478 m .6983 .72779 L .70527 .71523 L p .707 .577 .707 r
F P
0 g
s
.70527 .71523 m .70225 .66222 L .69529 .67478 L p .707 .577 .707 r
F P
0 g
s
.53693 .84116 m .53754 .85922 L .565 .86401 L p .707 .577 .707 r
F P
0 g
s
.65673 .84031 m .65733 .85836 L .68135 .85041 L p .707 .577 .707 r
F P
0 g
s
.68135 .85041 m .68074 .83236 L .65673 .84031 L p .707 .577 .707 r
F P
0 g
s
.68138 .77223 m .68475 .80599 L .70079 .79169 L p .707 .577 .707 r
F P
0 g
s
.70079 .79169 m .69742 .75793 L .68138 .77223 L p .707 .577 .707 r
F P
0 g
s
.53754 .85922 m .53693 .84116 L .51586 .83354 L p .707 .577 .707 r
F P
0 g
s
.50159 .67931 m .5046 .73232 L .51728 .74321 L p .707 .577 .707 r
F P
0 g
s
.5046 .73232 m .50159 .67931 L .49859 .66698 L p .707 .577 .707 r
F P
0 g
s
.51586 .83354 m .51646 .85159 L .53754 .85922 L p .707 .577 .707 r
F P
0 g
s
.51696 .78052 m .52032 .81428 L .54153 .82392 L p .707 .577 .707 r
F P
0 g
s
.52032 .81428 m .51696 .78052 L .50413 .76767 L p .707 .577 .707 r
F P
0 g
s
.68074 .83236 m .68135 .85041 L .69768 .8405 L p .707 .577 .707 r
F P
0 g
s
.69768 .8405 m .69707 .82244 L .68074 .83236 L p .707 .577 .707 r
F P
0 g
s
.70225 .66222 m .70527 .71523 L .70226 .7029 L p .707 .577 .707 r
F P
0 g
s
.70226 .7029 m .69925 .64989 L .70225 .66222 L p .707 .577 .707 r
F P
0 g
s
.69742 .75793 m .70079 .79169 L .70754 .77638 L p .707 .577 .707 r
F P
0 g
s
.70754 .77638 m .70418 .74263 L .69742 .75793 L p .707 .577 .707 r
F P
0 g
s
.51646 .85159 m .51586 .83354 L .50323 .82383 L p .707 .577 .707 r
F P
0 g
s
.49859 .66698 m .5016 .71999 L .5046 .73232 L p .707 .577 .707 r
F P
0 g
s
.50413 .76767 m .50749 .80143 L .52032 .81428 L p .707 .577 .707 r
F P
0 g
s
.50323 .82383 m .50384 .84189 L .51646 .85159 L p .707 .577 .707 r
F P
0 g
s
.5016 .71999 m .49859 .66698 L .50556 .65442 L p .707 .577 .707 r
F P
0 g
s
.69707 .82244 m .69768 .8405 L .70472 .82959 L p .707 .577 .707 r
F P
0 g
s
.70472 .82959 m .70411 .81153 L .69707 .82244 L p .707 .577 .707 r
F P
0 g
s
.50749 .80143 m .50413 .76767 L .50094 .75287 L p .707 .577 .707 r
F P
0 g
s
.48443 .81898 m .49406 .31125 L .45005 .30823 L p .707 .577 .707 r
F P
0 g
s
.50384 .84189 m .50323 .82383 L .5003 .81299 L p .707 .577 .707 r
F P
0 g
s
.50094 .75287 m .5043 .78662 L .50749 .80143 L p .707 .577 .707 r
F P
0 g
s
.5003 .81299 m .5009 .83105 L .50384 .84189 L p .707 .577 .707 r
F P
0 g
s
.50556 .65442 m .50857 .70743 L .5016 .71999 L p .707 .577 .707 r
F P
0 g
s
.50857 .70743 m .50556 .65442 L .52181 .64285 L p .707 .577 .707 r
F P
0 g
s
.5043 .78662 m .50094 .75287 L .50769 .73756 L p .707 .577 .707 r
F P
0 g
s
.5009 .83105 m .5003 .81299 L .50734 .80208 L p .707 .577 .707 r
F P
0 g
s
.50769 .73756 m .51105 .77132 L .5043 .78662 L p .707 .577 .707 r
F P
0 g
s
.52181 .64285 m .52482 .69586 L .50857 .70743 L p .707 .577 .707 r
F P
0 g
s
.50734 .80208 m .50795 .82013 L .5009 .83105 L p .707 .577 .707 r
F P
0 g
s
.51105 .77132 m .50769 .73756 L .52373 .72326 L p .707 .577 .707 r
F P
0 g
s
.50795 .82013 m .50734 .80208 L .52367 .79216 L p .707 .577 .707 r
F P
0 g
s
.52373 .72326 m .52709 .75702 L .51105 .77132 L p .707 .577 .707 r
F P
0 g
s
.52367 .79216 m .52427 .81022 L .50795 .82013 L p .707 .577 .707 r
F P
0 g
s
.52427 .81022 m .52367 .79216 L .54768 .78422 L p .707 .577 .707 r
F P
0 g
s
.54768 .78422 m .54829 .80227 L .52427 .81022 L p .707 .577 .707 r
F P
0 g
s
.49406 .31125 m .48443 .81898 L .52937 .81887 L p .707 .577 .707 r
F P
0 g
s
.52482 .69586 m .52181 .64285 L .54576 .63342 L p .707 .577 .707 r
F P
0 g
s
.54576 .63342 m .54877 .68643 L .52482 .69586 L p .707 .577 .707 r
F P
0 g
s
.52709 .75702 m .52373 .72326 L .54749 .71135 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .55085 .74511 L .52709 .75702 L p .707 .577 .707 r
F P
0 g
s
.52937 .81887 m .53899 .31115 L .49406 .31125 L p .707 .577 .707 r
F P
0 g
s
.70418 .74263 m .70754 .77638 L .70435 .76158 L p .707 .577 .707 r
F P
0 g
s
.70435 .76158 m .70098 .72782 L .70418 .74263 L p .707 .577 .707 r
F P
0 g
s
.69925 .64989 m .70226 .7029 L .68959 .69201 L p .707 .577 .707 r
F P
0 g
s
.68959 .69201 m .68658 .639 L .69925 .64989 L p .707 .577 .707 r
F P
0 g
s
.54877 .68643 m .54576 .63342 L .57506 .62703 L p .707 .577 .707 r
F P
0 g
s
.57506 .62703 m .57807 .68004 L .54877 .68643 L p .707 .577 .707 r
F P
0 g
s
.54749 .71135 m .57663 .703 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.55085 .74511 m .54846 .72107 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.54846 .72107 m .54749 .71135 L p .55681 .73537 L .707 .577 .707 r
F P
0 g
s
.57807 .68004 m .57506 .62703 L .60684 .62433 L p .707 .577 .707 r
F P
0 g
s
.60684 .62433 m .60985 .67734 L .57807 .68004 L p .707 .577 .707 r
F P
0 g
s
.58 .73676 m .57663 .703 L .60832 .69904 L p .707 .577 .707 r
F P
0 g
s
.57663 .703 m .58 .73676 L .55085 .74511 L p .707 .577 .707 r
F P
0 g
s
.60832 .69904 m .61168 .73279 L .58 .73676 L p .707 .577 .707 r
F P
0 g
s
.57764 .79707 m .57703 .77901 L .60885 .77706 L p .707 .577 .707 r
F P
0 g
s
.60885 .77706 m .60946 .79512 L .57764 .79707 L p .707 .577 .707 r
F P
0 g
s
.58046 .30791 m .57187 .76116 L p .60477 .8096 L .707 .577 .707 r
F P
0 g
s
.54829 .80227 m .54768 .78422 L .57703 .77901 L p .707 .577 .707 r
F P
0 g
s
.57703 .77901 m .57764 .79707 L .54829 .80227 L p .707 .577 .707 r
F P
0 g
s
.57187 .76116 m .57083 .81564 L .60059 .81035 L p .707 .577 .707 r
F P
0 g
s
.60059 .81035 m .60477 .8096 L p .57187 .76116 L .707 .577 .707 r
F P
0 g
s
.53899 .31115 m .52937 .81887 L .57083 .81564 L p .707 .577 .707 r
F P
0 g
s
.57083 .81564 m .58046 .30791 L .53899 .31115 L p .707 .577 .707 r
F P
0 g
s
.44043 .81596 m .45005 .30823 L .41129 .30237 L p .707 .577 .707 r
F P
0 g
s
.45005 .30823 m .44043 .81596 L .48443 .81898 L p .707 .577 .707 r
F P
0 g
s
.70411 .81153 m .70472 .82959 L .70178 .81875 L p .707 .577 .707 r
F P
0 g
s
.70178 .81875 m .70118 .80069 L .70411 .81153 L p .707 .577 .707 r
F P
0 g
s
.25401 .72107 m .251 .66806 L .21984 .66682 L p .707 .577 .707 r
F P
0 g
s
.251 .66806 m .25401 .72107 L .28579 .71836 L p .707 .577 .707 r
F P
0 g
s
.28579 .71836 m .28278 .66535 L .251 .66806 L p .707 .577 .707 r
F P
0 g
s
.60985 .67734 m .60684 .62433 L .63799 .62556 L p .707 .577 .707 r
F P
0 g
s
.60477 .8096 m .6144 .30188 L .58046 .30791 L p .707 .577 .707 r
F P
0 g
s
.28278 .66535 m .28579 .71836 L .31509 .71198 L p .707 .577 .707 r
F P
0 g
s
.31509 .71198 m .31208 .65897 L .28278 .66535 L p .707 .577 .707 r
F P
0 g
s
.22285 .71983 m .21984 .66682 L .19237 .66176 L p .707 .577 .707 r
F P
0 g
s
.21984 .66682 m .22285 .71983 L .25401 .72107 L p .707 .577 .707 r
F P
0 g
s
.70098 .72782 m .70435 .76158 L .69152 .74873 L p .707 .577 .707 r
F P
0 g
s
.69152 .74873 m .68816 .71497 L .70098 .72782 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68658 .639 m .68959 .69201 L .66848 .68363 L p .707 .577 .707 r
F P
0 g
s
.66848 .68363 m .66547 .63062 L .68658 .639 L p .707 .577 .707 r
F P
0 g
s
.40166 .8101 m .41129 .30237 L .38155 .29425 L p .707 .577 .707 r
F P
0 g
s
.41129 .30237 m .40166 .8101 L .44043 .81596 L p .707 .577 .707 r
F P
0 g
s
.31208 .65897 m .31509 .71198 L .33904 .70254 L p .707 .577 .707 r
F P
0 g
s
.33904 .70254 m .33603 .64953 L .31208 .65897 L p .707 .577 .707 r
F P
0 g
s
.19538 .71477 m .19237 .66176 L .17126 .65338 L p .707 .577 .707 r
F P
0 g
s
.19237 .66176 m .19538 .71477 L .22285 .71983 L p .707 .577 .707 r
F P
0 g
s
.63799 .62556 m .641 .67857 L .60985 .67734 L p .707 .577 .707 r
F P
0 g
s
.63944 .69984 m .6428 .7336 L .61168 .73279 L p .707 .577 .707 r
F P
0 g
s
.61168 .73279 m .60832 .69904 L .63944 .69984 L p .707 .577 .707 r
F P
0 g
s
.64002 .77856 m .64062 .79662 L .60946 .79512 L p .707 .577 .707 r
F P
0 g
s
.60946 .79512 m .60885 .77706 L .64002 .77856 L p .707 .577 .707 r
F P
0 g
s
.6144 .30188 m .60477 .8096 L .62786 .80135 L p .707 .577 .707 r
F P
0 g
s
.62786 .80135 m .63749 .29363 L .6144 .30188 L p .707 .577 .707 r
F P
0 g
s
.70118 .80069 m .70178 .81875 L .68916 .80904 L p .707 .577 .707 r
F P
0 g
s
.68916 .80904 m .68856 .79098 L .70118 .80069 L p .707 .577 .707 r
F P
0 g
s
.33603 .64953 m .33904 .70254 L .35529 .69098 L p .707 .577 .707 r
F P
0 g
s
.35529 .69098 m .35228 .63797 L .33603 .64953 L p .707 .577 .707 r
F P
0 g
s
.66547 .63062 m .66848 .68363 L .641 .67857 L p .707 .577 .707 r
F P
0 g
s
.641 .67857 m .63799 .62556 L .66547 .63062 L p .707 .577 .707 r
F P
0 g
s
.25715 .7934 m .25379 .75964 L .22267 .75884 L p .707 .577 .707 r
F P
0 g
s
.25379 .75964 m .25715 .7934 L .28884 .78943 L p .707 .577 .707 r
F P
0 g
s
.28884 .78943 m .28547 .75567 L .25379 .75964 L p .707 .577 .707 r
F P
0 g
s
.28547 .75567 m .28884 .78943 L .31798 .78109 L p .707 .577 .707 r
F P
0 g
s
.31798 .78109 m .31462 .74733 L .28547 .75567 L p .707 .577 .707 r
F P
0 g
s
.68816 .71497 m .69152 .74873 L .67031 .73909 L p .707 .577 .707 r
F P
0 g
s
.67031 .73909 m .66695 .70533 L .68816 .71497 L p .707 .577 .707 r
F P
0 g
s
.22603 .7926 m .22267 .75884 L .19516 .75335 L p .707 .577 .707 r
F P
0 g
s
.22267 .75884 m .22603 .7926 L .25715 .7934 L p .707 .577 .707 r
F P
0 g
s
.37192 .80197 m .38155 .29425 L .36376 .28466 L p .707 .577 .707 r
F P
0 g
s
.38155 .29425 m .37192 .80197 L .40166 .8101 L p .707 .577 .707 r
F P
0 g
s
.25316 .8287 m .25255 .81064 L .22139 .80914 L p .707 .577 .707 r
F P
0 g
s
.25255 .81064 m .25316 .8287 L .28497 .82675 L p .707 .577 .707 r
F P
0 g
s
.28497 .82675 m .28437 .80869 L .25255 .81064 L p .707 .577 .707 r
F P
0 g
s
.31462 .74733 m .31798 .78109 L .34174 .76918 L p .707 .577 .707 r
F P
0 g
s
.34174 .76918 m .33838 .73542 L .31462 .74733 L p .707 .577 .707 r
F P
0 g
s
.17427 .70639 m .17126 .65338 L .15858 .64249 L p .707 .577 .707 r
F P
0 g
s
.17126 .65338 m .17427 .70639 L .19538 .71477 L p .707 .577 .707 r
F P
0 g
s
.28437 .80869 m .28497 .82675 L .31433 .82155 L p .707 .577 .707 r
F P
0 g
s
.31433 .82155 m .31372 .80349 L .28437 .80869 L p .707 .577 .707 r
F P
0 g
s
.22139 .80914 m .22199 .8272 L .25316 .8287 L p .707 .577 .707 r
F P
0 g
s
.22199 .8272 m .22139 .80914 L .19392 .80435 L p .707 .577 .707 r
F P
0 g
s
.19852 .78711 m .19516 .75335 L .17395 .7437 L p .707 .577 .707 r
F P
0 g
s
.19516 .75335 m .19852 .78711 L .22603 .7926 L p .707 .577 .707 r
F P
0 g
s
.35228 .63797 m .35529 .69098 L .36226 .67841 L p .707 .577 .707 r
F P
0 g
s
.36226 .67841 m .35924 .6254 L .35228 .63797 L p .707 .577 .707 r
F P
0 g
s
.66695 .70533 m .67031 .73909 L .6428 .7336 L p .707 .577 .707 r
F P
0 g
s
.6428 .7336 m .63944 .69984 L .66695 .70533 L p .707 .577 .707 r
F P
0 g
s
.19392 .80435 m .19453 .8224 L .22199 .8272 L p .707 .577 .707 r
F P
0 g
s
.68856 .79098 m .68916 .80904 L .66809 .80141 L p .707 .577 .707 r
F P
0 g
s
.66809 .80141 m .66748 .78336 L .68856 .79098 L p .707 .577 .707 r
F P
0 g
s
.31372 .80349 m .31433 .82155 L .33834 .8136 L p .707 .577 .707 r
F P
0 g
s
.33834 .8136 m .33774 .79554 L .31372 .80349 L p .707 .577 .707 r
F P
0 g
s
.33838 .73542 m .34174 .76918 L .35778 .75487 L p .707 .577 .707 r
F P
0 g
s
.35778 .75487 m .35441 .72111 L .33838 .73542 L p .707 .577 .707 r
F P
0 g
s
.19453 .8224 m .19392 .80435 L .17285 .79672 L p .707 .577 .707 r
F P
0 g
s
.63749 .29363 m .62786 .80135 L .63784 .79169 L p .707 .577 .707 r
F P
0 g
s
.63784 .79169 m .64747 .28397 L .63749 .29363 L p .707 .577 .707 r
F P
0 g
s
.15858 .64249 m .16159 .6955 L .17427 .70639 L p .707 .577 .707 r
F P
0 g
s
.16159 .6955 m .15858 .64249 L .15558 .63016 L p .707 .577 .707 r
F P
0 g
s
.17285 .79672 m .17345 .81478 L .19453 .8224 L p .707 .577 .707 r
F P
0 g
s
.17395 .7437 m .17731 .77746 L .19852 .78711 L p .707 .577 .707 r
F P
0 g
s
.17731 .77746 m .17395 .7437 L .16112 .73085 L p .707 .577 .707 r
F P
0 g
s
.33774 .79554 m .33834 .8136 L .35467 .80368 L p .707 .577 .707 r
F P
0 g
s
.35467 .80368 m .35406 .78563 L .33774 .79554 L p .707 .577 .707 r
F P
0 g
s
.66748 .78336 m .66809 .80141 L .64062 .79662 L p .707 .577 .707 r
F P
0 g
s
.64062 .79662 m .64002 .77856 L .66748 .78336 L p .707 .577 .707 r
F P
0 g
s
.35926 .66609 m .35624 .61308 L .35924 .6254 L p .707 .577 .707 r
F P
0 g
s
.35441 .72111 m .35778 .75487 L .36453 .73957 L p .707 .577 .707 r
F P
0 g
s
.36453 .73957 m .36117 .70581 L .35441 .72111 L p .707 .577 .707 r
F P
0 g
s
.35406 .78563 m .35467 .80368 L .36171 .79277 L p .707 .577 .707 r
F P
0 g
s
.36171 .79277 m .3611 .77472 L .35406 .78563 L p .707 .577 .707 r
F P
0 g
s
.35624 .61308 m .35926 .66609 L .34658 .6552 L p .707 .577 .707 r
F P
0 g
s
.34658 .6552 m .34357 .60219 L .35624 .61308 L p .707 .577 .707 r
F P
0 g
s
.35797 .69101 m .35894 .70073 L p .34851 .71192 L .707 .577 .707 r
F P
0 g
s
.35894 .70073 m .36134 .72477 L .35695 .72037 L p .707 .577 .707 r
F P
0 g
s
.35695 .72037 m .34851 .71192 L p .35894 .70073 L .707 .577 .707 r
F P
0 g
s
.34851 .71192 m .34515 .67816 L .35797 .69101 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35965 .27454 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35817 .76388 m .35877 .78193 L .34615 .77222 L p .707 .577 .707 r
F P
0 g
s
.34615 .77222 m .34555 .75417 L .35817 .76388 L p .707 .577 .707 r
F P
0 g
s
.35413 .79238 m .35517 .7379 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35517 .7379 m .36376 .28466 L p .35466 .74287 L .707 .577 .707 r
F P
0 g
s
.35924 .6254 m .36226 .67841 L .35926 .66609 L p .707 .577 .707 r
F P
0 g
s
.36117 .70581 m .36453 .73957 L .36134 .72477 L p .707 .577 .707 r
F P
0 g
s
.36134 .72477 m .35797 .69101 L .36117 .70581 L p .707 .577 .707 r
F P
0 g
s
.3611 .77472 m .36171 .79277 L .35877 .78193 L p .707 .577 .707 r
F P
0 g
s
.35877 .78193 m .35817 .76388 L .3611 .77472 L p .707 .577 .707 r
F P
0 g
s
.36376 .28466 m .35413 .79238 L .37192 .80197 L p .707 .577 .707 r
F P
0 g
s
.17345 .81478 m .17285 .79672 L .16022 .78702 L p .707 .577 .707 r
F P
0 g
s
.15558 .63016 m .15859 .68317 L .16159 .6955 L p .707 .577 .707 r
F P
0 g
s
.16112 .73085 m .16449 .76461 L .17731 .77746 L p .707 .577 .707 r
F P
0 g
s
.16022 .78702 m .16083 .80507 L .17345 .81478 L p .707 .577 .707 r
F P
0 g
s
.15859 .68317 m .15558 .63016 L .16255 .6176 L p .707 .577 .707 r
F P
0 g
s
.16449 .76461 m .16112 .73085 L .15793 .71605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.64747 .28397 m .63784 .79169 L .63373 .78157 L p .707 .577 .707 r
F P
0 g
s
.63373 .78157 m .64336 .27385 L .64747 .28397 L p .707 .577 .707 r
F P
0 g
s
.16083 .80507 m .16022 .78702 L .15729 .77618 L p .707 .577 .707 r
F P
0 g
s
.15793 .71605 m .16129 .74981 L .16449 .76461 L p .707 .577 .707 r
F P
0 g
s
.15729 .77618 m .1579 .79423 L .16083 .80507 L p .707 .577 .707 r
F P
0 g
s
.16255 .6176 m .16556 .67061 L .15859 .68317 L p .707 .577 .707 r
F P
0 g
s
.35965 .27454 m .35002 .78226 L .35413 .79238 L p .707 .577 .707 r
F P
0 g
s
.35002 .78226 m .35965 .27454 L .36963 .26488 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16556 .67061 m .16255 .6176 L .1788 .60604 L p .707 .577 .707 r
F P
0 g
s
.16129 .74981 m .15793 .71605 L .16468 .70075 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34357 .60219 m .34658 .6552 L .32547 .64681 L p .707 .577 .707 r
F P
0 g
s
.32547 .64681 m .32246 .5938 L .34357 .60219 L p .707 .577 .707 r
F P
0 g
s
.1579 .79423 m .15729 .77618 L .16433 .76526 L p .707 .577 .707 r
F P
0 g
s
.16468 .70075 m .16805 .73451 L .16129 .74981 L p .707 .577 .707 r
F P
0 g
s
.1788 .60604 m .18181 .65905 L .16556 .67061 L p .707 .577 .707 r
F P
0 g
s
.16433 .76526 m .16494 .78332 L .1579 .79423 L p .707 .577 .707 r
F P
0 g
s
.64336 .27385 m .63373 .78157 L .61594 .77198 L p .707 .577 .707 r
F P
0 g
s
.61594 .77198 m .62557 .26426 L .64336 .27385 L p .707 .577 .707 r
F P
0 g
s
.18181 .65905 m .1788 .60604 L .20275 .5966 L p .707 .577 .707 r
F P
0 g
s
.16805 .73451 m .16468 .70075 L .18072 .68644 L p .707 .577 .707 r
F P
0 g
s
.32246 .5938 m .32547 .64681 L .29799 .64176 L p .707 .577 .707 r
F P
0 g
s
.29799 .64176 m .29498 .58875 L .32246 .5938 L p .707 .577 .707 r
F P
0 g
s
.34515 .67816 m .34851 .71192 L .3273 .70227 L p .707 .577 .707 r
F P
0 g
s
.3273 .70227 m .32394 .66851 L .34515 .67816 L p .707 .577 .707 r
F P
0 g
s
.36 .7726 m .36963 .26488 L .39272 .25663 L p .707 .577 .707 r
F P
0 g
s
.36963 .26488 m .36 .7726 L .35002 .78226 L p .707 .577 .707 r
F P
0 g
s
.20576 .64961 m .20275 .5966 L .23205 .59022 L p .707 .577 .707 r
F P
0 g
s
.20275 .5966 m .20576 .64961 L .18181 .65905 L p .707 .577 .707 r
F P
0 g
s
.16494 .78332 m .16433 .76526 L .18066 .75535 L p .707 .577 .707 r
F P
0 g
s
.18072 .68644 m .18408 .7202 L .16805 .73451 L p .707 .577 .707 r
F P
0 g
s
.29498 .58875 m .29799 .64176 L .26684 .64052 L p .707 .577 .707 r
F P
0 g
s
.26684 .64052 m .26383 .58751 L .29498 .58875 L p .707 .577 .707 r
F P
0 g
s
.18066 .75535 m .18126 .7734 L .16494 .78332 L p .707 .577 .707 r
F P
0 g
s
.18408 .7202 m .18072 .68644 L .20448 .67453 L p .707 .577 .707 r
F P
0 g
s
.23506 .64323 m .23205 .59022 L .26383 .58751 L p .707 .577 .707 r
F P
0 g
s
.23205 .59022 m .23506 .64323 L .20576 .64961 L p .707 .577 .707 r
F P
0 g
s
.26383 .58751 m .26684 .64052 L .23506 .64323 L p .707 .577 .707 r
F P
0 g
s
.32394 .66851 m .3273 .70227 L .29979 .69678 L p .707 .577 .707 r
F P
0 g
s
.29979 .69678 m .29643 .66302 L .32394 .66851 L p .707 .577 .707 r
F P
0 g
s
.34555 .75417 m .34615 .77222 L .32508 .7646 L p .707 .577 .707 r
F P
0 g
s
.32508 .7646 m .32447 .74654 L .34555 .75417 L p .707 .577 .707 r
F P
0 g
s
.62557 .26426 m .61594 .77198 L .5862 .76386 L p .707 .577 .707 r
F P
0 g
s
.5862 .76386 m .59583 .25613 L .62557 .26426 L p .707 .577 .707 r
F P
0 g
s
.20784 .70829 m .20448 .67453 L .23362 .66619 L p .707 .577 .707 r
F P
0 g
s
.20448 .67453 m .20784 .70829 L .18408 .7202 L p .707 .577 .707 r
F P
0 g
s
.73422 .67364 m .73121 .62063 L .70006 .61939 L p .707 .577 .707 r
F P
0 g
s
.73121 .62063 m .73422 .67364 L .766 .67093 L p .707 .577 .707 r
F P
0 g
s
.766 .67093 m .76299 .61792 L .73121 .62063 L p .707 .577 .707 r
F P
0 g
s
.18126 .7734 m .18066 .75535 L .20467 .7474 L p .707 .577 .707 r
F P
0 g
s
.76299 .61792 m .766 .67093 L .7953 .66455 L p .707 .577 .707 r
F P
0 g
s
.7953 .66455 m .79229 .61154 L .76299 .61792 L p .707 .577 .707 r
F P
0 g
s
.29643 .66302 m .29979 .69678 L .26867 .69598 L p .707 .577 .707 r
F P
0 g
s
.26867 .69598 m .26531 .66222 L .29643 .66302 L p .707 .577 .707 r
F P
0 g
s
.70307 .6724 m .70006 .61939 L .67258 .61434 L p .707 .577 .707 r
F P
0 g
s
.70006 .61939 m .70307 .6724 L .73422 .67364 L p .707 .577 .707 r
F P
0 g
s
.20467 .7474 m .20528 .76546 L .18126 .7734 L p .707 .577 .707 r
F P
0 g
s
.39272 .25663 m .38309 .76435 L .36 .7726 L p .707 .577 .707 r
F P
0 g
s
.38309 .76435 m .39272 .25663 L .42666 .25059 L p .707 .577 .707 r
F P
0 g
s
.23699 .69995 m .23362 .66619 L .26531 .66222 L p .707 .577 .707 r
F P
0 g
s
.23362 .66619 m .23699 .69995 L .20784 .70829 L p .707 .577 .707 r
F P
0 g
s
.26531 .66222 m .26867 .69598 L .23699 .69995 L p .707 .577 .707 r
F P
0 g
s
.32447 .74654 m .32508 .7646 L .29761 .7598 L p .707 .577 .707 r
F P
0 g
s
.29761 .7598 m .29701 .74175 L .32447 .74654 L p .707 .577 .707 r
F P
0 g
s
.79229 .61154 m .7953 .66455 L .81925 .65511 L p .707 .577 .707 r
F P
0 g
s
.81925 .65511 m .81624 .6021 L .79229 .61154 L p .707 .577 .707 r
F P
0 g
s
.20528 .76546 m .20467 .7474 L .23402 .7422 L p .707 .577 .707 r
F P
0 g
s
.67559 .66735 m .67258 .61434 L .65147 .60595 L p .707 .577 .707 r
F P
0 g
s
.67258 .61434 m .67559 .66735 L .70307 .6724 L p .707 .577 .707 r
F P
0 g
s
.59583 .25613 m .5862 .76386 L .54744 .758 L p .707 .577 .707 r
F P
0 g
s
.54744 .758 m .55706 .25027 L .59583 .25613 L p .707 .577 .707 r
F P
0 g
s
.23402 .7422 m .23463 .76025 L .20528 .76546 L p .707 .577 .707 r
F P
0 g
s
.29701 .74175 m .29761 .7598 L .26645 .7583 L p .707 .577 .707 r
F P
0 g
s
.26645 .7583 m .26584 .74025 L .29701 .74175 L p .707 .577 .707 r
F P
0 g
s
.73736 .73508 m .734 .70132 L .70288 .70052 L p .707 .577 .707 r
F P
0 g
s
.734 .70132 m .73736 .73508 L .76905 .73111 L p .707 .577 .707 r
F P
0 g
s
.76905 .73111 m .76569 .69736 L .734 .70132 L p .707 .577 .707 r
F P
0 g
s
.76569 .69736 m .76905 .73111 L .7982 .72277 L p .707 .577 .707 r
F P
0 g
s
.7982 .72277 m .79483 .68901 L .76569 .69736 L p .707 .577 .707 r
F P
0 g
s
.81624 .6021 m .81925 .65511 L .8355 .64355 L p .707 .577 .707 r
F P
0 g
s
.8355 .64355 m .83249 .59054 L .81624 .6021 L p .707 .577 .707 r
F P
0 g
s
.23463 .76025 m .23402 .7422 L .26584 .74025 L p .707 .577 .707 r
F P
0 g
s
.26584 .74025 m .26645 .7583 L .23463 .76025 L p .707 .577 .707 r
F P
0 g
s
.70624 .73428 m .70288 .70052 L .67537 .69503 L p .707 .577 .707 r
F P
0 g
s
.70288 .70052 m .70624 .73428 L .73736 .73508 L p .707 .577 .707 r
F P
0 g
s
.41703 .75831 m .42666 .25059 L .46812 .24736 L p .707 .577 .707 r
F P
0 g
s
.42666 .25059 m .41703 .75831 L .38309 .76435 L p .707 .577 .707 r
F P
0 g
s
.73337 .76157 m .73277 .74352 L .7016 .74202 L p .707 .577 .707 r
F P
0 g
s
.73277 .74352 m .73337 .76157 L .76519 .75962 L p .707 .577 .707 r
F P
0 g
s
.76519 .75962 m .76458 .74157 L .73277 .74352 L p .707 .577 .707 r
F P
0 g
s
.76458 .74157 m .76519 .75962 L .79454 .75442 L p .707 .577 .707 r
F P
0 g
s
.79454 .75442 m .79393 .73637 L .76458 .74157 L p .707 .577 .707 r
F P
0 g
s
.79483 .68901 m .7982 .72277 L .82195 .71086 L p .707 .577 .707 r
F P
0 g
s
.82195 .71086 m .81859 .6771 L .79483 .68901 L p .707 .577 .707 r
F P
0 g
s
.7016 .74202 m .70221 .76007 L .73337 .76157 L p .707 .577 .707 r
F P
0 g
s
.65448 .65896 m .65147 .60595 L .63879 .59507 L p .707 .577 .707 r
F P
0 g
s
.65147 .60595 m .65448 .65896 L .67559 .66735 L p .707 .577 .707 r
F P
0 g
s
.70221 .76007 m .7016 .74202 L .67414 .73722 L p .707 .577 .707 r
F P
0 g
s
.55706 .25027 m .54744 .758 L .50343 .75498 L p .707 .577 .707 r
F P
0 g
s
.50343 .75498 m .51306 .24725 L .55706 .25027 L p .707 .577 .707 r
F P
0 g
s
.67414 .73722 m .67474 .75528 L .70221 .76007 L p .707 .577 .707 r
F P
0 g
s
.79393 .73637 m .79454 .75442 L .81855 .74647 L p .707 .577 .707 r
F P
0 g
s
.81855 .74647 m .81795 .72842 L .79393 .73637 L p .707 .577 .707 r
F P
0 g
s
.67873 .72879 m .67537 .69503 L .65416 .68539 L p .707 .577 .707 r
F P
0 g
s
.67537 .69503 m .67873 .72879 L .70624 .73428 L p .707 .577 .707 r
F P
0 g
s
.4585 .75508 m .46812 .24736 L .51306 .24725 L p .707 .577 .707 r
F P
0 g
s
.46812 .24736 m .4585 .75508 L .41703 .75831 L p .707 .577 .707 r
F P
0 g
s
.83249 .59054 m .8355 .64355 L .84247 .63099 L p .707 .577 .707 r
F P
0 g
s
.84247 .63099 m .83946 .57798 L .83249 .59054 L p .707 .577 .707 r
F P
0 g
s
.51306 .24725 m .50343 .75498 L .4585 .75508 L p .707 .577 .707 r
F P
0 g
s
.81859 .6771 m .82195 .71086 L .83799 .69655 L p .707 .577 .707 r
F P
0 g
s
.83799 .69655 m .83463 .6628 L .81859 .6771 L p .707 .577 .707 r
F P
0 g
s
.67474 .75528 m .67414 .73722 L .65306 .7296 L p .707 .577 .707 r
F P
0 g
s
.65306 .7296 m .65367 .74765 L .67474 .75528 L p .707 .577 .707 r
F P
0 g
s
.63879 .59507 m .64181 .64808 L .65448 .65896 L p .707 .577 .707 r
F P
0 g
s
.65416 .68539 m .65753 .71914 L .67873 .72879 L p .707 .577 .707 r
F P
0 g
s
.81795 .72842 m .81855 .74647 L .83488 .73656 L p .707 .577 .707 r
F P
0 g
s
.83488 .73656 m .83428 .7185 L .81795 .72842 L p .707 .577 .707 r
F P
0 g
s
.64181 .64808 m .63879 .59507 L .63579 .58274 L p .707 .577 .707 r
F P
0 g
s
.65753 .71914 m .65416 .68539 L .64134 .67254 L p .707 .577 .707 r
F P
0 g
s
.83463 .6628 m .83799 .69655 L .84474 .68125 L p .707 .577 .707 r
F P
0 g
s
.84474 .68125 m .84138 .64749 L .83463 .6628 L p .707 .577 .707 r
F P
0 g
s
.65367 .74765 m .65306 .7296 L .64044 .71989 L p .707 .577 .707 r
F P
0 g
s
.83946 .57798 m .84247 .63099 L .83947 .61866 L p .707 .577 .707 r
F P
0 g
s
.83947 .61866 m .83646 .56565 L .83946 .57798 L p .707 .577 .707 r
F P
0 g
s
.64044 .71989 m .64104 .73795 L .65367 .74765 L p .707 .577 .707 r
F P
0 g
s
.64134 .67254 m .6447 .70629 L .65753 .71914 L p .707 .577 .707 r
F P
0 g
s
.63579 .58274 m .6388 .63575 L .64181 .64808 L p .707 .577 .707 r
F P
0 g
s
.83428 .7185 m .83488 .73656 L .84192 .72565 L p .707 .577 .707 r
F P
0 g
s
.84192 .72565 m .84132 .70759 L .83428 .7185 L p .707 .577 .707 r
F P
0 g
s
.6447 .70629 m .64134 .67254 L .63814 .65773 L p .707 .577 .707 r
F P
0 g
s
.6388 .63575 m .63579 .58274 L .64276 .57018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84138 .64749 m .84474 .68125 L .84155 .66645 L p .707 .577 .707 r
F P
0 g
s
.84155 .66645 m .83819 .63269 L .84138 .64749 L p .707 .577 .707 r
F P
0 g
s
.64104 .73795 m .64044 .71989 L .6375 .70905 L p .707 .577 .707 r
F P
0 g
s
.83646 .56565 m .83947 .61866 L .82679 .60777 L p .707 .577 .707 r
F P
0 g
s
.82679 .60777 m .82378 .55476 L .83646 .56565 L p .707 .577 .707 r
F P
0 g
s
.6375 .70905 m .63811 .72711 L .64104 .73795 L p .707 .577 .707 r
F P
0 g
s
.63814 .65773 m .64151 .69149 L .6447 .70629 L p .707 .577 .707 r
F P
0 g
s
.64276 .57018 m .64577 .62319 L .6388 .63575 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84132 .70759 m .84192 .72565 L .83899 .7148 L p .707 .577 .707 r
F P
0 g
s
.83899 .7148 m .83838 .69675 L .84132 .70759 L p .707 .577 .707 r
F P
0 g
s
.64151 .69149 m .63814 .65773 L .6449 .64243 L p .707 .577 .707 r
F P
0 g
s
.64577 .62319 m .64276 .57018 L .65901 .55861 L p .707 .577 .707 r
F P
0 g
s
.39121 .63682 m .3882 .58381 L .35705 .58258 L p .707 .577 .707 r
F P
0 g
s
.3882 .58381 m .39121 .63682 L .42299 .63412 L p .707 .577 .707 r
F P
0 g
s
.42299 .63412 m .41998 .58111 L .3882 .58381 L p .707 .577 .707 r
F P
0 g
s
.41998 .58111 m .42299 .63412 L .45229 .62773 L p .707 .577 .707 r
F P
0 g
s
.45229 .62773 m .44928 .57472 L .41998 .58111 L p .707 .577 .707 r
F P
0 g
s
.83819 .63269 m .84155 .66645 L .82872 .6536 L p .707 .577 .707 r
F P
0 g
s
.82872 .6536 m .82536 .61984 L .83819 .63269 L p .707 .577 .707 r
F P
0 g
s
.36006 .63559 m .35705 .58258 L .32957 .57752 L p .707 .577 .707 r
F P
0 g
s
.35705 .58258 m .36006 .63559 L .39121 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63811 .72711 m .6375 .70905 L .64454 .69814 L p .707 .577 .707 r
F P
0 g
s
.82378 .55476 m .82679 .60777 L .80568 .59939 L p .707 .577 .707 r
F P
0 g
s
.80568 .59939 m .80267 .54638 L .82378 .55476 L p .707 .577 .707 r
F P
0 g
s
.44928 .57472 m .45229 .62773 L .47624 .6183 L p .707 .577 .707 r
F P
0 g
s
.47624 .6183 m .47323 .56529 L .44928 .57472 L p .707 .577 .707 r
F P
0 g
s
.6449 .64243 m .64826 .67619 L .64151 .69149 L p .707 .577 .707 r
F P
0 g
s
.64454 .69814 m .64515 .71619 L .63811 .72711 L p .707 .577 .707 r
F P
0 g
s
.65901 .55861 m .66202 .61162 L .64577 .62319 L p .707 .577 .707 r
F P
0 g
s
.33258 .63053 m .32957 .57752 L .30846 .56914 L p .707 .577 .707 r
F P
0 g
s
.32957 .57752 m .33258 .63053 L .36006 .63559 L p .707 .577 .707 r
F P
0 g
s
.66202 .61162 m .65901 .55861 L .68296 .54917 L p .707 .577 .707 r
F P
0 g
s
.64826 .67619 m .6449 .64243 L .66094 .62812 L p .707 .577 .707 r
F P
0 g
s
.83838 .69675 m .83899 .7148 L .82637 .7051 L p .707 .577 .707 r
F P
0 g
s
.82637 .7051 m .82576 .68704 L .83838 .69675 L p .707 .577 .707 r
F P
0 g
s
.39435 .69827 m .39099 .66451 L .35987 .66371 L p .707 .577 .707 r
F P
0 g
s
.39099 .66451 m .39435 .69827 L .42604 .6943 L p .707 .577 .707 r
F P
0 g
s
.42604 .6943 m .42268 .66054 L .39099 .66451 L p .707 .577 .707 r
F P
0 g
s
.42268 .66054 m .42604 .6943 L .45519 .68595 L p .707 .577 .707 r
F P
0 g
s
.45519 .68595 m .45182 .65219 L .42268 .66054 L p .707 .577 .707 r
F P
0 g
s
.47323 .56529 m .47624 .6183 L .49249 .60673 L p .707 .577 .707 r
F P
0 g
s
.49249 .60673 m .48948 .55372 L .47323 .56529 L p .707 .577 .707 r
F P
0 g
s
.82536 .61984 m .82872 .6536 L .80752 .64395 L p .707 .577 .707 r
F P
0 g
s
.80752 .64395 m .80415 .6102 L .82536 .61984 L p .707 .577 .707 r
F P
0 g
s
.80267 .54638 m .80568 .59939 L .77821 .59433 L p .707 .577 .707 r
F P
0 g
s
.77821 .59433 m .7752 .54132 L .80267 .54638 L p .707 .577 .707 r
F P
0 g
s
.36323 .69746 m .35987 .66371 L .33236 .65821 L p .707 .577 .707 r
F P
0 g
s
.35987 .66371 m .36323 .69746 L .39435 .69827 L p .707 .577 .707 r
F P
0 g
s
.39036 .72476 m .38976 .7067 L .35859 .7052 L p .707 .577 .707 r
F P
0 g
s
.38976 .7067 m .39036 .72476 L .42218 .72281 L p .707 .577 .707 r
F P
0 g
s
.42218 .72281 m .42157 .70475 L .38976 .7067 L p .707 .577 .707 r
F P
0 g
s
.64515 .71619 m .64454 .69814 L .66087 .68822 L p .707 .577 .707 r
F P
0 g
s
.42157 .70475 m .42218 .72281 L .45153 .71761 L p .707 .577 .707 r
F P
0 g
s
.45153 .71761 m .45092 .69955 L .42157 .70475 L p .707 .577 .707 r
F P
0 g
s
.45182 .65219 m .45519 .68595 L .47894 .67404 L p .707 .577 .707 r
F P
0 g
s
.47894 .67404 m .47558 .64029 L .45182 .65219 L p .707 .577 .707 r
F P
0 g
s
.66094 .62812 m .6643 .66188 L .64826 .67619 L p .707 .577 .707 r
F P
0 g
s
.68597 .60219 m .68296 .54917 L .71226 .54279 L p .707 .577 .707 r
F P
0 g
s
.68296 .54917 m .68597 .60219 L .66202 .61162 L p .707 .577 .707 r
F P
0 g
s
.35859 .7052 m .3592 .72326 L .39036 .72476 L p .707 .577 .707 r
F P
0 g
s
.66087 .68822 m .66148 .70628 L .64515 .71619 L p .707 .577 .707 r
F P
0 g
s
.31147 .62215 m .30846 .56914 L .29578 .55825 L p .707 .577 .707 r
F P
0 g
s
.30846 .56914 m .31147 .62215 L .33258 .63053 L p .707 .577 .707 r
F P
0 g
s
.3592 .72326 m .35859 .7052 L .33113 .70041 L p .707 .577 .707 r
F P
0 g
s
.6643 .66188 m .66094 .62812 L .68469 .61622 L p .707 .577 .707 r
F P
0 g
s
.7752 .54132 m .77821 .59433 L .74705 .5931 L p .707 .577 .707 r
F P
0 g
s
.74705 .5931 m .74404 .54008 L .7752 .54132 L p .707 .577 .707 r
F P
0 g
s
.33113 .70041 m .33173 .71846 L .3592 .72326 L p .707 .577 .707 r
F P
0 g
s
.82576 .68704 m .82637 .7051 L .80529 .69747 L p .707 .577 .707 r
F P
0 g
s
.80529 .69747 m .80469 .67942 L .82576 .68704 L p .707 .577 .707 r
F P
0 g
s
.45092 .69955 m .45153 .71761 L .47554 .70966 L p .707 .577 .707 r
F P
0 g
s
.47554 .70966 m .47494 .6916 L .45092 .69955 L p .707 .577 .707 r
F P
0 g
s
.33572 .69197 m .33236 .65821 L .31115 .64857 L p .707 .577 .707 r
F P
0 g
s
.33236 .65821 m .33572 .69197 L .36323 .69746 L p .707 .577 .707 r
F P
0 g
s
.71527 .5958 m .71226 .54279 L .74404 .54008 L p .707 .577 .707 r
F P
0 g
s
.71226 .54279 m .71527 .5958 L .68597 .60219 L p .707 .577 .707 r
F P
0 g
s
.80415 .6102 m .80752 .64395 L .78001 .63846 L p .707 .577 .707 r
F P
0 g
s
.78001 .63846 m .77664 .6047 L .80415 .6102 L p .707 .577 .707 r
F P
0 g
s
.74404 .54008 m .74705 .5931 L .71527 .5958 L p .707 .577 .707 r
F P
0 g
s
.48948 .55372 m .49249 .60673 L .49946 .59417 L p .707 .577 .707 r
F P
0 g
s
.49946 .59417 m .49645 .54116 L .48948 .55372 L p .707 .577 .707 r
F P
0 g
s
.47558 .64029 m .47894 .67404 L .49498 .65974 L p .707 .577 .707 r
F P
0 g
s
.49498 .65974 m .49162 .62598 L .47558 .64029 L p .707 .577 .707 r
F P
0 g
s
.33173 .71846 m .33113 .70041 L .31005 .69278 L p .707 .577 .707 r
F P
0 g
s
.66148 .70628 m .66087 .68822 L .68489 .68027 L p .707 .577 .707 r
F P
0 g
s
.68805 .64997 m .68469 .61622 L .71384 .60787 L p .707 .577 .707 r
F P
0 g
s
.68469 .61622 m .68805 .64997 L .6643 .66188 L p .707 .577 .707 r
F P
0 g
s
.31005 .69278 m .31066 .71084 L .33173 .71846 L p .707 .577 .707 r
F P
0 g
s
.29578 .55825 m .2988 .61126 L .31147 .62215 L p .707 .577 .707 r
F P
0 g
s
.77664 .6047 m .78001 .63846 L .74889 .63766 L p .707 .577 .707 r
F P
0 g
s
.74889 .63766 m .74552 .6039 L .77664 .6047 L p .707 .577 .707 r
F P
0 g
s
.31115 .64857 m .31452 .68233 L .33572 .69197 L p .707 .577 .707 r
F P
0 g
s
.68489 .68027 m .68549 .69833 L .66148 .70628 L p .707 .577 .707 r
F P
0 g
s
.47494 .6916 m .47554 .70966 L .49187 .69974 L p .707 .577 .707 r
F P
0 g
s
.49187 .69974 m .49127 .68169 L .47494 .6916 L p .707 .577 .707 r
F P
0 g
s
.2988 .61126 m .29578 .55825 L .29278 .54592 L p .707 .577 .707 r
F P
0 g
s
.31452 .68233 m .31115 .64857 L .29833 .63572 L p .707 .577 .707 r
F P
0 g
s
.80469 .67942 m .80529 .69747 L .77783 .69268 L p .707 .577 .707 r
F P
0 g
s
.77783 .69268 m .77722 .67462 L .80469 .67942 L p .707 .577 .707 r
F P
0 g
s
.7172 .64163 m .71384 .60787 L .74552 .6039 L p .707 .577 .707 r
F P
0 g
s
.71384 .60787 m .7172 .64163 L .68805 .64997 L p .707 .577 .707 r
F P
0 g
s
.74552 .6039 m .74889 .63766 L .7172 .64163 L p .707 .577 .707 r
F P
0 g
s
.49162 .62598 m .49498 .65974 L .50173 .64443 L p .707 .577 .707 r
F P
0 g
s
.50173 .64443 m .49837 .61068 L .49162 .62598 L p .707 .577 .707 r
F P
0 g
s
.68549 .69833 m .68489 .68027 L .71424 .67507 L p .707 .577 .707 r
F P
0 g
s
.31066 .71084 m .31005 .69278 L .29743 .68308 L p .707 .577 .707 r
F P
0 g
s
.49645 .54116 m .49946 .59417 L .49646 .58184 L p .707 .577 .707 r
F P
0 g
s
.49646 .58184 m .49345 .52883 L .49645 .54116 L p .707 .577 .707 r
F P
0 g
s
.71424 .67507 m .71484 .69313 L .68549 .69833 L p .707 .577 .707 r
F P
0 g
s
.29743 .68308 m .29803 .70113 L .31066 .71084 L p .707 .577 .707 r
F P
0 g
s
.77722 .67462 m .77783 .69268 L .74666 .69118 L p .707 .577 .707 r
F P
0 g
s
.74666 .69118 m .74606 .67312 L .77722 .67462 L p .707 .577 .707 r
F P
0 g
s
.29833 .63572 m .30169 .66948 L .31452 .68233 L p .707 .577 .707 r
F P
0 g
s
.29278 .54592 m .29579 .59893 L .2988 .61126 L p .707 .577 .707 r
F P
0 g
s
.71484 .69313 m .71424 .67507 L .74606 .67312 L p .707 .577 .707 r
F P
0 g
s
.49127 .68169 m .49187 .69974 L .49891 .68883 L p .707 .577 .707 r
F P
0 g
s
.49891 .68883 m .49831 .67077 L .49127 .68169 L p .707 .577 .707 r
F P
0 g
s
.74606 .67312 m .74666 .69118 L .71484 .69313 L p .707 .577 .707 r
F P
0 g
s
.30169 .66948 m .29833 .63572 L .29513 .62092 L p .707 .577 .707 r
F P
0 g
s
.29579 .59893 m .29278 .54592 L .29975 .53336 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49837 .61068 m .50173 .64443 L .49854 .62963 L p .707 .577 .707 r
F P
0 g
s
.49854 .62963 m .49518 .59588 L .49837 .61068 L p .707 .577 .707 r
F P
0 g
s
.29803 .70113 m .29743 .68308 L .29449 .67223 L p .707 .577 .707 r
F P
0 g
s
.49345 .52883 m .49646 .58184 L .48378 .57096 L p .707 .577 .707 r
F P
0 g
s
.48378 .57096 m .48077 .51795 L .49345 .52883 L p .707 .577 .707 r
F P
0 g
s
.29449 .67223 m .2951 .69029 L .29803 .70113 L p .707 .577 .707 r
F P
0 g
s
.29513 .62092 m .29849 .65468 L .30169 .66948 L p .707 .577 .707 r
F P
0 g
s
.29975 .53336 m .30276 .58637 L .29579 .59893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49831 .67077 m .49891 .68883 L .49598 .67799 L p .707 .577 .707 r
F P
0 g
s
.49598 .67799 m .49537 .65993 L .49831 .67077 L p .707 .577 .707 r
F P
0 g
s
.29849 .65468 m .29513 .62092 L .30189 .60562 L p .707 .577 .707 r
F P
0 g
s
.30276 .58637 m .29975 .53336 L .316 .5218 L p .707 .577 .707 r
F P
0 g
s
.49518 .59588 m .49854 .62963 L .48571 .61678 L p .707 .577 .707 r
F P
0 g
s
.48571 .61678 m .48235 .58302 L .49518 .59588 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2951 .69029 m .29449 .67223 L .30153 .66132 L p .707 .577 .707 r
F P
0 g
s
.48077 .51795 m .48378 .57096 L .46267 .56257 L p .707 .577 .707 r
F P
0 g
s
.46267 .56257 m .45966 .50956 L .48077 .51795 L p .707 .577 .707 r
F P
0 g
s
.30189 .60562 m .30525 .63937 L .29849 .65468 L p .707 .577 .707 r
F P
0 g
s
.30153 .66132 m .30214 .67938 L .2951 .69029 L p .707 .577 .707 r
F P
0 g
s
.316 .5218 m .31901 .57481 L .30276 .58637 L p .707 .577 .707 r
F P
0 g
s
.31901 .57481 m .316 .5218 L .33995 .51236 L p .707 .577 .707 r
F P
0 g
s
.30525 .63937 m .30189 .60562 L .31793 .59131 L p .707 .577 .707 r
F P
0 g
s
.49537 .65993 m .49598 .67799 L .48336 .66828 L p .707 .577 .707 r
F P
0 g
s
.48336 .66828 m .48275 .65023 L .49537 .65993 L p .707 .577 .707 r
F P
0 g
s
.48235 .58302 m .48571 .61678 L .46451 .60714 L p .707 .577 .707 r
F P
0 g
s
.46451 .60714 m .46114 .57338 L .48235 .58302 L p .707 .577 .707 r
F P
0 g
s
.45966 .50956 m .46267 .56257 L .4352 .55752 L p .707 .577 .707 r
F P
0 g
s
.4352 .55752 m .43219 .50451 L .45966 .50956 L p .707 .577 .707 r
F P
0 g
s
.30214 .67938 m .30153 .66132 L .31786 .65141 L p .707 .577 .707 r
F P
0 g
s
.31793 .59131 m .32129 .62507 L .30525 .63937 L p .707 .577 .707 r
F P
0 g
s
.34296 .56537 m .33995 .51236 L .36925 .50598 L p .707 .577 .707 r
F P
0 g
s
.33995 .51236 m .34296 .56537 L .31901 .57481 L p .707 .577 .707 r
F P
0 g
s
.31786 .65141 m .31847 .66946 L .30214 .67938 L p .707 .577 .707 r
F P
0 g
s
.32129 .62507 m .31793 .59131 L .34168 .5794 L p .707 .577 .707 r
F P
0 g
s
.43219 .50451 m .4352 .55752 L .40404 .55628 L p .707 .577 .707 r
F P
0 g
s
.40404 .55628 m .40103 .50327 L .43219 .50451 L p .707 .577 .707 r
F P
0 g
s
.48275 .65023 m .48336 .66828 L .46228 .66066 L p .707 .577 .707 r
F P
0 g
s
.46228 .66066 m .46168 .6426 L .48275 .65023 L p .707 .577 .707 r
F P
0 g
s
.37226 .55899 m .36925 .50598 L .40103 .50327 L p .707 .577 .707 r
F P
0 g
s
.36925 .50598 m .37226 .55899 L .34296 .56537 L p .707 .577 .707 r
F P
0 g
s
.46114 .57338 m .46451 .60714 L .43699 .60165 L p .707 .577 .707 r
F P
0 g
s
.43699 .60165 m .43363 .56789 L .46114 .57338 L p .707 .577 .707 r
F P
0 g
s
.40103 .50327 m .40404 .55628 L .37226 .55899 L p .707 .577 .707 r
F P
0 g
s
.31847 .66946 m .31786 .65141 L .34188 .64346 L p .707 .577 .707 r
F P
0 g
s
.34504 .61316 m .34168 .5794 L .37083 .57105 L p .707 .577 .707 r
F P
0 g
s
.34168 .5794 m .34504 .61316 L .32129 .62507 L p .707 .577 .707 r
F P
0 g
s
.43363 .56789 m .43699 .60165 L .40587 .60085 L p .707 .577 .707 r
F P
0 g
s
.40587 .60085 m .40251 .56709 L .43363 .56789 L p .707 .577 .707 r
F P
0 g
s
.34188 .64346 m .34248 .66151 L .31847 .66946 L p .707 .577 .707 r
F P
0 g
s
.46168 .6426 m .46228 .66066 L .43482 .65586 L p .707 .577 .707 r
F P
0 g
s
.43482 .65586 m .43421 .63781 L .46168 .6426 L p .707 .577 .707 r
F P
0 g
s
.37419 .60481 m .37083 .57105 L .40251 .56709 L p .707 .577 .707 r
F P
0 g
s
.37083 .57105 m .37419 .60481 L .34504 .61316 L p .707 .577 .707 r
F P
0 g
s
.40251 .56709 m .40587 .60085 L .37419 .60481 L p .707 .577 .707 r
F P
0 g
s
.34248 .66151 m .34188 .64346 L .37123 .63826 L p .707 .577 .707 r
F P
0 g
s
.37123 .63826 m .37183 .65631 L .34248 .66151 L p .707 .577 .707 r
F P
0 g
s
.43421 .63781 m .43482 .65586 L .40365 .65436 L p .707 .577 .707 r
F P
0 g
s
.40365 .65436 m .40304 .63631 L .43421 .63781 L p .707 .577 .707 r
F P
0 g
s
.37183 .65631 m .37123 .63826 L .40304 .63631 L p .707 .577 .707 r
F P
0 g
s
.40304 .63631 m .40365 .65436 L .37183 .65631 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEP`007Uoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00
LWoo001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH01000FUH00000L7oo001[Ool300000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00KGoo001YOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001ZOol006Qoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH2001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0001H0
00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00Hgoo100000=JEP00FUH025YF00<005YFFUH01EYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Ggoo10001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001M
Ool200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005]oo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol01@00FUIJEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8001Qoo`l003moo`00Dgoo00<005YF00000eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000Ioo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001JEP00008000EJEP03001J
EUYF00=JEP@0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=oo`04
001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP07FUH4
0004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`04001JEUYF0003FUH0
1000FUIJEUYF0P0017oo00@005YFFUH000EJEQ0000IJEPD00003FUH005YF009JEP04001JEUYF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;goo001COol01000FUIJEP000eYF00@005YF000000Ioo`03001JEUYF00L000AJEP03001J
EUYF00IJEP03001JEP0000D000=JEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00E7oo
00<005YF00000eYF0P0027oo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1000
00=JEP00FUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF0000
0UYF00<005YFFUH020001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P000eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH000020004FUH00`00
FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000015YF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`04001JEP000005FUH20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH300001EYF001JEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaH00003FUH005YF009JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
0005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00?7oo100000=JEP00FUH025YF00<005YFFUH01EYF
0`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF009JEPT000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool003Qoo`@0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP<000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00=J
EP03001JEUYF00AJEPL00004Ool000000005Ool80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000fOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH200000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00@000Moo`D000aoo`D000AJEP05
001JEUYFFUH0000^Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000IJEPT000AJ
EP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH4000:Ool?0008Ool300000eYF
001JEP02FUH00`00Oomoo`0/Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF
00IJEPD000EJEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YF00000P0027oo1P0015YF00<005YFFUH01UYF
00<005YF00000`0000=oo`0000000P0000AJEP00000000=JEP8002eoo`00<Goo0P001UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00<005YFFUH015YF00<005YFFUH01000
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF0000009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP80
00Uoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP04001JEUYF0002
FUH2000]Ool002moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP<000EJEP03001JEUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP800003FUH005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00<000=oo`<000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF009JEP@002eoo`00;Woo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF00000002FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEP8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEP00000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00<0
05YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF00000P001EYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF0`00;Goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P0000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH2000015YF00000000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH015YF0`0000=JEP00FUH01UYF0`0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00@005YF000000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEP00001J
EP00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF1P0015YF00<005YFFUH01EYF1@001EYF00<005YF
FUH0100015YF00<005YFFUH015YF0P0000AJEP00000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF00=JEPT000=JEPd000QJEP03001JEUYF00=JEP04001JEP00FUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00007FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF00@005YF001JEPP000AJEP03001JEUYF009J
EPP000AJEP03001JEUYF009JEP05001JEUYF001JEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200001EYF001JEUYF00001eYF00<005YFFUH01EYF00<005YFFUH00UYF3`00
1UYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH015YF500000=JEP00000015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH600000eYF00000003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60008FUH00`00
FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP04000COol200000eYF0000000400001EYF000005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEPD000AJEP03001JEUYF008002eoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEP@001Moo`80009JEP04001oogooOol20003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
000015YF001JEUYF0P00;Goo000/Ool01000FUIJEP000eYF00@005YFFUIJEP8000moo`<000Uoo`04
001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF10000eYF00<007ooOol0:goo000/Ool01000FUIJEP000eYF00@0
05YF0000011oo`D000Qoo`80009JEP<000IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP04
001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00;Goo000]Ool00`00FUH00003FUH2000BOol5
0008Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH70004FUH50005
FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P001Woo00<005YF0000;Goo000]Ool00`00FUH00002FUH00`00FUIJ
EP05000=Ool?0004FUH00`00FUIJEP03FUHD0004FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40009Ool3000]Ool002eoo`03001JEP00008000AJEP04001JEUYFFUH=0004FUH00`00
FUIJEP06FUH20004FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUH0009JEP@000EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00@000aoo`800003FUH0000002aoo`00;Goo00@005YF000000EJEP03001JEUYF
00AJEP@00003FUH005YF00MJEP03001JEUYF00IJEP8000AJEP80009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP80009JEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP0000=JEP04
001JEUYFFUH400000eYF001JEP07FUH<000>Ool200000eYF001JEP02000/Ool002eoo`800003FUH0
05YF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH0000300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH20004FUH00`00FUIJEP03FUH00`00FUH0000G000;Ool01P00FUIJEUYF001JEP80
02aoo`00;Goo0P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000Eoo`8000AJEP04001JEUYF000/Ool002eo
o`05001JEUYFFUH00004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUH00002FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP05FUH0
0`00FUIJEP020005FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH000050002FUH00`00FUIJEP040006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH500000eYF001JEP03FUH01000FUIJEP00;7oo000]Ool01@00FUIJEUYF00000UYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P0015YF00<005YF
FUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH01EYF0`001UYF0P0000AJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP000Woo1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001EYF00<0
05YF0000;7oo000]Ool01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000EJEP<00003FUH005YF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00AJ
EP<000EJEP800006FUH005YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP0000001EYF10001UYF00<005YFFUH0
15YF1@001UYF00<005YFFUH010000UYF00@005YFFUIJEP8000=JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP030006FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001JEUYF
00800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00AJEPL0009JEP8000=JEP8000=JEP04
001JEUYFFUH40002FUH00`00FUIJEP05FUH30003FUH70006FUH400000eYF001JEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH9000;Ool300000eYF0000000200000eYF001JEP04FUH00`00
FUH00002000^Ool002ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000MJ
EP@000=JEP03001JEP0000<000EJEP03001JEP0000l00003FUH005YF00IJEP@000EJEP05001JEUYF
FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH0000015YF00<005YFFUH00UYF200037oo1P001UYF00<005YF00000P0015YF00D005YFFUIJEP00
02ioo`00;Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH0
1UYF00@005YFFUH000=JEP03001JEUYF009JEPD00005FUH005YFFUH00005FUH00`00FUIJEP07FUH0
1000FUIJEUYF10000UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH00`00FUH000020004FUH@0004
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomoo`0/Ool002eoo`80
00EJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH01000FUIJEUYF60001UYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000AJEP800003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP8000=JEP8002eo
o`00;Goo0P001EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00FUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP<0009JEP8002eoo`00;7oo00<005YF00001EYF00@005YFFUIJ
EP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF000000020004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002Ool4000]Ool002aoo`03001JEP0000EJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@0009oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH200000eYF001JEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH40006
FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Woo0P00;Goo000/Ool01000FUIJEP0015YF0P001Goo
2@0015YF00<005YFFUH00UYF1`002Goo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF
00@005YF000000Moo`<002eoo`00;7oo00@005YFFUH000=JEP03001oogoo00ioo`T001Eoo`P000AJ
EP03001JEUYF00=JEPT000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP@000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00AJEP<000Moo`<00003FUH007oo02aoo`00;7oo00D005YFFUH005YF008001Aoo`D0
01Moo`04001JEUYF0003FUH:0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH200000eYF001J
EP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP040008Ool20002FUH00`00FUH0000]Ool002ao
o`03001JEUYF008001Ioo`D001Ioo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEP8000=JEPH000AJEP03001JEUYF00IJEP<000AJEPD000Yoo`8000AJEP8002ioo`00
;7oo00@005YFFUH001Moo`D001Eoo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEP0000<000EJEPT000AJEP03001JEUYF00@000]oo`@00003FUH0
05YF00=JEP8002ioo`00;Goo00<005YF000067oo0`0057oo0P000UYF00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP<000=JEP03001JEUYF008000Aoo`L0
00Yoo`D000EJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P0000=JEP00Ool05Goo3`001goo
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH005YF0005FUH00`00FUH000030002FUH2000<Ool90003FUH00`00FUIJEP04FUH00`00FUIJEP02
000`Ool002eoo`80009JEP03001oogoo00]oo`P000AJEP03001JEUYF00IJEP03001JEP0000<00003
Ool0000000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH20005FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3000bOol0
02eoo`04001JEUYFFUH30005Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH40002FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00=7oo000]Ool20002FUH00`00FUIJEP0500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020002FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF1@000Woo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000`00=Woo000]Ool20002FUH01000FUH000001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF60001UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0027oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`00>Woo000]Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH:000;FUH0
0`00FUIJEP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04000mOol002ioo`<0009JEP03001JEUYF00AJEP03001J
EUYF009JEP`000EJEPP000AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00D0
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00IJEP03
001JEUYF009JEP8000mooaL0045oo`00;Woo00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH015YF1P0015YF0P000UYF00<005YFFUH00UYF10000eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YF
FUH00UYF0P003Goo0P0000=JEP00FUH00P00Dgoo000]Ool20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP0000000UYF00<0
05YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF0P0037oo00H005YFFUIJEP00FUH2001COol002eo
o`8000AJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEPD0009JEP800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJEP8000Yoo`8000AJEP04001J
EUYF001COol002aoo`03001JEP00009JEP8000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP03001JEUYF008000Aoo`03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
009JEP80009JEP8000Qoo`800003FUH005YF00=JEP04001JEUYF001COol002aoo`03001JEP000080
0003Ool0000000AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP<000Io
o`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=oo`8000=JEP03001JEUYF00=JEP03001J
EP0005=oo`00;7oo00<005YF00001Goo0`0000=JEP00FUH01UYF00<005YFFUH015YF1@001UYF00<0
05YFFUH015YF0P0027oo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000
00=JEPH0009JEP03001JEUYF00=JEP8005Aoo`00;7oo0P002Goo0`001UYF00<005YFFUH01EYF0`00
1eYF00<005YFFUH010002Woo00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000MJEP03001JEP00008000EJEP8005Aoo`00;7oo0`002goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`003Woo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF
00<005YFFUH00UYF0P000eYF00<007ooOol0Dgoo000/Ool200000eYF0000000=Ool@000COol20000
0eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP03
FUH20002FUH00`00Oomoo`1COol002aoo`8000=JEP8002aoo`8000=JEP<0009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEPP000=JEP03001JEUYF00=JEP04001JEP00001FOol002eoo`06001JEUYFFUH0
05YF0`009Goo100000=JEP00FUH00UYF0P0000Aoo`00000000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP@0
00EJEP05001JEUYFFUH0001EOol002eoo`05001JEUYFFUH00004FUH3000LOol60005FUH01@00FUIJ
EUYF000017oo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00MJEP03001JEUYF008000=JEP05001J
EUYFFUH0001EOol002ioo`04001JEUYF0005FUH00`00FUH00003000?Ool90004FUH00`00FUIJEP04
FUH01000FUIJEP0027oo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH005YF009JEP8005Aoo`00;goo0`001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH015YF0`003Goo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00UYF1P001UYF00<005YFFUH01EYF00@005YFFUIJEP800003Ool0000000=JEP8005Ao
o`00<Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0057oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF
2P000UYF1@001EYF00<005YFFUH01EYF00@005YF000000Eoo`800003FUH0000005Aoo`00<goo0`00
00=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
77oo8P0015YF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`002Goo0`00E7oo000fOol30006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000cOol00`00FUH00005Ool20000
0eYF001JEP06FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04000<Ool3001DOol003Uoo`@0009J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@003Ioo`8000Qoo`D000AJEP03001JEUYF
00IJEP<000AJEPD000ioo`<00003FUH007oo05=oo`00?Goo5`00>Woo0`0037oo2@0015YF00<005YF
FUH010004Goo0P000UYF00<005YF0000E7oo002>Ool200000eYF001oo`0COol7000COol20004FUH2
001EOol008ioo`80009JEP8002Qoo`@00003FUH005YF00=JEP8005Eoo`00Sgoo00D005YFFUH005YF
00<0029oo`<000EJEP03001JEUYF009JEP03001oogoo05Aoo`00Sgoo00@005YFFUH000AJEPD001Uo
o`@00003FUH005YF00EJEP03001JEUYF008005Moo`00T7oo00<005YF00001EYF00@005YFFUIJEQT0
00EJEP03001JEUYF00AJEP<005Uoo`00TGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00Fgoo002BOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00GGoo002DOol3
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000
Ggoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5001QOol009ao
o`T000AJEP03001JEUYF009JEPT006Ioo`00YGoo2@00Kgoo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]33\[InvisibleSpace]"     "\
\[InvisibleSpace]10.591178425646612`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 33, "     ", 10.591178425646612, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59806 .74923 m .59273 .69335 L .5617 .69449 L p .707 .577 .707 r
F P
0 g
s
.59273 .69335 m .59806 .74923 L .62977 .7457 L p .707 .577 .707 r
F P
0 g
s
.62977 .7457 m .62443 .68983 L .59273 .69335 L p .707 .577 .707 r
F P
0 g
s
.62443 .68983 m .62977 .7457 L .65904 .74015 L p .707 .577 .707 r
F P
0 g
s
.65904 .74015 m .65371 .68427 L .62443 .68983 L p .707 .577 .707 r
F P
0 g
s
.56703 .75037 m .5617 .69449 L .53439 .69314 L p .707 .577 .707 r
F P
0 g
s
.5617 .69449 m .56703 .75037 L .59806 .74923 L p .707 .577 .707 r
F P
0 g
s
.65371 .68427 m .65904 .74015 L .68303 .7331 L p .707 .577 .707 r
F P
0 g
s
.68303 .7331 m .6777 .67722 L .65371 .68427 L p .707 .577 .707 r
F P
0 g
s
.60104 .80271 m .59391 .76564 L .56332 .76988 L p .707 .577 .707 r
F P
0 g
s
.59391 .76564 m .60104 .80271 L .63235 .79639 L p .707 .577 .707 r
F P
0 g
s
.63235 .79639 m .62521 .75932 L .59391 .76564 L p .707 .577 .707 r
F P
0 g
s
.53439 .69314 m .53972 .74902 L .56703 .75037 L p .707 .577 .707 r
F P
0 g
s
.62521 .75932 m .63235 .79639 L .6613 .78862 L p .707 .577 .707 r
F P
0 g
s
.6613 .78862 m .65417 .75154 L .62521 .75932 L p .707 .577 .707 r
F P
0 g
s
.53972 .74902 m .53439 .69314 L .51346 .68943 L p .707 .577 .707 r
F P
0 g
s
.56332 .76988 m .57046 .80695 L .60104 .80271 L p .707 .577 .707 r
F P
0 g
s
.57046 .80695 m .56332 .76988 L .53646 .77163 L p .707 .577 .707 r
F P
0 g
s
.65417 .75154 m .6613 .78862 L .68509 .78014 L p .707 .577 .707 r
F P
0 g
s
.68509 .78014 m .67795 .74307 L .65417 .75154 L p .707 .577 .707 r
F P
0 g
s
.6777 .67722 m .68303 .7331 L .69938 .72525 L p .707 .577 .707 r
F P
0 g
s
.69938 .72525 m .69404 .66937 L .6777 .67722 L p .707 .577 .707 r
F P
0 g
s
.53646 .77163 m .5436 .80871 L .57046 .80695 L p .707 .577 .707 r
F P
0 g
s
.59554 .84187 m .59224 .82331 L .56158 .82708 L p .707 .577 .707 r
F P
0 g
s
.59224 .82331 m .59554 .84187 L .62692 .83597 L p .707 .577 .707 r
F P
0 g
s
.62692 .83597 m .62362 .81741 L .59224 .82331 L p .707 .577 .707 r
F P
0 g
s
.51346 .68943 m .5188 .74531 L .53972 .74902 L p .707 .577 .707 r
F P
0 g
s
.62362 .81741 m .62692 .83597 L .65595 .82853 L p .707 .577 .707 r
F P
0 g
s
.65595 .82853 m .65264 .80997 L .62362 .81741 L p .707 .577 .707 r
F P
0 g
s
.56158 .82708 m .56488 .84565 L .59554 .84187 L p .707 .577 .707 r
F P
0 g
s
.56488 .84565 m .56158 .82708 L .53462 .82837 L p .707 .577 .707 r
F P
0 g
s
.5436 .80871 m .53646 .77163 L .51594 .77072 L p .707 .577 .707 r
F P
0 g
s
.5188 .74531 m .51346 .68943 L .50098 .68373 L p .707 .577 .707 r
F P
0 g
s
.53462 .82837 m .53792 .84693 L .56488 .84565 L p .707 .577 .707 r
F P
0 g
s
.65264 .80997 m .65595 .82853 L .67977 .82027 L p .707 .577 .707 r
F P
0 g
s
.67977 .82027 m .67647 .80171 L .65264 .80997 L p .707 .577 .707 r
F P
0 g
s
.67795 .74307 m .68509 .78014 L .70136 .7718 L p .707 .577 .707 r
F P
0 g
s
.70136 .7718 m .69422 .73473 L .67795 .74307 L p .707 .577 .707 r
F P
0 g
s
.51594 .77072 m .52308 .80779 L .5436 .80871 L p .707 .577 .707 r
F P
0 g
s
.69404 .66937 m .69938 .72525 L .70648 .71736 L p .707 .577 .707 r
F P
0 g
s
.70648 .71736 m .70115 .66149 L .69404 .66937 L p .707 .577 .707 r
F P
0 g
s
.50098 .68373 m .50631 .73961 L .5188 .74531 L p .707 .577 .707 r
F P
0 g
s
.53792 .84693 m .53462 .82837 L .51402 .82703 L p .707 .577 .707 r
F P
0 g
s
.51402 .82703 m .51732 .8456 L .53792 .84693 L p .707 .577 .707 r
F P
0 g
s
.67647 .80171 m .67977 .82027 L .69606 .81201 L p .707 .577 .707 r
F P
0 g
s
.69606 .81201 m .69275 .79344 L .67647 .80171 L p .707 .577 .707 r
F P
0 g
s
.52308 .80779 m .51594 .77072 L .50377 .76724 L p .707 .577 .707 r
F P
0 g
s
.50631 .73961 m .50098 .68373 L .49815 .67659 L p .707 .577 .707 r
F P
0 g
s
.50377 .76724 m .51091 .80431 L .52308 .80779 L p .707 .577 .707 r
F P
0 g
s
.69422 .73473 m .70136 .7718 L .70854 .76441 L p .707 .577 .707 r
F P
0 g
s
.70854 .76441 m .7014 .72734 L .69422 .73473 L p .707 .577 .707 r
F P
0 g
s
.51732 .8456 m .51402 .82703 L .50179 .82321 L p .707 .577 .707 r
F P
0 g
s
.50179 .82321 m .50509 .84178 L .51732 .8456 L p .707 .577 .707 r
F P
0 g
s
.70115 .66149 m .70648 .71736 L .70365 .71022 L p .707 .577 .707 r
F P
0 g
s
.70365 .71022 m .69832 .65434 L .70115 .66149 L p .707 .577 .707 r
F P
0 g
s
.49815 .67659 m .50348 .73246 L .50631 .73961 L p .707 .577 .707 r
F P
0 g
s
.69275 .79344 m .69606 .81201 L .70322 .80454 L p .707 .577 .707 r
F P
0 g
s
.70322 .80454 m .69992 .78598 L .69275 .79344 L p .707 .577 .707 r
F P
0 g
s
.47849 .82203 m .49729 .32254 L .45331 .31819 L p .707 .577 .707 r
F P
0 g
s
.51091 .80431 m .50377 .76724 L .50114 .76152 L p .707 .577 .707 r
F P
0 g
s
.50114 .76152 m .50828 .79859 L .51091 .80431 L p .707 .577 .707 r
F P
0 g
s
.50348 .73246 m .49815 .67659 L .50525 .6687 L p .707 .577 .707 r
F P
0 g
s
.50509 .84178 m .50179 .82321 L .49913 .81728 L p .707 .577 .707 r
F P
0 g
s
.49913 .81728 m .50243 .83584 L .50509 .84178 L p .707 .577 .707 r
F P
0 g
s
.50525 .6687 m .51059 .72458 L .50348 .73246 L p .707 .577 .707 r
F P
0 g
s
.50828 .79859 m .50114 .76152 L .50832 .75413 L p .707 .577 .707 r
F P
0 g
s
.50832 .75413 m .51546 .7912 L .50828 .79859 L p .707 .577 .707 r
F P
0 g
s
.51059 .72458 m .50525 .6687 L .5216 .66085 L p .707 .577 .707 r
F P
0 g
s
.50243 .83584 m .49913 .81728 L .50629 .80981 L p .707 .577 .707 r
F P
0 g
s
.50629 .80981 m .50959 .82838 L .50243 .83584 L p .707 .577 .707 r
F P
0 g
s
.5216 .66085 m .52693 .71673 L .51059 .72458 L p .707 .577 .707 r
F P
0 g
s
.51546 .7912 m .50832 .75413 L .5246 .74579 L p .707 .577 .707 r
F P
0 g
s
.5246 .74579 m .53173 .78286 L .51546 .7912 L p .707 .577 .707 r
F P
0 g
s
.50959 .82838 m .50629 .80981 L .52258 .80155 L p .707 .577 .707 r
F P
0 g
s
.52258 .80155 m .52588 .82011 L .50959 .82838 L p .707 .577 .707 r
F P
0 g
s
.49729 .32254 m .47849 .82203 L .52341 .82244 L p .707 .577 .707 r
F P
0 g
s
.52693 .71673 m .5216 .66085 L .54559 .65381 L p .707 .577 .707 r
F P
0 g
s
.54559 .65381 m .55092 .70968 L .52693 .71673 L p .707 .577 .707 r
F P
0 g
s
.53173 .78286 m .5246 .74579 L .54838 .73731 L p .707 .577 .707 r
F P
0 g
s
.52588 .82011 m .52258 .80155 L .5464 .79329 L p .707 .577 .707 r
F P
0 g
s
.52341 .82244 m .5422 .32295 L .49729 .32254 L p .707 .577 .707 r
F P
0 g
s
.55092 .70968 m .54559 .65381 L .57486 .64825 L p .707 .577 .707 r
F P
0 g
s
.54838 .73731 m .55552 .77438 L .53173 .78286 L p .707 .577 .707 r
F P
0 g
s
.57486 .64825 m .5802 .70413 L .55092 .70968 L p .707 .577 .707 r
F P
0 g
s
.55552 .77438 m .54838 .73731 L .57734 .72953 L p .707 .577 .707 r
F P
0 g
s
.5464 .79329 m .5497 .81185 L .52588 .82011 L p .707 .577 .707 r
F P
0 g
s
.57734 .72953 m .58447 .76661 L .55552 .77438 L p .707 .577 .707 r
F P
0 g
s
.5497 .81185 m .5464 .79329 L .57542 .78585 L p .707 .577 .707 r
F P
0 g
s
.57542 .78585 m .57872 .80441 L .5497 .81185 L p .707 .577 .707 r
F P
0 g
s
.5422 .32295 m .52341 .82244 L .56487 .81886 L p .707 .577 .707 r
F P
0 g
s
.56487 .81886 m .58366 .31937 L .5422 .32295 L p .707 .577 .707 r
F P
0 g
s
.43452 .81769 m .45331 .31819 L .41458 .31033 L p .707 .577 .707 r
F P
0 g
s
.45331 .31819 m .43452 .81769 L .47849 .82203 L p .707 .577 .707 r
F P
0 g
s
.7014 .72734 m .70854 .76441 L .70591 .75869 L p .707 .577 .707 r
F P
0 g
s
.70591 .75869 m .69877 .72162 L .7014 .72734 L p .707 .577 .707 r
F P
0 g
s
.5802 .70413 m .57486 .64825 L .60657 .64472 L p .707 .577 .707 r
F P
0 g
s
.60657 .64472 m .6119 .7006 L .5802 .70413 L p .707 .577 .707 r
F P
0 g
s
.58447 .76661 m .57734 .72953 L .60864 .72322 L p .707 .577 .707 r
F P
0 g
s
.60864 .72322 m .61578 .76029 L .58447 .76661 L p .707 .577 .707 r
F P
0 g
s
.57872 .80441 m .57542 .78585 L .6068 .77995 L p .707 .577 .707 r
F P
0 g
s
.6068 .77995 m .6101 .79851 L .57872 .80441 L p .707 .577 .707 r
F P
0 g
s
.58366 .31937 m .56487 .81886 L .59881 .81165 L p .707 .577 .707 r
F P
0 g
s
.59881 .81165 m .6176 .31216 L .58366 .31937 L p .707 .577 .707 r
F P
0 g
s
.69832 .65434 m .70365 .71022 L .69116 .70452 L p .707 .577 .707 r
F P
0 g
s
.69116 .70452 m .68583 .64864 L .69832 .65434 L p .707 .577 .707 r
F P
0 g
s
.69992 .78598 m .70322 .80454 L .70055 .79861 L p .707 .577 .707 r
F P
0 g
s
.70055 .79861 m .69725 .78004 L .69992 .78598 L p .707 .577 .707 r
F P
0 g
s
.39578 .80982 m .41458 .31033 L .38488 .29972 L p .707 .577 .707 r
F P
0 g
s
.41458 .31033 m .39578 .80982 L .43452 .81769 L p .707 .577 .707 r
F P
0 g
s
.25505 .70703 m .24972 .65115 L .21869 .6523 L p .707 .577 .707 r
F P
0 g
s
.24972 .65115 m .25505 .70703 L .28676 .70351 L p .707 .577 .707 r
F P
0 g
s
.28676 .70351 m .28142 .64763 L .24972 .65115 L p .707 .577 .707 r
F P
0 g
s
.28142 .64763 m .28676 .70351 L .31603 .69795 L p .707 .577 .707 r
F P
0 g
s
.31603 .69795 m .3107 .64207 L .28142 .64763 L p .707 .577 .707 r
F P
0 g
s
.22403 .70818 m .21869 .6523 L .19138 .65095 L p .707 .577 .707 r
F P
0 g
s
.21869 .6523 m .22403 .70818 L .25505 .70703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69877 .72162 m .70591 .75869 L .69374 .75521 L p .707 .577 .707 r
F P
0 g
s
.69374 .75521 m .68661 .71813 L .69877 .72162 L p .707 .577 .707 r
F P
0 g
s
.3107 .64207 m .31603 .69795 L .34002 .6909 L p .707 .577 .707 r
F P
0 g
s
.34002 .6909 m .33469 .63502 L .3107 .64207 L p .707 .577 .707 r
F P
0 g
s
.63759 .64358 m .64293 .69946 L .6119 .7006 L p .707 .577 .707 r
F P
0 g
s
.6119 .7006 m .60657 .64472 L .63759 .64358 L p .707 .577 .707 r
F P
0 g
s
.63922 .71897 m .64636 .75605 L .61578 .76029 L p .707 .577 .707 r
F P
0 g
s
.61578 .76029 m .60864 .72322 L .63922 .71897 L p .707 .577 .707 r
F P
0 g
s
.63747 .77617 m .64077 .79474 L .6101 .79851 L p .707 .577 .707 r
F P
0 g
s
.6101 .79851 m .6068 .77995 L .63747 .77617 L p .707 .577 .707 r
F P
0 g
s
.6176 .31216 m .59881 .81165 L .62191 .80151 L p .707 .577 .707 r
F P
0 g
s
.62191 .80151 m .64071 .30202 L .6176 .31216 L p .707 .577 .707 r
F P
0 g
s
.68583 .64864 m .69116 .70452 L .67024 .70081 L p .707 .577 .707 r
F P
0 g
s
.67024 .70081 m .66491 .64493 L .68583 .64864 L p .707 .577 .707 r
F P
0 g
s
.19138 .65095 m .19671 .70683 L .22403 .70818 L p .707 .577 .707 r
F P
0 g
s
.25804 .76834 m .2509 .73126 L .22032 .73551 L p .707 .577 .707 r
F P
0 g
s
.2509 .73126 m .25804 .76834 L .28934 .76202 L p .707 .577 .707 r
F P
0 g
s
.28934 .76202 m .2822 .72494 L .2509 .73126 L p .707 .577 .707 r
F P
0 g
s
.2822 .72494 m .28934 .76202 L .3183 .75424 L p .707 .577 .707 r
F P
0 g
s
.3183 .75424 m .31116 .71717 L .2822 .72494 L p .707 .577 .707 r
F P
0 g
s
.19671 .70683 m .19138 .65095 L .17046 .64724 L p .707 .577 .707 r
F P
0 g
s
.69725 .78004 m .70055 .79861 L .68832 .79479 L p .707 .577 .707 r
F P
0 g
s
.68832 .79479 m .68502 .77622 L .69725 .78004 L p .707 .577 .707 r
F P
0 g
s
.22032 .73551 m .22746 .77258 L .25804 .76834 L p .707 .577 .707 r
F P
0 g
s
.22746 .77258 m .22032 .73551 L .19345 .73726 L p .707 .577 .707 r
F P
0 g
s
.36609 .79921 m .38488 .29972 L .36712 .28739 L p .707 .577 .707 r
F P
0 g
s
.38488 .29972 m .36609 .79921 L .39578 .80982 L p .707 .577 .707 r
F P
0 g
s
.33469 .63502 m .34002 .6909 L .35637 .68305 L p .707 .577 .707 r
F P
0 g
s
.35637 .68305 m .35103 .62717 L .33469 .63502 L p .707 .577 .707 r
F P
0 g
s
.31116 .71717 m .3183 .75424 L .34208 .74577 L p .707 .577 .707 r
F P
0 g
s
.34208 .74577 m .33494 .70869 L .31116 .71717 L p .707 .577 .707 r
F P
0 g
s
.19345 .73726 m .20059 .77433 L .22746 .77258 L p .707 .577 .707 r
F P
0 g
s
.17046 .64724 m .17579 .70312 L .19671 .70683 L p .707 .577 .707 r
F P
0 g
s
.68661 .71813 m .69374 .75521 L .67322 .75429 L p .707 .577 .707 r
F P
0 g
s
.67322 .75429 m .66608 .71722 L .68661 .71813 L p .707 .577 .707 r
F P
0 g
s
.25254 .81301 m .24924 .79445 L .21857 .79822 L p .707 .577 .707 r
F P
0 g
s
.24924 .79445 m .25254 .81301 L .28392 .80711 L p .707 .577 .707 r
F P
0 g
s
.28392 .80711 m .28062 .78855 L .24924 .79445 L p .707 .577 .707 r
F P
0 g
s
.28062 .78855 m .28392 .80711 L .31294 .79967 L p .707 .577 .707 r
F P
0 g
s
.31294 .79967 m .30964 .78111 L .28062 .78855 L p .707 .577 .707 r
F P
0 g
s
.66491 .64493 m .67024 .70081 L .64293 .69946 L p .707 .577 .707 r
F P
0 g
s
.64293 .69946 m .63759 .64358 L .66491 .64493 L p .707 .577 .707 r
F P
0 g
s
.21857 .79822 m .22187 .81679 L .25254 .81301 L p .707 .577 .707 r
F P
0 g
s
.20059 .77433 m .19345 .73726 L .17293 .73635 L p .707 .577 .707 r
F P
0 g
s
.17579 .70312 m .17046 .64724 L .15797 .64154 L p .707 .577 .707 r
F P
0 g
s
.22187 .81679 m .21857 .79822 L .19162 .79951 L p .707 .577 .707 r
F P
0 g
s
.19162 .79951 m .19492 .81807 L .22187 .81679 L p .707 .577 .707 r
F P
0 g
s
.30964 .78111 m .31294 .79967 L .33676 .79141 L p .707 .577 .707 r
F P
0 g
s
.33676 .79141 m .33346 .77285 L .30964 .78111 L p .707 .577 .707 r
F P
0 g
s
.33494 .70869 m .34208 .74577 L .35835 .73743 L p .707 .577 .707 r
F P
0 g
s
.35835 .73743 m .35121 .70035 L .33494 .70869 L p .707 .577 .707 r
F P
0 g
s
.17293 .73635 m .18007 .77342 L .20059 .77433 L p .707 .577 .707 r
F P
0 g
s
.68502 .77622 m .68832 .79479 L .66772 .79345 L p .707 .577 .707 r
F P
0 g
s
.66772 .79345 m .66442 .77489 L .68502 .77622 L p .707 .577 .707 r
F P
0 g
s
.64071 .30202 m .62191 .80151 L .63192 .78944 L p .707 .577 .707 r
F P
0 g
s
.63192 .78944 m .65071 .28995 L .64071 .30202 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .36305 .27457 L p .36009 .37768 L .707 .577 .707 r
F P
0 g
s
.35103 .62717 m .35637 .68305 L .36129 .67759 L p .707 .577 .707 r
F P
0 g
s
.36125 .66658 m .35103 .62717 L .36129 .67759 L .707 .577 .707 r
F
.36347 .67517 m .35814 .61929 L .35103 .62717 L p F P
0 g
s
.33346 .77285 m .33676 .79141 L .35305 .78315 L p .707 .577 .707 r
F P
0 g
s
.35305 .78315 m .34975 .76458 L .33346 .77285 L p .707 .577 .707 r
F P
0 g
s
.35121 .70035 m .35835 .73743 L .36553 .73003 L p .707 .577 .707 r
F P
0 g
s
.36553 .73003 m .35839 .69296 L .35121 .70035 L p .707 .577 .707 r
F P
0 g
s
.35531 .61215 m .35826 .64307 L p .34815 .66232 L .707 .577 .707 r
F P
0 g
s
.35826 .64307 m .36064 .66803 L .35655 .66616 L p .707 .577 .707 r
F P
0 g
s
.35655 .66616 m .34815 .66232 L p .35826 .64307 L .707 .577 .707 r
F P
0 g
s
.34815 .66232 m .34282 .60644 L .35531 .61215 L p .707 .577 .707 r
F P
0 g
s
.35074 .72083 m .3436 .68376 L .35577 .68724 L p .707 .577 .707 r
F P
0 g
s
.34975 .76458 m .35305 .78315 L .36021 .77568 L p .707 .577 .707 r
F P
0 g
s
.36021 .77568 m .35691 .75712 L .34975 .76458 L p .707 .577 .707 r
F P
0 g
s
.35424 .75119 m .35754 .76975 L .34531 .76593 L p .707 .577 .707 r
F P
0 g
s
.34531 .76593 m .34201 .74736 L .35424 .75119 L p .707 .577 .707 r
F P
0 g
s
.3436 .68376 m .35074 .72083 L .33021 .71992 L p .707 .577 .707 r
F P
0 g
s
.34878 .77126 m .36044 .46511 L .36009 .37768 L .707 .577 .707 r
F
.34833 .78689 m .34906 .76744 L p .34878 .77126 L F P
0 g
s
.35577 .68724 m .35646 .69086 L p .35074 .72083 L .707 .577 .707 r
F P
0 g
s
.35646 .69086 m .3629 .72432 L .35328 .72156 L p .707 .577 .707 r
F P
0 g
s
.35328 .72156 m .35074 .72083 L p .35646 .69086 L .707 .577 .707 r
F P
0 g
s
.34906 .76744 m .34937 .75934 L p .34878 .77126 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .36044 .46511 L p .34916 .76138 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .34916 .76138 L .34878 .77126 L .707 .577 .707 r
F
.36044 .46511 m .36712 .28739 L p .36009 .37768 L F P
0 g
s
.36129 .67759 m .36347 .67517 L p .36125 .66658 L .707 .577 .707 r
F P
0 g
s
.15797 .64154 m .1633 .69741 L .17579 .70312 L p .707 .577 .707 r
F P
0 g
s
.66608 .71722 m .67322 .75429 L .64636 .75605 L p .707 .577 .707 r
F P
0 g
s
.64636 .75605 m .63922 .71897 L .66608 .71722 L p .707 .577 .707 r
F P
0 g
s
.19492 .81807 m .19162 .79951 L .17102 .79817 L p .707 .577 .707 r
F P
0 g
s
.17102 .79817 m .17432 .81674 L .19492 .81807 L p .707 .577 .707 r
F P
0 g
s
.35814 .61929 m .36347 .67517 L .36064 .66803 L p .707 .577 .707 r
F P
0 g
s
.36064 .66803 m .35531 .61215 L .35814 .61929 L p .707 .577 .707 r
F P
0 g
s
.35839 .69296 m .36553 .73003 L .3629 .72432 L p .707 .577 .707 r
F P
0 g
s
.3629 .72432 m .35577 .68724 L .35839 .69296 L p .707 .577 .707 r
F P
0 g
s
.35691 .75712 m .36021 .77568 L .35754 .76975 L p .707 .577 .707 r
F P
0 g
s
.35754 .76975 m .35424 .75119 L .35691 .75712 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .34833 .78689 L .36609 .79921 L p .707 .577 .707 r
F P
0 g
s
.18007 .77342 m .17293 .73635 L .16076 .73286 L p .707 .577 .707 r
F P
0 g
s
.1633 .69741 m .15797 .64154 L .15514 .63439 L p .707 .577 .707 r
F P
0 g
s
.16076 .73286 m .1679 .76993 L .18007 .77342 L p .707 .577 .707 r
F P
0 g
s
.66442 .77489 m .66772 .79345 L .64077 .79474 L p .707 .577 .707 r
F P
0 g
s
.64077 .79474 m .63747 .77617 L .66442 .77489 L p .707 .577 .707 r
F P
0 g
s
.17432 .81674 m .17102 .79817 L .15878 .79435 L p .707 .577 .707 r
F P
0 g
s
.15514 .63439 m .16047 .69027 L .1633 .69741 L p .707 .577 .707 r
F P
0 g
s
.15878 .79435 m .16208 .81292 L .17432 .81674 L p .707 .577 .707 r
F P
0 g
s
.65071 .28995 m .63192 .78944 L .62784 .77662 L p .707 .577 .707 r
F P
0 g
s
.62784 .77662 m .64664 .27712 L .65071 .28995 L p .707 .577 .707 r
F P
0 g
s
.1679 .76993 m .16076 .73286 L .15813 .72714 L p .707 .577 .707 r
F P
0 g
s
.16047 .69027 m .15514 .63439 L .16224 .62651 L p .707 .577 .707 r
F P
0 g
s
.15813 .72714 m .16527 .76421 L .1679 .76993 L p .707 .577 .707 r
F P
0 g
s
.34201 .74736 m .34531 .76593 L .32471 .76459 L p .707 .577 .707 r
F P
0 g
s
.36305 .27457 m .34426 .77406 L .34833 .78689 L p .707 .577 .707 r
F P
0 g
s
.34426 .77406 m .36305 .27457 L .37305 .2625 L p .707 .577 .707 r
F P
0 g
s
.16208 .81292 m .15878 .79435 L .15612 .78842 L p .707 .577 .707 r
F P
0 g
s
.16224 .62651 m .16758 .68239 L .16047 .69027 L p .707 .577 .707 r
F P
0 g
s
.15612 .78842 m .15942 .80698 L .16208 .81292 L p .707 .577 .707 r
F P
0 g
s
.16527 .76421 m .15813 .72714 L .16531 .71975 L p .707 .577 .707 r
F P
0 g
s
.16758 .68239 m .16224 .62651 L .17859 .61866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16531 .71975 m .17245 .75682 L .16527 .76421 L p .707 .577 .707 r
F P
0 g
s
.64664 .27712 m .62784 .77662 L .61009 .76429 L p .707 .577 .707 r
F P
0 g
s
.61009 .76429 m .62888 .2648 L .64664 .27712 L p .707 .577 .707 r
F P
0 g
s
.34282 .60644 m .34815 .66232 L .32723 .65861 L p .707 .577 .707 r
F P
0 g
s
.32723 .65861 m .3219 .60274 L .34282 .60644 L p .707 .577 .707 r
F P
0 g
s
.15942 .80698 m .15612 .78842 L .16328 .78096 L p .707 .577 .707 r
F P
0 g
s
.17859 .61866 m .18392 .67454 L .16758 .68239 L p .707 .577 .707 r
F P
0 g
s
.16328 .78096 m .16658 .79952 L .15942 .80698 L p .707 .577 .707 r
F P
0 g
s
.35426 .76199 m .37305 .2625 L .39616 .25236 L p .707 .577 .707 r
F P
0 g
s
.37305 .2625 m .35426 .76199 L .34426 .77406 L p .707 .577 .707 r
F P
0 g
s
.17245 .75682 m .16531 .71975 L .18159 .71141 L p .707 .577 .707 r
F P
0 g
s
.18392 .67454 m .17859 .61866 L .20258 .61161 L p .707 .577 .707 r
F P
0 g
s
.18159 .71141 m .18873 .74848 L .17245 .75682 L p .707 .577 .707 r
F P
0 g
s
.33021 .71992 m .32307 .68284 L .3436 .68376 L p .707 .577 .707 r
F P
0 g
s
.3219 .60274 m .32723 .65861 L .29992 .65727 L p .707 .577 .707 r
F P
0 g
s
.29992 .65727 m .29458 .60139 L .3219 .60274 L p .707 .577 .707 r
F P
0 g
s
.20258 .61161 m .20791 .66749 L .18392 .67454 L p .707 .577 .707 r
F P
0 g
s
.62888 .2648 m .61009 .76429 L .58039 .75368 L p .707 .577 .707 r
F P
0 g
s
.58039 .75368 m .59919 .25419 L .62888 .2648 L p .707 .577 .707 r
F P
0 g
s
.16658 .79952 m .16328 .78096 L .17957 .77269 L p .707 .577 .707 r
F P
0 g
s
.20791 .66749 m .20258 .61161 L .23185 .60605 L p .707 .577 .707 r
F P
0 g
s
.17957 .77269 m .18287 .79125 L .16658 .79952 L p .707 .577 .707 r
F P
0 g
s
.18873 .74848 m .18159 .71141 L .20537 .70294 L p .707 .577 .707 r
F P
0 g
s
.32471 .76459 m .32141 .74603 L .34201 .74736 L p .707 .577 .707 r
F P
0 g
s
.29458 .60139 m .29992 .65727 L .26889 .65841 L p .707 .577 .707 r
F P
0 g
s
.26889 .65841 m .26356 .60253 L .29458 .60139 L p .707 .577 .707 r
F P
0 g
s
.39616 .25236 m .37736 .75185 L .35426 .76199 L p .707 .577 .707 r
F P
0 g
s
.37736 .75185 m .39616 .25236 L .4301 .24515 L p .707 .577 .707 r
F P
0 g
s
.32307 .68284 m .33021 .71992 L .30335 .72167 L p .707 .577 .707 r
F P
0 g
s
.30335 .72167 m .29621 .6846 L .32307 .68284 L p .707 .577 .707 r
F P
0 g
s
.23719 .66193 m .23185 .60605 L .26356 .60253 L p .707 .577 .707 r
F P
0 g
s
.23185 .60605 m .23719 .66193 L .20791 .66749 L p .707 .577 .707 r
F P
0 g
s
.20537 .70294 m .21251 .74001 L .18873 .74848 L p .707 .577 .707 r
F P
0 g
s
.26356 .60253 m .26889 .65841 L .23719 .66193 L p .707 .577 .707 r
F P
0 g
s
.73527 .65719 m .72993 .60131 L .69891 .60245 L p .707 .577 .707 r
F P
0 g
s
.72993 .60131 m .73527 .65719 L .76697 .65367 L p .707 .577 .707 r
F P
0 g
s
.76697 .65367 m .76164 .59779 L .72993 .60131 L p .707 .577 .707 r
F P
0 g
s
.76164 .59779 m .76697 .65367 L .79625 .64811 L p .707 .577 .707 r
F P
0 g
s
.79625 .64811 m .79091 .59223 L .76164 .59779 L p .707 .577 .707 r
F P
0 g
s
.18287 .79125 m .17957 .77269 L .20339 .76443 L p .707 .577 .707 r
F P
0 g
s
.70424 .65833 m .69891 .60245 L .67159 .6011 L p .707 .577 .707 r
F P
0 g
s
.69891 .60245 m .70424 .65833 L .73527 .65719 L p .707 .577 .707 r
F P
0 g
s
.21251 .74001 m .20537 .70294 L .23433 .69516 L p .707 .577 .707 r
F P
0 g
s
.20339 .76443 m .20669 .78299 L .18287 .79125 L p .707 .577 .707 r
F P
0 g
s
.59919 .25419 m .58039 .75368 L .54166 .74581 L p .707 .577 .707 r
F P
0 g
s
.54166 .74581 m .56045 .24632 L .59919 .25419 L p .707 .577 .707 r
F P
0 g
s
.29621 .6846 m .30335 .72167 L .27277 .72591 L p .707 .577 .707 r
F P
0 g
s
.27277 .72591 m .26563 .68884 L .29621 .6846 L p .707 .577 .707 r
F P
0 g
s
.79091 .59223 m .79625 .64811 L .82023 .64106 L p .707 .577 .707 r
F P
0 g
s
.82023 .64106 m .8149 .58518 L .79091 .59223 L p .707 .577 .707 r
F P
0 g
s
.32141 .74603 m .32471 .76459 L .29776 .76588 L p .707 .577 .707 r
F P
0 g
s
.29776 .76588 m .29446 .74731 L .32141 .74603 L p .707 .577 .707 r
F P
0 g
s
.23433 .69516 m .24146 .73223 L .21251 .74001 L p .707 .577 .707 r
F P
0 g
s
.73825 .71067 m .73111 .6736 L .70053 .67784 L p .707 .577 .707 r
F P
0 g
s
.73111 .6736 m .73825 .71067 L .76955 .70435 L p .707 .577 .707 r
F P
0 g
s
.76955 .70435 m .76241 .66728 L .73111 .6736 L p .707 .577 .707 r
F P
0 g
s
.24146 .73223 m .23433 .69516 L .26563 .68884 L p .707 .577 .707 r
F P
0 g
s
.67159 .6011 m .67693 .65698 L .70424 .65833 L p .707 .577 .707 r
F P
0 g
s
.76241 .66728 m .76955 .70435 L .79851 .69658 L p .707 .577 .707 r
F P
0 g
s
.79851 .69658 m .79137 .6595 L .76241 .66728 L p .707 .577 .707 r
F P
0 g
s
.26563 .68884 m .27277 .72591 L .24146 .73223 L p .707 .577 .707 r
F P
0 g
s
.41131 .74464 m .4301 .24515 L .47156 .24157 L p .707 .577 .707 r
F P
0 g
s
.4301 .24515 m .41131 .74464 L .37736 .75185 L p .707 .577 .707 r
F P
0 g
s
.67693 .65698 m .67159 .6011 L .65067 .5974 L p .707 .577 .707 r
F P
0 g
s
.20669 .78299 m .20339 .76443 L .23241 .75699 L p .707 .577 .707 r
F P
0 g
s
.70053 .67784 m .70767 .71492 L .73825 .71067 L p .707 .577 .707 r
F P
0 g
s
.70767 .71492 m .70053 .67784 L .67366 .6796 L p .707 .577 .707 r
F P
0 g
s
.23241 .75699 m .23571 .77555 L .20669 .78299 L p .707 .577 .707 r
F P
0 g
s
.29446 .74731 m .29776 .76588 L .26709 .76965 L p .707 .577 .707 r
F P
0 g
s
.26709 .76965 m .26379 .75109 L .29446 .74731 L p .707 .577 .707 r
F P
0 g
s
.79137 .6595 m .79851 .69658 L .82229 .6881 L p .707 .577 .707 r
F P
0 g
s
.82229 .6881 m .81515 .65103 L .79137 .6595 L p .707 .577 .707 r
F P
0 g
s
.8149 .58518 m .82023 .64106 L .83658 .63321 L p .707 .577 .707 r
F P
0 g
s
.83658 .63321 m .83125 .57733 L .8149 .58518 L p .707 .577 .707 r
F P
0 g
s
.56045 .24632 m .54166 .74581 L .49768 .74147 L p .707 .577 .707 r
F P
0 g
s
.49768 .74147 m .51648 .24197 L .56045 .24632 L p .707 .577 .707 r
F P
0 g
s
.67366 .6796 m .6808 .71667 L .70767 .71492 L p .707 .577 .707 r
F P
0 g
s
.73275 .74983 m .72945 .73127 L .69878 .73505 L p .707 .577 .707 r
F P
0 g
s
.72945 .73127 m .73275 .74983 L .76413 .74394 L p .707 .577 .707 r
F P
0 g
s
.76413 .74394 m .76083 .72537 L .72945 .73127 L p .707 .577 .707 r
F P
0 g
s
.65067 .5974 m .656 .65327 L .67693 .65698 L p .707 .577 .707 r
F P
0 g
s
.76083 .72537 m .76413 .74394 L .79315 .73649 L p .707 .577 .707 r
F P
0 g
s
.79315 .73649 m .78985 .71793 L .76083 .72537 L p .707 .577 .707 r
F P
0 g
s
.23571 .77555 m .23241 .75699 L .26379 .75109 L p .707 .577 .707 r
F P
0 g
s
.26379 .75109 m .26709 .76965 L .23571 .77555 L p .707 .577 .707 r
F P
0 g
s
.45277 .74106 m .47156 .24157 L .51648 .24197 L p .707 .577 .707 r
F P
0 g
s
.47156 .24157 m .45277 .74106 L .41131 .74464 L p .707 .577 .707 r
F P
0 g
s
.69878 .73505 m .70208 .75361 L .73275 .74983 L p .707 .577 .707 r
F P
0 g
s
.51648 .24197 m .49768 .74147 L .45277 .74106 L p .707 .577 .707 r
F P
0 g
s
.70208 .75361 m .69878 .73505 L .67183 .73633 L p .707 .577 .707 r
F P
0 g
s
.6808 .71667 m .67366 .6796 L .65314 .67868 L p .707 .577 .707 r
F P
0 g
s
.656 .65327 m .65067 .5974 L .63818 .59169 L p .707 .577 .707 r
F P
0 g
s
.67183 .73633 m .67513 .75489 L .70208 .75361 L p .707 .577 .707 r
F P
0 g
s
.78985 .71793 m .79315 .73649 L .81697 .72823 L p .707 .577 .707 r
F P
0 g
s
.81697 .72823 m .81367 .70967 L .78985 .71793 L p .707 .577 .707 r
F P
0 g
s
.81515 .65103 m .82229 .6881 L .83857 .67976 L p .707 .577 .707 r
F P
0 g
s
.83857 .67976 m .83143 .64269 L .81515 .65103 L p .707 .577 .707 r
F P
0 g
s
.65314 .67868 m .66028 .71576 L .6808 .71667 L p .707 .577 .707 r
F P
0 g
s
.83125 .57733 m .83658 .63321 L .84369 .62533 L p .707 .577 .707 r
F P
0 g
s
.84369 .62533 m .83835 .56945 L .83125 .57733 L p .707 .577 .707 r
F P
0 g
s
.63818 .59169 m .64351 .64757 L .656 .65327 L p .707 .577 .707 r
F P
0 g
s
.67513 .75489 m .67183 .73633 L .65123 .735 L p .707 .577 .707 r
F P
0 g
s
.65123 .735 m .65453 .75356 L .67513 .75489 L p .707 .577 .707 r
F P
0 g
s
.81367 .70967 m .81697 .72823 L .83326 .71997 L p .707 .577 .707 r
F P
0 g
s
.83326 .71997 m .82996 .7014 L .81367 .70967 L p .707 .577 .707 r
F P
0 g
s
.66028 .71576 m .65314 .67868 L .64097 .6752 L p .707 .577 .707 r
F P
0 g
s
.64351 .64757 m .63818 .59169 L .63535 .58455 L p .707 .577 .707 r
F P
0 g
s
.64097 .6752 m .64811 .71227 L .66028 .71576 L p .707 .577 .707 r
F P
0 g
s
.83143 .64269 m .83857 .67976 L .84574 .67237 L p .707 .577 .707 r
F P
0 g
s
.84574 .67237 m .8386 .6353 L .83143 .64269 L p .707 .577 .707 r
F P
0 g
s
.65453 .75356 m .65123 .735 L .639 .73118 L p .707 .577 .707 r
F P
0 g
s
.639 .73118 m .6423 .74974 L .65453 .75356 L p .707 .577 .707 r
F P
0 g
s
.83835 .56945 m .84369 .62533 L .84086 .61818 L p .707 .577 .707 r
F P
0 g
s
.84086 .61818 m .83552 .5623 L .83835 .56945 L p .707 .577 .707 r
F P
0 g
s
.63535 .58455 m .64068 .64043 L .64351 .64757 L p .707 .577 .707 r
F P
0 g
s
.82996 .7014 m .83326 .71997 L .84042 .7125 L p .707 .577 .707 r
F P
0 g
s
.84042 .7125 m .83712 .69394 L .82996 .7014 L p .707 .577 .707 r
F P
0 g
s
.64811 .71227 m .64097 .6752 L .63835 .66948 L p .707 .577 .707 r
F P
0 g
s
.63835 .66948 m .64549 .70655 L .64811 .71227 L p .707 .577 .707 r
F P
0 g
s
.64068 .64043 m .63535 .58455 L .64246 .57667 L p .707 .577 .707 r
F P
0 g
s
.8386 .6353 m .84574 .67237 L .84312 .66665 L p .707 .577 .707 r
F P
0 g
s
.84312 .66665 m .83598 .62958 L .8386 .6353 L p .707 .577 .707 r
F P
0 g
s
.6423 .74974 m .639 .73118 L .63633 .72524 L p .707 .577 .707 r
F P
0 g
s
.63633 .72524 m .63963 .7438 L .6423 .74974 L p .707 .577 .707 r
F P
0 g
s
.83552 .5623 m .84086 .61818 L .82837 .61248 L p .707 .577 .707 r
F P
0 g
s
.82837 .61248 m .82304 .5566 L .83552 .5623 L p .707 .577 .707 r
F P
0 g
s
.64246 .57667 m .64779 .63254 L .64068 .64043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83712 .69394 m .84042 .7125 L .83776 .70657 L p .707 .577 .707 r
F P
0 g
s
.83776 .70657 m .83446 .68801 L .83712 .69394 L p .707 .577 .707 r
F P
0 g
s
.64549 .70655 m .63835 .66948 L .64552 .66209 L p .707 .577 .707 r
F P
0 g
s
.39226 .61499 m .38692 .55912 L .3559 .56026 L p .707 .577 .707 r
F P
0 g
s
.38692 .55912 m .39226 .61499 L .42396 .61147 L p .707 .577 .707 r
F P
0 g
s
.42396 .61147 m .41863 .55559 L .38692 .55912 L p .707 .577 .707 r
F P
0 g
s
.41863 .55559 m .42396 .61147 L .45324 .60591 L p .707 .577 .707 r
F P
0 g
s
.45324 .60591 m .4479 .55003 L .41863 .55559 L p .707 .577 .707 r
F P
0 g
s
.64552 .66209 m .65266 .69916 L .64549 .70655 L p .707 .577 .707 r
F P
0 g
s
.64779 .63254 m .64246 .57667 L .6588 .56882 L p .707 .577 .707 r
F P
0 g
s
.36123 .61614 m .3559 .56026 L .32858 .55891 L p .707 .577 .707 r
F P
0 g
s
.3559 .56026 m .36123 .61614 L .39226 .61499 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83598 .62958 m .84312 .66665 L .83095 .66317 L p .707 .577 .707 r
F P
0 g
s
.83095 .66317 m .82381 .62609 L .83598 .62958 L p .707 .577 .707 r
F P
0 g
s
.4479 .55003 m .45324 .60591 L .47722 .59886 L p .707 .577 .707 r
F P
0 g
s
.47722 .59886 m .47189 .54299 L .4479 .55003 L p .707 .577 .707 r
F P
0 g
s
.63963 .7438 m .63633 .72524 L .6435 .71778 L p .707 .577 .707 r
F P
0 g
s
.82304 .5566 m .82837 .61248 L .80744 .60877 L p .707 .577 .707 r
F P
0 g
s
.80744 .60877 m .80211 .55289 L .82304 .5566 L p .707 .577 .707 r
F P
0 g
s
.6435 .71778 m .6468 .73634 L .63963 .7438 L p .707 .577 .707 r
F P
0 g
s
.6588 .56882 m .66414 .62469 L .64779 .63254 L p .707 .577 .707 r
F P
0 g
s
.32858 .55891 m .33392 .61479 L .36123 .61614 L p .707 .577 .707 r
F P
0 g
s
.39524 .6763 m .3881 .63922 L .35752 .64347 L p .707 .577 .707 r
F P
0 g
s
.3881 .63922 m .39524 .6763 L .42654 .66998 L p .707 .577 .707 r
F P
0 g
s
.42654 .66998 m .4194 .63291 L .3881 .63922 L p .707 .577 .707 r
F P
0 g
s
.4194 .63291 m .42654 .66998 L .4555 .6622 L p .707 .577 .707 r
F P
0 g
s
.4555 .6622 m .44836 .62513 L .4194 .63291 L p .707 .577 .707 r
F P
0 g
s
.33392 .61479 m .32858 .55891 L .30766 .5552 L p .707 .577 .707 r
F P
0 g
s
.83446 .68801 m .83776 .70657 L .82553 .70275 L p .707 .577 .707 r
F P
0 g
s
.82553 .70275 m .82223 .68419 L .83446 .68801 L p .707 .577 .707 r
F P
0 g
s
.35752 .64347 m .36466 .68054 L .39524 .6763 L p .707 .577 .707 r
F P
0 g
s
.65266 .69916 m .64552 .66209 L .6618 .65375 L p .707 .577 .707 r
F P
0 g
s
.36466 .68054 m .35752 .64347 L .33065 .64522 L p .707 .577 .707 r
F P
0 g
s
.47189 .54299 m .47722 .59886 L .49357 .59101 L p .707 .577 .707 r
F P
0 g
s
.49357 .59101 m .48824 .53514 L .47189 .54299 L p .707 .577 .707 r
F P
0 g
s
.66414 .62469 m .6588 .56882 L .68279 .56177 L p .707 .577 .707 r
F P
0 g
s
.44836 .62513 m .4555 .6622 L .47928 .65373 L p .707 .577 .707 r
F P
0 g
s
.47928 .65373 m .47214 .61665 L .44836 .62513 L p .707 .577 .707 r
F P
0 g
s
.6618 .65375 m .66894 .69082 L .65266 .69916 L p .707 .577 .707 r
F P
0 g
s
.33065 .64522 m .33779 .68229 L .36466 .68054 L p .707 .577 .707 r
F P
0 g
s
.30766 .5552 m .31299 .61108 L .33392 .61479 L p .707 .577 .707 r
F P
0 g
s
.82381 .62609 m .83095 .66317 L .81043 .66226 L p .707 .577 .707 r
F P
0 g
s
.81043 .66226 m .80329 .62518 L .82381 .62609 L p .707 .577 .707 r
F P
0 g
s
.38974 .72097 m .38644 .70241 L .35577 .70619 L p .707 .577 .707 r
F P
0 g
s
.38644 .70241 m .38974 .72097 L .42112 .71508 L p .707 .577 .707 r
F P
0 g
s
.42112 .71508 m .41782 .69651 L .38644 .70241 L p .707 .577 .707 r
F P
0 g
s
.41782 .69651 m .42112 .71508 L .45014 .70763 L p .707 .577 .707 r
F P
0 g
s
.45014 .70763 m .44684 .68907 L .41782 .69651 L p .707 .577 .707 r
F P
0 g
s
.80211 .55289 m .80744 .60877 L .78013 .60742 L p .707 .577 .707 r
F P
0 g
s
.78013 .60742 m .7748 .55154 L .80211 .55289 L p .707 .577 .707 r
F P
0 g
s
.35577 .70619 m .35907 .72475 L .38974 .72097 L p .707 .577 .707 r
F P
0 g
s
.6468 .73634 m .6435 .71778 L .65979 .70951 L p .707 .577 .707 r
F P
0 g
s
.68279 .56177 m .68812 .61765 L .66414 .62469 L p .707 .577 .707 r
F P
0 g
s
.33779 .68229 m .33065 .64522 L .31013 .64431 L p .707 .577 .707 r
F P
0 g
s
.31299 .61108 m .30766 .5552 L .29517 .5495 L p .707 .577 .707 r
F P
0 g
s
.35907 .72475 m .35577 .70619 L .32882 .70747 L p .707 .577 .707 r
F P
0 g
s
.65979 .70951 m .66309 .72807 L .6468 .73634 L p .707 .577 .707 r
F P
0 g
s
.32882 .70747 m .33212 .72603 L .35907 .72475 L p .707 .577 .707 r
F P
0 g
s
.44684 .68907 m .45014 .70763 L .47396 .69937 L p .707 .577 .707 r
F P
0 g
s
.47396 .69937 m .47066 .68081 L .44684 .68907 L p .707 .577 .707 r
F P
0 g
s
.68812 .61765 m .68279 .56177 L .71207 .55621 L p .707 .577 .707 r
F P
0 g
s
.47214 .61665 m .47928 .65373 L .49556 .64539 L p .707 .577 .707 r
F P
0 g
s
.49556 .64539 m .48842 .60831 L .47214 .61665 L p .707 .577 .707 r
F P
0 g
s
.31013 .64431 m .31727 .68138 L .33779 .68229 L p .707 .577 .707 r
F P
0 g
s
.82223 .68419 m .82553 .70275 L .80493 .70141 L p .707 .577 .707 r
F P
0 g
s
.80493 .70141 m .80163 .68285 L .82223 .68419 L p .707 .577 .707 r
F P
0 g
s
.66894 .69082 m .6618 .65375 L .68558 .64527 L p .707 .577 .707 r
F P
0 g
s
.7748 .55154 m .78013 .60742 L .74911 .60856 L p .707 .577 .707 r
F P
0 g
s
.74911 .60856 m .74377 .55269 L .7748 .55154 L p .707 .577 .707 r
F P
0 g
s
.48824 .53514 m .49357 .59101 L .50068 .58313 L p .707 .577 .707 r
F P
0 g
s
.50068 .58313 m .49534 .52725 L .48824 .53514 L p .707 .577 .707 r
F P
0 g
s
.29517 .5495 m .3005 .60538 L .31299 .61108 L p .707 .577 .707 r
F P
0 g
s
.80329 .62518 m .81043 .66226 L .78356 .66401 L p .707 .577 .707 r
F P
0 g
s
.78356 .66401 m .77642 .62693 L .80329 .62518 L p .707 .577 .707 r
F P
0 g
s
.68558 .64527 m .69272 .68235 L .66894 .69082 L p .707 .577 .707 r
F P
0 g
s
.7174 .61209 m .71207 .55621 L .74377 .55269 L p .707 .577 .707 r
F P
0 g
s
.71207 .55621 m .7174 .61209 L .68812 .61765 L p .707 .577 .707 r
F P
0 g
s
.33212 .72603 m .32882 .70747 L .30822 .70614 L p .707 .577 .707 r
F P
0 g
s
.74377 .55269 m .74911 .60856 L .7174 .61209 L p .707 .577 .707 r
F P
0 g
s
.30822 .70614 m .31152 .7247 L .33212 .72603 L p .707 .577 .707 r
F P
0 g
s
.31727 .68138 m .31013 .64431 L .29796 .64082 L p .707 .577 .707 r
F P
0 g
s
.47066 .68081 m .47396 .69937 L .49025 .69111 L p .707 .577 .707 r
F P
0 g
s
.49025 .69111 m .48695 .67255 L .47066 .68081 L p .707 .577 .707 r
F P
0 g
s
.66309 .72807 m .65979 .70951 L .68361 .70125 L p .707 .577 .707 r
F P
0 g
s
.69272 .68235 m .68558 .64527 L .71454 .6375 L p .707 .577 .707 r
F P
0 g
s
.68361 .70125 m .68691 .71981 L .66309 .72807 L p .707 .577 .707 r
F P
0 g
s
.3005 .60538 m .29517 .5495 L .29234 .54235 L p .707 .577 .707 r
F P
0 g
s
.29796 .64082 m .3051 .67789 L .31727 .68138 L p .707 .577 .707 r
F P
0 g
s
.80163 .68285 m .80493 .70141 L .77798 .7027 L p .707 .577 .707 r
F P
0 g
s
.77798 .7027 m .77467 .68414 L .80163 .68285 L p .707 .577 .707 r
F P
0 g
s
.77642 .62693 m .78356 .66401 L .75298 .66825 L p .707 .577 .707 r
F P
0 g
s
.75298 .66825 m .74584 .63118 L .77642 .62693 L p .707 .577 .707 r
F P
0 g
s
.48842 .60831 m .49556 .64539 L .50273 .638 L p .707 .577 .707 r
F P
0 g
s
.50273 .638 m .49559 .60092 L .48842 .60831 L p .707 .577 .707 r
F P
0 g
s
.71454 .6375 m .72168 .67457 L .69272 .68235 L p .707 .577 .707 r
F P
0 g
s
.72168 .67457 m .71454 .6375 L .74584 .63118 L p .707 .577 .707 r
F P
0 g
s
.74584 .63118 m .75298 .66825 L .72168 .67457 L p .707 .577 .707 r
F P
0 g
s
.31152 .7247 m .30822 .70614 L .29599 .70232 L p .707 .577 .707 r
F P
0 g
s
.49534 .52725 m .50068 .58313 L .49785 .57599 L p .707 .577 .707 r
F P
0 g
s
.49785 .57599 m .49251 .52011 L .49534 .52725 L p .707 .577 .707 r
F P
0 g
s
.29234 .54235 m .29767 .59823 L .3005 .60538 L p .707 .577 .707 r
F P
0 g
s
.68691 .71981 m .68361 .70125 L .71263 .69381 L p .707 .577 .707 r
F P
0 g
s
.29599 .70232 m .29929 .72088 L .31152 .7247 L p .707 .577 .707 r
F P
0 g
s
.71263 .69381 m .71593 .71237 L .68691 .71981 L p .707 .577 .707 r
F P
0 g
s
.77467 .68414 m .77798 .7027 L .74731 .70647 L p .707 .577 .707 r
F P
0 g
s
.74731 .70647 m .74401 .68791 L .77467 .68414 L p .707 .577 .707 r
F P
0 g
s
.48695 .67255 m .49025 .69111 L .49741 .68364 L p .707 .577 .707 r
F P
0 g
s
.49741 .68364 m .49411 .66508 L .48695 .67255 L p .707 .577 .707 r
F P
0 g
s
.3051 .67789 m .29796 .64082 L .29534 .6351 L p .707 .577 .707 r
F P
0 g
s
.71593 .71237 m .71263 .69381 L .74401 .68791 L p .707 .577 .707 r
F P
0 g
s
.74401 .68791 m .74731 .70647 L .71593 .71237 L p .707 .577 .707 r
F P
0 g
s
.29767 .59823 m .29234 .54235 L .29945 .53447 L p .707 .577 .707 r
F P
0 g
s
.29534 .6351 m .30248 .67218 L .3051 .67789 L p .707 .577 .707 r
F P
0 g
s
.49559 .60092 m .50273 .638 L .50011 .63228 L p .707 .577 .707 r
F P
0 g
s
.50011 .63228 m .49297 .5952 L .49559 .60092 L p .707 .577 .707 r
F P
0 g
s
.29929 .72088 m .29599 .70232 L .29332 .69638 L p .707 .577 .707 r
F P
0 g
s
.49251 .52011 m .49785 .57599 L .48536 .57028 L p .707 .577 .707 r
F P
0 g
s
.48536 .57028 m .48003 .51441 L .49251 .52011 L p .707 .577 .707 r
F P
0 g
s
.29945 .53447 m .30478 .59035 L .29767 .59823 L p .707 .577 .707 r
F P
0 g
s
.29332 .69638 m .29662 .71495 L .29929 .72088 L p .707 .577 .707 r
F P
0 g
s
.49411 .66508 m .49741 .68364 L .49475 .67771 L p .707 .577 .707 r
F P
0 g
s
.49475 .67771 m .49145 .65915 L .49411 .66508 L p .707 .577 .707 r
F P
0 g
s
.30248 .67218 m .29534 .6351 L .30251 .62771 L p .707 .577 .707 r
F P
0 g
s
.30478 .59035 m .29945 .53447 L .31579 .52662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30251 .62771 m .30965 .66478 L .30248 .67218 L p .707 .577 .707 r
F P
0 g
s
.49297 .5952 m .50011 .63228 L .48794 .62879 L p .707 .577 .707 r
F P
0 g
s
.48794 .62879 m .4808 .59172 L .49297 .5952 L p .707 .577 .707 r
F P
0 g
s
.48003 .51441 m .48536 .57028 L .46443 .56658 L p .707 .577 .707 r
F P
0 g
s
.46443 .56658 m .4591 .5107 L .48003 .51441 L p .707 .577 .707 r
F P
0 g
s
.29662 .71495 m .29332 .69638 L .30049 .68892 L p .707 .577 .707 r
F P
0 g
s
.31579 .52662 m .32113 .5825 L .30478 .59035 L p .707 .577 .707 r
F P
0 g
s
.30049 .68892 m .30379 .70748 L .29662 .71495 L p .707 .577 .707 r
F P
0 g
s
.49145 .65915 m .49475 .67771 L .48252 .67389 L p .707 .577 .707 r
F P
0 g
s
.48252 .67389 m .47922 .65533 L .49145 .65915 L p .707 .577 .707 r
F P
0 g
s
.30965 .66478 m .30251 .62771 L .31879 .61937 L p .707 .577 .707 r
F P
0 g
s
.32113 .5825 m .31579 .52662 L .33978 .51957 L p .707 .577 .707 r
F P
0 g
s
.31879 .61937 m .32593 .65644 L .30965 .66478 L p .707 .577 .707 r
F P
0 g
s
.4808 .59172 m .48794 .62879 L .46742 .62788 L p .707 .577 .707 r
F P
0 g
s
.46742 .62788 m .46028 .59081 L .4808 .59172 L p .707 .577 .707 r
F P
0 g
s
.4591 .5107 m .46443 .56658 L .43712 .56523 L p .707 .577 .707 r
F P
0 g
s
.43712 .56523 m .43179 .50935 L .4591 .5107 L p .707 .577 .707 r
F P
0 g
s
.33978 .51957 m .34511 .57545 L .32113 .5825 L p .707 .577 .707 r
F P
0 g
s
.30379 .70748 m .30049 .68892 L .31677 .68065 L p .707 .577 .707 r
F P
0 g
s
.34511 .57545 m .33978 .51957 L .36906 .51401 L p .707 .577 .707 r
F P
0 g
s
.31677 .68065 m .32008 .69921 L .30379 .70748 L p .707 .577 .707 r
F P
0 g
s
.32593 .65644 m .31879 .61937 L .34257 .6109 L p .707 .577 .707 r
F P
0 g
s
.47922 .65533 m .48252 .67389 L .46192 .67256 L p .707 .577 .707 r
F P
0 g
s
.46192 .67256 m .45862 .65399 L .47922 .65533 L p .707 .577 .707 r
F P
0 g
s
.43179 .50935 m .43712 .56523 L .40609 .56637 L p .707 .577 .707 r
F P
0 g
s
.40609 .56637 m .40076 .51049 L .43179 .50935 L p .707 .577 .707 r
F P
0 g
s
.46028 .59081 m .46742 .62788 L .44055 .62963 L p .707 .577 .707 r
F P
0 g
s
.44055 .62963 m .43341 .59256 L .46028 .59081 L p .707 .577 .707 r
F P
0 g
s
.37439 .56989 m .36906 .51401 L .40076 .51049 L p .707 .577 .707 r
F P
0 g
s
.36906 .51401 m .37439 .56989 L .34511 .57545 L p .707 .577 .707 r
F P
0 g
s
.34257 .6109 m .34971 .64797 L .32593 .65644 L p .707 .577 .707 r
F P
0 g
s
.40076 .51049 m .40609 .56637 L .37439 .56989 L p .707 .577 .707 r
F P
0 g
s
.32008 .69921 m .31677 .68065 L .3406 .67239 L p .707 .577 .707 r
F P
0 g
s
.34971 .64797 m .34257 .6109 L .37153 .60312 L p .707 .577 .707 r
F P
0 g
s
.3406 .67239 m .3439 .69095 L .32008 .69921 L p .707 .577 .707 r
F P
0 g
s
.43341 .59256 m .44055 .62963 L .40997 .63387 L p .707 .577 .707 r
F P
0 g
s
.40997 .63387 m .40283 .5968 L .43341 .59256 L p .707 .577 .707 r
F P
0 g
s
.45862 .65399 m .46192 .67256 L .43496 .67384 L p .707 .577 .707 r
F P
0 g
s
.43496 .67384 m .43166 .65528 L .45862 .65399 L p .707 .577 .707 r
F P
0 g
s
.37153 .60312 m .37867 .64019 L .34971 .64797 L p .707 .577 .707 r
F P
0 g
s
.37867 .64019 m .37153 .60312 L .40283 .5968 L p .707 .577 .707 r
F P
0 g
s
.40283 .5968 m .40997 .63387 L .37867 .64019 L p .707 .577 .707 r
F P
0 g
s
.3439 .69095 m .3406 .67239 L .36962 .66495 L p .707 .577 .707 r
F P
0 g
s
.36962 .66495 m .37292 .68351 L .3439 .69095 L p .707 .577 .707 r
F P
0 g
s
.43166 .65528 m .43496 .67384 L .4043 .67761 L p .707 .577 .707 r
F P
0 g
s
.4043 .67761 m .401 .65905 L .43166 .65528 L p .707 .577 .707 r
F P
0 g
s
.37292 .68351 m .36962 .66495 L .401 .65905 L p .707 .577 .707 r
F P
0 g
s
.401 .65905 m .4043 .67761 L .37292 .68351 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00Ngoo001`Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006ioo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00K7oo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06moo`00JWoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00JGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JWoo
001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Qoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008006Ioo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Aoo`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Ioo`00Ggoo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001HOol2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001FOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol8000mOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8001Uoo`T000AJEP04001JEUYFFUH6000gOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00D0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;goo001COol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
200015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20007Ool400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF20000UYF00L005YFFUIJEP00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF200025YF00<0
05YFFUH01EYF00<005YFFUH015YF1@000UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEPD0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF000015YF00<005YF00000`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005Aoo`03001JEP0000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Ao
o`04001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
4`0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH0000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00AWoo40000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003ioo`P000AJ
EP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00>7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEP00
00<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90008FUH70003FUH00`00FUIJEP02
000]Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH500000eYF0000000]Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0035oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP06001JEUYFFUH005YF
10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;Goo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH600000eYF001JEP03FUH00`00FUH0000]Ool002ioo`05001J
EUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP/0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH0
0`00FUIJEP0500000eYF0000000^Ool002eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPP000IJEP04001JEUYFFUH4000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00L005YF001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00FUH^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo
001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003
FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP03FUH40009FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00@005YFFUIJEP<00003FUH0
05YF00QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPH0009JEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEPH000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH015YF2@000eYF00<005YFFUH01@0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000=JEP05001JEUYFFUH00002FUH01000FUIJEP001eYF00<005YFFUH01UYF1`0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH01@00FUIJEUYF
00000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEQ400003FUH007oo02aoo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF1P001UYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH015YF
1P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000/
Ool002eoo`03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEPL000QJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002eo
o`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF009JEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUH0000/Ool002eoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEP0000800003FUH005YF00QJEP03001JEUYF
00AJEPH000YJEP03001JEUYF00=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEP<0
00=JEPH000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP8002eoo`00;Goo00<0
05YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
100015YF00<005YFFUH01eYF00<005YFFUH01@000eYF00<005YFFUH02EYF00<005YFFUH00`000eYF
00<005YF00000P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEP00008000IJEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002eoo`05001JEP00FUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH900000eYF001JEP05FUH00`00FUIJEP04FUH500000eYF
000000030002FUH00`00FUIJEP09FUH300000eYF001JEP04FUH01000FUH000002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF009JEP<00003
FUH005YF00MJEP03001JEUYF00EJEQD0031oo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00001P0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01000
15YF00<005YF000010000UYF00<005YFFUH01UYF0`0015YF00<005YFFUH00eYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001J
EP00008000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00
008002moo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF100000=JEP00FUH01EYF00<005YF000010000UYF
00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00003FUH40007FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030006FUH00`00FUIJ
EP06FUH20004FUH00`00FUH000030002FUH01000FUIJEP001UYF00<005YFFUH00`000eYF00<005YF
FUH00`0015YF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800006FUH005YFFUH005YF0P000eYF00<005YFFUH01EYF1@00
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo0P00
00=JEP00FUH015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF00<005YF0000
15YF0`001EYF00@005YFFUH000IJEP03001JEUYF00=JEPH000MJEP03001JEUYF00=JEP<000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP8000EJEP03
001JEUYF009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool0031oo`<000AJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0002FUH01000FUIJEP001EYF00@005YFFUH000AJEPP000AJEP03001JEUYF
00IJEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJEP02FUHC0002
FUH00`00Oomoo`0/Ool003=oo`<00005FUH00000FUH00008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUH000002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000AJEP00FUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEP/000aoo`H002ioo`00
=Goo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEPP0
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80009JEP8000EJEP03001JEUYF
00IJEP03001JEUYF00@0009JEP@000ioo`<0009JEP04001JEUYF000^Ool003=oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP@000MJEP03001JEUYF00AJ
EPX0011oo`800003FUH005YF00=JEP03001JEP0002ioo`00<Goo0`001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF1@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH020000goo0`00
3Woo0P000eYF00<005YFFUH00UYF0P00;goo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH010002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH015YF1P0027oo1@002Woo0`001EYF00<005YF
FUH00UYF00<007ooOol0;Woo000]Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40005FUH01000FUIJEUYF0P0000=JEP00FUH00`0027oo1@001Woo100000=JEP00FUH01UYF
00@005YFFUH0035oo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEPL000IJEQ@000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH01000FUH000000eYF
00<005YFFUH00P0027oo2`001EYF00<005YFFUH01EYF0`00<Woo000/Ool01@00FUIJEUYF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH40005FUH01000FUH005YF1Goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00=7oo
000/Ool01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEP04001JEP000003FUH00`00FUIJEP03FUH01@00FUIJEP00Ool010000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00=Woo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF000005YF018000IJEP03001JEUYF
00MJEP03001JEUYF00AJEP<003Yoo`00;Goo00@005YFFUH000AJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUHE0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
00000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04000mOol002eoo`04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP001UYF00<005YFFUH015YF2@00
00=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP0000000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH015YF1@00@Goo000]Ool01000FUIJEP0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF4`000UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH02UYF00<0
05YFFUH02EYF1`0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000AWoo000]Ool01@00FUIJEUYF
00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001:Ool002eoo`04001JEUYFFUH30004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF1@001eYF00<005YFFUH00UYF0P000UYF5P00DGoo000^Ool00`00FUIJEP020005FUH00`00
FUIJEP04FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00UYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1000
Dgoo000^Ool300000eYF001JEP04FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF0`0000=J
EP00FUH00eYF0P001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000005=oo`00;Woo0P00
0eYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF4P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EP0005=oo`00;goo0P000UYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH015YF1P0047oo
0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP8000IJEP03001JEUYF00AJEP03001JEUYF
00=JEP8005Aoo`00<Goo100015YF00<005YFFUH01eYF00<005YFFUH01@004goo0P0000=JEP000000
1EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF10001UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00<Goo0`001UYF00<005YFFUH015YF1@0000=oo`0000000`0047oo0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00004`00Egoo000_Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP040006Ool5000>Ool20002FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00H005YF000005YF0006FUH00`00FUIJEP03FUH00`00FUH00002001FOol002ioo`03
001JEUYF00=JEP03001JEUYF009JEP@000Yoo`D000Yoo`@000AJEP05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00=JEP05001JEUYFFUH0
001FOol002eoo`8000EJEP03001JEP00008000moo`<000Moo`@0009JEP03001JEUYF00AJEP03001J
EUYF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP00EWoo000/Ool00`00FUH00005FUH2000EOol70006FUH00`00FUIJ
EP04FUH30002Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF001FOol002aoo`04001JEUYF0002FUH2000?Ool80004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUH005YF40000eYF00<007ooOol0Dgoo000/Ool00`00FUIJEP040008Ool80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH000030009Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000<Ool400000eYF
001oo`1DOol002eoo`04001JEP000002FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`0<Ool30002FUH01000FUH00000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04000COol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P003Goo0P0000=JEP00FUH00eYF00<005YF0000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
000IOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH01000FUH000003Goo0P000eYF00<005YFFUH00UYF0P00EWoo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000QOol40008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH5000;Ool30005FUH00`00FUIJ
EP02FUH00`00Oomoo`1EOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF009J
EPH002Uoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
0003Ool0000000<000Ioo`@00003FUH005YF00IJEP04001JEUYF001HOol0031ooa@003Eoo`T000IJ
EP03001JEUYF00UJEP03001JEUYF00AJEPP000Ioo`D00003Ool0000000<000EJEP03001JEUYF00EJ
EP<005Uoo`00PWoo6@003Woo1P000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Fgoo002=Ool0
1@00FUIJEP00FUH00P0047oo2@0015YF00<005YFFUH01UYF00<005YF00000`00GGoo002>Ool00`00
FUH0000C0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001QOol008ioo`80009JEP03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006Aoo`00SWoo
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00J7oo
002>Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001]
Ool008moo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0075oo`00TGoo
5000N7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5991 .74892 m .59049 .69313 L .5597 .69616 L p .707 .577 .707 r
F P
0 g
s
.59049 .69313 m .5991 .74892 L .63059 .7437 L p .707 .577 .707 r
F P
0 g
s
.63059 .7437 m .62199 .68791 L .59049 .69313 L p .707 .577 .707 r
F P
0 g
s
.62199 .68791 m .63059 .7437 L .6597 .73679 L p .707 .577 .707 r
F P
0 g
s
.6597 .73679 m .6511 .68101 L .62199 .68791 L p .707 .577 .707 r
F P
0 g
s
.56831 .75195 m .5597 .69616 L .53263 .6967 L p .707 .577 .707 r
F P
0 g
s
.5597 .69616 m .56831 .75195 L .5991 .74892 L p .707 .577 .707 r
F P
0 g
s
.6511 .68101 m .6597 .73679 L .68358 .72888 L p .707 .577 .707 r
F P
0 g
s
.68358 .72888 m .67497 .67309 L .6511 .68101 L p .707 .577 .707 r
F P
0 g
s
.60344 .79796 m .59201 .76163 L .56238 .76963 L p .707 .577 .707 r
F P
0 g
s
.59201 .76163 m .60344 .79796 L .63388 .78826 L p .707 .577 .707 r
F P
0 g
s
.63388 .78826 m .62246 .75193 L .59201 .76163 L p .707 .577 .707 r
F P
0 g
s
.62246 .75193 m .63388 .78826 L .66216 .7778 L p .707 .577 .707 r
F P
0 g
s
.66216 .7778 m .65074 .74146 L .62246 .75193 L p .707 .577 .707 r
F P
0 g
s
.53263 .6967 m .54123 .75248 L .56831 .75195 L p .707 .577 .707 r
F P
0 g
s
.56238 .76963 m .57381 .80596 L .60344 .79796 L p .707 .577 .707 r
F P
0 g
s
.54123 .75248 m .53263 .6967 L .51191 .69469 L p .707 .577 .707 r
F P
0 g
s
.57381 .80596 m .56238 .76963 L .53646 .77513 L p .707 .577 .707 r
F P
0 g
s
.65074 .74146 m .66216 .7778 L .68551 .7676 L p .707 .577 .707 r
F P
0 g
s
.68551 .7676 m .67408 .73127 L .65074 .74146 L p .707 .577 .707 r
F P
0 g
s
.67497 .67309 m .68358 .72888 L .69989 .72073 L p .707 .577 .707 r
F P
0 g
s
.69989 .72073 m .69128 .66494 L .67497 .67309 L p .707 .577 .707 r
F P
0 g
s
.53646 .77513 m .54789 .81146 L .57381 .80596 L p .707 .577 .707 r
F P
0 g
s
.59466 .83567 m .58937 .81741 L .55951 .82466 L p .707 .577 .707 r
F P
0 g
s
.58937 .81741 m .59466 .83567 L .62531 .82664 L p .707 .577 .707 r
F P
0 g
s
.62531 .82664 m .62002 .80837 L .58937 .81741 L p .707 .577 .707 r
F P
0 g
s
.62002 .80837 m .62531 .82664 L .65375 .81671 L p .707 .577 .707 r
F P
0 g
s
.65375 .81671 m .64846 .79844 L .62002 .80837 L p .707 .577 .707 r
F P
0 g
s
.51191 .69469 m .52052 .75047 L .54123 .75248 L p .707 .577 .707 r
F P
0 g
s
.55951 .82466 m .5648 .84292 L .59466 .83567 L p .707 .577 .707 r
F P
0 g
s
.5648 .84292 m .55951 .82466 L .53337 .82942 L p .707 .577 .707 r
F P
0 g
s
.54789 .81146 m .53646 .77513 L .5168 .7776 L p .707 .577 .707 r
F P
0 g
s
.64846 .79844 m .65375 .81671 L .6772 .80685 L p .707 .577 .707 r
F P
0 g
s
.6772 .80685 m .67191 .78859 L .64846 .79844 L p .707 .577 .707 r
F P
0 g
s
.53337 .82942 m .53866 .84768 L .5648 .84292 L p .707 .577 .707 r
F P
0 g
s
.67408 .73127 m .68551 .7676 L .70163 .75866 L p .707 .577 .707 r
F P
0 g
s
.70163 .75866 m .69021 .72233 L .67408 .73127 L p .707 .577 .707 r
F P
0 g
s
.52052 .75047 m .51191 .69469 L .49959 .69033 L p .707 .577 .707 r
F P
0 g
s
.5168 .7776 m .52822 .81394 L .54789 .81146 L p .707 .577 .707 r
F P
0 g
s
.69128 .66494 m .69989 .72073 L .70703 .71314 L p .707 .577 .707 r
F P
0 g
s
.70703 .71314 m .69843 .65736 L .69128 .66494 L p .707 .577 .707 r
F P
0 g
s
.49959 .69033 m .5082 .74611 L .52052 .75047 L p .707 .577 .707 r
F P
0 g
s
.53866 .84768 m .53337 .82942 L .5135 .83122 L p .707 .577 .707 r
F P
0 g
s
.5135 .83122 m .51879 .84949 L .53866 .84768 L p .707 .577 .707 r
F P
0 g
s
.67191 .78859 m .6772 .80685 L .69336 .79803 L p .707 .577 .707 r
F P
0 g
s
.69336 .79803 m .68807 .77977 L .67191 .78859 L p .707 .577 .707 r
F P
0 g
s
.52822 .81394 m .5168 .7776 L .50531 .7768 L p .707 .577 .707 r
F P
0 g
s
.69021 .72233 m .70163 .75866 L .70896 .75187 L p .707 .577 .707 r
F P
0 g
s
.70896 .75187 m .69753 .71553 L .69021 .72233 L p .707 .577 .707 r
F P
0 g
s
.50531 .7768 m .51673 .81314 L .52822 .81394 L p .707 .577 .707 r
F P
0 g
s
.5082 .74611 m .49959 .69033 L .49687 .68405 L p .707 .577 .707 r
F P
0 g
s
.51879 .84949 m .5135 .83122 L .50185 .82989 L p .707 .577 .707 r
F P
0 g
s
.69843 .65736 m .70703 .71314 L .70431 .70687 L p .707 .577 .707 r
F P
0 g
s
.70431 .70687 m .6957 .65108 L .69843 .65736 L p .707 .577 .707 r
F P
0 g
s
.50185 .82989 m .50714 .84816 L .51879 .84949 L p .707 .577 .707 r
F P
0 g
s
.49687 .68405 m .50548 .73984 L .5082 .74611 L p .707 .577 .707 r
F P
0 g
s
.68807 .77977 m .69336 .79803 L .70065 .79112 L p .707 .577 .707 r
F P
0 g
s
.70065 .79112 m .69536 .77285 L .68807 .77977 L p .707 .577 .707 r
F P
0 g
s
.47109 .82196 m .50148 .32433 L .45756 .31896 L p .707 .577 .707 r
F P
0 g
s
.51673 .81314 m .50531 .7768 L .50312 .77281 L p .707 .577 .707 r
F P
0 g
s
.50312 .77281 m .51454 .80914 L .51673 .81314 L p .707 .577 .707 r
F P
0 g
s
.50548 .73984 m .49687 .68405 L .50401 .67647 L p .707 .577 .707 r
F P
0 g
s
.50401 .67647 m .51262 .73225 L .50548 .73984 L p .707 .577 .707 r
F P
0 g
s
.51454 .80914 m .50312 .77281 L .51045 .76601 L p .707 .577 .707 r
F P
0 g
s
.51045 .76601 m .52187 .80235 L .51454 .80914 L p .707 .577 .707 r
F P
0 g
s
.51262 .73225 m .50401 .67647 L .52032 .66832 L p .707 .577 .707 r
F P
0 g
s
.50714 .84816 m .50185 .82989 L .49956 .82556 L p .707 .577 .707 r
F P
0 g
s
.49956 .82556 m .50485 .84382 L .50714 .84816 L p .707 .577 .707 r
F P
0 g
s
.50485 .84382 m .49956 .82556 L .50685 .81864 L p .707 .577 .707 r
F P
0 g
s
.50685 .81864 m .51214 .83691 L .50485 .84382 L p .707 .577 .707 r
F P
0 g
s
.52032 .66832 m .52893 .72411 L .51262 .73225 L p .707 .577 .707 r
F P
0 g
s
.52187 .80235 m .51045 .76601 L .52657 .75708 L p .707 .577 .707 r
F P
0 g
s
.51214 .83691 m .50685 .81864 L .52301 .80983 L p .707 .577 .707 r
F P
0 g
s
.50148 .32433 m .47109 .82196 L .51596 .82329 L p .707 .577 .707 r
F P
0 g
s
.52893 .72411 m .52032 .66832 L .5442 .66041 L p .707 .577 .707 r
F P
0 g
s
.51596 .82329 m .54635 .32566 L .50148 .32433 L p .707 .577 .707 r
F P
0 g
s
.52657 .75708 m .538 .79341 L .52187 .80235 L p .707 .577 .707 r
F P
0 g
s
.5442 .66041 m .55281 .71619 L .52893 .72411 L p .707 .577 .707 r
F P
0 g
s
.52301 .80983 m .52831 .82809 L .51214 .83691 L p .707 .577 .707 r
F P
0 g
s
.55281 .71619 m .5442 .66041 L .57331 .6535 L p .707 .577 .707 r
F P
0 g
s
.538 .79341 m .52657 .75708 L .54992 .74688 L p .707 .577 .707 r
F P
0 g
s
.54992 .74688 m .56134 .78321 L .538 .79341 L p .707 .577 .707 r
F P
0 g
s
.57331 .6535 m .58192 .70928 L .55281 .71619 L p .707 .577 .707 r
F P
0 g
s
.52831 .82809 m .52301 .80983 L .54646 .79997 L p .707 .577 .707 r
F P
0 g
s
.54646 .79997 m .55175 .81823 L .52831 .82809 L p .707 .577 .707 r
F P
0 g
s
.56134 .78321 m .54992 .74688 L .5782 .73642 L p .707 .577 .707 r
F P
0 g
s
.55175 .81823 m .54646 .79997 L .5749 .79004 L p .707 .577 .707 r
F P
0 g
s
.5749 .79004 m .58019 .8083 L .55175 .81823 L p .707 .577 .707 r
F P
0 g
s
.54635 .32566 m .51596 .82329 L .55738 .82045 L p .707 .577 .707 r
F P
0 g
s
.55738 .82045 m .58778 .32281 L .54635 .32566 L p .707 .577 .707 r
F P
0 g
s
.42716 .81659 m .45756 .31896 L .41887 .31007 L p .707 .577 .707 r
F P
0 g
s
.45756 .31896 m .42716 .81659 L .47109 .82196 L p .707 .577 .707 r
F P
0 g
s
.69753 .71553 m .70896 .75187 L .70677 .74787 L p .707 .577 .707 r
F P
0 g
s
.70677 .74787 m .69535 .71154 L .69753 .71553 L p .707 .577 .707 r
F P
0 g
s
.58192 .70928 m .57331 .6535 L .6048 .64828 L p .707 .577 .707 r
F P
0 g
s
.6048 .64828 m .61341 .70406 L .58192 .70928 L p .707 .577 .707 r
F P
0 g
s
.5782 .73642 m .58962 .77275 L .56134 .78321 L p .707 .577 .707 r
F P
0 g
s
.58962 .77275 m .5782 .73642 L .60864 .72671 L p .707 .577 .707 r
F P
0 g
s
.60864 .72671 m .62007 .76305 L .58962 .77275 L p .707 .577 .707 r
F P
0 g
s
.58019 .8083 m .5749 .79004 L .60555 .781 L p .707 .577 .707 r
F P
0 g
s
.60555 .781 m .61084 .79927 L .58019 .8083 L p .707 .577 .707 r
F P
0 g
s
.58778 .32281 m .55738 .82045 L .5913 .81371 L p .707 .577 .707 r
F P
0 g
s
.5913 .81371 m .6217 .31607 L .58778 .32281 L p .707 .577 .707 r
F P
0 g
s
.6957 .65108 m .70431 .70687 L .69199 .70251 L p .707 .577 .707 r
F P
0 g
s
.69199 .70251 m .68338 .64673 L .6957 .65108 L p .707 .577 .707 r
F P
0 g
s
.69536 .77285 m .70065 .79112 L .69836 .78678 L p .707 .577 .707 r
F P
0 g
s
.69836 .78678 m .69307 .76852 L .69536 .77285 L p .707 .577 .707 r
F P
0 g
s
.38848 .8077 m .41887 .31007 L .38922 .29853 L p .707 .577 .707 r
F P
0 g
s
.41887 .31007 m .38848 .8077 L .42716 .81659 L p .707 .577 .707 r
F P
0 g
s
.25609 .7034 m .24749 .64762 L .21669 .65064 L p .707 .577 .707 r
F P
0 g
s
.24749 .64762 m .25609 .7034 L .28758 .69818 L p .707 .577 .707 r
F P
0 g
s
.28758 .69818 m .27898 .6424 L .24749 .64762 L p .707 .577 .707 r
F P
0 g
s
.27898 .6424 m .28758 .69818 L .31669 .69127 L p .707 .577 .707 r
F P
0 g
s
.31669 .69127 m .30809 .63549 L .27898 .6424 L p .707 .577 .707 r
F P
0 g
s
.69535 .71154 m .70677 .74787 L .69528 .74707 L p .707 .577 .707 r
F P
0 g
s
.69528 .74707 m .68386 .71074 L .69535 .71154 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2253 .70643 m .21669 .65064 L .18962 .65118 L p .707 .577 .707 r
F P
0 g
s
.21669 .65064 m .2253 .70643 L .25609 .7034 L p .707 .577 .707 r
F P
0 g
s
.30809 .63549 m .31669 .69127 L .34057 .68336 L p .707 .577 .707 r
F P
0 g
s
.34057 .68336 m .33196 .62757 L .30809 .63549 L p .707 .577 .707 r
F P
0 g
s
.63559 .64525 m .6442 .70104 L .61341 .70406 L p .707 .577 .707 r
F P
0 g
s
.61341 .70406 m .6048 .64828 L .63559 .64525 L p .707 .577 .707 r
F P
0 g
s
.62007 .76305 m .60864 .72671 L .63827 .71872 L p .707 .577 .707 r
F P
0 g
s
.63541 .77375 m .6407 .79201 L .61084 .79927 L p .707 .577 .707 r
F P
0 g
s
.61084 .79927 m .60555 .781 L .63541 .77375 L p .707 .577 .707 r
F P
0 g
s
.6217 .31607 m .5913 .81371 L .6144 .80373 L p .707 .577 .707 r
F P
0 g
s
.6144 .80373 m .64479 .3061 L .6217 .31607 L p .707 .577 .707 r
F P
0 g
s
.68338 .64673 m .69199 .70251 L .67128 .7005 L p .707 .577 .707 r
F P
0 g
s
.67128 .7005 m .66267 .64472 L .68338 .64673 L p .707 .577 .707 r
F P
0 g
s
.18962 .65118 m .19822 .70696 L .2253 .70643 L p .707 .577 .707 r
F P
0 g
s
.26043 .7651 m .249 .72876 L .21937 .73676 L p .707 .577 .707 r
F P
0 g
s
.249 .72876 m .26043 .7651 L .29087 .75539 L p .707 .577 .707 r
F P
0 g
s
.29087 .75539 m .27945 .71906 L .249 .72876 L p .707 .577 .707 r
F P
0 g
s
.27945 .71906 m .29087 .75539 L .31915 .74493 L p .707 .577 .707 r
F P
0 g
s
.31915 .74493 m .30773 .7086 L .27945 .71906 L p .707 .577 .707 r
F P
0 g
s
.69307 .76852 m .69836 .78678 L .68671 .78545 L p .707 .577 .707 r
F P
0 g
s
.68671 .78545 m .68142 .76719 L .69307 .76852 L p .707 .577 .707 r
F P
0 g
s
.19822 .70696 m .18962 .65118 L .1689 .64917 L p .707 .577 .707 r
F P
0 g
s
.21937 .73676 m .2308 .77309 L .26043 .7651 L p .707 .577 .707 r
F P
0 g
s
.34827 .61943 m .35688 .67521 L .35886 .67311 L p .707 .577 .707 r
F P
0 g
s
.35886 .67311 m .36402 .66763 L p .35871 .65137 L .707 .577 .707 r
F P
0 g
s
.35871 .65137 m .34827 .61943 L .35886 .67311 L .707 .577 .707 r
F
.3715 .28547 m .36745 .27218 L p .35747 .46585 L F P
0 g
s
.33196 .62757 m .34057 .68336 L .35688 .67521 L p .707 .577 .707 r
F P
0 g
s
.35688 .67521 m .34827 .61943 L .33196 .62757 L p .707 .577 .707 r
F P
0 g
s
.33107 .6984 m .3425 .73473 L .35862 .7258 L p .707 .577 .707 r
F P
0 g
s
.35862 .7258 m .3472 .68946 L .33107 .6984 L p .707 .577 .707 r
F P
0 g
s
.36402 .66763 m .35542 .61184 L .34827 .61943 L p .707 .577 .707 r
F P
0 g
s
.3289 .76464 m .33419 .78291 L .35035 .77409 L p .707 .577 .707 r
F P
0 g
s
.35035 .77409 m .34506 .75583 L .3289 .76464 L p .707 .577 .707 r
F P
0 g
s
.34898 .65699 m .34038 .60121 L .35269 .60556 L p .707 .577 .707 r
F P
0 g
s
.3472 .68946 m .35862 .7258 L .36595 .719 L p .707 .577 .707 r
F P
0 g
s
.36595 .719 m .35452 .68266 L .3472 .68946 L p .707 .577 .707 r
F P
0 g
s
.35227 .71421 m .3482 .70124 L p .35234 .67867 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .34085 .67787 L .3523 .67867 L p .707 .577 .707 r
F P
0 g
s
.3523 .67867 m .35234 .67867 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.34038 .60121 m .34898 .65699 L .32827 .65498 L p .707 .577 .707 r
F P
0 g
s
.3425 .73473 m .33107 .6984 L .30773 .7086 L p .707 .577 .707 r
F P
0 g
s
.34085 .67787 m .3482 .70124 L p .33261 .71668 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .35227 .71421 L .34688 .71488 L p .707 .577 .707 r
F P
0 g
s
.34688 .71488 m .33261 .71668 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.30773 .7086 m .31915 .74493 L .3425 .73473 L p .707 .577 .707 r
F P
0 g
s
.34506 .75583 m .35035 .77409 L .35764 .76717 L p .707 .577 .707 r
F P
0 g
s
.35764 .76717 m .35235 .74891 L .34506 .75583 L p .707 .577 .707 r
F P
0 g
s
.3437 .76151 m .33841 .74324 L .35006 .74458 L p .707 .577 .707 r
F P
0 g
s
.33841 .74324 m .3437 .76151 L .32383 .76331 L p .707 .577 .707 r
F P
0 g
s
.36745 .27218 m .33706 .76981 L .3405 .78112 L p .707 .577 .707 r
F P
0 g
s
.3405 .78112 m .34111 .78311 L p .34203 .76528 L .707 .577 .707 r
F P
0 g
s
.34203 .76528 m .36745 .27218 L .3405 .78112 L .707 .577 .707 r
F
.34419 .72326 m .35776 .5104 L .35747 .46585 L F
.34111 .78311 m .34505 .71855 L p .34419 .72326 L F P
0 g
s
.34505 .71855 m .35776 .5104 L p .34419 .72326 L .707 .577 .707 r
F P
0 g
s
.35776 .5104 m .3715 .28547 L p .35747 .46585 L .707 .577 .707 r
F P
0 g
s
.35542 .61184 m .36402 .66763 L .3613 .66135 L p .707 .577 .707 r
F P
0 g
s
.35452 .68266 m .36595 .719 L .36376 .715 L p .707 .577 .707 r
F P
0 g
s
.36376 .715 m .35234 .67867 L .35452 .68266 L p .707 .577 .707 r
F P
0 g
s
.35234 .67867 m .36376 .715 L .35227 .71421 L p .707 .577 .707 r
F P
0 g
s
.35883 .79616 m .38922 .29853 L .3715 .28547 L p .707 .577 .707 r
F P
0 g
s
.38922 .29853 m .35883 .79616 L .38848 .8077 L p .707 .577 .707 r
F P
0 g
s
.2308 .77309 m .21937 .73676 L .19345 .74226 L p .707 .577 .707 r
F P
0 g
s
.19345 .74226 m .20488 .7786 L .2308 .77309 L p .707 .577 .707 r
F P
0 g
s
.1689 .64917 m .17751 .70495 L .19822 .70696 L p .707 .577 .707 r
F P
0 g
s
.68386 .71074 m .69528 .74707 L .67562 .74955 L p .707 .577 .707 r
F P
0 g
s
.67562 .74955 m .66419 .71321 L .68386 .71074 L p .707 .577 .707 r
F P
0 g
s
.25165 .81173 m .24636 .79347 L .21651 .80072 L p .707 .577 .707 r
F P
0 g
s
.24636 .79347 m .25165 .81173 L .2823 .8027 L p .707 .577 .707 r
F P
0 g
s
.2823 .8027 m .27701 .78443 L .24636 .79347 L p .707 .577 .707 r
F P
0 g
s
.27701 .78443 m .2823 .8027 L .31074 .79276 L p .707 .577 .707 r
F P
0 g
s
.31074 .79276 m .30545 .7745 L .27701 .78443 L p .707 .577 .707 r
F P
0 g
s
.21651 .80072 m .2218 .81898 L .25165 .81173 L p .707 .577 .707 r
F P
0 g
s
.66267 .64472 m .67128 .7005 L .6442 .70104 L p .707 .577 .707 r
F P
0 g
s
.6442 .70104 m .63559 .64525 L .66267 .64472 L p .707 .577 .707 r
F P
0 g
s
.20488 .7786 m .19345 .74226 L .17379 .74473 L p .707 .577 .707 r
F P
0 g
s
.17751 .70495 m .1689 .64917 L .15658 .64481 L p .707 .577 .707 r
F P
0 g
s
.2218 .81898 m .21651 .80072 L .19036 .80548 L p .707 .577 .707 r
F P
0 g
s
.30545 .7745 m .31074 .79276 L .33419 .78291 L p .707 .577 .707 r
F P
0 g
s
.33419 .78291 m .3289 .76464 L .30545 .7745 L p .707 .577 .707 r
F P
0 g
s
.19036 .80548 m .19565 .82374 L .2218 .81898 L p .707 .577 .707 r
F P
0 g
s
.17379 .74473 m .18521 .78107 L .20488 .7786 L p .707 .577 .707 r
F P
0 g
s
.68142 .76719 m .68671 .78545 L .66684 .78725 L p .707 .577 .707 r
F P
0 g
s
.66684 .78725 m .66155 .76899 L .68142 .76719 L p .707 .577 .707 r
F P
0 g
s
.63827 .71872 m .6497 .75505 L .62007 .76305 L p .707 .577 .707 r
F P
0 g
s
.64479 .3061 m .6144 .80373 L .62441 .7915 L p .707 .577 .707 r
F P
0 g
s
.62441 .7915 m .6548 .29386 L .64479 .3061 L p .707 .577 .707 r
F P
0 g
s
.15658 .64481 m .16519 .7006 L .17751 .70495 L p .707 .577 .707 r
F P
0 g
s
.66419 .71321 m .67562 .74955 L .6497 .75505 L p .707 .577 .707 r
F P
0 g
s
.6497 .75505 m .63827 .71872 L .66419 .71321 L p .707 .577 .707 r
F P
0 g
s
.19565 .82374 m .19036 .80548 L .1705 .80728 L p .707 .577 .707 r
F P
0 g
s
.3613 .66135 m .35269 .60556 L .35542 .61184 L p .707 .577 .707 r
F P
0 g
s
.35269 .60556 m .3613 .66135 L .34898 .65699 L p .707 .577 .707 r
F P
0 g
s
.35235 .74891 m .35764 .76717 L .35535 .76284 L p .707 .577 .707 r
F P
0 g
s
.35535 .76284 m .35006 .74458 L .35235 .74891 L p .707 .577 .707 r
F P
0 g
s
.35006 .74458 m .35535 .76284 L .3437 .76151 L p .707 .577 .707 r
F P
0 g
s
.3715 .28547 m .34111 .78311 L .35883 .79616 L p .707 .577 .707 r
F P
0 g
s
.1705 .80728 m .17579 .82554 L .19565 .82374 L p .707 .577 .707 r
F P
0 g
s
.18521 .78107 m .17379 .74473 L .1623 .74394 L p .707 .577 .707 r
F P
0 g
s
.16519 .7006 m .15658 .64481 L .15386 .63854 L p .707 .577 .707 r
F P
0 g
s
.66155 .76899 m .66684 .78725 L .6407 .79201 L p .707 .577 .707 r
F P
0 g
s
.6407 .79201 m .63541 .77375 L .66155 .76899 L p .707 .577 .707 r
F P
0 g
s
.1623 .74394 m .17372 .78027 L .18521 .78107 L p .707 .577 .707 r
F P
0 g
s
.15386 .63854 m .16247 .69432 L .16519 .7006 L p .707 .577 .707 r
F P
0 g
s
.17579 .82554 m .1705 .80728 L .15884 .80595 L p .707 .577 .707 r
F P
0 g
s
.15884 .80595 m .16414 .82421 L .17579 .82554 L p .707 .577 .707 r
F P
0 g
s
.6548 .29386 m .62441 .7915 L .62036 .7782 L p .707 .577 .707 r
F P
0 g
s
.62036 .7782 m .65075 .28057 L .6548 .29386 L p .707 .577 .707 r
F P
0 g
s
.17372 .78027 m .1623 .74394 L .16011 .73994 L p .707 .577 .707 r
F P
0 g
s
.16011 .73994 m .17154 .77628 L .17372 .78027 L p .707 .577 .707 r
F P
0 g
s
.16247 .69432 m .15386 .63854 L .16101 .63095 L p .707 .577 .707 r
F P
0 g
s
.33706 .76981 m .36745 .27218 L .37746 .25994 L p .707 .577 .707 r
F P
0 g
s
.16101 .63095 m .16961 .68674 L .16247 .69432 L p .707 .577 .707 r
F P
0 g
s
.16414 .82421 m .15884 .80595 L .15655 .80161 L p .707 .577 .707 r
F P
0 g
s
.15655 .80161 m .16184 .81988 L .16414 .82421 L p .707 .577 .707 r
F P
0 g
s
.17154 .77628 m .16011 .73994 L .16744 .73314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16961 .68674 m .16101 .63095 L .17731 .6228 L p .707 .577 .707 r
F P
0 g
s
.65075 .28057 m .62036 .7782 L .60264 .76515 L p .707 .577 .707 r
F P
0 g
s
.60264 .76515 m .63303 .26751 L .65075 .28057 L p .707 .577 .707 r
F P
0 g
s
.16744 .73314 m .17886 .76948 L .17154 .77628 L p .707 .577 .707 r
F P
0 g
s
.32827 .65498 m .31966 .5992 L .34038 .60121 L p .707 .577 .707 r
F P
0 g
s
.17731 .6228 m .18592 .67859 L .16961 .68674 L p .707 .577 .707 r
F P
0 g
s
.34707 .75758 m .37746 .25994 L .40056 .24997 L p .707 .577 .707 r
F P
0 g
s
.37746 .25994 m .34707 .75758 L .33706 .76981 L p .707 .577 .707 r
F P
0 g
s
.16184 .81988 m .15655 .80161 L .16384 .7947 L p .707 .577 .707 r
F P
0 g
s
.16384 .7947 m .16914 .81296 L .16184 .81988 L p .707 .577 .707 r
F P
0 g
s
.17886 .76948 m .16744 .73314 L .18356 .72421 L p .707 .577 .707 r
F P
0 g
s
.18592 .67859 m .17731 .6228 L .20119 .61489 L p .707 .577 .707 r
F P
0 g
s
.33261 .71668 m .32118 .68034 L .34085 .67787 L p .707 .577 .707 r
F P
0 g
s
.18356 .72421 m .19499 .76054 L .17886 .76948 L p .707 .577 .707 r
F P
0 g
s
.31966 .5992 m .32827 .65498 L .30119 .65552 L p .707 .577 .707 r
F P
0 g
s
.30119 .65552 m .29259 .59973 L .31966 .5992 L p .707 .577 .707 r
F P
0 g
s
.20119 .61489 m .2098 .67067 L .18592 .67859 L p .707 .577 .707 r
F P
0 g
s
.63303 .26751 m .60264 .76515 L .57299 .75361 L p .707 .577 .707 r
F P
0 g
s
.57299 .75361 m .60338 .25597 L .63303 .26751 L p .707 .577 .707 r
F P
0 g
s
.16914 .81296 m .16384 .7947 L .18001 .78588 L p .707 .577 .707 r
F P
0 g
s
.2098 .67067 m .20119 .61489 L .2303 .60798 L p .707 .577 .707 r
F P
0 g
s
.18001 .78588 m .1853 .80415 L .16914 .81296 L p .707 .577 .707 r
F P
0 g
s
.32383 .76331 m .31854 .74505 L .33841 .74324 L p .707 .577 .707 r
F P
0 g
s
.40056 .24997 m .37016 .7476 L .34707 .75758 L p .707 .577 .707 r
F P
0 g
s
.37016 .7476 m .40056 .24997 L .43448 .24323 L p .707 .577 .707 r
F P
0 g
s
.29259 .59973 m .30119 .65552 L .2704 .65854 L p .707 .577 .707 r
F P
0 g
s
.2704 .65854 m .26179 .60276 L .29259 .59973 L p .707 .577 .707 r
F P
0 g
s
.19499 .76054 m .18356 .72421 L .20691 .71401 L p .707 .577 .707 r
F P
0 g
s
.32118 .68034 m .33261 .71668 L .30669 .72218 L p .707 .577 .707 r
F P
0 g
s
.30669 .72218 m .29526 .68585 L .32118 .68034 L p .707 .577 .707 r
F P
0 g
s
.23891 .66377 m .2303 .60798 L .26179 .60276 L p .707 .577 .707 r
F P
0 g
s
.2303 .60798 m .23891 .66377 L .2098 .67067 L p .707 .577 .707 r
F P
0 g
s
.20691 .71401 m .21833 .75034 L .19499 .76054 L p .707 .577 .707 r
F P
0 g
s
.26179 .60276 m .2704 .65854 L .23891 .66377 L p .707 .577 .707 r
F P
0 g
s
.7363 .65688 m .7277 .6011 L .69691 .60412 L p .707 .577 .707 r
F P
0 g
s
.7277 .6011 m .7363 .65688 L .7678 .65166 L p .707 .577 .707 r
F P
0 g
s
.7678 .65166 m .75919 .59587 L .7277 .6011 L p .707 .577 .707 r
F P
0 g
s
.75919 .59587 m .7678 .65166 L .79691 .64475 L p .707 .577 .707 r
F P
0 g
s
.79691 .64475 m .7883 .58897 L .75919 .59587 L p .707 .577 .707 r
F P
0 g
s
.70551 .65991 m .69691 .60412 L .66983 .60466 L p .707 .577 .707 r
F P
0 g
s
.69691 .60412 m .70551 .65991 L .7363 .65688 L p .707 .577 .707 r
F P
0 g
s
.1853 .80415 m .18001 .78588 L .20345 .77603 L p .707 .577 .707 r
F P
0 g
s
.21833 .75034 m .20691 .71401 L .23519 .70355 L p .707 .577 .707 r
F P
0 g
s
.60338 .25597 m .57299 .75361 L .5343 .74472 L p .707 .577 .707 r
F P
0 g
s
.5343 .74472 m .5647 .24708 L .60338 .25597 L p .707 .577 .707 r
F P
0 g
s
.20345 .77603 m .20874 .79429 L .1853 .80415 L p .707 .577 .707 r
F P
0 g
s
.7883 .58897 m .79691 .64475 L .82078 .63684 L p .707 .577 .707 r
F P
0 g
s
.82078 .63684 m .81218 .58105 L .7883 .58897 L p .707 .577 .707 r
F P
0 g
s
.29526 .68585 m .30669 .72218 L .27706 .73018 L p .707 .577 .707 r
F P
0 g
s
.27706 .73018 m .26563 .69384 L .29526 .68585 L p .707 .577 .707 r
F P
0 g
s
.31854 .74505 m .32383 .76331 L .29769 .76807 L p .707 .577 .707 r
F P
0 g
s
.29769 .76807 m .2924 .74981 L .31854 .74505 L p .707 .577 .707 r
F P
0 g
s
.23519 .70355 m .24661 .73988 L .21833 .75034 L p .707 .577 .707 r
F P
0 g
s
.74064 .70593 m .72922 .66959 L .69958 .67759 L p .707 .577 .707 r
F P
0 g
s
.72922 .66959 m .74064 .70593 L .77109 .69622 L p .707 .577 .707 r
F P
0 g
s
.77109 .69622 m .75966 .65989 L .72922 .66959 L p .707 .577 .707 r
F P
0 g
s
.40408 .74086 m .43448 .24323 L .4759 .24038 L p .707 .577 .707 r
F P
0 g
s
.43448 .24323 m .40547 .71822 L p .37016 .7476 L .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .44551 .73802 L .40408 .74086 L p .707 .577 .707 r
F P
0 g
s
.38621 .63672 m .39763 .67306 L .41973 .66601 L p .707 .577 .707 r
F P
0 g
s
.41973 .66601 m .42808 .66335 L p .42159 .65923 L .707 .577 .707 r
F P
0 g
s
.42159 .65923 m .38621 .63672 L .41973 .66601 L .707 .577 .707 r
F
.40547 .71822 m .40408 .74086 L .399 .74187 L p F P
0 g
s
.399 .74187 m .37016 .7476 L p .40547 .71822 L .707 .577 .707 r
F P
0 g
s
.75966 .65989 m .77109 .69622 L .79937 .68576 L p .707 .577 .707 r
F P
0 g
s
.79937 .68576 m .78794 .64943 L .75966 .65989 L p .707 .577 .707 r
F P
0 g
s
.66983 .60466 m .67844 .66044 L .70551 .65991 L p .707 .577 .707 r
F P
0 g
s
.24661 .73988 m .23519 .70355 L .26563 .69384 L p .707 .577 .707 r
F P
0 g
s
.26563 .69384 m .27706 .73018 L .24661 .73988 L p .707 .577 .707 r
F P
0 g
s
.69958 .67759 m .71101 .71392 L .74064 .70593 L p .707 .577 .707 r
F P
0 g
s
.67844 .66044 m .66983 .60466 L .64912 .60265 L p .707 .577 .707 r
F P
0 g
s
.71101 .71392 m .69958 .67759 L .67367 .68309 L p .707 .577 .707 r
F P
0 g
s
.20874 .79429 m .20345 .77603 L .23189 .76609 L p .707 .577 .707 r
F P
0 g
s
.78794 .64943 m .79937 .68576 L .82271 .67556 L p .707 .577 .707 r
F P
0 g
s
.82271 .67556 m .81129 .63923 L .78794 .64943 L p .707 .577 .707 r
F P
0 g
s
.2924 .74981 m .29769 .76807 L .26783 .77532 L p .707 .577 .707 r
F P
0 g
s
.26783 .77532 m .26254 .75706 L .2924 .74981 L p .707 .577 .707 r
F P
0 g
s
.23189 .76609 m .23718 .78436 L .20874 .79429 L p .707 .577 .707 r
F P
0 g
s
.5647 .24708 m .5343 .74472 L .49038 .73935 L p .707 .577 .707 r
F P
0 g
s
.49038 .73935 m .52077 .24171 L .5647 .24708 L p .707 .577 .707 r
F P
0 g
s
.81218 .58105 m .82078 .63684 L .83709 .62869 L p .707 .577 .707 r
F P
0 g
s
.83709 .62869 m .82849 .57291 L .81218 .58105 L p .707 .577 .707 r
F P
0 g
s
.67367 .68309 m .68509 .71943 L .71101 .71392 L p .707 .577 .707 r
F P
0 g
s
.73187 .74363 m .72657 .72537 L .69672 .73262 L p .707 .577 .707 r
F P
0 g
s
.72657 .72537 m .73187 .74363 L .76251 .7346 L p .707 .577 .707 r
F P
0 g
s
.76251 .7346 m .75722 .71634 L .72657 .72537 L p .707 .577 .707 r
F P
0 g
s
.75722 .71634 m .76251 .7346 L .79095 .72467 L p .707 .577 .707 r
F P
0 g
s
.79095 .72467 m .78566 .7064 L .75722 .71634 L p .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .52077 .24171 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.44982 .66746 m .4759 .24038 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.41665 .62702 m .41959 .63637 L p .45636 .65289 L .707 .577 .707 r
F P
0 g
s
.41959 .63637 m .42808 .66335 L .44113 .65852 L p .707 .577 .707 r
F P
0 g
s
.44113 .65852 m .45636 .65289 L p .41959 .63637 L .707 .577 .707 r
F P
0 g
s
.44589 .73172 m .44982 .66746 L p .44638 .73227 L .707 .577 .707 r
F P
0 g
s
.41421 .69239 m .41583 .69798 L p .44794 .70073 L .707 .577 .707 r
F P
0 g
s
.41583 .69798 m .4195 .71066 L .42532 .70863 L p .707 .577 .707 r
F P
0 g
s
.42532 .70863 m .44794 .70073 L p .41583 .69798 L .707 .577 .707 r
F P
0 g
s
.44638 .73227 m .44982 .66746 L .45534 .67314 L .707 .577 .707 r
F
.44551 .73802 m .44589 .73172 L p .44638 .73227 L F P
0 g
s
.64912 .60265 m .65772 .65843 L .67844 .66044 L p .707 .577 .707 r
F P
0 g
s
.69672 .73262 m .70201 .75089 L .73187 .74363 L p .707 .577 .707 r
F P
0 g
s
.23718 .78436 m .23189 .76609 L .26254 .75706 L p .707 .577 .707 r
F P
0 g
s
.26254 .75706 m .26783 .77532 L .23718 .78436 L p .707 .577 .707 r
F P
0 g
s
.52077 .24171 m .49038 .73935 L .44551 .73802 L p .707 .577 .707 r
F P
0 g
s
.70201 .75089 m .69672 .73262 L .67058 .73738 L p .707 .577 .707 r
F P
0 g
s
.68509 .71943 m .67367 .68309 L .654 .68556 L p .707 .577 .707 r
F P
0 g
s
.78566 .7064 m .79095 .72467 L .8144 .71481 L p .707 .577 .707 r
F P
0 g
s
.8144 .71481 m .80911 .69655 L .78566 .7064 L p .707 .577 .707 r
F P
0 g
s
.67058 .73738 m .67587 .75565 L .70201 .75089 L p .707 .577 .707 r
F P
0 g
s
.81129 .63923 m .82271 .67556 L .83884 .66663 L p .707 .577 .707 r
F P
0 g
s
.83884 .66663 m .82741 .63029 L .81129 .63923 L p .707 .577 .707 r
F P
0 g
s
.65772 .65843 m .64912 .60265 L .6368 .59829 L p .707 .577 .707 r
F P
0 g
s
.654 .68556 m .66543 .7219 L .68509 .71943 L p .707 .577 .707 r
F P
0 g
s
.82849 .57291 m .83709 .62869 L .84424 .62111 L p .707 .577 .707 r
F P
0 g
s
.84424 .62111 m .83563 .56532 L .82849 .57291 L p .707 .577 .707 r
F P
0 g
s
.6368 .59829 m .6454 .65408 L .65772 .65843 L p .707 .577 .707 r
F P
0 g
s
.67587 .75565 m .67058 .73738 L .65071 .73919 L p .707 .577 .707 r
F P
0 g
s
.65071 .73919 m .656 .75745 L .67587 .75565 L p .707 .577 .707 r
F P
0 g
s
.80911 .69655 m .8144 .71481 L .83056 .70599 L p .707 .577 .707 r
F P
0 g
s
.83056 .70599 m .82527 .68773 L .80911 .69655 L p .707 .577 .707 r
F P
0 g
s
.66543 .7219 m .654 .68556 L .64251 .68477 L p .707 .577 .707 r
F P
0 g
s
.82741 .63029 m .83884 .66663 L .84616 .65983 L p .707 .577 .707 r
F P
0 g
s
.84616 .65983 m .83474 .62349 L .82741 .63029 L p .707 .577 .707 r
F P
0 g
s
.64251 .68477 m .65394 .7211 L .66543 .7219 L p .707 .577 .707 r
F P
0 g
s
.6454 .65408 m .6368 .59829 L .63408 .59201 L p .707 .577 .707 r
F P
0 g
s
.656 .75745 m .65071 .73919 L .63906 .73785 L p .707 .577 .707 r
F P
0 g
s
.83563 .56532 m .84424 .62111 L .84152 .61483 L p .707 .577 .707 r
F P
0 g
s
.84152 .61483 m .83291 .55904 L .83563 .56532 L p .707 .577 .707 r
F P
0 g
s
.63906 .73785 m .64435 .75612 L .656 .75745 L p .707 .577 .707 r
F P
0 g
s
.63408 .59201 m .64268 .6478 L .6454 .65408 L p .707 .577 .707 r
F P
0 g
s
.82527 .68773 m .83056 .70599 L .83785 .69908 L p .707 .577 .707 r
F P
0 g
s
.83785 .69908 m .83256 .68082 L .82527 .68773 L p .707 .577 .707 r
F P
0 g
s
.65394 .7211 m .64251 .68477 L .64032 .68077 L p .707 .577 .707 r
F P
0 g
s
.64032 .68077 m .65175 .71711 L .65394 .7211 L p .707 .577 .707 r
F P
0 g
s
.83474 .62349 m .84616 .65983 L .84398 .65583 L p .707 .577 .707 r
F P
0 g
s
.84398 .65583 m .83255 .6195 L .83474 .62349 L p .707 .577 .707 r
F P
0 g
s
.64268 .6478 m .63408 .59201 L .64122 .58443 L p .707 .577 .707 r
F P
0 g
s
.64435 .75612 m .63906 .73785 L .63677 .73352 L p .707 .577 .707 r
F P
0 g
s
.63677 .73352 m .64206 .75178 L .64435 .75612 L p .707 .577 .707 r
F P
0 g
s
.83291 .55904 m .84152 .61483 L .8292 .61047 L p .707 .577 .707 r
F P
0 g
s
.8292 .61047 m .82059 .55469 L .83291 .55904 L p .707 .577 .707 r
F P
0 g
s
.64122 .58443 m .64983 .64021 L .64268 .6478 L p .707 .577 .707 r
F P
0 g
s
.83256 .68082 m .83785 .69908 L .83556 .69474 L p .707 .577 .707 r
F P
0 g
s
.83556 .69474 m .83027 .67648 L .83256 .68082 L p .707 .577 .707 r
F P
0 g
s
.39329 .61136 m .38469 .55558 L .3539 .5586 L p .707 .577 .707 r
F P
0 g
s
.38469 .55558 m .39329 .61136 L .42479 .60614 L p .707 .577 .707 r
F P
0 g
s
.42479 .60614 m .41618 .55036 L .38469 .55558 L p .707 .577 .707 r
F P
0 g
s
.41618 .55036 m .42479 .60614 L .4539 .59923 L p .707 .577 .707 r
F P
0 g
s
.4539 .59923 m .44529 .54345 L .41618 .55036 L p .707 .577 .707 r
F P
0 g
s
.65175 .71711 m .64032 .68077 L .64765 .67397 L p .707 .577 .707 r
F P
0 g
s
.64765 .67397 m .65908 .71031 L .65175 .71711 L p .707 .577 .707 r
F P
0 g
s
.83255 .6195 m .84398 .65583 L .83249 .65504 L p .707 .577 .707 r
F P
0 g
s
.83249 .65504 m .82106 .6187 L .83255 .6195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3625 .61439 m .3539 .5586 L .32682 .55914 L p .707 .577 .707 r
F P
0 g
s
.3539 .5586 m .3625 .61439 L .39329 .61136 L p .707 .577 .707 r
F P
0 g
s
.64983 .64021 m .64122 .58443 L .65753 .57628 L p .707 .577 .707 r
F P
0 g
s
.44529 .54345 m .4539 .59923 L .47777 .59132 L p .707 .577 .707 r
F P
0 g
s
.47777 .59132 m .46917 .53554 L .44529 .54345 L p .707 .577 .707 r
F P
0 g
s
.64206 .75178 m .63677 .73352 L .64406 .7266 L p .707 .577 .707 r
F P
0 g
s
.82059 .55469 m .8292 .61047 L .80848 .60846 L p .707 .577 .707 r
F P
0 g
s
.80848 .60846 m .79988 .55268 L .82059 .55469 L p .707 .577 .707 r
F P
0 g
s
.32682 .55914 m .33543 .61492 L .3625 .61439 L p .707 .577 .707 r
F P
0 g
s
.64406 .7266 m .64935 .74487 L .64206 .75178 L p .707 .577 .707 r
F P
0 g
s
.39763 .67306 m .38621 .63672 L .35657 .64472 L p .707 .577 .707 r
F P
0 g
s
.42808 .66335 m .41665 .62702 L .38621 .63672 L p .707 .577 .707 r
F P
0 g
s
.65753 .57628 m .66613 .63207 L .64983 .64021 L p .707 .577 .707 r
F P
0 g
s
.45636 .65289 m .44493 .61656 L .41665 .62702 L p .707 .577 .707 r
F P
0 g
s
.83027 .67648 m .83556 .69474 L .82391 .69341 L p .707 .577 .707 r
F P
0 g
s
.82391 .69341 m .81862 .67515 L .83027 .67648 L p .707 .577 .707 r
F P
0 g
s
.33543 .61492 m .32682 .55914 L .30611 .55713 L p .707 .577 .707 r
F P
0 g
s
.35657 .64472 m .368 .68105 L .39763 .67306 L p .707 .577 .707 r
F P
0 g
s
.368 .68105 m .35657 .64472 L .33066 .65022 L p .707 .577 .707 r
F P
0 g
s
.65908 .71031 m .64765 .67397 L .66378 .66504 L p .707 .577 .707 r
F P
0 g
s
.46917 .53554 m .47777 .59132 L .49408 .58317 L p .707 .577 .707 r
F P
0 g
s
.49408 .58317 m .48548 .52739 L .46917 .53554 L p .707 .577 .707 r
F P
0 g
s
.44493 .61656 m .45636 .65289 L .4797 .64269 L p .707 .577 .707 r
F P
0 g
s
.4797 .64269 m .46828 .60636 L .44493 .61656 L p .707 .577 .707 r
F P
0 g
s
.33066 .65022 m .34208 .68656 L .368 .68105 L p .707 .577 .707 r
F P
0 g
s
.66613 .63207 m .65753 .57628 L .68141 .56837 L p .707 .577 .707 r
F P
0 g
s
.30611 .55713 m .31471 .61291 L .33543 .61492 L p .707 .577 .707 r
F P
0 g
s
.82106 .6187 m .83249 .65504 L .81282 .65751 L p .707 .577 .707 r
F P
0 g
s
.81282 .65751 m .80139 .62117 L .82106 .6187 L p .707 .577 .707 r
F P
0 g
s
.66378 .66504 m .6752 .70137 L .65908 .71031 L p .707 .577 .707 r
F P
0 g
s
.38886 .71969 m .38356 .70143 L .35371 .70868 L p .707 .577 .707 r
F P
0 g
s
.38356 .70143 m .38886 .71969 L .4195 .71066 L p .707 .577 .707 r
F P
0 g
s
.4195 .71066 m .41421 .69239 L .38356 .70143 L p .707 .577 .707 r
F P
0 g
s
.44794 .70073 m .44265 .68246 L .41421 .69239 L p .707 .577 .707 r
F P
0 g
s
.35371 .70868 m .359 .72694 L .38886 .71969 L p .707 .577 .707 r
F P
0 g
s
.79988 .55268 m .80848 .60846 L .78141 .609 L p .707 .577 .707 r
F P
0 g
s
.78141 .609 m .7728 .55321 L .79988 .55268 L p .707 .577 .707 r
F P
0 g
s
.68141 .56837 m .69001 .62415 L .66613 .63207 L p .707 .577 .707 r
F P
0 g
s
.64935 .74487 m .64406 .7266 L .66022 .71779 L p .707 .577 .707 r
F P
0 g
s
.34208 .68656 m .33066 .65022 L .31099 .6527 L p .707 .577 .707 r
F P
0 g
s
.31471 .61291 m .30611 .55713 L .29379 .55277 L p .707 .577 .707 r
F P
0 g
s
.359 .72694 m .35371 .70868 L .32757 .71344 L p .707 .577 .707 r
F P
0 g
s
.66022 .71779 m .66551 .73605 L .64935 .74487 L p .707 .577 .707 r
F P
0 g
s
.44265 .68246 m .44794 .70073 L .47139 .69087 L p .707 .577 .707 r
F P
0 g
s
.47139 .69087 m .4661 .67261 L .44265 .68246 L p .707 .577 .707 r
F P
0 g
s
.46828 .60636 m .4797 .64269 L .49583 .63376 L p .707 .577 .707 r
F P
0 g
s
.49583 .63376 m .4844 .59742 L .46828 .60636 L p .707 .577 .707 r
F P
0 g
s
.32757 .71344 m .33286 .7317 L .359 .72694 L p .707 .577 .707 r
F P
0 g
s
.31099 .6527 m .32242 .68903 L .34208 .68656 L p .707 .577 .707 r
F P
0 g
s
.81862 .67515 m .82391 .69341 L .80404 .69522 L p .707 .577 .707 r
F P
0 g
s
.80404 .69522 m .79875 .67695 L .81862 .67515 L p .707 .577 .707 r
F P
0 g
s
.69001 .62415 m .68141 .56837 L .71052 .56146 L p .707 .577 .707 r
F P
0 g
s
.6752 .70137 m .66378 .66504 L .68712 .65484 L p .707 .577 .707 r
F P
0 g
s
.48548 .52739 m .49408 .58317 L .50123 .57559 L p .707 .577 .707 r
F P
0 g
s
.50123 .57559 m .49262 .5198 L .48548 .52739 L p .707 .577 .707 r
F P
0 g
s
.7728 .55321 m .78141 .609 L .75061 .61202 L p .707 .577 .707 r
F P
0 g
s
.75061 .61202 m .74201 .55624 L .7728 .55321 L p .707 .577 .707 r
F P
0 g
s
.29379 .55277 m .30239 .60856 L .31471 .61291 L p .707 .577 .707 r
F P
0 g
s
.80139 .62117 m .81282 .65751 L .7869 .66301 L p .707 .577 .707 r
F P
0 g
s
.7869 .66301 m .77548 .62668 L .80139 .62117 L p .707 .577 .707 r
F P
0 g
s
.68712 .65484 m .69855 .69118 L .6752 .70137 L p .707 .577 .707 r
F P
0 g
s
.71912 .61725 m .71052 .56146 L .74201 .55624 L p .707 .577 .707 r
F P
0 g
s
.71052 .56146 m .71912 .61725 L .69001 .62415 L p .707 .577 .707 r
F P
0 g
s
.33286 .7317 m .32757 .71344 L .3077 .71524 L p .707 .577 .707 r
F P
0 g
s
.74201 .55624 m .75061 .61202 L .71912 .61725 L p .707 .577 .707 r
F P
0 g
s
.3077 .71524 m .31299 .73351 L .33286 .7317 L p .707 .577 .707 r
F P
0 g
s
.4661 .67261 m .47139 .69087 L .48755 .68205 L p .707 .577 .707 r
F P
0 g
s
.48755 .68205 m .48226 .66379 L .4661 .67261 L p .707 .577 .707 r
F P
0 g
s
.32242 .68903 m .31099 .6527 L .2995 .6519 L p .707 .577 .707 r
F P
0 g
s
.66551 .73605 m .66022 .71779 L .68367 .70793 L p .707 .577 .707 r
F P
0 g
s
.68367 .70793 m .68896 .72619 L .66551 .73605 L p .707 .577 .707 r
F P
0 g
s
.69855 .69118 m .68712 .65484 L .7154 .64438 L p .707 .577 .707 r
F P
0 g
s
.30239 .60856 m .29379 .55277 L .29107 .5465 L p .707 .577 .707 r
F P
0 g
s
.4844 .59742 m .49583 .63376 L .50315 .62696 L p .707 .577 .707 r
F P
0 g
s
.50315 .62696 m .49173 .59063 L .4844 .59742 L p .707 .577 .707 r
F P
0 g
s
.79875 .67695 m .80404 .69522 L .7779 .69998 L p .707 .577 .707 r
F P
0 g
s
.7779 .69998 m .77261 .68171 L .79875 .67695 L p .707 .577 .707 r
F P
0 g
s
.2995 .6519 m .31093 .68823 L .32242 .68903 L p .707 .577 .707 r
F P
0 g
s
.77548 .62668 m .7869 .66301 L .75727 .67101 L p .707 .577 .707 r
F P
0 g
s
.75727 .67101 m .74585 .63467 L .77548 .62668 L p .707 .577 .707 r
F P
0 g
s
.7154 .64438 m .72683 .68071 L .69855 .69118 L p .707 .577 .707 r
F P
0 g
s
.72683 .68071 m .7154 .64438 L .74585 .63467 L p .707 .577 .707 r
F P
0 g
s
.49262 .5198 m .50123 .57559 L .4985 .56931 L p .707 .577 .707 r
F P
0 g
s
.4985 .56931 m .4899 .51353 L .49262 .5198 L p .707 .577 .707 r
F P
0 g
s
.74585 .63467 m .75727 .67101 L .72683 .68071 L p .707 .577 .707 r
F P
0 g
s
.29107 .5465 m .29967 .60228 L .30239 .60856 L p .707 .577 .707 r
F P
0 g
s
.31299 .73351 m .3077 .71524 L .29605 .71391 L p .707 .577 .707 r
F P
0 g
s
.68896 .72619 m .68367 .70793 L .71211 .698 L p .707 .577 .707 r
F P
0 g
s
.29605 .71391 m .30134 .73218 L .31299 .73351 L p .707 .577 .707 r
F P
0 g
s
.77261 .68171 m .7779 .69998 L .74805 .70723 L p .707 .577 .707 r
F P
0 g
s
.74805 .70723 m .74276 .68896 L .77261 .68171 L p .707 .577 .707 r
F P
0 g
s
.71211 .698 m .7174 .71626 L .68896 .72619 L p .707 .577 .707 r
F P
0 g
s
.48226 .66379 m .48755 .68205 L .49484 .67514 L p .707 .577 .707 r
F P
0 g
s
.49484 .67514 m .48955 .65687 L .48226 .66379 L p .707 .577 .707 r
F P
0 g
s
.31093 .68823 m .2995 .6519 L .29731 .6479 L p .707 .577 .707 r
F P
0 g
s
.7174 .71626 m .71211 .698 L .74276 .68896 L p .707 .577 .707 r
F P
0 g
s
.74276 .68896 m .74805 .70723 L .7174 .71626 L p .707 .577 .707 r
F P
0 g
s
.29731 .6479 m .30874 .68424 L .31093 .68823 L p .707 .577 .707 r
F P
0 g
s
.49173 .59063 m .50315 .62696 L .50097 .62297 L p .707 .577 .707 r
F P
0 g
s
.50097 .62297 m .48954 .58663 L .49173 .59063 L p .707 .577 .707 r
F P
0 g
s
.29967 .60228 m .29107 .5465 L .29821 .53891 L p .707 .577 .707 r
F P
0 g
s
.4899 .51353 m .4985 .56931 L .48619 .56495 L p .707 .577 .707 r
F P
0 g
s
.48619 .56495 m .47758 .50917 L .4899 .51353 L p .707 .577 .707 r
F P
0 g
s
.29821 .53891 m .30681 .5947 L .29967 .60228 L p .707 .577 .707 r
F P
0 g
s
.30134 .73218 m .29605 .71391 L .29376 .70958 L p .707 .577 .707 r
F P
0 g
s
.29376 .70958 m .29905 .72784 L .30134 .73218 L p .707 .577 .707 r
F P
0 g
s
.48955 .65687 m .49484 .67514 L .49255 .6708 L p .707 .577 .707 r
F P
0 g
s
.49255 .6708 m .48726 .65254 L .48955 .65687 L p .707 .577 .707 r
F P
0 g
s
.30874 .68424 m .29731 .6479 L .30464 .64111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30681 .5947 m .29821 .53891 L .31452 .53076 L p .707 .577 .707 r
F P
0 g
s
.30464 .64111 m .31607 .67744 L .30874 .68424 L p .707 .577 .707 r
F P
0 g
s
.48954 .58663 m .50097 .62297 L .48948 .62217 L p .707 .577 .707 r
F P
0 g
s
.48948 .62217 m .47805 .58583 L .48954 .58663 L p .707 .577 .707 r
F P
0 g
s
.47758 .50917 m .48619 .56495 L .46547 .56294 L p .707 .577 .707 r
F P
0 g
s
.46547 .56294 m .45687 .50716 L .47758 .50917 L p .707 .577 .707 r
F P
0 g
s
.31452 .53076 m .32312 .58655 L .30681 .5947 L p .707 .577 .707 r
F P
0 g
s
.29905 .72784 m .29376 .70958 L .30105 .70266 L p .707 .577 .707 r
F P
0 g
s
.30105 .70266 m .30634 .72093 L .29905 .72784 L p .707 .577 .707 r
F P
0 g
s
.48726 .65254 m .49255 .6708 L .4809 .66947 L p .707 .577 .707 r
F P
0 g
s
.4809 .66947 m .47561 .65121 L .48726 .65254 L p .707 .577 .707 r
F P
0 g
s
.31607 .67744 m .30464 .64111 L .32076 .63217 L p .707 .577 .707 r
F P
0 g
s
.32312 .58655 m .31452 .53076 L .3384 .52285 L p .707 .577 .707 r
F P
0 g
s
.47805 .58583 m .48948 .62217 L .46981 .62464 L p .707 .577 .707 r
F P
0 g
s
.46981 .62464 m .45838 .58831 L .47805 .58583 L p .707 .577 .707 r
F P
0 g
s
.32076 .63217 m .33219 .6685 L .31607 .67744 L p .707 .577 .707 r
F P
0 g
s
.45687 .50716 m .46547 .56294 L .4384 .56348 L p .707 .577 .707 r
F P
0 g
s
.4384 .56348 m .42979 .50769 L .45687 .50716 L p .707 .577 .707 r
F P
0 g
s
.3384 .52285 m .347 .57863 L .32312 .58655 L p .707 .577 .707 r
F P
0 g
s
.30634 .72093 m .30105 .70266 L .31721 .69384 L p .707 .577 .707 r
F P
0 g
s
.347 .57863 m .3384 .52285 L .36751 .51594 L p .707 .577 .707 r
F P
0 g
s
.31721 .69384 m .3225 .71211 L .30634 .72093 L p .707 .577 .707 r
F P
0 g
s
.47561 .65121 m .4809 .66947 L .46103 .67127 L p .707 .577 .707 r
F P
0 g
s
.46103 .67127 m .45574 .65301 L .47561 .65121 L p .707 .577 .707 r
F P
0 g
s
.42979 .50769 m .4384 .56348 L .4076 .56651 L p .707 .577 .707 r
F P
0 g
s
.4076 .56651 m .399 .51072 L .42979 .50769 L p .707 .577 .707 r
F P
0 g
s
.33219 .6685 m .32076 .63217 L .34411 .62197 L p .707 .577 .707 r
F P
0 g
s
.45838 .58831 m .46981 .62464 L .44389 .63014 L p .707 .577 .707 r
F P
0 g
s
.44389 .63014 m .43247 .59381 L .45838 .58831 L p .707 .577 .707 r
F P
0 g
s
.37611 .57173 m .36751 .51594 L .399 .51072 L p .707 .577 .707 r
F P
0 g
s
.36751 .51594 m .37611 .57173 L .347 .57863 L p .707 .577 .707 r
F P
0 g
s
.34411 .62197 m .35554 .65831 L .33219 .6685 L p .707 .577 .707 r
F P
0 g
s
.399 .51072 m .4076 .56651 L .37611 .57173 L p .707 .577 .707 r
F P
0 g
s
.3225 .71211 m .31721 .69384 L .34066 .68399 L p .707 .577 .707 r
F P
0 g
s
.35554 .65831 m .34411 .62197 L .37239 .61151 L p .707 .577 .707 r
F P
0 g
s
.34066 .68399 m .34595 .70225 L .3225 .71211 L p .707 .577 .707 r
F P
0 g
s
.43247 .59381 m .44389 .63014 L .41426 .63814 L p .707 .577 .707 r
F P
0 g
s
.41426 .63814 m .40284 .6018 L .43247 .59381 L p .707 .577 .707 r
F P
0 g
s
.45574 .65301 m .46103 .67127 L .43489 .67603 L p .707 .577 .707 r
F P
0 g
s
.43489 .67603 m .4296 .65777 L .45574 .65301 L p .707 .577 .707 r
F P
0 g
s
.37239 .61151 m .38381 .64784 L .35554 .65831 L p .707 .577 .707 r
F P
0 g
s
.38381 .64784 m .37239 .61151 L .40284 .6018 L p .707 .577 .707 r
F P
0 g
s
.40284 .6018 m .41426 .63814 L .38381 .64784 L p .707 .577 .707 r
F P
0 g
s
.34595 .70225 m .34066 .68399 L .3691 .67406 L p .707 .577 .707 r
F P
0 g
s
.4296 .65777 m .43489 .67603 L .40504 .68329 L p .707 .577 .707 r
F P
0 g
s
.40504 .68329 m .39974 .66502 L .4296 .65777 L p .707 .577 .707 r
F P
0 g
s
.3691 .67406 m .37439 .69232 L .34595 .70225 L p .707 .577 .707 r
F P
0 g
s
.37439 .69232 m .3691 .67406 L .39974 .66502 L p .707 .577 .707 r
F P
0 g
s
.39974 .66502 m .40504 .68329 L .37439 .69232 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001dOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001jOol0071oo`@000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Aoo`00KGoo0`0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`00LGoo001[Ool20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH3
001_Ool006Yoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF008006eoo`00JGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF
0P00Jgoo001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001YOol006Qoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001WOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02001U
Ool006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qo
o`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001ROol006Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00
Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001ROol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP1SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=o
o`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEWoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo00<005YF
00001UYF00<005YFFUH01UYF4P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol00`00FUH00006FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001OOol40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001KOol40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001GOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IWoo001EOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P008Goo4`00<goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000HOol90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00019oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00003FUH0
000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000ioo`@00003
FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002mo
o`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF
00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00002Woo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUH005YF02moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Ioo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_
Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol0
0`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00003Ool20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol00`00FUH00004FUH00`00FUH000030004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo
0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001DOol01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00001@000eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUIJEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH200000eYF001JEP07FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool004moo`H00004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool004Ioo`T000AJEP03001JEP0000=JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEPD000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo0010Ool60004FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?7oo100000=JEP00
FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEPD000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00Oomoo`0[Ool003Qoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUHA00000eYF001JEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90007FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000fOol200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<0
05YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YF0000;Goo000d
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
100000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH01UYF1P00
0UYF00<005YF00000P0000=JEP00Ool0;7oo000aOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF1@000UYF00<005YF00000P002EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUH00002000^Ool002moo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030003FUH01@00
FUIJEUYF00000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00H005YF000005YF0005FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH50006
FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF0`001eYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
00000`001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000[Ool00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH200000eYF001JEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000[Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`9J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUH000020005FUH20007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00
FUIJEP06FUH01000FUH0000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001J
EUYF00EJEP/0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP06FUH01000FUIJEUYF1000
00=JEP00FUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`00;7oo000/Ool00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUH00005FUH00`00FUIJEP04FUH3
0008FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP02FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF2@0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH00UYF00@005YFFUH002ao
o`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH01000FUIJEUYF10000UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF10001UYF00<005YFFUH00eYF0P00;Goo000/Ool01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP04
001JEP000005FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
0P001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<007ooOol0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH40006FUH01000FUIJEUYF10000UYF00<005YF
FUH01eYF00<005YFFUH015YF2`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF10001eYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;Goo00<005YF000015YF00<005YF00000`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF008000=JEP03001JEUYF00AJEP@0
00MJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0000000EJEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000]
Ool00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP020005FUH00`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP05FUH40003FUH20000
0eYF001JEP04FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP04FUH60002
FUH01000FUH00000<Goo000]Ool01000FUIJEP000UYF00@005YFFUH000QJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001JEP00008000AJEP03001JEUYF00MJ
EP03001JEUYF00@000EJEP8000=JEP03001JEUYF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40008FUH70003FUH00`00FUIJEP03FUH01000FUH00000<7oo000]Ool00`00FUIJEP030004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP05FUH50006FUH30006FUH00`00FUIJEP020002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEP000eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<0
05YFFUH00eYF00@005YFFUH0031oo`00;Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF1@000UYF2@002EYF00<005YFFUH01P0000=JEP00FUH00UYF100000=J
EP00FUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YF00000`001UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;goo000^Ool015YF
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP00FUH01eYF
0P000eYF00<005YFFUH01EYF100000=JEP00000020001UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00;Woo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF009JEP<000EJEP03001JEUYF00=JEP800003
FUH005YF00=JEPD00003FUH005YF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYF0003FUH00`00
FUIJEP02FUH20003FUH01000FUIJEUYF0`0015YF00<005YFFUH01UYF00<005YFFUH015YF3000;Woo
000^Ool01@00FUIJEUYF000015YF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01eYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YF00000P000eYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH01UYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP04001JEUYF0004FUH01000FUH000001EYF10001eYF00<005YF
FUH01eYF00<005YF00000`0000=oo`0000001EYF00@005YFFUH002ioo`00;Woo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP8000=JEP03001JEUYF
00AJEP<000IJEPD000MJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000D00003FUH005YF00=JEP8000IJEP800003FUH0
05YF00QJEP03001JEUYF00AJEP@0009oo`<00003FUH005YF00EJEP8002moo`00<7oo1@000eYF00<0
05YFFUH00UYF1`0025YF00<005YFFUH01EYF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP06FUH01000FUIJEUYF1@003EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00D005YFFUH005YF0080009JEP03001JEUYF
00<000=JEP03001JEUYF00MJEP03001JEUYF00@000=oo`<000EJEP03001JEUYF00=JEP03001oogoo
02ioo`00=Goo20000Woo0P0000=JEP00FUH025YF00<005YFFUH015YF00@005YFFUH000AJEP05001J
EP00001JEP070006FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP020004FUH3
0007FUH00`00FUIJEP04FUH50005Ool200000eYF001JEP05FUH01000FUIJEUYF0P00<Goo000lOol3
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF1P000eYF00<005YFFUH01eYF
00<005YFFUH015YF0`001UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P001EYF00D005YF001JEP00009JEP800003FUH005YF00MJEP03001J
EUYF00@000Moo`<000=JEP03001JEUYF00EJEP<003=oo`00>Goo0`001eYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00@000UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP<0009JEP<000=JEP03001JEUYF00EJEP@000=oo`<0009oo`<000IJEP03001JEUYF00AJ
EP8003Eoo`00=Woo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP000000
009JEP04001JEP000006FUH00`00FUIJEP02FUH20006Ool600000eYF001JEP07FUH01000FUIJEUYF
0P00=goo000dOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0`001eYF00<005YF00000P0027oo1@000UYF00<005YFFUH01UYF00@005YF000003Uoo`00<Woo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01P0000=JEP00FUH015YF00<005YFFUH0
15YF1@002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH015YF0P0000=JEP0000001Goo
20000eYF00<005YFFUH015YF0`00>goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH40004FUH01000FUIJEP001EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P000UYF0`0015YF00<005YFFUH00UYF0`000UYF0P0000=oo`0000000P0000AJEP00
FUIJEP<000AJEP03001JEUYF00@003ioo`00;goo00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF300000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP04001JEP000002FUH60006FUH00`00FUIJ
EP05FUH40012Ool002ioo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000EJ
EP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP800003FUH005YF009JEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20016
Ool002eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP06
FUH01000FUH000000Woo0UYF00<005YFFUH015YF00<005YFFUH015YF2@0000=JEP00FUH02EYF3000
1UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008004Qoo`00;Goo00@005YFFUH000EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEPP00003
FUH005YF00EJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00QJEPP000UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF
00AJEP@004]oo`00;Woo00<005YF00001EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YF
FUH01UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00=JEP@000EJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000=JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@004moo`00;Woo
00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH01UYF10001UYF00D005YFFUIJEP00
009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH400000eYF001JEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEP001UYF
00@005YFFUIJEPH005=oo`00;Woo00@005YFFUH000AJEP03001JEUYF009JEP80009JEP03001JEUYF
00MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00H005YF000005YF
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00020007FUH00`00FUIJEP02FUH00`00FUH00003FUH20002FUH01000FUIJEUYF1P000eYF0P00E7oo
000^Ool01000FUIJEP001EYF00@005YF000000EJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH00`00FUH0
000;0003FUH00`00FUIJEP03FUH00`00Oomoo`1COol002moo`03001JEP0000AJEP<000MJEP04001J
EUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP<00003FUH005YF00=JEP03001JEP0000MJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol0
02moo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH30004FUH00`00FUH00008FUH00`00FUIJEP04FUH3001HOol0
02moo`03001JEUYF008000EJEP03001JEUYF009JEP800003FUH005YF00QJEP03001JEUYF00EJEPH0
0006Ool00000FUH005YF0P003UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00@005YFFUH000=JEP<000QJEPX005Qoo`00<7oo00AJEP00FUH0
00EJEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEUYF00@000Eoo`8000AJEP<000iJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH2000015YF0000000015YF100000=JEP00FUH00eYF00<005YFFUH00P00Egoo000`Ool2
00000eYF001JEP04FUH20007FUH00`00FUIJEP06FUH40006Ool30006FUH3000>FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH300000eYF000000020005FUH00`00FUIJEP03FUH01000FUIJEP00Egoo000aOol2000015YF001J
EUYF0`0025YF00<005YFFUH00eYF10001goo0P0000=JEP00FUH01eYF0P003UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH00UYF00<005YFFUH00P00EWoo000cOol40003
FUH00`00FUIJEP06FUH00`00FUH000060004Ool30004FUH00`00FUIJEP04FUH3000=FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH005Ioo`00<Woo
0`001EYF00<005YFFUH01EYF0`000goo0`000Woo0`001eYF00<005YFFUH00UYF0P000goo0P002eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP`005Eoo`00<7oo0P0000=JEP00FUH0
1UYF00<005YFFUH010001goo100000=JEP00FUH025YF00@005YF000000Moo`03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUH000030002Ool00`00FUIJEP03FUH01000FUIJEP00
EGoo000^Ool20003FUH00`00FUIJEP04FUH40006Ool50006FUH00`00FUIJEP05FUH3000:Ool20008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP000UYF100017oo0`001UYF0P00EWoo000]Ool20005FUH01000
FUIJEUYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P003goo0P001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000`001Woo0P000eYF00<005YFFUH00eYF00<007ooOol0EGoo000/Ool01000
FUIJEP0015YF00@005YF000000Aoo`@000IJEP03001JEUYF00MJEP03001JEP00008001=oo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000Moo`<000EJEP04001JEUYFFUH2001HOol002aoo`04001JEUYF0004FUH2
0002Ool400000eYF001JEP08FUH00`00FUIJEP04FUH4000HOol300000eYF001JEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool400000eYF001JEP06FUH3001JOol002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJ
EP03001JEUYF00@001moo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH200000goo000000020005FUH00`00FUIJEP04FUH2001LOol002eo
o`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@002Ioo`@000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000@00003FUH005YF
00MJEP04001JEUYFFUH2001NOol002eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04
000^Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH80002
FUH00`00FUIJEP06FUH01000FUH00000H7oo000^Ool015YF001JEP001EYF00<005YFFUH015YF1000
=Woo1`001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH03@000UYF00<005YFFUH01EYF
0`00HWoo000^Ool01000FUIJEP001EYF00<005YFFUH01000@Goo3@001UYF00<005YFFUH015YF2000
00=oo`0000000P0000=JEP00FUH01@000eYF00<005YFFUH00UYF0P00IGoo000^Ool<001BOol>0002
Ool60006FUH00`00FUH000020004FUH00`00FUH00002001WOol008ioo`04001JEUYF0003FUH70003
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001ZOol008ioo`05001JEUYF001JEP020002FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001]Ool008moo`04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH5001aOol008moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00@007Ioo`00Sgoo00@005YFFUH000EJEP03001JEUYF00AJEP@007Yoo`00Sgoo0P000UYF00<0
05YFFUH00eYF00<005YF00000`00OWoo002@Ool;0022Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5991 .74892 m .59049 .69313 L .5597 .69616 L p .707 .577 .707 r
F P
0 g
s
.59049 .69313 m .5991 .74892 L .63059 .7437 L p .707 .577 .707 r
F P
0 g
s
.63059 .7437 m .62199 .68791 L .59049 .69313 L p .707 .577 .707 r
F P
0 g
s
.62199 .68791 m .63059 .7437 L .6597 .73679 L p .707 .577 .707 r
F P
0 g
s
.6597 .73679 m .6511 .68101 L .62199 .68791 L p .707 .577 .707 r
F P
0 g
s
.56831 .75195 m .5597 .69616 L .53263 .6967 L p .707 .577 .707 r
F P
0 g
s
.5597 .69616 m .56831 .75195 L .5991 .74892 L p .707 .577 .707 r
F P
0 g
s
.6511 .68101 m .6597 .73679 L .68358 .72888 L p .707 .577 .707 r
F P
0 g
s
.68358 .72888 m .67497 .67309 L .6511 .68101 L p .707 .577 .707 r
F P
0 g
s
.60344 .79796 m .59201 .76163 L .56238 .76963 L p .707 .577 .707 r
F P
0 g
s
.59201 .76163 m .60344 .79796 L .63388 .78826 L p .707 .577 .707 r
F P
0 g
s
.63388 .78826 m .62246 .75193 L .59201 .76163 L p .707 .577 .707 r
F P
0 g
s
.62246 .75193 m .63388 .78826 L .66216 .7778 L p .707 .577 .707 r
F P
0 g
s
.66216 .7778 m .65074 .74146 L .62246 .75193 L p .707 .577 .707 r
F P
0 g
s
.53263 .6967 m .54123 .75248 L .56831 .75195 L p .707 .577 .707 r
F P
0 g
s
.56238 .76963 m .57381 .80596 L .60344 .79796 L p .707 .577 .707 r
F P
0 g
s
.54123 .75248 m .53263 .6967 L .51191 .69469 L p .707 .577 .707 r
F P
0 g
s
.57381 .80596 m .56238 .76963 L .53646 .77513 L p .707 .577 .707 r
F P
0 g
s
.65074 .74146 m .66216 .7778 L .68551 .7676 L p .707 .577 .707 r
F P
0 g
s
.68551 .7676 m .67408 .73127 L .65074 .74146 L p .707 .577 .707 r
F P
0 g
s
.67497 .67309 m .68358 .72888 L .69989 .72073 L p .707 .577 .707 r
F P
0 g
s
.69989 .72073 m .69128 .66494 L .67497 .67309 L p .707 .577 .707 r
F P
0 g
s
.53646 .77513 m .54789 .81146 L .57381 .80596 L p .707 .577 .707 r
F P
0 g
s
.59466 .83567 m .58937 .81741 L .55951 .82466 L p .707 .577 .707 r
F P
0 g
s
.58937 .81741 m .59466 .83567 L .62531 .82664 L p .707 .577 .707 r
F P
0 g
s
.62531 .82664 m .62002 .80837 L .58937 .81741 L p .707 .577 .707 r
F P
0 g
s
.62002 .80837 m .62531 .82664 L .65375 .81671 L p .707 .577 .707 r
F P
0 g
s
.65375 .81671 m .64846 .79844 L .62002 .80837 L p .707 .577 .707 r
F P
0 g
s
.51191 .69469 m .52052 .75047 L .54123 .75248 L p .707 .577 .707 r
F P
0 g
s
.55951 .82466 m .5648 .84292 L .59466 .83567 L p .707 .577 .707 r
F P
0 g
s
.5648 .84292 m .55951 .82466 L .53337 .82942 L p .707 .577 .707 r
F P
0 g
s
.54789 .81146 m .53646 .77513 L .5168 .7776 L p .707 .577 .707 r
F P
0 g
s
.64846 .79844 m .65375 .81671 L .6772 .80685 L p .707 .577 .707 r
F P
0 g
s
.6772 .80685 m .67191 .78859 L .64846 .79844 L p .707 .577 .707 r
F P
0 g
s
.53337 .82942 m .53866 .84768 L .5648 .84292 L p .707 .577 .707 r
F P
0 g
s
.67408 .73127 m .68551 .7676 L .70163 .75866 L p .707 .577 .707 r
F P
0 g
s
.70163 .75866 m .69021 .72233 L .67408 .73127 L p .707 .577 .707 r
F P
0 g
s
.52052 .75047 m .51191 .69469 L .49959 .69033 L p .707 .577 .707 r
F P
0 g
s
.5168 .7776 m .52822 .81394 L .54789 .81146 L p .707 .577 .707 r
F P
0 g
s
.69128 .66494 m .69989 .72073 L .70703 .71314 L p .707 .577 .707 r
F P
0 g
s
.70703 .71314 m .69843 .65736 L .69128 .66494 L p .707 .577 .707 r
F P
0 g
s
.49959 .69033 m .5082 .74611 L .52052 .75047 L p .707 .577 .707 r
F P
0 g
s
.53866 .84768 m .53337 .82942 L .5135 .83122 L p .707 .577 .707 r
F P
0 g
s
.5135 .83122 m .51879 .84949 L .53866 .84768 L p .707 .577 .707 r
F P
0 g
s
.67191 .78859 m .6772 .80685 L .69336 .79803 L p .707 .577 .707 r
F P
0 g
s
.69336 .79803 m .68807 .77977 L .67191 .78859 L p .707 .577 .707 r
F P
0 g
s
.52822 .81394 m .5168 .7776 L .50531 .7768 L p .707 .577 .707 r
F P
0 g
s
.69021 .72233 m .70163 .75866 L .70896 .75187 L p .707 .577 .707 r
F P
0 g
s
.70896 .75187 m .69753 .71553 L .69021 .72233 L p .707 .577 .707 r
F P
0 g
s
.50531 .7768 m .51673 .81314 L .52822 .81394 L p .707 .577 .707 r
F P
0 g
s
.5082 .74611 m .49959 .69033 L .49687 .68405 L p .707 .577 .707 r
F P
0 g
s
.51879 .84949 m .5135 .83122 L .50185 .82989 L p .707 .577 .707 r
F P
0 g
s
.69843 .65736 m .70703 .71314 L .70431 .70687 L p .707 .577 .707 r
F P
0 g
s
.70431 .70687 m .6957 .65108 L .69843 .65736 L p .707 .577 .707 r
F P
0 g
s
.50185 .82989 m .50714 .84816 L .51879 .84949 L p .707 .577 .707 r
F P
0 g
s
.49687 .68405 m .50548 .73984 L .5082 .74611 L p .707 .577 .707 r
F P
0 g
s
.68807 .77977 m .69336 .79803 L .70065 .79112 L p .707 .577 .707 r
F P
0 g
s
.70065 .79112 m .69536 .77285 L .68807 .77977 L p .707 .577 .707 r
F P
0 g
s
.47109 .82196 m .50148 .32433 L .45756 .31896 L p .707 .577 .707 r
F P
0 g
s
.51673 .81314 m .50531 .7768 L .50312 .77281 L p .707 .577 .707 r
F P
0 g
s
.50312 .77281 m .51454 .80914 L .51673 .81314 L p .707 .577 .707 r
F P
0 g
s
.50548 .73984 m .49687 .68405 L .50401 .67647 L p .707 .577 .707 r
F P
0 g
s
.50401 .67647 m .51262 .73225 L .50548 .73984 L p .707 .577 .707 r
F P
0 g
s
.51454 .80914 m .50312 .77281 L .51045 .76601 L p .707 .577 .707 r
F P
0 g
s
.51045 .76601 m .52187 .80235 L .51454 .80914 L p .707 .577 .707 r
F P
0 g
s
.51262 .73225 m .50401 .67647 L .52032 .66832 L p .707 .577 .707 r
F P
0 g
s
.50714 .84816 m .50185 .82989 L .49956 .82556 L p .707 .577 .707 r
F P
0 g
s
.49956 .82556 m .50485 .84382 L .50714 .84816 L p .707 .577 .707 r
F P
0 g
s
.50485 .84382 m .49956 .82556 L .50685 .81864 L p .707 .577 .707 r
F P
0 g
s
.50685 .81864 m .51214 .83691 L .50485 .84382 L p .707 .577 .707 r
F P
0 g
s
.52032 .66832 m .52893 .72411 L .51262 .73225 L p .707 .577 .707 r
F P
0 g
s
.52187 .80235 m .51045 .76601 L .52657 .75708 L p .707 .577 .707 r
F P
0 g
s
.51214 .83691 m .50685 .81864 L .52301 .80983 L p .707 .577 .707 r
F P
0 g
s
.50148 .32433 m .47109 .82196 L .51596 .82329 L p .707 .577 .707 r
F P
0 g
s
.52893 .72411 m .52032 .66832 L .5442 .66041 L p .707 .577 .707 r
F P
0 g
s
.51596 .82329 m .54635 .32566 L .50148 .32433 L p .707 .577 .707 r
F P
0 g
s
.52657 .75708 m .538 .79341 L .52187 .80235 L p .707 .577 .707 r
F P
0 g
s
.5442 .66041 m .55281 .71619 L .52893 .72411 L p .707 .577 .707 r
F P
0 g
s
.52301 .80983 m .52831 .82809 L .51214 .83691 L p .707 .577 .707 r
F P
0 g
s
.55281 .71619 m .5442 .66041 L .57331 .6535 L p .707 .577 .707 r
F P
0 g
s
.538 .79341 m .52657 .75708 L .54992 .74688 L p .707 .577 .707 r
F P
0 g
s
.54992 .74688 m .56134 .78321 L .538 .79341 L p .707 .577 .707 r
F P
0 g
s
.57331 .6535 m .58192 .70928 L .55281 .71619 L p .707 .577 .707 r
F P
0 g
s
.52831 .82809 m .52301 .80983 L .54646 .79997 L p .707 .577 .707 r
F P
0 g
s
.54646 .79997 m .55175 .81823 L .52831 .82809 L p .707 .577 .707 r
F P
0 g
s
.56134 .78321 m .54992 .74688 L .5782 .73642 L p .707 .577 .707 r
F P
0 g
s
.55175 .81823 m .54646 .79997 L .5749 .79004 L p .707 .577 .707 r
F P
0 g
s
.5749 .79004 m .58019 .8083 L .55175 .81823 L p .707 .577 .707 r
F P
0 g
s
.54635 .32566 m .51596 .82329 L .55738 .82045 L p .707 .577 .707 r
F P
0 g
s
.55738 .82045 m .58778 .32281 L .54635 .32566 L p .707 .577 .707 r
F P
0 g
s
.42716 .81659 m .45756 .31896 L .41887 .31007 L p .707 .577 .707 r
F P
0 g
s
.45756 .31896 m .42716 .81659 L .47109 .82196 L p .707 .577 .707 r
F P
0 g
s
.69753 .71553 m .70896 .75187 L .70677 .74787 L p .707 .577 .707 r
F P
0 g
s
.70677 .74787 m .69535 .71154 L .69753 .71553 L p .707 .577 .707 r
F P
0 g
s
.58192 .70928 m .57331 .6535 L .6048 .64828 L p .707 .577 .707 r
F P
0 g
s
.6048 .64828 m .61341 .70406 L .58192 .70928 L p .707 .577 .707 r
F P
0 g
s
.5782 .73642 m .58962 .77275 L .56134 .78321 L p .707 .577 .707 r
F P
0 g
s
.58962 .77275 m .5782 .73642 L .60864 .72671 L p .707 .577 .707 r
F P
0 g
s
.60864 .72671 m .62007 .76305 L .58962 .77275 L p .707 .577 .707 r
F P
0 g
s
.58019 .8083 m .5749 .79004 L .60555 .781 L p .707 .577 .707 r
F P
0 g
s
.60555 .781 m .61084 .79927 L .58019 .8083 L p .707 .577 .707 r
F P
0 g
s
.58778 .32281 m .55738 .82045 L .5913 .81371 L p .707 .577 .707 r
F P
0 g
s
.5913 .81371 m .6217 .31607 L .58778 .32281 L p .707 .577 .707 r
F P
0 g
s
.6957 .65108 m .70431 .70687 L .69199 .70251 L p .707 .577 .707 r
F P
0 g
s
.69199 .70251 m .68338 .64673 L .6957 .65108 L p .707 .577 .707 r
F P
0 g
s
.69536 .77285 m .70065 .79112 L .69836 .78678 L p .707 .577 .707 r
F P
0 g
s
.69836 .78678 m .69307 .76852 L .69536 .77285 L p .707 .577 .707 r
F P
0 g
s
.38848 .8077 m .41887 .31007 L .38922 .29853 L p .707 .577 .707 r
F P
0 g
s
.41887 .31007 m .38848 .8077 L .42716 .81659 L p .707 .577 .707 r
F P
0 g
s
.25609 .7034 m .24749 .64762 L .21669 .65064 L p .707 .577 .707 r
F P
0 g
s
.24749 .64762 m .25609 .7034 L .28758 .69818 L p .707 .577 .707 r
F P
0 g
s
.28758 .69818 m .27898 .6424 L .24749 .64762 L p .707 .577 .707 r
F P
0 g
s
.27898 .6424 m .28758 .69818 L .31669 .69127 L p .707 .577 .707 r
F P
0 g
s
.31669 .69127 m .30809 .63549 L .27898 .6424 L p .707 .577 .707 r
F P
0 g
s
.69535 .71154 m .70677 .74787 L .69528 .74707 L p .707 .577 .707 r
F P
0 g
s
.69528 .74707 m .68386 .71074 L .69535 .71154 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2253 .70643 m .21669 .65064 L .18962 .65118 L p .707 .577 .707 r
F P
0 g
s
.21669 .65064 m .2253 .70643 L .25609 .7034 L p .707 .577 .707 r
F P
0 g
s
.30809 .63549 m .31669 .69127 L .34057 .68336 L p .707 .577 .707 r
F P
0 g
s
.34057 .68336 m .33196 .62757 L .30809 .63549 L p .707 .577 .707 r
F P
0 g
s
.63559 .64525 m .6442 .70104 L .61341 .70406 L p .707 .577 .707 r
F P
0 g
s
.61341 .70406 m .6048 .64828 L .63559 .64525 L p .707 .577 .707 r
F P
0 g
s
.62007 .76305 m .60864 .72671 L .63827 .71872 L p .707 .577 .707 r
F P
0 g
s
.63541 .77375 m .6407 .79201 L .61084 .79927 L p .707 .577 .707 r
F P
0 g
s
.61084 .79927 m .60555 .781 L .63541 .77375 L p .707 .577 .707 r
F P
0 g
s
.6217 .31607 m .5913 .81371 L .6144 .80373 L p .707 .577 .707 r
F P
0 g
s
.6144 .80373 m .64479 .3061 L .6217 .31607 L p .707 .577 .707 r
F P
0 g
s
.68338 .64673 m .69199 .70251 L .67128 .7005 L p .707 .577 .707 r
F P
0 g
s
.67128 .7005 m .66267 .64472 L .68338 .64673 L p .707 .577 .707 r
F P
0 g
s
.18962 .65118 m .19822 .70696 L .2253 .70643 L p .707 .577 .707 r
F P
0 g
s
.26043 .7651 m .249 .72876 L .21937 .73676 L p .707 .577 .707 r
F P
0 g
s
.249 .72876 m .26043 .7651 L .29087 .75539 L p .707 .577 .707 r
F P
0 g
s
.29087 .75539 m .27945 .71906 L .249 .72876 L p .707 .577 .707 r
F P
0 g
s
.27945 .71906 m .29087 .75539 L .31915 .74493 L p .707 .577 .707 r
F P
0 g
s
.31915 .74493 m .30773 .7086 L .27945 .71906 L p .707 .577 .707 r
F P
0 g
s
.69307 .76852 m .69836 .78678 L .68671 .78545 L p .707 .577 .707 r
F P
0 g
s
.68671 .78545 m .68142 .76719 L .69307 .76852 L p .707 .577 .707 r
F P
0 g
s
.19822 .70696 m .18962 .65118 L .1689 .64917 L p .707 .577 .707 r
F P
0 g
s
.21937 .73676 m .2308 .77309 L .26043 .7651 L p .707 .577 .707 r
F P
0 g
s
.34827 .61943 m .35688 .67521 L .35886 .67311 L p .707 .577 .707 r
F P
0 g
s
.35886 .67311 m .36402 .66763 L p .35871 .65137 L .707 .577 .707 r
F P
0 g
s
.35871 .65137 m .34827 .61943 L .35886 .67311 L .707 .577 .707 r
F
.3715 .28547 m .36745 .27218 L p .35747 .46585 L F P
0 g
s
.33196 .62757 m .34057 .68336 L .35688 .67521 L p .707 .577 .707 r
F P
0 g
s
.35688 .67521 m .34827 .61943 L .33196 .62757 L p .707 .577 .707 r
F P
0 g
s
.33107 .6984 m .3425 .73473 L .35862 .7258 L p .707 .577 .707 r
F P
0 g
s
.35862 .7258 m .3472 .68946 L .33107 .6984 L p .707 .577 .707 r
F P
0 g
s
.36402 .66763 m .35542 .61184 L .34827 .61943 L p .707 .577 .707 r
F P
0 g
s
.3289 .76464 m .33419 .78291 L .35035 .77409 L p .707 .577 .707 r
F P
0 g
s
.35035 .77409 m .34506 .75583 L .3289 .76464 L p .707 .577 .707 r
F P
0 g
s
.34898 .65699 m .34038 .60121 L .35269 .60556 L p .707 .577 .707 r
F P
0 g
s
.3472 .68946 m .35862 .7258 L .36595 .719 L p .707 .577 .707 r
F P
0 g
s
.36595 .719 m .35452 .68266 L .3472 .68946 L p .707 .577 .707 r
F P
0 g
s
.35227 .71421 m .3482 .70124 L p .35234 .67867 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .34085 .67787 L .3523 .67867 L p .707 .577 .707 r
F P
0 g
s
.3523 .67867 m .35234 .67867 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.34038 .60121 m .34898 .65699 L .32827 .65498 L p .707 .577 .707 r
F P
0 g
s
.3425 .73473 m .33107 .6984 L .30773 .7086 L p .707 .577 .707 r
F P
0 g
s
.34085 .67787 m .3482 .70124 L p .33261 .71668 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .35227 .71421 L .34688 .71488 L p .707 .577 .707 r
F P
0 g
s
.34688 .71488 m .33261 .71668 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.30773 .7086 m .31915 .74493 L .3425 .73473 L p .707 .577 .707 r
F P
0 g
s
.34506 .75583 m .35035 .77409 L .35764 .76717 L p .707 .577 .707 r
F P
0 g
s
.35764 .76717 m .35235 .74891 L .34506 .75583 L p .707 .577 .707 r
F P
0 g
s
.3437 .76151 m .33841 .74324 L .35006 .74458 L p .707 .577 .707 r
F P
0 g
s
.33841 .74324 m .3437 .76151 L .32383 .76331 L p .707 .577 .707 r
F P
0 g
s
.36745 .27218 m .33706 .76981 L .3405 .78112 L p .707 .577 .707 r
F P
0 g
s
.3405 .78112 m .34111 .78311 L p .34203 .76528 L .707 .577 .707 r
F P
0 g
s
.34203 .76528 m .36745 .27218 L .3405 .78112 L .707 .577 .707 r
F
.34419 .72326 m .35776 .5104 L .35747 .46585 L F
.34111 .78311 m .34505 .71855 L p .34419 .72326 L F P
0 g
s
.34505 .71855 m .35776 .5104 L p .34419 .72326 L .707 .577 .707 r
F P
0 g
s
.35776 .5104 m .3715 .28547 L p .35747 .46585 L .707 .577 .707 r
F P
0 g
s
.35542 .61184 m .36402 .66763 L .3613 .66135 L p .707 .577 .707 r
F P
0 g
s
.35452 .68266 m .36595 .719 L .36376 .715 L p .707 .577 .707 r
F P
0 g
s
.36376 .715 m .35234 .67867 L .35452 .68266 L p .707 .577 .707 r
F P
0 g
s
.35234 .67867 m .36376 .715 L .35227 .71421 L p .707 .577 .707 r
F P
0 g
s
.35883 .79616 m .38922 .29853 L .3715 .28547 L p .707 .577 .707 r
F P
0 g
s
.38922 .29853 m .35883 .79616 L .38848 .8077 L p .707 .577 .707 r
F P
0 g
s
.2308 .77309 m .21937 .73676 L .19345 .74226 L p .707 .577 .707 r
F P
0 g
s
.19345 .74226 m .20488 .7786 L .2308 .77309 L p .707 .577 .707 r
F P
0 g
s
.1689 .64917 m .17751 .70495 L .19822 .70696 L p .707 .577 .707 r
F P
0 g
s
.68386 .71074 m .69528 .74707 L .67562 .74955 L p .707 .577 .707 r
F P
0 g
s
.67562 .74955 m .66419 .71321 L .68386 .71074 L p .707 .577 .707 r
F P
0 g
s
.25165 .81173 m .24636 .79347 L .21651 .80072 L p .707 .577 .707 r
F P
0 g
s
.24636 .79347 m .25165 .81173 L .2823 .8027 L p .707 .577 .707 r
F P
0 g
s
.2823 .8027 m .27701 .78443 L .24636 .79347 L p .707 .577 .707 r
F P
0 g
s
.27701 .78443 m .2823 .8027 L .31074 .79276 L p .707 .577 .707 r
F P
0 g
s
.31074 .79276 m .30545 .7745 L .27701 .78443 L p .707 .577 .707 r
F P
0 g
s
.21651 .80072 m .2218 .81898 L .25165 .81173 L p .707 .577 .707 r
F P
0 g
s
.66267 .64472 m .67128 .7005 L .6442 .70104 L p .707 .577 .707 r
F P
0 g
s
.6442 .70104 m .63559 .64525 L .66267 .64472 L p .707 .577 .707 r
F P
0 g
s
.20488 .7786 m .19345 .74226 L .17379 .74473 L p .707 .577 .707 r
F P
0 g
s
.17751 .70495 m .1689 .64917 L .15658 .64481 L p .707 .577 .707 r
F P
0 g
s
.2218 .81898 m .21651 .80072 L .19036 .80548 L p .707 .577 .707 r
F P
0 g
s
.30545 .7745 m .31074 .79276 L .33419 .78291 L p .707 .577 .707 r
F P
0 g
s
.33419 .78291 m .3289 .76464 L .30545 .7745 L p .707 .577 .707 r
F P
0 g
s
.19036 .80548 m .19565 .82374 L .2218 .81898 L p .707 .577 .707 r
F P
0 g
s
.17379 .74473 m .18521 .78107 L .20488 .7786 L p .707 .577 .707 r
F P
0 g
s
.68142 .76719 m .68671 .78545 L .66684 .78725 L p .707 .577 .707 r
F P
0 g
s
.66684 .78725 m .66155 .76899 L .68142 .76719 L p .707 .577 .707 r
F P
0 g
s
.63827 .71872 m .6497 .75505 L .62007 .76305 L p .707 .577 .707 r
F P
0 g
s
.64479 .3061 m .6144 .80373 L .62441 .7915 L p .707 .577 .707 r
F P
0 g
s
.62441 .7915 m .6548 .29386 L .64479 .3061 L p .707 .577 .707 r
F P
0 g
s
.15658 .64481 m .16519 .7006 L .17751 .70495 L p .707 .577 .707 r
F P
0 g
s
.66419 .71321 m .67562 .74955 L .6497 .75505 L p .707 .577 .707 r
F P
0 g
s
.6497 .75505 m .63827 .71872 L .66419 .71321 L p .707 .577 .707 r
F P
0 g
s
.19565 .82374 m .19036 .80548 L .1705 .80728 L p .707 .577 .707 r
F P
0 g
s
.3613 .66135 m .35269 .60556 L .35542 .61184 L p .707 .577 .707 r
F P
0 g
s
.35269 .60556 m .3613 .66135 L .34898 .65699 L p .707 .577 .707 r
F P
0 g
s
.35235 .74891 m .35764 .76717 L .35535 .76284 L p .707 .577 .707 r
F P
0 g
s
.35535 .76284 m .35006 .74458 L .35235 .74891 L p .707 .577 .707 r
F P
0 g
s
.35006 .74458 m .35535 .76284 L .3437 .76151 L p .707 .577 .707 r
F P
0 g
s
.3715 .28547 m .34111 .78311 L .35883 .79616 L p .707 .577 .707 r
F P
0 g
s
.1705 .80728 m .17579 .82554 L .19565 .82374 L p .707 .577 .707 r
F P
0 g
s
.18521 .78107 m .17379 .74473 L .1623 .74394 L p .707 .577 .707 r
F P
0 g
s
.16519 .7006 m .15658 .64481 L .15386 .63854 L p .707 .577 .707 r
F P
0 g
s
.66155 .76899 m .66684 .78725 L .6407 .79201 L p .707 .577 .707 r
F P
0 g
s
.6407 .79201 m .63541 .77375 L .66155 .76899 L p .707 .577 .707 r
F P
0 g
s
.1623 .74394 m .17372 .78027 L .18521 .78107 L p .707 .577 .707 r
F P
0 g
s
.15386 .63854 m .16247 .69432 L .16519 .7006 L p .707 .577 .707 r
F P
0 g
s
.17579 .82554 m .1705 .80728 L .15884 .80595 L p .707 .577 .707 r
F P
0 g
s
.15884 .80595 m .16414 .82421 L .17579 .82554 L p .707 .577 .707 r
F P
0 g
s
.6548 .29386 m .62441 .7915 L .62036 .7782 L p .707 .577 .707 r
F P
0 g
s
.62036 .7782 m .65075 .28057 L .6548 .29386 L p .707 .577 .707 r
F P
0 g
s
.17372 .78027 m .1623 .74394 L .16011 .73994 L p .707 .577 .707 r
F P
0 g
s
.16011 .73994 m .17154 .77628 L .17372 .78027 L p .707 .577 .707 r
F P
0 g
s
.16247 .69432 m .15386 .63854 L .16101 .63095 L p .707 .577 .707 r
F P
0 g
s
.33706 .76981 m .36745 .27218 L .37746 .25994 L p .707 .577 .707 r
F P
0 g
s
.16101 .63095 m .16961 .68674 L .16247 .69432 L p .707 .577 .707 r
F P
0 g
s
.16414 .82421 m .15884 .80595 L .15655 .80161 L p .707 .577 .707 r
F P
0 g
s
.15655 .80161 m .16184 .81988 L .16414 .82421 L p .707 .577 .707 r
F P
0 g
s
.17154 .77628 m .16011 .73994 L .16744 .73314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16961 .68674 m .16101 .63095 L .17731 .6228 L p .707 .577 .707 r
F P
0 g
s
.65075 .28057 m .62036 .7782 L .60264 .76515 L p .707 .577 .707 r
F P
0 g
s
.60264 .76515 m .63303 .26751 L .65075 .28057 L p .707 .577 .707 r
F P
0 g
s
.16744 .73314 m .17886 .76948 L .17154 .77628 L p .707 .577 .707 r
F P
0 g
s
.32827 .65498 m .31966 .5992 L .34038 .60121 L p .707 .577 .707 r
F P
0 g
s
.17731 .6228 m .18592 .67859 L .16961 .68674 L p .707 .577 .707 r
F P
0 g
s
.34707 .75758 m .37746 .25994 L .40056 .24997 L p .707 .577 .707 r
F P
0 g
s
.37746 .25994 m .34707 .75758 L .33706 .76981 L p .707 .577 .707 r
F P
0 g
s
.16184 .81988 m .15655 .80161 L .16384 .7947 L p .707 .577 .707 r
F P
0 g
s
.16384 .7947 m .16914 .81296 L .16184 .81988 L p .707 .577 .707 r
F P
0 g
s
.17886 .76948 m .16744 .73314 L .18356 .72421 L p .707 .577 .707 r
F P
0 g
s
.18592 .67859 m .17731 .6228 L .20119 .61489 L p .707 .577 .707 r
F P
0 g
s
.33261 .71668 m .32118 .68034 L .34085 .67787 L p .707 .577 .707 r
F P
0 g
s
.18356 .72421 m .19499 .76054 L .17886 .76948 L p .707 .577 .707 r
F P
0 g
s
.31966 .5992 m .32827 .65498 L .30119 .65552 L p .707 .577 .707 r
F P
0 g
s
.30119 .65552 m .29259 .59973 L .31966 .5992 L p .707 .577 .707 r
F P
0 g
s
.20119 .61489 m .2098 .67067 L .18592 .67859 L p .707 .577 .707 r
F P
0 g
s
.63303 .26751 m .60264 .76515 L .57299 .75361 L p .707 .577 .707 r
F P
0 g
s
.57299 .75361 m .60338 .25597 L .63303 .26751 L p .707 .577 .707 r
F P
0 g
s
.16914 .81296 m .16384 .7947 L .18001 .78588 L p .707 .577 .707 r
F P
0 g
s
.2098 .67067 m .20119 .61489 L .2303 .60798 L p .707 .577 .707 r
F P
0 g
s
.18001 .78588 m .1853 .80415 L .16914 .81296 L p .707 .577 .707 r
F P
0 g
s
.32383 .76331 m .31854 .74505 L .33841 .74324 L p .707 .577 .707 r
F P
0 g
s
.40056 .24997 m .37016 .7476 L .34707 .75758 L p .707 .577 .707 r
F P
0 g
s
.37016 .7476 m .40056 .24997 L .43448 .24323 L p .707 .577 .707 r
F P
0 g
s
.29259 .59973 m .30119 .65552 L .2704 .65854 L p .707 .577 .707 r
F P
0 g
s
.2704 .65854 m .26179 .60276 L .29259 .59973 L p .707 .577 .707 r
F P
0 g
s
.19499 .76054 m .18356 .72421 L .20691 .71401 L p .707 .577 .707 r
F P
0 g
s
.32118 .68034 m .33261 .71668 L .30669 .72218 L p .707 .577 .707 r
F P
0 g
s
.30669 .72218 m .29526 .68585 L .32118 .68034 L p .707 .577 .707 r
F P
0 g
s
.23891 .66377 m .2303 .60798 L .26179 .60276 L p .707 .577 .707 r
F P
0 g
s
.2303 .60798 m .23891 .66377 L .2098 .67067 L p .707 .577 .707 r
F P
0 g
s
.20691 .71401 m .21833 .75034 L .19499 .76054 L p .707 .577 .707 r
F P
0 g
s
.26179 .60276 m .2704 .65854 L .23891 .66377 L p .707 .577 .707 r
F P
0 g
s
.7363 .65688 m .7277 .6011 L .69691 .60412 L p .707 .577 .707 r
F P
0 g
s
.7277 .6011 m .7363 .65688 L .7678 .65166 L p .707 .577 .707 r
F P
0 g
s
.7678 .65166 m .75919 .59587 L .7277 .6011 L p .707 .577 .707 r
F P
0 g
s
.75919 .59587 m .7678 .65166 L .79691 .64475 L p .707 .577 .707 r
F P
0 g
s
.79691 .64475 m .7883 .58897 L .75919 .59587 L p .707 .577 .707 r
F P
0 g
s
.70551 .65991 m .69691 .60412 L .66983 .60466 L p .707 .577 .707 r
F P
0 g
s
.69691 .60412 m .70551 .65991 L .7363 .65688 L p .707 .577 .707 r
F P
0 g
s
.1853 .80415 m .18001 .78588 L .20345 .77603 L p .707 .577 .707 r
F P
0 g
s
.21833 .75034 m .20691 .71401 L .23519 .70355 L p .707 .577 .707 r
F P
0 g
s
.60338 .25597 m .57299 .75361 L .5343 .74472 L p .707 .577 .707 r
F P
0 g
s
.5343 .74472 m .5647 .24708 L .60338 .25597 L p .707 .577 .707 r
F P
0 g
s
.20345 .77603 m .20874 .79429 L .1853 .80415 L p .707 .577 .707 r
F P
0 g
s
.7883 .58897 m .79691 .64475 L .82078 .63684 L p .707 .577 .707 r
F P
0 g
s
.82078 .63684 m .81218 .58105 L .7883 .58897 L p .707 .577 .707 r
F P
0 g
s
.29526 .68585 m .30669 .72218 L .27706 .73018 L p .707 .577 .707 r
F P
0 g
s
.27706 .73018 m .26563 .69384 L .29526 .68585 L p .707 .577 .707 r
F P
0 g
s
.31854 .74505 m .32383 .76331 L .29769 .76807 L p .707 .577 .707 r
F P
0 g
s
.29769 .76807 m .2924 .74981 L .31854 .74505 L p .707 .577 .707 r
F P
0 g
s
.23519 .70355 m .24661 .73988 L .21833 .75034 L p .707 .577 .707 r
F P
0 g
s
.74064 .70593 m .72922 .66959 L .69958 .67759 L p .707 .577 .707 r
F P
0 g
s
.72922 .66959 m .74064 .70593 L .77109 .69622 L p .707 .577 .707 r
F P
0 g
s
.77109 .69622 m .75966 .65989 L .72922 .66959 L p .707 .577 .707 r
F P
0 g
s
.40408 .74086 m .43448 .24323 L .4759 .24038 L p .707 .577 .707 r
F P
0 g
s
.43448 .24323 m .40547 .71822 L p .37016 .7476 L .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .44551 .73802 L .40408 .74086 L p .707 .577 .707 r
F P
0 g
s
.38621 .63672 m .39763 .67306 L .41973 .66601 L p .707 .577 .707 r
F P
0 g
s
.41973 .66601 m .42808 .66335 L p .42159 .65923 L .707 .577 .707 r
F P
0 g
s
.42159 .65923 m .38621 .63672 L .41973 .66601 L .707 .577 .707 r
F
.40547 .71822 m .40408 .74086 L .399 .74187 L p F P
0 g
s
.399 .74187 m .37016 .7476 L p .40547 .71822 L .707 .577 .707 r
F P
0 g
s
.75966 .65989 m .77109 .69622 L .79937 .68576 L p .707 .577 .707 r
F P
0 g
s
.79937 .68576 m .78794 .64943 L .75966 .65989 L p .707 .577 .707 r
F P
0 g
s
.66983 .60466 m .67844 .66044 L .70551 .65991 L p .707 .577 .707 r
F P
0 g
s
.24661 .73988 m .23519 .70355 L .26563 .69384 L p .707 .577 .707 r
F P
0 g
s
.26563 .69384 m .27706 .73018 L .24661 .73988 L p .707 .577 .707 r
F P
0 g
s
.69958 .67759 m .71101 .71392 L .74064 .70593 L p .707 .577 .707 r
F P
0 g
s
.67844 .66044 m .66983 .60466 L .64912 .60265 L p .707 .577 .707 r
F P
0 g
s
.71101 .71392 m .69958 .67759 L .67367 .68309 L p .707 .577 .707 r
F P
0 g
s
.20874 .79429 m .20345 .77603 L .23189 .76609 L p .707 .577 .707 r
F P
0 g
s
.78794 .64943 m .79937 .68576 L .82271 .67556 L p .707 .577 .707 r
F P
0 g
s
.82271 .67556 m .81129 .63923 L .78794 .64943 L p .707 .577 .707 r
F P
0 g
s
.2924 .74981 m .29769 .76807 L .26783 .77532 L p .707 .577 .707 r
F P
0 g
s
.26783 .77532 m .26254 .75706 L .2924 .74981 L p .707 .577 .707 r
F P
0 g
s
.23189 .76609 m .23718 .78436 L .20874 .79429 L p .707 .577 .707 r
F P
0 g
s
.5647 .24708 m .5343 .74472 L .49038 .73935 L p .707 .577 .707 r
F P
0 g
s
.49038 .73935 m .52077 .24171 L .5647 .24708 L p .707 .577 .707 r
F P
0 g
s
.81218 .58105 m .82078 .63684 L .83709 .62869 L p .707 .577 .707 r
F P
0 g
s
.83709 .62869 m .82849 .57291 L .81218 .58105 L p .707 .577 .707 r
F P
0 g
s
.67367 .68309 m .68509 .71943 L .71101 .71392 L p .707 .577 .707 r
F P
0 g
s
.73187 .74363 m .72657 .72537 L .69672 .73262 L p .707 .577 .707 r
F P
0 g
s
.72657 .72537 m .73187 .74363 L .76251 .7346 L p .707 .577 .707 r
F P
0 g
s
.76251 .7346 m .75722 .71634 L .72657 .72537 L p .707 .577 .707 r
F P
0 g
s
.75722 .71634 m .76251 .7346 L .79095 .72467 L p .707 .577 .707 r
F P
0 g
s
.79095 .72467 m .78566 .7064 L .75722 .71634 L p .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .52077 .24171 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.44982 .66746 m .4759 .24038 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.41665 .62702 m .41959 .63637 L p .45636 .65289 L .707 .577 .707 r
F P
0 g
s
.41959 .63637 m .42808 .66335 L .44113 .65852 L p .707 .577 .707 r
F P
0 g
s
.44113 .65852 m .45636 .65289 L p .41959 .63637 L .707 .577 .707 r
F P
0 g
s
.44589 .73172 m .44982 .66746 L p .44638 .73227 L .707 .577 .707 r
F P
0 g
s
.41421 .69239 m .41583 .69798 L p .44794 .70073 L .707 .577 .707 r
F P
0 g
s
.41583 .69798 m .4195 .71066 L .42532 .70863 L p .707 .577 .707 r
F P
0 g
s
.42532 .70863 m .44794 .70073 L p .41583 .69798 L .707 .577 .707 r
F P
0 g
s
.44638 .73227 m .44982 .66746 L .45534 .67314 L .707 .577 .707 r
F
.44551 .73802 m .44589 .73172 L p .44638 .73227 L F P
0 g
s
.64912 .60265 m .65772 .65843 L .67844 .66044 L p .707 .577 .707 r
F P
0 g
s
.69672 .73262 m .70201 .75089 L .73187 .74363 L p .707 .577 .707 r
F P
0 g
s
.23718 .78436 m .23189 .76609 L .26254 .75706 L p .707 .577 .707 r
F P
0 g
s
.26254 .75706 m .26783 .77532 L .23718 .78436 L p .707 .577 .707 r
F P
0 g
s
.52077 .24171 m .49038 .73935 L .44551 .73802 L p .707 .577 .707 r
F P
0 g
s
.70201 .75089 m .69672 .73262 L .67058 .73738 L p .707 .577 .707 r
F P
0 g
s
.68509 .71943 m .67367 .68309 L .654 .68556 L p .707 .577 .707 r
F P
0 g
s
.78566 .7064 m .79095 .72467 L .8144 .71481 L p .707 .577 .707 r
F P
0 g
s
.8144 .71481 m .80911 .69655 L .78566 .7064 L p .707 .577 .707 r
F P
0 g
s
.67058 .73738 m .67587 .75565 L .70201 .75089 L p .707 .577 .707 r
F P
0 g
s
.81129 .63923 m .82271 .67556 L .83884 .66663 L p .707 .577 .707 r
F P
0 g
s
.83884 .66663 m .82741 .63029 L .81129 .63923 L p .707 .577 .707 r
F P
0 g
s
.65772 .65843 m .64912 .60265 L .6368 .59829 L p .707 .577 .707 r
F P
0 g
s
.654 .68556 m .66543 .7219 L .68509 .71943 L p .707 .577 .707 r
F P
0 g
s
.82849 .57291 m .83709 .62869 L .84424 .62111 L p .707 .577 .707 r
F P
0 g
s
.84424 .62111 m .83563 .56532 L .82849 .57291 L p .707 .577 .707 r
F P
0 g
s
.6368 .59829 m .6454 .65408 L .65772 .65843 L p .707 .577 .707 r
F P
0 g
s
.67587 .75565 m .67058 .73738 L .65071 .73919 L p .707 .577 .707 r
F P
0 g
s
.65071 .73919 m .656 .75745 L .67587 .75565 L p .707 .577 .707 r
F P
0 g
s
.80911 .69655 m .8144 .71481 L .83056 .70599 L p .707 .577 .707 r
F P
0 g
s
.83056 .70599 m .82527 .68773 L .80911 .69655 L p .707 .577 .707 r
F P
0 g
s
.66543 .7219 m .654 .68556 L .64251 .68477 L p .707 .577 .707 r
F P
0 g
s
.82741 .63029 m .83884 .66663 L .84616 .65983 L p .707 .577 .707 r
F P
0 g
s
.84616 .65983 m .83474 .62349 L .82741 .63029 L p .707 .577 .707 r
F P
0 g
s
.64251 .68477 m .65394 .7211 L .66543 .7219 L p .707 .577 .707 r
F P
0 g
s
.6454 .65408 m .6368 .59829 L .63408 .59201 L p .707 .577 .707 r
F P
0 g
s
.656 .75745 m .65071 .73919 L .63906 .73785 L p .707 .577 .707 r
F P
0 g
s
.83563 .56532 m .84424 .62111 L .84152 .61483 L p .707 .577 .707 r
F P
0 g
s
.84152 .61483 m .83291 .55904 L .83563 .56532 L p .707 .577 .707 r
F P
0 g
s
.63906 .73785 m .64435 .75612 L .656 .75745 L p .707 .577 .707 r
F P
0 g
s
.63408 .59201 m .64268 .6478 L .6454 .65408 L p .707 .577 .707 r
F P
0 g
s
.82527 .68773 m .83056 .70599 L .83785 .69908 L p .707 .577 .707 r
F P
0 g
s
.83785 .69908 m .83256 .68082 L .82527 .68773 L p .707 .577 .707 r
F P
0 g
s
.65394 .7211 m .64251 .68477 L .64032 .68077 L p .707 .577 .707 r
F P
0 g
s
.64032 .68077 m .65175 .71711 L .65394 .7211 L p .707 .577 .707 r
F P
0 g
s
.83474 .62349 m .84616 .65983 L .84398 .65583 L p .707 .577 .707 r
F P
0 g
s
.84398 .65583 m .83255 .6195 L .83474 .62349 L p .707 .577 .707 r
F P
0 g
s
.64268 .6478 m .63408 .59201 L .64122 .58443 L p .707 .577 .707 r
F P
0 g
s
.64435 .75612 m .63906 .73785 L .63677 .73352 L p .707 .577 .707 r
F P
0 g
s
.63677 .73352 m .64206 .75178 L .64435 .75612 L p .707 .577 .707 r
F P
0 g
s
.83291 .55904 m .84152 .61483 L .8292 .61047 L p .707 .577 .707 r
F P
0 g
s
.8292 .61047 m .82059 .55469 L .83291 .55904 L p .707 .577 .707 r
F P
0 g
s
.64122 .58443 m .64983 .64021 L .64268 .6478 L p .707 .577 .707 r
F P
0 g
s
.83256 .68082 m .83785 .69908 L .83556 .69474 L p .707 .577 .707 r
F P
0 g
s
.83556 .69474 m .83027 .67648 L .83256 .68082 L p .707 .577 .707 r
F P
0 g
s
.39329 .61136 m .38469 .55558 L .3539 .5586 L p .707 .577 .707 r
F P
0 g
s
.38469 .55558 m .39329 .61136 L .42479 .60614 L p .707 .577 .707 r
F P
0 g
s
.42479 .60614 m .41618 .55036 L .38469 .55558 L p .707 .577 .707 r
F P
0 g
s
.41618 .55036 m .42479 .60614 L .4539 .59923 L p .707 .577 .707 r
F P
0 g
s
.4539 .59923 m .44529 .54345 L .41618 .55036 L p .707 .577 .707 r
F P
0 g
s
.65175 .71711 m .64032 .68077 L .64765 .67397 L p .707 .577 .707 r
F P
0 g
s
.64765 .67397 m .65908 .71031 L .65175 .71711 L p .707 .577 .707 r
F P
0 g
s
.83255 .6195 m .84398 .65583 L .83249 .65504 L p .707 .577 .707 r
F P
0 g
s
.83249 .65504 m .82106 .6187 L .83255 .6195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3625 .61439 m .3539 .5586 L .32682 .55914 L p .707 .577 .707 r
F P
0 g
s
.3539 .5586 m .3625 .61439 L .39329 .61136 L p .707 .577 .707 r
F P
0 g
s
.64983 .64021 m .64122 .58443 L .65753 .57628 L p .707 .577 .707 r
F P
0 g
s
.44529 .54345 m .4539 .59923 L .47777 .59132 L p .707 .577 .707 r
F P
0 g
s
.47777 .59132 m .46917 .53554 L .44529 .54345 L p .707 .577 .707 r
F P
0 g
s
.64206 .75178 m .63677 .73352 L .64406 .7266 L p .707 .577 .707 r
F P
0 g
s
.82059 .55469 m .8292 .61047 L .80848 .60846 L p .707 .577 .707 r
F P
0 g
s
.80848 .60846 m .79988 .55268 L .82059 .55469 L p .707 .577 .707 r
F P
0 g
s
.32682 .55914 m .33543 .61492 L .3625 .61439 L p .707 .577 .707 r
F P
0 g
s
.64406 .7266 m .64935 .74487 L .64206 .75178 L p .707 .577 .707 r
F P
0 g
s
.39763 .67306 m .38621 .63672 L .35657 .64472 L p .707 .577 .707 r
F P
0 g
s
.42808 .66335 m .41665 .62702 L .38621 .63672 L p .707 .577 .707 r
F P
0 g
s
.65753 .57628 m .66613 .63207 L .64983 .64021 L p .707 .577 .707 r
F P
0 g
s
.45636 .65289 m .44493 .61656 L .41665 .62702 L p .707 .577 .707 r
F P
0 g
s
.83027 .67648 m .83556 .69474 L .82391 .69341 L p .707 .577 .707 r
F P
0 g
s
.82391 .69341 m .81862 .67515 L .83027 .67648 L p .707 .577 .707 r
F P
0 g
s
.33543 .61492 m .32682 .55914 L .30611 .55713 L p .707 .577 .707 r
F P
0 g
s
.35657 .64472 m .368 .68105 L .39763 .67306 L p .707 .577 .707 r
F P
0 g
s
.368 .68105 m .35657 .64472 L .33066 .65022 L p .707 .577 .707 r
F P
0 g
s
.65908 .71031 m .64765 .67397 L .66378 .66504 L p .707 .577 .707 r
F P
0 g
s
.46917 .53554 m .47777 .59132 L .49408 .58317 L p .707 .577 .707 r
F P
0 g
s
.49408 .58317 m .48548 .52739 L .46917 .53554 L p .707 .577 .707 r
F P
0 g
s
.44493 .61656 m .45636 .65289 L .4797 .64269 L p .707 .577 .707 r
F P
0 g
s
.4797 .64269 m .46828 .60636 L .44493 .61656 L p .707 .577 .707 r
F P
0 g
s
.33066 .65022 m .34208 .68656 L .368 .68105 L p .707 .577 .707 r
F P
0 g
s
.66613 .63207 m .65753 .57628 L .68141 .56837 L p .707 .577 .707 r
F P
0 g
s
.30611 .55713 m .31471 .61291 L .33543 .61492 L p .707 .577 .707 r
F P
0 g
s
.82106 .6187 m .83249 .65504 L .81282 .65751 L p .707 .577 .707 r
F P
0 g
s
.81282 .65751 m .80139 .62117 L .82106 .6187 L p .707 .577 .707 r
F P
0 g
s
.66378 .66504 m .6752 .70137 L .65908 .71031 L p .707 .577 .707 r
F P
0 g
s
.38886 .71969 m .38356 .70143 L .35371 .70868 L p .707 .577 .707 r
F P
0 g
s
.38356 .70143 m .38886 .71969 L .4195 .71066 L p .707 .577 .707 r
F P
0 g
s
.4195 .71066 m .41421 .69239 L .38356 .70143 L p .707 .577 .707 r
F P
0 g
s
.44794 .70073 m .44265 .68246 L .41421 .69239 L p .707 .577 .707 r
F P
0 g
s
.35371 .70868 m .359 .72694 L .38886 .71969 L p .707 .577 .707 r
F P
0 g
s
.79988 .55268 m .80848 .60846 L .78141 .609 L p .707 .577 .707 r
F P
0 g
s
.78141 .609 m .7728 .55321 L .79988 .55268 L p .707 .577 .707 r
F P
0 g
s
.68141 .56837 m .69001 .62415 L .66613 .63207 L p .707 .577 .707 r
F P
0 g
s
.64935 .74487 m .64406 .7266 L .66022 .71779 L p .707 .577 .707 r
F P
0 g
s
.34208 .68656 m .33066 .65022 L .31099 .6527 L p .707 .577 .707 r
F P
0 g
s
.31471 .61291 m .30611 .55713 L .29379 .55277 L p .707 .577 .707 r
F P
0 g
s
.359 .72694 m .35371 .70868 L .32757 .71344 L p .707 .577 .707 r
F P
0 g
s
.66022 .71779 m .66551 .73605 L .64935 .74487 L p .707 .577 .707 r
F P
0 g
s
.44265 .68246 m .44794 .70073 L .47139 .69087 L p .707 .577 .707 r
F P
0 g
s
.47139 .69087 m .4661 .67261 L .44265 .68246 L p .707 .577 .707 r
F P
0 g
s
.46828 .60636 m .4797 .64269 L .49583 .63376 L p .707 .577 .707 r
F P
0 g
s
.49583 .63376 m .4844 .59742 L .46828 .60636 L p .707 .577 .707 r
F P
0 g
s
.32757 .71344 m .33286 .7317 L .359 .72694 L p .707 .577 .707 r
F P
0 g
s
.31099 .6527 m .32242 .68903 L .34208 .68656 L p .707 .577 .707 r
F P
0 g
s
.81862 .67515 m .82391 .69341 L .80404 .69522 L p .707 .577 .707 r
F P
0 g
s
.80404 .69522 m .79875 .67695 L .81862 .67515 L p .707 .577 .707 r
F P
0 g
s
.69001 .62415 m .68141 .56837 L .71052 .56146 L p .707 .577 .707 r
F P
0 g
s
.6752 .70137 m .66378 .66504 L .68712 .65484 L p .707 .577 .707 r
F P
0 g
s
.48548 .52739 m .49408 .58317 L .50123 .57559 L p .707 .577 .707 r
F P
0 g
s
.50123 .57559 m .49262 .5198 L .48548 .52739 L p .707 .577 .707 r
F P
0 g
s
.7728 .55321 m .78141 .609 L .75061 .61202 L p .707 .577 .707 r
F P
0 g
s
.75061 .61202 m .74201 .55624 L .7728 .55321 L p .707 .577 .707 r
F P
0 g
s
.29379 .55277 m .30239 .60856 L .31471 .61291 L p .707 .577 .707 r
F P
0 g
s
.80139 .62117 m .81282 .65751 L .7869 .66301 L p .707 .577 .707 r
F P
0 g
s
.7869 .66301 m .77548 .62668 L .80139 .62117 L p .707 .577 .707 r
F P
0 g
s
.68712 .65484 m .69855 .69118 L .6752 .70137 L p .707 .577 .707 r
F P
0 g
s
.71912 .61725 m .71052 .56146 L .74201 .55624 L p .707 .577 .707 r
F P
0 g
s
.71052 .56146 m .71912 .61725 L .69001 .62415 L p .707 .577 .707 r
F P
0 g
s
.33286 .7317 m .32757 .71344 L .3077 .71524 L p .707 .577 .707 r
F P
0 g
s
.74201 .55624 m .75061 .61202 L .71912 .61725 L p .707 .577 .707 r
F P
0 g
s
.3077 .71524 m .31299 .73351 L .33286 .7317 L p .707 .577 .707 r
F P
0 g
s
.4661 .67261 m .47139 .69087 L .48755 .68205 L p .707 .577 .707 r
F P
0 g
s
.48755 .68205 m .48226 .66379 L .4661 .67261 L p .707 .577 .707 r
F P
0 g
s
.32242 .68903 m .31099 .6527 L .2995 .6519 L p .707 .577 .707 r
F P
0 g
s
.66551 .73605 m .66022 .71779 L .68367 .70793 L p .707 .577 .707 r
F P
0 g
s
.68367 .70793 m .68896 .72619 L .66551 .73605 L p .707 .577 .707 r
F P
0 g
s
.69855 .69118 m .68712 .65484 L .7154 .64438 L p .707 .577 .707 r
F P
0 g
s
.30239 .60856 m .29379 .55277 L .29107 .5465 L p .707 .577 .707 r
F P
0 g
s
.4844 .59742 m .49583 .63376 L .50315 .62696 L p .707 .577 .707 r
F P
0 g
s
.50315 .62696 m .49173 .59063 L .4844 .59742 L p .707 .577 .707 r
F P
0 g
s
.79875 .67695 m .80404 .69522 L .7779 .69998 L p .707 .577 .707 r
F P
0 g
s
.7779 .69998 m .77261 .68171 L .79875 .67695 L p .707 .577 .707 r
F P
0 g
s
.2995 .6519 m .31093 .68823 L .32242 .68903 L p .707 .577 .707 r
F P
0 g
s
.77548 .62668 m .7869 .66301 L .75727 .67101 L p .707 .577 .707 r
F P
0 g
s
.75727 .67101 m .74585 .63467 L .77548 .62668 L p .707 .577 .707 r
F P
0 g
s
.7154 .64438 m .72683 .68071 L .69855 .69118 L p .707 .577 .707 r
F P
0 g
s
.72683 .68071 m .7154 .64438 L .74585 .63467 L p .707 .577 .707 r
F P
0 g
s
.49262 .5198 m .50123 .57559 L .4985 .56931 L p .707 .577 .707 r
F P
0 g
s
.4985 .56931 m .4899 .51353 L .49262 .5198 L p .707 .577 .707 r
F P
0 g
s
.74585 .63467 m .75727 .67101 L .72683 .68071 L p .707 .577 .707 r
F P
0 g
s
.29107 .5465 m .29967 .60228 L .30239 .60856 L p .707 .577 .707 r
F P
0 g
s
.31299 .73351 m .3077 .71524 L .29605 .71391 L p .707 .577 .707 r
F P
0 g
s
.68896 .72619 m .68367 .70793 L .71211 .698 L p .707 .577 .707 r
F P
0 g
s
.29605 .71391 m .30134 .73218 L .31299 .73351 L p .707 .577 .707 r
F P
0 g
s
.77261 .68171 m .7779 .69998 L .74805 .70723 L p .707 .577 .707 r
F P
0 g
s
.74805 .70723 m .74276 .68896 L .77261 .68171 L p .707 .577 .707 r
F P
0 g
s
.71211 .698 m .7174 .71626 L .68896 .72619 L p .707 .577 .707 r
F P
0 g
s
.48226 .66379 m .48755 .68205 L .49484 .67514 L p .707 .577 .707 r
F P
0 g
s
.49484 .67514 m .48955 .65687 L .48226 .66379 L p .707 .577 .707 r
F P
0 g
s
.31093 .68823 m .2995 .6519 L .29731 .6479 L p .707 .577 .707 r
F P
0 g
s
.7174 .71626 m .71211 .698 L .74276 .68896 L p .707 .577 .707 r
F P
0 g
s
.74276 .68896 m .74805 .70723 L .7174 .71626 L p .707 .577 .707 r
F P
0 g
s
.29731 .6479 m .30874 .68424 L .31093 .68823 L p .707 .577 .707 r
F P
0 g
s
.49173 .59063 m .50315 .62696 L .50097 .62297 L p .707 .577 .707 r
F P
0 g
s
.50097 .62297 m .48954 .58663 L .49173 .59063 L p .707 .577 .707 r
F P
0 g
s
.29967 .60228 m .29107 .5465 L .29821 .53891 L p .707 .577 .707 r
F P
0 g
s
.4899 .51353 m .4985 .56931 L .48619 .56495 L p .707 .577 .707 r
F P
0 g
s
.48619 .56495 m .47758 .50917 L .4899 .51353 L p .707 .577 .707 r
F P
0 g
s
.29821 .53891 m .30681 .5947 L .29967 .60228 L p .707 .577 .707 r
F P
0 g
s
.30134 .73218 m .29605 .71391 L .29376 .70958 L p .707 .577 .707 r
F P
0 g
s
.29376 .70958 m .29905 .72784 L .30134 .73218 L p .707 .577 .707 r
F P
0 g
s
.48955 .65687 m .49484 .67514 L .49255 .6708 L p .707 .577 .707 r
F P
0 g
s
.49255 .6708 m .48726 .65254 L .48955 .65687 L p .707 .577 .707 r
F P
0 g
s
.30874 .68424 m .29731 .6479 L .30464 .64111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30681 .5947 m .29821 .53891 L .31452 .53076 L p .707 .577 .707 r
F P
0 g
s
.30464 .64111 m .31607 .67744 L .30874 .68424 L p .707 .577 .707 r
F P
0 g
s
.48954 .58663 m .50097 .62297 L .48948 .62217 L p .707 .577 .707 r
F P
0 g
s
.48948 .62217 m .47805 .58583 L .48954 .58663 L p .707 .577 .707 r
F P
0 g
s
.47758 .50917 m .48619 .56495 L .46547 .56294 L p .707 .577 .707 r
F P
0 g
s
.46547 .56294 m .45687 .50716 L .47758 .50917 L p .707 .577 .707 r
F P
0 g
s
.31452 .53076 m .32312 .58655 L .30681 .5947 L p .707 .577 .707 r
F P
0 g
s
.29905 .72784 m .29376 .70958 L .30105 .70266 L p .707 .577 .707 r
F P
0 g
s
.30105 .70266 m .30634 .72093 L .29905 .72784 L p .707 .577 .707 r
F P
0 g
s
.48726 .65254 m .49255 .6708 L .4809 .66947 L p .707 .577 .707 r
F P
0 g
s
.4809 .66947 m .47561 .65121 L .48726 .65254 L p .707 .577 .707 r
F P
0 g
s
.31607 .67744 m .30464 .64111 L .32076 .63217 L p .707 .577 .707 r
F P
0 g
s
.32312 .58655 m .31452 .53076 L .3384 .52285 L p .707 .577 .707 r
F P
0 g
s
.47805 .58583 m .48948 .62217 L .46981 .62464 L p .707 .577 .707 r
F P
0 g
s
.46981 .62464 m .45838 .58831 L .47805 .58583 L p .707 .577 .707 r
F P
0 g
s
.32076 .63217 m .33219 .6685 L .31607 .67744 L p .707 .577 .707 r
F P
0 g
s
.45687 .50716 m .46547 .56294 L .4384 .56348 L p .707 .577 .707 r
F P
0 g
s
.4384 .56348 m .42979 .50769 L .45687 .50716 L p .707 .577 .707 r
F P
0 g
s
.3384 .52285 m .347 .57863 L .32312 .58655 L p .707 .577 .707 r
F P
0 g
s
.30634 .72093 m .30105 .70266 L .31721 .69384 L p .707 .577 .707 r
F P
0 g
s
.347 .57863 m .3384 .52285 L .36751 .51594 L p .707 .577 .707 r
F P
0 g
s
.31721 .69384 m .3225 .71211 L .30634 .72093 L p .707 .577 .707 r
F P
0 g
s
.47561 .65121 m .4809 .66947 L .46103 .67127 L p .707 .577 .707 r
F P
0 g
s
.46103 .67127 m .45574 .65301 L .47561 .65121 L p .707 .577 .707 r
F P
0 g
s
.42979 .50769 m .4384 .56348 L .4076 .56651 L p .707 .577 .707 r
F P
0 g
s
.4076 .56651 m .399 .51072 L .42979 .50769 L p .707 .577 .707 r
F P
0 g
s
.33219 .6685 m .32076 .63217 L .34411 .62197 L p .707 .577 .707 r
F P
0 g
s
.45838 .58831 m .46981 .62464 L .44389 .63014 L p .707 .577 .707 r
F P
0 g
s
.44389 .63014 m .43247 .59381 L .45838 .58831 L p .707 .577 .707 r
F P
0 g
s
.37611 .57173 m .36751 .51594 L .399 .51072 L p .707 .577 .707 r
F P
0 g
s
.36751 .51594 m .37611 .57173 L .347 .57863 L p .707 .577 .707 r
F P
0 g
s
.34411 .62197 m .35554 .65831 L .33219 .6685 L p .707 .577 .707 r
F P
0 g
s
.399 .51072 m .4076 .56651 L .37611 .57173 L p .707 .577 .707 r
F P
0 g
s
.3225 .71211 m .31721 .69384 L .34066 .68399 L p .707 .577 .707 r
F P
0 g
s
.35554 .65831 m .34411 .62197 L .37239 .61151 L p .707 .577 .707 r
F P
0 g
s
.34066 .68399 m .34595 .70225 L .3225 .71211 L p .707 .577 .707 r
F P
0 g
s
.43247 .59381 m .44389 .63014 L .41426 .63814 L p .707 .577 .707 r
F P
0 g
s
.41426 .63814 m .40284 .6018 L .43247 .59381 L p .707 .577 .707 r
F P
0 g
s
.45574 .65301 m .46103 .67127 L .43489 .67603 L p .707 .577 .707 r
F P
0 g
s
.43489 .67603 m .4296 .65777 L .45574 .65301 L p .707 .577 .707 r
F P
0 g
s
.37239 .61151 m .38381 .64784 L .35554 .65831 L p .707 .577 .707 r
F P
0 g
s
.38381 .64784 m .37239 .61151 L .40284 .6018 L p .707 .577 .707 r
F P
0 g
s
.40284 .6018 m .41426 .63814 L .38381 .64784 L p .707 .577 .707 r
F P
0 g
s
.34595 .70225 m .34066 .68399 L .3691 .67406 L p .707 .577 .707 r
F P
0 g
s
.4296 .65777 m .43489 .67603 L .40504 .68329 L p .707 .577 .707 r
F P
0 g
s
.40504 .68329 m .39974 .66502 L .4296 .65777 L p .707 .577 .707 r
F P
0 g
s
.3691 .67406 m .37439 .69232 L .34595 .70225 L p .707 .577 .707 r
F P
0 g
s
.37439 .69232 m .3691 .67406 L .39974 .66502 L p .707 .577 .707 r
F P
0 g
s
.39974 .66502 m .40504 .68329 L .37439 .69232 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001dOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001jOol0071oo`@000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Aoo`00KGoo0`0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`00LGoo001[Ool20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH3
001_Ool006Yoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF008006eoo`00JGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF
0P00Jgoo001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001YOol006Qoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001WOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02001U
Ool006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qo
o`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001ROol006Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00
Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001ROol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP1SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=o
o`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEWoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo00<005YF
00001UYF00<005YFFUH01UYF4P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol00`00FUH00006FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001OOol40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001KOol40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001GOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IWoo001EOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P008Goo4`00<goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000HOol90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00019oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00003FUH0
000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000ioo`@00003
FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002mo
o`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF
00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00002Woo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUH005YF02moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Ioo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_
Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol0
0`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00003Ool20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol00`00FUH00004FUH00`00FUH000030004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo
0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001DOol01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00001@000eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUIJEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH200000eYF001JEP07FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool004moo`H00004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool004Ioo`T000AJEP03001JEP0000=JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEPD000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo0010Ool60004FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?7oo100000=JEP00
FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEPD000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00Oomoo`0[Ool003Qoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUHA00000eYF001JEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90007FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000fOol200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<0
05YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YF0000;Goo000d
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
100000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH01UYF1P00
0UYF00<005YF00000P0000=JEP00Ool0;7oo000aOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF1@000UYF00<005YF00000P002EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUH00002000^Ool002moo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030003FUH01@00
FUIJEUYF00000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00H005YF000005YF0005FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH50006
FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF0`001eYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
00000`001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000[Ool00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH200000eYF001JEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000[Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`9J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUH000020005FUH20007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00
FUIJEP06FUH01000FUH0000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001J
EUYF00EJEP/0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP06FUH01000FUIJEUYF1000
00=JEP00FUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`00;7oo000/Ool00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUH00005FUH00`00FUIJEP04FUH3
0008FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP02FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF2@0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH00UYF00@005YFFUH002ao
o`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH01000FUIJEUYF10000UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF10001UYF00<005YFFUH00eYF0P00;Goo000/Ool01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP04
001JEP000005FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
0P001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<007ooOol0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH40006FUH01000FUIJEUYF10000UYF00<005YF
FUH01eYF00<005YFFUH015YF2`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF10001eYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;Goo00<005YF000015YF00<005YF00000`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF008000=JEP03001JEUYF00AJEP@0
00MJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0000000EJEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000]
Ool00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP020005FUH00`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP05FUH40003FUH20000
0eYF001JEP04FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP04FUH60002
FUH01000FUH00000<Goo000]Ool01000FUIJEP000UYF00@005YFFUH000QJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001JEP00008000AJEP03001JEUYF00MJ
EP03001JEUYF00@000EJEP8000=JEP03001JEUYF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40008FUH70003FUH00`00FUIJEP03FUH01000FUH00000<7oo000]Ool00`00FUIJEP030004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP05FUH50006FUH30006FUH00`00FUIJEP020002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEP000eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<0
05YFFUH00eYF00@005YFFUH0031oo`00;Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF1@000UYF2@002EYF00<005YFFUH01P0000=JEP00FUH00UYF100000=J
EP00FUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YF00000`001UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;goo000^Ool015YF
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP00FUH01eYF
0P000eYF00<005YFFUH01EYF100000=JEP00000020001UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00;Woo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF009JEP<000EJEP03001JEUYF00=JEP800003
FUH005YF00=JEPD00003FUH005YF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYF0003FUH00`00
FUIJEP02FUH20003FUH01000FUIJEUYF0`0015YF00<005YFFUH01UYF00<005YFFUH015YF3000;Woo
000^Ool01@00FUIJEUYF000015YF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01eYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YF00000P000eYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH01UYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP04001JEUYF0004FUH01000FUH000001EYF10001eYF00<005YF
FUH01eYF00<005YF00000`0000=oo`0000001EYF00@005YFFUH002ioo`00;Woo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP8000=JEP03001JEUYF
00AJEP<000IJEPD000MJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000D00003FUH005YF00=JEP8000IJEP800003FUH0
05YF00QJEP03001JEUYF00AJEP@0009oo`<00003FUH005YF00EJEP8002moo`00<7oo1@000eYF00<0
05YFFUH00UYF1`0025YF00<005YFFUH01EYF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP06FUH01000FUIJEUYF1@003EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00D005YFFUH005YF0080009JEP03001JEUYF
00<000=JEP03001JEUYF00MJEP03001JEUYF00@000=oo`<000EJEP03001JEUYF00=JEP03001oogoo
02ioo`00=Goo20000Woo0P0000=JEP00FUH025YF00<005YFFUH015YF00@005YFFUH000AJEP05001J
EP00001JEP070006FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP020004FUH3
0007FUH00`00FUIJEP04FUH50005Ool200000eYF001JEP05FUH01000FUIJEUYF0P00<Goo000lOol3
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF1P000eYF00<005YFFUH01eYF
00<005YFFUH015YF0`001UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P001EYF00D005YF001JEP00009JEP800003FUH005YF00MJEP03001J
EUYF00@000Moo`<000=JEP03001JEUYF00EJEP<003=oo`00>Goo0`001eYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00@000UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP<0009JEP<000=JEP03001JEUYF00EJEP@000=oo`<0009oo`<000IJEP03001JEUYF00AJ
EP8003Eoo`00=Woo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP000000
009JEP04001JEP000006FUH00`00FUIJEP02FUH20006Ool600000eYF001JEP07FUH01000FUIJEUYF
0P00=goo000dOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0`001eYF00<005YF00000P0027oo1@000UYF00<005YFFUH01UYF00@005YF000003Uoo`00<Woo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01P0000=JEP00FUH015YF00<005YFFUH0
15YF1@002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH015YF0P0000=JEP0000001Goo
20000eYF00<005YFFUH015YF0`00>goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH40004FUH01000FUIJEP001EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P000UYF0`0015YF00<005YFFUH00UYF0`000UYF0P0000=oo`0000000P0000AJEP00
FUIJEP<000AJEP03001JEUYF00@003ioo`00;goo00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF300000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP04001JEP000002FUH60006FUH00`00FUIJ
EP05FUH40012Ool002ioo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000EJ
EP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP800003FUH005YF009JEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20016
Ool002eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP06
FUH01000FUH000000Woo0UYF00<005YFFUH015YF00<005YFFUH015YF2@0000=JEP00FUH02EYF3000
1UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008004Qoo`00;Goo00@005YFFUH000EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEPP00003
FUH005YF00EJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00QJEPP000UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF
00AJEP@004]oo`00;Woo00<005YF00001EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YF
FUH01UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00=JEP@000EJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000=JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@004moo`00;Woo
00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH01UYF10001UYF00D005YFFUIJEP00
009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH400000eYF001JEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEP001UYF
00@005YFFUIJEPH005=oo`00;Woo00@005YFFUH000AJEP03001JEUYF009JEP80009JEP03001JEUYF
00MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00H005YF000005YF
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00020007FUH00`00FUIJEP02FUH00`00FUH00003FUH20002FUH01000FUIJEUYF1P000eYF0P00E7oo
000^Ool01000FUIJEP001EYF00@005YF000000EJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH00`00FUH0
000;0003FUH00`00FUIJEP03FUH00`00Oomoo`1COol002moo`03001JEP0000AJEP<000MJEP04001J
EUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP<00003FUH005YF00=JEP03001JEP0000MJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol0
02moo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH30004FUH00`00FUH00008FUH00`00FUIJEP04FUH3001HOol0
02moo`03001JEUYF008000EJEP03001JEUYF009JEP800003FUH005YF00QJEP03001JEUYF00EJEPH0
0006Ool00000FUH005YF0P003UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00@005YFFUH000=JEP<000QJEPX005Qoo`00<7oo00AJEP00FUH0
00EJEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEUYF00@000Eoo`8000AJEP<000iJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH2000015YF0000000015YF100000=JEP00FUH00eYF00<005YFFUH00P00Egoo000`Ool2
00000eYF001JEP04FUH20007FUH00`00FUIJEP06FUH40006Ool30006FUH3000>FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH300000eYF000000020005FUH00`00FUIJEP03FUH01000FUIJEP00Egoo000aOol2000015YF001J
EUYF0`0025YF00<005YFFUH00eYF10001goo0P0000=JEP00FUH01eYF0P003UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH00UYF00<005YFFUH00P00EWoo000cOol40003
FUH00`00FUIJEP06FUH00`00FUH000060004Ool30004FUH00`00FUIJEP04FUH3000=FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH005Ioo`00<Woo
0`001EYF00<005YFFUH01EYF0`000goo0`000Woo0`001eYF00<005YFFUH00UYF0P000goo0P002eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP`005Eoo`00<7oo0P0000=JEP00FUH0
1UYF00<005YFFUH010001goo100000=JEP00FUH025YF00@005YF000000Moo`03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUH000030002Ool00`00FUIJEP03FUH01000FUIJEP00
EGoo000^Ool20003FUH00`00FUIJEP04FUH40006Ool50006FUH00`00FUIJEP05FUH3000:Ool20008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP000UYF100017oo0`001UYF0P00EWoo000]Ool20005FUH01000
FUIJEUYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P003goo0P001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000`001Woo0P000eYF00<005YFFUH00eYF00<007ooOol0EGoo000/Ool01000
FUIJEP0015YF00@005YF000000Aoo`@000IJEP03001JEUYF00MJEP03001JEP00008001=oo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000Moo`<000EJEP04001JEUYFFUH2001HOol002aoo`04001JEUYF0004FUH2
0002Ool400000eYF001JEP08FUH00`00FUIJEP04FUH4000HOol300000eYF001JEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool400000eYF001JEP06FUH3001JOol002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJ
EP03001JEUYF00@001moo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH200000goo000000020005FUH00`00FUIJEP04FUH2001LOol002eo
o`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@002Ioo`@000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000@00003FUH005YF
00MJEP04001JEUYFFUH2001NOol002eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04
000^Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH80002
FUH00`00FUIJEP06FUH01000FUH00000H7oo000^Ool015YF001JEP001EYF00<005YFFUH015YF1000
=Woo1`001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH03@000UYF00<005YFFUH01EYF
0`00HWoo000^Ool01000FUIJEP001EYF00<005YFFUH01000@Goo3@001UYF00<005YFFUH015YF2000
00=oo`0000000P0000=JEP00FUH01@000eYF00<005YFFUH00UYF0P00IGoo000^Ool<001BOol>0002
Ool60006FUH00`00FUH000020004FUH00`00FUH00002001WOol008ioo`04001JEUYF0003FUH70003
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001ZOol008ioo`05001JEUYF001JEP020002FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001]Ool008moo`04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH5001aOol008moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00@007Ioo`00Sgoo00@005YFFUH000EJEP03001JEUYF00AJEP@007Yoo`00Sgoo0P000UYF00<0
05YFFUH00eYF00<005YF00000`00OWoo002@Ool;0022Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59806 .74923 m .59273 .69335 L .5617 .69449 L p .707 .577 .707 r
F P
0 g
s
.59273 .69335 m .59806 .74923 L .62977 .7457 L p .707 .577 .707 r
F P
0 g
s
.62977 .7457 m .62443 .68983 L .59273 .69335 L p .707 .577 .707 r
F P
0 g
s
.62443 .68983 m .62977 .7457 L .65904 .74015 L p .707 .577 .707 r
F P
0 g
s
.65904 .74015 m .65371 .68427 L .62443 .68983 L p .707 .577 .707 r
F P
0 g
s
.56703 .75037 m .5617 .69449 L .53439 .69314 L p .707 .577 .707 r
F P
0 g
s
.5617 .69449 m .56703 .75037 L .59806 .74923 L p .707 .577 .707 r
F P
0 g
s
.65371 .68427 m .65904 .74015 L .68303 .7331 L p .707 .577 .707 r
F P
0 g
s
.68303 .7331 m .6777 .67722 L .65371 .68427 L p .707 .577 .707 r
F P
0 g
s
.60104 .80271 m .59391 .76564 L .56332 .76988 L p .707 .577 .707 r
F P
0 g
s
.59391 .76564 m .60104 .80271 L .63235 .79639 L p .707 .577 .707 r
F P
0 g
s
.63235 .79639 m .62521 .75932 L .59391 .76564 L p .707 .577 .707 r
F P
0 g
s
.53439 .69314 m .53972 .74902 L .56703 .75037 L p .707 .577 .707 r
F P
0 g
s
.62521 .75932 m .63235 .79639 L .6613 .78862 L p .707 .577 .707 r
F P
0 g
s
.6613 .78862 m .65417 .75154 L .62521 .75932 L p .707 .577 .707 r
F P
0 g
s
.53972 .74902 m .53439 .69314 L .51346 .68943 L p .707 .577 .707 r
F P
0 g
s
.56332 .76988 m .57046 .80695 L .60104 .80271 L p .707 .577 .707 r
F P
0 g
s
.57046 .80695 m .56332 .76988 L .53646 .77163 L p .707 .577 .707 r
F P
0 g
s
.65417 .75154 m .6613 .78862 L .68509 .78014 L p .707 .577 .707 r
F P
0 g
s
.68509 .78014 m .67795 .74307 L .65417 .75154 L p .707 .577 .707 r
F P
0 g
s
.6777 .67722 m .68303 .7331 L .69938 .72525 L p .707 .577 .707 r
F P
0 g
s
.69938 .72525 m .69404 .66937 L .6777 .67722 L p .707 .577 .707 r
F P
0 g
s
.53646 .77163 m .5436 .80871 L .57046 .80695 L p .707 .577 .707 r
F P
0 g
s
.59554 .84187 m .59224 .82331 L .56158 .82708 L p .707 .577 .707 r
F P
0 g
s
.59224 .82331 m .59554 .84187 L .62692 .83597 L p .707 .577 .707 r
F P
0 g
s
.62692 .83597 m .62362 .81741 L .59224 .82331 L p .707 .577 .707 r
F P
0 g
s
.51346 .68943 m .5188 .74531 L .53972 .74902 L p .707 .577 .707 r
F P
0 g
s
.62362 .81741 m .62692 .83597 L .65595 .82853 L p .707 .577 .707 r
F P
0 g
s
.65595 .82853 m .65264 .80997 L .62362 .81741 L p .707 .577 .707 r
F P
0 g
s
.56158 .82708 m .56488 .84565 L .59554 .84187 L p .707 .577 .707 r
F P
0 g
s
.56488 .84565 m .56158 .82708 L .53462 .82837 L p .707 .577 .707 r
F P
0 g
s
.5436 .80871 m .53646 .77163 L .51594 .77072 L p .707 .577 .707 r
F P
0 g
s
.5188 .74531 m .51346 .68943 L .50098 .68373 L p .707 .577 .707 r
F P
0 g
s
.53462 .82837 m .53792 .84693 L .56488 .84565 L p .707 .577 .707 r
F P
0 g
s
.65264 .80997 m .65595 .82853 L .67977 .82027 L p .707 .577 .707 r
F P
0 g
s
.67977 .82027 m .67647 .80171 L .65264 .80997 L p .707 .577 .707 r
F P
0 g
s
.67795 .74307 m .68509 .78014 L .70136 .7718 L p .707 .577 .707 r
F P
0 g
s
.70136 .7718 m .69422 .73473 L .67795 .74307 L p .707 .577 .707 r
F P
0 g
s
.51594 .77072 m .52308 .80779 L .5436 .80871 L p .707 .577 .707 r
F P
0 g
s
.69404 .66937 m .69938 .72525 L .70648 .71736 L p .707 .577 .707 r
F P
0 g
s
.70648 .71736 m .70115 .66149 L .69404 .66937 L p .707 .577 .707 r
F P
0 g
s
.50098 .68373 m .50631 .73961 L .5188 .74531 L p .707 .577 .707 r
F P
0 g
s
.53792 .84693 m .53462 .82837 L .51402 .82703 L p .707 .577 .707 r
F P
0 g
s
.51402 .82703 m .51732 .8456 L .53792 .84693 L p .707 .577 .707 r
F P
0 g
s
.67647 .80171 m .67977 .82027 L .69606 .81201 L p .707 .577 .707 r
F P
0 g
s
.69606 .81201 m .69275 .79344 L .67647 .80171 L p .707 .577 .707 r
F P
0 g
s
.52308 .80779 m .51594 .77072 L .50377 .76724 L p .707 .577 .707 r
F P
0 g
s
.50631 .73961 m .50098 .68373 L .49815 .67659 L p .707 .577 .707 r
F P
0 g
s
.50377 .76724 m .51091 .80431 L .52308 .80779 L p .707 .577 .707 r
F P
0 g
s
.69422 .73473 m .70136 .7718 L .70854 .76441 L p .707 .577 .707 r
F P
0 g
s
.70854 .76441 m .7014 .72734 L .69422 .73473 L p .707 .577 .707 r
F P
0 g
s
.51732 .8456 m .51402 .82703 L .50179 .82321 L p .707 .577 .707 r
F P
0 g
s
.50179 .82321 m .50509 .84178 L .51732 .8456 L p .707 .577 .707 r
F P
0 g
s
.70115 .66149 m .70648 .71736 L .70365 .71022 L p .707 .577 .707 r
F P
0 g
s
.70365 .71022 m .69832 .65434 L .70115 .66149 L p .707 .577 .707 r
F P
0 g
s
.49815 .67659 m .50348 .73246 L .50631 .73961 L p .707 .577 .707 r
F P
0 g
s
.69275 .79344 m .69606 .81201 L .70322 .80454 L p .707 .577 .707 r
F P
0 g
s
.70322 .80454 m .69992 .78598 L .69275 .79344 L p .707 .577 .707 r
F P
0 g
s
.47849 .82203 m .49729 .32254 L .45331 .31819 L p .707 .577 .707 r
F P
0 g
s
.51091 .80431 m .50377 .76724 L .50114 .76152 L p .707 .577 .707 r
F P
0 g
s
.50114 .76152 m .50828 .79859 L .51091 .80431 L p .707 .577 .707 r
F P
0 g
s
.50348 .73246 m .49815 .67659 L .50525 .6687 L p .707 .577 .707 r
F P
0 g
s
.50509 .84178 m .50179 .82321 L .49913 .81728 L p .707 .577 .707 r
F P
0 g
s
.49913 .81728 m .50243 .83584 L .50509 .84178 L p .707 .577 .707 r
F P
0 g
s
.50525 .6687 m .51059 .72458 L .50348 .73246 L p .707 .577 .707 r
F P
0 g
s
.50828 .79859 m .50114 .76152 L .50832 .75413 L p .707 .577 .707 r
F P
0 g
s
.50832 .75413 m .51546 .7912 L .50828 .79859 L p .707 .577 .707 r
F P
0 g
s
.51059 .72458 m .50525 .6687 L .5216 .66085 L p .707 .577 .707 r
F P
0 g
s
.50243 .83584 m .49913 .81728 L .50629 .80981 L p .707 .577 .707 r
F P
0 g
s
.50629 .80981 m .50959 .82838 L .50243 .83584 L p .707 .577 .707 r
F P
0 g
s
.5216 .66085 m .52693 .71673 L .51059 .72458 L p .707 .577 .707 r
F P
0 g
s
.51546 .7912 m .50832 .75413 L .5246 .74579 L p .707 .577 .707 r
F P
0 g
s
.5246 .74579 m .53173 .78286 L .51546 .7912 L p .707 .577 .707 r
F P
0 g
s
.50959 .82838 m .50629 .80981 L .52258 .80155 L p .707 .577 .707 r
F P
0 g
s
.52258 .80155 m .52588 .82011 L .50959 .82838 L p .707 .577 .707 r
F P
0 g
s
.49729 .32254 m .47849 .82203 L .52341 .82244 L p .707 .577 .707 r
F P
0 g
s
.52693 .71673 m .5216 .66085 L .54559 .65381 L p .707 .577 .707 r
F P
0 g
s
.54559 .65381 m .55092 .70968 L .52693 .71673 L p .707 .577 .707 r
F P
0 g
s
.53173 .78286 m .5246 .74579 L .54838 .73731 L p .707 .577 .707 r
F P
0 g
s
.52588 .82011 m .52258 .80155 L .5464 .79329 L p .707 .577 .707 r
F P
0 g
s
.52341 .82244 m .5422 .32295 L .49729 .32254 L p .707 .577 .707 r
F P
0 g
s
.55092 .70968 m .54559 .65381 L .57486 .64825 L p .707 .577 .707 r
F P
0 g
s
.54838 .73731 m .55552 .77438 L .53173 .78286 L p .707 .577 .707 r
F P
0 g
s
.57486 .64825 m .5802 .70413 L .55092 .70968 L p .707 .577 .707 r
F P
0 g
s
.55552 .77438 m .54838 .73731 L .57734 .72953 L p .707 .577 .707 r
F P
0 g
s
.5464 .79329 m .5497 .81185 L .52588 .82011 L p .707 .577 .707 r
F P
0 g
s
.57734 .72953 m .58447 .76661 L .55552 .77438 L p .707 .577 .707 r
F P
0 g
s
.5497 .81185 m .5464 .79329 L .57542 .78585 L p .707 .577 .707 r
F P
0 g
s
.57542 .78585 m .57872 .80441 L .5497 .81185 L p .707 .577 .707 r
F P
0 g
s
.5422 .32295 m .52341 .82244 L .56487 .81886 L p .707 .577 .707 r
F P
0 g
s
.56487 .81886 m .58366 .31937 L .5422 .32295 L p .707 .577 .707 r
F P
0 g
s
.43452 .81769 m .45331 .31819 L .41458 .31033 L p .707 .577 .707 r
F P
0 g
s
.45331 .31819 m .43452 .81769 L .47849 .82203 L p .707 .577 .707 r
F P
0 g
s
.7014 .72734 m .70854 .76441 L .70591 .75869 L p .707 .577 .707 r
F P
0 g
s
.70591 .75869 m .69877 .72162 L .7014 .72734 L p .707 .577 .707 r
F P
0 g
s
.5802 .70413 m .57486 .64825 L .60657 .64472 L p .707 .577 .707 r
F P
0 g
s
.60657 .64472 m .6119 .7006 L .5802 .70413 L p .707 .577 .707 r
F P
0 g
s
.58447 .76661 m .57734 .72953 L .60864 .72322 L p .707 .577 .707 r
F P
0 g
s
.60864 .72322 m .61578 .76029 L .58447 .76661 L p .707 .577 .707 r
F P
0 g
s
.57872 .80441 m .57542 .78585 L .6068 .77995 L p .707 .577 .707 r
F P
0 g
s
.6068 .77995 m .6101 .79851 L .57872 .80441 L p .707 .577 .707 r
F P
0 g
s
.58366 .31937 m .56487 .81886 L .59881 .81165 L p .707 .577 .707 r
F P
0 g
s
.59881 .81165 m .6176 .31216 L .58366 .31937 L p .707 .577 .707 r
F P
0 g
s
.69832 .65434 m .70365 .71022 L .69116 .70452 L p .707 .577 .707 r
F P
0 g
s
.69116 .70452 m .68583 .64864 L .69832 .65434 L p .707 .577 .707 r
F P
0 g
s
.69992 .78598 m .70322 .80454 L .70055 .79861 L p .707 .577 .707 r
F P
0 g
s
.70055 .79861 m .69725 .78004 L .69992 .78598 L p .707 .577 .707 r
F P
0 g
s
.39578 .80982 m .41458 .31033 L .38488 .29972 L p .707 .577 .707 r
F P
0 g
s
.41458 .31033 m .39578 .80982 L .43452 .81769 L p .707 .577 .707 r
F P
0 g
s
.25505 .70703 m .24972 .65115 L .21869 .6523 L p .707 .577 .707 r
F P
0 g
s
.24972 .65115 m .25505 .70703 L .28676 .70351 L p .707 .577 .707 r
F P
0 g
s
.28676 .70351 m .28142 .64763 L .24972 .65115 L p .707 .577 .707 r
F P
0 g
s
.28142 .64763 m .28676 .70351 L .31603 .69795 L p .707 .577 .707 r
F P
0 g
s
.31603 .69795 m .3107 .64207 L .28142 .64763 L p .707 .577 .707 r
F P
0 g
s
.22403 .70818 m .21869 .6523 L .19138 .65095 L p .707 .577 .707 r
F P
0 g
s
.21869 .6523 m .22403 .70818 L .25505 .70703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69877 .72162 m .70591 .75869 L .69374 .75521 L p .707 .577 .707 r
F P
0 g
s
.69374 .75521 m .68661 .71813 L .69877 .72162 L p .707 .577 .707 r
F P
0 g
s
.3107 .64207 m .31603 .69795 L .34002 .6909 L p .707 .577 .707 r
F P
0 g
s
.34002 .6909 m .33469 .63502 L .3107 .64207 L p .707 .577 .707 r
F P
0 g
s
.63759 .64358 m .64293 .69946 L .6119 .7006 L p .707 .577 .707 r
F P
0 g
s
.6119 .7006 m .60657 .64472 L .63759 .64358 L p .707 .577 .707 r
F P
0 g
s
.63922 .71897 m .64636 .75605 L .61578 .76029 L p .707 .577 .707 r
F P
0 g
s
.61578 .76029 m .60864 .72322 L .63922 .71897 L p .707 .577 .707 r
F P
0 g
s
.63747 .77617 m .64077 .79474 L .6101 .79851 L p .707 .577 .707 r
F P
0 g
s
.6101 .79851 m .6068 .77995 L .63747 .77617 L p .707 .577 .707 r
F P
0 g
s
.6176 .31216 m .59881 .81165 L .62191 .80151 L p .707 .577 .707 r
F P
0 g
s
.62191 .80151 m .64071 .30202 L .6176 .31216 L p .707 .577 .707 r
F P
0 g
s
.68583 .64864 m .69116 .70452 L .67024 .70081 L p .707 .577 .707 r
F P
0 g
s
.67024 .70081 m .66491 .64493 L .68583 .64864 L p .707 .577 .707 r
F P
0 g
s
.19138 .65095 m .19671 .70683 L .22403 .70818 L p .707 .577 .707 r
F P
0 g
s
.25804 .76834 m .2509 .73126 L .22032 .73551 L p .707 .577 .707 r
F P
0 g
s
.2509 .73126 m .25804 .76834 L .28934 .76202 L p .707 .577 .707 r
F P
0 g
s
.28934 .76202 m .2822 .72494 L .2509 .73126 L p .707 .577 .707 r
F P
0 g
s
.2822 .72494 m .28934 .76202 L .3183 .75424 L p .707 .577 .707 r
F P
0 g
s
.3183 .75424 m .31116 .71717 L .2822 .72494 L p .707 .577 .707 r
F P
0 g
s
.19671 .70683 m .19138 .65095 L .17046 .64724 L p .707 .577 .707 r
F P
0 g
s
.69725 .78004 m .70055 .79861 L .68832 .79479 L p .707 .577 .707 r
F P
0 g
s
.68832 .79479 m .68502 .77622 L .69725 .78004 L p .707 .577 .707 r
F P
0 g
s
.22032 .73551 m .22746 .77258 L .25804 .76834 L p .707 .577 .707 r
F P
0 g
s
.22746 .77258 m .22032 .73551 L .19345 .73726 L p .707 .577 .707 r
F P
0 g
s
.36609 .79921 m .38488 .29972 L .36712 .28739 L p .707 .577 .707 r
F P
0 g
s
.38488 .29972 m .36609 .79921 L .39578 .80982 L p .707 .577 .707 r
F P
0 g
s
.33469 .63502 m .34002 .6909 L .35637 .68305 L p .707 .577 .707 r
F P
0 g
s
.35637 .68305 m .35103 .62717 L .33469 .63502 L p .707 .577 .707 r
F P
0 g
s
.31116 .71717 m .3183 .75424 L .34208 .74577 L p .707 .577 .707 r
F P
0 g
s
.34208 .74577 m .33494 .70869 L .31116 .71717 L p .707 .577 .707 r
F P
0 g
s
.19345 .73726 m .20059 .77433 L .22746 .77258 L p .707 .577 .707 r
F P
0 g
s
.17046 .64724 m .17579 .70312 L .19671 .70683 L p .707 .577 .707 r
F P
0 g
s
.68661 .71813 m .69374 .75521 L .67322 .75429 L p .707 .577 .707 r
F P
0 g
s
.67322 .75429 m .66608 .71722 L .68661 .71813 L p .707 .577 .707 r
F P
0 g
s
.25254 .81301 m .24924 .79445 L .21857 .79822 L p .707 .577 .707 r
F P
0 g
s
.24924 .79445 m .25254 .81301 L .28392 .80711 L p .707 .577 .707 r
F P
0 g
s
.28392 .80711 m .28062 .78855 L .24924 .79445 L p .707 .577 .707 r
F P
0 g
s
.28062 .78855 m .28392 .80711 L .31294 .79967 L p .707 .577 .707 r
F P
0 g
s
.31294 .79967 m .30964 .78111 L .28062 .78855 L p .707 .577 .707 r
F P
0 g
s
.66491 .64493 m .67024 .70081 L .64293 .69946 L p .707 .577 .707 r
F P
0 g
s
.64293 .69946 m .63759 .64358 L .66491 .64493 L p .707 .577 .707 r
F P
0 g
s
.21857 .79822 m .22187 .81679 L .25254 .81301 L p .707 .577 .707 r
F P
0 g
s
.20059 .77433 m .19345 .73726 L .17293 .73635 L p .707 .577 .707 r
F P
0 g
s
.17579 .70312 m .17046 .64724 L .15797 .64154 L p .707 .577 .707 r
F P
0 g
s
.22187 .81679 m .21857 .79822 L .19162 .79951 L p .707 .577 .707 r
F P
0 g
s
.19162 .79951 m .19492 .81807 L .22187 .81679 L p .707 .577 .707 r
F P
0 g
s
.30964 .78111 m .31294 .79967 L .33676 .79141 L p .707 .577 .707 r
F P
0 g
s
.33676 .79141 m .33346 .77285 L .30964 .78111 L p .707 .577 .707 r
F P
0 g
s
.33494 .70869 m .34208 .74577 L .35835 .73743 L p .707 .577 .707 r
F P
0 g
s
.35835 .73743 m .35121 .70035 L .33494 .70869 L p .707 .577 .707 r
F P
0 g
s
.17293 .73635 m .18007 .77342 L .20059 .77433 L p .707 .577 .707 r
F P
0 g
s
.68502 .77622 m .68832 .79479 L .66772 .79345 L p .707 .577 .707 r
F P
0 g
s
.66772 .79345 m .66442 .77489 L .68502 .77622 L p .707 .577 .707 r
F P
0 g
s
.64071 .30202 m .62191 .80151 L .63192 .78944 L p .707 .577 .707 r
F P
0 g
s
.63192 .78944 m .65071 .28995 L .64071 .30202 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .36305 .27457 L p .36009 .37768 L .707 .577 .707 r
F P
0 g
s
.35103 .62717 m .35637 .68305 L .36129 .67759 L p .707 .577 .707 r
F P
0 g
s
.36125 .66658 m .35103 .62717 L .36129 .67759 L .707 .577 .707 r
F
.36347 .67517 m .35814 .61929 L .35103 .62717 L p F P
0 g
s
.33346 .77285 m .33676 .79141 L .35305 .78315 L p .707 .577 .707 r
F P
0 g
s
.35305 .78315 m .34975 .76458 L .33346 .77285 L p .707 .577 .707 r
F P
0 g
s
.35121 .70035 m .35835 .73743 L .36553 .73003 L p .707 .577 .707 r
F P
0 g
s
.36553 .73003 m .35839 .69296 L .35121 .70035 L p .707 .577 .707 r
F P
0 g
s
.35531 .61215 m .35826 .64307 L p .34815 .66232 L .707 .577 .707 r
F P
0 g
s
.35826 .64307 m .36064 .66803 L .35655 .66616 L p .707 .577 .707 r
F P
0 g
s
.35655 .66616 m .34815 .66232 L p .35826 .64307 L .707 .577 .707 r
F P
0 g
s
.34815 .66232 m .34282 .60644 L .35531 .61215 L p .707 .577 .707 r
F P
0 g
s
.35074 .72083 m .3436 .68376 L .35577 .68724 L p .707 .577 .707 r
F P
0 g
s
.34975 .76458 m .35305 .78315 L .36021 .77568 L p .707 .577 .707 r
F P
0 g
s
.36021 .77568 m .35691 .75712 L .34975 .76458 L p .707 .577 .707 r
F P
0 g
s
.35424 .75119 m .35754 .76975 L .34531 .76593 L p .707 .577 .707 r
F P
0 g
s
.34531 .76593 m .34201 .74736 L .35424 .75119 L p .707 .577 .707 r
F P
0 g
s
.3436 .68376 m .35074 .72083 L .33021 .71992 L p .707 .577 .707 r
F P
0 g
s
.34878 .77126 m .36044 .46511 L .36009 .37768 L .707 .577 .707 r
F
.34833 .78689 m .34906 .76744 L p .34878 .77126 L F P
0 g
s
.35577 .68724 m .35646 .69086 L p .35074 .72083 L .707 .577 .707 r
F P
0 g
s
.35646 .69086 m .3629 .72432 L .35328 .72156 L p .707 .577 .707 r
F P
0 g
s
.35328 .72156 m .35074 .72083 L p .35646 .69086 L .707 .577 .707 r
F P
0 g
s
.34906 .76744 m .34937 .75934 L p .34878 .77126 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .36044 .46511 L p .34916 .76138 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .34916 .76138 L .34878 .77126 L .707 .577 .707 r
F
.36044 .46511 m .36712 .28739 L p .36009 .37768 L F P
0 g
s
.36129 .67759 m .36347 .67517 L p .36125 .66658 L .707 .577 .707 r
F P
0 g
s
.15797 .64154 m .1633 .69741 L .17579 .70312 L p .707 .577 .707 r
F P
0 g
s
.66608 .71722 m .67322 .75429 L .64636 .75605 L p .707 .577 .707 r
F P
0 g
s
.64636 .75605 m .63922 .71897 L .66608 .71722 L p .707 .577 .707 r
F P
0 g
s
.19492 .81807 m .19162 .79951 L .17102 .79817 L p .707 .577 .707 r
F P
0 g
s
.17102 .79817 m .17432 .81674 L .19492 .81807 L p .707 .577 .707 r
F P
0 g
s
.35814 .61929 m .36347 .67517 L .36064 .66803 L p .707 .577 .707 r
F P
0 g
s
.36064 .66803 m .35531 .61215 L .35814 .61929 L p .707 .577 .707 r
F P
0 g
s
.35839 .69296 m .36553 .73003 L .3629 .72432 L p .707 .577 .707 r
F P
0 g
s
.3629 .72432 m .35577 .68724 L .35839 .69296 L p .707 .577 .707 r
F P
0 g
s
.35691 .75712 m .36021 .77568 L .35754 .76975 L p .707 .577 .707 r
F P
0 g
s
.35754 .76975 m .35424 .75119 L .35691 .75712 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .34833 .78689 L .36609 .79921 L p .707 .577 .707 r
F P
0 g
s
.18007 .77342 m .17293 .73635 L .16076 .73286 L p .707 .577 .707 r
F P
0 g
s
.1633 .69741 m .15797 .64154 L .15514 .63439 L p .707 .577 .707 r
F P
0 g
s
.16076 .73286 m .1679 .76993 L .18007 .77342 L p .707 .577 .707 r
F P
0 g
s
.66442 .77489 m .66772 .79345 L .64077 .79474 L p .707 .577 .707 r
F P
0 g
s
.64077 .79474 m .63747 .77617 L .66442 .77489 L p .707 .577 .707 r
F P
0 g
s
.17432 .81674 m .17102 .79817 L .15878 .79435 L p .707 .577 .707 r
F P
0 g
s
.15514 .63439 m .16047 .69027 L .1633 .69741 L p .707 .577 .707 r
F P
0 g
s
.15878 .79435 m .16208 .81292 L .17432 .81674 L p .707 .577 .707 r
F P
0 g
s
.65071 .28995 m .63192 .78944 L .62784 .77662 L p .707 .577 .707 r
F P
0 g
s
.62784 .77662 m .64664 .27712 L .65071 .28995 L p .707 .577 .707 r
F P
0 g
s
.1679 .76993 m .16076 .73286 L .15813 .72714 L p .707 .577 .707 r
F P
0 g
s
.16047 .69027 m .15514 .63439 L .16224 .62651 L p .707 .577 .707 r
F P
0 g
s
.15813 .72714 m .16527 .76421 L .1679 .76993 L p .707 .577 .707 r
F P
0 g
s
.34201 .74736 m .34531 .76593 L .32471 .76459 L p .707 .577 .707 r
F P
0 g
s
.36305 .27457 m .34426 .77406 L .34833 .78689 L p .707 .577 .707 r
F P
0 g
s
.34426 .77406 m .36305 .27457 L .37305 .2625 L p .707 .577 .707 r
F P
0 g
s
.16208 .81292 m .15878 .79435 L .15612 .78842 L p .707 .577 .707 r
F P
0 g
s
.16224 .62651 m .16758 .68239 L .16047 .69027 L p .707 .577 .707 r
F P
0 g
s
.15612 .78842 m .15942 .80698 L .16208 .81292 L p .707 .577 .707 r
F P
0 g
s
.16527 .76421 m .15813 .72714 L .16531 .71975 L p .707 .577 .707 r
F P
0 g
s
.16758 .68239 m .16224 .62651 L .17859 .61866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16531 .71975 m .17245 .75682 L .16527 .76421 L p .707 .577 .707 r
F P
0 g
s
.64664 .27712 m .62784 .77662 L .61009 .76429 L p .707 .577 .707 r
F P
0 g
s
.61009 .76429 m .62888 .2648 L .64664 .27712 L p .707 .577 .707 r
F P
0 g
s
.34282 .60644 m .34815 .66232 L .32723 .65861 L p .707 .577 .707 r
F P
0 g
s
.32723 .65861 m .3219 .60274 L .34282 .60644 L p .707 .577 .707 r
F P
0 g
s
.15942 .80698 m .15612 .78842 L .16328 .78096 L p .707 .577 .707 r
F P
0 g
s
.17859 .61866 m .18392 .67454 L .16758 .68239 L p .707 .577 .707 r
F P
0 g
s
.16328 .78096 m .16658 .79952 L .15942 .80698 L p .707 .577 .707 r
F P
0 g
s
.35426 .76199 m .37305 .2625 L .39616 .25236 L p .707 .577 .707 r
F P
0 g
s
.37305 .2625 m .35426 .76199 L .34426 .77406 L p .707 .577 .707 r
F P
0 g
s
.17245 .75682 m .16531 .71975 L .18159 .71141 L p .707 .577 .707 r
F P
0 g
s
.18392 .67454 m .17859 .61866 L .20258 .61161 L p .707 .577 .707 r
F P
0 g
s
.18159 .71141 m .18873 .74848 L .17245 .75682 L p .707 .577 .707 r
F P
0 g
s
.33021 .71992 m .32307 .68284 L .3436 .68376 L p .707 .577 .707 r
F P
0 g
s
.3219 .60274 m .32723 .65861 L .29992 .65727 L p .707 .577 .707 r
F P
0 g
s
.29992 .65727 m .29458 .60139 L .3219 .60274 L p .707 .577 .707 r
F P
0 g
s
.20258 .61161 m .20791 .66749 L .18392 .67454 L p .707 .577 .707 r
F P
0 g
s
.62888 .2648 m .61009 .76429 L .58039 .75368 L p .707 .577 .707 r
F P
0 g
s
.58039 .75368 m .59919 .25419 L .62888 .2648 L p .707 .577 .707 r
F P
0 g
s
.16658 .79952 m .16328 .78096 L .17957 .77269 L p .707 .577 .707 r
F P
0 g
s
.20791 .66749 m .20258 .61161 L .23185 .60605 L p .707 .577 .707 r
F P
0 g
s
.17957 .77269 m .18287 .79125 L .16658 .79952 L p .707 .577 .707 r
F P
0 g
s
.18873 .74848 m .18159 .71141 L .20537 .70294 L p .707 .577 .707 r
F P
0 g
s
.32471 .76459 m .32141 .74603 L .34201 .74736 L p .707 .577 .707 r
F P
0 g
s
.29458 .60139 m .29992 .65727 L .26889 .65841 L p .707 .577 .707 r
F P
0 g
s
.26889 .65841 m .26356 .60253 L .29458 .60139 L p .707 .577 .707 r
F P
0 g
s
.39616 .25236 m .37736 .75185 L .35426 .76199 L p .707 .577 .707 r
F P
0 g
s
.37736 .75185 m .39616 .25236 L .4301 .24515 L p .707 .577 .707 r
F P
0 g
s
.32307 .68284 m .33021 .71992 L .30335 .72167 L p .707 .577 .707 r
F P
0 g
s
.30335 .72167 m .29621 .6846 L .32307 .68284 L p .707 .577 .707 r
F P
0 g
s
.23719 .66193 m .23185 .60605 L .26356 .60253 L p .707 .577 .707 r
F P
0 g
s
.23185 .60605 m .23719 .66193 L .20791 .66749 L p .707 .577 .707 r
F P
0 g
s
.20537 .70294 m .21251 .74001 L .18873 .74848 L p .707 .577 .707 r
F P
0 g
s
.26356 .60253 m .26889 .65841 L .23719 .66193 L p .707 .577 .707 r
F P
0 g
s
.73527 .65719 m .72993 .60131 L .69891 .60245 L p .707 .577 .707 r
F P
0 g
s
.72993 .60131 m .73527 .65719 L .76697 .65367 L p .707 .577 .707 r
F P
0 g
s
.76697 .65367 m .76164 .59779 L .72993 .60131 L p .707 .577 .707 r
F P
0 g
s
.76164 .59779 m .76697 .65367 L .79625 .64811 L p .707 .577 .707 r
F P
0 g
s
.79625 .64811 m .79091 .59223 L .76164 .59779 L p .707 .577 .707 r
F P
0 g
s
.18287 .79125 m .17957 .77269 L .20339 .76443 L p .707 .577 .707 r
F P
0 g
s
.70424 .65833 m .69891 .60245 L .67159 .6011 L p .707 .577 .707 r
F P
0 g
s
.69891 .60245 m .70424 .65833 L .73527 .65719 L p .707 .577 .707 r
F P
0 g
s
.21251 .74001 m .20537 .70294 L .23433 .69516 L p .707 .577 .707 r
F P
0 g
s
.20339 .76443 m .20669 .78299 L .18287 .79125 L p .707 .577 .707 r
F P
0 g
s
.59919 .25419 m .58039 .75368 L .54166 .74581 L p .707 .577 .707 r
F P
0 g
s
.54166 .74581 m .56045 .24632 L .59919 .25419 L p .707 .577 .707 r
F P
0 g
s
.29621 .6846 m .30335 .72167 L .27277 .72591 L p .707 .577 .707 r
F P
0 g
s
.27277 .72591 m .26563 .68884 L .29621 .6846 L p .707 .577 .707 r
F P
0 g
s
.79091 .59223 m .79625 .64811 L .82023 .64106 L p .707 .577 .707 r
F P
0 g
s
.82023 .64106 m .8149 .58518 L .79091 .59223 L p .707 .577 .707 r
F P
0 g
s
.32141 .74603 m .32471 .76459 L .29776 .76588 L p .707 .577 .707 r
F P
0 g
s
.29776 .76588 m .29446 .74731 L .32141 .74603 L p .707 .577 .707 r
F P
0 g
s
.23433 .69516 m .24146 .73223 L .21251 .74001 L p .707 .577 .707 r
F P
0 g
s
.73825 .71067 m .73111 .6736 L .70053 .67784 L p .707 .577 .707 r
F P
0 g
s
.73111 .6736 m .73825 .71067 L .76955 .70435 L p .707 .577 .707 r
F P
0 g
s
.76955 .70435 m .76241 .66728 L .73111 .6736 L p .707 .577 .707 r
F P
0 g
s
.24146 .73223 m .23433 .69516 L .26563 .68884 L p .707 .577 .707 r
F P
0 g
s
.67159 .6011 m .67693 .65698 L .70424 .65833 L p .707 .577 .707 r
F P
0 g
s
.76241 .66728 m .76955 .70435 L .79851 .69658 L p .707 .577 .707 r
F P
0 g
s
.79851 .69658 m .79137 .6595 L .76241 .66728 L p .707 .577 .707 r
F P
0 g
s
.26563 .68884 m .27277 .72591 L .24146 .73223 L p .707 .577 .707 r
F P
0 g
s
.41131 .74464 m .4301 .24515 L .47156 .24157 L p .707 .577 .707 r
F P
0 g
s
.4301 .24515 m .41131 .74464 L .37736 .75185 L p .707 .577 .707 r
F P
0 g
s
.67693 .65698 m .67159 .6011 L .65067 .5974 L p .707 .577 .707 r
F P
0 g
s
.20669 .78299 m .20339 .76443 L .23241 .75699 L p .707 .577 .707 r
F P
0 g
s
.70053 .67784 m .70767 .71492 L .73825 .71067 L p .707 .577 .707 r
F P
0 g
s
.70767 .71492 m .70053 .67784 L .67366 .6796 L p .707 .577 .707 r
F P
0 g
s
.23241 .75699 m .23571 .77555 L .20669 .78299 L p .707 .577 .707 r
F P
0 g
s
.29446 .74731 m .29776 .76588 L .26709 .76965 L p .707 .577 .707 r
F P
0 g
s
.26709 .76965 m .26379 .75109 L .29446 .74731 L p .707 .577 .707 r
F P
0 g
s
.79137 .6595 m .79851 .69658 L .82229 .6881 L p .707 .577 .707 r
F P
0 g
s
.82229 .6881 m .81515 .65103 L .79137 .6595 L p .707 .577 .707 r
F P
0 g
s
.8149 .58518 m .82023 .64106 L .83658 .63321 L p .707 .577 .707 r
F P
0 g
s
.83658 .63321 m .83125 .57733 L .8149 .58518 L p .707 .577 .707 r
F P
0 g
s
.56045 .24632 m .54166 .74581 L .49768 .74147 L p .707 .577 .707 r
F P
0 g
s
.49768 .74147 m .51648 .24197 L .56045 .24632 L p .707 .577 .707 r
F P
0 g
s
.67366 .6796 m .6808 .71667 L .70767 .71492 L p .707 .577 .707 r
F P
0 g
s
.73275 .74983 m .72945 .73127 L .69878 .73505 L p .707 .577 .707 r
F P
0 g
s
.72945 .73127 m .73275 .74983 L .76413 .74394 L p .707 .577 .707 r
F P
0 g
s
.76413 .74394 m .76083 .72537 L .72945 .73127 L p .707 .577 .707 r
F P
0 g
s
.65067 .5974 m .656 .65327 L .67693 .65698 L p .707 .577 .707 r
F P
0 g
s
.76083 .72537 m .76413 .74394 L .79315 .73649 L p .707 .577 .707 r
F P
0 g
s
.79315 .73649 m .78985 .71793 L .76083 .72537 L p .707 .577 .707 r
F P
0 g
s
.23571 .77555 m .23241 .75699 L .26379 .75109 L p .707 .577 .707 r
F P
0 g
s
.26379 .75109 m .26709 .76965 L .23571 .77555 L p .707 .577 .707 r
F P
0 g
s
.45277 .74106 m .47156 .24157 L .51648 .24197 L p .707 .577 .707 r
F P
0 g
s
.47156 .24157 m .45277 .74106 L .41131 .74464 L p .707 .577 .707 r
F P
0 g
s
.69878 .73505 m .70208 .75361 L .73275 .74983 L p .707 .577 .707 r
F P
0 g
s
.51648 .24197 m .49768 .74147 L .45277 .74106 L p .707 .577 .707 r
F P
0 g
s
.70208 .75361 m .69878 .73505 L .67183 .73633 L p .707 .577 .707 r
F P
0 g
s
.6808 .71667 m .67366 .6796 L .65314 .67868 L p .707 .577 .707 r
F P
0 g
s
.656 .65327 m .65067 .5974 L .63818 .59169 L p .707 .577 .707 r
F P
0 g
s
.67183 .73633 m .67513 .75489 L .70208 .75361 L p .707 .577 .707 r
F P
0 g
s
.78985 .71793 m .79315 .73649 L .81697 .72823 L p .707 .577 .707 r
F P
0 g
s
.81697 .72823 m .81367 .70967 L .78985 .71793 L p .707 .577 .707 r
F P
0 g
s
.81515 .65103 m .82229 .6881 L .83857 .67976 L p .707 .577 .707 r
F P
0 g
s
.83857 .67976 m .83143 .64269 L .81515 .65103 L p .707 .577 .707 r
F P
0 g
s
.65314 .67868 m .66028 .71576 L .6808 .71667 L p .707 .577 .707 r
F P
0 g
s
.83125 .57733 m .83658 .63321 L .84369 .62533 L p .707 .577 .707 r
F P
0 g
s
.84369 .62533 m .83835 .56945 L .83125 .57733 L p .707 .577 .707 r
F P
0 g
s
.63818 .59169 m .64351 .64757 L .656 .65327 L p .707 .577 .707 r
F P
0 g
s
.67513 .75489 m .67183 .73633 L .65123 .735 L p .707 .577 .707 r
F P
0 g
s
.65123 .735 m .65453 .75356 L .67513 .75489 L p .707 .577 .707 r
F P
0 g
s
.81367 .70967 m .81697 .72823 L .83326 .71997 L p .707 .577 .707 r
F P
0 g
s
.83326 .71997 m .82996 .7014 L .81367 .70967 L p .707 .577 .707 r
F P
0 g
s
.66028 .71576 m .65314 .67868 L .64097 .6752 L p .707 .577 .707 r
F P
0 g
s
.64351 .64757 m .63818 .59169 L .63535 .58455 L p .707 .577 .707 r
F P
0 g
s
.64097 .6752 m .64811 .71227 L .66028 .71576 L p .707 .577 .707 r
F P
0 g
s
.83143 .64269 m .83857 .67976 L .84574 .67237 L p .707 .577 .707 r
F P
0 g
s
.84574 .67237 m .8386 .6353 L .83143 .64269 L p .707 .577 .707 r
F P
0 g
s
.65453 .75356 m .65123 .735 L .639 .73118 L p .707 .577 .707 r
F P
0 g
s
.639 .73118 m .6423 .74974 L .65453 .75356 L p .707 .577 .707 r
F P
0 g
s
.83835 .56945 m .84369 .62533 L .84086 .61818 L p .707 .577 .707 r
F P
0 g
s
.84086 .61818 m .83552 .5623 L .83835 .56945 L p .707 .577 .707 r
F P
0 g
s
.63535 .58455 m .64068 .64043 L .64351 .64757 L p .707 .577 .707 r
F P
0 g
s
.82996 .7014 m .83326 .71997 L .84042 .7125 L p .707 .577 .707 r
F P
0 g
s
.84042 .7125 m .83712 .69394 L .82996 .7014 L p .707 .577 .707 r
F P
0 g
s
.64811 .71227 m .64097 .6752 L .63835 .66948 L p .707 .577 .707 r
F P
0 g
s
.63835 .66948 m .64549 .70655 L .64811 .71227 L p .707 .577 .707 r
F P
0 g
s
.64068 .64043 m .63535 .58455 L .64246 .57667 L p .707 .577 .707 r
F P
0 g
s
.8386 .6353 m .84574 .67237 L .84312 .66665 L p .707 .577 .707 r
F P
0 g
s
.84312 .66665 m .83598 .62958 L .8386 .6353 L p .707 .577 .707 r
F P
0 g
s
.6423 .74974 m .639 .73118 L .63633 .72524 L p .707 .577 .707 r
F P
0 g
s
.63633 .72524 m .63963 .7438 L .6423 .74974 L p .707 .577 .707 r
F P
0 g
s
.83552 .5623 m .84086 .61818 L .82837 .61248 L p .707 .577 .707 r
F P
0 g
s
.82837 .61248 m .82304 .5566 L .83552 .5623 L p .707 .577 .707 r
F P
0 g
s
.64246 .57667 m .64779 .63254 L .64068 .64043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83712 .69394 m .84042 .7125 L .83776 .70657 L p .707 .577 .707 r
F P
0 g
s
.83776 .70657 m .83446 .68801 L .83712 .69394 L p .707 .577 .707 r
F P
0 g
s
.64549 .70655 m .63835 .66948 L .64552 .66209 L p .707 .577 .707 r
F P
0 g
s
.39226 .61499 m .38692 .55912 L .3559 .56026 L p .707 .577 .707 r
F P
0 g
s
.38692 .55912 m .39226 .61499 L .42396 .61147 L p .707 .577 .707 r
F P
0 g
s
.42396 .61147 m .41863 .55559 L .38692 .55912 L p .707 .577 .707 r
F P
0 g
s
.41863 .55559 m .42396 .61147 L .45324 .60591 L p .707 .577 .707 r
F P
0 g
s
.45324 .60591 m .4479 .55003 L .41863 .55559 L p .707 .577 .707 r
F P
0 g
s
.64552 .66209 m .65266 .69916 L .64549 .70655 L p .707 .577 .707 r
F P
0 g
s
.64779 .63254 m .64246 .57667 L .6588 .56882 L p .707 .577 .707 r
F P
0 g
s
.36123 .61614 m .3559 .56026 L .32858 .55891 L p .707 .577 .707 r
F P
0 g
s
.3559 .56026 m .36123 .61614 L .39226 .61499 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83598 .62958 m .84312 .66665 L .83095 .66317 L p .707 .577 .707 r
F P
0 g
s
.83095 .66317 m .82381 .62609 L .83598 .62958 L p .707 .577 .707 r
F P
0 g
s
.4479 .55003 m .45324 .60591 L .47722 .59886 L p .707 .577 .707 r
F P
0 g
s
.47722 .59886 m .47189 .54299 L .4479 .55003 L p .707 .577 .707 r
F P
0 g
s
.63963 .7438 m .63633 .72524 L .6435 .71778 L p .707 .577 .707 r
F P
0 g
s
.82304 .5566 m .82837 .61248 L .80744 .60877 L p .707 .577 .707 r
F P
0 g
s
.80744 .60877 m .80211 .55289 L .82304 .5566 L p .707 .577 .707 r
F P
0 g
s
.6435 .71778 m .6468 .73634 L .63963 .7438 L p .707 .577 .707 r
F P
0 g
s
.6588 .56882 m .66414 .62469 L .64779 .63254 L p .707 .577 .707 r
F P
0 g
s
.32858 .55891 m .33392 .61479 L .36123 .61614 L p .707 .577 .707 r
F P
0 g
s
.39524 .6763 m .3881 .63922 L .35752 .64347 L p .707 .577 .707 r
F P
0 g
s
.3881 .63922 m .39524 .6763 L .42654 .66998 L p .707 .577 .707 r
F P
0 g
s
.42654 .66998 m .4194 .63291 L .3881 .63922 L p .707 .577 .707 r
F P
0 g
s
.4194 .63291 m .42654 .66998 L .4555 .6622 L p .707 .577 .707 r
F P
0 g
s
.4555 .6622 m .44836 .62513 L .4194 .63291 L p .707 .577 .707 r
F P
0 g
s
.33392 .61479 m .32858 .55891 L .30766 .5552 L p .707 .577 .707 r
F P
0 g
s
.83446 .68801 m .83776 .70657 L .82553 .70275 L p .707 .577 .707 r
F P
0 g
s
.82553 .70275 m .82223 .68419 L .83446 .68801 L p .707 .577 .707 r
F P
0 g
s
.35752 .64347 m .36466 .68054 L .39524 .6763 L p .707 .577 .707 r
F P
0 g
s
.65266 .69916 m .64552 .66209 L .6618 .65375 L p .707 .577 .707 r
F P
0 g
s
.36466 .68054 m .35752 .64347 L .33065 .64522 L p .707 .577 .707 r
F P
0 g
s
.47189 .54299 m .47722 .59886 L .49357 .59101 L p .707 .577 .707 r
F P
0 g
s
.49357 .59101 m .48824 .53514 L .47189 .54299 L p .707 .577 .707 r
F P
0 g
s
.66414 .62469 m .6588 .56882 L .68279 .56177 L p .707 .577 .707 r
F P
0 g
s
.44836 .62513 m .4555 .6622 L .47928 .65373 L p .707 .577 .707 r
F P
0 g
s
.47928 .65373 m .47214 .61665 L .44836 .62513 L p .707 .577 .707 r
F P
0 g
s
.6618 .65375 m .66894 .69082 L .65266 .69916 L p .707 .577 .707 r
F P
0 g
s
.33065 .64522 m .33779 .68229 L .36466 .68054 L p .707 .577 .707 r
F P
0 g
s
.30766 .5552 m .31299 .61108 L .33392 .61479 L p .707 .577 .707 r
F P
0 g
s
.82381 .62609 m .83095 .66317 L .81043 .66226 L p .707 .577 .707 r
F P
0 g
s
.81043 .66226 m .80329 .62518 L .82381 .62609 L p .707 .577 .707 r
F P
0 g
s
.38974 .72097 m .38644 .70241 L .35577 .70619 L p .707 .577 .707 r
F P
0 g
s
.38644 .70241 m .38974 .72097 L .42112 .71508 L p .707 .577 .707 r
F P
0 g
s
.42112 .71508 m .41782 .69651 L .38644 .70241 L p .707 .577 .707 r
F P
0 g
s
.41782 .69651 m .42112 .71508 L .45014 .70763 L p .707 .577 .707 r
F P
0 g
s
.45014 .70763 m .44684 .68907 L .41782 .69651 L p .707 .577 .707 r
F P
0 g
s
.80211 .55289 m .80744 .60877 L .78013 .60742 L p .707 .577 .707 r
F P
0 g
s
.78013 .60742 m .7748 .55154 L .80211 .55289 L p .707 .577 .707 r
F P
0 g
s
.35577 .70619 m .35907 .72475 L .38974 .72097 L p .707 .577 .707 r
F P
0 g
s
.6468 .73634 m .6435 .71778 L .65979 .70951 L p .707 .577 .707 r
F P
0 g
s
.68279 .56177 m .68812 .61765 L .66414 .62469 L p .707 .577 .707 r
F P
0 g
s
.33779 .68229 m .33065 .64522 L .31013 .64431 L p .707 .577 .707 r
F P
0 g
s
.31299 .61108 m .30766 .5552 L .29517 .5495 L p .707 .577 .707 r
F P
0 g
s
.35907 .72475 m .35577 .70619 L .32882 .70747 L p .707 .577 .707 r
F P
0 g
s
.65979 .70951 m .66309 .72807 L .6468 .73634 L p .707 .577 .707 r
F P
0 g
s
.32882 .70747 m .33212 .72603 L .35907 .72475 L p .707 .577 .707 r
F P
0 g
s
.44684 .68907 m .45014 .70763 L .47396 .69937 L p .707 .577 .707 r
F P
0 g
s
.47396 .69937 m .47066 .68081 L .44684 .68907 L p .707 .577 .707 r
F P
0 g
s
.68812 .61765 m .68279 .56177 L .71207 .55621 L p .707 .577 .707 r
F P
0 g
s
.47214 .61665 m .47928 .65373 L .49556 .64539 L p .707 .577 .707 r
F P
0 g
s
.49556 .64539 m .48842 .60831 L .47214 .61665 L p .707 .577 .707 r
F P
0 g
s
.31013 .64431 m .31727 .68138 L .33779 .68229 L p .707 .577 .707 r
F P
0 g
s
.82223 .68419 m .82553 .70275 L .80493 .70141 L p .707 .577 .707 r
F P
0 g
s
.80493 .70141 m .80163 .68285 L .82223 .68419 L p .707 .577 .707 r
F P
0 g
s
.66894 .69082 m .6618 .65375 L .68558 .64527 L p .707 .577 .707 r
F P
0 g
s
.7748 .55154 m .78013 .60742 L .74911 .60856 L p .707 .577 .707 r
F P
0 g
s
.74911 .60856 m .74377 .55269 L .7748 .55154 L p .707 .577 .707 r
F P
0 g
s
.48824 .53514 m .49357 .59101 L .50068 .58313 L p .707 .577 .707 r
F P
0 g
s
.50068 .58313 m .49534 .52725 L .48824 .53514 L p .707 .577 .707 r
F P
0 g
s
.29517 .5495 m .3005 .60538 L .31299 .61108 L p .707 .577 .707 r
F P
0 g
s
.80329 .62518 m .81043 .66226 L .78356 .66401 L p .707 .577 .707 r
F P
0 g
s
.78356 .66401 m .77642 .62693 L .80329 .62518 L p .707 .577 .707 r
F P
0 g
s
.68558 .64527 m .69272 .68235 L .66894 .69082 L p .707 .577 .707 r
F P
0 g
s
.7174 .61209 m .71207 .55621 L .74377 .55269 L p .707 .577 .707 r
F P
0 g
s
.71207 .55621 m .7174 .61209 L .68812 .61765 L p .707 .577 .707 r
F P
0 g
s
.33212 .72603 m .32882 .70747 L .30822 .70614 L p .707 .577 .707 r
F P
0 g
s
.74377 .55269 m .74911 .60856 L .7174 .61209 L p .707 .577 .707 r
F P
0 g
s
.30822 .70614 m .31152 .7247 L .33212 .72603 L p .707 .577 .707 r
F P
0 g
s
.31727 .68138 m .31013 .64431 L .29796 .64082 L p .707 .577 .707 r
F P
0 g
s
.47066 .68081 m .47396 .69937 L .49025 .69111 L p .707 .577 .707 r
F P
0 g
s
.49025 .69111 m .48695 .67255 L .47066 .68081 L p .707 .577 .707 r
F P
0 g
s
.66309 .72807 m .65979 .70951 L .68361 .70125 L p .707 .577 .707 r
F P
0 g
s
.69272 .68235 m .68558 .64527 L .71454 .6375 L p .707 .577 .707 r
F P
0 g
s
.68361 .70125 m .68691 .71981 L .66309 .72807 L p .707 .577 .707 r
F P
0 g
s
.3005 .60538 m .29517 .5495 L .29234 .54235 L p .707 .577 .707 r
F P
0 g
s
.29796 .64082 m .3051 .67789 L .31727 .68138 L p .707 .577 .707 r
F P
0 g
s
.80163 .68285 m .80493 .70141 L .77798 .7027 L p .707 .577 .707 r
F P
0 g
s
.77798 .7027 m .77467 .68414 L .80163 .68285 L p .707 .577 .707 r
F P
0 g
s
.77642 .62693 m .78356 .66401 L .75298 .66825 L p .707 .577 .707 r
F P
0 g
s
.75298 .66825 m .74584 .63118 L .77642 .62693 L p .707 .577 .707 r
F P
0 g
s
.48842 .60831 m .49556 .64539 L .50273 .638 L p .707 .577 .707 r
F P
0 g
s
.50273 .638 m .49559 .60092 L .48842 .60831 L p .707 .577 .707 r
F P
0 g
s
.71454 .6375 m .72168 .67457 L .69272 .68235 L p .707 .577 .707 r
F P
0 g
s
.72168 .67457 m .71454 .6375 L .74584 .63118 L p .707 .577 .707 r
F P
0 g
s
.74584 .63118 m .75298 .66825 L .72168 .67457 L p .707 .577 .707 r
F P
0 g
s
.31152 .7247 m .30822 .70614 L .29599 .70232 L p .707 .577 .707 r
F P
0 g
s
.49534 .52725 m .50068 .58313 L .49785 .57599 L p .707 .577 .707 r
F P
0 g
s
.49785 .57599 m .49251 .52011 L .49534 .52725 L p .707 .577 .707 r
F P
0 g
s
.29234 .54235 m .29767 .59823 L .3005 .60538 L p .707 .577 .707 r
F P
0 g
s
.68691 .71981 m .68361 .70125 L .71263 .69381 L p .707 .577 .707 r
F P
0 g
s
.29599 .70232 m .29929 .72088 L .31152 .7247 L p .707 .577 .707 r
F P
0 g
s
.71263 .69381 m .71593 .71237 L .68691 .71981 L p .707 .577 .707 r
F P
0 g
s
.77467 .68414 m .77798 .7027 L .74731 .70647 L p .707 .577 .707 r
F P
0 g
s
.74731 .70647 m .74401 .68791 L .77467 .68414 L p .707 .577 .707 r
F P
0 g
s
.48695 .67255 m .49025 .69111 L .49741 .68364 L p .707 .577 .707 r
F P
0 g
s
.49741 .68364 m .49411 .66508 L .48695 .67255 L p .707 .577 .707 r
F P
0 g
s
.3051 .67789 m .29796 .64082 L .29534 .6351 L p .707 .577 .707 r
F P
0 g
s
.71593 .71237 m .71263 .69381 L .74401 .68791 L p .707 .577 .707 r
F P
0 g
s
.74401 .68791 m .74731 .70647 L .71593 .71237 L p .707 .577 .707 r
F P
0 g
s
.29767 .59823 m .29234 .54235 L .29945 .53447 L p .707 .577 .707 r
F P
0 g
s
.29534 .6351 m .30248 .67218 L .3051 .67789 L p .707 .577 .707 r
F P
0 g
s
.49559 .60092 m .50273 .638 L .50011 .63228 L p .707 .577 .707 r
F P
0 g
s
.50011 .63228 m .49297 .5952 L .49559 .60092 L p .707 .577 .707 r
F P
0 g
s
.29929 .72088 m .29599 .70232 L .29332 .69638 L p .707 .577 .707 r
F P
0 g
s
.49251 .52011 m .49785 .57599 L .48536 .57028 L p .707 .577 .707 r
F P
0 g
s
.48536 .57028 m .48003 .51441 L .49251 .52011 L p .707 .577 .707 r
F P
0 g
s
.29945 .53447 m .30478 .59035 L .29767 .59823 L p .707 .577 .707 r
F P
0 g
s
.29332 .69638 m .29662 .71495 L .29929 .72088 L p .707 .577 .707 r
F P
0 g
s
.49411 .66508 m .49741 .68364 L .49475 .67771 L p .707 .577 .707 r
F P
0 g
s
.49475 .67771 m .49145 .65915 L .49411 .66508 L p .707 .577 .707 r
F P
0 g
s
.30248 .67218 m .29534 .6351 L .30251 .62771 L p .707 .577 .707 r
F P
0 g
s
.30478 .59035 m .29945 .53447 L .31579 .52662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30251 .62771 m .30965 .66478 L .30248 .67218 L p .707 .577 .707 r
F P
0 g
s
.49297 .5952 m .50011 .63228 L .48794 .62879 L p .707 .577 .707 r
F P
0 g
s
.48794 .62879 m .4808 .59172 L .49297 .5952 L p .707 .577 .707 r
F P
0 g
s
.48003 .51441 m .48536 .57028 L .46443 .56658 L p .707 .577 .707 r
F P
0 g
s
.46443 .56658 m .4591 .5107 L .48003 .51441 L p .707 .577 .707 r
F P
0 g
s
.29662 .71495 m .29332 .69638 L .30049 .68892 L p .707 .577 .707 r
F P
0 g
s
.31579 .52662 m .32113 .5825 L .30478 .59035 L p .707 .577 .707 r
F P
0 g
s
.30049 .68892 m .30379 .70748 L .29662 .71495 L p .707 .577 .707 r
F P
0 g
s
.49145 .65915 m .49475 .67771 L .48252 .67389 L p .707 .577 .707 r
F P
0 g
s
.48252 .67389 m .47922 .65533 L .49145 .65915 L p .707 .577 .707 r
F P
0 g
s
.30965 .66478 m .30251 .62771 L .31879 .61937 L p .707 .577 .707 r
F P
0 g
s
.32113 .5825 m .31579 .52662 L .33978 .51957 L p .707 .577 .707 r
F P
0 g
s
.31879 .61937 m .32593 .65644 L .30965 .66478 L p .707 .577 .707 r
F P
0 g
s
.4808 .59172 m .48794 .62879 L .46742 .62788 L p .707 .577 .707 r
F P
0 g
s
.46742 .62788 m .46028 .59081 L .4808 .59172 L p .707 .577 .707 r
F P
0 g
s
.4591 .5107 m .46443 .56658 L .43712 .56523 L p .707 .577 .707 r
F P
0 g
s
.43712 .56523 m .43179 .50935 L .4591 .5107 L p .707 .577 .707 r
F P
0 g
s
.33978 .51957 m .34511 .57545 L .32113 .5825 L p .707 .577 .707 r
F P
0 g
s
.30379 .70748 m .30049 .68892 L .31677 .68065 L p .707 .577 .707 r
F P
0 g
s
.34511 .57545 m .33978 .51957 L .36906 .51401 L p .707 .577 .707 r
F P
0 g
s
.31677 .68065 m .32008 .69921 L .30379 .70748 L p .707 .577 .707 r
F P
0 g
s
.32593 .65644 m .31879 .61937 L .34257 .6109 L p .707 .577 .707 r
F P
0 g
s
.47922 .65533 m .48252 .67389 L .46192 .67256 L p .707 .577 .707 r
F P
0 g
s
.46192 .67256 m .45862 .65399 L .47922 .65533 L p .707 .577 .707 r
F P
0 g
s
.43179 .50935 m .43712 .56523 L .40609 .56637 L p .707 .577 .707 r
F P
0 g
s
.40609 .56637 m .40076 .51049 L .43179 .50935 L p .707 .577 .707 r
F P
0 g
s
.46028 .59081 m .46742 .62788 L .44055 .62963 L p .707 .577 .707 r
F P
0 g
s
.44055 .62963 m .43341 .59256 L .46028 .59081 L p .707 .577 .707 r
F P
0 g
s
.37439 .56989 m .36906 .51401 L .40076 .51049 L p .707 .577 .707 r
F P
0 g
s
.36906 .51401 m .37439 .56989 L .34511 .57545 L p .707 .577 .707 r
F P
0 g
s
.34257 .6109 m .34971 .64797 L .32593 .65644 L p .707 .577 .707 r
F P
0 g
s
.40076 .51049 m .40609 .56637 L .37439 .56989 L p .707 .577 .707 r
F P
0 g
s
.32008 .69921 m .31677 .68065 L .3406 .67239 L p .707 .577 .707 r
F P
0 g
s
.34971 .64797 m .34257 .6109 L .37153 .60312 L p .707 .577 .707 r
F P
0 g
s
.3406 .67239 m .3439 .69095 L .32008 .69921 L p .707 .577 .707 r
F P
0 g
s
.43341 .59256 m .44055 .62963 L .40997 .63387 L p .707 .577 .707 r
F P
0 g
s
.40997 .63387 m .40283 .5968 L .43341 .59256 L p .707 .577 .707 r
F P
0 g
s
.45862 .65399 m .46192 .67256 L .43496 .67384 L p .707 .577 .707 r
F P
0 g
s
.43496 .67384 m .43166 .65528 L .45862 .65399 L p .707 .577 .707 r
F P
0 g
s
.37153 .60312 m .37867 .64019 L .34971 .64797 L p .707 .577 .707 r
F P
0 g
s
.37867 .64019 m .37153 .60312 L .40283 .5968 L p .707 .577 .707 r
F P
0 g
s
.40283 .5968 m .40997 .63387 L .37867 .64019 L p .707 .577 .707 r
F P
0 g
s
.3439 .69095 m .3406 .67239 L .36962 .66495 L p .707 .577 .707 r
F P
0 g
s
.36962 .66495 m .37292 .68351 L .3439 .69095 L p .707 .577 .707 r
F P
0 g
s
.43166 .65528 m .43496 .67384 L .4043 .67761 L p .707 .577 .707 r
F P
0 g
s
.4043 .67761 m .401 .65905 L .43166 .65528 L p .707 .577 .707 r
F P
0 g
s
.37292 .68351 m .36962 .66495 L .401 .65905 L p .707 .577 .707 r
F P
0 g
s
.401 .65905 m .4043 .67761 L .37292 .68351 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00Ngoo001`Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006ioo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00K7oo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06moo`00JWoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00JGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JWoo
001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Qoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008006Ioo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Aoo`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Ioo`00Ggoo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001HOol2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001FOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol8000mOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8001Uoo`T000AJEP04001JEUYFFUH6000gOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00D0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;goo001COol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
200015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20007Ool400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF20000UYF00L005YFFUIJEP00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF200025YF00<0
05YFFUH01EYF00<005YFFUH015YF1@000UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEPD0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF000015YF00<005YF00000`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005Aoo`03001JEP0000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Ao
o`04001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
4`0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH0000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00AWoo40000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003ioo`P000AJ
EP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00>7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEP00
00<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90008FUH70003FUH00`00FUIJEP02
000]Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH500000eYF0000000]Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0035oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP06001JEUYFFUH005YF
10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;Goo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH600000eYF001JEP03FUH00`00FUH0000]Ool002ioo`05001J
EUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP/0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH0
0`00FUIJEP0500000eYF0000000^Ool002eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPP000IJEP04001JEUYFFUH4000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00L005YF001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00FUH^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo
001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003
FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP03FUH40009FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00@005YFFUIJEP<00003FUH0
05YF00QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPH0009JEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEPH000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH015YF2@000eYF00<005YFFUH01@0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000=JEP05001JEUYFFUH00002FUH01000FUIJEP001eYF00<005YFFUH01UYF1`0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH01@00FUIJEUYF
00000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEQ400003FUH007oo02aoo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF1P001UYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH015YF
1P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000/
Ool002eoo`03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEPL000QJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002eo
o`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF009JEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUH0000/Ool002eoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEP0000800003FUH005YF00QJEP03001JEUYF
00AJEPH000YJEP03001JEUYF00=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEP<0
00=JEPH000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP8002eoo`00;Goo00<0
05YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
100015YF00<005YFFUH01eYF00<005YFFUH01@000eYF00<005YFFUH02EYF00<005YFFUH00`000eYF
00<005YF00000P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEP00008000IJEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002eoo`05001JEP00FUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH900000eYF001JEP05FUH00`00FUIJEP04FUH500000eYF
000000030002FUH00`00FUIJEP09FUH300000eYF001JEP04FUH01000FUH000002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF009JEP<00003
FUH005YF00MJEP03001JEUYF00EJEQD0031oo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00001P0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01000
15YF00<005YF000010000UYF00<005YFFUH01UYF0`0015YF00<005YFFUH00eYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001J
EP00008000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00
008002moo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF100000=JEP00FUH01EYF00<005YF000010000UYF
00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00003FUH40007FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030006FUH00`00FUIJ
EP06FUH20004FUH00`00FUH000030002FUH01000FUIJEP001UYF00<005YFFUH00`000eYF00<005YF
FUH00`0015YF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800006FUH005YFFUH005YF0P000eYF00<005YFFUH01EYF1@00
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo0P00
00=JEP00FUH015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF00<005YF0000
15YF0`001EYF00@005YFFUH000IJEP03001JEUYF00=JEPH000MJEP03001JEUYF00=JEP<000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP8000EJEP03
001JEUYF009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool0031oo`<000AJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0002FUH01000FUIJEP001EYF00@005YFFUH000AJEPP000AJEP03001JEUYF
00IJEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJEP02FUHC0002
FUH00`00Oomoo`0/Ool003=oo`<00005FUH00000FUH00008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUH000002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000AJEP00FUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEP/000aoo`H002ioo`00
=Goo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEPP0
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80009JEP8000EJEP03001JEUYF
00IJEP03001JEUYF00@0009JEP@000ioo`<0009JEP04001JEUYF000^Ool003=oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP@000MJEP03001JEUYF00AJ
EPX0011oo`800003FUH005YF00=JEP03001JEP0002ioo`00<Goo0`001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF1@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH020000goo0`00
3Woo0P000eYF00<005YFFUH00UYF0P00;goo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH010002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH015YF1P0027oo1@002Woo0`001EYF00<005YF
FUH00UYF00<007ooOol0;Woo000]Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40005FUH01000FUIJEUYF0P0000=JEP00FUH00`0027oo1@001Woo100000=JEP00FUH01UYF
00@005YFFUH0035oo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEPL000IJEQ@000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH01000FUH000000eYF
00<005YFFUH00P0027oo2`001EYF00<005YFFUH01EYF0`00<Woo000/Ool01@00FUIJEUYF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH40005FUH01000FUH005YF1Goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00=7oo
000/Ool01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEP04001JEP000003FUH00`00FUIJEP03FUH01@00FUIJEP00Ool010000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00=Woo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF000005YF018000IJEP03001JEUYF
00MJEP03001JEUYF00AJEP<003Yoo`00;Goo00@005YFFUH000AJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUHE0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
00000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04000mOol002eoo`04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP001UYF00<005YFFUH015YF2@00
00=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP0000000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH015YF1@00@Goo000]Ool01000FUIJEP0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF4`000UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH02UYF00<0
05YFFUH02EYF1`0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000AWoo000]Ool01@00FUIJEUYF
00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001:Ool002eoo`04001JEUYFFUH30004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF1@001eYF00<005YFFUH00UYF0P000UYF5P00DGoo000^Ool00`00FUIJEP020005FUH00`00
FUIJEP04FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00UYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1000
Dgoo000^Ool300000eYF001JEP04FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF0`0000=J
EP00FUH00eYF0P001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000005=oo`00;Woo0P00
0eYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF4P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EP0005=oo`00;goo0P000UYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH015YF1P0047oo
0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP8000IJEP03001JEUYF00AJEP03001JEUYF
00=JEP8005Aoo`00<Goo100015YF00<005YFFUH01eYF00<005YFFUH01@004goo0P0000=JEP000000
1EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF10001UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00<Goo0`001UYF00<005YFFUH015YF1@0000=oo`0000000`0047oo0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00004`00Egoo000_Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP040006Ool5000>Ool20002FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00H005YF000005YF0006FUH00`00FUIJEP03FUH00`00FUH00002001FOol002ioo`03
001JEUYF00=JEP03001JEUYF009JEP@000Yoo`D000Yoo`@000AJEP05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00=JEP05001JEUYFFUH0
001FOol002eoo`8000EJEP03001JEP00008000moo`<000Moo`@0009JEP03001JEUYF00AJEP03001J
EUYF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP00EWoo000/Ool00`00FUH00005FUH2000EOol70006FUH00`00FUIJ
EP04FUH30002Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF001FOol002aoo`04001JEUYF0002FUH2000?Ool80004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUH005YF40000eYF00<007ooOol0Dgoo000/Ool00`00FUIJEP040008Ool80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH000030009Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000<Ool400000eYF
001oo`1DOol002eoo`04001JEP000002FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`0<Ool30002FUH01000FUH00000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04000COol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P003Goo0P0000=JEP00FUH00eYF00<005YF0000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
000IOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH01000FUH000003Goo0P000eYF00<005YFFUH00UYF0P00EWoo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000QOol40008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH5000;Ool30005FUH00`00FUIJ
EP02FUH00`00Oomoo`1EOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF009J
EPH002Uoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
0003Ool0000000<000Ioo`@00003FUH005YF00IJEP04001JEUYF001HOol0031ooa@003Eoo`T000IJ
EP03001JEUYF00UJEP03001JEUYF00AJEPP000Ioo`D00003Ool0000000<000EJEP03001JEUYF00EJ
EP<005Uoo`00PWoo6@003Woo1P000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Fgoo002=Ool0
1@00FUIJEP00FUH00P0047oo2@0015YF00<005YFFUH01UYF00<005YF00000`00GGoo002>Ool00`00
FUH0000C0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001QOol008ioo`80009JEP03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006Aoo`00SWoo
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00J7oo
002>Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001]
Ool008moo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0075oo`00TGoo
5000N7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5939 .74946 m .59924 .69472 L .56821 .68981 L p .707 .577 .707 r
F P
0 g
s
.59924 .69472 m .5939 .74946 L .62561 .7514 L p .707 .577 .707 r
F P
0 g
s
.62561 .7514 m .63094 .69666 L .59924 .69472 L p .707 .577 .707 r
F P
0 g
s
.63094 .69666 m .62561 .7514 L .65488 .75018 L p .707 .577 .707 r
F P
0 g
s
.65488 .75018 m .66022 .69544 L .63094 .69666 L p .707 .577 .707 r
F P
0 g
s
.56288 .74454 m .56821 .68981 L .5409 .68241 L p .707 .577 .707 r
F P
0 g
s
.56821 .68981 m .56288 .74454 L .5939 .74946 L p .707 .577 .707 r
F P
0 g
s
.66022 .69544 m .65488 .75018 L .67887 .74591 L p .707 .577 .707 r
F P
0 g
s
.67887 .74591 m .6842 .69118 L .66022 .69544 L p .707 .577 .707 r
F P
0 g
s
.53556 .73714 m .5409 .68241 L .51997 .67323 L p .707 .577 .707 r
F P
0 g
s
.5409 .68241 m .53556 .73714 L .56288 .74454 L p .707 .577 .707 r
F P
0 g
s
.59003 .81613 m .59717 .78059 L .56659 .77267 L p .707 .577 .707 r
F P
0 g
s
.59717 .78059 m .59003 .81613 L .62133 .82078 L p .707 .577 .707 r
F P
0 g
s
.62133 .82078 m .62847 .78524 L .59717 .78059 L p .707 .577 .707 r
F P
0 g
s
.62847 .78524 m .62133 .82078 L .65029 .82171 L p .707 .577 .707 r
F P
0 g
s
.65029 .82171 m .65743 .78617 L .62847 .78524 L p .707 .577 .707 r
F P
0 g
s
.55945 .80821 m .56659 .77267 L .53972 .76226 L p .707 .577 .707 r
F P
0 g
s
.56659 .77267 m .55945 .80821 L .59003 .81613 L p .707 .577 .707 r
F P
0 g
s
.6842 .69118 m .67887 .74591 L .69522 .73902 L p .707 .577 .707 r
F P
0 g
s
.69522 .73902 m .70055 .68429 L .6842 .69118 L p .707 .577 .707 r
F P
0 g
s
.51997 .67323 m .51464 .72797 L .53556 .73714 L p .707 .577 .707 r
F P
0 g
s
.5957 .86109 m .599 .84323 L .56833 .83576 L p .707 .577 .707 r
F P
0 g
s
.599 .84323 m .5957 .86109 L .62708 .86533 L p .707 .577 .707 r
F P
0 g
s
.62708 .86533 m .63038 .84748 L .599 .84323 L p .707 .577 .707 r
F P
0 g
s
.53972 .76226 m .53258 .7978 L .55945 .80821 L p .707 .577 .707 r
F P
0 g
s
.65743 .78617 m .65029 .82171 L .67407 .81882 L p .707 .577 .707 r
F P
0 g
s
.67407 .81882 m .68121 .78328 L .65743 .78617 L p .707 .577 .707 r
F P
0 g
s
.51464 .72797 m .51997 .67323 L .50748 .66319 L p .707 .577 .707 r
F P
0 g
s
.53258 .7978 m .53972 .76226 L .5192 .75038 L p .707 .577 .707 r
F P
0 g
s
.63038 .84748 m .62708 .86533 L .6561 .86594 L p .707 .577 .707 r
F P
0 g
s
.6561 .86594 m .6594 .84809 L .63038 .84748 L p .707 .577 .707 r
F P
0 g
s
.56503 .85362 m .56833 .83576 L .54138 .82581 L p .707 .577 .707 r
F P
0 g
s
.56833 .83576 m .56503 .85362 L .5957 .86109 L p .707 .577 .707 r
F P
0 g
s
.54138 .82581 m .53808 .84366 L .56503 .85362 L p .707 .577 .707 r
F P
0 g
s
.5192 .75038 m .51206 .78592 L .53258 .7978 L p .707 .577 .707 r
F P
0 g
s
.6594 .84809 m .6561 .86594 L .67992 .86285 L p .707 .577 .707 r
F P
0 g
s
.67992 .86285 m .68322 .84499 L .6594 .84809 L p .707 .577 .707 r
F P
0 g
s
.53808 .84366 m .54138 .82581 L .52078 .81433 L p .707 .577 .707 r
F P
0 g
s
.50748 .66319 m .50215 .71793 L .51464 .72797 L p .707 .577 .707 r
F P
0 g
s
.70055 .68429 m .69522 .73902 L .70232 .73018 L p .707 .577 .707 r
F P
0 g
s
.70232 .73018 m .70766 .67544 L .70055 .68429 L p .707 .577 .707 r
F P
0 g
s
.68121 .78328 m .67407 .81882 L .69034 .81241 L p .707 .577 .707 r
F P
0 g
s
.69034 .81241 m .69748 .77687 L .68121 .78328 L p .707 .577 .707 r
F P
0 g
s
.51206 .78592 m .5192 .75038 L .50703 .73819 L p .707 .577 .707 r
F P
0 g
s
.52078 .81433 m .51748 .83218 L .53808 .84366 L p .707 .577 .707 r
F P
0 g
s
.50215 .71793 m .50748 .66319 L .50465 .65327 L p .707 .577 .707 r
F P
0 g
s
.50703 .73819 m .49989 .77373 L .51206 .78592 L p .707 .577 .707 r
F P
0 g
s
.68322 .84499 m .67992 .86285 L .69621 .85636 L p .707 .577 .707 r
F P
0 g
s
.69621 .85636 m .69951 .83851 L .68322 .84499 L p .707 .577 .707 r
F P
0 g
s
.51748 .83218 m .52078 .81433 L .50855 .80246 L p .707 .577 .707 r
F P
0 g
s
.50465 .65327 m .49932 .708 L .50215 .71793 L p .707 .577 .707 r
F P
0 g
s
.50855 .80246 m .50525 .82031 L .51748 .83218 L p .707 .577 .707 r
F P
0 g
s
.69748 .77687 m .69034 .81241 L .69752 .80309 L p .707 .577 .707 r
F P
0 g
s
.69752 .80309 m .70466 .76755 L .69748 .77687 L p .707 .577 .707 r
F P
0 g
s
.49989 .77373 m .50703 .73819 L .5044 .72688 L p .707 .577 .707 r
F P
0 g
s
.70766 .67544 m .70232 .73018 L .69949 .72025 L p .707 .577 .707 r
F P
0 g
s
.69949 .72025 m .70483 .66552 L .70766 .67544 L p .707 .577 .707 r
F P
0 g
s
.49932 .708 m .50465 .65327 L .51176 .64443 L p .707 .577 .707 r
F P
0 g
s
.5044 .72688 m .49726 .76242 L .49989 .77373 L p .707 .577 .707 r
F P
0 g
s
.49726 .76242 m .5044 .72688 L .51158 .71756 L p .707 .577 .707 r
F P
0 g
s
.51158 .71756 m .50444 .7531 L .49726 .76242 L p .707 .577 .707 r
F P
0 g
s
.50232 .82126 m .48352 .31773 L .43955 .31672 L p .707 .577 .707 r
F P
0 g
s
.50525 .82031 m .50855 .80246 L .50589 .79136 L p .707 .577 .707 r
F P
0 g
s
.50589 .79136 m .50258 .80921 L .50525 .82031 L p .707 .577 .707 r
F P
0 g
s
.51176 .64443 m .50643 .69916 L .49932 .708 L p .707 .577 .707 r
F P
0 g
s
.50643 .69916 m .51176 .64443 L .52811 .63754 L p .707 .577 .707 r
F P
0 g
s
.50258 .80921 m .50589 .79136 L .51305 .78211 L p .707 .577 .707 r
F P
0 g
s
.51305 .78211 m .50975 .79997 L .50258 .80921 L p .707 .577 .707 r
F P
0 g
s
.52811 .63754 m .52277 .69227 L .50643 .69916 L p .707 .577 .707 r
F P
0 g
s
.50444 .7531 m .51158 .71756 L .52786 .71115 L p .707 .577 .707 r
F P
0 g
s
.52277 .69227 m .52811 .63754 L .55209 .63327 L p .707 .577 .707 r
F P
0 g
s
.52786 .71115 m .52072 .74669 L .50444 .7531 L p .707 .577 .707 r
F P
0 g
s
.50975 .79997 m .51305 .78211 L .52934 .77563 L p .707 .577 .707 r
F P
0 g
s
.55209 .63327 m .54676 .688 L .52277 .69227 L p .707 .577 .707 r
F P
0 g
s
.52934 .77563 m .52604 .79348 L .50975 .79997 L p .707 .577 .707 r
F P
0 g
s
.52072 .74669 m .52786 .71115 L .55164 .70827 L p .707 .577 .707 r
F P
0 g
s
.55164 .70827 m .5445 .74381 L .52072 .74669 L p .707 .577 .707 r
F P
0 g
s
.52604 .79348 m .52934 .77563 L .55316 .77253 L p .707 .577 .707 r
F P
0 g
s
.55316 .77253 m .54986 .79039 L .52604 .79348 L p .707 .577 .707 r
F P
0 g
s
.48352 .31773 m .50232 .82126 L .54723 .81865 L p .707 .577 .707 r
F P
0 g
s
.54723 .81865 m .52844 .31512 L .48352 .31773 L p .707 .577 .707 r
F P
0 g
s
.69951 .83851 m .69621 .85636 L .70337 .84712 L p .707 .577 .707 r
F P
0 g
s
.70337 .84712 m .70667 .82926 L .69951 .83851 L p .707 .577 .707 r
F P
0 g
s
.54676 .688 m .55209 .63327 L .58137 .63205 L p .707 .577 .707 r
F P
0 g
s
.58137 .63205 m .57604 .68678 L .54676 .688 L p .707 .577 .707 r
F P
0 g
s
.5445 .74381 m .55164 .70827 L .5806 .70919 L p .707 .577 .707 r
F P
0 g
s
.5806 .70919 m .57346 .74473 L .5445 .74381 L p .707 .577 .707 r
F P
0 g
s
.57346 .74473 m .5806 .70919 L .6119 .71384 L p .707 .577 .707 r
F P
0 g
s
.54986 .79039 m .55316 .77253 L .58218 .77314 L p .707 .577 .707 r
F P
0 g
s
.6119 .71384 m .60476 .74938 L .57346 .74473 L p .707 .577 .707 r
F P
0 g
s
.58218 .77314 m .57888 .791 L .54986 .79039 L p .707 .577 .707 r
F P
0 g
s
.57888 .791 m .58218 .77314 L .61356 .77739 L p .707 .577 .707 r
F P
0 g
s
.61356 .77739 m .61026 .79524 L .57888 .791 L p .707 .577 .707 r
F P
0 g
s
.52844 .31512 m .54723 .81865 L .58869 .81268 L p .707 .577 .707 r
F P
0 g
s
.57604 .68678 m .58137 .63205 L .61307 .63399 L p .707 .577 .707 r
F P
0 g
s
.61307 .63399 m .60774 .68872 L .57604 .68678 L p .707 .577 .707 r
F P
0 g
s
.58869 .81268 m .5699 .30916 L .52844 .31512 L p .707 .577 .707 r
F P
0 g
s
.45834 .82024 m .43955 .31672 L .40081 .31219 L p .707 .577 .707 r
F P
0 g
s
.43955 .31672 m .45834 .82024 L .50232 .82126 L p .707 .577 .707 r
F P
0 g
s
.70466 .76755 m .69752 .80309 L .6949 .79178 L p .707 .577 .707 r
F P
0 g
s
.6949 .79178 m .70204 .75624 L .70466 .76755 L p .707 .577 .707 r
F P
0 g
s
.70483 .66552 m .69949 .72025 L .687 .71021 L p .707 .577 .707 r
F P
0 g
s
.687 .71021 m .69234 .65548 L .70483 .66552 L p .707 .577 .707 r
F P
0 g
s
.6441 .6389 m .63877 .69363 L .60774 .68872 L p .707 .577 .707 r
F P
0 g
s
.60774 .68872 m .61307 .63399 L .6441 .6389 L p .707 .577 .707 r
F P
0 g
s
.64248 .72176 m .63534 .7573 L .60476 .74938 L p .707 .577 .707 r
F P
0 g
s
.60476 .74938 m .6119 .71384 L .64248 .72176 L p .707 .577 .707 r
F P
0 g
s
.64423 .78486 m .64093 .80271 L .61026 .79524 L p .707 .577 .707 r
F P
0 g
s
.61026 .79524 m .61356 .77739 L .64423 .78486 L p .707 .577 .707 r
F P
0 g
s
.5699 .30916 m .58869 .81268 L .62263 .80394 L p .707 .577 .707 r
F P
0 g
s
.62263 .80394 m .60384 .30041 L .5699 .30916 L p .707 .577 .707 r
F P
0 g
s
.25089 .71802 m .25623 .66329 L .2252 .65837 L p .707 .577 .707 r
F P
0 g
s
.25623 .66329 m .25089 .71802 L .2826 .71996 L p .707 .577 .707 r
F P
0 g
s
.2826 .71996 m .28793 .66523 L .25623 .66329 L p .707 .577 .707 r
F P
0 g
s
.70667 .82926 m .70337 .84712 L .70071 .83602 L p .707 .577 .707 r
F P
0 g
s
.70071 .83602 m .70401 .81816 L .70667 .82926 L p .707 .577 .707 r
F P
0 g
s
.28793 .66523 m .2826 .71996 L .31188 .71874 L p .707 .577 .707 r
F P
0 g
s
.31188 .71874 m .31721 .66401 L .28793 .66523 L p .707 .577 .707 r
F P
0 g
s
.41961 .81571 m .40081 .31219 L .37111 .30458 L p .707 .577 .707 r
F P
0 g
s
.40081 .31219 m .41961 .81571 L .45834 .82024 L p .707 .577 .707 r
F P
0 g
s
.21987 .71311 m .2252 .65837 L .19789 .65097 L p .707 .577 .707 r
F P
0 g
s
.2252 .65837 m .21987 .71311 L .25089 .71802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31721 .66401 m .31188 .71874 L .33586 .71447 L p .707 .577 .707 r
F P
0 g
s
.33586 .71447 m .34119 .65974 L .31721 .66401 L p .707 .577 .707 r
F P
0 g
s
.70204 .75624 m .6949 .79178 L .68273 .77959 L p .707 .577 .707 r
F P
0 g
s
.68273 .77959 m .68987 .74405 L .70204 .75624 L p .707 .577 .707 r
F P
0 g
s
.69234 .65548 m .687 .71021 L .66608 .70104 L p .707 .577 .707 r
F P
0 g
s
.66608 .70104 m .67141 .64631 L .69234 .65548 L p .707 .577 .707 r
F P
0 g
s
.66934 .73217 m .66221 .76771 L .63534 .7573 L p .707 .577 .707 r
F P
0 g
s
.63534 .7573 m .64248 .72176 L .66934 .73217 L p .707 .577 .707 r
F P
0 g
s
.64093 .80271 m .64423 .78486 L .67118 .79481 L p .707 .577 .707 r
F P
0 g
s
.60384 .30041 m .62263 .80394 L .64574 .79327 L p .707 .577 .707 r
F P
0 g
s
.67141 .64631 m .66608 .70104 L .63877 .69363 L p .707 .577 .707 r
F P
0 g
s
.63877 .69363 m .6441 .6389 L .67141 .64631 L p .707 .577 .707 r
F P
0 g
s
.64574 .79327 m .62694 .28975 L .60384 .30041 L p .707 .577 .707 r
F P
0 g
s
.19255 .7057 m .19789 .65097 L .17696 .6418 L p .707 .577 .707 r
F P
0 g
s
.19789 .65097 m .19255 .7057 L .21987 .71311 L p .707 .577 .707 r
F P
0 g
s
.24702 .77687 m .25416 .74133 L .22358 .73342 L p .707 .577 .707 r
F P
0 g
s
.25416 .74133 m .24702 .77687 L .27832 .78152 L p .707 .577 .707 r
F P
0 g
s
.27832 .78152 m .28546 .74598 L .25416 .74133 L p .707 .577 .707 r
F P
0 g
s
.28546 .74598 m .27832 .78152 L .30728 .78245 L p .707 .577 .707 r
F P
0 g
s
.30728 .78245 m .31442 .74691 L .28546 .74598 L p .707 .577 .707 r
F P
0 g
s
.21644 .76896 m .22358 .73342 L .19671 .72301 L p .707 .577 .707 r
F P
0 g
s
.22358 .73342 m .21644 .76896 L .24702 .77687 L p .707 .577 .707 r
F P
0 g
s
.70401 .81816 m .70071 .83602 L .68848 .82415 L p .707 .577 .707 r
F P
0 g
s
.68848 .82415 m .69178 .80629 L .70401 .81816 L p .707 .577 .707 r
F P
0 g
s
.38991 .80811 m .37111 .30458 L .35336 .29465 L p .707 .577 .707 r
F P
0 g
s
.37111 .30458 m .38991 .80811 L .41961 .81571 L p .707 .577 .707 r
F P
0 g
s
.34119 .65974 m .33586 .71447 L .35221 .70758 L p .707 .577 .707 r
F P
0 g
s
.35221 .70758 m .35754 .65285 L .34119 .65974 L p .707 .577 .707 r
F P
0 g
s
.25269 .81632 m .25599 .79846 L .22532 .79099 L p .707 .577 .707 r
F P
0 g
s
.25599 .79846 m .25269 .81632 L .28407 .82056 L p .707 .577 .707 r
F P
0 g
s
.28407 .82056 m .28737 .80271 L .25599 .79846 L p .707 .577 .707 r
F P
0 g
s
.17696 .6418 m .17163 .69653 L .19255 .7057 L p .707 .577 .707 r
F P
0 g
s
.19671 .72301 m .18957 .75855 L .21644 .76896 L p .707 .577 .707 r
F P
0 g
s
.31442 .74691 m .30728 .78245 L .33106 .77957 L p .707 .577 .707 r
F P
0 g
s
.33106 .77957 m .3382 .74403 L .31442 .74691 L p .707 .577 .707 r
F P
0 g
s
.18957 .75855 m .19671 .72301 L .17619 .71113 L p .707 .577 .707 r
F P
0 g
s
.28737 .80271 m .28407 .82056 L .31309 .82117 L p .707 .577 .707 r
F P
0 g
s
.31309 .82117 m .31639 .80331 L .28737 .80271 L p .707 .577 .707 r
F P
0 g
s
.22202 .80885 m .22532 .79099 L .19837 .78103 L p .707 .577 .707 r
F P
0 g
s
.22532 .79099 m .22202 .80885 L .25269 .81632 L p .707 .577 .707 r
F P
0 g
s
.17163 .69653 m .17696 .6418 L .16447 .63176 L p .707 .577 .707 r
F P
0 g
s
.68987 .74405 m .68273 .77959 L .66221 .76771 L p .707 .577 .707 r
F P
0 g
s
.66221 .76771 m .66934 .73217 L .68987 .74405 L p .707 .577 .707 r
F P
0 g
s
.19837 .78103 m .19507 .79889 L .22202 .80885 L p .707 .577 .707 r
F P
0 g
s
.17619 .71113 m .16905 .74667 L .18957 .75855 L p .707 .577 .707 r
F P
0 g
s
.31639 .80331 m .31309 .82117 L .33691 .81808 L p .707 .577 .707 r
F P
0 g
s
.33691 .81808 m .34021 .80022 L .31639 .80331 L p .707 .577 .707 r
F P
0 g
s
.19507 .79889 m .19837 .78103 L .17777 .76956 L p .707 .577 .707 r
F P
0 g
s
.62694 .28975 m .64574 .79327 L .65574 .78173 L p .707 .577 .707 r
F P
0 g
s
.65574 .78173 m .63695 .2782 L .62694 .28975 L p .707 .577 .707 r
F P
0 g
s
.69178 .80629 m .68848 .82415 L .66788 .81267 L p .707 .577 .707 r
F P
0 g
s
.66788 .81267 m .67118 .79481 L .69178 .80629 L p .707 .577 .707 r
F P
0 g
s
.16447 .63176 m .15914 .68649 L .17163 .69653 L p .707 .577 .707 r
F P
0 g
s
.3382 .74403 m .33106 .77957 L .34733 .77315 L p .707 .577 .707 r
F P
0 g
s
.34733 .77315 m .35447 .73761 L .3382 .74403 L p .707 .577 .707 r
F P
0 g
s
.16905 .74667 m .17619 .71113 L .16402 .69893 L p .707 .577 .707 r
F P
0 g
s
.17777 .76956 m .17447 .78741 L .19507 .79889 L p .707 .577 .707 r
F P
0 g
s
.35754 .65285 m .35221 .70758 L .35931 .69874 L p .707 .577 .707 r
F P
0 g
s
.35931 .69874 m .36465 .64401 L .35754 .65285 L p .707 .577 .707 r
F P
0 g
s
.15914 .68649 m .16447 .63176 L .16165 .62183 L p .707 .577 .707 r
F P
0 g
s
.16402 .69893 m .15688 .73448 L .16905 .74667 L p .707 .577 .707 r
F P
0 g
s
.34021 .80022 m .33691 .81808 L .3532 .81159 L p .707 .577 .707 r
F P
0 g
s
.3532 .81159 m .3565 .79374 L .34021 .80022 L p .707 .577 .707 r
F P
0 g
s
.37215 .79818 m .35336 .29465 L .34928 .28336 L p .707 .577 .707 r
F P
0 g
s
.35336 .29465 m .37215 .79818 L .38991 .80811 L p .707 .577 .707 r
F P
0 g
s
.17447 .78741 m .17777 .76956 L .16554 .75769 L p .707 .577 .707 r
F P
0 g
s
.67118 .79481 m .66788 .81267 L .64093 .80271 L p .707 .577 .707 r
F P
0 g
s
.16554 .75769 m .16224 .77554 L .17447 .78741 L p .707 .577 .707 r
F P
0 g
s
.16165 .62183 m .15631 .67656 L .15914 .68649 L p .707 .577 .707 r
F P
0 g
s
.35447 .73761 m .34733 .77315 L .35451 .76384 L p .707 .577 .707 r
F P
0 g
s
.35451 .76384 m .36165 .7283 L .35447 .73761 L p .707 .577 .707 r
F P
0 g
s
.15688 .73448 m .16402 .69893 L .16139 .68763 L p .707 .577 .707 r
F P
0 g
s
.36465 .64401 m .35931 .69874 L .35648 .68881 L p .707 .577 .707 r
F P
0 g
s
.35648 .68881 m .36182 .63408 L .36465 .64401 L p .707 .577 .707 r
F P
0 g
s
.63695 .2782 m .65574 .78173 L .65224 .77203 L p .707 .577 .707 r
F P
0 g
s
.65122 .75543 m .63695 .2782 L .65224 .77203 L .707 .577 .707 r
F
.63287 .26691 m .63695 .2782 L p .64711 .61793 L F P
0 g
s
.65097 .74711 m .64583 .614 L .64711 .61793 L .707 .577 .707 r
F
.65063 .74267 m .64583 .614 L p .65097 .74711 L F P
0 g
s
.63287 .26691 m .65167 .77044 L .63391 .7605 L p .707 .577 .707 r
F P
0 g
s
.64423 .64615 m .64354 .64962 L p .64926 .69388 L .707 .577 .707 r
F P
0 g
s
.64354 .64962 m .63709 .68169 L .64672 .69133 L p .707 .577 .707 r
F P
0 g
s
.64672 .69133 m .64926 .69388 L p .64354 .64962 L .707 .577 .707 r
F P
0 g
s
.65167 .77044 m .65063 .74267 L p .65097 .74711 L .707 .577 .707 r
F P
0 g
s
.64583 .614 m .63287 .26691 L p .64711 .61793 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64186 .56123 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.63935 .62589 m .64174 .60144 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .64469 .57116 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64174 .60144 L p .65184 .63593 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .63935 .62589 L .64344 .62918 L p .707 .577 .707 r
F P
0 g
s
.64344 .62918 m .65184 .63593 L p .64174 .60144 L .707 .577 .707 r
F P
0 g
s
.65224 .77203 m .65167 .77044 L p .65122 .75543 L .707 .577 .707 r
F P
0 g
s
.15631 .67656 m .16165 .62183 L .16875 .61299 L p .707 .577 .707 r
F P
0 g
s
.16139 .68763 m .15426 .72317 L .15688 .73448 L p .707 .577 .707 r
F P
0 g
s
.3565 .79374 m .3532 .81159 L .36036 .80235 L p .707 .577 .707 r
F P
0 g
s
.36036 .80235 m .36366 .78449 L .3565 .79374 L p .707 .577 .707 r
F P
0 g
s
.16224 .77554 m .16554 .75769 L .16288 .74659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16288 .74659 m .15958 .76444 L .16224 .77554 L p .707 .577 .707 r
F P
0 g
s
.36165 .7283 m .35451 .76384 L .35189 .75253 L p .707 .577 .707 r
F P
0 g
s
.35189 .75253 m .35903 .71699 L .36165 .7283 L p .707 .577 .707 r
F P
0 g
s
.16875 .61299 m .16342 .66772 L .15631 .67656 L p .707 .577 .707 r
F P
0 g
s
.15426 .72317 m .16139 .68763 L .16857 .67831 L p .707 .577 .707 r
F P
0 g
s
.34928 .28336 m .36808 .78689 L .37215 .79818 L p .707 .577 .707 r
F P
0 g
s
.36808 .78689 m .34928 .28336 L .35929 .27181 L p .707 .577 .707 r
F P
0 g
s
.36182 .63408 m .35648 .68881 L .344 .67877 L p .707 .577 .707 r
F P
0 g
s
.344 .67877 m .34933 .62404 L .36182 .63408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16342 .66772 m .16875 .61299 L .1851 .6061 L p .707 .577 .707 r
F P
0 g
s
.16857 .67831 m .16143 .71385 L .15426 .72317 L p .707 .577 .707 r
F P
0 g
s
.36366 .78449 m .36036 .80235 L .3577 .79124 L p .707 .577 .707 r
F P
0 g
s
.3577 .79124 m .361 .77339 L .36366 .78449 L p .707 .577 .707 r
F P
0 g
s
.15958 .76444 m .16288 .74659 L .17004 .73734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17004 .73734 m .16674 .75519 L .15958 .76444 L p .707 .577 .707 r
F P
0 g
s
.63391 .7605 m .61512 .25698 L .63287 .26691 L p .707 .577 .707 r
F P
0 g
s
.35903 .71699 m .35189 .75253 L .33972 .74034 L p .707 .577 .707 r
F P
0 g
s
.33972 .74034 m .34686 .7048 L .35903 .71699 L p .707 .577 .707 r
F P
0 g
s
.1851 .6061 m .17976 .66083 L .16342 .66772 L p .707 .577 .707 r
F P
0 g
s
.16143 .71385 m .16857 .67831 L .18485 .67189 L p .707 .577 .707 r
F P
0 g
s
.34933 .62404 m .344 .67877 L .32307 .6696 L p .707 .577 .707 r
F P
0 g
s
.32307 .6696 m .3284 .61487 L .34933 .62404 L p .707 .577 .707 r
F P
0 g
s
.17976 .66083 m .1851 .6061 L .20908 .60183 L p .707 .577 .707 r
F P
0 g
s
.18485 .67189 m .17771 .70744 L .16143 .71385 L p .707 .577 .707 r
F P
0 g
s
.361 .77339 m .3577 .79124 L .34547 .77937 L p .707 .577 .707 r
F P
0 g
s
.34547 .77937 m .34877 .76152 L .361 .77339 L p .707 .577 .707 r
F P
0 g
s
.37808 .77534 m .35929 .27181 L .38239 .26115 L p .707 .577 .707 r
F P
0 g
s
.35929 .27181 m .37808 .77534 L .36808 .78689 L p .707 .577 .707 r
F P
0 g
s
.16674 .75519 m .17004 .73734 L .18633 .73085 L p .707 .577 .707 r
F P
0 g
s
.18633 .73085 m .18303 .74871 L .16674 .75519 L p .707 .577 .707 r
F P
0 g
s
.3284 .61487 m .32307 .6696 L .29576 .6622 L p .707 .577 .707 r
F P
0 g
s
.29576 .6622 m .30109 .60746 L .3284 .61487 L p .707 .577 .707 r
F P
0 g
s
.34686 .7048 m .33972 .74034 L .3192 .72846 L p .707 .577 .707 r
F P
0 g
s
.3192 .72846 m .32634 .69292 L .34686 .7048 L p .707 .577 .707 r
F P
0 g
s
.20908 .60183 m .20375 .65657 L .17976 .66083 L p .707 .577 .707 r
F P
0 g
s
.17771 .70744 m .18485 .67189 L .20863 .66901 L p .707 .577 .707 r
F P
0 g
s
.20375 .65657 m .20908 .60183 L .23836 .60061 L p .707 .577 .707 r
F P
0 g
s
.61512 .25698 m .63391 .7605 L .60421 .7529 L p .707 .577 .707 r
F P
0 g
s
.60421 .7529 m .58542 .24937 L .61512 .25698 L p .707 .577 .707 r
F P
0 g
s
.30109 .60746 m .29576 .6622 L .26473 .65728 L p .707 .577 .707 r
F P
0 g
s
.26473 .65728 m .27007 .60255 L .30109 .60746 L p .707 .577 .707 r
F P
0 g
s
.20863 .66901 m .20149 .70455 L .17771 .70744 L p .707 .577 .707 r
F P
0 g
s
.34877 .76152 m .34547 .77937 L .32487 .7679 L p .707 .577 .707 r
F P
0 g
s
.32487 .7679 m .32817 .75004 L .34877 .76152 L p .707 .577 .707 r
F P
0 g
s
.23303 .65534 m .23836 .60061 L .27007 .60255 L p .707 .577 .707 r
F P
0 g
s
.23836 .60061 m .23303 .65534 L .20375 .65657 L p .707 .577 .707 r
F P
0 g
s
.18303 .74871 m .18633 .73085 L .21015 .72776 L p .707 .577 .707 r
F P
0 g
s
.27007 .60255 m .26473 .65728 L .23303 .65534 L p .707 .577 .707 r
F P
0 g
s
.32634 .69292 m .3192 .72846 L .29233 .71805 L p .707 .577 .707 r
F P
0 g
s
.29233 .71805 m .29947 .68251 L .32634 .69292 L p .707 .577 .707 r
F P
0 g
s
.73111 .65742 m .73644 .60269 L .70541 .59777 L p .707 .577 .707 r
F P
0 g
s
.73644 .60269 m .73111 .65742 L .76281 .65936 L p .707 .577 .707 r
F P
0 g
s
.76281 .65936 m .76814 .60463 L .73644 .60269 L p .707 .577 .707 r
F P
0 g
s
.20149 .70455 m .20863 .66901 L .23759 .66994 L p .707 .577 .707 r
F P
0 g
s
.21015 .72776 m .20685 .74562 L .18303 .74871 L p .707 .577 .707 r
F P
0 g
s
.76814 .60463 m .76281 .65936 L .79209 .65814 L p .707 .577 .707 r
F P
0 g
s
.79209 .65814 m .79742 .6034 L .76814 .60463 L p .707 .577 .707 r
F P
0 g
s
.38239 .26115 m .40119 .76468 L .37808 .77534 L p .707 .577 .707 r
F P
0 g
s
.40119 .76468 m .38239 .26115 L .41634 .2524 L p .707 .577 .707 r
F P
0 g
s
.70008 .65251 m .70541 .59777 L .6781 .59037 L p .707 .577 .707 r
F P
0 g
s
.70541 .59777 m .70008 .65251 L .73111 .65742 L p .707 .577 .707 r
F P
0 g
s
.23759 .66994 m .23045 .70548 L .20149 .70455 L p .707 .577 .707 r
F P
0 g
s
.29947 .68251 m .29233 .71805 L .26175 .71013 L p .707 .577 .707 r
F P
0 g
s
.26175 .71013 m .26889 .67459 L .29947 .68251 L p .707 .577 .707 r
F P
0 g
s
.23045 .70548 m .23759 .66994 L .26889 .67459 L p .707 .577 .707 r
F P
0 g
s
.32817 .75004 m .32487 .7679 L .29792 .75794 L p .707 .577 .707 r
F P
0 g
s
.29792 .75794 m .30122 .74008 L .32817 .75004 L p .707 .577 .707 r
F P
0 g
s
.20685 .74562 m .21015 .72776 L .23917 .72837 L p .707 .577 .707 r
F P
0 g
s
.79742 .6034 m .79209 .65814 L .81607 .65387 L p .707 .577 .707 r
F P
0 g
s
.81607 .65387 m .82141 .59914 L .79742 .6034 L p .707 .577 .707 r
F P
0 g
s
.26889 .67459 m .26175 .71013 L .23045 .70548 L p .707 .577 .707 r
F P
0 g
s
.58542 .24937 m .60421 .7529 L .56548 .74837 L p .707 .577 .707 r
F P
0 g
s
.56548 .74837 m .54669 .24484 L .58542 .24937 L p .707 .577 .707 r
F P
0 g
s
.67277 .6451 m .6781 .59037 L .65718 .5812 L p .707 .577 .707 r
F P
0 g
s
.6781 .59037 m .67277 .6451 L .70008 .65251 L p .707 .577 .707 r
F P
0 g
s
.23917 .72837 m .23587 .74622 L .20685 .74562 L p .707 .577 .707 r
F P
0 g
s
.72723 .72409 m .73437 .68855 L .70379 .68063 L p .707 .577 .707 r
F P
0 g
s
.73437 .68855 m .72723 .72409 L .75853 .72874 L p .707 .577 .707 r
F P
0 g
s
.75853 .72874 m .76567 .6932 L .73437 .68855 L p .707 .577 .707 r
F P
0 g
s
.30122 .74008 m .29792 .75794 L .26725 .75047 L p .707 .577 .707 r
F P
0 g
s
.26725 .75047 m .27055 .73262 L .30122 .74008 L p .707 .577 .707 r
F P
0 g
s
.76567 .6932 m .75853 .72874 L .78749 .72967 L p .707 .577 .707 r
F P
0 g
s
.78749 .72967 m .79463 .69413 L .76567 .6932 L p .707 .577 .707 r
F P
0 g
s
.23587 .74622 m .23917 .72837 L .27055 .73262 L p .707 .577 .707 r
F P
0 g
s
.69665 .71617 m .70379 .68063 L .67692 .67022 L p .707 .577 .707 r
F P
0 g
s
.70379 .68063 m .69665 .71617 L .72723 .72409 L p .707 .577 .707 r
F P
0 g
s
.43513 .75593 m .41634 .2524 L .4578 .24644 L p .707 .577 .707 r
F P
0 g
s
.41634 .2524 m .43513 .75593 L .40119 .76468 L p .707 .577 .707 r
F P
0 g
s
.27055 .73262 m .26725 .75047 L .23587 .74622 L p .707 .577 .707 r
F P
0 g
s
.82141 .59914 m .81607 .65387 L .83242 .64698 L p .707 .577 .707 r
F P
0 g
s
.83242 .64698 m .83775 .59225 L .82141 .59914 L p .707 .577 .707 r
F P
0 g
s
.65718 .5812 m .65184 .63593 L .67277 .6451 L p .707 .577 .707 r
F P
0 g
s
.7329 .76905 m .7362 .7512 L .70554 .74373 L p .707 .577 .707 r
F P
0 g
s
.7362 .7512 m .7329 .76905 L .76428 .77329 L p .707 .577 .707 r
F P
0 g
s
.76428 .77329 m .76758 .75544 L .7362 .7512 L p .707 .577 .707 r
F P
0 g
s
.54669 .24484 m .56548 .74837 L .5215 .74736 L p .707 .577 .707 r
F P
0 g
s
.5215 .74736 m .50271 .24383 L .54669 .24484 L p .707 .577 .707 r
F P
0 g
s
.67692 .67022 m .66978 .70576 L .69665 .71617 L p .707 .577 .707 r
F P
0 g
s
.79463 .69413 m .78749 .72967 L .81127 .72679 L p .707 .577 .707 r
F P
0 g
s
.81127 .72679 m .81841 .69124 L .79463 .69413 L p .707 .577 .707 r
F P
0 g
s
.65184 .63593 m .65718 .5812 L .64469 .57116 L p .707 .577 .707 r
F P
0 g
s
.66978 .70576 m .67692 .67022 L .6564 .65834 L p .707 .577 .707 r
F P
0 g
s
.76758 .75544 m .76428 .77329 L .7933 .7739 L p .707 .577 .707 r
F P
0 g
s
.7933 .7739 m .79661 .75605 L .76758 .75544 L p .707 .577 .707 r
F P
0 g
s
.70224 .76158 m .70554 .74373 L .67858 .73377 L p .707 .577 .707 r
F P
0 g
s
.70554 .74373 m .70224 .76158 L .7329 .76905 L p .707 .577 .707 r
F P
0 g
s
.47659 .74996 m .4578 .24644 L .50271 .24383 L p .707 .577 .707 r
F P
0 g
s
.4578 .24644 m .47659 .74996 L .43513 .75593 L p .707 .577 .707 r
F P
0 g
s
.50271 .24383 m .5215 .74736 L .47659 .74996 L p .707 .577 .707 r
F P
0 g
s
.67858 .73377 m .67528 .75162 L .70224 .76158 L p .707 .577 .707 r
F P
0 g
s
.6564 .65834 m .64926 .69388 L .66978 .70576 L p .707 .577 .707 r
F P
0 g
s
.79661 .75605 m .7933 .7739 L .81713 .77081 L p .707 .577 .707 r
F P
0 g
s
.81713 .77081 m .82043 .75296 L .79661 .75605 L p .707 .577 .707 r
F P
0 g
s
.67528 .75162 m .67858 .73377 L .65798 .72229 L p .707 .577 .707 r
F P
0 g
s
.83775 .59225 m .83242 .64698 L .83953 .63814 L p .707 .577 .707 r
F P
0 g
s
.83953 .63814 m .84486 .58341 L .83775 .59225 L p .707 .577 .707 r
F P
0 g
s
.81841 .69124 m .81127 .72679 L .82755 .72037 L p .707 .577 .707 r
F P
0 g
s
.82755 .72037 m .83469 .68483 L .81841 .69124 L p .707 .577 .707 r
F P
0 g
s
.64926 .69388 m .6564 .65834 L .64423 .64615 L p .707 .577 .707 r
F P
0 g
s
.65798 .72229 m .65468 .74014 L .67528 .75162 L p .707 .577 .707 r
F P
0 g
s
.82043 .75296 m .81713 .77081 L .83341 .76432 L p .707 .577 .707 r
F P
0 g
s
.83341 .76432 m .83672 .74647 L .82043 .75296 L p .707 .577 .707 r
F P
0 g
s
.65468 .74014 m .65798 .72229 L .64575 .71042 L p .707 .577 .707 r
F P
0 g
s
.64186 .56123 m .63653 .61596 L .63935 .62589 L p .707 .577 .707 r
F P
0 g
s
.64575 .71042 m .64245 .72827 L .65468 .74014 L p .707 .577 .707 r
F P
0 g
s
.83469 .68483 m .82755 .72037 L .83473 .71105 L p .707 .577 .707 r
F P
0 g
s
.83473 .71105 m .84186 .67551 L .83469 .68483 L p .707 .577 .707 r
F P
0 g
s
.63709 .68169 m .64423 .64615 L .64161 .63484 L p .707 .577 .707 r
F P
0 g
s
.84486 .58341 m .83953 .63814 L .8367 .62821 L p .707 .577 .707 r
F P
0 g
s
.8367 .62821 m .84203 .57348 L .84486 .58341 L p .707 .577 .707 r
F P
0 g
s
.63653 .61596 m .64186 .56123 L .64896 .55239 L p .707 .577 .707 r
F P
0 g
s
.64161 .63484 m .63447 .67038 L .63709 .68169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83672 .74647 m .83341 .76432 L .84058 .75508 L p .707 .577 .707 r
F P
0 g
s
.84058 .75508 m .84388 .73722 L .83672 .74647 L p .707 .577 .707 r
F P
0 g
s
.64245 .72827 m .64575 .71042 L .64309 .69932 L p .707 .577 .707 r
F P
0 g
s
.64309 .69932 m .63979 .71717 L .64245 .72827 L p .707 .577 .707 r
F P
0 g
s
.64896 .55239 m .64363 .60712 L .63653 .61596 L p .707 .577 .707 r
F P
0 g
s
.84186 .67551 m .83473 .71105 L .8321 .69975 L p .707 .577 .707 r
F P
0 g
s
.8321 .69975 m .83924 .6642 L .84186 .67551 L p .707 .577 .707 r
F P
0 g
s
.63447 .67038 m .64161 .63484 L .64878 .62553 L p .707 .577 .707 r
F P
0 g
s
.84203 .57348 m .8367 .62821 L .82421 .61817 L p .707 .577 .707 r
F P
0 g
s
.82421 .61817 m .82954 .56344 L .84203 .57348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64363 .60712 m .64896 .55239 L .66531 .5455 L p .707 .577 .707 r
F P
0 g
s
.3881 .62598 m .39343 .57125 L .3624 .56634 L p .707 .577 .707 r
F P
0 g
s
.39343 .57125 m .3881 .62598 L .4198 .62792 L p .707 .577 .707 r
F P
0 g
s
.4198 .62792 m .42513 .57319 L .39343 .57125 L p .707 .577 .707 r
F P
0 g
s
.64878 .62553 m .64165 .66107 L .63447 .67038 L p .707 .577 .707 r
F P
0 g
s
.84388 .73722 m .84058 .75508 L .83791 .74398 L p .707 .577 .707 r
F P
0 g
s
.83791 .74398 m .84121 .72612 L .84388 .73722 L p .707 .577 .707 r
F P
0 g
s
.42513 .57319 m .4198 .62792 L .44908 .6267 L p .707 .577 .707 r
F P
0 g
s
.44908 .6267 m .45441 .57197 L .42513 .57319 L p .707 .577 .707 r
F P
0 g
s
.63979 .71717 m .64309 .69932 L .65025 .69007 L p .707 .577 .707 r
F P
0 g
s
.35707 .62107 m .3624 .56634 L .33509 .55893 L p .707 .577 .707 r
F P
0 g
s
.3624 .56634 m .35707 .62107 L .3881 .62598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65025 .69007 m .64695 .70793 L .63979 .71717 L p .707 .577 .707 r
F P
0 g
s
.66531 .5455 m .65998 .60023 L .64363 .60712 L p .707 .577 .707 r
F P
0 g
s
.45441 .57197 m .44908 .6267 L .47306 .62244 L p .707 .577 .707 r
F P
0 g
s
.47306 .62244 m .4784 .5677 L .45441 .57197 L p .707 .577 .707 r
F P
0 g
s
.83924 .6642 m .8321 .69975 L .81993 .68755 L p .707 .577 .707 r
F P
0 g
s
.81993 .68755 m .82707 .65201 L .83924 .6642 L p .707 .577 .707 r
F P
0 g
s
.64165 .66107 m .64878 .62553 L .66506 .61911 L p .707 .577 .707 r
F P
0 g
s
.82954 .56344 m .82421 .61817 L .80329 .609 L p .707 .577 .707 r
F P
0 g
s
.80329 .609 m .80862 .55427 L .82954 .56344 L p .707 .577 .707 r
F P
0 g
s
.32976 .61366 m .33509 .55893 L .31417 .54976 L p .707 .577 .707 r
F P
0 g
s
.33509 .55893 m .32976 .61366 L .35707 .62107 L p .707 .577 .707 r
F P
0 g
s
.38422 .68484 m .39136 .6493 L .36078 .64138 L p .707 .577 .707 r
F P
0 g
s
.39136 .6493 m .38422 .68484 L .41552 .68949 L p .707 .577 .707 r
F P
0 g
s
.41552 .68949 m .42266 .65395 L .39136 .6493 L p .707 .577 .707 r
F P
0 g
s
.65998 .60023 m .66531 .5455 L .6893 .54123 L p .707 .577 .707 r
F P
0 g
s
.42266 .65395 m .41552 .68949 L .44448 .69042 L p .707 .577 .707 r
F P
0 g
s
.44448 .69042 m .45162 .65487 L .42266 .65395 L p .707 .577 .707 r
F P
0 g
s
.35364 .67692 m .36078 .64138 L .33391 .63097 L p .707 .577 .707 r
F P
0 g
s
.36078 .64138 m .35364 .67692 L .38422 .68484 L p .707 .577 .707 r
F P
0 g
s
.66506 .61911 m .65792 .65465 L .64165 .66107 L p .707 .577 .707 r
F P
0 g
s
.84121 .72612 m .83791 .74398 L .82568 .73211 L p .707 .577 .707 r
F P
0 g
s
.82568 .73211 m .82898 .71425 L .84121 .72612 L p .707 .577 .707 r
F P
0 g
s
.64695 .70793 m .65025 .69007 L .66654 .68359 L p .707 .577 .707 r
F P
0 g
s
.4784 .5677 m .47306 .62244 L .48941 .61554 L p .707 .577 .707 r
F P
0 g
s
.48941 .61554 m .49474 .56081 L .4784 .5677 L p .707 .577 .707 r
F P
0 g
s
.38989 .72428 m .39319 .70642 L .36253 .69896 L p .707 .577 .707 r
F P
0 g
s
.39319 .70642 m .38989 .72428 L .42127 .72852 L p .707 .577 .707 r
F P
0 g
s
.42127 .72852 m .42457 .71067 L .39319 .70642 L p .707 .577 .707 r
F P
0 g
s
.31417 .54976 m .30883 .60449 L .32976 .61366 L p .707 .577 .707 r
F P
0 g
s
.80862 .55427 m .80329 .609 L .77597 .6016 L p .707 .577 .707 r
F P
0 g
s
.77597 .6016 m .78131 .54686 L .80862 .55427 L p .707 .577 .707 r
F P
0 g
s
.33391 .63097 m .32677 .66651 L .35364 .67692 L p .707 .577 .707 r
F P
0 g
s
.45162 .65487 m .44448 .69042 L .46826 .68753 L p .707 .577 .707 r
F P
0 g
s
.46826 .68753 m .4754 .65199 L .45162 .65487 L p .707 .577 .707 r
F P
0 g
s
.6893 .54123 m .68396 .59597 L .65998 .60023 L p .707 .577 .707 r
F P
0 g
s
.32677 .66651 m .33391 .63097 L .31339 .61909 L p .707 .577 .707 r
F P
0 g
s
.66654 .68359 m .66324 .70144 L .64695 .70793 L p .707 .577 .707 r
F P
0 g
s
.42457 .71067 m .42127 .72852 L .45029 .72913 L p .707 .577 .707 r
F P
0 g
s
.45029 .72913 m .4536 .71128 L .42457 .71067 L p .707 .577 .707 r
F P
0 g
s
.35923 .71681 m .36253 .69896 L .33557 .689 L p .707 .577 .707 r
F P
0 g
s
.36253 .69896 m .35923 .71681 L .38989 .72428 L p .707 .577 .707 r
F P
0 g
s
.30883 .60449 m .31417 .54976 L .30168 .53972 L p .707 .577 .707 r
F P
0 g
s
.82707 .65201 m .81993 .68755 L .79941 .67567 L p .707 .577 .707 r
F P
0 g
s
.79941 .67567 m .80655 .64013 L .82707 .65201 L p .707 .577 .707 r
F P
0 g
s
.65792 .65465 m .66506 .61911 L .68884 .61623 L p .707 .577 .707 r
F P
0 g
s
.68396 .59597 m .6893 .54123 L .71858 .54001 L p .707 .577 .707 r
F P
0 g
s
.33557 .689 m .33227 .70685 L .35923 .71681 L p .707 .577 .707 r
F P
0 g
s
.31339 .61909 m .30625 .65463 L .32677 .66651 L p .707 .577 .707 r
F P
0 g
s
.78131 .54686 m .77597 .6016 L .74495 .59668 L p .707 .577 .707 r
F P
0 g
s
.74495 .59668 m .75028 .54195 L .78131 .54686 L p .707 .577 .707 r
F P
0 g
s
.4536 .71128 m .45029 .72913 L .47412 .72604 L p .707 .577 .707 r
F P
0 g
s
.47412 .72604 m .47742 .70819 L .4536 .71128 L p .707 .577 .707 r
F P
0 g
s
.33227 .70685 m .33557 .689 L .31497 .67752 L p .707 .577 .707 r
F P
0 g
s
.71324 .59474 m .71858 .54001 L .75028 .54195 L p .707 .577 .707 r
F P
0 g
s
.71858 .54001 m .71324 .59474 L .68396 .59597 L p .707 .577 .707 r
F P
0 g
s
.68884 .61623 m .6817 .65177 L .65792 .65465 L p .707 .577 .707 r
F P
0 g
s
.82898 .71425 m .82568 .73211 L .80508 .72063 L p .707 .577 .707 r
F P
0 g
s
.80508 .72063 m .80838 .70278 L .82898 .71425 L p .707 .577 .707 r
F P
0 g
s
.30168 .53972 m .29634 .59445 L .30883 .60449 L p .707 .577 .707 r
F P
0 g
s
.75028 .54195 m .74495 .59668 L .71324 .59474 L p .707 .577 .707 r
F P
0 g
s
.4754 .65199 m .46826 .68753 L .48454 .68112 L p .707 .577 .707 r
F P
0 g
s
.48454 .68112 m .49168 .64558 L .4754 .65199 L p .707 .577 .707 r
F P
0 g
s
.66324 .70144 m .66654 .68359 L .69036 .6805 L p .707 .577 .707 r
F P
0 g
s
.30625 .65463 m .31339 .61909 L .30122 .6069 L p .707 .577 .707 r
F P
0 g
s
.31497 .67752 m .31167 .69537 L .33227 .70685 L p .707 .577 .707 r
F P
0 g
s
.49474 .56081 m .48941 .61554 L .49652 .6067 L p .707 .577 .707 r
F P
0 g
s
.49652 .6067 m .50185 .55197 L .49474 .56081 L p .707 .577 .707 r
F P
0 g
s
.80655 .64013 m .79941 .67567 L .77254 .66526 L p .707 .577 .707 r
F P
0 g
s
.77254 .66526 m .77968 .62972 L .80655 .64013 L p .707 .577 .707 r
F P
0 g
s
.6817 .65177 m .68884 .61623 L .7178 .61716 L p .707 .577 .707 r
F P
0 g
s
.69036 .6805 m .68706 .69835 L .66324 .70144 L p .707 .577 .707 r
F P
0 g
s
.29634 .59445 m .30168 .53972 L .29885 .52979 L p .707 .577 .707 r
F P
0 g
s
.30122 .6069 m .29408 .64244 L .30625 .65463 L p .707 .577 .707 r
F P
0 g
s
.47742 .70819 m .47412 .72604 L .4904 .71955 L p .707 .577 .707 r
F P
0 g
s
.4904 .71955 m .49371 .7017 L .47742 .70819 L p .707 .577 .707 r
F P
0 g
s
.31167 .69537 m .31497 .67752 L .30274 .66565 L p .707 .577 .707 r
F P
0 g
s
.7178 .61716 m .71066 .6527 L .6817 .65177 L p .707 .577 .707 r
F P
0 g
s
.77968 .62972 m .77254 .66526 L .74196 .65735 L p .707 .577 .707 r
F P
0 g
s
.74196 .65735 m .7491 .62181 L .77968 .62972 L p .707 .577 .707 r
F P
0 g
s
.71066 .6527 m .7178 .61716 L .7491 .62181 L p .707 .577 .707 r
F P
0 g
s
.80838 .70278 m .80508 .72063 L .77813 .71067 L p .707 .577 .707 r
F P
0 g
s
.77813 .71067 m .78143 .69282 L .80838 .70278 L p .707 .577 .707 r
F P
0 g
s
.68706 .69835 m .69036 .6805 L .71938 .6811 L p .707 .577 .707 r
F P
0 g
s
.7491 .62181 m .74196 .65735 L .71066 .6527 L p .707 .577 .707 r
F P
0 g
s
.30274 .66565 m .29944 .6835 L .31167 .69537 L p .707 .577 .707 r
F P
0 g
s
.29885 .52979 m .29351 .58453 L .29634 .59445 L p .707 .577 .707 r
F P
0 g
s
.49168 .64558 m .48454 .68112 L .49171 .6718 L p .707 .577 .707 r
F P
0 g
s
.49171 .6718 m .49885 .63626 L .49168 .64558 L p .707 .577 .707 r
F P
0 g
s
.71938 .6811 m .71608 .69896 L .68706 .69835 L p .707 .577 .707 r
F P
0 g
s
.29408 .64244 m .30122 .6069 L .2986 .59559 L p .707 .577 .707 r
F P
0 g
s
.50185 .55197 m .49652 .6067 L .49369 .59678 L p .707 .577 .707 r
F P
0 g
s
.49369 .59678 m .49902 .54204 L .50185 .55197 L p .707 .577 .707 r
F P
0 g
s
.78143 .69282 m .77813 .71067 L .74746 .7032 L p .707 .577 .707 r
F P
0 g
s
.74746 .7032 m .75076 .68535 L .78143 .69282 L p .707 .577 .707 r
F P
0 g
s
.71608 .69896 m .71938 .6811 L .75076 .68535 L p .707 .577 .707 r
F P
0 g
s
.75076 .68535 m .74746 .7032 L .71608 .69896 L p .707 .577 .707 r
F P
0 g
s
.29351 .58453 m .29885 .52979 L .30595 .52095 L p .707 .577 .707 r
F P
0 g
s
.2986 .59559 m .29146 .63113 L .29408 .64244 L p .707 .577 .707 r
F P
0 g
s
.49371 .7017 m .4904 .71955 L .49757 .71031 L p .707 .577 .707 r
F P
0 g
s
.49757 .71031 m .50087 .69245 L .49371 .7017 L p .707 .577 .707 r
F P
0 g
s
.29944 .6835 m .30274 .66565 L .30008 .65455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30008 .65455 m .29678 .6724 L .29944 .6835 L p .707 .577 .707 r
F P
0 g
s
.49885 .63626 m .49171 .6718 L .48909 .66049 L p .707 .577 .707 r
F P
0 g
s
.48909 .66049 m .49623 .62495 L .49885 .63626 L p .707 .577 .707 r
F P
0 g
s
.30595 .52095 m .30062 .57568 L .29351 .58453 L p .707 .577 .707 r
F P
0 g
s
.29146 .63113 m .2986 .59559 L .30577 .58627 L p .707 .577 .707 r
F P
0 g
s
.49902 .54204 m .49369 .59678 L .4812 .58674 L p .707 .577 .707 r
F P
0 g
s
.4812 .58674 m .48653 .532 L .49902 .54204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30062 .57568 m .30595 .52095 L .3223 .51406 L p .707 .577 .707 r
F P
0 g
s
.30577 .58627 m .29864 .62181 L .29146 .63113 L p .707 .577 .707 r
F P
0 g
s
.50087 .69245 m .49757 .71031 L .4949 .69921 L p .707 .577 .707 r
F P
0 g
s
.4949 .69921 m .4982 .68135 L .50087 .69245 L p .707 .577 .707 r
F P
0 g
s
.29678 .6724 m .30008 .65455 L .30724 .6453 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30724 .6453 m .30394 .66316 L .29678 .6724 L p .707 .577 .707 r
F P
0 g
s
.49623 .62495 m .48909 .66049 L .47692 .6483 L p .707 .577 .707 r
F P
0 g
s
.47692 .6483 m .48406 .61276 L .49623 .62495 L p .707 .577 .707 r
F P
0 g
s
.3223 .51406 m .31697 .56879 L .30062 .57568 L p .707 .577 .707 r
F P
0 g
s
.29864 .62181 m .30577 .58627 L .32205 .57986 L p .707 .577 .707 r
F P
0 g
s
.48653 .532 m .4812 .58674 L .46027 .57756 L p .707 .577 .707 r
F P
0 g
s
.46027 .57756 m .46561 .52283 L .48653 .532 L p .707 .577 .707 r
F P
0 g
s
.31697 .56879 m .3223 .51406 L .34629 .50979 L p .707 .577 .707 r
F P
0 g
s
.32205 .57986 m .31491 .6154 L .29864 .62181 L p .707 .577 .707 r
F P
0 g
s
.4982 .68135 m .4949 .69921 L .48267 .68734 L p .707 .577 .707 r
F P
0 g
s
.48267 .68734 m .48597 .66948 L .4982 .68135 L p .707 .577 .707 r
F P
0 g
s
.30394 .66316 m .30724 .6453 L .32353 .63882 L p .707 .577 .707 r
F P
0 g
s
.32353 .63882 m .32023 .65667 L .30394 .66316 L p .707 .577 .707 r
F P
0 g
s
.46561 .52283 m .46027 .57756 L .43296 .57016 L p .707 .577 .707 r
F P
0 g
s
.43296 .57016 m .4383 .51543 L .46561 .52283 L p .707 .577 .707 r
F P
0 g
s
.48406 .61276 m .47692 .6483 L .4564 .63642 L p .707 .577 .707 r
F P
0 g
s
.4564 .63642 m .46354 .60088 L .48406 .61276 L p .707 .577 .707 r
F P
0 g
s
.34629 .50979 m .34095 .56453 L .31697 .56879 L p .707 .577 .707 r
F P
0 g
s
.31491 .6154 m .32205 .57986 L .34583 .57697 L p .707 .577 .707 r
F P
0 g
s
.34095 .56453 m .34629 .50979 L .37556 .50857 L p .707 .577 .707 r
F P
0 g
s
.4383 .51543 m .43296 .57016 L .40194 .56525 L p .707 .577 .707 r
F P
0 g
s
.40194 .56525 m .40727 .51051 L .4383 .51543 L p .707 .577 .707 r
F P
0 g
s
.34583 .57697 m .33869 .61251 L .31491 .6154 L p .707 .577 .707 r
F P
0 g
s
.48597 .66948 m .48267 .68734 L .46207 .67586 L p .707 .577 .707 r
F P
0 g
s
.46207 .67586 m .46537 .65801 L .48597 .66948 L p .707 .577 .707 r
F P
0 g
s
.37023 .56331 m .37556 .50857 L .40727 .51051 L p .707 .577 .707 r
F P
0 g
s
.37556 .50857 m .37023 .56331 L .34095 .56453 L p .707 .577 .707 r
F P
0 g
s
.32023 .65667 m .32353 .63882 L .34735 .63572 L p .707 .577 .707 r
F P
0 g
s
.40727 .51051 m .40194 .56525 L .37023 .56331 L p .707 .577 .707 r
F P
0 g
s
.46354 .60088 m .4564 .63642 L .42953 .62601 L p .707 .577 .707 r
F P
0 g
s
.42953 .62601 m .43667 .59047 L .46354 .60088 L p .707 .577 .707 r
F P
0 g
s
.33869 .61251 m .34583 .57697 L .37479 .5779 L p .707 .577 .707 r
F P
0 g
s
.34735 .63572 m .34405 .65358 L .32023 .65667 L p .707 .577 .707 r
F P
0 g
s
.37479 .5779 m .36765 .61344 L .33869 .61251 L p .707 .577 .707 r
F P
0 g
s
.43667 .59047 m .42953 .62601 L .39895 .61809 L p .707 .577 .707 r
F P
0 g
s
.39895 .61809 m .40609 .58255 L .43667 .59047 L p .707 .577 .707 r
F P
0 g
s
.36765 .61344 m .37479 .5779 L .40609 .58255 L p .707 .577 .707 r
F P
0 g
s
.46537 .65801 m .46207 .67586 L .43512 .6659 L p .707 .577 .707 r
F P
0 g
s
.43512 .6659 m .43842 .64805 L .46537 .65801 L p .707 .577 .707 r
F P
0 g
s
.34405 .65358 m .34735 .63572 L .37637 .63633 L p .707 .577 .707 r
F P
0 g
s
.40609 .58255 m .39895 .61809 L .36765 .61344 L p .707 .577 .707 r
F P
0 g
s
.37637 .63633 m .37307 .65419 L .34405 .65358 L p .707 .577 .707 r
F P
0 g
s
.43842 .64805 m .43512 .6659 L .40445 .65843 L p .707 .577 .707 r
F P
0 g
s
.40445 .65843 m .40775 .64058 L .43842 .64805 L p .707 .577 .707 r
F P
0 g
s
.37307 .65419 m .37637 .63633 L .40775 .64058 L p .707 .577 .707 r
F P
0 g
s
.40775 .64058 m .40445 .65843 L .37307 .65419 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo6000O7oo001mOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Eoo`P000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001cOol0079oo`<00003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001`
Ool006ioo`@000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP<006eoo`00K7oo0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006]oo`00JWoo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Uoo`00J7oo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFJGoo001VOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol006Eoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001oogoo06Ioo`00I7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0IGoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`03
001JEP0000P000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo20000eYF00<005YFFUH00UYF2@0000=J
EP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001JOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Qoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001EOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol005Aoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Uoo`l004aoo`00E7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEPT004=oo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH003eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
000iOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH3000eOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF008003=oo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03
001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00Dgoo00<0
05YF00000eYF1@0000=JEP00FUH01EYF1@000eYF1@000UYF10000UYF00<005YFFUH015YF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000`Ool005=oo`04001JEP00FUH20005FUH00`00FUIJ
EP06FUH01000FUIJEUYF2@001EYF10001EYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0002FUH=00000eYF001JEP04FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00Dgoo0P000eYF00<005YF00005@0025YF00<005YFFUH01UYF0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002eoo`00Dgoo0P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000UYF00<005YFFUH01UYF00<005YFFUH00`0000=JEP00FUH00UYF0P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;7oo001COol200000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20003FUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2000/Ool005=oo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP8000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00H0
05YFFUH005YF000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000/Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH]Ool0041oo`P000aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEUYF
009JEP<000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF008000=J
EPD00003FUH005YF00EJEPH000=oo`D00003Ool000000080009JEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Qoo`P000=JEP03001JEUYF009JEPT000=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJ
EP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH0
05YF0`001EYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUH000AJEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH50005FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0P00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000UYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJEP03001J
EUYF00EJEP@000AJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP`0009JEP03001JEUYF00EJEPH000QJEP03001JEUYF00AJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEP0000l000QJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000UYF00D005YFFUIJEP00009JEP800003Ool0000000<000IJEP03001JEUYF009JEP<000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000050002FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004
FUH300000eYF001JEP03FUH20002Ool00`00FUH000030002FUH00`00FUIJEP05FUH300000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000`0025YF00<005YFFUH00eYF00@005YFFUIJEP<002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
0`0015YF00<005YFFUH00P001EYF0P0000=oo`00FUH00UYF00<005YF00003`001EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002ioo`00;Goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH00eYF0P000eYF00@005YF000000=JEP04001JEUYFFUH50007FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF00=JEPl00003FUH0000000<000MJEP03001JEUYF00=JEP8000IJEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
00000P001UYF00L005YFFUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00@000=J
EP03001JEUYF00EJEP03001JEUYF00H000MJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00L0
05YFFUIJEP00FUH0000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00AJEP03001JEUYF00MJEP04001JEUYF0004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03FUH2000_Ool002eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000YJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004
FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@000QJEP8000AJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003
FUH01000FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEPD0009J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH01000
FUIJEUYF3`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo000/Ool0
0`00FUH00004FUH01000FUIJEUYF5`001UYF0`000eYF1@001UYF2@0015YF00<005YFFUH01eYF00@0
05YFFUIJEP@000=JEP03001JEP0000<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEP000002FUH60004FUH20006Ool90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000`Ool002aoo`03001JEP0000=JEPD00003FUH005YF00AJEPH000=oo`D0009oo`@0009JEP<00003
FUH00000009JEP03001JEUYF00IJEP03001JEUYF00IJEPL000IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
0003FUH005YF009JEP03001JEUYF00=JEP8000ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP0002moo`00;7oo00@005YF001JEP8000IJEP03001JEUYF00EJEP04001JEUYFFUH90005
Ool60002FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH30003
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH40003FUH300000eYF001J
EP04FUH01000FUH000003goo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00;7oo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH=000015YF
000000001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH00P00
00=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF10000eYF00<005YF
FUH00P001EYF00D005YFFUIJEP0000Qoo`<000Ioo`<000MJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool002aoo`8000=JEP03001JEUYF00=JEQ8000QJEP03001JEUYF00@0009JEP80009JEP8000AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP<000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800005FUH005YFFUH00005FUH30002
FUH01@00FUIJEUYF00001goo1@0027oo0P0015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00/005YFFUH005YF001J
EP00FUH005YF0080009JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00EJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEP00008000=JEP8000Ioo`D000Yoo`<00003FUH005YF00EJEP06001JEUYF
001JEP00;Goo000/Ool2000015YF000000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH010001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P001UYF00<005YF00001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEP<0
0003FUH0000000Ioo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool40004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP02FUH30004
FUH20003FUH60002FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF0000
0eYF00<005YFFUH00eYF00<005YF00004P0047oo0P000eYF00L005YFFUIJEP00FUH0000]Ool002eo
o`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP03001JEUYF0080009JEP05001JEP00001JEP030002FUH90003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH300000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH00UYF
1P003goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH30003FUH40002FUH0
1000FUIJEUYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEPD00003FUH0000000=JEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P003Woo0P000eYF0P00;Woo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000
FUH000001UYF00D005YF000005YF00@0009JEP04001JEUYFFUH500000eYF0000000<0004FUH02@00
FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF
0`0027oo1P0000AJEP00FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH50002FUH00`00FUIJ
EP02FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00P0000=JEP00Ool0;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH0
0`00FUH000030004FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00QJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00YJEP04001JEUYFFUH30005FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH50007FUH00`00
FUIJEP05FUH70008FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUH0000^Ool002aoo`80
00AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP03
FUH50009FUH00`00FUIJEP09FUH01@00FUH00000FUH00P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0000EJEP00000005YF00<000MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000AJEP03001JEUYF00EJEP<000AJEP8002moo`00;7oo0P000UYF1P000Woo1000
0UYF00<005YFFUH01EYF1P0025YF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH01UYF
00<005YFFUH010001EYF00<005YFFUH01UYF1@000eYF0P001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP<00003FUH005YF00=JEP8000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP@00003FUH005YF00IJEP04001JEUYF0003FUH2000_Ool002aoo`04FUH000000002
FUH00`00Oomoo`07Ool50006FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH>0003FUH01000FUIJEUYF0P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000100000=JEP00FUH015YF100000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000EJEP03001JEUYF009JEP<00003FUH007oo
02ioo`00:goo0`0015YF0`0037oo10000UYF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00<005YF
FUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH3
00000eYF001JEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH00`0015YF00<005YFFUH015YF1000
00=JEP00FUH01EYF0P00<7oo000[Ool30004FUH00`00FUIJEP02000>Ool@0006FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00
FUH30005FUH00`00FUIJEP02FUH60002FUH00`00FUH000040003FUH00`00FUIJEP05FUH00`00FUIJ
EP020006FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEP8000moo`<000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEP0000@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004Ool90002FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20004FUH01000FUH00000;Woo000[Ool00`00FUIJEP03FUH00`00FUIJEP03FUH90007Ool5
000;Ool200000eYF001JEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF10000UYF00<005YF
FUH01EYF00@005YFFUIJEPD000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000AJEP<000=JEP07001JEUYFFUH005YF000027oo1@000UYF00<005YFFUH01EYF00@005YF
FUIJEPD0009JEP03001JEUYF009JEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF00<005YFFUH0
10000eYF00<005YFFUH00UYF30003Goo0P001UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03
001JEUYF00h000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP0000AJEP03001JEUYF00800003FUH005YF009JEP03001JEP0000Uoo`<00003Ool00000
00`000Eoo`<000AJEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00@005YFFUIJEPL000aoo`8000=JEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP03FUH20003FUH2000SOol00`00FUIJEP02FUH00`00Oomo
o`0[Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00@000Yoo`800003FUH005YF00=JEP800005OomJEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`001EYF00D005YF000005YF008002Aoo`03001JEUYF008002eoo`00;Woo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100027oo0P00
15YF00<007ooOol00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@0
05YFFUIJEP<002Eoo`@002eoo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000Aoo`D0009JEP80009oo`=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH4000SOol2000]Ool002ioo`8000=J
EQ@000AJEP03001JEUYF00MJEP04001JEUYFFUH40003FUH00`00FUH000030002Ool3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`000UYF0`0025YF00<005YFFUH010007Woo0P00;Woo000^Ool200000eYF00000002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03
0002Ool3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<000<FUH00`00FUIJEP06
FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00@005YF000000MJEP03001JEUYF00AJ
EPL001Eoo`@002ioo`00;Woo0`000Woo0`0025YF00<005YFFUH01UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF0`000eYF0`000Woo0eYF00<005YFFUH015YF00<005YFFUH01EYF20002eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001UYF00L005YFFUIJEP00FUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH01eYF00<005YFFUH00UYF5@000UYF0P00;Woo000]Ool30005Ool2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP0200000eYF
00000003Ool3FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00=JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008002moo`00;Goo10001Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH00eYF0`000goo0eYF00<005YFFUH015YF00<005YF00000P002UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00001UYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;goo000]Ool01@00FUH005YF00001goo0`0000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH01EYF0P000goo0eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YF00001UYF00@005YFFUIJEP800003Ool000000080009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002eoo`80
00=JEP03001oogoo00Moo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000IJ
EP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000000001UYF
00H005YFFUH005YF0005Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo
000^Ool01000FUIJEUYF0`002goo10000UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00H005YFFUIJEP00Ool3FUH01000FUH000001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
0000009oo`8000=JEP07001JEUYFFUH005YF000037oo200015YF00@005YFFUIJEPD003=oo`00;Woo
00D005YFFUIJEP00009JEP03001oogoo00aoo`P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH005YF009JEP03001ooeYF009JEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0004Ool200000eYF001JEP02FUH00`00FUH0000DOol8000hOol002moo`03001JEP0000AJEP8000mo
o`H0009JEP03001JEUYF00EJEP04001JEUYFFUH500000goo00000003FUH01@00OomJEUYF00000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Ioo`8000=JEP8005Eoo`00<7oo0P001UYF
0P003Goo1@0000=oo`000000300027oo00L005YF001JEP00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP000goo1P000UYF0P00EGoo000aOol00`00FUIJEP04FUH00`00FUH00003
000:Ool3000IOol2000015YF0000000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
10000eYF00L005YF001JEP00FUH0001EOol0039oo`8000AJEP03001JEUYF00=JEP@002=oo`03001J
EP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH007oo
05Aoo`00=7oo00@005YFFUH000QJEP04001JEP00000POol2000015YF001oo`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000eYF0P000eYF00<005YFFUH00UYF00<005YF0000EGoo000eOol30008
FUH01000FUIJEUYF0`006goo0P0000=JEP0000000Woo00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@0
05YFFUIJEP<000IJEP800003FUH005YF00=JEP8005Ioo`00=goo0P001UYF00<005YFFUH01EYF1P00
47oo1@000eYF0P000goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00EJEP<0
00AJEP8005Ioo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJ
EP00FUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH30002FUH40006FUH00`00FUIJEP020002FUH2001FOol003eoo`@000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20008Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH3001GOol0045oo`8000AJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000030004FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH2001GOol004=oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP00000BOol50008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH<0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00@005YF000005Eoo`00AWoo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEP@001Uoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJ
EPd000Aoo`P0009JEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH00`00Oomo
o`1BOol004aooa4002=ooaD0009JEP80011ooa<000Aoo`800003FUH005YF00=JEP03001oogoo059o
o`00T7oo00@005YFFUH000EJEP8000moo`<001Eoo`8000AJEP03001oogoo059oo`00TGoo0`001EYF
00@005YF000002Moo`03001JEUYF008005Aoo`00Tgoo00<005YFFUH00eYF00@005YFFUIJEP<002Eo
o`@005Aoo`00U7oo0P000UYF00<005YFFUH01EYF10008goo0P00E7oo002FOol30008FUH00`00FUIJ
EP04000NOol2001EOol009Qoo`8000MJEP03001JEUYF00AJEPL001Eoo`@005Eoo`00VWoo0P0015YF
00<005YFFUH01eYF00<005YFFUH00UYF200027oo1@000UYF0P00EGoo002LOol300000eYF001JEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YFFUH00P00EWoo002OOol40006FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:=oo`@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:Moo`D000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol00:aoo`@0009JEP03001JEUYF00EJ
EP04001JEUYFFUH5001JOol00;1oo`h005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59239 .74927 m .601 .69533 L .57021 .68859 L p .707 .577 .707 r
F P
0 g
s
.601 .69533 m .59239 .74927 L .62389 .75286 L p .707 .577 .707 r
F P
0 g
s
.62389 .75286 m .63249 .69893 L .601 .69533 L p .707 .577 .707 r
F P
0 g
s
.63249 .69893 m .62389 .75286 L .65299 .75295 L p .707 .577 .707 r
F P
0 g
s
.65299 .75295 m .6616 .69902 L .63249 .69893 L p .707 .577 .707 r
F P
0 g
s
.5616 .74252 m .57021 .68859 L .54313 .67935 L p .707 .577 .707 r
F P
0 g
s
.57021 .68859 m .5616 .74252 L .59239 .74927 L p .707 .577 .707 r
F P
0 g
s
.6616 .69902 m .65299 .75295 L .67687 .74953 L p .707 .577 .707 r
F P
0 g
s
.67687 .74953 m .68548 .69559 L .6616 .69902 L p .707 .577 .707 r
F P
0 g
s
.53452 .73329 m .54313 .67935 L .52242 .66852 L p .707 .577 .707 r
F P
0 g
s
.54313 .67935 m .53452 .73329 L .5616 .74252 L p .707 .577 .707 r
F P
0 g
s
.58574 .81947 m .59716 .78559 L .56753 .77413 L p .707 .577 .707 r
F P
0 g
s
.59716 .78559 m .58574 .81947 L .61618 .82732 L p .707 .577 .707 r
F P
0 g
s
.61618 .82732 m .62761 .79344 L .59716 .78559 L p .707 .577 .707 r
F P
0 g
s
.5561 .80801 m .56753 .77413 L .54161 .76017 L p .707 .577 .707 r
F P
0 g
s
.56753 .77413 m .5561 .80801 L .58574 .81947 L p .707 .577 .707 r
F P
0 g
s
.62761 .79344 m .61618 .82732 L .64446 .83079 L p .707 .577 .707 r
F P
0 g
s
.64446 .83079 m .65589 .79691 L .62761 .79344 L p .707 .577 .707 r
F P
0 g
s
.52242 .66852 m .51381 .72246 L .53452 .73329 L p .707 .577 .707 r
F P
0 g
s
.68548 .69559 m .67687 .74953 L .69318 .74293 L p .707 .577 .707 r
F P
0 g
s
.69318 .74293 m .70179 .68899 L .68548 .69559 L p .707 .577 .707 r
F P
0 g
s
.51381 .72246 m .52242 .66852 L .5101 .65717 L p .707 .577 .707 r
F P
0 g
s
.53019 .79405 m .54161 .76017 L .52195 .74509 L p .707 .577 .707 r
F P
0 g
s
.54161 .76017 m .53019 .79405 L .5561 .80801 L p .707 .577 .707 r
F P
0 g
s
.59496 .8666 m .60025 .84947 L .5704 .8387 L p .707 .577 .707 r
F P
0 g
s
.60025 .84947 m .59496 .8666 L .62561 .87382 L p .707 .577 .707 r
F P
0 g
s
.62561 .87382 m .6309 .8567 L .60025 .84947 L p .707 .577 .707 r
F P
0 g
s
.65589 .79691 m .64446 .83079 L .66781 .82954 L p .707 .577 .707 r
F P
0 g
s
.66781 .82954 m .67923 .79566 L .65589 .79691 L p .707 .577 .707 r
F P
0 g
s
.56511 .85583 m .5704 .8387 L .54425 .82544 L p .707 .577 .707 r
F P
0 g
s
.5704 .8387 m .56511 .85583 L .59496 .8666 L p .707 .577 .707 r
F P
0 g
s
.6309 .8567 m .62561 .87382 L .65405 .8768 L p .707 .577 .707 r
F P
0 g
s
.65405 .8768 m .65934 .85967 L .6309 .8567 L p .707 .577 .707 r
F P
0 g
s
.54425 .82544 m .53896 .84257 L .56511 .85583 L p .707 .577 .707 r
F P
0 g
s
.52195 .74509 m .51052 .77897 L .53019 .79405 L p .707 .577 .707 r
F P
0 g
s
.53896 .84257 m .54425 .82544 L .52439 .81098 L p .707 .577 .707 r
F P
0 g
s
.5101 .65717 m .50149 .71111 L .51381 .72246 L p .707 .577 .707 r
F P
0 g
s
.51052 .77897 m .52195 .74509 L .51046 .73035 L p .707 .577 .707 r
F P
0 g
s
.65934 .85967 m .65405 .8768 L .6775 .87522 L p .707 .577 .707 r
F P
0 g
s
.6775 .87522 m .68279 .8581 L .65934 .85967 L p .707 .577 .707 r
F P
0 g
s
.70179 .68899 m .69318 .74293 L .70032 .7338 L p .707 .577 .707 r
F P
0 g
s
.70032 .7338 m .70893 .67986 L .70179 .68899 L p .707 .577 .707 r
F P
0 g
s
.52439 .81098 m .5191 .82811 L .53896 .84257 L p .707 .577 .707 r
F P
0 g
s
.50149 .71111 m .5101 .65717 L .50738 .6464 L p .707 .577 .707 r
F P
0 g
s
.67923 .79566 m .66781 .82954 L .68393 .82369 L p .707 .577 .707 r
F P
0 g
s
.68393 .82369 m .69536 .78981 L .67923 .79566 L p .707 .577 .707 r
F P
0 g
s
.51046 .73035 m .49903 .76424 L .51052 .77897 L p .707 .577 .707 r
F P
0 g
s
.5191 .82811 m .52439 .81098 L .51274 .79675 L p .707 .577 .707 r
F P
0 g
s
.68279 .8581 m .6775 .87522 L .69366 .86926 L p .707 .577 .707 r
F P
0 g
s
.69366 .86926 m .69895 .85213 L .68279 .8581 L p .707 .577 .707 r
F P
0 g
s
.50738 .6464 m .49877 .70034 L .50149 .71111 L p .707 .577 .707 r
F P
0 g
s
.51274 .79675 m .50745 .81388 L .5191 .82811 L p .707 .577 .707 r
F P
0 g
s
.49903 .76424 m .51046 .73035 L .50827 .71742 L p .707 .577 .707 r
F P
0 g
s
.70893 .67986 m .70032 .7338 L .6976 .72303 L p .707 .577 .707 r
F P
0 g
s
.6976 .72303 m .70621 .66909 L .70893 .67986 L p .707 .577 .707 r
F P
0 g
s
.69536 .78981 m .68393 .82369 L .69126 .81381 L p .707 .577 .707 r
F P
0 g
s
.69126 .81381 m .70268 .77993 L .69536 .78981 L p .707 .577 .707 r
F P
0 g
s
.49877 .70034 m .50738 .6464 L .51452 .63727 L p .707 .577 .707 r
F P
0 g
s
.50827 .71742 m .49684 .7513 L .49903 .76424 L p .707 .577 .707 r
F P
0 g
s
.50745 .81388 m .51274 .79675 L .51044 .78413 L p .707 .577 .707 r
F P
0 g
s
.51044 .78413 m .50515 .80126 L .50745 .81388 L p .707 .577 .707 r
F P
0 g
s
.51452 .63727 m .50591 .69121 L .49877 .70034 L p .707 .577 .707 r
F P
0 g
s
.49684 .7513 m .50827 .71742 L .5156 .70754 L p .707 .577 .707 r
F P
0 g
s
.5156 .70754 m .50417 .74142 L .49684 .7513 L p .707 .577 .707 r
F P
0 g
s
.50515 .80126 m .51044 .78413 L .51774 .77436 L p .707 .577 .707 r
F P
0 g
s
.51774 .77436 m .51245 .79149 L .50515 .80126 L p .707 .577 .707 r
F P
0 g
s
.50417 .74142 m .5156 .70754 L .53172 .70168 L p .707 .577 .707 r
F P
0 g
s
.53172 .70168 m .5203 .73556 L .50417 .74142 L p .707 .577 .707 r
F P
0 g
s
.50962 .8207 m .47922 .31654 L .4353 .31657 L p .707 .577 .707 r
F P
0 g
s
.50591 .69121 m .51452 .63727 L .53083 .63067 L p .707 .577 .707 r
F P
0 g
s
.53083 .63067 m .52222 .68461 L .50591 .69121 L p .707 .577 .707 r
F P
0 g
s
.52222 .68461 m .53083 .63067 L .55471 .62725 L p .707 .577 .707 r
F P
0 g
s
.51245 .79149 m .51774 .77436 L .5339 .7684 L p .707 .577 .707 r
F P
0 g
s
.5339 .7684 m .52861 .78552 L .51245 .79149 L p .707 .577 .707 r
F P
0 g
s
.55471 .62725 m .5461 .68118 L .52222 .68461 L p .707 .577 .707 r
F P
0 g
s
.5203 .73556 m .53172 .70168 L .55507 .70043 L p .707 .577 .707 r
F P
0 g
s
.55507 .70043 m .54364 .73431 L .5203 .73556 L p .707 .577 .707 r
F P
0 g
s
.52861 .78552 m .5339 .7684 L .55734 .76682 L p .707 .577 .707 r
F P
0 g
s
.55734 .76682 m .55205 .78395 L .52861 .78552 L p .707 .577 .707 r
F P
0 g
s
.47922 .31654 m .50962 .8207 L .55449 .81716 L p .707 .577 .707 r
F P
0 g
s
.5461 .68118 m .55471 .62725 L .58382 .62734 L p .707 .577 .707 r
F P
0 g
s
.58382 .62734 m .57761 .66625 L p .5461 .68118 L .707 .577 .707 r
F P
0 g
s
.57761 .66625 m .57521 .68127 L .57055 .68126 L p .707 .577 .707 r
F P
0 g
s
.57055 .68126 m .5461 .68118 L p .57761 .66625 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .47922 .31654 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.54364 .73431 m .55507 .70043 L .58335 .7039 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .5804 .71262 L p .54364 .73431 L .707 .577 .707 r
F P
0 g
s
.5804 .71262 m .57192 .73778 L .55887 .73618 L p .707 .577 .707 r
F P
0 g
s
.55887 .73618 m .54364 .73431 L p .5804 .71262 L .707 .577 .707 r
F P
0 g
s
.54465 .75173 m .54905 .72698 L .5429 .74007 L .707 .577 .707 r
F
.55205 .78395 m .55734 .76682 L .58578 .7698 L p F P
0 g
s
.58578 .7698 m .58417 .77503 L p .55205 .78395 L .707 .577 .707 r
F P
0 g
s
.58417 .77503 m .58049 .78692 L .57468 .78632 L p .707 .577 .707 r
F P
0 g
s
.57468 .78632 m .55205 .78395 L p .58417 .77503 L .707 .577 .707 r
F P
0 g
s
.55362 .81137 m .55018 .74568 L .54465 .75173 L .707 .577 .707 r
F
.55449 .81716 m .55411 .81079 L p .55362 .81137 L F P
0 g
s
.55411 .81079 m .55018 .74568 L p .55362 .81137 L .707 .577 .707 r
F P
0 g
s
.55018 .74568 m .54905 .72698 L p .54465 .75173 L .707 .577 .707 r
F P
0 g
s
.54905 .72698 m .52409 .313 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.57521 .68127 m .58382 .62734 L .61531 .63093 L p .707 .577 .707 r
F P
0 g
s
.61531 .63093 m .6067 .68487 L .57521 .68127 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .61379 .71175 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.57192 .73778 m .576 .72569 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.576 .72569 m .58335 .7039 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.6461 .63768 m .63749 .69161 L .6067 .68487 L p .707 .577 .707 r
F P
0 g
s
.6067 .68487 m .61531 .63093 L .6461 .63768 L p .707 .577 .707 r
F P
0 g
s
.64342 .72322 m .632 .7571 L .60237 .74563 L p .707 .577 .707 r
F P
0 g
s
.60237 .74563 m .61379 .71175 L .64342 .72322 L p .707 .577 .707 r
F P
0 g
s
.61379 .71175 m .60237 .74563 L .57192 .73778 L p .707 .577 .707 r
F P
0 g
s
.58049 .78692 m .58578 .7698 L .61643 .77702 L p .707 .577 .707 r
F P
0 g
s
.64629 .78779 m .641 .80492 L .61114 .79415 L p .707 .577 .707 r
F P
0 g
s
.61114 .79415 m .61643 .77702 L .64629 .78779 L p .707 .577 .707 r
F P
0 g
s
.61643 .77702 m .61114 .79415 L .58049 .78692 L p .707 .577 .707 r
F P
0 g
s
.56552 .3063 m .59453 .78752 L p .62983 .80123 L .707 .577 .707 r
F P
0 g
s
.59453 .78752 m .59591 .81046 L .60099 .80907 L p .707 .577 .707 r
F P
0 g
s
.60099 .80907 m .62983 .80123 L p .59453 .78752 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .55449 .81716 L .59591 .81046 L p .707 .577 .707 r
F P
0 g
s
.59591 .81046 m .56552 .3063 L .52409 .313 L p .707 .577 .707 r
F P
0 g
s
.69895 .85213 m .69366 .86926 L .70095 .85949 L p .707 .577 .707 r
F P
0 g
s
.70095 .85949 m .70624 .84236 L .69895 .85213 L p .707 .577 .707 r
F P
0 g
s
.46569 .82073 m .4353 .31657 L .39662 .31307 L p .707 .577 .707 r
F P
0 g
s
.4353 .31657 m .46569 .82073 L .50962 .8207 L p .707 .577 .707 r
F P
0 g
s
.70621 .66909 m .6976 .72303 L .68528 .71168 L p .707 .577 .707 r
F P
0 g
s
.68528 .71168 m .69389 .65774 L .70621 .66909 L p .707 .577 .707 r
F P
0 g
s
.70268 .77993 m .69126 .81381 L .68907 .80087 L p .707 .577 .707 r
F P
0 g
s
.68907 .80087 m .7005 .76699 L .70268 .77993 L p .707 .577 .707 r
F P
0 g
s
.62983 .80123 m .59944 .29708 L .56552 .3063 L p .707 .577 .707 r
F P
0 g
s
.24938 .72116 m .25799 .66722 L .2272 .66047 L p .707 .577 .707 r
F P
0 g
s
.25799 .66722 m .24938 .72116 L .28088 .72475 L p .707 .577 .707 r
F P
0 g
s
.28088 .72475 m .28948 .67081 L .25799 .66722 L p .707 .577 .707 r
F P
0 g
s
.28948 .67081 m .28088 .72475 L .30999 .72484 L p .707 .577 .707 r
F P
0 g
s
.30999 .72484 m .31859 .6709 L .28948 .67081 L p .707 .577 .707 r
F P
0 g
s
.21859 .71441 m .2272 .66047 L .20012 .65124 L p .707 .577 .707 r
F P
0 g
s
.2272 .66047 m .21859 .71441 L .24938 .72116 L p .707 .577 .707 r
F P
0 g
s
.42701 .81723 m .39662 .31307 L .36696 .3064 L p .707 .577 .707 r
F P
0 g
s
.39662 .31307 m .42701 .81723 L .46569 .82073 L p .707 .577 .707 r
F P
0 g
s
.70624 .84236 m .70095 .85949 L .69866 .84687 L p .707 .577 .707 r
F P
0 g
s
.69866 .84687 m .70395 .82974 L .70624 .84236 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31859 .6709 m .30999 .72484 L .33386 .72142 L p .707 .577 .707 r
F P
0 g
s
.33386 .72142 m .34247 .66748 L .31859 .6709 L p .707 .577 .707 r
F P
0 g
s
.69389 .65774 m .68528 .71168 L .66457 .70085 L p .707 .577 .707 r
F P
0 g
s
.66457 .70085 m .67318 .64691 L .69389 .65774 L p .707 .577 .707 r
F P
0 g
s
.19152 .70517 m .20012 .65124 L .17941 .64041 L p .707 .577 .707 r
F P
0 g
s
.20012 .65124 m .19152 .70517 L .21859 .71441 L p .707 .577 .707 r
F P
0 g
s
.7005 .76699 m .68907 .80087 L .67758 .78614 L p .707 .577 .707 r
F P
0 g
s
.67758 .78614 m .68901 .75226 L .7005 .76699 L p .707 .577 .707 r
F P
0 g
s
.67318 .64691 m .66457 .70085 L .63749 .69161 L p .707 .577 .707 r
F P
0 g
s
.63749 .69161 m .6461 .63768 L .67318 .64691 L p .707 .577 .707 r
F P
0 g
s
.66934 .73717 m .65791 .77105 L .632 .7571 L p .707 .577 .707 r
F P
0 g
s
.632 .7571 m .64342 .72322 L .66934 .73717 L p .707 .577 .707 r
F P
0 g
s
.641 .80492 m .64629 .78779 L .67243 .80105 L p .707 .577 .707 r
F P
0 g
s
.59944 .29708 m .62983 .80123 L .65293 .7904 L p .707 .577 .707 r
F P
0 g
s
.65293 .7904 m .62253 .28625 L .59944 .29708 L p .707 .577 .707 r
F P
0 g
s
.24273 .77871 m .25415 .74483 L .22452 .73336 L p .707 .577 .707 r
F P
0 g
s
.25415 .74483 m .24273 .77871 L .27317 .78656 L p .707 .577 .707 r
F P
0 g
s
.27317 .78656 m .2846 .75268 L .25415 .74483 L p .707 .577 .707 r
F P
0 g
s
.2131 .76725 m .22452 .73336 L .1986 .71941 L p .707 .577 .707 r
F P
0 g
s
.22452 .73336 m .2131 .76725 L .24273 .77871 L p .707 .577 .707 r
F P
0 g
s
.2846 .75268 m .27317 .78656 L .30145 .79003 L p .707 .577 .707 r
F P
0 g
s
.30145 .79003 m .31288 .75615 L .2846 .75268 L p .707 .577 .707 r
F P
0 g
s
.70395 .82974 m .69866 .84687 L .68701 .83264 L p .707 .577 .707 r
F P
0 g
s
.68701 .83264 m .6923 .81551 L .70395 .82974 L p .707 .577 .707 r
F P
0 g
s
.25195 .81691 m .25724 .79978 L .22739 .78901 L p .707 .577 .707 r
F P
0 g
s
.25724 .79978 m .25195 .81691 L .2826 .82414 L p .707 .577 .707 r
F P
0 g
s
.2826 .82414 m .28789 .80701 L .25724 .79978 L p .707 .577 .707 r
F P
0 g
s
.17941 .64041 m .1708 .69435 L .19152 .70517 L p .707 .577 .707 r
F P
0 g
s
.34247 .66748 m .33386 .72142 L .35017 .71482 L p .707 .577 .707 r
F P
0 g
s
.35017 .71482 m .35878 .66088 L .34247 .66748 L p .707 .577 .707 r
F P
0 g
s
.39736 .81056 m .36696 .3064 L .34924 .29721 L p .707 .577 .707 r
F P
0 g
s
.36696 .3064 m .39736 .81056 L .42701 .81723 L p .707 .577 .707 r
F P
0 g
s
.18718 .75329 m .1986 .71941 L .17894 .70432 L p .707 .577 .707 r
F P
0 g
s
.1986 .71941 m .18718 .75329 L .2131 .76725 L p .707 .577 .707 r
F P
0 g
s
.2221 .80614 m .22739 .78901 L .20125 .77575 L p .707 .577 .707 r
F P
0 g
s
.22739 .78901 m .2221 .80614 L .25195 .81691 L p .707 .577 .707 r
F P
0 g
s
.1708 .69435 m .17941 .64041 L .16709 .62906 L p .707 .577 .707 r
F P
0 g
s
.28789 .80701 m .2826 .82414 L .31104 .82711 L p .707 .577 .707 r
F P
0 g
s
.31104 .82711 m .31633 .80998 L .28789 .80701 L p .707 .577 .707 r
F P
0 g
s
.31288 .75615 m .30145 .79003 L .3248 .78878 L p .707 .577 .707 r
F P
0 g
s
.3248 .78878 m .33622 .7549 L .31288 .75615 L p .707 .577 .707 r
F P
0 g
s
.68901 .75226 m .67758 .78614 L .65791 .77105 L p .707 .577 .707 r
F P
0 g
s
.65791 .77105 m .66934 .73717 L .68901 .75226 L p .707 .577 .707 r
F P
0 g
s
.20125 .77575 m .19595 .79288 L .2221 .80614 L p .707 .577 .707 r
F P
0 g
s
.17894 .70432 m .16751 .73821 L .18718 .75329 L p .707 .577 .707 r
F P
0 g
s
.19595 .79288 m .20125 .77575 L .18138 .76129 L p .707 .577 .707 r
F P
0 g
s
.31633 .80998 m .31104 .82711 L .33449 .82554 L p .707 .577 .707 r
F P
0 g
s
.33449 .82554 m .33978 .80841 L .31633 .80998 L p .707 .577 .707 r
F P
0 g
s
.62253 .28625 m .65293 .7904 L .66294 .77903 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .63255 .27487 L .62253 .28625 L p .707 .577 .707 r
F P
0 g
s
.16709 .62906 m .15848 .68299 L .1708 .69435 L p .707 .577 .707 r
F P
0 g
s
.16751 .73821 m .17894 .70432 L .16745 .68959 L p .707 .577 .707 r
F P
0 g
s
.18138 .76129 m .17609 .77842 L .19595 .79288 L p .707 .577 .707 r
F P
0 g
s
.6923 .81551 m .68701 .83264 L .66714 .81818 L p .707 .577 .707 r
F P
0 g
s
.66714 .81818 m .67243 .80105 L .6923 .81551 L p .707 .577 .707 r
F P
0 g
s
.35878 .66088 m .35017 .71482 L .35732 .70569 L p .707 .577 .707 r
F P
0 g
s
.35732 .70569 m .36592 .65175 L .35878 .66088 L p .707 .577 .707 r
F P
0 g
s
.33622 .7549 m .3248 .78878 L .34092 .78293 L p .707 .577 .707 r
F P
0 g
s
.34092 .78293 m .35235 .74904 L .33622 .7549 L p .707 .577 .707 r
F P
0 g
s
.15848 .68299 m .16709 .62906 L .16437 .61829 L p .707 .577 .707 r
F P
0 g
s
.16745 .68959 m .15602 .72347 L .16751 .73821 L p .707 .577 .707 r
F P
0 g
s
.17609 .77842 m .18138 .76129 L .16973 .74706 L p .707 .577 .707 r
F P
0 g
s
.33978 .80841 m .33449 .82554 L .35065 .81957 L p .707 .577 .707 r
F P
0 g
s
.35065 .81957 m .35594 .80244 L .33978 .80841 L p .707 .577 .707 r
F P
0 g
s
.37964 .80137 m .34924 .29721 L .34519 .2864 L p .707 .577 .707 r
F P
0 g
s
.34924 .29721 m .37964 .80137 L .39736 .81056 L p .707 .577 .707 r
F P
0 g
s
.16973 .74706 m .16444 .76419 L .17609 .77842 L p .707 .577 .707 r
F P
0 g
s
.67243 .80105 m .66714 .81818 L .641 .80492 L p .707 .577 .707 r
F P
0 g
s
.15602 .72347 m .16745 .68959 L .16526 .67665 L p .707 .577 .707 r
F P
0 g
s
.16437 .61829 m .15576 .67223 L .15848 .68299 L p .707 .577 .707 r
F P
0 g
s
.35235 .74904 m .34092 .78293 L .34825 .77305 L p .707 .577 .707 r
F P
0 g
s
.34825 .77305 m .35967 .73916 L .35235 .74904 L p .707 .577 .707 r
F P
0 g
s
.36592 .65175 m .35732 .70569 L .35459 .69492 L p .707 .577 .707 r
F P
0 g
s
.35459 .69492 m .3632 .64098 L .36592 .65175 L p .707 .577 .707 r
F P
0 g
s
.15576 .67223 m .16437 .61829 L .17151 .60916 L p .707 .577 .707 r
F P
0 g
s
.16526 .67665 m .15383 .71053 L .15602 .72347 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .6595 .76983 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.63255 .27487 m .66227 .7679 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.66227 .7679 m .66294 .77903 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.62849 .26405 m .65889 .76821 L .64117 .75902 L p .707 .577 .707 r
F P
0 g
s
.64773 .68693 m .6518 .67484 L p .64766 .63832 L .707 .577 .707 r
F P
0 g
s
.65797 .75099 m .63255 .27487 L .6595 .76983 L .707 .577 .707 r
F
.62849 .26405 m .63255 .27487 L p .65503 .69598 L F P
0 g
s
.65889 .76821 m .65366 .6815 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.65366 .6815 m .62849 .26405 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.6473 .56513 m .64438 .58345 L p .65102 .63042 L .707 .577 .707 r
F P
0 g
s
.64438 .58345 m .6387 .61907 L .64862 .62821 L p .707 .577 .707 r
F P
0 g
s
.64862 .62821 m .65102 .63042 L p .64438 .58345 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .65915 .65305 L .6477 .63836 L p .707 .577 .707 r
F P
0 g
s
.6477 .63836 m .64766 .63832 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.65915 .65305 m .6518 .67484 L p .66739 .70201 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .64773 .68693 L .65312 .69106 L p .707 .577 .707 r
F P
0 g
s
.65312 .69106 m .66739 .70201 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.6595 .76983 m .65889 .76821 L p .65797 .75099 L .707 .577 .707 r
F P
0 g
s
.16444 .76419 m .16973 .74706 L .16744 .73444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35594 .80244 m .35065 .81957 L .35794 .8098 L p .707 .577 .707 r
F P
0 g
s
.35794 .8098 m .36323 .79268 L .35594 .80244 L p .707 .577 .707 r
F P
0 g
s
.16744 .73444 m .16214 .75157 L .16444 .76419 L p .707 .577 .707 r
F P
0 g
s
.15383 .71053 m .16526 .67665 L .17259 .66677 L p .707 .577 .707 r
F P
0 g
s
.17151 .60916 m .16291 .66309 L .15576 .67223 L p .707 .577 .707 r
F P
0 g
s
.35967 .73916 m .34825 .77305 L .34606 .76011 L p .707 .577 .707 r
F P
0 g
s
.34606 .76011 m .35749 .72623 L .35967 .73916 L p .707 .577 .707 r
F P
0 g
s
.34519 .2864 m .37559 .79056 L .37964 .80137 L p .707 .577 .707 r
F P
0 g
s
.37559 .79056 m .34519 .2864 L .35521 .27502 L p .707 .577 .707 r
F P
0 g
s
.3632 .64098 m .35459 .69492 L .34227 .68356 L p .707 .577 .707 r
F P
0 g
s
.34227 .68356 m .35088 .62963 L .3632 .64098 L p .707 .577 .707 r
F P
0 g
s
.16291 .66309 m .17151 .60916 L .18782 .60256 L p .707 .577 .707 r
F P
0 g
s
.17259 .66677 m .16116 .70066 L .15383 .71053 L p .707 .577 .707 r
F P
0 g
s
.16214 .75157 m .16744 .73444 L .17473 .72467 L p .707 .577 .707 r
F P
0 g
s
.36323 .79268 m .35794 .8098 L .35565 .79718 L p .707 .577 .707 r
F P
0 g
s
.35565 .79718 m .36094 .78006 L .36323 .79268 L p .707 .577 .707 r
F P
0 g
s
.17473 .72467 m .16944 .7418 L .16214 .75157 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64117 .75902 m .61078 .25486 L .62849 .26405 L p .707 .577 .707 r
F P
0 g
s
.16116 .70066 m .17259 .66677 L .18871 .66092 L p .707 .577 .707 r
F P
0 g
s
.18782 .60256 m .17921 .65649 L .16291 .66309 L p .707 .577 .707 r
F P
0 g
s
.35749 .72623 m .34606 .76011 L .33457 .74538 L p .707 .577 .707 r
F P
0 g
s
.33457 .74538 m .346 .71149 L .35749 .72623 L p .707 .577 .707 r
F P
0 g
s
.35088 .62963 m .34227 .68356 L .32156 .67274 L p .707 .577 .707 r
F P
0 g
s
.32156 .67274 m .33017 .6188 L .35088 .62963 L p .707 .577 .707 r
F P
0 g
s
.17921 .65649 m .18782 .60256 L .2117 .59913 L p .707 .577 .707 r
F P
0 g
s
.18871 .66092 m .17729 .6948 L .16116 .70066 L p .707 .577 .707 r
F P
0 g
s
.16944 .7418 m .17473 .72467 L .19089 .71871 L p .707 .577 .707 r
F P
0 g
s
.36094 .78006 m .35565 .79718 L .344 .78295 L p .707 .577 .707 r
F P
0 g
s
.344 .78295 m .34929 .76582 L .36094 .78006 L p .707 .577 .707 r
F P
0 g
s
.3856 .77918 m .35521 .27502 L .3783 .26419 L p .707 .577 .707 r
F P
0 g
s
.35521 .27502 m .3856 .77918 L .37559 .79056 L p .707 .577 .707 r
F P
0 g
s
.19089 .71871 m .1856 .73584 L .16944 .7418 L p .707 .577 .707 r
F P
0 g
s
.17729 .6948 m .18871 .66092 L .21206 .65967 L p .707 .577 .707 r
F P
0 g
s
.2117 .59913 m .20309 .65307 L .17921 .65649 L p .707 .577 .707 r
F P
0 g
s
.33017 .6188 m .32156 .67274 L .29449 .6635 L p .707 .577 .707 r
F P
0 g
s
.29449 .6635 m .30309 .60956 L .33017 .6188 L p .707 .577 .707 r
F P
0 g
s
.20309 .65307 m .2117 .59913 L .24081 .59922 L p .707 .577 .707 r
F P
0 g
s
.346 .71149 m .33457 .74538 L .31491 .73029 L p .707 .577 .707 r
F P
0 g
s
.31491 .73029 m .32633 .69641 L .346 .71149 L p .707 .577 .707 r
F P
0 g
s
.61078 .25486 m .64117 .75902 L .61152 .75235 L p .707 .577 .707 r
F P
0 g
s
.61152 .75235 m .58112 .24819 L .61078 .25486 L p .707 .577 .707 r
F P
0 g
s
.21206 .65967 m .20063 .69355 L .17729 .6948 L p .707 .577 .707 r
F P
0 g
s
.1856 .73584 m .19089 .71871 L .21433 .71714 L p .707 .577 .707 r
F P
0 g
s
.30309 .60956 m .29449 .6635 L .26369 .65675 L p .707 .577 .707 r
F P
0 g
s
.26369 .65675 m .2723 .60282 L .30309 .60956 L p .707 .577 .707 r
F P
0 g
s
.2322 .65316 m .24081 .59922 L .2723 .60282 L p .707 .577 .707 r
F P
0 g
s
.24081 .59922 m .2322 .65316 L .20309 .65307 L p .707 .577 .707 r
F P
0 g
s
.34929 .76582 m .344 .78295 L .32413 .76849 L p .707 .577 .707 r
F P
0 g
s
.32413 .76849 m .32942 .75137 L .34929 .76582 L p .707 .577 .707 r
F P
0 g
s
.20063 .69355 m .21206 .65967 L .24034 .66314 L p .707 .577 .707 r
F P
0 g
s
.21433 .71714 m .20904 .73426 L .1856 .73584 L p .707 .577 .707 r
F P
0 g
s
.2723 .60282 m .26369 .65675 L .2322 .65316 L p .707 .577 .707 r
F P
0 g
s
.7296 .65723 m .7382 .60329 L .70741 .59655 L p .707 .577 .707 r
F P
0 g
s
.7382 .60329 m .7296 .65723 L .76109 .66082 L p .707 .577 .707 r
F P
0 g
s
.76109 .66082 m .7697 .60689 L .7382 .60329 L p .707 .577 .707 r
F P
0 g
s
.32633 .69641 m .31491 .73029 L .28899 .71634 L p .707 .577 .707 r
F P
0 g
s
.28899 .71634 m .30041 .68245 L .32633 .69641 L p .707 .577 .707 r
F P
0 g
s
.7697 .60689 m .76109 .66082 L .7902 .66091 L p .707 .577 .707 r
F P
0 g
s
.7902 .66091 m .79881 .60698 L .7697 .60689 L p .707 .577 .707 r
F P
0 g
s
.69881 .65048 m .70741 .59655 L .68033 .58731 L p .707 .577 .707 r
F P
0 g
s
.70741 .59655 m .69881 .65048 L .7296 .65723 L p .707 .577 .707 r
F P
0 g
s
.3783 .26419 m .4087 .76835 L .3856 .77918 L p .707 .577 .707 r
F P
0 g
s
.4087 .76835 m .3783 .26419 L .41222 .25496 L p .707 .577 .707 r
F P
0 g
s
.24034 .66314 m .22891 .69702 L .20063 .69355 L p .707 .577 .707 r
F P
0 g
s
.22891 .69702 m .24034 .66314 L .27078 .67099 L p .707 .577 .707 r
F P
0 g
s
.20904 .73426 m .21433 .71714 L .24277 .72011 L p .707 .577 .707 r
F P
0 g
s
.30041 .68245 m .28899 .71634 L .25936 .70487 L p .707 .577 .707 r
F P
0 g
s
.25936 .70487 m .27078 .67099 L .30041 .68245 L p .707 .577 .707 r
F P
0 g
s
.32942 .75137 m .32413 .76849 L .29799 .75523 L p .707 .577 .707 r
F P
0 g
s
.29799 .75523 m .30328 .7381 L .32942 .75137 L p .707 .577 .707 r
F P
0 g
s
.27078 .67099 m .25936 .70487 L .22891 .69702 L p .707 .577 .707 r
F P
0 g
s
.79881 .60698 m .7902 .66091 L .81408 .65749 L p .707 .577 .707 r
F P
0 g
s
.81408 .65749 m .82268 .60356 L .79881 .60698 L p .707 .577 .707 r
F P
0 g
s
.24277 .72011 m .23748 .73724 L .20904 .73426 L p .707 .577 .707 r
F P
0 g
s
.67173 .64125 m .68033 .58731 L .65962 .57649 L p .707 .577 .707 r
F P
0 g
s
.68033 .58731 m .67173 .64125 L .69881 .65048 L p .707 .577 .707 r
F P
0 g
s
.58112 .24819 m .61152 .75235 L .57284 .74885 L p .707 .577 .707 r
F P
0 g
s
.57284 .74885 m .54244 .24469 L .58112 .24819 L p .707 .577 .707 r
F P
0 g
s
.23748 .73724 m .24277 .72011 L .27342 .72733 L p .707 .577 .707 r
F P
0 g
s
.72294 .72743 m .73437 .69355 L .70473 .68209 L p .707 .577 .707 r
F P
0 g
s
.73437 .69355 m .72294 .72743 L .75339 .73529 L p .707 .577 .707 r
F P
0 g
s
.75339 .73529 m .76481 .70141 L .73437 .69355 L p .707 .577 .707 r
F P
0 g
s
.30328 .7381 m .29799 .75523 L .26813 .74446 L p .707 .577 .707 r
F P
0 g
s
.26813 .74446 m .27342 .72733 L .30328 .7381 L p .707 .577 .707 r
F P
0 g
s
.69331 .71597 m .70473 .68209 L .67882 .66813 L p .707 .577 .707 r
F P
0 g
s
.70473 .68209 m .69331 .71597 L .72294 .72743 L p .707 .577 .707 r
F P
0 g
s
.27342 .72733 m .26813 .74446 L .23748 .73724 L p .707 .577 .707 r
F P
0 g
s
.76481 .70141 m .75339 .73529 L .78167 .73876 L p .707 .577 .707 r
F P
0 g
s
.78167 .73876 m .79309 .70487 L .76481 .70141 L p .707 .577 .707 r
F P
0 g
s
.44262 .75912 m .41222 .25496 L .45364 .24826 L p .707 .577 .707 r
F P
0 g
s
.41222 .25496 m .44262 .75912 L .4087 .76835 L p .707 .577 .707 r
F P
0 g
s
.65962 .57649 m .65102 .63042 L .67173 .64125 L p .707 .577 .707 r
F P
0 g
s
.82268 .60356 m .81408 .65749 L .83039 .65089 L p .707 .577 .707 r
F P
0 g
s
.83039 .65089 m .83899 .59696 L .82268 .60356 L p .707 .577 .707 r
F P
0 g
s
.65102 .63042 m .65962 .57649 L .6473 .56513 L p .707 .577 .707 r
F P
0 g
s
.66739 .70201 m .67882 .66813 L .65915 .65305 L p .707 .577 .707 r
F P
0 g
s
.67882 .66813 m .66739 .70201 L .69331 .71597 L p .707 .577 .707 r
F P
0 g
s
.73217 .77456 m .73746 .75743 L .7076 .74666 L p .707 .577 .707 r
F P
0 g
s
.73746 .75743 m .73217 .77456 L .76281 .78179 L p .707 .577 .707 r
F P
0 g
s
.76281 .78179 m .7681 .76466 L .73746 .75743 L p .707 .577 .707 r
F P
0 g
s
.54244 .24469 m .57284 .74885 L .52891 .74888 L p .707 .577 .707 r
F P
0 g
s
.52891 .74888 m .49851 .24472 L .54244 .24469 L p .707 .577 .707 r
F P
0 g
s
.79309 .70487 m .78167 .73876 L .80501 .7375 L p .707 .577 .707 r
F P
0 g
s
.80501 .7375 m .81644 .70362 L .79309 .70487 L p .707 .577 .707 r
F P
0 g
s
.70231 .76379 m .7076 .74666 L .68146 .7334 L p .707 .577 .707 r
F P
0 g
s
.7076 .74666 m .70231 .76379 L .73217 .77456 L p .707 .577 .707 r
F P
0 g
s
.7681 .76466 m .76281 .78179 L .79125 .78476 L p .707 .577 .707 r
F P
0 g
s
.79125 .78476 m .79654 .76763 L .7681 .76466 L p .707 .577 .707 r
F P
0 g
s
.48404 .75242 m .45364 .24826 L .49851 .24472 L p .707 .577 .707 r
F P
0 g
s
.45364 .24826 m .48404 .75242 L .44262 .75912 L p .707 .577 .707 r
F P
0 g
s
.68146 .7334 m .67617 .75053 L .70231 .76379 L p .707 .577 .707 r
F P
0 g
s
.49851 .24472 m .52891 .74888 L .48404 .75242 L p .707 .577 .707 r
F P
0 g
s
.67617 .75053 m .68146 .7334 L .66159 .71894 L p .707 .577 .707 r
F P
0 g
s
.79654 .76763 m .79125 .78476 L .8147 .78319 L p .707 .577 .707 r
F P
0 g
s
.8147 .78319 m .81999 .76606 L .79654 .76763 L p .707 .577 .707 r
F P
0 g
s
.83899 .59696 m .83039 .65089 L .83753 .64176 L p .707 .577 .707 r
F P
0 g
s
.83753 .64176 m .84614 .58782 L .83899 .59696 L p .707 .577 .707 r
F P
0 g
s
.66159 .71894 m .6563 .73607 L .67617 .75053 L p .707 .577 .707 r
F P
0 g
s
.6387 .61907 m .6473 .56513 L .64458 .55436 L p .707 .577 .707 r
F P
0 g
s
.81644 .70362 m .80501 .7375 L .82114 .73165 L p .707 .577 .707 r
F P
0 g
s
.82114 .73165 m .83256 .69777 L .81644 .70362 L p .707 .577 .707 r
F P
0 g
s
.64766 .63832 m .63624 .6722 L .64773 .68693 L p .707 .577 .707 r
F P
0 g
s
.6563 .73607 m .66159 .71894 L .64994 .70471 L p .707 .577 .707 r
F P
0 g
s
.81999 .76606 m .8147 .78319 L .83086 .77722 L p .707 .577 .707 r
F P
0 g
s
.83086 .77722 m .83615 .76009 L .81999 .76606 L p .707 .577 .707 r
F P
0 g
s
.64458 .55436 m .63598 .6083 L .6387 .61907 L p .707 .577 .707 r
F P
0 g
s
.64994 .70471 m .64465 .72184 L .6563 .73607 L p .707 .577 .707 r
F P
0 g
s
.63624 .6722 m .64766 .63832 L .64547 .62538 L p .707 .577 .707 r
F P
0 g
s
.84614 .58782 m .83753 .64176 L .83481 .63099 L p .707 .577 .707 r
F P
0 g
s
.83481 .63099 m .84341 .57705 L .84614 .58782 L p .707 .577 .707 r
F P
0 g
s
.83256 .69777 m .82114 .73165 L .82846 .72177 L p .707 .577 .707 r
F P
0 g
s
.82846 .72177 m .83989 .68789 L .83256 .69777 L p .707 .577 .707 r
F P
0 g
s
.63598 .6083 m .64458 .55436 L .65172 .54523 L p .707 .577 .707 r
F P
0 g
s
.64547 .62538 m .63405 .65926 L .63624 .6722 L p .707 .577 .707 r
F P
0 g
s
.64465 .72184 m .64994 .70471 L .64765 .69209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83615 .76009 m .83086 .77722 L .83815 .76745 L p .707 .577 .707 r
F P
0 g
s
.83815 .76745 m .84345 .75033 L .83615 .76009 L p .707 .577 .707 r
F P
0 g
s
.64765 .69209 m .64236 .70922 L .64465 .72184 L p .707 .577 .707 r
F P
0 g
s
.65172 .54523 m .64312 .59917 L .63598 .6083 L p .707 .577 .707 r
F P
0 g
s
.63405 .65926 m .64547 .62538 L .6528 .6155 L p .707 .577 .707 r
F P
0 g
s
.84341 .57705 m .83481 .63099 L .82249 .61964 L p .707 .577 .707 r
F P
0 g
s
.82249 .61964 m .83109 .5657 L .84341 .57705 L p .707 .577 .707 r
F P
0 g
s
.83989 .68789 m .82846 .72177 L .82627 .70883 L p .707 .577 .707 r
F P
0 g
s
.82627 .70883 m .8377 .67495 L .83989 .68789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64312 .59917 m .65172 .54523 L .66803 .53863 L p .707 .577 .707 r
F P
0 g
s
.6528 .6155 m .64137 .64938 L .63405 .65926 L p .707 .577 .707 r
F P
0 g
s
.38659 .62912 m .39519 .57518 L .3644 .56844 L p .707 .577 .707 r
F P
0 g
s
.39519 .57518 m .38659 .62912 L .41808 .63271 L p .707 .577 .707 r
F P
0 g
s
.41808 .63271 m .42669 .57878 L .39519 .57518 L p .707 .577 .707 r
F P
0 g
s
.64236 .70922 m .64765 .69209 L .65494 .68232 L p .707 .577 .707 r
F P
0 g
s
.42669 .57878 m .41808 .63271 L .44719 .6328 L p .707 .577 .707 r
F P
0 g
s
.44719 .6328 m .4558 .57887 L .42669 .57878 L p .707 .577 .707 r
F P
0 g
s
.3558 .62237 m .3644 .56844 L .33732 .5592 L p .707 .577 .707 r
F P
0 g
s
.3644 .56844 m .3558 .62237 L .38659 .62912 L p .707 .577 .707 r
F P
0 g
s
.84345 .75033 m .83815 .76745 L .83586 .75483 L p .707 .577 .707 r
F P
0 g
s
.83586 .75483 m .84115 .73771 L .84345 .75033 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65494 .68232 m .64965 .69945 L .64236 .70922 L p .707 .577 .707 r
F P
0 g
s
.66803 .53863 m .65943 .59257 L .64312 .59917 L p .707 .577 .707 r
F P
0 g
s
.64137 .64938 m .6528 .6155 L .66893 .60964 L p .707 .577 .707 r
F P
0 g
s
.4558 .57887 m .44719 .6328 L .47107 .62938 L p .707 .577 .707 r
F P
0 g
s
.47107 .62938 m .47967 .57544 L .4558 .57887 L p .707 .577 .707 r
F P
0 g
s
.83109 .5657 m .82249 .61964 L .80178 .60881 L p .707 .577 .707 r
F P
0 g
s
.80178 .60881 m .81038 .55488 L .83109 .5657 L p .707 .577 .707 r
F P
0 g
s
.32872 .61313 m .33732 .5592 L .31661 .54837 L p .707 .577 .707 r
F P
0 g
s
.33732 .5592 m .32872 .61313 L .3558 .62237 L p .707 .577 .707 r
F P
0 g
s
.8377 .67495 m .82627 .70883 L .81479 .6941 L p .707 .577 .707 r
F P
0 g
s
.81479 .6941 m .82621 .66022 L .8377 .67495 L p .707 .577 .707 r
F P
0 g
s
.65943 .59257 m .66803 .53863 L .69191 .53521 L p .707 .577 .707 r
F P
0 g
s
.37993 .68667 m .39136 .65279 L .36172 .64133 L p .707 .577 .707 r
F P
0 g
s
.39136 .65279 m .37993 .68667 L .41038 .69452 L p .707 .577 .707 r
F P
0 g
s
.41038 .69452 m .4218 .66064 L .39136 .65279 L p .707 .577 .707 r
F P
0 g
s
.3503 .67521 m .36172 .64133 L .33581 .62737 L p .707 .577 .707 r
F P
0 g
s
.36172 .64133 m .3503 .67521 L .37993 .68667 L p .707 .577 .707 r
F P
0 g
s
.66893 .60964 m .6575 .64353 L .64137 .64938 L p .707 .577 .707 r
F P
0 g
s
.4218 .66064 m .41038 .69452 L .43866 .69799 L p .707 .577 .707 r
F P
0 g
s
.43866 .69799 m .45008 .66411 L .4218 .66064 L p .707 .577 .707 r
F P
0 g
s
.64965 .69945 m .65494 .68232 L .6711 .67636 L p .707 .577 .707 r
F P
0 g
s
.84115 .73771 m .83586 .75483 L .82421 .7406 L p .707 .577 .707 r
F P
0 g
s
.82421 .7406 m .8295 .72347 L .84115 .73771 L p .707 .577 .707 r
F P
0 g
s
.38916 .72487 m .39445 .70775 L .36459 .69697 L p .707 .577 .707 r
F P
0 g
s
.39445 .70775 m .38916 .72487 L .4198 .7321 L p .707 .577 .707 r
F P
0 g
s
.4198 .7321 m .42509 .71497 L .39445 .70775 L p .707 .577 .707 r
F P
0 g
s
.6711 .67636 m .66581 .69349 L .64965 .69945 L p .707 .577 .707 r
F P
0 g
s
.31661 .54837 m .30801 .60231 L .32872 .61313 L p .707 .577 .707 r
F P
0 g
s
.47967 .57544 m .47107 .62938 L .48738 .62278 L p .707 .577 .707 r
F P
0 g
s
.48738 .62278 m .49598 .56884 L .47967 .57544 L p .707 .577 .707 r
F P
0 g
s
.69191 .53521 m .68331 .58914 L .65943 .59257 L p .707 .577 .707 r
F P
0 g
s
.32438 .66125 m .33581 .62737 L .31614 .61229 L p .707 .577 .707 r
F P
0 g
s
.33581 .62737 m .32438 .66125 L .3503 .67521 L p .707 .577 .707 r
F P
0 g
s
.81038 .55488 m .80178 .60881 L .7747 .59957 L p .707 .577 .707 r
F P
0 g
s
.7747 .59957 m .78331 .54564 L .81038 .55488 L p .707 .577 .707 r
F P
0 g
s
.6575 .64353 m .66893 .60964 L .69227 .60839 L p .707 .577 .707 r
F P
0 g
s
.3593 .7141 m .36459 .69697 L .33845 .68371 L p .707 .577 .707 r
F P
0 g
s
.36459 .69697 m .3593 .7141 L .38916 .72487 L p .707 .577 .707 r
F P
0 g
s
.30801 .60231 m .31661 .54837 L .30429 .53702 L p .707 .577 .707 r
F P
0 g
s
.68331 .58914 m .69191 .53521 L .72102 .5353 L p .707 .577 .707 r
F P
0 g
s
.42509 .71497 m .4198 .7321 L .44824 .73507 L p .707 .577 .707 r
F P
0 g
s
.44824 .73507 m .45353 .71794 L .42509 .71497 L p .707 .577 .707 r
F P
0 g
s
.45008 .66411 m .43866 .69799 L .462 .69674 L p .707 .577 .707 r
F P
0 g
s
.462 .69674 m .47343 .66286 L .45008 .66411 L p .707 .577 .707 r
F P
0 g
s
.82621 .66022 m .81479 .6941 L .79512 .67902 L p .707 .577 .707 r
F P
0 g
s
.79512 .67902 m .80654 .64514 L .82621 .66022 L p .707 .577 .707 r
F P
0 g
s
.33845 .68371 m .33316 .70084 L .3593 .7141 L p .707 .577 .707 r
F P
0 g
s
.31614 .61229 m .30472 .64617 L .32438 .66125 L p .707 .577 .707 r
F P
0 g
s
.78331 .54564 m .7747 .59957 L .74391 .59283 L p .707 .577 .707 r
F P
0 g
s
.74391 .59283 m .75251 .53889 L .78331 .54564 L p .707 .577 .707 r
F P
0 g
s
.33316 .70084 m .33845 .68371 L .31858 .66926 L p .707 .577 .707 r
F P
0 g
s
.69227 .60839 m .68084 .64227 L .6575 .64353 L p .707 .577 .707 r
F P
0 g
s
.71242 .58923 m .72102 .5353 L .75251 .53889 L p .707 .577 .707 r
F P
0 g
s
.72102 .5353 m .71242 .58923 L .68331 .58914 L p .707 .577 .707 r
F P
0 g
s
.45353 .71794 m .44824 .73507 L .47169 .7335 L p .707 .577 .707 r
F P
0 g
s
.47169 .7335 m .47698 .71637 L .45353 .71794 L p .707 .577 .707 r
F P
0 g
s
.66581 .69349 m .6711 .67636 L .69455 .67479 L p .707 .577 .707 r
F P
0 g
s
.75251 .53889 m .74391 .59283 L .71242 .58923 L p .707 .577 .707 r
F P
0 g
s
.30429 .53702 m .29569 .59096 L .30801 .60231 L p .707 .577 .707 r
F P
0 g
s
.30472 .64617 m .31614 .61229 L .30465 .59755 L p .707 .577 .707 r
F P
0 g
s
.31858 .66926 m .31329 .68638 L .33316 .70084 L p .707 .577 .707 r
F P
0 g
s
.68084 .64227 m .69227 .60839 L .72055 .61186 L p .707 .577 .707 r
F P
0 g
s
.8295 .72347 m .82421 .7406 L .80434 .72614 L p .707 .577 .707 r
F P
0 g
s
.80434 .72614 m .80964 .70902 L .8295 .72347 L p .707 .577 .707 r
F P
0 g
s
.69455 .67479 m .68926 .69191 L .66581 .69349 L p .707 .577 .707 r
F P
0 g
s
.49598 .56884 m .48738 .62278 L .49452 .61365 L p .707 .577 .707 r
F P
0 g
s
.49452 .61365 m .50313 .55971 L .49598 .56884 L p .707 .577 .707 r
F P
0 g
s
.47343 .66286 m .462 .69674 L .47813 .69089 L p .707 .577 .707 r
F P
0 g
s
.47813 .69089 m .48955 .65701 L .47343 .66286 L p .707 .577 .707 r
F P
0 g
s
.80654 .64514 m .79512 .67902 L .7692 .66506 L p .707 .577 .707 r
F P
0 g
s
.7692 .66506 m .78063 .63118 L .80654 .64514 L p .707 .577 .707 r
F P
0 g
s
.29569 .59096 m .30429 .53702 L .30157 .52625 L p .707 .577 .707 r
F P
0 g
s
.30465 .59755 m .29323 .63143 L .30472 .64617 L p .707 .577 .707 r
F P
0 g
s
.31329 .68638 m .31858 .66926 L .30693 .65502 L p .707 .577 .707 r
F P
0 g
s
.72055 .61186 m .70912 .64574 L .68084 .64227 L p .707 .577 .707 r
F P
0 g
s
.70912 .64574 m .72055 .61186 L .751 .61971 L p .707 .577 .707 r
F P
0 g
s
.78063 .63118 m .7692 .66506 L .73957 .65359 L p .707 .577 .707 r
F P
0 g
s
.73957 .65359 m .751 .61971 L .78063 .63118 L p .707 .577 .707 r
F P
0 g
s
.47698 .71637 m .47169 .7335 L .48785 .72753 L p .707 .577 .707 r
F P
0 g
s
.48785 .72753 m .49314 .71041 L .47698 .71637 L p .707 .577 .707 r
F P
0 g
s
.68926 .69191 m .69455 .67479 L .72299 .67776 L p .707 .577 .707 r
F P
0 g
s
.30693 .65502 m .30164 .67215 L .31329 .68638 L p .707 .577 .707 r
F P
0 g
s
.751 .61971 m .73957 .65359 L .70912 .64574 L p .707 .577 .707 r
F P
0 g
s
.80964 .70902 m .80434 .72614 L .7782 .71288 L p .707 .577 .707 r
F P
0 g
s
.7782 .71288 m .78349 .69575 L .80964 .70902 L p .707 .577 .707 r
F P
0 g
s
.29323 .63143 m .30465 .59755 L .30246 .58461 L p .707 .577 .707 r
F P
0 g
s
.72299 .67776 m .7177 .69489 L .68926 .69191 L p .707 .577 .707 r
F P
0 g
s
.30157 .52625 m .29296 .58019 L .29569 .59096 L p .707 .577 .707 r
F P
0 g
s
.48955 .65701 m .47813 .69089 L .48545 .68101 L p .707 .577 .707 r
F P
0 g
s
.48545 .68101 m .49688 .64713 L .48955 .65701 L p .707 .577 .707 r
F P
0 g
s
.7177 .69489 m .72299 .67776 L .75364 .68498 L p .707 .577 .707 r
F P
0 g
s
.50313 .55971 m .49452 .61365 L .4918 .60288 L p .707 .577 .707 r
F P
0 g
s
.4918 .60288 m .5004 .54894 L .50313 .55971 L p .707 .577 .707 r
F P
0 g
s
.78349 .69575 m .7782 .71288 L .74835 .70211 L p .707 .577 .707 r
F P
0 g
s
.74835 .70211 m .75364 .68498 L .78349 .69575 L p .707 .577 .707 r
F P
0 g
s
.29296 .58019 m .30157 .52625 L .30871 .51712 L p .707 .577 .707 r
F P
0 g
s
.75364 .68498 m .74835 .70211 L .7177 .69489 L p .707 .577 .707 r
F P
0 g
s
.30246 .58461 m .29104 .6185 L .29323 .63143 L p .707 .577 .707 r
F P
0 g
s
.30164 .67215 m .30693 .65502 L .30464 .6424 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49314 .71041 m .48785 .72753 L .49514 .71776 L p .707 .577 .707 r
F P
0 g
s
.49514 .71776 m .50043 .70064 L .49314 .71041 L p .707 .577 .707 r
F P
0 g
s
.30464 .6424 m .29935 .65953 L .30164 .67215 L p .707 .577 .707 r
F P
0 g
s
.29104 .6185 m .30246 .58461 L .30979 .57474 L p .707 .577 .707 r
F P
0 g
s
.30871 .51712 m .30011 .57105 L .29296 .58019 L p .707 .577 .707 r
F P
0 g
s
.49688 .64713 m .48545 .68101 L .48326 .66807 L p .707 .577 .707 r
F P
0 g
s
.48326 .66807 m .49469 .63419 L .49688 .64713 L p .707 .577 .707 r
F P
0 g
s
.5004 .54894 m .4918 .60288 L .47948 .59152 L p .707 .577 .707 r
F P
0 g
s
.47948 .59152 m .48808 .53759 L .5004 .54894 L p .707 .577 .707 r
F P
0 g
s
.30011 .57105 m .30871 .51712 L .32502 .51052 L p .707 .577 .707 r
F P
0 g
s
.30979 .57474 m .29836 .60862 L .29104 .6185 L p .707 .577 .707 r
F P
0 g
s
.29935 .65953 m .30464 .6424 L .31193 .63263 L p .707 .577 .707 r
F P
0 g
s
.50043 .70064 m .49514 .71776 L .49285 .70515 L p .707 .577 .707 r
F P
0 g
s
.49285 .70515 m .49814 .68802 L .50043 .70064 L p .707 .577 .707 r
F P
0 g
s
.31193 .63263 m .30664 .64976 L .29935 .65953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29836 .60862 m .30979 .57474 L .32592 .56888 L p .707 .577 .707 r
F P
0 g
s
.32502 .51052 m .31642 .56445 L .30011 .57105 L p .707 .577 .707 r
F P
0 g
s
.49469 .63419 m .48326 .66807 L .47177 .65334 L p .707 .577 .707 r
F P
0 g
s
.47177 .65334 m .4832 .61946 L .49469 .63419 L p .707 .577 .707 r
F P
0 g
s
.48808 .53759 m .47948 .59152 L .45877 .5807 L p .707 .577 .707 r
F P
0 g
s
.45877 .5807 m .46737 .52676 L .48808 .53759 L p .707 .577 .707 r
F P
0 g
s
.31642 .56445 m .32502 .51052 L .3489 .50709 L p .707 .577 .707 r
F P
0 g
s
.32592 .56888 m .31449 .60276 L .29836 .60862 L p .707 .577 .707 r
F P
0 g
s
.30664 .64976 m .31193 .63263 L .32809 .62667 L p .707 .577 .707 r
F P
0 g
s
.49814 .68802 m .49285 .70515 L .4812 .69091 L p .707 .577 .707 r
F P
0 g
s
.4812 .69091 m .48649 .67378 L .49814 .68802 L p .707 .577 .707 r
F P
0 g
s
.32809 .62667 m .3228 .6438 L .30664 .64976 L p .707 .577 .707 r
F P
0 g
s
.31449 .60276 m .32592 .56888 L .34926 .56763 L p .707 .577 .707 r
F P
0 g
s
.3489 .50709 m .34029 .56103 L .31642 .56445 L p .707 .577 .707 r
F P
0 g
s
.46737 .52676 m .45877 .5807 L .43169 .57146 L p .707 .577 .707 r
F P
0 g
s
.43169 .57146 m .44029 .51752 L .46737 .52676 L p .707 .577 .707 r
F P
0 g
s
.34029 .56103 m .3489 .50709 L .37801 .50718 L p .707 .577 .707 r
F P
0 g
s
.4832 .61946 m .47177 .65334 L .45211 .63825 L p .707 .577 .707 r
F P
0 g
s
.45211 .63825 m .46353 .60437 L .4832 .61946 L p .707 .577 .707 r
F P
0 g
s
.34926 .56763 m .33783 .60151 L .31449 .60276 L p .707 .577 .707 r
F P
0 g
s
.3228 .6438 m .32809 .62667 L .35154 .6251 L p .707 .577 .707 r
F P
0 g
s
.44029 .51752 m .43169 .57146 L .4009 .56472 L p .707 .577 .707 r
F P
0 g
s
.4009 .56472 m .4095 .51078 L .44029 .51752 L p .707 .577 .707 r
F P
0 g
s
.3694 .56112 m .37801 .50718 L .4095 .51078 L p .707 .577 .707 r
F P
0 g
s
.37801 .50718 m .3694 .56112 L .34029 .56103 L p .707 .577 .707 r
F P
0 g
s
.48649 .67378 m .4812 .69091 L .46133 .67645 L p .707 .577 .707 r
F P
0 g
s
.46133 .67645 m .46662 .65933 L .48649 .67378 L p .707 .577 .707 r
F P
0 g
s
.33783 .60151 m .34926 .56763 L .37754 .5711 L p .707 .577 .707 r
F P
0 g
s
.35154 .6251 m .34625 .64223 L .3228 .6438 L p .707 .577 .707 r
F P
0 g
s
.4095 .51078 m .4009 .56472 L .3694 .56112 L p .707 .577 .707 r
F P
0 g
s
.46353 .60437 m .45211 .63825 L .42619 .6243 L p .707 .577 .707 r
F P
0 g
s
.42619 .6243 m .43762 .59042 L .46353 .60437 L p .707 .577 .707 r
F P
0 g
s
.37754 .5711 m .36611 .60498 L .33783 .60151 L p .707 .577 .707 r
F P
0 g
s
.36611 .60498 m .37754 .5711 L .40799 .57895 L p .707 .577 .707 r
F P
0 g
s
.34625 .64223 m .35154 .6251 L .37998 .62807 L p .707 .577 .707 r
F P
0 g
s
.43762 .59042 m .42619 .6243 L .39656 .61283 L p .707 .577 .707 r
F P
0 g
s
.39656 .61283 m .40799 .57895 L .43762 .59042 L p .707 .577 .707 r
F P
0 g
s
.46662 .65933 m .46133 .67645 L .43519 .66319 L p .707 .577 .707 r
F P
0 g
s
.43519 .66319 m .44048 .64606 L .46662 .65933 L p .707 .577 .707 r
F P
0 g
s
.40799 .57895 m .39656 .61283 L .36611 .60498 L p .707 .577 .707 r
F P
0 g
s
.37998 .62807 m .37469 .6452 L .34625 .64223 L p .707 .577 .707 r
F P
0 g
s
.37469 .6452 m .37998 .62807 L .41063 .63529 L p .707 .577 .707 r
F P
0 g
s
.44048 .64606 m .43519 .66319 L .40534 .65242 L p .707 .577 .707 r
F P
0 g
s
.40534 .65242 m .41063 .63529 L .44048 .64606 L p .707 .577 .707 r
F P
0 g
s
.41063 .63529 m .40534 .65242 L .37469 .6452 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Qgoo6@00OGoo001nOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Qoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH3001]Ool006eoo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006]oo`00JWoo0`0025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0J7oo001XOol200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIZOol006Ioo`8000=JEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<007ooOol0Igoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUIYOol0
06=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYFJGoo001ROol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUIYOol0069oo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF
00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001ROol00`00FUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006=oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001XOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVQoo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol006=oo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEUYF001JEVQoo`00Hgoo00<005YF00001eYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo
001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00I7oo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006Aoo`03001JEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYFFUH005YFIgoo001TOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001J
EVMoo`00I7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00H7oo40002EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00
Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00FGoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol0
05Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
FUH005YFIGoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVEoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001TOol005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000I7oo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Qooa0004aoo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0017oo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00AGoo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00=JEP<003Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF0`00=7oo001DOol20003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000bOol005Aoo`8000=J
EP@0009JEP03001JEP0000<00005Ool005YFFUH00003FUH70006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<7oo001COol01000FUH005YF0`000UYF3P00
15YF1@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP8002moo`00Dgoo00@005YF0000009JEP@000IJEP04001JEUYFFUH<0005FUH40006
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool005=oo`<0009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEP0000L000EJEP04001JEP000004FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P000UYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Goo001COol00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP06FUH20005FUH01`00FUIJEUYF001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000;Goo001COol01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00@005YF000000=JEP07001JEUYF
FUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP04001JEUYFFUH200000eYF001JEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<00003FUH005YF00EJEP8000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEP000003FUH50002FUH00`00FUH000030008Ool70006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJ
EP07001JEP00FUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF000005YF00<000IJEP03001JEUYF00=JEP@000Ioo`<0009oo`@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000iOol@000;Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJ
EP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000300000goo000000030005Ool4
0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000goo00<005YF00000UYF300015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qo
o`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0039oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH00000008000=JEP03001JEUYF00AJEPH0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP8000IJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD00003FUH0000000X00003FUH005YF00EJEP04001JEUYFFUH2000]Ool0031oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP06001o
o`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00P000eYF00<005YF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
00=JEP00FUH00UYF00<005YFFUH0300025YF0`001UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJ
EP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0015YF1P001UYF00<005YFFUH01UYF100025YF00<005YFFUH01EYF00@005YFFUIJEP80
009JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000EJEP<0
0003FUH005YF00AJEP04001JEUYFFUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH0
0`00FUIJEP02FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEPD00003Ool000000080009JEP03001JEUYF
00IJEP04001JEUYFFUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0
05YF00=JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEP@000=oo`@000IJEP03001JEUYF
00EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP80009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH00UYF0P0000=JEP0000002@000UYF00<005YFFUH01UYF00@005YF000000MJEP03001J
EUYF00EJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP000080
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000QJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEP0002eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01P000UYF00<0
05YFFUH00UYF2P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH007oo02aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEP0000l000=JEP03001JEUYF00AJEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP030007FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP8000AJEP04001J
EUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200001EYF001JEUYF
00000eYF1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00L005YF
FUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH50007FUH70006FUH00`00FUIJEP06FUH20005
FUH01@00FUIJEUYF00000eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0`000UYF2`0000=JEP0000001@001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=J
EP00FUH00eYF0P00;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH6
0002FUH00`00FUIJEP07FUH30004FUH30004FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH500000eYF001JEP03FUH30002Ool50003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH30004FUH2000_Ool002eoo`8000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP07FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70007FUH01000FUIJEUYF0P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP<000AJEP05001JEUYFFUH00002FUH00`00Oomoo`04Ool40002FUH40008FUH00`00FUIJEP06FUH0
0`00FUIJEP02000015YF00000000<7oo000]Ool20003FUH40002FUH00`00FUH000030008Ool70006
FUH00`00FUH0000200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00005
0005FUH00`00FUIJEP03FUH20003FUH01P00FUIJEP00FUH000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP<000AJEP800003FUH005YF00=JEP8000Qoo`P000IJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo035oo`00;7oo00@005YF001JEP<0009JEPh000Aoo`D00003Ool0
00000080009JEP04001JEP00FUH20002FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50000
0eYF001JEP07FUH01000FUIJEP000UYF00<005YF00001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00P001UYF00<007ooOol037oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<007ooOol0<7oo000/Ool01000FUH000000UYF10001UYF00@0
05YFFUIJEP`000Eoo`H00004FUH005YFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP020008FUH600000eYF001JEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH01@00FUIJEUYF00001UYF0P0047oo0P0000=JEP00FUH01eYF00<005YFFUH015YF0P00
<Goo000/Ool30002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070007Ool20002
FUH01000FUH005YF0P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF
00P005YFFUH005YF001JEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00002Goo0`001Goo0P0025YF00<005YFFUH0
0eYF00@005YFFUH0031oo`00;7oo0P000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF300015YF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH015YF0P000UYF00D005YFFUIJEP0000Moo`D000Ioo`8000EJ
EP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEUYF008000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000002FUH01000FUIJEP0015YF0`0015YF0`00
2EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH000060007Ool50008Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02aoo`05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30003FUH01@00FUIJEUYF00000UYF00H005YFFUIJEP00FUH20008FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH01UYF10000eYF00@005YFFUIJEP`000Yoo`<000IJEP03001JEUYF
00=JEP03001oogoo02aoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YF000015YF0P0000=JEP00FUH00UYF0`001EYF00<005YF
00000P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH010003Goo00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH20006FUH20003FUH200001goo00000000FUH005YF00D0009JEP03001JEUYF00EJEP03
001JEUYF00AJEP<0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH00000FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
10002Woo0P0015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP08FUH300000eYF001JEP05FUH300001UYF001J
EP00Ool0009JEPP0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000:Ool01@00FUIJEUYF0000
0eYF00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00@005YFFUIJEP800004FUH007oo0002FUH00`00
FUIJEP0500000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF
1P0015YF00<005YFFUH01eYF00<005YFFUH00UYF0`0027oo0`0015YF00<005YF0000;Woo000/Ool0
0`00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30002FUH0
0`00FUIJEP03FUH200001Goo001JEUYF00000eYF2@0015YF00<005YFFUH015YF00D005YF000005YF
008000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYF0002FUH60006FUH70007FUH00`00FUIJEP05FUH20008Ool00`00FUIJEP02FUH2000_Ool002ao
o`800003FUH00000008000=JEP03001JEUYF00AJEPH000MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP<000QJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP07001JEP00FUH005YF0000
1UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001P0025YF00<005YF
FUH01EYF10000UYF00<005YFFUH01eYF0`001goo00H005YFFUH005YF000_Ool002aoo`<0009JEP06
001oo`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00
25YF00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000P0000AJEP00
000000QJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF008000Eoo`06001JEUYF001J
EP00;goo000/Ool00`00FUH00003FUH00`00Oomoo`030006FUH00`00FUIJEP06FUH40008FUH00`00
FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YF
FUH02EYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH400000eYF000000040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03
FUH800000eYF001oo`0_Ool002]oo`<000AJEP<000=oo`8000AJEP03001JEUYF00IJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH300000eYF001J
EP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP0000000P000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF0P0000IJEP00FUH005YF000`Ool002]oo`03001JEP0000=JEP05001JEUYFFUH0
0004Ool300000eYF001JEP07FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP04FUH3
00000eYF001JEP08FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUH000030007FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP020005FUH300000eYF001J
EP07FUH00`00FUIJEP07FUH01000FUIJEUYF0P0025YF0P000UYF00<005YF0000<7oo000[Ool00`00
FUH00003FUH00`00FUIJEP02FUH20002Ool70005FUH00`00FUIJEP07FUH30007FUH00`00FUIJEP05
FUH2000017oo000000001eYF00<005YFFUH015YF1`001eYF1P0000=JEP00000025YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF00<005YF00000`001eYF
00<005YFFUH00`0015YF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=JEP00Ool0;goo000/
Ool00`00FUIJEP02FUH01000FUIJEUYF1@000UYF00<005YFFUH00UYF1P0025YF00@005YFFUIJEP80
00EJEP03001JEUYF00AJEP03001JEP0000Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
000015YF00<005YFFUH00UYF00<005YFFUH01@001EYF00<005YF000010000UYF00<005YFFUH01UYF
0P000eYF00<005YFFUH00UYF0P00<Goo000/Ool01@00FUIJEUYF00000UYF0P0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00@0
05YFFUH000Aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP8000=JEP03
001JEUYF009JEP800006Ool00000001JEP000UYF1@000UYF00<005YFFUH01EYF00<005YFFUH00`00
1UYF00<007ooOol0;goo000]Ool00`00FUIJEP030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH?0007FUH01@00FUIJEUYF00000goo00<005YFFUH01@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP0200000eYF001JEP03FUH20004Ool300000eYF00000003
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH2000`Ool002eoo`03001JEUYF
008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`03
001JEUYF00AJEP03001JEUYF009JEP05001oogooOol00002FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH0000035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP8000=JEP03001JEP0000Moo`D000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEP0002moo`00;Woo0`000eYF00@005YFFUIJ
EPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000Eoo`8000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF00<005YF00001@0015YF00@005YFFUIJEPD00003FUH005YF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000IJEP07001JEUYFFUH005YF0000
2Woo0`0000=JEP00FUH01eYF00<005YFFUH00UYF00@005YFFUH0009JEP05001JEUYFFUH0000^Ool0
02moo`80009JEPD000MJEPL000IJEP03001JEUYF00IJEP8000Eoo`05001JEUYFFUH00003FUH00`00
FUH00002Ool01000FUIJEP001UYF00<005YFFUH01EYF20001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP<00003FUH0000000ioo`D0
00AJEP04001JEUYFFUH5000017oo0000000015YF00<007ooOol0:goo000_Ool40003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH30004Ool30004FUH00`00FUH00002Ool0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00<001=oo`P000Qo
o`03001JEUYF009JEP03001oogoo02]oo`00;Woo100015YF00<005YFFUH01EYF00<005YFFUH01UYF
1`001eYF00@005YFFUIJEP8000Aoo`05001JEUYFFUH00002FUH01000Oomoo`000UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP8002=oo`03001JEUYF0080
02eoo`00;Woo0`0000=oo`0000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009o
o`8000EJEP03001JEUYF00=JEP8000=oo`06001JEUYF001JEP000goo00@005YFFUH000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEQP000EJEP03001JEUYF00IJEP03001JEUYF009J
EPH000MJEP<0021oo`03001JEUYF008002eoo`00;Woo00@005YF0000009oo`8000MJEP03001JEUYF
00MJEP03001JEUYF009JEP<00006Ool00000001JEP0025YF00@007ooOol0009JEP03001JEP0000=o
o`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH9000<FUH00`00FUIJEP09FUH80006
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0;7oo
000^Ool200000eYF001oo`02Ool00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60008
FUH5000015YF001JEP000goo00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF
009JEP8000EJEP03001JEUYF009JEP<001eoo`03001JEP0002eoo`00;Woo0P000UYF00@007ooOomo
o`8000EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30006FUH00`00FUIJEP030000
0eYF001oo`03Ool00`00FUIJEP08FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP03FUH30003
FUH00`00FUIJEP05FUH4000IOol00`00FUH0000]Ool002ioo`03001JEUYF009JEP03001oogoo009o
o`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009J
EP800003FUH007oo00Aoo`YJEP03001JEUYF009JEP<000MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001J
EUYF00<000UJEP03001JEUYF00@001Aoo`<002ioo`00;Woo00<005YFFUH00UYF0`0017oo0`002EYF
00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH20005Ool:FUH00`00FUH00002
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001JEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH015YF1P0027oo1P0000=J
EP000000;Woo000_Ool01@00FUIJEUYF00000UYF00<007ooOol00goo0P0025YF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP8000Eoo`UJEP<0009JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EP000004FUH00`00FUIJEP03FUH00`00Ool000020004FUH00`00FUIJEP07FUH01000FUIJEUYF2000
0eYF00@005YFFUIJEP8002ioo`00<7oo00<005YF000015YF0P001Goo0`001EYF00<005YF00000P00
0eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001Goo1eYF0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00=JEP03001oogoo009oo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035oo`8000IJEP03001o
ogoo00Eoo`<00003FUH005YF00D0009JEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001J
EUYF0004Ool5FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH00UYF0P001goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00<Woo00<005YFFUH0
15YF0`0027oo20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00@007oo
Oomoo`=JEP8000UJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF009JEP8000Yoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<0031oo`00<goo00<005YFFUH00UYF
00@005YFFUIJEP8000Uoo`D00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF008000AJEP04
001oogooOol2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000goo0P0015YF00<0
05YF00003Woo1P0015YF00@005YFFUIJEPH003=oo`00=7oo0P000UYF00<005YFFUH00eYF0P0027oo
2@0015YF00<005YFFUH015YF00@005YF0000009oo`05001JEUYFFUH00003Ool00eYF001JEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20005Ool00`00FUIJEP02FUH2000EOol8000iOol003Ioo`80
00QJEP8000moo`d000Eoo`05001JEP00FUH00002Ool20004FUH00`00FUIJEP0@FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`05
Ool01P00FUIJEP00FUH005Ioo`00=goo00<005YFFUH01UYF00<005YF00000P007goo0P0000AJEP00
Oomoo`8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006Ool01P00FUIJEP00FUH005Ioo`00>7oo
0P001UYF00<005YFFUH00UYF0`007Goo00<005YF00000goo00<005YFFUH00UYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEPT00003FUH007oo05Ioo`00>Woo0P000eYF00<005YFFUH01UYF0`006Woo0P00
17oo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH01UYF0P0000IJEP00FUH005YF001G
Ool003aoo`800003FUH005YF00QJEP03001JEP0000<001Aoo`@000Eoo`80009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP<000=JEP8000QJEP80009JEP03001JEP0005Moo`00?Woo0`001eYF00<005YFFUH015YF1P0027oo
1P000UYF00<007ooOol01Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH00`000UYF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=J
EP00Ool0EWoo0011Ool20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJEP80
00Yoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPH0
00=JEP03001JEUYF00IJEP8000=JEP03001JEUYF009JEP8005Qoo`00@goo0`0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH700000eYF000000030002FUH00`00FUIJEP05
FUH00`00FUIJEP030006FUH00`00Oomoo`1FOol004Ioo`@000IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH2000BOol80005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH:0002Ool20000
15YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF0P00Egoo001:
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000KOolH0002FUH00`00Oomo
o`09Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH00`00FUH0001FOol004ioo`H0
00AJEP04001JEUYFFUH6000`Ool20006FUH00`00Oomoo`0<Ool40002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000UYF00D005YFFUIJEP0005Eoo`00E7oo2000=goo00<005YFFUH015YF
0`0047oo1P0015YF00@005YFFUIJEPD00004Ool000000004FUH00`00Oomoo`1BOol009Aoo`8000AJ
EP03001JEUYF008001Aoo`P000Qoo`03001JEUYF009JEP03001oogoo059oo`00UWoo00@005YFFUH0
00EJEP8002=oo`03001JEUYF008005Aoo`00Ugoo0`001eYF0`0087oo00<005YFFUH00P00E7oo002I
Ool00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0Dgoo002JOol20005FUH00`00FUIJ
EP02FUH3000MOol00`00FUH0001DOol009aoo`8000=JEP03001JEUYF00EJEP@001Uoo`03001JEP00
05Aoo`00WWoo0`002EYF00<005YFFUH0100057oo0`00EGoo002POol20008FUH00`00FUIJEP04FUH6
0008Ool600000eYF0000001EOol00:9oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
1000FUIJEUYF0P00EGoo002UOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00EWoo002XOol30007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002[Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001GOol00:mo
o`H000AJEP04001JEUYFFUH6001JOol00;Eoo`P0061oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59239 .74927 m .601 .69533 L .57021 .68859 L p .707 .577 .707 r
F P
0 g
s
.601 .69533 m .59239 .74927 L .62389 .75286 L p .707 .577 .707 r
F P
0 g
s
.62389 .75286 m .63249 .69893 L .601 .69533 L p .707 .577 .707 r
F P
0 g
s
.63249 .69893 m .62389 .75286 L .65299 .75295 L p .707 .577 .707 r
F P
0 g
s
.65299 .75295 m .6616 .69902 L .63249 .69893 L p .707 .577 .707 r
F P
0 g
s
.5616 .74252 m .57021 .68859 L .54313 .67935 L p .707 .577 .707 r
F P
0 g
s
.57021 .68859 m .5616 .74252 L .59239 .74927 L p .707 .577 .707 r
F P
0 g
s
.6616 .69902 m .65299 .75295 L .67687 .74953 L p .707 .577 .707 r
F P
0 g
s
.67687 .74953 m .68548 .69559 L .6616 .69902 L p .707 .577 .707 r
F P
0 g
s
.53452 .73329 m .54313 .67935 L .52242 .66852 L p .707 .577 .707 r
F P
0 g
s
.54313 .67935 m .53452 .73329 L .5616 .74252 L p .707 .577 .707 r
F P
0 g
s
.58574 .81947 m .59716 .78559 L .56753 .77413 L p .707 .577 .707 r
F P
0 g
s
.59716 .78559 m .58574 .81947 L .61618 .82732 L p .707 .577 .707 r
F P
0 g
s
.61618 .82732 m .62761 .79344 L .59716 .78559 L p .707 .577 .707 r
F P
0 g
s
.5561 .80801 m .56753 .77413 L .54161 .76017 L p .707 .577 .707 r
F P
0 g
s
.56753 .77413 m .5561 .80801 L .58574 .81947 L p .707 .577 .707 r
F P
0 g
s
.62761 .79344 m .61618 .82732 L .64446 .83079 L p .707 .577 .707 r
F P
0 g
s
.64446 .83079 m .65589 .79691 L .62761 .79344 L p .707 .577 .707 r
F P
0 g
s
.52242 .66852 m .51381 .72246 L .53452 .73329 L p .707 .577 .707 r
F P
0 g
s
.68548 .69559 m .67687 .74953 L .69318 .74293 L p .707 .577 .707 r
F P
0 g
s
.69318 .74293 m .70179 .68899 L .68548 .69559 L p .707 .577 .707 r
F P
0 g
s
.51381 .72246 m .52242 .66852 L .5101 .65717 L p .707 .577 .707 r
F P
0 g
s
.53019 .79405 m .54161 .76017 L .52195 .74509 L p .707 .577 .707 r
F P
0 g
s
.54161 .76017 m .53019 .79405 L .5561 .80801 L p .707 .577 .707 r
F P
0 g
s
.59496 .8666 m .60025 .84947 L .5704 .8387 L p .707 .577 .707 r
F P
0 g
s
.60025 .84947 m .59496 .8666 L .62561 .87382 L p .707 .577 .707 r
F P
0 g
s
.62561 .87382 m .6309 .8567 L .60025 .84947 L p .707 .577 .707 r
F P
0 g
s
.65589 .79691 m .64446 .83079 L .66781 .82954 L p .707 .577 .707 r
F P
0 g
s
.66781 .82954 m .67923 .79566 L .65589 .79691 L p .707 .577 .707 r
F P
0 g
s
.56511 .85583 m .5704 .8387 L .54425 .82544 L p .707 .577 .707 r
F P
0 g
s
.5704 .8387 m .56511 .85583 L .59496 .8666 L p .707 .577 .707 r
F P
0 g
s
.6309 .8567 m .62561 .87382 L .65405 .8768 L p .707 .577 .707 r
F P
0 g
s
.65405 .8768 m .65934 .85967 L .6309 .8567 L p .707 .577 .707 r
F P
0 g
s
.54425 .82544 m .53896 .84257 L .56511 .85583 L p .707 .577 .707 r
F P
0 g
s
.52195 .74509 m .51052 .77897 L .53019 .79405 L p .707 .577 .707 r
F P
0 g
s
.53896 .84257 m .54425 .82544 L .52439 .81098 L p .707 .577 .707 r
F P
0 g
s
.5101 .65717 m .50149 .71111 L .51381 .72246 L p .707 .577 .707 r
F P
0 g
s
.51052 .77897 m .52195 .74509 L .51046 .73035 L p .707 .577 .707 r
F P
0 g
s
.65934 .85967 m .65405 .8768 L .6775 .87522 L p .707 .577 .707 r
F P
0 g
s
.6775 .87522 m .68279 .8581 L .65934 .85967 L p .707 .577 .707 r
F P
0 g
s
.70179 .68899 m .69318 .74293 L .70032 .7338 L p .707 .577 .707 r
F P
0 g
s
.70032 .7338 m .70893 .67986 L .70179 .68899 L p .707 .577 .707 r
F P
0 g
s
.52439 .81098 m .5191 .82811 L .53896 .84257 L p .707 .577 .707 r
F P
0 g
s
.50149 .71111 m .5101 .65717 L .50738 .6464 L p .707 .577 .707 r
F P
0 g
s
.67923 .79566 m .66781 .82954 L .68393 .82369 L p .707 .577 .707 r
F P
0 g
s
.68393 .82369 m .69536 .78981 L .67923 .79566 L p .707 .577 .707 r
F P
0 g
s
.51046 .73035 m .49903 .76424 L .51052 .77897 L p .707 .577 .707 r
F P
0 g
s
.5191 .82811 m .52439 .81098 L .51274 .79675 L p .707 .577 .707 r
F P
0 g
s
.68279 .8581 m .6775 .87522 L .69366 .86926 L p .707 .577 .707 r
F P
0 g
s
.69366 .86926 m .69895 .85213 L .68279 .8581 L p .707 .577 .707 r
F P
0 g
s
.50738 .6464 m .49877 .70034 L .50149 .71111 L p .707 .577 .707 r
F P
0 g
s
.51274 .79675 m .50745 .81388 L .5191 .82811 L p .707 .577 .707 r
F P
0 g
s
.49903 .76424 m .51046 .73035 L .50827 .71742 L p .707 .577 .707 r
F P
0 g
s
.70893 .67986 m .70032 .7338 L .6976 .72303 L p .707 .577 .707 r
F P
0 g
s
.6976 .72303 m .70621 .66909 L .70893 .67986 L p .707 .577 .707 r
F P
0 g
s
.69536 .78981 m .68393 .82369 L .69126 .81381 L p .707 .577 .707 r
F P
0 g
s
.69126 .81381 m .70268 .77993 L .69536 .78981 L p .707 .577 .707 r
F P
0 g
s
.49877 .70034 m .50738 .6464 L .51452 .63727 L p .707 .577 .707 r
F P
0 g
s
.50827 .71742 m .49684 .7513 L .49903 .76424 L p .707 .577 .707 r
F P
0 g
s
.50745 .81388 m .51274 .79675 L .51044 .78413 L p .707 .577 .707 r
F P
0 g
s
.51044 .78413 m .50515 .80126 L .50745 .81388 L p .707 .577 .707 r
F P
0 g
s
.51452 .63727 m .50591 .69121 L .49877 .70034 L p .707 .577 .707 r
F P
0 g
s
.49684 .7513 m .50827 .71742 L .5156 .70754 L p .707 .577 .707 r
F P
0 g
s
.5156 .70754 m .50417 .74142 L .49684 .7513 L p .707 .577 .707 r
F P
0 g
s
.50515 .80126 m .51044 .78413 L .51774 .77436 L p .707 .577 .707 r
F P
0 g
s
.51774 .77436 m .51245 .79149 L .50515 .80126 L p .707 .577 .707 r
F P
0 g
s
.50417 .74142 m .5156 .70754 L .53172 .70168 L p .707 .577 .707 r
F P
0 g
s
.53172 .70168 m .5203 .73556 L .50417 .74142 L p .707 .577 .707 r
F P
0 g
s
.50962 .8207 m .47922 .31654 L .4353 .31657 L p .707 .577 .707 r
F P
0 g
s
.50591 .69121 m .51452 .63727 L .53083 .63067 L p .707 .577 .707 r
F P
0 g
s
.53083 .63067 m .52222 .68461 L .50591 .69121 L p .707 .577 .707 r
F P
0 g
s
.52222 .68461 m .53083 .63067 L .55471 .62725 L p .707 .577 .707 r
F P
0 g
s
.51245 .79149 m .51774 .77436 L .5339 .7684 L p .707 .577 .707 r
F P
0 g
s
.5339 .7684 m .52861 .78552 L .51245 .79149 L p .707 .577 .707 r
F P
0 g
s
.55471 .62725 m .5461 .68118 L .52222 .68461 L p .707 .577 .707 r
F P
0 g
s
.5203 .73556 m .53172 .70168 L .55507 .70043 L p .707 .577 .707 r
F P
0 g
s
.55507 .70043 m .54364 .73431 L .5203 .73556 L p .707 .577 .707 r
F P
0 g
s
.52861 .78552 m .5339 .7684 L .55734 .76682 L p .707 .577 .707 r
F P
0 g
s
.55734 .76682 m .55205 .78395 L .52861 .78552 L p .707 .577 .707 r
F P
0 g
s
.47922 .31654 m .50962 .8207 L .55449 .81716 L p .707 .577 .707 r
F P
0 g
s
.5461 .68118 m .55471 .62725 L .58382 .62734 L p .707 .577 .707 r
F P
0 g
s
.58382 .62734 m .57761 .66625 L p .5461 .68118 L .707 .577 .707 r
F P
0 g
s
.57761 .66625 m .57521 .68127 L .57055 .68126 L p .707 .577 .707 r
F P
0 g
s
.57055 .68126 m .5461 .68118 L p .57761 .66625 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .47922 .31654 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.54364 .73431 m .55507 .70043 L .58335 .7039 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .5804 .71262 L p .54364 .73431 L .707 .577 .707 r
F P
0 g
s
.5804 .71262 m .57192 .73778 L .55887 .73618 L p .707 .577 .707 r
F P
0 g
s
.55887 .73618 m .54364 .73431 L p .5804 .71262 L .707 .577 .707 r
F P
0 g
s
.54465 .75173 m .54905 .72698 L .5429 .74007 L .707 .577 .707 r
F
.55205 .78395 m .55734 .76682 L .58578 .7698 L p F P
0 g
s
.58578 .7698 m .58417 .77503 L p .55205 .78395 L .707 .577 .707 r
F P
0 g
s
.58417 .77503 m .58049 .78692 L .57468 .78632 L p .707 .577 .707 r
F P
0 g
s
.57468 .78632 m .55205 .78395 L p .58417 .77503 L .707 .577 .707 r
F P
0 g
s
.55362 .81137 m .55018 .74568 L .54465 .75173 L .707 .577 .707 r
F
.55449 .81716 m .55411 .81079 L p .55362 .81137 L F P
0 g
s
.55411 .81079 m .55018 .74568 L p .55362 .81137 L .707 .577 .707 r
F P
0 g
s
.55018 .74568 m .54905 .72698 L p .54465 .75173 L .707 .577 .707 r
F P
0 g
s
.54905 .72698 m .52409 .313 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.57521 .68127 m .58382 .62734 L .61531 .63093 L p .707 .577 .707 r
F P
0 g
s
.61531 .63093 m .6067 .68487 L .57521 .68127 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .61379 .71175 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.57192 .73778 m .576 .72569 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.576 .72569 m .58335 .7039 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.6461 .63768 m .63749 .69161 L .6067 .68487 L p .707 .577 .707 r
F P
0 g
s
.6067 .68487 m .61531 .63093 L .6461 .63768 L p .707 .577 .707 r
F P
0 g
s
.64342 .72322 m .632 .7571 L .60237 .74563 L p .707 .577 .707 r
F P
0 g
s
.60237 .74563 m .61379 .71175 L .64342 .72322 L p .707 .577 .707 r
F P
0 g
s
.61379 .71175 m .60237 .74563 L .57192 .73778 L p .707 .577 .707 r
F P
0 g
s
.58049 .78692 m .58578 .7698 L .61643 .77702 L p .707 .577 .707 r
F P
0 g
s
.64629 .78779 m .641 .80492 L .61114 .79415 L p .707 .577 .707 r
F P
0 g
s
.61114 .79415 m .61643 .77702 L .64629 .78779 L p .707 .577 .707 r
F P
0 g
s
.61643 .77702 m .61114 .79415 L .58049 .78692 L p .707 .577 .707 r
F P
0 g
s
.56552 .3063 m .59453 .78752 L p .62983 .80123 L .707 .577 .707 r
F P
0 g
s
.59453 .78752 m .59591 .81046 L .60099 .80907 L p .707 .577 .707 r
F P
0 g
s
.60099 .80907 m .62983 .80123 L p .59453 .78752 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .55449 .81716 L .59591 .81046 L p .707 .577 .707 r
F P
0 g
s
.59591 .81046 m .56552 .3063 L .52409 .313 L p .707 .577 .707 r
F P
0 g
s
.69895 .85213 m .69366 .86926 L .70095 .85949 L p .707 .577 .707 r
F P
0 g
s
.70095 .85949 m .70624 .84236 L .69895 .85213 L p .707 .577 .707 r
F P
0 g
s
.46569 .82073 m .4353 .31657 L .39662 .31307 L p .707 .577 .707 r
F P
0 g
s
.4353 .31657 m .46569 .82073 L .50962 .8207 L p .707 .577 .707 r
F P
0 g
s
.70621 .66909 m .6976 .72303 L .68528 .71168 L p .707 .577 .707 r
F P
0 g
s
.68528 .71168 m .69389 .65774 L .70621 .66909 L p .707 .577 .707 r
F P
0 g
s
.70268 .77993 m .69126 .81381 L .68907 .80087 L p .707 .577 .707 r
F P
0 g
s
.68907 .80087 m .7005 .76699 L .70268 .77993 L p .707 .577 .707 r
F P
0 g
s
.62983 .80123 m .59944 .29708 L .56552 .3063 L p .707 .577 .707 r
F P
0 g
s
.24938 .72116 m .25799 .66722 L .2272 .66047 L p .707 .577 .707 r
F P
0 g
s
.25799 .66722 m .24938 .72116 L .28088 .72475 L p .707 .577 .707 r
F P
0 g
s
.28088 .72475 m .28948 .67081 L .25799 .66722 L p .707 .577 .707 r
F P
0 g
s
.28948 .67081 m .28088 .72475 L .30999 .72484 L p .707 .577 .707 r
F P
0 g
s
.30999 .72484 m .31859 .6709 L .28948 .67081 L p .707 .577 .707 r
F P
0 g
s
.21859 .71441 m .2272 .66047 L .20012 .65124 L p .707 .577 .707 r
F P
0 g
s
.2272 .66047 m .21859 .71441 L .24938 .72116 L p .707 .577 .707 r
F P
0 g
s
.42701 .81723 m .39662 .31307 L .36696 .3064 L p .707 .577 .707 r
F P
0 g
s
.39662 .31307 m .42701 .81723 L .46569 .82073 L p .707 .577 .707 r
F P
0 g
s
.70624 .84236 m .70095 .85949 L .69866 .84687 L p .707 .577 .707 r
F P
0 g
s
.69866 .84687 m .70395 .82974 L .70624 .84236 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31859 .6709 m .30999 .72484 L .33386 .72142 L p .707 .577 .707 r
F P
0 g
s
.33386 .72142 m .34247 .66748 L .31859 .6709 L p .707 .577 .707 r
F P
0 g
s
.69389 .65774 m .68528 .71168 L .66457 .70085 L p .707 .577 .707 r
F P
0 g
s
.66457 .70085 m .67318 .64691 L .69389 .65774 L p .707 .577 .707 r
F P
0 g
s
.19152 .70517 m .20012 .65124 L .17941 .64041 L p .707 .577 .707 r
F P
0 g
s
.20012 .65124 m .19152 .70517 L .21859 .71441 L p .707 .577 .707 r
F P
0 g
s
.7005 .76699 m .68907 .80087 L .67758 .78614 L p .707 .577 .707 r
F P
0 g
s
.67758 .78614 m .68901 .75226 L .7005 .76699 L p .707 .577 .707 r
F P
0 g
s
.67318 .64691 m .66457 .70085 L .63749 .69161 L p .707 .577 .707 r
F P
0 g
s
.63749 .69161 m .6461 .63768 L .67318 .64691 L p .707 .577 .707 r
F P
0 g
s
.66934 .73717 m .65791 .77105 L .632 .7571 L p .707 .577 .707 r
F P
0 g
s
.632 .7571 m .64342 .72322 L .66934 .73717 L p .707 .577 .707 r
F P
0 g
s
.641 .80492 m .64629 .78779 L .67243 .80105 L p .707 .577 .707 r
F P
0 g
s
.59944 .29708 m .62983 .80123 L .65293 .7904 L p .707 .577 .707 r
F P
0 g
s
.65293 .7904 m .62253 .28625 L .59944 .29708 L p .707 .577 .707 r
F P
0 g
s
.24273 .77871 m .25415 .74483 L .22452 .73336 L p .707 .577 .707 r
F P
0 g
s
.25415 .74483 m .24273 .77871 L .27317 .78656 L p .707 .577 .707 r
F P
0 g
s
.27317 .78656 m .2846 .75268 L .25415 .74483 L p .707 .577 .707 r
F P
0 g
s
.2131 .76725 m .22452 .73336 L .1986 .71941 L p .707 .577 .707 r
F P
0 g
s
.22452 .73336 m .2131 .76725 L .24273 .77871 L p .707 .577 .707 r
F P
0 g
s
.2846 .75268 m .27317 .78656 L .30145 .79003 L p .707 .577 .707 r
F P
0 g
s
.30145 .79003 m .31288 .75615 L .2846 .75268 L p .707 .577 .707 r
F P
0 g
s
.70395 .82974 m .69866 .84687 L .68701 .83264 L p .707 .577 .707 r
F P
0 g
s
.68701 .83264 m .6923 .81551 L .70395 .82974 L p .707 .577 .707 r
F P
0 g
s
.25195 .81691 m .25724 .79978 L .22739 .78901 L p .707 .577 .707 r
F P
0 g
s
.25724 .79978 m .25195 .81691 L .2826 .82414 L p .707 .577 .707 r
F P
0 g
s
.2826 .82414 m .28789 .80701 L .25724 .79978 L p .707 .577 .707 r
F P
0 g
s
.17941 .64041 m .1708 .69435 L .19152 .70517 L p .707 .577 .707 r
F P
0 g
s
.34247 .66748 m .33386 .72142 L .35017 .71482 L p .707 .577 .707 r
F P
0 g
s
.35017 .71482 m .35878 .66088 L .34247 .66748 L p .707 .577 .707 r
F P
0 g
s
.39736 .81056 m .36696 .3064 L .34924 .29721 L p .707 .577 .707 r
F P
0 g
s
.36696 .3064 m .39736 .81056 L .42701 .81723 L p .707 .577 .707 r
F P
0 g
s
.18718 .75329 m .1986 .71941 L .17894 .70432 L p .707 .577 .707 r
F P
0 g
s
.1986 .71941 m .18718 .75329 L .2131 .76725 L p .707 .577 .707 r
F P
0 g
s
.2221 .80614 m .22739 .78901 L .20125 .77575 L p .707 .577 .707 r
F P
0 g
s
.22739 .78901 m .2221 .80614 L .25195 .81691 L p .707 .577 .707 r
F P
0 g
s
.1708 .69435 m .17941 .64041 L .16709 .62906 L p .707 .577 .707 r
F P
0 g
s
.28789 .80701 m .2826 .82414 L .31104 .82711 L p .707 .577 .707 r
F P
0 g
s
.31104 .82711 m .31633 .80998 L .28789 .80701 L p .707 .577 .707 r
F P
0 g
s
.31288 .75615 m .30145 .79003 L .3248 .78878 L p .707 .577 .707 r
F P
0 g
s
.3248 .78878 m .33622 .7549 L .31288 .75615 L p .707 .577 .707 r
F P
0 g
s
.68901 .75226 m .67758 .78614 L .65791 .77105 L p .707 .577 .707 r
F P
0 g
s
.65791 .77105 m .66934 .73717 L .68901 .75226 L p .707 .577 .707 r
F P
0 g
s
.20125 .77575 m .19595 .79288 L .2221 .80614 L p .707 .577 .707 r
F P
0 g
s
.17894 .70432 m .16751 .73821 L .18718 .75329 L p .707 .577 .707 r
F P
0 g
s
.19595 .79288 m .20125 .77575 L .18138 .76129 L p .707 .577 .707 r
F P
0 g
s
.31633 .80998 m .31104 .82711 L .33449 .82554 L p .707 .577 .707 r
F P
0 g
s
.33449 .82554 m .33978 .80841 L .31633 .80998 L p .707 .577 .707 r
F P
0 g
s
.62253 .28625 m .65293 .7904 L .66294 .77903 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .63255 .27487 L .62253 .28625 L p .707 .577 .707 r
F P
0 g
s
.16709 .62906 m .15848 .68299 L .1708 .69435 L p .707 .577 .707 r
F P
0 g
s
.16751 .73821 m .17894 .70432 L .16745 .68959 L p .707 .577 .707 r
F P
0 g
s
.18138 .76129 m .17609 .77842 L .19595 .79288 L p .707 .577 .707 r
F P
0 g
s
.6923 .81551 m .68701 .83264 L .66714 .81818 L p .707 .577 .707 r
F P
0 g
s
.66714 .81818 m .67243 .80105 L .6923 .81551 L p .707 .577 .707 r
F P
0 g
s
.35878 .66088 m .35017 .71482 L .35732 .70569 L p .707 .577 .707 r
F P
0 g
s
.35732 .70569 m .36592 .65175 L .35878 .66088 L p .707 .577 .707 r
F P
0 g
s
.33622 .7549 m .3248 .78878 L .34092 .78293 L p .707 .577 .707 r
F P
0 g
s
.34092 .78293 m .35235 .74904 L .33622 .7549 L p .707 .577 .707 r
F P
0 g
s
.15848 .68299 m .16709 .62906 L .16437 .61829 L p .707 .577 .707 r
F P
0 g
s
.16745 .68959 m .15602 .72347 L .16751 .73821 L p .707 .577 .707 r
F P
0 g
s
.17609 .77842 m .18138 .76129 L .16973 .74706 L p .707 .577 .707 r
F P
0 g
s
.33978 .80841 m .33449 .82554 L .35065 .81957 L p .707 .577 .707 r
F P
0 g
s
.35065 .81957 m .35594 .80244 L .33978 .80841 L p .707 .577 .707 r
F P
0 g
s
.37964 .80137 m .34924 .29721 L .34519 .2864 L p .707 .577 .707 r
F P
0 g
s
.34924 .29721 m .37964 .80137 L .39736 .81056 L p .707 .577 .707 r
F P
0 g
s
.16973 .74706 m .16444 .76419 L .17609 .77842 L p .707 .577 .707 r
F P
0 g
s
.67243 .80105 m .66714 .81818 L .641 .80492 L p .707 .577 .707 r
F P
0 g
s
.15602 .72347 m .16745 .68959 L .16526 .67665 L p .707 .577 .707 r
F P
0 g
s
.16437 .61829 m .15576 .67223 L .15848 .68299 L p .707 .577 .707 r
F P
0 g
s
.35235 .74904 m .34092 .78293 L .34825 .77305 L p .707 .577 .707 r
F P
0 g
s
.34825 .77305 m .35967 .73916 L .35235 .74904 L p .707 .577 .707 r
F P
0 g
s
.36592 .65175 m .35732 .70569 L .35459 .69492 L p .707 .577 .707 r
F P
0 g
s
.35459 .69492 m .3632 .64098 L .36592 .65175 L p .707 .577 .707 r
F P
0 g
s
.15576 .67223 m .16437 .61829 L .17151 .60916 L p .707 .577 .707 r
F P
0 g
s
.16526 .67665 m .15383 .71053 L .15602 .72347 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .6595 .76983 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.63255 .27487 m .66227 .7679 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.66227 .7679 m .66294 .77903 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.62849 .26405 m .65889 .76821 L .64117 .75902 L p .707 .577 .707 r
F P
0 g
s
.64773 .68693 m .6518 .67484 L p .64766 .63832 L .707 .577 .707 r
F P
0 g
s
.65797 .75099 m .63255 .27487 L .6595 .76983 L .707 .577 .707 r
F
.62849 .26405 m .63255 .27487 L p .65503 .69598 L F P
0 g
s
.65889 .76821 m .65366 .6815 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.65366 .6815 m .62849 .26405 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.6473 .56513 m .64438 .58345 L p .65102 .63042 L .707 .577 .707 r
F P
0 g
s
.64438 .58345 m .6387 .61907 L .64862 .62821 L p .707 .577 .707 r
F P
0 g
s
.64862 .62821 m .65102 .63042 L p .64438 .58345 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .65915 .65305 L .6477 .63836 L p .707 .577 .707 r
F P
0 g
s
.6477 .63836 m .64766 .63832 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.65915 .65305 m .6518 .67484 L p .66739 .70201 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .64773 .68693 L .65312 .69106 L p .707 .577 .707 r
F P
0 g
s
.65312 .69106 m .66739 .70201 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.6595 .76983 m .65889 .76821 L p .65797 .75099 L .707 .577 .707 r
F P
0 g
s
.16444 .76419 m .16973 .74706 L .16744 .73444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35594 .80244 m .35065 .81957 L .35794 .8098 L p .707 .577 .707 r
F P
0 g
s
.35794 .8098 m .36323 .79268 L .35594 .80244 L p .707 .577 .707 r
F P
0 g
s
.16744 .73444 m .16214 .75157 L .16444 .76419 L p .707 .577 .707 r
F P
0 g
s
.15383 .71053 m .16526 .67665 L .17259 .66677 L p .707 .577 .707 r
F P
0 g
s
.17151 .60916 m .16291 .66309 L .15576 .67223 L p .707 .577 .707 r
F P
0 g
s
.35967 .73916 m .34825 .77305 L .34606 .76011 L p .707 .577 .707 r
F P
0 g
s
.34606 .76011 m .35749 .72623 L .35967 .73916 L p .707 .577 .707 r
F P
0 g
s
.34519 .2864 m .37559 .79056 L .37964 .80137 L p .707 .577 .707 r
F P
0 g
s
.37559 .79056 m .34519 .2864 L .35521 .27502 L p .707 .577 .707 r
F P
0 g
s
.3632 .64098 m .35459 .69492 L .34227 .68356 L p .707 .577 .707 r
F P
0 g
s
.34227 .68356 m .35088 .62963 L .3632 .64098 L p .707 .577 .707 r
F P
0 g
s
.16291 .66309 m .17151 .60916 L .18782 .60256 L p .707 .577 .707 r
F P
0 g
s
.17259 .66677 m .16116 .70066 L .15383 .71053 L p .707 .577 .707 r
F P
0 g
s
.16214 .75157 m .16744 .73444 L .17473 .72467 L p .707 .577 .707 r
F P
0 g
s
.36323 .79268 m .35794 .8098 L .35565 .79718 L p .707 .577 .707 r
F P
0 g
s
.35565 .79718 m .36094 .78006 L .36323 .79268 L p .707 .577 .707 r
F P
0 g
s
.17473 .72467 m .16944 .7418 L .16214 .75157 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64117 .75902 m .61078 .25486 L .62849 .26405 L p .707 .577 .707 r
F P
0 g
s
.16116 .70066 m .17259 .66677 L .18871 .66092 L p .707 .577 .707 r
F P
0 g
s
.18782 .60256 m .17921 .65649 L .16291 .66309 L p .707 .577 .707 r
F P
0 g
s
.35749 .72623 m .34606 .76011 L .33457 .74538 L p .707 .577 .707 r
F P
0 g
s
.33457 .74538 m .346 .71149 L .35749 .72623 L p .707 .577 .707 r
F P
0 g
s
.35088 .62963 m .34227 .68356 L .32156 .67274 L p .707 .577 .707 r
F P
0 g
s
.32156 .67274 m .33017 .6188 L .35088 .62963 L p .707 .577 .707 r
F P
0 g
s
.17921 .65649 m .18782 .60256 L .2117 .59913 L p .707 .577 .707 r
F P
0 g
s
.18871 .66092 m .17729 .6948 L .16116 .70066 L p .707 .577 .707 r
F P
0 g
s
.16944 .7418 m .17473 .72467 L .19089 .71871 L p .707 .577 .707 r
F P
0 g
s
.36094 .78006 m .35565 .79718 L .344 .78295 L p .707 .577 .707 r
F P
0 g
s
.344 .78295 m .34929 .76582 L .36094 .78006 L p .707 .577 .707 r
F P
0 g
s
.3856 .77918 m .35521 .27502 L .3783 .26419 L p .707 .577 .707 r
F P
0 g
s
.35521 .27502 m .3856 .77918 L .37559 .79056 L p .707 .577 .707 r
F P
0 g
s
.19089 .71871 m .1856 .73584 L .16944 .7418 L p .707 .577 .707 r
F P
0 g
s
.17729 .6948 m .18871 .66092 L .21206 .65967 L p .707 .577 .707 r
F P
0 g
s
.2117 .59913 m .20309 .65307 L .17921 .65649 L p .707 .577 .707 r
F P
0 g
s
.33017 .6188 m .32156 .67274 L .29449 .6635 L p .707 .577 .707 r
F P
0 g
s
.29449 .6635 m .30309 .60956 L .33017 .6188 L p .707 .577 .707 r
F P
0 g
s
.20309 .65307 m .2117 .59913 L .24081 .59922 L p .707 .577 .707 r
F P
0 g
s
.346 .71149 m .33457 .74538 L .31491 .73029 L p .707 .577 .707 r
F P
0 g
s
.31491 .73029 m .32633 .69641 L .346 .71149 L p .707 .577 .707 r
F P
0 g
s
.61078 .25486 m .64117 .75902 L .61152 .75235 L p .707 .577 .707 r
F P
0 g
s
.61152 .75235 m .58112 .24819 L .61078 .25486 L p .707 .577 .707 r
F P
0 g
s
.21206 .65967 m .20063 .69355 L .17729 .6948 L p .707 .577 .707 r
F P
0 g
s
.1856 .73584 m .19089 .71871 L .21433 .71714 L p .707 .577 .707 r
F P
0 g
s
.30309 .60956 m .29449 .6635 L .26369 .65675 L p .707 .577 .707 r
F P
0 g
s
.26369 .65675 m .2723 .60282 L .30309 .60956 L p .707 .577 .707 r
F P
0 g
s
.2322 .65316 m .24081 .59922 L .2723 .60282 L p .707 .577 .707 r
F P
0 g
s
.24081 .59922 m .2322 .65316 L .20309 .65307 L p .707 .577 .707 r
F P
0 g
s
.34929 .76582 m .344 .78295 L .32413 .76849 L p .707 .577 .707 r
F P
0 g
s
.32413 .76849 m .32942 .75137 L .34929 .76582 L p .707 .577 .707 r
F P
0 g
s
.20063 .69355 m .21206 .65967 L .24034 .66314 L p .707 .577 .707 r
F P
0 g
s
.21433 .71714 m .20904 .73426 L .1856 .73584 L p .707 .577 .707 r
F P
0 g
s
.2723 .60282 m .26369 .65675 L .2322 .65316 L p .707 .577 .707 r
F P
0 g
s
.7296 .65723 m .7382 .60329 L .70741 .59655 L p .707 .577 .707 r
F P
0 g
s
.7382 .60329 m .7296 .65723 L .76109 .66082 L p .707 .577 .707 r
F P
0 g
s
.76109 .66082 m .7697 .60689 L .7382 .60329 L p .707 .577 .707 r
F P
0 g
s
.32633 .69641 m .31491 .73029 L .28899 .71634 L p .707 .577 .707 r
F P
0 g
s
.28899 .71634 m .30041 .68245 L .32633 .69641 L p .707 .577 .707 r
F P
0 g
s
.7697 .60689 m .76109 .66082 L .7902 .66091 L p .707 .577 .707 r
F P
0 g
s
.7902 .66091 m .79881 .60698 L .7697 .60689 L p .707 .577 .707 r
F P
0 g
s
.69881 .65048 m .70741 .59655 L .68033 .58731 L p .707 .577 .707 r
F P
0 g
s
.70741 .59655 m .69881 .65048 L .7296 .65723 L p .707 .577 .707 r
F P
0 g
s
.3783 .26419 m .4087 .76835 L .3856 .77918 L p .707 .577 .707 r
F P
0 g
s
.4087 .76835 m .3783 .26419 L .41222 .25496 L p .707 .577 .707 r
F P
0 g
s
.24034 .66314 m .22891 .69702 L .20063 .69355 L p .707 .577 .707 r
F P
0 g
s
.22891 .69702 m .24034 .66314 L .27078 .67099 L p .707 .577 .707 r
F P
0 g
s
.20904 .73426 m .21433 .71714 L .24277 .72011 L p .707 .577 .707 r
F P
0 g
s
.30041 .68245 m .28899 .71634 L .25936 .70487 L p .707 .577 .707 r
F P
0 g
s
.25936 .70487 m .27078 .67099 L .30041 .68245 L p .707 .577 .707 r
F P
0 g
s
.32942 .75137 m .32413 .76849 L .29799 .75523 L p .707 .577 .707 r
F P
0 g
s
.29799 .75523 m .30328 .7381 L .32942 .75137 L p .707 .577 .707 r
F P
0 g
s
.27078 .67099 m .25936 .70487 L .22891 .69702 L p .707 .577 .707 r
F P
0 g
s
.79881 .60698 m .7902 .66091 L .81408 .65749 L p .707 .577 .707 r
F P
0 g
s
.81408 .65749 m .82268 .60356 L .79881 .60698 L p .707 .577 .707 r
F P
0 g
s
.24277 .72011 m .23748 .73724 L .20904 .73426 L p .707 .577 .707 r
F P
0 g
s
.67173 .64125 m .68033 .58731 L .65962 .57649 L p .707 .577 .707 r
F P
0 g
s
.68033 .58731 m .67173 .64125 L .69881 .65048 L p .707 .577 .707 r
F P
0 g
s
.58112 .24819 m .61152 .75235 L .57284 .74885 L p .707 .577 .707 r
F P
0 g
s
.57284 .74885 m .54244 .24469 L .58112 .24819 L p .707 .577 .707 r
F P
0 g
s
.23748 .73724 m .24277 .72011 L .27342 .72733 L p .707 .577 .707 r
F P
0 g
s
.72294 .72743 m .73437 .69355 L .70473 .68209 L p .707 .577 .707 r
F P
0 g
s
.73437 .69355 m .72294 .72743 L .75339 .73529 L p .707 .577 .707 r
F P
0 g
s
.75339 .73529 m .76481 .70141 L .73437 .69355 L p .707 .577 .707 r
F P
0 g
s
.30328 .7381 m .29799 .75523 L .26813 .74446 L p .707 .577 .707 r
F P
0 g
s
.26813 .74446 m .27342 .72733 L .30328 .7381 L p .707 .577 .707 r
F P
0 g
s
.69331 .71597 m .70473 .68209 L .67882 .66813 L p .707 .577 .707 r
F P
0 g
s
.70473 .68209 m .69331 .71597 L .72294 .72743 L p .707 .577 .707 r
F P
0 g
s
.27342 .72733 m .26813 .74446 L .23748 .73724 L p .707 .577 .707 r
F P
0 g
s
.76481 .70141 m .75339 .73529 L .78167 .73876 L p .707 .577 .707 r
F P
0 g
s
.78167 .73876 m .79309 .70487 L .76481 .70141 L p .707 .577 .707 r
F P
0 g
s
.44262 .75912 m .41222 .25496 L .45364 .24826 L p .707 .577 .707 r
F P
0 g
s
.41222 .25496 m .44262 .75912 L .4087 .76835 L p .707 .577 .707 r
F P
0 g
s
.65962 .57649 m .65102 .63042 L .67173 .64125 L p .707 .577 .707 r
F P
0 g
s
.82268 .60356 m .81408 .65749 L .83039 .65089 L p .707 .577 .707 r
F P
0 g
s
.83039 .65089 m .83899 .59696 L .82268 .60356 L p .707 .577 .707 r
F P
0 g
s
.65102 .63042 m .65962 .57649 L .6473 .56513 L p .707 .577 .707 r
F P
0 g
s
.66739 .70201 m .67882 .66813 L .65915 .65305 L p .707 .577 .707 r
F P
0 g
s
.67882 .66813 m .66739 .70201 L .69331 .71597 L p .707 .577 .707 r
F P
0 g
s
.73217 .77456 m .73746 .75743 L .7076 .74666 L p .707 .577 .707 r
F P
0 g
s
.73746 .75743 m .73217 .77456 L .76281 .78179 L p .707 .577 .707 r
F P
0 g
s
.76281 .78179 m .7681 .76466 L .73746 .75743 L p .707 .577 .707 r
F P
0 g
s
.54244 .24469 m .57284 .74885 L .52891 .74888 L p .707 .577 .707 r
F P
0 g
s
.52891 .74888 m .49851 .24472 L .54244 .24469 L p .707 .577 .707 r
F P
0 g
s
.79309 .70487 m .78167 .73876 L .80501 .7375 L p .707 .577 .707 r
F P
0 g
s
.80501 .7375 m .81644 .70362 L .79309 .70487 L p .707 .577 .707 r
F P
0 g
s
.70231 .76379 m .7076 .74666 L .68146 .7334 L p .707 .577 .707 r
F P
0 g
s
.7076 .74666 m .70231 .76379 L .73217 .77456 L p .707 .577 .707 r
F P
0 g
s
.7681 .76466 m .76281 .78179 L .79125 .78476 L p .707 .577 .707 r
F P
0 g
s
.79125 .78476 m .79654 .76763 L .7681 .76466 L p .707 .577 .707 r
F P
0 g
s
.48404 .75242 m .45364 .24826 L .49851 .24472 L p .707 .577 .707 r
F P
0 g
s
.45364 .24826 m .48404 .75242 L .44262 .75912 L p .707 .577 .707 r
F P
0 g
s
.68146 .7334 m .67617 .75053 L .70231 .76379 L p .707 .577 .707 r
F P
0 g
s
.49851 .24472 m .52891 .74888 L .48404 .75242 L p .707 .577 .707 r
F P
0 g
s
.67617 .75053 m .68146 .7334 L .66159 .71894 L p .707 .577 .707 r
F P
0 g
s
.79654 .76763 m .79125 .78476 L .8147 .78319 L p .707 .577 .707 r
F P
0 g
s
.8147 .78319 m .81999 .76606 L .79654 .76763 L p .707 .577 .707 r
F P
0 g
s
.83899 .59696 m .83039 .65089 L .83753 .64176 L p .707 .577 .707 r
F P
0 g
s
.83753 .64176 m .84614 .58782 L .83899 .59696 L p .707 .577 .707 r
F P
0 g
s
.66159 .71894 m .6563 .73607 L .67617 .75053 L p .707 .577 .707 r
F P
0 g
s
.6387 .61907 m .6473 .56513 L .64458 .55436 L p .707 .577 .707 r
F P
0 g
s
.81644 .70362 m .80501 .7375 L .82114 .73165 L p .707 .577 .707 r
F P
0 g
s
.82114 .73165 m .83256 .69777 L .81644 .70362 L p .707 .577 .707 r
F P
0 g
s
.64766 .63832 m .63624 .6722 L .64773 .68693 L p .707 .577 .707 r
F P
0 g
s
.6563 .73607 m .66159 .71894 L .64994 .70471 L p .707 .577 .707 r
F P
0 g
s
.81999 .76606 m .8147 .78319 L .83086 .77722 L p .707 .577 .707 r
F P
0 g
s
.83086 .77722 m .83615 .76009 L .81999 .76606 L p .707 .577 .707 r
F P
0 g
s
.64458 .55436 m .63598 .6083 L .6387 .61907 L p .707 .577 .707 r
F P
0 g
s
.64994 .70471 m .64465 .72184 L .6563 .73607 L p .707 .577 .707 r
F P
0 g
s
.63624 .6722 m .64766 .63832 L .64547 .62538 L p .707 .577 .707 r
F P
0 g
s
.84614 .58782 m .83753 .64176 L .83481 .63099 L p .707 .577 .707 r
F P
0 g
s
.83481 .63099 m .84341 .57705 L .84614 .58782 L p .707 .577 .707 r
F P
0 g
s
.83256 .69777 m .82114 .73165 L .82846 .72177 L p .707 .577 .707 r
F P
0 g
s
.82846 .72177 m .83989 .68789 L .83256 .69777 L p .707 .577 .707 r
F P
0 g
s
.63598 .6083 m .64458 .55436 L .65172 .54523 L p .707 .577 .707 r
F P
0 g
s
.64547 .62538 m .63405 .65926 L .63624 .6722 L p .707 .577 .707 r
F P
0 g
s
.64465 .72184 m .64994 .70471 L .64765 .69209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83615 .76009 m .83086 .77722 L .83815 .76745 L p .707 .577 .707 r
F P
0 g
s
.83815 .76745 m .84345 .75033 L .83615 .76009 L p .707 .577 .707 r
F P
0 g
s
.64765 .69209 m .64236 .70922 L .64465 .72184 L p .707 .577 .707 r
F P
0 g
s
.65172 .54523 m .64312 .59917 L .63598 .6083 L p .707 .577 .707 r
F P
0 g
s
.63405 .65926 m .64547 .62538 L .6528 .6155 L p .707 .577 .707 r
F P
0 g
s
.84341 .57705 m .83481 .63099 L .82249 .61964 L p .707 .577 .707 r
F P
0 g
s
.82249 .61964 m .83109 .5657 L .84341 .57705 L p .707 .577 .707 r
F P
0 g
s
.83989 .68789 m .82846 .72177 L .82627 .70883 L p .707 .577 .707 r
F P
0 g
s
.82627 .70883 m .8377 .67495 L .83989 .68789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64312 .59917 m .65172 .54523 L .66803 .53863 L p .707 .577 .707 r
F P
0 g
s
.6528 .6155 m .64137 .64938 L .63405 .65926 L p .707 .577 .707 r
F P
0 g
s
.38659 .62912 m .39519 .57518 L .3644 .56844 L p .707 .577 .707 r
F P
0 g
s
.39519 .57518 m .38659 .62912 L .41808 .63271 L p .707 .577 .707 r
F P
0 g
s
.41808 .63271 m .42669 .57878 L .39519 .57518 L p .707 .577 .707 r
F P
0 g
s
.64236 .70922 m .64765 .69209 L .65494 .68232 L p .707 .577 .707 r
F P
0 g
s
.42669 .57878 m .41808 .63271 L .44719 .6328 L p .707 .577 .707 r
F P
0 g
s
.44719 .6328 m .4558 .57887 L .42669 .57878 L p .707 .577 .707 r
F P
0 g
s
.3558 .62237 m .3644 .56844 L .33732 .5592 L p .707 .577 .707 r
F P
0 g
s
.3644 .56844 m .3558 .62237 L .38659 .62912 L p .707 .577 .707 r
F P
0 g
s
.84345 .75033 m .83815 .76745 L .83586 .75483 L p .707 .577 .707 r
F P
0 g
s
.83586 .75483 m .84115 .73771 L .84345 .75033 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65494 .68232 m .64965 .69945 L .64236 .70922 L p .707 .577 .707 r
F P
0 g
s
.66803 .53863 m .65943 .59257 L .64312 .59917 L p .707 .577 .707 r
F P
0 g
s
.64137 .64938 m .6528 .6155 L .66893 .60964 L p .707 .577 .707 r
F P
0 g
s
.4558 .57887 m .44719 .6328 L .47107 .62938 L p .707 .577 .707 r
F P
0 g
s
.47107 .62938 m .47967 .57544 L .4558 .57887 L p .707 .577 .707 r
F P
0 g
s
.83109 .5657 m .82249 .61964 L .80178 .60881 L p .707 .577 .707 r
F P
0 g
s
.80178 .60881 m .81038 .55488 L .83109 .5657 L p .707 .577 .707 r
F P
0 g
s
.32872 .61313 m .33732 .5592 L .31661 .54837 L p .707 .577 .707 r
F P
0 g
s
.33732 .5592 m .32872 .61313 L .3558 .62237 L p .707 .577 .707 r
F P
0 g
s
.8377 .67495 m .82627 .70883 L .81479 .6941 L p .707 .577 .707 r
F P
0 g
s
.81479 .6941 m .82621 .66022 L .8377 .67495 L p .707 .577 .707 r
F P
0 g
s
.65943 .59257 m .66803 .53863 L .69191 .53521 L p .707 .577 .707 r
F P
0 g
s
.37993 .68667 m .39136 .65279 L .36172 .64133 L p .707 .577 .707 r
F P
0 g
s
.39136 .65279 m .37993 .68667 L .41038 .69452 L p .707 .577 .707 r
F P
0 g
s
.41038 .69452 m .4218 .66064 L .39136 .65279 L p .707 .577 .707 r
F P
0 g
s
.3503 .67521 m .36172 .64133 L .33581 .62737 L p .707 .577 .707 r
F P
0 g
s
.36172 .64133 m .3503 .67521 L .37993 .68667 L p .707 .577 .707 r
F P
0 g
s
.66893 .60964 m .6575 .64353 L .64137 .64938 L p .707 .577 .707 r
F P
0 g
s
.4218 .66064 m .41038 .69452 L .43866 .69799 L p .707 .577 .707 r
F P
0 g
s
.43866 .69799 m .45008 .66411 L .4218 .66064 L p .707 .577 .707 r
F P
0 g
s
.64965 .69945 m .65494 .68232 L .6711 .67636 L p .707 .577 .707 r
F P
0 g
s
.84115 .73771 m .83586 .75483 L .82421 .7406 L p .707 .577 .707 r
F P
0 g
s
.82421 .7406 m .8295 .72347 L .84115 .73771 L p .707 .577 .707 r
F P
0 g
s
.38916 .72487 m .39445 .70775 L .36459 .69697 L p .707 .577 .707 r
F P
0 g
s
.39445 .70775 m .38916 .72487 L .4198 .7321 L p .707 .577 .707 r
F P
0 g
s
.4198 .7321 m .42509 .71497 L .39445 .70775 L p .707 .577 .707 r
F P
0 g
s
.6711 .67636 m .66581 .69349 L .64965 .69945 L p .707 .577 .707 r
F P
0 g
s
.31661 .54837 m .30801 .60231 L .32872 .61313 L p .707 .577 .707 r
F P
0 g
s
.47967 .57544 m .47107 .62938 L .48738 .62278 L p .707 .577 .707 r
F P
0 g
s
.48738 .62278 m .49598 .56884 L .47967 .57544 L p .707 .577 .707 r
F P
0 g
s
.69191 .53521 m .68331 .58914 L .65943 .59257 L p .707 .577 .707 r
F P
0 g
s
.32438 .66125 m .33581 .62737 L .31614 .61229 L p .707 .577 .707 r
F P
0 g
s
.33581 .62737 m .32438 .66125 L .3503 .67521 L p .707 .577 .707 r
F P
0 g
s
.81038 .55488 m .80178 .60881 L .7747 .59957 L p .707 .577 .707 r
F P
0 g
s
.7747 .59957 m .78331 .54564 L .81038 .55488 L p .707 .577 .707 r
F P
0 g
s
.6575 .64353 m .66893 .60964 L .69227 .60839 L p .707 .577 .707 r
F P
0 g
s
.3593 .7141 m .36459 .69697 L .33845 .68371 L p .707 .577 .707 r
F P
0 g
s
.36459 .69697 m .3593 .7141 L .38916 .72487 L p .707 .577 .707 r
F P
0 g
s
.30801 .60231 m .31661 .54837 L .30429 .53702 L p .707 .577 .707 r
F P
0 g
s
.68331 .58914 m .69191 .53521 L .72102 .5353 L p .707 .577 .707 r
F P
0 g
s
.42509 .71497 m .4198 .7321 L .44824 .73507 L p .707 .577 .707 r
F P
0 g
s
.44824 .73507 m .45353 .71794 L .42509 .71497 L p .707 .577 .707 r
F P
0 g
s
.45008 .66411 m .43866 .69799 L .462 .69674 L p .707 .577 .707 r
F P
0 g
s
.462 .69674 m .47343 .66286 L .45008 .66411 L p .707 .577 .707 r
F P
0 g
s
.82621 .66022 m .81479 .6941 L .79512 .67902 L p .707 .577 .707 r
F P
0 g
s
.79512 .67902 m .80654 .64514 L .82621 .66022 L p .707 .577 .707 r
F P
0 g
s
.33845 .68371 m .33316 .70084 L .3593 .7141 L p .707 .577 .707 r
F P
0 g
s
.31614 .61229 m .30472 .64617 L .32438 .66125 L p .707 .577 .707 r
F P
0 g
s
.78331 .54564 m .7747 .59957 L .74391 .59283 L p .707 .577 .707 r
F P
0 g
s
.74391 .59283 m .75251 .53889 L .78331 .54564 L p .707 .577 .707 r
F P
0 g
s
.33316 .70084 m .33845 .68371 L .31858 .66926 L p .707 .577 .707 r
F P
0 g
s
.69227 .60839 m .68084 .64227 L .6575 .64353 L p .707 .577 .707 r
F P
0 g
s
.71242 .58923 m .72102 .5353 L .75251 .53889 L p .707 .577 .707 r
F P
0 g
s
.72102 .5353 m .71242 .58923 L .68331 .58914 L p .707 .577 .707 r
F P
0 g
s
.45353 .71794 m .44824 .73507 L .47169 .7335 L p .707 .577 .707 r
F P
0 g
s
.47169 .7335 m .47698 .71637 L .45353 .71794 L p .707 .577 .707 r
F P
0 g
s
.66581 .69349 m .6711 .67636 L .69455 .67479 L p .707 .577 .707 r
F P
0 g
s
.75251 .53889 m .74391 .59283 L .71242 .58923 L p .707 .577 .707 r
F P
0 g
s
.30429 .53702 m .29569 .59096 L .30801 .60231 L p .707 .577 .707 r
F P
0 g
s
.30472 .64617 m .31614 .61229 L .30465 .59755 L p .707 .577 .707 r
F P
0 g
s
.31858 .66926 m .31329 .68638 L .33316 .70084 L p .707 .577 .707 r
F P
0 g
s
.68084 .64227 m .69227 .60839 L .72055 .61186 L p .707 .577 .707 r
F P
0 g
s
.8295 .72347 m .82421 .7406 L .80434 .72614 L p .707 .577 .707 r
F P
0 g
s
.80434 .72614 m .80964 .70902 L .8295 .72347 L p .707 .577 .707 r
F P
0 g
s
.69455 .67479 m .68926 .69191 L .66581 .69349 L p .707 .577 .707 r
F P
0 g
s
.49598 .56884 m .48738 .62278 L .49452 .61365 L p .707 .577 .707 r
F P
0 g
s
.49452 .61365 m .50313 .55971 L .49598 .56884 L p .707 .577 .707 r
F P
0 g
s
.47343 .66286 m .462 .69674 L .47813 .69089 L p .707 .577 .707 r
F P
0 g
s
.47813 .69089 m .48955 .65701 L .47343 .66286 L p .707 .577 .707 r
F P
0 g
s
.80654 .64514 m .79512 .67902 L .7692 .66506 L p .707 .577 .707 r
F P
0 g
s
.7692 .66506 m .78063 .63118 L .80654 .64514 L p .707 .577 .707 r
F P
0 g
s
.29569 .59096 m .30429 .53702 L .30157 .52625 L p .707 .577 .707 r
F P
0 g
s
.30465 .59755 m .29323 .63143 L .30472 .64617 L p .707 .577 .707 r
F P
0 g
s
.31329 .68638 m .31858 .66926 L .30693 .65502 L p .707 .577 .707 r
F P
0 g
s
.72055 .61186 m .70912 .64574 L .68084 .64227 L p .707 .577 .707 r
F P
0 g
s
.70912 .64574 m .72055 .61186 L .751 .61971 L p .707 .577 .707 r
F P
0 g
s
.78063 .63118 m .7692 .66506 L .73957 .65359 L p .707 .577 .707 r
F P
0 g
s
.73957 .65359 m .751 .61971 L .78063 .63118 L p .707 .577 .707 r
F P
0 g
s
.47698 .71637 m .47169 .7335 L .48785 .72753 L p .707 .577 .707 r
F P
0 g
s
.48785 .72753 m .49314 .71041 L .47698 .71637 L p .707 .577 .707 r
F P
0 g
s
.68926 .69191 m .69455 .67479 L .72299 .67776 L p .707 .577 .707 r
F P
0 g
s
.30693 .65502 m .30164 .67215 L .31329 .68638 L p .707 .577 .707 r
F P
0 g
s
.751 .61971 m .73957 .65359 L .70912 .64574 L p .707 .577 .707 r
F P
0 g
s
.80964 .70902 m .80434 .72614 L .7782 .71288 L p .707 .577 .707 r
F P
0 g
s
.7782 .71288 m .78349 .69575 L .80964 .70902 L p .707 .577 .707 r
F P
0 g
s
.29323 .63143 m .30465 .59755 L .30246 .58461 L p .707 .577 .707 r
F P
0 g
s
.72299 .67776 m .7177 .69489 L .68926 .69191 L p .707 .577 .707 r
F P
0 g
s
.30157 .52625 m .29296 .58019 L .29569 .59096 L p .707 .577 .707 r
F P
0 g
s
.48955 .65701 m .47813 .69089 L .48545 .68101 L p .707 .577 .707 r
F P
0 g
s
.48545 .68101 m .49688 .64713 L .48955 .65701 L p .707 .577 .707 r
F P
0 g
s
.7177 .69489 m .72299 .67776 L .75364 .68498 L p .707 .577 .707 r
F P
0 g
s
.50313 .55971 m .49452 .61365 L .4918 .60288 L p .707 .577 .707 r
F P
0 g
s
.4918 .60288 m .5004 .54894 L .50313 .55971 L p .707 .577 .707 r
F P
0 g
s
.78349 .69575 m .7782 .71288 L .74835 .70211 L p .707 .577 .707 r
F P
0 g
s
.74835 .70211 m .75364 .68498 L .78349 .69575 L p .707 .577 .707 r
F P
0 g
s
.29296 .58019 m .30157 .52625 L .30871 .51712 L p .707 .577 .707 r
F P
0 g
s
.75364 .68498 m .74835 .70211 L .7177 .69489 L p .707 .577 .707 r
F P
0 g
s
.30246 .58461 m .29104 .6185 L .29323 .63143 L p .707 .577 .707 r
F P
0 g
s
.30164 .67215 m .30693 .65502 L .30464 .6424 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49314 .71041 m .48785 .72753 L .49514 .71776 L p .707 .577 .707 r
F P
0 g
s
.49514 .71776 m .50043 .70064 L .49314 .71041 L p .707 .577 .707 r
F P
0 g
s
.30464 .6424 m .29935 .65953 L .30164 .67215 L p .707 .577 .707 r
F P
0 g
s
.29104 .6185 m .30246 .58461 L .30979 .57474 L p .707 .577 .707 r
F P
0 g
s
.30871 .51712 m .30011 .57105 L .29296 .58019 L p .707 .577 .707 r
F P
0 g
s
.49688 .64713 m .48545 .68101 L .48326 .66807 L p .707 .577 .707 r
F P
0 g
s
.48326 .66807 m .49469 .63419 L .49688 .64713 L p .707 .577 .707 r
F P
0 g
s
.5004 .54894 m .4918 .60288 L .47948 .59152 L p .707 .577 .707 r
F P
0 g
s
.47948 .59152 m .48808 .53759 L .5004 .54894 L p .707 .577 .707 r
F P
0 g
s
.30011 .57105 m .30871 .51712 L .32502 .51052 L p .707 .577 .707 r
F P
0 g
s
.30979 .57474 m .29836 .60862 L .29104 .6185 L p .707 .577 .707 r
F P
0 g
s
.29935 .65953 m .30464 .6424 L .31193 .63263 L p .707 .577 .707 r
F P
0 g
s
.50043 .70064 m .49514 .71776 L .49285 .70515 L p .707 .577 .707 r
F P
0 g
s
.49285 .70515 m .49814 .68802 L .50043 .70064 L p .707 .577 .707 r
F P
0 g
s
.31193 .63263 m .30664 .64976 L .29935 .65953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29836 .60862 m .30979 .57474 L .32592 .56888 L p .707 .577 .707 r
F P
0 g
s
.32502 .51052 m .31642 .56445 L .30011 .57105 L p .707 .577 .707 r
F P
0 g
s
.49469 .63419 m .48326 .66807 L .47177 .65334 L p .707 .577 .707 r
F P
0 g
s
.47177 .65334 m .4832 .61946 L .49469 .63419 L p .707 .577 .707 r
F P
0 g
s
.48808 .53759 m .47948 .59152 L .45877 .5807 L p .707 .577 .707 r
F P
0 g
s
.45877 .5807 m .46737 .52676 L .48808 .53759 L p .707 .577 .707 r
F P
0 g
s
.31642 .56445 m .32502 .51052 L .3489 .50709 L p .707 .577 .707 r
F P
0 g
s
.32592 .56888 m .31449 .60276 L .29836 .60862 L p .707 .577 .707 r
F P
0 g
s
.30664 .64976 m .31193 .63263 L .32809 .62667 L p .707 .577 .707 r
F P
0 g
s
.49814 .68802 m .49285 .70515 L .4812 .69091 L p .707 .577 .707 r
F P
0 g
s
.4812 .69091 m .48649 .67378 L .49814 .68802 L p .707 .577 .707 r
F P
0 g
s
.32809 .62667 m .3228 .6438 L .30664 .64976 L p .707 .577 .707 r
F P
0 g
s
.31449 .60276 m .32592 .56888 L .34926 .56763 L p .707 .577 .707 r
F P
0 g
s
.3489 .50709 m .34029 .56103 L .31642 .56445 L p .707 .577 .707 r
F P
0 g
s
.46737 .52676 m .45877 .5807 L .43169 .57146 L p .707 .577 .707 r
F P
0 g
s
.43169 .57146 m .44029 .51752 L .46737 .52676 L p .707 .577 .707 r
F P
0 g
s
.34029 .56103 m .3489 .50709 L .37801 .50718 L p .707 .577 .707 r
F P
0 g
s
.4832 .61946 m .47177 .65334 L .45211 .63825 L p .707 .577 .707 r
F P
0 g
s
.45211 .63825 m .46353 .60437 L .4832 .61946 L p .707 .577 .707 r
F P
0 g
s
.34926 .56763 m .33783 .60151 L .31449 .60276 L p .707 .577 .707 r
F P
0 g
s
.3228 .6438 m .32809 .62667 L .35154 .6251 L p .707 .577 .707 r
F P
0 g
s
.44029 .51752 m .43169 .57146 L .4009 .56472 L p .707 .577 .707 r
F P
0 g
s
.4009 .56472 m .4095 .51078 L .44029 .51752 L p .707 .577 .707 r
F P
0 g
s
.3694 .56112 m .37801 .50718 L .4095 .51078 L p .707 .577 .707 r
F P
0 g
s
.37801 .50718 m .3694 .56112 L .34029 .56103 L p .707 .577 .707 r
F P
0 g
s
.48649 .67378 m .4812 .69091 L .46133 .67645 L p .707 .577 .707 r
F P
0 g
s
.46133 .67645 m .46662 .65933 L .48649 .67378 L p .707 .577 .707 r
F P
0 g
s
.33783 .60151 m .34926 .56763 L .37754 .5711 L p .707 .577 .707 r
F P
0 g
s
.35154 .6251 m .34625 .64223 L .3228 .6438 L p .707 .577 .707 r
F P
0 g
s
.4095 .51078 m .4009 .56472 L .3694 .56112 L p .707 .577 .707 r
F P
0 g
s
.46353 .60437 m .45211 .63825 L .42619 .6243 L p .707 .577 .707 r
F P
0 g
s
.42619 .6243 m .43762 .59042 L .46353 .60437 L p .707 .577 .707 r
F P
0 g
s
.37754 .5711 m .36611 .60498 L .33783 .60151 L p .707 .577 .707 r
F P
0 g
s
.36611 .60498 m .37754 .5711 L .40799 .57895 L p .707 .577 .707 r
F P
0 g
s
.34625 .64223 m .35154 .6251 L .37998 .62807 L p .707 .577 .707 r
F P
0 g
s
.43762 .59042 m .42619 .6243 L .39656 .61283 L p .707 .577 .707 r
F P
0 g
s
.39656 .61283 m .40799 .57895 L .43762 .59042 L p .707 .577 .707 r
F P
0 g
s
.46662 .65933 m .46133 .67645 L .43519 .66319 L p .707 .577 .707 r
F P
0 g
s
.43519 .66319 m .44048 .64606 L .46662 .65933 L p .707 .577 .707 r
F P
0 g
s
.40799 .57895 m .39656 .61283 L .36611 .60498 L p .707 .577 .707 r
F P
0 g
s
.37998 .62807 m .37469 .6452 L .34625 .64223 L p .707 .577 .707 r
F P
0 g
s
.37469 .6452 m .37998 .62807 L .41063 .63529 L p .707 .577 .707 r
F P
0 g
s
.44048 .64606 m .43519 .66319 L .40534 .65242 L p .707 .577 .707 r
F P
0 g
s
.40534 .65242 m .41063 .63529 L .44048 .64606 L p .707 .577 .707 r
F P
0 g
s
.41063 .63529 m .40534 .65242 L .37469 .6452 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Qgoo6@00OGoo001nOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Qoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH3001]Ool006eoo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006]oo`00JWoo0`0025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0J7oo001XOol200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIZOol006Ioo`8000=JEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<007ooOol0Igoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUIYOol0
06=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYFJGoo001ROol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUIYOol0069oo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF
00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001ROol00`00FUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006=oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001XOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVQoo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol006=oo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEUYF001JEVQoo`00Hgoo00<005YF00001eYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo
001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00I7oo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006Aoo`03001JEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYFFUH005YFIgoo001TOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001J
EVMoo`00I7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00H7oo40002EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00
Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00FGoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol0
05Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
FUH005YFIGoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVEoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001TOol005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000I7oo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Qooa0004aoo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0017oo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00AGoo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00=JEP<003Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF0`00=7oo001DOol20003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000bOol005Aoo`8000=J
EP@0009JEP03001JEP0000<00005Ool005YFFUH00003FUH70006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<7oo001COol01000FUH005YF0`000UYF3P00
15YF1@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP8002moo`00Dgoo00@005YF0000009JEP@000IJEP04001JEUYFFUH<0005FUH40006
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool005=oo`<0009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEP0000L000EJEP04001JEP000004FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P000UYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Goo001COol00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP06FUH20005FUH01`00FUIJEUYF001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000;Goo001COol01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00@005YF000000=JEP07001JEUYF
FUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP04001JEUYFFUH200000eYF001JEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<00003FUH005YF00EJEP8000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEP000003FUH50002FUH00`00FUH000030008Ool70006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJ
EP07001JEP00FUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF000005YF00<000IJEP03001JEUYF00=JEP@000Ioo`<0009oo`@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000iOol@000;Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJ
EP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000300000goo000000030005Ool4
0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000goo00<005YF00000UYF300015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qo
o`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0039oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH00000008000=JEP03001JEUYF00AJEPH0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP8000IJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD00003FUH0000000X00003FUH005YF00EJEP04001JEUYFFUH2000]Ool0031oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP06001o
o`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00P000eYF00<005YF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
00=JEP00FUH00UYF00<005YFFUH0300025YF0`001UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJ
EP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0015YF1P001UYF00<005YFFUH01UYF100025YF00<005YFFUH01EYF00@005YFFUIJEP80
009JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000EJEP<0
0003FUH005YF00AJEP04001JEUYFFUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH0
0`00FUIJEP02FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEPD00003Ool000000080009JEP03001JEUYF
00IJEP04001JEUYFFUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0
05YF00=JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEP@000=oo`@000IJEP03001JEUYF
00EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP80009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH00UYF0P0000=JEP0000002@000UYF00<005YFFUH01UYF00@005YF000000MJEP03001J
EUYF00EJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP000080
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000QJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEP0002eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01P000UYF00<0
05YFFUH00UYF2P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH007oo02aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEP0000l000=JEP03001JEUYF00AJEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP030007FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP8000AJEP04001J
EUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200001EYF001JEUYF
00000eYF1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00L005YF
FUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH50007FUH70006FUH00`00FUIJEP06FUH20005
FUH01@00FUIJEUYF00000eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0`000UYF2`0000=JEP0000001@001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=J
EP00FUH00eYF0P00;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH6
0002FUH00`00FUIJEP07FUH30004FUH30004FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH500000eYF001JEP03FUH30002Ool50003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH30004FUH2000_Ool002eoo`8000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP07FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70007FUH01000FUIJEUYF0P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP<000AJEP05001JEUYFFUH00002FUH00`00Oomoo`04Ool40002FUH40008FUH00`00FUIJEP06FUH0
0`00FUIJEP02000015YF00000000<7oo000]Ool20003FUH40002FUH00`00FUH000030008Ool70006
FUH00`00FUH0000200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00005
0005FUH00`00FUIJEP03FUH20003FUH01P00FUIJEP00FUH000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP<000AJEP800003FUH005YF00=JEP8000Qoo`P000IJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo035oo`00;7oo00@005YF001JEP<0009JEPh000Aoo`D00003Ool0
00000080009JEP04001JEP00FUH20002FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50000
0eYF001JEP07FUH01000FUIJEP000UYF00<005YF00001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00P001UYF00<007ooOol037oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<007ooOol0<7oo000/Ool01000FUH000000UYF10001UYF00@0
05YFFUIJEP`000Eoo`H00004FUH005YFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP020008FUH600000eYF001JEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH01@00FUIJEUYF00001UYF0P0047oo0P0000=JEP00FUH01eYF00<005YFFUH015YF0P00
<Goo000/Ool30002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070007Ool20002
FUH01000FUH005YF0P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF
00P005YFFUH005YF001JEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00002Goo0`001Goo0P0025YF00<005YFFUH0
0eYF00@005YFFUH0031oo`00;7oo0P000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF300015YF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH015YF0P000UYF00D005YFFUIJEP0000Moo`D000Ioo`8000EJ
EP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEUYF008000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000002FUH01000FUIJEP0015YF0`0015YF0`00
2EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH000060007Ool50008Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02aoo`05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30003FUH01@00FUIJEUYF00000UYF00H005YFFUIJEP00FUH20008FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH01UYF10000eYF00@005YFFUIJEP`000Yoo`<000IJEP03001JEUYF
00=JEP03001oogoo02aoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YF000015YF0P0000=JEP00FUH00UYF0`001EYF00<005YF
00000P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH010003Goo00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH20006FUH20003FUH200001goo00000000FUH005YF00D0009JEP03001JEUYF00EJEP03
001JEUYF00AJEP<0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH00000FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
10002Woo0P0015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP08FUH300000eYF001JEP05FUH300001UYF001J
EP00Ool0009JEPP0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000:Ool01@00FUIJEUYF0000
0eYF00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00@005YFFUIJEP800004FUH007oo0002FUH00`00
FUIJEP0500000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF
1P0015YF00<005YFFUH01eYF00<005YFFUH00UYF0`0027oo0`0015YF00<005YF0000;Woo000/Ool0
0`00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30002FUH0
0`00FUIJEP03FUH200001Goo001JEUYF00000eYF2@0015YF00<005YFFUH015YF00D005YF000005YF
008000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYF0002FUH60006FUH70007FUH00`00FUIJEP05FUH20008Ool00`00FUIJEP02FUH2000_Ool002ao
o`800003FUH00000008000=JEP03001JEUYF00AJEPH000MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP<000QJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP07001JEP00FUH005YF0000
1UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001P0025YF00<005YF
FUH01EYF10000UYF00<005YFFUH01eYF0`001goo00H005YFFUH005YF000_Ool002aoo`<0009JEP06
001oo`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00
25YF00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000P0000AJEP00
000000QJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF008000Eoo`06001JEUYF001J
EP00;goo000/Ool00`00FUH00003FUH00`00Oomoo`030006FUH00`00FUIJEP06FUH40008FUH00`00
FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YF
FUH02EYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH400000eYF000000040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03
FUH800000eYF001oo`0_Ool002]oo`<000AJEP<000=oo`8000AJEP03001JEUYF00IJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH300000eYF001J
EP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP0000000P000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF0P0000IJEP00FUH005YF000`Ool002]oo`03001JEP0000=JEP05001JEUYFFUH0
0004Ool300000eYF001JEP07FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP04FUH3
00000eYF001JEP08FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUH000030007FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP020005FUH300000eYF001J
EP07FUH00`00FUIJEP07FUH01000FUIJEUYF0P0025YF0P000UYF00<005YF0000<7oo000[Ool00`00
FUH00003FUH00`00FUIJEP02FUH20002Ool70005FUH00`00FUIJEP07FUH30007FUH00`00FUIJEP05
FUH2000017oo000000001eYF00<005YFFUH015YF1`001eYF1P0000=JEP00000025YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF00<005YF00000`001eYF
00<005YFFUH00`0015YF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=JEP00Ool0;goo000/
Ool00`00FUIJEP02FUH01000FUIJEUYF1@000UYF00<005YFFUH00UYF1P0025YF00@005YFFUIJEP80
00EJEP03001JEUYF00AJEP03001JEP0000Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
000015YF00<005YFFUH00UYF00<005YFFUH01@001EYF00<005YF000010000UYF00<005YFFUH01UYF
0P000eYF00<005YFFUH00UYF0P00<Goo000/Ool01@00FUIJEUYF00000UYF0P0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00@0
05YFFUH000Aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP8000=JEP03
001JEUYF009JEP800006Ool00000001JEP000UYF1@000UYF00<005YFFUH01EYF00<005YFFUH00`00
1UYF00<007ooOol0;goo000]Ool00`00FUIJEP030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH?0007FUH01@00FUIJEUYF00000goo00<005YFFUH01@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP0200000eYF001JEP03FUH20004Ool300000eYF00000003
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH2000`Ool002eoo`03001JEUYF
008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`03
001JEUYF00AJEP03001JEUYF009JEP05001oogooOol00002FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH0000035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP8000=JEP03001JEP0000Moo`D000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEP0002moo`00;Woo0`000eYF00@005YFFUIJ
EPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000Eoo`8000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF00<005YF00001@0015YF00@005YFFUIJEPD00003FUH005YF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000IJEP07001JEUYFFUH005YF0000
2Woo0`0000=JEP00FUH01eYF00<005YFFUH00UYF00@005YFFUH0009JEP05001JEUYFFUH0000^Ool0
02moo`80009JEPD000MJEPL000IJEP03001JEUYF00IJEP8000Eoo`05001JEUYFFUH00003FUH00`00
FUH00002Ool01000FUIJEP001UYF00<005YFFUH01EYF20001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP<00003FUH0000000ioo`D0
00AJEP04001JEUYFFUH5000017oo0000000015YF00<007ooOol0:goo000_Ool40003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH30004Ool30004FUH00`00FUH00002Ool0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00<001=oo`P000Qo
o`03001JEUYF009JEP03001oogoo02]oo`00;Woo100015YF00<005YFFUH01EYF00<005YFFUH01UYF
1`001eYF00@005YFFUIJEP8000Aoo`05001JEUYFFUH00002FUH01000Oomoo`000UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP8002=oo`03001JEUYF0080
02eoo`00;Woo0`0000=oo`0000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009o
o`8000EJEP03001JEUYF00=JEP8000=oo`06001JEUYF001JEP000goo00@005YFFUH000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEQP000EJEP03001JEUYF00IJEP03001JEUYF009J
EPH000MJEP<0021oo`03001JEUYF008002eoo`00;Woo00@005YF0000009oo`8000MJEP03001JEUYF
00MJEP03001JEUYF009JEP<00006Ool00000001JEP0025YF00@007ooOol0009JEP03001JEP0000=o
o`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH9000<FUH00`00FUIJEP09FUH80006
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0;7oo
000^Ool200000eYF001oo`02Ool00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60008
FUH5000015YF001JEP000goo00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF
009JEP8000EJEP03001JEUYF009JEP<001eoo`03001JEP0002eoo`00;Woo0P000UYF00@007ooOomo
o`8000EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30006FUH00`00FUIJEP030000
0eYF001oo`03Ool00`00FUIJEP08FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP03FUH30003
FUH00`00FUIJEP05FUH4000IOol00`00FUH0000]Ool002ioo`03001JEUYF009JEP03001oogoo009o
o`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009J
EP800003FUH007oo00Aoo`YJEP03001JEUYF009JEP<000MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001J
EUYF00<000UJEP03001JEUYF00@001Aoo`<002ioo`00;Woo00<005YFFUH00UYF0`0017oo0`002EYF
00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH20005Ool:FUH00`00FUH00002
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001JEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH015YF1P0027oo1P0000=J
EP000000;Woo000_Ool01@00FUIJEUYF00000UYF00<007ooOol00goo0P0025YF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP8000Eoo`UJEP<0009JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EP000004FUH00`00FUIJEP03FUH00`00Ool000020004FUH00`00FUIJEP07FUH01000FUIJEUYF2000
0eYF00@005YFFUIJEP8002ioo`00<7oo00<005YF000015YF0P001Goo0`001EYF00<005YF00000P00
0eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001Goo1eYF0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00=JEP03001oogoo009oo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035oo`8000IJEP03001o
ogoo00Eoo`<00003FUH005YF00D0009JEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001J
EUYF0004Ool5FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH00UYF0P001goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00<Woo00<005YFFUH0
15YF0`0027oo20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00@007oo
Oomoo`=JEP8000UJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF009JEP8000Yoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<0031oo`00<goo00<005YFFUH00UYF
00@005YFFUIJEP8000Uoo`D00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF008000AJEP04
001oogooOol2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000goo0P0015YF00<0
05YF00003Woo1P0015YF00@005YFFUIJEPH003=oo`00=7oo0P000UYF00<005YFFUH00eYF0P0027oo
2@0015YF00<005YFFUH015YF00@005YF0000009oo`05001JEUYFFUH00003Ool00eYF001JEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20005Ool00`00FUIJEP02FUH2000EOol8000iOol003Ioo`80
00QJEP8000moo`d000Eoo`05001JEP00FUH00002Ool20004FUH00`00FUIJEP0@FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`05
Ool01P00FUIJEP00FUH005Ioo`00=goo00<005YFFUH01UYF00<005YF00000P007goo0P0000AJEP00
Oomoo`8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006Ool01P00FUIJEP00FUH005Ioo`00>7oo
0P001UYF00<005YFFUH00UYF0`007Goo00<005YF00000goo00<005YFFUH00UYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEPT00003FUH007oo05Ioo`00>Woo0P000eYF00<005YFFUH01UYF0`006Woo0P00
17oo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH01UYF0P0000IJEP00FUH005YF001G
Ool003aoo`800003FUH005YF00QJEP03001JEP0000<001Aoo`@000Eoo`80009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP<000=JEP8000QJEP80009JEP03001JEP0005Moo`00?Woo0`001eYF00<005YFFUH015YF1P0027oo
1P000UYF00<007ooOol01Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH00`000UYF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=J
EP00Ool0EWoo0011Ool20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJEP80
00Yoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPH0
00=JEP03001JEUYF00IJEP8000=JEP03001JEUYF009JEP8005Qoo`00@goo0`0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH700000eYF000000030002FUH00`00FUIJEP05
FUH00`00FUIJEP030006FUH00`00Oomoo`1FOol004Ioo`@000IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH2000BOol80005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH:0002Ool20000
15YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF0P00Egoo001:
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000KOolH0002FUH00`00Oomo
o`09Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH00`00FUH0001FOol004ioo`H0
00AJEP04001JEUYFFUH6000`Ool20006FUH00`00Oomoo`0<Ool40002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000UYF00D005YFFUIJEP0005Eoo`00E7oo2000=goo00<005YFFUH015YF
0`0047oo1P0015YF00@005YFFUIJEPD00004Ool000000004FUH00`00Oomoo`1BOol009Aoo`8000AJ
EP03001JEUYF008001Aoo`P000Qoo`03001JEUYF009JEP03001oogoo059oo`00UWoo00@005YFFUH0
00EJEP8002=oo`03001JEUYF008005Aoo`00Ugoo0`001eYF0`0087oo00<005YFFUH00P00E7oo002I
Ool00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0Dgoo002JOol20005FUH00`00FUIJ
EP02FUH3000MOol00`00FUH0001DOol009aoo`8000=JEP03001JEUYF00EJEP@001Uoo`03001JEP00
05Aoo`00WWoo0`002EYF00<005YFFUH0100057oo0`00EGoo002POol20008FUH00`00FUIJEP04FUH6
0008Ool600000eYF0000001EOol00:9oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
1000FUIJEUYF0P00EGoo002UOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00EWoo002XOol30007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002[Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001GOol00:mo
o`H000AJEP04001JEUYFFUH6001JOol00;Eoo`P0061oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5939 .74946 m .59924 .69472 L .56821 .68981 L p .707 .577 .707 r
F P
0 g
s
.59924 .69472 m .5939 .74946 L .62561 .7514 L p .707 .577 .707 r
F P
0 g
s
.62561 .7514 m .63094 .69666 L .59924 .69472 L p .707 .577 .707 r
F P
0 g
s
.63094 .69666 m .62561 .7514 L .65488 .75018 L p .707 .577 .707 r
F P
0 g
s
.65488 .75018 m .66022 .69544 L .63094 .69666 L p .707 .577 .707 r
F P
0 g
s
.56288 .74454 m .56821 .68981 L .5409 .68241 L p .707 .577 .707 r
F P
0 g
s
.56821 .68981 m .56288 .74454 L .5939 .74946 L p .707 .577 .707 r
F P
0 g
s
.66022 .69544 m .65488 .75018 L .67887 .74591 L p .707 .577 .707 r
F P
0 g
s
.67887 .74591 m .6842 .69118 L .66022 .69544 L p .707 .577 .707 r
F P
0 g
s
.53556 .73714 m .5409 .68241 L .51997 .67323 L p .707 .577 .707 r
F P
0 g
s
.5409 .68241 m .53556 .73714 L .56288 .74454 L p .707 .577 .707 r
F P
0 g
s
.59003 .81613 m .59717 .78059 L .56659 .77267 L p .707 .577 .707 r
F P
0 g
s
.59717 .78059 m .59003 .81613 L .62133 .82078 L p .707 .577 .707 r
F P
0 g
s
.62133 .82078 m .62847 .78524 L .59717 .78059 L p .707 .577 .707 r
F P
0 g
s
.62847 .78524 m .62133 .82078 L .65029 .82171 L p .707 .577 .707 r
F P
0 g
s
.65029 .82171 m .65743 .78617 L .62847 .78524 L p .707 .577 .707 r
F P
0 g
s
.55945 .80821 m .56659 .77267 L .53972 .76226 L p .707 .577 .707 r
F P
0 g
s
.56659 .77267 m .55945 .80821 L .59003 .81613 L p .707 .577 .707 r
F P
0 g
s
.6842 .69118 m .67887 .74591 L .69522 .73902 L p .707 .577 .707 r
F P
0 g
s
.69522 .73902 m .70055 .68429 L .6842 .69118 L p .707 .577 .707 r
F P
0 g
s
.51997 .67323 m .51464 .72797 L .53556 .73714 L p .707 .577 .707 r
F P
0 g
s
.5957 .86109 m .599 .84323 L .56833 .83576 L p .707 .577 .707 r
F P
0 g
s
.599 .84323 m .5957 .86109 L .62708 .86533 L p .707 .577 .707 r
F P
0 g
s
.62708 .86533 m .63038 .84748 L .599 .84323 L p .707 .577 .707 r
F P
0 g
s
.53972 .76226 m .53258 .7978 L .55945 .80821 L p .707 .577 .707 r
F P
0 g
s
.65743 .78617 m .65029 .82171 L .67407 .81882 L p .707 .577 .707 r
F P
0 g
s
.67407 .81882 m .68121 .78328 L .65743 .78617 L p .707 .577 .707 r
F P
0 g
s
.51464 .72797 m .51997 .67323 L .50748 .66319 L p .707 .577 .707 r
F P
0 g
s
.53258 .7978 m .53972 .76226 L .5192 .75038 L p .707 .577 .707 r
F P
0 g
s
.63038 .84748 m .62708 .86533 L .6561 .86594 L p .707 .577 .707 r
F P
0 g
s
.6561 .86594 m .6594 .84809 L .63038 .84748 L p .707 .577 .707 r
F P
0 g
s
.56503 .85362 m .56833 .83576 L .54138 .82581 L p .707 .577 .707 r
F P
0 g
s
.56833 .83576 m .56503 .85362 L .5957 .86109 L p .707 .577 .707 r
F P
0 g
s
.54138 .82581 m .53808 .84366 L .56503 .85362 L p .707 .577 .707 r
F P
0 g
s
.5192 .75038 m .51206 .78592 L .53258 .7978 L p .707 .577 .707 r
F P
0 g
s
.6594 .84809 m .6561 .86594 L .67992 .86285 L p .707 .577 .707 r
F P
0 g
s
.67992 .86285 m .68322 .84499 L .6594 .84809 L p .707 .577 .707 r
F P
0 g
s
.53808 .84366 m .54138 .82581 L .52078 .81433 L p .707 .577 .707 r
F P
0 g
s
.50748 .66319 m .50215 .71793 L .51464 .72797 L p .707 .577 .707 r
F P
0 g
s
.70055 .68429 m .69522 .73902 L .70232 .73018 L p .707 .577 .707 r
F P
0 g
s
.70232 .73018 m .70766 .67544 L .70055 .68429 L p .707 .577 .707 r
F P
0 g
s
.68121 .78328 m .67407 .81882 L .69034 .81241 L p .707 .577 .707 r
F P
0 g
s
.69034 .81241 m .69748 .77687 L .68121 .78328 L p .707 .577 .707 r
F P
0 g
s
.51206 .78592 m .5192 .75038 L .50703 .73819 L p .707 .577 .707 r
F P
0 g
s
.52078 .81433 m .51748 .83218 L .53808 .84366 L p .707 .577 .707 r
F P
0 g
s
.50215 .71793 m .50748 .66319 L .50465 .65327 L p .707 .577 .707 r
F P
0 g
s
.50703 .73819 m .49989 .77373 L .51206 .78592 L p .707 .577 .707 r
F P
0 g
s
.68322 .84499 m .67992 .86285 L .69621 .85636 L p .707 .577 .707 r
F P
0 g
s
.69621 .85636 m .69951 .83851 L .68322 .84499 L p .707 .577 .707 r
F P
0 g
s
.51748 .83218 m .52078 .81433 L .50855 .80246 L p .707 .577 .707 r
F P
0 g
s
.50465 .65327 m .49932 .708 L .50215 .71793 L p .707 .577 .707 r
F P
0 g
s
.50855 .80246 m .50525 .82031 L .51748 .83218 L p .707 .577 .707 r
F P
0 g
s
.69748 .77687 m .69034 .81241 L .69752 .80309 L p .707 .577 .707 r
F P
0 g
s
.69752 .80309 m .70466 .76755 L .69748 .77687 L p .707 .577 .707 r
F P
0 g
s
.49989 .77373 m .50703 .73819 L .5044 .72688 L p .707 .577 .707 r
F P
0 g
s
.70766 .67544 m .70232 .73018 L .69949 .72025 L p .707 .577 .707 r
F P
0 g
s
.69949 .72025 m .70483 .66552 L .70766 .67544 L p .707 .577 .707 r
F P
0 g
s
.49932 .708 m .50465 .65327 L .51176 .64443 L p .707 .577 .707 r
F P
0 g
s
.5044 .72688 m .49726 .76242 L .49989 .77373 L p .707 .577 .707 r
F P
0 g
s
.49726 .76242 m .5044 .72688 L .51158 .71756 L p .707 .577 .707 r
F P
0 g
s
.51158 .71756 m .50444 .7531 L .49726 .76242 L p .707 .577 .707 r
F P
0 g
s
.50232 .82126 m .48352 .31773 L .43955 .31672 L p .707 .577 .707 r
F P
0 g
s
.50525 .82031 m .50855 .80246 L .50589 .79136 L p .707 .577 .707 r
F P
0 g
s
.50589 .79136 m .50258 .80921 L .50525 .82031 L p .707 .577 .707 r
F P
0 g
s
.51176 .64443 m .50643 .69916 L .49932 .708 L p .707 .577 .707 r
F P
0 g
s
.50643 .69916 m .51176 .64443 L .52811 .63754 L p .707 .577 .707 r
F P
0 g
s
.50258 .80921 m .50589 .79136 L .51305 .78211 L p .707 .577 .707 r
F P
0 g
s
.51305 .78211 m .50975 .79997 L .50258 .80921 L p .707 .577 .707 r
F P
0 g
s
.52811 .63754 m .52277 .69227 L .50643 .69916 L p .707 .577 .707 r
F P
0 g
s
.50444 .7531 m .51158 .71756 L .52786 .71115 L p .707 .577 .707 r
F P
0 g
s
.52277 .69227 m .52811 .63754 L .55209 .63327 L p .707 .577 .707 r
F P
0 g
s
.52786 .71115 m .52072 .74669 L .50444 .7531 L p .707 .577 .707 r
F P
0 g
s
.50975 .79997 m .51305 .78211 L .52934 .77563 L p .707 .577 .707 r
F P
0 g
s
.55209 .63327 m .54676 .688 L .52277 .69227 L p .707 .577 .707 r
F P
0 g
s
.52934 .77563 m .52604 .79348 L .50975 .79997 L p .707 .577 .707 r
F P
0 g
s
.52072 .74669 m .52786 .71115 L .55164 .70827 L p .707 .577 .707 r
F P
0 g
s
.55164 .70827 m .5445 .74381 L .52072 .74669 L p .707 .577 .707 r
F P
0 g
s
.52604 .79348 m .52934 .77563 L .55316 .77253 L p .707 .577 .707 r
F P
0 g
s
.55316 .77253 m .54986 .79039 L .52604 .79348 L p .707 .577 .707 r
F P
0 g
s
.48352 .31773 m .50232 .82126 L .54723 .81865 L p .707 .577 .707 r
F P
0 g
s
.54723 .81865 m .52844 .31512 L .48352 .31773 L p .707 .577 .707 r
F P
0 g
s
.69951 .83851 m .69621 .85636 L .70337 .84712 L p .707 .577 .707 r
F P
0 g
s
.70337 .84712 m .70667 .82926 L .69951 .83851 L p .707 .577 .707 r
F P
0 g
s
.54676 .688 m .55209 .63327 L .58137 .63205 L p .707 .577 .707 r
F P
0 g
s
.58137 .63205 m .57604 .68678 L .54676 .688 L p .707 .577 .707 r
F P
0 g
s
.5445 .74381 m .55164 .70827 L .5806 .70919 L p .707 .577 .707 r
F P
0 g
s
.5806 .70919 m .57346 .74473 L .5445 .74381 L p .707 .577 .707 r
F P
0 g
s
.57346 .74473 m .5806 .70919 L .6119 .71384 L p .707 .577 .707 r
F P
0 g
s
.54986 .79039 m .55316 .77253 L .58218 .77314 L p .707 .577 .707 r
F P
0 g
s
.6119 .71384 m .60476 .74938 L .57346 .74473 L p .707 .577 .707 r
F P
0 g
s
.58218 .77314 m .57888 .791 L .54986 .79039 L p .707 .577 .707 r
F P
0 g
s
.57888 .791 m .58218 .77314 L .61356 .77739 L p .707 .577 .707 r
F P
0 g
s
.61356 .77739 m .61026 .79524 L .57888 .791 L p .707 .577 .707 r
F P
0 g
s
.52844 .31512 m .54723 .81865 L .58869 .81268 L p .707 .577 .707 r
F P
0 g
s
.57604 .68678 m .58137 .63205 L .61307 .63399 L p .707 .577 .707 r
F P
0 g
s
.61307 .63399 m .60774 .68872 L .57604 .68678 L p .707 .577 .707 r
F P
0 g
s
.58869 .81268 m .5699 .30916 L .52844 .31512 L p .707 .577 .707 r
F P
0 g
s
.45834 .82024 m .43955 .31672 L .40081 .31219 L p .707 .577 .707 r
F P
0 g
s
.43955 .31672 m .45834 .82024 L .50232 .82126 L p .707 .577 .707 r
F P
0 g
s
.70466 .76755 m .69752 .80309 L .6949 .79178 L p .707 .577 .707 r
F P
0 g
s
.6949 .79178 m .70204 .75624 L .70466 .76755 L p .707 .577 .707 r
F P
0 g
s
.70483 .66552 m .69949 .72025 L .687 .71021 L p .707 .577 .707 r
F P
0 g
s
.687 .71021 m .69234 .65548 L .70483 .66552 L p .707 .577 .707 r
F P
0 g
s
.6441 .6389 m .63877 .69363 L .60774 .68872 L p .707 .577 .707 r
F P
0 g
s
.60774 .68872 m .61307 .63399 L .6441 .6389 L p .707 .577 .707 r
F P
0 g
s
.64248 .72176 m .63534 .7573 L .60476 .74938 L p .707 .577 .707 r
F P
0 g
s
.60476 .74938 m .6119 .71384 L .64248 .72176 L p .707 .577 .707 r
F P
0 g
s
.64423 .78486 m .64093 .80271 L .61026 .79524 L p .707 .577 .707 r
F P
0 g
s
.61026 .79524 m .61356 .77739 L .64423 .78486 L p .707 .577 .707 r
F P
0 g
s
.5699 .30916 m .58869 .81268 L .62263 .80394 L p .707 .577 .707 r
F P
0 g
s
.62263 .80394 m .60384 .30041 L .5699 .30916 L p .707 .577 .707 r
F P
0 g
s
.25089 .71802 m .25623 .66329 L .2252 .65837 L p .707 .577 .707 r
F P
0 g
s
.25623 .66329 m .25089 .71802 L .2826 .71996 L p .707 .577 .707 r
F P
0 g
s
.2826 .71996 m .28793 .66523 L .25623 .66329 L p .707 .577 .707 r
F P
0 g
s
.70667 .82926 m .70337 .84712 L .70071 .83602 L p .707 .577 .707 r
F P
0 g
s
.70071 .83602 m .70401 .81816 L .70667 .82926 L p .707 .577 .707 r
F P
0 g
s
.28793 .66523 m .2826 .71996 L .31188 .71874 L p .707 .577 .707 r
F P
0 g
s
.31188 .71874 m .31721 .66401 L .28793 .66523 L p .707 .577 .707 r
F P
0 g
s
.41961 .81571 m .40081 .31219 L .37111 .30458 L p .707 .577 .707 r
F P
0 g
s
.40081 .31219 m .41961 .81571 L .45834 .82024 L p .707 .577 .707 r
F P
0 g
s
.21987 .71311 m .2252 .65837 L .19789 .65097 L p .707 .577 .707 r
F P
0 g
s
.2252 .65837 m .21987 .71311 L .25089 .71802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31721 .66401 m .31188 .71874 L .33586 .71447 L p .707 .577 .707 r
F P
0 g
s
.33586 .71447 m .34119 .65974 L .31721 .66401 L p .707 .577 .707 r
F P
0 g
s
.70204 .75624 m .6949 .79178 L .68273 .77959 L p .707 .577 .707 r
F P
0 g
s
.68273 .77959 m .68987 .74405 L .70204 .75624 L p .707 .577 .707 r
F P
0 g
s
.69234 .65548 m .687 .71021 L .66608 .70104 L p .707 .577 .707 r
F P
0 g
s
.66608 .70104 m .67141 .64631 L .69234 .65548 L p .707 .577 .707 r
F P
0 g
s
.66934 .73217 m .66221 .76771 L .63534 .7573 L p .707 .577 .707 r
F P
0 g
s
.63534 .7573 m .64248 .72176 L .66934 .73217 L p .707 .577 .707 r
F P
0 g
s
.64093 .80271 m .64423 .78486 L .67118 .79481 L p .707 .577 .707 r
F P
0 g
s
.60384 .30041 m .62263 .80394 L .64574 .79327 L p .707 .577 .707 r
F P
0 g
s
.67141 .64631 m .66608 .70104 L .63877 .69363 L p .707 .577 .707 r
F P
0 g
s
.63877 .69363 m .6441 .6389 L .67141 .64631 L p .707 .577 .707 r
F P
0 g
s
.64574 .79327 m .62694 .28975 L .60384 .30041 L p .707 .577 .707 r
F P
0 g
s
.19255 .7057 m .19789 .65097 L .17696 .6418 L p .707 .577 .707 r
F P
0 g
s
.19789 .65097 m .19255 .7057 L .21987 .71311 L p .707 .577 .707 r
F P
0 g
s
.24702 .77687 m .25416 .74133 L .22358 .73342 L p .707 .577 .707 r
F P
0 g
s
.25416 .74133 m .24702 .77687 L .27832 .78152 L p .707 .577 .707 r
F P
0 g
s
.27832 .78152 m .28546 .74598 L .25416 .74133 L p .707 .577 .707 r
F P
0 g
s
.28546 .74598 m .27832 .78152 L .30728 .78245 L p .707 .577 .707 r
F P
0 g
s
.30728 .78245 m .31442 .74691 L .28546 .74598 L p .707 .577 .707 r
F P
0 g
s
.21644 .76896 m .22358 .73342 L .19671 .72301 L p .707 .577 .707 r
F P
0 g
s
.22358 .73342 m .21644 .76896 L .24702 .77687 L p .707 .577 .707 r
F P
0 g
s
.70401 .81816 m .70071 .83602 L .68848 .82415 L p .707 .577 .707 r
F P
0 g
s
.68848 .82415 m .69178 .80629 L .70401 .81816 L p .707 .577 .707 r
F P
0 g
s
.38991 .80811 m .37111 .30458 L .35336 .29465 L p .707 .577 .707 r
F P
0 g
s
.37111 .30458 m .38991 .80811 L .41961 .81571 L p .707 .577 .707 r
F P
0 g
s
.34119 .65974 m .33586 .71447 L .35221 .70758 L p .707 .577 .707 r
F P
0 g
s
.35221 .70758 m .35754 .65285 L .34119 .65974 L p .707 .577 .707 r
F P
0 g
s
.25269 .81632 m .25599 .79846 L .22532 .79099 L p .707 .577 .707 r
F P
0 g
s
.25599 .79846 m .25269 .81632 L .28407 .82056 L p .707 .577 .707 r
F P
0 g
s
.28407 .82056 m .28737 .80271 L .25599 .79846 L p .707 .577 .707 r
F P
0 g
s
.17696 .6418 m .17163 .69653 L .19255 .7057 L p .707 .577 .707 r
F P
0 g
s
.19671 .72301 m .18957 .75855 L .21644 .76896 L p .707 .577 .707 r
F P
0 g
s
.31442 .74691 m .30728 .78245 L .33106 .77957 L p .707 .577 .707 r
F P
0 g
s
.33106 .77957 m .3382 .74403 L .31442 .74691 L p .707 .577 .707 r
F P
0 g
s
.18957 .75855 m .19671 .72301 L .17619 .71113 L p .707 .577 .707 r
F P
0 g
s
.28737 .80271 m .28407 .82056 L .31309 .82117 L p .707 .577 .707 r
F P
0 g
s
.31309 .82117 m .31639 .80331 L .28737 .80271 L p .707 .577 .707 r
F P
0 g
s
.22202 .80885 m .22532 .79099 L .19837 .78103 L p .707 .577 .707 r
F P
0 g
s
.22532 .79099 m .22202 .80885 L .25269 .81632 L p .707 .577 .707 r
F P
0 g
s
.17163 .69653 m .17696 .6418 L .16447 .63176 L p .707 .577 .707 r
F P
0 g
s
.68987 .74405 m .68273 .77959 L .66221 .76771 L p .707 .577 .707 r
F P
0 g
s
.66221 .76771 m .66934 .73217 L .68987 .74405 L p .707 .577 .707 r
F P
0 g
s
.19837 .78103 m .19507 .79889 L .22202 .80885 L p .707 .577 .707 r
F P
0 g
s
.17619 .71113 m .16905 .74667 L .18957 .75855 L p .707 .577 .707 r
F P
0 g
s
.31639 .80331 m .31309 .82117 L .33691 .81808 L p .707 .577 .707 r
F P
0 g
s
.33691 .81808 m .34021 .80022 L .31639 .80331 L p .707 .577 .707 r
F P
0 g
s
.19507 .79889 m .19837 .78103 L .17777 .76956 L p .707 .577 .707 r
F P
0 g
s
.62694 .28975 m .64574 .79327 L .65574 .78173 L p .707 .577 .707 r
F P
0 g
s
.65574 .78173 m .63695 .2782 L .62694 .28975 L p .707 .577 .707 r
F P
0 g
s
.69178 .80629 m .68848 .82415 L .66788 .81267 L p .707 .577 .707 r
F P
0 g
s
.66788 .81267 m .67118 .79481 L .69178 .80629 L p .707 .577 .707 r
F P
0 g
s
.16447 .63176 m .15914 .68649 L .17163 .69653 L p .707 .577 .707 r
F P
0 g
s
.3382 .74403 m .33106 .77957 L .34733 .77315 L p .707 .577 .707 r
F P
0 g
s
.34733 .77315 m .35447 .73761 L .3382 .74403 L p .707 .577 .707 r
F P
0 g
s
.16905 .74667 m .17619 .71113 L .16402 .69893 L p .707 .577 .707 r
F P
0 g
s
.17777 .76956 m .17447 .78741 L .19507 .79889 L p .707 .577 .707 r
F P
0 g
s
.35754 .65285 m .35221 .70758 L .35931 .69874 L p .707 .577 .707 r
F P
0 g
s
.35931 .69874 m .36465 .64401 L .35754 .65285 L p .707 .577 .707 r
F P
0 g
s
.15914 .68649 m .16447 .63176 L .16165 .62183 L p .707 .577 .707 r
F P
0 g
s
.16402 .69893 m .15688 .73448 L .16905 .74667 L p .707 .577 .707 r
F P
0 g
s
.34021 .80022 m .33691 .81808 L .3532 .81159 L p .707 .577 .707 r
F P
0 g
s
.3532 .81159 m .3565 .79374 L .34021 .80022 L p .707 .577 .707 r
F P
0 g
s
.37215 .79818 m .35336 .29465 L .34928 .28336 L p .707 .577 .707 r
F P
0 g
s
.35336 .29465 m .37215 .79818 L .38991 .80811 L p .707 .577 .707 r
F P
0 g
s
.17447 .78741 m .17777 .76956 L .16554 .75769 L p .707 .577 .707 r
F P
0 g
s
.67118 .79481 m .66788 .81267 L .64093 .80271 L p .707 .577 .707 r
F P
0 g
s
.16554 .75769 m .16224 .77554 L .17447 .78741 L p .707 .577 .707 r
F P
0 g
s
.16165 .62183 m .15631 .67656 L .15914 .68649 L p .707 .577 .707 r
F P
0 g
s
.35447 .73761 m .34733 .77315 L .35451 .76384 L p .707 .577 .707 r
F P
0 g
s
.35451 .76384 m .36165 .7283 L .35447 .73761 L p .707 .577 .707 r
F P
0 g
s
.15688 .73448 m .16402 .69893 L .16139 .68763 L p .707 .577 .707 r
F P
0 g
s
.36465 .64401 m .35931 .69874 L .35648 .68881 L p .707 .577 .707 r
F P
0 g
s
.35648 .68881 m .36182 .63408 L .36465 .64401 L p .707 .577 .707 r
F P
0 g
s
.63695 .2782 m .65574 .78173 L .65224 .77203 L p .707 .577 .707 r
F P
0 g
s
.65122 .75543 m .63695 .2782 L .65224 .77203 L .707 .577 .707 r
F
.63287 .26691 m .63695 .2782 L p .64711 .61793 L F P
0 g
s
.65097 .74711 m .64583 .614 L .64711 .61793 L .707 .577 .707 r
F
.65063 .74267 m .64583 .614 L p .65097 .74711 L F P
0 g
s
.63287 .26691 m .65167 .77044 L .63391 .7605 L p .707 .577 .707 r
F P
0 g
s
.64423 .64615 m .64354 .64962 L p .64926 .69388 L .707 .577 .707 r
F P
0 g
s
.64354 .64962 m .63709 .68169 L .64672 .69133 L p .707 .577 .707 r
F P
0 g
s
.64672 .69133 m .64926 .69388 L p .64354 .64962 L .707 .577 .707 r
F P
0 g
s
.65167 .77044 m .65063 .74267 L p .65097 .74711 L .707 .577 .707 r
F P
0 g
s
.64583 .614 m .63287 .26691 L p .64711 .61793 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64186 .56123 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.63935 .62589 m .64174 .60144 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .64469 .57116 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64174 .60144 L p .65184 .63593 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .63935 .62589 L .64344 .62918 L p .707 .577 .707 r
F P
0 g
s
.64344 .62918 m .65184 .63593 L p .64174 .60144 L .707 .577 .707 r
F P
0 g
s
.65224 .77203 m .65167 .77044 L p .65122 .75543 L .707 .577 .707 r
F P
0 g
s
.15631 .67656 m .16165 .62183 L .16875 .61299 L p .707 .577 .707 r
F P
0 g
s
.16139 .68763 m .15426 .72317 L .15688 .73448 L p .707 .577 .707 r
F P
0 g
s
.3565 .79374 m .3532 .81159 L .36036 .80235 L p .707 .577 .707 r
F P
0 g
s
.36036 .80235 m .36366 .78449 L .3565 .79374 L p .707 .577 .707 r
F P
0 g
s
.16224 .77554 m .16554 .75769 L .16288 .74659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16288 .74659 m .15958 .76444 L .16224 .77554 L p .707 .577 .707 r
F P
0 g
s
.36165 .7283 m .35451 .76384 L .35189 .75253 L p .707 .577 .707 r
F P
0 g
s
.35189 .75253 m .35903 .71699 L .36165 .7283 L p .707 .577 .707 r
F P
0 g
s
.16875 .61299 m .16342 .66772 L .15631 .67656 L p .707 .577 .707 r
F P
0 g
s
.15426 .72317 m .16139 .68763 L .16857 .67831 L p .707 .577 .707 r
F P
0 g
s
.34928 .28336 m .36808 .78689 L .37215 .79818 L p .707 .577 .707 r
F P
0 g
s
.36808 .78689 m .34928 .28336 L .35929 .27181 L p .707 .577 .707 r
F P
0 g
s
.36182 .63408 m .35648 .68881 L .344 .67877 L p .707 .577 .707 r
F P
0 g
s
.344 .67877 m .34933 .62404 L .36182 .63408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16342 .66772 m .16875 .61299 L .1851 .6061 L p .707 .577 .707 r
F P
0 g
s
.16857 .67831 m .16143 .71385 L .15426 .72317 L p .707 .577 .707 r
F P
0 g
s
.36366 .78449 m .36036 .80235 L .3577 .79124 L p .707 .577 .707 r
F P
0 g
s
.3577 .79124 m .361 .77339 L .36366 .78449 L p .707 .577 .707 r
F P
0 g
s
.15958 .76444 m .16288 .74659 L .17004 .73734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17004 .73734 m .16674 .75519 L .15958 .76444 L p .707 .577 .707 r
F P
0 g
s
.63391 .7605 m .61512 .25698 L .63287 .26691 L p .707 .577 .707 r
F P
0 g
s
.35903 .71699 m .35189 .75253 L .33972 .74034 L p .707 .577 .707 r
F P
0 g
s
.33972 .74034 m .34686 .7048 L .35903 .71699 L p .707 .577 .707 r
F P
0 g
s
.1851 .6061 m .17976 .66083 L .16342 .66772 L p .707 .577 .707 r
F P
0 g
s
.16143 .71385 m .16857 .67831 L .18485 .67189 L p .707 .577 .707 r
F P
0 g
s
.34933 .62404 m .344 .67877 L .32307 .6696 L p .707 .577 .707 r
F P
0 g
s
.32307 .6696 m .3284 .61487 L .34933 .62404 L p .707 .577 .707 r
F P
0 g
s
.17976 .66083 m .1851 .6061 L .20908 .60183 L p .707 .577 .707 r
F P
0 g
s
.18485 .67189 m .17771 .70744 L .16143 .71385 L p .707 .577 .707 r
F P
0 g
s
.361 .77339 m .3577 .79124 L .34547 .77937 L p .707 .577 .707 r
F P
0 g
s
.34547 .77937 m .34877 .76152 L .361 .77339 L p .707 .577 .707 r
F P
0 g
s
.37808 .77534 m .35929 .27181 L .38239 .26115 L p .707 .577 .707 r
F P
0 g
s
.35929 .27181 m .37808 .77534 L .36808 .78689 L p .707 .577 .707 r
F P
0 g
s
.16674 .75519 m .17004 .73734 L .18633 .73085 L p .707 .577 .707 r
F P
0 g
s
.18633 .73085 m .18303 .74871 L .16674 .75519 L p .707 .577 .707 r
F P
0 g
s
.3284 .61487 m .32307 .6696 L .29576 .6622 L p .707 .577 .707 r
F P
0 g
s
.29576 .6622 m .30109 .60746 L .3284 .61487 L p .707 .577 .707 r
F P
0 g
s
.34686 .7048 m .33972 .74034 L .3192 .72846 L p .707 .577 .707 r
F P
0 g
s
.3192 .72846 m .32634 .69292 L .34686 .7048 L p .707 .577 .707 r
F P
0 g
s
.20908 .60183 m .20375 .65657 L .17976 .66083 L p .707 .577 .707 r
F P
0 g
s
.17771 .70744 m .18485 .67189 L .20863 .66901 L p .707 .577 .707 r
F P
0 g
s
.20375 .65657 m .20908 .60183 L .23836 .60061 L p .707 .577 .707 r
F P
0 g
s
.61512 .25698 m .63391 .7605 L .60421 .7529 L p .707 .577 .707 r
F P
0 g
s
.60421 .7529 m .58542 .24937 L .61512 .25698 L p .707 .577 .707 r
F P
0 g
s
.30109 .60746 m .29576 .6622 L .26473 .65728 L p .707 .577 .707 r
F P
0 g
s
.26473 .65728 m .27007 .60255 L .30109 .60746 L p .707 .577 .707 r
F P
0 g
s
.20863 .66901 m .20149 .70455 L .17771 .70744 L p .707 .577 .707 r
F P
0 g
s
.34877 .76152 m .34547 .77937 L .32487 .7679 L p .707 .577 .707 r
F P
0 g
s
.32487 .7679 m .32817 .75004 L .34877 .76152 L p .707 .577 .707 r
F P
0 g
s
.23303 .65534 m .23836 .60061 L .27007 .60255 L p .707 .577 .707 r
F P
0 g
s
.23836 .60061 m .23303 .65534 L .20375 .65657 L p .707 .577 .707 r
F P
0 g
s
.18303 .74871 m .18633 .73085 L .21015 .72776 L p .707 .577 .707 r
F P
0 g
s
.27007 .60255 m .26473 .65728 L .23303 .65534 L p .707 .577 .707 r
F P
0 g
s
.32634 .69292 m .3192 .72846 L .29233 .71805 L p .707 .577 .707 r
F P
0 g
s
.29233 .71805 m .29947 .68251 L .32634 .69292 L p .707 .577 .707 r
F P
0 g
s
.73111 .65742 m .73644 .60269 L .70541 .59777 L p .707 .577 .707 r
F P
0 g
s
.73644 .60269 m .73111 .65742 L .76281 .65936 L p .707 .577 .707 r
F P
0 g
s
.76281 .65936 m .76814 .60463 L .73644 .60269 L p .707 .577 .707 r
F P
0 g
s
.20149 .70455 m .20863 .66901 L .23759 .66994 L p .707 .577 .707 r
F P
0 g
s
.21015 .72776 m .20685 .74562 L .18303 .74871 L p .707 .577 .707 r
F P
0 g
s
.76814 .60463 m .76281 .65936 L .79209 .65814 L p .707 .577 .707 r
F P
0 g
s
.79209 .65814 m .79742 .6034 L .76814 .60463 L p .707 .577 .707 r
F P
0 g
s
.38239 .26115 m .40119 .76468 L .37808 .77534 L p .707 .577 .707 r
F P
0 g
s
.40119 .76468 m .38239 .26115 L .41634 .2524 L p .707 .577 .707 r
F P
0 g
s
.70008 .65251 m .70541 .59777 L .6781 .59037 L p .707 .577 .707 r
F P
0 g
s
.70541 .59777 m .70008 .65251 L .73111 .65742 L p .707 .577 .707 r
F P
0 g
s
.23759 .66994 m .23045 .70548 L .20149 .70455 L p .707 .577 .707 r
F P
0 g
s
.29947 .68251 m .29233 .71805 L .26175 .71013 L p .707 .577 .707 r
F P
0 g
s
.26175 .71013 m .26889 .67459 L .29947 .68251 L p .707 .577 .707 r
F P
0 g
s
.23045 .70548 m .23759 .66994 L .26889 .67459 L p .707 .577 .707 r
F P
0 g
s
.32817 .75004 m .32487 .7679 L .29792 .75794 L p .707 .577 .707 r
F P
0 g
s
.29792 .75794 m .30122 .74008 L .32817 .75004 L p .707 .577 .707 r
F P
0 g
s
.20685 .74562 m .21015 .72776 L .23917 .72837 L p .707 .577 .707 r
F P
0 g
s
.79742 .6034 m .79209 .65814 L .81607 .65387 L p .707 .577 .707 r
F P
0 g
s
.81607 .65387 m .82141 .59914 L .79742 .6034 L p .707 .577 .707 r
F P
0 g
s
.26889 .67459 m .26175 .71013 L .23045 .70548 L p .707 .577 .707 r
F P
0 g
s
.58542 .24937 m .60421 .7529 L .56548 .74837 L p .707 .577 .707 r
F P
0 g
s
.56548 .74837 m .54669 .24484 L .58542 .24937 L p .707 .577 .707 r
F P
0 g
s
.67277 .6451 m .6781 .59037 L .65718 .5812 L p .707 .577 .707 r
F P
0 g
s
.6781 .59037 m .67277 .6451 L .70008 .65251 L p .707 .577 .707 r
F P
0 g
s
.23917 .72837 m .23587 .74622 L .20685 .74562 L p .707 .577 .707 r
F P
0 g
s
.72723 .72409 m .73437 .68855 L .70379 .68063 L p .707 .577 .707 r
F P
0 g
s
.73437 .68855 m .72723 .72409 L .75853 .72874 L p .707 .577 .707 r
F P
0 g
s
.75853 .72874 m .76567 .6932 L .73437 .68855 L p .707 .577 .707 r
F P
0 g
s
.30122 .74008 m .29792 .75794 L .26725 .75047 L p .707 .577 .707 r
F P
0 g
s
.26725 .75047 m .27055 .73262 L .30122 .74008 L p .707 .577 .707 r
F P
0 g
s
.76567 .6932 m .75853 .72874 L .78749 .72967 L p .707 .577 .707 r
F P
0 g
s
.78749 .72967 m .79463 .69413 L .76567 .6932 L p .707 .577 .707 r
F P
0 g
s
.23587 .74622 m .23917 .72837 L .27055 .73262 L p .707 .577 .707 r
F P
0 g
s
.69665 .71617 m .70379 .68063 L .67692 .67022 L p .707 .577 .707 r
F P
0 g
s
.70379 .68063 m .69665 .71617 L .72723 .72409 L p .707 .577 .707 r
F P
0 g
s
.43513 .75593 m .41634 .2524 L .4578 .24644 L p .707 .577 .707 r
F P
0 g
s
.41634 .2524 m .43513 .75593 L .40119 .76468 L p .707 .577 .707 r
F P
0 g
s
.27055 .73262 m .26725 .75047 L .23587 .74622 L p .707 .577 .707 r
F P
0 g
s
.82141 .59914 m .81607 .65387 L .83242 .64698 L p .707 .577 .707 r
F P
0 g
s
.83242 .64698 m .83775 .59225 L .82141 .59914 L p .707 .577 .707 r
F P
0 g
s
.65718 .5812 m .65184 .63593 L .67277 .6451 L p .707 .577 .707 r
F P
0 g
s
.7329 .76905 m .7362 .7512 L .70554 .74373 L p .707 .577 .707 r
F P
0 g
s
.7362 .7512 m .7329 .76905 L .76428 .77329 L p .707 .577 .707 r
F P
0 g
s
.76428 .77329 m .76758 .75544 L .7362 .7512 L p .707 .577 .707 r
F P
0 g
s
.54669 .24484 m .56548 .74837 L .5215 .74736 L p .707 .577 .707 r
F P
0 g
s
.5215 .74736 m .50271 .24383 L .54669 .24484 L p .707 .577 .707 r
F P
0 g
s
.67692 .67022 m .66978 .70576 L .69665 .71617 L p .707 .577 .707 r
F P
0 g
s
.79463 .69413 m .78749 .72967 L .81127 .72679 L p .707 .577 .707 r
F P
0 g
s
.81127 .72679 m .81841 .69124 L .79463 .69413 L p .707 .577 .707 r
F P
0 g
s
.65184 .63593 m .65718 .5812 L .64469 .57116 L p .707 .577 .707 r
F P
0 g
s
.66978 .70576 m .67692 .67022 L .6564 .65834 L p .707 .577 .707 r
F P
0 g
s
.76758 .75544 m .76428 .77329 L .7933 .7739 L p .707 .577 .707 r
F P
0 g
s
.7933 .7739 m .79661 .75605 L .76758 .75544 L p .707 .577 .707 r
F P
0 g
s
.70224 .76158 m .70554 .74373 L .67858 .73377 L p .707 .577 .707 r
F P
0 g
s
.70554 .74373 m .70224 .76158 L .7329 .76905 L p .707 .577 .707 r
F P
0 g
s
.47659 .74996 m .4578 .24644 L .50271 .24383 L p .707 .577 .707 r
F P
0 g
s
.4578 .24644 m .47659 .74996 L .43513 .75593 L p .707 .577 .707 r
F P
0 g
s
.50271 .24383 m .5215 .74736 L .47659 .74996 L p .707 .577 .707 r
F P
0 g
s
.67858 .73377 m .67528 .75162 L .70224 .76158 L p .707 .577 .707 r
F P
0 g
s
.6564 .65834 m .64926 .69388 L .66978 .70576 L p .707 .577 .707 r
F P
0 g
s
.79661 .75605 m .7933 .7739 L .81713 .77081 L p .707 .577 .707 r
F P
0 g
s
.81713 .77081 m .82043 .75296 L .79661 .75605 L p .707 .577 .707 r
F P
0 g
s
.67528 .75162 m .67858 .73377 L .65798 .72229 L p .707 .577 .707 r
F P
0 g
s
.83775 .59225 m .83242 .64698 L .83953 .63814 L p .707 .577 .707 r
F P
0 g
s
.83953 .63814 m .84486 .58341 L .83775 .59225 L p .707 .577 .707 r
F P
0 g
s
.81841 .69124 m .81127 .72679 L .82755 .72037 L p .707 .577 .707 r
F P
0 g
s
.82755 .72037 m .83469 .68483 L .81841 .69124 L p .707 .577 .707 r
F P
0 g
s
.64926 .69388 m .6564 .65834 L .64423 .64615 L p .707 .577 .707 r
F P
0 g
s
.65798 .72229 m .65468 .74014 L .67528 .75162 L p .707 .577 .707 r
F P
0 g
s
.82043 .75296 m .81713 .77081 L .83341 .76432 L p .707 .577 .707 r
F P
0 g
s
.83341 .76432 m .83672 .74647 L .82043 .75296 L p .707 .577 .707 r
F P
0 g
s
.65468 .74014 m .65798 .72229 L .64575 .71042 L p .707 .577 .707 r
F P
0 g
s
.64186 .56123 m .63653 .61596 L .63935 .62589 L p .707 .577 .707 r
F P
0 g
s
.64575 .71042 m .64245 .72827 L .65468 .74014 L p .707 .577 .707 r
F P
0 g
s
.83469 .68483 m .82755 .72037 L .83473 .71105 L p .707 .577 .707 r
F P
0 g
s
.83473 .71105 m .84186 .67551 L .83469 .68483 L p .707 .577 .707 r
F P
0 g
s
.63709 .68169 m .64423 .64615 L .64161 .63484 L p .707 .577 .707 r
F P
0 g
s
.84486 .58341 m .83953 .63814 L .8367 .62821 L p .707 .577 .707 r
F P
0 g
s
.8367 .62821 m .84203 .57348 L .84486 .58341 L p .707 .577 .707 r
F P
0 g
s
.63653 .61596 m .64186 .56123 L .64896 .55239 L p .707 .577 .707 r
F P
0 g
s
.64161 .63484 m .63447 .67038 L .63709 .68169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83672 .74647 m .83341 .76432 L .84058 .75508 L p .707 .577 .707 r
F P
0 g
s
.84058 .75508 m .84388 .73722 L .83672 .74647 L p .707 .577 .707 r
F P
0 g
s
.64245 .72827 m .64575 .71042 L .64309 .69932 L p .707 .577 .707 r
F P
0 g
s
.64309 .69932 m .63979 .71717 L .64245 .72827 L p .707 .577 .707 r
F P
0 g
s
.64896 .55239 m .64363 .60712 L .63653 .61596 L p .707 .577 .707 r
F P
0 g
s
.84186 .67551 m .83473 .71105 L .8321 .69975 L p .707 .577 .707 r
F P
0 g
s
.8321 .69975 m .83924 .6642 L .84186 .67551 L p .707 .577 .707 r
F P
0 g
s
.63447 .67038 m .64161 .63484 L .64878 .62553 L p .707 .577 .707 r
F P
0 g
s
.84203 .57348 m .8367 .62821 L .82421 .61817 L p .707 .577 .707 r
F P
0 g
s
.82421 .61817 m .82954 .56344 L .84203 .57348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64363 .60712 m .64896 .55239 L .66531 .5455 L p .707 .577 .707 r
F P
0 g
s
.3881 .62598 m .39343 .57125 L .3624 .56634 L p .707 .577 .707 r
F P
0 g
s
.39343 .57125 m .3881 .62598 L .4198 .62792 L p .707 .577 .707 r
F P
0 g
s
.4198 .62792 m .42513 .57319 L .39343 .57125 L p .707 .577 .707 r
F P
0 g
s
.64878 .62553 m .64165 .66107 L .63447 .67038 L p .707 .577 .707 r
F P
0 g
s
.84388 .73722 m .84058 .75508 L .83791 .74398 L p .707 .577 .707 r
F P
0 g
s
.83791 .74398 m .84121 .72612 L .84388 .73722 L p .707 .577 .707 r
F P
0 g
s
.42513 .57319 m .4198 .62792 L .44908 .6267 L p .707 .577 .707 r
F P
0 g
s
.44908 .6267 m .45441 .57197 L .42513 .57319 L p .707 .577 .707 r
F P
0 g
s
.63979 .71717 m .64309 .69932 L .65025 .69007 L p .707 .577 .707 r
F P
0 g
s
.35707 .62107 m .3624 .56634 L .33509 .55893 L p .707 .577 .707 r
F P
0 g
s
.3624 .56634 m .35707 .62107 L .3881 .62598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65025 .69007 m .64695 .70793 L .63979 .71717 L p .707 .577 .707 r
F P
0 g
s
.66531 .5455 m .65998 .60023 L .64363 .60712 L p .707 .577 .707 r
F P
0 g
s
.45441 .57197 m .44908 .6267 L .47306 .62244 L p .707 .577 .707 r
F P
0 g
s
.47306 .62244 m .4784 .5677 L .45441 .57197 L p .707 .577 .707 r
F P
0 g
s
.83924 .6642 m .8321 .69975 L .81993 .68755 L p .707 .577 .707 r
F P
0 g
s
.81993 .68755 m .82707 .65201 L .83924 .6642 L p .707 .577 .707 r
F P
0 g
s
.64165 .66107 m .64878 .62553 L .66506 .61911 L p .707 .577 .707 r
F P
0 g
s
.82954 .56344 m .82421 .61817 L .80329 .609 L p .707 .577 .707 r
F P
0 g
s
.80329 .609 m .80862 .55427 L .82954 .56344 L p .707 .577 .707 r
F P
0 g
s
.32976 .61366 m .33509 .55893 L .31417 .54976 L p .707 .577 .707 r
F P
0 g
s
.33509 .55893 m .32976 .61366 L .35707 .62107 L p .707 .577 .707 r
F P
0 g
s
.38422 .68484 m .39136 .6493 L .36078 .64138 L p .707 .577 .707 r
F P
0 g
s
.39136 .6493 m .38422 .68484 L .41552 .68949 L p .707 .577 .707 r
F P
0 g
s
.41552 .68949 m .42266 .65395 L .39136 .6493 L p .707 .577 .707 r
F P
0 g
s
.65998 .60023 m .66531 .5455 L .6893 .54123 L p .707 .577 .707 r
F P
0 g
s
.42266 .65395 m .41552 .68949 L .44448 .69042 L p .707 .577 .707 r
F P
0 g
s
.44448 .69042 m .45162 .65487 L .42266 .65395 L p .707 .577 .707 r
F P
0 g
s
.35364 .67692 m .36078 .64138 L .33391 .63097 L p .707 .577 .707 r
F P
0 g
s
.36078 .64138 m .35364 .67692 L .38422 .68484 L p .707 .577 .707 r
F P
0 g
s
.66506 .61911 m .65792 .65465 L .64165 .66107 L p .707 .577 .707 r
F P
0 g
s
.84121 .72612 m .83791 .74398 L .82568 .73211 L p .707 .577 .707 r
F P
0 g
s
.82568 .73211 m .82898 .71425 L .84121 .72612 L p .707 .577 .707 r
F P
0 g
s
.64695 .70793 m .65025 .69007 L .66654 .68359 L p .707 .577 .707 r
F P
0 g
s
.4784 .5677 m .47306 .62244 L .48941 .61554 L p .707 .577 .707 r
F P
0 g
s
.48941 .61554 m .49474 .56081 L .4784 .5677 L p .707 .577 .707 r
F P
0 g
s
.38989 .72428 m .39319 .70642 L .36253 .69896 L p .707 .577 .707 r
F P
0 g
s
.39319 .70642 m .38989 .72428 L .42127 .72852 L p .707 .577 .707 r
F P
0 g
s
.42127 .72852 m .42457 .71067 L .39319 .70642 L p .707 .577 .707 r
F P
0 g
s
.31417 .54976 m .30883 .60449 L .32976 .61366 L p .707 .577 .707 r
F P
0 g
s
.80862 .55427 m .80329 .609 L .77597 .6016 L p .707 .577 .707 r
F P
0 g
s
.77597 .6016 m .78131 .54686 L .80862 .55427 L p .707 .577 .707 r
F P
0 g
s
.33391 .63097 m .32677 .66651 L .35364 .67692 L p .707 .577 .707 r
F P
0 g
s
.45162 .65487 m .44448 .69042 L .46826 .68753 L p .707 .577 .707 r
F P
0 g
s
.46826 .68753 m .4754 .65199 L .45162 .65487 L p .707 .577 .707 r
F P
0 g
s
.6893 .54123 m .68396 .59597 L .65998 .60023 L p .707 .577 .707 r
F P
0 g
s
.32677 .66651 m .33391 .63097 L .31339 .61909 L p .707 .577 .707 r
F P
0 g
s
.66654 .68359 m .66324 .70144 L .64695 .70793 L p .707 .577 .707 r
F P
0 g
s
.42457 .71067 m .42127 .72852 L .45029 .72913 L p .707 .577 .707 r
F P
0 g
s
.45029 .72913 m .4536 .71128 L .42457 .71067 L p .707 .577 .707 r
F P
0 g
s
.35923 .71681 m .36253 .69896 L .33557 .689 L p .707 .577 .707 r
F P
0 g
s
.36253 .69896 m .35923 .71681 L .38989 .72428 L p .707 .577 .707 r
F P
0 g
s
.30883 .60449 m .31417 .54976 L .30168 .53972 L p .707 .577 .707 r
F P
0 g
s
.82707 .65201 m .81993 .68755 L .79941 .67567 L p .707 .577 .707 r
F P
0 g
s
.79941 .67567 m .80655 .64013 L .82707 .65201 L p .707 .577 .707 r
F P
0 g
s
.65792 .65465 m .66506 .61911 L .68884 .61623 L p .707 .577 .707 r
F P
0 g
s
.68396 .59597 m .6893 .54123 L .71858 .54001 L p .707 .577 .707 r
F P
0 g
s
.33557 .689 m .33227 .70685 L .35923 .71681 L p .707 .577 .707 r
F P
0 g
s
.31339 .61909 m .30625 .65463 L .32677 .66651 L p .707 .577 .707 r
F P
0 g
s
.78131 .54686 m .77597 .6016 L .74495 .59668 L p .707 .577 .707 r
F P
0 g
s
.74495 .59668 m .75028 .54195 L .78131 .54686 L p .707 .577 .707 r
F P
0 g
s
.4536 .71128 m .45029 .72913 L .47412 .72604 L p .707 .577 .707 r
F P
0 g
s
.47412 .72604 m .47742 .70819 L .4536 .71128 L p .707 .577 .707 r
F P
0 g
s
.33227 .70685 m .33557 .689 L .31497 .67752 L p .707 .577 .707 r
F P
0 g
s
.71324 .59474 m .71858 .54001 L .75028 .54195 L p .707 .577 .707 r
F P
0 g
s
.71858 .54001 m .71324 .59474 L .68396 .59597 L p .707 .577 .707 r
F P
0 g
s
.68884 .61623 m .6817 .65177 L .65792 .65465 L p .707 .577 .707 r
F P
0 g
s
.82898 .71425 m .82568 .73211 L .80508 .72063 L p .707 .577 .707 r
F P
0 g
s
.80508 .72063 m .80838 .70278 L .82898 .71425 L p .707 .577 .707 r
F P
0 g
s
.30168 .53972 m .29634 .59445 L .30883 .60449 L p .707 .577 .707 r
F P
0 g
s
.75028 .54195 m .74495 .59668 L .71324 .59474 L p .707 .577 .707 r
F P
0 g
s
.4754 .65199 m .46826 .68753 L .48454 .68112 L p .707 .577 .707 r
F P
0 g
s
.48454 .68112 m .49168 .64558 L .4754 .65199 L p .707 .577 .707 r
F P
0 g
s
.66324 .70144 m .66654 .68359 L .69036 .6805 L p .707 .577 .707 r
F P
0 g
s
.30625 .65463 m .31339 .61909 L .30122 .6069 L p .707 .577 .707 r
F P
0 g
s
.31497 .67752 m .31167 .69537 L .33227 .70685 L p .707 .577 .707 r
F P
0 g
s
.49474 .56081 m .48941 .61554 L .49652 .6067 L p .707 .577 .707 r
F P
0 g
s
.49652 .6067 m .50185 .55197 L .49474 .56081 L p .707 .577 .707 r
F P
0 g
s
.80655 .64013 m .79941 .67567 L .77254 .66526 L p .707 .577 .707 r
F P
0 g
s
.77254 .66526 m .77968 .62972 L .80655 .64013 L p .707 .577 .707 r
F P
0 g
s
.6817 .65177 m .68884 .61623 L .7178 .61716 L p .707 .577 .707 r
F P
0 g
s
.69036 .6805 m .68706 .69835 L .66324 .70144 L p .707 .577 .707 r
F P
0 g
s
.29634 .59445 m .30168 .53972 L .29885 .52979 L p .707 .577 .707 r
F P
0 g
s
.30122 .6069 m .29408 .64244 L .30625 .65463 L p .707 .577 .707 r
F P
0 g
s
.47742 .70819 m .47412 .72604 L .4904 .71955 L p .707 .577 .707 r
F P
0 g
s
.4904 .71955 m .49371 .7017 L .47742 .70819 L p .707 .577 .707 r
F P
0 g
s
.31167 .69537 m .31497 .67752 L .30274 .66565 L p .707 .577 .707 r
F P
0 g
s
.7178 .61716 m .71066 .6527 L .6817 .65177 L p .707 .577 .707 r
F P
0 g
s
.77968 .62972 m .77254 .66526 L .74196 .65735 L p .707 .577 .707 r
F P
0 g
s
.74196 .65735 m .7491 .62181 L .77968 .62972 L p .707 .577 .707 r
F P
0 g
s
.71066 .6527 m .7178 .61716 L .7491 .62181 L p .707 .577 .707 r
F P
0 g
s
.80838 .70278 m .80508 .72063 L .77813 .71067 L p .707 .577 .707 r
F P
0 g
s
.77813 .71067 m .78143 .69282 L .80838 .70278 L p .707 .577 .707 r
F P
0 g
s
.68706 .69835 m .69036 .6805 L .71938 .6811 L p .707 .577 .707 r
F P
0 g
s
.7491 .62181 m .74196 .65735 L .71066 .6527 L p .707 .577 .707 r
F P
0 g
s
.30274 .66565 m .29944 .6835 L .31167 .69537 L p .707 .577 .707 r
F P
0 g
s
.29885 .52979 m .29351 .58453 L .29634 .59445 L p .707 .577 .707 r
F P
0 g
s
.49168 .64558 m .48454 .68112 L .49171 .6718 L p .707 .577 .707 r
F P
0 g
s
.49171 .6718 m .49885 .63626 L .49168 .64558 L p .707 .577 .707 r
F P
0 g
s
.71938 .6811 m .71608 .69896 L .68706 .69835 L p .707 .577 .707 r
F P
0 g
s
.29408 .64244 m .30122 .6069 L .2986 .59559 L p .707 .577 .707 r
F P
0 g
s
.50185 .55197 m .49652 .6067 L .49369 .59678 L p .707 .577 .707 r
F P
0 g
s
.49369 .59678 m .49902 .54204 L .50185 .55197 L p .707 .577 .707 r
F P
0 g
s
.78143 .69282 m .77813 .71067 L .74746 .7032 L p .707 .577 .707 r
F P
0 g
s
.74746 .7032 m .75076 .68535 L .78143 .69282 L p .707 .577 .707 r
F P
0 g
s
.71608 .69896 m .71938 .6811 L .75076 .68535 L p .707 .577 .707 r
F P
0 g
s
.75076 .68535 m .74746 .7032 L .71608 .69896 L p .707 .577 .707 r
F P
0 g
s
.29351 .58453 m .29885 .52979 L .30595 .52095 L p .707 .577 .707 r
F P
0 g
s
.2986 .59559 m .29146 .63113 L .29408 .64244 L p .707 .577 .707 r
F P
0 g
s
.49371 .7017 m .4904 .71955 L .49757 .71031 L p .707 .577 .707 r
F P
0 g
s
.49757 .71031 m .50087 .69245 L .49371 .7017 L p .707 .577 .707 r
F P
0 g
s
.29944 .6835 m .30274 .66565 L .30008 .65455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30008 .65455 m .29678 .6724 L .29944 .6835 L p .707 .577 .707 r
F P
0 g
s
.49885 .63626 m .49171 .6718 L .48909 .66049 L p .707 .577 .707 r
F P
0 g
s
.48909 .66049 m .49623 .62495 L .49885 .63626 L p .707 .577 .707 r
F P
0 g
s
.30595 .52095 m .30062 .57568 L .29351 .58453 L p .707 .577 .707 r
F P
0 g
s
.29146 .63113 m .2986 .59559 L .30577 .58627 L p .707 .577 .707 r
F P
0 g
s
.49902 .54204 m .49369 .59678 L .4812 .58674 L p .707 .577 .707 r
F P
0 g
s
.4812 .58674 m .48653 .532 L .49902 .54204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30062 .57568 m .30595 .52095 L .3223 .51406 L p .707 .577 .707 r
F P
0 g
s
.30577 .58627 m .29864 .62181 L .29146 .63113 L p .707 .577 .707 r
F P
0 g
s
.50087 .69245 m .49757 .71031 L .4949 .69921 L p .707 .577 .707 r
F P
0 g
s
.4949 .69921 m .4982 .68135 L .50087 .69245 L p .707 .577 .707 r
F P
0 g
s
.29678 .6724 m .30008 .65455 L .30724 .6453 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30724 .6453 m .30394 .66316 L .29678 .6724 L p .707 .577 .707 r
F P
0 g
s
.49623 .62495 m .48909 .66049 L .47692 .6483 L p .707 .577 .707 r
F P
0 g
s
.47692 .6483 m .48406 .61276 L .49623 .62495 L p .707 .577 .707 r
F P
0 g
s
.3223 .51406 m .31697 .56879 L .30062 .57568 L p .707 .577 .707 r
F P
0 g
s
.29864 .62181 m .30577 .58627 L .32205 .57986 L p .707 .577 .707 r
F P
0 g
s
.48653 .532 m .4812 .58674 L .46027 .57756 L p .707 .577 .707 r
F P
0 g
s
.46027 .57756 m .46561 .52283 L .48653 .532 L p .707 .577 .707 r
F P
0 g
s
.31697 .56879 m .3223 .51406 L .34629 .50979 L p .707 .577 .707 r
F P
0 g
s
.32205 .57986 m .31491 .6154 L .29864 .62181 L p .707 .577 .707 r
F P
0 g
s
.4982 .68135 m .4949 .69921 L .48267 .68734 L p .707 .577 .707 r
F P
0 g
s
.48267 .68734 m .48597 .66948 L .4982 .68135 L p .707 .577 .707 r
F P
0 g
s
.30394 .66316 m .30724 .6453 L .32353 .63882 L p .707 .577 .707 r
F P
0 g
s
.32353 .63882 m .32023 .65667 L .30394 .66316 L p .707 .577 .707 r
F P
0 g
s
.46561 .52283 m .46027 .57756 L .43296 .57016 L p .707 .577 .707 r
F P
0 g
s
.43296 .57016 m .4383 .51543 L .46561 .52283 L p .707 .577 .707 r
F P
0 g
s
.48406 .61276 m .47692 .6483 L .4564 .63642 L p .707 .577 .707 r
F P
0 g
s
.4564 .63642 m .46354 .60088 L .48406 .61276 L p .707 .577 .707 r
F P
0 g
s
.34629 .50979 m .34095 .56453 L .31697 .56879 L p .707 .577 .707 r
F P
0 g
s
.31491 .6154 m .32205 .57986 L .34583 .57697 L p .707 .577 .707 r
F P
0 g
s
.34095 .56453 m .34629 .50979 L .37556 .50857 L p .707 .577 .707 r
F P
0 g
s
.4383 .51543 m .43296 .57016 L .40194 .56525 L p .707 .577 .707 r
F P
0 g
s
.40194 .56525 m .40727 .51051 L .4383 .51543 L p .707 .577 .707 r
F P
0 g
s
.34583 .57697 m .33869 .61251 L .31491 .6154 L p .707 .577 .707 r
F P
0 g
s
.48597 .66948 m .48267 .68734 L .46207 .67586 L p .707 .577 .707 r
F P
0 g
s
.46207 .67586 m .46537 .65801 L .48597 .66948 L p .707 .577 .707 r
F P
0 g
s
.37023 .56331 m .37556 .50857 L .40727 .51051 L p .707 .577 .707 r
F P
0 g
s
.37556 .50857 m .37023 .56331 L .34095 .56453 L p .707 .577 .707 r
F P
0 g
s
.32023 .65667 m .32353 .63882 L .34735 .63572 L p .707 .577 .707 r
F P
0 g
s
.40727 .51051 m .40194 .56525 L .37023 .56331 L p .707 .577 .707 r
F P
0 g
s
.46354 .60088 m .4564 .63642 L .42953 .62601 L p .707 .577 .707 r
F P
0 g
s
.42953 .62601 m .43667 .59047 L .46354 .60088 L p .707 .577 .707 r
F P
0 g
s
.33869 .61251 m .34583 .57697 L .37479 .5779 L p .707 .577 .707 r
F P
0 g
s
.34735 .63572 m .34405 .65358 L .32023 .65667 L p .707 .577 .707 r
F P
0 g
s
.37479 .5779 m .36765 .61344 L .33869 .61251 L p .707 .577 .707 r
F P
0 g
s
.43667 .59047 m .42953 .62601 L .39895 .61809 L p .707 .577 .707 r
F P
0 g
s
.39895 .61809 m .40609 .58255 L .43667 .59047 L p .707 .577 .707 r
F P
0 g
s
.36765 .61344 m .37479 .5779 L .40609 .58255 L p .707 .577 .707 r
F P
0 g
s
.46537 .65801 m .46207 .67586 L .43512 .6659 L p .707 .577 .707 r
F P
0 g
s
.43512 .6659 m .43842 .64805 L .46537 .65801 L p .707 .577 .707 r
F P
0 g
s
.34405 .65358 m .34735 .63572 L .37637 .63633 L p .707 .577 .707 r
F P
0 g
s
.40609 .58255 m .39895 .61809 L .36765 .61344 L p .707 .577 .707 r
F P
0 g
s
.37637 .63633 m .37307 .65419 L .34405 .65358 L p .707 .577 .707 r
F P
0 g
s
.43842 .64805 m .43512 .6659 L .40445 .65843 L p .707 .577 .707 r
F P
0 g
s
.40445 .65843 m .40775 .64058 L .43842 .64805 L p .707 .577 .707 r
F P
0 g
s
.37307 .65419 m .37637 .63633 L .40775 .64058 L p .707 .577 .707 r
F P
0 g
s
.40775 .64058 m .40445 .65843 L .37307 .65419 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo6000O7oo001mOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Eoo`P000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001cOol0079oo`<00003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001`
Ool006ioo`@000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP<006eoo`00K7oo0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006]oo`00JWoo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Uoo`00J7oo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFJGoo001VOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol006Eoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001oogoo06Ioo`00I7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0IGoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`03
001JEP0000P000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo20000eYF00<005YFFUH00UYF2@0000=J
EP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001JOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Qoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001EOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol005Aoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Uoo`l004aoo`00E7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEPT004=oo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH003eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
000iOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH3000eOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF008003=oo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03
001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00Dgoo00<0
05YF00000eYF1@0000=JEP00FUH01EYF1@000eYF1@000UYF10000UYF00<005YFFUH015YF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000`Ool005=oo`04001JEP00FUH20005FUH00`00FUIJ
EP06FUH01000FUIJEUYF2@001EYF10001EYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0002FUH=00000eYF001JEP04FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00Dgoo0P000eYF00<005YF00005@0025YF00<005YFFUH01UYF0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002eoo`00Dgoo0P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000UYF00<005YFFUH01UYF00<005YFFUH00`0000=JEP00FUH00UYF0P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;7oo001COol200000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20003FUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2000/Ool005=oo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP8000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00H0
05YFFUH005YF000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000/Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH]Ool0041oo`P000aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEUYF
009JEP<000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF008000=J
EPD00003FUH005YF00EJEPH000=oo`D00003Ool000000080009JEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Qoo`P000=JEP03001JEUYF009JEPT000=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJ
EP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH0
05YF0`001EYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUH000AJEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH50005FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0P00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000UYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJEP03001J
EUYF00EJEP@000AJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP`0009JEP03001JEUYF00EJEPH000QJEP03001JEUYF00AJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEP0000l000QJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000UYF00D005YFFUIJEP00009JEP800003Ool0000000<000IJEP03001JEUYF009JEP<000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000050002FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004
FUH300000eYF001JEP03FUH20002Ool00`00FUH000030002FUH00`00FUIJEP05FUH300000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000`0025YF00<005YFFUH00eYF00@005YFFUIJEP<002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
0`0015YF00<005YFFUH00P001EYF0P0000=oo`00FUH00UYF00<005YF00003`001EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002ioo`00;Goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH00eYF0P000eYF00@005YF000000=JEP04001JEUYFFUH50007FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF00=JEPl00003FUH0000000<000MJEP03001JEUYF00=JEP8000IJEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
00000P001UYF00L005YFFUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00@000=J
EP03001JEUYF00EJEP03001JEUYF00H000MJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00L0
05YFFUIJEP00FUH0000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00AJEP03001JEUYF00MJEP04001JEUYF0004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03FUH2000_Ool002eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000YJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004
FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@000QJEP8000AJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003
FUH01000FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEPD0009J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH01000
FUIJEUYF3`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo000/Ool0
0`00FUH00004FUH01000FUIJEUYF5`001UYF0`000eYF1@001UYF2@0015YF00<005YFFUH01eYF00@0
05YFFUIJEP@000=JEP03001JEP0000<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEP000002FUH60004FUH20006Ool90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000`Ool002aoo`03001JEP0000=JEPD00003FUH005YF00AJEPH000=oo`D0009oo`@0009JEP<00003
FUH00000009JEP03001JEUYF00IJEP03001JEUYF00IJEPL000IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
0003FUH005YF009JEP03001JEUYF00=JEP8000ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP0002moo`00;7oo00@005YF001JEP8000IJEP03001JEUYF00EJEP04001JEUYFFUH90005
Ool60002FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH30003
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH40003FUH300000eYF001J
EP04FUH01000FUH000003goo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00;7oo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH=000015YF
000000001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH00P00
00=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF10000eYF00<005YF
FUH00P001EYF00D005YFFUIJEP0000Qoo`<000Ioo`<000MJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool002aoo`8000=JEP03001JEUYF00=JEQ8000QJEP03001JEUYF00@0009JEP80009JEP8000AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP<000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800005FUH005YFFUH00005FUH30002
FUH01@00FUIJEUYF00001goo1@0027oo0P0015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00/005YFFUH005YF001J
EP00FUH005YF0080009JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00EJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEP00008000=JEP8000Ioo`D000Yoo`<00003FUH005YF00EJEP06001JEUYF
001JEP00;Goo000/Ool2000015YF000000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH010001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P001UYF00<005YF00001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEP<0
0003FUH0000000Ioo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool40004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP02FUH30004
FUH20003FUH60002FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF0000
0eYF00<005YFFUH00eYF00<005YF00004P0047oo0P000eYF00L005YFFUIJEP00FUH0000]Ool002eo
o`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP03001JEUYF0080009JEP05001JEP00001JEP030002FUH90003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH300000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH00UYF
1P003goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH30003FUH40002FUH0
1000FUIJEUYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEPD00003FUH0000000=JEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P003Woo0P000eYF0P00;Woo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000
FUH000001UYF00D005YF000005YF00@0009JEP04001JEUYFFUH500000eYF0000000<0004FUH02@00
FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF
0`0027oo1P0000AJEP00FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH50002FUH00`00FUIJ
EP02FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00P0000=JEP00Ool0;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH0
0`00FUH000030004FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00QJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00YJEP04001JEUYFFUH30005FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH50007FUH00`00
FUIJEP05FUH70008FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUH0000^Ool002aoo`80
00AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP03
FUH50009FUH00`00FUIJEP09FUH01@00FUH00000FUH00P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0000EJEP00000005YF00<000MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000AJEP03001JEUYF00EJEP<000AJEP8002moo`00;7oo0P000UYF1P000Woo1000
0UYF00<005YFFUH01EYF1P0025YF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH01UYF
00<005YFFUH010001EYF00<005YFFUH01UYF1@000eYF0P001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP<00003FUH005YF00=JEP8000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP@00003FUH005YF00IJEP04001JEUYF0003FUH2000_Ool002aoo`04FUH000000002
FUH00`00Oomoo`07Ool50006FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH>0003FUH01000FUIJEUYF0P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000100000=JEP00FUH015YF100000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000EJEP03001JEUYF009JEP<00003FUH007oo
02ioo`00:goo0`0015YF0`0037oo10000UYF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00<005YF
FUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH3
00000eYF001JEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH00`0015YF00<005YFFUH015YF1000
00=JEP00FUH01EYF0P00<7oo000[Ool30004FUH00`00FUIJEP02000>Ool@0006FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00
FUH30005FUH00`00FUIJEP02FUH60002FUH00`00FUH000040003FUH00`00FUIJEP05FUH00`00FUIJ
EP020006FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEP8000moo`<000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEP0000@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004Ool90002FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20004FUH01000FUH00000;Woo000[Ool00`00FUIJEP03FUH00`00FUIJEP03FUH90007Ool5
000;Ool200000eYF001JEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF10000UYF00<005YF
FUH01EYF00@005YFFUIJEPD000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000AJEP<000=JEP07001JEUYFFUH005YF000027oo1@000UYF00<005YFFUH01EYF00@005YF
FUIJEPD0009JEP03001JEUYF009JEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF00<005YFFUH0
10000eYF00<005YFFUH00UYF30003Goo0P001UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03
001JEUYF00h000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP0000AJEP03001JEUYF00800003FUH005YF009JEP03001JEP0000Uoo`<00003Ool00000
00`000Eoo`<000AJEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00@005YFFUIJEPL000aoo`8000=JEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP03FUH20003FUH2000SOol00`00FUIJEP02FUH00`00Oomo
o`0[Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00@000Yoo`800003FUH005YF00=JEP800005OomJEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`001EYF00D005YF000005YF008002Aoo`03001JEUYF008002eoo`00;Woo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100027oo0P00
15YF00<007ooOol00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@0
05YFFUIJEP<002Eoo`@002eoo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000Aoo`D0009JEP80009oo`=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH4000SOol2000]Ool002ioo`8000=J
EQ@000AJEP03001JEUYF00MJEP04001JEUYFFUH40003FUH00`00FUH000030002Ool3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`000UYF0`0025YF00<005YFFUH010007Woo0P00;Woo000^Ool200000eYF00000002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03
0002Ool3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<000<FUH00`00FUIJEP06
FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00@005YF000000MJEP03001JEUYF00AJ
EPL001Eoo`@002ioo`00;Woo0`000Woo0`0025YF00<005YFFUH01UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF0`000eYF0`000Woo0eYF00<005YFFUH015YF00<005YFFUH01EYF20002eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001UYF00L005YFFUIJEP00FUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH01eYF00<005YFFUH00UYF5@000UYF0P00;Woo000]Ool30005Ool2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP0200000eYF
00000003Ool3FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00=JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008002moo`00;Goo10001Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH00eYF0`000goo0eYF00<005YFFUH015YF00<005YF00000P002UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00001UYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;goo000]Ool01@00FUH005YF00001goo0`0000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH01EYF0P000goo0eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YF00001UYF00@005YFFUIJEP800003Ool000000080009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002eoo`80
00=JEP03001oogoo00Moo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000IJ
EP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000000001UYF
00H005YFFUH005YF0005Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo
000^Ool01000FUIJEUYF0`002goo10000UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00H005YFFUIJEP00Ool3FUH01000FUH000001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
0000009oo`8000=JEP07001JEUYFFUH005YF000037oo200015YF00@005YFFUIJEPD003=oo`00;Woo
00D005YFFUIJEP00009JEP03001oogoo00aoo`P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH005YF009JEP03001ooeYF009JEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0004Ool200000eYF001JEP02FUH00`00FUH0000DOol8000hOol002moo`03001JEP0000AJEP8000mo
o`H0009JEP03001JEUYF00EJEP04001JEUYFFUH500000goo00000003FUH01@00OomJEUYF00000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Ioo`8000=JEP8005Eoo`00<7oo0P001UYF
0P003Goo1@0000=oo`000000300027oo00L005YF001JEP00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP000goo1P000UYF0P00EGoo000aOol00`00FUIJEP04FUH00`00FUH00003
000:Ool3000IOol2000015YF0000000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
10000eYF00L005YF001JEP00FUH0001EOol0039oo`8000AJEP03001JEUYF00=JEP@002=oo`03001J
EP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH007oo
05Aoo`00=7oo00@005YFFUH000QJEP04001JEP00000POol2000015YF001oo`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000eYF0P000eYF00<005YFFUH00UYF00<005YF0000EGoo000eOol30008
FUH01000FUIJEUYF0`006goo0P0000=JEP0000000Woo00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@0
05YFFUIJEP<000IJEP800003FUH005YF00=JEP8005Ioo`00=goo0P001UYF00<005YFFUH01EYF1P00
47oo1@000eYF0P000goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00EJEP<0
00AJEP8005Ioo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJ
EP00FUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH30002FUH40006FUH00`00FUIJEP020002FUH2001FOol003eoo`@000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20008Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH3001GOol0045oo`8000AJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000030004FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH2001GOol004=oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP00000BOol50008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH<0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00@005YF000005Eoo`00AWoo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEP@001Uoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJ
EPd000Aoo`P0009JEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH00`00Oomo
o`1BOol004aooa4002=ooaD0009JEP80011ooa<000Aoo`800003FUH005YF00=JEP03001oogoo059o
o`00T7oo00@005YFFUH000EJEP8000moo`<001Eoo`8000AJEP03001oogoo059oo`00TGoo0`001EYF
00@005YF000002Moo`03001JEUYF008005Aoo`00Tgoo00<005YFFUH00eYF00@005YFFUIJEP<002Eo
o`@005Aoo`00U7oo0P000UYF00<005YFFUH01EYF10008goo0P00E7oo002FOol30008FUH00`00FUIJ
EP04000NOol2001EOol009Qoo`8000MJEP03001JEUYF00AJEPL001Eoo`@005Eoo`00VWoo0P0015YF
00<005YFFUH01eYF00<005YFFUH00UYF200027oo1@000UYF0P00EGoo002LOol300000eYF001JEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YFFUH00P00EWoo002OOol40006FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:=oo`@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:Moo`D000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol00:aoo`@0009JEP03001JEUYF00EJ
EP04001JEUYFFUH5001JOol00;1oo`h005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59806 .74923 m .59273 .69335 L .5617 .69449 L p .707 .577 .707 r
F P
0 g
s
.59273 .69335 m .59806 .74923 L .62977 .7457 L p .707 .577 .707 r
F P
0 g
s
.62977 .7457 m .62443 .68983 L .59273 .69335 L p .707 .577 .707 r
F P
0 g
s
.62443 .68983 m .62977 .7457 L .65904 .74015 L p .707 .577 .707 r
F P
0 g
s
.65904 .74015 m .65371 .68427 L .62443 .68983 L p .707 .577 .707 r
F P
0 g
s
.56703 .75037 m .5617 .69449 L .53439 .69314 L p .707 .577 .707 r
F P
0 g
s
.5617 .69449 m .56703 .75037 L .59806 .74923 L p .707 .577 .707 r
F P
0 g
s
.65371 .68427 m .65904 .74015 L .68303 .7331 L p .707 .577 .707 r
F P
0 g
s
.68303 .7331 m .6777 .67722 L .65371 .68427 L p .707 .577 .707 r
F P
0 g
s
.60104 .80271 m .59391 .76564 L .56332 .76988 L p .707 .577 .707 r
F P
0 g
s
.59391 .76564 m .60104 .80271 L .63235 .79639 L p .707 .577 .707 r
F P
0 g
s
.63235 .79639 m .62521 .75932 L .59391 .76564 L p .707 .577 .707 r
F P
0 g
s
.53439 .69314 m .53972 .74902 L .56703 .75037 L p .707 .577 .707 r
F P
0 g
s
.62521 .75932 m .63235 .79639 L .6613 .78862 L p .707 .577 .707 r
F P
0 g
s
.6613 .78862 m .65417 .75154 L .62521 .75932 L p .707 .577 .707 r
F P
0 g
s
.53972 .74902 m .53439 .69314 L .51346 .68943 L p .707 .577 .707 r
F P
0 g
s
.56332 .76988 m .57046 .80695 L .60104 .80271 L p .707 .577 .707 r
F P
0 g
s
.57046 .80695 m .56332 .76988 L .53646 .77163 L p .707 .577 .707 r
F P
0 g
s
.65417 .75154 m .6613 .78862 L .68509 .78014 L p .707 .577 .707 r
F P
0 g
s
.68509 .78014 m .67795 .74307 L .65417 .75154 L p .707 .577 .707 r
F P
0 g
s
.6777 .67722 m .68303 .7331 L .69938 .72525 L p .707 .577 .707 r
F P
0 g
s
.69938 .72525 m .69404 .66937 L .6777 .67722 L p .707 .577 .707 r
F P
0 g
s
.53646 .77163 m .5436 .80871 L .57046 .80695 L p .707 .577 .707 r
F P
0 g
s
.59554 .84187 m .59224 .82331 L .56158 .82708 L p .707 .577 .707 r
F P
0 g
s
.59224 .82331 m .59554 .84187 L .62692 .83597 L p .707 .577 .707 r
F P
0 g
s
.62692 .83597 m .62362 .81741 L .59224 .82331 L p .707 .577 .707 r
F P
0 g
s
.51346 .68943 m .5188 .74531 L .53972 .74902 L p .707 .577 .707 r
F P
0 g
s
.62362 .81741 m .62692 .83597 L .65595 .82853 L p .707 .577 .707 r
F P
0 g
s
.65595 .82853 m .65264 .80997 L .62362 .81741 L p .707 .577 .707 r
F P
0 g
s
.56158 .82708 m .56488 .84565 L .59554 .84187 L p .707 .577 .707 r
F P
0 g
s
.56488 .84565 m .56158 .82708 L .53462 .82837 L p .707 .577 .707 r
F P
0 g
s
.5436 .80871 m .53646 .77163 L .51594 .77072 L p .707 .577 .707 r
F P
0 g
s
.5188 .74531 m .51346 .68943 L .50098 .68373 L p .707 .577 .707 r
F P
0 g
s
.53462 .82837 m .53792 .84693 L .56488 .84565 L p .707 .577 .707 r
F P
0 g
s
.65264 .80997 m .65595 .82853 L .67977 .82027 L p .707 .577 .707 r
F P
0 g
s
.67977 .82027 m .67647 .80171 L .65264 .80997 L p .707 .577 .707 r
F P
0 g
s
.67795 .74307 m .68509 .78014 L .70136 .7718 L p .707 .577 .707 r
F P
0 g
s
.70136 .7718 m .69422 .73473 L .67795 .74307 L p .707 .577 .707 r
F P
0 g
s
.51594 .77072 m .52308 .80779 L .5436 .80871 L p .707 .577 .707 r
F P
0 g
s
.69404 .66937 m .69938 .72525 L .70648 .71736 L p .707 .577 .707 r
F P
0 g
s
.70648 .71736 m .70115 .66149 L .69404 .66937 L p .707 .577 .707 r
F P
0 g
s
.50098 .68373 m .50631 .73961 L .5188 .74531 L p .707 .577 .707 r
F P
0 g
s
.53792 .84693 m .53462 .82837 L .51402 .82703 L p .707 .577 .707 r
F P
0 g
s
.51402 .82703 m .51732 .8456 L .53792 .84693 L p .707 .577 .707 r
F P
0 g
s
.67647 .80171 m .67977 .82027 L .69606 .81201 L p .707 .577 .707 r
F P
0 g
s
.69606 .81201 m .69275 .79344 L .67647 .80171 L p .707 .577 .707 r
F P
0 g
s
.52308 .80779 m .51594 .77072 L .50377 .76724 L p .707 .577 .707 r
F P
0 g
s
.50631 .73961 m .50098 .68373 L .49815 .67659 L p .707 .577 .707 r
F P
0 g
s
.50377 .76724 m .51091 .80431 L .52308 .80779 L p .707 .577 .707 r
F P
0 g
s
.69422 .73473 m .70136 .7718 L .70854 .76441 L p .707 .577 .707 r
F P
0 g
s
.70854 .76441 m .7014 .72734 L .69422 .73473 L p .707 .577 .707 r
F P
0 g
s
.51732 .8456 m .51402 .82703 L .50179 .82321 L p .707 .577 .707 r
F P
0 g
s
.50179 .82321 m .50509 .84178 L .51732 .8456 L p .707 .577 .707 r
F P
0 g
s
.70115 .66149 m .70648 .71736 L .70365 .71022 L p .707 .577 .707 r
F P
0 g
s
.70365 .71022 m .69832 .65434 L .70115 .66149 L p .707 .577 .707 r
F P
0 g
s
.49815 .67659 m .50348 .73246 L .50631 .73961 L p .707 .577 .707 r
F P
0 g
s
.69275 .79344 m .69606 .81201 L .70322 .80454 L p .707 .577 .707 r
F P
0 g
s
.70322 .80454 m .69992 .78598 L .69275 .79344 L p .707 .577 .707 r
F P
0 g
s
.47849 .82203 m .49729 .32254 L .45331 .31819 L p .707 .577 .707 r
F P
0 g
s
.51091 .80431 m .50377 .76724 L .50114 .76152 L p .707 .577 .707 r
F P
0 g
s
.50114 .76152 m .50828 .79859 L .51091 .80431 L p .707 .577 .707 r
F P
0 g
s
.50348 .73246 m .49815 .67659 L .50525 .6687 L p .707 .577 .707 r
F P
0 g
s
.50509 .84178 m .50179 .82321 L .49913 .81728 L p .707 .577 .707 r
F P
0 g
s
.49913 .81728 m .50243 .83584 L .50509 .84178 L p .707 .577 .707 r
F P
0 g
s
.50525 .6687 m .51059 .72458 L .50348 .73246 L p .707 .577 .707 r
F P
0 g
s
.50828 .79859 m .50114 .76152 L .50832 .75413 L p .707 .577 .707 r
F P
0 g
s
.50832 .75413 m .51546 .7912 L .50828 .79859 L p .707 .577 .707 r
F P
0 g
s
.51059 .72458 m .50525 .6687 L .5216 .66085 L p .707 .577 .707 r
F P
0 g
s
.50243 .83584 m .49913 .81728 L .50629 .80981 L p .707 .577 .707 r
F P
0 g
s
.50629 .80981 m .50959 .82838 L .50243 .83584 L p .707 .577 .707 r
F P
0 g
s
.5216 .66085 m .52693 .71673 L .51059 .72458 L p .707 .577 .707 r
F P
0 g
s
.51546 .7912 m .50832 .75413 L .5246 .74579 L p .707 .577 .707 r
F P
0 g
s
.5246 .74579 m .53173 .78286 L .51546 .7912 L p .707 .577 .707 r
F P
0 g
s
.50959 .82838 m .50629 .80981 L .52258 .80155 L p .707 .577 .707 r
F P
0 g
s
.52258 .80155 m .52588 .82011 L .50959 .82838 L p .707 .577 .707 r
F P
0 g
s
.49729 .32254 m .47849 .82203 L .52341 .82244 L p .707 .577 .707 r
F P
0 g
s
.52693 .71673 m .5216 .66085 L .54559 .65381 L p .707 .577 .707 r
F P
0 g
s
.54559 .65381 m .55092 .70968 L .52693 .71673 L p .707 .577 .707 r
F P
0 g
s
.53173 .78286 m .5246 .74579 L .54838 .73731 L p .707 .577 .707 r
F P
0 g
s
.52588 .82011 m .52258 .80155 L .5464 .79329 L p .707 .577 .707 r
F P
0 g
s
.52341 .82244 m .5422 .32295 L .49729 .32254 L p .707 .577 .707 r
F P
0 g
s
.55092 .70968 m .54559 .65381 L .57486 .64825 L p .707 .577 .707 r
F P
0 g
s
.54838 .73731 m .55552 .77438 L .53173 .78286 L p .707 .577 .707 r
F P
0 g
s
.57486 .64825 m .5802 .70413 L .55092 .70968 L p .707 .577 .707 r
F P
0 g
s
.55552 .77438 m .54838 .73731 L .57734 .72953 L p .707 .577 .707 r
F P
0 g
s
.5464 .79329 m .5497 .81185 L .52588 .82011 L p .707 .577 .707 r
F P
0 g
s
.57734 .72953 m .58447 .76661 L .55552 .77438 L p .707 .577 .707 r
F P
0 g
s
.5497 .81185 m .5464 .79329 L .57542 .78585 L p .707 .577 .707 r
F P
0 g
s
.57542 .78585 m .57872 .80441 L .5497 .81185 L p .707 .577 .707 r
F P
0 g
s
.5422 .32295 m .52341 .82244 L .56487 .81886 L p .707 .577 .707 r
F P
0 g
s
.56487 .81886 m .58366 .31937 L .5422 .32295 L p .707 .577 .707 r
F P
0 g
s
.43452 .81769 m .45331 .31819 L .41458 .31033 L p .707 .577 .707 r
F P
0 g
s
.45331 .31819 m .43452 .81769 L .47849 .82203 L p .707 .577 .707 r
F P
0 g
s
.7014 .72734 m .70854 .76441 L .70591 .75869 L p .707 .577 .707 r
F P
0 g
s
.70591 .75869 m .69877 .72162 L .7014 .72734 L p .707 .577 .707 r
F P
0 g
s
.5802 .70413 m .57486 .64825 L .60657 .64472 L p .707 .577 .707 r
F P
0 g
s
.60657 .64472 m .6119 .7006 L .5802 .70413 L p .707 .577 .707 r
F P
0 g
s
.58447 .76661 m .57734 .72953 L .60864 .72322 L p .707 .577 .707 r
F P
0 g
s
.60864 .72322 m .61578 .76029 L .58447 .76661 L p .707 .577 .707 r
F P
0 g
s
.57872 .80441 m .57542 .78585 L .6068 .77995 L p .707 .577 .707 r
F P
0 g
s
.6068 .77995 m .6101 .79851 L .57872 .80441 L p .707 .577 .707 r
F P
0 g
s
.58366 .31937 m .56487 .81886 L .59881 .81165 L p .707 .577 .707 r
F P
0 g
s
.59881 .81165 m .6176 .31216 L .58366 .31937 L p .707 .577 .707 r
F P
0 g
s
.69832 .65434 m .70365 .71022 L .69116 .70452 L p .707 .577 .707 r
F P
0 g
s
.69116 .70452 m .68583 .64864 L .69832 .65434 L p .707 .577 .707 r
F P
0 g
s
.69992 .78598 m .70322 .80454 L .70055 .79861 L p .707 .577 .707 r
F P
0 g
s
.70055 .79861 m .69725 .78004 L .69992 .78598 L p .707 .577 .707 r
F P
0 g
s
.39578 .80982 m .41458 .31033 L .38488 .29972 L p .707 .577 .707 r
F P
0 g
s
.41458 .31033 m .39578 .80982 L .43452 .81769 L p .707 .577 .707 r
F P
0 g
s
.25505 .70703 m .24972 .65115 L .21869 .6523 L p .707 .577 .707 r
F P
0 g
s
.24972 .65115 m .25505 .70703 L .28676 .70351 L p .707 .577 .707 r
F P
0 g
s
.28676 .70351 m .28142 .64763 L .24972 .65115 L p .707 .577 .707 r
F P
0 g
s
.28142 .64763 m .28676 .70351 L .31603 .69795 L p .707 .577 .707 r
F P
0 g
s
.31603 .69795 m .3107 .64207 L .28142 .64763 L p .707 .577 .707 r
F P
0 g
s
.22403 .70818 m .21869 .6523 L .19138 .65095 L p .707 .577 .707 r
F P
0 g
s
.21869 .6523 m .22403 .70818 L .25505 .70703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69877 .72162 m .70591 .75869 L .69374 .75521 L p .707 .577 .707 r
F P
0 g
s
.69374 .75521 m .68661 .71813 L .69877 .72162 L p .707 .577 .707 r
F P
0 g
s
.3107 .64207 m .31603 .69795 L .34002 .6909 L p .707 .577 .707 r
F P
0 g
s
.34002 .6909 m .33469 .63502 L .3107 .64207 L p .707 .577 .707 r
F P
0 g
s
.63759 .64358 m .64293 .69946 L .6119 .7006 L p .707 .577 .707 r
F P
0 g
s
.6119 .7006 m .60657 .64472 L .63759 .64358 L p .707 .577 .707 r
F P
0 g
s
.63922 .71897 m .64636 .75605 L .61578 .76029 L p .707 .577 .707 r
F P
0 g
s
.61578 .76029 m .60864 .72322 L .63922 .71897 L p .707 .577 .707 r
F P
0 g
s
.63747 .77617 m .64077 .79474 L .6101 .79851 L p .707 .577 .707 r
F P
0 g
s
.6101 .79851 m .6068 .77995 L .63747 .77617 L p .707 .577 .707 r
F P
0 g
s
.6176 .31216 m .59881 .81165 L .62191 .80151 L p .707 .577 .707 r
F P
0 g
s
.62191 .80151 m .64071 .30202 L .6176 .31216 L p .707 .577 .707 r
F P
0 g
s
.68583 .64864 m .69116 .70452 L .67024 .70081 L p .707 .577 .707 r
F P
0 g
s
.67024 .70081 m .66491 .64493 L .68583 .64864 L p .707 .577 .707 r
F P
0 g
s
.19138 .65095 m .19671 .70683 L .22403 .70818 L p .707 .577 .707 r
F P
0 g
s
.25804 .76834 m .2509 .73126 L .22032 .73551 L p .707 .577 .707 r
F P
0 g
s
.2509 .73126 m .25804 .76834 L .28934 .76202 L p .707 .577 .707 r
F P
0 g
s
.28934 .76202 m .2822 .72494 L .2509 .73126 L p .707 .577 .707 r
F P
0 g
s
.2822 .72494 m .28934 .76202 L .3183 .75424 L p .707 .577 .707 r
F P
0 g
s
.3183 .75424 m .31116 .71717 L .2822 .72494 L p .707 .577 .707 r
F P
0 g
s
.19671 .70683 m .19138 .65095 L .17046 .64724 L p .707 .577 .707 r
F P
0 g
s
.69725 .78004 m .70055 .79861 L .68832 .79479 L p .707 .577 .707 r
F P
0 g
s
.68832 .79479 m .68502 .77622 L .69725 .78004 L p .707 .577 .707 r
F P
0 g
s
.22032 .73551 m .22746 .77258 L .25804 .76834 L p .707 .577 .707 r
F P
0 g
s
.22746 .77258 m .22032 .73551 L .19345 .73726 L p .707 .577 .707 r
F P
0 g
s
.36609 .79921 m .38488 .29972 L .36712 .28739 L p .707 .577 .707 r
F P
0 g
s
.38488 .29972 m .36609 .79921 L .39578 .80982 L p .707 .577 .707 r
F P
0 g
s
.33469 .63502 m .34002 .6909 L .35637 .68305 L p .707 .577 .707 r
F P
0 g
s
.35637 .68305 m .35103 .62717 L .33469 .63502 L p .707 .577 .707 r
F P
0 g
s
.31116 .71717 m .3183 .75424 L .34208 .74577 L p .707 .577 .707 r
F P
0 g
s
.34208 .74577 m .33494 .70869 L .31116 .71717 L p .707 .577 .707 r
F P
0 g
s
.19345 .73726 m .20059 .77433 L .22746 .77258 L p .707 .577 .707 r
F P
0 g
s
.17046 .64724 m .17579 .70312 L .19671 .70683 L p .707 .577 .707 r
F P
0 g
s
.68661 .71813 m .69374 .75521 L .67322 .75429 L p .707 .577 .707 r
F P
0 g
s
.67322 .75429 m .66608 .71722 L .68661 .71813 L p .707 .577 .707 r
F P
0 g
s
.25254 .81301 m .24924 .79445 L .21857 .79822 L p .707 .577 .707 r
F P
0 g
s
.24924 .79445 m .25254 .81301 L .28392 .80711 L p .707 .577 .707 r
F P
0 g
s
.28392 .80711 m .28062 .78855 L .24924 .79445 L p .707 .577 .707 r
F P
0 g
s
.28062 .78855 m .28392 .80711 L .31294 .79967 L p .707 .577 .707 r
F P
0 g
s
.31294 .79967 m .30964 .78111 L .28062 .78855 L p .707 .577 .707 r
F P
0 g
s
.66491 .64493 m .67024 .70081 L .64293 .69946 L p .707 .577 .707 r
F P
0 g
s
.64293 .69946 m .63759 .64358 L .66491 .64493 L p .707 .577 .707 r
F P
0 g
s
.21857 .79822 m .22187 .81679 L .25254 .81301 L p .707 .577 .707 r
F P
0 g
s
.20059 .77433 m .19345 .73726 L .17293 .73635 L p .707 .577 .707 r
F P
0 g
s
.17579 .70312 m .17046 .64724 L .15797 .64154 L p .707 .577 .707 r
F P
0 g
s
.22187 .81679 m .21857 .79822 L .19162 .79951 L p .707 .577 .707 r
F P
0 g
s
.19162 .79951 m .19492 .81807 L .22187 .81679 L p .707 .577 .707 r
F P
0 g
s
.30964 .78111 m .31294 .79967 L .33676 .79141 L p .707 .577 .707 r
F P
0 g
s
.33676 .79141 m .33346 .77285 L .30964 .78111 L p .707 .577 .707 r
F P
0 g
s
.33494 .70869 m .34208 .74577 L .35835 .73743 L p .707 .577 .707 r
F P
0 g
s
.35835 .73743 m .35121 .70035 L .33494 .70869 L p .707 .577 .707 r
F P
0 g
s
.17293 .73635 m .18007 .77342 L .20059 .77433 L p .707 .577 .707 r
F P
0 g
s
.68502 .77622 m .68832 .79479 L .66772 .79345 L p .707 .577 .707 r
F P
0 g
s
.66772 .79345 m .66442 .77489 L .68502 .77622 L p .707 .577 .707 r
F P
0 g
s
.64071 .30202 m .62191 .80151 L .63192 .78944 L p .707 .577 .707 r
F P
0 g
s
.63192 .78944 m .65071 .28995 L .64071 .30202 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .36305 .27457 L p .36009 .37768 L .707 .577 .707 r
F P
0 g
s
.35103 .62717 m .35637 .68305 L .36129 .67759 L p .707 .577 .707 r
F P
0 g
s
.36125 .66658 m .35103 .62717 L .36129 .67759 L .707 .577 .707 r
F
.36347 .67517 m .35814 .61929 L .35103 .62717 L p F P
0 g
s
.33346 .77285 m .33676 .79141 L .35305 .78315 L p .707 .577 .707 r
F P
0 g
s
.35305 .78315 m .34975 .76458 L .33346 .77285 L p .707 .577 .707 r
F P
0 g
s
.35121 .70035 m .35835 .73743 L .36553 .73003 L p .707 .577 .707 r
F P
0 g
s
.36553 .73003 m .35839 .69296 L .35121 .70035 L p .707 .577 .707 r
F P
0 g
s
.35531 .61215 m .35826 .64307 L p .34815 .66232 L .707 .577 .707 r
F P
0 g
s
.35826 .64307 m .36064 .66803 L .35655 .66616 L p .707 .577 .707 r
F P
0 g
s
.35655 .66616 m .34815 .66232 L p .35826 .64307 L .707 .577 .707 r
F P
0 g
s
.34815 .66232 m .34282 .60644 L .35531 .61215 L p .707 .577 .707 r
F P
0 g
s
.35074 .72083 m .3436 .68376 L .35577 .68724 L p .707 .577 .707 r
F P
0 g
s
.34975 .76458 m .35305 .78315 L .36021 .77568 L p .707 .577 .707 r
F P
0 g
s
.36021 .77568 m .35691 .75712 L .34975 .76458 L p .707 .577 .707 r
F P
0 g
s
.35424 .75119 m .35754 .76975 L .34531 .76593 L p .707 .577 .707 r
F P
0 g
s
.34531 .76593 m .34201 .74736 L .35424 .75119 L p .707 .577 .707 r
F P
0 g
s
.3436 .68376 m .35074 .72083 L .33021 .71992 L p .707 .577 .707 r
F P
0 g
s
.34878 .77126 m .36044 .46511 L .36009 .37768 L .707 .577 .707 r
F
.34833 .78689 m .34906 .76744 L p .34878 .77126 L F P
0 g
s
.35577 .68724 m .35646 .69086 L p .35074 .72083 L .707 .577 .707 r
F P
0 g
s
.35646 .69086 m .3629 .72432 L .35328 .72156 L p .707 .577 .707 r
F P
0 g
s
.35328 .72156 m .35074 .72083 L p .35646 .69086 L .707 .577 .707 r
F P
0 g
s
.34906 .76744 m .34937 .75934 L p .34878 .77126 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .36044 .46511 L p .34916 .76138 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .34916 .76138 L .34878 .77126 L .707 .577 .707 r
F
.36044 .46511 m .36712 .28739 L p .36009 .37768 L F P
0 g
s
.36129 .67759 m .36347 .67517 L p .36125 .66658 L .707 .577 .707 r
F P
0 g
s
.15797 .64154 m .1633 .69741 L .17579 .70312 L p .707 .577 .707 r
F P
0 g
s
.66608 .71722 m .67322 .75429 L .64636 .75605 L p .707 .577 .707 r
F P
0 g
s
.64636 .75605 m .63922 .71897 L .66608 .71722 L p .707 .577 .707 r
F P
0 g
s
.19492 .81807 m .19162 .79951 L .17102 .79817 L p .707 .577 .707 r
F P
0 g
s
.17102 .79817 m .17432 .81674 L .19492 .81807 L p .707 .577 .707 r
F P
0 g
s
.35814 .61929 m .36347 .67517 L .36064 .66803 L p .707 .577 .707 r
F P
0 g
s
.36064 .66803 m .35531 .61215 L .35814 .61929 L p .707 .577 .707 r
F P
0 g
s
.35839 .69296 m .36553 .73003 L .3629 .72432 L p .707 .577 .707 r
F P
0 g
s
.3629 .72432 m .35577 .68724 L .35839 .69296 L p .707 .577 .707 r
F P
0 g
s
.35691 .75712 m .36021 .77568 L .35754 .76975 L p .707 .577 .707 r
F P
0 g
s
.35754 .76975 m .35424 .75119 L .35691 .75712 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .34833 .78689 L .36609 .79921 L p .707 .577 .707 r
F P
0 g
s
.18007 .77342 m .17293 .73635 L .16076 .73286 L p .707 .577 .707 r
F P
0 g
s
.1633 .69741 m .15797 .64154 L .15514 .63439 L p .707 .577 .707 r
F P
0 g
s
.16076 .73286 m .1679 .76993 L .18007 .77342 L p .707 .577 .707 r
F P
0 g
s
.66442 .77489 m .66772 .79345 L .64077 .79474 L p .707 .577 .707 r
F P
0 g
s
.64077 .79474 m .63747 .77617 L .66442 .77489 L p .707 .577 .707 r
F P
0 g
s
.17432 .81674 m .17102 .79817 L .15878 .79435 L p .707 .577 .707 r
F P
0 g
s
.15514 .63439 m .16047 .69027 L .1633 .69741 L p .707 .577 .707 r
F P
0 g
s
.15878 .79435 m .16208 .81292 L .17432 .81674 L p .707 .577 .707 r
F P
0 g
s
.65071 .28995 m .63192 .78944 L .62784 .77662 L p .707 .577 .707 r
F P
0 g
s
.62784 .77662 m .64664 .27712 L .65071 .28995 L p .707 .577 .707 r
F P
0 g
s
.1679 .76993 m .16076 .73286 L .15813 .72714 L p .707 .577 .707 r
F P
0 g
s
.16047 .69027 m .15514 .63439 L .16224 .62651 L p .707 .577 .707 r
F P
0 g
s
.15813 .72714 m .16527 .76421 L .1679 .76993 L p .707 .577 .707 r
F P
0 g
s
.34201 .74736 m .34531 .76593 L .32471 .76459 L p .707 .577 .707 r
F P
0 g
s
.36305 .27457 m .34426 .77406 L .34833 .78689 L p .707 .577 .707 r
F P
0 g
s
.34426 .77406 m .36305 .27457 L .37305 .2625 L p .707 .577 .707 r
F P
0 g
s
.16208 .81292 m .15878 .79435 L .15612 .78842 L p .707 .577 .707 r
F P
0 g
s
.16224 .62651 m .16758 .68239 L .16047 .69027 L p .707 .577 .707 r
F P
0 g
s
.15612 .78842 m .15942 .80698 L .16208 .81292 L p .707 .577 .707 r
F P
0 g
s
.16527 .76421 m .15813 .72714 L .16531 .71975 L p .707 .577 .707 r
F P
0 g
s
.16758 .68239 m .16224 .62651 L .17859 .61866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16531 .71975 m .17245 .75682 L .16527 .76421 L p .707 .577 .707 r
F P
0 g
s
.64664 .27712 m .62784 .77662 L .61009 .76429 L p .707 .577 .707 r
F P
0 g
s
.61009 .76429 m .62888 .2648 L .64664 .27712 L p .707 .577 .707 r
F P
0 g
s
.34282 .60644 m .34815 .66232 L .32723 .65861 L p .707 .577 .707 r
F P
0 g
s
.32723 .65861 m .3219 .60274 L .34282 .60644 L p .707 .577 .707 r
F P
0 g
s
.15942 .80698 m .15612 .78842 L .16328 .78096 L p .707 .577 .707 r
F P
0 g
s
.17859 .61866 m .18392 .67454 L .16758 .68239 L p .707 .577 .707 r
F P
0 g
s
.16328 .78096 m .16658 .79952 L .15942 .80698 L p .707 .577 .707 r
F P
0 g
s
.35426 .76199 m .37305 .2625 L .39616 .25236 L p .707 .577 .707 r
F P
0 g
s
.37305 .2625 m .35426 .76199 L .34426 .77406 L p .707 .577 .707 r
F P
0 g
s
.17245 .75682 m .16531 .71975 L .18159 .71141 L p .707 .577 .707 r
F P
0 g
s
.18392 .67454 m .17859 .61866 L .20258 .61161 L p .707 .577 .707 r
F P
0 g
s
.18159 .71141 m .18873 .74848 L .17245 .75682 L p .707 .577 .707 r
F P
0 g
s
.33021 .71992 m .32307 .68284 L .3436 .68376 L p .707 .577 .707 r
F P
0 g
s
.3219 .60274 m .32723 .65861 L .29992 .65727 L p .707 .577 .707 r
F P
0 g
s
.29992 .65727 m .29458 .60139 L .3219 .60274 L p .707 .577 .707 r
F P
0 g
s
.20258 .61161 m .20791 .66749 L .18392 .67454 L p .707 .577 .707 r
F P
0 g
s
.62888 .2648 m .61009 .76429 L .58039 .75368 L p .707 .577 .707 r
F P
0 g
s
.58039 .75368 m .59919 .25419 L .62888 .2648 L p .707 .577 .707 r
F P
0 g
s
.16658 .79952 m .16328 .78096 L .17957 .77269 L p .707 .577 .707 r
F P
0 g
s
.20791 .66749 m .20258 .61161 L .23185 .60605 L p .707 .577 .707 r
F P
0 g
s
.17957 .77269 m .18287 .79125 L .16658 .79952 L p .707 .577 .707 r
F P
0 g
s
.18873 .74848 m .18159 .71141 L .20537 .70294 L p .707 .577 .707 r
F P
0 g
s
.32471 .76459 m .32141 .74603 L .34201 .74736 L p .707 .577 .707 r
F P
0 g
s
.29458 .60139 m .29992 .65727 L .26889 .65841 L p .707 .577 .707 r
F P
0 g
s
.26889 .65841 m .26356 .60253 L .29458 .60139 L p .707 .577 .707 r
F P
0 g
s
.39616 .25236 m .37736 .75185 L .35426 .76199 L p .707 .577 .707 r
F P
0 g
s
.37736 .75185 m .39616 .25236 L .4301 .24515 L p .707 .577 .707 r
F P
0 g
s
.32307 .68284 m .33021 .71992 L .30335 .72167 L p .707 .577 .707 r
F P
0 g
s
.30335 .72167 m .29621 .6846 L .32307 .68284 L p .707 .577 .707 r
F P
0 g
s
.23719 .66193 m .23185 .60605 L .26356 .60253 L p .707 .577 .707 r
F P
0 g
s
.23185 .60605 m .23719 .66193 L .20791 .66749 L p .707 .577 .707 r
F P
0 g
s
.20537 .70294 m .21251 .74001 L .18873 .74848 L p .707 .577 .707 r
F P
0 g
s
.26356 .60253 m .26889 .65841 L .23719 .66193 L p .707 .577 .707 r
F P
0 g
s
.73527 .65719 m .72993 .60131 L .69891 .60245 L p .707 .577 .707 r
F P
0 g
s
.72993 .60131 m .73527 .65719 L .76697 .65367 L p .707 .577 .707 r
F P
0 g
s
.76697 .65367 m .76164 .59779 L .72993 .60131 L p .707 .577 .707 r
F P
0 g
s
.76164 .59779 m .76697 .65367 L .79625 .64811 L p .707 .577 .707 r
F P
0 g
s
.79625 .64811 m .79091 .59223 L .76164 .59779 L p .707 .577 .707 r
F P
0 g
s
.18287 .79125 m .17957 .77269 L .20339 .76443 L p .707 .577 .707 r
F P
0 g
s
.70424 .65833 m .69891 .60245 L .67159 .6011 L p .707 .577 .707 r
F P
0 g
s
.69891 .60245 m .70424 .65833 L .73527 .65719 L p .707 .577 .707 r
F P
0 g
s
.21251 .74001 m .20537 .70294 L .23433 .69516 L p .707 .577 .707 r
F P
0 g
s
.20339 .76443 m .20669 .78299 L .18287 .79125 L p .707 .577 .707 r
F P
0 g
s
.59919 .25419 m .58039 .75368 L .54166 .74581 L p .707 .577 .707 r
F P
0 g
s
.54166 .74581 m .56045 .24632 L .59919 .25419 L p .707 .577 .707 r
F P
0 g
s
.29621 .6846 m .30335 .72167 L .27277 .72591 L p .707 .577 .707 r
F P
0 g
s
.27277 .72591 m .26563 .68884 L .29621 .6846 L p .707 .577 .707 r
F P
0 g
s
.79091 .59223 m .79625 .64811 L .82023 .64106 L p .707 .577 .707 r
F P
0 g
s
.82023 .64106 m .8149 .58518 L .79091 .59223 L p .707 .577 .707 r
F P
0 g
s
.32141 .74603 m .32471 .76459 L .29776 .76588 L p .707 .577 .707 r
F P
0 g
s
.29776 .76588 m .29446 .74731 L .32141 .74603 L p .707 .577 .707 r
F P
0 g
s
.23433 .69516 m .24146 .73223 L .21251 .74001 L p .707 .577 .707 r
F P
0 g
s
.73825 .71067 m .73111 .6736 L .70053 .67784 L p .707 .577 .707 r
F P
0 g
s
.73111 .6736 m .73825 .71067 L .76955 .70435 L p .707 .577 .707 r
F P
0 g
s
.76955 .70435 m .76241 .66728 L .73111 .6736 L p .707 .577 .707 r
F P
0 g
s
.24146 .73223 m .23433 .69516 L .26563 .68884 L p .707 .577 .707 r
F P
0 g
s
.67159 .6011 m .67693 .65698 L .70424 .65833 L p .707 .577 .707 r
F P
0 g
s
.76241 .66728 m .76955 .70435 L .79851 .69658 L p .707 .577 .707 r
F P
0 g
s
.79851 .69658 m .79137 .6595 L .76241 .66728 L p .707 .577 .707 r
F P
0 g
s
.26563 .68884 m .27277 .72591 L .24146 .73223 L p .707 .577 .707 r
F P
0 g
s
.41131 .74464 m .4301 .24515 L .47156 .24157 L p .707 .577 .707 r
F P
0 g
s
.4301 .24515 m .41131 .74464 L .37736 .75185 L p .707 .577 .707 r
F P
0 g
s
.67693 .65698 m .67159 .6011 L .65067 .5974 L p .707 .577 .707 r
F P
0 g
s
.20669 .78299 m .20339 .76443 L .23241 .75699 L p .707 .577 .707 r
F P
0 g
s
.70053 .67784 m .70767 .71492 L .73825 .71067 L p .707 .577 .707 r
F P
0 g
s
.70767 .71492 m .70053 .67784 L .67366 .6796 L p .707 .577 .707 r
F P
0 g
s
.23241 .75699 m .23571 .77555 L .20669 .78299 L p .707 .577 .707 r
F P
0 g
s
.29446 .74731 m .29776 .76588 L .26709 .76965 L p .707 .577 .707 r
F P
0 g
s
.26709 .76965 m .26379 .75109 L .29446 .74731 L p .707 .577 .707 r
F P
0 g
s
.79137 .6595 m .79851 .69658 L .82229 .6881 L p .707 .577 .707 r
F P
0 g
s
.82229 .6881 m .81515 .65103 L .79137 .6595 L p .707 .577 .707 r
F P
0 g
s
.8149 .58518 m .82023 .64106 L .83658 .63321 L p .707 .577 .707 r
F P
0 g
s
.83658 .63321 m .83125 .57733 L .8149 .58518 L p .707 .577 .707 r
F P
0 g
s
.56045 .24632 m .54166 .74581 L .49768 .74147 L p .707 .577 .707 r
F P
0 g
s
.49768 .74147 m .51648 .24197 L .56045 .24632 L p .707 .577 .707 r
F P
0 g
s
.67366 .6796 m .6808 .71667 L .70767 .71492 L p .707 .577 .707 r
F P
0 g
s
.73275 .74983 m .72945 .73127 L .69878 .73505 L p .707 .577 .707 r
F P
0 g
s
.72945 .73127 m .73275 .74983 L .76413 .74394 L p .707 .577 .707 r
F P
0 g
s
.76413 .74394 m .76083 .72537 L .72945 .73127 L p .707 .577 .707 r
F P
0 g
s
.65067 .5974 m .656 .65327 L .67693 .65698 L p .707 .577 .707 r
F P
0 g
s
.76083 .72537 m .76413 .74394 L .79315 .73649 L p .707 .577 .707 r
F P
0 g
s
.79315 .73649 m .78985 .71793 L .76083 .72537 L p .707 .577 .707 r
F P
0 g
s
.23571 .77555 m .23241 .75699 L .26379 .75109 L p .707 .577 .707 r
F P
0 g
s
.26379 .75109 m .26709 .76965 L .23571 .77555 L p .707 .577 .707 r
F P
0 g
s
.45277 .74106 m .47156 .24157 L .51648 .24197 L p .707 .577 .707 r
F P
0 g
s
.47156 .24157 m .45277 .74106 L .41131 .74464 L p .707 .577 .707 r
F P
0 g
s
.69878 .73505 m .70208 .75361 L .73275 .74983 L p .707 .577 .707 r
F P
0 g
s
.51648 .24197 m .49768 .74147 L .45277 .74106 L p .707 .577 .707 r
F P
0 g
s
.70208 .75361 m .69878 .73505 L .67183 .73633 L p .707 .577 .707 r
F P
0 g
s
.6808 .71667 m .67366 .6796 L .65314 .67868 L p .707 .577 .707 r
F P
0 g
s
.656 .65327 m .65067 .5974 L .63818 .59169 L p .707 .577 .707 r
F P
0 g
s
.67183 .73633 m .67513 .75489 L .70208 .75361 L p .707 .577 .707 r
F P
0 g
s
.78985 .71793 m .79315 .73649 L .81697 .72823 L p .707 .577 .707 r
F P
0 g
s
.81697 .72823 m .81367 .70967 L .78985 .71793 L p .707 .577 .707 r
F P
0 g
s
.81515 .65103 m .82229 .6881 L .83857 .67976 L p .707 .577 .707 r
F P
0 g
s
.83857 .67976 m .83143 .64269 L .81515 .65103 L p .707 .577 .707 r
F P
0 g
s
.65314 .67868 m .66028 .71576 L .6808 .71667 L p .707 .577 .707 r
F P
0 g
s
.83125 .57733 m .83658 .63321 L .84369 .62533 L p .707 .577 .707 r
F P
0 g
s
.84369 .62533 m .83835 .56945 L .83125 .57733 L p .707 .577 .707 r
F P
0 g
s
.63818 .59169 m .64351 .64757 L .656 .65327 L p .707 .577 .707 r
F P
0 g
s
.67513 .75489 m .67183 .73633 L .65123 .735 L p .707 .577 .707 r
F P
0 g
s
.65123 .735 m .65453 .75356 L .67513 .75489 L p .707 .577 .707 r
F P
0 g
s
.81367 .70967 m .81697 .72823 L .83326 .71997 L p .707 .577 .707 r
F P
0 g
s
.83326 .71997 m .82996 .7014 L .81367 .70967 L p .707 .577 .707 r
F P
0 g
s
.66028 .71576 m .65314 .67868 L .64097 .6752 L p .707 .577 .707 r
F P
0 g
s
.64351 .64757 m .63818 .59169 L .63535 .58455 L p .707 .577 .707 r
F P
0 g
s
.64097 .6752 m .64811 .71227 L .66028 .71576 L p .707 .577 .707 r
F P
0 g
s
.83143 .64269 m .83857 .67976 L .84574 .67237 L p .707 .577 .707 r
F P
0 g
s
.84574 .67237 m .8386 .6353 L .83143 .64269 L p .707 .577 .707 r
F P
0 g
s
.65453 .75356 m .65123 .735 L .639 .73118 L p .707 .577 .707 r
F P
0 g
s
.639 .73118 m .6423 .74974 L .65453 .75356 L p .707 .577 .707 r
F P
0 g
s
.83835 .56945 m .84369 .62533 L .84086 .61818 L p .707 .577 .707 r
F P
0 g
s
.84086 .61818 m .83552 .5623 L .83835 .56945 L p .707 .577 .707 r
F P
0 g
s
.63535 .58455 m .64068 .64043 L .64351 .64757 L p .707 .577 .707 r
F P
0 g
s
.82996 .7014 m .83326 .71997 L .84042 .7125 L p .707 .577 .707 r
F P
0 g
s
.84042 .7125 m .83712 .69394 L .82996 .7014 L p .707 .577 .707 r
F P
0 g
s
.64811 .71227 m .64097 .6752 L .63835 .66948 L p .707 .577 .707 r
F P
0 g
s
.63835 .66948 m .64549 .70655 L .64811 .71227 L p .707 .577 .707 r
F P
0 g
s
.64068 .64043 m .63535 .58455 L .64246 .57667 L p .707 .577 .707 r
F P
0 g
s
.8386 .6353 m .84574 .67237 L .84312 .66665 L p .707 .577 .707 r
F P
0 g
s
.84312 .66665 m .83598 .62958 L .8386 .6353 L p .707 .577 .707 r
F P
0 g
s
.6423 .74974 m .639 .73118 L .63633 .72524 L p .707 .577 .707 r
F P
0 g
s
.63633 .72524 m .63963 .7438 L .6423 .74974 L p .707 .577 .707 r
F P
0 g
s
.83552 .5623 m .84086 .61818 L .82837 .61248 L p .707 .577 .707 r
F P
0 g
s
.82837 .61248 m .82304 .5566 L .83552 .5623 L p .707 .577 .707 r
F P
0 g
s
.64246 .57667 m .64779 .63254 L .64068 .64043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83712 .69394 m .84042 .7125 L .83776 .70657 L p .707 .577 .707 r
F P
0 g
s
.83776 .70657 m .83446 .68801 L .83712 .69394 L p .707 .577 .707 r
F P
0 g
s
.64549 .70655 m .63835 .66948 L .64552 .66209 L p .707 .577 .707 r
F P
0 g
s
.39226 .61499 m .38692 .55912 L .3559 .56026 L p .707 .577 .707 r
F P
0 g
s
.38692 .55912 m .39226 .61499 L .42396 .61147 L p .707 .577 .707 r
F P
0 g
s
.42396 .61147 m .41863 .55559 L .38692 .55912 L p .707 .577 .707 r
F P
0 g
s
.41863 .55559 m .42396 .61147 L .45324 .60591 L p .707 .577 .707 r
F P
0 g
s
.45324 .60591 m .4479 .55003 L .41863 .55559 L p .707 .577 .707 r
F P
0 g
s
.64552 .66209 m .65266 .69916 L .64549 .70655 L p .707 .577 .707 r
F P
0 g
s
.64779 .63254 m .64246 .57667 L .6588 .56882 L p .707 .577 .707 r
F P
0 g
s
.36123 .61614 m .3559 .56026 L .32858 .55891 L p .707 .577 .707 r
F P
0 g
s
.3559 .56026 m .36123 .61614 L .39226 .61499 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83598 .62958 m .84312 .66665 L .83095 .66317 L p .707 .577 .707 r
F P
0 g
s
.83095 .66317 m .82381 .62609 L .83598 .62958 L p .707 .577 .707 r
F P
0 g
s
.4479 .55003 m .45324 .60591 L .47722 .59886 L p .707 .577 .707 r
F P
0 g
s
.47722 .59886 m .47189 .54299 L .4479 .55003 L p .707 .577 .707 r
F P
0 g
s
.63963 .7438 m .63633 .72524 L .6435 .71778 L p .707 .577 .707 r
F P
0 g
s
.82304 .5566 m .82837 .61248 L .80744 .60877 L p .707 .577 .707 r
F P
0 g
s
.80744 .60877 m .80211 .55289 L .82304 .5566 L p .707 .577 .707 r
F P
0 g
s
.6435 .71778 m .6468 .73634 L .63963 .7438 L p .707 .577 .707 r
F P
0 g
s
.6588 .56882 m .66414 .62469 L .64779 .63254 L p .707 .577 .707 r
F P
0 g
s
.32858 .55891 m .33392 .61479 L .36123 .61614 L p .707 .577 .707 r
F P
0 g
s
.39524 .6763 m .3881 .63922 L .35752 .64347 L p .707 .577 .707 r
F P
0 g
s
.3881 .63922 m .39524 .6763 L .42654 .66998 L p .707 .577 .707 r
F P
0 g
s
.42654 .66998 m .4194 .63291 L .3881 .63922 L p .707 .577 .707 r
F P
0 g
s
.4194 .63291 m .42654 .66998 L .4555 .6622 L p .707 .577 .707 r
F P
0 g
s
.4555 .6622 m .44836 .62513 L .4194 .63291 L p .707 .577 .707 r
F P
0 g
s
.33392 .61479 m .32858 .55891 L .30766 .5552 L p .707 .577 .707 r
F P
0 g
s
.83446 .68801 m .83776 .70657 L .82553 .70275 L p .707 .577 .707 r
F P
0 g
s
.82553 .70275 m .82223 .68419 L .83446 .68801 L p .707 .577 .707 r
F P
0 g
s
.35752 .64347 m .36466 .68054 L .39524 .6763 L p .707 .577 .707 r
F P
0 g
s
.65266 .69916 m .64552 .66209 L .6618 .65375 L p .707 .577 .707 r
F P
0 g
s
.36466 .68054 m .35752 .64347 L .33065 .64522 L p .707 .577 .707 r
F P
0 g
s
.47189 .54299 m .47722 .59886 L .49357 .59101 L p .707 .577 .707 r
F P
0 g
s
.49357 .59101 m .48824 .53514 L .47189 .54299 L p .707 .577 .707 r
F P
0 g
s
.66414 .62469 m .6588 .56882 L .68279 .56177 L p .707 .577 .707 r
F P
0 g
s
.44836 .62513 m .4555 .6622 L .47928 .65373 L p .707 .577 .707 r
F P
0 g
s
.47928 .65373 m .47214 .61665 L .44836 .62513 L p .707 .577 .707 r
F P
0 g
s
.6618 .65375 m .66894 .69082 L .65266 .69916 L p .707 .577 .707 r
F P
0 g
s
.33065 .64522 m .33779 .68229 L .36466 .68054 L p .707 .577 .707 r
F P
0 g
s
.30766 .5552 m .31299 .61108 L .33392 .61479 L p .707 .577 .707 r
F P
0 g
s
.82381 .62609 m .83095 .66317 L .81043 .66226 L p .707 .577 .707 r
F P
0 g
s
.81043 .66226 m .80329 .62518 L .82381 .62609 L p .707 .577 .707 r
F P
0 g
s
.38974 .72097 m .38644 .70241 L .35577 .70619 L p .707 .577 .707 r
F P
0 g
s
.38644 .70241 m .38974 .72097 L .42112 .71508 L p .707 .577 .707 r
F P
0 g
s
.42112 .71508 m .41782 .69651 L .38644 .70241 L p .707 .577 .707 r
F P
0 g
s
.41782 .69651 m .42112 .71508 L .45014 .70763 L p .707 .577 .707 r
F P
0 g
s
.45014 .70763 m .44684 .68907 L .41782 .69651 L p .707 .577 .707 r
F P
0 g
s
.80211 .55289 m .80744 .60877 L .78013 .60742 L p .707 .577 .707 r
F P
0 g
s
.78013 .60742 m .7748 .55154 L .80211 .55289 L p .707 .577 .707 r
F P
0 g
s
.35577 .70619 m .35907 .72475 L .38974 .72097 L p .707 .577 .707 r
F P
0 g
s
.6468 .73634 m .6435 .71778 L .65979 .70951 L p .707 .577 .707 r
F P
0 g
s
.68279 .56177 m .68812 .61765 L .66414 .62469 L p .707 .577 .707 r
F P
0 g
s
.33779 .68229 m .33065 .64522 L .31013 .64431 L p .707 .577 .707 r
F P
0 g
s
.31299 .61108 m .30766 .5552 L .29517 .5495 L p .707 .577 .707 r
F P
0 g
s
.35907 .72475 m .35577 .70619 L .32882 .70747 L p .707 .577 .707 r
F P
0 g
s
.65979 .70951 m .66309 .72807 L .6468 .73634 L p .707 .577 .707 r
F P
0 g
s
.32882 .70747 m .33212 .72603 L .35907 .72475 L p .707 .577 .707 r
F P
0 g
s
.44684 .68907 m .45014 .70763 L .47396 .69937 L p .707 .577 .707 r
F P
0 g
s
.47396 .69937 m .47066 .68081 L .44684 .68907 L p .707 .577 .707 r
F P
0 g
s
.68812 .61765 m .68279 .56177 L .71207 .55621 L p .707 .577 .707 r
F P
0 g
s
.47214 .61665 m .47928 .65373 L .49556 .64539 L p .707 .577 .707 r
F P
0 g
s
.49556 .64539 m .48842 .60831 L .47214 .61665 L p .707 .577 .707 r
F P
0 g
s
.31013 .64431 m .31727 .68138 L .33779 .68229 L p .707 .577 .707 r
F P
0 g
s
.82223 .68419 m .82553 .70275 L .80493 .70141 L p .707 .577 .707 r
F P
0 g
s
.80493 .70141 m .80163 .68285 L .82223 .68419 L p .707 .577 .707 r
F P
0 g
s
.66894 .69082 m .6618 .65375 L .68558 .64527 L p .707 .577 .707 r
F P
0 g
s
.7748 .55154 m .78013 .60742 L .74911 .60856 L p .707 .577 .707 r
F P
0 g
s
.74911 .60856 m .74377 .55269 L .7748 .55154 L p .707 .577 .707 r
F P
0 g
s
.48824 .53514 m .49357 .59101 L .50068 .58313 L p .707 .577 .707 r
F P
0 g
s
.50068 .58313 m .49534 .52725 L .48824 .53514 L p .707 .577 .707 r
F P
0 g
s
.29517 .5495 m .3005 .60538 L .31299 .61108 L p .707 .577 .707 r
F P
0 g
s
.80329 .62518 m .81043 .66226 L .78356 .66401 L p .707 .577 .707 r
F P
0 g
s
.78356 .66401 m .77642 .62693 L .80329 .62518 L p .707 .577 .707 r
F P
0 g
s
.68558 .64527 m .69272 .68235 L .66894 .69082 L p .707 .577 .707 r
F P
0 g
s
.7174 .61209 m .71207 .55621 L .74377 .55269 L p .707 .577 .707 r
F P
0 g
s
.71207 .55621 m .7174 .61209 L .68812 .61765 L p .707 .577 .707 r
F P
0 g
s
.33212 .72603 m .32882 .70747 L .30822 .70614 L p .707 .577 .707 r
F P
0 g
s
.74377 .55269 m .74911 .60856 L .7174 .61209 L p .707 .577 .707 r
F P
0 g
s
.30822 .70614 m .31152 .7247 L .33212 .72603 L p .707 .577 .707 r
F P
0 g
s
.31727 .68138 m .31013 .64431 L .29796 .64082 L p .707 .577 .707 r
F P
0 g
s
.47066 .68081 m .47396 .69937 L .49025 .69111 L p .707 .577 .707 r
F P
0 g
s
.49025 .69111 m .48695 .67255 L .47066 .68081 L p .707 .577 .707 r
F P
0 g
s
.66309 .72807 m .65979 .70951 L .68361 .70125 L p .707 .577 .707 r
F P
0 g
s
.69272 .68235 m .68558 .64527 L .71454 .6375 L p .707 .577 .707 r
F P
0 g
s
.68361 .70125 m .68691 .71981 L .66309 .72807 L p .707 .577 .707 r
F P
0 g
s
.3005 .60538 m .29517 .5495 L .29234 .54235 L p .707 .577 .707 r
F P
0 g
s
.29796 .64082 m .3051 .67789 L .31727 .68138 L p .707 .577 .707 r
F P
0 g
s
.80163 .68285 m .80493 .70141 L .77798 .7027 L p .707 .577 .707 r
F P
0 g
s
.77798 .7027 m .77467 .68414 L .80163 .68285 L p .707 .577 .707 r
F P
0 g
s
.77642 .62693 m .78356 .66401 L .75298 .66825 L p .707 .577 .707 r
F P
0 g
s
.75298 .66825 m .74584 .63118 L .77642 .62693 L p .707 .577 .707 r
F P
0 g
s
.48842 .60831 m .49556 .64539 L .50273 .638 L p .707 .577 .707 r
F P
0 g
s
.50273 .638 m .49559 .60092 L .48842 .60831 L p .707 .577 .707 r
F P
0 g
s
.71454 .6375 m .72168 .67457 L .69272 .68235 L p .707 .577 .707 r
F P
0 g
s
.72168 .67457 m .71454 .6375 L .74584 .63118 L p .707 .577 .707 r
F P
0 g
s
.74584 .63118 m .75298 .66825 L .72168 .67457 L p .707 .577 .707 r
F P
0 g
s
.31152 .7247 m .30822 .70614 L .29599 .70232 L p .707 .577 .707 r
F P
0 g
s
.49534 .52725 m .50068 .58313 L .49785 .57599 L p .707 .577 .707 r
F P
0 g
s
.49785 .57599 m .49251 .52011 L .49534 .52725 L p .707 .577 .707 r
F P
0 g
s
.29234 .54235 m .29767 .59823 L .3005 .60538 L p .707 .577 .707 r
F P
0 g
s
.68691 .71981 m .68361 .70125 L .71263 .69381 L p .707 .577 .707 r
F P
0 g
s
.29599 .70232 m .29929 .72088 L .31152 .7247 L p .707 .577 .707 r
F P
0 g
s
.71263 .69381 m .71593 .71237 L .68691 .71981 L p .707 .577 .707 r
F P
0 g
s
.77467 .68414 m .77798 .7027 L .74731 .70647 L p .707 .577 .707 r
F P
0 g
s
.74731 .70647 m .74401 .68791 L .77467 .68414 L p .707 .577 .707 r
F P
0 g
s
.48695 .67255 m .49025 .69111 L .49741 .68364 L p .707 .577 .707 r
F P
0 g
s
.49741 .68364 m .49411 .66508 L .48695 .67255 L p .707 .577 .707 r
F P
0 g
s
.3051 .67789 m .29796 .64082 L .29534 .6351 L p .707 .577 .707 r
F P
0 g
s
.71593 .71237 m .71263 .69381 L .74401 .68791 L p .707 .577 .707 r
F P
0 g
s
.74401 .68791 m .74731 .70647 L .71593 .71237 L p .707 .577 .707 r
F P
0 g
s
.29767 .59823 m .29234 .54235 L .29945 .53447 L p .707 .577 .707 r
F P
0 g
s
.29534 .6351 m .30248 .67218 L .3051 .67789 L p .707 .577 .707 r
F P
0 g
s
.49559 .60092 m .50273 .638 L .50011 .63228 L p .707 .577 .707 r
F P
0 g
s
.50011 .63228 m .49297 .5952 L .49559 .60092 L p .707 .577 .707 r
F P
0 g
s
.29929 .72088 m .29599 .70232 L .29332 .69638 L p .707 .577 .707 r
F P
0 g
s
.49251 .52011 m .49785 .57599 L .48536 .57028 L p .707 .577 .707 r
F P
0 g
s
.48536 .57028 m .48003 .51441 L .49251 .52011 L p .707 .577 .707 r
F P
0 g
s
.29945 .53447 m .30478 .59035 L .29767 .59823 L p .707 .577 .707 r
F P
0 g
s
.29332 .69638 m .29662 .71495 L .29929 .72088 L p .707 .577 .707 r
F P
0 g
s
.49411 .66508 m .49741 .68364 L .49475 .67771 L p .707 .577 .707 r
F P
0 g
s
.49475 .67771 m .49145 .65915 L .49411 .66508 L p .707 .577 .707 r
F P
0 g
s
.30248 .67218 m .29534 .6351 L .30251 .62771 L p .707 .577 .707 r
F P
0 g
s
.30478 .59035 m .29945 .53447 L .31579 .52662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30251 .62771 m .30965 .66478 L .30248 .67218 L p .707 .577 .707 r
F P
0 g
s
.49297 .5952 m .50011 .63228 L .48794 .62879 L p .707 .577 .707 r
F P
0 g
s
.48794 .62879 m .4808 .59172 L .49297 .5952 L p .707 .577 .707 r
F P
0 g
s
.48003 .51441 m .48536 .57028 L .46443 .56658 L p .707 .577 .707 r
F P
0 g
s
.46443 .56658 m .4591 .5107 L .48003 .51441 L p .707 .577 .707 r
F P
0 g
s
.29662 .71495 m .29332 .69638 L .30049 .68892 L p .707 .577 .707 r
F P
0 g
s
.31579 .52662 m .32113 .5825 L .30478 .59035 L p .707 .577 .707 r
F P
0 g
s
.30049 .68892 m .30379 .70748 L .29662 .71495 L p .707 .577 .707 r
F P
0 g
s
.49145 .65915 m .49475 .67771 L .48252 .67389 L p .707 .577 .707 r
F P
0 g
s
.48252 .67389 m .47922 .65533 L .49145 .65915 L p .707 .577 .707 r
F P
0 g
s
.30965 .66478 m .30251 .62771 L .31879 .61937 L p .707 .577 .707 r
F P
0 g
s
.32113 .5825 m .31579 .52662 L .33978 .51957 L p .707 .577 .707 r
F P
0 g
s
.31879 .61937 m .32593 .65644 L .30965 .66478 L p .707 .577 .707 r
F P
0 g
s
.4808 .59172 m .48794 .62879 L .46742 .62788 L p .707 .577 .707 r
F P
0 g
s
.46742 .62788 m .46028 .59081 L .4808 .59172 L p .707 .577 .707 r
F P
0 g
s
.4591 .5107 m .46443 .56658 L .43712 .56523 L p .707 .577 .707 r
F P
0 g
s
.43712 .56523 m .43179 .50935 L .4591 .5107 L p .707 .577 .707 r
F P
0 g
s
.33978 .51957 m .34511 .57545 L .32113 .5825 L p .707 .577 .707 r
F P
0 g
s
.30379 .70748 m .30049 .68892 L .31677 .68065 L p .707 .577 .707 r
F P
0 g
s
.34511 .57545 m .33978 .51957 L .36906 .51401 L p .707 .577 .707 r
F P
0 g
s
.31677 .68065 m .32008 .69921 L .30379 .70748 L p .707 .577 .707 r
F P
0 g
s
.32593 .65644 m .31879 .61937 L .34257 .6109 L p .707 .577 .707 r
F P
0 g
s
.47922 .65533 m .48252 .67389 L .46192 .67256 L p .707 .577 .707 r
F P
0 g
s
.46192 .67256 m .45862 .65399 L .47922 .65533 L p .707 .577 .707 r
F P
0 g
s
.43179 .50935 m .43712 .56523 L .40609 .56637 L p .707 .577 .707 r
F P
0 g
s
.40609 .56637 m .40076 .51049 L .43179 .50935 L p .707 .577 .707 r
F P
0 g
s
.46028 .59081 m .46742 .62788 L .44055 .62963 L p .707 .577 .707 r
F P
0 g
s
.44055 .62963 m .43341 .59256 L .46028 .59081 L p .707 .577 .707 r
F P
0 g
s
.37439 .56989 m .36906 .51401 L .40076 .51049 L p .707 .577 .707 r
F P
0 g
s
.36906 .51401 m .37439 .56989 L .34511 .57545 L p .707 .577 .707 r
F P
0 g
s
.34257 .6109 m .34971 .64797 L .32593 .65644 L p .707 .577 .707 r
F P
0 g
s
.40076 .51049 m .40609 .56637 L .37439 .56989 L p .707 .577 .707 r
F P
0 g
s
.32008 .69921 m .31677 .68065 L .3406 .67239 L p .707 .577 .707 r
F P
0 g
s
.34971 .64797 m .34257 .6109 L .37153 .60312 L p .707 .577 .707 r
F P
0 g
s
.3406 .67239 m .3439 .69095 L .32008 .69921 L p .707 .577 .707 r
F P
0 g
s
.43341 .59256 m .44055 .62963 L .40997 .63387 L p .707 .577 .707 r
F P
0 g
s
.40997 .63387 m .40283 .5968 L .43341 .59256 L p .707 .577 .707 r
F P
0 g
s
.45862 .65399 m .46192 .67256 L .43496 .67384 L p .707 .577 .707 r
F P
0 g
s
.43496 .67384 m .43166 .65528 L .45862 .65399 L p .707 .577 .707 r
F P
0 g
s
.37153 .60312 m .37867 .64019 L .34971 .64797 L p .707 .577 .707 r
F P
0 g
s
.37867 .64019 m .37153 .60312 L .40283 .5968 L p .707 .577 .707 r
F P
0 g
s
.40283 .5968 m .40997 .63387 L .37867 .64019 L p .707 .577 .707 r
F P
0 g
s
.3439 .69095 m .3406 .67239 L .36962 .66495 L p .707 .577 .707 r
F P
0 g
s
.36962 .66495 m .37292 .68351 L .3439 .69095 L p .707 .577 .707 r
F P
0 g
s
.43166 .65528 m .43496 .67384 L .4043 .67761 L p .707 .577 .707 r
F P
0 g
s
.4043 .67761 m .401 .65905 L .43166 .65528 L p .707 .577 .707 r
F P
0 g
s
.37292 .68351 m .36962 .66495 L .401 .65905 L p .707 .577 .707 r
F P
0 g
s
.401 .65905 m .4043 .67761 L .37292 .68351 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00Ngoo001`Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006ioo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00K7oo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06moo`00JWoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00JGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JWoo
001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Qoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008006Ioo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Aoo`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Ioo`00Ggoo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001HOol2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001FOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol8000mOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8001Uoo`T000AJEP04001JEUYFFUH6000gOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00D0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;goo001COol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
200015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20007Ool400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF20000UYF00L005YFFUIJEP00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF200025YF00<0
05YFFUH01EYF00<005YFFUH015YF1@000UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEPD0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF000015YF00<005YF00000`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005Aoo`03001JEP0000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Ao
o`04001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
4`0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH0000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00AWoo40000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003ioo`P000AJ
EP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00>7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEP00
00<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90008FUH70003FUH00`00FUIJEP02
000]Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH500000eYF0000000]Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0035oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP06001JEUYFFUH005YF
10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;Goo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH600000eYF001JEP03FUH00`00FUH0000]Ool002ioo`05001J
EUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP/0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH0
0`00FUIJEP0500000eYF0000000^Ool002eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPP000IJEP04001JEUYFFUH4000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00L005YF001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00FUH^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo
001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003
FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP03FUH40009FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00@005YFFUIJEP<00003FUH0
05YF00QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPH0009JEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEPH000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH015YF2@000eYF00<005YFFUH01@0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000=JEP05001JEUYFFUH00002FUH01000FUIJEP001eYF00<005YFFUH01UYF1`0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH01@00FUIJEUYF
00000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEQ400003FUH007oo02aoo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF1P001UYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH015YF
1P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000/
Ool002eoo`03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEPL000QJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002eo
o`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF009JEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUH0000/Ool002eoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEP0000800003FUH005YF00QJEP03001JEUYF
00AJEPH000YJEP03001JEUYF00=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEP<0
00=JEPH000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP8002eoo`00;Goo00<0
05YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
100015YF00<005YFFUH01eYF00<005YFFUH01@000eYF00<005YFFUH02EYF00<005YFFUH00`000eYF
00<005YF00000P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEP00008000IJEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002eoo`05001JEP00FUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH900000eYF001JEP05FUH00`00FUIJEP04FUH500000eYF
000000030002FUH00`00FUIJEP09FUH300000eYF001JEP04FUH01000FUH000002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF009JEP<00003
FUH005YF00MJEP03001JEUYF00EJEQD0031oo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00001P0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01000
15YF00<005YF000010000UYF00<005YFFUH01UYF0`0015YF00<005YFFUH00eYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001J
EP00008000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00
008002moo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF100000=JEP00FUH01EYF00<005YF000010000UYF
00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00003FUH40007FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030006FUH00`00FUIJ
EP06FUH20004FUH00`00FUH000030002FUH01000FUIJEP001UYF00<005YFFUH00`000eYF00<005YF
FUH00`0015YF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800006FUH005YFFUH005YF0P000eYF00<005YFFUH01EYF1@00
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo0P00
00=JEP00FUH015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF00<005YF0000
15YF0`001EYF00@005YFFUH000IJEP03001JEUYF00=JEPH000MJEP03001JEUYF00=JEP<000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP8000EJEP03
001JEUYF009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool0031oo`<000AJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0002FUH01000FUIJEP001EYF00@005YFFUH000AJEPP000AJEP03001JEUYF
00IJEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJEP02FUHC0002
FUH00`00Oomoo`0/Ool003=oo`<00005FUH00000FUH00008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUH000002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000AJEP00FUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEP/000aoo`H002ioo`00
=Goo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEPP0
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80009JEP8000EJEP03001JEUYF
00IJEP03001JEUYF00@0009JEP@000ioo`<0009JEP04001JEUYF000^Ool003=oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP@000MJEP03001JEUYF00AJ
EPX0011oo`800003FUH005YF00=JEP03001JEP0002ioo`00<Goo0`001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF1@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH020000goo0`00
3Woo0P000eYF00<005YFFUH00UYF0P00;goo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH010002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH015YF1P0027oo1@002Woo0`001EYF00<005YF
FUH00UYF00<007ooOol0;Woo000]Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40005FUH01000FUIJEUYF0P0000=JEP00FUH00`0027oo1@001Woo100000=JEP00FUH01UYF
00@005YFFUH0035oo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEPL000IJEQ@000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH01000FUH000000eYF
00<005YFFUH00P0027oo2`001EYF00<005YFFUH01EYF0`00<Woo000/Ool01@00FUIJEUYF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH40005FUH01000FUH005YF1Goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00=7oo
000/Ool01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEP04001JEP000003FUH00`00FUIJEP03FUH01@00FUIJEP00Ool010000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00=Woo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF000005YF018000IJEP03001JEUYF
00MJEP03001JEUYF00AJEP<003Yoo`00;Goo00@005YFFUH000AJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUHE0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
00000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04000mOol002eoo`04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP001UYF00<005YFFUH015YF2@00
00=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP0000000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH015YF1@00@Goo000]Ool01000FUIJEP0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF4`000UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH02UYF00<0
05YFFUH02EYF1`0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000AWoo000]Ool01@00FUIJEUYF
00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001:Ool002eoo`04001JEUYFFUH30004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF1@001eYF00<005YFFUH00UYF0P000UYF5P00DGoo000^Ool00`00FUIJEP020005FUH00`00
FUIJEP04FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00UYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1000
Dgoo000^Ool300000eYF001JEP04FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF0`0000=J
EP00FUH00eYF0P001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000005=oo`00;Woo0P00
0eYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF4P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EP0005=oo`00;goo0P000UYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH015YF1P0047oo
0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP8000IJEP03001JEUYF00AJEP03001JEUYF
00=JEP8005Aoo`00<Goo100015YF00<005YFFUH01eYF00<005YFFUH01@004goo0P0000=JEP000000
1EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF10001UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00<Goo0`001UYF00<005YFFUH015YF1@0000=oo`0000000`0047oo0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00004`00Egoo000_Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP040006Ool5000>Ool20002FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00H005YF000005YF0006FUH00`00FUIJEP03FUH00`00FUH00002001FOol002ioo`03
001JEUYF00=JEP03001JEUYF009JEP@000Yoo`D000Yoo`@000AJEP05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00=JEP05001JEUYFFUH0
001FOol002eoo`8000EJEP03001JEP00008000moo`<000Moo`@0009JEP03001JEUYF00AJEP03001J
EUYF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP00EWoo000/Ool00`00FUH00005FUH2000EOol70006FUH00`00FUIJ
EP04FUH30002Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF001FOol002aoo`04001JEUYF0002FUH2000?Ool80004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUH005YF40000eYF00<007ooOol0Dgoo000/Ool00`00FUIJEP040008Ool80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH000030009Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000<Ool400000eYF
001oo`1DOol002eoo`04001JEP000002FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`0<Ool30002FUH01000FUH00000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04000COol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P003Goo0P0000=JEP00FUH00eYF00<005YF0000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
000IOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH01000FUH000003Goo0P000eYF00<005YFFUH00UYF0P00EWoo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000QOol40008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH5000;Ool30005FUH00`00FUIJ
EP02FUH00`00Oomoo`1EOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF009J
EPH002Uoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
0003Ool0000000<000Ioo`@00003FUH005YF00IJEP04001JEUYF001HOol0031ooa@003Eoo`T000IJ
EP03001JEUYF00UJEP03001JEUYF00AJEPP000Ioo`D00003Ool0000000<000EJEP03001JEUYF00EJ
EP<005Uoo`00PWoo6@003Woo1P000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Fgoo002=Ool0
1@00FUIJEP00FUH00P0047oo2@0015YF00<005YFFUH01UYF00<005YF00000`00GGoo002>Ool00`00
FUH0000C0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001QOol008ioo`80009JEP03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006Aoo`00SWoo
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00J7oo
002>Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001]
Ool008moo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0075oo`00TGoo
5000N7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5991 .74892 m .59049 .69313 L .5597 .69616 L p .707 .577 .707 r
F P
0 g
s
.59049 .69313 m .5991 .74892 L .63059 .7437 L p .707 .577 .707 r
F P
0 g
s
.63059 .7437 m .62199 .68791 L .59049 .69313 L p .707 .577 .707 r
F P
0 g
s
.62199 .68791 m .63059 .7437 L .6597 .73679 L p .707 .577 .707 r
F P
0 g
s
.6597 .73679 m .6511 .68101 L .62199 .68791 L p .707 .577 .707 r
F P
0 g
s
.56831 .75195 m .5597 .69616 L .53263 .6967 L p .707 .577 .707 r
F P
0 g
s
.5597 .69616 m .56831 .75195 L .5991 .74892 L p .707 .577 .707 r
F P
0 g
s
.6511 .68101 m .6597 .73679 L .68358 .72888 L p .707 .577 .707 r
F P
0 g
s
.68358 .72888 m .67497 .67309 L .6511 .68101 L p .707 .577 .707 r
F P
0 g
s
.60344 .79796 m .59201 .76163 L .56238 .76963 L p .707 .577 .707 r
F P
0 g
s
.59201 .76163 m .60344 .79796 L .63388 .78826 L p .707 .577 .707 r
F P
0 g
s
.63388 .78826 m .62246 .75193 L .59201 .76163 L p .707 .577 .707 r
F P
0 g
s
.62246 .75193 m .63388 .78826 L .66216 .7778 L p .707 .577 .707 r
F P
0 g
s
.66216 .7778 m .65074 .74146 L .62246 .75193 L p .707 .577 .707 r
F P
0 g
s
.53263 .6967 m .54123 .75248 L .56831 .75195 L p .707 .577 .707 r
F P
0 g
s
.56238 .76963 m .57381 .80596 L .60344 .79796 L p .707 .577 .707 r
F P
0 g
s
.54123 .75248 m .53263 .6967 L .51191 .69469 L p .707 .577 .707 r
F P
0 g
s
.57381 .80596 m .56238 .76963 L .53646 .77513 L p .707 .577 .707 r
F P
0 g
s
.65074 .74146 m .66216 .7778 L .68551 .7676 L p .707 .577 .707 r
F P
0 g
s
.68551 .7676 m .67408 .73127 L .65074 .74146 L p .707 .577 .707 r
F P
0 g
s
.67497 .67309 m .68358 .72888 L .69989 .72073 L p .707 .577 .707 r
F P
0 g
s
.69989 .72073 m .69128 .66494 L .67497 .67309 L p .707 .577 .707 r
F P
0 g
s
.53646 .77513 m .54789 .81146 L .57381 .80596 L p .707 .577 .707 r
F P
0 g
s
.59466 .83567 m .58937 .81741 L .55951 .82466 L p .707 .577 .707 r
F P
0 g
s
.58937 .81741 m .59466 .83567 L .62531 .82664 L p .707 .577 .707 r
F P
0 g
s
.62531 .82664 m .62002 .80837 L .58937 .81741 L p .707 .577 .707 r
F P
0 g
s
.62002 .80837 m .62531 .82664 L .65375 .81671 L p .707 .577 .707 r
F P
0 g
s
.65375 .81671 m .64846 .79844 L .62002 .80837 L p .707 .577 .707 r
F P
0 g
s
.51191 .69469 m .52052 .75047 L .54123 .75248 L p .707 .577 .707 r
F P
0 g
s
.55951 .82466 m .5648 .84292 L .59466 .83567 L p .707 .577 .707 r
F P
0 g
s
.5648 .84292 m .55951 .82466 L .53337 .82942 L p .707 .577 .707 r
F P
0 g
s
.54789 .81146 m .53646 .77513 L .5168 .7776 L p .707 .577 .707 r
F P
0 g
s
.64846 .79844 m .65375 .81671 L .6772 .80685 L p .707 .577 .707 r
F P
0 g
s
.6772 .80685 m .67191 .78859 L .64846 .79844 L p .707 .577 .707 r
F P
0 g
s
.53337 .82942 m .53866 .84768 L .5648 .84292 L p .707 .577 .707 r
F P
0 g
s
.67408 .73127 m .68551 .7676 L .70163 .75866 L p .707 .577 .707 r
F P
0 g
s
.70163 .75866 m .69021 .72233 L .67408 .73127 L p .707 .577 .707 r
F P
0 g
s
.52052 .75047 m .51191 .69469 L .49959 .69033 L p .707 .577 .707 r
F P
0 g
s
.5168 .7776 m .52822 .81394 L .54789 .81146 L p .707 .577 .707 r
F P
0 g
s
.69128 .66494 m .69989 .72073 L .70703 .71314 L p .707 .577 .707 r
F P
0 g
s
.70703 .71314 m .69843 .65736 L .69128 .66494 L p .707 .577 .707 r
F P
0 g
s
.49959 .69033 m .5082 .74611 L .52052 .75047 L p .707 .577 .707 r
F P
0 g
s
.53866 .84768 m .53337 .82942 L .5135 .83122 L p .707 .577 .707 r
F P
0 g
s
.5135 .83122 m .51879 .84949 L .53866 .84768 L p .707 .577 .707 r
F P
0 g
s
.67191 .78859 m .6772 .80685 L .69336 .79803 L p .707 .577 .707 r
F P
0 g
s
.69336 .79803 m .68807 .77977 L .67191 .78859 L p .707 .577 .707 r
F P
0 g
s
.52822 .81394 m .5168 .7776 L .50531 .7768 L p .707 .577 .707 r
F P
0 g
s
.69021 .72233 m .70163 .75866 L .70896 .75187 L p .707 .577 .707 r
F P
0 g
s
.70896 .75187 m .69753 .71553 L .69021 .72233 L p .707 .577 .707 r
F P
0 g
s
.50531 .7768 m .51673 .81314 L .52822 .81394 L p .707 .577 .707 r
F P
0 g
s
.5082 .74611 m .49959 .69033 L .49687 .68405 L p .707 .577 .707 r
F P
0 g
s
.51879 .84949 m .5135 .83122 L .50185 .82989 L p .707 .577 .707 r
F P
0 g
s
.69843 .65736 m .70703 .71314 L .70431 .70687 L p .707 .577 .707 r
F P
0 g
s
.70431 .70687 m .6957 .65108 L .69843 .65736 L p .707 .577 .707 r
F P
0 g
s
.50185 .82989 m .50714 .84816 L .51879 .84949 L p .707 .577 .707 r
F P
0 g
s
.49687 .68405 m .50548 .73984 L .5082 .74611 L p .707 .577 .707 r
F P
0 g
s
.68807 .77977 m .69336 .79803 L .70065 .79112 L p .707 .577 .707 r
F P
0 g
s
.70065 .79112 m .69536 .77285 L .68807 .77977 L p .707 .577 .707 r
F P
0 g
s
.47109 .82196 m .50148 .32433 L .45756 .31896 L p .707 .577 .707 r
F P
0 g
s
.51673 .81314 m .50531 .7768 L .50312 .77281 L p .707 .577 .707 r
F P
0 g
s
.50312 .77281 m .51454 .80914 L .51673 .81314 L p .707 .577 .707 r
F P
0 g
s
.50548 .73984 m .49687 .68405 L .50401 .67647 L p .707 .577 .707 r
F P
0 g
s
.50401 .67647 m .51262 .73225 L .50548 .73984 L p .707 .577 .707 r
F P
0 g
s
.51454 .80914 m .50312 .77281 L .51045 .76601 L p .707 .577 .707 r
F P
0 g
s
.51045 .76601 m .52187 .80235 L .51454 .80914 L p .707 .577 .707 r
F P
0 g
s
.51262 .73225 m .50401 .67647 L .52032 .66832 L p .707 .577 .707 r
F P
0 g
s
.50714 .84816 m .50185 .82989 L .49956 .82556 L p .707 .577 .707 r
F P
0 g
s
.49956 .82556 m .50485 .84382 L .50714 .84816 L p .707 .577 .707 r
F P
0 g
s
.50485 .84382 m .49956 .82556 L .50685 .81864 L p .707 .577 .707 r
F P
0 g
s
.50685 .81864 m .51214 .83691 L .50485 .84382 L p .707 .577 .707 r
F P
0 g
s
.52032 .66832 m .52893 .72411 L .51262 .73225 L p .707 .577 .707 r
F P
0 g
s
.52187 .80235 m .51045 .76601 L .52657 .75708 L p .707 .577 .707 r
F P
0 g
s
.51214 .83691 m .50685 .81864 L .52301 .80983 L p .707 .577 .707 r
F P
0 g
s
.50148 .32433 m .47109 .82196 L .51596 .82329 L p .707 .577 .707 r
F P
0 g
s
.52893 .72411 m .52032 .66832 L .5442 .66041 L p .707 .577 .707 r
F P
0 g
s
.51596 .82329 m .54635 .32566 L .50148 .32433 L p .707 .577 .707 r
F P
0 g
s
.52657 .75708 m .538 .79341 L .52187 .80235 L p .707 .577 .707 r
F P
0 g
s
.5442 .66041 m .55281 .71619 L .52893 .72411 L p .707 .577 .707 r
F P
0 g
s
.52301 .80983 m .52831 .82809 L .51214 .83691 L p .707 .577 .707 r
F P
0 g
s
.55281 .71619 m .5442 .66041 L .57331 .6535 L p .707 .577 .707 r
F P
0 g
s
.538 .79341 m .52657 .75708 L .54992 .74688 L p .707 .577 .707 r
F P
0 g
s
.54992 .74688 m .56134 .78321 L .538 .79341 L p .707 .577 .707 r
F P
0 g
s
.57331 .6535 m .58192 .70928 L .55281 .71619 L p .707 .577 .707 r
F P
0 g
s
.52831 .82809 m .52301 .80983 L .54646 .79997 L p .707 .577 .707 r
F P
0 g
s
.54646 .79997 m .55175 .81823 L .52831 .82809 L p .707 .577 .707 r
F P
0 g
s
.56134 .78321 m .54992 .74688 L .5782 .73642 L p .707 .577 .707 r
F P
0 g
s
.55175 .81823 m .54646 .79997 L .5749 .79004 L p .707 .577 .707 r
F P
0 g
s
.5749 .79004 m .58019 .8083 L .55175 .81823 L p .707 .577 .707 r
F P
0 g
s
.54635 .32566 m .51596 .82329 L .55738 .82045 L p .707 .577 .707 r
F P
0 g
s
.55738 .82045 m .58778 .32281 L .54635 .32566 L p .707 .577 .707 r
F P
0 g
s
.42716 .81659 m .45756 .31896 L .41887 .31007 L p .707 .577 .707 r
F P
0 g
s
.45756 .31896 m .42716 .81659 L .47109 .82196 L p .707 .577 .707 r
F P
0 g
s
.69753 .71553 m .70896 .75187 L .70677 .74787 L p .707 .577 .707 r
F P
0 g
s
.70677 .74787 m .69535 .71154 L .69753 .71553 L p .707 .577 .707 r
F P
0 g
s
.58192 .70928 m .57331 .6535 L .6048 .64828 L p .707 .577 .707 r
F P
0 g
s
.6048 .64828 m .61341 .70406 L .58192 .70928 L p .707 .577 .707 r
F P
0 g
s
.5782 .73642 m .58962 .77275 L .56134 .78321 L p .707 .577 .707 r
F P
0 g
s
.58962 .77275 m .5782 .73642 L .60864 .72671 L p .707 .577 .707 r
F P
0 g
s
.60864 .72671 m .62007 .76305 L .58962 .77275 L p .707 .577 .707 r
F P
0 g
s
.58019 .8083 m .5749 .79004 L .60555 .781 L p .707 .577 .707 r
F P
0 g
s
.60555 .781 m .61084 .79927 L .58019 .8083 L p .707 .577 .707 r
F P
0 g
s
.58778 .32281 m .55738 .82045 L .5913 .81371 L p .707 .577 .707 r
F P
0 g
s
.5913 .81371 m .6217 .31607 L .58778 .32281 L p .707 .577 .707 r
F P
0 g
s
.6957 .65108 m .70431 .70687 L .69199 .70251 L p .707 .577 .707 r
F P
0 g
s
.69199 .70251 m .68338 .64673 L .6957 .65108 L p .707 .577 .707 r
F P
0 g
s
.69536 .77285 m .70065 .79112 L .69836 .78678 L p .707 .577 .707 r
F P
0 g
s
.69836 .78678 m .69307 .76852 L .69536 .77285 L p .707 .577 .707 r
F P
0 g
s
.38848 .8077 m .41887 .31007 L .38922 .29853 L p .707 .577 .707 r
F P
0 g
s
.41887 .31007 m .38848 .8077 L .42716 .81659 L p .707 .577 .707 r
F P
0 g
s
.25609 .7034 m .24749 .64762 L .21669 .65064 L p .707 .577 .707 r
F P
0 g
s
.24749 .64762 m .25609 .7034 L .28758 .69818 L p .707 .577 .707 r
F P
0 g
s
.28758 .69818 m .27898 .6424 L .24749 .64762 L p .707 .577 .707 r
F P
0 g
s
.27898 .6424 m .28758 .69818 L .31669 .69127 L p .707 .577 .707 r
F P
0 g
s
.31669 .69127 m .30809 .63549 L .27898 .6424 L p .707 .577 .707 r
F P
0 g
s
.69535 .71154 m .70677 .74787 L .69528 .74707 L p .707 .577 .707 r
F P
0 g
s
.69528 .74707 m .68386 .71074 L .69535 .71154 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2253 .70643 m .21669 .65064 L .18962 .65118 L p .707 .577 .707 r
F P
0 g
s
.21669 .65064 m .2253 .70643 L .25609 .7034 L p .707 .577 .707 r
F P
0 g
s
.30809 .63549 m .31669 .69127 L .34057 .68336 L p .707 .577 .707 r
F P
0 g
s
.34057 .68336 m .33196 .62757 L .30809 .63549 L p .707 .577 .707 r
F P
0 g
s
.63559 .64525 m .6442 .70104 L .61341 .70406 L p .707 .577 .707 r
F P
0 g
s
.61341 .70406 m .6048 .64828 L .63559 .64525 L p .707 .577 .707 r
F P
0 g
s
.62007 .76305 m .60864 .72671 L .63827 .71872 L p .707 .577 .707 r
F P
0 g
s
.63541 .77375 m .6407 .79201 L .61084 .79927 L p .707 .577 .707 r
F P
0 g
s
.61084 .79927 m .60555 .781 L .63541 .77375 L p .707 .577 .707 r
F P
0 g
s
.6217 .31607 m .5913 .81371 L .6144 .80373 L p .707 .577 .707 r
F P
0 g
s
.6144 .80373 m .64479 .3061 L .6217 .31607 L p .707 .577 .707 r
F P
0 g
s
.68338 .64673 m .69199 .70251 L .67128 .7005 L p .707 .577 .707 r
F P
0 g
s
.67128 .7005 m .66267 .64472 L .68338 .64673 L p .707 .577 .707 r
F P
0 g
s
.18962 .65118 m .19822 .70696 L .2253 .70643 L p .707 .577 .707 r
F P
0 g
s
.26043 .7651 m .249 .72876 L .21937 .73676 L p .707 .577 .707 r
F P
0 g
s
.249 .72876 m .26043 .7651 L .29087 .75539 L p .707 .577 .707 r
F P
0 g
s
.29087 .75539 m .27945 .71906 L .249 .72876 L p .707 .577 .707 r
F P
0 g
s
.27945 .71906 m .29087 .75539 L .31915 .74493 L p .707 .577 .707 r
F P
0 g
s
.31915 .74493 m .30773 .7086 L .27945 .71906 L p .707 .577 .707 r
F P
0 g
s
.69307 .76852 m .69836 .78678 L .68671 .78545 L p .707 .577 .707 r
F P
0 g
s
.68671 .78545 m .68142 .76719 L .69307 .76852 L p .707 .577 .707 r
F P
0 g
s
.19822 .70696 m .18962 .65118 L .1689 .64917 L p .707 .577 .707 r
F P
0 g
s
.21937 .73676 m .2308 .77309 L .26043 .7651 L p .707 .577 .707 r
F P
0 g
s
.34827 .61943 m .35688 .67521 L .35886 .67311 L p .707 .577 .707 r
F P
0 g
s
.35886 .67311 m .36402 .66763 L p .35871 .65137 L .707 .577 .707 r
F P
0 g
s
.35871 .65137 m .34827 .61943 L .35886 .67311 L .707 .577 .707 r
F
.3715 .28547 m .36745 .27218 L p .35747 .46585 L F P
0 g
s
.33196 .62757 m .34057 .68336 L .35688 .67521 L p .707 .577 .707 r
F P
0 g
s
.35688 .67521 m .34827 .61943 L .33196 .62757 L p .707 .577 .707 r
F P
0 g
s
.33107 .6984 m .3425 .73473 L .35862 .7258 L p .707 .577 .707 r
F P
0 g
s
.35862 .7258 m .3472 .68946 L .33107 .6984 L p .707 .577 .707 r
F P
0 g
s
.36402 .66763 m .35542 .61184 L .34827 .61943 L p .707 .577 .707 r
F P
0 g
s
.3289 .76464 m .33419 .78291 L .35035 .77409 L p .707 .577 .707 r
F P
0 g
s
.35035 .77409 m .34506 .75583 L .3289 .76464 L p .707 .577 .707 r
F P
0 g
s
.34898 .65699 m .34038 .60121 L .35269 .60556 L p .707 .577 .707 r
F P
0 g
s
.3472 .68946 m .35862 .7258 L .36595 .719 L p .707 .577 .707 r
F P
0 g
s
.36595 .719 m .35452 .68266 L .3472 .68946 L p .707 .577 .707 r
F P
0 g
s
.35227 .71421 m .3482 .70124 L p .35234 .67867 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .34085 .67787 L .3523 .67867 L p .707 .577 .707 r
F P
0 g
s
.3523 .67867 m .35234 .67867 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.34038 .60121 m .34898 .65699 L .32827 .65498 L p .707 .577 .707 r
F P
0 g
s
.3425 .73473 m .33107 .6984 L .30773 .7086 L p .707 .577 .707 r
F P
0 g
s
.34085 .67787 m .3482 .70124 L p .33261 .71668 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .35227 .71421 L .34688 .71488 L p .707 .577 .707 r
F P
0 g
s
.34688 .71488 m .33261 .71668 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.30773 .7086 m .31915 .74493 L .3425 .73473 L p .707 .577 .707 r
F P
0 g
s
.34506 .75583 m .35035 .77409 L .35764 .76717 L p .707 .577 .707 r
F P
0 g
s
.35764 .76717 m .35235 .74891 L .34506 .75583 L p .707 .577 .707 r
F P
0 g
s
.3437 .76151 m .33841 .74324 L .35006 .74458 L p .707 .577 .707 r
F P
0 g
s
.33841 .74324 m .3437 .76151 L .32383 .76331 L p .707 .577 .707 r
F P
0 g
s
.36745 .27218 m .33706 .76981 L .3405 .78112 L p .707 .577 .707 r
F P
0 g
s
.3405 .78112 m .34111 .78311 L p .34203 .76528 L .707 .577 .707 r
F P
0 g
s
.34203 .76528 m .36745 .27218 L .3405 .78112 L .707 .577 .707 r
F
.34419 .72326 m .35776 .5104 L .35747 .46585 L F
.34111 .78311 m .34505 .71855 L p .34419 .72326 L F P
0 g
s
.34505 .71855 m .35776 .5104 L p .34419 .72326 L .707 .577 .707 r
F P
0 g
s
.35776 .5104 m .3715 .28547 L p .35747 .46585 L .707 .577 .707 r
F P
0 g
s
.35542 .61184 m .36402 .66763 L .3613 .66135 L p .707 .577 .707 r
F P
0 g
s
.35452 .68266 m .36595 .719 L .36376 .715 L p .707 .577 .707 r
F P
0 g
s
.36376 .715 m .35234 .67867 L .35452 .68266 L p .707 .577 .707 r
F P
0 g
s
.35234 .67867 m .36376 .715 L .35227 .71421 L p .707 .577 .707 r
F P
0 g
s
.35883 .79616 m .38922 .29853 L .3715 .28547 L p .707 .577 .707 r
F P
0 g
s
.38922 .29853 m .35883 .79616 L .38848 .8077 L p .707 .577 .707 r
F P
0 g
s
.2308 .77309 m .21937 .73676 L .19345 .74226 L p .707 .577 .707 r
F P
0 g
s
.19345 .74226 m .20488 .7786 L .2308 .77309 L p .707 .577 .707 r
F P
0 g
s
.1689 .64917 m .17751 .70495 L .19822 .70696 L p .707 .577 .707 r
F P
0 g
s
.68386 .71074 m .69528 .74707 L .67562 .74955 L p .707 .577 .707 r
F P
0 g
s
.67562 .74955 m .66419 .71321 L .68386 .71074 L p .707 .577 .707 r
F P
0 g
s
.25165 .81173 m .24636 .79347 L .21651 .80072 L p .707 .577 .707 r
F P
0 g
s
.24636 .79347 m .25165 .81173 L .2823 .8027 L p .707 .577 .707 r
F P
0 g
s
.2823 .8027 m .27701 .78443 L .24636 .79347 L p .707 .577 .707 r
F P
0 g
s
.27701 .78443 m .2823 .8027 L .31074 .79276 L p .707 .577 .707 r
F P
0 g
s
.31074 .79276 m .30545 .7745 L .27701 .78443 L p .707 .577 .707 r
F P
0 g
s
.21651 .80072 m .2218 .81898 L .25165 .81173 L p .707 .577 .707 r
F P
0 g
s
.66267 .64472 m .67128 .7005 L .6442 .70104 L p .707 .577 .707 r
F P
0 g
s
.6442 .70104 m .63559 .64525 L .66267 .64472 L p .707 .577 .707 r
F P
0 g
s
.20488 .7786 m .19345 .74226 L .17379 .74473 L p .707 .577 .707 r
F P
0 g
s
.17751 .70495 m .1689 .64917 L .15658 .64481 L p .707 .577 .707 r
F P
0 g
s
.2218 .81898 m .21651 .80072 L .19036 .80548 L p .707 .577 .707 r
F P
0 g
s
.30545 .7745 m .31074 .79276 L .33419 .78291 L p .707 .577 .707 r
F P
0 g
s
.33419 .78291 m .3289 .76464 L .30545 .7745 L p .707 .577 .707 r
F P
0 g
s
.19036 .80548 m .19565 .82374 L .2218 .81898 L p .707 .577 .707 r
F P
0 g
s
.17379 .74473 m .18521 .78107 L .20488 .7786 L p .707 .577 .707 r
F P
0 g
s
.68142 .76719 m .68671 .78545 L .66684 .78725 L p .707 .577 .707 r
F P
0 g
s
.66684 .78725 m .66155 .76899 L .68142 .76719 L p .707 .577 .707 r
F P
0 g
s
.63827 .71872 m .6497 .75505 L .62007 .76305 L p .707 .577 .707 r
F P
0 g
s
.64479 .3061 m .6144 .80373 L .62441 .7915 L p .707 .577 .707 r
F P
0 g
s
.62441 .7915 m .6548 .29386 L .64479 .3061 L p .707 .577 .707 r
F P
0 g
s
.15658 .64481 m .16519 .7006 L .17751 .70495 L p .707 .577 .707 r
F P
0 g
s
.66419 .71321 m .67562 .74955 L .6497 .75505 L p .707 .577 .707 r
F P
0 g
s
.6497 .75505 m .63827 .71872 L .66419 .71321 L p .707 .577 .707 r
F P
0 g
s
.19565 .82374 m .19036 .80548 L .1705 .80728 L p .707 .577 .707 r
F P
0 g
s
.3613 .66135 m .35269 .60556 L .35542 .61184 L p .707 .577 .707 r
F P
0 g
s
.35269 .60556 m .3613 .66135 L .34898 .65699 L p .707 .577 .707 r
F P
0 g
s
.35235 .74891 m .35764 .76717 L .35535 .76284 L p .707 .577 .707 r
F P
0 g
s
.35535 .76284 m .35006 .74458 L .35235 .74891 L p .707 .577 .707 r
F P
0 g
s
.35006 .74458 m .35535 .76284 L .3437 .76151 L p .707 .577 .707 r
F P
0 g
s
.3715 .28547 m .34111 .78311 L .35883 .79616 L p .707 .577 .707 r
F P
0 g
s
.1705 .80728 m .17579 .82554 L .19565 .82374 L p .707 .577 .707 r
F P
0 g
s
.18521 .78107 m .17379 .74473 L .1623 .74394 L p .707 .577 .707 r
F P
0 g
s
.16519 .7006 m .15658 .64481 L .15386 .63854 L p .707 .577 .707 r
F P
0 g
s
.66155 .76899 m .66684 .78725 L .6407 .79201 L p .707 .577 .707 r
F P
0 g
s
.6407 .79201 m .63541 .77375 L .66155 .76899 L p .707 .577 .707 r
F P
0 g
s
.1623 .74394 m .17372 .78027 L .18521 .78107 L p .707 .577 .707 r
F P
0 g
s
.15386 .63854 m .16247 .69432 L .16519 .7006 L p .707 .577 .707 r
F P
0 g
s
.17579 .82554 m .1705 .80728 L .15884 .80595 L p .707 .577 .707 r
F P
0 g
s
.15884 .80595 m .16414 .82421 L .17579 .82554 L p .707 .577 .707 r
F P
0 g
s
.6548 .29386 m .62441 .7915 L .62036 .7782 L p .707 .577 .707 r
F P
0 g
s
.62036 .7782 m .65075 .28057 L .6548 .29386 L p .707 .577 .707 r
F P
0 g
s
.17372 .78027 m .1623 .74394 L .16011 .73994 L p .707 .577 .707 r
F P
0 g
s
.16011 .73994 m .17154 .77628 L .17372 .78027 L p .707 .577 .707 r
F P
0 g
s
.16247 .69432 m .15386 .63854 L .16101 .63095 L p .707 .577 .707 r
F P
0 g
s
.33706 .76981 m .36745 .27218 L .37746 .25994 L p .707 .577 .707 r
F P
0 g
s
.16101 .63095 m .16961 .68674 L .16247 .69432 L p .707 .577 .707 r
F P
0 g
s
.16414 .82421 m .15884 .80595 L .15655 .80161 L p .707 .577 .707 r
F P
0 g
s
.15655 .80161 m .16184 .81988 L .16414 .82421 L p .707 .577 .707 r
F P
0 g
s
.17154 .77628 m .16011 .73994 L .16744 .73314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16961 .68674 m .16101 .63095 L .17731 .6228 L p .707 .577 .707 r
F P
0 g
s
.65075 .28057 m .62036 .7782 L .60264 .76515 L p .707 .577 .707 r
F P
0 g
s
.60264 .76515 m .63303 .26751 L .65075 .28057 L p .707 .577 .707 r
F P
0 g
s
.16744 .73314 m .17886 .76948 L .17154 .77628 L p .707 .577 .707 r
F P
0 g
s
.32827 .65498 m .31966 .5992 L .34038 .60121 L p .707 .577 .707 r
F P
0 g
s
.17731 .6228 m .18592 .67859 L .16961 .68674 L p .707 .577 .707 r
F P
0 g
s
.34707 .75758 m .37746 .25994 L .40056 .24997 L p .707 .577 .707 r
F P
0 g
s
.37746 .25994 m .34707 .75758 L .33706 .76981 L p .707 .577 .707 r
F P
0 g
s
.16184 .81988 m .15655 .80161 L .16384 .7947 L p .707 .577 .707 r
F P
0 g
s
.16384 .7947 m .16914 .81296 L .16184 .81988 L p .707 .577 .707 r
F P
0 g
s
.17886 .76948 m .16744 .73314 L .18356 .72421 L p .707 .577 .707 r
F P
0 g
s
.18592 .67859 m .17731 .6228 L .20119 .61489 L p .707 .577 .707 r
F P
0 g
s
.33261 .71668 m .32118 .68034 L .34085 .67787 L p .707 .577 .707 r
F P
0 g
s
.18356 .72421 m .19499 .76054 L .17886 .76948 L p .707 .577 .707 r
F P
0 g
s
.31966 .5992 m .32827 .65498 L .30119 .65552 L p .707 .577 .707 r
F P
0 g
s
.30119 .65552 m .29259 .59973 L .31966 .5992 L p .707 .577 .707 r
F P
0 g
s
.20119 .61489 m .2098 .67067 L .18592 .67859 L p .707 .577 .707 r
F P
0 g
s
.63303 .26751 m .60264 .76515 L .57299 .75361 L p .707 .577 .707 r
F P
0 g
s
.57299 .75361 m .60338 .25597 L .63303 .26751 L p .707 .577 .707 r
F P
0 g
s
.16914 .81296 m .16384 .7947 L .18001 .78588 L p .707 .577 .707 r
F P
0 g
s
.2098 .67067 m .20119 .61489 L .2303 .60798 L p .707 .577 .707 r
F P
0 g
s
.18001 .78588 m .1853 .80415 L .16914 .81296 L p .707 .577 .707 r
F P
0 g
s
.32383 .76331 m .31854 .74505 L .33841 .74324 L p .707 .577 .707 r
F P
0 g
s
.40056 .24997 m .37016 .7476 L .34707 .75758 L p .707 .577 .707 r
F P
0 g
s
.37016 .7476 m .40056 .24997 L .43448 .24323 L p .707 .577 .707 r
F P
0 g
s
.29259 .59973 m .30119 .65552 L .2704 .65854 L p .707 .577 .707 r
F P
0 g
s
.2704 .65854 m .26179 .60276 L .29259 .59973 L p .707 .577 .707 r
F P
0 g
s
.19499 .76054 m .18356 .72421 L .20691 .71401 L p .707 .577 .707 r
F P
0 g
s
.32118 .68034 m .33261 .71668 L .30669 .72218 L p .707 .577 .707 r
F P
0 g
s
.30669 .72218 m .29526 .68585 L .32118 .68034 L p .707 .577 .707 r
F P
0 g
s
.23891 .66377 m .2303 .60798 L .26179 .60276 L p .707 .577 .707 r
F P
0 g
s
.2303 .60798 m .23891 .66377 L .2098 .67067 L p .707 .577 .707 r
F P
0 g
s
.20691 .71401 m .21833 .75034 L .19499 .76054 L p .707 .577 .707 r
F P
0 g
s
.26179 .60276 m .2704 .65854 L .23891 .66377 L p .707 .577 .707 r
F P
0 g
s
.7363 .65688 m .7277 .6011 L .69691 .60412 L p .707 .577 .707 r
F P
0 g
s
.7277 .6011 m .7363 .65688 L .7678 .65166 L p .707 .577 .707 r
F P
0 g
s
.7678 .65166 m .75919 .59587 L .7277 .6011 L p .707 .577 .707 r
F P
0 g
s
.75919 .59587 m .7678 .65166 L .79691 .64475 L p .707 .577 .707 r
F P
0 g
s
.79691 .64475 m .7883 .58897 L .75919 .59587 L p .707 .577 .707 r
F P
0 g
s
.70551 .65991 m .69691 .60412 L .66983 .60466 L p .707 .577 .707 r
F P
0 g
s
.69691 .60412 m .70551 .65991 L .7363 .65688 L p .707 .577 .707 r
F P
0 g
s
.1853 .80415 m .18001 .78588 L .20345 .77603 L p .707 .577 .707 r
F P
0 g
s
.21833 .75034 m .20691 .71401 L .23519 .70355 L p .707 .577 .707 r
F P
0 g
s
.60338 .25597 m .57299 .75361 L .5343 .74472 L p .707 .577 .707 r
F P
0 g
s
.5343 .74472 m .5647 .24708 L .60338 .25597 L p .707 .577 .707 r
F P
0 g
s
.20345 .77603 m .20874 .79429 L .1853 .80415 L p .707 .577 .707 r
F P
0 g
s
.7883 .58897 m .79691 .64475 L .82078 .63684 L p .707 .577 .707 r
F P
0 g
s
.82078 .63684 m .81218 .58105 L .7883 .58897 L p .707 .577 .707 r
F P
0 g
s
.29526 .68585 m .30669 .72218 L .27706 .73018 L p .707 .577 .707 r
F P
0 g
s
.27706 .73018 m .26563 .69384 L .29526 .68585 L p .707 .577 .707 r
F P
0 g
s
.31854 .74505 m .32383 .76331 L .29769 .76807 L p .707 .577 .707 r
F P
0 g
s
.29769 .76807 m .2924 .74981 L .31854 .74505 L p .707 .577 .707 r
F P
0 g
s
.23519 .70355 m .24661 .73988 L .21833 .75034 L p .707 .577 .707 r
F P
0 g
s
.74064 .70593 m .72922 .66959 L .69958 .67759 L p .707 .577 .707 r
F P
0 g
s
.72922 .66959 m .74064 .70593 L .77109 .69622 L p .707 .577 .707 r
F P
0 g
s
.77109 .69622 m .75966 .65989 L .72922 .66959 L p .707 .577 .707 r
F P
0 g
s
.40408 .74086 m .43448 .24323 L .4759 .24038 L p .707 .577 .707 r
F P
0 g
s
.43448 .24323 m .40547 .71822 L p .37016 .7476 L .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .44551 .73802 L .40408 .74086 L p .707 .577 .707 r
F P
0 g
s
.38621 .63672 m .39763 .67306 L .41973 .66601 L p .707 .577 .707 r
F P
0 g
s
.41973 .66601 m .42808 .66335 L p .42159 .65923 L .707 .577 .707 r
F P
0 g
s
.42159 .65923 m .38621 .63672 L .41973 .66601 L .707 .577 .707 r
F
.40547 .71822 m .40408 .74086 L .399 .74187 L p F P
0 g
s
.399 .74187 m .37016 .7476 L p .40547 .71822 L .707 .577 .707 r
F P
0 g
s
.75966 .65989 m .77109 .69622 L .79937 .68576 L p .707 .577 .707 r
F P
0 g
s
.79937 .68576 m .78794 .64943 L .75966 .65989 L p .707 .577 .707 r
F P
0 g
s
.66983 .60466 m .67844 .66044 L .70551 .65991 L p .707 .577 .707 r
F P
0 g
s
.24661 .73988 m .23519 .70355 L .26563 .69384 L p .707 .577 .707 r
F P
0 g
s
.26563 .69384 m .27706 .73018 L .24661 .73988 L p .707 .577 .707 r
F P
0 g
s
.69958 .67759 m .71101 .71392 L .74064 .70593 L p .707 .577 .707 r
F P
0 g
s
.67844 .66044 m .66983 .60466 L .64912 .60265 L p .707 .577 .707 r
F P
0 g
s
.71101 .71392 m .69958 .67759 L .67367 .68309 L p .707 .577 .707 r
F P
0 g
s
.20874 .79429 m .20345 .77603 L .23189 .76609 L p .707 .577 .707 r
F P
0 g
s
.78794 .64943 m .79937 .68576 L .82271 .67556 L p .707 .577 .707 r
F P
0 g
s
.82271 .67556 m .81129 .63923 L .78794 .64943 L p .707 .577 .707 r
F P
0 g
s
.2924 .74981 m .29769 .76807 L .26783 .77532 L p .707 .577 .707 r
F P
0 g
s
.26783 .77532 m .26254 .75706 L .2924 .74981 L p .707 .577 .707 r
F P
0 g
s
.23189 .76609 m .23718 .78436 L .20874 .79429 L p .707 .577 .707 r
F P
0 g
s
.5647 .24708 m .5343 .74472 L .49038 .73935 L p .707 .577 .707 r
F P
0 g
s
.49038 .73935 m .52077 .24171 L .5647 .24708 L p .707 .577 .707 r
F P
0 g
s
.81218 .58105 m .82078 .63684 L .83709 .62869 L p .707 .577 .707 r
F P
0 g
s
.83709 .62869 m .82849 .57291 L .81218 .58105 L p .707 .577 .707 r
F P
0 g
s
.67367 .68309 m .68509 .71943 L .71101 .71392 L p .707 .577 .707 r
F P
0 g
s
.73187 .74363 m .72657 .72537 L .69672 .73262 L p .707 .577 .707 r
F P
0 g
s
.72657 .72537 m .73187 .74363 L .76251 .7346 L p .707 .577 .707 r
F P
0 g
s
.76251 .7346 m .75722 .71634 L .72657 .72537 L p .707 .577 .707 r
F P
0 g
s
.75722 .71634 m .76251 .7346 L .79095 .72467 L p .707 .577 .707 r
F P
0 g
s
.79095 .72467 m .78566 .7064 L .75722 .71634 L p .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .52077 .24171 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.44982 .66746 m .4759 .24038 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.41665 .62702 m .41959 .63637 L p .45636 .65289 L .707 .577 .707 r
F P
0 g
s
.41959 .63637 m .42808 .66335 L .44113 .65852 L p .707 .577 .707 r
F P
0 g
s
.44113 .65852 m .45636 .65289 L p .41959 .63637 L .707 .577 .707 r
F P
0 g
s
.44589 .73172 m .44982 .66746 L p .44638 .73227 L .707 .577 .707 r
F P
0 g
s
.41421 .69239 m .41583 .69798 L p .44794 .70073 L .707 .577 .707 r
F P
0 g
s
.41583 .69798 m .4195 .71066 L .42532 .70863 L p .707 .577 .707 r
F P
0 g
s
.42532 .70863 m .44794 .70073 L p .41583 .69798 L .707 .577 .707 r
F P
0 g
s
.44638 .73227 m .44982 .66746 L .45534 .67314 L .707 .577 .707 r
F
.44551 .73802 m .44589 .73172 L p .44638 .73227 L F P
0 g
s
.64912 .60265 m .65772 .65843 L .67844 .66044 L p .707 .577 .707 r
F P
0 g
s
.69672 .73262 m .70201 .75089 L .73187 .74363 L p .707 .577 .707 r
F P
0 g
s
.23718 .78436 m .23189 .76609 L .26254 .75706 L p .707 .577 .707 r
F P
0 g
s
.26254 .75706 m .26783 .77532 L .23718 .78436 L p .707 .577 .707 r
F P
0 g
s
.52077 .24171 m .49038 .73935 L .44551 .73802 L p .707 .577 .707 r
F P
0 g
s
.70201 .75089 m .69672 .73262 L .67058 .73738 L p .707 .577 .707 r
F P
0 g
s
.68509 .71943 m .67367 .68309 L .654 .68556 L p .707 .577 .707 r
F P
0 g
s
.78566 .7064 m .79095 .72467 L .8144 .71481 L p .707 .577 .707 r
F P
0 g
s
.8144 .71481 m .80911 .69655 L .78566 .7064 L p .707 .577 .707 r
F P
0 g
s
.67058 .73738 m .67587 .75565 L .70201 .75089 L p .707 .577 .707 r
F P
0 g
s
.81129 .63923 m .82271 .67556 L .83884 .66663 L p .707 .577 .707 r
F P
0 g
s
.83884 .66663 m .82741 .63029 L .81129 .63923 L p .707 .577 .707 r
F P
0 g
s
.65772 .65843 m .64912 .60265 L .6368 .59829 L p .707 .577 .707 r
F P
0 g
s
.654 .68556 m .66543 .7219 L .68509 .71943 L p .707 .577 .707 r
F P
0 g
s
.82849 .57291 m .83709 .62869 L .84424 .62111 L p .707 .577 .707 r
F P
0 g
s
.84424 .62111 m .83563 .56532 L .82849 .57291 L p .707 .577 .707 r
F P
0 g
s
.6368 .59829 m .6454 .65408 L .65772 .65843 L p .707 .577 .707 r
F P
0 g
s
.67587 .75565 m .67058 .73738 L .65071 .73919 L p .707 .577 .707 r
F P
0 g
s
.65071 .73919 m .656 .75745 L .67587 .75565 L p .707 .577 .707 r
F P
0 g
s
.80911 .69655 m .8144 .71481 L .83056 .70599 L p .707 .577 .707 r
F P
0 g
s
.83056 .70599 m .82527 .68773 L .80911 .69655 L p .707 .577 .707 r
F P
0 g
s
.66543 .7219 m .654 .68556 L .64251 .68477 L p .707 .577 .707 r
F P
0 g
s
.82741 .63029 m .83884 .66663 L .84616 .65983 L p .707 .577 .707 r
F P
0 g
s
.84616 .65983 m .83474 .62349 L .82741 .63029 L p .707 .577 .707 r
F P
0 g
s
.64251 .68477 m .65394 .7211 L .66543 .7219 L p .707 .577 .707 r
F P
0 g
s
.6454 .65408 m .6368 .59829 L .63408 .59201 L p .707 .577 .707 r
F P
0 g
s
.656 .75745 m .65071 .73919 L .63906 .73785 L p .707 .577 .707 r
F P
0 g
s
.83563 .56532 m .84424 .62111 L .84152 .61483 L p .707 .577 .707 r
F P
0 g
s
.84152 .61483 m .83291 .55904 L .83563 .56532 L p .707 .577 .707 r
F P
0 g
s
.63906 .73785 m .64435 .75612 L .656 .75745 L p .707 .577 .707 r
F P
0 g
s
.63408 .59201 m .64268 .6478 L .6454 .65408 L p .707 .577 .707 r
F P
0 g
s
.82527 .68773 m .83056 .70599 L .83785 .69908 L p .707 .577 .707 r
F P
0 g
s
.83785 .69908 m .83256 .68082 L .82527 .68773 L p .707 .577 .707 r
F P
0 g
s
.65394 .7211 m .64251 .68477 L .64032 .68077 L p .707 .577 .707 r
F P
0 g
s
.64032 .68077 m .65175 .71711 L .65394 .7211 L p .707 .577 .707 r
F P
0 g
s
.83474 .62349 m .84616 .65983 L .84398 .65583 L p .707 .577 .707 r
F P
0 g
s
.84398 .65583 m .83255 .6195 L .83474 .62349 L p .707 .577 .707 r
F P
0 g
s
.64268 .6478 m .63408 .59201 L .64122 .58443 L p .707 .577 .707 r
F P
0 g
s
.64435 .75612 m .63906 .73785 L .63677 .73352 L p .707 .577 .707 r
F P
0 g
s
.63677 .73352 m .64206 .75178 L .64435 .75612 L p .707 .577 .707 r
F P
0 g
s
.83291 .55904 m .84152 .61483 L .8292 .61047 L p .707 .577 .707 r
F P
0 g
s
.8292 .61047 m .82059 .55469 L .83291 .55904 L p .707 .577 .707 r
F P
0 g
s
.64122 .58443 m .64983 .64021 L .64268 .6478 L p .707 .577 .707 r
F P
0 g
s
.83256 .68082 m .83785 .69908 L .83556 .69474 L p .707 .577 .707 r
F P
0 g
s
.83556 .69474 m .83027 .67648 L .83256 .68082 L p .707 .577 .707 r
F P
0 g
s
.39329 .61136 m .38469 .55558 L .3539 .5586 L p .707 .577 .707 r
F P
0 g
s
.38469 .55558 m .39329 .61136 L .42479 .60614 L p .707 .577 .707 r
F P
0 g
s
.42479 .60614 m .41618 .55036 L .38469 .55558 L p .707 .577 .707 r
F P
0 g
s
.41618 .55036 m .42479 .60614 L .4539 .59923 L p .707 .577 .707 r
F P
0 g
s
.4539 .59923 m .44529 .54345 L .41618 .55036 L p .707 .577 .707 r
F P
0 g
s
.65175 .71711 m .64032 .68077 L .64765 .67397 L p .707 .577 .707 r
F P
0 g
s
.64765 .67397 m .65908 .71031 L .65175 .71711 L p .707 .577 .707 r
F P
0 g
s
.83255 .6195 m .84398 .65583 L .83249 .65504 L p .707 .577 .707 r
F P
0 g
s
.83249 .65504 m .82106 .6187 L .83255 .6195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3625 .61439 m .3539 .5586 L .32682 .55914 L p .707 .577 .707 r
F P
0 g
s
.3539 .5586 m .3625 .61439 L .39329 .61136 L p .707 .577 .707 r
F P
0 g
s
.64983 .64021 m .64122 .58443 L .65753 .57628 L p .707 .577 .707 r
F P
0 g
s
.44529 .54345 m .4539 .59923 L .47777 .59132 L p .707 .577 .707 r
F P
0 g
s
.47777 .59132 m .46917 .53554 L .44529 .54345 L p .707 .577 .707 r
F P
0 g
s
.64206 .75178 m .63677 .73352 L .64406 .7266 L p .707 .577 .707 r
F P
0 g
s
.82059 .55469 m .8292 .61047 L .80848 .60846 L p .707 .577 .707 r
F P
0 g
s
.80848 .60846 m .79988 .55268 L .82059 .55469 L p .707 .577 .707 r
F P
0 g
s
.32682 .55914 m .33543 .61492 L .3625 .61439 L p .707 .577 .707 r
F P
0 g
s
.64406 .7266 m .64935 .74487 L .64206 .75178 L p .707 .577 .707 r
F P
0 g
s
.39763 .67306 m .38621 .63672 L .35657 .64472 L p .707 .577 .707 r
F P
0 g
s
.42808 .66335 m .41665 .62702 L .38621 .63672 L p .707 .577 .707 r
F P
0 g
s
.65753 .57628 m .66613 .63207 L .64983 .64021 L p .707 .577 .707 r
F P
0 g
s
.45636 .65289 m .44493 .61656 L .41665 .62702 L p .707 .577 .707 r
F P
0 g
s
.83027 .67648 m .83556 .69474 L .82391 .69341 L p .707 .577 .707 r
F P
0 g
s
.82391 .69341 m .81862 .67515 L .83027 .67648 L p .707 .577 .707 r
F P
0 g
s
.33543 .61492 m .32682 .55914 L .30611 .55713 L p .707 .577 .707 r
F P
0 g
s
.35657 .64472 m .368 .68105 L .39763 .67306 L p .707 .577 .707 r
F P
0 g
s
.368 .68105 m .35657 .64472 L .33066 .65022 L p .707 .577 .707 r
F P
0 g
s
.65908 .71031 m .64765 .67397 L .66378 .66504 L p .707 .577 .707 r
F P
0 g
s
.46917 .53554 m .47777 .59132 L .49408 .58317 L p .707 .577 .707 r
F P
0 g
s
.49408 .58317 m .48548 .52739 L .46917 .53554 L p .707 .577 .707 r
F P
0 g
s
.44493 .61656 m .45636 .65289 L .4797 .64269 L p .707 .577 .707 r
F P
0 g
s
.4797 .64269 m .46828 .60636 L .44493 .61656 L p .707 .577 .707 r
F P
0 g
s
.33066 .65022 m .34208 .68656 L .368 .68105 L p .707 .577 .707 r
F P
0 g
s
.66613 .63207 m .65753 .57628 L .68141 .56837 L p .707 .577 .707 r
F P
0 g
s
.30611 .55713 m .31471 .61291 L .33543 .61492 L p .707 .577 .707 r
F P
0 g
s
.82106 .6187 m .83249 .65504 L .81282 .65751 L p .707 .577 .707 r
F P
0 g
s
.81282 .65751 m .80139 .62117 L .82106 .6187 L p .707 .577 .707 r
F P
0 g
s
.66378 .66504 m .6752 .70137 L .65908 .71031 L p .707 .577 .707 r
F P
0 g
s
.38886 .71969 m .38356 .70143 L .35371 .70868 L p .707 .577 .707 r
F P
0 g
s
.38356 .70143 m .38886 .71969 L .4195 .71066 L p .707 .577 .707 r
F P
0 g
s
.4195 .71066 m .41421 .69239 L .38356 .70143 L p .707 .577 .707 r
F P
0 g
s
.44794 .70073 m .44265 .68246 L .41421 .69239 L p .707 .577 .707 r
F P
0 g
s
.35371 .70868 m .359 .72694 L .38886 .71969 L p .707 .577 .707 r
F P
0 g
s
.79988 .55268 m .80848 .60846 L .78141 .609 L p .707 .577 .707 r
F P
0 g
s
.78141 .609 m .7728 .55321 L .79988 .55268 L p .707 .577 .707 r
F P
0 g
s
.68141 .56837 m .69001 .62415 L .66613 .63207 L p .707 .577 .707 r
F P
0 g
s
.64935 .74487 m .64406 .7266 L .66022 .71779 L p .707 .577 .707 r
F P
0 g
s
.34208 .68656 m .33066 .65022 L .31099 .6527 L p .707 .577 .707 r
F P
0 g
s
.31471 .61291 m .30611 .55713 L .29379 .55277 L p .707 .577 .707 r
F P
0 g
s
.359 .72694 m .35371 .70868 L .32757 .71344 L p .707 .577 .707 r
F P
0 g
s
.66022 .71779 m .66551 .73605 L .64935 .74487 L p .707 .577 .707 r
F P
0 g
s
.44265 .68246 m .44794 .70073 L .47139 .69087 L p .707 .577 .707 r
F P
0 g
s
.47139 .69087 m .4661 .67261 L .44265 .68246 L p .707 .577 .707 r
F P
0 g
s
.46828 .60636 m .4797 .64269 L .49583 .63376 L p .707 .577 .707 r
F P
0 g
s
.49583 .63376 m .4844 .59742 L .46828 .60636 L p .707 .577 .707 r
F P
0 g
s
.32757 .71344 m .33286 .7317 L .359 .72694 L p .707 .577 .707 r
F P
0 g
s
.31099 .6527 m .32242 .68903 L .34208 .68656 L p .707 .577 .707 r
F P
0 g
s
.81862 .67515 m .82391 .69341 L .80404 .69522 L p .707 .577 .707 r
F P
0 g
s
.80404 .69522 m .79875 .67695 L .81862 .67515 L p .707 .577 .707 r
F P
0 g
s
.69001 .62415 m .68141 .56837 L .71052 .56146 L p .707 .577 .707 r
F P
0 g
s
.6752 .70137 m .66378 .66504 L .68712 .65484 L p .707 .577 .707 r
F P
0 g
s
.48548 .52739 m .49408 .58317 L .50123 .57559 L p .707 .577 .707 r
F P
0 g
s
.50123 .57559 m .49262 .5198 L .48548 .52739 L p .707 .577 .707 r
F P
0 g
s
.7728 .55321 m .78141 .609 L .75061 .61202 L p .707 .577 .707 r
F P
0 g
s
.75061 .61202 m .74201 .55624 L .7728 .55321 L p .707 .577 .707 r
F P
0 g
s
.29379 .55277 m .30239 .60856 L .31471 .61291 L p .707 .577 .707 r
F P
0 g
s
.80139 .62117 m .81282 .65751 L .7869 .66301 L p .707 .577 .707 r
F P
0 g
s
.7869 .66301 m .77548 .62668 L .80139 .62117 L p .707 .577 .707 r
F P
0 g
s
.68712 .65484 m .69855 .69118 L .6752 .70137 L p .707 .577 .707 r
F P
0 g
s
.71912 .61725 m .71052 .56146 L .74201 .55624 L p .707 .577 .707 r
F P
0 g
s
.71052 .56146 m .71912 .61725 L .69001 .62415 L p .707 .577 .707 r
F P
0 g
s
.33286 .7317 m .32757 .71344 L .3077 .71524 L p .707 .577 .707 r
F P
0 g
s
.74201 .55624 m .75061 .61202 L .71912 .61725 L p .707 .577 .707 r
F P
0 g
s
.3077 .71524 m .31299 .73351 L .33286 .7317 L p .707 .577 .707 r
F P
0 g
s
.4661 .67261 m .47139 .69087 L .48755 .68205 L p .707 .577 .707 r
F P
0 g
s
.48755 .68205 m .48226 .66379 L .4661 .67261 L p .707 .577 .707 r
F P
0 g
s
.32242 .68903 m .31099 .6527 L .2995 .6519 L p .707 .577 .707 r
F P
0 g
s
.66551 .73605 m .66022 .71779 L .68367 .70793 L p .707 .577 .707 r
F P
0 g
s
.68367 .70793 m .68896 .72619 L .66551 .73605 L p .707 .577 .707 r
F P
0 g
s
.69855 .69118 m .68712 .65484 L .7154 .64438 L p .707 .577 .707 r
F P
0 g
s
.30239 .60856 m .29379 .55277 L .29107 .5465 L p .707 .577 .707 r
F P
0 g
s
.4844 .59742 m .49583 .63376 L .50315 .62696 L p .707 .577 .707 r
F P
0 g
s
.50315 .62696 m .49173 .59063 L .4844 .59742 L p .707 .577 .707 r
F P
0 g
s
.79875 .67695 m .80404 .69522 L .7779 .69998 L p .707 .577 .707 r
F P
0 g
s
.7779 .69998 m .77261 .68171 L .79875 .67695 L p .707 .577 .707 r
F P
0 g
s
.2995 .6519 m .31093 .68823 L .32242 .68903 L p .707 .577 .707 r
F P
0 g
s
.77548 .62668 m .7869 .66301 L .75727 .67101 L p .707 .577 .707 r
F P
0 g
s
.75727 .67101 m .74585 .63467 L .77548 .62668 L p .707 .577 .707 r
F P
0 g
s
.7154 .64438 m .72683 .68071 L .69855 .69118 L p .707 .577 .707 r
F P
0 g
s
.72683 .68071 m .7154 .64438 L .74585 .63467 L p .707 .577 .707 r
F P
0 g
s
.49262 .5198 m .50123 .57559 L .4985 .56931 L p .707 .577 .707 r
F P
0 g
s
.4985 .56931 m .4899 .51353 L .49262 .5198 L p .707 .577 .707 r
F P
0 g
s
.74585 .63467 m .75727 .67101 L .72683 .68071 L p .707 .577 .707 r
F P
0 g
s
.29107 .5465 m .29967 .60228 L .30239 .60856 L p .707 .577 .707 r
F P
0 g
s
.31299 .73351 m .3077 .71524 L .29605 .71391 L p .707 .577 .707 r
F P
0 g
s
.68896 .72619 m .68367 .70793 L .71211 .698 L p .707 .577 .707 r
F P
0 g
s
.29605 .71391 m .30134 .73218 L .31299 .73351 L p .707 .577 .707 r
F P
0 g
s
.77261 .68171 m .7779 .69998 L .74805 .70723 L p .707 .577 .707 r
F P
0 g
s
.74805 .70723 m .74276 .68896 L .77261 .68171 L p .707 .577 .707 r
F P
0 g
s
.71211 .698 m .7174 .71626 L .68896 .72619 L p .707 .577 .707 r
F P
0 g
s
.48226 .66379 m .48755 .68205 L .49484 .67514 L p .707 .577 .707 r
F P
0 g
s
.49484 .67514 m .48955 .65687 L .48226 .66379 L p .707 .577 .707 r
F P
0 g
s
.31093 .68823 m .2995 .6519 L .29731 .6479 L p .707 .577 .707 r
F P
0 g
s
.7174 .71626 m .71211 .698 L .74276 .68896 L p .707 .577 .707 r
F P
0 g
s
.74276 .68896 m .74805 .70723 L .7174 .71626 L p .707 .577 .707 r
F P
0 g
s
.29731 .6479 m .30874 .68424 L .31093 .68823 L p .707 .577 .707 r
F P
0 g
s
.49173 .59063 m .50315 .62696 L .50097 .62297 L p .707 .577 .707 r
F P
0 g
s
.50097 .62297 m .48954 .58663 L .49173 .59063 L p .707 .577 .707 r
F P
0 g
s
.29967 .60228 m .29107 .5465 L .29821 .53891 L p .707 .577 .707 r
F P
0 g
s
.4899 .51353 m .4985 .56931 L .48619 .56495 L p .707 .577 .707 r
F P
0 g
s
.48619 .56495 m .47758 .50917 L .4899 .51353 L p .707 .577 .707 r
F P
0 g
s
.29821 .53891 m .30681 .5947 L .29967 .60228 L p .707 .577 .707 r
F P
0 g
s
.30134 .73218 m .29605 .71391 L .29376 .70958 L p .707 .577 .707 r
F P
0 g
s
.29376 .70958 m .29905 .72784 L .30134 .73218 L p .707 .577 .707 r
F P
0 g
s
.48955 .65687 m .49484 .67514 L .49255 .6708 L p .707 .577 .707 r
F P
0 g
s
.49255 .6708 m .48726 .65254 L .48955 .65687 L p .707 .577 .707 r
F P
0 g
s
.30874 .68424 m .29731 .6479 L .30464 .64111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30681 .5947 m .29821 .53891 L .31452 .53076 L p .707 .577 .707 r
F P
0 g
s
.30464 .64111 m .31607 .67744 L .30874 .68424 L p .707 .577 .707 r
F P
0 g
s
.48954 .58663 m .50097 .62297 L .48948 .62217 L p .707 .577 .707 r
F P
0 g
s
.48948 .62217 m .47805 .58583 L .48954 .58663 L p .707 .577 .707 r
F P
0 g
s
.47758 .50917 m .48619 .56495 L .46547 .56294 L p .707 .577 .707 r
F P
0 g
s
.46547 .56294 m .45687 .50716 L .47758 .50917 L p .707 .577 .707 r
F P
0 g
s
.31452 .53076 m .32312 .58655 L .30681 .5947 L p .707 .577 .707 r
F P
0 g
s
.29905 .72784 m .29376 .70958 L .30105 .70266 L p .707 .577 .707 r
F P
0 g
s
.30105 .70266 m .30634 .72093 L .29905 .72784 L p .707 .577 .707 r
F P
0 g
s
.48726 .65254 m .49255 .6708 L .4809 .66947 L p .707 .577 .707 r
F P
0 g
s
.4809 .66947 m .47561 .65121 L .48726 .65254 L p .707 .577 .707 r
F P
0 g
s
.31607 .67744 m .30464 .64111 L .32076 .63217 L p .707 .577 .707 r
F P
0 g
s
.32312 .58655 m .31452 .53076 L .3384 .52285 L p .707 .577 .707 r
F P
0 g
s
.47805 .58583 m .48948 .62217 L .46981 .62464 L p .707 .577 .707 r
F P
0 g
s
.46981 .62464 m .45838 .58831 L .47805 .58583 L p .707 .577 .707 r
F P
0 g
s
.32076 .63217 m .33219 .6685 L .31607 .67744 L p .707 .577 .707 r
F P
0 g
s
.45687 .50716 m .46547 .56294 L .4384 .56348 L p .707 .577 .707 r
F P
0 g
s
.4384 .56348 m .42979 .50769 L .45687 .50716 L p .707 .577 .707 r
F P
0 g
s
.3384 .52285 m .347 .57863 L .32312 .58655 L p .707 .577 .707 r
F P
0 g
s
.30634 .72093 m .30105 .70266 L .31721 .69384 L p .707 .577 .707 r
F P
0 g
s
.347 .57863 m .3384 .52285 L .36751 .51594 L p .707 .577 .707 r
F P
0 g
s
.31721 .69384 m .3225 .71211 L .30634 .72093 L p .707 .577 .707 r
F P
0 g
s
.47561 .65121 m .4809 .66947 L .46103 .67127 L p .707 .577 .707 r
F P
0 g
s
.46103 .67127 m .45574 .65301 L .47561 .65121 L p .707 .577 .707 r
F P
0 g
s
.42979 .50769 m .4384 .56348 L .4076 .56651 L p .707 .577 .707 r
F P
0 g
s
.4076 .56651 m .399 .51072 L .42979 .50769 L p .707 .577 .707 r
F P
0 g
s
.33219 .6685 m .32076 .63217 L .34411 .62197 L p .707 .577 .707 r
F P
0 g
s
.45838 .58831 m .46981 .62464 L .44389 .63014 L p .707 .577 .707 r
F P
0 g
s
.44389 .63014 m .43247 .59381 L .45838 .58831 L p .707 .577 .707 r
F P
0 g
s
.37611 .57173 m .36751 .51594 L .399 .51072 L p .707 .577 .707 r
F P
0 g
s
.36751 .51594 m .37611 .57173 L .347 .57863 L p .707 .577 .707 r
F P
0 g
s
.34411 .62197 m .35554 .65831 L .33219 .6685 L p .707 .577 .707 r
F P
0 g
s
.399 .51072 m .4076 .56651 L .37611 .57173 L p .707 .577 .707 r
F P
0 g
s
.3225 .71211 m .31721 .69384 L .34066 .68399 L p .707 .577 .707 r
F P
0 g
s
.35554 .65831 m .34411 .62197 L .37239 .61151 L p .707 .577 .707 r
F P
0 g
s
.34066 .68399 m .34595 .70225 L .3225 .71211 L p .707 .577 .707 r
F P
0 g
s
.43247 .59381 m .44389 .63014 L .41426 .63814 L p .707 .577 .707 r
F P
0 g
s
.41426 .63814 m .40284 .6018 L .43247 .59381 L p .707 .577 .707 r
F P
0 g
s
.45574 .65301 m .46103 .67127 L .43489 .67603 L p .707 .577 .707 r
F P
0 g
s
.43489 .67603 m .4296 .65777 L .45574 .65301 L p .707 .577 .707 r
F P
0 g
s
.37239 .61151 m .38381 .64784 L .35554 .65831 L p .707 .577 .707 r
F P
0 g
s
.38381 .64784 m .37239 .61151 L .40284 .6018 L p .707 .577 .707 r
F P
0 g
s
.40284 .6018 m .41426 .63814 L .38381 .64784 L p .707 .577 .707 r
F P
0 g
s
.34595 .70225 m .34066 .68399 L .3691 .67406 L p .707 .577 .707 r
F P
0 g
s
.4296 .65777 m .43489 .67603 L .40504 .68329 L p .707 .577 .707 r
F P
0 g
s
.40504 .68329 m .39974 .66502 L .4296 .65777 L p .707 .577 .707 r
F P
0 g
s
.3691 .67406 m .37439 .69232 L .34595 .70225 L p .707 .577 .707 r
F P
0 g
s
.37439 .69232 m .3691 .67406 L .39974 .66502 L p .707 .577 .707 r
F P
0 g
s
.39974 .66502 m .40504 .68329 L .37439 .69232 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001dOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001jOol0071oo`@000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Aoo`00KGoo0`0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`00LGoo001[Ool20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH3
001_Ool006Yoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF008006eoo`00JGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF
0P00Jgoo001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001YOol006Qoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001WOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02001U
Ool006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qo
o`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001ROol006Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00
Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001ROol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP1SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=o
o`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEWoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo00<005YF
00001UYF00<005YFFUH01UYF4P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol00`00FUH00006FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001OOol40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001KOol40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001GOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IWoo001EOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P008Goo4`00<goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000HOol90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00019oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00003FUH0
000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000ioo`@00003
FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002mo
o`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF
00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00002Woo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUH005YF02moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Ioo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_
Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol0
0`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00003Ool20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol00`00FUH00004FUH00`00FUH000030004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo
0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001DOol01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00001@000eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUIJEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH200000eYF001JEP07FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool004moo`H00004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool004Ioo`T000AJEP03001JEP0000=JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEPD000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo0010Ool60004FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?7oo100000=JEP00
FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEPD000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00Oomoo`0[Ool003Qoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUHA00000eYF001JEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90007FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000fOol200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<0
05YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YF0000;Goo000d
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
100000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH01UYF1P00
0UYF00<005YF00000P0000=JEP00Ool0;7oo000aOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF1@000UYF00<005YF00000P002EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUH00002000^Ool002moo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030003FUH01@00
FUIJEUYF00000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00H005YF000005YF0005FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH50006
FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF0`001eYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
00000`001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000[Ool00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH200000eYF001JEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000[Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`9J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUH000020005FUH20007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00
FUIJEP06FUH01000FUH0000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001J
EUYF00EJEP/0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP06FUH01000FUIJEUYF1000
00=JEP00FUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`00;7oo000/Ool00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUH00005FUH00`00FUIJEP04FUH3
0008FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP02FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF2@0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH00UYF00@005YFFUH002ao
o`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH01000FUIJEUYF10000UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF10001UYF00<005YFFUH00eYF0P00;Goo000/Ool01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP04
001JEP000005FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
0P001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<007ooOol0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH40006FUH01000FUIJEUYF10000UYF00<005YF
FUH01eYF00<005YFFUH015YF2`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF10001eYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;Goo00<005YF000015YF00<005YF00000`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF008000=JEP03001JEUYF00AJEP@0
00MJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0000000EJEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000]
Ool00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP020005FUH00`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP05FUH40003FUH20000
0eYF001JEP04FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP04FUH60002
FUH01000FUH00000<Goo000]Ool01000FUIJEP000UYF00@005YFFUH000QJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001JEP00008000AJEP03001JEUYF00MJ
EP03001JEUYF00@000EJEP8000=JEP03001JEUYF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40008FUH70003FUH00`00FUIJEP03FUH01000FUH00000<7oo000]Ool00`00FUIJEP030004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP05FUH50006FUH30006FUH00`00FUIJEP020002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEP000eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<0
05YFFUH00eYF00@005YFFUH0031oo`00;Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF1@000UYF2@002EYF00<005YFFUH01P0000=JEP00FUH00UYF100000=J
EP00FUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YF00000`001UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;goo000^Ool015YF
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP00FUH01eYF
0P000eYF00<005YFFUH01EYF100000=JEP00000020001UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00;Woo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF009JEP<000EJEP03001JEUYF00=JEP800003
FUH005YF00=JEPD00003FUH005YF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYF0003FUH00`00
FUIJEP02FUH20003FUH01000FUIJEUYF0`0015YF00<005YFFUH01UYF00<005YFFUH015YF3000;Woo
000^Ool01@00FUIJEUYF000015YF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01eYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YF00000P000eYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH01UYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP04001JEUYF0004FUH01000FUH000001EYF10001eYF00<005YF
FUH01eYF00<005YF00000`0000=oo`0000001EYF00@005YFFUH002ioo`00;Woo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP8000=JEP03001JEUYF
00AJEP<000IJEPD000MJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000D00003FUH005YF00=JEP8000IJEP800003FUH0
05YF00QJEP03001JEUYF00AJEP@0009oo`<00003FUH005YF00EJEP8002moo`00<7oo1@000eYF00<0
05YFFUH00UYF1`0025YF00<005YFFUH01EYF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP06FUH01000FUIJEUYF1@003EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00D005YFFUH005YF0080009JEP03001JEUYF
00<000=JEP03001JEUYF00MJEP03001JEUYF00@000=oo`<000EJEP03001JEUYF00=JEP03001oogoo
02ioo`00=Goo20000Woo0P0000=JEP00FUH025YF00<005YFFUH015YF00@005YFFUH000AJEP05001J
EP00001JEP070006FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP020004FUH3
0007FUH00`00FUIJEP04FUH50005Ool200000eYF001JEP05FUH01000FUIJEUYF0P00<Goo000lOol3
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF1P000eYF00<005YFFUH01eYF
00<005YFFUH015YF0`001UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P001EYF00D005YF001JEP00009JEP800003FUH005YF00MJEP03001J
EUYF00@000Moo`<000=JEP03001JEUYF00EJEP<003=oo`00>Goo0`001eYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00@000UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP<0009JEP<000=JEP03001JEUYF00EJEP@000=oo`<0009oo`<000IJEP03001JEUYF00AJ
EP8003Eoo`00=Woo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP000000
009JEP04001JEP000006FUH00`00FUIJEP02FUH20006Ool600000eYF001JEP07FUH01000FUIJEUYF
0P00=goo000dOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0`001eYF00<005YF00000P0027oo1@000UYF00<005YFFUH01UYF00@005YF000003Uoo`00<Woo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01P0000=JEP00FUH015YF00<005YFFUH0
15YF1@002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH015YF0P0000=JEP0000001Goo
20000eYF00<005YFFUH015YF0`00>goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH40004FUH01000FUIJEP001EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P000UYF0`0015YF00<005YFFUH00UYF0`000UYF0P0000=oo`0000000P0000AJEP00
FUIJEP<000AJEP03001JEUYF00@003ioo`00;goo00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF300000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP04001JEP000002FUH60006FUH00`00FUIJ
EP05FUH40012Ool002ioo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000EJ
EP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP800003FUH005YF009JEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20016
Ool002eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP06
FUH01000FUH000000Woo0UYF00<005YFFUH015YF00<005YFFUH015YF2@0000=JEP00FUH02EYF3000
1UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008004Qoo`00;Goo00@005YFFUH000EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEPP00003
FUH005YF00EJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00QJEPP000UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF
00AJEP@004]oo`00;Woo00<005YF00001EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YF
FUH01UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00=JEP@000EJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000=JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@004moo`00;Woo
00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH01UYF10001UYF00D005YFFUIJEP00
009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH400000eYF001JEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEP001UYF
00@005YFFUIJEPH005=oo`00;Woo00@005YFFUH000AJEP03001JEUYF009JEP80009JEP03001JEUYF
00MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00H005YF000005YF
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00020007FUH00`00FUIJEP02FUH00`00FUH00003FUH20002FUH01000FUIJEUYF1P000eYF0P00E7oo
000^Ool01000FUIJEP001EYF00@005YF000000EJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH00`00FUH0
000;0003FUH00`00FUIJEP03FUH00`00Oomoo`1COol002moo`03001JEP0000AJEP<000MJEP04001J
EUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP<00003FUH005YF00=JEP03001JEP0000MJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol0
02moo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH30004FUH00`00FUH00008FUH00`00FUIJEP04FUH3001HOol0
02moo`03001JEUYF008000EJEP03001JEUYF009JEP800003FUH005YF00QJEP03001JEUYF00EJEPH0
0006Ool00000FUH005YF0P003UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00@005YFFUH000=JEP<000QJEPX005Qoo`00<7oo00AJEP00FUH0
00EJEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEUYF00@000Eoo`8000AJEP<000iJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH2000015YF0000000015YF100000=JEP00FUH00eYF00<005YFFUH00P00Egoo000`Ool2
00000eYF001JEP04FUH20007FUH00`00FUIJEP06FUH40006Ool30006FUH3000>FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH300000eYF000000020005FUH00`00FUIJEP03FUH01000FUIJEP00Egoo000aOol2000015YF001J
EUYF0`0025YF00<005YFFUH00eYF10001goo0P0000=JEP00FUH01eYF0P003UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH00UYF00<005YFFUH00P00EWoo000cOol40003
FUH00`00FUIJEP06FUH00`00FUH000060004Ool30004FUH00`00FUIJEP04FUH3000=FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH005Ioo`00<Woo
0`001EYF00<005YFFUH01EYF0`000goo0`000Woo0`001eYF00<005YFFUH00UYF0P000goo0P002eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP`005Eoo`00<7oo0P0000=JEP00FUH0
1UYF00<005YFFUH010001goo100000=JEP00FUH025YF00@005YF000000Moo`03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUH000030002Ool00`00FUIJEP03FUH01000FUIJEP00
EGoo000^Ool20003FUH00`00FUIJEP04FUH40006Ool50006FUH00`00FUIJEP05FUH3000:Ool20008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP000UYF100017oo0`001UYF0P00EWoo000]Ool20005FUH01000
FUIJEUYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P003goo0P001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000`001Woo0P000eYF00<005YFFUH00eYF00<007ooOol0EGoo000/Ool01000
FUIJEP0015YF00@005YF000000Aoo`@000IJEP03001JEUYF00MJEP03001JEP00008001=oo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000Moo`<000EJEP04001JEUYFFUH2001HOol002aoo`04001JEUYF0004FUH2
0002Ool400000eYF001JEP08FUH00`00FUIJEP04FUH4000HOol300000eYF001JEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool400000eYF001JEP06FUH3001JOol002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJ
EP03001JEUYF00@001moo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH200000goo000000020005FUH00`00FUIJEP04FUH2001LOol002eo
o`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@002Ioo`@000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000@00003FUH005YF
00MJEP04001JEUYFFUH2001NOol002eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04
000^Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH80002
FUH00`00FUIJEP06FUH01000FUH00000H7oo000^Ool015YF001JEP001EYF00<005YFFUH015YF1000
=Woo1`001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH03@000UYF00<005YFFUH01EYF
0`00HWoo000^Ool01000FUIJEP001EYF00<005YFFUH01000@Goo3@001UYF00<005YFFUH015YF2000
00=oo`0000000P0000=JEP00FUH01@000eYF00<005YFFUH00UYF0P00IGoo000^Ool<001BOol>0002
Ool60006FUH00`00FUH000020004FUH00`00FUH00002001WOol008ioo`04001JEUYF0003FUH70003
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001ZOol008ioo`05001JEUYF001JEP020002FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001]Ool008moo`04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH5001aOol008moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00@007Ioo`00Sgoo00@005YFFUH000EJEP03001JEUYF00AJEP@007Yoo`00Sgoo0P000UYF00<0
05YFFUH00eYF00<005YF00000`00OWoo002@Ool;0022Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5991 .74892 m .59049 .69313 L .5597 .69616 L p .707 .577 .707 r
F P
0 g
s
.59049 .69313 m .5991 .74892 L .63059 .7437 L p .707 .577 .707 r
F P
0 g
s
.63059 .7437 m .62199 .68791 L .59049 .69313 L p .707 .577 .707 r
F P
0 g
s
.62199 .68791 m .63059 .7437 L .6597 .73679 L p .707 .577 .707 r
F P
0 g
s
.6597 .73679 m .6511 .68101 L .62199 .68791 L p .707 .577 .707 r
F P
0 g
s
.56831 .75195 m .5597 .69616 L .53263 .6967 L p .707 .577 .707 r
F P
0 g
s
.5597 .69616 m .56831 .75195 L .5991 .74892 L p .707 .577 .707 r
F P
0 g
s
.6511 .68101 m .6597 .73679 L .68358 .72888 L p .707 .577 .707 r
F P
0 g
s
.68358 .72888 m .67497 .67309 L .6511 .68101 L p .707 .577 .707 r
F P
0 g
s
.60344 .79796 m .59201 .76163 L .56238 .76963 L p .707 .577 .707 r
F P
0 g
s
.59201 .76163 m .60344 .79796 L .63388 .78826 L p .707 .577 .707 r
F P
0 g
s
.63388 .78826 m .62246 .75193 L .59201 .76163 L p .707 .577 .707 r
F P
0 g
s
.62246 .75193 m .63388 .78826 L .66216 .7778 L p .707 .577 .707 r
F P
0 g
s
.66216 .7778 m .65074 .74146 L .62246 .75193 L p .707 .577 .707 r
F P
0 g
s
.53263 .6967 m .54123 .75248 L .56831 .75195 L p .707 .577 .707 r
F P
0 g
s
.56238 .76963 m .57381 .80596 L .60344 .79796 L p .707 .577 .707 r
F P
0 g
s
.54123 .75248 m .53263 .6967 L .51191 .69469 L p .707 .577 .707 r
F P
0 g
s
.57381 .80596 m .56238 .76963 L .53646 .77513 L p .707 .577 .707 r
F P
0 g
s
.65074 .74146 m .66216 .7778 L .68551 .7676 L p .707 .577 .707 r
F P
0 g
s
.68551 .7676 m .67408 .73127 L .65074 .74146 L p .707 .577 .707 r
F P
0 g
s
.67497 .67309 m .68358 .72888 L .69989 .72073 L p .707 .577 .707 r
F P
0 g
s
.69989 .72073 m .69128 .66494 L .67497 .67309 L p .707 .577 .707 r
F P
0 g
s
.53646 .77513 m .54789 .81146 L .57381 .80596 L p .707 .577 .707 r
F P
0 g
s
.59466 .83567 m .58937 .81741 L .55951 .82466 L p .707 .577 .707 r
F P
0 g
s
.58937 .81741 m .59466 .83567 L .62531 .82664 L p .707 .577 .707 r
F P
0 g
s
.62531 .82664 m .62002 .80837 L .58937 .81741 L p .707 .577 .707 r
F P
0 g
s
.62002 .80837 m .62531 .82664 L .65375 .81671 L p .707 .577 .707 r
F P
0 g
s
.65375 .81671 m .64846 .79844 L .62002 .80837 L p .707 .577 .707 r
F P
0 g
s
.51191 .69469 m .52052 .75047 L .54123 .75248 L p .707 .577 .707 r
F P
0 g
s
.55951 .82466 m .5648 .84292 L .59466 .83567 L p .707 .577 .707 r
F P
0 g
s
.5648 .84292 m .55951 .82466 L .53337 .82942 L p .707 .577 .707 r
F P
0 g
s
.54789 .81146 m .53646 .77513 L .5168 .7776 L p .707 .577 .707 r
F P
0 g
s
.64846 .79844 m .65375 .81671 L .6772 .80685 L p .707 .577 .707 r
F P
0 g
s
.6772 .80685 m .67191 .78859 L .64846 .79844 L p .707 .577 .707 r
F P
0 g
s
.53337 .82942 m .53866 .84768 L .5648 .84292 L p .707 .577 .707 r
F P
0 g
s
.67408 .73127 m .68551 .7676 L .70163 .75866 L p .707 .577 .707 r
F P
0 g
s
.70163 .75866 m .69021 .72233 L .67408 .73127 L p .707 .577 .707 r
F P
0 g
s
.52052 .75047 m .51191 .69469 L .49959 .69033 L p .707 .577 .707 r
F P
0 g
s
.5168 .7776 m .52822 .81394 L .54789 .81146 L p .707 .577 .707 r
F P
0 g
s
.69128 .66494 m .69989 .72073 L .70703 .71314 L p .707 .577 .707 r
F P
0 g
s
.70703 .71314 m .69843 .65736 L .69128 .66494 L p .707 .577 .707 r
F P
0 g
s
.49959 .69033 m .5082 .74611 L .52052 .75047 L p .707 .577 .707 r
F P
0 g
s
.53866 .84768 m .53337 .82942 L .5135 .83122 L p .707 .577 .707 r
F P
0 g
s
.5135 .83122 m .51879 .84949 L .53866 .84768 L p .707 .577 .707 r
F P
0 g
s
.67191 .78859 m .6772 .80685 L .69336 .79803 L p .707 .577 .707 r
F P
0 g
s
.69336 .79803 m .68807 .77977 L .67191 .78859 L p .707 .577 .707 r
F P
0 g
s
.52822 .81394 m .5168 .7776 L .50531 .7768 L p .707 .577 .707 r
F P
0 g
s
.69021 .72233 m .70163 .75866 L .70896 .75187 L p .707 .577 .707 r
F P
0 g
s
.70896 .75187 m .69753 .71553 L .69021 .72233 L p .707 .577 .707 r
F P
0 g
s
.50531 .7768 m .51673 .81314 L .52822 .81394 L p .707 .577 .707 r
F P
0 g
s
.5082 .74611 m .49959 .69033 L .49687 .68405 L p .707 .577 .707 r
F P
0 g
s
.51879 .84949 m .5135 .83122 L .50185 .82989 L p .707 .577 .707 r
F P
0 g
s
.69843 .65736 m .70703 .71314 L .70431 .70687 L p .707 .577 .707 r
F P
0 g
s
.70431 .70687 m .6957 .65108 L .69843 .65736 L p .707 .577 .707 r
F P
0 g
s
.50185 .82989 m .50714 .84816 L .51879 .84949 L p .707 .577 .707 r
F P
0 g
s
.49687 .68405 m .50548 .73984 L .5082 .74611 L p .707 .577 .707 r
F P
0 g
s
.68807 .77977 m .69336 .79803 L .70065 .79112 L p .707 .577 .707 r
F P
0 g
s
.70065 .79112 m .69536 .77285 L .68807 .77977 L p .707 .577 .707 r
F P
0 g
s
.47109 .82196 m .50148 .32433 L .45756 .31896 L p .707 .577 .707 r
F P
0 g
s
.51673 .81314 m .50531 .7768 L .50312 .77281 L p .707 .577 .707 r
F P
0 g
s
.50312 .77281 m .51454 .80914 L .51673 .81314 L p .707 .577 .707 r
F P
0 g
s
.50548 .73984 m .49687 .68405 L .50401 .67647 L p .707 .577 .707 r
F P
0 g
s
.50401 .67647 m .51262 .73225 L .50548 .73984 L p .707 .577 .707 r
F P
0 g
s
.51454 .80914 m .50312 .77281 L .51045 .76601 L p .707 .577 .707 r
F P
0 g
s
.51045 .76601 m .52187 .80235 L .51454 .80914 L p .707 .577 .707 r
F P
0 g
s
.51262 .73225 m .50401 .67647 L .52032 .66832 L p .707 .577 .707 r
F P
0 g
s
.50714 .84816 m .50185 .82989 L .49956 .82556 L p .707 .577 .707 r
F P
0 g
s
.49956 .82556 m .50485 .84382 L .50714 .84816 L p .707 .577 .707 r
F P
0 g
s
.50485 .84382 m .49956 .82556 L .50685 .81864 L p .707 .577 .707 r
F P
0 g
s
.50685 .81864 m .51214 .83691 L .50485 .84382 L p .707 .577 .707 r
F P
0 g
s
.52032 .66832 m .52893 .72411 L .51262 .73225 L p .707 .577 .707 r
F P
0 g
s
.52187 .80235 m .51045 .76601 L .52657 .75708 L p .707 .577 .707 r
F P
0 g
s
.51214 .83691 m .50685 .81864 L .52301 .80983 L p .707 .577 .707 r
F P
0 g
s
.50148 .32433 m .47109 .82196 L .51596 .82329 L p .707 .577 .707 r
F P
0 g
s
.52893 .72411 m .52032 .66832 L .5442 .66041 L p .707 .577 .707 r
F P
0 g
s
.51596 .82329 m .54635 .32566 L .50148 .32433 L p .707 .577 .707 r
F P
0 g
s
.52657 .75708 m .538 .79341 L .52187 .80235 L p .707 .577 .707 r
F P
0 g
s
.5442 .66041 m .55281 .71619 L .52893 .72411 L p .707 .577 .707 r
F P
0 g
s
.52301 .80983 m .52831 .82809 L .51214 .83691 L p .707 .577 .707 r
F P
0 g
s
.55281 .71619 m .5442 .66041 L .57331 .6535 L p .707 .577 .707 r
F P
0 g
s
.538 .79341 m .52657 .75708 L .54992 .74688 L p .707 .577 .707 r
F P
0 g
s
.54992 .74688 m .56134 .78321 L .538 .79341 L p .707 .577 .707 r
F P
0 g
s
.57331 .6535 m .58192 .70928 L .55281 .71619 L p .707 .577 .707 r
F P
0 g
s
.52831 .82809 m .52301 .80983 L .54646 .79997 L p .707 .577 .707 r
F P
0 g
s
.54646 .79997 m .55175 .81823 L .52831 .82809 L p .707 .577 .707 r
F P
0 g
s
.56134 .78321 m .54992 .74688 L .5782 .73642 L p .707 .577 .707 r
F P
0 g
s
.55175 .81823 m .54646 .79997 L .5749 .79004 L p .707 .577 .707 r
F P
0 g
s
.5749 .79004 m .58019 .8083 L .55175 .81823 L p .707 .577 .707 r
F P
0 g
s
.54635 .32566 m .51596 .82329 L .55738 .82045 L p .707 .577 .707 r
F P
0 g
s
.55738 .82045 m .58778 .32281 L .54635 .32566 L p .707 .577 .707 r
F P
0 g
s
.42716 .81659 m .45756 .31896 L .41887 .31007 L p .707 .577 .707 r
F P
0 g
s
.45756 .31896 m .42716 .81659 L .47109 .82196 L p .707 .577 .707 r
F P
0 g
s
.69753 .71553 m .70896 .75187 L .70677 .74787 L p .707 .577 .707 r
F P
0 g
s
.70677 .74787 m .69535 .71154 L .69753 .71553 L p .707 .577 .707 r
F P
0 g
s
.58192 .70928 m .57331 .6535 L .6048 .64828 L p .707 .577 .707 r
F P
0 g
s
.6048 .64828 m .61341 .70406 L .58192 .70928 L p .707 .577 .707 r
F P
0 g
s
.5782 .73642 m .58962 .77275 L .56134 .78321 L p .707 .577 .707 r
F P
0 g
s
.58962 .77275 m .5782 .73642 L .60864 .72671 L p .707 .577 .707 r
F P
0 g
s
.60864 .72671 m .62007 .76305 L .58962 .77275 L p .707 .577 .707 r
F P
0 g
s
.58019 .8083 m .5749 .79004 L .60555 .781 L p .707 .577 .707 r
F P
0 g
s
.60555 .781 m .61084 .79927 L .58019 .8083 L p .707 .577 .707 r
F P
0 g
s
.58778 .32281 m .55738 .82045 L .5913 .81371 L p .707 .577 .707 r
F P
0 g
s
.5913 .81371 m .6217 .31607 L .58778 .32281 L p .707 .577 .707 r
F P
0 g
s
.6957 .65108 m .70431 .70687 L .69199 .70251 L p .707 .577 .707 r
F P
0 g
s
.69199 .70251 m .68338 .64673 L .6957 .65108 L p .707 .577 .707 r
F P
0 g
s
.69536 .77285 m .70065 .79112 L .69836 .78678 L p .707 .577 .707 r
F P
0 g
s
.69836 .78678 m .69307 .76852 L .69536 .77285 L p .707 .577 .707 r
F P
0 g
s
.38848 .8077 m .41887 .31007 L .38922 .29853 L p .707 .577 .707 r
F P
0 g
s
.41887 .31007 m .38848 .8077 L .42716 .81659 L p .707 .577 .707 r
F P
0 g
s
.25609 .7034 m .24749 .64762 L .21669 .65064 L p .707 .577 .707 r
F P
0 g
s
.24749 .64762 m .25609 .7034 L .28758 .69818 L p .707 .577 .707 r
F P
0 g
s
.28758 .69818 m .27898 .6424 L .24749 .64762 L p .707 .577 .707 r
F P
0 g
s
.27898 .6424 m .28758 .69818 L .31669 .69127 L p .707 .577 .707 r
F P
0 g
s
.31669 .69127 m .30809 .63549 L .27898 .6424 L p .707 .577 .707 r
F P
0 g
s
.69535 .71154 m .70677 .74787 L .69528 .74707 L p .707 .577 .707 r
F P
0 g
s
.69528 .74707 m .68386 .71074 L .69535 .71154 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2253 .70643 m .21669 .65064 L .18962 .65118 L p .707 .577 .707 r
F P
0 g
s
.21669 .65064 m .2253 .70643 L .25609 .7034 L p .707 .577 .707 r
F P
0 g
s
.30809 .63549 m .31669 .69127 L .34057 .68336 L p .707 .577 .707 r
F P
0 g
s
.34057 .68336 m .33196 .62757 L .30809 .63549 L p .707 .577 .707 r
F P
0 g
s
.63559 .64525 m .6442 .70104 L .61341 .70406 L p .707 .577 .707 r
F P
0 g
s
.61341 .70406 m .6048 .64828 L .63559 .64525 L p .707 .577 .707 r
F P
0 g
s
.62007 .76305 m .60864 .72671 L .63827 .71872 L p .707 .577 .707 r
F P
0 g
s
.63541 .77375 m .6407 .79201 L .61084 .79927 L p .707 .577 .707 r
F P
0 g
s
.61084 .79927 m .60555 .781 L .63541 .77375 L p .707 .577 .707 r
F P
0 g
s
.6217 .31607 m .5913 .81371 L .6144 .80373 L p .707 .577 .707 r
F P
0 g
s
.6144 .80373 m .64479 .3061 L .6217 .31607 L p .707 .577 .707 r
F P
0 g
s
.68338 .64673 m .69199 .70251 L .67128 .7005 L p .707 .577 .707 r
F P
0 g
s
.67128 .7005 m .66267 .64472 L .68338 .64673 L p .707 .577 .707 r
F P
0 g
s
.18962 .65118 m .19822 .70696 L .2253 .70643 L p .707 .577 .707 r
F P
0 g
s
.26043 .7651 m .249 .72876 L .21937 .73676 L p .707 .577 .707 r
F P
0 g
s
.249 .72876 m .26043 .7651 L .29087 .75539 L p .707 .577 .707 r
F P
0 g
s
.29087 .75539 m .27945 .71906 L .249 .72876 L p .707 .577 .707 r
F P
0 g
s
.27945 .71906 m .29087 .75539 L .31915 .74493 L p .707 .577 .707 r
F P
0 g
s
.31915 .74493 m .30773 .7086 L .27945 .71906 L p .707 .577 .707 r
F P
0 g
s
.69307 .76852 m .69836 .78678 L .68671 .78545 L p .707 .577 .707 r
F P
0 g
s
.68671 .78545 m .68142 .76719 L .69307 .76852 L p .707 .577 .707 r
F P
0 g
s
.19822 .70696 m .18962 .65118 L .1689 .64917 L p .707 .577 .707 r
F P
0 g
s
.21937 .73676 m .2308 .77309 L .26043 .7651 L p .707 .577 .707 r
F P
0 g
s
.34827 .61943 m .35688 .67521 L .35886 .67311 L p .707 .577 .707 r
F P
0 g
s
.35886 .67311 m .36402 .66763 L p .35871 .65137 L .707 .577 .707 r
F P
0 g
s
.35871 .65137 m .34827 .61943 L .35886 .67311 L .707 .577 .707 r
F
.3715 .28547 m .36745 .27218 L p .35747 .46585 L F P
0 g
s
.33196 .62757 m .34057 .68336 L .35688 .67521 L p .707 .577 .707 r
F P
0 g
s
.35688 .67521 m .34827 .61943 L .33196 .62757 L p .707 .577 .707 r
F P
0 g
s
.33107 .6984 m .3425 .73473 L .35862 .7258 L p .707 .577 .707 r
F P
0 g
s
.35862 .7258 m .3472 .68946 L .33107 .6984 L p .707 .577 .707 r
F P
0 g
s
.36402 .66763 m .35542 .61184 L .34827 .61943 L p .707 .577 .707 r
F P
0 g
s
.3289 .76464 m .33419 .78291 L .35035 .77409 L p .707 .577 .707 r
F P
0 g
s
.35035 .77409 m .34506 .75583 L .3289 .76464 L p .707 .577 .707 r
F P
0 g
s
.34898 .65699 m .34038 .60121 L .35269 .60556 L p .707 .577 .707 r
F P
0 g
s
.3472 .68946 m .35862 .7258 L .36595 .719 L p .707 .577 .707 r
F P
0 g
s
.36595 .719 m .35452 .68266 L .3472 .68946 L p .707 .577 .707 r
F P
0 g
s
.35227 .71421 m .3482 .70124 L p .35234 .67867 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .34085 .67787 L .3523 .67867 L p .707 .577 .707 r
F P
0 g
s
.3523 .67867 m .35234 .67867 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.34038 .60121 m .34898 .65699 L .32827 .65498 L p .707 .577 .707 r
F P
0 g
s
.3425 .73473 m .33107 .6984 L .30773 .7086 L p .707 .577 .707 r
F P
0 g
s
.34085 .67787 m .3482 .70124 L p .33261 .71668 L .707 .577 .707 r
F P
0 g
s
.3482 .70124 m .35227 .71421 L .34688 .71488 L p .707 .577 .707 r
F P
0 g
s
.34688 .71488 m .33261 .71668 L p .3482 .70124 L .707 .577 .707 r
F P
0 g
s
.30773 .7086 m .31915 .74493 L .3425 .73473 L p .707 .577 .707 r
F P
0 g
s
.34506 .75583 m .35035 .77409 L .35764 .76717 L p .707 .577 .707 r
F P
0 g
s
.35764 .76717 m .35235 .74891 L .34506 .75583 L p .707 .577 .707 r
F P
0 g
s
.3437 .76151 m .33841 .74324 L .35006 .74458 L p .707 .577 .707 r
F P
0 g
s
.33841 .74324 m .3437 .76151 L .32383 .76331 L p .707 .577 .707 r
F P
0 g
s
.36745 .27218 m .33706 .76981 L .3405 .78112 L p .707 .577 .707 r
F P
0 g
s
.3405 .78112 m .34111 .78311 L p .34203 .76528 L .707 .577 .707 r
F P
0 g
s
.34203 .76528 m .36745 .27218 L .3405 .78112 L .707 .577 .707 r
F
.34419 .72326 m .35776 .5104 L .35747 .46585 L F
.34111 .78311 m .34505 .71855 L p .34419 .72326 L F P
0 g
s
.34505 .71855 m .35776 .5104 L p .34419 .72326 L .707 .577 .707 r
F P
0 g
s
.35776 .5104 m .3715 .28547 L p .35747 .46585 L .707 .577 .707 r
F P
0 g
s
.35542 .61184 m .36402 .66763 L .3613 .66135 L p .707 .577 .707 r
F P
0 g
s
.35452 .68266 m .36595 .719 L .36376 .715 L p .707 .577 .707 r
F P
0 g
s
.36376 .715 m .35234 .67867 L .35452 .68266 L p .707 .577 .707 r
F P
0 g
s
.35234 .67867 m .36376 .715 L .35227 .71421 L p .707 .577 .707 r
F P
0 g
s
.35883 .79616 m .38922 .29853 L .3715 .28547 L p .707 .577 .707 r
F P
0 g
s
.38922 .29853 m .35883 .79616 L .38848 .8077 L p .707 .577 .707 r
F P
0 g
s
.2308 .77309 m .21937 .73676 L .19345 .74226 L p .707 .577 .707 r
F P
0 g
s
.19345 .74226 m .20488 .7786 L .2308 .77309 L p .707 .577 .707 r
F P
0 g
s
.1689 .64917 m .17751 .70495 L .19822 .70696 L p .707 .577 .707 r
F P
0 g
s
.68386 .71074 m .69528 .74707 L .67562 .74955 L p .707 .577 .707 r
F P
0 g
s
.67562 .74955 m .66419 .71321 L .68386 .71074 L p .707 .577 .707 r
F P
0 g
s
.25165 .81173 m .24636 .79347 L .21651 .80072 L p .707 .577 .707 r
F P
0 g
s
.24636 .79347 m .25165 .81173 L .2823 .8027 L p .707 .577 .707 r
F P
0 g
s
.2823 .8027 m .27701 .78443 L .24636 .79347 L p .707 .577 .707 r
F P
0 g
s
.27701 .78443 m .2823 .8027 L .31074 .79276 L p .707 .577 .707 r
F P
0 g
s
.31074 .79276 m .30545 .7745 L .27701 .78443 L p .707 .577 .707 r
F P
0 g
s
.21651 .80072 m .2218 .81898 L .25165 .81173 L p .707 .577 .707 r
F P
0 g
s
.66267 .64472 m .67128 .7005 L .6442 .70104 L p .707 .577 .707 r
F P
0 g
s
.6442 .70104 m .63559 .64525 L .66267 .64472 L p .707 .577 .707 r
F P
0 g
s
.20488 .7786 m .19345 .74226 L .17379 .74473 L p .707 .577 .707 r
F P
0 g
s
.17751 .70495 m .1689 .64917 L .15658 .64481 L p .707 .577 .707 r
F P
0 g
s
.2218 .81898 m .21651 .80072 L .19036 .80548 L p .707 .577 .707 r
F P
0 g
s
.30545 .7745 m .31074 .79276 L .33419 .78291 L p .707 .577 .707 r
F P
0 g
s
.33419 .78291 m .3289 .76464 L .30545 .7745 L p .707 .577 .707 r
F P
0 g
s
.19036 .80548 m .19565 .82374 L .2218 .81898 L p .707 .577 .707 r
F P
0 g
s
.17379 .74473 m .18521 .78107 L .20488 .7786 L p .707 .577 .707 r
F P
0 g
s
.68142 .76719 m .68671 .78545 L .66684 .78725 L p .707 .577 .707 r
F P
0 g
s
.66684 .78725 m .66155 .76899 L .68142 .76719 L p .707 .577 .707 r
F P
0 g
s
.63827 .71872 m .6497 .75505 L .62007 .76305 L p .707 .577 .707 r
F P
0 g
s
.64479 .3061 m .6144 .80373 L .62441 .7915 L p .707 .577 .707 r
F P
0 g
s
.62441 .7915 m .6548 .29386 L .64479 .3061 L p .707 .577 .707 r
F P
0 g
s
.15658 .64481 m .16519 .7006 L .17751 .70495 L p .707 .577 .707 r
F P
0 g
s
.66419 .71321 m .67562 .74955 L .6497 .75505 L p .707 .577 .707 r
F P
0 g
s
.6497 .75505 m .63827 .71872 L .66419 .71321 L p .707 .577 .707 r
F P
0 g
s
.19565 .82374 m .19036 .80548 L .1705 .80728 L p .707 .577 .707 r
F P
0 g
s
.3613 .66135 m .35269 .60556 L .35542 .61184 L p .707 .577 .707 r
F P
0 g
s
.35269 .60556 m .3613 .66135 L .34898 .65699 L p .707 .577 .707 r
F P
0 g
s
.35235 .74891 m .35764 .76717 L .35535 .76284 L p .707 .577 .707 r
F P
0 g
s
.35535 .76284 m .35006 .74458 L .35235 .74891 L p .707 .577 .707 r
F P
0 g
s
.35006 .74458 m .35535 .76284 L .3437 .76151 L p .707 .577 .707 r
F P
0 g
s
.3715 .28547 m .34111 .78311 L .35883 .79616 L p .707 .577 .707 r
F P
0 g
s
.1705 .80728 m .17579 .82554 L .19565 .82374 L p .707 .577 .707 r
F P
0 g
s
.18521 .78107 m .17379 .74473 L .1623 .74394 L p .707 .577 .707 r
F P
0 g
s
.16519 .7006 m .15658 .64481 L .15386 .63854 L p .707 .577 .707 r
F P
0 g
s
.66155 .76899 m .66684 .78725 L .6407 .79201 L p .707 .577 .707 r
F P
0 g
s
.6407 .79201 m .63541 .77375 L .66155 .76899 L p .707 .577 .707 r
F P
0 g
s
.1623 .74394 m .17372 .78027 L .18521 .78107 L p .707 .577 .707 r
F P
0 g
s
.15386 .63854 m .16247 .69432 L .16519 .7006 L p .707 .577 .707 r
F P
0 g
s
.17579 .82554 m .1705 .80728 L .15884 .80595 L p .707 .577 .707 r
F P
0 g
s
.15884 .80595 m .16414 .82421 L .17579 .82554 L p .707 .577 .707 r
F P
0 g
s
.6548 .29386 m .62441 .7915 L .62036 .7782 L p .707 .577 .707 r
F P
0 g
s
.62036 .7782 m .65075 .28057 L .6548 .29386 L p .707 .577 .707 r
F P
0 g
s
.17372 .78027 m .1623 .74394 L .16011 .73994 L p .707 .577 .707 r
F P
0 g
s
.16011 .73994 m .17154 .77628 L .17372 .78027 L p .707 .577 .707 r
F P
0 g
s
.16247 .69432 m .15386 .63854 L .16101 .63095 L p .707 .577 .707 r
F P
0 g
s
.33706 .76981 m .36745 .27218 L .37746 .25994 L p .707 .577 .707 r
F P
0 g
s
.16101 .63095 m .16961 .68674 L .16247 .69432 L p .707 .577 .707 r
F P
0 g
s
.16414 .82421 m .15884 .80595 L .15655 .80161 L p .707 .577 .707 r
F P
0 g
s
.15655 .80161 m .16184 .81988 L .16414 .82421 L p .707 .577 .707 r
F P
0 g
s
.17154 .77628 m .16011 .73994 L .16744 .73314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16961 .68674 m .16101 .63095 L .17731 .6228 L p .707 .577 .707 r
F P
0 g
s
.65075 .28057 m .62036 .7782 L .60264 .76515 L p .707 .577 .707 r
F P
0 g
s
.60264 .76515 m .63303 .26751 L .65075 .28057 L p .707 .577 .707 r
F P
0 g
s
.16744 .73314 m .17886 .76948 L .17154 .77628 L p .707 .577 .707 r
F P
0 g
s
.32827 .65498 m .31966 .5992 L .34038 .60121 L p .707 .577 .707 r
F P
0 g
s
.17731 .6228 m .18592 .67859 L .16961 .68674 L p .707 .577 .707 r
F P
0 g
s
.34707 .75758 m .37746 .25994 L .40056 .24997 L p .707 .577 .707 r
F P
0 g
s
.37746 .25994 m .34707 .75758 L .33706 .76981 L p .707 .577 .707 r
F P
0 g
s
.16184 .81988 m .15655 .80161 L .16384 .7947 L p .707 .577 .707 r
F P
0 g
s
.16384 .7947 m .16914 .81296 L .16184 .81988 L p .707 .577 .707 r
F P
0 g
s
.17886 .76948 m .16744 .73314 L .18356 .72421 L p .707 .577 .707 r
F P
0 g
s
.18592 .67859 m .17731 .6228 L .20119 .61489 L p .707 .577 .707 r
F P
0 g
s
.33261 .71668 m .32118 .68034 L .34085 .67787 L p .707 .577 .707 r
F P
0 g
s
.18356 .72421 m .19499 .76054 L .17886 .76948 L p .707 .577 .707 r
F P
0 g
s
.31966 .5992 m .32827 .65498 L .30119 .65552 L p .707 .577 .707 r
F P
0 g
s
.30119 .65552 m .29259 .59973 L .31966 .5992 L p .707 .577 .707 r
F P
0 g
s
.20119 .61489 m .2098 .67067 L .18592 .67859 L p .707 .577 .707 r
F P
0 g
s
.63303 .26751 m .60264 .76515 L .57299 .75361 L p .707 .577 .707 r
F P
0 g
s
.57299 .75361 m .60338 .25597 L .63303 .26751 L p .707 .577 .707 r
F P
0 g
s
.16914 .81296 m .16384 .7947 L .18001 .78588 L p .707 .577 .707 r
F P
0 g
s
.2098 .67067 m .20119 .61489 L .2303 .60798 L p .707 .577 .707 r
F P
0 g
s
.18001 .78588 m .1853 .80415 L .16914 .81296 L p .707 .577 .707 r
F P
0 g
s
.32383 .76331 m .31854 .74505 L .33841 .74324 L p .707 .577 .707 r
F P
0 g
s
.40056 .24997 m .37016 .7476 L .34707 .75758 L p .707 .577 .707 r
F P
0 g
s
.37016 .7476 m .40056 .24997 L .43448 .24323 L p .707 .577 .707 r
F P
0 g
s
.29259 .59973 m .30119 .65552 L .2704 .65854 L p .707 .577 .707 r
F P
0 g
s
.2704 .65854 m .26179 .60276 L .29259 .59973 L p .707 .577 .707 r
F P
0 g
s
.19499 .76054 m .18356 .72421 L .20691 .71401 L p .707 .577 .707 r
F P
0 g
s
.32118 .68034 m .33261 .71668 L .30669 .72218 L p .707 .577 .707 r
F P
0 g
s
.30669 .72218 m .29526 .68585 L .32118 .68034 L p .707 .577 .707 r
F P
0 g
s
.23891 .66377 m .2303 .60798 L .26179 .60276 L p .707 .577 .707 r
F P
0 g
s
.2303 .60798 m .23891 .66377 L .2098 .67067 L p .707 .577 .707 r
F P
0 g
s
.20691 .71401 m .21833 .75034 L .19499 .76054 L p .707 .577 .707 r
F P
0 g
s
.26179 .60276 m .2704 .65854 L .23891 .66377 L p .707 .577 .707 r
F P
0 g
s
.7363 .65688 m .7277 .6011 L .69691 .60412 L p .707 .577 .707 r
F P
0 g
s
.7277 .6011 m .7363 .65688 L .7678 .65166 L p .707 .577 .707 r
F P
0 g
s
.7678 .65166 m .75919 .59587 L .7277 .6011 L p .707 .577 .707 r
F P
0 g
s
.75919 .59587 m .7678 .65166 L .79691 .64475 L p .707 .577 .707 r
F P
0 g
s
.79691 .64475 m .7883 .58897 L .75919 .59587 L p .707 .577 .707 r
F P
0 g
s
.70551 .65991 m .69691 .60412 L .66983 .60466 L p .707 .577 .707 r
F P
0 g
s
.69691 .60412 m .70551 .65991 L .7363 .65688 L p .707 .577 .707 r
F P
0 g
s
.1853 .80415 m .18001 .78588 L .20345 .77603 L p .707 .577 .707 r
F P
0 g
s
.21833 .75034 m .20691 .71401 L .23519 .70355 L p .707 .577 .707 r
F P
0 g
s
.60338 .25597 m .57299 .75361 L .5343 .74472 L p .707 .577 .707 r
F P
0 g
s
.5343 .74472 m .5647 .24708 L .60338 .25597 L p .707 .577 .707 r
F P
0 g
s
.20345 .77603 m .20874 .79429 L .1853 .80415 L p .707 .577 .707 r
F P
0 g
s
.7883 .58897 m .79691 .64475 L .82078 .63684 L p .707 .577 .707 r
F P
0 g
s
.82078 .63684 m .81218 .58105 L .7883 .58897 L p .707 .577 .707 r
F P
0 g
s
.29526 .68585 m .30669 .72218 L .27706 .73018 L p .707 .577 .707 r
F P
0 g
s
.27706 .73018 m .26563 .69384 L .29526 .68585 L p .707 .577 .707 r
F P
0 g
s
.31854 .74505 m .32383 .76331 L .29769 .76807 L p .707 .577 .707 r
F P
0 g
s
.29769 .76807 m .2924 .74981 L .31854 .74505 L p .707 .577 .707 r
F P
0 g
s
.23519 .70355 m .24661 .73988 L .21833 .75034 L p .707 .577 .707 r
F P
0 g
s
.74064 .70593 m .72922 .66959 L .69958 .67759 L p .707 .577 .707 r
F P
0 g
s
.72922 .66959 m .74064 .70593 L .77109 .69622 L p .707 .577 .707 r
F P
0 g
s
.77109 .69622 m .75966 .65989 L .72922 .66959 L p .707 .577 .707 r
F P
0 g
s
.40408 .74086 m .43448 .24323 L .4759 .24038 L p .707 .577 .707 r
F P
0 g
s
.43448 .24323 m .40547 .71822 L p .37016 .7476 L .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .44551 .73802 L .40408 .74086 L p .707 .577 .707 r
F P
0 g
s
.38621 .63672 m .39763 .67306 L .41973 .66601 L p .707 .577 .707 r
F P
0 g
s
.41973 .66601 m .42808 .66335 L p .42159 .65923 L .707 .577 .707 r
F P
0 g
s
.42159 .65923 m .38621 .63672 L .41973 .66601 L .707 .577 .707 r
F
.40547 .71822 m .40408 .74086 L .399 .74187 L p F P
0 g
s
.399 .74187 m .37016 .7476 L p .40547 .71822 L .707 .577 .707 r
F P
0 g
s
.75966 .65989 m .77109 .69622 L .79937 .68576 L p .707 .577 .707 r
F P
0 g
s
.79937 .68576 m .78794 .64943 L .75966 .65989 L p .707 .577 .707 r
F P
0 g
s
.66983 .60466 m .67844 .66044 L .70551 .65991 L p .707 .577 .707 r
F P
0 g
s
.24661 .73988 m .23519 .70355 L .26563 .69384 L p .707 .577 .707 r
F P
0 g
s
.26563 .69384 m .27706 .73018 L .24661 .73988 L p .707 .577 .707 r
F P
0 g
s
.69958 .67759 m .71101 .71392 L .74064 .70593 L p .707 .577 .707 r
F P
0 g
s
.67844 .66044 m .66983 .60466 L .64912 .60265 L p .707 .577 .707 r
F P
0 g
s
.71101 .71392 m .69958 .67759 L .67367 .68309 L p .707 .577 .707 r
F P
0 g
s
.20874 .79429 m .20345 .77603 L .23189 .76609 L p .707 .577 .707 r
F P
0 g
s
.78794 .64943 m .79937 .68576 L .82271 .67556 L p .707 .577 .707 r
F P
0 g
s
.82271 .67556 m .81129 .63923 L .78794 .64943 L p .707 .577 .707 r
F P
0 g
s
.2924 .74981 m .29769 .76807 L .26783 .77532 L p .707 .577 .707 r
F P
0 g
s
.26783 .77532 m .26254 .75706 L .2924 .74981 L p .707 .577 .707 r
F P
0 g
s
.23189 .76609 m .23718 .78436 L .20874 .79429 L p .707 .577 .707 r
F P
0 g
s
.5647 .24708 m .5343 .74472 L .49038 .73935 L p .707 .577 .707 r
F P
0 g
s
.49038 .73935 m .52077 .24171 L .5647 .24708 L p .707 .577 .707 r
F P
0 g
s
.81218 .58105 m .82078 .63684 L .83709 .62869 L p .707 .577 .707 r
F P
0 g
s
.83709 .62869 m .82849 .57291 L .81218 .58105 L p .707 .577 .707 r
F P
0 g
s
.67367 .68309 m .68509 .71943 L .71101 .71392 L p .707 .577 .707 r
F P
0 g
s
.73187 .74363 m .72657 .72537 L .69672 .73262 L p .707 .577 .707 r
F P
0 g
s
.72657 .72537 m .73187 .74363 L .76251 .7346 L p .707 .577 .707 r
F P
0 g
s
.76251 .7346 m .75722 .71634 L .72657 .72537 L p .707 .577 .707 r
F P
0 g
s
.75722 .71634 m .76251 .7346 L .79095 .72467 L p .707 .577 .707 r
F P
0 g
s
.79095 .72467 m .78566 .7064 L .75722 .71634 L p .707 .577 .707 r
F P
0 g
s
.4759 .24038 m .52077 .24171 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.44982 .66746 m .4759 .24038 L p .45534 .67314 L .707 .577 .707 r
F P
0 g
s
.41665 .62702 m .41959 .63637 L p .45636 .65289 L .707 .577 .707 r
F P
0 g
s
.41959 .63637 m .42808 .66335 L .44113 .65852 L p .707 .577 .707 r
F P
0 g
s
.44113 .65852 m .45636 .65289 L p .41959 .63637 L .707 .577 .707 r
F P
0 g
s
.44589 .73172 m .44982 .66746 L p .44638 .73227 L .707 .577 .707 r
F P
0 g
s
.41421 .69239 m .41583 .69798 L p .44794 .70073 L .707 .577 .707 r
F P
0 g
s
.41583 .69798 m .4195 .71066 L .42532 .70863 L p .707 .577 .707 r
F P
0 g
s
.42532 .70863 m .44794 .70073 L p .41583 .69798 L .707 .577 .707 r
F P
0 g
s
.44638 .73227 m .44982 .66746 L .45534 .67314 L .707 .577 .707 r
F
.44551 .73802 m .44589 .73172 L p .44638 .73227 L F P
0 g
s
.64912 .60265 m .65772 .65843 L .67844 .66044 L p .707 .577 .707 r
F P
0 g
s
.69672 .73262 m .70201 .75089 L .73187 .74363 L p .707 .577 .707 r
F P
0 g
s
.23718 .78436 m .23189 .76609 L .26254 .75706 L p .707 .577 .707 r
F P
0 g
s
.26254 .75706 m .26783 .77532 L .23718 .78436 L p .707 .577 .707 r
F P
0 g
s
.52077 .24171 m .49038 .73935 L .44551 .73802 L p .707 .577 .707 r
F P
0 g
s
.70201 .75089 m .69672 .73262 L .67058 .73738 L p .707 .577 .707 r
F P
0 g
s
.68509 .71943 m .67367 .68309 L .654 .68556 L p .707 .577 .707 r
F P
0 g
s
.78566 .7064 m .79095 .72467 L .8144 .71481 L p .707 .577 .707 r
F P
0 g
s
.8144 .71481 m .80911 .69655 L .78566 .7064 L p .707 .577 .707 r
F P
0 g
s
.67058 .73738 m .67587 .75565 L .70201 .75089 L p .707 .577 .707 r
F P
0 g
s
.81129 .63923 m .82271 .67556 L .83884 .66663 L p .707 .577 .707 r
F P
0 g
s
.83884 .66663 m .82741 .63029 L .81129 .63923 L p .707 .577 .707 r
F P
0 g
s
.65772 .65843 m .64912 .60265 L .6368 .59829 L p .707 .577 .707 r
F P
0 g
s
.654 .68556 m .66543 .7219 L .68509 .71943 L p .707 .577 .707 r
F P
0 g
s
.82849 .57291 m .83709 .62869 L .84424 .62111 L p .707 .577 .707 r
F P
0 g
s
.84424 .62111 m .83563 .56532 L .82849 .57291 L p .707 .577 .707 r
F P
0 g
s
.6368 .59829 m .6454 .65408 L .65772 .65843 L p .707 .577 .707 r
F P
0 g
s
.67587 .75565 m .67058 .73738 L .65071 .73919 L p .707 .577 .707 r
F P
0 g
s
.65071 .73919 m .656 .75745 L .67587 .75565 L p .707 .577 .707 r
F P
0 g
s
.80911 .69655 m .8144 .71481 L .83056 .70599 L p .707 .577 .707 r
F P
0 g
s
.83056 .70599 m .82527 .68773 L .80911 .69655 L p .707 .577 .707 r
F P
0 g
s
.66543 .7219 m .654 .68556 L .64251 .68477 L p .707 .577 .707 r
F P
0 g
s
.82741 .63029 m .83884 .66663 L .84616 .65983 L p .707 .577 .707 r
F P
0 g
s
.84616 .65983 m .83474 .62349 L .82741 .63029 L p .707 .577 .707 r
F P
0 g
s
.64251 .68477 m .65394 .7211 L .66543 .7219 L p .707 .577 .707 r
F P
0 g
s
.6454 .65408 m .6368 .59829 L .63408 .59201 L p .707 .577 .707 r
F P
0 g
s
.656 .75745 m .65071 .73919 L .63906 .73785 L p .707 .577 .707 r
F P
0 g
s
.83563 .56532 m .84424 .62111 L .84152 .61483 L p .707 .577 .707 r
F P
0 g
s
.84152 .61483 m .83291 .55904 L .83563 .56532 L p .707 .577 .707 r
F P
0 g
s
.63906 .73785 m .64435 .75612 L .656 .75745 L p .707 .577 .707 r
F P
0 g
s
.63408 .59201 m .64268 .6478 L .6454 .65408 L p .707 .577 .707 r
F P
0 g
s
.82527 .68773 m .83056 .70599 L .83785 .69908 L p .707 .577 .707 r
F P
0 g
s
.83785 .69908 m .83256 .68082 L .82527 .68773 L p .707 .577 .707 r
F P
0 g
s
.65394 .7211 m .64251 .68477 L .64032 .68077 L p .707 .577 .707 r
F P
0 g
s
.64032 .68077 m .65175 .71711 L .65394 .7211 L p .707 .577 .707 r
F P
0 g
s
.83474 .62349 m .84616 .65983 L .84398 .65583 L p .707 .577 .707 r
F P
0 g
s
.84398 .65583 m .83255 .6195 L .83474 .62349 L p .707 .577 .707 r
F P
0 g
s
.64268 .6478 m .63408 .59201 L .64122 .58443 L p .707 .577 .707 r
F P
0 g
s
.64435 .75612 m .63906 .73785 L .63677 .73352 L p .707 .577 .707 r
F P
0 g
s
.63677 .73352 m .64206 .75178 L .64435 .75612 L p .707 .577 .707 r
F P
0 g
s
.83291 .55904 m .84152 .61483 L .8292 .61047 L p .707 .577 .707 r
F P
0 g
s
.8292 .61047 m .82059 .55469 L .83291 .55904 L p .707 .577 .707 r
F P
0 g
s
.64122 .58443 m .64983 .64021 L .64268 .6478 L p .707 .577 .707 r
F P
0 g
s
.83256 .68082 m .83785 .69908 L .83556 .69474 L p .707 .577 .707 r
F P
0 g
s
.83556 .69474 m .83027 .67648 L .83256 .68082 L p .707 .577 .707 r
F P
0 g
s
.39329 .61136 m .38469 .55558 L .3539 .5586 L p .707 .577 .707 r
F P
0 g
s
.38469 .55558 m .39329 .61136 L .42479 .60614 L p .707 .577 .707 r
F P
0 g
s
.42479 .60614 m .41618 .55036 L .38469 .55558 L p .707 .577 .707 r
F P
0 g
s
.41618 .55036 m .42479 .60614 L .4539 .59923 L p .707 .577 .707 r
F P
0 g
s
.4539 .59923 m .44529 .54345 L .41618 .55036 L p .707 .577 .707 r
F P
0 g
s
.65175 .71711 m .64032 .68077 L .64765 .67397 L p .707 .577 .707 r
F P
0 g
s
.64765 .67397 m .65908 .71031 L .65175 .71711 L p .707 .577 .707 r
F P
0 g
s
.83255 .6195 m .84398 .65583 L .83249 .65504 L p .707 .577 .707 r
F P
0 g
s
.83249 .65504 m .82106 .6187 L .83255 .6195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3625 .61439 m .3539 .5586 L .32682 .55914 L p .707 .577 .707 r
F P
0 g
s
.3539 .5586 m .3625 .61439 L .39329 .61136 L p .707 .577 .707 r
F P
0 g
s
.64983 .64021 m .64122 .58443 L .65753 .57628 L p .707 .577 .707 r
F P
0 g
s
.44529 .54345 m .4539 .59923 L .47777 .59132 L p .707 .577 .707 r
F P
0 g
s
.47777 .59132 m .46917 .53554 L .44529 .54345 L p .707 .577 .707 r
F P
0 g
s
.64206 .75178 m .63677 .73352 L .64406 .7266 L p .707 .577 .707 r
F P
0 g
s
.82059 .55469 m .8292 .61047 L .80848 .60846 L p .707 .577 .707 r
F P
0 g
s
.80848 .60846 m .79988 .55268 L .82059 .55469 L p .707 .577 .707 r
F P
0 g
s
.32682 .55914 m .33543 .61492 L .3625 .61439 L p .707 .577 .707 r
F P
0 g
s
.64406 .7266 m .64935 .74487 L .64206 .75178 L p .707 .577 .707 r
F P
0 g
s
.39763 .67306 m .38621 .63672 L .35657 .64472 L p .707 .577 .707 r
F P
0 g
s
.42808 .66335 m .41665 .62702 L .38621 .63672 L p .707 .577 .707 r
F P
0 g
s
.65753 .57628 m .66613 .63207 L .64983 .64021 L p .707 .577 .707 r
F P
0 g
s
.45636 .65289 m .44493 .61656 L .41665 .62702 L p .707 .577 .707 r
F P
0 g
s
.83027 .67648 m .83556 .69474 L .82391 .69341 L p .707 .577 .707 r
F P
0 g
s
.82391 .69341 m .81862 .67515 L .83027 .67648 L p .707 .577 .707 r
F P
0 g
s
.33543 .61492 m .32682 .55914 L .30611 .55713 L p .707 .577 .707 r
F P
0 g
s
.35657 .64472 m .368 .68105 L .39763 .67306 L p .707 .577 .707 r
F P
0 g
s
.368 .68105 m .35657 .64472 L .33066 .65022 L p .707 .577 .707 r
F P
0 g
s
.65908 .71031 m .64765 .67397 L .66378 .66504 L p .707 .577 .707 r
F P
0 g
s
.46917 .53554 m .47777 .59132 L .49408 .58317 L p .707 .577 .707 r
F P
0 g
s
.49408 .58317 m .48548 .52739 L .46917 .53554 L p .707 .577 .707 r
F P
0 g
s
.44493 .61656 m .45636 .65289 L .4797 .64269 L p .707 .577 .707 r
F P
0 g
s
.4797 .64269 m .46828 .60636 L .44493 .61656 L p .707 .577 .707 r
F P
0 g
s
.33066 .65022 m .34208 .68656 L .368 .68105 L p .707 .577 .707 r
F P
0 g
s
.66613 .63207 m .65753 .57628 L .68141 .56837 L p .707 .577 .707 r
F P
0 g
s
.30611 .55713 m .31471 .61291 L .33543 .61492 L p .707 .577 .707 r
F P
0 g
s
.82106 .6187 m .83249 .65504 L .81282 .65751 L p .707 .577 .707 r
F P
0 g
s
.81282 .65751 m .80139 .62117 L .82106 .6187 L p .707 .577 .707 r
F P
0 g
s
.66378 .66504 m .6752 .70137 L .65908 .71031 L p .707 .577 .707 r
F P
0 g
s
.38886 .71969 m .38356 .70143 L .35371 .70868 L p .707 .577 .707 r
F P
0 g
s
.38356 .70143 m .38886 .71969 L .4195 .71066 L p .707 .577 .707 r
F P
0 g
s
.4195 .71066 m .41421 .69239 L .38356 .70143 L p .707 .577 .707 r
F P
0 g
s
.44794 .70073 m .44265 .68246 L .41421 .69239 L p .707 .577 .707 r
F P
0 g
s
.35371 .70868 m .359 .72694 L .38886 .71969 L p .707 .577 .707 r
F P
0 g
s
.79988 .55268 m .80848 .60846 L .78141 .609 L p .707 .577 .707 r
F P
0 g
s
.78141 .609 m .7728 .55321 L .79988 .55268 L p .707 .577 .707 r
F P
0 g
s
.68141 .56837 m .69001 .62415 L .66613 .63207 L p .707 .577 .707 r
F P
0 g
s
.64935 .74487 m .64406 .7266 L .66022 .71779 L p .707 .577 .707 r
F P
0 g
s
.34208 .68656 m .33066 .65022 L .31099 .6527 L p .707 .577 .707 r
F P
0 g
s
.31471 .61291 m .30611 .55713 L .29379 .55277 L p .707 .577 .707 r
F P
0 g
s
.359 .72694 m .35371 .70868 L .32757 .71344 L p .707 .577 .707 r
F P
0 g
s
.66022 .71779 m .66551 .73605 L .64935 .74487 L p .707 .577 .707 r
F P
0 g
s
.44265 .68246 m .44794 .70073 L .47139 .69087 L p .707 .577 .707 r
F P
0 g
s
.47139 .69087 m .4661 .67261 L .44265 .68246 L p .707 .577 .707 r
F P
0 g
s
.46828 .60636 m .4797 .64269 L .49583 .63376 L p .707 .577 .707 r
F P
0 g
s
.49583 .63376 m .4844 .59742 L .46828 .60636 L p .707 .577 .707 r
F P
0 g
s
.32757 .71344 m .33286 .7317 L .359 .72694 L p .707 .577 .707 r
F P
0 g
s
.31099 .6527 m .32242 .68903 L .34208 .68656 L p .707 .577 .707 r
F P
0 g
s
.81862 .67515 m .82391 .69341 L .80404 .69522 L p .707 .577 .707 r
F P
0 g
s
.80404 .69522 m .79875 .67695 L .81862 .67515 L p .707 .577 .707 r
F P
0 g
s
.69001 .62415 m .68141 .56837 L .71052 .56146 L p .707 .577 .707 r
F P
0 g
s
.6752 .70137 m .66378 .66504 L .68712 .65484 L p .707 .577 .707 r
F P
0 g
s
.48548 .52739 m .49408 .58317 L .50123 .57559 L p .707 .577 .707 r
F P
0 g
s
.50123 .57559 m .49262 .5198 L .48548 .52739 L p .707 .577 .707 r
F P
0 g
s
.7728 .55321 m .78141 .609 L .75061 .61202 L p .707 .577 .707 r
F P
0 g
s
.75061 .61202 m .74201 .55624 L .7728 .55321 L p .707 .577 .707 r
F P
0 g
s
.29379 .55277 m .30239 .60856 L .31471 .61291 L p .707 .577 .707 r
F P
0 g
s
.80139 .62117 m .81282 .65751 L .7869 .66301 L p .707 .577 .707 r
F P
0 g
s
.7869 .66301 m .77548 .62668 L .80139 .62117 L p .707 .577 .707 r
F P
0 g
s
.68712 .65484 m .69855 .69118 L .6752 .70137 L p .707 .577 .707 r
F P
0 g
s
.71912 .61725 m .71052 .56146 L .74201 .55624 L p .707 .577 .707 r
F P
0 g
s
.71052 .56146 m .71912 .61725 L .69001 .62415 L p .707 .577 .707 r
F P
0 g
s
.33286 .7317 m .32757 .71344 L .3077 .71524 L p .707 .577 .707 r
F P
0 g
s
.74201 .55624 m .75061 .61202 L .71912 .61725 L p .707 .577 .707 r
F P
0 g
s
.3077 .71524 m .31299 .73351 L .33286 .7317 L p .707 .577 .707 r
F P
0 g
s
.4661 .67261 m .47139 .69087 L .48755 .68205 L p .707 .577 .707 r
F P
0 g
s
.48755 .68205 m .48226 .66379 L .4661 .67261 L p .707 .577 .707 r
F P
0 g
s
.32242 .68903 m .31099 .6527 L .2995 .6519 L p .707 .577 .707 r
F P
0 g
s
.66551 .73605 m .66022 .71779 L .68367 .70793 L p .707 .577 .707 r
F P
0 g
s
.68367 .70793 m .68896 .72619 L .66551 .73605 L p .707 .577 .707 r
F P
0 g
s
.69855 .69118 m .68712 .65484 L .7154 .64438 L p .707 .577 .707 r
F P
0 g
s
.30239 .60856 m .29379 .55277 L .29107 .5465 L p .707 .577 .707 r
F P
0 g
s
.4844 .59742 m .49583 .63376 L .50315 .62696 L p .707 .577 .707 r
F P
0 g
s
.50315 .62696 m .49173 .59063 L .4844 .59742 L p .707 .577 .707 r
F P
0 g
s
.79875 .67695 m .80404 .69522 L .7779 .69998 L p .707 .577 .707 r
F P
0 g
s
.7779 .69998 m .77261 .68171 L .79875 .67695 L p .707 .577 .707 r
F P
0 g
s
.2995 .6519 m .31093 .68823 L .32242 .68903 L p .707 .577 .707 r
F P
0 g
s
.77548 .62668 m .7869 .66301 L .75727 .67101 L p .707 .577 .707 r
F P
0 g
s
.75727 .67101 m .74585 .63467 L .77548 .62668 L p .707 .577 .707 r
F P
0 g
s
.7154 .64438 m .72683 .68071 L .69855 .69118 L p .707 .577 .707 r
F P
0 g
s
.72683 .68071 m .7154 .64438 L .74585 .63467 L p .707 .577 .707 r
F P
0 g
s
.49262 .5198 m .50123 .57559 L .4985 .56931 L p .707 .577 .707 r
F P
0 g
s
.4985 .56931 m .4899 .51353 L .49262 .5198 L p .707 .577 .707 r
F P
0 g
s
.74585 .63467 m .75727 .67101 L .72683 .68071 L p .707 .577 .707 r
F P
0 g
s
.29107 .5465 m .29967 .60228 L .30239 .60856 L p .707 .577 .707 r
F P
0 g
s
.31299 .73351 m .3077 .71524 L .29605 .71391 L p .707 .577 .707 r
F P
0 g
s
.68896 .72619 m .68367 .70793 L .71211 .698 L p .707 .577 .707 r
F P
0 g
s
.29605 .71391 m .30134 .73218 L .31299 .73351 L p .707 .577 .707 r
F P
0 g
s
.77261 .68171 m .7779 .69998 L .74805 .70723 L p .707 .577 .707 r
F P
0 g
s
.74805 .70723 m .74276 .68896 L .77261 .68171 L p .707 .577 .707 r
F P
0 g
s
.71211 .698 m .7174 .71626 L .68896 .72619 L p .707 .577 .707 r
F P
0 g
s
.48226 .66379 m .48755 .68205 L .49484 .67514 L p .707 .577 .707 r
F P
0 g
s
.49484 .67514 m .48955 .65687 L .48226 .66379 L p .707 .577 .707 r
F P
0 g
s
.31093 .68823 m .2995 .6519 L .29731 .6479 L p .707 .577 .707 r
F P
0 g
s
.7174 .71626 m .71211 .698 L .74276 .68896 L p .707 .577 .707 r
F P
0 g
s
.74276 .68896 m .74805 .70723 L .7174 .71626 L p .707 .577 .707 r
F P
0 g
s
.29731 .6479 m .30874 .68424 L .31093 .68823 L p .707 .577 .707 r
F P
0 g
s
.49173 .59063 m .50315 .62696 L .50097 .62297 L p .707 .577 .707 r
F P
0 g
s
.50097 .62297 m .48954 .58663 L .49173 .59063 L p .707 .577 .707 r
F P
0 g
s
.29967 .60228 m .29107 .5465 L .29821 .53891 L p .707 .577 .707 r
F P
0 g
s
.4899 .51353 m .4985 .56931 L .48619 .56495 L p .707 .577 .707 r
F P
0 g
s
.48619 .56495 m .47758 .50917 L .4899 .51353 L p .707 .577 .707 r
F P
0 g
s
.29821 .53891 m .30681 .5947 L .29967 .60228 L p .707 .577 .707 r
F P
0 g
s
.30134 .73218 m .29605 .71391 L .29376 .70958 L p .707 .577 .707 r
F P
0 g
s
.29376 .70958 m .29905 .72784 L .30134 .73218 L p .707 .577 .707 r
F P
0 g
s
.48955 .65687 m .49484 .67514 L .49255 .6708 L p .707 .577 .707 r
F P
0 g
s
.49255 .6708 m .48726 .65254 L .48955 .65687 L p .707 .577 .707 r
F P
0 g
s
.30874 .68424 m .29731 .6479 L .30464 .64111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30681 .5947 m .29821 .53891 L .31452 .53076 L p .707 .577 .707 r
F P
0 g
s
.30464 .64111 m .31607 .67744 L .30874 .68424 L p .707 .577 .707 r
F P
0 g
s
.48954 .58663 m .50097 .62297 L .48948 .62217 L p .707 .577 .707 r
F P
0 g
s
.48948 .62217 m .47805 .58583 L .48954 .58663 L p .707 .577 .707 r
F P
0 g
s
.47758 .50917 m .48619 .56495 L .46547 .56294 L p .707 .577 .707 r
F P
0 g
s
.46547 .56294 m .45687 .50716 L .47758 .50917 L p .707 .577 .707 r
F P
0 g
s
.31452 .53076 m .32312 .58655 L .30681 .5947 L p .707 .577 .707 r
F P
0 g
s
.29905 .72784 m .29376 .70958 L .30105 .70266 L p .707 .577 .707 r
F P
0 g
s
.30105 .70266 m .30634 .72093 L .29905 .72784 L p .707 .577 .707 r
F P
0 g
s
.48726 .65254 m .49255 .6708 L .4809 .66947 L p .707 .577 .707 r
F P
0 g
s
.4809 .66947 m .47561 .65121 L .48726 .65254 L p .707 .577 .707 r
F P
0 g
s
.31607 .67744 m .30464 .64111 L .32076 .63217 L p .707 .577 .707 r
F P
0 g
s
.32312 .58655 m .31452 .53076 L .3384 .52285 L p .707 .577 .707 r
F P
0 g
s
.47805 .58583 m .48948 .62217 L .46981 .62464 L p .707 .577 .707 r
F P
0 g
s
.46981 .62464 m .45838 .58831 L .47805 .58583 L p .707 .577 .707 r
F P
0 g
s
.32076 .63217 m .33219 .6685 L .31607 .67744 L p .707 .577 .707 r
F P
0 g
s
.45687 .50716 m .46547 .56294 L .4384 .56348 L p .707 .577 .707 r
F P
0 g
s
.4384 .56348 m .42979 .50769 L .45687 .50716 L p .707 .577 .707 r
F P
0 g
s
.3384 .52285 m .347 .57863 L .32312 .58655 L p .707 .577 .707 r
F P
0 g
s
.30634 .72093 m .30105 .70266 L .31721 .69384 L p .707 .577 .707 r
F P
0 g
s
.347 .57863 m .3384 .52285 L .36751 .51594 L p .707 .577 .707 r
F P
0 g
s
.31721 .69384 m .3225 .71211 L .30634 .72093 L p .707 .577 .707 r
F P
0 g
s
.47561 .65121 m .4809 .66947 L .46103 .67127 L p .707 .577 .707 r
F P
0 g
s
.46103 .67127 m .45574 .65301 L .47561 .65121 L p .707 .577 .707 r
F P
0 g
s
.42979 .50769 m .4384 .56348 L .4076 .56651 L p .707 .577 .707 r
F P
0 g
s
.4076 .56651 m .399 .51072 L .42979 .50769 L p .707 .577 .707 r
F P
0 g
s
.33219 .6685 m .32076 .63217 L .34411 .62197 L p .707 .577 .707 r
F P
0 g
s
.45838 .58831 m .46981 .62464 L .44389 .63014 L p .707 .577 .707 r
F P
0 g
s
.44389 .63014 m .43247 .59381 L .45838 .58831 L p .707 .577 .707 r
F P
0 g
s
.37611 .57173 m .36751 .51594 L .399 .51072 L p .707 .577 .707 r
F P
0 g
s
.36751 .51594 m .37611 .57173 L .347 .57863 L p .707 .577 .707 r
F P
0 g
s
.34411 .62197 m .35554 .65831 L .33219 .6685 L p .707 .577 .707 r
F P
0 g
s
.399 .51072 m .4076 .56651 L .37611 .57173 L p .707 .577 .707 r
F P
0 g
s
.3225 .71211 m .31721 .69384 L .34066 .68399 L p .707 .577 .707 r
F P
0 g
s
.35554 .65831 m .34411 .62197 L .37239 .61151 L p .707 .577 .707 r
F P
0 g
s
.34066 .68399 m .34595 .70225 L .3225 .71211 L p .707 .577 .707 r
F P
0 g
s
.43247 .59381 m .44389 .63014 L .41426 .63814 L p .707 .577 .707 r
F P
0 g
s
.41426 .63814 m .40284 .6018 L .43247 .59381 L p .707 .577 .707 r
F P
0 g
s
.45574 .65301 m .46103 .67127 L .43489 .67603 L p .707 .577 .707 r
F P
0 g
s
.43489 .67603 m .4296 .65777 L .45574 .65301 L p .707 .577 .707 r
F P
0 g
s
.37239 .61151 m .38381 .64784 L .35554 .65831 L p .707 .577 .707 r
F P
0 g
s
.38381 .64784 m .37239 .61151 L .40284 .6018 L p .707 .577 .707 r
F P
0 g
s
.40284 .6018 m .41426 .63814 L .38381 .64784 L p .707 .577 .707 r
F P
0 g
s
.34595 .70225 m .34066 .68399 L .3691 .67406 L p .707 .577 .707 r
F P
0 g
s
.4296 .65777 m .43489 .67603 L .40504 .68329 L p .707 .577 .707 r
F P
0 g
s
.40504 .68329 m .39974 .66502 L .4296 .65777 L p .707 .577 .707 r
F P
0 g
s
.3691 .67406 m .37439 .69232 L .34595 .70225 L p .707 .577 .707 r
F P
0 g
s
.37439 .69232 m .3691 .67406 L .39974 .66502 L p .707 .577 .707 r
F P
0 g
s
.39974 .66502 m .40504 .68329 L .37439 .69232 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001dOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001jOol0071oo`@000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Aoo`00KGoo0`0000=JEP00FUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`00LGoo001[Ool20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH3
001_Ool006Yoo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF008006eoo`00JGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF
0P00Jgoo001YOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001YOol006Qoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH3001WOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02001U
Ool006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qo
o`04001JEUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Qoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006=oo`00J7oo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001ROol006Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00
Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00069oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo061oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001ROol006Moo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP1SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP1SOol0
06Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=o
o`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol0
06Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0006Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEWoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Io
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Ioo`00I7oo00<005YF
00001UYF00<005YFFUH01UYF4P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol00`00FUH00006FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001OOol40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001KOol40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001GOol30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IWoo001EOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001BOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Igoo001BOol01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00`002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P008Goo4`00<goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000HOol90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000aOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00019oo`H000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00003FUH0
000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000ioo`@00003
FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002mo
o`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF
00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00002Woo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUH005YF02moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000Ioo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_
Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol0
0`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00003Ool20007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol00`00FUH00004FUH00`00FUH000030004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo
0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH30007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001DOol01000FUIJEP000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEPH0009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00001@000eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo001DOol00`00FUIJEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH200000eYF001JEP07FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool004moo`H00004FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool004Ioo`T000AJEP03001JEP0000=JEP03001JEUYF009JEP03001J
EUYF00EJEP03001JEUYF00IJEPD000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP05001JEUYFFUH00007
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo0010Ool60004FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?7oo100000=JEP00
FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEPD000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00Oomoo`0[Ool003Qoo`@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUHA00000eYF001JEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH90007FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000fOol200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<0
05YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YF0000;Goo000d
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
100000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00
FUH00eYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH01UYF1P00
0UYF00<005YF00000P0000=JEP00Ool0;7oo000aOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF1@000UYF00<005YF00000P002EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUH00002000^Ool002moo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030003FUH01@00
FUIJEUYF00000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00H005YF000005YF0005FUH00`00FUH000030004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH50006
FUH00`00FUIJEP03FUH01000FUIJEP00;goo000]Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00UYF0`001eYF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
00000`001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo000[Ool00`00FUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH200000eYF001JEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;Woo000[Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`9J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUH000020005FUH20007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH02000FUH00000FUH005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00
FUIJEP06FUH01000FUH0000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002eoo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001J
EUYF00EJEP/0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP06FUH01000FUIJEUYF1000
00=JEP00FUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00P0000=JEP00FUH015YF00<005YF00000P001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`00;7oo000/Ool00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUH00005FUH00`00FUIJEP04FUH3
0008FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP02FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF2@0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH00UYF00@005YFFUH002ao
o`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF009J
EP04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH01000FUIJEUYF10000UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF10001UYF00<005YFFUH00eYF0P00;Goo000/Ool01000FUIJEP0015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP04
001JEP000005FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF
0P001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010000eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<007ooOol0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH40006FUH01000FUIJEUYF10000UYF00<005YF
FUH01eYF00<005YFFUH015YF2`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF10001eYF00<005YFFUH0
15YF00@005YFFUIJEP8002moo`00;Goo00<005YF000015YF00<005YF00000`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH005YF008000=JEP03001JEUYF00AJEP@0
00MJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0000000EJEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000]
Ool00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP020005FUH00`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP05FUH40003FUH20000
0eYF001JEP04FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP04FUH60002
FUH01000FUH00000<Goo000]Ool01000FUIJEP000UYF00@005YFFUH000QJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001JEP00008000AJEP03001JEUYF00MJ
EP03001JEUYF00@000EJEP8000=JEP03001JEUYF00=JEP03001JEP0000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40008FUH70003FUH00`00FUIJEP03FUH01000FUH00000<7oo000]Ool00`00FUIJEP030004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP02FUH20007FUH00`00FUIJEP05FUH50006FUH30006FUH00`00FUIJEP020002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEP000eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF100000=JEP00FUH01UYF00<0
05YFFUH00eYF00@005YFFUH0031oo`00;Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF1@000UYF2@002EYF00<005YFFUH01P0000=JEP00FUH00UYF100000=J
EP00FUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF00000P001EYF00<0
05YF00000`001UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;goo000^Ool015YF
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF100000=JEP00FUH01eYF
0P000eYF00<005YFFUH01EYF100000=JEP00000020001UYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00;Woo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF009JEP<000EJEP03001JEUYF00=JEP800003
FUH005YF00=JEPD00003FUH005YF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYF0003FUH00`00
FUIJEP02FUH20003FUH01000FUIJEUYF0`0015YF00<005YFFUH01UYF00<005YFFUH015YF3000;Woo
000^Ool01@00FUIJEUYF000015YF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01eYF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YF00000P000eYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH01UYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP04001JEUYF0004FUH01000FUH000001EYF10001eYF00<005YF
FUH01eYF00<005YF00000`0000=oo`0000001EYF00@005YFFUH002ioo`00;Woo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP8000=JEP03001JEUYF
00AJEP<000IJEPD000MJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000D00003FUH005YF00=JEP8000IJEP800003FUH0
05YF00QJEP03001JEUYF00AJEP@0009oo`<00003FUH005YF00EJEP8002moo`00<7oo1@000eYF00<0
05YFFUH00UYF1`0025YF00<005YFFUH01EYF0P001EYF00@005YFFUIJEP80009JEP04001JEUYFFUH4
0002FUH00`00FUIJEP06FUH01000FUIJEUYF1@003EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00D005YFFUH005YF0080009JEP03001JEUYF
00<000=JEP03001JEUYF00MJEP03001JEUYF00@000=oo`<000EJEP03001JEUYF00=JEP03001oogoo
02ioo`00=Goo20000Woo0P0000=JEP00FUH025YF00<005YFFUH015YF00@005YFFUH000AJEP05001J
EP00001JEP070006FUH00`00FUIJEP07FUH30004FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP020004FUH3
0007FUH00`00FUIJEP04FUH50005Ool200000eYF001JEP05FUH01000FUIJEUYF0P00<Goo000lOol3
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF1P000eYF00<005YFFUH01eYF
00<005YFFUH015YF0`001UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P001EYF00D005YF001JEP00009JEP800003FUH005YF00MJEP03001J
EUYF00@000Moo`<000=JEP03001JEUYF00EJEP<003=oo`00>Goo0`001eYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00@000UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000AJEP<0009JEP<000=JEP03001JEUYF00EJEP@000=oo`<0009oo`<000IJEP03001JEUYF00AJ
EP8003Eoo`00=Woo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP000000
009JEP04001JEP000006FUH00`00FUIJEP02FUH20006Ool600000eYF001JEP07FUH01000FUIJEUYF
0P00=goo000dOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF
0`001eYF00<005YF00000P0027oo1@000UYF00<005YFFUH01UYF00@005YF000003Uoo`00<Woo0`00
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01P0000=JEP00FUH015YF00<005YFFUH0
15YF1@002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000eYF00<005YFFUH015YF0P0000=JEP0000001Goo
20000eYF00<005YFFUH015YF0`00>goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH40004FUH01000FUIJEP001EYF00<005YFFUH0100015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P000UYF0`0015YF00<005YFFUH00UYF0`000UYF0P0000=oo`0000000P0000AJEP00
FUIJEP<000AJEP03001JEUYF00@003ioo`00;goo00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF300000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP04001JEP000002FUH60006FUH00`00FUIJ
EP05FUH40012Ool002ioo`8000EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000EJ
EP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP800003FUH005YF009JEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20016
Ool002eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP06
FUH01000FUH000000Woo0UYF00<005YFFUH015YF00<005YFFUH015YF2@0000=JEP00FUH02EYF3000
1UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008004Qoo`00;Goo00@005YFFUH000EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEPP00003
FUH005YF00EJEP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00QJEPP000UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF
00AJEP@004]oo`00;Woo00<005YF00001EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YF
FUH01UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00=JEP@000EJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000=JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@004moo`00;Woo
00<005YF00001EYF00<005YFFUH015YF0`0025YF00<005YFFUH01UYF10001UYF00D005YFFUIJEP00
009JEP04001JEUYFFUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH400000eYF001JEP07FUH00`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEP001UYF
00@005YFFUIJEPH005=oo`00;Woo00@005YFFUH000AJEP03001JEUYF009JEP80009JEP03001JEUYF
00MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00H005YF000005YF
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00020007FUH00`00FUIJEP02FUH00`00FUH00003FUH20002FUH01000FUIJEUYF1P000eYF0P00E7oo
000^Ool01000FUIJEP001EYF00@005YF000000EJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH00`00FUH0
000;0003FUH00`00FUIJEP03FUH00`00Oomoo`1COol002moo`03001JEP0000AJEP<000MJEP04001J
EUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP<00003FUH005YF00=JEP03001JEP0000MJEP03001JEUYF00AJEP04001JEUYFFUH2001FOol0
02moo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80006FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH30004FUH00`00FUH00008FUH00`00FUIJEP04FUH3001HOol0
02moo`03001JEUYF008000EJEP03001JEUYF009JEP800003FUH005YF00QJEP03001JEUYF00EJEPH0
0006Ool00000FUH005YF0P003UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00@005YFFUH000=JEP<000QJEPX005Qoo`00<7oo00AJEP00FUH0
00EJEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEUYF00@000Eoo`8000AJEP<000iJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04
001JEUYFFUH2000015YF0000000015YF100000=JEP00FUH00eYF00<005YFFUH00P00Egoo000`Ool2
00000eYF001JEP04FUH20007FUH00`00FUIJEP06FUH40006Ool30006FUH3000>FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH300000eYF000000020005FUH00`00FUIJEP03FUH01000FUIJEP00Egoo000aOol2000015YF001J
EUYF0`0025YF00<005YFFUH00eYF10001goo0P0000=JEP00FUH01eYF0P003UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH00UYF00<005YFFUH00P00EWoo000cOol40003
FUH00`00FUIJEP06FUH00`00FUH000060004Ool30004FUH00`00FUIJEP04FUH3000=FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH005Ioo`00<Woo
0`001EYF00<005YFFUH01EYF0`000goo0`000Woo0`001eYF00<005YFFUH00UYF0P000goo0P002eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP`005Eoo`00<7oo0P0000=JEP00FUH0
1UYF00<005YFFUH010001goo100000=JEP00FUH025YF00@005YF000000Moo`03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0004FUH00`00FUH000030002Ool00`00FUIJEP03FUH01000FUIJEP00
EGoo000^Ool20003FUH00`00FUIJEP04FUH40006Ool50006FUH00`00FUIJEP05FUH3000:Ool20008
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP000UYF100017oo0`001UYF0P00EWoo000]Ool20005FUH01000
FUIJEUYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P003goo0P001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000`001Woo0P000eYF00<005YFFUH00eYF00<007ooOol0EGoo000/Ool01000
FUIJEP0015YF00@005YF000000Aoo`@000IJEP03001JEUYF00MJEP03001JEP00008001=oo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000Moo`<000EJEP04001JEUYFFUH2001HOol002aoo`04001JEUYF0004FUH2
0002Ool400000eYF001JEP08FUH00`00FUIJEP04FUH4000HOol300000eYF001JEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomo
o`02Ool400000eYF001JEP06FUH3001JOol002eoo`03001JEP0000=JEPD000IJEP03001JEUYF00IJ
EP03001JEUYF00@001moo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEUYFFUH200000goo000000020005FUH00`00FUIJEP04FUH2001LOol002eo
o`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@002Ioo`@000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000@00003FUH005YF
00MJEP04001JEUYFFUH2001NOol002eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04
000^Ool400000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH80002
FUH00`00FUIJEP06FUH01000FUH00000H7oo000^Ool015YF001JEP001EYF00<005YFFUH015YF1000
=Woo1`001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH03@000UYF00<005YFFUH01EYF
0`00HWoo000^Ool01000FUIJEP001EYF00<005YFFUH01000@Goo3@001UYF00<005YFFUH015YF2000
00=oo`0000000P0000=JEP00FUH01@000eYF00<005YFFUH00UYF0P00IGoo000^Ool<001BOol>0002
Ool60006FUH00`00FUH000020004FUH00`00FUH00002001WOol008ioo`04001JEUYF0003FUH70003
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3001ZOol008ioo`05001JEUYF001JEP020002FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04001]Ool008moo`04001JEP000005FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH5001aOol008moo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00@007Ioo`00Sgoo00@005YFFUH000EJEP03001JEUYF00AJEP@007Yoo`00Sgoo0P000UYF00<0
05YFFUH00eYF00<005YF00000`00OWoo002@Ool;0022Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59806 .74923 m .59273 .69335 L .5617 .69449 L p .707 .577 .707 r
F P
0 g
s
.59273 .69335 m .59806 .74923 L .62977 .7457 L p .707 .577 .707 r
F P
0 g
s
.62977 .7457 m .62443 .68983 L .59273 .69335 L p .707 .577 .707 r
F P
0 g
s
.62443 .68983 m .62977 .7457 L .65904 .74015 L p .707 .577 .707 r
F P
0 g
s
.65904 .74015 m .65371 .68427 L .62443 .68983 L p .707 .577 .707 r
F P
0 g
s
.56703 .75037 m .5617 .69449 L .53439 .69314 L p .707 .577 .707 r
F P
0 g
s
.5617 .69449 m .56703 .75037 L .59806 .74923 L p .707 .577 .707 r
F P
0 g
s
.65371 .68427 m .65904 .74015 L .68303 .7331 L p .707 .577 .707 r
F P
0 g
s
.68303 .7331 m .6777 .67722 L .65371 .68427 L p .707 .577 .707 r
F P
0 g
s
.60104 .80271 m .59391 .76564 L .56332 .76988 L p .707 .577 .707 r
F P
0 g
s
.59391 .76564 m .60104 .80271 L .63235 .79639 L p .707 .577 .707 r
F P
0 g
s
.63235 .79639 m .62521 .75932 L .59391 .76564 L p .707 .577 .707 r
F P
0 g
s
.53439 .69314 m .53972 .74902 L .56703 .75037 L p .707 .577 .707 r
F P
0 g
s
.62521 .75932 m .63235 .79639 L .6613 .78862 L p .707 .577 .707 r
F P
0 g
s
.6613 .78862 m .65417 .75154 L .62521 .75932 L p .707 .577 .707 r
F P
0 g
s
.53972 .74902 m .53439 .69314 L .51346 .68943 L p .707 .577 .707 r
F P
0 g
s
.56332 .76988 m .57046 .80695 L .60104 .80271 L p .707 .577 .707 r
F P
0 g
s
.57046 .80695 m .56332 .76988 L .53646 .77163 L p .707 .577 .707 r
F P
0 g
s
.65417 .75154 m .6613 .78862 L .68509 .78014 L p .707 .577 .707 r
F P
0 g
s
.68509 .78014 m .67795 .74307 L .65417 .75154 L p .707 .577 .707 r
F P
0 g
s
.6777 .67722 m .68303 .7331 L .69938 .72525 L p .707 .577 .707 r
F P
0 g
s
.69938 .72525 m .69404 .66937 L .6777 .67722 L p .707 .577 .707 r
F P
0 g
s
.53646 .77163 m .5436 .80871 L .57046 .80695 L p .707 .577 .707 r
F P
0 g
s
.59554 .84187 m .59224 .82331 L .56158 .82708 L p .707 .577 .707 r
F P
0 g
s
.59224 .82331 m .59554 .84187 L .62692 .83597 L p .707 .577 .707 r
F P
0 g
s
.62692 .83597 m .62362 .81741 L .59224 .82331 L p .707 .577 .707 r
F P
0 g
s
.51346 .68943 m .5188 .74531 L .53972 .74902 L p .707 .577 .707 r
F P
0 g
s
.62362 .81741 m .62692 .83597 L .65595 .82853 L p .707 .577 .707 r
F P
0 g
s
.65595 .82853 m .65264 .80997 L .62362 .81741 L p .707 .577 .707 r
F P
0 g
s
.56158 .82708 m .56488 .84565 L .59554 .84187 L p .707 .577 .707 r
F P
0 g
s
.56488 .84565 m .56158 .82708 L .53462 .82837 L p .707 .577 .707 r
F P
0 g
s
.5436 .80871 m .53646 .77163 L .51594 .77072 L p .707 .577 .707 r
F P
0 g
s
.5188 .74531 m .51346 .68943 L .50098 .68373 L p .707 .577 .707 r
F P
0 g
s
.53462 .82837 m .53792 .84693 L .56488 .84565 L p .707 .577 .707 r
F P
0 g
s
.65264 .80997 m .65595 .82853 L .67977 .82027 L p .707 .577 .707 r
F P
0 g
s
.67977 .82027 m .67647 .80171 L .65264 .80997 L p .707 .577 .707 r
F P
0 g
s
.67795 .74307 m .68509 .78014 L .70136 .7718 L p .707 .577 .707 r
F P
0 g
s
.70136 .7718 m .69422 .73473 L .67795 .74307 L p .707 .577 .707 r
F P
0 g
s
.51594 .77072 m .52308 .80779 L .5436 .80871 L p .707 .577 .707 r
F P
0 g
s
.69404 .66937 m .69938 .72525 L .70648 .71736 L p .707 .577 .707 r
F P
0 g
s
.70648 .71736 m .70115 .66149 L .69404 .66937 L p .707 .577 .707 r
F P
0 g
s
.50098 .68373 m .50631 .73961 L .5188 .74531 L p .707 .577 .707 r
F P
0 g
s
.53792 .84693 m .53462 .82837 L .51402 .82703 L p .707 .577 .707 r
F P
0 g
s
.51402 .82703 m .51732 .8456 L .53792 .84693 L p .707 .577 .707 r
F P
0 g
s
.67647 .80171 m .67977 .82027 L .69606 .81201 L p .707 .577 .707 r
F P
0 g
s
.69606 .81201 m .69275 .79344 L .67647 .80171 L p .707 .577 .707 r
F P
0 g
s
.52308 .80779 m .51594 .77072 L .50377 .76724 L p .707 .577 .707 r
F P
0 g
s
.50631 .73961 m .50098 .68373 L .49815 .67659 L p .707 .577 .707 r
F P
0 g
s
.50377 .76724 m .51091 .80431 L .52308 .80779 L p .707 .577 .707 r
F P
0 g
s
.69422 .73473 m .70136 .7718 L .70854 .76441 L p .707 .577 .707 r
F P
0 g
s
.70854 .76441 m .7014 .72734 L .69422 .73473 L p .707 .577 .707 r
F P
0 g
s
.51732 .8456 m .51402 .82703 L .50179 .82321 L p .707 .577 .707 r
F P
0 g
s
.50179 .82321 m .50509 .84178 L .51732 .8456 L p .707 .577 .707 r
F P
0 g
s
.70115 .66149 m .70648 .71736 L .70365 .71022 L p .707 .577 .707 r
F P
0 g
s
.70365 .71022 m .69832 .65434 L .70115 .66149 L p .707 .577 .707 r
F P
0 g
s
.49815 .67659 m .50348 .73246 L .50631 .73961 L p .707 .577 .707 r
F P
0 g
s
.69275 .79344 m .69606 .81201 L .70322 .80454 L p .707 .577 .707 r
F P
0 g
s
.70322 .80454 m .69992 .78598 L .69275 .79344 L p .707 .577 .707 r
F P
0 g
s
.47849 .82203 m .49729 .32254 L .45331 .31819 L p .707 .577 .707 r
F P
0 g
s
.51091 .80431 m .50377 .76724 L .50114 .76152 L p .707 .577 .707 r
F P
0 g
s
.50114 .76152 m .50828 .79859 L .51091 .80431 L p .707 .577 .707 r
F P
0 g
s
.50348 .73246 m .49815 .67659 L .50525 .6687 L p .707 .577 .707 r
F P
0 g
s
.50509 .84178 m .50179 .82321 L .49913 .81728 L p .707 .577 .707 r
F P
0 g
s
.49913 .81728 m .50243 .83584 L .50509 .84178 L p .707 .577 .707 r
F P
0 g
s
.50525 .6687 m .51059 .72458 L .50348 .73246 L p .707 .577 .707 r
F P
0 g
s
.50828 .79859 m .50114 .76152 L .50832 .75413 L p .707 .577 .707 r
F P
0 g
s
.50832 .75413 m .51546 .7912 L .50828 .79859 L p .707 .577 .707 r
F P
0 g
s
.51059 .72458 m .50525 .6687 L .5216 .66085 L p .707 .577 .707 r
F P
0 g
s
.50243 .83584 m .49913 .81728 L .50629 .80981 L p .707 .577 .707 r
F P
0 g
s
.50629 .80981 m .50959 .82838 L .50243 .83584 L p .707 .577 .707 r
F P
0 g
s
.5216 .66085 m .52693 .71673 L .51059 .72458 L p .707 .577 .707 r
F P
0 g
s
.51546 .7912 m .50832 .75413 L .5246 .74579 L p .707 .577 .707 r
F P
0 g
s
.5246 .74579 m .53173 .78286 L .51546 .7912 L p .707 .577 .707 r
F P
0 g
s
.50959 .82838 m .50629 .80981 L .52258 .80155 L p .707 .577 .707 r
F P
0 g
s
.52258 .80155 m .52588 .82011 L .50959 .82838 L p .707 .577 .707 r
F P
0 g
s
.49729 .32254 m .47849 .82203 L .52341 .82244 L p .707 .577 .707 r
F P
0 g
s
.52693 .71673 m .5216 .66085 L .54559 .65381 L p .707 .577 .707 r
F P
0 g
s
.54559 .65381 m .55092 .70968 L .52693 .71673 L p .707 .577 .707 r
F P
0 g
s
.53173 .78286 m .5246 .74579 L .54838 .73731 L p .707 .577 .707 r
F P
0 g
s
.52588 .82011 m .52258 .80155 L .5464 .79329 L p .707 .577 .707 r
F P
0 g
s
.52341 .82244 m .5422 .32295 L .49729 .32254 L p .707 .577 .707 r
F P
0 g
s
.55092 .70968 m .54559 .65381 L .57486 .64825 L p .707 .577 .707 r
F P
0 g
s
.54838 .73731 m .55552 .77438 L .53173 .78286 L p .707 .577 .707 r
F P
0 g
s
.57486 .64825 m .5802 .70413 L .55092 .70968 L p .707 .577 .707 r
F P
0 g
s
.55552 .77438 m .54838 .73731 L .57734 .72953 L p .707 .577 .707 r
F P
0 g
s
.5464 .79329 m .5497 .81185 L .52588 .82011 L p .707 .577 .707 r
F P
0 g
s
.57734 .72953 m .58447 .76661 L .55552 .77438 L p .707 .577 .707 r
F P
0 g
s
.5497 .81185 m .5464 .79329 L .57542 .78585 L p .707 .577 .707 r
F P
0 g
s
.57542 .78585 m .57872 .80441 L .5497 .81185 L p .707 .577 .707 r
F P
0 g
s
.5422 .32295 m .52341 .82244 L .56487 .81886 L p .707 .577 .707 r
F P
0 g
s
.56487 .81886 m .58366 .31937 L .5422 .32295 L p .707 .577 .707 r
F P
0 g
s
.43452 .81769 m .45331 .31819 L .41458 .31033 L p .707 .577 .707 r
F P
0 g
s
.45331 .31819 m .43452 .81769 L .47849 .82203 L p .707 .577 .707 r
F P
0 g
s
.7014 .72734 m .70854 .76441 L .70591 .75869 L p .707 .577 .707 r
F P
0 g
s
.70591 .75869 m .69877 .72162 L .7014 .72734 L p .707 .577 .707 r
F P
0 g
s
.5802 .70413 m .57486 .64825 L .60657 .64472 L p .707 .577 .707 r
F P
0 g
s
.60657 .64472 m .6119 .7006 L .5802 .70413 L p .707 .577 .707 r
F P
0 g
s
.58447 .76661 m .57734 .72953 L .60864 .72322 L p .707 .577 .707 r
F P
0 g
s
.60864 .72322 m .61578 .76029 L .58447 .76661 L p .707 .577 .707 r
F P
0 g
s
.57872 .80441 m .57542 .78585 L .6068 .77995 L p .707 .577 .707 r
F P
0 g
s
.6068 .77995 m .6101 .79851 L .57872 .80441 L p .707 .577 .707 r
F P
0 g
s
.58366 .31937 m .56487 .81886 L .59881 .81165 L p .707 .577 .707 r
F P
0 g
s
.59881 .81165 m .6176 .31216 L .58366 .31937 L p .707 .577 .707 r
F P
0 g
s
.69832 .65434 m .70365 .71022 L .69116 .70452 L p .707 .577 .707 r
F P
0 g
s
.69116 .70452 m .68583 .64864 L .69832 .65434 L p .707 .577 .707 r
F P
0 g
s
.69992 .78598 m .70322 .80454 L .70055 .79861 L p .707 .577 .707 r
F P
0 g
s
.70055 .79861 m .69725 .78004 L .69992 .78598 L p .707 .577 .707 r
F P
0 g
s
.39578 .80982 m .41458 .31033 L .38488 .29972 L p .707 .577 .707 r
F P
0 g
s
.41458 .31033 m .39578 .80982 L .43452 .81769 L p .707 .577 .707 r
F P
0 g
s
.25505 .70703 m .24972 .65115 L .21869 .6523 L p .707 .577 .707 r
F P
0 g
s
.24972 .65115 m .25505 .70703 L .28676 .70351 L p .707 .577 .707 r
F P
0 g
s
.28676 .70351 m .28142 .64763 L .24972 .65115 L p .707 .577 .707 r
F P
0 g
s
.28142 .64763 m .28676 .70351 L .31603 .69795 L p .707 .577 .707 r
F P
0 g
s
.31603 .69795 m .3107 .64207 L .28142 .64763 L p .707 .577 .707 r
F P
0 g
s
.22403 .70818 m .21869 .6523 L .19138 .65095 L p .707 .577 .707 r
F P
0 g
s
.21869 .6523 m .22403 .70818 L .25505 .70703 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69877 .72162 m .70591 .75869 L .69374 .75521 L p .707 .577 .707 r
F P
0 g
s
.69374 .75521 m .68661 .71813 L .69877 .72162 L p .707 .577 .707 r
F P
0 g
s
.3107 .64207 m .31603 .69795 L .34002 .6909 L p .707 .577 .707 r
F P
0 g
s
.34002 .6909 m .33469 .63502 L .3107 .64207 L p .707 .577 .707 r
F P
0 g
s
.63759 .64358 m .64293 .69946 L .6119 .7006 L p .707 .577 .707 r
F P
0 g
s
.6119 .7006 m .60657 .64472 L .63759 .64358 L p .707 .577 .707 r
F P
0 g
s
.63922 .71897 m .64636 .75605 L .61578 .76029 L p .707 .577 .707 r
F P
0 g
s
.61578 .76029 m .60864 .72322 L .63922 .71897 L p .707 .577 .707 r
F P
0 g
s
.63747 .77617 m .64077 .79474 L .6101 .79851 L p .707 .577 .707 r
F P
0 g
s
.6101 .79851 m .6068 .77995 L .63747 .77617 L p .707 .577 .707 r
F P
0 g
s
.6176 .31216 m .59881 .81165 L .62191 .80151 L p .707 .577 .707 r
F P
0 g
s
.62191 .80151 m .64071 .30202 L .6176 .31216 L p .707 .577 .707 r
F P
0 g
s
.68583 .64864 m .69116 .70452 L .67024 .70081 L p .707 .577 .707 r
F P
0 g
s
.67024 .70081 m .66491 .64493 L .68583 .64864 L p .707 .577 .707 r
F P
0 g
s
.19138 .65095 m .19671 .70683 L .22403 .70818 L p .707 .577 .707 r
F P
0 g
s
.25804 .76834 m .2509 .73126 L .22032 .73551 L p .707 .577 .707 r
F P
0 g
s
.2509 .73126 m .25804 .76834 L .28934 .76202 L p .707 .577 .707 r
F P
0 g
s
.28934 .76202 m .2822 .72494 L .2509 .73126 L p .707 .577 .707 r
F P
0 g
s
.2822 .72494 m .28934 .76202 L .3183 .75424 L p .707 .577 .707 r
F P
0 g
s
.3183 .75424 m .31116 .71717 L .2822 .72494 L p .707 .577 .707 r
F P
0 g
s
.19671 .70683 m .19138 .65095 L .17046 .64724 L p .707 .577 .707 r
F P
0 g
s
.69725 .78004 m .70055 .79861 L .68832 .79479 L p .707 .577 .707 r
F P
0 g
s
.68832 .79479 m .68502 .77622 L .69725 .78004 L p .707 .577 .707 r
F P
0 g
s
.22032 .73551 m .22746 .77258 L .25804 .76834 L p .707 .577 .707 r
F P
0 g
s
.22746 .77258 m .22032 .73551 L .19345 .73726 L p .707 .577 .707 r
F P
0 g
s
.36609 .79921 m .38488 .29972 L .36712 .28739 L p .707 .577 .707 r
F P
0 g
s
.38488 .29972 m .36609 .79921 L .39578 .80982 L p .707 .577 .707 r
F P
0 g
s
.33469 .63502 m .34002 .6909 L .35637 .68305 L p .707 .577 .707 r
F P
0 g
s
.35637 .68305 m .35103 .62717 L .33469 .63502 L p .707 .577 .707 r
F P
0 g
s
.31116 .71717 m .3183 .75424 L .34208 .74577 L p .707 .577 .707 r
F P
0 g
s
.34208 .74577 m .33494 .70869 L .31116 .71717 L p .707 .577 .707 r
F P
0 g
s
.19345 .73726 m .20059 .77433 L .22746 .77258 L p .707 .577 .707 r
F P
0 g
s
.17046 .64724 m .17579 .70312 L .19671 .70683 L p .707 .577 .707 r
F P
0 g
s
.68661 .71813 m .69374 .75521 L .67322 .75429 L p .707 .577 .707 r
F P
0 g
s
.67322 .75429 m .66608 .71722 L .68661 .71813 L p .707 .577 .707 r
F P
0 g
s
.25254 .81301 m .24924 .79445 L .21857 .79822 L p .707 .577 .707 r
F P
0 g
s
.24924 .79445 m .25254 .81301 L .28392 .80711 L p .707 .577 .707 r
F P
0 g
s
.28392 .80711 m .28062 .78855 L .24924 .79445 L p .707 .577 .707 r
F P
0 g
s
.28062 .78855 m .28392 .80711 L .31294 .79967 L p .707 .577 .707 r
F P
0 g
s
.31294 .79967 m .30964 .78111 L .28062 .78855 L p .707 .577 .707 r
F P
0 g
s
.66491 .64493 m .67024 .70081 L .64293 .69946 L p .707 .577 .707 r
F P
0 g
s
.64293 .69946 m .63759 .64358 L .66491 .64493 L p .707 .577 .707 r
F P
0 g
s
.21857 .79822 m .22187 .81679 L .25254 .81301 L p .707 .577 .707 r
F P
0 g
s
.20059 .77433 m .19345 .73726 L .17293 .73635 L p .707 .577 .707 r
F P
0 g
s
.17579 .70312 m .17046 .64724 L .15797 .64154 L p .707 .577 .707 r
F P
0 g
s
.22187 .81679 m .21857 .79822 L .19162 .79951 L p .707 .577 .707 r
F P
0 g
s
.19162 .79951 m .19492 .81807 L .22187 .81679 L p .707 .577 .707 r
F P
0 g
s
.30964 .78111 m .31294 .79967 L .33676 .79141 L p .707 .577 .707 r
F P
0 g
s
.33676 .79141 m .33346 .77285 L .30964 .78111 L p .707 .577 .707 r
F P
0 g
s
.33494 .70869 m .34208 .74577 L .35835 .73743 L p .707 .577 .707 r
F P
0 g
s
.35835 .73743 m .35121 .70035 L .33494 .70869 L p .707 .577 .707 r
F P
0 g
s
.17293 .73635 m .18007 .77342 L .20059 .77433 L p .707 .577 .707 r
F P
0 g
s
.68502 .77622 m .68832 .79479 L .66772 .79345 L p .707 .577 .707 r
F P
0 g
s
.66772 .79345 m .66442 .77489 L .68502 .77622 L p .707 .577 .707 r
F P
0 g
s
.64071 .30202 m .62191 .80151 L .63192 .78944 L p .707 .577 .707 r
F P
0 g
s
.63192 .78944 m .65071 .28995 L .64071 .30202 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .36305 .27457 L p .36009 .37768 L .707 .577 .707 r
F P
0 g
s
.35103 .62717 m .35637 .68305 L .36129 .67759 L p .707 .577 .707 r
F P
0 g
s
.36125 .66658 m .35103 .62717 L .36129 .67759 L .707 .577 .707 r
F
.36347 .67517 m .35814 .61929 L .35103 .62717 L p F P
0 g
s
.33346 .77285 m .33676 .79141 L .35305 .78315 L p .707 .577 .707 r
F P
0 g
s
.35305 .78315 m .34975 .76458 L .33346 .77285 L p .707 .577 .707 r
F P
0 g
s
.35121 .70035 m .35835 .73743 L .36553 .73003 L p .707 .577 .707 r
F P
0 g
s
.36553 .73003 m .35839 .69296 L .35121 .70035 L p .707 .577 .707 r
F P
0 g
s
.35531 .61215 m .35826 .64307 L p .34815 .66232 L .707 .577 .707 r
F P
0 g
s
.35826 .64307 m .36064 .66803 L .35655 .66616 L p .707 .577 .707 r
F P
0 g
s
.35655 .66616 m .34815 .66232 L p .35826 .64307 L .707 .577 .707 r
F P
0 g
s
.34815 .66232 m .34282 .60644 L .35531 .61215 L p .707 .577 .707 r
F P
0 g
s
.35074 .72083 m .3436 .68376 L .35577 .68724 L p .707 .577 .707 r
F P
0 g
s
.34975 .76458 m .35305 .78315 L .36021 .77568 L p .707 .577 .707 r
F P
0 g
s
.36021 .77568 m .35691 .75712 L .34975 .76458 L p .707 .577 .707 r
F P
0 g
s
.35424 .75119 m .35754 .76975 L .34531 .76593 L p .707 .577 .707 r
F P
0 g
s
.34531 .76593 m .34201 .74736 L .35424 .75119 L p .707 .577 .707 r
F P
0 g
s
.3436 .68376 m .35074 .72083 L .33021 .71992 L p .707 .577 .707 r
F P
0 g
s
.34878 .77126 m .36044 .46511 L .36009 .37768 L .707 .577 .707 r
F
.34833 .78689 m .34906 .76744 L p .34878 .77126 L F P
0 g
s
.35577 .68724 m .35646 .69086 L p .35074 .72083 L .707 .577 .707 r
F P
0 g
s
.35646 .69086 m .3629 .72432 L .35328 .72156 L p .707 .577 .707 r
F P
0 g
s
.35328 .72156 m .35074 .72083 L p .35646 .69086 L .707 .577 .707 r
F P
0 g
s
.34906 .76744 m .34937 .75934 L p .34878 .77126 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .36044 .46511 L p .34916 .76138 L .707 .577 .707 r
F P
0 g
s
.34937 .75934 m .34916 .76138 L .34878 .77126 L .707 .577 .707 r
F
.36044 .46511 m .36712 .28739 L p .36009 .37768 L F P
0 g
s
.36129 .67759 m .36347 .67517 L p .36125 .66658 L .707 .577 .707 r
F P
0 g
s
.15797 .64154 m .1633 .69741 L .17579 .70312 L p .707 .577 .707 r
F P
0 g
s
.66608 .71722 m .67322 .75429 L .64636 .75605 L p .707 .577 .707 r
F P
0 g
s
.64636 .75605 m .63922 .71897 L .66608 .71722 L p .707 .577 .707 r
F P
0 g
s
.19492 .81807 m .19162 .79951 L .17102 .79817 L p .707 .577 .707 r
F P
0 g
s
.17102 .79817 m .17432 .81674 L .19492 .81807 L p .707 .577 .707 r
F P
0 g
s
.35814 .61929 m .36347 .67517 L .36064 .66803 L p .707 .577 .707 r
F P
0 g
s
.36064 .66803 m .35531 .61215 L .35814 .61929 L p .707 .577 .707 r
F P
0 g
s
.35839 .69296 m .36553 .73003 L .3629 .72432 L p .707 .577 .707 r
F P
0 g
s
.3629 .72432 m .35577 .68724 L .35839 .69296 L p .707 .577 .707 r
F P
0 g
s
.35691 .75712 m .36021 .77568 L .35754 .76975 L p .707 .577 .707 r
F P
0 g
s
.35754 .76975 m .35424 .75119 L .35691 .75712 L p .707 .577 .707 r
F P
0 g
s
.36712 .28739 m .34833 .78689 L .36609 .79921 L p .707 .577 .707 r
F P
0 g
s
.18007 .77342 m .17293 .73635 L .16076 .73286 L p .707 .577 .707 r
F P
0 g
s
.1633 .69741 m .15797 .64154 L .15514 .63439 L p .707 .577 .707 r
F P
0 g
s
.16076 .73286 m .1679 .76993 L .18007 .77342 L p .707 .577 .707 r
F P
0 g
s
.66442 .77489 m .66772 .79345 L .64077 .79474 L p .707 .577 .707 r
F P
0 g
s
.64077 .79474 m .63747 .77617 L .66442 .77489 L p .707 .577 .707 r
F P
0 g
s
.17432 .81674 m .17102 .79817 L .15878 .79435 L p .707 .577 .707 r
F P
0 g
s
.15514 .63439 m .16047 .69027 L .1633 .69741 L p .707 .577 .707 r
F P
0 g
s
.15878 .79435 m .16208 .81292 L .17432 .81674 L p .707 .577 .707 r
F P
0 g
s
.65071 .28995 m .63192 .78944 L .62784 .77662 L p .707 .577 .707 r
F P
0 g
s
.62784 .77662 m .64664 .27712 L .65071 .28995 L p .707 .577 .707 r
F P
0 g
s
.1679 .76993 m .16076 .73286 L .15813 .72714 L p .707 .577 .707 r
F P
0 g
s
.16047 .69027 m .15514 .63439 L .16224 .62651 L p .707 .577 .707 r
F P
0 g
s
.15813 .72714 m .16527 .76421 L .1679 .76993 L p .707 .577 .707 r
F P
0 g
s
.34201 .74736 m .34531 .76593 L .32471 .76459 L p .707 .577 .707 r
F P
0 g
s
.36305 .27457 m .34426 .77406 L .34833 .78689 L p .707 .577 .707 r
F P
0 g
s
.34426 .77406 m .36305 .27457 L .37305 .2625 L p .707 .577 .707 r
F P
0 g
s
.16208 .81292 m .15878 .79435 L .15612 .78842 L p .707 .577 .707 r
F P
0 g
s
.16224 .62651 m .16758 .68239 L .16047 .69027 L p .707 .577 .707 r
F P
0 g
s
.15612 .78842 m .15942 .80698 L .16208 .81292 L p .707 .577 .707 r
F P
0 g
s
.16527 .76421 m .15813 .72714 L .16531 .71975 L p .707 .577 .707 r
F P
0 g
s
.16758 .68239 m .16224 .62651 L .17859 .61866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16531 .71975 m .17245 .75682 L .16527 .76421 L p .707 .577 .707 r
F P
0 g
s
.64664 .27712 m .62784 .77662 L .61009 .76429 L p .707 .577 .707 r
F P
0 g
s
.61009 .76429 m .62888 .2648 L .64664 .27712 L p .707 .577 .707 r
F P
0 g
s
.34282 .60644 m .34815 .66232 L .32723 .65861 L p .707 .577 .707 r
F P
0 g
s
.32723 .65861 m .3219 .60274 L .34282 .60644 L p .707 .577 .707 r
F P
0 g
s
.15942 .80698 m .15612 .78842 L .16328 .78096 L p .707 .577 .707 r
F P
0 g
s
.17859 .61866 m .18392 .67454 L .16758 .68239 L p .707 .577 .707 r
F P
0 g
s
.16328 .78096 m .16658 .79952 L .15942 .80698 L p .707 .577 .707 r
F P
0 g
s
.35426 .76199 m .37305 .2625 L .39616 .25236 L p .707 .577 .707 r
F P
0 g
s
.37305 .2625 m .35426 .76199 L .34426 .77406 L p .707 .577 .707 r
F P
0 g
s
.17245 .75682 m .16531 .71975 L .18159 .71141 L p .707 .577 .707 r
F P
0 g
s
.18392 .67454 m .17859 .61866 L .20258 .61161 L p .707 .577 .707 r
F P
0 g
s
.18159 .71141 m .18873 .74848 L .17245 .75682 L p .707 .577 .707 r
F P
0 g
s
.33021 .71992 m .32307 .68284 L .3436 .68376 L p .707 .577 .707 r
F P
0 g
s
.3219 .60274 m .32723 .65861 L .29992 .65727 L p .707 .577 .707 r
F P
0 g
s
.29992 .65727 m .29458 .60139 L .3219 .60274 L p .707 .577 .707 r
F P
0 g
s
.20258 .61161 m .20791 .66749 L .18392 .67454 L p .707 .577 .707 r
F P
0 g
s
.62888 .2648 m .61009 .76429 L .58039 .75368 L p .707 .577 .707 r
F P
0 g
s
.58039 .75368 m .59919 .25419 L .62888 .2648 L p .707 .577 .707 r
F P
0 g
s
.16658 .79952 m .16328 .78096 L .17957 .77269 L p .707 .577 .707 r
F P
0 g
s
.20791 .66749 m .20258 .61161 L .23185 .60605 L p .707 .577 .707 r
F P
0 g
s
.17957 .77269 m .18287 .79125 L .16658 .79952 L p .707 .577 .707 r
F P
0 g
s
.18873 .74848 m .18159 .71141 L .20537 .70294 L p .707 .577 .707 r
F P
0 g
s
.32471 .76459 m .32141 .74603 L .34201 .74736 L p .707 .577 .707 r
F P
0 g
s
.29458 .60139 m .29992 .65727 L .26889 .65841 L p .707 .577 .707 r
F P
0 g
s
.26889 .65841 m .26356 .60253 L .29458 .60139 L p .707 .577 .707 r
F P
0 g
s
.39616 .25236 m .37736 .75185 L .35426 .76199 L p .707 .577 .707 r
F P
0 g
s
.37736 .75185 m .39616 .25236 L .4301 .24515 L p .707 .577 .707 r
F P
0 g
s
.32307 .68284 m .33021 .71992 L .30335 .72167 L p .707 .577 .707 r
F P
0 g
s
.30335 .72167 m .29621 .6846 L .32307 .68284 L p .707 .577 .707 r
F P
0 g
s
.23719 .66193 m .23185 .60605 L .26356 .60253 L p .707 .577 .707 r
F P
0 g
s
.23185 .60605 m .23719 .66193 L .20791 .66749 L p .707 .577 .707 r
F P
0 g
s
.20537 .70294 m .21251 .74001 L .18873 .74848 L p .707 .577 .707 r
F P
0 g
s
.26356 .60253 m .26889 .65841 L .23719 .66193 L p .707 .577 .707 r
F P
0 g
s
.73527 .65719 m .72993 .60131 L .69891 .60245 L p .707 .577 .707 r
F P
0 g
s
.72993 .60131 m .73527 .65719 L .76697 .65367 L p .707 .577 .707 r
F P
0 g
s
.76697 .65367 m .76164 .59779 L .72993 .60131 L p .707 .577 .707 r
F P
0 g
s
.76164 .59779 m .76697 .65367 L .79625 .64811 L p .707 .577 .707 r
F P
0 g
s
.79625 .64811 m .79091 .59223 L .76164 .59779 L p .707 .577 .707 r
F P
0 g
s
.18287 .79125 m .17957 .77269 L .20339 .76443 L p .707 .577 .707 r
F P
0 g
s
.70424 .65833 m .69891 .60245 L .67159 .6011 L p .707 .577 .707 r
F P
0 g
s
.69891 .60245 m .70424 .65833 L .73527 .65719 L p .707 .577 .707 r
F P
0 g
s
.21251 .74001 m .20537 .70294 L .23433 .69516 L p .707 .577 .707 r
F P
0 g
s
.20339 .76443 m .20669 .78299 L .18287 .79125 L p .707 .577 .707 r
F P
0 g
s
.59919 .25419 m .58039 .75368 L .54166 .74581 L p .707 .577 .707 r
F P
0 g
s
.54166 .74581 m .56045 .24632 L .59919 .25419 L p .707 .577 .707 r
F P
0 g
s
.29621 .6846 m .30335 .72167 L .27277 .72591 L p .707 .577 .707 r
F P
0 g
s
.27277 .72591 m .26563 .68884 L .29621 .6846 L p .707 .577 .707 r
F P
0 g
s
.79091 .59223 m .79625 .64811 L .82023 .64106 L p .707 .577 .707 r
F P
0 g
s
.82023 .64106 m .8149 .58518 L .79091 .59223 L p .707 .577 .707 r
F P
0 g
s
.32141 .74603 m .32471 .76459 L .29776 .76588 L p .707 .577 .707 r
F P
0 g
s
.29776 .76588 m .29446 .74731 L .32141 .74603 L p .707 .577 .707 r
F P
0 g
s
.23433 .69516 m .24146 .73223 L .21251 .74001 L p .707 .577 .707 r
F P
0 g
s
.73825 .71067 m .73111 .6736 L .70053 .67784 L p .707 .577 .707 r
F P
0 g
s
.73111 .6736 m .73825 .71067 L .76955 .70435 L p .707 .577 .707 r
F P
0 g
s
.76955 .70435 m .76241 .66728 L .73111 .6736 L p .707 .577 .707 r
F P
0 g
s
.24146 .73223 m .23433 .69516 L .26563 .68884 L p .707 .577 .707 r
F P
0 g
s
.67159 .6011 m .67693 .65698 L .70424 .65833 L p .707 .577 .707 r
F P
0 g
s
.76241 .66728 m .76955 .70435 L .79851 .69658 L p .707 .577 .707 r
F P
0 g
s
.79851 .69658 m .79137 .6595 L .76241 .66728 L p .707 .577 .707 r
F P
0 g
s
.26563 .68884 m .27277 .72591 L .24146 .73223 L p .707 .577 .707 r
F P
0 g
s
.41131 .74464 m .4301 .24515 L .47156 .24157 L p .707 .577 .707 r
F P
0 g
s
.4301 .24515 m .41131 .74464 L .37736 .75185 L p .707 .577 .707 r
F P
0 g
s
.67693 .65698 m .67159 .6011 L .65067 .5974 L p .707 .577 .707 r
F P
0 g
s
.20669 .78299 m .20339 .76443 L .23241 .75699 L p .707 .577 .707 r
F P
0 g
s
.70053 .67784 m .70767 .71492 L .73825 .71067 L p .707 .577 .707 r
F P
0 g
s
.70767 .71492 m .70053 .67784 L .67366 .6796 L p .707 .577 .707 r
F P
0 g
s
.23241 .75699 m .23571 .77555 L .20669 .78299 L p .707 .577 .707 r
F P
0 g
s
.29446 .74731 m .29776 .76588 L .26709 .76965 L p .707 .577 .707 r
F P
0 g
s
.26709 .76965 m .26379 .75109 L .29446 .74731 L p .707 .577 .707 r
F P
0 g
s
.79137 .6595 m .79851 .69658 L .82229 .6881 L p .707 .577 .707 r
F P
0 g
s
.82229 .6881 m .81515 .65103 L .79137 .6595 L p .707 .577 .707 r
F P
0 g
s
.8149 .58518 m .82023 .64106 L .83658 .63321 L p .707 .577 .707 r
F P
0 g
s
.83658 .63321 m .83125 .57733 L .8149 .58518 L p .707 .577 .707 r
F P
0 g
s
.56045 .24632 m .54166 .74581 L .49768 .74147 L p .707 .577 .707 r
F P
0 g
s
.49768 .74147 m .51648 .24197 L .56045 .24632 L p .707 .577 .707 r
F P
0 g
s
.67366 .6796 m .6808 .71667 L .70767 .71492 L p .707 .577 .707 r
F P
0 g
s
.73275 .74983 m .72945 .73127 L .69878 .73505 L p .707 .577 .707 r
F P
0 g
s
.72945 .73127 m .73275 .74983 L .76413 .74394 L p .707 .577 .707 r
F P
0 g
s
.76413 .74394 m .76083 .72537 L .72945 .73127 L p .707 .577 .707 r
F P
0 g
s
.65067 .5974 m .656 .65327 L .67693 .65698 L p .707 .577 .707 r
F P
0 g
s
.76083 .72537 m .76413 .74394 L .79315 .73649 L p .707 .577 .707 r
F P
0 g
s
.79315 .73649 m .78985 .71793 L .76083 .72537 L p .707 .577 .707 r
F P
0 g
s
.23571 .77555 m .23241 .75699 L .26379 .75109 L p .707 .577 .707 r
F P
0 g
s
.26379 .75109 m .26709 .76965 L .23571 .77555 L p .707 .577 .707 r
F P
0 g
s
.45277 .74106 m .47156 .24157 L .51648 .24197 L p .707 .577 .707 r
F P
0 g
s
.47156 .24157 m .45277 .74106 L .41131 .74464 L p .707 .577 .707 r
F P
0 g
s
.69878 .73505 m .70208 .75361 L .73275 .74983 L p .707 .577 .707 r
F P
0 g
s
.51648 .24197 m .49768 .74147 L .45277 .74106 L p .707 .577 .707 r
F P
0 g
s
.70208 .75361 m .69878 .73505 L .67183 .73633 L p .707 .577 .707 r
F P
0 g
s
.6808 .71667 m .67366 .6796 L .65314 .67868 L p .707 .577 .707 r
F P
0 g
s
.656 .65327 m .65067 .5974 L .63818 .59169 L p .707 .577 .707 r
F P
0 g
s
.67183 .73633 m .67513 .75489 L .70208 .75361 L p .707 .577 .707 r
F P
0 g
s
.78985 .71793 m .79315 .73649 L .81697 .72823 L p .707 .577 .707 r
F P
0 g
s
.81697 .72823 m .81367 .70967 L .78985 .71793 L p .707 .577 .707 r
F P
0 g
s
.81515 .65103 m .82229 .6881 L .83857 .67976 L p .707 .577 .707 r
F P
0 g
s
.83857 .67976 m .83143 .64269 L .81515 .65103 L p .707 .577 .707 r
F P
0 g
s
.65314 .67868 m .66028 .71576 L .6808 .71667 L p .707 .577 .707 r
F P
0 g
s
.83125 .57733 m .83658 .63321 L .84369 .62533 L p .707 .577 .707 r
F P
0 g
s
.84369 .62533 m .83835 .56945 L .83125 .57733 L p .707 .577 .707 r
F P
0 g
s
.63818 .59169 m .64351 .64757 L .656 .65327 L p .707 .577 .707 r
F P
0 g
s
.67513 .75489 m .67183 .73633 L .65123 .735 L p .707 .577 .707 r
F P
0 g
s
.65123 .735 m .65453 .75356 L .67513 .75489 L p .707 .577 .707 r
F P
0 g
s
.81367 .70967 m .81697 .72823 L .83326 .71997 L p .707 .577 .707 r
F P
0 g
s
.83326 .71997 m .82996 .7014 L .81367 .70967 L p .707 .577 .707 r
F P
0 g
s
.66028 .71576 m .65314 .67868 L .64097 .6752 L p .707 .577 .707 r
F P
0 g
s
.64351 .64757 m .63818 .59169 L .63535 .58455 L p .707 .577 .707 r
F P
0 g
s
.64097 .6752 m .64811 .71227 L .66028 .71576 L p .707 .577 .707 r
F P
0 g
s
.83143 .64269 m .83857 .67976 L .84574 .67237 L p .707 .577 .707 r
F P
0 g
s
.84574 .67237 m .8386 .6353 L .83143 .64269 L p .707 .577 .707 r
F P
0 g
s
.65453 .75356 m .65123 .735 L .639 .73118 L p .707 .577 .707 r
F P
0 g
s
.639 .73118 m .6423 .74974 L .65453 .75356 L p .707 .577 .707 r
F P
0 g
s
.83835 .56945 m .84369 .62533 L .84086 .61818 L p .707 .577 .707 r
F P
0 g
s
.84086 .61818 m .83552 .5623 L .83835 .56945 L p .707 .577 .707 r
F P
0 g
s
.63535 .58455 m .64068 .64043 L .64351 .64757 L p .707 .577 .707 r
F P
0 g
s
.82996 .7014 m .83326 .71997 L .84042 .7125 L p .707 .577 .707 r
F P
0 g
s
.84042 .7125 m .83712 .69394 L .82996 .7014 L p .707 .577 .707 r
F P
0 g
s
.64811 .71227 m .64097 .6752 L .63835 .66948 L p .707 .577 .707 r
F P
0 g
s
.63835 .66948 m .64549 .70655 L .64811 .71227 L p .707 .577 .707 r
F P
0 g
s
.64068 .64043 m .63535 .58455 L .64246 .57667 L p .707 .577 .707 r
F P
0 g
s
.8386 .6353 m .84574 .67237 L .84312 .66665 L p .707 .577 .707 r
F P
0 g
s
.84312 .66665 m .83598 .62958 L .8386 .6353 L p .707 .577 .707 r
F P
0 g
s
.6423 .74974 m .639 .73118 L .63633 .72524 L p .707 .577 .707 r
F P
0 g
s
.63633 .72524 m .63963 .7438 L .6423 .74974 L p .707 .577 .707 r
F P
0 g
s
.83552 .5623 m .84086 .61818 L .82837 .61248 L p .707 .577 .707 r
F P
0 g
s
.82837 .61248 m .82304 .5566 L .83552 .5623 L p .707 .577 .707 r
F P
0 g
s
.64246 .57667 m .64779 .63254 L .64068 .64043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83712 .69394 m .84042 .7125 L .83776 .70657 L p .707 .577 .707 r
F P
0 g
s
.83776 .70657 m .83446 .68801 L .83712 .69394 L p .707 .577 .707 r
F P
0 g
s
.64549 .70655 m .63835 .66948 L .64552 .66209 L p .707 .577 .707 r
F P
0 g
s
.39226 .61499 m .38692 .55912 L .3559 .56026 L p .707 .577 .707 r
F P
0 g
s
.38692 .55912 m .39226 .61499 L .42396 .61147 L p .707 .577 .707 r
F P
0 g
s
.42396 .61147 m .41863 .55559 L .38692 .55912 L p .707 .577 .707 r
F P
0 g
s
.41863 .55559 m .42396 .61147 L .45324 .60591 L p .707 .577 .707 r
F P
0 g
s
.45324 .60591 m .4479 .55003 L .41863 .55559 L p .707 .577 .707 r
F P
0 g
s
.64552 .66209 m .65266 .69916 L .64549 .70655 L p .707 .577 .707 r
F P
0 g
s
.64779 .63254 m .64246 .57667 L .6588 .56882 L p .707 .577 .707 r
F P
0 g
s
.36123 .61614 m .3559 .56026 L .32858 .55891 L p .707 .577 .707 r
F P
0 g
s
.3559 .56026 m .36123 .61614 L .39226 .61499 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83598 .62958 m .84312 .66665 L .83095 .66317 L p .707 .577 .707 r
F P
0 g
s
.83095 .66317 m .82381 .62609 L .83598 .62958 L p .707 .577 .707 r
F P
0 g
s
.4479 .55003 m .45324 .60591 L .47722 .59886 L p .707 .577 .707 r
F P
0 g
s
.47722 .59886 m .47189 .54299 L .4479 .55003 L p .707 .577 .707 r
F P
0 g
s
.63963 .7438 m .63633 .72524 L .6435 .71778 L p .707 .577 .707 r
F P
0 g
s
.82304 .5566 m .82837 .61248 L .80744 .60877 L p .707 .577 .707 r
F P
0 g
s
.80744 .60877 m .80211 .55289 L .82304 .5566 L p .707 .577 .707 r
F P
0 g
s
.6435 .71778 m .6468 .73634 L .63963 .7438 L p .707 .577 .707 r
F P
0 g
s
.6588 .56882 m .66414 .62469 L .64779 .63254 L p .707 .577 .707 r
F P
0 g
s
.32858 .55891 m .33392 .61479 L .36123 .61614 L p .707 .577 .707 r
F P
0 g
s
.39524 .6763 m .3881 .63922 L .35752 .64347 L p .707 .577 .707 r
F P
0 g
s
.3881 .63922 m .39524 .6763 L .42654 .66998 L p .707 .577 .707 r
F P
0 g
s
.42654 .66998 m .4194 .63291 L .3881 .63922 L p .707 .577 .707 r
F P
0 g
s
.4194 .63291 m .42654 .66998 L .4555 .6622 L p .707 .577 .707 r
F P
0 g
s
.4555 .6622 m .44836 .62513 L .4194 .63291 L p .707 .577 .707 r
F P
0 g
s
.33392 .61479 m .32858 .55891 L .30766 .5552 L p .707 .577 .707 r
F P
0 g
s
.83446 .68801 m .83776 .70657 L .82553 .70275 L p .707 .577 .707 r
F P
0 g
s
.82553 .70275 m .82223 .68419 L .83446 .68801 L p .707 .577 .707 r
F P
0 g
s
.35752 .64347 m .36466 .68054 L .39524 .6763 L p .707 .577 .707 r
F P
0 g
s
.65266 .69916 m .64552 .66209 L .6618 .65375 L p .707 .577 .707 r
F P
0 g
s
.36466 .68054 m .35752 .64347 L .33065 .64522 L p .707 .577 .707 r
F P
0 g
s
.47189 .54299 m .47722 .59886 L .49357 .59101 L p .707 .577 .707 r
F P
0 g
s
.49357 .59101 m .48824 .53514 L .47189 .54299 L p .707 .577 .707 r
F P
0 g
s
.66414 .62469 m .6588 .56882 L .68279 .56177 L p .707 .577 .707 r
F P
0 g
s
.44836 .62513 m .4555 .6622 L .47928 .65373 L p .707 .577 .707 r
F P
0 g
s
.47928 .65373 m .47214 .61665 L .44836 .62513 L p .707 .577 .707 r
F P
0 g
s
.6618 .65375 m .66894 .69082 L .65266 .69916 L p .707 .577 .707 r
F P
0 g
s
.33065 .64522 m .33779 .68229 L .36466 .68054 L p .707 .577 .707 r
F P
0 g
s
.30766 .5552 m .31299 .61108 L .33392 .61479 L p .707 .577 .707 r
F P
0 g
s
.82381 .62609 m .83095 .66317 L .81043 .66226 L p .707 .577 .707 r
F P
0 g
s
.81043 .66226 m .80329 .62518 L .82381 .62609 L p .707 .577 .707 r
F P
0 g
s
.38974 .72097 m .38644 .70241 L .35577 .70619 L p .707 .577 .707 r
F P
0 g
s
.38644 .70241 m .38974 .72097 L .42112 .71508 L p .707 .577 .707 r
F P
0 g
s
.42112 .71508 m .41782 .69651 L .38644 .70241 L p .707 .577 .707 r
F P
0 g
s
.41782 .69651 m .42112 .71508 L .45014 .70763 L p .707 .577 .707 r
F P
0 g
s
.45014 .70763 m .44684 .68907 L .41782 .69651 L p .707 .577 .707 r
F P
0 g
s
.80211 .55289 m .80744 .60877 L .78013 .60742 L p .707 .577 .707 r
F P
0 g
s
.78013 .60742 m .7748 .55154 L .80211 .55289 L p .707 .577 .707 r
F P
0 g
s
.35577 .70619 m .35907 .72475 L .38974 .72097 L p .707 .577 .707 r
F P
0 g
s
.6468 .73634 m .6435 .71778 L .65979 .70951 L p .707 .577 .707 r
F P
0 g
s
.68279 .56177 m .68812 .61765 L .66414 .62469 L p .707 .577 .707 r
F P
0 g
s
.33779 .68229 m .33065 .64522 L .31013 .64431 L p .707 .577 .707 r
F P
0 g
s
.31299 .61108 m .30766 .5552 L .29517 .5495 L p .707 .577 .707 r
F P
0 g
s
.35907 .72475 m .35577 .70619 L .32882 .70747 L p .707 .577 .707 r
F P
0 g
s
.65979 .70951 m .66309 .72807 L .6468 .73634 L p .707 .577 .707 r
F P
0 g
s
.32882 .70747 m .33212 .72603 L .35907 .72475 L p .707 .577 .707 r
F P
0 g
s
.44684 .68907 m .45014 .70763 L .47396 .69937 L p .707 .577 .707 r
F P
0 g
s
.47396 .69937 m .47066 .68081 L .44684 .68907 L p .707 .577 .707 r
F P
0 g
s
.68812 .61765 m .68279 .56177 L .71207 .55621 L p .707 .577 .707 r
F P
0 g
s
.47214 .61665 m .47928 .65373 L .49556 .64539 L p .707 .577 .707 r
F P
0 g
s
.49556 .64539 m .48842 .60831 L .47214 .61665 L p .707 .577 .707 r
F P
0 g
s
.31013 .64431 m .31727 .68138 L .33779 .68229 L p .707 .577 .707 r
F P
0 g
s
.82223 .68419 m .82553 .70275 L .80493 .70141 L p .707 .577 .707 r
F P
0 g
s
.80493 .70141 m .80163 .68285 L .82223 .68419 L p .707 .577 .707 r
F P
0 g
s
.66894 .69082 m .6618 .65375 L .68558 .64527 L p .707 .577 .707 r
F P
0 g
s
.7748 .55154 m .78013 .60742 L .74911 .60856 L p .707 .577 .707 r
F P
0 g
s
.74911 .60856 m .74377 .55269 L .7748 .55154 L p .707 .577 .707 r
F P
0 g
s
.48824 .53514 m .49357 .59101 L .50068 .58313 L p .707 .577 .707 r
F P
0 g
s
.50068 .58313 m .49534 .52725 L .48824 .53514 L p .707 .577 .707 r
F P
0 g
s
.29517 .5495 m .3005 .60538 L .31299 .61108 L p .707 .577 .707 r
F P
0 g
s
.80329 .62518 m .81043 .66226 L .78356 .66401 L p .707 .577 .707 r
F P
0 g
s
.78356 .66401 m .77642 .62693 L .80329 .62518 L p .707 .577 .707 r
F P
0 g
s
.68558 .64527 m .69272 .68235 L .66894 .69082 L p .707 .577 .707 r
F P
0 g
s
.7174 .61209 m .71207 .55621 L .74377 .55269 L p .707 .577 .707 r
F P
0 g
s
.71207 .55621 m .7174 .61209 L .68812 .61765 L p .707 .577 .707 r
F P
0 g
s
.33212 .72603 m .32882 .70747 L .30822 .70614 L p .707 .577 .707 r
F P
0 g
s
.74377 .55269 m .74911 .60856 L .7174 .61209 L p .707 .577 .707 r
F P
0 g
s
.30822 .70614 m .31152 .7247 L .33212 .72603 L p .707 .577 .707 r
F P
0 g
s
.31727 .68138 m .31013 .64431 L .29796 .64082 L p .707 .577 .707 r
F P
0 g
s
.47066 .68081 m .47396 .69937 L .49025 .69111 L p .707 .577 .707 r
F P
0 g
s
.49025 .69111 m .48695 .67255 L .47066 .68081 L p .707 .577 .707 r
F P
0 g
s
.66309 .72807 m .65979 .70951 L .68361 .70125 L p .707 .577 .707 r
F P
0 g
s
.69272 .68235 m .68558 .64527 L .71454 .6375 L p .707 .577 .707 r
F P
0 g
s
.68361 .70125 m .68691 .71981 L .66309 .72807 L p .707 .577 .707 r
F P
0 g
s
.3005 .60538 m .29517 .5495 L .29234 .54235 L p .707 .577 .707 r
F P
0 g
s
.29796 .64082 m .3051 .67789 L .31727 .68138 L p .707 .577 .707 r
F P
0 g
s
.80163 .68285 m .80493 .70141 L .77798 .7027 L p .707 .577 .707 r
F P
0 g
s
.77798 .7027 m .77467 .68414 L .80163 .68285 L p .707 .577 .707 r
F P
0 g
s
.77642 .62693 m .78356 .66401 L .75298 .66825 L p .707 .577 .707 r
F P
0 g
s
.75298 .66825 m .74584 .63118 L .77642 .62693 L p .707 .577 .707 r
F P
0 g
s
.48842 .60831 m .49556 .64539 L .50273 .638 L p .707 .577 .707 r
F P
0 g
s
.50273 .638 m .49559 .60092 L .48842 .60831 L p .707 .577 .707 r
F P
0 g
s
.71454 .6375 m .72168 .67457 L .69272 .68235 L p .707 .577 .707 r
F P
0 g
s
.72168 .67457 m .71454 .6375 L .74584 .63118 L p .707 .577 .707 r
F P
0 g
s
.74584 .63118 m .75298 .66825 L .72168 .67457 L p .707 .577 .707 r
F P
0 g
s
.31152 .7247 m .30822 .70614 L .29599 .70232 L p .707 .577 .707 r
F P
0 g
s
.49534 .52725 m .50068 .58313 L .49785 .57599 L p .707 .577 .707 r
F P
0 g
s
.49785 .57599 m .49251 .52011 L .49534 .52725 L p .707 .577 .707 r
F P
0 g
s
.29234 .54235 m .29767 .59823 L .3005 .60538 L p .707 .577 .707 r
F P
0 g
s
.68691 .71981 m .68361 .70125 L .71263 .69381 L p .707 .577 .707 r
F P
0 g
s
.29599 .70232 m .29929 .72088 L .31152 .7247 L p .707 .577 .707 r
F P
0 g
s
.71263 .69381 m .71593 .71237 L .68691 .71981 L p .707 .577 .707 r
F P
0 g
s
.77467 .68414 m .77798 .7027 L .74731 .70647 L p .707 .577 .707 r
F P
0 g
s
.74731 .70647 m .74401 .68791 L .77467 .68414 L p .707 .577 .707 r
F P
0 g
s
.48695 .67255 m .49025 .69111 L .49741 .68364 L p .707 .577 .707 r
F P
0 g
s
.49741 .68364 m .49411 .66508 L .48695 .67255 L p .707 .577 .707 r
F P
0 g
s
.3051 .67789 m .29796 .64082 L .29534 .6351 L p .707 .577 .707 r
F P
0 g
s
.71593 .71237 m .71263 .69381 L .74401 .68791 L p .707 .577 .707 r
F P
0 g
s
.74401 .68791 m .74731 .70647 L .71593 .71237 L p .707 .577 .707 r
F P
0 g
s
.29767 .59823 m .29234 .54235 L .29945 .53447 L p .707 .577 .707 r
F P
0 g
s
.29534 .6351 m .30248 .67218 L .3051 .67789 L p .707 .577 .707 r
F P
0 g
s
.49559 .60092 m .50273 .638 L .50011 .63228 L p .707 .577 .707 r
F P
0 g
s
.50011 .63228 m .49297 .5952 L .49559 .60092 L p .707 .577 .707 r
F P
0 g
s
.29929 .72088 m .29599 .70232 L .29332 .69638 L p .707 .577 .707 r
F P
0 g
s
.49251 .52011 m .49785 .57599 L .48536 .57028 L p .707 .577 .707 r
F P
0 g
s
.48536 .57028 m .48003 .51441 L .49251 .52011 L p .707 .577 .707 r
F P
0 g
s
.29945 .53447 m .30478 .59035 L .29767 .59823 L p .707 .577 .707 r
F P
0 g
s
.29332 .69638 m .29662 .71495 L .29929 .72088 L p .707 .577 .707 r
F P
0 g
s
.49411 .66508 m .49741 .68364 L .49475 .67771 L p .707 .577 .707 r
F P
0 g
s
.49475 .67771 m .49145 .65915 L .49411 .66508 L p .707 .577 .707 r
F P
0 g
s
.30248 .67218 m .29534 .6351 L .30251 .62771 L p .707 .577 .707 r
F P
0 g
s
.30478 .59035 m .29945 .53447 L .31579 .52662 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30251 .62771 m .30965 .66478 L .30248 .67218 L p .707 .577 .707 r
F P
0 g
s
.49297 .5952 m .50011 .63228 L .48794 .62879 L p .707 .577 .707 r
F P
0 g
s
.48794 .62879 m .4808 .59172 L .49297 .5952 L p .707 .577 .707 r
F P
0 g
s
.48003 .51441 m .48536 .57028 L .46443 .56658 L p .707 .577 .707 r
F P
0 g
s
.46443 .56658 m .4591 .5107 L .48003 .51441 L p .707 .577 .707 r
F P
0 g
s
.29662 .71495 m .29332 .69638 L .30049 .68892 L p .707 .577 .707 r
F P
0 g
s
.31579 .52662 m .32113 .5825 L .30478 .59035 L p .707 .577 .707 r
F P
0 g
s
.30049 .68892 m .30379 .70748 L .29662 .71495 L p .707 .577 .707 r
F P
0 g
s
.49145 .65915 m .49475 .67771 L .48252 .67389 L p .707 .577 .707 r
F P
0 g
s
.48252 .67389 m .47922 .65533 L .49145 .65915 L p .707 .577 .707 r
F P
0 g
s
.30965 .66478 m .30251 .62771 L .31879 .61937 L p .707 .577 .707 r
F P
0 g
s
.32113 .5825 m .31579 .52662 L .33978 .51957 L p .707 .577 .707 r
F P
0 g
s
.31879 .61937 m .32593 .65644 L .30965 .66478 L p .707 .577 .707 r
F P
0 g
s
.4808 .59172 m .48794 .62879 L .46742 .62788 L p .707 .577 .707 r
F P
0 g
s
.46742 .62788 m .46028 .59081 L .4808 .59172 L p .707 .577 .707 r
F P
0 g
s
.4591 .5107 m .46443 .56658 L .43712 .56523 L p .707 .577 .707 r
F P
0 g
s
.43712 .56523 m .43179 .50935 L .4591 .5107 L p .707 .577 .707 r
F P
0 g
s
.33978 .51957 m .34511 .57545 L .32113 .5825 L p .707 .577 .707 r
F P
0 g
s
.30379 .70748 m .30049 .68892 L .31677 .68065 L p .707 .577 .707 r
F P
0 g
s
.34511 .57545 m .33978 .51957 L .36906 .51401 L p .707 .577 .707 r
F P
0 g
s
.31677 .68065 m .32008 .69921 L .30379 .70748 L p .707 .577 .707 r
F P
0 g
s
.32593 .65644 m .31879 .61937 L .34257 .6109 L p .707 .577 .707 r
F P
0 g
s
.47922 .65533 m .48252 .67389 L .46192 .67256 L p .707 .577 .707 r
F P
0 g
s
.46192 .67256 m .45862 .65399 L .47922 .65533 L p .707 .577 .707 r
F P
0 g
s
.43179 .50935 m .43712 .56523 L .40609 .56637 L p .707 .577 .707 r
F P
0 g
s
.40609 .56637 m .40076 .51049 L .43179 .50935 L p .707 .577 .707 r
F P
0 g
s
.46028 .59081 m .46742 .62788 L .44055 .62963 L p .707 .577 .707 r
F P
0 g
s
.44055 .62963 m .43341 .59256 L .46028 .59081 L p .707 .577 .707 r
F P
0 g
s
.37439 .56989 m .36906 .51401 L .40076 .51049 L p .707 .577 .707 r
F P
0 g
s
.36906 .51401 m .37439 .56989 L .34511 .57545 L p .707 .577 .707 r
F P
0 g
s
.34257 .6109 m .34971 .64797 L .32593 .65644 L p .707 .577 .707 r
F P
0 g
s
.40076 .51049 m .40609 .56637 L .37439 .56989 L p .707 .577 .707 r
F P
0 g
s
.32008 .69921 m .31677 .68065 L .3406 .67239 L p .707 .577 .707 r
F P
0 g
s
.34971 .64797 m .34257 .6109 L .37153 .60312 L p .707 .577 .707 r
F P
0 g
s
.3406 .67239 m .3439 .69095 L .32008 .69921 L p .707 .577 .707 r
F P
0 g
s
.43341 .59256 m .44055 .62963 L .40997 .63387 L p .707 .577 .707 r
F P
0 g
s
.40997 .63387 m .40283 .5968 L .43341 .59256 L p .707 .577 .707 r
F P
0 g
s
.45862 .65399 m .46192 .67256 L .43496 .67384 L p .707 .577 .707 r
F P
0 g
s
.43496 .67384 m .43166 .65528 L .45862 .65399 L p .707 .577 .707 r
F P
0 g
s
.37153 .60312 m .37867 .64019 L .34971 .64797 L p .707 .577 .707 r
F P
0 g
s
.37867 .64019 m .37153 .60312 L .40283 .5968 L p .707 .577 .707 r
F P
0 g
s
.40283 .5968 m .40997 .63387 L .37867 .64019 L p .707 .577 .707 r
F P
0 g
s
.3439 .69095 m .3406 .67239 L .36962 .66495 L p .707 .577 .707 r
F P
0 g
s
.36962 .66495 m .37292 .68351 L .3439 .69095 L p .707 .577 .707 r
F P
0 g
s
.43166 .65528 m .43496 .67384 L .4043 .67761 L p .707 .577 .707 r
F P
0 g
s
.4043 .67761 m .401 .65905 L .43166 .65528 L p .707 .577 .707 r
F P
0 g
s
.37292 .68351 m .36962 .66495 L .401 .65905 L p .707 .577 .707 r
F P
0 g
s
.401 .65905 m .4043 .67761 L .37292 .68351 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0085oo`00Lgoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00Ngoo001`Ool30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001eOol006ioo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@0075oo`00K7oo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000
06moo`00JWoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YFFUIJEP<006aoo`00JGoo0P001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00JWoo
001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001XOol006Qoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008006Ioo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=o
o`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Aoo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ao
o`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Moo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Aoo`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00IJEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000EJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00D000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Ioo`00Ggoo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001HOol2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001FOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJ
EP00009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol8000mOol005=oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8001Uoo`T000AJEP04001JEUYFFUH6000gOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80015oo`P000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00D0039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;goo001COol0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
200015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20007Ool400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF20000UYF00L005YFFUIJEP00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF200025YF00<0
05YFFUH01EYF00<005YFFUH015YF1@000UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF1P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEPD0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00E7oo00<005YF000015YF00<005YF00000`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005Aoo`03001JEP0000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Ao
o`04001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
05Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002io
o`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
4`0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH0000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00E7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00AWoo40000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003ioo`P000AJ
EP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH00eYF100000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF008002eo
o`00>7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEP00
00<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90008FUH70003FUH00`00FUIJEP02
000]Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH500000eYF0000000]Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0035oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP06001JEUYFFUH005YF
10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;Goo000_Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH600000eYF001JEP03FUH00`00FUH0000]Ool002ioo`05001J
EUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP/0
009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH0
0`00FUIJEP0500000eYF0000000^Ool002eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPP000IJEP04001JEUYFFUH4000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH000050004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00L005YF001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01`00FUH005YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000@000IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00FUH^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50009FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo
001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003
FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP03FUH40009FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000UYF00@005YFFUIJEP<00003FUH0
05YF00QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEPH0009JEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEPH000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<0
05YFFUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH015YF2@000eYF00<005YFFUH01@0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000=JEP05001JEUYFFUH00002FUH01000FUIJEP001eYF00<005YFFUH01UYF1`0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80008FUH01@00FUIJEUYF
00000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEQ400003FUH007oo02aoo`00;Goo00<005YF000015YF00<005YFFUH0
0eYF1P001UYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH015YF
1P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4000/
Ool002eoo`03001JEP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF009JEPL000QJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002eo
o`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF009JEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUH0000/Ool002eoo`03001JEP00009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEP0000800003FUH005YF00QJEP03001JEUYF
00AJEPH000YJEP03001JEUYF00=JEP800003FUH0000000<000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEP<0
00=JEPH000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP8002eoo`00;Goo00<0
05YF00000P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
100015YF00<005YFFUH01eYF00<005YFFUH01@000eYF00<005YFFUH02EYF00<005YFFUH00`000eYF
00<005YF00000P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEP00008000IJEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002eoo`05001JEP00FUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH900000eYF001JEP05FUH00`00FUIJEP04FUH500000eYF
000000030002FUH00`00FUIJEP09FUH300000eYF001JEP04FUH01000FUH000002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001JEUYF009JEP<00003
FUH005YF00MJEP03001JEUYF00EJEQD0031oo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00001P0015YF0`000eYF00<005YFFUH015YF00<005YFFUH01000
15YF00<005YF000010000UYF00<005YFFUH01UYF0`0015YF00<005YFFUH00eYF0P0000=JEP00FUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000EJEP03001J
EP00008000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00
008002moo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF100000=JEP00FUH01EYF00<005YF000010000UYF
00<005YFFUH00eYF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00003FUH40007FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030006FUH00`00FUIJ
EP06FUH20004FUH00`00FUH000030002FUH01000FUIJEP001UYF00<005YFFUH00`000eYF00<005YF
FUH00`0015YF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800006FUH005YFFUH005YF0P000eYF00<005YFFUH01EYF1@00
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002moo`00;Woo0P00
00=JEP00FUH015YF00<005YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH015YF00<005YF0000
15YF0`001EYF00@005YFFUH000IJEP03001JEUYF00=JEPH000MJEP03001JEUYF00=JEP<000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP8000EJEP03
001JEUYF009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool0031oo`<000AJEP03001JEP0000<000EJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0002FUH01000FUIJEP001EYF00@005YFFUH000AJEPP000AJEP03001JEUYF
00IJEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH00`00FUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJEP02FUHC0002
FUH00`00Oomoo`0/Ool003=oo`<00005FUH00000FUH00008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUH000002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0000AJEP00FUIJEP@00003FUH005YF00MJEP03001JEUYF00AJEP/000aoo`H002ioo`00
=Goo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEPP0
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80009JEP8000EJEP03001JEUYF
00IJEP03001JEUYF00@0009JEP@000ioo`<0009JEP04001JEUYF000^Ool003=oo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP@000MJEP03001JEUYF00AJ
EPX0011oo`800003FUH005YF00=JEP03001JEP0002ioo`00<Goo0`001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF1@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH020000goo0`00
3Woo0P000eYF00<005YFFUH00UYF0P00;goo000_Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH010002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH015YF1P0027oo1@002Woo0`001EYF00<005YF
FUH00UYF00<007ooOol0;Woo000]Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40005FUH01000FUIJEUYF0P0000=JEP00FUH00`0027oo1@001Woo100000=JEP00FUH01UYF
00@005YFFUH0035oo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEPL000IJEQ@000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH01000FUH000000eYF
00<005YFFUH00P0027oo2`001EYF00<005YFFUH01EYF0`00<Woo000/Ool01@00FUIJEUYF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01@0015YF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP04001J
EUYFFUH40005FUH01000FUH005YF1Goo1`0015YF00<005YFFUH01UYF00<005YFFUH00eYF0P00=7oo
000/Ool01@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEP04001JEP000003FUH00`00FUIJEP03FUH01@00FUIJEP00Ool010000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00=Woo000]Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF000005YF018000IJEP03001JEUYF
00MJEP03001JEUYF00AJEP<003Yoo`00;Goo00@005YFFUH000AJEP03001JEUYF00=JEP@000UJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUHE0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF
00000002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04000mOol002eoo`04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEP001UYF00<005YFFUH015YF2@00
00=JEP00FUH02eYF00<005YFFUH015YF1P000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP0000000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH015YF1@00@Goo000]Ool01000FUIJEP0015YF0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF4`000UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH02UYF00<0
05YFFUH02EYF1`0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000AWoo000]Ool01@00FUIJEUYF
00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001:Ool002eoo`04001JEUYFFUH30004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP000eYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF1@001eYF00<005YFFUH00UYF0P000UYF5P00DGoo000^Ool00`00FUIJEP020005FUH00`00
FUIJEP04FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00UYF10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1000
Dgoo000^Ool300000eYF001JEP04FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF0`0000=J
EP00FUH00eYF0P001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000005=oo`00;Woo0P00
0eYF00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH00UYF4P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000AJEP8000IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EP0005=oo`00;goo0P000UYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH015YF1P0047oo
0`001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009JEP8000IJEP03001JEUYF00AJEP03001JEUYF
00=JEP8005Aoo`00<Goo100015YF00<005YFFUH01eYF00<005YFFUH01@004goo0P0000=JEP000000
1EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF10001UYF00<005YFFUH01EYF00@005YFFUIJEP8005Eo
o`00<Goo0`001UYF00<005YFFUH015YF1@0000=oo`0000000`0047oo0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00004`00Egoo000_Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP040006Ool5000>Ool20002FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00H005YF000005YF0006FUH00`00FUIJEP03FUH00`00FUH00002001FOol002ioo`03
001JEUYF00=JEP03001JEUYF009JEP@000Yoo`D000Yoo`@000AJEP05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00=JEP05001JEUYFFUH0
001FOol002eoo`8000EJEP03001JEP00008000moo`<000Moo`@0009JEP03001JEUYF00AJEP03001J
EUYF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP00EWoo000/Ool00`00FUH00005FUH2000EOol70006FUH00`00FUIJ
EP04FUH30002Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF001FOol002aoo`04001JEUYF0002FUH2000?Ool80004FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUH005YF40000eYF00<007ooOol0Dgoo000/Ool00`00FUIJEP040008Ool80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH000030009Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000<Ool400000eYF
001oo`1DOol002eoo`04001JEP000002FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3000>Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`0<Ool30002FUH01000FUH00000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04000COol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P003Goo0P0000=JEP00FUH00eYF00<005YF0000
EGoo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5
000IOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH01000FUH000003Goo0P000eYF00<005YFFUH00UYF0P00EWoo000]Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000QOol40008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH5000;Ool30005FUH00`00FUIJ
EP02FUH00`00Oomoo`1EOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF009J
EPH002Uoo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00D0
0003Ool0000000<000Ioo`@00003FUH005YF00IJEP04001JEUYF001HOol0031ooa@003Eoo`T000IJ
EP03001JEUYF00UJEP03001JEUYF00AJEPP000Ioo`D00003Ool0000000<000EJEP03001JEUYF00EJ
EP<005Uoo`00PWoo6@003Woo1P000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00Fgoo002=Ool0
1@00FUIJEP00FUH00P0047oo2@0015YF00<005YFFUH01UYF00<005YF00000`00GGoo002>Ool00`00
FUH0000C0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001QOol008ioo`80009JEP03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@006Aoo`00SWoo
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1@00J7oo
002>Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04001]
Ool008moo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPL0075oo`00TGoo
5000N7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5939 .74946 m .59924 .69472 L .56821 .68981 L p .707 .577 .707 r
F P
0 g
s
.59924 .69472 m .5939 .74946 L .62561 .7514 L p .707 .577 .707 r
F P
0 g
s
.62561 .7514 m .63094 .69666 L .59924 .69472 L p .707 .577 .707 r
F P
0 g
s
.63094 .69666 m .62561 .7514 L .65488 .75018 L p .707 .577 .707 r
F P
0 g
s
.65488 .75018 m .66022 .69544 L .63094 .69666 L p .707 .577 .707 r
F P
0 g
s
.56288 .74454 m .56821 .68981 L .5409 .68241 L p .707 .577 .707 r
F P
0 g
s
.56821 .68981 m .56288 .74454 L .5939 .74946 L p .707 .577 .707 r
F P
0 g
s
.66022 .69544 m .65488 .75018 L .67887 .74591 L p .707 .577 .707 r
F P
0 g
s
.67887 .74591 m .6842 .69118 L .66022 .69544 L p .707 .577 .707 r
F P
0 g
s
.53556 .73714 m .5409 .68241 L .51997 .67323 L p .707 .577 .707 r
F P
0 g
s
.5409 .68241 m .53556 .73714 L .56288 .74454 L p .707 .577 .707 r
F P
0 g
s
.59003 .81613 m .59717 .78059 L .56659 .77267 L p .707 .577 .707 r
F P
0 g
s
.59717 .78059 m .59003 .81613 L .62133 .82078 L p .707 .577 .707 r
F P
0 g
s
.62133 .82078 m .62847 .78524 L .59717 .78059 L p .707 .577 .707 r
F P
0 g
s
.62847 .78524 m .62133 .82078 L .65029 .82171 L p .707 .577 .707 r
F P
0 g
s
.65029 .82171 m .65743 .78617 L .62847 .78524 L p .707 .577 .707 r
F P
0 g
s
.55945 .80821 m .56659 .77267 L .53972 .76226 L p .707 .577 .707 r
F P
0 g
s
.56659 .77267 m .55945 .80821 L .59003 .81613 L p .707 .577 .707 r
F P
0 g
s
.6842 .69118 m .67887 .74591 L .69522 .73902 L p .707 .577 .707 r
F P
0 g
s
.69522 .73902 m .70055 .68429 L .6842 .69118 L p .707 .577 .707 r
F P
0 g
s
.51997 .67323 m .51464 .72797 L .53556 .73714 L p .707 .577 .707 r
F P
0 g
s
.5957 .86109 m .599 .84323 L .56833 .83576 L p .707 .577 .707 r
F P
0 g
s
.599 .84323 m .5957 .86109 L .62708 .86533 L p .707 .577 .707 r
F P
0 g
s
.62708 .86533 m .63038 .84748 L .599 .84323 L p .707 .577 .707 r
F P
0 g
s
.53972 .76226 m .53258 .7978 L .55945 .80821 L p .707 .577 .707 r
F P
0 g
s
.65743 .78617 m .65029 .82171 L .67407 .81882 L p .707 .577 .707 r
F P
0 g
s
.67407 .81882 m .68121 .78328 L .65743 .78617 L p .707 .577 .707 r
F P
0 g
s
.51464 .72797 m .51997 .67323 L .50748 .66319 L p .707 .577 .707 r
F P
0 g
s
.53258 .7978 m .53972 .76226 L .5192 .75038 L p .707 .577 .707 r
F P
0 g
s
.63038 .84748 m .62708 .86533 L .6561 .86594 L p .707 .577 .707 r
F P
0 g
s
.6561 .86594 m .6594 .84809 L .63038 .84748 L p .707 .577 .707 r
F P
0 g
s
.56503 .85362 m .56833 .83576 L .54138 .82581 L p .707 .577 .707 r
F P
0 g
s
.56833 .83576 m .56503 .85362 L .5957 .86109 L p .707 .577 .707 r
F P
0 g
s
.54138 .82581 m .53808 .84366 L .56503 .85362 L p .707 .577 .707 r
F P
0 g
s
.5192 .75038 m .51206 .78592 L .53258 .7978 L p .707 .577 .707 r
F P
0 g
s
.6594 .84809 m .6561 .86594 L .67992 .86285 L p .707 .577 .707 r
F P
0 g
s
.67992 .86285 m .68322 .84499 L .6594 .84809 L p .707 .577 .707 r
F P
0 g
s
.53808 .84366 m .54138 .82581 L .52078 .81433 L p .707 .577 .707 r
F P
0 g
s
.50748 .66319 m .50215 .71793 L .51464 .72797 L p .707 .577 .707 r
F P
0 g
s
.70055 .68429 m .69522 .73902 L .70232 .73018 L p .707 .577 .707 r
F P
0 g
s
.70232 .73018 m .70766 .67544 L .70055 .68429 L p .707 .577 .707 r
F P
0 g
s
.68121 .78328 m .67407 .81882 L .69034 .81241 L p .707 .577 .707 r
F P
0 g
s
.69034 .81241 m .69748 .77687 L .68121 .78328 L p .707 .577 .707 r
F P
0 g
s
.51206 .78592 m .5192 .75038 L .50703 .73819 L p .707 .577 .707 r
F P
0 g
s
.52078 .81433 m .51748 .83218 L .53808 .84366 L p .707 .577 .707 r
F P
0 g
s
.50215 .71793 m .50748 .66319 L .50465 .65327 L p .707 .577 .707 r
F P
0 g
s
.50703 .73819 m .49989 .77373 L .51206 .78592 L p .707 .577 .707 r
F P
0 g
s
.68322 .84499 m .67992 .86285 L .69621 .85636 L p .707 .577 .707 r
F P
0 g
s
.69621 .85636 m .69951 .83851 L .68322 .84499 L p .707 .577 .707 r
F P
0 g
s
.51748 .83218 m .52078 .81433 L .50855 .80246 L p .707 .577 .707 r
F P
0 g
s
.50465 .65327 m .49932 .708 L .50215 .71793 L p .707 .577 .707 r
F P
0 g
s
.50855 .80246 m .50525 .82031 L .51748 .83218 L p .707 .577 .707 r
F P
0 g
s
.69748 .77687 m .69034 .81241 L .69752 .80309 L p .707 .577 .707 r
F P
0 g
s
.69752 .80309 m .70466 .76755 L .69748 .77687 L p .707 .577 .707 r
F P
0 g
s
.49989 .77373 m .50703 .73819 L .5044 .72688 L p .707 .577 .707 r
F P
0 g
s
.70766 .67544 m .70232 .73018 L .69949 .72025 L p .707 .577 .707 r
F P
0 g
s
.69949 .72025 m .70483 .66552 L .70766 .67544 L p .707 .577 .707 r
F P
0 g
s
.49932 .708 m .50465 .65327 L .51176 .64443 L p .707 .577 .707 r
F P
0 g
s
.5044 .72688 m .49726 .76242 L .49989 .77373 L p .707 .577 .707 r
F P
0 g
s
.49726 .76242 m .5044 .72688 L .51158 .71756 L p .707 .577 .707 r
F P
0 g
s
.51158 .71756 m .50444 .7531 L .49726 .76242 L p .707 .577 .707 r
F P
0 g
s
.50232 .82126 m .48352 .31773 L .43955 .31672 L p .707 .577 .707 r
F P
0 g
s
.50525 .82031 m .50855 .80246 L .50589 .79136 L p .707 .577 .707 r
F P
0 g
s
.50589 .79136 m .50258 .80921 L .50525 .82031 L p .707 .577 .707 r
F P
0 g
s
.51176 .64443 m .50643 .69916 L .49932 .708 L p .707 .577 .707 r
F P
0 g
s
.50643 .69916 m .51176 .64443 L .52811 .63754 L p .707 .577 .707 r
F P
0 g
s
.50258 .80921 m .50589 .79136 L .51305 .78211 L p .707 .577 .707 r
F P
0 g
s
.51305 .78211 m .50975 .79997 L .50258 .80921 L p .707 .577 .707 r
F P
0 g
s
.52811 .63754 m .52277 .69227 L .50643 .69916 L p .707 .577 .707 r
F P
0 g
s
.50444 .7531 m .51158 .71756 L .52786 .71115 L p .707 .577 .707 r
F P
0 g
s
.52277 .69227 m .52811 .63754 L .55209 .63327 L p .707 .577 .707 r
F P
0 g
s
.52786 .71115 m .52072 .74669 L .50444 .7531 L p .707 .577 .707 r
F P
0 g
s
.50975 .79997 m .51305 .78211 L .52934 .77563 L p .707 .577 .707 r
F P
0 g
s
.55209 .63327 m .54676 .688 L .52277 .69227 L p .707 .577 .707 r
F P
0 g
s
.52934 .77563 m .52604 .79348 L .50975 .79997 L p .707 .577 .707 r
F P
0 g
s
.52072 .74669 m .52786 .71115 L .55164 .70827 L p .707 .577 .707 r
F P
0 g
s
.55164 .70827 m .5445 .74381 L .52072 .74669 L p .707 .577 .707 r
F P
0 g
s
.52604 .79348 m .52934 .77563 L .55316 .77253 L p .707 .577 .707 r
F P
0 g
s
.55316 .77253 m .54986 .79039 L .52604 .79348 L p .707 .577 .707 r
F P
0 g
s
.48352 .31773 m .50232 .82126 L .54723 .81865 L p .707 .577 .707 r
F P
0 g
s
.54723 .81865 m .52844 .31512 L .48352 .31773 L p .707 .577 .707 r
F P
0 g
s
.69951 .83851 m .69621 .85636 L .70337 .84712 L p .707 .577 .707 r
F P
0 g
s
.70337 .84712 m .70667 .82926 L .69951 .83851 L p .707 .577 .707 r
F P
0 g
s
.54676 .688 m .55209 .63327 L .58137 .63205 L p .707 .577 .707 r
F P
0 g
s
.58137 .63205 m .57604 .68678 L .54676 .688 L p .707 .577 .707 r
F P
0 g
s
.5445 .74381 m .55164 .70827 L .5806 .70919 L p .707 .577 .707 r
F P
0 g
s
.5806 .70919 m .57346 .74473 L .5445 .74381 L p .707 .577 .707 r
F P
0 g
s
.57346 .74473 m .5806 .70919 L .6119 .71384 L p .707 .577 .707 r
F P
0 g
s
.54986 .79039 m .55316 .77253 L .58218 .77314 L p .707 .577 .707 r
F P
0 g
s
.6119 .71384 m .60476 .74938 L .57346 .74473 L p .707 .577 .707 r
F P
0 g
s
.58218 .77314 m .57888 .791 L .54986 .79039 L p .707 .577 .707 r
F P
0 g
s
.57888 .791 m .58218 .77314 L .61356 .77739 L p .707 .577 .707 r
F P
0 g
s
.61356 .77739 m .61026 .79524 L .57888 .791 L p .707 .577 .707 r
F P
0 g
s
.52844 .31512 m .54723 .81865 L .58869 .81268 L p .707 .577 .707 r
F P
0 g
s
.57604 .68678 m .58137 .63205 L .61307 .63399 L p .707 .577 .707 r
F P
0 g
s
.61307 .63399 m .60774 .68872 L .57604 .68678 L p .707 .577 .707 r
F P
0 g
s
.58869 .81268 m .5699 .30916 L .52844 .31512 L p .707 .577 .707 r
F P
0 g
s
.45834 .82024 m .43955 .31672 L .40081 .31219 L p .707 .577 .707 r
F P
0 g
s
.43955 .31672 m .45834 .82024 L .50232 .82126 L p .707 .577 .707 r
F P
0 g
s
.70466 .76755 m .69752 .80309 L .6949 .79178 L p .707 .577 .707 r
F P
0 g
s
.6949 .79178 m .70204 .75624 L .70466 .76755 L p .707 .577 .707 r
F P
0 g
s
.70483 .66552 m .69949 .72025 L .687 .71021 L p .707 .577 .707 r
F P
0 g
s
.687 .71021 m .69234 .65548 L .70483 .66552 L p .707 .577 .707 r
F P
0 g
s
.6441 .6389 m .63877 .69363 L .60774 .68872 L p .707 .577 .707 r
F P
0 g
s
.60774 .68872 m .61307 .63399 L .6441 .6389 L p .707 .577 .707 r
F P
0 g
s
.64248 .72176 m .63534 .7573 L .60476 .74938 L p .707 .577 .707 r
F P
0 g
s
.60476 .74938 m .6119 .71384 L .64248 .72176 L p .707 .577 .707 r
F P
0 g
s
.64423 .78486 m .64093 .80271 L .61026 .79524 L p .707 .577 .707 r
F P
0 g
s
.61026 .79524 m .61356 .77739 L .64423 .78486 L p .707 .577 .707 r
F P
0 g
s
.5699 .30916 m .58869 .81268 L .62263 .80394 L p .707 .577 .707 r
F P
0 g
s
.62263 .80394 m .60384 .30041 L .5699 .30916 L p .707 .577 .707 r
F P
0 g
s
.25089 .71802 m .25623 .66329 L .2252 .65837 L p .707 .577 .707 r
F P
0 g
s
.25623 .66329 m .25089 .71802 L .2826 .71996 L p .707 .577 .707 r
F P
0 g
s
.2826 .71996 m .28793 .66523 L .25623 .66329 L p .707 .577 .707 r
F P
0 g
s
.70667 .82926 m .70337 .84712 L .70071 .83602 L p .707 .577 .707 r
F P
0 g
s
.70071 .83602 m .70401 .81816 L .70667 .82926 L p .707 .577 .707 r
F P
0 g
s
.28793 .66523 m .2826 .71996 L .31188 .71874 L p .707 .577 .707 r
F P
0 g
s
.31188 .71874 m .31721 .66401 L .28793 .66523 L p .707 .577 .707 r
F P
0 g
s
.41961 .81571 m .40081 .31219 L .37111 .30458 L p .707 .577 .707 r
F P
0 g
s
.40081 .31219 m .41961 .81571 L .45834 .82024 L p .707 .577 .707 r
F P
0 g
s
.21987 .71311 m .2252 .65837 L .19789 .65097 L p .707 .577 .707 r
F P
0 g
s
.2252 .65837 m .21987 .71311 L .25089 .71802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31721 .66401 m .31188 .71874 L .33586 .71447 L p .707 .577 .707 r
F P
0 g
s
.33586 .71447 m .34119 .65974 L .31721 .66401 L p .707 .577 .707 r
F P
0 g
s
.70204 .75624 m .6949 .79178 L .68273 .77959 L p .707 .577 .707 r
F P
0 g
s
.68273 .77959 m .68987 .74405 L .70204 .75624 L p .707 .577 .707 r
F P
0 g
s
.69234 .65548 m .687 .71021 L .66608 .70104 L p .707 .577 .707 r
F P
0 g
s
.66608 .70104 m .67141 .64631 L .69234 .65548 L p .707 .577 .707 r
F P
0 g
s
.66934 .73217 m .66221 .76771 L .63534 .7573 L p .707 .577 .707 r
F P
0 g
s
.63534 .7573 m .64248 .72176 L .66934 .73217 L p .707 .577 .707 r
F P
0 g
s
.64093 .80271 m .64423 .78486 L .67118 .79481 L p .707 .577 .707 r
F P
0 g
s
.60384 .30041 m .62263 .80394 L .64574 .79327 L p .707 .577 .707 r
F P
0 g
s
.67141 .64631 m .66608 .70104 L .63877 .69363 L p .707 .577 .707 r
F P
0 g
s
.63877 .69363 m .6441 .6389 L .67141 .64631 L p .707 .577 .707 r
F P
0 g
s
.64574 .79327 m .62694 .28975 L .60384 .30041 L p .707 .577 .707 r
F P
0 g
s
.19255 .7057 m .19789 .65097 L .17696 .6418 L p .707 .577 .707 r
F P
0 g
s
.19789 .65097 m .19255 .7057 L .21987 .71311 L p .707 .577 .707 r
F P
0 g
s
.24702 .77687 m .25416 .74133 L .22358 .73342 L p .707 .577 .707 r
F P
0 g
s
.25416 .74133 m .24702 .77687 L .27832 .78152 L p .707 .577 .707 r
F P
0 g
s
.27832 .78152 m .28546 .74598 L .25416 .74133 L p .707 .577 .707 r
F P
0 g
s
.28546 .74598 m .27832 .78152 L .30728 .78245 L p .707 .577 .707 r
F P
0 g
s
.30728 .78245 m .31442 .74691 L .28546 .74598 L p .707 .577 .707 r
F P
0 g
s
.21644 .76896 m .22358 .73342 L .19671 .72301 L p .707 .577 .707 r
F P
0 g
s
.22358 .73342 m .21644 .76896 L .24702 .77687 L p .707 .577 .707 r
F P
0 g
s
.70401 .81816 m .70071 .83602 L .68848 .82415 L p .707 .577 .707 r
F P
0 g
s
.68848 .82415 m .69178 .80629 L .70401 .81816 L p .707 .577 .707 r
F P
0 g
s
.38991 .80811 m .37111 .30458 L .35336 .29465 L p .707 .577 .707 r
F P
0 g
s
.37111 .30458 m .38991 .80811 L .41961 .81571 L p .707 .577 .707 r
F P
0 g
s
.34119 .65974 m .33586 .71447 L .35221 .70758 L p .707 .577 .707 r
F P
0 g
s
.35221 .70758 m .35754 .65285 L .34119 .65974 L p .707 .577 .707 r
F P
0 g
s
.25269 .81632 m .25599 .79846 L .22532 .79099 L p .707 .577 .707 r
F P
0 g
s
.25599 .79846 m .25269 .81632 L .28407 .82056 L p .707 .577 .707 r
F P
0 g
s
.28407 .82056 m .28737 .80271 L .25599 .79846 L p .707 .577 .707 r
F P
0 g
s
.17696 .6418 m .17163 .69653 L .19255 .7057 L p .707 .577 .707 r
F P
0 g
s
.19671 .72301 m .18957 .75855 L .21644 .76896 L p .707 .577 .707 r
F P
0 g
s
.31442 .74691 m .30728 .78245 L .33106 .77957 L p .707 .577 .707 r
F P
0 g
s
.33106 .77957 m .3382 .74403 L .31442 .74691 L p .707 .577 .707 r
F P
0 g
s
.18957 .75855 m .19671 .72301 L .17619 .71113 L p .707 .577 .707 r
F P
0 g
s
.28737 .80271 m .28407 .82056 L .31309 .82117 L p .707 .577 .707 r
F P
0 g
s
.31309 .82117 m .31639 .80331 L .28737 .80271 L p .707 .577 .707 r
F P
0 g
s
.22202 .80885 m .22532 .79099 L .19837 .78103 L p .707 .577 .707 r
F P
0 g
s
.22532 .79099 m .22202 .80885 L .25269 .81632 L p .707 .577 .707 r
F P
0 g
s
.17163 .69653 m .17696 .6418 L .16447 .63176 L p .707 .577 .707 r
F P
0 g
s
.68987 .74405 m .68273 .77959 L .66221 .76771 L p .707 .577 .707 r
F P
0 g
s
.66221 .76771 m .66934 .73217 L .68987 .74405 L p .707 .577 .707 r
F P
0 g
s
.19837 .78103 m .19507 .79889 L .22202 .80885 L p .707 .577 .707 r
F P
0 g
s
.17619 .71113 m .16905 .74667 L .18957 .75855 L p .707 .577 .707 r
F P
0 g
s
.31639 .80331 m .31309 .82117 L .33691 .81808 L p .707 .577 .707 r
F P
0 g
s
.33691 .81808 m .34021 .80022 L .31639 .80331 L p .707 .577 .707 r
F P
0 g
s
.19507 .79889 m .19837 .78103 L .17777 .76956 L p .707 .577 .707 r
F P
0 g
s
.62694 .28975 m .64574 .79327 L .65574 .78173 L p .707 .577 .707 r
F P
0 g
s
.65574 .78173 m .63695 .2782 L .62694 .28975 L p .707 .577 .707 r
F P
0 g
s
.69178 .80629 m .68848 .82415 L .66788 .81267 L p .707 .577 .707 r
F P
0 g
s
.66788 .81267 m .67118 .79481 L .69178 .80629 L p .707 .577 .707 r
F P
0 g
s
.16447 .63176 m .15914 .68649 L .17163 .69653 L p .707 .577 .707 r
F P
0 g
s
.3382 .74403 m .33106 .77957 L .34733 .77315 L p .707 .577 .707 r
F P
0 g
s
.34733 .77315 m .35447 .73761 L .3382 .74403 L p .707 .577 .707 r
F P
0 g
s
.16905 .74667 m .17619 .71113 L .16402 .69893 L p .707 .577 .707 r
F P
0 g
s
.17777 .76956 m .17447 .78741 L .19507 .79889 L p .707 .577 .707 r
F P
0 g
s
.35754 .65285 m .35221 .70758 L .35931 .69874 L p .707 .577 .707 r
F P
0 g
s
.35931 .69874 m .36465 .64401 L .35754 .65285 L p .707 .577 .707 r
F P
0 g
s
.15914 .68649 m .16447 .63176 L .16165 .62183 L p .707 .577 .707 r
F P
0 g
s
.16402 .69893 m .15688 .73448 L .16905 .74667 L p .707 .577 .707 r
F P
0 g
s
.34021 .80022 m .33691 .81808 L .3532 .81159 L p .707 .577 .707 r
F P
0 g
s
.3532 .81159 m .3565 .79374 L .34021 .80022 L p .707 .577 .707 r
F P
0 g
s
.37215 .79818 m .35336 .29465 L .34928 .28336 L p .707 .577 .707 r
F P
0 g
s
.35336 .29465 m .37215 .79818 L .38991 .80811 L p .707 .577 .707 r
F P
0 g
s
.17447 .78741 m .17777 .76956 L .16554 .75769 L p .707 .577 .707 r
F P
0 g
s
.67118 .79481 m .66788 .81267 L .64093 .80271 L p .707 .577 .707 r
F P
0 g
s
.16554 .75769 m .16224 .77554 L .17447 .78741 L p .707 .577 .707 r
F P
0 g
s
.16165 .62183 m .15631 .67656 L .15914 .68649 L p .707 .577 .707 r
F P
0 g
s
.35447 .73761 m .34733 .77315 L .35451 .76384 L p .707 .577 .707 r
F P
0 g
s
.35451 .76384 m .36165 .7283 L .35447 .73761 L p .707 .577 .707 r
F P
0 g
s
.15688 .73448 m .16402 .69893 L .16139 .68763 L p .707 .577 .707 r
F P
0 g
s
.36465 .64401 m .35931 .69874 L .35648 .68881 L p .707 .577 .707 r
F P
0 g
s
.35648 .68881 m .36182 .63408 L .36465 .64401 L p .707 .577 .707 r
F P
0 g
s
.63695 .2782 m .65574 .78173 L .65224 .77203 L p .707 .577 .707 r
F P
0 g
s
.65122 .75543 m .63695 .2782 L .65224 .77203 L .707 .577 .707 r
F
.63287 .26691 m .63695 .2782 L p .64711 .61793 L F P
0 g
s
.65097 .74711 m .64583 .614 L .64711 .61793 L .707 .577 .707 r
F
.65063 .74267 m .64583 .614 L p .65097 .74711 L F P
0 g
s
.63287 .26691 m .65167 .77044 L .63391 .7605 L p .707 .577 .707 r
F P
0 g
s
.64423 .64615 m .64354 .64962 L p .64926 .69388 L .707 .577 .707 r
F P
0 g
s
.64354 .64962 m .63709 .68169 L .64672 .69133 L p .707 .577 .707 r
F P
0 g
s
.64672 .69133 m .64926 .69388 L p .64354 .64962 L .707 .577 .707 r
F P
0 g
s
.65167 .77044 m .65063 .74267 L p .65097 .74711 L .707 .577 .707 r
F P
0 g
s
.64583 .614 m .63287 .26691 L p .64711 .61793 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64186 .56123 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.63935 .62589 m .64174 .60144 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .64469 .57116 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64174 .60144 L p .65184 .63593 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .63935 .62589 L .64344 .62918 L p .707 .577 .707 r
F P
0 g
s
.64344 .62918 m .65184 .63593 L p .64174 .60144 L .707 .577 .707 r
F P
0 g
s
.65224 .77203 m .65167 .77044 L p .65122 .75543 L .707 .577 .707 r
F P
0 g
s
.15631 .67656 m .16165 .62183 L .16875 .61299 L p .707 .577 .707 r
F P
0 g
s
.16139 .68763 m .15426 .72317 L .15688 .73448 L p .707 .577 .707 r
F P
0 g
s
.3565 .79374 m .3532 .81159 L .36036 .80235 L p .707 .577 .707 r
F P
0 g
s
.36036 .80235 m .36366 .78449 L .3565 .79374 L p .707 .577 .707 r
F P
0 g
s
.16224 .77554 m .16554 .75769 L .16288 .74659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16288 .74659 m .15958 .76444 L .16224 .77554 L p .707 .577 .707 r
F P
0 g
s
.36165 .7283 m .35451 .76384 L .35189 .75253 L p .707 .577 .707 r
F P
0 g
s
.35189 .75253 m .35903 .71699 L .36165 .7283 L p .707 .577 .707 r
F P
0 g
s
.16875 .61299 m .16342 .66772 L .15631 .67656 L p .707 .577 .707 r
F P
0 g
s
.15426 .72317 m .16139 .68763 L .16857 .67831 L p .707 .577 .707 r
F P
0 g
s
.34928 .28336 m .36808 .78689 L .37215 .79818 L p .707 .577 .707 r
F P
0 g
s
.36808 .78689 m .34928 .28336 L .35929 .27181 L p .707 .577 .707 r
F P
0 g
s
.36182 .63408 m .35648 .68881 L .344 .67877 L p .707 .577 .707 r
F P
0 g
s
.344 .67877 m .34933 .62404 L .36182 .63408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16342 .66772 m .16875 .61299 L .1851 .6061 L p .707 .577 .707 r
F P
0 g
s
.16857 .67831 m .16143 .71385 L .15426 .72317 L p .707 .577 .707 r
F P
0 g
s
.36366 .78449 m .36036 .80235 L .3577 .79124 L p .707 .577 .707 r
F P
0 g
s
.3577 .79124 m .361 .77339 L .36366 .78449 L p .707 .577 .707 r
F P
0 g
s
.15958 .76444 m .16288 .74659 L .17004 .73734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17004 .73734 m .16674 .75519 L .15958 .76444 L p .707 .577 .707 r
F P
0 g
s
.63391 .7605 m .61512 .25698 L .63287 .26691 L p .707 .577 .707 r
F P
0 g
s
.35903 .71699 m .35189 .75253 L .33972 .74034 L p .707 .577 .707 r
F P
0 g
s
.33972 .74034 m .34686 .7048 L .35903 .71699 L p .707 .577 .707 r
F P
0 g
s
.1851 .6061 m .17976 .66083 L .16342 .66772 L p .707 .577 .707 r
F P
0 g
s
.16143 .71385 m .16857 .67831 L .18485 .67189 L p .707 .577 .707 r
F P
0 g
s
.34933 .62404 m .344 .67877 L .32307 .6696 L p .707 .577 .707 r
F P
0 g
s
.32307 .6696 m .3284 .61487 L .34933 .62404 L p .707 .577 .707 r
F P
0 g
s
.17976 .66083 m .1851 .6061 L .20908 .60183 L p .707 .577 .707 r
F P
0 g
s
.18485 .67189 m .17771 .70744 L .16143 .71385 L p .707 .577 .707 r
F P
0 g
s
.361 .77339 m .3577 .79124 L .34547 .77937 L p .707 .577 .707 r
F P
0 g
s
.34547 .77937 m .34877 .76152 L .361 .77339 L p .707 .577 .707 r
F P
0 g
s
.37808 .77534 m .35929 .27181 L .38239 .26115 L p .707 .577 .707 r
F P
0 g
s
.35929 .27181 m .37808 .77534 L .36808 .78689 L p .707 .577 .707 r
F P
0 g
s
.16674 .75519 m .17004 .73734 L .18633 .73085 L p .707 .577 .707 r
F P
0 g
s
.18633 .73085 m .18303 .74871 L .16674 .75519 L p .707 .577 .707 r
F P
0 g
s
.3284 .61487 m .32307 .6696 L .29576 .6622 L p .707 .577 .707 r
F P
0 g
s
.29576 .6622 m .30109 .60746 L .3284 .61487 L p .707 .577 .707 r
F P
0 g
s
.34686 .7048 m .33972 .74034 L .3192 .72846 L p .707 .577 .707 r
F P
0 g
s
.3192 .72846 m .32634 .69292 L .34686 .7048 L p .707 .577 .707 r
F P
0 g
s
.20908 .60183 m .20375 .65657 L .17976 .66083 L p .707 .577 .707 r
F P
0 g
s
.17771 .70744 m .18485 .67189 L .20863 .66901 L p .707 .577 .707 r
F P
0 g
s
.20375 .65657 m .20908 .60183 L .23836 .60061 L p .707 .577 .707 r
F P
0 g
s
.61512 .25698 m .63391 .7605 L .60421 .7529 L p .707 .577 .707 r
F P
0 g
s
.60421 .7529 m .58542 .24937 L .61512 .25698 L p .707 .577 .707 r
F P
0 g
s
.30109 .60746 m .29576 .6622 L .26473 .65728 L p .707 .577 .707 r
F P
0 g
s
.26473 .65728 m .27007 .60255 L .30109 .60746 L p .707 .577 .707 r
F P
0 g
s
.20863 .66901 m .20149 .70455 L .17771 .70744 L p .707 .577 .707 r
F P
0 g
s
.34877 .76152 m .34547 .77937 L .32487 .7679 L p .707 .577 .707 r
F P
0 g
s
.32487 .7679 m .32817 .75004 L .34877 .76152 L p .707 .577 .707 r
F P
0 g
s
.23303 .65534 m .23836 .60061 L .27007 .60255 L p .707 .577 .707 r
F P
0 g
s
.23836 .60061 m .23303 .65534 L .20375 .65657 L p .707 .577 .707 r
F P
0 g
s
.18303 .74871 m .18633 .73085 L .21015 .72776 L p .707 .577 .707 r
F P
0 g
s
.27007 .60255 m .26473 .65728 L .23303 .65534 L p .707 .577 .707 r
F P
0 g
s
.32634 .69292 m .3192 .72846 L .29233 .71805 L p .707 .577 .707 r
F P
0 g
s
.29233 .71805 m .29947 .68251 L .32634 .69292 L p .707 .577 .707 r
F P
0 g
s
.73111 .65742 m .73644 .60269 L .70541 .59777 L p .707 .577 .707 r
F P
0 g
s
.73644 .60269 m .73111 .65742 L .76281 .65936 L p .707 .577 .707 r
F P
0 g
s
.76281 .65936 m .76814 .60463 L .73644 .60269 L p .707 .577 .707 r
F P
0 g
s
.20149 .70455 m .20863 .66901 L .23759 .66994 L p .707 .577 .707 r
F P
0 g
s
.21015 .72776 m .20685 .74562 L .18303 .74871 L p .707 .577 .707 r
F P
0 g
s
.76814 .60463 m .76281 .65936 L .79209 .65814 L p .707 .577 .707 r
F P
0 g
s
.79209 .65814 m .79742 .6034 L .76814 .60463 L p .707 .577 .707 r
F P
0 g
s
.38239 .26115 m .40119 .76468 L .37808 .77534 L p .707 .577 .707 r
F P
0 g
s
.40119 .76468 m .38239 .26115 L .41634 .2524 L p .707 .577 .707 r
F P
0 g
s
.70008 .65251 m .70541 .59777 L .6781 .59037 L p .707 .577 .707 r
F P
0 g
s
.70541 .59777 m .70008 .65251 L .73111 .65742 L p .707 .577 .707 r
F P
0 g
s
.23759 .66994 m .23045 .70548 L .20149 .70455 L p .707 .577 .707 r
F P
0 g
s
.29947 .68251 m .29233 .71805 L .26175 .71013 L p .707 .577 .707 r
F P
0 g
s
.26175 .71013 m .26889 .67459 L .29947 .68251 L p .707 .577 .707 r
F P
0 g
s
.23045 .70548 m .23759 .66994 L .26889 .67459 L p .707 .577 .707 r
F P
0 g
s
.32817 .75004 m .32487 .7679 L .29792 .75794 L p .707 .577 .707 r
F P
0 g
s
.29792 .75794 m .30122 .74008 L .32817 .75004 L p .707 .577 .707 r
F P
0 g
s
.20685 .74562 m .21015 .72776 L .23917 .72837 L p .707 .577 .707 r
F P
0 g
s
.79742 .6034 m .79209 .65814 L .81607 .65387 L p .707 .577 .707 r
F P
0 g
s
.81607 .65387 m .82141 .59914 L .79742 .6034 L p .707 .577 .707 r
F P
0 g
s
.26889 .67459 m .26175 .71013 L .23045 .70548 L p .707 .577 .707 r
F P
0 g
s
.58542 .24937 m .60421 .7529 L .56548 .74837 L p .707 .577 .707 r
F P
0 g
s
.56548 .74837 m .54669 .24484 L .58542 .24937 L p .707 .577 .707 r
F P
0 g
s
.67277 .6451 m .6781 .59037 L .65718 .5812 L p .707 .577 .707 r
F P
0 g
s
.6781 .59037 m .67277 .6451 L .70008 .65251 L p .707 .577 .707 r
F P
0 g
s
.23917 .72837 m .23587 .74622 L .20685 .74562 L p .707 .577 .707 r
F P
0 g
s
.72723 .72409 m .73437 .68855 L .70379 .68063 L p .707 .577 .707 r
F P
0 g
s
.73437 .68855 m .72723 .72409 L .75853 .72874 L p .707 .577 .707 r
F P
0 g
s
.75853 .72874 m .76567 .6932 L .73437 .68855 L p .707 .577 .707 r
F P
0 g
s
.30122 .74008 m .29792 .75794 L .26725 .75047 L p .707 .577 .707 r
F P
0 g
s
.26725 .75047 m .27055 .73262 L .30122 .74008 L p .707 .577 .707 r
F P
0 g
s
.76567 .6932 m .75853 .72874 L .78749 .72967 L p .707 .577 .707 r
F P
0 g
s
.78749 .72967 m .79463 .69413 L .76567 .6932 L p .707 .577 .707 r
F P
0 g
s
.23587 .74622 m .23917 .72837 L .27055 .73262 L p .707 .577 .707 r
F P
0 g
s
.69665 .71617 m .70379 .68063 L .67692 .67022 L p .707 .577 .707 r
F P
0 g
s
.70379 .68063 m .69665 .71617 L .72723 .72409 L p .707 .577 .707 r
F P
0 g
s
.43513 .75593 m .41634 .2524 L .4578 .24644 L p .707 .577 .707 r
F P
0 g
s
.41634 .2524 m .43513 .75593 L .40119 .76468 L p .707 .577 .707 r
F P
0 g
s
.27055 .73262 m .26725 .75047 L .23587 .74622 L p .707 .577 .707 r
F P
0 g
s
.82141 .59914 m .81607 .65387 L .83242 .64698 L p .707 .577 .707 r
F P
0 g
s
.83242 .64698 m .83775 .59225 L .82141 .59914 L p .707 .577 .707 r
F P
0 g
s
.65718 .5812 m .65184 .63593 L .67277 .6451 L p .707 .577 .707 r
F P
0 g
s
.7329 .76905 m .7362 .7512 L .70554 .74373 L p .707 .577 .707 r
F P
0 g
s
.7362 .7512 m .7329 .76905 L .76428 .77329 L p .707 .577 .707 r
F P
0 g
s
.76428 .77329 m .76758 .75544 L .7362 .7512 L p .707 .577 .707 r
F P
0 g
s
.54669 .24484 m .56548 .74837 L .5215 .74736 L p .707 .577 .707 r
F P
0 g
s
.5215 .74736 m .50271 .24383 L .54669 .24484 L p .707 .577 .707 r
F P
0 g
s
.67692 .67022 m .66978 .70576 L .69665 .71617 L p .707 .577 .707 r
F P
0 g
s
.79463 .69413 m .78749 .72967 L .81127 .72679 L p .707 .577 .707 r
F P
0 g
s
.81127 .72679 m .81841 .69124 L .79463 .69413 L p .707 .577 .707 r
F P
0 g
s
.65184 .63593 m .65718 .5812 L .64469 .57116 L p .707 .577 .707 r
F P
0 g
s
.66978 .70576 m .67692 .67022 L .6564 .65834 L p .707 .577 .707 r
F P
0 g
s
.76758 .75544 m .76428 .77329 L .7933 .7739 L p .707 .577 .707 r
F P
0 g
s
.7933 .7739 m .79661 .75605 L .76758 .75544 L p .707 .577 .707 r
F P
0 g
s
.70224 .76158 m .70554 .74373 L .67858 .73377 L p .707 .577 .707 r
F P
0 g
s
.70554 .74373 m .70224 .76158 L .7329 .76905 L p .707 .577 .707 r
F P
0 g
s
.47659 .74996 m .4578 .24644 L .50271 .24383 L p .707 .577 .707 r
F P
0 g
s
.4578 .24644 m .47659 .74996 L .43513 .75593 L p .707 .577 .707 r
F P
0 g
s
.50271 .24383 m .5215 .74736 L .47659 .74996 L p .707 .577 .707 r
F P
0 g
s
.67858 .73377 m .67528 .75162 L .70224 .76158 L p .707 .577 .707 r
F P
0 g
s
.6564 .65834 m .64926 .69388 L .66978 .70576 L p .707 .577 .707 r
F P
0 g
s
.79661 .75605 m .7933 .7739 L .81713 .77081 L p .707 .577 .707 r
F P
0 g
s
.81713 .77081 m .82043 .75296 L .79661 .75605 L p .707 .577 .707 r
F P
0 g
s
.67528 .75162 m .67858 .73377 L .65798 .72229 L p .707 .577 .707 r
F P
0 g
s
.83775 .59225 m .83242 .64698 L .83953 .63814 L p .707 .577 .707 r
F P
0 g
s
.83953 .63814 m .84486 .58341 L .83775 .59225 L p .707 .577 .707 r
F P
0 g
s
.81841 .69124 m .81127 .72679 L .82755 .72037 L p .707 .577 .707 r
F P
0 g
s
.82755 .72037 m .83469 .68483 L .81841 .69124 L p .707 .577 .707 r
F P
0 g
s
.64926 .69388 m .6564 .65834 L .64423 .64615 L p .707 .577 .707 r
F P
0 g
s
.65798 .72229 m .65468 .74014 L .67528 .75162 L p .707 .577 .707 r
F P
0 g
s
.82043 .75296 m .81713 .77081 L .83341 .76432 L p .707 .577 .707 r
F P
0 g
s
.83341 .76432 m .83672 .74647 L .82043 .75296 L p .707 .577 .707 r
F P
0 g
s
.65468 .74014 m .65798 .72229 L .64575 .71042 L p .707 .577 .707 r
F P
0 g
s
.64186 .56123 m .63653 .61596 L .63935 .62589 L p .707 .577 .707 r
F P
0 g
s
.64575 .71042 m .64245 .72827 L .65468 .74014 L p .707 .577 .707 r
F P
0 g
s
.83469 .68483 m .82755 .72037 L .83473 .71105 L p .707 .577 .707 r
F P
0 g
s
.83473 .71105 m .84186 .67551 L .83469 .68483 L p .707 .577 .707 r
F P
0 g
s
.63709 .68169 m .64423 .64615 L .64161 .63484 L p .707 .577 .707 r
F P
0 g
s
.84486 .58341 m .83953 .63814 L .8367 .62821 L p .707 .577 .707 r
F P
0 g
s
.8367 .62821 m .84203 .57348 L .84486 .58341 L p .707 .577 .707 r
F P
0 g
s
.63653 .61596 m .64186 .56123 L .64896 .55239 L p .707 .577 .707 r
F P
0 g
s
.64161 .63484 m .63447 .67038 L .63709 .68169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83672 .74647 m .83341 .76432 L .84058 .75508 L p .707 .577 .707 r
F P
0 g
s
.84058 .75508 m .84388 .73722 L .83672 .74647 L p .707 .577 .707 r
F P
0 g
s
.64245 .72827 m .64575 .71042 L .64309 .69932 L p .707 .577 .707 r
F P
0 g
s
.64309 .69932 m .63979 .71717 L .64245 .72827 L p .707 .577 .707 r
F P
0 g
s
.64896 .55239 m .64363 .60712 L .63653 .61596 L p .707 .577 .707 r
F P
0 g
s
.84186 .67551 m .83473 .71105 L .8321 .69975 L p .707 .577 .707 r
F P
0 g
s
.8321 .69975 m .83924 .6642 L .84186 .67551 L p .707 .577 .707 r
F P
0 g
s
.63447 .67038 m .64161 .63484 L .64878 .62553 L p .707 .577 .707 r
F P
0 g
s
.84203 .57348 m .8367 .62821 L .82421 .61817 L p .707 .577 .707 r
F P
0 g
s
.82421 .61817 m .82954 .56344 L .84203 .57348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64363 .60712 m .64896 .55239 L .66531 .5455 L p .707 .577 .707 r
F P
0 g
s
.3881 .62598 m .39343 .57125 L .3624 .56634 L p .707 .577 .707 r
F P
0 g
s
.39343 .57125 m .3881 .62598 L .4198 .62792 L p .707 .577 .707 r
F P
0 g
s
.4198 .62792 m .42513 .57319 L .39343 .57125 L p .707 .577 .707 r
F P
0 g
s
.64878 .62553 m .64165 .66107 L .63447 .67038 L p .707 .577 .707 r
F P
0 g
s
.84388 .73722 m .84058 .75508 L .83791 .74398 L p .707 .577 .707 r
F P
0 g
s
.83791 .74398 m .84121 .72612 L .84388 .73722 L p .707 .577 .707 r
F P
0 g
s
.42513 .57319 m .4198 .62792 L .44908 .6267 L p .707 .577 .707 r
F P
0 g
s
.44908 .6267 m .45441 .57197 L .42513 .57319 L p .707 .577 .707 r
F P
0 g
s
.63979 .71717 m .64309 .69932 L .65025 .69007 L p .707 .577 .707 r
F P
0 g
s
.35707 .62107 m .3624 .56634 L .33509 .55893 L p .707 .577 .707 r
F P
0 g
s
.3624 .56634 m .35707 .62107 L .3881 .62598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65025 .69007 m .64695 .70793 L .63979 .71717 L p .707 .577 .707 r
F P
0 g
s
.66531 .5455 m .65998 .60023 L .64363 .60712 L p .707 .577 .707 r
F P
0 g
s
.45441 .57197 m .44908 .6267 L .47306 .62244 L p .707 .577 .707 r
F P
0 g
s
.47306 .62244 m .4784 .5677 L .45441 .57197 L p .707 .577 .707 r
F P
0 g
s
.83924 .6642 m .8321 .69975 L .81993 .68755 L p .707 .577 .707 r
F P
0 g
s
.81993 .68755 m .82707 .65201 L .83924 .6642 L p .707 .577 .707 r
F P
0 g
s
.64165 .66107 m .64878 .62553 L .66506 .61911 L p .707 .577 .707 r
F P
0 g
s
.82954 .56344 m .82421 .61817 L .80329 .609 L p .707 .577 .707 r
F P
0 g
s
.80329 .609 m .80862 .55427 L .82954 .56344 L p .707 .577 .707 r
F P
0 g
s
.32976 .61366 m .33509 .55893 L .31417 .54976 L p .707 .577 .707 r
F P
0 g
s
.33509 .55893 m .32976 .61366 L .35707 .62107 L p .707 .577 .707 r
F P
0 g
s
.38422 .68484 m .39136 .6493 L .36078 .64138 L p .707 .577 .707 r
F P
0 g
s
.39136 .6493 m .38422 .68484 L .41552 .68949 L p .707 .577 .707 r
F P
0 g
s
.41552 .68949 m .42266 .65395 L .39136 .6493 L p .707 .577 .707 r
F P
0 g
s
.65998 .60023 m .66531 .5455 L .6893 .54123 L p .707 .577 .707 r
F P
0 g
s
.42266 .65395 m .41552 .68949 L .44448 .69042 L p .707 .577 .707 r
F P
0 g
s
.44448 .69042 m .45162 .65487 L .42266 .65395 L p .707 .577 .707 r
F P
0 g
s
.35364 .67692 m .36078 .64138 L .33391 .63097 L p .707 .577 .707 r
F P
0 g
s
.36078 .64138 m .35364 .67692 L .38422 .68484 L p .707 .577 .707 r
F P
0 g
s
.66506 .61911 m .65792 .65465 L .64165 .66107 L p .707 .577 .707 r
F P
0 g
s
.84121 .72612 m .83791 .74398 L .82568 .73211 L p .707 .577 .707 r
F P
0 g
s
.82568 .73211 m .82898 .71425 L .84121 .72612 L p .707 .577 .707 r
F P
0 g
s
.64695 .70793 m .65025 .69007 L .66654 .68359 L p .707 .577 .707 r
F P
0 g
s
.4784 .5677 m .47306 .62244 L .48941 .61554 L p .707 .577 .707 r
F P
0 g
s
.48941 .61554 m .49474 .56081 L .4784 .5677 L p .707 .577 .707 r
F P
0 g
s
.38989 .72428 m .39319 .70642 L .36253 .69896 L p .707 .577 .707 r
F P
0 g
s
.39319 .70642 m .38989 .72428 L .42127 .72852 L p .707 .577 .707 r
F P
0 g
s
.42127 .72852 m .42457 .71067 L .39319 .70642 L p .707 .577 .707 r
F P
0 g
s
.31417 .54976 m .30883 .60449 L .32976 .61366 L p .707 .577 .707 r
F P
0 g
s
.80862 .55427 m .80329 .609 L .77597 .6016 L p .707 .577 .707 r
F P
0 g
s
.77597 .6016 m .78131 .54686 L .80862 .55427 L p .707 .577 .707 r
F P
0 g
s
.33391 .63097 m .32677 .66651 L .35364 .67692 L p .707 .577 .707 r
F P
0 g
s
.45162 .65487 m .44448 .69042 L .46826 .68753 L p .707 .577 .707 r
F P
0 g
s
.46826 .68753 m .4754 .65199 L .45162 .65487 L p .707 .577 .707 r
F P
0 g
s
.6893 .54123 m .68396 .59597 L .65998 .60023 L p .707 .577 .707 r
F P
0 g
s
.32677 .66651 m .33391 .63097 L .31339 .61909 L p .707 .577 .707 r
F P
0 g
s
.66654 .68359 m .66324 .70144 L .64695 .70793 L p .707 .577 .707 r
F P
0 g
s
.42457 .71067 m .42127 .72852 L .45029 .72913 L p .707 .577 .707 r
F P
0 g
s
.45029 .72913 m .4536 .71128 L .42457 .71067 L p .707 .577 .707 r
F P
0 g
s
.35923 .71681 m .36253 .69896 L .33557 .689 L p .707 .577 .707 r
F P
0 g
s
.36253 .69896 m .35923 .71681 L .38989 .72428 L p .707 .577 .707 r
F P
0 g
s
.30883 .60449 m .31417 .54976 L .30168 .53972 L p .707 .577 .707 r
F P
0 g
s
.82707 .65201 m .81993 .68755 L .79941 .67567 L p .707 .577 .707 r
F P
0 g
s
.79941 .67567 m .80655 .64013 L .82707 .65201 L p .707 .577 .707 r
F P
0 g
s
.65792 .65465 m .66506 .61911 L .68884 .61623 L p .707 .577 .707 r
F P
0 g
s
.68396 .59597 m .6893 .54123 L .71858 .54001 L p .707 .577 .707 r
F P
0 g
s
.33557 .689 m .33227 .70685 L .35923 .71681 L p .707 .577 .707 r
F P
0 g
s
.31339 .61909 m .30625 .65463 L .32677 .66651 L p .707 .577 .707 r
F P
0 g
s
.78131 .54686 m .77597 .6016 L .74495 .59668 L p .707 .577 .707 r
F P
0 g
s
.74495 .59668 m .75028 .54195 L .78131 .54686 L p .707 .577 .707 r
F P
0 g
s
.4536 .71128 m .45029 .72913 L .47412 .72604 L p .707 .577 .707 r
F P
0 g
s
.47412 .72604 m .47742 .70819 L .4536 .71128 L p .707 .577 .707 r
F P
0 g
s
.33227 .70685 m .33557 .689 L .31497 .67752 L p .707 .577 .707 r
F P
0 g
s
.71324 .59474 m .71858 .54001 L .75028 .54195 L p .707 .577 .707 r
F P
0 g
s
.71858 .54001 m .71324 .59474 L .68396 .59597 L p .707 .577 .707 r
F P
0 g
s
.68884 .61623 m .6817 .65177 L .65792 .65465 L p .707 .577 .707 r
F P
0 g
s
.82898 .71425 m .82568 .73211 L .80508 .72063 L p .707 .577 .707 r
F P
0 g
s
.80508 .72063 m .80838 .70278 L .82898 .71425 L p .707 .577 .707 r
F P
0 g
s
.30168 .53972 m .29634 .59445 L .30883 .60449 L p .707 .577 .707 r
F P
0 g
s
.75028 .54195 m .74495 .59668 L .71324 .59474 L p .707 .577 .707 r
F P
0 g
s
.4754 .65199 m .46826 .68753 L .48454 .68112 L p .707 .577 .707 r
F P
0 g
s
.48454 .68112 m .49168 .64558 L .4754 .65199 L p .707 .577 .707 r
F P
0 g
s
.66324 .70144 m .66654 .68359 L .69036 .6805 L p .707 .577 .707 r
F P
0 g
s
.30625 .65463 m .31339 .61909 L .30122 .6069 L p .707 .577 .707 r
F P
0 g
s
.31497 .67752 m .31167 .69537 L .33227 .70685 L p .707 .577 .707 r
F P
0 g
s
.49474 .56081 m .48941 .61554 L .49652 .6067 L p .707 .577 .707 r
F P
0 g
s
.49652 .6067 m .50185 .55197 L .49474 .56081 L p .707 .577 .707 r
F P
0 g
s
.80655 .64013 m .79941 .67567 L .77254 .66526 L p .707 .577 .707 r
F P
0 g
s
.77254 .66526 m .77968 .62972 L .80655 .64013 L p .707 .577 .707 r
F P
0 g
s
.6817 .65177 m .68884 .61623 L .7178 .61716 L p .707 .577 .707 r
F P
0 g
s
.69036 .6805 m .68706 .69835 L .66324 .70144 L p .707 .577 .707 r
F P
0 g
s
.29634 .59445 m .30168 .53972 L .29885 .52979 L p .707 .577 .707 r
F P
0 g
s
.30122 .6069 m .29408 .64244 L .30625 .65463 L p .707 .577 .707 r
F P
0 g
s
.47742 .70819 m .47412 .72604 L .4904 .71955 L p .707 .577 .707 r
F P
0 g
s
.4904 .71955 m .49371 .7017 L .47742 .70819 L p .707 .577 .707 r
F P
0 g
s
.31167 .69537 m .31497 .67752 L .30274 .66565 L p .707 .577 .707 r
F P
0 g
s
.7178 .61716 m .71066 .6527 L .6817 .65177 L p .707 .577 .707 r
F P
0 g
s
.77968 .62972 m .77254 .66526 L .74196 .65735 L p .707 .577 .707 r
F P
0 g
s
.74196 .65735 m .7491 .62181 L .77968 .62972 L p .707 .577 .707 r
F P
0 g
s
.71066 .6527 m .7178 .61716 L .7491 .62181 L p .707 .577 .707 r
F P
0 g
s
.80838 .70278 m .80508 .72063 L .77813 .71067 L p .707 .577 .707 r
F P
0 g
s
.77813 .71067 m .78143 .69282 L .80838 .70278 L p .707 .577 .707 r
F P
0 g
s
.68706 .69835 m .69036 .6805 L .71938 .6811 L p .707 .577 .707 r
F P
0 g
s
.7491 .62181 m .74196 .65735 L .71066 .6527 L p .707 .577 .707 r
F P
0 g
s
.30274 .66565 m .29944 .6835 L .31167 .69537 L p .707 .577 .707 r
F P
0 g
s
.29885 .52979 m .29351 .58453 L .29634 .59445 L p .707 .577 .707 r
F P
0 g
s
.49168 .64558 m .48454 .68112 L .49171 .6718 L p .707 .577 .707 r
F P
0 g
s
.49171 .6718 m .49885 .63626 L .49168 .64558 L p .707 .577 .707 r
F P
0 g
s
.71938 .6811 m .71608 .69896 L .68706 .69835 L p .707 .577 .707 r
F P
0 g
s
.29408 .64244 m .30122 .6069 L .2986 .59559 L p .707 .577 .707 r
F P
0 g
s
.50185 .55197 m .49652 .6067 L .49369 .59678 L p .707 .577 .707 r
F P
0 g
s
.49369 .59678 m .49902 .54204 L .50185 .55197 L p .707 .577 .707 r
F P
0 g
s
.78143 .69282 m .77813 .71067 L .74746 .7032 L p .707 .577 .707 r
F P
0 g
s
.74746 .7032 m .75076 .68535 L .78143 .69282 L p .707 .577 .707 r
F P
0 g
s
.71608 .69896 m .71938 .6811 L .75076 .68535 L p .707 .577 .707 r
F P
0 g
s
.75076 .68535 m .74746 .7032 L .71608 .69896 L p .707 .577 .707 r
F P
0 g
s
.29351 .58453 m .29885 .52979 L .30595 .52095 L p .707 .577 .707 r
F P
0 g
s
.2986 .59559 m .29146 .63113 L .29408 .64244 L p .707 .577 .707 r
F P
0 g
s
.49371 .7017 m .4904 .71955 L .49757 .71031 L p .707 .577 .707 r
F P
0 g
s
.49757 .71031 m .50087 .69245 L .49371 .7017 L p .707 .577 .707 r
F P
0 g
s
.29944 .6835 m .30274 .66565 L .30008 .65455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30008 .65455 m .29678 .6724 L .29944 .6835 L p .707 .577 .707 r
F P
0 g
s
.49885 .63626 m .49171 .6718 L .48909 .66049 L p .707 .577 .707 r
F P
0 g
s
.48909 .66049 m .49623 .62495 L .49885 .63626 L p .707 .577 .707 r
F P
0 g
s
.30595 .52095 m .30062 .57568 L .29351 .58453 L p .707 .577 .707 r
F P
0 g
s
.29146 .63113 m .2986 .59559 L .30577 .58627 L p .707 .577 .707 r
F P
0 g
s
.49902 .54204 m .49369 .59678 L .4812 .58674 L p .707 .577 .707 r
F P
0 g
s
.4812 .58674 m .48653 .532 L .49902 .54204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30062 .57568 m .30595 .52095 L .3223 .51406 L p .707 .577 .707 r
F P
0 g
s
.30577 .58627 m .29864 .62181 L .29146 .63113 L p .707 .577 .707 r
F P
0 g
s
.50087 .69245 m .49757 .71031 L .4949 .69921 L p .707 .577 .707 r
F P
0 g
s
.4949 .69921 m .4982 .68135 L .50087 .69245 L p .707 .577 .707 r
F P
0 g
s
.29678 .6724 m .30008 .65455 L .30724 .6453 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30724 .6453 m .30394 .66316 L .29678 .6724 L p .707 .577 .707 r
F P
0 g
s
.49623 .62495 m .48909 .66049 L .47692 .6483 L p .707 .577 .707 r
F P
0 g
s
.47692 .6483 m .48406 .61276 L .49623 .62495 L p .707 .577 .707 r
F P
0 g
s
.3223 .51406 m .31697 .56879 L .30062 .57568 L p .707 .577 .707 r
F P
0 g
s
.29864 .62181 m .30577 .58627 L .32205 .57986 L p .707 .577 .707 r
F P
0 g
s
.48653 .532 m .4812 .58674 L .46027 .57756 L p .707 .577 .707 r
F P
0 g
s
.46027 .57756 m .46561 .52283 L .48653 .532 L p .707 .577 .707 r
F P
0 g
s
.31697 .56879 m .3223 .51406 L .34629 .50979 L p .707 .577 .707 r
F P
0 g
s
.32205 .57986 m .31491 .6154 L .29864 .62181 L p .707 .577 .707 r
F P
0 g
s
.4982 .68135 m .4949 .69921 L .48267 .68734 L p .707 .577 .707 r
F P
0 g
s
.48267 .68734 m .48597 .66948 L .4982 .68135 L p .707 .577 .707 r
F P
0 g
s
.30394 .66316 m .30724 .6453 L .32353 .63882 L p .707 .577 .707 r
F P
0 g
s
.32353 .63882 m .32023 .65667 L .30394 .66316 L p .707 .577 .707 r
F P
0 g
s
.46561 .52283 m .46027 .57756 L .43296 .57016 L p .707 .577 .707 r
F P
0 g
s
.43296 .57016 m .4383 .51543 L .46561 .52283 L p .707 .577 .707 r
F P
0 g
s
.48406 .61276 m .47692 .6483 L .4564 .63642 L p .707 .577 .707 r
F P
0 g
s
.4564 .63642 m .46354 .60088 L .48406 .61276 L p .707 .577 .707 r
F P
0 g
s
.34629 .50979 m .34095 .56453 L .31697 .56879 L p .707 .577 .707 r
F P
0 g
s
.31491 .6154 m .32205 .57986 L .34583 .57697 L p .707 .577 .707 r
F P
0 g
s
.34095 .56453 m .34629 .50979 L .37556 .50857 L p .707 .577 .707 r
F P
0 g
s
.4383 .51543 m .43296 .57016 L .40194 .56525 L p .707 .577 .707 r
F P
0 g
s
.40194 .56525 m .40727 .51051 L .4383 .51543 L p .707 .577 .707 r
F P
0 g
s
.34583 .57697 m .33869 .61251 L .31491 .6154 L p .707 .577 .707 r
F P
0 g
s
.48597 .66948 m .48267 .68734 L .46207 .67586 L p .707 .577 .707 r
F P
0 g
s
.46207 .67586 m .46537 .65801 L .48597 .66948 L p .707 .577 .707 r
F P
0 g
s
.37023 .56331 m .37556 .50857 L .40727 .51051 L p .707 .577 .707 r
F P
0 g
s
.37556 .50857 m .37023 .56331 L .34095 .56453 L p .707 .577 .707 r
F P
0 g
s
.32023 .65667 m .32353 .63882 L .34735 .63572 L p .707 .577 .707 r
F P
0 g
s
.40727 .51051 m .40194 .56525 L .37023 .56331 L p .707 .577 .707 r
F P
0 g
s
.46354 .60088 m .4564 .63642 L .42953 .62601 L p .707 .577 .707 r
F P
0 g
s
.42953 .62601 m .43667 .59047 L .46354 .60088 L p .707 .577 .707 r
F P
0 g
s
.33869 .61251 m .34583 .57697 L .37479 .5779 L p .707 .577 .707 r
F P
0 g
s
.34735 .63572 m .34405 .65358 L .32023 .65667 L p .707 .577 .707 r
F P
0 g
s
.37479 .5779 m .36765 .61344 L .33869 .61251 L p .707 .577 .707 r
F P
0 g
s
.43667 .59047 m .42953 .62601 L .39895 .61809 L p .707 .577 .707 r
F P
0 g
s
.39895 .61809 m .40609 .58255 L .43667 .59047 L p .707 .577 .707 r
F P
0 g
s
.36765 .61344 m .37479 .5779 L .40609 .58255 L p .707 .577 .707 r
F P
0 g
s
.46537 .65801 m .46207 .67586 L .43512 .6659 L p .707 .577 .707 r
F P
0 g
s
.43512 .6659 m .43842 .64805 L .46537 .65801 L p .707 .577 .707 r
F P
0 g
s
.34405 .65358 m .34735 .63572 L .37637 .63633 L p .707 .577 .707 r
F P
0 g
s
.40609 .58255 m .39895 .61809 L .36765 .61344 L p .707 .577 .707 r
F P
0 g
s
.37637 .63633 m .37307 .65419 L .34405 .65358 L p .707 .577 .707 r
F P
0 g
s
.43842 .64805 m .43512 .6659 L .40445 .65843 L p .707 .577 .707 r
F P
0 g
s
.40445 .65843 m .40775 .64058 L .43842 .64805 L p .707 .577 .707 r
F P
0 g
s
.37307 .65419 m .37637 .63633 L .40775 .64058 L p .707 .577 .707 r
F P
0 g
s
.40775 .64058 m .40445 .65843 L .37307 .65419 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo6000O7oo001mOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Eoo`P000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001cOol0079oo`<00003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001`
Ool006ioo`@000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP<006eoo`00K7oo0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006]oo`00JWoo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Uoo`00J7oo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFJGoo001VOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol006Eoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001oogoo06Ioo`00I7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0IGoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`03
001JEP0000P000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo20000eYF00<005YFFUH00UYF2@0000=J
EP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001JOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Qoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001EOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol005Aoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Uoo`l004aoo`00E7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEPT004=oo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH003eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
000iOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH3000eOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF008003=oo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03
001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00Dgoo00<0
05YF00000eYF1@0000=JEP00FUH01EYF1@000eYF1@000UYF10000UYF00<005YFFUH015YF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000`Ool005=oo`04001JEP00FUH20005FUH00`00FUIJ
EP06FUH01000FUIJEUYF2@001EYF10001EYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0002FUH=00000eYF001JEP04FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00Dgoo0P000eYF00<005YF00005@0025YF00<005YFFUH01UYF0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002eoo`00Dgoo0P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000UYF00<005YFFUH01UYF00<005YFFUH00`0000=JEP00FUH00UYF0P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;7oo001COol200000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20003FUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2000/Ool005=oo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP8000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00H0
05YFFUH005YF000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000/Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH]Ool0041oo`P000aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEUYF
009JEP<000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF008000=J
EPD00003FUH005YF00EJEPH000=oo`D00003Ool000000080009JEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Qoo`P000=JEP03001JEUYF009JEPT000=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJ
EP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH0
05YF0`001EYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUH000AJEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH50005FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0P00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000UYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJEP03001J
EUYF00EJEP@000AJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP`0009JEP03001JEUYF00EJEPH000QJEP03001JEUYF00AJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEP0000l000QJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000UYF00D005YFFUIJEP00009JEP800003Ool0000000<000IJEP03001JEUYF009JEP<000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000050002FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004
FUH300000eYF001JEP03FUH20002Ool00`00FUH000030002FUH00`00FUIJEP05FUH300000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000`0025YF00<005YFFUH00eYF00@005YFFUIJEP<002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
0`0015YF00<005YFFUH00P001EYF0P0000=oo`00FUH00UYF00<005YF00003`001EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002ioo`00;Goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH00eYF0P000eYF00@005YF000000=JEP04001JEUYFFUH50007FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF00=JEPl00003FUH0000000<000MJEP03001JEUYF00=JEP8000IJEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
00000P001UYF00L005YFFUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00@000=J
EP03001JEUYF00EJEP03001JEUYF00H000MJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00L0
05YFFUIJEP00FUH0000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00AJEP03001JEUYF00MJEP04001JEUYF0004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03FUH2000_Ool002eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000YJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004
FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@000QJEP8000AJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003
FUH01000FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEPD0009J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH01000
FUIJEUYF3`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo000/Ool0
0`00FUH00004FUH01000FUIJEUYF5`001UYF0`000eYF1@001UYF2@0015YF00<005YFFUH01eYF00@0
05YFFUIJEP@000=JEP03001JEP0000<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEP000002FUH60004FUH20006Ool90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000`Ool002aoo`03001JEP0000=JEPD00003FUH005YF00AJEPH000=oo`D0009oo`@0009JEP<00003
FUH00000009JEP03001JEUYF00IJEP03001JEUYF00IJEPL000IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
0003FUH005YF009JEP03001JEUYF00=JEP8000ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP0002moo`00;7oo00@005YF001JEP8000IJEP03001JEUYF00EJEP04001JEUYFFUH90005
Ool60002FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH30003
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH40003FUH300000eYF001J
EP04FUH01000FUH000003goo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00;7oo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH=000015YF
000000001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH00P00
00=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF10000eYF00<005YF
FUH00P001EYF00D005YFFUIJEP0000Qoo`<000Ioo`<000MJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool002aoo`8000=JEP03001JEUYF00=JEQ8000QJEP03001JEUYF00@0009JEP80009JEP8000AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP<000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800005FUH005YFFUH00005FUH30002
FUH01@00FUIJEUYF00001goo1@0027oo0P0015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00/005YFFUH005YF001J
EP00FUH005YF0080009JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00EJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEP00008000=JEP8000Ioo`D000Yoo`<00003FUH005YF00EJEP06001JEUYF
001JEP00;Goo000/Ool2000015YF000000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH010001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P001UYF00<005YF00001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEP<0
0003FUH0000000Ioo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool40004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP02FUH30004
FUH20003FUH60002FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF0000
0eYF00<005YFFUH00eYF00<005YF00004P0047oo0P000eYF00L005YFFUIJEP00FUH0000]Ool002eo
o`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP03001JEUYF0080009JEP05001JEP00001JEP030002FUH90003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH300000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH00UYF
1P003goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH30003FUH40002FUH0
1000FUIJEUYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEPD00003FUH0000000=JEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P003Woo0P000eYF0P00;Woo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000
FUH000001UYF00D005YF000005YF00@0009JEP04001JEUYFFUH500000eYF0000000<0004FUH02@00
FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF
0`0027oo1P0000AJEP00FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH50002FUH00`00FUIJ
EP02FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00P0000=JEP00Ool0;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH0
0`00FUH000030004FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00QJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00YJEP04001JEUYFFUH30005FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH50007FUH00`00
FUIJEP05FUH70008FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUH0000^Ool002aoo`80
00AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP03
FUH50009FUH00`00FUIJEP09FUH01@00FUH00000FUH00P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0000EJEP00000005YF00<000MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000AJEP03001JEUYF00EJEP<000AJEP8002moo`00;7oo0P000UYF1P000Woo1000
0UYF00<005YFFUH01EYF1P0025YF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH01UYF
00<005YFFUH010001EYF00<005YFFUH01UYF1@000eYF0P001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP<00003FUH005YF00=JEP8000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP@00003FUH005YF00IJEP04001JEUYF0003FUH2000_Ool002aoo`04FUH000000002
FUH00`00Oomoo`07Ool50006FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH>0003FUH01000FUIJEUYF0P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000100000=JEP00FUH015YF100000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000EJEP03001JEUYF009JEP<00003FUH007oo
02ioo`00:goo0`0015YF0`0037oo10000UYF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00<005YF
FUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH3
00000eYF001JEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH00`0015YF00<005YFFUH015YF1000
00=JEP00FUH01EYF0P00<7oo000[Ool30004FUH00`00FUIJEP02000>Ool@0006FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00
FUH30005FUH00`00FUIJEP02FUH60002FUH00`00FUH000040003FUH00`00FUIJEP05FUH00`00FUIJ
EP020006FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEP8000moo`<000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEP0000@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004Ool90002FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20004FUH01000FUH00000;Woo000[Ool00`00FUIJEP03FUH00`00FUIJEP03FUH90007Ool5
000;Ool200000eYF001JEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF10000UYF00<005YF
FUH01EYF00@005YFFUIJEPD000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000AJEP<000=JEP07001JEUYFFUH005YF000027oo1@000UYF00<005YFFUH01EYF00@005YF
FUIJEPD0009JEP03001JEUYF009JEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF00<005YFFUH0
10000eYF00<005YFFUH00UYF30003Goo0P001UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03
001JEUYF00h000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP0000AJEP03001JEUYF00800003FUH005YF009JEP03001JEP0000Uoo`<00003Ool00000
00`000Eoo`<000AJEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00@005YFFUIJEPL000aoo`8000=JEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP03FUH20003FUH2000SOol00`00FUIJEP02FUH00`00Oomo
o`0[Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00@000Yoo`800003FUH005YF00=JEP800005OomJEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`001EYF00D005YF000005YF008002Aoo`03001JEUYF008002eoo`00;Woo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100027oo0P00
15YF00<007ooOol00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@0
05YFFUIJEP<002Eoo`@002eoo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000Aoo`D0009JEP80009oo`=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH4000SOol2000]Ool002ioo`8000=J
EQ@000AJEP03001JEUYF00MJEP04001JEUYFFUH40003FUH00`00FUH000030002Ool3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`000UYF0`0025YF00<005YFFUH010007Woo0P00;Woo000^Ool200000eYF00000002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03
0002Ool3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<000<FUH00`00FUIJEP06
FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00@005YF000000MJEP03001JEUYF00AJ
EPL001Eoo`@002ioo`00;Woo0`000Woo0`0025YF00<005YFFUH01UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF0`000eYF0`000Woo0eYF00<005YFFUH015YF00<005YFFUH01EYF20002eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001UYF00L005YFFUIJEP00FUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH01eYF00<005YFFUH00UYF5@000UYF0P00;Woo000]Ool30005Ool2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP0200000eYF
00000003Ool3FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00=JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008002moo`00;Goo10001Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH00eYF0`000goo0eYF00<005YFFUH015YF00<005YF00000P002UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00001UYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;goo000]Ool01@00FUH005YF00001goo0`0000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH01EYF0P000goo0eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YF00001UYF00@005YFFUIJEP800003Ool000000080009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002eoo`80
00=JEP03001oogoo00Moo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000IJ
EP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000000001UYF
00H005YFFUH005YF0005Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo
000^Ool01000FUIJEUYF0`002goo10000UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00H005YFFUIJEP00Ool3FUH01000FUH000001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
0000009oo`8000=JEP07001JEUYFFUH005YF000037oo200015YF00@005YFFUIJEPD003=oo`00;Woo
00D005YFFUIJEP00009JEP03001oogoo00aoo`P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH005YF009JEP03001ooeYF009JEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0004Ool200000eYF001JEP02FUH00`00FUH0000DOol8000hOol002moo`03001JEP0000AJEP8000mo
o`H0009JEP03001JEUYF00EJEP04001JEUYFFUH500000goo00000003FUH01@00OomJEUYF00000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Ioo`8000=JEP8005Eoo`00<7oo0P001UYF
0P003Goo1@0000=oo`000000300027oo00L005YF001JEP00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP000goo1P000UYF0P00EGoo000aOol00`00FUIJEP04FUH00`00FUH00003
000:Ool3000IOol2000015YF0000000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
10000eYF00L005YF001JEP00FUH0001EOol0039oo`8000AJEP03001JEUYF00=JEP@002=oo`03001J
EP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH007oo
05Aoo`00=7oo00@005YFFUH000QJEP04001JEP00000POol2000015YF001oo`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000eYF0P000eYF00<005YFFUH00UYF00<005YF0000EGoo000eOol30008
FUH01000FUIJEUYF0`006goo0P0000=JEP0000000Woo00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@0
05YFFUIJEP<000IJEP800003FUH005YF00=JEP8005Ioo`00=goo0P001UYF00<005YFFUH01EYF1P00
47oo1@000eYF0P000goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00EJEP<0
00AJEP8005Ioo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJ
EP00FUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH30002FUH40006FUH00`00FUIJEP020002FUH2001FOol003eoo`@000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20008Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH3001GOol0045oo`8000AJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000030004FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH2001GOol004=oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP00000BOol50008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH<0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00@005YF000005Eoo`00AWoo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEP@001Uoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJ
EPd000Aoo`P0009JEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH00`00Oomo
o`1BOol004aooa4002=ooaD0009JEP80011ooa<000Aoo`800003FUH005YF00=JEP03001oogoo059o
o`00T7oo00@005YFFUH000EJEP8000moo`<001Eoo`8000AJEP03001oogoo059oo`00TGoo0`001EYF
00@005YF000002Moo`03001JEUYF008005Aoo`00Tgoo00<005YFFUH00eYF00@005YFFUIJEP<002Eo
o`@005Aoo`00U7oo0P000UYF00<005YFFUH01EYF10008goo0P00E7oo002FOol30008FUH00`00FUIJ
EP04000NOol2001EOol009Qoo`8000MJEP03001JEUYF00AJEPL001Eoo`@005Eoo`00VWoo0P0015YF
00<005YFFUH01eYF00<005YFFUH00UYF200027oo1@000UYF0P00EGoo002LOol300000eYF001JEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YFFUH00P00EWoo002OOol40006FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:=oo`@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:Moo`D000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol00:aoo`@0009JEP03001JEUYF00EJ
EP04001JEUYFFUH5001JOol00;1oo`h005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59239 .74927 m .601 .69533 L .57021 .68859 L p .707 .577 .707 r
F P
0 g
s
.601 .69533 m .59239 .74927 L .62389 .75286 L p .707 .577 .707 r
F P
0 g
s
.62389 .75286 m .63249 .69893 L .601 .69533 L p .707 .577 .707 r
F P
0 g
s
.63249 .69893 m .62389 .75286 L .65299 .75295 L p .707 .577 .707 r
F P
0 g
s
.65299 .75295 m .6616 .69902 L .63249 .69893 L p .707 .577 .707 r
F P
0 g
s
.5616 .74252 m .57021 .68859 L .54313 .67935 L p .707 .577 .707 r
F P
0 g
s
.57021 .68859 m .5616 .74252 L .59239 .74927 L p .707 .577 .707 r
F P
0 g
s
.6616 .69902 m .65299 .75295 L .67687 .74953 L p .707 .577 .707 r
F P
0 g
s
.67687 .74953 m .68548 .69559 L .6616 .69902 L p .707 .577 .707 r
F P
0 g
s
.53452 .73329 m .54313 .67935 L .52242 .66852 L p .707 .577 .707 r
F P
0 g
s
.54313 .67935 m .53452 .73329 L .5616 .74252 L p .707 .577 .707 r
F P
0 g
s
.58574 .81947 m .59716 .78559 L .56753 .77413 L p .707 .577 .707 r
F P
0 g
s
.59716 .78559 m .58574 .81947 L .61618 .82732 L p .707 .577 .707 r
F P
0 g
s
.61618 .82732 m .62761 .79344 L .59716 .78559 L p .707 .577 .707 r
F P
0 g
s
.5561 .80801 m .56753 .77413 L .54161 .76017 L p .707 .577 .707 r
F P
0 g
s
.56753 .77413 m .5561 .80801 L .58574 .81947 L p .707 .577 .707 r
F P
0 g
s
.62761 .79344 m .61618 .82732 L .64446 .83079 L p .707 .577 .707 r
F P
0 g
s
.64446 .83079 m .65589 .79691 L .62761 .79344 L p .707 .577 .707 r
F P
0 g
s
.52242 .66852 m .51381 .72246 L .53452 .73329 L p .707 .577 .707 r
F P
0 g
s
.68548 .69559 m .67687 .74953 L .69318 .74293 L p .707 .577 .707 r
F P
0 g
s
.69318 .74293 m .70179 .68899 L .68548 .69559 L p .707 .577 .707 r
F P
0 g
s
.51381 .72246 m .52242 .66852 L .5101 .65717 L p .707 .577 .707 r
F P
0 g
s
.53019 .79405 m .54161 .76017 L .52195 .74509 L p .707 .577 .707 r
F P
0 g
s
.54161 .76017 m .53019 .79405 L .5561 .80801 L p .707 .577 .707 r
F P
0 g
s
.59496 .8666 m .60025 .84947 L .5704 .8387 L p .707 .577 .707 r
F P
0 g
s
.60025 .84947 m .59496 .8666 L .62561 .87382 L p .707 .577 .707 r
F P
0 g
s
.62561 .87382 m .6309 .8567 L .60025 .84947 L p .707 .577 .707 r
F P
0 g
s
.65589 .79691 m .64446 .83079 L .66781 .82954 L p .707 .577 .707 r
F P
0 g
s
.66781 .82954 m .67923 .79566 L .65589 .79691 L p .707 .577 .707 r
F P
0 g
s
.56511 .85583 m .5704 .8387 L .54425 .82544 L p .707 .577 .707 r
F P
0 g
s
.5704 .8387 m .56511 .85583 L .59496 .8666 L p .707 .577 .707 r
F P
0 g
s
.6309 .8567 m .62561 .87382 L .65405 .8768 L p .707 .577 .707 r
F P
0 g
s
.65405 .8768 m .65934 .85967 L .6309 .8567 L p .707 .577 .707 r
F P
0 g
s
.54425 .82544 m .53896 .84257 L .56511 .85583 L p .707 .577 .707 r
F P
0 g
s
.52195 .74509 m .51052 .77897 L .53019 .79405 L p .707 .577 .707 r
F P
0 g
s
.53896 .84257 m .54425 .82544 L .52439 .81098 L p .707 .577 .707 r
F P
0 g
s
.5101 .65717 m .50149 .71111 L .51381 .72246 L p .707 .577 .707 r
F P
0 g
s
.51052 .77897 m .52195 .74509 L .51046 .73035 L p .707 .577 .707 r
F P
0 g
s
.65934 .85967 m .65405 .8768 L .6775 .87522 L p .707 .577 .707 r
F P
0 g
s
.6775 .87522 m .68279 .8581 L .65934 .85967 L p .707 .577 .707 r
F P
0 g
s
.70179 .68899 m .69318 .74293 L .70032 .7338 L p .707 .577 .707 r
F P
0 g
s
.70032 .7338 m .70893 .67986 L .70179 .68899 L p .707 .577 .707 r
F P
0 g
s
.52439 .81098 m .5191 .82811 L .53896 .84257 L p .707 .577 .707 r
F P
0 g
s
.50149 .71111 m .5101 .65717 L .50738 .6464 L p .707 .577 .707 r
F P
0 g
s
.67923 .79566 m .66781 .82954 L .68393 .82369 L p .707 .577 .707 r
F P
0 g
s
.68393 .82369 m .69536 .78981 L .67923 .79566 L p .707 .577 .707 r
F P
0 g
s
.51046 .73035 m .49903 .76424 L .51052 .77897 L p .707 .577 .707 r
F P
0 g
s
.5191 .82811 m .52439 .81098 L .51274 .79675 L p .707 .577 .707 r
F P
0 g
s
.68279 .8581 m .6775 .87522 L .69366 .86926 L p .707 .577 .707 r
F P
0 g
s
.69366 .86926 m .69895 .85213 L .68279 .8581 L p .707 .577 .707 r
F P
0 g
s
.50738 .6464 m .49877 .70034 L .50149 .71111 L p .707 .577 .707 r
F P
0 g
s
.51274 .79675 m .50745 .81388 L .5191 .82811 L p .707 .577 .707 r
F P
0 g
s
.49903 .76424 m .51046 .73035 L .50827 .71742 L p .707 .577 .707 r
F P
0 g
s
.70893 .67986 m .70032 .7338 L .6976 .72303 L p .707 .577 .707 r
F P
0 g
s
.6976 .72303 m .70621 .66909 L .70893 .67986 L p .707 .577 .707 r
F P
0 g
s
.69536 .78981 m .68393 .82369 L .69126 .81381 L p .707 .577 .707 r
F P
0 g
s
.69126 .81381 m .70268 .77993 L .69536 .78981 L p .707 .577 .707 r
F P
0 g
s
.49877 .70034 m .50738 .6464 L .51452 .63727 L p .707 .577 .707 r
F P
0 g
s
.50827 .71742 m .49684 .7513 L .49903 .76424 L p .707 .577 .707 r
F P
0 g
s
.50745 .81388 m .51274 .79675 L .51044 .78413 L p .707 .577 .707 r
F P
0 g
s
.51044 .78413 m .50515 .80126 L .50745 .81388 L p .707 .577 .707 r
F P
0 g
s
.51452 .63727 m .50591 .69121 L .49877 .70034 L p .707 .577 .707 r
F P
0 g
s
.49684 .7513 m .50827 .71742 L .5156 .70754 L p .707 .577 .707 r
F P
0 g
s
.5156 .70754 m .50417 .74142 L .49684 .7513 L p .707 .577 .707 r
F P
0 g
s
.50515 .80126 m .51044 .78413 L .51774 .77436 L p .707 .577 .707 r
F P
0 g
s
.51774 .77436 m .51245 .79149 L .50515 .80126 L p .707 .577 .707 r
F P
0 g
s
.50417 .74142 m .5156 .70754 L .53172 .70168 L p .707 .577 .707 r
F P
0 g
s
.53172 .70168 m .5203 .73556 L .50417 .74142 L p .707 .577 .707 r
F P
0 g
s
.50962 .8207 m .47922 .31654 L .4353 .31657 L p .707 .577 .707 r
F P
0 g
s
.50591 .69121 m .51452 .63727 L .53083 .63067 L p .707 .577 .707 r
F P
0 g
s
.53083 .63067 m .52222 .68461 L .50591 .69121 L p .707 .577 .707 r
F P
0 g
s
.52222 .68461 m .53083 .63067 L .55471 .62725 L p .707 .577 .707 r
F P
0 g
s
.51245 .79149 m .51774 .77436 L .5339 .7684 L p .707 .577 .707 r
F P
0 g
s
.5339 .7684 m .52861 .78552 L .51245 .79149 L p .707 .577 .707 r
F P
0 g
s
.55471 .62725 m .5461 .68118 L .52222 .68461 L p .707 .577 .707 r
F P
0 g
s
.5203 .73556 m .53172 .70168 L .55507 .70043 L p .707 .577 .707 r
F P
0 g
s
.55507 .70043 m .54364 .73431 L .5203 .73556 L p .707 .577 .707 r
F P
0 g
s
.52861 .78552 m .5339 .7684 L .55734 .76682 L p .707 .577 .707 r
F P
0 g
s
.55734 .76682 m .55205 .78395 L .52861 .78552 L p .707 .577 .707 r
F P
0 g
s
.47922 .31654 m .50962 .8207 L .55449 .81716 L p .707 .577 .707 r
F P
0 g
s
.5461 .68118 m .55471 .62725 L .58382 .62734 L p .707 .577 .707 r
F P
0 g
s
.58382 .62734 m .57761 .66625 L p .5461 .68118 L .707 .577 .707 r
F P
0 g
s
.57761 .66625 m .57521 .68127 L .57055 .68126 L p .707 .577 .707 r
F P
0 g
s
.57055 .68126 m .5461 .68118 L p .57761 .66625 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .47922 .31654 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.54364 .73431 m .55507 .70043 L .58335 .7039 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .5804 .71262 L p .54364 .73431 L .707 .577 .707 r
F P
0 g
s
.5804 .71262 m .57192 .73778 L .55887 .73618 L p .707 .577 .707 r
F P
0 g
s
.55887 .73618 m .54364 .73431 L p .5804 .71262 L .707 .577 .707 r
F P
0 g
s
.54465 .75173 m .54905 .72698 L .5429 .74007 L .707 .577 .707 r
F
.55205 .78395 m .55734 .76682 L .58578 .7698 L p F P
0 g
s
.58578 .7698 m .58417 .77503 L p .55205 .78395 L .707 .577 .707 r
F P
0 g
s
.58417 .77503 m .58049 .78692 L .57468 .78632 L p .707 .577 .707 r
F P
0 g
s
.57468 .78632 m .55205 .78395 L p .58417 .77503 L .707 .577 .707 r
F P
0 g
s
.55362 .81137 m .55018 .74568 L .54465 .75173 L .707 .577 .707 r
F
.55449 .81716 m .55411 .81079 L p .55362 .81137 L F P
0 g
s
.55411 .81079 m .55018 .74568 L p .55362 .81137 L .707 .577 .707 r
F P
0 g
s
.55018 .74568 m .54905 .72698 L p .54465 .75173 L .707 .577 .707 r
F P
0 g
s
.54905 .72698 m .52409 .313 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.57521 .68127 m .58382 .62734 L .61531 .63093 L p .707 .577 .707 r
F P
0 g
s
.61531 .63093 m .6067 .68487 L .57521 .68127 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .61379 .71175 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.57192 .73778 m .576 .72569 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.576 .72569 m .58335 .7039 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.6461 .63768 m .63749 .69161 L .6067 .68487 L p .707 .577 .707 r
F P
0 g
s
.6067 .68487 m .61531 .63093 L .6461 .63768 L p .707 .577 .707 r
F P
0 g
s
.64342 .72322 m .632 .7571 L .60237 .74563 L p .707 .577 .707 r
F P
0 g
s
.60237 .74563 m .61379 .71175 L .64342 .72322 L p .707 .577 .707 r
F P
0 g
s
.61379 .71175 m .60237 .74563 L .57192 .73778 L p .707 .577 .707 r
F P
0 g
s
.58049 .78692 m .58578 .7698 L .61643 .77702 L p .707 .577 .707 r
F P
0 g
s
.64629 .78779 m .641 .80492 L .61114 .79415 L p .707 .577 .707 r
F P
0 g
s
.61114 .79415 m .61643 .77702 L .64629 .78779 L p .707 .577 .707 r
F P
0 g
s
.61643 .77702 m .61114 .79415 L .58049 .78692 L p .707 .577 .707 r
F P
0 g
s
.56552 .3063 m .59453 .78752 L p .62983 .80123 L .707 .577 .707 r
F P
0 g
s
.59453 .78752 m .59591 .81046 L .60099 .80907 L p .707 .577 .707 r
F P
0 g
s
.60099 .80907 m .62983 .80123 L p .59453 .78752 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .55449 .81716 L .59591 .81046 L p .707 .577 .707 r
F P
0 g
s
.59591 .81046 m .56552 .3063 L .52409 .313 L p .707 .577 .707 r
F P
0 g
s
.69895 .85213 m .69366 .86926 L .70095 .85949 L p .707 .577 .707 r
F P
0 g
s
.70095 .85949 m .70624 .84236 L .69895 .85213 L p .707 .577 .707 r
F P
0 g
s
.46569 .82073 m .4353 .31657 L .39662 .31307 L p .707 .577 .707 r
F P
0 g
s
.4353 .31657 m .46569 .82073 L .50962 .8207 L p .707 .577 .707 r
F P
0 g
s
.70621 .66909 m .6976 .72303 L .68528 .71168 L p .707 .577 .707 r
F P
0 g
s
.68528 .71168 m .69389 .65774 L .70621 .66909 L p .707 .577 .707 r
F P
0 g
s
.70268 .77993 m .69126 .81381 L .68907 .80087 L p .707 .577 .707 r
F P
0 g
s
.68907 .80087 m .7005 .76699 L .70268 .77993 L p .707 .577 .707 r
F P
0 g
s
.62983 .80123 m .59944 .29708 L .56552 .3063 L p .707 .577 .707 r
F P
0 g
s
.24938 .72116 m .25799 .66722 L .2272 .66047 L p .707 .577 .707 r
F P
0 g
s
.25799 .66722 m .24938 .72116 L .28088 .72475 L p .707 .577 .707 r
F P
0 g
s
.28088 .72475 m .28948 .67081 L .25799 .66722 L p .707 .577 .707 r
F P
0 g
s
.28948 .67081 m .28088 .72475 L .30999 .72484 L p .707 .577 .707 r
F P
0 g
s
.30999 .72484 m .31859 .6709 L .28948 .67081 L p .707 .577 .707 r
F P
0 g
s
.21859 .71441 m .2272 .66047 L .20012 .65124 L p .707 .577 .707 r
F P
0 g
s
.2272 .66047 m .21859 .71441 L .24938 .72116 L p .707 .577 .707 r
F P
0 g
s
.42701 .81723 m .39662 .31307 L .36696 .3064 L p .707 .577 .707 r
F P
0 g
s
.39662 .31307 m .42701 .81723 L .46569 .82073 L p .707 .577 .707 r
F P
0 g
s
.70624 .84236 m .70095 .85949 L .69866 .84687 L p .707 .577 .707 r
F P
0 g
s
.69866 .84687 m .70395 .82974 L .70624 .84236 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31859 .6709 m .30999 .72484 L .33386 .72142 L p .707 .577 .707 r
F P
0 g
s
.33386 .72142 m .34247 .66748 L .31859 .6709 L p .707 .577 .707 r
F P
0 g
s
.69389 .65774 m .68528 .71168 L .66457 .70085 L p .707 .577 .707 r
F P
0 g
s
.66457 .70085 m .67318 .64691 L .69389 .65774 L p .707 .577 .707 r
F P
0 g
s
.19152 .70517 m .20012 .65124 L .17941 .64041 L p .707 .577 .707 r
F P
0 g
s
.20012 .65124 m .19152 .70517 L .21859 .71441 L p .707 .577 .707 r
F P
0 g
s
.7005 .76699 m .68907 .80087 L .67758 .78614 L p .707 .577 .707 r
F P
0 g
s
.67758 .78614 m .68901 .75226 L .7005 .76699 L p .707 .577 .707 r
F P
0 g
s
.67318 .64691 m .66457 .70085 L .63749 .69161 L p .707 .577 .707 r
F P
0 g
s
.63749 .69161 m .6461 .63768 L .67318 .64691 L p .707 .577 .707 r
F P
0 g
s
.66934 .73717 m .65791 .77105 L .632 .7571 L p .707 .577 .707 r
F P
0 g
s
.632 .7571 m .64342 .72322 L .66934 .73717 L p .707 .577 .707 r
F P
0 g
s
.641 .80492 m .64629 .78779 L .67243 .80105 L p .707 .577 .707 r
F P
0 g
s
.59944 .29708 m .62983 .80123 L .65293 .7904 L p .707 .577 .707 r
F P
0 g
s
.65293 .7904 m .62253 .28625 L .59944 .29708 L p .707 .577 .707 r
F P
0 g
s
.24273 .77871 m .25415 .74483 L .22452 .73336 L p .707 .577 .707 r
F P
0 g
s
.25415 .74483 m .24273 .77871 L .27317 .78656 L p .707 .577 .707 r
F P
0 g
s
.27317 .78656 m .2846 .75268 L .25415 .74483 L p .707 .577 .707 r
F P
0 g
s
.2131 .76725 m .22452 .73336 L .1986 .71941 L p .707 .577 .707 r
F P
0 g
s
.22452 .73336 m .2131 .76725 L .24273 .77871 L p .707 .577 .707 r
F P
0 g
s
.2846 .75268 m .27317 .78656 L .30145 .79003 L p .707 .577 .707 r
F P
0 g
s
.30145 .79003 m .31288 .75615 L .2846 .75268 L p .707 .577 .707 r
F P
0 g
s
.70395 .82974 m .69866 .84687 L .68701 .83264 L p .707 .577 .707 r
F P
0 g
s
.68701 .83264 m .6923 .81551 L .70395 .82974 L p .707 .577 .707 r
F P
0 g
s
.25195 .81691 m .25724 .79978 L .22739 .78901 L p .707 .577 .707 r
F P
0 g
s
.25724 .79978 m .25195 .81691 L .2826 .82414 L p .707 .577 .707 r
F P
0 g
s
.2826 .82414 m .28789 .80701 L .25724 .79978 L p .707 .577 .707 r
F P
0 g
s
.17941 .64041 m .1708 .69435 L .19152 .70517 L p .707 .577 .707 r
F P
0 g
s
.34247 .66748 m .33386 .72142 L .35017 .71482 L p .707 .577 .707 r
F P
0 g
s
.35017 .71482 m .35878 .66088 L .34247 .66748 L p .707 .577 .707 r
F P
0 g
s
.39736 .81056 m .36696 .3064 L .34924 .29721 L p .707 .577 .707 r
F P
0 g
s
.36696 .3064 m .39736 .81056 L .42701 .81723 L p .707 .577 .707 r
F P
0 g
s
.18718 .75329 m .1986 .71941 L .17894 .70432 L p .707 .577 .707 r
F P
0 g
s
.1986 .71941 m .18718 .75329 L .2131 .76725 L p .707 .577 .707 r
F P
0 g
s
.2221 .80614 m .22739 .78901 L .20125 .77575 L p .707 .577 .707 r
F P
0 g
s
.22739 .78901 m .2221 .80614 L .25195 .81691 L p .707 .577 .707 r
F P
0 g
s
.1708 .69435 m .17941 .64041 L .16709 .62906 L p .707 .577 .707 r
F P
0 g
s
.28789 .80701 m .2826 .82414 L .31104 .82711 L p .707 .577 .707 r
F P
0 g
s
.31104 .82711 m .31633 .80998 L .28789 .80701 L p .707 .577 .707 r
F P
0 g
s
.31288 .75615 m .30145 .79003 L .3248 .78878 L p .707 .577 .707 r
F P
0 g
s
.3248 .78878 m .33622 .7549 L .31288 .75615 L p .707 .577 .707 r
F P
0 g
s
.68901 .75226 m .67758 .78614 L .65791 .77105 L p .707 .577 .707 r
F P
0 g
s
.65791 .77105 m .66934 .73717 L .68901 .75226 L p .707 .577 .707 r
F P
0 g
s
.20125 .77575 m .19595 .79288 L .2221 .80614 L p .707 .577 .707 r
F P
0 g
s
.17894 .70432 m .16751 .73821 L .18718 .75329 L p .707 .577 .707 r
F P
0 g
s
.19595 .79288 m .20125 .77575 L .18138 .76129 L p .707 .577 .707 r
F P
0 g
s
.31633 .80998 m .31104 .82711 L .33449 .82554 L p .707 .577 .707 r
F P
0 g
s
.33449 .82554 m .33978 .80841 L .31633 .80998 L p .707 .577 .707 r
F P
0 g
s
.62253 .28625 m .65293 .7904 L .66294 .77903 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .63255 .27487 L .62253 .28625 L p .707 .577 .707 r
F P
0 g
s
.16709 .62906 m .15848 .68299 L .1708 .69435 L p .707 .577 .707 r
F P
0 g
s
.16751 .73821 m .17894 .70432 L .16745 .68959 L p .707 .577 .707 r
F P
0 g
s
.18138 .76129 m .17609 .77842 L .19595 .79288 L p .707 .577 .707 r
F P
0 g
s
.6923 .81551 m .68701 .83264 L .66714 .81818 L p .707 .577 .707 r
F P
0 g
s
.66714 .81818 m .67243 .80105 L .6923 .81551 L p .707 .577 .707 r
F P
0 g
s
.35878 .66088 m .35017 .71482 L .35732 .70569 L p .707 .577 .707 r
F P
0 g
s
.35732 .70569 m .36592 .65175 L .35878 .66088 L p .707 .577 .707 r
F P
0 g
s
.33622 .7549 m .3248 .78878 L .34092 .78293 L p .707 .577 .707 r
F P
0 g
s
.34092 .78293 m .35235 .74904 L .33622 .7549 L p .707 .577 .707 r
F P
0 g
s
.15848 .68299 m .16709 .62906 L .16437 .61829 L p .707 .577 .707 r
F P
0 g
s
.16745 .68959 m .15602 .72347 L .16751 .73821 L p .707 .577 .707 r
F P
0 g
s
.17609 .77842 m .18138 .76129 L .16973 .74706 L p .707 .577 .707 r
F P
0 g
s
.33978 .80841 m .33449 .82554 L .35065 .81957 L p .707 .577 .707 r
F P
0 g
s
.35065 .81957 m .35594 .80244 L .33978 .80841 L p .707 .577 .707 r
F P
0 g
s
.37964 .80137 m .34924 .29721 L .34519 .2864 L p .707 .577 .707 r
F P
0 g
s
.34924 .29721 m .37964 .80137 L .39736 .81056 L p .707 .577 .707 r
F P
0 g
s
.16973 .74706 m .16444 .76419 L .17609 .77842 L p .707 .577 .707 r
F P
0 g
s
.67243 .80105 m .66714 .81818 L .641 .80492 L p .707 .577 .707 r
F P
0 g
s
.15602 .72347 m .16745 .68959 L .16526 .67665 L p .707 .577 .707 r
F P
0 g
s
.16437 .61829 m .15576 .67223 L .15848 .68299 L p .707 .577 .707 r
F P
0 g
s
.35235 .74904 m .34092 .78293 L .34825 .77305 L p .707 .577 .707 r
F P
0 g
s
.34825 .77305 m .35967 .73916 L .35235 .74904 L p .707 .577 .707 r
F P
0 g
s
.36592 .65175 m .35732 .70569 L .35459 .69492 L p .707 .577 .707 r
F P
0 g
s
.35459 .69492 m .3632 .64098 L .36592 .65175 L p .707 .577 .707 r
F P
0 g
s
.15576 .67223 m .16437 .61829 L .17151 .60916 L p .707 .577 .707 r
F P
0 g
s
.16526 .67665 m .15383 .71053 L .15602 .72347 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .6595 .76983 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.63255 .27487 m .66227 .7679 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.66227 .7679 m .66294 .77903 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.62849 .26405 m .65889 .76821 L .64117 .75902 L p .707 .577 .707 r
F P
0 g
s
.64773 .68693 m .6518 .67484 L p .64766 .63832 L .707 .577 .707 r
F P
0 g
s
.65797 .75099 m .63255 .27487 L .6595 .76983 L .707 .577 .707 r
F
.62849 .26405 m .63255 .27487 L p .65503 .69598 L F P
0 g
s
.65889 .76821 m .65366 .6815 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.65366 .6815 m .62849 .26405 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.6473 .56513 m .64438 .58345 L p .65102 .63042 L .707 .577 .707 r
F P
0 g
s
.64438 .58345 m .6387 .61907 L .64862 .62821 L p .707 .577 .707 r
F P
0 g
s
.64862 .62821 m .65102 .63042 L p .64438 .58345 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .65915 .65305 L .6477 .63836 L p .707 .577 .707 r
F P
0 g
s
.6477 .63836 m .64766 .63832 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.65915 .65305 m .6518 .67484 L p .66739 .70201 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .64773 .68693 L .65312 .69106 L p .707 .577 .707 r
F P
0 g
s
.65312 .69106 m .66739 .70201 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.6595 .76983 m .65889 .76821 L p .65797 .75099 L .707 .577 .707 r
F P
0 g
s
.16444 .76419 m .16973 .74706 L .16744 .73444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35594 .80244 m .35065 .81957 L .35794 .8098 L p .707 .577 .707 r
F P
0 g
s
.35794 .8098 m .36323 .79268 L .35594 .80244 L p .707 .577 .707 r
F P
0 g
s
.16744 .73444 m .16214 .75157 L .16444 .76419 L p .707 .577 .707 r
F P
0 g
s
.15383 .71053 m .16526 .67665 L .17259 .66677 L p .707 .577 .707 r
F P
0 g
s
.17151 .60916 m .16291 .66309 L .15576 .67223 L p .707 .577 .707 r
F P
0 g
s
.35967 .73916 m .34825 .77305 L .34606 .76011 L p .707 .577 .707 r
F P
0 g
s
.34606 .76011 m .35749 .72623 L .35967 .73916 L p .707 .577 .707 r
F P
0 g
s
.34519 .2864 m .37559 .79056 L .37964 .80137 L p .707 .577 .707 r
F P
0 g
s
.37559 .79056 m .34519 .2864 L .35521 .27502 L p .707 .577 .707 r
F P
0 g
s
.3632 .64098 m .35459 .69492 L .34227 .68356 L p .707 .577 .707 r
F P
0 g
s
.34227 .68356 m .35088 .62963 L .3632 .64098 L p .707 .577 .707 r
F P
0 g
s
.16291 .66309 m .17151 .60916 L .18782 .60256 L p .707 .577 .707 r
F P
0 g
s
.17259 .66677 m .16116 .70066 L .15383 .71053 L p .707 .577 .707 r
F P
0 g
s
.16214 .75157 m .16744 .73444 L .17473 .72467 L p .707 .577 .707 r
F P
0 g
s
.36323 .79268 m .35794 .8098 L .35565 .79718 L p .707 .577 .707 r
F P
0 g
s
.35565 .79718 m .36094 .78006 L .36323 .79268 L p .707 .577 .707 r
F P
0 g
s
.17473 .72467 m .16944 .7418 L .16214 .75157 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64117 .75902 m .61078 .25486 L .62849 .26405 L p .707 .577 .707 r
F P
0 g
s
.16116 .70066 m .17259 .66677 L .18871 .66092 L p .707 .577 .707 r
F P
0 g
s
.18782 .60256 m .17921 .65649 L .16291 .66309 L p .707 .577 .707 r
F P
0 g
s
.35749 .72623 m .34606 .76011 L .33457 .74538 L p .707 .577 .707 r
F P
0 g
s
.33457 .74538 m .346 .71149 L .35749 .72623 L p .707 .577 .707 r
F P
0 g
s
.35088 .62963 m .34227 .68356 L .32156 .67274 L p .707 .577 .707 r
F P
0 g
s
.32156 .67274 m .33017 .6188 L .35088 .62963 L p .707 .577 .707 r
F P
0 g
s
.17921 .65649 m .18782 .60256 L .2117 .59913 L p .707 .577 .707 r
F P
0 g
s
.18871 .66092 m .17729 .6948 L .16116 .70066 L p .707 .577 .707 r
F P
0 g
s
.16944 .7418 m .17473 .72467 L .19089 .71871 L p .707 .577 .707 r
F P
0 g
s
.36094 .78006 m .35565 .79718 L .344 .78295 L p .707 .577 .707 r
F P
0 g
s
.344 .78295 m .34929 .76582 L .36094 .78006 L p .707 .577 .707 r
F P
0 g
s
.3856 .77918 m .35521 .27502 L .3783 .26419 L p .707 .577 .707 r
F P
0 g
s
.35521 .27502 m .3856 .77918 L .37559 .79056 L p .707 .577 .707 r
F P
0 g
s
.19089 .71871 m .1856 .73584 L .16944 .7418 L p .707 .577 .707 r
F P
0 g
s
.17729 .6948 m .18871 .66092 L .21206 .65967 L p .707 .577 .707 r
F P
0 g
s
.2117 .59913 m .20309 .65307 L .17921 .65649 L p .707 .577 .707 r
F P
0 g
s
.33017 .6188 m .32156 .67274 L .29449 .6635 L p .707 .577 .707 r
F P
0 g
s
.29449 .6635 m .30309 .60956 L .33017 .6188 L p .707 .577 .707 r
F P
0 g
s
.20309 .65307 m .2117 .59913 L .24081 .59922 L p .707 .577 .707 r
F P
0 g
s
.346 .71149 m .33457 .74538 L .31491 .73029 L p .707 .577 .707 r
F P
0 g
s
.31491 .73029 m .32633 .69641 L .346 .71149 L p .707 .577 .707 r
F P
0 g
s
.61078 .25486 m .64117 .75902 L .61152 .75235 L p .707 .577 .707 r
F P
0 g
s
.61152 .75235 m .58112 .24819 L .61078 .25486 L p .707 .577 .707 r
F P
0 g
s
.21206 .65967 m .20063 .69355 L .17729 .6948 L p .707 .577 .707 r
F P
0 g
s
.1856 .73584 m .19089 .71871 L .21433 .71714 L p .707 .577 .707 r
F P
0 g
s
.30309 .60956 m .29449 .6635 L .26369 .65675 L p .707 .577 .707 r
F P
0 g
s
.26369 .65675 m .2723 .60282 L .30309 .60956 L p .707 .577 .707 r
F P
0 g
s
.2322 .65316 m .24081 .59922 L .2723 .60282 L p .707 .577 .707 r
F P
0 g
s
.24081 .59922 m .2322 .65316 L .20309 .65307 L p .707 .577 .707 r
F P
0 g
s
.34929 .76582 m .344 .78295 L .32413 .76849 L p .707 .577 .707 r
F P
0 g
s
.32413 .76849 m .32942 .75137 L .34929 .76582 L p .707 .577 .707 r
F P
0 g
s
.20063 .69355 m .21206 .65967 L .24034 .66314 L p .707 .577 .707 r
F P
0 g
s
.21433 .71714 m .20904 .73426 L .1856 .73584 L p .707 .577 .707 r
F P
0 g
s
.2723 .60282 m .26369 .65675 L .2322 .65316 L p .707 .577 .707 r
F P
0 g
s
.7296 .65723 m .7382 .60329 L .70741 .59655 L p .707 .577 .707 r
F P
0 g
s
.7382 .60329 m .7296 .65723 L .76109 .66082 L p .707 .577 .707 r
F P
0 g
s
.76109 .66082 m .7697 .60689 L .7382 .60329 L p .707 .577 .707 r
F P
0 g
s
.32633 .69641 m .31491 .73029 L .28899 .71634 L p .707 .577 .707 r
F P
0 g
s
.28899 .71634 m .30041 .68245 L .32633 .69641 L p .707 .577 .707 r
F P
0 g
s
.7697 .60689 m .76109 .66082 L .7902 .66091 L p .707 .577 .707 r
F P
0 g
s
.7902 .66091 m .79881 .60698 L .7697 .60689 L p .707 .577 .707 r
F P
0 g
s
.69881 .65048 m .70741 .59655 L .68033 .58731 L p .707 .577 .707 r
F P
0 g
s
.70741 .59655 m .69881 .65048 L .7296 .65723 L p .707 .577 .707 r
F P
0 g
s
.3783 .26419 m .4087 .76835 L .3856 .77918 L p .707 .577 .707 r
F P
0 g
s
.4087 .76835 m .3783 .26419 L .41222 .25496 L p .707 .577 .707 r
F P
0 g
s
.24034 .66314 m .22891 .69702 L .20063 .69355 L p .707 .577 .707 r
F P
0 g
s
.22891 .69702 m .24034 .66314 L .27078 .67099 L p .707 .577 .707 r
F P
0 g
s
.20904 .73426 m .21433 .71714 L .24277 .72011 L p .707 .577 .707 r
F P
0 g
s
.30041 .68245 m .28899 .71634 L .25936 .70487 L p .707 .577 .707 r
F P
0 g
s
.25936 .70487 m .27078 .67099 L .30041 .68245 L p .707 .577 .707 r
F P
0 g
s
.32942 .75137 m .32413 .76849 L .29799 .75523 L p .707 .577 .707 r
F P
0 g
s
.29799 .75523 m .30328 .7381 L .32942 .75137 L p .707 .577 .707 r
F P
0 g
s
.27078 .67099 m .25936 .70487 L .22891 .69702 L p .707 .577 .707 r
F P
0 g
s
.79881 .60698 m .7902 .66091 L .81408 .65749 L p .707 .577 .707 r
F P
0 g
s
.81408 .65749 m .82268 .60356 L .79881 .60698 L p .707 .577 .707 r
F P
0 g
s
.24277 .72011 m .23748 .73724 L .20904 .73426 L p .707 .577 .707 r
F P
0 g
s
.67173 .64125 m .68033 .58731 L .65962 .57649 L p .707 .577 .707 r
F P
0 g
s
.68033 .58731 m .67173 .64125 L .69881 .65048 L p .707 .577 .707 r
F P
0 g
s
.58112 .24819 m .61152 .75235 L .57284 .74885 L p .707 .577 .707 r
F P
0 g
s
.57284 .74885 m .54244 .24469 L .58112 .24819 L p .707 .577 .707 r
F P
0 g
s
.23748 .73724 m .24277 .72011 L .27342 .72733 L p .707 .577 .707 r
F P
0 g
s
.72294 .72743 m .73437 .69355 L .70473 .68209 L p .707 .577 .707 r
F P
0 g
s
.73437 .69355 m .72294 .72743 L .75339 .73529 L p .707 .577 .707 r
F P
0 g
s
.75339 .73529 m .76481 .70141 L .73437 .69355 L p .707 .577 .707 r
F P
0 g
s
.30328 .7381 m .29799 .75523 L .26813 .74446 L p .707 .577 .707 r
F P
0 g
s
.26813 .74446 m .27342 .72733 L .30328 .7381 L p .707 .577 .707 r
F P
0 g
s
.69331 .71597 m .70473 .68209 L .67882 .66813 L p .707 .577 .707 r
F P
0 g
s
.70473 .68209 m .69331 .71597 L .72294 .72743 L p .707 .577 .707 r
F P
0 g
s
.27342 .72733 m .26813 .74446 L .23748 .73724 L p .707 .577 .707 r
F P
0 g
s
.76481 .70141 m .75339 .73529 L .78167 .73876 L p .707 .577 .707 r
F P
0 g
s
.78167 .73876 m .79309 .70487 L .76481 .70141 L p .707 .577 .707 r
F P
0 g
s
.44262 .75912 m .41222 .25496 L .45364 .24826 L p .707 .577 .707 r
F P
0 g
s
.41222 .25496 m .44262 .75912 L .4087 .76835 L p .707 .577 .707 r
F P
0 g
s
.65962 .57649 m .65102 .63042 L .67173 .64125 L p .707 .577 .707 r
F P
0 g
s
.82268 .60356 m .81408 .65749 L .83039 .65089 L p .707 .577 .707 r
F P
0 g
s
.83039 .65089 m .83899 .59696 L .82268 .60356 L p .707 .577 .707 r
F P
0 g
s
.65102 .63042 m .65962 .57649 L .6473 .56513 L p .707 .577 .707 r
F P
0 g
s
.66739 .70201 m .67882 .66813 L .65915 .65305 L p .707 .577 .707 r
F P
0 g
s
.67882 .66813 m .66739 .70201 L .69331 .71597 L p .707 .577 .707 r
F P
0 g
s
.73217 .77456 m .73746 .75743 L .7076 .74666 L p .707 .577 .707 r
F P
0 g
s
.73746 .75743 m .73217 .77456 L .76281 .78179 L p .707 .577 .707 r
F P
0 g
s
.76281 .78179 m .7681 .76466 L .73746 .75743 L p .707 .577 .707 r
F P
0 g
s
.54244 .24469 m .57284 .74885 L .52891 .74888 L p .707 .577 .707 r
F P
0 g
s
.52891 .74888 m .49851 .24472 L .54244 .24469 L p .707 .577 .707 r
F P
0 g
s
.79309 .70487 m .78167 .73876 L .80501 .7375 L p .707 .577 .707 r
F P
0 g
s
.80501 .7375 m .81644 .70362 L .79309 .70487 L p .707 .577 .707 r
F P
0 g
s
.70231 .76379 m .7076 .74666 L .68146 .7334 L p .707 .577 .707 r
F P
0 g
s
.7076 .74666 m .70231 .76379 L .73217 .77456 L p .707 .577 .707 r
F P
0 g
s
.7681 .76466 m .76281 .78179 L .79125 .78476 L p .707 .577 .707 r
F P
0 g
s
.79125 .78476 m .79654 .76763 L .7681 .76466 L p .707 .577 .707 r
F P
0 g
s
.48404 .75242 m .45364 .24826 L .49851 .24472 L p .707 .577 .707 r
F P
0 g
s
.45364 .24826 m .48404 .75242 L .44262 .75912 L p .707 .577 .707 r
F P
0 g
s
.68146 .7334 m .67617 .75053 L .70231 .76379 L p .707 .577 .707 r
F P
0 g
s
.49851 .24472 m .52891 .74888 L .48404 .75242 L p .707 .577 .707 r
F P
0 g
s
.67617 .75053 m .68146 .7334 L .66159 .71894 L p .707 .577 .707 r
F P
0 g
s
.79654 .76763 m .79125 .78476 L .8147 .78319 L p .707 .577 .707 r
F P
0 g
s
.8147 .78319 m .81999 .76606 L .79654 .76763 L p .707 .577 .707 r
F P
0 g
s
.83899 .59696 m .83039 .65089 L .83753 .64176 L p .707 .577 .707 r
F P
0 g
s
.83753 .64176 m .84614 .58782 L .83899 .59696 L p .707 .577 .707 r
F P
0 g
s
.66159 .71894 m .6563 .73607 L .67617 .75053 L p .707 .577 .707 r
F P
0 g
s
.6387 .61907 m .6473 .56513 L .64458 .55436 L p .707 .577 .707 r
F P
0 g
s
.81644 .70362 m .80501 .7375 L .82114 .73165 L p .707 .577 .707 r
F P
0 g
s
.82114 .73165 m .83256 .69777 L .81644 .70362 L p .707 .577 .707 r
F P
0 g
s
.64766 .63832 m .63624 .6722 L .64773 .68693 L p .707 .577 .707 r
F P
0 g
s
.6563 .73607 m .66159 .71894 L .64994 .70471 L p .707 .577 .707 r
F P
0 g
s
.81999 .76606 m .8147 .78319 L .83086 .77722 L p .707 .577 .707 r
F P
0 g
s
.83086 .77722 m .83615 .76009 L .81999 .76606 L p .707 .577 .707 r
F P
0 g
s
.64458 .55436 m .63598 .6083 L .6387 .61907 L p .707 .577 .707 r
F P
0 g
s
.64994 .70471 m .64465 .72184 L .6563 .73607 L p .707 .577 .707 r
F P
0 g
s
.63624 .6722 m .64766 .63832 L .64547 .62538 L p .707 .577 .707 r
F P
0 g
s
.84614 .58782 m .83753 .64176 L .83481 .63099 L p .707 .577 .707 r
F P
0 g
s
.83481 .63099 m .84341 .57705 L .84614 .58782 L p .707 .577 .707 r
F P
0 g
s
.83256 .69777 m .82114 .73165 L .82846 .72177 L p .707 .577 .707 r
F P
0 g
s
.82846 .72177 m .83989 .68789 L .83256 .69777 L p .707 .577 .707 r
F P
0 g
s
.63598 .6083 m .64458 .55436 L .65172 .54523 L p .707 .577 .707 r
F P
0 g
s
.64547 .62538 m .63405 .65926 L .63624 .6722 L p .707 .577 .707 r
F P
0 g
s
.64465 .72184 m .64994 .70471 L .64765 .69209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83615 .76009 m .83086 .77722 L .83815 .76745 L p .707 .577 .707 r
F P
0 g
s
.83815 .76745 m .84345 .75033 L .83615 .76009 L p .707 .577 .707 r
F P
0 g
s
.64765 .69209 m .64236 .70922 L .64465 .72184 L p .707 .577 .707 r
F P
0 g
s
.65172 .54523 m .64312 .59917 L .63598 .6083 L p .707 .577 .707 r
F P
0 g
s
.63405 .65926 m .64547 .62538 L .6528 .6155 L p .707 .577 .707 r
F P
0 g
s
.84341 .57705 m .83481 .63099 L .82249 .61964 L p .707 .577 .707 r
F P
0 g
s
.82249 .61964 m .83109 .5657 L .84341 .57705 L p .707 .577 .707 r
F P
0 g
s
.83989 .68789 m .82846 .72177 L .82627 .70883 L p .707 .577 .707 r
F P
0 g
s
.82627 .70883 m .8377 .67495 L .83989 .68789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64312 .59917 m .65172 .54523 L .66803 .53863 L p .707 .577 .707 r
F P
0 g
s
.6528 .6155 m .64137 .64938 L .63405 .65926 L p .707 .577 .707 r
F P
0 g
s
.38659 .62912 m .39519 .57518 L .3644 .56844 L p .707 .577 .707 r
F P
0 g
s
.39519 .57518 m .38659 .62912 L .41808 .63271 L p .707 .577 .707 r
F P
0 g
s
.41808 .63271 m .42669 .57878 L .39519 .57518 L p .707 .577 .707 r
F P
0 g
s
.64236 .70922 m .64765 .69209 L .65494 .68232 L p .707 .577 .707 r
F P
0 g
s
.42669 .57878 m .41808 .63271 L .44719 .6328 L p .707 .577 .707 r
F P
0 g
s
.44719 .6328 m .4558 .57887 L .42669 .57878 L p .707 .577 .707 r
F P
0 g
s
.3558 .62237 m .3644 .56844 L .33732 .5592 L p .707 .577 .707 r
F P
0 g
s
.3644 .56844 m .3558 .62237 L .38659 .62912 L p .707 .577 .707 r
F P
0 g
s
.84345 .75033 m .83815 .76745 L .83586 .75483 L p .707 .577 .707 r
F P
0 g
s
.83586 .75483 m .84115 .73771 L .84345 .75033 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65494 .68232 m .64965 .69945 L .64236 .70922 L p .707 .577 .707 r
F P
0 g
s
.66803 .53863 m .65943 .59257 L .64312 .59917 L p .707 .577 .707 r
F P
0 g
s
.64137 .64938 m .6528 .6155 L .66893 .60964 L p .707 .577 .707 r
F P
0 g
s
.4558 .57887 m .44719 .6328 L .47107 .62938 L p .707 .577 .707 r
F P
0 g
s
.47107 .62938 m .47967 .57544 L .4558 .57887 L p .707 .577 .707 r
F P
0 g
s
.83109 .5657 m .82249 .61964 L .80178 .60881 L p .707 .577 .707 r
F P
0 g
s
.80178 .60881 m .81038 .55488 L .83109 .5657 L p .707 .577 .707 r
F P
0 g
s
.32872 .61313 m .33732 .5592 L .31661 .54837 L p .707 .577 .707 r
F P
0 g
s
.33732 .5592 m .32872 .61313 L .3558 .62237 L p .707 .577 .707 r
F P
0 g
s
.8377 .67495 m .82627 .70883 L .81479 .6941 L p .707 .577 .707 r
F P
0 g
s
.81479 .6941 m .82621 .66022 L .8377 .67495 L p .707 .577 .707 r
F P
0 g
s
.65943 .59257 m .66803 .53863 L .69191 .53521 L p .707 .577 .707 r
F P
0 g
s
.37993 .68667 m .39136 .65279 L .36172 .64133 L p .707 .577 .707 r
F P
0 g
s
.39136 .65279 m .37993 .68667 L .41038 .69452 L p .707 .577 .707 r
F P
0 g
s
.41038 .69452 m .4218 .66064 L .39136 .65279 L p .707 .577 .707 r
F P
0 g
s
.3503 .67521 m .36172 .64133 L .33581 .62737 L p .707 .577 .707 r
F P
0 g
s
.36172 .64133 m .3503 .67521 L .37993 .68667 L p .707 .577 .707 r
F P
0 g
s
.66893 .60964 m .6575 .64353 L .64137 .64938 L p .707 .577 .707 r
F P
0 g
s
.4218 .66064 m .41038 .69452 L .43866 .69799 L p .707 .577 .707 r
F P
0 g
s
.43866 .69799 m .45008 .66411 L .4218 .66064 L p .707 .577 .707 r
F P
0 g
s
.64965 .69945 m .65494 .68232 L .6711 .67636 L p .707 .577 .707 r
F P
0 g
s
.84115 .73771 m .83586 .75483 L .82421 .7406 L p .707 .577 .707 r
F P
0 g
s
.82421 .7406 m .8295 .72347 L .84115 .73771 L p .707 .577 .707 r
F P
0 g
s
.38916 .72487 m .39445 .70775 L .36459 .69697 L p .707 .577 .707 r
F P
0 g
s
.39445 .70775 m .38916 .72487 L .4198 .7321 L p .707 .577 .707 r
F P
0 g
s
.4198 .7321 m .42509 .71497 L .39445 .70775 L p .707 .577 .707 r
F P
0 g
s
.6711 .67636 m .66581 .69349 L .64965 .69945 L p .707 .577 .707 r
F P
0 g
s
.31661 .54837 m .30801 .60231 L .32872 .61313 L p .707 .577 .707 r
F P
0 g
s
.47967 .57544 m .47107 .62938 L .48738 .62278 L p .707 .577 .707 r
F P
0 g
s
.48738 .62278 m .49598 .56884 L .47967 .57544 L p .707 .577 .707 r
F P
0 g
s
.69191 .53521 m .68331 .58914 L .65943 .59257 L p .707 .577 .707 r
F P
0 g
s
.32438 .66125 m .33581 .62737 L .31614 .61229 L p .707 .577 .707 r
F P
0 g
s
.33581 .62737 m .32438 .66125 L .3503 .67521 L p .707 .577 .707 r
F P
0 g
s
.81038 .55488 m .80178 .60881 L .7747 .59957 L p .707 .577 .707 r
F P
0 g
s
.7747 .59957 m .78331 .54564 L .81038 .55488 L p .707 .577 .707 r
F P
0 g
s
.6575 .64353 m .66893 .60964 L .69227 .60839 L p .707 .577 .707 r
F P
0 g
s
.3593 .7141 m .36459 .69697 L .33845 .68371 L p .707 .577 .707 r
F P
0 g
s
.36459 .69697 m .3593 .7141 L .38916 .72487 L p .707 .577 .707 r
F P
0 g
s
.30801 .60231 m .31661 .54837 L .30429 .53702 L p .707 .577 .707 r
F P
0 g
s
.68331 .58914 m .69191 .53521 L .72102 .5353 L p .707 .577 .707 r
F P
0 g
s
.42509 .71497 m .4198 .7321 L .44824 .73507 L p .707 .577 .707 r
F P
0 g
s
.44824 .73507 m .45353 .71794 L .42509 .71497 L p .707 .577 .707 r
F P
0 g
s
.45008 .66411 m .43866 .69799 L .462 .69674 L p .707 .577 .707 r
F P
0 g
s
.462 .69674 m .47343 .66286 L .45008 .66411 L p .707 .577 .707 r
F P
0 g
s
.82621 .66022 m .81479 .6941 L .79512 .67902 L p .707 .577 .707 r
F P
0 g
s
.79512 .67902 m .80654 .64514 L .82621 .66022 L p .707 .577 .707 r
F P
0 g
s
.33845 .68371 m .33316 .70084 L .3593 .7141 L p .707 .577 .707 r
F P
0 g
s
.31614 .61229 m .30472 .64617 L .32438 .66125 L p .707 .577 .707 r
F P
0 g
s
.78331 .54564 m .7747 .59957 L .74391 .59283 L p .707 .577 .707 r
F P
0 g
s
.74391 .59283 m .75251 .53889 L .78331 .54564 L p .707 .577 .707 r
F P
0 g
s
.33316 .70084 m .33845 .68371 L .31858 .66926 L p .707 .577 .707 r
F P
0 g
s
.69227 .60839 m .68084 .64227 L .6575 .64353 L p .707 .577 .707 r
F P
0 g
s
.71242 .58923 m .72102 .5353 L .75251 .53889 L p .707 .577 .707 r
F P
0 g
s
.72102 .5353 m .71242 .58923 L .68331 .58914 L p .707 .577 .707 r
F P
0 g
s
.45353 .71794 m .44824 .73507 L .47169 .7335 L p .707 .577 .707 r
F P
0 g
s
.47169 .7335 m .47698 .71637 L .45353 .71794 L p .707 .577 .707 r
F P
0 g
s
.66581 .69349 m .6711 .67636 L .69455 .67479 L p .707 .577 .707 r
F P
0 g
s
.75251 .53889 m .74391 .59283 L .71242 .58923 L p .707 .577 .707 r
F P
0 g
s
.30429 .53702 m .29569 .59096 L .30801 .60231 L p .707 .577 .707 r
F P
0 g
s
.30472 .64617 m .31614 .61229 L .30465 .59755 L p .707 .577 .707 r
F P
0 g
s
.31858 .66926 m .31329 .68638 L .33316 .70084 L p .707 .577 .707 r
F P
0 g
s
.68084 .64227 m .69227 .60839 L .72055 .61186 L p .707 .577 .707 r
F P
0 g
s
.8295 .72347 m .82421 .7406 L .80434 .72614 L p .707 .577 .707 r
F P
0 g
s
.80434 .72614 m .80964 .70902 L .8295 .72347 L p .707 .577 .707 r
F P
0 g
s
.69455 .67479 m .68926 .69191 L .66581 .69349 L p .707 .577 .707 r
F P
0 g
s
.49598 .56884 m .48738 .62278 L .49452 .61365 L p .707 .577 .707 r
F P
0 g
s
.49452 .61365 m .50313 .55971 L .49598 .56884 L p .707 .577 .707 r
F P
0 g
s
.47343 .66286 m .462 .69674 L .47813 .69089 L p .707 .577 .707 r
F P
0 g
s
.47813 .69089 m .48955 .65701 L .47343 .66286 L p .707 .577 .707 r
F P
0 g
s
.80654 .64514 m .79512 .67902 L .7692 .66506 L p .707 .577 .707 r
F P
0 g
s
.7692 .66506 m .78063 .63118 L .80654 .64514 L p .707 .577 .707 r
F P
0 g
s
.29569 .59096 m .30429 .53702 L .30157 .52625 L p .707 .577 .707 r
F P
0 g
s
.30465 .59755 m .29323 .63143 L .30472 .64617 L p .707 .577 .707 r
F P
0 g
s
.31329 .68638 m .31858 .66926 L .30693 .65502 L p .707 .577 .707 r
F P
0 g
s
.72055 .61186 m .70912 .64574 L .68084 .64227 L p .707 .577 .707 r
F P
0 g
s
.70912 .64574 m .72055 .61186 L .751 .61971 L p .707 .577 .707 r
F P
0 g
s
.78063 .63118 m .7692 .66506 L .73957 .65359 L p .707 .577 .707 r
F P
0 g
s
.73957 .65359 m .751 .61971 L .78063 .63118 L p .707 .577 .707 r
F P
0 g
s
.47698 .71637 m .47169 .7335 L .48785 .72753 L p .707 .577 .707 r
F P
0 g
s
.48785 .72753 m .49314 .71041 L .47698 .71637 L p .707 .577 .707 r
F P
0 g
s
.68926 .69191 m .69455 .67479 L .72299 .67776 L p .707 .577 .707 r
F P
0 g
s
.30693 .65502 m .30164 .67215 L .31329 .68638 L p .707 .577 .707 r
F P
0 g
s
.751 .61971 m .73957 .65359 L .70912 .64574 L p .707 .577 .707 r
F P
0 g
s
.80964 .70902 m .80434 .72614 L .7782 .71288 L p .707 .577 .707 r
F P
0 g
s
.7782 .71288 m .78349 .69575 L .80964 .70902 L p .707 .577 .707 r
F P
0 g
s
.29323 .63143 m .30465 .59755 L .30246 .58461 L p .707 .577 .707 r
F P
0 g
s
.72299 .67776 m .7177 .69489 L .68926 .69191 L p .707 .577 .707 r
F P
0 g
s
.30157 .52625 m .29296 .58019 L .29569 .59096 L p .707 .577 .707 r
F P
0 g
s
.48955 .65701 m .47813 .69089 L .48545 .68101 L p .707 .577 .707 r
F P
0 g
s
.48545 .68101 m .49688 .64713 L .48955 .65701 L p .707 .577 .707 r
F P
0 g
s
.7177 .69489 m .72299 .67776 L .75364 .68498 L p .707 .577 .707 r
F P
0 g
s
.50313 .55971 m .49452 .61365 L .4918 .60288 L p .707 .577 .707 r
F P
0 g
s
.4918 .60288 m .5004 .54894 L .50313 .55971 L p .707 .577 .707 r
F P
0 g
s
.78349 .69575 m .7782 .71288 L .74835 .70211 L p .707 .577 .707 r
F P
0 g
s
.74835 .70211 m .75364 .68498 L .78349 .69575 L p .707 .577 .707 r
F P
0 g
s
.29296 .58019 m .30157 .52625 L .30871 .51712 L p .707 .577 .707 r
F P
0 g
s
.75364 .68498 m .74835 .70211 L .7177 .69489 L p .707 .577 .707 r
F P
0 g
s
.30246 .58461 m .29104 .6185 L .29323 .63143 L p .707 .577 .707 r
F P
0 g
s
.30164 .67215 m .30693 .65502 L .30464 .6424 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49314 .71041 m .48785 .72753 L .49514 .71776 L p .707 .577 .707 r
F P
0 g
s
.49514 .71776 m .50043 .70064 L .49314 .71041 L p .707 .577 .707 r
F P
0 g
s
.30464 .6424 m .29935 .65953 L .30164 .67215 L p .707 .577 .707 r
F P
0 g
s
.29104 .6185 m .30246 .58461 L .30979 .57474 L p .707 .577 .707 r
F P
0 g
s
.30871 .51712 m .30011 .57105 L .29296 .58019 L p .707 .577 .707 r
F P
0 g
s
.49688 .64713 m .48545 .68101 L .48326 .66807 L p .707 .577 .707 r
F P
0 g
s
.48326 .66807 m .49469 .63419 L .49688 .64713 L p .707 .577 .707 r
F P
0 g
s
.5004 .54894 m .4918 .60288 L .47948 .59152 L p .707 .577 .707 r
F P
0 g
s
.47948 .59152 m .48808 .53759 L .5004 .54894 L p .707 .577 .707 r
F P
0 g
s
.30011 .57105 m .30871 .51712 L .32502 .51052 L p .707 .577 .707 r
F P
0 g
s
.30979 .57474 m .29836 .60862 L .29104 .6185 L p .707 .577 .707 r
F P
0 g
s
.29935 .65953 m .30464 .6424 L .31193 .63263 L p .707 .577 .707 r
F P
0 g
s
.50043 .70064 m .49514 .71776 L .49285 .70515 L p .707 .577 .707 r
F P
0 g
s
.49285 .70515 m .49814 .68802 L .50043 .70064 L p .707 .577 .707 r
F P
0 g
s
.31193 .63263 m .30664 .64976 L .29935 .65953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29836 .60862 m .30979 .57474 L .32592 .56888 L p .707 .577 .707 r
F P
0 g
s
.32502 .51052 m .31642 .56445 L .30011 .57105 L p .707 .577 .707 r
F P
0 g
s
.49469 .63419 m .48326 .66807 L .47177 .65334 L p .707 .577 .707 r
F P
0 g
s
.47177 .65334 m .4832 .61946 L .49469 .63419 L p .707 .577 .707 r
F P
0 g
s
.48808 .53759 m .47948 .59152 L .45877 .5807 L p .707 .577 .707 r
F P
0 g
s
.45877 .5807 m .46737 .52676 L .48808 .53759 L p .707 .577 .707 r
F P
0 g
s
.31642 .56445 m .32502 .51052 L .3489 .50709 L p .707 .577 .707 r
F P
0 g
s
.32592 .56888 m .31449 .60276 L .29836 .60862 L p .707 .577 .707 r
F P
0 g
s
.30664 .64976 m .31193 .63263 L .32809 .62667 L p .707 .577 .707 r
F P
0 g
s
.49814 .68802 m .49285 .70515 L .4812 .69091 L p .707 .577 .707 r
F P
0 g
s
.4812 .69091 m .48649 .67378 L .49814 .68802 L p .707 .577 .707 r
F P
0 g
s
.32809 .62667 m .3228 .6438 L .30664 .64976 L p .707 .577 .707 r
F P
0 g
s
.31449 .60276 m .32592 .56888 L .34926 .56763 L p .707 .577 .707 r
F P
0 g
s
.3489 .50709 m .34029 .56103 L .31642 .56445 L p .707 .577 .707 r
F P
0 g
s
.46737 .52676 m .45877 .5807 L .43169 .57146 L p .707 .577 .707 r
F P
0 g
s
.43169 .57146 m .44029 .51752 L .46737 .52676 L p .707 .577 .707 r
F P
0 g
s
.34029 .56103 m .3489 .50709 L .37801 .50718 L p .707 .577 .707 r
F P
0 g
s
.4832 .61946 m .47177 .65334 L .45211 .63825 L p .707 .577 .707 r
F P
0 g
s
.45211 .63825 m .46353 .60437 L .4832 .61946 L p .707 .577 .707 r
F P
0 g
s
.34926 .56763 m .33783 .60151 L .31449 .60276 L p .707 .577 .707 r
F P
0 g
s
.3228 .6438 m .32809 .62667 L .35154 .6251 L p .707 .577 .707 r
F P
0 g
s
.44029 .51752 m .43169 .57146 L .4009 .56472 L p .707 .577 .707 r
F P
0 g
s
.4009 .56472 m .4095 .51078 L .44029 .51752 L p .707 .577 .707 r
F P
0 g
s
.3694 .56112 m .37801 .50718 L .4095 .51078 L p .707 .577 .707 r
F P
0 g
s
.37801 .50718 m .3694 .56112 L .34029 .56103 L p .707 .577 .707 r
F P
0 g
s
.48649 .67378 m .4812 .69091 L .46133 .67645 L p .707 .577 .707 r
F P
0 g
s
.46133 .67645 m .46662 .65933 L .48649 .67378 L p .707 .577 .707 r
F P
0 g
s
.33783 .60151 m .34926 .56763 L .37754 .5711 L p .707 .577 .707 r
F P
0 g
s
.35154 .6251 m .34625 .64223 L .3228 .6438 L p .707 .577 .707 r
F P
0 g
s
.4095 .51078 m .4009 .56472 L .3694 .56112 L p .707 .577 .707 r
F P
0 g
s
.46353 .60437 m .45211 .63825 L .42619 .6243 L p .707 .577 .707 r
F P
0 g
s
.42619 .6243 m .43762 .59042 L .46353 .60437 L p .707 .577 .707 r
F P
0 g
s
.37754 .5711 m .36611 .60498 L .33783 .60151 L p .707 .577 .707 r
F P
0 g
s
.36611 .60498 m .37754 .5711 L .40799 .57895 L p .707 .577 .707 r
F P
0 g
s
.34625 .64223 m .35154 .6251 L .37998 .62807 L p .707 .577 .707 r
F P
0 g
s
.43762 .59042 m .42619 .6243 L .39656 .61283 L p .707 .577 .707 r
F P
0 g
s
.39656 .61283 m .40799 .57895 L .43762 .59042 L p .707 .577 .707 r
F P
0 g
s
.46662 .65933 m .46133 .67645 L .43519 .66319 L p .707 .577 .707 r
F P
0 g
s
.43519 .66319 m .44048 .64606 L .46662 .65933 L p .707 .577 .707 r
F P
0 g
s
.40799 .57895 m .39656 .61283 L .36611 .60498 L p .707 .577 .707 r
F P
0 g
s
.37998 .62807 m .37469 .6452 L .34625 .64223 L p .707 .577 .707 r
F P
0 g
s
.37469 .6452 m .37998 .62807 L .41063 .63529 L p .707 .577 .707 r
F P
0 g
s
.44048 .64606 m .43519 .66319 L .40534 .65242 L p .707 .577 .707 r
F P
0 g
s
.40534 .65242 m .41063 .63529 L .44048 .64606 L p .707 .577 .707 r
F P
0 g
s
.41063 .63529 m .40534 .65242 L .37469 .6452 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Qgoo6@00OGoo001nOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Qoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH3001]Ool006eoo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006]oo`00JWoo0`0025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0J7oo001XOol200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIZOol006Ioo`8000=JEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<007ooOol0Igoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUIYOol0
06=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYFJGoo001ROol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUIYOol0069oo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF
00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001ROol00`00FUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006=oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001XOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVQoo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol006=oo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEUYF001JEVQoo`00Hgoo00<005YF00001eYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo
001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00I7oo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006Aoo`03001JEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYFFUH005YFIgoo001TOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001J
EVMoo`00I7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00H7oo40002EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00
Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00FGoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol0
05Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
FUH005YFIGoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVEoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001TOol005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000I7oo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Qooa0004aoo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0017oo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00AGoo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00=JEP<003Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF0`00=7oo001DOol20003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000bOol005Aoo`8000=J
EP@0009JEP03001JEP0000<00005Ool005YFFUH00003FUH70006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<7oo001COol01000FUH005YF0`000UYF3P00
15YF1@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP8002moo`00Dgoo00@005YF0000009JEP@000IJEP04001JEUYFFUH<0005FUH40006
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool005=oo`<0009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEP0000L000EJEP04001JEP000004FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P000UYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Goo001COol00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP06FUH20005FUH01`00FUIJEUYF001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000;Goo001COol01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00@005YF000000=JEP07001JEUYF
FUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP04001JEUYFFUH200000eYF001JEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<00003FUH005YF00EJEP8000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEP000003FUH50002FUH00`00FUH000030008Ool70006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJ
EP07001JEP00FUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF000005YF00<000IJEP03001JEUYF00=JEP@000Ioo`<0009oo`@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000iOol@000;Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJ
EP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000300000goo000000030005Ool4
0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000goo00<005YF00000UYF300015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qo
o`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0039oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH00000008000=JEP03001JEUYF00AJEPH0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP8000IJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD00003FUH0000000X00003FUH005YF00EJEP04001JEUYFFUH2000]Ool0031oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP06001o
o`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00P000eYF00<005YF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
00=JEP00FUH00UYF00<005YFFUH0300025YF0`001UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJ
EP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0015YF1P001UYF00<005YFFUH01UYF100025YF00<005YFFUH01EYF00@005YFFUIJEP80
009JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000EJEP<0
0003FUH005YF00AJEP04001JEUYFFUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH0
0`00FUIJEP02FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEPD00003Ool000000080009JEP03001JEUYF
00IJEP04001JEUYFFUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0
05YF00=JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEP@000=oo`@000IJEP03001JEUYF
00EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP80009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH00UYF0P0000=JEP0000002@000UYF00<005YFFUH01UYF00@005YF000000MJEP03001J
EUYF00EJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP000080
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000QJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEP0002eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01P000UYF00<0
05YFFUH00UYF2P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH007oo02aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEP0000l000=JEP03001JEUYF00AJEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP030007FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP8000AJEP04001J
EUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200001EYF001JEUYF
00000eYF1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00L005YF
FUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH50007FUH70006FUH00`00FUIJEP06FUH20005
FUH01@00FUIJEUYF00000eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0`000UYF2`0000=JEP0000001@001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=J
EP00FUH00eYF0P00;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH6
0002FUH00`00FUIJEP07FUH30004FUH30004FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH500000eYF001JEP03FUH30002Ool50003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH30004FUH2000_Ool002eoo`8000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP07FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70007FUH01000FUIJEUYF0P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP<000AJEP05001JEUYFFUH00002FUH00`00Oomoo`04Ool40002FUH40008FUH00`00FUIJEP06FUH0
0`00FUIJEP02000015YF00000000<7oo000]Ool20003FUH40002FUH00`00FUH000030008Ool70006
FUH00`00FUH0000200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00005
0005FUH00`00FUIJEP03FUH20003FUH01P00FUIJEP00FUH000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP<000AJEP800003FUH005YF00=JEP8000Qoo`P000IJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo035oo`00;7oo00@005YF001JEP<0009JEPh000Aoo`D00003Ool0
00000080009JEP04001JEP00FUH20002FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50000
0eYF001JEP07FUH01000FUIJEP000UYF00<005YF00001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00P001UYF00<007ooOol037oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<007ooOol0<7oo000/Ool01000FUH000000UYF10001UYF00@0
05YFFUIJEP`000Eoo`H00004FUH005YFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP020008FUH600000eYF001JEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH01@00FUIJEUYF00001UYF0P0047oo0P0000=JEP00FUH01eYF00<005YFFUH015YF0P00
<Goo000/Ool30002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070007Ool20002
FUH01000FUH005YF0P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF
00P005YFFUH005YF001JEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00002Goo0`001Goo0P0025YF00<005YFFUH0
0eYF00@005YFFUH0031oo`00;7oo0P000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF300015YF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH015YF0P000UYF00D005YFFUIJEP0000Moo`D000Ioo`8000EJ
EP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEUYF008000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000002FUH01000FUIJEP0015YF0`0015YF0`00
2EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH000060007Ool50008Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02aoo`05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30003FUH01@00FUIJEUYF00000UYF00H005YFFUIJEP00FUH20008FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH01UYF10000eYF00@005YFFUIJEP`000Yoo`<000IJEP03001JEUYF
00=JEP03001oogoo02aoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YF000015YF0P0000=JEP00FUH00UYF0`001EYF00<005YF
00000P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH010003Goo00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH20006FUH20003FUH200001goo00000000FUH005YF00D0009JEP03001JEUYF00EJEP03
001JEUYF00AJEP<0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH00000FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
10002Woo0P0015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP08FUH300000eYF001JEP05FUH300001UYF001J
EP00Ool0009JEPP0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000:Ool01@00FUIJEUYF0000
0eYF00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00@005YFFUIJEP800004FUH007oo0002FUH00`00
FUIJEP0500000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF
1P0015YF00<005YFFUH01eYF00<005YFFUH00UYF0`0027oo0`0015YF00<005YF0000;Woo000/Ool0
0`00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30002FUH0
0`00FUIJEP03FUH200001Goo001JEUYF00000eYF2@0015YF00<005YFFUH015YF00D005YF000005YF
008000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYF0002FUH60006FUH70007FUH00`00FUIJEP05FUH20008Ool00`00FUIJEP02FUH2000_Ool002ao
o`800003FUH00000008000=JEP03001JEUYF00AJEPH000MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP<000QJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP07001JEP00FUH005YF0000
1UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001P0025YF00<005YF
FUH01EYF10000UYF00<005YFFUH01eYF0`001goo00H005YFFUH005YF000_Ool002aoo`<0009JEP06
001oo`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00
25YF00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000P0000AJEP00
000000QJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF008000Eoo`06001JEUYF001J
EP00;goo000/Ool00`00FUH00003FUH00`00Oomoo`030006FUH00`00FUIJEP06FUH40008FUH00`00
FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YF
FUH02EYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH400000eYF000000040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03
FUH800000eYF001oo`0_Ool002]oo`<000AJEP<000=oo`8000AJEP03001JEUYF00IJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH300000eYF001J
EP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP0000000P000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF0P0000IJEP00FUH005YF000`Ool002]oo`03001JEP0000=JEP05001JEUYFFUH0
0004Ool300000eYF001JEP07FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP04FUH3
00000eYF001JEP08FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUH000030007FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP020005FUH300000eYF001J
EP07FUH00`00FUIJEP07FUH01000FUIJEUYF0P0025YF0P000UYF00<005YF0000<7oo000[Ool00`00
FUH00003FUH00`00FUIJEP02FUH20002Ool70005FUH00`00FUIJEP07FUH30007FUH00`00FUIJEP05
FUH2000017oo000000001eYF00<005YFFUH015YF1`001eYF1P0000=JEP00000025YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF00<005YF00000`001eYF
00<005YFFUH00`0015YF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=JEP00Ool0;goo000/
Ool00`00FUIJEP02FUH01000FUIJEUYF1@000UYF00<005YFFUH00UYF1P0025YF00@005YFFUIJEP80
00EJEP03001JEUYF00AJEP03001JEP0000Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
000015YF00<005YFFUH00UYF00<005YFFUH01@001EYF00<005YF000010000UYF00<005YFFUH01UYF
0P000eYF00<005YFFUH00UYF0P00<Goo000/Ool01@00FUIJEUYF00000UYF0P0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00@0
05YFFUH000Aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP8000=JEP03
001JEUYF009JEP800006Ool00000001JEP000UYF1@000UYF00<005YFFUH01EYF00<005YFFUH00`00
1UYF00<007ooOol0;goo000]Ool00`00FUIJEP030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH?0007FUH01@00FUIJEUYF00000goo00<005YFFUH01@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP0200000eYF001JEP03FUH20004Ool300000eYF00000003
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH2000`Ool002eoo`03001JEUYF
008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`03
001JEUYF00AJEP03001JEUYF009JEP05001oogooOol00002FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH0000035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP8000=JEP03001JEP0000Moo`D000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEP0002moo`00;Woo0`000eYF00@005YFFUIJ
EPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000Eoo`8000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF00<005YF00001@0015YF00@005YFFUIJEPD00003FUH005YF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000IJEP07001JEUYFFUH005YF0000
2Woo0`0000=JEP00FUH01eYF00<005YFFUH00UYF00@005YFFUH0009JEP05001JEUYFFUH0000^Ool0
02moo`80009JEPD000MJEPL000IJEP03001JEUYF00IJEP8000Eoo`05001JEUYFFUH00003FUH00`00
FUH00002Ool01000FUIJEP001UYF00<005YFFUH01EYF20001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP<00003FUH0000000ioo`D0
00AJEP04001JEUYFFUH5000017oo0000000015YF00<007ooOol0:goo000_Ool40003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH30004Ool30004FUH00`00FUH00002Ool0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00<001=oo`P000Qo
o`03001JEUYF009JEP03001oogoo02]oo`00;Woo100015YF00<005YFFUH01EYF00<005YFFUH01UYF
1`001eYF00@005YFFUIJEP8000Aoo`05001JEUYFFUH00002FUH01000Oomoo`000UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP8002=oo`03001JEUYF0080
02eoo`00;Woo0`0000=oo`0000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009o
o`8000EJEP03001JEUYF00=JEP8000=oo`06001JEUYF001JEP000goo00@005YFFUH000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEQP000EJEP03001JEUYF00IJEP03001JEUYF009J
EPH000MJEP<0021oo`03001JEUYF008002eoo`00;Woo00@005YF0000009oo`8000MJEP03001JEUYF
00MJEP03001JEUYF009JEP<00006Ool00000001JEP0025YF00@007ooOol0009JEP03001JEP0000=o
o`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH9000<FUH00`00FUIJEP09FUH80006
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0;7oo
000^Ool200000eYF001oo`02Ool00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60008
FUH5000015YF001JEP000goo00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF
009JEP8000EJEP03001JEUYF009JEP<001eoo`03001JEP0002eoo`00;Woo0P000UYF00@007ooOomo
o`8000EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30006FUH00`00FUIJEP030000
0eYF001oo`03Ool00`00FUIJEP08FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP03FUH30003
FUH00`00FUIJEP05FUH4000IOol00`00FUH0000]Ool002ioo`03001JEUYF009JEP03001oogoo009o
o`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009J
EP800003FUH007oo00Aoo`YJEP03001JEUYF009JEP<000MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001J
EUYF00<000UJEP03001JEUYF00@001Aoo`<002ioo`00;Woo00<005YFFUH00UYF0`0017oo0`002EYF
00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH20005Ool:FUH00`00FUH00002
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001JEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH015YF1P0027oo1P0000=J
EP000000;Woo000_Ool01@00FUIJEUYF00000UYF00<007ooOol00goo0P0025YF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP8000Eoo`UJEP<0009JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EP000004FUH00`00FUIJEP03FUH00`00Ool000020004FUH00`00FUIJEP07FUH01000FUIJEUYF2000
0eYF00@005YFFUIJEP8002ioo`00<7oo00<005YF000015YF0P001Goo0`001EYF00<005YF00000P00
0eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001Goo1eYF0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00=JEP03001oogoo009oo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035oo`8000IJEP03001o
ogoo00Eoo`<00003FUH005YF00D0009JEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001J
EUYF0004Ool5FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH00UYF0P001goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00<Woo00<005YFFUH0
15YF0`0027oo20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00@007oo
Oomoo`=JEP8000UJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF009JEP8000Yoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<0031oo`00<goo00<005YFFUH00UYF
00@005YFFUIJEP8000Uoo`D00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF008000AJEP04
001oogooOol2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000goo0P0015YF00<0
05YF00003Woo1P0015YF00@005YFFUIJEPH003=oo`00=7oo0P000UYF00<005YFFUH00eYF0P0027oo
2@0015YF00<005YFFUH015YF00@005YF0000009oo`05001JEUYFFUH00003Ool00eYF001JEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20005Ool00`00FUIJEP02FUH2000EOol8000iOol003Ioo`80
00QJEP8000moo`d000Eoo`05001JEP00FUH00002Ool20004FUH00`00FUIJEP0@FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`05
Ool01P00FUIJEP00FUH005Ioo`00=goo00<005YFFUH01UYF00<005YF00000P007goo0P0000AJEP00
Oomoo`8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006Ool01P00FUIJEP00FUH005Ioo`00>7oo
0P001UYF00<005YFFUH00UYF0`007Goo00<005YF00000goo00<005YFFUH00UYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEPT00003FUH007oo05Ioo`00>Woo0P000eYF00<005YFFUH01UYF0`006Woo0P00
17oo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH01UYF0P0000IJEP00FUH005YF001G
Ool003aoo`800003FUH005YF00QJEP03001JEP0000<001Aoo`@000Eoo`80009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP<000=JEP8000QJEP80009JEP03001JEP0005Moo`00?Woo0`001eYF00<005YFFUH015YF1P0027oo
1P000UYF00<007ooOol01Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH00`000UYF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=J
EP00Ool0EWoo0011Ool20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJEP80
00Yoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPH0
00=JEP03001JEUYF00IJEP8000=JEP03001JEUYF009JEP8005Qoo`00@goo0`0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH700000eYF000000030002FUH00`00FUIJEP05
FUH00`00FUIJEP030006FUH00`00Oomoo`1FOol004Ioo`@000IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH2000BOol80005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH:0002Ool20000
15YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF0P00Egoo001:
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000KOolH0002FUH00`00Oomo
o`09Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH00`00FUH0001FOol004ioo`H0
00AJEP04001JEUYFFUH6000`Ool20006FUH00`00Oomoo`0<Ool40002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000UYF00D005YFFUIJEP0005Eoo`00E7oo2000=goo00<005YFFUH015YF
0`0047oo1P0015YF00@005YFFUIJEPD00004Ool000000004FUH00`00Oomoo`1BOol009Aoo`8000AJ
EP03001JEUYF008001Aoo`P000Qoo`03001JEUYF009JEP03001oogoo059oo`00UWoo00@005YFFUH0
00EJEP8002=oo`03001JEUYF008005Aoo`00Ugoo0`001eYF0`0087oo00<005YFFUH00P00E7oo002I
Ool00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0Dgoo002JOol20005FUH00`00FUIJ
EP02FUH3000MOol00`00FUH0001DOol009aoo`8000=JEP03001JEUYF00EJEP@001Uoo`03001JEP00
05Aoo`00WWoo0`002EYF00<005YFFUH0100057oo0`00EGoo002POol20008FUH00`00FUIJEP04FUH6
0008Ool600000eYF0000001EOol00:9oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
1000FUIJEUYF0P00EGoo002UOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00EWoo002XOol30007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002[Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001GOol00:mo
o`H000AJEP04001JEUYFFUH6001JOol00;Eoo`P0061oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59239 .74927 m .601 .69533 L .57021 .68859 L p .707 .577 .707 r
F P
0 g
s
.601 .69533 m .59239 .74927 L .62389 .75286 L p .707 .577 .707 r
F P
0 g
s
.62389 .75286 m .63249 .69893 L .601 .69533 L p .707 .577 .707 r
F P
0 g
s
.63249 .69893 m .62389 .75286 L .65299 .75295 L p .707 .577 .707 r
F P
0 g
s
.65299 .75295 m .6616 .69902 L .63249 .69893 L p .707 .577 .707 r
F P
0 g
s
.5616 .74252 m .57021 .68859 L .54313 .67935 L p .707 .577 .707 r
F P
0 g
s
.57021 .68859 m .5616 .74252 L .59239 .74927 L p .707 .577 .707 r
F P
0 g
s
.6616 .69902 m .65299 .75295 L .67687 .74953 L p .707 .577 .707 r
F P
0 g
s
.67687 .74953 m .68548 .69559 L .6616 .69902 L p .707 .577 .707 r
F P
0 g
s
.53452 .73329 m .54313 .67935 L .52242 .66852 L p .707 .577 .707 r
F P
0 g
s
.54313 .67935 m .53452 .73329 L .5616 .74252 L p .707 .577 .707 r
F P
0 g
s
.58574 .81947 m .59716 .78559 L .56753 .77413 L p .707 .577 .707 r
F P
0 g
s
.59716 .78559 m .58574 .81947 L .61618 .82732 L p .707 .577 .707 r
F P
0 g
s
.61618 .82732 m .62761 .79344 L .59716 .78559 L p .707 .577 .707 r
F P
0 g
s
.5561 .80801 m .56753 .77413 L .54161 .76017 L p .707 .577 .707 r
F P
0 g
s
.56753 .77413 m .5561 .80801 L .58574 .81947 L p .707 .577 .707 r
F P
0 g
s
.62761 .79344 m .61618 .82732 L .64446 .83079 L p .707 .577 .707 r
F P
0 g
s
.64446 .83079 m .65589 .79691 L .62761 .79344 L p .707 .577 .707 r
F P
0 g
s
.52242 .66852 m .51381 .72246 L .53452 .73329 L p .707 .577 .707 r
F P
0 g
s
.68548 .69559 m .67687 .74953 L .69318 .74293 L p .707 .577 .707 r
F P
0 g
s
.69318 .74293 m .70179 .68899 L .68548 .69559 L p .707 .577 .707 r
F P
0 g
s
.51381 .72246 m .52242 .66852 L .5101 .65717 L p .707 .577 .707 r
F P
0 g
s
.53019 .79405 m .54161 .76017 L .52195 .74509 L p .707 .577 .707 r
F P
0 g
s
.54161 .76017 m .53019 .79405 L .5561 .80801 L p .707 .577 .707 r
F P
0 g
s
.59496 .8666 m .60025 .84947 L .5704 .8387 L p .707 .577 .707 r
F P
0 g
s
.60025 .84947 m .59496 .8666 L .62561 .87382 L p .707 .577 .707 r
F P
0 g
s
.62561 .87382 m .6309 .8567 L .60025 .84947 L p .707 .577 .707 r
F P
0 g
s
.65589 .79691 m .64446 .83079 L .66781 .82954 L p .707 .577 .707 r
F P
0 g
s
.66781 .82954 m .67923 .79566 L .65589 .79691 L p .707 .577 .707 r
F P
0 g
s
.56511 .85583 m .5704 .8387 L .54425 .82544 L p .707 .577 .707 r
F P
0 g
s
.5704 .8387 m .56511 .85583 L .59496 .8666 L p .707 .577 .707 r
F P
0 g
s
.6309 .8567 m .62561 .87382 L .65405 .8768 L p .707 .577 .707 r
F P
0 g
s
.65405 .8768 m .65934 .85967 L .6309 .8567 L p .707 .577 .707 r
F P
0 g
s
.54425 .82544 m .53896 .84257 L .56511 .85583 L p .707 .577 .707 r
F P
0 g
s
.52195 .74509 m .51052 .77897 L .53019 .79405 L p .707 .577 .707 r
F P
0 g
s
.53896 .84257 m .54425 .82544 L .52439 .81098 L p .707 .577 .707 r
F P
0 g
s
.5101 .65717 m .50149 .71111 L .51381 .72246 L p .707 .577 .707 r
F P
0 g
s
.51052 .77897 m .52195 .74509 L .51046 .73035 L p .707 .577 .707 r
F P
0 g
s
.65934 .85967 m .65405 .8768 L .6775 .87522 L p .707 .577 .707 r
F P
0 g
s
.6775 .87522 m .68279 .8581 L .65934 .85967 L p .707 .577 .707 r
F P
0 g
s
.70179 .68899 m .69318 .74293 L .70032 .7338 L p .707 .577 .707 r
F P
0 g
s
.70032 .7338 m .70893 .67986 L .70179 .68899 L p .707 .577 .707 r
F P
0 g
s
.52439 .81098 m .5191 .82811 L .53896 .84257 L p .707 .577 .707 r
F P
0 g
s
.50149 .71111 m .5101 .65717 L .50738 .6464 L p .707 .577 .707 r
F P
0 g
s
.67923 .79566 m .66781 .82954 L .68393 .82369 L p .707 .577 .707 r
F P
0 g
s
.68393 .82369 m .69536 .78981 L .67923 .79566 L p .707 .577 .707 r
F P
0 g
s
.51046 .73035 m .49903 .76424 L .51052 .77897 L p .707 .577 .707 r
F P
0 g
s
.5191 .82811 m .52439 .81098 L .51274 .79675 L p .707 .577 .707 r
F P
0 g
s
.68279 .8581 m .6775 .87522 L .69366 .86926 L p .707 .577 .707 r
F P
0 g
s
.69366 .86926 m .69895 .85213 L .68279 .8581 L p .707 .577 .707 r
F P
0 g
s
.50738 .6464 m .49877 .70034 L .50149 .71111 L p .707 .577 .707 r
F P
0 g
s
.51274 .79675 m .50745 .81388 L .5191 .82811 L p .707 .577 .707 r
F P
0 g
s
.49903 .76424 m .51046 .73035 L .50827 .71742 L p .707 .577 .707 r
F P
0 g
s
.70893 .67986 m .70032 .7338 L .6976 .72303 L p .707 .577 .707 r
F P
0 g
s
.6976 .72303 m .70621 .66909 L .70893 .67986 L p .707 .577 .707 r
F P
0 g
s
.69536 .78981 m .68393 .82369 L .69126 .81381 L p .707 .577 .707 r
F P
0 g
s
.69126 .81381 m .70268 .77993 L .69536 .78981 L p .707 .577 .707 r
F P
0 g
s
.49877 .70034 m .50738 .6464 L .51452 .63727 L p .707 .577 .707 r
F P
0 g
s
.50827 .71742 m .49684 .7513 L .49903 .76424 L p .707 .577 .707 r
F P
0 g
s
.50745 .81388 m .51274 .79675 L .51044 .78413 L p .707 .577 .707 r
F P
0 g
s
.51044 .78413 m .50515 .80126 L .50745 .81388 L p .707 .577 .707 r
F P
0 g
s
.51452 .63727 m .50591 .69121 L .49877 .70034 L p .707 .577 .707 r
F P
0 g
s
.49684 .7513 m .50827 .71742 L .5156 .70754 L p .707 .577 .707 r
F P
0 g
s
.5156 .70754 m .50417 .74142 L .49684 .7513 L p .707 .577 .707 r
F P
0 g
s
.50515 .80126 m .51044 .78413 L .51774 .77436 L p .707 .577 .707 r
F P
0 g
s
.51774 .77436 m .51245 .79149 L .50515 .80126 L p .707 .577 .707 r
F P
0 g
s
.50417 .74142 m .5156 .70754 L .53172 .70168 L p .707 .577 .707 r
F P
0 g
s
.53172 .70168 m .5203 .73556 L .50417 .74142 L p .707 .577 .707 r
F P
0 g
s
.50962 .8207 m .47922 .31654 L .4353 .31657 L p .707 .577 .707 r
F P
0 g
s
.50591 .69121 m .51452 .63727 L .53083 .63067 L p .707 .577 .707 r
F P
0 g
s
.53083 .63067 m .52222 .68461 L .50591 .69121 L p .707 .577 .707 r
F P
0 g
s
.52222 .68461 m .53083 .63067 L .55471 .62725 L p .707 .577 .707 r
F P
0 g
s
.51245 .79149 m .51774 .77436 L .5339 .7684 L p .707 .577 .707 r
F P
0 g
s
.5339 .7684 m .52861 .78552 L .51245 .79149 L p .707 .577 .707 r
F P
0 g
s
.55471 .62725 m .5461 .68118 L .52222 .68461 L p .707 .577 .707 r
F P
0 g
s
.5203 .73556 m .53172 .70168 L .55507 .70043 L p .707 .577 .707 r
F P
0 g
s
.55507 .70043 m .54364 .73431 L .5203 .73556 L p .707 .577 .707 r
F P
0 g
s
.52861 .78552 m .5339 .7684 L .55734 .76682 L p .707 .577 .707 r
F P
0 g
s
.55734 .76682 m .55205 .78395 L .52861 .78552 L p .707 .577 .707 r
F P
0 g
s
.47922 .31654 m .50962 .8207 L .55449 .81716 L p .707 .577 .707 r
F P
0 g
s
.5461 .68118 m .55471 .62725 L .58382 .62734 L p .707 .577 .707 r
F P
0 g
s
.58382 .62734 m .57761 .66625 L p .5461 .68118 L .707 .577 .707 r
F P
0 g
s
.57761 .66625 m .57521 .68127 L .57055 .68126 L p .707 .577 .707 r
F P
0 g
s
.57055 .68126 m .5461 .68118 L p .57761 .66625 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .47922 .31654 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.54364 .73431 m .55507 .70043 L .58335 .7039 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .5804 .71262 L p .54364 .73431 L .707 .577 .707 r
F P
0 g
s
.5804 .71262 m .57192 .73778 L .55887 .73618 L p .707 .577 .707 r
F P
0 g
s
.55887 .73618 m .54364 .73431 L p .5804 .71262 L .707 .577 .707 r
F P
0 g
s
.54465 .75173 m .54905 .72698 L .5429 .74007 L .707 .577 .707 r
F
.55205 .78395 m .55734 .76682 L .58578 .7698 L p F P
0 g
s
.58578 .7698 m .58417 .77503 L p .55205 .78395 L .707 .577 .707 r
F P
0 g
s
.58417 .77503 m .58049 .78692 L .57468 .78632 L p .707 .577 .707 r
F P
0 g
s
.57468 .78632 m .55205 .78395 L p .58417 .77503 L .707 .577 .707 r
F P
0 g
s
.55362 .81137 m .55018 .74568 L .54465 .75173 L .707 .577 .707 r
F
.55449 .81716 m .55411 .81079 L p .55362 .81137 L F P
0 g
s
.55411 .81079 m .55018 .74568 L p .55362 .81137 L .707 .577 .707 r
F P
0 g
s
.55018 .74568 m .54905 .72698 L p .54465 .75173 L .707 .577 .707 r
F P
0 g
s
.54905 .72698 m .52409 .313 L p .5429 .74007 L .707 .577 .707 r
F P
0 g
s
.57521 .68127 m .58382 .62734 L .61531 .63093 L p .707 .577 .707 r
F P
0 g
s
.61531 .63093 m .6067 .68487 L .57521 .68127 L p .707 .577 .707 r
F P
0 g
s
.58335 .7039 m .61379 .71175 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.57192 .73778 m .576 .72569 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.576 .72569 m .58335 .7039 L p .57841 .73375 L .707 .577 .707 r
F P
0 g
s
.6461 .63768 m .63749 .69161 L .6067 .68487 L p .707 .577 .707 r
F P
0 g
s
.6067 .68487 m .61531 .63093 L .6461 .63768 L p .707 .577 .707 r
F P
0 g
s
.64342 .72322 m .632 .7571 L .60237 .74563 L p .707 .577 .707 r
F P
0 g
s
.60237 .74563 m .61379 .71175 L .64342 .72322 L p .707 .577 .707 r
F P
0 g
s
.61379 .71175 m .60237 .74563 L .57192 .73778 L p .707 .577 .707 r
F P
0 g
s
.58049 .78692 m .58578 .7698 L .61643 .77702 L p .707 .577 .707 r
F P
0 g
s
.64629 .78779 m .641 .80492 L .61114 .79415 L p .707 .577 .707 r
F P
0 g
s
.61114 .79415 m .61643 .77702 L .64629 .78779 L p .707 .577 .707 r
F P
0 g
s
.61643 .77702 m .61114 .79415 L .58049 .78692 L p .707 .577 .707 r
F P
0 g
s
.56552 .3063 m .59453 .78752 L p .62983 .80123 L .707 .577 .707 r
F P
0 g
s
.59453 .78752 m .59591 .81046 L .60099 .80907 L p .707 .577 .707 r
F P
0 g
s
.60099 .80907 m .62983 .80123 L p .59453 .78752 L .707 .577 .707 r
F P
0 g
s
.52409 .313 m .55449 .81716 L .59591 .81046 L p .707 .577 .707 r
F P
0 g
s
.59591 .81046 m .56552 .3063 L .52409 .313 L p .707 .577 .707 r
F P
0 g
s
.69895 .85213 m .69366 .86926 L .70095 .85949 L p .707 .577 .707 r
F P
0 g
s
.70095 .85949 m .70624 .84236 L .69895 .85213 L p .707 .577 .707 r
F P
0 g
s
.46569 .82073 m .4353 .31657 L .39662 .31307 L p .707 .577 .707 r
F P
0 g
s
.4353 .31657 m .46569 .82073 L .50962 .8207 L p .707 .577 .707 r
F P
0 g
s
.70621 .66909 m .6976 .72303 L .68528 .71168 L p .707 .577 .707 r
F P
0 g
s
.68528 .71168 m .69389 .65774 L .70621 .66909 L p .707 .577 .707 r
F P
0 g
s
.70268 .77993 m .69126 .81381 L .68907 .80087 L p .707 .577 .707 r
F P
0 g
s
.68907 .80087 m .7005 .76699 L .70268 .77993 L p .707 .577 .707 r
F P
0 g
s
.62983 .80123 m .59944 .29708 L .56552 .3063 L p .707 .577 .707 r
F P
0 g
s
.24938 .72116 m .25799 .66722 L .2272 .66047 L p .707 .577 .707 r
F P
0 g
s
.25799 .66722 m .24938 .72116 L .28088 .72475 L p .707 .577 .707 r
F P
0 g
s
.28088 .72475 m .28948 .67081 L .25799 .66722 L p .707 .577 .707 r
F P
0 g
s
.28948 .67081 m .28088 .72475 L .30999 .72484 L p .707 .577 .707 r
F P
0 g
s
.30999 .72484 m .31859 .6709 L .28948 .67081 L p .707 .577 .707 r
F P
0 g
s
.21859 .71441 m .2272 .66047 L .20012 .65124 L p .707 .577 .707 r
F P
0 g
s
.2272 .66047 m .21859 .71441 L .24938 .72116 L p .707 .577 .707 r
F P
0 g
s
.42701 .81723 m .39662 .31307 L .36696 .3064 L p .707 .577 .707 r
F P
0 g
s
.39662 .31307 m .42701 .81723 L .46569 .82073 L p .707 .577 .707 r
F P
0 g
s
.70624 .84236 m .70095 .85949 L .69866 .84687 L p .707 .577 .707 r
F P
0 g
s
.69866 .84687 m .70395 .82974 L .70624 .84236 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31859 .6709 m .30999 .72484 L .33386 .72142 L p .707 .577 .707 r
F P
0 g
s
.33386 .72142 m .34247 .66748 L .31859 .6709 L p .707 .577 .707 r
F P
0 g
s
.69389 .65774 m .68528 .71168 L .66457 .70085 L p .707 .577 .707 r
F P
0 g
s
.66457 .70085 m .67318 .64691 L .69389 .65774 L p .707 .577 .707 r
F P
0 g
s
.19152 .70517 m .20012 .65124 L .17941 .64041 L p .707 .577 .707 r
F P
0 g
s
.20012 .65124 m .19152 .70517 L .21859 .71441 L p .707 .577 .707 r
F P
0 g
s
.7005 .76699 m .68907 .80087 L .67758 .78614 L p .707 .577 .707 r
F P
0 g
s
.67758 .78614 m .68901 .75226 L .7005 .76699 L p .707 .577 .707 r
F P
0 g
s
.67318 .64691 m .66457 .70085 L .63749 .69161 L p .707 .577 .707 r
F P
0 g
s
.63749 .69161 m .6461 .63768 L .67318 .64691 L p .707 .577 .707 r
F P
0 g
s
.66934 .73717 m .65791 .77105 L .632 .7571 L p .707 .577 .707 r
F P
0 g
s
.632 .7571 m .64342 .72322 L .66934 .73717 L p .707 .577 .707 r
F P
0 g
s
.641 .80492 m .64629 .78779 L .67243 .80105 L p .707 .577 .707 r
F P
0 g
s
.59944 .29708 m .62983 .80123 L .65293 .7904 L p .707 .577 .707 r
F P
0 g
s
.65293 .7904 m .62253 .28625 L .59944 .29708 L p .707 .577 .707 r
F P
0 g
s
.24273 .77871 m .25415 .74483 L .22452 .73336 L p .707 .577 .707 r
F P
0 g
s
.25415 .74483 m .24273 .77871 L .27317 .78656 L p .707 .577 .707 r
F P
0 g
s
.27317 .78656 m .2846 .75268 L .25415 .74483 L p .707 .577 .707 r
F P
0 g
s
.2131 .76725 m .22452 .73336 L .1986 .71941 L p .707 .577 .707 r
F P
0 g
s
.22452 .73336 m .2131 .76725 L .24273 .77871 L p .707 .577 .707 r
F P
0 g
s
.2846 .75268 m .27317 .78656 L .30145 .79003 L p .707 .577 .707 r
F P
0 g
s
.30145 .79003 m .31288 .75615 L .2846 .75268 L p .707 .577 .707 r
F P
0 g
s
.70395 .82974 m .69866 .84687 L .68701 .83264 L p .707 .577 .707 r
F P
0 g
s
.68701 .83264 m .6923 .81551 L .70395 .82974 L p .707 .577 .707 r
F P
0 g
s
.25195 .81691 m .25724 .79978 L .22739 .78901 L p .707 .577 .707 r
F P
0 g
s
.25724 .79978 m .25195 .81691 L .2826 .82414 L p .707 .577 .707 r
F P
0 g
s
.2826 .82414 m .28789 .80701 L .25724 .79978 L p .707 .577 .707 r
F P
0 g
s
.17941 .64041 m .1708 .69435 L .19152 .70517 L p .707 .577 .707 r
F P
0 g
s
.34247 .66748 m .33386 .72142 L .35017 .71482 L p .707 .577 .707 r
F P
0 g
s
.35017 .71482 m .35878 .66088 L .34247 .66748 L p .707 .577 .707 r
F P
0 g
s
.39736 .81056 m .36696 .3064 L .34924 .29721 L p .707 .577 .707 r
F P
0 g
s
.36696 .3064 m .39736 .81056 L .42701 .81723 L p .707 .577 .707 r
F P
0 g
s
.18718 .75329 m .1986 .71941 L .17894 .70432 L p .707 .577 .707 r
F P
0 g
s
.1986 .71941 m .18718 .75329 L .2131 .76725 L p .707 .577 .707 r
F P
0 g
s
.2221 .80614 m .22739 .78901 L .20125 .77575 L p .707 .577 .707 r
F P
0 g
s
.22739 .78901 m .2221 .80614 L .25195 .81691 L p .707 .577 .707 r
F P
0 g
s
.1708 .69435 m .17941 .64041 L .16709 .62906 L p .707 .577 .707 r
F P
0 g
s
.28789 .80701 m .2826 .82414 L .31104 .82711 L p .707 .577 .707 r
F P
0 g
s
.31104 .82711 m .31633 .80998 L .28789 .80701 L p .707 .577 .707 r
F P
0 g
s
.31288 .75615 m .30145 .79003 L .3248 .78878 L p .707 .577 .707 r
F P
0 g
s
.3248 .78878 m .33622 .7549 L .31288 .75615 L p .707 .577 .707 r
F P
0 g
s
.68901 .75226 m .67758 .78614 L .65791 .77105 L p .707 .577 .707 r
F P
0 g
s
.65791 .77105 m .66934 .73717 L .68901 .75226 L p .707 .577 .707 r
F P
0 g
s
.20125 .77575 m .19595 .79288 L .2221 .80614 L p .707 .577 .707 r
F P
0 g
s
.17894 .70432 m .16751 .73821 L .18718 .75329 L p .707 .577 .707 r
F P
0 g
s
.19595 .79288 m .20125 .77575 L .18138 .76129 L p .707 .577 .707 r
F P
0 g
s
.31633 .80998 m .31104 .82711 L .33449 .82554 L p .707 .577 .707 r
F P
0 g
s
.33449 .82554 m .33978 .80841 L .31633 .80998 L p .707 .577 .707 r
F P
0 g
s
.62253 .28625 m .65293 .7904 L .66294 .77903 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .63255 .27487 L .62253 .28625 L p .707 .577 .707 r
F P
0 g
s
.16709 .62906 m .15848 .68299 L .1708 .69435 L p .707 .577 .707 r
F P
0 g
s
.16751 .73821 m .17894 .70432 L .16745 .68959 L p .707 .577 .707 r
F P
0 g
s
.18138 .76129 m .17609 .77842 L .19595 .79288 L p .707 .577 .707 r
F P
0 g
s
.6923 .81551 m .68701 .83264 L .66714 .81818 L p .707 .577 .707 r
F P
0 g
s
.66714 .81818 m .67243 .80105 L .6923 .81551 L p .707 .577 .707 r
F P
0 g
s
.35878 .66088 m .35017 .71482 L .35732 .70569 L p .707 .577 .707 r
F P
0 g
s
.35732 .70569 m .36592 .65175 L .35878 .66088 L p .707 .577 .707 r
F P
0 g
s
.33622 .7549 m .3248 .78878 L .34092 .78293 L p .707 .577 .707 r
F P
0 g
s
.34092 .78293 m .35235 .74904 L .33622 .7549 L p .707 .577 .707 r
F P
0 g
s
.15848 .68299 m .16709 .62906 L .16437 .61829 L p .707 .577 .707 r
F P
0 g
s
.16745 .68959 m .15602 .72347 L .16751 .73821 L p .707 .577 .707 r
F P
0 g
s
.17609 .77842 m .18138 .76129 L .16973 .74706 L p .707 .577 .707 r
F P
0 g
s
.33978 .80841 m .33449 .82554 L .35065 .81957 L p .707 .577 .707 r
F P
0 g
s
.35065 .81957 m .35594 .80244 L .33978 .80841 L p .707 .577 .707 r
F P
0 g
s
.37964 .80137 m .34924 .29721 L .34519 .2864 L p .707 .577 .707 r
F P
0 g
s
.34924 .29721 m .37964 .80137 L .39736 .81056 L p .707 .577 .707 r
F P
0 g
s
.16973 .74706 m .16444 .76419 L .17609 .77842 L p .707 .577 .707 r
F P
0 g
s
.67243 .80105 m .66714 .81818 L .641 .80492 L p .707 .577 .707 r
F P
0 g
s
.15602 .72347 m .16745 .68959 L .16526 .67665 L p .707 .577 .707 r
F P
0 g
s
.16437 .61829 m .15576 .67223 L .15848 .68299 L p .707 .577 .707 r
F P
0 g
s
.35235 .74904 m .34092 .78293 L .34825 .77305 L p .707 .577 .707 r
F P
0 g
s
.34825 .77305 m .35967 .73916 L .35235 .74904 L p .707 .577 .707 r
F P
0 g
s
.36592 .65175 m .35732 .70569 L .35459 .69492 L p .707 .577 .707 r
F P
0 g
s
.35459 .69492 m .3632 .64098 L .36592 .65175 L p .707 .577 .707 r
F P
0 g
s
.15576 .67223 m .16437 .61829 L .17151 .60916 L p .707 .577 .707 r
F P
0 g
s
.16526 .67665 m .15383 .71053 L .15602 .72347 L p .707 .577 .707 r
F P
0 g
s
.66294 .77903 m .6595 .76983 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.63255 .27487 m .66227 .7679 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.66227 .7679 m .66294 .77903 L p .65669 .71831 L .707 .577 .707 r
F P
0 g
s
.62849 .26405 m .65889 .76821 L .64117 .75902 L p .707 .577 .707 r
F P
0 g
s
.64773 .68693 m .6518 .67484 L p .64766 .63832 L .707 .577 .707 r
F P
0 g
s
.65797 .75099 m .63255 .27487 L .6595 .76983 L .707 .577 .707 r
F
.62849 .26405 m .63255 .27487 L p .65503 .69598 L F P
0 g
s
.65889 .76821 m .65366 .6815 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.65366 .6815 m .62849 .26405 L p .65503 .69598 L .707 .577 .707 r
F P
0 g
s
.6473 .56513 m .64438 .58345 L p .65102 .63042 L .707 .577 .707 r
F P
0 g
s
.64438 .58345 m .6387 .61907 L .64862 .62821 L p .707 .577 .707 r
F P
0 g
s
.64862 .62821 m .65102 .63042 L p .64438 .58345 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .65915 .65305 L .6477 .63836 L p .707 .577 .707 r
F P
0 g
s
.6477 .63836 m .64766 .63832 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.65915 .65305 m .6518 .67484 L p .66739 .70201 L .707 .577 .707 r
F P
0 g
s
.6518 .67484 m .64773 .68693 L .65312 .69106 L p .707 .577 .707 r
F P
0 g
s
.65312 .69106 m .66739 .70201 L p .6518 .67484 L .707 .577 .707 r
F P
0 g
s
.6595 .76983 m .65889 .76821 L p .65797 .75099 L .707 .577 .707 r
F P
0 g
s
.16444 .76419 m .16973 .74706 L .16744 .73444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35594 .80244 m .35065 .81957 L .35794 .8098 L p .707 .577 .707 r
F P
0 g
s
.35794 .8098 m .36323 .79268 L .35594 .80244 L p .707 .577 .707 r
F P
0 g
s
.16744 .73444 m .16214 .75157 L .16444 .76419 L p .707 .577 .707 r
F P
0 g
s
.15383 .71053 m .16526 .67665 L .17259 .66677 L p .707 .577 .707 r
F P
0 g
s
.17151 .60916 m .16291 .66309 L .15576 .67223 L p .707 .577 .707 r
F P
0 g
s
.35967 .73916 m .34825 .77305 L .34606 .76011 L p .707 .577 .707 r
F P
0 g
s
.34606 .76011 m .35749 .72623 L .35967 .73916 L p .707 .577 .707 r
F P
0 g
s
.34519 .2864 m .37559 .79056 L .37964 .80137 L p .707 .577 .707 r
F P
0 g
s
.37559 .79056 m .34519 .2864 L .35521 .27502 L p .707 .577 .707 r
F P
0 g
s
.3632 .64098 m .35459 .69492 L .34227 .68356 L p .707 .577 .707 r
F P
0 g
s
.34227 .68356 m .35088 .62963 L .3632 .64098 L p .707 .577 .707 r
F P
0 g
s
.16291 .66309 m .17151 .60916 L .18782 .60256 L p .707 .577 .707 r
F P
0 g
s
.17259 .66677 m .16116 .70066 L .15383 .71053 L p .707 .577 .707 r
F P
0 g
s
.16214 .75157 m .16744 .73444 L .17473 .72467 L p .707 .577 .707 r
F P
0 g
s
.36323 .79268 m .35794 .8098 L .35565 .79718 L p .707 .577 .707 r
F P
0 g
s
.35565 .79718 m .36094 .78006 L .36323 .79268 L p .707 .577 .707 r
F P
0 g
s
.17473 .72467 m .16944 .7418 L .16214 .75157 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64117 .75902 m .61078 .25486 L .62849 .26405 L p .707 .577 .707 r
F P
0 g
s
.16116 .70066 m .17259 .66677 L .18871 .66092 L p .707 .577 .707 r
F P
0 g
s
.18782 .60256 m .17921 .65649 L .16291 .66309 L p .707 .577 .707 r
F P
0 g
s
.35749 .72623 m .34606 .76011 L .33457 .74538 L p .707 .577 .707 r
F P
0 g
s
.33457 .74538 m .346 .71149 L .35749 .72623 L p .707 .577 .707 r
F P
0 g
s
.35088 .62963 m .34227 .68356 L .32156 .67274 L p .707 .577 .707 r
F P
0 g
s
.32156 .67274 m .33017 .6188 L .35088 .62963 L p .707 .577 .707 r
F P
0 g
s
.17921 .65649 m .18782 .60256 L .2117 .59913 L p .707 .577 .707 r
F P
0 g
s
.18871 .66092 m .17729 .6948 L .16116 .70066 L p .707 .577 .707 r
F P
0 g
s
.16944 .7418 m .17473 .72467 L .19089 .71871 L p .707 .577 .707 r
F P
0 g
s
.36094 .78006 m .35565 .79718 L .344 .78295 L p .707 .577 .707 r
F P
0 g
s
.344 .78295 m .34929 .76582 L .36094 .78006 L p .707 .577 .707 r
F P
0 g
s
.3856 .77918 m .35521 .27502 L .3783 .26419 L p .707 .577 .707 r
F P
0 g
s
.35521 .27502 m .3856 .77918 L .37559 .79056 L p .707 .577 .707 r
F P
0 g
s
.19089 .71871 m .1856 .73584 L .16944 .7418 L p .707 .577 .707 r
F P
0 g
s
.17729 .6948 m .18871 .66092 L .21206 .65967 L p .707 .577 .707 r
F P
0 g
s
.2117 .59913 m .20309 .65307 L .17921 .65649 L p .707 .577 .707 r
F P
0 g
s
.33017 .6188 m .32156 .67274 L .29449 .6635 L p .707 .577 .707 r
F P
0 g
s
.29449 .6635 m .30309 .60956 L .33017 .6188 L p .707 .577 .707 r
F P
0 g
s
.20309 .65307 m .2117 .59913 L .24081 .59922 L p .707 .577 .707 r
F P
0 g
s
.346 .71149 m .33457 .74538 L .31491 .73029 L p .707 .577 .707 r
F P
0 g
s
.31491 .73029 m .32633 .69641 L .346 .71149 L p .707 .577 .707 r
F P
0 g
s
.61078 .25486 m .64117 .75902 L .61152 .75235 L p .707 .577 .707 r
F P
0 g
s
.61152 .75235 m .58112 .24819 L .61078 .25486 L p .707 .577 .707 r
F P
0 g
s
.21206 .65967 m .20063 .69355 L .17729 .6948 L p .707 .577 .707 r
F P
0 g
s
.1856 .73584 m .19089 .71871 L .21433 .71714 L p .707 .577 .707 r
F P
0 g
s
.30309 .60956 m .29449 .6635 L .26369 .65675 L p .707 .577 .707 r
F P
0 g
s
.26369 .65675 m .2723 .60282 L .30309 .60956 L p .707 .577 .707 r
F P
0 g
s
.2322 .65316 m .24081 .59922 L .2723 .60282 L p .707 .577 .707 r
F P
0 g
s
.24081 .59922 m .2322 .65316 L .20309 .65307 L p .707 .577 .707 r
F P
0 g
s
.34929 .76582 m .344 .78295 L .32413 .76849 L p .707 .577 .707 r
F P
0 g
s
.32413 .76849 m .32942 .75137 L .34929 .76582 L p .707 .577 .707 r
F P
0 g
s
.20063 .69355 m .21206 .65967 L .24034 .66314 L p .707 .577 .707 r
F P
0 g
s
.21433 .71714 m .20904 .73426 L .1856 .73584 L p .707 .577 .707 r
F P
0 g
s
.2723 .60282 m .26369 .65675 L .2322 .65316 L p .707 .577 .707 r
F P
0 g
s
.7296 .65723 m .7382 .60329 L .70741 .59655 L p .707 .577 .707 r
F P
0 g
s
.7382 .60329 m .7296 .65723 L .76109 .66082 L p .707 .577 .707 r
F P
0 g
s
.76109 .66082 m .7697 .60689 L .7382 .60329 L p .707 .577 .707 r
F P
0 g
s
.32633 .69641 m .31491 .73029 L .28899 .71634 L p .707 .577 .707 r
F P
0 g
s
.28899 .71634 m .30041 .68245 L .32633 .69641 L p .707 .577 .707 r
F P
0 g
s
.7697 .60689 m .76109 .66082 L .7902 .66091 L p .707 .577 .707 r
F P
0 g
s
.7902 .66091 m .79881 .60698 L .7697 .60689 L p .707 .577 .707 r
F P
0 g
s
.69881 .65048 m .70741 .59655 L .68033 .58731 L p .707 .577 .707 r
F P
0 g
s
.70741 .59655 m .69881 .65048 L .7296 .65723 L p .707 .577 .707 r
F P
0 g
s
.3783 .26419 m .4087 .76835 L .3856 .77918 L p .707 .577 .707 r
F P
0 g
s
.4087 .76835 m .3783 .26419 L .41222 .25496 L p .707 .577 .707 r
F P
0 g
s
.24034 .66314 m .22891 .69702 L .20063 .69355 L p .707 .577 .707 r
F P
0 g
s
.22891 .69702 m .24034 .66314 L .27078 .67099 L p .707 .577 .707 r
F P
0 g
s
.20904 .73426 m .21433 .71714 L .24277 .72011 L p .707 .577 .707 r
F P
0 g
s
.30041 .68245 m .28899 .71634 L .25936 .70487 L p .707 .577 .707 r
F P
0 g
s
.25936 .70487 m .27078 .67099 L .30041 .68245 L p .707 .577 .707 r
F P
0 g
s
.32942 .75137 m .32413 .76849 L .29799 .75523 L p .707 .577 .707 r
F P
0 g
s
.29799 .75523 m .30328 .7381 L .32942 .75137 L p .707 .577 .707 r
F P
0 g
s
.27078 .67099 m .25936 .70487 L .22891 .69702 L p .707 .577 .707 r
F P
0 g
s
.79881 .60698 m .7902 .66091 L .81408 .65749 L p .707 .577 .707 r
F P
0 g
s
.81408 .65749 m .82268 .60356 L .79881 .60698 L p .707 .577 .707 r
F P
0 g
s
.24277 .72011 m .23748 .73724 L .20904 .73426 L p .707 .577 .707 r
F P
0 g
s
.67173 .64125 m .68033 .58731 L .65962 .57649 L p .707 .577 .707 r
F P
0 g
s
.68033 .58731 m .67173 .64125 L .69881 .65048 L p .707 .577 .707 r
F P
0 g
s
.58112 .24819 m .61152 .75235 L .57284 .74885 L p .707 .577 .707 r
F P
0 g
s
.57284 .74885 m .54244 .24469 L .58112 .24819 L p .707 .577 .707 r
F P
0 g
s
.23748 .73724 m .24277 .72011 L .27342 .72733 L p .707 .577 .707 r
F P
0 g
s
.72294 .72743 m .73437 .69355 L .70473 .68209 L p .707 .577 .707 r
F P
0 g
s
.73437 .69355 m .72294 .72743 L .75339 .73529 L p .707 .577 .707 r
F P
0 g
s
.75339 .73529 m .76481 .70141 L .73437 .69355 L p .707 .577 .707 r
F P
0 g
s
.30328 .7381 m .29799 .75523 L .26813 .74446 L p .707 .577 .707 r
F P
0 g
s
.26813 .74446 m .27342 .72733 L .30328 .7381 L p .707 .577 .707 r
F P
0 g
s
.69331 .71597 m .70473 .68209 L .67882 .66813 L p .707 .577 .707 r
F P
0 g
s
.70473 .68209 m .69331 .71597 L .72294 .72743 L p .707 .577 .707 r
F P
0 g
s
.27342 .72733 m .26813 .74446 L .23748 .73724 L p .707 .577 .707 r
F P
0 g
s
.76481 .70141 m .75339 .73529 L .78167 .73876 L p .707 .577 .707 r
F P
0 g
s
.78167 .73876 m .79309 .70487 L .76481 .70141 L p .707 .577 .707 r
F P
0 g
s
.44262 .75912 m .41222 .25496 L .45364 .24826 L p .707 .577 .707 r
F P
0 g
s
.41222 .25496 m .44262 .75912 L .4087 .76835 L p .707 .577 .707 r
F P
0 g
s
.65962 .57649 m .65102 .63042 L .67173 .64125 L p .707 .577 .707 r
F P
0 g
s
.82268 .60356 m .81408 .65749 L .83039 .65089 L p .707 .577 .707 r
F P
0 g
s
.83039 .65089 m .83899 .59696 L .82268 .60356 L p .707 .577 .707 r
F P
0 g
s
.65102 .63042 m .65962 .57649 L .6473 .56513 L p .707 .577 .707 r
F P
0 g
s
.66739 .70201 m .67882 .66813 L .65915 .65305 L p .707 .577 .707 r
F P
0 g
s
.67882 .66813 m .66739 .70201 L .69331 .71597 L p .707 .577 .707 r
F P
0 g
s
.73217 .77456 m .73746 .75743 L .7076 .74666 L p .707 .577 .707 r
F P
0 g
s
.73746 .75743 m .73217 .77456 L .76281 .78179 L p .707 .577 .707 r
F P
0 g
s
.76281 .78179 m .7681 .76466 L .73746 .75743 L p .707 .577 .707 r
F P
0 g
s
.54244 .24469 m .57284 .74885 L .52891 .74888 L p .707 .577 .707 r
F P
0 g
s
.52891 .74888 m .49851 .24472 L .54244 .24469 L p .707 .577 .707 r
F P
0 g
s
.79309 .70487 m .78167 .73876 L .80501 .7375 L p .707 .577 .707 r
F P
0 g
s
.80501 .7375 m .81644 .70362 L .79309 .70487 L p .707 .577 .707 r
F P
0 g
s
.70231 .76379 m .7076 .74666 L .68146 .7334 L p .707 .577 .707 r
F P
0 g
s
.7076 .74666 m .70231 .76379 L .73217 .77456 L p .707 .577 .707 r
F P
0 g
s
.7681 .76466 m .76281 .78179 L .79125 .78476 L p .707 .577 .707 r
F P
0 g
s
.79125 .78476 m .79654 .76763 L .7681 .76466 L p .707 .577 .707 r
F P
0 g
s
.48404 .75242 m .45364 .24826 L .49851 .24472 L p .707 .577 .707 r
F P
0 g
s
.45364 .24826 m .48404 .75242 L .44262 .75912 L p .707 .577 .707 r
F P
0 g
s
.68146 .7334 m .67617 .75053 L .70231 .76379 L p .707 .577 .707 r
F P
0 g
s
.49851 .24472 m .52891 .74888 L .48404 .75242 L p .707 .577 .707 r
F P
0 g
s
.67617 .75053 m .68146 .7334 L .66159 .71894 L p .707 .577 .707 r
F P
0 g
s
.79654 .76763 m .79125 .78476 L .8147 .78319 L p .707 .577 .707 r
F P
0 g
s
.8147 .78319 m .81999 .76606 L .79654 .76763 L p .707 .577 .707 r
F P
0 g
s
.83899 .59696 m .83039 .65089 L .83753 .64176 L p .707 .577 .707 r
F P
0 g
s
.83753 .64176 m .84614 .58782 L .83899 .59696 L p .707 .577 .707 r
F P
0 g
s
.66159 .71894 m .6563 .73607 L .67617 .75053 L p .707 .577 .707 r
F P
0 g
s
.6387 .61907 m .6473 .56513 L .64458 .55436 L p .707 .577 .707 r
F P
0 g
s
.81644 .70362 m .80501 .7375 L .82114 .73165 L p .707 .577 .707 r
F P
0 g
s
.82114 .73165 m .83256 .69777 L .81644 .70362 L p .707 .577 .707 r
F P
0 g
s
.64766 .63832 m .63624 .6722 L .64773 .68693 L p .707 .577 .707 r
F P
0 g
s
.6563 .73607 m .66159 .71894 L .64994 .70471 L p .707 .577 .707 r
F P
0 g
s
.81999 .76606 m .8147 .78319 L .83086 .77722 L p .707 .577 .707 r
F P
0 g
s
.83086 .77722 m .83615 .76009 L .81999 .76606 L p .707 .577 .707 r
F P
0 g
s
.64458 .55436 m .63598 .6083 L .6387 .61907 L p .707 .577 .707 r
F P
0 g
s
.64994 .70471 m .64465 .72184 L .6563 .73607 L p .707 .577 .707 r
F P
0 g
s
.63624 .6722 m .64766 .63832 L .64547 .62538 L p .707 .577 .707 r
F P
0 g
s
.84614 .58782 m .83753 .64176 L .83481 .63099 L p .707 .577 .707 r
F P
0 g
s
.83481 .63099 m .84341 .57705 L .84614 .58782 L p .707 .577 .707 r
F P
0 g
s
.83256 .69777 m .82114 .73165 L .82846 .72177 L p .707 .577 .707 r
F P
0 g
s
.82846 .72177 m .83989 .68789 L .83256 .69777 L p .707 .577 .707 r
F P
0 g
s
.63598 .6083 m .64458 .55436 L .65172 .54523 L p .707 .577 .707 r
F P
0 g
s
.64547 .62538 m .63405 .65926 L .63624 .6722 L p .707 .577 .707 r
F P
0 g
s
.64465 .72184 m .64994 .70471 L .64765 .69209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83615 .76009 m .83086 .77722 L .83815 .76745 L p .707 .577 .707 r
F P
0 g
s
.83815 .76745 m .84345 .75033 L .83615 .76009 L p .707 .577 .707 r
F P
0 g
s
.64765 .69209 m .64236 .70922 L .64465 .72184 L p .707 .577 .707 r
F P
0 g
s
.65172 .54523 m .64312 .59917 L .63598 .6083 L p .707 .577 .707 r
F P
0 g
s
.63405 .65926 m .64547 .62538 L .6528 .6155 L p .707 .577 .707 r
F P
0 g
s
.84341 .57705 m .83481 .63099 L .82249 .61964 L p .707 .577 .707 r
F P
0 g
s
.82249 .61964 m .83109 .5657 L .84341 .57705 L p .707 .577 .707 r
F P
0 g
s
.83989 .68789 m .82846 .72177 L .82627 .70883 L p .707 .577 .707 r
F P
0 g
s
.82627 .70883 m .8377 .67495 L .83989 .68789 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64312 .59917 m .65172 .54523 L .66803 .53863 L p .707 .577 .707 r
F P
0 g
s
.6528 .6155 m .64137 .64938 L .63405 .65926 L p .707 .577 .707 r
F P
0 g
s
.38659 .62912 m .39519 .57518 L .3644 .56844 L p .707 .577 .707 r
F P
0 g
s
.39519 .57518 m .38659 .62912 L .41808 .63271 L p .707 .577 .707 r
F P
0 g
s
.41808 .63271 m .42669 .57878 L .39519 .57518 L p .707 .577 .707 r
F P
0 g
s
.64236 .70922 m .64765 .69209 L .65494 .68232 L p .707 .577 .707 r
F P
0 g
s
.42669 .57878 m .41808 .63271 L .44719 .6328 L p .707 .577 .707 r
F P
0 g
s
.44719 .6328 m .4558 .57887 L .42669 .57878 L p .707 .577 .707 r
F P
0 g
s
.3558 .62237 m .3644 .56844 L .33732 .5592 L p .707 .577 .707 r
F P
0 g
s
.3644 .56844 m .3558 .62237 L .38659 .62912 L p .707 .577 .707 r
F P
0 g
s
.84345 .75033 m .83815 .76745 L .83586 .75483 L p .707 .577 .707 r
F P
0 g
s
.83586 .75483 m .84115 .73771 L .84345 .75033 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65494 .68232 m .64965 .69945 L .64236 .70922 L p .707 .577 .707 r
F P
0 g
s
.66803 .53863 m .65943 .59257 L .64312 .59917 L p .707 .577 .707 r
F P
0 g
s
.64137 .64938 m .6528 .6155 L .66893 .60964 L p .707 .577 .707 r
F P
0 g
s
.4558 .57887 m .44719 .6328 L .47107 .62938 L p .707 .577 .707 r
F P
0 g
s
.47107 .62938 m .47967 .57544 L .4558 .57887 L p .707 .577 .707 r
F P
0 g
s
.83109 .5657 m .82249 .61964 L .80178 .60881 L p .707 .577 .707 r
F P
0 g
s
.80178 .60881 m .81038 .55488 L .83109 .5657 L p .707 .577 .707 r
F P
0 g
s
.32872 .61313 m .33732 .5592 L .31661 .54837 L p .707 .577 .707 r
F P
0 g
s
.33732 .5592 m .32872 .61313 L .3558 .62237 L p .707 .577 .707 r
F P
0 g
s
.8377 .67495 m .82627 .70883 L .81479 .6941 L p .707 .577 .707 r
F P
0 g
s
.81479 .6941 m .82621 .66022 L .8377 .67495 L p .707 .577 .707 r
F P
0 g
s
.65943 .59257 m .66803 .53863 L .69191 .53521 L p .707 .577 .707 r
F P
0 g
s
.37993 .68667 m .39136 .65279 L .36172 .64133 L p .707 .577 .707 r
F P
0 g
s
.39136 .65279 m .37993 .68667 L .41038 .69452 L p .707 .577 .707 r
F P
0 g
s
.41038 .69452 m .4218 .66064 L .39136 .65279 L p .707 .577 .707 r
F P
0 g
s
.3503 .67521 m .36172 .64133 L .33581 .62737 L p .707 .577 .707 r
F P
0 g
s
.36172 .64133 m .3503 .67521 L .37993 .68667 L p .707 .577 .707 r
F P
0 g
s
.66893 .60964 m .6575 .64353 L .64137 .64938 L p .707 .577 .707 r
F P
0 g
s
.4218 .66064 m .41038 .69452 L .43866 .69799 L p .707 .577 .707 r
F P
0 g
s
.43866 .69799 m .45008 .66411 L .4218 .66064 L p .707 .577 .707 r
F P
0 g
s
.64965 .69945 m .65494 .68232 L .6711 .67636 L p .707 .577 .707 r
F P
0 g
s
.84115 .73771 m .83586 .75483 L .82421 .7406 L p .707 .577 .707 r
F P
0 g
s
.82421 .7406 m .8295 .72347 L .84115 .73771 L p .707 .577 .707 r
F P
0 g
s
.38916 .72487 m .39445 .70775 L .36459 .69697 L p .707 .577 .707 r
F P
0 g
s
.39445 .70775 m .38916 .72487 L .4198 .7321 L p .707 .577 .707 r
F P
0 g
s
.4198 .7321 m .42509 .71497 L .39445 .70775 L p .707 .577 .707 r
F P
0 g
s
.6711 .67636 m .66581 .69349 L .64965 .69945 L p .707 .577 .707 r
F P
0 g
s
.31661 .54837 m .30801 .60231 L .32872 .61313 L p .707 .577 .707 r
F P
0 g
s
.47967 .57544 m .47107 .62938 L .48738 .62278 L p .707 .577 .707 r
F P
0 g
s
.48738 .62278 m .49598 .56884 L .47967 .57544 L p .707 .577 .707 r
F P
0 g
s
.69191 .53521 m .68331 .58914 L .65943 .59257 L p .707 .577 .707 r
F P
0 g
s
.32438 .66125 m .33581 .62737 L .31614 .61229 L p .707 .577 .707 r
F P
0 g
s
.33581 .62737 m .32438 .66125 L .3503 .67521 L p .707 .577 .707 r
F P
0 g
s
.81038 .55488 m .80178 .60881 L .7747 .59957 L p .707 .577 .707 r
F P
0 g
s
.7747 .59957 m .78331 .54564 L .81038 .55488 L p .707 .577 .707 r
F P
0 g
s
.6575 .64353 m .66893 .60964 L .69227 .60839 L p .707 .577 .707 r
F P
0 g
s
.3593 .7141 m .36459 .69697 L .33845 .68371 L p .707 .577 .707 r
F P
0 g
s
.36459 .69697 m .3593 .7141 L .38916 .72487 L p .707 .577 .707 r
F P
0 g
s
.30801 .60231 m .31661 .54837 L .30429 .53702 L p .707 .577 .707 r
F P
0 g
s
.68331 .58914 m .69191 .53521 L .72102 .5353 L p .707 .577 .707 r
F P
0 g
s
.42509 .71497 m .4198 .7321 L .44824 .73507 L p .707 .577 .707 r
F P
0 g
s
.44824 .73507 m .45353 .71794 L .42509 .71497 L p .707 .577 .707 r
F P
0 g
s
.45008 .66411 m .43866 .69799 L .462 .69674 L p .707 .577 .707 r
F P
0 g
s
.462 .69674 m .47343 .66286 L .45008 .66411 L p .707 .577 .707 r
F P
0 g
s
.82621 .66022 m .81479 .6941 L .79512 .67902 L p .707 .577 .707 r
F P
0 g
s
.79512 .67902 m .80654 .64514 L .82621 .66022 L p .707 .577 .707 r
F P
0 g
s
.33845 .68371 m .33316 .70084 L .3593 .7141 L p .707 .577 .707 r
F P
0 g
s
.31614 .61229 m .30472 .64617 L .32438 .66125 L p .707 .577 .707 r
F P
0 g
s
.78331 .54564 m .7747 .59957 L .74391 .59283 L p .707 .577 .707 r
F P
0 g
s
.74391 .59283 m .75251 .53889 L .78331 .54564 L p .707 .577 .707 r
F P
0 g
s
.33316 .70084 m .33845 .68371 L .31858 .66926 L p .707 .577 .707 r
F P
0 g
s
.69227 .60839 m .68084 .64227 L .6575 .64353 L p .707 .577 .707 r
F P
0 g
s
.71242 .58923 m .72102 .5353 L .75251 .53889 L p .707 .577 .707 r
F P
0 g
s
.72102 .5353 m .71242 .58923 L .68331 .58914 L p .707 .577 .707 r
F P
0 g
s
.45353 .71794 m .44824 .73507 L .47169 .7335 L p .707 .577 .707 r
F P
0 g
s
.47169 .7335 m .47698 .71637 L .45353 .71794 L p .707 .577 .707 r
F P
0 g
s
.66581 .69349 m .6711 .67636 L .69455 .67479 L p .707 .577 .707 r
F P
0 g
s
.75251 .53889 m .74391 .59283 L .71242 .58923 L p .707 .577 .707 r
F P
0 g
s
.30429 .53702 m .29569 .59096 L .30801 .60231 L p .707 .577 .707 r
F P
0 g
s
.30472 .64617 m .31614 .61229 L .30465 .59755 L p .707 .577 .707 r
F P
0 g
s
.31858 .66926 m .31329 .68638 L .33316 .70084 L p .707 .577 .707 r
F P
0 g
s
.68084 .64227 m .69227 .60839 L .72055 .61186 L p .707 .577 .707 r
F P
0 g
s
.8295 .72347 m .82421 .7406 L .80434 .72614 L p .707 .577 .707 r
F P
0 g
s
.80434 .72614 m .80964 .70902 L .8295 .72347 L p .707 .577 .707 r
F P
0 g
s
.69455 .67479 m .68926 .69191 L .66581 .69349 L p .707 .577 .707 r
F P
0 g
s
.49598 .56884 m .48738 .62278 L .49452 .61365 L p .707 .577 .707 r
F P
0 g
s
.49452 .61365 m .50313 .55971 L .49598 .56884 L p .707 .577 .707 r
F P
0 g
s
.47343 .66286 m .462 .69674 L .47813 .69089 L p .707 .577 .707 r
F P
0 g
s
.47813 .69089 m .48955 .65701 L .47343 .66286 L p .707 .577 .707 r
F P
0 g
s
.80654 .64514 m .79512 .67902 L .7692 .66506 L p .707 .577 .707 r
F P
0 g
s
.7692 .66506 m .78063 .63118 L .80654 .64514 L p .707 .577 .707 r
F P
0 g
s
.29569 .59096 m .30429 .53702 L .30157 .52625 L p .707 .577 .707 r
F P
0 g
s
.30465 .59755 m .29323 .63143 L .30472 .64617 L p .707 .577 .707 r
F P
0 g
s
.31329 .68638 m .31858 .66926 L .30693 .65502 L p .707 .577 .707 r
F P
0 g
s
.72055 .61186 m .70912 .64574 L .68084 .64227 L p .707 .577 .707 r
F P
0 g
s
.70912 .64574 m .72055 .61186 L .751 .61971 L p .707 .577 .707 r
F P
0 g
s
.78063 .63118 m .7692 .66506 L .73957 .65359 L p .707 .577 .707 r
F P
0 g
s
.73957 .65359 m .751 .61971 L .78063 .63118 L p .707 .577 .707 r
F P
0 g
s
.47698 .71637 m .47169 .7335 L .48785 .72753 L p .707 .577 .707 r
F P
0 g
s
.48785 .72753 m .49314 .71041 L .47698 .71637 L p .707 .577 .707 r
F P
0 g
s
.68926 .69191 m .69455 .67479 L .72299 .67776 L p .707 .577 .707 r
F P
0 g
s
.30693 .65502 m .30164 .67215 L .31329 .68638 L p .707 .577 .707 r
F P
0 g
s
.751 .61971 m .73957 .65359 L .70912 .64574 L p .707 .577 .707 r
F P
0 g
s
.80964 .70902 m .80434 .72614 L .7782 .71288 L p .707 .577 .707 r
F P
0 g
s
.7782 .71288 m .78349 .69575 L .80964 .70902 L p .707 .577 .707 r
F P
0 g
s
.29323 .63143 m .30465 .59755 L .30246 .58461 L p .707 .577 .707 r
F P
0 g
s
.72299 .67776 m .7177 .69489 L .68926 .69191 L p .707 .577 .707 r
F P
0 g
s
.30157 .52625 m .29296 .58019 L .29569 .59096 L p .707 .577 .707 r
F P
0 g
s
.48955 .65701 m .47813 .69089 L .48545 .68101 L p .707 .577 .707 r
F P
0 g
s
.48545 .68101 m .49688 .64713 L .48955 .65701 L p .707 .577 .707 r
F P
0 g
s
.7177 .69489 m .72299 .67776 L .75364 .68498 L p .707 .577 .707 r
F P
0 g
s
.50313 .55971 m .49452 .61365 L .4918 .60288 L p .707 .577 .707 r
F P
0 g
s
.4918 .60288 m .5004 .54894 L .50313 .55971 L p .707 .577 .707 r
F P
0 g
s
.78349 .69575 m .7782 .71288 L .74835 .70211 L p .707 .577 .707 r
F P
0 g
s
.74835 .70211 m .75364 .68498 L .78349 .69575 L p .707 .577 .707 r
F P
0 g
s
.29296 .58019 m .30157 .52625 L .30871 .51712 L p .707 .577 .707 r
F P
0 g
s
.75364 .68498 m .74835 .70211 L .7177 .69489 L p .707 .577 .707 r
F P
0 g
s
.30246 .58461 m .29104 .6185 L .29323 .63143 L p .707 .577 .707 r
F P
0 g
s
.30164 .67215 m .30693 .65502 L .30464 .6424 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49314 .71041 m .48785 .72753 L .49514 .71776 L p .707 .577 .707 r
F P
0 g
s
.49514 .71776 m .50043 .70064 L .49314 .71041 L p .707 .577 .707 r
F P
0 g
s
.30464 .6424 m .29935 .65953 L .30164 .67215 L p .707 .577 .707 r
F P
0 g
s
.29104 .6185 m .30246 .58461 L .30979 .57474 L p .707 .577 .707 r
F P
0 g
s
.30871 .51712 m .30011 .57105 L .29296 .58019 L p .707 .577 .707 r
F P
0 g
s
.49688 .64713 m .48545 .68101 L .48326 .66807 L p .707 .577 .707 r
F P
0 g
s
.48326 .66807 m .49469 .63419 L .49688 .64713 L p .707 .577 .707 r
F P
0 g
s
.5004 .54894 m .4918 .60288 L .47948 .59152 L p .707 .577 .707 r
F P
0 g
s
.47948 .59152 m .48808 .53759 L .5004 .54894 L p .707 .577 .707 r
F P
0 g
s
.30011 .57105 m .30871 .51712 L .32502 .51052 L p .707 .577 .707 r
F P
0 g
s
.30979 .57474 m .29836 .60862 L .29104 .6185 L p .707 .577 .707 r
F P
0 g
s
.29935 .65953 m .30464 .6424 L .31193 .63263 L p .707 .577 .707 r
F P
0 g
s
.50043 .70064 m .49514 .71776 L .49285 .70515 L p .707 .577 .707 r
F P
0 g
s
.49285 .70515 m .49814 .68802 L .50043 .70064 L p .707 .577 .707 r
F P
0 g
s
.31193 .63263 m .30664 .64976 L .29935 .65953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29836 .60862 m .30979 .57474 L .32592 .56888 L p .707 .577 .707 r
F P
0 g
s
.32502 .51052 m .31642 .56445 L .30011 .57105 L p .707 .577 .707 r
F P
0 g
s
.49469 .63419 m .48326 .66807 L .47177 .65334 L p .707 .577 .707 r
F P
0 g
s
.47177 .65334 m .4832 .61946 L .49469 .63419 L p .707 .577 .707 r
F P
0 g
s
.48808 .53759 m .47948 .59152 L .45877 .5807 L p .707 .577 .707 r
F P
0 g
s
.45877 .5807 m .46737 .52676 L .48808 .53759 L p .707 .577 .707 r
F P
0 g
s
.31642 .56445 m .32502 .51052 L .3489 .50709 L p .707 .577 .707 r
F P
0 g
s
.32592 .56888 m .31449 .60276 L .29836 .60862 L p .707 .577 .707 r
F P
0 g
s
.30664 .64976 m .31193 .63263 L .32809 .62667 L p .707 .577 .707 r
F P
0 g
s
.49814 .68802 m .49285 .70515 L .4812 .69091 L p .707 .577 .707 r
F P
0 g
s
.4812 .69091 m .48649 .67378 L .49814 .68802 L p .707 .577 .707 r
F P
0 g
s
.32809 .62667 m .3228 .6438 L .30664 .64976 L p .707 .577 .707 r
F P
0 g
s
.31449 .60276 m .32592 .56888 L .34926 .56763 L p .707 .577 .707 r
F P
0 g
s
.3489 .50709 m .34029 .56103 L .31642 .56445 L p .707 .577 .707 r
F P
0 g
s
.46737 .52676 m .45877 .5807 L .43169 .57146 L p .707 .577 .707 r
F P
0 g
s
.43169 .57146 m .44029 .51752 L .46737 .52676 L p .707 .577 .707 r
F P
0 g
s
.34029 .56103 m .3489 .50709 L .37801 .50718 L p .707 .577 .707 r
F P
0 g
s
.4832 .61946 m .47177 .65334 L .45211 .63825 L p .707 .577 .707 r
F P
0 g
s
.45211 .63825 m .46353 .60437 L .4832 .61946 L p .707 .577 .707 r
F P
0 g
s
.34926 .56763 m .33783 .60151 L .31449 .60276 L p .707 .577 .707 r
F P
0 g
s
.3228 .6438 m .32809 .62667 L .35154 .6251 L p .707 .577 .707 r
F P
0 g
s
.44029 .51752 m .43169 .57146 L .4009 .56472 L p .707 .577 .707 r
F P
0 g
s
.4009 .56472 m .4095 .51078 L .44029 .51752 L p .707 .577 .707 r
F P
0 g
s
.3694 .56112 m .37801 .50718 L .4095 .51078 L p .707 .577 .707 r
F P
0 g
s
.37801 .50718 m .3694 .56112 L .34029 .56103 L p .707 .577 .707 r
F P
0 g
s
.48649 .67378 m .4812 .69091 L .46133 .67645 L p .707 .577 .707 r
F P
0 g
s
.46133 .67645 m .46662 .65933 L .48649 .67378 L p .707 .577 .707 r
F P
0 g
s
.33783 .60151 m .34926 .56763 L .37754 .5711 L p .707 .577 .707 r
F P
0 g
s
.35154 .6251 m .34625 .64223 L .3228 .6438 L p .707 .577 .707 r
F P
0 g
s
.4095 .51078 m .4009 .56472 L .3694 .56112 L p .707 .577 .707 r
F P
0 g
s
.46353 .60437 m .45211 .63825 L .42619 .6243 L p .707 .577 .707 r
F P
0 g
s
.42619 .6243 m .43762 .59042 L .46353 .60437 L p .707 .577 .707 r
F P
0 g
s
.37754 .5711 m .36611 .60498 L .33783 .60151 L p .707 .577 .707 r
F P
0 g
s
.36611 .60498 m .37754 .5711 L .40799 .57895 L p .707 .577 .707 r
F P
0 g
s
.34625 .64223 m .35154 .6251 L .37998 .62807 L p .707 .577 .707 r
F P
0 g
s
.43762 .59042 m .42619 .6243 L .39656 .61283 L p .707 .577 .707 r
F P
0 g
s
.39656 .61283 m .40799 .57895 L .43762 .59042 L p .707 .577 .707 r
F P
0 g
s
.46662 .65933 m .46133 .67645 L .43519 .66319 L p .707 .577 .707 r
F P
0 g
s
.43519 .66319 m .44048 .64606 L .46662 .65933 L p .707 .577 .707 r
F P
0 g
s
.40799 .57895 m .39656 .61283 L .36611 .60498 L p .707 .577 .707 r
F P
0 g
s
.37998 .62807 m .37469 .6452 L .34625 .64223 L p .707 .577 .707 r
F P
0 g
s
.37469 .6452 m .37998 .62807 L .41063 .63529 L p .707 .577 .707 r
F P
0 g
s
.44048 .64606 m .43519 .66319 L .40534 .65242 L p .707 .577 .707 r
F P
0 g
s
.40534 .65242 m .41063 .63529 L .44048 .64606 L p .707 .577 .707 r
F P
0 g
s
.41063 .63529 m .40534 .65242 L .37469 .6452 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Qgoo6@00OGoo001nOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Qoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH3001]Ool006eoo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006]oo`00JWoo0`0025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0J7oo001XOol200000eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIZOol006Ioo`8000=JEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Moo`00I7oo0P001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<007ooOol0Igoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUIYOol0
06=oo`8000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF00001UYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYFJGoo001ROol00`00FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUIYOol0069oo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HWoo00<005YF
00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Igoo001ROol00`00FUH00007FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol006=oo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001XOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001SOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF
001JEVQoo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol006=oo`03
001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJ7oo001SOol00`00FUH00007FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01P00FUIJEUYF001JEVQoo`00Hgoo00<005YF00001eYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo
001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00I7oo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006Aoo`03001JEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYFFUH005YFIgoo001TOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001J
EVMoo`00I7oo00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJ
EP00FUIVOol006Eoo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001UOol0
0`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00H7oo40002EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00
Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Eoo`00FGoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIUOol0
05Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF
FUH005YFIGoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVEoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001TOol005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000I7oo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Qooa0004aoo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0017oo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00AGoo
001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000mOol005Aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`03001JEP0000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00=JEP<003Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF0`00=7oo001DOol20003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000bOol005Aoo`8000=J
EP@0009JEP03001JEP0000<00005Ool005YFFUH00003FUH70006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<7oo001COol01000FUH005YF0`000UYF3P00
15YF1@0000=JEP0000000P000UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP8002moo`00Dgoo00@005YF0000009JEP@000IJEP04001JEUYFFUH<0005FUH40006
FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool005=oo`<0009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEP0000L000EJEP04001JEP000004FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo0P000UYF0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00L005YFFUIJEP00FUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Goo001COol00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP06FUH20005FUH01`00FUIJEUYF001JEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000;Goo001COol01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00@005YF000000=JEP07001JEUYF
FUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP04001JEUYFFUH200000eYF001JEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000/Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP<00003FUH005YF00EJEP8000=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEP000003FUH50002FUH00`00FUH000030008Ool70006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJ
EP07001JEP00FUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YF000005YF00<000IJEP03001JEUYF00=JEP@000Ioo`<0009oo`@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000iOol@000;Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJ
EP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000300000goo000000030005Ool4
0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000goo00<005YF00000UYF300015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qo
o`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool0039oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH00000008000=JEP03001JEUYF00AJEPH0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP8000IJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEPD00003FUH0000000X00003FUH005YF00EJEP04001JEUYFFUH2000]Ool0031oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP06001o
o`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00P000eYF00<005YF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
00=JEP00FUH00UYF00<005YFFUH0300025YF0`001UYF00<005YFFUH01EYF0P001UYF00@005YFFUIJ
EP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`0015YF1P001UYF00<005YFFUH01UYF100025YF00<005YFFUH01EYF00@005YFFUIJEP80
009JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000EJEP<0
0003FUH005YF00AJEP04001JEUYFFUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH0
0`00FUIJEP02FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEPD00003Ool000000080009JEP03001JEUYF
00IJEP04001JEUYFFUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0
05YF00=JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEP@000=oo`@000IJEP03001JEUYF
00EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP80009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP0002eoo`00;Woo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00<005YFFUH00UYF0P0000=JEP0000002@000UYF00<005YFFUH01UYF00@005YF000000MJEP03001J
EUYF00EJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP000080
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000QJEP03001J
EUYF00=JEP03001JEP00009JEP03001JEP0002eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01P000UYF00<0
05YFFUH00UYF2P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP03001JEP0000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF
00<00003FUH007oo02aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEP0000l000=JEP03001JEUYF00AJEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP030007FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1000
0eYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP8000AJEP04001J
EUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200001EYF001JEUYF
00000eYF1`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00L005YF
FUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000002FUH50007FUH70006FUH00`00FUIJEP06FUH20005
FUH01@00FUIJEUYF00000eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF0`000UYF2`0000=JEP0000001@001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=J
EP00FUH00eYF0P00;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH6
0002FUH00`00FUIJEP07FUH30004FUH30004FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH500000eYF001JEP03FUH30002Ool50003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH30004FUH2000_Ool002eoo`8000=JEP04001JEUYFFUH@0004FUH00`00FUIJ
EP07FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70007FUH01000FUIJEUYF0P0015YF00D0
05YFFUIJEP00009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP<000AJEP05001JEUYFFUH00002FUH00`00Oomoo`04Ool40002FUH40008FUH00`00FUIJEP06FUH0
0`00FUIJEP02000015YF00000000<7oo000]Ool20003FUH40002FUH00`00FUH000030008Ool70006
FUH00`00FUH0000200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00005
0005FUH00`00FUIJEP03FUH20003FUH01P00FUIJEP00FUH000MJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP<000AJEP800003FUH005YF00=JEP8000Qoo`P000IJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo035oo`00;7oo00@005YF001JEP<0009JEPh000Aoo`D00003Ool0
00000080009JEP04001JEP00FUH20002FUH20007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50000
0eYF001JEP07FUH01000FUIJEP000UYF00<005YF00001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00P001UYF00<007ooOol037oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH015YF00<007ooOol0<7oo000/Ool01000FUH000000UYF10001UYF00@0
05YFFUIJEP`000Eoo`H00004FUH005YFFUH20007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP020008FUH600000eYF001JEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH20004FUH01@00FUIJEUYF00001UYF0P0047oo0P0000=JEP00FUH01eYF00<005YFFUH015YF0P00
<Goo000/Ool30002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH000070007Ool20002
FUH01000FUH005YF0P001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF
00P005YFFUH005YF001JEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00002Goo0`001Goo0P0025YF00<005YFFUH0
0eYF00@005YFFUH0031oo`00;7oo0P000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF300015YF0P000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH00UYF0`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFFUH015YF0P000UYF00D005YFFUIJEP0000Moo`D000Ioo`8000EJ
EP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEUYF008000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000002FUH01000FUIJEP0015YF0`0015YF0`00
2EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH000060007Ool50008Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02aoo`05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30003FUH01@00FUIJEUYF00000UYF00H005YFFUIJEP00FUH20008FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH01UYF10000eYF00@005YFFUIJEP`000Yoo`<000IJEP03001JEUYF
00=JEP03001oogoo02aoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF0P000eYF00<005YF000015YF0P0000=JEP00FUH00UYF0`001EYF00<005YF
00000P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH010003Goo00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH20006FUH20003FUH200001goo00000000FUH005YF00D0009JEP03001JEUYF00EJEP03
001JEUYF00AJEP<0009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUH00000FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
10002Woo0P0015YF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP08FUH300000eYF001JEP05FUH300001UYF001J
EP00Ool0009JEPP0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000:Ool01@00FUIJEUYF0000
0eYF00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00@005YFFUIJEP800004FUH007oo0002FUH00`00
FUIJEP0500000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF
1P0015YF00<005YFFUH01eYF00<005YFFUH00UYF0`0027oo0`0015YF00<005YF0000;Woo000/Ool0
0`00FUH00002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30002FUH0
0`00FUIJEP03FUH200001Goo001JEUYF00000eYF2@0015YF00<005YFFUH015YF00D005YF000005YF
008000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYF0002FUH60006FUH70007FUH00`00FUIJEP05FUH20008Ool00`00FUIJEP02FUH2000_Ool002ao
o`800003FUH00000008000=JEP03001JEUYF00AJEPH000MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP<000QJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP07001JEP00FUH005YF0000
1UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001P0025YF00<005YF
FUH01EYF10000UYF00<005YFFUH01eYF0`001goo00H005YFFUH005YF000_Ool002aoo`<0009JEP06
001oo`00001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00
25YF00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00
FUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000P0000AJEP00
000000QJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF008000Eoo`06001JEUYF001J
EP00;goo000/Ool00`00FUH00003FUH00`00Oomoo`030006FUH00`00FUIJEP06FUH40008FUH00`00
FUIJEP05FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YF
FUH02EYF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH400000eYF000000040006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03
FUH800000eYF001oo`0_Ool002]oo`<000AJEP<000=oo`8000AJEP03001JEUYF00IJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH300000eYF001J
EP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP0000000P000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF0P0000IJEP00FUH005YF000`Ool002]oo`03001JEP0000=JEP05001JEUYFFUH0
0004Ool300000eYF001JEP07FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJEP04FUH3
00000eYF001JEP08FUH00`00FUH000030006FUH00`00FUIJEP09FUH00`00FUH000030007FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP020005FUH300000eYF001J
EP07FUH00`00FUIJEP07FUH01000FUIJEUYF0P0025YF0P000UYF00<005YF0000<7oo000[Ool00`00
FUH00003FUH00`00FUIJEP02FUH20002Ool70005FUH00`00FUIJEP07FUH30007FUH00`00FUIJEP05
FUH2000017oo000000001eYF00<005YFFUH015YF1`001eYF1P0000=JEP00000025YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF00<005YF00000`001eYF
00<005YFFUH00`0015YF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=JEP00Ool0;goo000/
Ool00`00FUIJEP02FUH01000FUIJEUYF1@000UYF00<005YFFUH00UYF1P0025YF00@005YFFUIJEP80
00EJEP03001JEUYF00AJEP03001JEP0000Aoo`8000EJEP03001JEUYF00IJEP04001JEUYFFUH80003
FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
000015YF00<005YFFUH00UYF00<005YFFUH01@001EYF00<005YF000010000UYF00<005YFFUH01UYF
0P000eYF00<005YFFUH00UYF0P00<Goo000/Ool01@00FUIJEUYF00000UYF0P0000=JEP00FUH015YF
00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00@0
05YFFUH000Aoo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP8000=JEP03
001JEUYF009JEP800006Ool00000001JEP000UYF1@000UYF00<005YFFUH01EYF00<005YFFUH00`00
1UYF00<007ooOol0;goo000]Ool00`00FUIJEP030002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH?0007FUH01@00FUIJEUYF00000goo00<005YFFUH01@001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF0002FUH00`00FUIJEP0200000eYF001JEP03FUH20004Ool300000eYF00000003
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH2000`Ool002eoo`03001JEUYF
008000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000Moo`03
001JEUYF00AJEP03001JEUYF009JEP05001oogooOol00002FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUH0000035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP8000=JEP03001JEP0000Moo`D000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEP0002moo`00;Woo0`000eYF00@005YFFUIJ
EPL000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000Eoo`8000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF00<005YF00001@0015YF00@005YFFUIJEPD00003FUH005YF00]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000IJEP07001JEUYFFUH005YF0000
2Woo0`0000=JEP00FUH01eYF00<005YFFUH00UYF00@005YFFUH0009JEP05001JEUYFFUH0000^Ool0
02moo`80009JEPD000MJEPL000IJEP03001JEUYF00IJEP8000Eoo`05001JEUYFFUH00003FUH00`00
FUH00002Ool01000FUIJEP001UYF00<005YFFUH01EYF20001UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP<00003FUH0000000ioo`D0
00AJEP04001JEUYFFUH5000017oo0000000015YF00<007ooOol0:goo000_Ool40003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH30004Ool30004FUH00`00FUH00002Ool0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00<001=oo`P000Qo
o`03001JEUYF009JEP03001oogoo02]oo`00;Woo100015YF00<005YFFUH01EYF00<005YFFUH01UYF
1`001eYF00@005YFFUIJEP8000Aoo`05001JEUYFFUH00002FUH01000Oomoo`000UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=JEP8002=oo`03001JEUYF0080
02eoo`00;Woo0`0000=oo`0000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009o
o`8000EJEP03001JEUYF00=JEP8000=oo`06001JEUYF001JEP000goo00@005YFFUH000MJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00AJEQP000EJEP03001JEUYF00IJEP03001JEUYF009J
EPH000MJEP<0021oo`03001JEUYF008002eoo`00;Woo00@005YF0000009oo`8000MJEP03001JEUYF
00MJEP03001JEUYF009JEP<00006Ool00000001JEP0025YF00@007ooOol0009JEP03001JEP0000=o
o`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH9000<FUH00`00FUIJEP09FUH80006
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0;7oo
000^Ool200000eYF001oo`02Ool00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60008
FUH5000015YF001JEP000goo00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009JEP03001JEUYF00=JEP03001JEUYF
009JEP8000EJEP03001JEUYF009JEP<001eoo`03001JEP0002eoo`00;Woo0P000UYF00@007ooOomo
o`8000EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30006FUH00`00FUIJEP030000
0eYF001oo`03Ool00`00FUIJEP08FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP03FUH30003
FUH00`00FUIJEP05FUH4000IOol00`00FUH0000]Ool002ioo`03001JEUYF009JEP03001oogoo009o
o`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009J
EP800003FUH007oo00Aoo`YJEP03001JEUYF009JEP<000MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001J
EUYF00<000UJEP03001JEUYF00@001Aoo`<002ioo`00;Woo00<005YFFUH00UYF0`0017oo0`002EYF
00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0006FUH20005Ool:FUH00`00FUH00002
000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001JEP04FUH01000FUIJEUYF0`0025YF00<005YFFUH015YF1P0027oo1P0000=J
EP000000;Woo000_Ool01@00FUIJEUYF00000UYF00<007ooOol00goo0P0025YF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP8000Eoo`UJEP<0009JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EP000004FUH00`00FUIJEP03FUH00`00Ool000020004FUH00`00FUIJEP07FUH01000FUIJEUYF2000
0eYF00@005YFFUIJEP8002ioo`00<7oo00<005YF000015YF0P001Goo0`001EYF00<005YF00000P00
0eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF00001Goo1eYF0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00=JEP03001oogoo009oo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0035oo`8000IJEP03001o
ogoo00Eoo`<00003FUH005YF00D0009JEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001J
EUYF0004Ool5FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH00UYF0P001goo
0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00<Woo00<005YFFUH0
15YF0`0027oo20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00@007oo
Oomoo`=JEP8000UJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF009JEP8000Yoo`@0
009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<0031oo`00<goo00<005YFFUH00UYF
00@005YFFUIJEP8000Uoo`D00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF008000AJEP04
001oogooOol2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00eYF00<005YF00000goo0P0015YF00<0
05YF00003Woo1P0015YF00@005YFFUIJEPH003=oo`00=7oo0P000UYF00<005YFFUH00eYF0P0027oo
2@0015YF00<005YFFUH015YF00@005YF0000009oo`05001JEUYFFUH00003Ool00eYF001JEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20005Ool00`00FUIJEP02FUH2000EOol8000iOol003Ioo`80
00QJEP8000moo`d000Eoo`05001JEP00FUH00002Ool20004FUH00`00FUIJEP0@FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`05
Ool01P00FUIJEP00FUH005Ioo`00=goo00<005YFFUH01UYF00<005YF00000P007goo0P0000AJEP00
Oomoo`8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006Ool01P00FUIJEP00FUH005Ioo`00>7oo
0P001UYF00<005YFFUH00UYF0`007Goo00<005YF00000goo00<005YFFUH00UYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEPT00003FUH007oo05Ioo`00>Woo0P000eYF00<005YFFUH01UYF0`006Woo0P00
17oo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH01UYF0P0000IJEP00FUH005YF001G
Ool003aoo`800003FUH005YF00QJEP03001JEP0000<001Aoo`@000Eoo`80009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=J
EP<000=JEP8000QJEP80009JEP03001JEP0005Moo`00?Woo0`001eYF00<005YFFUH015YF1P0027oo
1P000UYF00<007ooOol01Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH00`000UYF00<005YFFUH00eYF0P001EYF00<005YFFUH00`0000=J
EP00Ool0EWoo0011Ool20005FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00@005YFFUIJEP80
00Yoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPH0
00=JEP03001JEUYF00IJEP8000=JEP03001JEUYF009JEP8005Qoo`00@goo0`0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000ioo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH700000eYF000000030002FUH00`00FUIJEP05
FUH00`00FUIJEP030006FUH00`00Oomoo`1FOol004Ioo`@000IJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYFFUH2000BOol80005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH:0002Ool20000
15YF001JEUYF1@000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF0P00Egoo001:
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000KOolH0002FUH00`00Oomo
o`09Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH00`00FUH0001FOol004ioo`H0
00AJEP04001JEUYFFUH6000`Ool20006FUH00`00Oomoo`0<Ool40002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000UYF00D005YFFUIJEP0005Eoo`00E7oo2000=goo00<005YFFUH015YF
0`0047oo1P0015YF00@005YFFUIJEPD00004Ool000000004FUH00`00Oomoo`1BOol009Aoo`8000AJ
EP03001JEUYF008001Aoo`P000Qoo`03001JEUYF009JEP03001oogoo059oo`00UWoo00@005YFFUH0
00EJEP8002=oo`03001JEUYF008005Aoo`00Ugoo0`001eYF0`0087oo00<005YFFUH00P00E7oo002I
Ool00`00FUIJEP06FUH01000FUH000007goo0P0000=JEP00Ool0Dgoo002JOol20005FUH00`00FUIJ
EP02FUH3000MOol00`00FUH0001DOol009aoo`8000=JEP03001JEUYF00EJEP@001Uoo`03001JEP00
05Aoo`00WWoo0`002EYF00<005YFFUH0100057oo0`00EGoo002POol20008FUH00`00FUIJEP04FUH6
0008Ool600000eYF0000001EOol00:9oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
1000FUIJEUYF0P00EGoo002UOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00EWoo002XOol30007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002[Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03001GOol00:mo
o`H000AJEP04001JEUYFFUH6001JOol00;Eoo`P0061oo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5939 .74946 m .59924 .69472 L .56821 .68981 L p .707 .577 .707 r
F P
0 g
s
.59924 .69472 m .5939 .74946 L .62561 .7514 L p .707 .577 .707 r
F P
0 g
s
.62561 .7514 m .63094 .69666 L .59924 .69472 L p .707 .577 .707 r
F P
0 g
s
.63094 .69666 m .62561 .7514 L .65488 .75018 L p .707 .577 .707 r
F P
0 g
s
.65488 .75018 m .66022 .69544 L .63094 .69666 L p .707 .577 .707 r
F P
0 g
s
.56288 .74454 m .56821 .68981 L .5409 .68241 L p .707 .577 .707 r
F P
0 g
s
.56821 .68981 m .56288 .74454 L .5939 .74946 L p .707 .577 .707 r
F P
0 g
s
.66022 .69544 m .65488 .75018 L .67887 .74591 L p .707 .577 .707 r
F P
0 g
s
.67887 .74591 m .6842 .69118 L .66022 .69544 L p .707 .577 .707 r
F P
0 g
s
.53556 .73714 m .5409 .68241 L .51997 .67323 L p .707 .577 .707 r
F P
0 g
s
.5409 .68241 m .53556 .73714 L .56288 .74454 L p .707 .577 .707 r
F P
0 g
s
.59003 .81613 m .59717 .78059 L .56659 .77267 L p .707 .577 .707 r
F P
0 g
s
.59717 .78059 m .59003 .81613 L .62133 .82078 L p .707 .577 .707 r
F P
0 g
s
.62133 .82078 m .62847 .78524 L .59717 .78059 L p .707 .577 .707 r
F P
0 g
s
.62847 .78524 m .62133 .82078 L .65029 .82171 L p .707 .577 .707 r
F P
0 g
s
.65029 .82171 m .65743 .78617 L .62847 .78524 L p .707 .577 .707 r
F P
0 g
s
.55945 .80821 m .56659 .77267 L .53972 .76226 L p .707 .577 .707 r
F P
0 g
s
.56659 .77267 m .55945 .80821 L .59003 .81613 L p .707 .577 .707 r
F P
0 g
s
.6842 .69118 m .67887 .74591 L .69522 .73902 L p .707 .577 .707 r
F P
0 g
s
.69522 .73902 m .70055 .68429 L .6842 .69118 L p .707 .577 .707 r
F P
0 g
s
.51997 .67323 m .51464 .72797 L .53556 .73714 L p .707 .577 .707 r
F P
0 g
s
.5957 .86109 m .599 .84323 L .56833 .83576 L p .707 .577 .707 r
F P
0 g
s
.599 .84323 m .5957 .86109 L .62708 .86533 L p .707 .577 .707 r
F P
0 g
s
.62708 .86533 m .63038 .84748 L .599 .84323 L p .707 .577 .707 r
F P
0 g
s
.53972 .76226 m .53258 .7978 L .55945 .80821 L p .707 .577 .707 r
F P
0 g
s
.65743 .78617 m .65029 .82171 L .67407 .81882 L p .707 .577 .707 r
F P
0 g
s
.67407 .81882 m .68121 .78328 L .65743 .78617 L p .707 .577 .707 r
F P
0 g
s
.51464 .72797 m .51997 .67323 L .50748 .66319 L p .707 .577 .707 r
F P
0 g
s
.53258 .7978 m .53972 .76226 L .5192 .75038 L p .707 .577 .707 r
F P
0 g
s
.63038 .84748 m .62708 .86533 L .6561 .86594 L p .707 .577 .707 r
F P
0 g
s
.6561 .86594 m .6594 .84809 L .63038 .84748 L p .707 .577 .707 r
F P
0 g
s
.56503 .85362 m .56833 .83576 L .54138 .82581 L p .707 .577 .707 r
F P
0 g
s
.56833 .83576 m .56503 .85362 L .5957 .86109 L p .707 .577 .707 r
F P
0 g
s
.54138 .82581 m .53808 .84366 L .56503 .85362 L p .707 .577 .707 r
F P
0 g
s
.5192 .75038 m .51206 .78592 L .53258 .7978 L p .707 .577 .707 r
F P
0 g
s
.6594 .84809 m .6561 .86594 L .67992 .86285 L p .707 .577 .707 r
F P
0 g
s
.67992 .86285 m .68322 .84499 L .6594 .84809 L p .707 .577 .707 r
F P
0 g
s
.53808 .84366 m .54138 .82581 L .52078 .81433 L p .707 .577 .707 r
F P
0 g
s
.50748 .66319 m .50215 .71793 L .51464 .72797 L p .707 .577 .707 r
F P
0 g
s
.70055 .68429 m .69522 .73902 L .70232 .73018 L p .707 .577 .707 r
F P
0 g
s
.70232 .73018 m .70766 .67544 L .70055 .68429 L p .707 .577 .707 r
F P
0 g
s
.68121 .78328 m .67407 .81882 L .69034 .81241 L p .707 .577 .707 r
F P
0 g
s
.69034 .81241 m .69748 .77687 L .68121 .78328 L p .707 .577 .707 r
F P
0 g
s
.51206 .78592 m .5192 .75038 L .50703 .73819 L p .707 .577 .707 r
F P
0 g
s
.52078 .81433 m .51748 .83218 L .53808 .84366 L p .707 .577 .707 r
F P
0 g
s
.50215 .71793 m .50748 .66319 L .50465 .65327 L p .707 .577 .707 r
F P
0 g
s
.50703 .73819 m .49989 .77373 L .51206 .78592 L p .707 .577 .707 r
F P
0 g
s
.68322 .84499 m .67992 .86285 L .69621 .85636 L p .707 .577 .707 r
F P
0 g
s
.69621 .85636 m .69951 .83851 L .68322 .84499 L p .707 .577 .707 r
F P
0 g
s
.51748 .83218 m .52078 .81433 L .50855 .80246 L p .707 .577 .707 r
F P
0 g
s
.50465 .65327 m .49932 .708 L .50215 .71793 L p .707 .577 .707 r
F P
0 g
s
.50855 .80246 m .50525 .82031 L .51748 .83218 L p .707 .577 .707 r
F P
0 g
s
.69748 .77687 m .69034 .81241 L .69752 .80309 L p .707 .577 .707 r
F P
0 g
s
.69752 .80309 m .70466 .76755 L .69748 .77687 L p .707 .577 .707 r
F P
0 g
s
.49989 .77373 m .50703 .73819 L .5044 .72688 L p .707 .577 .707 r
F P
0 g
s
.70766 .67544 m .70232 .73018 L .69949 .72025 L p .707 .577 .707 r
F P
0 g
s
.69949 .72025 m .70483 .66552 L .70766 .67544 L p .707 .577 .707 r
F P
0 g
s
.49932 .708 m .50465 .65327 L .51176 .64443 L p .707 .577 .707 r
F P
0 g
s
.5044 .72688 m .49726 .76242 L .49989 .77373 L p .707 .577 .707 r
F P
0 g
s
.49726 .76242 m .5044 .72688 L .51158 .71756 L p .707 .577 .707 r
F P
0 g
s
.51158 .71756 m .50444 .7531 L .49726 .76242 L p .707 .577 .707 r
F P
0 g
s
.50232 .82126 m .48352 .31773 L .43955 .31672 L p .707 .577 .707 r
F P
0 g
s
.50525 .82031 m .50855 .80246 L .50589 .79136 L p .707 .577 .707 r
F P
0 g
s
.50589 .79136 m .50258 .80921 L .50525 .82031 L p .707 .577 .707 r
F P
0 g
s
.51176 .64443 m .50643 .69916 L .49932 .708 L p .707 .577 .707 r
F P
0 g
s
.50643 .69916 m .51176 .64443 L .52811 .63754 L p .707 .577 .707 r
F P
0 g
s
.50258 .80921 m .50589 .79136 L .51305 .78211 L p .707 .577 .707 r
F P
0 g
s
.51305 .78211 m .50975 .79997 L .50258 .80921 L p .707 .577 .707 r
F P
0 g
s
.52811 .63754 m .52277 .69227 L .50643 .69916 L p .707 .577 .707 r
F P
0 g
s
.50444 .7531 m .51158 .71756 L .52786 .71115 L p .707 .577 .707 r
F P
0 g
s
.52277 .69227 m .52811 .63754 L .55209 .63327 L p .707 .577 .707 r
F P
0 g
s
.52786 .71115 m .52072 .74669 L .50444 .7531 L p .707 .577 .707 r
F P
0 g
s
.50975 .79997 m .51305 .78211 L .52934 .77563 L p .707 .577 .707 r
F P
0 g
s
.55209 .63327 m .54676 .688 L .52277 .69227 L p .707 .577 .707 r
F P
0 g
s
.52934 .77563 m .52604 .79348 L .50975 .79997 L p .707 .577 .707 r
F P
0 g
s
.52072 .74669 m .52786 .71115 L .55164 .70827 L p .707 .577 .707 r
F P
0 g
s
.55164 .70827 m .5445 .74381 L .52072 .74669 L p .707 .577 .707 r
F P
0 g
s
.52604 .79348 m .52934 .77563 L .55316 .77253 L p .707 .577 .707 r
F P
0 g
s
.55316 .77253 m .54986 .79039 L .52604 .79348 L p .707 .577 .707 r
F P
0 g
s
.48352 .31773 m .50232 .82126 L .54723 .81865 L p .707 .577 .707 r
F P
0 g
s
.54723 .81865 m .52844 .31512 L .48352 .31773 L p .707 .577 .707 r
F P
0 g
s
.69951 .83851 m .69621 .85636 L .70337 .84712 L p .707 .577 .707 r
F P
0 g
s
.70337 .84712 m .70667 .82926 L .69951 .83851 L p .707 .577 .707 r
F P
0 g
s
.54676 .688 m .55209 .63327 L .58137 .63205 L p .707 .577 .707 r
F P
0 g
s
.58137 .63205 m .57604 .68678 L .54676 .688 L p .707 .577 .707 r
F P
0 g
s
.5445 .74381 m .55164 .70827 L .5806 .70919 L p .707 .577 .707 r
F P
0 g
s
.5806 .70919 m .57346 .74473 L .5445 .74381 L p .707 .577 .707 r
F P
0 g
s
.57346 .74473 m .5806 .70919 L .6119 .71384 L p .707 .577 .707 r
F P
0 g
s
.54986 .79039 m .55316 .77253 L .58218 .77314 L p .707 .577 .707 r
F P
0 g
s
.6119 .71384 m .60476 .74938 L .57346 .74473 L p .707 .577 .707 r
F P
0 g
s
.58218 .77314 m .57888 .791 L .54986 .79039 L p .707 .577 .707 r
F P
0 g
s
.57888 .791 m .58218 .77314 L .61356 .77739 L p .707 .577 .707 r
F P
0 g
s
.61356 .77739 m .61026 .79524 L .57888 .791 L p .707 .577 .707 r
F P
0 g
s
.52844 .31512 m .54723 .81865 L .58869 .81268 L p .707 .577 .707 r
F P
0 g
s
.57604 .68678 m .58137 .63205 L .61307 .63399 L p .707 .577 .707 r
F P
0 g
s
.61307 .63399 m .60774 .68872 L .57604 .68678 L p .707 .577 .707 r
F P
0 g
s
.58869 .81268 m .5699 .30916 L .52844 .31512 L p .707 .577 .707 r
F P
0 g
s
.45834 .82024 m .43955 .31672 L .40081 .31219 L p .707 .577 .707 r
F P
0 g
s
.43955 .31672 m .45834 .82024 L .50232 .82126 L p .707 .577 .707 r
F P
0 g
s
.70466 .76755 m .69752 .80309 L .6949 .79178 L p .707 .577 .707 r
F P
0 g
s
.6949 .79178 m .70204 .75624 L .70466 .76755 L p .707 .577 .707 r
F P
0 g
s
.70483 .66552 m .69949 .72025 L .687 .71021 L p .707 .577 .707 r
F P
0 g
s
.687 .71021 m .69234 .65548 L .70483 .66552 L p .707 .577 .707 r
F P
0 g
s
.6441 .6389 m .63877 .69363 L .60774 .68872 L p .707 .577 .707 r
F P
0 g
s
.60774 .68872 m .61307 .63399 L .6441 .6389 L p .707 .577 .707 r
F P
0 g
s
.64248 .72176 m .63534 .7573 L .60476 .74938 L p .707 .577 .707 r
F P
0 g
s
.60476 .74938 m .6119 .71384 L .64248 .72176 L p .707 .577 .707 r
F P
0 g
s
.64423 .78486 m .64093 .80271 L .61026 .79524 L p .707 .577 .707 r
F P
0 g
s
.61026 .79524 m .61356 .77739 L .64423 .78486 L p .707 .577 .707 r
F P
0 g
s
.5699 .30916 m .58869 .81268 L .62263 .80394 L p .707 .577 .707 r
F P
0 g
s
.62263 .80394 m .60384 .30041 L .5699 .30916 L p .707 .577 .707 r
F P
0 g
s
.25089 .71802 m .25623 .66329 L .2252 .65837 L p .707 .577 .707 r
F P
0 g
s
.25623 .66329 m .25089 .71802 L .2826 .71996 L p .707 .577 .707 r
F P
0 g
s
.2826 .71996 m .28793 .66523 L .25623 .66329 L p .707 .577 .707 r
F P
0 g
s
.70667 .82926 m .70337 .84712 L .70071 .83602 L p .707 .577 .707 r
F P
0 g
s
.70071 .83602 m .70401 .81816 L .70667 .82926 L p .707 .577 .707 r
F P
0 g
s
.28793 .66523 m .2826 .71996 L .31188 .71874 L p .707 .577 .707 r
F P
0 g
s
.31188 .71874 m .31721 .66401 L .28793 .66523 L p .707 .577 .707 r
F P
0 g
s
.41961 .81571 m .40081 .31219 L .37111 .30458 L p .707 .577 .707 r
F P
0 g
s
.40081 .31219 m .41961 .81571 L .45834 .82024 L p .707 .577 .707 r
F P
0 g
s
.21987 .71311 m .2252 .65837 L .19789 .65097 L p .707 .577 .707 r
F P
0 g
s
.2252 .65837 m .21987 .71311 L .25089 .71802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31721 .66401 m .31188 .71874 L .33586 .71447 L p .707 .577 .707 r
F P
0 g
s
.33586 .71447 m .34119 .65974 L .31721 .66401 L p .707 .577 .707 r
F P
0 g
s
.70204 .75624 m .6949 .79178 L .68273 .77959 L p .707 .577 .707 r
F P
0 g
s
.68273 .77959 m .68987 .74405 L .70204 .75624 L p .707 .577 .707 r
F P
0 g
s
.69234 .65548 m .687 .71021 L .66608 .70104 L p .707 .577 .707 r
F P
0 g
s
.66608 .70104 m .67141 .64631 L .69234 .65548 L p .707 .577 .707 r
F P
0 g
s
.66934 .73217 m .66221 .76771 L .63534 .7573 L p .707 .577 .707 r
F P
0 g
s
.63534 .7573 m .64248 .72176 L .66934 .73217 L p .707 .577 .707 r
F P
0 g
s
.64093 .80271 m .64423 .78486 L .67118 .79481 L p .707 .577 .707 r
F P
0 g
s
.60384 .30041 m .62263 .80394 L .64574 .79327 L p .707 .577 .707 r
F P
0 g
s
.67141 .64631 m .66608 .70104 L .63877 .69363 L p .707 .577 .707 r
F P
0 g
s
.63877 .69363 m .6441 .6389 L .67141 .64631 L p .707 .577 .707 r
F P
0 g
s
.64574 .79327 m .62694 .28975 L .60384 .30041 L p .707 .577 .707 r
F P
0 g
s
.19255 .7057 m .19789 .65097 L .17696 .6418 L p .707 .577 .707 r
F P
0 g
s
.19789 .65097 m .19255 .7057 L .21987 .71311 L p .707 .577 .707 r
F P
0 g
s
.24702 .77687 m .25416 .74133 L .22358 .73342 L p .707 .577 .707 r
F P
0 g
s
.25416 .74133 m .24702 .77687 L .27832 .78152 L p .707 .577 .707 r
F P
0 g
s
.27832 .78152 m .28546 .74598 L .25416 .74133 L p .707 .577 .707 r
F P
0 g
s
.28546 .74598 m .27832 .78152 L .30728 .78245 L p .707 .577 .707 r
F P
0 g
s
.30728 .78245 m .31442 .74691 L .28546 .74598 L p .707 .577 .707 r
F P
0 g
s
.21644 .76896 m .22358 .73342 L .19671 .72301 L p .707 .577 .707 r
F P
0 g
s
.22358 .73342 m .21644 .76896 L .24702 .77687 L p .707 .577 .707 r
F P
0 g
s
.70401 .81816 m .70071 .83602 L .68848 .82415 L p .707 .577 .707 r
F P
0 g
s
.68848 .82415 m .69178 .80629 L .70401 .81816 L p .707 .577 .707 r
F P
0 g
s
.38991 .80811 m .37111 .30458 L .35336 .29465 L p .707 .577 .707 r
F P
0 g
s
.37111 .30458 m .38991 .80811 L .41961 .81571 L p .707 .577 .707 r
F P
0 g
s
.34119 .65974 m .33586 .71447 L .35221 .70758 L p .707 .577 .707 r
F P
0 g
s
.35221 .70758 m .35754 .65285 L .34119 .65974 L p .707 .577 .707 r
F P
0 g
s
.25269 .81632 m .25599 .79846 L .22532 .79099 L p .707 .577 .707 r
F P
0 g
s
.25599 .79846 m .25269 .81632 L .28407 .82056 L p .707 .577 .707 r
F P
0 g
s
.28407 .82056 m .28737 .80271 L .25599 .79846 L p .707 .577 .707 r
F P
0 g
s
.17696 .6418 m .17163 .69653 L .19255 .7057 L p .707 .577 .707 r
F P
0 g
s
.19671 .72301 m .18957 .75855 L .21644 .76896 L p .707 .577 .707 r
F P
0 g
s
.31442 .74691 m .30728 .78245 L .33106 .77957 L p .707 .577 .707 r
F P
0 g
s
.33106 .77957 m .3382 .74403 L .31442 .74691 L p .707 .577 .707 r
F P
0 g
s
.18957 .75855 m .19671 .72301 L .17619 .71113 L p .707 .577 .707 r
F P
0 g
s
.28737 .80271 m .28407 .82056 L .31309 .82117 L p .707 .577 .707 r
F P
0 g
s
.31309 .82117 m .31639 .80331 L .28737 .80271 L p .707 .577 .707 r
F P
0 g
s
.22202 .80885 m .22532 .79099 L .19837 .78103 L p .707 .577 .707 r
F P
0 g
s
.22532 .79099 m .22202 .80885 L .25269 .81632 L p .707 .577 .707 r
F P
0 g
s
.17163 .69653 m .17696 .6418 L .16447 .63176 L p .707 .577 .707 r
F P
0 g
s
.68987 .74405 m .68273 .77959 L .66221 .76771 L p .707 .577 .707 r
F P
0 g
s
.66221 .76771 m .66934 .73217 L .68987 .74405 L p .707 .577 .707 r
F P
0 g
s
.19837 .78103 m .19507 .79889 L .22202 .80885 L p .707 .577 .707 r
F P
0 g
s
.17619 .71113 m .16905 .74667 L .18957 .75855 L p .707 .577 .707 r
F P
0 g
s
.31639 .80331 m .31309 .82117 L .33691 .81808 L p .707 .577 .707 r
F P
0 g
s
.33691 .81808 m .34021 .80022 L .31639 .80331 L p .707 .577 .707 r
F P
0 g
s
.19507 .79889 m .19837 .78103 L .17777 .76956 L p .707 .577 .707 r
F P
0 g
s
.62694 .28975 m .64574 .79327 L .65574 .78173 L p .707 .577 .707 r
F P
0 g
s
.65574 .78173 m .63695 .2782 L .62694 .28975 L p .707 .577 .707 r
F P
0 g
s
.69178 .80629 m .68848 .82415 L .66788 .81267 L p .707 .577 .707 r
F P
0 g
s
.66788 .81267 m .67118 .79481 L .69178 .80629 L p .707 .577 .707 r
F P
0 g
s
.16447 .63176 m .15914 .68649 L .17163 .69653 L p .707 .577 .707 r
F P
0 g
s
.3382 .74403 m .33106 .77957 L .34733 .77315 L p .707 .577 .707 r
F P
0 g
s
.34733 .77315 m .35447 .73761 L .3382 .74403 L p .707 .577 .707 r
F P
0 g
s
.16905 .74667 m .17619 .71113 L .16402 .69893 L p .707 .577 .707 r
F P
0 g
s
.17777 .76956 m .17447 .78741 L .19507 .79889 L p .707 .577 .707 r
F P
0 g
s
.35754 .65285 m .35221 .70758 L .35931 .69874 L p .707 .577 .707 r
F P
0 g
s
.35931 .69874 m .36465 .64401 L .35754 .65285 L p .707 .577 .707 r
F P
0 g
s
.15914 .68649 m .16447 .63176 L .16165 .62183 L p .707 .577 .707 r
F P
0 g
s
.16402 .69893 m .15688 .73448 L .16905 .74667 L p .707 .577 .707 r
F P
0 g
s
.34021 .80022 m .33691 .81808 L .3532 .81159 L p .707 .577 .707 r
F P
0 g
s
.3532 .81159 m .3565 .79374 L .34021 .80022 L p .707 .577 .707 r
F P
0 g
s
.37215 .79818 m .35336 .29465 L .34928 .28336 L p .707 .577 .707 r
F P
0 g
s
.35336 .29465 m .37215 .79818 L .38991 .80811 L p .707 .577 .707 r
F P
0 g
s
.17447 .78741 m .17777 .76956 L .16554 .75769 L p .707 .577 .707 r
F P
0 g
s
.67118 .79481 m .66788 .81267 L .64093 .80271 L p .707 .577 .707 r
F P
0 g
s
.16554 .75769 m .16224 .77554 L .17447 .78741 L p .707 .577 .707 r
F P
0 g
s
.16165 .62183 m .15631 .67656 L .15914 .68649 L p .707 .577 .707 r
F P
0 g
s
.35447 .73761 m .34733 .77315 L .35451 .76384 L p .707 .577 .707 r
F P
0 g
s
.35451 .76384 m .36165 .7283 L .35447 .73761 L p .707 .577 .707 r
F P
0 g
s
.15688 .73448 m .16402 .69893 L .16139 .68763 L p .707 .577 .707 r
F P
0 g
s
.36465 .64401 m .35931 .69874 L .35648 .68881 L p .707 .577 .707 r
F P
0 g
s
.35648 .68881 m .36182 .63408 L .36465 .64401 L p .707 .577 .707 r
F P
0 g
s
.63695 .2782 m .65574 .78173 L .65224 .77203 L p .707 .577 .707 r
F P
0 g
s
.65122 .75543 m .63695 .2782 L .65224 .77203 L .707 .577 .707 r
F
.63287 .26691 m .63695 .2782 L p .64711 .61793 L F P
0 g
s
.65097 .74711 m .64583 .614 L .64711 .61793 L .707 .577 .707 r
F
.65063 .74267 m .64583 .614 L p .65097 .74711 L F P
0 g
s
.63287 .26691 m .65167 .77044 L .63391 .7605 L p .707 .577 .707 r
F P
0 g
s
.64423 .64615 m .64354 .64962 L p .64926 .69388 L .707 .577 .707 r
F P
0 g
s
.64354 .64962 m .63709 .68169 L .64672 .69133 L p .707 .577 .707 r
F P
0 g
s
.64672 .69133 m .64926 .69388 L p .64354 .64962 L .707 .577 .707 r
F P
0 g
s
.65167 .77044 m .65063 .74267 L p .65097 .74711 L .707 .577 .707 r
F P
0 g
s
.64583 .614 m .63287 .26691 L p .64711 .61793 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64186 .56123 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.63935 .62589 m .64174 .60144 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .64469 .57116 L p .64045 .5975 L .707 .577 .707 r
F P
0 g
s
.64469 .57116 m .64174 .60144 L p .65184 .63593 L .707 .577 .707 r
F P
0 g
s
.64174 .60144 m .63935 .62589 L .64344 .62918 L p .707 .577 .707 r
F P
0 g
s
.64344 .62918 m .65184 .63593 L p .64174 .60144 L .707 .577 .707 r
F P
0 g
s
.65224 .77203 m .65167 .77044 L p .65122 .75543 L .707 .577 .707 r
F P
0 g
s
.15631 .67656 m .16165 .62183 L .16875 .61299 L p .707 .577 .707 r
F P
0 g
s
.16139 .68763 m .15426 .72317 L .15688 .73448 L p .707 .577 .707 r
F P
0 g
s
.3565 .79374 m .3532 .81159 L .36036 .80235 L p .707 .577 .707 r
F P
0 g
s
.36036 .80235 m .36366 .78449 L .3565 .79374 L p .707 .577 .707 r
F P
0 g
s
.16224 .77554 m .16554 .75769 L .16288 .74659 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16288 .74659 m .15958 .76444 L .16224 .77554 L p .707 .577 .707 r
F P
0 g
s
.36165 .7283 m .35451 .76384 L .35189 .75253 L p .707 .577 .707 r
F P
0 g
s
.35189 .75253 m .35903 .71699 L .36165 .7283 L p .707 .577 .707 r
F P
0 g
s
.16875 .61299 m .16342 .66772 L .15631 .67656 L p .707 .577 .707 r
F P
0 g
s
.15426 .72317 m .16139 .68763 L .16857 .67831 L p .707 .577 .707 r
F P
0 g
s
.34928 .28336 m .36808 .78689 L .37215 .79818 L p .707 .577 .707 r
F P
0 g
s
.36808 .78689 m .34928 .28336 L .35929 .27181 L p .707 .577 .707 r
F P
0 g
s
.36182 .63408 m .35648 .68881 L .344 .67877 L p .707 .577 .707 r
F P
0 g
s
.344 .67877 m .34933 .62404 L .36182 .63408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16342 .66772 m .16875 .61299 L .1851 .6061 L p .707 .577 .707 r
F P
0 g
s
.16857 .67831 m .16143 .71385 L .15426 .72317 L p .707 .577 .707 r
F P
0 g
s
.36366 .78449 m .36036 .80235 L .3577 .79124 L p .707 .577 .707 r
F P
0 g
s
.3577 .79124 m .361 .77339 L .36366 .78449 L p .707 .577 .707 r
F P
0 g
s
.15958 .76444 m .16288 .74659 L .17004 .73734 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17004 .73734 m .16674 .75519 L .15958 .76444 L p .707 .577 .707 r
F P
0 g
s
.63391 .7605 m .61512 .25698 L .63287 .26691 L p .707 .577 .707 r
F P
0 g
s
.35903 .71699 m .35189 .75253 L .33972 .74034 L p .707 .577 .707 r
F P
0 g
s
.33972 .74034 m .34686 .7048 L .35903 .71699 L p .707 .577 .707 r
F P
0 g
s
.1851 .6061 m .17976 .66083 L .16342 .66772 L p .707 .577 .707 r
F P
0 g
s
.16143 .71385 m .16857 .67831 L .18485 .67189 L p .707 .577 .707 r
F P
0 g
s
.34933 .62404 m .344 .67877 L .32307 .6696 L p .707 .577 .707 r
F P
0 g
s
.32307 .6696 m .3284 .61487 L .34933 .62404 L p .707 .577 .707 r
F P
0 g
s
.17976 .66083 m .1851 .6061 L .20908 .60183 L p .707 .577 .707 r
F P
0 g
s
.18485 .67189 m .17771 .70744 L .16143 .71385 L p .707 .577 .707 r
F P
0 g
s
.361 .77339 m .3577 .79124 L .34547 .77937 L p .707 .577 .707 r
F P
0 g
s
.34547 .77937 m .34877 .76152 L .361 .77339 L p .707 .577 .707 r
F P
0 g
s
.37808 .77534 m .35929 .27181 L .38239 .26115 L p .707 .577 .707 r
F P
0 g
s
.35929 .27181 m .37808 .77534 L .36808 .78689 L p .707 .577 .707 r
F P
0 g
s
.16674 .75519 m .17004 .73734 L .18633 .73085 L p .707 .577 .707 r
F P
0 g
s
.18633 .73085 m .18303 .74871 L .16674 .75519 L p .707 .577 .707 r
F P
0 g
s
.3284 .61487 m .32307 .6696 L .29576 .6622 L p .707 .577 .707 r
F P
0 g
s
.29576 .6622 m .30109 .60746 L .3284 .61487 L p .707 .577 .707 r
F P
0 g
s
.34686 .7048 m .33972 .74034 L .3192 .72846 L p .707 .577 .707 r
F P
0 g
s
.3192 .72846 m .32634 .69292 L .34686 .7048 L p .707 .577 .707 r
F P
0 g
s
.20908 .60183 m .20375 .65657 L .17976 .66083 L p .707 .577 .707 r
F P
0 g
s
.17771 .70744 m .18485 .67189 L .20863 .66901 L p .707 .577 .707 r
F P
0 g
s
.20375 .65657 m .20908 .60183 L .23836 .60061 L p .707 .577 .707 r
F P
0 g
s
.61512 .25698 m .63391 .7605 L .60421 .7529 L p .707 .577 .707 r
F P
0 g
s
.60421 .7529 m .58542 .24937 L .61512 .25698 L p .707 .577 .707 r
F P
0 g
s
.30109 .60746 m .29576 .6622 L .26473 .65728 L p .707 .577 .707 r
F P
0 g
s
.26473 .65728 m .27007 .60255 L .30109 .60746 L p .707 .577 .707 r
F P
0 g
s
.20863 .66901 m .20149 .70455 L .17771 .70744 L p .707 .577 .707 r
F P
0 g
s
.34877 .76152 m .34547 .77937 L .32487 .7679 L p .707 .577 .707 r
F P
0 g
s
.32487 .7679 m .32817 .75004 L .34877 .76152 L p .707 .577 .707 r
F P
0 g
s
.23303 .65534 m .23836 .60061 L .27007 .60255 L p .707 .577 .707 r
F P
0 g
s
.23836 .60061 m .23303 .65534 L .20375 .65657 L p .707 .577 .707 r
F P
0 g
s
.18303 .74871 m .18633 .73085 L .21015 .72776 L p .707 .577 .707 r
F P
0 g
s
.27007 .60255 m .26473 .65728 L .23303 .65534 L p .707 .577 .707 r
F P
0 g
s
.32634 .69292 m .3192 .72846 L .29233 .71805 L p .707 .577 .707 r
F P
0 g
s
.29233 .71805 m .29947 .68251 L .32634 .69292 L p .707 .577 .707 r
F P
0 g
s
.73111 .65742 m .73644 .60269 L .70541 .59777 L p .707 .577 .707 r
F P
0 g
s
.73644 .60269 m .73111 .65742 L .76281 .65936 L p .707 .577 .707 r
F P
0 g
s
.76281 .65936 m .76814 .60463 L .73644 .60269 L p .707 .577 .707 r
F P
0 g
s
.20149 .70455 m .20863 .66901 L .23759 .66994 L p .707 .577 .707 r
F P
0 g
s
.21015 .72776 m .20685 .74562 L .18303 .74871 L p .707 .577 .707 r
F P
0 g
s
.76814 .60463 m .76281 .65936 L .79209 .65814 L p .707 .577 .707 r
F P
0 g
s
.79209 .65814 m .79742 .6034 L .76814 .60463 L p .707 .577 .707 r
F P
0 g
s
.38239 .26115 m .40119 .76468 L .37808 .77534 L p .707 .577 .707 r
F P
0 g
s
.40119 .76468 m .38239 .26115 L .41634 .2524 L p .707 .577 .707 r
F P
0 g
s
.70008 .65251 m .70541 .59777 L .6781 .59037 L p .707 .577 .707 r
F P
0 g
s
.70541 .59777 m .70008 .65251 L .73111 .65742 L p .707 .577 .707 r
F P
0 g
s
.23759 .66994 m .23045 .70548 L .20149 .70455 L p .707 .577 .707 r
F P
0 g
s
.29947 .68251 m .29233 .71805 L .26175 .71013 L p .707 .577 .707 r
F P
0 g
s
.26175 .71013 m .26889 .67459 L .29947 .68251 L p .707 .577 .707 r
F P
0 g
s
.23045 .70548 m .23759 .66994 L .26889 .67459 L p .707 .577 .707 r
F P
0 g
s
.32817 .75004 m .32487 .7679 L .29792 .75794 L p .707 .577 .707 r
F P
0 g
s
.29792 .75794 m .30122 .74008 L .32817 .75004 L p .707 .577 .707 r
F P
0 g
s
.20685 .74562 m .21015 .72776 L .23917 .72837 L p .707 .577 .707 r
F P
0 g
s
.79742 .6034 m .79209 .65814 L .81607 .65387 L p .707 .577 .707 r
F P
0 g
s
.81607 .65387 m .82141 .59914 L .79742 .6034 L p .707 .577 .707 r
F P
0 g
s
.26889 .67459 m .26175 .71013 L .23045 .70548 L p .707 .577 .707 r
F P
0 g
s
.58542 .24937 m .60421 .7529 L .56548 .74837 L p .707 .577 .707 r
F P
0 g
s
.56548 .74837 m .54669 .24484 L .58542 .24937 L p .707 .577 .707 r
F P
0 g
s
.67277 .6451 m .6781 .59037 L .65718 .5812 L p .707 .577 .707 r
F P
0 g
s
.6781 .59037 m .67277 .6451 L .70008 .65251 L p .707 .577 .707 r
F P
0 g
s
.23917 .72837 m .23587 .74622 L .20685 .74562 L p .707 .577 .707 r
F P
0 g
s
.72723 .72409 m .73437 .68855 L .70379 .68063 L p .707 .577 .707 r
F P
0 g
s
.73437 .68855 m .72723 .72409 L .75853 .72874 L p .707 .577 .707 r
F P
0 g
s
.75853 .72874 m .76567 .6932 L .73437 .68855 L p .707 .577 .707 r
F P
0 g
s
.30122 .74008 m .29792 .75794 L .26725 .75047 L p .707 .577 .707 r
F P
0 g
s
.26725 .75047 m .27055 .73262 L .30122 .74008 L p .707 .577 .707 r
F P
0 g
s
.76567 .6932 m .75853 .72874 L .78749 .72967 L p .707 .577 .707 r
F P
0 g
s
.78749 .72967 m .79463 .69413 L .76567 .6932 L p .707 .577 .707 r
F P
0 g
s
.23587 .74622 m .23917 .72837 L .27055 .73262 L p .707 .577 .707 r
F P
0 g
s
.69665 .71617 m .70379 .68063 L .67692 .67022 L p .707 .577 .707 r
F P
0 g
s
.70379 .68063 m .69665 .71617 L .72723 .72409 L p .707 .577 .707 r
F P
0 g
s
.43513 .75593 m .41634 .2524 L .4578 .24644 L p .707 .577 .707 r
F P
0 g
s
.41634 .2524 m .43513 .75593 L .40119 .76468 L p .707 .577 .707 r
F P
0 g
s
.27055 .73262 m .26725 .75047 L .23587 .74622 L p .707 .577 .707 r
F P
0 g
s
.82141 .59914 m .81607 .65387 L .83242 .64698 L p .707 .577 .707 r
F P
0 g
s
.83242 .64698 m .83775 .59225 L .82141 .59914 L p .707 .577 .707 r
F P
0 g
s
.65718 .5812 m .65184 .63593 L .67277 .6451 L p .707 .577 .707 r
F P
0 g
s
.7329 .76905 m .7362 .7512 L .70554 .74373 L p .707 .577 .707 r
F P
0 g
s
.7362 .7512 m .7329 .76905 L .76428 .77329 L p .707 .577 .707 r
F P
0 g
s
.76428 .77329 m .76758 .75544 L .7362 .7512 L p .707 .577 .707 r
F P
0 g
s
.54669 .24484 m .56548 .74837 L .5215 .74736 L p .707 .577 .707 r
F P
0 g
s
.5215 .74736 m .50271 .24383 L .54669 .24484 L p .707 .577 .707 r
F P
0 g
s
.67692 .67022 m .66978 .70576 L .69665 .71617 L p .707 .577 .707 r
F P
0 g
s
.79463 .69413 m .78749 .72967 L .81127 .72679 L p .707 .577 .707 r
F P
0 g
s
.81127 .72679 m .81841 .69124 L .79463 .69413 L p .707 .577 .707 r
F P
0 g
s
.65184 .63593 m .65718 .5812 L .64469 .57116 L p .707 .577 .707 r
F P
0 g
s
.66978 .70576 m .67692 .67022 L .6564 .65834 L p .707 .577 .707 r
F P
0 g
s
.76758 .75544 m .76428 .77329 L .7933 .7739 L p .707 .577 .707 r
F P
0 g
s
.7933 .7739 m .79661 .75605 L .76758 .75544 L p .707 .577 .707 r
F P
0 g
s
.70224 .76158 m .70554 .74373 L .67858 .73377 L p .707 .577 .707 r
F P
0 g
s
.70554 .74373 m .70224 .76158 L .7329 .76905 L p .707 .577 .707 r
F P
0 g
s
.47659 .74996 m .4578 .24644 L .50271 .24383 L p .707 .577 .707 r
F P
0 g
s
.4578 .24644 m .47659 .74996 L .43513 .75593 L p .707 .577 .707 r
F P
0 g
s
.50271 .24383 m .5215 .74736 L .47659 .74996 L p .707 .577 .707 r
F P
0 g
s
.67858 .73377 m .67528 .75162 L .70224 .76158 L p .707 .577 .707 r
F P
0 g
s
.6564 .65834 m .64926 .69388 L .66978 .70576 L p .707 .577 .707 r
F P
0 g
s
.79661 .75605 m .7933 .7739 L .81713 .77081 L p .707 .577 .707 r
F P
0 g
s
.81713 .77081 m .82043 .75296 L .79661 .75605 L p .707 .577 .707 r
F P
0 g
s
.67528 .75162 m .67858 .73377 L .65798 .72229 L p .707 .577 .707 r
F P
0 g
s
.83775 .59225 m .83242 .64698 L .83953 .63814 L p .707 .577 .707 r
F P
0 g
s
.83953 .63814 m .84486 .58341 L .83775 .59225 L p .707 .577 .707 r
F P
0 g
s
.81841 .69124 m .81127 .72679 L .82755 .72037 L p .707 .577 .707 r
F P
0 g
s
.82755 .72037 m .83469 .68483 L .81841 .69124 L p .707 .577 .707 r
F P
0 g
s
.64926 .69388 m .6564 .65834 L .64423 .64615 L p .707 .577 .707 r
F P
0 g
s
.65798 .72229 m .65468 .74014 L .67528 .75162 L p .707 .577 .707 r
F P
0 g
s
.82043 .75296 m .81713 .77081 L .83341 .76432 L p .707 .577 .707 r
F P
0 g
s
.83341 .76432 m .83672 .74647 L .82043 .75296 L p .707 .577 .707 r
F P
0 g
s
.65468 .74014 m .65798 .72229 L .64575 .71042 L p .707 .577 .707 r
F P
0 g
s
.64186 .56123 m .63653 .61596 L .63935 .62589 L p .707 .577 .707 r
F P
0 g
s
.64575 .71042 m .64245 .72827 L .65468 .74014 L p .707 .577 .707 r
F P
0 g
s
.83469 .68483 m .82755 .72037 L .83473 .71105 L p .707 .577 .707 r
F P
0 g
s
.83473 .71105 m .84186 .67551 L .83469 .68483 L p .707 .577 .707 r
F P
0 g
s
.63709 .68169 m .64423 .64615 L .64161 .63484 L p .707 .577 .707 r
F P
0 g
s
.84486 .58341 m .83953 .63814 L .8367 .62821 L p .707 .577 .707 r
F P
0 g
s
.8367 .62821 m .84203 .57348 L .84486 .58341 L p .707 .577 .707 r
F P
0 g
s
.63653 .61596 m .64186 .56123 L .64896 .55239 L p .707 .577 .707 r
F P
0 g
s
.64161 .63484 m .63447 .67038 L .63709 .68169 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83672 .74647 m .83341 .76432 L .84058 .75508 L p .707 .577 .707 r
F P
0 g
s
.84058 .75508 m .84388 .73722 L .83672 .74647 L p .707 .577 .707 r
F P
0 g
s
.64245 .72827 m .64575 .71042 L .64309 .69932 L p .707 .577 .707 r
F P
0 g
s
.64309 .69932 m .63979 .71717 L .64245 .72827 L p .707 .577 .707 r
F P
0 g
s
.64896 .55239 m .64363 .60712 L .63653 .61596 L p .707 .577 .707 r
F P
0 g
s
.84186 .67551 m .83473 .71105 L .8321 .69975 L p .707 .577 .707 r
F P
0 g
s
.8321 .69975 m .83924 .6642 L .84186 .67551 L p .707 .577 .707 r
F P
0 g
s
.63447 .67038 m .64161 .63484 L .64878 .62553 L p .707 .577 .707 r
F P
0 g
s
.84203 .57348 m .8367 .62821 L .82421 .61817 L p .707 .577 .707 r
F P
0 g
s
.82421 .61817 m .82954 .56344 L .84203 .57348 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64363 .60712 m .64896 .55239 L .66531 .5455 L p .707 .577 .707 r
F P
0 g
s
.3881 .62598 m .39343 .57125 L .3624 .56634 L p .707 .577 .707 r
F P
0 g
s
.39343 .57125 m .3881 .62598 L .4198 .62792 L p .707 .577 .707 r
F P
0 g
s
.4198 .62792 m .42513 .57319 L .39343 .57125 L p .707 .577 .707 r
F P
0 g
s
.64878 .62553 m .64165 .66107 L .63447 .67038 L p .707 .577 .707 r
F P
0 g
s
.84388 .73722 m .84058 .75508 L .83791 .74398 L p .707 .577 .707 r
F P
0 g
s
.83791 .74398 m .84121 .72612 L .84388 .73722 L p .707 .577 .707 r
F P
0 g
s
.42513 .57319 m .4198 .62792 L .44908 .6267 L p .707 .577 .707 r
F P
0 g
s
.44908 .6267 m .45441 .57197 L .42513 .57319 L p .707 .577 .707 r
F P
0 g
s
.63979 .71717 m .64309 .69932 L .65025 .69007 L p .707 .577 .707 r
F P
0 g
s
.35707 .62107 m .3624 .56634 L .33509 .55893 L p .707 .577 .707 r
F P
0 g
s
.3624 .56634 m .35707 .62107 L .3881 .62598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65025 .69007 m .64695 .70793 L .63979 .71717 L p .707 .577 .707 r
F P
0 g
s
.66531 .5455 m .65998 .60023 L .64363 .60712 L p .707 .577 .707 r
F P
0 g
s
.45441 .57197 m .44908 .6267 L .47306 .62244 L p .707 .577 .707 r
F P
0 g
s
.47306 .62244 m .4784 .5677 L .45441 .57197 L p .707 .577 .707 r
F P
0 g
s
.83924 .6642 m .8321 .69975 L .81993 .68755 L p .707 .577 .707 r
F P
0 g
s
.81993 .68755 m .82707 .65201 L .83924 .6642 L p .707 .577 .707 r
F P
0 g
s
.64165 .66107 m .64878 .62553 L .66506 .61911 L p .707 .577 .707 r
F P
0 g
s
.82954 .56344 m .82421 .61817 L .80329 .609 L p .707 .577 .707 r
F P
0 g
s
.80329 .609 m .80862 .55427 L .82954 .56344 L p .707 .577 .707 r
F P
0 g
s
.32976 .61366 m .33509 .55893 L .31417 .54976 L p .707 .577 .707 r
F P
0 g
s
.33509 .55893 m .32976 .61366 L .35707 .62107 L p .707 .577 .707 r
F P
0 g
s
.38422 .68484 m .39136 .6493 L .36078 .64138 L p .707 .577 .707 r
F P
0 g
s
.39136 .6493 m .38422 .68484 L .41552 .68949 L p .707 .577 .707 r
F P
0 g
s
.41552 .68949 m .42266 .65395 L .39136 .6493 L p .707 .577 .707 r
F P
0 g
s
.65998 .60023 m .66531 .5455 L .6893 .54123 L p .707 .577 .707 r
F P
0 g
s
.42266 .65395 m .41552 .68949 L .44448 .69042 L p .707 .577 .707 r
F P
0 g
s
.44448 .69042 m .45162 .65487 L .42266 .65395 L p .707 .577 .707 r
F P
0 g
s
.35364 .67692 m .36078 .64138 L .33391 .63097 L p .707 .577 .707 r
F P
0 g
s
.36078 .64138 m .35364 .67692 L .38422 .68484 L p .707 .577 .707 r
F P
0 g
s
.66506 .61911 m .65792 .65465 L .64165 .66107 L p .707 .577 .707 r
F P
0 g
s
.84121 .72612 m .83791 .74398 L .82568 .73211 L p .707 .577 .707 r
F P
0 g
s
.82568 .73211 m .82898 .71425 L .84121 .72612 L p .707 .577 .707 r
F P
0 g
s
.64695 .70793 m .65025 .69007 L .66654 .68359 L p .707 .577 .707 r
F P
0 g
s
.4784 .5677 m .47306 .62244 L .48941 .61554 L p .707 .577 .707 r
F P
0 g
s
.48941 .61554 m .49474 .56081 L .4784 .5677 L p .707 .577 .707 r
F P
0 g
s
.38989 .72428 m .39319 .70642 L .36253 .69896 L p .707 .577 .707 r
F P
0 g
s
.39319 .70642 m .38989 .72428 L .42127 .72852 L p .707 .577 .707 r
F P
0 g
s
.42127 .72852 m .42457 .71067 L .39319 .70642 L p .707 .577 .707 r
F P
0 g
s
.31417 .54976 m .30883 .60449 L .32976 .61366 L p .707 .577 .707 r
F P
0 g
s
.80862 .55427 m .80329 .609 L .77597 .6016 L p .707 .577 .707 r
F P
0 g
s
.77597 .6016 m .78131 .54686 L .80862 .55427 L p .707 .577 .707 r
F P
0 g
s
.33391 .63097 m .32677 .66651 L .35364 .67692 L p .707 .577 .707 r
F P
0 g
s
.45162 .65487 m .44448 .69042 L .46826 .68753 L p .707 .577 .707 r
F P
0 g
s
.46826 .68753 m .4754 .65199 L .45162 .65487 L p .707 .577 .707 r
F P
0 g
s
.6893 .54123 m .68396 .59597 L .65998 .60023 L p .707 .577 .707 r
F P
0 g
s
.32677 .66651 m .33391 .63097 L .31339 .61909 L p .707 .577 .707 r
F P
0 g
s
.66654 .68359 m .66324 .70144 L .64695 .70793 L p .707 .577 .707 r
F P
0 g
s
.42457 .71067 m .42127 .72852 L .45029 .72913 L p .707 .577 .707 r
F P
0 g
s
.45029 .72913 m .4536 .71128 L .42457 .71067 L p .707 .577 .707 r
F P
0 g
s
.35923 .71681 m .36253 .69896 L .33557 .689 L p .707 .577 .707 r
F P
0 g
s
.36253 .69896 m .35923 .71681 L .38989 .72428 L p .707 .577 .707 r
F P
0 g
s
.30883 .60449 m .31417 .54976 L .30168 .53972 L p .707 .577 .707 r
F P
0 g
s
.82707 .65201 m .81993 .68755 L .79941 .67567 L p .707 .577 .707 r
F P
0 g
s
.79941 .67567 m .80655 .64013 L .82707 .65201 L p .707 .577 .707 r
F P
0 g
s
.65792 .65465 m .66506 .61911 L .68884 .61623 L p .707 .577 .707 r
F P
0 g
s
.68396 .59597 m .6893 .54123 L .71858 .54001 L p .707 .577 .707 r
F P
0 g
s
.33557 .689 m .33227 .70685 L .35923 .71681 L p .707 .577 .707 r
F P
0 g
s
.31339 .61909 m .30625 .65463 L .32677 .66651 L p .707 .577 .707 r
F P
0 g
s
.78131 .54686 m .77597 .6016 L .74495 .59668 L p .707 .577 .707 r
F P
0 g
s
.74495 .59668 m .75028 .54195 L .78131 .54686 L p .707 .577 .707 r
F P
0 g
s
.4536 .71128 m .45029 .72913 L .47412 .72604 L p .707 .577 .707 r
F P
0 g
s
.47412 .72604 m .47742 .70819 L .4536 .71128 L p .707 .577 .707 r
F P
0 g
s
.33227 .70685 m .33557 .689 L .31497 .67752 L p .707 .577 .707 r
F P
0 g
s
.71324 .59474 m .71858 .54001 L .75028 .54195 L p .707 .577 .707 r
F P
0 g
s
.71858 .54001 m .71324 .59474 L .68396 .59597 L p .707 .577 .707 r
F P
0 g
s
.68884 .61623 m .6817 .65177 L .65792 .65465 L p .707 .577 .707 r
F P
0 g
s
.82898 .71425 m .82568 .73211 L .80508 .72063 L p .707 .577 .707 r
F P
0 g
s
.80508 .72063 m .80838 .70278 L .82898 .71425 L p .707 .577 .707 r
F P
0 g
s
.30168 .53972 m .29634 .59445 L .30883 .60449 L p .707 .577 .707 r
F P
0 g
s
.75028 .54195 m .74495 .59668 L .71324 .59474 L p .707 .577 .707 r
F P
0 g
s
.4754 .65199 m .46826 .68753 L .48454 .68112 L p .707 .577 .707 r
F P
0 g
s
.48454 .68112 m .49168 .64558 L .4754 .65199 L p .707 .577 .707 r
F P
0 g
s
.66324 .70144 m .66654 .68359 L .69036 .6805 L p .707 .577 .707 r
F P
0 g
s
.30625 .65463 m .31339 .61909 L .30122 .6069 L p .707 .577 .707 r
F P
0 g
s
.31497 .67752 m .31167 .69537 L .33227 .70685 L p .707 .577 .707 r
F P
0 g
s
.49474 .56081 m .48941 .61554 L .49652 .6067 L p .707 .577 .707 r
F P
0 g
s
.49652 .6067 m .50185 .55197 L .49474 .56081 L p .707 .577 .707 r
F P
0 g
s
.80655 .64013 m .79941 .67567 L .77254 .66526 L p .707 .577 .707 r
F P
0 g
s
.77254 .66526 m .77968 .62972 L .80655 .64013 L p .707 .577 .707 r
F P
0 g
s
.6817 .65177 m .68884 .61623 L .7178 .61716 L p .707 .577 .707 r
F P
0 g
s
.69036 .6805 m .68706 .69835 L .66324 .70144 L p .707 .577 .707 r
F P
0 g
s
.29634 .59445 m .30168 .53972 L .29885 .52979 L p .707 .577 .707 r
F P
0 g
s
.30122 .6069 m .29408 .64244 L .30625 .65463 L p .707 .577 .707 r
F P
0 g
s
.47742 .70819 m .47412 .72604 L .4904 .71955 L p .707 .577 .707 r
F P
0 g
s
.4904 .71955 m .49371 .7017 L .47742 .70819 L p .707 .577 .707 r
F P
0 g
s
.31167 .69537 m .31497 .67752 L .30274 .66565 L p .707 .577 .707 r
F P
0 g
s
.7178 .61716 m .71066 .6527 L .6817 .65177 L p .707 .577 .707 r
F P
0 g
s
.77968 .62972 m .77254 .66526 L .74196 .65735 L p .707 .577 .707 r
F P
0 g
s
.74196 .65735 m .7491 .62181 L .77968 .62972 L p .707 .577 .707 r
F P
0 g
s
.71066 .6527 m .7178 .61716 L .7491 .62181 L p .707 .577 .707 r
F P
0 g
s
.80838 .70278 m .80508 .72063 L .77813 .71067 L p .707 .577 .707 r
F P
0 g
s
.77813 .71067 m .78143 .69282 L .80838 .70278 L p .707 .577 .707 r
F P
0 g
s
.68706 .69835 m .69036 .6805 L .71938 .6811 L p .707 .577 .707 r
F P
0 g
s
.7491 .62181 m .74196 .65735 L .71066 .6527 L p .707 .577 .707 r
F P
0 g
s
.30274 .66565 m .29944 .6835 L .31167 .69537 L p .707 .577 .707 r
F P
0 g
s
.29885 .52979 m .29351 .58453 L .29634 .59445 L p .707 .577 .707 r
F P
0 g
s
.49168 .64558 m .48454 .68112 L .49171 .6718 L p .707 .577 .707 r
F P
0 g
s
.49171 .6718 m .49885 .63626 L .49168 .64558 L p .707 .577 .707 r
F P
0 g
s
.71938 .6811 m .71608 .69896 L .68706 .69835 L p .707 .577 .707 r
F P
0 g
s
.29408 .64244 m .30122 .6069 L .2986 .59559 L p .707 .577 .707 r
F P
0 g
s
.50185 .55197 m .49652 .6067 L .49369 .59678 L p .707 .577 .707 r
F P
0 g
s
.49369 .59678 m .49902 .54204 L .50185 .55197 L p .707 .577 .707 r
F P
0 g
s
.78143 .69282 m .77813 .71067 L .74746 .7032 L p .707 .577 .707 r
F P
0 g
s
.74746 .7032 m .75076 .68535 L .78143 .69282 L p .707 .577 .707 r
F P
0 g
s
.71608 .69896 m .71938 .6811 L .75076 .68535 L p .707 .577 .707 r
F P
0 g
s
.75076 .68535 m .74746 .7032 L .71608 .69896 L p .707 .577 .707 r
F P
0 g
s
.29351 .58453 m .29885 .52979 L .30595 .52095 L p .707 .577 .707 r
F P
0 g
s
.2986 .59559 m .29146 .63113 L .29408 .64244 L p .707 .577 .707 r
F P
0 g
s
.49371 .7017 m .4904 .71955 L .49757 .71031 L p .707 .577 .707 r
F P
0 g
s
.49757 .71031 m .50087 .69245 L .49371 .7017 L p .707 .577 .707 r
F P
0 g
s
.29944 .6835 m .30274 .66565 L .30008 .65455 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30008 .65455 m .29678 .6724 L .29944 .6835 L p .707 .577 .707 r
F P
0 g
s
.49885 .63626 m .49171 .6718 L .48909 .66049 L p .707 .577 .707 r
F P
0 g
s
.48909 .66049 m .49623 .62495 L .49885 .63626 L p .707 .577 .707 r
F P
0 g
s
.30595 .52095 m .30062 .57568 L .29351 .58453 L p .707 .577 .707 r
F P
0 g
s
.29146 .63113 m .2986 .59559 L .30577 .58627 L p .707 .577 .707 r
F P
0 g
s
.49902 .54204 m .49369 .59678 L .4812 .58674 L p .707 .577 .707 r
F P
0 g
s
.4812 .58674 m .48653 .532 L .49902 .54204 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30062 .57568 m .30595 .52095 L .3223 .51406 L p .707 .577 .707 r
F P
0 g
s
.30577 .58627 m .29864 .62181 L .29146 .63113 L p .707 .577 .707 r
F P
0 g
s
.50087 .69245 m .49757 .71031 L .4949 .69921 L p .707 .577 .707 r
F P
0 g
s
.4949 .69921 m .4982 .68135 L .50087 .69245 L p .707 .577 .707 r
F P
0 g
s
.29678 .6724 m .30008 .65455 L .30724 .6453 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30724 .6453 m .30394 .66316 L .29678 .6724 L p .707 .577 .707 r
F P
0 g
s
.49623 .62495 m .48909 .66049 L .47692 .6483 L p .707 .577 .707 r
F P
0 g
s
.47692 .6483 m .48406 .61276 L .49623 .62495 L p .707 .577 .707 r
F P
0 g
s
.3223 .51406 m .31697 .56879 L .30062 .57568 L p .707 .577 .707 r
F P
0 g
s
.29864 .62181 m .30577 .58627 L .32205 .57986 L p .707 .577 .707 r
F P
0 g
s
.48653 .532 m .4812 .58674 L .46027 .57756 L p .707 .577 .707 r
F P
0 g
s
.46027 .57756 m .46561 .52283 L .48653 .532 L p .707 .577 .707 r
F P
0 g
s
.31697 .56879 m .3223 .51406 L .34629 .50979 L p .707 .577 .707 r
F P
0 g
s
.32205 .57986 m .31491 .6154 L .29864 .62181 L p .707 .577 .707 r
F P
0 g
s
.4982 .68135 m .4949 .69921 L .48267 .68734 L p .707 .577 .707 r
F P
0 g
s
.48267 .68734 m .48597 .66948 L .4982 .68135 L p .707 .577 .707 r
F P
0 g
s
.30394 .66316 m .30724 .6453 L .32353 .63882 L p .707 .577 .707 r
F P
0 g
s
.32353 .63882 m .32023 .65667 L .30394 .66316 L p .707 .577 .707 r
F P
0 g
s
.46561 .52283 m .46027 .57756 L .43296 .57016 L p .707 .577 .707 r
F P
0 g
s
.43296 .57016 m .4383 .51543 L .46561 .52283 L p .707 .577 .707 r
F P
0 g
s
.48406 .61276 m .47692 .6483 L .4564 .63642 L p .707 .577 .707 r
F P
0 g
s
.4564 .63642 m .46354 .60088 L .48406 .61276 L p .707 .577 .707 r
F P
0 g
s
.34629 .50979 m .34095 .56453 L .31697 .56879 L p .707 .577 .707 r
F P
0 g
s
.31491 .6154 m .32205 .57986 L .34583 .57697 L p .707 .577 .707 r
F P
0 g
s
.34095 .56453 m .34629 .50979 L .37556 .50857 L p .707 .577 .707 r
F P
0 g
s
.4383 .51543 m .43296 .57016 L .40194 .56525 L p .707 .577 .707 r
F P
0 g
s
.40194 .56525 m .40727 .51051 L .4383 .51543 L p .707 .577 .707 r
F P
0 g
s
.34583 .57697 m .33869 .61251 L .31491 .6154 L p .707 .577 .707 r
F P
0 g
s
.48597 .66948 m .48267 .68734 L .46207 .67586 L p .707 .577 .707 r
F P
0 g
s
.46207 .67586 m .46537 .65801 L .48597 .66948 L p .707 .577 .707 r
F P
0 g
s
.37023 .56331 m .37556 .50857 L .40727 .51051 L p .707 .577 .707 r
F P
0 g
s
.37556 .50857 m .37023 .56331 L .34095 .56453 L p .707 .577 .707 r
F P
0 g
s
.32023 .65667 m .32353 .63882 L .34735 .63572 L p .707 .577 .707 r
F P
0 g
s
.40727 .51051 m .40194 .56525 L .37023 .56331 L p .707 .577 .707 r
F P
0 g
s
.46354 .60088 m .4564 .63642 L .42953 .62601 L p .707 .577 .707 r
F P
0 g
s
.42953 .62601 m .43667 .59047 L .46354 .60088 L p .707 .577 .707 r
F P
0 g
s
.33869 .61251 m .34583 .57697 L .37479 .5779 L p .707 .577 .707 r
F P
0 g
s
.34735 .63572 m .34405 .65358 L .32023 .65667 L p .707 .577 .707 r
F P
0 g
s
.37479 .5779 m .36765 .61344 L .33869 .61251 L p .707 .577 .707 r
F P
0 g
s
.43667 .59047 m .42953 .62601 L .39895 .61809 L p .707 .577 .707 r
F P
0 g
s
.39895 .61809 m .40609 .58255 L .43667 .59047 L p .707 .577 .707 r
F P
0 g
s
.36765 .61344 m .37479 .5779 L .40609 .58255 L p .707 .577 .707 r
F P
0 g
s
.46537 .65801 m .46207 .67586 L .43512 .6659 L p .707 .577 .707 r
F P
0 g
s
.43512 .6659 m .43842 .64805 L .46537 .65801 L p .707 .577 .707 r
F P
0 g
s
.34405 .65358 m .34735 .63572 L .37637 .63633 L p .707 .577 .707 r
F P
0 g
s
.40609 .58255 m .39895 .61809 L .36765 .61344 L p .707 .577 .707 r
F P
0 g
s
.37637 .63633 m .37307 .65419 L .34405 .65358 L p .707 .577 .707 r
F P
0 g
s
.43842 .64805 m .43512 .6659 L .40445 .65843 L p .707 .577 .707 r
F P
0 g
s
.40445 .65843 m .40775 .64058 L .43842 .64805 L p .707 .577 .707 r
F P
0 g
s
.37307 .65419 m .37637 .63633 L .40775 .64058 L p .707 .577 .707 r
F P
0 g
s
.40775 .64058 m .40445 .65843 L .37307 .65419 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RGoo6000O7oo001mOol<0005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Eoo`P000EJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001cOol0079oo`<00003
FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001`
Ool006ioo`@000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP<006eoo`00K7oo0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006]oo`00JWoo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Uoo`00J7oo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFJGoo001VOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1VOol006Eoo`8000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001oogoo06Ioo`00I7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0IGoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYFIgoo
001SOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IGoo001UOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`03
001JEP0000P000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Ggoo20000eYF00<005YFFUH00UYF2@0000=J
EP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001JOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH60007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol005Qoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10002eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001EOol2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol005Aoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Uoo`l004aoo`00E7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Ioo`<00003FUH005YF00MJEP03001JEUYF009JEPT004=oo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH003eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
000iOol005Aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8003Moo`00Dgoo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH3000eOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF008003=oo`00Dgoo00<005YF000015YF00@005YFFUIJEQL000IJEP03
001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00Dgoo00<0
05YF00000eYF1@0000=JEP00FUH01EYF1@000eYF1@000UYF10000UYF00<005YFFUH015YF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000`Ool005=oo`04001JEP00FUH20005FUH00`00FUIJ
EP06FUH01000FUIJEUYF2@001EYF10001EYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002ioo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0002FUH=00000eYF001JEP04FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eo
o`00Dgoo0P000eYF00<005YF00005@0025YF00<005YFFUH01UYF0`0015YF00@005YFFUIJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002eoo`00Dgoo0P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF1`000UYF00<005YFFUH01UYF00<005YFFUH00`0000=JEP00FUH00UYF0P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;7oo001COol200000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH20003FUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYFFUH2000/Ool005=oo`@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP8000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00H0
05YFFUH005YF000/Ool005Aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000/Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH01000FUIJEUYF5`001UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH]Ool0041oo`P000aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEUYF
009JEP<000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF008000=J
EPD00003FUH005YF00EJEPH000=oo`D00003Ool000000080009JEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool003Qoo`P000=JEP03001JEUYF009JEPT000=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJ
EP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH0
05YF0`001EYF00<005YFFUH01EYF00<005YFFUH00UYF4@001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUH000AJEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH50005FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<Goo0P00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000UYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJEP03001J
EUYF00EJEP@000AJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP02FUH2000]Ool0
02ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP`0009JEP03001JEUYF00EJEPH000QJEP03001JEUYF00AJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEP0000l000QJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEP0002eoo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000UYF00D005YFFUIJEP00009JEP800003Ool0000000<000IJEP03001JEUYF009JEP<000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000050002FUH00`00FUIJEP06FUH01000FUIJEUYF
1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004
FUH300000eYF001JEP03FUH20002Ool00`00FUH000030002FUH00`00FUIJEP05FUH300000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000`0025YF00<005YFFUH00eYF00@005YFFUIJEP<002ioo`00;Goo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
0`0015YF00<005YFFUH00P001EYF0P0000=oo`00FUH00UYF00<005YF00003`001EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP<000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002ioo`00;Goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF
00<005YFFUH00eYF0P000eYF00@005YF000000=JEP04001JEUYFFUH50007FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF00=JEPl00003FUH0000000<000MJEP03001JEUYF00=JEP8000IJEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
00000P001UYF00L005YFFUIJEP00FUH0000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00@000=J
EP03001JEUYF00EJEP03001JEUYF00H000MJEP03001JEUYF00EJEP8000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00L0
05YFFUIJEP00FUH0000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00AJEP03001JEUYF00MJEP04001JEUYF0004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP03FUH2000_Ool002eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000YJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004
FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@000QJEP8000AJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003
FUH01000FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000AJEPD0009J
EP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000004FUH01000
FUIJEUYF3`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo000/Ool0
0`00FUH00004FUH01000FUIJEUYF5`001UYF0`000eYF1@001UYF2@0015YF00<005YFFUH01eYF00@0
05YFFUIJEP@000=JEP03001JEP0000<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEP000002FUH60004FUH20006Ool90008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000`Ool002aoo`03001JEP0000=JEPD00003FUH005YF00AJEPH000=oo`D0009oo`@0009JEP<00003
FUH00000009JEP03001JEUYF00IJEP03001JEUYF00IJEPL000IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
0003FUH005YF009JEP03001JEUYF00=JEP8000ioo`<000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP0002moo`00;7oo00@005YF001JEP8000IJEP03001JEUYF00EJEP04001JEUYFFUH90005
Ool60002FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH30003
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH40003FUH300000eYF001J
EP04FUH01000FUH000003goo0`0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00;7oo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH=000015YF
000000001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001eYF00<005YFFUH00P00
00=JEP0000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF10000eYF00<005YF
FUH00P001EYF00D005YFFUIJEP0000Qoo`<000Ioo`<000MJEP03001JEUYF00=JEP05001JEUYFFUH0
000^Ool002aoo`8000=JEP03001JEUYF00=JEQ8000QJEP03001JEUYF00@0009JEP80009JEP8000AJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP<000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800005FUH005YFFUH00005FUH30002
FUH01@00FUIJEUYF00001goo1@0027oo0P0015YF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00
;7oo0P000eYF1`000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00/005YFFUH005YF001J
EP00FUH005YF0080009JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003
FUH005YF00EJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEP00008000=JEP8000Ioo`D000Yoo`<00003FUH005YF00EJEP06001JEUYF
001JEP00;Goo000/Ool2000015YF000000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000`000UYF0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH010001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P001UYF00<005YF00001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00@005YFFUIJEP<0
0003FUH0000000Ioo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool40004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP02FUH30004
FUH20003FUH60002FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
1@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF0000
0eYF00<005YFFUH00eYF00<005YF00004P0047oo0P000eYF00L005YFFUIJEP00FUH0000]Ool002eo
o`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP03001JEUYF0080009JEP05001JEP00001JEP030002FUH90003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH300000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH00UYF
1P003goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH200000eYF001JEP04FUH30003FUH40002FUH0
1000FUIJEUYF1P000UYF00<005YFFUH01EYF00@005YFFUIJEPD00003FUH0000000=JEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P003Woo0P000eYF0P00;Woo000]
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000
FUH000001UYF00D005YF000005YF00@0009JEP04001JEUYFFUH500000eYF0000000<0004FUH02@00
FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF
0`0027oo1P0000AJEP00FUH002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH50002FUH00`00FUIJ
EP02FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF20000eYF00<005YFFUH00P0000=JEP00Ool0;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH300000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH0
0`00FUH000030004FUH01`00FUIJEUYF001JEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
00QJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00YJEP04001JEUYFFUH30005FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH50007FUH00`00
FUIJEP05FUH70008FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUH0000^Ool002aoo`80
00AJEP04001JEUYFFUH@0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40008FUH00`00FUIJEP03
FUH50009FUH00`00FUIJEP09FUH01@00FUH00000FUH00P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0000EJEP00000005YF00<000MJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000AJEP03001JEUYF00EJEP<000AJEP8002moo`00;7oo0P000UYF1P000Woo1000
0UYF00<005YFFUH01EYF1P0025YF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YFFUH01UYF
00<005YFFUH010001EYF00<005YFFUH01UYF1@000eYF0P001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP<00003FUH005YF00=JEP8000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP@00003FUH005YF00IJEP04001JEUYF0003FUH2000_Ool002aoo`04FUH000000002
FUH00`00Oomoo`07Ool50006FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH>0003FUH01000FUIJEUYF0P001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000100000=JEP00FUH015YF100000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000EJEP03001JEUYF009JEP<00003FUH007oo
02ioo`00:goo0`0015YF0`0037oo10000UYF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00<005YF
FUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH3
00000eYF001JEP04FUH01000FUIJEUYF0`001UYF00<005YFFUH00`0015YF00<005YFFUH015YF1000
00=JEP00FUH01EYF0P00<7oo000[Ool30004FUH00`00FUIJEP02000>Ool@0006FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00
FUH30005FUH00`00FUIJEP02FUH60002FUH00`00FUH000040003FUH00`00FUIJEP05FUH00`00FUIJ
EP020006FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEP8000moo`<000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEP0000@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004Ool90002FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH20004FUH01000FUH00000;Woo000[Ool00`00FUIJEP03FUH00`00FUIJEP03FUH90007Ool5
000;Ool200000eYF001JEP05FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF10000UYF00<005YF
FUH01EYF00@005YFFUIJEPD000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP0000AJEP<000=JEP07001JEUYFFUH005YF000027oo1@000UYF00<005YFFUH01EYF00@005YF
FUIJEPD0009JEP03001JEUYF009JEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF00<005YFFUH0
10000eYF00<005YFFUH00UYF30003Goo0P001UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03
001JEUYF00h000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP0000AJEP03001JEUYF00800003FUH005YF009JEP03001JEP0000Uoo`<00003Ool00000
00`000Eoo`<000AJEP03001oogoo02]oo`00;7oo00<005YFFUH00UYF10001UYF00<005YFFUH01UYF
00@005YFFUIJEPL000aoo`8000=JEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYF0002FUH00`00FUIJEP03FUH20003FUH2000SOol00`00FUIJEP02FUH00`00Oomo
o`0[Ool002eoo`03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00@000Yoo`800003FUH005YF00=JEP800005OomJEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`001EYF00D005YF000005YF008002Aoo`03001JEUYF008002eoo`00;Woo0`00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100027oo0P00
15YF00<007ooOol00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@0
05YFFUIJEP<002Eoo`@002eoo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000Aoo`D0009JEP80009oo`=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH4000SOol2000]Ool002ioo`8000=J
EQ@000AJEP03001JEUYF00MJEP04001JEUYFFUH40003FUH00`00FUH000030002Ool3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUHE0008FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`000UYF0`0025YF00<005YFFUH010007Woo0P00;Woo000^Ool200000eYF00000002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03
0002Ool3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH<000<FUH00`00FUIJEP06
FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00@005YF000000MJEP03001JEUYF00AJ
EPL001Eoo`@002ioo`00;Woo0`000Woo0`0025YF00<005YFFUH01UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF0`000eYF0`000Woo0eYF00<005YFFUH015YF00<005YFFUH01EYF20002eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01@001UYF00L005YFFUIJEP00FUH00002FUH01000
FUIJEUYF0P0015YF00<005YFFUH01eYF00<005YFFUH00UYF5@000UYF0P00;Woo000]Ool30005Ool2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP0200000eYF
00000003Ool3FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00=JEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008002moo`00;Goo10001Woo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0015YF00<005YFFUH00eYF0`000goo0eYF00<005YFFUH015YF00<005YF00000P002UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YF00001UYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P00;goo000]Ool01@00FUH005YF00001goo0`0000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH01EYF0P000goo0eYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00UYF0P000eYF00<005YF00001UYF00@005YFFUIJEP800003Ool000000080009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002eoo`80
00=JEP03001oogoo00Moo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF008000IJ
EP03001JEP00009oo`=JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000000001UYF
00H005YFFUH005YF0005Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo
000^Ool01000FUIJEUYF0`002goo10000UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00H005YFFUIJEP00Ool3FUH01000FUH000001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
0000009oo`8000=JEP07001JEUYFFUH005YF000037oo200015YF00@005YFFUIJEPD003=oo`00;Woo
00D005YFFUIJEP00009JEP03001oogoo00aoo`P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH005YF009JEP03001ooeYF009JEP800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00
0004Ool200000eYF001JEP02FUH00`00FUH0000DOol8000hOol002moo`03001JEP0000AJEP8000mo
o`H0009JEP03001JEUYF00EJEP04001JEUYFFUH500000goo00000003FUH01@00OomJEUYF00000eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000Ioo`8000=JEP8005Eoo`00<7oo0P001UYF
0P003Goo1@0000=oo`000000300027oo00L005YF001JEP00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP000goo1P000UYF0P00EGoo000aOol00`00FUIJEP04FUH00`00FUH00003
000:Ool3000IOol2000015YF0000000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
10000eYF00L005YF001JEP00FUH0001EOol0039oo`8000AJEP03001JEUYF00=JEP@002=oo`03001J
EP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH007oo
05Aoo`00=7oo00@005YFFUH000QJEP04001JEP00000POol2000015YF001oo`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000eYF0P000eYF00<005YFFUH00UYF00<005YF0000EGoo000eOol30008
FUH01000FUIJEUYF0`006goo0P0000=JEP0000000Woo00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@0
05YFFUIJEP<000IJEP800003FUH005YF00=JEP8005Ioo`00=goo0P001UYF00<005YFFUH01EYF1P00
47oo1@000eYF0P000goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00EJEP<0
00AJEP8005Ioo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJ
EP00FUH00005Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH30002FUH40006FUH00`00FUIJEP020002FUH2001FOol003eoo`@000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20008Ool30006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH3001GOol0045oo`8000AJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000030004FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH2001GOol004=oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEP00000BOol50008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP04FUH<0002FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00@005YF000005Eoo`00AWoo1P00
15YF00<005YFFUH01UYF00@005YFFUIJEP@001Uoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJ
EPd000Aoo`P0009JEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP02FUH00`00Oomo
o`1BOol004aooa4002=ooaD0009JEP80011ooa<000Aoo`800003FUH005YF00=JEP03001oogoo059o
o`00T7oo00@005YFFUH000EJEP8000moo`<001Eoo`8000AJEP03001oogoo059oo`00TGoo0`001EYF
00@005YF000002Moo`03001JEUYF008005Aoo`00Tgoo00<005YFFUH00eYF00@005YFFUIJEP<002Eo
o`@005Aoo`00U7oo0P000UYF00<005YFFUH01EYF10008goo0P00E7oo002FOol30008FUH00`00FUIJ
EP04000NOol2001EOol009Qoo`8000MJEP03001JEUYF00AJEPL001Eoo`@005Eoo`00VWoo0P0015YF
00<005YFFUH01eYF00<005YFFUH00UYF200027oo1@000UYF0P00EGoo002LOol300000eYF001JEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YFFUH00P00EWoo002OOol40006FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:=oo`@0009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:Moo`D000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol00:aoo`@0009JEP03001JEUYF00EJ
EP04001JEUYFFUH5001JOol00;1oo`h005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]34\[InvisibleSpace]"     "\
\[InvisibleSpace]10.696221996221263`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 34, "     ", 10.696221996221263, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59149 .74918 m .59109 .69355 L .55991 .69188 L p .707 .577 .707 r
F P
0 g
s
.59109 .69355 m .59149 .74918 L .62332 .74819 L p .707 .577 .707 r
F P
0 g
s
.62332 .74819 m .62292 .69257 L .59109 .69355 L p .707 .577 .707 r
F P
0 g
s
.62292 .69257 m .62332 .74819 L .6527 .74465 L p .707 .577 .707 r
F P
0 g
s
.6527 .74465 m .6523 .68903 L .62292 .69257 L p .707 .577 .707 r
F P
0 g
s
.56032 .74751 m .55991 .69188 L .53246 .68772 L p .707 .577 .707 r
F P
0 g
s
.55991 .69188 m .56032 .74751 L .59149 .74918 L p .707 .577 .707 r
F P
0 g
s
.6523 .68903 m .6527 .74465 L .67676 .7389 L p .707 .577 .707 r
F P
0 g
s
.67676 .7389 m .67635 .68327 L .6523 .68903 L p .707 .577 .707 r
F P
0 g
s
.59856 .80838 m .59709 .7712 L .56595 .77055 L p .707 .577 .707 r
F P
0 g
s
.59709 .7712 m .59856 .80838 L .63037 .80647 L p .707 .577 .707 r
F P
0 g
s
.63037 .80647 m .62891 .76929 L .59709 .7712 L p .707 .577 .707 r
F P
0 g
s
.62891 .76929 m .63037 .80647 L .65974 .8022 L p .707 .577 .707 r
F P
0 g
s
.65974 .8022 m .65827 .76501 L .62891 .76929 L p .707 .577 .707 r
F P
0 g
s
.53246 .68772 m .53286 .74334 L .56032 .74751 L p .707 .577 .707 r
F P
0 g
s
.53286 .74334 m .53246 .68772 L .5114 .68147 L p .707 .577 .707 r
F P
0 g
s
.56741 .80773 m .56595 .77055 L .53851 .76741 L p .707 .577 .707 r
F P
0 g
s
.56595 .77055 m .56741 .80773 L .59856 .80838 L p .707 .577 .707 r
F P
0 g
s
.65827 .76501 m .65974 .8022 L .68378 .79597 L p .707 .577 .707 r
F P
0 g
s
.68378 .79597 m .68231 .75879 L .65827 .76501 L p .707 .577 .707 r
F P
0 g
s
.67635 .68327 m .67676 .7389 L .69313 .73149 L p .707 .577 .707 r
F P
0 g
s
.69313 .73149 m .69272 .67587 L .67635 .68327 L p .707 .577 .707 r
F P
0 g
s
.53851 .76741 m .53998 .80459 L .56741 .80773 L p .707 .577 .707 r
F P
0 g
s
.59649 .85969 m .60157 .84248 L .57161 .83205 L p .707 .577 .707 r
F P
0 g
s
.60157 .84248 m .59649 .85969 L .62724 .86661 L p .707 .577 .707 r
F P
0 g
s
.62724 .86661 m .63232 .84939 L .60157 .84248 L p .707 .577 .707 r
F P
0 g
s
.5114 .68147 m .51181 .7371 L .53286 .74334 L p .707 .577 .707 r
F P
0 g
s
.56653 .84927 m .57161 .83205 L .54537 .81914 L p .707 .577 .707 r
F P
0 g
s
.57161 .83205 m .56653 .84927 L .59649 .85969 L p .707 .577 .707 r
F P
0 g
s
.53998 .80459 m .53851 .76741 L .51748 .76209 L p .707 .577 .707 r
F P
0 g
s
.63232 .84939 m .62724 .86661 L .65575 .86933 L p .707 .577 .707 r
F P
0 g
s
.65575 .86933 m .66083 .85211 L .63232 .84939 L p .707 .577 .707 r
F P
0 g
s
.51181 .7371 m .5114 .68147 L .49881 .67375 L p .707 .577 .707 r
F P
0 g
s
.54537 .81914 m .54029 .83636 L .56653 .84927 L p .707 .577 .707 r
F P
0 g
s
.51748 .76209 m .51895 .79927 L .53998 .80459 L p .707 .577 .707 r
F P
0 g
s
.68231 .75879 m .68378 .79597 L .70015 .7884 L p .707 .577 .707 r
F P
0 g
s
.70015 .7884 m .69868 .75122 L .68231 .75879 L p .707 .577 .707 r
F P
0 g
s
.54029 .83636 m .54537 .81914 L .5254 .805 L p .707 .577 .707 r
F P
0 g
s
.66083 .85211 m .65575 .86933 L .67925 .8676 L p .707 .577 .707 r
F P
0 g
s
.67925 .8676 m .68433 .85038 L .66083 .85211 L p .707 .577 .707 r
F P
0 g
s
.5254 .805 m .52032 .82221 L .54029 .83636 L p .707 .577 .707 r
F P
0 g
s
.49881 .67375 m .49921 .72938 L .51181 .7371 L p .707 .577 .707 r
F P
0 g
s
.69272 .67587 m .69313 .73149 L .70021 .72316 L p .707 .577 .707 r
F P
0 g
s
.70021 .72316 m .69981 .66754 L .69272 .67587 L p .707 .577 .707 r
F P
0 g
s
.51895 .79927 m .51748 .76209 L .50491 .7551 L p .707 .577 .707 r
F P
0 g
s
.49921 .72938 m .49881 .67375 L .49591 .66531 L p .707 .577 .707 r
F P
0 g
s
.50491 .7551 m .50637 .79228 L .51895 .79927 L p .707 .577 .707 r
F P
0 g
s
.52032 .82221 m .5254 .805 L .51368 .79101 L p .707 .577 .707 r
F P
0 g
s
.68433 .85038 m .67925 .8676 L .69542 .86158 L p .707 .577 .707 r
F P
0 g
s
.69542 .86158 m .7005 .84436 L .68433 .85038 L p .707 .577 .707 r
F P
0 g
s
.69868 .75122 m .70015 .7884 L .70723 .78024 L p .707 .577 .707 r
F P
0 g
s
.70723 .78024 m .70577 .74306 L .69868 .75122 L p .707 .577 .707 r
F P
0 g
s
.51368 .79101 m .5086 .80823 L .52032 .82221 L p .707 .577 .707 r
F P
0 g
s
.49591 .66531 m .49632 .72094 L .49921 .72938 L p .707 .577 .707 r
F P
0 g
s
.69981 .66754 m .70021 .72316 L .69731 .71473 L p .707 .577 .707 r
F P
0 g
s
.69731 .71473 m .69691 .6591 L .69981 .66754 L p .707 .577 .707 r
F P
0 g
s
.50637 .79228 m .50491 .7551 L .50202 .74713 L p .707 .577 .707 r
F P
0 g
s
.48698 .82191 m .49208 .32059 L .44807 .31746 L p .707 .577 .707 r
F P
0 g
s
.5086 .80823 m .51368 .79101 L .51134 .77855 L p .707 .577 .707 r
F P
0 g
s
.50202 .74713 m .50349 .78431 L .50637 .79228 L p .707 .577 .707 r
F P
0 g
s
.49632 .72094 m .49591 .66531 L .503 .65699 L p .707 .577 .707 r
F P
0 g
s
.51134 .77855 m .50626 .79577 L .5086 .80823 L p .707 .577 .707 r
F P
0 g
s
.503 .65699 m .5034 .71261 L .49632 .72094 L p .707 .577 .707 r
F P
0 g
s
.50349 .78431 m .50202 .74713 L .50911 .73897 L p .707 .577 .707 r
F P
0 g
s
.50626 .79577 m .51134 .77855 L .51861 .76884 L p .707 .577 .707 r
F P
0 g
s
.50911 .73897 m .51058 .77615 L .50349 .78431 L p .707 .577 .707 r
F P
0 g
s
.5034 .71261 m .503 .65699 L .51937 .64958 L p .707 .577 .707 r
F P
0 g
s
.51861 .76884 m .51353 .78605 L .50626 .79577 L p .707 .577 .707 r
F P
0 g
s
.51937 .64958 m .51977 .70521 L .5034 .71261 L p .707 .577 .707 r
F P
0 g
s
.51058 .77615 m .50911 .73897 L .52547 .7314 L p .707 .577 .707 r
F P
0 g
s
.51353 .78605 m .51861 .76884 L .53479 .76282 L p .707 .577 .707 r
F P
0 g
s
.51977 .70521 m .51937 .64958 L .54342 .64383 L p .707 .577 .707 r
F P
0 g
s
.52547 .7314 m .52694 .76858 L .51058 .77615 L p .707 .577 .707 r
F P
0 g
s
.53479 .76282 m .52971 .78004 L .51353 .78605 L p .707 .577 .707 r
F P
0 g
s
.54342 .64383 m .54382 .69945 L .51977 .70521 L p .707 .577 .707 r
F P
0 g
s
.52694 .76858 m .52547 .7314 L .54951 .72517 L p .707 .577 .707 r
F P
0 g
s
.52971 .78004 m .53479 .76282 L .55829 .76109 L p .707 .577 .707 r
F P
0 g
s
.54951 .72517 m .55098 .76236 L .52694 .76858 L p .707 .577 .707 r
F P
0 g
s
.49208 .32059 m .48698 .82191 L .53192 .82122 L p .707 .577 .707 r
F P
0 g
s
.55829 .76109 m .55321 .7783 L .52971 .78004 L p .707 .577 .707 r
F P
0 g
s
.53192 .82122 m .53702 .3199 L .49208 .32059 L p .707 .577 .707 r
F P
0 g
s
.54382 .69945 m .54342 .64383 L .5728 .64028 L p .707 .577 .707 r
F P
0 g
s
.5728 .64028 m .5732 .69591 L .54382 .69945 L p .707 .577 .707 r
F P
0 g
s
.55098 .76236 m .54951 .72517 L .57888 .7209 L p .707 .577 .707 r
F P
0 g
s
.55321 .7783 m .55829 .76109 L .5868 .76381 L p .707 .577 .707 r
F P
0 g
s
.57888 .7209 m .58035 .75808 L .55098 .76236 L p .707 .577 .707 r
F P
0 g
s
.5868 .76381 m .58172 .78103 L .55321 .7783 L p .707 .577 .707 r
F P
0 g
s
.53702 .3199 m .53192 .82122 L .5734 .81677 L p .707 .577 .707 r
F P
0 g
s
.5732 .69591 m .5728 .64028 L .60463 .6393 L p .707 .577 .707 r
F P
0 g
s
.60463 .6393 m .60504 .69492 L .5732 .69591 L p .707 .577 .707 r
F P
0 g
s
.5734 .81677 m .5785 .31546 L .53702 .3199 L p .707 .577 .707 r
F P
0 g
s
.7005 .84436 m .69542 .86158 L .7027 .85186 L p .707 .577 .707 r
F P
0 g
s
.7027 .85186 m .70778 .83465 L .7005 .84436 L p .707 .577 .707 r
F P
0 g
s
.44297 .81877 m .44807 .31746 L .40931 .3108 L p .707 .577 .707 r
F P
0 g
s
.44807 .31746 m .44297 .81877 L .48698 .82191 L p .707 .577 .707 r
F P
0 g
s
.70577 .74306 m .70723 .78024 L .70435 .77227 L p .707 .577 .707 r
F P
0 g
s
.70435 .77227 m .70288 .73509 L .70577 .74306 L p .707 .577 .707 r
F P
0 g
s
.58035 .75808 m .57888 .7209 L .61069 .71899 L p .707 .577 .707 r
F P
0 g
s
.61069 .71899 m .61216 .75617 L .58035 .75808 L p .707 .577 .707 r
F P
0 g
s
.58172 .78103 m .5868 .76381 L .61754 .77072 L p .707 .577 .707 r
F P
0 g
s
.61754 .77072 m .61246 .78794 L .58172 .78103 L p .707 .577 .707 r
F P
0 g
s
.5785 .31546 m .5734 .81677 L .60735 .809 L p .707 .577 .707 r
F P
0 g
s
.63581 .64097 m .63621 .6966 L .60504 .69492 L p .707 .577 .707 r
F P
0 g
s
.60504 .69492 m .60463 .6393 L .63581 .64097 L p .707 .577 .707 r
F P
0 g
s
.60735 .809 m .61245 .30769 L .5785 .31546 L p .707 .577 .707 r
F P
0 g
s
.69691 .6591 m .69731 .71473 L .68472 .70701 L p .707 .577 .707 r
F P
0 g
s
.68472 .70701 m .68432 .65138 L .69691 .6591 L p .707 .577 .707 r
F P
0 g
s
.40421 .81212 m .40931 .3108 L .37959 .30128 L p .707 .577 .707 r
F P
0 g
s
.40931 .3108 m .40421 .81212 L .44297 .81877 L p .707 .577 .707 r
F P
0 g
s
.24848 .71154 m .24808 .65592 L .2169 .65425 L p .707 .577 .707 r
F P
0 g
s
.24808 .65592 m .24848 .71154 L .28031 .71056 L p .707 .577 .707 r
F P
0 g
s
.28031 .71056 m .27991 .65494 L .24808 .65592 L p .707 .577 .707 r
F P
0 g
s
.27991 .65494 m .28031 .71056 L .3097 .70702 L p .707 .577 .707 r
F P
0 g
s
.3097 .70702 m .30929 .65139 L .27991 .65494 L p .707 .577 .707 r
F P
0 g
s
.70778 .83465 m .7027 .85186 L .70036 .8394 L p .707 .577 .707 r
F P
0 g
s
.70036 .8394 m .70544 .82219 L .70778 .83465 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21731 .70987 m .2169 .65425 L .18945 .65008 L p .707 .577 .707 r
F P
0 g
s
.2169 .65425 m .21731 .70987 L .24848 .71154 L p .707 .577 .707 r
F P
0 g
s
.70288 .73509 m .70435 .77227 L .69177 .76528 L p .707 .577 .707 r
F P
0 g
s
.69177 .76528 m .69031 .7281 L .70288 .73509 L p .707 .577 .707 r
F P
0 g
s
.30929 .65139 m .3097 .70702 L .33375 .70126 L p .707 .577 .707 r
F P
0 g
s
.33375 .70126 m .33335 .64564 L .30929 .65139 L p .707 .577 .707 r
F P
0 g
s
.64184 .71964 m .64331 .75682 L .61216 .75617 L p .707 .577 .707 r
F P
0 g
s
.61216 .75617 m .61069 .71899 L .64184 .71964 L p .707 .577 .707 r
F P
0 g
s
.64751 .78114 m .64243 .79836 L .61246 .78794 L p .707 .577 .707 r
F P
0 g
s
.61246 .78794 m .61754 .77072 L .64751 .78114 L p .707 .577 .707 r
F P
0 g
s
.61245 .30769 m .60735 .809 L .63046 .79867 L p .707 .577 .707 r
F P
0 g
s
.63046 .79867 m .63556 .29736 L .61245 .30769 L p .707 .577 .707 r
F P
0 g
s
.68432 .65138 m .68472 .70701 L .66367 .70076 L p .707 .577 .707 r
F P
0 g
s
.66367 .70076 m .66326 .64514 L .68432 .65138 L p .707 .577 .707 r
F P
0 g
s
.25555 .77251 m .25409 .73533 L .22294 .73468 L p .707 .577 .707 r
F P
0 g
s
.25409 .73533 m .25555 .77251 L .28737 .77061 L p .707 .577 .707 r
F P
0 g
s
.28737 .77061 m .2859 .73343 L .25409 .73533 L p .707 .577 .707 r
F P
0 g
s
.2859 .73343 m .28737 .77061 L .31673 .76633 L p .707 .577 .707 r
F P
0 g
s
.31673 .76633 m .31526 .72915 L .2859 .73343 L p .707 .577 .707 r
F P
0 g
s
.18945 .65008 m .18985 .70571 L .21731 .70987 L p .707 .577 .707 r
F P
0 g
s
.18985 .70571 m .18945 .65008 L .16839 .64384 L p .707 .577 .707 r
F P
0 g
s
.22441 .77187 m .22294 .73468 L .1955 .73155 L p .707 .577 .707 r
F P
0 g
s
.22294 .73468 m .22441 .77187 L .25555 .77251 L p .707 .577 .707 r
F P
0 g
s
.37449 .8026 m .37959 .30128 L .36181 .28983 L p .707 .577 .707 r
F P
0 g
s
.37959 .30128 m .37449 .8026 L .40421 .81212 L p .707 .577 .707 r
F P
0 g
s
.70544 .82219 m .70036 .8394 L .68864 .82542 L p .707 .577 .707 r
F P
0 g
s
.68864 .82542 m .69372 .8082 L .70544 .82219 L p .707 .577 .707 r
F P
0 g
s
.31526 .72915 m .31673 .76633 L .34077 .76011 L p .707 .577 .707 r
F P
0 g
s
.34077 .76011 m .3393 .72292 L .31526 .72915 L p .707 .577 .707 r
F P
0 g
s
.33335 .64564 m .33375 .70126 L .35012 .69386 L p .707 .577 .707 r
F P
0 g
s
.35012 .69386 m .34971 .63823 L .33335 .64564 L p .707 .577 .707 r
F P
0 g
s
.1955 .73155 m .19697 .76873 L .22441 .77187 L p .707 .577 .707 r
F P
0 g
s
.25348 .82349 m .25856 .80628 L .2286 .79585 L p .707 .577 .707 r
F P
0 g
s
.25856 .80628 m .25348 .82349 L .28423 .83041 L p .707 .577 .707 r
F P
0 g
s
.28423 .83041 m .28931 .81319 L .25856 .80628 L p .707 .577 .707 r
F P
0 g
s
.69031 .7281 m .69177 .76528 L .67074 .75996 L p .707 .577 .707 r
F P
0 g
s
.67074 .75996 m .66927 .72278 L .69031 .7281 L p .707 .577 .707 r
F P
0 g
s
.16839 .64384 m .1688 .69946 L .18985 .70571 L p .707 .577 .707 r
F P
0 g
s
.22352 .81307 m .2286 .79585 L .20236 .78294 L p .707 .577 .707 r
F P
0 g
s
.2286 .79585 m .22352 .81307 L .25348 .82349 L p .707 .577 .707 r
F P
0 g
s
.66326 .64514 m .66367 .70076 L .63621 .6966 L p .707 .577 .707 r
F P
0 g
s
.63621 .6966 m .63581 .64097 L .66326 .64514 L p .707 .577 .707 r
F P
0 g
s
.19697 .76873 m .1955 .73155 L .17447 .72622 L p .707 .577 .707 r
F P
0 g
s
.28931 .81319 m .28423 .83041 L .31274 .83313 L p .707 .577 .707 r
F P
0 g
s
.31274 .83313 m .31782 .81591 L .28931 .81319 L p .707 .577 .707 r
F P
0 g
s
.1688 .69946 m .16839 .64384 L .1558 .63612 L p .707 .577 .707 r
F P
0 g
s
.20236 .78294 m .19728 .80016 L .22352 .81307 L p .707 .577 .707 r
F P
0 g
s
.17447 .72622 m .17594 .7634 L .19697 .76873 L p .707 .577 .707 r
F P
0 g
s
.3393 .72292 m .34077 .76011 L .35714 .75254 L p .707 .577 .707 r
F P
0 g
s
.35714 .75254 m .35567 .71536 L .3393 .72292 L p .707 .577 .707 r
F P
0 g
s
.19728 .80016 m .20236 .78294 L .18239 .7688 L p .707 .577 .707 r
F P
0 g
s
.63556 .29736 m .63046 .79867 L .64046 .78679 L p .707 .577 .707 r
F P
0 g
s
.64046 .78679 m .64556 .28548 L .63556 .29736 L p .707 .577 .707 r
F P
0 g
s
.31782 .81591 m .31274 .83313 L .33624 .8314 L p .707 .577 .707 r
F P
0 g
s
.33624 .8314 m .34132 .81418 L .31782 .81591 L p .707 .577 .707 r
F P
0 g
s
.69372 .8082 m .68864 .82542 L .66867 .81128 L p .707 .577 .707 r
F P
0 g
s
.66867 .81128 m .67375 .79406 L .69372 .8082 L p .707 .577 .707 r
F P
0 g
s
.66927 .72278 m .67074 .75996 L .64331 .75682 L p .707 .577 .707 r
F P
0 g
s
.64331 .75682 m .64184 .71964 L .66927 .72278 L p .707 .577 .707 r
F P
0 g
s
.18239 .7688 m .17731 .78601 L .19728 .80016 L p .707 .577 .707 r
F P
0 g
s
.1558 .63612 m .1562 .69174 L .1688 .69946 L p .707 .577 .707 r
F P
0 g
s
.34971 .63823 m .35012 .69386 L .3572 .68553 L p .707 .577 .707 r
F P
0 g
s
.3572 .68553 m .3568 .62991 L .34971 .63823 L p .707 .577 .707 r
F P
0 g
s
.17594 .7634 m .17447 .72622 L .1619 .71923 L p .707 .577 .707 r
F P
0 g
s
.35567 .71536 m .35714 .75254 L .36422 .74437 L p .707 .577 .707 r
F P
0 g
s
.36422 .74437 m .36276 .70719 L .35567 .71536 L p .707 .577 .707 r
F P
0 g
s
.3568 .62991 m .3572 .68553 L .3543 .67709 L p .707 .577 .707 r
F P
0 g
s
.35987 .69923 m .36134 .73641 L .34876 .72942 L p .707 .577 .707 r
F P
0 g
s
.34876 .72942 m .3473 .69224 L .35987 .69923 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .34563 .78922 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36243 .78599 m .36089 .79122 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36089 .79122 m .35735 .8032 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35772 .27756 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .35071 .772 L .36059 .78379 L p .707 .577 .707 r
F P
0 g
s
.36059 .78379 m .36243 .78599 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .36059 .78379 L .36069 .78632 L .707 .577 .707 r
F
.35262 .77887 m .35671 .79114 L p .35691 .69138 L F P
0 g
s
.3543 .67709 m .3539 .62147 L .3568 .62991 L p .707 .577 .707 r
F P
0 g
s
.35772 .27756 m .3542 .62354 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.3539 .62147 m .3543 .67709 L .34171 .66937 L p .707 .577 .707 r
F P
0 g
s
.3542 .62354 m .35262 .77887 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35671 .79114 m .35756 .70773 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35756 .70773 m .36181 .28983 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.36276 .70719 m .36422 .74437 L .36134 .73641 L p .707 .577 .707 r
F P
0 g
s
.36134 .73641 m .35987 .69923 L .36276 .70719 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .36243 .78599 L .36477 .79845 L p .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35671 .79114 L .37449 .8026 L p .707 .577 .707 r
F P
0 g
s
.1562 .69174 m .1558 .63612 L .1529 .62768 L p .707 .577 .707 r
F P
0 g
s
.1619 .71923 m .16336 .75642 L .17594 .7634 L p .707 .577 .707 r
F P
0 g
s
.17731 .78601 m .18239 .7688 L .17067 .75481 L p .707 .577 .707 r
F P
0 g
s
.34132 .81418 m .33624 .8314 L .35242 .82538 L p .707 .577 .707 r
F P
0 g
s
.35242 .82538 m .3575 .80816 L .34132 .81418 L p .707 .577 .707 r
F P
0 g
s
.67375 .79406 m .66867 .81128 L .64243 .79836 L p .707 .577 .707 r
F P
0 g
s
.64243 .79836 m .64751 .78114 L .67375 .79406 L p .707 .577 .707 r
F P
0 g
s
.17067 .75481 m .16559 .77203 L .17731 .78601 L p .707 .577 .707 r
F P
0 g
s
.1529 .62768 m .15331 .6833 L .1562 .69174 L p .707 .577 .707 r
F P
0 g
s
.16336 .75642 m .1619 .71923 L .15901 .71127 L p .707 .577 .707 r
F P
0 g
s
.64556 .28548 m .64046 .78679 L .63638 .77452 L p .707 .577 .707 r
F P
0 g
s
.63638 .77452 m .64147 .27321 L .64556 .28548 L p .707 .577 .707 r
F P
0 g
s
.16559 .77203 m .17067 .75481 L .16833 .74235 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15901 .71127 m .16048 .74845 L .16336 .75642 L p .707 .577 .707 r
F P
0 g
s
.15331 .6833 m .1529 .62768 L .15999 .61935 L p .707 .577 .707 r
F P
0 g
s
.3575 .80816 m .35242 .82538 L .35969 .81566 L p .707 .577 .707 r
F P
0 g
s
.35969 .81566 m .36477 .79845 L .3575 .80816 L p .707 .577 .707 r
F P
0 g
s
.16833 .74235 m .16325 .75957 L .16559 .77203 L p .707 .577 .707 r
F P
0 g
s
.35262 .77887 m .35772 .27756 L .36772 .26568 L p .707 .577 .707 r
F P
0 g
s
.15999 .61935 m .16039 .67498 L .15331 .6833 L p .707 .577 .707 r
F P
0 g
s
.34171 .66937 m .34131 .61375 L .3539 .62147 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16048 .74845 m .15901 .71127 L .1661 .7031 L p .707 .577 .707 r
F P
0 g
s
.16325 .75957 m .16833 .74235 L .1756 .73264 L p .707 .577 .707 r
F P
0 g
s
.16039 .67498 m .15999 .61935 L .17636 .61195 L p .707 .577 .707 r
F P
0 g
s
.36477 .79845 m .35969 .81566 L .35735 .8032 L p .707 .577 .707 r
F P
0 g
s
.1661 .7031 m .16757 .74028 L .16048 .74845 L p .707 .577 .707 r
F P
0 g
s
.1756 .73264 m .17052 .74985 L .16325 .75957 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64147 .27321 m .63638 .77452 L .6186 .76307 L p .707 .577 .707 r
F P
0 g
s
.6186 .76307 m .6237 .26176 L .64147 .27321 L p .707 .577 .707 r
F P
0 g
s
.17636 .61195 m .17676 .66757 L .16039 .67498 L p .707 .577 .707 r
F P
0 g
s
.34131 .61375 m .34171 .66937 L .32066 .66312 L p .707 .577 .707 r
F P
0 g
s
.32066 .66312 m .32025 .6075 L .34131 .61375 L p .707 .577 .707 r
F P
0 g
s
.16757 .74028 m .1661 .7031 L .18246 .69554 L p .707 .577 .707 r
F P
0 g
s
.36262 .76699 m .36772 .26568 L .39083 .25535 L p .707 .577 .707 r
F P
0 g
s
.36772 .26568 m .36262 .76699 L .35262 .77887 L p .707 .577 .707 r
F P
0 g
s
.17052 .74985 m .1756 .73264 L .19178 .72662 L p .707 .577 .707 r
F P
0 g
s
.17676 .66757 m .17636 .61195 L .20041 .60619 L p .707 .577 .707 r
F P
0 g
s
.18246 .69554 m .18393 .73272 L .16757 .74028 L p .707 .577 .707 r
F P
0 g
s
.19178 .72662 m .1867 .74384 L .17052 .74985 L p .707 .577 .707 r
F P
0 g
s
.3473 .69224 m .34876 .72942 L .32773 .7241 L p .707 .577 .707 r
F P
0 g
s
.32773 .7241 m .32626 .68691 L .3473 .69224 L p .707 .577 .707 r
F P
0 g
s
.32025 .6075 m .32066 .66312 L .2932 .65896 L p .707 .577 .707 r
F P
0 g
s
.2932 .65896 m .2928 .60334 L .32025 .6075 L p .707 .577 .707 r
F P
0 g
s
.20041 .60619 m .20081 .66182 L .17676 .66757 L p .707 .577 .707 r
F P
0 g
s
.6237 .26176 m .6186 .76307 L .58888 .75355 L p .707 .577 .707 r
F P
0 g
s
.58888 .75355 m .59398 .25224 L .6237 .26176 L p .707 .577 .707 r
F P
0 g
s
.20081 .66182 m .20041 .60619 L .22979 .60265 L p .707 .577 .707 r
F P
0 g
s
.18393 .73272 m .18246 .69554 L .2065 .68931 L p .707 .577 .707 r
F P
0 g
s
.1867 .74384 m .19178 .72662 L .21528 .72489 L p .707 .577 .707 r
F P
0 g
s
.2928 .60334 m .2932 .65896 L .26203 .65729 L p .707 .577 .707 r
F P
0 g
s
.26203 .65729 m .26163 .60167 L .2928 .60334 L p .707 .577 .707 r
F P
0 g
s
.35071 .772 m .34563 .78922 L .32566 .77508 L p .707 .577 .707 r
F P
0 g
s
.32566 .77508 m .33074 .75786 L .35071 .772 L p .707 .577 .707 r
F P
0 g
s
.2065 .68931 m .20797 .72649 L .18393 .73272 L p .707 .577 .707 r
F P
0 g
s
.32626 .68691 m .32773 .7241 L .3003 .72096 L p .707 .577 .707 r
F P
0 g
s
.3003 .72096 m .29883 .68378 L .32626 .68691 L p .707 .577 .707 r
F P
0 g
s
.23019 .65827 m .22979 .60265 L .26163 .60167 L p .707 .577 .707 r
F P
0 g
s
.22979 .60265 m .23019 .65827 L .20081 .66182 L p .707 .577 .707 r
F P
0 g
s
.21528 .72489 m .2102 .7421 L .1867 .74384 L p .707 .577 .707 r
F P
0 g
s
.39083 .25535 m .38573 .75666 L .36262 .76699 L p .707 .577 .707 r
F P
0 g
s
.38573 .75666 m .39083 .25535 L .42479 .24758 L p .707 .577 .707 r
F P
0 g
s
.26163 .60167 m .26203 .65729 L .23019 .65827 L p .707 .577 .707 r
F P
0 g
s
.72869 .65714 m .72829 .60152 L .69712 .59984 L p .707 .577 .707 r
F P
0 g
s
.72829 .60152 m .72869 .65714 L .76053 .65616 L p .707 .577 .707 r
F P
0 g
s
.76053 .65616 m .76012 .60053 L .72829 .60152 L p .707 .577 .707 r
F P
0 g
s
.76012 .60053 m .76053 .65616 L .78991 .65261 L p .707 .577 .707 r
F P
0 g
s
.78991 .65261 m .78951 .59699 L .76012 .60053 L p .707 .577 .707 r
F P
0 g
s
.20797 .72649 m .2065 .68931 L .23587 .68503 L p .707 .577 .707 r
F P
0 g
s
.69752 .65547 m .69712 .59984 L .66966 .59568 L p .707 .577 .707 r
F P
0 g
s
.69712 .59984 m .69752 .65547 L .72869 .65714 L p .707 .577 .707 r
F P
0 g
s
.2102 .7421 m .21528 .72489 L .24379 .72761 L p .707 .577 .707 r
F P
0 g
s
.29883 .68378 m .3003 .72096 L .26915 .72031 L p .707 .577 .707 r
F P
0 g
s
.26915 .72031 m .26768 .68313 L .29883 .68378 L p .707 .577 .707 r
F P
0 g
s
.33074 .75786 m .32566 .77508 L .29942 .76216 L p .707 .577 .707 r
F P
0 g
s
.29942 .76216 m .3045 .74494 L .33074 .75786 L p .707 .577 .707 r
F P
0 g
s
.23587 .68503 m .23734 .72222 L .20797 .72649 L p .707 .577 .707 r
F P
0 g
s
.59398 .25224 m .58888 .75355 L .55011 .7469 L p .707 .577 .707 r
F P
0 g
s
.55011 .7469 m .55521 .24558 L .59398 .25224 L p .707 .577 .707 r
F P
0 g
s
.78951 .59699 m .78991 .65261 L .81396 .64686 L p .707 .577 .707 r
F P
0 g
s
.81396 .64686 m .81356 .59123 L .78951 .59699 L p .707 .577 .707 r
F P
0 g
s
.23734 .72222 m .23587 .68503 L .26768 .68313 L p .707 .577 .707 r
F P
0 g
s
.24379 .72761 m .23871 .74483 L .2102 .7421 L p .707 .577 .707 r
F P
0 g
s
.26768 .68313 m .26915 .72031 L .23734 .72222 L p .707 .577 .707 r
F P
0 g
s
.73577 .71634 m .7343 .67916 L .70315 .67851 L p .707 .577 .707 r
F P
0 g
s
.7343 .67916 m .73577 .71634 L .76758 .71443 L p .707 .577 .707 r
F P
0 g
s
.76758 .71443 m .76611 .67725 L .7343 .67916 L p .707 .577 .707 r
F P
0 g
s
.76611 .67725 m .76758 .71443 L .79694 .71016 L p .707 .577 .707 r
F P
0 g
s
.79694 .71016 m .79548 .67298 L .76611 .67725 L p .707 .577 .707 r
F P
0 g
s
.66966 .59568 m .67006 .6513 L .69752 .65547 L p .707 .577 .707 r
F P
0 g
s
.67006 .6513 m .66966 .59568 L .64861 .58943 L p .707 .577 .707 r
F P
0 g
s
.23871 .74483 m .24379 .72761 L .27453 .73452 L p .707 .577 .707 r
F P
0 g
s
.41969 .7489 m .42479 .24758 L .46627 .24314 L p .707 .577 .707 r
F P
0 g
s
.42479 .24758 m .41969 .7489 L .38573 .75666 L p .707 .577 .707 r
F P
0 g
s
.3045 .74494 m .29942 .76216 L .26945 .75174 L p .707 .577 .707 r
F P
0 g
s
.26945 .75174 m .27453 .73452 L .3045 .74494 L p .707 .577 .707 r
F P
0 g
s
.70462 .71569 m .70315 .67851 L .67572 .67537 L p .707 .577 .707 r
F P
0 g
s
.70315 .67851 m .70462 .71569 L .73577 .71634 L p .707 .577 .707 r
F P
0 g
s
.27453 .73452 m .26945 .75174 L .23871 .74483 L p .707 .577 .707 r
F P
0 g
s
.79548 .67298 m .79694 .71016 L .82099 .70393 L p .707 .577 .707 r
F P
0 g
s
.82099 .70393 m .81952 .66675 L .79548 .67298 L p .707 .577 .707 r
F P
0 g
s
.81356 .59123 m .81396 .64686 L .83033 .63945 L p .707 .577 .707 r
F P
0 g
s
.83033 .63945 m .82993 .58383 L .81356 .59123 L p .707 .577 .707 r
F P
0 g
s
.67572 .67537 m .67719 .71255 L .70462 .71569 L p .707 .577 .707 r
F P
0 g
s
.55521 .24558 m .55011 .7469 L .50611 .74376 L p .707 .577 .707 r
F P
0 g
s
.50611 .74376 m .51121 .24245 L .55521 .24558 L p .707 .577 .707 r
F P
0 g
s
.7337 .76766 m .73878 .75044 L .70882 .74002 L p .707 .577 .707 r
F P
0 g
s
.73878 .75044 m .7337 .76766 L .76444 .77457 L p .707 .577 .707 r
F P
0 g
s
.76444 .77457 m .76952 .75735 L .73878 .75044 L p .707 .577 .707 r
F P
0 g
s
.64861 .58943 m .64901 .64506 L .67006 .6513 L p .707 .577 .707 r
F P
0 g
s
.70374 .75723 m .70882 .74002 L .68257 .7271 L p .707 .577 .707 r
F P
0 g
s
.70882 .74002 m .70374 .75723 L .7337 .76766 L p .707 .577 .707 r
F P
0 g
s
.46117 .74445 m .46627 .24314 L .51121 .24245 L p .707 .577 .707 r
F P
0 g
s
.46627 .24314 m .46117 .74445 L .41969 .7489 L p .707 .577 .707 r
F P
0 g
s
.67719 .71255 m .67572 .67537 L .65468 .67005 L p .707 .577 .707 r
F P
0 g
s
.76952 .75735 m .76444 .77457 L .79296 .77729 L p .707 .577 .707 r
F P
0 g
s
.79296 .77729 m .79804 .76007 L .76952 .75735 L p .707 .577 .707 r
F P
0 g
s
.51121 .24245 m .50611 .74376 L .46117 .74445 L p .707 .577 .707 r
F P
0 g
s
.64901 .64506 m .64861 .58943 L .63601 .58171 L p .707 .577 .707 r
F P
0 g
s
.68257 .7271 m .67749 .74432 L .70374 .75723 L p .707 .577 .707 r
F P
0 g
s
.65468 .67005 m .65615 .70723 L .67719 .71255 L p .707 .577 .707 r
F P
0 g
s
.81952 .66675 m .82099 .70393 L .83735 .69637 L p .707 .577 .707 r
F P
0 g
s
.83735 .69637 m .83588 .65918 L .81952 .66675 L p .707 .577 .707 r
F P
0 g
s
.67749 .74432 m .68257 .7271 L .66261 .71296 L p .707 .577 .707 r
F P
0 g
s
.79804 .76007 m .79296 .77729 L .81645 .77556 L p .707 .577 .707 r
F P
0 g
s
.81645 .77556 m .82153 .75834 L .79804 .76007 L p .707 .577 .707 r
F P
0 g
s
.66261 .71296 m .65753 .73018 L .67749 .74432 L p .707 .577 .707 r
F P
0 g
s
.63601 .58171 m .63642 .63734 L .64901 .64506 L p .707 .577 .707 r
F P
0 g
s
.82993 .58383 m .83033 .63945 L .83741 .63113 L p .707 .577 .707 r
F P
0 g
s
.83741 .63113 m .83701 .5755 L .82993 .58383 L p .707 .577 .707 r
F P
0 g
s
.65615 .70723 m .65468 .67005 L .64211 .66306 L p .707 .577 .707 r
F P
0 g
s
.63642 .63734 m .63601 .58171 L .63312 .57328 L p .707 .577 .707 r
F P
0 g
s
.64211 .66306 m .64358 .70024 L .65615 .70723 L p .707 .577 .707 r
F P
0 g
s
.65753 .73018 m .66261 .71296 L .65088 .69897 L p .707 .577 .707 r
F P
0 g
s
.82153 .75834 m .81645 .77556 L .83263 .76954 L p .707 .577 .707 r
F P
0 g
s
.83263 .76954 m .83771 .75232 L .82153 .75834 L p .707 .577 .707 r
F P
0 g
s
.83588 .65918 m .83735 .69637 L .84444 .6882 L p .707 .577 .707 r
F P
0 g
s
.84444 .6882 m .84297 .65102 L .83588 .65918 L p .707 .577 .707 r
F P
0 g
s
.65088 .69897 m .6458 .71619 L .65753 .73018 L p .707 .577 .707 r
F P
0 g
s
.63312 .57328 m .63352 .6289 L .63642 .63734 L p .707 .577 .707 r
F P
0 g
s
.83701 .5755 m .83741 .63113 L .83452 .62269 L p .707 .577 .707 r
F P
0 g
s
.83452 .62269 m .83412 .56706 L .83701 .5755 L p .707 .577 .707 r
F P
0 g
s
.64358 .70024 m .64211 .66306 L .63922 .65509 L p .707 .577 .707 r
F P
0 g
s
.6458 .71619 m .65088 .69897 L .64854 .68651 L p .707 .577 .707 r
F P
0 g
s
.63922 .65509 m .64069 .69227 L .64358 .70024 L p .707 .577 .707 r
F P
0 g
s
.63352 .6289 m .63312 .57328 L .6402 .56495 L p .707 .577 .707 r
F P
0 g
s
.83771 .75232 m .83263 .76954 L .8399 .75983 L p .707 .577 .707 r
F P
0 g
s
.8399 .75983 m .84498 .74261 L .83771 .75232 L p .707 .577 .707 r
F P
0 g
s
.64854 .68651 m .64346 .70373 L .6458 .71619 L p .707 .577 .707 r
F P
0 g
s
.84297 .65102 m .84444 .6882 L .84155 .68023 L p .707 .577 .707 r
F P
0 g
s
.84155 .68023 m .84009 .64305 L .84297 .65102 L p .707 .577 .707 r
F P
0 g
s
.6402 .56495 m .6406 .62057 L .63352 .6289 L p .707 .577 .707 r
F P
0 g
s
.83412 .56706 m .83452 .62269 L .82193 .61497 L p .707 .577 .707 r
F P
0 g
s
.82193 .61497 m .82152 .55934 L .83412 .56706 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64069 .69227 m .63922 .65509 L .64631 .64693 L p .707 .577 .707 r
F P
0 g
s
.64346 .70373 m .64854 .68651 L .65582 .6768 L p .707 .577 .707 r
F P
0 g
s
.38568 .6195 m .38528 .56388 L .35411 .56221 L p .707 .577 .707 r
F P
0 g
s
.38528 .56388 m .38568 .6195 L .41752 .61852 L p .707 .577 .707 r
F P
0 g
s
.41752 .61852 m .41711 .5629 L .38528 .56388 L p .707 .577 .707 r
F P
0 g
s
.41711 .5629 m .41752 .61852 L .4469 .61498 L p .707 .577 .707 r
F P
0 g
s
.4469 .61498 m .4465 .55935 L .41711 .5629 L p .707 .577 .707 r
F P
0 g
s
.84498 .74261 m .8399 .75983 L .83757 .74737 L p .707 .577 .707 r
F P
0 g
s
.83757 .74737 m .84265 .73015 L .84498 .74261 L p .707 .577 .707 r
F P
0 g
s
.64631 .64693 m .64778 .68411 L .64069 .69227 L p .707 .577 .707 r
F P
0 g
s
.6406 .62057 m .6402 .56495 L .65657 .55754 L p .707 .577 .707 r
F P
0 g
s
.65582 .6768 m .65074 .69402 L .64346 .70373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35451 .61783 m .35411 .56221 L .32665 .55805 L p .707 .577 .707 r
F P
0 g
s
.35411 .56221 m .35451 .61783 L .38568 .6195 L p .707 .577 .707 r
F P
0 g
s
.84009 .64305 m .84155 .68023 L .82898 .67325 L p .707 .577 .707 r
F P
0 g
s
.82898 .67325 m .82751 .63606 L .84009 .64305 L p .707 .577 .707 r
F P
0 g
s
.4465 .55935 m .4469 .61498 L .47095 .60922 L p .707 .577 .707 r
F P
0 g
s
.47095 .60922 m .47055 .5536 L .4465 .55935 L p .707 .577 .707 r
F P
0 g
s
.65657 .55754 m .65697 .61317 L .6406 .62057 L p .707 .577 .707 r
F P
0 g
s
.82152 .55934 m .82193 .61497 L .80087 .60872 L p .707 .577 .707 r
F P
0 g
s
.80087 .60872 m .80047 .5531 L .82152 .55934 L p .707 .577 .707 r
F P
0 g
s
.39276 .68048 m .39129 .64329 L .36014 .64265 L p .707 .577 .707 r
F P
0 g
s
.39129 .64329 m .39276 .68048 L .42457 .67857 L p .707 .577 .707 r
F P
0 g
s
.42457 .67857 m .4231 .64139 L .39129 .64329 L p .707 .577 .707 r
F P
0 g
s
.4231 .64139 m .42457 .67857 L .45393 .67429 L p .707 .577 .707 r
F P
0 g
s
.45393 .67429 m .45247 .63711 L .4231 .64139 L p .707 .577 .707 r
F P
0 g
s
.32665 .55805 m .32705 .61367 L .35451 .61783 L p .707 .577 .707 r
F P
0 g
s
.32705 .61367 m .32665 .55805 L .3056 .5518 L p .707 .577 .707 r
F P
0 g
s
.64778 .68411 m .64631 .64693 L .66268 .63936 L p .707 .577 .707 r
F P
0 g
s
.36161 .67983 m .36014 .64265 L .33271 .63951 L p .707 .577 .707 r
F P
0 g
s
.36014 .64265 m .36161 .67983 L .39276 .68048 L p .707 .577 .707 r
F P
0 g
s
.65074 .69402 m .65582 .6768 L .67199 .67078 L p .707 .577 .707 r
F P
0 g
s
.65697 .61317 m .65657 .55754 L .68062 .55179 L p .707 .577 .707 r
F P
0 g
s
.84265 .73015 m .83757 .74737 L .82584 .73338 L p .707 .577 .707 r
F P
0 g
s
.82584 .73338 m .83092 .71616 L .84265 .73015 L p .707 .577 .707 r
F P
0 g
s
.66268 .63936 m .66414 .67654 L .64778 .68411 L p .707 .577 .707 r
F P
0 g
s
.45247 .63711 m .45393 .67429 L .47798 .66807 L p .707 .577 .707 r
F P
0 g
s
.47798 .66807 m .47651 .63089 L .45247 .63711 L p .707 .577 .707 r
F P
0 g
s
.67199 .67078 m .66691 .688 L .65074 .69402 L p .707 .577 .707 r
F P
0 g
s
.47055 .5536 m .47095 .60922 L .48732 .60182 L p .707 .577 .707 r
F P
0 g
s
.48732 .60182 m .48692 .54619 L .47055 .5536 L p .707 .577 .707 r
F P
0 g
s
.33271 .63951 m .33418 .67669 L .36161 .67983 L p .707 .577 .707 r
F P
0 g
s
.39069 .73146 m .39577 .71424 L .36581 .70382 L p .707 .577 .707 r
F P
0 g
s
.39577 .71424 m .39069 .73146 L .42143 .73837 L p .707 .577 .707 r
F P
0 g
s
.42143 .73837 m .42651 .72115 L .39577 .71424 L p .707 .577 .707 r
F P
0 g
s
.82751 .63606 m .82898 .67325 L .80795 .66792 L p .707 .577 .707 r
F P
0 g
s
.80795 .66792 m .80648 .63074 L .82751 .63606 L p .707 .577 .707 r
F P
0 g
s
.3056 .5518 m .306 .60742 L .32705 .61367 L p .707 .577 .707 r
F P
0 g
s
.36073 .72103 m .36581 .70382 L .33956 .6909 L p .707 .577 .707 r
F P
0 g
s
.36581 .70382 m .36073 .72103 L .39069 .73146 L p .707 .577 .707 r
F P
0 g
s
.80047 .5531 m .80087 .60872 L .77341 .60456 L p .707 .577 .707 r
F P
0 g
s
.77341 .60456 m .77301 .54893 L .80047 .5531 L p .707 .577 .707 r
F P
0 g
s
.33418 .67669 m .33271 .63951 L .31167 .63418 L p .707 .577 .707 r
F P
0 g
s
.42651 .72115 m .42143 .73837 L .44995 .74109 L p .707 .577 .707 r
F P
0 g
s
.44995 .74109 m .45503 .72387 L .42651 .72115 L p .707 .577 .707 r
F P
0 g
s
.68062 .55179 m .68103 .60741 L .65697 .61317 L p .707 .577 .707 r
F P
0 g
s
.306 .60742 m .3056 .5518 L .293 .54408 L p .707 .577 .707 r
F P
0 g
s
.33956 .6909 m .33448 .70812 L .36073 .72103 L p .707 .577 .707 r
F P
0 g
s
.66414 .67654 m .66268 .63936 L .68672 .63314 L p .707 .577 .707 r
F P
0 g
s
.68103 .60741 m .68062 .55179 L .71 .54825 L p .707 .577 .707 r
F P
0 g
s
.31167 .63418 m .31314 .67136 L .33418 .67669 L p .707 .577 .707 r
F P
0 g
s
.47651 .63089 m .47798 .66807 L .49434 .6605 L p .707 .577 .707 r
F P
0 g
s
.49434 .6605 m .49287 .62332 L .47651 .63089 L p .707 .577 .707 r
F P
0 g
s
.33448 .70812 m .33956 .6909 L .3196 .67676 L p .707 .577 .707 r
F P
0 g
s
.66691 .688 m .67199 .67078 L .69549 .66905 L p .707 .577 .707 r
F P
0 g
s
.45503 .72387 m .44995 .74109 L .47344 .73936 L p .707 .577 .707 r
F P
0 g
s
.47344 .73936 m .47852 .72214 L .45503 .72387 L p .707 .577 .707 r
F P
0 g
s
.77301 .54893 m .77341 .60456 L .74224 .60289 L p .707 .577 .707 r
F P
0 g
s
.74224 .60289 m .74184 .54726 L .77301 .54893 L p .707 .577 .707 r
F P
0 g
s
.83092 .71616 m .82584 .73338 L .80588 .71924 L p .707 .577 .707 r
F P
0 g
s
.80588 .71924 m .81096 .70202 L .83092 .71616 L p .707 .577 .707 r
F P
0 g
s
.68672 .63314 m .68819 .67032 L .66414 .67654 L p .707 .577 .707 r
F P
0 g
s
.80648 .63074 m .80795 .66792 L .78051 .66478 L p .707 .577 .707 r
F P
0 g
s
.78051 .66478 m .77904 .6276 L .80648 .63074 L p .707 .577 .707 r
F P
0 g
s
.3196 .67676 m .31452 .69398 L .33448 .70812 L p .707 .577 .707 r
F P
0 g
s
.293 .54408 m .29341 .5997 L .306 .60742 L p .707 .577 .707 r
F P
0 g
s
.48692 .54619 m .48732 .60182 L .4944 .59349 L p .707 .577 .707 r
F P
0 g
s
.4944 .59349 m .494 .53787 L .48692 .54619 L p .707 .577 .707 r
F P
0 g
s
.69549 .66905 m .69041 .68627 L .66691 .688 L p .707 .577 .707 r
F P
0 g
s
.71041 .60387 m .71 .54825 L .74184 .54726 L p .707 .577 .707 r
F P
0 g
s
.71 .54825 m .71041 .60387 L .68103 .60741 L p .707 .577 .707 r
F P
0 g
s
.74184 .54726 m .74224 .60289 L .71041 .60387 L p .707 .577 .707 r
F P
0 g
s
.31314 .67136 m .31167 .63418 L .2991 .6272 L p .707 .577 .707 r
F P
0 g
s
.68819 .67032 m .68672 .63314 L .71608 .62886 L p .707 .577 .707 r
F P
0 g
s
.29341 .5997 m .293 .54408 L .29011 .53564 L p .707 .577 .707 r
F P
0 g
s
.2991 .6272 m .30057 .66438 L .31314 .67136 L p .707 .577 .707 r
F P
0 g
s
.31452 .69398 m .3196 .67676 L .30787 .66277 L p .707 .577 .707 r
F P
0 g
s
.69041 .68627 m .69549 .66905 L .72401 .67177 L p .707 .577 .707 r
F P
0 g
s
.77904 .6276 m .78051 .66478 L .74936 .66413 L p .707 .577 .707 r
F P
0 g
s
.74936 .66413 m .7479 .62695 L .77904 .6276 L p .707 .577 .707 r
F P
0 g
s
.47852 .72214 m .47344 .73936 L .48962 .73334 L p .707 .577 .707 r
F P
0 g
s
.48962 .73334 m .4947 .71612 L .47852 .72214 L p .707 .577 .707 r
F P
0 g
s
.81096 .70202 m .80588 .71924 L .77963 .70632 L p .707 .577 .707 r
F P
0 g
s
.77963 .70632 m .78471 .68911 L .81096 .70202 L p .707 .577 .707 r
F P
0 g
s
.71608 .62886 m .71755 .66604 L .68819 .67032 L p .707 .577 .707 r
F P
0 g
s
.49287 .62332 m .49434 .6605 L .50143 .65233 L p .707 .577 .707 r
F P
0 g
s
.50143 .65233 m .49996 .61515 L .49287 .62332 L p .707 .577 .707 r
F P
0 g
s
.71755 .66604 m .71608 .62886 L .7479 .62695 L p .707 .577 .707 r
F P
0 g
s
.30787 .66277 m .30279 .67999 L .31452 .69398 L p .707 .577 .707 r
F P
0 g
s
.72401 .67177 m .71893 .68899 L .69041 .68627 L p .707 .577 .707 r
F P
0 g
s
.7479 .62695 m .74936 .66413 L .71755 .66604 L p .707 .577 .707 r
F P
0 g
s
.29011 .53564 m .29051 .59127 L .29341 .5997 L p .707 .577 .707 r
F P
0 g
s
.71893 .68899 m .72401 .67177 L .75475 .67868 L p .707 .577 .707 r
F P
0 g
s
.494 .53787 m .4944 .59349 L .49151 .58505 L p .707 .577 .707 r
F P
0 g
s
.49151 .58505 m .4911 .52943 L .494 .53787 L p .707 .577 .707 r
F P
0 g
s
.78471 .68911 m .77963 .70632 L .74967 .6959 L p .707 .577 .707 r
F P
0 g
s
.74967 .6959 m .75475 .67868 L .78471 .68911 L p .707 .577 .707 r
F P
0 g
s
.30057 .66438 m .2991 .6272 L .29621 .61923 L p .707 .577 .707 r
F P
0 g
s
.75475 .67868 m .74967 .6959 L .71893 .68899 L p .707 .577 .707 r
F P
0 g
s
.30279 .67999 m .30787 .66277 L .30553 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29621 .61923 m .29768 .65641 L .30057 .66438 L p .707 .577 .707 r
F P
0 g
s
.29051 .59127 m .29011 .53564 L .29719 .52731 L p .707 .577 .707 r
F P
0 g
s
.4947 .71612 m .48962 .73334 L .49689 .72363 L p .707 .577 .707 r
F P
0 g
s
.49689 .72363 m .50197 .70641 L .4947 .71612 L p .707 .577 .707 r
F P
0 g
s
.30553 .65031 m .30045 .66753 L .30279 .67999 L p .707 .577 .707 r
F P
0 g
s
.49996 .61515 m .50143 .65233 L .49854 .64437 L p .707 .577 .707 r
F P
0 g
s
.49854 .64437 m .49708 .60719 L .49996 .61515 L p .707 .577 .707 r
F P
0 g
s
.29719 .52731 m .29759 .58294 L .29051 .59127 L p .707 .577 .707 r
F P
0 g
s
.4911 .52943 m .49151 .58505 L .47892 .57733 L p .707 .577 .707 r
F P
0 g
s
.47892 .57733 m .47851 .52171 L .4911 .52943 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29768 .65641 m .29621 .61923 L .3033 .61106 L p .707 .577 .707 r
F P
0 g
s
.30045 .66753 m .30553 .65031 L .31281 .6406 L p .707 .577 .707 r
F P
0 g
s
.29759 .58294 m .29719 .52731 L .31356 .51991 L p .707 .577 .707 r
F P
0 g
s
.50197 .70641 m .49689 .72363 L .49455 .71117 L p .707 .577 .707 r
F P
0 g
s
.49455 .71117 m .49963 .69395 L .50197 .70641 L p .707 .577 .707 r
F P
0 g
s
.3033 .61106 m .30477 .64824 L .29768 .65641 L p .707 .577 .707 r
F P
0 g
s
.31281 .6406 m .30773 .65782 L .30045 .66753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49708 .60719 m .49854 .64437 L .48597 .63738 L p .707 .577 .707 r
F P
0 g
s
.48597 .63738 m .4845 .6002 L .49708 .60719 L p .707 .577 .707 r
F P
0 g
s
.31356 .51991 m .31396 .57553 L .29759 .58294 L p .707 .577 .707 r
F P
0 g
s
.47851 .52171 m .47892 .57733 L .45786 .57109 L p .707 .577 .707 r
F P
0 g
s
.45786 .57109 m .45746 .51546 L .47851 .52171 L p .707 .577 .707 r
F P
0 g
s
.30477 .64824 m .3033 .61106 L .31967 .6035 L p .707 .577 .707 r
F P
0 g
s
.30773 .65782 m .31281 .6406 L .32898 .63458 L p .707 .577 .707 r
F P
0 g
s
.31396 .57553 m .31356 .51991 L .33761 .51415 L p .707 .577 .707 r
F P
0 g
s
.49963 .69395 m .49455 .71117 L .48283 .69718 L p .707 .577 .707 r
F P
0 g
s
.48283 .69718 m .48791 .67996 L .49963 .69395 L p .707 .577 .707 r
F P
0 g
s
.31967 .6035 m .32113 .64068 L .30477 .64824 L p .707 .577 .707 r
F P
0 g
s
.32898 .63458 m .3239 .6518 L .30773 .65782 L p .707 .577 .707 r
F P
0 g
s
.4845 .6002 m .48597 .63738 L .46493 .63206 L p .707 .577 .707 r
F P
0 g
s
.46493 .63206 m .46347 .59488 L .4845 .6002 L p .707 .577 .707 r
F P
0 g
s
.45746 .51546 m .45786 .57109 L .4304 .56692 L p .707 .577 .707 r
F P
0 g
s
.4304 .56692 m .43 .5113 L .45746 .51546 L p .707 .577 .707 r
F P
0 g
s
.33761 .51415 m .33802 .56978 L .31396 .57553 L p .707 .577 .707 r
F P
0 g
s
.33802 .56978 m .33761 .51415 L .36699 .51061 L p .707 .577 .707 r
F P
0 g
s
.32113 .64068 m .31967 .6035 L .34371 .59727 L p .707 .577 .707 r
F P
0 g
s
.3239 .6518 m .32898 .63458 L .35248 .63285 L p .707 .577 .707 r
F P
0 g
s
.43 .5113 m .4304 .56692 L .39923 .56525 L p .707 .577 .707 r
F P
0 g
s
.39923 .56525 m .39883 .50963 L .43 .5113 L p .707 .577 .707 r
F P
0 g
s
.48791 .67996 m .48283 .69718 L .46287 .68304 L p .707 .577 .707 r
F P
0 g
s
.46287 .68304 m .46795 .66582 L .48791 .67996 L p .707 .577 .707 r
F P
0 g
s
.34371 .59727 m .34518 .63445 L .32113 .64068 L p .707 .577 .707 r
F P
0 g
s
.46347 .59488 m .46493 .63206 L .4375 .62892 L p .707 .577 .707 r
F P
0 g
s
.4375 .62892 m .43603 .59174 L .46347 .59488 L p .707 .577 .707 r
F P
0 g
s
.3674 .56624 m .36699 .51061 L .39883 .50963 L p .707 .577 .707 r
F P
0 g
s
.36699 .51061 m .3674 .56624 L .33802 .56978 L p .707 .577 .707 r
F P
0 g
s
.35248 .63285 m .3474 .65007 L .3239 .6518 L p .707 .577 .707 r
F P
0 g
s
.39883 .50963 m .39923 .56525 L .3674 .56624 L p .707 .577 .707 r
F P
0 g
s
.34518 .63445 m .34371 .59727 L .37307 .593 L p .707 .577 .707 r
F P
0 g
s
.3474 .65007 m .35248 .63285 L .381 .63557 L p .707 .577 .707 r
F P
0 g
s
.43603 .59174 m .4375 .62892 L .40635 .62827 L p .707 .577 .707 r
F P
0 g
s
.40635 .62827 m .40489 .59109 L .43603 .59174 L p .707 .577 .707 r
F P
0 g
s
.46795 .66582 m .46287 .68304 L .43662 .67012 L p .707 .577 .707 r
F P
0 g
s
.43662 .67012 m .4417 .65291 L .46795 .66582 L p .707 .577 .707 r
F P
0 g
s
.37307 .593 m .37454 .63018 L .34518 .63445 L p .707 .577 .707 r
F P
0 g
s
.37454 .63018 m .37307 .593 L .40489 .59109 L p .707 .577 .707 r
F P
0 g
s
.381 .63557 m .37592 .65279 L .3474 .65007 L p .707 .577 .707 r
F P
0 g
s
.40489 .59109 m .40635 .62827 L .37454 .63018 L p .707 .577 .707 r
F P
0 g
s
.37592 .65279 m .381 .63557 L .41174 .64248 L p .707 .577 .707 r
F P
0 g
s
.4417 .65291 m .43662 .67012 L .40666 .6597 L p .707 .577 .707 r
F P
0 g
s
.40666 .6597 m .41174 .64248 L .4417 .65291 L p .707 .577 .707 r
F P
0 g
s
.41174 .64248 m .40666 .6597 L .37592 .65279 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF009J
EPT00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo2@0015YF00<005YFFUH00UYF20001EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001MOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001HOol50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?OolA0016Ool0
059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`H000=JEP03001JEUYF00IJEP03001J
EUYF009JEPP003ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001BOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000cOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF3P00
0eYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo
00<005YF000015YF00@005YFFUIJEPP000QJEPH000=JEP03001JEUYF00EJEPH000AJEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000015YF001JEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00DWoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002moo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000_Ool0059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEP0001T000EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00
DWoo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH70004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool005=oo`04001JEUYF0005
FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00D0
05YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0000_Ool003eooaX000=JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00=goo1P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH7
0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000dOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P00;Woo000aOol30004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000eYF0P00;Woo000_Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00
FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00:goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<0
05YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP04001JEUYFFUHG0006FUH00`00FUIJEP02FUH3000^Ool002]oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP`000AJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0015YF
00<005YF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP03FUH600000eYF000000090004
FUH00`00FUIJEP08FUH7000015YF001JEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEP0000D000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00H002moo`00:goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00eYF1@001EYF00@005YF0000
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002
FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP04001JEUYFFUH5000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000000eYF00@0
05YFFUIJEPH000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001J
EUYF009JEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF1@000eYF1@001UYF1`001eYF00<005YFFUH01EYF0P00
0UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEPD00003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP03
001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF1`0000AJEP00000000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF008000EJEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool002]oo`03001JEP0000AJEP04001JEUYFFUH80008FUH6
0003FUH00`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP03FUH20003FUH01000FUH0000015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00:goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YF00000P0015YF
00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0000=JEP00FUH01UYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPP00004Ool000000005
Ool>0004FUH01@00FUIJEUYF0000;Goo000[Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0P0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEPL000Mo
o`D000moo`H00003FUH005YF009JEP03001oogoo02]oo`00:goo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH00002
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH01P00FUIJEUYF001JEP@000=JEP04001JEUYFFUH<0009Ool60004FUH01000FUH000000eYF
0P00;7oo000[Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF1@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@000UYF0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00h000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF0000000/Ool002]oo`80
00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEUYFFUH300000eYF001JEP03FUHA0003FUH00`00FUIJEP07FUH30006FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH0
05YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPH000QJEP03001J
EUYF00=JEP03001JEUYF00=JEP<002aoo`00:goo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF
00@005YFFUIJEQL0009JEP03001JEUYF008000AJEP80009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040005FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000/Ool002]oo`8000=J
EP03001JEUYF009JEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF0P000eYF0P000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF0`0015YF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000`000UYF4`001UYF00<005YFFUH01EYF0`000UYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000;7oo000/Ool01@00FUIJEUYF000015YF00<005YF00001@001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEPD0009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP04001JEUYF0002FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
10000UYF00<005YFFUH01eYF10001UYF00<005YFFUH00UYF0P00;Goo000]Ool2000015YF001JEUYF
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00@005YFFUIJ
EP<000AJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000MJEP04001JEUYFFUH20005FUH0
0`00FUIJEP02FUH2000]Ool002moo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00001JEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01000FUIJEUYF0P00;Woo000_Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF0000
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00MJ
EP05001JEUYF001JEP02000`Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000MJEP8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEP00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000QJEPD0039oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001eYF00<005YF00000P00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01000FUIJEP00<goo000]Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000AJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001J
EUYF009JEP80035oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF
100015YF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP<00003FUH005YF009JEQT000Eoo`800003
FUH005YF00EJEP03001oogoo02ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF10002EYF00<005YFFUH0
1@002eYF00<005YFFUH015YF100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P000UYF00@005YFFUIJEP8000AJEP<000Qoo`D000moo`8000IJEP80
02moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2`001Woo3P0015YF0P00
00=JEP00000025YF00<005YFFUH015YF4`000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP03001JEUYF009JEP8000=JEP03001J
EP0000Qoo`D0015oo`03001JEUYF009JEP03001JEP0002moo`00;Goo00<005YF000015YF00<005YF
FUH00eYF4P003goo1`0000=JEP0000000UYF100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF0P001eYF00<005YFFUH00P002Goo1@004Woo0P000UYF00@0
05YFFUH002ioo`00;Goo00<005YF000015YF00<005YF00000`000eYF00<005YFFUH01EYF00<005YF
FUH010002Woo1@001EYF00<005YF00000P000UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH5000:Ool3000EOol2
0004FUH00`00Oomoo`0[Ool002eoo`03001JEP0000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH20004FUH01000FUIJEUYF0P008goo00<0
05YFFUH00UYF00<007ooOol0:goo000]Ool01000FUH005YF0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00D005YF
FUIJEP0000EJEP80029oo`05001JEUYFFUH0000]Ool002eoo`03001JEP00008000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF3@001eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0`0025YF
0P008Goo00D005YF001JEP0002aoo`00;Goo10000eYF4P001eYF00<005YFFUH01EYF0P000UYF00<0
05YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EP0000QJEP04001JEP00000POol200000eYF001oo`0[Ool002eoo`@00003FUH0000000=JEP03001J
EUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP020006FUH01000FUIJEUYF0`007Woo00<005YF
0000;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0025YF00<005YFFUH00P001EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=J
EP<000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP@001Uo
o`<002eoo`00;Woo0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF
00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH0
10004goo0P0000=JEP000000;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH300000eYF001JEP06FUH200001UYF00000000Ool0009JEP03001JEUYF
00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00=JEP03001J
EUYF00<000MJEP03001JEUYF00AJEPH000Qoo`D0009JEP8002ioo`00;Woo00<005YF00000P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0`000goo00@0
05YFFUH000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP@000AJEP03001JEP0000=oo`L000=JEP06001JEUYFFUH007oo0P0015YF
00<005YFFUH01eYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000^Ool002ioo`80009JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001J
EUYF0080009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF00<005YF00001P0015YF
10000eYF0P000Woo0`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000_Ool01P00FUIJEUYF001oo`L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00H000=JEP03001JEUYF009JEP03001oo`00009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP800004FUH005YF0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP0000001Goo10001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00;goo00@005YFFUIJEP<000Io
oaP000Ioo`<000IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000Uoo`@0009JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00000aOol0031oo`04001JEUYF0002FUH00`00Oomoo`0>Ool5000@Ool00`00
FUIJEP04FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000=Ool60004FUH01000FUIJEUYF1@00<goo000`Ool00`00FUH00004
FUH2000>Ool5000AOol20004FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00004goo2000>7oo000aOol20006FUH00`00
Oomoo`0;Ool5000COol01@00FUIJEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000100000=JEP00FUH01EYF00<005YFFUH00UYF0P00E7oo000bOol00`00FUIJEP04FUH3000<
Ool3000EOol30002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00
FUH005YF008000IJEP03001JEUYF009JEP8005Aoo`00<goo0P0015YF00<005YFFUH00P0097oo00@0
05YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH20004FUH01000
FUIJEUYF0P00EGoo000eOol01000FUIJEP001EYF0P008goo00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80009JEP04001JEP00001GOol003Ioo`<000MJ
EP80025oo`03001JEP0000<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00MJEPD0
05Uoo`00>7oo00<005YFFUH01EYF00<005YF00000P007goo0P0000=JEP00Ool00P001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P0000AJEP00000000MJEP04001JEUYF001JOol003Uoo`8000EJEP03001JEUYF009JEP<0
01eoo`03001JEP00009oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH20004FUH00`00FUIJ
EP02FUH2001HOol003]oo`80009JEP03001JEUYF00IJEP@001Uoo`8000Eoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00T0009oo`<00003FUH005YF00EJEP03001oogoo05Eoo`00?Goo0`002EYF00<005YFFUH010004goo
10002Goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
10003goo0P001UYF0P00EWoo000oOol20008FUH00`00FUIJEP04FUH60008Ool50002FUH2000>Ool6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09000AOol00`00
FUIJEP02FUH00`00FUH0001FOol0045oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
0`00FUIJEP02000EOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80004Ool5000BOol20002
FUH01000FUIJEP00EGoo0014Ool300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P007Woo6P002goo1@0057oo0P0015YF00<007ooOol0DWoo0017Ool30007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool20004FUH01000FUIJEUYF0P002Woo0`00
5Woo00<005YFFUH00UYF00<007ooOol0DWoo001:Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUH00000<goo00D005YFFUIJEP0000EJEP80029oo`05001JEUYFFUH0001DOol004iooa<0
03Ioo`<000QJEP80025oo`05001JEP00FUH0001COol009Uoo`03001JEUYF00IJEP04001JEP00000P
Ool200000eYF001oo`1BOol009Yoo`8000IJEP04001JEUYFFUH3000NOol00`00FUH0001COol009ao
o`8000=JEP03001JEUYF00EJEP@001Yoo`8005Aoo`00WWoo0P0000=JEP00FUH01eYF00<005YFFUH0
100057oo1000E7oo002POol30007FUH00`00FUIJEP04FUH60008Ool600000eYF0000001EOol00:=o
o`8000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00EGoo002UOol30000
0eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:Qoo`@000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:aoo`@0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00001HOol00;1oo`H000AJEP04001JEUYFFUH5001JOol00;Io
o`P005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58862 .74898 m .58797 .69333 L .5568 .6918 L p .707 .577 .707 r
F P
0 g
s
.58797 .69333 m .58862 .74898 L .62045 .74787 L p .707 .577 .707 r
F P
0 g
s
.62045 .74787 m .6198 .69222 L .58797 .69333 L p .707 .577 .707 r
F P
0 g
s
.6198 .69222 m .62045 .74787 L .64983 .74422 L p .707 .577 .707 r
F P
0 g
s
.64983 .74422 m .64918 .68858 L .6198 .69222 L p .707 .577 .707 r
F P
0 g
s
.55745 .74745 m .5568 .6918 L .52934 .68778 L p .707 .577 .707 r
F P
0 g
s
.5568 .6918 m .55745 .74745 L .58862 .74898 L p .707 .577 .707 r
F P
0 g
s
.64918 .68858 m .64983 .74422 L .67389 .7384 L p .707 .577 .707 r
F P
0 g
s
.67389 .7384 m .67323 .68276 L .64918 .68858 L p .707 .577 .707 r
F P
0 g
s
.60004 .80745 m .59767 .77022 L .56656 .77035 L p .707 .577 .707 r
F P
0 g
s
.59767 .77022 m .60004 .80745 L .63182 .80484 L p .707 .577 .707 r
F P
0 g
s
.63182 .80484 m .62944 .76761 L .59767 .77022 L p .707 .577 .707 r
F P
0 g
s
.62944 .76761 m .63182 .80484 L .66115 .80001 L p .707 .577 .707 r
F P
0 g
s
.66115 .80001 m .65878 .76278 L .62944 .76761 L p .707 .577 .707 r
F P
0 g
s
.52934 .68778 m .53 .74343 L .55745 .74745 L p .707 .577 .707 r
F P
0 g
s
.53 .74343 m .52934 .68778 L .50829 .68166 L p .707 .577 .707 r
F P
0 g
s
.56893 .80757 m .56656 .77035 L .53917 .76798 L p .707 .577 .707 r
F P
0 g
s
.56656 .77035 m .56893 .80757 L .60004 .80745 L p .707 .577 .707 r
F P
0 g
s
.65878 .76278 m .66115 .80001 L .68518 .79343 L p .707 .577 .707 r
F P
0 g
s
.68518 .79343 m .6828 .7562 L .65878 .76278 L p .707 .577 .707 r
F P
0 g
s
.53917 .76798 m .54154 .80521 L .56893 .80757 L p .707 .577 .707 r
F P
0 g
s
.67323 .68276 m .67389 .7384 L .69026 .73098 L p .707 .577 .707 r
F P
0 g
s
.69026 .73098 m .6896 .67533 L .67323 .68276 L p .707 .577 .707 r
F P
0 g
s
.59564 .86384 m .60367 .84815 L .57564 .8329 L p .707 .577 .707 r
F P
0 g
s
.60367 .84815 m .59564 .86384 L .62464 .8751 L p .707 .577 .707 r
F P
0 g
s
.62464 .8751 m .63268 .85942 L .60367 .84815 L p .707 .577 .707 r
F P
0 g
s
.50829 .68166 m .50894 .73731 L .53 .74343 L p .707 .577 .707 r
F P
0 g
s
.5676 .84859 m .57564 .8329 L .55131 .81516 L p .707 .577 .707 r
F P
0 g
s
.57564 .8329 m .5676 .84859 L .59564 .86384 L p .707 .577 .707 r
F P
0 g
s
.54154 .80521 m .53917 .76798 L .51817 .76336 L p .707 .577 .707 r
F P
0 g
s
.63268 .85942 m .62464 .8751 L .65178 .88128 L p .707 .577 .707 r
F P
0 g
s
.65178 .88128 m .65982 .8656 L .63268 .85942 L p .707 .577 .707 r
F P
0 g
s
.50894 .73731 m .50829 .68166 L .4957 .67404 L p .707 .577 .707 r
F P
0 g
s
.55131 .81516 m .54328 .83084 L .5676 .84859 L p .707 .577 .707 r
F P
0 g
s
.51817 .76336 m .52054 .80059 L .54154 .80521 L p .707 .577 .707 r
F P
0 g
s
.54328 .83084 m .55131 .81516 L .53309 .79666 L p .707 .577 .707 r
F P
0 g
s
.6828 .7562 m .68518 .79343 L .70154 .78574 L p .707 .577 .707 r
F P
0 g
s
.70154 .78574 m .69916 .74851 L .6828 .7562 L p .707 .577 .707 r
F P
0 g
s
.53309 .79666 m .52505 .81235 L .54328 .83084 L p .707 .577 .707 r
F P
0 g
s
.65982 .8656 m .65178 .88128 L .67439 .88177 L p .707 .577 .707 r
F P
0 g
s
.67439 .88177 m .68243 .86609 L .65982 .8656 L p .707 .577 .707 r
F P
0 g
s
.4957 .67404 m .49635 .72969 L .50894 .73731 L p .707 .577 .707 r
F P
0 g
s
.6896 .67533 m .69026 .73098 L .69734 .72267 L p .707 .577 .707 r
F P
0 g
s
.69734 .72267 m .69669 .66702 L .6896 .67533 L p .707 .577 .707 r
F P
0 g
s
.52054 .80059 m .51817 .76336 L .50562 .75693 L p .707 .577 .707 r
F P
0 g
s
.52505 .81235 m .53309 .79666 L .52274 .77922 L p .707 .577 .707 r
F P
0 g
s
.50562 .75693 m .508 .79415 L .52054 .80059 L p .707 .577 .707 r
F P
0 g
s
.49635 .72969 m .4957 .67404 L .4928 .66567 L p .707 .577 .707 r
F P
0 g
s
.52274 .77922 m .5147 .79491 L .52505 .81235 L p .707 .577 .707 r
F P
0 g
s
.69916 .74851 m .70154 .78574 L .70863 .77769 L p .707 .577 .707 r
F P
0 g
s
.70863 .77769 m .70626 .74047 L .69916 .74851 L p .707 .577 .707 r
F P
0 g
s
.68243 .86609 m .67439 .88177 L .69026 .87652 L p .707 .577 .707 r
F P
0 g
s
.69026 .87652 m .6983 .86083 L .68243 .86609 L p .707 .577 .707 r
F P
0 g
s
.4928 .66567 m .49346 .72132 L .49635 .72969 L p .707 .577 .707 r
F P
0 g
s
.69669 .66702 m .69734 .72267 L .69444 .7143 L p .707 .577 .707 r
F P
0 g
s
.69444 .7143 m .69379 .65865 L .69669 .66702 L p .707 .577 .707 r
F P
0 g
s
.5147 .79491 m .52274 .77922 L .52128 .76454 L p .707 .577 .707 r
F P
0 g
s
.508 .79415 m .50562 .75693 L .50276 .74932 L p .707 .577 .707 r
F P
0 g
s
.48484 .82193 m .49309 .321 L .44909 .31759 L p .707 .577 .707 r
F P
0 g
s
.52128 .76454 m .51325 .78023 L .5147 .79491 L p .707 .577 .707 r
F P
0 g
s
.50276 .74932 m .50513 .78654 L .508 .79415 L p .707 .577 .707 r
F P
0 g
s
.49346 .72132 m .4928 .66567 L .49989 .65737 L p .707 .577 .707 r
F P
0 g
s
.49989 .65737 m .50054 .71301 L .49346 .72132 L p .707 .577 .707 r
F P
0 g
s
.51325 .78023 m .52128 .76454 L .52886 .75407 L p .707 .577 .707 r
F P
0 g
s
.50513 .78654 m .50276 .74932 L .50985 .74127 L p .707 .577 .707 r
F P
0 g
s
.52886 .75407 m .52083 .76975 L .51325 .78023 L p .707 .577 .707 r
F P
0 g
s
.50985 .74127 m .51222 .7785 L .50513 .78654 L p .707 .577 .707 r
F P
0 g
s
.50054 .71301 m .49989 .65737 L .51625 .64994 L p .707 .577 .707 r
F P
0 g
s
.52083 .76975 m .52886 .75407 L .54474 .74881 L p .707 .577 .707 r
F P
0 g
s
.51625 .64994 m .51691 .70559 L .50054 .71301 L p .707 .577 .707 r
F P
0 g
s
.51222 .7785 m .50985 .74127 L .52621 .73359 L p .707 .577 .707 r
F P
0 g
s
.54474 .74881 m .5367 .76449 L .52083 .76975 L p .707 .577 .707 r
F P
0 g
s
.51691 .70559 m .51625 .64994 L .54031 .64412 L p .707 .577 .707 r
F P
0 g
s
.52621 .73359 m .52858 .77081 L .51222 .7785 L p .707 .577 .707 r
F P
0 g
s
.54031 .64412 m .54096 .69977 L .51691 .70559 L p .707 .577 .707 r
F P
0 g
s
.49309 .321 m .48484 .82193 L .52978 .8215 L p .707 .577 .707 r
F P
0 g
s
.52858 .77081 m .52621 .73359 L .55023 .727 L p .707 .577 .707 r
F P
0 g
s
.5367 .76449 m .54474 .74881 L .56735 .7493 L p .707 .577 .707 r
F P
0 g
s
.56735 .7493 m .55931 .76498 L .5367 .76449 L p .707 .577 .707 r
F P
0 g
s
.55023 .727 m .55261 .76423 L .52858 .77081 L p .707 .577 .707 r
F P
0 g
s
.52978 .8215 m .53803 .32057 L .49309 .321 L p .707 .577 .707 r
F P
0 g
s
.54096 .69977 m .54031 .64412 L .56969 .64047 L p .707 .577 .707 r
F P
0 g
s
.56969 .64047 m .57034 .69612 L .54096 .69977 L p .707 .577 .707 r
F P
0 g
s
.55931 .76498 m .56735 .7493 L .59448 .75548 L p .707 .577 .707 r
F P
0 g
s
.55261 .76423 m .55023 .727 L .57957 .72217 L p .707 .577 .707 r
F P
0 g
s
.59448 .75548 m .58645 .77116 L .55931 .76498 L p .707 .577 .707 r
F P
0 g
s
.57957 .72217 m .58194 .7594 L .55261 .76423 L p .707 .577 .707 r
F P
0 g
s
.53803 .32057 m .52978 .8215 L .57125 .81725 L p .707 .577 .707 r
F P
0 g
s
.57034 .69612 m .56969 .64047 L .60152 .63936 L p .707 .577 .707 r
F P
0 g
s
.60152 .63936 m .60217 .69501 L .57034 .69612 L p .707 .577 .707 r
F P
0 g
s
.57125 .81725 m .5795 .31632 L .53803 .32057 L p .707 .577 .707 r
F P
0 g
s
.44083 .81852 m .44909 .31759 L .41033 .31066 L p .707 .577 .707 r
F P
0 g
s
.44909 .31759 m .44083 .81852 L .48484 .82193 L p .707 .577 .707 r
F P
0 g
s
.70626 .74047 m .70863 .77769 L .70576 .77008 L p .707 .577 .707 r
F P
0 g
s
.70576 .77008 m .70339 .73286 L .70626 .74047 L p .707 .577 .707 r
F P
0 g
s
.6983 .86083 m .69026 .87652 L .69784 .86604 L p .707 .577 .707 r
F P
0 g
s
.69784 .86604 m .70588 .85035 L .6983 .86083 L p .707 .577 .707 r
F P
0 g
s
.58194 .7594 m .57957 .72217 L .61135 .71956 L p .707 .577 .707 r
F P
0 g
s
.58645 .77116 m .59448 .75548 L .62349 .76674 L p .707 .577 .707 r
F P
0 g
s
.61135 .71956 m .61372 .75679 L .58194 .7594 L p .707 .577 .707 r
F P
0 g
s
.62349 .76674 m .61546 .78243 L .58645 .77116 L p .707 .577 .707 r
F P
0 g
s
.5795 .31632 m .57125 .81725 L .60521 .80961 L p .707 .577 .707 r
F P
0 g
s
.63269 .64089 m .63334 .69654 L .60217 .69501 L p .707 .577 .707 r
F P
0 g
s
.60217 .69501 m .60152 .63936 L .63269 .64089 L p .707 .577 .707 r
F P
0 g
s
.60521 .80961 m .61346 .30868 L .5795 .31632 L p .707 .577 .707 r
F P
0 g
s
.69379 .65865 m .69444 .7143 L .68185 .70668 L p .707 .577 .707 r
F P
0 g
s
.68185 .70668 m .6812 .65103 L .69379 .65865 L p .707 .577 .707 r
F P
0 g
s
.40208 .81159 m .41033 .31066 L .38061 .30088 L p .707 .577 .707 r
F P
0 g
s
.41033 .31066 m .40208 .81159 L .44083 .81852 L p .707 .577 .707 r
F P
0 g
s
.24561 .71084 m .24496 .65519 L .21379 .65366 L p .707 .577 .707 r
F P
0 g
s
.24496 .65519 m .24561 .71084 L .27745 .70973 L p .707 .577 .707 r
F P
0 g
s
.27745 .70973 m .27679 .65408 L .24496 .65519 L p .707 .577 .707 r
F P
0 g
s
.27679 .65408 m .27745 .70973 L .30683 .70608 L p .707 .577 .707 r
F P
0 g
s
.30683 .70608 m .30617 .65044 L .27679 .65408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70588 .85035 m .69784 .86604 L .69639 .85136 L p .707 .577 .707 r
F P
0 g
s
.69639 .85136 m .70442 .83568 L .70588 .85035 L p .707 .577 .707 r
F P
0 g
s
.21444 .70931 m .21379 .65366 L .18633 .64964 L p .707 .577 .707 r
F P
0 g
s
.21379 .65366 m .21444 .70931 L .24561 .71084 L p .707 .577 .707 r
F P
0 g
s
.70339 .73286 m .70576 .77008 L .69322 .76365 L p .707 .577 .707 r
F P
0 g
s
.69322 .76365 m .69084 .72642 L .70339 .73286 L p .707 .577 .707 r
F P
0 g
s
.30617 .65044 m .30683 .70608 L .33088 .70026 L p .707 .577 .707 r
F P
0 g
s
.33088 .70026 m .33023 .64462 L .30617 .65044 L p .707 .577 .707 r
F P
0 g
s
.64245 .71944 m .64483 .75666 L .61372 .75679 L p .707 .577 .707 r
F P
0 g
s
.61372 .75679 m .61135 .71956 L .64245 .71944 L p .707 .577 .707 r
F P
0 g
s
.65153 .78199 m .64349 .79768 L .61546 .78243 L p .707 .577 .707 r
F P
0 g
s
.61546 .78243 m .62349 .76674 L .65153 .78199 L p .707 .577 .707 r
F P
0 g
s
.61346 .30868 m .60521 .80961 L .62832 .79932 L p .707 .577 .707 r
F P
0 g
s
.62832 .79932 m .63657 .29839 L .61346 .30868 L p .707 .577 .707 r
F P
0 g
s
.25703 .77217 m .25466 .73494 L .22355 .73507 L p .707 .577 .707 r
F P
0 g
s
.25466 .73494 m .25703 .77217 L .28881 .76956 L p .707 .577 .707 r
F P
0 g
s
.28881 .76956 m .28644 .73233 L .25466 .73494 L p .707 .577 .707 r
F P
0 g
s
.6812 .65103 m .68185 .70668 L .6608 .70056 L p .707 .577 .707 r
F P
0 g
s
.6608 .70056 m .66015 .64491 L .6812 .65103 L p .707 .577 .707 r
F P
0 g
s
.28644 .73233 m .28881 .76956 L .31815 .76473 L p .707 .577 .707 r
F P
0 g
s
.31815 .76473 m .31577 .7275 L .28644 .73233 L p .707 .577 .707 r
F P
0 g
s
.18633 .64964 m .18699 .70529 L .21444 .70931 L p .707 .577 .707 r
F P
0 g
s
.18699 .70529 m .18633 .64964 L .16528 .64352 L p .707 .577 .707 r
F P
0 g
s
.22592 .7723 m .22355 .73507 L .19616 .73271 L p .707 .577 .707 r
F P
0 g
s
.22355 .73507 m .22592 .7723 L .25703 .77217 L p .707 .577 .707 r
F P
0 g
s
.37236 .80181 m .38061 .30088 L .36283 .28923 L p .707 .577 .707 r
F P
0 g
s
.38061 .30088 m .37236 .80181 L .40208 .81159 L p .707 .577 .707 r
F P
0 g
s
.31577 .7275 m .31815 .76473 L .34217 .75815 L p .707 .577 .707 r
F P
0 g
s
.34217 .75815 m .33979 .72092 L .31577 .7275 L p .707 .577 .707 r
F P
0 g
s
.19616 .73271 m .19853 .76993 L .22592 .7723 L p .707 .577 .707 r
F P
0 g
s
.33023 .64462 m .33088 .70026 L .34725 .69284 L p .707 .577 .707 r
F P
0 g
s
.34725 .69284 m .34659 .63719 L .33023 .64462 L p .707 .577 .707 r
F P
0 g
s
.70442 .83568 m .69639 .85136 L .68604 .83392 L p .707 .577 .707 r
F P
0 g
s
.68604 .83392 m .69408 .81823 L .70442 .83568 L p .707 .577 .707 r
F P
0 g
s
.69084 .72642 m .69322 .76365 L .67222 .75903 L p .707 .577 .707 r
F P
0 g
s
.67222 .75903 m .66985 .7218 L .69084 .72642 L p .707 .577 .707 r
F P
0 g
s
.25263 .82802 m .26066 .81234 L .23263 .79708 L p .707 .577 .707 r
F P
0 g
s
.26066 .81234 m .25263 .82802 L .28163 .83928 L p .707 .577 .707 r
F P
0 g
s
.28163 .83928 m .28967 .8236 L .26066 .81234 L p .707 .577 .707 r
F P
0 g
s
.16528 .64352 m .16593 .69917 L .18699 .70529 L p .707 .577 .707 r
F P
0 g
s
.22459 .81277 m .23263 .79708 L .2083 .77934 L p .707 .577 .707 r
F P
0 g
s
.23263 .79708 m .22459 .81277 L .25263 .82802 L p .707 .577 .707 r
F P
0 g
s
.19853 .76993 m .19616 .73271 L .17516 .72808 L p .707 .577 .707 r
F P
0 g
s
.66015 .64491 m .6608 .70056 L .63334 .69654 L p .707 .577 .707 r
F P
0 g
s
.63334 .69654 m .63269 .64089 L .66015 .64491 L p .707 .577 .707 r
F P
0 g
s
.28967 .8236 m .28163 .83928 L .30877 .84546 L p .707 .577 .707 r
F P
0 g
s
.30877 .84546 m .31681 .82978 L .28967 .8236 L p .707 .577 .707 r
F P
0 g
s
.16593 .69917 m .16528 .64352 L .15269 .6359 L p .707 .577 .707 r
F P
0 g
s
.2083 .77934 m .20027 .79503 L .22459 .81277 L p .707 .577 .707 r
F P
0 g
s
.17516 .72808 m .17753 .76531 L .19853 .76993 L p .707 .577 .707 r
F P
0 g
s
.20027 .79503 m .2083 .77934 L .19008 .76085 L p .707 .577 .707 r
F P
0 g
s
.33979 .72092 m .34217 .75815 L .35853 .75046 L p .707 .577 .707 r
F P
0 g
s
.35853 .75046 m .35615 .71323 L .33979 .72092 L p .707 .577 .707 r
F P
0 g
s
.63657 .29839 m .62832 .79932 L .63832 .7874 L p .707 .577 .707 r
F P
0 g
s
.63832 .7874 m .64657 .28647 L .63657 .29839 L p .707 .577 .707 r
F P
0 g
s
.19008 .76085 m .18204 .77653 L .20027 .79503 L p .707 .577 .707 r
F P
0 g
s
.66985 .7218 m .67222 .75903 L .64483 .75666 L p .707 .577 .707 r
F P
0 g
s
.64483 .75666 m .64245 .71944 L .66985 .7218 L p .707 .577 .707 r
F P
0 g
s
.69408 .81823 m .68604 .83392 L .66781 .81542 L p .707 .577 .707 r
F P
0 g
s
.66781 .81542 m .67585 .79974 L .69408 .81823 L p .707 .577 .707 r
F P
0 g
s
.31681 .82978 m .30877 .84546 L .33138 .84595 L p .707 .577 .707 r
F P
0 g
s
.33138 .84595 m .33942 .83027 L .31681 .82978 L p .707 .577 .707 r
F P
0 g
s
.15269 .6359 m .15334 .69155 L .16593 .69917 L p .707 .577 .707 r
F P
0 g
s
.34659 .63719 m .34725 .69284 L .35433 .68453 L p .707 .577 .707 r
F P
0 g
s
.35433 .68453 m .35368 .62888 L .34659 .63719 L p .707 .577 .707 r
F P
0 g
s
.17753 .76531 m .17516 .72808 L .16261 .72165 L p .707 .577 .707 r
F P
0 g
s
.18204 .77653 m .19008 .76085 L .17973 .7434 L p .707 .577 .707 r
F P
0 g
s
.35615 .71323 m .35853 .75046 L .36562 .74242 L p .707 .577 .707 r
F P
0 g
s
.36562 .74242 m .36325 .70519 L .35615 .71323 L p .707 .577 .707 r
F P
0 g
s
.36038 .69758 m .36275 .73481 L .35021 .72838 L p .707 .577 .707 r
F P
0 g
s
.35021 .72838 m .34783 .69115 L .36038 .69758 L p .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35107 .78241 L .35797 .79405 L p .707 .577 .707 r
F P
0 g
s
.35797 .79405 m .36142 .79986 L p .35827 .79956 L .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35797 .79405 L .35827 .79956 L .707 .577 .707 r
F
.36283 .28923 m .35875 .27683 L p .355 .73937 L F P
0 g
s
.35458 .79016 m .35532 .74536 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.35532 .74536 m .36283 .28923 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.36325 .70519 m .36562 .74242 L .36275 .73481 L p .707 .577 .707 r
F P
0 g
s
.36275 .73481 m .36038 .69758 L .36325 .70519 L p .707 .577 .707 r
F P
0 g
s
.36283 .28923 m .35458 .79016 L .37236 .80181 L p .707 .577 .707 r
F P
0 g
s
.15334 .69155 m .15269 .6359 L .14979 .62753 L p .707 .577 .707 r
F P
0 g
s
.16261 .72165 m .16499 .75888 L .17753 .76531 L p .707 .577 .707 r
F P
0 g
s
.17973 .7434 m .17169 .75909 L .18204 .77653 L p .707 .577 .707 r
F P
0 g
s
.67585 .79974 m .66781 .81542 L .64349 .79768 L p .707 .577 .707 r
F P
0 g
s
.64349 .79768 m .65153 .78199 L .67585 .79974 L p .707 .577 .707 r
F P
0 g
s
.33942 .83027 m .33138 .84595 L .34726 .8407 L p .707 .577 .707 r
F P
0 g
s
.34726 .8407 m .35529 .82501 L .33942 .83027 L p .707 .577 .707 r
F P
0 g
s
.14979 .62753 m .15045 .68318 L .15334 .69155 L p .707 .577 .707 r
F P
0 g
s
.35368 .62888 m .35433 .68453 L .35143 .67616 L p .707 .577 .707 r
F P
0 g
s
.35143 .67616 m .35078 .62051 L .35368 .62888 L p .707 .577 .707 r
F P
0 g
s
.17169 .75909 m .17973 .7434 L .17827 .72872 L p .707 .577 .707 r
F P
0 g
s
.16499 .75888 m .16261 .72165 L .15975 .71404 L p .707 .577 .707 r
F P
0 g
s
.64657 .28647 m .63832 .7874 L .63423 .775 L p .707 .577 .707 r
F P
0 g
s
.63423 .775 m .64248 .27407 L .64657 .28647 L p .707 .577 .707 r
F P
0 g
s
.17827 .72872 m .17024 .74441 L .17169 .75909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15975 .71404 m .16212 .75127 L .16499 .75888 L p .707 .577 .707 r
F P
0 g
s
.15045 .68318 m .14979 .62753 L .15688 .61922 L p .707 .577 .707 r
F P
0 g
s
.35529 .82501 m .34726 .8407 L .35483 .83022 L p .707 .577 .707 r
F P
0 g
s
.35483 .83022 m .36287 .81454 L .35529 .82501 L p .707 .577 .707 r
F P
0 g
s
.35875 .27683 m .3505 .77776 L .35458 .79016 L p .707 .577 .707 r
F P
0 g
s
.3505 .77776 m .35875 .27683 L .36875 .26491 L p .707 .577 .707 r
F P
0 g
s
.15688 .61922 m .15753 .67487 L .15045 .68318 L p .707 .577 .707 r
F P
0 g
s
.17024 .74441 m .17827 .72872 L .18585 .71825 L p .707 .577 .707 r
F P
0 g
s
.35078 .62051 m .35143 .67616 L .33884 .66854 L p .707 .577 .707 r
F P
0 g
s
.33884 .66854 m .33819 .61289 L .35078 .62051 L p .707 .577 .707 r
F P
0 g
s
.16212 .75127 m .15975 .71404 L .16684 .706 L p .707 .577 .707 r
F P
0 g
s
.18585 .71825 m .17782 .73393 L .17024 .74441 L p .707 .577 .707 r
F P
0 g
s
.16684 .706 m .16921 .74323 L .16212 .75127 L p .707 .577 .707 r
F P
0 g
s
.15753 .67487 m .15688 .61922 L .17324 .6118 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64248 .27407 m .63423 .775 L .61646 .76335 L p .707 .577 .707 r
F P
0 g
s
.61646 .76335 m .62471 .26242 L .64248 .27407 L p .707 .577 .707 r
F P
0 g
s
.36287 .81454 m .35483 .83022 L .35338 .81554 L p .707 .577 .707 r
F P
0 g
s
.35338 .81554 m .36142 .79986 L .36287 .81454 L p .707 .577 .707 r
F P
0 g
s
.17324 .6118 m .1739 .66745 L .15753 .67487 L p .707 .577 .707 r
F P
0 g
s
.33819 .61289 m .33884 .66854 L .31779 .66242 L p .707 .577 .707 r
F P
0 g
s
.31779 .66242 m .31714 .60677 L .33819 .61289 L p .707 .577 .707 r
F P
0 g
s
.17782 .73393 m .18585 .71825 L .20173 .71299 L p .707 .577 .707 r
F P
0 g
s
.3605 .76584 m .36875 .26491 L .39186 .25462 L p .707 .577 .707 r
F P
0 g
s
.36875 .26491 m .3605 .76584 L .3505 .77776 L p .707 .577 .707 r
F P
0 g
s
.16921 .74323 m .16684 .706 L .1832 .69831 L p .707 .577 .707 r
F P
0 g
s
.20173 .71299 m .19369 .72868 L .17782 .73393 L p .707 .577 .707 r
F P
0 g
s
.1739 .66745 m .17324 .6118 L .1973 .60598 L p .707 .577 .707 r
F P
0 g
s
.1832 .69831 m .18557 .73554 L .16921 .74323 L p .707 .577 .707 r
F P
0 g
s
.36142 .79986 m .35338 .81554 L .34303 .7981 L p .707 .577 .707 r
F P
0 g
s
.34783 .69115 m .35021 .72838 L .32921 .72375 L p .707 .577 .707 r
F P
0 g
s
.32921 .72375 m .32684 .68652 L .34783 .69115 L p .707 .577 .707 r
F P
0 g
s
.31714 .60677 m .31779 .66242 L .29033 .6584 L p .707 .577 .707 r
F P
0 g
s
.29033 .6584 m .28968 .60275 L .31714 .60677 L p .707 .577 .707 r
F P
0 g
s
.1973 .60598 m .19795 .66163 L .1739 .66745 L p .707 .577 .707 r
F P
0 g
s
.19369 .72868 m .20173 .71299 L .22434 .71348 L p .707 .577 .707 r
F P
0 g
s
.62471 .26242 m .61646 .76335 L .58674 .75358 L p .707 .577 .707 r
F P
0 g
s
.58674 .75358 m .59499 .25265 L .62471 .26242 L p .707 .577 .707 r
F P
0 g
s
.18557 .73554 m .1832 .69831 L .20722 .69173 L p .707 .577 .707 r
F P
0 g
s
.19795 .66163 m .1973 .60598 L .22668 .60233 L p .707 .577 .707 r
F P
0 g
s
.22434 .71348 m .2163 .72916 L .19369 .72868 L p .707 .577 .707 r
F P
0 g
s
.28968 .60275 m .29033 .6584 L .25916 .65687 L p .707 .577 .707 r
F P
0 g
s
.25916 .65687 m .25851 .60122 L .28968 .60275 L p .707 .577 .707 r
F P
0 g
s
.20722 .69173 m .2096 .72895 L .18557 .73554 L p .707 .577 .707 r
F P
0 g
s
.32684 .68652 m .32921 .72375 L .30182 .72139 L p .707 .577 .707 r
F P
0 g
s
.30182 .72139 m .29944 .68416 L .32684 .68652 L p .707 .577 .707 r
F P
0 g
s
.39186 .25462 m .38361 .75555 L .3605 .76584 L p .707 .577 .707 r
F P
0 g
s
.38361 .75555 m .39186 .25462 L .42581 .24698 L p .707 .577 .707 r
F P
0 g
s
.35107 .78241 m .34303 .7981 L .32481 .7796 L p .707 .577 .707 r
F P
0 g
s
.32481 .7796 m .33284 .76392 L .35107 .78241 L p .707 .577 .707 r
F P
0 g
s
.22733 .65798 m .22668 .60233 L .25851 .60122 L p .707 .577 .707 r
F P
0 g
s
.22668 .60233 m .22733 .65798 L .19795 .66163 L p .707 .577 .707 r
F P
0 g
s
.25851 .60122 m .25916 .65687 L .22733 .65798 L p .707 .577 .707 r
F P
0 g
s
.72583 .65694 m .72517 .60129 L .694 .59976 L p .707 .577 .707 r
F P
0 g
s
.72517 .60129 m .72583 .65694 L .75766 .65583 L p .707 .577 .707 r
F P
0 g
s
.75766 .65583 m .75701 .60018 L .72517 .60129 L p .707 .577 .707 r
F P
0 g
s
.2163 .72916 m .22434 .71348 L .25148 .71966 L p .707 .577 .707 r
F P
0 g
s
.75701 .60018 m .75766 .65583 L .78704 .65219 L p .707 .577 .707 r
F P
0 g
s
.78704 .65219 m .78639 .59654 L .75701 .60018 L p .707 .577 .707 r
F P
0 g
s
.2096 .72895 m .20722 .69173 L .23656 .6869 L p .707 .577 .707 r
F P
0 g
s
.69465 .65541 m .694 .59976 L .66655 .59574 L p .707 .577 .707 r
F P
0 g
s
.694 .59976 m .69465 .65541 L .72583 .65694 L p .707 .577 .707 r
F P
0 g
s
.25148 .71966 m .24344 .73534 L .2163 .72916 L p .707 .577 .707 r
F P
0 g
s
.29944 .68416 m .30182 .72139 L .27071 .72152 L p .707 .577 .707 r
F P
0 g
s
.27071 .72152 m .26834 .68429 L .29944 .68416 L p .707 .577 .707 r
F P
0 g
s
.23656 .6869 m .23893 .72412 L .2096 .72895 L p .707 .577 .707 r
F P
0 g
s
.59499 .25265 m .58674 .75358 L .54798 .74665 L p .707 .577 .707 r
F P
0 g
s
.54798 .74665 m .55623 .24571 L .59499 .25265 L p .707 .577 .707 r
F P
0 g
s
.33284 .76392 m .32481 .7796 L .30048 .76186 L p .707 .577 .707 r
F P
0 g
s
.30048 .76186 m .30852 .74618 L .33284 .76392 L p .707 .577 .707 r
F P
0 g
s
.23893 .72412 m .23656 .6869 L .26834 .68429 L p .707 .577 .707 r
F P
0 g
s
.78639 .59654 m .78704 .65219 L .81109 .64637 L p .707 .577 .707 r
F P
0 g
s
.81109 .64637 m .81044 .59072 L .78639 .59654 L p .707 .577 .707 r
F P
0 g
s
.24344 .73534 m .25148 .71966 L .28048 .73092 L p .707 .577 .707 r
F P
0 g
s
.26834 .68429 m .27071 .72152 L .23893 .72412 L p .707 .577 .707 r
F P
0 g
s
.73725 .71541 m .73487 .67818 L .70376 .67831 L p .707 .577 .707 r
F P
0 g
s
.73487 .67818 m .73725 .71541 L .76902 .7128 L p .707 .577 .707 r
F P
0 g
s
.76902 .7128 m .76665 .67557 L .73487 .67818 L p .707 .577 .707 r
F P
0 g
s
.76665 .67557 m .76902 .7128 L .79836 .70797 L p .707 .577 .707 r
F P
0 g
s
.79836 .70797 m .79598 .67074 L .76665 .67557 L p .707 .577 .707 r
F P
0 g
s
.66655 .59574 m .6672 .65139 L .69465 .65541 L p .707 .577 .707 r
F P
0 g
s
.41756 .74791 m .42581 .24698 L .46729 .24274 L p .707 .577 .707 r
F P
0 g
s
.42581 .24698 m .41756 .74791 L .38361 .75555 L p .707 .577 .707 r
F P
0 g
s
.6672 .65139 m .66655 .59574 L .64549 .58962 L p .707 .577 .707 r
F P
0 g
s
.30852 .74618 m .30048 .76186 L .27245 .74661 L p .707 .577 .707 r
F P
0 g
s
.27245 .74661 m .28048 .73092 L .30852 .74618 L p .707 .577 .707 r
F P
0 g
s
.70614 .71554 m .70376 .67831 L .67637 .67594 L p .707 .577 .707 r
F P
0 g
s
.70376 .67831 m .70614 .71554 L .73725 .71541 L p .707 .577 .707 r
F P
0 g
s
.28048 .73092 m .27245 .74661 L .24344 .73534 L p .707 .577 .707 r
F P
0 g
s
.79598 .67074 m .79836 .70797 L .82238 .70139 L p .707 .577 .707 r
F P
0 g
s
.82238 .70139 m .82001 .66416 L .79598 .67074 L p .707 .577 .707 r
F P
0 g
s
.67637 .67594 m .67874 .71317 L .70614 .71554 L p .707 .577 .707 r
F P
0 g
s
.55623 .24571 m .54798 .74665 L .50398 .74323 L p .707 .577 .707 r
F P
0 g
s
.50398 .74323 m .51223 .2423 L .55623 .24571 L p .707 .577 .707 r
F P
0 g
s
.81044 .59072 m .81109 .64637 L .82746 .63894 L p .707 .577 .707 r
F P
0 g
s
.82746 .63894 m .82681 .58329 L .81044 .59072 L p .707 .577 .707 r
F P
0 g
s
.73284 .7718 m .74088 .75612 L .71284 .74087 L p .707 .577 .707 r
F P
0 g
s
.74088 .75612 m .73284 .7718 L .76185 .78307 L p .707 .577 .707 r
F P
0 g
s
.76185 .78307 m .76988 .76738 L .74088 .75612 L p .707 .577 .707 r
F P
0 g
s
.64549 .58962 m .64615 .64527 L .6672 .65139 L p .707 .577 .707 r
F P
0 g
s
.7048 .75655 m .71284 .74087 L .68852 .72312 L p .707 .577 .707 r
F P
0 g
s
.71284 .74087 m .7048 .75655 L .73284 .7718 L p .707 .577 .707 r
F P
0 g
s
.45904 .74367 m .46729 .24274 L .51223 .2423 L p .707 .577 .707 r
F P
0 g
s
.46729 .24274 m .45904 .74367 L .41756 .74791 L p .707 .577 .707 r
F P
0 g
s
.67874 .71317 m .67637 .67594 L .65537 .67132 L p .707 .577 .707 r
F P
0 g
s
.76988 .76738 m .76185 .78307 L .78898 .78924 L p .707 .577 .707 r
F P
0 g
s
.78898 .78924 m .79702 .77356 L .76988 .76738 L p .707 .577 .707 r
F P
0 g
s
.51223 .2423 m .50398 .74323 L .45904 .74367 L p .707 .577 .707 r
F P
0 g
s
.64615 .64527 m .64549 .58962 L .6329 .582 L p .707 .577 .707 r
F P
0 g
s
.68852 .72312 m .68048 .73881 L .7048 .75655 L p .707 .577 .707 r
F P
0 g
s
.65537 .67132 m .65775 .70855 L .67874 .71317 L p .707 .577 .707 r
F P
0 g
s
.68048 .73881 m .68852 .72312 L .67029 .70463 L p .707 .577 .707 r
F P
0 g
s
.82001 .66416 m .82238 .70139 L .83874 .6937 L p .707 .577 .707 r
F P
0 g
s
.83874 .6937 m .83637 .65647 L .82001 .66416 L p .707 .577 .707 r
F P
0 g
s
.67029 .70463 m .66225 .72031 L .68048 .73881 L p .707 .577 .707 r
F P
0 g
s
.79702 .77356 m .78898 .78924 L .8116 .78973 L p .707 .577 .707 r
F P
0 g
s
.8116 .78973 m .81963 .77405 L .79702 .77356 L p .707 .577 .707 r
F P
0 g
s
.6329 .582 m .63355 .63765 L .64615 .64527 L p .707 .577 .707 r
F P
0 g
s
.82681 .58329 m .82746 .63894 L .83454 .63063 L p .707 .577 .707 r
F P
0 g
s
.83454 .63063 m .83389 .57499 L .82681 .58329 L p .707 .577 .707 r
F P
0 g
s
.65775 .70855 m .65537 .67132 L .64283 .66489 L p .707 .577 .707 r
F P
0 g
s
.66225 .72031 m .67029 .70463 L .65994 .68718 L p .707 .577 .707 r
F P
0 g
s
.64283 .66489 m .6452 .70212 L .65775 .70855 L p .707 .577 .707 r
F P
0 g
s
.63355 .63765 m .6329 .582 L .63001 .57363 L p .707 .577 .707 r
F P
0 g
s
.65994 .68718 m .65191 .70287 L .66225 .72031 L p .707 .577 .707 r
F P
0 g
s
.83637 .65647 m .83874 .6937 L .84583 .68566 L p .707 .577 .707 r
F P
0 g
s
.84583 .68566 m .84346 .64843 L .83637 .65647 L p .707 .577 .707 r
F P
0 g
s
.81963 .77405 m .8116 .78973 L .82747 .78448 L p .707 .577 .707 r
F P
0 g
s
.82747 .78448 m .8355 .7688 L .81963 .77405 L p .707 .577 .707 r
F P
0 g
s
.63001 .57363 m .63066 .62928 L .63355 .63765 L p .707 .577 .707 r
F P
0 g
s
.83389 .57499 m .83454 .63063 L .83165 .62226 L p .707 .577 .707 r
F P
0 g
s
.83165 .62226 m .831 .56661 L .83389 .57499 L p .707 .577 .707 r
F P
0 g
s
.65191 .70287 m .65994 .68718 L .65849 .67251 L p .707 .577 .707 r
F P
0 g
s
.6452 .70212 m .64283 .66489 L .63996 .65728 L p .707 .577 .707 r
F P
0 g
s
.65849 .67251 m .65045 .68819 L .65191 .70287 L p .707 .577 .707 r
F P
0 g
s
.63996 .65728 m .64233 .69451 L .6452 .70212 L p .707 .577 .707 r
F P
0 g
s
.63066 .62928 m .63001 .57363 L .63709 .56533 L p .707 .577 .707 r
F P
0 g
s
.84346 .64843 m .84583 .68566 L .84297 .67805 L p .707 .577 .707 r
F P
0 g
s
.84297 .67805 m .84059 .64082 L .84346 .64843 L p .707 .577 .707 r
F P
0 g
s
.8355 .7688 m .82747 .78448 L .83505 .774 L p .707 .577 .707 r
F P
0 g
s
.83505 .774 m .84308 .75832 L .8355 .7688 L p .707 .577 .707 r
F P
0 g
s
.63709 .56533 m .63774 .62097 L .63066 .62928 L p .707 .577 .707 r
F P
0 g
s
.65045 .68819 m .65849 .67251 L .66607 .66203 L p .707 .577 .707 r
F P
0 g
s
.831 .56661 m .83165 .62226 L .81906 .61464 L p .707 .577 .707 r
F P
0 g
s
.81906 .61464 m .8184 .55899 L .831 .56661 L p .707 .577 .707 r
F P
0 g
s
.64233 .69451 m .63996 .65728 L .64705 .64924 L p .707 .577 .707 r
F P
0 g
s
.66607 .66203 m .65803 .67771 L .65045 .68819 L p .707 .577 .707 r
F P
0 g
s
.38282 .6188 m .38216 .56315 L .35099 .56162 L p .707 .577 .707 r
F P
0 g
s
.38216 .56315 m .38282 .6188 L .41465 .61769 L p .707 .577 .707 r
F P
0 g
s
.41465 .61769 m .414 .56204 L .38216 .56315 L p .707 .577 .707 r
F P
0 g
s
.64705 .64924 m .64943 .68646 L .64233 .69451 L p .707 .577 .707 r
F P
0 g
s
.414 .56204 m .41465 .61769 L .44403 .61404 L p .707 .577 .707 r
F P
0 g
s
.44403 .61404 m .44338 .5584 L .414 .56204 L p .707 .577 .707 r
F P
0 g
s
.63774 .62097 m .63709 .56533 L .65346 .5579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84308 .75832 m .83505 .774 L .83359 .75932 L p .707 .577 .707 r
F P
0 g
s
.83359 .75932 m .84163 .74364 L .84308 .75832 L p .707 .577 .707 r
F P
0 g
s
.35164 .61727 m .35099 .56162 L .32354 .5576 L p .707 .577 .707 r
F P
0 g
s
.35099 .56162 m .35164 .61727 L .38282 .6188 L p .707 .577 .707 r
F P
0 g
s
.84059 .64082 m .84297 .67805 L .83042 .67161 L p .707 .577 .707 r
F P
0 g
s
.83042 .67161 m .82805 .63439 L .84059 .64082 L p .707 .577 .707 r
F P
0 g
s
.44338 .5584 m .44403 .61404 L .46808 .60822 L p .707 .577 .707 r
F P
0 g
s
.46808 .60822 m .46743 .55258 L .44338 .5584 L p .707 .577 .707 r
F P
0 g
s
.39424 .68013 m .39186 .6429 L .36075 .64303 L p .707 .577 .707 r
F P
0 g
s
.39186 .6429 m .39424 .68013 L .42601 .67752 L p .707 .577 .707 r
F P
0 g
s
.42601 .67752 m .42364 .6403 L .39186 .6429 L p .707 .577 .707 r
F P
0 g
s
.65803 .67771 m .66607 .66203 L .68194 .65677 L p .707 .577 .707 r
F P
0 g
s
.65346 .5579 m .65411 .61355 L .63774 .62097 L p .707 .577 .707 r
F P
0 g
s
.8184 .55899 m .81906 .61464 L .798 .60852 L p .707 .577 .707 r
F P
0 g
s
.798 .60852 m .79735 .55288 L .8184 .55899 L p .707 .577 .707 r
F P
0 g
s
.42364 .6403 m .42601 .67752 L .45535 .67269 L p .707 .577 .707 r
F P
0 g
s
.45535 .67269 m .45297 .63547 L .42364 .6403 L p .707 .577 .707 r
F P
0 g
s
.32354 .5576 m .32419 .61325 L .35164 .61727 L p .707 .577 .707 r
F P
0 g
s
.64943 .68646 m .64705 .64924 L .66341 .64155 L p .707 .577 .707 r
F P
0 g
s
.32419 .61325 m .32354 .5576 L .30248 .55148 L p .707 .577 .707 r
F P
0 g
s
.36313 .68026 m .36075 .64303 L .33336 .64067 L p .707 .577 .707 r
F P
0 g
s
.36075 .64303 m .36313 .68026 L .39424 .68013 L p .707 .577 .707 r
F P
0 g
s
.68194 .65677 m .6739 .67246 L .65803 .67771 L p .707 .577 .707 r
F P
0 g
s
.65411 .61355 m .65346 .5579 L .67751 .55208 L p .707 .577 .707 r
F P
0 g
s
.66341 .64155 m .66579 .67877 L .64943 .68646 L p .707 .577 .707 r
F P
0 g
s
.45297 .63547 m .45535 .67269 L .47937 .66611 L p .707 .577 .707 r
F P
0 g
s
.47937 .66611 m .477 .62888 L .45297 .63547 L p .707 .577 .707 r
F P
0 g
s
.33336 .64067 m .33573 .6779 L .36313 .68026 L p .707 .577 .707 r
F P
0 g
s
.46743 .55258 m .46808 .60822 L .48445 .6008 L p .707 .577 .707 r
F P
0 g
s
.48445 .6008 m .4838 .54515 L .46743 .55258 L p .707 .577 .707 r
F P
0 g
s
.84163 .74364 m .83359 .75932 L .82325 .74188 L p .707 .577 .707 r
F P
0 g
s
.82325 .74188 m .83128 .7262 L .84163 .74364 L p .707 .577 .707 r
F P
0 g
s
.82805 .63439 m .83042 .67161 L .80942 .66699 L p .707 .577 .707 r
F P
0 g
s
.80942 .66699 m .80705 .62976 L .82805 .63439 L p .707 .577 .707 r
F P
0 g
s
.38983 .73598 m .39787 .7203 L .36983 .70505 L p .707 .577 .707 r
F P
0 g
s
.39787 .7203 m .38983 .73598 L .41884 .74725 L p .707 .577 .707 r
F P
0 g
s
.41884 .74725 m .42687 .73156 L .39787 .7203 L p .707 .577 .707 r
F P
0 g
s
.30248 .55148 m .30314 .60713 L .32419 .61325 L p .707 .577 .707 r
F P
0 g
s
.36179 .72073 m .36983 .70505 L .34551 .6873 L p .707 .577 .707 r
F P
0 g
s
.36983 .70505 m .36179 .72073 L .38983 .73598 L p .707 .577 .707 r
F P
0 g
s
.33573 .6779 m .33336 .64067 L .31236 .63604 L p .707 .577 .707 r
F P
0 g
s
.79735 .55288 m .798 .60852 L .77055 .6045 L p .707 .577 .707 r
F P
0 g
s
.77055 .6045 m .7699 .54885 L .79735 .55288 L p .707 .577 .707 r
F P
0 g
s
.42687 .73156 m .41884 .74725 L .44597 .75343 L p .707 .577 .707 r
F P
0 g
s
.44597 .75343 m .45401 .73774 L .42687 .73156 L p .707 .577 .707 r
F P
0 g
s
.67751 .55208 m .67816 .60773 L .65411 .61355 L p .707 .577 .707 r
F P
0 g
s
.6739 .67246 m .68194 .65677 L .70455 .65726 L p .707 .577 .707 r
F P
0 g
s
.30314 .60713 m .30248 .55148 L .28989 .54386 L p .707 .577 .707 r
F P
0 g
s
.34551 .6873 m .33747 .70299 L .36179 .72073 L p .707 .577 .707 r
F P
0 g
s
.66579 .67877 m .66341 .64155 L .68744 .63496 L p .707 .577 .707 r
F P
0 g
s
.31236 .63604 m .31474 .67327 L .33573 .6779 L p .707 .577 .707 r
F P
0 g
s
.33747 .70299 m .34551 .6873 L .32728 .66881 L p .707 .577 .707 r
F P
0 g
s
.67816 .60773 m .67751 .55208 L .70689 .54844 L p .707 .577 .707 r
F P
0 g
s
.477 .62888 m .47937 .66611 L .49573 .65842 L p .707 .577 .707 r
F P
0 g
s
.49573 .65842 m .49336 .62119 L .477 .62888 L p .707 .577 .707 r
F P
0 g
s
.70455 .65726 m .69652 .67294 L .6739 .67246 L p .707 .577 .707 r
F P
0 g
s
.32728 .66881 m .31924 .68449 L .33747 .70299 L p .707 .577 .707 r
F P
0 g
s
.7699 .54885 m .77055 .6045 L .73938 .60297 L p .707 .577 .707 r
F P
0 g
s
.73938 .60297 m .73873 .54732 L .7699 .54885 L p .707 .577 .707 r
F P
0 g
s
.68744 .63496 m .68981 .67219 L .66579 .67877 L p .707 .577 .707 r
F P
0 g
s
.80705 .62976 m .80942 .66699 L .78203 .66463 L p .707 .577 .707 r
F P
0 g
s
.78203 .66463 m .77966 .6274 L .80705 .62976 L p .707 .577 .707 r
F P
0 g
s
.83128 .7262 m .82325 .74188 L .80502 .72338 L p .707 .577 .707 r
F P
0 g
s
.80502 .72338 m .81306 .7077 L .83128 .7262 L p .707 .577 .707 r
F P
0 g
s
.45401 .73774 m .44597 .75343 L .46859 .75391 L p .707 .577 .707 r
F P
0 g
s
.46859 .75391 m .47662 .73823 L .45401 .73774 L p .707 .577 .707 r
F P
0 g
s
.28989 .54386 m .29054 .59951 L .30314 .60713 L p .707 .577 .707 r
F P
0 g
s
.4838 .54515 m .48445 .6008 L .49153 .59249 L p .707 .577 .707 r
F P
0 g
s
.49153 .59249 m .49088 .53684 L .4838 .54515 L p .707 .577 .707 r
F P
0 g
s
.70754 .60408 m .70689 .54844 L .73873 .54732 L p .707 .577 .707 r
F P
0 g
s
.70689 .54844 m .70754 .60408 L .67816 .60773 L p .707 .577 .707 r
F P
0 g
s
.73873 .54732 m .73938 .60297 L .70754 .60408 L p .707 .577 .707 r
F P
0 g
s
.31474 .67327 m .31236 .63604 L .29982 .62961 L p .707 .577 .707 r
F P
0 g
s
.69652 .67294 m .70455 .65726 L .73169 .66344 L p .707 .577 .707 r
F P
0 g
s
.31924 .68449 m .32728 .66881 L .31693 .65136 L p .707 .577 .707 r
F P
0 g
s
.68981 .67219 m .68744 .63496 L .71677 .63013 L p .707 .577 .707 r
F P
0 g
s
.29054 .59951 m .28989 .54386 L .287 .53549 L p .707 .577 .707 r
F P
0 g
s
.29982 .62961 m .30219 .66684 L .31474 .67327 L p .707 .577 .707 r
F P
0 g
s
.77966 .6274 m .78203 .66463 L .75092 .66475 L p .707 .577 .707 r
F P
0 g
s
.75092 .66475 m .74855 .62753 L .77966 .6274 L p .707 .577 .707 r
F P
0 g
s
.73169 .66344 m .72365 .67912 L .69652 .67294 L p .707 .577 .707 r
F P
0 g
s
.31693 .65136 m .3089 .66705 L .31924 .68449 L p .707 .577 .707 r
F P
0 g
s
.71677 .63013 m .71915 .66736 L .68981 .67219 L p .707 .577 .707 r
F P
0 g
s
.81306 .7077 m .80502 .72338 L .7807 .70564 L p .707 .577 .707 r
F P
0 g
s
.7807 .70564 m .78873 .68996 L .81306 .7077 L p .707 .577 .707 r
F P
0 g
s
.49336 .62119 m .49573 .65842 L .50282 .65038 L p .707 .577 .707 r
F P
0 g
s
.50282 .65038 m .50045 .61315 L .49336 .62119 L p .707 .577 .707 r
F P
0 g
s
.71915 .66736 m .71677 .63013 L .74855 .62753 L p .707 .577 .707 r
F P
0 g
s
.47662 .73823 m .46859 .75391 L .48446 .74866 L p .707 .577 .707 r
F P
0 g
s
.48446 .74866 m .49249 .73298 L .47662 .73823 L p .707 .577 .707 r
F P
0 g
s
.72365 .67912 m .73169 .66344 L .7607 .67471 L p .707 .577 .707 r
F P
0 g
s
.74855 .62753 m .75092 .66475 L .71915 .66736 L p .707 .577 .707 r
F P
0 g
s
.78873 .68996 m .7807 .70564 L .75266 .69039 L p .707 .577 .707 r
F P
0 g
s
.75266 .69039 m .7607 .67471 L .78873 .68996 L p .707 .577 .707 r
F P
0 g
s
.287 .53549 m .28765 .59114 L .29054 .59951 L p .707 .577 .707 r
F P
0 g
s
.7607 .67471 m .75266 .69039 L .72365 .67912 L p .707 .577 .707 r
F P
0 g
s
.49088 .53684 m .49153 .59249 L .48864 .58412 L p .707 .577 .707 r
F P
0 g
s
.48864 .58412 m .48799 .52847 L .49088 .53684 L p .707 .577 .707 r
F P
0 g
s
.3089 .66705 m .31693 .65136 L .31548 .63669 L p .707 .577 .707 r
F P
0 g
s
.30219 .66684 m .29982 .62961 L .29695 .622 L p .707 .577 .707 r
F P
0 g
s
.31548 .63669 m .30744 .65237 L .3089 .66705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29695 .622 m .29932 .65923 L .30219 .66684 L p .707 .577 .707 r
F P
0 g
s
.28765 .59114 m .287 .53549 L .29408 .52719 L p .707 .577 .707 r
F P
0 g
s
.50045 .61315 m .50282 .65038 L .49996 .64277 L p .707 .577 .707 r
F P
0 g
s
.49996 .64277 m .49758 .60554 L .50045 .61315 L p .707 .577 .707 r
F P
0 g
s
.49249 .73298 m .48446 .74866 L .49204 .73818 L p .707 .577 .707 r
F P
0 g
s
.49204 .73818 m .50007 .7225 L .49249 .73298 L p .707 .577 .707 r
F P
0 g
s
.29408 .52719 m .29473 .58283 L .28765 .59114 L p .707 .577 .707 r
F P
0 g
s
.30744 .65237 m .31548 .63669 L .32306 .62621 L p .707 .577 .707 r
F P
0 g
s
.48799 .52847 m .48864 .58412 L .47605 .5765 L p .707 .577 .707 r
F P
0 g
s
.47605 .5765 m .47539 .52085 L .48799 .52847 L p .707 .577 .707 r
F P
0 g
s
.29932 .65923 m .29695 .622 L .30404 .61396 L p .707 .577 .707 r
F P
0 g
s
.32306 .62621 m .31502 .64189 L .30744 .65237 L p .707 .577 .707 r
F P
0 g
s
.30404 .61396 m .30642 .65119 L .29932 .65923 L p .707 .577 .707 r
F P
0 g
s
.29473 .58283 m .29408 .52719 L .31045 .51976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50007 .7225 m .49204 .73818 L .49058 .7235 L p .707 .577 .707 r
F P
0 g
s
.49058 .7235 m .49862 .70782 L .50007 .7225 L p .707 .577 .707 r
F P
0 g
s
.49758 .60554 m .49996 .64277 L .48741 .63634 L p .707 .577 .707 r
F P
0 g
s
.48741 .63634 m .48504 .59911 L .49758 .60554 L p .707 .577 .707 r
F P
0 g
s
.31045 .51976 m .3111 .57541 L .29473 .58283 L p .707 .577 .707 r
F P
0 g
s
.47539 .52085 m .47605 .5765 L .45499 .57038 L p .707 .577 .707 r
F P
0 g
s
.45499 .57038 m .45434 .51473 L .47539 .52085 L p .707 .577 .707 r
F P
0 g
s
.31502 .64189 m .32306 .62621 L .33893 .62095 L p .707 .577 .707 r
F P
0 g
s
.30642 .65119 m .30404 .61396 L .3204 .60627 L p .707 .577 .707 r
F P
0 g
s
.33893 .62095 m .33089 .63664 L .31502 .64189 L p .707 .577 .707 r
F P
0 g
s
.3111 .57541 m .31045 .51976 L .3345 .51394 L p .707 .577 .707 r
F P
0 g
s
.3204 .60627 m .32278 .6435 L .30642 .65119 L p .707 .577 .707 r
F P
0 g
s
.49862 .70782 m .49058 .7235 L .48024 .70606 L p .707 .577 .707 r
F P
0 g
s
.48024 .70606 m .48827 .69038 L .49862 .70782 L p .707 .577 .707 r
F P
0 g
s
.48504 .59911 m .48741 .63634 L .46641 .63171 L p .707 .577 .707 r
F P
0 g
s
.46641 .63171 m .46404 .59448 L .48504 .59911 L p .707 .577 .707 r
F P
0 g
s
.45434 .51473 m .45499 .57038 L .42754 .56636 L p .707 .577 .707 r
F P
0 g
s
.42754 .56636 m .42688 .51071 L .45434 .51473 L p .707 .577 .707 r
F P
0 g
s
.3345 .51394 m .33515 .56959 L .3111 .57541 L p .707 .577 .707 r
F P
0 g
s
.33089 .63664 m .33893 .62095 L .36154 .62144 L p .707 .577 .707 r
F P
0 g
s
.32278 .6435 m .3204 .60627 L .34443 .59969 L p .707 .577 .707 r
F P
0 g
s
.33515 .56959 m .3345 .51394 L .36388 .51029 L p .707 .577 .707 r
F P
0 g
s
.36154 .62144 m .35351 .63712 L .33089 .63664 L p .707 .577 .707 r
F P
0 g
s
.42688 .51071 m .42754 .56636 L .39637 .56483 L p .707 .577 .707 r
F P
0 g
s
.39637 .56483 m .39571 .50918 L .42688 .51071 L p .707 .577 .707 r
F P
0 g
s
.34443 .59969 m .3468 .63692 L .32278 .6435 L p .707 .577 .707 r
F P
0 g
s
.46404 .59448 m .46641 .63171 L .43902 .62935 L p .707 .577 .707 r
F P
0 g
s
.43902 .62935 m .43665 .59212 L .46404 .59448 L p .707 .577 .707 r
F P
0 g
s
.48827 .69038 m .48024 .70606 L .46201 .68756 L p .707 .577 .707 r
F P
0 g
s
.46201 .68756 m .47004 .67188 L .48827 .69038 L p .707 .577 .707 r
F P
0 g
s
.36453 .56594 m .36388 .51029 L .39571 .50918 L p .707 .577 .707 r
F P
0 g
s
.36388 .51029 m .36453 .56594 L .33515 .56959 L p .707 .577 .707 r
F P
0 g
s
.39571 .50918 m .39637 .56483 L .36453 .56594 L p .707 .577 .707 r
F P
0 g
s
.35351 .63712 m .36154 .62144 L .38868 .62762 L p .707 .577 .707 r
F P
0 g
s
.3468 .63692 m .34443 .59969 L .37376 .59486 L p .707 .577 .707 r
F P
0 g
s
.38868 .62762 m .38064 .6433 L .35351 .63712 L p .707 .577 .707 r
F P
0 g
s
.43665 .59212 m .43902 .62935 L .40791 .62948 L p .707 .577 .707 r
F P
0 g
s
.40791 .62948 m .40554 .59225 L .43665 .59212 L p .707 .577 .707 r
F P
0 g
s
.37376 .59486 m .37614 .63208 L .3468 .63692 L p .707 .577 .707 r
F P
0 g
s
.47004 .67188 m .46201 .68756 L .43769 .66982 L p .707 .577 .707 r
F P
0 g
s
.43769 .66982 m .44572 .65414 L .47004 .67188 L p .707 .577 .707 r
F P
0 g
s
.37614 .63208 m .37376 .59486 L .40554 .59225 L p .707 .577 .707 r
F P
0 g
s
.38064 .6433 m .38868 .62762 L .41769 .63889 L p .707 .577 .707 r
F P
0 g
s
.40554 .59225 m .40791 .62948 L .37614 .63208 L p .707 .577 .707 r
F P
0 g
s
.44572 .65414 m .43769 .66982 L .40965 .65457 L p .707 .577 .707 r
F P
0 g
s
.40965 .65457 m .41769 .63889 L .44572 .65414 L p .707 .577 .707 r
F P
0 g
s
.41769 .63889 m .40965 .65457 L .38064 .6433 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo`d008Eo
o`00Ogoo30001UYF00<005YFFUH015YF2@00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001fOol0079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00IJEP@0079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eo
o`00JWoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001ZOol0
06Moo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001WOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0004FUH9
0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`P000AJEP03001JEUYF009JEPP000IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
G7oo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000aJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0055oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0047oo3`00Agoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool400000eYF001J
EP07FUH00`00FUIJEP02FUH8000oOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000hOol0055oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003Aoo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF1@001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
<Goo001AOol00`00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUH000040002FUH80004FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo00<005YF0000
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF1`00
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP@0009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00DGoo00@005YF001JEP8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001J
EUYFFUH005YF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol01P00FUH00000FUH000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000EJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP090004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;goo0015Ool90004Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00
?Goo200015YF00<005YFFUH00UYF1`0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000eOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEPL000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000_Ool0035oo`@0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000_Ool002moo`<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH2000_Ool002eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00800003FUH0000002moo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000_Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000_Ool0
02Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF000040001EYF00<005YFFUH00UYF00<005YF0000;goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH015YF3`0025YF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00P000AJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUH0000_Ool002Yoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP05FUH30005FUH40003FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH00UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01@00<7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001EYF1`00
15YF00<005YFFUH01UYF0`000eYF100000=JEP00FUH01EYF00@005YFFUIJEP800003FUH0000000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH500000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YF00003`002EYF1@001EYF00<005YFFUH015YF00<0
05YFFUH00UYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH200000eYF001JEP06FUH00`00FUIJ
EP04FUH20006FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF0000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEPH00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
0P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00H005YFFUIJEP00FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP0200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01P00FUH00000FUH000MJEP80009JEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP03000015YF001JEP000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002eoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@00
00=JEP0000000`000UYF200000=JEP0000000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000IJEP03001JEP00008000IJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH00000;Goo000ZOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YF000010000UYF
00<005YFFUH015YF00@005YF000000=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01@00FUIJEUYF00001UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000]Ool002Yoo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP04FUHN0003
FUH01000FUIJEP00;Goo000ZOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YF00001eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000IJEP@000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000=JEP03
001JEUYF00=JEP<000Uoo`@000EJEP@0009JEP8002aoo`00:Woo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUH00000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF009J
EP03001JEUYF00=JEP@000MJEP03001JEUYF00IJEP8000=oo`@0009JEP03001JEUYF00AJEP04001J
EUYFFUH4000/Ool002Yoo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUH0000;0002FUH00`00FUIJ
EP07FUH00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002Yoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUH0000B00000eYF001JEP08FUH01@00FUIJEUYF00000UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00FUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0100025YF00D005YFFUIJEP0000IJEP03
001JEUYF00AJEP03001JEUYF009JEP<002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH04@0000=JEP00FUH01EYF0`000UYF00<005YFFUH015YF1P00
0eYF00<005YFFUH025YF0`0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP090004FUH00`00FUIJ
EP06FUH01000FUIJEUYF0`001UYF0P000UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF0P00
1EYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000EJEP00001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00EJEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00:goo00D005YFFUIJEP0000EJ
EP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01P00FUH00000FUH000IJEPH000=JEP03001JEUYF00UJEP03001JEP0000EJEP03001JEUYF
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH0
05YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0P002UYF00<005YF00001UYF
00<005YFFUH00UYF0P00;Goo000/Ool200000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH20006FUH00`00FUH0
00020004FUH00`00FUIJEP09FUH01000FUIJEP000eYF00<005YF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@0000AJEP00FUH000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000MJEP04001JEP000006FUH01000FUIJEUYF0P00;Woo
000^Ool30002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00D0
05YFFUIJEP00009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP@00003FUH005YF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000<7oo000aOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001eYF0P0015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@0
05YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF0003
FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@0
05YFFUIJEP<0039oo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP05001JEUYFFUH00008FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`000eYF00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YF000000MJEP<003Eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEP00009J
EP04001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00<007oo
Ool0<goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF0P0025YF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0002FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000goo001JEP04FUH00`00FUH0000dOol002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00EJEP8000IJEP03001JEUYF00UJEP03001JEUYF00EJEP06001JEP00001J
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00P00
15YF00<005YFFUH04P002goo00D005YFFUIJEP0000=JEP03001oogoo035oo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH000UJEP8000AJEP03001JEUYF00UJEP03001JEUYF00EJEP80
009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP03001JEUYF
00=JEP03001JEP00008000Uoo`D000eoo`800003FUH005YF00=JEP03001oogoo031oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF7@0015YF00<005YFFUH00`001eYF00@005YF
0000009JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000=JEP@000EJEP800003FUH007oo00Qoo`D000moo`03001J
EUYF00AJEP03001oogoo02moo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@0
00AJEP03001JEUYF009JEP<000Yoo`D0009JEP<00005FUH005YFFUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`002eYF00<005YFFUH01UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP<000Yoo`D0011oo`03001JEUYF00AJ
EP03001oogoo02ioo`00;Goo00@005YFFUH000=JEP03001JEUYF00=JEPD000MJEP03001JEUYF00EJ
EP8000Aoo`@00003FUH005YF00EJEP04001JEP000002FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF0P002UYF00<005YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001eYF00D005YFFUIJEP0000=JEP03001oogoo00Qoo`<0019oo`03001J
EUYF009JEP03001JEP0002moo`00;Goo00@005YFFUH000=JEP03001JEP0000@000Aoo`@0009JEP03
001JEUYF00MJEPD000EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH200000eYF
001JEP07FUH50005FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0MOol01000
FUIJEP000UYF00<007ooOol0;Goo000^Ool00`00FUH00003FUH200000eYF001JEP02FUH<0007FUH0
1@00FUIJEUYF00001UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP<000QJEP03
001JEUYF009JEPl000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000MJEP04001JEP000006FUH2000NOol00`00FUH00003FUH00`00Oomoo`0/Ool002ioo`04
001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00`001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP04001JEUYF0008FUH00`00Oomoo`0LOol0
0`00FUIJEP02FUH00`00Oomoo`0/Ool002ioo`06001JEP00001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF100000=JEP00FUH01UYF0P000UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YFFUH030001UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH0
0P001UYF0`007Goo00<005YFFUH00UYF00<007ooOol0:goo000^Ool3000015YF001JEP000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH01000FUIJEP002eYF2@00
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF
FUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2000]Ool002ioo`04001JEP000002FUH01000
FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00<005YF00000P001UYF00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH010001EYF10000UYF00<005YFFUH00eYF00<005YF0000
0P0035YF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP8001]oo`05001JEP00FUH0000]Ool002ioo`04
001JEP000003FUH01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00D005YF
FUIJEP0000IJEP03001JEP00009JEP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEPX0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000MJEP03001JEUYF009JEP800003FUH005YF
00IJEP03001JEUYF00=JEP@000MJEP8001Uoo`05001JEP00FUH0000]Ool002ioo`03001JEP0000AJ
EP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJ
EP02FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF3@0015YF00@005YFFUH0
00UJEP8001Qoo`04001JEUYF000]Ool002moo`<000AJEP03001JEP0000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH40003Ool01@00FUIJEP00FUH00P0025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0P000goo1P000UYF0`0000AJEP00FUIJEP<000IJEP03001JEUYF008001Ioo`04001JEUYF000]
Ool0035oo`06001JEUYFFUH005YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000IJEP03001oogoo009oo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000004FUH50002
FUH00`00FUIJEP04FUH00`00FUH00002000015YF000007oo0P0015YF00<005YFFUH00UYF0`004goo
00<005YF0000;Woo000bOol00`00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
00000goo001JEP03FUH00`00FUH00003Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF0P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`000goo0P0000=JEP00FUH01eYF1@00
3Woo0`00;Woo000bOol00`00FUH00004FUH00`00Oomoo`0B000;Ool01@00FUIJEUYF00000UYF00<0
07ooOol00P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001EYF00<005YFFUH015YF00<005YF
FUH00UYF0`001Goo0`001eYF00<005YFFUH00UYF1`001Goo0P0000=JEP00Ool0;Woo000cOol00`00
FUIJEP04FUH00`00Oomoo`0:Ool5000>Ool30004FUH01000Ool0000015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000Qoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00D0009JEP8002moo`00=7oo00<005YFFUH015YF00<007oo
Ool02Goo1@0047oo00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000`000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002Woo0`0000=JEP00FUH01eYF
00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Woo000eOol00`00FUIJEP02FUH01000FUH0
00002Goo1@004Goo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH0009JEP800003FUH005YF00EJEP03001JEUYF009JEP8000ioo`<000MJEP03001JEUYF
00=JEP04001JEUYFFUH2000`Ool003Eoo`03001JEUYF009JEP05001JEUYFFUH00009Ool3000COol0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH01000
FUH000001UYF00@005YFFUIJEP80019oo`@0009JEP03001JEUYF00=JEP03001JEUYF00<0035oo`00
=Woo00@005YFFUH000EJEP03001oogoo01eoo`06001JEUYF001JEP0015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YF000001Qoo`/0
03Aoo`00=goo00<005YF00001UYF0P007Woo0P000eYF0P000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`00>7oo00<005YFFUH01eYF00<007oo
Ool077oo00H005YFFUIJEP00Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF00000007FUH3001LOol0
03Uoo`8000IJEP04001JEP00000MOol01@00FUIJEUYF00000Woo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
0eYF0P001eYF00<007ooOol0FWoo000kOol00`00FUIJEP03FUH01000FUIJEUYF0P006goo00<005YF
FUH00P0017oo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00@005YFFUIJEPP00003Ool005YF00AJEP03001JEP0005]oo`00?7oo00D0
05YFFUIJEP0000IJEP8001Yoo`04001JEP000007Ool300000eYF001JEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000002Woo00D005YFFUIJEP00
00=JEP03001oogoo05Qoo`00?Goo0P0000=JEP00FUH01eYF0P0067oo0P000UYF00<007ooOol01goo
100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10003Goo
0P0000=JEP00FUH00eYF00<007ooOol0Egoo000oOol00`00FUIJEP07FUH01000FUH000005goo00@0
05YFFUH000eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000moo`03001JEUYF00AJEP03001oogoo05Ioo`00@7oo0P001eYF00@005YFFUIJEP8001Eoo`03
001JEP0001Aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`03001JEUYF
00AJEP03001oogoo05Eoo`00@Woo0P0015YF00<005YFFUH015YF0P004goo00<005YF000077oo6P00
0UYF00<007ooOol01goo1@004Goo00<005YFFUH00UYF00<005YF0000EWoo0014Ool20002FUH00`00
FUIJEP06FUH5000>Ool2000bOol01000FUIJEP0015YF00<007ooOol01goo0`004Woo00<005YFFUH0
0UYF00<005YF0000EWoo0016Ool30008FUH00`00FUIJEP02FUH70005Ool4000cOol20006FUH2000M
Ool01000FUIJEP000eYF00<007ooOol0Dgoo0019Ool30005FUH00`00FUIJEP05FUH01000FUIJEUYF
1@000UYF00<007ooOol0<goo00<005YFFUH01UYF00<007ooOol06goo00<005YF00000eYF00<007oo
Ool0Dgoo001<Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=goo0P001UYF
0`0077oo00<005YFFUH00eYF00<007ooOol0DWoo001?Ool30006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000>Goo00<005YFFUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2001DOol0059oo`@0
009JEP03001JEUYF00=JEP03001JEUYF008003]oo`05001JEUYFFUH00004FUH2000JOol01000FUIJ
EUYF0P00E7oo001FOol;000nOol30007FUH2000IOol01@00FUH005YF0000E7oo002QOol00`00FUIJ
EP07FUH2000GOol01@00FUH005YF0000E7oo002ROol20006FUH00`00FUIJEP02000FOol01000FUIJ
EP00E7oo002TOol20004FUH00`00FUIJEP02FUH3000COol00`00FUH0001EOol00:Ioo`800003FUH0
05YF00MJEP<0011oo`03001JEP0005Eoo`00Z7oo0`001eYF00<005YFFUH010002Woo0P0000=JEP00
Ool0EGoo002[Ool20005FUH00`00FUIJEP04FUH:0002FUH2001FOol00:eoo`<00003FUH005YF00MJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05Eoo`00/7oo0`001eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00/goo10000UYF00<005YFFUH00eYF00<005YFFUH00`00F7oo002gOol;
001KOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58862 .74898 m .58797 .69333 L .5568 .6918 L p .707 .577 .707 r
F P
0 g
s
.58797 .69333 m .58862 .74898 L .62045 .74787 L p .707 .577 .707 r
F P
0 g
s
.62045 .74787 m .6198 .69222 L .58797 .69333 L p .707 .577 .707 r
F P
0 g
s
.6198 .69222 m .62045 .74787 L .64983 .74422 L p .707 .577 .707 r
F P
0 g
s
.64983 .74422 m .64918 .68858 L .6198 .69222 L p .707 .577 .707 r
F P
0 g
s
.55745 .74745 m .5568 .6918 L .52934 .68778 L p .707 .577 .707 r
F P
0 g
s
.5568 .6918 m .55745 .74745 L .58862 .74898 L p .707 .577 .707 r
F P
0 g
s
.64918 .68858 m .64983 .74422 L .67389 .7384 L p .707 .577 .707 r
F P
0 g
s
.67389 .7384 m .67323 .68276 L .64918 .68858 L p .707 .577 .707 r
F P
0 g
s
.60004 .80745 m .59767 .77022 L .56656 .77035 L p .707 .577 .707 r
F P
0 g
s
.59767 .77022 m .60004 .80745 L .63182 .80484 L p .707 .577 .707 r
F P
0 g
s
.63182 .80484 m .62944 .76761 L .59767 .77022 L p .707 .577 .707 r
F P
0 g
s
.62944 .76761 m .63182 .80484 L .66115 .80001 L p .707 .577 .707 r
F P
0 g
s
.66115 .80001 m .65878 .76278 L .62944 .76761 L p .707 .577 .707 r
F P
0 g
s
.52934 .68778 m .53 .74343 L .55745 .74745 L p .707 .577 .707 r
F P
0 g
s
.53 .74343 m .52934 .68778 L .50829 .68166 L p .707 .577 .707 r
F P
0 g
s
.56893 .80757 m .56656 .77035 L .53917 .76798 L p .707 .577 .707 r
F P
0 g
s
.56656 .77035 m .56893 .80757 L .60004 .80745 L p .707 .577 .707 r
F P
0 g
s
.65878 .76278 m .66115 .80001 L .68518 .79343 L p .707 .577 .707 r
F P
0 g
s
.68518 .79343 m .6828 .7562 L .65878 .76278 L p .707 .577 .707 r
F P
0 g
s
.53917 .76798 m .54154 .80521 L .56893 .80757 L p .707 .577 .707 r
F P
0 g
s
.67323 .68276 m .67389 .7384 L .69026 .73098 L p .707 .577 .707 r
F P
0 g
s
.69026 .73098 m .6896 .67533 L .67323 .68276 L p .707 .577 .707 r
F P
0 g
s
.59564 .86384 m .60367 .84815 L .57564 .8329 L p .707 .577 .707 r
F P
0 g
s
.60367 .84815 m .59564 .86384 L .62464 .8751 L p .707 .577 .707 r
F P
0 g
s
.62464 .8751 m .63268 .85942 L .60367 .84815 L p .707 .577 .707 r
F P
0 g
s
.50829 .68166 m .50894 .73731 L .53 .74343 L p .707 .577 .707 r
F P
0 g
s
.5676 .84859 m .57564 .8329 L .55131 .81516 L p .707 .577 .707 r
F P
0 g
s
.57564 .8329 m .5676 .84859 L .59564 .86384 L p .707 .577 .707 r
F P
0 g
s
.54154 .80521 m .53917 .76798 L .51817 .76336 L p .707 .577 .707 r
F P
0 g
s
.63268 .85942 m .62464 .8751 L .65178 .88128 L p .707 .577 .707 r
F P
0 g
s
.65178 .88128 m .65982 .8656 L .63268 .85942 L p .707 .577 .707 r
F P
0 g
s
.50894 .73731 m .50829 .68166 L .4957 .67404 L p .707 .577 .707 r
F P
0 g
s
.55131 .81516 m .54328 .83084 L .5676 .84859 L p .707 .577 .707 r
F P
0 g
s
.51817 .76336 m .52054 .80059 L .54154 .80521 L p .707 .577 .707 r
F P
0 g
s
.54328 .83084 m .55131 .81516 L .53309 .79666 L p .707 .577 .707 r
F P
0 g
s
.6828 .7562 m .68518 .79343 L .70154 .78574 L p .707 .577 .707 r
F P
0 g
s
.70154 .78574 m .69916 .74851 L .6828 .7562 L p .707 .577 .707 r
F P
0 g
s
.53309 .79666 m .52505 .81235 L .54328 .83084 L p .707 .577 .707 r
F P
0 g
s
.65982 .8656 m .65178 .88128 L .67439 .88177 L p .707 .577 .707 r
F P
0 g
s
.67439 .88177 m .68243 .86609 L .65982 .8656 L p .707 .577 .707 r
F P
0 g
s
.4957 .67404 m .49635 .72969 L .50894 .73731 L p .707 .577 .707 r
F P
0 g
s
.6896 .67533 m .69026 .73098 L .69734 .72267 L p .707 .577 .707 r
F P
0 g
s
.69734 .72267 m .69669 .66702 L .6896 .67533 L p .707 .577 .707 r
F P
0 g
s
.52054 .80059 m .51817 .76336 L .50562 .75693 L p .707 .577 .707 r
F P
0 g
s
.52505 .81235 m .53309 .79666 L .52274 .77922 L p .707 .577 .707 r
F P
0 g
s
.50562 .75693 m .508 .79415 L .52054 .80059 L p .707 .577 .707 r
F P
0 g
s
.49635 .72969 m .4957 .67404 L .4928 .66567 L p .707 .577 .707 r
F P
0 g
s
.52274 .77922 m .5147 .79491 L .52505 .81235 L p .707 .577 .707 r
F P
0 g
s
.69916 .74851 m .70154 .78574 L .70863 .77769 L p .707 .577 .707 r
F P
0 g
s
.70863 .77769 m .70626 .74047 L .69916 .74851 L p .707 .577 .707 r
F P
0 g
s
.68243 .86609 m .67439 .88177 L .69026 .87652 L p .707 .577 .707 r
F P
0 g
s
.69026 .87652 m .6983 .86083 L .68243 .86609 L p .707 .577 .707 r
F P
0 g
s
.4928 .66567 m .49346 .72132 L .49635 .72969 L p .707 .577 .707 r
F P
0 g
s
.69669 .66702 m .69734 .72267 L .69444 .7143 L p .707 .577 .707 r
F P
0 g
s
.69444 .7143 m .69379 .65865 L .69669 .66702 L p .707 .577 .707 r
F P
0 g
s
.5147 .79491 m .52274 .77922 L .52128 .76454 L p .707 .577 .707 r
F P
0 g
s
.508 .79415 m .50562 .75693 L .50276 .74932 L p .707 .577 .707 r
F P
0 g
s
.48484 .82193 m .49309 .321 L .44909 .31759 L p .707 .577 .707 r
F P
0 g
s
.52128 .76454 m .51325 .78023 L .5147 .79491 L p .707 .577 .707 r
F P
0 g
s
.50276 .74932 m .50513 .78654 L .508 .79415 L p .707 .577 .707 r
F P
0 g
s
.49346 .72132 m .4928 .66567 L .49989 .65737 L p .707 .577 .707 r
F P
0 g
s
.49989 .65737 m .50054 .71301 L .49346 .72132 L p .707 .577 .707 r
F P
0 g
s
.51325 .78023 m .52128 .76454 L .52886 .75407 L p .707 .577 .707 r
F P
0 g
s
.50513 .78654 m .50276 .74932 L .50985 .74127 L p .707 .577 .707 r
F P
0 g
s
.52886 .75407 m .52083 .76975 L .51325 .78023 L p .707 .577 .707 r
F P
0 g
s
.50985 .74127 m .51222 .7785 L .50513 .78654 L p .707 .577 .707 r
F P
0 g
s
.50054 .71301 m .49989 .65737 L .51625 .64994 L p .707 .577 .707 r
F P
0 g
s
.52083 .76975 m .52886 .75407 L .54474 .74881 L p .707 .577 .707 r
F P
0 g
s
.51625 .64994 m .51691 .70559 L .50054 .71301 L p .707 .577 .707 r
F P
0 g
s
.51222 .7785 m .50985 .74127 L .52621 .73359 L p .707 .577 .707 r
F P
0 g
s
.54474 .74881 m .5367 .76449 L .52083 .76975 L p .707 .577 .707 r
F P
0 g
s
.51691 .70559 m .51625 .64994 L .54031 .64412 L p .707 .577 .707 r
F P
0 g
s
.52621 .73359 m .52858 .77081 L .51222 .7785 L p .707 .577 .707 r
F P
0 g
s
.54031 .64412 m .54096 .69977 L .51691 .70559 L p .707 .577 .707 r
F P
0 g
s
.49309 .321 m .48484 .82193 L .52978 .8215 L p .707 .577 .707 r
F P
0 g
s
.52858 .77081 m .52621 .73359 L .55023 .727 L p .707 .577 .707 r
F P
0 g
s
.5367 .76449 m .54474 .74881 L .56735 .7493 L p .707 .577 .707 r
F P
0 g
s
.56735 .7493 m .55931 .76498 L .5367 .76449 L p .707 .577 .707 r
F P
0 g
s
.55023 .727 m .55261 .76423 L .52858 .77081 L p .707 .577 .707 r
F P
0 g
s
.52978 .8215 m .53803 .32057 L .49309 .321 L p .707 .577 .707 r
F P
0 g
s
.54096 .69977 m .54031 .64412 L .56969 .64047 L p .707 .577 .707 r
F P
0 g
s
.56969 .64047 m .57034 .69612 L .54096 .69977 L p .707 .577 .707 r
F P
0 g
s
.55931 .76498 m .56735 .7493 L .59448 .75548 L p .707 .577 .707 r
F P
0 g
s
.55261 .76423 m .55023 .727 L .57957 .72217 L p .707 .577 .707 r
F P
0 g
s
.59448 .75548 m .58645 .77116 L .55931 .76498 L p .707 .577 .707 r
F P
0 g
s
.57957 .72217 m .58194 .7594 L .55261 .76423 L p .707 .577 .707 r
F P
0 g
s
.53803 .32057 m .52978 .8215 L .57125 .81725 L p .707 .577 .707 r
F P
0 g
s
.57034 .69612 m .56969 .64047 L .60152 .63936 L p .707 .577 .707 r
F P
0 g
s
.60152 .63936 m .60217 .69501 L .57034 .69612 L p .707 .577 .707 r
F P
0 g
s
.57125 .81725 m .5795 .31632 L .53803 .32057 L p .707 .577 .707 r
F P
0 g
s
.44083 .81852 m .44909 .31759 L .41033 .31066 L p .707 .577 .707 r
F P
0 g
s
.44909 .31759 m .44083 .81852 L .48484 .82193 L p .707 .577 .707 r
F P
0 g
s
.70626 .74047 m .70863 .77769 L .70576 .77008 L p .707 .577 .707 r
F P
0 g
s
.70576 .77008 m .70339 .73286 L .70626 .74047 L p .707 .577 .707 r
F P
0 g
s
.6983 .86083 m .69026 .87652 L .69784 .86604 L p .707 .577 .707 r
F P
0 g
s
.69784 .86604 m .70588 .85035 L .6983 .86083 L p .707 .577 .707 r
F P
0 g
s
.58194 .7594 m .57957 .72217 L .61135 .71956 L p .707 .577 .707 r
F P
0 g
s
.58645 .77116 m .59448 .75548 L .62349 .76674 L p .707 .577 .707 r
F P
0 g
s
.61135 .71956 m .61372 .75679 L .58194 .7594 L p .707 .577 .707 r
F P
0 g
s
.62349 .76674 m .61546 .78243 L .58645 .77116 L p .707 .577 .707 r
F P
0 g
s
.5795 .31632 m .57125 .81725 L .60521 .80961 L p .707 .577 .707 r
F P
0 g
s
.63269 .64089 m .63334 .69654 L .60217 .69501 L p .707 .577 .707 r
F P
0 g
s
.60217 .69501 m .60152 .63936 L .63269 .64089 L p .707 .577 .707 r
F P
0 g
s
.60521 .80961 m .61346 .30868 L .5795 .31632 L p .707 .577 .707 r
F P
0 g
s
.69379 .65865 m .69444 .7143 L .68185 .70668 L p .707 .577 .707 r
F P
0 g
s
.68185 .70668 m .6812 .65103 L .69379 .65865 L p .707 .577 .707 r
F P
0 g
s
.40208 .81159 m .41033 .31066 L .38061 .30088 L p .707 .577 .707 r
F P
0 g
s
.41033 .31066 m .40208 .81159 L .44083 .81852 L p .707 .577 .707 r
F P
0 g
s
.24561 .71084 m .24496 .65519 L .21379 .65366 L p .707 .577 .707 r
F P
0 g
s
.24496 .65519 m .24561 .71084 L .27745 .70973 L p .707 .577 .707 r
F P
0 g
s
.27745 .70973 m .27679 .65408 L .24496 .65519 L p .707 .577 .707 r
F P
0 g
s
.27679 .65408 m .27745 .70973 L .30683 .70608 L p .707 .577 .707 r
F P
0 g
s
.30683 .70608 m .30617 .65044 L .27679 .65408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70588 .85035 m .69784 .86604 L .69639 .85136 L p .707 .577 .707 r
F P
0 g
s
.69639 .85136 m .70442 .83568 L .70588 .85035 L p .707 .577 .707 r
F P
0 g
s
.21444 .70931 m .21379 .65366 L .18633 .64964 L p .707 .577 .707 r
F P
0 g
s
.21379 .65366 m .21444 .70931 L .24561 .71084 L p .707 .577 .707 r
F P
0 g
s
.70339 .73286 m .70576 .77008 L .69322 .76365 L p .707 .577 .707 r
F P
0 g
s
.69322 .76365 m .69084 .72642 L .70339 .73286 L p .707 .577 .707 r
F P
0 g
s
.30617 .65044 m .30683 .70608 L .33088 .70026 L p .707 .577 .707 r
F P
0 g
s
.33088 .70026 m .33023 .64462 L .30617 .65044 L p .707 .577 .707 r
F P
0 g
s
.64245 .71944 m .64483 .75666 L .61372 .75679 L p .707 .577 .707 r
F P
0 g
s
.61372 .75679 m .61135 .71956 L .64245 .71944 L p .707 .577 .707 r
F P
0 g
s
.65153 .78199 m .64349 .79768 L .61546 .78243 L p .707 .577 .707 r
F P
0 g
s
.61546 .78243 m .62349 .76674 L .65153 .78199 L p .707 .577 .707 r
F P
0 g
s
.61346 .30868 m .60521 .80961 L .62832 .79932 L p .707 .577 .707 r
F P
0 g
s
.62832 .79932 m .63657 .29839 L .61346 .30868 L p .707 .577 .707 r
F P
0 g
s
.25703 .77217 m .25466 .73494 L .22355 .73507 L p .707 .577 .707 r
F P
0 g
s
.25466 .73494 m .25703 .77217 L .28881 .76956 L p .707 .577 .707 r
F P
0 g
s
.28881 .76956 m .28644 .73233 L .25466 .73494 L p .707 .577 .707 r
F P
0 g
s
.6812 .65103 m .68185 .70668 L .6608 .70056 L p .707 .577 .707 r
F P
0 g
s
.6608 .70056 m .66015 .64491 L .6812 .65103 L p .707 .577 .707 r
F P
0 g
s
.28644 .73233 m .28881 .76956 L .31815 .76473 L p .707 .577 .707 r
F P
0 g
s
.31815 .76473 m .31577 .7275 L .28644 .73233 L p .707 .577 .707 r
F P
0 g
s
.18633 .64964 m .18699 .70529 L .21444 .70931 L p .707 .577 .707 r
F P
0 g
s
.18699 .70529 m .18633 .64964 L .16528 .64352 L p .707 .577 .707 r
F P
0 g
s
.22592 .7723 m .22355 .73507 L .19616 .73271 L p .707 .577 .707 r
F P
0 g
s
.22355 .73507 m .22592 .7723 L .25703 .77217 L p .707 .577 .707 r
F P
0 g
s
.37236 .80181 m .38061 .30088 L .36283 .28923 L p .707 .577 .707 r
F P
0 g
s
.38061 .30088 m .37236 .80181 L .40208 .81159 L p .707 .577 .707 r
F P
0 g
s
.31577 .7275 m .31815 .76473 L .34217 .75815 L p .707 .577 .707 r
F P
0 g
s
.34217 .75815 m .33979 .72092 L .31577 .7275 L p .707 .577 .707 r
F P
0 g
s
.19616 .73271 m .19853 .76993 L .22592 .7723 L p .707 .577 .707 r
F P
0 g
s
.33023 .64462 m .33088 .70026 L .34725 .69284 L p .707 .577 .707 r
F P
0 g
s
.34725 .69284 m .34659 .63719 L .33023 .64462 L p .707 .577 .707 r
F P
0 g
s
.70442 .83568 m .69639 .85136 L .68604 .83392 L p .707 .577 .707 r
F P
0 g
s
.68604 .83392 m .69408 .81823 L .70442 .83568 L p .707 .577 .707 r
F P
0 g
s
.69084 .72642 m .69322 .76365 L .67222 .75903 L p .707 .577 .707 r
F P
0 g
s
.67222 .75903 m .66985 .7218 L .69084 .72642 L p .707 .577 .707 r
F P
0 g
s
.25263 .82802 m .26066 .81234 L .23263 .79708 L p .707 .577 .707 r
F P
0 g
s
.26066 .81234 m .25263 .82802 L .28163 .83928 L p .707 .577 .707 r
F P
0 g
s
.28163 .83928 m .28967 .8236 L .26066 .81234 L p .707 .577 .707 r
F P
0 g
s
.16528 .64352 m .16593 .69917 L .18699 .70529 L p .707 .577 .707 r
F P
0 g
s
.22459 .81277 m .23263 .79708 L .2083 .77934 L p .707 .577 .707 r
F P
0 g
s
.23263 .79708 m .22459 .81277 L .25263 .82802 L p .707 .577 .707 r
F P
0 g
s
.19853 .76993 m .19616 .73271 L .17516 .72808 L p .707 .577 .707 r
F P
0 g
s
.66015 .64491 m .6608 .70056 L .63334 .69654 L p .707 .577 .707 r
F P
0 g
s
.63334 .69654 m .63269 .64089 L .66015 .64491 L p .707 .577 .707 r
F P
0 g
s
.28967 .8236 m .28163 .83928 L .30877 .84546 L p .707 .577 .707 r
F P
0 g
s
.30877 .84546 m .31681 .82978 L .28967 .8236 L p .707 .577 .707 r
F P
0 g
s
.16593 .69917 m .16528 .64352 L .15269 .6359 L p .707 .577 .707 r
F P
0 g
s
.2083 .77934 m .20027 .79503 L .22459 .81277 L p .707 .577 .707 r
F P
0 g
s
.17516 .72808 m .17753 .76531 L .19853 .76993 L p .707 .577 .707 r
F P
0 g
s
.20027 .79503 m .2083 .77934 L .19008 .76085 L p .707 .577 .707 r
F P
0 g
s
.33979 .72092 m .34217 .75815 L .35853 .75046 L p .707 .577 .707 r
F P
0 g
s
.35853 .75046 m .35615 .71323 L .33979 .72092 L p .707 .577 .707 r
F P
0 g
s
.63657 .29839 m .62832 .79932 L .63832 .7874 L p .707 .577 .707 r
F P
0 g
s
.63832 .7874 m .64657 .28647 L .63657 .29839 L p .707 .577 .707 r
F P
0 g
s
.19008 .76085 m .18204 .77653 L .20027 .79503 L p .707 .577 .707 r
F P
0 g
s
.66985 .7218 m .67222 .75903 L .64483 .75666 L p .707 .577 .707 r
F P
0 g
s
.64483 .75666 m .64245 .71944 L .66985 .7218 L p .707 .577 .707 r
F P
0 g
s
.69408 .81823 m .68604 .83392 L .66781 .81542 L p .707 .577 .707 r
F P
0 g
s
.66781 .81542 m .67585 .79974 L .69408 .81823 L p .707 .577 .707 r
F P
0 g
s
.31681 .82978 m .30877 .84546 L .33138 .84595 L p .707 .577 .707 r
F P
0 g
s
.33138 .84595 m .33942 .83027 L .31681 .82978 L p .707 .577 .707 r
F P
0 g
s
.15269 .6359 m .15334 .69155 L .16593 .69917 L p .707 .577 .707 r
F P
0 g
s
.34659 .63719 m .34725 .69284 L .35433 .68453 L p .707 .577 .707 r
F P
0 g
s
.35433 .68453 m .35368 .62888 L .34659 .63719 L p .707 .577 .707 r
F P
0 g
s
.17753 .76531 m .17516 .72808 L .16261 .72165 L p .707 .577 .707 r
F P
0 g
s
.18204 .77653 m .19008 .76085 L .17973 .7434 L p .707 .577 .707 r
F P
0 g
s
.35615 .71323 m .35853 .75046 L .36562 .74242 L p .707 .577 .707 r
F P
0 g
s
.36562 .74242 m .36325 .70519 L .35615 .71323 L p .707 .577 .707 r
F P
0 g
s
.36038 .69758 m .36275 .73481 L .35021 .72838 L p .707 .577 .707 r
F P
0 g
s
.35021 .72838 m .34783 .69115 L .36038 .69758 L p .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35107 .78241 L .35797 .79405 L p .707 .577 .707 r
F P
0 g
s
.35797 .79405 m .36142 .79986 L p .35827 .79956 L .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35797 .79405 L .35827 .79956 L .707 .577 .707 r
F
.36283 .28923 m .35875 .27683 L p .355 .73937 L F P
0 g
s
.35458 .79016 m .35532 .74536 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.35532 .74536 m .36283 .28923 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.36325 .70519 m .36562 .74242 L .36275 .73481 L p .707 .577 .707 r
F P
0 g
s
.36275 .73481 m .36038 .69758 L .36325 .70519 L p .707 .577 .707 r
F P
0 g
s
.36283 .28923 m .35458 .79016 L .37236 .80181 L p .707 .577 .707 r
F P
0 g
s
.15334 .69155 m .15269 .6359 L .14979 .62753 L p .707 .577 .707 r
F P
0 g
s
.16261 .72165 m .16499 .75888 L .17753 .76531 L p .707 .577 .707 r
F P
0 g
s
.17973 .7434 m .17169 .75909 L .18204 .77653 L p .707 .577 .707 r
F P
0 g
s
.67585 .79974 m .66781 .81542 L .64349 .79768 L p .707 .577 .707 r
F P
0 g
s
.64349 .79768 m .65153 .78199 L .67585 .79974 L p .707 .577 .707 r
F P
0 g
s
.33942 .83027 m .33138 .84595 L .34726 .8407 L p .707 .577 .707 r
F P
0 g
s
.34726 .8407 m .35529 .82501 L .33942 .83027 L p .707 .577 .707 r
F P
0 g
s
.14979 .62753 m .15045 .68318 L .15334 .69155 L p .707 .577 .707 r
F P
0 g
s
.35368 .62888 m .35433 .68453 L .35143 .67616 L p .707 .577 .707 r
F P
0 g
s
.35143 .67616 m .35078 .62051 L .35368 .62888 L p .707 .577 .707 r
F P
0 g
s
.17169 .75909 m .17973 .7434 L .17827 .72872 L p .707 .577 .707 r
F P
0 g
s
.16499 .75888 m .16261 .72165 L .15975 .71404 L p .707 .577 .707 r
F P
0 g
s
.64657 .28647 m .63832 .7874 L .63423 .775 L p .707 .577 .707 r
F P
0 g
s
.63423 .775 m .64248 .27407 L .64657 .28647 L p .707 .577 .707 r
F P
0 g
s
.17827 .72872 m .17024 .74441 L .17169 .75909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15975 .71404 m .16212 .75127 L .16499 .75888 L p .707 .577 .707 r
F P
0 g
s
.15045 .68318 m .14979 .62753 L .15688 .61922 L p .707 .577 .707 r
F P
0 g
s
.35529 .82501 m .34726 .8407 L .35483 .83022 L p .707 .577 .707 r
F P
0 g
s
.35483 .83022 m .36287 .81454 L .35529 .82501 L p .707 .577 .707 r
F P
0 g
s
.35875 .27683 m .3505 .77776 L .35458 .79016 L p .707 .577 .707 r
F P
0 g
s
.3505 .77776 m .35875 .27683 L .36875 .26491 L p .707 .577 .707 r
F P
0 g
s
.15688 .61922 m .15753 .67487 L .15045 .68318 L p .707 .577 .707 r
F P
0 g
s
.17024 .74441 m .17827 .72872 L .18585 .71825 L p .707 .577 .707 r
F P
0 g
s
.35078 .62051 m .35143 .67616 L .33884 .66854 L p .707 .577 .707 r
F P
0 g
s
.33884 .66854 m .33819 .61289 L .35078 .62051 L p .707 .577 .707 r
F P
0 g
s
.16212 .75127 m .15975 .71404 L .16684 .706 L p .707 .577 .707 r
F P
0 g
s
.18585 .71825 m .17782 .73393 L .17024 .74441 L p .707 .577 .707 r
F P
0 g
s
.16684 .706 m .16921 .74323 L .16212 .75127 L p .707 .577 .707 r
F P
0 g
s
.15753 .67487 m .15688 .61922 L .17324 .6118 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64248 .27407 m .63423 .775 L .61646 .76335 L p .707 .577 .707 r
F P
0 g
s
.61646 .76335 m .62471 .26242 L .64248 .27407 L p .707 .577 .707 r
F P
0 g
s
.36287 .81454 m .35483 .83022 L .35338 .81554 L p .707 .577 .707 r
F P
0 g
s
.35338 .81554 m .36142 .79986 L .36287 .81454 L p .707 .577 .707 r
F P
0 g
s
.17324 .6118 m .1739 .66745 L .15753 .67487 L p .707 .577 .707 r
F P
0 g
s
.33819 .61289 m .33884 .66854 L .31779 .66242 L p .707 .577 .707 r
F P
0 g
s
.31779 .66242 m .31714 .60677 L .33819 .61289 L p .707 .577 .707 r
F P
0 g
s
.17782 .73393 m .18585 .71825 L .20173 .71299 L p .707 .577 .707 r
F P
0 g
s
.3605 .76584 m .36875 .26491 L .39186 .25462 L p .707 .577 .707 r
F P
0 g
s
.36875 .26491 m .3605 .76584 L .3505 .77776 L p .707 .577 .707 r
F P
0 g
s
.16921 .74323 m .16684 .706 L .1832 .69831 L p .707 .577 .707 r
F P
0 g
s
.20173 .71299 m .19369 .72868 L .17782 .73393 L p .707 .577 .707 r
F P
0 g
s
.1739 .66745 m .17324 .6118 L .1973 .60598 L p .707 .577 .707 r
F P
0 g
s
.1832 .69831 m .18557 .73554 L .16921 .74323 L p .707 .577 .707 r
F P
0 g
s
.36142 .79986 m .35338 .81554 L .34303 .7981 L p .707 .577 .707 r
F P
0 g
s
.34783 .69115 m .35021 .72838 L .32921 .72375 L p .707 .577 .707 r
F P
0 g
s
.32921 .72375 m .32684 .68652 L .34783 .69115 L p .707 .577 .707 r
F P
0 g
s
.31714 .60677 m .31779 .66242 L .29033 .6584 L p .707 .577 .707 r
F P
0 g
s
.29033 .6584 m .28968 .60275 L .31714 .60677 L p .707 .577 .707 r
F P
0 g
s
.1973 .60598 m .19795 .66163 L .1739 .66745 L p .707 .577 .707 r
F P
0 g
s
.19369 .72868 m .20173 .71299 L .22434 .71348 L p .707 .577 .707 r
F P
0 g
s
.62471 .26242 m .61646 .76335 L .58674 .75358 L p .707 .577 .707 r
F P
0 g
s
.58674 .75358 m .59499 .25265 L .62471 .26242 L p .707 .577 .707 r
F P
0 g
s
.18557 .73554 m .1832 .69831 L .20722 .69173 L p .707 .577 .707 r
F P
0 g
s
.19795 .66163 m .1973 .60598 L .22668 .60233 L p .707 .577 .707 r
F P
0 g
s
.22434 .71348 m .2163 .72916 L .19369 .72868 L p .707 .577 .707 r
F P
0 g
s
.28968 .60275 m .29033 .6584 L .25916 .65687 L p .707 .577 .707 r
F P
0 g
s
.25916 .65687 m .25851 .60122 L .28968 .60275 L p .707 .577 .707 r
F P
0 g
s
.20722 .69173 m .2096 .72895 L .18557 .73554 L p .707 .577 .707 r
F P
0 g
s
.32684 .68652 m .32921 .72375 L .30182 .72139 L p .707 .577 .707 r
F P
0 g
s
.30182 .72139 m .29944 .68416 L .32684 .68652 L p .707 .577 .707 r
F P
0 g
s
.39186 .25462 m .38361 .75555 L .3605 .76584 L p .707 .577 .707 r
F P
0 g
s
.38361 .75555 m .39186 .25462 L .42581 .24698 L p .707 .577 .707 r
F P
0 g
s
.35107 .78241 m .34303 .7981 L .32481 .7796 L p .707 .577 .707 r
F P
0 g
s
.32481 .7796 m .33284 .76392 L .35107 .78241 L p .707 .577 .707 r
F P
0 g
s
.22733 .65798 m .22668 .60233 L .25851 .60122 L p .707 .577 .707 r
F P
0 g
s
.22668 .60233 m .22733 .65798 L .19795 .66163 L p .707 .577 .707 r
F P
0 g
s
.25851 .60122 m .25916 .65687 L .22733 .65798 L p .707 .577 .707 r
F P
0 g
s
.72583 .65694 m .72517 .60129 L .694 .59976 L p .707 .577 .707 r
F P
0 g
s
.72517 .60129 m .72583 .65694 L .75766 .65583 L p .707 .577 .707 r
F P
0 g
s
.75766 .65583 m .75701 .60018 L .72517 .60129 L p .707 .577 .707 r
F P
0 g
s
.2163 .72916 m .22434 .71348 L .25148 .71966 L p .707 .577 .707 r
F P
0 g
s
.75701 .60018 m .75766 .65583 L .78704 .65219 L p .707 .577 .707 r
F P
0 g
s
.78704 .65219 m .78639 .59654 L .75701 .60018 L p .707 .577 .707 r
F P
0 g
s
.2096 .72895 m .20722 .69173 L .23656 .6869 L p .707 .577 .707 r
F P
0 g
s
.69465 .65541 m .694 .59976 L .66655 .59574 L p .707 .577 .707 r
F P
0 g
s
.694 .59976 m .69465 .65541 L .72583 .65694 L p .707 .577 .707 r
F P
0 g
s
.25148 .71966 m .24344 .73534 L .2163 .72916 L p .707 .577 .707 r
F P
0 g
s
.29944 .68416 m .30182 .72139 L .27071 .72152 L p .707 .577 .707 r
F P
0 g
s
.27071 .72152 m .26834 .68429 L .29944 .68416 L p .707 .577 .707 r
F P
0 g
s
.23656 .6869 m .23893 .72412 L .2096 .72895 L p .707 .577 .707 r
F P
0 g
s
.59499 .25265 m .58674 .75358 L .54798 .74665 L p .707 .577 .707 r
F P
0 g
s
.54798 .74665 m .55623 .24571 L .59499 .25265 L p .707 .577 .707 r
F P
0 g
s
.33284 .76392 m .32481 .7796 L .30048 .76186 L p .707 .577 .707 r
F P
0 g
s
.30048 .76186 m .30852 .74618 L .33284 .76392 L p .707 .577 .707 r
F P
0 g
s
.23893 .72412 m .23656 .6869 L .26834 .68429 L p .707 .577 .707 r
F P
0 g
s
.78639 .59654 m .78704 .65219 L .81109 .64637 L p .707 .577 .707 r
F P
0 g
s
.81109 .64637 m .81044 .59072 L .78639 .59654 L p .707 .577 .707 r
F P
0 g
s
.24344 .73534 m .25148 .71966 L .28048 .73092 L p .707 .577 .707 r
F P
0 g
s
.26834 .68429 m .27071 .72152 L .23893 .72412 L p .707 .577 .707 r
F P
0 g
s
.73725 .71541 m .73487 .67818 L .70376 .67831 L p .707 .577 .707 r
F P
0 g
s
.73487 .67818 m .73725 .71541 L .76902 .7128 L p .707 .577 .707 r
F P
0 g
s
.76902 .7128 m .76665 .67557 L .73487 .67818 L p .707 .577 .707 r
F P
0 g
s
.76665 .67557 m .76902 .7128 L .79836 .70797 L p .707 .577 .707 r
F P
0 g
s
.79836 .70797 m .79598 .67074 L .76665 .67557 L p .707 .577 .707 r
F P
0 g
s
.66655 .59574 m .6672 .65139 L .69465 .65541 L p .707 .577 .707 r
F P
0 g
s
.41756 .74791 m .42581 .24698 L .46729 .24274 L p .707 .577 .707 r
F P
0 g
s
.42581 .24698 m .41756 .74791 L .38361 .75555 L p .707 .577 .707 r
F P
0 g
s
.6672 .65139 m .66655 .59574 L .64549 .58962 L p .707 .577 .707 r
F P
0 g
s
.30852 .74618 m .30048 .76186 L .27245 .74661 L p .707 .577 .707 r
F P
0 g
s
.27245 .74661 m .28048 .73092 L .30852 .74618 L p .707 .577 .707 r
F P
0 g
s
.70614 .71554 m .70376 .67831 L .67637 .67594 L p .707 .577 .707 r
F P
0 g
s
.70376 .67831 m .70614 .71554 L .73725 .71541 L p .707 .577 .707 r
F P
0 g
s
.28048 .73092 m .27245 .74661 L .24344 .73534 L p .707 .577 .707 r
F P
0 g
s
.79598 .67074 m .79836 .70797 L .82238 .70139 L p .707 .577 .707 r
F P
0 g
s
.82238 .70139 m .82001 .66416 L .79598 .67074 L p .707 .577 .707 r
F P
0 g
s
.67637 .67594 m .67874 .71317 L .70614 .71554 L p .707 .577 .707 r
F P
0 g
s
.55623 .24571 m .54798 .74665 L .50398 .74323 L p .707 .577 .707 r
F P
0 g
s
.50398 .74323 m .51223 .2423 L .55623 .24571 L p .707 .577 .707 r
F P
0 g
s
.81044 .59072 m .81109 .64637 L .82746 .63894 L p .707 .577 .707 r
F P
0 g
s
.82746 .63894 m .82681 .58329 L .81044 .59072 L p .707 .577 .707 r
F P
0 g
s
.73284 .7718 m .74088 .75612 L .71284 .74087 L p .707 .577 .707 r
F P
0 g
s
.74088 .75612 m .73284 .7718 L .76185 .78307 L p .707 .577 .707 r
F P
0 g
s
.76185 .78307 m .76988 .76738 L .74088 .75612 L p .707 .577 .707 r
F P
0 g
s
.64549 .58962 m .64615 .64527 L .6672 .65139 L p .707 .577 .707 r
F P
0 g
s
.7048 .75655 m .71284 .74087 L .68852 .72312 L p .707 .577 .707 r
F P
0 g
s
.71284 .74087 m .7048 .75655 L .73284 .7718 L p .707 .577 .707 r
F P
0 g
s
.45904 .74367 m .46729 .24274 L .51223 .2423 L p .707 .577 .707 r
F P
0 g
s
.46729 .24274 m .45904 .74367 L .41756 .74791 L p .707 .577 .707 r
F P
0 g
s
.67874 .71317 m .67637 .67594 L .65537 .67132 L p .707 .577 .707 r
F P
0 g
s
.76988 .76738 m .76185 .78307 L .78898 .78924 L p .707 .577 .707 r
F P
0 g
s
.78898 .78924 m .79702 .77356 L .76988 .76738 L p .707 .577 .707 r
F P
0 g
s
.51223 .2423 m .50398 .74323 L .45904 .74367 L p .707 .577 .707 r
F P
0 g
s
.64615 .64527 m .64549 .58962 L .6329 .582 L p .707 .577 .707 r
F P
0 g
s
.68852 .72312 m .68048 .73881 L .7048 .75655 L p .707 .577 .707 r
F P
0 g
s
.65537 .67132 m .65775 .70855 L .67874 .71317 L p .707 .577 .707 r
F P
0 g
s
.68048 .73881 m .68852 .72312 L .67029 .70463 L p .707 .577 .707 r
F P
0 g
s
.82001 .66416 m .82238 .70139 L .83874 .6937 L p .707 .577 .707 r
F P
0 g
s
.83874 .6937 m .83637 .65647 L .82001 .66416 L p .707 .577 .707 r
F P
0 g
s
.67029 .70463 m .66225 .72031 L .68048 .73881 L p .707 .577 .707 r
F P
0 g
s
.79702 .77356 m .78898 .78924 L .8116 .78973 L p .707 .577 .707 r
F P
0 g
s
.8116 .78973 m .81963 .77405 L .79702 .77356 L p .707 .577 .707 r
F P
0 g
s
.6329 .582 m .63355 .63765 L .64615 .64527 L p .707 .577 .707 r
F P
0 g
s
.82681 .58329 m .82746 .63894 L .83454 .63063 L p .707 .577 .707 r
F P
0 g
s
.83454 .63063 m .83389 .57499 L .82681 .58329 L p .707 .577 .707 r
F P
0 g
s
.65775 .70855 m .65537 .67132 L .64283 .66489 L p .707 .577 .707 r
F P
0 g
s
.66225 .72031 m .67029 .70463 L .65994 .68718 L p .707 .577 .707 r
F P
0 g
s
.64283 .66489 m .6452 .70212 L .65775 .70855 L p .707 .577 .707 r
F P
0 g
s
.63355 .63765 m .6329 .582 L .63001 .57363 L p .707 .577 .707 r
F P
0 g
s
.65994 .68718 m .65191 .70287 L .66225 .72031 L p .707 .577 .707 r
F P
0 g
s
.83637 .65647 m .83874 .6937 L .84583 .68566 L p .707 .577 .707 r
F P
0 g
s
.84583 .68566 m .84346 .64843 L .83637 .65647 L p .707 .577 .707 r
F P
0 g
s
.81963 .77405 m .8116 .78973 L .82747 .78448 L p .707 .577 .707 r
F P
0 g
s
.82747 .78448 m .8355 .7688 L .81963 .77405 L p .707 .577 .707 r
F P
0 g
s
.63001 .57363 m .63066 .62928 L .63355 .63765 L p .707 .577 .707 r
F P
0 g
s
.83389 .57499 m .83454 .63063 L .83165 .62226 L p .707 .577 .707 r
F P
0 g
s
.83165 .62226 m .831 .56661 L .83389 .57499 L p .707 .577 .707 r
F P
0 g
s
.65191 .70287 m .65994 .68718 L .65849 .67251 L p .707 .577 .707 r
F P
0 g
s
.6452 .70212 m .64283 .66489 L .63996 .65728 L p .707 .577 .707 r
F P
0 g
s
.65849 .67251 m .65045 .68819 L .65191 .70287 L p .707 .577 .707 r
F P
0 g
s
.63996 .65728 m .64233 .69451 L .6452 .70212 L p .707 .577 .707 r
F P
0 g
s
.63066 .62928 m .63001 .57363 L .63709 .56533 L p .707 .577 .707 r
F P
0 g
s
.84346 .64843 m .84583 .68566 L .84297 .67805 L p .707 .577 .707 r
F P
0 g
s
.84297 .67805 m .84059 .64082 L .84346 .64843 L p .707 .577 .707 r
F P
0 g
s
.8355 .7688 m .82747 .78448 L .83505 .774 L p .707 .577 .707 r
F P
0 g
s
.83505 .774 m .84308 .75832 L .8355 .7688 L p .707 .577 .707 r
F P
0 g
s
.63709 .56533 m .63774 .62097 L .63066 .62928 L p .707 .577 .707 r
F P
0 g
s
.65045 .68819 m .65849 .67251 L .66607 .66203 L p .707 .577 .707 r
F P
0 g
s
.831 .56661 m .83165 .62226 L .81906 .61464 L p .707 .577 .707 r
F P
0 g
s
.81906 .61464 m .8184 .55899 L .831 .56661 L p .707 .577 .707 r
F P
0 g
s
.64233 .69451 m .63996 .65728 L .64705 .64924 L p .707 .577 .707 r
F P
0 g
s
.66607 .66203 m .65803 .67771 L .65045 .68819 L p .707 .577 .707 r
F P
0 g
s
.38282 .6188 m .38216 .56315 L .35099 .56162 L p .707 .577 .707 r
F P
0 g
s
.38216 .56315 m .38282 .6188 L .41465 .61769 L p .707 .577 .707 r
F P
0 g
s
.41465 .61769 m .414 .56204 L .38216 .56315 L p .707 .577 .707 r
F P
0 g
s
.64705 .64924 m .64943 .68646 L .64233 .69451 L p .707 .577 .707 r
F P
0 g
s
.414 .56204 m .41465 .61769 L .44403 .61404 L p .707 .577 .707 r
F P
0 g
s
.44403 .61404 m .44338 .5584 L .414 .56204 L p .707 .577 .707 r
F P
0 g
s
.63774 .62097 m .63709 .56533 L .65346 .5579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84308 .75832 m .83505 .774 L .83359 .75932 L p .707 .577 .707 r
F P
0 g
s
.83359 .75932 m .84163 .74364 L .84308 .75832 L p .707 .577 .707 r
F P
0 g
s
.35164 .61727 m .35099 .56162 L .32354 .5576 L p .707 .577 .707 r
F P
0 g
s
.35099 .56162 m .35164 .61727 L .38282 .6188 L p .707 .577 .707 r
F P
0 g
s
.84059 .64082 m .84297 .67805 L .83042 .67161 L p .707 .577 .707 r
F P
0 g
s
.83042 .67161 m .82805 .63439 L .84059 .64082 L p .707 .577 .707 r
F P
0 g
s
.44338 .5584 m .44403 .61404 L .46808 .60822 L p .707 .577 .707 r
F P
0 g
s
.46808 .60822 m .46743 .55258 L .44338 .5584 L p .707 .577 .707 r
F P
0 g
s
.39424 .68013 m .39186 .6429 L .36075 .64303 L p .707 .577 .707 r
F P
0 g
s
.39186 .6429 m .39424 .68013 L .42601 .67752 L p .707 .577 .707 r
F P
0 g
s
.42601 .67752 m .42364 .6403 L .39186 .6429 L p .707 .577 .707 r
F P
0 g
s
.65803 .67771 m .66607 .66203 L .68194 .65677 L p .707 .577 .707 r
F P
0 g
s
.65346 .5579 m .65411 .61355 L .63774 .62097 L p .707 .577 .707 r
F P
0 g
s
.8184 .55899 m .81906 .61464 L .798 .60852 L p .707 .577 .707 r
F P
0 g
s
.798 .60852 m .79735 .55288 L .8184 .55899 L p .707 .577 .707 r
F P
0 g
s
.42364 .6403 m .42601 .67752 L .45535 .67269 L p .707 .577 .707 r
F P
0 g
s
.45535 .67269 m .45297 .63547 L .42364 .6403 L p .707 .577 .707 r
F P
0 g
s
.32354 .5576 m .32419 .61325 L .35164 .61727 L p .707 .577 .707 r
F P
0 g
s
.64943 .68646 m .64705 .64924 L .66341 .64155 L p .707 .577 .707 r
F P
0 g
s
.32419 .61325 m .32354 .5576 L .30248 .55148 L p .707 .577 .707 r
F P
0 g
s
.36313 .68026 m .36075 .64303 L .33336 .64067 L p .707 .577 .707 r
F P
0 g
s
.36075 .64303 m .36313 .68026 L .39424 .68013 L p .707 .577 .707 r
F P
0 g
s
.68194 .65677 m .6739 .67246 L .65803 .67771 L p .707 .577 .707 r
F P
0 g
s
.65411 .61355 m .65346 .5579 L .67751 .55208 L p .707 .577 .707 r
F P
0 g
s
.66341 .64155 m .66579 .67877 L .64943 .68646 L p .707 .577 .707 r
F P
0 g
s
.45297 .63547 m .45535 .67269 L .47937 .66611 L p .707 .577 .707 r
F P
0 g
s
.47937 .66611 m .477 .62888 L .45297 .63547 L p .707 .577 .707 r
F P
0 g
s
.33336 .64067 m .33573 .6779 L .36313 .68026 L p .707 .577 .707 r
F P
0 g
s
.46743 .55258 m .46808 .60822 L .48445 .6008 L p .707 .577 .707 r
F P
0 g
s
.48445 .6008 m .4838 .54515 L .46743 .55258 L p .707 .577 .707 r
F P
0 g
s
.84163 .74364 m .83359 .75932 L .82325 .74188 L p .707 .577 .707 r
F P
0 g
s
.82325 .74188 m .83128 .7262 L .84163 .74364 L p .707 .577 .707 r
F P
0 g
s
.82805 .63439 m .83042 .67161 L .80942 .66699 L p .707 .577 .707 r
F P
0 g
s
.80942 .66699 m .80705 .62976 L .82805 .63439 L p .707 .577 .707 r
F P
0 g
s
.38983 .73598 m .39787 .7203 L .36983 .70505 L p .707 .577 .707 r
F P
0 g
s
.39787 .7203 m .38983 .73598 L .41884 .74725 L p .707 .577 .707 r
F P
0 g
s
.41884 .74725 m .42687 .73156 L .39787 .7203 L p .707 .577 .707 r
F P
0 g
s
.30248 .55148 m .30314 .60713 L .32419 .61325 L p .707 .577 .707 r
F P
0 g
s
.36179 .72073 m .36983 .70505 L .34551 .6873 L p .707 .577 .707 r
F P
0 g
s
.36983 .70505 m .36179 .72073 L .38983 .73598 L p .707 .577 .707 r
F P
0 g
s
.33573 .6779 m .33336 .64067 L .31236 .63604 L p .707 .577 .707 r
F P
0 g
s
.79735 .55288 m .798 .60852 L .77055 .6045 L p .707 .577 .707 r
F P
0 g
s
.77055 .6045 m .7699 .54885 L .79735 .55288 L p .707 .577 .707 r
F P
0 g
s
.42687 .73156 m .41884 .74725 L .44597 .75343 L p .707 .577 .707 r
F P
0 g
s
.44597 .75343 m .45401 .73774 L .42687 .73156 L p .707 .577 .707 r
F P
0 g
s
.67751 .55208 m .67816 .60773 L .65411 .61355 L p .707 .577 .707 r
F P
0 g
s
.6739 .67246 m .68194 .65677 L .70455 .65726 L p .707 .577 .707 r
F P
0 g
s
.30314 .60713 m .30248 .55148 L .28989 .54386 L p .707 .577 .707 r
F P
0 g
s
.34551 .6873 m .33747 .70299 L .36179 .72073 L p .707 .577 .707 r
F P
0 g
s
.66579 .67877 m .66341 .64155 L .68744 .63496 L p .707 .577 .707 r
F P
0 g
s
.31236 .63604 m .31474 .67327 L .33573 .6779 L p .707 .577 .707 r
F P
0 g
s
.33747 .70299 m .34551 .6873 L .32728 .66881 L p .707 .577 .707 r
F P
0 g
s
.67816 .60773 m .67751 .55208 L .70689 .54844 L p .707 .577 .707 r
F P
0 g
s
.477 .62888 m .47937 .66611 L .49573 .65842 L p .707 .577 .707 r
F P
0 g
s
.49573 .65842 m .49336 .62119 L .477 .62888 L p .707 .577 .707 r
F P
0 g
s
.70455 .65726 m .69652 .67294 L .6739 .67246 L p .707 .577 .707 r
F P
0 g
s
.32728 .66881 m .31924 .68449 L .33747 .70299 L p .707 .577 .707 r
F P
0 g
s
.7699 .54885 m .77055 .6045 L .73938 .60297 L p .707 .577 .707 r
F P
0 g
s
.73938 .60297 m .73873 .54732 L .7699 .54885 L p .707 .577 .707 r
F P
0 g
s
.68744 .63496 m .68981 .67219 L .66579 .67877 L p .707 .577 .707 r
F P
0 g
s
.80705 .62976 m .80942 .66699 L .78203 .66463 L p .707 .577 .707 r
F P
0 g
s
.78203 .66463 m .77966 .6274 L .80705 .62976 L p .707 .577 .707 r
F P
0 g
s
.83128 .7262 m .82325 .74188 L .80502 .72338 L p .707 .577 .707 r
F P
0 g
s
.80502 .72338 m .81306 .7077 L .83128 .7262 L p .707 .577 .707 r
F P
0 g
s
.45401 .73774 m .44597 .75343 L .46859 .75391 L p .707 .577 .707 r
F P
0 g
s
.46859 .75391 m .47662 .73823 L .45401 .73774 L p .707 .577 .707 r
F P
0 g
s
.28989 .54386 m .29054 .59951 L .30314 .60713 L p .707 .577 .707 r
F P
0 g
s
.4838 .54515 m .48445 .6008 L .49153 .59249 L p .707 .577 .707 r
F P
0 g
s
.49153 .59249 m .49088 .53684 L .4838 .54515 L p .707 .577 .707 r
F P
0 g
s
.70754 .60408 m .70689 .54844 L .73873 .54732 L p .707 .577 .707 r
F P
0 g
s
.70689 .54844 m .70754 .60408 L .67816 .60773 L p .707 .577 .707 r
F P
0 g
s
.73873 .54732 m .73938 .60297 L .70754 .60408 L p .707 .577 .707 r
F P
0 g
s
.31474 .67327 m .31236 .63604 L .29982 .62961 L p .707 .577 .707 r
F P
0 g
s
.69652 .67294 m .70455 .65726 L .73169 .66344 L p .707 .577 .707 r
F P
0 g
s
.31924 .68449 m .32728 .66881 L .31693 .65136 L p .707 .577 .707 r
F P
0 g
s
.68981 .67219 m .68744 .63496 L .71677 .63013 L p .707 .577 .707 r
F P
0 g
s
.29054 .59951 m .28989 .54386 L .287 .53549 L p .707 .577 .707 r
F P
0 g
s
.29982 .62961 m .30219 .66684 L .31474 .67327 L p .707 .577 .707 r
F P
0 g
s
.77966 .6274 m .78203 .66463 L .75092 .66475 L p .707 .577 .707 r
F P
0 g
s
.75092 .66475 m .74855 .62753 L .77966 .6274 L p .707 .577 .707 r
F P
0 g
s
.73169 .66344 m .72365 .67912 L .69652 .67294 L p .707 .577 .707 r
F P
0 g
s
.31693 .65136 m .3089 .66705 L .31924 .68449 L p .707 .577 .707 r
F P
0 g
s
.71677 .63013 m .71915 .66736 L .68981 .67219 L p .707 .577 .707 r
F P
0 g
s
.81306 .7077 m .80502 .72338 L .7807 .70564 L p .707 .577 .707 r
F P
0 g
s
.7807 .70564 m .78873 .68996 L .81306 .7077 L p .707 .577 .707 r
F P
0 g
s
.49336 .62119 m .49573 .65842 L .50282 .65038 L p .707 .577 .707 r
F P
0 g
s
.50282 .65038 m .50045 .61315 L .49336 .62119 L p .707 .577 .707 r
F P
0 g
s
.71915 .66736 m .71677 .63013 L .74855 .62753 L p .707 .577 .707 r
F P
0 g
s
.47662 .73823 m .46859 .75391 L .48446 .74866 L p .707 .577 .707 r
F P
0 g
s
.48446 .74866 m .49249 .73298 L .47662 .73823 L p .707 .577 .707 r
F P
0 g
s
.72365 .67912 m .73169 .66344 L .7607 .67471 L p .707 .577 .707 r
F P
0 g
s
.74855 .62753 m .75092 .66475 L .71915 .66736 L p .707 .577 .707 r
F P
0 g
s
.78873 .68996 m .7807 .70564 L .75266 .69039 L p .707 .577 .707 r
F P
0 g
s
.75266 .69039 m .7607 .67471 L .78873 .68996 L p .707 .577 .707 r
F P
0 g
s
.287 .53549 m .28765 .59114 L .29054 .59951 L p .707 .577 .707 r
F P
0 g
s
.7607 .67471 m .75266 .69039 L .72365 .67912 L p .707 .577 .707 r
F P
0 g
s
.49088 .53684 m .49153 .59249 L .48864 .58412 L p .707 .577 .707 r
F P
0 g
s
.48864 .58412 m .48799 .52847 L .49088 .53684 L p .707 .577 .707 r
F P
0 g
s
.3089 .66705 m .31693 .65136 L .31548 .63669 L p .707 .577 .707 r
F P
0 g
s
.30219 .66684 m .29982 .62961 L .29695 .622 L p .707 .577 .707 r
F P
0 g
s
.31548 .63669 m .30744 .65237 L .3089 .66705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29695 .622 m .29932 .65923 L .30219 .66684 L p .707 .577 .707 r
F P
0 g
s
.28765 .59114 m .287 .53549 L .29408 .52719 L p .707 .577 .707 r
F P
0 g
s
.50045 .61315 m .50282 .65038 L .49996 .64277 L p .707 .577 .707 r
F P
0 g
s
.49996 .64277 m .49758 .60554 L .50045 .61315 L p .707 .577 .707 r
F P
0 g
s
.49249 .73298 m .48446 .74866 L .49204 .73818 L p .707 .577 .707 r
F P
0 g
s
.49204 .73818 m .50007 .7225 L .49249 .73298 L p .707 .577 .707 r
F P
0 g
s
.29408 .52719 m .29473 .58283 L .28765 .59114 L p .707 .577 .707 r
F P
0 g
s
.30744 .65237 m .31548 .63669 L .32306 .62621 L p .707 .577 .707 r
F P
0 g
s
.48799 .52847 m .48864 .58412 L .47605 .5765 L p .707 .577 .707 r
F P
0 g
s
.47605 .5765 m .47539 .52085 L .48799 .52847 L p .707 .577 .707 r
F P
0 g
s
.29932 .65923 m .29695 .622 L .30404 .61396 L p .707 .577 .707 r
F P
0 g
s
.32306 .62621 m .31502 .64189 L .30744 .65237 L p .707 .577 .707 r
F P
0 g
s
.30404 .61396 m .30642 .65119 L .29932 .65923 L p .707 .577 .707 r
F P
0 g
s
.29473 .58283 m .29408 .52719 L .31045 .51976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50007 .7225 m .49204 .73818 L .49058 .7235 L p .707 .577 .707 r
F P
0 g
s
.49058 .7235 m .49862 .70782 L .50007 .7225 L p .707 .577 .707 r
F P
0 g
s
.49758 .60554 m .49996 .64277 L .48741 .63634 L p .707 .577 .707 r
F P
0 g
s
.48741 .63634 m .48504 .59911 L .49758 .60554 L p .707 .577 .707 r
F P
0 g
s
.31045 .51976 m .3111 .57541 L .29473 .58283 L p .707 .577 .707 r
F P
0 g
s
.47539 .52085 m .47605 .5765 L .45499 .57038 L p .707 .577 .707 r
F P
0 g
s
.45499 .57038 m .45434 .51473 L .47539 .52085 L p .707 .577 .707 r
F P
0 g
s
.31502 .64189 m .32306 .62621 L .33893 .62095 L p .707 .577 .707 r
F P
0 g
s
.30642 .65119 m .30404 .61396 L .3204 .60627 L p .707 .577 .707 r
F P
0 g
s
.33893 .62095 m .33089 .63664 L .31502 .64189 L p .707 .577 .707 r
F P
0 g
s
.3111 .57541 m .31045 .51976 L .3345 .51394 L p .707 .577 .707 r
F P
0 g
s
.3204 .60627 m .32278 .6435 L .30642 .65119 L p .707 .577 .707 r
F P
0 g
s
.49862 .70782 m .49058 .7235 L .48024 .70606 L p .707 .577 .707 r
F P
0 g
s
.48024 .70606 m .48827 .69038 L .49862 .70782 L p .707 .577 .707 r
F P
0 g
s
.48504 .59911 m .48741 .63634 L .46641 .63171 L p .707 .577 .707 r
F P
0 g
s
.46641 .63171 m .46404 .59448 L .48504 .59911 L p .707 .577 .707 r
F P
0 g
s
.45434 .51473 m .45499 .57038 L .42754 .56636 L p .707 .577 .707 r
F P
0 g
s
.42754 .56636 m .42688 .51071 L .45434 .51473 L p .707 .577 .707 r
F P
0 g
s
.3345 .51394 m .33515 .56959 L .3111 .57541 L p .707 .577 .707 r
F P
0 g
s
.33089 .63664 m .33893 .62095 L .36154 .62144 L p .707 .577 .707 r
F P
0 g
s
.32278 .6435 m .3204 .60627 L .34443 .59969 L p .707 .577 .707 r
F P
0 g
s
.33515 .56959 m .3345 .51394 L .36388 .51029 L p .707 .577 .707 r
F P
0 g
s
.36154 .62144 m .35351 .63712 L .33089 .63664 L p .707 .577 .707 r
F P
0 g
s
.42688 .51071 m .42754 .56636 L .39637 .56483 L p .707 .577 .707 r
F P
0 g
s
.39637 .56483 m .39571 .50918 L .42688 .51071 L p .707 .577 .707 r
F P
0 g
s
.34443 .59969 m .3468 .63692 L .32278 .6435 L p .707 .577 .707 r
F P
0 g
s
.46404 .59448 m .46641 .63171 L .43902 .62935 L p .707 .577 .707 r
F P
0 g
s
.43902 .62935 m .43665 .59212 L .46404 .59448 L p .707 .577 .707 r
F P
0 g
s
.48827 .69038 m .48024 .70606 L .46201 .68756 L p .707 .577 .707 r
F P
0 g
s
.46201 .68756 m .47004 .67188 L .48827 .69038 L p .707 .577 .707 r
F P
0 g
s
.36453 .56594 m .36388 .51029 L .39571 .50918 L p .707 .577 .707 r
F P
0 g
s
.36388 .51029 m .36453 .56594 L .33515 .56959 L p .707 .577 .707 r
F P
0 g
s
.39571 .50918 m .39637 .56483 L .36453 .56594 L p .707 .577 .707 r
F P
0 g
s
.35351 .63712 m .36154 .62144 L .38868 .62762 L p .707 .577 .707 r
F P
0 g
s
.3468 .63692 m .34443 .59969 L .37376 .59486 L p .707 .577 .707 r
F P
0 g
s
.38868 .62762 m .38064 .6433 L .35351 .63712 L p .707 .577 .707 r
F P
0 g
s
.43665 .59212 m .43902 .62935 L .40791 .62948 L p .707 .577 .707 r
F P
0 g
s
.40791 .62948 m .40554 .59225 L .43665 .59212 L p .707 .577 .707 r
F P
0 g
s
.37376 .59486 m .37614 .63208 L .3468 .63692 L p .707 .577 .707 r
F P
0 g
s
.47004 .67188 m .46201 .68756 L .43769 .66982 L p .707 .577 .707 r
F P
0 g
s
.43769 .66982 m .44572 .65414 L .47004 .67188 L p .707 .577 .707 r
F P
0 g
s
.37614 .63208 m .37376 .59486 L .40554 .59225 L p .707 .577 .707 r
F P
0 g
s
.38064 .6433 m .38868 .62762 L .41769 .63889 L p .707 .577 .707 r
F P
0 g
s
.40554 .59225 m .40791 .62948 L .37614 .63208 L p .707 .577 .707 r
F P
0 g
s
.44572 .65414 m .43769 .66982 L .40965 .65457 L p .707 .577 .707 r
F P
0 g
s
.40965 .65457 m .41769 .63889 L .44572 .65414 L p .707 .577 .707 r
F P
0 g
s
.41769 .63889 m .40965 .65457 L .38064 .6433 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo`d008Eo
o`00Ogoo30001UYF00<005YFFUH015YF2@00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001fOol0079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00IJEP@0079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eo
o`00JWoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001ZOol0
06Moo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001WOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0004FUH9
0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`P000AJEP03001JEUYF009JEPP000IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
G7oo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000aJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0055oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0047oo3`00Agoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool400000eYF001J
EP07FUH00`00FUIJEP02FUH8000oOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000hOol0055oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003Aoo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF1@001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
<Goo001AOol00`00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUH000040002FUH80004FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo00<005YF0000
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF1`00
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP@0009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00DGoo00@005YF001JEP8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001J
EUYFFUH005YF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol01P00FUH00000FUH000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000EJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP090004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;goo0015Ool90004Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00
?Goo200015YF00<005YFFUH00UYF1`0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000eOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEPL000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000_Ool0035oo`@0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000_Ool002moo`<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH2000_Ool002eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00800003FUH0000002moo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000_Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000_Ool0
02Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF000040001EYF00<005YFFUH00UYF00<005YF0000;goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH015YF3`0025YF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00P000AJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUH0000_Ool002Yoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP05FUH30005FUH40003FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH00UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01@00<7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001EYF1`00
15YF00<005YFFUH01UYF0`000eYF100000=JEP00FUH01EYF00@005YFFUIJEP800003FUH0000000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH500000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YF00003`002EYF1@001EYF00<005YFFUH015YF00<0
05YFFUH00UYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH200000eYF001JEP06FUH00`00FUIJ
EP04FUH20006FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF0000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEPH00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
0P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00H005YFFUIJEP00FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP0200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01P00FUH00000FUH000MJEP80009JEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP03000015YF001JEP000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002eoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@00
00=JEP0000000`000UYF200000=JEP0000000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000IJEP03001JEP00008000IJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH00000;Goo000ZOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YF000010000UYF
00<005YFFUH015YF00@005YF000000=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01@00FUIJEUYF00001UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000]Ool002Yoo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP04FUHN0003
FUH01000FUIJEP00;Goo000ZOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YF00001eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000IJEP@000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000=JEP03
001JEUYF00=JEP<000Uoo`@000EJEP@0009JEP8002aoo`00:Woo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUH00000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF009J
EP03001JEUYF00=JEP@000MJEP03001JEUYF00IJEP8000=oo`@0009JEP03001JEUYF00AJEP04001J
EUYFFUH4000/Ool002Yoo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUH0000;0002FUH00`00FUIJ
EP07FUH00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002Yoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUH0000B00000eYF001JEP08FUH01@00FUIJEUYF00000UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00FUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0100025YF00D005YFFUIJEP0000IJEP03
001JEUYF00AJEP03001JEUYF009JEP<002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH04@0000=JEP00FUH01EYF0`000UYF00<005YFFUH015YF1P00
0eYF00<005YFFUH025YF0`0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP090004FUH00`00FUIJ
EP06FUH01000FUIJEUYF0`001UYF0P000UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF0P00
1EYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000EJEP00001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00EJEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00:goo00D005YFFUIJEP0000EJ
EP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01P00FUH00000FUH000IJEPH000=JEP03001JEUYF00UJEP03001JEP0000EJEP03001JEUYF
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH0
05YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0P002UYF00<005YF00001UYF
00<005YFFUH00UYF0P00;Goo000/Ool200000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH20006FUH00`00FUH0
00020004FUH00`00FUIJEP09FUH01000FUIJEP000eYF00<005YF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@0000AJEP00FUH000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000MJEP04001JEP000006FUH01000FUIJEUYF0P00;Woo
000^Ool30002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00D0
05YFFUIJEP00009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP@00003FUH005YF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000<7oo000aOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001eYF0P0015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@0
05YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF0003
FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@0
05YFFUIJEP<0039oo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP05001JEUYFFUH00008FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`000eYF00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YF000000MJEP<003Eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEP00009J
EP04001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00<007oo
Ool0<goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF0P0025YF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0002FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000goo001JEP04FUH00`00FUH0000dOol002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00EJEP8000IJEP03001JEUYF00UJEP03001JEUYF00EJEP06001JEP00001J
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00P00
15YF00<005YFFUH04P002goo00D005YFFUIJEP0000=JEP03001oogoo035oo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH000UJEP8000AJEP03001JEUYF00UJEP03001JEUYF00EJEP80
009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP03001JEUYF
00=JEP03001JEP00008000Uoo`D000eoo`800003FUH005YF00=JEP03001oogoo031oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF7@0015YF00<005YFFUH00`001eYF00@005YF
0000009JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000=JEP@000EJEP800003FUH007oo00Qoo`D000moo`03001J
EUYF00AJEP03001oogoo02moo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@0
00AJEP03001JEUYF009JEP<000Yoo`D0009JEP<00005FUH005YFFUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`002eYF00<005YFFUH01UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP<000Yoo`D0011oo`03001JEUYF00AJ
EP03001oogoo02ioo`00;Goo00@005YFFUH000=JEP03001JEUYF00=JEPD000MJEP03001JEUYF00EJ
EP8000Aoo`@00003FUH005YF00EJEP04001JEP000002FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF0P002UYF00<005YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001eYF00D005YFFUIJEP0000=JEP03001oogoo00Qoo`<0019oo`03001J
EUYF009JEP03001JEP0002moo`00;Goo00@005YFFUH000=JEP03001JEP0000@000Aoo`@0009JEP03
001JEUYF00MJEPD000EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH200000eYF
001JEP07FUH50005FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0MOol01000
FUIJEP000UYF00<007ooOol0;Goo000^Ool00`00FUH00003FUH200000eYF001JEP02FUH<0007FUH0
1@00FUIJEUYF00001UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP<000QJEP03
001JEUYF009JEPl000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000MJEP04001JEP000006FUH2000NOol00`00FUH00003FUH00`00Oomoo`0/Ool002ioo`04
001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00`001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP04001JEUYF0008FUH00`00Oomoo`0LOol0
0`00FUIJEP02FUH00`00Oomoo`0/Ool002ioo`06001JEP00001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF100000=JEP00FUH01UYF0P000UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YFFUH030001UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH0
0P001UYF0`007Goo00<005YFFUH00UYF00<007ooOol0:goo000^Ool3000015YF001JEP000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH01000FUIJEP002eYF2@00
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF
FUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2000]Ool002ioo`04001JEP000002FUH01000
FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00<005YF00000P001UYF00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH010001EYF10000UYF00<005YFFUH00eYF00<005YF0000
0P0035YF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP8001]oo`05001JEP00FUH0000]Ool002ioo`04
001JEP000003FUH01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00D005YF
FUIJEP0000IJEP03001JEP00009JEP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEPX0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000MJEP03001JEUYF009JEP800003FUH005YF
00IJEP03001JEUYF00=JEP@000MJEP8001Uoo`05001JEP00FUH0000]Ool002ioo`03001JEP0000AJ
EP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJ
EP02FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF3@0015YF00@005YFFUH0
00UJEP8001Qoo`04001JEUYF000]Ool002moo`<000AJEP03001JEP0000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH40003Ool01@00FUIJEP00FUH00P0025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0P000goo1P000UYF0`0000AJEP00FUIJEP<000IJEP03001JEUYF008001Ioo`04001JEUYF000]
Ool0035oo`06001JEUYFFUH005YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000IJEP03001oogoo009oo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000004FUH50002
FUH00`00FUIJEP04FUH00`00FUH00002000015YF000007oo0P0015YF00<005YFFUH00UYF0`004goo
00<005YF0000;Woo000bOol00`00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
00000goo001JEP03FUH00`00FUH00003Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF0P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`000goo0P0000=JEP00FUH01eYF1@00
3Woo0`00;Woo000bOol00`00FUH00004FUH00`00Oomoo`0B000;Ool01@00FUIJEUYF00000UYF00<0
07ooOol00P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001EYF00<005YFFUH015YF00<005YF
FUH00UYF0`001Goo0`001eYF00<005YFFUH00UYF1`001Goo0P0000=JEP00Ool0;Woo000cOol00`00
FUIJEP04FUH00`00Oomoo`0:Ool5000>Ool30004FUH01000Ool0000015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000Qoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00D0009JEP8002moo`00=7oo00<005YFFUH015YF00<007oo
Ool02Goo1@0047oo00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000`000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002Woo0`0000=JEP00FUH01eYF
00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Woo000eOol00`00FUIJEP02FUH01000FUH0
00002Goo1@004Goo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH0009JEP800003FUH005YF00EJEP03001JEUYF009JEP8000ioo`<000MJEP03001JEUYF
00=JEP04001JEUYFFUH2000`Ool003Eoo`03001JEUYF009JEP05001JEUYFFUH00009Ool3000COol0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH01000
FUH000001UYF00@005YFFUIJEP80019oo`@0009JEP03001JEUYF00=JEP03001JEUYF00<0035oo`00
=Woo00@005YFFUH000EJEP03001oogoo01eoo`06001JEUYF001JEP0015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YF000001Qoo`/0
03Aoo`00=goo00<005YF00001UYF0P007Woo0P000eYF0P000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`00>7oo00<005YFFUH01eYF00<007oo
Ool077oo00H005YFFUIJEP00Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF00000007FUH3001LOol0
03Uoo`8000IJEP04001JEP00000MOol01@00FUIJEUYF00000Woo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
0eYF0P001eYF00<007ooOol0FWoo000kOol00`00FUIJEP03FUH01000FUIJEUYF0P006goo00<005YF
FUH00P0017oo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00@005YFFUIJEPP00003Ool005YF00AJEP03001JEP0005]oo`00?7oo00D0
05YFFUIJEP0000IJEP8001Yoo`04001JEP000007Ool300000eYF001JEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000002Woo00D005YFFUIJEP00
00=JEP03001oogoo05Qoo`00?Goo0P0000=JEP00FUH01eYF0P0067oo0P000UYF00<007ooOol01goo
100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10003Goo
0P0000=JEP00FUH00eYF00<007ooOol0Egoo000oOol00`00FUIJEP07FUH01000FUH000005goo00@0
05YFFUH000eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000moo`03001JEUYF00AJEP03001oogoo05Ioo`00@7oo0P001eYF00@005YFFUIJEP8001Eoo`03
001JEP0001Aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`03001JEUYF
00AJEP03001oogoo05Eoo`00@Woo0P0015YF00<005YFFUH015YF0P004goo00<005YF000077oo6P00
0UYF00<007ooOol01goo1@004Goo00<005YFFUH00UYF00<005YF0000EWoo0014Ool20002FUH00`00
FUIJEP06FUH5000>Ool2000bOol01000FUIJEP0015YF00<007ooOol01goo0`004Woo00<005YFFUH0
0UYF00<005YF0000EWoo0016Ool30008FUH00`00FUIJEP02FUH70005Ool4000cOol20006FUH2000M
Ool01000FUIJEP000eYF00<007ooOol0Dgoo0019Ool30005FUH00`00FUIJEP05FUH01000FUIJEUYF
1@000UYF00<007ooOol0<goo00<005YFFUH01UYF00<007ooOol06goo00<005YF00000eYF00<007oo
Ool0Dgoo001<Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=goo0P001UYF
0`0077oo00<005YFFUH00eYF00<007ooOol0DWoo001?Ool30006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000>Goo00<005YFFUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2001DOol0059oo`@0
009JEP03001JEUYF00=JEP03001JEUYF008003]oo`05001JEUYFFUH00004FUH2000JOol01000FUIJ
EUYF0P00E7oo001FOol;000nOol30007FUH2000IOol01@00FUH005YF0000E7oo002QOol00`00FUIJ
EP07FUH2000GOol01@00FUH005YF0000E7oo002ROol20006FUH00`00FUIJEP02000FOol01000FUIJ
EP00E7oo002TOol20004FUH00`00FUIJEP02FUH3000COol00`00FUH0001EOol00:Ioo`800003FUH0
05YF00MJEP<0011oo`03001JEP0005Eoo`00Z7oo0`001eYF00<005YFFUH010002Woo0P0000=JEP00
Ool0EGoo002[Ool20005FUH00`00FUIJEP04FUH:0002FUH2001FOol00:eoo`<00003FUH005YF00MJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05Eoo`00/7oo0`001eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00/goo10000UYF00<005YFFUH00eYF00<005YFFUH00`00F7oo002gOol;
001KOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59149 .74918 m .59109 .69355 L .55991 .69188 L p .707 .577 .707 r
F P
0 g
s
.59109 .69355 m .59149 .74918 L .62332 .74819 L p .707 .577 .707 r
F P
0 g
s
.62332 .74819 m .62292 .69257 L .59109 .69355 L p .707 .577 .707 r
F P
0 g
s
.62292 .69257 m .62332 .74819 L .6527 .74465 L p .707 .577 .707 r
F P
0 g
s
.6527 .74465 m .6523 .68903 L .62292 .69257 L p .707 .577 .707 r
F P
0 g
s
.56032 .74751 m .55991 .69188 L .53246 .68772 L p .707 .577 .707 r
F P
0 g
s
.55991 .69188 m .56032 .74751 L .59149 .74918 L p .707 .577 .707 r
F P
0 g
s
.6523 .68903 m .6527 .74465 L .67676 .7389 L p .707 .577 .707 r
F P
0 g
s
.67676 .7389 m .67635 .68327 L .6523 .68903 L p .707 .577 .707 r
F P
0 g
s
.59856 .80838 m .59709 .7712 L .56595 .77055 L p .707 .577 .707 r
F P
0 g
s
.59709 .7712 m .59856 .80838 L .63037 .80647 L p .707 .577 .707 r
F P
0 g
s
.63037 .80647 m .62891 .76929 L .59709 .7712 L p .707 .577 .707 r
F P
0 g
s
.62891 .76929 m .63037 .80647 L .65974 .8022 L p .707 .577 .707 r
F P
0 g
s
.65974 .8022 m .65827 .76501 L .62891 .76929 L p .707 .577 .707 r
F P
0 g
s
.53246 .68772 m .53286 .74334 L .56032 .74751 L p .707 .577 .707 r
F P
0 g
s
.53286 .74334 m .53246 .68772 L .5114 .68147 L p .707 .577 .707 r
F P
0 g
s
.56741 .80773 m .56595 .77055 L .53851 .76741 L p .707 .577 .707 r
F P
0 g
s
.56595 .77055 m .56741 .80773 L .59856 .80838 L p .707 .577 .707 r
F P
0 g
s
.65827 .76501 m .65974 .8022 L .68378 .79597 L p .707 .577 .707 r
F P
0 g
s
.68378 .79597 m .68231 .75879 L .65827 .76501 L p .707 .577 .707 r
F P
0 g
s
.67635 .68327 m .67676 .7389 L .69313 .73149 L p .707 .577 .707 r
F P
0 g
s
.69313 .73149 m .69272 .67587 L .67635 .68327 L p .707 .577 .707 r
F P
0 g
s
.53851 .76741 m .53998 .80459 L .56741 .80773 L p .707 .577 .707 r
F P
0 g
s
.59649 .85969 m .60157 .84248 L .57161 .83205 L p .707 .577 .707 r
F P
0 g
s
.60157 .84248 m .59649 .85969 L .62724 .86661 L p .707 .577 .707 r
F P
0 g
s
.62724 .86661 m .63232 .84939 L .60157 .84248 L p .707 .577 .707 r
F P
0 g
s
.5114 .68147 m .51181 .7371 L .53286 .74334 L p .707 .577 .707 r
F P
0 g
s
.56653 .84927 m .57161 .83205 L .54537 .81914 L p .707 .577 .707 r
F P
0 g
s
.57161 .83205 m .56653 .84927 L .59649 .85969 L p .707 .577 .707 r
F P
0 g
s
.53998 .80459 m .53851 .76741 L .51748 .76209 L p .707 .577 .707 r
F P
0 g
s
.63232 .84939 m .62724 .86661 L .65575 .86933 L p .707 .577 .707 r
F P
0 g
s
.65575 .86933 m .66083 .85211 L .63232 .84939 L p .707 .577 .707 r
F P
0 g
s
.51181 .7371 m .5114 .68147 L .49881 .67375 L p .707 .577 .707 r
F P
0 g
s
.54537 .81914 m .54029 .83636 L .56653 .84927 L p .707 .577 .707 r
F P
0 g
s
.51748 .76209 m .51895 .79927 L .53998 .80459 L p .707 .577 .707 r
F P
0 g
s
.68231 .75879 m .68378 .79597 L .70015 .7884 L p .707 .577 .707 r
F P
0 g
s
.70015 .7884 m .69868 .75122 L .68231 .75879 L p .707 .577 .707 r
F P
0 g
s
.54029 .83636 m .54537 .81914 L .5254 .805 L p .707 .577 .707 r
F P
0 g
s
.66083 .85211 m .65575 .86933 L .67925 .8676 L p .707 .577 .707 r
F P
0 g
s
.67925 .8676 m .68433 .85038 L .66083 .85211 L p .707 .577 .707 r
F P
0 g
s
.5254 .805 m .52032 .82221 L .54029 .83636 L p .707 .577 .707 r
F P
0 g
s
.49881 .67375 m .49921 .72938 L .51181 .7371 L p .707 .577 .707 r
F P
0 g
s
.69272 .67587 m .69313 .73149 L .70021 .72316 L p .707 .577 .707 r
F P
0 g
s
.70021 .72316 m .69981 .66754 L .69272 .67587 L p .707 .577 .707 r
F P
0 g
s
.51895 .79927 m .51748 .76209 L .50491 .7551 L p .707 .577 .707 r
F P
0 g
s
.49921 .72938 m .49881 .67375 L .49591 .66531 L p .707 .577 .707 r
F P
0 g
s
.50491 .7551 m .50637 .79228 L .51895 .79927 L p .707 .577 .707 r
F P
0 g
s
.52032 .82221 m .5254 .805 L .51368 .79101 L p .707 .577 .707 r
F P
0 g
s
.68433 .85038 m .67925 .8676 L .69542 .86158 L p .707 .577 .707 r
F P
0 g
s
.69542 .86158 m .7005 .84436 L .68433 .85038 L p .707 .577 .707 r
F P
0 g
s
.69868 .75122 m .70015 .7884 L .70723 .78024 L p .707 .577 .707 r
F P
0 g
s
.70723 .78024 m .70577 .74306 L .69868 .75122 L p .707 .577 .707 r
F P
0 g
s
.51368 .79101 m .5086 .80823 L .52032 .82221 L p .707 .577 .707 r
F P
0 g
s
.49591 .66531 m .49632 .72094 L .49921 .72938 L p .707 .577 .707 r
F P
0 g
s
.69981 .66754 m .70021 .72316 L .69731 .71473 L p .707 .577 .707 r
F P
0 g
s
.69731 .71473 m .69691 .6591 L .69981 .66754 L p .707 .577 .707 r
F P
0 g
s
.50637 .79228 m .50491 .7551 L .50202 .74713 L p .707 .577 .707 r
F P
0 g
s
.48698 .82191 m .49208 .32059 L .44807 .31746 L p .707 .577 .707 r
F P
0 g
s
.5086 .80823 m .51368 .79101 L .51134 .77855 L p .707 .577 .707 r
F P
0 g
s
.50202 .74713 m .50349 .78431 L .50637 .79228 L p .707 .577 .707 r
F P
0 g
s
.49632 .72094 m .49591 .66531 L .503 .65699 L p .707 .577 .707 r
F P
0 g
s
.51134 .77855 m .50626 .79577 L .5086 .80823 L p .707 .577 .707 r
F P
0 g
s
.503 .65699 m .5034 .71261 L .49632 .72094 L p .707 .577 .707 r
F P
0 g
s
.50349 .78431 m .50202 .74713 L .50911 .73897 L p .707 .577 .707 r
F P
0 g
s
.50626 .79577 m .51134 .77855 L .51861 .76884 L p .707 .577 .707 r
F P
0 g
s
.50911 .73897 m .51058 .77615 L .50349 .78431 L p .707 .577 .707 r
F P
0 g
s
.5034 .71261 m .503 .65699 L .51937 .64958 L p .707 .577 .707 r
F P
0 g
s
.51861 .76884 m .51353 .78605 L .50626 .79577 L p .707 .577 .707 r
F P
0 g
s
.51937 .64958 m .51977 .70521 L .5034 .71261 L p .707 .577 .707 r
F P
0 g
s
.51058 .77615 m .50911 .73897 L .52547 .7314 L p .707 .577 .707 r
F P
0 g
s
.51353 .78605 m .51861 .76884 L .53479 .76282 L p .707 .577 .707 r
F P
0 g
s
.51977 .70521 m .51937 .64958 L .54342 .64383 L p .707 .577 .707 r
F P
0 g
s
.52547 .7314 m .52694 .76858 L .51058 .77615 L p .707 .577 .707 r
F P
0 g
s
.53479 .76282 m .52971 .78004 L .51353 .78605 L p .707 .577 .707 r
F P
0 g
s
.54342 .64383 m .54382 .69945 L .51977 .70521 L p .707 .577 .707 r
F P
0 g
s
.52694 .76858 m .52547 .7314 L .54951 .72517 L p .707 .577 .707 r
F P
0 g
s
.52971 .78004 m .53479 .76282 L .55829 .76109 L p .707 .577 .707 r
F P
0 g
s
.54951 .72517 m .55098 .76236 L .52694 .76858 L p .707 .577 .707 r
F P
0 g
s
.49208 .32059 m .48698 .82191 L .53192 .82122 L p .707 .577 .707 r
F P
0 g
s
.55829 .76109 m .55321 .7783 L .52971 .78004 L p .707 .577 .707 r
F P
0 g
s
.53192 .82122 m .53702 .3199 L .49208 .32059 L p .707 .577 .707 r
F P
0 g
s
.54382 .69945 m .54342 .64383 L .5728 .64028 L p .707 .577 .707 r
F P
0 g
s
.5728 .64028 m .5732 .69591 L .54382 .69945 L p .707 .577 .707 r
F P
0 g
s
.55098 .76236 m .54951 .72517 L .57888 .7209 L p .707 .577 .707 r
F P
0 g
s
.55321 .7783 m .55829 .76109 L .5868 .76381 L p .707 .577 .707 r
F P
0 g
s
.57888 .7209 m .58035 .75808 L .55098 .76236 L p .707 .577 .707 r
F P
0 g
s
.5868 .76381 m .58172 .78103 L .55321 .7783 L p .707 .577 .707 r
F P
0 g
s
.53702 .3199 m .53192 .82122 L .5734 .81677 L p .707 .577 .707 r
F P
0 g
s
.5732 .69591 m .5728 .64028 L .60463 .6393 L p .707 .577 .707 r
F P
0 g
s
.60463 .6393 m .60504 .69492 L .5732 .69591 L p .707 .577 .707 r
F P
0 g
s
.5734 .81677 m .5785 .31546 L .53702 .3199 L p .707 .577 .707 r
F P
0 g
s
.7005 .84436 m .69542 .86158 L .7027 .85186 L p .707 .577 .707 r
F P
0 g
s
.7027 .85186 m .70778 .83465 L .7005 .84436 L p .707 .577 .707 r
F P
0 g
s
.44297 .81877 m .44807 .31746 L .40931 .3108 L p .707 .577 .707 r
F P
0 g
s
.44807 .31746 m .44297 .81877 L .48698 .82191 L p .707 .577 .707 r
F P
0 g
s
.70577 .74306 m .70723 .78024 L .70435 .77227 L p .707 .577 .707 r
F P
0 g
s
.70435 .77227 m .70288 .73509 L .70577 .74306 L p .707 .577 .707 r
F P
0 g
s
.58035 .75808 m .57888 .7209 L .61069 .71899 L p .707 .577 .707 r
F P
0 g
s
.61069 .71899 m .61216 .75617 L .58035 .75808 L p .707 .577 .707 r
F P
0 g
s
.58172 .78103 m .5868 .76381 L .61754 .77072 L p .707 .577 .707 r
F P
0 g
s
.61754 .77072 m .61246 .78794 L .58172 .78103 L p .707 .577 .707 r
F P
0 g
s
.5785 .31546 m .5734 .81677 L .60735 .809 L p .707 .577 .707 r
F P
0 g
s
.63581 .64097 m .63621 .6966 L .60504 .69492 L p .707 .577 .707 r
F P
0 g
s
.60504 .69492 m .60463 .6393 L .63581 .64097 L p .707 .577 .707 r
F P
0 g
s
.60735 .809 m .61245 .30769 L .5785 .31546 L p .707 .577 .707 r
F P
0 g
s
.69691 .6591 m .69731 .71473 L .68472 .70701 L p .707 .577 .707 r
F P
0 g
s
.68472 .70701 m .68432 .65138 L .69691 .6591 L p .707 .577 .707 r
F P
0 g
s
.40421 .81212 m .40931 .3108 L .37959 .30128 L p .707 .577 .707 r
F P
0 g
s
.40931 .3108 m .40421 .81212 L .44297 .81877 L p .707 .577 .707 r
F P
0 g
s
.24848 .71154 m .24808 .65592 L .2169 .65425 L p .707 .577 .707 r
F P
0 g
s
.24808 .65592 m .24848 .71154 L .28031 .71056 L p .707 .577 .707 r
F P
0 g
s
.28031 .71056 m .27991 .65494 L .24808 .65592 L p .707 .577 .707 r
F P
0 g
s
.27991 .65494 m .28031 .71056 L .3097 .70702 L p .707 .577 .707 r
F P
0 g
s
.3097 .70702 m .30929 .65139 L .27991 .65494 L p .707 .577 .707 r
F P
0 g
s
.70778 .83465 m .7027 .85186 L .70036 .8394 L p .707 .577 .707 r
F P
0 g
s
.70036 .8394 m .70544 .82219 L .70778 .83465 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21731 .70987 m .2169 .65425 L .18945 .65008 L p .707 .577 .707 r
F P
0 g
s
.2169 .65425 m .21731 .70987 L .24848 .71154 L p .707 .577 .707 r
F P
0 g
s
.70288 .73509 m .70435 .77227 L .69177 .76528 L p .707 .577 .707 r
F P
0 g
s
.69177 .76528 m .69031 .7281 L .70288 .73509 L p .707 .577 .707 r
F P
0 g
s
.30929 .65139 m .3097 .70702 L .33375 .70126 L p .707 .577 .707 r
F P
0 g
s
.33375 .70126 m .33335 .64564 L .30929 .65139 L p .707 .577 .707 r
F P
0 g
s
.64184 .71964 m .64331 .75682 L .61216 .75617 L p .707 .577 .707 r
F P
0 g
s
.61216 .75617 m .61069 .71899 L .64184 .71964 L p .707 .577 .707 r
F P
0 g
s
.64751 .78114 m .64243 .79836 L .61246 .78794 L p .707 .577 .707 r
F P
0 g
s
.61246 .78794 m .61754 .77072 L .64751 .78114 L p .707 .577 .707 r
F P
0 g
s
.61245 .30769 m .60735 .809 L .63046 .79867 L p .707 .577 .707 r
F P
0 g
s
.63046 .79867 m .63556 .29736 L .61245 .30769 L p .707 .577 .707 r
F P
0 g
s
.68432 .65138 m .68472 .70701 L .66367 .70076 L p .707 .577 .707 r
F P
0 g
s
.66367 .70076 m .66326 .64514 L .68432 .65138 L p .707 .577 .707 r
F P
0 g
s
.25555 .77251 m .25409 .73533 L .22294 .73468 L p .707 .577 .707 r
F P
0 g
s
.25409 .73533 m .25555 .77251 L .28737 .77061 L p .707 .577 .707 r
F P
0 g
s
.28737 .77061 m .2859 .73343 L .25409 .73533 L p .707 .577 .707 r
F P
0 g
s
.2859 .73343 m .28737 .77061 L .31673 .76633 L p .707 .577 .707 r
F P
0 g
s
.31673 .76633 m .31526 .72915 L .2859 .73343 L p .707 .577 .707 r
F P
0 g
s
.18945 .65008 m .18985 .70571 L .21731 .70987 L p .707 .577 .707 r
F P
0 g
s
.18985 .70571 m .18945 .65008 L .16839 .64384 L p .707 .577 .707 r
F P
0 g
s
.22441 .77187 m .22294 .73468 L .1955 .73155 L p .707 .577 .707 r
F P
0 g
s
.22294 .73468 m .22441 .77187 L .25555 .77251 L p .707 .577 .707 r
F P
0 g
s
.37449 .8026 m .37959 .30128 L .36181 .28983 L p .707 .577 .707 r
F P
0 g
s
.37959 .30128 m .37449 .8026 L .40421 .81212 L p .707 .577 .707 r
F P
0 g
s
.70544 .82219 m .70036 .8394 L .68864 .82542 L p .707 .577 .707 r
F P
0 g
s
.68864 .82542 m .69372 .8082 L .70544 .82219 L p .707 .577 .707 r
F P
0 g
s
.31526 .72915 m .31673 .76633 L .34077 .76011 L p .707 .577 .707 r
F P
0 g
s
.34077 .76011 m .3393 .72292 L .31526 .72915 L p .707 .577 .707 r
F P
0 g
s
.33335 .64564 m .33375 .70126 L .35012 .69386 L p .707 .577 .707 r
F P
0 g
s
.35012 .69386 m .34971 .63823 L .33335 .64564 L p .707 .577 .707 r
F P
0 g
s
.1955 .73155 m .19697 .76873 L .22441 .77187 L p .707 .577 .707 r
F P
0 g
s
.25348 .82349 m .25856 .80628 L .2286 .79585 L p .707 .577 .707 r
F P
0 g
s
.25856 .80628 m .25348 .82349 L .28423 .83041 L p .707 .577 .707 r
F P
0 g
s
.28423 .83041 m .28931 .81319 L .25856 .80628 L p .707 .577 .707 r
F P
0 g
s
.69031 .7281 m .69177 .76528 L .67074 .75996 L p .707 .577 .707 r
F P
0 g
s
.67074 .75996 m .66927 .72278 L .69031 .7281 L p .707 .577 .707 r
F P
0 g
s
.16839 .64384 m .1688 .69946 L .18985 .70571 L p .707 .577 .707 r
F P
0 g
s
.22352 .81307 m .2286 .79585 L .20236 .78294 L p .707 .577 .707 r
F P
0 g
s
.2286 .79585 m .22352 .81307 L .25348 .82349 L p .707 .577 .707 r
F P
0 g
s
.66326 .64514 m .66367 .70076 L .63621 .6966 L p .707 .577 .707 r
F P
0 g
s
.63621 .6966 m .63581 .64097 L .66326 .64514 L p .707 .577 .707 r
F P
0 g
s
.19697 .76873 m .1955 .73155 L .17447 .72622 L p .707 .577 .707 r
F P
0 g
s
.28931 .81319 m .28423 .83041 L .31274 .83313 L p .707 .577 .707 r
F P
0 g
s
.31274 .83313 m .31782 .81591 L .28931 .81319 L p .707 .577 .707 r
F P
0 g
s
.1688 .69946 m .16839 .64384 L .1558 .63612 L p .707 .577 .707 r
F P
0 g
s
.20236 .78294 m .19728 .80016 L .22352 .81307 L p .707 .577 .707 r
F P
0 g
s
.17447 .72622 m .17594 .7634 L .19697 .76873 L p .707 .577 .707 r
F P
0 g
s
.3393 .72292 m .34077 .76011 L .35714 .75254 L p .707 .577 .707 r
F P
0 g
s
.35714 .75254 m .35567 .71536 L .3393 .72292 L p .707 .577 .707 r
F P
0 g
s
.19728 .80016 m .20236 .78294 L .18239 .7688 L p .707 .577 .707 r
F P
0 g
s
.63556 .29736 m .63046 .79867 L .64046 .78679 L p .707 .577 .707 r
F P
0 g
s
.64046 .78679 m .64556 .28548 L .63556 .29736 L p .707 .577 .707 r
F P
0 g
s
.31782 .81591 m .31274 .83313 L .33624 .8314 L p .707 .577 .707 r
F P
0 g
s
.33624 .8314 m .34132 .81418 L .31782 .81591 L p .707 .577 .707 r
F P
0 g
s
.69372 .8082 m .68864 .82542 L .66867 .81128 L p .707 .577 .707 r
F P
0 g
s
.66867 .81128 m .67375 .79406 L .69372 .8082 L p .707 .577 .707 r
F P
0 g
s
.66927 .72278 m .67074 .75996 L .64331 .75682 L p .707 .577 .707 r
F P
0 g
s
.64331 .75682 m .64184 .71964 L .66927 .72278 L p .707 .577 .707 r
F P
0 g
s
.18239 .7688 m .17731 .78601 L .19728 .80016 L p .707 .577 .707 r
F P
0 g
s
.1558 .63612 m .1562 .69174 L .1688 .69946 L p .707 .577 .707 r
F P
0 g
s
.34971 .63823 m .35012 .69386 L .3572 .68553 L p .707 .577 .707 r
F P
0 g
s
.3572 .68553 m .3568 .62991 L .34971 .63823 L p .707 .577 .707 r
F P
0 g
s
.17594 .7634 m .17447 .72622 L .1619 .71923 L p .707 .577 .707 r
F P
0 g
s
.35567 .71536 m .35714 .75254 L .36422 .74437 L p .707 .577 .707 r
F P
0 g
s
.36422 .74437 m .36276 .70719 L .35567 .71536 L p .707 .577 .707 r
F P
0 g
s
.3568 .62991 m .3572 .68553 L .3543 .67709 L p .707 .577 .707 r
F P
0 g
s
.35987 .69923 m .36134 .73641 L .34876 .72942 L p .707 .577 .707 r
F P
0 g
s
.34876 .72942 m .3473 .69224 L .35987 .69923 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .34563 .78922 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36243 .78599 m .36089 .79122 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36089 .79122 m .35735 .8032 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35772 .27756 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .35071 .772 L .36059 .78379 L p .707 .577 .707 r
F P
0 g
s
.36059 .78379 m .36243 .78599 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .36059 .78379 L .36069 .78632 L .707 .577 .707 r
F
.35262 .77887 m .35671 .79114 L p .35691 .69138 L F P
0 g
s
.3543 .67709 m .3539 .62147 L .3568 .62991 L p .707 .577 .707 r
F P
0 g
s
.35772 .27756 m .3542 .62354 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.3539 .62147 m .3543 .67709 L .34171 .66937 L p .707 .577 .707 r
F P
0 g
s
.3542 .62354 m .35262 .77887 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35671 .79114 m .35756 .70773 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35756 .70773 m .36181 .28983 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.36276 .70719 m .36422 .74437 L .36134 .73641 L p .707 .577 .707 r
F P
0 g
s
.36134 .73641 m .35987 .69923 L .36276 .70719 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .36243 .78599 L .36477 .79845 L p .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35671 .79114 L .37449 .8026 L p .707 .577 .707 r
F P
0 g
s
.1562 .69174 m .1558 .63612 L .1529 .62768 L p .707 .577 .707 r
F P
0 g
s
.1619 .71923 m .16336 .75642 L .17594 .7634 L p .707 .577 .707 r
F P
0 g
s
.17731 .78601 m .18239 .7688 L .17067 .75481 L p .707 .577 .707 r
F P
0 g
s
.34132 .81418 m .33624 .8314 L .35242 .82538 L p .707 .577 .707 r
F P
0 g
s
.35242 .82538 m .3575 .80816 L .34132 .81418 L p .707 .577 .707 r
F P
0 g
s
.67375 .79406 m .66867 .81128 L .64243 .79836 L p .707 .577 .707 r
F P
0 g
s
.64243 .79836 m .64751 .78114 L .67375 .79406 L p .707 .577 .707 r
F P
0 g
s
.17067 .75481 m .16559 .77203 L .17731 .78601 L p .707 .577 .707 r
F P
0 g
s
.1529 .62768 m .15331 .6833 L .1562 .69174 L p .707 .577 .707 r
F P
0 g
s
.16336 .75642 m .1619 .71923 L .15901 .71127 L p .707 .577 .707 r
F P
0 g
s
.64556 .28548 m .64046 .78679 L .63638 .77452 L p .707 .577 .707 r
F P
0 g
s
.63638 .77452 m .64147 .27321 L .64556 .28548 L p .707 .577 .707 r
F P
0 g
s
.16559 .77203 m .17067 .75481 L .16833 .74235 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15901 .71127 m .16048 .74845 L .16336 .75642 L p .707 .577 .707 r
F P
0 g
s
.15331 .6833 m .1529 .62768 L .15999 .61935 L p .707 .577 .707 r
F P
0 g
s
.3575 .80816 m .35242 .82538 L .35969 .81566 L p .707 .577 .707 r
F P
0 g
s
.35969 .81566 m .36477 .79845 L .3575 .80816 L p .707 .577 .707 r
F P
0 g
s
.16833 .74235 m .16325 .75957 L .16559 .77203 L p .707 .577 .707 r
F P
0 g
s
.35262 .77887 m .35772 .27756 L .36772 .26568 L p .707 .577 .707 r
F P
0 g
s
.15999 .61935 m .16039 .67498 L .15331 .6833 L p .707 .577 .707 r
F P
0 g
s
.34171 .66937 m .34131 .61375 L .3539 .62147 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16048 .74845 m .15901 .71127 L .1661 .7031 L p .707 .577 .707 r
F P
0 g
s
.16325 .75957 m .16833 .74235 L .1756 .73264 L p .707 .577 .707 r
F P
0 g
s
.16039 .67498 m .15999 .61935 L .17636 .61195 L p .707 .577 .707 r
F P
0 g
s
.36477 .79845 m .35969 .81566 L .35735 .8032 L p .707 .577 .707 r
F P
0 g
s
.1661 .7031 m .16757 .74028 L .16048 .74845 L p .707 .577 .707 r
F P
0 g
s
.1756 .73264 m .17052 .74985 L .16325 .75957 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64147 .27321 m .63638 .77452 L .6186 .76307 L p .707 .577 .707 r
F P
0 g
s
.6186 .76307 m .6237 .26176 L .64147 .27321 L p .707 .577 .707 r
F P
0 g
s
.17636 .61195 m .17676 .66757 L .16039 .67498 L p .707 .577 .707 r
F P
0 g
s
.34131 .61375 m .34171 .66937 L .32066 .66312 L p .707 .577 .707 r
F P
0 g
s
.32066 .66312 m .32025 .6075 L .34131 .61375 L p .707 .577 .707 r
F P
0 g
s
.16757 .74028 m .1661 .7031 L .18246 .69554 L p .707 .577 .707 r
F P
0 g
s
.36262 .76699 m .36772 .26568 L .39083 .25535 L p .707 .577 .707 r
F P
0 g
s
.36772 .26568 m .36262 .76699 L .35262 .77887 L p .707 .577 .707 r
F P
0 g
s
.17052 .74985 m .1756 .73264 L .19178 .72662 L p .707 .577 .707 r
F P
0 g
s
.17676 .66757 m .17636 .61195 L .20041 .60619 L p .707 .577 .707 r
F P
0 g
s
.18246 .69554 m .18393 .73272 L .16757 .74028 L p .707 .577 .707 r
F P
0 g
s
.19178 .72662 m .1867 .74384 L .17052 .74985 L p .707 .577 .707 r
F P
0 g
s
.3473 .69224 m .34876 .72942 L .32773 .7241 L p .707 .577 .707 r
F P
0 g
s
.32773 .7241 m .32626 .68691 L .3473 .69224 L p .707 .577 .707 r
F P
0 g
s
.32025 .6075 m .32066 .66312 L .2932 .65896 L p .707 .577 .707 r
F P
0 g
s
.2932 .65896 m .2928 .60334 L .32025 .6075 L p .707 .577 .707 r
F P
0 g
s
.20041 .60619 m .20081 .66182 L .17676 .66757 L p .707 .577 .707 r
F P
0 g
s
.6237 .26176 m .6186 .76307 L .58888 .75355 L p .707 .577 .707 r
F P
0 g
s
.58888 .75355 m .59398 .25224 L .6237 .26176 L p .707 .577 .707 r
F P
0 g
s
.20081 .66182 m .20041 .60619 L .22979 .60265 L p .707 .577 .707 r
F P
0 g
s
.18393 .73272 m .18246 .69554 L .2065 .68931 L p .707 .577 .707 r
F P
0 g
s
.1867 .74384 m .19178 .72662 L .21528 .72489 L p .707 .577 .707 r
F P
0 g
s
.2928 .60334 m .2932 .65896 L .26203 .65729 L p .707 .577 .707 r
F P
0 g
s
.26203 .65729 m .26163 .60167 L .2928 .60334 L p .707 .577 .707 r
F P
0 g
s
.35071 .772 m .34563 .78922 L .32566 .77508 L p .707 .577 .707 r
F P
0 g
s
.32566 .77508 m .33074 .75786 L .35071 .772 L p .707 .577 .707 r
F P
0 g
s
.2065 .68931 m .20797 .72649 L .18393 .73272 L p .707 .577 .707 r
F P
0 g
s
.32626 .68691 m .32773 .7241 L .3003 .72096 L p .707 .577 .707 r
F P
0 g
s
.3003 .72096 m .29883 .68378 L .32626 .68691 L p .707 .577 .707 r
F P
0 g
s
.23019 .65827 m .22979 .60265 L .26163 .60167 L p .707 .577 .707 r
F P
0 g
s
.22979 .60265 m .23019 .65827 L .20081 .66182 L p .707 .577 .707 r
F P
0 g
s
.21528 .72489 m .2102 .7421 L .1867 .74384 L p .707 .577 .707 r
F P
0 g
s
.39083 .25535 m .38573 .75666 L .36262 .76699 L p .707 .577 .707 r
F P
0 g
s
.38573 .75666 m .39083 .25535 L .42479 .24758 L p .707 .577 .707 r
F P
0 g
s
.26163 .60167 m .26203 .65729 L .23019 .65827 L p .707 .577 .707 r
F P
0 g
s
.72869 .65714 m .72829 .60152 L .69712 .59984 L p .707 .577 .707 r
F P
0 g
s
.72829 .60152 m .72869 .65714 L .76053 .65616 L p .707 .577 .707 r
F P
0 g
s
.76053 .65616 m .76012 .60053 L .72829 .60152 L p .707 .577 .707 r
F P
0 g
s
.76012 .60053 m .76053 .65616 L .78991 .65261 L p .707 .577 .707 r
F P
0 g
s
.78991 .65261 m .78951 .59699 L .76012 .60053 L p .707 .577 .707 r
F P
0 g
s
.20797 .72649 m .2065 .68931 L .23587 .68503 L p .707 .577 .707 r
F P
0 g
s
.69752 .65547 m .69712 .59984 L .66966 .59568 L p .707 .577 .707 r
F P
0 g
s
.69712 .59984 m .69752 .65547 L .72869 .65714 L p .707 .577 .707 r
F P
0 g
s
.2102 .7421 m .21528 .72489 L .24379 .72761 L p .707 .577 .707 r
F P
0 g
s
.29883 .68378 m .3003 .72096 L .26915 .72031 L p .707 .577 .707 r
F P
0 g
s
.26915 .72031 m .26768 .68313 L .29883 .68378 L p .707 .577 .707 r
F P
0 g
s
.33074 .75786 m .32566 .77508 L .29942 .76216 L p .707 .577 .707 r
F P
0 g
s
.29942 .76216 m .3045 .74494 L .33074 .75786 L p .707 .577 .707 r
F P
0 g
s
.23587 .68503 m .23734 .72222 L .20797 .72649 L p .707 .577 .707 r
F P
0 g
s
.59398 .25224 m .58888 .75355 L .55011 .7469 L p .707 .577 .707 r
F P
0 g
s
.55011 .7469 m .55521 .24558 L .59398 .25224 L p .707 .577 .707 r
F P
0 g
s
.78951 .59699 m .78991 .65261 L .81396 .64686 L p .707 .577 .707 r
F P
0 g
s
.81396 .64686 m .81356 .59123 L .78951 .59699 L p .707 .577 .707 r
F P
0 g
s
.23734 .72222 m .23587 .68503 L .26768 .68313 L p .707 .577 .707 r
F P
0 g
s
.24379 .72761 m .23871 .74483 L .2102 .7421 L p .707 .577 .707 r
F P
0 g
s
.26768 .68313 m .26915 .72031 L .23734 .72222 L p .707 .577 .707 r
F P
0 g
s
.73577 .71634 m .7343 .67916 L .70315 .67851 L p .707 .577 .707 r
F P
0 g
s
.7343 .67916 m .73577 .71634 L .76758 .71443 L p .707 .577 .707 r
F P
0 g
s
.76758 .71443 m .76611 .67725 L .7343 .67916 L p .707 .577 .707 r
F P
0 g
s
.76611 .67725 m .76758 .71443 L .79694 .71016 L p .707 .577 .707 r
F P
0 g
s
.79694 .71016 m .79548 .67298 L .76611 .67725 L p .707 .577 .707 r
F P
0 g
s
.66966 .59568 m .67006 .6513 L .69752 .65547 L p .707 .577 .707 r
F P
0 g
s
.67006 .6513 m .66966 .59568 L .64861 .58943 L p .707 .577 .707 r
F P
0 g
s
.23871 .74483 m .24379 .72761 L .27453 .73452 L p .707 .577 .707 r
F P
0 g
s
.41969 .7489 m .42479 .24758 L .46627 .24314 L p .707 .577 .707 r
F P
0 g
s
.42479 .24758 m .41969 .7489 L .38573 .75666 L p .707 .577 .707 r
F P
0 g
s
.3045 .74494 m .29942 .76216 L .26945 .75174 L p .707 .577 .707 r
F P
0 g
s
.26945 .75174 m .27453 .73452 L .3045 .74494 L p .707 .577 .707 r
F P
0 g
s
.70462 .71569 m .70315 .67851 L .67572 .67537 L p .707 .577 .707 r
F P
0 g
s
.70315 .67851 m .70462 .71569 L .73577 .71634 L p .707 .577 .707 r
F P
0 g
s
.27453 .73452 m .26945 .75174 L .23871 .74483 L p .707 .577 .707 r
F P
0 g
s
.79548 .67298 m .79694 .71016 L .82099 .70393 L p .707 .577 .707 r
F P
0 g
s
.82099 .70393 m .81952 .66675 L .79548 .67298 L p .707 .577 .707 r
F P
0 g
s
.81356 .59123 m .81396 .64686 L .83033 .63945 L p .707 .577 .707 r
F P
0 g
s
.83033 .63945 m .82993 .58383 L .81356 .59123 L p .707 .577 .707 r
F P
0 g
s
.67572 .67537 m .67719 .71255 L .70462 .71569 L p .707 .577 .707 r
F P
0 g
s
.55521 .24558 m .55011 .7469 L .50611 .74376 L p .707 .577 .707 r
F P
0 g
s
.50611 .74376 m .51121 .24245 L .55521 .24558 L p .707 .577 .707 r
F P
0 g
s
.7337 .76766 m .73878 .75044 L .70882 .74002 L p .707 .577 .707 r
F P
0 g
s
.73878 .75044 m .7337 .76766 L .76444 .77457 L p .707 .577 .707 r
F P
0 g
s
.76444 .77457 m .76952 .75735 L .73878 .75044 L p .707 .577 .707 r
F P
0 g
s
.64861 .58943 m .64901 .64506 L .67006 .6513 L p .707 .577 .707 r
F P
0 g
s
.70374 .75723 m .70882 .74002 L .68257 .7271 L p .707 .577 .707 r
F P
0 g
s
.70882 .74002 m .70374 .75723 L .7337 .76766 L p .707 .577 .707 r
F P
0 g
s
.46117 .74445 m .46627 .24314 L .51121 .24245 L p .707 .577 .707 r
F P
0 g
s
.46627 .24314 m .46117 .74445 L .41969 .7489 L p .707 .577 .707 r
F P
0 g
s
.67719 .71255 m .67572 .67537 L .65468 .67005 L p .707 .577 .707 r
F P
0 g
s
.76952 .75735 m .76444 .77457 L .79296 .77729 L p .707 .577 .707 r
F P
0 g
s
.79296 .77729 m .79804 .76007 L .76952 .75735 L p .707 .577 .707 r
F P
0 g
s
.51121 .24245 m .50611 .74376 L .46117 .74445 L p .707 .577 .707 r
F P
0 g
s
.64901 .64506 m .64861 .58943 L .63601 .58171 L p .707 .577 .707 r
F P
0 g
s
.68257 .7271 m .67749 .74432 L .70374 .75723 L p .707 .577 .707 r
F P
0 g
s
.65468 .67005 m .65615 .70723 L .67719 .71255 L p .707 .577 .707 r
F P
0 g
s
.81952 .66675 m .82099 .70393 L .83735 .69637 L p .707 .577 .707 r
F P
0 g
s
.83735 .69637 m .83588 .65918 L .81952 .66675 L p .707 .577 .707 r
F P
0 g
s
.67749 .74432 m .68257 .7271 L .66261 .71296 L p .707 .577 .707 r
F P
0 g
s
.79804 .76007 m .79296 .77729 L .81645 .77556 L p .707 .577 .707 r
F P
0 g
s
.81645 .77556 m .82153 .75834 L .79804 .76007 L p .707 .577 .707 r
F P
0 g
s
.66261 .71296 m .65753 .73018 L .67749 .74432 L p .707 .577 .707 r
F P
0 g
s
.63601 .58171 m .63642 .63734 L .64901 .64506 L p .707 .577 .707 r
F P
0 g
s
.82993 .58383 m .83033 .63945 L .83741 .63113 L p .707 .577 .707 r
F P
0 g
s
.83741 .63113 m .83701 .5755 L .82993 .58383 L p .707 .577 .707 r
F P
0 g
s
.65615 .70723 m .65468 .67005 L .64211 .66306 L p .707 .577 .707 r
F P
0 g
s
.63642 .63734 m .63601 .58171 L .63312 .57328 L p .707 .577 .707 r
F P
0 g
s
.64211 .66306 m .64358 .70024 L .65615 .70723 L p .707 .577 .707 r
F P
0 g
s
.65753 .73018 m .66261 .71296 L .65088 .69897 L p .707 .577 .707 r
F P
0 g
s
.82153 .75834 m .81645 .77556 L .83263 .76954 L p .707 .577 .707 r
F P
0 g
s
.83263 .76954 m .83771 .75232 L .82153 .75834 L p .707 .577 .707 r
F P
0 g
s
.83588 .65918 m .83735 .69637 L .84444 .6882 L p .707 .577 .707 r
F P
0 g
s
.84444 .6882 m .84297 .65102 L .83588 .65918 L p .707 .577 .707 r
F P
0 g
s
.65088 .69897 m .6458 .71619 L .65753 .73018 L p .707 .577 .707 r
F P
0 g
s
.63312 .57328 m .63352 .6289 L .63642 .63734 L p .707 .577 .707 r
F P
0 g
s
.83701 .5755 m .83741 .63113 L .83452 .62269 L p .707 .577 .707 r
F P
0 g
s
.83452 .62269 m .83412 .56706 L .83701 .5755 L p .707 .577 .707 r
F P
0 g
s
.64358 .70024 m .64211 .66306 L .63922 .65509 L p .707 .577 .707 r
F P
0 g
s
.6458 .71619 m .65088 .69897 L .64854 .68651 L p .707 .577 .707 r
F P
0 g
s
.63922 .65509 m .64069 .69227 L .64358 .70024 L p .707 .577 .707 r
F P
0 g
s
.63352 .6289 m .63312 .57328 L .6402 .56495 L p .707 .577 .707 r
F P
0 g
s
.83771 .75232 m .83263 .76954 L .8399 .75983 L p .707 .577 .707 r
F P
0 g
s
.8399 .75983 m .84498 .74261 L .83771 .75232 L p .707 .577 .707 r
F P
0 g
s
.64854 .68651 m .64346 .70373 L .6458 .71619 L p .707 .577 .707 r
F P
0 g
s
.84297 .65102 m .84444 .6882 L .84155 .68023 L p .707 .577 .707 r
F P
0 g
s
.84155 .68023 m .84009 .64305 L .84297 .65102 L p .707 .577 .707 r
F P
0 g
s
.6402 .56495 m .6406 .62057 L .63352 .6289 L p .707 .577 .707 r
F P
0 g
s
.83412 .56706 m .83452 .62269 L .82193 .61497 L p .707 .577 .707 r
F P
0 g
s
.82193 .61497 m .82152 .55934 L .83412 .56706 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64069 .69227 m .63922 .65509 L .64631 .64693 L p .707 .577 .707 r
F P
0 g
s
.64346 .70373 m .64854 .68651 L .65582 .6768 L p .707 .577 .707 r
F P
0 g
s
.38568 .6195 m .38528 .56388 L .35411 .56221 L p .707 .577 .707 r
F P
0 g
s
.38528 .56388 m .38568 .6195 L .41752 .61852 L p .707 .577 .707 r
F P
0 g
s
.41752 .61852 m .41711 .5629 L .38528 .56388 L p .707 .577 .707 r
F P
0 g
s
.41711 .5629 m .41752 .61852 L .4469 .61498 L p .707 .577 .707 r
F P
0 g
s
.4469 .61498 m .4465 .55935 L .41711 .5629 L p .707 .577 .707 r
F P
0 g
s
.84498 .74261 m .8399 .75983 L .83757 .74737 L p .707 .577 .707 r
F P
0 g
s
.83757 .74737 m .84265 .73015 L .84498 .74261 L p .707 .577 .707 r
F P
0 g
s
.64631 .64693 m .64778 .68411 L .64069 .69227 L p .707 .577 .707 r
F P
0 g
s
.6406 .62057 m .6402 .56495 L .65657 .55754 L p .707 .577 .707 r
F P
0 g
s
.65582 .6768 m .65074 .69402 L .64346 .70373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35451 .61783 m .35411 .56221 L .32665 .55805 L p .707 .577 .707 r
F P
0 g
s
.35411 .56221 m .35451 .61783 L .38568 .6195 L p .707 .577 .707 r
F P
0 g
s
.84009 .64305 m .84155 .68023 L .82898 .67325 L p .707 .577 .707 r
F P
0 g
s
.82898 .67325 m .82751 .63606 L .84009 .64305 L p .707 .577 .707 r
F P
0 g
s
.4465 .55935 m .4469 .61498 L .47095 .60922 L p .707 .577 .707 r
F P
0 g
s
.47095 .60922 m .47055 .5536 L .4465 .55935 L p .707 .577 .707 r
F P
0 g
s
.65657 .55754 m .65697 .61317 L .6406 .62057 L p .707 .577 .707 r
F P
0 g
s
.82152 .55934 m .82193 .61497 L .80087 .60872 L p .707 .577 .707 r
F P
0 g
s
.80087 .60872 m .80047 .5531 L .82152 .55934 L p .707 .577 .707 r
F P
0 g
s
.39276 .68048 m .39129 .64329 L .36014 .64265 L p .707 .577 .707 r
F P
0 g
s
.39129 .64329 m .39276 .68048 L .42457 .67857 L p .707 .577 .707 r
F P
0 g
s
.42457 .67857 m .4231 .64139 L .39129 .64329 L p .707 .577 .707 r
F P
0 g
s
.4231 .64139 m .42457 .67857 L .45393 .67429 L p .707 .577 .707 r
F P
0 g
s
.45393 .67429 m .45247 .63711 L .4231 .64139 L p .707 .577 .707 r
F P
0 g
s
.32665 .55805 m .32705 .61367 L .35451 .61783 L p .707 .577 .707 r
F P
0 g
s
.32705 .61367 m .32665 .55805 L .3056 .5518 L p .707 .577 .707 r
F P
0 g
s
.64778 .68411 m .64631 .64693 L .66268 .63936 L p .707 .577 .707 r
F P
0 g
s
.36161 .67983 m .36014 .64265 L .33271 .63951 L p .707 .577 .707 r
F P
0 g
s
.36014 .64265 m .36161 .67983 L .39276 .68048 L p .707 .577 .707 r
F P
0 g
s
.65074 .69402 m .65582 .6768 L .67199 .67078 L p .707 .577 .707 r
F P
0 g
s
.65697 .61317 m .65657 .55754 L .68062 .55179 L p .707 .577 .707 r
F P
0 g
s
.84265 .73015 m .83757 .74737 L .82584 .73338 L p .707 .577 .707 r
F P
0 g
s
.82584 .73338 m .83092 .71616 L .84265 .73015 L p .707 .577 .707 r
F P
0 g
s
.66268 .63936 m .66414 .67654 L .64778 .68411 L p .707 .577 .707 r
F P
0 g
s
.45247 .63711 m .45393 .67429 L .47798 .66807 L p .707 .577 .707 r
F P
0 g
s
.47798 .66807 m .47651 .63089 L .45247 .63711 L p .707 .577 .707 r
F P
0 g
s
.67199 .67078 m .66691 .688 L .65074 .69402 L p .707 .577 .707 r
F P
0 g
s
.47055 .5536 m .47095 .60922 L .48732 .60182 L p .707 .577 .707 r
F P
0 g
s
.48732 .60182 m .48692 .54619 L .47055 .5536 L p .707 .577 .707 r
F P
0 g
s
.33271 .63951 m .33418 .67669 L .36161 .67983 L p .707 .577 .707 r
F P
0 g
s
.39069 .73146 m .39577 .71424 L .36581 .70382 L p .707 .577 .707 r
F P
0 g
s
.39577 .71424 m .39069 .73146 L .42143 .73837 L p .707 .577 .707 r
F P
0 g
s
.42143 .73837 m .42651 .72115 L .39577 .71424 L p .707 .577 .707 r
F P
0 g
s
.82751 .63606 m .82898 .67325 L .80795 .66792 L p .707 .577 .707 r
F P
0 g
s
.80795 .66792 m .80648 .63074 L .82751 .63606 L p .707 .577 .707 r
F P
0 g
s
.3056 .5518 m .306 .60742 L .32705 .61367 L p .707 .577 .707 r
F P
0 g
s
.36073 .72103 m .36581 .70382 L .33956 .6909 L p .707 .577 .707 r
F P
0 g
s
.36581 .70382 m .36073 .72103 L .39069 .73146 L p .707 .577 .707 r
F P
0 g
s
.80047 .5531 m .80087 .60872 L .77341 .60456 L p .707 .577 .707 r
F P
0 g
s
.77341 .60456 m .77301 .54893 L .80047 .5531 L p .707 .577 .707 r
F P
0 g
s
.33418 .67669 m .33271 .63951 L .31167 .63418 L p .707 .577 .707 r
F P
0 g
s
.42651 .72115 m .42143 .73837 L .44995 .74109 L p .707 .577 .707 r
F P
0 g
s
.44995 .74109 m .45503 .72387 L .42651 .72115 L p .707 .577 .707 r
F P
0 g
s
.68062 .55179 m .68103 .60741 L .65697 .61317 L p .707 .577 .707 r
F P
0 g
s
.306 .60742 m .3056 .5518 L .293 .54408 L p .707 .577 .707 r
F P
0 g
s
.33956 .6909 m .33448 .70812 L .36073 .72103 L p .707 .577 .707 r
F P
0 g
s
.66414 .67654 m .66268 .63936 L .68672 .63314 L p .707 .577 .707 r
F P
0 g
s
.68103 .60741 m .68062 .55179 L .71 .54825 L p .707 .577 .707 r
F P
0 g
s
.31167 .63418 m .31314 .67136 L .33418 .67669 L p .707 .577 .707 r
F P
0 g
s
.47651 .63089 m .47798 .66807 L .49434 .6605 L p .707 .577 .707 r
F P
0 g
s
.49434 .6605 m .49287 .62332 L .47651 .63089 L p .707 .577 .707 r
F P
0 g
s
.33448 .70812 m .33956 .6909 L .3196 .67676 L p .707 .577 .707 r
F P
0 g
s
.66691 .688 m .67199 .67078 L .69549 .66905 L p .707 .577 .707 r
F P
0 g
s
.45503 .72387 m .44995 .74109 L .47344 .73936 L p .707 .577 .707 r
F P
0 g
s
.47344 .73936 m .47852 .72214 L .45503 .72387 L p .707 .577 .707 r
F P
0 g
s
.77301 .54893 m .77341 .60456 L .74224 .60289 L p .707 .577 .707 r
F P
0 g
s
.74224 .60289 m .74184 .54726 L .77301 .54893 L p .707 .577 .707 r
F P
0 g
s
.83092 .71616 m .82584 .73338 L .80588 .71924 L p .707 .577 .707 r
F P
0 g
s
.80588 .71924 m .81096 .70202 L .83092 .71616 L p .707 .577 .707 r
F P
0 g
s
.68672 .63314 m .68819 .67032 L .66414 .67654 L p .707 .577 .707 r
F P
0 g
s
.80648 .63074 m .80795 .66792 L .78051 .66478 L p .707 .577 .707 r
F P
0 g
s
.78051 .66478 m .77904 .6276 L .80648 .63074 L p .707 .577 .707 r
F P
0 g
s
.3196 .67676 m .31452 .69398 L .33448 .70812 L p .707 .577 .707 r
F P
0 g
s
.293 .54408 m .29341 .5997 L .306 .60742 L p .707 .577 .707 r
F P
0 g
s
.48692 .54619 m .48732 .60182 L .4944 .59349 L p .707 .577 .707 r
F P
0 g
s
.4944 .59349 m .494 .53787 L .48692 .54619 L p .707 .577 .707 r
F P
0 g
s
.69549 .66905 m .69041 .68627 L .66691 .688 L p .707 .577 .707 r
F P
0 g
s
.71041 .60387 m .71 .54825 L .74184 .54726 L p .707 .577 .707 r
F P
0 g
s
.71 .54825 m .71041 .60387 L .68103 .60741 L p .707 .577 .707 r
F P
0 g
s
.74184 .54726 m .74224 .60289 L .71041 .60387 L p .707 .577 .707 r
F P
0 g
s
.31314 .67136 m .31167 .63418 L .2991 .6272 L p .707 .577 .707 r
F P
0 g
s
.68819 .67032 m .68672 .63314 L .71608 .62886 L p .707 .577 .707 r
F P
0 g
s
.29341 .5997 m .293 .54408 L .29011 .53564 L p .707 .577 .707 r
F P
0 g
s
.2991 .6272 m .30057 .66438 L .31314 .67136 L p .707 .577 .707 r
F P
0 g
s
.31452 .69398 m .3196 .67676 L .30787 .66277 L p .707 .577 .707 r
F P
0 g
s
.69041 .68627 m .69549 .66905 L .72401 .67177 L p .707 .577 .707 r
F P
0 g
s
.77904 .6276 m .78051 .66478 L .74936 .66413 L p .707 .577 .707 r
F P
0 g
s
.74936 .66413 m .7479 .62695 L .77904 .6276 L p .707 .577 .707 r
F P
0 g
s
.47852 .72214 m .47344 .73936 L .48962 .73334 L p .707 .577 .707 r
F P
0 g
s
.48962 .73334 m .4947 .71612 L .47852 .72214 L p .707 .577 .707 r
F P
0 g
s
.81096 .70202 m .80588 .71924 L .77963 .70632 L p .707 .577 .707 r
F P
0 g
s
.77963 .70632 m .78471 .68911 L .81096 .70202 L p .707 .577 .707 r
F P
0 g
s
.71608 .62886 m .71755 .66604 L .68819 .67032 L p .707 .577 .707 r
F P
0 g
s
.49287 .62332 m .49434 .6605 L .50143 .65233 L p .707 .577 .707 r
F P
0 g
s
.50143 .65233 m .49996 .61515 L .49287 .62332 L p .707 .577 .707 r
F P
0 g
s
.71755 .66604 m .71608 .62886 L .7479 .62695 L p .707 .577 .707 r
F P
0 g
s
.30787 .66277 m .30279 .67999 L .31452 .69398 L p .707 .577 .707 r
F P
0 g
s
.72401 .67177 m .71893 .68899 L .69041 .68627 L p .707 .577 .707 r
F P
0 g
s
.7479 .62695 m .74936 .66413 L .71755 .66604 L p .707 .577 .707 r
F P
0 g
s
.29011 .53564 m .29051 .59127 L .29341 .5997 L p .707 .577 .707 r
F P
0 g
s
.71893 .68899 m .72401 .67177 L .75475 .67868 L p .707 .577 .707 r
F P
0 g
s
.494 .53787 m .4944 .59349 L .49151 .58505 L p .707 .577 .707 r
F P
0 g
s
.49151 .58505 m .4911 .52943 L .494 .53787 L p .707 .577 .707 r
F P
0 g
s
.78471 .68911 m .77963 .70632 L .74967 .6959 L p .707 .577 .707 r
F P
0 g
s
.74967 .6959 m .75475 .67868 L .78471 .68911 L p .707 .577 .707 r
F P
0 g
s
.30057 .66438 m .2991 .6272 L .29621 .61923 L p .707 .577 .707 r
F P
0 g
s
.75475 .67868 m .74967 .6959 L .71893 .68899 L p .707 .577 .707 r
F P
0 g
s
.30279 .67999 m .30787 .66277 L .30553 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29621 .61923 m .29768 .65641 L .30057 .66438 L p .707 .577 .707 r
F P
0 g
s
.29051 .59127 m .29011 .53564 L .29719 .52731 L p .707 .577 .707 r
F P
0 g
s
.4947 .71612 m .48962 .73334 L .49689 .72363 L p .707 .577 .707 r
F P
0 g
s
.49689 .72363 m .50197 .70641 L .4947 .71612 L p .707 .577 .707 r
F P
0 g
s
.30553 .65031 m .30045 .66753 L .30279 .67999 L p .707 .577 .707 r
F P
0 g
s
.49996 .61515 m .50143 .65233 L .49854 .64437 L p .707 .577 .707 r
F P
0 g
s
.49854 .64437 m .49708 .60719 L .49996 .61515 L p .707 .577 .707 r
F P
0 g
s
.29719 .52731 m .29759 .58294 L .29051 .59127 L p .707 .577 .707 r
F P
0 g
s
.4911 .52943 m .49151 .58505 L .47892 .57733 L p .707 .577 .707 r
F P
0 g
s
.47892 .57733 m .47851 .52171 L .4911 .52943 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29768 .65641 m .29621 .61923 L .3033 .61106 L p .707 .577 .707 r
F P
0 g
s
.30045 .66753 m .30553 .65031 L .31281 .6406 L p .707 .577 .707 r
F P
0 g
s
.29759 .58294 m .29719 .52731 L .31356 .51991 L p .707 .577 .707 r
F P
0 g
s
.50197 .70641 m .49689 .72363 L .49455 .71117 L p .707 .577 .707 r
F P
0 g
s
.49455 .71117 m .49963 .69395 L .50197 .70641 L p .707 .577 .707 r
F P
0 g
s
.3033 .61106 m .30477 .64824 L .29768 .65641 L p .707 .577 .707 r
F P
0 g
s
.31281 .6406 m .30773 .65782 L .30045 .66753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49708 .60719 m .49854 .64437 L .48597 .63738 L p .707 .577 .707 r
F P
0 g
s
.48597 .63738 m .4845 .6002 L .49708 .60719 L p .707 .577 .707 r
F P
0 g
s
.31356 .51991 m .31396 .57553 L .29759 .58294 L p .707 .577 .707 r
F P
0 g
s
.47851 .52171 m .47892 .57733 L .45786 .57109 L p .707 .577 .707 r
F P
0 g
s
.45786 .57109 m .45746 .51546 L .47851 .52171 L p .707 .577 .707 r
F P
0 g
s
.30477 .64824 m .3033 .61106 L .31967 .6035 L p .707 .577 .707 r
F P
0 g
s
.30773 .65782 m .31281 .6406 L .32898 .63458 L p .707 .577 .707 r
F P
0 g
s
.31396 .57553 m .31356 .51991 L .33761 .51415 L p .707 .577 .707 r
F P
0 g
s
.49963 .69395 m .49455 .71117 L .48283 .69718 L p .707 .577 .707 r
F P
0 g
s
.48283 .69718 m .48791 .67996 L .49963 .69395 L p .707 .577 .707 r
F P
0 g
s
.31967 .6035 m .32113 .64068 L .30477 .64824 L p .707 .577 .707 r
F P
0 g
s
.32898 .63458 m .3239 .6518 L .30773 .65782 L p .707 .577 .707 r
F P
0 g
s
.4845 .6002 m .48597 .63738 L .46493 .63206 L p .707 .577 .707 r
F P
0 g
s
.46493 .63206 m .46347 .59488 L .4845 .6002 L p .707 .577 .707 r
F P
0 g
s
.45746 .51546 m .45786 .57109 L .4304 .56692 L p .707 .577 .707 r
F P
0 g
s
.4304 .56692 m .43 .5113 L .45746 .51546 L p .707 .577 .707 r
F P
0 g
s
.33761 .51415 m .33802 .56978 L .31396 .57553 L p .707 .577 .707 r
F P
0 g
s
.33802 .56978 m .33761 .51415 L .36699 .51061 L p .707 .577 .707 r
F P
0 g
s
.32113 .64068 m .31967 .6035 L .34371 .59727 L p .707 .577 .707 r
F P
0 g
s
.3239 .6518 m .32898 .63458 L .35248 .63285 L p .707 .577 .707 r
F P
0 g
s
.43 .5113 m .4304 .56692 L .39923 .56525 L p .707 .577 .707 r
F P
0 g
s
.39923 .56525 m .39883 .50963 L .43 .5113 L p .707 .577 .707 r
F P
0 g
s
.48791 .67996 m .48283 .69718 L .46287 .68304 L p .707 .577 .707 r
F P
0 g
s
.46287 .68304 m .46795 .66582 L .48791 .67996 L p .707 .577 .707 r
F P
0 g
s
.34371 .59727 m .34518 .63445 L .32113 .64068 L p .707 .577 .707 r
F P
0 g
s
.46347 .59488 m .46493 .63206 L .4375 .62892 L p .707 .577 .707 r
F P
0 g
s
.4375 .62892 m .43603 .59174 L .46347 .59488 L p .707 .577 .707 r
F P
0 g
s
.3674 .56624 m .36699 .51061 L .39883 .50963 L p .707 .577 .707 r
F P
0 g
s
.36699 .51061 m .3674 .56624 L .33802 .56978 L p .707 .577 .707 r
F P
0 g
s
.35248 .63285 m .3474 .65007 L .3239 .6518 L p .707 .577 .707 r
F P
0 g
s
.39883 .50963 m .39923 .56525 L .3674 .56624 L p .707 .577 .707 r
F P
0 g
s
.34518 .63445 m .34371 .59727 L .37307 .593 L p .707 .577 .707 r
F P
0 g
s
.3474 .65007 m .35248 .63285 L .381 .63557 L p .707 .577 .707 r
F P
0 g
s
.43603 .59174 m .4375 .62892 L .40635 .62827 L p .707 .577 .707 r
F P
0 g
s
.40635 .62827 m .40489 .59109 L .43603 .59174 L p .707 .577 .707 r
F P
0 g
s
.46795 .66582 m .46287 .68304 L .43662 .67012 L p .707 .577 .707 r
F P
0 g
s
.43662 .67012 m .4417 .65291 L .46795 .66582 L p .707 .577 .707 r
F P
0 g
s
.37307 .593 m .37454 .63018 L .34518 .63445 L p .707 .577 .707 r
F P
0 g
s
.37454 .63018 m .37307 .593 L .40489 .59109 L p .707 .577 .707 r
F P
0 g
s
.381 .63557 m .37592 .65279 L .3474 .65007 L p .707 .577 .707 r
F P
0 g
s
.40489 .59109 m .40635 .62827 L .37454 .63018 L p .707 .577 .707 r
F P
0 g
s
.37592 .65279 m .381 .63557 L .41174 .64248 L p .707 .577 .707 r
F P
0 g
s
.4417 .65291 m .43662 .67012 L .40666 .6597 L p .707 .577 .707 r
F P
0 g
s
.40666 .6597 m .41174 .64248 L .4417 .65291 L p .707 .577 .707 r
F P
0 g
s
.41174 .64248 m .40666 .6597 L .37592 .65279 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF009J
EPT00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo2@0015YF00<005YFFUH00UYF20001EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001MOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001HOol50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?OolA0016Ool0
059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`H000=JEP03001JEUYF00IJEP03001J
EUYF009JEPP003ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001BOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000cOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF3P00
0eYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo
00<005YF000015YF00@005YFFUIJEPP000QJEPH000=JEP03001JEUYF00EJEPH000AJEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000015YF001JEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00DWoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002moo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000_Ool0059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEP0001T000EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00
DWoo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH70004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool005=oo`04001JEUYF0005
FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00D0
05YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0000_Ool003eooaX000=JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00=goo1P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH7
0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000dOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P00;Woo000aOol30004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000eYF0P00;Woo000_Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00
FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00:goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<0
05YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP04001JEUYFFUHG0006FUH00`00FUIJEP02FUH3000^Ool002]oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP`000AJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0015YF
00<005YF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP03FUH600000eYF000000090004
FUH00`00FUIJEP08FUH7000015YF001JEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEP0000D000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00H002moo`00:goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00eYF1@001EYF00@005YF0000
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002
FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP04001JEUYFFUH5000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000000eYF00@0
05YFFUIJEPH000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001J
EUYF009JEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF1@000eYF1@001UYF1`001eYF00<005YFFUH01EYF0P00
0UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEPD00003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP03
001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF1`0000AJEP00000000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF008000EJEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool002]oo`03001JEP0000AJEP04001JEUYFFUH80008FUH6
0003FUH00`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP03FUH20003FUH01000FUH0000015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00:goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YF00000P0015YF
00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0000=JEP00FUH01UYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPP00004Ool000000005
Ool>0004FUH01@00FUIJEUYF0000;Goo000[Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0P0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEPL000Mo
o`D000moo`H00003FUH005YF009JEP03001oogoo02]oo`00:goo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH00002
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH01P00FUIJEUYF001JEP@000=JEP04001JEUYFFUH<0009Ool60004FUH01000FUH000000eYF
0P00;7oo000[Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF1@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@000UYF0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00h000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF0000000/Ool002]oo`80
00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEUYFFUH300000eYF001JEP03FUHA0003FUH00`00FUIJEP07FUH30006FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH0
05YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPH000QJEP03001J
EUYF00=JEP03001JEUYF00=JEP<002aoo`00:goo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF
00@005YFFUIJEQL0009JEP03001JEUYF008000AJEP80009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040005FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000/Ool002]oo`8000=J
EP03001JEUYF009JEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF0P000eYF0P000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF0`0015YF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000`000UYF4`001UYF00<005YFFUH01EYF0`000UYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000;7oo000/Ool01@00FUIJEUYF000015YF00<005YF00001@001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEPD0009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP04001JEUYF0002FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
10000UYF00<005YFFUH01eYF10001UYF00<005YFFUH00UYF0P00;Goo000]Ool2000015YF001JEUYF
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00@005YFFUIJ
EP<000AJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000MJEP04001JEUYFFUH20005FUH0
0`00FUIJEP02FUH2000]Ool002moo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00001JEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01000FUIJEUYF0P00;Woo000_Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF0000
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00MJ
EP05001JEUYF001JEP02000`Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000MJEP8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEP00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000QJEPD0039oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001eYF00<005YF00000P00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01000FUIJEP00<goo000]Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000AJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001J
EUYF009JEP80035oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF
100015YF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP<00003FUH005YF009JEQT000Eoo`800003
FUH005YF00EJEP03001oogoo02ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF10002EYF00<005YFFUH0
1@002eYF00<005YFFUH015YF100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P000UYF00@005YFFUIJEP8000AJEP<000Qoo`D000moo`8000IJEP80
02moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2`001Woo3P0015YF0P00
00=JEP00000025YF00<005YFFUH015YF4`000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP03001JEUYF009JEP8000=JEP03001J
EP0000Qoo`D0015oo`03001JEUYF009JEP03001JEP0002moo`00;Goo00<005YF000015YF00<005YF
FUH00eYF4P003goo1`0000=JEP0000000UYF100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF0P001eYF00<005YFFUH00P002Goo1@004Woo0P000UYF00@0
05YFFUH002ioo`00;Goo00<005YF000015YF00<005YF00000`000eYF00<005YFFUH01EYF00<005YF
FUH010002Woo1@001EYF00<005YF00000P000UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH5000:Ool3000EOol2
0004FUH00`00Oomoo`0[Ool002eoo`03001JEP0000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH20004FUH01000FUIJEUYF0P008goo00<0
05YFFUH00UYF00<007ooOol0:goo000]Ool01000FUH005YF0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00D005YF
FUIJEP0000EJEP80029oo`05001JEUYFFUH0000]Ool002eoo`03001JEP00008000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF3@001eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0`0025YF
0P008Goo00D005YF001JEP0002aoo`00;Goo10000eYF4P001eYF00<005YFFUH01EYF0P000UYF00<0
05YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EP0000QJEP04001JEP00000POol200000eYF001oo`0[Ool002eoo`@00003FUH0000000=JEP03001J
EUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP020006FUH01000FUIJEUYF0`007Woo00<005YF
0000;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0025YF00<005YFFUH00P001EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=J
EP<000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP@001Uo
o`<002eoo`00;Woo0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF
00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH0
10004goo0P0000=JEP000000;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH300000eYF001JEP06FUH200001UYF00000000Ool0009JEP03001JEUYF
00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00=JEP03001J
EUYF00<000MJEP03001JEUYF00AJEPH000Qoo`D0009JEP8002ioo`00;Woo00<005YF00000P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0`000goo00@0
05YFFUH000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP@000AJEP03001JEP0000=oo`L000=JEP06001JEUYFFUH007oo0P0015YF
00<005YFFUH01eYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000^Ool002ioo`80009JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001J
EUYF0080009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF00<005YF00001P0015YF
10000eYF0P000Woo0`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000_Ool01P00FUIJEUYF001oo`L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00H000=JEP03001JEUYF009JEP03001oo`00009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP800004FUH005YF0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP0000001Goo10001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00;goo00@005YFFUIJEP<000Io
oaP000Ioo`<000IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000Uoo`@0009JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00000aOol0031oo`04001JEUYF0002FUH00`00Oomoo`0>Ool5000@Ool00`00
FUIJEP04FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000=Ool60004FUH01000FUIJEUYF1@00<goo000`Ool00`00FUH00004
FUH2000>Ool5000AOol20004FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00004goo2000>7oo000aOol20006FUH00`00
Oomoo`0;Ool5000COol01@00FUIJEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000100000=JEP00FUH01EYF00<005YFFUH00UYF0P00E7oo000bOol00`00FUIJEP04FUH3000<
Ool3000EOol30002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00
FUH005YF008000IJEP03001JEUYF009JEP8005Aoo`00<goo0P0015YF00<005YFFUH00P0097oo00@0
05YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH20004FUH01000
FUIJEUYF0P00EGoo000eOol01000FUIJEP001EYF0P008goo00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80009JEP04001JEP00001GOol003Ioo`<000MJ
EP80025oo`03001JEP0000<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00MJEPD0
05Uoo`00>7oo00<005YFFUH01EYF00<005YF00000P007goo0P0000=JEP00Ool00P001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P0000AJEP00000000MJEP04001JEUYF001JOol003Uoo`8000EJEP03001JEUYF009JEP<0
01eoo`03001JEP00009oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH20004FUH00`00FUIJ
EP02FUH2001HOol003]oo`80009JEP03001JEUYF00IJEP@001Uoo`8000Eoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00T0009oo`<00003FUH005YF00EJEP03001oogoo05Eoo`00?Goo0`002EYF00<005YFFUH010004goo
10002Goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
10003goo0P001UYF0P00EWoo000oOol20008FUH00`00FUIJEP04FUH60008Ool50002FUH2000>Ool6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09000AOol00`00
FUIJEP02FUH00`00FUH0001FOol0045oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
0`00FUIJEP02000EOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80004Ool5000BOol20002
FUH01000FUIJEP00EGoo0014Ool300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P007Woo6P002goo1@0057oo0P0015YF00<007ooOol0DWoo0017Ool30007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool20004FUH01000FUIJEUYF0P002Woo0`00
5Woo00<005YFFUH00UYF00<007ooOol0DWoo001:Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUH00000<goo00D005YFFUIJEP0000EJEP80029oo`05001JEUYFFUH0001DOol004iooa<0
03Ioo`<000QJEP80025oo`05001JEP00FUH0001COol009Uoo`03001JEUYF00IJEP04001JEP00000P
Ool200000eYF001oo`1BOol009Yoo`8000IJEP04001JEUYFFUH3000NOol00`00FUH0001COol009ao
o`8000=JEP03001JEUYF00EJEP@001Yoo`8005Aoo`00WWoo0P0000=JEP00FUH01eYF00<005YFFUH0
100057oo1000E7oo002POol30007FUH00`00FUIJEP04FUH60008Ool600000eYF0000001EOol00:=o
o`8000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00EGoo002UOol30000
0eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:Qoo`@000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:aoo`@0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00001HOol00;1oo`H000AJEP04001JEUYFFUH5001JOol00;Io
o`P005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60076 .74981 m .60117 .69427 L .57 .69215 L p .707 .577 .707 r
F P
0 g
s
.60117 .69427 m .60076 .74981 L .6326 .74924 L p .707 .577 .707 r
F P
0 g
s
.6326 .74924 m .633 .6937 L .60117 .69427 L p .707 .577 .707 r
F P
0 g
s
.633 .6937 m .6326 .74924 L .66198 .74603 L p .707 .577 .707 r
F P
0 g
s
.66198 .74603 m .66238 .69049 L .633 .6937 L p .707 .577 .707 r
F P
0 g
s
.56959 .74768 m .57 .69215 L .54254 .68752 L p .707 .577 .707 r
F P
0 g
s
.57 .69215 m .56959 .74768 L .60076 .74981 L p .707 .577 .707 r
F P
0 g
s
.66238 .69049 m .66198 .74603 L .68603 .74048 L p .707 .577 .707 r
F P
0 g
s
.68603 .74048 m .68644 .68494 L .66238 .69049 L p .707 .577 .707 r
F P
0 g
s
.54254 .68752 m .54214 .74306 L .56959 .74768 L p .707 .577 .707 r
F P
0 g
s
.54214 .74306 m .54254 .68752 L .52148 .68086 L p .707 .577 .707 r
F P
0 g
s
.59364 .8113 m .59511 .77444 L .56396 .77129 L p .707 .577 .707 r
F P
0 g
s
.59511 .77444 m .59364 .8113 L .62546 .81165 L p .707 .577 .707 r
F P
0 g
s
.62546 .81165 m .62692 .77478 L .59511 .77444 L p .707 .577 .707 r
F P
0 g
s
.62692 .77478 m .62546 .81165 L .65482 .80916 L p .707 .577 .707 r
F P
0 g
s
.65482 .80916 m .65629 .7723 L .62692 .77478 L p .707 .577 .707 r
F P
0 g
s
.5625 .80815 m .56396 .77129 L .53653 .76565 L p .707 .577 .707 r
F P
0 g
s
.56396 .77129 m .5625 .80815 L .59364 .8113 L p .707 .577 .707 r
F P
0 g
s
.68644 .68494 m .68603 .74048 L .7024 .73315 L p .707 .577 .707 r
F P
0 g
s
.7024 .73315 m .70281 .67761 L .68644 .68494 L p .707 .577 .707 r
F P
0 g
s
.52148 .68086 m .52108 .7364 L .54214 .74306 L p .707 .577 .707 r
F P
0 g
s
.65629 .7723 m .65482 .80916 L .67886 .80409 L p .707 .577 .707 r
F P
0 g
s
.67886 .80409 m .68033 .76722 L .65629 .7723 L p .707 .577 .707 r
F P
0 g
s
.59334 .84267 m .58826 .82436 L .5583 .83124 L p .707 .577 .707 r
F P
0 g
s
.58826 .82436 m .59334 .84267 L .62408 .83397 L p .707 .577 .707 r
F P
0 g
s
.62408 .83397 m .619 .81566 L .58826 .82436 L p .707 .577 .707 r
F P
0 g
s
.53653 .76565 m .53506 .80251 L .5625 .80815 L p .707 .577 .707 r
F P
0 g
s
.619 .81566 m .62408 .83397 L .6526 .8243 L p .707 .577 .707 r
F P
0 g
s
.6526 .8243 m .64752 .80599 L .619 .81566 L p .707 .577 .707 r
F P
0 g
s
.5583 .83124 m .56338 .84955 L .59334 .84267 L p .707 .577 .707 r
F P
0 g
s
.52108 .7364 m .52148 .68086 L .50889 .67282 L p .707 .577 .707 r
F P
0 g
s
.53506 .80251 m .53653 .76565 L .5155 .75807 L p .707 .577 .707 r
F P
0 g
s
.56338 .84955 m .5583 .83124 L .53205 .83563 L p .707 .577 .707 r
F P
0 g
s
.53205 .83563 m .53713 .85394 L .56338 .84955 L p .707 .577 .707 r
F P
0 g
s
.64752 .80599 m .6526 .8243 L .67609 .81461 L p .707 .577 .707 r
F P
0 g
s
.67609 .81461 m .67101 .7963 L .64752 .80599 L p .707 .577 .707 r
F P
0 g
s
.5155 .75807 m .51403 .79493 L .53506 .80251 L p .707 .577 .707 r
F P
0 g
s
.68033 .76722 m .67886 .80409 L .69523 .79692 L p .707 .577 .707 r
F P
0 g
s
.69523 .79692 m .6967 .76005 L .68033 .76722 L p .707 .577 .707 r
F P
0 g
s
.50889 .67282 m .50849 .72835 L .52108 .7364 L p .707 .577 .707 r
F P
0 g
s
.70281 .67761 m .7024 .73315 L .70949 .72475 L p .707 .577 .707 r
F P
0 g
s
.70949 .72475 m .70989 .66921 L .70281 .67761 L p .707 .577 .707 r
F P
0 g
s
.53713 .85394 m .53205 .83563 L .51209 .8371 L p .707 .577 .707 r
F P
0 g
s
.51403 .79493 m .5155 .75807 L .50292 .74929 L p .707 .577 .707 r
F P
0 g
s
.51209 .8371 m .51717 .85541 L .53713 .85394 L p .707 .577 .707 r
F P
0 g
s
.67101 .7963 m .67609 .81461 L .69227 .80585 L p .707 .577 .707 r
F P
0 g
s
.69227 .80585 m .68719 .78755 L .67101 .7963 L p .707 .577 .707 r
F P
0 g
s
.50849 .72835 m .50889 .67282 L .506 .66417 L p .707 .577 .707 r
F P
0 g
s
.50292 .74929 m .50145 .78616 L .51403 .79493 L p .707 .577 .707 r
F P
0 g
s
.6967 .76005 m .69523 .79692 L .70231 .78835 L p .707 .577 .707 r
F P
0 g
s
.70231 .78835 m .70378 .75149 L .6967 .76005 L p .707 .577 .707 r
F P
0 g
s
.506 .66417 m .50559 .71971 L .50849 .72835 L p .707 .577 .707 r
F P
0 g
s
.70989 .66921 m .70949 .72475 L .70659 .7161 L p .707 .577 .707 r
F P
0 g
s
.70659 .7161 m .70699 .66057 L .70989 .66921 L p .707 .577 .707 r
F P
0 g
s
.51717 .85541 m .51209 .8371 L .50036 .8355 L p .707 .577 .707 r
F P
0 g
s
.50036 .8355 m .50544 .85381 L .51717 .85541 L p .707 .577 .707 r
F P
0 g
s
.50145 .78616 m .50292 .74929 L .50004 .74018 L p .707 .577 .707 r
F P
0 g
s
.68719 .78755 m .69227 .80585 L .69954 .79888 L p .707 .577 .707 r
F P
0 g
s
.69954 .79888 m .69446 .78057 L .68719 .78755 L p .707 .577 .707 r
F P
0 g
s
.49389 .82174 m .48879 .31933 L .44478 .3171 L p .707 .577 .707 r
F P
0 g
s
.50559 .71971 m .506 .66417 L .51308 .65577 L p .707 .577 .707 r
F P
0 g
s
.50004 .74018 m .49857 .77704 L .50145 .78616 L p .707 .577 .707 r
F P
0 g
s
.51308 .65577 m .51268 .7113 L .50559 .71971 L p .707 .577 .707 r
F P
0 g
s
.49857 .77704 m .50004 .74018 L .50712 .73161 L p .707 .577 .707 r
F P
0 g
s
.51268 .7113 m .51308 .65577 L .52945 .64844 L p .707 .577 .707 r
F P
0 g
s
.50712 .73161 m .50566 .76848 L .49857 .77704 L p .707 .577 .707 r
F P
0 g
s
.52945 .64844 m .52905 .70397 L .51268 .7113 L p .707 .577 .707 r
F P
0 g
s
.50566 .76848 m .50712 .73161 L .52349 .72444 L p .707 .577 .707 r
F P
0 g
s
.52349 .72444 m .52202 .76131 L .50566 .76848 L p .707 .577 .707 r
F P
0 g
s
.51038 .84233 m .5053 .82403 L .52148 .81527 L p .707 .577 .707 r
F P
0 g
s
.52202 .76131 m .52349 .72444 L .54753 .71937 L p .707 .577 .707 r
F P
0 g
s
.52148 .81527 m .52656 .83357 L .51038 .84233 L p .707 .577 .707 r
F P
0 g
s
.54753 .71937 m .54606 .75623 L .52202 .76131 L p .707 .577 .707 r
F P
0 g
s
.52656 .83357 m .52148 .81527 L .54497 .80558 L p .707 .577 .707 r
F P
0 g
s
.54497 .80558 m .55005 .82389 L .52656 .83357 L p .707 .577 .707 r
F P
0 g
s
.48879 .31933 m .49389 .82174 L .53883 .82024 L p .707 .577 .707 r
F P
0 g
s
.52905 .70397 m .52945 .64844 L .5535 .64289 L p .707 .577 .707 r
F P
0 g
s
.5535 .64289 m .5531 .69843 L .52905 .70397 L p .707 .577 .707 r
F P
0 g
s
.53883 .82024 m .53373 .31783 L .48879 .31933 L p .707 .577 .707 r
F P
0 g
s
.5531 .69843 m .5535 .64289 L .58288 .63968 L p .707 .577 .707 r
F P
0 g
s
.58288 .63968 m .58248 .69521 L .5531 .69843 L p .707 .577 .707 r
F P
0 g
s
.54606 .75623 m .54753 .71937 L .5769 .71688 L p .707 .577 .707 r
F P
0 g
s
.5769 .71688 m .57543 .75375 L .54606 .75623 L p .707 .577 .707 r
F P
0 g
s
.55005 .82389 m .54497 .80558 L .57349 .79591 L p .707 .577 .707 r
F P
0 g
s
.57349 .79591 m .57857 .81422 L .55005 .82389 L p .707 .577 .707 r
F P
0 g
s
.57857 .81422 m .57349 .79591 L .60423 .78721 L p .707 .577 .707 r
F P
0 g
s
.60423 .78721 m .60931 .80552 L .57857 .81422 L p .707 .577 .707 r
F P
0 g
s
.53373 .31783 m .53883 .82024 L .58031 .81514 L p .707 .577 .707 r
F P
0 g
s
.57543 .75375 m .5769 .71688 L .60871 .71723 L p .707 .577 .707 r
F P
0 g
s
.60871 .71723 m .60724 .7541 L .57543 .75375 L p .707 .577 .707 r
F P
0 g
s
.58031 .81514 m .57521 .31273 L .53373 .31783 L p .707 .577 .707 r
F P
0 g
s
.44988 .81951 m .44478 .3171 L .40602 .31136 L p .707 .577 .707 r
F P
0 g
s
.44478 .3171 m .44988 .81951 L .49389 .82174 L p .707 .577 .707 r
F P
0 g
s
.70378 .75149 m .70231 .78835 L .69943 .77924 L p .707 .577 .707 r
F P
0 g
s
.69943 .77924 m .7009 .74237 L .70378 .75149 L p .707 .577 .707 r
F P
0 g
s
.70699 .66057 m .70659 .7161 L .694 .70805 L p .707 .577 .707 r
F P
0 g
s
.694 .70805 m .6944 .65252 L .70699 .66057 L p .707 .577 .707 r
F P
0 g
s
.50544 .85381 m .50036 .8355 L .49802 .831 L p .707 .577 .707 r
F P
0 g
s
.58248 .69521 m .58288 .63968 L .61472 .63911 L p .707 .577 .707 r
F P
0 g
s
.61472 .63911 m .61431 .69464 L .58248 .69521 L p .707 .577 .707 r
F P
0 g
s
.63986 .72038 m .63839 .75724 L .60724 .7541 L p .707 .577 .707 r
F P
0 g
s
.60724 .7541 m .60871 .71723 L .63986 .72038 L p .707 .577 .707 r
F P
0 g
s
.63419 .78033 m .63927 .79864 L .60931 .80552 L p .707 .577 .707 r
F P
0 g
s
.60931 .80552 m .60423 .78721 L .63419 .78033 L p .707 .577 .707 r
F P
0 g
s
.57521 .31273 m .58031 .81514 L .61427 .80696 L p .707 .577 .707 r
F P
0 g
s
.61427 .80696 m .60917 .30455 L .57521 .31273 L p .707 .577 .707 r
F P
0 g
s
.49802 .831 m .5031 .84931 L .50544 .85381 L p .707 .577 .707 r
F P
0 g
s
.69446 .78057 m .69954 .79888 L .69721 .79437 L p .707 .577 .707 r
F P
0 g
s
.69721 .79437 m .69212 .77607 L .69446 .78057 L p .707 .577 .707 r
F P
0 g
s
.25776 .71382 m .25816 .65828 L .22699 .65615 L p .707 .577 .707 r
F P
0 g
s
.25816 .65828 m .25776 .71382 L .28959 .71325 L p .707 .577 .707 r
F P
0 g
s
.28959 .71325 m .28999 .65771 L .25816 .65828 L p .707 .577 .707 r
F P
0 g
s
.28999 .65771 m .28959 .71325 L .31897 .71003 L p .707 .577 .707 r
F P
0 g
s
.31897 .71003 m .31938 .65449 L .28999 .65771 L p .707 .577 .707 r
F P
0 g
s
.41112 .81376 m .40602 .31136 L .3763 .30265 L p .707 .577 .707 r
F P
0 g
s
.40602 .31136 m .41112 .81376 L .44988 .81951 L p .707 .577 .707 r
F P
0 g
s
.22658 .71169 m .22699 .65615 L .19953 .65153 L p .707 .577 .707 r
F P
0 g
s
.22699 .65615 m .22658 .71169 L .25776 .71382 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31938 .65449 m .31897 .71003 L .34302 .70449 L p .707 .577 .707 r
F P
0 g
s
.34302 .70449 m .34343 .64895 L .31938 .65449 L p .707 .577 .707 r
F P
0 g
s
.7009 .74237 m .69943 .77924 L .68686 .77046 L p .707 .577 .707 r
F P
0 g
s
.68686 .77046 m .68832 .7336 L .7009 .74237 L p .707 .577 .707 r
F P
0 g
s
.6944 .65252 m .694 .70805 L .67294 .70139 L p .707 .577 .707 r
F P
0 g
s
.67294 .70139 m .67335 .64586 L .6944 .65252 L p .707 .577 .707 r
F P
0 g
s
.64589 .64124 m .64549 .69677 L .61431 .69464 L p .707 .577 .707 r
F P
0 g
s
.61431 .69464 m .61472 .63911 L .64589 .64124 L p .707 .577 .707 r
F P
0 g
s
.63927 .79864 m .63419 .78033 L .66044 .77594 L p .707 .577 .707 r
F P
0 g
s
.60917 .30455 m .61427 .80696 L .63738 .79648 L p .707 .577 .707 r
F P
0 g
s
.63738 .79648 m .63228 .29408 L .60917 .30455 L p .707 .577 .707 r
F P
0 g
s
.5031 .84931 m .49802 .831 L .5053 .82403 L p .707 .577 .707 r
F P
0 g
s
.19953 .65153 m .19913 .70707 L .22658 .71169 L p .707 .577 .707 r
F P
0 g
s
.19913 .70707 m .19953 .65153 L .17848 .64487 L p .707 .577 .707 r
F P
0 g
s
.25063 .77353 m .2521 .73667 L .22095 .73352 L p .707 .577 .707 r
F P
0 g
s
.2521 .73667 m .25063 .77353 L .28245 .77388 L p .707 .577 .707 r
F P
0 g
s
.28245 .77388 m .28392 .73702 L .2521 .73667 L p .707 .577 .707 r
F P
0 g
s
.5053 .82403 m .51038 .84233 L .5031 .84931 L p .707 .577 .707 r
F P
0 g
s
.28392 .73702 m .28245 .77388 L .31181 .7714 L p .707 .577 .707 r
F P
0 g
s
.31181 .7714 m .31328 .73453 L .28392 .73702 L p .707 .577 .707 r
F P
0 g
s
.69212 .77607 m .69721 .79437 L .68548 .79278 L p .707 .577 .707 r
F P
0 g
s
.68548 .79278 m .6804 .77447 L .69212 .77607 L p .707 .577 .707 r
F P
0 g
s
.21949 .77039 m .22095 .73352 L .19352 .72788 L p .707 .577 .707 r
F P
0 g
s
.22095 .73352 m .21949 .77039 L .25063 .77353 L p .707 .577 .707 r
F P
0 g
s
.34343 .64895 m .34302 .70449 L .35939 .69715 L p .707 .577 .707 r
F P
0 g
s
.35939 .69715 m .3598 .64162 L .34343 .64895 L p .707 .577 .707 r
F P
0 g
s
.3814 .80506 m .3763 .30265 L .35852 .29185 L p .707 .577 .707 r
F P
0 g
s
.3763 .30265 m .3814 .80506 L .41112 .81376 L p .707 .577 .707 r
F P
0 g
s
.17848 .64487 m .17807 .7004 L .19913 .70707 L p .707 .577 .707 r
F P
0 g
s
.31328 .73453 m .31181 .7714 L .33585 .76632 L p .707 .577 .707 r
F P
0 g
s
.33585 .76632 m .33732 .72945 L .31328 .73453 L p .707 .577 .707 r
F P
0 g
s
.25033 .80523 m .24525 .78693 L .21529 .79381 L p .707 .577 .707 r
F P
0 g
s
.24525 .78693 m .25033 .80523 L .28107 .79653 L p .707 .577 .707 r
F P
0 g
s
.28107 .79653 m .27599 .77823 L .24525 .78693 L p .707 .577 .707 r
F P
0 g
s
.67335 .64586 m .67294 .70139 L .64549 .69677 L p .707 .577 .707 r
F P
0 g
s
.64549 .69677 m .64589 .64124 L .67335 .64586 L p .707 .577 .707 r
F P
0 g
s
.19352 .72788 m .19205 .76475 L .21949 .77039 L p .707 .577 .707 r
F P
0 g
s
.27599 .77823 m .28107 .79653 L .30959 .78687 L p .707 .577 .707 r
F P
0 g
s
.30959 .78687 m .30451 .76856 L .27599 .77823 L p .707 .577 .707 r
F P
0 g
s
.68832 .7336 m .68686 .77046 L .66582 .76288 L p .707 .577 .707 r
F P
0 g
s
.66582 .76288 m .66729 .72602 L .68832 .7336 L p .707 .577 .707 r
F P
0 g
s
.21529 .79381 m .22037 .81212 L .25033 .80523 L p .707 .577 .707 r
F P
0 g
s
.17807 .7004 m .17848 .64487 L .16588 .63682 L p .707 .577 .707 r
F P
0 g
s
.19205 .76475 m .19352 .72788 L .17249 .7203 L p .707 .577 .707 r
F P
0 g
s
.22037 .81212 m .21529 .79381 L .18904 .7982 L p .707 .577 .707 r
F P
0 g
s
.18904 .7982 m .19412 .81651 L .22037 .81212 L p .707 .577 .707 r
F P
0 g
s
.30451 .76856 m .30959 .78687 L .33308 .77718 L p .707 .577 .707 r
F P
0 g
s
.33308 .77718 m .328 .75887 L .30451 .76856 L p .707 .577 .707 r
F P
0 g
s
.17249 .7203 m .17102 .75717 L .19205 .76475 L p .707 .577 .707 r
F P
0 g
s
.6804 .77447 m .68548 .79278 L .66552 .79425 L p .707 .577 .707 r
F P
0 g
s
.66552 .79425 m .66044 .77594 L .6804 .77447 L p .707 .577 .707 r
F P
0 g
s
.66729 .72602 m .66582 .76288 L .63839 .75724 L p .707 .577 .707 r
F P
0 g
s
.63839 .75724 m .63986 .72038 L .66729 .72602 L p .707 .577 .707 r
F P
0 g
s
.63228 .29408 m .63738 .79648 L .64738 .78475 L p .707 .577 .707 r
F P
0 g
s
.64738 .78475 m .64228 .28234 L .63228 .29408 L p .707 .577 .707 r
F P
0 g
s
.33732 .72945 m .33585 .76632 L .35222 .75915 L p .707 .577 .707 r
F P
0 g
s
.35222 .75915 m .35369 .72228 L .33732 .72945 L p .707 .577 .707 r
F P
0 g
s
.16588 .63682 m .16548 .69236 L .17807 .7004 L p .707 .577 .707 r
F P
0 g
s
.3598 .64162 m .35939 .69715 L .36648 .68875 L p .707 .577 .707 r
F P
0 g
s
.36648 .68875 m .36688 .63322 L .3598 .64162 L p .707 .577 .707 r
F P
0 g
s
.19412 .81651 m .18904 .7982 L .16908 .79967 L p .707 .577 .707 r
F P
0 g
s
.17102 .75717 m .17249 .7203 L .15991 .71153 L p .707 .577 .707 r
F P
0 g
s
.16908 .79967 m .17416 .81798 L .19412 .81651 L p .707 .577 .707 r
F P
0 g
s
.328 .75887 m .33308 .77718 L .34926 .76842 L p .707 .577 .707 r
F P
0 g
s
.34926 .76842 m .34418 .75012 L .328 .75887 L p .707 .577 .707 r
F P
0 g
s
.16548 .69236 m .16588 .63682 L .16299 .62817 L p .707 .577 .707 r
F P
0 g
s
.36398 .62457 m .36358 .68011 L .35099 .67206 L p .707 .577 .707 r
F P
0 g
s
.35099 .67206 m .35139 .61652 L .36398 .62457 L p .707 .577 .707 r
F P
0 g
s
.36362 .79425 m .35852 .29185 L .35443 .27999 L p .707 .577 .707 r
F P
0 g
s
.36688 .63322 m .36648 .68875 L .36358 .68011 L p .707 .577 .707 r
F P
0 g
s
.36358 .68011 m .36398 .62457 L .36688 .63322 L p .707 .577 .707 r
F P
0 g
s
.35852 .29185 m .36362 .79425 L .3814 .80506 L p .707 .577 .707 r
F P
0 g
s
.15991 .71153 m .15845 .74839 L .17102 .75717 L p .707 .577 .707 r
F P
0 g
s
.66044 .77594 m .66552 .79425 L .63927 .79864 L p .707 .577 .707 r
F P
0 g
s
.35369 .72228 m .35222 .75915 L .35931 .75059 L p .707 .577 .707 r
F P
0 g
s
.35931 .75059 m .36077 .71372 L .35369 .72228 L p .707 .577 .707 r
F P
0 g
s
.16299 .62817 m .16258 .68371 L .16548 .69236 L p .707 .577 .707 r
F P
0 g
s
.17416 .81798 m .16908 .79967 L .15735 .79807 L p .707 .577 .707 r
F P
0 g
s
.15735 .79807 m .16243 .81638 L .17416 .81798 L p .707 .577 .707 r
F P
0 g
s
.15845 .74839 m .15991 .71153 L .15703 .70241 L p .707 .577 .707 r
F P
0 g
s
.34418 .75012 m .34926 .76842 L .35654 .76145 L p .707 .577 .707 r
F P
0 g
s
.35654 .76145 m .35146 .74314 L .34418 .75012 L p .707 .577 .707 r
F P
0 g
s
.64228 .28234 m .64738 .78475 L .64329 .7729 L p .707 .577 .707 r
F P
0 g
s
.64329 .7729 m .63819 .27049 L .64228 .28234 L p .707 .577 .707 r
F P
0 g
s
.16258 .68371 m .16299 .62817 L .17007 .61977 L p .707 .577 .707 r
F P
0 g
s
.15703 .70241 m .15556 .73928 L .15845 .74839 L p .707 .577 .707 r
F P
0 g
s
.36077 .71372 m .35931 .75059 L .35642 .74147 L p .707 .577 .707 r
F P
0 g
s
.35642 .74147 m .35789 .70461 L .36077 .71372 L p .707 .577 .707 r
F P
0 g
s
.35443 .27999 m .35953 .7824 L .36362 .79425 L p .707 .577 .707 r
F P
0 g
s
.35953 .7824 m .35443 .27999 L .36443 .26826 L p .707 .577 .707 r
F P
0 g
s
.17007 .61977 m .16967 .67531 L .16258 .68371 L p .707 .577 .707 r
F P
0 g
s
.16243 .81638 m .15735 .79807 L .15501 .79357 L p .707 .577 .707 r
F P
0 g
s
.15501 .79357 m .16009 .81188 L .16243 .81638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15556 .73928 m .15703 .70241 L .16411 .69385 L p .707 .577 .707 r
F P
0 g
s
.35146 .74314 m .35654 .76145 L .3542 .75694 L p .707 .577 .707 r
F P
0 g
s
.3542 .75694 m .34912 .73864 L .35146 .74314 L p .707 .577 .707 r
F P
0 g
s
.16967 .67531 m .17007 .61977 L .18644 .61244 L p .707 .577 .707 r
F P
0 g
s
.16411 .69385 m .16265 .73071 L .15556 .73928 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63819 .27049 m .64329 .7729 L .62551 .76209 L p .707 .577 .707 r
F P
0 g
s
.62551 .76209 m .62041 .25968 L .63819 .27049 L p .707 .577 .707 r
F P
0 g
s
.35789 .70461 m .35642 .74147 L .34385 .7327 L p .707 .577 .707 r
F P
0 g
s
.34385 .7327 m .34531 .69583 L .35789 .70461 L p .707 .577 .707 r
F P
0 g
s
.18644 .61244 m .18604 .66798 L .16967 .67531 L p .707 .577 .707 r
F P
0 g
s
.35139 .61652 m .35099 .67206 L .32993 .6654 L p .707 .577 .707 r
F P
0 g
s
.32993 .6654 m .33034 .60986 L .35139 .61652 L p .707 .577 .707 r
F P
0 g
s
.16009 .81188 m .15501 .79357 L .16229 .7866 L p .707 .577 .707 r
F P
0 g
s
.16229 .7866 m .16737 .8049 L .16009 .81188 L p .707 .577 .707 r
F P
0 g
s
.16265 .73071 m .16411 .69385 L .18048 .68668 L p .707 .577 .707 r
F P
0 g
s
.34912 .73864 m .3542 .75694 L .34247 .75535 L p .707 .577 .707 r
F P
0 g
s
.34247 .75535 m .33739 .73704 L .34912 .73864 L p .707 .577 .707 r
F P
0 g
s
.18604 .66798 m .18644 .61244 L .21049 .6069 L p .707 .577 .707 r
F P
0 g
s
.36953 .77067 m .36443 .26826 L .38754 .25778 L p .707 .577 .707 r
F P
0 g
s
.36443 .26826 m .36953 .77067 L .35953 .7824 L p .707 .577 .707 r
F P
0 g
s
.18048 .68668 m .17901 .72354 L .16265 .73071 L p .707 .577 .707 r
F P
0 g
s
.33034 .60986 m .32993 .6654 L .30248 .66078 L p .707 .577 .707 r
F P
0 g
s
.30248 .66078 m .30288 .60524 L .33034 .60986 L p .707 .577 .707 r
F P
0 g
s
.34531 .69583 m .34385 .7327 L .32281 .72512 L p .707 .577 .707 r
F P
0 g
s
.32281 .72512 m .32428 .68825 L .34531 .69583 L p .707 .577 .707 r
F P
0 g
s
.21049 .6069 m .21009 .66243 L .18604 .66798 L p .707 .577 .707 r
F P
0 g
s
.21009 .66243 m .21049 .6069 L .23987 .60368 L p .707 .577 .707 r
F P
0 g
s
.17901 .72354 m .18048 .68668 L .20452 .6816 L p .707 .577 .707 r
F P
0 g
s
.62041 .25968 m .62551 .76209 L .59579 .75339 L p .707 .577 .707 r
F P
0 g
s
.59579 .75339 m .59069 .25098 L .62041 .25968 L p .707 .577 .707 r
F P
0 g
s
.16737 .8049 m .16229 .7866 L .17847 .77784 L p .707 .577 .707 r
F P
0 g
s
.17847 .77784 m .18355 .79614 L .16737 .8049 L p .707 .577 .707 r
F P
0 g
s
.30288 .60524 m .30248 .66078 L .2713 .65865 L p .707 .577 .707 r
F P
0 g
s
.2713 .65865 m .27171 .60311 L .30288 .60524 L p .707 .577 .707 r
F P
0 g
s
.33739 .73704 m .34247 .75535 L .32251 .75682 L p .707 .577 .707 r
F P
0 g
s
.32251 .75682 m .31743 .73851 L .33739 .73704 L p .707 .577 .707 r
F P
0 g
s
.23947 .65922 m .23987 .60368 L .27171 .60311 L p .707 .577 .707 r
F P
0 g
s
.23987 .60368 m .23947 .65922 L .21009 .66243 L p .707 .577 .707 r
F P
0 g
s
.20452 .6816 m .20305 .71847 L .17901 .72354 L p .707 .577 .707 r
F P
0 g
s
.27171 .60311 m .2713 .65865 L .23947 .65922 L p .707 .577 .707 r
F P
0 g
s
.73797 .65777 m .73837 .60224 L .7072 .60011 L p .707 .577 .707 r
F P
0 g
s
.73837 .60224 m .73797 .65777 L .7698 .6572 L p .707 .577 .707 r
F P
0 g
s
.7698 .6572 m .77021 .60167 L .73837 .60224 L p .707 .577 .707 r
F P
0 g
s
.32428 .68825 m .32281 .72512 L .29538 .71948 L p .707 .577 .707 r
F P
0 g
s
.29538 .71948 m .29685 .68261 L .32428 .68825 L p .707 .577 .707 r
F P
0 g
s
.38754 .25778 m .39264 .76019 L .36953 .77067 L p .707 .577 .707 r
F P
0 g
s
.39264 .76019 m .38754 .25778 L .4215 .2496 L p .707 .577 .707 r
F P
0 g
s
.77021 .60167 m .7698 .6572 L .79919 .65399 L p .707 .577 .707 r
F P
0 g
s
.79919 .65399 m .79959 .59845 L .77021 .60167 L p .707 .577 .707 r
F P
0 g
s
.20305 .71847 m .20452 .6816 L .23389 .67912 L p .707 .577 .707 r
F P
0 g
s
.7068 .65564 m .7072 .60011 L .67974 .59549 L p .707 .577 .707 r
F P
0 g
s
.7072 .60011 m .7068 .65564 L .73797 .65777 L p .707 .577 .707 r
F P
0 g
s
.18355 .79614 m .17847 .77784 L .20196 .76815 L p .707 .577 .707 r
F P
0 g
s
.79959 .59845 m .79919 .65399 L .82324 .64844 L p .707 .577 .707 r
F P
0 g
s
.82324 .64844 m .82364 .59291 L .79959 .59845 L p .707 .577 .707 r
F P
0 g
s
.20196 .76815 m .20704 .78646 L .18355 .79614 L p .707 .577 .707 r
F P
0 g
s
.29685 .68261 m .29538 .71948 L .26423 .71633 L p .707 .577 .707 r
F P
0 g
s
.26423 .71633 m .2657 .67946 L .29685 .68261 L p .707 .577 .707 r
F P
0 g
s
.31743 .73851 m .32251 .75682 L .29626 .76121 L p .707 .577 .707 r
F P
0 g
s
.29626 .76121 m .29118 .7429 L .31743 .73851 L p .707 .577 .707 r
F P
0 g
s
.23389 .67912 m .23242 .71598 L .20305 .71847 L p .707 .577 .707 r
F P
0 g
s
.23242 .71598 m .23389 .67912 L .2657 .67946 L p .707 .577 .707 r
F P
0 g
s
.59069 .25098 m .59579 .75339 L .55703 .74764 L p .707 .577 .707 r
F P
0 g
s
.55703 .74764 m .55193 .24523 L .59069 .25098 L p .707 .577 .707 r
F P
0 g
s
.2657 .67946 m .26423 .71633 L .23242 .71598 L p .707 .577 .707 r
F P
0 g
s
.67974 .59549 m .67934 .65102 L .7068 .65564 L p .707 .577 .707 r
F P
0 g
s
.67934 .65102 m .67974 .59549 L .65869 .58883 L p .707 .577 .707 r
F P
0 g
s
.73085 .71926 m .73232 .6824 L .70117 .67925 L p .707 .577 .707 r
F P
0 g
s
.73232 .6824 m .73085 .71926 L .76266 .71961 L p .707 .577 .707 r
F P
0 g
s
.76266 .71961 m .76413 .68275 L .73232 .6824 L p .707 .577 .707 r
F P
0 g
s
.76413 .68275 m .76266 .71961 L .79203 .71713 L p .707 .577 .707 r
F P
0 g
s
.79203 .71713 m .79349 .68026 L .76413 .68275 L p .707 .577 .707 r
F P
0 g
s
.4266 .75201 m .4215 .2496 L .46298 .24451 L p .707 .577 .707 r
F P
0 g
s
.4215 .2496 m .4266 .75201 L .39264 .76019 L p .707 .577 .707 r
F P
0 g
s
.6997 .71612 m .70117 .67925 L .67373 .67361 L p .707 .577 .707 r
F P
0 g
s
.70117 .67925 m .6997 .71612 L .73085 .71926 L p .707 .577 .707 r
F P
0 g
s
.20704 .78646 m .20196 .76815 L .23048 .75848 L p .707 .577 .707 r
F P
0 g
s
.23048 .75848 m .23556 .77679 L .20704 .78646 L p .707 .577 .707 r
F P
0 g
s
.29118 .7429 m .29626 .76121 L .2663 .76809 L p .707 .577 .707 r
F P
0 g
s
.2663 .76809 m .26122 .74978 L .29118 .7429 L p .707 .577 .707 r
F P
0 g
s
.82364 .59291 m .82324 .64844 L .83961 .64111 L p .707 .577 .707 r
F P
0 g
s
.83961 .64111 m .84001 .58557 L .82364 .59291 L p .707 .577 .707 r
F P
0 g
s
.65869 .58883 m .65829 .64436 L .67934 .65102 L p .707 .577 .707 r
F P
0 g
s
.79349 .68026 m .79203 .71713 L .81607 .71205 L p .707 .577 .707 r
F P
0 g
s
.81607 .71205 m .81753 .67518 L .79349 .68026 L p .707 .577 .707 r
F P
0 g
s
.55193 .24523 m .55703 .74764 L .51302 .74541 L p .707 .577 .707 r
F P
0 g
s
.51302 .74541 m .50792 .243 L .55193 .24523 L p .707 .577 .707 r
F P
0 g
s
.73054 .75063 m .72546 .73232 L .6955 .7392 L p .707 .577 .707 r
F P
0 g
s
.72546 .73232 m .73054 .75063 L .76129 .74193 L p .707 .577 .707 r
F P
0 g
s
.76129 .74193 m .75621 .72362 L .72546 .73232 L p .707 .577 .707 r
F P
0 g
s
.67373 .67361 m .67227 .71048 L .6997 .71612 L p .707 .577 .707 r
F P
0 g
s
.23556 .77679 m .23048 .75848 L .26122 .74978 L p .707 .577 .707 r
F P
0 g
s
.75621 .72362 m .76129 .74193 L .7898 .73226 L p .707 .577 .707 r
F P
0 g
s
.7898 .73226 m .78472 .71395 L .75621 .72362 L p .707 .577 .707 r
F P
0 g
s
.26122 .74978 m .2663 .76809 L .23556 .77679 L p .707 .577 .707 r
F P
0 g
s
.6955 .7392 m .70058 .75751 L .73054 .75063 L p .707 .577 .707 r
F P
0 g
s
.65829 .64436 m .65869 .58883 L .6461 .58078 L p .707 .577 .707 r
F P
0 g
s
.67227 .71048 m .67373 .67361 L .6527 .66603 L p .707 .577 .707 r
F P
0 g
s
.46808 .74691 m .46298 .24451 L .50792 .243 L p .707 .577 .707 r
F P
0 g
s
.46298 .24451 m .46808 .74691 L .4266 .75201 L p .707 .577 .707 r
F P
0 g
s
.70058 .75751 m .6955 .7392 L .66925 .74359 L p .707 .577 .707 r
F P
0 g
s
.50792 .243 m .51302 .74541 L .46808 .74691 L p .707 .577 .707 r
F P
0 g
s
.66925 .74359 m .67434 .7619 L .70058 .75751 L p .707 .577 .707 r
F P
0 g
s
.78472 .71395 m .7898 .73226 L .8133 .72257 L p .707 .577 .707 r
F P
0 g
s
.8133 .72257 m .80822 .70427 L .78472 .71395 L p .707 .577 .707 r
F P
0 g
s
.6527 .66603 m .65123 .7029 L .67227 .71048 L p .707 .577 .707 r
F P
0 g
s
.81753 .67518 m .81607 .71205 L .83243 .70488 L p .707 .577 .707 r
F P
0 g
s
.83243 .70488 m .8339 .66801 L .81753 .67518 L p .707 .577 .707 r
F P
0 g
s
.6461 .58078 m .64569 .63631 L .65829 .64436 L p .707 .577 .707 r
F P
0 g
s
.84001 .58557 m .83961 .64111 L .84669 .63271 L p .707 .577 .707 r
F P
0 g
s
.84669 .63271 m .84709 .57717 L .84001 .58557 L p .707 .577 .707 r
F P
0 g
s
.67434 .7619 m .66925 .74359 L .64929 .74506 L p .707 .577 .707 r
F P
0 g
s
.65123 .7029 m .6527 .66603 L .64013 .65725 L p .707 .577 .707 r
F P
0 g
s
.64929 .74506 m .65437 .76337 L .67434 .7619 L p .707 .577 .707 r
F P
0 g
s
.80822 .70427 m .8133 .72257 L .82947 .71381 L p .707 .577 .707 r
F P
0 g
s
.82947 .71381 m .82439 .69551 L .80822 .70427 L p .707 .577 .707 r
F P
0 g
s
.64569 .63631 m .6461 .58078 L .6432 .57213 L p .707 .577 .707 r
F P
0 g
s
.64013 .65725 m .63866 .69412 L .65123 .7029 L p .707 .577 .707 r
F P
0 g
s
.8339 .66801 m .83243 .70488 L .83952 .69632 L p .707 .577 .707 r
F P
0 g
s
.83952 .69632 m .84099 .65945 L .8339 .66801 L p .707 .577 .707 r
F P
0 g
s
.6432 .57213 m .6428 .62767 L .64569 .63631 L p .707 .577 .707 r
F P
0 g
s
.84709 .57717 m .84669 .63271 L .84379 .62406 L p .707 .577 .707 r
F P
0 g
s
.84379 .62406 m .8442 .56853 L .84709 .57717 L p .707 .577 .707 r
F P
0 g
s
.65437 .76337 m .64929 .74506 L .63757 .74347 L p .707 .577 .707 r
F P
0 g
s
.63757 .74347 m .64265 .76177 L .65437 .76337 L p .707 .577 .707 r
F P
0 g
s
.63866 .69412 m .64013 .65725 L .63724 .64814 L p .707 .577 .707 r
F P
0 g
s
.82439 .69551 m .82947 .71381 L .83675 .70684 L p .707 .577 .707 r
F P
0 g
s
.83675 .70684 m .83167 .68853 L .82439 .69551 L p .707 .577 .707 r
F P
0 g
s
.6428 .62767 m .6432 .57213 L .65028 .56373 L p .707 .577 .707 r
F P
0 g
s
.63724 .64814 m .63577 .685 L .63866 .69412 L p .707 .577 .707 r
F P
0 g
s
.84099 .65945 m .83952 .69632 L .83663 .6872 L p .707 .577 .707 r
F P
0 g
s
.83663 .6872 m .8381 .65034 L .84099 .65945 L p .707 .577 .707 r
F P
0 g
s
.65028 .56373 m .64988 .61927 L .6428 .62767 L p .707 .577 .707 r
F P
0 g
s
.8442 .56853 m .84379 .62406 L .8312 .61602 L p .707 .577 .707 r
F P
0 g
s
.8312 .61602 m .83161 .56048 L .8442 .56853 L p .707 .577 .707 r
F P
0 g
s
.64265 .76177 m .63757 .74347 L .63523 .73896 L p .707 .577 .707 r
F P
0 g
s
.63523 .73896 m .64031 .75727 L .64265 .76177 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63577 .685 m .63724 .64814 L .64433 .63958 L p .707 .577 .707 r
F P
0 g
s
.83167 .68853 m .83675 .70684 L .83441 .70234 L p .707 .577 .707 r
F P
0 g
s
.83441 .70234 m .82933 .68403 L .83167 .68853 L p .707 .577 .707 r
F P
0 g
s
.39496 .62178 m .39536 .56624 L .36419 .56411 L p .707 .577 .707 r
F P
0 g
s
.39536 .56624 m .39496 .62178 L .42679 .62121 L p .707 .577 .707 r
F P
0 g
s
.42679 .62121 m .4272 .56567 L .39536 .56624 L p .707 .577 .707 r
F P
0 g
s
.64988 .61927 m .65028 .56373 L .66665 .5564 L p .707 .577 .707 r
F P
0 g
s
.4272 .56567 m .42679 .62121 L .45618 .61799 L p .707 .577 .707 r
F P
0 g
s
.45618 .61799 m .45658 .56245 L .4272 .56567 L p .707 .577 .707 r
F P
0 g
s
.64433 .63958 m .64286 .67644 L .63577 .685 L p .707 .577 .707 r
F P
0 g
s
.36379 .61965 m .36419 .56411 L .33673 .55949 L p .707 .577 .707 r
F P
0 g
s
.36419 .56411 m .36379 .61965 L .39496 .62178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45658 .56245 m .45618 .61799 L .48023 .61245 L p .707 .577 .707 r
F P
0 g
s
.48023 .61245 m .48063 .55691 L .45658 .56245 L p .707 .577 .707 r
F P
0 g
s
.8381 .65034 m .83663 .6872 L .82406 .67842 L p .707 .577 .707 r
F P
0 g
s
.82406 .67842 m .82553 .64156 L .8381 .65034 L p .707 .577 .707 r
F P
0 g
s
.66665 .5564 m .66625 .61193 L .64988 .61927 L p .707 .577 .707 r
F P
0 g
s
.83161 .56048 m .8312 .61602 L .81015 .60936 L p .707 .577 .707 r
F P
0 g
s
.81015 .60936 m .81055 .55382 L .83161 .56048 L p .707 .577 .707 r
F P
0 g
s
.64031 .75727 m .63523 .73896 L .6425 .73199 L p .707 .577 .707 r
F P
0 g
s
.33673 .55949 m .33633 .61503 L .36379 .61965 L p .707 .577 .707 r
F P
0 g
s
.33633 .61503 m .33673 .55949 L .31568 .55283 L p .707 .577 .707 r
F P
0 g
s
.38784 .6815 m .38931 .64463 L .35816 .64148 L p .707 .577 .707 r
F P
0 g
s
.38931 .64463 m .38784 .6815 L .41965 .68184 L p .707 .577 .707 r
F P
0 g
s
.41965 .68184 m .42112 .64498 L .38931 .64463 L p .707 .577 .707 r
F P
0 g
s
.6425 .73199 m .64758 .75029 L .64031 .75727 L p .707 .577 .707 r
F P
0 g
s
.64286 .67644 m .64433 .63958 L .66069 .63241 L p .707 .577 .707 r
F P
0 g
s
.42112 .64498 m .41965 .68184 L .44902 .67936 L p .707 .577 .707 r
F P
0 g
s
.44902 .67936 m .45048 .64249 L .42112 .64498 L p .707 .577 .707 r
F P
0 g
s
.82933 .68403 m .83441 .70234 L .82268 .70074 L p .707 .577 .707 r
F P
0 g
s
.82268 .70074 m .8176 .68243 L .82933 .68403 L p .707 .577 .707 r
F P
0 g
s
.66625 .61193 m .66665 .5564 L .69071 .55085 L p .707 .577 .707 r
F P
0 g
s
.35669 .67835 m .35816 .64148 L .33072 .63584 L p .707 .577 .707 r
F P
0 g
s
.35816 .64148 m .35669 .67835 L .38784 .6815 L p .707 .577 .707 r
F P
0 g
s
.48063 .55691 m .48023 .61245 L .4966 .60512 L p .707 .577 .707 r
F P
0 g
s
.4966 .60512 m .497 .54958 L .48063 .55691 L p .707 .577 .707 r
F P
0 g
s
.66069 .63241 m .65923 .66927 L .64286 .67644 L p .707 .577 .707 r
F P
0 g
s
.31568 .55283 m .31527 .60837 L .33633 .61503 L p .707 .577 .707 r
F P
0 g
s
.45048 .64249 m .44902 .67936 L .47306 .67428 L p .707 .577 .707 r
F P
0 g
s
.47306 .67428 m .47452 .63742 L .45048 .64249 L p .707 .577 .707 r
F P
0 g
s
.38753 .7132 m .38245 .69489 L .35249 .70177 L p .707 .577 .707 r
F P
0 g
s
.38245 .69489 m .38753 .7132 L .41828 .7045 L p .707 .577 .707 r
F P
0 g
s
.41828 .7045 m .4132 .68619 L .38245 .69489 L p .707 .577 .707 r
F P
0 g
s
.81055 .55382 m .81015 .60936 L .78269 .60473 L p .707 .577 .707 r
F P
0 g
s
.78269 .60473 m .78309 .5492 L .81055 .55382 L p .707 .577 .707 r
F P
0 g
s
.33072 .63584 m .32926 .67271 L .35669 .67835 L p .707 .577 .707 r
F P
0 g
s
.4132 .68619 m .41828 .7045 L .44679 .69483 L p .707 .577 .707 r
F P
0 g
s
.44679 .69483 m .44171 .67652 L .4132 .68619 L p .707 .577 .707 r
F P
0 g
s
.82553 .64156 m .82406 .67842 L .80303 .67084 L p .707 .577 .707 r
F P
0 g
s
.80303 .67084 m .80449 .63398 L .82553 .64156 L p .707 .577 .707 r
F P
0 g
s
.35249 .70177 m .35757 .72008 L .38753 .7132 L p .707 .577 .707 r
F P
0 g
s
.69071 .55085 m .6903 .60639 L .66625 .61193 L p .707 .577 .707 r
F P
0 g
s
.31527 .60837 m .31568 .55283 L .30309 .54478 L p .707 .577 .707 r
F P
0 g
s
.32926 .67271 m .33072 .63584 L .30969 .62826 L p .707 .577 .707 r
F P
0 g
s
.6903 .60639 m .69071 .55085 L .72009 .54764 L p .707 .577 .707 r
F P
0 g
s
.35757 .72008 m .35249 .70177 L .32624 .70616 L p .707 .577 .707 r
F P
0 g
s
.64758 .75029 m .6425 .73199 L .65868 .72323 L p .707 .577 .707 r
F P
0 g
s
.65923 .66927 m .66069 .63241 L .68474 .62733 L p .707 .577 .707 r
F P
0 g
s
.32624 .70616 m .33132 .72447 L .35757 .72008 L p .707 .577 .707 r
F P
0 g
s
.44171 .67652 m .44679 .69483 L .47029 .68514 L p .707 .577 .707 r
F P
0 g
s
.47029 .68514 m .46521 .66684 L .44171 .67652 L p .707 .577 .707 r
F P
0 g
s
.65868 .72323 m .66376 .74154 L .64758 .75029 L p .707 .577 .707 r
F P
0 g
s
.30969 .62826 m .30822 .66513 L .32926 .67271 L p .707 .577 .707 r
F P
0 g
s
.78309 .5492 m .78269 .60473 L .75152 .6026 L p .707 .577 .707 r
F P
0 g
s
.75152 .6026 m .75192 .54707 L .78309 .5492 L p .707 .577 .707 r
F P
0 g
s
.8176 .68243 m .82268 .70074 L .80272 .70221 L p .707 .577 .707 r
F P
0 g
s
.80272 .70221 m .79764 .6839 L .8176 .68243 L p .707 .577 .707 r
F P
0 g
s
.47452 .63742 m .47306 .67428 L .48942 .66711 L p .707 .577 .707 r
F P
0 g
s
.48942 .66711 m .49089 .63025 L .47452 .63742 L p .707 .577 .707 r
F P
0 g
s
.71968 .60318 m .72009 .54764 L .75192 .54707 L p .707 .577 .707 r
F P
0 g
s
.72009 .54764 m .71968 .60318 L .6903 .60639 L p .707 .577 .707 r
F P
0 g
s
.30309 .54478 m .30268 .60032 L .31527 .60837 L p .707 .577 .707 r
F P
0 g
s
.497 .54958 m .4966 .60512 L .50368 .59672 L p .707 .577 .707 r
F P
0 g
s
.50368 .59672 m .50408 .54118 L .497 .54958 L p .707 .577 .707 r
F P
0 g
s
.68474 .62733 m .68327 .66419 L .65923 .66927 L p .707 .577 .707 r
F P
0 g
s
.75192 .54707 m .75152 .6026 L .71968 .60318 L p .707 .577 .707 r
F P
0 g
s
.80449 .63398 m .80303 .67084 L .77559 .66521 L p .707 .577 .707 r
F P
0 g
s
.77559 .66521 m .77706 .62834 L .80449 .63398 L p .707 .577 .707 r
F P
0 g
s
.33132 .72447 m .32624 .70616 L .30628 .70763 L p .707 .577 .707 r
F P
0 g
s
.30822 .66513 m .30969 .62826 L .29712 .61949 L p .707 .577 .707 r
F P
0 g
s
.30628 .70763 m .31136 .72594 L .33132 .72447 L p .707 .577 .707 r
F P
0 g
s
.46521 .66684 m .47029 .68514 L .48646 .67638 L p .707 .577 .707 r
F P
0 g
s
.48646 .67638 m .48138 .65808 L .46521 .66684 L p .707 .577 .707 r
F P
0 g
s
.68327 .66419 m .68474 .62733 L .7141 .62484 L p .707 .577 .707 r
F P
0 g
s
.30268 .60032 m .30309 .54478 L .30019 .53613 L p .707 .577 .707 r
F P
0 g
s
.66376 .74154 m .65868 .72323 L .68218 .71354 L p .707 .577 .707 r
F P
0 g
s
.29712 .61949 m .29565 .65635 L .30822 .66513 L p .707 .577 .707 r
F P
0 g
s
.68218 .71354 m .68726 .73185 L .66376 .74154 L p .707 .577 .707 r
F P
0 g
s
.77706 .62834 m .77559 .66521 L .74445 .66206 L p .707 .577 .707 r
F P
0 g
s
.74445 .66206 m .74591 .62519 L .77706 .62834 L p .707 .577 .707 r
F P
0 g
s
.79764 .6839 m .80272 .70221 L .77648 .7066 L p .707 .577 .707 r
F P
0 g
s
.77648 .7066 m .77139 .68829 L .79764 .6839 L p .707 .577 .707 r
F P
0 g
s
.7141 .62484 m .71263 .66171 L .68327 .66419 L p .707 .577 .707 r
F P
0 g
s
.71263 .66171 m .7141 .62484 L .74591 .62519 L p .707 .577 .707 r
F P
0 g
s
.49089 .63025 m .48942 .66711 L .49651 .65855 L p .707 .577 .707 r
F P
0 g
s
.49651 .65855 m .49798 .62168 L .49089 .63025 L p .707 .577 .707 r
F P
0 g
s
.74591 .62519 m .74445 .66206 L .71263 .66171 L p .707 .577 .707 r
F P
0 g
s
.30019 .53613 m .29979 .59167 L .30268 .60032 L p .707 .577 .707 r
F P
0 g
s
.50408 .54118 m .50368 .59672 L .50078 .58807 L p .707 .577 .707 r
F P
0 g
s
.50078 .58807 m .50119 .53253 L .50408 .54118 L p .707 .577 .707 r
F P
0 g
s
.31136 .72594 m .30628 .70763 L .29456 .70604 L p .707 .577 .707 r
F P
0 g
s
.29456 .70604 m .29964 .72434 L .31136 .72594 L p .707 .577 .707 r
F P
0 g
s
.29565 .65635 m .29712 .61949 L .29423 .61037 L p .707 .577 .707 r
F P
0 g
s
.68726 .73185 m .68218 .71354 L .71069 .70388 L p .707 .577 .707 r
F P
0 g
s
.48138 .65808 m .48646 .67638 L .49374 .66941 L p .707 .577 .707 r
F P
0 g
s
.49374 .66941 m .48866 .6511 L .48138 .65808 L p .707 .577 .707 r
F P
0 g
s
.71069 .70388 m .71577 .72218 L .68726 .73185 L p .707 .577 .707 r
F P
0 g
s
.77139 .68829 m .77648 .7066 L .74651 .71348 L p .707 .577 .707 r
F P
0 g
s
.74651 .71348 m .74143 .69518 L .77139 .68829 L p .707 .577 .707 r
F P
0 g
s
.29979 .59167 m .30019 .53613 L .30727 .52773 L p .707 .577 .707 r
F P
0 g
s
.29423 .61037 m .29276 .64724 L .29565 .65635 L p .707 .577 .707 r
F P
0 g
s
.71577 .72218 m .71069 .70388 L .74143 .69518 L p .707 .577 .707 r
F P
0 g
s
.74143 .69518 m .74651 .71348 L .71577 .72218 L p .707 .577 .707 r
F P
0 g
s
.49798 .62168 m .49651 .65855 L .49362 .64943 L p .707 .577 .707 r
F P
0 g
s
.49362 .64943 m .49509 .61257 L .49798 .62168 L p .707 .577 .707 r
F P
0 g
s
.30727 .52773 m .30687 .58327 L .29979 .59167 L p .707 .577 .707 r
F P
0 g
s
.29964 .72434 m .29456 .70604 L .29222 .70153 L p .707 .577 .707 r
F P
0 g
s
.50119 .53253 m .50078 .58807 L .48819 .58002 L p .707 .577 .707 r
F P
0 g
s
.48819 .58002 m .4886 .52448 L .50119 .53253 L p .707 .577 .707 r
F P
0 g
s
.29222 .70153 m .2973 .71984 L .29964 .72434 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29276 .64724 m .29423 .61037 L .30132 .60181 L p .707 .577 .707 r
F P
0 g
s
.48866 .6511 m .49374 .66941 L .4914 .66491 L p .707 .577 .707 r
F P
0 g
s
.4914 .66491 m .48632 .6466 L .48866 .6511 L p .707 .577 .707 r
F P
0 g
s
.30687 .58327 m .30727 .52773 L .32364 .5204 L p .707 .577 .707 r
F P
0 g
s
.30132 .60181 m .29985 .63868 L .29276 .64724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49509 .61257 m .49362 .64943 L .48105 .64066 L p .707 .577 .707 r
F P
0 g
s
.48105 .64066 m .48252 .60379 L .49509 .61257 L p .707 .577 .707 r
F P
0 g
s
.32364 .5204 m .32324 .57594 L .30687 .58327 L p .707 .577 .707 r
F P
0 g
s
.4886 .52448 m .48819 .58002 L .46714 .57336 L p .707 .577 .707 r
F P
0 g
s
.46714 .57336 m .46754 .51782 L .4886 .52448 L p .707 .577 .707 r
F P
0 g
s
.2973 .71984 m .29222 .70153 L .29949 .69456 L p .707 .577 .707 r
F P
0 g
s
.29949 .69456 m .30457 .71286 L .2973 .71984 L p .707 .577 .707 r
F P
0 g
s
.29985 .63868 m .30132 .60181 L .31768 .59464 L p .707 .577 .707 r
F P
0 g
s
.48632 .6466 m .4914 .66491 L .47967 .66331 L p .707 .577 .707 r
F P
0 g
s
.47967 .66331 m .47459 .645 L .48632 .6466 L p .707 .577 .707 r
F P
0 g
s
.32324 .57594 m .32364 .5204 L .3477 .51486 L p .707 .577 .707 r
F P
0 g
s
.31768 .59464 m .31622 .6315 L .29985 .63868 L p .707 .577 .707 r
F P
0 g
s
.46754 .51782 m .46714 .57336 L .43968 .56874 L p .707 .577 .707 r
F P
0 g
s
.43968 .56874 m .44008 .5132 L .46754 .51782 L p .707 .577 .707 r
F P
0 g
s
.48252 .60379 m .48105 .64066 L .46002 .63308 L p .707 .577 .707 r
F P
0 g
s
.46002 .63308 m .46148 .59621 L .48252 .60379 L p .707 .577 .707 r
F P
0 g
s
.3477 .51486 m .34729 .57039 L .32324 .57594 L p .707 .577 .707 r
F P
0 g
s
.34729 .57039 m .3477 .51486 L .37708 .51164 L p .707 .577 .707 r
F P
0 g
s
.31622 .6315 m .31768 .59464 L .34172 .58956 L p .707 .577 .707 r
F P
0 g
s
.30457 .71286 m .29949 .69456 L .31567 .6858 L p .707 .577 .707 r
F P
0 g
s
.31567 .6858 m .32075 .70411 L .30457 .71286 L p .707 .577 .707 r
F P
0 g
s
.44008 .5132 m .43968 .56874 L .40851 .56661 L p .707 .577 .707 r
F P
0 g
s
.40851 .56661 m .40891 .51107 L .44008 .5132 L p .707 .577 .707 r
F P
0 g
s
.47459 .645 m .47967 .66331 L .45971 .66478 L p .707 .577 .707 r
F P
0 g
s
.45971 .66478 m .45463 .64647 L .47459 .645 L p .707 .577 .707 r
F P
0 g
s
.37667 .56718 m .37708 .51164 L .40891 .51107 L p .707 .577 .707 r
F P
0 g
s
.37708 .51164 m .37667 .56718 L .34729 .57039 L p .707 .577 .707 r
F P
0 g
s
.34172 .58956 m .34026 .62643 L .31622 .6315 L p .707 .577 .707 r
F P
0 g
s
.40891 .51107 m .40851 .56661 L .37667 .56718 L p .707 .577 .707 r
F P
0 g
s
.46148 .59621 m .46002 .63308 L .43258 .62744 L p .707 .577 .707 r
F P
0 g
s
.43258 .62744 m .43405 .59057 L .46148 .59621 L p .707 .577 .707 r
F P
0 g
s
.34026 .62643 m .34172 .58956 L .37109 .58708 L p .707 .577 .707 r
F P
0 g
s
.32075 .70411 m .31567 .6858 L .33916 .67611 L p .707 .577 .707 r
F P
0 g
s
.33916 .67611 m .34425 .69442 L .32075 .70411 L p .707 .577 .707 r
F P
0 g
s
.43405 .59057 m .43258 .62744 L .40143 .62429 L p .707 .577 .707 r
F P
0 g
s
.40143 .62429 m .4029 .58742 L .43405 .59057 L p .707 .577 .707 r
F P
0 g
s
.45463 .64647 m .45971 .66478 L .43346 .66917 L p .707 .577 .707 r
F P
0 g
s
.43346 .66917 m .42838 .65086 L .45463 .64647 L p .707 .577 .707 r
F P
0 g
s
.37109 .58708 m .36962 .62394 L .34026 .62643 L p .707 .577 .707 r
F P
0 g
s
.36962 .62394 m .37109 .58708 L .4029 .58742 L p .707 .577 .707 r
F P
0 g
s
.4029 .58742 m .40143 .62429 L .36962 .62394 L p .707 .577 .707 r
F P
0 g
s
.34425 .69442 m .33916 .67611 L .36768 .66644 L p .707 .577 .707 r
F P
0 g
s
.36768 .66644 m .37276 .68475 L .34425 .69442 L p .707 .577 .707 r
F P
0 g
s
.42838 .65086 m .43346 .66917 L .4035 .67605 L p .707 .577 .707 r
F P
0 g
s
.4035 .67605 m .39842 .65774 L .42838 .65086 L p .707 .577 .707 r
F P
0 g
s
.37276 .68475 m .36768 .66644 L .39842 .65774 L p .707 .577 .707 r
F P
0 g
s
.39842 .65774 m .4035 .67605 L .37276 .68475 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0000G
0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0006Eoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
00=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001UOol005ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000IGoo001KOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol005Uoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Egoo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000AOolA0013
Ool005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH8000kOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Goo001EOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0017oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P00<Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`00;Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<0
05YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol00`00FUH00003
FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH70003FUH00`00
FUIJEP02FUH?0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool005Eoo`80009JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000IJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
02aoo`00EGoo0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF10000eYF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000`0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0010OolB
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool003Yoo`H000AJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF008002aoo`00=goo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF1@0015YF00<005YFFUH00P00;7oo000dOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00AJEP00FUIJEP8002aoo`00<Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2
000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
02aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEQ40009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP<002aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEPT0
009JEP03001JEUYF00AJEP<000AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF
20000eYF00<005YFFUH01eYF00@005YFFUIJEPH000EJEP03001JEUYF00=JEP03001JEUYF009JEP<0
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF1@001EYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH010000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF009JEP03001JEP00
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF001JEP8000AJEP<000=JEP03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP03001JEUYF00AJEP@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P00;Goo000^Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00
FUH00000FUH000EJEP03001JEP0000<00005FUH005YFFUH00005FUH50006FUH00`00FUIJEP08FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH000030004FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEPH000EJEP<000MJEP03001JEUYF00P0009JEP<000=JEP8000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP8002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF
2`0000=JEP0000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP03FUH01000FUIJ
EUYF10000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00=JEP03001JEUYF00@0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF0080
0003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH00UYF5P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF1P00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00;Woo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF100000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF00MJEP04
001JEUYFFUH70003FUH40004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEP0000<000AJEP03001JEUYF008000Moo`<000Aoo`P000AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002ioo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP800003
FUH005YF00QJEP03001JEUYF00AJEPL00005FUH00000FUH00004FUH01000FUIJEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP04
FUH00`00FUIJEP020006Ool5000;Ool60004FUH01P00FUIJEP00FUH002eoo`00;Woo00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
0000100000AJEP00000000=JEP03001JEUYF00MJEP03001JEUYF00@000IJEP8000=JEP03001JEUYF
00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00
FUH00P0015YF0`0015YF00<005YFFUH00P001Woo1@004Goo0`0000MJEP00FUIJEP00FUH0000]Ool0
02ioo`05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH30006
FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00800003FUH005YF00AJEP03001JEP0000@0009JEP8000Ioo`D0011oo`H0009JEP03001J
EP0002eoo`00;Woo0P000UYF00<005YFFUH00eYF60000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH01eYF00<005YFFUH0400000=JEP00FUH01UYF00@005YF000000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00=JEPL000Eoo`<000Yoo`L000=JEP05001JEUYF001JEP02000^Ool002ioo`80009JEP03001JEUYF
00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP<000=JEP03001JEUYF
00EJEP@0009JEPD000AJEP<000AJEP03001JEUYF00AJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF009JEQ800003FUH0000000h002ioo`00;Woo0P000UYF0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF009JEP800003FUH005YF00=J
EPT000MJEP03001JEUYF009JEP<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEPH000=JEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;goo0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`001eYF00<005YF00000`00
0UYF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH20003FUH01@00FUIJEP00FUH0
1`000eYF00<005YFFUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP02FUH2000015YF000005YF1P0000=JEP00FUH025YF00<005YFFUH00UYF0`001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=J
EP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YF0000009JEPH0
00IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000_Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003
FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00
0eYF00<005YFFUH015YF00<005YF00000`001eYF00<005YFFUH01EYF1`000eYF00<005YFFUH00eYF
00<005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0P0000=JEP00FUH00eYF10000UYF
00<005YFFUH01eYF00<005YFFUH010001UYF00<005YF00000P001EYF00<005YF0000;goo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUH000050006FUH00`00FUIJEP06FUH400000eYF001JEP07FUH20003FUH00`00
FUIJEP02FUH2000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEP03001JEUYF00<000UJEP03001JEUYF009JEP@000AJEP03001JEUYF
009JEP@000EJEP05001JEUYFFUH0000bOol002aoo`03001JEP0000=JEP04001JEUYFFUH8000AOol7
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUIJEP06FUH00`00FUH0000?0002FUH00`00FUIJ
EP05FUH3000cOol002aoo`03001JEP0000=JEP@0019oo`<000Yoo`800003FUH005YF00AJEP03001J
EP0000<00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000@000EJEP03001JEUYF00EJEP<000=oo`T000IJEP03001JEUYF00AJEP8003Eoo`00;7oo00@0
05YF001JEP8000AJEP<000ioo`D000]oo`T00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00=JEP8000Ioo`D00003
FUH005YF00QJEP04001JEUYFFUH2000gOol002aoo`06001JEP00001JEP001EYF00<005YF00000`00
2Woo1@004Goo0`0000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00<005YFFUH01EYF00<005YF00000`001goo10000eYF00<005YFFUH01UYF00@0
05YF000003Uoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1P0017oo1@002Goo2000
0UYF0`000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH00eYF0`0000=JEP00000017oo10001eYF00<005YFFUH01EYF0`00>goo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH01000FUIJEUYF1000
00AJEP00001JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00
FUH00003000015YF000000000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01000?Woo000/Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH60002FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP00
0UYF00<005YFFUH00UYF0P0015YF1P001UYF00<005YFFUH01UYF1000@Woo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUIJEPL0
00=JEP03001JEUYF00MJEP03001JEUYF009JEP<004Ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001J
EUYF00800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH=000;FUH90008FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF00000P00BGoo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60006FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001JEUYF
00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001<Ool002moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH4000015YF000000000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF0P001UYF
00<005YFFUH01EYF00<005YFFUH01000Cgoo000`Ool20004FUH00`00FUIJEP05FUH00`00FUH00003
0006FUH00`00FUIJEP07FUH01000FUIJEUYF1`000eYF1@000UYF00<005YFFUH00eYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF009JEPH005=oo`00<Woo0`0000=JEP00FUH0
1UYF0P0000=JEP00FUH025YF00<005YFFUH015YF1`0000EJEP00001JEP0000AJEP03001JEUYF0080
009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP@000AJEP800003FUH005YF009JEPL0009JEP03001JEP0005Ao
o`00=Goo0`000eYF0`000eYF00<005YFFUH01eYF00<005YFFUH010001UYF0P000eYF00<005YFFUH0
0eYF0P0000Eoo`00FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0000400000goo
00000003FUH01P00FUIJEP00FUH005Aoo`00>7oo0`001eYF00<005YFFUH015YF1@000UYF00<005YF
FUH00UYF0`001UYF00@005YFFUIJEP80009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3
00000eYF001oo`04Ool400001eYF001JEUYF001JEP0005Aoo`00=Woo0P0000=JEP00FUH01eYF00<0
05YFFUH01`0015YF00<005YFFUH00P0000=JEP00FUH01UYF00@005YF000000Aoo`03001JEUYF0080
0003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000@000=JEP<0009JEP8005Eoo`00=7oo
0P000eYF00<005YFFUH01EYF10000Woo300015YF00<005YFFUH015YF0P001Woo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000003P00EGoo000bOol20006FUH00`00FUIJ
EP02FUH20006Ool90007FUH00`00FUIJEP02FUH20008Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01000EGoo000`Ool30007FUH00`00
FUH000020008Ool50002FUH00`00FUIJEP07FUH01000FUH000002Woo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000=JEP03001JEUYF009JEP04001JEUYFFUH3001EOol002ioo`80
00=JEP03001JEUYF00AJEP8000Qoo`L000=JEP03001JEUYF00IJEP<000aoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005Eoo`00
;Goo0P0015YF00<005YFFUH00UYF0P001Woo100000=JEP00FUH025YF00<005YFFUH00UYF0`0047oo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH00UYF
00@005YFFUIJEP8005Eoo`00;7oo00<005YF00001EYF00@005YF0000009oo`H000IJEP03001JEUYF
00IJEP03001JEP00008001=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJ
EP/005Ioo`00;7oo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<001Mo
o`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP@0009JEP03001JEUYF009JEP04001J
EUYF001FOol002aoo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04000LOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF1P000UYF00<005YF00000P001EYF00<005YF0000EWoo
000]Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH015YF1@008Woo0P001UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
00000`001UYF0P000eYF00<005YFFUH00UYF0P00Egoo000]Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04000YOol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH400000eYF001JEP03FUH40005FUH00`00FUIJEP02FUH0
0`00Oomoo`1FOol002eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH4000_Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0?0002FUH00`00
FUIJEP05FUH01000FUH00000FGoo000]Ool20002FUH00`00FUIJEP03FUH00`00FUH00003000fOol4
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool90006FUH00`00FUIJ
EP04FUH3001KOol002ioo`/003ioo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00L000Ioo`D00003FUH005YF00QJEP04001JEUYFFUH2001NOol007eoob000004FUH000000008Ool5
0002FUH00`00FUIJEP06FUH01000FUH00000H7oo002?Ool00`00FUIJEP02FUH00`00FUIJEP04FUH3
0007Ool4000015YF000000000eYF00<005YFFUH01EYF0`00HWoo002>Ool20005FUH01000FUIJEUYF
0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo002=Ool01000FUIJEP0015YF
00@005YF0000009oo`H000IJEP03001JEUYF00MJEP03001JEP00008006Moo`00SGoo00@005YFFUH0
00AJEPH000=JEP03001JEUYF00MJEP03001JEUYF00AJEP@006Yoo`00SWoo00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006ioo`00SWoo00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF1000LWoo002?Ool015YF001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01000MWoo002?Ool01000FUIJEP001EYF00<005YFFUH00UYF1P00NWoo002?Ool2
0002FUH00`00FUIJEP070020Ool0095oo`D008Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60363 .75001 m .60428 .6945 L .57311 .69223 L p .707 .577 .707 r
F P
0 g
s
.60428 .6945 m .60363 .75001 L .63546 .74956 L p .707 .577 .707 r
F P
0 g
s
.63546 .74956 m .63612 .69406 L .60428 .6945 L p .707 .577 .707 r
F P
0 g
s
.63612 .69406 m .63546 .74956 L .66484 .74645 L p .707 .577 .707 r
F P
0 g
s
.66484 .74645 m .6655 .69094 L .63612 .69406 L p .707 .577 .707 r
F P
0 g
s
.57246 .74774 m .57311 .69223 L .54566 .68747 L p .707 .577 .707 r
F P
0 g
s
.57311 .69223 m .57246 .74774 L .60363 .75001 L p .707 .577 .707 r
F P
0 g
s
.6655 .69094 m .66484 .74645 L .6889 .74097 L p .707 .577 .707 r
F P
0 g
s
.6889 .74097 m .68955 .68546 L .6655 .69094 L p .707 .577 .707 r
F P
0 g
s
.545 .74297 m .54566 .68747 L .5246 .68068 L p .707 .577 .707 r
F P
0 g
s
.54566 .68747 m .545 .74297 L .57246 .74774 L p .707 .577 .707 r
F P
0 g
s
.59208 .81217 m .59446 .77546 L .56335 .77154 L p .707 .577 .707 r
F P
0 g
s
.59446 .77546 m .59208 .81217 L .62386 .81321 L p .707 .577 .707 r
F P
0 g
s
.62386 .81321 m .62623 .7765 L .59446 .77546 L p .707 .577 .707 r
F P
0 g
s
.62623 .7765 m .62386 .81321 L .6532 .81128 L p .707 .577 .707 r
F P
0 g
s
.6532 .81128 m .65557 .77456 L .62623 .7765 L p .707 .577 .707 r
F P
0 g
s
.56098 .80826 m .56335 .77154 L .53596 .76513 L p .707 .577 .707 r
F P
0 g
s
.56335 .77154 m .56098 .80826 L .59208 .81217 L p .707 .577 .707 r
F P
0 g
s
.68955 .68546 m .6889 .74097 L .70526 .73366 L p .707 .577 .707 r
F P
0 g
s
.70526 .73366 m .70592 .67815 L .68955 .68546 L p .707 .577 .707 r
F P
0 g
s
.5246 .68068 m .52395 .73619 L .545 .74297 L p .707 .577 .707 r
F P
0 g
s
.65557 .77456 m .6532 .81128 L .67722 .80655 L p .707 .577 .707 r
F P
0 g
s
.67722 .80655 m .67959 .76984 L .65557 .77456 L p .707 .577 .707 r
F P
0 g
s
.59035 .83689 m .58231 .81948 L .55427 .83161 L p .707 .577 .707 r
F P
0 g
s
.58231 .81948 m .59035 .83689 L .61935 .82346 L p .707 .577 .707 r
F P
0 g
s
.61935 .82346 m .61132 .80606 L .58231 .81948 L p .707 .577 .707 r
F P
0 g
s
.53596 .76513 m .53358 .80185 L .56098 .80826 L p .707 .577 .707 r
F P
0 g
s
.61132 .80606 m .61935 .82346 L .64649 .81005 L p .707 .577 .707 r
F P
0 g
s
.64649 .81005 m .63846 .79264 L .61132 .80606 L p .707 .577 .707 r
F P
0 g
s
.55427 .83161 m .56231 .84902 L .59035 .83689 L p .707 .577 .707 r
F P
0 g
s
.52395 .73619 m .5246 .68068 L .51201 .67253 L p .707 .577 .707 r
F P
0 g
s
.53358 .80185 m .53596 .76513 L .51496 .75686 L p .707 .577 .707 r
F P
0 g
s
.56231 .84902 m .55427 .83161 L .52995 .84124 L p .707 .577 .707 r
F P
0 g
s
.63846 .79264 m .64649 .81005 L .6691 .79795 L p .707 .577 .707 r
F P
0 g
s
.6691 .79795 m .66107 .78054 L .63846 .79264 L p .707 .577 .707 r
F P
0 g
s
.52995 .84124 m .53799 .85865 L .56231 .84902 L p .707 .577 .707 r
F P
0 g
s
.51496 .75686 m .51259 .79358 L .53358 .80185 L p .707 .577 .707 r
F P
0 g
s
.51201 .67253 m .51136 .72804 L .52395 .73619 L p .707 .577 .707 r
F P
0 g
s
.70592 .67815 m .70526 .73366 L .71235 .72524 L p .707 .577 .707 r
F P
0 g
s
.71235 .72524 m .713 .66973 L .70592 .67815 L p .707 .577 .707 r
F P
0 g
s
.67959 .76984 m .67722 .80655 L .69358 .79951 L p .707 .577 .707 r
F P
0 g
s
.69358 .79951 m .69595 .76279 L .67959 .76984 L p .707 .577 .707 r
F P
0 g
s
.51259 .79358 m .51496 .75686 L .50241 .74754 L p .707 .577 .707 r
F P
0 g
s
.53799 .85865 m .52995 .84124 L .51173 .84743 L p .707 .577 .707 r
F P
0 g
s
.51173 .84743 m .51976 .86484 L .53799 .85865 L p .707 .577 .707 r
F P
0 g
s
.51136 .72804 m .51201 .67253 L .50912 .66382 L p .707 .577 .707 r
F P
0 g
s
.66107 .78054 m .6691 .79795 L .68497 .78836 L p .707 .577 .707 r
F P
0 g
s
.68497 .78836 m .67694 .77095 L .66107 .78054 L p .707 .577 .707 r
F P
0 g
s
.50241 .74754 m .50004 .78425 L .51259 .79358 L p .707 .577 .707 r
F P
0 g
s
.50912 .66382 m .50846 .71932 L .51136 .72804 L p .707 .577 .707 r
F P
0 g
s
.69595 .76279 m .69358 .79951 L .70067 .79082 L p .707 .577 .707 r
F P
0 g
s
.70067 .79082 m .70305 .7541 L .69595 .76279 L p .707 .577 .707 r
F P
0 g
s
.713 .66973 m .71235 .72524 L .70945 .71653 L p .707 .577 .707 r
F P
0 g
s
.70945 .71653 m .71011 .66102 L .713 .66973 L p .707 .577 .707 r
F P
0 g
s
.51976 .86484 m .51173 .84743 L .50138 .84959 L p .707 .577 .707 r
F P
0 g
s
.50004 .78425 m .50241 .74754 L .49955 .73807 L p .707 .577 .707 r
F P
0 g
s
.50138 .84959 m .50941 .867 L .51976 .86484 L p .707 .577 .707 r
F P
0 g
s
.67694 .77095 m .68497 .78836 L .69255 .78222 L p .707 .577 .707 r
F P
0 g
s
.69255 .78222 m .68452 .76481 L .67694 .77095 L p .707 .577 .707 r
F P
0 g
s
.50846 .71932 m .50912 .66382 L .5162 .65539 L p .707 .577 .707 r
F P
0 g
s
.49602 .82167 m .48777 .31897 L .44377 .31702 L p .707 .577 .707 r
F P
0 g
s
.49955 .73807 m .49717 .77479 L .50004 .78425 L p .707 .577 .707 r
F P
0 g
s
.5162 .65539 m .51555 .7109 L .50846 .71932 L p .707 .577 .707 r
F P
0 g
s
.49717 .77479 m .49955 .73807 L .50664 .72938 L p .707 .577 .707 r
F P
0 g
s
.51555 .7109 m .5162 .65539 L .53257 .64808 L p .707 .577 .707 r
F P
0 g
s
.50664 .72938 m .50427 .7661 L .49717 .77479 L p .707 .577 .707 r
F P
0 g
s
.53257 .64808 m .53192 .70359 L .51555 .7109 L p .707 .577 .707 r
F P
0 g
s
.50427 .7661 m .50664 .72938 L .523 .72234 L p .707 .577 .707 r
F P
0 g
s
.523 .72234 m .52063 .75905 L .50427 .7661 L p .707 .577 .707 r
F P
0 g
s
.52063 .75905 m .523 .72234 L .54702 .71761 L p .707 .577 .707 r
F P
0 g
s
.54702 .71761 m .54465 .75433 L .52063 .75905 L p .707 .577 .707 r
F P
0 g
s
.48777 .31897 m .49602 .82167 L .54096 .81991 L p .707 .577 .707 r
F P
0 g
s
.53192 .70359 m .53257 .64808 L .55662 .6426 L p .707 .577 .707 r
F P
0 g
s
.55662 .6426 m .55597 .69811 L .53192 .70359 L p .707 .577 .707 r
F P
0 g
s
.54096 .81991 m .53271 .31721 L .48777 .31897 L p .707 .577 .707 r
F P
0 g
s
.55597 .69811 m .55662 .6426 L .586 .63949 L p .707 .577 .707 r
F P
0 g
s
.586 .63949 m .58535 .695 L .55597 .69811 L p .707 .577 .707 r
F P
0 g
s
.54465 .75433 m .54702 .71761 L .57636 .71568 L p .707 .577 .707 r
F P
0 g
s
.57636 .71568 m .57398 .75239 L .54465 .75433 L p .707 .577 .707 r
F P
0 g
s
.57398 .75239 m .57636 .71568 L .60814 .71672 L p .707 .577 .707 r
F P
0 g
s
.60814 .71672 m .60576 .75343 L .57398 .75239 L p .707 .577 .707 r
F P
0 g
s
.55402 .83707 m .54599 .81967 L .57312 .80625 L p .707 .577 .707 r
F P
0 g
s
.57312 .80625 m .58116 .82366 L .55402 .83707 L p .707 .577 .707 r
F P
0 g
s
.58116 .82366 m .57312 .80625 L .60213 .79282 L p .707 .577 .707 r
F P
0 g
s
.53271 .31721 m .54096 .81991 L .58244 .81461 L p .707 .577 .707 r
F P
0 g
s
.58244 .81461 m .57419 .31191 L .53271 .31721 L p .707 .577 .707 r
F P
0 g
s
.45202 .81972 m .44377 .31702 L .40501 .31155 L p .707 .577 .707 r
F P
0 g
s
.44377 .31702 m .45202 .81972 L .49602 .82167 L p .707 .577 .707 r
F P
0 g
s
.70305 .7541 m .70067 .79082 L .69781 .78135 L p .707 .577 .707 r
F P
0 g
s
.69781 .78135 m .70018 .74464 L .70305 .7541 L p .707 .577 .707 r
F P
0 g
s
.71011 .66102 m .70945 .71653 L .69686 .70838 L p .707 .577 .707 r
F P
0 g
s
.69686 .70838 m .69751 .65287 L .71011 .66102 L p .707 .577 .707 r
F P
0 g
s
.58535 .695 m .586 .63949 L .61783 .63905 L p .707 .577 .707 r
F P
0 g
s
.61783 .63905 m .61718 .69456 L .58535 .695 L p .707 .577 .707 r
F P
0 g
s
.63924 .72063 m .63687 .75735 L .60576 .75343 L p .707 .577 .707 r
F P
0 g
s
.60576 .75343 m .60814 .71672 L .63924 .72063 L p .707 .577 .707 r
F P
0 g
s
.63017 .7807 m .6382 .79811 L .61017 .81023 L p .707 .577 .707 r
F P
0 g
s
.61017 .81023 m .60213 .79282 L .63017 .7807 L p .707 .577 .707 r
F P
0 g
s
.60213 .79282 m .61017 .81023 L .58116 .82366 L p .707 .577 .707 r
F P
0 g
s
.57419 .31191 m .58244 .81461 L .61639 .8063 L p .707 .577 .707 r
F P
0 g
s
.61639 .8063 m .60814 .3036 L .57419 .31191 L p .707 .577 .707 r
F P
0 g
s
.50941 .867 m .50138 .84959 L .49992 .84749 L p .708 .578 .707 r
F P
0 g
s
.49992 .84749 m .50796 .8649 L .50941 .867 L p .708 .578 .707 r
F P
0 g
s
.68452 .76481 m .69255 .78222 L .6911 .78012 L p .708 .578 .707 r
F P
0 g
s
.6911 .78012 m .68306 .76271 L .68452 .76481 L p .708 .578 .707 r
F P
0 g
s
.26062 .71452 m .26127 .65901 L .2301 .65674 L p .707 .577 .707 r
F P
0 g
s
.26127 .65901 m .26062 .71452 L .29245 .71407 L p .707 .577 .707 r
F P
0 g
s
.29245 .71407 m .29311 .65857 L .26127 .65901 L p .707 .577 .707 r
F P
0 g
s
.29311 .65857 m .29245 .71407 L .32183 .71096 L p .707 .577 .707 r
F P
0 g
s
.32183 .71096 m .32249 .65545 L .29311 .65857 L p .707 .577 .707 r
F P
0 g
s
.41326 .81425 m .40501 .31155 L .37529 .3031 L p .707 .577 .707 r
F P
0 g
s
.40501 .31155 m .41326 .81425 L .45202 .81972 L p .707 .577 .707 r
F P
0 g
s
.22945 .71225 m .2301 .65674 L .20265 .65198 L p .707 .577 .707 r
F P
0 g
s
.2301 .65674 m .22945 .71225 L .26062 .71452 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.32249 .65545 m .32183 .71096 L .34589 .70548 L p .707 .577 .707 r
F P
0 g
s
.34589 .70548 m .34654 .64997 L .32249 .65545 L p .707 .577 .707 r
F P
0 g
s
.68306 .76271 m .6911 .78012 L .68075 .78228 L p .707 .577 .707 r
F P
0 g
s
.70018 .74464 m .69781 .78135 L .68526 .77203 L p .707 .577 .707 r
F P
0 g
s
.68526 .77203 m .68763 .73531 L .70018 .74464 L p .707 .577 .707 r
F P
0 g
s
.69751 .65287 m .69686 .70838 L .67581 .70159 L p .707 .577 .707 r
F P
0 g
s
.67581 .70159 m .67646 .64608 L .69751 .65287 L p .707 .577 .707 r
F P
0 g
s
.649 .64132 m .64835 .69683 L .61718 .69456 L p .707 .577 .707 r
F P
0 g
s
.61718 .69456 m .61783 .63905 L .649 .64132 L p .707 .577 .707 r
F P
0 g
s
.66664 .72704 m .66426 .76376 L .63687 .75735 L p .707 .577 .707 r
F P
0 g
s
.63687 .75735 m .63924 .72063 L .66664 .72704 L p .707 .577 .707 r
F P
0 g
s
.6382 .79811 m .63017 .7807 L .65449 .77107 L p .707 .577 .707 r
F P
0 g
s
.60814 .3036 m .61639 .8063 L .6395 .79578 L p .707 .577 .707 r
F P
0 g
s
.6395 .79578 m .63125 .29308 L .60814 .3036 L p .707 .577 .707 r
F P
0 g
s
.20199 .70748 m .20265 .65198 L .18159 .64519 L p .707 .577 .707 r
F P
0 g
s
.20265 .65198 m .20199 .70748 L .22945 .71225 L p .707 .577 .707 r
F P
0 g
s
.24908 .77382 m .25145 .7371 L .22034 .73319 L p .707 .577 .707 r
F P
0 g
s
.25145 .7371 m .24908 .77382 L .28085 .77486 L p .707 .577 .707 r
F P
0 g
s
.28085 .77486 m .28323 .73814 L .25145 .7371 L p .707 .577 .707 r
F P
0 g
s
.50796 .8649 m .49992 .84749 L .5075 .84135 L p .707 .577 .707 r
F P
0 g
s
.5075 .84135 m .51554 .85876 L .50796 .8649 L p .707 .577 .707 r
F P
0 g
s
.28323 .73814 m .28085 .77486 L .31019 .77292 L p .707 .577 .707 r
F P
0 g
s
.31019 .77292 m .31256 .73621 L .28323 .73814 L p .707 .577 .707 r
F P
0 g
s
.68075 .78228 m .67272 .76487 L .68306 .76271 L p .707 .577 .707 r
F P
0 g
s
.21797 .7699 m .22034 .73319 L .19295 .72678 L p .707 .577 .707 r
F P
0 g
s
.22034 .73319 m .21797 .7699 L .24908 .77382 L p .707 .577 .707 r
F P
0 g
s
.34654 .64997 m .34589 .70548 L .36226 .69817 L p .707 .577 .707 r
F P
0 g
s
.36226 .69817 m .36291 .64266 L .34654 .64997 L p .707 .577 .707 r
F P
0 g
s
.18159 .64519 m .18094 .7007 L .20199 .70748 L p .707 .577 .707 r
F P
0 g
s
.38354 .8058 m .37529 .3031 L .35752 .29249 L p .707 .577 .707 r
F P
0 g
s
.37529 .3031 m .38354 .8058 L .41326 .81425 L p .707 .577 .707 r
F P
0 g
s
.67646 .64608 m .67581 .70159 L .64835 .69683 L p .707 .577 .707 r
F P
0 g
s
.64835 .69683 m .649 .64132 L .67646 .64608 L p .707 .577 .707 r
F P
0 g
s
.31256 .73621 m .31019 .77292 L .33421 .7682 L p .707 .577 .707 r
F P
0 g
s
.33421 .7682 m .33658 .73148 L .31256 .73621 L p .707 .577 .707 r
F P
0 g
s
.19295 .72678 m .19057 .7635 L .21797 .7699 L p .707 .577 .707 r
F P
0 g
s
.24734 .79908 m .2393 .78167 L .21127 .7938 L p .707 .577 .707 r
F P
0 g
s
.2393 .78167 m .24734 .79908 L .27634 .78565 L p .707 .577 .707 r
F P
0 g
s
.27634 .78565 m .26831 .76825 L .2393 .78167 L p .707 .577 .707 r
F P
0 g
s
.26831 .76825 m .27634 .78565 L .30348 .77224 L p .707 .577 .707 r
F P
0 g
s
.30348 .77224 m .29545 .75483 L .26831 .76825 L p .707 .577 .707 r
F P
0 g
s
.21127 .7938 m .2193 .8112 L .24734 .79908 L p .707 .577 .707 r
F P
0 g
s
.67272 .76487 m .68075 .78228 L .66253 .78847 L p .707 .577 .707 r
F P
0 g
s
.66253 .78847 m .65449 .77107 L .67272 .76487 L p .707 .577 .707 r
F P
0 g
s
.68763 .73531 m .68526 .77203 L .66426 .76376 L p .707 .577 .707 r
F P
0 g
s
.66426 .76376 m .66664 .72704 L .68763 .73531 L p .707 .577 .707 r
F P
0 g
s
.18094 .7007 m .18159 .64519 L .169 .63704 L p .707 .577 .707 r
F P
0 g
s
.19057 .7635 m .19295 .72678 L .17195 .71851 L p .707 .577 .707 r
F P
0 g
s
.2193 .8112 m .21127 .7938 L .18694 .80343 L p .707 .577 .707 r
F P
0 g
s
.29545 .75483 m .30348 .77224 L .32609 .76014 L p .707 .577 .707 r
F P
0 g
s
.32609 .76014 m .31806 .74273 L .29545 .75483 L p .707 .577 .707 r
F P
0 g
s
.18694 .80343 m .19498 .82084 L .2193 .8112 L p .707 .577 .707 r
F P
0 g
s
.51554 .85876 m .5075 .84135 L .52338 .83176 L p .707 .577 .707 r
F P
0 g
s
.17195 .71851 m .16958 .75523 L .19057 .7635 L p .707 .577 .707 r
F P
0 g
s
.52338 .83176 m .53141 .84917 L .51554 .85876 L p .707 .577 .707 r
F P
0 g
s
.65449 .77107 m .66253 .78847 L .6382 .79811 L p .707 .577 .707 r
F P
0 g
s
.63125 .29308 m .6395 .79578 L .6495 .78409 L p .707 .577 .707 r
F P
0 g
s
.6495 .78409 m .64125 .28139 L .63125 .29308 L p .707 .577 .707 r
F P
0 g
s
.169 .63704 m .16835 .69255 L .18094 .7007 L p .707 .577 .707 r
F P
0 g
s
.36291 .64266 m .36226 .69817 L .36934 .68975 L p .707 .577 .707 r
F P
0 g
s
.36934 .68975 m .36999 .63424 L .36291 .64266 L p .707 .577 .707 r
F P
0 g
s
.33658 .73148 m .33421 .7682 L .35057 .76115 L p .707 .577 .707 r
F P
0 g
s
.35057 .76115 m .35294 .72443 L .33658 .73148 L p .707 .577 .707 r
F P
0 g
s
.16958 .75523 m .17195 .71851 L .1594 .70918 L p .707 .577 .707 r
F P
0 g
s
.19498 .82084 m .18694 .80343 L .16872 .80962 L p .707 .577 .707 r
F P
0 g
s
.16872 .80962 m .17675 .82703 L .19498 .82084 L p .707 .577 .707 r
F P
0 g
s
.31806 .74273 m .32609 .76014 L .34197 .75055 L p .707 .577 .707 r
F P
0 g
s
.34197 .75055 m .33393 .73314 L .31806 .74273 L p .707 .577 .707 r
F P
0 g
s
.16835 .69255 m .169 .63704 L .16611 .62833 L p .707 .577 .707 r
F P
0 g
s
.3671 .62553 m .36644 .68104 L .35385 .67289 L p .707 .577 .707 r
F P
0 g
s
.35385 .67289 m .35451 .61738 L .3671 .62553 L p .707 .577 .707 r
F P
0 g
s
.36577 .79519 m .35752 .29249 L .35343 .28077 L p .707 .577 .707 r
F P
0 g
s
.36999 .63424 m .36934 .68975 L .36644 .68104 L p .707 .577 .707 r
F P
0 g
s
.36644 .68104 m .3671 .62553 L .36999 .63424 L p .707 .577 .707 r
F P
0 g
s
.35752 .29249 m .36577 .79519 L .38354 .8058 L p .707 .577 .707 r
F P
0 g
s
.1594 .70918 m .15703 .7459 L .16958 .75523 L p .707 .577 .707 r
F P
0 g
s
.53141 .84917 m .52338 .83176 L .54599 .81967 L p .707 .577 .707 r
F P
0 g
s
.54599 .81967 m .55402 .83707 L .53141 .84917 L p .707 .577 .707 r
F P
0 g
s
.35294 .72443 m .35057 .76115 L .35766 .75247 L p .707 .577 .707 r
F P
0 g
s
.35766 .75247 m .36004 .71575 L .35294 .72443 L p .707 .577 .707 r
F P
0 g
s
.16611 .62833 m .16545 .68383 L .16835 .69255 L p .707 .577 .707 r
F P
0 g
s
.17675 .82703 m .16872 .80962 L .15837 .81178 L p .707 .577 .707 r
F P
0 g
s
.15703 .7459 m .1594 .70918 L .15654 .69971 L p .707 .577 .707 r
F P
0 g
s
.15837 .81178 m .1664 .82919 L .17675 .82703 L p .707 .577 .707 r
F P
0 g
s
.33393 .73314 m .34197 .75055 L .34955 .74441 L p .707 .577 .707 r
F P
0 g
s
.34955 .74441 m .34151 .727 L .33393 .73314 L p .707 .577 .707 r
F P
0 g
s
.64125 .28139 m .6495 .78409 L .64541 .77237 L p .707 .577 .707 r
F P
0 g
s
.64541 .77237 m .63716 .26967 L .64125 .28139 L p .707 .577 .707 r
F P
0 g
s
.16545 .68383 m .16611 .62833 L .17319 .6199 L p .707 .577 .707 r
F P
0 g
s
.15654 .69971 m .15416 .73643 L .15703 .7459 L p .707 .577 .707 r
F P
0 g
s
.36004 .71575 m .35766 .75247 L .3548 .743 L p .707 .577 .707 r
F P
0 g
s
.3548 .743 m .35717 .70628 L .36004 .71575 L p .707 .577 .707 r
F P
0 g
s
.17319 .6199 m .17254 .67541 L .16545 .68383 L p .707 .577 .707 r
F P
0 g
s
.35343 .28077 m .36168 .78347 L .36577 .79519 L p .707 .577 .707 r
F P
0 g
s
.36168 .78347 m .35343 .28077 L .36343 .26908 L p .707 .577 .707 r
F P
0 g
s
.1664 .82919 m .15837 .81178 L .15691 .80968 L p .708 .578 .707 r
F P
0 g
s
.15416 .73643 m .15654 .69971 L .16363 .69103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15691 .80968 m .16495 .82709 L .1664 .82919 L p .708 .578 .707 r
F P
0 g
s
.34151 .727 m .34955 .74441 L .34809 .74231 L p .708 .578 .707 r
F P
0 g
s
.34809 .74231 m .34005 .7249 L .34151 .727 L p .708 .578 .707 r
F P
0 g
s
.17254 .67541 m .17319 .6199 L .18956 .61259 L p .707 .577 .707 r
F P
0 g
s
.16363 .69103 m .16126 .72775 L .15416 .73643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63716 .26967 m .64541 .77237 L .62764 .76176 L p .707 .577 .707 r
F P
0 g
s
.62764 .76176 m .61939 .25906 L .63716 .26967 L p .707 .577 .707 r
F P
0 g
s
.34005 .7249 m .34809 .74231 L .33774 .74447 L p .707 .577 .707 r
F P
0 g
s
.35717 .70628 m .3548 .743 L .34225 .73367 L p .707 .577 .707 r
F P
0 g
s
.34225 .73367 m .34462 .69696 L .35717 .70628 L p .707 .577 .707 r
F P
0 g
s
.18956 .61259 m .18891 .6681 L .17254 .67541 L p .707 .577 .707 r
F P
0 g
s
.35451 .61738 m .35385 .67289 L .3328 .6661 L p .707 .577 .707 r
F P
0 g
s
.3328 .6661 m .33345 .61059 L .35451 .61738 L p .707 .577 .707 r
F P
0 g
s
.16126 .72775 m .16363 .69103 L .17999 .68398 L p .707 .577 .707 r
F P
0 g
s
.16495 .82709 m .15691 .80968 L .16449 .80354 L p .707 .577 .707 r
F P
0 g
s
.16449 .80354 m .17253 .82095 L .16495 .82709 L p .707 .577 .707 r
F P
0 g
s
.18891 .6681 m .18956 .61259 L .21361 .60711 L p .707 .577 .707 r
F P
0 g
s
.33774 .74447 m .32971 .72706 L .34005 .7249 L p .707 .577 .707 r
F P
0 g
s
.37168 .77178 m .36343 .26908 L .38654 .25856 L p .707 .577 .707 r
F P
0 g
s
.36343 .26908 m .37168 .77178 L .36168 .78347 L p .707 .577 .707 r
F P
0 g
s
.17999 .68398 m .17762 .7207 L .16126 .72775 L p .707 .577 .707 r
F P
0 g
s
.33345 .61059 m .3328 .6661 L .30534 .66134 L p .707 .577 .707 r
F P
0 g
s
.30534 .66134 m .306 .60583 L .33345 .61059 L p .707 .577 .707 r
F P
0 g
s
.21361 .60711 m .21296 .66262 L .18891 .6681 L p .707 .577 .707 r
F P
0 g
s
.32971 .72706 m .33774 .74447 L .31952 .75066 L p .707 .577 .707 r
F P
0 g
s
.31952 .75066 m .31148 .73326 L .32971 .72706 L p .707 .577 .707 r
F P
0 g
s
.34462 .69696 m .34225 .73367 L .32125 .7254 L p .707 .577 .707 r
F P
0 g
s
.32125 .7254 m .32363 .68868 L .34462 .69696 L p .707 .577 .707 r
F P
0 g
s
.21296 .66262 m .21361 .60711 L .24299 .604 L p .707 .577 .707 r
F P
0 g
s
.17762 .7207 m .17999 .68398 L .20401 .67926 L p .707 .577 .707 r
F P
0 g
s
.61939 .25906 m .62764 .76176 L .59792 .75331 L p .707 .577 .707 r
F P
0 g
s
.59792 .75331 m .58967 .25061 L .61939 .25906 L p .707 .577 .707 r
F P
0 g
s
.17253 .82095 m .16449 .80354 L .18037 .79395 L p .707 .577 .707 r
F P
0 g
s
.306 .60583 m .30534 .66134 L .27417 .65907 L p .707 .577 .707 r
F P
0 g
s
.27417 .65907 m .27483 .60356 L .306 .60583 L p .707 .577 .707 r
F P
0 g
s
.18037 .79395 m .1884 .81136 L .17253 .82095 L p .707 .577 .707 r
F P
0 g
s
.24234 .65951 m .24299 .604 L .27483 .60356 L p .707 .577 .707 r
F P
0 g
s
.24299 .604 m .24234 .65951 L .21296 .66262 L p .707 .577 .707 r
F P
0 g
s
.20401 .67926 m .20164 .71598 L .17762 .7207 L p .707 .577 .707 r
F P
0 g
s
.27483 .60356 m .27417 .65907 L .24234 .65951 L p .707 .577 .707 r
F P
0 g
s
.74083 .65797 m .74149 .60246 L .71032 .60019 L p .707 .577 .707 r
F P
0 g
s
.74149 .60246 m .74083 .65797 L .77267 .65753 L p .707 .577 .707 r
F P
0 g
s
.77267 .65753 m .77332 .60202 L .74149 .60246 L p .707 .577 .707 r
F P
0 g
s
.32363 .68868 m .32125 .7254 L .29386 .71899 L p .707 .577 .707 r
F P
0 g
s
.29386 .71899 m .29623 .68228 L .32363 .68868 L p .707 .577 .707 r
F P
0 g
s
.77332 .60202 m .77267 .65753 L .80205 .65441 L p .707 .577 .707 r
F P
0 g
s
.80205 .65441 m .8027 .5989 L .77332 .60202 L p .707 .577 .707 r
F P
0 g
s
.38654 .25856 m .39479 .76126 L .37168 .77178 L p .707 .577 .707 r
F P
0 g
s
.39479 .76126 m .38654 .25856 L .42049 .25025 L p .707 .577 .707 r
F P
0 g
s
.70966 .6557 m .71032 .60019 L .68286 .59543 L p .707 .577 .707 r
F P
0 g
s
.71032 .60019 m .70966 .6557 L .74083 .65797 L p .707 .577 .707 r
F P
0 g
s
.20164 .71598 m .20401 .67926 L .23335 .67732 L p .707 .577 .707 r
F P
0 g
s
.8027 .5989 m .80205 .65441 L .8261 .64893 L p .707 .577 .707 r
F P
0 g
s
.8261 .64893 m .82675 .59342 L .8027 .5989 L p .707 .577 .707 r
F P
0 g
s
.29623 .68228 m .29386 .71899 L .26275 .71508 L p .707 .577 .707 r
F P
0 g
s
.26275 .71508 m .26513 .67836 L .29623 .68228 L p .707 .577 .707 r
F P
0 g
s
.1884 .81136 m .18037 .79395 L .20298 .78186 L p .707 .577 .707 r
F P
0 g
s
.23335 .67732 m .23098 .71404 L .20164 .71598 L p .707 .577 .707 r
F P
0 g
s
.20298 .78186 m .21101 .79926 L .1884 .81136 L p .707 .577 .707 r
F P
0 g
s
.31148 .73326 m .31952 .75066 L .29519 .76029 L p .707 .577 .707 r
F P
0 g
s
.29519 .76029 m .28716 .74289 L .31148 .73326 L p .707 .577 .707 r
F P
0 g
s
.23098 .71404 m .23335 .67732 L .26513 .67836 L p .707 .577 .707 r
F P
0 g
s
.58967 .25061 m .59792 .75331 L .55916 .74785 L p .707 .577 .707 r
F P
0 g
s
.55916 .74785 m .55091 .24514 L .58967 .25061 L p .707 .577 .707 r
F P
0 g
s
.68221 .65093 m .68286 .59543 L .66181 .58864 L p .707 .577 .707 r
F P
0 g
s
.68286 .59543 m .68221 .65093 L .70966 .6557 L p .707 .577 .707 r
F P
0 g
s
.26513 .67836 m .26275 .71508 L .23098 .71404 L p .707 .577 .707 r
F P
0 g
s
.72929 .72014 m .73166 .68342 L .70055 .6795 L p .707 .577 .707 r
F P
0 g
s
.73166 .68342 m .72929 .72014 L .76107 .72118 L p .707 .577 .707 r
F P
0 g
s
.76107 .72118 m .76344 .68446 L .73166 .68342 L p .707 .577 .707 r
F P
0 g
s
.76344 .68446 m .76107 .72118 L .7904 .71924 L p .707 .577 .707 r
F P
0 g
s
.7904 .71924 m .79277 .68252 L .76344 .68446 L p .707 .577 .707 r
F P
0 g
s
.42875 .75295 m .42049 .25025 L .46197 .24495 L p .707 .577 .707 r
F P
0 g
s
.42049 .25025 m .42875 .75295 L .39479 .76126 L p .707 .577 .707 r
F P
0 g
s
.69818 .71622 m .70055 .6795 L .67316 .6731 L p .707 .577 .707 r
F P
0 g
s
.70055 .6795 m .69818 .71622 L .72929 .72014 L p .707 .577 .707 r
F P
0 g
s
.82675 .59342 m .8261 .64893 L .84247 .64162 L p .707 .577 .707 r
F P
0 g
s
.84247 .64162 m .84312 .58611 L .82675 .59342 L p .707 .577 .707 r
F P
0 g
s
.21101 .79926 m .20298 .78186 L .23011 .76844 L p .707 .577 .707 r
F P
0 g
s
.28716 .74289 m .29519 .76029 L .26716 .77242 L p .707 .577 .707 r
F P
0 g
s
.26716 .77242 m .25912 .75501 L .28716 .74289 L p .707 .577 .707 r
F P
0 g
s
.23011 .76844 m .23815 .78585 L .21101 .79926 L p .707 .577 .707 r
F P
0 g
s
.66181 .58864 m .66115 .64415 L .68221 .65093 L p .707 .577 .707 r
F P
0 g
s
.79277 .68252 m .7904 .71924 L .81442 .71452 L p .707 .577 .707 r
F P
0 g
s
.81442 .71452 m .8168 .6778 L .79277 .68252 L p .707 .577 .707 r
F P
0 g
s
.55091 .24514 m .55916 .74785 L .51516 .7459 L p .707 .577 .707 r
F P
0 g
s
.51516 .7459 m .50691 .24319 L .55091 .24514 L p .707 .577 .707 r
F P
0 g
s
.72755 .74485 m .71952 .72745 L .69148 .73957 L p .707 .577 .707 r
F P
0 g
s
.71952 .72745 m .72755 .74485 L .75656 .73143 L p .707 .577 .707 r
F P
0 g
s
.75656 .73143 m .74852 .71402 L .71952 .72745 L p .707 .577 .707 r
F P
0 g
s
.67316 .6731 m .67079 .70981 L .69818 .71622 L p .707 .577 .707 r
F P
0 g
s
.74852 .71402 m .75656 .73143 L .7837 .71801 L p .707 .577 .707 r
F P
0 g
s
.7837 .71801 m .77566 .7006 L .74852 .71402 L p .707 .577 .707 r
F P
0 g
s
.69148 .73957 m .69951 .75698 L .72755 .74485 L p .707 .577 .707 r
F P
0 g
s
.66115 .64415 m .66181 .58864 L .64922 .58049 L p .707 .577 .707 r
F P
0 g
s
.23815 .78585 m .23011 .76844 L .25912 .75501 L p .707 .577 .707 r
F P
0 g
s
.25912 .75501 m .26716 .77242 L .23815 .78585 L p .707 .577 .707 r
F P
0 g
s
.67079 .70981 m .67316 .6731 L .65216 .66482 L p .707 .577 .707 r
F P
0 g
s
.47022 .74765 m .46197 .24495 L .50691 .24319 L p .707 .577 .707 r
F P
0 g
s
.46197 .24495 m .47022 .74765 L .42875 .75295 L p .707 .577 .707 r
F P
0 g
s
.50691 .24319 m .51516 .7459 L .47022 .74765 L p .707 .577 .707 r
F P
0 g
s
.69951 .75698 m .69148 .73957 L .66716 .7492 L p .707 .577 .707 r
F P
0 g
s
.77566 .7006 m .7837 .71801 L .80631 .70591 L p .707 .577 .707 r
F P
0 g
s
.80631 .70591 m .79827 .6885 L .77566 .7006 L p .707 .577 .707 r
F P
0 g
s
.66716 .7492 m .67519 .76661 L .69951 .75698 L p .707 .577 .707 r
F P
0 g
s
.65216 .66482 m .64979 .70154 L .67079 .70981 L p .707 .577 .707 r
F P
0 g
s
.64922 .58049 m .64856 .636 L .66115 .64415 L p .707 .577 .707 r
F P
0 g
s
.84312 .58611 m .84247 .64162 L .84955 .6332 L p .707 .577 .707 r
F P
0 g
s
.84955 .6332 m .85021 .57769 L .84312 .58611 L p .707 .577 .707 r
F P
0 g
s
.8168 .6778 m .81442 .71452 L .83078 .70747 L p .707 .577 .707 r
F P
0 g
s
.83078 .70747 m .83316 .67075 L .8168 .6778 L p .707 .577 .707 r
F P
0 g
s
.64979 .70154 m .65216 .66482 L .63962 .6555 L p .707 .577 .707 r
F P
0 g
s
.67519 .76661 m .66716 .7492 L .64893 .7554 L p .707 .577 .707 r
F P
0 g
s
.64893 .7554 m .65697 .77281 L .67519 .76661 L p .707 .577 .707 r
F P
0 g
s
.64856 .636 m .64922 .58049 L .64632 .57178 L p .707 .577 .707 r
F P
0 g
s
.79827 .6885 m .80631 .70591 L .82218 .69632 L p .707 .577 .707 r
F P
0 g
s
.82218 .69632 m .81414 .67892 L .79827 .6885 L p .707 .577 .707 r
F P
0 g
s
.63962 .6555 m .63724 .69222 L .64979 .70154 L p .707 .577 .707 r
F P
0 g
s
.64632 .57178 m .64567 .62729 L .64856 .636 L p .707 .577 .707 r
F P
0 g
s
.83316 .67075 m .83078 .70747 L .83788 .69878 L p .707 .577 .707 r
F P
0 g
s
.83788 .69878 m .84025 .66207 L .83316 .67075 L p .707 .577 .707 r
F P
0 g
s
.85021 .57769 m .84955 .6332 L .84666 .62449 L p .707 .577 .707 r
F P
0 g
s
.84666 .62449 m .84731 .56898 L .85021 .57769 L p .707 .577 .707 r
F P
0 g
s
.65697 .77281 m .64893 .7554 L .63858 .75755 L p .707 .577 .707 r
F P
0 g
s
.63724 .69222 m .63962 .6555 L .63675 .64603 L p .707 .577 .707 r
F P
0 g
s
.63858 .75755 m .64662 .77496 L .65697 .77281 L p .707 .577 .707 r
F P
0 g
s
.81414 .67892 m .82218 .69632 L .82976 .69018 L p .707 .577 .707 r
F P
0 g
s
.82976 .69018 m .82172 .67277 L .81414 .67892 L p .707 .577 .707 r
F P
0 g
s
.64567 .62729 m .64632 .57178 L .6534 .56335 L p .707 .577 .707 r
F P
0 g
s
.63675 .64603 m .63438 .68275 L .63724 .69222 L p .707 .577 .707 r
F P
0 g
s
.84025 .66207 m .83788 .69878 L .83501 .68932 L p .707 .577 .707 r
F P
0 g
s
.83501 .68932 m .83738 .6526 L .84025 .66207 L p .707 .577 .707 r
F P
0 g
s
.6534 .56335 m .65275 .61886 L .64567 .62729 L p .707 .577 .707 r
F P
0 g
s
.84731 .56898 m .84666 .62449 L .83407 .61634 L p .707 .577 .707 r
F P
0 g
s
.83407 .61634 m .83472 .56083 L .84731 .56898 L p .707 .577 .707 r
F P
0 g
s
.64662 .77496 m .63858 .75755 L .63713 .75546 L p .708 .578 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63713 .75546 m .64516 .77286 L .64662 .77496 L p .708 .578 .707 r
F P
0 g
s
.63438 .68275 m .63675 .64603 L .64384 .63735 L p .707 .577 .707 r
F P
0 g
s
.82172 .67277 m .82976 .69018 L .8283 .68808 L p .708 .578 .707 r
F P
0 g
s
.8283 .68808 m .82027 .67068 L .82172 .67277 L p .708 .578 .707 r
F P
0 g
s
.39782 .62248 m .39848 .56697 L .36731 .5647 L p .707 .577 .707 r
F P
0 g
s
.39848 .56697 m .39782 .62248 L .42966 .62204 L p .707 .577 .707 r
F P
0 g
s
.42966 .62204 m .43031 .56653 L .39848 .56697 L p .707 .577 .707 r
F P
0 g
s
.65275 .61886 m .6534 .56335 L .66977 .55604 L p .707 .577 .707 r
F P
0 g
s
.43031 .56653 m .42966 .62204 L .45904 .61892 L p .707 .577 .707 r
F P
0 g
s
.45904 .61892 m .45969 .56341 L .43031 .56653 L p .707 .577 .707 r
F P
0 g
s
.36665 .62021 m .36731 .5647 L .33985 .55994 L p .707 .577 .707 r
F P
0 g
s
.36731 .5647 m .36665 .62021 L .39782 .62248 L p .707 .577 .707 r
F P
0 g
s
.64384 .63735 m .64147 .67406 L .63438 .68275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45969 .56341 m .45904 .61892 L .48309 .61344 L p .707 .577 .707 r
F P
0 g
s
.48309 .61344 m .48374 .55793 L .45969 .56341 L p .707 .577 .707 r
F P
0 g
s
.82027 .67068 m .8283 .68808 L .81796 .69024 L p .707 .577 .707 r
F P
0 g
s
.83738 .6526 m .83501 .68932 L .82246 .67999 L p .707 .577 .707 r
F P
0 g
s
.82246 .67999 m .82484 .64327 L .83738 .6526 L p .707 .577 .707 r
F P
0 g
s
.66977 .55604 m .66912 .61155 L .65275 .61886 L p .707 .577 .707 r
F P
0 g
s
.83472 .56083 m .83407 .61634 L .81301 .60955 L p .707 .577 .707 r
F P
0 g
s
.81301 .60955 m .81367 .55404 L .83472 .56083 L p .707 .577 .707 r
F P
0 g
s
.3392 .61544 m .33985 .55994 L .3188 .55315 L p .707 .577 .707 r
F P
0 g
s
.33985 .55994 m .3392 .61544 L .36665 .62021 L p .707 .577 .707 r
F P
0 g
s
.38628 .68178 m .38865 .64506 L .35754 .64115 L p .707 .577 .707 r
F P
0 g
s
.38865 .64506 m .38628 .68178 L .41806 .68282 L p .707 .577 .707 r
F P
0 g
s
.41806 .68282 m .42043 .6461 L .38865 .64506 L p .707 .577 .707 r
F P
0 g
s
.64147 .67406 m .64384 .63735 L .6602 .6303 L p .707 .577 .707 r
F P
0 g
s
.64516 .77286 m .63713 .75546 L .64471 .74931 L p .707 .577 .707 r
F P
0 g
s
.66912 .61155 m .66977 .55604 L .69382 .55057 L p .707 .577 .707 r
F P
0 g
s
.64471 .74931 m .65274 .76672 L .64516 .77286 L p .707 .577 .707 r
F P
0 g
s
.42043 .6461 m .41806 .68282 L .44739 .68089 L p .707 .577 .707 r
F P
0 g
s
.44739 .68089 m .44977 .64417 L .42043 .6461 L p .707 .577 .707 r
F P
0 g
s
.81796 .69024 m .80992 .67283 L .82027 .67068 L p .707 .577 .707 r
F P
0 g
s
.35517 .67787 m .35754 .64115 L .33015 .63474 L p .707 .577 .707 r
F P
0 g
s
.35754 .64115 m .35517 .67787 L .38628 .68178 L p .707 .577 .707 r
F P
0 g
s
.48374 .55793 m .48309 .61344 L .49946 .60613 L p .707 .577 .707 r
F P
0 g
s
.49946 .60613 m .50011 .55062 L .48374 .55793 L p .707 .577 .707 r
F P
0 g
s
.6602 .6303 m .65783 .66702 L .64147 .67406 L p .707 .577 .707 r
F P
0 g
s
.3188 .55315 m .31814 .60866 L .3392 .61544 L p .707 .577 .707 r
F P
0 g
s
.81367 .55404 m .81301 .60955 L .78556 .60479 L p .707 .577 .707 r
F P
0 g
s
.78556 .60479 m .78621 .54928 L .81367 .55404 L p .707 .577 .707 r
F P
0 g
s
.44977 .64417 m .44739 .68089 L .47141 .67616 L p .707 .577 .707 r
F P
0 g
s
.47141 .67616 m .47379 .63944 L .44977 .64417 L p .707 .577 .707 r
F P
0 g
s
.33015 .63474 m .32778 .67146 L .35517 .67787 L p .707 .577 .707 r
F P
0 g
s
.38454 .70704 m .37651 .68964 L .34847 .70176 L p .707 .577 .707 r
F P
0 g
s
.37651 .68964 m .38454 .70704 L .41355 .69362 L p .707 .577 .707 r
F P
0 g
s
.41355 .69362 m .40551 .67621 L .37651 .68964 L p .707 .577 .707 r
F P
0 g
s
.40551 .67621 m .41355 .69362 L .44069 .6802 L p .707 .577 .707 r
F P
0 g
s
.44069 .6802 m .43265 .66279 L .40551 .67621 L p .707 .577 .707 r
F P
0 g
s
.69382 .55057 m .69317 .60607 L .66912 .61155 L p .707 .577 .707 r
F P
0 g
s
.34847 .70176 m .3565 .71917 L .38454 .70704 L p .707 .577 .707 r
F P
0 g
s
.80992 .67283 m .81796 .69024 L .79973 .69644 L p .707 .577 .707 r
F P
0 g
s
.79973 .69644 m .79169 .67903 L .80992 .67283 L p .707 .577 .707 r
F P
0 g
s
.82484 .64327 m .82246 .67999 L .80147 .67172 L p .707 .577 .707 r
F P
0 g
s
.80147 .67172 m .80384 .635 L .82484 .64327 L p .707 .577 .707 r
F P
0 g
s
.31814 .60866 m .3188 .55315 L .30621 .545 L p .707 .577 .707 r
F P
0 g
s
.32778 .67146 m .33015 .63474 L .30915 .62647 L p .707 .577 .707 r
F P
0 g
s
.69317 .60607 m .69382 .55057 L .72321 .54745 L p .707 .577 .707 r
F P
0 g
s
.3565 .71917 m .34847 .70176 L .32415 .71139 L p .707 .577 .707 r
F P
0 g
s
.65783 .66702 m .6602 .6303 L .68423 .62557 L p .707 .577 .707 r
F P
0 g
s
.43265 .66279 m .44069 .6802 L .4633 .6681 L p .707 .577 .707 r
F P
0 g
s
.4633 .6681 m .45526 .65069 L .43265 .66279 L p .707 .577 .707 r
F P
0 g
s
.32415 .71139 m .33218 .7288 L .3565 .71917 L p .707 .577 .707 r
F P
0 g
s
.78621 .54928 m .78556 .60479 L .75439 .60252 L p .707 .577 .707 r
F P
0 g
s
.75439 .60252 m .75504 .54701 L .78621 .54928 L p .707 .577 .707 r
F P
0 g
s
.65274 .76672 m .64471 .74931 L .66058 .73972 L p .707 .577 .707 r
F P
0 g
s
.30915 .62647 m .30678 .66319 L .32778 .67146 L p .707 .577 .707 r
F P
0 g
s
.66058 .73972 m .66862 .75713 L .65274 .76672 L p .707 .577 .707 r
F P
0 g
s
.72255 .60296 m .72321 .54745 L .75504 .54701 L p .707 .577 .707 r
F P
0 g
s
.72321 .54745 m .72255 .60296 L .69317 .60607 L p .707 .577 .707 r
F P
0 g
s
.30621 .545 m .30555 .60051 L .31814 .60866 L p .707 .577 .707 r
F P
0 g
s
.50011 .55062 m .49946 .60613 L .50654 .59771 L p .707 .577 .707 r
F P
0 g
s
.50654 .59771 m .5072 .5422 L .50011 .55062 L p .707 .577 .707 r
F P
0 g
s
.47379 .63944 m .47141 .67616 L .48777 .66911 L p .707 .577 .707 r
F P
0 g
s
.48777 .66911 m .49015 .63239 L .47379 .63944 L p .707 .577 .707 r
F P
0 g
s
.75504 .54701 m .75439 .60252 L .72255 .60296 L p .707 .577 .707 r
F P
0 g
s
.68423 .62557 m .68185 .66229 L .65783 .66702 L p .707 .577 .707 r
F P
0 g
s
.80384 .635 m .80147 .67172 L .77407 .66531 L p .707 .577 .707 r
F P
0 g
s
.77407 .66531 m .77645 .62859 L .80384 .635 L p .707 .577 .707 r
F P
0 g
s
.30678 .66319 m .30915 .62647 L .29661 .61714 L p .707 .577 .707 r
F P
0 g
s
.33218 .7288 m .32415 .71139 L .30592 .71759 L p .707 .577 .707 r
F P
0 g
s
.30592 .71759 m .31396 .73499 L .33218 .7288 L p .707 .577 .707 r
F P
0 g
s
.45526 .65069 m .4633 .6681 L .47917 .65851 L p .707 .577 .707 r
F P
0 g
s
.47917 .65851 m .47113 .6411 L .45526 .65069 L p .707 .577 .707 r
F P
0 g
s
.68185 .66229 m .68423 .62557 L .71356 .62364 L p .707 .577 .707 r
F P
0 g
s
.30555 .60051 m .30621 .545 L .30331 .53629 L p .707 .577 .707 r
F P
0 g
s
.29661 .61714 m .29423 .65386 L .30678 .66319 L p .707 .577 .707 r
F P
0 g
s
.77645 .62859 m .77407 .66531 L .74297 .6614 L p .707 .577 .707 r
F P
0 g
s
.74297 .6614 m .74534 .62468 L .77645 .62859 L p .707 .577 .707 r
F P
0 g
s
.66862 .75713 m .66058 .73972 L .68319 .72763 L p .707 .577 .707 r
F P
0 g
s
.71356 .62364 m .71119 .66036 L .68185 .66229 L p .707 .577 .707 r
F P
0 g
s
.68319 .72763 m .69123 .74504 L .66862 .75713 L p .707 .577 .707 r
F P
0 g
s
.79169 .67903 m .79973 .69644 L .77541 .70607 L p .707 .577 .707 r
F P
0 g
s
.77541 .70607 m .76737 .68866 L .79169 .67903 L p .707 .577 .707 r
F P
0 g
s
.71119 .66036 m .71356 .62364 L .74534 .62468 L p .707 .577 .707 r
F P
0 g
s
.49015 .63239 m .48777 .66911 L .49487 .66043 L p .707 .577 .707 r
F P
0 g
s
.49487 .66043 m .49724 .62371 L .49015 .63239 L p .707 .577 .707 r
F P
0 g
s
.74534 .62468 m .74297 .6614 L .71119 .66036 L p .707 .577 .707 r
F P
0 g
s
.30331 .53629 m .30266 .59179 L .30555 .60051 L p .707 .577 .707 r
F P
0 g
s
.5072 .5422 m .50654 .59771 L .50365 .589 L p .707 .577 .707 r
F P
0 g
s
.50365 .589 m .5043 .53349 L .5072 .5422 L p .707 .577 .707 r
F P
0 g
s
.31396 .73499 m .30592 .71759 L .29557 .71974 L p .707 .577 .707 r
F P
0 g
s
.29423 .65386 m .29661 .61714 L .29374 .60767 L p .707 .577 .707 r
F P
0 g
s
.29557 .71974 m .30361 .73715 L .31396 .73499 L p .707 .577 .707 r
F P
0 g
s
.47113 .6411 m .47917 .65851 L .48675 .65237 L p .707 .577 .707 r
F P
0 g
s
.48675 .65237 m .47871 .63496 L .47113 .6411 L p .707 .577 .707 r
F P
0 g
s
.69123 .74504 m .68319 .72763 L .71033 .71421 L p .707 .577 .707 r
F P
0 g
s
.76737 .68866 m .77541 .70607 L .74737 .71819 L p .707 .577 .707 r
F P
0 g
s
.74737 .71819 m .73934 .70078 L .76737 .68866 L p .707 .577 .707 r
F P
0 g
s
.71033 .71421 m .71836 .73162 L .69123 .74504 L p .707 .577 .707 r
F P
0 g
s
.30266 .59179 m .30331 .53629 L .31039 .52786 L p .707 .577 .707 r
F P
0 g
s
.29374 .60767 m .29137 .64439 L .29423 .65386 L p .707 .577 .707 r
F P
0 g
s
.71836 .73162 m .71033 .71421 L .73934 .70078 L p .707 .577 .707 r
F P
0 g
s
.73934 .70078 m .74737 .71819 L .71836 .73162 L p .707 .577 .707 r
F P
0 g
s
.49724 .62371 m .49487 .66043 L .492 .65096 L p .707 .577 .707 r
F P
0 g
s
.492 .65096 m .49437 .61424 L .49724 .62371 L p .707 .577 .707 r
F P
0 g
s
.31039 .52786 m .30974 .58337 L .30266 .59179 L p .707 .577 .707 r
F P
0 g
s
.5043 .53349 m .50365 .589 L .49106 .58085 L p .707 .577 .707 r
F P
0 g
s
.49106 .58085 m .49171 .52534 L .5043 .53349 L p .707 .577 .707 r
F P
0 g
s
.30361 .73715 m .29557 .71974 L .29412 .71764 L p .708 .578 .707 r
F P
0 g
s
.29137 .64439 m .29374 .60767 L .30083 .59899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29412 .71764 m .30215 .73505 L .30361 .73715 L p .708 .578 .707 r
F P
0 g
s
.47871 .63496 m .48675 .65237 L .48529 .65027 L p .708 .578 .707 r
F P
0 g
s
.48529 .65027 m .47726 .63286 L .47871 .63496 L p .708 .578 .707 r
F P
0 g
s
.30974 .58337 m .31039 .52786 L .32676 .52055 L p .707 .577 .707 r
F P
0 g
s
.30083 .59899 m .29846 .63571 L .29137 .64439 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47726 .63286 m .48529 .65027 L .47495 .65243 L p .707 .577 .707 r
F P
0 g
s
.49437 .61424 m .492 .65096 L .47945 .64163 L p .707 .577 .707 r
F P
0 g
s
.47945 .64163 m .48183 .60492 L .49437 .61424 L p .707 .577 .707 r
F P
0 g
s
.32676 .52055 m .32611 .57606 L .30974 .58337 L p .707 .577 .707 r
F P
0 g
s
.49171 .52534 m .49106 .58085 L .47 .57406 L p .707 .577 .707 r
F P
0 g
s
.47 .57406 m .47066 .51855 L .49171 .52534 L p .707 .577 .707 r
F P
0 g
s
.29846 .63571 m .30083 .59899 L .31719 .59194 L p .707 .577 .707 r
F P
0 g
s
.30215 .73505 m .29412 .71764 L .3017 .7115 L p .707 .577 .707 r
F P
0 g
s
.3017 .7115 m .30973 .72891 L .30215 .73505 L p .707 .577 .707 r
F P
0 g
s
.32611 .57606 m .32676 .52055 L .35081 .51507 L p .707 .577 .707 r
F P
0 g
s
.47495 .65243 m .46691 .63502 L .47726 .63286 L p .707 .577 .707 r
F P
0 g
s
.31719 .59194 m .31482 .62866 L .29846 .63571 L p .707 .577 .707 r
F P
0 g
s
.47066 .51855 m .47 .57406 L .44255 .5693 L p .707 .577 .707 r
F P
0 g
s
.44255 .5693 m .4432 .51379 L .47066 .51855 L p .707 .577 .707 r
F P
0 g
s
.35081 .51507 m .35016 .57058 L .32611 .57606 L p .707 .577 .707 r
F P
0 g
s
.46691 .63502 m .47495 .65243 L .45672 .65862 L p .707 .577 .707 r
F P
0 g
s
.45672 .65862 m .44868 .64122 L .46691 .63502 L p .707 .577 .707 r
F P
0 g
s
.48183 .60492 m .47945 .64163 L .45846 .63336 L p .707 .577 .707 r
F P
0 g
s
.45846 .63336 m .46083 .59664 L .48183 .60492 L p .707 .577 .707 r
F P
0 g
s
.35016 .57058 m .35081 .51507 L .3802 .51196 L p .707 .577 .707 r
F P
0 g
s
.31482 .62866 m .31719 .59194 L .34122 .58722 L p .707 .577 .707 r
F P
0 g
s
.30973 .72891 m .3017 .7115 L .31757 .70191 L p .707 .577 .707 r
F P
0 g
s
.4432 .51379 m .44255 .5693 L .41138 .56703 L p .707 .577 .707 r
F P
0 g
s
.41138 .56703 m .41203 .51152 L .4432 .51379 L p .707 .577 .707 r
F P
0 g
s
.31757 .70191 m .3256 .71932 L .30973 .72891 L p .707 .577 .707 r
F P
0 g
s
.37954 .56747 m .3802 .51196 L .41203 .51152 L p .707 .577 .707 r
F P
0 g
s
.3802 .51196 m .37954 .56747 L .35016 .57058 L p .707 .577 .707 r
F P
0 g
s
.34122 .58722 m .33884 .62394 L .31482 .62866 L p .707 .577 .707 r
F P
0 g
s
.41203 .51152 m .41138 .56703 L .37954 .56747 L p .707 .577 .707 r
F P
0 g
s
.46083 .59664 m .45846 .63336 L .43106 .62696 L p .707 .577 .707 r
F P
0 g
s
.43106 .62696 m .43344 .59024 L .46083 .59664 L p .707 .577 .707 r
F P
0 g
s
.33884 .62394 m .34122 .58722 L .37055 .58528 L p .707 .577 .707 r
F P
0 g
s
.43344 .59024 m .43106 .62696 L .39996 .62304 L p .707 .577 .707 r
F P
0 g
s
.39996 .62304 m .40233 .58632 L .43344 .59024 L p .707 .577 .707 r
F P
0 g
s
.3256 .71932 m .31757 .70191 L .34018 .68982 L p .707 .577 .707 r
F P
0 g
s
.37055 .58528 m .36818 .622 L .33884 .62394 L p .707 .577 .707 r
F P
0 g
s
.34018 .68982 m .34822 .70723 L .3256 .71932 L p .707 .577 .707 r
F P
0 g
s
.44868 .64122 m .45672 .65862 L .4324 .66826 L p .707 .577 .707 r
F P
0 g
s
.4324 .66826 m .42436 .65085 L .44868 .64122 L p .707 .577 .707 r
F P
0 g
s
.36818 .622 m .37055 .58528 L .40233 .58632 L p .707 .577 .707 r
F P
0 g
s
.40233 .58632 m .39996 .62304 L .36818 .622 L p .707 .577 .707 r
F P
0 g
s
.34822 .70723 m .34018 .68982 L .36732 .6764 L p .707 .577 .707 r
F P
0 g
s
.42436 .65085 m .4324 .66826 L .40436 .68038 L p .707 .577 .707 r
F P
0 g
s
.40436 .68038 m .39632 .66297 L .42436 .65085 L p .707 .577 .707 r
F P
0 g
s
.36732 .6764 m .37535 .69381 L .34822 .70723 L p .707 .577 .707 r
F P
0 g
s
.37535 .69381 m .36732 .6764 L .39632 .66297 L p .707 .577 .707 r
F P
0 g
s
.39632 .66297 m .40436 .68038 L .37535 .69381 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00
FUIJEP0A000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol0069oo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool005ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005ao
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00FWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000BOolA
0012Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000jOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<Goo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;goo001FOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;Goo001FOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0`00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001J
EUYF009JEP@0009JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ao
o`00EWoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@0015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`04001JEP00FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00<0
05YFFUH00eYF00<005YFFUH00eYF4@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000AJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00@005YFFUIJEPP000=J
EP03001JEUYF00IJEP03001JEUYF009JEPH000EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001JEUYF00D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP09001JEUYFFUH005YF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:goo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH01000FUIJEUYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo0011OolA0002Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo000kOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH80008FUH00`00
FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool003Moo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEPD0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF008002]o
o`00=Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000[Ool003=oo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000015YF000000001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF0000009JEP8002]oo`00<Goo0P000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF1000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEQL000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<002]oo`00;goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH500000eYF001J
EP04FUH20002FUH00`00FUIJEP04FUH30004FUH60006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<0
05YF00000`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00:goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000AJEP000000009JEP03001JEUYF
00=JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001J
EUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF0`00
1EYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF100015YF00H005YFFUH005YF0004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP02
FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEP0000<00003FUH00000009J
EP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP800006FUH00000001JEP000UYF00<005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000800003FUH005YF00=JEP8002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF
1`001EYF0`001eYF00<005YFFUH00UYF0`0015YF00@005YF0000009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP80
02eoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF500000=JEP00
FUH01EYF00D005YFFUH005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP00009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000_Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=J
EP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH00eYF0`0000AJEP00000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH01eYF00<005YF00000P0000=JEP00FUH010001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000=J
EP<000EJEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3
0004FUH2000015YF001JEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP04001JEUYF
FUH90008FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
0007FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPT0009JEP03001oogoo
00=oo`T000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00
;goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01EYF00<005YFFUH01UYF10002EYF00@005YF000000EJEP800003FUH005YF009JEP80
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40002
FUH00`00FUIJEP03FUH00`00FUIJEP020006Ool30004Ool60005FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002moo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJEP8000=JEP03
001JEUYF00EJEP<000EJEP8000=JEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUH005YF001JEP800004FUH000000002FUH00`00FUIJEP03FUH00`00
FUIJEP020005Ool50009Ool400000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002mo
o`03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH400000eYF001JEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01@00FUIJ
EUYF00001EYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEP00FUH200000eYF001JEP03FUH30005FUH00`00FUIJEP020005Ool5000=Ool30004FUH01000
FUIJEUYF0P00;Woo000_Ool01@00FUH005YF00001EYF00<005YFFUH00eYF3`001EYF00<005YFFUH0
1EYF00<005YFFUH015YF200025YF00<005YF00000P001EYF00@005YF000000=JEPD000YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00
FUH00003000015YF001JEUYF0P001Goo1@003Woo1@0000=JEP00FUH00UYF0P00;Woo000_Ool20002
FUH01000FUIJEUYF20000eYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH01UYF00<005YF
FUH015YF00@005YFFUIJEP<000UJEP8000UJEPH0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH6
0006Ool3000<Ool30004FUH30003FUH2000^Ool002moo`03001JEUYF00D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPH000=JEP03001JEUYF00AJEP04001JEP000003FUH00`00
FUIJEP04FUH300000eYF001JEP05FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQD00003FUH005YF00AJEP04001JEUYF0002FUH2000^Ool002moo`<00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH20005FUH00`00
FUIJEP02FUH500000eYF001JEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00@005YF000000IJEP03001JEUYF00=JEP03001JEP0000@002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000=JEP00000025YF00<005YF00001P000UYF00<005YF00000P002eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEUYF009J
EP<00003FUH00000008002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF0P000eYF0`000eYF0P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH00`00FUIJEP05FUH01000FUH000000UYF0P0000AJEP00000002ioo`00;7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YFFUH015YF0`00
15YF00H005YFFUH005YF000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000QJEP03001JEP0000<0009JEP03001JEUYF008000=JEP8002moo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001eYF00@005YF000000MJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001UYF
00000000FUH000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP8000MJEP<000AJEP8002moo`00
;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00P000eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF0`001UYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P0000=JEP00FUH015YF0P000UYF
00@005YFFUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH010000UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF0P000eYF00@005YFFUIJEP8000AJEP04001JEP00000bOol002aoo`80
00AJEP04001JEUYFFUHI0004FUH200000eYF001JEP04FUH01000FUH000001EYF00<005YF00000P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF20002EYF00@005YF0000
00IJEP<000=JEPD003Aoo`00:goo00<005YF00000eYF1@006Goo1@000UYF00<005YFFUH00eYF0P00
1UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P000UYF00<005YFFUH01eYF0P001eYF1`00>Goo000[Ool01000FUH005YF0P00
00AJEP00000001=oo`<000Qoo`05001JEUYFFUH00003FUH00`00FUH00004FUH200000eYF00000002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH30004FUH0
0`00FUIJEP05FUH40005FUH20010Ool002]oo`06001JEP00001JEP0015YF0`003goo1@0027oo00D0
05YFFUH005YF008000=JEP04001JEP000002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH30004FUH20007FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P00@Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000;Ool50008Ool01@00FUIJEUYF
000015YF0`0000MJEP00FUIJEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20004FUH60008FUH00`00FUIJEP02000015YF000000000UYF0`00A7oo000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH70004Ool50009Ool015YF000000000UYF0P0000=JEP00FUH0
0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`000eYF
00<005YFFUH01EYF0`001UYF0P00Agoo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUHH0004FUH01@00FUH00000FUH00`000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF0P00BGoo
000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUH000020005FUH01000FUH00000
Bgoo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0`001UYF00<005YFFUH00eYF20000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000AJEP00FUH000MJEP8000QJEP8004eoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00MJEP03001JEP0000800003FUH005YF
00D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQh000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP800003FUH005YF00EJEP8004moo`00;Goo0P00
00=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP<000AJEP03001JEUYF
00AJEP<000EJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF
1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF009JEP80055oo`00;goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF009JEP80009JEP04001JEUYF
FUH20002FUH200001Goo001JEUYF00001UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00`001EYF00@005YF0000
00EJEP04001JEP00001COol0035oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@000UJEP04
001JEP000005FUH40003FUH200001Goo001JEUYF00001UYF00<005YFFUH010002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00AJEP<005Eoo`00<goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
0P000eYF00<005YFFUH01EYF0`001eYF00@005YFFUH000=JEP04001oogoo0002FUH00`00FUIJEP03
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH40002FUH200000eYF001JEP02FUH30002FUH40002FUH00`00Oomoo`1COol003Eoo`D0
00=JEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP8000=JEP04
001JEP000003Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP800004FUH005YFFUH30002FUH3
00000eYF001JEP02FUH2001EOol003Yoo`H00003FUH0000000QJEP03001JEP00008000EJEP03001J
EUYF0080009JEPD000Eoo`05001JEUYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH200000eYF
0000000300000eYF001JEP02FUH2001EOol003moo`<000UJEP8000UJEPH000Yoo`03001JEUYF0080
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000@000AJEP<000=JEP8005Eoo`00?Goo
0P000eYF00<005YFFUH015YF0`0000=JEP00FUH01EYF0P0047oo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00H005YF000005YF0005FUH01000FUIJEP000UYF0P00EGoo000kOol20005
FUH00`00FUIJEP02FUH500000eYF001JEP03FUH2000BOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00001000EGoo000iOol20008FUH00`00
FUH000060002FUH01000FUH0000057oo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF009JEP<00003FUH00000008005Eoo`00=goo0`002EYF0P000eYF0`000eYF
0P005Woo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YF0000009J
EP800004FUH00000001EOol003Eoo`8000=JEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80
01Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000AJEP06001JEUYF001JEP00
EGoo000cOol20005FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2000KOol00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP020003FUH2001FOol0035oo`<0
00MJEP04001JEP000007FUH01000FUH000007Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001eYF0`0015YF0P00EWoo000_Ool20003FUH00`00FUIJEP04FUH30007FUH3000POol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0000=JEP00FUH015YF0P000UYF00@005YFFUIJEP80
05Moo`00;Woo00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P009Goo0P00
00=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000=JEP04001JEUYFFUH20004FUH01000FUH00000FGoo000]Ool0
0`00FUH00005FUH01000FUH000001EYF00<005YF00000P00:Goo0`001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10001UYF0`000eYF1@00
Fgoo000/Ool01000FUIJEP001EYF0P001UYF0`00;goo10000UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01`0025YF1P00H7oo000/Ool01@00FUIJ
EUYF00000eYF00<005YF000015YF0P00=Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF1@0000=JEP00000010001UYF0P00IWoo000]Ool01@00FUIJEP00FUH00P000eYF00@0
05YF000003eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH600000eYF001J
EP03FUH500000eYF001JEP02FUH2001XOol002eoo`05001JEUYFFUH00004FUH30015OolO0007FUH0
0`00FUIJEP0700000eYF001JEP02001ZOol002ioo`04FUH000000002FUH2001ROol200000eYF001J
EP08FUH20003FUH30002FUH2001/Ool002ioo`H0069oo`8000AJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP<006ioo`00U7oo0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00`00LGoo002C
Ool00`00FUH00007FUH01000FUH000001UYF0P00M7oo002AOol20002FUH00`00FUIJEP05FUH20006
FUH2001fOol0091oo`03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00=JEP8007Qoo`00
SWoo0`001EYF00<005YFFUH00P0015YF00@005YF000007Yoo`00SWoo00@005YFFUH000EJEP8000EJ
EP<007aoo`00SWoo0P0000=JEP00FUH00UYF0`0015YF0P00Ogoo002?Ool00`00FUIJEP030003FUH0
1000FUH00000PGoo002?Ool00`00FUIJEP020002FUH40023Ool0091oo`H008Moo`00T7oo0P00Rgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60363 .75001 m .60428 .6945 L .57311 .69223 L p .707 .577 .707 r
F P
0 g
s
.60428 .6945 m .60363 .75001 L .63546 .74956 L p .707 .577 .707 r
F P
0 g
s
.63546 .74956 m .63612 .69406 L .60428 .6945 L p .707 .577 .707 r
F P
0 g
s
.63612 .69406 m .63546 .74956 L .66484 .74645 L p .707 .577 .707 r
F P
0 g
s
.66484 .74645 m .6655 .69094 L .63612 .69406 L p .707 .577 .707 r
F P
0 g
s
.57246 .74774 m .57311 .69223 L .54566 .68747 L p .707 .577 .707 r
F P
0 g
s
.57311 .69223 m .57246 .74774 L .60363 .75001 L p .707 .577 .707 r
F P
0 g
s
.6655 .69094 m .66484 .74645 L .6889 .74097 L p .707 .577 .707 r
F P
0 g
s
.6889 .74097 m .68955 .68546 L .6655 .69094 L p .707 .577 .707 r
F P
0 g
s
.545 .74297 m .54566 .68747 L .5246 .68068 L p .707 .577 .707 r
F P
0 g
s
.54566 .68747 m .545 .74297 L .57246 .74774 L p .707 .577 .707 r
F P
0 g
s
.59208 .81217 m .59446 .77546 L .56335 .77154 L p .707 .577 .707 r
F P
0 g
s
.59446 .77546 m .59208 .81217 L .62386 .81321 L p .707 .577 .707 r
F P
0 g
s
.62386 .81321 m .62623 .7765 L .59446 .77546 L p .707 .577 .707 r
F P
0 g
s
.62623 .7765 m .62386 .81321 L .6532 .81128 L p .707 .577 .707 r
F P
0 g
s
.6532 .81128 m .65557 .77456 L .62623 .7765 L p .707 .577 .707 r
F P
0 g
s
.56098 .80826 m .56335 .77154 L .53596 .76513 L p .707 .577 .707 r
F P
0 g
s
.56335 .77154 m .56098 .80826 L .59208 .81217 L p .707 .577 .707 r
F P
0 g
s
.68955 .68546 m .6889 .74097 L .70526 .73366 L p .707 .577 .707 r
F P
0 g
s
.70526 .73366 m .70592 .67815 L .68955 .68546 L p .707 .577 .707 r
F P
0 g
s
.5246 .68068 m .52395 .73619 L .545 .74297 L p .707 .577 .707 r
F P
0 g
s
.65557 .77456 m .6532 .81128 L .67722 .80655 L p .707 .577 .707 r
F P
0 g
s
.67722 .80655 m .67959 .76984 L .65557 .77456 L p .707 .577 .707 r
F P
0 g
s
.59035 .83689 m .58231 .81948 L .55427 .83161 L p .707 .577 .707 r
F P
0 g
s
.58231 .81948 m .59035 .83689 L .61935 .82346 L p .707 .577 .707 r
F P
0 g
s
.61935 .82346 m .61132 .80606 L .58231 .81948 L p .707 .577 .707 r
F P
0 g
s
.53596 .76513 m .53358 .80185 L .56098 .80826 L p .707 .577 .707 r
F P
0 g
s
.61132 .80606 m .61935 .82346 L .64649 .81005 L p .707 .577 .707 r
F P
0 g
s
.64649 .81005 m .63846 .79264 L .61132 .80606 L p .707 .577 .707 r
F P
0 g
s
.55427 .83161 m .56231 .84902 L .59035 .83689 L p .707 .577 .707 r
F P
0 g
s
.52395 .73619 m .5246 .68068 L .51201 .67253 L p .707 .577 .707 r
F P
0 g
s
.53358 .80185 m .53596 .76513 L .51496 .75686 L p .707 .577 .707 r
F P
0 g
s
.56231 .84902 m .55427 .83161 L .52995 .84124 L p .707 .577 .707 r
F P
0 g
s
.63846 .79264 m .64649 .81005 L .6691 .79795 L p .707 .577 .707 r
F P
0 g
s
.6691 .79795 m .66107 .78054 L .63846 .79264 L p .707 .577 .707 r
F P
0 g
s
.52995 .84124 m .53799 .85865 L .56231 .84902 L p .707 .577 .707 r
F P
0 g
s
.51496 .75686 m .51259 .79358 L .53358 .80185 L p .707 .577 .707 r
F P
0 g
s
.51201 .67253 m .51136 .72804 L .52395 .73619 L p .707 .577 .707 r
F P
0 g
s
.70592 .67815 m .70526 .73366 L .71235 .72524 L p .707 .577 .707 r
F P
0 g
s
.71235 .72524 m .713 .66973 L .70592 .67815 L p .707 .577 .707 r
F P
0 g
s
.67959 .76984 m .67722 .80655 L .69358 .79951 L p .707 .577 .707 r
F P
0 g
s
.69358 .79951 m .69595 .76279 L .67959 .76984 L p .707 .577 .707 r
F P
0 g
s
.51259 .79358 m .51496 .75686 L .50241 .74754 L p .707 .577 .707 r
F P
0 g
s
.53799 .85865 m .52995 .84124 L .51173 .84743 L p .707 .577 .707 r
F P
0 g
s
.51173 .84743 m .51976 .86484 L .53799 .85865 L p .707 .577 .707 r
F P
0 g
s
.51136 .72804 m .51201 .67253 L .50912 .66382 L p .707 .577 .707 r
F P
0 g
s
.66107 .78054 m .6691 .79795 L .68497 .78836 L p .707 .577 .707 r
F P
0 g
s
.68497 .78836 m .67694 .77095 L .66107 .78054 L p .707 .577 .707 r
F P
0 g
s
.50241 .74754 m .50004 .78425 L .51259 .79358 L p .707 .577 .707 r
F P
0 g
s
.50912 .66382 m .50846 .71932 L .51136 .72804 L p .707 .577 .707 r
F P
0 g
s
.69595 .76279 m .69358 .79951 L .70067 .79082 L p .707 .577 .707 r
F P
0 g
s
.70067 .79082 m .70305 .7541 L .69595 .76279 L p .707 .577 .707 r
F P
0 g
s
.713 .66973 m .71235 .72524 L .70945 .71653 L p .707 .577 .707 r
F P
0 g
s
.70945 .71653 m .71011 .66102 L .713 .66973 L p .707 .577 .707 r
F P
0 g
s
.51976 .86484 m .51173 .84743 L .50138 .84959 L p .707 .577 .707 r
F P
0 g
s
.50004 .78425 m .50241 .74754 L .49955 .73807 L p .707 .577 .707 r
F P
0 g
s
.50138 .84959 m .50941 .867 L .51976 .86484 L p .707 .577 .707 r
F P
0 g
s
.67694 .77095 m .68497 .78836 L .69255 .78222 L p .707 .577 .707 r
F P
0 g
s
.69255 .78222 m .68452 .76481 L .67694 .77095 L p .707 .577 .707 r
F P
0 g
s
.50846 .71932 m .50912 .66382 L .5162 .65539 L p .707 .577 .707 r
F P
0 g
s
.49602 .82167 m .48777 .31897 L .44377 .31702 L p .707 .577 .707 r
F P
0 g
s
.49955 .73807 m .49717 .77479 L .50004 .78425 L p .707 .577 .707 r
F P
0 g
s
.5162 .65539 m .51555 .7109 L .50846 .71932 L p .707 .577 .707 r
F P
0 g
s
.49717 .77479 m .49955 .73807 L .50664 .72938 L p .707 .577 .707 r
F P
0 g
s
.51555 .7109 m .5162 .65539 L .53257 .64808 L p .707 .577 .707 r
F P
0 g
s
.50664 .72938 m .50427 .7661 L .49717 .77479 L p .707 .577 .707 r
F P
0 g
s
.53257 .64808 m .53192 .70359 L .51555 .7109 L p .707 .577 .707 r
F P
0 g
s
.50427 .7661 m .50664 .72938 L .523 .72234 L p .707 .577 .707 r
F P
0 g
s
.523 .72234 m .52063 .75905 L .50427 .7661 L p .707 .577 .707 r
F P
0 g
s
.52063 .75905 m .523 .72234 L .54702 .71761 L p .707 .577 .707 r
F P
0 g
s
.54702 .71761 m .54465 .75433 L .52063 .75905 L p .707 .577 .707 r
F P
0 g
s
.48777 .31897 m .49602 .82167 L .54096 .81991 L p .707 .577 .707 r
F P
0 g
s
.53192 .70359 m .53257 .64808 L .55662 .6426 L p .707 .577 .707 r
F P
0 g
s
.55662 .6426 m .55597 .69811 L .53192 .70359 L p .707 .577 .707 r
F P
0 g
s
.54096 .81991 m .53271 .31721 L .48777 .31897 L p .707 .577 .707 r
F P
0 g
s
.55597 .69811 m .55662 .6426 L .586 .63949 L p .707 .577 .707 r
F P
0 g
s
.586 .63949 m .58535 .695 L .55597 .69811 L p .707 .577 .707 r
F P
0 g
s
.54465 .75433 m .54702 .71761 L .57636 .71568 L p .707 .577 .707 r
F P
0 g
s
.57636 .71568 m .57398 .75239 L .54465 .75433 L p .707 .577 .707 r
F P
0 g
s
.57398 .75239 m .57636 .71568 L .60814 .71672 L p .707 .577 .707 r
F P
0 g
s
.60814 .71672 m .60576 .75343 L .57398 .75239 L p .707 .577 .707 r
F P
0 g
s
.55402 .83707 m .54599 .81967 L .57312 .80625 L p .707 .577 .707 r
F P
0 g
s
.57312 .80625 m .58116 .82366 L .55402 .83707 L p .707 .577 .707 r
F P
0 g
s
.58116 .82366 m .57312 .80625 L .60213 .79282 L p .707 .577 .707 r
F P
0 g
s
.53271 .31721 m .54096 .81991 L .58244 .81461 L p .707 .577 .707 r
F P
0 g
s
.58244 .81461 m .57419 .31191 L .53271 .31721 L p .707 .577 .707 r
F P
0 g
s
.45202 .81972 m .44377 .31702 L .40501 .31155 L p .707 .577 .707 r
F P
0 g
s
.44377 .31702 m .45202 .81972 L .49602 .82167 L p .707 .577 .707 r
F P
0 g
s
.70305 .7541 m .70067 .79082 L .69781 .78135 L p .707 .577 .707 r
F P
0 g
s
.69781 .78135 m .70018 .74464 L .70305 .7541 L p .707 .577 .707 r
F P
0 g
s
.71011 .66102 m .70945 .71653 L .69686 .70838 L p .707 .577 .707 r
F P
0 g
s
.69686 .70838 m .69751 .65287 L .71011 .66102 L p .707 .577 .707 r
F P
0 g
s
.58535 .695 m .586 .63949 L .61783 .63905 L p .707 .577 .707 r
F P
0 g
s
.61783 .63905 m .61718 .69456 L .58535 .695 L p .707 .577 .707 r
F P
0 g
s
.63924 .72063 m .63687 .75735 L .60576 .75343 L p .707 .577 .707 r
F P
0 g
s
.60576 .75343 m .60814 .71672 L .63924 .72063 L p .707 .577 .707 r
F P
0 g
s
.63017 .7807 m .6382 .79811 L .61017 .81023 L p .707 .577 .707 r
F P
0 g
s
.61017 .81023 m .60213 .79282 L .63017 .7807 L p .707 .577 .707 r
F P
0 g
s
.60213 .79282 m .61017 .81023 L .58116 .82366 L p .707 .577 .707 r
F P
0 g
s
.57419 .31191 m .58244 .81461 L .61639 .8063 L p .707 .577 .707 r
F P
0 g
s
.61639 .8063 m .60814 .3036 L .57419 .31191 L p .707 .577 .707 r
F P
0 g
s
.50941 .867 m .50138 .84959 L .49992 .84749 L p .708 .578 .707 r
F P
0 g
s
.49992 .84749 m .50796 .8649 L .50941 .867 L p .708 .578 .707 r
F P
0 g
s
.68452 .76481 m .69255 .78222 L .6911 .78012 L p .708 .578 .707 r
F P
0 g
s
.6911 .78012 m .68306 .76271 L .68452 .76481 L p .708 .578 .707 r
F P
0 g
s
.26062 .71452 m .26127 .65901 L .2301 .65674 L p .707 .577 .707 r
F P
0 g
s
.26127 .65901 m .26062 .71452 L .29245 .71407 L p .707 .577 .707 r
F P
0 g
s
.29245 .71407 m .29311 .65857 L .26127 .65901 L p .707 .577 .707 r
F P
0 g
s
.29311 .65857 m .29245 .71407 L .32183 .71096 L p .707 .577 .707 r
F P
0 g
s
.32183 .71096 m .32249 .65545 L .29311 .65857 L p .707 .577 .707 r
F P
0 g
s
.41326 .81425 m .40501 .31155 L .37529 .3031 L p .707 .577 .707 r
F P
0 g
s
.40501 .31155 m .41326 .81425 L .45202 .81972 L p .707 .577 .707 r
F P
0 g
s
.22945 .71225 m .2301 .65674 L .20265 .65198 L p .707 .577 .707 r
F P
0 g
s
.2301 .65674 m .22945 .71225 L .26062 .71452 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.32249 .65545 m .32183 .71096 L .34589 .70548 L p .707 .577 .707 r
F P
0 g
s
.34589 .70548 m .34654 .64997 L .32249 .65545 L p .707 .577 .707 r
F P
0 g
s
.68306 .76271 m .6911 .78012 L .68075 .78228 L p .707 .577 .707 r
F P
0 g
s
.70018 .74464 m .69781 .78135 L .68526 .77203 L p .707 .577 .707 r
F P
0 g
s
.68526 .77203 m .68763 .73531 L .70018 .74464 L p .707 .577 .707 r
F P
0 g
s
.69751 .65287 m .69686 .70838 L .67581 .70159 L p .707 .577 .707 r
F P
0 g
s
.67581 .70159 m .67646 .64608 L .69751 .65287 L p .707 .577 .707 r
F P
0 g
s
.649 .64132 m .64835 .69683 L .61718 .69456 L p .707 .577 .707 r
F P
0 g
s
.61718 .69456 m .61783 .63905 L .649 .64132 L p .707 .577 .707 r
F P
0 g
s
.66664 .72704 m .66426 .76376 L .63687 .75735 L p .707 .577 .707 r
F P
0 g
s
.63687 .75735 m .63924 .72063 L .66664 .72704 L p .707 .577 .707 r
F P
0 g
s
.6382 .79811 m .63017 .7807 L .65449 .77107 L p .707 .577 .707 r
F P
0 g
s
.60814 .3036 m .61639 .8063 L .6395 .79578 L p .707 .577 .707 r
F P
0 g
s
.6395 .79578 m .63125 .29308 L .60814 .3036 L p .707 .577 .707 r
F P
0 g
s
.20199 .70748 m .20265 .65198 L .18159 .64519 L p .707 .577 .707 r
F P
0 g
s
.20265 .65198 m .20199 .70748 L .22945 .71225 L p .707 .577 .707 r
F P
0 g
s
.24908 .77382 m .25145 .7371 L .22034 .73319 L p .707 .577 .707 r
F P
0 g
s
.25145 .7371 m .24908 .77382 L .28085 .77486 L p .707 .577 .707 r
F P
0 g
s
.28085 .77486 m .28323 .73814 L .25145 .7371 L p .707 .577 .707 r
F P
0 g
s
.50796 .8649 m .49992 .84749 L .5075 .84135 L p .707 .577 .707 r
F P
0 g
s
.5075 .84135 m .51554 .85876 L .50796 .8649 L p .707 .577 .707 r
F P
0 g
s
.28323 .73814 m .28085 .77486 L .31019 .77292 L p .707 .577 .707 r
F P
0 g
s
.31019 .77292 m .31256 .73621 L .28323 .73814 L p .707 .577 .707 r
F P
0 g
s
.68075 .78228 m .67272 .76487 L .68306 .76271 L p .707 .577 .707 r
F P
0 g
s
.21797 .7699 m .22034 .73319 L .19295 .72678 L p .707 .577 .707 r
F P
0 g
s
.22034 .73319 m .21797 .7699 L .24908 .77382 L p .707 .577 .707 r
F P
0 g
s
.34654 .64997 m .34589 .70548 L .36226 .69817 L p .707 .577 .707 r
F P
0 g
s
.36226 .69817 m .36291 .64266 L .34654 .64997 L p .707 .577 .707 r
F P
0 g
s
.18159 .64519 m .18094 .7007 L .20199 .70748 L p .707 .577 .707 r
F P
0 g
s
.38354 .8058 m .37529 .3031 L .35752 .29249 L p .707 .577 .707 r
F P
0 g
s
.37529 .3031 m .38354 .8058 L .41326 .81425 L p .707 .577 .707 r
F P
0 g
s
.67646 .64608 m .67581 .70159 L .64835 .69683 L p .707 .577 .707 r
F P
0 g
s
.64835 .69683 m .649 .64132 L .67646 .64608 L p .707 .577 .707 r
F P
0 g
s
.31256 .73621 m .31019 .77292 L .33421 .7682 L p .707 .577 .707 r
F P
0 g
s
.33421 .7682 m .33658 .73148 L .31256 .73621 L p .707 .577 .707 r
F P
0 g
s
.19295 .72678 m .19057 .7635 L .21797 .7699 L p .707 .577 .707 r
F P
0 g
s
.24734 .79908 m .2393 .78167 L .21127 .7938 L p .707 .577 .707 r
F P
0 g
s
.2393 .78167 m .24734 .79908 L .27634 .78565 L p .707 .577 .707 r
F P
0 g
s
.27634 .78565 m .26831 .76825 L .2393 .78167 L p .707 .577 .707 r
F P
0 g
s
.26831 .76825 m .27634 .78565 L .30348 .77224 L p .707 .577 .707 r
F P
0 g
s
.30348 .77224 m .29545 .75483 L .26831 .76825 L p .707 .577 .707 r
F P
0 g
s
.21127 .7938 m .2193 .8112 L .24734 .79908 L p .707 .577 .707 r
F P
0 g
s
.67272 .76487 m .68075 .78228 L .66253 .78847 L p .707 .577 .707 r
F P
0 g
s
.66253 .78847 m .65449 .77107 L .67272 .76487 L p .707 .577 .707 r
F P
0 g
s
.68763 .73531 m .68526 .77203 L .66426 .76376 L p .707 .577 .707 r
F P
0 g
s
.66426 .76376 m .66664 .72704 L .68763 .73531 L p .707 .577 .707 r
F P
0 g
s
.18094 .7007 m .18159 .64519 L .169 .63704 L p .707 .577 .707 r
F P
0 g
s
.19057 .7635 m .19295 .72678 L .17195 .71851 L p .707 .577 .707 r
F P
0 g
s
.2193 .8112 m .21127 .7938 L .18694 .80343 L p .707 .577 .707 r
F P
0 g
s
.29545 .75483 m .30348 .77224 L .32609 .76014 L p .707 .577 .707 r
F P
0 g
s
.32609 .76014 m .31806 .74273 L .29545 .75483 L p .707 .577 .707 r
F P
0 g
s
.18694 .80343 m .19498 .82084 L .2193 .8112 L p .707 .577 .707 r
F P
0 g
s
.51554 .85876 m .5075 .84135 L .52338 .83176 L p .707 .577 .707 r
F P
0 g
s
.17195 .71851 m .16958 .75523 L .19057 .7635 L p .707 .577 .707 r
F P
0 g
s
.52338 .83176 m .53141 .84917 L .51554 .85876 L p .707 .577 .707 r
F P
0 g
s
.65449 .77107 m .66253 .78847 L .6382 .79811 L p .707 .577 .707 r
F P
0 g
s
.63125 .29308 m .6395 .79578 L .6495 .78409 L p .707 .577 .707 r
F P
0 g
s
.6495 .78409 m .64125 .28139 L .63125 .29308 L p .707 .577 .707 r
F P
0 g
s
.169 .63704 m .16835 .69255 L .18094 .7007 L p .707 .577 .707 r
F P
0 g
s
.36291 .64266 m .36226 .69817 L .36934 .68975 L p .707 .577 .707 r
F P
0 g
s
.36934 .68975 m .36999 .63424 L .36291 .64266 L p .707 .577 .707 r
F P
0 g
s
.33658 .73148 m .33421 .7682 L .35057 .76115 L p .707 .577 .707 r
F P
0 g
s
.35057 .76115 m .35294 .72443 L .33658 .73148 L p .707 .577 .707 r
F P
0 g
s
.16958 .75523 m .17195 .71851 L .1594 .70918 L p .707 .577 .707 r
F P
0 g
s
.19498 .82084 m .18694 .80343 L .16872 .80962 L p .707 .577 .707 r
F P
0 g
s
.16872 .80962 m .17675 .82703 L .19498 .82084 L p .707 .577 .707 r
F P
0 g
s
.31806 .74273 m .32609 .76014 L .34197 .75055 L p .707 .577 .707 r
F P
0 g
s
.34197 .75055 m .33393 .73314 L .31806 .74273 L p .707 .577 .707 r
F P
0 g
s
.16835 .69255 m .169 .63704 L .16611 .62833 L p .707 .577 .707 r
F P
0 g
s
.3671 .62553 m .36644 .68104 L .35385 .67289 L p .707 .577 .707 r
F P
0 g
s
.35385 .67289 m .35451 .61738 L .3671 .62553 L p .707 .577 .707 r
F P
0 g
s
.36577 .79519 m .35752 .29249 L .35343 .28077 L p .707 .577 .707 r
F P
0 g
s
.36999 .63424 m .36934 .68975 L .36644 .68104 L p .707 .577 .707 r
F P
0 g
s
.36644 .68104 m .3671 .62553 L .36999 .63424 L p .707 .577 .707 r
F P
0 g
s
.35752 .29249 m .36577 .79519 L .38354 .8058 L p .707 .577 .707 r
F P
0 g
s
.1594 .70918 m .15703 .7459 L .16958 .75523 L p .707 .577 .707 r
F P
0 g
s
.53141 .84917 m .52338 .83176 L .54599 .81967 L p .707 .577 .707 r
F P
0 g
s
.54599 .81967 m .55402 .83707 L .53141 .84917 L p .707 .577 .707 r
F P
0 g
s
.35294 .72443 m .35057 .76115 L .35766 .75247 L p .707 .577 .707 r
F P
0 g
s
.35766 .75247 m .36004 .71575 L .35294 .72443 L p .707 .577 .707 r
F P
0 g
s
.16611 .62833 m .16545 .68383 L .16835 .69255 L p .707 .577 .707 r
F P
0 g
s
.17675 .82703 m .16872 .80962 L .15837 .81178 L p .707 .577 .707 r
F P
0 g
s
.15703 .7459 m .1594 .70918 L .15654 .69971 L p .707 .577 .707 r
F P
0 g
s
.15837 .81178 m .1664 .82919 L .17675 .82703 L p .707 .577 .707 r
F P
0 g
s
.33393 .73314 m .34197 .75055 L .34955 .74441 L p .707 .577 .707 r
F P
0 g
s
.34955 .74441 m .34151 .727 L .33393 .73314 L p .707 .577 .707 r
F P
0 g
s
.64125 .28139 m .6495 .78409 L .64541 .77237 L p .707 .577 .707 r
F P
0 g
s
.64541 .77237 m .63716 .26967 L .64125 .28139 L p .707 .577 .707 r
F P
0 g
s
.16545 .68383 m .16611 .62833 L .17319 .6199 L p .707 .577 .707 r
F P
0 g
s
.15654 .69971 m .15416 .73643 L .15703 .7459 L p .707 .577 .707 r
F P
0 g
s
.36004 .71575 m .35766 .75247 L .3548 .743 L p .707 .577 .707 r
F P
0 g
s
.3548 .743 m .35717 .70628 L .36004 .71575 L p .707 .577 .707 r
F P
0 g
s
.17319 .6199 m .17254 .67541 L .16545 .68383 L p .707 .577 .707 r
F P
0 g
s
.35343 .28077 m .36168 .78347 L .36577 .79519 L p .707 .577 .707 r
F P
0 g
s
.36168 .78347 m .35343 .28077 L .36343 .26908 L p .707 .577 .707 r
F P
0 g
s
.1664 .82919 m .15837 .81178 L .15691 .80968 L p .708 .578 .707 r
F P
0 g
s
.15416 .73643 m .15654 .69971 L .16363 .69103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15691 .80968 m .16495 .82709 L .1664 .82919 L p .708 .578 .707 r
F P
0 g
s
.34151 .727 m .34955 .74441 L .34809 .74231 L p .708 .578 .707 r
F P
0 g
s
.34809 .74231 m .34005 .7249 L .34151 .727 L p .708 .578 .707 r
F P
0 g
s
.17254 .67541 m .17319 .6199 L .18956 .61259 L p .707 .577 .707 r
F P
0 g
s
.16363 .69103 m .16126 .72775 L .15416 .73643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63716 .26967 m .64541 .77237 L .62764 .76176 L p .707 .577 .707 r
F P
0 g
s
.62764 .76176 m .61939 .25906 L .63716 .26967 L p .707 .577 .707 r
F P
0 g
s
.34005 .7249 m .34809 .74231 L .33774 .74447 L p .707 .577 .707 r
F P
0 g
s
.35717 .70628 m .3548 .743 L .34225 .73367 L p .707 .577 .707 r
F P
0 g
s
.34225 .73367 m .34462 .69696 L .35717 .70628 L p .707 .577 .707 r
F P
0 g
s
.18956 .61259 m .18891 .6681 L .17254 .67541 L p .707 .577 .707 r
F P
0 g
s
.35451 .61738 m .35385 .67289 L .3328 .6661 L p .707 .577 .707 r
F P
0 g
s
.3328 .6661 m .33345 .61059 L .35451 .61738 L p .707 .577 .707 r
F P
0 g
s
.16126 .72775 m .16363 .69103 L .17999 .68398 L p .707 .577 .707 r
F P
0 g
s
.16495 .82709 m .15691 .80968 L .16449 .80354 L p .707 .577 .707 r
F P
0 g
s
.16449 .80354 m .17253 .82095 L .16495 .82709 L p .707 .577 .707 r
F P
0 g
s
.18891 .6681 m .18956 .61259 L .21361 .60711 L p .707 .577 .707 r
F P
0 g
s
.33774 .74447 m .32971 .72706 L .34005 .7249 L p .707 .577 .707 r
F P
0 g
s
.37168 .77178 m .36343 .26908 L .38654 .25856 L p .707 .577 .707 r
F P
0 g
s
.36343 .26908 m .37168 .77178 L .36168 .78347 L p .707 .577 .707 r
F P
0 g
s
.17999 .68398 m .17762 .7207 L .16126 .72775 L p .707 .577 .707 r
F P
0 g
s
.33345 .61059 m .3328 .6661 L .30534 .66134 L p .707 .577 .707 r
F P
0 g
s
.30534 .66134 m .306 .60583 L .33345 .61059 L p .707 .577 .707 r
F P
0 g
s
.21361 .60711 m .21296 .66262 L .18891 .6681 L p .707 .577 .707 r
F P
0 g
s
.32971 .72706 m .33774 .74447 L .31952 .75066 L p .707 .577 .707 r
F P
0 g
s
.31952 .75066 m .31148 .73326 L .32971 .72706 L p .707 .577 .707 r
F P
0 g
s
.34462 .69696 m .34225 .73367 L .32125 .7254 L p .707 .577 .707 r
F P
0 g
s
.32125 .7254 m .32363 .68868 L .34462 .69696 L p .707 .577 .707 r
F P
0 g
s
.21296 .66262 m .21361 .60711 L .24299 .604 L p .707 .577 .707 r
F P
0 g
s
.17762 .7207 m .17999 .68398 L .20401 .67926 L p .707 .577 .707 r
F P
0 g
s
.61939 .25906 m .62764 .76176 L .59792 .75331 L p .707 .577 .707 r
F P
0 g
s
.59792 .75331 m .58967 .25061 L .61939 .25906 L p .707 .577 .707 r
F P
0 g
s
.17253 .82095 m .16449 .80354 L .18037 .79395 L p .707 .577 .707 r
F P
0 g
s
.306 .60583 m .30534 .66134 L .27417 .65907 L p .707 .577 .707 r
F P
0 g
s
.27417 .65907 m .27483 .60356 L .306 .60583 L p .707 .577 .707 r
F P
0 g
s
.18037 .79395 m .1884 .81136 L .17253 .82095 L p .707 .577 .707 r
F P
0 g
s
.24234 .65951 m .24299 .604 L .27483 .60356 L p .707 .577 .707 r
F P
0 g
s
.24299 .604 m .24234 .65951 L .21296 .66262 L p .707 .577 .707 r
F P
0 g
s
.20401 .67926 m .20164 .71598 L .17762 .7207 L p .707 .577 .707 r
F P
0 g
s
.27483 .60356 m .27417 .65907 L .24234 .65951 L p .707 .577 .707 r
F P
0 g
s
.74083 .65797 m .74149 .60246 L .71032 .60019 L p .707 .577 .707 r
F P
0 g
s
.74149 .60246 m .74083 .65797 L .77267 .65753 L p .707 .577 .707 r
F P
0 g
s
.77267 .65753 m .77332 .60202 L .74149 .60246 L p .707 .577 .707 r
F P
0 g
s
.32363 .68868 m .32125 .7254 L .29386 .71899 L p .707 .577 .707 r
F P
0 g
s
.29386 .71899 m .29623 .68228 L .32363 .68868 L p .707 .577 .707 r
F P
0 g
s
.77332 .60202 m .77267 .65753 L .80205 .65441 L p .707 .577 .707 r
F P
0 g
s
.80205 .65441 m .8027 .5989 L .77332 .60202 L p .707 .577 .707 r
F P
0 g
s
.38654 .25856 m .39479 .76126 L .37168 .77178 L p .707 .577 .707 r
F P
0 g
s
.39479 .76126 m .38654 .25856 L .42049 .25025 L p .707 .577 .707 r
F P
0 g
s
.70966 .6557 m .71032 .60019 L .68286 .59543 L p .707 .577 .707 r
F P
0 g
s
.71032 .60019 m .70966 .6557 L .74083 .65797 L p .707 .577 .707 r
F P
0 g
s
.20164 .71598 m .20401 .67926 L .23335 .67732 L p .707 .577 .707 r
F P
0 g
s
.8027 .5989 m .80205 .65441 L .8261 .64893 L p .707 .577 .707 r
F P
0 g
s
.8261 .64893 m .82675 .59342 L .8027 .5989 L p .707 .577 .707 r
F P
0 g
s
.29623 .68228 m .29386 .71899 L .26275 .71508 L p .707 .577 .707 r
F P
0 g
s
.26275 .71508 m .26513 .67836 L .29623 .68228 L p .707 .577 .707 r
F P
0 g
s
.1884 .81136 m .18037 .79395 L .20298 .78186 L p .707 .577 .707 r
F P
0 g
s
.23335 .67732 m .23098 .71404 L .20164 .71598 L p .707 .577 .707 r
F P
0 g
s
.20298 .78186 m .21101 .79926 L .1884 .81136 L p .707 .577 .707 r
F P
0 g
s
.31148 .73326 m .31952 .75066 L .29519 .76029 L p .707 .577 .707 r
F P
0 g
s
.29519 .76029 m .28716 .74289 L .31148 .73326 L p .707 .577 .707 r
F P
0 g
s
.23098 .71404 m .23335 .67732 L .26513 .67836 L p .707 .577 .707 r
F P
0 g
s
.58967 .25061 m .59792 .75331 L .55916 .74785 L p .707 .577 .707 r
F P
0 g
s
.55916 .74785 m .55091 .24514 L .58967 .25061 L p .707 .577 .707 r
F P
0 g
s
.68221 .65093 m .68286 .59543 L .66181 .58864 L p .707 .577 .707 r
F P
0 g
s
.68286 .59543 m .68221 .65093 L .70966 .6557 L p .707 .577 .707 r
F P
0 g
s
.26513 .67836 m .26275 .71508 L .23098 .71404 L p .707 .577 .707 r
F P
0 g
s
.72929 .72014 m .73166 .68342 L .70055 .6795 L p .707 .577 .707 r
F P
0 g
s
.73166 .68342 m .72929 .72014 L .76107 .72118 L p .707 .577 .707 r
F P
0 g
s
.76107 .72118 m .76344 .68446 L .73166 .68342 L p .707 .577 .707 r
F P
0 g
s
.76344 .68446 m .76107 .72118 L .7904 .71924 L p .707 .577 .707 r
F P
0 g
s
.7904 .71924 m .79277 .68252 L .76344 .68446 L p .707 .577 .707 r
F P
0 g
s
.42875 .75295 m .42049 .25025 L .46197 .24495 L p .707 .577 .707 r
F P
0 g
s
.42049 .25025 m .42875 .75295 L .39479 .76126 L p .707 .577 .707 r
F P
0 g
s
.69818 .71622 m .70055 .6795 L .67316 .6731 L p .707 .577 .707 r
F P
0 g
s
.70055 .6795 m .69818 .71622 L .72929 .72014 L p .707 .577 .707 r
F P
0 g
s
.82675 .59342 m .8261 .64893 L .84247 .64162 L p .707 .577 .707 r
F P
0 g
s
.84247 .64162 m .84312 .58611 L .82675 .59342 L p .707 .577 .707 r
F P
0 g
s
.21101 .79926 m .20298 .78186 L .23011 .76844 L p .707 .577 .707 r
F P
0 g
s
.28716 .74289 m .29519 .76029 L .26716 .77242 L p .707 .577 .707 r
F P
0 g
s
.26716 .77242 m .25912 .75501 L .28716 .74289 L p .707 .577 .707 r
F P
0 g
s
.23011 .76844 m .23815 .78585 L .21101 .79926 L p .707 .577 .707 r
F P
0 g
s
.66181 .58864 m .66115 .64415 L .68221 .65093 L p .707 .577 .707 r
F P
0 g
s
.79277 .68252 m .7904 .71924 L .81442 .71452 L p .707 .577 .707 r
F P
0 g
s
.81442 .71452 m .8168 .6778 L .79277 .68252 L p .707 .577 .707 r
F P
0 g
s
.55091 .24514 m .55916 .74785 L .51516 .7459 L p .707 .577 .707 r
F P
0 g
s
.51516 .7459 m .50691 .24319 L .55091 .24514 L p .707 .577 .707 r
F P
0 g
s
.72755 .74485 m .71952 .72745 L .69148 .73957 L p .707 .577 .707 r
F P
0 g
s
.71952 .72745 m .72755 .74485 L .75656 .73143 L p .707 .577 .707 r
F P
0 g
s
.75656 .73143 m .74852 .71402 L .71952 .72745 L p .707 .577 .707 r
F P
0 g
s
.67316 .6731 m .67079 .70981 L .69818 .71622 L p .707 .577 .707 r
F P
0 g
s
.74852 .71402 m .75656 .73143 L .7837 .71801 L p .707 .577 .707 r
F P
0 g
s
.7837 .71801 m .77566 .7006 L .74852 .71402 L p .707 .577 .707 r
F P
0 g
s
.69148 .73957 m .69951 .75698 L .72755 .74485 L p .707 .577 .707 r
F P
0 g
s
.66115 .64415 m .66181 .58864 L .64922 .58049 L p .707 .577 .707 r
F P
0 g
s
.23815 .78585 m .23011 .76844 L .25912 .75501 L p .707 .577 .707 r
F P
0 g
s
.25912 .75501 m .26716 .77242 L .23815 .78585 L p .707 .577 .707 r
F P
0 g
s
.67079 .70981 m .67316 .6731 L .65216 .66482 L p .707 .577 .707 r
F P
0 g
s
.47022 .74765 m .46197 .24495 L .50691 .24319 L p .707 .577 .707 r
F P
0 g
s
.46197 .24495 m .47022 .74765 L .42875 .75295 L p .707 .577 .707 r
F P
0 g
s
.50691 .24319 m .51516 .7459 L .47022 .74765 L p .707 .577 .707 r
F P
0 g
s
.69951 .75698 m .69148 .73957 L .66716 .7492 L p .707 .577 .707 r
F P
0 g
s
.77566 .7006 m .7837 .71801 L .80631 .70591 L p .707 .577 .707 r
F P
0 g
s
.80631 .70591 m .79827 .6885 L .77566 .7006 L p .707 .577 .707 r
F P
0 g
s
.66716 .7492 m .67519 .76661 L .69951 .75698 L p .707 .577 .707 r
F P
0 g
s
.65216 .66482 m .64979 .70154 L .67079 .70981 L p .707 .577 .707 r
F P
0 g
s
.64922 .58049 m .64856 .636 L .66115 .64415 L p .707 .577 .707 r
F P
0 g
s
.84312 .58611 m .84247 .64162 L .84955 .6332 L p .707 .577 .707 r
F P
0 g
s
.84955 .6332 m .85021 .57769 L .84312 .58611 L p .707 .577 .707 r
F P
0 g
s
.8168 .6778 m .81442 .71452 L .83078 .70747 L p .707 .577 .707 r
F P
0 g
s
.83078 .70747 m .83316 .67075 L .8168 .6778 L p .707 .577 .707 r
F P
0 g
s
.64979 .70154 m .65216 .66482 L .63962 .6555 L p .707 .577 .707 r
F P
0 g
s
.67519 .76661 m .66716 .7492 L .64893 .7554 L p .707 .577 .707 r
F P
0 g
s
.64893 .7554 m .65697 .77281 L .67519 .76661 L p .707 .577 .707 r
F P
0 g
s
.64856 .636 m .64922 .58049 L .64632 .57178 L p .707 .577 .707 r
F P
0 g
s
.79827 .6885 m .80631 .70591 L .82218 .69632 L p .707 .577 .707 r
F P
0 g
s
.82218 .69632 m .81414 .67892 L .79827 .6885 L p .707 .577 .707 r
F P
0 g
s
.63962 .6555 m .63724 .69222 L .64979 .70154 L p .707 .577 .707 r
F P
0 g
s
.64632 .57178 m .64567 .62729 L .64856 .636 L p .707 .577 .707 r
F P
0 g
s
.83316 .67075 m .83078 .70747 L .83788 .69878 L p .707 .577 .707 r
F P
0 g
s
.83788 .69878 m .84025 .66207 L .83316 .67075 L p .707 .577 .707 r
F P
0 g
s
.85021 .57769 m .84955 .6332 L .84666 .62449 L p .707 .577 .707 r
F P
0 g
s
.84666 .62449 m .84731 .56898 L .85021 .57769 L p .707 .577 .707 r
F P
0 g
s
.65697 .77281 m .64893 .7554 L .63858 .75755 L p .707 .577 .707 r
F P
0 g
s
.63724 .69222 m .63962 .6555 L .63675 .64603 L p .707 .577 .707 r
F P
0 g
s
.63858 .75755 m .64662 .77496 L .65697 .77281 L p .707 .577 .707 r
F P
0 g
s
.81414 .67892 m .82218 .69632 L .82976 .69018 L p .707 .577 .707 r
F P
0 g
s
.82976 .69018 m .82172 .67277 L .81414 .67892 L p .707 .577 .707 r
F P
0 g
s
.64567 .62729 m .64632 .57178 L .6534 .56335 L p .707 .577 .707 r
F P
0 g
s
.63675 .64603 m .63438 .68275 L .63724 .69222 L p .707 .577 .707 r
F P
0 g
s
.84025 .66207 m .83788 .69878 L .83501 .68932 L p .707 .577 .707 r
F P
0 g
s
.83501 .68932 m .83738 .6526 L .84025 .66207 L p .707 .577 .707 r
F P
0 g
s
.6534 .56335 m .65275 .61886 L .64567 .62729 L p .707 .577 .707 r
F P
0 g
s
.84731 .56898 m .84666 .62449 L .83407 .61634 L p .707 .577 .707 r
F P
0 g
s
.83407 .61634 m .83472 .56083 L .84731 .56898 L p .707 .577 .707 r
F P
0 g
s
.64662 .77496 m .63858 .75755 L .63713 .75546 L p .708 .578 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63713 .75546 m .64516 .77286 L .64662 .77496 L p .708 .578 .707 r
F P
0 g
s
.63438 .68275 m .63675 .64603 L .64384 .63735 L p .707 .577 .707 r
F P
0 g
s
.82172 .67277 m .82976 .69018 L .8283 .68808 L p .708 .578 .707 r
F P
0 g
s
.8283 .68808 m .82027 .67068 L .82172 .67277 L p .708 .578 .707 r
F P
0 g
s
.39782 .62248 m .39848 .56697 L .36731 .5647 L p .707 .577 .707 r
F P
0 g
s
.39848 .56697 m .39782 .62248 L .42966 .62204 L p .707 .577 .707 r
F P
0 g
s
.42966 .62204 m .43031 .56653 L .39848 .56697 L p .707 .577 .707 r
F P
0 g
s
.65275 .61886 m .6534 .56335 L .66977 .55604 L p .707 .577 .707 r
F P
0 g
s
.43031 .56653 m .42966 .62204 L .45904 .61892 L p .707 .577 .707 r
F P
0 g
s
.45904 .61892 m .45969 .56341 L .43031 .56653 L p .707 .577 .707 r
F P
0 g
s
.36665 .62021 m .36731 .5647 L .33985 .55994 L p .707 .577 .707 r
F P
0 g
s
.36731 .5647 m .36665 .62021 L .39782 .62248 L p .707 .577 .707 r
F P
0 g
s
.64384 .63735 m .64147 .67406 L .63438 .68275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45969 .56341 m .45904 .61892 L .48309 .61344 L p .707 .577 .707 r
F P
0 g
s
.48309 .61344 m .48374 .55793 L .45969 .56341 L p .707 .577 .707 r
F P
0 g
s
.82027 .67068 m .8283 .68808 L .81796 .69024 L p .707 .577 .707 r
F P
0 g
s
.83738 .6526 m .83501 .68932 L .82246 .67999 L p .707 .577 .707 r
F P
0 g
s
.82246 .67999 m .82484 .64327 L .83738 .6526 L p .707 .577 .707 r
F P
0 g
s
.66977 .55604 m .66912 .61155 L .65275 .61886 L p .707 .577 .707 r
F P
0 g
s
.83472 .56083 m .83407 .61634 L .81301 .60955 L p .707 .577 .707 r
F P
0 g
s
.81301 .60955 m .81367 .55404 L .83472 .56083 L p .707 .577 .707 r
F P
0 g
s
.3392 .61544 m .33985 .55994 L .3188 .55315 L p .707 .577 .707 r
F P
0 g
s
.33985 .55994 m .3392 .61544 L .36665 .62021 L p .707 .577 .707 r
F P
0 g
s
.38628 .68178 m .38865 .64506 L .35754 .64115 L p .707 .577 .707 r
F P
0 g
s
.38865 .64506 m .38628 .68178 L .41806 .68282 L p .707 .577 .707 r
F P
0 g
s
.41806 .68282 m .42043 .6461 L .38865 .64506 L p .707 .577 .707 r
F P
0 g
s
.64147 .67406 m .64384 .63735 L .6602 .6303 L p .707 .577 .707 r
F P
0 g
s
.64516 .77286 m .63713 .75546 L .64471 .74931 L p .707 .577 .707 r
F P
0 g
s
.66912 .61155 m .66977 .55604 L .69382 .55057 L p .707 .577 .707 r
F P
0 g
s
.64471 .74931 m .65274 .76672 L .64516 .77286 L p .707 .577 .707 r
F P
0 g
s
.42043 .6461 m .41806 .68282 L .44739 .68089 L p .707 .577 .707 r
F P
0 g
s
.44739 .68089 m .44977 .64417 L .42043 .6461 L p .707 .577 .707 r
F P
0 g
s
.81796 .69024 m .80992 .67283 L .82027 .67068 L p .707 .577 .707 r
F P
0 g
s
.35517 .67787 m .35754 .64115 L .33015 .63474 L p .707 .577 .707 r
F P
0 g
s
.35754 .64115 m .35517 .67787 L .38628 .68178 L p .707 .577 .707 r
F P
0 g
s
.48374 .55793 m .48309 .61344 L .49946 .60613 L p .707 .577 .707 r
F P
0 g
s
.49946 .60613 m .50011 .55062 L .48374 .55793 L p .707 .577 .707 r
F P
0 g
s
.6602 .6303 m .65783 .66702 L .64147 .67406 L p .707 .577 .707 r
F P
0 g
s
.3188 .55315 m .31814 .60866 L .3392 .61544 L p .707 .577 .707 r
F P
0 g
s
.81367 .55404 m .81301 .60955 L .78556 .60479 L p .707 .577 .707 r
F P
0 g
s
.78556 .60479 m .78621 .54928 L .81367 .55404 L p .707 .577 .707 r
F P
0 g
s
.44977 .64417 m .44739 .68089 L .47141 .67616 L p .707 .577 .707 r
F P
0 g
s
.47141 .67616 m .47379 .63944 L .44977 .64417 L p .707 .577 .707 r
F P
0 g
s
.33015 .63474 m .32778 .67146 L .35517 .67787 L p .707 .577 .707 r
F P
0 g
s
.38454 .70704 m .37651 .68964 L .34847 .70176 L p .707 .577 .707 r
F P
0 g
s
.37651 .68964 m .38454 .70704 L .41355 .69362 L p .707 .577 .707 r
F P
0 g
s
.41355 .69362 m .40551 .67621 L .37651 .68964 L p .707 .577 .707 r
F P
0 g
s
.40551 .67621 m .41355 .69362 L .44069 .6802 L p .707 .577 .707 r
F P
0 g
s
.44069 .6802 m .43265 .66279 L .40551 .67621 L p .707 .577 .707 r
F P
0 g
s
.69382 .55057 m .69317 .60607 L .66912 .61155 L p .707 .577 .707 r
F P
0 g
s
.34847 .70176 m .3565 .71917 L .38454 .70704 L p .707 .577 .707 r
F P
0 g
s
.80992 .67283 m .81796 .69024 L .79973 .69644 L p .707 .577 .707 r
F P
0 g
s
.79973 .69644 m .79169 .67903 L .80992 .67283 L p .707 .577 .707 r
F P
0 g
s
.82484 .64327 m .82246 .67999 L .80147 .67172 L p .707 .577 .707 r
F P
0 g
s
.80147 .67172 m .80384 .635 L .82484 .64327 L p .707 .577 .707 r
F P
0 g
s
.31814 .60866 m .3188 .55315 L .30621 .545 L p .707 .577 .707 r
F P
0 g
s
.32778 .67146 m .33015 .63474 L .30915 .62647 L p .707 .577 .707 r
F P
0 g
s
.69317 .60607 m .69382 .55057 L .72321 .54745 L p .707 .577 .707 r
F P
0 g
s
.3565 .71917 m .34847 .70176 L .32415 .71139 L p .707 .577 .707 r
F P
0 g
s
.65783 .66702 m .6602 .6303 L .68423 .62557 L p .707 .577 .707 r
F P
0 g
s
.43265 .66279 m .44069 .6802 L .4633 .6681 L p .707 .577 .707 r
F P
0 g
s
.4633 .6681 m .45526 .65069 L .43265 .66279 L p .707 .577 .707 r
F P
0 g
s
.32415 .71139 m .33218 .7288 L .3565 .71917 L p .707 .577 .707 r
F P
0 g
s
.78621 .54928 m .78556 .60479 L .75439 .60252 L p .707 .577 .707 r
F P
0 g
s
.75439 .60252 m .75504 .54701 L .78621 .54928 L p .707 .577 .707 r
F P
0 g
s
.65274 .76672 m .64471 .74931 L .66058 .73972 L p .707 .577 .707 r
F P
0 g
s
.30915 .62647 m .30678 .66319 L .32778 .67146 L p .707 .577 .707 r
F P
0 g
s
.66058 .73972 m .66862 .75713 L .65274 .76672 L p .707 .577 .707 r
F P
0 g
s
.72255 .60296 m .72321 .54745 L .75504 .54701 L p .707 .577 .707 r
F P
0 g
s
.72321 .54745 m .72255 .60296 L .69317 .60607 L p .707 .577 .707 r
F P
0 g
s
.30621 .545 m .30555 .60051 L .31814 .60866 L p .707 .577 .707 r
F P
0 g
s
.50011 .55062 m .49946 .60613 L .50654 .59771 L p .707 .577 .707 r
F P
0 g
s
.50654 .59771 m .5072 .5422 L .50011 .55062 L p .707 .577 .707 r
F P
0 g
s
.47379 .63944 m .47141 .67616 L .48777 .66911 L p .707 .577 .707 r
F P
0 g
s
.48777 .66911 m .49015 .63239 L .47379 .63944 L p .707 .577 .707 r
F P
0 g
s
.75504 .54701 m .75439 .60252 L .72255 .60296 L p .707 .577 .707 r
F P
0 g
s
.68423 .62557 m .68185 .66229 L .65783 .66702 L p .707 .577 .707 r
F P
0 g
s
.80384 .635 m .80147 .67172 L .77407 .66531 L p .707 .577 .707 r
F P
0 g
s
.77407 .66531 m .77645 .62859 L .80384 .635 L p .707 .577 .707 r
F P
0 g
s
.30678 .66319 m .30915 .62647 L .29661 .61714 L p .707 .577 .707 r
F P
0 g
s
.33218 .7288 m .32415 .71139 L .30592 .71759 L p .707 .577 .707 r
F P
0 g
s
.30592 .71759 m .31396 .73499 L .33218 .7288 L p .707 .577 .707 r
F P
0 g
s
.45526 .65069 m .4633 .6681 L .47917 .65851 L p .707 .577 .707 r
F P
0 g
s
.47917 .65851 m .47113 .6411 L .45526 .65069 L p .707 .577 .707 r
F P
0 g
s
.68185 .66229 m .68423 .62557 L .71356 .62364 L p .707 .577 .707 r
F P
0 g
s
.30555 .60051 m .30621 .545 L .30331 .53629 L p .707 .577 .707 r
F P
0 g
s
.29661 .61714 m .29423 .65386 L .30678 .66319 L p .707 .577 .707 r
F P
0 g
s
.77645 .62859 m .77407 .66531 L .74297 .6614 L p .707 .577 .707 r
F P
0 g
s
.74297 .6614 m .74534 .62468 L .77645 .62859 L p .707 .577 .707 r
F P
0 g
s
.66862 .75713 m .66058 .73972 L .68319 .72763 L p .707 .577 .707 r
F P
0 g
s
.71356 .62364 m .71119 .66036 L .68185 .66229 L p .707 .577 .707 r
F P
0 g
s
.68319 .72763 m .69123 .74504 L .66862 .75713 L p .707 .577 .707 r
F P
0 g
s
.79169 .67903 m .79973 .69644 L .77541 .70607 L p .707 .577 .707 r
F P
0 g
s
.77541 .70607 m .76737 .68866 L .79169 .67903 L p .707 .577 .707 r
F P
0 g
s
.71119 .66036 m .71356 .62364 L .74534 .62468 L p .707 .577 .707 r
F P
0 g
s
.49015 .63239 m .48777 .66911 L .49487 .66043 L p .707 .577 .707 r
F P
0 g
s
.49487 .66043 m .49724 .62371 L .49015 .63239 L p .707 .577 .707 r
F P
0 g
s
.74534 .62468 m .74297 .6614 L .71119 .66036 L p .707 .577 .707 r
F P
0 g
s
.30331 .53629 m .30266 .59179 L .30555 .60051 L p .707 .577 .707 r
F P
0 g
s
.5072 .5422 m .50654 .59771 L .50365 .589 L p .707 .577 .707 r
F P
0 g
s
.50365 .589 m .5043 .53349 L .5072 .5422 L p .707 .577 .707 r
F P
0 g
s
.31396 .73499 m .30592 .71759 L .29557 .71974 L p .707 .577 .707 r
F P
0 g
s
.29423 .65386 m .29661 .61714 L .29374 .60767 L p .707 .577 .707 r
F P
0 g
s
.29557 .71974 m .30361 .73715 L .31396 .73499 L p .707 .577 .707 r
F P
0 g
s
.47113 .6411 m .47917 .65851 L .48675 .65237 L p .707 .577 .707 r
F P
0 g
s
.48675 .65237 m .47871 .63496 L .47113 .6411 L p .707 .577 .707 r
F P
0 g
s
.69123 .74504 m .68319 .72763 L .71033 .71421 L p .707 .577 .707 r
F P
0 g
s
.76737 .68866 m .77541 .70607 L .74737 .71819 L p .707 .577 .707 r
F P
0 g
s
.74737 .71819 m .73934 .70078 L .76737 .68866 L p .707 .577 .707 r
F P
0 g
s
.71033 .71421 m .71836 .73162 L .69123 .74504 L p .707 .577 .707 r
F P
0 g
s
.30266 .59179 m .30331 .53629 L .31039 .52786 L p .707 .577 .707 r
F P
0 g
s
.29374 .60767 m .29137 .64439 L .29423 .65386 L p .707 .577 .707 r
F P
0 g
s
.71836 .73162 m .71033 .71421 L .73934 .70078 L p .707 .577 .707 r
F P
0 g
s
.73934 .70078 m .74737 .71819 L .71836 .73162 L p .707 .577 .707 r
F P
0 g
s
.49724 .62371 m .49487 .66043 L .492 .65096 L p .707 .577 .707 r
F P
0 g
s
.492 .65096 m .49437 .61424 L .49724 .62371 L p .707 .577 .707 r
F P
0 g
s
.31039 .52786 m .30974 .58337 L .30266 .59179 L p .707 .577 .707 r
F P
0 g
s
.5043 .53349 m .50365 .589 L .49106 .58085 L p .707 .577 .707 r
F P
0 g
s
.49106 .58085 m .49171 .52534 L .5043 .53349 L p .707 .577 .707 r
F P
0 g
s
.30361 .73715 m .29557 .71974 L .29412 .71764 L p .708 .578 .707 r
F P
0 g
s
.29137 .64439 m .29374 .60767 L .30083 .59899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29412 .71764 m .30215 .73505 L .30361 .73715 L p .708 .578 .707 r
F P
0 g
s
.47871 .63496 m .48675 .65237 L .48529 .65027 L p .708 .578 .707 r
F P
0 g
s
.48529 .65027 m .47726 .63286 L .47871 .63496 L p .708 .578 .707 r
F P
0 g
s
.30974 .58337 m .31039 .52786 L .32676 .52055 L p .707 .577 .707 r
F P
0 g
s
.30083 .59899 m .29846 .63571 L .29137 .64439 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47726 .63286 m .48529 .65027 L .47495 .65243 L p .707 .577 .707 r
F P
0 g
s
.49437 .61424 m .492 .65096 L .47945 .64163 L p .707 .577 .707 r
F P
0 g
s
.47945 .64163 m .48183 .60492 L .49437 .61424 L p .707 .577 .707 r
F P
0 g
s
.32676 .52055 m .32611 .57606 L .30974 .58337 L p .707 .577 .707 r
F P
0 g
s
.49171 .52534 m .49106 .58085 L .47 .57406 L p .707 .577 .707 r
F P
0 g
s
.47 .57406 m .47066 .51855 L .49171 .52534 L p .707 .577 .707 r
F P
0 g
s
.29846 .63571 m .30083 .59899 L .31719 .59194 L p .707 .577 .707 r
F P
0 g
s
.30215 .73505 m .29412 .71764 L .3017 .7115 L p .707 .577 .707 r
F P
0 g
s
.3017 .7115 m .30973 .72891 L .30215 .73505 L p .707 .577 .707 r
F P
0 g
s
.32611 .57606 m .32676 .52055 L .35081 .51507 L p .707 .577 .707 r
F P
0 g
s
.47495 .65243 m .46691 .63502 L .47726 .63286 L p .707 .577 .707 r
F P
0 g
s
.31719 .59194 m .31482 .62866 L .29846 .63571 L p .707 .577 .707 r
F P
0 g
s
.47066 .51855 m .47 .57406 L .44255 .5693 L p .707 .577 .707 r
F P
0 g
s
.44255 .5693 m .4432 .51379 L .47066 .51855 L p .707 .577 .707 r
F P
0 g
s
.35081 .51507 m .35016 .57058 L .32611 .57606 L p .707 .577 .707 r
F P
0 g
s
.46691 .63502 m .47495 .65243 L .45672 .65862 L p .707 .577 .707 r
F P
0 g
s
.45672 .65862 m .44868 .64122 L .46691 .63502 L p .707 .577 .707 r
F P
0 g
s
.48183 .60492 m .47945 .64163 L .45846 .63336 L p .707 .577 .707 r
F P
0 g
s
.45846 .63336 m .46083 .59664 L .48183 .60492 L p .707 .577 .707 r
F P
0 g
s
.35016 .57058 m .35081 .51507 L .3802 .51196 L p .707 .577 .707 r
F P
0 g
s
.31482 .62866 m .31719 .59194 L .34122 .58722 L p .707 .577 .707 r
F P
0 g
s
.30973 .72891 m .3017 .7115 L .31757 .70191 L p .707 .577 .707 r
F P
0 g
s
.4432 .51379 m .44255 .5693 L .41138 .56703 L p .707 .577 .707 r
F P
0 g
s
.41138 .56703 m .41203 .51152 L .4432 .51379 L p .707 .577 .707 r
F P
0 g
s
.31757 .70191 m .3256 .71932 L .30973 .72891 L p .707 .577 .707 r
F P
0 g
s
.37954 .56747 m .3802 .51196 L .41203 .51152 L p .707 .577 .707 r
F P
0 g
s
.3802 .51196 m .37954 .56747 L .35016 .57058 L p .707 .577 .707 r
F P
0 g
s
.34122 .58722 m .33884 .62394 L .31482 .62866 L p .707 .577 .707 r
F P
0 g
s
.41203 .51152 m .41138 .56703 L .37954 .56747 L p .707 .577 .707 r
F P
0 g
s
.46083 .59664 m .45846 .63336 L .43106 .62696 L p .707 .577 .707 r
F P
0 g
s
.43106 .62696 m .43344 .59024 L .46083 .59664 L p .707 .577 .707 r
F P
0 g
s
.33884 .62394 m .34122 .58722 L .37055 .58528 L p .707 .577 .707 r
F P
0 g
s
.43344 .59024 m .43106 .62696 L .39996 .62304 L p .707 .577 .707 r
F P
0 g
s
.39996 .62304 m .40233 .58632 L .43344 .59024 L p .707 .577 .707 r
F P
0 g
s
.3256 .71932 m .31757 .70191 L .34018 .68982 L p .707 .577 .707 r
F P
0 g
s
.37055 .58528 m .36818 .622 L .33884 .62394 L p .707 .577 .707 r
F P
0 g
s
.34018 .68982 m .34822 .70723 L .3256 .71932 L p .707 .577 .707 r
F P
0 g
s
.44868 .64122 m .45672 .65862 L .4324 .66826 L p .707 .577 .707 r
F P
0 g
s
.4324 .66826 m .42436 .65085 L .44868 .64122 L p .707 .577 .707 r
F P
0 g
s
.36818 .622 m .37055 .58528 L .40233 .58632 L p .707 .577 .707 r
F P
0 g
s
.40233 .58632 m .39996 .62304 L .36818 .622 L p .707 .577 .707 r
F P
0 g
s
.34822 .70723 m .34018 .68982 L .36732 .6764 L p .707 .577 .707 r
F P
0 g
s
.42436 .65085 m .4324 .66826 L .40436 .68038 L p .707 .577 .707 r
F P
0 g
s
.40436 .68038 m .39632 .66297 L .42436 .65085 L p .707 .577 .707 r
F P
0 g
s
.36732 .6764 m .37535 .69381 L .34822 .70723 L p .707 .577 .707 r
F P
0 g
s
.37535 .69381 m .36732 .6764 L .39632 .66297 L p .707 .577 .707 r
F P
0 g
s
.39632 .66297 m .40436 .68038 L .37535 .69381 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00
FUIJEP0A000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol0069oo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool005ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005ao
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00FWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000BOolA
0012Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000jOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<Goo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;goo001FOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;Goo001FOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0`00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001J
EUYF009JEP@0009JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ao
o`00EWoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@0015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`04001JEP00FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00<0
05YFFUH00eYF00<005YFFUH00eYF4@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000AJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00@005YFFUIJEPP000=J
EP03001JEUYF00IJEP03001JEUYF009JEPH000EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001JEUYF00D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP09001JEUYFFUH005YF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:goo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH01000FUIJEUYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo0011OolA0002Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo000kOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH80008FUH00`00
FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool003Moo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEPD0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF008002]o
o`00=Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000[Ool003=oo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000015YF000000001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF0000009JEP8002]oo`00<Goo0P000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF1000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEQL000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<002]oo`00;goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH500000eYF001J
EP04FUH20002FUH00`00FUIJEP04FUH30004FUH60006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<0
05YF00000`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00:goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000AJEP000000009JEP03001JEUYF
00=JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001J
EUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF0`00
1EYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF100015YF00H005YFFUH005YF0004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP02
FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEP0000<00003FUH00000009J
EP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP800006FUH00000001JEP000UYF00<005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000800003FUH005YF00=JEP8002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF
1`001EYF0`001eYF00<005YFFUH00UYF0`0015YF00@005YF0000009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP80
02eoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF500000=JEP00
FUH01EYF00D005YFFUH005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP00009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000_Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=J
EP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH00eYF0`0000AJEP00000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH01eYF00<005YF00000P0000=JEP00FUH010001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000=J
EP<000EJEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3
0004FUH2000015YF001JEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP04001JEUYF
FUH90008FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
0007FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPT0009JEP03001oogoo
00=oo`T000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00
;goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01EYF00<005YFFUH01UYF10002EYF00@005YF000000EJEP800003FUH005YF009JEP80
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40002
FUH00`00FUIJEP03FUH00`00FUIJEP020006Ool30004Ool60005FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002moo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJEP8000=JEP03
001JEUYF00EJEP<000EJEP8000=JEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUH005YF001JEP800004FUH000000002FUH00`00FUIJEP03FUH00`00
FUIJEP020005Ool50009Ool400000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002mo
o`03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH400000eYF001JEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01@00FUIJ
EUYF00001EYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEP00FUH200000eYF001JEP03FUH30005FUH00`00FUIJEP020005Ool5000=Ool30004FUH01000
FUIJEUYF0P00;Woo000_Ool01@00FUH005YF00001EYF00<005YFFUH00eYF3`001EYF00<005YFFUH0
1EYF00<005YFFUH015YF200025YF00<005YF00000P001EYF00@005YF000000=JEPD000YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00
FUH00003000015YF001JEUYF0P001Goo1@003Woo1@0000=JEP00FUH00UYF0P00;Woo000_Ool20002
FUH01000FUIJEUYF20000eYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH01UYF00<005YF
FUH015YF00@005YFFUIJEP<000UJEP8000UJEPH0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH6
0006Ool3000<Ool30004FUH30003FUH2000^Ool002moo`03001JEUYF00D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPH000=JEP03001JEUYF00AJEP04001JEP000003FUH00`00
FUIJEP04FUH300000eYF001JEP05FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQD00003FUH005YF00AJEP04001JEUYF0002FUH2000^Ool002moo`<00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH20005FUH00`00
FUIJEP02FUH500000eYF001JEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00@005YF000000IJEP03001JEUYF00=JEP03001JEP0000@002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000=JEP00000025YF00<005YF00001P000UYF00<005YF00000P002eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEUYF009J
EP<00003FUH00000008002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF0P000eYF0`000eYF0P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH00`00FUIJEP05FUH01000FUH000000UYF0P0000AJEP00000002ioo`00;7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YFFUH015YF0`00
15YF00H005YFFUH005YF000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000QJEP03001JEP0000<0009JEP03001JEUYF008000=JEP8002moo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001eYF00@005YF000000MJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001UYF
00000000FUH000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP8000MJEP<000AJEP8002moo`00
;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00P000eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF0`001UYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P0000=JEP00FUH015YF0P000UYF
00@005YFFUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH010000UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF0P000eYF00@005YFFUIJEP8000AJEP04001JEP00000bOol002aoo`80
00AJEP04001JEUYFFUHI0004FUH200000eYF001JEP04FUH01000FUH000001EYF00<005YF00000P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF20002EYF00@005YF0000
00IJEP<000=JEPD003Aoo`00:goo00<005YF00000eYF1@006Goo1@000UYF00<005YFFUH00eYF0P00
1UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P000UYF00<005YFFUH01eYF0P001eYF1`00>Goo000[Ool01000FUH005YF0P00
00AJEP00000001=oo`<000Qoo`05001JEUYFFUH00003FUH00`00FUH00004FUH200000eYF00000002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH30004FUH0
0`00FUIJEP05FUH40005FUH20010Ool002]oo`06001JEP00001JEP0015YF0`003goo1@0027oo00D0
05YFFUH005YF008000=JEP04001JEP000002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH30004FUH20007FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P00@Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000;Ool50008Ool01@00FUIJEUYF
000015YF0`0000MJEP00FUIJEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20004FUH60008FUH00`00FUIJEP02000015YF000000000UYF0`00A7oo000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH70004Ool50009Ool015YF000000000UYF0P0000=JEP00FUH0
0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`000eYF
00<005YFFUH01EYF0`001UYF0P00Agoo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUHH0004FUH01@00FUH00000FUH00`000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF0P00BGoo
000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUH000020005FUH01000FUH00000
Bgoo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0`001UYF00<005YFFUH00eYF20000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000AJEP00FUH000MJEP8000QJEP8004eoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00MJEP03001JEP0000800003FUH005YF
00D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQh000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP800003FUH005YF00EJEP8004moo`00;Goo0P00
00=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP<000AJEP03001JEUYF
00AJEP<000EJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF
1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF009JEP80055oo`00;goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF009JEP80009JEP04001JEUYF
FUH20002FUH200001Goo001JEUYF00001UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00`001EYF00@005YF0000
00EJEP04001JEP00001COol0035oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@000UJEP04
001JEP000005FUH40003FUH200001Goo001JEUYF00001UYF00<005YFFUH010002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00AJEP<005Eoo`00<goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
0P000eYF00<005YFFUH01EYF0`001eYF00@005YFFUH000=JEP04001oogoo0002FUH00`00FUIJEP03
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH40002FUH200000eYF001JEP02FUH30002FUH40002FUH00`00Oomoo`1COol003Eoo`D0
00=JEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP8000=JEP04
001JEP000003Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP800004FUH005YFFUH30002FUH3
00000eYF001JEP02FUH2001EOol003Yoo`H00003FUH0000000QJEP03001JEP00008000EJEP03001J
EUYF0080009JEPD000Eoo`05001JEUYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH200000eYF
0000000300000eYF001JEP02FUH2001EOol003moo`<000UJEP8000UJEPH000Yoo`03001JEUYF0080
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000@000AJEP<000=JEP8005Eoo`00?Goo
0P000eYF00<005YFFUH015YF0`0000=JEP00FUH01EYF0P0047oo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00H005YF000005YF0005FUH01000FUIJEP000UYF0P00EGoo000kOol20005
FUH00`00FUIJEP02FUH500000eYF001JEP03FUH2000BOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00001000EGoo000iOol20008FUH00`00
FUH000060002FUH01000FUH0000057oo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF009JEP<00003FUH00000008005Eoo`00=goo0`002EYF0P000eYF0`000eYF
0P005Woo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YF0000009J
EP800004FUH00000001EOol003Eoo`8000=JEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80
01Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000AJEP06001JEUYF001JEP00
EGoo000cOol20005FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2000KOol00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP020003FUH2001FOol0035oo`<0
00MJEP04001JEP000007FUH01000FUH000007Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001eYF0`0015YF0P00EWoo000_Ool20003FUH00`00FUIJEP04FUH30007FUH3000POol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0000=JEP00FUH015YF0P000UYF00@005YFFUIJEP80
05Moo`00;Woo00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P009Goo0P00
00=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000=JEP04001JEUYFFUH20004FUH01000FUH00000FGoo000]Ool0
0`00FUH00005FUH01000FUH000001EYF00<005YF00000P00:Goo0`001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10001UYF0`000eYF1@00
Fgoo000/Ool01000FUIJEP001EYF0P001UYF0`00;goo10000UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01`0025YF1P00H7oo000/Ool01@00FUIJ
EUYF00000eYF00<005YF000015YF0P00=Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF1@0000=JEP00000010001UYF0P00IWoo000]Ool01@00FUIJEP00FUH00P000eYF00@0
05YF000003eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH600000eYF001J
EP03FUH500000eYF001JEP02FUH2001XOol002eoo`05001JEUYFFUH00004FUH30015OolO0007FUH0
0`00FUIJEP0700000eYF001JEP02001ZOol002ioo`04FUH000000002FUH2001ROol200000eYF001J
EP08FUH20003FUH30002FUH2001/Ool002ioo`H0069oo`8000AJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP<006ioo`00U7oo0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00`00LGoo002C
Ool00`00FUH00007FUH01000FUH000001UYF0P00M7oo002AOol20002FUH00`00FUIJEP05FUH20006
FUH2001fOol0091oo`03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00=JEP8007Qoo`00
SWoo0`001EYF00<005YFFUH00P0015YF00@005YF000007Yoo`00SWoo00@005YFFUH000EJEP8000EJ
EP<007aoo`00SWoo0P0000=JEP00FUH00UYF0`0015YF0P00Ogoo002?Ool00`00FUIJEP030003FUH0
1000FUH00000PGoo002?Ool00`00FUIJEP020002FUH40023Ool0091oo`H008Moo`00T7oo0P00Rgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60076 .74981 m .60117 .69427 L .57 .69215 L p .707 .577 .707 r
F P
0 g
s
.60117 .69427 m .60076 .74981 L .6326 .74924 L p .707 .577 .707 r
F P
0 g
s
.6326 .74924 m .633 .6937 L .60117 .69427 L p .707 .577 .707 r
F P
0 g
s
.633 .6937 m .6326 .74924 L .66198 .74603 L p .707 .577 .707 r
F P
0 g
s
.66198 .74603 m .66238 .69049 L .633 .6937 L p .707 .577 .707 r
F P
0 g
s
.56959 .74768 m .57 .69215 L .54254 .68752 L p .707 .577 .707 r
F P
0 g
s
.57 .69215 m .56959 .74768 L .60076 .74981 L p .707 .577 .707 r
F P
0 g
s
.66238 .69049 m .66198 .74603 L .68603 .74048 L p .707 .577 .707 r
F P
0 g
s
.68603 .74048 m .68644 .68494 L .66238 .69049 L p .707 .577 .707 r
F P
0 g
s
.54254 .68752 m .54214 .74306 L .56959 .74768 L p .707 .577 .707 r
F P
0 g
s
.54214 .74306 m .54254 .68752 L .52148 .68086 L p .707 .577 .707 r
F P
0 g
s
.59364 .8113 m .59511 .77444 L .56396 .77129 L p .707 .577 .707 r
F P
0 g
s
.59511 .77444 m .59364 .8113 L .62546 .81165 L p .707 .577 .707 r
F P
0 g
s
.62546 .81165 m .62692 .77478 L .59511 .77444 L p .707 .577 .707 r
F P
0 g
s
.62692 .77478 m .62546 .81165 L .65482 .80916 L p .707 .577 .707 r
F P
0 g
s
.65482 .80916 m .65629 .7723 L .62692 .77478 L p .707 .577 .707 r
F P
0 g
s
.5625 .80815 m .56396 .77129 L .53653 .76565 L p .707 .577 .707 r
F P
0 g
s
.56396 .77129 m .5625 .80815 L .59364 .8113 L p .707 .577 .707 r
F P
0 g
s
.68644 .68494 m .68603 .74048 L .7024 .73315 L p .707 .577 .707 r
F P
0 g
s
.7024 .73315 m .70281 .67761 L .68644 .68494 L p .707 .577 .707 r
F P
0 g
s
.52148 .68086 m .52108 .7364 L .54214 .74306 L p .707 .577 .707 r
F P
0 g
s
.65629 .7723 m .65482 .80916 L .67886 .80409 L p .707 .577 .707 r
F P
0 g
s
.67886 .80409 m .68033 .76722 L .65629 .7723 L p .707 .577 .707 r
F P
0 g
s
.59334 .84267 m .58826 .82436 L .5583 .83124 L p .707 .577 .707 r
F P
0 g
s
.58826 .82436 m .59334 .84267 L .62408 .83397 L p .707 .577 .707 r
F P
0 g
s
.62408 .83397 m .619 .81566 L .58826 .82436 L p .707 .577 .707 r
F P
0 g
s
.53653 .76565 m .53506 .80251 L .5625 .80815 L p .707 .577 .707 r
F P
0 g
s
.619 .81566 m .62408 .83397 L .6526 .8243 L p .707 .577 .707 r
F P
0 g
s
.6526 .8243 m .64752 .80599 L .619 .81566 L p .707 .577 .707 r
F P
0 g
s
.5583 .83124 m .56338 .84955 L .59334 .84267 L p .707 .577 .707 r
F P
0 g
s
.52108 .7364 m .52148 .68086 L .50889 .67282 L p .707 .577 .707 r
F P
0 g
s
.53506 .80251 m .53653 .76565 L .5155 .75807 L p .707 .577 .707 r
F P
0 g
s
.56338 .84955 m .5583 .83124 L .53205 .83563 L p .707 .577 .707 r
F P
0 g
s
.53205 .83563 m .53713 .85394 L .56338 .84955 L p .707 .577 .707 r
F P
0 g
s
.64752 .80599 m .6526 .8243 L .67609 .81461 L p .707 .577 .707 r
F P
0 g
s
.67609 .81461 m .67101 .7963 L .64752 .80599 L p .707 .577 .707 r
F P
0 g
s
.5155 .75807 m .51403 .79493 L .53506 .80251 L p .707 .577 .707 r
F P
0 g
s
.68033 .76722 m .67886 .80409 L .69523 .79692 L p .707 .577 .707 r
F P
0 g
s
.69523 .79692 m .6967 .76005 L .68033 .76722 L p .707 .577 .707 r
F P
0 g
s
.50889 .67282 m .50849 .72835 L .52108 .7364 L p .707 .577 .707 r
F P
0 g
s
.70281 .67761 m .7024 .73315 L .70949 .72475 L p .707 .577 .707 r
F P
0 g
s
.70949 .72475 m .70989 .66921 L .70281 .67761 L p .707 .577 .707 r
F P
0 g
s
.53713 .85394 m .53205 .83563 L .51209 .8371 L p .707 .577 .707 r
F P
0 g
s
.51403 .79493 m .5155 .75807 L .50292 .74929 L p .707 .577 .707 r
F P
0 g
s
.51209 .8371 m .51717 .85541 L .53713 .85394 L p .707 .577 .707 r
F P
0 g
s
.67101 .7963 m .67609 .81461 L .69227 .80585 L p .707 .577 .707 r
F P
0 g
s
.69227 .80585 m .68719 .78755 L .67101 .7963 L p .707 .577 .707 r
F P
0 g
s
.50849 .72835 m .50889 .67282 L .506 .66417 L p .707 .577 .707 r
F P
0 g
s
.50292 .74929 m .50145 .78616 L .51403 .79493 L p .707 .577 .707 r
F P
0 g
s
.6967 .76005 m .69523 .79692 L .70231 .78835 L p .707 .577 .707 r
F P
0 g
s
.70231 .78835 m .70378 .75149 L .6967 .76005 L p .707 .577 .707 r
F P
0 g
s
.506 .66417 m .50559 .71971 L .50849 .72835 L p .707 .577 .707 r
F P
0 g
s
.70989 .66921 m .70949 .72475 L .70659 .7161 L p .707 .577 .707 r
F P
0 g
s
.70659 .7161 m .70699 .66057 L .70989 .66921 L p .707 .577 .707 r
F P
0 g
s
.51717 .85541 m .51209 .8371 L .50036 .8355 L p .707 .577 .707 r
F P
0 g
s
.50036 .8355 m .50544 .85381 L .51717 .85541 L p .707 .577 .707 r
F P
0 g
s
.50145 .78616 m .50292 .74929 L .50004 .74018 L p .707 .577 .707 r
F P
0 g
s
.68719 .78755 m .69227 .80585 L .69954 .79888 L p .707 .577 .707 r
F P
0 g
s
.69954 .79888 m .69446 .78057 L .68719 .78755 L p .707 .577 .707 r
F P
0 g
s
.49389 .82174 m .48879 .31933 L .44478 .3171 L p .707 .577 .707 r
F P
0 g
s
.50559 .71971 m .506 .66417 L .51308 .65577 L p .707 .577 .707 r
F P
0 g
s
.50004 .74018 m .49857 .77704 L .50145 .78616 L p .707 .577 .707 r
F P
0 g
s
.51308 .65577 m .51268 .7113 L .50559 .71971 L p .707 .577 .707 r
F P
0 g
s
.49857 .77704 m .50004 .74018 L .50712 .73161 L p .707 .577 .707 r
F P
0 g
s
.51268 .7113 m .51308 .65577 L .52945 .64844 L p .707 .577 .707 r
F P
0 g
s
.50712 .73161 m .50566 .76848 L .49857 .77704 L p .707 .577 .707 r
F P
0 g
s
.52945 .64844 m .52905 .70397 L .51268 .7113 L p .707 .577 .707 r
F P
0 g
s
.50566 .76848 m .50712 .73161 L .52349 .72444 L p .707 .577 .707 r
F P
0 g
s
.52349 .72444 m .52202 .76131 L .50566 .76848 L p .707 .577 .707 r
F P
0 g
s
.51038 .84233 m .5053 .82403 L .52148 .81527 L p .707 .577 .707 r
F P
0 g
s
.52202 .76131 m .52349 .72444 L .54753 .71937 L p .707 .577 .707 r
F P
0 g
s
.52148 .81527 m .52656 .83357 L .51038 .84233 L p .707 .577 .707 r
F P
0 g
s
.54753 .71937 m .54606 .75623 L .52202 .76131 L p .707 .577 .707 r
F P
0 g
s
.52656 .83357 m .52148 .81527 L .54497 .80558 L p .707 .577 .707 r
F P
0 g
s
.54497 .80558 m .55005 .82389 L .52656 .83357 L p .707 .577 .707 r
F P
0 g
s
.48879 .31933 m .49389 .82174 L .53883 .82024 L p .707 .577 .707 r
F P
0 g
s
.52905 .70397 m .52945 .64844 L .5535 .64289 L p .707 .577 .707 r
F P
0 g
s
.5535 .64289 m .5531 .69843 L .52905 .70397 L p .707 .577 .707 r
F P
0 g
s
.53883 .82024 m .53373 .31783 L .48879 .31933 L p .707 .577 .707 r
F P
0 g
s
.5531 .69843 m .5535 .64289 L .58288 .63968 L p .707 .577 .707 r
F P
0 g
s
.58288 .63968 m .58248 .69521 L .5531 .69843 L p .707 .577 .707 r
F P
0 g
s
.54606 .75623 m .54753 .71937 L .5769 .71688 L p .707 .577 .707 r
F P
0 g
s
.5769 .71688 m .57543 .75375 L .54606 .75623 L p .707 .577 .707 r
F P
0 g
s
.55005 .82389 m .54497 .80558 L .57349 .79591 L p .707 .577 .707 r
F P
0 g
s
.57349 .79591 m .57857 .81422 L .55005 .82389 L p .707 .577 .707 r
F P
0 g
s
.57857 .81422 m .57349 .79591 L .60423 .78721 L p .707 .577 .707 r
F P
0 g
s
.60423 .78721 m .60931 .80552 L .57857 .81422 L p .707 .577 .707 r
F P
0 g
s
.53373 .31783 m .53883 .82024 L .58031 .81514 L p .707 .577 .707 r
F P
0 g
s
.57543 .75375 m .5769 .71688 L .60871 .71723 L p .707 .577 .707 r
F P
0 g
s
.60871 .71723 m .60724 .7541 L .57543 .75375 L p .707 .577 .707 r
F P
0 g
s
.58031 .81514 m .57521 .31273 L .53373 .31783 L p .707 .577 .707 r
F P
0 g
s
.44988 .81951 m .44478 .3171 L .40602 .31136 L p .707 .577 .707 r
F P
0 g
s
.44478 .3171 m .44988 .81951 L .49389 .82174 L p .707 .577 .707 r
F P
0 g
s
.70378 .75149 m .70231 .78835 L .69943 .77924 L p .707 .577 .707 r
F P
0 g
s
.69943 .77924 m .7009 .74237 L .70378 .75149 L p .707 .577 .707 r
F P
0 g
s
.70699 .66057 m .70659 .7161 L .694 .70805 L p .707 .577 .707 r
F P
0 g
s
.694 .70805 m .6944 .65252 L .70699 .66057 L p .707 .577 .707 r
F P
0 g
s
.50544 .85381 m .50036 .8355 L .49802 .831 L p .707 .577 .707 r
F P
0 g
s
.58248 .69521 m .58288 .63968 L .61472 .63911 L p .707 .577 .707 r
F P
0 g
s
.61472 .63911 m .61431 .69464 L .58248 .69521 L p .707 .577 .707 r
F P
0 g
s
.63986 .72038 m .63839 .75724 L .60724 .7541 L p .707 .577 .707 r
F P
0 g
s
.60724 .7541 m .60871 .71723 L .63986 .72038 L p .707 .577 .707 r
F P
0 g
s
.63419 .78033 m .63927 .79864 L .60931 .80552 L p .707 .577 .707 r
F P
0 g
s
.60931 .80552 m .60423 .78721 L .63419 .78033 L p .707 .577 .707 r
F P
0 g
s
.57521 .31273 m .58031 .81514 L .61427 .80696 L p .707 .577 .707 r
F P
0 g
s
.61427 .80696 m .60917 .30455 L .57521 .31273 L p .707 .577 .707 r
F P
0 g
s
.49802 .831 m .5031 .84931 L .50544 .85381 L p .707 .577 .707 r
F P
0 g
s
.69446 .78057 m .69954 .79888 L .69721 .79437 L p .707 .577 .707 r
F P
0 g
s
.69721 .79437 m .69212 .77607 L .69446 .78057 L p .707 .577 .707 r
F P
0 g
s
.25776 .71382 m .25816 .65828 L .22699 .65615 L p .707 .577 .707 r
F P
0 g
s
.25816 .65828 m .25776 .71382 L .28959 .71325 L p .707 .577 .707 r
F P
0 g
s
.28959 .71325 m .28999 .65771 L .25816 .65828 L p .707 .577 .707 r
F P
0 g
s
.28999 .65771 m .28959 .71325 L .31897 .71003 L p .707 .577 .707 r
F P
0 g
s
.31897 .71003 m .31938 .65449 L .28999 .65771 L p .707 .577 .707 r
F P
0 g
s
.41112 .81376 m .40602 .31136 L .3763 .30265 L p .707 .577 .707 r
F P
0 g
s
.40602 .31136 m .41112 .81376 L .44988 .81951 L p .707 .577 .707 r
F P
0 g
s
.22658 .71169 m .22699 .65615 L .19953 .65153 L p .707 .577 .707 r
F P
0 g
s
.22699 .65615 m .22658 .71169 L .25776 .71382 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31938 .65449 m .31897 .71003 L .34302 .70449 L p .707 .577 .707 r
F P
0 g
s
.34302 .70449 m .34343 .64895 L .31938 .65449 L p .707 .577 .707 r
F P
0 g
s
.7009 .74237 m .69943 .77924 L .68686 .77046 L p .707 .577 .707 r
F P
0 g
s
.68686 .77046 m .68832 .7336 L .7009 .74237 L p .707 .577 .707 r
F P
0 g
s
.6944 .65252 m .694 .70805 L .67294 .70139 L p .707 .577 .707 r
F P
0 g
s
.67294 .70139 m .67335 .64586 L .6944 .65252 L p .707 .577 .707 r
F P
0 g
s
.64589 .64124 m .64549 .69677 L .61431 .69464 L p .707 .577 .707 r
F P
0 g
s
.61431 .69464 m .61472 .63911 L .64589 .64124 L p .707 .577 .707 r
F P
0 g
s
.63927 .79864 m .63419 .78033 L .66044 .77594 L p .707 .577 .707 r
F P
0 g
s
.60917 .30455 m .61427 .80696 L .63738 .79648 L p .707 .577 .707 r
F P
0 g
s
.63738 .79648 m .63228 .29408 L .60917 .30455 L p .707 .577 .707 r
F P
0 g
s
.5031 .84931 m .49802 .831 L .5053 .82403 L p .707 .577 .707 r
F P
0 g
s
.19953 .65153 m .19913 .70707 L .22658 .71169 L p .707 .577 .707 r
F P
0 g
s
.19913 .70707 m .19953 .65153 L .17848 .64487 L p .707 .577 .707 r
F P
0 g
s
.25063 .77353 m .2521 .73667 L .22095 .73352 L p .707 .577 .707 r
F P
0 g
s
.2521 .73667 m .25063 .77353 L .28245 .77388 L p .707 .577 .707 r
F P
0 g
s
.28245 .77388 m .28392 .73702 L .2521 .73667 L p .707 .577 .707 r
F P
0 g
s
.5053 .82403 m .51038 .84233 L .5031 .84931 L p .707 .577 .707 r
F P
0 g
s
.28392 .73702 m .28245 .77388 L .31181 .7714 L p .707 .577 .707 r
F P
0 g
s
.31181 .7714 m .31328 .73453 L .28392 .73702 L p .707 .577 .707 r
F P
0 g
s
.69212 .77607 m .69721 .79437 L .68548 .79278 L p .707 .577 .707 r
F P
0 g
s
.68548 .79278 m .6804 .77447 L .69212 .77607 L p .707 .577 .707 r
F P
0 g
s
.21949 .77039 m .22095 .73352 L .19352 .72788 L p .707 .577 .707 r
F P
0 g
s
.22095 .73352 m .21949 .77039 L .25063 .77353 L p .707 .577 .707 r
F P
0 g
s
.34343 .64895 m .34302 .70449 L .35939 .69715 L p .707 .577 .707 r
F P
0 g
s
.35939 .69715 m .3598 .64162 L .34343 .64895 L p .707 .577 .707 r
F P
0 g
s
.3814 .80506 m .3763 .30265 L .35852 .29185 L p .707 .577 .707 r
F P
0 g
s
.3763 .30265 m .3814 .80506 L .41112 .81376 L p .707 .577 .707 r
F P
0 g
s
.17848 .64487 m .17807 .7004 L .19913 .70707 L p .707 .577 .707 r
F P
0 g
s
.31328 .73453 m .31181 .7714 L .33585 .76632 L p .707 .577 .707 r
F P
0 g
s
.33585 .76632 m .33732 .72945 L .31328 .73453 L p .707 .577 .707 r
F P
0 g
s
.25033 .80523 m .24525 .78693 L .21529 .79381 L p .707 .577 .707 r
F P
0 g
s
.24525 .78693 m .25033 .80523 L .28107 .79653 L p .707 .577 .707 r
F P
0 g
s
.28107 .79653 m .27599 .77823 L .24525 .78693 L p .707 .577 .707 r
F P
0 g
s
.67335 .64586 m .67294 .70139 L .64549 .69677 L p .707 .577 .707 r
F P
0 g
s
.64549 .69677 m .64589 .64124 L .67335 .64586 L p .707 .577 .707 r
F P
0 g
s
.19352 .72788 m .19205 .76475 L .21949 .77039 L p .707 .577 .707 r
F P
0 g
s
.27599 .77823 m .28107 .79653 L .30959 .78687 L p .707 .577 .707 r
F P
0 g
s
.30959 .78687 m .30451 .76856 L .27599 .77823 L p .707 .577 .707 r
F P
0 g
s
.68832 .7336 m .68686 .77046 L .66582 .76288 L p .707 .577 .707 r
F P
0 g
s
.66582 .76288 m .66729 .72602 L .68832 .7336 L p .707 .577 .707 r
F P
0 g
s
.21529 .79381 m .22037 .81212 L .25033 .80523 L p .707 .577 .707 r
F P
0 g
s
.17807 .7004 m .17848 .64487 L .16588 .63682 L p .707 .577 .707 r
F P
0 g
s
.19205 .76475 m .19352 .72788 L .17249 .7203 L p .707 .577 .707 r
F P
0 g
s
.22037 .81212 m .21529 .79381 L .18904 .7982 L p .707 .577 .707 r
F P
0 g
s
.18904 .7982 m .19412 .81651 L .22037 .81212 L p .707 .577 .707 r
F P
0 g
s
.30451 .76856 m .30959 .78687 L .33308 .77718 L p .707 .577 .707 r
F P
0 g
s
.33308 .77718 m .328 .75887 L .30451 .76856 L p .707 .577 .707 r
F P
0 g
s
.17249 .7203 m .17102 .75717 L .19205 .76475 L p .707 .577 .707 r
F P
0 g
s
.6804 .77447 m .68548 .79278 L .66552 .79425 L p .707 .577 .707 r
F P
0 g
s
.66552 .79425 m .66044 .77594 L .6804 .77447 L p .707 .577 .707 r
F P
0 g
s
.66729 .72602 m .66582 .76288 L .63839 .75724 L p .707 .577 .707 r
F P
0 g
s
.63839 .75724 m .63986 .72038 L .66729 .72602 L p .707 .577 .707 r
F P
0 g
s
.63228 .29408 m .63738 .79648 L .64738 .78475 L p .707 .577 .707 r
F P
0 g
s
.64738 .78475 m .64228 .28234 L .63228 .29408 L p .707 .577 .707 r
F P
0 g
s
.33732 .72945 m .33585 .76632 L .35222 .75915 L p .707 .577 .707 r
F P
0 g
s
.35222 .75915 m .35369 .72228 L .33732 .72945 L p .707 .577 .707 r
F P
0 g
s
.16588 .63682 m .16548 .69236 L .17807 .7004 L p .707 .577 .707 r
F P
0 g
s
.3598 .64162 m .35939 .69715 L .36648 .68875 L p .707 .577 .707 r
F P
0 g
s
.36648 .68875 m .36688 .63322 L .3598 .64162 L p .707 .577 .707 r
F P
0 g
s
.19412 .81651 m .18904 .7982 L .16908 .79967 L p .707 .577 .707 r
F P
0 g
s
.17102 .75717 m .17249 .7203 L .15991 .71153 L p .707 .577 .707 r
F P
0 g
s
.16908 .79967 m .17416 .81798 L .19412 .81651 L p .707 .577 .707 r
F P
0 g
s
.328 .75887 m .33308 .77718 L .34926 .76842 L p .707 .577 .707 r
F P
0 g
s
.34926 .76842 m .34418 .75012 L .328 .75887 L p .707 .577 .707 r
F P
0 g
s
.16548 .69236 m .16588 .63682 L .16299 .62817 L p .707 .577 .707 r
F P
0 g
s
.36398 .62457 m .36358 .68011 L .35099 .67206 L p .707 .577 .707 r
F P
0 g
s
.35099 .67206 m .35139 .61652 L .36398 .62457 L p .707 .577 .707 r
F P
0 g
s
.36362 .79425 m .35852 .29185 L .35443 .27999 L p .707 .577 .707 r
F P
0 g
s
.36688 .63322 m .36648 .68875 L .36358 .68011 L p .707 .577 .707 r
F P
0 g
s
.36358 .68011 m .36398 .62457 L .36688 .63322 L p .707 .577 .707 r
F P
0 g
s
.35852 .29185 m .36362 .79425 L .3814 .80506 L p .707 .577 .707 r
F P
0 g
s
.15991 .71153 m .15845 .74839 L .17102 .75717 L p .707 .577 .707 r
F P
0 g
s
.66044 .77594 m .66552 .79425 L .63927 .79864 L p .707 .577 .707 r
F P
0 g
s
.35369 .72228 m .35222 .75915 L .35931 .75059 L p .707 .577 .707 r
F P
0 g
s
.35931 .75059 m .36077 .71372 L .35369 .72228 L p .707 .577 .707 r
F P
0 g
s
.16299 .62817 m .16258 .68371 L .16548 .69236 L p .707 .577 .707 r
F P
0 g
s
.17416 .81798 m .16908 .79967 L .15735 .79807 L p .707 .577 .707 r
F P
0 g
s
.15735 .79807 m .16243 .81638 L .17416 .81798 L p .707 .577 .707 r
F P
0 g
s
.15845 .74839 m .15991 .71153 L .15703 .70241 L p .707 .577 .707 r
F P
0 g
s
.34418 .75012 m .34926 .76842 L .35654 .76145 L p .707 .577 .707 r
F P
0 g
s
.35654 .76145 m .35146 .74314 L .34418 .75012 L p .707 .577 .707 r
F P
0 g
s
.64228 .28234 m .64738 .78475 L .64329 .7729 L p .707 .577 .707 r
F P
0 g
s
.64329 .7729 m .63819 .27049 L .64228 .28234 L p .707 .577 .707 r
F P
0 g
s
.16258 .68371 m .16299 .62817 L .17007 .61977 L p .707 .577 .707 r
F P
0 g
s
.15703 .70241 m .15556 .73928 L .15845 .74839 L p .707 .577 .707 r
F P
0 g
s
.36077 .71372 m .35931 .75059 L .35642 .74147 L p .707 .577 .707 r
F P
0 g
s
.35642 .74147 m .35789 .70461 L .36077 .71372 L p .707 .577 .707 r
F P
0 g
s
.35443 .27999 m .35953 .7824 L .36362 .79425 L p .707 .577 .707 r
F P
0 g
s
.35953 .7824 m .35443 .27999 L .36443 .26826 L p .707 .577 .707 r
F P
0 g
s
.17007 .61977 m .16967 .67531 L .16258 .68371 L p .707 .577 .707 r
F P
0 g
s
.16243 .81638 m .15735 .79807 L .15501 .79357 L p .707 .577 .707 r
F P
0 g
s
.15501 .79357 m .16009 .81188 L .16243 .81638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15556 .73928 m .15703 .70241 L .16411 .69385 L p .707 .577 .707 r
F P
0 g
s
.35146 .74314 m .35654 .76145 L .3542 .75694 L p .707 .577 .707 r
F P
0 g
s
.3542 .75694 m .34912 .73864 L .35146 .74314 L p .707 .577 .707 r
F P
0 g
s
.16967 .67531 m .17007 .61977 L .18644 .61244 L p .707 .577 .707 r
F P
0 g
s
.16411 .69385 m .16265 .73071 L .15556 .73928 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63819 .27049 m .64329 .7729 L .62551 .76209 L p .707 .577 .707 r
F P
0 g
s
.62551 .76209 m .62041 .25968 L .63819 .27049 L p .707 .577 .707 r
F P
0 g
s
.35789 .70461 m .35642 .74147 L .34385 .7327 L p .707 .577 .707 r
F P
0 g
s
.34385 .7327 m .34531 .69583 L .35789 .70461 L p .707 .577 .707 r
F P
0 g
s
.18644 .61244 m .18604 .66798 L .16967 .67531 L p .707 .577 .707 r
F P
0 g
s
.35139 .61652 m .35099 .67206 L .32993 .6654 L p .707 .577 .707 r
F P
0 g
s
.32993 .6654 m .33034 .60986 L .35139 .61652 L p .707 .577 .707 r
F P
0 g
s
.16009 .81188 m .15501 .79357 L .16229 .7866 L p .707 .577 .707 r
F P
0 g
s
.16229 .7866 m .16737 .8049 L .16009 .81188 L p .707 .577 .707 r
F P
0 g
s
.16265 .73071 m .16411 .69385 L .18048 .68668 L p .707 .577 .707 r
F P
0 g
s
.34912 .73864 m .3542 .75694 L .34247 .75535 L p .707 .577 .707 r
F P
0 g
s
.34247 .75535 m .33739 .73704 L .34912 .73864 L p .707 .577 .707 r
F P
0 g
s
.18604 .66798 m .18644 .61244 L .21049 .6069 L p .707 .577 .707 r
F P
0 g
s
.36953 .77067 m .36443 .26826 L .38754 .25778 L p .707 .577 .707 r
F P
0 g
s
.36443 .26826 m .36953 .77067 L .35953 .7824 L p .707 .577 .707 r
F P
0 g
s
.18048 .68668 m .17901 .72354 L .16265 .73071 L p .707 .577 .707 r
F P
0 g
s
.33034 .60986 m .32993 .6654 L .30248 .66078 L p .707 .577 .707 r
F P
0 g
s
.30248 .66078 m .30288 .60524 L .33034 .60986 L p .707 .577 .707 r
F P
0 g
s
.34531 .69583 m .34385 .7327 L .32281 .72512 L p .707 .577 .707 r
F P
0 g
s
.32281 .72512 m .32428 .68825 L .34531 .69583 L p .707 .577 .707 r
F P
0 g
s
.21049 .6069 m .21009 .66243 L .18604 .66798 L p .707 .577 .707 r
F P
0 g
s
.21009 .66243 m .21049 .6069 L .23987 .60368 L p .707 .577 .707 r
F P
0 g
s
.17901 .72354 m .18048 .68668 L .20452 .6816 L p .707 .577 .707 r
F P
0 g
s
.62041 .25968 m .62551 .76209 L .59579 .75339 L p .707 .577 .707 r
F P
0 g
s
.59579 .75339 m .59069 .25098 L .62041 .25968 L p .707 .577 .707 r
F P
0 g
s
.16737 .8049 m .16229 .7866 L .17847 .77784 L p .707 .577 .707 r
F P
0 g
s
.17847 .77784 m .18355 .79614 L .16737 .8049 L p .707 .577 .707 r
F P
0 g
s
.30288 .60524 m .30248 .66078 L .2713 .65865 L p .707 .577 .707 r
F P
0 g
s
.2713 .65865 m .27171 .60311 L .30288 .60524 L p .707 .577 .707 r
F P
0 g
s
.33739 .73704 m .34247 .75535 L .32251 .75682 L p .707 .577 .707 r
F P
0 g
s
.32251 .75682 m .31743 .73851 L .33739 .73704 L p .707 .577 .707 r
F P
0 g
s
.23947 .65922 m .23987 .60368 L .27171 .60311 L p .707 .577 .707 r
F P
0 g
s
.23987 .60368 m .23947 .65922 L .21009 .66243 L p .707 .577 .707 r
F P
0 g
s
.20452 .6816 m .20305 .71847 L .17901 .72354 L p .707 .577 .707 r
F P
0 g
s
.27171 .60311 m .2713 .65865 L .23947 .65922 L p .707 .577 .707 r
F P
0 g
s
.73797 .65777 m .73837 .60224 L .7072 .60011 L p .707 .577 .707 r
F P
0 g
s
.73837 .60224 m .73797 .65777 L .7698 .6572 L p .707 .577 .707 r
F P
0 g
s
.7698 .6572 m .77021 .60167 L .73837 .60224 L p .707 .577 .707 r
F P
0 g
s
.32428 .68825 m .32281 .72512 L .29538 .71948 L p .707 .577 .707 r
F P
0 g
s
.29538 .71948 m .29685 .68261 L .32428 .68825 L p .707 .577 .707 r
F P
0 g
s
.38754 .25778 m .39264 .76019 L .36953 .77067 L p .707 .577 .707 r
F P
0 g
s
.39264 .76019 m .38754 .25778 L .4215 .2496 L p .707 .577 .707 r
F P
0 g
s
.77021 .60167 m .7698 .6572 L .79919 .65399 L p .707 .577 .707 r
F P
0 g
s
.79919 .65399 m .79959 .59845 L .77021 .60167 L p .707 .577 .707 r
F P
0 g
s
.20305 .71847 m .20452 .6816 L .23389 .67912 L p .707 .577 .707 r
F P
0 g
s
.7068 .65564 m .7072 .60011 L .67974 .59549 L p .707 .577 .707 r
F P
0 g
s
.7072 .60011 m .7068 .65564 L .73797 .65777 L p .707 .577 .707 r
F P
0 g
s
.18355 .79614 m .17847 .77784 L .20196 .76815 L p .707 .577 .707 r
F P
0 g
s
.79959 .59845 m .79919 .65399 L .82324 .64844 L p .707 .577 .707 r
F P
0 g
s
.82324 .64844 m .82364 .59291 L .79959 .59845 L p .707 .577 .707 r
F P
0 g
s
.20196 .76815 m .20704 .78646 L .18355 .79614 L p .707 .577 .707 r
F P
0 g
s
.29685 .68261 m .29538 .71948 L .26423 .71633 L p .707 .577 .707 r
F P
0 g
s
.26423 .71633 m .2657 .67946 L .29685 .68261 L p .707 .577 .707 r
F P
0 g
s
.31743 .73851 m .32251 .75682 L .29626 .76121 L p .707 .577 .707 r
F P
0 g
s
.29626 .76121 m .29118 .7429 L .31743 .73851 L p .707 .577 .707 r
F P
0 g
s
.23389 .67912 m .23242 .71598 L .20305 .71847 L p .707 .577 .707 r
F P
0 g
s
.23242 .71598 m .23389 .67912 L .2657 .67946 L p .707 .577 .707 r
F P
0 g
s
.59069 .25098 m .59579 .75339 L .55703 .74764 L p .707 .577 .707 r
F P
0 g
s
.55703 .74764 m .55193 .24523 L .59069 .25098 L p .707 .577 .707 r
F P
0 g
s
.2657 .67946 m .26423 .71633 L .23242 .71598 L p .707 .577 .707 r
F P
0 g
s
.67974 .59549 m .67934 .65102 L .7068 .65564 L p .707 .577 .707 r
F P
0 g
s
.67934 .65102 m .67974 .59549 L .65869 .58883 L p .707 .577 .707 r
F P
0 g
s
.73085 .71926 m .73232 .6824 L .70117 .67925 L p .707 .577 .707 r
F P
0 g
s
.73232 .6824 m .73085 .71926 L .76266 .71961 L p .707 .577 .707 r
F P
0 g
s
.76266 .71961 m .76413 .68275 L .73232 .6824 L p .707 .577 .707 r
F P
0 g
s
.76413 .68275 m .76266 .71961 L .79203 .71713 L p .707 .577 .707 r
F P
0 g
s
.79203 .71713 m .79349 .68026 L .76413 .68275 L p .707 .577 .707 r
F P
0 g
s
.4266 .75201 m .4215 .2496 L .46298 .24451 L p .707 .577 .707 r
F P
0 g
s
.4215 .2496 m .4266 .75201 L .39264 .76019 L p .707 .577 .707 r
F P
0 g
s
.6997 .71612 m .70117 .67925 L .67373 .67361 L p .707 .577 .707 r
F P
0 g
s
.70117 .67925 m .6997 .71612 L .73085 .71926 L p .707 .577 .707 r
F P
0 g
s
.20704 .78646 m .20196 .76815 L .23048 .75848 L p .707 .577 .707 r
F P
0 g
s
.23048 .75848 m .23556 .77679 L .20704 .78646 L p .707 .577 .707 r
F P
0 g
s
.29118 .7429 m .29626 .76121 L .2663 .76809 L p .707 .577 .707 r
F P
0 g
s
.2663 .76809 m .26122 .74978 L .29118 .7429 L p .707 .577 .707 r
F P
0 g
s
.82364 .59291 m .82324 .64844 L .83961 .64111 L p .707 .577 .707 r
F P
0 g
s
.83961 .64111 m .84001 .58557 L .82364 .59291 L p .707 .577 .707 r
F P
0 g
s
.65869 .58883 m .65829 .64436 L .67934 .65102 L p .707 .577 .707 r
F P
0 g
s
.79349 .68026 m .79203 .71713 L .81607 .71205 L p .707 .577 .707 r
F P
0 g
s
.81607 .71205 m .81753 .67518 L .79349 .68026 L p .707 .577 .707 r
F P
0 g
s
.55193 .24523 m .55703 .74764 L .51302 .74541 L p .707 .577 .707 r
F P
0 g
s
.51302 .74541 m .50792 .243 L .55193 .24523 L p .707 .577 .707 r
F P
0 g
s
.73054 .75063 m .72546 .73232 L .6955 .7392 L p .707 .577 .707 r
F P
0 g
s
.72546 .73232 m .73054 .75063 L .76129 .74193 L p .707 .577 .707 r
F P
0 g
s
.76129 .74193 m .75621 .72362 L .72546 .73232 L p .707 .577 .707 r
F P
0 g
s
.67373 .67361 m .67227 .71048 L .6997 .71612 L p .707 .577 .707 r
F P
0 g
s
.23556 .77679 m .23048 .75848 L .26122 .74978 L p .707 .577 .707 r
F P
0 g
s
.75621 .72362 m .76129 .74193 L .7898 .73226 L p .707 .577 .707 r
F P
0 g
s
.7898 .73226 m .78472 .71395 L .75621 .72362 L p .707 .577 .707 r
F P
0 g
s
.26122 .74978 m .2663 .76809 L .23556 .77679 L p .707 .577 .707 r
F P
0 g
s
.6955 .7392 m .70058 .75751 L .73054 .75063 L p .707 .577 .707 r
F P
0 g
s
.65829 .64436 m .65869 .58883 L .6461 .58078 L p .707 .577 .707 r
F P
0 g
s
.67227 .71048 m .67373 .67361 L .6527 .66603 L p .707 .577 .707 r
F P
0 g
s
.46808 .74691 m .46298 .24451 L .50792 .243 L p .707 .577 .707 r
F P
0 g
s
.46298 .24451 m .46808 .74691 L .4266 .75201 L p .707 .577 .707 r
F P
0 g
s
.70058 .75751 m .6955 .7392 L .66925 .74359 L p .707 .577 .707 r
F P
0 g
s
.50792 .243 m .51302 .74541 L .46808 .74691 L p .707 .577 .707 r
F P
0 g
s
.66925 .74359 m .67434 .7619 L .70058 .75751 L p .707 .577 .707 r
F P
0 g
s
.78472 .71395 m .7898 .73226 L .8133 .72257 L p .707 .577 .707 r
F P
0 g
s
.8133 .72257 m .80822 .70427 L .78472 .71395 L p .707 .577 .707 r
F P
0 g
s
.6527 .66603 m .65123 .7029 L .67227 .71048 L p .707 .577 .707 r
F P
0 g
s
.81753 .67518 m .81607 .71205 L .83243 .70488 L p .707 .577 .707 r
F P
0 g
s
.83243 .70488 m .8339 .66801 L .81753 .67518 L p .707 .577 .707 r
F P
0 g
s
.6461 .58078 m .64569 .63631 L .65829 .64436 L p .707 .577 .707 r
F P
0 g
s
.84001 .58557 m .83961 .64111 L .84669 .63271 L p .707 .577 .707 r
F P
0 g
s
.84669 .63271 m .84709 .57717 L .84001 .58557 L p .707 .577 .707 r
F P
0 g
s
.67434 .7619 m .66925 .74359 L .64929 .74506 L p .707 .577 .707 r
F P
0 g
s
.65123 .7029 m .6527 .66603 L .64013 .65725 L p .707 .577 .707 r
F P
0 g
s
.64929 .74506 m .65437 .76337 L .67434 .7619 L p .707 .577 .707 r
F P
0 g
s
.80822 .70427 m .8133 .72257 L .82947 .71381 L p .707 .577 .707 r
F P
0 g
s
.82947 .71381 m .82439 .69551 L .80822 .70427 L p .707 .577 .707 r
F P
0 g
s
.64569 .63631 m .6461 .58078 L .6432 .57213 L p .707 .577 .707 r
F P
0 g
s
.64013 .65725 m .63866 .69412 L .65123 .7029 L p .707 .577 .707 r
F P
0 g
s
.8339 .66801 m .83243 .70488 L .83952 .69632 L p .707 .577 .707 r
F P
0 g
s
.83952 .69632 m .84099 .65945 L .8339 .66801 L p .707 .577 .707 r
F P
0 g
s
.6432 .57213 m .6428 .62767 L .64569 .63631 L p .707 .577 .707 r
F P
0 g
s
.84709 .57717 m .84669 .63271 L .84379 .62406 L p .707 .577 .707 r
F P
0 g
s
.84379 .62406 m .8442 .56853 L .84709 .57717 L p .707 .577 .707 r
F P
0 g
s
.65437 .76337 m .64929 .74506 L .63757 .74347 L p .707 .577 .707 r
F P
0 g
s
.63757 .74347 m .64265 .76177 L .65437 .76337 L p .707 .577 .707 r
F P
0 g
s
.63866 .69412 m .64013 .65725 L .63724 .64814 L p .707 .577 .707 r
F P
0 g
s
.82439 .69551 m .82947 .71381 L .83675 .70684 L p .707 .577 .707 r
F P
0 g
s
.83675 .70684 m .83167 .68853 L .82439 .69551 L p .707 .577 .707 r
F P
0 g
s
.6428 .62767 m .6432 .57213 L .65028 .56373 L p .707 .577 .707 r
F P
0 g
s
.63724 .64814 m .63577 .685 L .63866 .69412 L p .707 .577 .707 r
F P
0 g
s
.84099 .65945 m .83952 .69632 L .83663 .6872 L p .707 .577 .707 r
F P
0 g
s
.83663 .6872 m .8381 .65034 L .84099 .65945 L p .707 .577 .707 r
F P
0 g
s
.65028 .56373 m .64988 .61927 L .6428 .62767 L p .707 .577 .707 r
F P
0 g
s
.8442 .56853 m .84379 .62406 L .8312 .61602 L p .707 .577 .707 r
F P
0 g
s
.8312 .61602 m .83161 .56048 L .8442 .56853 L p .707 .577 .707 r
F P
0 g
s
.64265 .76177 m .63757 .74347 L .63523 .73896 L p .707 .577 .707 r
F P
0 g
s
.63523 .73896 m .64031 .75727 L .64265 .76177 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63577 .685 m .63724 .64814 L .64433 .63958 L p .707 .577 .707 r
F P
0 g
s
.83167 .68853 m .83675 .70684 L .83441 .70234 L p .707 .577 .707 r
F P
0 g
s
.83441 .70234 m .82933 .68403 L .83167 .68853 L p .707 .577 .707 r
F P
0 g
s
.39496 .62178 m .39536 .56624 L .36419 .56411 L p .707 .577 .707 r
F P
0 g
s
.39536 .56624 m .39496 .62178 L .42679 .62121 L p .707 .577 .707 r
F P
0 g
s
.42679 .62121 m .4272 .56567 L .39536 .56624 L p .707 .577 .707 r
F P
0 g
s
.64988 .61927 m .65028 .56373 L .66665 .5564 L p .707 .577 .707 r
F P
0 g
s
.4272 .56567 m .42679 .62121 L .45618 .61799 L p .707 .577 .707 r
F P
0 g
s
.45618 .61799 m .45658 .56245 L .4272 .56567 L p .707 .577 .707 r
F P
0 g
s
.64433 .63958 m .64286 .67644 L .63577 .685 L p .707 .577 .707 r
F P
0 g
s
.36379 .61965 m .36419 .56411 L .33673 .55949 L p .707 .577 .707 r
F P
0 g
s
.36419 .56411 m .36379 .61965 L .39496 .62178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45658 .56245 m .45618 .61799 L .48023 .61245 L p .707 .577 .707 r
F P
0 g
s
.48023 .61245 m .48063 .55691 L .45658 .56245 L p .707 .577 .707 r
F P
0 g
s
.8381 .65034 m .83663 .6872 L .82406 .67842 L p .707 .577 .707 r
F P
0 g
s
.82406 .67842 m .82553 .64156 L .8381 .65034 L p .707 .577 .707 r
F P
0 g
s
.66665 .5564 m .66625 .61193 L .64988 .61927 L p .707 .577 .707 r
F P
0 g
s
.83161 .56048 m .8312 .61602 L .81015 .60936 L p .707 .577 .707 r
F P
0 g
s
.81015 .60936 m .81055 .55382 L .83161 .56048 L p .707 .577 .707 r
F P
0 g
s
.64031 .75727 m .63523 .73896 L .6425 .73199 L p .707 .577 .707 r
F P
0 g
s
.33673 .55949 m .33633 .61503 L .36379 .61965 L p .707 .577 .707 r
F P
0 g
s
.33633 .61503 m .33673 .55949 L .31568 .55283 L p .707 .577 .707 r
F P
0 g
s
.38784 .6815 m .38931 .64463 L .35816 .64148 L p .707 .577 .707 r
F P
0 g
s
.38931 .64463 m .38784 .6815 L .41965 .68184 L p .707 .577 .707 r
F P
0 g
s
.41965 .68184 m .42112 .64498 L .38931 .64463 L p .707 .577 .707 r
F P
0 g
s
.6425 .73199 m .64758 .75029 L .64031 .75727 L p .707 .577 .707 r
F P
0 g
s
.64286 .67644 m .64433 .63958 L .66069 .63241 L p .707 .577 .707 r
F P
0 g
s
.42112 .64498 m .41965 .68184 L .44902 .67936 L p .707 .577 .707 r
F P
0 g
s
.44902 .67936 m .45048 .64249 L .42112 .64498 L p .707 .577 .707 r
F P
0 g
s
.82933 .68403 m .83441 .70234 L .82268 .70074 L p .707 .577 .707 r
F P
0 g
s
.82268 .70074 m .8176 .68243 L .82933 .68403 L p .707 .577 .707 r
F P
0 g
s
.66625 .61193 m .66665 .5564 L .69071 .55085 L p .707 .577 .707 r
F P
0 g
s
.35669 .67835 m .35816 .64148 L .33072 .63584 L p .707 .577 .707 r
F P
0 g
s
.35816 .64148 m .35669 .67835 L .38784 .6815 L p .707 .577 .707 r
F P
0 g
s
.48063 .55691 m .48023 .61245 L .4966 .60512 L p .707 .577 .707 r
F P
0 g
s
.4966 .60512 m .497 .54958 L .48063 .55691 L p .707 .577 .707 r
F P
0 g
s
.66069 .63241 m .65923 .66927 L .64286 .67644 L p .707 .577 .707 r
F P
0 g
s
.31568 .55283 m .31527 .60837 L .33633 .61503 L p .707 .577 .707 r
F P
0 g
s
.45048 .64249 m .44902 .67936 L .47306 .67428 L p .707 .577 .707 r
F P
0 g
s
.47306 .67428 m .47452 .63742 L .45048 .64249 L p .707 .577 .707 r
F P
0 g
s
.38753 .7132 m .38245 .69489 L .35249 .70177 L p .707 .577 .707 r
F P
0 g
s
.38245 .69489 m .38753 .7132 L .41828 .7045 L p .707 .577 .707 r
F P
0 g
s
.41828 .7045 m .4132 .68619 L .38245 .69489 L p .707 .577 .707 r
F P
0 g
s
.81055 .55382 m .81015 .60936 L .78269 .60473 L p .707 .577 .707 r
F P
0 g
s
.78269 .60473 m .78309 .5492 L .81055 .55382 L p .707 .577 .707 r
F P
0 g
s
.33072 .63584 m .32926 .67271 L .35669 .67835 L p .707 .577 .707 r
F P
0 g
s
.4132 .68619 m .41828 .7045 L .44679 .69483 L p .707 .577 .707 r
F P
0 g
s
.44679 .69483 m .44171 .67652 L .4132 .68619 L p .707 .577 .707 r
F P
0 g
s
.82553 .64156 m .82406 .67842 L .80303 .67084 L p .707 .577 .707 r
F P
0 g
s
.80303 .67084 m .80449 .63398 L .82553 .64156 L p .707 .577 .707 r
F P
0 g
s
.35249 .70177 m .35757 .72008 L .38753 .7132 L p .707 .577 .707 r
F P
0 g
s
.69071 .55085 m .6903 .60639 L .66625 .61193 L p .707 .577 .707 r
F P
0 g
s
.31527 .60837 m .31568 .55283 L .30309 .54478 L p .707 .577 .707 r
F P
0 g
s
.32926 .67271 m .33072 .63584 L .30969 .62826 L p .707 .577 .707 r
F P
0 g
s
.6903 .60639 m .69071 .55085 L .72009 .54764 L p .707 .577 .707 r
F P
0 g
s
.35757 .72008 m .35249 .70177 L .32624 .70616 L p .707 .577 .707 r
F P
0 g
s
.64758 .75029 m .6425 .73199 L .65868 .72323 L p .707 .577 .707 r
F P
0 g
s
.65923 .66927 m .66069 .63241 L .68474 .62733 L p .707 .577 .707 r
F P
0 g
s
.32624 .70616 m .33132 .72447 L .35757 .72008 L p .707 .577 .707 r
F P
0 g
s
.44171 .67652 m .44679 .69483 L .47029 .68514 L p .707 .577 .707 r
F P
0 g
s
.47029 .68514 m .46521 .66684 L .44171 .67652 L p .707 .577 .707 r
F P
0 g
s
.65868 .72323 m .66376 .74154 L .64758 .75029 L p .707 .577 .707 r
F P
0 g
s
.30969 .62826 m .30822 .66513 L .32926 .67271 L p .707 .577 .707 r
F P
0 g
s
.78309 .5492 m .78269 .60473 L .75152 .6026 L p .707 .577 .707 r
F P
0 g
s
.75152 .6026 m .75192 .54707 L .78309 .5492 L p .707 .577 .707 r
F P
0 g
s
.8176 .68243 m .82268 .70074 L .80272 .70221 L p .707 .577 .707 r
F P
0 g
s
.80272 .70221 m .79764 .6839 L .8176 .68243 L p .707 .577 .707 r
F P
0 g
s
.47452 .63742 m .47306 .67428 L .48942 .66711 L p .707 .577 .707 r
F P
0 g
s
.48942 .66711 m .49089 .63025 L .47452 .63742 L p .707 .577 .707 r
F P
0 g
s
.71968 .60318 m .72009 .54764 L .75192 .54707 L p .707 .577 .707 r
F P
0 g
s
.72009 .54764 m .71968 .60318 L .6903 .60639 L p .707 .577 .707 r
F P
0 g
s
.30309 .54478 m .30268 .60032 L .31527 .60837 L p .707 .577 .707 r
F P
0 g
s
.497 .54958 m .4966 .60512 L .50368 .59672 L p .707 .577 .707 r
F P
0 g
s
.50368 .59672 m .50408 .54118 L .497 .54958 L p .707 .577 .707 r
F P
0 g
s
.68474 .62733 m .68327 .66419 L .65923 .66927 L p .707 .577 .707 r
F P
0 g
s
.75192 .54707 m .75152 .6026 L .71968 .60318 L p .707 .577 .707 r
F P
0 g
s
.80449 .63398 m .80303 .67084 L .77559 .66521 L p .707 .577 .707 r
F P
0 g
s
.77559 .66521 m .77706 .62834 L .80449 .63398 L p .707 .577 .707 r
F P
0 g
s
.33132 .72447 m .32624 .70616 L .30628 .70763 L p .707 .577 .707 r
F P
0 g
s
.30822 .66513 m .30969 .62826 L .29712 .61949 L p .707 .577 .707 r
F P
0 g
s
.30628 .70763 m .31136 .72594 L .33132 .72447 L p .707 .577 .707 r
F P
0 g
s
.46521 .66684 m .47029 .68514 L .48646 .67638 L p .707 .577 .707 r
F P
0 g
s
.48646 .67638 m .48138 .65808 L .46521 .66684 L p .707 .577 .707 r
F P
0 g
s
.68327 .66419 m .68474 .62733 L .7141 .62484 L p .707 .577 .707 r
F P
0 g
s
.30268 .60032 m .30309 .54478 L .30019 .53613 L p .707 .577 .707 r
F P
0 g
s
.66376 .74154 m .65868 .72323 L .68218 .71354 L p .707 .577 .707 r
F P
0 g
s
.29712 .61949 m .29565 .65635 L .30822 .66513 L p .707 .577 .707 r
F P
0 g
s
.68218 .71354 m .68726 .73185 L .66376 .74154 L p .707 .577 .707 r
F P
0 g
s
.77706 .62834 m .77559 .66521 L .74445 .66206 L p .707 .577 .707 r
F P
0 g
s
.74445 .66206 m .74591 .62519 L .77706 .62834 L p .707 .577 .707 r
F P
0 g
s
.79764 .6839 m .80272 .70221 L .77648 .7066 L p .707 .577 .707 r
F P
0 g
s
.77648 .7066 m .77139 .68829 L .79764 .6839 L p .707 .577 .707 r
F P
0 g
s
.7141 .62484 m .71263 .66171 L .68327 .66419 L p .707 .577 .707 r
F P
0 g
s
.71263 .66171 m .7141 .62484 L .74591 .62519 L p .707 .577 .707 r
F P
0 g
s
.49089 .63025 m .48942 .66711 L .49651 .65855 L p .707 .577 .707 r
F P
0 g
s
.49651 .65855 m .49798 .62168 L .49089 .63025 L p .707 .577 .707 r
F P
0 g
s
.74591 .62519 m .74445 .66206 L .71263 .66171 L p .707 .577 .707 r
F P
0 g
s
.30019 .53613 m .29979 .59167 L .30268 .60032 L p .707 .577 .707 r
F P
0 g
s
.50408 .54118 m .50368 .59672 L .50078 .58807 L p .707 .577 .707 r
F P
0 g
s
.50078 .58807 m .50119 .53253 L .50408 .54118 L p .707 .577 .707 r
F P
0 g
s
.31136 .72594 m .30628 .70763 L .29456 .70604 L p .707 .577 .707 r
F P
0 g
s
.29456 .70604 m .29964 .72434 L .31136 .72594 L p .707 .577 .707 r
F P
0 g
s
.29565 .65635 m .29712 .61949 L .29423 .61037 L p .707 .577 .707 r
F P
0 g
s
.68726 .73185 m .68218 .71354 L .71069 .70388 L p .707 .577 .707 r
F P
0 g
s
.48138 .65808 m .48646 .67638 L .49374 .66941 L p .707 .577 .707 r
F P
0 g
s
.49374 .66941 m .48866 .6511 L .48138 .65808 L p .707 .577 .707 r
F P
0 g
s
.71069 .70388 m .71577 .72218 L .68726 .73185 L p .707 .577 .707 r
F P
0 g
s
.77139 .68829 m .77648 .7066 L .74651 .71348 L p .707 .577 .707 r
F P
0 g
s
.74651 .71348 m .74143 .69518 L .77139 .68829 L p .707 .577 .707 r
F P
0 g
s
.29979 .59167 m .30019 .53613 L .30727 .52773 L p .707 .577 .707 r
F P
0 g
s
.29423 .61037 m .29276 .64724 L .29565 .65635 L p .707 .577 .707 r
F P
0 g
s
.71577 .72218 m .71069 .70388 L .74143 .69518 L p .707 .577 .707 r
F P
0 g
s
.74143 .69518 m .74651 .71348 L .71577 .72218 L p .707 .577 .707 r
F P
0 g
s
.49798 .62168 m .49651 .65855 L .49362 .64943 L p .707 .577 .707 r
F P
0 g
s
.49362 .64943 m .49509 .61257 L .49798 .62168 L p .707 .577 .707 r
F P
0 g
s
.30727 .52773 m .30687 .58327 L .29979 .59167 L p .707 .577 .707 r
F P
0 g
s
.29964 .72434 m .29456 .70604 L .29222 .70153 L p .707 .577 .707 r
F P
0 g
s
.50119 .53253 m .50078 .58807 L .48819 .58002 L p .707 .577 .707 r
F P
0 g
s
.48819 .58002 m .4886 .52448 L .50119 .53253 L p .707 .577 .707 r
F P
0 g
s
.29222 .70153 m .2973 .71984 L .29964 .72434 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29276 .64724 m .29423 .61037 L .30132 .60181 L p .707 .577 .707 r
F P
0 g
s
.48866 .6511 m .49374 .66941 L .4914 .66491 L p .707 .577 .707 r
F P
0 g
s
.4914 .66491 m .48632 .6466 L .48866 .6511 L p .707 .577 .707 r
F P
0 g
s
.30687 .58327 m .30727 .52773 L .32364 .5204 L p .707 .577 .707 r
F P
0 g
s
.30132 .60181 m .29985 .63868 L .29276 .64724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49509 .61257 m .49362 .64943 L .48105 .64066 L p .707 .577 .707 r
F P
0 g
s
.48105 .64066 m .48252 .60379 L .49509 .61257 L p .707 .577 .707 r
F P
0 g
s
.32364 .5204 m .32324 .57594 L .30687 .58327 L p .707 .577 .707 r
F P
0 g
s
.4886 .52448 m .48819 .58002 L .46714 .57336 L p .707 .577 .707 r
F P
0 g
s
.46714 .57336 m .46754 .51782 L .4886 .52448 L p .707 .577 .707 r
F P
0 g
s
.2973 .71984 m .29222 .70153 L .29949 .69456 L p .707 .577 .707 r
F P
0 g
s
.29949 .69456 m .30457 .71286 L .2973 .71984 L p .707 .577 .707 r
F P
0 g
s
.29985 .63868 m .30132 .60181 L .31768 .59464 L p .707 .577 .707 r
F P
0 g
s
.48632 .6466 m .4914 .66491 L .47967 .66331 L p .707 .577 .707 r
F P
0 g
s
.47967 .66331 m .47459 .645 L .48632 .6466 L p .707 .577 .707 r
F P
0 g
s
.32324 .57594 m .32364 .5204 L .3477 .51486 L p .707 .577 .707 r
F P
0 g
s
.31768 .59464 m .31622 .6315 L .29985 .63868 L p .707 .577 .707 r
F P
0 g
s
.46754 .51782 m .46714 .57336 L .43968 .56874 L p .707 .577 .707 r
F P
0 g
s
.43968 .56874 m .44008 .5132 L .46754 .51782 L p .707 .577 .707 r
F P
0 g
s
.48252 .60379 m .48105 .64066 L .46002 .63308 L p .707 .577 .707 r
F P
0 g
s
.46002 .63308 m .46148 .59621 L .48252 .60379 L p .707 .577 .707 r
F P
0 g
s
.3477 .51486 m .34729 .57039 L .32324 .57594 L p .707 .577 .707 r
F P
0 g
s
.34729 .57039 m .3477 .51486 L .37708 .51164 L p .707 .577 .707 r
F P
0 g
s
.31622 .6315 m .31768 .59464 L .34172 .58956 L p .707 .577 .707 r
F P
0 g
s
.30457 .71286 m .29949 .69456 L .31567 .6858 L p .707 .577 .707 r
F P
0 g
s
.31567 .6858 m .32075 .70411 L .30457 .71286 L p .707 .577 .707 r
F P
0 g
s
.44008 .5132 m .43968 .56874 L .40851 .56661 L p .707 .577 .707 r
F P
0 g
s
.40851 .56661 m .40891 .51107 L .44008 .5132 L p .707 .577 .707 r
F P
0 g
s
.47459 .645 m .47967 .66331 L .45971 .66478 L p .707 .577 .707 r
F P
0 g
s
.45971 .66478 m .45463 .64647 L .47459 .645 L p .707 .577 .707 r
F P
0 g
s
.37667 .56718 m .37708 .51164 L .40891 .51107 L p .707 .577 .707 r
F P
0 g
s
.37708 .51164 m .37667 .56718 L .34729 .57039 L p .707 .577 .707 r
F P
0 g
s
.34172 .58956 m .34026 .62643 L .31622 .6315 L p .707 .577 .707 r
F P
0 g
s
.40891 .51107 m .40851 .56661 L .37667 .56718 L p .707 .577 .707 r
F P
0 g
s
.46148 .59621 m .46002 .63308 L .43258 .62744 L p .707 .577 .707 r
F P
0 g
s
.43258 .62744 m .43405 .59057 L .46148 .59621 L p .707 .577 .707 r
F P
0 g
s
.34026 .62643 m .34172 .58956 L .37109 .58708 L p .707 .577 .707 r
F P
0 g
s
.32075 .70411 m .31567 .6858 L .33916 .67611 L p .707 .577 .707 r
F P
0 g
s
.33916 .67611 m .34425 .69442 L .32075 .70411 L p .707 .577 .707 r
F P
0 g
s
.43405 .59057 m .43258 .62744 L .40143 .62429 L p .707 .577 .707 r
F P
0 g
s
.40143 .62429 m .4029 .58742 L .43405 .59057 L p .707 .577 .707 r
F P
0 g
s
.45463 .64647 m .45971 .66478 L .43346 .66917 L p .707 .577 .707 r
F P
0 g
s
.43346 .66917 m .42838 .65086 L .45463 .64647 L p .707 .577 .707 r
F P
0 g
s
.37109 .58708 m .36962 .62394 L .34026 .62643 L p .707 .577 .707 r
F P
0 g
s
.36962 .62394 m .37109 .58708 L .4029 .58742 L p .707 .577 .707 r
F P
0 g
s
.4029 .58742 m .40143 .62429 L .36962 .62394 L p .707 .577 .707 r
F P
0 g
s
.34425 .69442 m .33916 .67611 L .36768 .66644 L p .707 .577 .707 r
F P
0 g
s
.36768 .66644 m .37276 .68475 L .34425 .69442 L p .707 .577 .707 r
F P
0 g
s
.42838 .65086 m .43346 .66917 L .4035 .67605 L p .707 .577 .707 r
F P
0 g
s
.4035 .67605 m .39842 .65774 L .42838 .65086 L p .707 .577 .707 r
F P
0 g
s
.37276 .68475 m .36768 .66644 L .39842 .65774 L p .707 .577 .707 r
F P
0 g
s
.39842 .65774 m .4035 .67605 L .37276 .68475 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0000G
0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0006Eoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
00=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001UOol005ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000IGoo001KOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol005Uoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Egoo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000AOolA0013
Ool005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH8000kOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Goo001EOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0017oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P00<Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`00;Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<0
05YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol00`00FUH00003
FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH70003FUH00`00
FUIJEP02FUH?0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool005Eoo`80009JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000IJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
02aoo`00EGoo0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF10000eYF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000`0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0010OolB
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool003Yoo`H000AJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF008002aoo`00=goo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF1@0015YF00<005YFFUH00P00;7oo000dOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00AJEP00FUIJEP8002aoo`00<Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2
000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
02aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEQ40009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP<002aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEPT0
009JEP03001JEUYF00AJEP<000AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF
20000eYF00<005YFFUH01eYF00@005YFFUIJEPH000EJEP03001JEUYF00=JEP03001JEUYF009JEP<0
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF1@001EYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH010000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF009JEP03001JEP00
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF001JEP8000AJEP<000=JEP03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP03001JEUYF00AJEP@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P00;Goo000^Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00
FUH00000FUH000EJEP03001JEP0000<00005FUH005YFFUH00005FUH50006FUH00`00FUIJEP08FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH000030004FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEPH000EJEP<000MJEP03001JEUYF00P0009JEP<000=JEP8000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP8002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF
2`0000=JEP0000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP03FUH01000FUIJ
EUYF10000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00=JEP03001JEUYF00@0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF0080
0003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH00UYF5P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF1P00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00;Woo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF100000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF00MJEP04
001JEUYFFUH70003FUH40004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEP0000<000AJEP03001JEUYF008000Moo`<000Aoo`P000AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002ioo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP800003
FUH005YF00QJEP03001JEUYF00AJEPL00005FUH00000FUH00004FUH01000FUIJEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP04
FUH00`00FUIJEP020006Ool5000;Ool60004FUH01P00FUIJEP00FUH002eoo`00;Woo00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
0000100000AJEP00000000=JEP03001JEUYF00MJEP03001JEUYF00@000IJEP8000=JEP03001JEUYF
00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00
FUH00P0015YF0`0015YF00<005YFFUH00P001Woo1@004Goo0`0000MJEP00FUIJEP00FUH0000]Ool0
02ioo`05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH30006
FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00800003FUH005YF00AJEP03001JEP0000@0009JEP8000Ioo`D0011oo`H0009JEP03001J
EP0002eoo`00;Woo0P000UYF00<005YFFUH00eYF60000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH01eYF00<005YFFUH0400000=JEP00FUH01UYF00@005YF000000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00=JEPL000Eoo`<000Yoo`L000=JEP05001JEUYF001JEP02000^Ool002ioo`80009JEP03001JEUYF
00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP<000=JEP03001JEUYF
00EJEP@0009JEPD000AJEP<000AJEP03001JEUYF00AJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF009JEQ800003FUH0000000h002ioo`00;Woo0P000UYF0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF009JEP800003FUH005YF00=J
EPT000MJEP03001JEUYF009JEP<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEPH000=JEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;goo0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`001eYF00<005YF00000`00
0UYF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH20003FUH01@00FUIJEP00FUH0
1`000eYF00<005YFFUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP02FUH2000015YF000005YF1P0000=JEP00FUH025YF00<005YFFUH00UYF0`001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=J
EP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YF0000009JEPH0
00IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000_Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003
FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00
0eYF00<005YFFUH015YF00<005YF00000`001eYF00<005YFFUH01EYF1`000eYF00<005YFFUH00eYF
00<005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0P0000=JEP00FUH00eYF10000UYF
00<005YFFUH01eYF00<005YFFUH010001UYF00<005YF00000P001EYF00<005YF0000;goo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUH000050006FUH00`00FUIJEP06FUH400000eYF001JEP07FUH20003FUH00`00
FUIJEP02FUH2000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEP03001JEUYF00<000UJEP03001JEUYF009JEP@000AJEP03001JEUYF
009JEP@000EJEP05001JEUYFFUH0000bOol002aoo`03001JEP0000=JEP04001JEUYFFUH8000AOol7
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUIJEP06FUH00`00FUH0000?0002FUH00`00FUIJ
EP05FUH3000cOol002aoo`03001JEP0000=JEP@0019oo`<000Yoo`800003FUH005YF00AJEP03001J
EP0000<00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000@000EJEP03001JEUYF00EJEP<000=oo`T000IJEP03001JEUYF00AJEP8003Eoo`00;7oo00@0
05YF001JEP8000AJEP<000ioo`D000]oo`T00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00=JEP8000Ioo`D00003
FUH005YF00QJEP04001JEUYFFUH2000gOol002aoo`06001JEP00001JEP001EYF00<005YF00000`00
2Woo1@004Goo0`0000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00<005YFFUH01EYF00<005YF00000`001goo10000eYF00<005YFFUH01UYF00@0
05YF000003Uoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1P0017oo1@002Goo2000
0UYF0`000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH00eYF0`0000=JEP00000017oo10001eYF00<005YFFUH01EYF0`00>goo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH01000FUIJEUYF1000
00AJEP00001JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00
FUH00003000015YF000000000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01000?Woo000/Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH60002FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP00
0UYF00<005YFFUH00UYF0P0015YF1P001UYF00<005YFFUH01UYF1000@Woo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUIJEPL0
00=JEP03001JEUYF00MJEP03001JEUYF009JEP<004Ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001J
EUYF00800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH=000;FUH90008FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF00000P00BGoo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60006FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001JEUYF
00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001<Ool002moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH4000015YF000000000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF0P001UYF
00<005YFFUH01EYF00<005YFFUH01000Cgoo000`Ool20004FUH00`00FUIJEP05FUH00`00FUH00003
0006FUH00`00FUIJEP07FUH01000FUIJEUYF1`000eYF1@000UYF00<005YFFUH00eYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF009JEPH005=oo`00<Woo0`0000=JEP00FUH0
1UYF0P0000=JEP00FUH025YF00<005YFFUH015YF1`0000EJEP00001JEP0000AJEP03001JEUYF0080
009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP@000AJEP800003FUH005YF009JEPL0009JEP03001JEP0005Ao
o`00=Goo0`000eYF0`000eYF00<005YFFUH01eYF00<005YFFUH010001UYF0P000eYF00<005YFFUH0
0eYF0P0000Eoo`00FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0000400000goo
00000003FUH01P00FUIJEP00FUH005Aoo`00>7oo0`001eYF00<005YFFUH015YF1@000UYF00<005YF
FUH00UYF0`001UYF00@005YFFUIJEP80009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3
00000eYF001oo`04Ool400001eYF001JEUYF001JEP0005Aoo`00=Woo0P0000=JEP00FUH01eYF00<0
05YFFUH01`0015YF00<005YFFUH00P0000=JEP00FUH01UYF00@005YF000000Aoo`03001JEUYF0080
0003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000@000=JEP<0009JEP8005Eoo`00=7oo
0P000eYF00<005YFFUH01EYF10000Woo300015YF00<005YFFUH015YF0P001Woo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000003P00EGoo000bOol20006FUH00`00FUIJ
EP02FUH20006Ool90007FUH00`00FUIJEP02FUH20008Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01000EGoo000`Ool30007FUH00`00
FUH000020008Ool50002FUH00`00FUIJEP07FUH01000FUH000002Woo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000=JEP03001JEUYF009JEP04001JEUYFFUH3001EOol002ioo`80
00=JEP03001JEUYF00AJEP8000Qoo`L000=JEP03001JEUYF00IJEP<000aoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005Eoo`00
;Goo0P0015YF00<005YFFUH00UYF0P001Woo100000=JEP00FUH025YF00<005YFFUH00UYF0`0047oo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH00UYF
00@005YFFUIJEP8005Eoo`00;7oo00<005YF00001EYF00@005YF0000009oo`H000IJEP03001JEUYF
00IJEP03001JEP00008001=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJ
EP/005Ioo`00;7oo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<001Mo
o`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP@0009JEP03001JEUYF009JEP04001J
EUYF001FOol002aoo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04000LOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF1P000UYF00<005YF00000P001EYF00<005YF0000EWoo
000]Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH015YF1@008Woo0P001UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
00000`001UYF0P000eYF00<005YFFUH00UYF0P00Egoo000]Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04000YOol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH400000eYF001JEP03FUH40005FUH00`00FUIJEP02FUH0
0`00Oomoo`1FOol002eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH4000_Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0?0002FUH00`00
FUIJEP05FUH01000FUH00000FGoo000]Ool20002FUH00`00FUIJEP03FUH00`00FUH00003000fOol4
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool90006FUH00`00FUIJ
EP04FUH3001KOol002ioo`/003ioo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00L000Ioo`D00003FUH005YF00QJEP04001JEUYFFUH2001NOol007eoob000004FUH000000008Ool5
0002FUH00`00FUIJEP06FUH01000FUH00000H7oo002?Ool00`00FUIJEP02FUH00`00FUIJEP04FUH3
0007Ool4000015YF000000000eYF00<005YFFUH01EYF0`00HWoo002>Ool20005FUH01000FUIJEUYF
0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo002=Ool01000FUIJEP0015YF
00@005YF0000009oo`H000IJEP03001JEUYF00MJEP03001JEP00008006Moo`00SGoo00@005YFFUH0
00AJEPH000=JEP03001JEUYF00MJEP03001JEUYF00AJEP@006Yoo`00SWoo00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006ioo`00SWoo00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF1000LWoo002?Ool015YF001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01000MWoo002?Ool01000FUIJEP001EYF00<005YFFUH00UYF1P00NWoo002?Ool2
0002FUH00`00FUIJEP070020Ool0095oo`D008Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59149 .74918 m .59109 .69355 L .55991 .69188 L p .707 .577 .707 r
F P
0 g
s
.59109 .69355 m .59149 .74918 L .62332 .74819 L p .707 .577 .707 r
F P
0 g
s
.62332 .74819 m .62292 .69257 L .59109 .69355 L p .707 .577 .707 r
F P
0 g
s
.62292 .69257 m .62332 .74819 L .6527 .74465 L p .707 .577 .707 r
F P
0 g
s
.6527 .74465 m .6523 .68903 L .62292 .69257 L p .707 .577 .707 r
F P
0 g
s
.56032 .74751 m .55991 .69188 L .53246 .68772 L p .707 .577 .707 r
F P
0 g
s
.55991 .69188 m .56032 .74751 L .59149 .74918 L p .707 .577 .707 r
F P
0 g
s
.6523 .68903 m .6527 .74465 L .67676 .7389 L p .707 .577 .707 r
F P
0 g
s
.67676 .7389 m .67635 .68327 L .6523 .68903 L p .707 .577 .707 r
F P
0 g
s
.59856 .80838 m .59709 .7712 L .56595 .77055 L p .707 .577 .707 r
F P
0 g
s
.59709 .7712 m .59856 .80838 L .63037 .80647 L p .707 .577 .707 r
F P
0 g
s
.63037 .80647 m .62891 .76929 L .59709 .7712 L p .707 .577 .707 r
F P
0 g
s
.62891 .76929 m .63037 .80647 L .65974 .8022 L p .707 .577 .707 r
F P
0 g
s
.65974 .8022 m .65827 .76501 L .62891 .76929 L p .707 .577 .707 r
F P
0 g
s
.53246 .68772 m .53286 .74334 L .56032 .74751 L p .707 .577 .707 r
F P
0 g
s
.53286 .74334 m .53246 .68772 L .5114 .68147 L p .707 .577 .707 r
F P
0 g
s
.56741 .80773 m .56595 .77055 L .53851 .76741 L p .707 .577 .707 r
F P
0 g
s
.56595 .77055 m .56741 .80773 L .59856 .80838 L p .707 .577 .707 r
F P
0 g
s
.65827 .76501 m .65974 .8022 L .68378 .79597 L p .707 .577 .707 r
F P
0 g
s
.68378 .79597 m .68231 .75879 L .65827 .76501 L p .707 .577 .707 r
F P
0 g
s
.67635 .68327 m .67676 .7389 L .69313 .73149 L p .707 .577 .707 r
F P
0 g
s
.69313 .73149 m .69272 .67587 L .67635 .68327 L p .707 .577 .707 r
F P
0 g
s
.53851 .76741 m .53998 .80459 L .56741 .80773 L p .707 .577 .707 r
F P
0 g
s
.59649 .85969 m .60157 .84248 L .57161 .83205 L p .707 .577 .707 r
F P
0 g
s
.60157 .84248 m .59649 .85969 L .62724 .86661 L p .707 .577 .707 r
F P
0 g
s
.62724 .86661 m .63232 .84939 L .60157 .84248 L p .707 .577 .707 r
F P
0 g
s
.5114 .68147 m .51181 .7371 L .53286 .74334 L p .707 .577 .707 r
F P
0 g
s
.56653 .84927 m .57161 .83205 L .54537 .81914 L p .707 .577 .707 r
F P
0 g
s
.57161 .83205 m .56653 .84927 L .59649 .85969 L p .707 .577 .707 r
F P
0 g
s
.53998 .80459 m .53851 .76741 L .51748 .76209 L p .707 .577 .707 r
F P
0 g
s
.63232 .84939 m .62724 .86661 L .65575 .86933 L p .707 .577 .707 r
F P
0 g
s
.65575 .86933 m .66083 .85211 L .63232 .84939 L p .707 .577 .707 r
F P
0 g
s
.51181 .7371 m .5114 .68147 L .49881 .67375 L p .707 .577 .707 r
F P
0 g
s
.54537 .81914 m .54029 .83636 L .56653 .84927 L p .707 .577 .707 r
F P
0 g
s
.51748 .76209 m .51895 .79927 L .53998 .80459 L p .707 .577 .707 r
F P
0 g
s
.68231 .75879 m .68378 .79597 L .70015 .7884 L p .707 .577 .707 r
F P
0 g
s
.70015 .7884 m .69868 .75122 L .68231 .75879 L p .707 .577 .707 r
F P
0 g
s
.54029 .83636 m .54537 .81914 L .5254 .805 L p .707 .577 .707 r
F P
0 g
s
.66083 .85211 m .65575 .86933 L .67925 .8676 L p .707 .577 .707 r
F P
0 g
s
.67925 .8676 m .68433 .85038 L .66083 .85211 L p .707 .577 .707 r
F P
0 g
s
.5254 .805 m .52032 .82221 L .54029 .83636 L p .707 .577 .707 r
F P
0 g
s
.49881 .67375 m .49921 .72938 L .51181 .7371 L p .707 .577 .707 r
F P
0 g
s
.69272 .67587 m .69313 .73149 L .70021 .72316 L p .707 .577 .707 r
F P
0 g
s
.70021 .72316 m .69981 .66754 L .69272 .67587 L p .707 .577 .707 r
F P
0 g
s
.51895 .79927 m .51748 .76209 L .50491 .7551 L p .707 .577 .707 r
F P
0 g
s
.49921 .72938 m .49881 .67375 L .49591 .66531 L p .707 .577 .707 r
F P
0 g
s
.50491 .7551 m .50637 .79228 L .51895 .79927 L p .707 .577 .707 r
F P
0 g
s
.52032 .82221 m .5254 .805 L .51368 .79101 L p .707 .577 .707 r
F P
0 g
s
.68433 .85038 m .67925 .8676 L .69542 .86158 L p .707 .577 .707 r
F P
0 g
s
.69542 .86158 m .7005 .84436 L .68433 .85038 L p .707 .577 .707 r
F P
0 g
s
.69868 .75122 m .70015 .7884 L .70723 .78024 L p .707 .577 .707 r
F P
0 g
s
.70723 .78024 m .70577 .74306 L .69868 .75122 L p .707 .577 .707 r
F P
0 g
s
.51368 .79101 m .5086 .80823 L .52032 .82221 L p .707 .577 .707 r
F P
0 g
s
.49591 .66531 m .49632 .72094 L .49921 .72938 L p .707 .577 .707 r
F P
0 g
s
.69981 .66754 m .70021 .72316 L .69731 .71473 L p .707 .577 .707 r
F P
0 g
s
.69731 .71473 m .69691 .6591 L .69981 .66754 L p .707 .577 .707 r
F P
0 g
s
.50637 .79228 m .50491 .7551 L .50202 .74713 L p .707 .577 .707 r
F P
0 g
s
.48698 .82191 m .49208 .32059 L .44807 .31746 L p .707 .577 .707 r
F P
0 g
s
.5086 .80823 m .51368 .79101 L .51134 .77855 L p .707 .577 .707 r
F P
0 g
s
.50202 .74713 m .50349 .78431 L .50637 .79228 L p .707 .577 .707 r
F P
0 g
s
.49632 .72094 m .49591 .66531 L .503 .65699 L p .707 .577 .707 r
F P
0 g
s
.51134 .77855 m .50626 .79577 L .5086 .80823 L p .707 .577 .707 r
F P
0 g
s
.503 .65699 m .5034 .71261 L .49632 .72094 L p .707 .577 .707 r
F P
0 g
s
.50349 .78431 m .50202 .74713 L .50911 .73897 L p .707 .577 .707 r
F P
0 g
s
.50626 .79577 m .51134 .77855 L .51861 .76884 L p .707 .577 .707 r
F P
0 g
s
.50911 .73897 m .51058 .77615 L .50349 .78431 L p .707 .577 .707 r
F P
0 g
s
.5034 .71261 m .503 .65699 L .51937 .64958 L p .707 .577 .707 r
F P
0 g
s
.51861 .76884 m .51353 .78605 L .50626 .79577 L p .707 .577 .707 r
F P
0 g
s
.51937 .64958 m .51977 .70521 L .5034 .71261 L p .707 .577 .707 r
F P
0 g
s
.51058 .77615 m .50911 .73897 L .52547 .7314 L p .707 .577 .707 r
F P
0 g
s
.51353 .78605 m .51861 .76884 L .53479 .76282 L p .707 .577 .707 r
F P
0 g
s
.51977 .70521 m .51937 .64958 L .54342 .64383 L p .707 .577 .707 r
F P
0 g
s
.52547 .7314 m .52694 .76858 L .51058 .77615 L p .707 .577 .707 r
F P
0 g
s
.53479 .76282 m .52971 .78004 L .51353 .78605 L p .707 .577 .707 r
F P
0 g
s
.54342 .64383 m .54382 .69945 L .51977 .70521 L p .707 .577 .707 r
F P
0 g
s
.52694 .76858 m .52547 .7314 L .54951 .72517 L p .707 .577 .707 r
F P
0 g
s
.52971 .78004 m .53479 .76282 L .55829 .76109 L p .707 .577 .707 r
F P
0 g
s
.54951 .72517 m .55098 .76236 L .52694 .76858 L p .707 .577 .707 r
F P
0 g
s
.49208 .32059 m .48698 .82191 L .53192 .82122 L p .707 .577 .707 r
F P
0 g
s
.55829 .76109 m .55321 .7783 L .52971 .78004 L p .707 .577 .707 r
F P
0 g
s
.53192 .82122 m .53702 .3199 L .49208 .32059 L p .707 .577 .707 r
F P
0 g
s
.54382 .69945 m .54342 .64383 L .5728 .64028 L p .707 .577 .707 r
F P
0 g
s
.5728 .64028 m .5732 .69591 L .54382 .69945 L p .707 .577 .707 r
F P
0 g
s
.55098 .76236 m .54951 .72517 L .57888 .7209 L p .707 .577 .707 r
F P
0 g
s
.55321 .7783 m .55829 .76109 L .5868 .76381 L p .707 .577 .707 r
F P
0 g
s
.57888 .7209 m .58035 .75808 L .55098 .76236 L p .707 .577 .707 r
F P
0 g
s
.5868 .76381 m .58172 .78103 L .55321 .7783 L p .707 .577 .707 r
F P
0 g
s
.53702 .3199 m .53192 .82122 L .5734 .81677 L p .707 .577 .707 r
F P
0 g
s
.5732 .69591 m .5728 .64028 L .60463 .6393 L p .707 .577 .707 r
F P
0 g
s
.60463 .6393 m .60504 .69492 L .5732 .69591 L p .707 .577 .707 r
F P
0 g
s
.5734 .81677 m .5785 .31546 L .53702 .3199 L p .707 .577 .707 r
F P
0 g
s
.7005 .84436 m .69542 .86158 L .7027 .85186 L p .707 .577 .707 r
F P
0 g
s
.7027 .85186 m .70778 .83465 L .7005 .84436 L p .707 .577 .707 r
F P
0 g
s
.44297 .81877 m .44807 .31746 L .40931 .3108 L p .707 .577 .707 r
F P
0 g
s
.44807 .31746 m .44297 .81877 L .48698 .82191 L p .707 .577 .707 r
F P
0 g
s
.70577 .74306 m .70723 .78024 L .70435 .77227 L p .707 .577 .707 r
F P
0 g
s
.70435 .77227 m .70288 .73509 L .70577 .74306 L p .707 .577 .707 r
F P
0 g
s
.58035 .75808 m .57888 .7209 L .61069 .71899 L p .707 .577 .707 r
F P
0 g
s
.61069 .71899 m .61216 .75617 L .58035 .75808 L p .707 .577 .707 r
F P
0 g
s
.58172 .78103 m .5868 .76381 L .61754 .77072 L p .707 .577 .707 r
F P
0 g
s
.61754 .77072 m .61246 .78794 L .58172 .78103 L p .707 .577 .707 r
F P
0 g
s
.5785 .31546 m .5734 .81677 L .60735 .809 L p .707 .577 .707 r
F P
0 g
s
.63581 .64097 m .63621 .6966 L .60504 .69492 L p .707 .577 .707 r
F P
0 g
s
.60504 .69492 m .60463 .6393 L .63581 .64097 L p .707 .577 .707 r
F P
0 g
s
.60735 .809 m .61245 .30769 L .5785 .31546 L p .707 .577 .707 r
F P
0 g
s
.69691 .6591 m .69731 .71473 L .68472 .70701 L p .707 .577 .707 r
F P
0 g
s
.68472 .70701 m .68432 .65138 L .69691 .6591 L p .707 .577 .707 r
F P
0 g
s
.40421 .81212 m .40931 .3108 L .37959 .30128 L p .707 .577 .707 r
F P
0 g
s
.40931 .3108 m .40421 .81212 L .44297 .81877 L p .707 .577 .707 r
F P
0 g
s
.24848 .71154 m .24808 .65592 L .2169 .65425 L p .707 .577 .707 r
F P
0 g
s
.24808 .65592 m .24848 .71154 L .28031 .71056 L p .707 .577 .707 r
F P
0 g
s
.28031 .71056 m .27991 .65494 L .24808 .65592 L p .707 .577 .707 r
F P
0 g
s
.27991 .65494 m .28031 .71056 L .3097 .70702 L p .707 .577 .707 r
F P
0 g
s
.3097 .70702 m .30929 .65139 L .27991 .65494 L p .707 .577 .707 r
F P
0 g
s
.70778 .83465 m .7027 .85186 L .70036 .8394 L p .707 .577 .707 r
F P
0 g
s
.70036 .8394 m .70544 .82219 L .70778 .83465 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21731 .70987 m .2169 .65425 L .18945 .65008 L p .707 .577 .707 r
F P
0 g
s
.2169 .65425 m .21731 .70987 L .24848 .71154 L p .707 .577 .707 r
F P
0 g
s
.70288 .73509 m .70435 .77227 L .69177 .76528 L p .707 .577 .707 r
F P
0 g
s
.69177 .76528 m .69031 .7281 L .70288 .73509 L p .707 .577 .707 r
F P
0 g
s
.30929 .65139 m .3097 .70702 L .33375 .70126 L p .707 .577 .707 r
F P
0 g
s
.33375 .70126 m .33335 .64564 L .30929 .65139 L p .707 .577 .707 r
F P
0 g
s
.64184 .71964 m .64331 .75682 L .61216 .75617 L p .707 .577 .707 r
F P
0 g
s
.61216 .75617 m .61069 .71899 L .64184 .71964 L p .707 .577 .707 r
F P
0 g
s
.64751 .78114 m .64243 .79836 L .61246 .78794 L p .707 .577 .707 r
F P
0 g
s
.61246 .78794 m .61754 .77072 L .64751 .78114 L p .707 .577 .707 r
F P
0 g
s
.61245 .30769 m .60735 .809 L .63046 .79867 L p .707 .577 .707 r
F P
0 g
s
.63046 .79867 m .63556 .29736 L .61245 .30769 L p .707 .577 .707 r
F P
0 g
s
.68432 .65138 m .68472 .70701 L .66367 .70076 L p .707 .577 .707 r
F P
0 g
s
.66367 .70076 m .66326 .64514 L .68432 .65138 L p .707 .577 .707 r
F P
0 g
s
.25555 .77251 m .25409 .73533 L .22294 .73468 L p .707 .577 .707 r
F P
0 g
s
.25409 .73533 m .25555 .77251 L .28737 .77061 L p .707 .577 .707 r
F P
0 g
s
.28737 .77061 m .2859 .73343 L .25409 .73533 L p .707 .577 .707 r
F P
0 g
s
.2859 .73343 m .28737 .77061 L .31673 .76633 L p .707 .577 .707 r
F P
0 g
s
.31673 .76633 m .31526 .72915 L .2859 .73343 L p .707 .577 .707 r
F P
0 g
s
.18945 .65008 m .18985 .70571 L .21731 .70987 L p .707 .577 .707 r
F P
0 g
s
.18985 .70571 m .18945 .65008 L .16839 .64384 L p .707 .577 .707 r
F P
0 g
s
.22441 .77187 m .22294 .73468 L .1955 .73155 L p .707 .577 .707 r
F P
0 g
s
.22294 .73468 m .22441 .77187 L .25555 .77251 L p .707 .577 .707 r
F P
0 g
s
.37449 .8026 m .37959 .30128 L .36181 .28983 L p .707 .577 .707 r
F P
0 g
s
.37959 .30128 m .37449 .8026 L .40421 .81212 L p .707 .577 .707 r
F P
0 g
s
.70544 .82219 m .70036 .8394 L .68864 .82542 L p .707 .577 .707 r
F P
0 g
s
.68864 .82542 m .69372 .8082 L .70544 .82219 L p .707 .577 .707 r
F P
0 g
s
.31526 .72915 m .31673 .76633 L .34077 .76011 L p .707 .577 .707 r
F P
0 g
s
.34077 .76011 m .3393 .72292 L .31526 .72915 L p .707 .577 .707 r
F P
0 g
s
.33335 .64564 m .33375 .70126 L .35012 .69386 L p .707 .577 .707 r
F P
0 g
s
.35012 .69386 m .34971 .63823 L .33335 .64564 L p .707 .577 .707 r
F P
0 g
s
.1955 .73155 m .19697 .76873 L .22441 .77187 L p .707 .577 .707 r
F P
0 g
s
.25348 .82349 m .25856 .80628 L .2286 .79585 L p .707 .577 .707 r
F P
0 g
s
.25856 .80628 m .25348 .82349 L .28423 .83041 L p .707 .577 .707 r
F P
0 g
s
.28423 .83041 m .28931 .81319 L .25856 .80628 L p .707 .577 .707 r
F P
0 g
s
.69031 .7281 m .69177 .76528 L .67074 .75996 L p .707 .577 .707 r
F P
0 g
s
.67074 .75996 m .66927 .72278 L .69031 .7281 L p .707 .577 .707 r
F P
0 g
s
.16839 .64384 m .1688 .69946 L .18985 .70571 L p .707 .577 .707 r
F P
0 g
s
.22352 .81307 m .2286 .79585 L .20236 .78294 L p .707 .577 .707 r
F P
0 g
s
.2286 .79585 m .22352 .81307 L .25348 .82349 L p .707 .577 .707 r
F P
0 g
s
.66326 .64514 m .66367 .70076 L .63621 .6966 L p .707 .577 .707 r
F P
0 g
s
.63621 .6966 m .63581 .64097 L .66326 .64514 L p .707 .577 .707 r
F P
0 g
s
.19697 .76873 m .1955 .73155 L .17447 .72622 L p .707 .577 .707 r
F P
0 g
s
.28931 .81319 m .28423 .83041 L .31274 .83313 L p .707 .577 .707 r
F P
0 g
s
.31274 .83313 m .31782 .81591 L .28931 .81319 L p .707 .577 .707 r
F P
0 g
s
.1688 .69946 m .16839 .64384 L .1558 .63612 L p .707 .577 .707 r
F P
0 g
s
.20236 .78294 m .19728 .80016 L .22352 .81307 L p .707 .577 .707 r
F P
0 g
s
.17447 .72622 m .17594 .7634 L .19697 .76873 L p .707 .577 .707 r
F P
0 g
s
.3393 .72292 m .34077 .76011 L .35714 .75254 L p .707 .577 .707 r
F P
0 g
s
.35714 .75254 m .35567 .71536 L .3393 .72292 L p .707 .577 .707 r
F P
0 g
s
.19728 .80016 m .20236 .78294 L .18239 .7688 L p .707 .577 .707 r
F P
0 g
s
.63556 .29736 m .63046 .79867 L .64046 .78679 L p .707 .577 .707 r
F P
0 g
s
.64046 .78679 m .64556 .28548 L .63556 .29736 L p .707 .577 .707 r
F P
0 g
s
.31782 .81591 m .31274 .83313 L .33624 .8314 L p .707 .577 .707 r
F P
0 g
s
.33624 .8314 m .34132 .81418 L .31782 .81591 L p .707 .577 .707 r
F P
0 g
s
.69372 .8082 m .68864 .82542 L .66867 .81128 L p .707 .577 .707 r
F P
0 g
s
.66867 .81128 m .67375 .79406 L .69372 .8082 L p .707 .577 .707 r
F P
0 g
s
.66927 .72278 m .67074 .75996 L .64331 .75682 L p .707 .577 .707 r
F P
0 g
s
.64331 .75682 m .64184 .71964 L .66927 .72278 L p .707 .577 .707 r
F P
0 g
s
.18239 .7688 m .17731 .78601 L .19728 .80016 L p .707 .577 .707 r
F P
0 g
s
.1558 .63612 m .1562 .69174 L .1688 .69946 L p .707 .577 .707 r
F P
0 g
s
.34971 .63823 m .35012 .69386 L .3572 .68553 L p .707 .577 .707 r
F P
0 g
s
.3572 .68553 m .3568 .62991 L .34971 .63823 L p .707 .577 .707 r
F P
0 g
s
.17594 .7634 m .17447 .72622 L .1619 .71923 L p .707 .577 .707 r
F P
0 g
s
.35567 .71536 m .35714 .75254 L .36422 .74437 L p .707 .577 .707 r
F P
0 g
s
.36422 .74437 m .36276 .70719 L .35567 .71536 L p .707 .577 .707 r
F P
0 g
s
.3568 .62991 m .3572 .68553 L .3543 .67709 L p .707 .577 .707 r
F P
0 g
s
.35987 .69923 m .36134 .73641 L .34876 .72942 L p .707 .577 .707 r
F P
0 g
s
.34876 .72942 m .3473 .69224 L .35987 .69923 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .34563 .78922 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36243 .78599 m .36089 .79122 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36089 .79122 m .35735 .8032 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35772 .27756 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .35071 .772 L .36059 .78379 L p .707 .577 .707 r
F P
0 g
s
.36059 .78379 m .36243 .78599 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .36059 .78379 L .36069 .78632 L .707 .577 .707 r
F
.35262 .77887 m .35671 .79114 L p .35691 .69138 L F P
0 g
s
.3543 .67709 m .3539 .62147 L .3568 .62991 L p .707 .577 .707 r
F P
0 g
s
.35772 .27756 m .3542 .62354 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.3539 .62147 m .3543 .67709 L .34171 .66937 L p .707 .577 .707 r
F P
0 g
s
.3542 .62354 m .35262 .77887 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35671 .79114 m .35756 .70773 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35756 .70773 m .36181 .28983 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.36276 .70719 m .36422 .74437 L .36134 .73641 L p .707 .577 .707 r
F P
0 g
s
.36134 .73641 m .35987 .69923 L .36276 .70719 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .36243 .78599 L .36477 .79845 L p .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35671 .79114 L .37449 .8026 L p .707 .577 .707 r
F P
0 g
s
.1562 .69174 m .1558 .63612 L .1529 .62768 L p .707 .577 .707 r
F P
0 g
s
.1619 .71923 m .16336 .75642 L .17594 .7634 L p .707 .577 .707 r
F P
0 g
s
.17731 .78601 m .18239 .7688 L .17067 .75481 L p .707 .577 .707 r
F P
0 g
s
.34132 .81418 m .33624 .8314 L .35242 .82538 L p .707 .577 .707 r
F P
0 g
s
.35242 .82538 m .3575 .80816 L .34132 .81418 L p .707 .577 .707 r
F P
0 g
s
.67375 .79406 m .66867 .81128 L .64243 .79836 L p .707 .577 .707 r
F P
0 g
s
.64243 .79836 m .64751 .78114 L .67375 .79406 L p .707 .577 .707 r
F P
0 g
s
.17067 .75481 m .16559 .77203 L .17731 .78601 L p .707 .577 .707 r
F P
0 g
s
.1529 .62768 m .15331 .6833 L .1562 .69174 L p .707 .577 .707 r
F P
0 g
s
.16336 .75642 m .1619 .71923 L .15901 .71127 L p .707 .577 .707 r
F P
0 g
s
.64556 .28548 m .64046 .78679 L .63638 .77452 L p .707 .577 .707 r
F P
0 g
s
.63638 .77452 m .64147 .27321 L .64556 .28548 L p .707 .577 .707 r
F P
0 g
s
.16559 .77203 m .17067 .75481 L .16833 .74235 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15901 .71127 m .16048 .74845 L .16336 .75642 L p .707 .577 .707 r
F P
0 g
s
.15331 .6833 m .1529 .62768 L .15999 .61935 L p .707 .577 .707 r
F P
0 g
s
.3575 .80816 m .35242 .82538 L .35969 .81566 L p .707 .577 .707 r
F P
0 g
s
.35969 .81566 m .36477 .79845 L .3575 .80816 L p .707 .577 .707 r
F P
0 g
s
.16833 .74235 m .16325 .75957 L .16559 .77203 L p .707 .577 .707 r
F P
0 g
s
.35262 .77887 m .35772 .27756 L .36772 .26568 L p .707 .577 .707 r
F P
0 g
s
.15999 .61935 m .16039 .67498 L .15331 .6833 L p .707 .577 .707 r
F P
0 g
s
.34171 .66937 m .34131 .61375 L .3539 .62147 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16048 .74845 m .15901 .71127 L .1661 .7031 L p .707 .577 .707 r
F P
0 g
s
.16325 .75957 m .16833 .74235 L .1756 .73264 L p .707 .577 .707 r
F P
0 g
s
.16039 .67498 m .15999 .61935 L .17636 .61195 L p .707 .577 .707 r
F P
0 g
s
.36477 .79845 m .35969 .81566 L .35735 .8032 L p .707 .577 .707 r
F P
0 g
s
.1661 .7031 m .16757 .74028 L .16048 .74845 L p .707 .577 .707 r
F P
0 g
s
.1756 .73264 m .17052 .74985 L .16325 .75957 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64147 .27321 m .63638 .77452 L .6186 .76307 L p .707 .577 .707 r
F P
0 g
s
.6186 .76307 m .6237 .26176 L .64147 .27321 L p .707 .577 .707 r
F P
0 g
s
.17636 .61195 m .17676 .66757 L .16039 .67498 L p .707 .577 .707 r
F P
0 g
s
.34131 .61375 m .34171 .66937 L .32066 .66312 L p .707 .577 .707 r
F P
0 g
s
.32066 .66312 m .32025 .6075 L .34131 .61375 L p .707 .577 .707 r
F P
0 g
s
.16757 .74028 m .1661 .7031 L .18246 .69554 L p .707 .577 .707 r
F P
0 g
s
.36262 .76699 m .36772 .26568 L .39083 .25535 L p .707 .577 .707 r
F P
0 g
s
.36772 .26568 m .36262 .76699 L .35262 .77887 L p .707 .577 .707 r
F P
0 g
s
.17052 .74985 m .1756 .73264 L .19178 .72662 L p .707 .577 .707 r
F P
0 g
s
.17676 .66757 m .17636 .61195 L .20041 .60619 L p .707 .577 .707 r
F P
0 g
s
.18246 .69554 m .18393 .73272 L .16757 .74028 L p .707 .577 .707 r
F P
0 g
s
.19178 .72662 m .1867 .74384 L .17052 .74985 L p .707 .577 .707 r
F P
0 g
s
.3473 .69224 m .34876 .72942 L .32773 .7241 L p .707 .577 .707 r
F P
0 g
s
.32773 .7241 m .32626 .68691 L .3473 .69224 L p .707 .577 .707 r
F P
0 g
s
.32025 .6075 m .32066 .66312 L .2932 .65896 L p .707 .577 .707 r
F P
0 g
s
.2932 .65896 m .2928 .60334 L .32025 .6075 L p .707 .577 .707 r
F P
0 g
s
.20041 .60619 m .20081 .66182 L .17676 .66757 L p .707 .577 .707 r
F P
0 g
s
.6237 .26176 m .6186 .76307 L .58888 .75355 L p .707 .577 .707 r
F P
0 g
s
.58888 .75355 m .59398 .25224 L .6237 .26176 L p .707 .577 .707 r
F P
0 g
s
.20081 .66182 m .20041 .60619 L .22979 .60265 L p .707 .577 .707 r
F P
0 g
s
.18393 .73272 m .18246 .69554 L .2065 .68931 L p .707 .577 .707 r
F P
0 g
s
.1867 .74384 m .19178 .72662 L .21528 .72489 L p .707 .577 .707 r
F P
0 g
s
.2928 .60334 m .2932 .65896 L .26203 .65729 L p .707 .577 .707 r
F P
0 g
s
.26203 .65729 m .26163 .60167 L .2928 .60334 L p .707 .577 .707 r
F P
0 g
s
.35071 .772 m .34563 .78922 L .32566 .77508 L p .707 .577 .707 r
F P
0 g
s
.32566 .77508 m .33074 .75786 L .35071 .772 L p .707 .577 .707 r
F P
0 g
s
.2065 .68931 m .20797 .72649 L .18393 .73272 L p .707 .577 .707 r
F P
0 g
s
.32626 .68691 m .32773 .7241 L .3003 .72096 L p .707 .577 .707 r
F P
0 g
s
.3003 .72096 m .29883 .68378 L .32626 .68691 L p .707 .577 .707 r
F P
0 g
s
.23019 .65827 m .22979 .60265 L .26163 .60167 L p .707 .577 .707 r
F P
0 g
s
.22979 .60265 m .23019 .65827 L .20081 .66182 L p .707 .577 .707 r
F P
0 g
s
.21528 .72489 m .2102 .7421 L .1867 .74384 L p .707 .577 .707 r
F P
0 g
s
.39083 .25535 m .38573 .75666 L .36262 .76699 L p .707 .577 .707 r
F P
0 g
s
.38573 .75666 m .39083 .25535 L .42479 .24758 L p .707 .577 .707 r
F P
0 g
s
.26163 .60167 m .26203 .65729 L .23019 .65827 L p .707 .577 .707 r
F P
0 g
s
.72869 .65714 m .72829 .60152 L .69712 .59984 L p .707 .577 .707 r
F P
0 g
s
.72829 .60152 m .72869 .65714 L .76053 .65616 L p .707 .577 .707 r
F P
0 g
s
.76053 .65616 m .76012 .60053 L .72829 .60152 L p .707 .577 .707 r
F P
0 g
s
.76012 .60053 m .76053 .65616 L .78991 .65261 L p .707 .577 .707 r
F P
0 g
s
.78991 .65261 m .78951 .59699 L .76012 .60053 L p .707 .577 .707 r
F P
0 g
s
.20797 .72649 m .2065 .68931 L .23587 .68503 L p .707 .577 .707 r
F P
0 g
s
.69752 .65547 m .69712 .59984 L .66966 .59568 L p .707 .577 .707 r
F P
0 g
s
.69712 .59984 m .69752 .65547 L .72869 .65714 L p .707 .577 .707 r
F P
0 g
s
.2102 .7421 m .21528 .72489 L .24379 .72761 L p .707 .577 .707 r
F P
0 g
s
.29883 .68378 m .3003 .72096 L .26915 .72031 L p .707 .577 .707 r
F P
0 g
s
.26915 .72031 m .26768 .68313 L .29883 .68378 L p .707 .577 .707 r
F P
0 g
s
.33074 .75786 m .32566 .77508 L .29942 .76216 L p .707 .577 .707 r
F P
0 g
s
.29942 .76216 m .3045 .74494 L .33074 .75786 L p .707 .577 .707 r
F P
0 g
s
.23587 .68503 m .23734 .72222 L .20797 .72649 L p .707 .577 .707 r
F P
0 g
s
.59398 .25224 m .58888 .75355 L .55011 .7469 L p .707 .577 .707 r
F P
0 g
s
.55011 .7469 m .55521 .24558 L .59398 .25224 L p .707 .577 .707 r
F P
0 g
s
.78951 .59699 m .78991 .65261 L .81396 .64686 L p .707 .577 .707 r
F P
0 g
s
.81396 .64686 m .81356 .59123 L .78951 .59699 L p .707 .577 .707 r
F P
0 g
s
.23734 .72222 m .23587 .68503 L .26768 .68313 L p .707 .577 .707 r
F P
0 g
s
.24379 .72761 m .23871 .74483 L .2102 .7421 L p .707 .577 .707 r
F P
0 g
s
.26768 .68313 m .26915 .72031 L .23734 .72222 L p .707 .577 .707 r
F P
0 g
s
.73577 .71634 m .7343 .67916 L .70315 .67851 L p .707 .577 .707 r
F P
0 g
s
.7343 .67916 m .73577 .71634 L .76758 .71443 L p .707 .577 .707 r
F P
0 g
s
.76758 .71443 m .76611 .67725 L .7343 .67916 L p .707 .577 .707 r
F P
0 g
s
.76611 .67725 m .76758 .71443 L .79694 .71016 L p .707 .577 .707 r
F P
0 g
s
.79694 .71016 m .79548 .67298 L .76611 .67725 L p .707 .577 .707 r
F P
0 g
s
.66966 .59568 m .67006 .6513 L .69752 .65547 L p .707 .577 .707 r
F P
0 g
s
.67006 .6513 m .66966 .59568 L .64861 .58943 L p .707 .577 .707 r
F P
0 g
s
.23871 .74483 m .24379 .72761 L .27453 .73452 L p .707 .577 .707 r
F P
0 g
s
.41969 .7489 m .42479 .24758 L .46627 .24314 L p .707 .577 .707 r
F P
0 g
s
.42479 .24758 m .41969 .7489 L .38573 .75666 L p .707 .577 .707 r
F P
0 g
s
.3045 .74494 m .29942 .76216 L .26945 .75174 L p .707 .577 .707 r
F P
0 g
s
.26945 .75174 m .27453 .73452 L .3045 .74494 L p .707 .577 .707 r
F P
0 g
s
.70462 .71569 m .70315 .67851 L .67572 .67537 L p .707 .577 .707 r
F P
0 g
s
.70315 .67851 m .70462 .71569 L .73577 .71634 L p .707 .577 .707 r
F P
0 g
s
.27453 .73452 m .26945 .75174 L .23871 .74483 L p .707 .577 .707 r
F P
0 g
s
.79548 .67298 m .79694 .71016 L .82099 .70393 L p .707 .577 .707 r
F P
0 g
s
.82099 .70393 m .81952 .66675 L .79548 .67298 L p .707 .577 .707 r
F P
0 g
s
.81356 .59123 m .81396 .64686 L .83033 .63945 L p .707 .577 .707 r
F P
0 g
s
.83033 .63945 m .82993 .58383 L .81356 .59123 L p .707 .577 .707 r
F P
0 g
s
.67572 .67537 m .67719 .71255 L .70462 .71569 L p .707 .577 .707 r
F P
0 g
s
.55521 .24558 m .55011 .7469 L .50611 .74376 L p .707 .577 .707 r
F P
0 g
s
.50611 .74376 m .51121 .24245 L .55521 .24558 L p .707 .577 .707 r
F P
0 g
s
.7337 .76766 m .73878 .75044 L .70882 .74002 L p .707 .577 .707 r
F P
0 g
s
.73878 .75044 m .7337 .76766 L .76444 .77457 L p .707 .577 .707 r
F P
0 g
s
.76444 .77457 m .76952 .75735 L .73878 .75044 L p .707 .577 .707 r
F P
0 g
s
.64861 .58943 m .64901 .64506 L .67006 .6513 L p .707 .577 .707 r
F P
0 g
s
.70374 .75723 m .70882 .74002 L .68257 .7271 L p .707 .577 .707 r
F P
0 g
s
.70882 .74002 m .70374 .75723 L .7337 .76766 L p .707 .577 .707 r
F P
0 g
s
.46117 .74445 m .46627 .24314 L .51121 .24245 L p .707 .577 .707 r
F P
0 g
s
.46627 .24314 m .46117 .74445 L .41969 .7489 L p .707 .577 .707 r
F P
0 g
s
.67719 .71255 m .67572 .67537 L .65468 .67005 L p .707 .577 .707 r
F P
0 g
s
.76952 .75735 m .76444 .77457 L .79296 .77729 L p .707 .577 .707 r
F P
0 g
s
.79296 .77729 m .79804 .76007 L .76952 .75735 L p .707 .577 .707 r
F P
0 g
s
.51121 .24245 m .50611 .74376 L .46117 .74445 L p .707 .577 .707 r
F P
0 g
s
.64901 .64506 m .64861 .58943 L .63601 .58171 L p .707 .577 .707 r
F P
0 g
s
.68257 .7271 m .67749 .74432 L .70374 .75723 L p .707 .577 .707 r
F P
0 g
s
.65468 .67005 m .65615 .70723 L .67719 .71255 L p .707 .577 .707 r
F P
0 g
s
.81952 .66675 m .82099 .70393 L .83735 .69637 L p .707 .577 .707 r
F P
0 g
s
.83735 .69637 m .83588 .65918 L .81952 .66675 L p .707 .577 .707 r
F P
0 g
s
.67749 .74432 m .68257 .7271 L .66261 .71296 L p .707 .577 .707 r
F P
0 g
s
.79804 .76007 m .79296 .77729 L .81645 .77556 L p .707 .577 .707 r
F P
0 g
s
.81645 .77556 m .82153 .75834 L .79804 .76007 L p .707 .577 .707 r
F P
0 g
s
.66261 .71296 m .65753 .73018 L .67749 .74432 L p .707 .577 .707 r
F P
0 g
s
.63601 .58171 m .63642 .63734 L .64901 .64506 L p .707 .577 .707 r
F P
0 g
s
.82993 .58383 m .83033 .63945 L .83741 .63113 L p .707 .577 .707 r
F P
0 g
s
.83741 .63113 m .83701 .5755 L .82993 .58383 L p .707 .577 .707 r
F P
0 g
s
.65615 .70723 m .65468 .67005 L .64211 .66306 L p .707 .577 .707 r
F P
0 g
s
.63642 .63734 m .63601 .58171 L .63312 .57328 L p .707 .577 .707 r
F P
0 g
s
.64211 .66306 m .64358 .70024 L .65615 .70723 L p .707 .577 .707 r
F P
0 g
s
.65753 .73018 m .66261 .71296 L .65088 .69897 L p .707 .577 .707 r
F P
0 g
s
.82153 .75834 m .81645 .77556 L .83263 .76954 L p .707 .577 .707 r
F P
0 g
s
.83263 .76954 m .83771 .75232 L .82153 .75834 L p .707 .577 .707 r
F P
0 g
s
.83588 .65918 m .83735 .69637 L .84444 .6882 L p .707 .577 .707 r
F P
0 g
s
.84444 .6882 m .84297 .65102 L .83588 .65918 L p .707 .577 .707 r
F P
0 g
s
.65088 .69897 m .6458 .71619 L .65753 .73018 L p .707 .577 .707 r
F P
0 g
s
.63312 .57328 m .63352 .6289 L .63642 .63734 L p .707 .577 .707 r
F P
0 g
s
.83701 .5755 m .83741 .63113 L .83452 .62269 L p .707 .577 .707 r
F P
0 g
s
.83452 .62269 m .83412 .56706 L .83701 .5755 L p .707 .577 .707 r
F P
0 g
s
.64358 .70024 m .64211 .66306 L .63922 .65509 L p .707 .577 .707 r
F P
0 g
s
.6458 .71619 m .65088 .69897 L .64854 .68651 L p .707 .577 .707 r
F P
0 g
s
.63922 .65509 m .64069 .69227 L .64358 .70024 L p .707 .577 .707 r
F P
0 g
s
.63352 .6289 m .63312 .57328 L .6402 .56495 L p .707 .577 .707 r
F P
0 g
s
.83771 .75232 m .83263 .76954 L .8399 .75983 L p .707 .577 .707 r
F P
0 g
s
.8399 .75983 m .84498 .74261 L .83771 .75232 L p .707 .577 .707 r
F P
0 g
s
.64854 .68651 m .64346 .70373 L .6458 .71619 L p .707 .577 .707 r
F P
0 g
s
.84297 .65102 m .84444 .6882 L .84155 .68023 L p .707 .577 .707 r
F P
0 g
s
.84155 .68023 m .84009 .64305 L .84297 .65102 L p .707 .577 .707 r
F P
0 g
s
.6402 .56495 m .6406 .62057 L .63352 .6289 L p .707 .577 .707 r
F P
0 g
s
.83412 .56706 m .83452 .62269 L .82193 .61497 L p .707 .577 .707 r
F P
0 g
s
.82193 .61497 m .82152 .55934 L .83412 .56706 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64069 .69227 m .63922 .65509 L .64631 .64693 L p .707 .577 .707 r
F P
0 g
s
.64346 .70373 m .64854 .68651 L .65582 .6768 L p .707 .577 .707 r
F P
0 g
s
.38568 .6195 m .38528 .56388 L .35411 .56221 L p .707 .577 .707 r
F P
0 g
s
.38528 .56388 m .38568 .6195 L .41752 .61852 L p .707 .577 .707 r
F P
0 g
s
.41752 .61852 m .41711 .5629 L .38528 .56388 L p .707 .577 .707 r
F P
0 g
s
.41711 .5629 m .41752 .61852 L .4469 .61498 L p .707 .577 .707 r
F P
0 g
s
.4469 .61498 m .4465 .55935 L .41711 .5629 L p .707 .577 .707 r
F P
0 g
s
.84498 .74261 m .8399 .75983 L .83757 .74737 L p .707 .577 .707 r
F P
0 g
s
.83757 .74737 m .84265 .73015 L .84498 .74261 L p .707 .577 .707 r
F P
0 g
s
.64631 .64693 m .64778 .68411 L .64069 .69227 L p .707 .577 .707 r
F P
0 g
s
.6406 .62057 m .6402 .56495 L .65657 .55754 L p .707 .577 .707 r
F P
0 g
s
.65582 .6768 m .65074 .69402 L .64346 .70373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35451 .61783 m .35411 .56221 L .32665 .55805 L p .707 .577 .707 r
F P
0 g
s
.35411 .56221 m .35451 .61783 L .38568 .6195 L p .707 .577 .707 r
F P
0 g
s
.84009 .64305 m .84155 .68023 L .82898 .67325 L p .707 .577 .707 r
F P
0 g
s
.82898 .67325 m .82751 .63606 L .84009 .64305 L p .707 .577 .707 r
F P
0 g
s
.4465 .55935 m .4469 .61498 L .47095 .60922 L p .707 .577 .707 r
F P
0 g
s
.47095 .60922 m .47055 .5536 L .4465 .55935 L p .707 .577 .707 r
F P
0 g
s
.65657 .55754 m .65697 .61317 L .6406 .62057 L p .707 .577 .707 r
F P
0 g
s
.82152 .55934 m .82193 .61497 L .80087 .60872 L p .707 .577 .707 r
F P
0 g
s
.80087 .60872 m .80047 .5531 L .82152 .55934 L p .707 .577 .707 r
F P
0 g
s
.39276 .68048 m .39129 .64329 L .36014 .64265 L p .707 .577 .707 r
F P
0 g
s
.39129 .64329 m .39276 .68048 L .42457 .67857 L p .707 .577 .707 r
F P
0 g
s
.42457 .67857 m .4231 .64139 L .39129 .64329 L p .707 .577 .707 r
F P
0 g
s
.4231 .64139 m .42457 .67857 L .45393 .67429 L p .707 .577 .707 r
F P
0 g
s
.45393 .67429 m .45247 .63711 L .4231 .64139 L p .707 .577 .707 r
F P
0 g
s
.32665 .55805 m .32705 .61367 L .35451 .61783 L p .707 .577 .707 r
F P
0 g
s
.32705 .61367 m .32665 .55805 L .3056 .5518 L p .707 .577 .707 r
F P
0 g
s
.64778 .68411 m .64631 .64693 L .66268 .63936 L p .707 .577 .707 r
F P
0 g
s
.36161 .67983 m .36014 .64265 L .33271 .63951 L p .707 .577 .707 r
F P
0 g
s
.36014 .64265 m .36161 .67983 L .39276 .68048 L p .707 .577 .707 r
F P
0 g
s
.65074 .69402 m .65582 .6768 L .67199 .67078 L p .707 .577 .707 r
F P
0 g
s
.65697 .61317 m .65657 .55754 L .68062 .55179 L p .707 .577 .707 r
F P
0 g
s
.84265 .73015 m .83757 .74737 L .82584 .73338 L p .707 .577 .707 r
F P
0 g
s
.82584 .73338 m .83092 .71616 L .84265 .73015 L p .707 .577 .707 r
F P
0 g
s
.66268 .63936 m .66414 .67654 L .64778 .68411 L p .707 .577 .707 r
F P
0 g
s
.45247 .63711 m .45393 .67429 L .47798 .66807 L p .707 .577 .707 r
F P
0 g
s
.47798 .66807 m .47651 .63089 L .45247 .63711 L p .707 .577 .707 r
F P
0 g
s
.67199 .67078 m .66691 .688 L .65074 .69402 L p .707 .577 .707 r
F P
0 g
s
.47055 .5536 m .47095 .60922 L .48732 .60182 L p .707 .577 .707 r
F P
0 g
s
.48732 .60182 m .48692 .54619 L .47055 .5536 L p .707 .577 .707 r
F P
0 g
s
.33271 .63951 m .33418 .67669 L .36161 .67983 L p .707 .577 .707 r
F P
0 g
s
.39069 .73146 m .39577 .71424 L .36581 .70382 L p .707 .577 .707 r
F P
0 g
s
.39577 .71424 m .39069 .73146 L .42143 .73837 L p .707 .577 .707 r
F P
0 g
s
.42143 .73837 m .42651 .72115 L .39577 .71424 L p .707 .577 .707 r
F P
0 g
s
.82751 .63606 m .82898 .67325 L .80795 .66792 L p .707 .577 .707 r
F P
0 g
s
.80795 .66792 m .80648 .63074 L .82751 .63606 L p .707 .577 .707 r
F P
0 g
s
.3056 .5518 m .306 .60742 L .32705 .61367 L p .707 .577 .707 r
F P
0 g
s
.36073 .72103 m .36581 .70382 L .33956 .6909 L p .707 .577 .707 r
F P
0 g
s
.36581 .70382 m .36073 .72103 L .39069 .73146 L p .707 .577 .707 r
F P
0 g
s
.80047 .5531 m .80087 .60872 L .77341 .60456 L p .707 .577 .707 r
F P
0 g
s
.77341 .60456 m .77301 .54893 L .80047 .5531 L p .707 .577 .707 r
F P
0 g
s
.33418 .67669 m .33271 .63951 L .31167 .63418 L p .707 .577 .707 r
F P
0 g
s
.42651 .72115 m .42143 .73837 L .44995 .74109 L p .707 .577 .707 r
F P
0 g
s
.44995 .74109 m .45503 .72387 L .42651 .72115 L p .707 .577 .707 r
F P
0 g
s
.68062 .55179 m .68103 .60741 L .65697 .61317 L p .707 .577 .707 r
F P
0 g
s
.306 .60742 m .3056 .5518 L .293 .54408 L p .707 .577 .707 r
F P
0 g
s
.33956 .6909 m .33448 .70812 L .36073 .72103 L p .707 .577 .707 r
F P
0 g
s
.66414 .67654 m .66268 .63936 L .68672 .63314 L p .707 .577 .707 r
F P
0 g
s
.68103 .60741 m .68062 .55179 L .71 .54825 L p .707 .577 .707 r
F P
0 g
s
.31167 .63418 m .31314 .67136 L .33418 .67669 L p .707 .577 .707 r
F P
0 g
s
.47651 .63089 m .47798 .66807 L .49434 .6605 L p .707 .577 .707 r
F P
0 g
s
.49434 .6605 m .49287 .62332 L .47651 .63089 L p .707 .577 .707 r
F P
0 g
s
.33448 .70812 m .33956 .6909 L .3196 .67676 L p .707 .577 .707 r
F P
0 g
s
.66691 .688 m .67199 .67078 L .69549 .66905 L p .707 .577 .707 r
F P
0 g
s
.45503 .72387 m .44995 .74109 L .47344 .73936 L p .707 .577 .707 r
F P
0 g
s
.47344 .73936 m .47852 .72214 L .45503 .72387 L p .707 .577 .707 r
F P
0 g
s
.77301 .54893 m .77341 .60456 L .74224 .60289 L p .707 .577 .707 r
F P
0 g
s
.74224 .60289 m .74184 .54726 L .77301 .54893 L p .707 .577 .707 r
F P
0 g
s
.83092 .71616 m .82584 .73338 L .80588 .71924 L p .707 .577 .707 r
F P
0 g
s
.80588 .71924 m .81096 .70202 L .83092 .71616 L p .707 .577 .707 r
F P
0 g
s
.68672 .63314 m .68819 .67032 L .66414 .67654 L p .707 .577 .707 r
F P
0 g
s
.80648 .63074 m .80795 .66792 L .78051 .66478 L p .707 .577 .707 r
F P
0 g
s
.78051 .66478 m .77904 .6276 L .80648 .63074 L p .707 .577 .707 r
F P
0 g
s
.3196 .67676 m .31452 .69398 L .33448 .70812 L p .707 .577 .707 r
F P
0 g
s
.293 .54408 m .29341 .5997 L .306 .60742 L p .707 .577 .707 r
F P
0 g
s
.48692 .54619 m .48732 .60182 L .4944 .59349 L p .707 .577 .707 r
F P
0 g
s
.4944 .59349 m .494 .53787 L .48692 .54619 L p .707 .577 .707 r
F P
0 g
s
.69549 .66905 m .69041 .68627 L .66691 .688 L p .707 .577 .707 r
F P
0 g
s
.71041 .60387 m .71 .54825 L .74184 .54726 L p .707 .577 .707 r
F P
0 g
s
.71 .54825 m .71041 .60387 L .68103 .60741 L p .707 .577 .707 r
F P
0 g
s
.74184 .54726 m .74224 .60289 L .71041 .60387 L p .707 .577 .707 r
F P
0 g
s
.31314 .67136 m .31167 .63418 L .2991 .6272 L p .707 .577 .707 r
F P
0 g
s
.68819 .67032 m .68672 .63314 L .71608 .62886 L p .707 .577 .707 r
F P
0 g
s
.29341 .5997 m .293 .54408 L .29011 .53564 L p .707 .577 .707 r
F P
0 g
s
.2991 .6272 m .30057 .66438 L .31314 .67136 L p .707 .577 .707 r
F P
0 g
s
.31452 .69398 m .3196 .67676 L .30787 .66277 L p .707 .577 .707 r
F P
0 g
s
.69041 .68627 m .69549 .66905 L .72401 .67177 L p .707 .577 .707 r
F P
0 g
s
.77904 .6276 m .78051 .66478 L .74936 .66413 L p .707 .577 .707 r
F P
0 g
s
.74936 .66413 m .7479 .62695 L .77904 .6276 L p .707 .577 .707 r
F P
0 g
s
.47852 .72214 m .47344 .73936 L .48962 .73334 L p .707 .577 .707 r
F P
0 g
s
.48962 .73334 m .4947 .71612 L .47852 .72214 L p .707 .577 .707 r
F P
0 g
s
.81096 .70202 m .80588 .71924 L .77963 .70632 L p .707 .577 .707 r
F P
0 g
s
.77963 .70632 m .78471 .68911 L .81096 .70202 L p .707 .577 .707 r
F P
0 g
s
.71608 .62886 m .71755 .66604 L .68819 .67032 L p .707 .577 .707 r
F P
0 g
s
.49287 .62332 m .49434 .6605 L .50143 .65233 L p .707 .577 .707 r
F P
0 g
s
.50143 .65233 m .49996 .61515 L .49287 .62332 L p .707 .577 .707 r
F P
0 g
s
.71755 .66604 m .71608 .62886 L .7479 .62695 L p .707 .577 .707 r
F P
0 g
s
.30787 .66277 m .30279 .67999 L .31452 .69398 L p .707 .577 .707 r
F P
0 g
s
.72401 .67177 m .71893 .68899 L .69041 .68627 L p .707 .577 .707 r
F P
0 g
s
.7479 .62695 m .74936 .66413 L .71755 .66604 L p .707 .577 .707 r
F P
0 g
s
.29011 .53564 m .29051 .59127 L .29341 .5997 L p .707 .577 .707 r
F P
0 g
s
.71893 .68899 m .72401 .67177 L .75475 .67868 L p .707 .577 .707 r
F P
0 g
s
.494 .53787 m .4944 .59349 L .49151 .58505 L p .707 .577 .707 r
F P
0 g
s
.49151 .58505 m .4911 .52943 L .494 .53787 L p .707 .577 .707 r
F P
0 g
s
.78471 .68911 m .77963 .70632 L .74967 .6959 L p .707 .577 .707 r
F P
0 g
s
.74967 .6959 m .75475 .67868 L .78471 .68911 L p .707 .577 .707 r
F P
0 g
s
.30057 .66438 m .2991 .6272 L .29621 .61923 L p .707 .577 .707 r
F P
0 g
s
.75475 .67868 m .74967 .6959 L .71893 .68899 L p .707 .577 .707 r
F P
0 g
s
.30279 .67999 m .30787 .66277 L .30553 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29621 .61923 m .29768 .65641 L .30057 .66438 L p .707 .577 .707 r
F P
0 g
s
.29051 .59127 m .29011 .53564 L .29719 .52731 L p .707 .577 .707 r
F P
0 g
s
.4947 .71612 m .48962 .73334 L .49689 .72363 L p .707 .577 .707 r
F P
0 g
s
.49689 .72363 m .50197 .70641 L .4947 .71612 L p .707 .577 .707 r
F P
0 g
s
.30553 .65031 m .30045 .66753 L .30279 .67999 L p .707 .577 .707 r
F P
0 g
s
.49996 .61515 m .50143 .65233 L .49854 .64437 L p .707 .577 .707 r
F P
0 g
s
.49854 .64437 m .49708 .60719 L .49996 .61515 L p .707 .577 .707 r
F P
0 g
s
.29719 .52731 m .29759 .58294 L .29051 .59127 L p .707 .577 .707 r
F P
0 g
s
.4911 .52943 m .49151 .58505 L .47892 .57733 L p .707 .577 .707 r
F P
0 g
s
.47892 .57733 m .47851 .52171 L .4911 .52943 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29768 .65641 m .29621 .61923 L .3033 .61106 L p .707 .577 .707 r
F P
0 g
s
.30045 .66753 m .30553 .65031 L .31281 .6406 L p .707 .577 .707 r
F P
0 g
s
.29759 .58294 m .29719 .52731 L .31356 .51991 L p .707 .577 .707 r
F P
0 g
s
.50197 .70641 m .49689 .72363 L .49455 .71117 L p .707 .577 .707 r
F P
0 g
s
.49455 .71117 m .49963 .69395 L .50197 .70641 L p .707 .577 .707 r
F P
0 g
s
.3033 .61106 m .30477 .64824 L .29768 .65641 L p .707 .577 .707 r
F P
0 g
s
.31281 .6406 m .30773 .65782 L .30045 .66753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49708 .60719 m .49854 .64437 L .48597 .63738 L p .707 .577 .707 r
F P
0 g
s
.48597 .63738 m .4845 .6002 L .49708 .60719 L p .707 .577 .707 r
F P
0 g
s
.31356 .51991 m .31396 .57553 L .29759 .58294 L p .707 .577 .707 r
F P
0 g
s
.47851 .52171 m .47892 .57733 L .45786 .57109 L p .707 .577 .707 r
F P
0 g
s
.45786 .57109 m .45746 .51546 L .47851 .52171 L p .707 .577 .707 r
F P
0 g
s
.30477 .64824 m .3033 .61106 L .31967 .6035 L p .707 .577 .707 r
F P
0 g
s
.30773 .65782 m .31281 .6406 L .32898 .63458 L p .707 .577 .707 r
F P
0 g
s
.31396 .57553 m .31356 .51991 L .33761 .51415 L p .707 .577 .707 r
F P
0 g
s
.49963 .69395 m .49455 .71117 L .48283 .69718 L p .707 .577 .707 r
F P
0 g
s
.48283 .69718 m .48791 .67996 L .49963 .69395 L p .707 .577 .707 r
F P
0 g
s
.31967 .6035 m .32113 .64068 L .30477 .64824 L p .707 .577 .707 r
F P
0 g
s
.32898 .63458 m .3239 .6518 L .30773 .65782 L p .707 .577 .707 r
F P
0 g
s
.4845 .6002 m .48597 .63738 L .46493 .63206 L p .707 .577 .707 r
F P
0 g
s
.46493 .63206 m .46347 .59488 L .4845 .6002 L p .707 .577 .707 r
F P
0 g
s
.45746 .51546 m .45786 .57109 L .4304 .56692 L p .707 .577 .707 r
F P
0 g
s
.4304 .56692 m .43 .5113 L .45746 .51546 L p .707 .577 .707 r
F P
0 g
s
.33761 .51415 m .33802 .56978 L .31396 .57553 L p .707 .577 .707 r
F P
0 g
s
.33802 .56978 m .33761 .51415 L .36699 .51061 L p .707 .577 .707 r
F P
0 g
s
.32113 .64068 m .31967 .6035 L .34371 .59727 L p .707 .577 .707 r
F P
0 g
s
.3239 .6518 m .32898 .63458 L .35248 .63285 L p .707 .577 .707 r
F P
0 g
s
.43 .5113 m .4304 .56692 L .39923 .56525 L p .707 .577 .707 r
F P
0 g
s
.39923 .56525 m .39883 .50963 L .43 .5113 L p .707 .577 .707 r
F P
0 g
s
.48791 .67996 m .48283 .69718 L .46287 .68304 L p .707 .577 .707 r
F P
0 g
s
.46287 .68304 m .46795 .66582 L .48791 .67996 L p .707 .577 .707 r
F P
0 g
s
.34371 .59727 m .34518 .63445 L .32113 .64068 L p .707 .577 .707 r
F P
0 g
s
.46347 .59488 m .46493 .63206 L .4375 .62892 L p .707 .577 .707 r
F P
0 g
s
.4375 .62892 m .43603 .59174 L .46347 .59488 L p .707 .577 .707 r
F P
0 g
s
.3674 .56624 m .36699 .51061 L .39883 .50963 L p .707 .577 .707 r
F P
0 g
s
.36699 .51061 m .3674 .56624 L .33802 .56978 L p .707 .577 .707 r
F P
0 g
s
.35248 .63285 m .3474 .65007 L .3239 .6518 L p .707 .577 .707 r
F P
0 g
s
.39883 .50963 m .39923 .56525 L .3674 .56624 L p .707 .577 .707 r
F P
0 g
s
.34518 .63445 m .34371 .59727 L .37307 .593 L p .707 .577 .707 r
F P
0 g
s
.3474 .65007 m .35248 .63285 L .381 .63557 L p .707 .577 .707 r
F P
0 g
s
.43603 .59174 m .4375 .62892 L .40635 .62827 L p .707 .577 .707 r
F P
0 g
s
.40635 .62827 m .40489 .59109 L .43603 .59174 L p .707 .577 .707 r
F P
0 g
s
.46795 .66582 m .46287 .68304 L .43662 .67012 L p .707 .577 .707 r
F P
0 g
s
.43662 .67012 m .4417 .65291 L .46795 .66582 L p .707 .577 .707 r
F P
0 g
s
.37307 .593 m .37454 .63018 L .34518 .63445 L p .707 .577 .707 r
F P
0 g
s
.37454 .63018 m .37307 .593 L .40489 .59109 L p .707 .577 .707 r
F P
0 g
s
.381 .63557 m .37592 .65279 L .3474 .65007 L p .707 .577 .707 r
F P
0 g
s
.40489 .59109 m .40635 .62827 L .37454 .63018 L p .707 .577 .707 r
F P
0 g
s
.37592 .65279 m .381 .63557 L .41174 .64248 L p .707 .577 .707 r
F P
0 g
s
.4417 .65291 m .43662 .67012 L .40666 .6597 L p .707 .577 .707 r
F P
0 g
s
.40666 .6597 m .41174 .64248 L .4417 .65291 L p .707 .577 .707 r
F P
0 g
s
.41174 .64248 m .40666 .6597 L .37592 .65279 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF009J
EPT00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo2@0015YF00<005YFFUH00UYF20001EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001MOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001HOol50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?OolA0016Ool0
059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`H000=JEP03001JEUYF00IJEP03001J
EUYF009JEPP003ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001BOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000cOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF3P00
0eYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo
00<005YF000015YF00@005YFFUIJEPP000QJEPH000=JEP03001JEUYF00EJEPH000AJEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000015YF001JEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00DWoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002moo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000_Ool0059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEP0001T000EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00
DWoo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH70004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool005=oo`04001JEUYF0005
FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00D0
05YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0000_Ool003eooaX000=JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00=goo1P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH7
0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000dOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P00;Woo000aOol30004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000eYF0P00;Woo000_Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00
FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00:goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<0
05YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP04001JEUYFFUHG0006FUH00`00FUIJEP02FUH3000^Ool002]oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP`000AJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0015YF
00<005YF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP03FUH600000eYF000000090004
FUH00`00FUIJEP08FUH7000015YF001JEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEP0000D000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00H002moo`00:goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00eYF1@001EYF00@005YF0000
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002
FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP04001JEUYFFUH5000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000000eYF00@0
05YFFUIJEPH000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001J
EUYF009JEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF1@000eYF1@001UYF1`001eYF00<005YFFUH01EYF0P00
0UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEPD00003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP03
001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF1`0000AJEP00000000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF008000EJEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool002]oo`03001JEP0000AJEP04001JEUYFFUH80008FUH6
0003FUH00`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP03FUH20003FUH01000FUH0000015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00:goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YF00000P0015YF
00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0000=JEP00FUH01UYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPP00004Ool000000005
Ool>0004FUH01@00FUIJEUYF0000;Goo000[Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0P0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEPL000Mo
o`D000moo`H00003FUH005YF009JEP03001oogoo02]oo`00:goo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH00002
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH01P00FUIJEUYF001JEP@000=JEP04001JEUYFFUH<0009Ool60004FUH01000FUH000000eYF
0P00;7oo000[Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF1@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@000UYF0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00h000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF0000000/Ool002]oo`80
00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEUYFFUH300000eYF001JEP03FUHA0003FUH00`00FUIJEP07FUH30006FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH0
05YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPH000QJEP03001J
EUYF00=JEP03001JEUYF00=JEP<002aoo`00:goo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF
00@005YFFUIJEQL0009JEP03001JEUYF008000AJEP80009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040005FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000/Ool002]oo`8000=J
EP03001JEUYF009JEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF0P000eYF0P000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF0`0015YF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000`000UYF4`001UYF00<005YFFUH01EYF0`000UYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000;7oo000/Ool01@00FUIJEUYF000015YF00<005YF00001@001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEPD0009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP04001JEUYF0002FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
10000UYF00<005YFFUH01eYF10001UYF00<005YFFUH00UYF0P00;Goo000]Ool2000015YF001JEUYF
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00@005YFFUIJ
EP<000AJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000MJEP04001JEUYFFUH20005FUH0
0`00FUIJEP02FUH2000]Ool002moo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00001JEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01000FUIJEUYF0P00;Woo000_Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF0000
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00MJ
EP05001JEUYF001JEP02000`Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000MJEP8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEP00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000QJEPD0039oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001eYF00<005YF00000P00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01000FUIJEP00<goo000]Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000AJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001J
EUYF009JEP80035oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF
100015YF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP<00003FUH005YF009JEQT000Eoo`800003
FUH005YF00EJEP03001oogoo02ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF10002EYF00<005YFFUH0
1@002eYF00<005YFFUH015YF100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P000UYF00@005YFFUIJEP8000AJEP<000Qoo`D000moo`8000IJEP80
02moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2`001Woo3P0015YF0P00
00=JEP00000025YF00<005YFFUH015YF4`000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP03001JEUYF009JEP8000=JEP03001J
EP0000Qoo`D0015oo`03001JEUYF009JEP03001JEP0002moo`00;Goo00<005YF000015YF00<005YF
FUH00eYF4P003goo1`0000=JEP0000000UYF100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF0P001eYF00<005YFFUH00P002Goo1@004Woo0P000UYF00@0
05YFFUH002ioo`00;Goo00<005YF000015YF00<005YF00000`000eYF00<005YFFUH01EYF00<005YF
FUH010002Woo1@001EYF00<005YF00000P000UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH5000:Ool3000EOol2
0004FUH00`00Oomoo`0[Ool002eoo`03001JEP0000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH20004FUH01000FUIJEUYF0P008goo00<0
05YFFUH00UYF00<007ooOol0:goo000]Ool01000FUH005YF0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00D005YF
FUIJEP0000EJEP80029oo`05001JEUYFFUH0000]Ool002eoo`03001JEP00008000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF3@001eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0`0025YF
0P008Goo00D005YF001JEP0002aoo`00;Goo10000eYF4P001eYF00<005YFFUH01EYF0P000UYF00<0
05YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EP0000QJEP04001JEP00000POol200000eYF001oo`0[Ool002eoo`@00003FUH0000000=JEP03001J
EUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP020006FUH01000FUIJEUYF0`007Woo00<005YF
0000;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0025YF00<005YFFUH00P001EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=J
EP<000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP@001Uo
o`<002eoo`00;Woo0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF
00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH0
10004goo0P0000=JEP000000;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH300000eYF001JEP06FUH200001UYF00000000Ool0009JEP03001JEUYF
00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00=JEP03001J
EUYF00<000MJEP03001JEUYF00AJEPH000Qoo`D0009JEP8002ioo`00;Woo00<005YF00000P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0`000goo00@0
05YFFUH000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP@000AJEP03001JEP0000=oo`L000=JEP06001JEUYFFUH007oo0P0015YF
00<005YFFUH01eYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000^Ool002ioo`80009JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001J
EUYF0080009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF00<005YF00001P0015YF
10000eYF0P000Woo0`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000_Ool01P00FUIJEUYF001oo`L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00H000=JEP03001JEUYF009JEP03001oo`00009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP800004FUH005YF0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP0000001Goo10001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00;goo00@005YFFUIJEP<000Io
oaP000Ioo`<000IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000Uoo`@0009JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00000aOol0031oo`04001JEUYF0002FUH00`00Oomoo`0>Ool5000@Ool00`00
FUIJEP04FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000=Ool60004FUH01000FUIJEUYF1@00<goo000`Ool00`00FUH00004
FUH2000>Ool5000AOol20004FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00004goo2000>7oo000aOol20006FUH00`00
Oomoo`0;Ool5000COol01@00FUIJEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000100000=JEP00FUH01EYF00<005YFFUH00UYF0P00E7oo000bOol00`00FUIJEP04FUH3000<
Ool3000EOol30002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00
FUH005YF008000IJEP03001JEUYF009JEP8005Aoo`00<goo0P0015YF00<005YFFUH00P0097oo00@0
05YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH20004FUH01000
FUIJEUYF0P00EGoo000eOol01000FUIJEP001EYF0P008goo00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80009JEP04001JEP00001GOol003Ioo`<000MJ
EP80025oo`03001JEP0000<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00MJEPD0
05Uoo`00>7oo00<005YFFUH01EYF00<005YF00000P007goo0P0000=JEP00Ool00P001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P0000AJEP00000000MJEP04001JEUYF001JOol003Uoo`8000EJEP03001JEUYF009JEP<0
01eoo`03001JEP00009oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH20004FUH00`00FUIJ
EP02FUH2001HOol003]oo`80009JEP03001JEUYF00IJEP@001Uoo`8000Eoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00T0009oo`<00003FUH005YF00EJEP03001oogoo05Eoo`00?Goo0`002EYF00<005YFFUH010004goo
10002Goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
10003goo0P001UYF0P00EWoo000oOol20008FUH00`00FUIJEP04FUH60008Ool50002FUH2000>Ool6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09000AOol00`00
FUIJEP02FUH00`00FUH0001FOol0045oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
0`00FUIJEP02000EOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80004Ool5000BOol20002
FUH01000FUIJEP00EGoo0014Ool300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P007Woo6P002goo1@0057oo0P0015YF00<007ooOol0DWoo0017Ool30007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool20004FUH01000FUIJEUYF0P002Woo0`00
5Woo00<005YFFUH00UYF00<007ooOol0DWoo001:Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUH00000<goo00D005YFFUIJEP0000EJEP80029oo`05001JEUYFFUH0001DOol004iooa<0
03Ioo`<000QJEP80025oo`05001JEP00FUH0001COol009Uoo`03001JEUYF00IJEP04001JEP00000P
Ool200000eYF001oo`1BOol009Yoo`8000IJEP04001JEUYFFUH3000NOol00`00FUH0001COol009ao
o`8000=JEP03001JEUYF00EJEP@001Yoo`8005Aoo`00WWoo0P0000=JEP00FUH01eYF00<005YFFUH0
100057oo1000E7oo002POol30007FUH00`00FUIJEP04FUH60008Ool600000eYF0000001EOol00:=o
o`8000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00EGoo002UOol30000
0eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:Qoo`@000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:aoo`@0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00001HOol00;1oo`H000AJEP04001JEUYFFUH5001JOol00;Io
o`P005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58862 .74898 m .58797 .69333 L .5568 .6918 L p .707 .577 .707 r
F P
0 g
s
.58797 .69333 m .58862 .74898 L .62045 .74787 L p .707 .577 .707 r
F P
0 g
s
.62045 .74787 m .6198 .69222 L .58797 .69333 L p .707 .577 .707 r
F P
0 g
s
.6198 .69222 m .62045 .74787 L .64983 .74422 L p .707 .577 .707 r
F P
0 g
s
.64983 .74422 m .64918 .68858 L .6198 .69222 L p .707 .577 .707 r
F P
0 g
s
.55745 .74745 m .5568 .6918 L .52934 .68778 L p .707 .577 .707 r
F P
0 g
s
.5568 .6918 m .55745 .74745 L .58862 .74898 L p .707 .577 .707 r
F P
0 g
s
.64918 .68858 m .64983 .74422 L .67389 .7384 L p .707 .577 .707 r
F P
0 g
s
.67389 .7384 m .67323 .68276 L .64918 .68858 L p .707 .577 .707 r
F P
0 g
s
.60004 .80745 m .59767 .77022 L .56656 .77035 L p .707 .577 .707 r
F P
0 g
s
.59767 .77022 m .60004 .80745 L .63182 .80484 L p .707 .577 .707 r
F P
0 g
s
.63182 .80484 m .62944 .76761 L .59767 .77022 L p .707 .577 .707 r
F P
0 g
s
.62944 .76761 m .63182 .80484 L .66115 .80001 L p .707 .577 .707 r
F P
0 g
s
.66115 .80001 m .65878 .76278 L .62944 .76761 L p .707 .577 .707 r
F P
0 g
s
.52934 .68778 m .53 .74343 L .55745 .74745 L p .707 .577 .707 r
F P
0 g
s
.53 .74343 m .52934 .68778 L .50829 .68166 L p .707 .577 .707 r
F P
0 g
s
.56893 .80757 m .56656 .77035 L .53917 .76798 L p .707 .577 .707 r
F P
0 g
s
.56656 .77035 m .56893 .80757 L .60004 .80745 L p .707 .577 .707 r
F P
0 g
s
.65878 .76278 m .66115 .80001 L .68518 .79343 L p .707 .577 .707 r
F P
0 g
s
.68518 .79343 m .6828 .7562 L .65878 .76278 L p .707 .577 .707 r
F P
0 g
s
.53917 .76798 m .54154 .80521 L .56893 .80757 L p .707 .577 .707 r
F P
0 g
s
.67323 .68276 m .67389 .7384 L .69026 .73098 L p .707 .577 .707 r
F P
0 g
s
.69026 .73098 m .6896 .67533 L .67323 .68276 L p .707 .577 .707 r
F P
0 g
s
.59564 .86384 m .60367 .84815 L .57564 .8329 L p .707 .577 .707 r
F P
0 g
s
.60367 .84815 m .59564 .86384 L .62464 .8751 L p .707 .577 .707 r
F P
0 g
s
.62464 .8751 m .63268 .85942 L .60367 .84815 L p .707 .577 .707 r
F P
0 g
s
.50829 .68166 m .50894 .73731 L .53 .74343 L p .707 .577 .707 r
F P
0 g
s
.5676 .84859 m .57564 .8329 L .55131 .81516 L p .707 .577 .707 r
F P
0 g
s
.57564 .8329 m .5676 .84859 L .59564 .86384 L p .707 .577 .707 r
F P
0 g
s
.54154 .80521 m .53917 .76798 L .51817 .76336 L p .707 .577 .707 r
F P
0 g
s
.63268 .85942 m .62464 .8751 L .65178 .88128 L p .707 .577 .707 r
F P
0 g
s
.65178 .88128 m .65982 .8656 L .63268 .85942 L p .707 .577 .707 r
F P
0 g
s
.50894 .73731 m .50829 .68166 L .4957 .67404 L p .707 .577 .707 r
F P
0 g
s
.55131 .81516 m .54328 .83084 L .5676 .84859 L p .707 .577 .707 r
F P
0 g
s
.51817 .76336 m .52054 .80059 L .54154 .80521 L p .707 .577 .707 r
F P
0 g
s
.54328 .83084 m .55131 .81516 L .53309 .79666 L p .707 .577 .707 r
F P
0 g
s
.6828 .7562 m .68518 .79343 L .70154 .78574 L p .707 .577 .707 r
F P
0 g
s
.70154 .78574 m .69916 .74851 L .6828 .7562 L p .707 .577 .707 r
F P
0 g
s
.53309 .79666 m .52505 .81235 L .54328 .83084 L p .707 .577 .707 r
F P
0 g
s
.65982 .8656 m .65178 .88128 L .67439 .88177 L p .707 .577 .707 r
F P
0 g
s
.67439 .88177 m .68243 .86609 L .65982 .8656 L p .707 .577 .707 r
F P
0 g
s
.4957 .67404 m .49635 .72969 L .50894 .73731 L p .707 .577 .707 r
F P
0 g
s
.6896 .67533 m .69026 .73098 L .69734 .72267 L p .707 .577 .707 r
F P
0 g
s
.69734 .72267 m .69669 .66702 L .6896 .67533 L p .707 .577 .707 r
F P
0 g
s
.52054 .80059 m .51817 .76336 L .50562 .75693 L p .707 .577 .707 r
F P
0 g
s
.52505 .81235 m .53309 .79666 L .52274 .77922 L p .707 .577 .707 r
F P
0 g
s
.50562 .75693 m .508 .79415 L .52054 .80059 L p .707 .577 .707 r
F P
0 g
s
.49635 .72969 m .4957 .67404 L .4928 .66567 L p .707 .577 .707 r
F P
0 g
s
.52274 .77922 m .5147 .79491 L .52505 .81235 L p .707 .577 .707 r
F P
0 g
s
.69916 .74851 m .70154 .78574 L .70863 .77769 L p .707 .577 .707 r
F P
0 g
s
.70863 .77769 m .70626 .74047 L .69916 .74851 L p .707 .577 .707 r
F P
0 g
s
.68243 .86609 m .67439 .88177 L .69026 .87652 L p .707 .577 .707 r
F P
0 g
s
.69026 .87652 m .6983 .86083 L .68243 .86609 L p .707 .577 .707 r
F P
0 g
s
.4928 .66567 m .49346 .72132 L .49635 .72969 L p .707 .577 .707 r
F P
0 g
s
.69669 .66702 m .69734 .72267 L .69444 .7143 L p .707 .577 .707 r
F P
0 g
s
.69444 .7143 m .69379 .65865 L .69669 .66702 L p .707 .577 .707 r
F P
0 g
s
.5147 .79491 m .52274 .77922 L .52128 .76454 L p .707 .577 .707 r
F P
0 g
s
.508 .79415 m .50562 .75693 L .50276 .74932 L p .707 .577 .707 r
F P
0 g
s
.48484 .82193 m .49309 .321 L .44909 .31759 L p .707 .577 .707 r
F P
0 g
s
.52128 .76454 m .51325 .78023 L .5147 .79491 L p .707 .577 .707 r
F P
0 g
s
.50276 .74932 m .50513 .78654 L .508 .79415 L p .707 .577 .707 r
F P
0 g
s
.49346 .72132 m .4928 .66567 L .49989 .65737 L p .707 .577 .707 r
F P
0 g
s
.49989 .65737 m .50054 .71301 L .49346 .72132 L p .707 .577 .707 r
F P
0 g
s
.51325 .78023 m .52128 .76454 L .52886 .75407 L p .707 .577 .707 r
F P
0 g
s
.50513 .78654 m .50276 .74932 L .50985 .74127 L p .707 .577 .707 r
F P
0 g
s
.52886 .75407 m .52083 .76975 L .51325 .78023 L p .707 .577 .707 r
F P
0 g
s
.50985 .74127 m .51222 .7785 L .50513 .78654 L p .707 .577 .707 r
F P
0 g
s
.50054 .71301 m .49989 .65737 L .51625 .64994 L p .707 .577 .707 r
F P
0 g
s
.52083 .76975 m .52886 .75407 L .54474 .74881 L p .707 .577 .707 r
F P
0 g
s
.51625 .64994 m .51691 .70559 L .50054 .71301 L p .707 .577 .707 r
F P
0 g
s
.51222 .7785 m .50985 .74127 L .52621 .73359 L p .707 .577 .707 r
F P
0 g
s
.54474 .74881 m .5367 .76449 L .52083 .76975 L p .707 .577 .707 r
F P
0 g
s
.51691 .70559 m .51625 .64994 L .54031 .64412 L p .707 .577 .707 r
F P
0 g
s
.52621 .73359 m .52858 .77081 L .51222 .7785 L p .707 .577 .707 r
F P
0 g
s
.54031 .64412 m .54096 .69977 L .51691 .70559 L p .707 .577 .707 r
F P
0 g
s
.49309 .321 m .48484 .82193 L .52978 .8215 L p .707 .577 .707 r
F P
0 g
s
.52858 .77081 m .52621 .73359 L .55023 .727 L p .707 .577 .707 r
F P
0 g
s
.5367 .76449 m .54474 .74881 L .56735 .7493 L p .707 .577 .707 r
F P
0 g
s
.56735 .7493 m .55931 .76498 L .5367 .76449 L p .707 .577 .707 r
F P
0 g
s
.55023 .727 m .55261 .76423 L .52858 .77081 L p .707 .577 .707 r
F P
0 g
s
.52978 .8215 m .53803 .32057 L .49309 .321 L p .707 .577 .707 r
F P
0 g
s
.54096 .69977 m .54031 .64412 L .56969 .64047 L p .707 .577 .707 r
F P
0 g
s
.56969 .64047 m .57034 .69612 L .54096 .69977 L p .707 .577 .707 r
F P
0 g
s
.55931 .76498 m .56735 .7493 L .59448 .75548 L p .707 .577 .707 r
F P
0 g
s
.55261 .76423 m .55023 .727 L .57957 .72217 L p .707 .577 .707 r
F P
0 g
s
.59448 .75548 m .58645 .77116 L .55931 .76498 L p .707 .577 .707 r
F P
0 g
s
.57957 .72217 m .58194 .7594 L .55261 .76423 L p .707 .577 .707 r
F P
0 g
s
.53803 .32057 m .52978 .8215 L .57125 .81725 L p .707 .577 .707 r
F P
0 g
s
.57034 .69612 m .56969 .64047 L .60152 .63936 L p .707 .577 .707 r
F P
0 g
s
.60152 .63936 m .60217 .69501 L .57034 .69612 L p .707 .577 .707 r
F P
0 g
s
.57125 .81725 m .5795 .31632 L .53803 .32057 L p .707 .577 .707 r
F P
0 g
s
.44083 .81852 m .44909 .31759 L .41033 .31066 L p .707 .577 .707 r
F P
0 g
s
.44909 .31759 m .44083 .81852 L .48484 .82193 L p .707 .577 .707 r
F P
0 g
s
.70626 .74047 m .70863 .77769 L .70576 .77008 L p .707 .577 .707 r
F P
0 g
s
.70576 .77008 m .70339 .73286 L .70626 .74047 L p .707 .577 .707 r
F P
0 g
s
.6983 .86083 m .69026 .87652 L .69784 .86604 L p .707 .577 .707 r
F P
0 g
s
.69784 .86604 m .70588 .85035 L .6983 .86083 L p .707 .577 .707 r
F P
0 g
s
.58194 .7594 m .57957 .72217 L .61135 .71956 L p .707 .577 .707 r
F P
0 g
s
.58645 .77116 m .59448 .75548 L .62349 .76674 L p .707 .577 .707 r
F P
0 g
s
.61135 .71956 m .61372 .75679 L .58194 .7594 L p .707 .577 .707 r
F P
0 g
s
.62349 .76674 m .61546 .78243 L .58645 .77116 L p .707 .577 .707 r
F P
0 g
s
.5795 .31632 m .57125 .81725 L .60521 .80961 L p .707 .577 .707 r
F P
0 g
s
.63269 .64089 m .63334 .69654 L .60217 .69501 L p .707 .577 .707 r
F P
0 g
s
.60217 .69501 m .60152 .63936 L .63269 .64089 L p .707 .577 .707 r
F P
0 g
s
.60521 .80961 m .61346 .30868 L .5795 .31632 L p .707 .577 .707 r
F P
0 g
s
.69379 .65865 m .69444 .7143 L .68185 .70668 L p .707 .577 .707 r
F P
0 g
s
.68185 .70668 m .6812 .65103 L .69379 .65865 L p .707 .577 .707 r
F P
0 g
s
.40208 .81159 m .41033 .31066 L .38061 .30088 L p .707 .577 .707 r
F P
0 g
s
.41033 .31066 m .40208 .81159 L .44083 .81852 L p .707 .577 .707 r
F P
0 g
s
.24561 .71084 m .24496 .65519 L .21379 .65366 L p .707 .577 .707 r
F P
0 g
s
.24496 .65519 m .24561 .71084 L .27745 .70973 L p .707 .577 .707 r
F P
0 g
s
.27745 .70973 m .27679 .65408 L .24496 .65519 L p .707 .577 .707 r
F P
0 g
s
.27679 .65408 m .27745 .70973 L .30683 .70608 L p .707 .577 .707 r
F P
0 g
s
.30683 .70608 m .30617 .65044 L .27679 .65408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70588 .85035 m .69784 .86604 L .69639 .85136 L p .707 .577 .707 r
F P
0 g
s
.69639 .85136 m .70442 .83568 L .70588 .85035 L p .707 .577 .707 r
F P
0 g
s
.21444 .70931 m .21379 .65366 L .18633 .64964 L p .707 .577 .707 r
F P
0 g
s
.21379 .65366 m .21444 .70931 L .24561 .71084 L p .707 .577 .707 r
F P
0 g
s
.70339 .73286 m .70576 .77008 L .69322 .76365 L p .707 .577 .707 r
F P
0 g
s
.69322 .76365 m .69084 .72642 L .70339 .73286 L p .707 .577 .707 r
F P
0 g
s
.30617 .65044 m .30683 .70608 L .33088 .70026 L p .707 .577 .707 r
F P
0 g
s
.33088 .70026 m .33023 .64462 L .30617 .65044 L p .707 .577 .707 r
F P
0 g
s
.64245 .71944 m .64483 .75666 L .61372 .75679 L p .707 .577 .707 r
F P
0 g
s
.61372 .75679 m .61135 .71956 L .64245 .71944 L p .707 .577 .707 r
F P
0 g
s
.65153 .78199 m .64349 .79768 L .61546 .78243 L p .707 .577 .707 r
F P
0 g
s
.61546 .78243 m .62349 .76674 L .65153 .78199 L p .707 .577 .707 r
F P
0 g
s
.61346 .30868 m .60521 .80961 L .62832 .79932 L p .707 .577 .707 r
F P
0 g
s
.62832 .79932 m .63657 .29839 L .61346 .30868 L p .707 .577 .707 r
F P
0 g
s
.25703 .77217 m .25466 .73494 L .22355 .73507 L p .707 .577 .707 r
F P
0 g
s
.25466 .73494 m .25703 .77217 L .28881 .76956 L p .707 .577 .707 r
F P
0 g
s
.28881 .76956 m .28644 .73233 L .25466 .73494 L p .707 .577 .707 r
F P
0 g
s
.6812 .65103 m .68185 .70668 L .6608 .70056 L p .707 .577 .707 r
F P
0 g
s
.6608 .70056 m .66015 .64491 L .6812 .65103 L p .707 .577 .707 r
F P
0 g
s
.28644 .73233 m .28881 .76956 L .31815 .76473 L p .707 .577 .707 r
F P
0 g
s
.31815 .76473 m .31577 .7275 L .28644 .73233 L p .707 .577 .707 r
F P
0 g
s
.18633 .64964 m .18699 .70529 L .21444 .70931 L p .707 .577 .707 r
F P
0 g
s
.18699 .70529 m .18633 .64964 L .16528 .64352 L p .707 .577 .707 r
F P
0 g
s
.22592 .7723 m .22355 .73507 L .19616 .73271 L p .707 .577 .707 r
F P
0 g
s
.22355 .73507 m .22592 .7723 L .25703 .77217 L p .707 .577 .707 r
F P
0 g
s
.37236 .80181 m .38061 .30088 L .36283 .28923 L p .707 .577 .707 r
F P
0 g
s
.38061 .30088 m .37236 .80181 L .40208 .81159 L p .707 .577 .707 r
F P
0 g
s
.31577 .7275 m .31815 .76473 L .34217 .75815 L p .707 .577 .707 r
F P
0 g
s
.34217 .75815 m .33979 .72092 L .31577 .7275 L p .707 .577 .707 r
F P
0 g
s
.19616 .73271 m .19853 .76993 L .22592 .7723 L p .707 .577 .707 r
F P
0 g
s
.33023 .64462 m .33088 .70026 L .34725 .69284 L p .707 .577 .707 r
F P
0 g
s
.34725 .69284 m .34659 .63719 L .33023 .64462 L p .707 .577 .707 r
F P
0 g
s
.70442 .83568 m .69639 .85136 L .68604 .83392 L p .707 .577 .707 r
F P
0 g
s
.68604 .83392 m .69408 .81823 L .70442 .83568 L p .707 .577 .707 r
F P
0 g
s
.69084 .72642 m .69322 .76365 L .67222 .75903 L p .707 .577 .707 r
F P
0 g
s
.67222 .75903 m .66985 .7218 L .69084 .72642 L p .707 .577 .707 r
F P
0 g
s
.25263 .82802 m .26066 .81234 L .23263 .79708 L p .707 .577 .707 r
F P
0 g
s
.26066 .81234 m .25263 .82802 L .28163 .83928 L p .707 .577 .707 r
F P
0 g
s
.28163 .83928 m .28967 .8236 L .26066 .81234 L p .707 .577 .707 r
F P
0 g
s
.16528 .64352 m .16593 .69917 L .18699 .70529 L p .707 .577 .707 r
F P
0 g
s
.22459 .81277 m .23263 .79708 L .2083 .77934 L p .707 .577 .707 r
F P
0 g
s
.23263 .79708 m .22459 .81277 L .25263 .82802 L p .707 .577 .707 r
F P
0 g
s
.19853 .76993 m .19616 .73271 L .17516 .72808 L p .707 .577 .707 r
F P
0 g
s
.66015 .64491 m .6608 .70056 L .63334 .69654 L p .707 .577 .707 r
F P
0 g
s
.63334 .69654 m .63269 .64089 L .66015 .64491 L p .707 .577 .707 r
F P
0 g
s
.28967 .8236 m .28163 .83928 L .30877 .84546 L p .707 .577 .707 r
F P
0 g
s
.30877 .84546 m .31681 .82978 L .28967 .8236 L p .707 .577 .707 r
F P
0 g
s
.16593 .69917 m .16528 .64352 L .15269 .6359 L p .707 .577 .707 r
F P
0 g
s
.2083 .77934 m .20027 .79503 L .22459 .81277 L p .707 .577 .707 r
F P
0 g
s
.17516 .72808 m .17753 .76531 L .19853 .76993 L p .707 .577 .707 r
F P
0 g
s
.20027 .79503 m .2083 .77934 L .19008 .76085 L p .707 .577 .707 r
F P
0 g
s
.33979 .72092 m .34217 .75815 L .35853 .75046 L p .707 .577 .707 r
F P
0 g
s
.35853 .75046 m .35615 .71323 L .33979 .72092 L p .707 .577 .707 r
F P
0 g
s
.63657 .29839 m .62832 .79932 L .63832 .7874 L p .707 .577 .707 r
F P
0 g
s
.63832 .7874 m .64657 .28647 L .63657 .29839 L p .707 .577 .707 r
F P
0 g
s
.19008 .76085 m .18204 .77653 L .20027 .79503 L p .707 .577 .707 r
F P
0 g
s
.66985 .7218 m .67222 .75903 L .64483 .75666 L p .707 .577 .707 r
F P
0 g
s
.64483 .75666 m .64245 .71944 L .66985 .7218 L p .707 .577 .707 r
F P
0 g
s
.69408 .81823 m .68604 .83392 L .66781 .81542 L p .707 .577 .707 r
F P
0 g
s
.66781 .81542 m .67585 .79974 L .69408 .81823 L p .707 .577 .707 r
F P
0 g
s
.31681 .82978 m .30877 .84546 L .33138 .84595 L p .707 .577 .707 r
F P
0 g
s
.33138 .84595 m .33942 .83027 L .31681 .82978 L p .707 .577 .707 r
F P
0 g
s
.15269 .6359 m .15334 .69155 L .16593 .69917 L p .707 .577 .707 r
F P
0 g
s
.34659 .63719 m .34725 .69284 L .35433 .68453 L p .707 .577 .707 r
F P
0 g
s
.35433 .68453 m .35368 .62888 L .34659 .63719 L p .707 .577 .707 r
F P
0 g
s
.17753 .76531 m .17516 .72808 L .16261 .72165 L p .707 .577 .707 r
F P
0 g
s
.18204 .77653 m .19008 .76085 L .17973 .7434 L p .707 .577 .707 r
F P
0 g
s
.35615 .71323 m .35853 .75046 L .36562 .74242 L p .707 .577 .707 r
F P
0 g
s
.36562 .74242 m .36325 .70519 L .35615 .71323 L p .707 .577 .707 r
F P
0 g
s
.36038 .69758 m .36275 .73481 L .35021 .72838 L p .707 .577 .707 r
F P
0 g
s
.35021 .72838 m .34783 .69115 L .36038 .69758 L p .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35107 .78241 L .35797 .79405 L p .707 .577 .707 r
F P
0 g
s
.35797 .79405 m .36142 .79986 L p .35827 .79956 L .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35797 .79405 L .35827 .79956 L .707 .577 .707 r
F
.36283 .28923 m .35875 .27683 L p .355 .73937 L F P
0 g
s
.35458 .79016 m .35532 .74536 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.35532 .74536 m .36283 .28923 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.36325 .70519 m .36562 .74242 L .36275 .73481 L p .707 .577 .707 r
F P
0 g
s
.36275 .73481 m .36038 .69758 L .36325 .70519 L p .707 .577 .707 r
F P
0 g
s
.36283 .28923 m .35458 .79016 L .37236 .80181 L p .707 .577 .707 r
F P
0 g
s
.15334 .69155 m .15269 .6359 L .14979 .62753 L p .707 .577 .707 r
F P
0 g
s
.16261 .72165 m .16499 .75888 L .17753 .76531 L p .707 .577 .707 r
F P
0 g
s
.17973 .7434 m .17169 .75909 L .18204 .77653 L p .707 .577 .707 r
F P
0 g
s
.67585 .79974 m .66781 .81542 L .64349 .79768 L p .707 .577 .707 r
F P
0 g
s
.64349 .79768 m .65153 .78199 L .67585 .79974 L p .707 .577 .707 r
F P
0 g
s
.33942 .83027 m .33138 .84595 L .34726 .8407 L p .707 .577 .707 r
F P
0 g
s
.34726 .8407 m .35529 .82501 L .33942 .83027 L p .707 .577 .707 r
F P
0 g
s
.14979 .62753 m .15045 .68318 L .15334 .69155 L p .707 .577 .707 r
F P
0 g
s
.35368 .62888 m .35433 .68453 L .35143 .67616 L p .707 .577 .707 r
F P
0 g
s
.35143 .67616 m .35078 .62051 L .35368 .62888 L p .707 .577 .707 r
F P
0 g
s
.17169 .75909 m .17973 .7434 L .17827 .72872 L p .707 .577 .707 r
F P
0 g
s
.16499 .75888 m .16261 .72165 L .15975 .71404 L p .707 .577 .707 r
F P
0 g
s
.64657 .28647 m .63832 .7874 L .63423 .775 L p .707 .577 .707 r
F P
0 g
s
.63423 .775 m .64248 .27407 L .64657 .28647 L p .707 .577 .707 r
F P
0 g
s
.17827 .72872 m .17024 .74441 L .17169 .75909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15975 .71404 m .16212 .75127 L .16499 .75888 L p .707 .577 .707 r
F P
0 g
s
.15045 .68318 m .14979 .62753 L .15688 .61922 L p .707 .577 .707 r
F P
0 g
s
.35529 .82501 m .34726 .8407 L .35483 .83022 L p .707 .577 .707 r
F P
0 g
s
.35483 .83022 m .36287 .81454 L .35529 .82501 L p .707 .577 .707 r
F P
0 g
s
.35875 .27683 m .3505 .77776 L .35458 .79016 L p .707 .577 .707 r
F P
0 g
s
.3505 .77776 m .35875 .27683 L .36875 .26491 L p .707 .577 .707 r
F P
0 g
s
.15688 .61922 m .15753 .67487 L .15045 .68318 L p .707 .577 .707 r
F P
0 g
s
.17024 .74441 m .17827 .72872 L .18585 .71825 L p .707 .577 .707 r
F P
0 g
s
.35078 .62051 m .35143 .67616 L .33884 .66854 L p .707 .577 .707 r
F P
0 g
s
.33884 .66854 m .33819 .61289 L .35078 .62051 L p .707 .577 .707 r
F P
0 g
s
.16212 .75127 m .15975 .71404 L .16684 .706 L p .707 .577 .707 r
F P
0 g
s
.18585 .71825 m .17782 .73393 L .17024 .74441 L p .707 .577 .707 r
F P
0 g
s
.16684 .706 m .16921 .74323 L .16212 .75127 L p .707 .577 .707 r
F P
0 g
s
.15753 .67487 m .15688 .61922 L .17324 .6118 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64248 .27407 m .63423 .775 L .61646 .76335 L p .707 .577 .707 r
F P
0 g
s
.61646 .76335 m .62471 .26242 L .64248 .27407 L p .707 .577 .707 r
F P
0 g
s
.36287 .81454 m .35483 .83022 L .35338 .81554 L p .707 .577 .707 r
F P
0 g
s
.35338 .81554 m .36142 .79986 L .36287 .81454 L p .707 .577 .707 r
F P
0 g
s
.17324 .6118 m .1739 .66745 L .15753 .67487 L p .707 .577 .707 r
F P
0 g
s
.33819 .61289 m .33884 .66854 L .31779 .66242 L p .707 .577 .707 r
F P
0 g
s
.31779 .66242 m .31714 .60677 L .33819 .61289 L p .707 .577 .707 r
F P
0 g
s
.17782 .73393 m .18585 .71825 L .20173 .71299 L p .707 .577 .707 r
F P
0 g
s
.3605 .76584 m .36875 .26491 L .39186 .25462 L p .707 .577 .707 r
F P
0 g
s
.36875 .26491 m .3605 .76584 L .3505 .77776 L p .707 .577 .707 r
F P
0 g
s
.16921 .74323 m .16684 .706 L .1832 .69831 L p .707 .577 .707 r
F P
0 g
s
.20173 .71299 m .19369 .72868 L .17782 .73393 L p .707 .577 .707 r
F P
0 g
s
.1739 .66745 m .17324 .6118 L .1973 .60598 L p .707 .577 .707 r
F P
0 g
s
.1832 .69831 m .18557 .73554 L .16921 .74323 L p .707 .577 .707 r
F P
0 g
s
.36142 .79986 m .35338 .81554 L .34303 .7981 L p .707 .577 .707 r
F P
0 g
s
.34783 .69115 m .35021 .72838 L .32921 .72375 L p .707 .577 .707 r
F P
0 g
s
.32921 .72375 m .32684 .68652 L .34783 .69115 L p .707 .577 .707 r
F P
0 g
s
.31714 .60677 m .31779 .66242 L .29033 .6584 L p .707 .577 .707 r
F P
0 g
s
.29033 .6584 m .28968 .60275 L .31714 .60677 L p .707 .577 .707 r
F P
0 g
s
.1973 .60598 m .19795 .66163 L .1739 .66745 L p .707 .577 .707 r
F P
0 g
s
.19369 .72868 m .20173 .71299 L .22434 .71348 L p .707 .577 .707 r
F P
0 g
s
.62471 .26242 m .61646 .76335 L .58674 .75358 L p .707 .577 .707 r
F P
0 g
s
.58674 .75358 m .59499 .25265 L .62471 .26242 L p .707 .577 .707 r
F P
0 g
s
.18557 .73554 m .1832 .69831 L .20722 .69173 L p .707 .577 .707 r
F P
0 g
s
.19795 .66163 m .1973 .60598 L .22668 .60233 L p .707 .577 .707 r
F P
0 g
s
.22434 .71348 m .2163 .72916 L .19369 .72868 L p .707 .577 .707 r
F P
0 g
s
.28968 .60275 m .29033 .6584 L .25916 .65687 L p .707 .577 .707 r
F P
0 g
s
.25916 .65687 m .25851 .60122 L .28968 .60275 L p .707 .577 .707 r
F P
0 g
s
.20722 .69173 m .2096 .72895 L .18557 .73554 L p .707 .577 .707 r
F P
0 g
s
.32684 .68652 m .32921 .72375 L .30182 .72139 L p .707 .577 .707 r
F P
0 g
s
.30182 .72139 m .29944 .68416 L .32684 .68652 L p .707 .577 .707 r
F P
0 g
s
.39186 .25462 m .38361 .75555 L .3605 .76584 L p .707 .577 .707 r
F P
0 g
s
.38361 .75555 m .39186 .25462 L .42581 .24698 L p .707 .577 .707 r
F P
0 g
s
.35107 .78241 m .34303 .7981 L .32481 .7796 L p .707 .577 .707 r
F P
0 g
s
.32481 .7796 m .33284 .76392 L .35107 .78241 L p .707 .577 .707 r
F P
0 g
s
.22733 .65798 m .22668 .60233 L .25851 .60122 L p .707 .577 .707 r
F P
0 g
s
.22668 .60233 m .22733 .65798 L .19795 .66163 L p .707 .577 .707 r
F P
0 g
s
.25851 .60122 m .25916 .65687 L .22733 .65798 L p .707 .577 .707 r
F P
0 g
s
.72583 .65694 m .72517 .60129 L .694 .59976 L p .707 .577 .707 r
F P
0 g
s
.72517 .60129 m .72583 .65694 L .75766 .65583 L p .707 .577 .707 r
F P
0 g
s
.75766 .65583 m .75701 .60018 L .72517 .60129 L p .707 .577 .707 r
F P
0 g
s
.2163 .72916 m .22434 .71348 L .25148 .71966 L p .707 .577 .707 r
F P
0 g
s
.75701 .60018 m .75766 .65583 L .78704 .65219 L p .707 .577 .707 r
F P
0 g
s
.78704 .65219 m .78639 .59654 L .75701 .60018 L p .707 .577 .707 r
F P
0 g
s
.2096 .72895 m .20722 .69173 L .23656 .6869 L p .707 .577 .707 r
F P
0 g
s
.69465 .65541 m .694 .59976 L .66655 .59574 L p .707 .577 .707 r
F P
0 g
s
.694 .59976 m .69465 .65541 L .72583 .65694 L p .707 .577 .707 r
F P
0 g
s
.25148 .71966 m .24344 .73534 L .2163 .72916 L p .707 .577 .707 r
F P
0 g
s
.29944 .68416 m .30182 .72139 L .27071 .72152 L p .707 .577 .707 r
F P
0 g
s
.27071 .72152 m .26834 .68429 L .29944 .68416 L p .707 .577 .707 r
F P
0 g
s
.23656 .6869 m .23893 .72412 L .2096 .72895 L p .707 .577 .707 r
F P
0 g
s
.59499 .25265 m .58674 .75358 L .54798 .74665 L p .707 .577 .707 r
F P
0 g
s
.54798 .74665 m .55623 .24571 L .59499 .25265 L p .707 .577 .707 r
F P
0 g
s
.33284 .76392 m .32481 .7796 L .30048 .76186 L p .707 .577 .707 r
F P
0 g
s
.30048 .76186 m .30852 .74618 L .33284 .76392 L p .707 .577 .707 r
F P
0 g
s
.23893 .72412 m .23656 .6869 L .26834 .68429 L p .707 .577 .707 r
F P
0 g
s
.78639 .59654 m .78704 .65219 L .81109 .64637 L p .707 .577 .707 r
F P
0 g
s
.81109 .64637 m .81044 .59072 L .78639 .59654 L p .707 .577 .707 r
F P
0 g
s
.24344 .73534 m .25148 .71966 L .28048 .73092 L p .707 .577 .707 r
F P
0 g
s
.26834 .68429 m .27071 .72152 L .23893 .72412 L p .707 .577 .707 r
F P
0 g
s
.73725 .71541 m .73487 .67818 L .70376 .67831 L p .707 .577 .707 r
F P
0 g
s
.73487 .67818 m .73725 .71541 L .76902 .7128 L p .707 .577 .707 r
F P
0 g
s
.76902 .7128 m .76665 .67557 L .73487 .67818 L p .707 .577 .707 r
F P
0 g
s
.76665 .67557 m .76902 .7128 L .79836 .70797 L p .707 .577 .707 r
F P
0 g
s
.79836 .70797 m .79598 .67074 L .76665 .67557 L p .707 .577 .707 r
F P
0 g
s
.66655 .59574 m .6672 .65139 L .69465 .65541 L p .707 .577 .707 r
F P
0 g
s
.41756 .74791 m .42581 .24698 L .46729 .24274 L p .707 .577 .707 r
F P
0 g
s
.42581 .24698 m .41756 .74791 L .38361 .75555 L p .707 .577 .707 r
F P
0 g
s
.6672 .65139 m .66655 .59574 L .64549 .58962 L p .707 .577 .707 r
F P
0 g
s
.30852 .74618 m .30048 .76186 L .27245 .74661 L p .707 .577 .707 r
F P
0 g
s
.27245 .74661 m .28048 .73092 L .30852 .74618 L p .707 .577 .707 r
F P
0 g
s
.70614 .71554 m .70376 .67831 L .67637 .67594 L p .707 .577 .707 r
F P
0 g
s
.70376 .67831 m .70614 .71554 L .73725 .71541 L p .707 .577 .707 r
F P
0 g
s
.28048 .73092 m .27245 .74661 L .24344 .73534 L p .707 .577 .707 r
F P
0 g
s
.79598 .67074 m .79836 .70797 L .82238 .70139 L p .707 .577 .707 r
F P
0 g
s
.82238 .70139 m .82001 .66416 L .79598 .67074 L p .707 .577 .707 r
F P
0 g
s
.67637 .67594 m .67874 .71317 L .70614 .71554 L p .707 .577 .707 r
F P
0 g
s
.55623 .24571 m .54798 .74665 L .50398 .74323 L p .707 .577 .707 r
F P
0 g
s
.50398 .74323 m .51223 .2423 L .55623 .24571 L p .707 .577 .707 r
F P
0 g
s
.81044 .59072 m .81109 .64637 L .82746 .63894 L p .707 .577 .707 r
F P
0 g
s
.82746 .63894 m .82681 .58329 L .81044 .59072 L p .707 .577 .707 r
F P
0 g
s
.73284 .7718 m .74088 .75612 L .71284 .74087 L p .707 .577 .707 r
F P
0 g
s
.74088 .75612 m .73284 .7718 L .76185 .78307 L p .707 .577 .707 r
F P
0 g
s
.76185 .78307 m .76988 .76738 L .74088 .75612 L p .707 .577 .707 r
F P
0 g
s
.64549 .58962 m .64615 .64527 L .6672 .65139 L p .707 .577 .707 r
F P
0 g
s
.7048 .75655 m .71284 .74087 L .68852 .72312 L p .707 .577 .707 r
F P
0 g
s
.71284 .74087 m .7048 .75655 L .73284 .7718 L p .707 .577 .707 r
F P
0 g
s
.45904 .74367 m .46729 .24274 L .51223 .2423 L p .707 .577 .707 r
F P
0 g
s
.46729 .24274 m .45904 .74367 L .41756 .74791 L p .707 .577 .707 r
F P
0 g
s
.67874 .71317 m .67637 .67594 L .65537 .67132 L p .707 .577 .707 r
F P
0 g
s
.76988 .76738 m .76185 .78307 L .78898 .78924 L p .707 .577 .707 r
F P
0 g
s
.78898 .78924 m .79702 .77356 L .76988 .76738 L p .707 .577 .707 r
F P
0 g
s
.51223 .2423 m .50398 .74323 L .45904 .74367 L p .707 .577 .707 r
F P
0 g
s
.64615 .64527 m .64549 .58962 L .6329 .582 L p .707 .577 .707 r
F P
0 g
s
.68852 .72312 m .68048 .73881 L .7048 .75655 L p .707 .577 .707 r
F P
0 g
s
.65537 .67132 m .65775 .70855 L .67874 .71317 L p .707 .577 .707 r
F P
0 g
s
.68048 .73881 m .68852 .72312 L .67029 .70463 L p .707 .577 .707 r
F P
0 g
s
.82001 .66416 m .82238 .70139 L .83874 .6937 L p .707 .577 .707 r
F P
0 g
s
.83874 .6937 m .83637 .65647 L .82001 .66416 L p .707 .577 .707 r
F P
0 g
s
.67029 .70463 m .66225 .72031 L .68048 .73881 L p .707 .577 .707 r
F P
0 g
s
.79702 .77356 m .78898 .78924 L .8116 .78973 L p .707 .577 .707 r
F P
0 g
s
.8116 .78973 m .81963 .77405 L .79702 .77356 L p .707 .577 .707 r
F P
0 g
s
.6329 .582 m .63355 .63765 L .64615 .64527 L p .707 .577 .707 r
F P
0 g
s
.82681 .58329 m .82746 .63894 L .83454 .63063 L p .707 .577 .707 r
F P
0 g
s
.83454 .63063 m .83389 .57499 L .82681 .58329 L p .707 .577 .707 r
F P
0 g
s
.65775 .70855 m .65537 .67132 L .64283 .66489 L p .707 .577 .707 r
F P
0 g
s
.66225 .72031 m .67029 .70463 L .65994 .68718 L p .707 .577 .707 r
F P
0 g
s
.64283 .66489 m .6452 .70212 L .65775 .70855 L p .707 .577 .707 r
F P
0 g
s
.63355 .63765 m .6329 .582 L .63001 .57363 L p .707 .577 .707 r
F P
0 g
s
.65994 .68718 m .65191 .70287 L .66225 .72031 L p .707 .577 .707 r
F P
0 g
s
.83637 .65647 m .83874 .6937 L .84583 .68566 L p .707 .577 .707 r
F P
0 g
s
.84583 .68566 m .84346 .64843 L .83637 .65647 L p .707 .577 .707 r
F P
0 g
s
.81963 .77405 m .8116 .78973 L .82747 .78448 L p .707 .577 .707 r
F P
0 g
s
.82747 .78448 m .8355 .7688 L .81963 .77405 L p .707 .577 .707 r
F P
0 g
s
.63001 .57363 m .63066 .62928 L .63355 .63765 L p .707 .577 .707 r
F P
0 g
s
.83389 .57499 m .83454 .63063 L .83165 .62226 L p .707 .577 .707 r
F P
0 g
s
.83165 .62226 m .831 .56661 L .83389 .57499 L p .707 .577 .707 r
F P
0 g
s
.65191 .70287 m .65994 .68718 L .65849 .67251 L p .707 .577 .707 r
F P
0 g
s
.6452 .70212 m .64283 .66489 L .63996 .65728 L p .707 .577 .707 r
F P
0 g
s
.65849 .67251 m .65045 .68819 L .65191 .70287 L p .707 .577 .707 r
F P
0 g
s
.63996 .65728 m .64233 .69451 L .6452 .70212 L p .707 .577 .707 r
F P
0 g
s
.63066 .62928 m .63001 .57363 L .63709 .56533 L p .707 .577 .707 r
F P
0 g
s
.84346 .64843 m .84583 .68566 L .84297 .67805 L p .707 .577 .707 r
F P
0 g
s
.84297 .67805 m .84059 .64082 L .84346 .64843 L p .707 .577 .707 r
F P
0 g
s
.8355 .7688 m .82747 .78448 L .83505 .774 L p .707 .577 .707 r
F P
0 g
s
.83505 .774 m .84308 .75832 L .8355 .7688 L p .707 .577 .707 r
F P
0 g
s
.63709 .56533 m .63774 .62097 L .63066 .62928 L p .707 .577 .707 r
F P
0 g
s
.65045 .68819 m .65849 .67251 L .66607 .66203 L p .707 .577 .707 r
F P
0 g
s
.831 .56661 m .83165 .62226 L .81906 .61464 L p .707 .577 .707 r
F P
0 g
s
.81906 .61464 m .8184 .55899 L .831 .56661 L p .707 .577 .707 r
F P
0 g
s
.64233 .69451 m .63996 .65728 L .64705 .64924 L p .707 .577 .707 r
F P
0 g
s
.66607 .66203 m .65803 .67771 L .65045 .68819 L p .707 .577 .707 r
F P
0 g
s
.38282 .6188 m .38216 .56315 L .35099 .56162 L p .707 .577 .707 r
F P
0 g
s
.38216 .56315 m .38282 .6188 L .41465 .61769 L p .707 .577 .707 r
F P
0 g
s
.41465 .61769 m .414 .56204 L .38216 .56315 L p .707 .577 .707 r
F P
0 g
s
.64705 .64924 m .64943 .68646 L .64233 .69451 L p .707 .577 .707 r
F P
0 g
s
.414 .56204 m .41465 .61769 L .44403 .61404 L p .707 .577 .707 r
F P
0 g
s
.44403 .61404 m .44338 .5584 L .414 .56204 L p .707 .577 .707 r
F P
0 g
s
.63774 .62097 m .63709 .56533 L .65346 .5579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84308 .75832 m .83505 .774 L .83359 .75932 L p .707 .577 .707 r
F P
0 g
s
.83359 .75932 m .84163 .74364 L .84308 .75832 L p .707 .577 .707 r
F P
0 g
s
.35164 .61727 m .35099 .56162 L .32354 .5576 L p .707 .577 .707 r
F P
0 g
s
.35099 .56162 m .35164 .61727 L .38282 .6188 L p .707 .577 .707 r
F P
0 g
s
.84059 .64082 m .84297 .67805 L .83042 .67161 L p .707 .577 .707 r
F P
0 g
s
.83042 .67161 m .82805 .63439 L .84059 .64082 L p .707 .577 .707 r
F P
0 g
s
.44338 .5584 m .44403 .61404 L .46808 .60822 L p .707 .577 .707 r
F P
0 g
s
.46808 .60822 m .46743 .55258 L .44338 .5584 L p .707 .577 .707 r
F P
0 g
s
.39424 .68013 m .39186 .6429 L .36075 .64303 L p .707 .577 .707 r
F P
0 g
s
.39186 .6429 m .39424 .68013 L .42601 .67752 L p .707 .577 .707 r
F P
0 g
s
.42601 .67752 m .42364 .6403 L .39186 .6429 L p .707 .577 .707 r
F P
0 g
s
.65803 .67771 m .66607 .66203 L .68194 .65677 L p .707 .577 .707 r
F P
0 g
s
.65346 .5579 m .65411 .61355 L .63774 .62097 L p .707 .577 .707 r
F P
0 g
s
.8184 .55899 m .81906 .61464 L .798 .60852 L p .707 .577 .707 r
F P
0 g
s
.798 .60852 m .79735 .55288 L .8184 .55899 L p .707 .577 .707 r
F P
0 g
s
.42364 .6403 m .42601 .67752 L .45535 .67269 L p .707 .577 .707 r
F P
0 g
s
.45535 .67269 m .45297 .63547 L .42364 .6403 L p .707 .577 .707 r
F P
0 g
s
.32354 .5576 m .32419 .61325 L .35164 .61727 L p .707 .577 .707 r
F P
0 g
s
.64943 .68646 m .64705 .64924 L .66341 .64155 L p .707 .577 .707 r
F P
0 g
s
.32419 .61325 m .32354 .5576 L .30248 .55148 L p .707 .577 .707 r
F P
0 g
s
.36313 .68026 m .36075 .64303 L .33336 .64067 L p .707 .577 .707 r
F P
0 g
s
.36075 .64303 m .36313 .68026 L .39424 .68013 L p .707 .577 .707 r
F P
0 g
s
.68194 .65677 m .6739 .67246 L .65803 .67771 L p .707 .577 .707 r
F P
0 g
s
.65411 .61355 m .65346 .5579 L .67751 .55208 L p .707 .577 .707 r
F P
0 g
s
.66341 .64155 m .66579 .67877 L .64943 .68646 L p .707 .577 .707 r
F P
0 g
s
.45297 .63547 m .45535 .67269 L .47937 .66611 L p .707 .577 .707 r
F P
0 g
s
.47937 .66611 m .477 .62888 L .45297 .63547 L p .707 .577 .707 r
F P
0 g
s
.33336 .64067 m .33573 .6779 L .36313 .68026 L p .707 .577 .707 r
F P
0 g
s
.46743 .55258 m .46808 .60822 L .48445 .6008 L p .707 .577 .707 r
F P
0 g
s
.48445 .6008 m .4838 .54515 L .46743 .55258 L p .707 .577 .707 r
F P
0 g
s
.84163 .74364 m .83359 .75932 L .82325 .74188 L p .707 .577 .707 r
F P
0 g
s
.82325 .74188 m .83128 .7262 L .84163 .74364 L p .707 .577 .707 r
F P
0 g
s
.82805 .63439 m .83042 .67161 L .80942 .66699 L p .707 .577 .707 r
F P
0 g
s
.80942 .66699 m .80705 .62976 L .82805 .63439 L p .707 .577 .707 r
F P
0 g
s
.38983 .73598 m .39787 .7203 L .36983 .70505 L p .707 .577 .707 r
F P
0 g
s
.39787 .7203 m .38983 .73598 L .41884 .74725 L p .707 .577 .707 r
F P
0 g
s
.41884 .74725 m .42687 .73156 L .39787 .7203 L p .707 .577 .707 r
F P
0 g
s
.30248 .55148 m .30314 .60713 L .32419 .61325 L p .707 .577 .707 r
F P
0 g
s
.36179 .72073 m .36983 .70505 L .34551 .6873 L p .707 .577 .707 r
F P
0 g
s
.36983 .70505 m .36179 .72073 L .38983 .73598 L p .707 .577 .707 r
F P
0 g
s
.33573 .6779 m .33336 .64067 L .31236 .63604 L p .707 .577 .707 r
F P
0 g
s
.79735 .55288 m .798 .60852 L .77055 .6045 L p .707 .577 .707 r
F P
0 g
s
.77055 .6045 m .7699 .54885 L .79735 .55288 L p .707 .577 .707 r
F P
0 g
s
.42687 .73156 m .41884 .74725 L .44597 .75343 L p .707 .577 .707 r
F P
0 g
s
.44597 .75343 m .45401 .73774 L .42687 .73156 L p .707 .577 .707 r
F P
0 g
s
.67751 .55208 m .67816 .60773 L .65411 .61355 L p .707 .577 .707 r
F P
0 g
s
.6739 .67246 m .68194 .65677 L .70455 .65726 L p .707 .577 .707 r
F P
0 g
s
.30314 .60713 m .30248 .55148 L .28989 .54386 L p .707 .577 .707 r
F P
0 g
s
.34551 .6873 m .33747 .70299 L .36179 .72073 L p .707 .577 .707 r
F P
0 g
s
.66579 .67877 m .66341 .64155 L .68744 .63496 L p .707 .577 .707 r
F P
0 g
s
.31236 .63604 m .31474 .67327 L .33573 .6779 L p .707 .577 .707 r
F P
0 g
s
.33747 .70299 m .34551 .6873 L .32728 .66881 L p .707 .577 .707 r
F P
0 g
s
.67816 .60773 m .67751 .55208 L .70689 .54844 L p .707 .577 .707 r
F P
0 g
s
.477 .62888 m .47937 .66611 L .49573 .65842 L p .707 .577 .707 r
F P
0 g
s
.49573 .65842 m .49336 .62119 L .477 .62888 L p .707 .577 .707 r
F P
0 g
s
.70455 .65726 m .69652 .67294 L .6739 .67246 L p .707 .577 .707 r
F P
0 g
s
.32728 .66881 m .31924 .68449 L .33747 .70299 L p .707 .577 .707 r
F P
0 g
s
.7699 .54885 m .77055 .6045 L .73938 .60297 L p .707 .577 .707 r
F P
0 g
s
.73938 .60297 m .73873 .54732 L .7699 .54885 L p .707 .577 .707 r
F P
0 g
s
.68744 .63496 m .68981 .67219 L .66579 .67877 L p .707 .577 .707 r
F P
0 g
s
.80705 .62976 m .80942 .66699 L .78203 .66463 L p .707 .577 .707 r
F P
0 g
s
.78203 .66463 m .77966 .6274 L .80705 .62976 L p .707 .577 .707 r
F P
0 g
s
.83128 .7262 m .82325 .74188 L .80502 .72338 L p .707 .577 .707 r
F P
0 g
s
.80502 .72338 m .81306 .7077 L .83128 .7262 L p .707 .577 .707 r
F P
0 g
s
.45401 .73774 m .44597 .75343 L .46859 .75391 L p .707 .577 .707 r
F P
0 g
s
.46859 .75391 m .47662 .73823 L .45401 .73774 L p .707 .577 .707 r
F P
0 g
s
.28989 .54386 m .29054 .59951 L .30314 .60713 L p .707 .577 .707 r
F P
0 g
s
.4838 .54515 m .48445 .6008 L .49153 .59249 L p .707 .577 .707 r
F P
0 g
s
.49153 .59249 m .49088 .53684 L .4838 .54515 L p .707 .577 .707 r
F P
0 g
s
.70754 .60408 m .70689 .54844 L .73873 .54732 L p .707 .577 .707 r
F P
0 g
s
.70689 .54844 m .70754 .60408 L .67816 .60773 L p .707 .577 .707 r
F P
0 g
s
.73873 .54732 m .73938 .60297 L .70754 .60408 L p .707 .577 .707 r
F P
0 g
s
.31474 .67327 m .31236 .63604 L .29982 .62961 L p .707 .577 .707 r
F P
0 g
s
.69652 .67294 m .70455 .65726 L .73169 .66344 L p .707 .577 .707 r
F P
0 g
s
.31924 .68449 m .32728 .66881 L .31693 .65136 L p .707 .577 .707 r
F P
0 g
s
.68981 .67219 m .68744 .63496 L .71677 .63013 L p .707 .577 .707 r
F P
0 g
s
.29054 .59951 m .28989 .54386 L .287 .53549 L p .707 .577 .707 r
F P
0 g
s
.29982 .62961 m .30219 .66684 L .31474 .67327 L p .707 .577 .707 r
F P
0 g
s
.77966 .6274 m .78203 .66463 L .75092 .66475 L p .707 .577 .707 r
F P
0 g
s
.75092 .66475 m .74855 .62753 L .77966 .6274 L p .707 .577 .707 r
F P
0 g
s
.73169 .66344 m .72365 .67912 L .69652 .67294 L p .707 .577 .707 r
F P
0 g
s
.31693 .65136 m .3089 .66705 L .31924 .68449 L p .707 .577 .707 r
F P
0 g
s
.71677 .63013 m .71915 .66736 L .68981 .67219 L p .707 .577 .707 r
F P
0 g
s
.81306 .7077 m .80502 .72338 L .7807 .70564 L p .707 .577 .707 r
F P
0 g
s
.7807 .70564 m .78873 .68996 L .81306 .7077 L p .707 .577 .707 r
F P
0 g
s
.49336 .62119 m .49573 .65842 L .50282 .65038 L p .707 .577 .707 r
F P
0 g
s
.50282 .65038 m .50045 .61315 L .49336 .62119 L p .707 .577 .707 r
F P
0 g
s
.71915 .66736 m .71677 .63013 L .74855 .62753 L p .707 .577 .707 r
F P
0 g
s
.47662 .73823 m .46859 .75391 L .48446 .74866 L p .707 .577 .707 r
F P
0 g
s
.48446 .74866 m .49249 .73298 L .47662 .73823 L p .707 .577 .707 r
F P
0 g
s
.72365 .67912 m .73169 .66344 L .7607 .67471 L p .707 .577 .707 r
F P
0 g
s
.74855 .62753 m .75092 .66475 L .71915 .66736 L p .707 .577 .707 r
F P
0 g
s
.78873 .68996 m .7807 .70564 L .75266 .69039 L p .707 .577 .707 r
F P
0 g
s
.75266 .69039 m .7607 .67471 L .78873 .68996 L p .707 .577 .707 r
F P
0 g
s
.287 .53549 m .28765 .59114 L .29054 .59951 L p .707 .577 .707 r
F P
0 g
s
.7607 .67471 m .75266 .69039 L .72365 .67912 L p .707 .577 .707 r
F P
0 g
s
.49088 .53684 m .49153 .59249 L .48864 .58412 L p .707 .577 .707 r
F P
0 g
s
.48864 .58412 m .48799 .52847 L .49088 .53684 L p .707 .577 .707 r
F P
0 g
s
.3089 .66705 m .31693 .65136 L .31548 .63669 L p .707 .577 .707 r
F P
0 g
s
.30219 .66684 m .29982 .62961 L .29695 .622 L p .707 .577 .707 r
F P
0 g
s
.31548 .63669 m .30744 .65237 L .3089 .66705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29695 .622 m .29932 .65923 L .30219 .66684 L p .707 .577 .707 r
F P
0 g
s
.28765 .59114 m .287 .53549 L .29408 .52719 L p .707 .577 .707 r
F P
0 g
s
.50045 .61315 m .50282 .65038 L .49996 .64277 L p .707 .577 .707 r
F P
0 g
s
.49996 .64277 m .49758 .60554 L .50045 .61315 L p .707 .577 .707 r
F P
0 g
s
.49249 .73298 m .48446 .74866 L .49204 .73818 L p .707 .577 .707 r
F P
0 g
s
.49204 .73818 m .50007 .7225 L .49249 .73298 L p .707 .577 .707 r
F P
0 g
s
.29408 .52719 m .29473 .58283 L .28765 .59114 L p .707 .577 .707 r
F P
0 g
s
.30744 .65237 m .31548 .63669 L .32306 .62621 L p .707 .577 .707 r
F P
0 g
s
.48799 .52847 m .48864 .58412 L .47605 .5765 L p .707 .577 .707 r
F P
0 g
s
.47605 .5765 m .47539 .52085 L .48799 .52847 L p .707 .577 .707 r
F P
0 g
s
.29932 .65923 m .29695 .622 L .30404 .61396 L p .707 .577 .707 r
F P
0 g
s
.32306 .62621 m .31502 .64189 L .30744 .65237 L p .707 .577 .707 r
F P
0 g
s
.30404 .61396 m .30642 .65119 L .29932 .65923 L p .707 .577 .707 r
F P
0 g
s
.29473 .58283 m .29408 .52719 L .31045 .51976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50007 .7225 m .49204 .73818 L .49058 .7235 L p .707 .577 .707 r
F P
0 g
s
.49058 .7235 m .49862 .70782 L .50007 .7225 L p .707 .577 .707 r
F P
0 g
s
.49758 .60554 m .49996 .64277 L .48741 .63634 L p .707 .577 .707 r
F P
0 g
s
.48741 .63634 m .48504 .59911 L .49758 .60554 L p .707 .577 .707 r
F P
0 g
s
.31045 .51976 m .3111 .57541 L .29473 .58283 L p .707 .577 .707 r
F P
0 g
s
.47539 .52085 m .47605 .5765 L .45499 .57038 L p .707 .577 .707 r
F P
0 g
s
.45499 .57038 m .45434 .51473 L .47539 .52085 L p .707 .577 .707 r
F P
0 g
s
.31502 .64189 m .32306 .62621 L .33893 .62095 L p .707 .577 .707 r
F P
0 g
s
.30642 .65119 m .30404 .61396 L .3204 .60627 L p .707 .577 .707 r
F P
0 g
s
.33893 .62095 m .33089 .63664 L .31502 .64189 L p .707 .577 .707 r
F P
0 g
s
.3111 .57541 m .31045 .51976 L .3345 .51394 L p .707 .577 .707 r
F P
0 g
s
.3204 .60627 m .32278 .6435 L .30642 .65119 L p .707 .577 .707 r
F P
0 g
s
.49862 .70782 m .49058 .7235 L .48024 .70606 L p .707 .577 .707 r
F P
0 g
s
.48024 .70606 m .48827 .69038 L .49862 .70782 L p .707 .577 .707 r
F P
0 g
s
.48504 .59911 m .48741 .63634 L .46641 .63171 L p .707 .577 .707 r
F P
0 g
s
.46641 .63171 m .46404 .59448 L .48504 .59911 L p .707 .577 .707 r
F P
0 g
s
.45434 .51473 m .45499 .57038 L .42754 .56636 L p .707 .577 .707 r
F P
0 g
s
.42754 .56636 m .42688 .51071 L .45434 .51473 L p .707 .577 .707 r
F P
0 g
s
.3345 .51394 m .33515 .56959 L .3111 .57541 L p .707 .577 .707 r
F P
0 g
s
.33089 .63664 m .33893 .62095 L .36154 .62144 L p .707 .577 .707 r
F P
0 g
s
.32278 .6435 m .3204 .60627 L .34443 .59969 L p .707 .577 .707 r
F P
0 g
s
.33515 .56959 m .3345 .51394 L .36388 .51029 L p .707 .577 .707 r
F P
0 g
s
.36154 .62144 m .35351 .63712 L .33089 .63664 L p .707 .577 .707 r
F P
0 g
s
.42688 .51071 m .42754 .56636 L .39637 .56483 L p .707 .577 .707 r
F P
0 g
s
.39637 .56483 m .39571 .50918 L .42688 .51071 L p .707 .577 .707 r
F P
0 g
s
.34443 .59969 m .3468 .63692 L .32278 .6435 L p .707 .577 .707 r
F P
0 g
s
.46404 .59448 m .46641 .63171 L .43902 .62935 L p .707 .577 .707 r
F P
0 g
s
.43902 .62935 m .43665 .59212 L .46404 .59448 L p .707 .577 .707 r
F P
0 g
s
.48827 .69038 m .48024 .70606 L .46201 .68756 L p .707 .577 .707 r
F P
0 g
s
.46201 .68756 m .47004 .67188 L .48827 .69038 L p .707 .577 .707 r
F P
0 g
s
.36453 .56594 m .36388 .51029 L .39571 .50918 L p .707 .577 .707 r
F P
0 g
s
.36388 .51029 m .36453 .56594 L .33515 .56959 L p .707 .577 .707 r
F P
0 g
s
.39571 .50918 m .39637 .56483 L .36453 .56594 L p .707 .577 .707 r
F P
0 g
s
.35351 .63712 m .36154 .62144 L .38868 .62762 L p .707 .577 .707 r
F P
0 g
s
.3468 .63692 m .34443 .59969 L .37376 .59486 L p .707 .577 .707 r
F P
0 g
s
.38868 .62762 m .38064 .6433 L .35351 .63712 L p .707 .577 .707 r
F P
0 g
s
.43665 .59212 m .43902 .62935 L .40791 .62948 L p .707 .577 .707 r
F P
0 g
s
.40791 .62948 m .40554 .59225 L .43665 .59212 L p .707 .577 .707 r
F P
0 g
s
.37376 .59486 m .37614 .63208 L .3468 .63692 L p .707 .577 .707 r
F P
0 g
s
.47004 .67188 m .46201 .68756 L .43769 .66982 L p .707 .577 .707 r
F P
0 g
s
.43769 .66982 m .44572 .65414 L .47004 .67188 L p .707 .577 .707 r
F P
0 g
s
.37614 .63208 m .37376 .59486 L .40554 .59225 L p .707 .577 .707 r
F P
0 g
s
.38064 .6433 m .38868 .62762 L .41769 .63889 L p .707 .577 .707 r
F P
0 g
s
.40554 .59225 m .40791 .62948 L .37614 .63208 L p .707 .577 .707 r
F P
0 g
s
.44572 .65414 m .43769 .66982 L .40965 .65457 L p .707 .577 .707 r
F P
0 g
s
.40965 .65457 m .41769 .63889 L .44572 .65414 L p .707 .577 .707 r
F P
0 g
s
.41769 .63889 m .40965 .65457 L .38064 .6433 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo`d008Eo
o`00Ogoo30001UYF00<005YFFUH015YF2@00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001fOol0079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00IJEP@0079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eo
o`00JWoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001ZOol0
06Moo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001WOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0004FUH9
0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`P000AJEP03001JEUYF009JEPP000IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
G7oo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000aJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0055oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0047oo3`00Agoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool400000eYF001J
EP07FUH00`00FUIJEP02FUH8000oOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000hOol0055oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003Aoo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF1@001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
<Goo001AOol00`00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUH000040002FUH80004FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo00<005YF0000
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF1`00
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP@0009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00DGoo00@005YF001JEP8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001J
EUYFFUH005YF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol01P00FUH00000FUH000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000EJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP090004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;goo0015Ool90004Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00
?Goo200015YF00<005YFFUH00UYF1`0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000eOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEPL000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000_Ool0035oo`@0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000_Ool002moo`<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH2000_Ool002eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00800003FUH0000002moo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000_Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000_Ool0
02Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF000040001EYF00<005YFFUH00UYF00<005YF0000;goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH015YF3`0025YF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00P000AJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUH0000_Ool002Yoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP05FUH30005FUH40003FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH00UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01@00<7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001EYF1`00
15YF00<005YFFUH01UYF0`000eYF100000=JEP00FUH01EYF00@005YFFUIJEP800003FUH0000000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH500000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YF00003`002EYF1@001EYF00<005YFFUH015YF00<0
05YFFUH00UYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH200000eYF001JEP06FUH00`00FUIJ
EP04FUH20006FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF0000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEPH00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
0P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00H005YFFUIJEP00FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP0200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01P00FUH00000FUH000MJEP80009JEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP03000015YF001JEP000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002eoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@00
00=JEP0000000`000UYF200000=JEP0000000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000IJEP03001JEP00008000IJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH00000;Goo000ZOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YF000010000UYF
00<005YFFUH015YF00@005YF000000=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01@00FUIJEUYF00001UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000]Ool002Yoo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP04FUHN0003
FUH01000FUIJEP00;Goo000ZOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YF00001eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000IJEP@000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000=JEP03
001JEUYF00=JEP<000Uoo`@000EJEP@0009JEP8002aoo`00:Woo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUH00000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF009J
EP03001JEUYF00=JEP@000MJEP03001JEUYF00IJEP8000=oo`@0009JEP03001JEUYF00AJEP04001J
EUYFFUH4000/Ool002Yoo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUH0000;0002FUH00`00FUIJ
EP07FUH00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002Yoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUH0000B00000eYF001JEP08FUH01@00FUIJEUYF00000UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00FUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0100025YF00D005YFFUIJEP0000IJEP03
001JEUYF00AJEP03001JEUYF009JEP<002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH04@0000=JEP00FUH01EYF0`000UYF00<005YFFUH015YF1P00
0eYF00<005YFFUH025YF0`0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP090004FUH00`00FUIJ
EP06FUH01000FUIJEUYF0`001UYF0P000UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF0P00
1EYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000EJEP00001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00EJEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00:goo00D005YFFUIJEP0000EJ
EP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01P00FUH00000FUH000IJEPH000=JEP03001JEUYF00UJEP03001JEP0000EJEP03001JEUYF
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH0
05YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0P002UYF00<005YF00001UYF
00<005YFFUH00UYF0P00;Goo000/Ool200000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH20006FUH00`00FUH0
00020004FUH00`00FUIJEP09FUH01000FUIJEP000eYF00<005YF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@0000AJEP00FUH000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000MJEP04001JEP000006FUH01000FUIJEUYF0P00;Woo
000^Ool30002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00D0
05YFFUIJEP00009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP@00003FUH005YF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000<7oo000aOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001eYF0P0015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@0
05YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF0003
FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@0
05YFFUIJEP<0039oo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP05001JEUYFFUH00008FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`000eYF00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YF000000MJEP<003Eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEP00009J
EP04001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00<007oo
Ool0<goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF0P0025YF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0002FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000goo001JEP04FUH00`00FUH0000dOol002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00EJEP8000IJEP03001JEUYF00UJEP03001JEUYF00EJEP06001JEP00001J
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00P00
15YF00<005YFFUH04P002goo00D005YFFUIJEP0000=JEP03001oogoo035oo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH000UJEP8000AJEP03001JEUYF00UJEP03001JEUYF00EJEP80
009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP03001JEUYF
00=JEP03001JEP00008000Uoo`D000eoo`800003FUH005YF00=JEP03001oogoo031oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF7@0015YF00<005YFFUH00`001eYF00@005YF
0000009JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000=JEP@000EJEP800003FUH007oo00Qoo`D000moo`03001J
EUYF00AJEP03001oogoo02moo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@0
00AJEP03001JEUYF009JEP<000Yoo`D0009JEP<00005FUH005YFFUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`002eYF00<005YFFUH01UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP<000Yoo`D0011oo`03001JEUYF00AJ
EP03001oogoo02ioo`00;Goo00@005YFFUH000=JEP03001JEUYF00=JEPD000MJEP03001JEUYF00EJ
EP8000Aoo`@00003FUH005YF00EJEP04001JEP000002FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF0P002UYF00<005YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001eYF00D005YFFUIJEP0000=JEP03001oogoo00Qoo`<0019oo`03001J
EUYF009JEP03001JEP0002moo`00;Goo00@005YFFUH000=JEP03001JEP0000@000Aoo`@0009JEP03
001JEUYF00MJEPD000EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH200000eYF
001JEP07FUH50005FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0MOol01000
FUIJEP000UYF00<007ooOol0;Goo000^Ool00`00FUH00003FUH200000eYF001JEP02FUH<0007FUH0
1@00FUIJEUYF00001UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP<000QJEP03
001JEUYF009JEPl000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000MJEP04001JEP000006FUH2000NOol00`00FUH00003FUH00`00Oomoo`0/Ool002ioo`04
001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00`001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP04001JEUYF0008FUH00`00Oomoo`0LOol0
0`00FUIJEP02FUH00`00Oomoo`0/Ool002ioo`06001JEP00001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF100000=JEP00FUH01UYF0P000UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YFFUH030001UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH0
0P001UYF0`007Goo00<005YFFUH00UYF00<007ooOol0:goo000^Ool3000015YF001JEP000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH01000FUIJEP002eYF2@00
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF
FUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2000]Ool002ioo`04001JEP000002FUH01000
FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00<005YF00000P001UYF00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH010001EYF10000UYF00<005YFFUH00eYF00<005YF0000
0P0035YF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP8001]oo`05001JEP00FUH0000]Ool002ioo`04
001JEP000003FUH01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00D005YF
FUIJEP0000IJEP03001JEP00009JEP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEPX0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000MJEP03001JEUYF009JEP800003FUH005YF
00IJEP03001JEUYF00=JEP@000MJEP8001Uoo`05001JEP00FUH0000]Ool002ioo`03001JEP0000AJ
EP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJ
EP02FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF3@0015YF00@005YFFUH0
00UJEP8001Qoo`04001JEUYF000]Ool002moo`<000AJEP03001JEP0000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH40003Ool01@00FUIJEP00FUH00P0025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0P000goo1P000UYF0`0000AJEP00FUIJEP<000IJEP03001JEUYF008001Ioo`04001JEUYF000]
Ool0035oo`06001JEUYFFUH005YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000IJEP03001oogoo009oo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000004FUH50002
FUH00`00FUIJEP04FUH00`00FUH00002000015YF000007oo0P0015YF00<005YFFUH00UYF0`004goo
00<005YF0000;Woo000bOol00`00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
00000goo001JEP03FUH00`00FUH00003Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF0P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`000goo0P0000=JEP00FUH01eYF1@00
3Woo0`00;Woo000bOol00`00FUH00004FUH00`00Oomoo`0B000;Ool01@00FUIJEUYF00000UYF00<0
07ooOol00P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001EYF00<005YFFUH015YF00<005YF
FUH00UYF0`001Goo0`001eYF00<005YFFUH00UYF1`001Goo0P0000=JEP00Ool0;Woo000cOol00`00
FUIJEP04FUH00`00Oomoo`0:Ool5000>Ool30004FUH01000Ool0000015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000Qoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00D0009JEP8002moo`00=7oo00<005YFFUH015YF00<007oo
Ool02Goo1@0047oo00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000`000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002Woo0`0000=JEP00FUH01eYF
00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Woo000eOol00`00FUIJEP02FUH01000FUH0
00002Goo1@004Goo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH0009JEP800003FUH005YF00EJEP03001JEUYF009JEP8000ioo`<000MJEP03001JEUYF
00=JEP04001JEUYFFUH2000`Ool003Eoo`03001JEUYF009JEP05001JEUYFFUH00009Ool3000COol0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH01000
FUH000001UYF00@005YFFUIJEP80019oo`@0009JEP03001JEUYF00=JEP03001JEUYF00<0035oo`00
=Woo00@005YFFUH000EJEP03001oogoo01eoo`06001JEUYF001JEP0015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YF000001Qoo`/0
03Aoo`00=goo00<005YF00001UYF0P007Woo0P000eYF0P000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`00>7oo00<005YFFUH01eYF00<007oo
Ool077oo00H005YFFUIJEP00Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF00000007FUH3001LOol0
03Uoo`8000IJEP04001JEP00000MOol01@00FUIJEUYF00000Woo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
0eYF0P001eYF00<007ooOol0FWoo000kOol00`00FUIJEP03FUH01000FUIJEUYF0P006goo00<005YF
FUH00P0017oo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00@005YFFUIJEPP00003Ool005YF00AJEP03001JEP0005]oo`00?7oo00D0
05YFFUIJEP0000IJEP8001Yoo`04001JEP000007Ool300000eYF001JEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000002Woo00D005YFFUIJEP00
00=JEP03001oogoo05Qoo`00?Goo0P0000=JEP00FUH01eYF0P0067oo0P000UYF00<007ooOol01goo
100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10003Goo
0P0000=JEP00FUH00eYF00<007ooOol0Egoo000oOol00`00FUIJEP07FUH01000FUH000005goo00@0
05YFFUH000eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000moo`03001JEUYF00AJEP03001oogoo05Ioo`00@7oo0P001eYF00@005YFFUIJEP8001Eoo`03
001JEP0001Aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`03001JEUYF
00AJEP03001oogoo05Eoo`00@Woo0P0015YF00<005YFFUH015YF0P004goo00<005YF000077oo6P00
0UYF00<007ooOol01goo1@004Goo00<005YFFUH00UYF00<005YF0000EWoo0014Ool20002FUH00`00
FUIJEP06FUH5000>Ool2000bOol01000FUIJEP0015YF00<007ooOol01goo0`004Woo00<005YFFUH0
0UYF00<005YF0000EWoo0016Ool30008FUH00`00FUIJEP02FUH70005Ool4000cOol20006FUH2000M
Ool01000FUIJEP000eYF00<007ooOol0Dgoo0019Ool30005FUH00`00FUIJEP05FUH01000FUIJEUYF
1@000UYF00<007ooOol0<goo00<005YFFUH01UYF00<007ooOol06goo00<005YF00000eYF00<007oo
Ool0Dgoo001<Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=goo0P001UYF
0`0077oo00<005YFFUH00eYF00<007ooOol0DWoo001?Ool30006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000>Goo00<005YFFUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2001DOol0059oo`@0
009JEP03001JEUYF00=JEP03001JEUYF008003]oo`05001JEUYFFUH00004FUH2000JOol01000FUIJ
EUYF0P00E7oo001FOol;000nOol30007FUH2000IOol01@00FUH005YF0000E7oo002QOol00`00FUIJ
EP07FUH2000GOol01@00FUH005YF0000E7oo002ROol20006FUH00`00FUIJEP02000FOol01000FUIJ
EP00E7oo002TOol20004FUH00`00FUIJEP02FUH3000COol00`00FUH0001EOol00:Ioo`800003FUH0
05YF00MJEP<0011oo`03001JEP0005Eoo`00Z7oo0`001eYF00<005YFFUH010002Woo0P0000=JEP00
Ool0EGoo002[Ool20005FUH00`00FUIJEP04FUH:0002FUH2001FOol00:eoo`<00003FUH005YF00MJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05Eoo`00/7oo0`001eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00/goo10000UYF00<005YFFUH00eYF00<005YFFUH00`00F7oo002gOol;
001KOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58862 .74898 m .58797 .69333 L .5568 .6918 L p .707 .577 .707 r
F P
0 g
s
.58797 .69333 m .58862 .74898 L .62045 .74787 L p .707 .577 .707 r
F P
0 g
s
.62045 .74787 m .6198 .69222 L .58797 .69333 L p .707 .577 .707 r
F P
0 g
s
.6198 .69222 m .62045 .74787 L .64983 .74422 L p .707 .577 .707 r
F P
0 g
s
.64983 .74422 m .64918 .68858 L .6198 .69222 L p .707 .577 .707 r
F P
0 g
s
.55745 .74745 m .5568 .6918 L .52934 .68778 L p .707 .577 .707 r
F P
0 g
s
.5568 .6918 m .55745 .74745 L .58862 .74898 L p .707 .577 .707 r
F P
0 g
s
.64918 .68858 m .64983 .74422 L .67389 .7384 L p .707 .577 .707 r
F P
0 g
s
.67389 .7384 m .67323 .68276 L .64918 .68858 L p .707 .577 .707 r
F P
0 g
s
.60004 .80745 m .59767 .77022 L .56656 .77035 L p .707 .577 .707 r
F P
0 g
s
.59767 .77022 m .60004 .80745 L .63182 .80484 L p .707 .577 .707 r
F P
0 g
s
.63182 .80484 m .62944 .76761 L .59767 .77022 L p .707 .577 .707 r
F P
0 g
s
.62944 .76761 m .63182 .80484 L .66115 .80001 L p .707 .577 .707 r
F P
0 g
s
.66115 .80001 m .65878 .76278 L .62944 .76761 L p .707 .577 .707 r
F P
0 g
s
.52934 .68778 m .53 .74343 L .55745 .74745 L p .707 .577 .707 r
F P
0 g
s
.53 .74343 m .52934 .68778 L .50829 .68166 L p .707 .577 .707 r
F P
0 g
s
.56893 .80757 m .56656 .77035 L .53917 .76798 L p .707 .577 .707 r
F P
0 g
s
.56656 .77035 m .56893 .80757 L .60004 .80745 L p .707 .577 .707 r
F P
0 g
s
.65878 .76278 m .66115 .80001 L .68518 .79343 L p .707 .577 .707 r
F P
0 g
s
.68518 .79343 m .6828 .7562 L .65878 .76278 L p .707 .577 .707 r
F P
0 g
s
.53917 .76798 m .54154 .80521 L .56893 .80757 L p .707 .577 .707 r
F P
0 g
s
.67323 .68276 m .67389 .7384 L .69026 .73098 L p .707 .577 .707 r
F P
0 g
s
.69026 .73098 m .6896 .67533 L .67323 .68276 L p .707 .577 .707 r
F P
0 g
s
.59564 .86384 m .60367 .84815 L .57564 .8329 L p .707 .577 .707 r
F P
0 g
s
.60367 .84815 m .59564 .86384 L .62464 .8751 L p .707 .577 .707 r
F P
0 g
s
.62464 .8751 m .63268 .85942 L .60367 .84815 L p .707 .577 .707 r
F P
0 g
s
.50829 .68166 m .50894 .73731 L .53 .74343 L p .707 .577 .707 r
F P
0 g
s
.5676 .84859 m .57564 .8329 L .55131 .81516 L p .707 .577 .707 r
F P
0 g
s
.57564 .8329 m .5676 .84859 L .59564 .86384 L p .707 .577 .707 r
F P
0 g
s
.54154 .80521 m .53917 .76798 L .51817 .76336 L p .707 .577 .707 r
F P
0 g
s
.63268 .85942 m .62464 .8751 L .65178 .88128 L p .707 .577 .707 r
F P
0 g
s
.65178 .88128 m .65982 .8656 L .63268 .85942 L p .707 .577 .707 r
F P
0 g
s
.50894 .73731 m .50829 .68166 L .4957 .67404 L p .707 .577 .707 r
F P
0 g
s
.55131 .81516 m .54328 .83084 L .5676 .84859 L p .707 .577 .707 r
F P
0 g
s
.51817 .76336 m .52054 .80059 L .54154 .80521 L p .707 .577 .707 r
F P
0 g
s
.54328 .83084 m .55131 .81516 L .53309 .79666 L p .707 .577 .707 r
F P
0 g
s
.6828 .7562 m .68518 .79343 L .70154 .78574 L p .707 .577 .707 r
F P
0 g
s
.70154 .78574 m .69916 .74851 L .6828 .7562 L p .707 .577 .707 r
F P
0 g
s
.53309 .79666 m .52505 .81235 L .54328 .83084 L p .707 .577 .707 r
F P
0 g
s
.65982 .8656 m .65178 .88128 L .67439 .88177 L p .707 .577 .707 r
F P
0 g
s
.67439 .88177 m .68243 .86609 L .65982 .8656 L p .707 .577 .707 r
F P
0 g
s
.4957 .67404 m .49635 .72969 L .50894 .73731 L p .707 .577 .707 r
F P
0 g
s
.6896 .67533 m .69026 .73098 L .69734 .72267 L p .707 .577 .707 r
F P
0 g
s
.69734 .72267 m .69669 .66702 L .6896 .67533 L p .707 .577 .707 r
F P
0 g
s
.52054 .80059 m .51817 .76336 L .50562 .75693 L p .707 .577 .707 r
F P
0 g
s
.52505 .81235 m .53309 .79666 L .52274 .77922 L p .707 .577 .707 r
F P
0 g
s
.50562 .75693 m .508 .79415 L .52054 .80059 L p .707 .577 .707 r
F P
0 g
s
.49635 .72969 m .4957 .67404 L .4928 .66567 L p .707 .577 .707 r
F P
0 g
s
.52274 .77922 m .5147 .79491 L .52505 .81235 L p .707 .577 .707 r
F P
0 g
s
.69916 .74851 m .70154 .78574 L .70863 .77769 L p .707 .577 .707 r
F P
0 g
s
.70863 .77769 m .70626 .74047 L .69916 .74851 L p .707 .577 .707 r
F P
0 g
s
.68243 .86609 m .67439 .88177 L .69026 .87652 L p .707 .577 .707 r
F P
0 g
s
.69026 .87652 m .6983 .86083 L .68243 .86609 L p .707 .577 .707 r
F P
0 g
s
.4928 .66567 m .49346 .72132 L .49635 .72969 L p .707 .577 .707 r
F P
0 g
s
.69669 .66702 m .69734 .72267 L .69444 .7143 L p .707 .577 .707 r
F P
0 g
s
.69444 .7143 m .69379 .65865 L .69669 .66702 L p .707 .577 .707 r
F P
0 g
s
.5147 .79491 m .52274 .77922 L .52128 .76454 L p .707 .577 .707 r
F P
0 g
s
.508 .79415 m .50562 .75693 L .50276 .74932 L p .707 .577 .707 r
F P
0 g
s
.48484 .82193 m .49309 .321 L .44909 .31759 L p .707 .577 .707 r
F P
0 g
s
.52128 .76454 m .51325 .78023 L .5147 .79491 L p .707 .577 .707 r
F P
0 g
s
.50276 .74932 m .50513 .78654 L .508 .79415 L p .707 .577 .707 r
F P
0 g
s
.49346 .72132 m .4928 .66567 L .49989 .65737 L p .707 .577 .707 r
F P
0 g
s
.49989 .65737 m .50054 .71301 L .49346 .72132 L p .707 .577 .707 r
F P
0 g
s
.51325 .78023 m .52128 .76454 L .52886 .75407 L p .707 .577 .707 r
F P
0 g
s
.50513 .78654 m .50276 .74932 L .50985 .74127 L p .707 .577 .707 r
F P
0 g
s
.52886 .75407 m .52083 .76975 L .51325 .78023 L p .707 .577 .707 r
F P
0 g
s
.50985 .74127 m .51222 .7785 L .50513 .78654 L p .707 .577 .707 r
F P
0 g
s
.50054 .71301 m .49989 .65737 L .51625 .64994 L p .707 .577 .707 r
F P
0 g
s
.52083 .76975 m .52886 .75407 L .54474 .74881 L p .707 .577 .707 r
F P
0 g
s
.51625 .64994 m .51691 .70559 L .50054 .71301 L p .707 .577 .707 r
F P
0 g
s
.51222 .7785 m .50985 .74127 L .52621 .73359 L p .707 .577 .707 r
F P
0 g
s
.54474 .74881 m .5367 .76449 L .52083 .76975 L p .707 .577 .707 r
F P
0 g
s
.51691 .70559 m .51625 .64994 L .54031 .64412 L p .707 .577 .707 r
F P
0 g
s
.52621 .73359 m .52858 .77081 L .51222 .7785 L p .707 .577 .707 r
F P
0 g
s
.54031 .64412 m .54096 .69977 L .51691 .70559 L p .707 .577 .707 r
F P
0 g
s
.49309 .321 m .48484 .82193 L .52978 .8215 L p .707 .577 .707 r
F P
0 g
s
.52858 .77081 m .52621 .73359 L .55023 .727 L p .707 .577 .707 r
F P
0 g
s
.5367 .76449 m .54474 .74881 L .56735 .7493 L p .707 .577 .707 r
F P
0 g
s
.56735 .7493 m .55931 .76498 L .5367 .76449 L p .707 .577 .707 r
F P
0 g
s
.55023 .727 m .55261 .76423 L .52858 .77081 L p .707 .577 .707 r
F P
0 g
s
.52978 .8215 m .53803 .32057 L .49309 .321 L p .707 .577 .707 r
F P
0 g
s
.54096 .69977 m .54031 .64412 L .56969 .64047 L p .707 .577 .707 r
F P
0 g
s
.56969 .64047 m .57034 .69612 L .54096 .69977 L p .707 .577 .707 r
F P
0 g
s
.55931 .76498 m .56735 .7493 L .59448 .75548 L p .707 .577 .707 r
F P
0 g
s
.55261 .76423 m .55023 .727 L .57957 .72217 L p .707 .577 .707 r
F P
0 g
s
.59448 .75548 m .58645 .77116 L .55931 .76498 L p .707 .577 .707 r
F P
0 g
s
.57957 .72217 m .58194 .7594 L .55261 .76423 L p .707 .577 .707 r
F P
0 g
s
.53803 .32057 m .52978 .8215 L .57125 .81725 L p .707 .577 .707 r
F P
0 g
s
.57034 .69612 m .56969 .64047 L .60152 .63936 L p .707 .577 .707 r
F P
0 g
s
.60152 .63936 m .60217 .69501 L .57034 .69612 L p .707 .577 .707 r
F P
0 g
s
.57125 .81725 m .5795 .31632 L .53803 .32057 L p .707 .577 .707 r
F P
0 g
s
.44083 .81852 m .44909 .31759 L .41033 .31066 L p .707 .577 .707 r
F P
0 g
s
.44909 .31759 m .44083 .81852 L .48484 .82193 L p .707 .577 .707 r
F P
0 g
s
.70626 .74047 m .70863 .77769 L .70576 .77008 L p .707 .577 .707 r
F P
0 g
s
.70576 .77008 m .70339 .73286 L .70626 .74047 L p .707 .577 .707 r
F P
0 g
s
.6983 .86083 m .69026 .87652 L .69784 .86604 L p .707 .577 .707 r
F P
0 g
s
.69784 .86604 m .70588 .85035 L .6983 .86083 L p .707 .577 .707 r
F P
0 g
s
.58194 .7594 m .57957 .72217 L .61135 .71956 L p .707 .577 .707 r
F P
0 g
s
.58645 .77116 m .59448 .75548 L .62349 .76674 L p .707 .577 .707 r
F P
0 g
s
.61135 .71956 m .61372 .75679 L .58194 .7594 L p .707 .577 .707 r
F P
0 g
s
.62349 .76674 m .61546 .78243 L .58645 .77116 L p .707 .577 .707 r
F P
0 g
s
.5795 .31632 m .57125 .81725 L .60521 .80961 L p .707 .577 .707 r
F P
0 g
s
.63269 .64089 m .63334 .69654 L .60217 .69501 L p .707 .577 .707 r
F P
0 g
s
.60217 .69501 m .60152 .63936 L .63269 .64089 L p .707 .577 .707 r
F P
0 g
s
.60521 .80961 m .61346 .30868 L .5795 .31632 L p .707 .577 .707 r
F P
0 g
s
.69379 .65865 m .69444 .7143 L .68185 .70668 L p .707 .577 .707 r
F P
0 g
s
.68185 .70668 m .6812 .65103 L .69379 .65865 L p .707 .577 .707 r
F P
0 g
s
.40208 .81159 m .41033 .31066 L .38061 .30088 L p .707 .577 .707 r
F P
0 g
s
.41033 .31066 m .40208 .81159 L .44083 .81852 L p .707 .577 .707 r
F P
0 g
s
.24561 .71084 m .24496 .65519 L .21379 .65366 L p .707 .577 .707 r
F P
0 g
s
.24496 .65519 m .24561 .71084 L .27745 .70973 L p .707 .577 .707 r
F P
0 g
s
.27745 .70973 m .27679 .65408 L .24496 .65519 L p .707 .577 .707 r
F P
0 g
s
.27679 .65408 m .27745 .70973 L .30683 .70608 L p .707 .577 .707 r
F P
0 g
s
.30683 .70608 m .30617 .65044 L .27679 .65408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70588 .85035 m .69784 .86604 L .69639 .85136 L p .707 .577 .707 r
F P
0 g
s
.69639 .85136 m .70442 .83568 L .70588 .85035 L p .707 .577 .707 r
F P
0 g
s
.21444 .70931 m .21379 .65366 L .18633 .64964 L p .707 .577 .707 r
F P
0 g
s
.21379 .65366 m .21444 .70931 L .24561 .71084 L p .707 .577 .707 r
F P
0 g
s
.70339 .73286 m .70576 .77008 L .69322 .76365 L p .707 .577 .707 r
F P
0 g
s
.69322 .76365 m .69084 .72642 L .70339 .73286 L p .707 .577 .707 r
F P
0 g
s
.30617 .65044 m .30683 .70608 L .33088 .70026 L p .707 .577 .707 r
F P
0 g
s
.33088 .70026 m .33023 .64462 L .30617 .65044 L p .707 .577 .707 r
F P
0 g
s
.64245 .71944 m .64483 .75666 L .61372 .75679 L p .707 .577 .707 r
F P
0 g
s
.61372 .75679 m .61135 .71956 L .64245 .71944 L p .707 .577 .707 r
F P
0 g
s
.65153 .78199 m .64349 .79768 L .61546 .78243 L p .707 .577 .707 r
F P
0 g
s
.61546 .78243 m .62349 .76674 L .65153 .78199 L p .707 .577 .707 r
F P
0 g
s
.61346 .30868 m .60521 .80961 L .62832 .79932 L p .707 .577 .707 r
F P
0 g
s
.62832 .79932 m .63657 .29839 L .61346 .30868 L p .707 .577 .707 r
F P
0 g
s
.25703 .77217 m .25466 .73494 L .22355 .73507 L p .707 .577 .707 r
F P
0 g
s
.25466 .73494 m .25703 .77217 L .28881 .76956 L p .707 .577 .707 r
F P
0 g
s
.28881 .76956 m .28644 .73233 L .25466 .73494 L p .707 .577 .707 r
F P
0 g
s
.6812 .65103 m .68185 .70668 L .6608 .70056 L p .707 .577 .707 r
F P
0 g
s
.6608 .70056 m .66015 .64491 L .6812 .65103 L p .707 .577 .707 r
F P
0 g
s
.28644 .73233 m .28881 .76956 L .31815 .76473 L p .707 .577 .707 r
F P
0 g
s
.31815 .76473 m .31577 .7275 L .28644 .73233 L p .707 .577 .707 r
F P
0 g
s
.18633 .64964 m .18699 .70529 L .21444 .70931 L p .707 .577 .707 r
F P
0 g
s
.18699 .70529 m .18633 .64964 L .16528 .64352 L p .707 .577 .707 r
F P
0 g
s
.22592 .7723 m .22355 .73507 L .19616 .73271 L p .707 .577 .707 r
F P
0 g
s
.22355 .73507 m .22592 .7723 L .25703 .77217 L p .707 .577 .707 r
F P
0 g
s
.37236 .80181 m .38061 .30088 L .36283 .28923 L p .707 .577 .707 r
F P
0 g
s
.38061 .30088 m .37236 .80181 L .40208 .81159 L p .707 .577 .707 r
F P
0 g
s
.31577 .7275 m .31815 .76473 L .34217 .75815 L p .707 .577 .707 r
F P
0 g
s
.34217 .75815 m .33979 .72092 L .31577 .7275 L p .707 .577 .707 r
F P
0 g
s
.19616 .73271 m .19853 .76993 L .22592 .7723 L p .707 .577 .707 r
F P
0 g
s
.33023 .64462 m .33088 .70026 L .34725 .69284 L p .707 .577 .707 r
F P
0 g
s
.34725 .69284 m .34659 .63719 L .33023 .64462 L p .707 .577 .707 r
F P
0 g
s
.70442 .83568 m .69639 .85136 L .68604 .83392 L p .707 .577 .707 r
F P
0 g
s
.68604 .83392 m .69408 .81823 L .70442 .83568 L p .707 .577 .707 r
F P
0 g
s
.69084 .72642 m .69322 .76365 L .67222 .75903 L p .707 .577 .707 r
F P
0 g
s
.67222 .75903 m .66985 .7218 L .69084 .72642 L p .707 .577 .707 r
F P
0 g
s
.25263 .82802 m .26066 .81234 L .23263 .79708 L p .707 .577 .707 r
F P
0 g
s
.26066 .81234 m .25263 .82802 L .28163 .83928 L p .707 .577 .707 r
F P
0 g
s
.28163 .83928 m .28967 .8236 L .26066 .81234 L p .707 .577 .707 r
F P
0 g
s
.16528 .64352 m .16593 .69917 L .18699 .70529 L p .707 .577 .707 r
F P
0 g
s
.22459 .81277 m .23263 .79708 L .2083 .77934 L p .707 .577 .707 r
F P
0 g
s
.23263 .79708 m .22459 .81277 L .25263 .82802 L p .707 .577 .707 r
F P
0 g
s
.19853 .76993 m .19616 .73271 L .17516 .72808 L p .707 .577 .707 r
F P
0 g
s
.66015 .64491 m .6608 .70056 L .63334 .69654 L p .707 .577 .707 r
F P
0 g
s
.63334 .69654 m .63269 .64089 L .66015 .64491 L p .707 .577 .707 r
F P
0 g
s
.28967 .8236 m .28163 .83928 L .30877 .84546 L p .707 .577 .707 r
F P
0 g
s
.30877 .84546 m .31681 .82978 L .28967 .8236 L p .707 .577 .707 r
F P
0 g
s
.16593 .69917 m .16528 .64352 L .15269 .6359 L p .707 .577 .707 r
F P
0 g
s
.2083 .77934 m .20027 .79503 L .22459 .81277 L p .707 .577 .707 r
F P
0 g
s
.17516 .72808 m .17753 .76531 L .19853 .76993 L p .707 .577 .707 r
F P
0 g
s
.20027 .79503 m .2083 .77934 L .19008 .76085 L p .707 .577 .707 r
F P
0 g
s
.33979 .72092 m .34217 .75815 L .35853 .75046 L p .707 .577 .707 r
F P
0 g
s
.35853 .75046 m .35615 .71323 L .33979 .72092 L p .707 .577 .707 r
F P
0 g
s
.63657 .29839 m .62832 .79932 L .63832 .7874 L p .707 .577 .707 r
F P
0 g
s
.63832 .7874 m .64657 .28647 L .63657 .29839 L p .707 .577 .707 r
F P
0 g
s
.19008 .76085 m .18204 .77653 L .20027 .79503 L p .707 .577 .707 r
F P
0 g
s
.66985 .7218 m .67222 .75903 L .64483 .75666 L p .707 .577 .707 r
F P
0 g
s
.64483 .75666 m .64245 .71944 L .66985 .7218 L p .707 .577 .707 r
F P
0 g
s
.69408 .81823 m .68604 .83392 L .66781 .81542 L p .707 .577 .707 r
F P
0 g
s
.66781 .81542 m .67585 .79974 L .69408 .81823 L p .707 .577 .707 r
F P
0 g
s
.31681 .82978 m .30877 .84546 L .33138 .84595 L p .707 .577 .707 r
F P
0 g
s
.33138 .84595 m .33942 .83027 L .31681 .82978 L p .707 .577 .707 r
F P
0 g
s
.15269 .6359 m .15334 .69155 L .16593 .69917 L p .707 .577 .707 r
F P
0 g
s
.34659 .63719 m .34725 .69284 L .35433 .68453 L p .707 .577 .707 r
F P
0 g
s
.35433 .68453 m .35368 .62888 L .34659 .63719 L p .707 .577 .707 r
F P
0 g
s
.17753 .76531 m .17516 .72808 L .16261 .72165 L p .707 .577 .707 r
F P
0 g
s
.18204 .77653 m .19008 .76085 L .17973 .7434 L p .707 .577 .707 r
F P
0 g
s
.35615 .71323 m .35853 .75046 L .36562 .74242 L p .707 .577 .707 r
F P
0 g
s
.36562 .74242 m .36325 .70519 L .35615 .71323 L p .707 .577 .707 r
F P
0 g
s
.36038 .69758 m .36275 .73481 L .35021 .72838 L p .707 .577 .707 r
F P
0 g
s
.35021 .72838 m .34783 .69115 L .36038 .69758 L p .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35107 .78241 L .35797 .79405 L p .707 .577 .707 r
F P
0 g
s
.35797 .79405 m .36142 .79986 L p .35827 .79956 L .707 .577 .707 r
F P
0 g
s
.34303 .7981 m .35797 .79405 L .35827 .79956 L .707 .577 .707 r
F
.36283 .28923 m .35875 .27683 L p .355 .73937 L F P
0 g
s
.35458 .79016 m .35532 .74536 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.35532 .74536 m .36283 .28923 L p .355 .73937 L .707 .577 .707 r
F P
0 g
s
.36325 .70519 m .36562 .74242 L .36275 .73481 L p .707 .577 .707 r
F P
0 g
s
.36275 .73481 m .36038 .69758 L .36325 .70519 L p .707 .577 .707 r
F P
0 g
s
.36283 .28923 m .35458 .79016 L .37236 .80181 L p .707 .577 .707 r
F P
0 g
s
.15334 .69155 m .15269 .6359 L .14979 .62753 L p .707 .577 .707 r
F P
0 g
s
.16261 .72165 m .16499 .75888 L .17753 .76531 L p .707 .577 .707 r
F P
0 g
s
.17973 .7434 m .17169 .75909 L .18204 .77653 L p .707 .577 .707 r
F P
0 g
s
.67585 .79974 m .66781 .81542 L .64349 .79768 L p .707 .577 .707 r
F P
0 g
s
.64349 .79768 m .65153 .78199 L .67585 .79974 L p .707 .577 .707 r
F P
0 g
s
.33942 .83027 m .33138 .84595 L .34726 .8407 L p .707 .577 .707 r
F P
0 g
s
.34726 .8407 m .35529 .82501 L .33942 .83027 L p .707 .577 .707 r
F P
0 g
s
.14979 .62753 m .15045 .68318 L .15334 .69155 L p .707 .577 .707 r
F P
0 g
s
.35368 .62888 m .35433 .68453 L .35143 .67616 L p .707 .577 .707 r
F P
0 g
s
.35143 .67616 m .35078 .62051 L .35368 .62888 L p .707 .577 .707 r
F P
0 g
s
.17169 .75909 m .17973 .7434 L .17827 .72872 L p .707 .577 .707 r
F P
0 g
s
.16499 .75888 m .16261 .72165 L .15975 .71404 L p .707 .577 .707 r
F P
0 g
s
.64657 .28647 m .63832 .7874 L .63423 .775 L p .707 .577 .707 r
F P
0 g
s
.63423 .775 m .64248 .27407 L .64657 .28647 L p .707 .577 .707 r
F P
0 g
s
.17827 .72872 m .17024 .74441 L .17169 .75909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15975 .71404 m .16212 .75127 L .16499 .75888 L p .707 .577 .707 r
F P
0 g
s
.15045 .68318 m .14979 .62753 L .15688 .61922 L p .707 .577 .707 r
F P
0 g
s
.35529 .82501 m .34726 .8407 L .35483 .83022 L p .707 .577 .707 r
F P
0 g
s
.35483 .83022 m .36287 .81454 L .35529 .82501 L p .707 .577 .707 r
F P
0 g
s
.35875 .27683 m .3505 .77776 L .35458 .79016 L p .707 .577 .707 r
F P
0 g
s
.3505 .77776 m .35875 .27683 L .36875 .26491 L p .707 .577 .707 r
F P
0 g
s
.15688 .61922 m .15753 .67487 L .15045 .68318 L p .707 .577 .707 r
F P
0 g
s
.17024 .74441 m .17827 .72872 L .18585 .71825 L p .707 .577 .707 r
F P
0 g
s
.35078 .62051 m .35143 .67616 L .33884 .66854 L p .707 .577 .707 r
F P
0 g
s
.33884 .66854 m .33819 .61289 L .35078 .62051 L p .707 .577 .707 r
F P
0 g
s
.16212 .75127 m .15975 .71404 L .16684 .706 L p .707 .577 .707 r
F P
0 g
s
.18585 .71825 m .17782 .73393 L .17024 .74441 L p .707 .577 .707 r
F P
0 g
s
.16684 .706 m .16921 .74323 L .16212 .75127 L p .707 .577 .707 r
F P
0 g
s
.15753 .67487 m .15688 .61922 L .17324 .6118 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64248 .27407 m .63423 .775 L .61646 .76335 L p .707 .577 .707 r
F P
0 g
s
.61646 .76335 m .62471 .26242 L .64248 .27407 L p .707 .577 .707 r
F P
0 g
s
.36287 .81454 m .35483 .83022 L .35338 .81554 L p .707 .577 .707 r
F P
0 g
s
.35338 .81554 m .36142 .79986 L .36287 .81454 L p .707 .577 .707 r
F P
0 g
s
.17324 .6118 m .1739 .66745 L .15753 .67487 L p .707 .577 .707 r
F P
0 g
s
.33819 .61289 m .33884 .66854 L .31779 .66242 L p .707 .577 .707 r
F P
0 g
s
.31779 .66242 m .31714 .60677 L .33819 .61289 L p .707 .577 .707 r
F P
0 g
s
.17782 .73393 m .18585 .71825 L .20173 .71299 L p .707 .577 .707 r
F P
0 g
s
.3605 .76584 m .36875 .26491 L .39186 .25462 L p .707 .577 .707 r
F P
0 g
s
.36875 .26491 m .3605 .76584 L .3505 .77776 L p .707 .577 .707 r
F P
0 g
s
.16921 .74323 m .16684 .706 L .1832 .69831 L p .707 .577 .707 r
F P
0 g
s
.20173 .71299 m .19369 .72868 L .17782 .73393 L p .707 .577 .707 r
F P
0 g
s
.1739 .66745 m .17324 .6118 L .1973 .60598 L p .707 .577 .707 r
F P
0 g
s
.1832 .69831 m .18557 .73554 L .16921 .74323 L p .707 .577 .707 r
F P
0 g
s
.36142 .79986 m .35338 .81554 L .34303 .7981 L p .707 .577 .707 r
F P
0 g
s
.34783 .69115 m .35021 .72838 L .32921 .72375 L p .707 .577 .707 r
F P
0 g
s
.32921 .72375 m .32684 .68652 L .34783 .69115 L p .707 .577 .707 r
F P
0 g
s
.31714 .60677 m .31779 .66242 L .29033 .6584 L p .707 .577 .707 r
F P
0 g
s
.29033 .6584 m .28968 .60275 L .31714 .60677 L p .707 .577 .707 r
F P
0 g
s
.1973 .60598 m .19795 .66163 L .1739 .66745 L p .707 .577 .707 r
F P
0 g
s
.19369 .72868 m .20173 .71299 L .22434 .71348 L p .707 .577 .707 r
F P
0 g
s
.62471 .26242 m .61646 .76335 L .58674 .75358 L p .707 .577 .707 r
F P
0 g
s
.58674 .75358 m .59499 .25265 L .62471 .26242 L p .707 .577 .707 r
F P
0 g
s
.18557 .73554 m .1832 .69831 L .20722 .69173 L p .707 .577 .707 r
F P
0 g
s
.19795 .66163 m .1973 .60598 L .22668 .60233 L p .707 .577 .707 r
F P
0 g
s
.22434 .71348 m .2163 .72916 L .19369 .72868 L p .707 .577 .707 r
F P
0 g
s
.28968 .60275 m .29033 .6584 L .25916 .65687 L p .707 .577 .707 r
F P
0 g
s
.25916 .65687 m .25851 .60122 L .28968 .60275 L p .707 .577 .707 r
F P
0 g
s
.20722 .69173 m .2096 .72895 L .18557 .73554 L p .707 .577 .707 r
F P
0 g
s
.32684 .68652 m .32921 .72375 L .30182 .72139 L p .707 .577 .707 r
F P
0 g
s
.30182 .72139 m .29944 .68416 L .32684 .68652 L p .707 .577 .707 r
F P
0 g
s
.39186 .25462 m .38361 .75555 L .3605 .76584 L p .707 .577 .707 r
F P
0 g
s
.38361 .75555 m .39186 .25462 L .42581 .24698 L p .707 .577 .707 r
F P
0 g
s
.35107 .78241 m .34303 .7981 L .32481 .7796 L p .707 .577 .707 r
F P
0 g
s
.32481 .7796 m .33284 .76392 L .35107 .78241 L p .707 .577 .707 r
F P
0 g
s
.22733 .65798 m .22668 .60233 L .25851 .60122 L p .707 .577 .707 r
F P
0 g
s
.22668 .60233 m .22733 .65798 L .19795 .66163 L p .707 .577 .707 r
F P
0 g
s
.25851 .60122 m .25916 .65687 L .22733 .65798 L p .707 .577 .707 r
F P
0 g
s
.72583 .65694 m .72517 .60129 L .694 .59976 L p .707 .577 .707 r
F P
0 g
s
.72517 .60129 m .72583 .65694 L .75766 .65583 L p .707 .577 .707 r
F P
0 g
s
.75766 .65583 m .75701 .60018 L .72517 .60129 L p .707 .577 .707 r
F P
0 g
s
.2163 .72916 m .22434 .71348 L .25148 .71966 L p .707 .577 .707 r
F P
0 g
s
.75701 .60018 m .75766 .65583 L .78704 .65219 L p .707 .577 .707 r
F P
0 g
s
.78704 .65219 m .78639 .59654 L .75701 .60018 L p .707 .577 .707 r
F P
0 g
s
.2096 .72895 m .20722 .69173 L .23656 .6869 L p .707 .577 .707 r
F P
0 g
s
.69465 .65541 m .694 .59976 L .66655 .59574 L p .707 .577 .707 r
F P
0 g
s
.694 .59976 m .69465 .65541 L .72583 .65694 L p .707 .577 .707 r
F P
0 g
s
.25148 .71966 m .24344 .73534 L .2163 .72916 L p .707 .577 .707 r
F P
0 g
s
.29944 .68416 m .30182 .72139 L .27071 .72152 L p .707 .577 .707 r
F P
0 g
s
.27071 .72152 m .26834 .68429 L .29944 .68416 L p .707 .577 .707 r
F P
0 g
s
.23656 .6869 m .23893 .72412 L .2096 .72895 L p .707 .577 .707 r
F P
0 g
s
.59499 .25265 m .58674 .75358 L .54798 .74665 L p .707 .577 .707 r
F P
0 g
s
.54798 .74665 m .55623 .24571 L .59499 .25265 L p .707 .577 .707 r
F P
0 g
s
.33284 .76392 m .32481 .7796 L .30048 .76186 L p .707 .577 .707 r
F P
0 g
s
.30048 .76186 m .30852 .74618 L .33284 .76392 L p .707 .577 .707 r
F P
0 g
s
.23893 .72412 m .23656 .6869 L .26834 .68429 L p .707 .577 .707 r
F P
0 g
s
.78639 .59654 m .78704 .65219 L .81109 .64637 L p .707 .577 .707 r
F P
0 g
s
.81109 .64637 m .81044 .59072 L .78639 .59654 L p .707 .577 .707 r
F P
0 g
s
.24344 .73534 m .25148 .71966 L .28048 .73092 L p .707 .577 .707 r
F P
0 g
s
.26834 .68429 m .27071 .72152 L .23893 .72412 L p .707 .577 .707 r
F P
0 g
s
.73725 .71541 m .73487 .67818 L .70376 .67831 L p .707 .577 .707 r
F P
0 g
s
.73487 .67818 m .73725 .71541 L .76902 .7128 L p .707 .577 .707 r
F P
0 g
s
.76902 .7128 m .76665 .67557 L .73487 .67818 L p .707 .577 .707 r
F P
0 g
s
.76665 .67557 m .76902 .7128 L .79836 .70797 L p .707 .577 .707 r
F P
0 g
s
.79836 .70797 m .79598 .67074 L .76665 .67557 L p .707 .577 .707 r
F P
0 g
s
.66655 .59574 m .6672 .65139 L .69465 .65541 L p .707 .577 .707 r
F P
0 g
s
.41756 .74791 m .42581 .24698 L .46729 .24274 L p .707 .577 .707 r
F P
0 g
s
.42581 .24698 m .41756 .74791 L .38361 .75555 L p .707 .577 .707 r
F P
0 g
s
.6672 .65139 m .66655 .59574 L .64549 .58962 L p .707 .577 .707 r
F P
0 g
s
.30852 .74618 m .30048 .76186 L .27245 .74661 L p .707 .577 .707 r
F P
0 g
s
.27245 .74661 m .28048 .73092 L .30852 .74618 L p .707 .577 .707 r
F P
0 g
s
.70614 .71554 m .70376 .67831 L .67637 .67594 L p .707 .577 .707 r
F P
0 g
s
.70376 .67831 m .70614 .71554 L .73725 .71541 L p .707 .577 .707 r
F P
0 g
s
.28048 .73092 m .27245 .74661 L .24344 .73534 L p .707 .577 .707 r
F P
0 g
s
.79598 .67074 m .79836 .70797 L .82238 .70139 L p .707 .577 .707 r
F P
0 g
s
.82238 .70139 m .82001 .66416 L .79598 .67074 L p .707 .577 .707 r
F P
0 g
s
.67637 .67594 m .67874 .71317 L .70614 .71554 L p .707 .577 .707 r
F P
0 g
s
.55623 .24571 m .54798 .74665 L .50398 .74323 L p .707 .577 .707 r
F P
0 g
s
.50398 .74323 m .51223 .2423 L .55623 .24571 L p .707 .577 .707 r
F P
0 g
s
.81044 .59072 m .81109 .64637 L .82746 .63894 L p .707 .577 .707 r
F P
0 g
s
.82746 .63894 m .82681 .58329 L .81044 .59072 L p .707 .577 .707 r
F P
0 g
s
.73284 .7718 m .74088 .75612 L .71284 .74087 L p .707 .577 .707 r
F P
0 g
s
.74088 .75612 m .73284 .7718 L .76185 .78307 L p .707 .577 .707 r
F P
0 g
s
.76185 .78307 m .76988 .76738 L .74088 .75612 L p .707 .577 .707 r
F P
0 g
s
.64549 .58962 m .64615 .64527 L .6672 .65139 L p .707 .577 .707 r
F P
0 g
s
.7048 .75655 m .71284 .74087 L .68852 .72312 L p .707 .577 .707 r
F P
0 g
s
.71284 .74087 m .7048 .75655 L .73284 .7718 L p .707 .577 .707 r
F P
0 g
s
.45904 .74367 m .46729 .24274 L .51223 .2423 L p .707 .577 .707 r
F P
0 g
s
.46729 .24274 m .45904 .74367 L .41756 .74791 L p .707 .577 .707 r
F P
0 g
s
.67874 .71317 m .67637 .67594 L .65537 .67132 L p .707 .577 .707 r
F P
0 g
s
.76988 .76738 m .76185 .78307 L .78898 .78924 L p .707 .577 .707 r
F P
0 g
s
.78898 .78924 m .79702 .77356 L .76988 .76738 L p .707 .577 .707 r
F P
0 g
s
.51223 .2423 m .50398 .74323 L .45904 .74367 L p .707 .577 .707 r
F P
0 g
s
.64615 .64527 m .64549 .58962 L .6329 .582 L p .707 .577 .707 r
F P
0 g
s
.68852 .72312 m .68048 .73881 L .7048 .75655 L p .707 .577 .707 r
F P
0 g
s
.65537 .67132 m .65775 .70855 L .67874 .71317 L p .707 .577 .707 r
F P
0 g
s
.68048 .73881 m .68852 .72312 L .67029 .70463 L p .707 .577 .707 r
F P
0 g
s
.82001 .66416 m .82238 .70139 L .83874 .6937 L p .707 .577 .707 r
F P
0 g
s
.83874 .6937 m .83637 .65647 L .82001 .66416 L p .707 .577 .707 r
F P
0 g
s
.67029 .70463 m .66225 .72031 L .68048 .73881 L p .707 .577 .707 r
F P
0 g
s
.79702 .77356 m .78898 .78924 L .8116 .78973 L p .707 .577 .707 r
F P
0 g
s
.8116 .78973 m .81963 .77405 L .79702 .77356 L p .707 .577 .707 r
F P
0 g
s
.6329 .582 m .63355 .63765 L .64615 .64527 L p .707 .577 .707 r
F P
0 g
s
.82681 .58329 m .82746 .63894 L .83454 .63063 L p .707 .577 .707 r
F P
0 g
s
.83454 .63063 m .83389 .57499 L .82681 .58329 L p .707 .577 .707 r
F P
0 g
s
.65775 .70855 m .65537 .67132 L .64283 .66489 L p .707 .577 .707 r
F P
0 g
s
.66225 .72031 m .67029 .70463 L .65994 .68718 L p .707 .577 .707 r
F P
0 g
s
.64283 .66489 m .6452 .70212 L .65775 .70855 L p .707 .577 .707 r
F P
0 g
s
.63355 .63765 m .6329 .582 L .63001 .57363 L p .707 .577 .707 r
F P
0 g
s
.65994 .68718 m .65191 .70287 L .66225 .72031 L p .707 .577 .707 r
F P
0 g
s
.83637 .65647 m .83874 .6937 L .84583 .68566 L p .707 .577 .707 r
F P
0 g
s
.84583 .68566 m .84346 .64843 L .83637 .65647 L p .707 .577 .707 r
F P
0 g
s
.81963 .77405 m .8116 .78973 L .82747 .78448 L p .707 .577 .707 r
F P
0 g
s
.82747 .78448 m .8355 .7688 L .81963 .77405 L p .707 .577 .707 r
F P
0 g
s
.63001 .57363 m .63066 .62928 L .63355 .63765 L p .707 .577 .707 r
F P
0 g
s
.83389 .57499 m .83454 .63063 L .83165 .62226 L p .707 .577 .707 r
F P
0 g
s
.83165 .62226 m .831 .56661 L .83389 .57499 L p .707 .577 .707 r
F P
0 g
s
.65191 .70287 m .65994 .68718 L .65849 .67251 L p .707 .577 .707 r
F P
0 g
s
.6452 .70212 m .64283 .66489 L .63996 .65728 L p .707 .577 .707 r
F P
0 g
s
.65849 .67251 m .65045 .68819 L .65191 .70287 L p .707 .577 .707 r
F P
0 g
s
.63996 .65728 m .64233 .69451 L .6452 .70212 L p .707 .577 .707 r
F P
0 g
s
.63066 .62928 m .63001 .57363 L .63709 .56533 L p .707 .577 .707 r
F P
0 g
s
.84346 .64843 m .84583 .68566 L .84297 .67805 L p .707 .577 .707 r
F P
0 g
s
.84297 .67805 m .84059 .64082 L .84346 .64843 L p .707 .577 .707 r
F P
0 g
s
.8355 .7688 m .82747 .78448 L .83505 .774 L p .707 .577 .707 r
F P
0 g
s
.83505 .774 m .84308 .75832 L .8355 .7688 L p .707 .577 .707 r
F P
0 g
s
.63709 .56533 m .63774 .62097 L .63066 .62928 L p .707 .577 .707 r
F P
0 g
s
.65045 .68819 m .65849 .67251 L .66607 .66203 L p .707 .577 .707 r
F P
0 g
s
.831 .56661 m .83165 .62226 L .81906 .61464 L p .707 .577 .707 r
F P
0 g
s
.81906 .61464 m .8184 .55899 L .831 .56661 L p .707 .577 .707 r
F P
0 g
s
.64233 .69451 m .63996 .65728 L .64705 .64924 L p .707 .577 .707 r
F P
0 g
s
.66607 .66203 m .65803 .67771 L .65045 .68819 L p .707 .577 .707 r
F P
0 g
s
.38282 .6188 m .38216 .56315 L .35099 .56162 L p .707 .577 .707 r
F P
0 g
s
.38216 .56315 m .38282 .6188 L .41465 .61769 L p .707 .577 .707 r
F P
0 g
s
.41465 .61769 m .414 .56204 L .38216 .56315 L p .707 .577 .707 r
F P
0 g
s
.64705 .64924 m .64943 .68646 L .64233 .69451 L p .707 .577 .707 r
F P
0 g
s
.414 .56204 m .41465 .61769 L .44403 .61404 L p .707 .577 .707 r
F P
0 g
s
.44403 .61404 m .44338 .5584 L .414 .56204 L p .707 .577 .707 r
F P
0 g
s
.63774 .62097 m .63709 .56533 L .65346 .5579 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84308 .75832 m .83505 .774 L .83359 .75932 L p .707 .577 .707 r
F P
0 g
s
.83359 .75932 m .84163 .74364 L .84308 .75832 L p .707 .577 .707 r
F P
0 g
s
.35164 .61727 m .35099 .56162 L .32354 .5576 L p .707 .577 .707 r
F P
0 g
s
.35099 .56162 m .35164 .61727 L .38282 .6188 L p .707 .577 .707 r
F P
0 g
s
.84059 .64082 m .84297 .67805 L .83042 .67161 L p .707 .577 .707 r
F P
0 g
s
.83042 .67161 m .82805 .63439 L .84059 .64082 L p .707 .577 .707 r
F P
0 g
s
.44338 .5584 m .44403 .61404 L .46808 .60822 L p .707 .577 .707 r
F P
0 g
s
.46808 .60822 m .46743 .55258 L .44338 .5584 L p .707 .577 .707 r
F P
0 g
s
.39424 .68013 m .39186 .6429 L .36075 .64303 L p .707 .577 .707 r
F P
0 g
s
.39186 .6429 m .39424 .68013 L .42601 .67752 L p .707 .577 .707 r
F P
0 g
s
.42601 .67752 m .42364 .6403 L .39186 .6429 L p .707 .577 .707 r
F P
0 g
s
.65803 .67771 m .66607 .66203 L .68194 .65677 L p .707 .577 .707 r
F P
0 g
s
.65346 .5579 m .65411 .61355 L .63774 .62097 L p .707 .577 .707 r
F P
0 g
s
.8184 .55899 m .81906 .61464 L .798 .60852 L p .707 .577 .707 r
F P
0 g
s
.798 .60852 m .79735 .55288 L .8184 .55899 L p .707 .577 .707 r
F P
0 g
s
.42364 .6403 m .42601 .67752 L .45535 .67269 L p .707 .577 .707 r
F P
0 g
s
.45535 .67269 m .45297 .63547 L .42364 .6403 L p .707 .577 .707 r
F P
0 g
s
.32354 .5576 m .32419 .61325 L .35164 .61727 L p .707 .577 .707 r
F P
0 g
s
.64943 .68646 m .64705 .64924 L .66341 .64155 L p .707 .577 .707 r
F P
0 g
s
.32419 .61325 m .32354 .5576 L .30248 .55148 L p .707 .577 .707 r
F P
0 g
s
.36313 .68026 m .36075 .64303 L .33336 .64067 L p .707 .577 .707 r
F P
0 g
s
.36075 .64303 m .36313 .68026 L .39424 .68013 L p .707 .577 .707 r
F P
0 g
s
.68194 .65677 m .6739 .67246 L .65803 .67771 L p .707 .577 .707 r
F P
0 g
s
.65411 .61355 m .65346 .5579 L .67751 .55208 L p .707 .577 .707 r
F P
0 g
s
.66341 .64155 m .66579 .67877 L .64943 .68646 L p .707 .577 .707 r
F P
0 g
s
.45297 .63547 m .45535 .67269 L .47937 .66611 L p .707 .577 .707 r
F P
0 g
s
.47937 .66611 m .477 .62888 L .45297 .63547 L p .707 .577 .707 r
F P
0 g
s
.33336 .64067 m .33573 .6779 L .36313 .68026 L p .707 .577 .707 r
F P
0 g
s
.46743 .55258 m .46808 .60822 L .48445 .6008 L p .707 .577 .707 r
F P
0 g
s
.48445 .6008 m .4838 .54515 L .46743 .55258 L p .707 .577 .707 r
F P
0 g
s
.84163 .74364 m .83359 .75932 L .82325 .74188 L p .707 .577 .707 r
F P
0 g
s
.82325 .74188 m .83128 .7262 L .84163 .74364 L p .707 .577 .707 r
F P
0 g
s
.82805 .63439 m .83042 .67161 L .80942 .66699 L p .707 .577 .707 r
F P
0 g
s
.80942 .66699 m .80705 .62976 L .82805 .63439 L p .707 .577 .707 r
F P
0 g
s
.38983 .73598 m .39787 .7203 L .36983 .70505 L p .707 .577 .707 r
F P
0 g
s
.39787 .7203 m .38983 .73598 L .41884 .74725 L p .707 .577 .707 r
F P
0 g
s
.41884 .74725 m .42687 .73156 L .39787 .7203 L p .707 .577 .707 r
F P
0 g
s
.30248 .55148 m .30314 .60713 L .32419 .61325 L p .707 .577 .707 r
F P
0 g
s
.36179 .72073 m .36983 .70505 L .34551 .6873 L p .707 .577 .707 r
F P
0 g
s
.36983 .70505 m .36179 .72073 L .38983 .73598 L p .707 .577 .707 r
F P
0 g
s
.33573 .6779 m .33336 .64067 L .31236 .63604 L p .707 .577 .707 r
F P
0 g
s
.79735 .55288 m .798 .60852 L .77055 .6045 L p .707 .577 .707 r
F P
0 g
s
.77055 .6045 m .7699 .54885 L .79735 .55288 L p .707 .577 .707 r
F P
0 g
s
.42687 .73156 m .41884 .74725 L .44597 .75343 L p .707 .577 .707 r
F P
0 g
s
.44597 .75343 m .45401 .73774 L .42687 .73156 L p .707 .577 .707 r
F P
0 g
s
.67751 .55208 m .67816 .60773 L .65411 .61355 L p .707 .577 .707 r
F P
0 g
s
.6739 .67246 m .68194 .65677 L .70455 .65726 L p .707 .577 .707 r
F P
0 g
s
.30314 .60713 m .30248 .55148 L .28989 .54386 L p .707 .577 .707 r
F P
0 g
s
.34551 .6873 m .33747 .70299 L .36179 .72073 L p .707 .577 .707 r
F P
0 g
s
.66579 .67877 m .66341 .64155 L .68744 .63496 L p .707 .577 .707 r
F P
0 g
s
.31236 .63604 m .31474 .67327 L .33573 .6779 L p .707 .577 .707 r
F P
0 g
s
.33747 .70299 m .34551 .6873 L .32728 .66881 L p .707 .577 .707 r
F P
0 g
s
.67816 .60773 m .67751 .55208 L .70689 .54844 L p .707 .577 .707 r
F P
0 g
s
.477 .62888 m .47937 .66611 L .49573 .65842 L p .707 .577 .707 r
F P
0 g
s
.49573 .65842 m .49336 .62119 L .477 .62888 L p .707 .577 .707 r
F P
0 g
s
.70455 .65726 m .69652 .67294 L .6739 .67246 L p .707 .577 .707 r
F P
0 g
s
.32728 .66881 m .31924 .68449 L .33747 .70299 L p .707 .577 .707 r
F P
0 g
s
.7699 .54885 m .77055 .6045 L .73938 .60297 L p .707 .577 .707 r
F P
0 g
s
.73938 .60297 m .73873 .54732 L .7699 .54885 L p .707 .577 .707 r
F P
0 g
s
.68744 .63496 m .68981 .67219 L .66579 .67877 L p .707 .577 .707 r
F P
0 g
s
.80705 .62976 m .80942 .66699 L .78203 .66463 L p .707 .577 .707 r
F P
0 g
s
.78203 .66463 m .77966 .6274 L .80705 .62976 L p .707 .577 .707 r
F P
0 g
s
.83128 .7262 m .82325 .74188 L .80502 .72338 L p .707 .577 .707 r
F P
0 g
s
.80502 .72338 m .81306 .7077 L .83128 .7262 L p .707 .577 .707 r
F P
0 g
s
.45401 .73774 m .44597 .75343 L .46859 .75391 L p .707 .577 .707 r
F P
0 g
s
.46859 .75391 m .47662 .73823 L .45401 .73774 L p .707 .577 .707 r
F P
0 g
s
.28989 .54386 m .29054 .59951 L .30314 .60713 L p .707 .577 .707 r
F P
0 g
s
.4838 .54515 m .48445 .6008 L .49153 .59249 L p .707 .577 .707 r
F P
0 g
s
.49153 .59249 m .49088 .53684 L .4838 .54515 L p .707 .577 .707 r
F P
0 g
s
.70754 .60408 m .70689 .54844 L .73873 .54732 L p .707 .577 .707 r
F P
0 g
s
.70689 .54844 m .70754 .60408 L .67816 .60773 L p .707 .577 .707 r
F P
0 g
s
.73873 .54732 m .73938 .60297 L .70754 .60408 L p .707 .577 .707 r
F P
0 g
s
.31474 .67327 m .31236 .63604 L .29982 .62961 L p .707 .577 .707 r
F P
0 g
s
.69652 .67294 m .70455 .65726 L .73169 .66344 L p .707 .577 .707 r
F P
0 g
s
.31924 .68449 m .32728 .66881 L .31693 .65136 L p .707 .577 .707 r
F P
0 g
s
.68981 .67219 m .68744 .63496 L .71677 .63013 L p .707 .577 .707 r
F P
0 g
s
.29054 .59951 m .28989 .54386 L .287 .53549 L p .707 .577 .707 r
F P
0 g
s
.29982 .62961 m .30219 .66684 L .31474 .67327 L p .707 .577 .707 r
F P
0 g
s
.77966 .6274 m .78203 .66463 L .75092 .66475 L p .707 .577 .707 r
F P
0 g
s
.75092 .66475 m .74855 .62753 L .77966 .6274 L p .707 .577 .707 r
F P
0 g
s
.73169 .66344 m .72365 .67912 L .69652 .67294 L p .707 .577 .707 r
F P
0 g
s
.31693 .65136 m .3089 .66705 L .31924 .68449 L p .707 .577 .707 r
F P
0 g
s
.71677 .63013 m .71915 .66736 L .68981 .67219 L p .707 .577 .707 r
F P
0 g
s
.81306 .7077 m .80502 .72338 L .7807 .70564 L p .707 .577 .707 r
F P
0 g
s
.7807 .70564 m .78873 .68996 L .81306 .7077 L p .707 .577 .707 r
F P
0 g
s
.49336 .62119 m .49573 .65842 L .50282 .65038 L p .707 .577 .707 r
F P
0 g
s
.50282 .65038 m .50045 .61315 L .49336 .62119 L p .707 .577 .707 r
F P
0 g
s
.71915 .66736 m .71677 .63013 L .74855 .62753 L p .707 .577 .707 r
F P
0 g
s
.47662 .73823 m .46859 .75391 L .48446 .74866 L p .707 .577 .707 r
F P
0 g
s
.48446 .74866 m .49249 .73298 L .47662 .73823 L p .707 .577 .707 r
F P
0 g
s
.72365 .67912 m .73169 .66344 L .7607 .67471 L p .707 .577 .707 r
F P
0 g
s
.74855 .62753 m .75092 .66475 L .71915 .66736 L p .707 .577 .707 r
F P
0 g
s
.78873 .68996 m .7807 .70564 L .75266 .69039 L p .707 .577 .707 r
F P
0 g
s
.75266 .69039 m .7607 .67471 L .78873 .68996 L p .707 .577 .707 r
F P
0 g
s
.287 .53549 m .28765 .59114 L .29054 .59951 L p .707 .577 .707 r
F P
0 g
s
.7607 .67471 m .75266 .69039 L .72365 .67912 L p .707 .577 .707 r
F P
0 g
s
.49088 .53684 m .49153 .59249 L .48864 .58412 L p .707 .577 .707 r
F P
0 g
s
.48864 .58412 m .48799 .52847 L .49088 .53684 L p .707 .577 .707 r
F P
0 g
s
.3089 .66705 m .31693 .65136 L .31548 .63669 L p .707 .577 .707 r
F P
0 g
s
.30219 .66684 m .29982 .62961 L .29695 .622 L p .707 .577 .707 r
F P
0 g
s
.31548 .63669 m .30744 .65237 L .3089 .66705 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29695 .622 m .29932 .65923 L .30219 .66684 L p .707 .577 .707 r
F P
0 g
s
.28765 .59114 m .287 .53549 L .29408 .52719 L p .707 .577 .707 r
F P
0 g
s
.50045 .61315 m .50282 .65038 L .49996 .64277 L p .707 .577 .707 r
F P
0 g
s
.49996 .64277 m .49758 .60554 L .50045 .61315 L p .707 .577 .707 r
F P
0 g
s
.49249 .73298 m .48446 .74866 L .49204 .73818 L p .707 .577 .707 r
F P
0 g
s
.49204 .73818 m .50007 .7225 L .49249 .73298 L p .707 .577 .707 r
F P
0 g
s
.29408 .52719 m .29473 .58283 L .28765 .59114 L p .707 .577 .707 r
F P
0 g
s
.30744 .65237 m .31548 .63669 L .32306 .62621 L p .707 .577 .707 r
F P
0 g
s
.48799 .52847 m .48864 .58412 L .47605 .5765 L p .707 .577 .707 r
F P
0 g
s
.47605 .5765 m .47539 .52085 L .48799 .52847 L p .707 .577 .707 r
F P
0 g
s
.29932 .65923 m .29695 .622 L .30404 .61396 L p .707 .577 .707 r
F P
0 g
s
.32306 .62621 m .31502 .64189 L .30744 .65237 L p .707 .577 .707 r
F P
0 g
s
.30404 .61396 m .30642 .65119 L .29932 .65923 L p .707 .577 .707 r
F P
0 g
s
.29473 .58283 m .29408 .52719 L .31045 .51976 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50007 .7225 m .49204 .73818 L .49058 .7235 L p .707 .577 .707 r
F P
0 g
s
.49058 .7235 m .49862 .70782 L .50007 .7225 L p .707 .577 .707 r
F P
0 g
s
.49758 .60554 m .49996 .64277 L .48741 .63634 L p .707 .577 .707 r
F P
0 g
s
.48741 .63634 m .48504 .59911 L .49758 .60554 L p .707 .577 .707 r
F P
0 g
s
.31045 .51976 m .3111 .57541 L .29473 .58283 L p .707 .577 .707 r
F P
0 g
s
.47539 .52085 m .47605 .5765 L .45499 .57038 L p .707 .577 .707 r
F P
0 g
s
.45499 .57038 m .45434 .51473 L .47539 .52085 L p .707 .577 .707 r
F P
0 g
s
.31502 .64189 m .32306 .62621 L .33893 .62095 L p .707 .577 .707 r
F P
0 g
s
.30642 .65119 m .30404 .61396 L .3204 .60627 L p .707 .577 .707 r
F P
0 g
s
.33893 .62095 m .33089 .63664 L .31502 .64189 L p .707 .577 .707 r
F P
0 g
s
.3111 .57541 m .31045 .51976 L .3345 .51394 L p .707 .577 .707 r
F P
0 g
s
.3204 .60627 m .32278 .6435 L .30642 .65119 L p .707 .577 .707 r
F P
0 g
s
.49862 .70782 m .49058 .7235 L .48024 .70606 L p .707 .577 .707 r
F P
0 g
s
.48024 .70606 m .48827 .69038 L .49862 .70782 L p .707 .577 .707 r
F P
0 g
s
.48504 .59911 m .48741 .63634 L .46641 .63171 L p .707 .577 .707 r
F P
0 g
s
.46641 .63171 m .46404 .59448 L .48504 .59911 L p .707 .577 .707 r
F P
0 g
s
.45434 .51473 m .45499 .57038 L .42754 .56636 L p .707 .577 .707 r
F P
0 g
s
.42754 .56636 m .42688 .51071 L .45434 .51473 L p .707 .577 .707 r
F P
0 g
s
.3345 .51394 m .33515 .56959 L .3111 .57541 L p .707 .577 .707 r
F P
0 g
s
.33089 .63664 m .33893 .62095 L .36154 .62144 L p .707 .577 .707 r
F P
0 g
s
.32278 .6435 m .3204 .60627 L .34443 .59969 L p .707 .577 .707 r
F P
0 g
s
.33515 .56959 m .3345 .51394 L .36388 .51029 L p .707 .577 .707 r
F P
0 g
s
.36154 .62144 m .35351 .63712 L .33089 .63664 L p .707 .577 .707 r
F P
0 g
s
.42688 .51071 m .42754 .56636 L .39637 .56483 L p .707 .577 .707 r
F P
0 g
s
.39637 .56483 m .39571 .50918 L .42688 .51071 L p .707 .577 .707 r
F P
0 g
s
.34443 .59969 m .3468 .63692 L .32278 .6435 L p .707 .577 .707 r
F P
0 g
s
.46404 .59448 m .46641 .63171 L .43902 .62935 L p .707 .577 .707 r
F P
0 g
s
.43902 .62935 m .43665 .59212 L .46404 .59448 L p .707 .577 .707 r
F P
0 g
s
.48827 .69038 m .48024 .70606 L .46201 .68756 L p .707 .577 .707 r
F P
0 g
s
.46201 .68756 m .47004 .67188 L .48827 .69038 L p .707 .577 .707 r
F P
0 g
s
.36453 .56594 m .36388 .51029 L .39571 .50918 L p .707 .577 .707 r
F P
0 g
s
.36388 .51029 m .36453 .56594 L .33515 .56959 L p .707 .577 .707 r
F P
0 g
s
.39571 .50918 m .39637 .56483 L .36453 .56594 L p .707 .577 .707 r
F P
0 g
s
.35351 .63712 m .36154 .62144 L .38868 .62762 L p .707 .577 .707 r
F P
0 g
s
.3468 .63692 m .34443 .59969 L .37376 .59486 L p .707 .577 .707 r
F P
0 g
s
.38868 .62762 m .38064 .6433 L .35351 .63712 L p .707 .577 .707 r
F P
0 g
s
.43665 .59212 m .43902 .62935 L .40791 .62948 L p .707 .577 .707 r
F P
0 g
s
.40791 .62948 m .40554 .59225 L .43665 .59212 L p .707 .577 .707 r
F P
0 g
s
.37376 .59486 m .37614 .63208 L .3468 .63692 L p .707 .577 .707 r
F P
0 g
s
.47004 .67188 m .46201 .68756 L .43769 .66982 L p .707 .577 .707 r
F P
0 g
s
.43769 .66982 m .44572 .65414 L .47004 .67188 L p .707 .577 .707 r
F P
0 g
s
.37614 .63208 m .37376 .59486 L .40554 .59225 L p .707 .577 .707 r
F P
0 g
s
.38064 .6433 m .38868 .62762 L .41769 .63889 L p .707 .577 .707 r
F P
0 g
s
.40554 .59225 m .40791 .62948 L .37614 .63208 L p .707 .577 .707 r
F P
0 g
s
.44572 .65414 m .43769 .66982 L .40965 .65457 L p .707 .577 .707 r
F P
0 g
s
.40965 .65457 m .41769 .63889 L .44572 .65414 L p .707 .577 .707 r
F P
0 g
s
.41769 .63889 m .40965 .65457 L .38064 .6433 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo`d008Eo
o`00Ogoo30001UYF00<005YFFUH015YF2@00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001fOol0079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00IJEP@0079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eo
o`00JWoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001ZOol0
06Moo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001WOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0004FUH9
0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`P000AJEP03001JEUYF009JEPP000IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
G7oo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000aJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0055oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0047oo3`00Agoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool400000eYF001J
EP07FUH00`00FUIJEP02FUH8000oOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Io
o`H000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000hOol0055oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003Aoo`00DGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF1@001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000
<Goo001AOol00`00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUH000040002FUH80004FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo00<005YF0000
15YF00<005YF00000`001EYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF1`00
0eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`03001JEP0000=JEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=J
EP@0009JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001J
EP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00DGoo00@005YF001JEP8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001J
EUYFFUH005YF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo001AOol01P00FUH00000FUH000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool0055oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000EJEP07001JEUYFFUH005YF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP090004FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;goo0015Ool90004Ool01@00FUIJEUYF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00
?Goo200015YF00<005YFFUH00UYF1`0000=JEP00FUH015YF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHH0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000eOol80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP030002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00=JEPL000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2000_Ool0035oo`@0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1P00FUIJEP00FUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000_Ool002moo`<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH2000_Ool002eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00800003FUH0000002moo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000_Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000_Ool0
02Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF000040001EYF00<005YFFUH00UYF00<005YF0000;goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH015YF3`0025YF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00P000AJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUH0000_Ool002Yoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP05FUH30005FUH40003FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH00UYF1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01@00<7oo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001EYF1`00
15YF00<005YFFUH01UYF0`000eYF100000=JEP00FUH01EYF00@005YFFUIJEP800003FUH0000000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH500000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP000eYF00<005YF00003`002EYF1@001EYF00<005YFFUH015YF00<0
05YFFUH00UYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH200000eYF001JEP06FUH00`00FUIJ
EP04FUH20006FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF0000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEPH00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000^Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP07001JEUYF001JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
0P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00H005YFFUIJEP00FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP0200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01P00FUH00000FUH000MJEP80009JEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP03000015YF001JEP000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH01000FUIJEUYF0P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002eoo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@00
00=JEP0000000`000UYF200000=JEP0000000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00=JEP8000IJEP03001JEP00008000IJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH00000;Goo000ZOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YF000010000UYF
00<005YFFUH015YF00@005YF000000=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20004FUH01@00FUIJEUYF00001UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000]Ool002Yoo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001J
EUYF00AJEP03001JEP0000AJEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20000
0eYF001JEP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP04FUHN0003
FUH01000FUIJEP00;Goo000ZOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YF00001eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000IJEP@000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000=JEP03
001JEUYF00=JEP<000Uoo`@000EJEP@0009JEP8002aoo`00:Woo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUH00000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF009J
EP03001JEUYF00=JEP@000MJEP03001JEUYF00IJEP8000=oo`@0009JEP03001JEUYF00AJEP04001J
EUYFFUH4000/Ool002Yoo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000eYF001JEP03FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUH0000;0002FUH00`00FUIJ
EP07FUH00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002Yoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUH0000B00000eYF001JEP08FUH01@00FUIJEUYF00000UYF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00FUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH0100025YF00D005YFFUIJEP0000IJEP03
001JEUYF00AJEP03001JEUYF009JEP<002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH04@0000=JEP00FUH01EYF0`000UYF00<005YFFUH015YF1P00
0eYF00<005YFFUH025YF0`0015YF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH0
15YF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP090004FUH00`00FUIJ
EP06FUH01000FUIJEUYF0`001UYF0P000UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF0P00
1EYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0000EJEP00001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF
00EJEP80009JEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00:goo00D005YFFUIJEP0000EJ
EP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01P00FUH00000FUH000IJEPH000=JEP03001JEUYF00UJEP03001JEP0000EJEP03001JEUYF
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH0
05YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0P002UYF00<005YF00001UYF
00<005YFFUH00UYF0P00;Goo000/Ool200000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP02FUH20006FUH00`00FUH0
00020004FUH00`00FUIJEP09FUH01000FUIJEP000eYF00<005YF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@0000AJEP00FUH000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000MJEP04001JEP000006FUH01000FUIJEUYF0P00;Woo
000^Ool30002FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00D0
05YFFUIJEP00009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP@00003FUH005YF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20004FUH00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000<7oo000aOol200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEP001eYF0P0015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00UYF0P000eYF00@0
05YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF0003
FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00@0
05YFFUIJEP<0039oo`00;goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000MJEP05001JEUYFFUH00008FUH00`00
FUIJEP09FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`000eYF00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YF000000MJEP<003Eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00FUIJEP09FUH00`00FUIJEP04FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEP00009J
EP04001JEP000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001eYF00<007oo
Ool0<goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF0P0025YF00<005YFFUH0
2EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0002FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000goo001JEP04FUH00`00FUH0000dOol002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00EJEP8000IJEP03001JEUYF00UJEP03001JEUYF00EJEP06001JEP00001J
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00P00
15YF00<005YFFUH04P002goo00D005YFFUIJEP0000=JEP03001oogoo035oo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH000UJEP8000AJEP03001JEUYF00UJEP03001JEUYF00EJEP80
009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH0009JEP03001JEUYF
00=JEP03001JEP00008000Uoo`D000eoo`800003FUH005YF00=JEP03001oogoo031oo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF7@0015YF00<005YFFUH00`001eYF00@005YF
0000009JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000=JEP@000EJEP800003FUH007oo00Qoo`D000moo`03001J
EUYF00AJEP03001oogoo02moo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00@0
00AJEP03001JEUYF009JEP<000Yoo`D0009JEP<00005FUH005YFFUH00002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`002eYF00<005YFFUH01UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP<000Yoo`D0011oo`03001JEUYF00AJ
EP03001oogoo02ioo`00;Goo00@005YFFUH000=JEP03001JEUYF00=JEPD000MJEP03001JEUYF00EJ
EP8000Aoo`@00003FUH005YF00EJEP04001JEP000002FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF0P002UYF00<005YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001eYF00D005YFFUIJEP0000=JEP03001oogoo00Qoo`<0019oo`03001J
EUYF009JEP03001JEP0002moo`00;Goo00@005YFFUH000=JEP03001JEP0000@000Aoo`@0009JEP03
001JEUYF00MJEPD000EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH200000eYF
001JEP07FUH50005FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH20002FUH00`00FUIJEP02FUH00`00Oomoo`0MOol01000
FUIJEP000UYF00<007ooOol0;Goo000^Ool00`00FUH00003FUH200000eYF001JEP02FUH<0007FUH0
1@00FUIJEUYF00001UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00AJEP<000QJEP03
001JEUYF009JEPl000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000MJEP04001JEP000006FUH2000NOol00`00FUH00003FUH00`00Oomoo`0/Ool002ioo`04
001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00`001EYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP04001JEUYF0008FUH00`00Oomoo`0LOol0
0`00FUIJEP02FUH00`00Oomoo`0/Ool002ioo`06001JEP00001JEP000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF100000=JEP00FUH01UYF0P000UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YFFUH030001UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH0
0P001UYF0`007Goo00<005YFFUH00UYF00<007ooOol0:goo000^Ool3000015YF001JEP000UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP8000UJEP04001JEUYF0006FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH01000FUIJEP002eYF2@00
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF
FUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2000]Ool002ioo`04001JEP000002FUH01000
FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00<005YF00000P001UYF00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH010001EYF10000UYF00<005YFFUH00eYF00<005YF0000
0P0035YF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP8001]oo`05001JEP00FUH0000]Ool002ioo`04
001JEP000003FUH01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00D005YF
FUIJEP0000IJEP03001JEP00009JEP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEPX0009JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000MJEP03001JEUYF009JEP800003FUH005YF
00IJEP03001JEUYF00=JEP@000MJEP8001Uoo`05001JEP00FUH0000]Ool002ioo`03001JEP0000AJ
EP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJ
EP02FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF3@0015YF00@005YFFUH0
00UJEP8001Qoo`04001JEUYF000]Ool002moo`<000AJEP03001JEP0000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH40003Ool01@00FUIJEP00FUH00P0025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0P000goo1P000UYF0`0000AJEP00FUIJEP<000IJEP03001JEUYF008001Ioo`04001JEUYF000]
Ool0035oo`06001JEUYFFUH005YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000IJEP03001oogoo009oo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000004FUH50002
FUH00`00FUIJEP04FUH00`00FUH00002000015YF000007oo0P0015YF00<005YFFUH00UYF0`004goo
00<005YF0000;Woo000bOol00`00FUH00003FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
00000goo001JEP03FUH00`00FUH00003Ool00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF0P001EYF00<005YFFUH015YF00<005YFFUH00UYF0`000goo0P0000=JEP00FUH01eYF1@00
3Woo0`00;Woo000bOol00`00FUH00004FUH00`00Oomoo`0B000;Ool01@00FUIJEUYF00000UYF00<0
07ooOol00P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001EYF00<005YFFUH015YF00<005YF
FUH00UYF0`001Goo0`001eYF00<005YFFUH00UYF1`001Goo0P0000=JEP00Ool0;Woo000cOol00`00
FUIJEP04FUH00`00Oomoo`0:Ool5000>Ool30004FUH01000Ool0000015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YF000000EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000Qoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00D0009JEP8002moo`00=7oo00<005YFFUH015YF00<007oo
Ool02Goo1@0047oo00<005YFFUH00eYF0P001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000`000eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002Woo0`0000=JEP00FUH01eYF
00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Woo000eOol00`00FUIJEP02FUH01000FUH0
00002Goo1@004Goo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH0009JEP800003FUH005YF00EJEP03001JEUYF009JEP8000ioo`<000MJEP03001JEUYF
00=JEP04001JEUYFFUH2000`Ool003Eoo`03001JEUYF009JEP05001JEUYFFUH00009Ool3000COol0
1`00FUIJEUYF001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH01000
FUH000001UYF00@005YFFUIJEP80019oo`@0009JEP03001JEUYF00=JEP03001JEUYF00<0035oo`00
=Woo00@005YFFUH000EJEP03001oogoo01eoo`06001JEUYF001JEP0015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YF000001Qoo`/0
03Aoo`00=goo00<005YF00001UYF0P007Woo0P000eYF0P000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEP<005Uoo`00>7oo00<005YFFUH01eYF00<007oo
Ool077oo00H005YFFUIJEP00Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF00000007FUH3001LOol0
03Uoo`8000IJEP04001JEP00000MOol01@00FUIJEUYF00000Woo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
0eYF0P001eYF00<007ooOol0FWoo000kOol00`00FUIJEP03FUH01000FUIJEUYF0P006goo00<005YF
FUH00P0017oo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00@005YFFUIJEPP00003Ool005YF00AJEP03001JEP0005]oo`00?7oo00D0
05YFFUIJEP0000IJEP8001Yoo`04001JEP000007Ool300000eYF001JEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000002Woo00D005YFFUIJEP00
00=JEP03001oogoo05Qoo`00?Goo0P0000=JEP00FUH01eYF0P0067oo0P000UYF00<007ooOol01goo
100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10003Goo
0P0000=JEP00FUH00eYF00<007ooOol0Egoo000oOol00`00FUIJEP07FUH01000FUH000005goo00@0
05YFFUH000eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00T000moo`03001JEUYF00AJEP03001oogoo05Ioo`00@7oo0P001eYF00@005YFFUIJEP8001Eoo`03
001JEP0001Aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Aoo`D0011oo`03001JEUYF
00AJEP03001oogoo05Eoo`00@Woo0P0015YF00<005YFFUH015YF0P004goo00<005YF000077oo6P00
0UYF00<007ooOol01goo1@004Goo00<005YFFUH00UYF00<005YF0000EWoo0014Ool20002FUH00`00
FUIJEP06FUH5000>Ool2000bOol01000FUIJEP0015YF00<007ooOol01goo0`004Woo00<005YFFUH0
0UYF00<005YF0000EWoo0016Ool30008FUH00`00FUIJEP02FUH70005Ool4000cOol20006FUH2000M
Ool01000FUIJEP000eYF00<007ooOol0Dgoo0019Ool30005FUH00`00FUIJEP05FUH01000FUIJEUYF
1@000UYF00<007ooOol0<goo00<005YFFUH01UYF00<007ooOol06goo00<005YF00000eYF00<007oo
Ool0Dgoo001<Ool300000eYF001JEP07FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=goo0P001UYF
0`0077oo00<005YFFUH00eYF00<007ooOol0DWoo001?Ool30006FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000>Goo00<005YFFUH00UYF00D005YFFUIJEP0001aoo`04001JEUYFFUH2001DOol0059oo`@0
009JEP03001JEUYF00=JEP03001JEUYF008003]oo`05001JEUYFFUH00004FUH2000JOol01000FUIJ
EUYF0P00E7oo001FOol;000nOol30007FUH2000IOol01@00FUH005YF0000E7oo002QOol00`00FUIJ
EP07FUH2000GOol01@00FUH005YF0000E7oo002ROol20006FUH00`00FUIJEP02000FOol01000FUIJ
EP00E7oo002TOol20004FUH00`00FUIJEP02FUH3000COol00`00FUH0001EOol00:Ioo`800003FUH0
05YF00MJEP<0011oo`03001JEP0005Eoo`00Z7oo0`001eYF00<005YFFUH010002Woo0P0000=JEP00
Ool0EGoo002[Ool20005FUH00`00FUIJEP04FUH:0002FUH2001FOol00:eoo`<00003FUH005YF00MJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05Eoo`00/7oo0`001eYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00/goo10000UYF00<005YFFUH00eYF00<005YFFUH00`00F7oo002gOol;
001KOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59149 .74918 m .59109 .69355 L .55991 .69188 L p .707 .577 .707 r
F P
0 g
s
.59109 .69355 m .59149 .74918 L .62332 .74819 L p .707 .577 .707 r
F P
0 g
s
.62332 .74819 m .62292 .69257 L .59109 .69355 L p .707 .577 .707 r
F P
0 g
s
.62292 .69257 m .62332 .74819 L .6527 .74465 L p .707 .577 .707 r
F P
0 g
s
.6527 .74465 m .6523 .68903 L .62292 .69257 L p .707 .577 .707 r
F P
0 g
s
.56032 .74751 m .55991 .69188 L .53246 .68772 L p .707 .577 .707 r
F P
0 g
s
.55991 .69188 m .56032 .74751 L .59149 .74918 L p .707 .577 .707 r
F P
0 g
s
.6523 .68903 m .6527 .74465 L .67676 .7389 L p .707 .577 .707 r
F P
0 g
s
.67676 .7389 m .67635 .68327 L .6523 .68903 L p .707 .577 .707 r
F P
0 g
s
.59856 .80838 m .59709 .7712 L .56595 .77055 L p .707 .577 .707 r
F P
0 g
s
.59709 .7712 m .59856 .80838 L .63037 .80647 L p .707 .577 .707 r
F P
0 g
s
.63037 .80647 m .62891 .76929 L .59709 .7712 L p .707 .577 .707 r
F P
0 g
s
.62891 .76929 m .63037 .80647 L .65974 .8022 L p .707 .577 .707 r
F P
0 g
s
.65974 .8022 m .65827 .76501 L .62891 .76929 L p .707 .577 .707 r
F P
0 g
s
.53246 .68772 m .53286 .74334 L .56032 .74751 L p .707 .577 .707 r
F P
0 g
s
.53286 .74334 m .53246 .68772 L .5114 .68147 L p .707 .577 .707 r
F P
0 g
s
.56741 .80773 m .56595 .77055 L .53851 .76741 L p .707 .577 .707 r
F P
0 g
s
.56595 .77055 m .56741 .80773 L .59856 .80838 L p .707 .577 .707 r
F P
0 g
s
.65827 .76501 m .65974 .8022 L .68378 .79597 L p .707 .577 .707 r
F P
0 g
s
.68378 .79597 m .68231 .75879 L .65827 .76501 L p .707 .577 .707 r
F P
0 g
s
.67635 .68327 m .67676 .7389 L .69313 .73149 L p .707 .577 .707 r
F P
0 g
s
.69313 .73149 m .69272 .67587 L .67635 .68327 L p .707 .577 .707 r
F P
0 g
s
.53851 .76741 m .53998 .80459 L .56741 .80773 L p .707 .577 .707 r
F P
0 g
s
.59649 .85969 m .60157 .84248 L .57161 .83205 L p .707 .577 .707 r
F P
0 g
s
.60157 .84248 m .59649 .85969 L .62724 .86661 L p .707 .577 .707 r
F P
0 g
s
.62724 .86661 m .63232 .84939 L .60157 .84248 L p .707 .577 .707 r
F P
0 g
s
.5114 .68147 m .51181 .7371 L .53286 .74334 L p .707 .577 .707 r
F P
0 g
s
.56653 .84927 m .57161 .83205 L .54537 .81914 L p .707 .577 .707 r
F P
0 g
s
.57161 .83205 m .56653 .84927 L .59649 .85969 L p .707 .577 .707 r
F P
0 g
s
.53998 .80459 m .53851 .76741 L .51748 .76209 L p .707 .577 .707 r
F P
0 g
s
.63232 .84939 m .62724 .86661 L .65575 .86933 L p .707 .577 .707 r
F P
0 g
s
.65575 .86933 m .66083 .85211 L .63232 .84939 L p .707 .577 .707 r
F P
0 g
s
.51181 .7371 m .5114 .68147 L .49881 .67375 L p .707 .577 .707 r
F P
0 g
s
.54537 .81914 m .54029 .83636 L .56653 .84927 L p .707 .577 .707 r
F P
0 g
s
.51748 .76209 m .51895 .79927 L .53998 .80459 L p .707 .577 .707 r
F P
0 g
s
.68231 .75879 m .68378 .79597 L .70015 .7884 L p .707 .577 .707 r
F P
0 g
s
.70015 .7884 m .69868 .75122 L .68231 .75879 L p .707 .577 .707 r
F P
0 g
s
.54029 .83636 m .54537 .81914 L .5254 .805 L p .707 .577 .707 r
F P
0 g
s
.66083 .85211 m .65575 .86933 L .67925 .8676 L p .707 .577 .707 r
F P
0 g
s
.67925 .8676 m .68433 .85038 L .66083 .85211 L p .707 .577 .707 r
F P
0 g
s
.5254 .805 m .52032 .82221 L .54029 .83636 L p .707 .577 .707 r
F P
0 g
s
.49881 .67375 m .49921 .72938 L .51181 .7371 L p .707 .577 .707 r
F P
0 g
s
.69272 .67587 m .69313 .73149 L .70021 .72316 L p .707 .577 .707 r
F P
0 g
s
.70021 .72316 m .69981 .66754 L .69272 .67587 L p .707 .577 .707 r
F P
0 g
s
.51895 .79927 m .51748 .76209 L .50491 .7551 L p .707 .577 .707 r
F P
0 g
s
.49921 .72938 m .49881 .67375 L .49591 .66531 L p .707 .577 .707 r
F P
0 g
s
.50491 .7551 m .50637 .79228 L .51895 .79927 L p .707 .577 .707 r
F P
0 g
s
.52032 .82221 m .5254 .805 L .51368 .79101 L p .707 .577 .707 r
F P
0 g
s
.68433 .85038 m .67925 .8676 L .69542 .86158 L p .707 .577 .707 r
F P
0 g
s
.69542 .86158 m .7005 .84436 L .68433 .85038 L p .707 .577 .707 r
F P
0 g
s
.69868 .75122 m .70015 .7884 L .70723 .78024 L p .707 .577 .707 r
F P
0 g
s
.70723 .78024 m .70577 .74306 L .69868 .75122 L p .707 .577 .707 r
F P
0 g
s
.51368 .79101 m .5086 .80823 L .52032 .82221 L p .707 .577 .707 r
F P
0 g
s
.49591 .66531 m .49632 .72094 L .49921 .72938 L p .707 .577 .707 r
F P
0 g
s
.69981 .66754 m .70021 .72316 L .69731 .71473 L p .707 .577 .707 r
F P
0 g
s
.69731 .71473 m .69691 .6591 L .69981 .66754 L p .707 .577 .707 r
F P
0 g
s
.50637 .79228 m .50491 .7551 L .50202 .74713 L p .707 .577 .707 r
F P
0 g
s
.48698 .82191 m .49208 .32059 L .44807 .31746 L p .707 .577 .707 r
F P
0 g
s
.5086 .80823 m .51368 .79101 L .51134 .77855 L p .707 .577 .707 r
F P
0 g
s
.50202 .74713 m .50349 .78431 L .50637 .79228 L p .707 .577 .707 r
F P
0 g
s
.49632 .72094 m .49591 .66531 L .503 .65699 L p .707 .577 .707 r
F P
0 g
s
.51134 .77855 m .50626 .79577 L .5086 .80823 L p .707 .577 .707 r
F P
0 g
s
.503 .65699 m .5034 .71261 L .49632 .72094 L p .707 .577 .707 r
F P
0 g
s
.50349 .78431 m .50202 .74713 L .50911 .73897 L p .707 .577 .707 r
F P
0 g
s
.50626 .79577 m .51134 .77855 L .51861 .76884 L p .707 .577 .707 r
F P
0 g
s
.50911 .73897 m .51058 .77615 L .50349 .78431 L p .707 .577 .707 r
F P
0 g
s
.5034 .71261 m .503 .65699 L .51937 .64958 L p .707 .577 .707 r
F P
0 g
s
.51861 .76884 m .51353 .78605 L .50626 .79577 L p .707 .577 .707 r
F P
0 g
s
.51937 .64958 m .51977 .70521 L .5034 .71261 L p .707 .577 .707 r
F P
0 g
s
.51058 .77615 m .50911 .73897 L .52547 .7314 L p .707 .577 .707 r
F P
0 g
s
.51353 .78605 m .51861 .76884 L .53479 .76282 L p .707 .577 .707 r
F P
0 g
s
.51977 .70521 m .51937 .64958 L .54342 .64383 L p .707 .577 .707 r
F P
0 g
s
.52547 .7314 m .52694 .76858 L .51058 .77615 L p .707 .577 .707 r
F P
0 g
s
.53479 .76282 m .52971 .78004 L .51353 .78605 L p .707 .577 .707 r
F P
0 g
s
.54342 .64383 m .54382 .69945 L .51977 .70521 L p .707 .577 .707 r
F P
0 g
s
.52694 .76858 m .52547 .7314 L .54951 .72517 L p .707 .577 .707 r
F P
0 g
s
.52971 .78004 m .53479 .76282 L .55829 .76109 L p .707 .577 .707 r
F P
0 g
s
.54951 .72517 m .55098 .76236 L .52694 .76858 L p .707 .577 .707 r
F P
0 g
s
.49208 .32059 m .48698 .82191 L .53192 .82122 L p .707 .577 .707 r
F P
0 g
s
.55829 .76109 m .55321 .7783 L .52971 .78004 L p .707 .577 .707 r
F P
0 g
s
.53192 .82122 m .53702 .3199 L .49208 .32059 L p .707 .577 .707 r
F P
0 g
s
.54382 .69945 m .54342 .64383 L .5728 .64028 L p .707 .577 .707 r
F P
0 g
s
.5728 .64028 m .5732 .69591 L .54382 .69945 L p .707 .577 .707 r
F P
0 g
s
.55098 .76236 m .54951 .72517 L .57888 .7209 L p .707 .577 .707 r
F P
0 g
s
.55321 .7783 m .55829 .76109 L .5868 .76381 L p .707 .577 .707 r
F P
0 g
s
.57888 .7209 m .58035 .75808 L .55098 .76236 L p .707 .577 .707 r
F P
0 g
s
.5868 .76381 m .58172 .78103 L .55321 .7783 L p .707 .577 .707 r
F P
0 g
s
.53702 .3199 m .53192 .82122 L .5734 .81677 L p .707 .577 .707 r
F P
0 g
s
.5732 .69591 m .5728 .64028 L .60463 .6393 L p .707 .577 .707 r
F P
0 g
s
.60463 .6393 m .60504 .69492 L .5732 .69591 L p .707 .577 .707 r
F P
0 g
s
.5734 .81677 m .5785 .31546 L .53702 .3199 L p .707 .577 .707 r
F P
0 g
s
.7005 .84436 m .69542 .86158 L .7027 .85186 L p .707 .577 .707 r
F P
0 g
s
.7027 .85186 m .70778 .83465 L .7005 .84436 L p .707 .577 .707 r
F P
0 g
s
.44297 .81877 m .44807 .31746 L .40931 .3108 L p .707 .577 .707 r
F P
0 g
s
.44807 .31746 m .44297 .81877 L .48698 .82191 L p .707 .577 .707 r
F P
0 g
s
.70577 .74306 m .70723 .78024 L .70435 .77227 L p .707 .577 .707 r
F P
0 g
s
.70435 .77227 m .70288 .73509 L .70577 .74306 L p .707 .577 .707 r
F P
0 g
s
.58035 .75808 m .57888 .7209 L .61069 .71899 L p .707 .577 .707 r
F P
0 g
s
.61069 .71899 m .61216 .75617 L .58035 .75808 L p .707 .577 .707 r
F P
0 g
s
.58172 .78103 m .5868 .76381 L .61754 .77072 L p .707 .577 .707 r
F P
0 g
s
.61754 .77072 m .61246 .78794 L .58172 .78103 L p .707 .577 .707 r
F P
0 g
s
.5785 .31546 m .5734 .81677 L .60735 .809 L p .707 .577 .707 r
F P
0 g
s
.63581 .64097 m .63621 .6966 L .60504 .69492 L p .707 .577 .707 r
F P
0 g
s
.60504 .69492 m .60463 .6393 L .63581 .64097 L p .707 .577 .707 r
F P
0 g
s
.60735 .809 m .61245 .30769 L .5785 .31546 L p .707 .577 .707 r
F P
0 g
s
.69691 .6591 m .69731 .71473 L .68472 .70701 L p .707 .577 .707 r
F P
0 g
s
.68472 .70701 m .68432 .65138 L .69691 .6591 L p .707 .577 .707 r
F P
0 g
s
.40421 .81212 m .40931 .3108 L .37959 .30128 L p .707 .577 .707 r
F P
0 g
s
.40931 .3108 m .40421 .81212 L .44297 .81877 L p .707 .577 .707 r
F P
0 g
s
.24848 .71154 m .24808 .65592 L .2169 .65425 L p .707 .577 .707 r
F P
0 g
s
.24808 .65592 m .24848 .71154 L .28031 .71056 L p .707 .577 .707 r
F P
0 g
s
.28031 .71056 m .27991 .65494 L .24808 .65592 L p .707 .577 .707 r
F P
0 g
s
.27991 .65494 m .28031 .71056 L .3097 .70702 L p .707 .577 .707 r
F P
0 g
s
.3097 .70702 m .30929 .65139 L .27991 .65494 L p .707 .577 .707 r
F P
0 g
s
.70778 .83465 m .7027 .85186 L .70036 .8394 L p .707 .577 .707 r
F P
0 g
s
.70036 .8394 m .70544 .82219 L .70778 .83465 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21731 .70987 m .2169 .65425 L .18945 .65008 L p .707 .577 .707 r
F P
0 g
s
.2169 .65425 m .21731 .70987 L .24848 .71154 L p .707 .577 .707 r
F P
0 g
s
.70288 .73509 m .70435 .77227 L .69177 .76528 L p .707 .577 .707 r
F P
0 g
s
.69177 .76528 m .69031 .7281 L .70288 .73509 L p .707 .577 .707 r
F P
0 g
s
.30929 .65139 m .3097 .70702 L .33375 .70126 L p .707 .577 .707 r
F P
0 g
s
.33375 .70126 m .33335 .64564 L .30929 .65139 L p .707 .577 .707 r
F P
0 g
s
.64184 .71964 m .64331 .75682 L .61216 .75617 L p .707 .577 .707 r
F P
0 g
s
.61216 .75617 m .61069 .71899 L .64184 .71964 L p .707 .577 .707 r
F P
0 g
s
.64751 .78114 m .64243 .79836 L .61246 .78794 L p .707 .577 .707 r
F P
0 g
s
.61246 .78794 m .61754 .77072 L .64751 .78114 L p .707 .577 .707 r
F P
0 g
s
.61245 .30769 m .60735 .809 L .63046 .79867 L p .707 .577 .707 r
F P
0 g
s
.63046 .79867 m .63556 .29736 L .61245 .30769 L p .707 .577 .707 r
F P
0 g
s
.68432 .65138 m .68472 .70701 L .66367 .70076 L p .707 .577 .707 r
F P
0 g
s
.66367 .70076 m .66326 .64514 L .68432 .65138 L p .707 .577 .707 r
F P
0 g
s
.25555 .77251 m .25409 .73533 L .22294 .73468 L p .707 .577 .707 r
F P
0 g
s
.25409 .73533 m .25555 .77251 L .28737 .77061 L p .707 .577 .707 r
F P
0 g
s
.28737 .77061 m .2859 .73343 L .25409 .73533 L p .707 .577 .707 r
F P
0 g
s
.2859 .73343 m .28737 .77061 L .31673 .76633 L p .707 .577 .707 r
F P
0 g
s
.31673 .76633 m .31526 .72915 L .2859 .73343 L p .707 .577 .707 r
F P
0 g
s
.18945 .65008 m .18985 .70571 L .21731 .70987 L p .707 .577 .707 r
F P
0 g
s
.18985 .70571 m .18945 .65008 L .16839 .64384 L p .707 .577 .707 r
F P
0 g
s
.22441 .77187 m .22294 .73468 L .1955 .73155 L p .707 .577 .707 r
F P
0 g
s
.22294 .73468 m .22441 .77187 L .25555 .77251 L p .707 .577 .707 r
F P
0 g
s
.37449 .8026 m .37959 .30128 L .36181 .28983 L p .707 .577 .707 r
F P
0 g
s
.37959 .30128 m .37449 .8026 L .40421 .81212 L p .707 .577 .707 r
F P
0 g
s
.70544 .82219 m .70036 .8394 L .68864 .82542 L p .707 .577 .707 r
F P
0 g
s
.68864 .82542 m .69372 .8082 L .70544 .82219 L p .707 .577 .707 r
F P
0 g
s
.31526 .72915 m .31673 .76633 L .34077 .76011 L p .707 .577 .707 r
F P
0 g
s
.34077 .76011 m .3393 .72292 L .31526 .72915 L p .707 .577 .707 r
F P
0 g
s
.33335 .64564 m .33375 .70126 L .35012 .69386 L p .707 .577 .707 r
F P
0 g
s
.35012 .69386 m .34971 .63823 L .33335 .64564 L p .707 .577 .707 r
F P
0 g
s
.1955 .73155 m .19697 .76873 L .22441 .77187 L p .707 .577 .707 r
F P
0 g
s
.25348 .82349 m .25856 .80628 L .2286 .79585 L p .707 .577 .707 r
F P
0 g
s
.25856 .80628 m .25348 .82349 L .28423 .83041 L p .707 .577 .707 r
F P
0 g
s
.28423 .83041 m .28931 .81319 L .25856 .80628 L p .707 .577 .707 r
F P
0 g
s
.69031 .7281 m .69177 .76528 L .67074 .75996 L p .707 .577 .707 r
F P
0 g
s
.67074 .75996 m .66927 .72278 L .69031 .7281 L p .707 .577 .707 r
F P
0 g
s
.16839 .64384 m .1688 .69946 L .18985 .70571 L p .707 .577 .707 r
F P
0 g
s
.22352 .81307 m .2286 .79585 L .20236 .78294 L p .707 .577 .707 r
F P
0 g
s
.2286 .79585 m .22352 .81307 L .25348 .82349 L p .707 .577 .707 r
F P
0 g
s
.66326 .64514 m .66367 .70076 L .63621 .6966 L p .707 .577 .707 r
F P
0 g
s
.63621 .6966 m .63581 .64097 L .66326 .64514 L p .707 .577 .707 r
F P
0 g
s
.19697 .76873 m .1955 .73155 L .17447 .72622 L p .707 .577 .707 r
F P
0 g
s
.28931 .81319 m .28423 .83041 L .31274 .83313 L p .707 .577 .707 r
F P
0 g
s
.31274 .83313 m .31782 .81591 L .28931 .81319 L p .707 .577 .707 r
F P
0 g
s
.1688 .69946 m .16839 .64384 L .1558 .63612 L p .707 .577 .707 r
F P
0 g
s
.20236 .78294 m .19728 .80016 L .22352 .81307 L p .707 .577 .707 r
F P
0 g
s
.17447 .72622 m .17594 .7634 L .19697 .76873 L p .707 .577 .707 r
F P
0 g
s
.3393 .72292 m .34077 .76011 L .35714 .75254 L p .707 .577 .707 r
F P
0 g
s
.35714 .75254 m .35567 .71536 L .3393 .72292 L p .707 .577 .707 r
F P
0 g
s
.19728 .80016 m .20236 .78294 L .18239 .7688 L p .707 .577 .707 r
F P
0 g
s
.63556 .29736 m .63046 .79867 L .64046 .78679 L p .707 .577 .707 r
F P
0 g
s
.64046 .78679 m .64556 .28548 L .63556 .29736 L p .707 .577 .707 r
F P
0 g
s
.31782 .81591 m .31274 .83313 L .33624 .8314 L p .707 .577 .707 r
F P
0 g
s
.33624 .8314 m .34132 .81418 L .31782 .81591 L p .707 .577 .707 r
F P
0 g
s
.69372 .8082 m .68864 .82542 L .66867 .81128 L p .707 .577 .707 r
F P
0 g
s
.66867 .81128 m .67375 .79406 L .69372 .8082 L p .707 .577 .707 r
F P
0 g
s
.66927 .72278 m .67074 .75996 L .64331 .75682 L p .707 .577 .707 r
F P
0 g
s
.64331 .75682 m .64184 .71964 L .66927 .72278 L p .707 .577 .707 r
F P
0 g
s
.18239 .7688 m .17731 .78601 L .19728 .80016 L p .707 .577 .707 r
F P
0 g
s
.1558 .63612 m .1562 .69174 L .1688 .69946 L p .707 .577 .707 r
F P
0 g
s
.34971 .63823 m .35012 .69386 L .3572 .68553 L p .707 .577 .707 r
F P
0 g
s
.3572 .68553 m .3568 .62991 L .34971 .63823 L p .707 .577 .707 r
F P
0 g
s
.17594 .7634 m .17447 .72622 L .1619 .71923 L p .707 .577 .707 r
F P
0 g
s
.35567 .71536 m .35714 .75254 L .36422 .74437 L p .707 .577 .707 r
F P
0 g
s
.36422 .74437 m .36276 .70719 L .35567 .71536 L p .707 .577 .707 r
F P
0 g
s
.3568 .62991 m .3572 .68553 L .3543 .67709 L p .707 .577 .707 r
F P
0 g
s
.35987 .69923 m .36134 .73641 L .34876 .72942 L p .707 .577 .707 r
F P
0 g
s
.34876 .72942 m .3473 .69224 L .35987 .69923 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .34563 .78922 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36243 .78599 m .36089 .79122 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36089 .79122 m .35735 .8032 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35772 .27756 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .35071 .772 L .36059 .78379 L p .707 .577 .707 r
F P
0 g
s
.36059 .78379 m .36243 .78599 L p .36069 .78632 L .707 .577 .707 r
F P
0 g
s
.34563 .78922 m .36059 .78379 L .36069 .78632 L .707 .577 .707 r
F
.35262 .77887 m .35671 .79114 L p .35691 .69138 L F P
0 g
s
.3543 .67709 m .3539 .62147 L .3568 .62991 L p .707 .577 .707 r
F P
0 g
s
.35772 .27756 m .3542 .62354 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.3539 .62147 m .3543 .67709 L .34171 .66937 L p .707 .577 .707 r
F P
0 g
s
.3542 .62354 m .35262 .77887 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35671 .79114 m .35756 .70773 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.35756 .70773 m .36181 .28983 L p .35691 .69138 L .707 .577 .707 r
F P
0 g
s
.36276 .70719 m .36422 .74437 L .36134 .73641 L p .707 .577 .707 r
F P
0 g
s
.36134 .73641 m .35987 .69923 L .36276 .70719 L p .707 .577 .707 r
F P
0 g
s
.35735 .8032 m .36243 .78599 L .36477 .79845 L p .707 .577 .707 r
F P
0 g
s
.36181 .28983 m .35671 .79114 L .37449 .8026 L p .707 .577 .707 r
F P
0 g
s
.1562 .69174 m .1558 .63612 L .1529 .62768 L p .707 .577 .707 r
F P
0 g
s
.1619 .71923 m .16336 .75642 L .17594 .7634 L p .707 .577 .707 r
F P
0 g
s
.17731 .78601 m .18239 .7688 L .17067 .75481 L p .707 .577 .707 r
F P
0 g
s
.34132 .81418 m .33624 .8314 L .35242 .82538 L p .707 .577 .707 r
F P
0 g
s
.35242 .82538 m .3575 .80816 L .34132 .81418 L p .707 .577 .707 r
F P
0 g
s
.67375 .79406 m .66867 .81128 L .64243 .79836 L p .707 .577 .707 r
F P
0 g
s
.64243 .79836 m .64751 .78114 L .67375 .79406 L p .707 .577 .707 r
F P
0 g
s
.17067 .75481 m .16559 .77203 L .17731 .78601 L p .707 .577 .707 r
F P
0 g
s
.1529 .62768 m .15331 .6833 L .1562 .69174 L p .707 .577 .707 r
F P
0 g
s
.16336 .75642 m .1619 .71923 L .15901 .71127 L p .707 .577 .707 r
F P
0 g
s
.64556 .28548 m .64046 .78679 L .63638 .77452 L p .707 .577 .707 r
F P
0 g
s
.63638 .77452 m .64147 .27321 L .64556 .28548 L p .707 .577 .707 r
F P
0 g
s
.16559 .77203 m .17067 .75481 L .16833 .74235 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15901 .71127 m .16048 .74845 L .16336 .75642 L p .707 .577 .707 r
F P
0 g
s
.15331 .6833 m .1529 .62768 L .15999 .61935 L p .707 .577 .707 r
F P
0 g
s
.3575 .80816 m .35242 .82538 L .35969 .81566 L p .707 .577 .707 r
F P
0 g
s
.35969 .81566 m .36477 .79845 L .3575 .80816 L p .707 .577 .707 r
F P
0 g
s
.16833 .74235 m .16325 .75957 L .16559 .77203 L p .707 .577 .707 r
F P
0 g
s
.35262 .77887 m .35772 .27756 L .36772 .26568 L p .707 .577 .707 r
F P
0 g
s
.15999 .61935 m .16039 .67498 L .15331 .6833 L p .707 .577 .707 r
F P
0 g
s
.34171 .66937 m .34131 .61375 L .3539 .62147 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16048 .74845 m .15901 .71127 L .1661 .7031 L p .707 .577 .707 r
F P
0 g
s
.16325 .75957 m .16833 .74235 L .1756 .73264 L p .707 .577 .707 r
F P
0 g
s
.16039 .67498 m .15999 .61935 L .17636 .61195 L p .707 .577 .707 r
F P
0 g
s
.36477 .79845 m .35969 .81566 L .35735 .8032 L p .707 .577 .707 r
F P
0 g
s
.1661 .7031 m .16757 .74028 L .16048 .74845 L p .707 .577 .707 r
F P
0 g
s
.1756 .73264 m .17052 .74985 L .16325 .75957 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64147 .27321 m .63638 .77452 L .6186 .76307 L p .707 .577 .707 r
F P
0 g
s
.6186 .76307 m .6237 .26176 L .64147 .27321 L p .707 .577 .707 r
F P
0 g
s
.17636 .61195 m .17676 .66757 L .16039 .67498 L p .707 .577 .707 r
F P
0 g
s
.34131 .61375 m .34171 .66937 L .32066 .66312 L p .707 .577 .707 r
F P
0 g
s
.32066 .66312 m .32025 .6075 L .34131 .61375 L p .707 .577 .707 r
F P
0 g
s
.16757 .74028 m .1661 .7031 L .18246 .69554 L p .707 .577 .707 r
F P
0 g
s
.36262 .76699 m .36772 .26568 L .39083 .25535 L p .707 .577 .707 r
F P
0 g
s
.36772 .26568 m .36262 .76699 L .35262 .77887 L p .707 .577 .707 r
F P
0 g
s
.17052 .74985 m .1756 .73264 L .19178 .72662 L p .707 .577 .707 r
F P
0 g
s
.17676 .66757 m .17636 .61195 L .20041 .60619 L p .707 .577 .707 r
F P
0 g
s
.18246 .69554 m .18393 .73272 L .16757 .74028 L p .707 .577 .707 r
F P
0 g
s
.19178 .72662 m .1867 .74384 L .17052 .74985 L p .707 .577 .707 r
F P
0 g
s
.3473 .69224 m .34876 .72942 L .32773 .7241 L p .707 .577 .707 r
F P
0 g
s
.32773 .7241 m .32626 .68691 L .3473 .69224 L p .707 .577 .707 r
F P
0 g
s
.32025 .6075 m .32066 .66312 L .2932 .65896 L p .707 .577 .707 r
F P
0 g
s
.2932 .65896 m .2928 .60334 L .32025 .6075 L p .707 .577 .707 r
F P
0 g
s
.20041 .60619 m .20081 .66182 L .17676 .66757 L p .707 .577 .707 r
F P
0 g
s
.6237 .26176 m .6186 .76307 L .58888 .75355 L p .707 .577 .707 r
F P
0 g
s
.58888 .75355 m .59398 .25224 L .6237 .26176 L p .707 .577 .707 r
F P
0 g
s
.20081 .66182 m .20041 .60619 L .22979 .60265 L p .707 .577 .707 r
F P
0 g
s
.18393 .73272 m .18246 .69554 L .2065 .68931 L p .707 .577 .707 r
F P
0 g
s
.1867 .74384 m .19178 .72662 L .21528 .72489 L p .707 .577 .707 r
F P
0 g
s
.2928 .60334 m .2932 .65896 L .26203 .65729 L p .707 .577 .707 r
F P
0 g
s
.26203 .65729 m .26163 .60167 L .2928 .60334 L p .707 .577 .707 r
F P
0 g
s
.35071 .772 m .34563 .78922 L .32566 .77508 L p .707 .577 .707 r
F P
0 g
s
.32566 .77508 m .33074 .75786 L .35071 .772 L p .707 .577 .707 r
F P
0 g
s
.2065 .68931 m .20797 .72649 L .18393 .73272 L p .707 .577 .707 r
F P
0 g
s
.32626 .68691 m .32773 .7241 L .3003 .72096 L p .707 .577 .707 r
F P
0 g
s
.3003 .72096 m .29883 .68378 L .32626 .68691 L p .707 .577 .707 r
F P
0 g
s
.23019 .65827 m .22979 .60265 L .26163 .60167 L p .707 .577 .707 r
F P
0 g
s
.22979 .60265 m .23019 .65827 L .20081 .66182 L p .707 .577 .707 r
F P
0 g
s
.21528 .72489 m .2102 .7421 L .1867 .74384 L p .707 .577 .707 r
F P
0 g
s
.39083 .25535 m .38573 .75666 L .36262 .76699 L p .707 .577 .707 r
F P
0 g
s
.38573 .75666 m .39083 .25535 L .42479 .24758 L p .707 .577 .707 r
F P
0 g
s
.26163 .60167 m .26203 .65729 L .23019 .65827 L p .707 .577 .707 r
F P
0 g
s
.72869 .65714 m .72829 .60152 L .69712 .59984 L p .707 .577 .707 r
F P
0 g
s
.72829 .60152 m .72869 .65714 L .76053 .65616 L p .707 .577 .707 r
F P
0 g
s
.76053 .65616 m .76012 .60053 L .72829 .60152 L p .707 .577 .707 r
F P
0 g
s
.76012 .60053 m .76053 .65616 L .78991 .65261 L p .707 .577 .707 r
F P
0 g
s
.78991 .65261 m .78951 .59699 L .76012 .60053 L p .707 .577 .707 r
F P
0 g
s
.20797 .72649 m .2065 .68931 L .23587 .68503 L p .707 .577 .707 r
F P
0 g
s
.69752 .65547 m .69712 .59984 L .66966 .59568 L p .707 .577 .707 r
F P
0 g
s
.69712 .59984 m .69752 .65547 L .72869 .65714 L p .707 .577 .707 r
F P
0 g
s
.2102 .7421 m .21528 .72489 L .24379 .72761 L p .707 .577 .707 r
F P
0 g
s
.29883 .68378 m .3003 .72096 L .26915 .72031 L p .707 .577 .707 r
F P
0 g
s
.26915 .72031 m .26768 .68313 L .29883 .68378 L p .707 .577 .707 r
F P
0 g
s
.33074 .75786 m .32566 .77508 L .29942 .76216 L p .707 .577 .707 r
F P
0 g
s
.29942 .76216 m .3045 .74494 L .33074 .75786 L p .707 .577 .707 r
F P
0 g
s
.23587 .68503 m .23734 .72222 L .20797 .72649 L p .707 .577 .707 r
F P
0 g
s
.59398 .25224 m .58888 .75355 L .55011 .7469 L p .707 .577 .707 r
F P
0 g
s
.55011 .7469 m .55521 .24558 L .59398 .25224 L p .707 .577 .707 r
F P
0 g
s
.78951 .59699 m .78991 .65261 L .81396 .64686 L p .707 .577 .707 r
F P
0 g
s
.81396 .64686 m .81356 .59123 L .78951 .59699 L p .707 .577 .707 r
F P
0 g
s
.23734 .72222 m .23587 .68503 L .26768 .68313 L p .707 .577 .707 r
F P
0 g
s
.24379 .72761 m .23871 .74483 L .2102 .7421 L p .707 .577 .707 r
F P
0 g
s
.26768 .68313 m .26915 .72031 L .23734 .72222 L p .707 .577 .707 r
F P
0 g
s
.73577 .71634 m .7343 .67916 L .70315 .67851 L p .707 .577 .707 r
F P
0 g
s
.7343 .67916 m .73577 .71634 L .76758 .71443 L p .707 .577 .707 r
F P
0 g
s
.76758 .71443 m .76611 .67725 L .7343 .67916 L p .707 .577 .707 r
F P
0 g
s
.76611 .67725 m .76758 .71443 L .79694 .71016 L p .707 .577 .707 r
F P
0 g
s
.79694 .71016 m .79548 .67298 L .76611 .67725 L p .707 .577 .707 r
F P
0 g
s
.66966 .59568 m .67006 .6513 L .69752 .65547 L p .707 .577 .707 r
F P
0 g
s
.67006 .6513 m .66966 .59568 L .64861 .58943 L p .707 .577 .707 r
F P
0 g
s
.23871 .74483 m .24379 .72761 L .27453 .73452 L p .707 .577 .707 r
F P
0 g
s
.41969 .7489 m .42479 .24758 L .46627 .24314 L p .707 .577 .707 r
F P
0 g
s
.42479 .24758 m .41969 .7489 L .38573 .75666 L p .707 .577 .707 r
F P
0 g
s
.3045 .74494 m .29942 .76216 L .26945 .75174 L p .707 .577 .707 r
F P
0 g
s
.26945 .75174 m .27453 .73452 L .3045 .74494 L p .707 .577 .707 r
F P
0 g
s
.70462 .71569 m .70315 .67851 L .67572 .67537 L p .707 .577 .707 r
F P
0 g
s
.70315 .67851 m .70462 .71569 L .73577 .71634 L p .707 .577 .707 r
F P
0 g
s
.27453 .73452 m .26945 .75174 L .23871 .74483 L p .707 .577 .707 r
F P
0 g
s
.79548 .67298 m .79694 .71016 L .82099 .70393 L p .707 .577 .707 r
F P
0 g
s
.82099 .70393 m .81952 .66675 L .79548 .67298 L p .707 .577 .707 r
F P
0 g
s
.81356 .59123 m .81396 .64686 L .83033 .63945 L p .707 .577 .707 r
F P
0 g
s
.83033 .63945 m .82993 .58383 L .81356 .59123 L p .707 .577 .707 r
F P
0 g
s
.67572 .67537 m .67719 .71255 L .70462 .71569 L p .707 .577 .707 r
F P
0 g
s
.55521 .24558 m .55011 .7469 L .50611 .74376 L p .707 .577 .707 r
F P
0 g
s
.50611 .74376 m .51121 .24245 L .55521 .24558 L p .707 .577 .707 r
F P
0 g
s
.7337 .76766 m .73878 .75044 L .70882 .74002 L p .707 .577 .707 r
F P
0 g
s
.73878 .75044 m .7337 .76766 L .76444 .77457 L p .707 .577 .707 r
F P
0 g
s
.76444 .77457 m .76952 .75735 L .73878 .75044 L p .707 .577 .707 r
F P
0 g
s
.64861 .58943 m .64901 .64506 L .67006 .6513 L p .707 .577 .707 r
F P
0 g
s
.70374 .75723 m .70882 .74002 L .68257 .7271 L p .707 .577 .707 r
F P
0 g
s
.70882 .74002 m .70374 .75723 L .7337 .76766 L p .707 .577 .707 r
F P
0 g
s
.46117 .74445 m .46627 .24314 L .51121 .24245 L p .707 .577 .707 r
F P
0 g
s
.46627 .24314 m .46117 .74445 L .41969 .7489 L p .707 .577 .707 r
F P
0 g
s
.67719 .71255 m .67572 .67537 L .65468 .67005 L p .707 .577 .707 r
F P
0 g
s
.76952 .75735 m .76444 .77457 L .79296 .77729 L p .707 .577 .707 r
F P
0 g
s
.79296 .77729 m .79804 .76007 L .76952 .75735 L p .707 .577 .707 r
F P
0 g
s
.51121 .24245 m .50611 .74376 L .46117 .74445 L p .707 .577 .707 r
F P
0 g
s
.64901 .64506 m .64861 .58943 L .63601 .58171 L p .707 .577 .707 r
F P
0 g
s
.68257 .7271 m .67749 .74432 L .70374 .75723 L p .707 .577 .707 r
F P
0 g
s
.65468 .67005 m .65615 .70723 L .67719 .71255 L p .707 .577 .707 r
F P
0 g
s
.81952 .66675 m .82099 .70393 L .83735 .69637 L p .707 .577 .707 r
F P
0 g
s
.83735 .69637 m .83588 .65918 L .81952 .66675 L p .707 .577 .707 r
F P
0 g
s
.67749 .74432 m .68257 .7271 L .66261 .71296 L p .707 .577 .707 r
F P
0 g
s
.79804 .76007 m .79296 .77729 L .81645 .77556 L p .707 .577 .707 r
F P
0 g
s
.81645 .77556 m .82153 .75834 L .79804 .76007 L p .707 .577 .707 r
F P
0 g
s
.66261 .71296 m .65753 .73018 L .67749 .74432 L p .707 .577 .707 r
F P
0 g
s
.63601 .58171 m .63642 .63734 L .64901 .64506 L p .707 .577 .707 r
F P
0 g
s
.82993 .58383 m .83033 .63945 L .83741 .63113 L p .707 .577 .707 r
F P
0 g
s
.83741 .63113 m .83701 .5755 L .82993 .58383 L p .707 .577 .707 r
F P
0 g
s
.65615 .70723 m .65468 .67005 L .64211 .66306 L p .707 .577 .707 r
F P
0 g
s
.63642 .63734 m .63601 .58171 L .63312 .57328 L p .707 .577 .707 r
F P
0 g
s
.64211 .66306 m .64358 .70024 L .65615 .70723 L p .707 .577 .707 r
F P
0 g
s
.65753 .73018 m .66261 .71296 L .65088 .69897 L p .707 .577 .707 r
F P
0 g
s
.82153 .75834 m .81645 .77556 L .83263 .76954 L p .707 .577 .707 r
F P
0 g
s
.83263 .76954 m .83771 .75232 L .82153 .75834 L p .707 .577 .707 r
F P
0 g
s
.83588 .65918 m .83735 .69637 L .84444 .6882 L p .707 .577 .707 r
F P
0 g
s
.84444 .6882 m .84297 .65102 L .83588 .65918 L p .707 .577 .707 r
F P
0 g
s
.65088 .69897 m .6458 .71619 L .65753 .73018 L p .707 .577 .707 r
F P
0 g
s
.63312 .57328 m .63352 .6289 L .63642 .63734 L p .707 .577 .707 r
F P
0 g
s
.83701 .5755 m .83741 .63113 L .83452 .62269 L p .707 .577 .707 r
F P
0 g
s
.83452 .62269 m .83412 .56706 L .83701 .5755 L p .707 .577 .707 r
F P
0 g
s
.64358 .70024 m .64211 .66306 L .63922 .65509 L p .707 .577 .707 r
F P
0 g
s
.6458 .71619 m .65088 .69897 L .64854 .68651 L p .707 .577 .707 r
F P
0 g
s
.63922 .65509 m .64069 .69227 L .64358 .70024 L p .707 .577 .707 r
F P
0 g
s
.63352 .6289 m .63312 .57328 L .6402 .56495 L p .707 .577 .707 r
F P
0 g
s
.83771 .75232 m .83263 .76954 L .8399 .75983 L p .707 .577 .707 r
F P
0 g
s
.8399 .75983 m .84498 .74261 L .83771 .75232 L p .707 .577 .707 r
F P
0 g
s
.64854 .68651 m .64346 .70373 L .6458 .71619 L p .707 .577 .707 r
F P
0 g
s
.84297 .65102 m .84444 .6882 L .84155 .68023 L p .707 .577 .707 r
F P
0 g
s
.84155 .68023 m .84009 .64305 L .84297 .65102 L p .707 .577 .707 r
F P
0 g
s
.6402 .56495 m .6406 .62057 L .63352 .6289 L p .707 .577 .707 r
F P
0 g
s
.83412 .56706 m .83452 .62269 L .82193 .61497 L p .707 .577 .707 r
F P
0 g
s
.82193 .61497 m .82152 .55934 L .83412 .56706 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64069 .69227 m .63922 .65509 L .64631 .64693 L p .707 .577 .707 r
F P
0 g
s
.64346 .70373 m .64854 .68651 L .65582 .6768 L p .707 .577 .707 r
F P
0 g
s
.38568 .6195 m .38528 .56388 L .35411 .56221 L p .707 .577 .707 r
F P
0 g
s
.38528 .56388 m .38568 .6195 L .41752 .61852 L p .707 .577 .707 r
F P
0 g
s
.41752 .61852 m .41711 .5629 L .38528 .56388 L p .707 .577 .707 r
F P
0 g
s
.41711 .5629 m .41752 .61852 L .4469 .61498 L p .707 .577 .707 r
F P
0 g
s
.4469 .61498 m .4465 .55935 L .41711 .5629 L p .707 .577 .707 r
F P
0 g
s
.84498 .74261 m .8399 .75983 L .83757 .74737 L p .707 .577 .707 r
F P
0 g
s
.83757 .74737 m .84265 .73015 L .84498 .74261 L p .707 .577 .707 r
F P
0 g
s
.64631 .64693 m .64778 .68411 L .64069 .69227 L p .707 .577 .707 r
F P
0 g
s
.6406 .62057 m .6402 .56495 L .65657 .55754 L p .707 .577 .707 r
F P
0 g
s
.65582 .6768 m .65074 .69402 L .64346 .70373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.35451 .61783 m .35411 .56221 L .32665 .55805 L p .707 .577 .707 r
F P
0 g
s
.35411 .56221 m .35451 .61783 L .38568 .6195 L p .707 .577 .707 r
F P
0 g
s
.84009 .64305 m .84155 .68023 L .82898 .67325 L p .707 .577 .707 r
F P
0 g
s
.82898 .67325 m .82751 .63606 L .84009 .64305 L p .707 .577 .707 r
F P
0 g
s
.4465 .55935 m .4469 .61498 L .47095 .60922 L p .707 .577 .707 r
F P
0 g
s
.47095 .60922 m .47055 .5536 L .4465 .55935 L p .707 .577 .707 r
F P
0 g
s
.65657 .55754 m .65697 .61317 L .6406 .62057 L p .707 .577 .707 r
F P
0 g
s
.82152 .55934 m .82193 .61497 L .80087 .60872 L p .707 .577 .707 r
F P
0 g
s
.80087 .60872 m .80047 .5531 L .82152 .55934 L p .707 .577 .707 r
F P
0 g
s
.39276 .68048 m .39129 .64329 L .36014 .64265 L p .707 .577 .707 r
F P
0 g
s
.39129 .64329 m .39276 .68048 L .42457 .67857 L p .707 .577 .707 r
F P
0 g
s
.42457 .67857 m .4231 .64139 L .39129 .64329 L p .707 .577 .707 r
F P
0 g
s
.4231 .64139 m .42457 .67857 L .45393 .67429 L p .707 .577 .707 r
F P
0 g
s
.45393 .67429 m .45247 .63711 L .4231 .64139 L p .707 .577 .707 r
F P
0 g
s
.32665 .55805 m .32705 .61367 L .35451 .61783 L p .707 .577 .707 r
F P
0 g
s
.32705 .61367 m .32665 .55805 L .3056 .5518 L p .707 .577 .707 r
F P
0 g
s
.64778 .68411 m .64631 .64693 L .66268 .63936 L p .707 .577 .707 r
F P
0 g
s
.36161 .67983 m .36014 .64265 L .33271 .63951 L p .707 .577 .707 r
F P
0 g
s
.36014 .64265 m .36161 .67983 L .39276 .68048 L p .707 .577 .707 r
F P
0 g
s
.65074 .69402 m .65582 .6768 L .67199 .67078 L p .707 .577 .707 r
F P
0 g
s
.65697 .61317 m .65657 .55754 L .68062 .55179 L p .707 .577 .707 r
F P
0 g
s
.84265 .73015 m .83757 .74737 L .82584 .73338 L p .707 .577 .707 r
F P
0 g
s
.82584 .73338 m .83092 .71616 L .84265 .73015 L p .707 .577 .707 r
F P
0 g
s
.66268 .63936 m .66414 .67654 L .64778 .68411 L p .707 .577 .707 r
F P
0 g
s
.45247 .63711 m .45393 .67429 L .47798 .66807 L p .707 .577 .707 r
F P
0 g
s
.47798 .66807 m .47651 .63089 L .45247 .63711 L p .707 .577 .707 r
F P
0 g
s
.67199 .67078 m .66691 .688 L .65074 .69402 L p .707 .577 .707 r
F P
0 g
s
.47055 .5536 m .47095 .60922 L .48732 .60182 L p .707 .577 .707 r
F P
0 g
s
.48732 .60182 m .48692 .54619 L .47055 .5536 L p .707 .577 .707 r
F P
0 g
s
.33271 .63951 m .33418 .67669 L .36161 .67983 L p .707 .577 .707 r
F P
0 g
s
.39069 .73146 m .39577 .71424 L .36581 .70382 L p .707 .577 .707 r
F P
0 g
s
.39577 .71424 m .39069 .73146 L .42143 .73837 L p .707 .577 .707 r
F P
0 g
s
.42143 .73837 m .42651 .72115 L .39577 .71424 L p .707 .577 .707 r
F P
0 g
s
.82751 .63606 m .82898 .67325 L .80795 .66792 L p .707 .577 .707 r
F P
0 g
s
.80795 .66792 m .80648 .63074 L .82751 .63606 L p .707 .577 .707 r
F P
0 g
s
.3056 .5518 m .306 .60742 L .32705 .61367 L p .707 .577 .707 r
F P
0 g
s
.36073 .72103 m .36581 .70382 L .33956 .6909 L p .707 .577 .707 r
F P
0 g
s
.36581 .70382 m .36073 .72103 L .39069 .73146 L p .707 .577 .707 r
F P
0 g
s
.80047 .5531 m .80087 .60872 L .77341 .60456 L p .707 .577 .707 r
F P
0 g
s
.77341 .60456 m .77301 .54893 L .80047 .5531 L p .707 .577 .707 r
F P
0 g
s
.33418 .67669 m .33271 .63951 L .31167 .63418 L p .707 .577 .707 r
F P
0 g
s
.42651 .72115 m .42143 .73837 L .44995 .74109 L p .707 .577 .707 r
F P
0 g
s
.44995 .74109 m .45503 .72387 L .42651 .72115 L p .707 .577 .707 r
F P
0 g
s
.68062 .55179 m .68103 .60741 L .65697 .61317 L p .707 .577 .707 r
F P
0 g
s
.306 .60742 m .3056 .5518 L .293 .54408 L p .707 .577 .707 r
F P
0 g
s
.33956 .6909 m .33448 .70812 L .36073 .72103 L p .707 .577 .707 r
F P
0 g
s
.66414 .67654 m .66268 .63936 L .68672 .63314 L p .707 .577 .707 r
F P
0 g
s
.68103 .60741 m .68062 .55179 L .71 .54825 L p .707 .577 .707 r
F P
0 g
s
.31167 .63418 m .31314 .67136 L .33418 .67669 L p .707 .577 .707 r
F P
0 g
s
.47651 .63089 m .47798 .66807 L .49434 .6605 L p .707 .577 .707 r
F P
0 g
s
.49434 .6605 m .49287 .62332 L .47651 .63089 L p .707 .577 .707 r
F P
0 g
s
.33448 .70812 m .33956 .6909 L .3196 .67676 L p .707 .577 .707 r
F P
0 g
s
.66691 .688 m .67199 .67078 L .69549 .66905 L p .707 .577 .707 r
F P
0 g
s
.45503 .72387 m .44995 .74109 L .47344 .73936 L p .707 .577 .707 r
F P
0 g
s
.47344 .73936 m .47852 .72214 L .45503 .72387 L p .707 .577 .707 r
F P
0 g
s
.77301 .54893 m .77341 .60456 L .74224 .60289 L p .707 .577 .707 r
F P
0 g
s
.74224 .60289 m .74184 .54726 L .77301 .54893 L p .707 .577 .707 r
F P
0 g
s
.83092 .71616 m .82584 .73338 L .80588 .71924 L p .707 .577 .707 r
F P
0 g
s
.80588 .71924 m .81096 .70202 L .83092 .71616 L p .707 .577 .707 r
F P
0 g
s
.68672 .63314 m .68819 .67032 L .66414 .67654 L p .707 .577 .707 r
F P
0 g
s
.80648 .63074 m .80795 .66792 L .78051 .66478 L p .707 .577 .707 r
F P
0 g
s
.78051 .66478 m .77904 .6276 L .80648 .63074 L p .707 .577 .707 r
F P
0 g
s
.3196 .67676 m .31452 .69398 L .33448 .70812 L p .707 .577 .707 r
F P
0 g
s
.293 .54408 m .29341 .5997 L .306 .60742 L p .707 .577 .707 r
F P
0 g
s
.48692 .54619 m .48732 .60182 L .4944 .59349 L p .707 .577 .707 r
F P
0 g
s
.4944 .59349 m .494 .53787 L .48692 .54619 L p .707 .577 .707 r
F P
0 g
s
.69549 .66905 m .69041 .68627 L .66691 .688 L p .707 .577 .707 r
F P
0 g
s
.71041 .60387 m .71 .54825 L .74184 .54726 L p .707 .577 .707 r
F P
0 g
s
.71 .54825 m .71041 .60387 L .68103 .60741 L p .707 .577 .707 r
F P
0 g
s
.74184 .54726 m .74224 .60289 L .71041 .60387 L p .707 .577 .707 r
F P
0 g
s
.31314 .67136 m .31167 .63418 L .2991 .6272 L p .707 .577 .707 r
F P
0 g
s
.68819 .67032 m .68672 .63314 L .71608 .62886 L p .707 .577 .707 r
F P
0 g
s
.29341 .5997 m .293 .54408 L .29011 .53564 L p .707 .577 .707 r
F P
0 g
s
.2991 .6272 m .30057 .66438 L .31314 .67136 L p .707 .577 .707 r
F P
0 g
s
.31452 .69398 m .3196 .67676 L .30787 .66277 L p .707 .577 .707 r
F P
0 g
s
.69041 .68627 m .69549 .66905 L .72401 .67177 L p .707 .577 .707 r
F P
0 g
s
.77904 .6276 m .78051 .66478 L .74936 .66413 L p .707 .577 .707 r
F P
0 g
s
.74936 .66413 m .7479 .62695 L .77904 .6276 L p .707 .577 .707 r
F P
0 g
s
.47852 .72214 m .47344 .73936 L .48962 .73334 L p .707 .577 .707 r
F P
0 g
s
.48962 .73334 m .4947 .71612 L .47852 .72214 L p .707 .577 .707 r
F P
0 g
s
.81096 .70202 m .80588 .71924 L .77963 .70632 L p .707 .577 .707 r
F P
0 g
s
.77963 .70632 m .78471 .68911 L .81096 .70202 L p .707 .577 .707 r
F P
0 g
s
.71608 .62886 m .71755 .66604 L .68819 .67032 L p .707 .577 .707 r
F P
0 g
s
.49287 .62332 m .49434 .6605 L .50143 .65233 L p .707 .577 .707 r
F P
0 g
s
.50143 .65233 m .49996 .61515 L .49287 .62332 L p .707 .577 .707 r
F P
0 g
s
.71755 .66604 m .71608 .62886 L .7479 .62695 L p .707 .577 .707 r
F P
0 g
s
.30787 .66277 m .30279 .67999 L .31452 .69398 L p .707 .577 .707 r
F P
0 g
s
.72401 .67177 m .71893 .68899 L .69041 .68627 L p .707 .577 .707 r
F P
0 g
s
.7479 .62695 m .74936 .66413 L .71755 .66604 L p .707 .577 .707 r
F P
0 g
s
.29011 .53564 m .29051 .59127 L .29341 .5997 L p .707 .577 .707 r
F P
0 g
s
.71893 .68899 m .72401 .67177 L .75475 .67868 L p .707 .577 .707 r
F P
0 g
s
.494 .53787 m .4944 .59349 L .49151 .58505 L p .707 .577 .707 r
F P
0 g
s
.49151 .58505 m .4911 .52943 L .494 .53787 L p .707 .577 .707 r
F P
0 g
s
.78471 .68911 m .77963 .70632 L .74967 .6959 L p .707 .577 .707 r
F P
0 g
s
.74967 .6959 m .75475 .67868 L .78471 .68911 L p .707 .577 .707 r
F P
0 g
s
.30057 .66438 m .2991 .6272 L .29621 .61923 L p .707 .577 .707 r
F P
0 g
s
.75475 .67868 m .74967 .6959 L .71893 .68899 L p .707 .577 .707 r
F P
0 g
s
.30279 .67999 m .30787 .66277 L .30553 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29621 .61923 m .29768 .65641 L .30057 .66438 L p .707 .577 .707 r
F P
0 g
s
.29051 .59127 m .29011 .53564 L .29719 .52731 L p .707 .577 .707 r
F P
0 g
s
.4947 .71612 m .48962 .73334 L .49689 .72363 L p .707 .577 .707 r
F P
0 g
s
.49689 .72363 m .50197 .70641 L .4947 .71612 L p .707 .577 .707 r
F P
0 g
s
.30553 .65031 m .30045 .66753 L .30279 .67999 L p .707 .577 .707 r
F P
0 g
s
.49996 .61515 m .50143 .65233 L .49854 .64437 L p .707 .577 .707 r
F P
0 g
s
.49854 .64437 m .49708 .60719 L .49996 .61515 L p .707 .577 .707 r
F P
0 g
s
.29719 .52731 m .29759 .58294 L .29051 .59127 L p .707 .577 .707 r
F P
0 g
s
.4911 .52943 m .49151 .58505 L .47892 .57733 L p .707 .577 .707 r
F P
0 g
s
.47892 .57733 m .47851 .52171 L .4911 .52943 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29768 .65641 m .29621 .61923 L .3033 .61106 L p .707 .577 .707 r
F P
0 g
s
.30045 .66753 m .30553 .65031 L .31281 .6406 L p .707 .577 .707 r
F P
0 g
s
.29759 .58294 m .29719 .52731 L .31356 .51991 L p .707 .577 .707 r
F P
0 g
s
.50197 .70641 m .49689 .72363 L .49455 .71117 L p .707 .577 .707 r
F P
0 g
s
.49455 .71117 m .49963 .69395 L .50197 .70641 L p .707 .577 .707 r
F P
0 g
s
.3033 .61106 m .30477 .64824 L .29768 .65641 L p .707 .577 .707 r
F P
0 g
s
.31281 .6406 m .30773 .65782 L .30045 .66753 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49708 .60719 m .49854 .64437 L .48597 .63738 L p .707 .577 .707 r
F P
0 g
s
.48597 .63738 m .4845 .6002 L .49708 .60719 L p .707 .577 .707 r
F P
0 g
s
.31356 .51991 m .31396 .57553 L .29759 .58294 L p .707 .577 .707 r
F P
0 g
s
.47851 .52171 m .47892 .57733 L .45786 .57109 L p .707 .577 .707 r
F P
0 g
s
.45786 .57109 m .45746 .51546 L .47851 .52171 L p .707 .577 .707 r
F P
0 g
s
.30477 .64824 m .3033 .61106 L .31967 .6035 L p .707 .577 .707 r
F P
0 g
s
.30773 .65782 m .31281 .6406 L .32898 .63458 L p .707 .577 .707 r
F P
0 g
s
.31396 .57553 m .31356 .51991 L .33761 .51415 L p .707 .577 .707 r
F P
0 g
s
.49963 .69395 m .49455 .71117 L .48283 .69718 L p .707 .577 .707 r
F P
0 g
s
.48283 .69718 m .48791 .67996 L .49963 .69395 L p .707 .577 .707 r
F P
0 g
s
.31967 .6035 m .32113 .64068 L .30477 .64824 L p .707 .577 .707 r
F P
0 g
s
.32898 .63458 m .3239 .6518 L .30773 .65782 L p .707 .577 .707 r
F P
0 g
s
.4845 .6002 m .48597 .63738 L .46493 .63206 L p .707 .577 .707 r
F P
0 g
s
.46493 .63206 m .46347 .59488 L .4845 .6002 L p .707 .577 .707 r
F P
0 g
s
.45746 .51546 m .45786 .57109 L .4304 .56692 L p .707 .577 .707 r
F P
0 g
s
.4304 .56692 m .43 .5113 L .45746 .51546 L p .707 .577 .707 r
F P
0 g
s
.33761 .51415 m .33802 .56978 L .31396 .57553 L p .707 .577 .707 r
F P
0 g
s
.33802 .56978 m .33761 .51415 L .36699 .51061 L p .707 .577 .707 r
F P
0 g
s
.32113 .64068 m .31967 .6035 L .34371 .59727 L p .707 .577 .707 r
F P
0 g
s
.3239 .6518 m .32898 .63458 L .35248 .63285 L p .707 .577 .707 r
F P
0 g
s
.43 .5113 m .4304 .56692 L .39923 .56525 L p .707 .577 .707 r
F P
0 g
s
.39923 .56525 m .39883 .50963 L .43 .5113 L p .707 .577 .707 r
F P
0 g
s
.48791 .67996 m .48283 .69718 L .46287 .68304 L p .707 .577 .707 r
F P
0 g
s
.46287 .68304 m .46795 .66582 L .48791 .67996 L p .707 .577 .707 r
F P
0 g
s
.34371 .59727 m .34518 .63445 L .32113 .64068 L p .707 .577 .707 r
F P
0 g
s
.46347 .59488 m .46493 .63206 L .4375 .62892 L p .707 .577 .707 r
F P
0 g
s
.4375 .62892 m .43603 .59174 L .46347 .59488 L p .707 .577 .707 r
F P
0 g
s
.3674 .56624 m .36699 .51061 L .39883 .50963 L p .707 .577 .707 r
F P
0 g
s
.36699 .51061 m .3674 .56624 L .33802 .56978 L p .707 .577 .707 r
F P
0 g
s
.35248 .63285 m .3474 .65007 L .3239 .6518 L p .707 .577 .707 r
F P
0 g
s
.39883 .50963 m .39923 .56525 L .3674 .56624 L p .707 .577 .707 r
F P
0 g
s
.34518 .63445 m .34371 .59727 L .37307 .593 L p .707 .577 .707 r
F P
0 g
s
.3474 .65007 m .35248 .63285 L .381 .63557 L p .707 .577 .707 r
F P
0 g
s
.43603 .59174 m .4375 .62892 L .40635 .62827 L p .707 .577 .707 r
F P
0 g
s
.40635 .62827 m .40489 .59109 L .43603 .59174 L p .707 .577 .707 r
F P
0 g
s
.46795 .66582 m .46287 .68304 L .43662 .67012 L p .707 .577 .707 r
F P
0 g
s
.43662 .67012 m .4417 .65291 L .46795 .66582 L p .707 .577 .707 r
F P
0 g
s
.37307 .593 m .37454 .63018 L .34518 .63445 L p .707 .577 .707 r
F P
0 g
s
.37454 .63018 m .37307 .593 L .40489 .59109 L p .707 .577 .707 r
F P
0 g
s
.381 .63557 m .37592 .65279 L .3474 .65007 L p .707 .577 .707 r
F P
0 g
s
.40489 .59109 m .40635 .62827 L .37454 .63018 L p .707 .577 .707 r
F P
0 g
s
.37592 .65279 m .381 .63557 L .41174 .64248 L p .707 .577 .707 r
F P
0 g
s
.4417 .65291 m .43662 .67012 L .40666 .6597 L p .707 .577 .707 r
F P
0 g
s
.40666 .6597 m .41174 .64248 L .4417 .65291 L p .707 .577 .707 r
F P
0 g
s
.41174 .64248 m .40666 .6597 L .37592 .65279 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF009J
EPT00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo2@0015YF00<005YFFUH00UYF20001EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001MOol70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001HOol50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
059oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DWoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?OolA0016Ool0
059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`H000=JEP03001JEUYF00IJEP03001J
EUYF009JEPP003ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Qoo`00DWoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P00=Goo001BOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000cOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF3P00
0eYF200015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DWoo
00<005YF000015YF00@005YFFUIJEPP000QJEPH000=JEP03001JEUYF00EJEPH000AJEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJEP06
FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000015YF001JEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00DWoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002moo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;goo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000_Ool0059oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEP0001T000EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00
DWoo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH70004FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool005=oo`04001JEUYF0005
FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP060004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00D0
05YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0000_Ool003eooaX000=JEP8000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00D005YFFUIJEP0002moo`00=goo1P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH7
0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000dOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF0P00;Woo000aOol30004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF10000eYF0P00;Woo000_Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
0002FUH2000^Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00
FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00:goo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<0
05YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP04001JEUYFFUHG0006FUH00`00FUIJEP02FUH3000^Ool002]oo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009JEP`000AJEP03001JEUYF00IJEPH000AJEP03
001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1`0015YF
00<005YF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP03FUH600000eYF000000090004
FUH00`00FUIJEP08FUH7000015YF001JEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEP0000D000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00H002moo`00:goo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00eYF1@001EYF00@005YF0000
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002
FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000_Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP800003FUH005YF009JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP04001JEUYFFUH5000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH200001UYF00000000FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH0
05YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000007FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF000000000eYF00@0
05YFFUIJEPH000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001J
EUYF009JEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF1@000eYF1@001UYF1`001eYF00<005YFFUH01EYF0P00
0UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEPD00003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP03
001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF1`0000AJEP00000000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEP0000<000QJEP03001JEUYF008000EJEP04001JEUYFFUH20002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool002]oo`03001JEP0000AJEP04001JEUYFFUH80008FUH6
0003FUH00`00FUIJEP03FUH300000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP03FUH20003FUH01000FUH0000015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002eoo`00:goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YF00000P0015YF
00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0000=JEP00FUH01UYF1@001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPP00004Ool000000005
Ool>0004FUH01@00FUIJEUYF0000;Goo000[Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0P0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00D005YFFUIJEP0000EJEPL000Mo
o`D000moo`H00003FUH005YF009JEP03001oogoo02]oo`00:goo00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH00002
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH01P00FUIJEUYF001JEP@000=JEP04001JEUYFFUH<0009Ool60004FUH01000FUH000000eYF
0P00;7oo000[Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF1@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@000UYF0P000eYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00h000AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF0000000/Ool002]oo`80
00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEUYFFUH300000eYF001JEP03FUHA0003FUH00`00FUIJEP07FUH30006FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH0
05YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPH000QJEP03001J
EUYF00=JEP03001JEUYF00=JEP<002aoo`00:goo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF
00@005YFFUIJEQL0009JEP03001JEUYF008000AJEP80009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP03001JEUYF00AJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040005FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000/Ool002]oo`8000=J
EP03001JEUYF009JEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EUYF001JEP0015YF0P000eYF0P000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF0`0015YF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000`000UYF4`001UYF00<005YFFUH01EYF0`000UYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF0000;7oo000/Ool01@00FUIJEUYF000015YF00<005YF00001@001UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8000IJEPD0009JEP03001JEUYF00=JEPH000AJEP03001J
EUYF00UJEP04001JEUYF0002FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
10000UYF00<005YFFUH01eYF10001UYF00<005YFFUH00UYF0P00;Goo000]Ool2000015YF001JEUYF
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00@005YFFUIJ
EP<000AJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000MJEP04001JEUYFFUH20005FUH0
0`00FUIJEP02FUH2000]Ool002moo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEP00001JEP020005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01000FUIJEUYF0P00;Woo000_Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP001EYF0`001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF
00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF0000
05YF008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00MJ
EP05001JEUYF001JEP02000`Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000MJEP8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP07001JEP00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YF000000QJEPD0039oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001eYF00<005YF00000P00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01000FUIJEP00<goo000]Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000AJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001J
EUYF009JEP80035oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF
100015YF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP<00003FUH005YF009JEQT000Eoo`800003
FUH005YF00EJEP03001oogoo02ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF10002EYF00<005YFFUH0
1@002eYF00<005YFFUH015YF100000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P000UYF00@005YFFUIJEP8000AJEP<000Qoo`D000moo`8000IJEP80
02moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2`001Woo3P0015YF0P00
00=JEP00000025YF00<005YFFUH015YF4`000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP03001JEUYF009JEP8000=JEP03001J
EP0000Qoo`D0015oo`03001JEUYF009JEP03001JEP0002moo`00;Goo00<005YF000015YF00<005YF
FUH00eYF4P003goo1`0000=JEP0000000UYF100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000UYF0P001eYF00<005YFFUH00P002Goo1@004Woo0P000UYF00@0
05YFFUH002ioo`00;Goo00<005YF000015YF00<005YF00000`000eYF00<005YFFUH01EYF00<005YF
FUH010002Woo1@001EYF00<005YF00000P000UYF00@005YFFUIJEP<00003FUH005YF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH5000:Ool3000EOol2
0004FUH00`00Oomoo`0[Ool002eoo`03001JEP0000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF
00EJEPX000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH20004FUH01000FUIJEUYF0P008goo00<0
05YFFUH00UYF00<007ooOol0:goo000]Ool01000FUH005YF0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00D005YF
FUIJEP0000EJEP80029oo`05001JEUYFFUH0000]Ool002eoo`03001JEP00008000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP05
001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF3@001eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0`0025YF
0P008Goo00D005YF001JEP0002aoo`00;Goo10000eYF4P001eYF00<005YFFUH01EYF0P000UYF00<0
05YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJ
EQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000MJEP03001J
EP0000QJEP04001JEP00000POol200000eYF001oo`0[Ool002eoo`@00003FUH0000000=JEP03001J
EUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00MJEP@000IJEP05001JEUYFFUH00002FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP020006FUH01000FUIJEUYF0`007Woo00<005YF
0000;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF0000
0`0025YF00<005YFFUH00P001EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=J
EP<000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP@001Uo
o`<002eoo`00;Woo0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH00eYF0P000eYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YF
00000`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF
00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH0
10004goo0P0000=JEP000000;Goo000^Ool00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH300000eYF001JEP06FUH200001UYF00000000Ool0009JEP03001JEUYF
00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00=JEP03001J
EUYF00<000MJEP03001JEUYF00AJEPH000Qoo`D0009JEP8002ioo`00;Woo00<005YF00000P001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0025YF0`000goo00@0
05YFFUH000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP@000AJEP03001JEP0000=oo`L000=JEP06001JEUYFFUH007oo0P0015YF
00<005YFFUH01eYF00@005YFFUIJEPP000=JEP04001JEUYFFUH2000^Ool002ioo`80009JEP<000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001J
EUYF0080009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF00<005YF00001P0015YF
10000eYF0P000Woo0`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P00;goo000_Ool01P00FUIJEUYF001oo`L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00H000=JEP03001JEUYF009JEP03001oo`00009JEP800003FUH005YF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP800004FUH005YF0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP0000001Goo10001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00;goo00@005YFFUIJEP<000Io
oaP000Ioo`<000IJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0
05YF00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000Uoo`@0009JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00000aOol0031oo`04001JEUYF0002FUH00`00Oomoo`0>Ool5000@Ool00`00
FUIJEP04FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP03FUH3000=Ool60004FUH01000FUIJEUYF1@00<goo000`Ool00`00FUH00004
FUH2000>Ool5000AOol20004FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH00000
15YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00004goo2000>7oo000aOol20006FUH00`00
Oomoo`0;Ool5000COol01@00FUIJEP00FUH00P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF0000100000=JEP00FUH01EYF00<005YFFUH00UYF0P00E7oo000bOol00`00FUIJEP04FUH3000<
Ool3000EOol30002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEP00
FUH005YF008000IJEP03001JEUYF009JEP8005Aoo`00<goo0P0015YF00<005YFFUH00P0097oo00@0
05YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH20004FUH01000
FUIJEUYF0P00EGoo000eOol01000FUIJEP001EYF0P008goo00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80009JEP04001JEP00001GOol003Ioo`<000MJ
EP80025oo`03001JEP0000<00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00MJEPD0
05Uoo`00>7oo00<005YFFUH01EYF00<005YF00000P007goo0P0000=JEP00Ool00P001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P0000AJEP00000000MJEP04001JEUYF001JOol003Uoo`8000EJEP03001JEUYF009JEP<0
01eoo`03001JEP00009oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH20004FUH00`00FUIJ
EP02FUH2001HOol003]oo`80009JEP03001JEUYF00IJEP@001Uoo`8000Eoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00T0009oo`<00003FUH005YF00EJEP03001oogoo05Eoo`00?Goo0`002EYF00<005YFFUH010004goo
10002Goo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
10003goo0P001UYF0P00EWoo000oOol20008FUH00`00FUIJEP04FUH60008Ool50002FUH2000>Ool6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09000AOol00`00
FUIJEP02FUH00`00FUH0001FOol0045oo`<000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH0
0`00FUIJEP02000EOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80004Ool5000BOol20002
FUH01000FUIJEP00EGoo0014Ool300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P007Woo6P002goo1@0057oo0P0015YF00<007ooOol0DWoo0017Ool30007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool20004FUH01000FUIJEUYF0P002Woo0`00
5Woo00<005YFFUH00UYF00<007ooOol0DWoo001:Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUH00000<goo00D005YFFUIJEP0000EJEP80029oo`05001JEUYFFUH0001DOol004iooa<0
03Ioo`<000QJEP80025oo`05001JEP00FUH0001COol009Uoo`03001JEUYF00IJEP04001JEP00000P
Ool200000eYF001oo`1BOol009Yoo`8000IJEP04001JEUYFFUH3000NOol00`00FUH0001COol009ao
o`8000=JEP03001JEUYF00EJEP@001Yoo`8005Aoo`00WWoo0P0000=JEP00FUH01eYF00<005YFFUH0
100057oo1000E7oo002POol30007FUH00`00FUIJEP04FUH60008Ool600000eYF0000001EOol00:=o
o`8000AJEP03001JEUYF00MJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00EGoo002UOol30000
0eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol00:Qoo`@000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0001GOol00:aoo`@0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP00001HOol00;1oo`H000AJEP04001JEUYFFUH5001JOol00;Io
o`P005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60076 .74981 m .60117 .69427 L .57 .69215 L p .707 .577 .707 r
F P
0 g
s
.60117 .69427 m .60076 .74981 L .6326 .74924 L p .707 .577 .707 r
F P
0 g
s
.6326 .74924 m .633 .6937 L .60117 .69427 L p .707 .577 .707 r
F P
0 g
s
.633 .6937 m .6326 .74924 L .66198 .74603 L p .707 .577 .707 r
F P
0 g
s
.66198 .74603 m .66238 .69049 L .633 .6937 L p .707 .577 .707 r
F P
0 g
s
.56959 .74768 m .57 .69215 L .54254 .68752 L p .707 .577 .707 r
F P
0 g
s
.57 .69215 m .56959 .74768 L .60076 .74981 L p .707 .577 .707 r
F P
0 g
s
.66238 .69049 m .66198 .74603 L .68603 .74048 L p .707 .577 .707 r
F P
0 g
s
.68603 .74048 m .68644 .68494 L .66238 .69049 L p .707 .577 .707 r
F P
0 g
s
.54254 .68752 m .54214 .74306 L .56959 .74768 L p .707 .577 .707 r
F P
0 g
s
.54214 .74306 m .54254 .68752 L .52148 .68086 L p .707 .577 .707 r
F P
0 g
s
.59364 .8113 m .59511 .77444 L .56396 .77129 L p .707 .577 .707 r
F P
0 g
s
.59511 .77444 m .59364 .8113 L .62546 .81165 L p .707 .577 .707 r
F P
0 g
s
.62546 .81165 m .62692 .77478 L .59511 .77444 L p .707 .577 .707 r
F P
0 g
s
.62692 .77478 m .62546 .81165 L .65482 .80916 L p .707 .577 .707 r
F P
0 g
s
.65482 .80916 m .65629 .7723 L .62692 .77478 L p .707 .577 .707 r
F P
0 g
s
.5625 .80815 m .56396 .77129 L .53653 .76565 L p .707 .577 .707 r
F P
0 g
s
.56396 .77129 m .5625 .80815 L .59364 .8113 L p .707 .577 .707 r
F P
0 g
s
.68644 .68494 m .68603 .74048 L .7024 .73315 L p .707 .577 .707 r
F P
0 g
s
.7024 .73315 m .70281 .67761 L .68644 .68494 L p .707 .577 .707 r
F P
0 g
s
.52148 .68086 m .52108 .7364 L .54214 .74306 L p .707 .577 .707 r
F P
0 g
s
.65629 .7723 m .65482 .80916 L .67886 .80409 L p .707 .577 .707 r
F P
0 g
s
.67886 .80409 m .68033 .76722 L .65629 .7723 L p .707 .577 .707 r
F P
0 g
s
.59334 .84267 m .58826 .82436 L .5583 .83124 L p .707 .577 .707 r
F P
0 g
s
.58826 .82436 m .59334 .84267 L .62408 .83397 L p .707 .577 .707 r
F P
0 g
s
.62408 .83397 m .619 .81566 L .58826 .82436 L p .707 .577 .707 r
F P
0 g
s
.53653 .76565 m .53506 .80251 L .5625 .80815 L p .707 .577 .707 r
F P
0 g
s
.619 .81566 m .62408 .83397 L .6526 .8243 L p .707 .577 .707 r
F P
0 g
s
.6526 .8243 m .64752 .80599 L .619 .81566 L p .707 .577 .707 r
F P
0 g
s
.5583 .83124 m .56338 .84955 L .59334 .84267 L p .707 .577 .707 r
F P
0 g
s
.52108 .7364 m .52148 .68086 L .50889 .67282 L p .707 .577 .707 r
F P
0 g
s
.53506 .80251 m .53653 .76565 L .5155 .75807 L p .707 .577 .707 r
F P
0 g
s
.56338 .84955 m .5583 .83124 L .53205 .83563 L p .707 .577 .707 r
F P
0 g
s
.53205 .83563 m .53713 .85394 L .56338 .84955 L p .707 .577 .707 r
F P
0 g
s
.64752 .80599 m .6526 .8243 L .67609 .81461 L p .707 .577 .707 r
F P
0 g
s
.67609 .81461 m .67101 .7963 L .64752 .80599 L p .707 .577 .707 r
F P
0 g
s
.5155 .75807 m .51403 .79493 L .53506 .80251 L p .707 .577 .707 r
F P
0 g
s
.68033 .76722 m .67886 .80409 L .69523 .79692 L p .707 .577 .707 r
F P
0 g
s
.69523 .79692 m .6967 .76005 L .68033 .76722 L p .707 .577 .707 r
F P
0 g
s
.50889 .67282 m .50849 .72835 L .52108 .7364 L p .707 .577 .707 r
F P
0 g
s
.70281 .67761 m .7024 .73315 L .70949 .72475 L p .707 .577 .707 r
F P
0 g
s
.70949 .72475 m .70989 .66921 L .70281 .67761 L p .707 .577 .707 r
F P
0 g
s
.53713 .85394 m .53205 .83563 L .51209 .8371 L p .707 .577 .707 r
F P
0 g
s
.51403 .79493 m .5155 .75807 L .50292 .74929 L p .707 .577 .707 r
F P
0 g
s
.51209 .8371 m .51717 .85541 L .53713 .85394 L p .707 .577 .707 r
F P
0 g
s
.67101 .7963 m .67609 .81461 L .69227 .80585 L p .707 .577 .707 r
F P
0 g
s
.69227 .80585 m .68719 .78755 L .67101 .7963 L p .707 .577 .707 r
F P
0 g
s
.50849 .72835 m .50889 .67282 L .506 .66417 L p .707 .577 .707 r
F P
0 g
s
.50292 .74929 m .50145 .78616 L .51403 .79493 L p .707 .577 .707 r
F P
0 g
s
.6967 .76005 m .69523 .79692 L .70231 .78835 L p .707 .577 .707 r
F P
0 g
s
.70231 .78835 m .70378 .75149 L .6967 .76005 L p .707 .577 .707 r
F P
0 g
s
.506 .66417 m .50559 .71971 L .50849 .72835 L p .707 .577 .707 r
F P
0 g
s
.70989 .66921 m .70949 .72475 L .70659 .7161 L p .707 .577 .707 r
F P
0 g
s
.70659 .7161 m .70699 .66057 L .70989 .66921 L p .707 .577 .707 r
F P
0 g
s
.51717 .85541 m .51209 .8371 L .50036 .8355 L p .707 .577 .707 r
F P
0 g
s
.50036 .8355 m .50544 .85381 L .51717 .85541 L p .707 .577 .707 r
F P
0 g
s
.50145 .78616 m .50292 .74929 L .50004 .74018 L p .707 .577 .707 r
F P
0 g
s
.68719 .78755 m .69227 .80585 L .69954 .79888 L p .707 .577 .707 r
F P
0 g
s
.69954 .79888 m .69446 .78057 L .68719 .78755 L p .707 .577 .707 r
F P
0 g
s
.49389 .82174 m .48879 .31933 L .44478 .3171 L p .707 .577 .707 r
F P
0 g
s
.50559 .71971 m .506 .66417 L .51308 .65577 L p .707 .577 .707 r
F P
0 g
s
.50004 .74018 m .49857 .77704 L .50145 .78616 L p .707 .577 .707 r
F P
0 g
s
.51308 .65577 m .51268 .7113 L .50559 .71971 L p .707 .577 .707 r
F P
0 g
s
.49857 .77704 m .50004 .74018 L .50712 .73161 L p .707 .577 .707 r
F P
0 g
s
.51268 .7113 m .51308 .65577 L .52945 .64844 L p .707 .577 .707 r
F P
0 g
s
.50712 .73161 m .50566 .76848 L .49857 .77704 L p .707 .577 .707 r
F P
0 g
s
.52945 .64844 m .52905 .70397 L .51268 .7113 L p .707 .577 .707 r
F P
0 g
s
.50566 .76848 m .50712 .73161 L .52349 .72444 L p .707 .577 .707 r
F P
0 g
s
.52349 .72444 m .52202 .76131 L .50566 .76848 L p .707 .577 .707 r
F P
0 g
s
.51038 .84233 m .5053 .82403 L .52148 .81527 L p .707 .577 .707 r
F P
0 g
s
.52202 .76131 m .52349 .72444 L .54753 .71937 L p .707 .577 .707 r
F P
0 g
s
.52148 .81527 m .52656 .83357 L .51038 .84233 L p .707 .577 .707 r
F P
0 g
s
.54753 .71937 m .54606 .75623 L .52202 .76131 L p .707 .577 .707 r
F P
0 g
s
.52656 .83357 m .52148 .81527 L .54497 .80558 L p .707 .577 .707 r
F P
0 g
s
.54497 .80558 m .55005 .82389 L .52656 .83357 L p .707 .577 .707 r
F P
0 g
s
.48879 .31933 m .49389 .82174 L .53883 .82024 L p .707 .577 .707 r
F P
0 g
s
.52905 .70397 m .52945 .64844 L .5535 .64289 L p .707 .577 .707 r
F P
0 g
s
.5535 .64289 m .5531 .69843 L .52905 .70397 L p .707 .577 .707 r
F P
0 g
s
.53883 .82024 m .53373 .31783 L .48879 .31933 L p .707 .577 .707 r
F P
0 g
s
.5531 .69843 m .5535 .64289 L .58288 .63968 L p .707 .577 .707 r
F P
0 g
s
.58288 .63968 m .58248 .69521 L .5531 .69843 L p .707 .577 .707 r
F P
0 g
s
.54606 .75623 m .54753 .71937 L .5769 .71688 L p .707 .577 .707 r
F P
0 g
s
.5769 .71688 m .57543 .75375 L .54606 .75623 L p .707 .577 .707 r
F P
0 g
s
.55005 .82389 m .54497 .80558 L .57349 .79591 L p .707 .577 .707 r
F P
0 g
s
.57349 .79591 m .57857 .81422 L .55005 .82389 L p .707 .577 .707 r
F P
0 g
s
.57857 .81422 m .57349 .79591 L .60423 .78721 L p .707 .577 .707 r
F P
0 g
s
.60423 .78721 m .60931 .80552 L .57857 .81422 L p .707 .577 .707 r
F P
0 g
s
.53373 .31783 m .53883 .82024 L .58031 .81514 L p .707 .577 .707 r
F P
0 g
s
.57543 .75375 m .5769 .71688 L .60871 .71723 L p .707 .577 .707 r
F P
0 g
s
.60871 .71723 m .60724 .7541 L .57543 .75375 L p .707 .577 .707 r
F P
0 g
s
.58031 .81514 m .57521 .31273 L .53373 .31783 L p .707 .577 .707 r
F P
0 g
s
.44988 .81951 m .44478 .3171 L .40602 .31136 L p .707 .577 .707 r
F P
0 g
s
.44478 .3171 m .44988 .81951 L .49389 .82174 L p .707 .577 .707 r
F P
0 g
s
.70378 .75149 m .70231 .78835 L .69943 .77924 L p .707 .577 .707 r
F P
0 g
s
.69943 .77924 m .7009 .74237 L .70378 .75149 L p .707 .577 .707 r
F P
0 g
s
.70699 .66057 m .70659 .7161 L .694 .70805 L p .707 .577 .707 r
F P
0 g
s
.694 .70805 m .6944 .65252 L .70699 .66057 L p .707 .577 .707 r
F P
0 g
s
.50544 .85381 m .50036 .8355 L .49802 .831 L p .707 .577 .707 r
F P
0 g
s
.58248 .69521 m .58288 .63968 L .61472 .63911 L p .707 .577 .707 r
F P
0 g
s
.61472 .63911 m .61431 .69464 L .58248 .69521 L p .707 .577 .707 r
F P
0 g
s
.63986 .72038 m .63839 .75724 L .60724 .7541 L p .707 .577 .707 r
F P
0 g
s
.60724 .7541 m .60871 .71723 L .63986 .72038 L p .707 .577 .707 r
F P
0 g
s
.63419 .78033 m .63927 .79864 L .60931 .80552 L p .707 .577 .707 r
F P
0 g
s
.60931 .80552 m .60423 .78721 L .63419 .78033 L p .707 .577 .707 r
F P
0 g
s
.57521 .31273 m .58031 .81514 L .61427 .80696 L p .707 .577 .707 r
F P
0 g
s
.61427 .80696 m .60917 .30455 L .57521 .31273 L p .707 .577 .707 r
F P
0 g
s
.49802 .831 m .5031 .84931 L .50544 .85381 L p .707 .577 .707 r
F P
0 g
s
.69446 .78057 m .69954 .79888 L .69721 .79437 L p .707 .577 .707 r
F P
0 g
s
.69721 .79437 m .69212 .77607 L .69446 .78057 L p .707 .577 .707 r
F P
0 g
s
.25776 .71382 m .25816 .65828 L .22699 .65615 L p .707 .577 .707 r
F P
0 g
s
.25816 .65828 m .25776 .71382 L .28959 .71325 L p .707 .577 .707 r
F P
0 g
s
.28959 .71325 m .28999 .65771 L .25816 .65828 L p .707 .577 .707 r
F P
0 g
s
.28999 .65771 m .28959 .71325 L .31897 .71003 L p .707 .577 .707 r
F P
0 g
s
.31897 .71003 m .31938 .65449 L .28999 .65771 L p .707 .577 .707 r
F P
0 g
s
.41112 .81376 m .40602 .31136 L .3763 .30265 L p .707 .577 .707 r
F P
0 g
s
.40602 .31136 m .41112 .81376 L .44988 .81951 L p .707 .577 .707 r
F P
0 g
s
.22658 .71169 m .22699 .65615 L .19953 .65153 L p .707 .577 .707 r
F P
0 g
s
.22699 .65615 m .22658 .71169 L .25776 .71382 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31938 .65449 m .31897 .71003 L .34302 .70449 L p .707 .577 .707 r
F P
0 g
s
.34302 .70449 m .34343 .64895 L .31938 .65449 L p .707 .577 .707 r
F P
0 g
s
.7009 .74237 m .69943 .77924 L .68686 .77046 L p .707 .577 .707 r
F P
0 g
s
.68686 .77046 m .68832 .7336 L .7009 .74237 L p .707 .577 .707 r
F P
0 g
s
.6944 .65252 m .694 .70805 L .67294 .70139 L p .707 .577 .707 r
F P
0 g
s
.67294 .70139 m .67335 .64586 L .6944 .65252 L p .707 .577 .707 r
F P
0 g
s
.64589 .64124 m .64549 .69677 L .61431 .69464 L p .707 .577 .707 r
F P
0 g
s
.61431 .69464 m .61472 .63911 L .64589 .64124 L p .707 .577 .707 r
F P
0 g
s
.63927 .79864 m .63419 .78033 L .66044 .77594 L p .707 .577 .707 r
F P
0 g
s
.60917 .30455 m .61427 .80696 L .63738 .79648 L p .707 .577 .707 r
F P
0 g
s
.63738 .79648 m .63228 .29408 L .60917 .30455 L p .707 .577 .707 r
F P
0 g
s
.5031 .84931 m .49802 .831 L .5053 .82403 L p .707 .577 .707 r
F P
0 g
s
.19953 .65153 m .19913 .70707 L .22658 .71169 L p .707 .577 .707 r
F P
0 g
s
.19913 .70707 m .19953 .65153 L .17848 .64487 L p .707 .577 .707 r
F P
0 g
s
.25063 .77353 m .2521 .73667 L .22095 .73352 L p .707 .577 .707 r
F P
0 g
s
.2521 .73667 m .25063 .77353 L .28245 .77388 L p .707 .577 .707 r
F P
0 g
s
.28245 .77388 m .28392 .73702 L .2521 .73667 L p .707 .577 .707 r
F P
0 g
s
.5053 .82403 m .51038 .84233 L .5031 .84931 L p .707 .577 .707 r
F P
0 g
s
.28392 .73702 m .28245 .77388 L .31181 .7714 L p .707 .577 .707 r
F P
0 g
s
.31181 .7714 m .31328 .73453 L .28392 .73702 L p .707 .577 .707 r
F P
0 g
s
.69212 .77607 m .69721 .79437 L .68548 .79278 L p .707 .577 .707 r
F P
0 g
s
.68548 .79278 m .6804 .77447 L .69212 .77607 L p .707 .577 .707 r
F P
0 g
s
.21949 .77039 m .22095 .73352 L .19352 .72788 L p .707 .577 .707 r
F P
0 g
s
.22095 .73352 m .21949 .77039 L .25063 .77353 L p .707 .577 .707 r
F P
0 g
s
.34343 .64895 m .34302 .70449 L .35939 .69715 L p .707 .577 .707 r
F P
0 g
s
.35939 .69715 m .3598 .64162 L .34343 .64895 L p .707 .577 .707 r
F P
0 g
s
.3814 .80506 m .3763 .30265 L .35852 .29185 L p .707 .577 .707 r
F P
0 g
s
.3763 .30265 m .3814 .80506 L .41112 .81376 L p .707 .577 .707 r
F P
0 g
s
.17848 .64487 m .17807 .7004 L .19913 .70707 L p .707 .577 .707 r
F P
0 g
s
.31328 .73453 m .31181 .7714 L .33585 .76632 L p .707 .577 .707 r
F P
0 g
s
.33585 .76632 m .33732 .72945 L .31328 .73453 L p .707 .577 .707 r
F P
0 g
s
.25033 .80523 m .24525 .78693 L .21529 .79381 L p .707 .577 .707 r
F P
0 g
s
.24525 .78693 m .25033 .80523 L .28107 .79653 L p .707 .577 .707 r
F P
0 g
s
.28107 .79653 m .27599 .77823 L .24525 .78693 L p .707 .577 .707 r
F P
0 g
s
.67335 .64586 m .67294 .70139 L .64549 .69677 L p .707 .577 .707 r
F P
0 g
s
.64549 .69677 m .64589 .64124 L .67335 .64586 L p .707 .577 .707 r
F P
0 g
s
.19352 .72788 m .19205 .76475 L .21949 .77039 L p .707 .577 .707 r
F P
0 g
s
.27599 .77823 m .28107 .79653 L .30959 .78687 L p .707 .577 .707 r
F P
0 g
s
.30959 .78687 m .30451 .76856 L .27599 .77823 L p .707 .577 .707 r
F P
0 g
s
.68832 .7336 m .68686 .77046 L .66582 .76288 L p .707 .577 .707 r
F P
0 g
s
.66582 .76288 m .66729 .72602 L .68832 .7336 L p .707 .577 .707 r
F P
0 g
s
.21529 .79381 m .22037 .81212 L .25033 .80523 L p .707 .577 .707 r
F P
0 g
s
.17807 .7004 m .17848 .64487 L .16588 .63682 L p .707 .577 .707 r
F P
0 g
s
.19205 .76475 m .19352 .72788 L .17249 .7203 L p .707 .577 .707 r
F P
0 g
s
.22037 .81212 m .21529 .79381 L .18904 .7982 L p .707 .577 .707 r
F P
0 g
s
.18904 .7982 m .19412 .81651 L .22037 .81212 L p .707 .577 .707 r
F P
0 g
s
.30451 .76856 m .30959 .78687 L .33308 .77718 L p .707 .577 .707 r
F P
0 g
s
.33308 .77718 m .328 .75887 L .30451 .76856 L p .707 .577 .707 r
F P
0 g
s
.17249 .7203 m .17102 .75717 L .19205 .76475 L p .707 .577 .707 r
F P
0 g
s
.6804 .77447 m .68548 .79278 L .66552 .79425 L p .707 .577 .707 r
F P
0 g
s
.66552 .79425 m .66044 .77594 L .6804 .77447 L p .707 .577 .707 r
F P
0 g
s
.66729 .72602 m .66582 .76288 L .63839 .75724 L p .707 .577 .707 r
F P
0 g
s
.63839 .75724 m .63986 .72038 L .66729 .72602 L p .707 .577 .707 r
F P
0 g
s
.63228 .29408 m .63738 .79648 L .64738 .78475 L p .707 .577 .707 r
F P
0 g
s
.64738 .78475 m .64228 .28234 L .63228 .29408 L p .707 .577 .707 r
F P
0 g
s
.33732 .72945 m .33585 .76632 L .35222 .75915 L p .707 .577 .707 r
F P
0 g
s
.35222 .75915 m .35369 .72228 L .33732 .72945 L p .707 .577 .707 r
F P
0 g
s
.16588 .63682 m .16548 .69236 L .17807 .7004 L p .707 .577 .707 r
F P
0 g
s
.3598 .64162 m .35939 .69715 L .36648 .68875 L p .707 .577 .707 r
F P
0 g
s
.36648 .68875 m .36688 .63322 L .3598 .64162 L p .707 .577 .707 r
F P
0 g
s
.19412 .81651 m .18904 .7982 L .16908 .79967 L p .707 .577 .707 r
F P
0 g
s
.17102 .75717 m .17249 .7203 L .15991 .71153 L p .707 .577 .707 r
F P
0 g
s
.16908 .79967 m .17416 .81798 L .19412 .81651 L p .707 .577 .707 r
F P
0 g
s
.328 .75887 m .33308 .77718 L .34926 .76842 L p .707 .577 .707 r
F P
0 g
s
.34926 .76842 m .34418 .75012 L .328 .75887 L p .707 .577 .707 r
F P
0 g
s
.16548 .69236 m .16588 .63682 L .16299 .62817 L p .707 .577 .707 r
F P
0 g
s
.36398 .62457 m .36358 .68011 L .35099 .67206 L p .707 .577 .707 r
F P
0 g
s
.35099 .67206 m .35139 .61652 L .36398 .62457 L p .707 .577 .707 r
F P
0 g
s
.36362 .79425 m .35852 .29185 L .35443 .27999 L p .707 .577 .707 r
F P
0 g
s
.36688 .63322 m .36648 .68875 L .36358 .68011 L p .707 .577 .707 r
F P
0 g
s
.36358 .68011 m .36398 .62457 L .36688 .63322 L p .707 .577 .707 r
F P
0 g
s
.35852 .29185 m .36362 .79425 L .3814 .80506 L p .707 .577 .707 r
F P
0 g
s
.15991 .71153 m .15845 .74839 L .17102 .75717 L p .707 .577 .707 r
F P
0 g
s
.66044 .77594 m .66552 .79425 L .63927 .79864 L p .707 .577 .707 r
F P
0 g
s
.35369 .72228 m .35222 .75915 L .35931 .75059 L p .707 .577 .707 r
F P
0 g
s
.35931 .75059 m .36077 .71372 L .35369 .72228 L p .707 .577 .707 r
F P
0 g
s
.16299 .62817 m .16258 .68371 L .16548 .69236 L p .707 .577 .707 r
F P
0 g
s
.17416 .81798 m .16908 .79967 L .15735 .79807 L p .707 .577 .707 r
F P
0 g
s
.15735 .79807 m .16243 .81638 L .17416 .81798 L p .707 .577 .707 r
F P
0 g
s
.15845 .74839 m .15991 .71153 L .15703 .70241 L p .707 .577 .707 r
F P
0 g
s
.34418 .75012 m .34926 .76842 L .35654 .76145 L p .707 .577 .707 r
F P
0 g
s
.35654 .76145 m .35146 .74314 L .34418 .75012 L p .707 .577 .707 r
F P
0 g
s
.64228 .28234 m .64738 .78475 L .64329 .7729 L p .707 .577 .707 r
F P
0 g
s
.64329 .7729 m .63819 .27049 L .64228 .28234 L p .707 .577 .707 r
F P
0 g
s
.16258 .68371 m .16299 .62817 L .17007 .61977 L p .707 .577 .707 r
F P
0 g
s
.15703 .70241 m .15556 .73928 L .15845 .74839 L p .707 .577 .707 r
F P
0 g
s
.36077 .71372 m .35931 .75059 L .35642 .74147 L p .707 .577 .707 r
F P
0 g
s
.35642 .74147 m .35789 .70461 L .36077 .71372 L p .707 .577 .707 r
F P
0 g
s
.35443 .27999 m .35953 .7824 L .36362 .79425 L p .707 .577 .707 r
F P
0 g
s
.35953 .7824 m .35443 .27999 L .36443 .26826 L p .707 .577 .707 r
F P
0 g
s
.17007 .61977 m .16967 .67531 L .16258 .68371 L p .707 .577 .707 r
F P
0 g
s
.16243 .81638 m .15735 .79807 L .15501 .79357 L p .707 .577 .707 r
F P
0 g
s
.15501 .79357 m .16009 .81188 L .16243 .81638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15556 .73928 m .15703 .70241 L .16411 .69385 L p .707 .577 .707 r
F P
0 g
s
.35146 .74314 m .35654 .76145 L .3542 .75694 L p .707 .577 .707 r
F P
0 g
s
.3542 .75694 m .34912 .73864 L .35146 .74314 L p .707 .577 .707 r
F P
0 g
s
.16967 .67531 m .17007 .61977 L .18644 .61244 L p .707 .577 .707 r
F P
0 g
s
.16411 .69385 m .16265 .73071 L .15556 .73928 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63819 .27049 m .64329 .7729 L .62551 .76209 L p .707 .577 .707 r
F P
0 g
s
.62551 .76209 m .62041 .25968 L .63819 .27049 L p .707 .577 .707 r
F P
0 g
s
.35789 .70461 m .35642 .74147 L .34385 .7327 L p .707 .577 .707 r
F P
0 g
s
.34385 .7327 m .34531 .69583 L .35789 .70461 L p .707 .577 .707 r
F P
0 g
s
.18644 .61244 m .18604 .66798 L .16967 .67531 L p .707 .577 .707 r
F P
0 g
s
.35139 .61652 m .35099 .67206 L .32993 .6654 L p .707 .577 .707 r
F P
0 g
s
.32993 .6654 m .33034 .60986 L .35139 .61652 L p .707 .577 .707 r
F P
0 g
s
.16009 .81188 m .15501 .79357 L .16229 .7866 L p .707 .577 .707 r
F P
0 g
s
.16229 .7866 m .16737 .8049 L .16009 .81188 L p .707 .577 .707 r
F P
0 g
s
.16265 .73071 m .16411 .69385 L .18048 .68668 L p .707 .577 .707 r
F P
0 g
s
.34912 .73864 m .3542 .75694 L .34247 .75535 L p .707 .577 .707 r
F P
0 g
s
.34247 .75535 m .33739 .73704 L .34912 .73864 L p .707 .577 .707 r
F P
0 g
s
.18604 .66798 m .18644 .61244 L .21049 .6069 L p .707 .577 .707 r
F P
0 g
s
.36953 .77067 m .36443 .26826 L .38754 .25778 L p .707 .577 .707 r
F P
0 g
s
.36443 .26826 m .36953 .77067 L .35953 .7824 L p .707 .577 .707 r
F P
0 g
s
.18048 .68668 m .17901 .72354 L .16265 .73071 L p .707 .577 .707 r
F P
0 g
s
.33034 .60986 m .32993 .6654 L .30248 .66078 L p .707 .577 .707 r
F P
0 g
s
.30248 .66078 m .30288 .60524 L .33034 .60986 L p .707 .577 .707 r
F P
0 g
s
.34531 .69583 m .34385 .7327 L .32281 .72512 L p .707 .577 .707 r
F P
0 g
s
.32281 .72512 m .32428 .68825 L .34531 .69583 L p .707 .577 .707 r
F P
0 g
s
.21049 .6069 m .21009 .66243 L .18604 .66798 L p .707 .577 .707 r
F P
0 g
s
.21009 .66243 m .21049 .6069 L .23987 .60368 L p .707 .577 .707 r
F P
0 g
s
.17901 .72354 m .18048 .68668 L .20452 .6816 L p .707 .577 .707 r
F P
0 g
s
.62041 .25968 m .62551 .76209 L .59579 .75339 L p .707 .577 .707 r
F P
0 g
s
.59579 .75339 m .59069 .25098 L .62041 .25968 L p .707 .577 .707 r
F P
0 g
s
.16737 .8049 m .16229 .7866 L .17847 .77784 L p .707 .577 .707 r
F P
0 g
s
.17847 .77784 m .18355 .79614 L .16737 .8049 L p .707 .577 .707 r
F P
0 g
s
.30288 .60524 m .30248 .66078 L .2713 .65865 L p .707 .577 .707 r
F P
0 g
s
.2713 .65865 m .27171 .60311 L .30288 .60524 L p .707 .577 .707 r
F P
0 g
s
.33739 .73704 m .34247 .75535 L .32251 .75682 L p .707 .577 .707 r
F P
0 g
s
.32251 .75682 m .31743 .73851 L .33739 .73704 L p .707 .577 .707 r
F P
0 g
s
.23947 .65922 m .23987 .60368 L .27171 .60311 L p .707 .577 .707 r
F P
0 g
s
.23987 .60368 m .23947 .65922 L .21009 .66243 L p .707 .577 .707 r
F P
0 g
s
.20452 .6816 m .20305 .71847 L .17901 .72354 L p .707 .577 .707 r
F P
0 g
s
.27171 .60311 m .2713 .65865 L .23947 .65922 L p .707 .577 .707 r
F P
0 g
s
.73797 .65777 m .73837 .60224 L .7072 .60011 L p .707 .577 .707 r
F P
0 g
s
.73837 .60224 m .73797 .65777 L .7698 .6572 L p .707 .577 .707 r
F P
0 g
s
.7698 .6572 m .77021 .60167 L .73837 .60224 L p .707 .577 .707 r
F P
0 g
s
.32428 .68825 m .32281 .72512 L .29538 .71948 L p .707 .577 .707 r
F P
0 g
s
.29538 .71948 m .29685 .68261 L .32428 .68825 L p .707 .577 .707 r
F P
0 g
s
.38754 .25778 m .39264 .76019 L .36953 .77067 L p .707 .577 .707 r
F P
0 g
s
.39264 .76019 m .38754 .25778 L .4215 .2496 L p .707 .577 .707 r
F P
0 g
s
.77021 .60167 m .7698 .6572 L .79919 .65399 L p .707 .577 .707 r
F P
0 g
s
.79919 .65399 m .79959 .59845 L .77021 .60167 L p .707 .577 .707 r
F P
0 g
s
.20305 .71847 m .20452 .6816 L .23389 .67912 L p .707 .577 .707 r
F P
0 g
s
.7068 .65564 m .7072 .60011 L .67974 .59549 L p .707 .577 .707 r
F P
0 g
s
.7072 .60011 m .7068 .65564 L .73797 .65777 L p .707 .577 .707 r
F P
0 g
s
.18355 .79614 m .17847 .77784 L .20196 .76815 L p .707 .577 .707 r
F P
0 g
s
.79959 .59845 m .79919 .65399 L .82324 .64844 L p .707 .577 .707 r
F P
0 g
s
.82324 .64844 m .82364 .59291 L .79959 .59845 L p .707 .577 .707 r
F P
0 g
s
.20196 .76815 m .20704 .78646 L .18355 .79614 L p .707 .577 .707 r
F P
0 g
s
.29685 .68261 m .29538 .71948 L .26423 .71633 L p .707 .577 .707 r
F P
0 g
s
.26423 .71633 m .2657 .67946 L .29685 .68261 L p .707 .577 .707 r
F P
0 g
s
.31743 .73851 m .32251 .75682 L .29626 .76121 L p .707 .577 .707 r
F P
0 g
s
.29626 .76121 m .29118 .7429 L .31743 .73851 L p .707 .577 .707 r
F P
0 g
s
.23389 .67912 m .23242 .71598 L .20305 .71847 L p .707 .577 .707 r
F P
0 g
s
.23242 .71598 m .23389 .67912 L .2657 .67946 L p .707 .577 .707 r
F P
0 g
s
.59069 .25098 m .59579 .75339 L .55703 .74764 L p .707 .577 .707 r
F P
0 g
s
.55703 .74764 m .55193 .24523 L .59069 .25098 L p .707 .577 .707 r
F P
0 g
s
.2657 .67946 m .26423 .71633 L .23242 .71598 L p .707 .577 .707 r
F P
0 g
s
.67974 .59549 m .67934 .65102 L .7068 .65564 L p .707 .577 .707 r
F P
0 g
s
.67934 .65102 m .67974 .59549 L .65869 .58883 L p .707 .577 .707 r
F P
0 g
s
.73085 .71926 m .73232 .6824 L .70117 .67925 L p .707 .577 .707 r
F P
0 g
s
.73232 .6824 m .73085 .71926 L .76266 .71961 L p .707 .577 .707 r
F P
0 g
s
.76266 .71961 m .76413 .68275 L .73232 .6824 L p .707 .577 .707 r
F P
0 g
s
.76413 .68275 m .76266 .71961 L .79203 .71713 L p .707 .577 .707 r
F P
0 g
s
.79203 .71713 m .79349 .68026 L .76413 .68275 L p .707 .577 .707 r
F P
0 g
s
.4266 .75201 m .4215 .2496 L .46298 .24451 L p .707 .577 .707 r
F P
0 g
s
.4215 .2496 m .4266 .75201 L .39264 .76019 L p .707 .577 .707 r
F P
0 g
s
.6997 .71612 m .70117 .67925 L .67373 .67361 L p .707 .577 .707 r
F P
0 g
s
.70117 .67925 m .6997 .71612 L .73085 .71926 L p .707 .577 .707 r
F P
0 g
s
.20704 .78646 m .20196 .76815 L .23048 .75848 L p .707 .577 .707 r
F P
0 g
s
.23048 .75848 m .23556 .77679 L .20704 .78646 L p .707 .577 .707 r
F P
0 g
s
.29118 .7429 m .29626 .76121 L .2663 .76809 L p .707 .577 .707 r
F P
0 g
s
.2663 .76809 m .26122 .74978 L .29118 .7429 L p .707 .577 .707 r
F P
0 g
s
.82364 .59291 m .82324 .64844 L .83961 .64111 L p .707 .577 .707 r
F P
0 g
s
.83961 .64111 m .84001 .58557 L .82364 .59291 L p .707 .577 .707 r
F P
0 g
s
.65869 .58883 m .65829 .64436 L .67934 .65102 L p .707 .577 .707 r
F P
0 g
s
.79349 .68026 m .79203 .71713 L .81607 .71205 L p .707 .577 .707 r
F P
0 g
s
.81607 .71205 m .81753 .67518 L .79349 .68026 L p .707 .577 .707 r
F P
0 g
s
.55193 .24523 m .55703 .74764 L .51302 .74541 L p .707 .577 .707 r
F P
0 g
s
.51302 .74541 m .50792 .243 L .55193 .24523 L p .707 .577 .707 r
F P
0 g
s
.73054 .75063 m .72546 .73232 L .6955 .7392 L p .707 .577 .707 r
F P
0 g
s
.72546 .73232 m .73054 .75063 L .76129 .74193 L p .707 .577 .707 r
F P
0 g
s
.76129 .74193 m .75621 .72362 L .72546 .73232 L p .707 .577 .707 r
F P
0 g
s
.67373 .67361 m .67227 .71048 L .6997 .71612 L p .707 .577 .707 r
F P
0 g
s
.23556 .77679 m .23048 .75848 L .26122 .74978 L p .707 .577 .707 r
F P
0 g
s
.75621 .72362 m .76129 .74193 L .7898 .73226 L p .707 .577 .707 r
F P
0 g
s
.7898 .73226 m .78472 .71395 L .75621 .72362 L p .707 .577 .707 r
F P
0 g
s
.26122 .74978 m .2663 .76809 L .23556 .77679 L p .707 .577 .707 r
F P
0 g
s
.6955 .7392 m .70058 .75751 L .73054 .75063 L p .707 .577 .707 r
F P
0 g
s
.65829 .64436 m .65869 .58883 L .6461 .58078 L p .707 .577 .707 r
F P
0 g
s
.67227 .71048 m .67373 .67361 L .6527 .66603 L p .707 .577 .707 r
F P
0 g
s
.46808 .74691 m .46298 .24451 L .50792 .243 L p .707 .577 .707 r
F P
0 g
s
.46298 .24451 m .46808 .74691 L .4266 .75201 L p .707 .577 .707 r
F P
0 g
s
.70058 .75751 m .6955 .7392 L .66925 .74359 L p .707 .577 .707 r
F P
0 g
s
.50792 .243 m .51302 .74541 L .46808 .74691 L p .707 .577 .707 r
F P
0 g
s
.66925 .74359 m .67434 .7619 L .70058 .75751 L p .707 .577 .707 r
F P
0 g
s
.78472 .71395 m .7898 .73226 L .8133 .72257 L p .707 .577 .707 r
F P
0 g
s
.8133 .72257 m .80822 .70427 L .78472 .71395 L p .707 .577 .707 r
F P
0 g
s
.6527 .66603 m .65123 .7029 L .67227 .71048 L p .707 .577 .707 r
F P
0 g
s
.81753 .67518 m .81607 .71205 L .83243 .70488 L p .707 .577 .707 r
F P
0 g
s
.83243 .70488 m .8339 .66801 L .81753 .67518 L p .707 .577 .707 r
F P
0 g
s
.6461 .58078 m .64569 .63631 L .65829 .64436 L p .707 .577 .707 r
F P
0 g
s
.84001 .58557 m .83961 .64111 L .84669 .63271 L p .707 .577 .707 r
F P
0 g
s
.84669 .63271 m .84709 .57717 L .84001 .58557 L p .707 .577 .707 r
F P
0 g
s
.67434 .7619 m .66925 .74359 L .64929 .74506 L p .707 .577 .707 r
F P
0 g
s
.65123 .7029 m .6527 .66603 L .64013 .65725 L p .707 .577 .707 r
F P
0 g
s
.64929 .74506 m .65437 .76337 L .67434 .7619 L p .707 .577 .707 r
F P
0 g
s
.80822 .70427 m .8133 .72257 L .82947 .71381 L p .707 .577 .707 r
F P
0 g
s
.82947 .71381 m .82439 .69551 L .80822 .70427 L p .707 .577 .707 r
F P
0 g
s
.64569 .63631 m .6461 .58078 L .6432 .57213 L p .707 .577 .707 r
F P
0 g
s
.64013 .65725 m .63866 .69412 L .65123 .7029 L p .707 .577 .707 r
F P
0 g
s
.8339 .66801 m .83243 .70488 L .83952 .69632 L p .707 .577 .707 r
F P
0 g
s
.83952 .69632 m .84099 .65945 L .8339 .66801 L p .707 .577 .707 r
F P
0 g
s
.6432 .57213 m .6428 .62767 L .64569 .63631 L p .707 .577 .707 r
F P
0 g
s
.84709 .57717 m .84669 .63271 L .84379 .62406 L p .707 .577 .707 r
F P
0 g
s
.84379 .62406 m .8442 .56853 L .84709 .57717 L p .707 .577 .707 r
F P
0 g
s
.65437 .76337 m .64929 .74506 L .63757 .74347 L p .707 .577 .707 r
F P
0 g
s
.63757 .74347 m .64265 .76177 L .65437 .76337 L p .707 .577 .707 r
F P
0 g
s
.63866 .69412 m .64013 .65725 L .63724 .64814 L p .707 .577 .707 r
F P
0 g
s
.82439 .69551 m .82947 .71381 L .83675 .70684 L p .707 .577 .707 r
F P
0 g
s
.83675 .70684 m .83167 .68853 L .82439 .69551 L p .707 .577 .707 r
F P
0 g
s
.6428 .62767 m .6432 .57213 L .65028 .56373 L p .707 .577 .707 r
F P
0 g
s
.63724 .64814 m .63577 .685 L .63866 .69412 L p .707 .577 .707 r
F P
0 g
s
.84099 .65945 m .83952 .69632 L .83663 .6872 L p .707 .577 .707 r
F P
0 g
s
.83663 .6872 m .8381 .65034 L .84099 .65945 L p .707 .577 .707 r
F P
0 g
s
.65028 .56373 m .64988 .61927 L .6428 .62767 L p .707 .577 .707 r
F P
0 g
s
.8442 .56853 m .84379 .62406 L .8312 .61602 L p .707 .577 .707 r
F P
0 g
s
.8312 .61602 m .83161 .56048 L .8442 .56853 L p .707 .577 .707 r
F P
0 g
s
.64265 .76177 m .63757 .74347 L .63523 .73896 L p .707 .577 .707 r
F P
0 g
s
.63523 .73896 m .64031 .75727 L .64265 .76177 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63577 .685 m .63724 .64814 L .64433 .63958 L p .707 .577 .707 r
F P
0 g
s
.83167 .68853 m .83675 .70684 L .83441 .70234 L p .707 .577 .707 r
F P
0 g
s
.83441 .70234 m .82933 .68403 L .83167 .68853 L p .707 .577 .707 r
F P
0 g
s
.39496 .62178 m .39536 .56624 L .36419 .56411 L p .707 .577 .707 r
F P
0 g
s
.39536 .56624 m .39496 .62178 L .42679 .62121 L p .707 .577 .707 r
F P
0 g
s
.42679 .62121 m .4272 .56567 L .39536 .56624 L p .707 .577 .707 r
F P
0 g
s
.64988 .61927 m .65028 .56373 L .66665 .5564 L p .707 .577 .707 r
F P
0 g
s
.4272 .56567 m .42679 .62121 L .45618 .61799 L p .707 .577 .707 r
F P
0 g
s
.45618 .61799 m .45658 .56245 L .4272 .56567 L p .707 .577 .707 r
F P
0 g
s
.64433 .63958 m .64286 .67644 L .63577 .685 L p .707 .577 .707 r
F P
0 g
s
.36379 .61965 m .36419 .56411 L .33673 .55949 L p .707 .577 .707 r
F P
0 g
s
.36419 .56411 m .36379 .61965 L .39496 .62178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45658 .56245 m .45618 .61799 L .48023 .61245 L p .707 .577 .707 r
F P
0 g
s
.48023 .61245 m .48063 .55691 L .45658 .56245 L p .707 .577 .707 r
F P
0 g
s
.8381 .65034 m .83663 .6872 L .82406 .67842 L p .707 .577 .707 r
F P
0 g
s
.82406 .67842 m .82553 .64156 L .8381 .65034 L p .707 .577 .707 r
F P
0 g
s
.66665 .5564 m .66625 .61193 L .64988 .61927 L p .707 .577 .707 r
F P
0 g
s
.83161 .56048 m .8312 .61602 L .81015 .60936 L p .707 .577 .707 r
F P
0 g
s
.81015 .60936 m .81055 .55382 L .83161 .56048 L p .707 .577 .707 r
F P
0 g
s
.64031 .75727 m .63523 .73896 L .6425 .73199 L p .707 .577 .707 r
F P
0 g
s
.33673 .55949 m .33633 .61503 L .36379 .61965 L p .707 .577 .707 r
F P
0 g
s
.33633 .61503 m .33673 .55949 L .31568 .55283 L p .707 .577 .707 r
F P
0 g
s
.38784 .6815 m .38931 .64463 L .35816 .64148 L p .707 .577 .707 r
F P
0 g
s
.38931 .64463 m .38784 .6815 L .41965 .68184 L p .707 .577 .707 r
F P
0 g
s
.41965 .68184 m .42112 .64498 L .38931 .64463 L p .707 .577 .707 r
F P
0 g
s
.6425 .73199 m .64758 .75029 L .64031 .75727 L p .707 .577 .707 r
F P
0 g
s
.64286 .67644 m .64433 .63958 L .66069 .63241 L p .707 .577 .707 r
F P
0 g
s
.42112 .64498 m .41965 .68184 L .44902 .67936 L p .707 .577 .707 r
F P
0 g
s
.44902 .67936 m .45048 .64249 L .42112 .64498 L p .707 .577 .707 r
F P
0 g
s
.82933 .68403 m .83441 .70234 L .82268 .70074 L p .707 .577 .707 r
F P
0 g
s
.82268 .70074 m .8176 .68243 L .82933 .68403 L p .707 .577 .707 r
F P
0 g
s
.66625 .61193 m .66665 .5564 L .69071 .55085 L p .707 .577 .707 r
F P
0 g
s
.35669 .67835 m .35816 .64148 L .33072 .63584 L p .707 .577 .707 r
F P
0 g
s
.35816 .64148 m .35669 .67835 L .38784 .6815 L p .707 .577 .707 r
F P
0 g
s
.48063 .55691 m .48023 .61245 L .4966 .60512 L p .707 .577 .707 r
F P
0 g
s
.4966 .60512 m .497 .54958 L .48063 .55691 L p .707 .577 .707 r
F P
0 g
s
.66069 .63241 m .65923 .66927 L .64286 .67644 L p .707 .577 .707 r
F P
0 g
s
.31568 .55283 m .31527 .60837 L .33633 .61503 L p .707 .577 .707 r
F P
0 g
s
.45048 .64249 m .44902 .67936 L .47306 .67428 L p .707 .577 .707 r
F P
0 g
s
.47306 .67428 m .47452 .63742 L .45048 .64249 L p .707 .577 .707 r
F P
0 g
s
.38753 .7132 m .38245 .69489 L .35249 .70177 L p .707 .577 .707 r
F P
0 g
s
.38245 .69489 m .38753 .7132 L .41828 .7045 L p .707 .577 .707 r
F P
0 g
s
.41828 .7045 m .4132 .68619 L .38245 .69489 L p .707 .577 .707 r
F P
0 g
s
.81055 .55382 m .81015 .60936 L .78269 .60473 L p .707 .577 .707 r
F P
0 g
s
.78269 .60473 m .78309 .5492 L .81055 .55382 L p .707 .577 .707 r
F P
0 g
s
.33072 .63584 m .32926 .67271 L .35669 .67835 L p .707 .577 .707 r
F P
0 g
s
.4132 .68619 m .41828 .7045 L .44679 .69483 L p .707 .577 .707 r
F P
0 g
s
.44679 .69483 m .44171 .67652 L .4132 .68619 L p .707 .577 .707 r
F P
0 g
s
.82553 .64156 m .82406 .67842 L .80303 .67084 L p .707 .577 .707 r
F P
0 g
s
.80303 .67084 m .80449 .63398 L .82553 .64156 L p .707 .577 .707 r
F P
0 g
s
.35249 .70177 m .35757 .72008 L .38753 .7132 L p .707 .577 .707 r
F P
0 g
s
.69071 .55085 m .6903 .60639 L .66625 .61193 L p .707 .577 .707 r
F P
0 g
s
.31527 .60837 m .31568 .55283 L .30309 .54478 L p .707 .577 .707 r
F P
0 g
s
.32926 .67271 m .33072 .63584 L .30969 .62826 L p .707 .577 .707 r
F P
0 g
s
.6903 .60639 m .69071 .55085 L .72009 .54764 L p .707 .577 .707 r
F P
0 g
s
.35757 .72008 m .35249 .70177 L .32624 .70616 L p .707 .577 .707 r
F P
0 g
s
.64758 .75029 m .6425 .73199 L .65868 .72323 L p .707 .577 .707 r
F P
0 g
s
.65923 .66927 m .66069 .63241 L .68474 .62733 L p .707 .577 .707 r
F P
0 g
s
.32624 .70616 m .33132 .72447 L .35757 .72008 L p .707 .577 .707 r
F P
0 g
s
.44171 .67652 m .44679 .69483 L .47029 .68514 L p .707 .577 .707 r
F P
0 g
s
.47029 .68514 m .46521 .66684 L .44171 .67652 L p .707 .577 .707 r
F P
0 g
s
.65868 .72323 m .66376 .74154 L .64758 .75029 L p .707 .577 .707 r
F P
0 g
s
.30969 .62826 m .30822 .66513 L .32926 .67271 L p .707 .577 .707 r
F P
0 g
s
.78309 .5492 m .78269 .60473 L .75152 .6026 L p .707 .577 .707 r
F P
0 g
s
.75152 .6026 m .75192 .54707 L .78309 .5492 L p .707 .577 .707 r
F P
0 g
s
.8176 .68243 m .82268 .70074 L .80272 .70221 L p .707 .577 .707 r
F P
0 g
s
.80272 .70221 m .79764 .6839 L .8176 .68243 L p .707 .577 .707 r
F P
0 g
s
.47452 .63742 m .47306 .67428 L .48942 .66711 L p .707 .577 .707 r
F P
0 g
s
.48942 .66711 m .49089 .63025 L .47452 .63742 L p .707 .577 .707 r
F P
0 g
s
.71968 .60318 m .72009 .54764 L .75192 .54707 L p .707 .577 .707 r
F P
0 g
s
.72009 .54764 m .71968 .60318 L .6903 .60639 L p .707 .577 .707 r
F P
0 g
s
.30309 .54478 m .30268 .60032 L .31527 .60837 L p .707 .577 .707 r
F P
0 g
s
.497 .54958 m .4966 .60512 L .50368 .59672 L p .707 .577 .707 r
F P
0 g
s
.50368 .59672 m .50408 .54118 L .497 .54958 L p .707 .577 .707 r
F P
0 g
s
.68474 .62733 m .68327 .66419 L .65923 .66927 L p .707 .577 .707 r
F P
0 g
s
.75192 .54707 m .75152 .6026 L .71968 .60318 L p .707 .577 .707 r
F P
0 g
s
.80449 .63398 m .80303 .67084 L .77559 .66521 L p .707 .577 .707 r
F P
0 g
s
.77559 .66521 m .77706 .62834 L .80449 .63398 L p .707 .577 .707 r
F P
0 g
s
.33132 .72447 m .32624 .70616 L .30628 .70763 L p .707 .577 .707 r
F P
0 g
s
.30822 .66513 m .30969 .62826 L .29712 .61949 L p .707 .577 .707 r
F P
0 g
s
.30628 .70763 m .31136 .72594 L .33132 .72447 L p .707 .577 .707 r
F P
0 g
s
.46521 .66684 m .47029 .68514 L .48646 .67638 L p .707 .577 .707 r
F P
0 g
s
.48646 .67638 m .48138 .65808 L .46521 .66684 L p .707 .577 .707 r
F P
0 g
s
.68327 .66419 m .68474 .62733 L .7141 .62484 L p .707 .577 .707 r
F P
0 g
s
.30268 .60032 m .30309 .54478 L .30019 .53613 L p .707 .577 .707 r
F P
0 g
s
.66376 .74154 m .65868 .72323 L .68218 .71354 L p .707 .577 .707 r
F P
0 g
s
.29712 .61949 m .29565 .65635 L .30822 .66513 L p .707 .577 .707 r
F P
0 g
s
.68218 .71354 m .68726 .73185 L .66376 .74154 L p .707 .577 .707 r
F P
0 g
s
.77706 .62834 m .77559 .66521 L .74445 .66206 L p .707 .577 .707 r
F P
0 g
s
.74445 .66206 m .74591 .62519 L .77706 .62834 L p .707 .577 .707 r
F P
0 g
s
.79764 .6839 m .80272 .70221 L .77648 .7066 L p .707 .577 .707 r
F P
0 g
s
.77648 .7066 m .77139 .68829 L .79764 .6839 L p .707 .577 .707 r
F P
0 g
s
.7141 .62484 m .71263 .66171 L .68327 .66419 L p .707 .577 .707 r
F P
0 g
s
.71263 .66171 m .7141 .62484 L .74591 .62519 L p .707 .577 .707 r
F P
0 g
s
.49089 .63025 m .48942 .66711 L .49651 .65855 L p .707 .577 .707 r
F P
0 g
s
.49651 .65855 m .49798 .62168 L .49089 .63025 L p .707 .577 .707 r
F P
0 g
s
.74591 .62519 m .74445 .66206 L .71263 .66171 L p .707 .577 .707 r
F P
0 g
s
.30019 .53613 m .29979 .59167 L .30268 .60032 L p .707 .577 .707 r
F P
0 g
s
.50408 .54118 m .50368 .59672 L .50078 .58807 L p .707 .577 .707 r
F P
0 g
s
.50078 .58807 m .50119 .53253 L .50408 .54118 L p .707 .577 .707 r
F P
0 g
s
.31136 .72594 m .30628 .70763 L .29456 .70604 L p .707 .577 .707 r
F P
0 g
s
.29456 .70604 m .29964 .72434 L .31136 .72594 L p .707 .577 .707 r
F P
0 g
s
.29565 .65635 m .29712 .61949 L .29423 .61037 L p .707 .577 .707 r
F P
0 g
s
.68726 .73185 m .68218 .71354 L .71069 .70388 L p .707 .577 .707 r
F P
0 g
s
.48138 .65808 m .48646 .67638 L .49374 .66941 L p .707 .577 .707 r
F P
0 g
s
.49374 .66941 m .48866 .6511 L .48138 .65808 L p .707 .577 .707 r
F P
0 g
s
.71069 .70388 m .71577 .72218 L .68726 .73185 L p .707 .577 .707 r
F P
0 g
s
.77139 .68829 m .77648 .7066 L .74651 .71348 L p .707 .577 .707 r
F P
0 g
s
.74651 .71348 m .74143 .69518 L .77139 .68829 L p .707 .577 .707 r
F P
0 g
s
.29979 .59167 m .30019 .53613 L .30727 .52773 L p .707 .577 .707 r
F P
0 g
s
.29423 .61037 m .29276 .64724 L .29565 .65635 L p .707 .577 .707 r
F P
0 g
s
.71577 .72218 m .71069 .70388 L .74143 .69518 L p .707 .577 .707 r
F P
0 g
s
.74143 .69518 m .74651 .71348 L .71577 .72218 L p .707 .577 .707 r
F P
0 g
s
.49798 .62168 m .49651 .65855 L .49362 .64943 L p .707 .577 .707 r
F P
0 g
s
.49362 .64943 m .49509 .61257 L .49798 .62168 L p .707 .577 .707 r
F P
0 g
s
.30727 .52773 m .30687 .58327 L .29979 .59167 L p .707 .577 .707 r
F P
0 g
s
.29964 .72434 m .29456 .70604 L .29222 .70153 L p .707 .577 .707 r
F P
0 g
s
.50119 .53253 m .50078 .58807 L .48819 .58002 L p .707 .577 .707 r
F P
0 g
s
.48819 .58002 m .4886 .52448 L .50119 .53253 L p .707 .577 .707 r
F P
0 g
s
.29222 .70153 m .2973 .71984 L .29964 .72434 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29276 .64724 m .29423 .61037 L .30132 .60181 L p .707 .577 .707 r
F P
0 g
s
.48866 .6511 m .49374 .66941 L .4914 .66491 L p .707 .577 .707 r
F P
0 g
s
.4914 .66491 m .48632 .6466 L .48866 .6511 L p .707 .577 .707 r
F P
0 g
s
.30687 .58327 m .30727 .52773 L .32364 .5204 L p .707 .577 .707 r
F P
0 g
s
.30132 .60181 m .29985 .63868 L .29276 .64724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49509 .61257 m .49362 .64943 L .48105 .64066 L p .707 .577 .707 r
F P
0 g
s
.48105 .64066 m .48252 .60379 L .49509 .61257 L p .707 .577 .707 r
F P
0 g
s
.32364 .5204 m .32324 .57594 L .30687 .58327 L p .707 .577 .707 r
F P
0 g
s
.4886 .52448 m .48819 .58002 L .46714 .57336 L p .707 .577 .707 r
F P
0 g
s
.46714 .57336 m .46754 .51782 L .4886 .52448 L p .707 .577 .707 r
F P
0 g
s
.2973 .71984 m .29222 .70153 L .29949 .69456 L p .707 .577 .707 r
F P
0 g
s
.29949 .69456 m .30457 .71286 L .2973 .71984 L p .707 .577 .707 r
F P
0 g
s
.29985 .63868 m .30132 .60181 L .31768 .59464 L p .707 .577 .707 r
F P
0 g
s
.48632 .6466 m .4914 .66491 L .47967 .66331 L p .707 .577 .707 r
F P
0 g
s
.47967 .66331 m .47459 .645 L .48632 .6466 L p .707 .577 .707 r
F P
0 g
s
.32324 .57594 m .32364 .5204 L .3477 .51486 L p .707 .577 .707 r
F P
0 g
s
.31768 .59464 m .31622 .6315 L .29985 .63868 L p .707 .577 .707 r
F P
0 g
s
.46754 .51782 m .46714 .57336 L .43968 .56874 L p .707 .577 .707 r
F P
0 g
s
.43968 .56874 m .44008 .5132 L .46754 .51782 L p .707 .577 .707 r
F P
0 g
s
.48252 .60379 m .48105 .64066 L .46002 .63308 L p .707 .577 .707 r
F P
0 g
s
.46002 .63308 m .46148 .59621 L .48252 .60379 L p .707 .577 .707 r
F P
0 g
s
.3477 .51486 m .34729 .57039 L .32324 .57594 L p .707 .577 .707 r
F P
0 g
s
.34729 .57039 m .3477 .51486 L .37708 .51164 L p .707 .577 .707 r
F P
0 g
s
.31622 .6315 m .31768 .59464 L .34172 .58956 L p .707 .577 .707 r
F P
0 g
s
.30457 .71286 m .29949 .69456 L .31567 .6858 L p .707 .577 .707 r
F P
0 g
s
.31567 .6858 m .32075 .70411 L .30457 .71286 L p .707 .577 .707 r
F P
0 g
s
.44008 .5132 m .43968 .56874 L .40851 .56661 L p .707 .577 .707 r
F P
0 g
s
.40851 .56661 m .40891 .51107 L .44008 .5132 L p .707 .577 .707 r
F P
0 g
s
.47459 .645 m .47967 .66331 L .45971 .66478 L p .707 .577 .707 r
F P
0 g
s
.45971 .66478 m .45463 .64647 L .47459 .645 L p .707 .577 .707 r
F P
0 g
s
.37667 .56718 m .37708 .51164 L .40891 .51107 L p .707 .577 .707 r
F P
0 g
s
.37708 .51164 m .37667 .56718 L .34729 .57039 L p .707 .577 .707 r
F P
0 g
s
.34172 .58956 m .34026 .62643 L .31622 .6315 L p .707 .577 .707 r
F P
0 g
s
.40891 .51107 m .40851 .56661 L .37667 .56718 L p .707 .577 .707 r
F P
0 g
s
.46148 .59621 m .46002 .63308 L .43258 .62744 L p .707 .577 .707 r
F P
0 g
s
.43258 .62744 m .43405 .59057 L .46148 .59621 L p .707 .577 .707 r
F P
0 g
s
.34026 .62643 m .34172 .58956 L .37109 .58708 L p .707 .577 .707 r
F P
0 g
s
.32075 .70411 m .31567 .6858 L .33916 .67611 L p .707 .577 .707 r
F P
0 g
s
.33916 .67611 m .34425 .69442 L .32075 .70411 L p .707 .577 .707 r
F P
0 g
s
.43405 .59057 m .43258 .62744 L .40143 .62429 L p .707 .577 .707 r
F P
0 g
s
.40143 .62429 m .4029 .58742 L .43405 .59057 L p .707 .577 .707 r
F P
0 g
s
.45463 .64647 m .45971 .66478 L .43346 .66917 L p .707 .577 .707 r
F P
0 g
s
.43346 .66917 m .42838 .65086 L .45463 .64647 L p .707 .577 .707 r
F P
0 g
s
.37109 .58708 m .36962 .62394 L .34026 .62643 L p .707 .577 .707 r
F P
0 g
s
.36962 .62394 m .37109 .58708 L .4029 .58742 L p .707 .577 .707 r
F P
0 g
s
.4029 .58742 m .40143 .62429 L .36962 .62394 L p .707 .577 .707 r
F P
0 g
s
.34425 .69442 m .33916 .67611 L .36768 .66644 L p .707 .577 .707 r
F P
0 g
s
.36768 .66644 m .37276 .68475 L .34425 .69442 L p .707 .577 .707 r
F P
0 g
s
.42838 .65086 m .43346 .66917 L .4035 .67605 L p .707 .577 .707 r
F P
0 g
s
.4035 .67605 m .39842 .65774 L .42838 .65086 L p .707 .577 .707 r
F P
0 g
s
.37276 .68475 m .36768 .66644 L .39842 .65774 L p .707 .577 .707 r
F P
0 g
s
.39842 .65774 m .4035 .67605 L .37276 .68475 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0000G
0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0006Eoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
00=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001UOol005ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000IGoo001KOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol005Uoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Egoo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000AOolA0013
Ool005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH8000kOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Goo001EOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0017oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P00<Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`00;Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<0
05YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol00`00FUH00003
FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH70003FUH00`00
FUIJEP02FUH?0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool005Eoo`80009JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000IJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
02aoo`00EGoo0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF10000eYF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000`0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0010OolB
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool003Yoo`H000AJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF008002aoo`00=goo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF1@0015YF00<005YFFUH00P00;7oo000dOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00AJEP00FUIJEP8002aoo`00<Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2
000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
02aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEQ40009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP<002aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEPT0
009JEP03001JEUYF00AJEP<000AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF
20000eYF00<005YFFUH01eYF00@005YFFUIJEPH000EJEP03001JEUYF00=JEP03001JEUYF009JEP<0
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF1@001EYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH010000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF009JEP03001JEP00
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF001JEP8000AJEP<000=JEP03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP03001JEUYF00AJEP@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P00;Goo000^Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00
FUH00000FUH000EJEP03001JEP0000<00005FUH005YFFUH00005FUH50006FUH00`00FUIJEP08FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH000030004FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEPH000EJEP<000MJEP03001JEUYF00P0009JEP<000=JEP8000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP8002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF
2`0000=JEP0000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP03FUH01000FUIJ
EUYF10000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00=JEP03001JEUYF00@0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF0080
0003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH00UYF5P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF1P00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00;Woo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF100000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF00MJEP04
001JEUYFFUH70003FUH40004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEP0000<000AJEP03001JEUYF008000Moo`<000Aoo`P000AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002ioo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP800003
FUH005YF00QJEP03001JEUYF00AJEPL00005FUH00000FUH00004FUH01000FUIJEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP04
FUH00`00FUIJEP020006Ool5000;Ool60004FUH01P00FUIJEP00FUH002eoo`00;Woo00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
0000100000AJEP00000000=JEP03001JEUYF00MJEP03001JEUYF00@000IJEP8000=JEP03001JEUYF
00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00
FUH00P0015YF0`0015YF00<005YFFUH00P001Woo1@004Goo0`0000MJEP00FUIJEP00FUH0000]Ool0
02ioo`05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH30006
FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00800003FUH005YF00AJEP03001JEP0000@0009JEP8000Ioo`D0011oo`H0009JEP03001J
EP0002eoo`00;Woo0P000UYF00<005YFFUH00eYF60000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH01eYF00<005YFFUH0400000=JEP00FUH01UYF00@005YF000000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00=JEPL000Eoo`<000Yoo`L000=JEP05001JEUYF001JEP02000^Ool002ioo`80009JEP03001JEUYF
00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP<000=JEP03001JEUYF
00EJEP@0009JEPD000AJEP<000AJEP03001JEUYF00AJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF009JEQ800003FUH0000000h002ioo`00;Woo0P000UYF0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF009JEP800003FUH005YF00=J
EPT000MJEP03001JEUYF009JEP<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEPH000=JEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;goo0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`001eYF00<005YF00000`00
0UYF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH20003FUH01@00FUIJEP00FUH0
1`000eYF00<005YFFUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP02FUH2000015YF000005YF1P0000=JEP00FUH025YF00<005YFFUH00UYF0`001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=J
EP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YF0000009JEPH0
00IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000_Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003
FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00
0eYF00<005YFFUH015YF00<005YF00000`001eYF00<005YFFUH01EYF1`000eYF00<005YFFUH00eYF
00<005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0P0000=JEP00FUH00eYF10000UYF
00<005YFFUH01eYF00<005YFFUH010001UYF00<005YF00000P001EYF00<005YF0000;goo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUH000050006FUH00`00FUIJEP06FUH400000eYF001JEP07FUH20003FUH00`00
FUIJEP02FUH2000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEP03001JEUYF00<000UJEP03001JEUYF009JEP@000AJEP03001JEUYF
009JEP@000EJEP05001JEUYFFUH0000bOol002aoo`03001JEP0000=JEP04001JEUYFFUH8000AOol7
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUIJEP06FUH00`00FUH0000?0002FUH00`00FUIJ
EP05FUH3000cOol002aoo`03001JEP0000=JEP@0019oo`<000Yoo`800003FUH005YF00AJEP03001J
EP0000<00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000@000EJEP03001JEUYF00EJEP<000=oo`T000IJEP03001JEUYF00AJEP8003Eoo`00;7oo00@0
05YF001JEP8000AJEP<000ioo`D000]oo`T00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00=JEP8000Ioo`D00003
FUH005YF00QJEP04001JEUYFFUH2000gOol002aoo`06001JEP00001JEP001EYF00<005YF00000`00
2Woo1@004Goo0`0000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00<005YFFUH01EYF00<005YF00000`001goo10000eYF00<005YFFUH01UYF00@0
05YF000003Uoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1P0017oo1@002Goo2000
0UYF0`000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH00eYF0`0000=JEP00000017oo10001eYF00<005YFFUH01EYF0`00>goo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH01000FUIJEUYF1000
00AJEP00001JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00
FUH00003000015YF000000000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01000?Woo000/Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH60002FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP00
0UYF00<005YFFUH00UYF0P0015YF1P001UYF00<005YFFUH01UYF1000@Woo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUIJEPL0
00=JEP03001JEUYF00MJEP03001JEUYF009JEP<004Ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001J
EUYF00800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH=000;FUH90008FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF00000P00BGoo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60006FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001JEUYF
00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001<Ool002moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH4000015YF000000000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF0P001UYF
00<005YFFUH01EYF00<005YFFUH01000Cgoo000`Ool20004FUH00`00FUIJEP05FUH00`00FUH00003
0006FUH00`00FUIJEP07FUH01000FUIJEUYF1`000eYF1@000UYF00<005YFFUH00eYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF009JEPH005=oo`00<Woo0`0000=JEP00FUH0
1UYF0P0000=JEP00FUH025YF00<005YFFUH015YF1`0000EJEP00001JEP0000AJEP03001JEUYF0080
009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP@000AJEP800003FUH005YF009JEPL0009JEP03001JEP0005Ao
o`00=Goo0`000eYF0`000eYF00<005YFFUH01eYF00<005YFFUH010001UYF0P000eYF00<005YFFUH0
0eYF0P0000Eoo`00FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0000400000goo
00000003FUH01P00FUIJEP00FUH005Aoo`00>7oo0`001eYF00<005YFFUH015YF1@000UYF00<005YF
FUH00UYF0`001UYF00@005YFFUIJEP80009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3
00000eYF001oo`04Ool400001eYF001JEUYF001JEP0005Aoo`00=Woo0P0000=JEP00FUH01eYF00<0
05YFFUH01`0015YF00<005YFFUH00P0000=JEP00FUH01UYF00@005YF000000Aoo`03001JEUYF0080
0003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000@000=JEP<0009JEP8005Eoo`00=7oo
0P000eYF00<005YFFUH01EYF10000Woo300015YF00<005YFFUH015YF0P001Woo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000003P00EGoo000bOol20006FUH00`00FUIJ
EP02FUH20006Ool90007FUH00`00FUIJEP02FUH20008Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01000EGoo000`Ool30007FUH00`00
FUH000020008Ool50002FUH00`00FUIJEP07FUH01000FUH000002Woo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000=JEP03001JEUYF009JEP04001JEUYFFUH3001EOol002ioo`80
00=JEP03001JEUYF00AJEP8000Qoo`L000=JEP03001JEUYF00IJEP<000aoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005Eoo`00
;Goo0P0015YF00<005YFFUH00UYF0P001Woo100000=JEP00FUH025YF00<005YFFUH00UYF0`0047oo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH00UYF
00@005YFFUIJEP8005Eoo`00;7oo00<005YF00001EYF00@005YF0000009oo`H000IJEP03001JEUYF
00IJEP03001JEP00008001=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJ
EP/005Ioo`00;7oo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<001Mo
o`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP@0009JEP03001JEUYF009JEP04001J
EUYF001FOol002aoo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04000LOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF1P000UYF00<005YF00000P001EYF00<005YF0000EWoo
000]Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH015YF1@008Woo0P001UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
00000`001UYF0P000eYF00<005YFFUH00UYF0P00Egoo000]Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04000YOol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH400000eYF001JEP03FUH40005FUH00`00FUIJEP02FUH0
0`00Oomoo`1FOol002eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH4000_Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0?0002FUH00`00
FUIJEP05FUH01000FUH00000FGoo000]Ool20002FUH00`00FUIJEP03FUH00`00FUH00003000fOol4
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool90006FUH00`00FUIJ
EP04FUH3001KOol002ioo`/003ioo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00L000Ioo`D00003FUH005YF00QJEP04001JEUYFFUH2001NOol007eoob000004FUH000000008Ool5
0002FUH00`00FUIJEP06FUH01000FUH00000H7oo002?Ool00`00FUIJEP02FUH00`00FUIJEP04FUH3
0007Ool4000015YF000000000eYF00<005YFFUH01EYF0`00HWoo002>Ool20005FUH01000FUIJEUYF
0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo002=Ool01000FUIJEP0015YF
00@005YF0000009oo`H000IJEP03001JEUYF00MJEP03001JEP00008006Moo`00SGoo00@005YFFUH0
00AJEPH000=JEP03001JEUYF00MJEP03001JEUYF00AJEP@006Yoo`00SWoo00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006ioo`00SWoo00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF1000LWoo002?Ool015YF001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01000MWoo002?Ool01000FUIJEP001EYF00<005YFFUH00UYF1P00NWoo002?Ool2
0002FUH00`00FUIJEP070020Ool0095oo`D008Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60363 .75001 m .60428 .6945 L .57311 .69223 L p .707 .577 .707 r
F P
0 g
s
.60428 .6945 m .60363 .75001 L .63546 .74956 L p .707 .577 .707 r
F P
0 g
s
.63546 .74956 m .63612 .69406 L .60428 .6945 L p .707 .577 .707 r
F P
0 g
s
.63612 .69406 m .63546 .74956 L .66484 .74645 L p .707 .577 .707 r
F P
0 g
s
.66484 .74645 m .6655 .69094 L .63612 .69406 L p .707 .577 .707 r
F P
0 g
s
.57246 .74774 m .57311 .69223 L .54566 .68747 L p .707 .577 .707 r
F P
0 g
s
.57311 .69223 m .57246 .74774 L .60363 .75001 L p .707 .577 .707 r
F P
0 g
s
.6655 .69094 m .66484 .74645 L .6889 .74097 L p .707 .577 .707 r
F P
0 g
s
.6889 .74097 m .68955 .68546 L .6655 .69094 L p .707 .577 .707 r
F P
0 g
s
.545 .74297 m .54566 .68747 L .5246 .68068 L p .707 .577 .707 r
F P
0 g
s
.54566 .68747 m .545 .74297 L .57246 .74774 L p .707 .577 .707 r
F P
0 g
s
.59208 .81217 m .59446 .77546 L .56335 .77154 L p .707 .577 .707 r
F P
0 g
s
.59446 .77546 m .59208 .81217 L .62386 .81321 L p .707 .577 .707 r
F P
0 g
s
.62386 .81321 m .62623 .7765 L .59446 .77546 L p .707 .577 .707 r
F P
0 g
s
.62623 .7765 m .62386 .81321 L .6532 .81128 L p .707 .577 .707 r
F P
0 g
s
.6532 .81128 m .65557 .77456 L .62623 .7765 L p .707 .577 .707 r
F P
0 g
s
.56098 .80826 m .56335 .77154 L .53596 .76513 L p .707 .577 .707 r
F P
0 g
s
.56335 .77154 m .56098 .80826 L .59208 .81217 L p .707 .577 .707 r
F P
0 g
s
.68955 .68546 m .6889 .74097 L .70526 .73366 L p .707 .577 .707 r
F P
0 g
s
.70526 .73366 m .70592 .67815 L .68955 .68546 L p .707 .577 .707 r
F P
0 g
s
.5246 .68068 m .52395 .73619 L .545 .74297 L p .707 .577 .707 r
F P
0 g
s
.65557 .77456 m .6532 .81128 L .67722 .80655 L p .707 .577 .707 r
F P
0 g
s
.67722 .80655 m .67959 .76984 L .65557 .77456 L p .707 .577 .707 r
F P
0 g
s
.59035 .83689 m .58231 .81948 L .55427 .83161 L p .707 .577 .707 r
F P
0 g
s
.58231 .81948 m .59035 .83689 L .61935 .82346 L p .707 .577 .707 r
F P
0 g
s
.61935 .82346 m .61132 .80606 L .58231 .81948 L p .707 .577 .707 r
F P
0 g
s
.53596 .76513 m .53358 .80185 L .56098 .80826 L p .707 .577 .707 r
F P
0 g
s
.61132 .80606 m .61935 .82346 L .64649 .81005 L p .707 .577 .707 r
F P
0 g
s
.64649 .81005 m .63846 .79264 L .61132 .80606 L p .707 .577 .707 r
F P
0 g
s
.55427 .83161 m .56231 .84902 L .59035 .83689 L p .707 .577 .707 r
F P
0 g
s
.52395 .73619 m .5246 .68068 L .51201 .67253 L p .707 .577 .707 r
F P
0 g
s
.53358 .80185 m .53596 .76513 L .51496 .75686 L p .707 .577 .707 r
F P
0 g
s
.56231 .84902 m .55427 .83161 L .52995 .84124 L p .707 .577 .707 r
F P
0 g
s
.63846 .79264 m .64649 .81005 L .6691 .79795 L p .707 .577 .707 r
F P
0 g
s
.6691 .79795 m .66107 .78054 L .63846 .79264 L p .707 .577 .707 r
F P
0 g
s
.52995 .84124 m .53799 .85865 L .56231 .84902 L p .707 .577 .707 r
F P
0 g
s
.51496 .75686 m .51259 .79358 L .53358 .80185 L p .707 .577 .707 r
F P
0 g
s
.51201 .67253 m .51136 .72804 L .52395 .73619 L p .707 .577 .707 r
F P
0 g
s
.70592 .67815 m .70526 .73366 L .71235 .72524 L p .707 .577 .707 r
F P
0 g
s
.71235 .72524 m .713 .66973 L .70592 .67815 L p .707 .577 .707 r
F P
0 g
s
.67959 .76984 m .67722 .80655 L .69358 .79951 L p .707 .577 .707 r
F P
0 g
s
.69358 .79951 m .69595 .76279 L .67959 .76984 L p .707 .577 .707 r
F P
0 g
s
.51259 .79358 m .51496 .75686 L .50241 .74754 L p .707 .577 .707 r
F P
0 g
s
.53799 .85865 m .52995 .84124 L .51173 .84743 L p .707 .577 .707 r
F P
0 g
s
.51173 .84743 m .51976 .86484 L .53799 .85865 L p .707 .577 .707 r
F P
0 g
s
.51136 .72804 m .51201 .67253 L .50912 .66382 L p .707 .577 .707 r
F P
0 g
s
.66107 .78054 m .6691 .79795 L .68497 .78836 L p .707 .577 .707 r
F P
0 g
s
.68497 .78836 m .67694 .77095 L .66107 .78054 L p .707 .577 .707 r
F P
0 g
s
.50241 .74754 m .50004 .78425 L .51259 .79358 L p .707 .577 .707 r
F P
0 g
s
.50912 .66382 m .50846 .71932 L .51136 .72804 L p .707 .577 .707 r
F P
0 g
s
.69595 .76279 m .69358 .79951 L .70067 .79082 L p .707 .577 .707 r
F P
0 g
s
.70067 .79082 m .70305 .7541 L .69595 .76279 L p .707 .577 .707 r
F P
0 g
s
.713 .66973 m .71235 .72524 L .70945 .71653 L p .707 .577 .707 r
F P
0 g
s
.70945 .71653 m .71011 .66102 L .713 .66973 L p .707 .577 .707 r
F P
0 g
s
.51976 .86484 m .51173 .84743 L .50138 .84959 L p .707 .577 .707 r
F P
0 g
s
.50004 .78425 m .50241 .74754 L .49955 .73807 L p .707 .577 .707 r
F P
0 g
s
.50138 .84959 m .50941 .867 L .51976 .86484 L p .707 .577 .707 r
F P
0 g
s
.67694 .77095 m .68497 .78836 L .69255 .78222 L p .707 .577 .707 r
F P
0 g
s
.69255 .78222 m .68452 .76481 L .67694 .77095 L p .707 .577 .707 r
F P
0 g
s
.50846 .71932 m .50912 .66382 L .5162 .65539 L p .707 .577 .707 r
F P
0 g
s
.49602 .82167 m .48777 .31897 L .44377 .31702 L p .707 .577 .707 r
F P
0 g
s
.49955 .73807 m .49717 .77479 L .50004 .78425 L p .707 .577 .707 r
F P
0 g
s
.5162 .65539 m .51555 .7109 L .50846 .71932 L p .707 .577 .707 r
F P
0 g
s
.49717 .77479 m .49955 .73807 L .50664 .72938 L p .707 .577 .707 r
F P
0 g
s
.51555 .7109 m .5162 .65539 L .53257 .64808 L p .707 .577 .707 r
F P
0 g
s
.50664 .72938 m .50427 .7661 L .49717 .77479 L p .707 .577 .707 r
F P
0 g
s
.53257 .64808 m .53192 .70359 L .51555 .7109 L p .707 .577 .707 r
F P
0 g
s
.50427 .7661 m .50664 .72938 L .523 .72234 L p .707 .577 .707 r
F P
0 g
s
.523 .72234 m .52063 .75905 L .50427 .7661 L p .707 .577 .707 r
F P
0 g
s
.52063 .75905 m .523 .72234 L .54702 .71761 L p .707 .577 .707 r
F P
0 g
s
.54702 .71761 m .54465 .75433 L .52063 .75905 L p .707 .577 .707 r
F P
0 g
s
.48777 .31897 m .49602 .82167 L .54096 .81991 L p .707 .577 .707 r
F P
0 g
s
.53192 .70359 m .53257 .64808 L .55662 .6426 L p .707 .577 .707 r
F P
0 g
s
.55662 .6426 m .55597 .69811 L .53192 .70359 L p .707 .577 .707 r
F P
0 g
s
.54096 .81991 m .53271 .31721 L .48777 .31897 L p .707 .577 .707 r
F P
0 g
s
.55597 .69811 m .55662 .6426 L .586 .63949 L p .707 .577 .707 r
F P
0 g
s
.586 .63949 m .58535 .695 L .55597 .69811 L p .707 .577 .707 r
F P
0 g
s
.54465 .75433 m .54702 .71761 L .57636 .71568 L p .707 .577 .707 r
F P
0 g
s
.57636 .71568 m .57398 .75239 L .54465 .75433 L p .707 .577 .707 r
F P
0 g
s
.57398 .75239 m .57636 .71568 L .60814 .71672 L p .707 .577 .707 r
F P
0 g
s
.60814 .71672 m .60576 .75343 L .57398 .75239 L p .707 .577 .707 r
F P
0 g
s
.55402 .83707 m .54599 .81967 L .57312 .80625 L p .707 .577 .707 r
F P
0 g
s
.57312 .80625 m .58116 .82366 L .55402 .83707 L p .707 .577 .707 r
F P
0 g
s
.58116 .82366 m .57312 .80625 L .60213 .79282 L p .707 .577 .707 r
F P
0 g
s
.53271 .31721 m .54096 .81991 L .58244 .81461 L p .707 .577 .707 r
F P
0 g
s
.58244 .81461 m .57419 .31191 L .53271 .31721 L p .707 .577 .707 r
F P
0 g
s
.45202 .81972 m .44377 .31702 L .40501 .31155 L p .707 .577 .707 r
F P
0 g
s
.44377 .31702 m .45202 .81972 L .49602 .82167 L p .707 .577 .707 r
F P
0 g
s
.70305 .7541 m .70067 .79082 L .69781 .78135 L p .707 .577 .707 r
F P
0 g
s
.69781 .78135 m .70018 .74464 L .70305 .7541 L p .707 .577 .707 r
F P
0 g
s
.71011 .66102 m .70945 .71653 L .69686 .70838 L p .707 .577 .707 r
F P
0 g
s
.69686 .70838 m .69751 .65287 L .71011 .66102 L p .707 .577 .707 r
F P
0 g
s
.58535 .695 m .586 .63949 L .61783 .63905 L p .707 .577 .707 r
F P
0 g
s
.61783 .63905 m .61718 .69456 L .58535 .695 L p .707 .577 .707 r
F P
0 g
s
.63924 .72063 m .63687 .75735 L .60576 .75343 L p .707 .577 .707 r
F P
0 g
s
.60576 .75343 m .60814 .71672 L .63924 .72063 L p .707 .577 .707 r
F P
0 g
s
.63017 .7807 m .6382 .79811 L .61017 .81023 L p .707 .577 .707 r
F P
0 g
s
.61017 .81023 m .60213 .79282 L .63017 .7807 L p .707 .577 .707 r
F P
0 g
s
.60213 .79282 m .61017 .81023 L .58116 .82366 L p .707 .577 .707 r
F P
0 g
s
.57419 .31191 m .58244 .81461 L .61639 .8063 L p .707 .577 .707 r
F P
0 g
s
.61639 .8063 m .60814 .3036 L .57419 .31191 L p .707 .577 .707 r
F P
0 g
s
.50941 .867 m .50138 .84959 L .49992 .84749 L p .708 .578 .707 r
F P
0 g
s
.49992 .84749 m .50796 .8649 L .50941 .867 L p .708 .578 .707 r
F P
0 g
s
.68452 .76481 m .69255 .78222 L .6911 .78012 L p .708 .578 .707 r
F P
0 g
s
.6911 .78012 m .68306 .76271 L .68452 .76481 L p .708 .578 .707 r
F P
0 g
s
.26062 .71452 m .26127 .65901 L .2301 .65674 L p .707 .577 .707 r
F P
0 g
s
.26127 .65901 m .26062 .71452 L .29245 .71407 L p .707 .577 .707 r
F P
0 g
s
.29245 .71407 m .29311 .65857 L .26127 .65901 L p .707 .577 .707 r
F P
0 g
s
.29311 .65857 m .29245 .71407 L .32183 .71096 L p .707 .577 .707 r
F P
0 g
s
.32183 .71096 m .32249 .65545 L .29311 .65857 L p .707 .577 .707 r
F P
0 g
s
.41326 .81425 m .40501 .31155 L .37529 .3031 L p .707 .577 .707 r
F P
0 g
s
.40501 .31155 m .41326 .81425 L .45202 .81972 L p .707 .577 .707 r
F P
0 g
s
.22945 .71225 m .2301 .65674 L .20265 .65198 L p .707 .577 .707 r
F P
0 g
s
.2301 .65674 m .22945 .71225 L .26062 .71452 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.32249 .65545 m .32183 .71096 L .34589 .70548 L p .707 .577 .707 r
F P
0 g
s
.34589 .70548 m .34654 .64997 L .32249 .65545 L p .707 .577 .707 r
F P
0 g
s
.68306 .76271 m .6911 .78012 L .68075 .78228 L p .707 .577 .707 r
F P
0 g
s
.70018 .74464 m .69781 .78135 L .68526 .77203 L p .707 .577 .707 r
F P
0 g
s
.68526 .77203 m .68763 .73531 L .70018 .74464 L p .707 .577 .707 r
F P
0 g
s
.69751 .65287 m .69686 .70838 L .67581 .70159 L p .707 .577 .707 r
F P
0 g
s
.67581 .70159 m .67646 .64608 L .69751 .65287 L p .707 .577 .707 r
F P
0 g
s
.649 .64132 m .64835 .69683 L .61718 .69456 L p .707 .577 .707 r
F P
0 g
s
.61718 .69456 m .61783 .63905 L .649 .64132 L p .707 .577 .707 r
F P
0 g
s
.66664 .72704 m .66426 .76376 L .63687 .75735 L p .707 .577 .707 r
F P
0 g
s
.63687 .75735 m .63924 .72063 L .66664 .72704 L p .707 .577 .707 r
F P
0 g
s
.6382 .79811 m .63017 .7807 L .65449 .77107 L p .707 .577 .707 r
F P
0 g
s
.60814 .3036 m .61639 .8063 L .6395 .79578 L p .707 .577 .707 r
F P
0 g
s
.6395 .79578 m .63125 .29308 L .60814 .3036 L p .707 .577 .707 r
F P
0 g
s
.20199 .70748 m .20265 .65198 L .18159 .64519 L p .707 .577 .707 r
F P
0 g
s
.20265 .65198 m .20199 .70748 L .22945 .71225 L p .707 .577 .707 r
F P
0 g
s
.24908 .77382 m .25145 .7371 L .22034 .73319 L p .707 .577 .707 r
F P
0 g
s
.25145 .7371 m .24908 .77382 L .28085 .77486 L p .707 .577 .707 r
F P
0 g
s
.28085 .77486 m .28323 .73814 L .25145 .7371 L p .707 .577 .707 r
F P
0 g
s
.50796 .8649 m .49992 .84749 L .5075 .84135 L p .707 .577 .707 r
F P
0 g
s
.5075 .84135 m .51554 .85876 L .50796 .8649 L p .707 .577 .707 r
F P
0 g
s
.28323 .73814 m .28085 .77486 L .31019 .77292 L p .707 .577 .707 r
F P
0 g
s
.31019 .77292 m .31256 .73621 L .28323 .73814 L p .707 .577 .707 r
F P
0 g
s
.68075 .78228 m .67272 .76487 L .68306 .76271 L p .707 .577 .707 r
F P
0 g
s
.21797 .7699 m .22034 .73319 L .19295 .72678 L p .707 .577 .707 r
F P
0 g
s
.22034 .73319 m .21797 .7699 L .24908 .77382 L p .707 .577 .707 r
F P
0 g
s
.34654 .64997 m .34589 .70548 L .36226 .69817 L p .707 .577 .707 r
F P
0 g
s
.36226 .69817 m .36291 .64266 L .34654 .64997 L p .707 .577 .707 r
F P
0 g
s
.18159 .64519 m .18094 .7007 L .20199 .70748 L p .707 .577 .707 r
F P
0 g
s
.38354 .8058 m .37529 .3031 L .35752 .29249 L p .707 .577 .707 r
F P
0 g
s
.37529 .3031 m .38354 .8058 L .41326 .81425 L p .707 .577 .707 r
F P
0 g
s
.67646 .64608 m .67581 .70159 L .64835 .69683 L p .707 .577 .707 r
F P
0 g
s
.64835 .69683 m .649 .64132 L .67646 .64608 L p .707 .577 .707 r
F P
0 g
s
.31256 .73621 m .31019 .77292 L .33421 .7682 L p .707 .577 .707 r
F P
0 g
s
.33421 .7682 m .33658 .73148 L .31256 .73621 L p .707 .577 .707 r
F P
0 g
s
.19295 .72678 m .19057 .7635 L .21797 .7699 L p .707 .577 .707 r
F P
0 g
s
.24734 .79908 m .2393 .78167 L .21127 .7938 L p .707 .577 .707 r
F P
0 g
s
.2393 .78167 m .24734 .79908 L .27634 .78565 L p .707 .577 .707 r
F P
0 g
s
.27634 .78565 m .26831 .76825 L .2393 .78167 L p .707 .577 .707 r
F P
0 g
s
.26831 .76825 m .27634 .78565 L .30348 .77224 L p .707 .577 .707 r
F P
0 g
s
.30348 .77224 m .29545 .75483 L .26831 .76825 L p .707 .577 .707 r
F P
0 g
s
.21127 .7938 m .2193 .8112 L .24734 .79908 L p .707 .577 .707 r
F P
0 g
s
.67272 .76487 m .68075 .78228 L .66253 .78847 L p .707 .577 .707 r
F P
0 g
s
.66253 .78847 m .65449 .77107 L .67272 .76487 L p .707 .577 .707 r
F P
0 g
s
.68763 .73531 m .68526 .77203 L .66426 .76376 L p .707 .577 .707 r
F P
0 g
s
.66426 .76376 m .66664 .72704 L .68763 .73531 L p .707 .577 .707 r
F P
0 g
s
.18094 .7007 m .18159 .64519 L .169 .63704 L p .707 .577 .707 r
F P
0 g
s
.19057 .7635 m .19295 .72678 L .17195 .71851 L p .707 .577 .707 r
F P
0 g
s
.2193 .8112 m .21127 .7938 L .18694 .80343 L p .707 .577 .707 r
F P
0 g
s
.29545 .75483 m .30348 .77224 L .32609 .76014 L p .707 .577 .707 r
F P
0 g
s
.32609 .76014 m .31806 .74273 L .29545 .75483 L p .707 .577 .707 r
F P
0 g
s
.18694 .80343 m .19498 .82084 L .2193 .8112 L p .707 .577 .707 r
F P
0 g
s
.51554 .85876 m .5075 .84135 L .52338 .83176 L p .707 .577 .707 r
F P
0 g
s
.17195 .71851 m .16958 .75523 L .19057 .7635 L p .707 .577 .707 r
F P
0 g
s
.52338 .83176 m .53141 .84917 L .51554 .85876 L p .707 .577 .707 r
F P
0 g
s
.65449 .77107 m .66253 .78847 L .6382 .79811 L p .707 .577 .707 r
F P
0 g
s
.63125 .29308 m .6395 .79578 L .6495 .78409 L p .707 .577 .707 r
F P
0 g
s
.6495 .78409 m .64125 .28139 L .63125 .29308 L p .707 .577 .707 r
F P
0 g
s
.169 .63704 m .16835 .69255 L .18094 .7007 L p .707 .577 .707 r
F P
0 g
s
.36291 .64266 m .36226 .69817 L .36934 .68975 L p .707 .577 .707 r
F P
0 g
s
.36934 .68975 m .36999 .63424 L .36291 .64266 L p .707 .577 .707 r
F P
0 g
s
.33658 .73148 m .33421 .7682 L .35057 .76115 L p .707 .577 .707 r
F P
0 g
s
.35057 .76115 m .35294 .72443 L .33658 .73148 L p .707 .577 .707 r
F P
0 g
s
.16958 .75523 m .17195 .71851 L .1594 .70918 L p .707 .577 .707 r
F P
0 g
s
.19498 .82084 m .18694 .80343 L .16872 .80962 L p .707 .577 .707 r
F P
0 g
s
.16872 .80962 m .17675 .82703 L .19498 .82084 L p .707 .577 .707 r
F P
0 g
s
.31806 .74273 m .32609 .76014 L .34197 .75055 L p .707 .577 .707 r
F P
0 g
s
.34197 .75055 m .33393 .73314 L .31806 .74273 L p .707 .577 .707 r
F P
0 g
s
.16835 .69255 m .169 .63704 L .16611 .62833 L p .707 .577 .707 r
F P
0 g
s
.3671 .62553 m .36644 .68104 L .35385 .67289 L p .707 .577 .707 r
F P
0 g
s
.35385 .67289 m .35451 .61738 L .3671 .62553 L p .707 .577 .707 r
F P
0 g
s
.36577 .79519 m .35752 .29249 L .35343 .28077 L p .707 .577 .707 r
F P
0 g
s
.36999 .63424 m .36934 .68975 L .36644 .68104 L p .707 .577 .707 r
F P
0 g
s
.36644 .68104 m .3671 .62553 L .36999 .63424 L p .707 .577 .707 r
F P
0 g
s
.35752 .29249 m .36577 .79519 L .38354 .8058 L p .707 .577 .707 r
F P
0 g
s
.1594 .70918 m .15703 .7459 L .16958 .75523 L p .707 .577 .707 r
F P
0 g
s
.53141 .84917 m .52338 .83176 L .54599 .81967 L p .707 .577 .707 r
F P
0 g
s
.54599 .81967 m .55402 .83707 L .53141 .84917 L p .707 .577 .707 r
F P
0 g
s
.35294 .72443 m .35057 .76115 L .35766 .75247 L p .707 .577 .707 r
F P
0 g
s
.35766 .75247 m .36004 .71575 L .35294 .72443 L p .707 .577 .707 r
F P
0 g
s
.16611 .62833 m .16545 .68383 L .16835 .69255 L p .707 .577 .707 r
F P
0 g
s
.17675 .82703 m .16872 .80962 L .15837 .81178 L p .707 .577 .707 r
F P
0 g
s
.15703 .7459 m .1594 .70918 L .15654 .69971 L p .707 .577 .707 r
F P
0 g
s
.15837 .81178 m .1664 .82919 L .17675 .82703 L p .707 .577 .707 r
F P
0 g
s
.33393 .73314 m .34197 .75055 L .34955 .74441 L p .707 .577 .707 r
F P
0 g
s
.34955 .74441 m .34151 .727 L .33393 .73314 L p .707 .577 .707 r
F P
0 g
s
.64125 .28139 m .6495 .78409 L .64541 .77237 L p .707 .577 .707 r
F P
0 g
s
.64541 .77237 m .63716 .26967 L .64125 .28139 L p .707 .577 .707 r
F P
0 g
s
.16545 .68383 m .16611 .62833 L .17319 .6199 L p .707 .577 .707 r
F P
0 g
s
.15654 .69971 m .15416 .73643 L .15703 .7459 L p .707 .577 .707 r
F P
0 g
s
.36004 .71575 m .35766 .75247 L .3548 .743 L p .707 .577 .707 r
F P
0 g
s
.3548 .743 m .35717 .70628 L .36004 .71575 L p .707 .577 .707 r
F P
0 g
s
.17319 .6199 m .17254 .67541 L .16545 .68383 L p .707 .577 .707 r
F P
0 g
s
.35343 .28077 m .36168 .78347 L .36577 .79519 L p .707 .577 .707 r
F P
0 g
s
.36168 .78347 m .35343 .28077 L .36343 .26908 L p .707 .577 .707 r
F P
0 g
s
.1664 .82919 m .15837 .81178 L .15691 .80968 L p .708 .578 .707 r
F P
0 g
s
.15416 .73643 m .15654 .69971 L .16363 .69103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15691 .80968 m .16495 .82709 L .1664 .82919 L p .708 .578 .707 r
F P
0 g
s
.34151 .727 m .34955 .74441 L .34809 .74231 L p .708 .578 .707 r
F P
0 g
s
.34809 .74231 m .34005 .7249 L .34151 .727 L p .708 .578 .707 r
F P
0 g
s
.17254 .67541 m .17319 .6199 L .18956 .61259 L p .707 .577 .707 r
F P
0 g
s
.16363 .69103 m .16126 .72775 L .15416 .73643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63716 .26967 m .64541 .77237 L .62764 .76176 L p .707 .577 .707 r
F P
0 g
s
.62764 .76176 m .61939 .25906 L .63716 .26967 L p .707 .577 .707 r
F P
0 g
s
.34005 .7249 m .34809 .74231 L .33774 .74447 L p .707 .577 .707 r
F P
0 g
s
.35717 .70628 m .3548 .743 L .34225 .73367 L p .707 .577 .707 r
F P
0 g
s
.34225 .73367 m .34462 .69696 L .35717 .70628 L p .707 .577 .707 r
F P
0 g
s
.18956 .61259 m .18891 .6681 L .17254 .67541 L p .707 .577 .707 r
F P
0 g
s
.35451 .61738 m .35385 .67289 L .3328 .6661 L p .707 .577 .707 r
F P
0 g
s
.3328 .6661 m .33345 .61059 L .35451 .61738 L p .707 .577 .707 r
F P
0 g
s
.16126 .72775 m .16363 .69103 L .17999 .68398 L p .707 .577 .707 r
F P
0 g
s
.16495 .82709 m .15691 .80968 L .16449 .80354 L p .707 .577 .707 r
F P
0 g
s
.16449 .80354 m .17253 .82095 L .16495 .82709 L p .707 .577 .707 r
F P
0 g
s
.18891 .6681 m .18956 .61259 L .21361 .60711 L p .707 .577 .707 r
F P
0 g
s
.33774 .74447 m .32971 .72706 L .34005 .7249 L p .707 .577 .707 r
F P
0 g
s
.37168 .77178 m .36343 .26908 L .38654 .25856 L p .707 .577 .707 r
F P
0 g
s
.36343 .26908 m .37168 .77178 L .36168 .78347 L p .707 .577 .707 r
F P
0 g
s
.17999 .68398 m .17762 .7207 L .16126 .72775 L p .707 .577 .707 r
F P
0 g
s
.33345 .61059 m .3328 .6661 L .30534 .66134 L p .707 .577 .707 r
F P
0 g
s
.30534 .66134 m .306 .60583 L .33345 .61059 L p .707 .577 .707 r
F P
0 g
s
.21361 .60711 m .21296 .66262 L .18891 .6681 L p .707 .577 .707 r
F P
0 g
s
.32971 .72706 m .33774 .74447 L .31952 .75066 L p .707 .577 .707 r
F P
0 g
s
.31952 .75066 m .31148 .73326 L .32971 .72706 L p .707 .577 .707 r
F P
0 g
s
.34462 .69696 m .34225 .73367 L .32125 .7254 L p .707 .577 .707 r
F P
0 g
s
.32125 .7254 m .32363 .68868 L .34462 .69696 L p .707 .577 .707 r
F P
0 g
s
.21296 .66262 m .21361 .60711 L .24299 .604 L p .707 .577 .707 r
F P
0 g
s
.17762 .7207 m .17999 .68398 L .20401 .67926 L p .707 .577 .707 r
F P
0 g
s
.61939 .25906 m .62764 .76176 L .59792 .75331 L p .707 .577 .707 r
F P
0 g
s
.59792 .75331 m .58967 .25061 L .61939 .25906 L p .707 .577 .707 r
F P
0 g
s
.17253 .82095 m .16449 .80354 L .18037 .79395 L p .707 .577 .707 r
F P
0 g
s
.306 .60583 m .30534 .66134 L .27417 .65907 L p .707 .577 .707 r
F P
0 g
s
.27417 .65907 m .27483 .60356 L .306 .60583 L p .707 .577 .707 r
F P
0 g
s
.18037 .79395 m .1884 .81136 L .17253 .82095 L p .707 .577 .707 r
F P
0 g
s
.24234 .65951 m .24299 .604 L .27483 .60356 L p .707 .577 .707 r
F P
0 g
s
.24299 .604 m .24234 .65951 L .21296 .66262 L p .707 .577 .707 r
F P
0 g
s
.20401 .67926 m .20164 .71598 L .17762 .7207 L p .707 .577 .707 r
F P
0 g
s
.27483 .60356 m .27417 .65907 L .24234 .65951 L p .707 .577 .707 r
F P
0 g
s
.74083 .65797 m .74149 .60246 L .71032 .60019 L p .707 .577 .707 r
F P
0 g
s
.74149 .60246 m .74083 .65797 L .77267 .65753 L p .707 .577 .707 r
F P
0 g
s
.77267 .65753 m .77332 .60202 L .74149 .60246 L p .707 .577 .707 r
F P
0 g
s
.32363 .68868 m .32125 .7254 L .29386 .71899 L p .707 .577 .707 r
F P
0 g
s
.29386 .71899 m .29623 .68228 L .32363 .68868 L p .707 .577 .707 r
F P
0 g
s
.77332 .60202 m .77267 .65753 L .80205 .65441 L p .707 .577 .707 r
F P
0 g
s
.80205 .65441 m .8027 .5989 L .77332 .60202 L p .707 .577 .707 r
F P
0 g
s
.38654 .25856 m .39479 .76126 L .37168 .77178 L p .707 .577 .707 r
F P
0 g
s
.39479 .76126 m .38654 .25856 L .42049 .25025 L p .707 .577 .707 r
F P
0 g
s
.70966 .6557 m .71032 .60019 L .68286 .59543 L p .707 .577 .707 r
F P
0 g
s
.71032 .60019 m .70966 .6557 L .74083 .65797 L p .707 .577 .707 r
F P
0 g
s
.20164 .71598 m .20401 .67926 L .23335 .67732 L p .707 .577 .707 r
F P
0 g
s
.8027 .5989 m .80205 .65441 L .8261 .64893 L p .707 .577 .707 r
F P
0 g
s
.8261 .64893 m .82675 .59342 L .8027 .5989 L p .707 .577 .707 r
F P
0 g
s
.29623 .68228 m .29386 .71899 L .26275 .71508 L p .707 .577 .707 r
F P
0 g
s
.26275 .71508 m .26513 .67836 L .29623 .68228 L p .707 .577 .707 r
F P
0 g
s
.1884 .81136 m .18037 .79395 L .20298 .78186 L p .707 .577 .707 r
F P
0 g
s
.23335 .67732 m .23098 .71404 L .20164 .71598 L p .707 .577 .707 r
F P
0 g
s
.20298 .78186 m .21101 .79926 L .1884 .81136 L p .707 .577 .707 r
F P
0 g
s
.31148 .73326 m .31952 .75066 L .29519 .76029 L p .707 .577 .707 r
F P
0 g
s
.29519 .76029 m .28716 .74289 L .31148 .73326 L p .707 .577 .707 r
F P
0 g
s
.23098 .71404 m .23335 .67732 L .26513 .67836 L p .707 .577 .707 r
F P
0 g
s
.58967 .25061 m .59792 .75331 L .55916 .74785 L p .707 .577 .707 r
F P
0 g
s
.55916 .74785 m .55091 .24514 L .58967 .25061 L p .707 .577 .707 r
F P
0 g
s
.68221 .65093 m .68286 .59543 L .66181 .58864 L p .707 .577 .707 r
F P
0 g
s
.68286 .59543 m .68221 .65093 L .70966 .6557 L p .707 .577 .707 r
F P
0 g
s
.26513 .67836 m .26275 .71508 L .23098 .71404 L p .707 .577 .707 r
F P
0 g
s
.72929 .72014 m .73166 .68342 L .70055 .6795 L p .707 .577 .707 r
F P
0 g
s
.73166 .68342 m .72929 .72014 L .76107 .72118 L p .707 .577 .707 r
F P
0 g
s
.76107 .72118 m .76344 .68446 L .73166 .68342 L p .707 .577 .707 r
F P
0 g
s
.76344 .68446 m .76107 .72118 L .7904 .71924 L p .707 .577 .707 r
F P
0 g
s
.7904 .71924 m .79277 .68252 L .76344 .68446 L p .707 .577 .707 r
F P
0 g
s
.42875 .75295 m .42049 .25025 L .46197 .24495 L p .707 .577 .707 r
F P
0 g
s
.42049 .25025 m .42875 .75295 L .39479 .76126 L p .707 .577 .707 r
F P
0 g
s
.69818 .71622 m .70055 .6795 L .67316 .6731 L p .707 .577 .707 r
F P
0 g
s
.70055 .6795 m .69818 .71622 L .72929 .72014 L p .707 .577 .707 r
F P
0 g
s
.82675 .59342 m .8261 .64893 L .84247 .64162 L p .707 .577 .707 r
F P
0 g
s
.84247 .64162 m .84312 .58611 L .82675 .59342 L p .707 .577 .707 r
F P
0 g
s
.21101 .79926 m .20298 .78186 L .23011 .76844 L p .707 .577 .707 r
F P
0 g
s
.28716 .74289 m .29519 .76029 L .26716 .77242 L p .707 .577 .707 r
F P
0 g
s
.26716 .77242 m .25912 .75501 L .28716 .74289 L p .707 .577 .707 r
F P
0 g
s
.23011 .76844 m .23815 .78585 L .21101 .79926 L p .707 .577 .707 r
F P
0 g
s
.66181 .58864 m .66115 .64415 L .68221 .65093 L p .707 .577 .707 r
F P
0 g
s
.79277 .68252 m .7904 .71924 L .81442 .71452 L p .707 .577 .707 r
F P
0 g
s
.81442 .71452 m .8168 .6778 L .79277 .68252 L p .707 .577 .707 r
F P
0 g
s
.55091 .24514 m .55916 .74785 L .51516 .7459 L p .707 .577 .707 r
F P
0 g
s
.51516 .7459 m .50691 .24319 L .55091 .24514 L p .707 .577 .707 r
F P
0 g
s
.72755 .74485 m .71952 .72745 L .69148 .73957 L p .707 .577 .707 r
F P
0 g
s
.71952 .72745 m .72755 .74485 L .75656 .73143 L p .707 .577 .707 r
F P
0 g
s
.75656 .73143 m .74852 .71402 L .71952 .72745 L p .707 .577 .707 r
F P
0 g
s
.67316 .6731 m .67079 .70981 L .69818 .71622 L p .707 .577 .707 r
F P
0 g
s
.74852 .71402 m .75656 .73143 L .7837 .71801 L p .707 .577 .707 r
F P
0 g
s
.7837 .71801 m .77566 .7006 L .74852 .71402 L p .707 .577 .707 r
F P
0 g
s
.69148 .73957 m .69951 .75698 L .72755 .74485 L p .707 .577 .707 r
F P
0 g
s
.66115 .64415 m .66181 .58864 L .64922 .58049 L p .707 .577 .707 r
F P
0 g
s
.23815 .78585 m .23011 .76844 L .25912 .75501 L p .707 .577 .707 r
F P
0 g
s
.25912 .75501 m .26716 .77242 L .23815 .78585 L p .707 .577 .707 r
F P
0 g
s
.67079 .70981 m .67316 .6731 L .65216 .66482 L p .707 .577 .707 r
F P
0 g
s
.47022 .74765 m .46197 .24495 L .50691 .24319 L p .707 .577 .707 r
F P
0 g
s
.46197 .24495 m .47022 .74765 L .42875 .75295 L p .707 .577 .707 r
F P
0 g
s
.50691 .24319 m .51516 .7459 L .47022 .74765 L p .707 .577 .707 r
F P
0 g
s
.69951 .75698 m .69148 .73957 L .66716 .7492 L p .707 .577 .707 r
F P
0 g
s
.77566 .7006 m .7837 .71801 L .80631 .70591 L p .707 .577 .707 r
F P
0 g
s
.80631 .70591 m .79827 .6885 L .77566 .7006 L p .707 .577 .707 r
F P
0 g
s
.66716 .7492 m .67519 .76661 L .69951 .75698 L p .707 .577 .707 r
F P
0 g
s
.65216 .66482 m .64979 .70154 L .67079 .70981 L p .707 .577 .707 r
F P
0 g
s
.64922 .58049 m .64856 .636 L .66115 .64415 L p .707 .577 .707 r
F P
0 g
s
.84312 .58611 m .84247 .64162 L .84955 .6332 L p .707 .577 .707 r
F P
0 g
s
.84955 .6332 m .85021 .57769 L .84312 .58611 L p .707 .577 .707 r
F P
0 g
s
.8168 .6778 m .81442 .71452 L .83078 .70747 L p .707 .577 .707 r
F P
0 g
s
.83078 .70747 m .83316 .67075 L .8168 .6778 L p .707 .577 .707 r
F P
0 g
s
.64979 .70154 m .65216 .66482 L .63962 .6555 L p .707 .577 .707 r
F P
0 g
s
.67519 .76661 m .66716 .7492 L .64893 .7554 L p .707 .577 .707 r
F P
0 g
s
.64893 .7554 m .65697 .77281 L .67519 .76661 L p .707 .577 .707 r
F P
0 g
s
.64856 .636 m .64922 .58049 L .64632 .57178 L p .707 .577 .707 r
F P
0 g
s
.79827 .6885 m .80631 .70591 L .82218 .69632 L p .707 .577 .707 r
F P
0 g
s
.82218 .69632 m .81414 .67892 L .79827 .6885 L p .707 .577 .707 r
F P
0 g
s
.63962 .6555 m .63724 .69222 L .64979 .70154 L p .707 .577 .707 r
F P
0 g
s
.64632 .57178 m .64567 .62729 L .64856 .636 L p .707 .577 .707 r
F P
0 g
s
.83316 .67075 m .83078 .70747 L .83788 .69878 L p .707 .577 .707 r
F P
0 g
s
.83788 .69878 m .84025 .66207 L .83316 .67075 L p .707 .577 .707 r
F P
0 g
s
.85021 .57769 m .84955 .6332 L .84666 .62449 L p .707 .577 .707 r
F P
0 g
s
.84666 .62449 m .84731 .56898 L .85021 .57769 L p .707 .577 .707 r
F P
0 g
s
.65697 .77281 m .64893 .7554 L .63858 .75755 L p .707 .577 .707 r
F P
0 g
s
.63724 .69222 m .63962 .6555 L .63675 .64603 L p .707 .577 .707 r
F P
0 g
s
.63858 .75755 m .64662 .77496 L .65697 .77281 L p .707 .577 .707 r
F P
0 g
s
.81414 .67892 m .82218 .69632 L .82976 .69018 L p .707 .577 .707 r
F P
0 g
s
.82976 .69018 m .82172 .67277 L .81414 .67892 L p .707 .577 .707 r
F P
0 g
s
.64567 .62729 m .64632 .57178 L .6534 .56335 L p .707 .577 .707 r
F P
0 g
s
.63675 .64603 m .63438 .68275 L .63724 .69222 L p .707 .577 .707 r
F P
0 g
s
.84025 .66207 m .83788 .69878 L .83501 .68932 L p .707 .577 .707 r
F P
0 g
s
.83501 .68932 m .83738 .6526 L .84025 .66207 L p .707 .577 .707 r
F P
0 g
s
.6534 .56335 m .65275 .61886 L .64567 .62729 L p .707 .577 .707 r
F P
0 g
s
.84731 .56898 m .84666 .62449 L .83407 .61634 L p .707 .577 .707 r
F P
0 g
s
.83407 .61634 m .83472 .56083 L .84731 .56898 L p .707 .577 .707 r
F P
0 g
s
.64662 .77496 m .63858 .75755 L .63713 .75546 L p .708 .578 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63713 .75546 m .64516 .77286 L .64662 .77496 L p .708 .578 .707 r
F P
0 g
s
.63438 .68275 m .63675 .64603 L .64384 .63735 L p .707 .577 .707 r
F P
0 g
s
.82172 .67277 m .82976 .69018 L .8283 .68808 L p .708 .578 .707 r
F P
0 g
s
.8283 .68808 m .82027 .67068 L .82172 .67277 L p .708 .578 .707 r
F P
0 g
s
.39782 .62248 m .39848 .56697 L .36731 .5647 L p .707 .577 .707 r
F P
0 g
s
.39848 .56697 m .39782 .62248 L .42966 .62204 L p .707 .577 .707 r
F P
0 g
s
.42966 .62204 m .43031 .56653 L .39848 .56697 L p .707 .577 .707 r
F P
0 g
s
.65275 .61886 m .6534 .56335 L .66977 .55604 L p .707 .577 .707 r
F P
0 g
s
.43031 .56653 m .42966 .62204 L .45904 .61892 L p .707 .577 .707 r
F P
0 g
s
.45904 .61892 m .45969 .56341 L .43031 .56653 L p .707 .577 .707 r
F P
0 g
s
.36665 .62021 m .36731 .5647 L .33985 .55994 L p .707 .577 .707 r
F P
0 g
s
.36731 .5647 m .36665 .62021 L .39782 .62248 L p .707 .577 .707 r
F P
0 g
s
.64384 .63735 m .64147 .67406 L .63438 .68275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45969 .56341 m .45904 .61892 L .48309 .61344 L p .707 .577 .707 r
F P
0 g
s
.48309 .61344 m .48374 .55793 L .45969 .56341 L p .707 .577 .707 r
F P
0 g
s
.82027 .67068 m .8283 .68808 L .81796 .69024 L p .707 .577 .707 r
F P
0 g
s
.83738 .6526 m .83501 .68932 L .82246 .67999 L p .707 .577 .707 r
F P
0 g
s
.82246 .67999 m .82484 .64327 L .83738 .6526 L p .707 .577 .707 r
F P
0 g
s
.66977 .55604 m .66912 .61155 L .65275 .61886 L p .707 .577 .707 r
F P
0 g
s
.83472 .56083 m .83407 .61634 L .81301 .60955 L p .707 .577 .707 r
F P
0 g
s
.81301 .60955 m .81367 .55404 L .83472 .56083 L p .707 .577 .707 r
F P
0 g
s
.3392 .61544 m .33985 .55994 L .3188 .55315 L p .707 .577 .707 r
F P
0 g
s
.33985 .55994 m .3392 .61544 L .36665 .62021 L p .707 .577 .707 r
F P
0 g
s
.38628 .68178 m .38865 .64506 L .35754 .64115 L p .707 .577 .707 r
F P
0 g
s
.38865 .64506 m .38628 .68178 L .41806 .68282 L p .707 .577 .707 r
F P
0 g
s
.41806 .68282 m .42043 .6461 L .38865 .64506 L p .707 .577 .707 r
F P
0 g
s
.64147 .67406 m .64384 .63735 L .6602 .6303 L p .707 .577 .707 r
F P
0 g
s
.64516 .77286 m .63713 .75546 L .64471 .74931 L p .707 .577 .707 r
F P
0 g
s
.66912 .61155 m .66977 .55604 L .69382 .55057 L p .707 .577 .707 r
F P
0 g
s
.64471 .74931 m .65274 .76672 L .64516 .77286 L p .707 .577 .707 r
F P
0 g
s
.42043 .6461 m .41806 .68282 L .44739 .68089 L p .707 .577 .707 r
F P
0 g
s
.44739 .68089 m .44977 .64417 L .42043 .6461 L p .707 .577 .707 r
F P
0 g
s
.81796 .69024 m .80992 .67283 L .82027 .67068 L p .707 .577 .707 r
F P
0 g
s
.35517 .67787 m .35754 .64115 L .33015 .63474 L p .707 .577 .707 r
F P
0 g
s
.35754 .64115 m .35517 .67787 L .38628 .68178 L p .707 .577 .707 r
F P
0 g
s
.48374 .55793 m .48309 .61344 L .49946 .60613 L p .707 .577 .707 r
F P
0 g
s
.49946 .60613 m .50011 .55062 L .48374 .55793 L p .707 .577 .707 r
F P
0 g
s
.6602 .6303 m .65783 .66702 L .64147 .67406 L p .707 .577 .707 r
F P
0 g
s
.3188 .55315 m .31814 .60866 L .3392 .61544 L p .707 .577 .707 r
F P
0 g
s
.81367 .55404 m .81301 .60955 L .78556 .60479 L p .707 .577 .707 r
F P
0 g
s
.78556 .60479 m .78621 .54928 L .81367 .55404 L p .707 .577 .707 r
F P
0 g
s
.44977 .64417 m .44739 .68089 L .47141 .67616 L p .707 .577 .707 r
F P
0 g
s
.47141 .67616 m .47379 .63944 L .44977 .64417 L p .707 .577 .707 r
F P
0 g
s
.33015 .63474 m .32778 .67146 L .35517 .67787 L p .707 .577 .707 r
F P
0 g
s
.38454 .70704 m .37651 .68964 L .34847 .70176 L p .707 .577 .707 r
F P
0 g
s
.37651 .68964 m .38454 .70704 L .41355 .69362 L p .707 .577 .707 r
F P
0 g
s
.41355 .69362 m .40551 .67621 L .37651 .68964 L p .707 .577 .707 r
F P
0 g
s
.40551 .67621 m .41355 .69362 L .44069 .6802 L p .707 .577 .707 r
F P
0 g
s
.44069 .6802 m .43265 .66279 L .40551 .67621 L p .707 .577 .707 r
F P
0 g
s
.69382 .55057 m .69317 .60607 L .66912 .61155 L p .707 .577 .707 r
F P
0 g
s
.34847 .70176 m .3565 .71917 L .38454 .70704 L p .707 .577 .707 r
F P
0 g
s
.80992 .67283 m .81796 .69024 L .79973 .69644 L p .707 .577 .707 r
F P
0 g
s
.79973 .69644 m .79169 .67903 L .80992 .67283 L p .707 .577 .707 r
F P
0 g
s
.82484 .64327 m .82246 .67999 L .80147 .67172 L p .707 .577 .707 r
F P
0 g
s
.80147 .67172 m .80384 .635 L .82484 .64327 L p .707 .577 .707 r
F P
0 g
s
.31814 .60866 m .3188 .55315 L .30621 .545 L p .707 .577 .707 r
F P
0 g
s
.32778 .67146 m .33015 .63474 L .30915 .62647 L p .707 .577 .707 r
F P
0 g
s
.69317 .60607 m .69382 .55057 L .72321 .54745 L p .707 .577 .707 r
F P
0 g
s
.3565 .71917 m .34847 .70176 L .32415 .71139 L p .707 .577 .707 r
F P
0 g
s
.65783 .66702 m .6602 .6303 L .68423 .62557 L p .707 .577 .707 r
F P
0 g
s
.43265 .66279 m .44069 .6802 L .4633 .6681 L p .707 .577 .707 r
F P
0 g
s
.4633 .6681 m .45526 .65069 L .43265 .66279 L p .707 .577 .707 r
F P
0 g
s
.32415 .71139 m .33218 .7288 L .3565 .71917 L p .707 .577 .707 r
F P
0 g
s
.78621 .54928 m .78556 .60479 L .75439 .60252 L p .707 .577 .707 r
F P
0 g
s
.75439 .60252 m .75504 .54701 L .78621 .54928 L p .707 .577 .707 r
F P
0 g
s
.65274 .76672 m .64471 .74931 L .66058 .73972 L p .707 .577 .707 r
F P
0 g
s
.30915 .62647 m .30678 .66319 L .32778 .67146 L p .707 .577 .707 r
F P
0 g
s
.66058 .73972 m .66862 .75713 L .65274 .76672 L p .707 .577 .707 r
F P
0 g
s
.72255 .60296 m .72321 .54745 L .75504 .54701 L p .707 .577 .707 r
F P
0 g
s
.72321 .54745 m .72255 .60296 L .69317 .60607 L p .707 .577 .707 r
F P
0 g
s
.30621 .545 m .30555 .60051 L .31814 .60866 L p .707 .577 .707 r
F P
0 g
s
.50011 .55062 m .49946 .60613 L .50654 .59771 L p .707 .577 .707 r
F P
0 g
s
.50654 .59771 m .5072 .5422 L .50011 .55062 L p .707 .577 .707 r
F P
0 g
s
.47379 .63944 m .47141 .67616 L .48777 .66911 L p .707 .577 .707 r
F P
0 g
s
.48777 .66911 m .49015 .63239 L .47379 .63944 L p .707 .577 .707 r
F P
0 g
s
.75504 .54701 m .75439 .60252 L .72255 .60296 L p .707 .577 .707 r
F P
0 g
s
.68423 .62557 m .68185 .66229 L .65783 .66702 L p .707 .577 .707 r
F P
0 g
s
.80384 .635 m .80147 .67172 L .77407 .66531 L p .707 .577 .707 r
F P
0 g
s
.77407 .66531 m .77645 .62859 L .80384 .635 L p .707 .577 .707 r
F P
0 g
s
.30678 .66319 m .30915 .62647 L .29661 .61714 L p .707 .577 .707 r
F P
0 g
s
.33218 .7288 m .32415 .71139 L .30592 .71759 L p .707 .577 .707 r
F P
0 g
s
.30592 .71759 m .31396 .73499 L .33218 .7288 L p .707 .577 .707 r
F P
0 g
s
.45526 .65069 m .4633 .6681 L .47917 .65851 L p .707 .577 .707 r
F P
0 g
s
.47917 .65851 m .47113 .6411 L .45526 .65069 L p .707 .577 .707 r
F P
0 g
s
.68185 .66229 m .68423 .62557 L .71356 .62364 L p .707 .577 .707 r
F P
0 g
s
.30555 .60051 m .30621 .545 L .30331 .53629 L p .707 .577 .707 r
F P
0 g
s
.29661 .61714 m .29423 .65386 L .30678 .66319 L p .707 .577 .707 r
F P
0 g
s
.77645 .62859 m .77407 .66531 L .74297 .6614 L p .707 .577 .707 r
F P
0 g
s
.74297 .6614 m .74534 .62468 L .77645 .62859 L p .707 .577 .707 r
F P
0 g
s
.66862 .75713 m .66058 .73972 L .68319 .72763 L p .707 .577 .707 r
F P
0 g
s
.71356 .62364 m .71119 .66036 L .68185 .66229 L p .707 .577 .707 r
F P
0 g
s
.68319 .72763 m .69123 .74504 L .66862 .75713 L p .707 .577 .707 r
F P
0 g
s
.79169 .67903 m .79973 .69644 L .77541 .70607 L p .707 .577 .707 r
F P
0 g
s
.77541 .70607 m .76737 .68866 L .79169 .67903 L p .707 .577 .707 r
F P
0 g
s
.71119 .66036 m .71356 .62364 L .74534 .62468 L p .707 .577 .707 r
F P
0 g
s
.49015 .63239 m .48777 .66911 L .49487 .66043 L p .707 .577 .707 r
F P
0 g
s
.49487 .66043 m .49724 .62371 L .49015 .63239 L p .707 .577 .707 r
F P
0 g
s
.74534 .62468 m .74297 .6614 L .71119 .66036 L p .707 .577 .707 r
F P
0 g
s
.30331 .53629 m .30266 .59179 L .30555 .60051 L p .707 .577 .707 r
F P
0 g
s
.5072 .5422 m .50654 .59771 L .50365 .589 L p .707 .577 .707 r
F P
0 g
s
.50365 .589 m .5043 .53349 L .5072 .5422 L p .707 .577 .707 r
F P
0 g
s
.31396 .73499 m .30592 .71759 L .29557 .71974 L p .707 .577 .707 r
F P
0 g
s
.29423 .65386 m .29661 .61714 L .29374 .60767 L p .707 .577 .707 r
F P
0 g
s
.29557 .71974 m .30361 .73715 L .31396 .73499 L p .707 .577 .707 r
F P
0 g
s
.47113 .6411 m .47917 .65851 L .48675 .65237 L p .707 .577 .707 r
F P
0 g
s
.48675 .65237 m .47871 .63496 L .47113 .6411 L p .707 .577 .707 r
F P
0 g
s
.69123 .74504 m .68319 .72763 L .71033 .71421 L p .707 .577 .707 r
F P
0 g
s
.76737 .68866 m .77541 .70607 L .74737 .71819 L p .707 .577 .707 r
F P
0 g
s
.74737 .71819 m .73934 .70078 L .76737 .68866 L p .707 .577 .707 r
F P
0 g
s
.71033 .71421 m .71836 .73162 L .69123 .74504 L p .707 .577 .707 r
F P
0 g
s
.30266 .59179 m .30331 .53629 L .31039 .52786 L p .707 .577 .707 r
F P
0 g
s
.29374 .60767 m .29137 .64439 L .29423 .65386 L p .707 .577 .707 r
F P
0 g
s
.71836 .73162 m .71033 .71421 L .73934 .70078 L p .707 .577 .707 r
F P
0 g
s
.73934 .70078 m .74737 .71819 L .71836 .73162 L p .707 .577 .707 r
F P
0 g
s
.49724 .62371 m .49487 .66043 L .492 .65096 L p .707 .577 .707 r
F P
0 g
s
.492 .65096 m .49437 .61424 L .49724 .62371 L p .707 .577 .707 r
F P
0 g
s
.31039 .52786 m .30974 .58337 L .30266 .59179 L p .707 .577 .707 r
F P
0 g
s
.5043 .53349 m .50365 .589 L .49106 .58085 L p .707 .577 .707 r
F P
0 g
s
.49106 .58085 m .49171 .52534 L .5043 .53349 L p .707 .577 .707 r
F P
0 g
s
.30361 .73715 m .29557 .71974 L .29412 .71764 L p .708 .578 .707 r
F P
0 g
s
.29137 .64439 m .29374 .60767 L .30083 .59899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29412 .71764 m .30215 .73505 L .30361 .73715 L p .708 .578 .707 r
F P
0 g
s
.47871 .63496 m .48675 .65237 L .48529 .65027 L p .708 .578 .707 r
F P
0 g
s
.48529 .65027 m .47726 .63286 L .47871 .63496 L p .708 .578 .707 r
F P
0 g
s
.30974 .58337 m .31039 .52786 L .32676 .52055 L p .707 .577 .707 r
F P
0 g
s
.30083 .59899 m .29846 .63571 L .29137 .64439 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47726 .63286 m .48529 .65027 L .47495 .65243 L p .707 .577 .707 r
F P
0 g
s
.49437 .61424 m .492 .65096 L .47945 .64163 L p .707 .577 .707 r
F P
0 g
s
.47945 .64163 m .48183 .60492 L .49437 .61424 L p .707 .577 .707 r
F P
0 g
s
.32676 .52055 m .32611 .57606 L .30974 .58337 L p .707 .577 .707 r
F P
0 g
s
.49171 .52534 m .49106 .58085 L .47 .57406 L p .707 .577 .707 r
F P
0 g
s
.47 .57406 m .47066 .51855 L .49171 .52534 L p .707 .577 .707 r
F P
0 g
s
.29846 .63571 m .30083 .59899 L .31719 .59194 L p .707 .577 .707 r
F P
0 g
s
.30215 .73505 m .29412 .71764 L .3017 .7115 L p .707 .577 .707 r
F P
0 g
s
.3017 .7115 m .30973 .72891 L .30215 .73505 L p .707 .577 .707 r
F P
0 g
s
.32611 .57606 m .32676 .52055 L .35081 .51507 L p .707 .577 .707 r
F P
0 g
s
.47495 .65243 m .46691 .63502 L .47726 .63286 L p .707 .577 .707 r
F P
0 g
s
.31719 .59194 m .31482 .62866 L .29846 .63571 L p .707 .577 .707 r
F P
0 g
s
.47066 .51855 m .47 .57406 L .44255 .5693 L p .707 .577 .707 r
F P
0 g
s
.44255 .5693 m .4432 .51379 L .47066 .51855 L p .707 .577 .707 r
F P
0 g
s
.35081 .51507 m .35016 .57058 L .32611 .57606 L p .707 .577 .707 r
F P
0 g
s
.46691 .63502 m .47495 .65243 L .45672 .65862 L p .707 .577 .707 r
F P
0 g
s
.45672 .65862 m .44868 .64122 L .46691 .63502 L p .707 .577 .707 r
F P
0 g
s
.48183 .60492 m .47945 .64163 L .45846 .63336 L p .707 .577 .707 r
F P
0 g
s
.45846 .63336 m .46083 .59664 L .48183 .60492 L p .707 .577 .707 r
F P
0 g
s
.35016 .57058 m .35081 .51507 L .3802 .51196 L p .707 .577 .707 r
F P
0 g
s
.31482 .62866 m .31719 .59194 L .34122 .58722 L p .707 .577 .707 r
F P
0 g
s
.30973 .72891 m .3017 .7115 L .31757 .70191 L p .707 .577 .707 r
F P
0 g
s
.4432 .51379 m .44255 .5693 L .41138 .56703 L p .707 .577 .707 r
F P
0 g
s
.41138 .56703 m .41203 .51152 L .4432 .51379 L p .707 .577 .707 r
F P
0 g
s
.31757 .70191 m .3256 .71932 L .30973 .72891 L p .707 .577 .707 r
F P
0 g
s
.37954 .56747 m .3802 .51196 L .41203 .51152 L p .707 .577 .707 r
F P
0 g
s
.3802 .51196 m .37954 .56747 L .35016 .57058 L p .707 .577 .707 r
F P
0 g
s
.34122 .58722 m .33884 .62394 L .31482 .62866 L p .707 .577 .707 r
F P
0 g
s
.41203 .51152 m .41138 .56703 L .37954 .56747 L p .707 .577 .707 r
F P
0 g
s
.46083 .59664 m .45846 .63336 L .43106 .62696 L p .707 .577 .707 r
F P
0 g
s
.43106 .62696 m .43344 .59024 L .46083 .59664 L p .707 .577 .707 r
F P
0 g
s
.33884 .62394 m .34122 .58722 L .37055 .58528 L p .707 .577 .707 r
F P
0 g
s
.43344 .59024 m .43106 .62696 L .39996 .62304 L p .707 .577 .707 r
F P
0 g
s
.39996 .62304 m .40233 .58632 L .43344 .59024 L p .707 .577 .707 r
F P
0 g
s
.3256 .71932 m .31757 .70191 L .34018 .68982 L p .707 .577 .707 r
F P
0 g
s
.37055 .58528 m .36818 .622 L .33884 .62394 L p .707 .577 .707 r
F P
0 g
s
.34018 .68982 m .34822 .70723 L .3256 .71932 L p .707 .577 .707 r
F P
0 g
s
.44868 .64122 m .45672 .65862 L .4324 .66826 L p .707 .577 .707 r
F P
0 g
s
.4324 .66826 m .42436 .65085 L .44868 .64122 L p .707 .577 .707 r
F P
0 g
s
.36818 .622 m .37055 .58528 L .40233 .58632 L p .707 .577 .707 r
F P
0 g
s
.40233 .58632 m .39996 .62304 L .36818 .622 L p .707 .577 .707 r
F P
0 g
s
.34822 .70723 m .34018 .68982 L .36732 .6764 L p .707 .577 .707 r
F P
0 g
s
.42436 .65085 m .4324 .66826 L .40436 .68038 L p .707 .577 .707 r
F P
0 g
s
.40436 .68038 m .39632 .66297 L .42436 .65085 L p .707 .577 .707 r
F P
0 g
s
.36732 .6764 m .37535 .69381 L .34822 .70723 L p .707 .577 .707 r
F P
0 g
s
.37535 .69381 m .36732 .6764 L .39632 .66297 L p .707 .577 .707 r
F P
0 g
s
.39632 .66297 m .40436 .68038 L .37535 .69381 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00
FUIJEP0A000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol0069oo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool005ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005ao
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00FWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000BOolA
0012Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000jOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<Goo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;goo001FOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;Goo001FOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0`00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001J
EUYF009JEP@0009JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ao
o`00EWoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@0015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`04001JEP00FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00<0
05YFFUH00eYF00<005YFFUH00eYF4@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000AJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00@005YFFUIJEPP000=J
EP03001JEUYF00IJEP03001JEUYF009JEPH000EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001JEUYF00D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP09001JEUYFFUH005YF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:goo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH01000FUIJEUYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo0011OolA0002Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo000kOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH80008FUH00`00
FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool003Moo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEPD0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF008002]o
o`00=Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000[Ool003=oo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000015YF000000001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF0000009JEP8002]oo`00<Goo0P000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF1000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEQL000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<002]oo`00;goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH500000eYF001J
EP04FUH20002FUH00`00FUIJEP04FUH30004FUH60006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<0
05YF00000`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00:goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000AJEP000000009JEP03001JEUYF
00=JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001J
EUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF0`00
1EYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF100015YF00H005YFFUH005YF0004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP02
FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEP0000<00003FUH00000009J
EP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP800006FUH00000001JEP000UYF00<005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000800003FUH005YF00=JEP8002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF
1`001EYF0`001eYF00<005YFFUH00UYF0`0015YF00@005YF0000009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP80
02eoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF500000=JEP00
FUH01EYF00D005YFFUH005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP00009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000_Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=J
EP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH00eYF0`0000AJEP00000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH01eYF00<005YF00000P0000=JEP00FUH010001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000=J
EP<000EJEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3
0004FUH2000015YF001JEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP04001JEUYF
FUH90008FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
0007FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPT0009JEP03001oogoo
00=oo`T000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00
;goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01EYF00<005YFFUH01UYF10002EYF00@005YF000000EJEP800003FUH005YF009JEP80
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40002
FUH00`00FUIJEP03FUH00`00FUIJEP020006Ool30004Ool60005FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002moo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJEP8000=JEP03
001JEUYF00EJEP<000EJEP8000=JEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUH005YF001JEP800004FUH000000002FUH00`00FUIJEP03FUH00`00
FUIJEP020005Ool50009Ool400000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002mo
o`03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH400000eYF001JEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01@00FUIJ
EUYF00001EYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEP00FUH200000eYF001JEP03FUH30005FUH00`00FUIJEP020005Ool5000=Ool30004FUH01000
FUIJEUYF0P00;Woo000_Ool01@00FUH005YF00001EYF00<005YFFUH00eYF3`001EYF00<005YFFUH0
1EYF00<005YFFUH015YF200025YF00<005YF00000P001EYF00@005YF000000=JEPD000YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00
FUH00003000015YF001JEUYF0P001Goo1@003Woo1@0000=JEP00FUH00UYF0P00;Woo000_Ool20002
FUH01000FUIJEUYF20000eYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH01UYF00<005YF
FUH015YF00@005YFFUIJEP<000UJEP8000UJEPH0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH6
0006Ool3000<Ool30004FUH30003FUH2000^Ool002moo`03001JEUYF00D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPH000=JEP03001JEUYF00AJEP04001JEP000003FUH00`00
FUIJEP04FUH300000eYF001JEP05FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQD00003FUH005YF00AJEP04001JEUYF0002FUH2000^Ool002moo`<00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH20005FUH00`00
FUIJEP02FUH500000eYF001JEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00@005YF000000IJEP03001JEUYF00=JEP03001JEP0000@002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000=JEP00000025YF00<005YF00001P000UYF00<005YF00000P002eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEUYF009J
EP<00003FUH00000008002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF0P000eYF0`000eYF0P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH00`00FUIJEP05FUH01000FUH000000UYF0P0000AJEP00000002ioo`00;7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YFFUH015YF0`00
15YF00H005YFFUH005YF000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000QJEP03001JEP0000<0009JEP03001JEUYF008000=JEP8002moo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001eYF00@005YF000000MJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001UYF
00000000FUH000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP8000MJEP<000AJEP8002moo`00
;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00P000eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF0`001UYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P0000=JEP00FUH015YF0P000UYF
00@005YFFUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH010000UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF0P000eYF00@005YFFUIJEP8000AJEP04001JEP00000bOol002aoo`80
00AJEP04001JEUYFFUHI0004FUH200000eYF001JEP04FUH01000FUH000001EYF00<005YF00000P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF20002EYF00@005YF0000
00IJEP<000=JEPD003Aoo`00:goo00<005YF00000eYF1@006Goo1@000UYF00<005YFFUH00eYF0P00
1UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P000UYF00<005YFFUH01eYF0P001eYF1`00>Goo000[Ool01000FUH005YF0P00
00AJEP00000001=oo`<000Qoo`05001JEUYFFUH00003FUH00`00FUH00004FUH200000eYF00000002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH30004FUH0
0`00FUIJEP05FUH40005FUH20010Ool002]oo`06001JEP00001JEP0015YF0`003goo1@0027oo00D0
05YFFUH005YF008000=JEP04001JEP000002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH30004FUH20007FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P00@Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000;Ool50008Ool01@00FUIJEUYF
000015YF0`0000MJEP00FUIJEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20004FUH60008FUH00`00FUIJEP02000015YF000000000UYF0`00A7oo000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH70004Ool50009Ool015YF000000000UYF0P0000=JEP00FUH0
0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`000eYF
00<005YFFUH01EYF0`001UYF0P00Agoo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUHH0004FUH01@00FUH00000FUH00`000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF0P00BGoo
000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUH000020005FUH01000FUH00000
Bgoo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0`001UYF00<005YFFUH00eYF20000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000AJEP00FUH000MJEP8000QJEP8004eoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00MJEP03001JEP0000800003FUH005YF
00D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQh000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP800003FUH005YF00EJEP8004moo`00;Goo0P00
00=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP<000AJEP03001JEUYF
00AJEP<000EJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF
1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF009JEP80055oo`00;goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF009JEP80009JEP04001JEUYF
FUH20002FUH200001Goo001JEUYF00001UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00`001EYF00@005YF0000
00EJEP04001JEP00001COol0035oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@000UJEP04
001JEP000005FUH40003FUH200001Goo001JEUYF00001UYF00<005YFFUH010002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00AJEP<005Eoo`00<goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
0P000eYF00<005YFFUH01EYF0`001eYF00@005YFFUH000=JEP04001oogoo0002FUH00`00FUIJEP03
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH40002FUH200000eYF001JEP02FUH30002FUH40002FUH00`00Oomoo`1COol003Eoo`D0
00=JEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP8000=JEP04
001JEP000003Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP800004FUH005YFFUH30002FUH3
00000eYF001JEP02FUH2001EOol003Yoo`H00003FUH0000000QJEP03001JEP00008000EJEP03001J
EUYF0080009JEPD000Eoo`05001JEUYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH200000eYF
0000000300000eYF001JEP02FUH2001EOol003moo`<000UJEP8000UJEPH000Yoo`03001JEUYF0080
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000@000AJEP<000=JEP8005Eoo`00?Goo
0P000eYF00<005YFFUH015YF0`0000=JEP00FUH01EYF0P0047oo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00H005YF000005YF0005FUH01000FUIJEP000UYF0P00EGoo000kOol20005
FUH00`00FUIJEP02FUH500000eYF001JEP03FUH2000BOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00001000EGoo000iOol20008FUH00`00
FUH000060002FUH01000FUH0000057oo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF009JEP<00003FUH00000008005Eoo`00=goo0`002EYF0P000eYF0`000eYF
0P005Woo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YF0000009J
EP800004FUH00000001EOol003Eoo`8000=JEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80
01Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000AJEP06001JEUYF001JEP00
EGoo000cOol20005FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2000KOol00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP020003FUH2001FOol0035oo`<0
00MJEP04001JEP000007FUH01000FUH000007Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001eYF0`0015YF0P00EWoo000_Ool20003FUH00`00FUIJEP04FUH30007FUH3000POol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0000=JEP00FUH015YF0P000UYF00@005YFFUIJEP80
05Moo`00;Woo00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P009Goo0P00
00=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000=JEP04001JEUYFFUH20004FUH01000FUH00000FGoo000]Ool0
0`00FUH00005FUH01000FUH000001EYF00<005YF00000P00:Goo0`001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10001UYF0`000eYF1@00
Fgoo000/Ool01000FUIJEP001EYF0P001UYF0`00;goo10000UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01`0025YF1P00H7oo000/Ool01@00FUIJ
EUYF00000eYF00<005YF000015YF0P00=Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF1@0000=JEP00000010001UYF0P00IWoo000]Ool01@00FUIJEP00FUH00P000eYF00@0
05YF000003eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH600000eYF001J
EP03FUH500000eYF001JEP02FUH2001XOol002eoo`05001JEUYFFUH00004FUH30015OolO0007FUH0
0`00FUIJEP0700000eYF001JEP02001ZOol002ioo`04FUH000000002FUH2001ROol200000eYF001J
EP08FUH20003FUH30002FUH2001/Ool002ioo`H0069oo`8000AJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP<006ioo`00U7oo0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00`00LGoo002C
Ool00`00FUH00007FUH01000FUH000001UYF0P00M7oo002AOol20002FUH00`00FUIJEP05FUH20006
FUH2001fOol0091oo`03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00=JEP8007Qoo`00
SWoo0`001EYF00<005YFFUH00P0015YF00@005YF000007Yoo`00SWoo00@005YFFUH000EJEP8000EJ
EP<007aoo`00SWoo0P0000=JEP00FUH00UYF0`0015YF0P00Ogoo002?Ool00`00FUIJEP030003FUH0
1000FUH00000PGoo002?Ool00`00FUIJEP020002FUH40023Ool0091oo`H008Moo`00T7oo0P00Rgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60363 .75001 m .60428 .6945 L .57311 .69223 L p .707 .577 .707 r
F P
0 g
s
.60428 .6945 m .60363 .75001 L .63546 .74956 L p .707 .577 .707 r
F P
0 g
s
.63546 .74956 m .63612 .69406 L .60428 .6945 L p .707 .577 .707 r
F P
0 g
s
.63612 .69406 m .63546 .74956 L .66484 .74645 L p .707 .577 .707 r
F P
0 g
s
.66484 .74645 m .6655 .69094 L .63612 .69406 L p .707 .577 .707 r
F P
0 g
s
.57246 .74774 m .57311 .69223 L .54566 .68747 L p .707 .577 .707 r
F P
0 g
s
.57311 .69223 m .57246 .74774 L .60363 .75001 L p .707 .577 .707 r
F P
0 g
s
.6655 .69094 m .66484 .74645 L .6889 .74097 L p .707 .577 .707 r
F P
0 g
s
.6889 .74097 m .68955 .68546 L .6655 .69094 L p .707 .577 .707 r
F P
0 g
s
.545 .74297 m .54566 .68747 L .5246 .68068 L p .707 .577 .707 r
F P
0 g
s
.54566 .68747 m .545 .74297 L .57246 .74774 L p .707 .577 .707 r
F P
0 g
s
.59208 .81217 m .59446 .77546 L .56335 .77154 L p .707 .577 .707 r
F P
0 g
s
.59446 .77546 m .59208 .81217 L .62386 .81321 L p .707 .577 .707 r
F P
0 g
s
.62386 .81321 m .62623 .7765 L .59446 .77546 L p .707 .577 .707 r
F P
0 g
s
.62623 .7765 m .62386 .81321 L .6532 .81128 L p .707 .577 .707 r
F P
0 g
s
.6532 .81128 m .65557 .77456 L .62623 .7765 L p .707 .577 .707 r
F P
0 g
s
.56098 .80826 m .56335 .77154 L .53596 .76513 L p .707 .577 .707 r
F P
0 g
s
.56335 .77154 m .56098 .80826 L .59208 .81217 L p .707 .577 .707 r
F P
0 g
s
.68955 .68546 m .6889 .74097 L .70526 .73366 L p .707 .577 .707 r
F P
0 g
s
.70526 .73366 m .70592 .67815 L .68955 .68546 L p .707 .577 .707 r
F P
0 g
s
.5246 .68068 m .52395 .73619 L .545 .74297 L p .707 .577 .707 r
F P
0 g
s
.65557 .77456 m .6532 .81128 L .67722 .80655 L p .707 .577 .707 r
F P
0 g
s
.67722 .80655 m .67959 .76984 L .65557 .77456 L p .707 .577 .707 r
F P
0 g
s
.59035 .83689 m .58231 .81948 L .55427 .83161 L p .707 .577 .707 r
F P
0 g
s
.58231 .81948 m .59035 .83689 L .61935 .82346 L p .707 .577 .707 r
F P
0 g
s
.61935 .82346 m .61132 .80606 L .58231 .81948 L p .707 .577 .707 r
F P
0 g
s
.53596 .76513 m .53358 .80185 L .56098 .80826 L p .707 .577 .707 r
F P
0 g
s
.61132 .80606 m .61935 .82346 L .64649 .81005 L p .707 .577 .707 r
F P
0 g
s
.64649 .81005 m .63846 .79264 L .61132 .80606 L p .707 .577 .707 r
F P
0 g
s
.55427 .83161 m .56231 .84902 L .59035 .83689 L p .707 .577 .707 r
F P
0 g
s
.52395 .73619 m .5246 .68068 L .51201 .67253 L p .707 .577 .707 r
F P
0 g
s
.53358 .80185 m .53596 .76513 L .51496 .75686 L p .707 .577 .707 r
F P
0 g
s
.56231 .84902 m .55427 .83161 L .52995 .84124 L p .707 .577 .707 r
F P
0 g
s
.63846 .79264 m .64649 .81005 L .6691 .79795 L p .707 .577 .707 r
F P
0 g
s
.6691 .79795 m .66107 .78054 L .63846 .79264 L p .707 .577 .707 r
F P
0 g
s
.52995 .84124 m .53799 .85865 L .56231 .84902 L p .707 .577 .707 r
F P
0 g
s
.51496 .75686 m .51259 .79358 L .53358 .80185 L p .707 .577 .707 r
F P
0 g
s
.51201 .67253 m .51136 .72804 L .52395 .73619 L p .707 .577 .707 r
F P
0 g
s
.70592 .67815 m .70526 .73366 L .71235 .72524 L p .707 .577 .707 r
F P
0 g
s
.71235 .72524 m .713 .66973 L .70592 .67815 L p .707 .577 .707 r
F P
0 g
s
.67959 .76984 m .67722 .80655 L .69358 .79951 L p .707 .577 .707 r
F P
0 g
s
.69358 .79951 m .69595 .76279 L .67959 .76984 L p .707 .577 .707 r
F P
0 g
s
.51259 .79358 m .51496 .75686 L .50241 .74754 L p .707 .577 .707 r
F P
0 g
s
.53799 .85865 m .52995 .84124 L .51173 .84743 L p .707 .577 .707 r
F P
0 g
s
.51173 .84743 m .51976 .86484 L .53799 .85865 L p .707 .577 .707 r
F P
0 g
s
.51136 .72804 m .51201 .67253 L .50912 .66382 L p .707 .577 .707 r
F P
0 g
s
.66107 .78054 m .6691 .79795 L .68497 .78836 L p .707 .577 .707 r
F P
0 g
s
.68497 .78836 m .67694 .77095 L .66107 .78054 L p .707 .577 .707 r
F P
0 g
s
.50241 .74754 m .50004 .78425 L .51259 .79358 L p .707 .577 .707 r
F P
0 g
s
.50912 .66382 m .50846 .71932 L .51136 .72804 L p .707 .577 .707 r
F P
0 g
s
.69595 .76279 m .69358 .79951 L .70067 .79082 L p .707 .577 .707 r
F P
0 g
s
.70067 .79082 m .70305 .7541 L .69595 .76279 L p .707 .577 .707 r
F P
0 g
s
.713 .66973 m .71235 .72524 L .70945 .71653 L p .707 .577 .707 r
F P
0 g
s
.70945 .71653 m .71011 .66102 L .713 .66973 L p .707 .577 .707 r
F P
0 g
s
.51976 .86484 m .51173 .84743 L .50138 .84959 L p .707 .577 .707 r
F P
0 g
s
.50004 .78425 m .50241 .74754 L .49955 .73807 L p .707 .577 .707 r
F P
0 g
s
.50138 .84959 m .50941 .867 L .51976 .86484 L p .707 .577 .707 r
F P
0 g
s
.67694 .77095 m .68497 .78836 L .69255 .78222 L p .707 .577 .707 r
F P
0 g
s
.69255 .78222 m .68452 .76481 L .67694 .77095 L p .707 .577 .707 r
F P
0 g
s
.50846 .71932 m .50912 .66382 L .5162 .65539 L p .707 .577 .707 r
F P
0 g
s
.49602 .82167 m .48777 .31897 L .44377 .31702 L p .707 .577 .707 r
F P
0 g
s
.49955 .73807 m .49717 .77479 L .50004 .78425 L p .707 .577 .707 r
F P
0 g
s
.5162 .65539 m .51555 .7109 L .50846 .71932 L p .707 .577 .707 r
F P
0 g
s
.49717 .77479 m .49955 .73807 L .50664 .72938 L p .707 .577 .707 r
F P
0 g
s
.51555 .7109 m .5162 .65539 L .53257 .64808 L p .707 .577 .707 r
F P
0 g
s
.50664 .72938 m .50427 .7661 L .49717 .77479 L p .707 .577 .707 r
F P
0 g
s
.53257 .64808 m .53192 .70359 L .51555 .7109 L p .707 .577 .707 r
F P
0 g
s
.50427 .7661 m .50664 .72938 L .523 .72234 L p .707 .577 .707 r
F P
0 g
s
.523 .72234 m .52063 .75905 L .50427 .7661 L p .707 .577 .707 r
F P
0 g
s
.52063 .75905 m .523 .72234 L .54702 .71761 L p .707 .577 .707 r
F P
0 g
s
.54702 .71761 m .54465 .75433 L .52063 .75905 L p .707 .577 .707 r
F P
0 g
s
.48777 .31897 m .49602 .82167 L .54096 .81991 L p .707 .577 .707 r
F P
0 g
s
.53192 .70359 m .53257 .64808 L .55662 .6426 L p .707 .577 .707 r
F P
0 g
s
.55662 .6426 m .55597 .69811 L .53192 .70359 L p .707 .577 .707 r
F P
0 g
s
.54096 .81991 m .53271 .31721 L .48777 .31897 L p .707 .577 .707 r
F P
0 g
s
.55597 .69811 m .55662 .6426 L .586 .63949 L p .707 .577 .707 r
F P
0 g
s
.586 .63949 m .58535 .695 L .55597 .69811 L p .707 .577 .707 r
F P
0 g
s
.54465 .75433 m .54702 .71761 L .57636 .71568 L p .707 .577 .707 r
F P
0 g
s
.57636 .71568 m .57398 .75239 L .54465 .75433 L p .707 .577 .707 r
F P
0 g
s
.57398 .75239 m .57636 .71568 L .60814 .71672 L p .707 .577 .707 r
F P
0 g
s
.60814 .71672 m .60576 .75343 L .57398 .75239 L p .707 .577 .707 r
F P
0 g
s
.55402 .83707 m .54599 .81967 L .57312 .80625 L p .707 .577 .707 r
F P
0 g
s
.57312 .80625 m .58116 .82366 L .55402 .83707 L p .707 .577 .707 r
F P
0 g
s
.58116 .82366 m .57312 .80625 L .60213 .79282 L p .707 .577 .707 r
F P
0 g
s
.53271 .31721 m .54096 .81991 L .58244 .81461 L p .707 .577 .707 r
F P
0 g
s
.58244 .81461 m .57419 .31191 L .53271 .31721 L p .707 .577 .707 r
F P
0 g
s
.45202 .81972 m .44377 .31702 L .40501 .31155 L p .707 .577 .707 r
F P
0 g
s
.44377 .31702 m .45202 .81972 L .49602 .82167 L p .707 .577 .707 r
F P
0 g
s
.70305 .7541 m .70067 .79082 L .69781 .78135 L p .707 .577 .707 r
F P
0 g
s
.69781 .78135 m .70018 .74464 L .70305 .7541 L p .707 .577 .707 r
F P
0 g
s
.71011 .66102 m .70945 .71653 L .69686 .70838 L p .707 .577 .707 r
F P
0 g
s
.69686 .70838 m .69751 .65287 L .71011 .66102 L p .707 .577 .707 r
F P
0 g
s
.58535 .695 m .586 .63949 L .61783 .63905 L p .707 .577 .707 r
F P
0 g
s
.61783 .63905 m .61718 .69456 L .58535 .695 L p .707 .577 .707 r
F P
0 g
s
.63924 .72063 m .63687 .75735 L .60576 .75343 L p .707 .577 .707 r
F P
0 g
s
.60576 .75343 m .60814 .71672 L .63924 .72063 L p .707 .577 .707 r
F P
0 g
s
.63017 .7807 m .6382 .79811 L .61017 .81023 L p .707 .577 .707 r
F P
0 g
s
.61017 .81023 m .60213 .79282 L .63017 .7807 L p .707 .577 .707 r
F P
0 g
s
.60213 .79282 m .61017 .81023 L .58116 .82366 L p .707 .577 .707 r
F P
0 g
s
.57419 .31191 m .58244 .81461 L .61639 .8063 L p .707 .577 .707 r
F P
0 g
s
.61639 .8063 m .60814 .3036 L .57419 .31191 L p .707 .577 .707 r
F P
0 g
s
.50941 .867 m .50138 .84959 L .49992 .84749 L p .708 .578 .707 r
F P
0 g
s
.49992 .84749 m .50796 .8649 L .50941 .867 L p .708 .578 .707 r
F P
0 g
s
.68452 .76481 m .69255 .78222 L .6911 .78012 L p .708 .578 .707 r
F P
0 g
s
.6911 .78012 m .68306 .76271 L .68452 .76481 L p .708 .578 .707 r
F P
0 g
s
.26062 .71452 m .26127 .65901 L .2301 .65674 L p .707 .577 .707 r
F P
0 g
s
.26127 .65901 m .26062 .71452 L .29245 .71407 L p .707 .577 .707 r
F P
0 g
s
.29245 .71407 m .29311 .65857 L .26127 .65901 L p .707 .577 .707 r
F P
0 g
s
.29311 .65857 m .29245 .71407 L .32183 .71096 L p .707 .577 .707 r
F P
0 g
s
.32183 .71096 m .32249 .65545 L .29311 .65857 L p .707 .577 .707 r
F P
0 g
s
.41326 .81425 m .40501 .31155 L .37529 .3031 L p .707 .577 .707 r
F P
0 g
s
.40501 .31155 m .41326 .81425 L .45202 .81972 L p .707 .577 .707 r
F P
0 g
s
.22945 .71225 m .2301 .65674 L .20265 .65198 L p .707 .577 .707 r
F P
0 g
s
.2301 .65674 m .22945 .71225 L .26062 .71452 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.32249 .65545 m .32183 .71096 L .34589 .70548 L p .707 .577 .707 r
F P
0 g
s
.34589 .70548 m .34654 .64997 L .32249 .65545 L p .707 .577 .707 r
F P
0 g
s
.68306 .76271 m .6911 .78012 L .68075 .78228 L p .707 .577 .707 r
F P
0 g
s
.70018 .74464 m .69781 .78135 L .68526 .77203 L p .707 .577 .707 r
F P
0 g
s
.68526 .77203 m .68763 .73531 L .70018 .74464 L p .707 .577 .707 r
F P
0 g
s
.69751 .65287 m .69686 .70838 L .67581 .70159 L p .707 .577 .707 r
F P
0 g
s
.67581 .70159 m .67646 .64608 L .69751 .65287 L p .707 .577 .707 r
F P
0 g
s
.649 .64132 m .64835 .69683 L .61718 .69456 L p .707 .577 .707 r
F P
0 g
s
.61718 .69456 m .61783 .63905 L .649 .64132 L p .707 .577 .707 r
F P
0 g
s
.66664 .72704 m .66426 .76376 L .63687 .75735 L p .707 .577 .707 r
F P
0 g
s
.63687 .75735 m .63924 .72063 L .66664 .72704 L p .707 .577 .707 r
F P
0 g
s
.6382 .79811 m .63017 .7807 L .65449 .77107 L p .707 .577 .707 r
F P
0 g
s
.60814 .3036 m .61639 .8063 L .6395 .79578 L p .707 .577 .707 r
F P
0 g
s
.6395 .79578 m .63125 .29308 L .60814 .3036 L p .707 .577 .707 r
F P
0 g
s
.20199 .70748 m .20265 .65198 L .18159 .64519 L p .707 .577 .707 r
F P
0 g
s
.20265 .65198 m .20199 .70748 L .22945 .71225 L p .707 .577 .707 r
F P
0 g
s
.24908 .77382 m .25145 .7371 L .22034 .73319 L p .707 .577 .707 r
F P
0 g
s
.25145 .7371 m .24908 .77382 L .28085 .77486 L p .707 .577 .707 r
F P
0 g
s
.28085 .77486 m .28323 .73814 L .25145 .7371 L p .707 .577 .707 r
F P
0 g
s
.50796 .8649 m .49992 .84749 L .5075 .84135 L p .707 .577 .707 r
F P
0 g
s
.5075 .84135 m .51554 .85876 L .50796 .8649 L p .707 .577 .707 r
F P
0 g
s
.28323 .73814 m .28085 .77486 L .31019 .77292 L p .707 .577 .707 r
F P
0 g
s
.31019 .77292 m .31256 .73621 L .28323 .73814 L p .707 .577 .707 r
F P
0 g
s
.68075 .78228 m .67272 .76487 L .68306 .76271 L p .707 .577 .707 r
F P
0 g
s
.21797 .7699 m .22034 .73319 L .19295 .72678 L p .707 .577 .707 r
F P
0 g
s
.22034 .73319 m .21797 .7699 L .24908 .77382 L p .707 .577 .707 r
F P
0 g
s
.34654 .64997 m .34589 .70548 L .36226 .69817 L p .707 .577 .707 r
F P
0 g
s
.36226 .69817 m .36291 .64266 L .34654 .64997 L p .707 .577 .707 r
F P
0 g
s
.18159 .64519 m .18094 .7007 L .20199 .70748 L p .707 .577 .707 r
F P
0 g
s
.38354 .8058 m .37529 .3031 L .35752 .29249 L p .707 .577 .707 r
F P
0 g
s
.37529 .3031 m .38354 .8058 L .41326 .81425 L p .707 .577 .707 r
F P
0 g
s
.67646 .64608 m .67581 .70159 L .64835 .69683 L p .707 .577 .707 r
F P
0 g
s
.64835 .69683 m .649 .64132 L .67646 .64608 L p .707 .577 .707 r
F P
0 g
s
.31256 .73621 m .31019 .77292 L .33421 .7682 L p .707 .577 .707 r
F P
0 g
s
.33421 .7682 m .33658 .73148 L .31256 .73621 L p .707 .577 .707 r
F P
0 g
s
.19295 .72678 m .19057 .7635 L .21797 .7699 L p .707 .577 .707 r
F P
0 g
s
.24734 .79908 m .2393 .78167 L .21127 .7938 L p .707 .577 .707 r
F P
0 g
s
.2393 .78167 m .24734 .79908 L .27634 .78565 L p .707 .577 .707 r
F P
0 g
s
.27634 .78565 m .26831 .76825 L .2393 .78167 L p .707 .577 .707 r
F P
0 g
s
.26831 .76825 m .27634 .78565 L .30348 .77224 L p .707 .577 .707 r
F P
0 g
s
.30348 .77224 m .29545 .75483 L .26831 .76825 L p .707 .577 .707 r
F P
0 g
s
.21127 .7938 m .2193 .8112 L .24734 .79908 L p .707 .577 .707 r
F P
0 g
s
.67272 .76487 m .68075 .78228 L .66253 .78847 L p .707 .577 .707 r
F P
0 g
s
.66253 .78847 m .65449 .77107 L .67272 .76487 L p .707 .577 .707 r
F P
0 g
s
.68763 .73531 m .68526 .77203 L .66426 .76376 L p .707 .577 .707 r
F P
0 g
s
.66426 .76376 m .66664 .72704 L .68763 .73531 L p .707 .577 .707 r
F P
0 g
s
.18094 .7007 m .18159 .64519 L .169 .63704 L p .707 .577 .707 r
F P
0 g
s
.19057 .7635 m .19295 .72678 L .17195 .71851 L p .707 .577 .707 r
F P
0 g
s
.2193 .8112 m .21127 .7938 L .18694 .80343 L p .707 .577 .707 r
F P
0 g
s
.29545 .75483 m .30348 .77224 L .32609 .76014 L p .707 .577 .707 r
F P
0 g
s
.32609 .76014 m .31806 .74273 L .29545 .75483 L p .707 .577 .707 r
F P
0 g
s
.18694 .80343 m .19498 .82084 L .2193 .8112 L p .707 .577 .707 r
F P
0 g
s
.51554 .85876 m .5075 .84135 L .52338 .83176 L p .707 .577 .707 r
F P
0 g
s
.17195 .71851 m .16958 .75523 L .19057 .7635 L p .707 .577 .707 r
F P
0 g
s
.52338 .83176 m .53141 .84917 L .51554 .85876 L p .707 .577 .707 r
F P
0 g
s
.65449 .77107 m .66253 .78847 L .6382 .79811 L p .707 .577 .707 r
F P
0 g
s
.63125 .29308 m .6395 .79578 L .6495 .78409 L p .707 .577 .707 r
F P
0 g
s
.6495 .78409 m .64125 .28139 L .63125 .29308 L p .707 .577 .707 r
F P
0 g
s
.169 .63704 m .16835 .69255 L .18094 .7007 L p .707 .577 .707 r
F P
0 g
s
.36291 .64266 m .36226 .69817 L .36934 .68975 L p .707 .577 .707 r
F P
0 g
s
.36934 .68975 m .36999 .63424 L .36291 .64266 L p .707 .577 .707 r
F P
0 g
s
.33658 .73148 m .33421 .7682 L .35057 .76115 L p .707 .577 .707 r
F P
0 g
s
.35057 .76115 m .35294 .72443 L .33658 .73148 L p .707 .577 .707 r
F P
0 g
s
.16958 .75523 m .17195 .71851 L .1594 .70918 L p .707 .577 .707 r
F P
0 g
s
.19498 .82084 m .18694 .80343 L .16872 .80962 L p .707 .577 .707 r
F P
0 g
s
.16872 .80962 m .17675 .82703 L .19498 .82084 L p .707 .577 .707 r
F P
0 g
s
.31806 .74273 m .32609 .76014 L .34197 .75055 L p .707 .577 .707 r
F P
0 g
s
.34197 .75055 m .33393 .73314 L .31806 .74273 L p .707 .577 .707 r
F P
0 g
s
.16835 .69255 m .169 .63704 L .16611 .62833 L p .707 .577 .707 r
F P
0 g
s
.3671 .62553 m .36644 .68104 L .35385 .67289 L p .707 .577 .707 r
F P
0 g
s
.35385 .67289 m .35451 .61738 L .3671 .62553 L p .707 .577 .707 r
F P
0 g
s
.36577 .79519 m .35752 .29249 L .35343 .28077 L p .707 .577 .707 r
F P
0 g
s
.36999 .63424 m .36934 .68975 L .36644 .68104 L p .707 .577 .707 r
F P
0 g
s
.36644 .68104 m .3671 .62553 L .36999 .63424 L p .707 .577 .707 r
F P
0 g
s
.35752 .29249 m .36577 .79519 L .38354 .8058 L p .707 .577 .707 r
F P
0 g
s
.1594 .70918 m .15703 .7459 L .16958 .75523 L p .707 .577 .707 r
F P
0 g
s
.53141 .84917 m .52338 .83176 L .54599 .81967 L p .707 .577 .707 r
F P
0 g
s
.54599 .81967 m .55402 .83707 L .53141 .84917 L p .707 .577 .707 r
F P
0 g
s
.35294 .72443 m .35057 .76115 L .35766 .75247 L p .707 .577 .707 r
F P
0 g
s
.35766 .75247 m .36004 .71575 L .35294 .72443 L p .707 .577 .707 r
F P
0 g
s
.16611 .62833 m .16545 .68383 L .16835 .69255 L p .707 .577 .707 r
F P
0 g
s
.17675 .82703 m .16872 .80962 L .15837 .81178 L p .707 .577 .707 r
F P
0 g
s
.15703 .7459 m .1594 .70918 L .15654 .69971 L p .707 .577 .707 r
F P
0 g
s
.15837 .81178 m .1664 .82919 L .17675 .82703 L p .707 .577 .707 r
F P
0 g
s
.33393 .73314 m .34197 .75055 L .34955 .74441 L p .707 .577 .707 r
F P
0 g
s
.34955 .74441 m .34151 .727 L .33393 .73314 L p .707 .577 .707 r
F P
0 g
s
.64125 .28139 m .6495 .78409 L .64541 .77237 L p .707 .577 .707 r
F P
0 g
s
.64541 .77237 m .63716 .26967 L .64125 .28139 L p .707 .577 .707 r
F P
0 g
s
.16545 .68383 m .16611 .62833 L .17319 .6199 L p .707 .577 .707 r
F P
0 g
s
.15654 .69971 m .15416 .73643 L .15703 .7459 L p .707 .577 .707 r
F P
0 g
s
.36004 .71575 m .35766 .75247 L .3548 .743 L p .707 .577 .707 r
F P
0 g
s
.3548 .743 m .35717 .70628 L .36004 .71575 L p .707 .577 .707 r
F P
0 g
s
.17319 .6199 m .17254 .67541 L .16545 .68383 L p .707 .577 .707 r
F P
0 g
s
.35343 .28077 m .36168 .78347 L .36577 .79519 L p .707 .577 .707 r
F P
0 g
s
.36168 .78347 m .35343 .28077 L .36343 .26908 L p .707 .577 .707 r
F P
0 g
s
.1664 .82919 m .15837 .81178 L .15691 .80968 L p .708 .578 .707 r
F P
0 g
s
.15416 .73643 m .15654 .69971 L .16363 .69103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15691 .80968 m .16495 .82709 L .1664 .82919 L p .708 .578 .707 r
F P
0 g
s
.34151 .727 m .34955 .74441 L .34809 .74231 L p .708 .578 .707 r
F P
0 g
s
.34809 .74231 m .34005 .7249 L .34151 .727 L p .708 .578 .707 r
F P
0 g
s
.17254 .67541 m .17319 .6199 L .18956 .61259 L p .707 .577 .707 r
F P
0 g
s
.16363 .69103 m .16126 .72775 L .15416 .73643 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63716 .26967 m .64541 .77237 L .62764 .76176 L p .707 .577 .707 r
F P
0 g
s
.62764 .76176 m .61939 .25906 L .63716 .26967 L p .707 .577 .707 r
F P
0 g
s
.34005 .7249 m .34809 .74231 L .33774 .74447 L p .707 .577 .707 r
F P
0 g
s
.35717 .70628 m .3548 .743 L .34225 .73367 L p .707 .577 .707 r
F P
0 g
s
.34225 .73367 m .34462 .69696 L .35717 .70628 L p .707 .577 .707 r
F P
0 g
s
.18956 .61259 m .18891 .6681 L .17254 .67541 L p .707 .577 .707 r
F P
0 g
s
.35451 .61738 m .35385 .67289 L .3328 .6661 L p .707 .577 .707 r
F P
0 g
s
.3328 .6661 m .33345 .61059 L .35451 .61738 L p .707 .577 .707 r
F P
0 g
s
.16126 .72775 m .16363 .69103 L .17999 .68398 L p .707 .577 .707 r
F P
0 g
s
.16495 .82709 m .15691 .80968 L .16449 .80354 L p .707 .577 .707 r
F P
0 g
s
.16449 .80354 m .17253 .82095 L .16495 .82709 L p .707 .577 .707 r
F P
0 g
s
.18891 .6681 m .18956 .61259 L .21361 .60711 L p .707 .577 .707 r
F P
0 g
s
.33774 .74447 m .32971 .72706 L .34005 .7249 L p .707 .577 .707 r
F P
0 g
s
.37168 .77178 m .36343 .26908 L .38654 .25856 L p .707 .577 .707 r
F P
0 g
s
.36343 .26908 m .37168 .77178 L .36168 .78347 L p .707 .577 .707 r
F P
0 g
s
.17999 .68398 m .17762 .7207 L .16126 .72775 L p .707 .577 .707 r
F P
0 g
s
.33345 .61059 m .3328 .6661 L .30534 .66134 L p .707 .577 .707 r
F P
0 g
s
.30534 .66134 m .306 .60583 L .33345 .61059 L p .707 .577 .707 r
F P
0 g
s
.21361 .60711 m .21296 .66262 L .18891 .6681 L p .707 .577 .707 r
F P
0 g
s
.32971 .72706 m .33774 .74447 L .31952 .75066 L p .707 .577 .707 r
F P
0 g
s
.31952 .75066 m .31148 .73326 L .32971 .72706 L p .707 .577 .707 r
F P
0 g
s
.34462 .69696 m .34225 .73367 L .32125 .7254 L p .707 .577 .707 r
F P
0 g
s
.32125 .7254 m .32363 .68868 L .34462 .69696 L p .707 .577 .707 r
F P
0 g
s
.21296 .66262 m .21361 .60711 L .24299 .604 L p .707 .577 .707 r
F P
0 g
s
.17762 .7207 m .17999 .68398 L .20401 .67926 L p .707 .577 .707 r
F P
0 g
s
.61939 .25906 m .62764 .76176 L .59792 .75331 L p .707 .577 .707 r
F P
0 g
s
.59792 .75331 m .58967 .25061 L .61939 .25906 L p .707 .577 .707 r
F P
0 g
s
.17253 .82095 m .16449 .80354 L .18037 .79395 L p .707 .577 .707 r
F P
0 g
s
.306 .60583 m .30534 .66134 L .27417 .65907 L p .707 .577 .707 r
F P
0 g
s
.27417 .65907 m .27483 .60356 L .306 .60583 L p .707 .577 .707 r
F P
0 g
s
.18037 .79395 m .1884 .81136 L .17253 .82095 L p .707 .577 .707 r
F P
0 g
s
.24234 .65951 m .24299 .604 L .27483 .60356 L p .707 .577 .707 r
F P
0 g
s
.24299 .604 m .24234 .65951 L .21296 .66262 L p .707 .577 .707 r
F P
0 g
s
.20401 .67926 m .20164 .71598 L .17762 .7207 L p .707 .577 .707 r
F P
0 g
s
.27483 .60356 m .27417 .65907 L .24234 .65951 L p .707 .577 .707 r
F P
0 g
s
.74083 .65797 m .74149 .60246 L .71032 .60019 L p .707 .577 .707 r
F P
0 g
s
.74149 .60246 m .74083 .65797 L .77267 .65753 L p .707 .577 .707 r
F P
0 g
s
.77267 .65753 m .77332 .60202 L .74149 .60246 L p .707 .577 .707 r
F P
0 g
s
.32363 .68868 m .32125 .7254 L .29386 .71899 L p .707 .577 .707 r
F P
0 g
s
.29386 .71899 m .29623 .68228 L .32363 .68868 L p .707 .577 .707 r
F P
0 g
s
.77332 .60202 m .77267 .65753 L .80205 .65441 L p .707 .577 .707 r
F P
0 g
s
.80205 .65441 m .8027 .5989 L .77332 .60202 L p .707 .577 .707 r
F P
0 g
s
.38654 .25856 m .39479 .76126 L .37168 .77178 L p .707 .577 .707 r
F P
0 g
s
.39479 .76126 m .38654 .25856 L .42049 .25025 L p .707 .577 .707 r
F P
0 g
s
.70966 .6557 m .71032 .60019 L .68286 .59543 L p .707 .577 .707 r
F P
0 g
s
.71032 .60019 m .70966 .6557 L .74083 .65797 L p .707 .577 .707 r
F P
0 g
s
.20164 .71598 m .20401 .67926 L .23335 .67732 L p .707 .577 .707 r
F P
0 g
s
.8027 .5989 m .80205 .65441 L .8261 .64893 L p .707 .577 .707 r
F P
0 g
s
.8261 .64893 m .82675 .59342 L .8027 .5989 L p .707 .577 .707 r
F P
0 g
s
.29623 .68228 m .29386 .71899 L .26275 .71508 L p .707 .577 .707 r
F P
0 g
s
.26275 .71508 m .26513 .67836 L .29623 .68228 L p .707 .577 .707 r
F P
0 g
s
.1884 .81136 m .18037 .79395 L .20298 .78186 L p .707 .577 .707 r
F P
0 g
s
.23335 .67732 m .23098 .71404 L .20164 .71598 L p .707 .577 .707 r
F P
0 g
s
.20298 .78186 m .21101 .79926 L .1884 .81136 L p .707 .577 .707 r
F P
0 g
s
.31148 .73326 m .31952 .75066 L .29519 .76029 L p .707 .577 .707 r
F P
0 g
s
.29519 .76029 m .28716 .74289 L .31148 .73326 L p .707 .577 .707 r
F P
0 g
s
.23098 .71404 m .23335 .67732 L .26513 .67836 L p .707 .577 .707 r
F P
0 g
s
.58967 .25061 m .59792 .75331 L .55916 .74785 L p .707 .577 .707 r
F P
0 g
s
.55916 .74785 m .55091 .24514 L .58967 .25061 L p .707 .577 .707 r
F P
0 g
s
.68221 .65093 m .68286 .59543 L .66181 .58864 L p .707 .577 .707 r
F P
0 g
s
.68286 .59543 m .68221 .65093 L .70966 .6557 L p .707 .577 .707 r
F P
0 g
s
.26513 .67836 m .26275 .71508 L .23098 .71404 L p .707 .577 .707 r
F P
0 g
s
.72929 .72014 m .73166 .68342 L .70055 .6795 L p .707 .577 .707 r
F P
0 g
s
.73166 .68342 m .72929 .72014 L .76107 .72118 L p .707 .577 .707 r
F P
0 g
s
.76107 .72118 m .76344 .68446 L .73166 .68342 L p .707 .577 .707 r
F P
0 g
s
.76344 .68446 m .76107 .72118 L .7904 .71924 L p .707 .577 .707 r
F P
0 g
s
.7904 .71924 m .79277 .68252 L .76344 .68446 L p .707 .577 .707 r
F P
0 g
s
.42875 .75295 m .42049 .25025 L .46197 .24495 L p .707 .577 .707 r
F P
0 g
s
.42049 .25025 m .42875 .75295 L .39479 .76126 L p .707 .577 .707 r
F P
0 g
s
.69818 .71622 m .70055 .6795 L .67316 .6731 L p .707 .577 .707 r
F P
0 g
s
.70055 .6795 m .69818 .71622 L .72929 .72014 L p .707 .577 .707 r
F P
0 g
s
.82675 .59342 m .8261 .64893 L .84247 .64162 L p .707 .577 .707 r
F P
0 g
s
.84247 .64162 m .84312 .58611 L .82675 .59342 L p .707 .577 .707 r
F P
0 g
s
.21101 .79926 m .20298 .78186 L .23011 .76844 L p .707 .577 .707 r
F P
0 g
s
.28716 .74289 m .29519 .76029 L .26716 .77242 L p .707 .577 .707 r
F P
0 g
s
.26716 .77242 m .25912 .75501 L .28716 .74289 L p .707 .577 .707 r
F P
0 g
s
.23011 .76844 m .23815 .78585 L .21101 .79926 L p .707 .577 .707 r
F P
0 g
s
.66181 .58864 m .66115 .64415 L .68221 .65093 L p .707 .577 .707 r
F P
0 g
s
.79277 .68252 m .7904 .71924 L .81442 .71452 L p .707 .577 .707 r
F P
0 g
s
.81442 .71452 m .8168 .6778 L .79277 .68252 L p .707 .577 .707 r
F P
0 g
s
.55091 .24514 m .55916 .74785 L .51516 .7459 L p .707 .577 .707 r
F P
0 g
s
.51516 .7459 m .50691 .24319 L .55091 .24514 L p .707 .577 .707 r
F P
0 g
s
.72755 .74485 m .71952 .72745 L .69148 .73957 L p .707 .577 .707 r
F P
0 g
s
.71952 .72745 m .72755 .74485 L .75656 .73143 L p .707 .577 .707 r
F P
0 g
s
.75656 .73143 m .74852 .71402 L .71952 .72745 L p .707 .577 .707 r
F P
0 g
s
.67316 .6731 m .67079 .70981 L .69818 .71622 L p .707 .577 .707 r
F P
0 g
s
.74852 .71402 m .75656 .73143 L .7837 .71801 L p .707 .577 .707 r
F P
0 g
s
.7837 .71801 m .77566 .7006 L .74852 .71402 L p .707 .577 .707 r
F P
0 g
s
.69148 .73957 m .69951 .75698 L .72755 .74485 L p .707 .577 .707 r
F P
0 g
s
.66115 .64415 m .66181 .58864 L .64922 .58049 L p .707 .577 .707 r
F P
0 g
s
.23815 .78585 m .23011 .76844 L .25912 .75501 L p .707 .577 .707 r
F P
0 g
s
.25912 .75501 m .26716 .77242 L .23815 .78585 L p .707 .577 .707 r
F P
0 g
s
.67079 .70981 m .67316 .6731 L .65216 .66482 L p .707 .577 .707 r
F P
0 g
s
.47022 .74765 m .46197 .24495 L .50691 .24319 L p .707 .577 .707 r
F P
0 g
s
.46197 .24495 m .47022 .74765 L .42875 .75295 L p .707 .577 .707 r
F P
0 g
s
.50691 .24319 m .51516 .7459 L .47022 .74765 L p .707 .577 .707 r
F P
0 g
s
.69951 .75698 m .69148 .73957 L .66716 .7492 L p .707 .577 .707 r
F P
0 g
s
.77566 .7006 m .7837 .71801 L .80631 .70591 L p .707 .577 .707 r
F P
0 g
s
.80631 .70591 m .79827 .6885 L .77566 .7006 L p .707 .577 .707 r
F P
0 g
s
.66716 .7492 m .67519 .76661 L .69951 .75698 L p .707 .577 .707 r
F P
0 g
s
.65216 .66482 m .64979 .70154 L .67079 .70981 L p .707 .577 .707 r
F P
0 g
s
.64922 .58049 m .64856 .636 L .66115 .64415 L p .707 .577 .707 r
F P
0 g
s
.84312 .58611 m .84247 .64162 L .84955 .6332 L p .707 .577 .707 r
F P
0 g
s
.84955 .6332 m .85021 .57769 L .84312 .58611 L p .707 .577 .707 r
F P
0 g
s
.8168 .6778 m .81442 .71452 L .83078 .70747 L p .707 .577 .707 r
F P
0 g
s
.83078 .70747 m .83316 .67075 L .8168 .6778 L p .707 .577 .707 r
F P
0 g
s
.64979 .70154 m .65216 .66482 L .63962 .6555 L p .707 .577 .707 r
F P
0 g
s
.67519 .76661 m .66716 .7492 L .64893 .7554 L p .707 .577 .707 r
F P
0 g
s
.64893 .7554 m .65697 .77281 L .67519 .76661 L p .707 .577 .707 r
F P
0 g
s
.64856 .636 m .64922 .58049 L .64632 .57178 L p .707 .577 .707 r
F P
0 g
s
.79827 .6885 m .80631 .70591 L .82218 .69632 L p .707 .577 .707 r
F P
0 g
s
.82218 .69632 m .81414 .67892 L .79827 .6885 L p .707 .577 .707 r
F P
0 g
s
.63962 .6555 m .63724 .69222 L .64979 .70154 L p .707 .577 .707 r
F P
0 g
s
.64632 .57178 m .64567 .62729 L .64856 .636 L p .707 .577 .707 r
F P
0 g
s
.83316 .67075 m .83078 .70747 L .83788 .69878 L p .707 .577 .707 r
F P
0 g
s
.83788 .69878 m .84025 .66207 L .83316 .67075 L p .707 .577 .707 r
F P
0 g
s
.85021 .57769 m .84955 .6332 L .84666 .62449 L p .707 .577 .707 r
F P
0 g
s
.84666 .62449 m .84731 .56898 L .85021 .57769 L p .707 .577 .707 r
F P
0 g
s
.65697 .77281 m .64893 .7554 L .63858 .75755 L p .707 .577 .707 r
F P
0 g
s
.63724 .69222 m .63962 .6555 L .63675 .64603 L p .707 .577 .707 r
F P
0 g
s
.63858 .75755 m .64662 .77496 L .65697 .77281 L p .707 .577 .707 r
F P
0 g
s
.81414 .67892 m .82218 .69632 L .82976 .69018 L p .707 .577 .707 r
F P
0 g
s
.82976 .69018 m .82172 .67277 L .81414 .67892 L p .707 .577 .707 r
F P
0 g
s
.64567 .62729 m .64632 .57178 L .6534 .56335 L p .707 .577 .707 r
F P
0 g
s
.63675 .64603 m .63438 .68275 L .63724 .69222 L p .707 .577 .707 r
F P
0 g
s
.84025 .66207 m .83788 .69878 L .83501 .68932 L p .707 .577 .707 r
F P
0 g
s
.83501 .68932 m .83738 .6526 L .84025 .66207 L p .707 .577 .707 r
F P
0 g
s
.6534 .56335 m .65275 .61886 L .64567 .62729 L p .707 .577 .707 r
F P
0 g
s
.84731 .56898 m .84666 .62449 L .83407 .61634 L p .707 .577 .707 r
F P
0 g
s
.83407 .61634 m .83472 .56083 L .84731 .56898 L p .707 .577 .707 r
F P
0 g
s
.64662 .77496 m .63858 .75755 L .63713 .75546 L p .708 .578 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63713 .75546 m .64516 .77286 L .64662 .77496 L p .708 .578 .707 r
F P
0 g
s
.63438 .68275 m .63675 .64603 L .64384 .63735 L p .707 .577 .707 r
F P
0 g
s
.82172 .67277 m .82976 .69018 L .8283 .68808 L p .708 .578 .707 r
F P
0 g
s
.8283 .68808 m .82027 .67068 L .82172 .67277 L p .708 .578 .707 r
F P
0 g
s
.39782 .62248 m .39848 .56697 L .36731 .5647 L p .707 .577 .707 r
F P
0 g
s
.39848 .56697 m .39782 .62248 L .42966 .62204 L p .707 .577 .707 r
F P
0 g
s
.42966 .62204 m .43031 .56653 L .39848 .56697 L p .707 .577 .707 r
F P
0 g
s
.65275 .61886 m .6534 .56335 L .66977 .55604 L p .707 .577 .707 r
F P
0 g
s
.43031 .56653 m .42966 .62204 L .45904 .61892 L p .707 .577 .707 r
F P
0 g
s
.45904 .61892 m .45969 .56341 L .43031 .56653 L p .707 .577 .707 r
F P
0 g
s
.36665 .62021 m .36731 .5647 L .33985 .55994 L p .707 .577 .707 r
F P
0 g
s
.36731 .5647 m .36665 .62021 L .39782 .62248 L p .707 .577 .707 r
F P
0 g
s
.64384 .63735 m .64147 .67406 L .63438 .68275 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45969 .56341 m .45904 .61892 L .48309 .61344 L p .707 .577 .707 r
F P
0 g
s
.48309 .61344 m .48374 .55793 L .45969 .56341 L p .707 .577 .707 r
F P
0 g
s
.82027 .67068 m .8283 .68808 L .81796 .69024 L p .707 .577 .707 r
F P
0 g
s
.83738 .6526 m .83501 .68932 L .82246 .67999 L p .707 .577 .707 r
F P
0 g
s
.82246 .67999 m .82484 .64327 L .83738 .6526 L p .707 .577 .707 r
F P
0 g
s
.66977 .55604 m .66912 .61155 L .65275 .61886 L p .707 .577 .707 r
F P
0 g
s
.83472 .56083 m .83407 .61634 L .81301 .60955 L p .707 .577 .707 r
F P
0 g
s
.81301 .60955 m .81367 .55404 L .83472 .56083 L p .707 .577 .707 r
F P
0 g
s
.3392 .61544 m .33985 .55994 L .3188 .55315 L p .707 .577 .707 r
F P
0 g
s
.33985 .55994 m .3392 .61544 L .36665 .62021 L p .707 .577 .707 r
F P
0 g
s
.38628 .68178 m .38865 .64506 L .35754 .64115 L p .707 .577 .707 r
F P
0 g
s
.38865 .64506 m .38628 .68178 L .41806 .68282 L p .707 .577 .707 r
F P
0 g
s
.41806 .68282 m .42043 .6461 L .38865 .64506 L p .707 .577 .707 r
F P
0 g
s
.64147 .67406 m .64384 .63735 L .6602 .6303 L p .707 .577 .707 r
F P
0 g
s
.64516 .77286 m .63713 .75546 L .64471 .74931 L p .707 .577 .707 r
F P
0 g
s
.66912 .61155 m .66977 .55604 L .69382 .55057 L p .707 .577 .707 r
F P
0 g
s
.64471 .74931 m .65274 .76672 L .64516 .77286 L p .707 .577 .707 r
F P
0 g
s
.42043 .6461 m .41806 .68282 L .44739 .68089 L p .707 .577 .707 r
F P
0 g
s
.44739 .68089 m .44977 .64417 L .42043 .6461 L p .707 .577 .707 r
F P
0 g
s
.81796 .69024 m .80992 .67283 L .82027 .67068 L p .707 .577 .707 r
F P
0 g
s
.35517 .67787 m .35754 .64115 L .33015 .63474 L p .707 .577 .707 r
F P
0 g
s
.35754 .64115 m .35517 .67787 L .38628 .68178 L p .707 .577 .707 r
F P
0 g
s
.48374 .55793 m .48309 .61344 L .49946 .60613 L p .707 .577 .707 r
F P
0 g
s
.49946 .60613 m .50011 .55062 L .48374 .55793 L p .707 .577 .707 r
F P
0 g
s
.6602 .6303 m .65783 .66702 L .64147 .67406 L p .707 .577 .707 r
F P
0 g
s
.3188 .55315 m .31814 .60866 L .3392 .61544 L p .707 .577 .707 r
F P
0 g
s
.81367 .55404 m .81301 .60955 L .78556 .60479 L p .707 .577 .707 r
F P
0 g
s
.78556 .60479 m .78621 .54928 L .81367 .55404 L p .707 .577 .707 r
F P
0 g
s
.44977 .64417 m .44739 .68089 L .47141 .67616 L p .707 .577 .707 r
F P
0 g
s
.47141 .67616 m .47379 .63944 L .44977 .64417 L p .707 .577 .707 r
F P
0 g
s
.33015 .63474 m .32778 .67146 L .35517 .67787 L p .707 .577 .707 r
F P
0 g
s
.38454 .70704 m .37651 .68964 L .34847 .70176 L p .707 .577 .707 r
F P
0 g
s
.37651 .68964 m .38454 .70704 L .41355 .69362 L p .707 .577 .707 r
F P
0 g
s
.41355 .69362 m .40551 .67621 L .37651 .68964 L p .707 .577 .707 r
F P
0 g
s
.40551 .67621 m .41355 .69362 L .44069 .6802 L p .707 .577 .707 r
F P
0 g
s
.44069 .6802 m .43265 .66279 L .40551 .67621 L p .707 .577 .707 r
F P
0 g
s
.69382 .55057 m .69317 .60607 L .66912 .61155 L p .707 .577 .707 r
F P
0 g
s
.34847 .70176 m .3565 .71917 L .38454 .70704 L p .707 .577 .707 r
F P
0 g
s
.80992 .67283 m .81796 .69024 L .79973 .69644 L p .707 .577 .707 r
F P
0 g
s
.79973 .69644 m .79169 .67903 L .80992 .67283 L p .707 .577 .707 r
F P
0 g
s
.82484 .64327 m .82246 .67999 L .80147 .67172 L p .707 .577 .707 r
F P
0 g
s
.80147 .67172 m .80384 .635 L .82484 .64327 L p .707 .577 .707 r
F P
0 g
s
.31814 .60866 m .3188 .55315 L .30621 .545 L p .707 .577 .707 r
F P
0 g
s
.32778 .67146 m .33015 .63474 L .30915 .62647 L p .707 .577 .707 r
F P
0 g
s
.69317 .60607 m .69382 .55057 L .72321 .54745 L p .707 .577 .707 r
F P
0 g
s
.3565 .71917 m .34847 .70176 L .32415 .71139 L p .707 .577 .707 r
F P
0 g
s
.65783 .66702 m .6602 .6303 L .68423 .62557 L p .707 .577 .707 r
F P
0 g
s
.43265 .66279 m .44069 .6802 L .4633 .6681 L p .707 .577 .707 r
F P
0 g
s
.4633 .6681 m .45526 .65069 L .43265 .66279 L p .707 .577 .707 r
F P
0 g
s
.32415 .71139 m .33218 .7288 L .3565 .71917 L p .707 .577 .707 r
F P
0 g
s
.78621 .54928 m .78556 .60479 L .75439 .60252 L p .707 .577 .707 r
F P
0 g
s
.75439 .60252 m .75504 .54701 L .78621 .54928 L p .707 .577 .707 r
F P
0 g
s
.65274 .76672 m .64471 .74931 L .66058 .73972 L p .707 .577 .707 r
F P
0 g
s
.30915 .62647 m .30678 .66319 L .32778 .67146 L p .707 .577 .707 r
F P
0 g
s
.66058 .73972 m .66862 .75713 L .65274 .76672 L p .707 .577 .707 r
F P
0 g
s
.72255 .60296 m .72321 .54745 L .75504 .54701 L p .707 .577 .707 r
F P
0 g
s
.72321 .54745 m .72255 .60296 L .69317 .60607 L p .707 .577 .707 r
F P
0 g
s
.30621 .545 m .30555 .60051 L .31814 .60866 L p .707 .577 .707 r
F P
0 g
s
.50011 .55062 m .49946 .60613 L .50654 .59771 L p .707 .577 .707 r
F P
0 g
s
.50654 .59771 m .5072 .5422 L .50011 .55062 L p .707 .577 .707 r
F P
0 g
s
.47379 .63944 m .47141 .67616 L .48777 .66911 L p .707 .577 .707 r
F P
0 g
s
.48777 .66911 m .49015 .63239 L .47379 .63944 L p .707 .577 .707 r
F P
0 g
s
.75504 .54701 m .75439 .60252 L .72255 .60296 L p .707 .577 .707 r
F P
0 g
s
.68423 .62557 m .68185 .66229 L .65783 .66702 L p .707 .577 .707 r
F P
0 g
s
.80384 .635 m .80147 .67172 L .77407 .66531 L p .707 .577 .707 r
F P
0 g
s
.77407 .66531 m .77645 .62859 L .80384 .635 L p .707 .577 .707 r
F P
0 g
s
.30678 .66319 m .30915 .62647 L .29661 .61714 L p .707 .577 .707 r
F P
0 g
s
.33218 .7288 m .32415 .71139 L .30592 .71759 L p .707 .577 .707 r
F P
0 g
s
.30592 .71759 m .31396 .73499 L .33218 .7288 L p .707 .577 .707 r
F P
0 g
s
.45526 .65069 m .4633 .6681 L .47917 .65851 L p .707 .577 .707 r
F P
0 g
s
.47917 .65851 m .47113 .6411 L .45526 .65069 L p .707 .577 .707 r
F P
0 g
s
.68185 .66229 m .68423 .62557 L .71356 .62364 L p .707 .577 .707 r
F P
0 g
s
.30555 .60051 m .30621 .545 L .30331 .53629 L p .707 .577 .707 r
F P
0 g
s
.29661 .61714 m .29423 .65386 L .30678 .66319 L p .707 .577 .707 r
F P
0 g
s
.77645 .62859 m .77407 .66531 L .74297 .6614 L p .707 .577 .707 r
F P
0 g
s
.74297 .6614 m .74534 .62468 L .77645 .62859 L p .707 .577 .707 r
F P
0 g
s
.66862 .75713 m .66058 .73972 L .68319 .72763 L p .707 .577 .707 r
F P
0 g
s
.71356 .62364 m .71119 .66036 L .68185 .66229 L p .707 .577 .707 r
F P
0 g
s
.68319 .72763 m .69123 .74504 L .66862 .75713 L p .707 .577 .707 r
F P
0 g
s
.79169 .67903 m .79973 .69644 L .77541 .70607 L p .707 .577 .707 r
F P
0 g
s
.77541 .70607 m .76737 .68866 L .79169 .67903 L p .707 .577 .707 r
F P
0 g
s
.71119 .66036 m .71356 .62364 L .74534 .62468 L p .707 .577 .707 r
F P
0 g
s
.49015 .63239 m .48777 .66911 L .49487 .66043 L p .707 .577 .707 r
F P
0 g
s
.49487 .66043 m .49724 .62371 L .49015 .63239 L p .707 .577 .707 r
F P
0 g
s
.74534 .62468 m .74297 .6614 L .71119 .66036 L p .707 .577 .707 r
F P
0 g
s
.30331 .53629 m .30266 .59179 L .30555 .60051 L p .707 .577 .707 r
F P
0 g
s
.5072 .5422 m .50654 .59771 L .50365 .589 L p .707 .577 .707 r
F P
0 g
s
.50365 .589 m .5043 .53349 L .5072 .5422 L p .707 .577 .707 r
F P
0 g
s
.31396 .73499 m .30592 .71759 L .29557 .71974 L p .707 .577 .707 r
F P
0 g
s
.29423 .65386 m .29661 .61714 L .29374 .60767 L p .707 .577 .707 r
F P
0 g
s
.29557 .71974 m .30361 .73715 L .31396 .73499 L p .707 .577 .707 r
F P
0 g
s
.47113 .6411 m .47917 .65851 L .48675 .65237 L p .707 .577 .707 r
F P
0 g
s
.48675 .65237 m .47871 .63496 L .47113 .6411 L p .707 .577 .707 r
F P
0 g
s
.69123 .74504 m .68319 .72763 L .71033 .71421 L p .707 .577 .707 r
F P
0 g
s
.76737 .68866 m .77541 .70607 L .74737 .71819 L p .707 .577 .707 r
F P
0 g
s
.74737 .71819 m .73934 .70078 L .76737 .68866 L p .707 .577 .707 r
F P
0 g
s
.71033 .71421 m .71836 .73162 L .69123 .74504 L p .707 .577 .707 r
F P
0 g
s
.30266 .59179 m .30331 .53629 L .31039 .52786 L p .707 .577 .707 r
F P
0 g
s
.29374 .60767 m .29137 .64439 L .29423 .65386 L p .707 .577 .707 r
F P
0 g
s
.71836 .73162 m .71033 .71421 L .73934 .70078 L p .707 .577 .707 r
F P
0 g
s
.73934 .70078 m .74737 .71819 L .71836 .73162 L p .707 .577 .707 r
F P
0 g
s
.49724 .62371 m .49487 .66043 L .492 .65096 L p .707 .577 .707 r
F P
0 g
s
.492 .65096 m .49437 .61424 L .49724 .62371 L p .707 .577 .707 r
F P
0 g
s
.31039 .52786 m .30974 .58337 L .30266 .59179 L p .707 .577 .707 r
F P
0 g
s
.5043 .53349 m .50365 .589 L .49106 .58085 L p .707 .577 .707 r
F P
0 g
s
.49106 .58085 m .49171 .52534 L .5043 .53349 L p .707 .577 .707 r
F P
0 g
s
.30361 .73715 m .29557 .71974 L .29412 .71764 L p .708 .578 .707 r
F P
0 g
s
.29137 .64439 m .29374 .60767 L .30083 .59899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29412 .71764 m .30215 .73505 L .30361 .73715 L p .708 .578 .707 r
F P
0 g
s
.47871 .63496 m .48675 .65237 L .48529 .65027 L p .708 .578 .707 r
F P
0 g
s
.48529 .65027 m .47726 .63286 L .47871 .63496 L p .708 .578 .707 r
F P
0 g
s
.30974 .58337 m .31039 .52786 L .32676 .52055 L p .707 .577 .707 r
F P
0 g
s
.30083 .59899 m .29846 .63571 L .29137 .64439 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47726 .63286 m .48529 .65027 L .47495 .65243 L p .707 .577 .707 r
F P
0 g
s
.49437 .61424 m .492 .65096 L .47945 .64163 L p .707 .577 .707 r
F P
0 g
s
.47945 .64163 m .48183 .60492 L .49437 .61424 L p .707 .577 .707 r
F P
0 g
s
.32676 .52055 m .32611 .57606 L .30974 .58337 L p .707 .577 .707 r
F P
0 g
s
.49171 .52534 m .49106 .58085 L .47 .57406 L p .707 .577 .707 r
F P
0 g
s
.47 .57406 m .47066 .51855 L .49171 .52534 L p .707 .577 .707 r
F P
0 g
s
.29846 .63571 m .30083 .59899 L .31719 .59194 L p .707 .577 .707 r
F P
0 g
s
.30215 .73505 m .29412 .71764 L .3017 .7115 L p .707 .577 .707 r
F P
0 g
s
.3017 .7115 m .30973 .72891 L .30215 .73505 L p .707 .577 .707 r
F P
0 g
s
.32611 .57606 m .32676 .52055 L .35081 .51507 L p .707 .577 .707 r
F P
0 g
s
.47495 .65243 m .46691 .63502 L .47726 .63286 L p .707 .577 .707 r
F P
0 g
s
.31719 .59194 m .31482 .62866 L .29846 .63571 L p .707 .577 .707 r
F P
0 g
s
.47066 .51855 m .47 .57406 L .44255 .5693 L p .707 .577 .707 r
F P
0 g
s
.44255 .5693 m .4432 .51379 L .47066 .51855 L p .707 .577 .707 r
F P
0 g
s
.35081 .51507 m .35016 .57058 L .32611 .57606 L p .707 .577 .707 r
F P
0 g
s
.46691 .63502 m .47495 .65243 L .45672 .65862 L p .707 .577 .707 r
F P
0 g
s
.45672 .65862 m .44868 .64122 L .46691 .63502 L p .707 .577 .707 r
F P
0 g
s
.48183 .60492 m .47945 .64163 L .45846 .63336 L p .707 .577 .707 r
F P
0 g
s
.45846 .63336 m .46083 .59664 L .48183 .60492 L p .707 .577 .707 r
F P
0 g
s
.35016 .57058 m .35081 .51507 L .3802 .51196 L p .707 .577 .707 r
F P
0 g
s
.31482 .62866 m .31719 .59194 L .34122 .58722 L p .707 .577 .707 r
F P
0 g
s
.30973 .72891 m .3017 .7115 L .31757 .70191 L p .707 .577 .707 r
F P
0 g
s
.4432 .51379 m .44255 .5693 L .41138 .56703 L p .707 .577 .707 r
F P
0 g
s
.41138 .56703 m .41203 .51152 L .4432 .51379 L p .707 .577 .707 r
F P
0 g
s
.31757 .70191 m .3256 .71932 L .30973 .72891 L p .707 .577 .707 r
F P
0 g
s
.37954 .56747 m .3802 .51196 L .41203 .51152 L p .707 .577 .707 r
F P
0 g
s
.3802 .51196 m .37954 .56747 L .35016 .57058 L p .707 .577 .707 r
F P
0 g
s
.34122 .58722 m .33884 .62394 L .31482 .62866 L p .707 .577 .707 r
F P
0 g
s
.41203 .51152 m .41138 .56703 L .37954 .56747 L p .707 .577 .707 r
F P
0 g
s
.46083 .59664 m .45846 .63336 L .43106 .62696 L p .707 .577 .707 r
F P
0 g
s
.43106 .62696 m .43344 .59024 L .46083 .59664 L p .707 .577 .707 r
F P
0 g
s
.33884 .62394 m .34122 .58722 L .37055 .58528 L p .707 .577 .707 r
F P
0 g
s
.43344 .59024 m .43106 .62696 L .39996 .62304 L p .707 .577 .707 r
F P
0 g
s
.39996 .62304 m .40233 .58632 L .43344 .59024 L p .707 .577 .707 r
F P
0 g
s
.3256 .71932 m .31757 .70191 L .34018 .68982 L p .707 .577 .707 r
F P
0 g
s
.37055 .58528 m .36818 .622 L .33884 .62394 L p .707 .577 .707 r
F P
0 g
s
.34018 .68982 m .34822 .70723 L .3256 .71932 L p .707 .577 .707 r
F P
0 g
s
.44868 .64122 m .45672 .65862 L .4324 .66826 L p .707 .577 .707 r
F P
0 g
s
.4324 .66826 m .42436 .65085 L .44868 .64122 L p .707 .577 .707 r
F P
0 g
s
.36818 .622 m .37055 .58528 L .40233 .58632 L p .707 .577 .707 r
F P
0 g
s
.40233 .58632 m .39996 .62304 L .36818 .622 L p .707 .577 .707 r
F P
0 g
s
.34822 .70723 m .34018 .68982 L .36732 .6764 L p .707 .577 .707 r
F P
0 g
s
.42436 .65085 m .4324 .66826 L .40436 .68038 L p .707 .577 .707 r
F P
0 g
s
.40436 .68038 m .39632 .66297 L .42436 .65085 L p .707 .577 .707 r
F P
0 g
s
.36732 .6764 m .37535 .69381 L .34822 .70723 L p .707 .577 .707 r
F P
0 g
s
.37535 .69381 m .36732 .6764 L .39632 .66297 L p .707 .577 .707 r
F P
0 g
s
.39632 .66297 m .40436 .68038 L .37535 .69381 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00
FUIJEP0A000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol0069oo`H000AJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool005ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005ao
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00FWoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000BOolA
0012Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH8000jOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008Ool400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00<Goo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;goo001FOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;Goo001FOol00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0`00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002aoo`00EWoo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001J
EUYF009JEP@0009JEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ao
o`00EWoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
1@0015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`04001JEP00FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH300000eYF001JEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001J
EP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00<0
05YFFUH00eYF00<005YFFUH00eYF4@000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000AJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00@005YFFUIJEPP000=J
EP03001JEUYF00IJEP03001JEUYF009JEPH000EJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001JEUYF00D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00EJEP09001JEUYFFUH005YF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00:goo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH01000FUIJEUYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo0011OolA0002Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo000kOol60004FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00UYF0`000eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP04001JEUYFFUH80008FUH00`00
FUIJEP06FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool003Moo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEPD0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF008002]o
o`00=Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00004FUH005YFFUH2000[Ool003=oo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000015YF000000001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF0000009JEP8002]oo`00<Goo0P000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH00UYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
05YF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF1000:goo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEQL000=JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<002]oo`00;goo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH500000eYF001J
EP04FUH20002FUH00`00FUIJEP04FUH30004FUH60006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
15YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<0
05YF00000`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00:goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000AJEP000000009JEP03001JEUYF
00=JEP80009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001J
EUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030000
0eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF0`00
1EYF0P000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF100015YF00H005YFFUH005YF0004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP02
FUH00`00FUH0000[Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEP0000<00003FUH00000009J
EP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP800006FUH00000001JEP000UYF00<005YF0000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000800003FUH005YF00=JEP8002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF
1`001EYF0`001eYF00<005YFFUH00UYF0`0015YF00@005YF0000009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP80
02eoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF500000=JEP00
FUH01EYF00D005YFFUH005YF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP00009JEP05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4000_Ool002moo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=J
EP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00
009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH00000;goo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH00eYF0`0000AJEP00000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000;Woo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH01eYF00<005YF00000P0000=JEP00FUH010001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05
001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000=J
EP<000EJEP03001JEUYF00AJEP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH3
0004FUH2000015YF001JEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D0
05YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool002moo`03001JEP0000=JEP04001JEUYF
FUH90008FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
0007FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP020003FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00@005YFFUIJEPT0009JEP03001oogoo
00=oo`T000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00
;goo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01EYF00<005YFFUH01UYF10002EYF00@005YF000000EJEP800003FUH005YF009JEP80
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH40002
FUH00`00FUIJEP03FUH00`00FUIJEP020006Ool30004Ool60005FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00Oomoo`0/Ool002moo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF00EJEP8000=JEP03
001JEUYF00EJEP<000EJEP8000=JEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUH005YF001JEP800004FUH000000002FUH00`00FUIJEP03FUH00`00
FUIJEP020005Ool50009Ool400000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002mo
o`03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYFFUH400000eYF001JEP04FUH20005FUH00`00FUIJEP03FUH20003FUH01@00FUIJ
EUYF00001EYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEP00FUH200000eYF001JEP03FUH30005FUH00`00FUIJEP020005Ool5000=Ool30004FUH01000
FUIJEUYF0P00;Woo000_Ool01@00FUH005YF00001EYF00<005YFFUH00eYF3`001EYF00<005YFFUH0
1EYF00<005YFFUH015YF200025YF00<005YF00000P001EYF00@005YF000000=JEPD000YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00
FUH00003000015YF001JEUYF0P001Goo1@003Woo1@0000=JEP00FUH00UYF0P00;Woo000_Ool20002
FUH01000FUIJEUYF20000eYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH01UYF00<005YF
FUH015YF00@005YFFUIJEP<000UJEP8000UJEPH0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH6
0006Ool3000<Ool30004FUH30003FUH2000^Ool002moo`03001JEUYF00D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPH000=JEP03001JEUYF00AJEP04001JEP000003FUH00`00
FUIJEP04FUH300000eYF001JEP05FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQD00003FUH005YF00AJEP04001JEUYF0002FUH2000^Ool002moo`<00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH20005FUH00`00
FUIJEP02FUH500000eYF001JEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00@005YF000000IJEP03001JEUYF00=JEP03001JEP0000@002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000=JEP00000025YF00<005YF00001P000UYF00<005YF00000P002eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEUYF009J
EP<00003FUH00000008002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF0P000eYF0`000eYF0P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
0003FUH00`00FUIJEP05FUH01000FUH000000UYF0P0000AJEP00000002ioo`00;7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YFFUH015YF0`00
15YF00H005YFFUH005YF000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP00008000QJEP03001JEP0000<0009JEP03001JEUYF008000=JEP8002moo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`001eYF00@005YF000000MJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001UYF
00000000FUH000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP8000MJEP<000AJEP8002moo`00
;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00P000eYF00<005YFFUH015YF0`001eYF0`0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF0`001UYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P0000=JEP00FUH015YF0P000UYF
00@005YFFUIJEP80031oo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH010000UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00UYF0P000eYF00@005YFFUIJEP8000AJEP04001JEP00000bOol002aoo`80
00AJEP04001JEUYFFUHI0004FUH200000eYF001JEP04FUH01000FUH000001EYF00<005YF00000P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF20002EYF00@005YF0000
00IJEP<000=JEPD003Aoo`00:goo00<005YF00000eYF1@006Goo1@000UYF00<005YFFUH00eYF0P00
1UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH00P000UYF00<005YFFUH01eYF0P001eYF1`00>Goo000[Ool01000FUH005YF0P00
00AJEP00000001=oo`<000Qoo`05001JEUYFFUH00003FUH00`00FUH00004FUH200000eYF00000002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH30004FUH0
0`00FUIJEP05FUH40005FUH20010Ool002]oo`06001JEP00001JEP0015YF0`003goo1@0027oo00D0
05YFFUH005YF008000=JEP04001JEP000002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH30004FUH20007FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P00@Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000;Ool50008Ool01@00FUIJEUYF
000015YF0`0000MJEP00FUIJEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20004FUH60008FUH00`00FUIJEP02000015YF000000000UYF0`00A7oo000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH70004Ool50009Ool015YF000000000UYF0P0000=JEP00FUH0
0P000UYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF0`000eYF
00<005YFFUH01EYF0`001UYF0P00Agoo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUHH0004FUH01@00FUH00000FUH00`000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF0P00BGoo
000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH00`00FUH000020005FUH01000FUH00000
Bgoo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
0`001UYF00<005YFFUH00eYF20000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000AJEP00FUH000MJEP8000QJEP8004eoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00MJEP03001JEP0000800003FUH005YF
00D0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQh000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP800003FUH005YF00EJEP8004moo`00;Goo0P00
00=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJEP<000AJEP03001JEUYF
00AJEP<000EJEP04001JEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF
1P002EYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF009JEP80055oo`00;goo0P001EYF00<0
05YFFUH015YF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF009JEP80009JEP04001JEUYF
FUH20002FUH200001Goo001JEUYF00001UYF00<005YFFUH015YF1P000eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00`001EYF00@005YF0000
00EJEP04001JEP00001COol0035oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP@000UJEP04
001JEP000005FUH40003FUH200001Goo001JEUYF00001UYF00<005YFFUH010002EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00AJEP<005Eoo`00<goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF
0P000eYF00<005YFFUH01EYF0`001eYF00@005YFFUH000=JEP04001oogoo0002FUH00`00FUIJEP03
FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH40002FUH200000eYF001JEP02FUH30002FUH40002FUH00`00Oomoo`1COol003Eoo`D0
00=JEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP8000=JEP04
001JEP000003Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP800004FUH005YFFUH30002FUH3
00000eYF001JEP02FUH2001EOol003Yoo`H00003FUH0000000QJEP03001JEP00008000EJEP03001J
EUYF0080009JEPD000Eoo`05001JEUYF001JEP030007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH200000eYF
0000000300000eYF001JEP02FUH2001EOol003moo`<000UJEP8000UJEPH000Yoo`03001JEUYF0080
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000@000AJEP<000=JEP8005Eoo`00?Goo
0P000eYF00<005YFFUH015YF0`0000=JEP00FUH01EYF0P0047oo00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF00H005YF000005YF0005FUH01000FUIJEP000UYF0P00EGoo000kOol20005
FUH00`00FUIJEP02FUH500000eYF001JEP03FUH2000BOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF00001000EGoo000iOol20008FUH00`00
FUH000060002FUH01000FUH0000057oo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH0009JEP03001JEUYF009JEP<00003FUH00000008005Eoo`00=goo0`002EYF0P000eYF0`000eYF
0P005Woo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YF0000009J
EP800004FUH00000001EOol003Eoo`8000=JEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP80
01Qoo`8000EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000AJEP06001JEUYF001JEP00
EGoo000cOol20005FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2000KOol00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP020003FUH2001FOol0035oo`<0
00MJEP04001JEP000007FUH01000FUH000007Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P001eYF0`0015YF0P00EWoo000_Ool20003FUH00`00FUIJEP04FUH30007FUH3000POol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0000=JEP00FUH015YF0P000UYF00@005YFFUIJEP80
05Moo`00;Woo00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P009Goo0P00
00=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YF000000=JEP04001JEUYFFUH20004FUH01000FUH00000FGoo000]Ool0
0`00FUH00005FUH01000FUH000001EYF00<005YF00000P00:Goo0`001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10001UYF0`000eYF1@00
Fgoo000/Ool01000FUIJEP001EYF0P001UYF0`00;goo10000UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01`0025YF1P00H7oo000/Ool01@00FUIJ
EUYF00000eYF00<005YF000015YF0P00=Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF1@0000=JEP00000010001UYF0P00IWoo000]Ool01@00FUIJEP00FUH00P000eYF00@0
05YF000003eoo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH600000eYF001J
EP03FUH500000eYF001JEP02FUH2001XOol002eoo`05001JEUYFFUH00004FUH30015OolO0007FUH0
0`00FUIJEP0700000eYF001JEP02001ZOol002ioo`04FUH000000002FUH2001ROol200000eYF001J
EP08FUH20003FUH30002FUH2001/Ool002ioo`H0069oo`8000AJEP03001JEUYF00AJEP800003FUH0
05YF00AJEP<006ioo`00U7oo0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH00`00LGoo002C
Ool00`00FUH00007FUH01000FUH000001UYF0P00M7oo002AOol20002FUH00`00FUIJEP05FUH20006
FUH2001fOol0091oo`03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00=JEP8007Qoo`00
SWoo0`001EYF00<005YFFUH00P0015YF00@005YF000007Yoo`00SWoo00@005YFFUH000EJEP8000EJ
EP<007aoo`00SWoo0P0000=JEP00FUH00UYF0`0015YF0P00Ogoo002?Ool00`00FUIJEP030003FUH0
1000FUH00000PGoo002?Ool00`00FUIJEP020002FUH40023Ool0091oo`H008Moo`00T7oo0P00Rgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60076 .74981 m .60117 .69427 L .57 .69215 L p .707 .577 .707 r
F P
0 g
s
.60117 .69427 m .60076 .74981 L .6326 .74924 L p .707 .577 .707 r
F P
0 g
s
.6326 .74924 m .633 .6937 L .60117 .69427 L p .707 .577 .707 r
F P
0 g
s
.633 .6937 m .6326 .74924 L .66198 .74603 L p .707 .577 .707 r
F P
0 g
s
.66198 .74603 m .66238 .69049 L .633 .6937 L p .707 .577 .707 r
F P
0 g
s
.56959 .74768 m .57 .69215 L .54254 .68752 L p .707 .577 .707 r
F P
0 g
s
.57 .69215 m .56959 .74768 L .60076 .74981 L p .707 .577 .707 r
F P
0 g
s
.66238 .69049 m .66198 .74603 L .68603 .74048 L p .707 .577 .707 r
F P
0 g
s
.68603 .74048 m .68644 .68494 L .66238 .69049 L p .707 .577 .707 r
F P
0 g
s
.54254 .68752 m .54214 .74306 L .56959 .74768 L p .707 .577 .707 r
F P
0 g
s
.54214 .74306 m .54254 .68752 L .52148 .68086 L p .707 .577 .707 r
F P
0 g
s
.59364 .8113 m .59511 .77444 L .56396 .77129 L p .707 .577 .707 r
F P
0 g
s
.59511 .77444 m .59364 .8113 L .62546 .81165 L p .707 .577 .707 r
F P
0 g
s
.62546 .81165 m .62692 .77478 L .59511 .77444 L p .707 .577 .707 r
F P
0 g
s
.62692 .77478 m .62546 .81165 L .65482 .80916 L p .707 .577 .707 r
F P
0 g
s
.65482 .80916 m .65629 .7723 L .62692 .77478 L p .707 .577 .707 r
F P
0 g
s
.5625 .80815 m .56396 .77129 L .53653 .76565 L p .707 .577 .707 r
F P
0 g
s
.56396 .77129 m .5625 .80815 L .59364 .8113 L p .707 .577 .707 r
F P
0 g
s
.68644 .68494 m .68603 .74048 L .7024 .73315 L p .707 .577 .707 r
F P
0 g
s
.7024 .73315 m .70281 .67761 L .68644 .68494 L p .707 .577 .707 r
F P
0 g
s
.52148 .68086 m .52108 .7364 L .54214 .74306 L p .707 .577 .707 r
F P
0 g
s
.65629 .7723 m .65482 .80916 L .67886 .80409 L p .707 .577 .707 r
F P
0 g
s
.67886 .80409 m .68033 .76722 L .65629 .7723 L p .707 .577 .707 r
F P
0 g
s
.59334 .84267 m .58826 .82436 L .5583 .83124 L p .707 .577 .707 r
F P
0 g
s
.58826 .82436 m .59334 .84267 L .62408 .83397 L p .707 .577 .707 r
F P
0 g
s
.62408 .83397 m .619 .81566 L .58826 .82436 L p .707 .577 .707 r
F P
0 g
s
.53653 .76565 m .53506 .80251 L .5625 .80815 L p .707 .577 .707 r
F P
0 g
s
.619 .81566 m .62408 .83397 L .6526 .8243 L p .707 .577 .707 r
F P
0 g
s
.6526 .8243 m .64752 .80599 L .619 .81566 L p .707 .577 .707 r
F P
0 g
s
.5583 .83124 m .56338 .84955 L .59334 .84267 L p .707 .577 .707 r
F P
0 g
s
.52108 .7364 m .52148 .68086 L .50889 .67282 L p .707 .577 .707 r
F P
0 g
s
.53506 .80251 m .53653 .76565 L .5155 .75807 L p .707 .577 .707 r
F P
0 g
s
.56338 .84955 m .5583 .83124 L .53205 .83563 L p .707 .577 .707 r
F P
0 g
s
.53205 .83563 m .53713 .85394 L .56338 .84955 L p .707 .577 .707 r
F P
0 g
s
.64752 .80599 m .6526 .8243 L .67609 .81461 L p .707 .577 .707 r
F P
0 g
s
.67609 .81461 m .67101 .7963 L .64752 .80599 L p .707 .577 .707 r
F P
0 g
s
.5155 .75807 m .51403 .79493 L .53506 .80251 L p .707 .577 .707 r
F P
0 g
s
.68033 .76722 m .67886 .80409 L .69523 .79692 L p .707 .577 .707 r
F P
0 g
s
.69523 .79692 m .6967 .76005 L .68033 .76722 L p .707 .577 .707 r
F P
0 g
s
.50889 .67282 m .50849 .72835 L .52108 .7364 L p .707 .577 .707 r
F P
0 g
s
.70281 .67761 m .7024 .73315 L .70949 .72475 L p .707 .577 .707 r
F P
0 g
s
.70949 .72475 m .70989 .66921 L .70281 .67761 L p .707 .577 .707 r
F P
0 g
s
.53713 .85394 m .53205 .83563 L .51209 .8371 L p .707 .577 .707 r
F P
0 g
s
.51403 .79493 m .5155 .75807 L .50292 .74929 L p .707 .577 .707 r
F P
0 g
s
.51209 .8371 m .51717 .85541 L .53713 .85394 L p .707 .577 .707 r
F P
0 g
s
.67101 .7963 m .67609 .81461 L .69227 .80585 L p .707 .577 .707 r
F P
0 g
s
.69227 .80585 m .68719 .78755 L .67101 .7963 L p .707 .577 .707 r
F P
0 g
s
.50849 .72835 m .50889 .67282 L .506 .66417 L p .707 .577 .707 r
F P
0 g
s
.50292 .74929 m .50145 .78616 L .51403 .79493 L p .707 .577 .707 r
F P
0 g
s
.6967 .76005 m .69523 .79692 L .70231 .78835 L p .707 .577 .707 r
F P
0 g
s
.70231 .78835 m .70378 .75149 L .6967 .76005 L p .707 .577 .707 r
F P
0 g
s
.506 .66417 m .50559 .71971 L .50849 .72835 L p .707 .577 .707 r
F P
0 g
s
.70989 .66921 m .70949 .72475 L .70659 .7161 L p .707 .577 .707 r
F P
0 g
s
.70659 .7161 m .70699 .66057 L .70989 .66921 L p .707 .577 .707 r
F P
0 g
s
.51717 .85541 m .51209 .8371 L .50036 .8355 L p .707 .577 .707 r
F P
0 g
s
.50036 .8355 m .50544 .85381 L .51717 .85541 L p .707 .577 .707 r
F P
0 g
s
.50145 .78616 m .50292 .74929 L .50004 .74018 L p .707 .577 .707 r
F P
0 g
s
.68719 .78755 m .69227 .80585 L .69954 .79888 L p .707 .577 .707 r
F P
0 g
s
.69954 .79888 m .69446 .78057 L .68719 .78755 L p .707 .577 .707 r
F P
0 g
s
.49389 .82174 m .48879 .31933 L .44478 .3171 L p .707 .577 .707 r
F P
0 g
s
.50559 .71971 m .506 .66417 L .51308 .65577 L p .707 .577 .707 r
F P
0 g
s
.50004 .74018 m .49857 .77704 L .50145 .78616 L p .707 .577 .707 r
F P
0 g
s
.51308 .65577 m .51268 .7113 L .50559 .71971 L p .707 .577 .707 r
F P
0 g
s
.49857 .77704 m .50004 .74018 L .50712 .73161 L p .707 .577 .707 r
F P
0 g
s
.51268 .7113 m .51308 .65577 L .52945 .64844 L p .707 .577 .707 r
F P
0 g
s
.50712 .73161 m .50566 .76848 L .49857 .77704 L p .707 .577 .707 r
F P
0 g
s
.52945 .64844 m .52905 .70397 L .51268 .7113 L p .707 .577 .707 r
F P
0 g
s
.50566 .76848 m .50712 .73161 L .52349 .72444 L p .707 .577 .707 r
F P
0 g
s
.52349 .72444 m .52202 .76131 L .50566 .76848 L p .707 .577 .707 r
F P
0 g
s
.51038 .84233 m .5053 .82403 L .52148 .81527 L p .707 .577 .707 r
F P
0 g
s
.52202 .76131 m .52349 .72444 L .54753 .71937 L p .707 .577 .707 r
F P
0 g
s
.52148 .81527 m .52656 .83357 L .51038 .84233 L p .707 .577 .707 r
F P
0 g
s
.54753 .71937 m .54606 .75623 L .52202 .76131 L p .707 .577 .707 r
F P
0 g
s
.52656 .83357 m .52148 .81527 L .54497 .80558 L p .707 .577 .707 r
F P
0 g
s
.54497 .80558 m .55005 .82389 L .52656 .83357 L p .707 .577 .707 r
F P
0 g
s
.48879 .31933 m .49389 .82174 L .53883 .82024 L p .707 .577 .707 r
F P
0 g
s
.52905 .70397 m .52945 .64844 L .5535 .64289 L p .707 .577 .707 r
F P
0 g
s
.5535 .64289 m .5531 .69843 L .52905 .70397 L p .707 .577 .707 r
F P
0 g
s
.53883 .82024 m .53373 .31783 L .48879 .31933 L p .707 .577 .707 r
F P
0 g
s
.5531 .69843 m .5535 .64289 L .58288 .63968 L p .707 .577 .707 r
F P
0 g
s
.58288 .63968 m .58248 .69521 L .5531 .69843 L p .707 .577 .707 r
F P
0 g
s
.54606 .75623 m .54753 .71937 L .5769 .71688 L p .707 .577 .707 r
F P
0 g
s
.5769 .71688 m .57543 .75375 L .54606 .75623 L p .707 .577 .707 r
F P
0 g
s
.55005 .82389 m .54497 .80558 L .57349 .79591 L p .707 .577 .707 r
F P
0 g
s
.57349 .79591 m .57857 .81422 L .55005 .82389 L p .707 .577 .707 r
F P
0 g
s
.57857 .81422 m .57349 .79591 L .60423 .78721 L p .707 .577 .707 r
F P
0 g
s
.60423 .78721 m .60931 .80552 L .57857 .81422 L p .707 .577 .707 r
F P
0 g
s
.53373 .31783 m .53883 .82024 L .58031 .81514 L p .707 .577 .707 r
F P
0 g
s
.57543 .75375 m .5769 .71688 L .60871 .71723 L p .707 .577 .707 r
F P
0 g
s
.60871 .71723 m .60724 .7541 L .57543 .75375 L p .707 .577 .707 r
F P
0 g
s
.58031 .81514 m .57521 .31273 L .53373 .31783 L p .707 .577 .707 r
F P
0 g
s
.44988 .81951 m .44478 .3171 L .40602 .31136 L p .707 .577 .707 r
F P
0 g
s
.44478 .3171 m .44988 .81951 L .49389 .82174 L p .707 .577 .707 r
F P
0 g
s
.70378 .75149 m .70231 .78835 L .69943 .77924 L p .707 .577 .707 r
F P
0 g
s
.69943 .77924 m .7009 .74237 L .70378 .75149 L p .707 .577 .707 r
F P
0 g
s
.70699 .66057 m .70659 .7161 L .694 .70805 L p .707 .577 .707 r
F P
0 g
s
.694 .70805 m .6944 .65252 L .70699 .66057 L p .707 .577 .707 r
F P
0 g
s
.50544 .85381 m .50036 .8355 L .49802 .831 L p .707 .577 .707 r
F P
0 g
s
.58248 .69521 m .58288 .63968 L .61472 .63911 L p .707 .577 .707 r
F P
0 g
s
.61472 .63911 m .61431 .69464 L .58248 .69521 L p .707 .577 .707 r
F P
0 g
s
.63986 .72038 m .63839 .75724 L .60724 .7541 L p .707 .577 .707 r
F P
0 g
s
.60724 .7541 m .60871 .71723 L .63986 .72038 L p .707 .577 .707 r
F P
0 g
s
.63419 .78033 m .63927 .79864 L .60931 .80552 L p .707 .577 .707 r
F P
0 g
s
.60931 .80552 m .60423 .78721 L .63419 .78033 L p .707 .577 .707 r
F P
0 g
s
.57521 .31273 m .58031 .81514 L .61427 .80696 L p .707 .577 .707 r
F P
0 g
s
.61427 .80696 m .60917 .30455 L .57521 .31273 L p .707 .577 .707 r
F P
0 g
s
.49802 .831 m .5031 .84931 L .50544 .85381 L p .707 .577 .707 r
F P
0 g
s
.69446 .78057 m .69954 .79888 L .69721 .79437 L p .707 .577 .707 r
F P
0 g
s
.69721 .79437 m .69212 .77607 L .69446 .78057 L p .707 .577 .707 r
F P
0 g
s
.25776 .71382 m .25816 .65828 L .22699 .65615 L p .707 .577 .707 r
F P
0 g
s
.25816 .65828 m .25776 .71382 L .28959 .71325 L p .707 .577 .707 r
F P
0 g
s
.28959 .71325 m .28999 .65771 L .25816 .65828 L p .707 .577 .707 r
F P
0 g
s
.28999 .65771 m .28959 .71325 L .31897 .71003 L p .707 .577 .707 r
F P
0 g
s
.31897 .71003 m .31938 .65449 L .28999 .65771 L p .707 .577 .707 r
F P
0 g
s
.41112 .81376 m .40602 .31136 L .3763 .30265 L p .707 .577 .707 r
F P
0 g
s
.40602 .31136 m .41112 .81376 L .44988 .81951 L p .707 .577 .707 r
F P
0 g
s
.22658 .71169 m .22699 .65615 L .19953 .65153 L p .707 .577 .707 r
F P
0 g
s
.22699 .65615 m .22658 .71169 L .25776 .71382 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31938 .65449 m .31897 .71003 L .34302 .70449 L p .707 .577 .707 r
F P
0 g
s
.34302 .70449 m .34343 .64895 L .31938 .65449 L p .707 .577 .707 r
F P
0 g
s
.7009 .74237 m .69943 .77924 L .68686 .77046 L p .707 .577 .707 r
F P
0 g
s
.68686 .77046 m .68832 .7336 L .7009 .74237 L p .707 .577 .707 r
F P
0 g
s
.6944 .65252 m .694 .70805 L .67294 .70139 L p .707 .577 .707 r
F P
0 g
s
.67294 .70139 m .67335 .64586 L .6944 .65252 L p .707 .577 .707 r
F P
0 g
s
.64589 .64124 m .64549 .69677 L .61431 .69464 L p .707 .577 .707 r
F P
0 g
s
.61431 .69464 m .61472 .63911 L .64589 .64124 L p .707 .577 .707 r
F P
0 g
s
.63927 .79864 m .63419 .78033 L .66044 .77594 L p .707 .577 .707 r
F P
0 g
s
.60917 .30455 m .61427 .80696 L .63738 .79648 L p .707 .577 .707 r
F P
0 g
s
.63738 .79648 m .63228 .29408 L .60917 .30455 L p .707 .577 .707 r
F P
0 g
s
.5031 .84931 m .49802 .831 L .5053 .82403 L p .707 .577 .707 r
F P
0 g
s
.19953 .65153 m .19913 .70707 L .22658 .71169 L p .707 .577 .707 r
F P
0 g
s
.19913 .70707 m .19953 .65153 L .17848 .64487 L p .707 .577 .707 r
F P
0 g
s
.25063 .77353 m .2521 .73667 L .22095 .73352 L p .707 .577 .707 r
F P
0 g
s
.2521 .73667 m .25063 .77353 L .28245 .77388 L p .707 .577 .707 r
F P
0 g
s
.28245 .77388 m .28392 .73702 L .2521 .73667 L p .707 .577 .707 r
F P
0 g
s
.5053 .82403 m .51038 .84233 L .5031 .84931 L p .707 .577 .707 r
F P
0 g
s
.28392 .73702 m .28245 .77388 L .31181 .7714 L p .707 .577 .707 r
F P
0 g
s
.31181 .7714 m .31328 .73453 L .28392 .73702 L p .707 .577 .707 r
F P
0 g
s
.69212 .77607 m .69721 .79437 L .68548 .79278 L p .707 .577 .707 r
F P
0 g
s
.68548 .79278 m .6804 .77447 L .69212 .77607 L p .707 .577 .707 r
F P
0 g
s
.21949 .77039 m .22095 .73352 L .19352 .72788 L p .707 .577 .707 r
F P
0 g
s
.22095 .73352 m .21949 .77039 L .25063 .77353 L p .707 .577 .707 r
F P
0 g
s
.34343 .64895 m .34302 .70449 L .35939 .69715 L p .707 .577 .707 r
F P
0 g
s
.35939 .69715 m .3598 .64162 L .34343 .64895 L p .707 .577 .707 r
F P
0 g
s
.3814 .80506 m .3763 .30265 L .35852 .29185 L p .707 .577 .707 r
F P
0 g
s
.3763 .30265 m .3814 .80506 L .41112 .81376 L p .707 .577 .707 r
F P
0 g
s
.17848 .64487 m .17807 .7004 L .19913 .70707 L p .707 .577 .707 r
F P
0 g
s
.31328 .73453 m .31181 .7714 L .33585 .76632 L p .707 .577 .707 r
F P
0 g
s
.33585 .76632 m .33732 .72945 L .31328 .73453 L p .707 .577 .707 r
F P
0 g
s
.25033 .80523 m .24525 .78693 L .21529 .79381 L p .707 .577 .707 r
F P
0 g
s
.24525 .78693 m .25033 .80523 L .28107 .79653 L p .707 .577 .707 r
F P
0 g
s
.28107 .79653 m .27599 .77823 L .24525 .78693 L p .707 .577 .707 r
F P
0 g
s
.67335 .64586 m .67294 .70139 L .64549 .69677 L p .707 .577 .707 r
F P
0 g
s
.64549 .69677 m .64589 .64124 L .67335 .64586 L p .707 .577 .707 r
F P
0 g
s
.19352 .72788 m .19205 .76475 L .21949 .77039 L p .707 .577 .707 r
F P
0 g
s
.27599 .77823 m .28107 .79653 L .30959 .78687 L p .707 .577 .707 r
F P
0 g
s
.30959 .78687 m .30451 .76856 L .27599 .77823 L p .707 .577 .707 r
F P
0 g
s
.68832 .7336 m .68686 .77046 L .66582 .76288 L p .707 .577 .707 r
F P
0 g
s
.66582 .76288 m .66729 .72602 L .68832 .7336 L p .707 .577 .707 r
F P
0 g
s
.21529 .79381 m .22037 .81212 L .25033 .80523 L p .707 .577 .707 r
F P
0 g
s
.17807 .7004 m .17848 .64487 L .16588 .63682 L p .707 .577 .707 r
F P
0 g
s
.19205 .76475 m .19352 .72788 L .17249 .7203 L p .707 .577 .707 r
F P
0 g
s
.22037 .81212 m .21529 .79381 L .18904 .7982 L p .707 .577 .707 r
F P
0 g
s
.18904 .7982 m .19412 .81651 L .22037 .81212 L p .707 .577 .707 r
F P
0 g
s
.30451 .76856 m .30959 .78687 L .33308 .77718 L p .707 .577 .707 r
F P
0 g
s
.33308 .77718 m .328 .75887 L .30451 .76856 L p .707 .577 .707 r
F P
0 g
s
.17249 .7203 m .17102 .75717 L .19205 .76475 L p .707 .577 .707 r
F P
0 g
s
.6804 .77447 m .68548 .79278 L .66552 .79425 L p .707 .577 .707 r
F P
0 g
s
.66552 .79425 m .66044 .77594 L .6804 .77447 L p .707 .577 .707 r
F P
0 g
s
.66729 .72602 m .66582 .76288 L .63839 .75724 L p .707 .577 .707 r
F P
0 g
s
.63839 .75724 m .63986 .72038 L .66729 .72602 L p .707 .577 .707 r
F P
0 g
s
.63228 .29408 m .63738 .79648 L .64738 .78475 L p .707 .577 .707 r
F P
0 g
s
.64738 .78475 m .64228 .28234 L .63228 .29408 L p .707 .577 .707 r
F P
0 g
s
.33732 .72945 m .33585 .76632 L .35222 .75915 L p .707 .577 .707 r
F P
0 g
s
.35222 .75915 m .35369 .72228 L .33732 .72945 L p .707 .577 .707 r
F P
0 g
s
.16588 .63682 m .16548 .69236 L .17807 .7004 L p .707 .577 .707 r
F P
0 g
s
.3598 .64162 m .35939 .69715 L .36648 .68875 L p .707 .577 .707 r
F P
0 g
s
.36648 .68875 m .36688 .63322 L .3598 .64162 L p .707 .577 .707 r
F P
0 g
s
.19412 .81651 m .18904 .7982 L .16908 .79967 L p .707 .577 .707 r
F P
0 g
s
.17102 .75717 m .17249 .7203 L .15991 .71153 L p .707 .577 .707 r
F P
0 g
s
.16908 .79967 m .17416 .81798 L .19412 .81651 L p .707 .577 .707 r
F P
0 g
s
.328 .75887 m .33308 .77718 L .34926 .76842 L p .707 .577 .707 r
F P
0 g
s
.34926 .76842 m .34418 .75012 L .328 .75887 L p .707 .577 .707 r
F P
0 g
s
.16548 .69236 m .16588 .63682 L .16299 .62817 L p .707 .577 .707 r
F P
0 g
s
.36398 .62457 m .36358 .68011 L .35099 .67206 L p .707 .577 .707 r
F P
0 g
s
.35099 .67206 m .35139 .61652 L .36398 .62457 L p .707 .577 .707 r
F P
0 g
s
.36362 .79425 m .35852 .29185 L .35443 .27999 L p .707 .577 .707 r
F P
0 g
s
.36688 .63322 m .36648 .68875 L .36358 .68011 L p .707 .577 .707 r
F P
0 g
s
.36358 .68011 m .36398 .62457 L .36688 .63322 L p .707 .577 .707 r
F P
0 g
s
.35852 .29185 m .36362 .79425 L .3814 .80506 L p .707 .577 .707 r
F P
0 g
s
.15991 .71153 m .15845 .74839 L .17102 .75717 L p .707 .577 .707 r
F P
0 g
s
.66044 .77594 m .66552 .79425 L .63927 .79864 L p .707 .577 .707 r
F P
0 g
s
.35369 .72228 m .35222 .75915 L .35931 .75059 L p .707 .577 .707 r
F P
0 g
s
.35931 .75059 m .36077 .71372 L .35369 .72228 L p .707 .577 .707 r
F P
0 g
s
.16299 .62817 m .16258 .68371 L .16548 .69236 L p .707 .577 .707 r
F P
0 g
s
.17416 .81798 m .16908 .79967 L .15735 .79807 L p .707 .577 .707 r
F P
0 g
s
.15735 .79807 m .16243 .81638 L .17416 .81798 L p .707 .577 .707 r
F P
0 g
s
.15845 .74839 m .15991 .71153 L .15703 .70241 L p .707 .577 .707 r
F P
0 g
s
.34418 .75012 m .34926 .76842 L .35654 .76145 L p .707 .577 .707 r
F P
0 g
s
.35654 .76145 m .35146 .74314 L .34418 .75012 L p .707 .577 .707 r
F P
0 g
s
.64228 .28234 m .64738 .78475 L .64329 .7729 L p .707 .577 .707 r
F P
0 g
s
.64329 .7729 m .63819 .27049 L .64228 .28234 L p .707 .577 .707 r
F P
0 g
s
.16258 .68371 m .16299 .62817 L .17007 .61977 L p .707 .577 .707 r
F P
0 g
s
.15703 .70241 m .15556 .73928 L .15845 .74839 L p .707 .577 .707 r
F P
0 g
s
.36077 .71372 m .35931 .75059 L .35642 .74147 L p .707 .577 .707 r
F P
0 g
s
.35642 .74147 m .35789 .70461 L .36077 .71372 L p .707 .577 .707 r
F P
0 g
s
.35443 .27999 m .35953 .7824 L .36362 .79425 L p .707 .577 .707 r
F P
0 g
s
.35953 .7824 m .35443 .27999 L .36443 .26826 L p .707 .577 .707 r
F P
0 g
s
.17007 .61977 m .16967 .67531 L .16258 .68371 L p .707 .577 .707 r
F P
0 g
s
.16243 .81638 m .15735 .79807 L .15501 .79357 L p .707 .577 .707 r
F P
0 g
s
.15501 .79357 m .16009 .81188 L .16243 .81638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15556 .73928 m .15703 .70241 L .16411 .69385 L p .707 .577 .707 r
F P
0 g
s
.35146 .74314 m .35654 .76145 L .3542 .75694 L p .707 .577 .707 r
F P
0 g
s
.3542 .75694 m .34912 .73864 L .35146 .74314 L p .707 .577 .707 r
F P
0 g
s
.16967 .67531 m .17007 .61977 L .18644 .61244 L p .707 .577 .707 r
F P
0 g
s
.16411 .69385 m .16265 .73071 L .15556 .73928 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63819 .27049 m .64329 .7729 L .62551 .76209 L p .707 .577 .707 r
F P
0 g
s
.62551 .76209 m .62041 .25968 L .63819 .27049 L p .707 .577 .707 r
F P
0 g
s
.35789 .70461 m .35642 .74147 L .34385 .7327 L p .707 .577 .707 r
F P
0 g
s
.34385 .7327 m .34531 .69583 L .35789 .70461 L p .707 .577 .707 r
F P
0 g
s
.18644 .61244 m .18604 .66798 L .16967 .67531 L p .707 .577 .707 r
F P
0 g
s
.35139 .61652 m .35099 .67206 L .32993 .6654 L p .707 .577 .707 r
F P
0 g
s
.32993 .6654 m .33034 .60986 L .35139 .61652 L p .707 .577 .707 r
F P
0 g
s
.16009 .81188 m .15501 .79357 L .16229 .7866 L p .707 .577 .707 r
F P
0 g
s
.16229 .7866 m .16737 .8049 L .16009 .81188 L p .707 .577 .707 r
F P
0 g
s
.16265 .73071 m .16411 .69385 L .18048 .68668 L p .707 .577 .707 r
F P
0 g
s
.34912 .73864 m .3542 .75694 L .34247 .75535 L p .707 .577 .707 r
F P
0 g
s
.34247 .75535 m .33739 .73704 L .34912 .73864 L p .707 .577 .707 r
F P
0 g
s
.18604 .66798 m .18644 .61244 L .21049 .6069 L p .707 .577 .707 r
F P
0 g
s
.36953 .77067 m .36443 .26826 L .38754 .25778 L p .707 .577 .707 r
F P
0 g
s
.36443 .26826 m .36953 .77067 L .35953 .7824 L p .707 .577 .707 r
F P
0 g
s
.18048 .68668 m .17901 .72354 L .16265 .73071 L p .707 .577 .707 r
F P
0 g
s
.33034 .60986 m .32993 .6654 L .30248 .66078 L p .707 .577 .707 r
F P
0 g
s
.30248 .66078 m .30288 .60524 L .33034 .60986 L p .707 .577 .707 r
F P
0 g
s
.34531 .69583 m .34385 .7327 L .32281 .72512 L p .707 .577 .707 r
F P
0 g
s
.32281 .72512 m .32428 .68825 L .34531 .69583 L p .707 .577 .707 r
F P
0 g
s
.21049 .6069 m .21009 .66243 L .18604 .66798 L p .707 .577 .707 r
F P
0 g
s
.21009 .66243 m .21049 .6069 L .23987 .60368 L p .707 .577 .707 r
F P
0 g
s
.17901 .72354 m .18048 .68668 L .20452 .6816 L p .707 .577 .707 r
F P
0 g
s
.62041 .25968 m .62551 .76209 L .59579 .75339 L p .707 .577 .707 r
F P
0 g
s
.59579 .75339 m .59069 .25098 L .62041 .25968 L p .707 .577 .707 r
F P
0 g
s
.16737 .8049 m .16229 .7866 L .17847 .77784 L p .707 .577 .707 r
F P
0 g
s
.17847 .77784 m .18355 .79614 L .16737 .8049 L p .707 .577 .707 r
F P
0 g
s
.30288 .60524 m .30248 .66078 L .2713 .65865 L p .707 .577 .707 r
F P
0 g
s
.2713 .65865 m .27171 .60311 L .30288 .60524 L p .707 .577 .707 r
F P
0 g
s
.33739 .73704 m .34247 .75535 L .32251 .75682 L p .707 .577 .707 r
F P
0 g
s
.32251 .75682 m .31743 .73851 L .33739 .73704 L p .707 .577 .707 r
F P
0 g
s
.23947 .65922 m .23987 .60368 L .27171 .60311 L p .707 .577 .707 r
F P
0 g
s
.23987 .60368 m .23947 .65922 L .21009 .66243 L p .707 .577 .707 r
F P
0 g
s
.20452 .6816 m .20305 .71847 L .17901 .72354 L p .707 .577 .707 r
F P
0 g
s
.27171 .60311 m .2713 .65865 L .23947 .65922 L p .707 .577 .707 r
F P
0 g
s
.73797 .65777 m .73837 .60224 L .7072 .60011 L p .707 .577 .707 r
F P
0 g
s
.73837 .60224 m .73797 .65777 L .7698 .6572 L p .707 .577 .707 r
F P
0 g
s
.7698 .6572 m .77021 .60167 L .73837 .60224 L p .707 .577 .707 r
F P
0 g
s
.32428 .68825 m .32281 .72512 L .29538 .71948 L p .707 .577 .707 r
F P
0 g
s
.29538 .71948 m .29685 .68261 L .32428 .68825 L p .707 .577 .707 r
F P
0 g
s
.38754 .25778 m .39264 .76019 L .36953 .77067 L p .707 .577 .707 r
F P
0 g
s
.39264 .76019 m .38754 .25778 L .4215 .2496 L p .707 .577 .707 r
F P
0 g
s
.77021 .60167 m .7698 .6572 L .79919 .65399 L p .707 .577 .707 r
F P
0 g
s
.79919 .65399 m .79959 .59845 L .77021 .60167 L p .707 .577 .707 r
F P
0 g
s
.20305 .71847 m .20452 .6816 L .23389 .67912 L p .707 .577 .707 r
F P
0 g
s
.7068 .65564 m .7072 .60011 L .67974 .59549 L p .707 .577 .707 r
F P
0 g
s
.7072 .60011 m .7068 .65564 L .73797 .65777 L p .707 .577 .707 r
F P
0 g
s
.18355 .79614 m .17847 .77784 L .20196 .76815 L p .707 .577 .707 r
F P
0 g
s
.79959 .59845 m .79919 .65399 L .82324 .64844 L p .707 .577 .707 r
F P
0 g
s
.82324 .64844 m .82364 .59291 L .79959 .59845 L p .707 .577 .707 r
F P
0 g
s
.20196 .76815 m .20704 .78646 L .18355 .79614 L p .707 .577 .707 r
F P
0 g
s
.29685 .68261 m .29538 .71948 L .26423 .71633 L p .707 .577 .707 r
F P
0 g
s
.26423 .71633 m .2657 .67946 L .29685 .68261 L p .707 .577 .707 r
F P
0 g
s
.31743 .73851 m .32251 .75682 L .29626 .76121 L p .707 .577 .707 r
F P
0 g
s
.29626 .76121 m .29118 .7429 L .31743 .73851 L p .707 .577 .707 r
F P
0 g
s
.23389 .67912 m .23242 .71598 L .20305 .71847 L p .707 .577 .707 r
F P
0 g
s
.23242 .71598 m .23389 .67912 L .2657 .67946 L p .707 .577 .707 r
F P
0 g
s
.59069 .25098 m .59579 .75339 L .55703 .74764 L p .707 .577 .707 r
F P
0 g
s
.55703 .74764 m .55193 .24523 L .59069 .25098 L p .707 .577 .707 r
F P
0 g
s
.2657 .67946 m .26423 .71633 L .23242 .71598 L p .707 .577 .707 r
F P
0 g
s
.67974 .59549 m .67934 .65102 L .7068 .65564 L p .707 .577 .707 r
F P
0 g
s
.67934 .65102 m .67974 .59549 L .65869 .58883 L p .707 .577 .707 r
F P
0 g
s
.73085 .71926 m .73232 .6824 L .70117 .67925 L p .707 .577 .707 r
F P
0 g
s
.73232 .6824 m .73085 .71926 L .76266 .71961 L p .707 .577 .707 r
F P
0 g
s
.76266 .71961 m .76413 .68275 L .73232 .6824 L p .707 .577 .707 r
F P
0 g
s
.76413 .68275 m .76266 .71961 L .79203 .71713 L p .707 .577 .707 r
F P
0 g
s
.79203 .71713 m .79349 .68026 L .76413 .68275 L p .707 .577 .707 r
F P
0 g
s
.4266 .75201 m .4215 .2496 L .46298 .24451 L p .707 .577 .707 r
F P
0 g
s
.4215 .2496 m .4266 .75201 L .39264 .76019 L p .707 .577 .707 r
F P
0 g
s
.6997 .71612 m .70117 .67925 L .67373 .67361 L p .707 .577 .707 r
F P
0 g
s
.70117 .67925 m .6997 .71612 L .73085 .71926 L p .707 .577 .707 r
F P
0 g
s
.20704 .78646 m .20196 .76815 L .23048 .75848 L p .707 .577 .707 r
F P
0 g
s
.23048 .75848 m .23556 .77679 L .20704 .78646 L p .707 .577 .707 r
F P
0 g
s
.29118 .7429 m .29626 .76121 L .2663 .76809 L p .707 .577 .707 r
F P
0 g
s
.2663 .76809 m .26122 .74978 L .29118 .7429 L p .707 .577 .707 r
F P
0 g
s
.82364 .59291 m .82324 .64844 L .83961 .64111 L p .707 .577 .707 r
F P
0 g
s
.83961 .64111 m .84001 .58557 L .82364 .59291 L p .707 .577 .707 r
F P
0 g
s
.65869 .58883 m .65829 .64436 L .67934 .65102 L p .707 .577 .707 r
F P
0 g
s
.79349 .68026 m .79203 .71713 L .81607 .71205 L p .707 .577 .707 r
F P
0 g
s
.81607 .71205 m .81753 .67518 L .79349 .68026 L p .707 .577 .707 r
F P
0 g
s
.55193 .24523 m .55703 .74764 L .51302 .74541 L p .707 .577 .707 r
F P
0 g
s
.51302 .74541 m .50792 .243 L .55193 .24523 L p .707 .577 .707 r
F P
0 g
s
.73054 .75063 m .72546 .73232 L .6955 .7392 L p .707 .577 .707 r
F P
0 g
s
.72546 .73232 m .73054 .75063 L .76129 .74193 L p .707 .577 .707 r
F P
0 g
s
.76129 .74193 m .75621 .72362 L .72546 .73232 L p .707 .577 .707 r
F P
0 g
s
.67373 .67361 m .67227 .71048 L .6997 .71612 L p .707 .577 .707 r
F P
0 g
s
.23556 .77679 m .23048 .75848 L .26122 .74978 L p .707 .577 .707 r
F P
0 g
s
.75621 .72362 m .76129 .74193 L .7898 .73226 L p .707 .577 .707 r
F P
0 g
s
.7898 .73226 m .78472 .71395 L .75621 .72362 L p .707 .577 .707 r
F P
0 g
s
.26122 .74978 m .2663 .76809 L .23556 .77679 L p .707 .577 .707 r
F P
0 g
s
.6955 .7392 m .70058 .75751 L .73054 .75063 L p .707 .577 .707 r
F P
0 g
s
.65829 .64436 m .65869 .58883 L .6461 .58078 L p .707 .577 .707 r
F P
0 g
s
.67227 .71048 m .67373 .67361 L .6527 .66603 L p .707 .577 .707 r
F P
0 g
s
.46808 .74691 m .46298 .24451 L .50792 .243 L p .707 .577 .707 r
F P
0 g
s
.46298 .24451 m .46808 .74691 L .4266 .75201 L p .707 .577 .707 r
F P
0 g
s
.70058 .75751 m .6955 .7392 L .66925 .74359 L p .707 .577 .707 r
F P
0 g
s
.50792 .243 m .51302 .74541 L .46808 .74691 L p .707 .577 .707 r
F P
0 g
s
.66925 .74359 m .67434 .7619 L .70058 .75751 L p .707 .577 .707 r
F P
0 g
s
.78472 .71395 m .7898 .73226 L .8133 .72257 L p .707 .577 .707 r
F P
0 g
s
.8133 .72257 m .80822 .70427 L .78472 .71395 L p .707 .577 .707 r
F P
0 g
s
.6527 .66603 m .65123 .7029 L .67227 .71048 L p .707 .577 .707 r
F P
0 g
s
.81753 .67518 m .81607 .71205 L .83243 .70488 L p .707 .577 .707 r
F P
0 g
s
.83243 .70488 m .8339 .66801 L .81753 .67518 L p .707 .577 .707 r
F P
0 g
s
.6461 .58078 m .64569 .63631 L .65829 .64436 L p .707 .577 .707 r
F P
0 g
s
.84001 .58557 m .83961 .64111 L .84669 .63271 L p .707 .577 .707 r
F P
0 g
s
.84669 .63271 m .84709 .57717 L .84001 .58557 L p .707 .577 .707 r
F P
0 g
s
.67434 .7619 m .66925 .74359 L .64929 .74506 L p .707 .577 .707 r
F P
0 g
s
.65123 .7029 m .6527 .66603 L .64013 .65725 L p .707 .577 .707 r
F P
0 g
s
.64929 .74506 m .65437 .76337 L .67434 .7619 L p .707 .577 .707 r
F P
0 g
s
.80822 .70427 m .8133 .72257 L .82947 .71381 L p .707 .577 .707 r
F P
0 g
s
.82947 .71381 m .82439 .69551 L .80822 .70427 L p .707 .577 .707 r
F P
0 g
s
.64569 .63631 m .6461 .58078 L .6432 .57213 L p .707 .577 .707 r
F P
0 g
s
.64013 .65725 m .63866 .69412 L .65123 .7029 L p .707 .577 .707 r
F P
0 g
s
.8339 .66801 m .83243 .70488 L .83952 .69632 L p .707 .577 .707 r
F P
0 g
s
.83952 .69632 m .84099 .65945 L .8339 .66801 L p .707 .577 .707 r
F P
0 g
s
.6432 .57213 m .6428 .62767 L .64569 .63631 L p .707 .577 .707 r
F P
0 g
s
.84709 .57717 m .84669 .63271 L .84379 .62406 L p .707 .577 .707 r
F P
0 g
s
.84379 .62406 m .8442 .56853 L .84709 .57717 L p .707 .577 .707 r
F P
0 g
s
.65437 .76337 m .64929 .74506 L .63757 .74347 L p .707 .577 .707 r
F P
0 g
s
.63757 .74347 m .64265 .76177 L .65437 .76337 L p .707 .577 .707 r
F P
0 g
s
.63866 .69412 m .64013 .65725 L .63724 .64814 L p .707 .577 .707 r
F P
0 g
s
.82439 .69551 m .82947 .71381 L .83675 .70684 L p .707 .577 .707 r
F P
0 g
s
.83675 .70684 m .83167 .68853 L .82439 .69551 L p .707 .577 .707 r
F P
0 g
s
.6428 .62767 m .6432 .57213 L .65028 .56373 L p .707 .577 .707 r
F P
0 g
s
.63724 .64814 m .63577 .685 L .63866 .69412 L p .707 .577 .707 r
F P
0 g
s
.84099 .65945 m .83952 .69632 L .83663 .6872 L p .707 .577 .707 r
F P
0 g
s
.83663 .6872 m .8381 .65034 L .84099 .65945 L p .707 .577 .707 r
F P
0 g
s
.65028 .56373 m .64988 .61927 L .6428 .62767 L p .707 .577 .707 r
F P
0 g
s
.8442 .56853 m .84379 .62406 L .8312 .61602 L p .707 .577 .707 r
F P
0 g
s
.8312 .61602 m .83161 .56048 L .8442 .56853 L p .707 .577 .707 r
F P
0 g
s
.64265 .76177 m .63757 .74347 L .63523 .73896 L p .707 .577 .707 r
F P
0 g
s
.63523 .73896 m .64031 .75727 L .64265 .76177 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63577 .685 m .63724 .64814 L .64433 .63958 L p .707 .577 .707 r
F P
0 g
s
.83167 .68853 m .83675 .70684 L .83441 .70234 L p .707 .577 .707 r
F P
0 g
s
.83441 .70234 m .82933 .68403 L .83167 .68853 L p .707 .577 .707 r
F P
0 g
s
.39496 .62178 m .39536 .56624 L .36419 .56411 L p .707 .577 .707 r
F P
0 g
s
.39536 .56624 m .39496 .62178 L .42679 .62121 L p .707 .577 .707 r
F P
0 g
s
.42679 .62121 m .4272 .56567 L .39536 .56624 L p .707 .577 .707 r
F P
0 g
s
.64988 .61927 m .65028 .56373 L .66665 .5564 L p .707 .577 .707 r
F P
0 g
s
.4272 .56567 m .42679 .62121 L .45618 .61799 L p .707 .577 .707 r
F P
0 g
s
.45618 .61799 m .45658 .56245 L .4272 .56567 L p .707 .577 .707 r
F P
0 g
s
.64433 .63958 m .64286 .67644 L .63577 .685 L p .707 .577 .707 r
F P
0 g
s
.36379 .61965 m .36419 .56411 L .33673 .55949 L p .707 .577 .707 r
F P
0 g
s
.36419 .56411 m .36379 .61965 L .39496 .62178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45658 .56245 m .45618 .61799 L .48023 .61245 L p .707 .577 .707 r
F P
0 g
s
.48023 .61245 m .48063 .55691 L .45658 .56245 L p .707 .577 .707 r
F P
0 g
s
.8381 .65034 m .83663 .6872 L .82406 .67842 L p .707 .577 .707 r
F P
0 g
s
.82406 .67842 m .82553 .64156 L .8381 .65034 L p .707 .577 .707 r
F P
0 g
s
.66665 .5564 m .66625 .61193 L .64988 .61927 L p .707 .577 .707 r
F P
0 g
s
.83161 .56048 m .8312 .61602 L .81015 .60936 L p .707 .577 .707 r
F P
0 g
s
.81015 .60936 m .81055 .55382 L .83161 .56048 L p .707 .577 .707 r
F P
0 g
s
.64031 .75727 m .63523 .73896 L .6425 .73199 L p .707 .577 .707 r
F P
0 g
s
.33673 .55949 m .33633 .61503 L .36379 .61965 L p .707 .577 .707 r
F P
0 g
s
.33633 .61503 m .33673 .55949 L .31568 .55283 L p .707 .577 .707 r
F P
0 g
s
.38784 .6815 m .38931 .64463 L .35816 .64148 L p .707 .577 .707 r
F P
0 g
s
.38931 .64463 m .38784 .6815 L .41965 .68184 L p .707 .577 .707 r
F P
0 g
s
.41965 .68184 m .42112 .64498 L .38931 .64463 L p .707 .577 .707 r
F P
0 g
s
.6425 .73199 m .64758 .75029 L .64031 .75727 L p .707 .577 .707 r
F P
0 g
s
.64286 .67644 m .64433 .63958 L .66069 .63241 L p .707 .577 .707 r
F P
0 g
s
.42112 .64498 m .41965 .68184 L .44902 .67936 L p .707 .577 .707 r
F P
0 g
s
.44902 .67936 m .45048 .64249 L .42112 .64498 L p .707 .577 .707 r
F P
0 g
s
.82933 .68403 m .83441 .70234 L .82268 .70074 L p .707 .577 .707 r
F P
0 g
s
.82268 .70074 m .8176 .68243 L .82933 .68403 L p .707 .577 .707 r
F P
0 g
s
.66625 .61193 m .66665 .5564 L .69071 .55085 L p .707 .577 .707 r
F P
0 g
s
.35669 .67835 m .35816 .64148 L .33072 .63584 L p .707 .577 .707 r
F P
0 g
s
.35816 .64148 m .35669 .67835 L .38784 .6815 L p .707 .577 .707 r
F P
0 g
s
.48063 .55691 m .48023 .61245 L .4966 .60512 L p .707 .577 .707 r
F P
0 g
s
.4966 .60512 m .497 .54958 L .48063 .55691 L p .707 .577 .707 r
F P
0 g
s
.66069 .63241 m .65923 .66927 L .64286 .67644 L p .707 .577 .707 r
F P
0 g
s
.31568 .55283 m .31527 .60837 L .33633 .61503 L p .707 .577 .707 r
F P
0 g
s
.45048 .64249 m .44902 .67936 L .47306 .67428 L p .707 .577 .707 r
F P
0 g
s
.47306 .67428 m .47452 .63742 L .45048 .64249 L p .707 .577 .707 r
F P
0 g
s
.38753 .7132 m .38245 .69489 L .35249 .70177 L p .707 .577 .707 r
F P
0 g
s
.38245 .69489 m .38753 .7132 L .41828 .7045 L p .707 .577 .707 r
F P
0 g
s
.41828 .7045 m .4132 .68619 L .38245 .69489 L p .707 .577 .707 r
F P
0 g
s
.81055 .55382 m .81015 .60936 L .78269 .60473 L p .707 .577 .707 r
F P
0 g
s
.78269 .60473 m .78309 .5492 L .81055 .55382 L p .707 .577 .707 r
F P
0 g
s
.33072 .63584 m .32926 .67271 L .35669 .67835 L p .707 .577 .707 r
F P
0 g
s
.4132 .68619 m .41828 .7045 L .44679 .69483 L p .707 .577 .707 r
F P
0 g
s
.44679 .69483 m .44171 .67652 L .4132 .68619 L p .707 .577 .707 r
F P
0 g
s
.82553 .64156 m .82406 .67842 L .80303 .67084 L p .707 .577 .707 r
F P
0 g
s
.80303 .67084 m .80449 .63398 L .82553 .64156 L p .707 .577 .707 r
F P
0 g
s
.35249 .70177 m .35757 .72008 L .38753 .7132 L p .707 .577 .707 r
F P
0 g
s
.69071 .55085 m .6903 .60639 L .66625 .61193 L p .707 .577 .707 r
F P
0 g
s
.31527 .60837 m .31568 .55283 L .30309 .54478 L p .707 .577 .707 r
F P
0 g
s
.32926 .67271 m .33072 .63584 L .30969 .62826 L p .707 .577 .707 r
F P
0 g
s
.6903 .60639 m .69071 .55085 L .72009 .54764 L p .707 .577 .707 r
F P
0 g
s
.35757 .72008 m .35249 .70177 L .32624 .70616 L p .707 .577 .707 r
F P
0 g
s
.64758 .75029 m .6425 .73199 L .65868 .72323 L p .707 .577 .707 r
F P
0 g
s
.65923 .66927 m .66069 .63241 L .68474 .62733 L p .707 .577 .707 r
F P
0 g
s
.32624 .70616 m .33132 .72447 L .35757 .72008 L p .707 .577 .707 r
F P
0 g
s
.44171 .67652 m .44679 .69483 L .47029 .68514 L p .707 .577 .707 r
F P
0 g
s
.47029 .68514 m .46521 .66684 L .44171 .67652 L p .707 .577 .707 r
F P
0 g
s
.65868 .72323 m .66376 .74154 L .64758 .75029 L p .707 .577 .707 r
F P
0 g
s
.30969 .62826 m .30822 .66513 L .32926 .67271 L p .707 .577 .707 r
F P
0 g
s
.78309 .5492 m .78269 .60473 L .75152 .6026 L p .707 .577 .707 r
F P
0 g
s
.75152 .6026 m .75192 .54707 L .78309 .5492 L p .707 .577 .707 r
F P
0 g
s
.8176 .68243 m .82268 .70074 L .80272 .70221 L p .707 .577 .707 r
F P
0 g
s
.80272 .70221 m .79764 .6839 L .8176 .68243 L p .707 .577 .707 r
F P
0 g
s
.47452 .63742 m .47306 .67428 L .48942 .66711 L p .707 .577 .707 r
F P
0 g
s
.48942 .66711 m .49089 .63025 L .47452 .63742 L p .707 .577 .707 r
F P
0 g
s
.71968 .60318 m .72009 .54764 L .75192 .54707 L p .707 .577 .707 r
F P
0 g
s
.72009 .54764 m .71968 .60318 L .6903 .60639 L p .707 .577 .707 r
F P
0 g
s
.30309 .54478 m .30268 .60032 L .31527 .60837 L p .707 .577 .707 r
F P
0 g
s
.497 .54958 m .4966 .60512 L .50368 .59672 L p .707 .577 .707 r
F P
0 g
s
.50368 .59672 m .50408 .54118 L .497 .54958 L p .707 .577 .707 r
F P
0 g
s
.68474 .62733 m .68327 .66419 L .65923 .66927 L p .707 .577 .707 r
F P
0 g
s
.75192 .54707 m .75152 .6026 L .71968 .60318 L p .707 .577 .707 r
F P
0 g
s
.80449 .63398 m .80303 .67084 L .77559 .66521 L p .707 .577 .707 r
F P
0 g
s
.77559 .66521 m .77706 .62834 L .80449 .63398 L p .707 .577 .707 r
F P
0 g
s
.33132 .72447 m .32624 .70616 L .30628 .70763 L p .707 .577 .707 r
F P
0 g
s
.30822 .66513 m .30969 .62826 L .29712 .61949 L p .707 .577 .707 r
F P
0 g
s
.30628 .70763 m .31136 .72594 L .33132 .72447 L p .707 .577 .707 r
F P
0 g
s
.46521 .66684 m .47029 .68514 L .48646 .67638 L p .707 .577 .707 r
F P
0 g
s
.48646 .67638 m .48138 .65808 L .46521 .66684 L p .707 .577 .707 r
F P
0 g
s
.68327 .66419 m .68474 .62733 L .7141 .62484 L p .707 .577 .707 r
F P
0 g
s
.30268 .60032 m .30309 .54478 L .30019 .53613 L p .707 .577 .707 r
F P
0 g
s
.66376 .74154 m .65868 .72323 L .68218 .71354 L p .707 .577 .707 r
F P
0 g
s
.29712 .61949 m .29565 .65635 L .30822 .66513 L p .707 .577 .707 r
F P
0 g
s
.68218 .71354 m .68726 .73185 L .66376 .74154 L p .707 .577 .707 r
F P
0 g
s
.77706 .62834 m .77559 .66521 L .74445 .66206 L p .707 .577 .707 r
F P
0 g
s
.74445 .66206 m .74591 .62519 L .77706 .62834 L p .707 .577 .707 r
F P
0 g
s
.79764 .6839 m .80272 .70221 L .77648 .7066 L p .707 .577 .707 r
F P
0 g
s
.77648 .7066 m .77139 .68829 L .79764 .6839 L p .707 .577 .707 r
F P
0 g
s
.7141 .62484 m .71263 .66171 L .68327 .66419 L p .707 .577 .707 r
F P
0 g
s
.71263 .66171 m .7141 .62484 L .74591 .62519 L p .707 .577 .707 r
F P
0 g
s
.49089 .63025 m .48942 .66711 L .49651 .65855 L p .707 .577 .707 r
F P
0 g
s
.49651 .65855 m .49798 .62168 L .49089 .63025 L p .707 .577 .707 r
F P
0 g
s
.74591 .62519 m .74445 .66206 L .71263 .66171 L p .707 .577 .707 r
F P
0 g
s
.30019 .53613 m .29979 .59167 L .30268 .60032 L p .707 .577 .707 r
F P
0 g
s
.50408 .54118 m .50368 .59672 L .50078 .58807 L p .707 .577 .707 r
F P
0 g
s
.50078 .58807 m .50119 .53253 L .50408 .54118 L p .707 .577 .707 r
F P
0 g
s
.31136 .72594 m .30628 .70763 L .29456 .70604 L p .707 .577 .707 r
F P
0 g
s
.29456 .70604 m .29964 .72434 L .31136 .72594 L p .707 .577 .707 r
F P
0 g
s
.29565 .65635 m .29712 .61949 L .29423 .61037 L p .707 .577 .707 r
F P
0 g
s
.68726 .73185 m .68218 .71354 L .71069 .70388 L p .707 .577 .707 r
F P
0 g
s
.48138 .65808 m .48646 .67638 L .49374 .66941 L p .707 .577 .707 r
F P
0 g
s
.49374 .66941 m .48866 .6511 L .48138 .65808 L p .707 .577 .707 r
F P
0 g
s
.71069 .70388 m .71577 .72218 L .68726 .73185 L p .707 .577 .707 r
F P
0 g
s
.77139 .68829 m .77648 .7066 L .74651 .71348 L p .707 .577 .707 r
F P
0 g
s
.74651 .71348 m .74143 .69518 L .77139 .68829 L p .707 .577 .707 r
F P
0 g
s
.29979 .59167 m .30019 .53613 L .30727 .52773 L p .707 .577 .707 r
F P
0 g
s
.29423 .61037 m .29276 .64724 L .29565 .65635 L p .707 .577 .707 r
F P
0 g
s
.71577 .72218 m .71069 .70388 L .74143 .69518 L p .707 .577 .707 r
F P
0 g
s
.74143 .69518 m .74651 .71348 L .71577 .72218 L p .707 .577 .707 r
F P
0 g
s
.49798 .62168 m .49651 .65855 L .49362 .64943 L p .707 .577 .707 r
F P
0 g
s
.49362 .64943 m .49509 .61257 L .49798 .62168 L p .707 .577 .707 r
F P
0 g
s
.30727 .52773 m .30687 .58327 L .29979 .59167 L p .707 .577 .707 r
F P
0 g
s
.29964 .72434 m .29456 .70604 L .29222 .70153 L p .707 .577 .707 r
F P
0 g
s
.50119 .53253 m .50078 .58807 L .48819 .58002 L p .707 .577 .707 r
F P
0 g
s
.48819 .58002 m .4886 .52448 L .50119 .53253 L p .707 .577 .707 r
F P
0 g
s
.29222 .70153 m .2973 .71984 L .29964 .72434 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29276 .64724 m .29423 .61037 L .30132 .60181 L p .707 .577 .707 r
F P
0 g
s
.48866 .6511 m .49374 .66941 L .4914 .66491 L p .707 .577 .707 r
F P
0 g
s
.4914 .66491 m .48632 .6466 L .48866 .6511 L p .707 .577 .707 r
F P
0 g
s
.30687 .58327 m .30727 .52773 L .32364 .5204 L p .707 .577 .707 r
F P
0 g
s
.30132 .60181 m .29985 .63868 L .29276 .64724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49509 .61257 m .49362 .64943 L .48105 .64066 L p .707 .577 .707 r
F P
0 g
s
.48105 .64066 m .48252 .60379 L .49509 .61257 L p .707 .577 .707 r
F P
0 g
s
.32364 .5204 m .32324 .57594 L .30687 .58327 L p .707 .577 .707 r
F P
0 g
s
.4886 .52448 m .48819 .58002 L .46714 .57336 L p .707 .577 .707 r
F P
0 g
s
.46714 .57336 m .46754 .51782 L .4886 .52448 L p .707 .577 .707 r
F P
0 g
s
.2973 .71984 m .29222 .70153 L .29949 .69456 L p .707 .577 .707 r
F P
0 g
s
.29949 .69456 m .30457 .71286 L .2973 .71984 L p .707 .577 .707 r
F P
0 g
s
.29985 .63868 m .30132 .60181 L .31768 .59464 L p .707 .577 .707 r
F P
0 g
s
.48632 .6466 m .4914 .66491 L .47967 .66331 L p .707 .577 .707 r
F P
0 g
s
.47967 .66331 m .47459 .645 L .48632 .6466 L p .707 .577 .707 r
F P
0 g
s
.32324 .57594 m .32364 .5204 L .3477 .51486 L p .707 .577 .707 r
F P
0 g
s
.31768 .59464 m .31622 .6315 L .29985 .63868 L p .707 .577 .707 r
F P
0 g
s
.46754 .51782 m .46714 .57336 L .43968 .56874 L p .707 .577 .707 r
F P
0 g
s
.43968 .56874 m .44008 .5132 L .46754 .51782 L p .707 .577 .707 r
F P
0 g
s
.48252 .60379 m .48105 .64066 L .46002 .63308 L p .707 .577 .707 r
F P
0 g
s
.46002 .63308 m .46148 .59621 L .48252 .60379 L p .707 .577 .707 r
F P
0 g
s
.3477 .51486 m .34729 .57039 L .32324 .57594 L p .707 .577 .707 r
F P
0 g
s
.34729 .57039 m .3477 .51486 L .37708 .51164 L p .707 .577 .707 r
F P
0 g
s
.31622 .6315 m .31768 .59464 L .34172 .58956 L p .707 .577 .707 r
F P
0 g
s
.30457 .71286 m .29949 .69456 L .31567 .6858 L p .707 .577 .707 r
F P
0 g
s
.31567 .6858 m .32075 .70411 L .30457 .71286 L p .707 .577 .707 r
F P
0 g
s
.44008 .5132 m .43968 .56874 L .40851 .56661 L p .707 .577 .707 r
F P
0 g
s
.40851 .56661 m .40891 .51107 L .44008 .5132 L p .707 .577 .707 r
F P
0 g
s
.47459 .645 m .47967 .66331 L .45971 .66478 L p .707 .577 .707 r
F P
0 g
s
.45971 .66478 m .45463 .64647 L .47459 .645 L p .707 .577 .707 r
F P
0 g
s
.37667 .56718 m .37708 .51164 L .40891 .51107 L p .707 .577 .707 r
F P
0 g
s
.37708 .51164 m .37667 .56718 L .34729 .57039 L p .707 .577 .707 r
F P
0 g
s
.34172 .58956 m .34026 .62643 L .31622 .6315 L p .707 .577 .707 r
F P
0 g
s
.40891 .51107 m .40851 .56661 L .37667 .56718 L p .707 .577 .707 r
F P
0 g
s
.46148 .59621 m .46002 .63308 L .43258 .62744 L p .707 .577 .707 r
F P
0 g
s
.43258 .62744 m .43405 .59057 L .46148 .59621 L p .707 .577 .707 r
F P
0 g
s
.34026 .62643 m .34172 .58956 L .37109 .58708 L p .707 .577 .707 r
F P
0 g
s
.32075 .70411 m .31567 .6858 L .33916 .67611 L p .707 .577 .707 r
F P
0 g
s
.33916 .67611 m .34425 .69442 L .32075 .70411 L p .707 .577 .707 r
F P
0 g
s
.43405 .59057 m .43258 .62744 L .40143 .62429 L p .707 .577 .707 r
F P
0 g
s
.40143 .62429 m .4029 .58742 L .43405 .59057 L p .707 .577 .707 r
F P
0 g
s
.45463 .64647 m .45971 .66478 L .43346 .66917 L p .707 .577 .707 r
F P
0 g
s
.43346 .66917 m .42838 .65086 L .45463 .64647 L p .707 .577 .707 r
F P
0 g
s
.37109 .58708 m .36962 .62394 L .34026 .62643 L p .707 .577 .707 r
F P
0 g
s
.36962 .62394 m .37109 .58708 L .4029 .58742 L p .707 .577 .707 r
F P
0 g
s
.4029 .58742 m .40143 .62429 L .36962 .62394 L p .707 .577 .707 r
F P
0 g
s
.34425 .69442 m .33916 .67611 L .36768 .66644 L p .707 .577 .707 r
F P
0 g
s
.36768 .66644 m .37276 .68475 L .34425 .69442 L p .707 .577 .707 r
F P
0 g
s
.42838 .65086 m .43346 .66917 L .4035 .67605 L p .707 .577 .707 r
F P
0 g
s
.4035 .67605 m .39842 .65774 L .42838 .65086 L p .707 .577 .707 r
F P
0 g
s
.37276 .68475 m .36768 .66644 L .39842 .65774 L p .707 .577 .707 r
F P
0 g
s
.39842 .65774 m .4035 .67605 L .37276 .68475 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0000G
0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0006Eoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
00=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH0001UOol005ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000IGoo001KOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol005Uoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Egoo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol005Eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000AOolA0013
Ool005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH8000kOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007Ool400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=Goo001EOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0017oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P00<Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000Woo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00<7oo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`00;Woo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHG0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00EGoo00<0
05YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo001EOol00`00FUH00003
FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60003FUH01000FUIJEUYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF0P00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH80002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol20002FUH00`00FUIJEP03FUH70003FUH00`00
FUIJEP02FUH?0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000/Ool005Eoo`80009JEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000IJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
02aoo`00EGoo0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF10000eYF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00
EWoo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000`0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo0010OolB
0003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool003Yoo`H000AJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03
001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF008002aoo`00=goo
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF1@0015YF00<005YFFUH00P00;7oo000dOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`000UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00AJEP00FUIJEP8002aoo`00<Woo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2
000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
02aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEQ40009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF009JEP<002aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEPT0
009JEP03001JEUYF00AJEP<000AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF
20000eYF00<005YFFUH01eYF00@005YFFUIJEPH000EJEP03001JEUYF00=JEP03001JEUYF009JEP<0
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF1@001EYF00<005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH010000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF009JEP03001JEP00
02aoo`00;Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF001JEP8000AJEP<000=JEP03001JEP00009JEP03001JEUYF00=JEPD000IJ
EP03001JEUYF00AJEP@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF000000001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF0P00;Goo000^Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00
FUH00000FUH000EJEP03001JEP0000<00005FUH005YFFUH00005FUH50006FUH00`00FUIJEP08FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH000030004FUH2000]Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03
001JEUYF00=JEPH000EJEP<000MJEP03001JEUYF00P0009JEP<000=JEP8000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP8002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF
2`0000=JEP0000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP03FUH01000FUIJ
EUYF10000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEPD000EJEP03001JEUYF00=JEP03001JEUYF00@0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF0080
0003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH00UYF5P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF1P00
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00;Woo00<005YF00000eYF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF100000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEQL000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF00MJEP04
001JEUYFFUH70003FUH40004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEP0000<000AJEP03001JEUYF008000Moo`<000Aoo`P000AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002ioo`03001JEP00009JEP03001JEUYF009JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP800003
FUH005YF00QJEP03001JEUYF00AJEPL00005FUH00000FUH00004FUH01000FUIJEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH400000eYF001JEP04
FUH00`00FUIJEP020006Ool5000;Ool60004FUH01P00FUIJEP00FUH002eoo`00;Woo00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
0000100000AJEP00000000=JEP03001JEUYF00MJEP03001JEUYF00@000IJEP8000=JEP03001JEUYF
00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00
FUH00P0015YF0`0015YF00<005YFFUH00P001Woo1@004Goo0`0000MJEP00FUIJEP00FUH0000]Ool0
02ioo`05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP02FUH30006
FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00800003FUH005YF00AJEP03001JEP0000@0009JEP8000Ioo`D0011oo`H0009JEP03001J
EP0002eoo`00;Woo0P000UYF00<005YFFUH00eYF60000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH01eYF00<005YFFUH0400000=JEP00FUH01UYF00@005YF000000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00=JEPL000Eoo`<000Yoo`L000=JEP05001JEUYF001JEP02000^Ool002ioo`80009JEP03001JEUYF
00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP<000=JEP03001JEUYF
00EJEP@0009JEPD000AJEP<000AJEP03001JEUYF00AJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF009JEQ800003FUH0000000h002ioo`00;Woo0P000UYF0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF009JEP800003FUH005YF00=J
EPT000MJEP03001JEUYF009JEP<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEPH000=JEP03001JEUYF00=JEP03001JEUYF00@002ioo`00;goo0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`001eYF00<005YF00000`00
0UYF00<005YFFUH00UYF1@000UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP04FUH20003FUH01@00FUIJEP00FUH0
1`000eYF00<005YFFUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00;Woo000]Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP02FUH2000015YF000005YF1P0000=JEP00FUH025YF00<005YFFUH00UYF0`001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=J
EP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00@005YF0000009JEPH0
00IJEP03001JEUYF00IJEP03001JEP00008000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000_Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003
FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P00
0eYF00<005YFFUH015YF00<005YF00000`001eYF00<005YFFUH01EYF1`000eYF00<005YFFUH00eYF
00<005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0P0000=JEP00FUH00eYF10000UYF
00<005YFFUH01eYF00<005YFFUH010001UYF00<005YF00000P001EYF00<005YF0000;goo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUH000050006FUH00`00FUIJEP06FUH400000eYF001JEP07FUH20003FUH00`00
FUIJEP02FUH2000`Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJ
EP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000=JEP03001JEUYF00<000UJEP03001JEUYF009JEP@000AJEP03001JEUYF
009JEP@000EJEP05001JEUYFFUH0000bOol002aoo`03001JEP0000=JEP04001JEUYFFUH8000AOol7
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUIJEP06FUH00`00FUH0000?0002FUH00`00FUIJ
EP05FUH3000cOol002aoo`03001JEP0000=JEP@0019oo`<000Yoo`800003FUH005YF00AJEP03001J
EP0000<00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000@000EJEP03001JEUYF00EJEP<000=oo`T000IJEP03001JEUYF00AJEP8003Eoo`00;7oo00@0
05YF001JEP8000AJEP<000ioo`D000]oo`T00003FUH005YF009JEP80009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00=JEP8000Ioo`D00003
FUH005YF00QJEP04001JEUYFFUH2000gOol002aoo`06001JEP00001JEP001EYF00<005YF00000`00
2Woo1@004Goo0`0000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00<005YFFUH01EYF00<005YF00000`001goo10000eYF00<005YFFUH01UYF00@0
05YF000003Uoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1P0017oo1@002Goo2000
0UYF0`000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH00eYF0`0000=JEP00000017oo10001eYF00<005YFFUH01EYF0`00>goo000/Ool2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0004FUH01000FUIJEUYF1000
00AJEP00001JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00
FUH00003000015YF000000000Woo10000UYF00<005YFFUH01eYF00<005YFFUH01000?Woo000/Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH60002FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP00
0UYF00<005YFFUH00UYF0P0015YF1P001UYF00<005YFFUH01UYF1000@Woo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YFFUIJEPL0
00=JEP03001JEUYF00MJEP03001JEUYF009JEP<004Ioo`00;Goo00@005YFFUH000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00IJEP03001JEUYF00=JEP03001J
EUYF00800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH=000;FUH90008FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YF00000P00BGoo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60006FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001JEUYF
00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3001<Ool002moo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH4000015YF000000000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`001eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF0P001UYF
00<005YFFUH01EYF00<005YFFUH01000Cgoo000`Ool20004FUH00`00FUIJEP05FUH00`00FUH00003
0006FUH00`00FUIJEP07FUH01000FUIJEUYF1`000eYF1@000UYF00<005YFFUH00eYF00<005YF0000
0`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF009JEPH005=oo`00<Woo0`0000=JEP00FUH0
1UYF0P0000=JEP00FUH025YF00<005YFFUH015YF1`0000EJEP00001JEP0000AJEP03001JEUYF0080
009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP@000AJEP800003FUH005YF009JEPL0009JEP03001JEP0005Ao
o`00=Goo0`000eYF0`000eYF00<005YFFUH01eYF00<005YFFUH010001UYF0P000eYF00<005YFFUH0
0eYF0P0000Eoo`00FUIJEP0000=JEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0000400000goo
00000003FUH01P00FUIJEP00FUH005Aoo`00>7oo0`001eYF00<005YFFUH015YF1@000UYF00<005YF
FUH00UYF0`001UYF00@005YFFUIJEP80009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3
00000eYF001oo`04Ool400001eYF001JEUYF001JEP0005Aoo`00=Woo0P0000=JEP00FUH01eYF00<0
05YFFUH01`0015YF00<005YFFUH00P0000=JEP00FUH01UYF00@005YF000000Aoo`03001JEUYF0080
0003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000@000=JEP<0009JEP8005Eoo`00=7oo
0P000eYF00<005YFFUH01EYF10000Woo300015YF00<005YFFUH015YF0P001Woo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000003P00EGoo000bOol20006FUH00`00FUIJ
EP02FUH20006Ool90007FUH00`00FUIJEP02FUH20008Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01000EGoo000`Ool30007FUH00`00
FUH000020008Ool50002FUH00`00FUIJEP07FUH01000FUH000002Woo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00@005YF000000=JEP03001JEUYF009JEP04001JEUYFFUH3001EOol002ioo`80
00=JEP03001JEUYF00AJEP8000Qoo`L000=JEP03001JEUYF00IJEP<000aoo`8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP03FUH01P00FUIJEP00FUH005Eoo`00
;Goo0P0015YF00<005YFFUH00UYF0P001Woo100000=JEP00FUH025YF00<005YFFUH00UYF0`0047oo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH00UYF
00@005YFFUIJEP8005Eoo`00;7oo00<005YF00001EYF00@005YF0000009oo`H000IJEP03001JEUYF
00IJEP03001JEP00008001=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJ
EP/005Ioo`00;7oo00@005YFFUH000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00EJEP<001Mo
o`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP@0009JEP03001JEUYF009JEP04001J
EUYF001FOol002aoo`05001JEUYF001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04000LOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF1P000UYF00<005YF00000P001EYF00<005YF0000EWoo
000]Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH015YF1@008Woo0P001UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
00000`001UYF0P000eYF00<005YFFUH00UYF0P00Egoo000]Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04000YOol20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH400000eYF001JEP03FUH40005FUH00`00FUIJEP02FUH0
0`00Oomoo`1FOol002eoo`05001JEUYFFUH00004FUH00`00FUIJEP04FUH4000_Ool300000eYF001J
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0?0002FUH00`00
FUIJEP05FUH01000FUH00000FGoo000]Ool20002FUH00`00FUIJEP03FUH00`00FUH00003000fOol4
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool90006FUH00`00FUIJ
EP04FUH3001KOol002ioo`/003ioo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00L000Ioo`D00003FUH005YF00QJEP04001JEUYFFUH2001NOol007eoob000004FUH000000008Ool5
0002FUH00`00FUIJEP06FUH01000FUH00000H7oo002?Ool00`00FUIJEP02FUH00`00FUIJEP04FUH3
0007Ool4000015YF000000000eYF00<005YFFUH01EYF0`00HWoo002>Ool20005FUH01000FUIJEUYF
0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo002=Ool01000FUIJEP0015YF
00@005YF0000009oo`H000IJEP03001JEUYF00MJEP03001JEP00008006Moo`00SGoo00@005YFFUH0
00AJEPH000=JEP03001JEUYF00MJEP03001JEUYF00AJEP@006Yoo`00SWoo00D005YFFUH005YF0080
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006ioo`00SWoo00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH01EYF1000LWoo002?Ool015YF001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01000MWoo002?Ool01000FUIJEP001EYF00<005YFFUH00UYF1P00NWoo002?Ool2
0002FUH00`00FUIJEP070020Ool0095oo`D008Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]36\[InvisibleSpace]"     "\
\[InvisibleSpace]11.328523591985396`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 36, "     ", 11.328523591985396, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60091 .74909 m .60071 .69353 L .56955 .6917 L p .707 .577 .707 r
F P
0 g
s
.60071 .69353 m .60091 .74909 L .63275 .74822 L p .707 .577 .707 r
F P
0 g
s
.63275 .74822 m .63255 .69266 L .60071 .69353 L p .707 .577 .707 r
F P
0 g
s
.63255 .69266 m .63275 .74822 L .66216 .74474 L p .707 .577 .707 r
F P
0 g
s
.66216 .74474 m .66196 .68918 L .63255 .69266 L p .707 .577 .707 r
F P
0 g
s
.56975 .74726 m .56955 .6917 L .54213 .68736 L p .707 .577 .707 r
F P
0 g
s
.56955 .6917 m .56975 .74726 L .60091 .74909 L p .707 .577 .707 r
F P
0 g
s
.66196 .68918 m .66216 .74474 L .68625 .73899 L p .707 .577 .707 r
F P
0 g
s
.68625 .73899 m .68605 .68343 L .66196 .68918 L p .707 .577 .707 r
F P
0 g
s
.5935 .80827 m .59494 .77108 L .56381 .76813 L p .707 .577 .707 r
F P
0 g
s
.59494 .77108 m .5935 .80827 L .62532 .80872 L p .707 .577 .707 r
F P
0 g
s
.62532 .80872 m .62676 .77153 L .59494 .77108 L p .707 .577 .707 r
F P
0 g
s
.62676 .77153 m .62532 .80872 L .65473 .80662 L p .707 .577 .707 r
F P
0 g
s
.65473 .80662 m .65617 .76944 L .62676 .77153 L p .707 .577 .707 r
F P
0 g
s
.54213 .68736 m .54232 .74292 L .56975 .74726 L p .707 .577 .707 r
F P
0 g
s
.54232 .74292 m .54213 .68736 L .52112 .68093 L p .707 .577 .707 r
F P
0 g
s
.56237 .80532 m .56381 .76813 L .53643 .76297 L p .707 .577 .707 r
F P
0 g
s
.56381 .76813 m .56237 .80532 L .5935 .80827 L p .707 .577 .707 r
F P
0 g
s
.65617 .76944 m .65473 .80662 L .67884 .80219 L p .707 .577 .707 r
F P
0 g
s
.67884 .80219 m .68028 .76501 L .65617 .76944 L p .707 .577 .707 r
F P
0 g
s
.68605 .68343 m .68625 .73899 L .70267 .73154 L p .707 .577 .707 r
F P
0 g
s
.70267 .73154 m .70247 .67598 L .68605 .68343 L p .707 .577 .707 r
F P
0 g
s
.53643 .76297 m .53499 .80016 L .56237 .80532 L p .707 .577 .707 r
F P
0 g
s
.62456 .85548 m .61953 .83828 L .58878 .84702 L p .707 .577 .707 r
F P
0 g
s
.61953 .83828 m .62456 .85548 L .65298 .84367 L p .707 .577 .707 r
F P
0 g
s
.65298 .84367 m .64795 .82647 L .61953 .83828 L p .707 .577 .707 r
F P
0 g
s
.52112 .68093 m .52131 .73649 L .54232 .74292 L p .707 .577 .707 r
F P
0 g
s
.59382 .86423 m .58878 .84702 L .55874 .85185 L p .707 .577 .707 r
F P
0 g
s
.58878 .84702 m .59382 .86423 L .62456 .85548 L p .707 .577 .707 r
F P
0 g
s
.53499 .80016 m .53643 .76297 L .51547 .75611 L p .707 .577 .707 r
F P
0 g
s
.55874 .85185 m .56377 .86905 L .59382 .86423 L p .707 .577 .707 r
F P
0 g
s
.52131 .73649 m .52112 .68093 L .50858 .67304 L p .707 .577 .707 r
F P
0 g
s
.64795 .82647 m .65298 .84367 L .67631 .82996 L p .707 .577 .707 r
F P
0 g
s
.67631 .82996 m .67128 .81275 L .64795 .82647 L p .707 .577 .707 r
F P
0 g
s
.56377 .86905 m .55874 .85185 L .53232 .85228 L p .707 .577 .707 r
F P
0 g
s
.51547 .75611 m .51403 .7933 L .53499 .80016 L p .707 .577 .707 r
F P
0 g
s
.68028 .76501 m .67884 .80219 L .69529 .79586 L p .707 .577 .707 r
F P
0 g
s
.69529 .79586 m .69673 .75867 L .68028 .76501 L p .707 .577 .707 r
F P
0 g
s
.53232 .85228 m .53735 .86949 L .56377 .86905 L p .707 .577 .707 r
F P
0 g
s
.70247 .67598 m .70267 .73154 L .70981 .72311 L p .707 .577 .707 r
F P
0 g
s
.70981 .72311 m .70961 .66755 L .70247 .67598 L p .707 .577 .707 r
F P
0 g
s
.50858 .67304 m .50877 .7286 L .52131 .73649 L p .707 .577 .707 r
F P
0 g
s
.67128 .81275 m .67631 .82996 L .69225 .81568 L p .707 .577 .707 r
F P
0 g
s
.69225 .81568 m .68722 .79848 L .67128 .81275 L p .707 .577 .707 r
F P
0 g
s
.51403 .7933 m .51547 .75611 L .50299 .74822 L p .707 .577 .707 r
F P
0 g
s
.53735 .86949 m .53232 .85228 L .51212 .84828 L p .707 .577 .707 r
F P
0 g
s
.51212 .84828 m .51715 .86549 L .53735 .86949 L p .707 .577 .707 r
F P
0 g
s
.50877 .7286 m .50858 .67304 L .50574 .66446 L p .707 .577 .707 r
F P
0 g
s
.50299 .74822 m .50155 .78541 L .51403 .7933 L p .707 .577 .707 r
F P
0 g
s
.69673 .75867 m .69529 .79586 L .70248 .78825 L p .707 .577 .707 r
F P
0 g
s
.70248 .78825 m .70392 .75106 L .69673 .75867 L p .707 .577 .707 r
F P
0 g
s
.68722 .79848 m .69225 .81568 L .69925 .80224 L p .707 .577 .707 r
F P
0 g
s
.69925 .80224 m .69422 .78503 L .68722 .79848 L p .707 .577 .707 r
F P
0 g
s
.50574 .66446 m .50594 .72002 L .50877 .7286 L p .707 .577 .707 r
F P
0 g
s
.51715 .86549 m .51212 .84828 L .50012 .84024 L p .707 .577 .707 r
F P
0 g
s
.70961 .66755 m .70981 .72311 L .70697 .71453 L p .707 .577 .707 r
F P
0 g
s
.70697 .71453 m .70678 .65897 L .70961 .66755 L p .707 .577 .707 r
F P
0 g
s
.50155 .78541 m .50299 .74822 L .50021 .74006 L p .707 .577 .707 r
F P
0 g
s
.50012 .84024 m .50515 .85745 L .51715 .86549 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.50021 .74006 m .49877 .77725 L .50155 .78541 L p .707 .577 .707 r
F P
0 g
s
.50594 .72002 m .50574 .66446 L .51288 .65604 L p .707 .577 .707 r
F P
0 g
s
.51288 .65604 m .51308 .7116 L .50594 .72002 L p .707 .577 .707 r
F P
0 g
s
.49877 .77725 m .50021 .74006 L .5074 .73245 L p .707 .577 .707 r
F P
0 g
s
.5074 .73245 m .50596 .76963 L .49877 .77725 L p .707 .577 .707 r
F P
0 g
s
.51308 .7116 m .51288 .65604 L .5293 .64858 L p .707 .577 .707 r
F P
0 g
s
.50252 .84616 m .49749 .82895 L .50449 .81551 L p .707 .577 .707 r
F P
0 g
s
.5293 .64858 m .5295 .70414 L .51308 .7116 L p .707 .577 .707 r
F P
0 g
s
.50596 .76963 m .5074 .73245 L .52385 .72611 L p .707 .577 .707 r
F P
0 g
s
.50449 .81551 m .50952 .83271 L .50252 .84616 L p .707 .577 .707 r
F P
0 g
s
.52385 .72611 m .52241 .7633 L .50596 .76963 L p .707 .577 .707 r
F P
0 g
s
.50952 .83271 m .50449 .81551 L .52044 .80123 L p .707 .577 .707 r
F P
0 g
s
.52241 .7633 m .52385 .72611 L .54796 .72168 L p .707 .577 .707 r
F P
0 g
s
.52044 .80123 m .52547 .81843 L .50952 .83271 L p .707 .577 .707 r
F P
0 g
s
.54796 .72168 m .54652 .75887 L .52241 .7633 L p .707 .577 .707 r
F P
0 g
s
.52547 .81843 m .52044 .80123 L .54376 .78752 L p .707 .577 .707 r
F P
0 g
s
.54376 .78752 m .54879 .80472 L .52547 .81843 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53822 .82054 L p .707 .577 .707 r
F P
0 g
s
.5295 .70414 m .5293 .64858 L .55339 .64284 L p .707 .577 .707 r
F P
0 g
s
.55339 .64284 m .55359 .6984 L .5295 .70414 L p .707 .577 .707 r
F P
0 g
s
.53822 .82054 m .53822 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.55359 .6984 m .55339 .64284 L .5828 .63936 L p .707 .577 .707 r
F P
0 g
s
.5828 .63936 m .583 .69492 L .55359 .6984 L p .707 .577 .707 r
F P
0 g
s
.54652 .75887 m .54796 .72168 L .57737 .71959 L p .707 .577 .707 r
F P
0 g
s
.57737 .71959 m .57593 .75678 L .54652 .75887 L p .707 .577 .707 r
F P
0 g
s
.54879 .80472 m .54376 .78752 L .57219 .77571 L p .707 .577 .707 r
F P
0 g
s
.57219 .77571 m .57722 .79291 L .54879 .80472 L p .707 .577 .707 r
F P
0 g
s
.60293 .76696 m .60796 .78417 L .57722 .79291 L p .707 .577 .707 r
F P
0 g
s
.57722 .79291 m .57219 .77571 L .60293 .76696 L p .707 .577 .707 r
F P
0 g
s
.53822 .31865 m .53822 .82054 L .57933 .81554 L p .707 .577 .707 r
F P
0 g
s
.57593 .75678 m .57737 .71959 L .60919 .72004 L p .707 .577 .707 r
F P
0 g
s
.60919 .72004 m .60775 .75723 L .57593 .75678 L p .707 .577 .707 r
F P
0 g
s
.57933 .81554 m .57933 .31366 L .53822 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40994 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.70392 .75106 m .70248 .78825 L .69969 .78009 L p .707 .577 .707 r
F P
0 g
s
.69969 .78009 m .70113 .7429 L .70392 .75106 L p .707 .577 .707 r
F P
0 g
s
.69422 .78503 m .69925 .80224 L .69662 .79094 L p .707 .577 .707 r
F P
0 g
s
.69662 .79094 m .69159 .77374 L .69422 .78503 L p .707 .577 .707 r
F P
0 g
s
.50515 .85745 m .50012 .84024 L .49749 .82895 L p .707 .577 .707 r
F P
0 g
s
.70678 .65897 m .70697 .71453 L .69443 .70664 L p .707 .577 .707 r
F P
0 g
s
.69443 .70664 m .69424 .65108 L .70678 .65897 L p .707 .577 .707 r
F P
0 g
s
.583 .69492 m .5828 .63936 L .61464 .63849 L p .707 .577 .707 r
F P
0 g
s
.61464 .63849 m .61484 .69405 L .583 .69492 L p .707 .577 .707 r
F P
0 g
s
.64032 .72299 m .63888 .76018 L .60775 .75723 L p .707 .577 .707 r
F P
0 g
s
.60775 .75723 m .60919 .72004 L .64032 .72299 L p .707 .577 .707 r
F P
0 g
s
.63298 .76214 m .63801 .77934 L .60796 .78417 L p .707 .577 .707 r
F P
0 g
s
.60796 .78417 m .60293 .76696 L .63298 .76214 L p .707 .577 .707 r
F P
0 g
s
.57933 .31366 m .57933 .81554 L .61267 .80738 L p .707 .577 .707 r
F P
0 g
s
.61267 .80738 m .61267 .3055 L .57933 .31366 L p .707 .577 .707 r
F P
0 g
s
.25506 .71369 m .25498 .65805 L .22382 .6562 L p .707 .577 .707 r
F P
0 g
s
.25498 .65805 m .25506 .71369 L .2869 .71289 L p .707 .577 .707 r
F P
0 g
s
.2869 .71289 m .28682 .65726 L .25498 .65805 L p .707 .577 .707 r
F P
0 g
s
.49749 .82895 m .50252 .84616 L .50515 .85745 L p .707 .577 .707 r
F P
0 g
s
.28682 .65726 m .2869 .71289 L .31631 .70953 L p .707 .577 .707 r
F P
0 g
s
.31631 .70953 m .31622 .65389 L .28682 .65726 L p .707 .577 .707 r
F P
0 g
s
.40994 .81345 m .40994 .31156 L .37953 .30262 L p .707 .577 .707 r
F P
0 g
s
.40994 .31156 m .40994 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.2239 .71184 m .22382 .6562 L .19639 .65189 L p .707 .577 .707 r
F P
0 g
s
.22382 .6562 m .2239 .71184 L .25506 .71369 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31622 .65389 m .31631 .70953 L .3404 .70392 L p .707 .577 .707 r
F P
0 g
s
.3404 .70392 m .34031 .64829 L .31622 .65389 L p .707 .577 .707 r
F P
0 g
s
.69159 .77374 m .69662 .79094 L .68462 .7829 L p .707 .577 .707 r
F P
0 g
s
.68462 .7829 m .67959 .7657 L .69159 .77374 L p .707 .577 .707 r
F P
0 g
s
.70113 .7429 m .69969 .78009 L .68721 .7722 L p .707 .577 .707 r
F P
0 g
s
.68721 .7722 m .68865 .73501 L .70113 .7429 L p .707 .577 .707 r
F P
0 g
s
.19639 .65189 m .19647 .70752 L .2239 .71184 L p .707 .577 .707 r
F P
0 g
s
.19647 .70752 m .19639 .65189 L .17538 .64553 L p .707 .577 .707 r
F P
0 g
s
.69424 .65108 m .69443 .70664 L .67342 .70021 L p .707 .577 .707 r
F P
0 g
s
.67342 .70021 m .67323 .64466 L .69424 .65108 L p .707 .577 .707 r
F P
0 g
s
.6458 .64032 m .646 .69588 L .61484 .69405 L p .707 .577 .707 r
F P
0 g
s
.61484 .69405 m .61464 .63849 L .6458 .64032 L p .707 .577 .707 r
F P
0 g
s
.63801 .77934 m .63298 .76214 L .65939 .7617 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80738 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.25181 .77597 m .25243 .73934 L .22128 .73667 L p .707 .577 .707 r
F P
0 g
s
.25243 .73934 m .25181 .77597 L .28365 .77561 L p .707 .577 .707 r
F P
0 g
s
.28365 .77561 m .28427 .73897 L .25243 .73934 L p .707 .577 .707 r
F P
0 g
s
.28427 .73897 m .28365 .77561 L .31307 .77225 L p .707 .577 .707 r
F P
0 g
s
.31307 .77225 m .31369 .73562 L .28427 .73897 L p .707 .577 .707 r
F P
0 g
s
.34031 .64829 m .3404 .70392 L .35682 .69663 L p .707 .577 .707 r
F P
0 g
s
.35682 .69663 m .35673 .641 L .34031 .64829 L p .707 .577 .707 r
F P
0 g
s
.22066 .77331 m .22128 .73667 L .19388 .73125 L p .707 .577 .707 r
F P
0 g
s
.22128 .73667 m .22066 .77331 L .25181 .77597 L p .707 .577 .707 r
F P
0 g
s
.37953 .8045 m .37953 .30262 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37953 .30262 m .37953 .8045 L .40994 .81345 L p .707 .577 .707 r
F P
0 g
s
.17538 .64553 m .17546 .70117 L .19647 .70752 L p .707 .577 .707 r
F P
0 g
s
.31369 .73562 m .31307 .77225 L .33719 .76624 L p .707 .577 .707 r
F P
0 g
s
.33719 .76624 m .33781 .7296 L .31369 .73562 L p .707 .577 .707 r
F P
0 g
s
.67959 .7657 m .68462 .7829 L .66442 .77891 L p .707 .577 .707 r
F P
0 g
s
.66442 .77891 m .65939 .7617 L .67959 .7657 L p .707 .577 .707 r
F P
0 g
s
.68865 .73501 m .68721 .7722 L .66626 .76534 L p .707 .577 .707 r
F P
0 g
s
.66626 .76534 m .6677 .72815 L .68865 .73501 L p .707 .577 .707 r
F P
0 g
s
.17546 .70117 m .17538 .64553 L .16284 .63776 L p .707 .577 .707 r
F P
0 g
s
.19388 .73125 m .19326 .76788 L .22066 .77331 L p .707 .577 .707 r
F P
0 g
s
.25294 .78809 m .25074 .76898 L .21973 .7725 L p .707 .577 .707 r
F P
0 g
s
.25074 .76898 m .25294 .78809 L .28455 .78443 L p .707 .577 .707 r
F P
0 g
s
.28455 .78443 m .28235 .76532 L .25074 .76898 L p .707 .577 .707 r
F P
0 g
s
.21973 .7725 m .22193 .79161 L .25294 .78809 L p .707 .577 .707 r
F P
0 g
s
.67323 .64466 m .67342 .70021 L .646 .69588 L p .707 .577 .707 r
F P
0 g
s
.646 .69588 m .6458 .64032 L .67323 .64466 L p .707 .577 .707 r
F P
0 g
s
.28235 .76532 m .28455 .78443 L .31366 .78098 L p .707 .577 .707 r
F P
0 g
s
.31366 .78098 m .31146 .76187 L .28235 .76532 L p .707 .577 .707 r
F P
0 g
s
.19326 .76788 m .19388 .73125 L .17291 .72358 L p .707 .577 .707 r
F P
0 g
s
.22193 .79161 m .21973 .7725 L .19235 .77553 L p .707 .577 .707 r
F P
0 g
s
.19235 .77553 m .19455 .79463 L .22193 .79161 L p .707 .577 .707 r
F P
0 g
s
.16284 .63776 m .16292 .69339 L .17546 .70117 L p .707 .577 .707 r
F P
0 g
s
.35673 .641 m .35682 .69663 L .36396 .68836 L p .707 .577 .707 r
F P
0 g
s
.36396 .68836 m .36388 .63273 L .35673 .641 L p .707 .577 .707 r
F P
0 g
s
.31146 .76187 m .31366 .78098 L .33743 .77808 L p .707 .577 .707 r
F P
0 g
s
.33743 .77808 m .33523 .75897 L .31146 .76187 L p .707 .577 .707 r
F P
0 g
s
.17291 .72358 m .17229 .76022 L .19326 .76788 L p .707 .577 .707 r
F P
0 g
s
.33781 .7296 m .33719 .76624 L .35365 .75815 L p .707 .577 .707 r
F P
0 g
s
.35365 .75815 m .35426 .72151 L .33781 .7296 L p .707 .577 .707 r
F P
0 g
s
.65939 .7617 m .66442 .77891 L .63801 .77934 L p .707 .577 .707 r
F P
0 g
s
.6677 .72815 m .66626 .76534 L .63888 .76018 L p .707 .577 .707 r
F P
0 g
s
.63888 .76018 m .64032 .72299 L .6677 .72815 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.19455 .79463 m .19235 .77553 L .17129 .77776 L p .707 .577 .707 r
F P
0 g
s
.17129 .77776 m .17349 .79687 L .19455 .79463 L p .707 .577 .707 r
F P
0 g
s
.17229 .76022 m .17291 .72358 L .16041 .71444 L p .707 .577 .707 r
F P
0 g
s
.16292 .69339 m .16284 .63776 L .16 .62932 L p .707 .577 .707 r
F P
0 g
s
.35426 .72151 m .35365 .75815 L .36083 .74878 L p .707 .577 .707 r
F P
0 g
s
.36083 .74878 m .36145 .71214 L .35426 .72151 L p .707 .577 .707 r
F P
0 g
s
.36145 .71214 m .36083 .74878 L .35804 .73905 L p .707 .577 .707 r
F P
0 g
s
.35804 .73905 m .35865 .70241 L .36145 .71214 L p .707 .577 .707 r
F P
0 g
s
.36104 .62429 m .36112 .67993 L .34858 .67215 L p .707 .577 .707 r
F P
0 g
s
.34858 .67215 m .3485 .61652 L .36104 .62429 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36388 .63273 m .36396 .68836 L .36112 .67993 L p .707 .577 .707 r
F P
0 g
s
.36112 .67993 m .36104 .62429 L .36388 .63273 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37953 .8045 L p .707 .577 .707 r
F P
0 g
s
.33523 .75897 m .33743 .77808 L .35352 .77601 L p .707 .577 .707 r
F P
0 g
s
.35352 .77601 m .35132 .75691 L .33523 .75897 L p .707 .577 .707 r
F P
0 g
s
.16041 .71444 m .1598 .75107 L .17229 .76022 L p .707 .577 .707 r
F P
0 g
s
.16 .62932 m .16009 .68496 L .16292 .69339 L p .707 .577 .707 r
F P
0 g
s
.17349 .79687 m .17129 .77776 L .1586 .779 L p .707 .577 .707 r
F P
0 g
s
.1586 .779 m .1608 .7981 L .17349 .79687 L p .707 .577 .707 r
F P
0 g
s
.1598 .75107 m .16041 .71444 L .15762 .7047 L p .707 .577 .707 r
F P
0 g
s
.16009 .68496 m .16 .62932 L .16714 .62105 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77296 L p .707 .577 .707 r
F P
0 g
s
.63909 .77296 m .63909 .27107 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.35132 .75691 m .35352 .77601 L .36037 .77498 L p .707 .577 .707 r
F P
0 g
s
.36037 .77498 m .35817 .75588 L .35132 .75691 L p .707 .577 .707 r
F P
0 g
s
.15762 .7047 m .157 .74134 L .1598 .75107 L p .707 .577 .707 r
F P
0 g
s
.35817 .75588 m .36037 .77498 L .3573 .77509 L p .707 .577 .707 r
F P
0 g
s
.3573 .77509 m .3551 .75598 L .35817 .75588 L p .707 .577 .707 r
F P
0 g
s
.35865 .70241 m .35804 .73905 L .34554 .7299 L p .707 .577 .707 r
F P
0 g
s
.34554 .7299 m .34616 .69326 L .35865 .70241 L p .707 .577 .707 r
F P
0 g
s
.3551 .75598 m .3573 .77509 L .34461 .77632 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.16714 .62105 m .16723 .67669 L .16009 .68496 L p .707 .577 .707 r
F P
0 g
s
.1608 .7981 m .1586 .779 L .15553 .7791 L p .707 .577 .707 r
F P
0 g
s
.15553 .7791 m .15773 .79821 L .1608 .7981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.157 .74134 m .15762 .7047 L .1648 .69533 L p .707 .577 .707 r
F P
0 g
s
.16723 .67669 m .16714 .62105 L .18356 .61376 L p .707 .577 .707 r
F P
0 g
s
.1648 .69533 m .16419 .73197 L .157 .74134 L p .707 .577 .707 r
F P
0 g
s
.63909 .27107 m .63909 .77296 L .62047 .76193 L p .707 .577 .707 r
F P
0 g
s
.62047 .76193 m .62047 .26004 L .63909 .27107 L p .707 .577 .707 r
F P
0 g
s
.18356 .61376 m .18365 .6694 L .16723 .67669 L p .707 .577 .707 r
F P
0 g
s
.3485 .61652 m .34858 .67215 L .32757 .66579 L p .707 .577 .707 r
F P
0 g
s
.32757 .66579 m .32749 .61016 L .3485 .61652 L p .707 .577 .707 r
F P
0 g
s
.15773 .79821 m .15553 .7791 L .16238 .77807 L p .707 .577 .707 r
F P
0 g
s
.16238 .77807 m .16458 .79718 L .15773 .79821 L p .707 .577 .707 r
F P
0 g
s
.18365 .6694 m .18356 .61376 L .20766 .60816 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38732 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.16419 .73197 m .1648 .69533 L .18126 .68724 L p .707 .577 .707 r
F P
0 g
s
.18126 .68724 m .18064 .72388 L .16419 .73197 L p .707 .577 .707 r
F P
0 g
s
.32749 .61016 m .32757 .66579 L .30015 .66148 L p .707 .577 .707 r
F P
0 g
s
.30015 .66148 m .30006 .60585 L .32749 .61016 L p .707 .577 .707 r
F P
0 g
s
.34461 .77632 m .34241 .75722 L .3551 .75598 L p .707 .577 .707 r
F P
0 g
s
.20766 .60816 m .20774 .66379 L .18365 .6694 L p .707 .577 .707 r
F P
0 g
s
.34616 .69326 m .34554 .7299 L .32457 .72224 L p .707 .577 .707 r
F P
0 g
s
.32457 .72224 m .32519 .6856 L .34616 .69326 L p .707 .577 .707 r
F P
0 g
s
.20774 .66379 m .20766 .60816 L .23706 .60479 L p .707 .577 .707 r
F P
0 g
s
.16458 .79718 m .16238 .77807 L .17847 .77601 L p .707 .577 .707 r
F P
0 g
s
.17847 .77601 m .18067 .79511 L .16458 .79718 L p .707 .577 .707 r
F P
0 g
s
.18064 .72388 m .18126 .68724 L .20538 .68123 L p .707 .577 .707 r
F P
0 g
s
.62047 .26004 m .62047 .76193 L .59006 .75298 L p .707 .577 .707 r
F P
0 g
s
.59006 .75298 m .59006 .2511 L .62047 .26004 L p .707 .577 .707 r
F P
0 g
s
.30006 .60585 m .30015 .66148 L .26899 .65963 L p .707 .577 .707 r
F P
0 g
s
.26899 .65963 m .2689 .604 L .30006 .60585 L p .707 .577 .707 r
F P
0 g
s
.23715 .66043 m .23706 .60479 L .2689 .604 L p .707 .577 .707 r
F P
0 g
s
.23706 .60479 m .23715 .66043 L .20774 .66379 L p .707 .577 .707 r
F P
0 g
s
.2689 .604 m .26899 .65963 L .23715 .66043 L p .707 .577 .707 r
F P
0 g
s
.38732 .25716 m .38732 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38732 .75905 m .38732 .25716 L .42067 .249 L p .707 .577 .707 r
F P
0 g
s
.20538 .68123 m .20476 .71787 L .18064 .72388 L p .707 .577 .707 r
F P
0 g
s
.32519 .6856 m .32457 .72224 L .29717 .71681 L p .707 .577 .707 r
F P
0 g
s
.29717 .71681 m .29779 .68017 L .32519 .6856 L p .707 .577 .707 r
F P
0 g
s
.34241 .75722 m .34461 .77632 L .32355 .77856 L p .707 .577 .707 r
F P
0 g
s
.32355 .77856 m .32135 .75945 L .34241 .75722 L p .707 .577 .707 r
F P
0 g
s
.73101 .65644 m .7311 .60091 L .69994 .59893 L p .707 .577 .707 r
F P
0 g
s
.7311 .60091 m .73101 .65644 L .76285 .65572 L p .707 .577 .707 r
F P
0 g
s
.76285 .65572 m .76294 .60019 L .7311 .60091 L p .707 .577 .707 r
F P
0 g
s
.20476 .71787 m .20538 .68123 L .2348 .67788 L p .707 .577 .707 r
F P
0 g
s
.76294 .60019 m .76285 .65572 L .79226 .65235 L p .707 .577 .707 r
F P
0 g
s
.79226 .65235 m .79234 .59682 L .76294 .60019 L p .707 .577 .707 r
F P
0 g
s
.18067 .79511 m .17847 .77601 L .20224 .77311 L p .707 .577 .707 r
F P
0 g
s
.20224 .77311 m .20444 .79221 L .18067 .79511 L p .707 .577 .707 r
F P
0 g
s
.69985 .65446 m .69994 .59893 L .67251 .59443 L p .707 .577 .707 r
F P
0 g
s
.69994 .59893 m .69985 .65446 L .73101 .65644 L p .707 .577 .707 r
F P
0 g
s
.29779 .68017 m .29717 .71681 L .26602 .71415 L p .707 .577 .707 r
F P
0 g
s
.26602 .71415 m .26664 .67751 L .29779 .68017 L p .707 .577 .707 r
F P
0 g
s
.2348 .67788 m .23418 .71451 L .20476 .71787 L p .707 .577 .707 r
F P
0 g
s
.23418 .71451 m .2348 .67788 L .26664 .67751 L p .707 .577 .707 r
F P
0 g
s
.59006 .2511 m .59006 .75298 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59006 .2511 L p .707 .577 .707 r
F P
0 g
s
.79234 .59682 m .79226 .65235 L .81635 .64668 L p .707 .577 .707 r
F P
0 g
s
.81635 .64668 m .81643 .59115 L .79234 .59682 L p .707 .577 .707 r
F P
0 g
s
.26664 .67751 m .26602 .71415 L .23418 .71451 L p .707 .577 .707 r
F P
0 g
s
.73397 .71481 m .73336 .6774 L .70221 .67622 L p .707 .577 .707 r
F P
0 g
s
.73336 .6774 m .73397 .71481 L .76581 .71367 L p .707 .577 .707 r
F P
0 g
s
.76581 .71367 m .7652 .67626 L .73336 .6774 L p .707 .577 .707 r
F P
0 g
s
.7652 .67626 m .76581 .71367 L .79523 .71031 L p .707 .577 .707 r
F P
0 g
s
.79523 .71031 m .79462 .6729 L .7652 .67626 L p .707 .577 .707 r
F P
0 g
s
.32135 .75945 m .32355 .77856 L .29617 .78159 L p .707 .577 .707 r
F P
0 g
s
.29617 .78159 m .29397 .76248 L .32135 .75945 L p .707 .577 .707 r
F P
0 g
s
.42067 .75089 m .42067 .249 L .46178 .24401 L p .707 .577 .707 r
F P
0 g
s
.42067 .249 m .42067 .75089 L .38732 .75905 L p .707 .577 .707 r
F P
0 g
s
.67251 .59443 m .67242 .64996 L .69985 .65446 L p .707 .577 .707 r
F P
0 g
s
.67242 .64996 m .67251 .59443 L .6515 .58786 L p .707 .577 .707 r
F P
0 g
s
.70283 .71363 m .70221 .67622 L .67481 .67283 L p .707 .577 .707 r
F P
0 g
s
.70221 .67622 m .70283 .71363 L .73397 .71481 L p .707 .577 .707 r
F P
0 g
s
.20444 .79221 m .20224 .77311 L .23135 .76966 L p .707 .577 .707 r
F P
0 g
s
.23135 .76966 m .23355 .78876 L .20444 .79221 L p .707 .577 .707 r
F P
0 g
s
.79462 .6729 m .79523 .71031 L .81935 .70507 L p .707 .577 .707 r
F P
0 g
s
.81935 .70507 m .81874 .66766 L .79462 .6729 L p .707 .577 .707 r
F P
0 g
s
.67481 .67283 m .67543 .71024 L .70283 .71363 L p .707 .577 .707 r
F P
0 g
s
.81643 .59115 m .81635 .64668 L .83277 .63925 L p .707 .577 .707 r
F P
0 g
s
.83277 .63925 m .83285 .58373 L .81643 .59115 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50663 .74455 L p .707 .577 .707 r
F P
0 g
s
.50663 .74455 m .50663 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.29397 .76248 m .29617 .78159 L .26516 .7851 L p .707 .577 .707 r
F P
0 g
s
.26516 .7851 m .26296 .766 L .29397 .76248 L p .707 .577 .707 r
F P
0 g
s
.73484 .78391 m .73704 .76748 L .70603 .76089 L p .707 .577 .707 r
F P
0 g
s
.73704 .76748 m .73484 .78391 L .76645 .78546 L p .707 .577 .707 r
F P
0 g
s
.76645 .78546 m .76864 .76903 L .73704 .76748 L p .707 .577 .707 r
F P
0 g
s
.6515 .58786 m .65141 .64339 L .67242 .64996 L p .707 .577 .707 r
F P
0 g
s
.67543 .71024 m .67481 .67283 L .65384 .66756 L p .707 .577 .707 r
F P
0 g
s
.46178 .7459 m .46178 .24401 L .50663 .24266 L p .707 .577 .707 r
F P
0 g
s
.46178 .24401 m .46178 .7459 L .42067 .75089 L p .707 .577 .707 r
F P
0 g
s
.23355 .78876 m .23135 .76966 L .26296 .766 L p .707 .577 .707 r
F P
0 g
s
.26296 .766 m .26516 .7851 L .23355 .78876 L p .707 .577 .707 r
F P
0 g
s
.70383 .77732 m .70603 .76089 L .67865 .74991 L p .707 .577 .707 r
F P
0 g
s
.70603 .76089 m .70383 .77732 L .73484 .78391 L p .707 .577 .707 r
F P
0 g
s
.76864 .76903 m .76645 .78546 L .79556 .78182 L p .707 .577 .707 r
F P
0 g
s
.79556 .78182 m .79776 .76539 L .76864 .76903 L p .707 .577 .707 r
F P
0 g
s
.50663 .24266 m .50663 .74455 L .46178 .7459 L p .707 .577 .707 r
F P
0 g
s
.65141 .64339 m .6515 .58786 L .63896 .57986 L p .707 .577 .707 r
F P
0 g
s
.65384 .66756 m .65445 .70497 L .67543 .71024 L p .707 .577 .707 r
F P
0 g
s
.81874 .66766 m .81935 .70507 L .83581 .69846 L p .707 .577 .707 r
F P
0 g
s
.83581 .69846 m .83519 .66104 L .81874 .66766 L p .707 .577 .707 r
F P
0 g
s
.67865 .74991 m .67645 .76634 L .70383 .77732 L p .707 .577 .707 r
F P
0 g
s
.67645 .76634 m .67865 .74991 L .65759 .73562 L p .707 .577 .707 r
F P
0 g
s
.79776 .76539 m .79556 .78182 L .81933 .77336 L p .707 .577 .707 r
F P
0 g
s
.81933 .77336 m .82152 .75693 L .79776 .76539 L p .707 .577 .707 r
F P
0 g
s
.83285 .58373 m .83277 .63925 L .83991 .6308 L p .707 .577 .707 r
F P
0 g
s
.83991 .6308 m .84 .57527 L .83285 .58373 L p .707 .577 .707 r
F P
0 g
s
.63896 .57986 m .63888 .63539 L .65141 .64339 L p .707 .577 .707 r
F P
0 g
s
.65445 .70497 m .65384 .66756 L .64134 .66093 L p .707 .577 .707 r
F P
0 g
s
.65759 .73562 m .65539 .75205 L .67645 .76634 L p .707 .577 .707 r
F P
0 g
s
.64134 .66093 m .64196 .69834 L .65445 .70497 L p .707 .577 .707 r
F P
0 g
s
.65539 .75205 m .65759 .73562 L .6449 .71941 L p .707 .577 .707 r
F P
0 g
s
.63888 .63539 m .63896 .57986 L .63612 .5712 L p .707 .577 .707 r
F P
0 g
s
.82152 .75693 m .81933 .77336 L .83542 .76089 L p .707 .577 .707 r
F P
0 g
s
.83542 .76089 m .83762 .74446 L .82152 .75693 L p .707 .577 .707 r
F P
0 g
s
.83519 .66104 m .83581 .69846 L .84299 .69112 L p .707 .577 .707 r
F P
0 g
s
.84299 .69112 m .84238 .65371 L .83519 .66104 L p .707 .577 .707 r
F P
0 g
s
.6449 .71941 m .6427 .73584 L .65539 .75205 L p .707 .577 .707 r
F P
0 g
s
.63612 .5712 m .63604 .62673 L .63888 .63539 L p .707 .577 .707 r
F P
0 g
s
.64196 .69834 m .64134 .66093 L .63855 .65359 L p .707 .577 .707 r
F P
0 g
s
.84 .57527 m .83991 .6308 L .83707 .62215 L p .707 .577 .707 r
F P
0 g
s
.83707 .62215 m .83716 .56662 L .84 .57527 L p .707 .577 .707 r
F P
0 g
s
.6427 .73584 m .6449 .71941 L .64183 .70287 L p .707 .577 .707 r
F P
0 g
s
.83762 .74446 m .83542 .76089 L .84227 .74563 L p .707 .577 .707 r
F P
0 g
s
.84227 .74563 m .84447 .7292 L .83762 .74446 L p .707 .577 .707 r
F P
0 g
s
.63855 .65359 m .63917 .691 L .64196 .69834 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63604 .62673 m .63612 .5712 L .64326 .56275 L p .707 .577 .707 r
F P
0 g
s
.84238 .65371 m .84299 .69112 L .8402 .68378 L p .707 .577 .707 r
F P
0 g
s
.8402 .68378 m .83959 .64636 L .84238 .65371 L p .707 .577 .707 r
F P
0 g
s
.64183 .70287 m .63963 .7193 L .6427 .73584 L p .707 .577 .707 r
F P
0 g
s
.64326 .56275 m .64318 .61828 L .63604 .62673 L p .707 .577 .707 r
F P
0 g
s
.63917 .691 m .63855 .65359 L .64574 .64625 L p .707 .577 .707 r
F P
0 g
s
.83716 .56662 m .83707 .62215 L .82454 .61415 L p .707 .577 .707 r
F P
0 g
s
.82454 .61415 m .82462 .55862 L .83716 .56662 L p .707 .577 .707 r
F P
0 g
s
.63963 .7193 m .64183 .70287 L .64867 .68762 L p .707 .577 .707 r
F P
0 g
s
.38516 .62104 m .38536 .56544 L .3542 .56343 L p .707 .577 .707 r
F P
0 g
s
.38536 .56544 m .38516 .62104 L .417 .62039 L p .707 .577 .707 r
F P
0 g
s
.417 .62039 m .4172 .56479 L .38536 .56544 L p .707 .577 .707 r
F P
0 g
s
.84447 .7292 m .84227 .74563 L .8392 .72909 L p .707 .577 .707 r
F P
0 g
s
.8392 .72909 m .8414 .71266 L .84447 .7292 L p .707 .577 .707 r
F P
0 g
s
.4172 .56479 m .417 .62039 L .44641 .61714 L p .707 .577 .707 r
F P
0 g
s
.44641 .61714 m .4466 .56154 L .4172 .56479 L p .707 .577 .707 r
F P
0 g
s
.64574 .64625 m .64635 .68367 L .63917 .691 L p .707 .577 .707 r
F P
0 g
s
.354 .61904 m .3542 .56343 L .32677 .55896 L p .707 .577 .707 r
F P
0 g
s
.3542 .56343 m .354 .61904 L .38516 .62104 L p .707 .577 .707 r
F P
0 g
s
.64867 .68762 m .64648 .70405 L .63963 .7193 L p .707 .577 .707 r
F P
0 g
s
.64318 .61828 m .64326 .56275 L .65968 .55532 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83959 .64636 m .8402 .68378 L .82771 .67715 L p .707 .577 .707 r
F P
0 g
s
.82771 .67715 m .82709 .63974 L .83959 .64636 L p .707 .577 .707 r
F P
0 g
s
.4466 .56154 m .44641 .61714 L .4705 .61161 L p .707 .577 .707 r
F P
0 g
s
.4705 .61161 m .47069 .55601 L .4466 .56154 L p .707 .577 .707 r
F P
0 g
s
.32677 .55896 m .32657 .61456 L .354 .61904 L p .707 .577 .707 r
F P
0 g
s
.32657 .61456 m .32677 .55896 L .30576 .55246 L p .707 .577 .707 r
F P
0 g
s
.39225 .68254 m .39081 .64568 L .35968 .64476 L p .707 .577 .707 r
F P
0 g
s
.39081 .64568 m .39225 .68254 L .42407 .68061 L p .707 .577 .707 r
F P
0 g
s
.42407 .68061 m .42263 .64375 L .39081 .64568 L p .707 .577 .707 r
F P
0 g
s
.82462 .55862 m .82454 .61415 L .80353 .60757 L p .707 .577 .707 r
F P
0 g
s
.80353 .60757 m .80361 .55204 L .82462 .55862 L p .707 .577 .707 r
F P
0 g
s
.65968 .55532 m .6596 .61085 L .64318 .61828 L p .707 .577 .707 r
F P
0 g
s
.64648 .70405 m .64867 .68762 L .66477 .67515 L p .707 .577 .707 r
F P
0 g
s
.64635 .68367 m .64574 .64625 L .66219 .63964 L p .707 .577 .707 r
F P
0 g
s
.42263 .64375 m .42407 .68061 L .45348 .67601 L p .707 .577 .707 r
F P
0 g
s
.45348 .67601 m .45203 .63915 L .42263 .64375 L p .707 .577 .707 r
F P
0 g
s
.8414 .71266 m .8392 .72909 L .82651 .71288 L p .707 .577 .707 r
F P
0 g
s
.82651 .71288 m .82871 .69645 L .8414 .71266 L p .707 .577 .707 r
F P
0 g
s
.36112 .68162 m .35968 .64476 L .3323 .64107 L p .707 .577 .707 r
F P
0 g
s
.35968 .64476 m .36112 .68162 L .39225 .68254 L p .707 .577 .707 r
F P
0 g
s
.47069 .55601 m .4705 .61161 L .48692 .60434 L p .707 .577 .707 r
F P
0 g
s
.48692 .60434 m .48711 .54874 L .47069 .55601 L p .707 .577 .707 r
F P
0 g
s
.6596 .61085 m .65968 .55532 L .68378 .54965 L p .707 .577 .707 r
F P
0 g
s
.66219 .63964 m .66281 .67705 L .64635 .68367 L p .707 .577 .707 r
F P
0 g
s
.66477 .67515 m .66257 .69158 L .64648 .70405 L p .707 .577 .707 r
F P
0 g
s
.30576 .55246 m .30556 .60806 L .32657 .61456 L p .707 .577 .707 r
F P
0 g
s
.45203 .63915 m .45348 .67601 L .47759 .66919 L p .707 .577 .707 r
F P
0 g
s
.47759 .66919 m .47614 .63233 L .45203 .63915 L p .707 .577 .707 r
F P
0 g
s
.39204 .70906 m .39707 .69073 L .36702 .68154 L p .707 .577 .707 r
F P
0 g
s
.39707 .69073 m .39204 .70906 L .42278 .71686 L p .707 .577 .707 r
F P
0 g
s
.42278 .71686 m .42781 .69853 L .39707 .69073 L p .707 .577 .707 r
F P
0 g
s
.82709 .63974 m .82771 .67715 L .80674 .67188 L p .707 .577 .707 r
F P
0 g
s
.80674 .67188 m .80612 .63447 L .82709 .63974 L p .707 .577 .707 r
F P
0 g
s
.3323 .64107 m .33374 .67793 L .36112 .68162 L p .707 .577 .707 r
F P
0 g
s
.36702 .68154 m .36199 .69987 L .39204 .70906 L p .707 .577 .707 r
F P
0 g
s
.42781 .69853 m .42278 .71686 L .45121 .7225 L p .707 .577 .707 r
F P
0 g
s
.45121 .7225 m .45624 .70417 L .42781 .69853 L p .707 .577 .707 r
F P
0 g
s
.30556 .60806 m .30576 .55246 L .29322 .54457 L p .707 .577 .707 r
F P
0 g
s
.36199 .69987 m .36702 .68154 L .3406 .67187 L p .707 .577 .707 r
F P
0 g
s
.80361 .55204 m .80353 .60757 L .7761 .60307 L p .707 .577 .707 r
F P
0 g
s
.7761 .60307 m .77618 .54754 L .80361 .55204 L p .707 .577 .707 r
F P
0 g
s
.33374 .67793 m .3323 .64107 L .31134 .63498 L p .707 .577 .707 r
F P
0 g
s
.3406 .67187 m .33557 .6902 L .36199 .69987 L p .707 .577 .707 r
F P
0 g
s
.68378 .54965 m .68369 .60518 L .6596 .61085 L p .707 .577 .707 r
F P
0 g
s
.66257 .69158 m .66477 .67515 L .68854 .66668 L p .707 .577 .707 r
F P
0 g
s
.82871 .69645 m .82651 .71288 L .80545 .69859 L p .707 .577 .707 r
F P
0 g
s
.80545 .69859 m .80765 .68216 L .82871 .69645 L p .707 .577 .707 r
F P
0 g
s
.66281 .67705 m .66219 .63964 L .68631 .6344 L p .707 .577 .707 r
F P
0 g
s
.68369 .60518 m .68378 .54965 L .71318 .54629 L p .707 .577 .707 r
F P
0 g
s
.45624 .70417 m .45121 .7225 L .47453 .72544 L p .707 .577 .707 r
F P
0 g
s
.47453 .72544 m .47956 .70711 L .45624 .70417 L p .707 .577 .707 r
F P
0 g
s
.47614 .63233 m .47759 .66919 L .49404 .66083 L p .707 .577 .707 r
F P
0 g
s
.49404 .66083 m .4926 .62397 L .47614 .63233 L p .707 .577 .707 r
F P
0 g
s
.31134 .63498 m .31278 .67184 L .33374 .67793 L p .707 .577 .707 r
F P
0 g
s
.68854 .66668 m .68634 .68311 L .66257 .69158 L p .707 .577 .707 r
F P
0 g
s
.29322 .54457 m .29303 .60017 L .30556 .60806 L p .707 .577 .707 r
F P
0 g
s
.48711 .54874 m .48692 .60434 L .49406 .59605 L p .707 .577 .707 r
F P
0 g
s
.49406 .59605 m .49426 .54045 L .48711 .54874 L p .707 .577 .707 r
F P
0 g
s
.33557 .6902 m .3406 .67187 L .32041 .66265 L p .707 .577 .707 r
F P
0 g
s
.68631 .6344 m .68693 .67181 L .66281 .67705 L p .707 .577 .707 r
F P
0 g
s
.77618 .54754 m .7761 .60307 L .74494 .60109 L p .707 .577 .707 r
F P
0 g
s
.74494 .60109 m .74502 .54556 L .77618 .54754 L p .707 .577 .707 r
F P
0 g
s
.32041 .66265 m .31538 .68098 L .33557 .6902 L p .707 .577 .707 r
F P
0 g
s
.80612 .63447 m .80674 .67188 L .77933 .66849 L p .707 .577 .707 r
F P
0 g
s
.77933 .66849 m .77872 .63108 L .80612 .63447 L p .707 .577 .707 r
F P
0 g
s
.7131 .60182 m .71318 .54629 L .74502 .54556 L p .707 .577 .707 r
F P
0 g
s
.71318 .54629 m .7131 .60182 L .68369 .60518 L p .707 .577 .707 r
F P
0 g
s
.74502 .54556 m .74494 .60109 L .7131 .60182 L p .707 .577 .707 r
F P
0 g
s
.68634 .68311 m .68854 .66668 L .71765 .66304 L p .707 .577 .707 r
F P
0 g
s
.31278 .67184 m .31134 .63498 L .29886 .62708 L p .707 .577 .707 r
F P
0 g
s
.80765 .68216 m .80545 .69859 L .77807 .68761 L p .707 .577 .707 r
F P
0 g
s
.77807 .68761 m .78027 .67118 L .80765 .68216 L p .707 .577 .707 r
F P
0 g
s
.68693 .67181 m .68631 .6344 L .71573 .63104 L p .707 .577 .707 r
F P
0 g
s
.29303 .60017 m .29322 .54457 L .29038 .53606 L p .707 .577 .707 r
F P
0 g
s
.47956 .70711 m .47453 .72544 L .49047 .72539 L p .707 .577 .707 r
F P
0 g
s
.49047 .72539 m .4955 .70706 L .47956 .70711 L p .707 .577 .707 r
F P
0 g
s
.71765 .66304 m .71545 .67947 L .68634 .68311 L p .707 .577 .707 r
F P
0 g
s
.74706 .68103 m .74926 .66459 L .78027 .67118 L p .707 .577 .707 r
F P
0 g
s
.74926 .66459 m .74706 .68103 L .71545 .67947 L p .707 .577 .707 r
F P
0 g
s
.77872 .63108 m .77933 .66849 L .74819 .66731 L p .707 .577 .707 r
F P
0 g
s
.71545 .67947 m .71765 .66304 L .74926 .66459 L p .707 .577 .707 r
F P
0 g
s
.74819 .66731 m .74757 .6299 L .77872 .63108 L p .707 .577 .707 r
F P
0 g
s
.29886 .62708 m .3003 .66394 L .31278 .67184 L p .707 .577 .707 r
F P
0 g
s
.71573 .63104 m .71635 .66845 L .68693 .67181 L p .707 .577 .707 r
F P
0 g
s
.78027 .67118 m .77807 .68761 L .74706 .68103 L p .707 .577 .707 r
F P
0 g
s
.4926 .62397 m .49404 .66083 L .50123 .65173 L p .707 .577 .707 r
F P
0 g
s
.50123 .65173 m .49979 .61487 L .4926 .62397 L p .707 .577 .707 r
F P
0 g
s
.31538 .68098 m .32041 .66265 L .30841 .65479 L p .707 .577 .707 r
F P
0 g
s
.71635 .66845 m .71573 .63104 L .74757 .6299 L p .707 .577 .707 r
F P
0 g
s
.30841 .65479 m .30338 .67312 L .31538 .68098 L p .707 .577 .707 r
F P
0 g
s
.74757 .6299 m .74819 .66731 L .71635 .66845 L p .707 .577 .707 r
F P
0 g
s
.29038 .53606 m .29019 .59167 L .29303 .60017 L p .707 .577 .707 r
F P
0 g
s
.49426 .54045 m .49406 .59605 L .49122 .58754 L p .707 .577 .707 r
F P
0 g
s
.49122 .58754 m .49142 .53194 L .49426 .54045 L p .707 .577 .707 r
F P
0 g
s
.3003 .66394 m .29886 .62708 L .29608 .61815 L p .707 .577 .707 r
F P
0 g
s
.29019 .59167 m .29038 .53606 L .29752 .52777 L p .707 .577 .707 r
F P
0 g
s
.4955 .70706 m .49047 .72539 L .49747 .72234 L p .707 .577 .707 r
F P
0 g
s
.49747 .72234 m .5025 .70401 L .4955 .70706 L p .707 .577 .707 r
F P
0 g
s
.29608 .61815 m .29752 .65501 L .3003 .66394 L p .707 .577 .707 r
F P
0 g
s
.30338 .67312 m .30841 .65479 L .30578 .64905 L p .707 .577 .707 r
F P
0 g
s
.49979 .61487 m .50123 .65173 L .49844 .6428 L p .707 .577 .707 r
F P
0 g
s
.49844 .6428 m .497 .60594 L .49979 .61487 L p .707 .577 .707 r
F P
0 g
s
.30578 .64905 m .30075 .66738 L .30338 .67312 L p .707 .577 .707 r
F P
0 g
s
.29752 .52777 m .29733 .58337 L .29019 .59167 L p .707 .577 .707 r
F P
0 g
s
.49142 .53194 m .49122 .58754 L .47868 .57965 L p .707 .577 .707 r
F P
0 g
s
.47868 .57965 m .47888 .52405 L .49142 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29752 .65501 m .29608 .61815 L .30327 .60906 L p .707 .577 .707 r
F P
0 g
s
.29733 .58337 m .29752 .52777 L .31395 .5205 L p .707 .577 .707 r
F P
0 g
s
.5025 .70401 m .49747 .72234 L .49484 .71661 L p .707 .577 .707 r
F P
0 g
s
.49484 .71661 m .49987 .69828 L .5025 .70401 L p .707 .577 .707 r
F P
0 g
s
.30327 .60906 m .30471 .64592 L .29752 .65501 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30075 .66738 m .30578 .64905 L .31278 .64601 L p .707 .577 .707 r
F P
0 g
s
.497 .60594 m .49844 .6428 L .48596 .6349 L p .707 .577 .707 r
F P
0 g
s
.48596 .6349 m .48452 .59804 L .497 .60594 L p .707 .577 .707 r
F P
0 g
s
.31278 .64601 m .30775 .66434 L .30075 .66738 L p .707 .577 .707 r
F P
0 g
s
.31395 .5205 m .31375 .5761 L .29733 .58337 L p .707 .577 .707 r
F P
0 g
s
.47888 .52405 m .47868 .57965 L .45767 .57315 L p .707 .577 .707 r
F P
0 g
s
.45767 .57315 m .45787 .51755 L .47888 .52405 L p .707 .577 .707 r
F P
0 g
s
.30471 .64592 m .30327 .60906 L .31972 .60069 L p .707 .577 .707 r
F P
0 g
s
.31375 .5761 m .31395 .5205 L .33804 .51497 L p .707 .577 .707 r
F P
0 g
s
.49987 .69828 m .49484 .71661 L .48284 .70875 L p .707 .577 .707 r
F P
0 g
s
.48284 .70875 m .48787 .69042 L .49987 .69828 L p .707 .577 .707 r
F P
0 g
s
.31972 .60069 m .32116 .63755 L .30471 .64592 L p .707 .577 .707 r
F P
0 g
s
.48452 .59804 m .48596 .6349 L .46501 .62881 L p .707 .577 .707 r
F P
0 g
s
.46501 .62881 m .46357 .59195 L .48452 .59804 L p .707 .577 .707 r
F P
0 g
s
.45787 .51755 m .45767 .57315 L .43025 .56868 L p .707 .577 .707 r
F P
0 g
s
.43025 .56868 m .43044 .51307 L .45787 .51755 L p .707 .577 .707 r
F P
0 g
s
.30775 .66434 m .31278 .64601 L .32872 .64596 L p .707 .577 .707 r
F P
0 g
s
.33804 .51497 m .33784 .57057 L .31375 .5761 L p .707 .577 .707 r
F P
0 g
s
.32872 .64596 m .32369 .66429 L .30775 .66434 L p .707 .577 .707 r
F P
0 g
s
.33784 .57057 m .33804 .51497 L .36744 .51172 L p .707 .577 .707 r
F P
0 g
s
.32116 .63755 m .31972 .60069 L .34383 .59388 L p .707 .577 .707 r
F P
0 g
s
.43044 .51307 m .43025 .56868 L .39909 .56667 L p .707 .577 .707 r
F P
0 g
s
.39909 .56667 m .39928 .51107 L .43044 .51307 L p .707 .577 .707 r
F P
0 g
s
.36725 .56732 m .36744 .51172 L .39928 .51107 L p .707 .577 .707 r
F P
0 g
s
.36744 .51172 m .36725 .56732 L .33784 .57057 L p .707 .577 .707 r
F P
0 g
s
.39928 .51107 m .39909 .56667 L .36725 .56732 L p .707 .577 .707 r
F P
0 g
s
.46357 .59195 m .46501 .62881 L .43763 .62512 L p .707 .577 .707 r
F P
0 g
s
.43763 .62512 m .43618 .58826 L .46357 .59195 L p .707 .577 .707 r
F P
0 g
s
.34383 .59388 m .34527 .63073 L .32116 .63755 L p .707 .577 .707 r
F P
0 g
s
.48787 .69042 m .48284 .70875 L .46265 .69953 L p .707 .577 .707 r
F P
0 g
s
.46265 .69953 m .46768 .6812 L .48787 .69042 L p .707 .577 .707 r
F P
0 g
s
.32369 .66429 m .32872 .64596 L .35205 .6489 L p .707 .577 .707 r
F P
0 g
s
.34527 .63073 m .34383 .59388 L .37324 .58928 L p .707 .577 .707 r
F P
0 g
s
.35205 .6489 m .34701 .66723 L .32369 .66429 L p .707 .577 .707 r
F P
0 g
s
.43618 .58826 m .43763 .62512 L .4065 .6242 L p .707 .577 .707 r
F P
0 g
s
.4065 .6242 m .40506 .58734 L .43618 .58826 L p .707 .577 .707 r
F P
0 g
s
.37324 .58928 m .37468 .62613 L .34527 .63073 L p .707 .577 .707 r
F P
0 g
s
.37468 .62613 m .37324 .58928 L .40506 .58734 L p .707 .577 .707 r
F P
0 g
s
.40506 .58734 m .4065 .6242 L .37468 .62613 L p .707 .577 .707 r
F P
0 g
s
.46768 .6812 m .46265 .69953 L .43623 .68985 L p .707 .577 .707 r
F P
0 g
s
.43623 .68985 m .44126 .67152 L .46768 .6812 L p .707 .577 .707 r
F P
0 g
s
.34701 .66723 m .35205 .6489 L .38047 .65454 L p .707 .577 .707 r
F P
0 g
s
.38047 .65454 m .37544 .67287 L .34701 .66723 L p .707 .577 .707 r
F P
0 g
s
.44126 .67152 m .43623 .68985 L .40618 .68067 L p .707 .577 .707 r
F P
0 g
s
.40618 .68067 m .41121 .66234 L .44126 .67152 L p .707 .577 .707 r
F P
0 g
s
.37544 .67287 m .38047 .65454 L .41121 .66234 L p .707 .577 .707 r
F P
0 g
s
.41121 .66234 m .40618 .68067 L .37544 .67287 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOolG0007FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001HOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo5`00?goo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007Ool80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000kOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0000=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0039o
o`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
0000<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00004FUH01000
FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040003FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo001BOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YF000060001UYF00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`80009JEP03001JEUYF00=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1`0015YF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJ
EP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool004Qoo`T000=oo`<0009JEP8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000jOol>0004FUH00`00FUIJEP02FUH800000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYF
FUH80008FUH60003FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP02000^Ool003Ioo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EPH000IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000^Ool003=oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH02000FUIJEUYF001JEP00FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2000^Ool0035oo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@002ioo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002ioo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH;0005FUH0
0`00FUIJEP06FUH60004FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEPL000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF00006@001UYF00L005YFFUIJEP00FUH0000^
Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEP0000<0009JEP05001JEP00FUH00006FUH50004FUH00`00
FUIJEP08FUH400000eYF001JEP020002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF2@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPP000=JEP8002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF00D005YF001JEP00
00IJEPD000AJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP050003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00FUH20003FUH500001UYF001JEP00FUH000IJEP@000EJEP04001JEUYFFUH400000eYF001JEP05
FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000X00003FUH00000
01L000EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH50004FUH01000FUIJEUYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03
001JEUYF00AJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001J
EUYF00AJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@000eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1@0000=JEP0000001P000eYF00<005YFFUH01UYF00<005YFFUH015YF
1@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF2@001eYF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YF
FUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP8000AJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP@00003FUH005YF00AJEP8000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEPP000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00;Goo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH20004FUH00`00FUH000040006FUH00`00FUIJ
EP07FUH01@00FUH00000FUH010002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000P000=JEP03001JEUYF008002eoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF4@0000=JEP00FUH015YF0`001UYF00<005YF000010001UYF10000UYF00<005YFFUH01eYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30004FUH40002FUH2000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP03001JEUYF00=JEPD000AJ
EPH000MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool20002FUH01000FUIJEUYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00IJEP03
001JEP0000T00004FUH000000004FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH60008
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05FUH200000eYF001JEP03FUH3000]Ool002eoo`80
009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
0003FUH005YF00IJEP03001JEUYF009JEPL000AJEP@00003FUH005YF00IJEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP04
001JEP000004FUH3000]Ool002ioo`06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF1@0015YF
00@005YFFUIJEP<000EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP@000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP<00003FUH0000000<000IJEP@00003FUH0
05YF00EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP04FUH00`00FUIJEP02000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00QJEP03001JEUYF00AJEP@000MJEP8000IJEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YF00000`0015YF0`000eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEP00
FUH005YF00@0009JEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH00000FUH00003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000002
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00@005YFFUH002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF0005FUH50006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF0P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF20000Woo0`000eYF00<007ooOol0;7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000015YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH015YF2@0015YF00<005YFFUH00UYF2@0037oo00<005YF
FUH00UYF00<007ooOol0:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF00EJEP@000IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH30002Ool9000FOol01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF20005goo10000UYF00<005YFFUH0
0eYF00H005YFFUH005YF0006FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00@005YFFUIJEP<000Ioo`D001Moo`04001JEUYF000]
Ool002aoo`03001JEP0000AJEP@0015oo`<000moo`@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH015YF1@000eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00001Woo1@005goo00D005YF001JEP0002aoo`00;7oo00<005YF00000UYF
1@004Goo1@004Woo0`0000MJEP00FUIJEP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH:
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
00050006FUH01000FUIJEUYF0P001goo1@0067oo0P0000=JEP00Ool0:goo000/Ool00`00FUH00003
0004FUH3000>Ool5000COol40002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP030004FUH01000FUIJEUYF0P0027oo0`006Woo00<005YF0000;7oo000/Ool0
0`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000?Ool400002EYF001JEUYF001J
EP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01P00FUIJEUYF001JEP<00003
FUH005YF009JEP03001oogoo02Aoo`03001JEP0002aoo`00;7oo0P000eYF00<005YFFUH00eYF00<0
05YFFUH00eYF1P001Goo0`002Woo1P001EYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH200000eYF0000000WOol00`00FUH0000/
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001J
EUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00002FUH40005FUH3000XOol2000]Ool002aoo`80009JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP03001JEUYF00=J
EP03001JEUYF008002Ioo`8002eoo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Goo0`00
;Goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF00000UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P008Woo0P0000=J
EP00Ool0;Goo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH0
10002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF
00<005YF00000eYF0P000eYF00@005YF000000=JEP80025oo`03001JEUYF008002ioo`00;goo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`0000EJEP00
001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYF0003FUH5
000OOol20003FUH00`00Oomoo`0]Ool0031oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEPT000=JEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF009JEP8000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0
00AJEP04001JEP000004FUH40006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0]Ool0039o
o`<00003FUH005YF00IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF00800003FUH005YF00<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04001JEP00FUH600000eYF001J
EP06FUH00`00FUIJEP04000@Ool50004FUH00`00FUIJEP02000`Ool003Eoo`D000AJEPP000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EQ0000=JEP03001JEUYF00=JEP<0039oo`00=Woo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP800003FUH005YF00=JEP03001JEUYF009JEP@000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo039oo`00<Goo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPP000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEP0000800003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000eOol002aoo`D00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH:0003Ool2
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000080003FUH00`00FUH000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000=goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=0008Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00UYF10000UYF0`0017oo2@0015YF
00<005YFFUH00UYF1P00>Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH>000@Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH00`0000=JEP00Ool037oo2@00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH=000JOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1000EGoo000/Ool00`00FUH00004
FUH01000FUIJEUYF3@008Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00;7oo2`00<7oo0P000UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo05Aoo`00
JGoo0`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00=JEP04001JEP000002FUH00`00Oomoo`1D
Ool006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEP000008FUH01000FUIJEUYF1P000UYF00<007ooOol0E7oo001]Ool3
0004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUHB0002Ool2000015YF001JEP00Egoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06000BOol00`00FUIJEP02FUH2001GOol007=o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009oo`D0011oo`03001J
EUYF00=JEP03001oogoo05Ioo`00Mgoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPH000Moo`D000ioo`<000AJEP03001oogoo05Moo`00OGoo7`003Goo1@003Goo00D005YFFUIJ
EP00009JEP03001oogoo05Qoo`00SGoo00D005YFFUH005YF008001Ioo`<000aoo`8000AJEP03001J
EP0005]oo`00SGoo00<005YFFUH00P009Goo0P001eYF00<007ooOol0FWoo002=Ool01000FUIJEP00
97oo0P0000=JEP00FUH015YF0P00GGoo002=Ool3000ROol30003FUH01000FUIJEUYF0P00Ggoo002>
Ool2000NOol40007FUH3001QOol008ioo`8001Yoo`@0009JEP03001JEUYF00IJEP03001oogoo065o
o`00SWoo00<005YF000057oo1@001UYF00<005YFFUH015YF0P00I7oo002>Ool2000015YF00000000
3Goo10000UYF00<005YFFUH01eYF00@005YFFUIJEP8006Ioo`00Sgoo00<005YF00000UYF3@001UYF
00<005YFFUH01eYF00@005YF000006Qoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEP@006Yoo`00T7oo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01000KWoo002AOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH4001b
Ool009=oo`<0009JEP03001JEUYF00EJEP03001JEUYF00@007Ioo`00UWoo3@00NWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60386 .74883 m .60355 .69329 L .5724 .69151 L p .707 .577 .707 r
F P
0 g
s
.60355 .69329 m .60386 .74883 L .63571 .74791 L p .707 .577 .707 r
F P
0 g
s
.63571 .74791 m .63539 .69236 L .60355 .69329 L p .707 .577 .707 r
F P
0 g
s
.63539 .69236 m .63571 .74791 L .66513 .74437 L p .707 .577 .707 r
F P
0 g
s
.66513 .74437 m .66481 .68882 L .63539 .69236 L p .707 .577 .707 r
F P
0 g
s
.57271 .74706 m .5724 .69151 L .54499 .6872 L p .707 .577 .707 r
F P
0 g
s
.5724 .69151 m .57271 .74706 L .60386 .74883 L p .707 .577 .707 r
F P
0 g
s
.66481 .68882 m .66513 .74437 L .68924 .73856 L p .707 .577 .707 r
F P
0 g
s
.68924 .73856 m .68893 .68302 L .66481 .68882 L p .707 .577 .707 r
F P
0 g
s
.59187 .80726 m .59419 .77002 L .56312 .76642 L p .707 .577 .707 r
F P
0 g
s
.59419 .77002 m .59187 .80726 L .62366 .80847 L p .707 .577 .707 r
F P
0 g
s
.62366 .80847 m .62599 .77123 L .59419 .77002 L p .707 .577 .707 r
F P
0 g
s
.62599 .77123 m .62366 .80847 L .65306 .80718 L p .707 .577 .707 r
F P
0 g
s
.65306 .80718 m .65539 .76994 L .62599 .77123 L p .707 .577 .707 r
F P
0 g
s
.54499 .6872 m .54531 .74275 L .57271 .74706 L p .707 .577 .707 r
F P
0 g
s
.54531 .74275 m .54499 .6872 L .52401 .68079 L p .707 .577 .707 r
F P
0 g
s
.56079 .80366 m .56312 .76642 L .53581 .76079 L p .707 .577 .707 r
F P
0 g
s
.56312 .76642 m .56079 .80366 L .59187 .80726 L p .707 .577 .707 r
F P
0 g
s
.65539 .76994 m .65306 .80718 L .67719 .8035 L p .707 .577 .707 r
F P
0 g
s
.67719 .8035 m .67952 .76626 L .65539 .76994 L p .707 .577 .707 r
F P
0 g
s
.53581 .76079 m .53348 .79803 L .56079 .80366 L p .707 .577 .707 r
F P
0 g
s
.68893 .68302 m .68924 .73856 L .7057 .73106 L p .707 .577 .707 r
F P
0 g
s
.7057 .73106 m .70538 .67551 L .68893 .68302 L p .707 .577 .707 r
F P
0 g
s
.621 .85854 m .61302 .84281 L .58402 .85575 L p .707 .577 .707 r
F P
0 g
s
.61302 .84281 m .621 .85854 L .64791 .84221 L p .707 .577 .707 r
F P
0 g
s
.64791 .84221 m .63993 .82647 L .61302 .84281 L p .707 .577 .707 r
F P
0 g
s
.52401 .68079 m .52432 .73633 L .54531 .74275 L p .707 .577 .707 r
F P
0 g
s
.59199 .87148 m .58402 .85575 L .55575 .86401 L p .707 .577 .707 r
F P
0 g
s
.58402 .85575 m .59199 .87148 L .621 .85854 L p .707 .577 .707 r
F P
0 g
s
.53348 .79803 m .53581 .76079 L .51493 .75368 L p .707 .577 .707 r
F P
0 g
s
.63993 .82647 m .64791 .84221 L .67008 .82406 L p .707 .577 .707 r
F P
0 g
s
.67008 .82406 m .66211 .80833 L .63993 .82647 L p .707 .577 .707 r
F P
0 g
s
.52432 .73633 m .52401 .68079 L .5115 .67289 L p .707 .577 .707 r
F P
0 g
s
.55575 .86401 m .56372 .87975 L .59199 .87148 L p .707 .577 .707 r
F P
0 g
s
.51493 .75368 m .5126 .79092 L .53348 .79803 L p .707 .577 .707 r
F P
0 g
s
.56372 .87975 m .55575 .86401 L .53099 .8668 L p .707 .577 .707 r
F P
0 g
s
.67952 .76626 m .67719 .8035 L .69369 .79781 L p .707 .577 .707 r
F P
0 g
s
.69369 .79781 m .69602 .76057 L .67952 .76626 L p .707 .577 .707 r
F P
0 g
s
.66211 .80833 m .67008 .82406 L .68536 .80589 L p .707 .577 .707 r
F P
0 g
s
.68536 .80589 m .67738 .79016 L .66211 .80833 L p .707 .577 .707 r
F P
0 g
s
.53099 .8668 m .53896 .88254 L .56372 .87975 L p .707 .577 .707 r
F P
0 g
s
.70538 .67551 m .7057 .73106 L .71287 .72259 L p .707 .577 .707 r
F P
0 g
s
.71287 .72259 m .71255 .66705 L .70538 .67551 L p .707 .577 .707 r
F P
0 g
s
.5115 .67289 m .51182 .72844 L .52432 .73633 L p .707 .577 .707 r
F P
0 g
s
.5126 .79092 m .51493 .75368 L .50253 .74578 L p .707 .577 .707 r
F P
0 g
s
.53896 .88254 m .53099 .8668 L .51216 .86384 L p .707 .577 .707 r
F P
0 g
s
.50253 .74578 m .5002 .78302 L .5126 .79092 L p .707 .577 .707 r
F P
0 g
s
.51182 .72844 m .5115 .67289 L .5087 .66429 L p .707 .577 .707 r
F P
0 g
s
.67738 .79016 m .68536 .80589 L .69223 .78948 L p .707 .577 .707 r
F P
0 g
s
.69223 .78948 m .68426 .77374 L .67738 .79016 L p .707 .577 .707 r
F P
0 g
s
.51216 .86384 m .52014 .87957 L .53896 .88254 L p .707 .577 .707 r
F P
0 g
s
.69602 .76057 m .69369 .79781 L .70094 .79066 L p .707 .577 .707 r
F P
0 g
s
.70094 .79066 m .70327 .75342 L .69602 .76057 L p .707 .577 .707 r
F P
0 g
s
.5087 .66429 m .50902 .71984 L .51182 .72844 L p .707 .577 .707 r
F P
0 g
s
.5002 .78302 m .50253 .74578 L .49983 .73787 L p .707 .577 .707 r
F P
0 g
s
.71255 .66705 m .71287 .72259 L .71007 .71399 L p .707 .577 .707 r
F P
0 g
s
.71007 .71399 m .70975 .65845 L .71255 .66705 L p .707 .577 .707 r
F P
0 g
s
.52014 .87957 m .51216 .86384 L .50111 .85542 L p .707 .577 .707 r
F P
0 g
s
.49518 .8219 m .49518 .32001 L .45086 .31772 L p .707 .577 .707 r
F P
0 g
s
.49983 .73787 m .4975 .77511 L .5002 .78302 L p .707 .577 .707 r
F P
0 g
s
.50902 .71984 m .5087 .66429 L .51588 .65583 L p .707 .577 .707 r
F P
0 g
s
.51588 .65583 m .5162 .71137 L .50902 .71984 L p .707 .577 .707 r
F P
0 g
s
.4975 .77511 m .49983 .73787 L .50708 .73072 L p .707 .577 .707 r
F P
0 g
s
.50708 .73072 m .50475 .76796 L .4975 .77511 L p .707 .577 .707 r
F P
0 g
s
.5162 .71137 m .51588 .65583 L .53233 .64832 L p .707 .577 .707 r
F P
0 g
s
.53233 .64832 m .53265 .70387 L .5162 .71137 L p .707 .577 .707 r
F P
0 g
s
.50475 .76796 m .50708 .73072 L .52357 .72503 L p .707 .577 .707 r
F P
0 g
s
.52357 .72503 m .52124 .76227 L .50475 .76796 L p .707 .577 .707 r
F P
0 g
s
.52124 .76227 m .52357 .72503 L .5477 .72135 L p .707 .577 .707 r
F P
0 g
s
.51376 .84167 m .50579 .82594 L .52106 .80777 L p .707 .577 .707 r
F P
0 g
s
.5477 .72135 m .54538 .75859 L .52124 .76227 L p .707 .577 .707 r
F P
0 g
s
.52106 .80777 m .52903 .8235 L .51376 .84167 L p .707 .577 .707 r
F P
0 g
s
.52903 .8235 m .52106 .80777 L .54324 .78963 L p .707 .577 .707 r
F P
0 g
s
.54324 .78963 m .55121 .80536 L .52903 .8235 L p .707 .577 .707 r
F P
0 g
s
.49518 .32001 m .49518 .8219 L .53996 .82041 L p .707 .577 .707 r
F P
0 g
s
.53265 .70387 m .53233 .64832 L .55645 .64252 L p .707 .577 .707 r
F P
0 g
s
.55645 .64252 m .55676 .69806 L .53265 .70387 L p .707 .577 .707 r
F P
0 g
s
.53996 .82041 m .53996 .31852 L .49518 .32001 L p .707 .577 .707 r
F P
0 g
s
.55676 .69806 m .55645 .64252 L .58587 .63898 L p .707 .577 .707 r
F P
0 g
s
.58587 .63898 m .58618 .69452 L .55676 .69806 L p .707 .577 .707 r
F P
0 g
s
.54538 .75859 m .5477 .72135 L .5771 .72006 L p .707 .577 .707 r
F P
0 g
s
.5771 .72006 m .57478 .7573 L .54538 .75859 L p .707 .577 .707 r
F P
0 g
s
.57478 .7573 m .5771 .72006 L .6089 .72127 L p .707 .577 .707 r
F P
0 g
s
.60713 .77609 m .59916 .76035 L .62742 .75208 L p .707 .577 .707 r
F P
0 g
s
.6089 .72127 m .60657 .75851 L .57478 .7573 L p .707 .577 .707 r
F P
0 g
s
.55121 .80536 m .54324 .78963 L .57015 .77329 L p .707 .577 .707 r
F P
0 g
s
.59916 .76035 m .60713 .77609 L .57812 .78902 L p .707 .577 .707 r
F P
0 g
s
.57812 .78902 m .57015 .77329 L .59916 .76035 L p .707 .577 .707 r
F P
0 g
s
.57015 .77329 m .57812 .78902 L .55121 .80536 L p .707 .577 .707 r
F P
0 g
s
.53996 .31852 m .53996 .82041 L .58083 .81527 L p .707 .577 .707 r
F P
0 g
s
.58083 .81527 m .58083 .31339 L .53996 .31852 L p .707 .577 .707 r
F P
0 g
s
.68426 .77374 m .69223 .78948 L .69003 .77642 L p .707 .577 .707 r
F P
0 g
s
.69003 .77642 m .68206 .76068 L .68426 .77374 L p .707 .577 .707 r
F P
0 g
s
.50111 .85542 m .50908 .87115 L .52014 .87957 L p .707 .577 .707 r
F P
0 g
s
.45086 .81961 m .45086 .31772 L .41136 .31186 L p .707 .577 .707 r
F P
0 g
s
.45086 .31772 m .45086 .81961 L .49518 .8219 L p .707 .577 .707 r
F P
0 g
s
.70327 .75342 m .70094 .79066 L .69823 .78275 L p .707 .577 .707 r
F P
0 g
s
.69823 .78275 m .70056 .74551 L .70327 .75342 L p .707 .577 .707 r
F P
0 g
s
.25626 .71431 m .25612 .65864 L .22497 .65682 L p .707 .577 .707 r
F P
0 g
s
.25612 .65864 m .25626 .71431 L .2881 .7135 L p .707 .577 .707 r
F P
0 g
s
.2881 .7135 m .28797 .65783 L .25612 .65864 L p .707 .577 .707 r
F P
0 g
s
.58618 .69452 m .58587 .63898 L .61771 .63805 L p .707 .577 .707 r
F P
0 g
s
.61771 .63805 m .61803 .6936 L .58618 .69452 L p .707 .577 .707 r
F P
0 g
s
.62742 .75208 m .6354 .76782 L .60713 .77609 L p .707 .577 .707 r
F P
0 g
s
.6354 .76782 m .62742 .75208 L .65218 .7493 L p .707 .577 .707 r
F P
0 g
s
.63997 .72487 m .63764 .76211 L .60657 .75851 L p .707 .577 .707 r
F P
0 g
s
.60657 .75851 m .6089 .72127 L .63997 .72487 L p .707 .577 .707 r
F P
0 g
s
.58083 .31339 m .58083 .81527 L .6138 .807 L p .707 .577 .707 r
F P
0 g
s
.6138 .807 m .6138 .30511 L .58083 .31339 L p .707 .577 .707 r
F P
0 g
s
.70975 .65845 m .71007 .71399 L .69757 .7061 L p .707 .577 .707 r
F P
0 g
s
.69757 .7061 m .69725 .65055 L .70975 .65845 L p .707 .577 .707 r
F P
0 g
s
.28797 .65783 m .2881 .7135 L .31752 .71014 L p .707 .577 .707 r
F P
0 g
s
.31752 .71014 m .31739 .65448 L .28797 .65783 L p .707 .577 .707 r
F P
0 g
s
.50908 .87115 m .50111 .85542 L .49891 .84236 L p .707 .577 .707 r
F P
0 g
s
.41136 .81375 m .41136 .31186 L .38053 .30302 L p .707 .577 .707 r
F P
0 g
s
.41136 .31186 m .41136 .81375 L .45086 .81961 L p .707 .577 .707 r
F P
0 g
s
.22511 .71249 m .22497 .65682 L .19756 .65256 L p .707 .577 .707 r
F P
0 g
s
.22497 .65682 m .22511 .71249 L .25626 .71431 L p .707 .577 .707 r
F P
0 g
s
.68206 .76068 m .69003 .77642 L .67898 .76799 L p .707 .577 .707 r
F P
0 g
s
.67898 .76799 m .67101 .75226 L .68206 .76068 L p .707 .577 .707 r
F P
0 g
s
.49891 .84236 m .50689 .85809 L .50908 .87115 L p .707 .577 .707 r
F P
0 g
s
.31739 .65448 m .31752 .71014 L .34164 .70457 L p .707 .577 .707 r
F P
0 g
s
.34164 .70457 m .3415 .6489 L .31739 .65448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70056 .74551 m .69823 .78275 L .68583 .77485 L p .707 .577 .707 r
F P
0 g
s
.68583 .77485 m .68816 .73761 L .70056 .74551 L p .707 .577 .707 r
F P
0 g
s
.19756 .65256 m .1977 .70823 L .22511 .71249 L p .707 .577 .707 r
F P
0 g
s
.1977 .70823 m .19756 .65256 L .17658 .64626 L p .707 .577 .707 r
F P
0 g
s
.69725 .65055 m .69757 .7061 L .67659 .69968 L p .707 .577 .707 r
F P
0 g
s
.67659 .69968 m .67627 .64414 L .69725 .65055 L p .707 .577 .707 r
F P
0 g
s
.64886 .63983 m .64918 .69537 L .61803 .6936 L p .707 .577 .707 r
F P
0 g
s
.61803 .6936 m .61771 .63805 L .64886 .63983 L p .707 .577 .707 r
F P
0 g
s
.6138 .30511 m .6138 .807 L .63562 .7964 L p .707 .577 .707 r
F P
0 g
s
.65218 .7493 m .66015 .76503 L .6354 .76782 L p .707 .577 .707 r
F P
0 g
s
.63562 .7964 m .63562 .29451 L .6138 .30511 L p .707 .577 .707 r
F P
0 g
s
.25101 .77775 m .25201 .7414 L .22089 .73827 L p .707 .577 .707 r
F P
0 g
s
.25201 .7414 m .25101 .77775 L .28285 .77764 L p .707 .577 .707 r
F P
0 g
s
.28285 .77764 m .28385 .74129 L .25201 .7414 L p .707 .577 .707 r
F P
0 g
s
.50689 .85809 m .49891 .84236 L .50579 .82594 L p .707 .577 .707 r
F P
0 g
s
.3415 .6489 m .34164 .70457 L .35809 .69732 L p .707 .577 .707 r
F P
0 g
s
.35809 .69732 m .35796 .64166 L .3415 .6489 L p .707 .577 .707 r
F P
0 g
s
.28385 .74129 m .28285 .77764 L .31229 .7743 L p .707 .577 .707 r
F P
0 g
s
.31229 .7743 m .31329 .73795 L .28385 .74129 L p .707 .577 .707 r
F P
0 g
s
.38053 .80491 m .38053 .30302 L .3614 .29205 L p .707 .577 .707 r
F P
0 g
s
.38053 .30302 m .38053 .80491 L .41136 .81375 L p .707 .577 .707 r
F P
0 g
s
.17658 .64626 m .17672 .70193 L .1977 .70823 L p .707 .577 .707 r
F P
0 g
s
.21989 .77462 m .22089 .73827 L .19352 .73221 L p .707 .577 .707 r
F P
0 g
s
.22089 .73827 m .21989 .77462 L .25101 .77775 L p .707 .577 .707 r
F P
0 g
s
.67101 .75226 m .67898 .76799 L .66015 .76503 L p .707 .577 .707 r
F P
0 g
s
.66015 .76503 m .65218 .7493 L .67101 .75226 L p .707 .577 .707 r
F P
0 g
s
.50579 .82594 m .51376 .84167 L .50689 .85809 L p .707 .577 .707 r
F P
0 g
s
.17672 .70193 m .17658 .64626 L .16408 .63855 L p .707 .577 .707 r
F P
0 g
s
.31329 .73795 m .31229 .7743 L .33644 .76806 L p .707 .577 .707 r
F P
0 g
s
.33644 .76806 m .33744 .73171 L .31329 .73795 L p .707 .577 .707 r
F P
0 g
s
.68816 .73761 m .68583 .77485 L .66496 .76774 L p .707 .577 .707 r
F P
0 g
s
.66496 .76774 m .66728 .7305 L .68816 .73761 L p .707 .577 .707 r
F P
0 g
s
.21912 .75917 m .22271 .77784 L .25344 .77106 L p .707 .577 .707 r
F P
0 g
s
.25344 .77106 m .24984 .75239 L .21912 .75917 L p .707 .577 .707 r
F P
0 g
s
.24984 .75239 m .25344 .77106 L .28467 .7657 L p .707 .577 .707 r
F P
0 g
s
.19352 .73221 m .19253 .76856 L .21989 .77462 L p .707 .577 .707 r
F P
0 g
s
.67627 .64414 m .67659 .69968 L .64918 .69537 L p .707 .577 .707 r
F P
0 g
s
.64918 .69537 m .64886 .63983 L .67627 .64414 L p .707 .577 .707 r
F P
0 g
s
.19253 .76856 m .19352 .73221 L .1726 .72381 L p .707 .577 .707 r
F P
0 g
s
.28467 .7657 m .28107 .74703 L .24984 .75239 L p .707 .577 .707 r
F P
0 g
s
.28107 .74703 m .28467 .7657 L .31334 .76229 L p .707 .577 .707 r
F P
0 g
s
.1726 .72381 m .1716 .76016 L .19253 .76856 L p .707 .577 .707 r
F P
0 g
s
.1919 .76672 m .19549 .78539 L .22271 .77784 L p .707 .577 .707 r
F P
0 g
s
.22271 .77784 m .21912 .75917 L .1919 .76672 L p .707 .577 .707 r
F P
0 g
s
.31334 .76229 m .30974 .74362 L .28107 .74703 L p .707 .577 .707 r
F P
0 g
s
.16408 .63855 m .16421 .69422 L .17672 .70193 L p .707 .577 .707 r
F P
0 g
s
.35796 .64166 m .35809 .69732 L .36527 .68911 L p .707 .577 .707 r
F P
0 g
s
.36527 .68911 m .36513 .63345 L .35796 .64166 L p .707 .577 .707 r
F P
0 g
s
.33744 .73171 m .33644 .76806 L .35295 .75952 L p .707 .577 .707 r
F P
0 g
s
.35295 .75952 m .35395 .72318 L .33744 .73171 L p .707 .577 .707 r
F P
0 g
s
.66728 .7305 m .66496 .76774 L .63764 .76211 L p .707 .577 .707 r
F P
0 g
s
.63764 .76211 m .63997 .72487 L .66728 .7305 L p .707 .577 .707 r
F P
0 g
s
.63562 .29451 m .63562 .7964 L .64416 .78451 L p .707 .577 .707 r
F P
0 g
s
.64416 .78451 m .64416 .28262 L .63562 .29451 L p .707 .577 .707 r
F P
0 g
s
.30974 .74362 m .31334 .76229 L .33664 .76117 L p .707 .577 .707 r
F P
0 g
s
.17085 .77429 m .17445 .79296 L .19549 .78539 L p .707 .577 .707 r
F P
0 g
s
.19549 .78539 m .1919 .76672 L .17085 .77429 L p .707 .577 .707 r
F P
0 g
s
.33664 .76117 m .33305 .7425 L .30974 .74362 L p .707 .577 .707 r
F P
0 g
s
.16421 .69422 m .16408 .63855 L .16128 .63019 L p .707 .577 .707 r
F P
0 g
s
.36019 .74954 m .36119 .71319 L .35395 .72318 L p .707 .577 .707 r
F P
0 g
s
.36233 .62508 m .36247 .68075 L .34996 .67304 L p .707 .577 .707 r
F P
0 g
s
.34996 .67304 m .34983 .61737 L .36233 .62508 L p .707 .577 .707 r
F P
0 g
s
.35395 .72318 m .35295 .75952 L .36019 .74954 L p .707 .577 .707 r
F P
0 g
s
.36119 .71319 m .36019 .74954 L .35746 .73907 L p .707 .577 .707 r
F P
0 g
s
.35746 .73907 m .35846 .70273 L .36119 .71319 L p .707 .577 .707 r
F P
0 g
s
.3614 .79394 m .3614 .29205 L .35583 .28004 L p .707 .577 .707 r
F P
0 g
s
.36513 .63345 m .36527 .68911 L .36247 .68075 L p .707 .577 .707 r
F P
0 g
s
.36247 .68075 m .36233 .62508 L .36513 .63345 L p .707 .577 .707 r
F P
0 g
s
.3614 .29205 m .3614 .79394 L .38053 .80491 L p .707 .577 .707 r
F P
0 g
s
.1716 .76016 m .1726 .72381 L .16016 .71389 L p .707 .577 .707 r
F P
0 g
s
.16128 .63019 m .16141 .68585 L .16421 .69422 L p .707 .577 .707 r
F P
0 g
s
.16016 .71389 m .15917 .75024 L .1716 .76016 L p .707 .577 .707 r
F P
0 g
s
.33305 .7425 m .33664 .76117 L .35231 .76244 L p .707 .577 .707 r
F P
0 g
s
.35231 .76244 m .34871 .74377 L .33305 .7425 L p .707 .577 .707 r
F P
0 g
s
.15804 .78114 m .16163 .79981 L .17445 .79296 L p .707 .577 .707 r
F P
0 g
s
.17445 .79296 m .17085 .77429 L .15804 .78114 L p .707 .577 .707 r
F P
0 g
s
.15917 .75024 m .16016 .71389 L .15743 .70343 L p .707 .577 .707 r
F P
0 g
s
.16141 .68585 m .16128 .63019 L .16845 .62198 L p .707 .577 .707 r
F P
0 g
s
.64416 .28262 m .64416 .78451 L .6386 .7725 L p .707 .577 .707 r
F P
0 g
s
.6386 .7725 m .6386 .27061 L .64416 .28262 L p .707 .577 .707 r
F P
0 g
s
.15743 .70343 m .15644 .73978 L .15917 .75024 L p .707 .577 .707 r
F P
0 g
s
.34871 .74377 m .35231 .76244 L .35879 .76598 L p .707 .577 .707 r
F P
0 g
s
.35879 .76598 m .3552 .74731 L .34871 .74377 L p .707 .577 .707 r
F P
0 g
s
.3552 .74731 m .35879 .76598 L .35546 .77144 L p .707 .577 .707 r
F P
0 g
s
.35846 .70273 m .35746 .73907 L .34503 .72915 L p .707 .577 .707 r
F P
0 g
s
.34503 .72915 m .34602 .69281 L .35846 .70273 L p .707 .577 .707 r
F P
0 g
s
.35583 .28004 m .35583 .78192 L .3614 .79394 L p .707 .577 .707 r
F P
0 g
s
.35583 .78192 m .35583 .28004 L .36438 .26814 L p .707 .577 .707 r
F P
0 g
s
.16845 .62198 m .16859 .67764 L .16141 .68585 L p .707 .577 .707 r
F P
0 g
s
.15471 .7866 m .15831 .80528 L .16163 .79981 L p .707 .577 .707 r
F P
0 g
s
.16163 .79981 m .15804 .78114 L .15471 .7866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15644 .73978 m .15743 .70343 L .16467 .69344 L p .707 .577 .707 r
F P
0 g
s
.16859 .67764 m .16845 .62198 L .1849 .61473 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16467 .69344 m .16368 .72979 L .15644 .73978 L p .707 .577 .707 r
F P
0 g
s
.1849 .61473 m .18504 .6704 L .16859 .67764 L p .707 .577 .707 r
F P
0 g
s
.34983 .61737 m .34996 .67304 L .32898 .66674 L p .707 .577 .707 r
F P
0 g
s
.32898 .66674 m .32884 .61107 L .34983 .61737 L p .707 .577 .707 r
F P
0 g
s
.35546 .77144 m .35187 .75277 L .3552 .74731 L p .707 .577 .707 r
F P
0 g
s
.6386 .27061 m .6386 .7725 L .61947 .76153 L p .707 .577 .707 r
F P
0 g
s
.61947 .76153 m .61947 .25964 L .6386 .27061 L p .707 .577 .707 r
F P
0 g
s
.1612 .79014 m .16479 .80882 L .15831 .80528 L p .707 .577 .707 r
F P
0 g
s
.15831 .80528 m .15471 .7866 L .1612 .79014 L p .707 .577 .707 r
F P
0 g
s
.18504 .6704 m .1849 .61473 L .20902 .60916 L p .707 .577 .707 r
F P
0 g
s
.36438 .77003 m .36438 .26814 L .3862 .25754 L p .707 .577 .707 r
F P
0 g
s
.36438 .26814 m .36438 .77003 L .35583 .78192 L p .707 .577 .707 r
F P
0 g
s
.16368 .72979 m .16467 .69344 L .18118 .68491 L p .707 .577 .707 r
F P
0 g
s
.32884 .61107 m .32898 .66674 L .30157 .66248 L p .707 .577 .707 r
F P
0 g
s
.30157 .66248 m .30144 .60681 L .32884 .61107 L p .707 .577 .707 r
F P
0 g
s
.20902 .60916 m .20916 .66482 L .18504 .6704 L p .707 .577 .707 r
F P
0 g
s
.18118 .68491 m .18018 .72126 L .16368 .72979 L p .707 .577 .707 r
F P
0 g
s
.34602 .69281 m .34503 .72915 L .3241 .72075 L p .707 .577 .707 r
F P
0 g
s
.3241 .72075 m .3251 .68441 L .34602 .69281 L p .707 .577 .707 r
F P
0 g
s
.35187 .75277 m .35546 .77144 L .34265 .7783 L p .707 .577 .707 r
F P
0 g
s
.20916 .66482 m .20902 .60916 L .23844 .6058 L p .707 .577 .707 r
F P
0 g
s
.34265 .7783 m .33905 .75962 L .35187 .75277 L p .707 .577 .707 r
F P
0 g
s
.17686 .79141 m .18046 .81009 L .16479 .80882 L p .707 .577 .707 r
F P
0 g
s
.16479 .80882 m .1612 .79014 L .17686 .79141 L p .707 .577 .707 r
F P
0 g
s
.30144 .60681 m .30157 .66248 L .27042 .66066 L p .707 .577 .707 r
F P
0 g
s
.27042 .66066 m .27028 .60499 L .30144 .60681 L p .707 .577 .707 r
F P
0 g
s
.18018 .72126 m .18118 .68491 L .20533 .67867 L p .707 .577 .707 r
F P
0 g
s
.61947 .25964 m .61947 .76153 L .58864 .75268 L p .707 .577 .707 r
F P
0 g
s
.58864 .75268 m .58864 .25079 L .61947 .25964 L p .707 .577 .707 r
F P
0 g
s
.23858 .66147 m .23844 .6058 L .27028 .60499 L p .707 .577 .707 r
F P
0 g
s
.23844 .6058 m .23858 .66147 L .20916 .66482 L p .707 .577 .707 r
F P
0 g
s
.27028 .60499 m .27042 .66066 L .23858 .66147 L p .707 .577 .707 r
F P
0 g
s
.3862 .25754 m .3862 .75943 L .36438 .77003 L p .707 .577 .707 r
F P
0 g
s
.3862 .75943 m .3862 .25754 L .41916 .24927 L p .707 .577 .707 r
F P
0 g
s
.20533 .67867 m .20434 .71502 L .18018 .72126 L p .707 .577 .707 r
F P
0 g
s
.3251 .68441 m .3241 .72075 L .29674 .71469 L p .707 .577 .707 r
F P
0 g
s
.29674 .71469 m .29774 .67835 L .3251 .68441 L p .707 .577 .707 r
F P
0 g
s
.33905 .75962 m .34265 .7783 L .3216 .78587 L p .707 .577 .707 r
F P
0 g
s
.20434 .71502 m .20533 .67867 L .23477 .67533 L p .707 .577 .707 r
F P
0 g
s
.3216 .78587 m .31801 .76719 L .33905 .75962 L p .707 .577 .707 r
F P
0 g
s
.72958 .65582 m .72971 .60032 L .69856 .59829 L p .707 .577 .707 r
F P
0 g
s
.72971 .60032 m .72958 .65582 L .76142 .65512 L p .707 .577 .707 r
F P
0 g
s
.76142 .65512 m .76156 .59963 L .72971 .60032 L p .707 .577 .707 r
F P
0 g
s
.20017 .79029 m .20376 .80896 L .18046 .81009 L p .707 .577 .707 r
F P
0 g
s
.18046 .81009 m .17686 .79141 L .20017 .79029 L p .707 .577 .707 r
F P
0 g
s
.76156 .59963 m .76142 .65512 L .79084 .65177 L p .707 .577 .707 r
F P
0 g
s
.79084 .65177 m .79098 .59627 L .76156 .59963 L p .707 .577 .707 r
F P
0 g
s
.29774 .67835 m .29674 .71469 L .26561 .71156 L p .707 .577 .707 r
F P
0 g
s
.26561 .71156 m .26661 .67522 L .29774 .67835 L p .707 .577 .707 r
F P
0 g
s
.69843 .65378 m .69856 .59829 L .67115 .59372 L p .707 .577 .707 r
F P
0 g
s
.69856 .59829 m .69843 .65378 L .72958 .65582 L p .707 .577 .707 r
F P
0 g
s
.23377 .71168 m .23477 .67533 L .26661 .67522 L p .707 .577 .707 r
F P
0 g
s
.23477 .67533 m .23377 .71168 L .20434 .71502 L p .707 .577 .707 r
F P
0 g
s
.73438 .71292 m .73339 .67532 L .70226 .67459 L p .707 .577 .707 r
F P
0 g
s
.73339 .67532 m .73438 .71292 L .76622 .71154 L p .707 .577 .707 r
F P
0 g
s
.76622 .71154 m .76523 .67394 L .73339 .67532 L p .707 .577 .707 r
F P
0 g
s
.58864 .25079 m .58864 .75268 L .54913 .74683 L p .707 .577 .707 r
F P
0 g
s
.54913 .74683 m .54913 .24494 L .58864 .25079 L p .707 .577 .707 r
F P
0 g
s
.26661 .67522 m .26561 .71156 L .23377 .71168 L p .707 .577 .707 r
F P
0 g
s
.76523 .67394 m .76622 .71154 L .79566 .70819 L p .707 .577 .707 r
F P
0 g
s
.79566 .70819 m .79466 .67059 L .76523 .67394 L p .707 .577 .707 r
F P
0 g
s
.79098 .59627 m .79084 .65177 L .81496 .64608 L p .707 .577 .707 r
F P
0 g
s
.81496 .64608 m .81509 .59059 L .79098 .59627 L p .707 .577 .707 r
F P
0 g
s
.41916 .75116 m .41916 .24927 L .46004 .24414 L p .707 .577 .707 r
F P
0 g
s
.41916 .24927 m .41916 .75116 L .3862 .75943 L p .707 .577 .707 r
F P
0 g
s
.70326 .71219 m .70226 .67459 L .6749 .67183 L p .707 .577 .707 r
F P
0 g
s
.70226 .67459 m .70326 .71219 L .73438 .71292 L p .707 .577 .707 r
F P
0 g
s
.31801 .76719 m .3216 .78587 L .29439 .79341 L p .707 .577 .707 r
F P
0 g
s
.22884 .78688 m .23243 .80556 L .20376 .80896 L p .707 .577 .707 r
F P
0 g
s
.20376 .80896 m .20017 .79029 L .22884 .78688 L p .707 .577 .707 r
F P
0 g
s
.29439 .79341 m .29079 .77474 L .31801 .76719 L p .707 .577 .707 r
F P
0 g
s
.67115 .59372 m .67102 .64922 L .69843 .65378 L p .707 .577 .707 r
F P
0 g
s
.67102 .64922 m .67115 .59372 L .65017 .58708 L p .707 .577 .707 r
F P
0 g
s
.79466 .67059 m .79566 .70819 L .81981 .7032 L p .707 .577 .707 r
F P
0 g
s
.81981 .7032 m .81882 .6656 L .79466 .67059 L p .707 .577 .707 r
F P
0 g
s
.6749 .67183 m .6759 .70943 L .70326 .71219 L p .707 .577 .707 r
F P
0 g
s
.54913 .24494 m .54913 .74683 L .50482 .74454 L p .707 .577 .707 r
F P
0 g
s
.50482 .74454 m .50482 .24265 L .54913 .24494 L p .707 .577 .707 r
F P
0 g
s
.29079 .77474 m .29439 .79341 L .26366 .8002 L p .707 .577 .707 r
F P
0 g
s
.81509 .59059 m .81496 .64608 L .83141 .63862 L p .707 .577 .707 r
F P
0 g
s
.83141 .63862 m .83155 .58312 L .81509 .59059 L p .707 .577 .707 r
F P
0 g
s
.6759 .70943 m .6749 .67183 L .65397 .66731 L p .707 .577 .707 r
F P
0 g
s
.46004 .74603 m .46004 .24414 L .50482 .24265 L p .707 .577 .707 r
F P
0 g
s
.46004 .24414 m .46004 .74603 L .41916 .75116 L p .707 .577 .707 r
F P
0 g
s
.26006 .78152 m .26366 .8002 L .23243 .80556 L p .707 .577 .707 r
F P
0 g
s
.23243 .80556 m .22884 .78688 L .26006 .78152 L p .707 .577 .707 r
F P
0 g
s
.26366 .8002 m .26006 .78152 L .29079 .77474 L p .707 .577 .707 r
F P
0 g
s
.65017 .58708 m .65003 .64257 L .67102 .64922 L p .707 .577 .707 r
F P
0 g
s
.73634 .79694 m .73993 .78244 L .70921 .77372 L p .707 .577 .707 r
F P
0 g
s
.73993 .78244 m .73634 .79694 L .76756 .79932 L p .707 .577 .707 r
F P
0 g
s
.76756 .79932 m .77116 .78483 L .73993 .78244 L p .707 .577 .707 r
F P
0 g
s
.50482 .24265 m .50482 .74454 L .46004 .74603 L p .707 .577 .707 r
F P
0 g
s
.70561 .78822 m .70921 .77372 L .68199 .75952 L p .707 .577 .707 r
F P
0 g
s
.70921 .77372 m .70561 .78822 L .73634 .79694 L p .707 .577 .707 r
F P
0 g
s
.65397 .66731 m .65497 .70491 L .6759 .70943 L p .707 .577 .707 r
F P
0 g
s
.65003 .64257 m .65017 .58708 L .63767 .579 L p .707 .577 .707 r
F P
0 g
s
.77116 .78483 m .76756 .79932 L .79624 .79515 L p .707 .577 .707 r
F P
0 g
s
.79624 .79515 m .79983 .78065 L .77116 .78483 L p .707 .577 .707 r
F P
0 g
s
.81882 .6656 m .81981 .7032 L .83632 .69706 L p .707 .577 .707 r
F P
0 g
s
.83632 .69706 m .83532 .65945 L .81882 .6656 L p .707 .577 .707 r
F P
0 g
s
.67839 .77402 m .68199 .75952 L .66094 .74123 L p .707 .577 .707 r
F P
0 g
s
.68199 .75952 m .67839 .77402 L .70561 .78822 L p .707 .577 .707 r
F P
0 g
s
.65497 .70491 m .65397 .66731 L .64154 .66146 L p .707 .577 .707 r
F P
0 g
s
.79983 .78065 m .79624 .79515 L .81954 .78481 L p .707 .577 .707 r
F P
0 g
s
.81954 .78481 m .82314 .77032 L .79983 .78065 L p .707 .577 .707 r
F P
0 g
s
.83155 .58312 m .83141 .63862 L .83859 .63011 L p .707 .577 .707 r
F P
0 g
s
.83859 .63011 m .83872 .57461 L .83155 .58312 L p .707 .577 .707 r
F P
0 g
s
.63767 .579 m .63753 .63449 L .65003 .64257 L p .707 .577 .707 r
F P
0 g
s
.66094 .74123 m .65735 .75573 L .67839 .77402 L p .707 .577 .707 r
F P
0 g
s
.65735 .75573 m .66094 .74123 L .64813 .72065 L p .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64813 .72065 L .64789 .71916 L p .707 .577 .707 r
F P
0 g
s
.64154 .66146 m .64254 .69906 L .65209 .70355 L p .707 .577 .707 r
F P
0 g
s
.64789 .71916 m .6448 .69978 L p .64456 .73153 L .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64789 .71916 L .64456 .73153 L .707 .577 .707 r
F
.65209 .70355 m .65497 .70491 L p .65324 .6993 L F P
0 g
s
.65324 .6993 m .64154 .66146 L .65209 .70355 L .707 .577 .707 r
F
.83532 .65945 m .83632 .69706 L .84356 .69036 L p F P
0 g
s
.84356 .69036 m .84257 .65276 L .83532 .65945 L p .707 .577 .707 r
F P
0 g
s
.63753 .63449 m .63767 .579 L .63487 .57028 L p .707 .577 .707 r
F P
0 g
s
.64813 .72065 m .64453 .73514 L .65735 .75573 L p .707 .577 .707 r
F P
0 g
s
.82314 .77032 m .81954 .78481 L .83521 .76934 L p .707 .577 .707 r
F P
0 g
s
.83521 .76934 m .8388 .75484 L .82314 .77032 L p .707 .577 .707 r
F P
0 g
s
.64254 .69906 m .64154 .66146 L .63881 .65487 L p .707 .577 .707 r
F P
0 g
s
.63487 .57028 m .63473 .62577 L .63753 .63449 L p .707 .577 .707 r
F P
0 g
s
.83872 .57461 m .83859 .63011 L .83579 .62139 L p .707 .577 .707 r
F P
0 g
s
.83579 .62139 m .83592 .56589 L .83872 .57461 L p .707 .577 .707 r
F P
0 g
s
.63881 .65487 m .63981 .69247 L .64254 .69906 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6448 .69978 m .64121 .71428 L .64453 .73514 L p .707 .577 .707 r
F P
0 g
s
.8388 .75484 m .83521 .76934 L .84169 .75023 L p .707 .577 .707 r
F P
0 g
s
.84169 .75023 m .84529 .73573 L .8388 .75484 L p .707 .577 .707 r
F P
0 g
s
.84257 .65276 m .84356 .69036 L .84083 .68376 L p .707 .577 .707 r
F P
0 g
s
.84083 .68376 m .83984 .64616 L .84257 .65276 L p .707 .577 .707 r
F P
0 g
s
.63473 .62577 m .63487 .57028 L .64204 .56177 L p .707 .577 .707 r
F P
0 g
s
.64121 .71428 m .6448 .69978 L .65129 .68067 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63981 .69247 m .63881 .65487 L .64605 .64817 L p .707 .577 .707 r
F P
0 g
s
.64204 .56177 m .64191 .61727 L .63473 .62577 L p .707 .577 .707 r
F P
0 g
s
.38197 .62129 m .38229 .56568 L .35114 .5636 L p .707 .577 .707 r
F P
0 g
s
.38229 .56568 m .38197 .62129 L .41381 .62072 L p .707 .577 .707 r
F P
0 g
s
.41381 .62072 m .41413 .5651 L .38229 .56568 L p .707 .577 .707 r
F P
0 g
s
.83592 .56589 m .83579 .62139 L .82328 .61331 L p .707 .577 .707 r
F P
0 g
s
.82328 .61331 m .82342 .55782 L .83592 .56589 L p .707 .577 .707 r
F P
0 g
s
.65129 .68067 m .64769 .69517 L .64121 .71428 L p .707 .577 .707 r
F P
0 g
s
.41413 .5651 m .41381 .62072 L .44323 .61755 L p .707 .577 .707 r
F P
0 g
s
.44323 .61755 m .44355 .56193 L .41413 .5651 L p .707 .577 .707 r
F P
0 g
s
.64605 .64817 m .64705 .68577 L .63981 .69247 L p .707 .577 .707 r
F P
0 g
s
.84529 .73573 m .84169 .75023 L .83836 .72936 L p .707 .577 .707 r
F P
0 g
s
.83836 .72936 m .84196 .71486 L .84529 .73573 L p .707 .577 .707 r
F P
0 g
s
.35082 .61922 m .35114 .5636 L .32373 .55908 L p .707 .577 .707 r
F P
0 g
s
.35114 .5636 m .35082 .61922 L .38197 .62129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83984 .64616 m .84083 .68376 L .8284 .67792 L p .707 .577 .707 r
F P
0 g
s
.8284 .67792 m .8274 .64032 L .83984 .64616 L p .707 .577 .707 r
F P
0 g
s
.64191 .61727 m .64204 .56177 L .65849 .55431 L p .707 .577 .707 r
F P
0 g
s
.64769 .69517 m .65129 .68067 L .66695 .66519 L p .707 .577 .707 r
F P
0 g
s
.44355 .56193 m .44323 .61755 L .46735 .61209 L p .707 .577 .707 r
F P
0 g
s
.46735 .61209 m .46767 .55647 L .44355 .56193 L p .707 .577 .707 r
F P
0 g
s
.32373 .55908 m .32341 .6147 L .35082 .61922 L p .707 .577 .707 r
F P
0 g
s
.32341 .6147 m .32373 .55908 L .30275 .55255 L p .707 .577 .707 r
F P
0 g
s
.66695 .66519 m .66336 .67969 L .64769 .69517 L p .707 .577 .707 r
F P
0 g
s
.39343 .68348 m .3911 .64677 L .36003 .64644 L p .707 .577 .707 r
F P
0 g
s
.3911 .64677 m .39343 .68348 L .42522 .68084 L p .707 .577 .707 r
F P
0 g
s
.42522 .68084 m .42289 .64413 L .3911 .64677 L p .707 .577 .707 r
F P
0 g
s
.64705 .68577 m .64605 .64817 L .66256 .64203 L p .707 .577 .707 r
F P
0 g
s
.42289 .64413 m .42522 .68084 L .45462 .67549 L p .707 .577 .707 r
F P
0 g
s
.45462 .67549 m .45229 .63878 L .42289 .64413 L p .707 .577 .707 r
F P
0 g
s
.82342 .55782 m .82328 .61331 L .8023 .60667 L p .707 .577 .707 r
F P
0 g
s
.8023 .60667 m .80243 .55117 L .82342 .55782 L p .707 .577 .707 r
F P
0 g
s
.65849 .55431 m .65836 .6098 L .64191 .61727 L p .707 .577 .707 r
F P
0 g
s
.84196 .71486 m .83836 .72936 L .82555 .70877 L p .707 .577 .707 r
F P
0 g
s
.82555 .70877 m .82915 .69427 L .84196 .71486 L p .707 .577 .707 r
F P
0 g
s
.36235 .68315 m .36003 .64644 L .33271 .64318 L p .707 .577 .707 r
F P
0 g
s
.36003 .64644 m .36235 .68315 L .39343 .68348 L p .707 .577 .707 r
F P
0 g
s
.46767 .55647 m .46735 .61209 L .4838 .60488 L p .707 .577 .707 r
F P
0 g
s
.4838 .60488 m .48412 .54927 L .46767 .55647 L p .707 .577 .707 r
F P
0 g
s
.66336 .67969 m .66695 .66519 L .69026 .65486 L p .707 .577 .707 r
F P
0 g
s
.69026 .65486 m .68666 .66935 L .66336 .67969 L p .707 .577 .707 r
F P
0 g
s
.66256 .64203 m .66355 .67963 L .64705 .68577 L p .707 .577 .707 r
F P
0 g
s
.30275 .55255 m .30243 .60817 L .32341 .6147 L p .707 .577 .707 r
F P
0 g
s
.65836 .6098 m .65849 .55431 L .68261 .54862 L p .707 .577 .707 r
F P
0 g
s
.45229 .63878 m .45462 .67549 L .47875 .66796 L p .707 .577 .707 r
F P
0 g
s
.47875 .66796 m .47642 .63126 L .45229 .63878 L p .707 .577 .707 r
F P
0 g
s
.8274 .64032 m .8284 .67792 L .80747 .6734 L p .707 .577 .707 r
F P
0 g
s
.80747 .6734 m .80648 .63579 L .8274 .64032 L p .707 .577 .707 r
F P
0 g
s
.39287 .69981 m .40084 .68238 L .37257 .66888 L p .707 .577 .707 r
F P
0 g
s
.40084 .68238 m .39287 .69981 L .42188 .71276 L p .707 .577 .707 r
F P
0 g
s
.42188 .71276 m .42985 .69532 L .40084 .68238 L p .707 .577 .707 r
F P
0 g
s
.37257 .66888 m .3646 .68631 L .39287 .69981 L p .707 .577 .707 r
F P
0 g
s
.33271 .64318 m .33504 .67989 L .36235 .68315 L p .707 .577 .707 r
F P
0 g
s
.30243 .60817 m .30275 .55255 L .29024 .54466 L p .707 .577 .707 r
F P
0 g
s
.42985 .69532 m .42188 .71276 L .44879 .72387 L p .707 .577 .707 r
F P
0 g
s
.44879 .72387 m .45676 .70644 L .42985 .69532 L p .707 .577 .707 r
F P
0 g
s
.3646 .68631 m .37257 .66888 L .34782 .65614 L p .707 .577 .707 r
F P
0 g
s
.33504 .67989 m .33271 .64318 L .31184 .63731 L p .707 .577 .707 r
F P
0 g
s
.82915 .69427 m .82555 .70877 L .80451 .69049 L p .707 .577 .707 r
F P
0 g
s
.80451 .69049 m .8081 .67599 L .82915 .69427 L p .707 .577 .707 r
F P
0 g
s
.34782 .65614 m .33984 .67357 L .3646 .68631 L p .707 .577 .707 r
F P
0 g
s
.80243 .55117 m .8023 .60667 L .77489 .6021 L p .707 .577 .707 r
F P
0 g
s
.77489 .6021 m .77503 .54661 L .80243 .55117 L p .707 .577 .707 r
F P
0 g
s
.66355 .67963 m .66256 .64203 L .68671 .63703 L p .707 .577 .707 r
F P
0 g
s
.68261 .54862 m .68248 .60412 L .65836 .6098 L p .707 .577 .707 r
F P
0 g
s
.68666 .66935 m .69026 .65486 L .71893 .65068 L p .707 .577 .707 r
F P
0 g
s
.47642 .63126 m .47875 .66796 L .49525 .65899 L p .707 .577 .707 r
F P
0 g
s
.49525 .65899 m .49292 .62228 L .47642 .63126 L p .707 .577 .707 r
F P
0 g
s
.68248 .60412 m .68261 .54862 L .71203 .54527 L p .707 .577 .707 r
F P
0 g
s
.45676 .70644 m .44879 .72387 L .47096 .73207 L p .707 .577 .707 r
F P
0 g
s
.47096 .73207 m .47894 .71464 L .45676 .70644 L p .707 .577 .707 r
F P
0 g
s
.29024 .54466 m .28992 .60027 L .30243 .60817 L p .707 .577 .707 r
F P
0 g
s
.48412 .54927 m .4838 .60488 L .49098 .59663 L p .707 .577 .707 r
F P
0 g
s
.49098 .59663 m .4913 .54102 L .48412 .54927 L p .707 .577 .707 r
F P
0 g
s
.31184 .63731 m .31416 .67402 L .33504 .67989 L p .707 .577 .707 r
F P
0 g
s
.71893 .65068 m .71533 .66518 L .68666 .66935 L p .707 .577 .707 r
F P
0 g
s
.68671 .63703 m .68771 .67464 L .66355 .67963 L p .707 .577 .707 r
F P
0 g
s
.33984 .67357 m .34782 .65614 L .32899 .6454 L p .707 .577 .707 r
F P
0 g
s
.77729 .67629 m .78088 .66179 L .8081 .67599 L p .707 .577 .707 r
F P
0 g
s
.80648 .63579 m .80747 .6734 L .78011 .67064 L p .707 .577 .707 r
F P
0 g
s
.78088 .66179 m .77729 .67629 L .74656 .66757 L p .707 .577 .707 r
F P
0 g
s
.74656 .66757 m .75016 .65307 L .78088 .66179 L p .707 .577 .707 r
F P
0 g
s
.78011 .67064 m .77911 .63303 L .80648 .63579 L p .707 .577 .707 r
F P
0 g
s
.8081 .67599 m .80451 .69049 L .77729 .67629 L p .707 .577 .707 r
F P
0 g
s
.32899 .6454 m .32102 .66284 L .33984 .67357 L p .707 .577 .707 r
F P
0 g
s
.77503 .54661 m .77489 .6021 L .74374 .60007 L p .707 .577 .707 r
F P
0 g
s
.74374 .60007 m .74387 .54457 L .77503 .54661 L p .707 .577 .707 r
F P
0 g
s
.71533 .66518 m .71893 .65068 L .75016 .65307 L p .707 .577 .707 r
F P
0 g
s
.7119 .60076 m .71203 .54527 L .74387 .54457 L p .707 .577 .707 r
F P
0 g
s
.71203 .54527 m .7119 .60076 L .68248 .60412 L p .707 .577 .707 r
F P
0 g
s
.31416 .67402 m .31184 .63731 L .29944 .62939 L p .707 .577 .707 r
F P
0 g
s
.28992 .60027 m .29024 .54466 L .28744 .53617 L p .707 .577 .707 r
F P
0 g
s
.74387 .54457 m .74374 .60007 L .7119 .60076 L p .707 .577 .707 r
F P
0 g
s
.68771 .67464 m .68671 .63703 L .71615 .63369 L p .707 .577 .707 r
F P
0 g
s
.75016 .65307 m .74656 .66757 L .71533 .66518 L p .707 .577 .707 r
F P
0 g
s
.47894 .71464 m .47096 .73207 L .48624 .73656 L p .707 .577 .707 r
F P
0 g
s
.48624 .73656 m .49421 .71913 L .47894 .71464 L p .707 .577 .707 r
F P
0 g
s
.77911 .63303 m .78011 .67064 L .74899 .66991 L p .707 .577 .707 r
F P
0 g
s
.74899 .66991 m .74799 .63231 L .77911 .63303 L p .707 .577 .707 r
F P
0 g
s
.71615 .63369 m .71715 .67129 L .68771 .67464 L p .707 .577 .707 r
F P
0 g
s
.29944 .62939 m .30177 .6661 L .31416 .67402 L p .707 .577 .707 r
F P
0 g
s
.49292 .62228 m .49525 .65899 L .5025 .64945 L p .707 .577 .707 r
F P
0 g
s
.5025 .64945 m .50017 .61274 L .49292 .62228 L p .707 .577 .707 r
F P
0 g
s
.71715 .67129 m .71615 .63369 L .74799 .63231 L p .707 .577 .707 r
F P
0 g
s
.32102 .66284 m .32899 .6454 L .31793 .63773 L p .707 .577 .707 r
F P
0 g
s
.74799 .63231 m .74899 .66991 L .71715 .67129 L p .707 .577 .707 r
F P
0 g
s
.28744 .53617 m .28712 .59179 L .28992 .60027 L p .707 .577 .707 r
F P
0 g
s
.31793 .63773 m .30996 .65516 L .32102 .66284 L p .707 .577 .707 r
F P
0 g
s
.4913 .54102 m .49098 .59663 L .48818 .58815 L p .707 .577 .707 r
F P
0 g
s
.48818 .58815 m .48849 .53253 L .4913 .54102 L p .707 .577 .707 r
F P
0 g
s
.30177 .6661 m .29944 .62939 L .29673 .62022 L p .707 .577 .707 r
F P
0 g
s
.28712 .59179 m .28744 .53617 L .29462 .52792 L p .707 .577 .707 r
F P
0 g
s
.49421 .71913 m .48624 .73656 L .49311 .73688 L p .707 .577 .707 r
F P
0 g
s
.49311 .73688 m .50108 .71945 L .49421 .71913 L p .707 .577 .707 r
F P
0 g
s
.29673 .62022 m .29906 .65693 L .30177 .6661 L p .707 .577 .707 r
F P
0 g
s
.50017 .61274 m .5025 .64945 L .49979 .64027 L p .707 .577 .707 r
F P
0 g
s
.49979 .64027 m .49747 .60356 L .50017 .61274 L p .707 .577 .707 r
F P
0 g
s
.30996 .65516 m .31793 .63773 L .31574 .63387 L p .707 .577 .707 r
F P
0 g
s
.31574 .63387 m .30777 .6513 L .30996 .65516 L p .707 .577 .707 r
F P
0 g
s
.29462 .52792 m .2943 .58354 L .28712 .59179 L p .707 .577 .707 r
F P
0 g
s
.48849 .53253 m .48818 .58815 L .47567 .58025 L p .707 .577 .707 r
F P
0 g
s
.47567 .58025 m .47599 .52464 L .48849 .53253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29906 .65693 m .29673 .62022 L .30398 .61067 L p .707 .577 .707 r
F P
0 g
s
.2943 .58354 m .29462 .52792 L .31107 .52071 L p .707 .577 .707 r
F P
0 g
s
.50108 .71945 m .49311 .73688 L .49092 .73302 L p .707 .577 .707 r
F P
0 g
s
.49092 .73302 m .49889 .71559 L .50108 .71945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30398 .61067 m .30631 .64738 L .29906 .65693 L p .707 .577 .707 r
F P
0 g
s
.49747 .60356 m .49979 .64027 L .4874 .63236 L p .707 .577 .707 r
F P
0 g
s
.4874 .63236 m .48507 .59565 L .49747 .60356 L p .707 .577 .707 r
F P
0 g
s
.30777 .6513 m .31574 .63387 L .32261 .6342 L p .707 .577 .707 r
F P
0 g
s
.31107 .52071 m .31075 .57633 L .2943 .58354 L p .707 .577 .707 r
F P
0 g
s
.47599 .52464 m .47567 .58025 L .45469 .57373 L p .707 .577 .707 r
F P
0 g
s
.45469 .57373 m .45501 .51811 L .47599 .52464 L p .707 .577 .707 r
F P
0 g
s
.32261 .6342 m .31464 .65163 L .30777 .6513 L p .707 .577 .707 r
F P
0 g
s
.31075 .57633 m .31107 .52071 L .33519 .51526 L p .707 .577 .707 r
F P
0 g
s
.30631 .64738 m .30398 .61067 L .32048 .6017 L p .707 .577 .707 r
F P
0 g
s
.49889 .71559 m .49092 .73302 L .47986 .72535 L p .707 .577 .707 r
F P
0 g
s
.47986 .72535 m .48784 .70792 L .49889 .71559 L p .707 .577 .707 r
F P
0 g
s
.31464 .65163 m .32261 .6342 L .33789 .63868 L p .707 .577 .707 r
F P
0 g
s
.32048 .6017 m .32281 .63841 L .30631 .64738 L p .707 .577 .707 r
F P
0 g
s
.45501 .51811 m .45469 .57373 L .42728 .5692 L p .707 .577 .707 r
F P
0 g
s
.42728 .5692 m .4276 .51359 L .45501 .51811 L p .707 .577 .707 r
F P
0 g
s
.48507 .59565 m .4874 .63236 L .46652 .62648 L p .707 .577 .707 r
F P
0 g
s
.46652 .62648 m .46419 .58977 L .48507 .59565 L p .707 .577 .707 r
F P
0 g
s
.33519 .51526 m .33487 .57088 L .31075 .57633 L p .707 .577 .707 r
F P
0 g
s
.33487 .57088 m .33519 .51526 L .36461 .51209 L p .707 .577 .707 r
F P
0 g
s
.33789 .63868 m .32991 .65611 L .31464 .65163 L p .707 .577 .707 r
F P
0 g
s
.32281 .63841 m .32048 .6017 L .34461 .59417 L p .707 .577 .707 r
F P
0 g
s
.4276 .51359 m .42728 .5692 L .39613 .56713 L p .707 .577 .707 r
F P
0 g
s
.39613 .56713 m .39645 .51151 L .4276 .51359 L p .707 .577 .707 r
F P
0 g
s
.36429 .5677 m .36461 .51209 L .39645 .51151 L p .707 .577 .707 r
F P
0 g
s
.36461 .51209 m .36429 .5677 L .33487 .57088 L p .707 .577 .707 r
F P
0 g
s
.39645 .51151 m .39613 .56713 L .36429 .5677 L p .707 .577 .707 r
F P
0 g
s
.46419 .58977 m .46652 .62648 L .43921 .62322 L p .707 .577 .707 r
F P
0 g
s
.43921 .62322 m .43688 .58651 L .46419 .58977 L p .707 .577 .707 r
F P
0 g
s
.34461 .59417 m .34694 .63088 L .32281 .63841 L p .707 .577 .707 r
F P
0 g
s
.48784 .70792 m .47986 .72535 L .46103 .71462 L p .707 .577 .707 r
F P
0 g
s
.46103 .71462 m .46901 .69719 L .48784 .70792 L p .707 .577 .707 r
F P
0 g
s
.34694 .63088 m .34461 .59417 L .37401 .58882 L p .707 .577 .707 r
F P
0 g
s
.32991 .65611 m .33789 .63868 L .36006 .64688 L p .707 .577 .707 r
F P
0 g
s
.36006 .64688 m .35209 .66431 L .32991 .65611 L p .707 .577 .707 r
F P
0 g
s
.43688 .58651 m .43921 .62322 L .40813 .6229 L p .707 .577 .707 r
F P
0 g
s
.40813 .6229 m .4058 .58619 L .43688 .58651 L p .707 .577 .707 r
F P
0 g
s
.37401 .58882 m .37634 .62553 L .34694 .63088 L p .707 .577 .707 r
F P
0 g
s
.37634 .62553 m .37401 .58882 L .4058 .58619 L p .707 .577 .707 r
F P
0 g
s
.4058 .58619 m .40813 .6229 L .37634 .62553 L p .707 .577 .707 r
F P
0 g
s
.46901 .69719 m .46103 .71462 L .43628 .70188 L p .707 .577 .707 r
F P
0 g
s
.43628 .70188 m .44425 .68445 L .46901 .69719 L p .707 .577 .707 r
F P
0 g
s
.35209 .66431 m .36006 .64688 L .38697 .658 L p .707 .577 .707 r
F P
0 g
s
.38697 .658 m .379 .67543 L .35209 .66431 L p .707 .577 .707 r
F P
0 g
s
.44425 .68445 m .43628 .70188 L .40801 .68837 L p .707 .577 .707 r
F P
0 g
s
.40801 .68837 m .41598 .67094 L .44425 .68445 L p .707 .577 .707 r
F P
0 g
s
.379 .67543 m .38697 .658 L .41598 .67094 L p .707 .577 .707 r
F P
0 g
s
.41598 .67094 m .40801 .68837 L .379 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aooa40009JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00GWoo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001JOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001GOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001A
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0001Moo`T004Eoo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo2000
15YF00<005YFFUH00UYF2000?Goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0007Ool80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol0055oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DGoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo001AOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001AOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001AOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool0055oo`03001JEP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEPD000AJEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol0
1000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001A
Ool00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH000000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
055oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000AJ
EP04001JEUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DGoo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH02@0015YF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP<0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000015YF
000000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0055oo`80009JEP03001JEUYF00=JEP04001J
EUYFFUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000EJEP04001J
EP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo0`0015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH70008
FUH60003FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaL00005FUH00000FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF1P0015YF
00<005YFFUH00P00;Woo000hOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000015YF001JEUYF0P00;Woo000cOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00P005YFFUIJEP00FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8002io
o`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUIJEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00;Woo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01UYF1`000eYF00@005YFFUIJEP80
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH500000eYF001J
EP04FUH60004FUH00`00FUIJEP08FUH01000FUIJEUYF1@000eYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEPX0
00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03
001JEP0000<0009JEP05001JEP00FUH00005FUH60004FUH00`00FUIJEP08FUH400000eYF001JEP02
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YF00001`0015YF00<005YFFUH00UYF3`0015YF0P00;goo000]
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000eYF0P0000=JEP0000000P0000IJEP00FUH005YF0005FUH60004FUH00`00FUIJ
EP05FUH30005FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40005FUH00`00FUH000070003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001J
EUYF00@00003FUH005YF00AJEP03001JEP00008000EJEP04001JEUYFFUH400000eYF001JEP05FUH0
0`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000P0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJ
EP03FUHF0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002io
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002
FUH40006FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF0`000eYF1000
00=JEP00FUH01eYF0`0025YF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF2@0025YF1@000eYF00<005YF00001EYF00@005YF000000QJEP03001JEUYF008000IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool002eoo`03001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00P000eYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF
00000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF0`001UYF0P000eYF00<005YFFUH01UYF0P0000=JEP00FUH01eYF00@005YFFUIJEP8000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo
00@005YF001JEP8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP<000AJEP8000QJEP800003FUH005YF00MJEP04001JEP000008FUH01000FUH000002UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF2P0017oo2`0000=JEP00FUH00eYF1`000eYF00<005YFFUH00P00;Goo000]Ool01P00
FUH00000FUH000EJEQh000AJEP@00003FUH005YF008000EJEP03001JEUYF008000QJEP04001JEUYF
FUH20002FUH6000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP02FUH90004FUH01000FUH000001eYF
0P000UYF10000UYF0P00;Goo000]Ool20003FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040003FUH70003FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH0
1000FUIJEUYF0P001UYF0P0000=JEP00FUH00UYF1000;Goo000]Ool20003FUH30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH000040006
FUH40002FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00P0015YF0`00;Goo000]
Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01`00FUIJEUYF001JEP0000IJEPL000UJEP<00003FUH005YF00]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH00UYF0P00
0eYF0`00;Goo000]Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH000020004FUH50002FUH20006
FUH01000FUIJEUYF0P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000EJEP06001JEUYF001JEP00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUH00002FUH20003FUH30005FUH20004FUH00`00FUIJEP03FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF
00@005YF000002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH00eYF0P0000=JEP00
FUH025YF0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00H005YFFUH005YF0005FUH40008FUH01000FUH0000025YF0`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
15YF001JEP00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP@000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003Ool00000
009JEP03001oogoo02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH80003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60006Ool01@00FUIJEUYF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJEP<000MJEP@000IJEP<0009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEQ/000eoo`04001JEUYF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPH000Eoo`T000=oo`P000AJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00@005YF000000EJEP04001JEUYF0005FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009J
EP<000Ioo`<001Moo`05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP0000<001mo
o`D000EJEP06001JEUYF001JEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<00003FUH005YF00=J
EP8000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30005Ool5000GOol01000FUIJEP00
;Goo000/Ool00`00FUH00003FUH3000COol3000BOol20003FUH01P00FUIJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP<000=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00FUH00005Ool5000HOol3000]Ool002aoo`04001JEP00FUH4000COol5000COol200001eYF001J
EUYF001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP8000AJEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000=J
EP03001JEUYF00=JEP03001JEUYF009JEP8000Ioo`D001Qoo`<002eoo`00;7oo00H005YF000005YF
0002FUH2000AOol5000DOol30002FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
0002FUH00`00FUIJEP03000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEPH000AJEP03001JEUYF009JEP03001oogoo00Ioo`<001Yoo`03001JEP00
02aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0037oo1@004Goo0`000eYF00D005YF001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEP0000<0009JEP<0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP05001JEUYF001JEP03
000015YF001JEUYF0P009Woo00<005YF0000;7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF20001Goo0`002Woo20000UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH00eYF1@000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUH000AJEP@002Qoo`03001JEP0002ao
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF0000009JEP03001JEP0000EJEP<002Qoo`03001JEP0002aoo`00;7oo0P000UYF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEQ800003FUH005YF
00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH30005FUH00`00FUIJEP02000WOol00`00
Oomoo`0[Ool002eoo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH<0003FUH00`00FUIJEP07FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH005YF0P000UYF00<005YFFUH00eYF00D005YFFUIJEP0002Moo`03001oogoo02]oo`00;Goo
00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEPP000=JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00=JEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Woo0P00;Goo000^Ool00`00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH50006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<007ooOol097oo0P00;Goo000_Ool20005FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0400000eYF001JEP04
FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH20004FUH00`00
Oomoo`0SOol2000^Ool0031oo`8000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF009JEPd0009JEP800003FUH005YF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<000AJEP03001JEP0000AJ
EP03001JEUYF009JEP<000=JEP03001oogoo029oo`<002ioo`00<Woo0`0000=JEP00FUH00`000eYF
00<005YFFUH01eYF00<005YFFUH015YF1P000eYF00@005YFFUIJEP<00003FUH005YF00=JEP04001J
EP00FUH200000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUH000030002FUH01@00FUIJEUYF
00000UYF00@005YF000002=oo`03001JEP0002moo`00=Goo0`001UYF00<005YFFUH01eYF00<005YF
FUH0100000=JEP00FUH01UYF100015YF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH0000000H00003FUH005YF00=JEP<0029oo`04001JEUYF000_Ool0
039oo`<00003FUH005YF00MJEP03001JEUYF00AJEPD000EJEP03001JEUYF009JEP@00003FUH005YF
00EJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
15YF0P001UYF0P007goo0P000UYF00<007ooOol0;Woo000`Ool20004FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF000000030004FUH50005FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF00<005YFFUH01UYF0`006Goo0`00
00AJEP00FUH0035oo`00;Woo0`001UYF00<005YFFUH015YF100000=oo`0000002`000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
0000009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00@0019oo`<000=JEP03001JEP00039oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH0100027oo1P001UYF00<005YFFUH01UYF00<005YF
00000P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
00AJEP04001JEP000003FUH00`00FUIJEP05FUH70007Ool400000eYF001JEP03FUH2000cOol002]o
o`8000AJEP03001JEUYF009JEP@000=oo`T000=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000Qo
o`8000EJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP02FUH00`00Oomoo`0b
Ool002]oo`D00003FUH005YF00X000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00aoo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00AJEP04001JEUYFFUH200000eYF000000020006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00=Goo000/Ool20002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000@Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP03FUH20003FUH30004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000F
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01@00
FUIJEP00FUH00`002Goo1`0015YF00<005YFFUH00UYF1@00>Goo000]Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000LOol200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1EYF00<005YFFUH00UYF00H005YFFUH005YF000BOol9000nOol002eoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00@0029oo`<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH01@00FUIJEUYF0000
15YF00<007ooOol0F7oo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH7000YOol20004
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04
FUHA0005FUH00`00Oomoo`1HOol0035oo`d0039oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D000ioo`8000AJEP03001oogoo05Uoo`00Lgoo
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=oo`0000000`0037oo
00@005YFFUH0009JEP03001oogoo05Yoo`00Mgoo1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF
00@005YFFUIJEPH000Ioo`D000Yoo`8000=JEP04001JEUYF001LOol007eoob0000aoo`D000Uoo`03
001JEUYF00AJEP8005eoo`00Sgoo00<005YFFUH015YF00<007ooOol04Goo0`002Goo00<005YFFUH0
1EYF00<007ooOol0G7oo002?Ool20004FUH00`00Oomoo`0MOol00`00FUIJEP05FUH00`00Oomoo`1M
Ool008ioo`03001JEP0000=JEP03001oogoo01aoo`800003FUH005YF00AJEP03001oogoo05ioo`00
SWoo00@005YFFUH0009JEP03001oogoo01Yoo`8000=JEP04001JEUYFFUH2001QOol008eoo`07001J
EUYFFUH005YF00006goo0P001UYF00<005YF0000Hgoo002=Ool00`00FUIJEP02FUH00`00Oomoo`0I
Ool00`00FUIJEP07FUH00`00Oomoo`1ROol008eoo`80009JEP03001oogoo01Qoo`<000MJEP8006Eo
o`00SGoo0P000UYF00<007ooOol05Woo0P000eYF00<005YFFUH00eYF00<007ooOol0IGoo002>Ool3
000GOol20005FUH01000FUIJEUYF0P00J7oo002>Ool00`00FUH0000COol40008FUH3001ZOol008io
o`03001JEP0000moo`@0009JEP03001JEUYF00IJEP8006aoo`00Sgoo1@001Woo1P001eYF00<005YF
FUH00eYF0P00KWoo002?Ool30002FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP03001`Ool0091o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP<007=oo`00TGoo0P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00MWoo002BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP03001h
Ool009=oo`l007]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60386 .74883 m .60355 .69329 L .5724 .69151 L p .707 .577 .707 r
F P
0 g
s
.60355 .69329 m .60386 .74883 L .63571 .74791 L p .707 .577 .707 r
F P
0 g
s
.63571 .74791 m .63539 .69236 L .60355 .69329 L p .707 .577 .707 r
F P
0 g
s
.63539 .69236 m .63571 .74791 L .66513 .74437 L p .707 .577 .707 r
F P
0 g
s
.66513 .74437 m .66481 .68882 L .63539 .69236 L p .707 .577 .707 r
F P
0 g
s
.57271 .74706 m .5724 .69151 L .54499 .6872 L p .707 .577 .707 r
F P
0 g
s
.5724 .69151 m .57271 .74706 L .60386 .74883 L p .707 .577 .707 r
F P
0 g
s
.66481 .68882 m .66513 .74437 L .68924 .73856 L p .707 .577 .707 r
F P
0 g
s
.68924 .73856 m .68893 .68302 L .66481 .68882 L p .707 .577 .707 r
F P
0 g
s
.59187 .80726 m .59419 .77002 L .56312 .76642 L p .707 .577 .707 r
F P
0 g
s
.59419 .77002 m .59187 .80726 L .62366 .80847 L p .707 .577 .707 r
F P
0 g
s
.62366 .80847 m .62599 .77123 L .59419 .77002 L p .707 .577 .707 r
F P
0 g
s
.62599 .77123 m .62366 .80847 L .65306 .80718 L p .707 .577 .707 r
F P
0 g
s
.65306 .80718 m .65539 .76994 L .62599 .77123 L p .707 .577 .707 r
F P
0 g
s
.54499 .6872 m .54531 .74275 L .57271 .74706 L p .707 .577 .707 r
F P
0 g
s
.54531 .74275 m .54499 .6872 L .52401 .68079 L p .707 .577 .707 r
F P
0 g
s
.56079 .80366 m .56312 .76642 L .53581 .76079 L p .707 .577 .707 r
F P
0 g
s
.56312 .76642 m .56079 .80366 L .59187 .80726 L p .707 .577 .707 r
F P
0 g
s
.65539 .76994 m .65306 .80718 L .67719 .8035 L p .707 .577 .707 r
F P
0 g
s
.67719 .8035 m .67952 .76626 L .65539 .76994 L p .707 .577 .707 r
F P
0 g
s
.53581 .76079 m .53348 .79803 L .56079 .80366 L p .707 .577 .707 r
F P
0 g
s
.68893 .68302 m .68924 .73856 L .7057 .73106 L p .707 .577 .707 r
F P
0 g
s
.7057 .73106 m .70538 .67551 L .68893 .68302 L p .707 .577 .707 r
F P
0 g
s
.621 .85854 m .61302 .84281 L .58402 .85575 L p .707 .577 .707 r
F P
0 g
s
.61302 .84281 m .621 .85854 L .64791 .84221 L p .707 .577 .707 r
F P
0 g
s
.64791 .84221 m .63993 .82647 L .61302 .84281 L p .707 .577 .707 r
F P
0 g
s
.52401 .68079 m .52432 .73633 L .54531 .74275 L p .707 .577 .707 r
F P
0 g
s
.59199 .87148 m .58402 .85575 L .55575 .86401 L p .707 .577 .707 r
F P
0 g
s
.58402 .85575 m .59199 .87148 L .621 .85854 L p .707 .577 .707 r
F P
0 g
s
.53348 .79803 m .53581 .76079 L .51493 .75368 L p .707 .577 .707 r
F P
0 g
s
.63993 .82647 m .64791 .84221 L .67008 .82406 L p .707 .577 .707 r
F P
0 g
s
.67008 .82406 m .66211 .80833 L .63993 .82647 L p .707 .577 .707 r
F P
0 g
s
.52432 .73633 m .52401 .68079 L .5115 .67289 L p .707 .577 .707 r
F P
0 g
s
.55575 .86401 m .56372 .87975 L .59199 .87148 L p .707 .577 .707 r
F P
0 g
s
.51493 .75368 m .5126 .79092 L .53348 .79803 L p .707 .577 .707 r
F P
0 g
s
.56372 .87975 m .55575 .86401 L .53099 .8668 L p .707 .577 .707 r
F P
0 g
s
.67952 .76626 m .67719 .8035 L .69369 .79781 L p .707 .577 .707 r
F P
0 g
s
.69369 .79781 m .69602 .76057 L .67952 .76626 L p .707 .577 .707 r
F P
0 g
s
.66211 .80833 m .67008 .82406 L .68536 .80589 L p .707 .577 .707 r
F P
0 g
s
.68536 .80589 m .67738 .79016 L .66211 .80833 L p .707 .577 .707 r
F P
0 g
s
.53099 .8668 m .53896 .88254 L .56372 .87975 L p .707 .577 .707 r
F P
0 g
s
.70538 .67551 m .7057 .73106 L .71287 .72259 L p .707 .577 .707 r
F P
0 g
s
.71287 .72259 m .71255 .66705 L .70538 .67551 L p .707 .577 .707 r
F P
0 g
s
.5115 .67289 m .51182 .72844 L .52432 .73633 L p .707 .577 .707 r
F P
0 g
s
.5126 .79092 m .51493 .75368 L .50253 .74578 L p .707 .577 .707 r
F P
0 g
s
.53896 .88254 m .53099 .8668 L .51216 .86384 L p .707 .577 .707 r
F P
0 g
s
.50253 .74578 m .5002 .78302 L .5126 .79092 L p .707 .577 .707 r
F P
0 g
s
.51182 .72844 m .5115 .67289 L .5087 .66429 L p .707 .577 .707 r
F P
0 g
s
.67738 .79016 m .68536 .80589 L .69223 .78948 L p .707 .577 .707 r
F P
0 g
s
.69223 .78948 m .68426 .77374 L .67738 .79016 L p .707 .577 .707 r
F P
0 g
s
.51216 .86384 m .52014 .87957 L .53896 .88254 L p .707 .577 .707 r
F P
0 g
s
.69602 .76057 m .69369 .79781 L .70094 .79066 L p .707 .577 .707 r
F P
0 g
s
.70094 .79066 m .70327 .75342 L .69602 .76057 L p .707 .577 .707 r
F P
0 g
s
.5087 .66429 m .50902 .71984 L .51182 .72844 L p .707 .577 .707 r
F P
0 g
s
.5002 .78302 m .50253 .74578 L .49983 .73787 L p .707 .577 .707 r
F P
0 g
s
.71255 .66705 m .71287 .72259 L .71007 .71399 L p .707 .577 .707 r
F P
0 g
s
.71007 .71399 m .70975 .65845 L .71255 .66705 L p .707 .577 .707 r
F P
0 g
s
.52014 .87957 m .51216 .86384 L .50111 .85542 L p .707 .577 .707 r
F P
0 g
s
.49518 .8219 m .49518 .32001 L .45086 .31772 L p .707 .577 .707 r
F P
0 g
s
.49983 .73787 m .4975 .77511 L .5002 .78302 L p .707 .577 .707 r
F P
0 g
s
.50902 .71984 m .5087 .66429 L .51588 .65583 L p .707 .577 .707 r
F P
0 g
s
.51588 .65583 m .5162 .71137 L .50902 .71984 L p .707 .577 .707 r
F P
0 g
s
.4975 .77511 m .49983 .73787 L .50708 .73072 L p .707 .577 .707 r
F P
0 g
s
.50708 .73072 m .50475 .76796 L .4975 .77511 L p .707 .577 .707 r
F P
0 g
s
.5162 .71137 m .51588 .65583 L .53233 .64832 L p .707 .577 .707 r
F P
0 g
s
.53233 .64832 m .53265 .70387 L .5162 .71137 L p .707 .577 .707 r
F P
0 g
s
.50475 .76796 m .50708 .73072 L .52357 .72503 L p .707 .577 .707 r
F P
0 g
s
.52357 .72503 m .52124 .76227 L .50475 .76796 L p .707 .577 .707 r
F P
0 g
s
.52124 .76227 m .52357 .72503 L .5477 .72135 L p .707 .577 .707 r
F P
0 g
s
.51376 .84167 m .50579 .82594 L .52106 .80777 L p .707 .577 .707 r
F P
0 g
s
.5477 .72135 m .54538 .75859 L .52124 .76227 L p .707 .577 .707 r
F P
0 g
s
.52106 .80777 m .52903 .8235 L .51376 .84167 L p .707 .577 .707 r
F P
0 g
s
.52903 .8235 m .52106 .80777 L .54324 .78963 L p .707 .577 .707 r
F P
0 g
s
.54324 .78963 m .55121 .80536 L .52903 .8235 L p .707 .577 .707 r
F P
0 g
s
.49518 .32001 m .49518 .8219 L .53996 .82041 L p .707 .577 .707 r
F P
0 g
s
.53265 .70387 m .53233 .64832 L .55645 .64252 L p .707 .577 .707 r
F P
0 g
s
.55645 .64252 m .55676 .69806 L .53265 .70387 L p .707 .577 .707 r
F P
0 g
s
.53996 .82041 m .53996 .31852 L .49518 .32001 L p .707 .577 .707 r
F P
0 g
s
.55676 .69806 m .55645 .64252 L .58587 .63898 L p .707 .577 .707 r
F P
0 g
s
.58587 .63898 m .58618 .69452 L .55676 .69806 L p .707 .577 .707 r
F P
0 g
s
.54538 .75859 m .5477 .72135 L .5771 .72006 L p .707 .577 .707 r
F P
0 g
s
.5771 .72006 m .57478 .7573 L .54538 .75859 L p .707 .577 .707 r
F P
0 g
s
.57478 .7573 m .5771 .72006 L .6089 .72127 L p .707 .577 .707 r
F P
0 g
s
.60713 .77609 m .59916 .76035 L .62742 .75208 L p .707 .577 .707 r
F P
0 g
s
.6089 .72127 m .60657 .75851 L .57478 .7573 L p .707 .577 .707 r
F P
0 g
s
.55121 .80536 m .54324 .78963 L .57015 .77329 L p .707 .577 .707 r
F P
0 g
s
.59916 .76035 m .60713 .77609 L .57812 .78902 L p .707 .577 .707 r
F P
0 g
s
.57812 .78902 m .57015 .77329 L .59916 .76035 L p .707 .577 .707 r
F P
0 g
s
.57015 .77329 m .57812 .78902 L .55121 .80536 L p .707 .577 .707 r
F P
0 g
s
.53996 .31852 m .53996 .82041 L .58083 .81527 L p .707 .577 .707 r
F P
0 g
s
.58083 .81527 m .58083 .31339 L .53996 .31852 L p .707 .577 .707 r
F P
0 g
s
.68426 .77374 m .69223 .78948 L .69003 .77642 L p .707 .577 .707 r
F P
0 g
s
.69003 .77642 m .68206 .76068 L .68426 .77374 L p .707 .577 .707 r
F P
0 g
s
.50111 .85542 m .50908 .87115 L .52014 .87957 L p .707 .577 .707 r
F P
0 g
s
.45086 .81961 m .45086 .31772 L .41136 .31186 L p .707 .577 .707 r
F P
0 g
s
.45086 .31772 m .45086 .81961 L .49518 .8219 L p .707 .577 .707 r
F P
0 g
s
.70327 .75342 m .70094 .79066 L .69823 .78275 L p .707 .577 .707 r
F P
0 g
s
.69823 .78275 m .70056 .74551 L .70327 .75342 L p .707 .577 .707 r
F P
0 g
s
.25626 .71431 m .25612 .65864 L .22497 .65682 L p .707 .577 .707 r
F P
0 g
s
.25612 .65864 m .25626 .71431 L .2881 .7135 L p .707 .577 .707 r
F P
0 g
s
.2881 .7135 m .28797 .65783 L .25612 .65864 L p .707 .577 .707 r
F P
0 g
s
.58618 .69452 m .58587 .63898 L .61771 .63805 L p .707 .577 .707 r
F P
0 g
s
.61771 .63805 m .61803 .6936 L .58618 .69452 L p .707 .577 .707 r
F P
0 g
s
.62742 .75208 m .6354 .76782 L .60713 .77609 L p .707 .577 .707 r
F P
0 g
s
.6354 .76782 m .62742 .75208 L .65218 .7493 L p .707 .577 .707 r
F P
0 g
s
.63997 .72487 m .63764 .76211 L .60657 .75851 L p .707 .577 .707 r
F P
0 g
s
.60657 .75851 m .6089 .72127 L .63997 .72487 L p .707 .577 .707 r
F P
0 g
s
.58083 .31339 m .58083 .81527 L .6138 .807 L p .707 .577 .707 r
F P
0 g
s
.6138 .807 m .6138 .30511 L .58083 .31339 L p .707 .577 .707 r
F P
0 g
s
.70975 .65845 m .71007 .71399 L .69757 .7061 L p .707 .577 .707 r
F P
0 g
s
.69757 .7061 m .69725 .65055 L .70975 .65845 L p .707 .577 .707 r
F P
0 g
s
.28797 .65783 m .2881 .7135 L .31752 .71014 L p .707 .577 .707 r
F P
0 g
s
.31752 .71014 m .31739 .65448 L .28797 .65783 L p .707 .577 .707 r
F P
0 g
s
.50908 .87115 m .50111 .85542 L .49891 .84236 L p .707 .577 .707 r
F P
0 g
s
.41136 .81375 m .41136 .31186 L .38053 .30302 L p .707 .577 .707 r
F P
0 g
s
.41136 .31186 m .41136 .81375 L .45086 .81961 L p .707 .577 .707 r
F P
0 g
s
.22511 .71249 m .22497 .65682 L .19756 .65256 L p .707 .577 .707 r
F P
0 g
s
.22497 .65682 m .22511 .71249 L .25626 .71431 L p .707 .577 .707 r
F P
0 g
s
.68206 .76068 m .69003 .77642 L .67898 .76799 L p .707 .577 .707 r
F P
0 g
s
.67898 .76799 m .67101 .75226 L .68206 .76068 L p .707 .577 .707 r
F P
0 g
s
.49891 .84236 m .50689 .85809 L .50908 .87115 L p .707 .577 .707 r
F P
0 g
s
.31739 .65448 m .31752 .71014 L .34164 .70457 L p .707 .577 .707 r
F P
0 g
s
.34164 .70457 m .3415 .6489 L .31739 .65448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70056 .74551 m .69823 .78275 L .68583 .77485 L p .707 .577 .707 r
F P
0 g
s
.68583 .77485 m .68816 .73761 L .70056 .74551 L p .707 .577 .707 r
F P
0 g
s
.19756 .65256 m .1977 .70823 L .22511 .71249 L p .707 .577 .707 r
F P
0 g
s
.1977 .70823 m .19756 .65256 L .17658 .64626 L p .707 .577 .707 r
F P
0 g
s
.69725 .65055 m .69757 .7061 L .67659 .69968 L p .707 .577 .707 r
F P
0 g
s
.67659 .69968 m .67627 .64414 L .69725 .65055 L p .707 .577 .707 r
F P
0 g
s
.64886 .63983 m .64918 .69537 L .61803 .6936 L p .707 .577 .707 r
F P
0 g
s
.61803 .6936 m .61771 .63805 L .64886 .63983 L p .707 .577 .707 r
F P
0 g
s
.6138 .30511 m .6138 .807 L .63562 .7964 L p .707 .577 .707 r
F P
0 g
s
.65218 .7493 m .66015 .76503 L .6354 .76782 L p .707 .577 .707 r
F P
0 g
s
.63562 .7964 m .63562 .29451 L .6138 .30511 L p .707 .577 .707 r
F P
0 g
s
.25101 .77775 m .25201 .7414 L .22089 .73827 L p .707 .577 .707 r
F P
0 g
s
.25201 .7414 m .25101 .77775 L .28285 .77764 L p .707 .577 .707 r
F P
0 g
s
.28285 .77764 m .28385 .74129 L .25201 .7414 L p .707 .577 .707 r
F P
0 g
s
.50689 .85809 m .49891 .84236 L .50579 .82594 L p .707 .577 .707 r
F P
0 g
s
.3415 .6489 m .34164 .70457 L .35809 .69732 L p .707 .577 .707 r
F P
0 g
s
.35809 .69732 m .35796 .64166 L .3415 .6489 L p .707 .577 .707 r
F P
0 g
s
.28385 .74129 m .28285 .77764 L .31229 .7743 L p .707 .577 .707 r
F P
0 g
s
.31229 .7743 m .31329 .73795 L .28385 .74129 L p .707 .577 .707 r
F P
0 g
s
.38053 .80491 m .38053 .30302 L .3614 .29205 L p .707 .577 .707 r
F P
0 g
s
.38053 .30302 m .38053 .80491 L .41136 .81375 L p .707 .577 .707 r
F P
0 g
s
.17658 .64626 m .17672 .70193 L .1977 .70823 L p .707 .577 .707 r
F P
0 g
s
.21989 .77462 m .22089 .73827 L .19352 .73221 L p .707 .577 .707 r
F P
0 g
s
.22089 .73827 m .21989 .77462 L .25101 .77775 L p .707 .577 .707 r
F P
0 g
s
.67101 .75226 m .67898 .76799 L .66015 .76503 L p .707 .577 .707 r
F P
0 g
s
.66015 .76503 m .65218 .7493 L .67101 .75226 L p .707 .577 .707 r
F P
0 g
s
.50579 .82594 m .51376 .84167 L .50689 .85809 L p .707 .577 .707 r
F P
0 g
s
.17672 .70193 m .17658 .64626 L .16408 .63855 L p .707 .577 .707 r
F P
0 g
s
.31329 .73795 m .31229 .7743 L .33644 .76806 L p .707 .577 .707 r
F P
0 g
s
.33644 .76806 m .33744 .73171 L .31329 .73795 L p .707 .577 .707 r
F P
0 g
s
.68816 .73761 m .68583 .77485 L .66496 .76774 L p .707 .577 .707 r
F P
0 g
s
.66496 .76774 m .66728 .7305 L .68816 .73761 L p .707 .577 .707 r
F P
0 g
s
.21912 .75917 m .22271 .77784 L .25344 .77106 L p .707 .577 .707 r
F P
0 g
s
.25344 .77106 m .24984 .75239 L .21912 .75917 L p .707 .577 .707 r
F P
0 g
s
.24984 .75239 m .25344 .77106 L .28467 .7657 L p .707 .577 .707 r
F P
0 g
s
.19352 .73221 m .19253 .76856 L .21989 .77462 L p .707 .577 .707 r
F P
0 g
s
.67627 .64414 m .67659 .69968 L .64918 .69537 L p .707 .577 .707 r
F P
0 g
s
.64918 .69537 m .64886 .63983 L .67627 .64414 L p .707 .577 .707 r
F P
0 g
s
.19253 .76856 m .19352 .73221 L .1726 .72381 L p .707 .577 .707 r
F P
0 g
s
.28467 .7657 m .28107 .74703 L .24984 .75239 L p .707 .577 .707 r
F P
0 g
s
.28107 .74703 m .28467 .7657 L .31334 .76229 L p .707 .577 .707 r
F P
0 g
s
.1726 .72381 m .1716 .76016 L .19253 .76856 L p .707 .577 .707 r
F P
0 g
s
.1919 .76672 m .19549 .78539 L .22271 .77784 L p .707 .577 .707 r
F P
0 g
s
.22271 .77784 m .21912 .75917 L .1919 .76672 L p .707 .577 .707 r
F P
0 g
s
.31334 .76229 m .30974 .74362 L .28107 .74703 L p .707 .577 .707 r
F P
0 g
s
.16408 .63855 m .16421 .69422 L .17672 .70193 L p .707 .577 .707 r
F P
0 g
s
.35796 .64166 m .35809 .69732 L .36527 .68911 L p .707 .577 .707 r
F P
0 g
s
.36527 .68911 m .36513 .63345 L .35796 .64166 L p .707 .577 .707 r
F P
0 g
s
.33744 .73171 m .33644 .76806 L .35295 .75952 L p .707 .577 .707 r
F P
0 g
s
.35295 .75952 m .35395 .72318 L .33744 .73171 L p .707 .577 .707 r
F P
0 g
s
.66728 .7305 m .66496 .76774 L .63764 .76211 L p .707 .577 .707 r
F P
0 g
s
.63764 .76211 m .63997 .72487 L .66728 .7305 L p .707 .577 .707 r
F P
0 g
s
.63562 .29451 m .63562 .7964 L .64416 .78451 L p .707 .577 .707 r
F P
0 g
s
.64416 .78451 m .64416 .28262 L .63562 .29451 L p .707 .577 .707 r
F P
0 g
s
.30974 .74362 m .31334 .76229 L .33664 .76117 L p .707 .577 .707 r
F P
0 g
s
.17085 .77429 m .17445 .79296 L .19549 .78539 L p .707 .577 .707 r
F P
0 g
s
.19549 .78539 m .1919 .76672 L .17085 .77429 L p .707 .577 .707 r
F P
0 g
s
.33664 .76117 m .33305 .7425 L .30974 .74362 L p .707 .577 .707 r
F P
0 g
s
.16421 .69422 m .16408 .63855 L .16128 .63019 L p .707 .577 .707 r
F P
0 g
s
.36019 .74954 m .36119 .71319 L .35395 .72318 L p .707 .577 .707 r
F P
0 g
s
.36233 .62508 m .36247 .68075 L .34996 .67304 L p .707 .577 .707 r
F P
0 g
s
.34996 .67304 m .34983 .61737 L .36233 .62508 L p .707 .577 .707 r
F P
0 g
s
.35395 .72318 m .35295 .75952 L .36019 .74954 L p .707 .577 .707 r
F P
0 g
s
.36119 .71319 m .36019 .74954 L .35746 .73907 L p .707 .577 .707 r
F P
0 g
s
.35746 .73907 m .35846 .70273 L .36119 .71319 L p .707 .577 .707 r
F P
0 g
s
.3614 .79394 m .3614 .29205 L .35583 .28004 L p .707 .577 .707 r
F P
0 g
s
.36513 .63345 m .36527 .68911 L .36247 .68075 L p .707 .577 .707 r
F P
0 g
s
.36247 .68075 m .36233 .62508 L .36513 .63345 L p .707 .577 .707 r
F P
0 g
s
.3614 .29205 m .3614 .79394 L .38053 .80491 L p .707 .577 .707 r
F P
0 g
s
.1716 .76016 m .1726 .72381 L .16016 .71389 L p .707 .577 .707 r
F P
0 g
s
.16128 .63019 m .16141 .68585 L .16421 .69422 L p .707 .577 .707 r
F P
0 g
s
.16016 .71389 m .15917 .75024 L .1716 .76016 L p .707 .577 .707 r
F P
0 g
s
.33305 .7425 m .33664 .76117 L .35231 .76244 L p .707 .577 .707 r
F P
0 g
s
.35231 .76244 m .34871 .74377 L .33305 .7425 L p .707 .577 .707 r
F P
0 g
s
.15804 .78114 m .16163 .79981 L .17445 .79296 L p .707 .577 .707 r
F P
0 g
s
.17445 .79296 m .17085 .77429 L .15804 .78114 L p .707 .577 .707 r
F P
0 g
s
.15917 .75024 m .16016 .71389 L .15743 .70343 L p .707 .577 .707 r
F P
0 g
s
.16141 .68585 m .16128 .63019 L .16845 .62198 L p .707 .577 .707 r
F P
0 g
s
.64416 .28262 m .64416 .78451 L .6386 .7725 L p .707 .577 .707 r
F P
0 g
s
.6386 .7725 m .6386 .27061 L .64416 .28262 L p .707 .577 .707 r
F P
0 g
s
.15743 .70343 m .15644 .73978 L .15917 .75024 L p .707 .577 .707 r
F P
0 g
s
.34871 .74377 m .35231 .76244 L .35879 .76598 L p .707 .577 .707 r
F P
0 g
s
.35879 .76598 m .3552 .74731 L .34871 .74377 L p .707 .577 .707 r
F P
0 g
s
.3552 .74731 m .35879 .76598 L .35546 .77144 L p .707 .577 .707 r
F P
0 g
s
.35846 .70273 m .35746 .73907 L .34503 .72915 L p .707 .577 .707 r
F P
0 g
s
.34503 .72915 m .34602 .69281 L .35846 .70273 L p .707 .577 .707 r
F P
0 g
s
.35583 .28004 m .35583 .78192 L .3614 .79394 L p .707 .577 .707 r
F P
0 g
s
.35583 .78192 m .35583 .28004 L .36438 .26814 L p .707 .577 .707 r
F P
0 g
s
.16845 .62198 m .16859 .67764 L .16141 .68585 L p .707 .577 .707 r
F P
0 g
s
.15471 .7866 m .15831 .80528 L .16163 .79981 L p .707 .577 .707 r
F P
0 g
s
.16163 .79981 m .15804 .78114 L .15471 .7866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15644 .73978 m .15743 .70343 L .16467 .69344 L p .707 .577 .707 r
F P
0 g
s
.16859 .67764 m .16845 .62198 L .1849 .61473 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16467 .69344 m .16368 .72979 L .15644 .73978 L p .707 .577 .707 r
F P
0 g
s
.1849 .61473 m .18504 .6704 L .16859 .67764 L p .707 .577 .707 r
F P
0 g
s
.34983 .61737 m .34996 .67304 L .32898 .66674 L p .707 .577 .707 r
F P
0 g
s
.32898 .66674 m .32884 .61107 L .34983 .61737 L p .707 .577 .707 r
F P
0 g
s
.35546 .77144 m .35187 .75277 L .3552 .74731 L p .707 .577 .707 r
F P
0 g
s
.6386 .27061 m .6386 .7725 L .61947 .76153 L p .707 .577 .707 r
F P
0 g
s
.61947 .76153 m .61947 .25964 L .6386 .27061 L p .707 .577 .707 r
F P
0 g
s
.1612 .79014 m .16479 .80882 L .15831 .80528 L p .707 .577 .707 r
F P
0 g
s
.15831 .80528 m .15471 .7866 L .1612 .79014 L p .707 .577 .707 r
F P
0 g
s
.18504 .6704 m .1849 .61473 L .20902 .60916 L p .707 .577 .707 r
F P
0 g
s
.36438 .77003 m .36438 .26814 L .3862 .25754 L p .707 .577 .707 r
F P
0 g
s
.36438 .26814 m .36438 .77003 L .35583 .78192 L p .707 .577 .707 r
F P
0 g
s
.16368 .72979 m .16467 .69344 L .18118 .68491 L p .707 .577 .707 r
F P
0 g
s
.32884 .61107 m .32898 .66674 L .30157 .66248 L p .707 .577 .707 r
F P
0 g
s
.30157 .66248 m .30144 .60681 L .32884 .61107 L p .707 .577 .707 r
F P
0 g
s
.20902 .60916 m .20916 .66482 L .18504 .6704 L p .707 .577 .707 r
F P
0 g
s
.18118 .68491 m .18018 .72126 L .16368 .72979 L p .707 .577 .707 r
F P
0 g
s
.34602 .69281 m .34503 .72915 L .3241 .72075 L p .707 .577 .707 r
F P
0 g
s
.3241 .72075 m .3251 .68441 L .34602 .69281 L p .707 .577 .707 r
F P
0 g
s
.35187 .75277 m .35546 .77144 L .34265 .7783 L p .707 .577 .707 r
F P
0 g
s
.20916 .66482 m .20902 .60916 L .23844 .6058 L p .707 .577 .707 r
F P
0 g
s
.34265 .7783 m .33905 .75962 L .35187 .75277 L p .707 .577 .707 r
F P
0 g
s
.17686 .79141 m .18046 .81009 L .16479 .80882 L p .707 .577 .707 r
F P
0 g
s
.16479 .80882 m .1612 .79014 L .17686 .79141 L p .707 .577 .707 r
F P
0 g
s
.30144 .60681 m .30157 .66248 L .27042 .66066 L p .707 .577 .707 r
F P
0 g
s
.27042 .66066 m .27028 .60499 L .30144 .60681 L p .707 .577 .707 r
F P
0 g
s
.18018 .72126 m .18118 .68491 L .20533 .67867 L p .707 .577 .707 r
F P
0 g
s
.61947 .25964 m .61947 .76153 L .58864 .75268 L p .707 .577 .707 r
F P
0 g
s
.58864 .75268 m .58864 .25079 L .61947 .25964 L p .707 .577 .707 r
F P
0 g
s
.23858 .66147 m .23844 .6058 L .27028 .60499 L p .707 .577 .707 r
F P
0 g
s
.23844 .6058 m .23858 .66147 L .20916 .66482 L p .707 .577 .707 r
F P
0 g
s
.27028 .60499 m .27042 .66066 L .23858 .66147 L p .707 .577 .707 r
F P
0 g
s
.3862 .25754 m .3862 .75943 L .36438 .77003 L p .707 .577 .707 r
F P
0 g
s
.3862 .75943 m .3862 .25754 L .41916 .24927 L p .707 .577 .707 r
F P
0 g
s
.20533 .67867 m .20434 .71502 L .18018 .72126 L p .707 .577 .707 r
F P
0 g
s
.3251 .68441 m .3241 .72075 L .29674 .71469 L p .707 .577 .707 r
F P
0 g
s
.29674 .71469 m .29774 .67835 L .3251 .68441 L p .707 .577 .707 r
F P
0 g
s
.33905 .75962 m .34265 .7783 L .3216 .78587 L p .707 .577 .707 r
F P
0 g
s
.20434 .71502 m .20533 .67867 L .23477 .67533 L p .707 .577 .707 r
F P
0 g
s
.3216 .78587 m .31801 .76719 L .33905 .75962 L p .707 .577 .707 r
F P
0 g
s
.72958 .65582 m .72971 .60032 L .69856 .59829 L p .707 .577 .707 r
F P
0 g
s
.72971 .60032 m .72958 .65582 L .76142 .65512 L p .707 .577 .707 r
F P
0 g
s
.76142 .65512 m .76156 .59963 L .72971 .60032 L p .707 .577 .707 r
F P
0 g
s
.20017 .79029 m .20376 .80896 L .18046 .81009 L p .707 .577 .707 r
F P
0 g
s
.18046 .81009 m .17686 .79141 L .20017 .79029 L p .707 .577 .707 r
F P
0 g
s
.76156 .59963 m .76142 .65512 L .79084 .65177 L p .707 .577 .707 r
F P
0 g
s
.79084 .65177 m .79098 .59627 L .76156 .59963 L p .707 .577 .707 r
F P
0 g
s
.29774 .67835 m .29674 .71469 L .26561 .71156 L p .707 .577 .707 r
F P
0 g
s
.26561 .71156 m .26661 .67522 L .29774 .67835 L p .707 .577 .707 r
F P
0 g
s
.69843 .65378 m .69856 .59829 L .67115 .59372 L p .707 .577 .707 r
F P
0 g
s
.69856 .59829 m .69843 .65378 L .72958 .65582 L p .707 .577 .707 r
F P
0 g
s
.23377 .71168 m .23477 .67533 L .26661 .67522 L p .707 .577 .707 r
F P
0 g
s
.23477 .67533 m .23377 .71168 L .20434 .71502 L p .707 .577 .707 r
F P
0 g
s
.73438 .71292 m .73339 .67532 L .70226 .67459 L p .707 .577 .707 r
F P
0 g
s
.73339 .67532 m .73438 .71292 L .76622 .71154 L p .707 .577 .707 r
F P
0 g
s
.76622 .71154 m .76523 .67394 L .73339 .67532 L p .707 .577 .707 r
F P
0 g
s
.58864 .25079 m .58864 .75268 L .54913 .74683 L p .707 .577 .707 r
F P
0 g
s
.54913 .74683 m .54913 .24494 L .58864 .25079 L p .707 .577 .707 r
F P
0 g
s
.26661 .67522 m .26561 .71156 L .23377 .71168 L p .707 .577 .707 r
F P
0 g
s
.76523 .67394 m .76622 .71154 L .79566 .70819 L p .707 .577 .707 r
F P
0 g
s
.79566 .70819 m .79466 .67059 L .76523 .67394 L p .707 .577 .707 r
F P
0 g
s
.79098 .59627 m .79084 .65177 L .81496 .64608 L p .707 .577 .707 r
F P
0 g
s
.81496 .64608 m .81509 .59059 L .79098 .59627 L p .707 .577 .707 r
F P
0 g
s
.41916 .75116 m .41916 .24927 L .46004 .24414 L p .707 .577 .707 r
F P
0 g
s
.41916 .24927 m .41916 .75116 L .3862 .75943 L p .707 .577 .707 r
F P
0 g
s
.70326 .71219 m .70226 .67459 L .6749 .67183 L p .707 .577 .707 r
F P
0 g
s
.70226 .67459 m .70326 .71219 L .73438 .71292 L p .707 .577 .707 r
F P
0 g
s
.31801 .76719 m .3216 .78587 L .29439 .79341 L p .707 .577 .707 r
F P
0 g
s
.22884 .78688 m .23243 .80556 L .20376 .80896 L p .707 .577 .707 r
F P
0 g
s
.20376 .80896 m .20017 .79029 L .22884 .78688 L p .707 .577 .707 r
F P
0 g
s
.29439 .79341 m .29079 .77474 L .31801 .76719 L p .707 .577 .707 r
F P
0 g
s
.67115 .59372 m .67102 .64922 L .69843 .65378 L p .707 .577 .707 r
F P
0 g
s
.67102 .64922 m .67115 .59372 L .65017 .58708 L p .707 .577 .707 r
F P
0 g
s
.79466 .67059 m .79566 .70819 L .81981 .7032 L p .707 .577 .707 r
F P
0 g
s
.81981 .7032 m .81882 .6656 L .79466 .67059 L p .707 .577 .707 r
F P
0 g
s
.6749 .67183 m .6759 .70943 L .70326 .71219 L p .707 .577 .707 r
F P
0 g
s
.54913 .24494 m .54913 .74683 L .50482 .74454 L p .707 .577 .707 r
F P
0 g
s
.50482 .74454 m .50482 .24265 L .54913 .24494 L p .707 .577 .707 r
F P
0 g
s
.29079 .77474 m .29439 .79341 L .26366 .8002 L p .707 .577 .707 r
F P
0 g
s
.81509 .59059 m .81496 .64608 L .83141 .63862 L p .707 .577 .707 r
F P
0 g
s
.83141 .63862 m .83155 .58312 L .81509 .59059 L p .707 .577 .707 r
F P
0 g
s
.6759 .70943 m .6749 .67183 L .65397 .66731 L p .707 .577 .707 r
F P
0 g
s
.46004 .74603 m .46004 .24414 L .50482 .24265 L p .707 .577 .707 r
F P
0 g
s
.46004 .24414 m .46004 .74603 L .41916 .75116 L p .707 .577 .707 r
F P
0 g
s
.26006 .78152 m .26366 .8002 L .23243 .80556 L p .707 .577 .707 r
F P
0 g
s
.23243 .80556 m .22884 .78688 L .26006 .78152 L p .707 .577 .707 r
F P
0 g
s
.26366 .8002 m .26006 .78152 L .29079 .77474 L p .707 .577 .707 r
F P
0 g
s
.65017 .58708 m .65003 .64257 L .67102 .64922 L p .707 .577 .707 r
F P
0 g
s
.73634 .79694 m .73993 .78244 L .70921 .77372 L p .707 .577 .707 r
F P
0 g
s
.73993 .78244 m .73634 .79694 L .76756 .79932 L p .707 .577 .707 r
F P
0 g
s
.76756 .79932 m .77116 .78483 L .73993 .78244 L p .707 .577 .707 r
F P
0 g
s
.50482 .24265 m .50482 .74454 L .46004 .74603 L p .707 .577 .707 r
F P
0 g
s
.70561 .78822 m .70921 .77372 L .68199 .75952 L p .707 .577 .707 r
F P
0 g
s
.70921 .77372 m .70561 .78822 L .73634 .79694 L p .707 .577 .707 r
F P
0 g
s
.65397 .66731 m .65497 .70491 L .6759 .70943 L p .707 .577 .707 r
F P
0 g
s
.65003 .64257 m .65017 .58708 L .63767 .579 L p .707 .577 .707 r
F P
0 g
s
.77116 .78483 m .76756 .79932 L .79624 .79515 L p .707 .577 .707 r
F P
0 g
s
.79624 .79515 m .79983 .78065 L .77116 .78483 L p .707 .577 .707 r
F P
0 g
s
.81882 .6656 m .81981 .7032 L .83632 .69706 L p .707 .577 .707 r
F P
0 g
s
.83632 .69706 m .83532 .65945 L .81882 .6656 L p .707 .577 .707 r
F P
0 g
s
.67839 .77402 m .68199 .75952 L .66094 .74123 L p .707 .577 .707 r
F P
0 g
s
.68199 .75952 m .67839 .77402 L .70561 .78822 L p .707 .577 .707 r
F P
0 g
s
.65497 .70491 m .65397 .66731 L .64154 .66146 L p .707 .577 .707 r
F P
0 g
s
.79983 .78065 m .79624 .79515 L .81954 .78481 L p .707 .577 .707 r
F P
0 g
s
.81954 .78481 m .82314 .77032 L .79983 .78065 L p .707 .577 .707 r
F P
0 g
s
.83155 .58312 m .83141 .63862 L .83859 .63011 L p .707 .577 .707 r
F P
0 g
s
.83859 .63011 m .83872 .57461 L .83155 .58312 L p .707 .577 .707 r
F P
0 g
s
.63767 .579 m .63753 .63449 L .65003 .64257 L p .707 .577 .707 r
F P
0 g
s
.66094 .74123 m .65735 .75573 L .67839 .77402 L p .707 .577 .707 r
F P
0 g
s
.65735 .75573 m .66094 .74123 L .64813 .72065 L p .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64813 .72065 L .64789 .71916 L p .707 .577 .707 r
F P
0 g
s
.64154 .66146 m .64254 .69906 L .65209 .70355 L p .707 .577 .707 r
F P
0 g
s
.64789 .71916 m .6448 .69978 L p .64456 .73153 L .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64789 .71916 L .64456 .73153 L .707 .577 .707 r
F
.65209 .70355 m .65497 .70491 L p .65324 .6993 L F P
0 g
s
.65324 .6993 m .64154 .66146 L .65209 .70355 L .707 .577 .707 r
F
.83532 .65945 m .83632 .69706 L .84356 .69036 L p F P
0 g
s
.84356 .69036 m .84257 .65276 L .83532 .65945 L p .707 .577 .707 r
F P
0 g
s
.63753 .63449 m .63767 .579 L .63487 .57028 L p .707 .577 .707 r
F P
0 g
s
.64813 .72065 m .64453 .73514 L .65735 .75573 L p .707 .577 .707 r
F P
0 g
s
.82314 .77032 m .81954 .78481 L .83521 .76934 L p .707 .577 .707 r
F P
0 g
s
.83521 .76934 m .8388 .75484 L .82314 .77032 L p .707 .577 .707 r
F P
0 g
s
.64254 .69906 m .64154 .66146 L .63881 .65487 L p .707 .577 .707 r
F P
0 g
s
.63487 .57028 m .63473 .62577 L .63753 .63449 L p .707 .577 .707 r
F P
0 g
s
.83872 .57461 m .83859 .63011 L .83579 .62139 L p .707 .577 .707 r
F P
0 g
s
.83579 .62139 m .83592 .56589 L .83872 .57461 L p .707 .577 .707 r
F P
0 g
s
.63881 .65487 m .63981 .69247 L .64254 .69906 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6448 .69978 m .64121 .71428 L .64453 .73514 L p .707 .577 .707 r
F P
0 g
s
.8388 .75484 m .83521 .76934 L .84169 .75023 L p .707 .577 .707 r
F P
0 g
s
.84169 .75023 m .84529 .73573 L .8388 .75484 L p .707 .577 .707 r
F P
0 g
s
.84257 .65276 m .84356 .69036 L .84083 .68376 L p .707 .577 .707 r
F P
0 g
s
.84083 .68376 m .83984 .64616 L .84257 .65276 L p .707 .577 .707 r
F P
0 g
s
.63473 .62577 m .63487 .57028 L .64204 .56177 L p .707 .577 .707 r
F P
0 g
s
.64121 .71428 m .6448 .69978 L .65129 .68067 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63981 .69247 m .63881 .65487 L .64605 .64817 L p .707 .577 .707 r
F P
0 g
s
.64204 .56177 m .64191 .61727 L .63473 .62577 L p .707 .577 .707 r
F P
0 g
s
.38197 .62129 m .38229 .56568 L .35114 .5636 L p .707 .577 .707 r
F P
0 g
s
.38229 .56568 m .38197 .62129 L .41381 .62072 L p .707 .577 .707 r
F P
0 g
s
.41381 .62072 m .41413 .5651 L .38229 .56568 L p .707 .577 .707 r
F P
0 g
s
.83592 .56589 m .83579 .62139 L .82328 .61331 L p .707 .577 .707 r
F P
0 g
s
.82328 .61331 m .82342 .55782 L .83592 .56589 L p .707 .577 .707 r
F P
0 g
s
.65129 .68067 m .64769 .69517 L .64121 .71428 L p .707 .577 .707 r
F P
0 g
s
.41413 .5651 m .41381 .62072 L .44323 .61755 L p .707 .577 .707 r
F P
0 g
s
.44323 .61755 m .44355 .56193 L .41413 .5651 L p .707 .577 .707 r
F P
0 g
s
.64605 .64817 m .64705 .68577 L .63981 .69247 L p .707 .577 .707 r
F P
0 g
s
.84529 .73573 m .84169 .75023 L .83836 .72936 L p .707 .577 .707 r
F P
0 g
s
.83836 .72936 m .84196 .71486 L .84529 .73573 L p .707 .577 .707 r
F P
0 g
s
.35082 .61922 m .35114 .5636 L .32373 .55908 L p .707 .577 .707 r
F P
0 g
s
.35114 .5636 m .35082 .61922 L .38197 .62129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83984 .64616 m .84083 .68376 L .8284 .67792 L p .707 .577 .707 r
F P
0 g
s
.8284 .67792 m .8274 .64032 L .83984 .64616 L p .707 .577 .707 r
F P
0 g
s
.64191 .61727 m .64204 .56177 L .65849 .55431 L p .707 .577 .707 r
F P
0 g
s
.64769 .69517 m .65129 .68067 L .66695 .66519 L p .707 .577 .707 r
F P
0 g
s
.44355 .56193 m .44323 .61755 L .46735 .61209 L p .707 .577 .707 r
F P
0 g
s
.46735 .61209 m .46767 .55647 L .44355 .56193 L p .707 .577 .707 r
F P
0 g
s
.32373 .55908 m .32341 .6147 L .35082 .61922 L p .707 .577 .707 r
F P
0 g
s
.32341 .6147 m .32373 .55908 L .30275 .55255 L p .707 .577 .707 r
F P
0 g
s
.66695 .66519 m .66336 .67969 L .64769 .69517 L p .707 .577 .707 r
F P
0 g
s
.39343 .68348 m .3911 .64677 L .36003 .64644 L p .707 .577 .707 r
F P
0 g
s
.3911 .64677 m .39343 .68348 L .42522 .68084 L p .707 .577 .707 r
F P
0 g
s
.42522 .68084 m .42289 .64413 L .3911 .64677 L p .707 .577 .707 r
F P
0 g
s
.64705 .68577 m .64605 .64817 L .66256 .64203 L p .707 .577 .707 r
F P
0 g
s
.42289 .64413 m .42522 .68084 L .45462 .67549 L p .707 .577 .707 r
F P
0 g
s
.45462 .67549 m .45229 .63878 L .42289 .64413 L p .707 .577 .707 r
F P
0 g
s
.82342 .55782 m .82328 .61331 L .8023 .60667 L p .707 .577 .707 r
F P
0 g
s
.8023 .60667 m .80243 .55117 L .82342 .55782 L p .707 .577 .707 r
F P
0 g
s
.65849 .55431 m .65836 .6098 L .64191 .61727 L p .707 .577 .707 r
F P
0 g
s
.84196 .71486 m .83836 .72936 L .82555 .70877 L p .707 .577 .707 r
F P
0 g
s
.82555 .70877 m .82915 .69427 L .84196 .71486 L p .707 .577 .707 r
F P
0 g
s
.36235 .68315 m .36003 .64644 L .33271 .64318 L p .707 .577 .707 r
F P
0 g
s
.36003 .64644 m .36235 .68315 L .39343 .68348 L p .707 .577 .707 r
F P
0 g
s
.46767 .55647 m .46735 .61209 L .4838 .60488 L p .707 .577 .707 r
F P
0 g
s
.4838 .60488 m .48412 .54927 L .46767 .55647 L p .707 .577 .707 r
F P
0 g
s
.66336 .67969 m .66695 .66519 L .69026 .65486 L p .707 .577 .707 r
F P
0 g
s
.69026 .65486 m .68666 .66935 L .66336 .67969 L p .707 .577 .707 r
F P
0 g
s
.66256 .64203 m .66355 .67963 L .64705 .68577 L p .707 .577 .707 r
F P
0 g
s
.30275 .55255 m .30243 .60817 L .32341 .6147 L p .707 .577 .707 r
F P
0 g
s
.65836 .6098 m .65849 .55431 L .68261 .54862 L p .707 .577 .707 r
F P
0 g
s
.45229 .63878 m .45462 .67549 L .47875 .66796 L p .707 .577 .707 r
F P
0 g
s
.47875 .66796 m .47642 .63126 L .45229 .63878 L p .707 .577 .707 r
F P
0 g
s
.8274 .64032 m .8284 .67792 L .80747 .6734 L p .707 .577 .707 r
F P
0 g
s
.80747 .6734 m .80648 .63579 L .8274 .64032 L p .707 .577 .707 r
F P
0 g
s
.39287 .69981 m .40084 .68238 L .37257 .66888 L p .707 .577 .707 r
F P
0 g
s
.40084 .68238 m .39287 .69981 L .42188 .71276 L p .707 .577 .707 r
F P
0 g
s
.42188 .71276 m .42985 .69532 L .40084 .68238 L p .707 .577 .707 r
F P
0 g
s
.37257 .66888 m .3646 .68631 L .39287 .69981 L p .707 .577 .707 r
F P
0 g
s
.33271 .64318 m .33504 .67989 L .36235 .68315 L p .707 .577 .707 r
F P
0 g
s
.30243 .60817 m .30275 .55255 L .29024 .54466 L p .707 .577 .707 r
F P
0 g
s
.42985 .69532 m .42188 .71276 L .44879 .72387 L p .707 .577 .707 r
F P
0 g
s
.44879 .72387 m .45676 .70644 L .42985 .69532 L p .707 .577 .707 r
F P
0 g
s
.3646 .68631 m .37257 .66888 L .34782 .65614 L p .707 .577 .707 r
F P
0 g
s
.33504 .67989 m .33271 .64318 L .31184 .63731 L p .707 .577 .707 r
F P
0 g
s
.82915 .69427 m .82555 .70877 L .80451 .69049 L p .707 .577 .707 r
F P
0 g
s
.80451 .69049 m .8081 .67599 L .82915 .69427 L p .707 .577 .707 r
F P
0 g
s
.34782 .65614 m .33984 .67357 L .3646 .68631 L p .707 .577 .707 r
F P
0 g
s
.80243 .55117 m .8023 .60667 L .77489 .6021 L p .707 .577 .707 r
F P
0 g
s
.77489 .6021 m .77503 .54661 L .80243 .55117 L p .707 .577 .707 r
F P
0 g
s
.66355 .67963 m .66256 .64203 L .68671 .63703 L p .707 .577 .707 r
F P
0 g
s
.68261 .54862 m .68248 .60412 L .65836 .6098 L p .707 .577 .707 r
F P
0 g
s
.68666 .66935 m .69026 .65486 L .71893 .65068 L p .707 .577 .707 r
F P
0 g
s
.47642 .63126 m .47875 .66796 L .49525 .65899 L p .707 .577 .707 r
F P
0 g
s
.49525 .65899 m .49292 .62228 L .47642 .63126 L p .707 .577 .707 r
F P
0 g
s
.68248 .60412 m .68261 .54862 L .71203 .54527 L p .707 .577 .707 r
F P
0 g
s
.45676 .70644 m .44879 .72387 L .47096 .73207 L p .707 .577 .707 r
F P
0 g
s
.47096 .73207 m .47894 .71464 L .45676 .70644 L p .707 .577 .707 r
F P
0 g
s
.29024 .54466 m .28992 .60027 L .30243 .60817 L p .707 .577 .707 r
F P
0 g
s
.48412 .54927 m .4838 .60488 L .49098 .59663 L p .707 .577 .707 r
F P
0 g
s
.49098 .59663 m .4913 .54102 L .48412 .54927 L p .707 .577 .707 r
F P
0 g
s
.31184 .63731 m .31416 .67402 L .33504 .67989 L p .707 .577 .707 r
F P
0 g
s
.71893 .65068 m .71533 .66518 L .68666 .66935 L p .707 .577 .707 r
F P
0 g
s
.68671 .63703 m .68771 .67464 L .66355 .67963 L p .707 .577 .707 r
F P
0 g
s
.33984 .67357 m .34782 .65614 L .32899 .6454 L p .707 .577 .707 r
F P
0 g
s
.77729 .67629 m .78088 .66179 L .8081 .67599 L p .707 .577 .707 r
F P
0 g
s
.80648 .63579 m .80747 .6734 L .78011 .67064 L p .707 .577 .707 r
F P
0 g
s
.78088 .66179 m .77729 .67629 L .74656 .66757 L p .707 .577 .707 r
F P
0 g
s
.74656 .66757 m .75016 .65307 L .78088 .66179 L p .707 .577 .707 r
F P
0 g
s
.78011 .67064 m .77911 .63303 L .80648 .63579 L p .707 .577 .707 r
F P
0 g
s
.8081 .67599 m .80451 .69049 L .77729 .67629 L p .707 .577 .707 r
F P
0 g
s
.32899 .6454 m .32102 .66284 L .33984 .67357 L p .707 .577 .707 r
F P
0 g
s
.77503 .54661 m .77489 .6021 L .74374 .60007 L p .707 .577 .707 r
F P
0 g
s
.74374 .60007 m .74387 .54457 L .77503 .54661 L p .707 .577 .707 r
F P
0 g
s
.71533 .66518 m .71893 .65068 L .75016 .65307 L p .707 .577 .707 r
F P
0 g
s
.7119 .60076 m .71203 .54527 L .74387 .54457 L p .707 .577 .707 r
F P
0 g
s
.71203 .54527 m .7119 .60076 L .68248 .60412 L p .707 .577 .707 r
F P
0 g
s
.31416 .67402 m .31184 .63731 L .29944 .62939 L p .707 .577 .707 r
F P
0 g
s
.28992 .60027 m .29024 .54466 L .28744 .53617 L p .707 .577 .707 r
F P
0 g
s
.74387 .54457 m .74374 .60007 L .7119 .60076 L p .707 .577 .707 r
F P
0 g
s
.68771 .67464 m .68671 .63703 L .71615 .63369 L p .707 .577 .707 r
F P
0 g
s
.75016 .65307 m .74656 .66757 L .71533 .66518 L p .707 .577 .707 r
F P
0 g
s
.47894 .71464 m .47096 .73207 L .48624 .73656 L p .707 .577 .707 r
F P
0 g
s
.48624 .73656 m .49421 .71913 L .47894 .71464 L p .707 .577 .707 r
F P
0 g
s
.77911 .63303 m .78011 .67064 L .74899 .66991 L p .707 .577 .707 r
F P
0 g
s
.74899 .66991 m .74799 .63231 L .77911 .63303 L p .707 .577 .707 r
F P
0 g
s
.71615 .63369 m .71715 .67129 L .68771 .67464 L p .707 .577 .707 r
F P
0 g
s
.29944 .62939 m .30177 .6661 L .31416 .67402 L p .707 .577 .707 r
F P
0 g
s
.49292 .62228 m .49525 .65899 L .5025 .64945 L p .707 .577 .707 r
F P
0 g
s
.5025 .64945 m .50017 .61274 L .49292 .62228 L p .707 .577 .707 r
F P
0 g
s
.71715 .67129 m .71615 .63369 L .74799 .63231 L p .707 .577 .707 r
F P
0 g
s
.32102 .66284 m .32899 .6454 L .31793 .63773 L p .707 .577 .707 r
F P
0 g
s
.74799 .63231 m .74899 .66991 L .71715 .67129 L p .707 .577 .707 r
F P
0 g
s
.28744 .53617 m .28712 .59179 L .28992 .60027 L p .707 .577 .707 r
F P
0 g
s
.31793 .63773 m .30996 .65516 L .32102 .66284 L p .707 .577 .707 r
F P
0 g
s
.4913 .54102 m .49098 .59663 L .48818 .58815 L p .707 .577 .707 r
F P
0 g
s
.48818 .58815 m .48849 .53253 L .4913 .54102 L p .707 .577 .707 r
F P
0 g
s
.30177 .6661 m .29944 .62939 L .29673 .62022 L p .707 .577 .707 r
F P
0 g
s
.28712 .59179 m .28744 .53617 L .29462 .52792 L p .707 .577 .707 r
F P
0 g
s
.49421 .71913 m .48624 .73656 L .49311 .73688 L p .707 .577 .707 r
F P
0 g
s
.49311 .73688 m .50108 .71945 L .49421 .71913 L p .707 .577 .707 r
F P
0 g
s
.29673 .62022 m .29906 .65693 L .30177 .6661 L p .707 .577 .707 r
F P
0 g
s
.50017 .61274 m .5025 .64945 L .49979 .64027 L p .707 .577 .707 r
F P
0 g
s
.49979 .64027 m .49747 .60356 L .50017 .61274 L p .707 .577 .707 r
F P
0 g
s
.30996 .65516 m .31793 .63773 L .31574 .63387 L p .707 .577 .707 r
F P
0 g
s
.31574 .63387 m .30777 .6513 L .30996 .65516 L p .707 .577 .707 r
F P
0 g
s
.29462 .52792 m .2943 .58354 L .28712 .59179 L p .707 .577 .707 r
F P
0 g
s
.48849 .53253 m .48818 .58815 L .47567 .58025 L p .707 .577 .707 r
F P
0 g
s
.47567 .58025 m .47599 .52464 L .48849 .53253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29906 .65693 m .29673 .62022 L .30398 .61067 L p .707 .577 .707 r
F P
0 g
s
.2943 .58354 m .29462 .52792 L .31107 .52071 L p .707 .577 .707 r
F P
0 g
s
.50108 .71945 m .49311 .73688 L .49092 .73302 L p .707 .577 .707 r
F P
0 g
s
.49092 .73302 m .49889 .71559 L .50108 .71945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30398 .61067 m .30631 .64738 L .29906 .65693 L p .707 .577 .707 r
F P
0 g
s
.49747 .60356 m .49979 .64027 L .4874 .63236 L p .707 .577 .707 r
F P
0 g
s
.4874 .63236 m .48507 .59565 L .49747 .60356 L p .707 .577 .707 r
F P
0 g
s
.30777 .6513 m .31574 .63387 L .32261 .6342 L p .707 .577 .707 r
F P
0 g
s
.31107 .52071 m .31075 .57633 L .2943 .58354 L p .707 .577 .707 r
F P
0 g
s
.47599 .52464 m .47567 .58025 L .45469 .57373 L p .707 .577 .707 r
F P
0 g
s
.45469 .57373 m .45501 .51811 L .47599 .52464 L p .707 .577 .707 r
F P
0 g
s
.32261 .6342 m .31464 .65163 L .30777 .6513 L p .707 .577 .707 r
F P
0 g
s
.31075 .57633 m .31107 .52071 L .33519 .51526 L p .707 .577 .707 r
F P
0 g
s
.30631 .64738 m .30398 .61067 L .32048 .6017 L p .707 .577 .707 r
F P
0 g
s
.49889 .71559 m .49092 .73302 L .47986 .72535 L p .707 .577 .707 r
F P
0 g
s
.47986 .72535 m .48784 .70792 L .49889 .71559 L p .707 .577 .707 r
F P
0 g
s
.31464 .65163 m .32261 .6342 L .33789 .63868 L p .707 .577 .707 r
F P
0 g
s
.32048 .6017 m .32281 .63841 L .30631 .64738 L p .707 .577 .707 r
F P
0 g
s
.45501 .51811 m .45469 .57373 L .42728 .5692 L p .707 .577 .707 r
F P
0 g
s
.42728 .5692 m .4276 .51359 L .45501 .51811 L p .707 .577 .707 r
F P
0 g
s
.48507 .59565 m .4874 .63236 L .46652 .62648 L p .707 .577 .707 r
F P
0 g
s
.46652 .62648 m .46419 .58977 L .48507 .59565 L p .707 .577 .707 r
F P
0 g
s
.33519 .51526 m .33487 .57088 L .31075 .57633 L p .707 .577 .707 r
F P
0 g
s
.33487 .57088 m .33519 .51526 L .36461 .51209 L p .707 .577 .707 r
F P
0 g
s
.33789 .63868 m .32991 .65611 L .31464 .65163 L p .707 .577 .707 r
F P
0 g
s
.32281 .63841 m .32048 .6017 L .34461 .59417 L p .707 .577 .707 r
F P
0 g
s
.4276 .51359 m .42728 .5692 L .39613 .56713 L p .707 .577 .707 r
F P
0 g
s
.39613 .56713 m .39645 .51151 L .4276 .51359 L p .707 .577 .707 r
F P
0 g
s
.36429 .5677 m .36461 .51209 L .39645 .51151 L p .707 .577 .707 r
F P
0 g
s
.36461 .51209 m .36429 .5677 L .33487 .57088 L p .707 .577 .707 r
F P
0 g
s
.39645 .51151 m .39613 .56713 L .36429 .5677 L p .707 .577 .707 r
F P
0 g
s
.46419 .58977 m .46652 .62648 L .43921 .62322 L p .707 .577 .707 r
F P
0 g
s
.43921 .62322 m .43688 .58651 L .46419 .58977 L p .707 .577 .707 r
F P
0 g
s
.34461 .59417 m .34694 .63088 L .32281 .63841 L p .707 .577 .707 r
F P
0 g
s
.48784 .70792 m .47986 .72535 L .46103 .71462 L p .707 .577 .707 r
F P
0 g
s
.46103 .71462 m .46901 .69719 L .48784 .70792 L p .707 .577 .707 r
F P
0 g
s
.34694 .63088 m .34461 .59417 L .37401 .58882 L p .707 .577 .707 r
F P
0 g
s
.32991 .65611 m .33789 .63868 L .36006 .64688 L p .707 .577 .707 r
F P
0 g
s
.36006 .64688 m .35209 .66431 L .32991 .65611 L p .707 .577 .707 r
F P
0 g
s
.43688 .58651 m .43921 .62322 L .40813 .6229 L p .707 .577 .707 r
F P
0 g
s
.40813 .6229 m .4058 .58619 L .43688 .58651 L p .707 .577 .707 r
F P
0 g
s
.37401 .58882 m .37634 .62553 L .34694 .63088 L p .707 .577 .707 r
F P
0 g
s
.37634 .62553 m .37401 .58882 L .4058 .58619 L p .707 .577 .707 r
F P
0 g
s
.4058 .58619 m .40813 .6229 L .37634 .62553 L p .707 .577 .707 r
F P
0 g
s
.46901 .69719 m .46103 .71462 L .43628 .70188 L p .707 .577 .707 r
F P
0 g
s
.43628 .70188 m .44425 .68445 L .46901 .69719 L p .707 .577 .707 r
F P
0 g
s
.35209 .66431 m .36006 .64688 L .38697 .658 L p .707 .577 .707 r
F P
0 g
s
.38697 .658 m .379 .67543 L .35209 .66431 L p .707 .577 .707 r
F P
0 g
s
.44425 .68445 m .43628 .70188 L .40801 .68837 L p .707 .577 .707 r
F P
0 g
s
.40801 .68837 m .41598 .67094 L .44425 .68445 L p .707 .577 .707 r
F P
0 g
s
.379 .67543 m .38697 .658 L .41598 .67094 L p .707 .577 .707 r
F P
0 g
s
.41598 .67094 m .40801 .68837 L .379 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aooa40009JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00GWoo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001JOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001GOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001A
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0001Moo`T004Eoo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo2000
15YF00<005YFFUH00UYF2000?Goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0007Ool80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol0055oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DGoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo001AOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001AOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001AOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool0055oo`03001JEP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEPD000AJEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol0
1000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001A
Ool00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH000000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
055oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000AJ
EP04001JEUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DGoo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH02@0015YF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP<0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000015YF
000000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0055oo`80009JEP03001JEUYF00=JEP04001J
EUYFFUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000EJEP04001J
EP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo0`0015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH70008
FUH60003FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaL00005FUH00000FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF1P0015YF
00<005YFFUH00P00;Woo000hOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000015YF001JEUYF0P00;Woo000cOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00P005YFFUIJEP00FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8002io
o`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUIJEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00;Woo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01UYF1`000eYF00@005YFFUIJEP80
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH500000eYF001J
EP04FUH60004FUH00`00FUIJEP08FUH01000FUIJEUYF1@000eYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEPX0
00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03
001JEP0000<0009JEP05001JEP00FUH00005FUH60004FUH00`00FUIJEP08FUH400000eYF001JEP02
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YF00001`0015YF00<005YFFUH00UYF3`0015YF0P00;goo000]
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000eYF0P0000=JEP0000000P0000IJEP00FUH005YF0005FUH60004FUH00`00FUIJ
EP05FUH30005FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40005FUH00`00FUH000070003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001J
EUYF00@00003FUH005YF00AJEP03001JEP00008000EJEP04001JEUYFFUH400000eYF001JEP05FUH0
0`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000P0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJ
EP03FUHF0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002io
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002
FUH40006FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF0`000eYF1000
00=JEP00FUH01eYF0`0025YF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF2@0025YF1@000eYF00<005YF00001EYF00@005YF000000QJEP03001JEUYF008000IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool002eoo`03001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00P000eYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF
00000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF0`001UYF0P000eYF00<005YFFUH01UYF0P0000=JEP00FUH01eYF00@005YFFUIJEP8000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo
00@005YF001JEP8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP<000AJEP8000QJEP800003FUH005YF00MJEP04001JEP000008FUH01000FUH000002UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF2P0017oo2`0000=JEP00FUH00eYF1`000eYF00<005YFFUH00P00;Goo000]Ool01P00
FUH00000FUH000EJEQh000AJEP@00003FUH005YF008000EJEP03001JEUYF008000QJEP04001JEUYF
FUH20002FUH6000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP02FUH90004FUH01000FUH000001eYF
0P000UYF10000UYF0P00;Goo000]Ool20003FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040003FUH70003FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH0
1000FUIJEUYF0P001UYF0P0000=JEP00FUH00UYF1000;Goo000]Ool20003FUH30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH000040006
FUH40002FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00P0015YF0`00;Goo000]
Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01`00FUIJEUYF001JEP0000IJEPL000UJEP<00003FUH005YF00]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH00UYF0P00
0eYF0`00;Goo000]Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH000020004FUH50002FUH20006
FUH01000FUIJEUYF0P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000EJEP06001JEUYF001JEP00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUH00002FUH20003FUH30005FUH20004FUH00`00FUIJEP03FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF
00@005YF000002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH00eYF0P0000=JEP00
FUH025YF0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00H005YFFUH005YF0005FUH40008FUH01000FUH0000025YF0`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
15YF001JEP00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP@000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003Ool00000
009JEP03001oogoo02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH80003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60006Ool01@00FUIJEUYF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJEP<000MJEP@000IJEP<0009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEQ/000eoo`04001JEUYF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPH000Eoo`T000=oo`P000AJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00@005YF000000EJEP04001JEUYF0005FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009J
EP<000Ioo`<001Moo`05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP0000<001mo
o`D000EJEP06001JEUYF001JEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<00003FUH005YF00=J
EP8000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30005Ool5000GOol01000FUIJEP00
;Goo000/Ool00`00FUH00003FUH3000COol3000BOol20003FUH01P00FUIJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP<000=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00FUH00005Ool5000HOol3000]Ool002aoo`04001JEP00FUH4000COol5000COol200001eYF001J
EUYF001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP8000AJEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000=J
EP03001JEUYF00=JEP03001JEUYF009JEP8000Ioo`D001Qoo`<002eoo`00;7oo00H005YF000005YF
0002FUH2000AOol5000DOol30002FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
0002FUH00`00FUIJEP03000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEPH000AJEP03001JEUYF009JEP03001oogoo00Ioo`<001Yoo`03001JEP00
02aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0037oo1@004Goo0`000eYF00D005YF001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEP0000<0009JEP<0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP05001JEUYF001JEP03
000015YF001JEUYF0P009Woo00<005YF0000;7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF20001Goo0`002Woo20000UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH00eYF1@000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUH000AJEP@002Qoo`03001JEP0002ao
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF0000009JEP03001JEP0000EJEP<002Qoo`03001JEP0002aoo`00;7oo0P000UYF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEQ800003FUH005YF
00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH30005FUH00`00FUIJEP02000WOol00`00
Oomoo`0[Ool002eoo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH<0003FUH00`00FUIJEP07FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH005YF0P000UYF00<005YFFUH00eYF00D005YFFUIJEP0002Moo`03001oogoo02]oo`00;Goo
00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEPP000=JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00=JEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Woo0P00;Goo000^Ool00`00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH50006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<007ooOol097oo0P00;Goo000_Ool20005FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0400000eYF001JEP04
FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH20004FUH00`00
Oomoo`0SOol2000^Ool0031oo`8000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF009JEPd0009JEP800003FUH005YF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<000AJEP03001JEP0000AJ
EP03001JEUYF009JEP<000=JEP03001oogoo029oo`<002ioo`00<Woo0`0000=JEP00FUH00`000eYF
00<005YFFUH01eYF00<005YFFUH015YF1P000eYF00@005YFFUIJEP<00003FUH005YF00=JEP04001J
EP00FUH200000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUH000030002FUH01@00FUIJEUYF
00000UYF00@005YF000002=oo`03001JEP0002moo`00=Goo0`001UYF00<005YFFUH01eYF00<005YF
FUH0100000=JEP00FUH01UYF100015YF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH0000000H00003FUH005YF00=JEP<0029oo`04001JEUYF000_Ool0
039oo`<00003FUH005YF00MJEP03001JEUYF00AJEPD000EJEP03001JEUYF009JEP@00003FUH005YF
00EJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
15YF0P001UYF0P007goo0P000UYF00<007ooOol0;Woo000`Ool20004FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF000000030004FUH50005FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF00<005YFFUH01UYF0`006Goo0`00
00AJEP00FUH0035oo`00;Woo0`001UYF00<005YFFUH015YF100000=oo`0000002`000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
0000009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00@0019oo`<000=JEP03001JEP00039oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH0100027oo1P001UYF00<005YFFUH01UYF00<005YF
00000P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
00AJEP04001JEP000003FUH00`00FUIJEP05FUH70007Ool400000eYF001JEP03FUH2000cOol002]o
o`8000AJEP03001JEUYF009JEP@000=oo`T000=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000Qo
o`8000EJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP02FUH00`00Oomoo`0b
Ool002]oo`D00003FUH005YF00X000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00aoo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00AJEP04001JEUYFFUH200000eYF000000020006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00=Goo000/Ool20002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000@Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP03FUH20003FUH30004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000F
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01@00
FUIJEP00FUH00`002Goo1`0015YF00<005YFFUH00UYF1@00>Goo000]Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000LOol200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1EYF00<005YFFUH00UYF00H005YFFUH005YF000BOol9000nOol002eoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00@0029oo`<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH01@00FUIJEUYF0000
15YF00<007ooOol0F7oo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH7000YOol20004
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04
FUHA0005FUH00`00Oomoo`1HOol0035oo`d0039oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D000ioo`8000AJEP03001oogoo05Uoo`00Lgoo
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=oo`0000000`0037oo
00@005YFFUH0009JEP03001oogoo05Yoo`00Mgoo1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF
00@005YFFUIJEPH000Ioo`D000Yoo`8000=JEP04001JEUYF001LOol007eoob0000aoo`D000Uoo`03
001JEUYF00AJEP8005eoo`00Sgoo00<005YFFUH015YF00<007ooOol04Goo0`002Goo00<005YFFUH0
1EYF00<007ooOol0G7oo002?Ool20004FUH00`00Oomoo`0MOol00`00FUIJEP05FUH00`00Oomoo`1M
Ool008ioo`03001JEP0000=JEP03001oogoo01aoo`800003FUH005YF00AJEP03001oogoo05ioo`00
SWoo00@005YFFUH0009JEP03001oogoo01Yoo`8000=JEP04001JEUYFFUH2001QOol008eoo`07001J
EUYFFUH005YF00006goo0P001UYF00<005YF0000Hgoo002=Ool00`00FUIJEP02FUH00`00Oomoo`0I
Ool00`00FUIJEP07FUH00`00Oomoo`1ROol008eoo`80009JEP03001oogoo01Qoo`<000MJEP8006Eo
o`00SGoo0P000UYF00<007ooOol05Woo0P000eYF00<005YFFUH00eYF00<007ooOol0IGoo002>Ool3
000GOol20005FUH01000FUIJEUYF0P00J7oo002>Ool00`00FUH0000COol40008FUH3001ZOol008io
o`03001JEP0000moo`@0009JEP03001JEUYF00IJEP8006aoo`00Sgoo1@001Woo1P001eYF00<005YF
FUH00eYF0P00KWoo002?Ool30002FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP03001`Ool0091o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP<007=oo`00TGoo0P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00MWoo002BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP03001h
Ool009=oo`l007]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60091 .74909 m .60071 .69353 L .56955 .6917 L p .707 .577 .707 r
F P
0 g
s
.60071 .69353 m .60091 .74909 L .63275 .74822 L p .707 .577 .707 r
F P
0 g
s
.63275 .74822 m .63255 .69266 L .60071 .69353 L p .707 .577 .707 r
F P
0 g
s
.63255 .69266 m .63275 .74822 L .66216 .74474 L p .707 .577 .707 r
F P
0 g
s
.66216 .74474 m .66196 .68918 L .63255 .69266 L p .707 .577 .707 r
F P
0 g
s
.56975 .74726 m .56955 .6917 L .54213 .68736 L p .707 .577 .707 r
F P
0 g
s
.56955 .6917 m .56975 .74726 L .60091 .74909 L p .707 .577 .707 r
F P
0 g
s
.66196 .68918 m .66216 .74474 L .68625 .73899 L p .707 .577 .707 r
F P
0 g
s
.68625 .73899 m .68605 .68343 L .66196 .68918 L p .707 .577 .707 r
F P
0 g
s
.5935 .80827 m .59494 .77108 L .56381 .76813 L p .707 .577 .707 r
F P
0 g
s
.59494 .77108 m .5935 .80827 L .62532 .80872 L p .707 .577 .707 r
F P
0 g
s
.62532 .80872 m .62676 .77153 L .59494 .77108 L p .707 .577 .707 r
F P
0 g
s
.62676 .77153 m .62532 .80872 L .65473 .80662 L p .707 .577 .707 r
F P
0 g
s
.65473 .80662 m .65617 .76944 L .62676 .77153 L p .707 .577 .707 r
F P
0 g
s
.54213 .68736 m .54232 .74292 L .56975 .74726 L p .707 .577 .707 r
F P
0 g
s
.54232 .74292 m .54213 .68736 L .52112 .68093 L p .707 .577 .707 r
F P
0 g
s
.56237 .80532 m .56381 .76813 L .53643 .76297 L p .707 .577 .707 r
F P
0 g
s
.56381 .76813 m .56237 .80532 L .5935 .80827 L p .707 .577 .707 r
F P
0 g
s
.65617 .76944 m .65473 .80662 L .67884 .80219 L p .707 .577 .707 r
F P
0 g
s
.67884 .80219 m .68028 .76501 L .65617 .76944 L p .707 .577 .707 r
F P
0 g
s
.68605 .68343 m .68625 .73899 L .70267 .73154 L p .707 .577 .707 r
F P
0 g
s
.70267 .73154 m .70247 .67598 L .68605 .68343 L p .707 .577 .707 r
F P
0 g
s
.53643 .76297 m .53499 .80016 L .56237 .80532 L p .707 .577 .707 r
F P
0 g
s
.62456 .85548 m .61953 .83828 L .58878 .84702 L p .707 .577 .707 r
F P
0 g
s
.61953 .83828 m .62456 .85548 L .65298 .84367 L p .707 .577 .707 r
F P
0 g
s
.65298 .84367 m .64795 .82647 L .61953 .83828 L p .707 .577 .707 r
F P
0 g
s
.52112 .68093 m .52131 .73649 L .54232 .74292 L p .707 .577 .707 r
F P
0 g
s
.59382 .86423 m .58878 .84702 L .55874 .85185 L p .707 .577 .707 r
F P
0 g
s
.58878 .84702 m .59382 .86423 L .62456 .85548 L p .707 .577 .707 r
F P
0 g
s
.53499 .80016 m .53643 .76297 L .51547 .75611 L p .707 .577 .707 r
F P
0 g
s
.55874 .85185 m .56377 .86905 L .59382 .86423 L p .707 .577 .707 r
F P
0 g
s
.52131 .73649 m .52112 .68093 L .50858 .67304 L p .707 .577 .707 r
F P
0 g
s
.64795 .82647 m .65298 .84367 L .67631 .82996 L p .707 .577 .707 r
F P
0 g
s
.67631 .82996 m .67128 .81275 L .64795 .82647 L p .707 .577 .707 r
F P
0 g
s
.56377 .86905 m .55874 .85185 L .53232 .85228 L p .707 .577 .707 r
F P
0 g
s
.51547 .75611 m .51403 .7933 L .53499 .80016 L p .707 .577 .707 r
F P
0 g
s
.68028 .76501 m .67884 .80219 L .69529 .79586 L p .707 .577 .707 r
F P
0 g
s
.69529 .79586 m .69673 .75867 L .68028 .76501 L p .707 .577 .707 r
F P
0 g
s
.53232 .85228 m .53735 .86949 L .56377 .86905 L p .707 .577 .707 r
F P
0 g
s
.70247 .67598 m .70267 .73154 L .70981 .72311 L p .707 .577 .707 r
F P
0 g
s
.70981 .72311 m .70961 .66755 L .70247 .67598 L p .707 .577 .707 r
F P
0 g
s
.50858 .67304 m .50877 .7286 L .52131 .73649 L p .707 .577 .707 r
F P
0 g
s
.67128 .81275 m .67631 .82996 L .69225 .81568 L p .707 .577 .707 r
F P
0 g
s
.69225 .81568 m .68722 .79848 L .67128 .81275 L p .707 .577 .707 r
F P
0 g
s
.51403 .7933 m .51547 .75611 L .50299 .74822 L p .707 .577 .707 r
F P
0 g
s
.53735 .86949 m .53232 .85228 L .51212 .84828 L p .707 .577 .707 r
F P
0 g
s
.51212 .84828 m .51715 .86549 L .53735 .86949 L p .707 .577 .707 r
F P
0 g
s
.50877 .7286 m .50858 .67304 L .50574 .66446 L p .707 .577 .707 r
F P
0 g
s
.50299 .74822 m .50155 .78541 L .51403 .7933 L p .707 .577 .707 r
F P
0 g
s
.69673 .75867 m .69529 .79586 L .70248 .78825 L p .707 .577 .707 r
F P
0 g
s
.70248 .78825 m .70392 .75106 L .69673 .75867 L p .707 .577 .707 r
F P
0 g
s
.68722 .79848 m .69225 .81568 L .69925 .80224 L p .707 .577 .707 r
F P
0 g
s
.69925 .80224 m .69422 .78503 L .68722 .79848 L p .707 .577 .707 r
F P
0 g
s
.50574 .66446 m .50594 .72002 L .50877 .7286 L p .707 .577 .707 r
F P
0 g
s
.51715 .86549 m .51212 .84828 L .50012 .84024 L p .707 .577 .707 r
F P
0 g
s
.70961 .66755 m .70981 .72311 L .70697 .71453 L p .707 .577 .707 r
F P
0 g
s
.70697 .71453 m .70678 .65897 L .70961 .66755 L p .707 .577 .707 r
F P
0 g
s
.50155 .78541 m .50299 .74822 L .50021 .74006 L p .707 .577 .707 r
F P
0 g
s
.50012 .84024 m .50515 .85745 L .51715 .86549 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.50021 .74006 m .49877 .77725 L .50155 .78541 L p .707 .577 .707 r
F P
0 g
s
.50594 .72002 m .50574 .66446 L .51288 .65604 L p .707 .577 .707 r
F P
0 g
s
.51288 .65604 m .51308 .7116 L .50594 .72002 L p .707 .577 .707 r
F P
0 g
s
.49877 .77725 m .50021 .74006 L .5074 .73245 L p .707 .577 .707 r
F P
0 g
s
.5074 .73245 m .50596 .76963 L .49877 .77725 L p .707 .577 .707 r
F P
0 g
s
.51308 .7116 m .51288 .65604 L .5293 .64858 L p .707 .577 .707 r
F P
0 g
s
.50252 .84616 m .49749 .82895 L .50449 .81551 L p .707 .577 .707 r
F P
0 g
s
.5293 .64858 m .5295 .70414 L .51308 .7116 L p .707 .577 .707 r
F P
0 g
s
.50596 .76963 m .5074 .73245 L .52385 .72611 L p .707 .577 .707 r
F P
0 g
s
.50449 .81551 m .50952 .83271 L .50252 .84616 L p .707 .577 .707 r
F P
0 g
s
.52385 .72611 m .52241 .7633 L .50596 .76963 L p .707 .577 .707 r
F P
0 g
s
.50952 .83271 m .50449 .81551 L .52044 .80123 L p .707 .577 .707 r
F P
0 g
s
.52241 .7633 m .52385 .72611 L .54796 .72168 L p .707 .577 .707 r
F P
0 g
s
.52044 .80123 m .52547 .81843 L .50952 .83271 L p .707 .577 .707 r
F P
0 g
s
.54796 .72168 m .54652 .75887 L .52241 .7633 L p .707 .577 .707 r
F P
0 g
s
.52547 .81843 m .52044 .80123 L .54376 .78752 L p .707 .577 .707 r
F P
0 g
s
.54376 .78752 m .54879 .80472 L .52547 .81843 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53822 .82054 L p .707 .577 .707 r
F P
0 g
s
.5295 .70414 m .5293 .64858 L .55339 .64284 L p .707 .577 .707 r
F P
0 g
s
.55339 .64284 m .55359 .6984 L .5295 .70414 L p .707 .577 .707 r
F P
0 g
s
.53822 .82054 m .53822 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.55359 .6984 m .55339 .64284 L .5828 .63936 L p .707 .577 .707 r
F P
0 g
s
.5828 .63936 m .583 .69492 L .55359 .6984 L p .707 .577 .707 r
F P
0 g
s
.54652 .75887 m .54796 .72168 L .57737 .71959 L p .707 .577 .707 r
F P
0 g
s
.57737 .71959 m .57593 .75678 L .54652 .75887 L p .707 .577 .707 r
F P
0 g
s
.54879 .80472 m .54376 .78752 L .57219 .77571 L p .707 .577 .707 r
F P
0 g
s
.57219 .77571 m .57722 .79291 L .54879 .80472 L p .707 .577 .707 r
F P
0 g
s
.60293 .76696 m .60796 .78417 L .57722 .79291 L p .707 .577 .707 r
F P
0 g
s
.57722 .79291 m .57219 .77571 L .60293 .76696 L p .707 .577 .707 r
F P
0 g
s
.53822 .31865 m .53822 .82054 L .57933 .81554 L p .707 .577 .707 r
F P
0 g
s
.57593 .75678 m .57737 .71959 L .60919 .72004 L p .707 .577 .707 r
F P
0 g
s
.60919 .72004 m .60775 .75723 L .57593 .75678 L p .707 .577 .707 r
F P
0 g
s
.57933 .81554 m .57933 .31366 L .53822 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40994 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.70392 .75106 m .70248 .78825 L .69969 .78009 L p .707 .577 .707 r
F P
0 g
s
.69969 .78009 m .70113 .7429 L .70392 .75106 L p .707 .577 .707 r
F P
0 g
s
.69422 .78503 m .69925 .80224 L .69662 .79094 L p .707 .577 .707 r
F P
0 g
s
.69662 .79094 m .69159 .77374 L .69422 .78503 L p .707 .577 .707 r
F P
0 g
s
.50515 .85745 m .50012 .84024 L .49749 .82895 L p .707 .577 .707 r
F P
0 g
s
.70678 .65897 m .70697 .71453 L .69443 .70664 L p .707 .577 .707 r
F P
0 g
s
.69443 .70664 m .69424 .65108 L .70678 .65897 L p .707 .577 .707 r
F P
0 g
s
.583 .69492 m .5828 .63936 L .61464 .63849 L p .707 .577 .707 r
F P
0 g
s
.61464 .63849 m .61484 .69405 L .583 .69492 L p .707 .577 .707 r
F P
0 g
s
.64032 .72299 m .63888 .76018 L .60775 .75723 L p .707 .577 .707 r
F P
0 g
s
.60775 .75723 m .60919 .72004 L .64032 .72299 L p .707 .577 .707 r
F P
0 g
s
.63298 .76214 m .63801 .77934 L .60796 .78417 L p .707 .577 .707 r
F P
0 g
s
.60796 .78417 m .60293 .76696 L .63298 .76214 L p .707 .577 .707 r
F P
0 g
s
.57933 .31366 m .57933 .81554 L .61267 .80738 L p .707 .577 .707 r
F P
0 g
s
.61267 .80738 m .61267 .3055 L .57933 .31366 L p .707 .577 .707 r
F P
0 g
s
.25506 .71369 m .25498 .65805 L .22382 .6562 L p .707 .577 .707 r
F P
0 g
s
.25498 .65805 m .25506 .71369 L .2869 .71289 L p .707 .577 .707 r
F P
0 g
s
.2869 .71289 m .28682 .65726 L .25498 .65805 L p .707 .577 .707 r
F P
0 g
s
.49749 .82895 m .50252 .84616 L .50515 .85745 L p .707 .577 .707 r
F P
0 g
s
.28682 .65726 m .2869 .71289 L .31631 .70953 L p .707 .577 .707 r
F P
0 g
s
.31631 .70953 m .31622 .65389 L .28682 .65726 L p .707 .577 .707 r
F P
0 g
s
.40994 .81345 m .40994 .31156 L .37953 .30262 L p .707 .577 .707 r
F P
0 g
s
.40994 .31156 m .40994 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.2239 .71184 m .22382 .6562 L .19639 .65189 L p .707 .577 .707 r
F P
0 g
s
.22382 .6562 m .2239 .71184 L .25506 .71369 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31622 .65389 m .31631 .70953 L .3404 .70392 L p .707 .577 .707 r
F P
0 g
s
.3404 .70392 m .34031 .64829 L .31622 .65389 L p .707 .577 .707 r
F P
0 g
s
.69159 .77374 m .69662 .79094 L .68462 .7829 L p .707 .577 .707 r
F P
0 g
s
.68462 .7829 m .67959 .7657 L .69159 .77374 L p .707 .577 .707 r
F P
0 g
s
.70113 .7429 m .69969 .78009 L .68721 .7722 L p .707 .577 .707 r
F P
0 g
s
.68721 .7722 m .68865 .73501 L .70113 .7429 L p .707 .577 .707 r
F P
0 g
s
.19639 .65189 m .19647 .70752 L .2239 .71184 L p .707 .577 .707 r
F P
0 g
s
.19647 .70752 m .19639 .65189 L .17538 .64553 L p .707 .577 .707 r
F P
0 g
s
.69424 .65108 m .69443 .70664 L .67342 .70021 L p .707 .577 .707 r
F P
0 g
s
.67342 .70021 m .67323 .64466 L .69424 .65108 L p .707 .577 .707 r
F P
0 g
s
.6458 .64032 m .646 .69588 L .61484 .69405 L p .707 .577 .707 r
F P
0 g
s
.61484 .69405 m .61464 .63849 L .6458 .64032 L p .707 .577 .707 r
F P
0 g
s
.63801 .77934 m .63298 .76214 L .65939 .7617 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80738 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.25181 .77597 m .25243 .73934 L .22128 .73667 L p .707 .577 .707 r
F P
0 g
s
.25243 .73934 m .25181 .77597 L .28365 .77561 L p .707 .577 .707 r
F P
0 g
s
.28365 .77561 m .28427 .73897 L .25243 .73934 L p .707 .577 .707 r
F P
0 g
s
.28427 .73897 m .28365 .77561 L .31307 .77225 L p .707 .577 .707 r
F P
0 g
s
.31307 .77225 m .31369 .73562 L .28427 .73897 L p .707 .577 .707 r
F P
0 g
s
.34031 .64829 m .3404 .70392 L .35682 .69663 L p .707 .577 .707 r
F P
0 g
s
.35682 .69663 m .35673 .641 L .34031 .64829 L p .707 .577 .707 r
F P
0 g
s
.22066 .77331 m .22128 .73667 L .19388 .73125 L p .707 .577 .707 r
F P
0 g
s
.22128 .73667 m .22066 .77331 L .25181 .77597 L p .707 .577 .707 r
F P
0 g
s
.37953 .8045 m .37953 .30262 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37953 .30262 m .37953 .8045 L .40994 .81345 L p .707 .577 .707 r
F P
0 g
s
.17538 .64553 m .17546 .70117 L .19647 .70752 L p .707 .577 .707 r
F P
0 g
s
.31369 .73562 m .31307 .77225 L .33719 .76624 L p .707 .577 .707 r
F P
0 g
s
.33719 .76624 m .33781 .7296 L .31369 .73562 L p .707 .577 .707 r
F P
0 g
s
.67959 .7657 m .68462 .7829 L .66442 .77891 L p .707 .577 .707 r
F P
0 g
s
.66442 .77891 m .65939 .7617 L .67959 .7657 L p .707 .577 .707 r
F P
0 g
s
.68865 .73501 m .68721 .7722 L .66626 .76534 L p .707 .577 .707 r
F P
0 g
s
.66626 .76534 m .6677 .72815 L .68865 .73501 L p .707 .577 .707 r
F P
0 g
s
.17546 .70117 m .17538 .64553 L .16284 .63776 L p .707 .577 .707 r
F P
0 g
s
.19388 .73125 m .19326 .76788 L .22066 .77331 L p .707 .577 .707 r
F P
0 g
s
.25294 .78809 m .25074 .76898 L .21973 .7725 L p .707 .577 .707 r
F P
0 g
s
.25074 .76898 m .25294 .78809 L .28455 .78443 L p .707 .577 .707 r
F P
0 g
s
.28455 .78443 m .28235 .76532 L .25074 .76898 L p .707 .577 .707 r
F P
0 g
s
.21973 .7725 m .22193 .79161 L .25294 .78809 L p .707 .577 .707 r
F P
0 g
s
.67323 .64466 m .67342 .70021 L .646 .69588 L p .707 .577 .707 r
F P
0 g
s
.646 .69588 m .6458 .64032 L .67323 .64466 L p .707 .577 .707 r
F P
0 g
s
.28235 .76532 m .28455 .78443 L .31366 .78098 L p .707 .577 .707 r
F P
0 g
s
.31366 .78098 m .31146 .76187 L .28235 .76532 L p .707 .577 .707 r
F P
0 g
s
.19326 .76788 m .19388 .73125 L .17291 .72358 L p .707 .577 .707 r
F P
0 g
s
.22193 .79161 m .21973 .7725 L .19235 .77553 L p .707 .577 .707 r
F P
0 g
s
.19235 .77553 m .19455 .79463 L .22193 .79161 L p .707 .577 .707 r
F P
0 g
s
.16284 .63776 m .16292 .69339 L .17546 .70117 L p .707 .577 .707 r
F P
0 g
s
.35673 .641 m .35682 .69663 L .36396 .68836 L p .707 .577 .707 r
F P
0 g
s
.36396 .68836 m .36388 .63273 L .35673 .641 L p .707 .577 .707 r
F P
0 g
s
.31146 .76187 m .31366 .78098 L .33743 .77808 L p .707 .577 .707 r
F P
0 g
s
.33743 .77808 m .33523 .75897 L .31146 .76187 L p .707 .577 .707 r
F P
0 g
s
.17291 .72358 m .17229 .76022 L .19326 .76788 L p .707 .577 .707 r
F P
0 g
s
.33781 .7296 m .33719 .76624 L .35365 .75815 L p .707 .577 .707 r
F P
0 g
s
.35365 .75815 m .35426 .72151 L .33781 .7296 L p .707 .577 .707 r
F P
0 g
s
.65939 .7617 m .66442 .77891 L .63801 .77934 L p .707 .577 .707 r
F P
0 g
s
.6677 .72815 m .66626 .76534 L .63888 .76018 L p .707 .577 .707 r
F P
0 g
s
.63888 .76018 m .64032 .72299 L .6677 .72815 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.19455 .79463 m .19235 .77553 L .17129 .77776 L p .707 .577 .707 r
F P
0 g
s
.17129 .77776 m .17349 .79687 L .19455 .79463 L p .707 .577 .707 r
F P
0 g
s
.17229 .76022 m .17291 .72358 L .16041 .71444 L p .707 .577 .707 r
F P
0 g
s
.16292 .69339 m .16284 .63776 L .16 .62932 L p .707 .577 .707 r
F P
0 g
s
.35426 .72151 m .35365 .75815 L .36083 .74878 L p .707 .577 .707 r
F P
0 g
s
.36083 .74878 m .36145 .71214 L .35426 .72151 L p .707 .577 .707 r
F P
0 g
s
.36145 .71214 m .36083 .74878 L .35804 .73905 L p .707 .577 .707 r
F P
0 g
s
.35804 .73905 m .35865 .70241 L .36145 .71214 L p .707 .577 .707 r
F P
0 g
s
.36104 .62429 m .36112 .67993 L .34858 .67215 L p .707 .577 .707 r
F P
0 g
s
.34858 .67215 m .3485 .61652 L .36104 .62429 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36388 .63273 m .36396 .68836 L .36112 .67993 L p .707 .577 .707 r
F P
0 g
s
.36112 .67993 m .36104 .62429 L .36388 .63273 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37953 .8045 L p .707 .577 .707 r
F P
0 g
s
.33523 .75897 m .33743 .77808 L .35352 .77601 L p .707 .577 .707 r
F P
0 g
s
.35352 .77601 m .35132 .75691 L .33523 .75897 L p .707 .577 .707 r
F P
0 g
s
.16041 .71444 m .1598 .75107 L .17229 .76022 L p .707 .577 .707 r
F P
0 g
s
.16 .62932 m .16009 .68496 L .16292 .69339 L p .707 .577 .707 r
F P
0 g
s
.17349 .79687 m .17129 .77776 L .1586 .779 L p .707 .577 .707 r
F P
0 g
s
.1586 .779 m .1608 .7981 L .17349 .79687 L p .707 .577 .707 r
F P
0 g
s
.1598 .75107 m .16041 .71444 L .15762 .7047 L p .707 .577 .707 r
F P
0 g
s
.16009 .68496 m .16 .62932 L .16714 .62105 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77296 L p .707 .577 .707 r
F P
0 g
s
.63909 .77296 m .63909 .27107 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.35132 .75691 m .35352 .77601 L .36037 .77498 L p .707 .577 .707 r
F P
0 g
s
.36037 .77498 m .35817 .75588 L .35132 .75691 L p .707 .577 .707 r
F P
0 g
s
.15762 .7047 m .157 .74134 L .1598 .75107 L p .707 .577 .707 r
F P
0 g
s
.35817 .75588 m .36037 .77498 L .3573 .77509 L p .707 .577 .707 r
F P
0 g
s
.3573 .77509 m .3551 .75598 L .35817 .75588 L p .707 .577 .707 r
F P
0 g
s
.35865 .70241 m .35804 .73905 L .34554 .7299 L p .707 .577 .707 r
F P
0 g
s
.34554 .7299 m .34616 .69326 L .35865 .70241 L p .707 .577 .707 r
F P
0 g
s
.3551 .75598 m .3573 .77509 L .34461 .77632 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.16714 .62105 m .16723 .67669 L .16009 .68496 L p .707 .577 .707 r
F P
0 g
s
.1608 .7981 m .1586 .779 L .15553 .7791 L p .707 .577 .707 r
F P
0 g
s
.15553 .7791 m .15773 .79821 L .1608 .7981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.157 .74134 m .15762 .7047 L .1648 .69533 L p .707 .577 .707 r
F P
0 g
s
.16723 .67669 m .16714 .62105 L .18356 .61376 L p .707 .577 .707 r
F P
0 g
s
.1648 .69533 m .16419 .73197 L .157 .74134 L p .707 .577 .707 r
F P
0 g
s
.63909 .27107 m .63909 .77296 L .62047 .76193 L p .707 .577 .707 r
F P
0 g
s
.62047 .76193 m .62047 .26004 L .63909 .27107 L p .707 .577 .707 r
F P
0 g
s
.18356 .61376 m .18365 .6694 L .16723 .67669 L p .707 .577 .707 r
F P
0 g
s
.3485 .61652 m .34858 .67215 L .32757 .66579 L p .707 .577 .707 r
F P
0 g
s
.32757 .66579 m .32749 .61016 L .3485 .61652 L p .707 .577 .707 r
F P
0 g
s
.15773 .79821 m .15553 .7791 L .16238 .77807 L p .707 .577 .707 r
F P
0 g
s
.16238 .77807 m .16458 .79718 L .15773 .79821 L p .707 .577 .707 r
F P
0 g
s
.18365 .6694 m .18356 .61376 L .20766 .60816 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38732 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.16419 .73197 m .1648 .69533 L .18126 .68724 L p .707 .577 .707 r
F P
0 g
s
.18126 .68724 m .18064 .72388 L .16419 .73197 L p .707 .577 .707 r
F P
0 g
s
.32749 .61016 m .32757 .66579 L .30015 .66148 L p .707 .577 .707 r
F P
0 g
s
.30015 .66148 m .30006 .60585 L .32749 .61016 L p .707 .577 .707 r
F P
0 g
s
.34461 .77632 m .34241 .75722 L .3551 .75598 L p .707 .577 .707 r
F P
0 g
s
.20766 .60816 m .20774 .66379 L .18365 .6694 L p .707 .577 .707 r
F P
0 g
s
.34616 .69326 m .34554 .7299 L .32457 .72224 L p .707 .577 .707 r
F P
0 g
s
.32457 .72224 m .32519 .6856 L .34616 .69326 L p .707 .577 .707 r
F P
0 g
s
.20774 .66379 m .20766 .60816 L .23706 .60479 L p .707 .577 .707 r
F P
0 g
s
.16458 .79718 m .16238 .77807 L .17847 .77601 L p .707 .577 .707 r
F P
0 g
s
.17847 .77601 m .18067 .79511 L .16458 .79718 L p .707 .577 .707 r
F P
0 g
s
.18064 .72388 m .18126 .68724 L .20538 .68123 L p .707 .577 .707 r
F P
0 g
s
.62047 .26004 m .62047 .76193 L .59006 .75298 L p .707 .577 .707 r
F P
0 g
s
.59006 .75298 m .59006 .2511 L .62047 .26004 L p .707 .577 .707 r
F P
0 g
s
.30006 .60585 m .30015 .66148 L .26899 .65963 L p .707 .577 .707 r
F P
0 g
s
.26899 .65963 m .2689 .604 L .30006 .60585 L p .707 .577 .707 r
F P
0 g
s
.23715 .66043 m .23706 .60479 L .2689 .604 L p .707 .577 .707 r
F P
0 g
s
.23706 .60479 m .23715 .66043 L .20774 .66379 L p .707 .577 .707 r
F P
0 g
s
.2689 .604 m .26899 .65963 L .23715 .66043 L p .707 .577 .707 r
F P
0 g
s
.38732 .25716 m .38732 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38732 .75905 m .38732 .25716 L .42067 .249 L p .707 .577 .707 r
F P
0 g
s
.20538 .68123 m .20476 .71787 L .18064 .72388 L p .707 .577 .707 r
F P
0 g
s
.32519 .6856 m .32457 .72224 L .29717 .71681 L p .707 .577 .707 r
F P
0 g
s
.29717 .71681 m .29779 .68017 L .32519 .6856 L p .707 .577 .707 r
F P
0 g
s
.34241 .75722 m .34461 .77632 L .32355 .77856 L p .707 .577 .707 r
F P
0 g
s
.32355 .77856 m .32135 .75945 L .34241 .75722 L p .707 .577 .707 r
F P
0 g
s
.73101 .65644 m .7311 .60091 L .69994 .59893 L p .707 .577 .707 r
F P
0 g
s
.7311 .60091 m .73101 .65644 L .76285 .65572 L p .707 .577 .707 r
F P
0 g
s
.76285 .65572 m .76294 .60019 L .7311 .60091 L p .707 .577 .707 r
F P
0 g
s
.20476 .71787 m .20538 .68123 L .2348 .67788 L p .707 .577 .707 r
F P
0 g
s
.76294 .60019 m .76285 .65572 L .79226 .65235 L p .707 .577 .707 r
F P
0 g
s
.79226 .65235 m .79234 .59682 L .76294 .60019 L p .707 .577 .707 r
F P
0 g
s
.18067 .79511 m .17847 .77601 L .20224 .77311 L p .707 .577 .707 r
F P
0 g
s
.20224 .77311 m .20444 .79221 L .18067 .79511 L p .707 .577 .707 r
F P
0 g
s
.69985 .65446 m .69994 .59893 L .67251 .59443 L p .707 .577 .707 r
F P
0 g
s
.69994 .59893 m .69985 .65446 L .73101 .65644 L p .707 .577 .707 r
F P
0 g
s
.29779 .68017 m .29717 .71681 L .26602 .71415 L p .707 .577 .707 r
F P
0 g
s
.26602 .71415 m .26664 .67751 L .29779 .68017 L p .707 .577 .707 r
F P
0 g
s
.2348 .67788 m .23418 .71451 L .20476 .71787 L p .707 .577 .707 r
F P
0 g
s
.23418 .71451 m .2348 .67788 L .26664 .67751 L p .707 .577 .707 r
F P
0 g
s
.59006 .2511 m .59006 .75298 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59006 .2511 L p .707 .577 .707 r
F P
0 g
s
.79234 .59682 m .79226 .65235 L .81635 .64668 L p .707 .577 .707 r
F P
0 g
s
.81635 .64668 m .81643 .59115 L .79234 .59682 L p .707 .577 .707 r
F P
0 g
s
.26664 .67751 m .26602 .71415 L .23418 .71451 L p .707 .577 .707 r
F P
0 g
s
.73397 .71481 m .73336 .6774 L .70221 .67622 L p .707 .577 .707 r
F P
0 g
s
.73336 .6774 m .73397 .71481 L .76581 .71367 L p .707 .577 .707 r
F P
0 g
s
.76581 .71367 m .7652 .67626 L .73336 .6774 L p .707 .577 .707 r
F P
0 g
s
.7652 .67626 m .76581 .71367 L .79523 .71031 L p .707 .577 .707 r
F P
0 g
s
.79523 .71031 m .79462 .6729 L .7652 .67626 L p .707 .577 .707 r
F P
0 g
s
.32135 .75945 m .32355 .77856 L .29617 .78159 L p .707 .577 .707 r
F P
0 g
s
.29617 .78159 m .29397 .76248 L .32135 .75945 L p .707 .577 .707 r
F P
0 g
s
.42067 .75089 m .42067 .249 L .46178 .24401 L p .707 .577 .707 r
F P
0 g
s
.42067 .249 m .42067 .75089 L .38732 .75905 L p .707 .577 .707 r
F P
0 g
s
.67251 .59443 m .67242 .64996 L .69985 .65446 L p .707 .577 .707 r
F P
0 g
s
.67242 .64996 m .67251 .59443 L .6515 .58786 L p .707 .577 .707 r
F P
0 g
s
.70283 .71363 m .70221 .67622 L .67481 .67283 L p .707 .577 .707 r
F P
0 g
s
.70221 .67622 m .70283 .71363 L .73397 .71481 L p .707 .577 .707 r
F P
0 g
s
.20444 .79221 m .20224 .77311 L .23135 .76966 L p .707 .577 .707 r
F P
0 g
s
.23135 .76966 m .23355 .78876 L .20444 .79221 L p .707 .577 .707 r
F P
0 g
s
.79462 .6729 m .79523 .71031 L .81935 .70507 L p .707 .577 .707 r
F P
0 g
s
.81935 .70507 m .81874 .66766 L .79462 .6729 L p .707 .577 .707 r
F P
0 g
s
.67481 .67283 m .67543 .71024 L .70283 .71363 L p .707 .577 .707 r
F P
0 g
s
.81643 .59115 m .81635 .64668 L .83277 .63925 L p .707 .577 .707 r
F P
0 g
s
.83277 .63925 m .83285 .58373 L .81643 .59115 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50663 .74455 L p .707 .577 .707 r
F P
0 g
s
.50663 .74455 m .50663 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.29397 .76248 m .29617 .78159 L .26516 .7851 L p .707 .577 .707 r
F P
0 g
s
.26516 .7851 m .26296 .766 L .29397 .76248 L p .707 .577 .707 r
F P
0 g
s
.73484 .78391 m .73704 .76748 L .70603 .76089 L p .707 .577 .707 r
F P
0 g
s
.73704 .76748 m .73484 .78391 L .76645 .78546 L p .707 .577 .707 r
F P
0 g
s
.76645 .78546 m .76864 .76903 L .73704 .76748 L p .707 .577 .707 r
F P
0 g
s
.6515 .58786 m .65141 .64339 L .67242 .64996 L p .707 .577 .707 r
F P
0 g
s
.67543 .71024 m .67481 .67283 L .65384 .66756 L p .707 .577 .707 r
F P
0 g
s
.46178 .7459 m .46178 .24401 L .50663 .24266 L p .707 .577 .707 r
F P
0 g
s
.46178 .24401 m .46178 .7459 L .42067 .75089 L p .707 .577 .707 r
F P
0 g
s
.23355 .78876 m .23135 .76966 L .26296 .766 L p .707 .577 .707 r
F P
0 g
s
.26296 .766 m .26516 .7851 L .23355 .78876 L p .707 .577 .707 r
F P
0 g
s
.70383 .77732 m .70603 .76089 L .67865 .74991 L p .707 .577 .707 r
F P
0 g
s
.70603 .76089 m .70383 .77732 L .73484 .78391 L p .707 .577 .707 r
F P
0 g
s
.76864 .76903 m .76645 .78546 L .79556 .78182 L p .707 .577 .707 r
F P
0 g
s
.79556 .78182 m .79776 .76539 L .76864 .76903 L p .707 .577 .707 r
F P
0 g
s
.50663 .24266 m .50663 .74455 L .46178 .7459 L p .707 .577 .707 r
F P
0 g
s
.65141 .64339 m .6515 .58786 L .63896 .57986 L p .707 .577 .707 r
F P
0 g
s
.65384 .66756 m .65445 .70497 L .67543 .71024 L p .707 .577 .707 r
F P
0 g
s
.81874 .66766 m .81935 .70507 L .83581 .69846 L p .707 .577 .707 r
F P
0 g
s
.83581 .69846 m .83519 .66104 L .81874 .66766 L p .707 .577 .707 r
F P
0 g
s
.67865 .74991 m .67645 .76634 L .70383 .77732 L p .707 .577 .707 r
F P
0 g
s
.67645 .76634 m .67865 .74991 L .65759 .73562 L p .707 .577 .707 r
F P
0 g
s
.79776 .76539 m .79556 .78182 L .81933 .77336 L p .707 .577 .707 r
F P
0 g
s
.81933 .77336 m .82152 .75693 L .79776 .76539 L p .707 .577 .707 r
F P
0 g
s
.83285 .58373 m .83277 .63925 L .83991 .6308 L p .707 .577 .707 r
F P
0 g
s
.83991 .6308 m .84 .57527 L .83285 .58373 L p .707 .577 .707 r
F P
0 g
s
.63896 .57986 m .63888 .63539 L .65141 .64339 L p .707 .577 .707 r
F P
0 g
s
.65445 .70497 m .65384 .66756 L .64134 .66093 L p .707 .577 .707 r
F P
0 g
s
.65759 .73562 m .65539 .75205 L .67645 .76634 L p .707 .577 .707 r
F P
0 g
s
.64134 .66093 m .64196 .69834 L .65445 .70497 L p .707 .577 .707 r
F P
0 g
s
.65539 .75205 m .65759 .73562 L .6449 .71941 L p .707 .577 .707 r
F P
0 g
s
.63888 .63539 m .63896 .57986 L .63612 .5712 L p .707 .577 .707 r
F P
0 g
s
.82152 .75693 m .81933 .77336 L .83542 .76089 L p .707 .577 .707 r
F P
0 g
s
.83542 .76089 m .83762 .74446 L .82152 .75693 L p .707 .577 .707 r
F P
0 g
s
.83519 .66104 m .83581 .69846 L .84299 .69112 L p .707 .577 .707 r
F P
0 g
s
.84299 .69112 m .84238 .65371 L .83519 .66104 L p .707 .577 .707 r
F P
0 g
s
.6449 .71941 m .6427 .73584 L .65539 .75205 L p .707 .577 .707 r
F P
0 g
s
.63612 .5712 m .63604 .62673 L .63888 .63539 L p .707 .577 .707 r
F P
0 g
s
.64196 .69834 m .64134 .66093 L .63855 .65359 L p .707 .577 .707 r
F P
0 g
s
.84 .57527 m .83991 .6308 L .83707 .62215 L p .707 .577 .707 r
F P
0 g
s
.83707 .62215 m .83716 .56662 L .84 .57527 L p .707 .577 .707 r
F P
0 g
s
.6427 .73584 m .6449 .71941 L .64183 .70287 L p .707 .577 .707 r
F P
0 g
s
.83762 .74446 m .83542 .76089 L .84227 .74563 L p .707 .577 .707 r
F P
0 g
s
.84227 .74563 m .84447 .7292 L .83762 .74446 L p .707 .577 .707 r
F P
0 g
s
.63855 .65359 m .63917 .691 L .64196 .69834 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63604 .62673 m .63612 .5712 L .64326 .56275 L p .707 .577 .707 r
F P
0 g
s
.84238 .65371 m .84299 .69112 L .8402 .68378 L p .707 .577 .707 r
F P
0 g
s
.8402 .68378 m .83959 .64636 L .84238 .65371 L p .707 .577 .707 r
F P
0 g
s
.64183 .70287 m .63963 .7193 L .6427 .73584 L p .707 .577 .707 r
F P
0 g
s
.64326 .56275 m .64318 .61828 L .63604 .62673 L p .707 .577 .707 r
F P
0 g
s
.63917 .691 m .63855 .65359 L .64574 .64625 L p .707 .577 .707 r
F P
0 g
s
.83716 .56662 m .83707 .62215 L .82454 .61415 L p .707 .577 .707 r
F P
0 g
s
.82454 .61415 m .82462 .55862 L .83716 .56662 L p .707 .577 .707 r
F P
0 g
s
.63963 .7193 m .64183 .70287 L .64867 .68762 L p .707 .577 .707 r
F P
0 g
s
.38516 .62104 m .38536 .56544 L .3542 .56343 L p .707 .577 .707 r
F P
0 g
s
.38536 .56544 m .38516 .62104 L .417 .62039 L p .707 .577 .707 r
F P
0 g
s
.417 .62039 m .4172 .56479 L .38536 .56544 L p .707 .577 .707 r
F P
0 g
s
.84447 .7292 m .84227 .74563 L .8392 .72909 L p .707 .577 .707 r
F P
0 g
s
.8392 .72909 m .8414 .71266 L .84447 .7292 L p .707 .577 .707 r
F P
0 g
s
.4172 .56479 m .417 .62039 L .44641 .61714 L p .707 .577 .707 r
F P
0 g
s
.44641 .61714 m .4466 .56154 L .4172 .56479 L p .707 .577 .707 r
F P
0 g
s
.64574 .64625 m .64635 .68367 L .63917 .691 L p .707 .577 .707 r
F P
0 g
s
.354 .61904 m .3542 .56343 L .32677 .55896 L p .707 .577 .707 r
F P
0 g
s
.3542 .56343 m .354 .61904 L .38516 .62104 L p .707 .577 .707 r
F P
0 g
s
.64867 .68762 m .64648 .70405 L .63963 .7193 L p .707 .577 .707 r
F P
0 g
s
.64318 .61828 m .64326 .56275 L .65968 .55532 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83959 .64636 m .8402 .68378 L .82771 .67715 L p .707 .577 .707 r
F P
0 g
s
.82771 .67715 m .82709 .63974 L .83959 .64636 L p .707 .577 .707 r
F P
0 g
s
.4466 .56154 m .44641 .61714 L .4705 .61161 L p .707 .577 .707 r
F P
0 g
s
.4705 .61161 m .47069 .55601 L .4466 .56154 L p .707 .577 .707 r
F P
0 g
s
.32677 .55896 m .32657 .61456 L .354 .61904 L p .707 .577 .707 r
F P
0 g
s
.32657 .61456 m .32677 .55896 L .30576 .55246 L p .707 .577 .707 r
F P
0 g
s
.39225 .68254 m .39081 .64568 L .35968 .64476 L p .707 .577 .707 r
F P
0 g
s
.39081 .64568 m .39225 .68254 L .42407 .68061 L p .707 .577 .707 r
F P
0 g
s
.42407 .68061 m .42263 .64375 L .39081 .64568 L p .707 .577 .707 r
F P
0 g
s
.82462 .55862 m .82454 .61415 L .80353 .60757 L p .707 .577 .707 r
F P
0 g
s
.80353 .60757 m .80361 .55204 L .82462 .55862 L p .707 .577 .707 r
F P
0 g
s
.65968 .55532 m .6596 .61085 L .64318 .61828 L p .707 .577 .707 r
F P
0 g
s
.64648 .70405 m .64867 .68762 L .66477 .67515 L p .707 .577 .707 r
F P
0 g
s
.64635 .68367 m .64574 .64625 L .66219 .63964 L p .707 .577 .707 r
F P
0 g
s
.42263 .64375 m .42407 .68061 L .45348 .67601 L p .707 .577 .707 r
F P
0 g
s
.45348 .67601 m .45203 .63915 L .42263 .64375 L p .707 .577 .707 r
F P
0 g
s
.8414 .71266 m .8392 .72909 L .82651 .71288 L p .707 .577 .707 r
F P
0 g
s
.82651 .71288 m .82871 .69645 L .8414 .71266 L p .707 .577 .707 r
F P
0 g
s
.36112 .68162 m .35968 .64476 L .3323 .64107 L p .707 .577 .707 r
F P
0 g
s
.35968 .64476 m .36112 .68162 L .39225 .68254 L p .707 .577 .707 r
F P
0 g
s
.47069 .55601 m .4705 .61161 L .48692 .60434 L p .707 .577 .707 r
F P
0 g
s
.48692 .60434 m .48711 .54874 L .47069 .55601 L p .707 .577 .707 r
F P
0 g
s
.6596 .61085 m .65968 .55532 L .68378 .54965 L p .707 .577 .707 r
F P
0 g
s
.66219 .63964 m .66281 .67705 L .64635 .68367 L p .707 .577 .707 r
F P
0 g
s
.66477 .67515 m .66257 .69158 L .64648 .70405 L p .707 .577 .707 r
F P
0 g
s
.30576 .55246 m .30556 .60806 L .32657 .61456 L p .707 .577 .707 r
F P
0 g
s
.45203 .63915 m .45348 .67601 L .47759 .66919 L p .707 .577 .707 r
F P
0 g
s
.47759 .66919 m .47614 .63233 L .45203 .63915 L p .707 .577 .707 r
F P
0 g
s
.39204 .70906 m .39707 .69073 L .36702 .68154 L p .707 .577 .707 r
F P
0 g
s
.39707 .69073 m .39204 .70906 L .42278 .71686 L p .707 .577 .707 r
F P
0 g
s
.42278 .71686 m .42781 .69853 L .39707 .69073 L p .707 .577 .707 r
F P
0 g
s
.82709 .63974 m .82771 .67715 L .80674 .67188 L p .707 .577 .707 r
F P
0 g
s
.80674 .67188 m .80612 .63447 L .82709 .63974 L p .707 .577 .707 r
F P
0 g
s
.3323 .64107 m .33374 .67793 L .36112 .68162 L p .707 .577 .707 r
F P
0 g
s
.36702 .68154 m .36199 .69987 L .39204 .70906 L p .707 .577 .707 r
F P
0 g
s
.42781 .69853 m .42278 .71686 L .45121 .7225 L p .707 .577 .707 r
F P
0 g
s
.45121 .7225 m .45624 .70417 L .42781 .69853 L p .707 .577 .707 r
F P
0 g
s
.30556 .60806 m .30576 .55246 L .29322 .54457 L p .707 .577 .707 r
F P
0 g
s
.36199 .69987 m .36702 .68154 L .3406 .67187 L p .707 .577 .707 r
F P
0 g
s
.80361 .55204 m .80353 .60757 L .7761 .60307 L p .707 .577 .707 r
F P
0 g
s
.7761 .60307 m .77618 .54754 L .80361 .55204 L p .707 .577 .707 r
F P
0 g
s
.33374 .67793 m .3323 .64107 L .31134 .63498 L p .707 .577 .707 r
F P
0 g
s
.3406 .67187 m .33557 .6902 L .36199 .69987 L p .707 .577 .707 r
F P
0 g
s
.68378 .54965 m .68369 .60518 L .6596 .61085 L p .707 .577 .707 r
F P
0 g
s
.66257 .69158 m .66477 .67515 L .68854 .66668 L p .707 .577 .707 r
F P
0 g
s
.82871 .69645 m .82651 .71288 L .80545 .69859 L p .707 .577 .707 r
F P
0 g
s
.80545 .69859 m .80765 .68216 L .82871 .69645 L p .707 .577 .707 r
F P
0 g
s
.66281 .67705 m .66219 .63964 L .68631 .6344 L p .707 .577 .707 r
F P
0 g
s
.68369 .60518 m .68378 .54965 L .71318 .54629 L p .707 .577 .707 r
F P
0 g
s
.45624 .70417 m .45121 .7225 L .47453 .72544 L p .707 .577 .707 r
F P
0 g
s
.47453 .72544 m .47956 .70711 L .45624 .70417 L p .707 .577 .707 r
F P
0 g
s
.47614 .63233 m .47759 .66919 L .49404 .66083 L p .707 .577 .707 r
F P
0 g
s
.49404 .66083 m .4926 .62397 L .47614 .63233 L p .707 .577 .707 r
F P
0 g
s
.31134 .63498 m .31278 .67184 L .33374 .67793 L p .707 .577 .707 r
F P
0 g
s
.68854 .66668 m .68634 .68311 L .66257 .69158 L p .707 .577 .707 r
F P
0 g
s
.29322 .54457 m .29303 .60017 L .30556 .60806 L p .707 .577 .707 r
F P
0 g
s
.48711 .54874 m .48692 .60434 L .49406 .59605 L p .707 .577 .707 r
F P
0 g
s
.49406 .59605 m .49426 .54045 L .48711 .54874 L p .707 .577 .707 r
F P
0 g
s
.33557 .6902 m .3406 .67187 L .32041 .66265 L p .707 .577 .707 r
F P
0 g
s
.68631 .6344 m .68693 .67181 L .66281 .67705 L p .707 .577 .707 r
F P
0 g
s
.77618 .54754 m .7761 .60307 L .74494 .60109 L p .707 .577 .707 r
F P
0 g
s
.74494 .60109 m .74502 .54556 L .77618 .54754 L p .707 .577 .707 r
F P
0 g
s
.32041 .66265 m .31538 .68098 L .33557 .6902 L p .707 .577 .707 r
F P
0 g
s
.80612 .63447 m .80674 .67188 L .77933 .66849 L p .707 .577 .707 r
F P
0 g
s
.77933 .66849 m .77872 .63108 L .80612 .63447 L p .707 .577 .707 r
F P
0 g
s
.7131 .60182 m .71318 .54629 L .74502 .54556 L p .707 .577 .707 r
F P
0 g
s
.71318 .54629 m .7131 .60182 L .68369 .60518 L p .707 .577 .707 r
F P
0 g
s
.74502 .54556 m .74494 .60109 L .7131 .60182 L p .707 .577 .707 r
F P
0 g
s
.68634 .68311 m .68854 .66668 L .71765 .66304 L p .707 .577 .707 r
F P
0 g
s
.31278 .67184 m .31134 .63498 L .29886 .62708 L p .707 .577 .707 r
F P
0 g
s
.80765 .68216 m .80545 .69859 L .77807 .68761 L p .707 .577 .707 r
F P
0 g
s
.77807 .68761 m .78027 .67118 L .80765 .68216 L p .707 .577 .707 r
F P
0 g
s
.68693 .67181 m .68631 .6344 L .71573 .63104 L p .707 .577 .707 r
F P
0 g
s
.29303 .60017 m .29322 .54457 L .29038 .53606 L p .707 .577 .707 r
F P
0 g
s
.47956 .70711 m .47453 .72544 L .49047 .72539 L p .707 .577 .707 r
F P
0 g
s
.49047 .72539 m .4955 .70706 L .47956 .70711 L p .707 .577 .707 r
F P
0 g
s
.71765 .66304 m .71545 .67947 L .68634 .68311 L p .707 .577 .707 r
F P
0 g
s
.74706 .68103 m .74926 .66459 L .78027 .67118 L p .707 .577 .707 r
F P
0 g
s
.74926 .66459 m .74706 .68103 L .71545 .67947 L p .707 .577 .707 r
F P
0 g
s
.77872 .63108 m .77933 .66849 L .74819 .66731 L p .707 .577 .707 r
F P
0 g
s
.71545 .67947 m .71765 .66304 L .74926 .66459 L p .707 .577 .707 r
F P
0 g
s
.74819 .66731 m .74757 .6299 L .77872 .63108 L p .707 .577 .707 r
F P
0 g
s
.29886 .62708 m .3003 .66394 L .31278 .67184 L p .707 .577 .707 r
F P
0 g
s
.71573 .63104 m .71635 .66845 L .68693 .67181 L p .707 .577 .707 r
F P
0 g
s
.78027 .67118 m .77807 .68761 L .74706 .68103 L p .707 .577 .707 r
F P
0 g
s
.4926 .62397 m .49404 .66083 L .50123 .65173 L p .707 .577 .707 r
F P
0 g
s
.50123 .65173 m .49979 .61487 L .4926 .62397 L p .707 .577 .707 r
F P
0 g
s
.31538 .68098 m .32041 .66265 L .30841 .65479 L p .707 .577 .707 r
F P
0 g
s
.71635 .66845 m .71573 .63104 L .74757 .6299 L p .707 .577 .707 r
F P
0 g
s
.30841 .65479 m .30338 .67312 L .31538 .68098 L p .707 .577 .707 r
F P
0 g
s
.74757 .6299 m .74819 .66731 L .71635 .66845 L p .707 .577 .707 r
F P
0 g
s
.29038 .53606 m .29019 .59167 L .29303 .60017 L p .707 .577 .707 r
F P
0 g
s
.49426 .54045 m .49406 .59605 L .49122 .58754 L p .707 .577 .707 r
F P
0 g
s
.49122 .58754 m .49142 .53194 L .49426 .54045 L p .707 .577 .707 r
F P
0 g
s
.3003 .66394 m .29886 .62708 L .29608 .61815 L p .707 .577 .707 r
F P
0 g
s
.29019 .59167 m .29038 .53606 L .29752 .52777 L p .707 .577 .707 r
F P
0 g
s
.4955 .70706 m .49047 .72539 L .49747 .72234 L p .707 .577 .707 r
F P
0 g
s
.49747 .72234 m .5025 .70401 L .4955 .70706 L p .707 .577 .707 r
F P
0 g
s
.29608 .61815 m .29752 .65501 L .3003 .66394 L p .707 .577 .707 r
F P
0 g
s
.30338 .67312 m .30841 .65479 L .30578 .64905 L p .707 .577 .707 r
F P
0 g
s
.49979 .61487 m .50123 .65173 L .49844 .6428 L p .707 .577 .707 r
F P
0 g
s
.49844 .6428 m .497 .60594 L .49979 .61487 L p .707 .577 .707 r
F P
0 g
s
.30578 .64905 m .30075 .66738 L .30338 .67312 L p .707 .577 .707 r
F P
0 g
s
.29752 .52777 m .29733 .58337 L .29019 .59167 L p .707 .577 .707 r
F P
0 g
s
.49142 .53194 m .49122 .58754 L .47868 .57965 L p .707 .577 .707 r
F P
0 g
s
.47868 .57965 m .47888 .52405 L .49142 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29752 .65501 m .29608 .61815 L .30327 .60906 L p .707 .577 .707 r
F P
0 g
s
.29733 .58337 m .29752 .52777 L .31395 .5205 L p .707 .577 .707 r
F P
0 g
s
.5025 .70401 m .49747 .72234 L .49484 .71661 L p .707 .577 .707 r
F P
0 g
s
.49484 .71661 m .49987 .69828 L .5025 .70401 L p .707 .577 .707 r
F P
0 g
s
.30327 .60906 m .30471 .64592 L .29752 .65501 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30075 .66738 m .30578 .64905 L .31278 .64601 L p .707 .577 .707 r
F P
0 g
s
.497 .60594 m .49844 .6428 L .48596 .6349 L p .707 .577 .707 r
F P
0 g
s
.48596 .6349 m .48452 .59804 L .497 .60594 L p .707 .577 .707 r
F P
0 g
s
.31278 .64601 m .30775 .66434 L .30075 .66738 L p .707 .577 .707 r
F P
0 g
s
.31395 .5205 m .31375 .5761 L .29733 .58337 L p .707 .577 .707 r
F P
0 g
s
.47888 .52405 m .47868 .57965 L .45767 .57315 L p .707 .577 .707 r
F P
0 g
s
.45767 .57315 m .45787 .51755 L .47888 .52405 L p .707 .577 .707 r
F P
0 g
s
.30471 .64592 m .30327 .60906 L .31972 .60069 L p .707 .577 .707 r
F P
0 g
s
.31375 .5761 m .31395 .5205 L .33804 .51497 L p .707 .577 .707 r
F P
0 g
s
.49987 .69828 m .49484 .71661 L .48284 .70875 L p .707 .577 .707 r
F P
0 g
s
.48284 .70875 m .48787 .69042 L .49987 .69828 L p .707 .577 .707 r
F P
0 g
s
.31972 .60069 m .32116 .63755 L .30471 .64592 L p .707 .577 .707 r
F P
0 g
s
.48452 .59804 m .48596 .6349 L .46501 .62881 L p .707 .577 .707 r
F P
0 g
s
.46501 .62881 m .46357 .59195 L .48452 .59804 L p .707 .577 .707 r
F P
0 g
s
.45787 .51755 m .45767 .57315 L .43025 .56868 L p .707 .577 .707 r
F P
0 g
s
.43025 .56868 m .43044 .51307 L .45787 .51755 L p .707 .577 .707 r
F P
0 g
s
.30775 .66434 m .31278 .64601 L .32872 .64596 L p .707 .577 .707 r
F P
0 g
s
.33804 .51497 m .33784 .57057 L .31375 .5761 L p .707 .577 .707 r
F P
0 g
s
.32872 .64596 m .32369 .66429 L .30775 .66434 L p .707 .577 .707 r
F P
0 g
s
.33784 .57057 m .33804 .51497 L .36744 .51172 L p .707 .577 .707 r
F P
0 g
s
.32116 .63755 m .31972 .60069 L .34383 .59388 L p .707 .577 .707 r
F P
0 g
s
.43044 .51307 m .43025 .56868 L .39909 .56667 L p .707 .577 .707 r
F P
0 g
s
.39909 .56667 m .39928 .51107 L .43044 .51307 L p .707 .577 .707 r
F P
0 g
s
.36725 .56732 m .36744 .51172 L .39928 .51107 L p .707 .577 .707 r
F P
0 g
s
.36744 .51172 m .36725 .56732 L .33784 .57057 L p .707 .577 .707 r
F P
0 g
s
.39928 .51107 m .39909 .56667 L .36725 .56732 L p .707 .577 .707 r
F P
0 g
s
.46357 .59195 m .46501 .62881 L .43763 .62512 L p .707 .577 .707 r
F P
0 g
s
.43763 .62512 m .43618 .58826 L .46357 .59195 L p .707 .577 .707 r
F P
0 g
s
.34383 .59388 m .34527 .63073 L .32116 .63755 L p .707 .577 .707 r
F P
0 g
s
.48787 .69042 m .48284 .70875 L .46265 .69953 L p .707 .577 .707 r
F P
0 g
s
.46265 .69953 m .46768 .6812 L .48787 .69042 L p .707 .577 .707 r
F P
0 g
s
.32369 .66429 m .32872 .64596 L .35205 .6489 L p .707 .577 .707 r
F P
0 g
s
.34527 .63073 m .34383 .59388 L .37324 .58928 L p .707 .577 .707 r
F P
0 g
s
.35205 .6489 m .34701 .66723 L .32369 .66429 L p .707 .577 .707 r
F P
0 g
s
.43618 .58826 m .43763 .62512 L .4065 .6242 L p .707 .577 .707 r
F P
0 g
s
.4065 .6242 m .40506 .58734 L .43618 .58826 L p .707 .577 .707 r
F P
0 g
s
.37324 .58928 m .37468 .62613 L .34527 .63073 L p .707 .577 .707 r
F P
0 g
s
.37468 .62613 m .37324 .58928 L .40506 .58734 L p .707 .577 .707 r
F P
0 g
s
.40506 .58734 m .4065 .6242 L .37468 .62613 L p .707 .577 .707 r
F P
0 g
s
.46768 .6812 m .46265 .69953 L .43623 .68985 L p .707 .577 .707 r
F P
0 g
s
.43623 .68985 m .44126 .67152 L .46768 .6812 L p .707 .577 .707 r
F P
0 g
s
.34701 .66723 m .35205 .6489 L .38047 .65454 L p .707 .577 .707 r
F P
0 g
s
.38047 .65454 m .37544 .67287 L .34701 .66723 L p .707 .577 .707 r
F P
0 g
s
.44126 .67152 m .43623 .68985 L .40618 .68067 L p .707 .577 .707 r
F P
0 g
s
.40618 .68067 m .41121 .66234 L .44126 .67152 L p .707 .577 .707 r
F P
0 g
s
.37544 .67287 m .38047 .65454 L .41121 .66234 L p .707 .577 .707 r
F P
0 g
s
.41121 .66234 m .40618 .68067 L .37544 .67287 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOolG0007FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001HOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo5`00?goo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007Ool80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000kOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0000=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0039o
o`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
0000<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00004FUH01000
FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040003FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo001BOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YF000060001UYF00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`80009JEP03001JEUYF00=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1`0015YF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJ
EP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool004Qoo`T000=oo`<0009JEP8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000jOol>0004FUH00`00FUIJEP02FUH800000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYF
FUH80008FUH60003FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP02000^Ool003Ioo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EPH000IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000^Ool003=oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH02000FUIJEUYF001JEP00FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2000^Ool0035oo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@002ioo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002ioo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH;0005FUH0
0`00FUIJEP06FUH60004FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEPL000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF00006@001UYF00L005YFFUIJEP00FUH0000^
Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEP0000<0009JEP05001JEP00FUH00006FUH50004FUH00`00
FUIJEP08FUH400000eYF001JEP020002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF2@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPP000=JEP8002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF00D005YF001JEP00
00IJEPD000AJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP050003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00FUH20003FUH500001UYF001JEP00FUH000IJEP@000EJEP04001JEUYFFUH400000eYF001JEP05
FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000X00003FUH00000
01L000EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH50004FUH01000FUIJEUYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03
001JEUYF00AJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001J
EUYF00AJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@000eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1@0000=JEP0000001P000eYF00<005YFFUH01UYF00<005YFFUH015YF
1@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF2@001eYF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YF
FUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP8000AJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP@00003FUH005YF00AJEP8000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEPP000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00;Goo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH20004FUH00`00FUH000040006FUH00`00FUIJ
EP07FUH01@00FUH00000FUH010002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000P000=JEP03001JEUYF008002eoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF4@0000=JEP00FUH015YF0`001UYF00<005YF000010001UYF10000UYF00<005YFFUH01eYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30004FUH40002FUH2000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP03001JEUYF00=JEPD000AJ
EPH000MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool20002FUH01000FUIJEUYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00IJEP03
001JEP0000T00004FUH000000004FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH60008
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05FUH200000eYF001JEP03FUH3000]Ool002eoo`80
009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
0003FUH005YF00IJEP03001JEUYF009JEPL000AJEP@00003FUH005YF00IJEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP04
001JEP000004FUH3000]Ool002ioo`06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF1@0015YF
00@005YFFUIJEP<000EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP@000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP<00003FUH0000000<000IJEP@00003FUH0
05YF00EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP04FUH00`00FUIJEP02000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00QJEP03001JEUYF00AJEP@000MJEP8000IJEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YF00000`0015YF0`000eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEP00
FUH005YF00@0009JEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH00000FUH00003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000002
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00@005YFFUH002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF0005FUH50006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF0P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF20000Woo0`000eYF00<007ooOol0;7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000015YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH015YF2@0015YF00<005YFFUH00UYF2@0037oo00<005YF
FUH00UYF00<007ooOol0:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF00EJEP@000IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH30002Ool9000FOol01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF20005goo10000UYF00<005YFFUH0
0eYF00H005YFFUH005YF0006FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00@005YFFUIJEP<000Ioo`D001Moo`04001JEUYF000]
Ool002aoo`03001JEP0000AJEP@0015oo`<000moo`@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH015YF1@000eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00001Woo1@005goo00D005YF001JEP0002aoo`00;7oo00<005YF00000UYF
1@004Goo1@004Woo0`0000MJEP00FUIJEP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH:
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
00050006FUH01000FUIJEUYF0P001goo1@0067oo0P0000=JEP00Ool0:goo000/Ool00`00FUH00003
0004FUH3000>Ool5000COol40002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP030004FUH01000FUIJEUYF0P0027oo0`006Woo00<005YF0000;7oo000/Ool0
0`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000?Ool400002EYF001JEUYF001J
EP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01P00FUIJEUYF001JEP<00003
FUH005YF009JEP03001oogoo02Aoo`03001JEP0002aoo`00;7oo0P000eYF00<005YFFUH00eYF00<0
05YFFUH00eYF1P001Goo0`002Woo1P001EYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH200000eYF0000000WOol00`00FUH0000/
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001J
EUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00002FUH40005FUH3000XOol2000]Ool002aoo`80009JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP03001JEUYF00=J
EP03001JEUYF008002Ioo`8002eoo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Goo0`00
;Goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF00000UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P008Woo0P0000=J
EP00Ool0;Goo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH0
10002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF
00<005YF00000eYF0P000eYF00@005YF000000=JEP80025oo`03001JEUYF008002ioo`00;goo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`0000EJEP00
001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYF0003FUH5
000OOol20003FUH00`00Oomoo`0]Ool0031oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEPT000=JEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF009JEP8000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0
00AJEP04001JEP000004FUH40006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0]Ool0039o
o`<00003FUH005YF00IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF00800003FUH005YF00<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04001JEP00FUH600000eYF001J
EP06FUH00`00FUIJEP04000@Ool50004FUH00`00FUIJEP02000`Ool003Eoo`D000AJEPP000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EQ0000=JEP03001JEUYF00=JEP<0039oo`00=Woo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP800003FUH005YF00=JEP03001JEUYF009JEP@000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo039oo`00<Goo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPP000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEP0000800003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000eOol002aoo`D00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH:0003Ool2
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000080003FUH00`00FUH000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000=goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=0008Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00UYF10000UYF0`0017oo2@0015YF
00<005YFFUH00UYF1P00>Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH>000@Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH00`0000=JEP00Ool037oo2@00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH=000JOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1000EGoo000/Ool00`00FUH00004
FUH01000FUIJEUYF3@008Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00;7oo2`00<7oo0P000UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo05Aoo`00
JGoo0`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00=JEP04001JEP000002FUH00`00Oomoo`1D
Ool006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEP000008FUH01000FUIJEUYF1P000UYF00<007ooOol0E7oo001]Ool3
0004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUHB0002Ool2000015YF001JEP00Egoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06000BOol00`00FUIJEP02FUH2001GOol007=o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009oo`D0011oo`03001J
EUYF00=JEP03001oogoo05Ioo`00Mgoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPH000Moo`D000ioo`<000AJEP03001oogoo05Moo`00OGoo7`003Goo1@003Goo00D005YFFUIJ
EP00009JEP03001oogoo05Qoo`00SGoo00D005YFFUH005YF008001Ioo`<000aoo`8000AJEP03001J
EP0005]oo`00SGoo00<005YFFUH00P009Goo0P001eYF00<007ooOol0FWoo002=Ool01000FUIJEP00
97oo0P0000=JEP00FUH015YF0P00GGoo002=Ool3000ROol30003FUH01000FUIJEUYF0P00Ggoo002>
Ool2000NOol40007FUH3001QOol008ioo`8001Yoo`@0009JEP03001JEUYF00IJEP03001oogoo065o
o`00SWoo00<005YF000057oo1@001UYF00<005YFFUH015YF0P00I7oo002>Ool2000015YF00000000
3Goo10000UYF00<005YFFUH01eYF00@005YFFUIJEP8006Ioo`00Sgoo00<005YF00000UYF3@001UYF
00<005YFFUH01eYF00@005YF000006Qoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEP@006Yoo`00T7oo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01000KWoo002AOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH4001b
Ool009=oo`<0009JEP03001JEUYF00EJEP03001JEUYF00@007Ioo`00UWoo3@00NWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59135 .74991 m .59154 .6943 L .56036 .69232 L p .707 .577 .707 r
F P
0 g
s
.59154 .6943 m .59135 .74991 L .62317 .74922 L p .707 .577 .707 r
F P
0 g
s
.62317 .74922 m .62337 .69362 L .59154 .6943 L p .707 .577 .707 r
F P
0 g
s
.62337 .69362 m .62317 .74922 L .65253 .74594 L p .707 .577 .707 r
F P
0 g
s
.65253 .74594 m .65273 .69034 L .62337 .69362 L p .707 .577 .707 r
F P
0 g
s
.56016 .74793 m .56036 .69232 L .53287 .68788 L p .707 .577 .707 r
F P
0 g
s
.56036 .69232 m .56016 .74793 L .59135 .74991 L p .707 .577 .707 r
F P
0 g
s
.65273 .69034 m .65253 .74594 L .67655 .74039 L p .707 .577 .707 r
F P
0 g
s
.67655 .74039 m .67674 .68478 L .65273 .69034 L p .707 .577 .707 r
F P
0 g
s
.53287 .68788 m .53267 .74348 L .56016 .74793 L p .707 .577 .707 r
F P
0 g
s
.53267 .74348 m .53287 .68788 L .51177 .6814 L p .707 .577 .707 r
F P
0 g
s
.59875 .8114 m .5973 .77454 L .56613 .77369 L p .707 .577 .707 r
F P
0 g
s
.5973 .77454 m .59875 .8114 L .63055 .8094 L p .707 .577 .707 r
F P
0 g
s
.63055 .8094 m .62911 .77255 L .5973 .77454 L p .707 .577 .707 r
F P
0 g
s
.62911 .77255 m .63055 .8094 L .65987 .80475 L p .707 .577 .707 r
F P
0 g
s
.65987 .80475 m .65843 .76789 L .62911 .77255 L p .707 .577 .707 r
F P
0 g
s
.56757 .81054 m .56613 .77369 L .53864 .77005 L p .707 .577 .707 r
F P
0 g
s
.56613 .77369 m .56757 .81054 L .59875 .8114 L p .707 .577 .707 r
F P
0 g
s
.67674 .68478 m .67655 .74039 L .69287 .7331 L p .707 .577 .707 r
F P
0 g
s
.69287 .7331 m .69306 .6775 L .67674 .68478 L p .707 .577 .707 r
F P
0 g
s
.51177 .6814 m .51157 .737 L .53267 .74348 L p .707 .577 .707 r
F P
0 g
s
.65843 .76789 m .65987 .80475 L .68384 .79788 L p .707 .577 .707 r
F P
0 g
s
.68384 .79788 m .68239 .76103 L .65843 .76789 L p .707 .577 .707 r
F P
0 g
s
.59776 .83791 m .60279 .81958 L .57275 .81039 L p .707 .577 .707 r
F P
0 g
s
.60279 .81958 m .59776 .83791 L .6285 .84571 L p .707 .577 .707 r
F P
0 g
s
.6285 .84571 m .63353 .82738 L .60279 .81958 L p .707 .577 .707 r
F P
0 g
s
.53864 .77005 m .54008 .80691 L .56757 .81054 L p .707 .577 .707 r
F P
0 g
s
.57275 .81039 m .56772 .82872 L .59776 .83791 L p .707 .577 .707 r
F P
0 g
s
.63353 .82738 m .6285 .84571 L .65694 .85135 L p .707 .577 .707 r
F P
0 g
s
.65694 .85135 m .66197 .83302 L .63353 .82738 L p .707 .577 .707 r
F P
0 g
s
.51157 .737 m .51177 .6814 L .49912 .67352 L p .707 .577 .707 r
F P
0 g
s
.56772 .82872 m .57275 .81039 L .54634 .80071 L p .707 .577 .707 r
F P
0 g
s
.54008 .80691 m .53864 .77005 L .51752 .76401 L p .707 .577 .707 r
F P
0 g
s
.54634 .80071 m .54131 .81904 L .56772 .82872 L p .707 .577 .707 r
F P
0 g
s
.66197 .83302 m .65694 .85135 L .68028 .8543 L p .707 .577 .707 r
F P
0 g
s
.68028 .8543 m .68531 .83597 L .66197 .83302 L p .707 .577 .707 r
F P
0 g
s
.51752 .76401 m .51896 .80086 L .54008 .80691 L p .707 .577 .707 r
F P
0 g
s
.68239 .76103 m .68384 .79788 L .7001 .78949 L p .707 .577 .707 r
F P
0 g
s
.7001 .78949 m .69866 .75263 L .68239 .76103 L p .707 .577 .707 r
F P
0 g
s
.49912 .67352 m .49892 .72913 L .51157 .737 L p .707 .577 .707 r
F P
0 g
s
.69306 .6775 m .69287 .7331 L .69989 .7248 L p .707 .577 .707 r
F P
0 g
s
.69989 .7248 m .70009 .6692 L .69306 .6775 L p .707 .577 .707 r
F P
0 g
s
.54131 .81904 m .54634 .80071 L .52617 .79149 L p .707 .577 .707 r
F P
0 g
s
.52617 .79149 m .52114 .80982 L .54131 .81904 L p .707 .577 .707 r
F P
0 g
s
.51896 .80086 m .51752 .76401 L .50484 .75613 L p .707 .577 .707 r
F P
0 g
s
.49892 .72913 m .49912 .67352 L .49617 .66502 L p .707 .577 .707 r
F P
0 g
s
.68531 .83597 m .68028 .8543 L .69625 .85424 L p .707 .577 .707 r
F P
0 g
s
.69625 .85424 m .70128 .83591 L .68531 .83597 L p .707 .577 .707 r
F P
0 g
s
.50484 .75613 m .50628 .79299 L .51896 .80086 L p .707 .577 .707 r
F P
0 g
s
.52114 .80982 m .52617 .79149 L .51419 .78363 L p .707 .577 .707 r
F P
0 g
s
.69866 .75263 m .7001 .78949 L .70708 .78038 L p .707 .577 .707 r
F P
0 g
s
.70708 .78038 m .70564 .74353 L .69866 .75263 L p .707 .577 .707 r
F P
0 g
s
.51419 .78363 m .50916 .80196 L .52114 .80982 L p .707 .577 .707 r
F P
0 g
s
.49617 .66502 m .49597 .72062 L .49892 .72913 L p .707 .577 .707 r
F P
0 g
s
.70009 .6692 m .69989 .7248 L .69693 .7163 L p .707 .577 .707 r
F P
0 g
s
.69693 .7163 m .69713 .66069 L .70009 .6692 L p .707 .577 .707 r
F P
0 g
s
.50628 .79299 m .50484 .75613 L .50184 .74721 L p .707 .577 .707 r
F P
0 g
s
.48751 .82178 m .48751 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.49597 .72062 m .49617 .66502 L .50319 .65671 L p .707 .577 .707 r
F P
0 g
s
.50184 .74721 m .50328 .78407 L .50628 .79299 L p .707 .577 .707 r
F P
0 g
s
.50916 .80196 m .51419 .78363 L .51159 .7779 L p .707 .577 .707 r
F P
0 g
s
.51159 .7779 m .50656 .79623 L .50916 .80196 L p .707 .577 .707 r
F P
0 g
s
.50319 .65671 m .50299 .71232 L .49597 .72062 L p .707 .577 .707 r
F P
0 g
s
.50328 .78407 m .50184 .74721 L .50881 .7381 L p .707 .577 .707 r
F P
0 g
s
.50299 .71232 m .50319 .65671 L .51951 .64943 L p .707 .577 .707 r
F P
0 g
s
.50881 .7381 m .51026 .77496 L .50328 .78407 L p .707 .577 .707 r
F P
0 g
s
.50656 .79623 m .51159 .7779 L .51861 .77486 L p .707 .577 .707 r
F P
0 g
s
.51861 .77486 m .51358 .79319 L .50656 .79623 L p .707 .577 .707 r
F P
0 g
s
.51951 .64943 m .51931 .70504 L .50299 .71232 L p .707 .577 .707 r
F P
0 g
s
.51026 .77496 m .50881 .7381 L .52508 .72971 L p .707 .577 .707 r
F P
0 g
s
.51931 .70504 m .51951 .64943 L .54352 .64388 L p .707 .577 .707 r
F P
0 g
s
.52508 .72971 m .52653 .76656 L .51026 .77496 L p .707 .577 .707 r
F P
0 g
s
.51358 .79319 m .51861 .77486 L .53458 .77481 L p .707 .577 .707 r
F P
0 g
s
.54352 .64388 m .54333 .69948 L .51931 .70504 L p .707 .577 .707 r
F P
0 g
s
.53458 .77481 m .52955 .79314 L .51358 .79319 L p .707 .577 .707 r
F P
0 g
s
.52653 .76656 m .52508 .72971 L .54905 .72285 L p .707 .577 .707 r
F P
0 g
s
.54905 .72285 m .55049 .7597 L .52653 .76656 L p .707 .577 .707 r
F P
0 g
s
.52955 .79314 m .53458 .77481 L .55792 .77775 L p .707 .577 .707 r
F P
0 g
s
.55792 .77775 m .55289 .79608 L .52955 .79314 L p .707 .577 .707 r
F P
0 g
s
.48751 .31989 m .48751 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48751 .31989 L p .707 .577 .707 r
F P
0 g
s
.54333 .69948 m .54352 .64388 L .57288 .6406 L p .707 .577 .707 r
F P
0 g
s
.57288 .6406 m .57268 .6962 L .54333 .69948 L p .707 .577 .707 r
F P
0 g
s
.55049 .7597 m .54905 .72285 L .57837 .71819 L p .707 .577 .707 r
F P
0 g
s
.57837 .71819 m .57981 .75504 L .55049 .7597 L p .707 .577 .707 r
F P
0 g
s
.55289 .79608 m .55792 .77775 L .58636 .7834 L p .707 .577 .707 r
F P
0 g
s
.58636 .7834 m .58133 .80173 L .55289 .79608 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57436 .81638 L p .707 .577 .707 r
F P
0 g
s
.57268 .6962 m .57288 .6406 L .60471 .63991 L p .707 .577 .707 r
F P
0 g
s
.60471 .63991 m .60451 .69552 L .57268 .6962 L p .707 .577 .707 r
F P
0 g
s
.57436 .81638 m .57436 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70128 .83591 m .69625 .85424 L .70327 .8512 L p .707 .577 .707 r
F P
0 g
s
.70327 .8512 m .7083 .83287 L .70128 .83591 L p .707 .577 .707 r
F P
0 g
s
.44371 .81885 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44371 .81885 L .48751 .82178 L p .707 .577 .707 r
F P
0 g
s
.70564 .74353 m .70708 .78038 L .70408 .77146 L p .707 .577 .707 r
F P
0 g
s
.70408 .77146 m .70264 .7346 L .70564 .74353 L p .707 .577 .707 r
F P
0 g
s
.69713 .66069 m .69693 .7163 L .68429 .70842 L p .707 .577 .707 r
F P
0 g
s
.68429 .70842 m .68448 .65282 L .69713 .66069 L p .707 .577 .707 r
F P
0 g
s
.57981 .75504 m .57837 .71819 L .61017 .71619 L p .707 .577 .707 r
F P
0 g
s
.61017 .71619 m .61162 .75305 L .57981 .75504 L p .707 .577 .707 r
F P
0 g
s
.58133 .80173 m .58636 .7834 L .6171 .7912 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .61207 .80953 L .58133 .80173 L p .707 .577 .707 r
F P
0 g
s
.57436 .31449 m .57436 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.6359 .64189 m .6357 .6975 L .60451 .69552 L p .707 .577 .707 r
F P
0 g
s
.60451 .69552 m .60471 .63991 L .6359 .64189 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .30671 L .57436 .31449 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44371 .81885 L p .707 .577 .707 r
F P
0 g
s
.25118 .71167 m .25126 .65614 L .22008 .65419 L p .707 .577 .707 r
F P
0 g
s
.25126 .65614 m .25118 .71167 L .28301 .71092 L p .707 .577 .707 r
F P
0 g
s
.28301 .71092 m .28309 .65539 L .25126 .65614 L p .707 .577 .707 r
F P
0 g
s
.7083 .83287 m .70327 .8512 L .70067 .84547 L p .707 .577 .707 r
F P
0 g
s
.70067 .84547 m .7057 .82714 L .7083 .83287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28309 .65539 m .28301 .71092 L .31237 .70752 L p .707 .577 .707 r
F P
0 g
s
.31237 .70752 m .31245 .65199 L .28309 .65539 L p .707 .577 .707 r
F P
0 g
s
.21999 .70972 m .22008 .65419 L .19259 .64972 L p .707 .577 .707 r
F P
0 g
s
.22008 .65419 m .21999 .70972 L .25118 .71167 L p .707 .577 .707 r
F P
0 g
s
.70264 .7346 m .70408 .77146 L .6914 .76358 L p .707 .577 .707 r
F P
0 g
s
.6914 .76358 m .68996 .72673 L .70264 .7346 L p .707 .577 .707 r
F P
0 g
s
.68448 .65282 m .68429 .70842 L .66319 .70194 L p .707 .577 .707 r
F P
0 g
s
.66319 .70194 m .66338 .64634 L .68448 .65282 L p .707 .577 .707 r
F P
0 g
s
.64135 .71705 m .64279 .75391 L .61162 .75305 L p .707 .577 .707 r
F P
0 g
s
.61162 .75305 m .61017 .71619 L .64135 .71705 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .64715 .80039 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61207 .80953 m .61249 .80803 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61249 .80803 m .6171 .7912 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.66338 .64634 m .66319 .70194 L .6357 .6975 L p .707 .577 .707 r
F P
0 g
s
.6357 .6975 m .6359 .64189 L .66338 .64634 L p .707 .577 .707 r
F P
0 g
s
.66884 .72068 m .67028 .75754 L .64279 .75391 L p .707 .577 .707 r
F P
0 g
s
.64279 .75391 m .64135 .71705 L .66884 .72068 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .6437 .78657 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .31285 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .31285 m .63281 .79832 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.60892 .30671 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .30671 L p .707 .577 .707 r
F P
0 g
s
.31245 .65199 m .31237 .70752 L .33638 .70182 L p .707 .577 .707 r
F P
0 g
s
.33638 .70182 m .33646 .6463 L .31245 .65199 L p .707 .577 .707 r
F P
0 g
s
.25445 .77005 m .25383 .73264 L .22264 .73151 L p .707 .577 .707 r
F P
0 g
s
.25383 .73264 m .25445 .77005 L .28628 .76885 L p .707 .577 .707 r
F P
0 g
s
.28628 .76885 m .28566 .73144 L .25383 .73264 L p .707 .577 .707 r
F P
0 g
s
.28566 .73144 m .28628 .76885 L .31561 .76545 L p .707 .577 .707 r
F P
0 g
s
.31561 .76545 m .31499 .72804 L .28566 .73144 L p .707 .577 .707 r
F P
0 g
s
.19259 .64972 m .1925 .70525 L .21999 .70972 L p .707 .577 .707 r
F P
0 g
s
.22326 .76892 m .22264 .73151 L .19513 .72817 L p .707 .577 .707 r
F P
0 g
s
.22264 .73151 m .22326 .76892 L .25445 .77005 L p .707 .577 .707 r
F P
0 g
s
.1925 .70525 m .19259 .64972 L .17149 .64317 L p .707 .577 .707 r
F P
0 g
s
.31499 .72804 m .31561 .76545 L .33959 .76017 L p .707 .577 .707 r
F P
0 g
s
.33959 .76017 m .33897 .72276 L .31499 .72804 L p .707 .577 .707 r
F P
0 g
s
.7057 .82714 m .70067 .84547 L .6887 .83761 L p .707 .577 .707 r
F P
0 g
s
.6887 .83761 m .69373 .81928 L .7057 .82714 L p .707 .577 .707 r
F P
0 g
s
.19513 .72817 m .19575 .76558 L .22326 .76892 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.68996 .72673 m .6914 .76358 L .67028 .75754 L p .707 .577 .707 r
F P
0 g
s
.67028 .75754 m .66884 .72068 L .68996 .72673 L p .707 .577 .707 r
F P
0 g
s
.33646 .6463 m .33638 .70182 L .3527 .69438 L p .707 .577 .707 r
F P
0 g
s
.3527 .69438 m .35278 .63885 L .33646 .6463 L p .707 .577 .707 r
F P
0 g
s
.25454 .83913 m .25674 .8227 L .22573 .8161 L p .707 .577 .707 r
F P
0 g
s
.25674 .8227 m .25454 .83913 L .28615 .8407 L p .707 .577 .707 r
F P
0 g
s
.28615 .8407 m .28835 .82427 L .25674 .8227 L p .707 .577 .707 r
F P
0 g
s
.17149 .64317 m .1714 .6987 L .1925 .70525 L p .707 .577 .707 r
F P
0 g
s
.19575 .76558 m .19513 .72817 L .17399 .72293 L p .707 .577 .707 r
F P
0 g
s
.22353 .83253 m .22573 .8161 L .19837 .80512 L p .707 .577 .707 r
F P
0 g
s
.22573 .8161 m .22353 .83253 L .25454 .83913 L p .707 .577 .707 r
F P
0 g
s
.28835 .82427 m .28615 .8407 L .31527 .83707 L p .707 .577 .707 r
F P
0 g
s
.31527 .83707 m .31747 .82064 L .28835 .82427 L p .707 .577 .707 r
F P
0 g
s
.1714 .6987 m .17149 .64317 L .15884 .63518 L p .707 .577 .707 r
F P
0 g
s
.17399 .72293 m .17461 .76034 L .19575 .76558 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.33897 .72276 m .33959 .76017 L .35586 .75352 L p .707 .577 .707 r
F P
0 g
s
.35586 .75352 m .35524 .71611 L .33897 .72276 L p .707 .577 .707 r
F P
0 g
s
.19837 .80512 m .19617 .82155 L .22353 .83253 L p .707 .577 .707 r
F P
0 g
s
.19617 .82155 m .19837 .80512 L .17733 .79081 L p .707 .577 .707 r
F P
0 g
s
.31747 .82064 m .31527 .83707 L .33906 .82861 L p .707 .577 .707 r
F P
0 g
s
.33906 .82861 m .34126 .81218 L .31747 .82064 L p .707 .577 .707 r
F P
0 g
s
.69373 .81928 m .6887 .83761 L .66852 .82839 L p .707 .577 .707 r
F P
0 g
s
.66852 .82839 m .67355 .81006 L .69373 .81928 L p .707 .577 .707 r
F P
0 g
s
.15884 .63518 m .15876 .69071 L .1714 .6987 L p .707 .577 .707 r
F P
0 g
s
.17461 .76034 m .17399 .72293 L .1613 .71632 L p .707 .577 .707 r
F P
0 g
s
.35278 .63885 m .3527 .69438 L .35972 .68592 L p .707 .577 .707 r
F P
0 g
s
.35972 .68592 m .35981 .63039 L .35278 .63885 L p .707 .577 .707 r
F P
0 g
s
.17733 .79081 m .17513 .80724 L .19617 .82155 L p .707 .577 .707 r
F P
0 g
s
.1613 .71632 m .16192 .75373 L .17461 .76034 L p .707 .577 .707 r
F P
0 g
s
.35524 .71611 m .35586 .75352 L .36283 .74617 L p .707 .577 .707 r
F P
0 g
s
.36283 .74617 m .36221 .70876 L .35524 .71611 L p .707 .577 .707 r
F P
0 g
s
.35981 .63039 m .35972 .68592 L .35677 .67727 L p .707 .577 .707 r
F P
0 g
s
.35677 .67727 m .35685 .62174 L .35981 .63039 L p .707 .577 .707 r
F P
0 g
s
.35982 .73883 m .3592 .70142 L .36221 .70876 L p .707 .577 .707 r
F P
0 g
s
.36205 .80089 m .36425 .78446 L .35737 .79972 L p .707 .577 .707 r
F P
0 g
s
.36425 .78446 m .36205 .80089 L .35901 .78435 L p .707 .577 .707 r
F P
0 g
s
.35901 .78435 m .3612 .76792 L .36425 .78446 L p .707 .577 .707 r
F P
0 g
s
.3592 .70142 m .35982 .73883 L .34713 .73222 L p .707 .577 .707 r
F P
0 g
s
.34713 .73222 m .34651 .69481 L .3592 .70142 L p .707 .577 .707 r
F P
0 g
s
.3612 .76792 m .35901 .78435 L .34634 .76813 L p .707 .577 .707 r
F P
0 g
s
.34634 .76813 m .34854 .7517 L .3612 .76792 L p .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .29006 L .3563 .27798 L p .707 .577 .707 r
F P
0 g
s
.36221 .70876 m .36283 .74617 L .35982 .73883 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.17513 .80724 m .17733 .79081 L .16466 .7746 L p .707 .577 .707 r
F P
0 g
s
.15876 .69071 m .15884 .63518 L .15588 .62653 L p .707 .577 .707 r
F P
0 g
s
.34126 .81218 m .33906 .82861 L .35518 .81615 L p .707 .577 .707 r
F P
0 g
s
.35518 .81615 m .35737 .79972 L .34126 .81218 L p .707 .577 .707 r
F P
0 g
s
.67355 .81006 m .66852 .82839 L .64212 .81872 L p .707 .577 .707 r
F P
0 g
s
.64212 .81872 m .64715 .80039 L .67355 .81006 L p .707 .577 .707 r
F P
0 g
s
.16466 .7746 m .16246 .79103 L .17513 .80724 L p .707 .577 .707 r
F P
0 g
s
.15588 .62653 m .1558 .68206 L .15876 .69071 L p .707 .577 .707 r
F P
0 g
s
.16192 .75373 m .1613 .71632 L .15829 .70898 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .78657 L .64053 .77449 L p .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.16246 .79103 m .16466 .7746 L .16162 .75805 L p .707 .577 .707 r
F P
0 g
s
.64715 .80039 m .64212 .81872 L .61207 .80953 L p .707 .577 .707 r
F P
0 g
s
.35737 .79972 m .35518 .81615 L .36205 .80089 L p .707 .577 .707 r
F P
0 g
s
.15829 .70898 m .15891 .74639 L .16192 .75373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1558 .68206 m .15588 .62653 L .16291 .61807 L p .707 .577 .707 r
F P
0 g
s
.16162 .75805 m .15942 .77448 L .16246 .79103 L p .707 .577 .707 r
F P
0 g
s
.35685 .62174 m .35677 .67727 L .34412 .66928 L p .707 .577 .707 r
F P
0 g
s
.34412 .66928 m .3442 .61375 L .35685 .62174 L p .707 .577 .707 r
F P
0 g
s
.3563 .27798 m .35629 .77987 L .35947 .79195 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .3563 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16291 .61807 m .16283 .6736 L .1558 .68206 L p .707 .577 .707 r
F P
0 g
s
.15891 .74639 m .15829 .70898 L .16526 .70163 L p .707 .577 .707 r
F P
0 g
s
.15942 .77448 m .16162 .75805 L .16849 .7428 L p .707 .577 .707 r
F P
0 g
s
.16526 .70163 m .16588 .73904 L .15891 .74639 L p .707 .577 .707 r
F P
0 g
s
.16283 .6736 m .16291 .61807 L .17923 .61063 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .6236 .76326 L p .707 .577 .707 r
F P
0 g
s
.6236 .76326 m .6236 .26138 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.16849 .7428 m .16629 .75923 L .15942 .77448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17923 .61063 m .17914 .66616 L .16283 .6736 L p .707 .577 .707 r
F P
0 g
s
.3442 .61375 m .34412 .66928 L .32302 .66273 L p .707 .577 .707 r
F P
0 g
s
.32302 .66273 m .3231 .6072 L .3442 .61375 L p .707 .577 .707 r
F P
0 g
s
.16588 .73904 m .16526 .70163 L .18153 .69499 L p .707 .577 .707 r
F P
0 g
s
.16629 .75923 m .16849 .7428 L .18461 .73034 L p .707 .577 .707 r
F P
0 g
s
.36719 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36719 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18153 .69499 m .18215 .7324 L .16588 .73904 L p .707 .577 .707 r
F P
0 g
s
.17914 .66616 m .17923 .61063 L .20324 .60493 L p .707 .577 .707 r
F P
0 g
s
.18461 .73034 m .18241 .74677 L .16629 .75923 L p .707 .577 .707 r
F P
0 g
s
.34651 .69481 m .34713 .73222 L .32599 .72699 L p .707 .577 .707 r
F P
0 g
s
.32599 .72699 m .32537 .68958 L .34651 .69481 L p .707 .577 .707 r
F P
0 g
s
.3231 .6072 m .32302 .66273 L .29553 .65826 L p .707 .577 .707 r
F P
0 g
s
.29553 .65826 m .29562 .60273 L .3231 .6072 L p .707 .577 .707 r
F P
0 g
s
.6236 .26138 m .6236 .76326 L .59457 .75399 L p .707 .577 .707 r
F P
0 g
s
.59457 .75399 m .59457 .2521 L .6236 .26138 L p .707 .577 .707 r
F P
0 g
s
.20324 .60493 m .20316 .66046 L .17914 .66616 L p .707 .577 .707 r
F P
0 g
s
.18241 .74677 m .18461 .73034 L .20839 .72188 L p .707 .577 .707 r
F P
0 g
s
.34854 .7517 m .34634 .76813 L .3253 .75383 L p .707 .577 .707 r
F P
0 g
s
.3253 .75383 m .3275 .7374 L .34854 .7517 L p .707 .577 .707 r
F P
0 g
s
.18215 .7324 m .18153 .69499 L .20551 .68971 L p .707 .577 .707 r
F P
0 g
s
.20316 .66046 m .20324 .60493 L .2326 .60154 L p .707 .577 .707 r
F P
0 g
s
.20839 .72188 m .2062 .73831 L .18241 .74677 L p .707 .577 .707 r
F P
0 g
s
.20551 .68971 m .20613 .72712 L .18215 .7324 L p .707 .577 .707 r
F P
0 g
s
.73565 .65847 m .73557 .60284 L .70438 .60102 L p .707 .577 .707 r
F P
0 g
s
.73557 .60284 m .73565 .65847 L .76748 .65764 L p .707 .577 .707 r
F P
0 g
s
.76748 .65764 m .7674 .60201 L .73557 .60284 L p .707 .577 .707 r
F P
0 g
s
.29562 .60273 m .29553 .65826 L .26435 .65631 L p .707 .577 .707 r
F P
0 g
s
.26435 .65631 m .26443 .60078 L .29562 .60273 L p .707 .577 .707 r
F P
0 g
s
.32537 .68958 m .32599 .72699 L .29848 .72364 L p .707 .577 .707 r
F P
0 g
s
.29848 .72364 m .29786 .68623 L .32537 .68958 L p .707 .577 .707 r
F P
0 g
s
.7674 .60201 m .76748 .65764 L .79684 .65425 L p .707 .577 .707 r
F P
0 g
s
.79684 .65425 m .79676 .59861 L .7674 .60201 L p .707 .577 .707 r
F P
0 g
s
.23252 .65707 m .2326 .60154 L .26443 .60078 L p .707 .577 .707 r
F P
0 g
s
.2326 .60154 m .23252 .65707 L .20316 .66046 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36719 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42564 .24816 L p .707 .577 .707 r
F P
0 g
s
.70447 .65665 m .70438 .60102 L .67689 .59673 L p .707 .577 .707 r
F P
0 g
s
.70438 .60102 m .70447 .65665 L .73565 .65847 L p .707 .577 .707 r
F P
0 g
s
.26443 .60078 m .26435 .65631 L .23252 .65707 L p .707 .577 .707 r
F P
0 g
s
.2062 .73831 m .20839 .72188 L .23752 .71825 L p .707 .577 .707 r
F P
0 g
s
.3275 .7374 m .3253 .75383 L .29794 .74284 L p .707 .577 .707 r
F P
0 g
s
.29794 .74284 m .30013 .72641 L .3275 .7374 L p .707 .577 .707 r
F P
0 g
s
.20613 .72712 m .20551 .68971 L .23484 .6863 L p .707 .577 .707 r
F P
0 g
s
.79676 .59861 m .79684 .65425 L .82085 .64862 L p .707 .577 .707 r
F P
0 g
s
.82085 .64862 m .82077 .59299 L .79676 .59861 L p .707 .577 .707 r
F P
0 g
s
.23752 .71825 m .23532 .73468 L .2062 .73831 L p .707 .577 .707 r
F P
0 g
s
.26693 .73624 m .26913 .71981 L .30013 .72641 L p .707 .577 .707 r
F P
0 g
s
.26913 .71981 m .26693 .73624 L .23532 .73468 L p .707 .577 .707 r
F P
0 g
s
.29786 .68623 m .29848 .72364 L .26728 .72251 L p .707 .577 .707 r
F P
0 g
s
.23532 .73468 m .23752 .71825 L .26913 .71981 L p .707 .577 .707 r
F P
0 g
s
.26728 .72251 m .26666 .6851 L .29786 .68623 L p .707 .577 .707 r
F P
0 g
s
.23484 .6863 m .23546 .72371 L .20613 .72712 L p .707 .577 .707 r
F P
0 g
s
.59457 .2521 m .59457 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59457 .2521 L p .707 .577 .707 r
F P
0 g
s
.30013 .72641 m .29794 .74284 L .26693 .73624 L p .707 .577 .707 r
F P
0 g
s
.67689 .59673 m .67698 .65237 L .70447 .65665 L p .707 .577 .707 r
F P
0 g
s
.23546 .72371 m .23484 .6863 L .26666 .6851 L p .707 .577 .707 r
F P
0 g
s
.67698 .65237 m .67689 .59673 L .65579 .5904 L p .707 .577 .707 r
F P
0 g
s
.26666 .6851 m .26728 .72251 L .23546 .72371 L p .707 .577 .707 r
F P
0 g
s
.73271 .72076 m .73333 .68412 L .70214 .68152 L p .707 .577 .707 r
F P
0 g
s
.73333 .68412 m .73271 .72076 L .76453 .72033 L p .707 .577 .707 r
F P
0 g
s
.76453 .72033 m .76515 .68369 L .73333 .68412 L p .707 .577 .707 r
F P
0 g
s
.76515 .68369 m .76453 .72033 L .79387 .71692 L p .707 .577 .707 r
F P
0 g
s
.79387 .71692 m .79449 .68028 L .76515 .68369 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42564 .24816 L .46747 .24362 L p .707 .577 .707 r
F P
0 g
s
.42564 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.70152 .71816 m .70214 .68152 L .67463 .67615 L p .707 .577 .707 r
F P
0 g
s
.70214 .68152 m .70152 .71816 L .73271 .72076 L p .707 .577 .707 r
F P
0 g
s
.82077 .59299 m .82085 .64862 L .83717 .64131 L p .707 .577 .707 r
F P
0 g
s
.83717 .64131 m .83709 .58568 L .82077 .59299 L p .707 .577 .707 r
F P
0 g
s
.65579 .5904 m .65588 .64603 L .67698 .65237 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51249 .74466 L p .707 .577 .707 r
F P
0 g
s
.51249 .74466 m .51249 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.79449 .68028 m .79387 .71692 L .81784 .71086 L p .707 .577 .707 r
F P
0 g
s
.81784 .71086 m .81846 .67422 L .79449 .68028 L p .707 .577 .707 r
F P
0 g
s
.65588 .64603 m .65579 .5904 L .64315 .58263 L p .707 .577 .707 r
F P
0 g
s
.67463 .67615 m .67401 .71278 L .70152 .71816 L p .707 .577 .707 r
F P
0 g
s
.73307 .73286 m .73087 .71375 L .69986 .71727 L p .707 .577 .707 r
F P
0 g
s
.73087 .71375 m .73307 .73286 L .76468 .7292 L p .707 .577 .707 r
F P
0 g
s
.76468 .7292 m .76248 .71009 L .73087 .71375 L p .707 .577 .707 r
F P
0 g
s
.69986 .71727 m .70206 .73637 L .73307 .73286 L p .707 .577 .707 r
F P
0 g
s
.76248 .71009 m .76468 .7292 L .7938 .72575 L p .707 .577 .707 r
F P
0 g
s
.7938 .72575 m .7916 .70665 L .76248 .71009 L p .707 .577 .707 r
F P
0 g
s
.46747 .74551 m .46747 .24362 L .51249 .24277 L p .707 .577 .707 r
F P
0 g
s
.46747 .24362 m .46747 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.67401 .71278 m .67463 .67615 L .65349 .66853 L p .707 .577 .707 r
F P
0 g
s
.51249 .24277 m .51249 .74466 L .46747 .74551 L p .707 .577 .707 r
F P
0 g
s
.70206 .73637 m .69986 .71727 L .6725 .72029 L p .707 .577 .707 r
F P
0 g
s
.6725 .72029 m .6747 .7394 L .70206 .73637 L p .707 .577 .707 r
F P
0 g
s
.64315 .58263 m .64323 .63827 L .65588 .64603 L p .707 .577 .707 r
F P
0 g
s
.83709 .58568 m .83717 .64131 L .8442 .63304 L p .707 .577 .707 r
F P
0 g
s
.8442 .63304 m .84411 .5774 L .83709 .58568 L p .707 .577 .707 r
F P
0 g
s
.65349 .66853 m .65287 .70517 L .67401 .71278 L p .707 .577 .707 r
F P
0 g
s
.7916 .70665 m .7938 .72575 L .81759 .72286 L p .707 .577 .707 r
F P
0 g
s
.81759 .72286 m .81539 .70375 L .7916 .70665 L p .707 .577 .707 r
F P
0 g
s
.81846 .67422 m .81784 .71086 L .83411 .70274 L p .707 .577 .707 r
F P
0 g
s
.83411 .70274 m .83473 .6661 L .81846 .67422 L p .707 .577 .707 r
F P
0 g
s
.6747 .7394 m .6725 .72029 L .65146 .72253 L p .707 .577 .707 r
F P
0 g
s
.65146 .72253 m .65366 .74164 L .6747 .7394 L p .707 .577 .707 r
F P
0 g
s
.65287 .70517 m .65349 .66853 L .6408 .65941 L p .707 .577 .707 r
F P
0 g
s
.64323 .63827 m .64315 .58263 L .64019 .5742 L p .707 .577 .707 r
F P
0 g
s
.81539 .70375 m .81759 .72286 L .83371 .72079 L p .707 .577 .707 r
F P
0 g
s
.83371 .72079 m .83151 .70169 L .81539 .70375 L p .707 .577 .707 r
F P
0 g
s
.6408 .65941 m .64018 .69605 L .65287 .70517 L p .707 .577 .707 r
F P
0 g
s
.64019 .5742 m .64028 .62983 L .64323 .63827 L p .707 .577 .707 r
F P
0 g
s
.83473 .6661 m .83411 .70274 L .84109 .69335 L p .707 .577 .707 r
F P
0 g
s
.84109 .69335 m .84171 .65672 L .83473 .6661 L p .707 .577 .707 r
F P
0 g
s
.84411 .5774 m .8442 .63304 L .84124 .6246 L p .707 .577 .707 r
F P
0 g
s
.84124 .6246 m .84116 .56897 L .84411 .5774 L p .707 .577 .707 r
F P
0 g
s
.65366 .74164 m .65146 .72253 L .63879 .72377 L p .707 .577 .707 r
F P
0 g
s
.63879 .72377 m .64099 .74287 L .65366 .74164 L p .707 .577 .707 r
F P
0 g
s
.64018 .69605 m .6408 .65941 L .63779 .64968 L p .707 .577 .707 r
F P
0 g
s
.64028 .62983 m .64019 .5742 L .64722 .56592 L p .707 .577 .707 r
F P
0 g
s
.83151 .70169 m .83371 .72079 L .84058 .71977 L p .707 .577 .707 r
F P
0 g
s
.84058 .71977 m .83838 .70066 L .83151 .70169 L p .707 .577 .707 r
F P
0 g
s
.63779 .64968 m .63717 .68632 L .64018 .69605 L p .707 .577 .707 r
F P
0 g
s
.64722 .56592 m .6473 .62156 L .64028 .62983 L p .707 .577 .707 r
F P
0 g
s
.84171 .65672 m .84109 .69335 L .83808 .68363 L p .707 .577 .707 r
F P
0 g
s
.83808 .68363 m .8387 .64699 L .84171 .65672 L p .707 .577 .707 r
F P
0 g
s
.84116 .56897 m .84124 .6246 L .8286 .61684 L p .707 .577 .707 r
F P
0 g
s
.8286 .61684 m .82851 .56121 L .84116 .56897 L p .707 .577 .707 r
F P
0 g
s
.64099 .74287 m .63879 .72377 L .63575 .72387 L p .707 .577 .707 r
F P
0 g
s
.63575 .72387 m .63795 .74298 L .64099 .74287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63717 .68632 m .63779 .64968 L .64476 .6403 L p .707 .577 .707 r
F P
0 g
s
.6473 .62156 m .64722 .56592 L .66353 .55861 L p .707 .577 .707 r
F P
0 g
s
.39548 .62024 m .39529 .56468 L .3641 .56289 L p .707 .577 .707 r
F P
0 g
s
.39529 .56468 m .39548 .62024 L .42731 .61934 L p .707 .577 .707 r
F P
0 g
s
.42731 .61934 m .42712 .56378 L .39529 .56468 L p .707 .577 .707 r
F P
0 g
s
.42712 .56378 m .42731 .61934 L .45667 .61583 L p .707 .577 .707 r
F P
0 g
s
.45667 .61583 m .45648 .56027 L .42712 .56378 L p .707 .577 .707 r
F P
0 g
s
.83838 .70066 m .84058 .71977 L .83753 .71987 L p .707 .577 .707 r
F P
0 g
s
.83753 .71987 m .83534 .70077 L .83838 .70066 L p .707 .577 .707 r
F P
0 g
s
.64476 .6403 m .64414 .67694 L .63717 .68632 L p .707 .577 .707 r
F P
0 g
s
.3643 .61845 m .3641 .56289 L .33661 .55857 L p .707 .577 .707 r
F P
0 g
s
.3641 .56289 m .3643 .61845 L .39548 .62024 L p .707 .577 .707 r
F P
0 g
s
.66353 .55861 m .66362 .61425 L .6473 .62156 L p .707 .577 .707 r
F P
0 g
s
.8387 .64699 m .83808 .68363 L .82539 .67451 L p .707 .577 .707 r
F P
0 g
s
.82539 .67451 m .82601 .63787 L .8387 .64699 L p .707 .577 .707 r
F P
0 g
s
.82851 .56121 m .8286 .61684 L .8075 .61051 L p .707 .577 .707 r
F P
0 g
s
.8075 .61051 m .80741 .55487 L .82851 .56121 L p .707 .577 .707 r
F P
0 g
s
.45648 .56027 m .45667 .61583 L .48069 .61006 L p .707 .577 .707 r
F P
0 g
s
.48069 .61006 m .48049 .5545 L .45648 .56027 L p .707 .577 .707 r
F P
0 g
s
.63795 .74298 m .63575 .72387 L .64262 .72285 L p .707 .577 .707 r
F P
0 g
s
.64262 .72285 m .64482 .74195 L .63795 .74298 L p .707 .577 .707 r
F P
0 g
s
.38838 .67943 m .38983 .64224 L .35865 .63934 L p .707 .577 .707 r
F P
0 g
s
.38983 .64224 m .38838 .67943 L .42019 .67983 L p .707 .577 .707 r
F P
0 g
s
.42019 .67983 m .42163 .64264 L .38983 .64224 L p .707 .577 .707 r
F P
0 g
s
.64414 .67694 m .64476 .6403 L .66103 .63218 L p .707 .577 .707 r
F P
0 g
s
.42163 .64264 m .42019 .67983 L .44951 .67769 L p .707 .577 .707 r
F P
0 g
s
.44951 .67769 m .45095 .6405 L .42163 .64264 L p .707 .577 .707 r
F P
0 g
s
.33661 .55857 m .33681 .61413 L .3643 .61845 L p .707 .577 .707 r
F P
0 g
s
.66362 .61425 m .66353 .55861 L .68755 .55299 L p .707 .577 .707 r
F P
0 g
s
.33681 .61413 m .33661 .55857 L .31551 .55217 L p .707 .577 .707 r
F P
0 g
s
.35721 .67654 m .35865 .63934 L .33116 .63423 L p .707 .577 .707 r
F P
0 g
s
.35865 .63934 m .35721 .67654 L .38838 .67943 L p .707 .577 .707 r
F P
0 g
s
.66103 .63218 m .66041 .66882 L .64414 .67694 L p .707 .577 .707 r
F P
0 g
s
.45095 .6405 m .44951 .67769 L .47347 .67322 L p .707 .577 .707 r
F P
0 g
s
.47347 .67322 m .47492 .63603 L .45095 .6405 L p .707 .577 .707 r
F P
0 g
s
.83534 .70077 m .83753 .71987 L .82487 .72111 L p .707 .577 .707 r
F P
0 g
s
.82487 .72111 m .82267 .702 L .83534 .70077 L p .707 .577 .707 r
F P
0 g
s
.80741 .55487 m .8075 .61051 L .78001 .60622 L p .707 .577 .707 r
F P
0 g
s
.78001 .60622 m .77992 .55058 L .80741 .55487 L p .707 .577 .707 r
F P
0 g
s
.48049 .5545 m .48069 .61006 L .497 .60259 L p .707 .577 .707 r
F P
0 g
s
.497 .60259 m .49681 .54703 L .48049 .5545 L p .707 .577 .707 r
F P
0 g
s
.33116 .63423 m .32972 .67142 L .35721 .67654 L p .707 .577 .707 r
F P
0 g
s
.68755 .55299 m .68763 .60862 L .66362 .61425 L p .707 .577 .707 r
F P
0 g
s
.41867 .72664 m .41364 .70944 L .38289 .71817 L p .707 .577 .707 r
F P
0 g
s
.41364 .70944 m .41867 .72664 L .4471 .71485 L p .707 .577 .707 r
F P
0 g
s
.4471 .71485 m .44207 .69764 L .41364 .70944 L p .707 .577 .707 r
F P
0 g
s
.31551 .55217 m .31571 .60773 L .33681 .61413 L p .707 .577 .707 r
F P
0 g
s
.38792 .73538 m .38289 .71817 L .35285 .72298 L p .707 .577 .707 r
F P
0 g
s
.38289 .71817 m .38792 .73538 L .41867 .72664 L p .707 .577 .707 r
F P
0 g
s
.82601 .63787 m .82539 .67451 L .80425 .66689 L p .707 .577 .707 r
F P
0 g
s
.80425 .66689 m .80487 .63025 L .82601 .63787 L p .707 .577 .707 r
F P
0 g
s
.32972 .67142 m .33116 .63423 L .31004 .6274 L p .707 .577 .707 r
F P
0 g
s
.68763 .60862 m .68755 .55299 L .71691 .54959 L p .707 .577 .707 r
F P
0 g
s
.35285 .72298 m .35788 .74019 L .38792 .73538 L p .707 .577 .707 r
F P
0 g
s
.31571 .60773 m .31551 .55217 L .30287 .54429 L p .707 .577 .707 r
F P
0 g
s
.44207 .69764 m .4471 .71485 L .47045 .70114 L p .707 .577 .707 r
F P
0 g
s
.47045 .70114 m .46542 .68393 L .44207 .69764 L p .707 .577 .707 r
F P
0 g
s
.64482 .74195 m .64262 .72285 L .65874 .72078 L p .707 .577 .707 r
F P
0 g
s
.65874 .72078 m .66094 .73989 L .64482 .74195 L p .707 .577 .707 r
F P
0 g
s
.35788 .74019 m .35285 .72298 L .32645 .72341 L p .707 .577 .707 r
F P
0 g
s
.66041 .66882 m .66103 .63218 L .68501 .62612 L p .707 .577 .707 r
F P
0 g
s
.31004 .6274 m .3086 .66459 L .32972 .67142 L p .707 .577 .707 r
F P
0 g
s
.77992 .55058 m .78001 .60622 L .74882 .6044 L p .707 .577 .707 r
F P
0 g
s
.74882 .6044 m .74874 .54877 L .77992 .55058 L p .707 .577 .707 r
F P
0 g
s
.71699 .60523 m .71691 .54959 L .74874 .54877 L p .707 .577 .707 r
F P
0 g
s
.71691 .54959 m .71699 .60523 L .68763 .60862 L p .707 .577 .707 r
F P
0 g
s
.32645 .72341 m .33148 .74062 L .35788 .74019 L p .707 .577 .707 r
F P
0 g
s
.47492 .63603 m .47347 .67322 L .48974 .66686 L p .707 .577 .707 r
F P
0 g
s
.48974 .66686 m .49118 .62967 L .47492 .63603 L p .707 .577 .707 r
F P
0 g
s
.74874 .54877 m .74882 .6044 L .71699 .60523 L p .707 .577 .707 r
F P
0 g
s
.68501 .62612 m .68439 .66276 L .66041 .66882 L p .707 .577 .707 r
F P
0 g
s
.30287 .54429 m .30306 .59985 L .31571 .60773 L p .707 .577 .707 r
F P
0 g
s
.49681 .54703 m .497 .60259 L .50403 .59416 L p .707 .577 .707 r
F P
0 g
s
.50403 .59416 m .50383 .5386 L .49681 .54703 L p .707 .577 .707 r
F P
0 g
s
.80487 .63025 m .80425 .66689 L .77674 .66152 L p .707 .577 .707 r
F P
0 g
s
.77674 .66152 m .77736 .62488 L .80487 .63025 L p .707 .577 .707 r
F P
0 g
s
.46542 .68393 m .47045 .70114 L .48641 .68687 L p .707 .577 .707 r
F P
0 g
s
.48641 .68687 m .48138 .66966 L .46542 .68393 L p .707 .577 .707 r
F P
0 g
s
.3086 .66459 m .31004 .6274 L .29736 .61953 L p .707 .577 .707 r
F P
0 g
s
.82267 .702 m .82487 .72111 L .80383 .72335 L p .707 .577 .707 r
F P
0 g
s
.80383 .72335 m .80163 .70424 L .82267 .702 L p .707 .577 .707 r
F P
0 g
s
.33148 .74062 m .32645 .72341 L .30627 .7194 L p .707 .577 .707 r
F P
0 g
s
.68439 .66276 m .68501 .62612 L .71434 .62271 L p .707 .577 .707 r
F P
0 g
s
.30627 .7194 m .3113 .73661 L .33148 .74062 L p .707 .577 .707 r
F P
0 g
s
.29736 .61953 m .29592 .65672 L .3086 .66459 L p .707 .577 .707 r
F P
0 g
s
.30306 .59985 m .30287 .54429 L .29991 .53571 L p .707 .577 .707 r
F P
0 g
s
.66094 .73989 m .65874 .72078 L .68253 .71789 L p .707 .577 .707 r
F P
0 g
s
.68253 .71789 m .68472 .73699 L .66094 .73989 L p .707 .577 .707 r
F P
0 g
s
.77736 .62488 m .77674 .66152 L .74554 .65892 L p .707 .577 .707 r
F P
0 g
s
.74554 .65892 m .74616 .62228 L .77736 .62488 L p .707 .577 .707 r
F P
0 g
s
.71434 .62271 m .71372 .65935 L .68439 .66276 L p .707 .577 .707 r
F P
0 g
s
.71372 .65935 m .71434 .62271 L .74616 .62228 L p .707 .577 .707 r
F P
0 g
s
.49118 .62967 m .48974 .66686 L .49672 .65923 L p .707 .577 .707 r
F P
0 g
s
.49672 .65923 m .49816 .62204 L .49118 .62967 L p .707 .577 .707 r
F P
0 g
s
.74616 .62228 m .74554 .65892 L .71372 .65935 L p .707 .577 .707 r
F P
0 g
s
.48138 .66966 m .48641 .68687 L .49344 .67342 L p .707 .577 .707 r
F P
0 g
s
.49344 .67342 m .48841 .65622 L .48138 .66966 L p .707 .577 .707 r
F P
0 g
s
.80163 .70424 m .80383 .72335 L .77646 .72637 L p .707 .577 .707 r
F P
0 g
s
.77646 .72637 m .77427 .70727 L .80163 .70424 L p .707 .577 .707 r
F P
0 g
s
.29991 .53571 m .30011 .59127 L .30306 .59985 L p .707 .577 .707 r
F P
0 g
s
.3113 .73661 m .30627 .7194 L .29429 .71136 L p .707 .577 .707 r
F P
0 g
s
.50383 .5386 m .50403 .59416 L .50107 .58558 L p .707 .577 .707 r
F P
0 g
s
.50107 .58558 m .50088 .53002 L .50383 .5386 L p .707 .577 .707 r
F P
0 g
s
.29592 .65672 m .29736 .61953 L .29436 .61137 L p .707 .577 .707 r
F P
0 g
s
.68472 .73699 m .68253 .71789 L .71165 .71444 L p .707 .577 .707 r
F P
0 g
s
.71165 .71444 m .71385 .73355 L .68472 .73699 L p .707 .577 .707 r
F P
0 g
s
.29429 .71136 m .29932 .72856 L .3113 .73661 L p .707 .577 .707 r
F P
0 g
s
.29436 .61137 m .29292 .64857 L .29592 .65672 L p .707 .577 .707 r
F P
0 g
s
.30011 .59127 m .29991 .53571 L .30694 .52728 L p .707 .577 .707 r
F P
0 g
s
.77427 .70727 m .77646 .72637 L .74546 .72989 L p .707 .577 .707 r
F P
0 g
s
.74546 .72989 m .74326 .71078 L .77427 .70727 L p .707 .577 .707 r
F P
0 g
s
.71385 .73355 m .71165 .71444 L .74326 .71078 L p .707 .577 .707 r
F P
0 g
s
.74326 .71078 m .74546 .72989 L .71385 .73355 L p .707 .577 .707 r
F P
0 g
s
.49816 .62204 m .49672 .65923 L .49372 .65107 L p .707 .577 .707 r
F P
0 g
s
.49372 .65107 m .49516 .61388 L .49816 .62204 L p .707 .577 .707 r
F P
0 g
s
.48841 .65622 m .49344 .67342 L .49084 .66213 L p .707 .577 .707 r
F P
0 g
s
.49084 .66213 m .48581 .64492 L .48841 .65622 L p .707 .577 .707 r
F P
0 g
s
.29932 .72856 m .29429 .71136 L .29169 .70006 L p .707 .577 .707 r
F P
0 g
s
.30694 .52728 m .30713 .58284 L .30011 .59127 L p .707 .577 .707 r
F P
0 g
s
.50088 .53002 m .50107 .58558 L .48843 .5777 L p .707 .577 .707 r
F P
0 g
s
.48843 .5777 m .48823 .52214 L .50088 .53002 L p .707 .577 .707 r
F P
0 g
s
.29292 .64857 m .29436 .61137 L .30134 .60374 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29169 .70006 m .29672 .71727 L .29932 .72856 L p .707 .577 .707 r
F P
0 g
s
.30134 .60374 m .29989 .64094 L .29292 .64857 L p .707 .577 .707 r
F P
0 g
s
.30713 .58284 m .30694 .52728 L .32325 .51981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48581 .64492 m .49084 .66213 L .47886 .65408 L p .707 .577 .707 r
F P
0 g
s
.47886 .65408 m .47383 .63687 L .48581 .64492 L p .707 .577 .707 r
F P
0 g
s
.49516 .61388 m .49372 .65107 L .48104 .6432 L p .707 .577 .707 r
F P
0 g
s
.48104 .6432 m .48248 .60601 L .49516 .61388 L p .707 .577 .707 r
F P
0 g
s
.29672 .71727 m .29169 .70006 L .29872 .68661 L p .707 .577 .707 r
F P
0 g
s
.32325 .51981 m .32345 .57537 L .30713 .58284 L p .707 .577 .707 r
F P
0 g
s
.48823 .52214 m .48843 .5777 L .46733 .57129 L p .707 .577 .707 r
F P
0 g
s
.46733 .57129 m .46713 .51573 L .48823 .52214 L p .707 .577 .707 r
F P
0 g
s
.29989 .64094 m .30134 .60374 L .3176 .59738 L p .707 .577 .707 r
F P
0 g
s
.29872 .68661 m .30375 .70382 L .29672 .71727 L p .707 .577 .707 r
F P
0 g
s
.32345 .57537 m .32325 .51981 L .34727 .51404 L p .707 .577 .707 r
F P
0 g
s
.3176 .59738 m .31616 .63457 L .29989 .64094 L p .707 .577 .707 r
F P
0 g
s
.47383 .63687 m .47886 .65408 L .45868 .65007 L p .707 .577 .707 r
F P
0 g
s
.45868 .65007 m .45365 .63287 L .47383 .63687 L p .707 .577 .707 r
F P
0 g
s
.48248 .60601 m .48104 .6432 L .45992 .63637 L p .707 .577 .707 r
F P
0 g
s
.45992 .63637 m .46136 .59918 L .48248 .60601 L p .707 .577 .707 r
F P
0 g
s
.46713 .51573 m .46733 .57129 L .43984 .56698 L p .707 .577 .707 r
F P
0 g
s
.43984 .56698 m .43964 .51142 L .46713 .51573 L p .707 .577 .707 r
F P
0 g
s
.34727 .51404 m .34746 .5696 L .32345 .57537 L p .707 .577 .707 r
F P
0 g
s
.30375 .70382 m .29872 .68661 L .31468 .67234 L p .707 .577 .707 r
F P
0 g
s
.31616 .63457 m .3176 .59738 L .34157 .59291 L p .707 .577 .707 r
F P
0 g
s
.34746 .5696 m .34727 .51404 L .37663 .51053 L p .707 .577 .707 r
F P
0 g
s
.31468 .67234 m .31971 .68955 L .30375 .70382 L p .707 .577 .707 r
F P
0 g
s
.43964 .51142 m .43984 .56698 L .40865 .56519 L p .707 .577 .707 r
F P
0 g
s
.40865 .56519 m .40846 .50963 L .43964 .51142 L p .707 .577 .707 r
F P
0 g
s
.34157 .59291 m .34013 .6301 L .31616 .63457 L p .707 .577 .707 r
F P
0 g
s
.37682 .56609 m .37663 .51053 L .40846 .50963 L p .707 .577 .707 r
F P
0 g
s
.37663 .51053 m .37682 .56609 L .34746 .5696 L p .707 .577 .707 r
F P
0 g
s
.45365 .63287 m .45868 .65007 L .43228 .6505 L p .707 .577 .707 r
F P
0 g
s
.43228 .6505 m .42725 .63329 L .45365 .63287 L p .707 .577 .707 r
F P
0 g
s
.46136 .59918 m .45992 .63637 L .43243 .63126 L p .707 .577 .707 r
F P
0 g
s
.43243 .63126 m .43387 .59407 L .46136 .59918 L p .707 .577 .707 r
F P
0 g
s
.40846 .50963 m .40865 .56519 L .37682 .56609 L p .707 .577 .707 r
F P
0 g
s
.34013 .6301 m .34157 .59291 L .37089 .59077 L p .707 .577 .707 r
F P
0 g
s
.31971 .68955 m .31468 .67234 L .33803 .65864 L p .707 .577 .707 r
F P
0 g
s
.33803 .65864 m .34306 .67584 L .31971 .68955 L p .707 .577 .707 r
F P
0 g
s
.43387 .59407 m .43243 .63126 L .40125 .62836 L p .707 .577 .707 r
F P
0 g
s
.40125 .62836 m .4027 .59117 L .43387 .59407 L p .707 .577 .707 r
F P
0 g
s
.37089 .59077 m .36945 .62796 L .34013 .6301 L p .707 .577 .707 r
F P
0 g
s
.36945 .62796 m .37089 .59077 L .4027 .59117 L p .707 .577 .707 r
F P
0 g
s
.42725 .63329 m .43228 .6505 L .40224 .65531 L p .707 .577 .707 r
F P
0 g
s
.40224 .65531 m .39721 .63811 L .42725 .63329 L p .707 .577 .707 r
F P
0 g
s
.4027 .59117 m .40125 .62836 L .36945 .62796 L p .707 .577 .707 r
F P
0 g
s
.34306 .67584 m .33803 .65864 L .36646 .64684 L p .707 .577 .707 r
F P
0 g
s
.36646 .64684 m .37149 .66405 L .34306 .67584 L p .707 .577 .707 r
F P
0 g
s
.39721 .63811 m .40224 .65531 L .37149 .66405 L p .707 .577 .707 r
F P
0 g
s
.37149 .66405 m .36646 .64684 L .39721 .63811 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH:000;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`03001JEP0000P000AJEP04001JEUYFFUH80004FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005mo
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`@000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00008000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00FGoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001GOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00mooaT003aoo`00EGoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH6000fOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`02Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF009JEPX000QJEPP000=JEP03001JEUYF00=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000=JEP04001JEUYFFUH90008FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001E
Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP0200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo
0P000UYF00<005YFFUH00UYF7`0015YF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo0P000UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo0017Ool90006Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003ioo`T000AJEP03001JEUYF009JEPL000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000=JEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00=Woo200015YF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000eYF001JEP06FUH80004FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000bOol40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF0000;Goo000`Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH6
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF
001JEP02FUH00`00Oomoo`0[Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003
FUH00`00Oomoo`0[Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000=JEP00Ool0;7oo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEPT000AJEP04001JEUYFFUH60004FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000@000IJEP07001JEUYFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJ
EUYF2@000UYF00<005YFFUH00eYF1@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH50003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF2@000eYF00@005YFFUH000EJEPD0009JEPP00003
FUH0000000@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000eYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00000`000eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P00
1EYF00@005YFFUIJEPP000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF009J
EP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00001JEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03
001JEUYF009JEPD00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP@002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40008FUH0
0`00FUIJEP05FUH;0003FUH00`00FUIJEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP80009JEP03001JEUYF00MJEP03001JEUYF00@0
00MJEP04001JEUYFFUH300000eYF001JEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP04001JEUYF0005FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00=J
EPL000QJEPD000AJEPP000EJEP03001JEUYF008000MJEP03001JEUYF00@000MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH015YF0P0015YF100025YF0`00
0UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUH005YF008000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YF
FUH00eYF1P004Goo200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF0000
0eYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1P000UYF00<0
05YFFUH015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUH0000300000eYF001JEP02FUH00`00Oomoo`08Ool3000<Ool60004FUH0
1000FUIJEUYF0P00;Goo000/Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJEP04001JEUYFFUH20007FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000EJEP05001J
EUYFFUH00009Ool5000AOol300000eYF001JEP02FUH2000]Ool002aoo`03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000MJEP03001JEP00
008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH50004FUH0
1@00FUIJEUYF00002Goo1@004Woo10000eYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH90004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH7000015YF001JEP000UYF00<005YF00001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH50003FUH00`00Oomoo`07
Ool5000>Ool400001EYF001JEUYF00000UYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP04FUH2
0003FUH20002FUH00`00FUH0000A0008FUH20003FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
00Eoo`<000Yoo`D000EJEP04001JEUYFFUH4000]Ool002aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEPX000AJEP03001JEUYF009JEP03001JEUYF00<000AJEP80009JEP03
001JEUYF00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP02FUH50005FUH30002FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool01000FUIJEP001EYF2@000eYF00<005YFFUH01UYF
00<005YFFUH01EYF0P001EYF1P0015YF0P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Woo0`0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00@005YFFUH0009JEPL0009JEP03001JEUYF00AJEP<000IJEP03001JEUYF00=JEP80
00EJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YF
FUIJEP0000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP06001JEP00001JEP001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2000;Woo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJ
EUYF00001EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP<0
00AJEP03001JEUYF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH:0002FUH01000FUIJEUYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00L005YFFUIJEP00FUH0000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP`000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP08FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF0`001UYF00@005YFFUIJEPd0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP8000AJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00IJEPl000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000MJEP03001J
EP0000<0009JEP03001JEUYF00=JEP04001JEUYF0002FUH60008FUH00`00FUIJEP03FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP0>0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQH0
009JEP03001JEUYF00l000=JEP03001JEUYF00QJEP03001JEP00008000QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP`0031oo`00;Goo
00<005YF00000eYF00<005YFFUH00eYF1P000eYF00<005YFFUH01eYF00<005YFFUH015YF0`0000=J
EP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000hOol002eoo`03001J
EP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl003moo`00;Goo00<005YF
00000eYF0P001EYF00<005YFFUH00UYF200015YF00<005YFFUH01eYF100015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUH>0018Ool002eoo`04001JEP00FUH200000eYF001JEP03FUH70007FUH70006FUH01000
FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003
FUH01000FUIJEUYF3@00DGoo000]Ool01000FUH000000UYF00@005YFFUIJEP8000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEPl000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF3P000UYF0P00E7oo000]Ool30003FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH50007FUH01000FUIJEP0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00MJEQH000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002eoo`<000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF009JEP80009JEP04001JEUYF0006FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00E7oo000]Ool30002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
00000eYF001JEP05FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60002FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol002eoo`03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000006
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00D0
05YFFUIJEP0005Aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP<0009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP04001oogooOol60004FUH01@00FUIJEUYF0000E7oo000]Ool01000FUH0
07oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<0
07ooOol01goo0`0000=JEP00FUH00UYF00<007ooOol0DWoo000]Ool20005Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003Ool30002FUH01@00FUIJEP00FUH00P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<007ooOol017oo0`0000=JEP00FUH00P000eYF00<007ooOol0DWoo000]
Ool2000<OolK000<Ool01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
1`0015YF00@005YFFUIJEP800003FUH007oo05=oo`00;Goo0P006Goo0`0067oo00D005YF001JEP00
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00=JEP03001JEUYF009JEP<0
05Aoo`00;Goo0P0067oo1@0067oo0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Aoo`00;Goo0`005goo1@0067oo0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEP0005Aoo`00;Goo0P0000=JEP00Ool05Goo1@006Goo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYFFUH2001EOol002ioo`04
001JEUYF000FOol3000JOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00;Woo00D005YFFUIJEP0003=oo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP05001JEUYFFUH0
001FOol002moo`03001JEUYF00<0035oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000IJEP03001JEUYF00AJEP04001JEP00001GOol002moo`04001JEUYF0002FUH00`00Oomoo`0]
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP03FUH3001IOol0031o
o`8000AJEP8002eoo`80009oo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP80009JEP<0009JEP03001JEP0000<0
05aoo`00<7oo0P001UYF00<007ooOol0:Goo0`0017oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00<005YF
00000`00H7oo000aOol00`00FUIJEP04FUH3000WOol200000eYF001oo`06Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30008FUH0
1000FUIJEUYF0`00Ggoo000bOol20004FUH00`00FUIJEP02000SOol20002FUH20009Ool300000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP05FUH3001LOol003Aoo`04001JEUYF0005FUH2000OOol200001EYF001JEUYF0000
3Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000020000Woo
10000UYF00<005YFFUH01UYF00<005YF00000P00FGoo000eOol30007FUH5000HOol20003FUH01000
FUIJEP0057oo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF1`000UYF1`001Woo10001eYF00<0
05YFFUH00UYF0P00Egoo000gOol20007FUH01000FUIJEUYF2@002Goo1P0015YF00@005YFFUH0021o
oaX000=JEP03001JEUYF00EJEPD000Yoo`8000AJEP03001JEUYF00AJEP8005Ioo`00>Goo0P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF0`00>Woo0`0000=JEP00FUH0
1eYF0`0000=JEP0000000P0027oo0`0000=JEP00FUH015YF00@005YFFUH005Eoo`00>goo0`0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00?goo0`001eYF00<0
05YFFUH01EYF1P001Goo0P001EYF00D005YFFUIJEP0005Aoo`00?Woo10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8004Aoo`8000EJEP03001JEUYF00MJEP04001JEUYFFUH90003
FUH01000FUIJEUYF0P00Dgoo0012Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0
0000B7oo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01@0015YF0P00Dgoo0016Ool7
0004FUH00`00FUIJEP02FUH5001=Ool40007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2
001DOol004eoo`T005Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP02
001DOol00;1oo`@000MJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00]7oo10000UYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH0001EOol00;Qooa0005Eoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58839 .75016 m .58871 .69454 L .55751 .69252 L p .707 .577 .707 r
F P
0 g
s
.58871 .69454 m .58839 .75016 L .62022 .74953 L p .707 .577 .707 r
F P
0 g
s
.62022 .74953 m .62053 .69391 L .58871 .69454 L p .707 .577 .707 r
F P
0 g
s
.62053 .69391 m .62022 .74953 L .64956 .74631 L p .707 .577 .707 r
F P
0 g
s
.64956 .74631 m .64988 .6907 L .62053 .69391 L p .707 .577 .707 r
F P
0 g
s
.5572 .74813 m .55751 .69252 L .53001 .68804 L p .707 .577 .707 r
F P
0 g
s
.55751 .69252 m .5572 .74813 L .58839 .75016 L p .707 .577 .707 r
F P
0 g
s
.64988 .6907 m .64956 .74631 L .67355 .74082 L p .707 .577 .707 r
F P
0 g
s
.67355 .74082 m .67387 .6852 L .64988 .6907 L p .707 .577 .707 r
F P
0 g
s
.53001 .68804 m .52969 .74365 L .5572 .74813 L p .707 .577 .707 r
F P
0 g
s
.52969 .74365 m .53001 .68804 L .50888 .68154 L p .707 .577 .707 r
F P
0 g
s
.60036 .81233 m .59802 .77563 L .56687 .77541 L p .707 .577 .707 r
F P
0 g
s
.59802 .77563 m .60036 .81233 L .63212 .80959 L p .707 .577 .707 r
F P
0 g
s
.63212 .80959 m .62978 .77288 L .59802 .77563 L p .707 .577 .707 r
F P
0 g
s
.62978 .77288 m .63212 .80959 L .66138 .80414 L p .707 .577 .707 r
F P
0 g
s
.66138 .80414 m .65904 .76744 L .62978 .77288 L p .707 .577 .707 r
F P
0 g
s
.56921 .81211 m .56687 .77541 L .53938 .77225 L p .707 .577 .707 r
F P
0 g
s
.56687 .77541 m .56921 .81211 L .60036 .81233 L p .707 .577 .707 r
F P
0 g
s
.67387 .6852 m .67355 .74082 L .68983 .73359 L p .707 .577 .707 r
F P
0 g
s
.68983 .73359 m .69015 .67797 L .67387 .6852 L p .707 .577 .707 r
F P
0 g
s
.50888 .68154 m .50856 .73716 L .52969 .74365 L p .707 .577 .707 r
F P
0 g
s
.65904 .76744 m .66138 .80414 L .68528 .79654 L p .707 .577 .707 r
F P
0 g
s
.68528 .79654 m .68294 .75983 L .65904 .76744 L p .707 .577 .707 r
F P
0 g
s
.59854 .82865 m .60651 .81122 L .57825 .79772 L p .707 .577 .707 r
F P
0 g
s
.60651 .81122 m .59854 .82865 L .62755 .84159 L p .707 .577 .707 r
F P
0 g
s
.62755 .84159 m .63552 .82416 L .60651 .81122 L p .707 .577 .707 r
F P
0 g
s
.57825 .79772 m .57028 .81515 L .59854 .82865 L p .707 .577 .707 r
F P
0 g
s
.53938 .77225 m .54171 .80895 L .56921 .81211 L p .707 .577 .707 r
F P
0 g
s
.50856 .73716 m .50888 .68154 L .4962 .67367 L p .707 .577 .707 r
F P
0 g
s
.63552 .82416 m .62755 .84159 L .65448 .85271 L p .707 .577 .707 r
F P
0 g
s
.65448 .85271 m .66245 .83528 L .63552 .82416 L p .707 .577 .707 r
F P
0 g
s
.57028 .81515 m .57825 .79772 L .55351 .78498 L p .707 .577 .707 r
F P
0 g
s
.54171 .80895 m .53938 .77225 L .51824 .76645 L p .707 .577 .707 r
F P
0 g
s
.55351 .78498 m .54554 .80241 L .57028 .81515 L p .707 .577 .707 r
F P
0 g
s
.66245 .83528 m .65448 .85271 L .67669 .86091 L p .707 .577 .707 r
F P
0 g
s
.67669 .86091 m .68466 .84348 L .66245 .83528 L p .707 .577 .707 r
F P
0 g
s
.68294 .75983 m .68528 .79654 L .70148 .78751 L p .707 .577 .707 r
F P
0 g
s
.70148 .78751 m .69914 .75081 L .68294 .75983 L p .707 .577 .707 r
F P
0 g
s
.4962 .67367 m .49588 .72929 L .50856 .73716 L p .707 .577 .707 r
F P
0 g
s
.51824 .76645 m .52057 .80315 L .54171 .80895 L p .707 .577 .707 r
F P
0 g
s
.69015 .67797 m .68983 .73359 L .69682 .72533 L p .707 .577 .707 r
F P
0 g
s
.69682 .72533 m .69714 .66971 L .69015 .67797 L p .707 .577 .707 r
F P
0 g
s
.54554 .80241 m .55351 .78498 L .53472 .77425 L p .707 .577 .707 r
F P
0 g
s
.53472 .77425 m .52675 .79168 L .54554 .80241 L p .707 .577 .707 r
F P
0 g
s
.52057 .80315 m .51824 .76645 L .50551 .75858 L p .707 .577 .707 r
F P
0 g
s
.49588 .72929 m .4962 .67367 L .49321 .66519 L p .707 .577 .707 r
F P
0 g
s
.68466 .84348 m .67669 .86091 L .692 .8654 L p .707 .577 .707 r
F P
0 g
s
.692 .8654 m .69997 .84797 L .68466 .84348 L p .707 .577 .707 r
F P
0 g
s
.50551 .75858 m .50785 .79529 L .52057 .80315 L p .707 .577 .707 r
F P
0 g
s
.69914 .75081 m .70148 .78751 L .70838 .77795 L p .707 .577 .707 r
F P
0 g
s
.70838 .77795 m .70605 .74125 L .69914 .75081 L p .707 .577 .707 r
F P
0 g
s
.52675 .79168 m .53472 .77425 L .5237 .76659 L p .707 .577 .707 r
F P
0 g
s
.49321 .66519 m .49289 .7208 L .49588 .72929 L p .707 .577 .707 r
F P
0 g
s
.5237 .76659 m .51573 .78402 L .52675 .79168 L p .707 .577 .707 r
F P
0 g
s
.69714 .66971 m .69682 .72533 L .69383 .71684 L p .707 .577 .707 r
F P
0 g
s
.69383 .71684 m .69415 .66123 L .69714 .66971 L p .707 .577 .707 r
F P
0 g
s
.50785 .79529 m .50551 .75858 L .50246 .74942 L p .707 .577 .707 r
F P
0 g
s
.49289 .7208 m .49321 .66519 L .5002 .65692 L p .707 .577 .707 r
F P
0 g
s
.48571 .82173 m .48571 .31984 L .44205 .31677 L p .707 .577 .707 r
F P
0 g
s
.50246 .74942 m .50479 .78613 L .50785 .79529 L p .707 .577 .707 r
F P
0 g
s
.51573 .78402 m .5237 .76659 L .52155 .76273 L p .707 .577 .707 r
F P
0 g
s
.52155 .76273 m .51358 .78016 L .51573 .78402 L p .707 .577 .707 r
F P
0 g
s
.5002 .65692 m .49988 .71254 L .49289 .7208 L p .707 .577 .707 r
F P
0 g
s
.50479 .78613 m .50246 .74942 L .50937 .73986 L p .707 .577 .707 r
F P
0 g
s
.49988 .71254 m .5002 .65692 L .51648 .64969 L p .707 .577 .707 r
F P
0 g
s
.50937 .73986 m .5117 .77656 L .50479 .78613 L p .707 .577 .707 r
F P
0 g
s
.51358 .78016 m .52155 .76273 L .52846 .76306 L p .707 .577 .707 r
F P
0 g
s
.51648 .64969 m .51617 .70531 L .49988 .71254 L p .707 .577 .707 r
F P
0 g
s
.52846 .76306 m .52049 .78049 L .51358 .78016 L p .707 .577 .707 r
F P
0 g
s
.51617 .70531 m .51648 .64969 L .54047 .6442 L p .707 .577 .707 r
F P
0 g
s
.5117 .77656 m .50937 .73986 L .52556 .73083 L p .707 .577 .707 r
F P
0 g
s
.52049 .78049 m .52846 .76306 L .54378 .76755 L p .707 .577 .707 r
F P
0 g
s
.52556 .73083 m .5279 .76754 L .5117 .77656 L p .707 .577 .707 r
F P
0 g
s
.54047 .6442 m .54015 .69982 L .51617 .70531 L p .707 .577 .707 r
F P
0 g
s
.54378 .76755 m .53581 .78498 L .52049 .78049 L p .707 .577 .707 r
F P
0 g
s
.48571 .31984 m .48571 .82173 L .53076 .82103 L p .707 .577 .707 r
F P
0 g
s
.5279 .76754 m .52556 .73083 L .54946 .72323 L p .707 .577 .707 r
F P
0 g
s
.54946 .72323 m .5518 .75993 L .5279 .76754 L p .707 .577 .707 r
F P
0 g
s
.53076 .82103 m .53076 .31914 L .48571 .31984 L p .707 .577 .707 r
F P
0 g
s
.54015 .69982 m .54047 .6442 L .56982 .64098 L p .707 .577 .707 r
F P
0 g
s
.56982 .64098 m .5695 .6966 L .54015 .69982 L p .707 .577 .707 r
F P
0 g
s
.5518 .75993 m .54946 .72323 L .57872 .71778 L p .707 .577 .707 r
F P
0 g
s
.53581 .78498 m .54378 .76755 L .56598 .77575 L p .707 .577 .707 r
F P
0 g
s
.56598 .77575 m .55801 .79318 L .53581 .78498 L p .707 .577 .707 r
F P
0 g
s
.57872 .71778 m .58106 .75449 L .5518 .75993 L p .707 .577 .707 r
F P
0 g
s
.55801 .79318 m .56598 .77575 L .59291 .78687 L p .707 .577 .707 r
F P
0 g
s
.59291 .78687 m .58494 .8043 L .55801 .79318 L p .707 .577 .707 r
F P
0 g
s
.53076 .31914 m .53076 .82103 L .5728 .81663 L p .707 .577 .707 r
F P
0 g
s
.5695 .6966 m .56982 .64098 L .60164 .64035 L p .707 .577 .707 r
F P
0 g
s
.60164 .64035 m .60132 .69597 L .5695 .6966 L p .707 .577 .707 r
F P
0 g
s
.5728 .81663 m .5728 .31474 L .53076 .31914 L p .707 .577 .707 r
F P
0 g
s
.69997 .84797 m .692 .8654 L .69891 .86573 L p .707 .577 .707 r
F P
0 g
s
.69891 .86573 m .70688 .8483 L .69997 .84797 L p .707 .577 .707 r
F P
0 g
s
.44205 .81866 m .44205 .31677 L .40407 .31023 L p .707 .577 .707 r
F P
0 g
s
.44205 .31677 m .44205 .81866 L .48571 .82173 L p .707 .577 .707 r
F P
0 g
s
.70605 .74125 m .70838 .77795 L .70533 .76879 L p .707 .577 .707 r
F P
0 g
s
.70533 .76879 m .70299 .73208 L .70605 .74125 L p .707 .577 .707 r
F P
0 g
s
.69415 .66123 m .69383 .71684 L .68115 .70897 L p .707 .577 .707 r
F P
0 g
s
.68115 .70897 m .68147 .65335 L .69415 .66123 L p .707 .577 .707 r
F P
0 g
s
.58106 .75449 m .57872 .71778 L .61049 .71504 L p .707 .577 .707 r
F P
0 g
s
.61049 .71504 m .61282 .75174 L .58106 .75449 L p .707 .577 .707 r
F P
0 g
s
.58494 .8043 m .59291 .78687 L .62192 .79981 L p .707 .577 .707 r
F P
0 g
s
.62192 .79981 m .61395 .81724 L .58494 .8043 L p .707 .577 .707 r
F P
0 g
s
.5728 .31474 m .5728 .81663 L .60772 .80896 L p .707 .577 .707 r
F P
0 g
s
.63283 .64238 m .63252 .698 L .60132 .69597 L p .707 .577 .707 r
F P
0 g
s
.60132 .69597 m .60164 .64035 L .63283 .64238 L p .707 .577 .707 r
F P
0 g
s
.60772 .80896 m .60772 .30707 L .5728 .31474 L p .707 .577 .707 r
F P
0 g
s
.40407 .81212 m .40407 .31023 L .37547 .30087 L p .707 .577 .707 r
F P
0 g
s
.40407 .31023 m .40407 .81212 L .44205 .81866 L p .707 .577 .707 r
F P
0 g
s
.70688 .8483 m .69891 .86573 L .69676 .86188 L p .707 .577 .707 r
F P
0 g
s
.69676 .86188 m .70473 .84444 L .70688 .8483 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24998 .71105 m .25011 .65555 L .21892 .65357 L p .707 .577 .707 r
F P
0 g
s
.25011 .65555 m .24998 .71105 L .2818 .7103 L p .707 .577 .707 r
F P
0 g
s
.2818 .7103 m .28194 .65481 L .25011 .65555 L p .707 .577 .707 r
F P
0 g
s
.28194 .65481 m .2818 .7103 L .31115 .7069 L p .707 .577 .707 r
F P
0 g
s
.31115 .7069 m .31128 .65141 L .28194 .65481 L p .707 .577 .707 r
F P
0 g
s
.70299 .73208 m .70533 .76879 L .69261 .76092 L p .707 .577 .707 r
F P
0 g
s
.69261 .76092 m .69027 .72422 L .70299 .73208 L p .707 .577 .707 r
F P
0 g
s
.21878 .70907 m .21892 .65357 L .19141 .64905 L p .707 .577 .707 r
F P
0 g
s
.21892 .65357 m .21878 .70907 L .24998 .71105 L p .707 .577 .707 r
F P
0 g
s
.64164 .71526 m .64397 .75196 L .61282 .75174 L p .707 .577 .707 r
F P
0 g
s
.61282 .75174 m .61049 .71504 L .64164 .71526 L p .707 .577 .707 r
F P
0 g
s
.61395 .81724 m .62192 .79981 L .65018 .81331 L p .707 .577 .707 r
F P
0 g
s
.60772 .30707 m .60772 .80896 L .63209 .79877 L p .707 .577 .707 r
F P
0 g
s
.63209 .79877 m .63209 .29688 L .60772 .30707 L p .707 .577 .707 r
F P
0 g
s
.68147 .65335 m .68115 .70897 L .66002 .70248 L p .707 .577 .707 r
F P
0 g
s
.66002 .70248 m .66034 .64686 L .68147 .65335 L p .707 .577 .707 r
F P
0 g
s
.25529 .76817 m .25429 .73058 L .22309 .72993 L p .707 .577 .707 r
F P
0 g
s
.25429 .73058 m .25529 .76817 L .2871 .76672 L p .707 .577 .707 r
F P
0 g
s
.2871 .76672 m .2861 .72912 L .25429 .73058 L p .707 .577 .707 r
F P
0 g
s
.2861 .72912 m .2871 .76672 L .3164 .76329 L p .707 .577 .707 r
F P
0 g
s
.3164 .76329 m .3154 .72569 L .2861 .72912 L p .707 .577 .707 r
F P
0 g
s
.31128 .65141 m .31115 .7069 L .33514 .70118 L p .707 .577 .707 r
F P
0 g
s
.33514 .70118 m .33527 .64568 L .31128 .65141 L p .707 .577 .707 r
F P
0 g
s
.22409 .76752 m .22309 .72993 L .19554 .72723 L p .707 .577 .707 r
F P
0 g
s
.22309 .72993 m .22409 .76752 L .25529 .76817 L p .707 .577 .707 r
F P
0 g
s
.19128 .70455 m .19141 .64905 L .17029 .64244 L p .707 .577 .707 r
F P
0 g
s
.19141 .64905 m .19128 .70455 L .21878 .70907 L p .707 .577 .707 r
F P
0 g
s
.19554 .72723 m .19655 .76483 L .22409 .76752 L p .707 .577 .707 r
F P
0 g
s
.3154 .72569 m .3164 .76329 L .34032 .75824 L p .707 .577 .707 r
F P
0 g
s
.34032 .75824 m .33932 .72064 L .3154 .72569 L p .707 .577 .707 r
F P
0 g
s
.70473 .84444 m .69676 .86188 L .68575 .85421 L p .707 .577 .707 r
F P
0 g
s
.68575 .85421 m .69372 .83678 L .70473 .84444 L p .707 .577 .707 r
F P
0 g
s
.37547 .80275 m .37547 .30087 L .35907 .28958 L p .707 .577 .707 r
F P
0 g
s
.37547 .30087 m .37547 .80275 L .40407 .81212 L p .707 .577 .707 r
F P
0 g
s
.66034 .64686 m .66002 .70248 L .63252 .698 L p .707 .577 .707 r
F P
0 g
s
.63252 .698 m .63283 .64238 L .66034 .64686 L p .707 .577 .707 r
F P
0 g
s
.69027 .72422 m .69261 .76092 L .67146 .75512 L p .707 .577 .707 r
F P
0 g
s
.67146 .75512 m .66913 .71842 L .69027 .72422 L p .707 .577 .707 r
F P
0 g
s
.19655 .76483 m .19554 .72723 L .17436 .72276 L p .707 .577 .707 r
F P
0 g
s
.33527 .64568 m .33514 .70118 L .35142 .69369 L p .707 .577 .707 r
F P
0 g
s
.35142 .69369 m .35156 .63819 L .33527 .64568 L p .707 .577 .707 r
F P
0 g
s
.17029 .64244 m .17015 .69794 L .19128 .70455 L p .707 .577 .707 r
F P
0 g
s
.25599 .85217 m .25958 .83767 L .22886 .82893 L p .707 .577 .707 r
F P
0 g
s
.25958 .83767 m .25599 .85217 L .28722 .85458 L p .707 .577 .707 r
F P
0 g
s
.28722 .85458 m .29081 .84008 L .25958 .83767 L p .707 .577 .707 r
F P
0 g
s
.22527 .84342 m .22886 .82893 L .20167 .81471 L p .707 .577 .707 r
F P
0 g
s
.22886 .82893 m .22527 .84342 L .25599 .85217 L p .707 .577 .707 r
F P
0 g
s
.17436 .72276 m .17536 .76035 L .19655 .76483 L p .707 .577 .707 r
F P
0 g
s
.64397 .75196 m .64164 .71526 L .66913 .71842 L p .707 .577 .707 r
F P
0 g
s
.63209 .29688 m .63209 .79877 L .64353 .78705 L p .707 .577 .707 r
F P
0 g
s
.64353 .78705 m .64353 .28516 L .63209 .29688 L p .707 .577 .707 r
F P
0 g
s
.17015 .69794 m .17029 .64244 L .1576 .63438 L p .707 .577 .707 r
F P
0 g
s
.29081 .84008 m .28722 .85458 L .31591 .85042 L p .707 .577 .707 r
F P
0 g
s
.31591 .85042 m .3195 .83593 L .29081 .84008 L p .707 .577 .707 r
F P
0 g
s
.33932 .72064 m .34032 .75824 L .35653 .75205 L p .707 .577 .707 r
F P
0 g
s
.35653 .75205 m .35552 .71445 L .33932 .72064 L p .707 .577 .707 r
F P
0 g
s
.19807 .8292 m .20167 .81471 L .18065 .7964 L p .707 .577 .707 r
F P
0 g
s
.20167 .81471 m .19807 .8292 L .22527 .84342 L p .707 .577 .707 r
F P
0 g
s
.66913 .71842 m .67146 .75512 L .64397 .75196 L p .707 .577 .707 r
F P
0 g
s
.17536 .76035 m .17436 .72276 L .1616 .71694 L p .707 .577 .707 r
F P
0 g
s
.69372 .83678 m .68575 .85421 L .66695 .84348 L p .707 .577 .707 r
F P
0 g
s
.66695 .84348 m .67492 .82605 L .69372 .83678 L p .707 .577 .707 r
F P
0 g
s
.3195 .83593 m .31591 .85042 L .33925 .8401 L p .707 .577 .707 r
F P
0 g
s
.33925 .8401 m .34284 .82561 L .3195 .83593 L p .707 .577 .707 r
F P
0 g
s
.1576 .63438 m .15747 .68988 L .17015 .69794 L p .707 .577 .707 r
F P
0 g
s
.35156 .63819 m .35142 .69369 L .35841 .68517 L p .707 .577 .707 r
F P
0 g
s
.35841 .68517 m .35855 .62967 L .35156 .63819 L p .707 .577 .707 r
F P
0 g
s
.18065 .7964 m .17706 .8109 L .19807 .8292 L p .707 .577 .707 r
F P
0 g
s
.17706 .8109 m .18065 .7964 L .16788 .77581 L p .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16788 .77581 L .16766 .77442 L p .707 .577 .707 r
F P
0 g
s
.1616 .71694 m .1626 .75453 L .17175 .75871 L p .707 .577 .707 r
F P
0 g
s
.16766 .77442 m .16459 .75493 L p .16431 .78729 L .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16766 .77442 L .16431 .78729 L .707 .577 .707 r
F
.17175 .75871 m .17536 .76035 L p .17314 .75336 L F P
0 g
s
.17314 .75336 m .1616 .71694 L .17175 .75871 L .707 .577 .707 r
F
.35552 .71445 m .35653 .75205 L .36343 .74533 L p F P
0 g
s
.36343 .74533 m .36242 .70773 L .35552 .71445 L p .707 .577 .707 r
F P
0 g
s
.35855 .62967 m .35841 .68517 L .35542 .67645 L p .707 .577 .707 r
F P
0 g
s
.35542 .67645 m .35556 .62096 L .35855 .62967 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .36507 .79103 L .35854 .81013 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .35819 .78465 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36507 .79103 m .36353 .79722 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36353 .79722 m .36147 .80552 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35646 .27749 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36178 .77015 L .36235 .77375 L p .707 .577 .707 r
F P
0 g
s
.36235 .77375 m .36507 .79103 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36235 .77375 L .36313 .78923 L .707 .577 .707 r
F
.35934 .70114 m .36035 .73874 L .34759 .73292 L p F P
0 g
s
.34759 .73292 m .34658 .69532 L .35934 .70114 L p .707 .577 .707 r
F P
0 g
s
.36178 .77015 m .35819 .78465 L .34542 .76405 L p .707 .577 .707 r
F P
0 g
s
.34542 .76405 m .34901 .74955 L .36178 .77015 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35907 .79147 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .27749 m .35646 .65696 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .65696 m .35646 .77938 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .79147 m .35907 .70871 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .70871 m .35907 .28958 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.36242 .70773 m .36343 .74533 L .36035 .73874 L p .707 .577 .707 r
F P
0 g
s
.36035 .73874 m .35934 .70114 L .36242 .70773 L p .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35907 .79147 L .37547 .80275 L p .707 .577 .707 r
F P
0 g
s
.15747 .68988 m .1576 .63438 L .15461 .62567 L p .707 .577 .707 r
F P
0 g
s
.16788 .77581 m .16428 .7903 L .17706 .8109 L p .707 .577 .707 r
F P
0 g
s
.34284 .82561 m .33925 .8401 L .35495 .82463 L p .707 .577 .707 r
F P
0 g
s
.35495 .82463 m .35854 .81013 L .34284 .82561 L p .707 .577 .707 r
F P
0 g
s
.67492 .82605 m .66695 .84348 L .64221 .83074 L p .707 .577 .707 r
F P
0 g
s
.64221 .83074 m .65018 .81331 L .67492 .82605 L p .707 .577 .707 r
F P
0 g
s
.64353 .28516 m .64353 .78705 L .64093 .77496 L p .707 .577 .707 r
F P
0 g
s
.64093 .77496 m .64093 .27308 L .64353 .28516 L p .707 .577 .707 r
F P
0 g
s
.1626 .75453 m .1616 .71694 L .15852 .71034 L p .707 .577 .707 r
F P
0 g
s
.15461 .62567 m .15448 .68116 L .15747 .68988 L p .707 .577 .707 r
F P
0 g
s
.15852 .71034 m .15952 .74794 L .1626 .75453 L p .707 .577 .707 r
F P
0 g
s
.65018 .81331 m .64221 .83074 L .61395 .81724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16459 .75493 m .161 .76942 L .16428 .7903 L p .707 .577 .707 r
F P
0 g
s
.35854 .81013 m .35495 .82463 L .36147 .80552 L p .707 .577 .707 r
F P
0 g
s
.15448 .68116 m .15461 .62567 L .1616 .61715 L p .707 .577 .707 r
F P
0 g
s
.161 .76942 m .16459 .75493 L .17112 .73582 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35646 .27749 L .36791 .26578 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15952 .74794 m .15852 .71034 L .16542 .70362 L p .707 .577 .707 r
F P
0 g
s
.1616 .61715 m .16146 .67265 L .15448 .68116 L p .707 .577 .707 r
F P
0 g
s
.35556 .62096 m .35542 .67645 L .34274 .66839 L p .707 .577 .707 r
F P
0 g
s
.34274 .66839 m .34288 .6129 L .35556 .62096 L p .707 .577 .707 r
F P
0 g
s
.17112 .73582 m .16753 .75032 L .161 .76942 L p .707 .577 .707 r
F P
0 g
s
.16542 .70362 m .16642 .74122 L .15952 .74794 L p .707 .577 .707 r
F P
0 g
s
.64093 .27308 m .64093 .77496 L .62452 .76368 L p .707 .577 .707 r
F P
0 g
s
.62452 .76368 m .62452 .26179 L .64093 .27308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16146 .67265 m .1616 .61715 L .17789 .60966 L p .707 .577 .707 r
F P
0 g
s
.16753 .75032 m .17112 .73582 L .18682 .72035 L p .707 .577 .707 r
F P
0 g
s
.18682 .72035 m .18323 .73484 L .16753 .75032 L p .707 .577 .707 r
F P
0 g
s
.16642 .74122 m .16542 .70362 L .18162 .69743 L p .707 .577 .707 r
F P
0 g
s
.17789 .60966 m .17775 .66516 L .16146 .67265 L p .707 .577 .707 r
F P
0 g
s
.34288 .6129 m .34274 .66839 L .32161 .66178 L p .707 .577 .707 r
F P
0 g
s
.32161 .66178 m .32175 .60629 L .34288 .6129 L p .707 .577 .707 r
F P
0 g
s
.36791 .76767 m .36791 .26578 L .39228 .25559 L p .707 .577 .707 r
F P
0 g
s
.36791 .26578 m .36791 .76767 L .35646 .77938 L p .707 .577 .707 r
F P
0 g
s
.18162 .69743 m .18263 .73503 L .16642 .74122 L p .707 .577 .707 r
F P
0 g
s
.18323 .73484 m .18682 .72035 L .21016 .71003 L p .707 .577 .707 r
F P
0 g
s
.17775 .66516 m .17789 .60966 L .20188 .60393 L p .707 .577 .707 r
F P
0 g
s
.34658 .69532 m .34759 .73292 L .3264 .72844 L p .707 .577 .707 r
F P
0 g
s
.3264 .72844 m .3254 .69084 L .34658 .69532 L p .707 .577 .707 r
F P
0 g
s
.62452 .26179 m .62452 .76368 L .59593 .75431 L p .707 .577 .707 r
F P
0 g
s
.59593 .75431 m .59593 .25242 L .62452 .26179 L p .707 .577 .707 r
F P
0 g
s
.21016 .71003 m .20656 .72452 L .18323 .73484 L p .707 .577 .707 r
F P
0 g
s
.34901 .74955 m .34542 .76405 L .3244 .74574 L p .707 .577 .707 r
F P
0 g
s
.3244 .74574 m .32799 .73125 L .34901 .74955 L p .707 .577 .707 r
F P
0 g
s
.32175 .60629 m .32161 .66178 L .2941 .65726 L p .707 .577 .707 r
F P
0 g
s
.2941 .65726 m .29424 .60177 L .32175 .60629 L p .707 .577 .707 r
F P
0 g
s
.18263 .73503 m .18162 .69743 L .20554 .69238 L p .707 .577 .707 r
F P
0 g
s
.20188 .60393 m .20174 .65943 L .17775 .66516 L p .707 .577 .707 r
F P
0 g
s
.20656 .72452 m .21016 .71003 L .23885 .70587 L p .707 .577 .707 r
F P
0 g
s
.20174 .65943 m .20188 .60393 L .23122 .60053 L p .707 .577 .707 r
F P
0 g
s
.73709 .6591 m .73695 .60343 L .70576 .60166 L p .707 .577 .707 r
F P
0 g
s
.73695 .60343 m .73709 .6591 L .76891 .65824 L p .707 .577 .707 r
F P
0 g
s
.76891 .65824 m .76878 .60257 L .73695 .60343 L p .707 .577 .707 r
F P
0 g
s
.20554 .69238 m .20655 .72998 L .18263 .73503 L p .707 .577 .707 r
F P
0 g
s
.76878 .60257 m .76891 .65824 L .79826 .65483 L p .707 .577 .707 r
F P
0 g
s
.79826 .65483 m .79812 .59917 L .76878 .60257 L p .707 .577 .707 r
F P
0 g
s
.32799 .73125 m .3244 .74574 L .2972 .73152 L p .707 .577 .707 r
F P
0 g
s
.2972 .73152 m .3008 .71703 L .32799 .73125 L p .707 .577 .707 r
F P
0 g
s
.3254 .69084 m .3264 .72844 L .29886 .72574 L p .707 .577 .707 r
F P
0 g
s
.3008 .71703 m .2972 .73152 L .26648 .72278 L p .707 .577 .707 r
F P
0 g
s
.26648 .72278 m .27008 .70828 L .3008 .71703 L p .707 .577 .707 r
F P
0 g
s
.29886 .72574 m .29785 .68815 L .3254 .69084 L p .707 .577 .707 r
F P
0 g
s
.29424 .60177 m .2941 .65726 L .26291 .65528 L p .707 .577 .707 r
F P
0 g
s
.26291 .65528 m .26305 .59978 L .29424 .60177 L p .707 .577 .707 r
F P
0 g
s
.70589 .65733 m .70576 .60166 L .67825 .59744 L p .707 .577 .707 r
F P
0 g
s
.70576 .60166 m .70589 .65733 L .73709 .6591 L p .707 .577 .707 r
F P
0 g
s
.23885 .70587 m .23525 .72037 L .20656 .72452 L p .707 .577 .707 r
F P
0 g
s
.23525 .72037 m .23885 .70587 L .27008 .70828 L p .707 .577 .707 r
F P
0 g
s
.39228 .25559 m .39228 .75748 L .36791 .76767 L p .707 .577 .707 r
F P
0 g
s
.39228 .75748 m .39228 .25559 L .42719 .24792 L p .707 .577 .707 r
F P
0 g
s
.23108 .65603 m .23122 .60053 L .26305 .59978 L p .707 .577 .707 r
F P
0 g
s
.23122 .60053 m .23108 .65603 L .20174 .65943 L p .707 .577 .707 r
F P
0 g
s
.20655 .72998 m .20554 .69238 L .23484 .68896 L p .707 .577 .707 r
F P
0 g
s
.26305 .59978 m .26291 .65528 L .23108 .65603 L p .707 .577 .707 r
F P
0 g
s
.27008 .70828 m .26648 .72278 L .23525 .72037 L p .707 .577 .707 r
F P
0 g
s
.79812 .59917 m .79826 .65483 L .82225 .64922 L p .707 .577 .707 r
F P
0 g
s
.82225 .64922 m .82211 .59356 L .79812 .59917 L p .707 .577 .707 r
F P
0 g
s
.23484 .68896 m .23585 .72655 L .20655 .72998 L p .707 .577 .707 r
F P
0 g
s
.29785 .68815 m .29886 .72574 L .26766 .72509 L p .707 .577 .707 r
F P
0 g
s
.26766 .72509 m .26665 .6875 L .29785 .68815 L p .707 .577 .707 r
F P
0 g
s
.59593 .25242 m .59593 .75431 L .55795 .74777 L p .707 .577 .707 r
F P
0 g
s
.55795 .74777 m .55795 .24588 L .59593 .25242 L p .707 .577 .707 r
F P
0 g
s
.67825 .59744 m .67839 .65311 L .70589 .65733 L p .707 .577 .707 r
F P
0 g
s
.67839 .65311 m .67825 .59744 L .65712 .59118 L p .707 .577 .707 r
F P
0 g
s
.23585 .72655 m .23484 .68896 L .26665 .6875 L p .707 .577 .707 r
F P
0 g
s
.26665 .6875 m .26766 .72509 L .23585 .72655 L p .707 .577 .707 r
F P
0 g
s
.73234 .72253 m .73335 .68618 L .70214 .68316 L p .707 .577 .707 r
F P
0 g
s
.73335 .68618 m .73234 .72253 L .76415 .72231 L p .707 .577 .707 r
F P
0 g
s
.76415 .72231 m .76515 .68596 L .73335 .68618 L p .707 .577 .707 r
F P
0 g
s
.82211 .59356 m .82225 .64922 L .83853 .64195 L p .707 .577 .707 r
F P
0 g
s
.83853 .64195 m .8384 .58628 L .82211 .59356 L p .707 .577 .707 r
F P
0 g
s
.76515 .68596 m .76415 .72231 L .79345 .71888 L p .707 .577 .707 r
F P
0 g
s
.79345 .71888 m .79445 .68253 L .76515 .68596 L p .707 .577 .707 r
F P
0 g
s
.42719 .74981 m .42719 .24792 L .46924 .24351 L p .707 .577 .707 r
F P
0 g
s
.42719 .24792 m .42719 .74981 L .39228 .75748 L p .707 .577 .707 r
F P
0 g
s
.65712 .59118 m .65726 .64685 L .67839 .65311 L p .707 .577 .707 r
F P
0 g
s
.70114 .71951 m .70214 .68316 L .6746 .6772 L p .707 .577 .707 r
F P
0 g
s
.70214 .68316 m .70114 .71951 L .73234 .72253 L p .707 .577 .707 r
F P
0 g
s
.55795 .24588 m .55795 .74777 L .51429 .7447 L p .707 .577 .707 r
F P
0 g
s
.51429 .7447 m .51429 .24281 L .55795 .24588 L p .707 .577 .707 r
F P
0 g
s
.65726 .64685 m .65712 .59118 L .64444 .58349 L p .707 .577 .707 r
F P
0 g
s
.79445 .68253 m .79345 .71888 L .81737 .71256 L p .707 .577 .707 r
F P
0 g
s
.81737 .71256 m .81838 .67621 L .79445 .68253 L p .707 .577 .707 r
F P
0 g
s
.6746 .6772 m .6736 .71355 L .70114 .71951 L p .707 .577 .707 r
F P
0 g
s
.6992 .70393 m .70279 .72261 L .73351 .71582 L p .707 .577 .707 r
F P
0 g
s
.73351 .71582 m .72992 .69715 L .6992 .70393 L p .707 .577 .707 r
F P
0 g
s
.72992 .69715 m .73351 .71582 L .76475 .71046 L p .707 .577 .707 r
F P
0 g
s
.46924 .7454 m .46924 .24351 L .51429 .24281 L p .707 .577 .707 r
F P
0 g
s
.46924 .24351 m .46924 .7454 L .42719 .74981 L p .707 .577 .707 r
F P
0 g
s
.6736 .71355 m .6746 .6772 L .65341 .66887 L p .707 .577 .707 r
F P
0 g
s
.76475 .71046 m .76115 .69179 L .72992 .69715 L p .707 .577 .707 r
F P
0 g
s
.51429 .24281 m .51429 .7447 L .46924 .7454 L p .707 .577 .707 r
F P
0 g
s
.76115 .69179 m .76475 .71046 L .79343 .70705 L p .707 .577 .707 r
F P
0 g
s
.65341 .66887 m .65241 .70522 L .6736 .71355 L p .707 .577 .707 r
F P
0 g
s
.672 .71148 m .6756 .73016 L .70279 .72261 L p .707 .577 .707 r
F P
0 g
s
.70279 .72261 m .6992 .70393 L .672 .71148 L p .707 .577 .707 r
F P
0 g
s
.79343 .70705 m .78984 .68838 L .76115 .69179 L p .707 .577 .707 r
F P
0 g
s
.64444 .58349 m .64458 .63916 L .65726 .64685 L p .707 .577 .707 r
F P
0 g
s
.8384 .58628 m .83853 .64195 L .84552 .63373 L p .707 .577 .707 r
F P
0 g
s
.84552 .63373 m .84539 .57806 L .8384 .58628 L p .707 .577 .707 r
F P
0 g
s
.81838 .67621 m .81737 .71256 L .83358 .70398 L p .707 .577 .707 r
F P
0 g
s
.83358 .70398 m .83458 .66762 L .81838 .67621 L p .707 .577 .707 r
F P
0 g
s
.78984 .68838 m .79343 .70705 L .81677 .70593 L p .707 .577 .707 r
F P
0 g
s
.65099 .71906 m .65458 .73773 L .6756 .73016 L p .707 .577 .707 r
F P
0 g
s
.6756 .73016 m .672 .71148 L .65099 .71906 L p .707 .577 .707 r
F P
0 g
s
.81677 .70593 m .81318 .68726 L .78984 .68838 L p .707 .577 .707 r
F P
0 g
s
.64458 .63916 m .64444 .58349 L .64145 .57512 L p .707 .577 .707 r
F P
0 g
s
.65241 .70522 m .65341 .66887 L .64066 .659 L p .707 .577 .707 r
F P
0 g
s
.64066 .659 m .63965 .69535 L .65241 .70522 L p .707 .577 .707 r
F P
0 g
s
.64145 .57512 m .64158 .63079 L .64458 .63916 L p .707 .577 .707 r
F P
0 g
s
.81318 .68726 m .81677 .70593 L .83247 .70721 L p .707 .577 .707 r
F P
0 g
s
.84539 .57806 m .84552 .63373 L .84253 .62536 L p .707 .577 .707 r
F P
0 g
s
.84253 .62536 m .84239 .5697 L .84539 .57806 L p .707 .577 .707 r
F P
0 g
s
.83247 .70721 m .82888 .68853 L .81318 .68726 L p .707 .577 .707 r
F P
0 g
s
.83458 .66762 m .83358 .70398 L .84048 .69397 L p .707 .577 .707 r
F P
0 g
s
.84048 .69397 m .84148 .65762 L .83458 .66762 L p .707 .577 .707 r
F P
0 g
s
.63821 .72592 m .64181 .74459 L .65458 .73773 L p .707 .577 .707 r
F P
0 g
s
.65458 .73773 m .65099 .71906 L .63821 .72592 L p .707 .577 .707 r
F P
0 g
s
.63965 .69535 m .64066 .659 L .63758 .64855 L p .707 .577 .707 r
F P
0 g
s
.64158 .63079 m .64145 .57512 L .64844 .5669 L p .707 .577 .707 r
F P
0 g
s
.63758 .64855 m .63657 .6849 L .63965 .69535 L p .707 .577 .707 r
F P
0 g
s
.82888 .68853 m .83247 .70721 L .839 .71075 L p .707 .577 .707 r
F P
0 g
s
.64844 .5669 m .64857 .62257 L .64158 .63079 L p .707 .577 .707 r
F P
0 g
s
.839 .71075 m .83541 .69208 L .82888 .68853 L p .707 .577 .707 r
F P
0 g
s
.84239 .5697 m .84253 .62536 L .82985 .61767 L p .707 .577 .707 r
F P
0 g
s
.82985 .61767 m .82971 .56201 L .84239 .5697 L p .707 .577 .707 r
F P
0 g
s
.63493 .73138 m .63852 .75006 L .64181 .74459 L p .707 .577 .707 r
F P
0 g
s
.64181 .74459 m .63821 .72592 L .63493 .73138 L p .707 .577 .707 r
F P
0 g
s
.84148 .65762 m .84048 .69397 L .8374 .68352 L p .707 .577 .707 r
F P
0 g
s
.8374 .68352 m .8384 .64717 L .84148 .65762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63657 .6849 m .63758 .64855 L .64448 .63855 L p .707 .577 .707 r
F P
0 g
s
.64857 .62257 m .64844 .5669 L .66472 .55963 L p .707 .577 .707 r
F P
0 g
s
.39867 .61999 m .39836 .56444 L .36716 .56272 L p .707 .577 .707 r
F P
0 g
s
.39836 .56444 m .39867 .61999 L .4305 .61901 L p .707 .577 .707 r
F P
0 g
s
.4305 .61901 m .43018 .56347 L .39836 .56444 L p .707 .577 .707 r
F P
0 g
s
.43018 .56347 m .4305 .61901 L .45984 .61542 L p .707 .577 .707 r
F P
0 g
s
.45984 .61542 m .45953 .55988 L .43018 .56347 L p .707 .577 .707 r
F P
0 g
s
.64448 .63855 m .64347 .6749 L .63657 .6849 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36748 .61826 m .36716 .56272 L .33966 .55846 L p .707 .577 .707 r
F P
0 g
s
.36716 .56272 m .36748 .61826 L .39867 .61999 L p .707 .577 .707 r
F P
0 g
s
.66472 .55963 m .66486 .6153 L .64857 .62257 L p .707 .577 .707 r
F P
0 g
s
.83541 .69208 m .839 .71075 L .83571 .71622 L p .707 .577 .707 r
F P
0 g
s
.82971 .56201 m .82985 .61767 L .80872 .61141 L p .707 .577 .707 r
F P
0 g
s
.80872 .61141 m .80859 .55575 L .82971 .56201 L p .707 .577 .707 r
F P
0 g
s
.83571 .71622 m .83212 .69755 L .83541 .69208 L p .707 .577 .707 r
F P
0 g
s
.8384 .64717 m .8374 .68352 L .82464 .67365 L p .707 .577 .707 r
F P
0 g
s
.82464 .67365 m .82564 .6373 L .8384 .64717 L p .707 .577 .707 r
F P
0 g
s
.64146 .73493 m .64505 .7536 L .63852 .75006 L p .707 .577 .707 r
F P
0 g
s
.63852 .75006 m .63493 .73138 L .64146 .73493 L p .707 .577 .707 r
F P
0 g
s
.45953 .55988 m .45984 .61542 L .48383 .60958 L p .707 .577 .707 r
F P
0 g
s
.48383 .60958 m .48351 .55403 L .45953 .55988 L p .707 .577 .707 r
F P
0 g
s
.38718 .67844 m .38951 .6412 L .35836 .63768 L p .707 .577 .707 r
F P
0 g
s
.38951 .6412 m .38718 .67844 L .41894 .67957 L p .707 .577 .707 r
F P
0 g
s
.41894 .67957 m .42127 .64233 L .38951 .6412 L p .707 .577 .707 r
F P
0 g
s
.66486 .6153 m .66472 .55963 L .68871 .55402 L p .707 .577 .707 r
F P
0 g
s
.64347 .6749 m .64448 .63855 L .66068 .62996 L p .707 .577 .707 r
F P
0 g
s
.42127 .64233 m .41894 .67957 L .4482 .6782 L p .707 .577 .707 r
F P
0 g
s
.4482 .6782 m .45054 .64096 L .42127 .64233 L p .707 .577 .707 r
F P
0 g
s
.33966 .55846 m .33997 .614 L .36748 .61826 L p .707 .577 .707 r
F P
0 g
s
.33997 .614 m .33966 .55846 L .31853 .55208 L p .707 .577 .707 r
F P
0 g
s
.35602 .67492 m .35836 .63768 L .33087 .63211 L p .707 .577 .707 r
F P
0 g
s
.35836 .63768 m .35602 .67492 L .38718 .67844 L p .707 .577 .707 r
F P
0 g
s
.80859 .55575 m .80872 .61141 L .78121 .60719 L p .707 .577 .707 r
F P
0 g
s
.78121 .60719 m .78108 .55152 L .80859 .55575 L p .707 .577 .707 r
F P
0 g
s
.33087 .63211 m .32853 .66936 L .35602 .67492 L p .707 .577 .707 r
F P
0 g
s
.66068 .62996 m .65968 .66632 L .64347 .6749 L p .707 .577 .707 r
F P
0 g
s
.68871 .55402 m .68885 .60969 L .66486 .6153 L p .707 .577 .707 r
F P
0 g
s
.45054 .64096 m .4482 .6782 L .4721 .67447 L p .707 .577 .707 r
F P
0 g
s
.4721 .67447 m .47443 .63722 L .45054 .64096 L p .707 .577 .707 r
F P
0 g
s
.48351 .55403 m .48383 .60958 L .50012 .60205 L p .707 .577 .707 r
F P
0 g
s
.50012 .60205 m .4998 .5465 L .48351 .55403 L p .707 .577 .707 r
F P
0 g
s
.41506 .72972 m .40709 .71399 L .37807 .7269 L p .707 .577 .707 r
F P
0 g
s
.40709 .71399 m .41506 .72972 L .44199 .7134 L p .707 .577 .707 r
F P
0 g
s
.44199 .7134 m .43402 .69767 L .40709 .71399 L p .707 .577 .707 r
F P
0 g
s
.31853 .55208 m .31885 .60762 L .33997 .614 L p .707 .577 .707 r
F P
0 g
s
.68885 .60969 m .68871 .55402 L .71806 .55062 L p .707 .577 .707 r
F P
0 g
s
.83212 .69755 m .83571 .71622 L .82294 .72308 L p .707 .577 .707 r
F P
0 g
s
.82564 .6373 m .82464 .67365 L .80345 .66533 L p .707 .577 .707 r
F P
0 g
s
.80345 .66533 m .80446 .62897 L .82564 .6373 L p .707 .577 .707 r
F P
0 g
s
.32853 .66936 m .33087 .63211 L .30973 .62505 L p .707 .577 .707 r
F P
0 g
s
.38604 .74264 m .37807 .7269 L .34982 .73514 L p .707 .577 .707 r
F P
0 g
s
.37807 .7269 m .38604 .74264 L .41506 .72972 L p .707 .577 .707 r
F P
0 g
s
.43402 .69767 m .44199 .7134 L .46419 .69528 L p .707 .577 .707 r
F P
0 g
s
.46419 .69528 m .45622 .67954 L .43402 .69767 L p .707 .577 .707 r
F P
0 g
s
.82294 .72308 m .81935 .70441 L .83212 .69755 L p .707 .577 .707 r
F P
0 g
s
.65716 .7362 m .66075 .75488 L .64505 .7536 L p .707 .577 .707 r
F P
0 g
s
.64505 .7536 m .64146 .73493 L .65716 .7362 L p .707 .577 .707 r
F P
0 g
s
.31885 .60762 m .31853 .55208 L .30585 .5442 L p .707 .577 .707 r
F P
0 g
s
.65968 .66632 m .66068 .62996 L .6846 .62364 L p .707 .577 .707 r
F P
0 g
s
.78108 .55152 m .78121 .60719 L .75002 .60542 L p .707 .577 .707 r
F P
0 g
s
.75002 .60542 m .74988 .54976 L .78108 .55152 L p .707 .577 .707 r
F P
0 g
s
.34982 .73514 m .35778 .75088 L .38604 .74264 L p .707 .577 .707 r
F P
0 g
s
.30973 .62505 m .30739 .66229 L .32853 .66936 L p .707 .577 .707 r
F P
0 g
s
.71819 .60628 m .71806 .55062 L .74988 .54976 L p .707 .577 .707 r
F P
0 g
s
.71806 .55062 m .71819 .60628 L .68885 .60969 L p .707 .577 .707 r
F P
0 g
s
.35778 .75088 m .34982 .73514 L .32508 .73791 L p .707 .577 .707 r
F P
0 g
s
.74988 .54976 m .75002 .60542 L .71819 .60628 L p .707 .577 .707 r
F P
0 g
s
.47443 .63722 m .4721 .67447 L .48829 .66873 L p .707 .577 .707 r
F P
0 g
s
.48829 .66873 m .49063 .63149 L .47443 .63722 L p .707 .577 .707 r
F P
0 g
s
.45622 .67954 m .46419 .69528 L .4795 .67711 L p .707 .577 .707 r
F P
0 g
s
.4795 .67711 m .47153 .66138 L .45622 .67954 L p .707 .577 .707 r
F P
0 g
s
.6846 .62364 m .6836 .66 L .65968 .66632 L p .707 .577 .707 r
F P
0 g
s
.32508 .73791 m .33305 .75365 L .35778 .75088 L p .707 .577 .707 r
F P
0 g
s
.80446 .62897 m .80345 .66533 L .77591 .65936 L p .707 .577 .707 r
F P
0 g
s
.77591 .65936 m .77691 .62301 L .80446 .62897 L p .707 .577 .707 r
F P
0 g
s
.30585 .5442 m .30616 .59975 L .31885 .60762 L p .707 .577 .707 r
F P
0 g
s
.4998 .5465 m .50012 .60205 L .50711 .59357 L p .707 .577 .707 r
F P
0 g
s
.50711 .59357 m .50679 .53803 L .4998 .5465 L p .707 .577 .707 r
F P
0 g
s
.30739 .66229 m .30973 .62505 L .29701 .61718 L p .707 .577 .707 r
F P
0 g
s
.6836 .66 m .6846 .62364 L .7139 .62021 L p .707 .577 .707 r
F P
0 g
s
.81935 .70441 m .82294 .72308 L .80193 .73065 L p .707 .577 .707 r
F P
0 g
s
.80193 .73065 m .79833 .71198 L .81935 .70441 L p .707 .577 .707 r
F P
0 g
s
.6805 .73508 m .68409 .75376 L .66075 .75488 L p .707 .577 .707 r
F P
0 g
s
.66075 .75488 m .65716 .7362 L .6805 .73508 L p .707 .577 .707 r
F P
0 g
s
.29701 .61718 m .29467 .65442 L .30739 .66229 L p .707 .577 .707 r
F P
0 g
s
.33305 .75365 m .32508 .73791 L .30628 .73493 L p .707 .577 .707 r
F P
0 g
s
.30616 .59975 m .30585 .5442 L .30285 .53561 L p .707 .577 .707 r
F P
0 g
s
.77691 .62301 m .77591 .65936 L .74471 .65634 L p .707 .577 .707 r
F P
0 g
s
.74471 .65634 m .74571 .61999 L .77691 .62301 L p .707 .577 .707 r
F P
0 g
s
.47153 .66138 m .4795 .67711 L .48642 .6607 L p .707 .577 .707 r
F P
0 g
s
.48642 .6607 m .47845 .64496 L .47153 .66138 L p .707 .577 .707 r
F P
0 g
s
.7129 .65656 m .7139 .62021 L .74571 .61999 L p .707 .577 .707 r
F P
0 g
s
.7139 .62021 m .7129 .65656 L .6836 .66 L p .707 .577 .707 r
F P
0 g
s
.30628 .73493 m .31425 .75067 L .33305 .75365 L p .707 .577 .707 r
F P
0 g
s
.49063 .63149 m .48829 .66873 L .4952 .66156 L p .707 .577 .707 r
F P
0 g
s
.4952 .66156 m .49754 .62431 L .49063 .63149 L p .707 .577 .707 r
F P
0 g
s
.74571 .61999 m .74471 .65634 L .7129 .65656 L p .707 .577 .707 r
F P
0 g
s
.30285 .53561 m .30317 .59115 L .30616 .59975 L p .707 .577 .707 r
F P
0 g
s
.79833 .71198 m .80193 .73065 L .77473 .7382 L p .707 .577 .707 r
F P
0 g
s
.29467 .65442 m .29701 .61718 L .29395 .60926 L p .707 .577 .707 r
F P
0 g
s
.50679 .53803 m .50711 .59357 L .50412 .58497 L p .707 .577 .707 r
F P
0 g
s
.50412 .58497 m .5038 .52943 L .50679 .53803 L p .707 .577 .707 r
F P
0 g
s
.70918 .73168 m .71278 .75035 L .68409 .75376 L p .707 .577 .707 r
F P
0 g
s
.68409 .75376 m .6805 .73508 L .70918 .73168 L p .707 .577 .707 r
F P
0 g
s
.77473 .7382 m .77113 .71953 L .79833 .71198 L p .707 .577 .707 r
F P
0 g
s
.31425 .75067 m .30628 .73493 L .29527 .72649 L p .707 .577 .707 r
F P
0 g
s
.29395 .60926 m .29161 .64651 L .29467 .65442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.47845 .64496 m .48642 .6607 L .48427 .64763 L p .707 .577 .707 r
F P
0 g
s
.48427 .64763 m .4763 .63189 L .47845 .64496 L p .707 .577 .707 r
F P
0 g
s
.30317 .59115 m .30285 .53561 L .30984 .52713 L p .707 .577 .707 r
F P
0 g
s
.77113 .71953 m .77473 .7382 L .74401 .74499 L p .707 .577 .707 r
F P
0 g
s
.29527 .72649 m .30324 .74223 L .31425 .75067 L p .707 .577 .707 r
F P
0 g
s
.74042 .72632 m .74401 .74499 L .71278 .75035 L p .707 .577 .707 r
F P
0 g
s
.71278 .75035 m .70918 .73168 L .74042 .72632 L p .707 .577 .707 r
F P
0 g
s
.74401 .74499 m .74042 .72632 L .77113 .71953 L p .707 .577 .707 r
F P
0 g
s
.49754 .62431 m .4952 .66156 L .49215 .65365 L p .707 .577 .707 r
F P
0 g
s
.49215 .65365 m .49448 .6164 L .49754 .62431 L p .707 .577 .707 r
F P
0 g
s
.30984 .52713 m .31016 .58267 L .30317 .59115 L p .707 .577 .707 r
F P
0 g
s
.29161 .64651 m .29395 .60926 L .30086 .60209 L p .707 .577 .707 r
F P
0 g
s
.5038 .52943 m .50412 .58497 L .49144 .5771 L p .707 .577 .707 r
F P
0 g
s
.49144 .5771 m .49112 .52156 L .5038 .52943 L p .707 .577 .707 r
F P
0 g
s
.30324 .74223 m .29527 .72649 L .29311 .71343 L p .707 .577 .707 r
F P
0 g
s
.30086 .60209 m .29852 .63933 L .29161 .64651 L p .707 .577 .707 r
F P
0 g
s
.4763 .63189 m .48427 .64763 L .47325 .63919 L p .707 .577 .707 r
F P
0 g
s
.47325 .63919 m .46528 .62346 L .4763 .63189 L p .707 .577 .707 r
F P
0 g
s
.29311 .71343 m .30108 .72917 L .30324 .74223 L p .707 .577 .707 r
F P
0 g
s
.31016 .58267 m .30984 .52713 L .32613 .5196 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49448 .6164 m .49215 .65365 L .47942 .64577 L p .707 .577 .707 r
F P
0 g
s
.47942 .64577 m .48176 .60853 L .49448 .6164 L p .707 .577 .707 r
F P
0 g
s
.32613 .5196 m .32645 .57514 L .31016 .58267 L p .707 .577 .707 r
F P
0 g
s
.49112 .52156 m .49144 .5771 L .47031 .57072 L p .707 .577 .707 r
F P
0 g
s
.47031 .57072 m .46999 .51518 L .49112 .52156 L p .707 .577 .707 r
F P
0 g
s
.29852 .63933 m .30086 .60209 L .31705 .59635 L p .707 .577 .707 r
F P
0 g
s
.30108 .72917 m .29311 .71343 L .30003 .69701 L p .707 .577 .707 r
F P
0 g
s
.31705 .59635 m .31472 .6336 L .29852 .63933 L p .707 .577 .707 r
F P
0 g
s
.32645 .57514 m .32613 .5196 L .35012 .51375 L p .707 .577 .707 r
F P
0 g
s
.46528 .62346 m .47325 .63919 L .45446 .63621 L p .707 .577 .707 r
F P
0 g
s
.45446 .63621 m .44649 .62047 L .46528 .62346 L p .707 .577 .707 r
F P
0 g
s
.30003 .69701 m .308 .71275 L .30108 .72917 L p .707 .577 .707 r
F P
0 g
s
.48176 .60853 m .47942 .64577 L .45828 .63871 L p .707 .577 .707 r
F P
0 g
s
.45828 .63871 m .46062 .60146 L .48176 .60853 L p .707 .577 .707 r
F P
0 g
s
.46999 .51518 m .47031 .57072 L .4428 .56646 L p .707 .577 .707 r
F P
0 g
s
.4428 .56646 m .44248 .51091 L .46999 .51518 L p .707 .577 .707 r
F P
0 g
s
.35012 .51375 m .35044 .5693 L .32645 .57514 L p .707 .577 .707 r
F P
0 g
s
.31472 .6336 m .31705 .59635 L .34095 .59262 L p .707 .577 .707 r
F P
0 g
s
.35044 .5693 m .35012 .51375 L .37946 .51017 L p .707 .577 .707 r
F P
0 g
s
.308 .71275 m .30003 .69701 L .31534 .67885 L p .707 .577 .707 r
F P
0 g
s
.44649 .62047 m .45446 .63621 L .42972 .63898 L p .707 .577 .707 r
F P
0 g
s
.42972 .63898 m .42175 .62324 L .44649 .62047 L p .707 .577 .707 r
F P
0 g
s
.34095 .59262 m .33862 .62986 L .31472 .6336 L p .707 .577 .707 r
F P
0 g
s
.44248 .51091 m .4428 .56646 L .41161 .56473 L p .707 .577 .707 r
F P
0 g
s
.41161 .56473 m .41129 .50919 L .44248 .51091 L p .707 .577 .707 r
F P
0 g
s
.31534 .67885 m .32331 .69459 L .308 .71275 L p .707 .577 .707 r
F P
0 g
s
.37978 .56571 m .37946 .51017 L .41129 .50919 L p .707 .577 .707 r
F P
0 g
s
.37946 .51017 m .37978 .56571 L .35044 .5693 L p .707 .577 .707 r
F P
0 g
s
.46062 .60146 m .45828 .63871 L .43079 .63314 L p .707 .577 .707 r
F P
0 g
s
.43079 .63314 m .43313 .5959 L .46062 .60146 L p .707 .577 .707 r
F P
0 g
s
.41129 .50919 m .41161 .56473 L .37978 .56571 L p .707 .577 .707 r
F P
0 g
s
.33862 .62986 m .34095 .59262 L .37021 .59125 L p .707 .577 .707 r
F P
0 g
s
.32331 .69459 m .31534 .67885 L .33755 .66072 L p .707 .577 .707 r
F P
0 g
s
.42175 .62324 m .42972 .63898 L .40146 .64723 L p .707 .577 .707 r
F P
0 g
s
.40146 .64723 m .39349 .63149 L .42175 .62324 L p .707 .577 .707 r
F P
0 g
s
.37021 .59125 m .36788 .62849 L .33862 .62986 L p .707 .577 .707 r
F P
0 g
s
.43313 .5959 m .43079 .63314 L .39964 .62962 L p .707 .577 .707 r
F P
0 g
s
.39964 .62962 m .40198 .59238 L .43313 .5959 L p .707 .577 .707 r
F P
0 g
s
.33755 .66072 m .34552 .67646 L .32331 .69459 L p .707 .577 .707 r
F P
0 g
s
.36788 .62849 m .37021 .59125 L .40198 .59238 L p .707 .577 .707 r
F P
0 g
s
.40198 .59238 m .39964 .62962 L .36788 .62849 L p .707 .577 .707 r
F P
0 g
s
.34552 .67646 m .33755 .66072 L .36447 .6444 L p .707 .577 .707 r
F P
0 g
s
.39349 .63149 m .40146 .64723 L .37244 .66014 L p .707 .577 .707 r
F P
0 g
s
.37244 .66014 m .36447 .6444 L .39349 .63149 L p .707 .577 .707 r
F P
0 g
s
.36447 .6444 m .37244 .66014 L .34552 .67646 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF2`002eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol00`00FUIJEP080004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0061oo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`@000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00FWoo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Aoo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00
EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo00mooaP003eoo`00EWoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo00Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Uo
o`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Eoo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0035oo`00EWoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001oogooOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000`Ool005Ioo`03001JEP0000=JEP03001JEUYF00=JEPL000EJEPD000IJEPP000AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000Ool000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002ioo`00EWoo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH00eYF1@001eYF00<005YFFUH015YF1P0015YF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`03001JEP0000=JEP80009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`04001JEP00FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020000
1EYF000005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00@005YF
FUIJEQT000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001FOol200000eYF000000030002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;7oo000nOolA0008Ool200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P000UYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool0035oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;7oo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH2000/Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8002aoo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00AJEQ40009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH70003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF0`00;7oo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<0009JEP03001JEUYF009JEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1P0000=J
EP00FUH0100000EJEP00FUIJEP0000AJEP800003FUH005YF00AJEPP000AJEP03001JEUYF00=JEP06
001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000AJEP00000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00<000AJEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH00eYF1P0000=JEP0000000eYF00<005YFFUH01UYF2`0015YF00H005YFFUH005YF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH2000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP04
001JEUYFFUH20006FUH00`00FUIJEP03FUH@00001eYF001JEUYF001JEP0000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH0000002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00@005YF000000QJEP03
001JEUYF00@000QJEP03001JEUYF00=JEP<0009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<000UJEP<000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH00000008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH00UYF5P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000008000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH70008FUH50004FUH01000FUIJEUYF0P0000=J
EP00FUH015YF00@005YF000000QJEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEPH000Iooa4000IJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002]oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00=JEP<000AJEP800003FUH005YF00EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEP0000@000=JEP03001oogoo01Ioo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002]oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP@00005FUH005YFFUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH30006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP<000AJEP05001JEUYFFUH0
000;Ool3000>Ool40004FUH01000FUIJEUYF0P00;Goo000[Ool01000FUH005YF0P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP05
001JEUYFFUH00008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001J
EP040005FUH01000FUIJEUYF0P002Goo1@004Goo0`0000=JEP00FUH00UYF0P00;Goo000[Ool01P00
FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYF0005FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH0
05YF00800003FUH005YF00<000=JEP04001JEUYFFUH20009Ool5000DOol20003FUH2000]Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000MJEP@0009JEP03001JEP0000P000AJEP03001JEUYF009JEPL000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP@000=JEP8000Uoo`D0019oo`80009JEP04001JEUYF000^Ool002]oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000IJEP800004FUH005YF0002FUH00`00FUIJEP04FUH300000eYF000000070005FUH00`00FUIJ
EP03FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP03FUH00`00FUH00005000:Ool3000?Ool400000eYF001JEP02FUH3000^
Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP07001JEUYFFUH005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1`004Woo1@001EYF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF6P000UYF00@005YFFUIJ
EP8000=JEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHQ00000eYF001oo`0]Ool002aoo`05001J
EUYFFUH00005FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YF00000`000eYF0`000UYF00<005YFFUH00eYF1@001UYF00@005YFFUIJEP8000=JEP04
001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<0
05YFFUH015YF00@005YFFUIJEP@002ioo`00;Goo0P0000=JEP00FUH00eYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P000UYF1@0000Eoo`00FUIJEP0000IJ
EP<000MJEP04001JEUYF0006FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;goo
0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YF00001EYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF00001UYF00@005YFFUH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03000_Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000=JEP04001JEUYF0005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF0`00
1EYF00D005YFFUIJEP0000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP@000EJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002moo`00;goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUH000EJEP04001J
EUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0015YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P0015YF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJ
EPD0009JEP03001JEP0002ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0`0000=J
EP00FUH0100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF
0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000EJEP03001JEUYF
00MJEP03001JEUYF009JEPT000=JEP<000AJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJ
EP0000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH2
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH400001UYF00000000FUH000MJEP03001JEUYF00AJEPL000AJEP04001JEUYFFUH400000eYF
001JEP05FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH010000UYF1@0015YF10001EYF00<005YFFUH015YF00@005YF
0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
009JEP<000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP03FUH40002Ool=0002FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000bOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEQD00004FUH000000004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF00000P00
1eYF00H005YF000005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF000010002Goo1@001UYF00<0
05YFFUH01EYF00<005YF00000P00=Goo000]Ool00`00FUH00003FUH00`00FUIJEP03FUHJ00000eYF
00000002FUH70003FUH01000FUIJEP000UYF0P0000=JEP00FUH025YF00D005YFFUIJEP0000]JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF009JEP<0009JEP03001JEP0000Eoo`@0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP<003Qoo`00;Goo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<0
05YF00001P000eYF1P000UYF0`0015YF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YF00000P001EYF00<005YF00001@001UYF00<005YFFUH01eYF00<005YF00000`00>goo000]Ool0
0`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH01`00FUIJEUYF001J
EP00009JEP/000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH03P000eYF00<005YF
FUH01eYF00<005YFFUH015YF1000?goo000]Ool00`00FUH000030004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01eYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01000@goo000]Ool300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Agoo
000]Ool50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0003FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH01eYF00@005YFFUIJEPH000MJ
EP03001JEUYF00UJEP03001JEP0000P000QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01000C7oo000]Ool300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01EYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF1P000UYF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH6001@Ool0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00H00004FUH000000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUHA00000eYF001oo`1COol002ioo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF0080009JEP03001JEUYF00=J
EPD000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF009JEP03001oogoo00Moo`<00003FUH005YF009JEP03001oogoo059oo`00;Goo0P00
0Woo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000`000Woo0P000UYF00@005YFFUH000=JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF00=JEP03001oogoo
00Qoo`@000=JEP8005=oo`00;Goo0P001Goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1@001goo00@005YFFUH0009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<0
07ooOol017oo100000AJEP00FUIJEP800003FUH0000005=oo`00;Goo00<005YF00002goo6`0037oo
00@005YFFUH0009JEP<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001oo`0000@000EJEP04001JEUYF
FUH4001COol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001COol002eoo`03001JEP00
01Moo`D001Moo`04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000Dgoo000]Ool01000FUH000005Woo1@0067oo
0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005=oo`00;Woo00<005YF00005Woo1@0067oo0`000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00;Woo
00@005YFFUH001Ioo`<001Yoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1COol002ioo`05001JEUYFFUH0000bOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP02001FOol002moo`04001JEUYF000bOol20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP04FUH3001HOol002moo`05001JEUYFFUH0000aOol00`00FUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH2001JOol0031oo`03001JEUYF0080035o
o`D000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP0000<005aoo`00<Goo0P000UYF00<007ooOol0
;Woo00@007ooOomoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006FUH3001POol0035oo`8000=JEP8002eoo`80
00Eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000003FUH200000eYF00000002001SOol0039oo`03001JEUYF00=JEP03
001oogoo02Yoo`8000Uoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP@00003FUH005YF00AJEP8006Ioo`00<goo00<005YFFUH00eYF00<007ooOol0:7oo
0P003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02P00
25YF0`00Hgoo000dOol00`00FUIJEP02FUH3000WOol3000EOol90006FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH80004FUH60009FUH01000FUH00000HGoo000eOol200000eYF001JEP02FUH2000TOol0
0`00FUH0000OOolI0008Ool20002FUH500000eYF00000006FUH00`00FUIJEP02FUH2001OOol003Mo
o`8000EJEP80021oo`80009JEP03001oogoo041oo`800004FUH000000004FUH20004FUH00`00FUIJ
EP04FUH2001MOol003Qoo`03001JEUYF00EJEP<001]oo`800004FUH005YF0015Ool20008FUH20000
0eYF001JEP07FUH3001KOol003Uoo`8000IJEP04001JEP00000GOol20002FUH00`00FUH00018Ool2
0006FUH00`00FUH000020006FUH01000FUIJEUYF0P00FGoo000kOol20003FUH00`00FUIJEP02FUH3
000?Ool50004FUH2001;Ool20004FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH2001GOol0
03eoo`800003FUH005YF00IJEPl000=JEP03001JEUYF009JEP8004ioo`800003FUH005YF00IJEP80
0003FUH005YF00EJEP03001JEP0005Ioo`00?goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80059oo`<000MJEP<000IJEP04001JEUYF001EOol0049oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00001GOol20005FUH00`00FUIJEP020003FUH00`00FUIJEP02
FUH00`00Oomoo`1BOol004Aoo`<00003FUH005YF00MJEP03001JEUYF009JEPD005]oo`<00003FUH0
05YF00AJEP800003FUH005YF00=JEP03001oogoo059oo`00Agoo3`00Hgoo0`001EYF0P0015YF0P00
E7oo002lOol300001EYF001JEUYF00000eYF00<007ooOol0Dgoo002oOol20003FUH4001EOol00<5o
o`800004FUH005YF001FOol00<=oo`@005Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58839 .75016 m .58871 .69454 L .55751 .69252 L p .707 .577 .707 r
F P
0 g
s
.58871 .69454 m .58839 .75016 L .62022 .74953 L p .707 .577 .707 r
F P
0 g
s
.62022 .74953 m .62053 .69391 L .58871 .69454 L p .707 .577 .707 r
F P
0 g
s
.62053 .69391 m .62022 .74953 L .64956 .74631 L p .707 .577 .707 r
F P
0 g
s
.64956 .74631 m .64988 .6907 L .62053 .69391 L p .707 .577 .707 r
F P
0 g
s
.5572 .74813 m .55751 .69252 L .53001 .68804 L p .707 .577 .707 r
F P
0 g
s
.55751 .69252 m .5572 .74813 L .58839 .75016 L p .707 .577 .707 r
F P
0 g
s
.64988 .6907 m .64956 .74631 L .67355 .74082 L p .707 .577 .707 r
F P
0 g
s
.67355 .74082 m .67387 .6852 L .64988 .6907 L p .707 .577 .707 r
F P
0 g
s
.53001 .68804 m .52969 .74365 L .5572 .74813 L p .707 .577 .707 r
F P
0 g
s
.52969 .74365 m .53001 .68804 L .50888 .68154 L p .707 .577 .707 r
F P
0 g
s
.60036 .81233 m .59802 .77563 L .56687 .77541 L p .707 .577 .707 r
F P
0 g
s
.59802 .77563 m .60036 .81233 L .63212 .80959 L p .707 .577 .707 r
F P
0 g
s
.63212 .80959 m .62978 .77288 L .59802 .77563 L p .707 .577 .707 r
F P
0 g
s
.62978 .77288 m .63212 .80959 L .66138 .80414 L p .707 .577 .707 r
F P
0 g
s
.66138 .80414 m .65904 .76744 L .62978 .77288 L p .707 .577 .707 r
F P
0 g
s
.56921 .81211 m .56687 .77541 L .53938 .77225 L p .707 .577 .707 r
F P
0 g
s
.56687 .77541 m .56921 .81211 L .60036 .81233 L p .707 .577 .707 r
F P
0 g
s
.67387 .6852 m .67355 .74082 L .68983 .73359 L p .707 .577 .707 r
F P
0 g
s
.68983 .73359 m .69015 .67797 L .67387 .6852 L p .707 .577 .707 r
F P
0 g
s
.50888 .68154 m .50856 .73716 L .52969 .74365 L p .707 .577 .707 r
F P
0 g
s
.65904 .76744 m .66138 .80414 L .68528 .79654 L p .707 .577 .707 r
F P
0 g
s
.68528 .79654 m .68294 .75983 L .65904 .76744 L p .707 .577 .707 r
F P
0 g
s
.59854 .82865 m .60651 .81122 L .57825 .79772 L p .707 .577 .707 r
F P
0 g
s
.60651 .81122 m .59854 .82865 L .62755 .84159 L p .707 .577 .707 r
F P
0 g
s
.62755 .84159 m .63552 .82416 L .60651 .81122 L p .707 .577 .707 r
F P
0 g
s
.57825 .79772 m .57028 .81515 L .59854 .82865 L p .707 .577 .707 r
F P
0 g
s
.53938 .77225 m .54171 .80895 L .56921 .81211 L p .707 .577 .707 r
F P
0 g
s
.50856 .73716 m .50888 .68154 L .4962 .67367 L p .707 .577 .707 r
F P
0 g
s
.63552 .82416 m .62755 .84159 L .65448 .85271 L p .707 .577 .707 r
F P
0 g
s
.65448 .85271 m .66245 .83528 L .63552 .82416 L p .707 .577 .707 r
F P
0 g
s
.57028 .81515 m .57825 .79772 L .55351 .78498 L p .707 .577 .707 r
F P
0 g
s
.54171 .80895 m .53938 .77225 L .51824 .76645 L p .707 .577 .707 r
F P
0 g
s
.55351 .78498 m .54554 .80241 L .57028 .81515 L p .707 .577 .707 r
F P
0 g
s
.66245 .83528 m .65448 .85271 L .67669 .86091 L p .707 .577 .707 r
F P
0 g
s
.67669 .86091 m .68466 .84348 L .66245 .83528 L p .707 .577 .707 r
F P
0 g
s
.68294 .75983 m .68528 .79654 L .70148 .78751 L p .707 .577 .707 r
F P
0 g
s
.70148 .78751 m .69914 .75081 L .68294 .75983 L p .707 .577 .707 r
F P
0 g
s
.4962 .67367 m .49588 .72929 L .50856 .73716 L p .707 .577 .707 r
F P
0 g
s
.51824 .76645 m .52057 .80315 L .54171 .80895 L p .707 .577 .707 r
F P
0 g
s
.69015 .67797 m .68983 .73359 L .69682 .72533 L p .707 .577 .707 r
F P
0 g
s
.69682 .72533 m .69714 .66971 L .69015 .67797 L p .707 .577 .707 r
F P
0 g
s
.54554 .80241 m .55351 .78498 L .53472 .77425 L p .707 .577 .707 r
F P
0 g
s
.53472 .77425 m .52675 .79168 L .54554 .80241 L p .707 .577 .707 r
F P
0 g
s
.52057 .80315 m .51824 .76645 L .50551 .75858 L p .707 .577 .707 r
F P
0 g
s
.49588 .72929 m .4962 .67367 L .49321 .66519 L p .707 .577 .707 r
F P
0 g
s
.68466 .84348 m .67669 .86091 L .692 .8654 L p .707 .577 .707 r
F P
0 g
s
.692 .8654 m .69997 .84797 L .68466 .84348 L p .707 .577 .707 r
F P
0 g
s
.50551 .75858 m .50785 .79529 L .52057 .80315 L p .707 .577 .707 r
F P
0 g
s
.69914 .75081 m .70148 .78751 L .70838 .77795 L p .707 .577 .707 r
F P
0 g
s
.70838 .77795 m .70605 .74125 L .69914 .75081 L p .707 .577 .707 r
F P
0 g
s
.52675 .79168 m .53472 .77425 L .5237 .76659 L p .707 .577 .707 r
F P
0 g
s
.49321 .66519 m .49289 .7208 L .49588 .72929 L p .707 .577 .707 r
F P
0 g
s
.5237 .76659 m .51573 .78402 L .52675 .79168 L p .707 .577 .707 r
F P
0 g
s
.69714 .66971 m .69682 .72533 L .69383 .71684 L p .707 .577 .707 r
F P
0 g
s
.69383 .71684 m .69415 .66123 L .69714 .66971 L p .707 .577 .707 r
F P
0 g
s
.50785 .79529 m .50551 .75858 L .50246 .74942 L p .707 .577 .707 r
F P
0 g
s
.49289 .7208 m .49321 .66519 L .5002 .65692 L p .707 .577 .707 r
F P
0 g
s
.48571 .82173 m .48571 .31984 L .44205 .31677 L p .707 .577 .707 r
F P
0 g
s
.50246 .74942 m .50479 .78613 L .50785 .79529 L p .707 .577 .707 r
F P
0 g
s
.51573 .78402 m .5237 .76659 L .52155 .76273 L p .707 .577 .707 r
F P
0 g
s
.52155 .76273 m .51358 .78016 L .51573 .78402 L p .707 .577 .707 r
F P
0 g
s
.5002 .65692 m .49988 .71254 L .49289 .7208 L p .707 .577 .707 r
F P
0 g
s
.50479 .78613 m .50246 .74942 L .50937 .73986 L p .707 .577 .707 r
F P
0 g
s
.49988 .71254 m .5002 .65692 L .51648 .64969 L p .707 .577 .707 r
F P
0 g
s
.50937 .73986 m .5117 .77656 L .50479 .78613 L p .707 .577 .707 r
F P
0 g
s
.51358 .78016 m .52155 .76273 L .52846 .76306 L p .707 .577 .707 r
F P
0 g
s
.51648 .64969 m .51617 .70531 L .49988 .71254 L p .707 .577 .707 r
F P
0 g
s
.52846 .76306 m .52049 .78049 L .51358 .78016 L p .707 .577 .707 r
F P
0 g
s
.51617 .70531 m .51648 .64969 L .54047 .6442 L p .707 .577 .707 r
F P
0 g
s
.5117 .77656 m .50937 .73986 L .52556 .73083 L p .707 .577 .707 r
F P
0 g
s
.52049 .78049 m .52846 .76306 L .54378 .76755 L p .707 .577 .707 r
F P
0 g
s
.52556 .73083 m .5279 .76754 L .5117 .77656 L p .707 .577 .707 r
F P
0 g
s
.54047 .6442 m .54015 .69982 L .51617 .70531 L p .707 .577 .707 r
F P
0 g
s
.54378 .76755 m .53581 .78498 L .52049 .78049 L p .707 .577 .707 r
F P
0 g
s
.48571 .31984 m .48571 .82173 L .53076 .82103 L p .707 .577 .707 r
F P
0 g
s
.5279 .76754 m .52556 .73083 L .54946 .72323 L p .707 .577 .707 r
F P
0 g
s
.54946 .72323 m .5518 .75993 L .5279 .76754 L p .707 .577 .707 r
F P
0 g
s
.53076 .82103 m .53076 .31914 L .48571 .31984 L p .707 .577 .707 r
F P
0 g
s
.54015 .69982 m .54047 .6442 L .56982 .64098 L p .707 .577 .707 r
F P
0 g
s
.56982 .64098 m .5695 .6966 L .54015 .69982 L p .707 .577 .707 r
F P
0 g
s
.5518 .75993 m .54946 .72323 L .57872 .71778 L p .707 .577 .707 r
F P
0 g
s
.53581 .78498 m .54378 .76755 L .56598 .77575 L p .707 .577 .707 r
F P
0 g
s
.56598 .77575 m .55801 .79318 L .53581 .78498 L p .707 .577 .707 r
F P
0 g
s
.57872 .71778 m .58106 .75449 L .5518 .75993 L p .707 .577 .707 r
F P
0 g
s
.55801 .79318 m .56598 .77575 L .59291 .78687 L p .707 .577 .707 r
F P
0 g
s
.59291 .78687 m .58494 .8043 L .55801 .79318 L p .707 .577 .707 r
F P
0 g
s
.53076 .31914 m .53076 .82103 L .5728 .81663 L p .707 .577 .707 r
F P
0 g
s
.5695 .6966 m .56982 .64098 L .60164 .64035 L p .707 .577 .707 r
F P
0 g
s
.60164 .64035 m .60132 .69597 L .5695 .6966 L p .707 .577 .707 r
F P
0 g
s
.5728 .81663 m .5728 .31474 L .53076 .31914 L p .707 .577 .707 r
F P
0 g
s
.69997 .84797 m .692 .8654 L .69891 .86573 L p .707 .577 .707 r
F P
0 g
s
.69891 .86573 m .70688 .8483 L .69997 .84797 L p .707 .577 .707 r
F P
0 g
s
.44205 .81866 m .44205 .31677 L .40407 .31023 L p .707 .577 .707 r
F P
0 g
s
.44205 .31677 m .44205 .81866 L .48571 .82173 L p .707 .577 .707 r
F P
0 g
s
.70605 .74125 m .70838 .77795 L .70533 .76879 L p .707 .577 .707 r
F P
0 g
s
.70533 .76879 m .70299 .73208 L .70605 .74125 L p .707 .577 .707 r
F P
0 g
s
.69415 .66123 m .69383 .71684 L .68115 .70897 L p .707 .577 .707 r
F P
0 g
s
.68115 .70897 m .68147 .65335 L .69415 .66123 L p .707 .577 .707 r
F P
0 g
s
.58106 .75449 m .57872 .71778 L .61049 .71504 L p .707 .577 .707 r
F P
0 g
s
.61049 .71504 m .61282 .75174 L .58106 .75449 L p .707 .577 .707 r
F P
0 g
s
.58494 .8043 m .59291 .78687 L .62192 .79981 L p .707 .577 .707 r
F P
0 g
s
.62192 .79981 m .61395 .81724 L .58494 .8043 L p .707 .577 .707 r
F P
0 g
s
.5728 .31474 m .5728 .81663 L .60772 .80896 L p .707 .577 .707 r
F P
0 g
s
.63283 .64238 m .63252 .698 L .60132 .69597 L p .707 .577 .707 r
F P
0 g
s
.60132 .69597 m .60164 .64035 L .63283 .64238 L p .707 .577 .707 r
F P
0 g
s
.60772 .80896 m .60772 .30707 L .5728 .31474 L p .707 .577 .707 r
F P
0 g
s
.40407 .81212 m .40407 .31023 L .37547 .30087 L p .707 .577 .707 r
F P
0 g
s
.40407 .31023 m .40407 .81212 L .44205 .81866 L p .707 .577 .707 r
F P
0 g
s
.70688 .8483 m .69891 .86573 L .69676 .86188 L p .707 .577 .707 r
F P
0 g
s
.69676 .86188 m .70473 .84444 L .70688 .8483 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24998 .71105 m .25011 .65555 L .21892 .65357 L p .707 .577 .707 r
F P
0 g
s
.25011 .65555 m .24998 .71105 L .2818 .7103 L p .707 .577 .707 r
F P
0 g
s
.2818 .7103 m .28194 .65481 L .25011 .65555 L p .707 .577 .707 r
F P
0 g
s
.28194 .65481 m .2818 .7103 L .31115 .7069 L p .707 .577 .707 r
F P
0 g
s
.31115 .7069 m .31128 .65141 L .28194 .65481 L p .707 .577 .707 r
F P
0 g
s
.70299 .73208 m .70533 .76879 L .69261 .76092 L p .707 .577 .707 r
F P
0 g
s
.69261 .76092 m .69027 .72422 L .70299 .73208 L p .707 .577 .707 r
F P
0 g
s
.21878 .70907 m .21892 .65357 L .19141 .64905 L p .707 .577 .707 r
F P
0 g
s
.21892 .65357 m .21878 .70907 L .24998 .71105 L p .707 .577 .707 r
F P
0 g
s
.64164 .71526 m .64397 .75196 L .61282 .75174 L p .707 .577 .707 r
F P
0 g
s
.61282 .75174 m .61049 .71504 L .64164 .71526 L p .707 .577 .707 r
F P
0 g
s
.61395 .81724 m .62192 .79981 L .65018 .81331 L p .707 .577 .707 r
F P
0 g
s
.60772 .30707 m .60772 .80896 L .63209 .79877 L p .707 .577 .707 r
F P
0 g
s
.63209 .79877 m .63209 .29688 L .60772 .30707 L p .707 .577 .707 r
F P
0 g
s
.68147 .65335 m .68115 .70897 L .66002 .70248 L p .707 .577 .707 r
F P
0 g
s
.66002 .70248 m .66034 .64686 L .68147 .65335 L p .707 .577 .707 r
F P
0 g
s
.25529 .76817 m .25429 .73058 L .22309 .72993 L p .707 .577 .707 r
F P
0 g
s
.25429 .73058 m .25529 .76817 L .2871 .76672 L p .707 .577 .707 r
F P
0 g
s
.2871 .76672 m .2861 .72912 L .25429 .73058 L p .707 .577 .707 r
F P
0 g
s
.2861 .72912 m .2871 .76672 L .3164 .76329 L p .707 .577 .707 r
F P
0 g
s
.3164 .76329 m .3154 .72569 L .2861 .72912 L p .707 .577 .707 r
F P
0 g
s
.31128 .65141 m .31115 .7069 L .33514 .70118 L p .707 .577 .707 r
F P
0 g
s
.33514 .70118 m .33527 .64568 L .31128 .65141 L p .707 .577 .707 r
F P
0 g
s
.22409 .76752 m .22309 .72993 L .19554 .72723 L p .707 .577 .707 r
F P
0 g
s
.22309 .72993 m .22409 .76752 L .25529 .76817 L p .707 .577 .707 r
F P
0 g
s
.19128 .70455 m .19141 .64905 L .17029 .64244 L p .707 .577 .707 r
F P
0 g
s
.19141 .64905 m .19128 .70455 L .21878 .70907 L p .707 .577 .707 r
F P
0 g
s
.19554 .72723 m .19655 .76483 L .22409 .76752 L p .707 .577 .707 r
F P
0 g
s
.3154 .72569 m .3164 .76329 L .34032 .75824 L p .707 .577 .707 r
F P
0 g
s
.34032 .75824 m .33932 .72064 L .3154 .72569 L p .707 .577 .707 r
F P
0 g
s
.70473 .84444 m .69676 .86188 L .68575 .85421 L p .707 .577 .707 r
F P
0 g
s
.68575 .85421 m .69372 .83678 L .70473 .84444 L p .707 .577 .707 r
F P
0 g
s
.37547 .80275 m .37547 .30087 L .35907 .28958 L p .707 .577 .707 r
F P
0 g
s
.37547 .30087 m .37547 .80275 L .40407 .81212 L p .707 .577 .707 r
F P
0 g
s
.66034 .64686 m .66002 .70248 L .63252 .698 L p .707 .577 .707 r
F P
0 g
s
.63252 .698 m .63283 .64238 L .66034 .64686 L p .707 .577 .707 r
F P
0 g
s
.69027 .72422 m .69261 .76092 L .67146 .75512 L p .707 .577 .707 r
F P
0 g
s
.67146 .75512 m .66913 .71842 L .69027 .72422 L p .707 .577 .707 r
F P
0 g
s
.19655 .76483 m .19554 .72723 L .17436 .72276 L p .707 .577 .707 r
F P
0 g
s
.33527 .64568 m .33514 .70118 L .35142 .69369 L p .707 .577 .707 r
F P
0 g
s
.35142 .69369 m .35156 .63819 L .33527 .64568 L p .707 .577 .707 r
F P
0 g
s
.17029 .64244 m .17015 .69794 L .19128 .70455 L p .707 .577 .707 r
F P
0 g
s
.25599 .85217 m .25958 .83767 L .22886 .82893 L p .707 .577 .707 r
F P
0 g
s
.25958 .83767 m .25599 .85217 L .28722 .85458 L p .707 .577 .707 r
F P
0 g
s
.28722 .85458 m .29081 .84008 L .25958 .83767 L p .707 .577 .707 r
F P
0 g
s
.22527 .84342 m .22886 .82893 L .20167 .81471 L p .707 .577 .707 r
F P
0 g
s
.22886 .82893 m .22527 .84342 L .25599 .85217 L p .707 .577 .707 r
F P
0 g
s
.17436 .72276 m .17536 .76035 L .19655 .76483 L p .707 .577 .707 r
F P
0 g
s
.64397 .75196 m .64164 .71526 L .66913 .71842 L p .707 .577 .707 r
F P
0 g
s
.63209 .29688 m .63209 .79877 L .64353 .78705 L p .707 .577 .707 r
F P
0 g
s
.64353 .78705 m .64353 .28516 L .63209 .29688 L p .707 .577 .707 r
F P
0 g
s
.17015 .69794 m .17029 .64244 L .1576 .63438 L p .707 .577 .707 r
F P
0 g
s
.29081 .84008 m .28722 .85458 L .31591 .85042 L p .707 .577 .707 r
F P
0 g
s
.31591 .85042 m .3195 .83593 L .29081 .84008 L p .707 .577 .707 r
F P
0 g
s
.33932 .72064 m .34032 .75824 L .35653 .75205 L p .707 .577 .707 r
F P
0 g
s
.35653 .75205 m .35552 .71445 L .33932 .72064 L p .707 .577 .707 r
F P
0 g
s
.19807 .8292 m .20167 .81471 L .18065 .7964 L p .707 .577 .707 r
F P
0 g
s
.20167 .81471 m .19807 .8292 L .22527 .84342 L p .707 .577 .707 r
F P
0 g
s
.66913 .71842 m .67146 .75512 L .64397 .75196 L p .707 .577 .707 r
F P
0 g
s
.17536 .76035 m .17436 .72276 L .1616 .71694 L p .707 .577 .707 r
F P
0 g
s
.69372 .83678 m .68575 .85421 L .66695 .84348 L p .707 .577 .707 r
F P
0 g
s
.66695 .84348 m .67492 .82605 L .69372 .83678 L p .707 .577 .707 r
F P
0 g
s
.3195 .83593 m .31591 .85042 L .33925 .8401 L p .707 .577 .707 r
F P
0 g
s
.33925 .8401 m .34284 .82561 L .3195 .83593 L p .707 .577 .707 r
F P
0 g
s
.1576 .63438 m .15747 .68988 L .17015 .69794 L p .707 .577 .707 r
F P
0 g
s
.35156 .63819 m .35142 .69369 L .35841 .68517 L p .707 .577 .707 r
F P
0 g
s
.35841 .68517 m .35855 .62967 L .35156 .63819 L p .707 .577 .707 r
F P
0 g
s
.18065 .7964 m .17706 .8109 L .19807 .8292 L p .707 .577 .707 r
F P
0 g
s
.17706 .8109 m .18065 .7964 L .16788 .77581 L p .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16788 .77581 L .16766 .77442 L p .707 .577 .707 r
F P
0 g
s
.1616 .71694 m .1626 .75453 L .17175 .75871 L p .707 .577 .707 r
F P
0 g
s
.16766 .77442 m .16459 .75493 L p .16431 .78729 L .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16766 .77442 L .16431 .78729 L .707 .577 .707 r
F
.17175 .75871 m .17536 .76035 L p .17314 .75336 L F P
0 g
s
.17314 .75336 m .1616 .71694 L .17175 .75871 L .707 .577 .707 r
F
.35552 .71445 m .35653 .75205 L .36343 .74533 L p F P
0 g
s
.36343 .74533 m .36242 .70773 L .35552 .71445 L p .707 .577 .707 r
F P
0 g
s
.35855 .62967 m .35841 .68517 L .35542 .67645 L p .707 .577 .707 r
F P
0 g
s
.35542 .67645 m .35556 .62096 L .35855 .62967 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .36507 .79103 L .35854 .81013 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .35819 .78465 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36507 .79103 m .36353 .79722 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36353 .79722 m .36147 .80552 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35646 .27749 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36178 .77015 L .36235 .77375 L p .707 .577 .707 r
F P
0 g
s
.36235 .77375 m .36507 .79103 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36235 .77375 L .36313 .78923 L .707 .577 .707 r
F
.35934 .70114 m .36035 .73874 L .34759 .73292 L p F P
0 g
s
.34759 .73292 m .34658 .69532 L .35934 .70114 L p .707 .577 .707 r
F P
0 g
s
.36178 .77015 m .35819 .78465 L .34542 .76405 L p .707 .577 .707 r
F P
0 g
s
.34542 .76405 m .34901 .74955 L .36178 .77015 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35907 .79147 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .27749 m .35646 .65696 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .65696 m .35646 .77938 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .79147 m .35907 .70871 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .70871 m .35907 .28958 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.36242 .70773 m .36343 .74533 L .36035 .73874 L p .707 .577 .707 r
F P
0 g
s
.36035 .73874 m .35934 .70114 L .36242 .70773 L p .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35907 .79147 L .37547 .80275 L p .707 .577 .707 r
F P
0 g
s
.15747 .68988 m .1576 .63438 L .15461 .62567 L p .707 .577 .707 r
F P
0 g
s
.16788 .77581 m .16428 .7903 L .17706 .8109 L p .707 .577 .707 r
F P
0 g
s
.34284 .82561 m .33925 .8401 L .35495 .82463 L p .707 .577 .707 r
F P
0 g
s
.35495 .82463 m .35854 .81013 L .34284 .82561 L p .707 .577 .707 r
F P
0 g
s
.67492 .82605 m .66695 .84348 L .64221 .83074 L p .707 .577 .707 r
F P
0 g
s
.64221 .83074 m .65018 .81331 L .67492 .82605 L p .707 .577 .707 r
F P
0 g
s
.64353 .28516 m .64353 .78705 L .64093 .77496 L p .707 .577 .707 r
F P
0 g
s
.64093 .77496 m .64093 .27308 L .64353 .28516 L p .707 .577 .707 r
F P
0 g
s
.1626 .75453 m .1616 .71694 L .15852 .71034 L p .707 .577 .707 r
F P
0 g
s
.15461 .62567 m .15448 .68116 L .15747 .68988 L p .707 .577 .707 r
F P
0 g
s
.15852 .71034 m .15952 .74794 L .1626 .75453 L p .707 .577 .707 r
F P
0 g
s
.65018 .81331 m .64221 .83074 L .61395 .81724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16459 .75493 m .161 .76942 L .16428 .7903 L p .707 .577 .707 r
F P
0 g
s
.35854 .81013 m .35495 .82463 L .36147 .80552 L p .707 .577 .707 r
F P
0 g
s
.15448 .68116 m .15461 .62567 L .1616 .61715 L p .707 .577 .707 r
F P
0 g
s
.161 .76942 m .16459 .75493 L .17112 .73582 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35646 .27749 L .36791 .26578 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15952 .74794 m .15852 .71034 L .16542 .70362 L p .707 .577 .707 r
F P
0 g
s
.1616 .61715 m .16146 .67265 L .15448 .68116 L p .707 .577 .707 r
F P
0 g
s
.35556 .62096 m .35542 .67645 L .34274 .66839 L p .707 .577 .707 r
F P
0 g
s
.34274 .66839 m .34288 .6129 L .35556 .62096 L p .707 .577 .707 r
F P
0 g
s
.17112 .73582 m .16753 .75032 L .161 .76942 L p .707 .577 .707 r
F P
0 g
s
.16542 .70362 m .16642 .74122 L .15952 .74794 L p .707 .577 .707 r
F P
0 g
s
.64093 .27308 m .64093 .77496 L .62452 .76368 L p .707 .577 .707 r
F P
0 g
s
.62452 .76368 m .62452 .26179 L .64093 .27308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16146 .67265 m .1616 .61715 L .17789 .60966 L p .707 .577 .707 r
F P
0 g
s
.16753 .75032 m .17112 .73582 L .18682 .72035 L p .707 .577 .707 r
F P
0 g
s
.18682 .72035 m .18323 .73484 L .16753 .75032 L p .707 .577 .707 r
F P
0 g
s
.16642 .74122 m .16542 .70362 L .18162 .69743 L p .707 .577 .707 r
F P
0 g
s
.17789 .60966 m .17775 .66516 L .16146 .67265 L p .707 .577 .707 r
F P
0 g
s
.34288 .6129 m .34274 .66839 L .32161 .66178 L p .707 .577 .707 r
F P
0 g
s
.32161 .66178 m .32175 .60629 L .34288 .6129 L p .707 .577 .707 r
F P
0 g
s
.36791 .76767 m .36791 .26578 L .39228 .25559 L p .707 .577 .707 r
F P
0 g
s
.36791 .26578 m .36791 .76767 L .35646 .77938 L p .707 .577 .707 r
F P
0 g
s
.18162 .69743 m .18263 .73503 L .16642 .74122 L p .707 .577 .707 r
F P
0 g
s
.18323 .73484 m .18682 .72035 L .21016 .71003 L p .707 .577 .707 r
F P
0 g
s
.17775 .66516 m .17789 .60966 L .20188 .60393 L p .707 .577 .707 r
F P
0 g
s
.34658 .69532 m .34759 .73292 L .3264 .72844 L p .707 .577 .707 r
F P
0 g
s
.3264 .72844 m .3254 .69084 L .34658 .69532 L p .707 .577 .707 r
F P
0 g
s
.62452 .26179 m .62452 .76368 L .59593 .75431 L p .707 .577 .707 r
F P
0 g
s
.59593 .75431 m .59593 .25242 L .62452 .26179 L p .707 .577 .707 r
F P
0 g
s
.21016 .71003 m .20656 .72452 L .18323 .73484 L p .707 .577 .707 r
F P
0 g
s
.34901 .74955 m .34542 .76405 L .3244 .74574 L p .707 .577 .707 r
F P
0 g
s
.3244 .74574 m .32799 .73125 L .34901 .74955 L p .707 .577 .707 r
F P
0 g
s
.32175 .60629 m .32161 .66178 L .2941 .65726 L p .707 .577 .707 r
F P
0 g
s
.2941 .65726 m .29424 .60177 L .32175 .60629 L p .707 .577 .707 r
F P
0 g
s
.18263 .73503 m .18162 .69743 L .20554 .69238 L p .707 .577 .707 r
F P
0 g
s
.20188 .60393 m .20174 .65943 L .17775 .66516 L p .707 .577 .707 r
F P
0 g
s
.20656 .72452 m .21016 .71003 L .23885 .70587 L p .707 .577 .707 r
F P
0 g
s
.20174 .65943 m .20188 .60393 L .23122 .60053 L p .707 .577 .707 r
F P
0 g
s
.73709 .6591 m .73695 .60343 L .70576 .60166 L p .707 .577 .707 r
F P
0 g
s
.73695 .60343 m .73709 .6591 L .76891 .65824 L p .707 .577 .707 r
F P
0 g
s
.76891 .65824 m .76878 .60257 L .73695 .60343 L p .707 .577 .707 r
F P
0 g
s
.20554 .69238 m .20655 .72998 L .18263 .73503 L p .707 .577 .707 r
F P
0 g
s
.76878 .60257 m .76891 .65824 L .79826 .65483 L p .707 .577 .707 r
F P
0 g
s
.79826 .65483 m .79812 .59917 L .76878 .60257 L p .707 .577 .707 r
F P
0 g
s
.32799 .73125 m .3244 .74574 L .2972 .73152 L p .707 .577 .707 r
F P
0 g
s
.2972 .73152 m .3008 .71703 L .32799 .73125 L p .707 .577 .707 r
F P
0 g
s
.3254 .69084 m .3264 .72844 L .29886 .72574 L p .707 .577 .707 r
F P
0 g
s
.3008 .71703 m .2972 .73152 L .26648 .72278 L p .707 .577 .707 r
F P
0 g
s
.26648 .72278 m .27008 .70828 L .3008 .71703 L p .707 .577 .707 r
F P
0 g
s
.29886 .72574 m .29785 .68815 L .3254 .69084 L p .707 .577 .707 r
F P
0 g
s
.29424 .60177 m .2941 .65726 L .26291 .65528 L p .707 .577 .707 r
F P
0 g
s
.26291 .65528 m .26305 .59978 L .29424 .60177 L p .707 .577 .707 r
F P
0 g
s
.70589 .65733 m .70576 .60166 L .67825 .59744 L p .707 .577 .707 r
F P
0 g
s
.70576 .60166 m .70589 .65733 L .73709 .6591 L p .707 .577 .707 r
F P
0 g
s
.23885 .70587 m .23525 .72037 L .20656 .72452 L p .707 .577 .707 r
F P
0 g
s
.23525 .72037 m .23885 .70587 L .27008 .70828 L p .707 .577 .707 r
F P
0 g
s
.39228 .25559 m .39228 .75748 L .36791 .76767 L p .707 .577 .707 r
F P
0 g
s
.39228 .75748 m .39228 .25559 L .42719 .24792 L p .707 .577 .707 r
F P
0 g
s
.23108 .65603 m .23122 .60053 L .26305 .59978 L p .707 .577 .707 r
F P
0 g
s
.23122 .60053 m .23108 .65603 L .20174 .65943 L p .707 .577 .707 r
F P
0 g
s
.20655 .72998 m .20554 .69238 L .23484 .68896 L p .707 .577 .707 r
F P
0 g
s
.26305 .59978 m .26291 .65528 L .23108 .65603 L p .707 .577 .707 r
F P
0 g
s
.27008 .70828 m .26648 .72278 L .23525 .72037 L p .707 .577 .707 r
F P
0 g
s
.79812 .59917 m .79826 .65483 L .82225 .64922 L p .707 .577 .707 r
F P
0 g
s
.82225 .64922 m .82211 .59356 L .79812 .59917 L p .707 .577 .707 r
F P
0 g
s
.23484 .68896 m .23585 .72655 L .20655 .72998 L p .707 .577 .707 r
F P
0 g
s
.29785 .68815 m .29886 .72574 L .26766 .72509 L p .707 .577 .707 r
F P
0 g
s
.26766 .72509 m .26665 .6875 L .29785 .68815 L p .707 .577 .707 r
F P
0 g
s
.59593 .25242 m .59593 .75431 L .55795 .74777 L p .707 .577 .707 r
F P
0 g
s
.55795 .74777 m .55795 .24588 L .59593 .25242 L p .707 .577 .707 r
F P
0 g
s
.67825 .59744 m .67839 .65311 L .70589 .65733 L p .707 .577 .707 r
F P
0 g
s
.67839 .65311 m .67825 .59744 L .65712 .59118 L p .707 .577 .707 r
F P
0 g
s
.23585 .72655 m .23484 .68896 L .26665 .6875 L p .707 .577 .707 r
F P
0 g
s
.26665 .6875 m .26766 .72509 L .23585 .72655 L p .707 .577 .707 r
F P
0 g
s
.73234 .72253 m .73335 .68618 L .70214 .68316 L p .707 .577 .707 r
F P
0 g
s
.73335 .68618 m .73234 .72253 L .76415 .72231 L p .707 .577 .707 r
F P
0 g
s
.76415 .72231 m .76515 .68596 L .73335 .68618 L p .707 .577 .707 r
F P
0 g
s
.82211 .59356 m .82225 .64922 L .83853 .64195 L p .707 .577 .707 r
F P
0 g
s
.83853 .64195 m .8384 .58628 L .82211 .59356 L p .707 .577 .707 r
F P
0 g
s
.76515 .68596 m .76415 .72231 L .79345 .71888 L p .707 .577 .707 r
F P
0 g
s
.79345 .71888 m .79445 .68253 L .76515 .68596 L p .707 .577 .707 r
F P
0 g
s
.42719 .74981 m .42719 .24792 L .46924 .24351 L p .707 .577 .707 r
F P
0 g
s
.42719 .24792 m .42719 .74981 L .39228 .75748 L p .707 .577 .707 r
F P
0 g
s
.65712 .59118 m .65726 .64685 L .67839 .65311 L p .707 .577 .707 r
F P
0 g
s
.70114 .71951 m .70214 .68316 L .6746 .6772 L p .707 .577 .707 r
F P
0 g
s
.70214 .68316 m .70114 .71951 L .73234 .72253 L p .707 .577 .707 r
F P
0 g
s
.55795 .24588 m .55795 .74777 L .51429 .7447 L p .707 .577 .707 r
F P
0 g
s
.51429 .7447 m .51429 .24281 L .55795 .24588 L p .707 .577 .707 r
F P
0 g
s
.65726 .64685 m .65712 .59118 L .64444 .58349 L p .707 .577 .707 r
F P
0 g
s
.79445 .68253 m .79345 .71888 L .81737 .71256 L p .707 .577 .707 r
F P
0 g
s
.81737 .71256 m .81838 .67621 L .79445 .68253 L p .707 .577 .707 r
F P
0 g
s
.6746 .6772 m .6736 .71355 L .70114 .71951 L p .707 .577 .707 r
F P
0 g
s
.6992 .70393 m .70279 .72261 L .73351 .71582 L p .707 .577 .707 r
F P
0 g
s
.73351 .71582 m .72992 .69715 L .6992 .70393 L p .707 .577 .707 r
F P
0 g
s
.72992 .69715 m .73351 .71582 L .76475 .71046 L p .707 .577 .707 r
F P
0 g
s
.46924 .7454 m .46924 .24351 L .51429 .24281 L p .707 .577 .707 r
F P
0 g
s
.46924 .24351 m .46924 .7454 L .42719 .74981 L p .707 .577 .707 r
F P
0 g
s
.6736 .71355 m .6746 .6772 L .65341 .66887 L p .707 .577 .707 r
F P
0 g
s
.76475 .71046 m .76115 .69179 L .72992 .69715 L p .707 .577 .707 r
F P
0 g
s
.51429 .24281 m .51429 .7447 L .46924 .7454 L p .707 .577 .707 r
F P
0 g
s
.76115 .69179 m .76475 .71046 L .79343 .70705 L p .707 .577 .707 r
F P
0 g
s
.65341 .66887 m .65241 .70522 L .6736 .71355 L p .707 .577 .707 r
F P
0 g
s
.672 .71148 m .6756 .73016 L .70279 .72261 L p .707 .577 .707 r
F P
0 g
s
.70279 .72261 m .6992 .70393 L .672 .71148 L p .707 .577 .707 r
F P
0 g
s
.79343 .70705 m .78984 .68838 L .76115 .69179 L p .707 .577 .707 r
F P
0 g
s
.64444 .58349 m .64458 .63916 L .65726 .64685 L p .707 .577 .707 r
F P
0 g
s
.8384 .58628 m .83853 .64195 L .84552 .63373 L p .707 .577 .707 r
F P
0 g
s
.84552 .63373 m .84539 .57806 L .8384 .58628 L p .707 .577 .707 r
F P
0 g
s
.81838 .67621 m .81737 .71256 L .83358 .70398 L p .707 .577 .707 r
F P
0 g
s
.83358 .70398 m .83458 .66762 L .81838 .67621 L p .707 .577 .707 r
F P
0 g
s
.78984 .68838 m .79343 .70705 L .81677 .70593 L p .707 .577 .707 r
F P
0 g
s
.65099 .71906 m .65458 .73773 L .6756 .73016 L p .707 .577 .707 r
F P
0 g
s
.6756 .73016 m .672 .71148 L .65099 .71906 L p .707 .577 .707 r
F P
0 g
s
.81677 .70593 m .81318 .68726 L .78984 .68838 L p .707 .577 .707 r
F P
0 g
s
.64458 .63916 m .64444 .58349 L .64145 .57512 L p .707 .577 .707 r
F P
0 g
s
.65241 .70522 m .65341 .66887 L .64066 .659 L p .707 .577 .707 r
F P
0 g
s
.64066 .659 m .63965 .69535 L .65241 .70522 L p .707 .577 .707 r
F P
0 g
s
.64145 .57512 m .64158 .63079 L .64458 .63916 L p .707 .577 .707 r
F P
0 g
s
.81318 .68726 m .81677 .70593 L .83247 .70721 L p .707 .577 .707 r
F P
0 g
s
.84539 .57806 m .84552 .63373 L .84253 .62536 L p .707 .577 .707 r
F P
0 g
s
.84253 .62536 m .84239 .5697 L .84539 .57806 L p .707 .577 .707 r
F P
0 g
s
.83247 .70721 m .82888 .68853 L .81318 .68726 L p .707 .577 .707 r
F P
0 g
s
.83458 .66762 m .83358 .70398 L .84048 .69397 L p .707 .577 .707 r
F P
0 g
s
.84048 .69397 m .84148 .65762 L .83458 .66762 L p .707 .577 .707 r
F P
0 g
s
.63821 .72592 m .64181 .74459 L .65458 .73773 L p .707 .577 .707 r
F P
0 g
s
.65458 .73773 m .65099 .71906 L .63821 .72592 L p .707 .577 .707 r
F P
0 g
s
.63965 .69535 m .64066 .659 L .63758 .64855 L p .707 .577 .707 r
F P
0 g
s
.64158 .63079 m .64145 .57512 L .64844 .5669 L p .707 .577 .707 r
F P
0 g
s
.63758 .64855 m .63657 .6849 L .63965 .69535 L p .707 .577 .707 r
F P
0 g
s
.82888 .68853 m .83247 .70721 L .839 .71075 L p .707 .577 .707 r
F P
0 g
s
.64844 .5669 m .64857 .62257 L .64158 .63079 L p .707 .577 .707 r
F P
0 g
s
.839 .71075 m .83541 .69208 L .82888 .68853 L p .707 .577 .707 r
F P
0 g
s
.84239 .5697 m .84253 .62536 L .82985 .61767 L p .707 .577 .707 r
F P
0 g
s
.82985 .61767 m .82971 .56201 L .84239 .5697 L p .707 .577 .707 r
F P
0 g
s
.63493 .73138 m .63852 .75006 L .64181 .74459 L p .707 .577 .707 r
F P
0 g
s
.64181 .74459 m .63821 .72592 L .63493 .73138 L p .707 .577 .707 r
F P
0 g
s
.84148 .65762 m .84048 .69397 L .8374 .68352 L p .707 .577 .707 r
F P
0 g
s
.8374 .68352 m .8384 .64717 L .84148 .65762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63657 .6849 m .63758 .64855 L .64448 .63855 L p .707 .577 .707 r
F P
0 g
s
.64857 .62257 m .64844 .5669 L .66472 .55963 L p .707 .577 .707 r
F P
0 g
s
.39867 .61999 m .39836 .56444 L .36716 .56272 L p .707 .577 .707 r
F P
0 g
s
.39836 .56444 m .39867 .61999 L .4305 .61901 L p .707 .577 .707 r
F P
0 g
s
.4305 .61901 m .43018 .56347 L .39836 .56444 L p .707 .577 .707 r
F P
0 g
s
.43018 .56347 m .4305 .61901 L .45984 .61542 L p .707 .577 .707 r
F P
0 g
s
.45984 .61542 m .45953 .55988 L .43018 .56347 L p .707 .577 .707 r
F P
0 g
s
.64448 .63855 m .64347 .6749 L .63657 .6849 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36748 .61826 m .36716 .56272 L .33966 .55846 L p .707 .577 .707 r
F P
0 g
s
.36716 .56272 m .36748 .61826 L .39867 .61999 L p .707 .577 .707 r
F P
0 g
s
.66472 .55963 m .66486 .6153 L .64857 .62257 L p .707 .577 .707 r
F P
0 g
s
.83541 .69208 m .839 .71075 L .83571 .71622 L p .707 .577 .707 r
F P
0 g
s
.82971 .56201 m .82985 .61767 L .80872 .61141 L p .707 .577 .707 r
F P
0 g
s
.80872 .61141 m .80859 .55575 L .82971 .56201 L p .707 .577 .707 r
F P
0 g
s
.83571 .71622 m .83212 .69755 L .83541 .69208 L p .707 .577 .707 r
F P
0 g
s
.8384 .64717 m .8374 .68352 L .82464 .67365 L p .707 .577 .707 r
F P
0 g
s
.82464 .67365 m .82564 .6373 L .8384 .64717 L p .707 .577 .707 r
F P
0 g
s
.64146 .73493 m .64505 .7536 L .63852 .75006 L p .707 .577 .707 r
F P
0 g
s
.63852 .75006 m .63493 .73138 L .64146 .73493 L p .707 .577 .707 r
F P
0 g
s
.45953 .55988 m .45984 .61542 L .48383 .60958 L p .707 .577 .707 r
F P
0 g
s
.48383 .60958 m .48351 .55403 L .45953 .55988 L p .707 .577 .707 r
F P
0 g
s
.38718 .67844 m .38951 .6412 L .35836 .63768 L p .707 .577 .707 r
F P
0 g
s
.38951 .6412 m .38718 .67844 L .41894 .67957 L p .707 .577 .707 r
F P
0 g
s
.41894 .67957 m .42127 .64233 L .38951 .6412 L p .707 .577 .707 r
F P
0 g
s
.66486 .6153 m .66472 .55963 L .68871 .55402 L p .707 .577 .707 r
F P
0 g
s
.64347 .6749 m .64448 .63855 L .66068 .62996 L p .707 .577 .707 r
F P
0 g
s
.42127 .64233 m .41894 .67957 L .4482 .6782 L p .707 .577 .707 r
F P
0 g
s
.4482 .6782 m .45054 .64096 L .42127 .64233 L p .707 .577 .707 r
F P
0 g
s
.33966 .55846 m .33997 .614 L .36748 .61826 L p .707 .577 .707 r
F P
0 g
s
.33997 .614 m .33966 .55846 L .31853 .55208 L p .707 .577 .707 r
F P
0 g
s
.35602 .67492 m .35836 .63768 L .33087 .63211 L p .707 .577 .707 r
F P
0 g
s
.35836 .63768 m .35602 .67492 L .38718 .67844 L p .707 .577 .707 r
F P
0 g
s
.80859 .55575 m .80872 .61141 L .78121 .60719 L p .707 .577 .707 r
F P
0 g
s
.78121 .60719 m .78108 .55152 L .80859 .55575 L p .707 .577 .707 r
F P
0 g
s
.33087 .63211 m .32853 .66936 L .35602 .67492 L p .707 .577 .707 r
F P
0 g
s
.66068 .62996 m .65968 .66632 L .64347 .6749 L p .707 .577 .707 r
F P
0 g
s
.68871 .55402 m .68885 .60969 L .66486 .6153 L p .707 .577 .707 r
F P
0 g
s
.45054 .64096 m .4482 .6782 L .4721 .67447 L p .707 .577 .707 r
F P
0 g
s
.4721 .67447 m .47443 .63722 L .45054 .64096 L p .707 .577 .707 r
F P
0 g
s
.48351 .55403 m .48383 .60958 L .50012 .60205 L p .707 .577 .707 r
F P
0 g
s
.50012 .60205 m .4998 .5465 L .48351 .55403 L p .707 .577 .707 r
F P
0 g
s
.41506 .72972 m .40709 .71399 L .37807 .7269 L p .707 .577 .707 r
F P
0 g
s
.40709 .71399 m .41506 .72972 L .44199 .7134 L p .707 .577 .707 r
F P
0 g
s
.44199 .7134 m .43402 .69767 L .40709 .71399 L p .707 .577 .707 r
F P
0 g
s
.31853 .55208 m .31885 .60762 L .33997 .614 L p .707 .577 .707 r
F P
0 g
s
.68885 .60969 m .68871 .55402 L .71806 .55062 L p .707 .577 .707 r
F P
0 g
s
.83212 .69755 m .83571 .71622 L .82294 .72308 L p .707 .577 .707 r
F P
0 g
s
.82564 .6373 m .82464 .67365 L .80345 .66533 L p .707 .577 .707 r
F P
0 g
s
.80345 .66533 m .80446 .62897 L .82564 .6373 L p .707 .577 .707 r
F P
0 g
s
.32853 .66936 m .33087 .63211 L .30973 .62505 L p .707 .577 .707 r
F P
0 g
s
.38604 .74264 m .37807 .7269 L .34982 .73514 L p .707 .577 .707 r
F P
0 g
s
.37807 .7269 m .38604 .74264 L .41506 .72972 L p .707 .577 .707 r
F P
0 g
s
.43402 .69767 m .44199 .7134 L .46419 .69528 L p .707 .577 .707 r
F P
0 g
s
.46419 .69528 m .45622 .67954 L .43402 .69767 L p .707 .577 .707 r
F P
0 g
s
.82294 .72308 m .81935 .70441 L .83212 .69755 L p .707 .577 .707 r
F P
0 g
s
.65716 .7362 m .66075 .75488 L .64505 .7536 L p .707 .577 .707 r
F P
0 g
s
.64505 .7536 m .64146 .73493 L .65716 .7362 L p .707 .577 .707 r
F P
0 g
s
.31885 .60762 m .31853 .55208 L .30585 .5442 L p .707 .577 .707 r
F P
0 g
s
.65968 .66632 m .66068 .62996 L .6846 .62364 L p .707 .577 .707 r
F P
0 g
s
.78108 .55152 m .78121 .60719 L .75002 .60542 L p .707 .577 .707 r
F P
0 g
s
.75002 .60542 m .74988 .54976 L .78108 .55152 L p .707 .577 .707 r
F P
0 g
s
.34982 .73514 m .35778 .75088 L .38604 .74264 L p .707 .577 .707 r
F P
0 g
s
.30973 .62505 m .30739 .66229 L .32853 .66936 L p .707 .577 .707 r
F P
0 g
s
.71819 .60628 m .71806 .55062 L .74988 .54976 L p .707 .577 .707 r
F P
0 g
s
.71806 .55062 m .71819 .60628 L .68885 .60969 L p .707 .577 .707 r
F P
0 g
s
.35778 .75088 m .34982 .73514 L .32508 .73791 L p .707 .577 .707 r
F P
0 g
s
.74988 .54976 m .75002 .60542 L .71819 .60628 L p .707 .577 .707 r
F P
0 g
s
.47443 .63722 m .4721 .67447 L .48829 .66873 L p .707 .577 .707 r
F P
0 g
s
.48829 .66873 m .49063 .63149 L .47443 .63722 L p .707 .577 .707 r
F P
0 g
s
.45622 .67954 m .46419 .69528 L .4795 .67711 L p .707 .577 .707 r
F P
0 g
s
.4795 .67711 m .47153 .66138 L .45622 .67954 L p .707 .577 .707 r
F P
0 g
s
.6846 .62364 m .6836 .66 L .65968 .66632 L p .707 .577 .707 r
F P
0 g
s
.32508 .73791 m .33305 .75365 L .35778 .75088 L p .707 .577 .707 r
F P
0 g
s
.80446 .62897 m .80345 .66533 L .77591 .65936 L p .707 .577 .707 r
F P
0 g
s
.77591 .65936 m .77691 .62301 L .80446 .62897 L p .707 .577 .707 r
F P
0 g
s
.30585 .5442 m .30616 .59975 L .31885 .60762 L p .707 .577 .707 r
F P
0 g
s
.4998 .5465 m .50012 .60205 L .50711 .59357 L p .707 .577 .707 r
F P
0 g
s
.50711 .59357 m .50679 .53803 L .4998 .5465 L p .707 .577 .707 r
F P
0 g
s
.30739 .66229 m .30973 .62505 L .29701 .61718 L p .707 .577 .707 r
F P
0 g
s
.6836 .66 m .6846 .62364 L .7139 .62021 L p .707 .577 .707 r
F P
0 g
s
.81935 .70441 m .82294 .72308 L .80193 .73065 L p .707 .577 .707 r
F P
0 g
s
.80193 .73065 m .79833 .71198 L .81935 .70441 L p .707 .577 .707 r
F P
0 g
s
.6805 .73508 m .68409 .75376 L .66075 .75488 L p .707 .577 .707 r
F P
0 g
s
.66075 .75488 m .65716 .7362 L .6805 .73508 L p .707 .577 .707 r
F P
0 g
s
.29701 .61718 m .29467 .65442 L .30739 .66229 L p .707 .577 .707 r
F P
0 g
s
.33305 .75365 m .32508 .73791 L .30628 .73493 L p .707 .577 .707 r
F P
0 g
s
.30616 .59975 m .30585 .5442 L .30285 .53561 L p .707 .577 .707 r
F P
0 g
s
.77691 .62301 m .77591 .65936 L .74471 .65634 L p .707 .577 .707 r
F P
0 g
s
.74471 .65634 m .74571 .61999 L .77691 .62301 L p .707 .577 .707 r
F P
0 g
s
.47153 .66138 m .4795 .67711 L .48642 .6607 L p .707 .577 .707 r
F P
0 g
s
.48642 .6607 m .47845 .64496 L .47153 .66138 L p .707 .577 .707 r
F P
0 g
s
.7129 .65656 m .7139 .62021 L .74571 .61999 L p .707 .577 .707 r
F P
0 g
s
.7139 .62021 m .7129 .65656 L .6836 .66 L p .707 .577 .707 r
F P
0 g
s
.30628 .73493 m .31425 .75067 L .33305 .75365 L p .707 .577 .707 r
F P
0 g
s
.49063 .63149 m .48829 .66873 L .4952 .66156 L p .707 .577 .707 r
F P
0 g
s
.4952 .66156 m .49754 .62431 L .49063 .63149 L p .707 .577 .707 r
F P
0 g
s
.74571 .61999 m .74471 .65634 L .7129 .65656 L p .707 .577 .707 r
F P
0 g
s
.30285 .53561 m .30317 .59115 L .30616 .59975 L p .707 .577 .707 r
F P
0 g
s
.79833 .71198 m .80193 .73065 L .77473 .7382 L p .707 .577 .707 r
F P
0 g
s
.29467 .65442 m .29701 .61718 L .29395 .60926 L p .707 .577 .707 r
F P
0 g
s
.50679 .53803 m .50711 .59357 L .50412 .58497 L p .707 .577 .707 r
F P
0 g
s
.50412 .58497 m .5038 .52943 L .50679 .53803 L p .707 .577 .707 r
F P
0 g
s
.70918 .73168 m .71278 .75035 L .68409 .75376 L p .707 .577 .707 r
F P
0 g
s
.68409 .75376 m .6805 .73508 L .70918 .73168 L p .707 .577 .707 r
F P
0 g
s
.77473 .7382 m .77113 .71953 L .79833 .71198 L p .707 .577 .707 r
F P
0 g
s
.31425 .75067 m .30628 .73493 L .29527 .72649 L p .707 .577 .707 r
F P
0 g
s
.29395 .60926 m .29161 .64651 L .29467 .65442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.47845 .64496 m .48642 .6607 L .48427 .64763 L p .707 .577 .707 r
F P
0 g
s
.48427 .64763 m .4763 .63189 L .47845 .64496 L p .707 .577 .707 r
F P
0 g
s
.30317 .59115 m .30285 .53561 L .30984 .52713 L p .707 .577 .707 r
F P
0 g
s
.77113 .71953 m .77473 .7382 L .74401 .74499 L p .707 .577 .707 r
F P
0 g
s
.29527 .72649 m .30324 .74223 L .31425 .75067 L p .707 .577 .707 r
F P
0 g
s
.74042 .72632 m .74401 .74499 L .71278 .75035 L p .707 .577 .707 r
F P
0 g
s
.71278 .75035 m .70918 .73168 L .74042 .72632 L p .707 .577 .707 r
F P
0 g
s
.74401 .74499 m .74042 .72632 L .77113 .71953 L p .707 .577 .707 r
F P
0 g
s
.49754 .62431 m .4952 .66156 L .49215 .65365 L p .707 .577 .707 r
F P
0 g
s
.49215 .65365 m .49448 .6164 L .49754 .62431 L p .707 .577 .707 r
F P
0 g
s
.30984 .52713 m .31016 .58267 L .30317 .59115 L p .707 .577 .707 r
F P
0 g
s
.29161 .64651 m .29395 .60926 L .30086 .60209 L p .707 .577 .707 r
F P
0 g
s
.5038 .52943 m .50412 .58497 L .49144 .5771 L p .707 .577 .707 r
F P
0 g
s
.49144 .5771 m .49112 .52156 L .5038 .52943 L p .707 .577 .707 r
F P
0 g
s
.30324 .74223 m .29527 .72649 L .29311 .71343 L p .707 .577 .707 r
F P
0 g
s
.30086 .60209 m .29852 .63933 L .29161 .64651 L p .707 .577 .707 r
F P
0 g
s
.4763 .63189 m .48427 .64763 L .47325 .63919 L p .707 .577 .707 r
F P
0 g
s
.47325 .63919 m .46528 .62346 L .4763 .63189 L p .707 .577 .707 r
F P
0 g
s
.29311 .71343 m .30108 .72917 L .30324 .74223 L p .707 .577 .707 r
F P
0 g
s
.31016 .58267 m .30984 .52713 L .32613 .5196 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49448 .6164 m .49215 .65365 L .47942 .64577 L p .707 .577 .707 r
F P
0 g
s
.47942 .64577 m .48176 .60853 L .49448 .6164 L p .707 .577 .707 r
F P
0 g
s
.32613 .5196 m .32645 .57514 L .31016 .58267 L p .707 .577 .707 r
F P
0 g
s
.49112 .52156 m .49144 .5771 L .47031 .57072 L p .707 .577 .707 r
F P
0 g
s
.47031 .57072 m .46999 .51518 L .49112 .52156 L p .707 .577 .707 r
F P
0 g
s
.29852 .63933 m .30086 .60209 L .31705 .59635 L p .707 .577 .707 r
F P
0 g
s
.30108 .72917 m .29311 .71343 L .30003 .69701 L p .707 .577 .707 r
F P
0 g
s
.31705 .59635 m .31472 .6336 L .29852 .63933 L p .707 .577 .707 r
F P
0 g
s
.32645 .57514 m .32613 .5196 L .35012 .51375 L p .707 .577 .707 r
F P
0 g
s
.46528 .62346 m .47325 .63919 L .45446 .63621 L p .707 .577 .707 r
F P
0 g
s
.45446 .63621 m .44649 .62047 L .46528 .62346 L p .707 .577 .707 r
F P
0 g
s
.30003 .69701 m .308 .71275 L .30108 .72917 L p .707 .577 .707 r
F P
0 g
s
.48176 .60853 m .47942 .64577 L .45828 .63871 L p .707 .577 .707 r
F P
0 g
s
.45828 .63871 m .46062 .60146 L .48176 .60853 L p .707 .577 .707 r
F P
0 g
s
.46999 .51518 m .47031 .57072 L .4428 .56646 L p .707 .577 .707 r
F P
0 g
s
.4428 .56646 m .44248 .51091 L .46999 .51518 L p .707 .577 .707 r
F P
0 g
s
.35012 .51375 m .35044 .5693 L .32645 .57514 L p .707 .577 .707 r
F P
0 g
s
.31472 .6336 m .31705 .59635 L .34095 .59262 L p .707 .577 .707 r
F P
0 g
s
.35044 .5693 m .35012 .51375 L .37946 .51017 L p .707 .577 .707 r
F P
0 g
s
.308 .71275 m .30003 .69701 L .31534 .67885 L p .707 .577 .707 r
F P
0 g
s
.44649 .62047 m .45446 .63621 L .42972 .63898 L p .707 .577 .707 r
F P
0 g
s
.42972 .63898 m .42175 .62324 L .44649 .62047 L p .707 .577 .707 r
F P
0 g
s
.34095 .59262 m .33862 .62986 L .31472 .6336 L p .707 .577 .707 r
F P
0 g
s
.44248 .51091 m .4428 .56646 L .41161 .56473 L p .707 .577 .707 r
F P
0 g
s
.41161 .56473 m .41129 .50919 L .44248 .51091 L p .707 .577 .707 r
F P
0 g
s
.31534 .67885 m .32331 .69459 L .308 .71275 L p .707 .577 .707 r
F P
0 g
s
.37978 .56571 m .37946 .51017 L .41129 .50919 L p .707 .577 .707 r
F P
0 g
s
.37946 .51017 m .37978 .56571 L .35044 .5693 L p .707 .577 .707 r
F P
0 g
s
.46062 .60146 m .45828 .63871 L .43079 .63314 L p .707 .577 .707 r
F P
0 g
s
.43079 .63314 m .43313 .5959 L .46062 .60146 L p .707 .577 .707 r
F P
0 g
s
.41129 .50919 m .41161 .56473 L .37978 .56571 L p .707 .577 .707 r
F P
0 g
s
.33862 .62986 m .34095 .59262 L .37021 .59125 L p .707 .577 .707 r
F P
0 g
s
.32331 .69459 m .31534 .67885 L .33755 .66072 L p .707 .577 .707 r
F P
0 g
s
.42175 .62324 m .42972 .63898 L .40146 .64723 L p .707 .577 .707 r
F P
0 g
s
.40146 .64723 m .39349 .63149 L .42175 .62324 L p .707 .577 .707 r
F P
0 g
s
.37021 .59125 m .36788 .62849 L .33862 .62986 L p .707 .577 .707 r
F P
0 g
s
.43313 .5959 m .43079 .63314 L .39964 .62962 L p .707 .577 .707 r
F P
0 g
s
.39964 .62962 m .40198 .59238 L .43313 .5959 L p .707 .577 .707 r
F P
0 g
s
.33755 .66072 m .34552 .67646 L .32331 .69459 L p .707 .577 .707 r
F P
0 g
s
.36788 .62849 m .37021 .59125 L .40198 .59238 L p .707 .577 .707 r
F P
0 g
s
.40198 .59238 m .39964 .62962 L .36788 .62849 L p .707 .577 .707 r
F P
0 g
s
.34552 .67646 m .33755 .66072 L .36447 .6444 L p .707 .577 .707 r
F P
0 g
s
.39349 .63149 m .40146 .64723 L .37244 .66014 L p .707 .577 .707 r
F P
0 g
s
.37244 .66014 m .36447 .6444 L .39349 .63149 L p .707 .577 .707 r
F P
0 g
s
.36447 .6444 m .37244 .66014 L .34552 .67646 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF2`002eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol00`00FUIJEP080004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0061oo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`@000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00FWoo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Aoo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00
EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo00mooaP003eoo`00EWoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo00Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Uo
o`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Eoo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0035oo`00EWoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001oogooOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000`Ool005Ioo`03001JEP0000=JEP03001JEUYF00=JEPL000EJEPD000IJEPP000AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000Ool000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002ioo`00EWoo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH00eYF1@001eYF00<005YFFUH015YF1P0015YF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`03001JEP0000=JEP80009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`04001JEP00FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020000
1EYF000005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00@005YF
FUIJEQT000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001FOol200000eYF000000030002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;7oo000nOolA0008Ool200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P000UYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool0035oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;7oo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH2000/Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8002aoo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00AJEQ40009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH70003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF0`00;7oo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<0009JEP03001JEUYF009JEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1P0000=J
EP00FUH0100000EJEP00FUIJEP0000AJEP800003FUH005YF00AJEPP000AJEP03001JEUYF00=JEP06
001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000AJEP00000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00<000AJEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH00eYF1P0000=JEP0000000eYF00<005YFFUH01UYF2`0015YF00H005YFFUH005YF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH2000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP04
001JEUYFFUH20006FUH00`00FUIJEP03FUH@00001eYF001JEUYF001JEP0000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH0000002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00@005YF000000QJEP03
001JEUYF00@000QJEP03001JEUYF00=JEP<0009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<000UJEP<000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH00000008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH00UYF5P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000008000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH70008FUH50004FUH01000FUIJEUYF0P0000=J
EP00FUH015YF00@005YF000000QJEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEPH000Iooa4000IJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002]oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00=JEP<000AJEP800003FUH005YF00EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEP0000@000=JEP03001oogoo01Ioo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002]oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP@00005FUH005YFFUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH30006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP<000AJEP05001JEUYFFUH0
000;Ool3000>Ool40004FUH01000FUIJEUYF0P00;Goo000[Ool01000FUH005YF0P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP05
001JEUYFFUH00008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001J
EP040005FUH01000FUIJEUYF0P002Goo1@004Goo0`0000=JEP00FUH00UYF0P00;Goo000[Ool01P00
FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYF0005FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH0
05YF00800003FUH005YF00<000=JEP04001JEUYFFUH20009Ool5000DOol20003FUH2000]Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000MJEP@0009JEP03001JEP0000P000AJEP03001JEUYF009JEPL000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP@000=JEP8000Uoo`D0019oo`80009JEP04001JEUYF000^Ool002]oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000IJEP800004FUH005YF0002FUH00`00FUIJEP04FUH300000eYF000000070005FUH00`00FUIJ
EP03FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP03FUH00`00FUH00005000:Ool3000?Ool400000eYF001JEP02FUH3000^
Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP07001JEUYFFUH005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1`004Woo1@001EYF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF6P000UYF00@005YFFUIJ
EP8000=JEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHQ00000eYF001oo`0]Ool002aoo`05001J
EUYFFUH00005FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YF00000`000eYF0`000UYF00<005YFFUH00eYF1@001UYF00@005YFFUIJEP8000=JEP04
001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<0
05YFFUH015YF00@005YFFUIJEP@002ioo`00;Goo0P0000=JEP00FUH00eYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P000UYF1@0000Eoo`00FUIJEP0000IJ
EP<000MJEP04001JEUYF0006FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;goo
0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YF00001EYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF00001UYF00@005YFFUH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03000_Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000=JEP04001JEUYF0005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF0`00
1EYF00D005YFFUIJEP0000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP@000EJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002moo`00;goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUH000EJEP04001J
EUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0015YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P0015YF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJ
EPD0009JEP03001JEP0002ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0`0000=J
EP00FUH0100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF
0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000EJEP03001JEUYF
00MJEP03001JEUYF009JEPT000=JEP<000AJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJ
EP0000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH2
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH400001UYF00000000FUH000MJEP03001JEUYF00AJEPL000AJEP04001JEUYFFUH400000eYF
001JEP05FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH010000UYF1@0015YF10001EYF00<005YFFUH015YF00@005YF
0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
009JEP<000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP03FUH40002Ool=0002FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000bOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEQD00004FUH000000004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF00000P00
1eYF00H005YF000005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF000010002Goo1@001UYF00<0
05YFFUH01EYF00<005YF00000P00=Goo000]Ool00`00FUH00003FUH00`00FUIJEP03FUHJ00000eYF
00000002FUH70003FUH01000FUIJEP000UYF0P0000=JEP00FUH025YF00D005YFFUIJEP0000]JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF009JEP<0009JEP03001JEP0000Eoo`@0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP<003Qoo`00;Goo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<0
05YF00001P000eYF1P000UYF0`0015YF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YF00000P001EYF00<005YF00001@001UYF00<005YFFUH01eYF00<005YF00000`00>goo000]Ool0
0`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH01`00FUIJEUYF001J
EP00009JEP/000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH03P000eYF00<005YF
FUH01eYF00<005YFFUH015YF1000?goo000]Ool00`00FUH000030004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01eYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01000@goo000]Ool300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Agoo
000]Ool50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0003FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH01eYF00@005YFFUIJEPH000MJ
EP03001JEUYF00UJEP03001JEP0000P000QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01000C7oo000]Ool300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01EYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF1P000UYF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH6001@Ool0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00H00004FUH000000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUHA00000eYF001oo`1COol002ioo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF0080009JEP03001JEUYF00=J
EPD000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF009JEP03001oogoo00Moo`<00003FUH005YF009JEP03001oogoo059oo`00;Goo0P00
0Woo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000`000Woo0P000UYF00@005YFFUH000=JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF00=JEP03001oogoo
00Qoo`@000=JEP8005=oo`00;Goo0P001Goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1@001goo00@005YFFUH0009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<0
07ooOol017oo100000AJEP00FUIJEP800003FUH0000005=oo`00;Goo00<005YF00002goo6`0037oo
00@005YFFUH0009JEP<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001oo`0000@000EJEP04001JEUYF
FUH4001COol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001COol002eoo`03001JEP00
01Moo`D001Moo`04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000Dgoo000]Ool01000FUH000005Woo1@0067oo
0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005=oo`00;Woo00<005YF00005Woo1@0067oo0`000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00;Woo
00@005YFFUH001Ioo`<001Yoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1COol002ioo`05001JEUYFFUH0000bOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP02001FOol002moo`04001JEUYF000bOol20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP04FUH3001HOol002moo`05001JEUYFFUH0000aOol00`00FUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH2001JOol0031oo`03001JEUYF0080035o
o`D000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP0000<005aoo`00<Goo0P000UYF00<007ooOol0
;Woo00@007ooOomoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006FUH3001POol0035oo`8000=JEP8002eoo`80
00Eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000003FUH200000eYF00000002001SOol0039oo`03001JEUYF00=JEP03
001oogoo02Yoo`8000Uoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP@00003FUH005YF00AJEP8006Ioo`00<goo00<005YFFUH00eYF00<007ooOol0:7oo
0P003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02P00
25YF0`00Hgoo000dOol00`00FUIJEP02FUH3000WOol3000EOol90006FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH80004FUH60009FUH01000FUH00000HGoo000eOol200000eYF001JEP02FUH2000TOol0
0`00FUH0000OOolI0008Ool20002FUH500000eYF00000006FUH00`00FUIJEP02FUH2001OOol003Mo
o`8000EJEP80021oo`80009JEP03001oogoo041oo`800004FUH000000004FUH20004FUH00`00FUIJ
EP04FUH2001MOol003Qoo`03001JEUYF00EJEP<001]oo`800004FUH005YF0015Ool20008FUH20000
0eYF001JEP07FUH3001KOol003Uoo`8000IJEP04001JEP00000GOol20002FUH00`00FUH00018Ool2
0006FUH00`00FUH000020006FUH01000FUIJEUYF0P00FGoo000kOol20003FUH00`00FUIJEP02FUH3
000?Ool50004FUH2001;Ool20004FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH2001GOol0
03eoo`800003FUH005YF00IJEPl000=JEP03001JEUYF009JEP8004ioo`800003FUH005YF00IJEP80
0003FUH005YF00EJEP03001JEP0005Ioo`00?goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80059oo`<000MJEP<000IJEP04001JEUYF001EOol0049oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00001GOol20005FUH00`00FUIJEP020003FUH00`00FUIJEP02
FUH00`00Oomoo`1BOol004Aoo`<00003FUH005YF00MJEP03001JEUYF009JEPD005]oo`<00003FUH0
05YF00AJEP800003FUH005YF00=JEP03001oogoo059oo`00Agoo3`00Hgoo0`001EYF0P0015YF0P00
E7oo002lOol300001EYF001JEUYF00000eYF00<007ooOol0Dgoo002oOol20003FUH4001EOol00<5o
o`800004FUH005YF001FOol00<=oo`@005Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59135 .74991 m .59154 .6943 L .56036 .69232 L p .707 .577 .707 r
F P
0 g
s
.59154 .6943 m .59135 .74991 L .62317 .74922 L p .707 .577 .707 r
F P
0 g
s
.62317 .74922 m .62337 .69362 L .59154 .6943 L p .707 .577 .707 r
F P
0 g
s
.62337 .69362 m .62317 .74922 L .65253 .74594 L p .707 .577 .707 r
F P
0 g
s
.65253 .74594 m .65273 .69034 L .62337 .69362 L p .707 .577 .707 r
F P
0 g
s
.56016 .74793 m .56036 .69232 L .53287 .68788 L p .707 .577 .707 r
F P
0 g
s
.56036 .69232 m .56016 .74793 L .59135 .74991 L p .707 .577 .707 r
F P
0 g
s
.65273 .69034 m .65253 .74594 L .67655 .74039 L p .707 .577 .707 r
F P
0 g
s
.67655 .74039 m .67674 .68478 L .65273 .69034 L p .707 .577 .707 r
F P
0 g
s
.53287 .68788 m .53267 .74348 L .56016 .74793 L p .707 .577 .707 r
F P
0 g
s
.53267 .74348 m .53287 .68788 L .51177 .6814 L p .707 .577 .707 r
F P
0 g
s
.59875 .8114 m .5973 .77454 L .56613 .77369 L p .707 .577 .707 r
F P
0 g
s
.5973 .77454 m .59875 .8114 L .63055 .8094 L p .707 .577 .707 r
F P
0 g
s
.63055 .8094 m .62911 .77255 L .5973 .77454 L p .707 .577 .707 r
F P
0 g
s
.62911 .77255 m .63055 .8094 L .65987 .80475 L p .707 .577 .707 r
F P
0 g
s
.65987 .80475 m .65843 .76789 L .62911 .77255 L p .707 .577 .707 r
F P
0 g
s
.56757 .81054 m .56613 .77369 L .53864 .77005 L p .707 .577 .707 r
F P
0 g
s
.56613 .77369 m .56757 .81054 L .59875 .8114 L p .707 .577 .707 r
F P
0 g
s
.67674 .68478 m .67655 .74039 L .69287 .7331 L p .707 .577 .707 r
F P
0 g
s
.69287 .7331 m .69306 .6775 L .67674 .68478 L p .707 .577 .707 r
F P
0 g
s
.51177 .6814 m .51157 .737 L .53267 .74348 L p .707 .577 .707 r
F P
0 g
s
.65843 .76789 m .65987 .80475 L .68384 .79788 L p .707 .577 .707 r
F P
0 g
s
.68384 .79788 m .68239 .76103 L .65843 .76789 L p .707 .577 .707 r
F P
0 g
s
.59776 .83791 m .60279 .81958 L .57275 .81039 L p .707 .577 .707 r
F P
0 g
s
.60279 .81958 m .59776 .83791 L .6285 .84571 L p .707 .577 .707 r
F P
0 g
s
.6285 .84571 m .63353 .82738 L .60279 .81958 L p .707 .577 .707 r
F P
0 g
s
.53864 .77005 m .54008 .80691 L .56757 .81054 L p .707 .577 .707 r
F P
0 g
s
.57275 .81039 m .56772 .82872 L .59776 .83791 L p .707 .577 .707 r
F P
0 g
s
.63353 .82738 m .6285 .84571 L .65694 .85135 L p .707 .577 .707 r
F P
0 g
s
.65694 .85135 m .66197 .83302 L .63353 .82738 L p .707 .577 .707 r
F P
0 g
s
.51157 .737 m .51177 .6814 L .49912 .67352 L p .707 .577 .707 r
F P
0 g
s
.56772 .82872 m .57275 .81039 L .54634 .80071 L p .707 .577 .707 r
F P
0 g
s
.54008 .80691 m .53864 .77005 L .51752 .76401 L p .707 .577 .707 r
F P
0 g
s
.54634 .80071 m .54131 .81904 L .56772 .82872 L p .707 .577 .707 r
F P
0 g
s
.66197 .83302 m .65694 .85135 L .68028 .8543 L p .707 .577 .707 r
F P
0 g
s
.68028 .8543 m .68531 .83597 L .66197 .83302 L p .707 .577 .707 r
F P
0 g
s
.51752 .76401 m .51896 .80086 L .54008 .80691 L p .707 .577 .707 r
F P
0 g
s
.68239 .76103 m .68384 .79788 L .7001 .78949 L p .707 .577 .707 r
F P
0 g
s
.7001 .78949 m .69866 .75263 L .68239 .76103 L p .707 .577 .707 r
F P
0 g
s
.49912 .67352 m .49892 .72913 L .51157 .737 L p .707 .577 .707 r
F P
0 g
s
.69306 .6775 m .69287 .7331 L .69989 .7248 L p .707 .577 .707 r
F P
0 g
s
.69989 .7248 m .70009 .6692 L .69306 .6775 L p .707 .577 .707 r
F P
0 g
s
.54131 .81904 m .54634 .80071 L .52617 .79149 L p .707 .577 .707 r
F P
0 g
s
.52617 .79149 m .52114 .80982 L .54131 .81904 L p .707 .577 .707 r
F P
0 g
s
.51896 .80086 m .51752 .76401 L .50484 .75613 L p .707 .577 .707 r
F P
0 g
s
.49892 .72913 m .49912 .67352 L .49617 .66502 L p .707 .577 .707 r
F P
0 g
s
.68531 .83597 m .68028 .8543 L .69625 .85424 L p .707 .577 .707 r
F P
0 g
s
.69625 .85424 m .70128 .83591 L .68531 .83597 L p .707 .577 .707 r
F P
0 g
s
.50484 .75613 m .50628 .79299 L .51896 .80086 L p .707 .577 .707 r
F P
0 g
s
.52114 .80982 m .52617 .79149 L .51419 .78363 L p .707 .577 .707 r
F P
0 g
s
.69866 .75263 m .7001 .78949 L .70708 .78038 L p .707 .577 .707 r
F P
0 g
s
.70708 .78038 m .70564 .74353 L .69866 .75263 L p .707 .577 .707 r
F P
0 g
s
.51419 .78363 m .50916 .80196 L .52114 .80982 L p .707 .577 .707 r
F P
0 g
s
.49617 .66502 m .49597 .72062 L .49892 .72913 L p .707 .577 .707 r
F P
0 g
s
.70009 .6692 m .69989 .7248 L .69693 .7163 L p .707 .577 .707 r
F P
0 g
s
.69693 .7163 m .69713 .66069 L .70009 .6692 L p .707 .577 .707 r
F P
0 g
s
.50628 .79299 m .50484 .75613 L .50184 .74721 L p .707 .577 .707 r
F P
0 g
s
.48751 .82178 m .48751 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.49597 .72062 m .49617 .66502 L .50319 .65671 L p .707 .577 .707 r
F P
0 g
s
.50184 .74721 m .50328 .78407 L .50628 .79299 L p .707 .577 .707 r
F P
0 g
s
.50916 .80196 m .51419 .78363 L .51159 .7779 L p .707 .577 .707 r
F P
0 g
s
.51159 .7779 m .50656 .79623 L .50916 .80196 L p .707 .577 .707 r
F P
0 g
s
.50319 .65671 m .50299 .71232 L .49597 .72062 L p .707 .577 .707 r
F P
0 g
s
.50328 .78407 m .50184 .74721 L .50881 .7381 L p .707 .577 .707 r
F P
0 g
s
.50299 .71232 m .50319 .65671 L .51951 .64943 L p .707 .577 .707 r
F P
0 g
s
.50881 .7381 m .51026 .77496 L .50328 .78407 L p .707 .577 .707 r
F P
0 g
s
.50656 .79623 m .51159 .7779 L .51861 .77486 L p .707 .577 .707 r
F P
0 g
s
.51861 .77486 m .51358 .79319 L .50656 .79623 L p .707 .577 .707 r
F P
0 g
s
.51951 .64943 m .51931 .70504 L .50299 .71232 L p .707 .577 .707 r
F P
0 g
s
.51026 .77496 m .50881 .7381 L .52508 .72971 L p .707 .577 .707 r
F P
0 g
s
.51931 .70504 m .51951 .64943 L .54352 .64388 L p .707 .577 .707 r
F P
0 g
s
.52508 .72971 m .52653 .76656 L .51026 .77496 L p .707 .577 .707 r
F P
0 g
s
.51358 .79319 m .51861 .77486 L .53458 .77481 L p .707 .577 .707 r
F P
0 g
s
.54352 .64388 m .54333 .69948 L .51931 .70504 L p .707 .577 .707 r
F P
0 g
s
.53458 .77481 m .52955 .79314 L .51358 .79319 L p .707 .577 .707 r
F P
0 g
s
.52653 .76656 m .52508 .72971 L .54905 .72285 L p .707 .577 .707 r
F P
0 g
s
.54905 .72285 m .55049 .7597 L .52653 .76656 L p .707 .577 .707 r
F P
0 g
s
.52955 .79314 m .53458 .77481 L .55792 .77775 L p .707 .577 .707 r
F P
0 g
s
.55792 .77775 m .55289 .79608 L .52955 .79314 L p .707 .577 .707 r
F P
0 g
s
.48751 .31989 m .48751 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48751 .31989 L p .707 .577 .707 r
F P
0 g
s
.54333 .69948 m .54352 .64388 L .57288 .6406 L p .707 .577 .707 r
F P
0 g
s
.57288 .6406 m .57268 .6962 L .54333 .69948 L p .707 .577 .707 r
F P
0 g
s
.55049 .7597 m .54905 .72285 L .57837 .71819 L p .707 .577 .707 r
F P
0 g
s
.57837 .71819 m .57981 .75504 L .55049 .7597 L p .707 .577 .707 r
F P
0 g
s
.55289 .79608 m .55792 .77775 L .58636 .7834 L p .707 .577 .707 r
F P
0 g
s
.58636 .7834 m .58133 .80173 L .55289 .79608 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57436 .81638 L p .707 .577 .707 r
F P
0 g
s
.57268 .6962 m .57288 .6406 L .60471 .63991 L p .707 .577 .707 r
F P
0 g
s
.60471 .63991 m .60451 .69552 L .57268 .6962 L p .707 .577 .707 r
F P
0 g
s
.57436 .81638 m .57436 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70128 .83591 m .69625 .85424 L .70327 .8512 L p .707 .577 .707 r
F P
0 g
s
.70327 .8512 m .7083 .83287 L .70128 .83591 L p .707 .577 .707 r
F P
0 g
s
.44371 .81885 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44371 .81885 L .48751 .82178 L p .707 .577 .707 r
F P
0 g
s
.70564 .74353 m .70708 .78038 L .70408 .77146 L p .707 .577 .707 r
F P
0 g
s
.70408 .77146 m .70264 .7346 L .70564 .74353 L p .707 .577 .707 r
F P
0 g
s
.69713 .66069 m .69693 .7163 L .68429 .70842 L p .707 .577 .707 r
F P
0 g
s
.68429 .70842 m .68448 .65282 L .69713 .66069 L p .707 .577 .707 r
F P
0 g
s
.57981 .75504 m .57837 .71819 L .61017 .71619 L p .707 .577 .707 r
F P
0 g
s
.61017 .71619 m .61162 .75305 L .57981 .75504 L p .707 .577 .707 r
F P
0 g
s
.58133 .80173 m .58636 .7834 L .6171 .7912 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .61207 .80953 L .58133 .80173 L p .707 .577 .707 r
F P
0 g
s
.57436 .31449 m .57436 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.6359 .64189 m .6357 .6975 L .60451 .69552 L p .707 .577 .707 r
F P
0 g
s
.60451 .69552 m .60471 .63991 L .6359 .64189 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .30671 L .57436 .31449 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44371 .81885 L p .707 .577 .707 r
F P
0 g
s
.25118 .71167 m .25126 .65614 L .22008 .65419 L p .707 .577 .707 r
F P
0 g
s
.25126 .65614 m .25118 .71167 L .28301 .71092 L p .707 .577 .707 r
F P
0 g
s
.28301 .71092 m .28309 .65539 L .25126 .65614 L p .707 .577 .707 r
F P
0 g
s
.7083 .83287 m .70327 .8512 L .70067 .84547 L p .707 .577 .707 r
F P
0 g
s
.70067 .84547 m .7057 .82714 L .7083 .83287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28309 .65539 m .28301 .71092 L .31237 .70752 L p .707 .577 .707 r
F P
0 g
s
.31237 .70752 m .31245 .65199 L .28309 .65539 L p .707 .577 .707 r
F P
0 g
s
.21999 .70972 m .22008 .65419 L .19259 .64972 L p .707 .577 .707 r
F P
0 g
s
.22008 .65419 m .21999 .70972 L .25118 .71167 L p .707 .577 .707 r
F P
0 g
s
.70264 .7346 m .70408 .77146 L .6914 .76358 L p .707 .577 .707 r
F P
0 g
s
.6914 .76358 m .68996 .72673 L .70264 .7346 L p .707 .577 .707 r
F P
0 g
s
.68448 .65282 m .68429 .70842 L .66319 .70194 L p .707 .577 .707 r
F P
0 g
s
.66319 .70194 m .66338 .64634 L .68448 .65282 L p .707 .577 .707 r
F P
0 g
s
.64135 .71705 m .64279 .75391 L .61162 .75305 L p .707 .577 .707 r
F P
0 g
s
.61162 .75305 m .61017 .71619 L .64135 .71705 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .64715 .80039 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61207 .80953 m .61249 .80803 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61249 .80803 m .6171 .7912 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.66338 .64634 m .66319 .70194 L .6357 .6975 L p .707 .577 .707 r
F P
0 g
s
.6357 .6975 m .6359 .64189 L .66338 .64634 L p .707 .577 .707 r
F P
0 g
s
.66884 .72068 m .67028 .75754 L .64279 .75391 L p .707 .577 .707 r
F P
0 g
s
.64279 .75391 m .64135 .71705 L .66884 .72068 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .6437 .78657 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .31285 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .31285 m .63281 .79832 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.60892 .30671 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .30671 L p .707 .577 .707 r
F P
0 g
s
.31245 .65199 m .31237 .70752 L .33638 .70182 L p .707 .577 .707 r
F P
0 g
s
.33638 .70182 m .33646 .6463 L .31245 .65199 L p .707 .577 .707 r
F P
0 g
s
.25445 .77005 m .25383 .73264 L .22264 .73151 L p .707 .577 .707 r
F P
0 g
s
.25383 .73264 m .25445 .77005 L .28628 .76885 L p .707 .577 .707 r
F P
0 g
s
.28628 .76885 m .28566 .73144 L .25383 .73264 L p .707 .577 .707 r
F P
0 g
s
.28566 .73144 m .28628 .76885 L .31561 .76545 L p .707 .577 .707 r
F P
0 g
s
.31561 .76545 m .31499 .72804 L .28566 .73144 L p .707 .577 .707 r
F P
0 g
s
.19259 .64972 m .1925 .70525 L .21999 .70972 L p .707 .577 .707 r
F P
0 g
s
.22326 .76892 m .22264 .73151 L .19513 .72817 L p .707 .577 .707 r
F P
0 g
s
.22264 .73151 m .22326 .76892 L .25445 .77005 L p .707 .577 .707 r
F P
0 g
s
.1925 .70525 m .19259 .64972 L .17149 .64317 L p .707 .577 .707 r
F P
0 g
s
.31499 .72804 m .31561 .76545 L .33959 .76017 L p .707 .577 .707 r
F P
0 g
s
.33959 .76017 m .33897 .72276 L .31499 .72804 L p .707 .577 .707 r
F P
0 g
s
.7057 .82714 m .70067 .84547 L .6887 .83761 L p .707 .577 .707 r
F P
0 g
s
.6887 .83761 m .69373 .81928 L .7057 .82714 L p .707 .577 .707 r
F P
0 g
s
.19513 .72817 m .19575 .76558 L .22326 .76892 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.68996 .72673 m .6914 .76358 L .67028 .75754 L p .707 .577 .707 r
F P
0 g
s
.67028 .75754 m .66884 .72068 L .68996 .72673 L p .707 .577 .707 r
F P
0 g
s
.33646 .6463 m .33638 .70182 L .3527 .69438 L p .707 .577 .707 r
F P
0 g
s
.3527 .69438 m .35278 .63885 L .33646 .6463 L p .707 .577 .707 r
F P
0 g
s
.25454 .83913 m .25674 .8227 L .22573 .8161 L p .707 .577 .707 r
F P
0 g
s
.25674 .8227 m .25454 .83913 L .28615 .8407 L p .707 .577 .707 r
F P
0 g
s
.28615 .8407 m .28835 .82427 L .25674 .8227 L p .707 .577 .707 r
F P
0 g
s
.17149 .64317 m .1714 .6987 L .1925 .70525 L p .707 .577 .707 r
F P
0 g
s
.19575 .76558 m .19513 .72817 L .17399 .72293 L p .707 .577 .707 r
F P
0 g
s
.22353 .83253 m .22573 .8161 L .19837 .80512 L p .707 .577 .707 r
F P
0 g
s
.22573 .8161 m .22353 .83253 L .25454 .83913 L p .707 .577 .707 r
F P
0 g
s
.28835 .82427 m .28615 .8407 L .31527 .83707 L p .707 .577 .707 r
F P
0 g
s
.31527 .83707 m .31747 .82064 L .28835 .82427 L p .707 .577 .707 r
F P
0 g
s
.1714 .6987 m .17149 .64317 L .15884 .63518 L p .707 .577 .707 r
F P
0 g
s
.17399 .72293 m .17461 .76034 L .19575 .76558 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.33897 .72276 m .33959 .76017 L .35586 .75352 L p .707 .577 .707 r
F P
0 g
s
.35586 .75352 m .35524 .71611 L .33897 .72276 L p .707 .577 .707 r
F P
0 g
s
.19837 .80512 m .19617 .82155 L .22353 .83253 L p .707 .577 .707 r
F P
0 g
s
.19617 .82155 m .19837 .80512 L .17733 .79081 L p .707 .577 .707 r
F P
0 g
s
.31747 .82064 m .31527 .83707 L .33906 .82861 L p .707 .577 .707 r
F P
0 g
s
.33906 .82861 m .34126 .81218 L .31747 .82064 L p .707 .577 .707 r
F P
0 g
s
.69373 .81928 m .6887 .83761 L .66852 .82839 L p .707 .577 .707 r
F P
0 g
s
.66852 .82839 m .67355 .81006 L .69373 .81928 L p .707 .577 .707 r
F P
0 g
s
.15884 .63518 m .15876 .69071 L .1714 .6987 L p .707 .577 .707 r
F P
0 g
s
.17461 .76034 m .17399 .72293 L .1613 .71632 L p .707 .577 .707 r
F P
0 g
s
.35278 .63885 m .3527 .69438 L .35972 .68592 L p .707 .577 .707 r
F P
0 g
s
.35972 .68592 m .35981 .63039 L .35278 .63885 L p .707 .577 .707 r
F P
0 g
s
.17733 .79081 m .17513 .80724 L .19617 .82155 L p .707 .577 .707 r
F P
0 g
s
.1613 .71632 m .16192 .75373 L .17461 .76034 L p .707 .577 .707 r
F P
0 g
s
.35524 .71611 m .35586 .75352 L .36283 .74617 L p .707 .577 .707 r
F P
0 g
s
.36283 .74617 m .36221 .70876 L .35524 .71611 L p .707 .577 .707 r
F P
0 g
s
.35981 .63039 m .35972 .68592 L .35677 .67727 L p .707 .577 .707 r
F P
0 g
s
.35677 .67727 m .35685 .62174 L .35981 .63039 L p .707 .577 .707 r
F P
0 g
s
.35982 .73883 m .3592 .70142 L .36221 .70876 L p .707 .577 .707 r
F P
0 g
s
.36205 .80089 m .36425 .78446 L .35737 .79972 L p .707 .577 .707 r
F P
0 g
s
.36425 .78446 m .36205 .80089 L .35901 .78435 L p .707 .577 .707 r
F P
0 g
s
.35901 .78435 m .3612 .76792 L .36425 .78446 L p .707 .577 .707 r
F P
0 g
s
.3592 .70142 m .35982 .73883 L .34713 .73222 L p .707 .577 .707 r
F P
0 g
s
.34713 .73222 m .34651 .69481 L .3592 .70142 L p .707 .577 .707 r
F P
0 g
s
.3612 .76792 m .35901 .78435 L .34634 .76813 L p .707 .577 .707 r
F P
0 g
s
.34634 .76813 m .34854 .7517 L .3612 .76792 L p .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .29006 L .3563 .27798 L p .707 .577 .707 r
F P
0 g
s
.36221 .70876 m .36283 .74617 L .35982 .73883 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.17513 .80724 m .17733 .79081 L .16466 .7746 L p .707 .577 .707 r
F P
0 g
s
.15876 .69071 m .15884 .63518 L .15588 .62653 L p .707 .577 .707 r
F P
0 g
s
.34126 .81218 m .33906 .82861 L .35518 .81615 L p .707 .577 .707 r
F P
0 g
s
.35518 .81615 m .35737 .79972 L .34126 .81218 L p .707 .577 .707 r
F P
0 g
s
.67355 .81006 m .66852 .82839 L .64212 .81872 L p .707 .577 .707 r
F P
0 g
s
.64212 .81872 m .64715 .80039 L .67355 .81006 L p .707 .577 .707 r
F P
0 g
s
.16466 .7746 m .16246 .79103 L .17513 .80724 L p .707 .577 .707 r
F P
0 g
s
.15588 .62653 m .1558 .68206 L .15876 .69071 L p .707 .577 .707 r
F P
0 g
s
.16192 .75373 m .1613 .71632 L .15829 .70898 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .78657 L .64053 .77449 L p .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.16246 .79103 m .16466 .7746 L .16162 .75805 L p .707 .577 .707 r
F P
0 g
s
.64715 .80039 m .64212 .81872 L .61207 .80953 L p .707 .577 .707 r
F P
0 g
s
.35737 .79972 m .35518 .81615 L .36205 .80089 L p .707 .577 .707 r
F P
0 g
s
.15829 .70898 m .15891 .74639 L .16192 .75373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1558 .68206 m .15588 .62653 L .16291 .61807 L p .707 .577 .707 r
F P
0 g
s
.16162 .75805 m .15942 .77448 L .16246 .79103 L p .707 .577 .707 r
F P
0 g
s
.35685 .62174 m .35677 .67727 L .34412 .66928 L p .707 .577 .707 r
F P
0 g
s
.34412 .66928 m .3442 .61375 L .35685 .62174 L p .707 .577 .707 r
F P
0 g
s
.3563 .27798 m .35629 .77987 L .35947 .79195 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .3563 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16291 .61807 m .16283 .6736 L .1558 .68206 L p .707 .577 .707 r
F P
0 g
s
.15891 .74639 m .15829 .70898 L .16526 .70163 L p .707 .577 .707 r
F P
0 g
s
.15942 .77448 m .16162 .75805 L .16849 .7428 L p .707 .577 .707 r
F P
0 g
s
.16526 .70163 m .16588 .73904 L .15891 .74639 L p .707 .577 .707 r
F P
0 g
s
.16283 .6736 m .16291 .61807 L .17923 .61063 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .6236 .76326 L p .707 .577 .707 r
F P
0 g
s
.6236 .76326 m .6236 .26138 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.16849 .7428 m .16629 .75923 L .15942 .77448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17923 .61063 m .17914 .66616 L .16283 .6736 L p .707 .577 .707 r
F P
0 g
s
.3442 .61375 m .34412 .66928 L .32302 .66273 L p .707 .577 .707 r
F P
0 g
s
.32302 .66273 m .3231 .6072 L .3442 .61375 L p .707 .577 .707 r
F P
0 g
s
.16588 .73904 m .16526 .70163 L .18153 .69499 L p .707 .577 .707 r
F P
0 g
s
.16629 .75923 m .16849 .7428 L .18461 .73034 L p .707 .577 .707 r
F P
0 g
s
.36719 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36719 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18153 .69499 m .18215 .7324 L .16588 .73904 L p .707 .577 .707 r
F P
0 g
s
.17914 .66616 m .17923 .61063 L .20324 .60493 L p .707 .577 .707 r
F P
0 g
s
.18461 .73034 m .18241 .74677 L .16629 .75923 L p .707 .577 .707 r
F P
0 g
s
.34651 .69481 m .34713 .73222 L .32599 .72699 L p .707 .577 .707 r
F P
0 g
s
.32599 .72699 m .32537 .68958 L .34651 .69481 L p .707 .577 .707 r
F P
0 g
s
.3231 .6072 m .32302 .66273 L .29553 .65826 L p .707 .577 .707 r
F P
0 g
s
.29553 .65826 m .29562 .60273 L .3231 .6072 L p .707 .577 .707 r
F P
0 g
s
.6236 .26138 m .6236 .76326 L .59457 .75399 L p .707 .577 .707 r
F P
0 g
s
.59457 .75399 m .59457 .2521 L .6236 .26138 L p .707 .577 .707 r
F P
0 g
s
.20324 .60493 m .20316 .66046 L .17914 .66616 L p .707 .577 .707 r
F P
0 g
s
.18241 .74677 m .18461 .73034 L .20839 .72188 L p .707 .577 .707 r
F P
0 g
s
.34854 .7517 m .34634 .76813 L .3253 .75383 L p .707 .577 .707 r
F P
0 g
s
.3253 .75383 m .3275 .7374 L .34854 .7517 L p .707 .577 .707 r
F P
0 g
s
.18215 .7324 m .18153 .69499 L .20551 .68971 L p .707 .577 .707 r
F P
0 g
s
.20316 .66046 m .20324 .60493 L .2326 .60154 L p .707 .577 .707 r
F P
0 g
s
.20839 .72188 m .2062 .73831 L .18241 .74677 L p .707 .577 .707 r
F P
0 g
s
.20551 .68971 m .20613 .72712 L .18215 .7324 L p .707 .577 .707 r
F P
0 g
s
.73565 .65847 m .73557 .60284 L .70438 .60102 L p .707 .577 .707 r
F P
0 g
s
.73557 .60284 m .73565 .65847 L .76748 .65764 L p .707 .577 .707 r
F P
0 g
s
.76748 .65764 m .7674 .60201 L .73557 .60284 L p .707 .577 .707 r
F P
0 g
s
.29562 .60273 m .29553 .65826 L .26435 .65631 L p .707 .577 .707 r
F P
0 g
s
.26435 .65631 m .26443 .60078 L .29562 .60273 L p .707 .577 .707 r
F P
0 g
s
.32537 .68958 m .32599 .72699 L .29848 .72364 L p .707 .577 .707 r
F P
0 g
s
.29848 .72364 m .29786 .68623 L .32537 .68958 L p .707 .577 .707 r
F P
0 g
s
.7674 .60201 m .76748 .65764 L .79684 .65425 L p .707 .577 .707 r
F P
0 g
s
.79684 .65425 m .79676 .59861 L .7674 .60201 L p .707 .577 .707 r
F P
0 g
s
.23252 .65707 m .2326 .60154 L .26443 .60078 L p .707 .577 .707 r
F P
0 g
s
.2326 .60154 m .23252 .65707 L .20316 .66046 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36719 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42564 .24816 L p .707 .577 .707 r
F P
0 g
s
.70447 .65665 m .70438 .60102 L .67689 .59673 L p .707 .577 .707 r
F P
0 g
s
.70438 .60102 m .70447 .65665 L .73565 .65847 L p .707 .577 .707 r
F P
0 g
s
.26443 .60078 m .26435 .65631 L .23252 .65707 L p .707 .577 .707 r
F P
0 g
s
.2062 .73831 m .20839 .72188 L .23752 .71825 L p .707 .577 .707 r
F P
0 g
s
.3275 .7374 m .3253 .75383 L .29794 .74284 L p .707 .577 .707 r
F P
0 g
s
.29794 .74284 m .30013 .72641 L .3275 .7374 L p .707 .577 .707 r
F P
0 g
s
.20613 .72712 m .20551 .68971 L .23484 .6863 L p .707 .577 .707 r
F P
0 g
s
.79676 .59861 m .79684 .65425 L .82085 .64862 L p .707 .577 .707 r
F P
0 g
s
.82085 .64862 m .82077 .59299 L .79676 .59861 L p .707 .577 .707 r
F P
0 g
s
.23752 .71825 m .23532 .73468 L .2062 .73831 L p .707 .577 .707 r
F P
0 g
s
.26693 .73624 m .26913 .71981 L .30013 .72641 L p .707 .577 .707 r
F P
0 g
s
.26913 .71981 m .26693 .73624 L .23532 .73468 L p .707 .577 .707 r
F P
0 g
s
.29786 .68623 m .29848 .72364 L .26728 .72251 L p .707 .577 .707 r
F P
0 g
s
.23532 .73468 m .23752 .71825 L .26913 .71981 L p .707 .577 .707 r
F P
0 g
s
.26728 .72251 m .26666 .6851 L .29786 .68623 L p .707 .577 .707 r
F P
0 g
s
.23484 .6863 m .23546 .72371 L .20613 .72712 L p .707 .577 .707 r
F P
0 g
s
.59457 .2521 m .59457 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59457 .2521 L p .707 .577 .707 r
F P
0 g
s
.30013 .72641 m .29794 .74284 L .26693 .73624 L p .707 .577 .707 r
F P
0 g
s
.67689 .59673 m .67698 .65237 L .70447 .65665 L p .707 .577 .707 r
F P
0 g
s
.23546 .72371 m .23484 .6863 L .26666 .6851 L p .707 .577 .707 r
F P
0 g
s
.67698 .65237 m .67689 .59673 L .65579 .5904 L p .707 .577 .707 r
F P
0 g
s
.26666 .6851 m .26728 .72251 L .23546 .72371 L p .707 .577 .707 r
F P
0 g
s
.73271 .72076 m .73333 .68412 L .70214 .68152 L p .707 .577 .707 r
F P
0 g
s
.73333 .68412 m .73271 .72076 L .76453 .72033 L p .707 .577 .707 r
F P
0 g
s
.76453 .72033 m .76515 .68369 L .73333 .68412 L p .707 .577 .707 r
F P
0 g
s
.76515 .68369 m .76453 .72033 L .79387 .71692 L p .707 .577 .707 r
F P
0 g
s
.79387 .71692 m .79449 .68028 L .76515 .68369 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42564 .24816 L .46747 .24362 L p .707 .577 .707 r
F P
0 g
s
.42564 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.70152 .71816 m .70214 .68152 L .67463 .67615 L p .707 .577 .707 r
F P
0 g
s
.70214 .68152 m .70152 .71816 L .73271 .72076 L p .707 .577 .707 r
F P
0 g
s
.82077 .59299 m .82085 .64862 L .83717 .64131 L p .707 .577 .707 r
F P
0 g
s
.83717 .64131 m .83709 .58568 L .82077 .59299 L p .707 .577 .707 r
F P
0 g
s
.65579 .5904 m .65588 .64603 L .67698 .65237 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51249 .74466 L p .707 .577 .707 r
F P
0 g
s
.51249 .74466 m .51249 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.79449 .68028 m .79387 .71692 L .81784 .71086 L p .707 .577 .707 r
F P
0 g
s
.81784 .71086 m .81846 .67422 L .79449 .68028 L p .707 .577 .707 r
F P
0 g
s
.65588 .64603 m .65579 .5904 L .64315 .58263 L p .707 .577 .707 r
F P
0 g
s
.67463 .67615 m .67401 .71278 L .70152 .71816 L p .707 .577 .707 r
F P
0 g
s
.73307 .73286 m .73087 .71375 L .69986 .71727 L p .707 .577 .707 r
F P
0 g
s
.73087 .71375 m .73307 .73286 L .76468 .7292 L p .707 .577 .707 r
F P
0 g
s
.76468 .7292 m .76248 .71009 L .73087 .71375 L p .707 .577 .707 r
F P
0 g
s
.69986 .71727 m .70206 .73637 L .73307 .73286 L p .707 .577 .707 r
F P
0 g
s
.76248 .71009 m .76468 .7292 L .7938 .72575 L p .707 .577 .707 r
F P
0 g
s
.7938 .72575 m .7916 .70665 L .76248 .71009 L p .707 .577 .707 r
F P
0 g
s
.46747 .74551 m .46747 .24362 L .51249 .24277 L p .707 .577 .707 r
F P
0 g
s
.46747 .24362 m .46747 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.67401 .71278 m .67463 .67615 L .65349 .66853 L p .707 .577 .707 r
F P
0 g
s
.51249 .24277 m .51249 .74466 L .46747 .74551 L p .707 .577 .707 r
F P
0 g
s
.70206 .73637 m .69986 .71727 L .6725 .72029 L p .707 .577 .707 r
F P
0 g
s
.6725 .72029 m .6747 .7394 L .70206 .73637 L p .707 .577 .707 r
F P
0 g
s
.64315 .58263 m .64323 .63827 L .65588 .64603 L p .707 .577 .707 r
F P
0 g
s
.83709 .58568 m .83717 .64131 L .8442 .63304 L p .707 .577 .707 r
F P
0 g
s
.8442 .63304 m .84411 .5774 L .83709 .58568 L p .707 .577 .707 r
F P
0 g
s
.65349 .66853 m .65287 .70517 L .67401 .71278 L p .707 .577 .707 r
F P
0 g
s
.7916 .70665 m .7938 .72575 L .81759 .72286 L p .707 .577 .707 r
F P
0 g
s
.81759 .72286 m .81539 .70375 L .7916 .70665 L p .707 .577 .707 r
F P
0 g
s
.81846 .67422 m .81784 .71086 L .83411 .70274 L p .707 .577 .707 r
F P
0 g
s
.83411 .70274 m .83473 .6661 L .81846 .67422 L p .707 .577 .707 r
F P
0 g
s
.6747 .7394 m .6725 .72029 L .65146 .72253 L p .707 .577 .707 r
F P
0 g
s
.65146 .72253 m .65366 .74164 L .6747 .7394 L p .707 .577 .707 r
F P
0 g
s
.65287 .70517 m .65349 .66853 L .6408 .65941 L p .707 .577 .707 r
F P
0 g
s
.64323 .63827 m .64315 .58263 L .64019 .5742 L p .707 .577 .707 r
F P
0 g
s
.81539 .70375 m .81759 .72286 L .83371 .72079 L p .707 .577 .707 r
F P
0 g
s
.83371 .72079 m .83151 .70169 L .81539 .70375 L p .707 .577 .707 r
F P
0 g
s
.6408 .65941 m .64018 .69605 L .65287 .70517 L p .707 .577 .707 r
F P
0 g
s
.64019 .5742 m .64028 .62983 L .64323 .63827 L p .707 .577 .707 r
F P
0 g
s
.83473 .6661 m .83411 .70274 L .84109 .69335 L p .707 .577 .707 r
F P
0 g
s
.84109 .69335 m .84171 .65672 L .83473 .6661 L p .707 .577 .707 r
F P
0 g
s
.84411 .5774 m .8442 .63304 L .84124 .6246 L p .707 .577 .707 r
F P
0 g
s
.84124 .6246 m .84116 .56897 L .84411 .5774 L p .707 .577 .707 r
F P
0 g
s
.65366 .74164 m .65146 .72253 L .63879 .72377 L p .707 .577 .707 r
F P
0 g
s
.63879 .72377 m .64099 .74287 L .65366 .74164 L p .707 .577 .707 r
F P
0 g
s
.64018 .69605 m .6408 .65941 L .63779 .64968 L p .707 .577 .707 r
F P
0 g
s
.64028 .62983 m .64019 .5742 L .64722 .56592 L p .707 .577 .707 r
F P
0 g
s
.83151 .70169 m .83371 .72079 L .84058 .71977 L p .707 .577 .707 r
F P
0 g
s
.84058 .71977 m .83838 .70066 L .83151 .70169 L p .707 .577 .707 r
F P
0 g
s
.63779 .64968 m .63717 .68632 L .64018 .69605 L p .707 .577 .707 r
F P
0 g
s
.64722 .56592 m .6473 .62156 L .64028 .62983 L p .707 .577 .707 r
F P
0 g
s
.84171 .65672 m .84109 .69335 L .83808 .68363 L p .707 .577 .707 r
F P
0 g
s
.83808 .68363 m .8387 .64699 L .84171 .65672 L p .707 .577 .707 r
F P
0 g
s
.84116 .56897 m .84124 .6246 L .8286 .61684 L p .707 .577 .707 r
F P
0 g
s
.8286 .61684 m .82851 .56121 L .84116 .56897 L p .707 .577 .707 r
F P
0 g
s
.64099 .74287 m .63879 .72377 L .63575 .72387 L p .707 .577 .707 r
F P
0 g
s
.63575 .72387 m .63795 .74298 L .64099 .74287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63717 .68632 m .63779 .64968 L .64476 .6403 L p .707 .577 .707 r
F P
0 g
s
.6473 .62156 m .64722 .56592 L .66353 .55861 L p .707 .577 .707 r
F P
0 g
s
.39548 .62024 m .39529 .56468 L .3641 .56289 L p .707 .577 .707 r
F P
0 g
s
.39529 .56468 m .39548 .62024 L .42731 .61934 L p .707 .577 .707 r
F P
0 g
s
.42731 .61934 m .42712 .56378 L .39529 .56468 L p .707 .577 .707 r
F P
0 g
s
.42712 .56378 m .42731 .61934 L .45667 .61583 L p .707 .577 .707 r
F P
0 g
s
.45667 .61583 m .45648 .56027 L .42712 .56378 L p .707 .577 .707 r
F P
0 g
s
.83838 .70066 m .84058 .71977 L .83753 .71987 L p .707 .577 .707 r
F P
0 g
s
.83753 .71987 m .83534 .70077 L .83838 .70066 L p .707 .577 .707 r
F P
0 g
s
.64476 .6403 m .64414 .67694 L .63717 .68632 L p .707 .577 .707 r
F P
0 g
s
.3643 .61845 m .3641 .56289 L .33661 .55857 L p .707 .577 .707 r
F P
0 g
s
.3641 .56289 m .3643 .61845 L .39548 .62024 L p .707 .577 .707 r
F P
0 g
s
.66353 .55861 m .66362 .61425 L .6473 .62156 L p .707 .577 .707 r
F P
0 g
s
.8387 .64699 m .83808 .68363 L .82539 .67451 L p .707 .577 .707 r
F P
0 g
s
.82539 .67451 m .82601 .63787 L .8387 .64699 L p .707 .577 .707 r
F P
0 g
s
.82851 .56121 m .8286 .61684 L .8075 .61051 L p .707 .577 .707 r
F P
0 g
s
.8075 .61051 m .80741 .55487 L .82851 .56121 L p .707 .577 .707 r
F P
0 g
s
.45648 .56027 m .45667 .61583 L .48069 .61006 L p .707 .577 .707 r
F P
0 g
s
.48069 .61006 m .48049 .5545 L .45648 .56027 L p .707 .577 .707 r
F P
0 g
s
.63795 .74298 m .63575 .72387 L .64262 .72285 L p .707 .577 .707 r
F P
0 g
s
.64262 .72285 m .64482 .74195 L .63795 .74298 L p .707 .577 .707 r
F P
0 g
s
.38838 .67943 m .38983 .64224 L .35865 .63934 L p .707 .577 .707 r
F P
0 g
s
.38983 .64224 m .38838 .67943 L .42019 .67983 L p .707 .577 .707 r
F P
0 g
s
.42019 .67983 m .42163 .64264 L .38983 .64224 L p .707 .577 .707 r
F P
0 g
s
.64414 .67694 m .64476 .6403 L .66103 .63218 L p .707 .577 .707 r
F P
0 g
s
.42163 .64264 m .42019 .67983 L .44951 .67769 L p .707 .577 .707 r
F P
0 g
s
.44951 .67769 m .45095 .6405 L .42163 .64264 L p .707 .577 .707 r
F P
0 g
s
.33661 .55857 m .33681 .61413 L .3643 .61845 L p .707 .577 .707 r
F P
0 g
s
.66362 .61425 m .66353 .55861 L .68755 .55299 L p .707 .577 .707 r
F P
0 g
s
.33681 .61413 m .33661 .55857 L .31551 .55217 L p .707 .577 .707 r
F P
0 g
s
.35721 .67654 m .35865 .63934 L .33116 .63423 L p .707 .577 .707 r
F P
0 g
s
.35865 .63934 m .35721 .67654 L .38838 .67943 L p .707 .577 .707 r
F P
0 g
s
.66103 .63218 m .66041 .66882 L .64414 .67694 L p .707 .577 .707 r
F P
0 g
s
.45095 .6405 m .44951 .67769 L .47347 .67322 L p .707 .577 .707 r
F P
0 g
s
.47347 .67322 m .47492 .63603 L .45095 .6405 L p .707 .577 .707 r
F P
0 g
s
.83534 .70077 m .83753 .71987 L .82487 .72111 L p .707 .577 .707 r
F P
0 g
s
.82487 .72111 m .82267 .702 L .83534 .70077 L p .707 .577 .707 r
F P
0 g
s
.80741 .55487 m .8075 .61051 L .78001 .60622 L p .707 .577 .707 r
F P
0 g
s
.78001 .60622 m .77992 .55058 L .80741 .55487 L p .707 .577 .707 r
F P
0 g
s
.48049 .5545 m .48069 .61006 L .497 .60259 L p .707 .577 .707 r
F P
0 g
s
.497 .60259 m .49681 .54703 L .48049 .5545 L p .707 .577 .707 r
F P
0 g
s
.33116 .63423 m .32972 .67142 L .35721 .67654 L p .707 .577 .707 r
F P
0 g
s
.68755 .55299 m .68763 .60862 L .66362 .61425 L p .707 .577 .707 r
F P
0 g
s
.41867 .72664 m .41364 .70944 L .38289 .71817 L p .707 .577 .707 r
F P
0 g
s
.41364 .70944 m .41867 .72664 L .4471 .71485 L p .707 .577 .707 r
F P
0 g
s
.4471 .71485 m .44207 .69764 L .41364 .70944 L p .707 .577 .707 r
F P
0 g
s
.31551 .55217 m .31571 .60773 L .33681 .61413 L p .707 .577 .707 r
F P
0 g
s
.38792 .73538 m .38289 .71817 L .35285 .72298 L p .707 .577 .707 r
F P
0 g
s
.38289 .71817 m .38792 .73538 L .41867 .72664 L p .707 .577 .707 r
F P
0 g
s
.82601 .63787 m .82539 .67451 L .80425 .66689 L p .707 .577 .707 r
F P
0 g
s
.80425 .66689 m .80487 .63025 L .82601 .63787 L p .707 .577 .707 r
F P
0 g
s
.32972 .67142 m .33116 .63423 L .31004 .6274 L p .707 .577 .707 r
F P
0 g
s
.68763 .60862 m .68755 .55299 L .71691 .54959 L p .707 .577 .707 r
F P
0 g
s
.35285 .72298 m .35788 .74019 L .38792 .73538 L p .707 .577 .707 r
F P
0 g
s
.31571 .60773 m .31551 .55217 L .30287 .54429 L p .707 .577 .707 r
F P
0 g
s
.44207 .69764 m .4471 .71485 L .47045 .70114 L p .707 .577 .707 r
F P
0 g
s
.47045 .70114 m .46542 .68393 L .44207 .69764 L p .707 .577 .707 r
F P
0 g
s
.64482 .74195 m .64262 .72285 L .65874 .72078 L p .707 .577 .707 r
F P
0 g
s
.65874 .72078 m .66094 .73989 L .64482 .74195 L p .707 .577 .707 r
F P
0 g
s
.35788 .74019 m .35285 .72298 L .32645 .72341 L p .707 .577 .707 r
F P
0 g
s
.66041 .66882 m .66103 .63218 L .68501 .62612 L p .707 .577 .707 r
F P
0 g
s
.31004 .6274 m .3086 .66459 L .32972 .67142 L p .707 .577 .707 r
F P
0 g
s
.77992 .55058 m .78001 .60622 L .74882 .6044 L p .707 .577 .707 r
F P
0 g
s
.74882 .6044 m .74874 .54877 L .77992 .55058 L p .707 .577 .707 r
F P
0 g
s
.71699 .60523 m .71691 .54959 L .74874 .54877 L p .707 .577 .707 r
F P
0 g
s
.71691 .54959 m .71699 .60523 L .68763 .60862 L p .707 .577 .707 r
F P
0 g
s
.32645 .72341 m .33148 .74062 L .35788 .74019 L p .707 .577 .707 r
F P
0 g
s
.47492 .63603 m .47347 .67322 L .48974 .66686 L p .707 .577 .707 r
F P
0 g
s
.48974 .66686 m .49118 .62967 L .47492 .63603 L p .707 .577 .707 r
F P
0 g
s
.74874 .54877 m .74882 .6044 L .71699 .60523 L p .707 .577 .707 r
F P
0 g
s
.68501 .62612 m .68439 .66276 L .66041 .66882 L p .707 .577 .707 r
F P
0 g
s
.30287 .54429 m .30306 .59985 L .31571 .60773 L p .707 .577 .707 r
F P
0 g
s
.49681 .54703 m .497 .60259 L .50403 .59416 L p .707 .577 .707 r
F P
0 g
s
.50403 .59416 m .50383 .5386 L .49681 .54703 L p .707 .577 .707 r
F P
0 g
s
.80487 .63025 m .80425 .66689 L .77674 .66152 L p .707 .577 .707 r
F P
0 g
s
.77674 .66152 m .77736 .62488 L .80487 .63025 L p .707 .577 .707 r
F P
0 g
s
.46542 .68393 m .47045 .70114 L .48641 .68687 L p .707 .577 .707 r
F P
0 g
s
.48641 .68687 m .48138 .66966 L .46542 .68393 L p .707 .577 .707 r
F P
0 g
s
.3086 .66459 m .31004 .6274 L .29736 .61953 L p .707 .577 .707 r
F P
0 g
s
.82267 .702 m .82487 .72111 L .80383 .72335 L p .707 .577 .707 r
F P
0 g
s
.80383 .72335 m .80163 .70424 L .82267 .702 L p .707 .577 .707 r
F P
0 g
s
.33148 .74062 m .32645 .72341 L .30627 .7194 L p .707 .577 .707 r
F P
0 g
s
.68439 .66276 m .68501 .62612 L .71434 .62271 L p .707 .577 .707 r
F P
0 g
s
.30627 .7194 m .3113 .73661 L .33148 .74062 L p .707 .577 .707 r
F P
0 g
s
.29736 .61953 m .29592 .65672 L .3086 .66459 L p .707 .577 .707 r
F P
0 g
s
.30306 .59985 m .30287 .54429 L .29991 .53571 L p .707 .577 .707 r
F P
0 g
s
.66094 .73989 m .65874 .72078 L .68253 .71789 L p .707 .577 .707 r
F P
0 g
s
.68253 .71789 m .68472 .73699 L .66094 .73989 L p .707 .577 .707 r
F P
0 g
s
.77736 .62488 m .77674 .66152 L .74554 .65892 L p .707 .577 .707 r
F P
0 g
s
.74554 .65892 m .74616 .62228 L .77736 .62488 L p .707 .577 .707 r
F P
0 g
s
.71434 .62271 m .71372 .65935 L .68439 .66276 L p .707 .577 .707 r
F P
0 g
s
.71372 .65935 m .71434 .62271 L .74616 .62228 L p .707 .577 .707 r
F P
0 g
s
.49118 .62967 m .48974 .66686 L .49672 .65923 L p .707 .577 .707 r
F P
0 g
s
.49672 .65923 m .49816 .62204 L .49118 .62967 L p .707 .577 .707 r
F P
0 g
s
.74616 .62228 m .74554 .65892 L .71372 .65935 L p .707 .577 .707 r
F P
0 g
s
.48138 .66966 m .48641 .68687 L .49344 .67342 L p .707 .577 .707 r
F P
0 g
s
.49344 .67342 m .48841 .65622 L .48138 .66966 L p .707 .577 .707 r
F P
0 g
s
.80163 .70424 m .80383 .72335 L .77646 .72637 L p .707 .577 .707 r
F P
0 g
s
.77646 .72637 m .77427 .70727 L .80163 .70424 L p .707 .577 .707 r
F P
0 g
s
.29991 .53571 m .30011 .59127 L .30306 .59985 L p .707 .577 .707 r
F P
0 g
s
.3113 .73661 m .30627 .7194 L .29429 .71136 L p .707 .577 .707 r
F P
0 g
s
.50383 .5386 m .50403 .59416 L .50107 .58558 L p .707 .577 .707 r
F P
0 g
s
.50107 .58558 m .50088 .53002 L .50383 .5386 L p .707 .577 .707 r
F P
0 g
s
.29592 .65672 m .29736 .61953 L .29436 .61137 L p .707 .577 .707 r
F P
0 g
s
.68472 .73699 m .68253 .71789 L .71165 .71444 L p .707 .577 .707 r
F P
0 g
s
.71165 .71444 m .71385 .73355 L .68472 .73699 L p .707 .577 .707 r
F P
0 g
s
.29429 .71136 m .29932 .72856 L .3113 .73661 L p .707 .577 .707 r
F P
0 g
s
.29436 .61137 m .29292 .64857 L .29592 .65672 L p .707 .577 .707 r
F P
0 g
s
.30011 .59127 m .29991 .53571 L .30694 .52728 L p .707 .577 .707 r
F P
0 g
s
.77427 .70727 m .77646 .72637 L .74546 .72989 L p .707 .577 .707 r
F P
0 g
s
.74546 .72989 m .74326 .71078 L .77427 .70727 L p .707 .577 .707 r
F P
0 g
s
.71385 .73355 m .71165 .71444 L .74326 .71078 L p .707 .577 .707 r
F P
0 g
s
.74326 .71078 m .74546 .72989 L .71385 .73355 L p .707 .577 .707 r
F P
0 g
s
.49816 .62204 m .49672 .65923 L .49372 .65107 L p .707 .577 .707 r
F P
0 g
s
.49372 .65107 m .49516 .61388 L .49816 .62204 L p .707 .577 .707 r
F P
0 g
s
.48841 .65622 m .49344 .67342 L .49084 .66213 L p .707 .577 .707 r
F P
0 g
s
.49084 .66213 m .48581 .64492 L .48841 .65622 L p .707 .577 .707 r
F P
0 g
s
.29932 .72856 m .29429 .71136 L .29169 .70006 L p .707 .577 .707 r
F P
0 g
s
.30694 .52728 m .30713 .58284 L .30011 .59127 L p .707 .577 .707 r
F P
0 g
s
.50088 .53002 m .50107 .58558 L .48843 .5777 L p .707 .577 .707 r
F P
0 g
s
.48843 .5777 m .48823 .52214 L .50088 .53002 L p .707 .577 .707 r
F P
0 g
s
.29292 .64857 m .29436 .61137 L .30134 .60374 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29169 .70006 m .29672 .71727 L .29932 .72856 L p .707 .577 .707 r
F P
0 g
s
.30134 .60374 m .29989 .64094 L .29292 .64857 L p .707 .577 .707 r
F P
0 g
s
.30713 .58284 m .30694 .52728 L .32325 .51981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48581 .64492 m .49084 .66213 L .47886 .65408 L p .707 .577 .707 r
F P
0 g
s
.47886 .65408 m .47383 .63687 L .48581 .64492 L p .707 .577 .707 r
F P
0 g
s
.49516 .61388 m .49372 .65107 L .48104 .6432 L p .707 .577 .707 r
F P
0 g
s
.48104 .6432 m .48248 .60601 L .49516 .61388 L p .707 .577 .707 r
F P
0 g
s
.29672 .71727 m .29169 .70006 L .29872 .68661 L p .707 .577 .707 r
F P
0 g
s
.32325 .51981 m .32345 .57537 L .30713 .58284 L p .707 .577 .707 r
F P
0 g
s
.48823 .52214 m .48843 .5777 L .46733 .57129 L p .707 .577 .707 r
F P
0 g
s
.46733 .57129 m .46713 .51573 L .48823 .52214 L p .707 .577 .707 r
F P
0 g
s
.29989 .64094 m .30134 .60374 L .3176 .59738 L p .707 .577 .707 r
F P
0 g
s
.29872 .68661 m .30375 .70382 L .29672 .71727 L p .707 .577 .707 r
F P
0 g
s
.32345 .57537 m .32325 .51981 L .34727 .51404 L p .707 .577 .707 r
F P
0 g
s
.3176 .59738 m .31616 .63457 L .29989 .64094 L p .707 .577 .707 r
F P
0 g
s
.47383 .63687 m .47886 .65408 L .45868 .65007 L p .707 .577 .707 r
F P
0 g
s
.45868 .65007 m .45365 .63287 L .47383 .63687 L p .707 .577 .707 r
F P
0 g
s
.48248 .60601 m .48104 .6432 L .45992 .63637 L p .707 .577 .707 r
F P
0 g
s
.45992 .63637 m .46136 .59918 L .48248 .60601 L p .707 .577 .707 r
F P
0 g
s
.46713 .51573 m .46733 .57129 L .43984 .56698 L p .707 .577 .707 r
F P
0 g
s
.43984 .56698 m .43964 .51142 L .46713 .51573 L p .707 .577 .707 r
F P
0 g
s
.34727 .51404 m .34746 .5696 L .32345 .57537 L p .707 .577 .707 r
F P
0 g
s
.30375 .70382 m .29872 .68661 L .31468 .67234 L p .707 .577 .707 r
F P
0 g
s
.31616 .63457 m .3176 .59738 L .34157 .59291 L p .707 .577 .707 r
F P
0 g
s
.34746 .5696 m .34727 .51404 L .37663 .51053 L p .707 .577 .707 r
F P
0 g
s
.31468 .67234 m .31971 .68955 L .30375 .70382 L p .707 .577 .707 r
F P
0 g
s
.43964 .51142 m .43984 .56698 L .40865 .56519 L p .707 .577 .707 r
F P
0 g
s
.40865 .56519 m .40846 .50963 L .43964 .51142 L p .707 .577 .707 r
F P
0 g
s
.34157 .59291 m .34013 .6301 L .31616 .63457 L p .707 .577 .707 r
F P
0 g
s
.37682 .56609 m .37663 .51053 L .40846 .50963 L p .707 .577 .707 r
F P
0 g
s
.37663 .51053 m .37682 .56609 L .34746 .5696 L p .707 .577 .707 r
F P
0 g
s
.45365 .63287 m .45868 .65007 L .43228 .6505 L p .707 .577 .707 r
F P
0 g
s
.43228 .6505 m .42725 .63329 L .45365 .63287 L p .707 .577 .707 r
F P
0 g
s
.46136 .59918 m .45992 .63637 L .43243 .63126 L p .707 .577 .707 r
F P
0 g
s
.43243 .63126 m .43387 .59407 L .46136 .59918 L p .707 .577 .707 r
F P
0 g
s
.40846 .50963 m .40865 .56519 L .37682 .56609 L p .707 .577 .707 r
F P
0 g
s
.34013 .6301 m .34157 .59291 L .37089 .59077 L p .707 .577 .707 r
F P
0 g
s
.31971 .68955 m .31468 .67234 L .33803 .65864 L p .707 .577 .707 r
F P
0 g
s
.33803 .65864 m .34306 .67584 L .31971 .68955 L p .707 .577 .707 r
F P
0 g
s
.43387 .59407 m .43243 .63126 L .40125 .62836 L p .707 .577 .707 r
F P
0 g
s
.40125 .62836 m .4027 .59117 L .43387 .59407 L p .707 .577 .707 r
F P
0 g
s
.37089 .59077 m .36945 .62796 L .34013 .6301 L p .707 .577 .707 r
F P
0 g
s
.36945 .62796 m .37089 .59077 L .4027 .59117 L p .707 .577 .707 r
F P
0 g
s
.42725 .63329 m .43228 .6505 L .40224 .65531 L p .707 .577 .707 r
F P
0 g
s
.40224 .65531 m .39721 .63811 L .42725 .63329 L p .707 .577 .707 r
F P
0 g
s
.4027 .59117 m .40125 .62836 L .36945 .62796 L p .707 .577 .707 r
F P
0 g
s
.34306 .67584 m .33803 .65864 L .36646 .64684 L p .707 .577 .707 r
F P
0 g
s
.36646 .64684 m .37149 .66405 L .34306 .67584 L p .707 .577 .707 r
F P
0 g
s
.39721 .63811 m .40224 .65531 L .37149 .66405 L p .707 .577 .707 r
F P
0 g
s
.37149 .66405 m .36646 .64684 L .39721 .63811 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH:000;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`03001JEP0000P000AJEP04001JEUYFFUH80004FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005mo
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`@000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00008000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00FGoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001GOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00mooaT003aoo`00EGoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH6000fOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`02Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF009JEPX000QJEPP000=JEP03001JEUYF00=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000=JEP04001JEUYFFUH90008FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001E
Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP0200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo
0P000UYF00<005YFFUH00UYF7`0015YF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo0P000UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo0017Ool90006Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003ioo`T000AJEP03001JEUYF009JEPL000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000=JEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00=Woo200015YF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000eYF001JEP06FUH80004FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000bOol40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF0000;Goo000`Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH6
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF
001JEP02FUH00`00Oomoo`0[Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003
FUH00`00Oomoo`0[Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000=JEP00Ool0;7oo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEPT000AJEP04001JEUYFFUH60004FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000@000IJEP07001JEUYFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJ
EUYF2@000UYF00<005YFFUH00eYF1@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH50003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF2@000eYF00@005YFFUH000EJEPD0009JEPP00003
FUH0000000@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000eYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00000`000eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P00
1EYF00@005YFFUIJEPP000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF009J
EP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00001JEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03
001JEUYF009JEPD00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP@002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40008FUH0
0`00FUIJEP05FUH;0003FUH00`00FUIJEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP80009JEP03001JEUYF00MJEP03001JEUYF00@0
00MJEP04001JEUYFFUH300000eYF001JEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP04001JEUYF0005FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00=J
EPL000QJEPD000AJEPP000EJEP03001JEUYF008000MJEP03001JEUYF00@000MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH015YF0P0015YF100025YF0`00
0UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUH005YF008000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YF
FUH00eYF1P004Goo200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF0000
0eYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1P000UYF00<0
05YFFUH015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUH0000300000eYF001JEP02FUH00`00Oomoo`08Ool3000<Ool60004FUH0
1000FUIJEUYF0P00;Goo000/Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJEP04001JEUYFFUH20007FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000EJEP05001J
EUYFFUH00009Ool5000AOol300000eYF001JEP02FUH2000]Ool002aoo`03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000MJEP03001JEP00
008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH50004FUH0
1@00FUIJEUYF00002Goo1@004Woo10000eYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH90004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH7000015YF001JEP000UYF00<005YF00001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH50003FUH00`00Oomoo`07
Ool5000>Ool400001EYF001JEUYF00000UYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP04FUH2
0003FUH20002FUH00`00FUH0000A0008FUH20003FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
00Eoo`<000Yoo`D000EJEP04001JEUYFFUH4000]Ool002aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEPX000AJEP03001JEUYF009JEP03001JEUYF00<000AJEP80009JEP03
001JEUYF00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP02FUH50005FUH30002FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool01000FUIJEP001EYF2@000eYF00<005YFFUH01UYF
00<005YFFUH01EYF0P001EYF1P0015YF0P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Woo0`0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00@005YFFUH0009JEPL0009JEP03001JEUYF00AJEP<000IJEP03001JEUYF00=JEP80
00EJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YF
FUIJEP0000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP06001JEP00001JEP001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2000;Woo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJ
EUYF00001EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP<0
00AJEP03001JEUYF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH:0002FUH01000FUIJEUYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00L005YFFUIJEP00FUH0000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP`000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP08FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF0`001UYF00@005YFFUIJEPd0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP8000AJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00IJEPl000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000MJEP03001J
EP0000<0009JEP03001JEUYF00=JEP04001JEUYF0002FUH60008FUH00`00FUIJEP03FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP0>0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQH0
009JEP03001JEUYF00l000=JEP03001JEUYF00QJEP03001JEP00008000QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP`0031oo`00;Goo
00<005YF00000eYF00<005YFFUH00eYF1P000eYF00<005YFFUH01eYF00<005YFFUH015YF0`0000=J
EP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000hOol002eoo`03001J
EP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl003moo`00;Goo00<005YF
00000eYF0P001EYF00<005YFFUH00UYF200015YF00<005YFFUH01eYF100015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUH>0018Ool002eoo`04001JEP00FUH200000eYF001JEP03FUH70007FUH70006FUH01000
FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003
FUH01000FUIJEUYF3@00DGoo000]Ool01000FUH000000UYF00@005YFFUIJEP8000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEPl000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF3P000UYF0P00E7oo000]Ool30003FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH50007FUH01000FUIJEP0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00MJEQH000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002eoo`<000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF009JEP80009JEP04001JEUYF0006FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00E7oo000]Ool30002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
00000eYF001JEP05FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60002FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol002eoo`03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000006
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00D0
05YFFUIJEP0005Aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP<0009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP04001oogooOol60004FUH01@00FUIJEUYF0000E7oo000]Ool01000FUH0
07oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<0
07ooOol01goo0`0000=JEP00FUH00UYF00<007ooOol0DWoo000]Ool20005Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003Ool30002FUH01@00FUIJEP00FUH00P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<007ooOol017oo0`0000=JEP00FUH00P000eYF00<007ooOol0DWoo000]
Ool2000<OolK000<Ool01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
1`0015YF00@005YFFUIJEP800003FUH007oo05=oo`00;Goo0P006Goo0`0067oo00D005YF001JEP00
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00=JEP03001JEUYF009JEP<0
05Aoo`00;Goo0P0067oo1@0067oo0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Aoo`00;Goo0`005goo1@0067oo0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEP0005Aoo`00;Goo0P0000=JEP00Ool05Goo1@006Goo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYFFUH2001EOol002ioo`04
001JEUYF000FOol3000JOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00;Woo00D005YFFUIJEP0003=oo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP05001JEUYFFUH0
001FOol002moo`03001JEUYF00<0035oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000IJEP03001JEUYF00AJEP04001JEP00001GOol002moo`04001JEUYF0002FUH00`00Oomoo`0]
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP03FUH3001IOol0031o
o`8000AJEP8002eoo`80009oo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP80009JEP<0009JEP03001JEP0000<0
05aoo`00<7oo0P001UYF00<007ooOol0:Goo0`0017oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00<005YF
00000`00H7oo000aOol00`00FUIJEP04FUH3000WOol200000eYF001oo`06Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30008FUH0
1000FUIJEUYF0`00Ggoo000bOol20004FUH00`00FUIJEP02000SOol20002FUH20009Ool300000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP05FUH3001LOol003Aoo`04001JEUYF0005FUH2000OOol200001EYF001JEUYF0000
3Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000020000Woo
10000UYF00<005YFFUH01UYF00<005YF00000P00FGoo000eOol30007FUH5000HOol20003FUH01000
FUIJEP0057oo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF1`000UYF1`001Woo10001eYF00<0
05YFFUH00UYF0P00Egoo000gOol20007FUH01000FUIJEUYF2@002Goo1P0015YF00@005YFFUH0021o
oaX000=JEP03001JEUYF00EJEPD000Yoo`8000AJEP03001JEUYF00AJEP8005Ioo`00>Goo0P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF0`00>Woo0`0000=JEP00FUH0
1eYF0`0000=JEP0000000P0027oo0`0000=JEP00FUH015YF00@005YFFUH005Eoo`00>goo0`0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00?goo0`001eYF00<0
05YFFUH01EYF1P001Goo0P001EYF00D005YFFUIJEP0005Aoo`00?Woo10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8004Aoo`8000EJEP03001JEUYF00MJEP04001JEUYFFUH90003
FUH01000FUIJEUYF0P00Dgoo0012Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0
0000B7oo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01@0015YF0P00Dgoo0016Ool7
0004FUH00`00FUIJEP02FUH5001=Ool40007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2
001DOol004eoo`T005Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP02
001DOol00;1oo`@000MJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00]7oo10000UYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH0001EOol00;Qooa0005Eoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60091 .74909 m .60071 .69353 L .56955 .6917 L p .707 .577 .707 r
F P
0 g
s
.60071 .69353 m .60091 .74909 L .63275 .74822 L p .707 .577 .707 r
F P
0 g
s
.63275 .74822 m .63255 .69266 L .60071 .69353 L p .707 .577 .707 r
F P
0 g
s
.63255 .69266 m .63275 .74822 L .66216 .74474 L p .707 .577 .707 r
F P
0 g
s
.66216 .74474 m .66196 .68918 L .63255 .69266 L p .707 .577 .707 r
F P
0 g
s
.56975 .74726 m .56955 .6917 L .54213 .68736 L p .707 .577 .707 r
F P
0 g
s
.56955 .6917 m .56975 .74726 L .60091 .74909 L p .707 .577 .707 r
F P
0 g
s
.66196 .68918 m .66216 .74474 L .68625 .73899 L p .707 .577 .707 r
F P
0 g
s
.68625 .73899 m .68605 .68343 L .66196 .68918 L p .707 .577 .707 r
F P
0 g
s
.5935 .80827 m .59494 .77108 L .56381 .76813 L p .707 .577 .707 r
F P
0 g
s
.59494 .77108 m .5935 .80827 L .62532 .80872 L p .707 .577 .707 r
F P
0 g
s
.62532 .80872 m .62676 .77153 L .59494 .77108 L p .707 .577 .707 r
F P
0 g
s
.62676 .77153 m .62532 .80872 L .65473 .80662 L p .707 .577 .707 r
F P
0 g
s
.65473 .80662 m .65617 .76944 L .62676 .77153 L p .707 .577 .707 r
F P
0 g
s
.54213 .68736 m .54232 .74292 L .56975 .74726 L p .707 .577 .707 r
F P
0 g
s
.54232 .74292 m .54213 .68736 L .52112 .68093 L p .707 .577 .707 r
F P
0 g
s
.56237 .80532 m .56381 .76813 L .53643 .76297 L p .707 .577 .707 r
F P
0 g
s
.56381 .76813 m .56237 .80532 L .5935 .80827 L p .707 .577 .707 r
F P
0 g
s
.65617 .76944 m .65473 .80662 L .67884 .80219 L p .707 .577 .707 r
F P
0 g
s
.67884 .80219 m .68028 .76501 L .65617 .76944 L p .707 .577 .707 r
F P
0 g
s
.68605 .68343 m .68625 .73899 L .70267 .73154 L p .707 .577 .707 r
F P
0 g
s
.70267 .73154 m .70247 .67598 L .68605 .68343 L p .707 .577 .707 r
F P
0 g
s
.53643 .76297 m .53499 .80016 L .56237 .80532 L p .707 .577 .707 r
F P
0 g
s
.62456 .85548 m .61953 .83828 L .58878 .84702 L p .707 .577 .707 r
F P
0 g
s
.61953 .83828 m .62456 .85548 L .65298 .84367 L p .707 .577 .707 r
F P
0 g
s
.65298 .84367 m .64795 .82647 L .61953 .83828 L p .707 .577 .707 r
F P
0 g
s
.52112 .68093 m .52131 .73649 L .54232 .74292 L p .707 .577 .707 r
F P
0 g
s
.59382 .86423 m .58878 .84702 L .55874 .85185 L p .707 .577 .707 r
F P
0 g
s
.58878 .84702 m .59382 .86423 L .62456 .85548 L p .707 .577 .707 r
F P
0 g
s
.53499 .80016 m .53643 .76297 L .51547 .75611 L p .707 .577 .707 r
F P
0 g
s
.55874 .85185 m .56377 .86905 L .59382 .86423 L p .707 .577 .707 r
F P
0 g
s
.52131 .73649 m .52112 .68093 L .50858 .67304 L p .707 .577 .707 r
F P
0 g
s
.64795 .82647 m .65298 .84367 L .67631 .82996 L p .707 .577 .707 r
F P
0 g
s
.67631 .82996 m .67128 .81275 L .64795 .82647 L p .707 .577 .707 r
F P
0 g
s
.56377 .86905 m .55874 .85185 L .53232 .85228 L p .707 .577 .707 r
F P
0 g
s
.51547 .75611 m .51403 .7933 L .53499 .80016 L p .707 .577 .707 r
F P
0 g
s
.68028 .76501 m .67884 .80219 L .69529 .79586 L p .707 .577 .707 r
F P
0 g
s
.69529 .79586 m .69673 .75867 L .68028 .76501 L p .707 .577 .707 r
F P
0 g
s
.53232 .85228 m .53735 .86949 L .56377 .86905 L p .707 .577 .707 r
F P
0 g
s
.70247 .67598 m .70267 .73154 L .70981 .72311 L p .707 .577 .707 r
F P
0 g
s
.70981 .72311 m .70961 .66755 L .70247 .67598 L p .707 .577 .707 r
F P
0 g
s
.50858 .67304 m .50877 .7286 L .52131 .73649 L p .707 .577 .707 r
F P
0 g
s
.67128 .81275 m .67631 .82996 L .69225 .81568 L p .707 .577 .707 r
F P
0 g
s
.69225 .81568 m .68722 .79848 L .67128 .81275 L p .707 .577 .707 r
F P
0 g
s
.51403 .7933 m .51547 .75611 L .50299 .74822 L p .707 .577 .707 r
F P
0 g
s
.53735 .86949 m .53232 .85228 L .51212 .84828 L p .707 .577 .707 r
F P
0 g
s
.51212 .84828 m .51715 .86549 L .53735 .86949 L p .707 .577 .707 r
F P
0 g
s
.50877 .7286 m .50858 .67304 L .50574 .66446 L p .707 .577 .707 r
F P
0 g
s
.50299 .74822 m .50155 .78541 L .51403 .7933 L p .707 .577 .707 r
F P
0 g
s
.69673 .75867 m .69529 .79586 L .70248 .78825 L p .707 .577 .707 r
F P
0 g
s
.70248 .78825 m .70392 .75106 L .69673 .75867 L p .707 .577 .707 r
F P
0 g
s
.68722 .79848 m .69225 .81568 L .69925 .80224 L p .707 .577 .707 r
F P
0 g
s
.69925 .80224 m .69422 .78503 L .68722 .79848 L p .707 .577 .707 r
F P
0 g
s
.50574 .66446 m .50594 .72002 L .50877 .7286 L p .707 .577 .707 r
F P
0 g
s
.51715 .86549 m .51212 .84828 L .50012 .84024 L p .707 .577 .707 r
F P
0 g
s
.70961 .66755 m .70981 .72311 L .70697 .71453 L p .707 .577 .707 r
F P
0 g
s
.70697 .71453 m .70678 .65897 L .70961 .66755 L p .707 .577 .707 r
F P
0 g
s
.50155 .78541 m .50299 .74822 L .50021 .74006 L p .707 .577 .707 r
F P
0 g
s
.50012 .84024 m .50515 .85745 L .51715 .86549 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.50021 .74006 m .49877 .77725 L .50155 .78541 L p .707 .577 .707 r
F P
0 g
s
.50594 .72002 m .50574 .66446 L .51288 .65604 L p .707 .577 .707 r
F P
0 g
s
.51288 .65604 m .51308 .7116 L .50594 .72002 L p .707 .577 .707 r
F P
0 g
s
.49877 .77725 m .50021 .74006 L .5074 .73245 L p .707 .577 .707 r
F P
0 g
s
.5074 .73245 m .50596 .76963 L .49877 .77725 L p .707 .577 .707 r
F P
0 g
s
.51308 .7116 m .51288 .65604 L .5293 .64858 L p .707 .577 .707 r
F P
0 g
s
.50252 .84616 m .49749 .82895 L .50449 .81551 L p .707 .577 .707 r
F P
0 g
s
.5293 .64858 m .5295 .70414 L .51308 .7116 L p .707 .577 .707 r
F P
0 g
s
.50596 .76963 m .5074 .73245 L .52385 .72611 L p .707 .577 .707 r
F P
0 g
s
.50449 .81551 m .50952 .83271 L .50252 .84616 L p .707 .577 .707 r
F P
0 g
s
.52385 .72611 m .52241 .7633 L .50596 .76963 L p .707 .577 .707 r
F P
0 g
s
.50952 .83271 m .50449 .81551 L .52044 .80123 L p .707 .577 .707 r
F P
0 g
s
.52241 .7633 m .52385 .72611 L .54796 .72168 L p .707 .577 .707 r
F P
0 g
s
.52044 .80123 m .52547 .81843 L .50952 .83271 L p .707 .577 .707 r
F P
0 g
s
.54796 .72168 m .54652 .75887 L .52241 .7633 L p .707 .577 .707 r
F P
0 g
s
.52547 .81843 m .52044 .80123 L .54376 .78752 L p .707 .577 .707 r
F P
0 g
s
.54376 .78752 m .54879 .80472 L .52547 .81843 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53822 .82054 L p .707 .577 .707 r
F P
0 g
s
.5295 .70414 m .5293 .64858 L .55339 .64284 L p .707 .577 .707 r
F P
0 g
s
.55339 .64284 m .55359 .6984 L .5295 .70414 L p .707 .577 .707 r
F P
0 g
s
.53822 .82054 m .53822 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.55359 .6984 m .55339 .64284 L .5828 .63936 L p .707 .577 .707 r
F P
0 g
s
.5828 .63936 m .583 .69492 L .55359 .6984 L p .707 .577 .707 r
F P
0 g
s
.54652 .75887 m .54796 .72168 L .57737 .71959 L p .707 .577 .707 r
F P
0 g
s
.57737 .71959 m .57593 .75678 L .54652 .75887 L p .707 .577 .707 r
F P
0 g
s
.54879 .80472 m .54376 .78752 L .57219 .77571 L p .707 .577 .707 r
F P
0 g
s
.57219 .77571 m .57722 .79291 L .54879 .80472 L p .707 .577 .707 r
F P
0 g
s
.60293 .76696 m .60796 .78417 L .57722 .79291 L p .707 .577 .707 r
F P
0 g
s
.57722 .79291 m .57219 .77571 L .60293 .76696 L p .707 .577 .707 r
F P
0 g
s
.53822 .31865 m .53822 .82054 L .57933 .81554 L p .707 .577 .707 r
F P
0 g
s
.57593 .75678 m .57737 .71959 L .60919 .72004 L p .707 .577 .707 r
F P
0 g
s
.60919 .72004 m .60775 .75723 L .57593 .75678 L p .707 .577 .707 r
F P
0 g
s
.57933 .81554 m .57933 .31366 L .53822 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40994 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.70392 .75106 m .70248 .78825 L .69969 .78009 L p .707 .577 .707 r
F P
0 g
s
.69969 .78009 m .70113 .7429 L .70392 .75106 L p .707 .577 .707 r
F P
0 g
s
.69422 .78503 m .69925 .80224 L .69662 .79094 L p .707 .577 .707 r
F P
0 g
s
.69662 .79094 m .69159 .77374 L .69422 .78503 L p .707 .577 .707 r
F P
0 g
s
.50515 .85745 m .50012 .84024 L .49749 .82895 L p .707 .577 .707 r
F P
0 g
s
.70678 .65897 m .70697 .71453 L .69443 .70664 L p .707 .577 .707 r
F P
0 g
s
.69443 .70664 m .69424 .65108 L .70678 .65897 L p .707 .577 .707 r
F P
0 g
s
.583 .69492 m .5828 .63936 L .61464 .63849 L p .707 .577 .707 r
F P
0 g
s
.61464 .63849 m .61484 .69405 L .583 .69492 L p .707 .577 .707 r
F P
0 g
s
.64032 .72299 m .63888 .76018 L .60775 .75723 L p .707 .577 .707 r
F P
0 g
s
.60775 .75723 m .60919 .72004 L .64032 .72299 L p .707 .577 .707 r
F P
0 g
s
.63298 .76214 m .63801 .77934 L .60796 .78417 L p .707 .577 .707 r
F P
0 g
s
.60796 .78417 m .60293 .76696 L .63298 .76214 L p .707 .577 .707 r
F P
0 g
s
.57933 .31366 m .57933 .81554 L .61267 .80738 L p .707 .577 .707 r
F P
0 g
s
.61267 .80738 m .61267 .3055 L .57933 .31366 L p .707 .577 .707 r
F P
0 g
s
.25506 .71369 m .25498 .65805 L .22382 .6562 L p .707 .577 .707 r
F P
0 g
s
.25498 .65805 m .25506 .71369 L .2869 .71289 L p .707 .577 .707 r
F P
0 g
s
.2869 .71289 m .28682 .65726 L .25498 .65805 L p .707 .577 .707 r
F P
0 g
s
.49749 .82895 m .50252 .84616 L .50515 .85745 L p .707 .577 .707 r
F P
0 g
s
.28682 .65726 m .2869 .71289 L .31631 .70953 L p .707 .577 .707 r
F P
0 g
s
.31631 .70953 m .31622 .65389 L .28682 .65726 L p .707 .577 .707 r
F P
0 g
s
.40994 .81345 m .40994 .31156 L .37953 .30262 L p .707 .577 .707 r
F P
0 g
s
.40994 .31156 m .40994 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.2239 .71184 m .22382 .6562 L .19639 .65189 L p .707 .577 .707 r
F P
0 g
s
.22382 .6562 m .2239 .71184 L .25506 .71369 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31622 .65389 m .31631 .70953 L .3404 .70392 L p .707 .577 .707 r
F P
0 g
s
.3404 .70392 m .34031 .64829 L .31622 .65389 L p .707 .577 .707 r
F P
0 g
s
.69159 .77374 m .69662 .79094 L .68462 .7829 L p .707 .577 .707 r
F P
0 g
s
.68462 .7829 m .67959 .7657 L .69159 .77374 L p .707 .577 .707 r
F P
0 g
s
.70113 .7429 m .69969 .78009 L .68721 .7722 L p .707 .577 .707 r
F P
0 g
s
.68721 .7722 m .68865 .73501 L .70113 .7429 L p .707 .577 .707 r
F P
0 g
s
.19639 .65189 m .19647 .70752 L .2239 .71184 L p .707 .577 .707 r
F P
0 g
s
.19647 .70752 m .19639 .65189 L .17538 .64553 L p .707 .577 .707 r
F P
0 g
s
.69424 .65108 m .69443 .70664 L .67342 .70021 L p .707 .577 .707 r
F P
0 g
s
.67342 .70021 m .67323 .64466 L .69424 .65108 L p .707 .577 .707 r
F P
0 g
s
.6458 .64032 m .646 .69588 L .61484 .69405 L p .707 .577 .707 r
F P
0 g
s
.61484 .69405 m .61464 .63849 L .6458 .64032 L p .707 .577 .707 r
F P
0 g
s
.63801 .77934 m .63298 .76214 L .65939 .7617 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80738 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.25181 .77597 m .25243 .73934 L .22128 .73667 L p .707 .577 .707 r
F P
0 g
s
.25243 .73934 m .25181 .77597 L .28365 .77561 L p .707 .577 .707 r
F P
0 g
s
.28365 .77561 m .28427 .73897 L .25243 .73934 L p .707 .577 .707 r
F P
0 g
s
.28427 .73897 m .28365 .77561 L .31307 .77225 L p .707 .577 .707 r
F P
0 g
s
.31307 .77225 m .31369 .73562 L .28427 .73897 L p .707 .577 .707 r
F P
0 g
s
.34031 .64829 m .3404 .70392 L .35682 .69663 L p .707 .577 .707 r
F P
0 g
s
.35682 .69663 m .35673 .641 L .34031 .64829 L p .707 .577 .707 r
F P
0 g
s
.22066 .77331 m .22128 .73667 L .19388 .73125 L p .707 .577 .707 r
F P
0 g
s
.22128 .73667 m .22066 .77331 L .25181 .77597 L p .707 .577 .707 r
F P
0 g
s
.37953 .8045 m .37953 .30262 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37953 .30262 m .37953 .8045 L .40994 .81345 L p .707 .577 .707 r
F P
0 g
s
.17538 .64553 m .17546 .70117 L .19647 .70752 L p .707 .577 .707 r
F P
0 g
s
.31369 .73562 m .31307 .77225 L .33719 .76624 L p .707 .577 .707 r
F P
0 g
s
.33719 .76624 m .33781 .7296 L .31369 .73562 L p .707 .577 .707 r
F P
0 g
s
.67959 .7657 m .68462 .7829 L .66442 .77891 L p .707 .577 .707 r
F P
0 g
s
.66442 .77891 m .65939 .7617 L .67959 .7657 L p .707 .577 .707 r
F P
0 g
s
.68865 .73501 m .68721 .7722 L .66626 .76534 L p .707 .577 .707 r
F P
0 g
s
.66626 .76534 m .6677 .72815 L .68865 .73501 L p .707 .577 .707 r
F P
0 g
s
.17546 .70117 m .17538 .64553 L .16284 .63776 L p .707 .577 .707 r
F P
0 g
s
.19388 .73125 m .19326 .76788 L .22066 .77331 L p .707 .577 .707 r
F P
0 g
s
.25294 .78809 m .25074 .76898 L .21973 .7725 L p .707 .577 .707 r
F P
0 g
s
.25074 .76898 m .25294 .78809 L .28455 .78443 L p .707 .577 .707 r
F P
0 g
s
.28455 .78443 m .28235 .76532 L .25074 .76898 L p .707 .577 .707 r
F P
0 g
s
.21973 .7725 m .22193 .79161 L .25294 .78809 L p .707 .577 .707 r
F P
0 g
s
.67323 .64466 m .67342 .70021 L .646 .69588 L p .707 .577 .707 r
F P
0 g
s
.646 .69588 m .6458 .64032 L .67323 .64466 L p .707 .577 .707 r
F P
0 g
s
.28235 .76532 m .28455 .78443 L .31366 .78098 L p .707 .577 .707 r
F P
0 g
s
.31366 .78098 m .31146 .76187 L .28235 .76532 L p .707 .577 .707 r
F P
0 g
s
.19326 .76788 m .19388 .73125 L .17291 .72358 L p .707 .577 .707 r
F P
0 g
s
.22193 .79161 m .21973 .7725 L .19235 .77553 L p .707 .577 .707 r
F P
0 g
s
.19235 .77553 m .19455 .79463 L .22193 .79161 L p .707 .577 .707 r
F P
0 g
s
.16284 .63776 m .16292 .69339 L .17546 .70117 L p .707 .577 .707 r
F P
0 g
s
.35673 .641 m .35682 .69663 L .36396 .68836 L p .707 .577 .707 r
F P
0 g
s
.36396 .68836 m .36388 .63273 L .35673 .641 L p .707 .577 .707 r
F P
0 g
s
.31146 .76187 m .31366 .78098 L .33743 .77808 L p .707 .577 .707 r
F P
0 g
s
.33743 .77808 m .33523 .75897 L .31146 .76187 L p .707 .577 .707 r
F P
0 g
s
.17291 .72358 m .17229 .76022 L .19326 .76788 L p .707 .577 .707 r
F P
0 g
s
.33781 .7296 m .33719 .76624 L .35365 .75815 L p .707 .577 .707 r
F P
0 g
s
.35365 .75815 m .35426 .72151 L .33781 .7296 L p .707 .577 .707 r
F P
0 g
s
.65939 .7617 m .66442 .77891 L .63801 .77934 L p .707 .577 .707 r
F P
0 g
s
.6677 .72815 m .66626 .76534 L .63888 .76018 L p .707 .577 .707 r
F P
0 g
s
.63888 .76018 m .64032 .72299 L .6677 .72815 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.19455 .79463 m .19235 .77553 L .17129 .77776 L p .707 .577 .707 r
F P
0 g
s
.17129 .77776 m .17349 .79687 L .19455 .79463 L p .707 .577 .707 r
F P
0 g
s
.17229 .76022 m .17291 .72358 L .16041 .71444 L p .707 .577 .707 r
F P
0 g
s
.16292 .69339 m .16284 .63776 L .16 .62932 L p .707 .577 .707 r
F P
0 g
s
.35426 .72151 m .35365 .75815 L .36083 .74878 L p .707 .577 .707 r
F P
0 g
s
.36083 .74878 m .36145 .71214 L .35426 .72151 L p .707 .577 .707 r
F P
0 g
s
.36145 .71214 m .36083 .74878 L .35804 .73905 L p .707 .577 .707 r
F P
0 g
s
.35804 .73905 m .35865 .70241 L .36145 .71214 L p .707 .577 .707 r
F P
0 g
s
.36104 .62429 m .36112 .67993 L .34858 .67215 L p .707 .577 .707 r
F P
0 g
s
.34858 .67215 m .3485 .61652 L .36104 .62429 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36388 .63273 m .36396 .68836 L .36112 .67993 L p .707 .577 .707 r
F P
0 g
s
.36112 .67993 m .36104 .62429 L .36388 .63273 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37953 .8045 L p .707 .577 .707 r
F P
0 g
s
.33523 .75897 m .33743 .77808 L .35352 .77601 L p .707 .577 .707 r
F P
0 g
s
.35352 .77601 m .35132 .75691 L .33523 .75897 L p .707 .577 .707 r
F P
0 g
s
.16041 .71444 m .1598 .75107 L .17229 .76022 L p .707 .577 .707 r
F P
0 g
s
.16 .62932 m .16009 .68496 L .16292 .69339 L p .707 .577 .707 r
F P
0 g
s
.17349 .79687 m .17129 .77776 L .1586 .779 L p .707 .577 .707 r
F P
0 g
s
.1586 .779 m .1608 .7981 L .17349 .79687 L p .707 .577 .707 r
F P
0 g
s
.1598 .75107 m .16041 .71444 L .15762 .7047 L p .707 .577 .707 r
F P
0 g
s
.16009 .68496 m .16 .62932 L .16714 .62105 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77296 L p .707 .577 .707 r
F P
0 g
s
.63909 .77296 m .63909 .27107 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.35132 .75691 m .35352 .77601 L .36037 .77498 L p .707 .577 .707 r
F P
0 g
s
.36037 .77498 m .35817 .75588 L .35132 .75691 L p .707 .577 .707 r
F P
0 g
s
.15762 .7047 m .157 .74134 L .1598 .75107 L p .707 .577 .707 r
F P
0 g
s
.35817 .75588 m .36037 .77498 L .3573 .77509 L p .707 .577 .707 r
F P
0 g
s
.3573 .77509 m .3551 .75598 L .35817 .75588 L p .707 .577 .707 r
F P
0 g
s
.35865 .70241 m .35804 .73905 L .34554 .7299 L p .707 .577 .707 r
F P
0 g
s
.34554 .7299 m .34616 .69326 L .35865 .70241 L p .707 .577 .707 r
F P
0 g
s
.3551 .75598 m .3573 .77509 L .34461 .77632 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.16714 .62105 m .16723 .67669 L .16009 .68496 L p .707 .577 .707 r
F P
0 g
s
.1608 .7981 m .1586 .779 L .15553 .7791 L p .707 .577 .707 r
F P
0 g
s
.15553 .7791 m .15773 .79821 L .1608 .7981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.157 .74134 m .15762 .7047 L .1648 .69533 L p .707 .577 .707 r
F P
0 g
s
.16723 .67669 m .16714 .62105 L .18356 .61376 L p .707 .577 .707 r
F P
0 g
s
.1648 .69533 m .16419 .73197 L .157 .74134 L p .707 .577 .707 r
F P
0 g
s
.63909 .27107 m .63909 .77296 L .62047 .76193 L p .707 .577 .707 r
F P
0 g
s
.62047 .76193 m .62047 .26004 L .63909 .27107 L p .707 .577 .707 r
F P
0 g
s
.18356 .61376 m .18365 .6694 L .16723 .67669 L p .707 .577 .707 r
F P
0 g
s
.3485 .61652 m .34858 .67215 L .32757 .66579 L p .707 .577 .707 r
F P
0 g
s
.32757 .66579 m .32749 .61016 L .3485 .61652 L p .707 .577 .707 r
F P
0 g
s
.15773 .79821 m .15553 .7791 L .16238 .77807 L p .707 .577 .707 r
F P
0 g
s
.16238 .77807 m .16458 .79718 L .15773 .79821 L p .707 .577 .707 r
F P
0 g
s
.18365 .6694 m .18356 .61376 L .20766 .60816 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38732 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.16419 .73197 m .1648 .69533 L .18126 .68724 L p .707 .577 .707 r
F P
0 g
s
.18126 .68724 m .18064 .72388 L .16419 .73197 L p .707 .577 .707 r
F P
0 g
s
.32749 .61016 m .32757 .66579 L .30015 .66148 L p .707 .577 .707 r
F P
0 g
s
.30015 .66148 m .30006 .60585 L .32749 .61016 L p .707 .577 .707 r
F P
0 g
s
.34461 .77632 m .34241 .75722 L .3551 .75598 L p .707 .577 .707 r
F P
0 g
s
.20766 .60816 m .20774 .66379 L .18365 .6694 L p .707 .577 .707 r
F P
0 g
s
.34616 .69326 m .34554 .7299 L .32457 .72224 L p .707 .577 .707 r
F P
0 g
s
.32457 .72224 m .32519 .6856 L .34616 .69326 L p .707 .577 .707 r
F P
0 g
s
.20774 .66379 m .20766 .60816 L .23706 .60479 L p .707 .577 .707 r
F P
0 g
s
.16458 .79718 m .16238 .77807 L .17847 .77601 L p .707 .577 .707 r
F P
0 g
s
.17847 .77601 m .18067 .79511 L .16458 .79718 L p .707 .577 .707 r
F P
0 g
s
.18064 .72388 m .18126 .68724 L .20538 .68123 L p .707 .577 .707 r
F P
0 g
s
.62047 .26004 m .62047 .76193 L .59006 .75298 L p .707 .577 .707 r
F P
0 g
s
.59006 .75298 m .59006 .2511 L .62047 .26004 L p .707 .577 .707 r
F P
0 g
s
.30006 .60585 m .30015 .66148 L .26899 .65963 L p .707 .577 .707 r
F P
0 g
s
.26899 .65963 m .2689 .604 L .30006 .60585 L p .707 .577 .707 r
F P
0 g
s
.23715 .66043 m .23706 .60479 L .2689 .604 L p .707 .577 .707 r
F P
0 g
s
.23706 .60479 m .23715 .66043 L .20774 .66379 L p .707 .577 .707 r
F P
0 g
s
.2689 .604 m .26899 .65963 L .23715 .66043 L p .707 .577 .707 r
F P
0 g
s
.38732 .25716 m .38732 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38732 .75905 m .38732 .25716 L .42067 .249 L p .707 .577 .707 r
F P
0 g
s
.20538 .68123 m .20476 .71787 L .18064 .72388 L p .707 .577 .707 r
F P
0 g
s
.32519 .6856 m .32457 .72224 L .29717 .71681 L p .707 .577 .707 r
F P
0 g
s
.29717 .71681 m .29779 .68017 L .32519 .6856 L p .707 .577 .707 r
F P
0 g
s
.34241 .75722 m .34461 .77632 L .32355 .77856 L p .707 .577 .707 r
F P
0 g
s
.32355 .77856 m .32135 .75945 L .34241 .75722 L p .707 .577 .707 r
F P
0 g
s
.73101 .65644 m .7311 .60091 L .69994 .59893 L p .707 .577 .707 r
F P
0 g
s
.7311 .60091 m .73101 .65644 L .76285 .65572 L p .707 .577 .707 r
F P
0 g
s
.76285 .65572 m .76294 .60019 L .7311 .60091 L p .707 .577 .707 r
F P
0 g
s
.20476 .71787 m .20538 .68123 L .2348 .67788 L p .707 .577 .707 r
F P
0 g
s
.76294 .60019 m .76285 .65572 L .79226 .65235 L p .707 .577 .707 r
F P
0 g
s
.79226 .65235 m .79234 .59682 L .76294 .60019 L p .707 .577 .707 r
F P
0 g
s
.18067 .79511 m .17847 .77601 L .20224 .77311 L p .707 .577 .707 r
F P
0 g
s
.20224 .77311 m .20444 .79221 L .18067 .79511 L p .707 .577 .707 r
F P
0 g
s
.69985 .65446 m .69994 .59893 L .67251 .59443 L p .707 .577 .707 r
F P
0 g
s
.69994 .59893 m .69985 .65446 L .73101 .65644 L p .707 .577 .707 r
F P
0 g
s
.29779 .68017 m .29717 .71681 L .26602 .71415 L p .707 .577 .707 r
F P
0 g
s
.26602 .71415 m .26664 .67751 L .29779 .68017 L p .707 .577 .707 r
F P
0 g
s
.2348 .67788 m .23418 .71451 L .20476 .71787 L p .707 .577 .707 r
F P
0 g
s
.23418 .71451 m .2348 .67788 L .26664 .67751 L p .707 .577 .707 r
F P
0 g
s
.59006 .2511 m .59006 .75298 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59006 .2511 L p .707 .577 .707 r
F P
0 g
s
.79234 .59682 m .79226 .65235 L .81635 .64668 L p .707 .577 .707 r
F P
0 g
s
.81635 .64668 m .81643 .59115 L .79234 .59682 L p .707 .577 .707 r
F P
0 g
s
.26664 .67751 m .26602 .71415 L .23418 .71451 L p .707 .577 .707 r
F P
0 g
s
.73397 .71481 m .73336 .6774 L .70221 .67622 L p .707 .577 .707 r
F P
0 g
s
.73336 .6774 m .73397 .71481 L .76581 .71367 L p .707 .577 .707 r
F P
0 g
s
.76581 .71367 m .7652 .67626 L .73336 .6774 L p .707 .577 .707 r
F P
0 g
s
.7652 .67626 m .76581 .71367 L .79523 .71031 L p .707 .577 .707 r
F P
0 g
s
.79523 .71031 m .79462 .6729 L .7652 .67626 L p .707 .577 .707 r
F P
0 g
s
.32135 .75945 m .32355 .77856 L .29617 .78159 L p .707 .577 .707 r
F P
0 g
s
.29617 .78159 m .29397 .76248 L .32135 .75945 L p .707 .577 .707 r
F P
0 g
s
.42067 .75089 m .42067 .249 L .46178 .24401 L p .707 .577 .707 r
F P
0 g
s
.42067 .249 m .42067 .75089 L .38732 .75905 L p .707 .577 .707 r
F P
0 g
s
.67251 .59443 m .67242 .64996 L .69985 .65446 L p .707 .577 .707 r
F P
0 g
s
.67242 .64996 m .67251 .59443 L .6515 .58786 L p .707 .577 .707 r
F P
0 g
s
.70283 .71363 m .70221 .67622 L .67481 .67283 L p .707 .577 .707 r
F P
0 g
s
.70221 .67622 m .70283 .71363 L .73397 .71481 L p .707 .577 .707 r
F P
0 g
s
.20444 .79221 m .20224 .77311 L .23135 .76966 L p .707 .577 .707 r
F P
0 g
s
.23135 .76966 m .23355 .78876 L .20444 .79221 L p .707 .577 .707 r
F P
0 g
s
.79462 .6729 m .79523 .71031 L .81935 .70507 L p .707 .577 .707 r
F P
0 g
s
.81935 .70507 m .81874 .66766 L .79462 .6729 L p .707 .577 .707 r
F P
0 g
s
.67481 .67283 m .67543 .71024 L .70283 .71363 L p .707 .577 .707 r
F P
0 g
s
.81643 .59115 m .81635 .64668 L .83277 .63925 L p .707 .577 .707 r
F P
0 g
s
.83277 .63925 m .83285 .58373 L .81643 .59115 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50663 .74455 L p .707 .577 .707 r
F P
0 g
s
.50663 .74455 m .50663 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.29397 .76248 m .29617 .78159 L .26516 .7851 L p .707 .577 .707 r
F P
0 g
s
.26516 .7851 m .26296 .766 L .29397 .76248 L p .707 .577 .707 r
F P
0 g
s
.73484 .78391 m .73704 .76748 L .70603 .76089 L p .707 .577 .707 r
F P
0 g
s
.73704 .76748 m .73484 .78391 L .76645 .78546 L p .707 .577 .707 r
F P
0 g
s
.76645 .78546 m .76864 .76903 L .73704 .76748 L p .707 .577 .707 r
F P
0 g
s
.6515 .58786 m .65141 .64339 L .67242 .64996 L p .707 .577 .707 r
F P
0 g
s
.67543 .71024 m .67481 .67283 L .65384 .66756 L p .707 .577 .707 r
F P
0 g
s
.46178 .7459 m .46178 .24401 L .50663 .24266 L p .707 .577 .707 r
F P
0 g
s
.46178 .24401 m .46178 .7459 L .42067 .75089 L p .707 .577 .707 r
F P
0 g
s
.23355 .78876 m .23135 .76966 L .26296 .766 L p .707 .577 .707 r
F P
0 g
s
.26296 .766 m .26516 .7851 L .23355 .78876 L p .707 .577 .707 r
F P
0 g
s
.70383 .77732 m .70603 .76089 L .67865 .74991 L p .707 .577 .707 r
F P
0 g
s
.70603 .76089 m .70383 .77732 L .73484 .78391 L p .707 .577 .707 r
F P
0 g
s
.76864 .76903 m .76645 .78546 L .79556 .78182 L p .707 .577 .707 r
F P
0 g
s
.79556 .78182 m .79776 .76539 L .76864 .76903 L p .707 .577 .707 r
F P
0 g
s
.50663 .24266 m .50663 .74455 L .46178 .7459 L p .707 .577 .707 r
F P
0 g
s
.65141 .64339 m .6515 .58786 L .63896 .57986 L p .707 .577 .707 r
F P
0 g
s
.65384 .66756 m .65445 .70497 L .67543 .71024 L p .707 .577 .707 r
F P
0 g
s
.81874 .66766 m .81935 .70507 L .83581 .69846 L p .707 .577 .707 r
F P
0 g
s
.83581 .69846 m .83519 .66104 L .81874 .66766 L p .707 .577 .707 r
F P
0 g
s
.67865 .74991 m .67645 .76634 L .70383 .77732 L p .707 .577 .707 r
F P
0 g
s
.67645 .76634 m .67865 .74991 L .65759 .73562 L p .707 .577 .707 r
F P
0 g
s
.79776 .76539 m .79556 .78182 L .81933 .77336 L p .707 .577 .707 r
F P
0 g
s
.81933 .77336 m .82152 .75693 L .79776 .76539 L p .707 .577 .707 r
F P
0 g
s
.83285 .58373 m .83277 .63925 L .83991 .6308 L p .707 .577 .707 r
F P
0 g
s
.83991 .6308 m .84 .57527 L .83285 .58373 L p .707 .577 .707 r
F P
0 g
s
.63896 .57986 m .63888 .63539 L .65141 .64339 L p .707 .577 .707 r
F P
0 g
s
.65445 .70497 m .65384 .66756 L .64134 .66093 L p .707 .577 .707 r
F P
0 g
s
.65759 .73562 m .65539 .75205 L .67645 .76634 L p .707 .577 .707 r
F P
0 g
s
.64134 .66093 m .64196 .69834 L .65445 .70497 L p .707 .577 .707 r
F P
0 g
s
.65539 .75205 m .65759 .73562 L .6449 .71941 L p .707 .577 .707 r
F P
0 g
s
.63888 .63539 m .63896 .57986 L .63612 .5712 L p .707 .577 .707 r
F P
0 g
s
.82152 .75693 m .81933 .77336 L .83542 .76089 L p .707 .577 .707 r
F P
0 g
s
.83542 .76089 m .83762 .74446 L .82152 .75693 L p .707 .577 .707 r
F P
0 g
s
.83519 .66104 m .83581 .69846 L .84299 .69112 L p .707 .577 .707 r
F P
0 g
s
.84299 .69112 m .84238 .65371 L .83519 .66104 L p .707 .577 .707 r
F P
0 g
s
.6449 .71941 m .6427 .73584 L .65539 .75205 L p .707 .577 .707 r
F P
0 g
s
.63612 .5712 m .63604 .62673 L .63888 .63539 L p .707 .577 .707 r
F P
0 g
s
.64196 .69834 m .64134 .66093 L .63855 .65359 L p .707 .577 .707 r
F P
0 g
s
.84 .57527 m .83991 .6308 L .83707 .62215 L p .707 .577 .707 r
F P
0 g
s
.83707 .62215 m .83716 .56662 L .84 .57527 L p .707 .577 .707 r
F P
0 g
s
.6427 .73584 m .6449 .71941 L .64183 .70287 L p .707 .577 .707 r
F P
0 g
s
.83762 .74446 m .83542 .76089 L .84227 .74563 L p .707 .577 .707 r
F P
0 g
s
.84227 .74563 m .84447 .7292 L .83762 .74446 L p .707 .577 .707 r
F P
0 g
s
.63855 .65359 m .63917 .691 L .64196 .69834 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63604 .62673 m .63612 .5712 L .64326 .56275 L p .707 .577 .707 r
F P
0 g
s
.84238 .65371 m .84299 .69112 L .8402 .68378 L p .707 .577 .707 r
F P
0 g
s
.8402 .68378 m .83959 .64636 L .84238 .65371 L p .707 .577 .707 r
F P
0 g
s
.64183 .70287 m .63963 .7193 L .6427 .73584 L p .707 .577 .707 r
F P
0 g
s
.64326 .56275 m .64318 .61828 L .63604 .62673 L p .707 .577 .707 r
F P
0 g
s
.63917 .691 m .63855 .65359 L .64574 .64625 L p .707 .577 .707 r
F P
0 g
s
.83716 .56662 m .83707 .62215 L .82454 .61415 L p .707 .577 .707 r
F P
0 g
s
.82454 .61415 m .82462 .55862 L .83716 .56662 L p .707 .577 .707 r
F P
0 g
s
.63963 .7193 m .64183 .70287 L .64867 .68762 L p .707 .577 .707 r
F P
0 g
s
.38516 .62104 m .38536 .56544 L .3542 .56343 L p .707 .577 .707 r
F P
0 g
s
.38536 .56544 m .38516 .62104 L .417 .62039 L p .707 .577 .707 r
F P
0 g
s
.417 .62039 m .4172 .56479 L .38536 .56544 L p .707 .577 .707 r
F P
0 g
s
.84447 .7292 m .84227 .74563 L .8392 .72909 L p .707 .577 .707 r
F P
0 g
s
.8392 .72909 m .8414 .71266 L .84447 .7292 L p .707 .577 .707 r
F P
0 g
s
.4172 .56479 m .417 .62039 L .44641 .61714 L p .707 .577 .707 r
F P
0 g
s
.44641 .61714 m .4466 .56154 L .4172 .56479 L p .707 .577 .707 r
F P
0 g
s
.64574 .64625 m .64635 .68367 L .63917 .691 L p .707 .577 .707 r
F P
0 g
s
.354 .61904 m .3542 .56343 L .32677 .55896 L p .707 .577 .707 r
F P
0 g
s
.3542 .56343 m .354 .61904 L .38516 .62104 L p .707 .577 .707 r
F P
0 g
s
.64867 .68762 m .64648 .70405 L .63963 .7193 L p .707 .577 .707 r
F P
0 g
s
.64318 .61828 m .64326 .56275 L .65968 .55532 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83959 .64636 m .8402 .68378 L .82771 .67715 L p .707 .577 .707 r
F P
0 g
s
.82771 .67715 m .82709 .63974 L .83959 .64636 L p .707 .577 .707 r
F P
0 g
s
.4466 .56154 m .44641 .61714 L .4705 .61161 L p .707 .577 .707 r
F P
0 g
s
.4705 .61161 m .47069 .55601 L .4466 .56154 L p .707 .577 .707 r
F P
0 g
s
.32677 .55896 m .32657 .61456 L .354 .61904 L p .707 .577 .707 r
F P
0 g
s
.32657 .61456 m .32677 .55896 L .30576 .55246 L p .707 .577 .707 r
F P
0 g
s
.39225 .68254 m .39081 .64568 L .35968 .64476 L p .707 .577 .707 r
F P
0 g
s
.39081 .64568 m .39225 .68254 L .42407 .68061 L p .707 .577 .707 r
F P
0 g
s
.42407 .68061 m .42263 .64375 L .39081 .64568 L p .707 .577 .707 r
F P
0 g
s
.82462 .55862 m .82454 .61415 L .80353 .60757 L p .707 .577 .707 r
F P
0 g
s
.80353 .60757 m .80361 .55204 L .82462 .55862 L p .707 .577 .707 r
F P
0 g
s
.65968 .55532 m .6596 .61085 L .64318 .61828 L p .707 .577 .707 r
F P
0 g
s
.64648 .70405 m .64867 .68762 L .66477 .67515 L p .707 .577 .707 r
F P
0 g
s
.64635 .68367 m .64574 .64625 L .66219 .63964 L p .707 .577 .707 r
F P
0 g
s
.42263 .64375 m .42407 .68061 L .45348 .67601 L p .707 .577 .707 r
F P
0 g
s
.45348 .67601 m .45203 .63915 L .42263 .64375 L p .707 .577 .707 r
F P
0 g
s
.8414 .71266 m .8392 .72909 L .82651 .71288 L p .707 .577 .707 r
F P
0 g
s
.82651 .71288 m .82871 .69645 L .8414 .71266 L p .707 .577 .707 r
F P
0 g
s
.36112 .68162 m .35968 .64476 L .3323 .64107 L p .707 .577 .707 r
F P
0 g
s
.35968 .64476 m .36112 .68162 L .39225 .68254 L p .707 .577 .707 r
F P
0 g
s
.47069 .55601 m .4705 .61161 L .48692 .60434 L p .707 .577 .707 r
F P
0 g
s
.48692 .60434 m .48711 .54874 L .47069 .55601 L p .707 .577 .707 r
F P
0 g
s
.6596 .61085 m .65968 .55532 L .68378 .54965 L p .707 .577 .707 r
F P
0 g
s
.66219 .63964 m .66281 .67705 L .64635 .68367 L p .707 .577 .707 r
F P
0 g
s
.66477 .67515 m .66257 .69158 L .64648 .70405 L p .707 .577 .707 r
F P
0 g
s
.30576 .55246 m .30556 .60806 L .32657 .61456 L p .707 .577 .707 r
F P
0 g
s
.45203 .63915 m .45348 .67601 L .47759 .66919 L p .707 .577 .707 r
F P
0 g
s
.47759 .66919 m .47614 .63233 L .45203 .63915 L p .707 .577 .707 r
F P
0 g
s
.39204 .70906 m .39707 .69073 L .36702 .68154 L p .707 .577 .707 r
F P
0 g
s
.39707 .69073 m .39204 .70906 L .42278 .71686 L p .707 .577 .707 r
F P
0 g
s
.42278 .71686 m .42781 .69853 L .39707 .69073 L p .707 .577 .707 r
F P
0 g
s
.82709 .63974 m .82771 .67715 L .80674 .67188 L p .707 .577 .707 r
F P
0 g
s
.80674 .67188 m .80612 .63447 L .82709 .63974 L p .707 .577 .707 r
F P
0 g
s
.3323 .64107 m .33374 .67793 L .36112 .68162 L p .707 .577 .707 r
F P
0 g
s
.36702 .68154 m .36199 .69987 L .39204 .70906 L p .707 .577 .707 r
F P
0 g
s
.42781 .69853 m .42278 .71686 L .45121 .7225 L p .707 .577 .707 r
F P
0 g
s
.45121 .7225 m .45624 .70417 L .42781 .69853 L p .707 .577 .707 r
F P
0 g
s
.30556 .60806 m .30576 .55246 L .29322 .54457 L p .707 .577 .707 r
F P
0 g
s
.36199 .69987 m .36702 .68154 L .3406 .67187 L p .707 .577 .707 r
F P
0 g
s
.80361 .55204 m .80353 .60757 L .7761 .60307 L p .707 .577 .707 r
F P
0 g
s
.7761 .60307 m .77618 .54754 L .80361 .55204 L p .707 .577 .707 r
F P
0 g
s
.33374 .67793 m .3323 .64107 L .31134 .63498 L p .707 .577 .707 r
F P
0 g
s
.3406 .67187 m .33557 .6902 L .36199 .69987 L p .707 .577 .707 r
F P
0 g
s
.68378 .54965 m .68369 .60518 L .6596 .61085 L p .707 .577 .707 r
F P
0 g
s
.66257 .69158 m .66477 .67515 L .68854 .66668 L p .707 .577 .707 r
F P
0 g
s
.82871 .69645 m .82651 .71288 L .80545 .69859 L p .707 .577 .707 r
F P
0 g
s
.80545 .69859 m .80765 .68216 L .82871 .69645 L p .707 .577 .707 r
F P
0 g
s
.66281 .67705 m .66219 .63964 L .68631 .6344 L p .707 .577 .707 r
F P
0 g
s
.68369 .60518 m .68378 .54965 L .71318 .54629 L p .707 .577 .707 r
F P
0 g
s
.45624 .70417 m .45121 .7225 L .47453 .72544 L p .707 .577 .707 r
F P
0 g
s
.47453 .72544 m .47956 .70711 L .45624 .70417 L p .707 .577 .707 r
F P
0 g
s
.47614 .63233 m .47759 .66919 L .49404 .66083 L p .707 .577 .707 r
F P
0 g
s
.49404 .66083 m .4926 .62397 L .47614 .63233 L p .707 .577 .707 r
F P
0 g
s
.31134 .63498 m .31278 .67184 L .33374 .67793 L p .707 .577 .707 r
F P
0 g
s
.68854 .66668 m .68634 .68311 L .66257 .69158 L p .707 .577 .707 r
F P
0 g
s
.29322 .54457 m .29303 .60017 L .30556 .60806 L p .707 .577 .707 r
F P
0 g
s
.48711 .54874 m .48692 .60434 L .49406 .59605 L p .707 .577 .707 r
F P
0 g
s
.49406 .59605 m .49426 .54045 L .48711 .54874 L p .707 .577 .707 r
F P
0 g
s
.33557 .6902 m .3406 .67187 L .32041 .66265 L p .707 .577 .707 r
F P
0 g
s
.68631 .6344 m .68693 .67181 L .66281 .67705 L p .707 .577 .707 r
F P
0 g
s
.77618 .54754 m .7761 .60307 L .74494 .60109 L p .707 .577 .707 r
F P
0 g
s
.74494 .60109 m .74502 .54556 L .77618 .54754 L p .707 .577 .707 r
F P
0 g
s
.32041 .66265 m .31538 .68098 L .33557 .6902 L p .707 .577 .707 r
F P
0 g
s
.80612 .63447 m .80674 .67188 L .77933 .66849 L p .707 .577 .707 r
F P
0 g
s
.77933 .66849 m .77872 .63108 L .80612 .63447 L p .707 .577 .707 r
F P
0 g
s
.7131 .60182 m .71318 .54629 L .74502 .54556 L p .707 .577 .707 r
F P
0 g
s
.71318 .54629 m .7131 .60182 L .68369 .60518 L p .707 .577 .707 r
F P
0 g
s
.74502 .54556 m .74494 .60109 L .7131 .60182 L p .707 .577 .707 r
F P
0 g
s
.68634 .68311 m .68854 .66668 L .71765 .66304 L p .707 .577 .707 r
F P
0 g
s
.31278 .67184 m .31134 .63498 L .29886 .62708 L p .707 .577 .707 r
F P
0 g
s
.80765 .68216 m .80545 .69859 L .77807 .68761 L p .707 .577 .707 r
F P
0 g
s
.77807 .68761 m .78027 .67118 L .80765 .68216 L p .707 .577 .707 r
F P
0 g
s
.68693 .67181 m .68631 .6344 L .71573 .63104 L p .707 .577 .707 r
F P
0 g
s
.29303 .60017 m .29322 .54457 L .29038 .53606 L p .707 .577 .707 r
F P
0 g
s
.47956 .70711 m .47453 .72544 L .49047 .72539 L p .707 .577 .707 r
F P
0 g
s
.49047 .72539 m .4955 .70706 L .47956 .70711 L p .707 .577 .707 r
F P
0 g
s
.71765 .66304 m .71545 .67947 L .68634 .68311 L p .707 .577 .707 r
F P
0 g
s
.74706 .68103 m .74926 .66459 L .78027 .67118 L p .707 .577 .707 r
F P
0 g
s
.74926 .66459 m .74706 .68103 L .71545 .67947 L p .707 .577 .707 r
F P
0 g
s
.77872 .63108 m .77933 .66849 L .74819 .66731 L p .707 .577 .707 r
F P
0 g
s
.71545 .67947 m .71765 .66304 L .74926 .66459 L p .707 .577 .707 r
F P
0 g
s
.74819 .66731 m .74757 .6299 L .77872 .63108 L p .707 .577 .707 r
F P
0 g
s
.29886 .62708 m .3003 .66394 L .31278 .67184 L p .707 .577 .707 r
F P
0 g
s
.71573 .63104 m .71635 .66845 L .68693 .67181 L p .707 .577 .707 r
F P
0 g
s
.78027 .67118 m .77807 .68761 L .74706 .68103 L p .707 .577 .707 r
F P
0 g
s
.4926 .62397 m .49404 .66083 L .50123 .65173 L p .707 .577 .707 r
F P
0 g
s
.50123 .65173 m .49979 .61487 L .4926 .62397 L p .707 .577 .707 r
F P
0 g
s
.31538 .68098 m .32041 .66265 L .30841 .65479 L p .707 .577 .707 r
F P
0 g
s
.71635 .66845 m .71573 .63104 L .74757 .6299 L p .707 .577 .707 r
F P
0 g
s
.30841 .65479 m .30338 .67312 L .31538 .68098 L p .707 .577 .707 r
F P
0 g
s
.74757 .6299 m .74819 .66731 L .71635 .66845 L p .707 .577 .707 r
F P
0 g
s
.29038 .53606 m .29019 .59167 L .29303 .60017 L p .707 .577 .707 r
F P
0 g
s
.49426 .54045 m .49406 .59605 L .49122 .58754 L p .707 .577 .707 r
F P
0 g
s
.49122 .58754 m .49142 .53194 L .49426 .54045 L p .707 .577 .707 r
F P
0 g
s
.3003 .66394 m .29886 .62708 L .29608 .61815 L p .707 .577 .707 r
F P
0 g
s
.29019 .59167 m .29038 .53606 L .29752 .52777 L p .707 .577 .707 r
F P
0 g
s
.4955 .70706 m .49047 .72539 L .49747 .72234 L p .707 .577 .707 r
F P
0 g
s
.49747 .72234 m .5025 .70401 L .4955 .70706 L p .707 .577 .707 r
F P
0 g
s
.29608 .61815 m .29752 .65501 L .3003 .66394 L p .707 .577 .707 r
F P
0 g
s
.30338 .67312 m .30841 .65479 L .30578 .64905 L p .707 .577 .707 r
F P
0 g
s
.49979 .61487 m .50123 .65173 L .49844 .6428 L p .707 .577 .707 r
F P
0 g
s
.49844 .6428 m .497 .60594 L .49979 .61487 L p .707 .577 .707 r
F P
0 g
s
.30578 .64905 m .30075 .66738 L .30338 .67312 L p .707 .577 .707 r
F P
0 g
s
.29752 .52777 m .29733 .58337 L .29019 .59167 L p .707 .577 .707 r
F P
0 g
s
.49142 .53194 m .49122 .58754 L .47868 .57965 L p .707 .577 .707 r
F P
0 g
s
.47868 .57965 m .47888 .52405 L .49142 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29752 .65501 m .29608 .61815 L .30327 .60906 L p .707 .577 .707 r
F P
0 g
s
.29733 .58337 m .29752 .52777 L .31395 .5205 L p .707 .577 .707 r
F P
0 g
s
.5025 .70401 m .49747 .72234 L .49484 .71661 L p .707 .577 .707 r
F P
0 g
s
.49484 .71661 m .49987 .69828 L .5025 .70401 L p .707 .577 .707 r
F P
0 g
s
.30327 .60906 m .30471 .64592 L .29752 .65501 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30075 .66738 m .30578 .64905 L .31278 .64601 L p .707 .577 .707 r
F P
0 g
s
.497 .60594 m .49844 .6428 L .48596 .6349 L p .707 .577 .707 r
F P
0 g
s
.48596 .6349 m .48452 .59804 L .497 .60594 L p .707 .577 .707 r
F P
0 g
s
.31278 .64601 m .30775 .66434 L .30075 .66738 L p .707 .577 .707 r
F P
0 g
s
.31395 .5205 m .31375 .5761 L .29733 .58337 L p .707 .577 .707 r
F P
0 g
s
.47888 .52405 m .47868 .57965 L .45767 .57315 L p .707 .577 .707 r
F P
0 g
s
.45767 .57315 m .45787 .51755 L .47888 .52405 L p .707 .577 .707 r
F P
0 g
s
.30471 .64592 m .30327 .60906 L .31972 .60069 L p .707 .577 .707 r
F P
0 g
s
.31375 .5761 m .31395 .5205 L .33804 .51497 L p .707 .577 .707 r
F P
0 g
s
.49987 .69828 m .49484 .71661 L .48284 .70875 L p .707 .577 .707 r
F P
0 g
s
.48284 .70875 m .48787 .69042 L .49987 .69828 L p .707 .577 .707 r
F P
0 g
s
.31972 .60069 m .32116 .63755 L .30471 .64592 L p .707 .577 .707 r
F P
0 g
s
.48452 .59804 m .48596 .6349 L .46501 .62881 L p .707 .577 .707 r
F P
0 g
s
.46501 .62881 m .46357 .59195 L .48452 .59804 L p .707 .577 .707 r
F P
0 g
s
.45787 .51755 m .45767 .57315 L .43025 .56868 L p .707 .577 .707 r
F P
0 g
s
.43025 .56868 m .43044 .51307 L .45787 .51755 L p .707 .577 .707 r
F P
0 g
s
.30775 .66434 m .31278 .64601 L .32872 .64596 L p .707 .577 .707 r
F P
0 g
s
.33804 .51497 m .33784 .57057 L .31375 .5761 L p .707 .577 .707 r
F P
0 g
s
.32872 .64596 m .32369 .66429 L .30775 .66434 L p .707 .577 .707 r
F P
0 g
s
.33784 .57057 m .33804 .51497 L .36744 .51172 L p .707 .577 .707 r
F P
0 g
s
.32116 .63755 m .31972 .60069 L .34383 .59388 L p .707 .577 .707 r
F P
0 g
s
.43044 .51307 m .43025 .56868 L .39909 .56667 L p .707 .577 .707 r
F P
0 g
s
.39909 .56667 m .39928 .51107 L .43044 .51307 L p .707 .577 .707 r
F P
0 g
s
.36725 .56732 m .36744 .51172 L .39928 .51107 L p .707 .577 .707 r
F P
0 g
s
.36744 .51172 m .36725 .56732 L .33784 .57057 L p .707 .577 .707 r
F P
0 g
s
.39928 .51107 m .39909 .56667 L .36725 .56732 L p .707 .577 .707 r
F P
0 g
s
.46357 .59195 m .46501 .62881 L .43763 .62512 L p .707 .577 .707 r
F P
0 g
s
.43763 .62512 m .43618 .58826 L .46357 .59195 L p .707 .577 .707 r
F P
0 g
s
.34383 .59388 m .34527 .63073 L .32116 .63755 L p .707 .577 .707 r
F P
0 g
s
.48787 .69042 m .48284 .70875 L .46265 .69953 L p .707 .577 .707 r
F P
0 g
s
.46265 .69953 m .46768 .6812 L .48787 .69042 L p .707 .577 .707 r
F P
0 g
s
.32369 .66429 m .32872 .64596 L .35205 .6489 L p .707 .577 .707 r
F P
0 g
s
.34527 .63073 m .34383 .59388 L .37324 .58928 L p .707 .577 .707 r
F P
0 g
s
.35205 .6489 m .34701 .66723 L .32369 .66429 L p .707 .577 .707 r
F P
0 g
s
.43618 .58826 m .43763 .62512 L .4065 .6242 L p .707 .577 .707 r
F P
0 g
s
.4065 .6242 m .40506 .58734 L .43618 .58826 L p .707 .577 .707 r
F P
0 g
s
.37324 .58928 m .37468 .62613 L .34527 .63073 L p .707 .577 .707 r
F P
0 g
s
.37468 .62613 m .37324 .58928 L .40506 .58734 L p .707 .577 .707 r
F P
0 g
s
.40506 .58734 m .4065 .6242 L .37468 .62613 L p .707 .577 .707 r
F P
0 g
s
.46768 .6812 m .46265 .69953 L .43623 .68985 L p .707 .577 .707 r
F P
0 g
s
.43623 .68985 m .44126 .67152 L .46768 .6812 L p .707 .577 .707 r
F P
0 g
s
.34701 .66723 m .35205 .6489 L .38047 .65454 L p .707 .577 .707 r
F P
0 g
s
.38047 .65454 m .37544 .67287 L .34701 .66723 L p .707 .577 .707 r
F P
0 g
s
.44126 .67152 m .43623 .68985 L .40618 .68067 L p .707 .577 .707 r
F P
0 g
s
.40618 .68067 m .41121 .66234 L .44126 .67152 L p .707 .577 .707 r
F P
0 g
s
.37544 .67287 m .38047 .65454 L .41121 .66234 L p .707 .577 .707 r
F P
0 g
s
.41121 .66234 m .40618 .68067 L .37544 .67287 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOolG0007FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001HOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo5`00?goo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007Ool80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000kOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0000=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0039o
o`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
0000<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00004FUH01000
FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040003FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo001BOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YF000060001UYF00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`80009JEP03001JEUYF00=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1`0015YF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJ
EP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool004Qoo`T000=oo`<0009JEP8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000jOol>0004FUH00`00FUIJEP02FUH800000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYF
FUH80008FUH60003FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP02000^Ool003Ioo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EPH000IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000^Ool003=oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH02000FUIJEUYF001JEP00FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2000^Ool0035oo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@002ioo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002ioo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH;0005FUH0
0`00FUIJEP06FUH60004FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEPL000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF00006@001UYF00L005YFFUIJEP00FUH0000^
Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEP0000<0009JEP05001JEP00FUH00006FUH50004FUH00`00
FUIJEP08FUH400000eYF001JEP020002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF2@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPP000=JEP8002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF00D005YF001JEP00
00IJEPD000AJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP050003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00FUH20003FUH500001UYF001JEP00FUH000IJEP@000EJEP04001JEUYFFUH400000eYF001JEP05
FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000X00003FUH00000
01L000EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH50004FUH01000FUIJEUYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03
001JEUYF00AJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001J
EUYF00AJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@000eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1@0000=JEP0000001P000eYF00<005YFFUH01UYF00<005YFFUH015YF
1@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF2@001eYF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YF
FUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP8000AJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP@00003FUH005YF00AJEP8000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEPP000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00;Goo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH20004FUH00`00FUH000040006FUH00`00FUIJ
EP07FUH01@00FUH00000FUH010002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000P000=JEP03001JEUYF008002eoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF4@0000=JEP00FUH015YF0`001UYF00<005YF000010001UYF10000UYF00<005YFFUH01eYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30004FUH40002FUH2000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP03001JEUYF00=JEPD000AJ
EPH000MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool20002FUH01000FUIJEUYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00IJEP03
001JEP0000T00004FUH000000004FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH60008
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05FUH200000eYF001JEP03FUH3000]Ool002eoo`80
009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
0003FUH005YF00IJEP03001JEUYF009JEPL000AJEP@00003FUH005YF00IJEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP04
001JEP000004FUH3000]Ool002ioo`06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF1@0015YF
00@005YFFUIJEP<000EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP@000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP<00003FUH0000000<000IJEP@00003FUH0
05YF00EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP04FUH00`00FUIJEP02000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00QJEP03001JEUYF00AJEP@000MJEP8000IJEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YF00000`0015YF0`000eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEP00
FUH005YF00@0009JEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH00000FUH00003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000002
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00@005YFFUH002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF0005FUH50006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF0P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF20000Woo0`000eYF00<007ooOol0;7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000015YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH015YF2@0015YF00<005YFFUH00UYF2@0037oo00<005YF
FUH00UYF00<007ooOol0:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF00EJEP@000IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH30002Ool9000FOol01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF20005goo10000UYF00<005YFFUH0
0eYF00H005YFFUH005YF0006FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00@005YFFUIJEP<000Ioo`D001Moo`04001JEUYF000]
Ool002aoo`03001JEP0000AJEP@0015oo`<000moo`@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH015YF1@000eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00001Woo1@005goo00D005YF001JEP0002aoo`00;7oo00<005YF00000UYF
1@004Goo1@004Woo0`0000MJEP00FUIJEP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH:
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
00050006FUH01000FUIJEUYF0P001goo1@0067oo0P0000=JEP00Ool0:goo000/Ool00`00FUH00003
0004FUH3000>Ool5000COol40002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP030004FUH01000FUIJEUYF0P0027oo0`006Woo00<005YF0000;7oo000/Ool0
0`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000?Ool400002EYF001JEUYF001J
EP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01P00FUIJEUYF001JEP<00003
FUH005YF009JEP03001oogoo02Aoo`03001JEP0002aoo`00;7oo0P000eYF00<005YFFUH00eYF00<0
05YFFUH00eYF1P001Goo0`002Woo1P001EYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH200000eYF0000000WOol00`00FUH0000/
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001J
EUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00002FUH40005FUH3000XOol2000]Ool002aoo`80009JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP03001JEUYF00=J
EP03001JEUYF008002Ioo`8002eoo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Goo0`00
;Goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF00000UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P008Woo0P0000=J
EP00Ool0;Goo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH0
10002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF
00<005YF00000eYF0P000eYF00@005YF000000=JEP80025oo`03001JEUYF008002ioo`00;goo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`0000EJEP00
001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYF0003FUH5
000OOol20003FUH00`00Oomoo`0]Ool0031oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEPT000=JEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF009JEP8000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0
00AJEP04001JEP000004FUH40006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0]Ool0039o
o`<00003FUH005YF00IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF00800003FUH005YF00<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04001JEP00FUH600000eYF001J
EP06FUH00`00FUIJEP04000@Ool50004FUH00`00FUIJEP02000`Ool003Eoo`D000AJEPP000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EQ0000=JEP03001JEUYF00=JEP<0039oo`00=Woo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP800003FUH005YF00=JEP03001JEUYF009JEP@000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo039oo`00<Goo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPP000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEP0000800003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000eOol002aoo`D00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH:0003Ool2
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000080003FUH00`00FUH000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000=goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=0008Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00UYF10000UYF0`0017oo2@0015YF
00<005YFFUH00UYF1P00>Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH>000@Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH00`0000=JEP00Ool037oo2@00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH=000JOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1000EGoo000/Ool00`00FUH00004
FUH01000FUIJEUYF3@008Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00;7oo2`00<7oo0P000UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo05Aoo`00
JGoo0`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00=JEP04001JEP000002FUH00`00Oomoo`1D
Ool006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEP000008FUH01000FUIJEUYF1P000UYF00<007ooOol0E7oo001]Ool3
0004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUHB0002Ool2000015YF001JEP00Egoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06000BOol00`00FUIJEP02FUH2001GOol007=o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009oo`D0011oo`03001J
EUYF00=JEP03001oogoo05Ioo`00Mgoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPH000Moo`D000ioo`<000AJEP03001oogoo05Moo`00OGoo7`003Goo1@003Goo00D005YFFUIJ
EP00009JEP03001oogoo05Qoo`00SGoo00D005YFFUH005YF008001Ioo`<000aoo`8000AJEP03001J
EP0005]oo`00SGoo00<005YFFUH00P009Goo0P001eYF00<007ooOol0FWoo002=Ool01000FUIJEP00
97oo0P0000=JEP00FUH015YF0P00GGoo002=Ool3000ROol30003FUH01000FUIJEUYF0P00Ggoo002>
Ool2000NOol40007FUH3001QOol008ioo`8001Yoo`@0009JEP03001JEUYF00IJEP03001oogoo065o
o`00SWoo00<005YF000057oo1@001UYF00<005YFFUH015YF0P00I7oo002>Ool2000015YF00000000
3Goo10000UYF00<005YFFUH01eYF00@005YFFUIJEP8006Ioo`00Sgoo00<005YF00000UYF3@001UYF
00<005YFFUH01eYF00@005YF000006Qoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEP@006Yoo`00T7oo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01000KWoo002AOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH4001b
Ool009=oo`<0009JEP03001JEUYF00EJEP03001JEUYF00@007Ioo`00UWoo3@00NWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60386 .74883 m .60355 .69329 L .5724 .69151 L p .707 .577 .707 r
F P
0 g
s
.60355 .69329 m .60386 .74883 L .63571 .74791 L p .707 .577 .707 r
F P
0 g
s
.63571 .74791 m .63539 .69236 L .60355 .69329 L p .707 .577 .707 r
F P
0 g
s
.63539 .69236 m .63571 .74791 L .66513 .74437 L p .707 .577 .707 r
F P
0 g
s
.66513 .74437 m .66481 .68882 L .63539 .69236 L p .707 .577 .707 r
F P
0 g
s
.57271 .74706 m .5724 .69151 L .54499 .6872 L p .707 .577 .707 r
F P
0 g
s
.5724 .69151 m .57271 .74706 L .60386 .74883 L p .707 .577 .707 r
F P
0 g
s
.66481 .68882 m .66513 .74437 L .68924 .73856 L p .707 .577 .707 r
F P
0 g
s
.68924 .73856 m .68893 .68302 L .66481 .68882 L p .707 .577 .707 r
F P
0 g
s
.59187 .80726 m .59419 .77002 L .56312 .76642 L p .707 .577 .707 r
F P
0 g
s
.59419 .77002 m .59187 .80726 L .62366 .80847 L p .707 .577 .707 r
F P
0 g
s
.62366 .80847 m .62599 .77123 L .59419 .77002 L p .707 .577 .707 r
F P
0 g
s
.62599 .77123 m .62366 .80847 L .65306 .80718 L p .707 .577 .707 r
F P
0 g
s
.65306 .80718 m .65539 .76994 L .62599 .77123 L p .707 .577 .707 r
F P
0 g
s
.54499 .6872 m .54531 .74275 L .57271 .74706 L p .707 .577 .707 r
F P
0 g
s
.54531 .74275 m .54499 .6872 L .52401 .68079 L p .707 .577 .707 r
F P
0 g
s
.56079 .80366 m .56312 .76642 L .53581 .76079 L p .707 .577 .707 r
F P
0 g
s
.56312 .76642 m .56079 .80366 L .59187 .80726 L p .707 .577 .707 r
F P
0 g
s
.65539 .76994 m .65306 .80718 L .67719 .8035 L p .707 .577 .707 r
F P
0 g
s
.67719 .8035 m .67952 .76626 L .65539 .76994 L p .707 .577 .707 r
F P
0 g
s
.53581 .76079 m .53348 .79803 L .56079 .80366 L p .707 .577 .707 r
F P
0 g
s
.68893 .68302 m .68924 .73856 L .7057 .73106 L p .707 .577 .707 r
F P
0 g
s
.7057 .73106 m .70538 .67551 L .68893 .68302 L p .707 .577 .707 r
F P
0 g
s
.621 .85854 m .61302 .84281 L .58402 .85575 L p .707 .577 .707 r
F P
0 g
s
.61302 .84281 m .621 .85854 L .64791 .84221 L p .707 .577 .707 r
F P
0 g
s
.64791 .84221 m .63993 .82647 L .61302 .84281 L p .707 .577 .707 r
F P
0 g
s
.52401 .68079 m .52432 .73633 L .54531 .74275 L p .707 .577 .707 r
F P
0 g
s
.59199 .87148 m .58402 .85575 L .55575 .86401 L p .707 .577 .707 r
F P
0 g
s
.58402 .85575 m .59199 .87148 L .621 .85854 L p .707 .577 .707 r
F P
0 g
s
.53348 .79803 m .53581 .76079 L .51493 .75368 L p .707 .577 .707 r
F P
0 g
s
.63993 .82647 m .64791 .84221 L .67008 .82406 L p .707 .577 .707 r
F P
0 g
s
.67008 .82406 m .66211 .80833 L .63993 .82647 L p .707 .577 .707 r
F P
0 g
s
.52432 .73633 m .52401 .68079 L .5115 .67289 L p .707 .577 .707 r
F P
0 g
s
.55575 .86401 m .56372 .87975 L .59199 .87148 L p .707 .577 .707 r
F P
0 g
s
.51493 .75368 m .5126 .79092 L .53348 .79803 L p .707 .577 .707 r
F P
0 g
s
.56372 .87975 m .55575 .86401 L .53099 .8668 L p .707 .577 .707 r
F P
0 g
s
.67952 .76626 m .67719 .8035 L .69369 .79781 L p .707 .577 .707 r
F P
0 g
s
.69369 .79781 m .69602 .76057 L .67952 .76626 L p .707 .577 .707 r
F P
0 g
s
.66211 .80833 m .67008 .82406 L .68536 .80589 L p .707 .577 .707 r
F P
0 g
s
.68536 .80589 m .67738 .79016 L .66211 .80833 L p .707 .577 .707 r
F P
0 g
s
.53099 .8668 m .53896 .88254 L .56372 .87975 L p .707 .577 .707 r
F P
0 g
s
.70538 .67551 m .7057 .73106 L .71287 .72259 L p .707 .577 .707 r
F P
0 g
s
.71287 .72259 m .71255 .66705 L .70538 .67551 L p .707 .577 .707 r
F P
0 g
s
.5115 .67289 m .51182 .72844 L .52432 .73633 L p .707 .577 .707 r
F P
0 g
s
.5126 .79092 m .51493 .75368 L .50253 .74578 L p .707 .577 .707 r
F P
0 g
s
.53896 .88254 m .53099 .8668 L .51216 .86384 L p .707 .577 .707 r
F P
0 g
s
.50253 .74578 m .5002 .78302 L .5126 .79092 L p .707 .577 .707 r
F P
0 g
s
.51182 .72844 m .5115 .67289 L .5087 .66429 L p .707 .577 .707 r
F P
0 g
s
.67738 .79016 m .68536 .80589 L .69223 .78948 L p .707 .577 .707 r
F P
0 g
s
.69223 .78948 m .68426 .77374 L .67738 .79016 L p .707 .577 .707 r
F P
0 g
s
.51216 .86384 m .52014 .87957 L .53896 .88254 L p .707 .577 .707 r
F P
0 g
s
.69602 .76057 m .69369 .79781 L .70094 .79066 L p .707 .577 .707 r
F P
0 g
s
.70094 .79066 m .70327 .75342 L .69602 .76057 L p .707 .577 .707 r
F P
0 g
s
.5087 .66429 m .50902 .71984 L .51182 .72844 L p .707 .577 .707 r
F P
0 g
s
.5002 .78302 m .50253 .74578 L .49983 .73787 L p .707 .577 .707 r
F P
0 g
s
.71255 .66705 m .71287 .72259 L .71007 .71399 L p .707 .577 .707 r
F P
0 g
s
.71007 .71399 m .70975 .65845 L .71255 .66705 L p .707 .577 .707 r
F P
0 g
s
.52014 .87957 m .51216 .86384 L .50111 .85542 L p .707 .577 .707 r
F P
0 g
s
.49518 .8219 m .49518 .32001 L .45086 .31772 L p .707 .577 .707 r
F P
0 g
s
.49983 .73787 m .4975 .77511 L .5002 .78302 L p .707 .577 .707 r
F P
0 g
s
.50902 .71984 m .5087 .66429 L .51588 .65583 L p .707 .577 .707 r
F P
0 g
s
.51588 .65583 m .5162 .71137 L .50902 .71984 L p .707 .577 .707 r
F P
0 g
s
.4975 .77511 m .49983 .73787 L .50708 .73072 L p .707 .577 .707 r
F P
0 g
s
.50708 .73072 m .50475 .76796 L .4975 .77511 L p .707 .577 .707 r
F P
0 g
s
.5162 .71137 m .51588 .65583 L .53233 .64832 L p .707 .577 .707 r
F P
0 g
s
.53233 .64832 m .53265 .70387 L .5162 .71137 L p .707 .577 .707 r
F P
0 g
s
.50475 .76796 m .50708 .73072 L .52357 .72503 L p .707 .577 .707 r
F P
0 g
s
.52357 .72503 m .52124 .76227 L .50475 .76796 L p .707 .577 .707 r
F P
0 g
s
.52124 .76227 m .52357 .72503 L .5477 .72135 L p .707 .577 .707 r
F P
0 g
s
.51376 .84167 m .50579 .82594 L .52106 .80777 L p .707 .577 .707 r
F P
0 g
s
.5477 .72135 m .54538 .75859 L .52124 .76227 L p .707 .577 .707 r
F P
0 g
s
.52106 .80777 m .52903 .8235 L .51376 .84167 L p .707 .577 .707 r
F P
0 g
s
.52903 .8235 m .52106 .80777 L .54324 .78963 L p .707 .577 .707 r
F P
0 g
s
.54324 .78963 m .55121 .80536 L .52903 .8235 L p .707 .577 .707 r
F P
0 g
s
.49518 .32001 m .49518 .8219 L .53996 .82041 L p .707 .577 .707 r
F P
0 g
s
.53265 .70387 m .53233 .64832 L .55645 .64252 L p .707 .577 .707 r
F P
0 g
s
.55645 .64252 m .55676 .69806 L .53265 .70387 L p .707 .577 .707 r
F P
0 g
s
.53996 .82041 m .53996 .31852 L .49518 .32001 L p .707 .577 .707 r
F P
0 g
s
.55676 .69806 m .55645 .64252 L .58587 .63898 L p .707 .577 .707 r
F P
0 g
s
.58587 .63898 m .58618 .69452 L .55676 .69806 L p .707 .577 .707 r
F P
0 g
s
.54538 .75859 m .5477 .72135 L .5771 .72006 L p .707 .577 .707 r
F P
0 g
s
.5771 .72006 m .57478 .7573 L .54538 .75859 L p .707 .577 .707 r
F P
0 g
s
.57478 .7573 m .5771 .72006 L .6089 .72127 L p .707 .577 .707 r
F P
0 g
s
.60713 .77609 m .59916 .76035 L .62742 .75208 L p .707 .577 .707 r
F P
0 g
s
.6089 .72127 m .60657 .75851 L .57478 .7573 L p .707 .577 .707 r
F P
0 g
s
.55121 .80536 m .54324 .78963 L .57015 .77329 L p .707 .577 .707 r
F P
0 g
s
.59916 .76035 m .60713 .77609 L .57812 .78902 L p .707 .577 .707 r
F P
0 g
s
.57812 .78902 m .57015 .77329 L .59916 .76035 L p .707 .577 .707 r
F P
0 g
s
.57015 .77329 m .57812 .78902 L .55121 .80536 L p .707 .577 .707 r
F P
0 g
s
.53996 .31852 m .53996 .82041 L .58083 .81527 L p .707 .577 .707 r
F P
0 g
s
.58083 .81527 m .58083 .31339 L .53996 .31852 L p .707 .577 .707 r
F P
0 g
s
.68426 .77374 m .69223 .78948 L .69003 .77642 L p .707 .577 .707 r
F P
0 g
s
.69003 .77642 m .68206 .76068 L .68426 .77374 L p .707 .577 .707 r
F P
0 g
s
.50111 .85542 m .50908 .87115 L .52014 .87957 L p .707 .577 .707 r
F P
0 g
s
.45086 .81961 m .45086 .31772 L .41136 .31186 L p .707 .577 .707 r
F P
0 g
s
.45086 .31772 m .45086 .81961 L .49518 .8219 L p .707 .577 .707 r
F P
0 g
s
.70327 .75342 m .70094 .79066 L .69823 .78275 L p .707 .577 .707 r
F P
0 g
s
.69823 .78275 m .70056 .74551 L .70327 .75342 L p .707 .577 .707 r
F P
0 g
s
.25626 .71431 m .25612 .65864 L .22497 .65682 L p .707 .577 .707 r
F P
0 g
s
.25612 .65864 m .25626 .71431 L .2881 .7135 L p .707 .577 .707 r
F P
0 g
s
.2881 .7135 m .28797 .65783 L .25612 .65864 L p .707 .577 .707 r
F P
0 g
s
.58618 .69452 m .58587 .63898 L .61771 .63805 L p .707 .577 .707 r
F P
0 g
s
.61771 .63805 m .61803 .6936 L .58618 .69452 L p .707 .577 .707 r
F P
0 g
s
.62742 .75208 m .6354 .76782 L .60713 .77609 L p .707 .577 .707 r
F P
0 g
s
.6354 .76782 m .62742 .75208 L .65218 .7493 L p .707 .577 .707 r
F P
0 g
s
.63997 .72487 m .63764 .76211 L .60657 .75851 L p .707 .577 .707 r
F P
0 g
s
.60657 .75851 m .6089 .72127 L .63997 .72487 L p .707 .577 .707 r
F P
0 g
s
.58083 .31339 m .58083 .81527 L .6138 .807 L p .707 .577 .707 r
F P
0 g
s
.6138 .807 m .6138 .30511 L .58083 .31339 L p .707 .577 .707 r
F P
0 g
s
.70975 .65845 m .71007 .71399 L .69757 .7061 L p .707 .577 .707 r
F P
0 g
s
.69757 .7061 m .69725 .65055 L .70975 .65845 L p .707 .577 .707 r
F P
0 g
s
.28797 .65783 m .2881 .7135 L .31752 .71014 L p .707 .577 .707 r
F P
0 g
s
.31752 .71014 m .31739 .65448 L .28797 .65783 L p .707 .577 .707 r
F P
0 g
s
.50908 .87115 m .50111 .85542 L .49891 .84236 L p .707 .577 .707 r
F P
0 g
s
.41136 .81375 m .41136 .31186 L .38053 .30302 L p .707 .577 .707 r
F P
0 g
s
.41136 .31186 m .41136 .81375 L .45086 .81961 L p .707 .577 .707 r
F P
0 g
s
.22511 .71249 m .22497 .65682 L .19756 .65256 L p .707 .577 .707 r
F P
0 g
s
.22497 .65682 m .22511 .71249 L .25626 .71431 L p .707 .577 .707 r
F P
0 g
s
.68206 .76068 m .69003 .77642 L .67898 .76799 L p .707 .577 .707 r
F P
0 g
s
.67898 .76799 m .67101 .75226 L .68206 .76068 L p .707 .577 .707 r
F P
0 g
s
.49891 .84236 m .50689 .85809 L .50908 .87115 L p .707 .577 .707 r
F P
0 g
s
.31739 .65448 m .31752 .71014 L .34164 .70457 L p .707 .577 .707 r
F P
0 g
s
.34164 .70457 m .3415 .6489 L .31739 .65448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70056 .74551 m .69823 .78275 L .68583 .77485 L p .707 .577 .707 r
F P
0 g
s
.68583 .77485 m .68816 .73761 L .70056 .74551 L p .707 .577 .707 r
F P
0 g
s
.19756 .65256 m .1977 .70823 L .22511 .71249 L p .707 .577 .707 r
F P
0 g
s
.1977 .70823 m .19756 .65256 L .17658 .64626 L p .707 .577 .707 r
F P
0 g
s
.69725 .65055 m .69757 .7061 L .67659 .69968 L p .707 .577 .707 r
F P
0 g
s
.67659 .69968 m .67627 .64414 L .69725 .65055 L p .707 .577 .707 r
F P
0 g
s
.64886 .63983 m .64918 .69537 L .61803 .6936 L p .707 .577 .707 r
F P
0 g
s
.61803 .6936 m .61771 .63805 L .64886 .63983 L p .707 .577 .707 r
F P
0 g
s
.6138 .30511 m .6138 .807 L .63562 .7964 L p .707 .577 .707 r
F P
0 g
s
.65218 .7493 m .66015 .76503 L .6354 .76782 L p .707 .577 .707 r
F P
0 g
s
.63562 .7964 m .63562 .29451 L .6138 .30511 L p .707 .577 .707 r
F P
0 g
s
.25101 .77775 m .25201 .7414 L .22089 .73827 L p .707 .577 .707 r
F P
0 g
s
.25201 .7414 m .25101 .77775 L .28285 .77764 L p .707 .577 .707 r
F P
0 g
s
.28285 .77764 m .28385 .74129 L .25201 .7414 L p .707 .577 .707 r
F P
0 g
s
.50689 .85809 m .49891 .84236 L .50579 .82594 L p .707 .577 .707 r
F P
0 g
s
.3415 .6489 m .34164 .70457 L .35809 .69732 L p .707 .577 .707 r
F P
0 g
s
.35809 .69732 m .35796 .64166 L .3415 .6489 L p .707 .577 .707 r
F P
0 g
s
.28385 .74129 m .28285 .77764 L .31229 .7743 L p .707 .577 .707 r
F P
0 g
s
.31229 .7743 m .31329 .73795 L .28385 .74129 L p .707 .577 .707 r
F P
0 g
s
.38053 .80491 m .38053 .30302 L .3614 .29205 L p .707 .577 .707 r
F P
0 g
s
.38053 .30302 m .38053 .80491 L .41136 .81375 L p .707 .577 .707 r
F P
0 g
s
.17658 .64626 m .17672 .70193 L .1977 .70823 L p .707 .577 .707 r
F P
0 g
s
.21989 .77462 m .22089 .73827 L .19352 .73221 L p .707 .577 .707 r
F P
0 g
s
.22089 .73827 m .21989 .77462 L .25101 .77775 L p .707 .577 .707 r
F P
0 g
s
.67101 .75226 m .67898 .76799 L .66015 .76503 L p .707 .577 .707 r
F P
0 g
s
.66015 .76503 m .65218 .7493 L .67101 .75226 L p .707 .577 .707 r
F P
0 g
s
.50579 .82594 m .51376 .84167 L .50689 .85809 L p .707 .577 .707 r
F P
0 g
s
.17672 .70193 m .17658 .64626 L .16408 .63855 L p .707 .577 .707 r
F P
0 g
s
.31329 .73795 m .31229 .7743 L .33644 .76806 L p .707 .577 .707 r
F P
0 g
s
.33644 .76806 m .33744 .73171 L .31329 .73795 L p .707 .577 .707 r
F P
0 g
s
.68816 .73761 m .68583 .77485 L .66496 .76774 L p .707 .577 .707 r
F P
0 g
s
.66496 .76774 m .66728 .7305 L .68816 .73761 L p .707 .577 .707 r
F P
0 g
s
.21912 .75917 m .22271 .77784 L .25344 .77106 L p .707 .577 .707 r
F P
0 g
s
.25344 .77106 m .24984 .75239 L .21912 .75917 L p .707 .577 .707 r
F P
0 g
s
.24984 .75239 m .25344 .77106 L .28467 .7657 L p .707 .577 .707 r
F P
0 g
s
.19352 .73221 m .19253 .76856 L .21989 .77462 L p .707 .577 .707 r
F P
0 g
s
.67627 .64414 m .67659 .69968 L .64918 .69537 L p .707 .577 .707 r
F P
0 g
s
.64918 .69537 m .64886 .63983 L .67627 .64414 L p .707 .577 .707 r
F P
0 g
s
.19253 .76856 m .19352 .73221 L .1726 .72381 L p .707 .577 .707 r
F P
0 g
s
.28467 .7657 m .28107 .74703 L .24984 .75239 L p .707 .577 .707 r
F P
0 g
s
.28107 .74703 m .28467 .7657 L .31334 .76229 L p .707 .577 .707 r
F P
0 g
s
.1726 .72381 m .1716 .76016 L .19253 .76856 L p .707 .577 .707 r
F P
0 g
s
.1919 .76672 m .19549 .78539 L .22271 .77784 L p .707 .577 .707 r
F P
0 g
s
.22271 .77784 m .21912 .75917 L .1919 .76672 L p .707 .577 .707 r
F P
0 g
s
.31334 .76229 m .30974 .74362 L .28107 .74703 L p .707 .577 .707 r
F P
0 g
s
.16408 .63855 m .16421 .69422 L .17672 .70193 L p .707 .577 .707 r
F P
0 g
s
.35796 .64166 m .35809 .69732 L .36527 .68911 L p .707 .577 .707 r
F P
0 g
s
.36527 .68911 m .36513 .63345 L .35796 .64166 L p .707 .577 .707 r
F P
0 g
s
.33744 .73171 m .33644 .76806 L .35295 .75952 L p .707 .577 .707 r
F P
0 g
s
.35295 .75952 m .35395 .72318 L .33744 .73171 L p .707 .577 .707 r
F P
0 g
s
.66728 .7305 m .66496 .76774 L .63764 .76211 L p .707 .577 .707 r
F P
0 g
s
.63764 .76211 m .63997 .72487 L .66728 .7305 L p .707 .577 .707 r
F P
0 g
s
.63562 .29451 m .63562 .7964 L .64416 .78451 L p .707 .577 .707 r
F P
0 g
s
.64416 .78451 m .64416 .28262 L .63562 .29451 L p .707 .577 .707 r
F P
0 g
s
.30974 .74362 m .31334 .76229 L .33664 .76117 L p .707 .577 .707 r
F P
0 g
s
.17085 .77429 m .17445 .79296 L .19549 .78539 L p .707 .577 .707 r
F P
0 g
s
.19549 .78539 m .1919 .76672 L .17085 .77429 L p .707 .577 .707 r
F P
0 g
s
.33664 .76117 m .33305 .7425 L .30974 .74362 L p .707 .577 .707 r
F P
0 g
s
.16421 .69422 m .16408 .63855 L .16128 .63019 L p .707 .577 .707 r
F P
0 g
s
.36019 .74954 m .36119 .71319 L .35395 .72318 L p .707 .577 .707 r
F P
0 g
s
.36233 .62508 m .36247 .68075 L .34996 .67304 L p .707 .577 .707 r
F P
0 g
s
.34996 .67304 m .34983 .61737 L .36233 .62508 L p .707 .577 .707 r
F P
0 g
s
.35395 .72318 m .35295 .75952 L .36019 .74954 L p .707 .577 .707 r
F P
0 g
s
.36119 .71319 m .36019 .74954 L .35746 .73907 L p .707 .577 .707 r
F P
0 g
s
.35746 .73907 m .35846 .70273 L .36119 .71319 L p .707 .577 .707 r
F P
0 g
s
.3614 .79394 m .3614 .29205 L .35583 .28004 L p .707 .577 .707 r
F P
0 g
s
.36513 .63345 m .36527 .68911 L .36247 .68075 L p .707 .577 .707 r
F P
0 g
s
.36247 .68075 m .36233 .62508 L .36513 .63345 L p .707 .577 .707 r
F P
0 g
s
.3614 .29205 m .3614 .79394 L .38053 .80491 L p .707 .577 .707 r
F P
0 g
s
.1716 .76016 m .1726 .72381 L .16016 .71389 L p .707 .577 .707 r
F P
0 g
s
.16128 .63019 m .16141 .68585 L .16421 .69422 L p .707 .577 .707 r
F P
0 g
s
.16016 .71389 m .15917 .75024 L .1716 .76016 L p .707 .577 .707 r
F P
0 g
s
.33305 .7425 m .33664 .76117 L .35231 .76244 L p .707 .577 .707 r
F P
0 g
s
.35231 .76244 m .34871 .74377 L .33305 .7425 L p .707 .577 .707 r
F P
0 g
s
.15804 .78114 m .16163 .79981 L .17445 .79296 L p .707 .577 .707 r
F P
0 g
s
.17445 .79296 m .17085 .77429 L .15804 .78114 L p .707 .577 .707 r
F P
0 g
s
.15917 .75024 m .16016 .71389 L .15743 .70343 L p .707 .577 .707 r
F P
0 g
s
.16141 .68585 m .16128 .63019 L .16845 .62198 L p .707 .577 .707 r
F P
0 g
s
.64416 .28262 m .64416 .78451 L .6386 .7725 L p .707 .577 .707 r
F P
0 g
s
.6386 .7725 m .6386 .27061 L .64416 .28262 L p .707 .577 .707 r
F P
0 g
s
.15743 .70343 m .15644 .73978 L .15917 .75024 L p .707 .577 .707 r
F P
0 g
s
.34871 .74377 m .35231 .76244 L .35879 .76598 L p .707 .577 .707 r
F P
0 g
s
.35879 .76598 m .3552 .74731 L .34871 .74377 L p .707 .577 .707 r
F P
0 g
s
.3552 .74731 m .35879 .76598 L .35546 .77144 L p .707 .577 .707 r
F P
0 g
s
.35846 .70273 m .35746 .73907 L .34503 .72915 L p .707 .577 .707 r
F P
0 g
s
.34503 .72915 m .34602 .69281 L .35846 .70273 L p .707 .577 .707 r
F P
0 g
s
.35583 .28004 m .35583 .78192 L .3614 .79394 L p .707 .577 .707 r
F P
0 g
s
.35583 .78192 m .35583 .28004 L .36438 .26814 L p .707 .577 .707 r
F P
0 g
s
.16845 .62198 m .16859 .67764 L .16141 .68585 L p .707 .577 .707 r
F P
0 g
s
.15471 .7866 m .15831 .80528 L .16163 .79981 L p .707 .577 .707 r
F P
0 g
s
.16163 .79981 m .15804 .78114 L .15471 .7866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15644 .73978 m .15743 .70343 L .16467 .69344 L p .707 .577 .707 r
F P
0 g
s
.16859 .67764 m .16845 .62198 L .1849 .61473 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16467 .69344 m .16368 .72979 L .15644 .73978 L p .707 .577 .707 r
F P
0 g
s
.1849 .61473 m .18504 .6704 L .16859 .67764 L p .707 .577 .707 r
F P
0 g
s
.34983 .61737 m .34996 .67304 L .32898 .66674 L p .707 .577 .707 r
F P
0 g
s
.32898 .66674 m .32884 .61107 L .34983 .61737 L p .707 .577 .707 r
F P
0 g
s
.35546 .77144 m .35187 .75277 L .3552 .74731 L p .707 .577 .707 r
F P
0 g
s
.6386 .27061 m .6386 .7725 L .61947 .76153 L p .707 .577 .707 r
F P
0 g
s
.61947 .76153 m .61947 .25964 L .6386 .27061 L p .707 .577 .707 r
F P
0 g
s
.1612 .79014 m .16479 .80882 L .15831 .80528 L p .707 .577 .707 r
F P
0 g
s
.15831 .80528 m .15471 .7866 L .1612 .79014 L p .707 .577 .707 r
F P
0 g
s
.18504 .6704 m .1849 .61473 L .20902 .60916 L p .707 .577 .707 r
F P
0 g
s
.36438 .77003 m .36438 .26814 L .3862 .25754 L p .707 .577 .707 r
F P
0 g
s
.36438 .26814 m .36438 .77003 L .35583 .78192 L p .707 .577 .707 r
F P
0 g
s
.16368 .72979 m .16467 .69344 L .18118 .68491 L p .707 .577 .707 r
F P
0 g
s
.32884 .61107 m .32898 .66674 L .30157 .66248 L p .707 .577 .707 r
F P
0 g
s
.30157 .66248 m .30144 .60681 L .32884 .61107 L p .707 .577 .707 r
F P
0 g
s
.20902 .60916 m .20916 .66482 L .18504 .6704 L p .707 .577 .707 r
F P
0 g
s
.18118 .68491 m .18018 .72126 L .16368 .72979 L p .707 .577 .707 r
F P
0 g
s
.34602 .69281 m .34503 .72915 L .3241 .72075 L p .707 .577 .707 r
F P
0 g
s
.3241 .72075 m .3251 .68441 L .34602 .69281 L p .707 .577 .707 r
F P
0 g
s
.35187 .75277 m .35546 .77144 L .34265 .7783 L p .707 .577 .707 r
F P
0 g
s
.20916 .66482 m .20902 .60916 L .23844 .6058 L p .707 .577 .707 r
F P
0 g
s
.34265 .7783 m .33905 .75962 L .35187 .75277 L p .707 .577 .707 r
F P
0 g
s
.17686 .79141 m .18046 .81009 L .16479 .80882 L p .707 .577 .707 r
F P
0 g
s
.16479 .80882 m .1612 .79014 L .17686 .79141 L p .707 .577 .707 r
F P
0 g
s
.30144 .60681 m .30157 .66248 L .27042 .66066 L p .707 .577 .707 r
F P
0 g
s
.27042 .66066 m .27028 .60499 L .30144 .60681 L p .707 .577 .707 r
F P
0 g
s
.18018 .72126 m .18118 .68491 L .20533 .67867 L p .707 .577 .707 r
F P
0 g
s
.61947 .25964 m .61947 .76153 L .58864 .75268 L p .707 .577 .707 r
F P
0 g
s
.58864 .75268 m .58864 .25079 L .61947 .25964 L p .707 .577 .707 r
F P
0 g
s
.23858 .66147 m .23844 .6058 L .27028 .60499 L p .707 .577 .707 r
F P
0 g
s
.23844 .6058 m .23858 .66147 L .20916 .66482 L p .707 .577 .707 r
F P
0 g
s
.27028 .60499 m .27042 .66066 L .23858 .66147 L p .707 .577 .707 r
F P
0 g
s
.3862 .25754 m .3862 .75943 L .36438 .77003 L p .707 .577 .707 r
F P
0 g
s
.3862 .75943 m .3862 .25754 L .41916 .24927 L p .707 .577 .707 r
F P
0 g
s
.20533 .67867 m .20434 .71502 L .18018 .72126 L p .707 .577 .707 r
F P
0 g
s
.3251 .68441 m .3241 .72075 L .29674 .71469 L p .707 .577 .707 r
F P
0 g
s
.29674 .71469 m .29774 .67835 L .3251 .68441 L p .707 .577 .707 r
F P
0 g
s
.33905 .75962 m .34265 .7783 L .3216 .78587 L p .707 .577 .707 r
F P
0 g
s
.20434 .71502 m .20533 .67867 L .23477 .67533 L p .707 .577 .707 r
F P
0 g
s
.3216 .78587 m .31801 .76719 L .33905 .75962 L p .707 .577 .707 r
F P
0 g
s
.72958 .65582 m .72971 .60032 L .69856 .59829 L p .707 .577 .707 r
F P
0 g
s
.72971 .60032 m .72958 .65582 L .76142 .65512 L p .707 .577 .707 r
F P
0 g
s
.76142 .65512 m .76156 .59963 L .72971 .60032 L p .707 .577 .707 r
F P
0 g
s
.20017 .79029 m .20376 .80896 L .18046 .81009 L p .707 .577 .707 r
F P
0 g
s
.18046 .81009 m .17686 .79141 L .20017 .79029 L p .707 .577 .707 r
F P
0 g
s
.76156 .59963 m .76142 .65512 L .79084 .65177 L p .707 .577 .707 r
F P
0 g
s
.79084 .65177 m .79098 .59627 L .76156 .59963 L p .707 .577 .707 r
F P
0 g
s
.29774 .67835 m .29674 .71469 L .26561 .71156 L p .707 .577 .707 r
F P
0 g
s
.26561 .71156 m .26661 .67522 L .29774 .67835 L p .707 .577 .707 r
F P
0 g
s
.69843 .65378 m .69856 .59829 L .67115 .59372 L p .707 .577 .707 r
F P
0 g
s
.69856 .59829 m .69843 .65378 L .72958 .65582 L p .707 .577 .707 r
F P
0 g
s
.23377 .71168 m .23477 .67533 L .26661 .67522 L p .707 .577 .707 r
F P
0 g
s
.23477 .67533 m .23377 .71168 L .20434 .71502 L p .707 .577 .707 r
F P
0 g
s
.73438 .71292 m .73339 .67532 L .70226 .67459 L p .707 .577 .707 r
F P
0 g
s
.73339 .67532 m .73438 .71292 L .76622 .71154 L p .707 .577 .707 r
F P
0 g
s
.76622 .71154 m .76523 .67394 L .73339 .67532 L p .707 .577 .707 r
F P
0 g
s
.58864 .25079 m .58864 .75268 L .54913 .74683 L p .707 .577 .707 r
F P
0 g
s
.54913 .74683 m .54913 .24494 L .58864 .25079 L p .707 .577 .707 r
F P
0 g
s
.26661 .67522 m .26561 .71156 L .23377 .71168 L p .707 .577 .707 r
F P
0 g
s
.76523 .67394 m .76622 .71154 L .79566 .70819 L p .707 .577 .707 r
F P
0 g
s
.79566 .70819 m .79466 .67059 L .76523 .67394 L p .707 .577 .707 r
F P
0 g
s
.79098 .59627 m .79084 .65177 L .81496 .64608 L p .707 .577 .707 r
F P
0 g
s
.81496 .64608 m .81509 .59059 L .79098 .59627 L p .707 .577 .707 r
F P
0 g
s
.41916 .75116 m .41916 .24927 L .46004 .24414 L p .707 .577 .707 r
F P
0 g
s
.41916 .24927 m .41916 .75116 L .3862 .75943 L p .707 .577 .707 r
F P
0 g
s
.70326 .71219 m .70226 .67459 L .6749 .67183 L p .707 .577 .707 r
F P
0 g
s
.70226 .67459 m .70326 .71219 L .73438 .71292 L p .707 .577 .707 r
F P
0 g
s
.31801 .76719 m .3216 .78587 L .29439 .79341 L p .707 .577 .707 r
F P
0 g
s
.22884 .78688 m .23243 .80556 L .20376 .80896 L p .707 .577 .707 r
F P
0 g
s
.20376 .80896 m .20017 .79029 L .22884 .78688 L p .707 .577 .707 r
F P
0 g
s
.29439 .79341 m .29079 .77474 L .31801 .76719 L p .707 .577 .707 r
F P
0 g
s
.67115 .59372 m .67102 .64922 L .69843 .65378 L p .707 .577 .707 r
F P
0 g
s
.67102 .64922 m .67115 .59372 L .65017 .58708 L p .707 .577 .707 r
F P
0 g
s
.79466 .67059 m .79566 .70819 L .81981 .7032 L p .707 .577 .707 r
F P
0 g
s
.81981 .7032 m .81882 .6656 L .79466 .67059 L p .707 .577 .707 r
F P
0 g
s
.6749 .67183 m .6759 .70943 L .70326 .71219 L p .707 .577 .707 r
F P
0 g
s
.54913 .24494 m .54913 .74683 L .50482 .74454 L p .707 .577 .707 r
F P
0 g
s
.50482 .74454 m .50482 .24265 L .54913 .24494 L p .707 .577 .707 r
F P
0 g
s
.29079 .77474 m .29439 .79341 L .26366 .8002 L p .707 .577 .707 r
F P
0 g
s
.81509 .59059 m .81496 .64608 L .83141 .63862 L p .707 .577 .707 r
F P
0 g
s
.83141 .63862 m .83155 .58312 L .81509 .59059 L p .707 .577 .707 r
F P
0 g
s
.6759 .70943 m .6749 .67183 L .65397 .66731 L p .707 .577 .707 r
F P
0 g
s
.46004 .74603 m .46004 .24414 L .50482 .24265 L p .707 .577 .707 r
F P
0 g
s
.46004 .24414 m .46004 .74603 L .41916 .75116 L p .707 .577 .707 r
F P
0 g
s
.26006 .78152 m .26366 .8002 L .23243 .80556 L p .707 .577 .707 r
F P
0 g
s
.23243 .80556 m .22884 .78688 L .26006 .78152 L p .707 .577 .707 r
F P
0 g
s
.26366 .8002 m .26006 .78152 L .29079 .77474 L p .707 .577 .707 r
F P
0 g
s
.65017 .58708 m .65003 .64257 L .67102 .64922 L p .707 .577 .707 r
F P
0 g
s
.73634 .79694 m .73993 .78244 L .70921 .77372 L p .707 .577 .707 r
F P
0 g
s
.73993 .78244 m .73634 .79694 L .76756 .79932 L p .707 .577 .707 r
F P
0 g
s
.76756 .79932 m .77116 .78483 L .73993 .78244 L p .707 .577 .707 r
F P
0 g
s
.50482 .24265 m .50482 .74454 L .46004 .74603 L p .707 .577 .707 r
F P
0 g
s
.70561 .78822 m .70921 .77372 L .68199 .75952 L p .707 .577 .707 r
F P
0 g
s
.70921 .77372 m .70561 .78822 L .73634 .79694 L p .707 .577 .707 r
F P
0 g
s
.65397 .66731 m .65497 .70491 L .6759 .70943 L p .707 .577 .707 r
F P
0 g
s
.65003 .64257 m .65017 .58708 L .63767 .579 L p .707 .577 .707 r
F P
0 g
s
.77116 .78483 m .76756 .79932 L .79624 .79515 L p .707 .577 .707 r
F P
0 g
s
.79624 .79515 m .79983 .78065 L .77116 .78483 L p .707 .577 .707 r
F P
0 g
s
.81882 .6656 m .81981 .7032 L .83632 .69706 L p .707 .577 .707 r
F P
0 g
s
.83632 .69706 m .83532 .65945 L .81882 .6656 L p .707 .577 .707 r
F P
0 g
s
.67839 .77402 m .68199 .75952 L .66094 .74123 L p .707 .577 .707 r
F P
0 g
s
.68199 .75952 m .67839 .77402 L .70561 .78822 L p .707 .577 .707 r
F P
0 g
s
.65497 .70491 m .65397 .66731 L .64154 .66146 L p .707 .577 .707 r
F P
0 g
s
.79983 .78065 m .79624 .79515 L .81954 .78481 L p .707 .577 .707 r
F P
0 g
s
.81954 .78481 m .82314 .77032 L .79983 .78065 L p .707 .577 .707 r
F P
0 g
s
.83155 .58312 m .83141 .63862 L .83859 .63011 L p .707 .577 .707 r
F P
0 g
s
.83859 .63011 m .83872 .57461 L .83155 .58312 L p .707 .577 .707 r
F P
0 g
s
.63767 .579 m .63753 .63449 L .65003 .64257 L p .707 .577 .707 r
F P
0 g
s
.66094 .74123 m .65735 .75573 L .67839 .77402 L p .707 .577 .707 r
F P
0 g
s
.65735 .75573 m .66094 .74123 L .64813 .72065 L p .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64813 .72065 L .64789 .71916 L p .707 .577 .707 r
F P
0 g
s
.64154 .66146 m .64254 .69906 L .65209 .70355 L p .707 .577 .707 r
F P
0 g
s
.64789 .71916 m .6448 .69978 L p .64456 .73153 L .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64789 .71916 L .64456 .73153 L .707 .577 .707 r
F
.65209 .70355 m .65497 .70491 L p .65324 .6993 L F P
0 g
s
.65324 .6993 m .64154 .66146 L .65209 .70355 L .707 .577 .707 r
F
.83532 .65945 m .83632 .69706 L .84356 .69036 L p F P
0 g
s
.84356 .69036 m .84257 .65276 L .83532 .65945 L p .707 .577 .707 r
F P
0 g
s
.63753 .63449 m .63767 .579 L .63487 .57028 L p .707 .577 .707 r
F P
0 g
s
.64813 .72065 m .64453 .73514 L .65735 .75573 L p .707 .577 .707 r
F P
0 g
s
.82314 .77032 m .81954 .78481 L .83521 .76934 L p .707 .577 .707 r
F P
0 g
s
.83521 .76934 m .8388 .75484 L .82314 .77032 L p .707 .577 .707 r
F P
0 g
s
.64254 .69906 m .64154 .66146 L .63881 .65487 L p .707 .577 .707 r
F P
0 g
s
.63487 .57028 m .63473 .62577 L .63753 .63449 L p .707 .577 .707 r
F P
0 g
s
.83872 .57461 m .83859 .63011 L .83579 .62139 L p .707 .577 .707 r
F P
0 g
s
.83579 .62139 m .83592 .56589 L .83872 .57461 L p .707 .577 .707 r
F P
0 g
s
.63881 .65487 m .63981 .69247 L .64254 .69906 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6448 .69978 m .64121 .71428 L .64453 .73514 L p .707 .577 .707 r
F P
0 g
s
.8388 .75484 m .83521 .76934 L .84169 .75023 L p .707 .577 .707 r
F P
0 g
s
.84169 .75023 m .84529 .73573 L .8388 .75484 L p .707 .577 .707 r
F P
0 g
s
.84257 .65276 m .84356 .69036 L .84083 .68376 L p .707 .577 .707 r
F P
0 g
s
.84083 .68376 m .83984 .64616 L .84257 .65276 L p .707 .577 .707 r
F P
0 g
s
.63473 .62577 m .63487 .57028 L .64204 .56177 L p .707 .577 .707 r
F P
0 g
s
.64121 .71428 m .6448 .69978 L .65129 .68067 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63981 .69247 m .63881 .65487 L .64605 .64817 L p .707 .577 .707 r
F P
0 g
s
.64204 .56177 m .64191 .61727 L .63473 .62577 L p .707 .577 .707 r
F P
0 g
s
.38197 .62129 m .38229 .56568 L .35114 .5636 L p .707 .577 .707 r
F P
0 g
s
.38229 .56568 m .38197 .62129 L .41381 .62072 L p .707 .577 .707 r
F P
0 g
s
.41381 .62072 m .41413 .5651 L .38229 .56568 L p .707 .577 .707 r
F P
0 g
s
.83592 .56589 m .83579 .62139 L .82328 .61331 L p .707 .577 .707 r
F P
0 g
s
.82328 .61331 m .82342 .55782 L .83592 .56589 L p .707 .577 .707 r
F P
0 g
s
.65129 .68067 m .64769 .69517 L .64121 .71428 L p .707 .577 .707 r
F P
0 g
s
.41413 .5651 m .41381 .62072 L .44323 .61755 L p .707 .577 .707 r
F P
0 g
s
.44323 .61755 m .44355 .56193 L .41413 .5651 L p .707 .577 .707 r
F P
0 g
s
.64605 .64817 m .64705 .68577 L .63981 .69247 L p .707 .577 .707 r
F P
0 g
s
.84529 .73573 m .84169 .75023 L .83836 .72936 L p .707 .577 .707 r
F P
0 g
s
.83836 .72936 m .84196 .71486 L .84529 .73573 L p .707 .577 .707 r
F P
0 g
s
.35082 .61922 m .35114 .5636 L .32373 .55908 L p .707 .577 .707 r
F P
0 g
s
.35114 .5636 m .35082 .61922 L .38197 .62129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83984 .64616 m .84083 .68376 L .8284 .67792 L p .707 .577 .707 r
F P
0 g
s
.8284 .67792 m .8274 .64032 L .83984 .64616 L p .707 .577 .707 r
F P
0 g
s
.64191 .61727 m .64204 .56177 L .65849 .55431 L p .707 .577 .707 r
F P
0 g
s
.64769 .69517 m .65129 .68067 L .66695 .66519 L p .707 .577 .707 r
F P
0 g
s
.44355 .56193 m .44323 .61755 L .46735 .61209 L p .707 .577 .707 r
F P
0 g
s
.46735 .61209 m .46767 .55647 L .44355 .56193 L p .707 .577 .707 r
F P
0 g
s
.32373 .55908 m .32341 .6147 L .35082 .61922 L p .707 .577 .707 r
F P
0 g
s
.32341 .6147 m .32373 .55908 L .30275 .55255 L p .707 .577 .707 r
F P
0 g
s
.66695 .66519 m .66336 .67969 L .64769 .69517 L p .707 .577 .707 r
F P
0 g
s
.39343 .68348 m .3911 .64677 L .36003 .64644 L p .707 .577 .707 r
F P
0 g
s
.3911 .64677 m .39343 .68348 L .42522 .68084 L p .707 .577 .707 r
F P
0 g
s
.42522 .68084 m .42289 .64413 L .3911 .64677 L p .707 .577 .707 r
F P
0 g
s
.64705 .68577 m .64605 .64817 L .66256 .64203 L p .707 .577 .707 r
F P
0 g
s
.42289 .64413 m .42522 .68084 L .45462 .67549 L p .707 .577 .707 r
F P
0 g
s
.45462 .67549 m .45229 .63878 L .42289 .64413 L p .707 .577 .707 r
F P
0 g
s
.82342 .55782 m .82328 .61331 L .8023 .60667 L p .707 .577 .707 r
F P
0 g
s
.8023 .60667 m .80243 .55117 L .82342 .55782 L p .707 .577 .707 r
F P
0 g
s
.65849 .55431 m .65836 .6098 L .64191 .61727 L p .707 .577 .707 r
F P
0 g
s
.84196 .71486 m .83836 .72936 L .82555 .70877 L p .707 .577 .707 r
F P
0 g
s
.82555 .70877 m .82915 .69427 L .84196 .71486 L p .707 .577 .707 r
F P
0 g
s
.36235 .68315 m .36003 .64644 L .33271 .64318 L p .707 .577 .707 r
F P
0 g
s
.36003 .64644 m .36235 .68315 L .39343 .68348 L p .707 .577 .707 r
F P
0 g
s
.46767 .55647 m .46735 .61209 L .4838 .60488 L p .707 .577 .707 r
F P
0 g
s
.4838 .60488 m .48412 .54927 L .46767 .55647 L p .707 .577 .707 r
F P
0 g
s
.66336 .67969 m .66695 .66519 L .69026 .65486 L p .707 .577 .707 r
F P
0 g
s
.69026 .65486 m .68666 .66935 L .66336 .67969 L p .707 .577 .707 r
F P
0 g
s
.66256 .64203 m .66355 .67963 L .64705 .68577 L p .707 .577 .707 r
F P
0 g
s
.30275 .55255 m .30243 .60817 L .32341 .6147 L p .707 .577 .707 r
F P
0 g
s
.65836 .6098 m .65849 .55431 L .68261 .54862 L p .707 .577 .707 r
F P
0 g
s
.45229 .63878 m .45462 .67549 L .47875 .66796 L p .707 .577 .707 r
F P
0 g
s
.47875 .66796 m .47642 .63126 L .45229 .63878 L p .707 .577 .707 r
F P
0 g
s
.8274 .64032 m .8284 .67792 L .80747 .6734 L p .707 .577 .707 r
F P
0 g
s
.80747 .6734 m .80648 .63579 L .8274 .64032 L p .707 .577 .707 r
F P
0 g
s
.39287 .69981 m .40084 .68238 L .37257 .66888 L p .707 .577 .707 r
F P
0 g
s
.40084 .68238 m .39287 .69981 L .42188 .71276 L p .707 .577 .707 r
F P
0 g
s
.42188 .71276 m .42985 .69532 L .40084 .68238 L p .707 .577 .707 r
F P
0 g
s
.37257 .66888 m .3646 .68631 L .39287 .69981 L p .707 .577 .707 r
F P
0 g
s
.33271 .64318 m .33504 .67989 L .36235 .68315 L p .707 .577 .707 r
F P
0 g
s
.30243 .60817 m .30275 .55255 L .29024 .54466 L p .707 .577 .707 r
F P
0 g
s
.42985 .69532 m .42188 .71276 L .44879 .72387 L p .707 .577 .707 r
F P
0 g
s
.44879 .72387 m .45676 .70644 L .42985 .69532 L p .707 .577 .707 r
F P
0 g
s
.3646 .68631 m .37257 .66888 L .34782 .65614 L p .707 .577 .707 r
F P
0 g
s
.33504 .67989 m .33271 .64318 L .31184 .63731 L p .707 .577 .707 r
F P
0 g
s
.82915 .69427 m .82555 .70877 L .80451 .69049 L p .707 .577 .707 r
F P
0 g
s
.80451 .69049 m .8081 .67599 L .82915 .69427 L p .707 .577 .707 r
F P
0 g
s
.34782 .65614 m .33984 .67357 L .3646 .68631 L p .707 .577 .707 r
F P
0 g
s
.80243 .55117 m .8023 .60667 L .77489 .6021 L p .707 .577 .707 r
F P
0 g
s
.77489 .6021 m .77503 .54661 L .80243 .55117 L p .707 .577 .707 r
F P
0 g
s
.66355 .67963 m .66256 .64203 L .68671 .63703 L p .707 .577 .707 r
F P
0 g
s
.68261 .54862 m .68248 .60412 L .65836 .6098 L p .707 .577 .707 r
F P
0 g
s
.68666 .66935 m .69026 .65486 L .71893 .65068 L p .707 .577 .707 r
F P
0 g
s
.47642 .63126 m .47875 .66796 L .49525 .65899 L p .707 .577 .707 r
F P
0 g
s
.49525 .65899 m .49292 .62228 L .47642 .63126 L p .707 .577 .707 r
F P
0 g
s
.68248 .60412 m .68261 .54862 L .71203 .54527 L p .707 .577 .707 r
F P
0 g
s
.45676 .70644 m .44879 .72387 L .47096 .73207 L p .707 .577 .707 r
F P
0 g
s
.47096 .73207 m .47894 .71464 L .45676 .70644 L p .707 .577 .707 r
F P
0 g
s
.29024 .54466 m .28992 .60027 L .30243 .60817 L p .707 .577 .707 r
F P
0 g
s
.48412 .54927 m .4838 .60488 L .49098 .59663 L p .707 .577 .707 r
F P
0 g
s
.49098 .59663 m .4913 .54102 L .48412 .54927 L p .707 .577 .707 r
F P
0 g
s
.31184 .63731 m .31416 .67402 L .33504 .67989 L p .707 .577 .707 r
F P
0 g
s
.71893 .65068 m .71533 .66518 L .68666 .66935 L p .707 .577 .707 r
F P
0 g
s
.68671 .63703 m .68771 .67464 L .66355 .67963 L p .707 .577 .707 r
F P
0 g
s
.33984 .67357 m .34782 .65614 L .32899 .6454 L p .707 .577 .707 r
F P
0 g
s
.77729 .67629 m .78088 .66179 L .8081 .67599 L p .707 .577 .707 r
F P
0 g
s
.80648 .63579 m .80747 .6734 L .78011 .67064 L p .707 .577 .707 r
F P
0 g
s
.78088 .66179 m .77729 .67629 L .74656 .66757 L p .707 .577 .707 r
F P
0 g
s
.74656 .66757 m .75016 .65307 L .78088 .66179 L p .707 .577 .707 r
F P
0 g
s
.78011 .67064 m .77911 .63303 L .80648 .63579 L p .707 .577 .707 r
F P
0 g
s
.8081 .67599 m .80451 .69049 L .77729 .67629 L p .707 .577 .707 r
F P
0 g
s
.32899 .6454 m .32102 .66284 L .33984 .67357 L p .707 .577 .707 r
F P
0 g
s
.77503 .54661 m .77489 .6021 L .74374 .60007 L p .707 .577 .707 r
F P
0 g
s
.74374 .60007 m .74387 .54457 L .77503 .54661 L p .707 .577 .707 r
F P
0 g
s
.71533 .66518 m .71893 .65068 L .75016 .65307 L p .707 .577 .707 r
F P
0 g
s
.7119 .60076 m .71203 .54527 L .74387 .54457 L p .707 .577 .707 r
F P
0 g
s
.71203 .54527 m .7119 .60076 L .68248 .60412 L p .707 .577 .707 r
F P
0 g
s
.31416 .67402 m .31184 .63731 L .29944 .62939 L p .707 .577 .707 r
F P
0 g
s
.28992 .60027 m .29024 .54466 L .28744 .53617 L p .707 .577 .707 r
F P
0 g
s
.74387 .54457 m .74374 .60007 L .7119 .60076 L p .707 .577 .707 r
F P
0 g
s
.68771 .67464 m .68671 .63703 L .71615 .63369 L p .707 .577 .707 r
F P
0 g
s
.75016 .65307 m .74656 .66757 L .71533 .66518 L p .707 .577 .707 r
F P
0 g
s
.47894 .71464 m .47096 .73207 L .48624 .73656 L p .707 .577 .707 r
F P
0 g
s
.48624 .73656 m .49421 .71913 L .47894 .71464 L p .707 .577 .707 r
F P
0 g
s
.77911 .63303 m .78011 .67064 L .74899 .66991 L p .707 .577 .707 r
F P
0 g
s
.74899 .66991 m .74799 .63231 L .77911 .63303 L p .707 .577 .707 r
F P
0 g
s
.71615 .63369 m .71715 .67129 L .68771 .67464 L p .707 .577 .707 r
F P
0 g
s
.29944 .62939 m .30177 .6661 L .31416 .67402 L p .707 .577 .707 r
F P
0 g
s
.49292 .62228 m .49525 .65899 L .5025 .64945 L p .707 .577 .707 r
F P
0 g
s
.5025 .64945 m .50017 .61274 L .49292 .62228 L p .707 .577 .707 r
F P
0 g
s
.71715 .67129 m .71615 .63369 L .74799 .63231 L p .707 .577 .707 r
F P
0 g
s
.32102 .66284 m .32899 .6454 L .31793 .63773 L p .707 .577 .707 r
F P
0 g
s
.74799 .63231 m .74899 .66991 L .71715 .67129 L p .707 .577 .707 r
F P
0 g
s
.28744 .53617 m .28712 .59179 L .28992 .60027 L p .707 .577 .707 r
F P
0 g
s
.31793 .63773 m .30996 .65516 L .32102 .66284 L p .707 .577 .707 r
F P
0 g
s
.4913 .54102 m .49098 .59663 L .48818 .58815 L p .707 .577 .707 r
F P
0 g
s
.48818 .58815 m .48849 .53253 L .4913 .54102 L p .707 .577 .707 r
F P
0 g
s
.30177 .6661 m .29944 .62939 L .29673 .62022 L p .707 .577 .707 r
F P
0 g
s
.28712 .59179 m .28744 .53617 L .29462 .52792 L p .707 .577 .707 r
F P
0 g
s
.49421 .71913 m .48624 .73656 L .49311 .73688 L p .707 .577 .707 r
F P
0 g
s
.49311 .73688 m .50108 .71945 L .49421 .71913 L p .707 .577 .707 r
F P
0 g
s
.29673 .62022 m .29906 .65693 L .30177 .6661 L p .707 .577 .707 r
F P
0 g
s
.50017 .61274 m .5025 .64945 L .49979 .64027 L p .707 .577 .707 r
F P
0 g
s
.49979 .64027 m .49747 .60356 L .50017 .61274 L p .707 .577 .707 r
F P
0 g
s
.30996 .65516 m .31793 .63773 L .31574 .63387 L p .707 .577 .707 r
F P
0 g
s
.31574 .63387 m .30777 .6513 L .30996 .65516 L p .707 .577 .707 r
F P
0 g
s
.29462 .52792 m .2943 .58354 L .28712 .59179 L p .707 .577 .707 r
F P
0 g
s
.48849 .53253 m .48818 .58815 L .47567 .58025 L p .707 .577 .707 r
F P
0 g
s
.47567 .58025 m .47599 .52464 L .48849 .53253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29906 .65693 m .29673 .62022 L .30398 .61067 L p .707 .577 .707 r
F P
0 g
s
.2943 .58354 m .29462 .52792 L .31107 .52071 L p .707 .577 .707 r
F P
0 g
s
.50108 .71945 m .49311 .73688 L .49092 .73302 L p .707 .577 .707 r
F P
0 g
s
.49092 .73302 m .49889 .71559 L .50108 .71945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30398 .61067 m .30631 .64738 L .29906 .65693 L p .707 .577 .707 r
F P
0 g
s
.49747 .60356 m .49979 .64027 L .4874 .63236 L p .707 .577 .707 r
F P
0 g
s
.4874 .63236 m .48507 .59565 L .49747 .60356 L p .707 .577 .707 r
F P
0 g
s
.30777 .6513 m .31574 .63387 L .32261 .6342 L p .707 .577 .707 r
F P
0 g
s
.31107 .52071 m .31075 .57633 L .2943 .58354 L p .707 .577 .707 r
F P
0 g
s
.47599 .52464 m .47567 .58025 L .45469 .57373 L p .707 .577 .707 r
F P
0 g
s
.45469 .57373 m .45501 .51811 L .47599 .52464 L p .707 .577 .707 r
F P
0 g
s
.32261 .6342 m .31464 .65163 L .30777 .6513 L p .707 .577 .707 r
F P
0 g
s
.31075 .57633 m .31107 .52071 L .33519 .51526 L p .707 .577 .707 r
F P
0 g
s
.30631 .64738 m .30398 .61067 L .32048 .6017 L p .707 .577 .707 r
F P
0 g
s
.49889 .71559 m .49092 .73302 L .47986 .72535 L p .707 .577 .707 r
F P
0 g
s
.47986 .72535 m .48784 .70792 L .49889 .71559 L p .707 .577 .707 r
F P
0 g
s
.31464 .65163 m .32261 .6342 L .33789 .63868 L p .707 .577 .707 r
F P
0 g
s
.32048 .6017 m .32281 .63841 L .30631 .64738 L p .707 .577 .707 r
F P
0 g
s
.45501 .51811 m .45469 .57373 L .42728 .5692 L p .707 .577 .707 r
F P
0 g
s
.42728 .5692 m .4276 .51359 L .45501 .51811 L p .707 .577 .707 r
F P
0 g
s
.48507 .59565 m .4874 .63236 L .46652 .62648 L p .707 .577 .707 r
F P
0 g
s
.46652 .62648 m .46419 .58977 L .48507 .59565 L p .707 .577 .707 r
F P
0 g
s
.33519 .51526 m .33487 .57088 L .31075 .57633 L p .707 .577 .707 r
F P
0 g
s
.33487 .57088 m .33519 .51526 L .36461 .51209 L p .707 .577 .707 r
F P
0 g
s
.33789 .63868 m .32991 .65611 L .31464 .65163 L p .707 .577 .707 r
F P
0 g
s
.32281 .63841 m .32048 .6017 L .34461 .59417 L p .707 .577 .707 r
F P
0 g
s
.4276 .51359 m .42728 .5692 L .39613 .56713 L p .707 .577 .707 r
F P
0 g
s
.39613 .56713 m .39645 .51151 L .4276 .51359 L p .707 .577 .707 r
F P
0 g
s
.36429 .5677 m .36461 .51209 L .39645 .51151 L p .707 .577 .707 r
F P
0 g
s
.36461 .51209 m .36429 .5677 L .33487 .57088 L p .707 .577 .707 r
F P
0 g
s
.39645 .51151 m .39613 .56713 L .36429 .5677 L p .707 .577 .707 r
F P
0 g
s
.46419 .58977 m .46652 .62648 L .43921 .62322 L p .707 .577 .707 r
F P
0 g
s
.43921 .62322 m .43688 .58651 L .46419 .58977 L p .707 .577 .707 r
F P
0 g
s
.34461 .59417 m .34694 .63088 L .32281 .63841 L p .707 .577 .707 r
F P
0 g
s
.48784 .70792 m .47986 .72535 L .46103 .71462 L p .707 .577 .707 r
F P
0 g
s
.46103 .71462 m .46901 .69719 L .48784 .70792 L p .707 .577 .707 r
F P
0 g
s
.34694 .63088 m .34461 .59417 L .37401 .58882 L p .707 .577 .707 r
F P
0 g
s
.32991 .65611 m .33789 .63868 L .36006 .64688 L p .707 .577 .707 r
F P
0 g
s
.36006 .64688 m .35209 .66431 L .32991 .65611 L p .707 .577 .707 r
F P
0 g
s
.43688 .58651 m .43921 .62322 L .40813 .6229 L p .707 .577 .707 r
F P
0 g
s
.40813 .6229 m .4058 .58619 L .43688 .58651 L p .707 .577 .707 r
F P
0 g
s
.37401 .58882 m .37634 .62553 L .34694 .63088 L p .707 .577 .707 r
F P
0 g
s
.37634 .62553 m .37401 .58882 L .4058 .58619 L p .707 .577 .707 r
F P
0 g
s
.4058 .58619 m .40813 .6229 L .37634 .62553 L p .707 .577 .707 r
F P
0 g
s
.46901 .69719 m .46103 .71462 L .43628 .70188 L p .707 .577 .707 r
F P
0 g
s
.43628 .70188 m .44425 .68445 L .46901 .69719 L p .707 .577 .707 r
F P
0 g
s
.35209 .66431 m .36006 .64688 L .38697 .658 L p .707 .577 .707 r
F P
0 g
s
.38697 .658 m .379 .67543 L .35209 .66431 L p .707 .577 .707 r
F P
0 g
s
.44425 .68445 m .43628 .70188 L .40801 .68837 L p .707 .577 .707 r
F P
0 g
s
.40801 .68837 m .41598 .67094 L .44425 .68445 L p .707 .577 .707 r
F P
0 g
s
.379 .67543 m .38697 .658 L .41598 .67094 L p .707 .577 .707 r
F P
0 g
s
.41598 .67094 m .40801 .68837 L .379 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aooa40009JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00GWoo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001JOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001GOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001A
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0001Moo`T004Eoo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo2000
15YF00<005YFFUH00UYF2000?Goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0007Ool80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol0055oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DGoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo001AOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001AOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001AOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool0055oo`03001JEP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEPD000AJEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol0
1000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001A
Ool00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH000000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
055oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000AJ
EP04001JEUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DGoo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH02@0015YF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP<0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000015YF
000000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0055oo`80009JEP03001JEUYF00=JEP04001J
EUYFFUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000EJEP04001J
EP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo0`0015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH70008
FUH60003FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaL00005FUH00000FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF1P0015YF
00<005YFFUH00P00;Woo000hOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000015YF001JEUYF0P00;Woo000cOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00P005YFFUIJEP00FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8002io
o`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUIJEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00;Woo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01UYF1`000eYF00@005YFFUIJEP80
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH500000eYF001J
EP04FUH60004FUH00`00FUIJEP08FUH01000FUIJEUYF1@000eYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEPX0
00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03
001JEP0000<0009JEP05001JEP00FUH00005FUH60004FUH00`00FUIJEP08FUH400000eYF001JEP02
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YF00001`0015YF00<005YFFUH00UYF3`0015YF0P00;goo000]
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000eYF0P0000=JEP0000000P0000IJEP00FUH005YF0005FUH60004FUH00`00FUIJ
EP05FUH30005FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40005FUH00`00FUH000070003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001J
EUYF00@00003FUH005YF00AJEP03001JEP00008000EJEP04001JEUYFFUH400000eYF001JEP05FUH0
0`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000P0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJ
EP03FUHF0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002io
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002
FUH40006FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF0`000eYF1000
00=JEP00FUH01eYF0`0025YF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF2@0025YF1@000eYF00<005YF00001EYF00@005YF000000QJEP03001JEUYF008000IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool002eoo`03001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00P000eYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF
00000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF0`001UYF0P000eYF00<005YFFUH01UYF0P0000=JEP00FUH01eYF00@005YFFUIJEP8000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo
00@005YF001JEP8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP<000AJEP8000QJEP800003FUH005YF00MJEP04001JEP000008FUH01000FUH000002UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF2P0017oo2`0000=JEP00FUH00eYF1`000eYF00<005YFFUH00P00;Goo000]Ool01P00
FUH00000FUH000EJEQh000AJEP@00003FUH005YF008000EJEP03001JEUYF008000QJEP04001JEUYF
FUH20002FUH6000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP02FUH90004FUH01000FUH000001eYF
0P000UYF10000UYF0P00;Goo000]Ool20003FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040003FUH70003FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH0
1000FUIJEUYF0P001UYF0P0000=JEP00FUH00UYF1000;Goo000]Ool20003FUH30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH000040006
FUH40002FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00P0015YF0`00;Goo000]
Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01`00FUIJEUYF001JEP0000IJEPL000UJEP<00003FUH005YF00]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH00UYF0P00
0eYF0`00;Goo000]Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH000020004FUH50002FUH20006
FUH01000FUIJEUYF0P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000EJEP06001JEUYF001JEP00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUH00002FUH20003FUH30005FUH20004FUH00`00FUIJEP03FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF
00@005YF000002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH00eYF0P0000=JEP00
FUH025YF0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00H005YFFUH005YF0005FUH40008FUH01000FUH0000025YF0`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
15YF001JEP00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP@000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003Ool00000
009JEP03001oogoo02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH80003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60006Ool01@00FUIJEUYF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJEP<000MJEP@000IJEP<0009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEQ/000eoo`04001JEUYF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPH000Eoo`T000=oo`P000AJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00@005YF000000EJEP04001JEUYF0005FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009J
EP<000Ioo`<001Moo`05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP0000<001mo
o`D000EJEP06001JEUYF001JEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<00003FUH005YF00=J
EP8000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30005Ool5000GOol01000FUIJEP00
;Goo000/Ool00`00FUH00003FUH3000COol3000BOol20003FUH01P00FUIJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP<000=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00FUH00005Ool5000HOol3000]Ool002aoo`04001JEP00FUH4000COol5000COol200001eYF001J
EUYF001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP8000AJEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000=J
EP03001JEUYF00=JEP03001JEUYF009JEP8000Ioo`D001Qoo`<002eoo`00;7oo00H005YF000005YF
0002FUH2000AOol5000DOol30002FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
0002FUH00`00FUIJEP03000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEPH000AJEP03001JEUYF009JEP03001oogoo00Ioo`<001Yoo`03001JEP00
02aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0037oo1@004Goo0`000eYF00D005YF001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEP0000<0009JEP<0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP05001JEUYF001JEP03
000015YF001JEUYF0P009Woo00<005YF0000;7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF20001Goo0`002Woo20000UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH00eYF1@000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUH000AJEP@002Qoo`03001JEP0002ao
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF0000009JEP03001JEP0000EJEP<002Qoo`03001JEP0002aoo`00;7oo0P000UYF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEQ800003FUH005YF
00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH30005FUH00`00FUIJEP02000WOol00`00
Oomoo`0[Ool002eoo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH<0003FUH00`00FUIJEP07FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH005YF0P000UYF00<005YFFUH00eYF00D005YFFUIJEP0002Moo`03001oogoo02]oo`00;Goo
00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEPP000=JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00=JEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Woo0P00;Goo000^Ool00`00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH50006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<007ooOol097oo0P00;Goo000_Ool20005FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0400000eYF001JEP04
FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH20004FUH00`00
Oomoo`0SOol2000^Ool0031oo`8000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF009JEPd0009JEP800003FUH005YF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<000AJEP03001JEP0000AJ
EP03001JEUYF009JEP<000=JEP03001oogoo029oo`<002ioo`00<Woo0`0000=JEP00FUH00`000eYF
00<005YFFUH01eYF00<005YFFUH015YF1P000eYF00@005YFFUIJEP<00003FUH005YF00=JEP04001J
EP00FUH200000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUH000030002FUH01@00FUIJEUYF
00000UYF00@005YF000002=oo`03001JEP0002moo`00=Goo0`001UYF00<005YFFUH01eYF00<005YF
FUH0100000=JEP00FUH01UYF100015YF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH0000000H00003FUH005YF00=JEP<0029oo`04001JEUYF000_Ool0
039oo`<00003FUH005YF00MJEP03001JEUYF00AJEPD000EJEP03001JEUYF009JEP@00003FUH005YF
00EJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
15YF0P001UYF0P007goo0P000UYF00<007ooOol0;Woo000`Ool20004FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF000000030004FUH50005FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF00<005YFFUH01UYF0`006Goo0`00
00AJEP00FUH0035oo`00;Woo0`001UYF00<005YFFUH015YF100000=oo`0000002`000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
0000009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00@0019oo`<000=JEP03001JEP00039oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH0100027oo1P001UYF00<005YFFUH01UYF00<005YF
00000P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
00AJEP04001JEP000003FUH00`00FUIJEP05FUH70007Ool400000eYF001JEP03FUH2000cOol002]o
o`8000AJEP03001JEUYF009JEP@000=oo`T000=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000Qo
o`8000EJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP02FUH00`00Oomoo`0b
Ool002]oo`D00003FUH005YF00X000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00aoo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00AJEP04001JEUYFFUH200000eYF000000020006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00=Goo000/Ool20002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000@Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP03FUH20003FUH30004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000F
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01@00
FUIJEP00FUH00`002Goo1`0015YF00<005YFFUH00UYF1@00>Goo000]Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000LOol200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1EYF00<005YFFUH00UYF00H005YFFUH005YF000BOol9000nOol002eoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00@0029oo`<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH01@00FUIJEUYF0000
15YF00<007ooOol0F7oo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH7000YOol20004
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04
FUHA0005FUH00`00Oomoo`1HOol0035oo`d0039oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D000ioo`8000AJEP03001oogoo05Uoo`00Lgoo
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=oo`0000000`0037oo
00@005YFFUH0009JEP03001oogoo05Yoo`00Mgoo1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF
00@005YFFUIJEPH000Ioo`D000Yoo`8000=JEP04001JEUYF001LOol007eoob0000aoo`D000Uoo`03
001JEUYF00AJEP8005eoo`00Sgoo00<005YFFUH015YF00<007ooOol04Goo0`002Goo00<005YFFUH0
1EYF00<007ooOol0G7oo002?Ool20004FUH00`00Oomoo`0MOol00`00FUIJEP05FUH00`00Oomoo`1M
Ool008ioo`03001JEP0000=JEP03001oogoo01aoo`800003FUH005YF00AJEP03001oogoo05ioo`00
SWoo00@005YFFUH0009JEP03001oogoo01Yoo`8000=JEP04001JEUYFFUH2001QOol008eoo`07001J
EUYFFUH005YF00006goo0P001UYF00<005YF0000Hgoo002=Ool00`00FUIJEP02FUH00`00Oomoo`0I
Ool00`00FUIJEP07FUH00`00Oomoo`1ROol008eoo`80009JEP03001oogoo01Qoo`<000MJEP8006Eo
o`00SGoo0P000UYF00<007ooOol05Woo0P000eYF00<005YFFUH00eYF00<007ooOol0IGoo002>Ool3
000GOol20005FUH01000FUIJEUYF0P00J7oo002>Ool00`00FUH0000COol40008FUH3001ZOol008io
o`03001JEP0000moo`@0009JEP03001JEUYF00IJEP8006aoo`00Sgoo1@001Woo1P001eYF00<005YF
FUH00eYF0P00KWoo002?Ool30002FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP03001`Ool0091o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP<007=oo`00TGoo0P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00MWoo002BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP03001h
Ool009=oo`l007]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60386 .74883 m .60355 .69329 L .5724 .69151 L p .707 .577 .707 r
F P
0 g
s
.60355 .69329 m .60386 .74883 L .63571 .74791 L p .707 .577 .707 r
F P
0 g
s
.63571 .74791 m .63539 .69236 L .60355 .69329 L p .707 .577 .707 r
F P
0 g
s
.63539 .69236 m .63571 .74791 L .66513 .74437 L p .707 .577 .707 r
F P
0 g
s
.66513 .74437 m .66481 .68882 L .63539 .69236 L p .707 .577 .707 r
F P
0 g
s
.57271 .74706 m .5724 .69151 L .54499 .6872 L p .707 .577 .707 r
F P
0 g
s
.5724 .69151 m .57271 .74706 L .60386 .74883 L p .707 .577 .707 r
F P
0 g
s
.66481 .68882 m .66513 .74437 L .68924 .73856 L p .707 .577 .707 r
F P
0 g
s
.68924 .73856 m .68893 .68302 L .66481 .68882 L p .707 .577 .707 r
F P
0 g
s
.59187 .80726 m .59419 .77002 L .56312 .76642 L p .707 .577 .707 r
F P
0 g
s
.59419 .77002 m .59187 .80726 L .62366 .80847 L p .707 .577 .707 r
F P
0 g
s
.62366 .80847 m .62599 .77123 L .59419 .77002 L p .707 .577 .707 r
F P
0 g
s
.62599 .77123 m .62366 .80847 L .65306 .80718 L p .707 .577 .707 r
F P
0 g
s
.65306 .80718 m .65539 .76994 L .62599 .77123 L p .707 .577 .707 r
F P
0 g
s
.54499 .6872 m .54531 .74275 L .57271 .74706 L p .707 .577 .707 r
F P
0 g
s
.54531 .74275 m .54499 .6872 L .52401 .68079 L p .707 .577 .707 r
F P
0 g
s
.56079 .80366 m .56312 .76642 L .53581 .76079 L p .707 .577 .707 r
F P
0 g
s
.56312 .76642 m .56079 .80366 L .59187 .80726 L p .707 .577 .707 r
F P
0 g
s
.65539 .76994 m .65306 .80718 L .67719 .8035 L p .707 .577 .707 r
F P
0 g
s
.67719 .8035 m .67952 .76626 L .65539 .76994 L p .707 .577 .707 r
F P
0 g
s
.53581 .76079 m .53348 .79803 L .56079 .80366 L p .707 .577 .707 r
F P
0 g
s
.68893 .68302 m .68924 .73856 L .7057 .73106 L p .707 .577 .707 r
F P
0 g
s
.7057 .73106 m .70538 .67551 L .68893 .68302 L p .707 .577 .707 r
F P
0 g
s
.621 .85854 m .61302 .84281 L .58402 .85575 L p .707 .577 .707 r
F P
0 g
s
.61302 .84281 m .621 .85854 L .64791 .84221 L p .707 .577 .707 r
F P
0 g
s
.64791 .84221 m .63993 .82647 L .61302 .84281 L p .707 .577 .707 r
F P
0 g
s
.52401 .68079 m .52432 .73633 L .54531 .74275 L p .707 .577 .707 r
F P
0 g
s
.59199 .87148 m .58402 .85575 L .55575 .86401 L p .707 .577 .707 r
F P
0 g
s
.58402 .85575 m .59199 .87148 L .621 .85854 L p .707 .577 .707 r
F P
0 g
s
.53348 .79803 m .53581 .76079 L .51493 .75368 L p .707 .577 .707 r
F P
0 g
s
.63993 .82647 m .64791 .84221 L .67008 .82406 L p .707 .577 .707 r
F P
0 g
s
.67008 .82406 m .66211 .80833 L .63993 .82647 L p .707 .577 .707 r
F P
0 g
s
.52432 .73633 m .52401 .68079 L .5115 .67289 L p .707 .577 .707 r
F P
0 g
s
.55575 .86401 m .56372 .87975 L .59199 .87148 L p .707 .577 .707 r
F P
0 g
s
.51493 .75368 m .5126 .79092 L .53348 .79803 L p .707 .577 .707 r
F P
0 g
s
.56372 .87975 m .55575 .86401 L .53099 .8668 L p .707 .577 .707 r
F P
0 g
s
.67952 .76626 m .67719 .8035 L .69369 .79781 L p .707 .577 .707 r
F P
0 g
s
.69369 .79781 m .69602 .76057 L .67952 .76626 L p .707 .577 .707 r
F P
0 g
s
.66211 .80833 m .67008 .82406 L .68536 .80589 L p .707 .577 .707 r
F P
0 g
s
.68536 .80589 m .67738 .79016 L .66211 .80833 L p .707 .577 .707 r
F P
0 g
s
.53099 .8668 m .53896 .88254 L .56372 .87975 L p .707 .577 .707 r
F P
0 g
s
.70538 .67551 m .7057 .73106 L .71287 .72259 L p .707 .577 .707 r
F P
0 g
s
.71287 .72259 m .71255 .66705 L .70538 .67551 L p .707 .577 .707 r
F P
0 g
s
.5115 .67289 m .51182 .72844 L .52432 .73633 L p .707 .577 .707 r
F P
0 g
s
.5126 .79092 m .51493 .75368 L .50253 .74578 L p .707 .577 .707 r
F P
0 g
s
.53896 .88254 m .53099 .8668 L .51216 .86384 L p .707 .577 .707 r
F P
0 g
s
.50253 .74578 m .5002 .78302 L .5126 .79092 L p .707 .577 .707 r
F P
0 g
s
.51182 .72844 m .5115 .67289 L .5087 .66429 L p .707 .577 .707 r
F P
0 g
s
.67738 .79016 m .68536 .80589 L .69223 .78948 L p .707 .577 .707 r
F P
0 g
s
.69223 .78948 m .68426 .77374 L .67738 .79016 L p .707 .577 .707 r
F P
0 g
s
.51216 .86384 m .52014 .87957 L .53896 .88254 L p .707 .577 .707 r
F P
0 g
s
.69602 .76057 m .69369 .79781 L .70094 .79066 L p .707 .577 .707 r
F P
0 g
s
.70094 .79066 m .70327 .75342 L .69602 .76057 L p .707 .577 .707 r
F P
0 g
s
.5087 .66429 m .50902 .71984 L .51182 .72844 L p .707 .577 .707 r
F P
0 g
s
.5002 .78302 m .50253 .74578 L .49983 .73787 L p .707 .577 .707 r
F P
0 g
s
.71255 .66705 m .71287 .72259 L .71007 .71399 L p .707 .577 .707 r
F P
0 g
s
.71007 .71399 m .70975 .65845 L .71255 .66705 L p .707 .577 .707 r
F P
0 g
s
.52014 .87957 m .51216 .86384 L .50111 .85542 L p .707 .577 .707 r
F P
0 g
s
.49518 .8219 m .49518 .32001 L .45086 .31772 L p .707 .577 .707 r
F P
0 g
s
.49983 .73787 m .4975 .77511 L .5002 .78302 L p .707 .577 .707 r
F P
0 g
s
.50902 .71984 m .5087 .66429 L .51588 .65583 L p .707 .577 .707 r
F P
0 g
s
.51588 .65583 m .5162 .71137 L .50902 .71984 L p .707 .577 .707 r
F P
0 g
s
.4975 .77511 m .49983 .73787 L .50708 .73072 L p .707 .577 .707 r
F P
0 g
s
.50708 .73072 m .50475 .76796 L .4975 .77511 L p .707 .577 .707 r
F P
0 g
s
.5162 .71137 m .51588 .65583 L .53233 .64832 L p .707 .577 .707 r
F P
0 g
s
.53233 .64832 m .53265 .70387 L .5162 .71137 L p .707 .577 .707 r
F P
0 g
s
.50475 .76796 m .50708 .73072 L .52357 .72503 L p .707 .577 .707 r
F P
0 g
s
.52357 .72503 m .52124 .76227 L .50475 .76796 L p .707 .577 .707 r
F P
0 g
s
.52124 .76227 m .52357 .72503 L .5477 .72135 L p .707 .577 .707 r
F P
0 g
s
.51376 .84167 m .50579 .82594 L .52106 .80777 L p .707 .577 .707 r
F P
0 g
s
.5477 .72135 m .54538 .75859 L .52124 .76227 L p .707 .577 .707 r
F P
0 g
s
.52106 .80777 m .52903 .8235 L .51376 .84167 L p .707 .577 .707 r
F P
0 g
s
.52903 .8235 m .52106 .80777 L .54324 .78963 L p .707 .577 .707 r
F P
0 g
s
.54324 .78963 m .55121 .80536 L .52903 .8235 L p .707 .577 .707 r
F P
0 g
s
.49518 .32001 m .49518 .8219 L .53996 .82041 L p .707 .577 .707 r
F P
0 g
s
.53265 .70387 m .53233 .64832 L .55645 .64252 L p .707 .577 .707 r
F P
0 g
s
.55645 .64252 m .55676 .69806 L .53265 .70387 L p .707 .577 .707 r
F P
0 g
s
.53996 .82041 m .53996 .31852 L .49518 .32001 L p .707 .577 .707 r
F P
0 g
s
.55676 .69806 m .55645 .64252 L .58587 .63898 L p .707 .577 .707 r
F P
0 g
s
.58587 .63898 m .58618 .69452 L .55676 .69806 L p .707 .577 .707 r
F P
0 g
s
.54538 .75859 m .5477 .72135 L .5771 .72006 L p .707 .577 .707 r
F P
0 g
s
.5771 .72006 m .57478 .7573 L .54538 .75859 L p .707 .577 .707 r
F P
0 g
s
.57478 .7573 m .5771 .72006 L .6089 .72127 L p .707 .577 .707 r
F P
0 g
s
.60713 .77609 m .59916 .76035 L .62742 .75208 L p .707 .577 .707 r
F P
0 g
s
.6089 .72127 m .60657 .75851 L .57478 .7573 L p .707 .577 .707 r
F P
0 g
s
.55121 .80536 m .54324 .78963 L .57015 .77329 L p .707 .577 .707 r
F P
0 g
s
.59916 .76035 m .60713 .77609 L .57812 .78902 L p .707 .577 .707 r
F P
0 g
s
.57812 .78902 m .57015 .77329 L .59916 .76035 L p .707 .577 .707 r
F P
0 g
s
.57015 .77329 m .57812 .78902 L .55121 .80536 L p .707 .577 .707 r
F P
0 g
s
.53996 .31852 m .53996 .82041 L .58083 .81527 L p .707 .577 .707 r
F P
0 g
s
.58083 .81527 m .58083 .31339 L .53996 .31852 L p .707 .577 .707 r
F P
0 g
s
.68426 .77374 m .69223 .78948 L .69003 .77642 L p .707 .577 .707 r
F P
0 g
s
.69003 .77642 m .68206 .76068 L .68426 .77374 L p .707 .577 .707 r
F P
0 g
s
.50111 .85542 m .50908 .87115 L .52014 .87957 L p .707 .577 .707 r
F P
0 g
s
.45086 .81961 m .45086 .31772 L .41136 .31186 L p .707 .577 .707 r
F P
0 g
s
.45086 .31772 m .45086 .81961 L .49518 .8219 L p .707 .577 .707 r
F P
0 g
s
.70327 .75342 m .70094 .79066 L .69823 .78275 L p .707 .577 .707 r
F P
0 g
s
.69823 .78275 m .70056 .74551 L .70327 .75342 L p .707 .577 .707 r
F P
0 g
s
.25626 .71431 m .25612 .65864 L .22497 .65682 L p .707 .577 .707 r
F P
0 g
s
.25612 .65864 m .25626 .71431 L .2881 .7135 L p .707 .577 .707 r
F P
0 g
s
.2881 .7135 m .28797 .65783 L .25612 .65864 L p .707 .577 .707 r
F P
0 g
s
.58618 .69452 m .58587 .63898 L .61771 .63805 L p .707 .577 .707 r
F P
0 g
s
.61771 .63805 m .61803 .6936 L .58618 .69452 L p .707 .577 .707 r
F P
0 g
s
.62742 .75208 m .6354 .76782 L .60713 .77609 L p .707 .577 .707 r
F P
0 g
s
.6354 .76782 m .62742 .75208 L .65218 .7493 L p .707 .577 .707 r
F P
0 g
s
.63997 .72487 m .63764 .76211 L .60657 .75851 L p .707 .577 .707 r
F P
0 g
s
.60657 .75851 m .6089 .72127 L .63997 .72487 L p .707 .577 .707 r
F P
0 g
s
.58083 .31339 m .58083 .81527 L .6138 .807 L p .707 .577 .707 r
F P
0 g
s
.6138 .807 m .6138 .30511 L .58083 .31339 L p .707 .577 .707 r
F P
0 g
s
.70975 .65845 m .71007 .71399 L .69757 .7061 L p .707 .577 .707 r
F P
0 g
s
.69757 .7061 m .69725 .65055 L .70975 .65845 L p .707 .577 .707 r
F P
0 g
s
.28797 .65783 m .2881 .7135 L .31752 .71014 L p .707 .577 .707 r
F P
0 g
s
.31752 .71014 m .31739 .65448 L .28797 .65783 L p .707 .577 .707 r
F P
0 g
s
.50908 .87115 m .50111 .85542 L .49891 .84236 L p .707 .577 .707 r
F P
0 g
s
.41136 .81375 m .41136 .31186 L .38053 .30302 L p .707 .577 .707 r
F P
0 g
s
.41136 .31186 m .41136 .81375 L .45086 .81961 L p .707 .577 .707 r
F P
0 g
s
.22511 .71249 m .22497 .65682 L .19756 .65256 L p .707 .577 .707 r
F P
0 g
s
.22497 .65682 m .22511 .71249 L .25626 .71431 L p .707 .577 .707 r
F P
0 g
s
.68206 .76068 m .69003 .77642 L .67898 .76799 L p .707 .577 .707 r
F P
0 g
s
.67898 .76799 m .67101 .75226 L .68206 .76068 L p .707 .577 .707 r
F P
0 g
s
.49891 .84236 m .50689 .85809 L .50908 .87115 L p .707 .577 .707 r
F P
0 g
s
.31739 .65448 m .31752 .71014 L .34164 .70457 L p .707 .577 .707 r
F P
0 g
s
.34164 .70457 m .3415 .6489 L .31739 .65448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70056 .74551 m .69823 .78275 L .68583 .77485 L p .707 .577 .707 r
F P
0 g
s
.68583 .77485 m .68816 .73761 L .70056 .74551 L p .707 .577 .707 r
F P
0 g
s
.19756 .65256 m .1977 .70823 L .22511 .71249 L p .707 .577 .707 r
F P
0 g
s
.1977 .70823 m .19756 .65256 L .17658 .64626 L p .707 .577 .707 r
F P
0 g
s
.69725 .65055 m .69757 .7061 L .67659 .69968 L p .707 .577 .707 r
F P
0 g
s
.67659 .69968 m .67627 .64414 L .69725 .65055 L p .707 .577 .707 r
F P
0 g
s
.64886 .63983 m .64918 .69537 L .61803 .6936 L p .707 .577 .707 r
F P
0 g
s
.61803 .6936 m .61771 .63805 L .64886 .63983 L p .707 .577 .707 r
F P
0 g
s
.6138 .30511 m .6138 .807 L .63562 .7964 L p .707 .577 .707 r
F P
0 g
s
.65218 .7493 m .66015 .76503 L .6354 .76782 L p .707 .577 .707 r
F P
0 g
s
.63562 .7964 m .63562 .29451 L .6138 .30511 L p .707 .577 .707 r
F P
0 g
s
.25101 .77775 m .25201 .7414 L .22089 .73827 L p .707 .577 .707 r
F P
0 g
s
.25201 .7414 m .25101 .77775 L .28285 .77764 L p .707 .577 .707 r
F P
0 g
s
.28285 .77764 m .28385 .74129 L .25201 .7414 L p .707 .577 .707 r
F P
0 g
s
.50689 .85809 m .49891 .84236 L .50579 .82594 L p .707 .577 .707 r
F P
0 g
s
.3415 .6489 m .34164 .70457 L .35809 .69732 L p .707 .577 .707 r
F P
0 g
s
.35809 .69732 m .35796 .64166 L .3415 .6489 L p .707 .577 .707 r
F P
0 g
s
.28385 .74129 m .28285 .77764 L .31229 .7743 L p .707 .577 .707 r
F P
0 g
s
.31229 .7743 m .31329 .73795 L .28385 .74129 L p .707 .577 .707 r
F P
0 g
s
.38053 .80491 m .38053 .30302 L .3614 .29205 L p .707 .577 .707 r
F P
0 g
s
.38053 .30302 m .38053 .80491 L .41136 .81375 L p .707 .577 .707 r
F P
0 g
s
.17658 .64626 m .17672 .70193 L .1977 .70823 L p .707 .577 .707 r
F P
0 g
s
.21989 .77462 m .22089 .73827 L .19352 .73221 L p .707 .577 .707 r
F P
0 g
s
.22089 .73827 m .21989 .77462 L .25101 .77775 L p .707 .577 .707 r
F P
0 g
s
.67101 .75226 m .67898 .76799 L .66015 .76503 L p .707 .577 .707 r
F P
0 g
s
.66015 .76503 m .65218 .7493 L .67101 .75226 L p .707 .577 .707 r
F P
0 g
s
.50579 .82594 m .51376 .84167 L .50689 .85809 L p .707 .577 .707 r
F P
0 g
s
.17672 .70193 m .17658 .64626 L .16408 .63855 L p .707 .577 .707 r
F P
0 g
s
.31329 .73795 m .31229 .7743 L .33644 .76806 L p .707 .577 .707 r
F P
0 g
s
.33644 .76806 m .33744 .73171 L .31329 .73795 L p .707 .577 .707 r
F P
0 g
s
.68816 .73761 m .68583 .77485 L .66496 .76774 L p .707 .577 .707 r
F P
0 g
s
.66496 .76774 m .66728 .7305 L .68816 .73761 L p .707 .577 .707 r
F P
0 g
s
.21912 .75917 m .22271 .77784 L .25344 .77106 L p .707 .577 .707 r
F P
0 g
s
.25344 .77106 m .24984 .75239 L .21912 .75917 L p .707 .577 .707 r
F P
0 g
s
.24984 .75239 m .25344 .77106 L .28467 .7657 L p .707 .577 .707 r
F P
0 g
s
.19352 .73221 m .19253 .76856 L .21989 .77462 L p .707 .577 .707 r
F P
0 g
s
.67627 .64414 m .67659 .69968 L .64918 .69537 L p .707 .577 .707 r
F P
0 g
s
.64918 .69537 m .64886 .63983 L .67627 .64414 L p .707 .577 .707 r
F P
0 g
s
.19253 .76856 m .19352 .73221 L .1726 .72381 L p .707 .577 .707 r
F P
0 g
s
.28467 .7657 m .28107 .74703 L .24984 .75239 L p .707 .577 .707 r
F P
0 g
s
.28107 .74703 m .28467 .7657 L .31334 .76229 L p .707 .577 .707 r
F P
0 g
s
.1726 .72381 m .1716 .76016 L .19253 .76856 L p .707 .577 .707 r
F P
0 g
s
.1919 .76672 m .19549 .78539 L .22271 .77784 L p .707 .577 .707 r
F P
0 g
s
.22271 .77784 m .21912 .75917 L .1919 .76672 L p .707 .577 .707 r
F P
0 g
s
.31334 .76229 m .30974 .74362 L .28107 .74703 L p .707 .577 .707 r
F P
0 g
s
.16408 .63855 m .16421 .69422 L .17672 .70193 L p .707 .577 .707 r
F P
0 g
s
.35796 .64166 m .35809 .69732 L .36527 .68911 L p .707 .577 .707 r
F P
0 g
s
.36527 .68911 m .36513 .63345 L .35796 .64166 L p .707 .577 .707 r
F P
0 g
s
.33744 .73171 m .33644 .76806 L .35295 .75952 L p .707 .577 .707 r
F P
0 g
s
.35295 .75952 m .35395 .72318 L .33744 .73171 L p .707 .577 .707 r
F P
0 g
s
.66728 .7305 m .66496 .76774 L .63764 .76211 L p .707 .577 .707 r
F P
0 g
s
.63764 .76211 m .63997 .72487 L .66728 .7305 L p .707 .577 .707 r
F P
0 g
s
.63562 .29451 m .63562 .7964 L .64416 .78451 L p .707 .577 .707 r
F P
0 g
s
.64416 .78451 m .64416 .28262 L .63562 .29451 L p .707 .577 .707 r
F P
0 g
s
.30974 .74362 m .31334 .76229 L .33664 .76117 L p .707 .577 .707 r
F P
0 g
s
.17085 .77429 m .17445 .79296 L .19549 .78539 L p .707 .577 .707 r
F P
0 g
s
.19549 .78539 m .1919 .76672 L .17085 .77429 L p .707 .577 .707 r
F P
0 g
s
.33664 .76117 m .33305 .7425 L .30974 .74362 L p .707 .577 .707 r
F P
0 g
s
.16421 .69422 m .16408 .63855 L .16128 .63019 L p .707 .577 .707 r
F P
0 g
s
.36019 .74954 m .36119 .71319 L .35395 .72318 L p .707 .577 .707 r
F P
0 g
s
.36233 .62508 m .36247 .68075 L .34996 .67304 L p .707 .577 .707 r
F P
0 g
s
.34996 .67304 m .34983 .61737 L .36233 .62508 L p .707 .577 .707 r
F P
0 g
s
.35395 .72318 m .35295 .75952 L .36019 .74954 L p .707 .577 .707 r
F P
0 g
s
.36119 .71319 m .36019 .74954 L .35746 .73907 L p .707 .577 .707 r
F P
0 g
s
.35746 .73907 m .35846 .70273 L .36119 .71319 L p .707 .577 .707 r
F P
0 g
s
.3614 .79394 m .3614 .29205 L .35583 .28004 L p .707 .577 .707 r
F P
0 g
s
.36513 .63345 m .36527 .68911 L .36247 .68075 L p .707 .577 .707 r
F P
0 g
s
.36247 .68075 m .36233 .62508 L .36513 .63345 L p .707 .577 .707 r
F P
0 g
s
.3614 .29205 m .3614 .79394 L .38053 .80491 L p .707 .577 .707 r
F P
0 g
s
.1716 .76016 m .1726 .72381 L .16016 .71389 L p .707 .577 .707 r
F P
0 g
s
.16128 .63019 m .16141 .68585 L .16421 .69422 L p .707 .577 .707 r
F P
0 g
s
.16016 .71389 m .15917 .75024 L .1716 .76016 L p .707 .577 .707 r
F P
0 g
s
.33305 .7425 m .33664 .76117 L .35231 .76244 L p .707 .577 .707 r
F P
0 g
s
.35231 .76244 m .34871 .74377 L .33305 .7425 L p .707 .577 .707 r
F P
0 g
s
.15804 .78114 m .16163 .79981 L .17445 .79296 L p .707 .577 .707 r
F P
0 g
s
.17445 .79296 m .17085 .77429 L .15804 .78114 L p .707 .577 .707 r
F P
0 g
s
.15917 .75024 m .16016 .71389 L .15743 .70343 L p .707 .577 .707 r
F P
0 g
s
.16141 .68585 m .16128 .63019 L .16845 .62198 L p .707 .577 .707 r
F P
0 g
s
.64416 .28262 m .64416 .78451 L .6386 .7725 L p .707 .577 .707 r
F P
0 g
s
.6386 .7725 m .6386 .27061 L .64416 .28262 L p .707 .577 .707 r
F P
0 g
s
.15743 .70343 m .15644 .73978 L .15917 .75024 L p .707 .577 .707 r
F P
0 g
s
.34871 .74377 m .35231 .76244 L .35879 .76598 L p .707 .577 .707 r
F P
0 g
s
.35879 .76598 m .3552 .74731 L .34871 .74377 L p .707 .577 .707 r
F P
0 g
s
.3552 .74731 m .35879 .76598 L .35546 .77144 L p .707 .577 .707 r
F P
0 g
s
.35846 .70273 m .35746 .73907 L .34503 .72915 L p .707 .577 .707 r
F P
0 g
s
.34503 .72915 m .34602 .69281 L .35846 .70273 L p .707 .577 .707 r
F P
0 g
s
.35583 .28004 m .35583 .78192 L .3614 .79394 L p .707 .577 .707 r
F P
0 g
s
.35583 .78192 m .35583 .28004 L .36438 .26814 L p .707 .577 .707 r
F P
0 g
s
.16845 .62198 m .16859 .67764 L .16141 .68585 L p .707 .577 .707 r
F P
0 g
s
.15471 .7866 m .15831 .80528 L .16163 .79981 L p .707 .577 .707 r
F P
0 g
s
.16163 .79981 m .15804 .78114 L .15471 .7866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15644 .73978 m .15743 .70343 L .16467 .69344 L p .707 .577 .707 r
F P
0 g
s
.16859 .67764 m .16845 .62198 L .1849 .61473 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16467 .69344 m .16368 .72979 L .15644 .73978 L p .707 .577 .707 r
F P
0 g
s
.1849 .61473 m .18504 .6704 L .16859 .67764 L p .707 .577 .707 r
F P
0 g
s
.34983 .61737 m .34996 .67304 L .32898 .66674 L p .707 .577 .707 r
F P
0 g
s
.32898 .66674 m .32884 .61107 L .34983 .61737 L p .707 .577 .707 r
F P
0 g
s
.35546 .77144 m .35187 .75277 L .3552 .74731 L p .707 .577 .707 r
F P
0 g
s
.6386 .27061 m .6386 .7725 L .61947 .76153 L p .707 .577 .707 r
F P
0 g
s
.61947 .76153 m .61947 .25964 L .6386 .27061 L p .707 .577 .707 r
F P
0 g
s
.1612 .79014 m .16479 .80882 L .15831 .80528 L p .707 .577 .707 r
F P
0 g
s
.15831 .80528 m .15471 .7866 L .1612 .79014 L p .707 .577 .707 r
F P
0 g
s
.18504 .6704 m .1849 .61473 L .20902 .60916 L p .707 .577 .707 r
F P
0 g
s
.36438 .77003 m .36438 .26814 L .3862 .25754 L p .707 .577 .707 r
F P
0 g
s
.36438 .26814 m .36438 .77003 L .35583 .78192 L p .707 .577 .707 r
F P
0 g
s
.16368 .72979 m .16467 .69344 L .18118 .68491 L p .707 .577 .707 r
F P
0 g
s
.32884 .61107 m .32898 .66674 L .30157 .66248 L p .707 .577 .707 r
F P
0 g
s
.30157 .66248 m .30144 .60681 L .32884 .61107 L p .707 .577 .707 r
F P
0 g
s
.20902 .60916 m .20916 .66482 L .18504 .6704 L p .707 .577 .707 r
F P
0 g
s
.18118 .68491 m .18018 .72126 L .16368 .72979 L p .707 .577 .707 r
F P
0 g
s
.34602 .69281 m .34503 .72915 L .3241 .72075 L p .707 .577 .707 r
F P
0 g
s
.3241 .72075 m .3251 .68441 L .34602 .69281 L p .707 .577 .707 r
F P
0 g
s
.35187 .75277 m .35546 .77144 L .34265 .7783 L p .707 .577 .707 r
F P
0 g
s
.20916 .66482 m .20902 .60916 L .23844 .6058 L p .707 .577 .707 r
F P
0 g
s
.34265 .7783 m .33905 .75962 L .35187 .75277 L p .707 .577 .707 r
F P
0 g
s
.17686 .79141 m .18046 .81009 L .16479 .80882 L p .707 .577 .707 r
F P
0 g
s
.16479 .80882 m .1612 .79014 L .17686 .79141 L p .707 .577 .707 r
F P
0 g
s
.30144 .60681 m .30157 .66248 L .27042 .66066 L p .707 .577 .707 r
F P
0 g
s
.27042 .66066 m .27028 .60499 L .30144 .60681 L p .707 .577 .707 r
F P
0 g
s
.18018 .72126 m .18118 .68491 L .20533 .67867 L p .707 .577 .707 r
F P
0 g
s
.61947 .25964 m .61947 .76153 L .58864 .75268 L p .707 .577 .707 r
F P
0 g
s
.58864 .75268 m .58864 .25079 L .61947 .25964 L p .707 .577 .707 r
F P
0 g
s
.23858 .66147 m .23844 .6058 L .27028 .60499 L p .707 .577 .707 r
F P
0 g
s
.23844 .6058 m .23858 .66147 L .20916 .66482 L p .707 .577 .707 r
F P
0 g
s
.27028 .60499 m .27042 .66066 L .23858 .66147 L p .707 .577 .707 r
F P
0 g
s
.3862 .25754 m .3862 .75943 L .36438 .77003 L p .707 .577 .707 r
F P
0 g
s
.3862 .75943 m .3862 .25754 L .41916 .24927 L p .707 .577 .707 r
F P
0 g
s
.20533 .67867 m .20434 .71502 L .18018 .72126 L p .707 .577 .707 r
F P
0 g
s
.3251 .68441 m .3241 .72075 L .29674 .71469 L p .707 .577 .707 r
F P
0 g
s
.29674 .71469 m .29774 .67835 L .3251 .68441 L p .707 .577 .707 r
F P
0 g
s
.33905 .75962 m .34265 .7783 L .3216 .78587 L p .707 .577 .707 r
F P
0 g
s
.20434 .71502 m .20533 .67867 L .23477 .67533 L p .707 .577 .707 r
F P
0 g
s
.3216 .78587 m .31801 .76719 L .33905 .75962 L p .707 .577 .707 r
F P
0 g
s
.72958 .65582 m .72971 .60032 L .69856 .59829 L p .707 .577 .707 r
F P
0 g
s
.72971 .60032 m .72958 .65582 L .76142 .65512 L p .707 .577 .707 r
F P
0 g
s
.76142 .65512 m .76156 .59963 L .72971 .60032 L p .707 .577 .707 r
F P
0 g
s
.20017 .79029 m .20376 .80896 L .18046 .81009 L p .707 .577 .707 r
F P
0 g
s
.18046 .81009 m .17686 .79141 L .20017 .79029 L p .707 .577 .707 r
F P
0 g
s
.76156 .59963 m .76142 .65512 L .79084 .65177 L p .707 .577 .707 r
F P
0 g
s
.79084 .65177 m .79098 .59627 L .76156 .59963 L p .707 .577 .707 r
F P
0 g
s
.29774 .67835 m .29674 .71469 L .26561 .71156 L p .707 .577 .707 r
F P
0 g
s
.26561 .71156 m .26661 .67522 L .29774 .67835 L p .707 .577 .707 r
F P
0 g
s
.69843 .65378 m .69856 .59829 L .67115 .59372 L p .707 .577 .707 r
F P
0 g
s
.69856 .59829 m .69843 .65378 L .72958 .65582 L p .707 .577 .707 r
F P
0 g
s
.23377 .71168 m .23477 .67533 L .26661 .67522 L p .707 .577 .707 r
F P
0 g
s
.23477 .67533 m .23377 .71168 L .20434 .71502 L p .707 .577 .707 r
F P
0 g
s
.73438 .71292 m .73339 .67532 L .70226 .67459 L p .707 .577 .707 r
F P
0 g
s
.73339 .67532 m .73438 .71292 L .76622 .71154 L p .707 .577 .707 r
F P
0 g
s
.76622 .71154 m .76523 .67394 L .73339 .67532 L p .707 .577 .707 r
F P
0 g
s
.58864 .25079 m .58864 .75268 L .54913 .74683 L p .707 .577 .707 r
F P
0 g
s
.54913 .74683 m .54913 .24494 L .58864 .25079 L p .707 .577 .707 r
F P
0 g
s
.26661 .67522 m .26561 .71156 L .23377 .71168 L p .707 .577 .707 r
F P
0 g
s
.76523 .67394 m .76622 .71154 L .79566 .70819 L p .707 .577 .707 r
F P
0 g
s
.79566 .70819 m .79466 .67059 L .76523 .67394 L p .707 .577 .707 r
F P
0 g
s
.79098 .59627 m .79084 .65177 L .81496 .64608 L p .707 .577 .707 r
F P
0 g
s
.81496 .64608 m .81509 .59059 L .79098 .59627 L p .707 .577 .707 r
F P
0 g
s
.41916 .75116 m .41916 .24927 L .46004 .24414 L p .707 .577 .707 r
F P
0 g
s
.41916 .24927 m .41916 .75116 L .3862 .75943 L p .707 .577 .707 r
F P
0 g
s
.70326 .71219 m .70226 .67459 L .6749 .67183 L p .707 .577 .707 r
F P
0 g
s
.70226 .67459 m .70326 .71219 L .73438 .71292 L p .707 .577 .707 r
F P
0 g
s
.31801 .76719 m .3216 .78587 L .29439 .79341 L p .707 .577 .707 r
F P
0 g
s
.22884 .78688 m .23243 .80556 L .20376 .80896 L p .707 .577 .707 r
F P
0 g
s
.20376 .80896 m .20017 .79029 L .22884 .78688 L p .707 .577 .707 r
F P
0 g
s
.29439 .79341 m .29079 .77474 L .31801 .76719 L p .707 .577 .707 r
F P
0 g
s
.67115 .59372 m .67102 .64922 L .69843 .65378 L p .707 .577 .707 r
F P
0 g
s
.67102 .64922 m .67115 .59372 L .65017 .58708 L p .707 .577 .707 r
F P
0 g
s
.79466 .67059 m .79566 .70819 L .81981 .7032 L p .707 .577 .707 r
F P
0 g
s
.81981 .7032 m .81882 .6656 L .79466 .67059 L p .707 .577 .707 r
F P
0 g
s
.6749 .67183 m .6759 .70943 L .70326 .71219 L p .707 .577 .707 r
F P
0 g
s
.54913 .24494 m .54913 .74683 L .50482 .74454 L p .707 .577 .707 r
F P
0 g
s
.50482 .74454 m .50482 .24265 L .54913 .24494 L p .707 .577 .707 r
F P
0 g
s
.29079 .77474 m .29439 .79341 L .26366 .8002 L p .707 .577 .707 r
F P
0 g
s
.81509 .59059 m .81496 .64608 L .83141 .63862 L p .707 .577 .707 r
F P
0 g
s
.83141 .63862 m .83155 .58312 L .81509 .59059 L p .707 .577 .707 r
F P
0 g
s
.6759 .70943 m .6749 .67183 L .65397 .66731 L p .707 .577 .707 r
F P
0 g
s
.46004 .74603 m .46004 .24414 L .50482 .24265 L p .707 .577 .707 r
F P
0 g
s
.46004 .24414 m .46004 .74603 L .41916 .75116 L p .707 .577 .707 r
F P
0 g
s
.26006 .78152 m .26366 .8002 L .23243 .80556 L p .707 .577 .707 r
F P
0 g
s
.23243 .80556 m .22884 .78688 L .26006 .78152 L p .707 .577 .707 r
F P
0 g
s
.26366 .8002 m .26006 .78152 L .29079 .77474 L p .707 .577 .707 r
F P
0 g
s
.65017 .58708 m .65003 .64257 L .67102 .64922 L p .707 .577 .707 r
F P
0 g
s
.73634 .79694 m .73993 .78244 L .70921 .77372 L p .707 .577 .707 r
F P
0 g
s
.73993 .78244 m .73634 .79694 L .76756 .79932 L p .707 .577 .707 r
F P
0 g
s
.76756 .79932 m .77116 .78483 L .73993 .78244 L p .707 .577 .707 r
F P
0 g
s
.50482 .24265 m .50482 .74454 L .46004 .74603 L p .707 .577 .707 r
F P
0 g
s
.70561 .78822 m .70921 .77372 L .68199 .75952 L p .707 .577 .707 r
F P
0 g
s
.70921 .77372 m .70561 .78822 L .73634 .79694 L p .707 .577 .707 r
F P
0 g
s
.65397 .66731 m .65497 .70491 L .6759 .70943 L p .707 .577 .707 r
F P
0 g
s
.65003 .64257 m .65017 .58708 L .63767 .579 L p .707 .577 .707 r
F P
0 g
s
.77116 .78483 m .76756 .79932 L .79624 .79515 L p .707 .577 .707 r
F P
0 g
s
.79624 .79515 m .79983 .78065 L .77116 .78483 L p .707 .577 .707 r
F P
0 g
s
.81882 .6656 m .81981 .7032 L .83632 .69706 L p .707 .577 .707 r
F P
0 g
s
.83632 .69706 m .83532 .65945 L .81882 .6656 L p .707 .577 .707 r
F P
0 g
s
.67839 .77402 m .68199 .75952 L .66094 .74123 L p .707 .577 .707 r
F P
0 g
s
.68199 .75952 m .67839 .77402 L .70561 .78822 L p .707 .577 .707 r
F P
0 g
s
.65497 .70491 m .65397 .66731 L .64154 .66146 L p .707 .577 .707 r
F P
0 g
s
.79983 .78065 m .79624 .79515 L .81954 .78481 L p .707 .577 .707 r
F P
0 g
s
.81954 .78481 m .82314 .77032 L .79983 .78065 L p .707 .577 .707 r
F P
0 g
s
.83155 .58312 m .83141 .63862 L .83859 .63011 L p .707 .577 .707 r
F P
0 g
s
.83859 .63011 m .83872 .57461 L .83155 .58312 L p .707 .577 .707 r
F P
0 g
s
.63767 .579 m .63753 .63449 L .65003 .64257 L p .707 .577 .707 r
F P
0 g
s
.66094 .74123 m .65735 .75573 L .67839 .77402 L p .707 .577 .707 r
F P
0 g
s
.65735 .75573 m .66094 .74123 L .64813 .72065 L p .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64813 .72065 L .64789 .71916 L p .707 .577 .707 r
F P
0 g
s
.64154 .66146 m .64254 .69906 L .65209 .70355 L p .707 .577 .707 r
F P
0 g
s
.64789 .71916 m .6448 .69978 L p .64456 .73153 L .707 .577 .707 r
F P
0 g
s
.64453 .73514 m .64789 .71916 L .64456 .73153 L .707 .577 .707 r
F
.65209 .70355 m .65497 .70491 L p .65324 .6993 L F P
0 g
s
.65324 .6993 m .64154 .66146 L .65209 .70355 L .707 .577 .707 r
F
.83532 .65945 m .83632 .69706 L .84356 .69036 L p F P
0 g
s
.84356 .69036 m .84257 .65276 L .83532 .65945 L p .707 .577 .707 r
F P
0 g
s
.63753 .63449 m .63767 .579 L .63487 .57028 L p .707 .577 .707 r
F P
0 g
s
.64813 .72065 m .64453 .73514 L .65735 .75573 L p .707 .577 .707 r
F P
0 g
s
.82314 .77032 m .81954 .78481 L .83521 .76934 L p .707 .577 .707 r
F P
0 g
s
.83521 .76934 m .8388 .75484 L .82314 .77032 L p .707 .577 .707 r
F P
0 g
s
.64254 .69906 m .64154 .66146 L .63881 .65487 L p .707 .577 .707 r
F P
0 g
s
.63487 .57028 m .63473 .62577 L .63753 .63449 L p .707 .577 .707 r
F P
0 g
s
.83872 .57461 m .83859 .63011 L .83579 .62139 L p .707 .577 .707 r
F P
0 g
s
.83579 .62139 m .83592 .56589 L .83872 .57461 L p .707 .577 .707 r
F P
0 g
s
.63881 .65487 m .63981 .69247 L .64254 .69906 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.6448 .69978 m .64121 .71428 L .64453 .73514 L p .707 .577 .707 r
F P
0 g
s
.8388 .75484 m .83521 .76934 L .84169 .75023 L p .707 .577 .707 r
F P
0 g
s
.84169 .75023 m .84529 .73573 L .8388 .75484 L p .707 .577 .707 r
F P
0 g
s
.84257 .65276 m .84356 .69036 L .84083 .68376 L p .707 .577 .707 r
F P
0 g
s
.84083 .68376 m .83984 .64616 L .84257 .65276 L p .707 .577 .707 r
F P
0 g
s
.63473 .62577 m .63487 .57028 L .64204 .56177 L p .707 .577 .707 r
F P
0 g
s
.64121 .71428 m .6448 .69978 L .65129 .68067 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63981 .69247 m .63881 .65487 L .64605 .64817 L p .707 .577 .707 r
F P
0 g
s
.64204 .56177 m .64191 .61727 L .63473 .62577 L p .707 .577 .707 r
F P
0 g
s
.38197 .62129 m .38229 .56568 L .35114 .5636 L p .707 .577 .707 r
F P
0 g
s
.38229 .56568 m .38197 .62129 L .41381 .62072 L p .707 .577 .707 r
F P
0 g
s
.41381 .62072 m .41413 .5651 L .38229 .56568 L p .707 .577 .707 r
F P
0 g
s
.83592 .56589 m .83579 .62139 L .82328 .61331 L p .707 .577 .707 r
F P
0 g
s
.82328 .61331 m .82342 .55782 L .83592 .56589 L p .707 .577 .707 r
F P
0 g
s
.65129 .68067 m .64769 .69517 L .64121 .71428 L p .707 .577 .707 r
F P
0 g
s
.41413 .5651 m .41381 .62072 L .44323 .61755 L p .707 .577 .707 r
F P
0 g
s
.44323 .61755 m .44355 .56193 L .41413 .5651 L p .707 .577 .707 r
F P
0 g
s
.64605 .64817 m .64705 .68577 L .63981 .69247 L p .707 .577 .707 r
F P
0 g
s
.84529 .73573 m .84169 .75023 L .83836 .72936 L p .707 .577 .707 r
F P
0 g
s
.83836 .72936 m .84196 .71486 L .84529 .73573 L p .707 .577 .707 r
F P
0 g
s
.35082 .61922 m .35114 .5636 L .32373 .55908 L p .707 .577 .707 r
F P
0 g
s
.35114 .5636 m .35082 .61922 L .38197 .62129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83984 .64616 m .84083 .68376 L .8284 .67792 L p .707 .577 .707 r
F P
0 g
s
.8284 .67792 m .8274 .64032 L .83984 .64616 L p .707 .577 .707 r
F P
0 g
s
.64191 .61727 m .64204 .56177 L .65849 .55431 L p .707 .577 .707 r
F P
0 g
s
.64769 .69517 m .65129 .68067 L .66695 .66519 L p .707 .577 .707 r
F P
0 g
s
.44355 .56193 m .44323 .61755 L .46735 .61209 L p .707 .577 .707 r
F P
0 g
s
.46735 .61209 m .46767 .55647 L .44355 .56193 L p .707 .577 .707 r
F P
0 g
s
.32373 .55908 m .32341 .6147 L .35082 .61922 L p .707 .577 .707 r
F P
0 g
s
.32341 .6147 m .32373 .55908 L .30275 .55255 L p .707 .577 .707 r
F P
0 g
s
.66695 .66519 m .66336 .67969 L .64769 .69517 L p .707 .577 .707 r
F P
0 g
s
.39343 .68348 m .3911 .64677 L .36003 .64644 L p .707 .577 .707 r
F P
0 g
s
.3911 .64677 m .39343 .68348 L .42522 .68084 L p .707 .577 .707 r
F P
0 g
s
.42522 .68084 m .42289 .64413 L .3911 .64677 L p .707 .577 .707 r
F P
0 g
s
.64705 .68577 m .64605 .64817 L .66256 .64203 L p .707 .577 .707 r
F P
0 g
s
.42289 .64413 m .42522 .68084 L .45462 .67549 L p .707 .577 .707 r
F P
0 g
s
.45462 .67549 m .45229 .63878 L .42289 .64413 L p .707 .577 .707 r
F P
0 g
s
.82342 .55782 m .82328 .61331 L .8023 .60667 L p .707 .577 .707 r
F P
0 g
s
.8023 .60667 m .80243 .55117 L .82342 .55782 L p .707 .577 .707 r
F P
0 g
s
.65849 .55431 m .65836 .6098 L .64191 .61727 L p .707 .577 .707 r
F P
0 g
s
.84196 .71486 m .83836 .72936 L .82555 .70877 L p .707 .577 .707 r
F P
0 g
s
.82555 .70877 m .82915 .69427 L .84196 .71486 L p .707 .577 .707 r
F P
0 g
s
.36235 .68315 m .36003 .64644 L .33271 .64318 L p .707 .577 .707 r
F P
0 g
s
.36003 .64644 m .36235 .68315 L .39343 .68348 L p .707 .577 .707 r
F P
0 g
s
.46767 .55647 m .46735 .61209 L .4838 .60488 L p .707 .577 .707 r
F P
0 g
s
.4838 .60488 m .48412 .54927 L .46767 .55647 L p .707 .577 .707 r
F P
0 g
s
.66336 .67969 m .66695 .66519 L .69026 .65486 L p .707 .577 .707 r
F P
0 g
s
.69026 .65486 m .68666 .66935 L .66336 .67969 L p .707 .577 .707 r
F P
0 g
s
.66256 .64203 m .66355 .67963 L .64705 .68577 L p .707 .577 .707 r
F P
0 g
s
.30275 .55255 m .30243 .60817 L .32341 .6147 L p .707 .577 .707 r
F P
0 g
s
.65836 .6098 m .65849 .55431 L .68261 .54862 L p .707 .577 .707 r
F P
0 g
s
.45229 .63878 m .45462 .67549 L .47875 .66796 L p .707 .577 .707 r
F P
0 g
s
.47875 .66796 m .47642 .63126 L .45229 .63878 L p .707 .577 .707 r
F P
0 g
s
.8274 .64032 m .8284 .67792 L .80747 .6734 L p .707 .577 .707 r
F P
0 g
s
.80747 .6734 m .80648 .63579 L .8274 .64032 L p .707 .577 .707 r
F P
0 g
s
.39287 .69981 m .40084 .68238 L .37257 .66888 L p .707 .577 .707 r
F P
0 g
s
.40084 .68238 m .39287 .69981 L .42188 .71276 L p .707 .577 .707 r
F P
0 g
s
.42188 .71276 m .42985 .69532 L .40084 .68238 L p .707 .577 .707 r
F P
0 g
s
.37257 .66888 m .3646 .68631 L .39287 .69981 L p .707 .577 .707 r
F P
0 g
s
.33271 .64318 m .33504 .67989 L .36235 .68315 L p .707 .577 .707 r
F P
0 g
s
.30243 .60817 m .30275 .55255 L .29024 .54466 L p .707 .577 .707 r
F P
0 g
s
.42985 .69532 m .42188 .71276 L .44879 .72387 L p .707 .577 .707 r
F P
0 g
s
.44879 .72387 m .45676 .70644 L .42985 .69532 L p .707 .577 .707 r
F P
0 g
s
.3646 .68631 m .37257 .66888 L .34782 .65614 L p .707 .577 .707 r
F P
0 g
s
.33504 .67989 m .33271 .64318 L .31184 .63731 L p .707 .577 .707 r
F P
0 g
s
.82915 .69427 m .82555 .70877 L .80451 .69049 L p .707 .577 .707 r
F P
0 g
s
.80451 .69049 m .8081 .67599 L .82915 .69427 L p .707 .577 .707 r
F P
0 g
s
.34782 .65614 m .33984 .67357 L .3646 .68631 L p .707 .577 .707 r
F P
0 g
s
.80243 .55117 m .8023 .60667 L .77489 .6021 L p .707 .577 .707 r
F P
0 g
s
.77489 .6021 m .77503 .54661 L .80243 .55117 L p .707 .577 .707 r
F P
0 g
s
.66355 .67963 m .66256 .64203 L .68671 .63703 L p .707 .577 .707 r
F P
0 g
s
.68261 .54862 m .68248 .60412 L .65836 .6098 L p .707 .577 .707 r
F P
0 g
s
.68666 .66935 m .69026 .65486 L .71893 .65068 L p .707 .577 .707 r
F P
0 g
s
.47642 .63126 m .47875 .66796 L .49525 .65899 L p .707 .577 .707 r
F P
0 g
s
.49525 .65899 m .49292 .62228 L .47642 .63126 L p .707 .577 .707 r
F P
0 g
s
.68248 .60412 m .68261 .54862 L .71203 .54527 L p .707 .577 .707 r
F P
0 g
s
.45676 .70644 m .44879 .72387 L .47096 .73207 L p .707 .577 .707 r
F P
0 g
s
.47096 .73207 m .47894 .71464 L .45676 .70644 L p .707 .577 .707 r
F P
0 g
s
.29024 .54466 m .28992 .60027 L .30243 .60817 L p .707 .577 .707 r
F P
0 g
s
.48412 .54927 m .4838 .60488 L .49098 .59663 L p .707 .577 .707 r
F P
0 g
s
.49098 .59663 m .4913 .54102 L .48412 .54927 L p .707 .577 .707 r
F P
0 g
s
.31184 .63731 m .31416 .67402 L .33504 .67989 L p .707 .577 .707 r
F P
0 g
s
.71893 .65068 m .71533 .66518 L .68666 .66935 L p .707 .577 .707 r
F P
0 g
s
.68671 .63703 m .68771 .67464 L .66355 .67963 L p .707 .577 .707 r
F P
0 g
s
.33984 .67357 m .34782 .65614 L .32899 .6454 L p .707 .577 .707 r
F P
0 g
s
.77729 .67629 m .78088 .66179 L .8081 .67599 L p .707 .577 .707 r
F P
0 g
s
.80648 .63579 m .80747 .6734 L .78011 .67064 L p .707 .577 .707 r
F P
0 g
s
.78088 .66179 m .77729 .67629 L .74656 .66757 L p .707 .577 .707 r
F P
0 g
s
.74656 .66757 m .75016 .65307 L .78088 .66179 L p .707 .577 .707 r
F P
0 g
s
.78011 .67064 m .77911 .63303 L .80648 .63579 L p .707 .577 .707 r
F P
0 g
s
.8081 .67599 m .80451 .69049 L .77729 .67629 L p .707 .577 .707 r
F P
0 g
s
.32899 .6454 m .32102 .66284 L .33984 .67357 L p .707 .577 .707 r
F P
0 g
s
.77503 .54661 m .77489 .6021 L .74374 .60007 L p .707 .577 .707 r
F P
0 g
s
.74374 .60007 m .74387 .54457 L .77503 .54661 L p .707 .577 .707 r
F P
0 g
s
.71533 .66518 m .71893 .65068 L .75016 .65307 L p .707 .577 .707 r
F P
0 g
s
.7119 .60076 m .71203 .54527 L .74387 .54457 L p .707 .577 .707 r
F P
0 g
s
.71203 .54527 m .7119 .60076 L .68248 .60412 L p .707 .577 .707 r
F P
0 g
s
.31416 .67402 m .31184 .63731 L .29944 .62939 L p .707 .577 .707 r
F P
0 g
s
.28992 .60027 m .29024 .54466 L .28744 .53617 L p .707 .577 .707 r
F P
0 g
s
.74387 .54457 m .74374 .60007 L .7119 .60076 L p .707 .577 .707 r
F P
0 g
s
.68771 .67464 m .68671 .63703 L .71615 .63369 L p .707 .577 .707 r
F P
0 g
s
.75016 .65307 m .74656 .66757 L .71533 .66518 L p .707 .577 .707 r
F P
0 g
s
.47894 .71464 m .47096 .73207 L .48624 .73656 L p .707 .577 .707 r
F P
0 g
s
.48624 .73656 m .49421 .71913 L .47894 .71464 L p .707 .577 .707 r
F P
0 g
s
.77911 .63303 m .78011 .67064 L .74899 .66991 L p .707 .577 .707 r
F P
0 g
s
.74899 .66991 m .74799 .63231 L .77911 .63303 L p .707 .577 .707 r
F P
0 g
s
.71615 .63369 m .71715 .67129 L .68771 .67464 L p .707 .577 .707 r
F P
0 g
s
.29944 .62939 m .30177 .6661 L .31416 .67402 L p .707 .577 .707 r
F P
0 g
s
.49292 .62228 m .49525 .65899 L .5025 .64945 L p .707 .577 .707 r
F P
0 g
s
.5025 .64945 m .50017 .61274 L .49292 .62228 L p .707 .577 .707 r
F P
0 g
s
.71715 .67129 m .71615 .63369 L .74799 .63231 L p .707 .577 .707 r
F P
0 g
s
.32102 .66284 m .32899 .6454 L .31793 .63773 L p .707 .577 .707 r
F P
0 g
s
.74799 .63231 m .74899 .66991 L .71715 .67129 L p .707 .577 .707 r
F P
0 g
s
.28744 .53617 m .28712 .59179 L .28992 .60027 L p .707 .577 .707 r
F P
0 g
s
.31793 .63773 m .30996 .65516 L .32102 .66284 L p .707 .577 .707 r
F P
0 g
s
.4913 .54102 m .49098 .59663 L .48818 .58815 L p .707 .577 .707 r
F P
0 g
s
.48818 .58815 m .48849 .53253 L .4913 .54102 L p .707 .577 .707 r
F P
0 g
s
.30177 .6661 m .29944 .62939 L .29673 .62022 L p .707 .577 .707 r
F P
0 g
s
.28712 .59179 m .28744 .53617 L .29462 .52792 L p .707 .577 .707 r
F P
0 g
s
.49421 .71913 m .48624 .73656 L .49311 .73688 L p .707 .577 .707 r
F P
0 g
s
.49311 .73688 m .50108 .71945 L .49421 .71913 L p .707 .577 .707 r
F P
0 g
s
.29673 .62022 m .29906 .65693 L .30177 .6661 L p .707 .577 .707 r
F P
0 g
s
.50017 .61274 m .5025 .64945 L .49979 .64027 L p .707 .577 .707 r
F P
0 g
s
.49979 .64027 m .49747 .60356 L .50017 .61274 L p .707 .577 .707 r
F P
0 g
s
.30996 .65516 m .31793 .63773 L .31574 .63387 L p .707 .577 .707 r
F P
0 g
s
.31574 .63387 m .30777 .6513 L .30996 .65516 L p .707 .577 .707 r
F P
0 g
s
.29462 .52792 m .2943 .58354 L .28712 .59179 L p .707 .577 .707 r
F P
0 g
s
.48849 .53253 m .48818 .58815 L .47567 .58025 L p .707 .577 .707 r
F P
0 g
s
.47567 .58025 m .47599 .52464 L .48849 .53253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29906 .65693 m .29673 .62022 L .30398 .61067 L p .707 .577 .707 r
F P
0 g
s
.2943 .58354 m .29462 .52792 L .31107 .52071 L p .707 .577 .707 r
F P
0 g
s
.50108 .71945 m .49311 .73688 L .49092 .73302 L p .707 .577 .707 r
F P
0 g
s
.49092 .73302 m .49889 .71559 L .50108 .71945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30398 .61067 m .30631 .64738 L .29906 .65693 L p .707 .577 .707 r
F P
0 g
s
.49747 .60356 m .49979 .64027 L .4874 .63236 L p .707 .577 .707 r
F P
0 g
s
.4874 .63236 m .48507 .59565 L .49747 .60356 L p .707 .577 .707 r
F P
0 g
s
.30777 .6513 m .31574 .63387 L .32261 .6342 L p .707 .577 .707 r
F P
0 g
s
.31107 .52071 m .31075 .57633 L .2943 .58354 L p .707 .577 .707 r
F P
0 g
s
.47599 .52464 m .47567 .58025 L .45469 .57373 L p .707 .577 .707 r
F P
0 g
s
.45469 .57373 m .45501 .51811 L .47599 .52464 L p .707 .577 .707 r
F P
0 g
s
.32261 .6342 m .31464 .65163 L .30777 .6513 L p .707 .577 .707 r
F P
0 g
s
.31075 .57633 m .31107 .52071 L .33519 .51526 L p .707 .577 .707 r
F P
0 g
s
.30631 .64738 m .30398 .61067 L .32048 .6017 L p .707 .577 .707 r
F P
0 g
s
.49889 .71559 m .49092 .73302 L .47986 .72535 L p .707 .577 .707 r
F P
0 g
s
.47986 .72535 m .48784 .70792 L .49889 .71559 L p .707 .577 .707 r
F P
0 g
s
.31464 .65163 m .32261 .6342 L .33789 .63868 L p .707 .577 .707 r
F P
0 g
s
.32048 .6017 m .32281 .63841 L .30631 .64738 L p .707 .577 .707 r
F P
0 g
s
.45501 .51811 m .45469 .57373 L .42728 .5692 L p .707 .577 .707 r
F P
0 g
s
.42728 .5692 m .4276 .51359 L .45501 .51811 L p .707 .577 .707 r
F P
0 g
s
.48507 .59565 m .4874 .63236 L .46652 .62648 L p .707 .577 .707 r
F P
0 g
s
.46652 .62648 m .46419 .58977 L .48507 .59565 L p .707 .577 .707 r
F P
0 g
s
.33519 .51526 m .33487 .57088 L .31075 .57633 L p .707 .577 .707 r
F P
0 g
s
.33487 .57088 m .33519 .51526 L .36461 .51209 L p .707 .577 .707 r
F P
0 g
s
.33789 .63868 m .32991 .65611 L .31464 .65163 L p .707 .577 .707 r
F P
0 g
s
.32281 .63841 m .32048 .6017 L .34461 .59417 L p .707 .577 .707 r
F P
0 g
s
.4276 .51359 m .42728 .5692 L .39613 .56713 L p .707 .577 .707 r
F P
0 g
s
.39613 .56713 m .39645 .51151 L .4276 .51359 L p .707 .577 .707 r
F P
0 g
s
.36429 .5677 m .36461 .51209 L .39645 .51151 L p .707 .577 .707 r
F P
0 g
s
.36461 .51209 m .36429 .5677 L .33487 .57088 L p .707 .577 .707 r
F P
0 g
s
.39645 .51151 m .39613 .56713 L .36429 .5677 L p .707 .577 .707 r
F P
0 g
s
.46419 .58977 m .46652 .62648 L .43921 .62322 L p .707 .577 .707 r
F P
0 g
s
.43921 .62322 m .43688 .58651 L .46419 .58977 L p .707 .577 .707 r
F P
0 g
s
.34461 .59417 m .34694 .63088 L .32281 .63841 L p .707 .577 .707 r
F P
0 g
s
.48784 .70792 m .47986 .72535 L .46103 .71462 L p .707 .577 .707 r
F P
0 g
s
.46103 .71462 m .46901 .69719 L .48784 .70792 L p .707 .577 .707 r
F P
0 g
s
.34694 .63088 m .34461 .59417 L .37401 .58882 L p .707 .577 .707 r
F P
0 g
s
.32991 .65611 m .33789 .63868 L .36006 .64688 L p .707 .577 .707 r
F P
0 g
s
.36006 .64688 m .35209 .66431 L .32991 .65611 L p .707 .577 .707 r
F P
0 g
s
.43688 .58651 m .43921 .62322 L .40813 .6229 L p .707 .577 .707 r
F P
0 g
s
.40813 .6229 m .4058 .58619 L .43688 .58651 L p .707 .577 .707 r
F P
0 g
s
.37401 .58882 m .37634 .62553 L .34694 .63088 L p .707 .577 .707 r
F P
0 g
s
.37634 .62553 m .37401 .58882 L .4058 .58619 L p .707 .577 .707 r
F P
0 g
s
.4058 .58619 m .40813 .6229 L .37634 .62553 L p .707 .577 .707 r
F P
0 g
s
.46901 .69719 m .46103 .71462 L .43628 .70188 L p .707 .577 .707 r
F P
0 g
s
.43628 .70188 m .44425 .68445 L .46901 .69719 L p .707 .577 .707 r
F P
0 g
s
.35209 .66431 m .36006 .64688 L .38697 .658 L p .707 .577 .707 r
F P
0 g
s
.38697 .658 m .379 .67543 L .35209 .66431 L p .707 .577 .707 r
F P
0 g
s
.44425 .68445 m .43628 .70188 L .40801 .68837 L p .707 .577 .707 r
F P
0 g
s
.40801 .68837 m .41598 .67094 L .44425 .68445 L p .707 .577 .707 r
F P
0 g
s
.379 .67543 m .38697 .658 L .41598 .67094 L p .707 .577 .707 r
F P
0 g
s
.41598 .67094 m .40801 .68837 L .379 .67543 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aooa40009JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00GWoo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001JOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001GOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001A
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0001Moo`T004Eoo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo2000
15YF00<005YFFUH00UYF2000?Goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0007Ool80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol0055oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00DGoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo001AOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001AOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001AOol00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH0
1UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool0055oo`03001JEP0000=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEPD000AJEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol0
1000FUH005YF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000AJEP00FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001A
Ool00`00FUH000020006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH000000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0
055oo`80009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF014000AJ
EP04001JEUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DGoo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH02@0015YF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP<0
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000015YF
000000000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0055oo`80009JEP03001JEUYF00=JEP04001J
EUYFFUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000EJEP04001J
EP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo0`0015YF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP02FUH70008
FUH60003FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0041ooaL00005FUH00000FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF1P000eYF00<005YFFUH01EYF1P0015YF
00<005YFFUH00P00;Woo000hOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000015YF001JEUYF0P00;Woo000cOol50003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00P005YFFUIJEP00FUH005YF0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8002io
o`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUIJEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00;Woo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01UYF1`000eYF00@005YFFUIJEP80
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000^Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH500000eYF001J
EP04FUH60004FUH00`00FUIJEP08FUH01000FUIJEUYF1@000eYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEPX0
00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;Goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03
001JEP0000<0009JEP05001JEP00FUH00005FUH60004FUH00`00FUIJEP08FUH400000eYF001JEP02
FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YF00001`0015YF00<005YFFUH00UYF3`0015YF0P00;goo000]
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEP000eYF0P0000=JEP0000000P0000IJEP00FUH005YF0005FUH60004FUH00`00FUIJ
EP05FUH30005FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40005FUH00`00FUH000070003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000`Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001J
EUYF00@00003FUH005YF00AJEP03001JEP00008000EJEP04001JEUYFFUH400000eYF001JEP05FUH0
0`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000P0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004FUH00`00FUIJ
EP03FUHF0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002io
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
1P000eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002
FUH40006FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF0`000eYF1000
00=JEP00FUH01eYF0`0025YF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF2@0025YF1@000eYF00<005YF00001EYF00@005YF000000QJEP03001JEUYF008000IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]
Ool002eoo`03001JEP0000AJEP04001JEUYFFUH80008FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00P000eYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF
00000eYF1P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF0`001UYF0P000eYF00<005YFFUH01UYF0P0000=JEP00FUH01eYF00@005YFFUIJEP8000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF009JEQT000AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo
00@005YF001JEP8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP<000AJEP8000QJEP800003FUH005YF00MJEP04001JEP000008FUH01000FUH000002UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF2P0017oo2`0000=JEP00FUH00eYF1`000eYF00<005YFFUH00P00;Goo000]Ool01P00
FUH00000FUH000EJEQh000AJEP@00003FUH005YF008000EJEP03001JEUYF008000QJEP04001JEUYF
FUH20002FUH6000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP02FUH90004FUH01000FUH000001eYF
0P000UYF10000UYF0P00;Goo000]Ool20003FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000040003FUH70003FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH0
1000FUIJEUYF0P001UYF0P0000=JEP00FUH00UYF1000;Goo000]Ool20003FUH30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00FUH000040006
FUH40002FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00P0015YF0`00;Goo000]
Ool20002FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30002FUH01`00FUIJEUYF001JEP0000IJEPL000UJEP<00003FUH005YF00]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH00UYF0P00
0eYF0`00;Goo000]Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUH000020004FUH50002FUH20006
FUH01000FUIJEUYF0P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000AJEP00000000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000EJEP06001JEUYF001JEP00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUH00002FUH20003FUH30005FUH20004FUH00`00FUIJEP03FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP001EYF
00@005YF000002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH00eYF0P0000=JEP00
FUH025YF0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00H005YFFUH005YF0005FUH40008FUH01000FUH0000025YF0`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
15YF001JEP00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP04
001JEUYFFUH20005FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP@000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<00003Ool00000
009JEP03001oogoo02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005
FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH80003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60006Ool01@00FUIJEUYF0000;Woo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJEP<000MJEP@000IJEP<0009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00AJEQ/000eoo`04001JEUYF000^Ool002aoo`03001JEP0000AJEP03001JEUYF00=J
EPH000Eoo`T000=oo`P000AJEP03001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01eYF
00@005YF000000EJEP04001JEUYF0005FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009J
EP<000Ioo`<001Moo`05001JEUYFFUH0000]Ool002aoo`03001JEP0000AJEP03001JEP0000<001mo
o`D000EJEP06001JEUYF001JEP001EYF00<005YFFUH01eYF00@005YFFUIJEP<00003FUH005YF00=J
EP8000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30005Ool5000GOol01000FUIJEP00
;Goo000/Ool00`00FUH00003FUH3000COol3000BOol20003FUH01P00FUIJEP00FUH000EJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000IJEP<000=JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02FUH0
0`00FUH00005Ool5000HOol3000]Ool002aoo`04001JEP00FUH4000COol5000COol200001eYF001J
EUYF001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP8000AJEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000=J
EP03001JEUYF00=JEP03001JEUYF009JEP8000Ioo`D001Qoo`<002eoo`00;7oo00H005YF000005YF
0002FUH2000AOol5000DOol30002FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
0002FUH00`00FUIJEP03000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEPH000AJEP03001JEUYF009JEP03001oogoo00Ioo`<001Yoo`03001JEP00
02aoo`00;7oo0P000eYF00<005YFFUH00UYF1@0037oo1@004Goo0`000eYF00D005YF001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEP0000<0009JEP<0009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP05001JEUYF001JEP03
000015YF001JEUYF0P009Woo00<005YF0000;7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF20001Goo0`002Woo20000UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH00eYF1@000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUH000AJEP@002Qoo`03001JEP0002ao
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF0000009JEP03001JEP0000EJEP<002Qoo`03001JEP0002aoo`00;7oo0P000UYF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEQ800003FUH005YF
00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH30005FUH00`00FUIJEP02000WOol00`00
Oomoo`0[Ool002eoo`04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH<0003FUH00`00FUIJEP07FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH005YF0P000UYF00<005YFFUH00eYF00D005YFFUIJEP0002Moo`03001oogoo02]oo`00;Goo
00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEPP000=JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00=JEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Woo0P00;Goo000^Ool00`00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH50006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<007ooOol097oo0P00;Goo000_Ool20005FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP0400000eYF001JEP04
FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP03FUH20004FUH00`00
Oomoo`0SOol2000^Ool0031oo`8000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF009JEPd0009JEP800003FUH005YF009JEP8000MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<000AJEP03001JEP0000AJ
EP03001JEUYF009JEP<000=JEP03001oogoo029oo`<002ioo`00<Woo0`0000=JEP00FUH00`000eYF
00<005YFFUH01eYF00<005YFFUH015YF1P000eYF00@005YFFUIJEP<00003FUH005YF00=JEP04001J
EP00FUH200000eYF001JEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH00`00FUH000030002FUH01@00FUIJEUYF
00000UYF00@005YF000002=oo`03001JEP0002moo`00=Goo0`001UYF00<005YFFUH01eYF00<005YF
FUH0100000=JEP00FUH01UYF100015YF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00EJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH0000000H00003FUH005YF00=JEP<0029oo`04001JEUYF000_Ool0
039oo`<00003FUH005YF00MJEP03001JEUYF00AJEPD000EJEP03001JEUYF009JEP@00003FUH005YF
00EJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
15YF0P001UYF0P007goo0P000UYF00<007ooOol0;Woo000`Ool20004FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF000000030004FUH50005FUH00`00FUIJEP04FUH00`00FUH000030005FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF00<005YFFUH01UYF0`006Goo0`00
00AJEP00FUH0035oo`00;Woo0`001UYF00<005YFFUH015YF100000=oo`0000002`000UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`000Woo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
0000009JEP03001JEUYF00AJEP8000IJEP03001JEUYF00@0019oo`<000=JEP03001JEP00039oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH0100027oo1P001UYF00<005YFFUH01UYF00<005YF
00000P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF
00AJEP04001JEP000003FUH00`00FUIJEP05FUH70007Ool400000eYF001JEP03FUH2000cOol002]o
o`8000AJEP03001JEUYF009JEP@000=oo`T000=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000Qo
o`8000EJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00
FUIJEP0400000eYF001JEP08FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP02FUH00`00Oomoo`0b
Ool002]oo`D00003FUH005YF00X000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00aoo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00AJEP04001JEUYFFUH200000eYF000000020006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00=Goo000/Ool20002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000@Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP03FUH20003FUH30004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=goo
000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000F
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01@00
FUIJEP00FUH00`002Goo1`0015YF00<005YFFUH00UYF1@00>Goo000]Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4000LOol200000eYF001JEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
1EYF00<005YFFUH00UYF00H005YFFUH005YF000BOol9000nOol002eoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00@0029oo`<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH01@00FUIJEUYF0000
15YF00<007ooOol0F7oo000^Ool30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH7000YOol20004
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04
FUHA0005FUH00`00Oomoo`1HOol0035oo`d0039oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D000ioo`8000AJEP03001oogoo05Uoo`00Lgoo
10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=oo`0000000`0037oo
00@005YFFUH0009JEP03001oogoo05Yoo`00Mgoo1P000eYF00<005YFFUH02EYF00<005YFFUH02UYF
00@005YFFUIJEPH000Ioo`D000Yoo`8000=JEP04001JEUYF001LOol007eoob0000aoo`D000Uoo`03
001JEUYF00AJEP8005eoo`00Sgoo00<005YFFUH015YF00<007ooOol04Goo0`002Goo00<005YFFUH0
1EYF00<007ooOol0G7oo002?Ool20004FUH00`00Oomoo`0MOol00`00FUIJEP05FUH00`00Oomoo`1M
Ool008ioo`03001JEP0000=JEP03001oogoo01aoo`800003FUH005YF00AJEP03001oogoo05ioo`00
SWoo00@005YFFUH0009JEP03001oogoo01Yoo`8000=JEP04001JEUYFFUH2001QOol008eoo`07001J
EUYFFUH005YF00006goo0P001UYF00<005YF0000Hgoo002=Ool00`00FUIJEP02FUH00`00Oomoo`0I
Ool00`00FUIJEP07FUH00`00Oomoo`1ROol008eoo`80009JEP03001oogoo01Qoo`<000MJEP8006Eo
o`00SGoo0P000UYF00<007ooOol05Woo0P000eYF00<005YFFUH00eYF00<007ooOol0IGoo002>Ool3
000GOol20005FUH01000FUIJEUYF0P00J7oo002>Ool00`00FUH0000COol40008FUH3001ZOol008io
o`03001JEP0000moo`@0009JEP03001JEUYF00IJEP8006aoo`00Sgoo1@001Woo1P001eYF00<005YF
FUH00eYF0P00KWoo002?Ool30002FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP03001`Ool0091o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP<007=oo`00TGoo0P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00MWoo002BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP03001h
Ool009=oo`l007]oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60091 .74909 m .60071 .69353 L .56955 .6917 L p .707 .577 .707 r
F P
0 g
s
.60071 .69353 m .60091 .74909 L .63275 .74822 L p .707 .577 .707 r
F P
0 g
s
.63275 .74822 m .63255 .69266 L .60071 .69353 L p .707 .577 .707 r
F P
0 g
s
.63255 .69266 m .63275 .74822 L .66216 .74474 L p .707 .577 .707 r
F P
0 g
s
.66216 .74474 m .66196 .68918 L .63255 .69266 L p .707 .577 .707 r
F P
0 g
s
.56975 .74726 m .56955 .6917 L .54213 .68736 L p .707 .577 .707 r
F P
0 g
s
.56955 .6917 m .56975 .74726 L .60091 .74909 L p .707 .577 .707 r
F P
0 g
s
.66196 .68918 m .66216 .74474 L .68625 .73899 L p .707 .577 .707 r
F P
0 g
s
.68625 .73899 m .68605 .68343 L .66196 .68918 L p .707 .577 .707 r
F P
0 g
s
.5935 .80827 m .59494 .77108 L .56381 .76813 L p .707 .577 .707 r
F P
0 g
s
.59494 .77108 m .5935 .80827 L .62532 .80872 L p .707 .577 .707 r
F P
0 g
s
.62532 .80872 m .62676 .77153 L .59494 .77108 L p .707 .577 .707 r
F P
0 g
s
.62676 .77153 m .62532 .80872 L .65473 .80662 L p .707 .577 .707 r
F P
0 g
s
.65473 .80662 m .65617 .76944 L .62676 .77153 L p .707 .577 .707 r
F P
0 g
s
.54213 .68736 m .54232 .74292 L .56975 .74726 L p .707 .577 .707 r
F P
0 g
s
.54232 .74292 m .54213 .68736 L .52112 .68093 L p .707 .577 .707 r
F P
0 g
s
.56237 .80532 m .56381 .76813 L .53643 .76297 L p .707 .577 .707 r
F P
0 g
s
.56381 .76813 m .56237 .80532 L .5935 .80827 L p .707 .577 .707 r
F P
0 g
s
.65617 .76944 m .65473 .80662 L .67884 .80219 L p .707 .577 .707 r
F P
0 g
s
.67884 .80219 m .68028 .76501 L .65617 .76944 L p .707 .577 .707 r
F P
0 g
s
.68605 .68343 m .68625 .73899 L .70267 .73154 L p .707 .577 .707 r
F P
0 g
s
.70267 .73154 m .70247 .67598 L .68605 .68343 L p .707 .577 .707 r
F P
0 g
s
.53643 .76297 m .53499 .80016 L .56237 .80532 L p .707 .577 .707 r
F P
0 g
s
.62456 .85548 m .61953 .83828 L .58878 .84702 L p .707 .577 .707 r
F P
0 g
s
.61953 .83828 m .62456 .85548 L .65298 .84367 L p .707 .577 .707 r
F P
0 g
s
.65298 .84367 m .64795 .82647 L .61953 .83828 L p .707 .577 .707 r
F P
0 g
s
.52112 .68093 m .52131 .73649 L .54232 .74292 L p .707 .577 .707 r
F P
0 g
s
.59382 .86423 m .58878 .84702 L .55874 .85185 L p .707 .577 .707 r
F P
0 g
s
.58878 .84702 m .59382 .86423 L .62456 .85548 L p .707 .577 .707 r
F P
0 g
s
.53499 .80016 m .53643 .76297 L .51547 .75611 L p .707 .577 .707 r
F P
0 g
s
.55874 .85185 m .56377 .86905 L .59382 .86423 L p .707 .577 .707 r
F P
0 g
s
.52131 .73649 m .52112 .68093 L .50858 .67304 L p .707 .577 .707 r
F P
0 g
s
.64795 .82647 m .65298 .84367 L .67631 .82996 L p .707 .577 .707 r
F P
0 g
s
.67631 .82996 m .67128 .81275 L .64795 .82647 L p .707 .577 .707 r
F P
0 g
s
.56377 .86905 m .55874 .85185 L .53232 .85228 L p .707 .577 .707 r
F P
0 g
s
.51547 .75611 m .51403 .7933 L .53499 .80016 L p .707 .577 .707 r
F P
0 g
s
.68028 .76501 m .67884 .80219 L .69529 .79586 L p .707 .577 .707 r
F P
0 g
s
.69529 .79586 m .69673 .75867 L .68028 .76501 L p .707 .577 .707 r
F P
0 g
s
.53232 .85228 m .53735 .86949 L .56377 .86905 L p .707 .577 .707 r
F P
0 g
s
.70247 .67598 m .70267 .73154 L .70981 .72311 L p .707 .577 .707 r
F P
0 g
s
.70981 .72311 m .70961 .66755 L .70247 .67598 L p .707 .577 .707 r
F P
0 g
s
.50858 .67304 m .50877 .7286 L .52131 .73649 L p .707 .577 .707 r
F P
0 g
s
.67128 .81275 m .67631 .82996 L .69225 .81568 L p .707 .577 .707 r
F P
0 g
s
.69225 .81568 m .68722 .79848 L .67128 .81275 L p .707 .577 .707 r
F P
0 g
s
.51403 .7933 m .51547 .75611 L .50299 .74822 L p .707 .577 .707 r
F P
0 g
s
.53735 .86949 m .53232 .85228 L .51212 .84828 L p .707 .577 .707 r
F P
0 g
s
.51212 .84828 m .51715 .86549 L .53735 .86949 L p .707 .577 .707 r
F P
0 g
s
.50877 .7286 m .50858 .67304 L .50574 .66446 L p .707 .577 .707 r
F P
0 g
s
.50299 .74822 m .50155 .78541 L .51403 .7933 L p .707 .577 .707 r
F P
0 g
s
.69673 .75867 m .69529 .79586 L .70248 .78825 L p .707 .577 .707 r
F P
0 g
s
.70248 .78825 m .70392 .75106 L .69673 .75867 L p .707 .577 .707 r
F P
0 g
s
.68722 .79848 m .69225 .81568 L .69925 .80224 L p .707 .577 .707 r
F P
0 g
s
.69925 .80224 m .69422 .78503 L .68722 .79848 L p .707 .577 .707 r
F P
0 g
s
.50574 .66446 m .50594 .72002 L .50877 .7286 L p .707 .577 .707 r
F P
0 g
s
.51715 .86549 m .51212 .84828 L .50012 .84024 L p .707 .577 .707 r
F P
0 g
s
.70961 .66755 m .70981 .72311 L .70697 .71453 L p .707 .577 .707 r
F P
0 g
s
.70697 .71453 m .70678 .65897 L .70961 .66755 L p .707 .577 .707 r
F P
0 g
s
.50155 .78541 m .50299 .74822 L .50021 .74006 L p .707 .577 .707 r
F P
0 g
s
.50012 .84024 m .50515 .85745 L .51715 .86549 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.50021 .74006 m .49877 .77725 L .50155 .78541 L p .707 .577 .707 r
F P
0 g
s
.50594 .72002 m .50574 .66446 L .51288 .65604 L p .707 .577 .707 r
F P
0 g
s
.51288 .65604 m .51308 .7116 L .50594 .72002 L p .707 .577 .707 r
F P
0 g
s
.49877 .77725 m .50021 .74006 L .5074 .73245 L p .707 .577 .707 r
F P
0 g
s
.5074 .73245 m .50596 .76963 L .49877 .77725 L p .707 .577 .707 r
F P
0 g
s
.51308 .7116 m .51288 .65604 L .5293 .64858 L p .707 .577 .707 r
F P
0 g
s
.50252 .84616 m .49749 .82895 L .50449 .81551 L p .707 .577 .707 r
F P
0 g
s
.5293 .64858 m .5295 .70414 L .51308 .7116 L p .707 .577 .707 r
F P
0 g
s
.50596 .76963 m .5074 .73245 L .52385 .72611 L p .707 .577 .707 r
F P
0 g
s
.50449 .81551 m .50952 .83271 L .50252 .84616 L p .707 .577 .707 r
F P
0 g
s
.52385 .72611 m .52241 .7633 L .50596 .76963 L p .707 .577 .707 r
F P
0 g
s
.50952 .83271 m .50449 .81551 L .52044 .80123 L p .707 .577 .707 r
F P
0 g
s
.52241 .7633 m .52385 .72611 L .54796 .72168 L p .707 .577 .707 r
F P
0 g
s
.52044 .80123 m .52547 .81843 L .50952 .83271 L p .707 .577 .707 r
F P
0 g
s
.54796 .72168 m .54652 .75887 L .52241 .7633 L p .707 .577 .707 r
F P
0 g
s
.52547 .81843 m .52044 .80123 L .54376 .78752 L p .707 .577 .707 r
F P
0 g
s
.54376 .78752 m .54879 .80472 L .52547 .81843 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53822 .82054 L p .707 .577 .707 r
F P
0 g
s
.5295 .70414 m .5293 .64858 L .55339 .64284 L p .707 .577 .707 r
F P
0 g
s
.55339 .64284 m .55359 .6984 L .5295 .70414 L p .707 .577 .707 r
F P
0 g
s
.53822 .82054 m .53822 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.55359 .6984 m .55339 .64284 L .5828 .63936 L p .707 .577 .707 r
F P
0 g
s
.5828 .63936 m .583 .69492 L .55359 .6984 L p .707 .577 .707 r
F P
0 g
s
.54652 .75887 m .54796 .72168 L .57737 .71959 L p .707 .577 .707 r
F P
0 g
s
.57737 .71959 m .57593 .75678 L .54652 .75887 L p .707 .577 .707 r
F P
0 g
s
.54879 .80472 m .54376 .78752 L .57219 .77571 L p .707 .577 .707 r
F P
0 g
s
.57219 .77571 m .57722 .79291 L .54879 .80472 L p .707 .577 .707 r
F P
0 g
s
.60293 .76696 m .60796 .78417 L .57722 .79291 L p .707 .577 .707 r
F P
0 g
s
.57722 .79291 m .57219 .77571 L .60293 .76696 L p .707 .577 .707 r
F P
0 g
s
.53822 .31865 m .53822 .82054 L .57933 .81554 L p .707 .577 .707 r
F P
0 g
s
.57593 .75678 m .57737 .71959 L .60919 .72004 L p .707 .577 .707 r
F P
0 g
s
.60919 .72004 m .60775 .75723 L .57593 .75678 L p .707 .577 .707 r
F P
0 g
s
.57933 .81554 m .57933 .31366 L .53822 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40994 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.70392 .75106 m .70248 .78825 L .69969 .78009 L p .707 .577 .707 r
F P
0 g
s
.69969 .78009 m .70113 .7429 L .70392 .75106 L p .707 .577 .707 r
F P
0 g
s
.69422 .78503 m .69925 .80224 L .69662 .79094 L p .707 .577 .707 r
F P
0 g
s
.69662 .79094 m .69159 .77374 L .69422 .78503 L p .707 .577 .707 r
F P
0 g
s
.50515 .85745 m .50012 .84024 L .49749 .82895 L p .707 .577 .707 r
F P
0 g
s
.70678 .65897 m .70697 .71453 L .69443 .70664 L p .707 .577 .707 r
F P
0 g
s
.69443 .70664 m .69424 .65108 L .70678 .65897 L p .707 .577 .707 r
F P
0 g
s
.583 .69492 m .5828 .63936 L .61464 .63849 L p .707 .577 .707 r
F P
0 g
s
.61464 .63849 m .61484 .69405 L .583 .69492 L p .707 .577 .707 r
F P
0 g
s
.64032 .72299 m .63888 .76018 L .60775 .75723 L p .707 .577 .707 r
F P
0 g
s
.60775 .75723 m .60919 .72004 L .64032 .72299 L p .707 .577 .707 r
F P
0 g
s
.63298 .76214 m .63801 .77934 L .60796 .78417 L p .707 .577 .707 r
F P
0 g
s
.60796 .78417 m .60293 .76696 L .63298 .76214 L p .707 .577 .707 r
F P
0 g
s
.57933 .31366 m .57933 .81554 L .61267 .80738 L p .707 .577 .707 r
F P
0 g
s
.61267 .80738 m .61267 .3055 L .57933 .31366 L p .707 .577 .707 r
F P
0 g
s
.25506 .71369 m .25498 .65805 L .22382 .6562 L p .707 .577 .707 r
F P
0 g
s
.25498 .65805 m .25506 .71369 L .2869 .71289 L p .707 .577 .707 r
F P
0 g
s
.2869 .71289 m .28682 .65726 L .25498 .65805 L p .707 .577 .707 r
F P
0 g
s
.49749 .82895 m .50252 .84616 L .50515 .85745 L p .707 .577 .707 r
F P
0 g
s
.28682 .65726 m .2869 .71289 L .31631 .70953 L p .707 .577 .707 r
F P
0 g
s
.31631 .70953 m .31622 .65389 L .28682 .65726 L p .707 .577 .707 r
F P
0 g
s
.40994 .81345 m .40994 .31156 L .37953 .30262 L p .707 .577 .707 r
F P
0 g
s
.40994 .31156 m .40994 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.2239 .71184 m .22382 .6562 L .19639 .65189 L p .707 .577 .707 r
F P
0 g
s
.22382 .6562 m .2239 .71184 L .25506 .71369 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31622 .65389 m .31631 .70953 L .3404 .70392 L p .707 .577 .707 r
F P
0 g
s
.3404 .70392 m .34031 .64829 L .31622 .65389 L p .707 .577 .707 r
F P
0 g
s
.69159 .77374 m .69662 .79094 L .68462 .7829 L p .707 .577 .707 r
F P
0 g
s
.68462 .7829 m .67959 .7657 L .69159 .77374 L p .707 .577 .707 r
F P
0 g
s
.70113 .7429 m .69969 .78009 L .68721 .7722 L p .707 .577 .707 r
F P
0 g
s
.68721 .7722 m .68865 .73501 L .70113 .7429 L p .707 .577 .707 r
F P
0 g
s
.19639 .65189 m .19647 .70752 L .2239 .71184 L p .707 .577 .707 r
F P
0 g
s
.19647 .70752 m .19639 .65189 L .17538 .64553 L p .707 .577 .707 r
F P
0 g
s
.69424 .65108 m .69443 .70664 L .67342 .70021 L p .707 .577 .707 r
F P
0 g
s
.67342 .70021 m .67323 .64466 L .69424 .65108 L p .707 .577 .707 r
F P
0 g
s
.6458 .64032 m .646 .69588 L .61484 .69405 L p .707 .577 .707 r
F P
0 g
s
.61484 .69405 m .61464 .63849 L .6458 .64032 L p .707 .577 .707 r
F P
0 g
s
.63801 .77934 m .63298 .76214 L .65939 .7617 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80738 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.25181 .77597 m .25243 .73934 L .22128 .73667 L p .707 .577 .707 r
F P
0 g
s
.25243 .73934 m .25181 .77597 L .28365 .77561 L p .707 .577 .707 r
F P
0 g
s
.28365 .77561 m .28427 .73897 L .25243 .73934 L p .707 .577 .707 r
F P
0 g
s
.28427 .73897 m .28365 .77561 L .31307 .77225 L p .707 .577 .707 r
F P
0 g
s
.31307 .77225 m .31369 .73562 L .28427 .73897 L p .707 .577 .707 r
F P
0 g
s
.34031 .64829 m .3404 .70392 L .35682 .69663 L p .707 .577 .707 r
F P
0 g
s
.35682 .69663 m .35673 .641 L .34031 .64829 L p .707 .577 .707 r
F P
0 g
s
.22066 .77331 m .22128 .73667 L .19388 .73125 L p .707 .577 .707 r
F P
0 g
s
.22128 .73667 m .22066 .77331 L .25181 .77597 L p .707 .577 .707 r
F P
0 g
s
.37953 .8045 m .37953 .30262 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37953 .30262 m .37953 .8045 L .40994 .81345 L p .707 .577 .707 r
F P
0 g
s
.17538 .64553 m .17546 .70117 L .19647 .70752 L p .707 .577 .707 r
F P
0 g
s
.31369 .73562 m .31307 .77225 L .33719 .76624 L p .707 .577 .707 r
F P
0 g
s
.33719 .76624 m .33781 .7296 L .31369 .73562 L p .707 .577 .707 r
F P
0 g
s
.67959 .7657 m .68462 .7829 L .66442 .77891 L p .707 .577 .707 r
F P
0 g
s
.66442 .77891 m .65939 .7617 L .67959 .7657 L p .707 .577 .707 r
F P
0 g
s
.68865 .73501 m .68721 .7722 L .66626 .76534 L p .707 .577 .707 r
F P
0 g
s
.66626 .76534 m .6677 .72815 L .68865 .73501 L p .707 .577 .707 r
F P
0 g
s
.17546 .70117 m .17538 .64553 L .16284 .63776 L p .707 .577 .707 r
F P
0 g
s
.19388 .73125 m .19326 .76788 L .22066 .77331 L p .707 .577 .707 r
F P
0 g
s
.25294 .78809 m .25074 .76898 L .21973 .7725 L p .707 .577 .707 r
F P
0 g
s
.25074 .76898 m .25294 .78809 L .28455 .78443 L p .707 .577 .707 r
F P
0 g
s
.28455 .78443 m .28235 .76532 L .25074 .76898 L p .707 .577 .707 r
F P
0 g
s
.21973 .7725 m .22193 .79161 L .25294 .78809 L p .707 .577 .707 r
F P
0 g
s
.67323 .64466 m .67342 .70021 L .646 .69588 L p .707 .577 .707 r
F P
0 g
s
.646 .69588 m .6458 .64032 L .67323 .64466 L p .707 .577 .707 r
F P
0 g
s
.28235 .76532 m .28455 .78443 L .31366 .78098 L p .707 .577 .707 r
F P
0 g
s
.31366 .78098 m .31146 .76187 L .28235 .76532 L p .707 .577 .707 r
F P
0 g
s
.19326 .76788 m .19388 .73125 L .17291 .72358 L p .707 .577 .707 r
F P
0 g
s
.22193 .79161 m .21973 .7725 L .19235 .77553 L p .707 .577 .707 r
F P
0 g
s
.19235 .77553 m .19455 .79463 L .22193 .79161 L p .707 .577 .707 r
F P
0 g
s
.16284 .63776 m .16292 .69339 L .17546 .70117 L p .707 .577 .707 r
F P
0 g
s
.35673 .641 m .35682 .69663 L .36396 .68836 L p .707 .577 .707 r
F P
0 g
s
.36396 .68836 m .36388 .63273 L .35673 .641 L p .707 .577 .707 r
F P
0 g
s
.31146 .76187 m .31366 .78098 L .33743 .77808 L p .707 .577 .707 r
F P
0 g
s
.33743 .77808 m .33523 .75897 L .31146 .76187 L p .707 .577 .707 r
F P
0 g
s
.17291 .72358 m .17229 .76022 L .19326 .76788 L p .707 .577 .707 r
F P
0 g
s
.33781 .7296 m .33719 .76624 L .35365 .75815 L p .707 .577 .707 r
F P
0 g
s
.35365 .75815 m .35426 .72151 L .33781 .7296 L p .707 .577 .707 r
F P
0 g
s
.65939 .7617 m .66442 .77891 L .63801 .77934 L p .707 .577 .707 r
F P
0 g
s
.6677 .72815 m .66626 .76534 L .63888 .76018 L p .707 .577 .707 r
F P
0 g
s
.63888 .76018 m .64032 .72299 L .6677 .72815 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.19455 .79463 m .19235 .77553 L .17129 .77776 L p .707 .577 .707 r
F P
0 g
s
.17129 .77776 m .17349 .79687 L .19455 .79463 L p .707 .577 .707 r
F P
0 g
s
.17229 .76022 m .17291 .72358 L .16041 .71444 L p .707 .577 .707 r
F P
0 g
s
.16292 .69339 m .16284 .63776 L .16 .62932 L p .707 .577 .707 r
F P
0 g
s
.35426 .72151 m .35365 .75815 L .36083 .74878 L p .707 .577 .707 r
F P
0 g
s
.36083 .74878 m .36145 .71214 L .35426 .72151 L p .707 .577 .707 r
F P
0 g
s
.36145 .71214 m .36083 .74878 L .35804 .73905 L p .707 .577 .707 r
F P
0 g
s
.35804 .73905 m .35865 .70241 L .36145 .71214 L p .707 .577 .707 r
F P
0 g
s
.36104 .62429 m .36112 .67993 L .34858 .67215 L p .707 .577 .707 r
F P
0 g
s
.34858 .67215 m .3485 .61652 L .36104 .62429 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36388 .63273 m .36396 .68836 L .36112 .67993 L p .707 .577 .707 r
F P
0 g
s
.36112 .67993 m .36104 .62429 L .36388 .63273 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37953 .8045 L p .707 .577 .707 r
F P
0 g
s
.33523 .75897 m .33743 .77808 L .35352 .77601 L p .707 .577 .707 r
F P
0 g
s
.35352 .77601 m .35132 .75691 L .33523 .75897 L p .707 .577 .707 r
F P
0 g
s
.16041 .71444 m .1598 .75107 L .17229 .76022 L p .707 .577 .707 r
F P
0 g
s
.16 .62932 m .16009 .68496 L .16292 .69339 L p .707 .577 .707 r
F P
0 g
s
.17349 .79687 m .17129 .77776 L .1586 .779 L p .707 .577 .707 r
F P
0 g
s
.1586 .779 m .1608 .7981 L .17349 .79687 L p .707 .577 .707 r
F P
0 g
s
.1598 .75107 m .16041 .71444 L .15762 .7047 L p .707 .577 .707 r
F P
0 g
s
.16009 .68496 m .16 .62932 L .16714 .62105 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77296 L p .707 .577 .707 r
F P
0 g
s
.63909 .77296 m .63909 .27107 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.35132 .75691 m .35352 .77601 L .36037 .77498 L p .707 .577 .707 r
F P
0 g
s
.36037 .77498 m .35817 .75588 L .35132 .75691 L p .707 .577 .707 r
F P
0 g
s
.15762 .7047 m .157 .74134 L .1598 .75107 L p .707 .577 .707 r
F P
0 g
s
.35817 .75588 m .36037 .77498 L .3573 .77509 L p .707 .577 .707 r
F P
0 g
s
.3573 .77509 m .3551 .75598 L .35817 .75588 L p .707 .577 .707 r
F P
0 g
s
.35865 .70241 m .35804 .73905 L .34554 .7299 L p .707 .577 .707 r
F P
0 g
s
.34554 .7299 m .34616 .69326 L .35865 .70241 L p .707 .577 .707 r
F P
0 g
s
.3551 .75598 m .3573 .77509 L .34461 .77632 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.16714 .62105 m .16723 .67669 L .16009 .68496 L p .707 .577 .707 r
F P
0 g
s
.1608 .7981 m .1586 .779 L .15553 .7791 L p .707 .577 .707 r
F P
0 g
s
.15553 .7791 m .15773 .79821 L .1608 .7981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.157 .74134 m .15762 .7047 L .1648 .69533 L p .707 .577 .707 r
F P
0 g
s
.16723 .67669 m .16714 .62105 L .18356 .61376 L p .707 .577 .707 r
F P
0 g
s
.1648 .69533 m .16419 .73197 L .157 .74134 L p .707 .577 .707 r
F P
0 g
s
.63909 .27107 m .63909 .77296 L .62047 .76193 L p .707 .577 .707 r
F P
0 g
s
.62047 .76193 m .62047 .26004 L .63909 .27107 L p .707 .577 .707 r
F P
0 g
s
.18356 .61376 m .18365 .6694 L .16723 .67669 L p .707 .577 .707 r
F P
0 g
s
.3485 .61652 m .34858 .67215 L .32757 .66579 L p .707 .577 .707 r
F P
0 g
s
.32757 .66579 m .32749 .61016 L .3485 .61652 L p .707 .577 .707 r
F P
0 g
s
.15773 .79821 m .15553 .7791 L .16238 .77807 L p .707 .577 .707 r
F P
0 g
s
.16238 .77807 m .16458 .79718 L .15773 .79821 L p .707 .577 .707 r
F P
0 g
s
.18365 .6694 m .18356 .61376 L .20766 .60816 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38732 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.16419 .73197 m .1648 .69533 L .18126 .68724 L p .707 .577 .707 r
F P
0 g
s
.18126 .68724 m .18064 .72388 L .16419 .73197 L p .707 .577 .707 r
F P
0 g
s
.32749 .61016 m .32757 .66579 L .30015 .66148 L p .707 .577 .707 r
F P
0 g
s
.30015 .66148 m .30006 .60585 L .32749 .61016 L p .707 .577 .707 r
F P
0 g
s
.34461 .77632 m .34241 .75722 L .3551 .75598 L p .707 .577 .707 r
F P
0 g
s
.20766 .60816 m .20774 .66379 L .18365 .6694 L p .707 .577 .707 r
F P
0 g
s
.34616 .69326 m .34554 .7299 L .32457 .72224 L p .707 .577 .707 r
F P
0 g
s
.32457 .72224 m .32519 .6856 L .34616 .69326 L p .707 .577 .707 r
F P
0 g
s
.20774 .66379 m .20766 .60816 L .23706 .60479 L p .707 .577 .707 r
F P
0 g
s
.16458 .79718 m .16238 .77807 L .17847 .77601 L p .707 .577 .707 r
F P
0 g
s
.17847 .77601 m .18067 .79511 L .16458 .79718 L p .707 .577 .707 r
F P
0 g
s
.18064 .72388 m .18126 .68724 L .20538 .68123 L p .707 .577 .707 r
F P
0 g
s
.62047 .26004 m .62047 .76193 L .59006 .75298 L p .707 .577 .707 r
F P
0 g
s
.59006 .75298 m .59006 .2511 L .62047 .26004 L p .707 .577 .707 r
F P
0 g
s
.30006 .60585 m .30015 .66148 L .26899 .65963 L p .707 .577 .707 r
F P
0 g
s
.26899 .65963 m .2689 .604 L .30006 .60585 L p .707 .577 .707 r
F P
0 g
s
.23715 .66043 m .23706 .60479 L .2689 .604 L p .707 .577 .707 r
F P
0 g
s
.23706 .60479 m .23715 .66043 L .20774 .66379 L p .707 .577 .707 r
F P
0 g
s
.2689 .604 m .26899 .65963 L .23715 .66043 L p .707 .577 .707 r
F P
0 g
s
.38732 .25716 m .38732 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38732 .75905 m .38732 .25716 L .42067 .249 L p .707 .577 .707 r
F P
0 g
s
.20538 .68123 m .20476 .71787 L .18064 .72388 L p .707 .577 .707 r
F P
0 g
s
.32519 .6856 m .32457 .72224 L .29717 .71681 L p .707 .577 .707 r
F P
0 g
s
.29717 .71681 m .29779 .68017 L .32519 .6856 L p .707 .577 .707 r
F P
0 g
s
.34241 .75722 m .34461 .77632 L .32355 .77856 L p .707 .577 .707 r
F P
0 g
s
.32355 .77856 m .32135 .75945 L .34241 .75722 L p .707 .577 .707 r
F P
0 g
s
.73101 .65644 m .7311 .60091 L .69994 .59893 L p .707 .577 .707 r
F P
0 g
s
.7311 .60091 m .73101 .65644 L .76285 .65572 L p .707 .577 .707 r
F P
0 g
s
.76285 .65572 m .76294 .60019 L .7311 .60091 L p .707 .577 .707 r
F P
0 g
s
.20476 .71787 m .20538 .68123 L .2348 .67788 L p .707 .577 .707 r
F P
0 g
s
.76294 .60019 m .76285 .65572 L .79226 .65235 L p .707 .577 .707 r
F P
0 g
s
.79226 .65235 m .79234 .59682 L .76294 .60019 L p .707 .577 .707 r
F P
0 g
s
.18067 .79511 m .17847 .77601 L .20224 .77311 L p .707 .577 .707 r
F P
0 g
s
.20224 .77311 m .20444 .79221 L .18067 .79511 L p .707 .577 .707 r
F P
0 g
s
.69985 .65446 m .69994 .59893 L .67251 .59443 L p .707 .577 .707 r
F P
0 g
s
.69994 .59893 m .69985 .65446 L .73101 .65644 L p .707 .577 .707 r
F P
0 g
s
.29779 .68017 m .29717 .71681 L .26602 .71415 L p .707 .577 .707 r
F P
0 g
s
.26602 .71415 m .26664 .67751 L .29779 .68017 L p .707 .577 .707 r
F P
0 g
s
.2348 .67788 m .23418 .71451 L .20476 .71787 L p .707 .577 .707 r
F P
0 g
s
.23418 .71451 m .2348 .67788 L .26664 .67751 L p .707 .577 .707 r
F P
0 g
s
.59006 .2511 m .59006 .75298 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59006 .2511 L p .707 .577 .707 r
F P
0 g
s
.79234 .59682 m .79226 .65235 L .81635 .64668 L p .707 .577 .707 r
F P
0 g
s
.81635 .64668 m .81643 .59115 L .79234 .59682 L p .707 .577 .707 r
F P
0 g
s
.26664 .67751 m .26602 .71415 L .23418 .71451 L p .707 .577 .707 r
F P
0 g
s
.73397 .71481 m .73336 .6774 L .70221 .67622 L p .707 .577 .707 r
F P
0 g
s
.73336 .6774 m .73397 .71481 L .76581 .71367 L p .707 .577 .707 r
F P
0 g
s
.76581 .71367 m .7652 .67626 L .73336 .6774 L p .707 .577 .707 r
F P
0 g
s
.7652 .67626 m .76581 .71367 L .79523 .71031 L p .707 .577 .707 r
F P
0 g
s
.79523 .71031 m .79462 .6729 L .7652 .67626 L p .707 .577 .707 r
F P
0 g
s
.32135 .75945 m .32355 .77856 L .29617 .78159 L p .707 .577 .707 r
F P
0 g
s
.29617 .78159 m .29397 .76248 L .32135 .75945 L p .707 .577 .707 r
F P
0 g
s
.42067 .75089 m .42067 .249 L .46178 .24401 L p .707 .577 .707 r
F P
0 g
s
.42067 .249 m .42067 .75089 L .38732 .75905 L p .707 .577 .707 r
F P
0 g
s
.67251 .59443 m .67242 .64996 L .69985 .65446 L p .707 .577 .707 r
F P
0 g
s
.67242 .64996 m .67251 .59443 L .6515 .58786 L p .707 .577 .707 r
F P
0 g
s
.70283 .71363 m .70221 .67622 L .67481 .67283 L p .707 .577 .707 r
F P
0 g
s
.70221 .67622 m .70283 .71363 L .73397 .71481 L p .707 .577 .707 r
F P
0 g
s
.20444 .79221 m .20224 .77311 L .23135 .76966 L p .707 .577 .707 r
F P
0 g
s
.23135 .76966 m .23355 .78876 L .20444 .79221 L p .707 .577 .707 r
F P
0 g
s
.79462 .6729 m .79523 .71031 L .81935 .70507 L p .707 .577 .707 r
F P
0 g
s
.81935 .70507 m .81874 .66766 L .79462 .6729 L p .707 .577 .707 r
F P
0 g
s
.67481 .67283 m .67543 .71024 L .70283 .71363 L p .707 .577 .707 r
F P
0 g
s
.81643 .59115 m .81635 .64668 L .83277 .63925 L p .707 .577 .707 r
F P
0 g
s
.83277 .63925 m .83285 .58373 L .81643 .59115 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50663 .74455 L p .707 .577 .707 r
F P
0 g
s
.50663 .74455 m .50663 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.29397 .76248 m .29617 .78159 L .26516 .7851 L p .707 .577 .707 r
F P
0 g
s
.26516 .7851 m .26296 .766 L .29397 .76248 L p .707 .577 .707 r
F P
0 g
s
.73484 .78391 m .73704 .76748 L .70603 .76089 L p .707 .577 .707 r
F P
0 g
s
.73704 .76748 m .73484 .78391 L .76645 .78546 L p .707 .577 .707 r
F P
0 g
s
.76645 .78546 m .76864 .76903 L .73704 .76748 L p .707 .577 .707 r
F P
0 g
s
.6515 .58786 m .65141 .64339 L .67242 .64996 L p .707 .577 .707 r
F P
0 g
s
.67543 .71024 m .67481 .67283 L .65384 .66756 L p .707 .577 .707 r
F P
0 g
s
.46178 .7459 m .46178 .24401 L .50663 .24266 L p .707 .577 .707 r
F P
0 g
s
.46178 .24401 m .46178 .7459 L .42067 .75089 L p .707 .577 .707 r
F P
0 g
s
.23355 .78876 m .23135 .76966 L .26296 .766 L p .707 .577 .707 r
F P
0 g
s
.26296 .766 m .26516 .7851 L .23355 .78876 L p .707 .577 .707 r
F P
0 g
s
.70383 .77732 m .70603 .76089 L .67865 .74991 L p .707 .577 .707 r
F P
0 g
s
.70603 .76089 m .70383 .77732 L .73484 .78391 L p .707 .577 .707 r
F P
0 g
s
.76864 .76903 m .76645 .78546 L .79556 .78182 L p .707 .577 .707 r
F P
0 g
s
.79556 .78182 m .79776 .76539 L .76864 .76903 L p .707 .577 .707 r
F P
0 g
s
.50663 .24266 m .50663 .74455 L .46178 .7459 L p .707 .577 .707 r
F P
0 g
s
.65141 .64339 m .6515 .58786 L .63896 .57986 L p .707 .577 .707 r
F P
0 g
s
.65384 .66756 m .65445 .70497 L .67543 .71024 L p .707 .577 .707 r
F P
0 g
s
.81874 .66766 m .81935 .70507 L .83581 .69846 L p .707 .577 .707 r
F P
0 g
s
.83581 .69846 m .83519 .66104 L .81874 .66766 L p .707 .577 .707 r
F P
0 g
s
.67865 .74991 m .67645 .76634 L .70383 .77732 L p .707 .577 .707 r
F P
0 g
s
.67645 .76634 m .67865 .74991 L .65759 .73562 L p .707 .577 .707 r
F P
0 g
s
.79776 .76539 m .79556 .78182 L .81933 .77336 L p .707 .577 .707 r
F P
0 g
s
.81933 .77336 m .82152 .75693 L .79776 .76539 L p .707 .577 .707 r
F P
0 g
s
.83285 .58373 m .83277 .63925 L .83991 .6308 L p .707 .577 .707 r
F P
0 g
s
.83991 .6308 m .84 .57527 L .83285 .58373 L p .707 .577 .707 r
F P
0 g
s
.63896 .57986 m .63888 .63539 L .65141 .64339 L p .707 .577 .707 r
F P
0 g
s
.65445 .70497 m .65384 .66756 L .64134 .66093 L p .707 .577 .707 r
F P
0 g
s
.65759 .73562 m .65539 .75205 L .67645 .76634 L p .707 .577 .707 r
F P
0 g
s
.64134 .66093 m .64196 .69834 L .65445 .70497 L p .707 .577 .707 r
F P
0 g
s
.65539 .75205 m .65759 .73562 L .6449 .71941 L p .707 .577 .707 r
F P
0 g
s
.63888 .63539 m .63896 .57986 L .63612 .5712 L p .707 .577 .707 r
F P
0 g
s
.82152 .75693 m .81933 .77336 L .83542 .76089 L p .707 .577 .707 r
F P
0 g
s
.83542 .76089 m .83762 .74446 L .82152 .75693 L p .707 .577 .707 r
F P
0 g
s
.83519 .66104 m .83581 .69846 L .84299 .69112 L p .707 .577 .707 r
F P
0 g
s
.84299 .69112 m .84238 .65371 L .83519 .66104 L p .707 .577 .707 r
F P
0 g
s
.6449 .71941 m .6427 .73584 L .65539 .75205 L p .707 .577 .707 r
F P
0 g
s
.63612 .5712 m .63604 .62673 L .63888 .63539 L p .707 .577 .707 r
F P
0 g
s
.64196 .69834 m .64134 .66093 L .63855 .65359 L p .707 .577 .707 r
F P
0 g
s
.84 .57527 m .83991 .6308 L .83707 .62215 L p .707 .577 .707 r
F P
0 g
s
.83707 .62215 m .83716 .56662 L .84 .57527 L p .707 .577 .707 r
F P
0 g
s
.6427 .73584 m .6449 .71941 L .64183 .70287 L p .707 .577 .707 r
F P
0 g
s
.83762 .74446 m .83542 .76089 L .84227 .74563 L p .707 .577 .707 r
F P
0 g
s
.84227 .74563 m .84447 .7292 L .83762 .74446 L p .707 .577 .707 r
F P
0 g
s
.63855 .65359 m .63917 .691 L .64196 .69834 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63604 .62673 m .63612 .5712 L .64326 .56275 L p .707 .577 .707 r
F P
0 g
s
.84238 .65371 m .84299 .69112 L .8402 .68378 L p .707 .577 .707 r
F P
0 g
s
.8402 .68378 m .83959 .64636 L .84238 .65371 L p .707 .577 .707 r
F P
0 g
s
.64183 .70287 m .63963 .7193 L .6427 .73584 L p .707 .577 .707 r
F P
0 g
s
.64326 .56275 m .64318 .61828 L .63604 .62673 L p .707 .577 .707 r
F P
0 g
s
.63917 .691 m .63855 .65359 L .64574 .64625 L p .707 .577 .707 r
F P
0 g
s
.83716 .56662 m .83707 .62215 L .82454 .61415 L p .707 .577 .707 r
F P
0 g
s
.82454 .61415 m .82462 .55862 L .83716 .56662 L p .707 .577 .707 r
F P
0 g
s
.63963 .7193 m .64183 .70287 L .64867 .68762 L p .707 .577 .707 r
F P
0 g
s
.38516 .62104 m .38536 .56544 L .3542 .56343 L p .707 .577 .707 r
F P
0 g
s
.38536 .56544 m .38516 .62104 L .417 .62039 L p .707 .577 .707 r
F P
0 g
s
.417 .62039 m .4172 .56479 L .38536 .56544 L p .707 .577 .707 r
F P
0 g
s
.84447 .7292 m .84227 .74563 L .8392 .72909 L p .707 .577 .707 r
F P
0 g
s
.8392 .72909 m .8414 .71266 L .84447 .7292 L p .707 .577 .707 r
F P
0 g
s
.4172 .56479 m .417 .62039 L .44641 .61714 L p .707 .577 .707 r
F P
0 g
s
.44641 .61714 m .4466 .56154 L .4172 .56479 L p .707 .577 .707 r
F P
0 g
s
.64574 .64625 m .64635 .68367 L .63917 .691 L p .707 .577 .707 r
F P
0 g
s
.354 .61904 m .3542 .56343 L .32677 .55896 L p .707 .577 .707 r
F P
0 g
s
.3542 .56343 m .354 .61904 L .38516 .62104 L p .707 .577 .707 r
F P
0 g
s
.64867 .68762 m .64648 .70405 L .63963 .7193 L p .707 .577 .707 r
F P
0 g
s
.64318 .61828 m .64326 .56275 L .65968 .55532 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83959 .64636 m .8402 .68378 L .82771 .67715 L p .707 .577 .707 r
F P
0 g
s
.82771 .67715 m .82709 .63974 L .83959 .64636 L p .707 .577 .707 r
F P
0 g
s
.4466 .56154 m .44641 .61714 L .4705 .61161 L p .707 .577 .707 r
F P
0 g
s
.4705 .61161 m .47069 .55601 L .4466 .56154 L p .707 .577 .707 r
F P
0 g
s
.32677 .55896 m .32657 .61456 L .354 .61904 L p .707 .577 .707 r
F P
0 g
s
.32657 .61456 m .32677 .55896 L .30576 .55246 L p .707 .577 .707 r
F P
0 g
s
.39225 .68254 m .39081 .64568 L .35968 .64476 L p .707 .577 .707 r
F P
0 g
s
.39081 .64568 m .39225 .68254 L .42407 .68061 L p .707 .577 .707 r
F P
0 g
s
.42407 .68061 m .42263 .64375 L .39081 .64568 L p .707 .577 .707 r
F P
0 g
s
.82462 .55862 m .82454 .61415 L .80353 .60757 L p .707 .577 .707 r
F P
0 g
s
.80353 .60757 m .80361 .55204 L .82462 .55862 L p .707 .577 .707 r
F P
0 g
s
.65968 .55532 m .6596 .61085 L .64318 .61828 L p .707 .577 .707 r
F P
0 g
s
.64648 .70405 m .64867 .68762 L .66477 .67515 L p .707 .577 .707 r
F P
0 g
s
.64635 .68367 m .64574 .64625 L .66219 .63964 L p .707 .577 .707 r
F P
0 g
s
.42263 .64375 m .42407 .68061 L .45348 .67601 L p .707 .577 .707 r
F P
0 g
s
.45348 .67601 m .45203 .63915 L .42263 .64375 L p .707 .577 .707 r
F P
0 g
s
.8414 .71266 m .8392 .72909 L .82651 .71288 L p .707 .577 .707 r
F P
0 g
s
.82651 .71288 m .82871 .69645 L .8414 .71266 L p .707 .577 .707 r
F P
0 g
s
.36112 .68162 m .35968 .64476 L .3323 .64107 L p .707 .577 .707 r
F P
0 g
s
.35968 .64476 m .36112 .68162 L .39225 .68254 L p .707 .577 .707 r
F P
0 g
s
.47069 .55601 m .4705 .61161 L .48692 .60434 L p .707 .577 .707 r
F P
0 g
s
.48692 .60434 m .48711 .54874 L .47069 .55601 L p .707 .577 .707 r
F P
0 g
s
.6596 .61085 m .65968 .55532 L .68378 .54965 L p .707 .577 .707 r
F P
0 g
s
.66219 .63964 m .66281 .67705 L .64635 .68367 L p .707 .577 .707 r
F P
0 g
s
.66477 .67515 m .66257 .69158 L .64648 .70405 L p .707 .577 .707 r
F P
0 g
s
.30576 .55246 m .30556 .60806 L .32657 .61456 L p .707 .577 .707 r
F P
0 g
s
.45203 .63915 m .45348 .67601 L .47759 .66919 L p .707 .577 .707 r
F P
0 g
s
.47759 .66919 m .47614 .63233 L .45203 .63915 L p .707 .577 .707 r
F P
0 g
s
.39204 .70906 m .39707 .69073 L .36702 .68154 L p .707 .577 .707 r
F P
0 g
s
.39707 .69073 m .39204 .70906 L .42278 .71686 L p .707 .577 .707 r
F P
0 g
s
.42278 .71686 m .42781 .69853 L .39707 .69073 L p .707 .577 .707 r
F P
0 g
s
.82709 .63974 m .82771 .67715 L .80674 .67188 L p .707 .577 .707 r
F P
0 g
s
.80674 .67188 m .80612 .63447 L .82709 .63974 L p .707 .577 .707 r
F P
0 g
s
.3323 .64107 m .33374 .67793 L .36112 .68162 L p .707 .577 .707 r
F P
0 g
s
.36702 .68154 m .36199 .69987 L .39204 .70906 L p .707 .577 .707 r
F P
0 g
s
.42781 .69853 m .42278 .71686 L .45121 .7225 L p .707 .577 .707 r
F P
0 g
s
.45121 .7225 m .45624 .70417 L .42781 .69853 L p .707 .577 .707 r
F P
0 g
s
.30556 .60806 m .30576 .55246 L .29322 .54457 L p .707 .577 .707 r
F P
0 g
s
.36199 .69987 m .36702 .68154 L .3406 .67187 L p .707 .577 .707 r
F P
0 g
s
.80361 .55204 m .80353 .60757 L .7761 .60307 L p .707 .577 .707 r
F P
0 g
s
.7761 .60307 m .77618 .54754 L .80361 .55204 L p .707 .577 .707 r
F P
0 g
s
.33374 .67793 m .3323 .64107 L .31134 .63498 L p .707 .577 .707 r
F P
0 g
s
.3406 .67187 m .33557 .6902 L .36199 .69987 L p .707 .577 .707 r
F P
0 g
s
.68378 .54965 m .68369 .60518 L .6596 .61085 L p .707 .577 .707 r
F P
0 g
s
.66257 .69158 m .66477 .67515 L .68854 .66668 L p .707 .577 .707 r
F P
0 g
s
.82871 .69645 m .82651 .71288 L .80545 .69859 L p .707 .577 .707 r
F P
0 g
s
.80545 .69859 m .80765 .68216 L .82871 .69645 L p .707 .577 .707 r
F P
0 g
s
.66281 .67705 m .66219 .63964 L .68631 .6344 L p .707 .577 .707 r
F P
0 g
s
.68369 .60518 m .68378 .54965 L .71318 .54629 L p .707 .577 .707 r
F P
0 g
s
.45624 .70417 m .45121 .7225 L .47453 .72544 L p .707 .577 .707 r
F P
0 g
s
.47453 .72544 m .47956 .70711 L .45624 .70417 L p .707 .577 .707 r
F P
0 g
s
.47614 .63233 m .47759 .66919 L .49404 .66083 L p .707 .577 .707 r
F P
0 g
s
.49404 .66083 m .4926 .62397 L .47614 .63233 L p .707 .577 .707 r
F P
0 g
s
.31134 .63498 m .31278 .67184 L .33374 .67793 L p .707 .577 .707 r
F P
0 g
s
.68854 .66668 m .68634 .68311 L .66257 .69158 L p .707 .577 .707 r
F P
0 g
s
.29322 .54457 m .29303 .60017 L .30556 .60806 L p .707 .577 .707 r
F P
0 g
s
.48711 .54874 m .48692 .60434 L .49406 .59605 L p .707 .577 .707 r
F P
0 g
s
.49406 .59605 m .49426 .54045 L .48711 .54874 L p .707 .577 .707 r
F P
0 g
s
.33557 .6902 m .3406 .67187 L .32041 .66265 L p .707 .577 .707 r
F P
0 g
s
.68631 .6344 m .68693 .67181 L .66281 .67705 L p .707 .577 .707 r
F P
0 g
s
.77618 .54754 m .7761 .60307 L .74494 .60109 L p .707 .577 .707 r
F P
0 g
s
.74494 .60109 m .74502 .54556 L .77618 .54754 L p .707 .577 .707 r
F P
0 g
s
.32041 .66265 m .31538 .68098 L .33557 .6902 L p .707 .577 .707 r
F P
0 g
s
.80612 .63447 m .80674 .67188 L .77933 .66849 L p .707 .577 .707 r
F P
0 g
s
.77933 .66849 m .77872 .63108 L .80612 .63447 L p .707 .577 .707 r
F P
0 g
s
.7131 .60182 m .71318 .54629 L .74502 .54556 L p .707 .577 .707 r
F P
0 g
s
.71318 .54629 m .7131 .60182 L .68369 .60518 L p .707 .577 .707 r
F P
0 g
s
.74502 .54556 m .74494 .60109 L .7131 .60182 L p .707 .577 .707 r
F P
0 g
s
.68634 .68311 m .68854 .66668 L .71765 .66304 L p .707 .577 .707 r
F P
0 g
s
.31278 .67184 m .31134 .63498 L .29886 .62708 L p .707 .577 .707 r
F P
0 g
s
.80765 .68216 m .80545 .69859 L .77807 .68761 L p .707 .577 .707 r
F P
0 g
s
.77807 .68761 m .78027 .67118 L .80765 .68216 L p .707 .577 .707 r
F P
0 g
s
.68693 .67181 m .68631 .6344 L .71573 .63104 L p .707 .577 .707 r
F P
0 g
s
.29303 .60017 m .29322 .54457 L .29038 .53606 L p .707 .577 .707 r
F P
0 g
s
.47956 .70711 m .47453 .72544 L .49047 .72539 L p .707 .577 .707 r
F P
0 g
s
.49047 .72539 m .4955 .70706 L .47956 .70711 L p .707 .577 .707 r
F P
0 g
s
.71765 .66304 m .71545 .67947 L .68634 .68311 L p .707 .577 .707 r
F P
0 g
s
.74706 .68103 m .74926 .66459 L .78027 .67118 L p .707 .577 .707 r
F P
0 g
s
.74926 .66459 m .74706 .68103 L .71545 .67947 L p .707 .577 .707 r
F P
0 g
s
.77872 .63108 m .77933 .66849 L .74819 .66731 L p .707 .577 .707 r
F P
0 g
s
.71545 .67947 m .71765 .66304 L .74926 .66459 L p .707 .577 .707 r
F P
0 g
s
.74819 .66731 m .74757 .6299 L .77872 .63108 L p .707 .577 .707 r
F P
0 g
s
.29886 .62708 m .3003 .66394 L .31278 .67184 L p .707 .577 .707 r
F P
0 g
s
.71573 .63104 m .71635 .66845 L .68693 .67181 L p .707 .577 .707 r
F P
0 g
s
.78027 .67118 m .77807 .68761 L .74706 .68103 L p .707 .577 .707 r
F P
0 g
s
.4926 .62397 m .49404 .66083 L .50123 .65173 L p .707 .577 .707 r
F P
0 g
s
.50123 .65173 m .49979 .61487 L .4926 .62397 L p .707 .577 .707 r
F P
0 g
s
.31538 .68098 m .32041 .66265 L .30841 .65479 L p .707 .577 .707 r
F P
0 g
s
.71635 .66845 m .71573 .63104 L .74757 .6299 L p .707 .577 .707 r
F P
0 g
s
.30841 .65479 m .30338 .67312 L .31538 .68098 L p .707 .577 .707 r
F P
0 g
s
.74757 .6299 m .74819 .66731 L .71635 .66845 L p .707 .577 .707 r
F P
0 g
s
.29038 .53606 m .29019 .59167 L .29303 .60017 L p .707 .577 .707 r
F P
0 g
s
.49426 .54045 m .49406 .59605 L .49122 .58754 L p .707 .577 .707 r
F P
0 g
s
.49122 .58754 m .49142 .53194 L .49426 .54045 L p .707 .577 .707 r
F P
0 g
s
.3003 .66394 m .29886 .62708 L .29608 .61815 L p .707 .577 .707 r
F P
0 g
s
.29019 .59167 m .29038 .53606 L .29752 .52777 L p .707 .577 .707 r
F P
0 g
s
.4955 .70706 m .49047 .72539 L .49747 .72234 L p .707 .577 .707 r
F P
0 g
s
.49747 .72234 m .5025 .70401 L .4955 .70706 L p .707 .577 .707 r
F P
0 g
s
.29608 .61815 m .29752 .65501 L .3003 .66394 L p .707 .577 .707 r
F P
0 g
s
.30338 .67312 m .30841 .65479 L .30578 .64905 L p .707 .577 .707 r
F P
0 g
s
.49979 .61487 m .50123 .65173 L .49844 .6428 L p .707 .577 .707 r
F P
0 g
s
.49844 .6428 m .497 .60594 L .49979 .61487 L p .707 .577 .707 r
F P
0 g
s
.30578 .64905 m .30075 .66738 L .30338 .67312 L p .707 .577 .707 r
F P
0 g
s
.29752 .52777 m .29733 .58337 L .29019 .59167 L p .707 .577 .707 r
F P
0 g
s
.49142 .53194 m .49122 .58754 L .47868 .57965 L p .707 .577 .707 r
F P
0 g
s
.47868 .57965 m .47888 .52405 L .49142 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29752 .65501 m .29608 .61815 L .30327 .60906 L p .707 .577 .707 r
F P
0 g
s
.29733 .58337 m .29752 .52777 L .31395 .5205 L p .707 .577 .707 r
F P
0 g
s
.5025 .70401 m .49747 .72234 L .49484 .71661 L p .707 .577 .707 r
F P
0 g
s
.49484 .71661 m .49987 .69828 L .5025 .70401 L p .707 .577 .707 r
F P
0 g
s
.30327 .60906 m .30471 .64592 L .29752 .65501 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30075 .66738 m .30578 .64905 L .31278 .64601 L p .707 .577 .707 r
F P
0 g
s
.497 .60594 m .49844 .6428 L .48596 .6349 L p .707 .577 .707 r
F P
0 g
s
.48596 .6349 m .48452 .59804 L .497 .60594 L p .707 .577 .707 r
F P
0 g
s
.31278 .64601 m .30775 .66434 L .30075 .66738 L p .707 .577 .707 r
F P
0 g
s
.31395 .5205 m .31375 .5761 L .29733 .58337 L p .707 .577 .707 r
F P
0 g
s
.47888 .52405 m .47868 .57965 L .45767 .57315 L p .707 .577 .707 r
F P
0 g
s
.45767 .57315 m .45787 .51755 L .47888 .52405 L p .707 .577 .707 r
F P
0 g
s
.30471 .64592 m .30327 .60906 L .31972 .60069 L p .707 .577 .707 r
F P
0 g
s
.31375 .5761 m .31395 .5205 L .33804 .51497 L p .707 .577 .707 r
F P
0 g
s
.49987 .69828 m .49484 .71661 L .48284 .70875 L p .707 .577 .707 r
F P
0 g
s
.48284 .70875 m .48787 .69042 L .49987 .69828 L p .707 .577 .707 r
F P
0 g
s
.31972 .60069 m .32116 .63755 L .30471 .64592 L p .707 .577 .707 r
F P
0 g
s
.48452 .59804 m .48596 .6349 L .46501 .62881 L p .707 .577 .707 r
F P
0 g
s
.46501 .62881 m .46357 .59195 L .48452 .59804 L p .707 .577 .707 r
F P
0 g
s
.45787 .51755 m .45767 .57315 L .43025 .56868 L p .707 .577 .707 r
F P
0 g
s
.43025 .56868 m .43044 .51307 L .45787 .51755 L p .707 .577 .707 r
F P
0 g
s
.30775 .66434 m .31278 .64601 L .32872 .64596 L p .707 .577 .707 r
F P
0 g
s
.33804 .51497 m .33784 .57057 L .31375 .5761 L p .707 .577 .707 r
F P
0 g
s
.32872 .64596 m .32369 .66429 L .30775 .66434 L p .707 .577 .707 r
F P
0 g
s
.33784 .57057 m .33804 .51497 L .36744 .51172 L p .707 .577 .707 r
F P
0 g
s
.32116 .63755 m .31972 .60069 L .34383 .59388 L p .707 .577 .707 r
F P
0 g
s
.43044 .51307 m .43025 .56868 L .39909 .56667 L p .707 .577 .707 r
F P
0 g
s
.39909 .56667 m .39928 .51107 L .43044 .51307 L p .707 .577 .707 r
F P
0 g
s
.36725 .56732 m .36744 .51172 L .39928 .51107 L p .707 .577 .707 r
F P
0 g
s
.36744 .51172 m .36725 .56732 L .33784 .57057 L p .707 .577 .707 r
F P
0 g
s
.39928 .51107 m .39909 .56667 L .36725 .56732 L p .707 .577 .707 r
F P
0 g
s
.46357 .59195 m .46501 .62881 L .43763 .62512 L p .707 .577 .707 r
F P
0 g
s
.43763 .62512 m .43618 .58826 L .46357 .59195 L p .707 .577 .707 r
F P
0 g
s
.34383 .59388 m .34527 .63073 L .32116 .63755 L p .707 .577 .707 r
F P
0 g
s
.48787 .69042 m .48284 .70875 L .46265 .69953 L p .707 .577 .707 r
F P
0 g
s
.46265 .69953 m .46768 .6812 L .48787 .69042 L p .707 .577 .707 r
F P
0 g
s
.32369 .66429 m .32872 .64596 L .35205 .6489 L p .707 .577 .707 r
F P
0 g
s
.34527 .63073 m .34383 .59388 L .37324 .58928 L p .707 .577 .707 r
F P
0 g
s
.35205 .6489 m .34701 .66723 L .32369 .66429 L p .707 .577 .707 r
F P
0 g
s
.43618 .58826 m .43763 .62512 L .4065 .6242 L p .707 .577 .707 r
F P
0 g
s
.4065 .6242 m .40506 .58734 L .43618 .58826 L p .707 .577 .707 r
F P
0 g
s
.37324 .58928 m .37468 .62613 L .34527 .63073 L p .707 .577 .707 r
F P
0 g
s
.37468 .62613 m .37324 .58928 L .40506 .58734 L p .707 .577 .707 r
F P
0 g
s
.40506 .58734 m .4065 .6242 L .37468 .62613 L p .707 .577 .707 r
F P
0 g
s
.46768 .6812 m .46265 .69953 L .43623 .68985 L p .707 .577 .707 r
F P
0 g
s
.43623 .68985 m .44126 .67152 L .46768 .6812 L p .707 .577 .707 r
F P
0 g
s
.34701 .66723 m .35205 .6489 L .38047 .65454 L p .707 .577 .707 r
F P
0 g
s
.38047 .65454 m .37544 .67287 L .34701 .66723 L p .707 .577 .707 r
F P
0 g
s
.44126 .67152 m .43623 .68985 L .40618 .68067 L p .707 .577 .707 r
F P
0 g
s
.40618 .68067 m .41121 .66234 L .44126 .67152 L p .707 .577 .707 r
F P
0 g
s
.37544 .67287 m .38047 .65454 L .41121 .66234 L p .707 .577 .707 r
F P
0 g
s
.41121 .66234 m .40618 .68067 L .37544 .67287 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOolG0007FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005moo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF100035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001HOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003goo5`00?goo001B
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007Ool80003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000kOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0000=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPD003Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0039o
o`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
035oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
0000<7oo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00004FUH01000
FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH00003FUH50007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040003FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP8000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo001BOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001BOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YF000060001UYF00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`80009JEP03001JEUYF00=JEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUIJEUYF1`0015YF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`80009JEP03001J
EUYF00=JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJ
EP000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF100015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool004Qoo`T000=oo`<0009JEP8000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF3P000eYF200015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000jOol>0004FUH00`00FUIJEP02FUH800000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYF
FUH80008FUH60003FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP02000^Ool003Ioo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EPH000IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0004FUH005YFFUH2000^Ool003=oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH02000FUIJEUYF001JEP00FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH2000^Ool0035oo`800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEP800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@002ioo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool002ioo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0`00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH;0005FUH0
0`00FUIJEP06FUH60004FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEPL000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF00006@001UYF00L005YFFUIJEP00FUH0000^
Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEP0000<0009JEP05001JEP00FUH00006FUH50004FUH00`00
FUIJEP08FUH400000eYF001JEP020002FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF2@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPP000=JEP8002moo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF10001EYF00D005YF001JEP00
00IJEPD000AJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH400000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP050003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000`Ool002eoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00FUH20003FUH500001UYF001JEP00FUH000IJEP@000EJEP04001JEUYFFUH400000eYF001JEP05
FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000X00003FUH00000
01L000EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH50004FUH01000FUIJEUYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03
001JEUYF00AJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001J
EUYF00AJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@000eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1@0000=JEP0000001P000eYF00<005YFFUH01UYF00<005YFFUH015YF
1@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF2@001eYF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YF
FUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH300000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP8000AJ
EP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP@00003FUH005YF00AJEP8000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEPP000AJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00;Goo00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH20004FUH00`00FUH000040006FUH00`00FUIJ
EP07FUH01@00FUH00000FUH010002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF000015YF00@005YFFUIJEPP000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000P000=JEP03001JEUYF008002eoo`00;Goo00<005YF00000P001EYF00<005YF
FUH01EYF4@0000=JEP00FUH015YF0`001UYF00<005YF000010001UYF10000UYF00<005YFFUH01eYF
00@005YFFUIJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH30004FUH40002FUH2000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP03001JEUYF00=JEPD000AJ
EPH000MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP04FUH20002FUH01000FUIJEUYF1000;Goo000]Ool20002FUH01000FUIJEUYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00IJEP03
001JEP0000T00004FUH000000004FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH60008
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05FUH200000eYF001JEP03FUH3000]Ool002eoo`80
009JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP80
0003FUH005YF00IJEP03001JEUYF009JEPL000AJEP@00003FUH005YF00IJEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000IJEP04
001JEP000004FUH3000]Ool002ioo`06001JEP00001JEP001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YFFUH015YF1@0015YF
00@005YFFUIJEP<000EJEP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP@000=JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYFFUH20003FUH00`00FUH0000]Ool002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP<00003FUH0000000<000IJEP@00003FUH0
05YF00EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
00000eYF001JEP04FUH00`00FUIJEP02000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH0
05YF00QJEP03001JEUYF00AJEP@000MJEP8000IJEP03001JEUYF00800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP<002moo`00;Goo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH010001UYF00<005YFFUH01eYF00<005YF00000`0015YF0`000eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1000
00=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00P0015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEP00
FUH005YF00@0009JEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH00000FUH00003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000002
0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00@005YFFUH002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH0
05YF0005FUH50006FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF0P0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF1`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF20000Woo0`000eYF00<007ooOol0;7oo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000015YF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH015YF2@0015YF00<005YFFUH00UYF2@0037oo00<005YF
FUH00UYF00<007ooOol0:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG
0006FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000IJEP03001JEUYF00EJEP@000IJEP03001JEUYF
00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH30002Ool9000FOol01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF20005goo10000UYF00<005YFFUH0
0eYF00H005YFFUH005YF0006FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00@005YFFUIJEP<000Ioo`D001Moo`04001JEUYF000]
Ool002aoo`03001JEP0000AJEP@0015oo`<000moo`@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH015YF1@000eYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00001Woo1@005goo00D005YF001JEP0002aoo`00;7oo00<005YF00000UYF
1@004Goo1@004Woo0`0000MJEP00FUIJEP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH:
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
00050006FUH01000FUIJEUYF0P001goo1@0067oo0P0000=JEP00Ool0:goo000/Ool00`00FUH00003
0004FUH3000>Ool5000COol40002FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP030004FUH01000FUIJEUYF0P0027oo0`006Woo00<005YF0000;7oo000/Ool0
0`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000?Ool400002EYF001JEUYF001J
EP00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01P00FUIJEUYF001JEP<00003
FUH005YF009JEP03001oogoo02Aoo`03001JEP0002aoo`00;7oo0P000eYF00<005YFFUH00eYF00<0
05YFFUH00eYF1P001Goo0`002Woo1P001EYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP04001JEUYF0004FUH200000eYF0000000WOol00`00FUH0000/
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP03001J
EUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00002FUH40005FUH3000XOol2000]Ool002aoo`80009JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH0009JEP03001JEUYF00=J
EP03001JEUYF008002Ioo`8002eoo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP00FUH20003FUH20003FUH01@00FUIJEUYF00009Goo0`00
;Goo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH015YF
2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF00000UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF0P008Woo0P0000=J
EP00Ool0;Goo000^Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH0
10002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF
00<005YF00000eYF0P000eYF00@005YF000000=JEP80025oo`03001JEUYF008002ioo`00;goo0P00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2`0000EJEP00
001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYF0003FUH5
000OOol20003FUH00`00Oomoo`0]Ool0031oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEPT000=JEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF009JEP8000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<0
00AJEP04001JEP000004FUH40006FUH4000IOol400000eYF001JEP02FUH00`00Oomoo`0]Ool0039o
o`<00003FUH005YF00IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF00800003FUH005YF00<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04001JEP00FUH600000eYF001J
EP06FUH00`00FUIJEP04000@Ool50004FUH00`00FUIJEP02000`Ool003Eoo`D000AJEPP000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EQ0000=JEP03001JEUYF00=JEP<0039oo`00=Woo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP800003FUH005YF00=JEP03001JEUYF009JEP@000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo039oo`00<Goo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPP000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEP0000800003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2000eOol002aoo`D00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH:0003Ool2
0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000080003FUH00`00FUH000070004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000=goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=0008Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00UYF10000UYF0`0017oo2@0015YF
00<005YFFUH00UYF1P00>Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH>000@Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH00`0000=JEP00Ool037oo2@00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH=000JOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1000EGoo000/Ool00`00FUH00004
FUH01000FUIJEUYF3@008Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00;7oo2`00<7oo0P000UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001oogoo05Aoo`00
JGoo0`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00=JEP04001JEP000002FUH00`00Oomoo`1D
Ool006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP04001JEP000008FUH01000FUIJEUYF1P000UYF00<007ooOol0E7oo001]Ool3
0004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUHB0002Ool2000015YF001JEP00Egoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06000BOol00`00FUIJEP02FUH2001GOol007=o
o`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009oo`D0011oo`03001J
EUYF00=JEP03001oogoo05Ioo`00Mgoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YF
FUIJEPH000Moo`D000ioo`<000AJEP03001oogoo05Moo`00OGoo7`003Goo1@003Goo00D005YFFUIJ
EP00009JEP03001oogoo05Qoo`00SGoo00D005YFFUH005YF008001Ioo`<000aoo`8000AJEP03001J
EP0005]oo`00SGoo00<005YFFUH00P009Goo0P001eYF00<007ooOol0FWoo002=Ool01000FUIJEP00
97oo0P0000=JEP00FUH015YF0P00GGoo002=Ool3000ROol30003FUH01000FUIJEUYF0P00Ggoo002>
Ool2000NOol40007FUH3001QOol008ioo`8001Yoo`@0009JEP03001JEUYF00IJEP03001oogoo065o
o`00SWoo00<005YF000057oo1@001UYF00<005YFFUH015YF0P00I7oo002>Ool2000015YF00000000
3Goo10000UYF00<005YFFUH01eYF00@005YFFUIJEP8006Ioo`00Sgoo00<005YF00000UYF3@001UYF
00<005YFFUH01eYF00@005YF000006Qoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEP@006Yoo`00T7oo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01000KWoo002AOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH4001b
Ool009=oo`<0009JEP03001JEUYF00EJEP03001JEUYF00@007Ioo`00UWoo3@00NWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59135 .74991 m .59154 .6943 L .56036 .69232 L p .707 .577 .707 r
F P
0 g
s
.59154 .6943 m .59135 .74991 L .62317 .74922 L p .707 .577 .707 r
F P
0 g
s
.62317 .74922 m .62337 .69362 L .59154 .6943 L p .707 .577 .707 r
F P
0 g
s
.62337 .69362 m .62317 .74922 L .65253 .74594 L p .707 .577 .707 r
F P
0 g
s
.65253 .74594 m .65273 .69034 L .62337 .69362 L p .707 .577 .707 r
F P
0 g
s
.56016 .74793 m .56036 .69232 L .53287 .68788 L p .707 .577 .707 r
F P
0 g
s
.56036 .69232 m .56016 .74793 L .59135 .74991 L p .707 .577 .707 r
F P
0 g
s
.65273 .69034 m .65253 .74594 L .67655 .74039 L p .707 .577 .707 r
F P
0 g
s
.67655 .74039 m .67674 .68478 L .65273 .69034 L p .707 .577 .707 r
F P
0 g
s
.53287 .68788 m .53267 .74348 L .56016 .74793 L p .707 .577 .707 r
F P
0 g
s
.53267 .74348 m .53287 .68788 L .51177 .6814 L p .707 .577 .707 r
F P
0 g
s
.59875 .8114 m .5973 .77454 L .56613 .77369 L p .707 .577 .707 r
F P
0 g
s
.5973 .77454 m .59875 .8114 L .63055 .8094 L p .707 .577 .707 r
F P
0 g
s
.63055 .8094 m .62911 .77255 L .5973 .77454 L p .707 .577 .707 r
F P
0 g
s
.62911 .77255 m .63055 .8094 L .65987 .80475 L p .707 .577 .707 r
F P
0 g
s
.65987 .80475 m .65843 .76789 L .62911 .77255 L p .707 .577 .707 r
F P
0 g
s
.56757 .81054 m .56613 .77369 L .53864 .77005 L p .707 .577 .707 r
F P
0 g
s
.56613 .77369 m .56757 .81054 L .59875 .8114 L p .707 .577 .707 r
F P
0 g
s
.67674 .68478 m .67655 .74039 L .69287 .7331 L p .707 .577 .707 r
F P
0 g
s
.69287 .7331 m .69306 .6775 L .67674 .68478 L p .707 .577 .707 r
F P
0 g
s
.51177 .6814 m .51157 .737 L .53267 .74348 L p .707 .577 .707 r
F P
0 g
s
.65843 .76789 m .65987 .80475 L .68384 .79788 L p .707 .577 .707 r
F P
0 g
s
.68384 .79788 m .68239 .76103 L .65843 .76789 L p .707 .577 .707 r
F P
0 g
s
.59776 .83791 m .60279 .81958 L .57275 .81039 L p .707 .577 .707 r
F P
0 g
s
.60279 .81958 m .59776 .83791 L .6285 .84571 L p .707 .577 .707 r
F P
0 g
s
.6285 .84571 m .63353 .82738 L .60279 .81958 L p .707 .577 .707 r
F P
0 g
s
.53864 .77005 m .54008 .80691 L .56757 .81054 L p .707 .577 .707 r
F P
0 g
s
.57275 .81039 m .56772 .82872 L .59776 .83791 L p .707 .577 .707 r
F P
0 g
s
.63353 .82738 m .6285 .84571 L .65694 .85135 L p .707 .577 .707 r
F P
0 g
s
.65694 .85135 m .66197 .83302 L .63353 .82738 L p .707 .577 .707 r
F P
0 g
s
.51157 .737 m .51177 .6814 L .49912 .67352 L p .707 .577 .707 r
F P
0 g
s
.56772 .82872 m .57275 .81039 L .54634 .80071 L p .707 .577 .707 r
F P
0 g
s
.54008 .80691 m .53864 .77005 L .51752 .76401 L p .707 .577 .707 r
F P
0 g
s
.54634 .80071 m .54131 .81904 L .56772 .82872 L p .707 .577 .707 r
F P
0 g
s
.66197 .83302 m .65694 .85135 L .68028 .8543 L p .707 .577 .707 r
F P
0 g
s
.68028 .8543 m .68531 .83597 L .66197 .83302 L p .707 .577 .707 r
F P
0 g
s
.51752 .76401 m .51896 .80086 L .54008 .80691 L p .707 .577 .707 r
F P
0 g
s
.68239 .76103 m .68384 .79788 L .7001 .78949 L p .707 .577 .707 r
F P
0 g
s
.7001 .78949 m .69866 .75263 L .68239 .76103 L p .707 .577 .707 r
F P
0 g
s
.49912 .67352 m .49892 .72913 L .51157 .737 L p .707 .577 .707 r
F P
0 g
s
.69306 .6775 m .69287 .7331 L .69989 .7248 L p .707 .577 .707 r
F P
0 g
s
.69989 .7248 m .70009 .6692 L .69306 .6775 L p .707 .577 .707 r
F P
0 g
s
.54131 .81904 m .54634 .80071 L .52617 .79149 L p .707 .577 .707 r
F P
0 g
s
.52617 .79149 m .52114 .80982 L .54131 .81904 L p .707 .577 .707 r
F P
0 g
s
.51896 .80086 m .51752 .76401 L .50484 .75613 L p .707 .577 .707 r
F P
0 g
s
.49892 .72913 m .49912 .67352 L .49617 .66502 L p .707 .577 .707 r
F P
0 g
s
.68531 .83597 m .68028 .8543 L .69625 .85424 L p .707 .577 .707 r
F P
0 g
s
.69625 .85424 m .70128 .83591 L .68531 .83597 L p .707 .577 .707 r
F P
0 g
s
.50484 .75613 m .50628 .79299 L .51896 .80086 L p .707 .577 .707 r
F P
0 g
s
.52114 .80982 m .52617 .79149 L .51419 .78363 L p .707 .577 .707 r
F P
0 g
s
.69866 .75263 m .7001 .78949 L .70708 .78038 L p .707 .577 .707 r
F P
0 g
s
.70708 .78038 m .70564 .74353 L .69866 .75263 L p .707 .577 .707 r
F P
0 g
s
.51419 .78363 m .50916 .80196 L .52114 .80982 L p .707 .577 .707 r
F P
0 g
s
.49617 .66502 m .49597 .72062 L .49892 .72913 L p .707 .577 .707 r
F P
0 g
s
.70009 .6692 m .69989 .7248 L .69693 .7163 L p .707 .577 .707 r
F P
0 g
s
.69693 .7163 m .69713 .66069 L .70009 .6692 L p .707 .577 .707 r
F P
0 g
s
.50628 .79299 m .50484 .75613 L .50184 .74721 L p .707 .577 .707 r
F P
0 g
s
.48751 .82178 m .48751 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.49597 .72062 m .49617 .66502 L .50319 .65671 L p .707 .577 .707 r
F P
0 g
s
.50184 .74721 m .50328 .78407 L .50628 .79299 L p .707 .577 .707 r
F P
0 g
s
.50916 .80196 m .51419 .78363 L .51159 .7779 L p .707 .577 .707 r
F P
0 g
s
.51159 .7779 m .50656 .79623 L .50916 .80196 L p .707 .577 .707 r
F P
0 g
s
.50319 .65671 m .50299 .71232 L .49597 .72062 L p .707 .577 .707 r
F P
0 g
s
.50328 .78407 m .50184 .74721 L .50881 .7381 L p .707 .577 .707 r
F P
0 g
s
.50299 .71232 m .50319 .65671 L .51951 .64943 L p .707 .577 .707 r
F P
0 g
s
.50881 .7381 m .51026 .77496 L .50328 .78407 L p .707 .577 .707 r
F P
0 g
s
.50656 .79623 m .51159 .7779 L .51861 .77486 L p .707 .577 .707 r
F P
0 g
s
.51861 .77486 m .51358 .79319 L .50656 .79623 L p .707 .577 .707 r
F P
0 g
s
.51951 .64943 m .51931 .70504 L .50299 .71232 L p .707 .577 .707 r
F P
0 g
s
.51026 .77496 m .50881 .7381 L .52508 .72971 L p .707 .577 .707 r
F P
0 g
s
.51931 .70504 m .51951 .64943 L .54352 .64388 L p .707 .577 .707 r
F P
0 g
s
.52508 .72971 m .52653 .76656 L .51026 .77496 L p .707 .577 .707 r
F P
0 g
s
.51358 .79319 m .51861 .77486 L .53458 .77481 L p .707 .577 .707 r
F P
0 g
s
.54352 .64388 m .54333 .69948 L .51931 .70504 L p .707 .577 .707 r
F P
0 g
s
.53458 .77481 m .52955 .79314 L .51358 .79319 L p .707 .577 .707 r
F P
0 g
s
.52653 .76656 m .52508 .72971 L .54905 .72285 L p .707 .577 .707 r
F P
0 g
s
.54905 .72285 m .55049 .7597 L .52653 .76656 L p .707 .577 .707 r
F P
0 g
s
.52955 .79314 m .53458 .77481 L .55792 .77775 L p .707 .577 .707 r
F P
0 g
s
.55792 .77775 m .55289 .79608 L .52955 .79314 L p .707 .577 .707 r
F P
0 g
s
.48751 .31989 m .48751 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48751 .31989 L p .707 .577 .707 r
F P
0 g
s
.54333 .69948 m .54352 .64388 L .57288 .6406 L p .707 .577 .707 r
F P
0 g
s
.57288 .6406 m .57268 .6962 L .54333 .69948 L p .707 .577 .707 r
F P
0 g
s
.55049 .7597 m .54905 .72285 L .57837 .71819 L p .707 .577 .707 r
F P
0 g
s
.57837 .71819 m .57981 .75504 L .55049 .7597 L p .707 .577 .707 r
F P
0 g
s
.55289 .79608 m .55792 .77775 L .58636 .7834 L p .707 .577 .707 r
F P
0 g
s
.58636 .7834 m .58133 .80173 L .55289 .79608 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57436 .81638 L p .707 .577 .707 r
F P
0 g
s
.57268 .6962 m .57288 .6406 L .60471 .63991 L p .707 .577 .707 r
F P
0 g
s
.60471 .63991 m .60451 .69552 L .57268 .6962 L p .707 .577 .707 r
F P
0 g
s
.57436 .81638 m .57436 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70128 .83591 m .69625 .85424 L .70327 .8512 L p .707 .577 .707 r
F P
0 g
s
.70327 .8512 m .7083 .83287 L .70128 .83591 L p .707 .577 .707 r
F P
0 g
s
.44371 .81885 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44371 .81885 L .48751 .82178 L p .707 .577 .707 r
F P
0 g
s
.70564 .74353 m .70708 .78038 L .70408 .77146 L p .707 .577 .707 r
F P
0 g
s
.70408 .77146 m .70264 .7346 L .70564 .74353 L p .707 .577 .707 r
F P
0 g
s
.69713 .66069 m .69693 .7163 L .68429 .70842 L p .707 .577 .707 r
F P
0 g
s
.68429 .70842 m .68448 .65282 L .69713 .66069 L p .707 .577 .707 r
F P
0 g
s
.57981 .75504 m .57837 .71819 L .61017 .71619 L p .707 .577 .707 r
F P
0 g
s
.61017 .71619 m .61162 .75305 L .57981 .75504 L p .707 .577 .707 r
F P
0 g
s
.58133 .80173 m .58636 .7834 L .6171 .7912 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .61207 .80953 L .58133 .80173 L p .707 .577 .707 r
F P
0 g
s
.57436 .31449 m .57436 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.6359 .64189 m .6357 .6975 L .60451 .69552 L p .707 .577 .707 r
F P
0 g
s
.60451 .69552 m .60471 .63991 L .6359 .64189 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .30671 L .57436 .31449 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44371 .81885 L p .707 .577 .707 r
F P
0 g
s
.25118 .71167 m .25126 .65614 L .22008 .65419 L p .707 .577 .707 r
F P
0 g
s
.25126 .65614 m .25118 .71167 L .28301 .71092 L p .707 .577 .707 r
F P
0 g
s
.28301 .71092 m .28309 .65539 L .25126 .65614 L p .707 .577 .707 r
F P
0 g
s
.7083 .83287 m .70327 .8512 L .70067 .84547 L p .707 .577 .707 r
F P
0 g
s
.70067 .84547 m .7057 .82714 L .7083 .83287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28309 .65539 m .28301 .71092 L .31237 .70752 L p .707 .577 .707 r
F P
0 g
s
.31237 .70752 m .31245 .65199 L .28309 .65539 L p .707 .577 .707 r
F P
0 g
s
.21999 .70972 m .22008 .65419 L .19259 .64972 L p .707 .577 .707 r
F P
0 g
s
.22008 .65419 m .21999 .70972 L .25118 .71167 L p .707 .577 .707 r
F P
0 g
s
.70264 .7346 m .70408 .77146 L .6914 .76358 L p .707 .577 .707 r
F P
0 g
s
.6914 .76358 m .68996 .72673 L .70264 .7346 L p .707 .577 .707 r
F P
0 g
s
.68448 .65282 m .68429 .70842 L .66319 .70194 L p .707 .577 .707 r
F P
0 g
s
.66319 .70194 m .66338 .64634 L .68448 .65282 L p .707 .577 .707 r
F P
0 g
s
.64135 .71705 m .64279 .75391 L .61162 .75305 L p .707 .577 .707 r
F P
0 g
s
.61162 .75305 m .61017 .71619 L .64135 .71705 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .64715 .80039 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61207 .80953 m .61249 .80803 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61249 .80803 m .6171 .7912 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.66338 .64634 m .66319 .70194 L .6357 .6975 L p .707 .577 .707 r
F P
0 g
s
.6357 .6975 m .6359 .64189 L .66338 .64634 L p .707 .577 .707 r
F P
0 g
s
.66884 .72068 m .67028 .75754 L .64279 .75391 L p .707 .577 .707 r
F P
0 g
s
.64279 .75391 m .64135 .71705 L .66884 .72068 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .6437 .78657 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .31285 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .31285 m .63281 .79832 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.60892 .30671 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .30671 L p .707 .577 .707 r
F P
0 g
s
.31245 .65199 m .31237 .70752 L .33638 .70182 L p .707 .577 .707 r
F P
0 g
s
.33638 .70182 m .33646 .6463 L .31245 .65199 L p .707 .577 .707 r
F P
0 g
s
.25445 .77005 m .25383 .73264 L .22264 .73151 L p .707 .577 .707 r
F P
0 g
s
.25383 .73264 m .25445 .77005 L .28628 .76885 L p .707 .577 .707 r
F P
0 g
s
.28628 .76885 m .28566 .73144 L .25383 .73264 L p .707 .577 .707 r
F P
0 g
s
.28566 .73144 m .28628 .76885 L .31561 .76545 L p .707 .577 .707 r
F P
0 g
s
.31561 .76545 m .31499 .72804 L .28566 .73144 L p .707 .577 .707 r
F P
0 g
s
.19259 .64972 m .1925 .70525 L .21999 .70972 L p .707 .577 .707 r
F P
0 g
s
.22326 .76892 m .22264 .73151 L .19513 .72817 L p .707 .577 .707 r
F P
0 g
s
.22264 .73151 m .22326 .76892 L .25445 .77005 L p .707 .577 .707 r
F P
0 g
s
.1925 .70525 m .19259 .64972 L .17149 .64317 L p .707 .577 .707 r
F P
0 g
s
.31499 .72804 m .31561 .76545 L .33959 .76017 L p .707 .577 .707 r
F P
0 g
s
.33959 .76017 m .33897 .72276 L .31499 .72804 L p .707 .577 .707 r
F P
0 g
s
.7057 .82714 m .70067 .84547 L .6887 .83761 L p .707 .577 .707 r
F P
0 g
s
.6887 .83761 m .69373 .81928 L .7057 .82714 L p .707 .577 .707 r
F P
0 g
s
.19513 .72817 m .19575 .76558 L .22326 .76892 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.68996 .72673 m .6914 .76358 L .67028 .75754 L p .707 .577 .707 r
F P
0 g
s
.67028 .75754 m .66884 .72068 L .68996 .72673 L p .707 .577 .707 r
F P
0 g
s
.33646 .6463 m .33638 .70182 L .3527 .69438 L p .707 .577 .707 r
F P
0 g
s
.3527 .69438 m .35278 .63885 L .33646 .6463 L p .707 .577 .707 r
F P
0 g
s
.25454 .83913 m .25674 .8227 L .22573 .8161 L p .707 .577 .707 r
F P
0 g
s
.25674 .8227 m .25454 .83913 L .28615 .8407 L p .707 .577 .707 r
F P
0 g
s
.28615 .8407 m .28835 .82427 L .25674 .8227 L p .707 .577 .707 r
F P
0 g
s
.17149 .64317 m .1714 .6987 L .1925 .70525 L p .707 .577 .707 r
F P
0 g
s
.19575 .76558 m .19513 .72817 L .17399 .72293 L p .707 .577 .707 r
F P
0 g
s
.22353 .83253 m .22573 .8161 L .19837 .80512 L p .707 .577 .707 r
F P
0 g
s
.22573 .8161 m .22353 .83253 L .25454 .83913 L p .707 .577 .707 r
F P
0 g
s
.28835 .82427 m .28615 .8407 L .31527 .83707 L p .707 .577 .707 r
F P
0 g
s
.31527 .83707 m .31747 .82064 L .28835 .82427 L p .707 .577 .707 r
F P
0 g
s
.1714 .6987 m .17149 .64317 L .15884 .63518 L p .707 .577 .707 r
F P
0 g
s
.17399 .72293 m .17461 .76034 L .19575 .76558 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.33897 .72276 m .33959 .76017 L .35586 .75352 L p .707 .577 .707 r
F P
0 g
s
.35586 .75352 m .35524 .71611 L .33897 .72276 L p .707 .577 .707 r
F P
0 g
s
.19837 .80512 m .19617 .82155 L .22353 .83253 L p .707 .577 .707 r
F P
0 g
s
.19617 .82155 m .19837 .80512 L .17733 .79081 L p .707 .577 .707 r
F P
0 g
s
.31747 .82064 m .31527 .83707 L .33906 .82861 L p .707 .577 .707 r
F P
0 g
s
.33906 .82861 m .34126 .81218 L .31747 .82064 L p .707 .577 .707 r
F P
0 g
s
.69373 .81928 m .6887 .83761 L .66852 .82839 L p .707 .577 .707 r
F P
0 g
s
.66852 .82839 m .67355 .81006 L .69373 .81928 L p .707 .577 .707 r
F P
0 g
s
.15884 .63518 m .15876 .69071 L .1714 .6987 L p .707 .577 .707 r
F P
0 g
s
.17461 .76034 m .17399 .72293 L .1613 .71632 L p .707 .577 .707 r
F P
0 g
s
.35278 .63885 m .3527 .69438 L .35972 .68592 L p .707 .577 .707 r
F P
0 g
s
.35972 .68592 m .35981 .63039 L .35278 .63885 L p .707 .577 .707 r
F P
0 g
s
.17733 .79081 m .17513 .80724 L .19617 .82155 L p .707 .577 .707 r
F P
0 g
s
.1613 .71632 m .16192 .75373 L .17461 .76034 L p .707 .577 .707 r
F P
0 g
s
.35524 .71611 m .35586 .75352 L .36283 .74617 L p .707 .577 .707 r
F P
0 g
s
.36283 .74617 m .36221 .70876 L .35524 .71611 L p .707 .577 .707 r
F P
0 g
s
.35981 .63039 m .35972 .68592 L .35677 .67727 L p .707 .577 .707 r
F P
0 g
s
.35677 .67727 m .35685 .62174 L .35981 .63039 L p .707 .577 .707 r
F P
0 g
s
.35982 .73883 m .3592 .70142 L .36221 .70876 L p .707 .577 .707 r
F P
0 g
s
.36205 .80089 m .36425 .78446 L .35737 .79972 L p .707 .577 .707 r
F P
0 g
s
.36425 .78446 m .36205 .80089 L .35901 .78435 L p .707 .577 .707 r
F P
0 g
s
.35901 .78435 m .3612 .76792 L .36425 .78446 L p .707 .577 .707 r
F P
0 g
s
.3592 .70142 m .35982 .73883 L .34713 .73222 L p .707 .577 .707 r
F P
0 g
s
.34713 .73222 m .34651 .69481 L .3592 .70142 L p .707 .577 .707 r
F P
0 g
s
.3612 .76792 m .35901 .78435 L .34634 .76813 L p .707 .577 .707 r
F P
0 g
s
.34634 .76813 m .34854 .7517 L .3612 .76792 L p .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .29006 L .3563 .27798 L p .707 .577 .707 r
F P
0 g
s
.36221 .70876 m .36283 .74617 L .35982 .73883 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.17513 .80724 m .17733 .79081 L .16466 .7746 L p .707 .577 .707 r
F P
0 g
s
.15876 .69071 m .15884 .63518 L .15588 .62653 L p .707 .577 .707 r
F P
0 g
s
.34126 .81218 m .33906 .82861 L .35518 .81615 L p .707 .577 .707 r
F P
0 g
s
.35518 .81615 m .35737 .79972 L .34126 .81218 L p .707 .577 .707 r
F P
0 g
s
.67355 .81006 m .66852 .82839 L .64212 .81872 L p .707 .577 .707 r
F P
0 g
s
.64212 .81872 m .64715 .80039 L .67355 .81006 L p .707 .577 .707 r
F P
0 g
s
.16466 .7746 m .16246 .79103 L .17513 .80724 L p .707 .577 .707 r
F P
0 g
s
.15588 .62653 m .1558 .68206 L .15876 .69071 L p .707 .577 .707 r
F P
0 g
s
.16192 .75373 m .1613 .71632 L .15829 .70898 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .78657 L .64053 .77449 L p .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.16246 .79103 m .16466 .7746 L .16162 .75805 L p .707 .577 .707 r
F P
0 g
s
.64715 .80039 m .64212 .81872 L .61207 .80953 L p .707 .577 .707 r
F P
0 g
s
.35737 .79972 m .35518 .81615 L .36205 .80089 L p .707 .577 .707 r
F P
0 g
s
.15829 .70898 m .15891 .74639 L .16192 .75373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1558 .68206 m .15588 .62653 L .16291 .61807 L p .707 .577 .707 r
F P
0 g
s
.16162 .75805 m .15942 .77448 L .16246 .79103 L p .707 .577 .707 r
F P
0 g
s
.35685 .62174 m .35677 .67727 L .34412 .66928 L p .707 .577 .707 r
F P
0 g
s
.34412 .66928 m .3442 .61375 L .35685 .62174 L p .707 .577 .707 r
F P
0 g
s
.3563 .27798 m .35629 .77987 L .35947 .79195 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .3563 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16291 .61807 m .16283 .6736 L .1558 .68206 L p .707 .577 .707 r
F P
0 g
s
.15891 .74639 m .15829 .70898 L .16526 .70163 L p .707 .577 .707 r
F P
0 g
s
.15942 .77448 m .16162 .75805 L .16849 .7428 L p .707 .577 .707 r
F P
0 g
s
.16526 .70163 m .16588 .73904 L .15891 .74639 L p .707 .577 .707 r
F P
0 g
s
.16283 .6736 m .16291 .61807 L .17923 .61063 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .6236 .76326 L p .707 .577 .707 r
F P
0 g
s
.6236 .76326 m .6236 .26138 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.16849 .7428 m .16629 .75923 L .15942 .77448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17923 .61063 m .17914 .66616 L .16283 .6736 L p .707 .577 .707 r
F P
0 g
s
.3442 .61375 m .34412 .66928 L .32302 .66273 L p .707 .577 .707 r
F P
0 g
s
.32302 .66273 m .3231 .6072 L .3442 .61375 L p .707 .577 .707 r
F P
0 g
s
.16588 .73904 m .16526 .70163 L .18153 .69499 L p .707 .577 .707 r
F P
0 g
s
.16629 .75923 m .16849 .7428 L .18461 .73034 L p .707 .577 .707 r
F P
0 g
s
.36719 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36719 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18153 .69499 m .18215 .7324 L .16588 .73904 L p .707 .577 .707 r
F P
0 g
s
.17914 .66616 m .17923 .61063 L .20324 .60493 L p .707 .577 .707 r
F P
0 g
s
.18461 .73034 m .18241 .74677 L .16629 .75923 L p .707 .577 .707 r
F P
0 g
s
.34651 .69481 m .34713 .73222 L .32599 .72699 L p .707 .577 .707 r
F P
0 g
s
.32599 .72699 m .32537 .68958 L .34651 .69481 L p .707 .577 .707 r
F P
0 g
s
.3231 .6072 m .32302 .66273 L .29553 .65826 L p .707 .577 .707 r
F P
0 g
s
.29553 .65826 m .29562 .60273 L .3231 .6072 L p .707 .577 .707 r
F P
0 g
s
.6236 .26138 m .6236 .76326 L .59457 .75399 L p .707 .577 .707 r
F P
0 g
s
.59457 .75399 m .59457 .2521 L .6236 .26138 L p .707 .577 .707 r
F P
0 g
s
.20324 .60493 m .20316 .66046 L .17914 .66616 L p .707 .577 .707 r
F P
0 g
s
.18241 .74677 m .18461 .73034 L .20839 .72188 L p .707 .577 .707 r
F P
0 g
s
.34854 .7517 m .34634 .76813 L .3253 .75383 L p .707 .577 .707 r
F P
0 g
s
.3253 .75383 m .3275 .7374 L .34854 .7517 L p .707 .577 .707 r
F P
0 g
s
.18215 .7324 m .18153 .69499 L .20551 .68971 L p .707 .577 .707 r
F P
0 g
s
.20316 .66046 m .20324 .60493 L .2326 .60154 L p .707 .577 .707 r
F P
0 g
s
.20839 .72188 m .2062 .73831 L .18241 .74677 L p .707 .577 .707 r
F P
0 g
s
.20551 .68971 m .20613 .72712 L .18215 .7324 L p .707 .577 .707 r
F P
0 g
s
.73565 .65847 m .73557 .60284 L .70438 .60102 L p .707 .577 .707 r
F P
0 g
s
.73557 .60284 m .73565 .65847 L .76748 .65764 L p .707 .577 .707 r
F P
0 g
s
.76748 .65764 m .7674 .60201 L .73557 .60284 L p .707 .577 .707 r
F P
0 g
s
.29562 .60273 m .29553 .65826 L .26435 .65631 L p .707 .577 .707 r
F P
0 g
s
.26435 .65631 m .26443 .60078 L .29562 .60273 L p .707 .577 .707 r
F P
0 g
s
.32537 .68958 m .32599 .72699 L .29848 .72364 L p .707 .577 .707 r
F P
0 g
s
.29848 .72364 m .29786 .68623 L .32537 .68958 L p .707 .577 .707 r
F P
0 g
s
.7674 .60201 m .76748 .65764 L .79684 .65425 L p .707 .577 .707 r
F P
0 g
s
.79684 .65425 m .79676 .59861 L .7674 .60201 L p .707 .577 .707 r
F P
0 g
s
.23252 .65707 m .2326 .60154 L .26443 .60078 L p .707 .577 .707 r
F P
0 g
s
.2326 .60154 m .23252 .65707 L .20316 .66046 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36719 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42564 .24816 L p .707 .577 .707 r
F P
0 g
s
.70447 .65665 m .70438 .60102 L .67689 .59673 L p .707 .577 .707 r
F P
0 g
s
.70438 .60102 m .70447 .65665 L .73565 .65847 L p .707 .577 .707 r
F P
0 g
s
.26443 .60078 m .26435 .65631 L .23252 .65707 L p .707 .577 .707 r
F P
0 g
s
.2062 .73831 m .20839 .72188 L .23752 .71825 L p .707 .577 .707 r
F P
0 g
s
.3275 .7374 m .3253 .75383 L .29794 .74284 L p .707 .577 .707 r
F P
0 g
s
.29794 .74284 m .30013 .72641 L .3275 .7374 L p .707 .577 .707 r
F P
0 g
s
.20613 .72712 m .20551 .68971 L .23484 .6863 L p .707 .577 .707 r
F P
0 g
s
.79676 .59861 m .79684 .65425 L .82085 .64862 L p .707 .577 .707 r
F P
0 g
s
.82085 .64862 m .82077 .59299 L .79676 .59861 L p .707 .577 .707 r
F P
0 g
s
.23752 .71825 m .23532 .73468 L .2062 .73831 L p .707 .577 .707 r
F P
0 g
s
.26693 .73624 m .26913 .71981 L .30013 .72641 L p .707 .577 .707 r
F P
0 g
s
.26913 .71981 m .26693 .73624 L .23532 .73468 L p .707 .577 .707 r
F P
0 g
s
.29786 .68623 m .29848 .72364 L .26728 .72251 L p .707 .577 .707 r
F P
0 g
s
.23532 .73468 m .23752 .71825 L .26913 .71981 L p .707 .577 .707 r
F P
0 g
s
.26728 .72251 m .26666 .6851 L .29786 .68623 L p .707 .577 .707 r
F P
0 g
s
.23484 .6863 m .23546 .72371 L .20613 .72712 L p .707 .577 .707 r
F P
0 g
s
.59457 .2521 m .59457 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59457 .2521 L p .707 .577 .707 r
F P
0 g
s
.30013 .72641 m .29794 .74284 L .26693 .73624 L p .707 .577 .707 r
F P
0 g
s
.67689 .59673 m .67698 .65237 L .70447 .65665 L p .707 .577 .707 r
F P
0 g
s
.23546 .72371 m .23484 .6863 L .26666 .6851 L p .707 .577 .707 r
F P
0 g
s
.67698 .65237 m .67689 .59673 L .65579 .5904 L p .707 .577 .707 r
F P
0 g
s
.26666 .6851 m .26728 .72251 L .23546 .72371 L p .707 .577 .707 r
F P
0 g
s
.73271 .72076 m .73333 .68412 L .70214 .68152 L p .707 .577 .707 r
F P
0 g
s
.73333 .68412 m .73271 .72076 L .76453 .72033 L p .707 .577 .707 r
F P
0 g
s
.76453 .72033 m .76515 .68369 L .73333 .68412 L p .707 .577 .707 r
F P
0 g
s
.76515 .68369 m .76453 .72033 L .79387 .71692 L p .707 .577 .707 r
F P
0 g
s
.79387 .71692 m .79449 .68028 L .76515 .68369 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42564 .24816 L .46747 .24362 L p .707 .577 .707 r
F P
0 g
s
.42564 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.70152 .71816 m .70214 .68152 L .67463 .67615 L p .707 .577 .707 r
F P
0 g
s
.70214 .68152 m .70152 .71816 L .73271 .72076 L p .707 .577 .707 r
F P
0 g
s
.82077 .59299 m .82085 .64862 L .83717 .64131 L p .707 .577 .707 r
F P
0 g
s
.83717 .64131 m .83709 .58568 L .82077 .59299 L p .707 .577 .707 r
F P
0 g
s
.65579 .5904 m .65588 .64603 L .67698 .65237 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51249 .74466 L p .707 .577 .707 r
F P
0 g
s
.51249 .74466 m .51249 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.79449 .68028 m .79387 .71692 L .81784 .71086 L p .707 .577 .707 r
F P
0 g
s
.81784 .71086 m .81846 .67422 L .79449 .68028 L p .707 .577 .707 r
F P
0 g
s
.65588 .64603 m .65579 .5904 L .64315 .58263 L p .707 .577 .707 r
F P
0 g
s
.67463 .67615 m .67401 .71278 L .70152 .71816 L p .707 .577 .707 r
F P
0 g
s
.73307 .73286 m .73087 .71375 L .69986 .71727 L p .707 .577 .707 r
F P
0 g
s
.73087 .71375 m .73307 .73286 L .76468 .7292 L p .707 .577 .707 r
F P
0 g
s
.76468 .7292 m .76248 .71009 L .73087 .71375 L p .707 .577 .707 r
F P
0 g
s
.69986 .71727 m .70206 .73637 L .73307 .73286 L p .707 .577 .707 r
F P
0 g
s
.76248 .71009 m .76468 .7292 L .7938 .72575 L p .707 .577 .707 r
F P
0 g
s
.7938 .72575 m .7916 .70665 L .76248 .71009 L p .707 .577 .707 r
F P
0 g
s
.46747 .74551 m .46747 .24362 L .51249 .24277 L p .707 .577 .707 r
F P
0 g
s
.46747 .24362 m .46747 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.67401 .71278 m .67463 .67615 L .65349 .66853 L p .707 .577 .707 r
F P
0 g
s
.51249 .24277 m .51249 .74466 L .46747 .74551 L p .707 .577 .707 r
F P
0 g
s
.70206 .73637 m .69986 .71727 L .6725 .72029 L p .707 .577 .707 r
F P
0 g
s
.6725 .72029 m .6747 .7394 L .70206 .73637 L p .707 .577 .707 r
F P
0 g
s
.64315 .58263 m .64323 .63827 L .65588 .64603 L p .707 .577 .707 r
F P
0 g
s
.83709 .58568 m .83717 .64131 L .8442 .63304 L p .707 .577 .707 r
F P
0 g
s
.8442 .63304 m .84411 .5774 L .83709 .58568 L p .707 .577 .707 r
F P
0 g
s
.65349 .66853 m .65287 .70517 L .67401 .71278 L p .707 .577 .707 r
F P
0 g
s
.7916 .70665 m .7938 .72575 L .81759 .72286 L p .707 .577 .707 r
F P
0 g
s
.81759 .72286 m .81539 .70375 L .7916 .70665 L p .707 .577 .707 r
F P
0 g
s
.81846 .67422 m .81784 .71086 L .83411 .70274 L p .707 .577 .707 r
F P
0 g
s
.83411 .70274 m .83473 .6661 L .81846 .67422 L p .707 .577 .707 r
F P
0 g
s
.6747 .7394 m .6725 .72029 L .65146 .72253 L p .707 .577 .707 r
F P
0 g
s
.65146 .72253 m .65366 .74164 L .6747 .7394 L p .707 .577 .707 r
F P
0 g
s
.65287 .70517 m .65349 .66853 L .6408 .65941 L p .707 .577 .707 r
F P
0 g
s
.64323 .63827 m .64315 .58263 L .64019 .5742 L p .707 .577 .707 r
F P
0 g
s
.81539 .70375 m .81759 .72286 L .83371 .72079 L p .707 .577 .707 r
F P
0 g
s
.83371 .72079 m .83151 .70169 L .81539 .70375 L p .707 .577 .707 r
F P
0 g
s
.6408 .65941 m .64018 .69605 L .65287 .70517 L p .707 .577 .707 r
F P
0 g
s
.64019 .5742 m .64028 .62983 L .64323 .63827 L p .707 .577 .707 r
F P
0 g
s
.83473 .6661 m .83411 .70274 L .84109 .69335 L p .707 .577 .707 r
F P
0 g
s
.84109 .69335 m .84171 .65672 L .83473 .6661 L p .707 .577 .707 r
F P
0 g
s
.84411 .5774 m .8442 .63304 L .84124 .6246 L p .707 .577 .707 r
F P
0 g
s
.84124 .6246 m .84116 .56897 L .84411 .5774 L p .707 .577 .707 r
F P
0 g
s
.65366 .74164 m .65146 .72253 L .63879 .72377 L p .707 .577 .707 r
F P
0 g
s
.63879 .72377 m .64099 .74287 L .65366 .74164 L p .707 .577 .707 r
F P
0 g
s
.64018 .69605 m .6408 .65941 L .63779 .64968 L p .707 .577 .707 r
F P
0 g
s
.64028 .62983 m .64019 .5742 L .64722 .56592 L p .707 .577 .707 r
F P
0 g
s
.83151 .70169 m .83371 .72079 L .84058 .71977 L p .707 .577 .707 r
F P
0 g
s
.84058 .71977 m .83838 .70066 L .83151 .70169 L p .707 .577 .707 r
F P
0 g
s
.63779 .64968 m .63717 .68632 L .64018 .69605 L p .707 .577 .707 r
F P
0 g
s
.64722 .56592 m .6473 .62156 L .64028 .62983 L p .707 .577 .707 r
F P
0 g
s
.84171 .65672 m .84109 .69335 L .83808 .68363 L p .707 .577 .707 r
F P
0 g
s
.83808 .68363 m .8387 .64699 L .84171 .65672 L p .707 .577 .707 r
F P
0 g
s
.84116 .56897 m .84124 .6246 L .8286 .61684 L p .707 .577 .707 r
F P
0 g
s
.8286 .61684 m .82851 .56121 L .84116 .56897 L p .707 .577 .707 r
F P
0 g
s
.64099 .74287 m .63879 .72377 L .63575 .72387 L p .707 .577 .707 r
F P
0 g
s
.63575 .72387 m .63795 .74298 L .64099 .74287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63717 .68632 m .63779 .64968 L .64476 .6403 L p .707 .577 .707 r
F P
0 g
s
.6473 .62156 m .64722 .56592 L .66353 .55861 L p .707 .577 .707 r
F P
0 g
s
.39548 .62024 m .39529 .56468 L .3641 .56289 L p .707 .577 .707 r
F P
0 g
s
.39529 .56468 m .39548 .62024 L .42731 .61934 L p .707 .577 .707 r
F P
0 g
s
.42731 .61934 m .42712 .56378 L .39529 .56468 L p .707 .577 .707 r
F P
0 g
s
.42712 .56378 m .42731 .61934 L .45667 .61583 L p .707 .577 .707 r
F P
0 g
s
.45667 .61583 m .45648 .56027 L .42712 .56378 L p .707 .577 .707 r
F P
0 g
s
.83838 .70066 m .84058 .71977 L .83753 .71987 L p .707 .577 .707 r
F P
0 g
s
.83753 .71987 m .83534 .70077 L .83838 .70066 L p .707 .577 .707 r
F P
0 g
s
.64476 .6403 m .64414 .67694 L .63717 .68632 L p .707 .577 .707 r
F P
0 g
s
.3643 .61845 m .3641 .56289 L .33661 .55857 L p .707 .577 .707 r
F P
0 g
s
.3641 .56289 m .3643 .61845 L .39548 .62024 L p .707 .577 .707 r
F P
0 g
s
.66353 .55861 m .66362 .61425 L .6473 .62156 L p .707 .577 .707 r
F P
0 g
s
.8387 .64699 m .83808 .68363 L .82539 .67451 L p .707 .577 .707 r
F P
0 g
s
.82539 .67451 m .82601 .63787 L .8387 .64699 L p .707 .577 .707 r
F P
0 g
s
.82851 .56121 m .8286 .61684 L .8075 .61051 L p .707 .577 .707 r
F P
0 g
s
.8075 .61051 m .80741 .55487 L .82851 .56121 L p .707 .577 .707 r
F P
0 g
s
.45648 .56027 m .45667 .61583 L .48069 .61006 L p .707 .577 .707 r
F P
0 g
s
.48069 .61006 m .48049 .5545 L .45648 .56027 L p .707 .577 .707 r
F P
0 g
s
.63795 .74298 m .63575 .72387 L .64262 .72285 L p .707 .577 .707 r
F P
0 g
s
.64262 .72285 m .64482 .74195 L .63795 .74298 L p .707 .577 .707 r
F P
0 g
s
.38838 .67943 m .38983 .64224 L .35865 .63934 L p .707 .577 .707 r
F P
0 g
s
.38983 .64224 m .38838 .67943 L .42019 .67983 L p .707 .577 .707 r
F P
0 g
s
.42019 .67983 m .42163 .64264 L .38983 .64224 L p .707 .577 .707 r
F P
0 g
s
.64414 .67694 m .64476 .6403 L .66103 .63218 L p .707 .577 .707 r
F P
0 g
s
.42163 .64264 m .42019 .67983 L .44951 .67769 L p .707 .577 .707 r
F P
0 g
s
.44951 .67769 m .45095 .6405 L .42163 .64264 L p .707 .577 .707 r
F P
0 g
s
.33661 .55857 m .33681 .61413 L .3643 .61845 L p .707 .577 .707 r
F P
0 g
s
.66362 .61425 m .66353 .55861 L .68755 .55299 L p .707 .577 .707 r
F P
0 g
s
.33681 .61413 m .33661 .55857 L .31551 .55217 L p .707 .577 .707 r
F P
0 g
s
.35721 .67654 m .35865 .63934 L .33116 .63423 L p .707 .577 .707 r
F P
0 g
s
.35865 .63934 m .35721 .67654 L .38838 .67943 L p .707 .577 .707 r
F P
0 g
s
.66103 .63218 m .66041 .66882 L .64414 .67694 L p .707 .577 .707 r
F P
0 g
s
.45095 .6405 m .44951 .67769 L .47347 .67322 L p .707 .577 .707 r
F P
0 g
s
.47347 .67322 m .47492 .63603 L .45095 .6405 L p .707 .577 .707 r
F P
0 g
s
.83534 .70077 m .83753 .71987 L .82487 .72111 L p .707 .577 .707 r
F P
0 g
s
.82487 .72111 m .82267 .702 L .83534 .70077 L p .707 .577 .707 r
F P
0 g
s
.80741 .55487 m .8075 .61051 L .78001 .60622 L p .707 .577 .707 r
F P
0 g
s
.78001 .60622 m .77992 .55058 L .80741 .55487 L p .707 .577 .707 r
F P
0 g
s
.48049 .5545 m .48069 .61006 L .497 .60259 L p .707 .577 .707 r
F P
0 g
s
.497 .60259 m .49681 .54703 L .48049 .5545 L p .707 .577 .707 r
F P
0 g
s
.33116 .63423 m .32972 .67142 L .35721 .67654 L p .707 .577 .707 r
F P
0 g
s
.68755 .55299 m .68763 .60862 L .66362 .61425 L p .707 .577 .707 r
F P
0 g
s
.41867 .72664 m .41364 .70944 L .38289 .71817 L p .707 .577 .707 r
F P
0 g
s
.41364 .70944 m .41867 .72664 L .4471 .71485 L p .707 .577 .707 r
F P
0 g
s
.4471 .71485 m .44207 .69764 L .41364 .70944 L p .707 .577 .707 r
F P
0 g
s
.31551 .55217 m .31571 .60773 L .33681 .61413 L p .707 .577 .707 r
F P
0 g
s
.38792 .73538 m .38289 .71817 L .35285 .72298 L p .707 .577 .707 r
F P
0 g
s
.38289 .71817 m .38792 .73538 L .41867 .72664 L p .707 .577 .707 r
F P
0 g
s
.82601 .63787 m .82539 .67451 L .80425 .66689 L p .707 .577 .707 r
F P
0 g
s
.80425 .66689 m .80487 .63025 L .82601 .63787 L p .707 .577 .707 r
F P
0 g
s
.32972 .67142 m .33116 .63423 L .31004 .6274 L p .707 .577 .707 r
F P
0 g
s
.68763 .60862 m .68755 .55299 L .71691 .54959 L p .707 .577 .707 r
F P
0 g
s
.35285 .72298 m .35788 .74019 L .38792 .73538 L p .707 .577 .707 r
F P
0 g
s
.31571 .60773 m .31551 .55217 L .30287 .54429 L p .707 .577 .707 r
F P
0 g
s
.44207 .69764 m .4471 .71485 L .47045 .70114 L p .707 .577 .707 r
F P
0 g
s
.47045 .70114 m .46542 .68393 L .44207 .69764 L p .707 .577 .707 r
F P
0 g
s
.64482 .74195 m .64262 .72285 L .65874 .72078 L p .707 .577 .707 r
F P
0 g
s
.65874 .72078 m .66094 .73989 L .64482 .74195 L p .707 .577 .707 r
F P
0 g
s
.35788 .74019 m .35285 .72298 L .32645 .72341 L p .707 .577 .707 r
F P
0 g
s
.66041 .66882 m .66103 .63218 L .68501 .62612 L p .707 .577 .707 r
F P
0 g
s
.31004 .6274 m .3086 .66459 L .32972 .67142 L p .707 .577 .707 r
F P
0 g
s
.77992 .55058 m .78001 .60622 L .74882 .6044 L p .707 .577 .707 r
F P
0 g
s
.74882 .6044 m .74874 .54877 L .77992 .55058 L p .707 .577 .707 r
F P
0 g
s
.71699 .60523 m .71691 .54959 L .74874 .54877 L p .707 .577 .707 r
F P
0 g
s
.71691 .54959 m .71699 .60523 L .68763 .60862 L p .707 .577 .707 r
F P
0 g
s
.32645 .72341 m .33148 .74062 L .35788 .74019 L p .707 .577 .707 r
F P
0 g
s
.47492 .63603 m .47347 .67322 L .48974 .66686 L p .707 .577 .707 r
F P
0 g
s
.48974 .66686 m .49118 .62967 L .47492 .63603 L p .707 .577 .707 r
F P
0 g
s
.74874 .54877 m .74882 .6044 L .71699 .60523 L p .707 .577 .707 r
F P
0 g
s
.68501 .62612 m .68439 .66276 L .66041 .66882 L p .707 .577 .707 r
F P
0 g
s
.30287 .54429 m .30306 .59985 L .31571 .60773 L p .707 .577 .707 r
F P
0 g
s
.49681 .54703 m .497 .60259 L .50403 .59416 L p .707 .577 .707 r
F P
0 g
s
.50403 .59416 m .50383 .5386 L .49681 .54703 L p .707 .577 .707 r
F P
0 g
s
.80487 .63025 m .80425 .66689 L .77674 .66152 L p .707 .577 .707 r
F P
0 g
s
.77674 .66152 m .77736 .62488 L .80487 .63025 L p .707 .577 .707 r
F P
0 g
s
.46542 .68393 m .47045 .70114 L .48641 .68687 L p .707 .577 .707 r
F P
0 g
s
.48641 .68687 m .48138 .66966 L .46542 .68393 L p .707 .577 .707 r
F P
0 g
s
.3086 .66459 m .31004 .6274 L .29736 .61953 L p .707 .577 .707 r
F P
0 g
s
.82267 .702 m .82487 .72111 L .80383 .72335 L p .707 .577 .707 r
F P
0 g
s
.80383 .72335 m .80163 .70424 L .82267 .702 L p .707 .577 .707 r
F P
0 g
s
.33148 .74062 m .32645 .72341 L .30627 .7194 L p .707 .577 .707 r
F P
0 g
s
.68439 .66276 m .68501 .62612 L .71434 .62271 L p .707 .577 .707 r
F P
0 g
s
.30627 .7194 m .3113 .73661 L .33148 .74062 L p .707 .577 .707 r
F P
0 g
s
.29736 .61953 m .29592 .65672 L .3086 .66459 L p .707 .577 .707 r
F P
0 g
s
.30306 .59985 m .30287 .54429 L .29991 .53571 L p .707 .577 .707 r
F P
0 g
s
.66094 .73989 m .65874 .72078 L .68253 .71789 L p .707 .577 .707 r
F P
0 g
s
.68253 .71789 m .68472 .73699 L .66094 .73989 L p .707 .577 .707 r
F P
0 g
s
.77736 .62488 m .77674 .66152 L .74554 .65892 L p .707 .577 .707 r
F P
0 g
s
.74554 .65892 m .74616 .62228 L .77736 .62488 L p .707 .577 .707 r
F P
0 g
s
.71434 .62271 m .71372 .65935 L .68439 .66276 L p .707 .577 .707 r
F P
0 g
s
.71372 .65935 m .71434 .62271 L .74616 .62228 L p .707 .577 .707 r
F P
0 g
s
.49118 .62967 m .48974 .66686 L .49672 .65923 L p .707 .577 .707 r
F P
0 g
s
.49672 .65923 m .49816 .62204 L .49118 .62967 L p .707 .577 .707 r
F P
0 g
s
.74616 .62228 m .74554 .65892 L .71372 .65935 L p .707 .577 .707 r
F P
0 g
s
.48138 .66966 m .48641 .68687 L .49344 .67342 L p .707 .577 .707 r
F P
0 g
s
.49344 .67342 m .48841 .65622 L .48138 .66966 L p .707 .577 .707 r
F P
0 g
s
.80163 .70424 m .80383 .72335 L .77646 .72637 L p .707 .577 .707 r
F P
0 g
s
.77646 .72637 m .77427 .70727 L .80163 .70424 L p .707 .577 .707 r
F P
0 g
s
.29991 .53571 m .30011 .59127 L .30306 .59985 L p .707 .577 .707 r
F P
0 g
s
.3113 .73661 m .30627 .7194 L .29429 .71136 L p .707 .577 .707 r
F P
0 g
s
.50383 .5386 m .50403 .59416 L .50107 .58558 L p .707 .577 .707 r
F P
0 g
s
.50107 .58558 m .50088 .53002 L .50383 .5386 L p .707 .577 .707 r
F P
0 g
s
.29592 .65672 m .29736 .61953 L .29436 .61137 L p .707 .577 .707 r
F P
0 g
s
.68472 .73699 m .68253 .71789 L .71165 .71444 L p .707 .577 .707 r
F P
0 g
s
.71165 .71444 m .71385 .73355 L .68472 .73699 L p .707 .577 .707 r
F P
0 g
s
.29429 .71136 m .29932 .72856 L .3113 .73661 L p .707 .577 .707 r
F P
0 g
s
.29436 .61137 m .29292 .64857 L .29592 .65672 L p .707 .577 .707 r
F P
0 g
s
.30011 .59127 m .29991 .53571 L .30694 .52728 L p .707 .577 .707 r
F P
0 g
s
.77427 .70727 m .77646 .72637 L .74546 .72989 L p .707 .577 .707 r
F P
0 g
s
.74546 .72989 m .74326 .71078 L .77427 .70727 L p .707 .577 .707 r
F P
0 g
s
.71385 .73355 m .71165 .71444 L .74326 .71078 L p .707 .577 .707 r
F P
0 g
s
.74326 .71078 m .74546 .72989 L .71385 .73355 L p .707 .577 .707 r
F P
0 g
s
.49816 .62204 m .49672 .65923 L .49372 .65107 L p .707 .577 .707 r
F P
0 g
s
.49372 .65107 m .49516 .61388 L .49816 .62204 L p .707 .577 .707 r
F P
0 g
s
.48841 .65622 m .49344 .67342 L .49084 .66213 L p .707 .577 .707 r
F P
0 g
s
.49084 .66213 m .48581 .64492 L .48841 .65622 L p .707 .577 .707 r
F P
0 g
s
.29932 .72856 m .29429 .71136 L .29169 .70006 L p .707 .577 .707 r
F P
0 g
s
.30694 .52728 m .30713 .58284 L .30011 .59127 L p .707 .577 .707 r
F P
0 g
s
.50088 .53002 m .50107 .58558 L .48843 .5777 L p .707 .577 .707 r
F P
0 g
s
.48843 .5777 m .48823 .52214 L .50088 .53002 L p .707 .577 .707 r
F P
0 g
s
.29292 .64857 m .29436 .61137 L .30134 .60374 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29169 .70006 m .29672 .71727 L .29932 .72856 L p .707 .577 .707 r
F P
0 g
s
.30134 .60374 m .29989 .64094 L .29292 .64857 L p .707 .577 .707 r
F P
0 g
s
.30713 .58284 m .30694 .52728 L .32325 .51981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48581 .64492 m .49084 .66213 L .47886 .65408 L p .707 .577 .707 r
F P
0 g
s
.47886 .65408 m .47383 .63687 L .48581 .64492 L p .707 .577 .707 r
F P
0 g
s
.49516 .61388 m .49372 .65107 L .48104 .6432 L p .707 .577 .707 r
F P
0 g
s
.48104 .6432 m .48248 .60601 L .49516 .61388 L p .707 .577 .707 r
F P
0 g
s
.29672 .71727 m .29169 .70006 L .29872 .68661 L p .707 .577 .707 r
F P
0 g
s
.32325 .51981 m .32345 .57537 L .30713 .58284 L p .707 .577 .707 r
F P
0 g
s
.48823 .52214 m .48843 .5777 L .46733 .57129 L p .707 .577 .707 r
F P
0 g
s
.46733 .57129 m .46713 .51573 L .48823 .52214 L p .707 .577 .707 r
F P
0 g
s
.29989 .64094 m .30134 .60374 L .3176 .59738 L p .707 .577 .707 r
F P
0 g
s
.29872 .68661 m .30375 .70382 L .29672 .71727 L p .707 .577 .707 r
F P
0 g
s
.32345 .57537 m .32325 .51981 L .34727 .51404 L p .707 .577 .707 r
F P
0 g
s
.3176 .59738 m .31616 .63457 L .29989 .64094 L p .707 .577 .707 r
F P
0 g
s
.47383 .63687 m .47886 .65408 L .45868 .65007 L p .707 .577 .707 r
F P
0 g
s
.45868 .65007 m .45365 .63287 L .47383 .63687 L p .707 .577 .707 r
F P
0 g
s
.48248 .60601 m .48104 .6432 L .45992 .63637 L p .707 .577 .707 r
F P
0 g
s
.45992 .63637 m .46136 .59918 L .48248 .60601 L p .707 .577 .707 r
F P
0 g
s
.46713 .51573 m .46733 .57129 L .43984 .56698 L p .707 .577 .707 r
F P
0 g
s
.43984 .56698 m .43964 .51142 L .46713 .51573 L p .707 .577 .707 r
F P
0 g
s
.34727 .51404 m .34746 .5696 L .32345 .57537 L p .707 .577 .707 r
F P
0 g
s
.30375 .70382 m .29872 .68661 L .31468 .67234 L p .707 .577 .707 r
F P
0 g
s
.31616 .63457 m .3176 .59738 L .34157 .59291 L p .707 .577 .707 r
F P
0 g
s
.34746 .5696 m .34727 .51404 L .37663 .51053 L p .707 .577 .707 r
F P
0 g
s
.31468 .67234 m .31971 .68955 L .30375 .70382 L p .707 .577 .707 r
F P
0 g
s
.43964 .51142 m .43984 .56698 L .40865 .56519 L p .707 .577 .707 r
F P
0 g
s
.40865 .56519 m .40846 .50963 L .43964 .51142 L p .707 .577 .707 r
F P
0 g
s
.34157 .59291 m .34013 .6301 L .31616 .63457 L p .707 .577 .707 r
F P
0 g
s
.37682 .56609 m .37663 .51053 L .40846 .50963 L p .707 .577 .707 r
F P
0 g
s
.37663 .51053 m .37682 .56609 L .34746 .5696 L p .707 .577 .707 r
F P
0 g
s
.45365 .63287 m .45868 .65007 L .43228 .6505 L p .707 .577 .707 r
F P
0 g
s
.43228 .6505 m .42725 .63329 L .45365 .63287 L p .707 .577 .707 r
F P
0 g
s
.46136 .59918 m .45992 .63637 L .43243 .63126 L p .707 .577 .707 r
F P
0 g
s
.43243 .63126 m .43387 .59407 L .46136 .59918 L p .707 .577 .707 r
F P
0 g
s
.40846 .50963 m .40865 .56519 L .37682 .56609 L p .707 .577 .707 r
F P
0 g
s
.34013 .6301 m .34157 .59291 L .37089 .59077 L p .707 .577 .707 r
F P
0 g
s
.31971 .68955 m .31468 .67234 L .33803 .65864 L p .707 .577 .707 r
F P
0 g
s
.33803 .65864 m .34306 .67584 L .31971 .68955 L p .707 .577 .707 r
F P
0 g
s
.43387 .59407 m .43243 .63126 L .40125 .62836 L p .707 .577 .707 r
F P
0 g
s
.40125 .62836 m .4027 .59117 L .43387 .59407 L p .707 .577 .707 r
F P
0 g
s
.37089 .59077 m .36945 .62796 L .34013 .6301 L p .707 .577 .707 r
F P
0 g
s
.36945 .62796 m .37089 .59077 L .4027 .59117 L p .707 .577 .707 r
F P
0 g
s
.42725 .63329 m .43228 .6505 L .40224 .65531 L p .707 .577 .707 r
F P
0 g
s
.40224 .65531 m .39721 .63811 L .42725 .63329 L p .707 .577 .707 r
F P
0 g
s
.4027 .59117 m .40125 .62836 L .36945 .62796 L p .707 .577 .707 r
F P
0 g
s
.34306 .67584 m .33803 .65864 L .36646 .64684 L p .707 .577 .707 r
F P
0 g
s
.36646 .64684 m .37149 .66405 L .34306 .67584 L p .707 .577 .707 r
F P
0 g
s
.39721 .63811 m .40224 .65531 L .37149 .66405 L p .707 .577 .707 r
F P
0 g
s
.37149 .66405 m .36646 .64684 L .39721 .63811 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH:000;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`03001JEP0000P000AJEP04001JEUYFFUH80004FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005mo
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`@000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00008000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00FGoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001GOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00mooaT003aoo`00EGoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH6000fOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`02Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF009JEPX000QJEPP000=JEP03001JEUYF00=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000=JEP04001JEUYFFUH90008FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001E
Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP0200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo
0P000UYF00<005YFFUH00UYF7`0015YF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo0P000UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo0017Ool90006Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003ioo`T000AJEP03001JEUYF009JEPL000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000=JEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00=Woo200015YF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000eYF001JEP06FUH80004FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000bOol40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF0000;Goo000`Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH6
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF
001JEP02FUH00`00Oomoo`0[Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003
FUH00`00Oomoo`0[Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000=JEP00Ool0;7oo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEPT000AJEP04001JEUYFFUH60004FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000@000IJEP07001JEUYFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJ
EUYF2@000UYF00<005YFFUH00eYF1@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH50003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF2@000eYF00@005YFFUH000EJEPD0009JEPP00003
FUH0000000@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000eYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00000`000eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P00
1EYF00@005YFFUIJEPP000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF009J
EP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00001JEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03
001JEUYF009JEPD00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP@002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40008FUH0
0`00FUIJEP05FUH;0003FUH00`00FUIJEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP80009JEP03001JEUYF00MJEP03001JEUYF00@0
00MJEP04001JEUYFFUH300000eYF001JEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP04001JEUYF0005FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00=J
EPL000QJEPD000AJEPP000EJEP03001JEUYF008000MJEP03001JEUYF00@000MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH015YF0P0015YF100025YF0`00
0UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUH005YF008000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YF
FUH00eYF1P004Goo200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF0000
0eYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1P000UYF00<0
05YFFUH015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUH0000300000eYF001JEP02FUH00`00Oomoo`08Ool3000<Ool60004FUH0
1000FUIJEUYF0P00;Goo000/Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJEP04001JEUYFFUH20007FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000EJEP05001J
EUYFFUH00009Ool5000AOol300000eYF001JEP02FUH2000]Ool002aoo`03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000MJEP03001JEP00
008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH50004FUH0
1@00FUIJEUYF00002Goo1@004Woo10000eYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH90004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH7000015YF001JEP000UYF00<005YF00001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH50003FUH00`00Oomoo`07
Ool5000>Ool400001EYF001JEUYF00000UYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP04FUH2
0003FUH20002FUH00`00FUH0000A0008FUH20003FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
00Eoo`<000Yoo`D000EJEP04001JEUYFFUH4000]Ool002aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEPX000AJEP03001JEUYF009JEP03001JEUYF00<000AJEP80009JEP03
001JEUYF00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP02FUH50005FUH30002FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool01000FUIJEP001EYF2@000eYF00<005YFFUH01UYF
00<005YFFUH01EYF0P001EYF1P0015YF0P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Woo0`0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00@005YFFUH0009JEPL0009JEP03001JEUYF00AJEP<000IJEP03001JEUYF00=JEP80
00EJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YF
FUIJEP0000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP06001JEP00001JEP001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2000;Woo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJ
EUYF00001EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP<0
00AJEP03001JEUYF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH:0002FUH01000FUIJEUYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00L005YFFUIJEP00FUH0000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP`000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP08FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF0`001UYF00@005YFFUIJEPd0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP8000AJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00IJEPl000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000MJEP03001J
EP0000<0009JEP03001JEUYF00=JEP04001JEUYF0002FUH60008FUH00`00FUIJEP03FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP0>0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQH0
009JEP03001JEUYF00l000=JEP03001JEUYF00QJEP03001JEP00008000QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP`0031oo`00;Goo
00<005YF00000eYF00<005YFFUH00eYF1P000eYF00<005YFFUH01eYF00<005YFFUH015YF0`0000=J
EP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000hOol002eoo`03001J
EP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl003moo`00;Goo00<005YF
00000eYF0P001EYF00<005YFFUH00UYF200015YF00<005YFFUH01eYF100015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUH>0018Ool002eoo`04001JEP00FUH200000eYF001JEP03FUH70007FUH70006FUH01000
FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003
FUH01000FUIJEUYF3@00DGoo000]Ool01000FUH000000UYF00@005YFFUIJEP8000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEPl000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF3P000UYF0P00E7oo000]Ool30003FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH50007FUH01000FUIJEP0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00MJEQH000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002eoo`<000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF009JEP80009JEP04001JEUYF0006FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00E7oo000]Ool30002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
00000eYF001JEP05FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60002FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol002eoo`03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000006
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00D0
05YFFUIJEP0005Aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP<0009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP04001oogooOol60004FUH01@00FUIJEUYF0000E7oo000]Ool01000FUH0
07oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<0
07ooOol01goo0`0000=JEP00FUH00UYF00<007ooOol0DWoo000]Ool20005Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003Ool30002FUH01@00FUIJEP00FUH00P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<007ooOol017oo0`0000=JEP00FUH00P000eYF00<007ooOol0DWoo000]
Ool2000<OolK000<Ool01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
1`0015YF00@005YFFUIJEP800003FUH007oo05=oo`00;Goo0P006Goo0`0067oo00D005YF001JEP00
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00=JEP03001JEUYF009JEP<0
05Aoo`00;Goo0P0067oo1@0067oo0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Aoo`00;Goo0`005goo1@0067oo0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEP0005Aoo`00;Goo0P0000=JEP00Ool05Goo1@006Goo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYFFUH2001EOol002ioo`04
001JEUYF000FOol3000JOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00;Woo00D005YFFUIJEP0003=oo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP05001JEUYFFUH0
001FOol002moo`03001JEUYF00<0035oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000IJEP03001JEUYF00AJEP04001JEP00001GOol002moo`04001JEUYF0002FUH00`00Oomoo`0]
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP03FUH3001IOol0031o
o`8000AJEP8002eoo`80009oo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP80009JEP<0009JEP03001JEP0000<0
05aoo`00<7oo0P001UYF00<007ooOol0:Goo0`0017oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00<005YF
00000`00H7oo000aOol00`00FUIJEP04FUH3000WOol200000eYF001oo`06Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30008FUH0
1000FUIJEUYF0`00Ggoo000bOol20004FUH00`00FUIJEP02000SOol20002FUH20009Ool300000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP05FUH3001LOol003Aoo`04001JEUYF0005FUH2000OOol200001EYF001JEUYF0000
3Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000020000Woo
10000UYF00<005YFFUH01UYF00<005YF00000P00FGoo000eOol30007FUH5000HOol20003FUH01000
FUIJEP0057oo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF1`000UYF1`001Woo10001eYF00<0
05YFFUH00UYF0P00Egoo000gOol20007FUH01000FUIJEUYF2@002Goo1P0015YF00@005YFFUH0021o
oaX000=JEP03001JEUYF00EJEPD000Yoo`8000AJEP03001JEUYF00AJEP8005Ioo`00>Goo0P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF0`00>Woo0`0000=JEP00FUH0
1eYF0`0000=JEP0000000P0027oo0`0000=JEP00FUH015YF00@005YFFUH005Eoo`00>goo0`0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00?goo0`001eYF00<0
05YFFUH01EYF1P001Goo0P001EYF00D005YFFUIJEP0005Aoo`00?Woo10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8004Aoo`8000EJEP03001JEUYF00MJEP04001JEUYFFUH90003
FUH01000FUIJEUYF0P00Dgoo0012Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0
0000B7oo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01@0015YF0P00Dgoo0016Ool7
0004FUH00`00FUIJEP02FUH5001=Ool40007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2
001DOol004eoo`T005Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP02
001DOol00;1oo`@000MJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00]7oo10000UYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH0001EOol00;Qooa0005Eoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58839 .75016 m .58871 .69454 L .55751 .69252 L p .707 .577 .707 r
F P
0 g
s
.58871 .69454 m .58839 .75016 L .62022 .74953 L p .707 .577 .707 r
F P
0 g
s
.62022 .74953 m .62053 .69391 L .58871 .69454 L p .707 .577 .707 r
F P
0 g
s
.62053 .69391 m .62022 .74953 L .64956 .74631 L p .707 .577 .707 r
F P
0 g
s
.64956 .74631 m .64988 .6907 L .62053 .69391 L p .707 .577 .707 r
F P
0 g
s
.5572 .74813 m .55751 .69252 L .53001 .68804 L p .707 .577 .707 r
F P
0 g
s
.55751 .69252 m .5572 .74813 L .58839 .75016 L p .707 .577 .707 r
F P
0 g
s
.64988 .6907 m .64956 .74631 L .67355 .74082 L p .707 .577 .707 r
F P
0 g
s
.67355 .74082 m .67387 .6852 L .64988 .6907 L p .707 .577 .707 r
F P
0 g
s
.53001 .68804 m .52969 .74365 L .5572 .74813 L p .707 .577 .707 r
F P
0 g
s
.52969 .74365 m .53001 .68804 L .50888 .68154 L p .707 .577 .707 r
F P
0 g
s
.60036 .81233 m .59802 .77563 L .56687 .77541 L p .707 .577 .707 r
F P
0 g
s
.59802 .77563 m .60036 .81233 L .63212 .80959 L p .707 .577 .707 r
F P
0 g
s
.63212 .80959 m .62978 .77288 L .59802 .77563 L p .707 .577 .707 r
F P
0 g
s
.62978 .77288 m .63212 .80959 L .66138 .80414 L p .707 .577 .707 r
F P
0 g
s
.66138 .80414 m .65904 .76744 L .62978 .77288 L p .707 .577 .707 r
F P
0 g
s
.56921 .81211 m .56687 .77541 L .53938 .77225 L p .707 .577 .707 r
F P
0 g
s
.56687 .77541 m .56921 .81211 L .60036 .81233 L p .707 .577 .707 r
F P
0 g
s
.67387 .6852 m .67355 .74082 L .68983 .73359 L p .707 .577 .707 r
F P
0 g
s
.68983 .73359 m .69015 .67797 L .67387 .6852 L p .707 .577 .707 r
F P
0 g
s
.50888 .68154 m .50856 .73716 L .52969 .74365 L p .707 .577 .707 r
F P
0 g
s
.65904 .76744 m .66138 .80414 L .68528 .79654 L p .707 .577 .707 r
F P
0 g
s
.68528 .79654 m .68294 .75983 L .65904 .76744 L p .707 .577 .707 r
F P
0 g
s
.59854 .82865 m .60651 .81122 L .57825 .79772 L p .707 .577 .707 r
F P
0 g
s
.60651 .81122 m .59854 .82865 L .62755 .84159 L p .707 .577 .707 r
F P
0 g
s
.62755 .84159 m .63552 .82416 L .60651 .81122 L p .707 .577 .707 r
F P
0 g
s
.57825 .79772 m .57028 .81515 L .59854 .82865 L p .707 .577 .707 r
F P
0 g
s
.53938 .77225 m .54171 .80895 L .56921 .81211 L p .707 .577 .707 r
F P
0 g
s
.50856 .73716 m .50888 .68154 L .4962 .67367 L p .707 .577 .707 r
F P
0 g
s
.63552 .82416 m .62755 .84159 L .65448 .85271 L p .707 .577 .707 r
F P
0 g
s
.65448 .85271 m .66245 .83528 L .63552 .82416 L p .707 .577 .707 r
F P
0 g
s
.57028 .81515 m .57825 .79772 L .55351 .78498 L p .707 .577 .707 r
F P
0 g
s
.54171 .80895 m .53938 .77225 L .51824 .76645 L p .707 .577 .707 r
F P
0 g
s
.55351 .78498 m .54554 .80241 L .57028 .81515 L p .707 .577 .707 r
F P
0 g
s
.66245 .83528 m .65448 .85271 L .67669 .86091 L p .707 .577 .707 r
F P
0 g
s
.67669 .86091 m .68466 .84348 L .66245 .83528 L p .707 .577 .707 r
F P
0 g
s
.68294 .75983 m .68528 .79654 L .70148 .78751 L p .707 .577 .707 r
F P
0 g
s
.70148 .78751 m .69914 .75081 L .68294 .75983 L p .707 .577 .707 r
F P
0 g
s
.4962 .67367 m .49588 .72929 L .50856 .73716 L p .707 .577 .707 r
F P
0 g
s
.51824 .76645 m .52057 .80315 L .54171 .80895 L p .707 .577 .707 r
F P
0 g
s
.69015 .67797 m .68983 .73359 L .69682 .72533 L p .707 .577 .707 r
F P
0 g
s
.69682 .72533 m .69714 .66971 L .69015 .67797 L p .707 .577 .707 r
F P
0 g
s
.54554 .80241 m .55351 .78498 L .53472 .77425 L p .707 .577 .707 r
F P
0 g
s
.53472 .77425 m .52675 .79168 L .54554 .80241 L p .707 .577 .707 r
F P
0 g
s
.52057 .80315 m .51824 .76645 L .50551 .75858 L p .707 .577 .707 r
F P
0 g
s
.49588 .72929 m .4962 .67367 L .49321 .66519 L p .707 .577 .707 r
F P
0 g
s
.68466 .84348 m .67669 .86091 L .692 .8654 L p .707 .577 .707 r
F P
0 g
s
.692 .8654 m .69997 .84797 L .68466 .84348 L p .707 .577 .707 r
F P
0 g
s
.50551 .75858 m .50785 .79529 L .52057 .80315 L p .707 .577 .707 r
F P
0 g
s
.69914 .75081 m .70148 .78751 L .70838 .77795 L p .707 .577 .707 r
F P
0 g
s
.70838 .77795 m .70605 .74125 L .69914 .75081 L p .707 .577 .707 r
F P
0 g
s
.52675 .79168 m .53472 .77425 L .5237 .76659 L p .707 .577 .707 r
F P
0 g
s
.49321 .66519 m .49289 .7208 L .49588 .72929 L p .707 .577 .707 r
F P
0 g
s
.5237 .76659 m .51573 .78402 L .52675 .79168 L p .707 .577 .707 r
F P
0 g
s
.69714 .66971 m .69682 .72533 L .69383 .71684 L p .707 .577 .707 r
F P
0 g
s
.69383 .71684 m .69415 .66123 L .69714 .66971 L p .707 .577 .707 r
F P
0 g
s
.50785 .79529 m .50551 .75858 L .50246 .74942 L p .707 .577 .707 r
F P
0 g
s
.49289 .7208 m .49321 .66519 L .5002 .65692 L p .707 .577 .707 r
F P
0 g
s
.48571 .82173 m .48571 .31984 L .44205 .31677 L p .707 .577 .707 r
F P
0 g
s
.50246 .74942 m .50479 .78613 L .50785 .79529 L p .707 .577 .707 r
F P
0 g
s
.51573 .78402 m .5237 .76659 L .52155 .76273 L p .707 .577 .707 r
F P
0 g
s
.52155 .76273 m .51358 .78016 L .51573 .78402 L p .707 .577 .707 r
F P
0 g
s
.5002 .65692 m .49988 .71254 L .49289 .7208 L p .707 .577 .707 r
F P
0 g
s
.50479 .78613 m .50246 .74942 L .50937 .73986 L p .707 .577 .707 r
F P
0 g
s
.49988 .71254 m .5002 .65692 L .51648 .64969 L p .707 .577 .707 r
F P
0 g
s
.50937 .73986 m .5117 .77656 L .50479 .78613 L p .707 .577 .707 r
F P
0 g
s
.51358 .78016 m .52155 .76273 L .52846 .76306 L p .707 .577 .707 r
F P
0 g
s
.51648 .64969 m .51617 .70531 L .49988 .71254 L p .707 .577 .707 r
F P
0 g
s
.52846 .76306 m .52049 .78049 L .51358 .78016 L p .707 .577 .707 r
F P
0 g
s
.51617 .70531 m .51648 .64969 L .54047 .6442 L p .707 .577 .707 r
F P
0 g
s
.5117 .77656 m .50937 .73986 L .52556 .73083 L p .707 .577 .707 r
F P
0 g
s
.52049 .78049 m .52846 .76306 L .54378 .76755 L p .707 .577 .707 r
F P
0 g
s
.52556 .73083 m .5279 .76754 L .5117 .77656 L p .707 .577 .707 r
F P
0 g
s
.54047 .6442 m .54015 .69982 L .51617 .70531 L p .707 .577 .707 r
F P
0 g
s
.54378 .76755 m .53581 .78498 L .52049 .78049 L p .707 .577 .707 r
F P
0 g
s
.48571 .31984 m .48571 .82173 L .53076 .82103 L p .707 .577 .707 r
F P
0 g
s
.5279 .76754 m .52556 .73083 L .54946 .72323 L p .707 .577 .707 r
F P
0 g
s
.54946 .72323 m .5518 .75993 L .5279 .76754 L p .707 .577 .707 r
F P
0 g
s
.53076 .82103 m .53076 .31914 L .48571 .31984 L p .707 .577 .707 r
F P
0 g
s
.54015 .69982 m .54047 .6442 L .56982 .64098 L p .707 .577 .707 r
F P
0 g
s
.56982 .64098 m .5695 .6966 L .54015 .69982 L p .707 .577 .707 r
F P
0 g
s
.5518 .75993 m .54946 .72323 L .57872 .71778 L p .707 .577 .707 r
F P
0 g
s
.53581 .78498 m .54378 .76755 L .56598 .77575 L p .707 .577 .707 r
F P
0 g
s
.56598 .77575 m .55801 .79318 L .53581 .78498 L p .707 .577 .707 r
F P
0 g
s
.57872 .71778 m .58106 .75449 L .5518 .75993 L p .707 .577 .707 r
F P
0 g
s
.55801 .79318 m .56598 .77575 L .59291 .78687 L p .707 .577 .707 r
F P
0 g
s
.59291 .78687 m .58494 .8043 L .55801 .79318 L p .707 .577 .707 r
F P
0 g
s
.53076 .31914 m .53076 .82103 L .5728 .81663 L p .707 .577 .707 r
F P
0 g
s
.5695 .6966 m .56982 .64098 L .60164 .64035 L p .707 .577 .707 r
F P
0 g
s
.60164 .64035 m .60132 .69597 L .5695 .6966 L p .707 .577 .707 r
F P
0 g
s
.5728 .81663 m .5728 .31474 L .53076 .31914 L p .707 .577 .707 r
F P
0 g
s
.69997 .84797 m .692 .8654 L .69891 .86573 L p .707 .577 .707 r
F P
0 g
s
.69891 .86573 m .70688 .8483 L .69997 .84797 L p .707 .577 .707 r
F P
0 g
s
.44205 .81866 m .44205 .31677 L .40407 .31023 L p .707 .577 .707 r
F P
0 g
s
.44205 .31677 m .44205 .81866 L .48571 .82173 L p .707 .577 .707 r
F P
0 g
s
.70605 .74125 m .70838 .77795 L .70533 .76879 L p .707 .577 .707 r
F P
0 g
s
.70533 .76879 m .70299 .73208 L .70605 .74125 L p .707 .577 .707 r
F P
0 g
s
.69415 .66123 m .69383 .71684 L .68115 .70897 L p .707 .577 .707 r
F P
0 g
s
.68115 .70897 m .68147 .65335 L .69415 .66123 L p .707 .577 .707 r
F P
0 g
s
.58106 .75449 m .57872 .71778 L .61049 .71504 L p .707 .577 .707 r
F P
0 g
s
.61049 .71504 m .61282 .75174 L .58106 .75449 L p .707 .577 .707 r
F P
0 g
s
.58494 .8043 m .59291 .78687 L .62192 .79981 L p .707 .577 .707 r
F P
0 g
s
.62192 .79981 m .61395 .81724 L .58494 .8043 L p .707 .577 .707 r
F P
0 g
s
.5728 .31474 m .5728 .81663 L .60772 .80896 L p .707 .577 .707 r
F P
0 g
s
.63283 .64238 m .63252 .698 L .60132 .69597 L p .707 .577 .707 r
F P
0 g
s
.60132 .69597 m .60164 .64035 L .63283 .64238 L p .707 .577 .707 r
F P
0 g
s
.60772 .80896 m .60772 .30707 L .5728 .31474 L p .707 .577 .707 r
F P
0 g
s
.40407 .81212 m .40407 .31023 L .37547 .30087 L p .707 .577 .707 r
F P
0 g
s
.40407 .31023 m .40407 .81212 L .44205 .81866 L p .707 .577 .707 r
F P
0 g
s
.70688 .8483 m .69891 .86573 L .69676 .86188 L p .707 .577 .707 r
F P
0 g
s
.69676 .86188 m .70473 .84444 L .70688 .8483 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24998 .71105 m .25011 .65555 L .21892 .65357 L p .707 .577 .707 r
F P
0 g
s
.25011 .65555 m .24998 .71105 L .2818 .7103 L p .707 .577 .707 r
F P
0 g
s
.2818 .7103 m .28194 .65481 L .25011 .65555 L p .707 .577 .707 r
F P
0 g
s
.28194 .65481 m .2818 .7103 L .31115 .7069 L p .707 .577 .707 r
F P
0 g
s
.31115 .7069 m .31128 .65141 L .28194 .65481 L p .707 .577 .707 r
F P
0 g
s
.70299 .73208 m .70533 .76879 L .69261 .76092 L p .707 .577 .707 r
F P
0 g
s
.69261 .76092 m .69027 .72422 L .70299 .73208 L p .707 .577 .707 r
F P
0 g
s
.21878 .70907 m .21892 .65357 L .19141 .64905 L p .707 .577 .707 r
F P
0 g
s
.21892 .65357 m .21878 .70907 L .24998 .71105 L p .707 .577 .707 r
F P
0 g
s
.64164 .71526 m .64397 .75196 L .61282 .75174 L p .707 .577 .707 r
F P
0 g
s
.61282 .75174 m .61049 .71504 L .64164 .71526 L p .707 .577 .707 r
F P
0 g
s
.61395 .81724 m .62192 .79981 L .65018 .81331 L p .707 .577 .707 r
F P
0 g
s
.60772 .30707 m .60772 .80896 L .63209 .79877 L p .707 .577 .707 r
F P
0 g
s
.63209 .79877 m .63209 .29688 L .60772 .30707 L p .707 .577 .707 r
F P
0 g
s
.68147 .65335 m .68115 .70897 L .66002 .70248 L p .707 .577 .707 r
F P
0 g
s
.66002 .70248 m .66034 .64686 L .68147 .65335 L p .707 .577 .707 r
F P
0 g
s
.25529 .76817 m .25429 .73058 L .22309 .72993 L p .707 .577 .707 r
F P
0 g
s
.25429 .73058 m .25529 .76817 L .2871 .76672 L p .707 .577 .707 r
F P
0 g
s
.2871 .76672 m .2861 .72912 L .25429 .73058 L p .707 .577 .707 r
F P
0 g
s
.2861 .72912 m .2871 .76672 L .3164 .76329 L p .707 .577 .707 r
F P
0 g
s
.3164 .76329 m .3154 .72569 L .2861 .72912 L p .707 .577 .707 r
F P
0 g
s
.31128 .65141 m .31115 .7069 L .33514 .70118 L p .707 .577 .707 r
F P
0 g
s
.33514 .70118 m .33527 .64568 L .31128 .65141 L p .707 .577 .707 r
F P
0 g
s
.22409 .76752 m .22309 .72993 L .19554 .72723 L p .707 .577 .707 r
F P
0 g
s
.22309 .72993 m .22409 .76752 L .25529 .76817 L p .707 .577 .707 r
F P
0 g
s
.19128 .70455 m .19141 .64905 L .17029 .64244 L p .707 .577 .707 r
F P
0 g
s
.19141 .64905 m .19128 .70455 L .21878 .70907 L p .707 .577 .707 r
F P
0 g
s
.19554 .72723 m .19655 .76483 L .22409 .76752 L p .707 .577 .707 r
F P
0 g
s
.3154 .72569 m .3164 .76329 L .34032 .75824 L p .707 .577 .707 r
F P
0 g
s
.34032 .75824 m .33932 .72064 L .3154 .72569 L p .707 .577 .707 r
F P
0 g
s
.70473 .84444 m .69676 .86188 L .68575 .85421 L p .707 .577 .707 r
F P
0 g
s
.68575 .85421 m .69372 .83678 L .70473 .84444 L p .707 .577 .707 r
F P
0 g
s
.37547 .80275 m .37547 .30087 L .35907 .28958 L p .707 .577 .707 r
F P
0 g
s
.37547 .30087 m .37547 .80275 L .40407 .81212 L p .707 .577 .707 r
F P
0 g
s
.66034 .64686 m .66002 .70248 L .63252 .698 L p .707 .577 .707 r
F P
0 g
s
.63252 .698 m .63283 .64238 L .66034 .64686 L p .707 .577 .707 r
F P
0 g
s
.69027 .72422 m .69261 .76092 L .67146 .75512 L p .707 .577 .707 r
F P
0 g
s
.67146 .75512 m .66913 .71842 L .69027 .72422 L p .707 .577 .707 r
F P
0 g
s
.19655 .76483 m .19554 .72723 L .17436 .72276 L p .707 .577 .707 r
F P
0 g
s
.33527 .64568 m .33514 .70118 L .35142 .69369 L p .707 .577 .707 r
F P
0 g
s
.35142 .69369 m .35156 .63819 L .33527 .64568 L p .707 .577 .707 r
F P
0 g
s
.17029 .64244 m .17015 .69794 L .19128 .70455 L p .707 .577 .707 r
F P
0 g
s
.25599 .85217 m .25958 .83767 L .22886 .82893 L p .707 .577 .707 r
F P
0 g
s
.25958 .83767 m .25599 .85217 L .28722 .85458 L p .707 .577 .707 r
F P
0 g
s
.28722 .85458 m .29081 .84008 L .25958 .83767 L p .707 .577 .707 r
F P
0 g
s
.22527 .84342 m .22886 .82893 L .20167 .81471 L p .707 .577 .707 r
F P
0 g
s
.22886 .82893 m .22527 .84342 L .25599 .85217 L p .707 .577 .707 r
F P
0 g
s
.17436 .72276 m .17536 .76035 L .19655 .76483 L p .707 .577 .707 r
F P
0 g
s
.64397 .75196 m .64164 .71526 L .66913 .71842 L p .707 .577 .707 r
F P
0 g
s
.63209 .29688 m .63209 .79877 L .64353 .78705 L p .707 .577 .707 r
F P
0 g
s
.64353 .78705 m .64353 .28516 L .63209 .29688 L p .707 .577 .707 r
F P
0 g
s
.17015 .69794 m .17029 .64244 L .1576 .63438 L p .707 .577 .707 r
F P
0 g
s
.29081 .84008 m .28722 .85458 L .31591 .85042 L p .707 .577 .707 r
F P
0 g
s
.31591 .85042 m .3195 .83593 L .29081 .84008 L p .707 .577 .707 r
F P
0 g
s
.33932 .72064 m .34032 .75824 L .35653 .75205 L p .707 .577 .707 r
F P
0 g
s
.35653 .75205 m .35552 .71445 L .33932 .72064 L p .707 .577 .707 r
F P
0 g
s
.19807 .8292 m .20167 .81471 L .18065 .7964 L p .707 .577 .707 r
F P
0 g
s
.20167 .81471 m .19807 .8292 L .22527 .84342 L p .707 .577 .707 r
F P
0 g
s
.66913 .71842 m .67146 .75512 L .64397 .75196 L p .707 .577 .707 r
F P
0 g
s
.17536 .76035 m .17436 .72276 L .1616 .71694 L p .707 .577 .707 r
F P
0 g
s
.69372 .83678 m .68575 .85421 L .66695 .84348 L p .707 .577 .707 r
F P
0 g
s
.66695 .84348 m .67492 .82605 L .69372 .83678 L p .707 .577 .707 r
F P
0 g
s
.3195 .83593 m .31591 .85042 L .33925 .8401 L p .707 .577 .707 r
F P
0 g
s
.33925 .8401 m .34284 .82561 L .3195 .83593 L p .707 .577 .707 r
F P
0 g
s
.1576 .63438 m .15747 .68988 L .17015 .69794 L p .707 .577 .707 r
F P
0 g
s
.35156 .63819 m .35142 .69369 L .35841 .68517 L p .707 .577 .707 r
F P
0 g
s
.35841 .68517 m .35855 .62967 L .35156 .63819 L p .707 .577 .707 r
F P
0 g
s
.18065 .7964 m .17706 .8109 L .19807 .8292 L p .707 .577 .707 r
F P
0 g
s
.17706 .8109 m .18065 .7964 L .16788 .77581 L p .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16788 .77581 L .16766 .77442 L p .707 .577 .707 r
F P
0 g
s
.1616 .71694 m .1626 .75453 L .17175 .75871 L p .707 .577 .707 r
F P
0 g
s
.16766 .77442 m .16459 .75493 L p .16431 .78729 L .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16766 .77442 L .16431 .78729 L .707 .577 .707 r
F
.17175 .75871 m .17536 .76035 L p .17314 .75336 L F P
0 g
s
.17314 .75336 m .1616 .71694 L .17175 .75871 L .707 .577 .707 r
F
.35552 .71445 m .35653 .75205 L .36343 .74533 L p F P
0 g
s
.36343 .74533 m .36242 .70773 L .35552 .71445 L p .707 .577 .707 r
F P
0 g
s
.35855 .62967 m .35841 .68517 L .35542 .67645 L p .707 .577 .707 r
F P
0 g
s
.35542 .67645 m .35556 .62096 L .35855 .62967 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .36507 .79103 L .35854 .81013 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .35819 .78465 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36507 .79103 m .36353 .79722 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36353 .79722 m .36147 .80552 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35646 .27749 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36178 .77015 L .36235 .77375 L p .707 .577 .707 r
F P
0 g
s
.36235 .77375 m .36507 .79103 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36235 .77375 L .36313 .78923 L .707 .577 .707 r
F
.35934 .70114 m .36035 .73874 L .34759 .73292 L p F P
0 g
s
.34759 .73292 m .34658 .69532 L .35934 .70114 L p .707 .577 .707 r
F P
0 g
s
.36178 .77015 m .35819 .78465 L .34542 .76405 L p .707 .577 .707 r
F P
0 g
s
.34542 .76405 m .34901 .74955 L .36178 .77015 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35907 .79147 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .27749 m .35646 .65696 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .65696 m .35646 .77938 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .79147 m .35907 .70871 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .70871 m .35907 .28958 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.36242 .70773 m .36343 .74533 L .36035 .73874 L p .707 .577 .707 r
F P
0 g
s
.36035 .73874 m .35934 .70114 L .36242 .70773 L p .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35907 .79147 L .37547 .80275 L p .707 .577 .707 r
F P
0 g
s
.15747 .68988 m .1576 .63438 L .15461 .62567 L p .707 .577 .707 r
F P
0 g
s
.16788 .77581 m .16428 .7903 L .17706 .8109 L p .707 .577 .707 r
F P
0 g
s
.34284 .82561 m .33925 .8401 L .35495 .82463 L p .707 .577 .707 r
F P
0 g
s
.35495 .82463 m .35854 .81013 L .34284 .82561 L p .707 .577 .707 r
F P
0 g
s
.67492 .82605 m .66695 .84348 L .64221 .83074 L p .707 .577 .707 r
F P
0 g
s
.64221 .83074 m .65018 .81331 L .67492 .82605 L p .707 .577 .707 r
F P
0 g
s
.64353 .28516 m .64353 .78705 L .64093 .77496 L p .707 .577 .707 r
F P
0 g
s
.64093 .77496 m .64093 .27308 L .64353 .28516 L p .707 .577 .707 r
F P
0 g
s
.1626 .75453 m .1616 .71694 L .15852 .71034 L p .707 .577 .707 r
F P
0 g
s
.15461 .62567 m .15448 .68116 L .15747 .68988 L p .707 .577 .707 r
F P
0 g
s
.15852 .71034 m .15952 .74794 L .1626 .75453 L p .707 .577 .707 r
F P
0 g
s
.65018 .81331 m .64221 .83074 L .61395 .81724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16459 .75493 m .161 .76942 L .16428 .7903 L p .707 .577 .707 r
F P
0 g
s
.35854 .81013 m .35495 .82463 L .36147 .80552 L p .707 .577 .707 r
F P
0 g
s
.15448 .68116 m .15461 .62567 L .1616 .61715 L p .707 .577 .707 r
F P
0 g
s
.161 .76942 m .16459 .75493 L .17112 .73582 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35646 .27749 L .36791 .26578 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15952 .74794 m .15852 .71034 L .16542 .70362 L p .707 .577 .707 r
F P
0 g
s
.1616 .61715 m .16146 .67265 L .15448 .68116 L p .707 .577 .707 r
F P
0 g
s
.35556 .62096 m .35542 .67645 L .34274 .66839 L p .707 .577 .707 r
F P
0 g
s
.34274 .66839 m .34288 .6129 L .35556 .62096 L p .707 .577 .707 r
F P
0 g
s
.17112 .73582 m .16753 .75032 L .161 .76942 L p .707 .577 .707 r
F P
0 g
s
.16542 .70362 m .16642 .74122 L .15952 .74794 L p .707 .577 .707 r
F P
0 g
s
.64093 .27308 m .64093 .77496 L .62452 .76368 L p .707 .577 .707 r
F P
0 g
s
.62452 .76368 m .62452 .26179 L .64093 .27308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16146 .67265 m .1616 .61715 L .17789 .60966 L p .707 .577 .707 r
F P
0 g
s
.16753 .75032 m .17112 .73582 L .18682 .72035 L p .707 .577 .707 r
F P
0 g
s
.18682 .72035 m .18323 .73484 L .16753 .75032 L p .707 .577 .707 r
F P
0 g
s
.16642 .74122 m .16542 .70362 L .18162 .69743 L p .707 .577 .707 r
F P
0 g
s
.17789 .60966 m .17775 .66516 L .16146 .67265 L p .707 .577 .707 r
F P
0 g
s
.34288 .6129 m .34274 .66839 L .32161 .66178 L p .707 .577 .707 r
F P
0 g
s
.32161 .66178 m .32175 .60629 L .34288 .6129 L p .707 .577 .707 r
F P
0 g
s
.36791 .76767 m .36791 .26578 L .39228 .25559 L p .707 .577 .707 r
F P
0 g
s
.36791 .26578 m .36791 .76767 L .35646 .77938 L p .707 .577 .707 r
F P
0 g
s
.18162 .69743 m .18263 .73503 L .16642 .74122 L p .707 .577 .707 r
F P
0 g
s
.18323 .73484 m .18682 .72035 L .21016 .71003 L p .707 .577 .707 r
F P
0 g
s
.17775 .66516 m .17789 .60966 L .20188 .60393 L p .707 .577 .707 r
F P
0 g
s
.34658 .69532 m .34759 .73292 L .3264 .72844 L p .707 .577 .707 r
F P
0 g
s
.3264 .72844 m .3254 .69084 L .34658 .69532 L p .707 .577 .707 r
F P
0 g
s
.62452 .26179 m .62452 .76368 L .59593 .75431 L p .707 .577 .707 r
F P
0 g
s
.59593 .75431 m .59593 .25242 L .62452 .26179 L p .707 .577 .707 r
F P
0 g
s
.21016 .71003 m .20656 .72452 L .18323 .73484 L p .707 .577 .707 r
F P
0 g
s
.34901 .74955 m .34542 .76405 L .3244 .74574 L p .707 .577 .707 r
F P
0 g
s
.3244 .74574 m .32799 .73125 L .34901 .74955 L p .707 .577 .707 r
F P
0 g
s
.32175 .60629 m .32161 .66178 L .2941 .65726 L p .707 .577 .707 r
F P
0 g
s
.2941 .65726 m .29424 .60177 L .32175 .60629 L p .707 .577 .707 r
F P
0 g
s
.18263 .73503 m .18162 .69743 L .20554 .69238 L p .707 .577 .707 r
F P
0 g
s
.20188 .60393 m .20174 .65943 L .17775 .66516 L p .707 .577 .707 r
F P
0 g
s
.20656 .72452 m .21016 .71003 L .23885 .70587 L p .707 .577 .707 r
F P
0 g
s
.20174 .65943 m .20188 .60393 L .23122 .60053 L p .707 .577 .707 r
F P
0 g
s
.73709 .6591 m .73695 .60343 L .70576 .60166 L p .707 .577 .707 r
F P
0 g
s
.73695 .60343 m .73709 .6591 L .76891 .65824 L p .707 .577 .707 r
F P
0 g
s
.76891 .65824 m .76878 .60257 L .73695 .60343 L p .707 .577 .707 r
F P
0 g
s
.20554 .69238 m .20655 .72998 L .18263 .73503 L p .707 .577 .707 r
F P
0 g
s
.76878 .60257 m .76891 .65824 L .79826 .65483 L p .707 .577 .707 r
F P
0 g
s
.79826 .65483 m .79812 .59917 L .76878 .60257 L p .707 .577 .707 r
F P
0 g
s
.32799 .73125 m .3244 .74574 L .2972 .73152 L p .707 .577 .707 r
F P
0 g
s
.2972 .73152 m .3008 .71703 L .32799 .73125 L p .707 .577 .707 r
F P
0 g
s
.3254 .69084 m .3264 .72844 L .29886 .72574 L p .707 .577 .707 r
F P
0 g
s
.3008 .71703 m .2972 .73152 L .26648 .72278 L p .707 .577 .707 r
F P
0 g
s
.26648 .72278 m .27008 .70828 L .3008 .71703 L p .707 .577 .707 r
F P
0 g
s
.29886 .72574 m .29785 .68815 L .3254 .69084 L p .707 .577 .707 r
F P
0 g
s
.29424 .60177 m .2941 .65726 L .26291 .65528 L p .707 .577 .707 r
F P
0 g
s
.26291 .65528 m .26305 .59978 L .29424 .60177 L p .707 .577 .707 r
F P
0 g
s
.70589 .65733 m .70576 .60166 L .67825 .59744 L p .707 .577 .707 r
F P
0 g
s
.70576 .60166 m .70589 .65733 L .73709 .6591 L p .707 .577 .707 r
F P
0 g
s
.23885 .70587 m .23525 .72037 L .20656 .72452 L p .707 .577 .707 r
F P
0 g
s
.23525 .72037 m .23885 .70587 L .27008 .70828 L p .707 .577 .707 r
F P
0 g
s
.39228 .25559 m .39228 .75748 L .36791 .76767 L p .707 .577 .707 r
F P
0 g
s
.39228 .75748 m .39228 .25559 L .42719 .24792 L p .707 .577 .707 r
F P
0 g
s
.23108 .65603 m .23122 .60053 L .26305 .59978 L p .707 .577 .707 r
F P
0 g
s
.23122 .60053 m .23108 .65603 L .20174 .65943 L p .707 .577 .707 r
F P
0 g
s
.20655 .72998 m .20554 .69238 L .23484 .68896 L p .707 .577 .707 r
F P
0 g
s
.26305 .59978 m .26291 .65528 L .23108 .65603 L p .707 .577 .707 r
F P
0 g
s
.27008 .70828 m .26648 .72278 L .23525 .72037 L p .707 .577 .707 r
F P
0 g
s
.79812 .59917 m .79826 .65483 L .82225 .64922 L p .707 .577 .707 r
F P
0 g
s
.82225 .64922 m .82211 .59356 L .79812 .59917 L p .707 .577 .707 r
F P
0 g
s
.23484 .68896 m .23585 .72655 L .20655 .72998 L p .707 .577 .707 r
F P
0 g
s
.29785 .68815 m .29886 .72574 L .26766 .72509 L p .707 .577 .707 r
F P
0 g
s
.26766 .72509 m .26665 .6875 L .29785 .68815 L p .707 .577 .707 r
F P
0 g
s
.59593 .25242 m .59593 .75431 L .55795 .74777 L p .707 .577 .707 r
F P
0 g
s
.55795 .74777 m .55795 .24588 L .59593 .25242 L p .707 .577 .707 r
F P
0 g
s
.67825 .59744 m .67839 .65311 L .70589 .65733 L p .707 .577 .707 r
F P
0 g
s
.67839 .65311 m .67825 .59744 L .65712 .59118 L p .707 .577 .707 r
F P
0 g
s
.23585 .72655 m .23484 .68896 L .26665 .6875 L p .707 .577 .707 r
F P
0 g
s
.26665 .6875 m .26766 .72509 L .23585 .72655 L p .707 .577 .707 r
F P
0 g
s
.73234 .72253 m .73335 .68618 L .70214 .68316 L p .707 .577 .707 r
F P
0 g
s
.73335 .68618 m .73234 .72253 L .76415 .72231 L p .707 .577 .707 r
F P
0 g
s
.76415 .72231 m .76515 .68596 L .73335 .68618 L p .707 .577 .707 r
F P
0 g
s
.82211 .59356 m .82225 .64922 L .83853 .64195 L p .707 .577 .707 r
F P
0 g
s
.83853 .64195 m .8384 .58628 L .82211 .59356 L p .707 .577 .707 r
F P
0 g
s
.76515 .68596 m .76415 .72231 L .79345 .71888 L p .707 .577 .707 r
F P
0 g
s
.79345 .71888 m .79445 .68253 L .76515 .68596 L p .707 .577 .707 r
F P
0 g
s
.42719 .74981 m .42719 .24792 L .46924 .24351 L p .707 .577 .707 r
F P
0 g
s
.42719 .24792 m .42719 .74981 L .39228 .75748 L p .707 .577 .707 r
F P
0 g
s
.65712 .59118 m .65726 .64685 L .67839 .65311 L p .707 .577 .707 r
F P
0 g
s
.70114 .71951 m .70214 .68316 L .6746 .6772 L p .707 .577 .707 r
F P
0 g
s
.70214 .68316 m .70114 .71951 L .73234 .72253 L p .707 .577 .707 r
F P
0 g
s
.55795 .24588 m .55795 .74777 L .51429 .7447 L p .707 .577 .707 r
F P
0 g
s
.51429 .7447 m .51429 .24281 L .55795 .24588 L p .707 .577 .707 r
F P
0 g
s
.65726 .64685 m .65712 .59118 L .64444 .58349 L p .707 .577 .707 r
F P
0 g
s
.79445 .68253 m .79345 .71888 L .81737 .71256 L p .707 .577 .707 r
F P
0 g
s
.81737 .71256 m .81838 .67621 L .79445 .68253 L p .707 .577 .707 r
F P
0 g
s
.6746 .6772 m .6736 .71355 L .70114 .71951 L p .707 .577 .707 r
F P
0 g
s
.6992 .70393 m .70279 .72261 L .73351 .71582 L p .707 .577 .707 r
F P
0 g
s
.73351 .71582 m .72992 .69715 L .6992 .70393 L p .707 .577 .707 r
F P
0 g
s
.72992 .69715 m .73351 .71582 L .76475 .71046 L p .707 .577 .707 r
F P
0 g
s
.46924 .7454 m .46924 .24351 L .51429 .24281 L p .707 .577 .707 r
F P
0 g
s
.46924 .24351 m .46924 .7454 L .42719 .74981 L p .707 .577 .707 r
F P
0 g
s
.6736 .71355 m .6746 .6772 L .65341 .66887 L p .707 .577 .707 r
F P
0 g
s
.76475 .71046 m .76115 .69179 L .72992 .69715 L p .707 .577 .707 r
F P
0 g
s
.51429 .24281 m .51429 .7447 L .46924 .7454 L p .707 .577 .707 r
F P
0 g
s
.76115 .69179 m .76475 .71046 L .79343 .70705 L p .707 .577 .707 r
F P
0 g
s
.65341 .66887 m .65241 .70522 L .6736 .71355 L p .707 .577 .707 r
F P
0 g
s
.672 .71148 m .6756 .73016 L .70279 .72261 L p .707 .577 .707 r
F P
0 g
s
.70279 .72261 m .6992 .70393 L .672 .71148 L p .707 .577 .707 r
F P
0 g
s
.79343 .70705 m .78984 .68838 L .76115 .69179 L p .707 .577 .707 r
F P
0 g
s
.64444 .58349 m .64458 .63916 L .65726 .64685 L p .707 .577 .707 r
F P
0 g
s
.8384 .58628 m .83853 .64195 L .84552 .63373 L p .707 .577 .707 r
F P
0 g
s
.84552 .63373 m .84539 .57806 L .8384 .58628 L p .707 .577 .707 r
F P
0 g
s
.81838 .67621 m .81737 .71256 L .83358 .70398 L p .707 .577 .707 r
F P
0 g
s
.83358 .70398 m .83458 .66762 L .81838 .67621 L p .707 .577 .707 r
F P
0 g
s
.78984 .68838 m .79343 .70705 L .81677 .70593 L p .707 .577 .707 r
F P
0 g
s
.65099 .71906 m .65458 .73773 L .6756 .73016 L p .707 .577 .707 r
F P
0 g
s
.6756 .73016 m .672 .71148 L .65099 .71906 L p .707 .577 .707 r
F P
0 g
s
.81677 .70593 m .81318 .68726 L .78984 .68838 L p .707 .577 .707 r
F P
0 g
s
.64458 .63916 m .64444 .58349 L .64145 .57512 L p .707 .577 .707 r
F P
0 g
s
.65241 .70522 m .65341 .66887 L .64066 .659 L p .707 .577 .707 r
F P
0 g
s
.64066 .659 m .63965 .69535 L .65241 .70522 L p .707 .577 .707 r
F P
0 g
s
.64145 .57512 m .64158 .63079 L .64458 .63916 L p .707 .577 .707 r
F P
0 g
s
.81318 .68726 m .81677 .70593 L .83247 .70721 L p .707 .577 .707 r
F P
0 g
s
.84539 .57806 m .84552 .63373 L .84253 .62536 L p .707 .577 .707 r
F P
0 g
s
.84253 .62536 m .84239 .5697 L .84539 .57806 L p .707 .577 .707 r
F P
0 g
s
.83247 .70721 m .82888 .68853 L .81318 .68726 L p .707 .577 .707 r
F P
0 g
s
.83458 .66762 m .83358 .70398 L .84048 .69397 L p .707 .577 .707 r
F P
0 g
s
.84048 .69397 m .84148 .65762 L .83458 .66762 L p .707 .577 .707 r
F P
0 g
s
.63821 .72592 m .64181 .74459 L .65458 .73773 L p .707 .577 .707 r
F P
0 g
s
.65458 .73773 m .65099 .71906 L .63821 .72592 L p .707 .577 .707 r
F P
0 g
s
.63965 .69535 m .64066 .659 L .63758 .64855 L p .707 .577 .707 r
F P
0 g
s
.64158 .63079 m .64145 .57512 L .64844 .5669 L p .707 .577 .707 r
F P
0 g
s
.63758 .64855 m .63657 .6849 L .63965 .69535 L p .707 .577 .707 r
F P
0 g
s
.82888 .68853 m .83247 .70721 L .839 .71075 L p .707 .577 .707 r
F P
0 g
s
.64844 .5669 m .64857 .62257 L .64158 .63079 L p .707 .577 .707 r
F P
0 g
s
.839 .71075 m .83541 .69208 L .82888 .68853 L p .707 .577 .707 r
F P
0 g
s
.84239 .5697 m .84253 .62536 L .82985 .61767 L p .707 .577 .707 r
F P
0 g
s
.82985 .61767 m .82971 .56201 L .84239 .5697 L p .707 .577 .707 r
F P
0 g
s
.63493 .73138 m .63852 .75006 L .64181 .74459 L p .707 .577 .707 r
F P
0 g
s
.64181 .74459 m .63821 .72592 L .63493 .73138 L p .707 .577 .707 r
F P
0 g
s
.84148 .65762 m .84048 .69397 L .8374 .68352 L p .707 .577 .707 r
F P
0 g
s
.8374 .68352 m .8384 .64717 L .84148 .65762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63657 .6849 m .63758 .64855 L .64448 .63855 L p .707 .577 .707 r
F P
0 g
s
.64857 .62257 m .64844 .5669 L .66472 .55963 L p .707 .577 .707 r
F P
0 g
s
.39867 .61999 m .39836 .56444 L .36716 .56272 L p .707 .577 .707 r
F P
0 g
s
.39836 .56444 m .39867 .61999 L .4305 .61901 L p .707 .577 .707 r
F P
0 g
s
.4305 .61901 m .43018 .56347 L .39836 .56444 L p .707 .577 .707 r
F P
0 g
s
.43018 .56347 m .4305 .61901 L .45984 .61542 L p .707 .577 .707 r
F P
0 g
s
.45984 .61542 m .45953 .55988 L .43018 .56347 L p .707 .577 .707 r
F P
0 g
s
.64448 .63855 m .64347 .6749 L .63657 .6849 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36748 .61826 m .36716 .56272 L .33966 .55846 L p .707 .577 .707 r
F P
0 g
s
.36716 .56272 m .36748 .61826 L .39867 .61999 L p .707 .577 .707 r
F P
0 g
s
.66472 .55963 m .66486 .6153 L .64857 .62257 L p .707 .577 .707 r
F P
0 g
s
.83541 .69208 m .839 .71075 L .83571 .71622 L p .707 .577 .707 r
F P
0 g
s
.82971 .56201 m .82985 .61767 L .80872 .61141 L p .707 .577 .707 r
F P
0 g
s
.80872 .61141 m .80859 .55575 L .82971 .56201 L p .707 .577 .707 r
F P
0 g
s
.83571 .71622 m .83212 .69755 L .83541 .69208 L p .707 .577 .707 r
F P
0 g
s
.8384 .64717 m .8374 .68352 L .82464 .67365 L p .707 .577 .707 r
F P
0 g
s
.82464 .67365 m .82564 .6373 L .8384 .64717 L p .707 .577 .707 r
F P
0 g
s
.64146 .73493 m .64505 .7536 L .63852 .75006 L p .707 .577 .707 r
F P
0 g
s
.63852 .75006 m .63493 .73138 L .64146 .73493 L p .707 .577 .707 r
F P
0 g
s
.45953 .55988 m .45984 .61542 L .48383 .60958 L p .707 .577 .707 r
F P
0 g
s
.48383 .60958 m .48351 .55403 L .45953 .55988 L p .707 .577 .707 r
F P
0 g
s
.38718 .67844 m .38951 .6412 L .35836 .63768 L p .707 .577 .707 r
F P
0 g
s
.38951 .6412 m .38718 .67844 L .41894 .67957 L p .707 .577 .707 r
F P
0 g
s
.41894 .67957 m .42127 .64233 L .38951 .6412 L p .707 .577 .707 r
F P
0 g
s
.66486 .6153 m .66472 .55963 L .68871 .55402 L p .707 .577 .707 r
F P
0 g
s
.64347 .6749 m .64448 .63855 L .66068 .62996 L p .707 .577 .707 r
F P
0 g
s
.42127 .64233 m .41894 .67957 L .4482 .6782 L p .707 .577 .707 r
F P
0 g
s
.4482 .6782 m .45054 .64096 L .42127 .64233 L p .707 .577 .707 r
F P
0 g
s
.33966 .55846 m .33997 .614 L .36748 .61826 L p .707 .577 .707 r
F P
0 g
s
.33997 .614 m .33966 .55846 L .31853 .55208 L p .707 .577 .707 r
F P
0 g
s
.35602 .67492 m .35836 .63768 L .33087 .63211 L p .707 .577 .707 r
F P
0 g
s
.35836 .63768 m .35602 .67492 L .38718 .67844 L p .707 .577 .707 r
F P
0 g
s
.80859 .55575 m .80872 .61141 L .78121 .60719 L p .707 .577 .707 r
F P
0 g
s
.78121 .60719 m .78108 .55152 L .80859 .55575 L p .707 .577 .707 r
F P
0 g
s
.33087 .63211 m .32853 .66936 L .35602 .67492 L p .707 .577 .707 r
F P
0 g
s
.66068 .62996 m .65968 .66632 L .64347 .6749 L p .707 .577 .707 r
F P
0 g
s
.68871 .55402 m .68885 .60969 L .66486 .6153 L p .707 .577 .707 r
F P
0 g
s
.45054 .64096 m .4482 .6782 L .4721 .67447 L p .707 .577 .707 r
F P
0 g
s
.4721 .67447 m .47443 .63722 L .45054 .64096 L p .707 .577 .707 r
F P
0 g
s
.48351 .55403 m .48383 .60958 L .50012 .60205 L p .707 .577 .707 r
F P
0 g
s
.50012 .60205 m .4998 .5465 L .48351 .55403 L p .707 .577 .707 r
F P
0 g
s
.41506 .72972 m .40709 .71399 L .37807 .7269 L p .707 .577 .707 r
F P
0 g
s
.40709 .71399 m .41506 .72972 L .44199 .7134 L p .707 .577 .707 r
F P
0 g
s
.44199 .7134 m .43402 .69767 L .40709 .71399 L p .707 .577 .707 r
F P
0 g
s
.31853 .55208 m .31885 .60762 L .33997 .614 L p .707 .577 .707 r
F P
0 g
s
.68885 .60969 m .68871 .55402 L .71806 .55062 L p .707 .577 .707 r
F P
0 g
s
.83212 .69755 m .83571 .71622 L .82294 .72308 L p .707 .577 .707 r
F P
0 g
s
.82564 .6373 m .82464 .67365 L .80345 .66533 L p .707 .577 .707 r
F P
0 g
s
.80345 .66533 m .80446 .62897 L .82564 .6373 L p .707 .577 .707 r
F P
0 g
s
.32853 .66936 m .33087 .63211 L .30973 .62505 L p .707 .577 .707 r
F P
0 g
s
.38604 .74264 m .37807 .7269 L .34982 .73514 L p .707 .577 .707 r
F P
0 g
s
.37807 .7269 m .38604 .74264 L .41506 .72972 L p .707 .577 .707 r
F P
0 g
s
.43402 .69767 m .44199 .7134 L .46419 .69528 L p .707 .577 .707 r
F P
0 g
s
.46419 .69528 m .45622 .67954 L .43402 .69767 L p .707 .577 .707 r
F P
0 g
s
.82294 .72308 m .81935 .70441 L .83212 .69755 L p .707 .577 .707 r
F P
0 g
s
.65716 .7362 m .66075 .75488 L .64505 .7536 L p .707 .577 .707 r
F P
0 g
s
.64505 .7536 m .64146 .73493 L .65716 .7362 L p .707 .577 .707 r
F P
0 g
s
.31885 .60762 m .31853 .55208 L .30585 .5442 L p .707 .577 .707 r
F P
0 g
s
.65968 .66632 m .66068 .62996 L .6846 .62364 L p .707 .577 .707 r
F P
0 g
s
.78108 .55152 m .78121 .60719 L .75002 .60542 L p .707 .577 .707 r
F P
0 g
s
.75002 .60542 m .74988 .54976 L .78108 .55152 L p .707 .577 .707 r
F P
0 g
s
.34982 .73514 m .35778 .75088 L .38604 .74264 L p .707 .577 .707 r
F P
0 g
s
.30973 .62505 m .30739 .66229 L .32853 .66936 L p .707 .577 .707 r
F P
0 g
s
.71819 .60628 m .71806 .55062 L .74988 .54976 L p .707 .577 .707 r
F P
0 g
s
.71806 .55062 m .71819 .60628 L .68885 .60969 L p .707 .577 .707 r
F P
0 g
s
.35778 .75088 m .34982 .73514 L .32508 .73791 L p .707 .577 .707 r
F P
0 g
s
.74988 .54976 m .75002 .60542 L .71819 .60628 L p .707 .577 .707 r
F P
0 g
s
.47443 .63722 m .4721 .67447 L .48829 .66873 L p .707 .577 .707 r
F P
0 g
s
.48829 .66873 m .49063 .63149 L .47443 .63722 L p .707 .577 .707 r
F P
0 g
s
.45622 .67954 m .46419 .69528 L .4795 .67711 L p .707 .577 .707 r
F P
0 g
s
.4795 .67711 m .47153 .66138 L .45622 .67954 L p .707 .577 .707 r
F P
0 g
s
.6846 .62364 m .6836 .66 L .65968 .66632 L p .707 .577 .707 r
F P
0 g
s
.32508 .73791 m .33305 .75365 L .35778 .75088 L p .707 .577 .707 r
F P
0 g
s
.80446 .62897 m .80345 .66533 L .77591 .65936 L p .707 .577 .707 r
F P
0 g
s
.77591 .65936 m .77691 .62301 L .80446 .62897 L p .707 .577 .707 r
F P
0 g
s
.30585 .5442 m .30616 .59975 L .31885 .60762 L p .707 .577 .707 r
F P
0 g
s
.4998 .5465 m .50012 .60205 L .50711 .59357 L p .707 .577 .707 r
F P
0 g
s
.50711 .59357 m .50679 .53803 L .4998 .5465 L p .707 .577 .707 r
F P
0 g
s
.30739 .66229 m .30973 .62505 L .29701 .61718 L p .707 .577 .707 r
F P
0 g
s
.6836 .66 m .6846 .62364 L .7139 .62021 L p .707 .577 .707 r
F P
0 g
s
.81935 .70441 m .82294 .72308 L .80193 .73065 L p .707 .577 .707 r
F P
0 g
s
.80193 .73065 m .79833 .71198 L .81935 .70441 L p .707 .577 .707 r
F P
0 g
s
.6805 .73508 m .68409 .75376 L .66075 .75488 L p .707 .577 .707 r
F P
0 g
s
.66075 .75488 m .65716 .7362 L .6805 .73508 L p .707 .577 .707 r
F P
0 g
s
.29701 .61718 m .29467 .65442 L .30739 .66229 L p .707 .577 .707 r
F P
0 g
s
.33305 .75365 m .32508 .73791 L .30628 .73493 L p .707 .577 .707 r
F P
0 g
s
.30616 .59975 m .30585 .5442 L .30285 .53561 L p .707 .577 .707 r
F P
0 g
s
.77691 .62301 m .77591 .65936 L .74471 .65634 L p .707 .577 .707 r
F P
0 g
s
.74471 .65634 m .74571 .61999 L .77691 .62301 L p .707 .577 .707 r
F P
0 g
s
.47153 .66138 m .4795 .67711 L .48642 .6607 L p .707 .577 .707 r
F P
0 g
s
.48642 .6607 m .47845 .64496 L .47153 .66138 L p .707 .577 .707 r
F P
0 g
s
.7129 .65656 m .7139 .62021 L .74571 .61999 L p .707 .577 .707 r
F P
0 g
s
.7139 .62021 m .7129 .65656 L .6836 .66 L p .707 .577 .707 r
F P
0 g
s
.30628 .73493 m .31425 .75067 L .33305 .75365 L p .707 .577 .707 r
F P
0 g
s
.49063 .63149 m .48829 .66873 L .4952 .66156 L p .707 .577 .707 r
F P
0 g
s
.4952 .66156 m .49754 .62431 L .49063 .63149 L p .707 .577 .707 r
F P
0 g
s
.74571 .61999 m .74471 .65634 L .7129 .65656 L p .707 .577 .707 r
F P
0 g
s
.30285 .53561 m .30317 .59115 L .30616 .59975 L p .707 .577 .707 r
F P
0 g
s
.79833 .71198 m .80193 .73065 L .77473 .7382 L p .707 .577 .707 r
F P
0 g
s
.29467 .65442 m .29701 .61718 L .29395 .60926 L p .707 .577 .707 r
F P
0 g
s
.50679 .53803 m .50711 .59357 L .50412 .58497 L p .707 .577 .707 r
F P
0 g
s
.50412 .58497 m .5038 .52943 L .50679 .53803 L p .707 .577 .707 r
F P
0 g
s
.70918 .73168 m .71278 .75035 L .68409 .75376 L p .707 .577 .707 r
F P
0 g
s
.68409 .75376 m .6805 .73508 L .70918 .73168 L p .707 .577 .707 r
F P
0 g
s
.77473 .7382 m .77113 .71953 L .79833 .71198 L p .707 .577 .707 r
F P
0 g
s
.31425 .75067 m .30628 .73493 L .29527 .72649 L p .707 .577 .707 r
F P
0 g
s
.29395 .60926 m .29161 .64651 L .29467 .65442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.47845 .64496 m .48642 .6607 L .48427 .64763 L p .707 .577 .707 r
F P
0 g
s
.48427 .64763 m .4763 .63189 L .47845 .64496 L p .707 .577 .707 r
F P
0 g
s
.30317 .59115 m .30285 .53561 L .30984 .52713 L p .707 .577 .707 r
F P
0 g
s
.77113 .71953 m .77473 .7382 L .74401 .74499 L p .707 .577 .707 r
F P
0 g
s
.29527 .72649 m .30324 .74223 L .31425 .75067 L p .707 .577 .707 r
F P
0 g
s
.74042 .72632 m .74401 .74499 L .71278 .75035 L p .707 .577 .707 r
F P
0 g
s
.71278 .75035 m .70918 .73168 L .74042 .72632 L p .707 .577 .707 r
F P
0 g
s
.74401 .74499 m .74042 .72632 L .77113 .71953 L p .707 .577 .707 r
F P
0 g
s
.49754 .62431 m .4952 .66156 L .49215 .65365 L p .707 .577 .707 r
F P
0 g
s
.49215 .65365 m .49448 .6164 L .49754 .62431 L p .707 .577 .707 r
F P
0 g
s
.30984 .52713 m .31016 .58267 L .30317 .59115 L p .707 .577 .707 r
F P
0 g
s
.29161 .64651 m .29395 .60926 L .30086 .60209 L p .707 .577 .707 r
F P
0 g
s
.5038 .52943 m .50412 .58497 L .49144 .5771 L p .707 .577 .707 r
F P
0 g
s
.49144 .5771 m .49112 .52156 L .5038 .52943 L p .707 .577 .707 r
F P
0 g
s
.30324 .74223 m .29527 .72649 L .29311 .71343 L p .707 .577 .707 r
F P
0 g
s
.30086 .60209 m .29852 .63933 L .29161 .64651 L p .707 .577 .707 r
F P
0 g
s
.4763 .63189 m .48427 .64763 L .47325 .63919 L p .707 .577 .707 r
F P
0 g
s
.47325 .63919 m .46528 .62346 L .4763 .63189 L p .707 .577 .707 r
F P
0 g
s
.29311 .71343 m .30108 .72917 L .30324 .74223 L p .707 .577 .707 r
F P
0 g
s
.31016 .58267 m .30984 .52713 L .32613 .5196 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49448 .6164 m .49215 .65365 L .47942 .64577 L p .707 .577 .707 r
F P
0 g
s
.47942 .64577 m .48176 .60853 L .49448 .6164 L p .707 .577 .707 r
F P
0 g
s
.32613 .5196 m .32645 .57514 L .31016 .58267 L p .707 .577 .707 r
F P
0 g
s
.49112 .52156 m .49144 .5771 L .47031 .57072 L p .707 .577 .707 r
F P
0 g
s
.47031 .57072 m .46999 .51518 L .49112 .52156 L p .707 .577 .707 r
F P
0 g
s
.29852 .63933 m .30086 .60209 L .31705 .59635 L p .707 .577 .707 r
F P
0 g
s
.30108 .72917 m .29311 .71343 L .30003 .69701 L p .707 .577 .707 r
F P
0 g
s
.31705 .59635 m .31472 .6336 L .29852 .63933 L p .707 .577 .707 r
F P
0 g
s
.32645 .57514 m .32613 .5196 L .35012 .51375 L p .707 .577 .707 r
F P
0 g
s
.46528 .62346 m .47325 .63919 L .45446 .63621 L p .707 .577 .707 r
F P
0 g
s
.45446 .63621 m .44649 .62047 L .46528 .62346 L p .707 .577 .707 r
F P
0 g
s
.30003 .69701 m .308 .71275 L .30108 .72917 L p .707 .577 .707 r
F P
0 g
s
.48176 .60853 m .47942 .64577 L .45828 .63871 L p .707 .577 .707 r
F P
0 g
s
.45828 .63871 m .46062 .60146 L .48176 .60853 L p .707 .577 .707 r
F P
0 g
s
.46999 .51518 m .47031 .57072 L .4428 .56646 L p .707 .577 .707 r
F P
0 g
s
.4428 .56646 m .44248 .51091 L .46999 .51518 L p .707 .577 .707 r
F P
0 g
s
.35012 .51375 m .35044 .5693 L .32645 .57514 L p .707 .577 .707 r
F P
0 g
s
.31472 .6336 m .31705 .59635 L .34095 .59262 L p .707 .577 .707 r
F P
0 g
s
.35044 .5693 m .35012 .51375 L .37946 .51017 L p .707 .577 .707 r
F P
0 g
s
.308 .71275 m .30003 .69701 L .31534 .67885 L p .707 .577 .707 r
F P
0 g
s
.44649 .62047 m .45446 .63621 L .42972 .63898 L p .707 .577 .707 r
F P
0 g
s
.42972 .63898 m .42175 .62324 L .44649 .62047 L p .707 .577 .707 r
F P
0 g
s
.34095 .59262 m .33862 .62986 L .31472 .6336 L p .707 .577 .707 r
F P
0 g
s
.44248 .51091 m .4428 .56646 L .41161 .56473 L p .707 .577 .707 r
F P
0 g
s
.41161 .56473 m .41129 .50919 L .44248 .51091 L p .707 .577 .707 r
F P
0 g
s
.31534 .67885 m .32331 .69459 L .308 .71275 L p .707 .577 .707 r
F P
0 g
s
.37978 .56571 m .37946 .51017 L .41129 .50919 L p .707 .577 .707 r
F P
0 g
s
.37946 .51017 m .37978 .56571 L .35044 .5693 L p .707 .577 .707 r
F P
0 g
s
.46062 .60146 m .45828 .63871 L .43079 .63314 L p .707 .577 .707 r
F P
0 g
s
.43079 .63314 m .43313 .5959 L .46062 .60146 L p .707 .577 .707 r
F P
0 g
s
.41129 .50919 m .41161 .56473 L .37978 .56571 L p .707 .577 .707 r
F P
0 g
s
.33862 .62986 m .34095 .59262 L .37021 .59125 L p .707 .577 .707 r
F P
0 g
s
.32331 .69459 m .31534 .67885 L .33755 .66072 L p .707 .577 .707 r
F P
0 g
s
.42175 .62324 m .42972 .63898 L .40146 .64723 L p .707 .577 .707 r
F P
0 g
s
.40146 .64723 m .39349 .63149 L .42175 .62324 L p .707 .577 .707 r
F P
0 g
s
.37021 .59125 m .36788 .62849 L .33862 .62986 L p .707 .577 .707 r
F P
0 g
s
.43313 .5959 m .43079 .63314 L .39964 .62962 L p .707 .577 .707 r
F P
0 g
s
.39964 .62962 m .40198 .59238 L .43313 .5959 L p .707 .577 .707 r
F P
0 g
s
.33755 .66072 m .34552 .67646 L .32331 .69459 L p .707 .577 .707 r
F P
0 g
s
.36788 .62849 m .37021 .59125 L .40198 .59238 L p .707 .577 .707 r
F P
0 g
s
.40198 .59238 m .39964 .62962 L .36788 .62849 L p .707 .577 .707 r
F P
0 g
s
.34552 .67646 m .33755 .66072 L .36447 .6444 L p .707 .577 .707 r
F P
0 g
s
.39349 .63149 m .40146 .64723 L .37244 .66014 L p .707 .577 .707 r
F P
0 g
s
.37244 .66014 m .36447 .6444 L .39349 .63149 L p .707 .577 .707 r
F P
0 g
s
.36447 .6444 m .37244 .66014 L .34552 .67646 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF2`002eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol00`00FUIJEP080004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0061oo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`@000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00FWoo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Aoo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00
EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo00mooaP003eoo`00EWoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo00Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Uo
o`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Eoo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0035oo`00EWoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001oogooOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000`Ool005Ioo`03001JEP0000=JEP03001JEUYF00=JEPL000EJEPD000IJEPP000AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000Ool000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002ioo`00EWoo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH00eYF1@001eYF00<005YFFUH015YF1P0015YF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`03001JEP0000=JEP80009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`04001JEP00FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020000
1EYF000005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00@005YF
FUIJEQT000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001FOol200000eYF000000030002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;7oo000nOolA0008Ool200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P000UYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool0035oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;7oo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH2000/Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8002aoo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00AJEQ40009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH70003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF0`00;7oo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<0009JEP03001JEUYF009JEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1P0000=J
EP00FUH0100000EJEP00FUIJEP0000AJEP800003FUH005YF00AJEPP000AJEP03001JEUYF00=JEP06
001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000AJEP00000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00<000AJEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH00eYF1P0000=JEP0000000eYF00<005YFFUH01UYF2`0015YF00H005YFFUH005YF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH2000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP04
001JEUYFFUH20006FUH00`00FUIJEP03FUH@00001eYF001JEUYF001JEP0000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH0000002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00@005YF000000QJEP03
001JEUYF00@000QJEP03001JEUYF00=JEP<0009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<000UJEP<000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH00000008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH00UYF5P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000008000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH70008FUH50004FUH01000FUIJEUYF0P0000=J
EP00FUH015YF00@005YF000000QJEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEPH000Iooa4000IJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002]oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00=JEP<000AJEP800003FUH005YF00EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEP0000@000=JEP03001oogoo01Ioo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002]oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP@00005FUH005YFFUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH30006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP<000AJEP05001JEUYFFUH0
000;Ool3000>Ool40004FUH01000FUIJEUYF0P00;Goo000[Ool01000FUH005YF0P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP05
001JEUYFFUH00008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001J
EP040005FUH01000FUIJEUYF0P002Goo1@004Goo0`0000=JEP00FUH00UYF0P00;Goo000[Ool01P00
FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYF0005FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH0
05YF00800003FUH005YF00<000=JEP04001JEUYFFUH20009Ool5000DOol20003FUH2000]Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000MJEP@0009JEP03001JEP0000P000AJEP03001JEUYF009JEPL000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP@000=JEP8000Uoo`D0019oo`80009JEP04001JEUYF000^Ool002]oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000IJEP800004FUH005YF0002FUH00`00FUIJEP04FUH300000eYF000000070005FUH00`00FUIJ
EP03FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP03FUH00`00FUH00005000:Ool3000?Ool400000eYF001JEP02FUH3000^
Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP07001JEUYFFUH005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1`004Woo1@001EYF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF6P000UYF00@005YFFUIJ
EP8000=JEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHQ00000eYF001oo`0]Ool002aoo`05001J
EUYFFUH00005FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YF00000`000eYF0`000UYF00<005YFFUH00eYF1@001UYF00@005YFFUIJEP8000=JEP04
001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<0
05YFFUH015YF00@005YFFUIJEP@002ioo`00;Goo0P0000=JEP00FUH00eYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P000UYF1@0000Eoo`00FUIJEP0000IJ
EP<000MJEP04001JEUYF0006FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;goo
0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YF00001EYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF00001UYF00@005YFFUH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03000_Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000=JEP04001JEUYF0005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF0`00
1EYF00D005YFFUIJEP0000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP@000EJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002moo`00;goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUH000EJEP04001J
EUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0015YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P0015YF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJ
EPD0009JEP03001JEP0002ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0`0000=J
EP00FUH0100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF
0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000EJEP03001JEUYF
00MJEP03001JEUYF009JEPT000=JEP<000AJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJ
EP0000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH2
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH400001UYF00000000FUH000MJEP03001JEUYF00AJEPL000AJEP04001JEUYFFUH400000eYF
001JEP05FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH010000UYF1@0015YF10001EYF00<005YFFUH015YF00@005YF
0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
009JEP<000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP03FUH40002Ool=0002FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000bOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEQD00004FUH000000004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF00000P00
1eYF00H005YF000005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF000010002Goo1@001UYF00<0
05YFFUH01EYF00<005YF00000P00=Goo000]Ool00`00FUH00003FUH00`00FUIJEP03FUHJ00000eYF
00000002FUH70003FUH01000FUIJEP000UYF0P0000=JEP00FUH025YF00D005YFFUIJEP0000]JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF009JEP<0009JEP03001JEP0000Eoo`@0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP<003Qoo`00;Goo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<0
05YF00001P000eYF1P000UYF0`0015YF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YF00000P001EYF00<005YF00001@001UYF00<005YFFUH01eYF00<005YF00000`00>goo000]Ool0
0`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH01`00FUIJEUYF001J
EP00009JEP/000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH03P000eYF00<005YF
FUH01eYF00<005YFFUH015YF1000?goo000]Ool00`00FUH000030004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01eYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01000@goo000]Ool300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Agoo
000]Ool50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0003FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH01eYF00@005YFFUIJEPH000MJ
EP03001JEUYF00UJEP03001JEP0000P000QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01000C7oo000]Ool300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01EYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF1P000UYF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH6001@Ool0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00H00004FUH000000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUHA00000eYF001oo`1COol002ioo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF0080009JEP03001JEUYF00=J
EPD000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF009JEP03001oogoo00Moo`<00003FUH005YF009JEP03001oogoo059oo`00;Goo0P00
0Woo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000`000Woo0P000UYF00@005YFFUH000=JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF00=JEP03001oogoo
00Qoo`@000=JEP8005=oo`00;Goo0P001Goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1@001goo00@005YFFUH0009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<0
07ooOol017oo100000AJEP00FUIJEP800003FUH0000005=oo`00;Goo00<005YF00002goo6`0037oo
00@005YFFUH0009JEP<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001oo`0000@000EJEP04001JEUYF
FUH4001COol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001COol002eoo`03001JEP00
01Moo`D001Moo`04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000Dgoo000]Ool01000FUH000005Woo1@0067oo
0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005=oo`00;Woo00<005YF00005Woo1@0067oo0`000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00;Woo
00@005YFFUH001Ioo`<001Yoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1COol002ioo`05001JEUYFFUH0000bOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP02001FOol002moo`04001JEUYF000bOol20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP04FUH3001HOol002moo`05001JEUYFFUH0000aOol00`00FUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH2001JOol0031oo`03001JEUYF0080035o
o`D000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP0000<005aoo`00<Goo0P000UYF00<007ooOol0
;Woo00@007ooOomoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006FUH3001POol0035oo`8000=JEP8002eoo`80
00Eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000003FUH200000eYF00000002001SOol0039oo`03001JEUYF00=JEP03
001oogoo02Yoo`8000Uoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP@00003FUH005YF00AJEP8006Ioo`00<goo00<005YFFUH00eYF00<007ooOol0:7oo
0P003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02P00
25YF0`00Hgoo000dOol00`00FUIJEP02FUH3000WOol3000EOol90006FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH80004FUH60009FUH01000FUH00000HGoo000eOol200000eYF001JEP02FUH2000TOol0
0`00FUH0000OOolI0008Ool20002FUH500000eYF00000006FUH00`00FUIJEP02FUH2001OOol003Mo
o`8000EJEP80021oo`80009JEP03001oogoo041oo`800004FUH000000004FUH20004FUH00`00FUIJ
EP04FUH2001MOol003Qoo`03001JEUYF00EJEP<001]oo`800004FUH005YF0015Ool20008FUH20000
0eYF001JEP07FUH3001KOol003Uoo`8000IJEP04001JEP00000GOol20002FUH00`00FUH00018Ool2
0006FUH00`00FUH000020006FUH01000FUIJEUYF0P00FGoo000kOol20003FUH00`00FUIJEP02FUH3
000?Ool50004FUH2001;Ool20004FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH2001GOol0
03eoo`800003FUH005YF00IJEPl000=JEP03001JEUYF009JEP8004ioo`800003FUH005YF00IJEP80
0003FUH005YF00EJEP03001JEP0005Ioo`00?goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80059oo`<000MJEP<000IJEP04001JEUYF001EOol0049oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00001GOol20005FUH00`00FUIJEP020003FUH00`00FUIJEP02
FUH00`00Oomoo`1BOol004Aoo`<00003FUH005YF00MJEP03001JEUYF009JEPD005]oo`<00003FUH0
05YF00AJEP800003FUH005YF00=JEP03001oogoo059oo`00Agoo3`00Hgoo0`001EYF0P0015YF0P00
E7oo002lOol300001EYF001JEUYF00000eYF00<007ooOol0Dgoo002oOol20003FUH4001EOol00<5o
o`800004FUH005YF001FOol00<=oo`@005Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58839 .75016 m .58871 .69454 L .55751 .69252 L p .707 .577 .707 r
F P
0 g
s
.58871 .69454 m .58839 .75016 L .62022 .74953 L p .707 .577 .707 r
F P
0 g
s
.62022 .74953 m .62053 .69391 L .58871 .69454 L p .707 .577 .707 r
F P
0 g
s
.62053 .69391 m .62022 .74953 L .64956 .74631 L p .707 .577 .707 r
F P
0 g
s
.64956 .74631 m .64988 .6907 L .62053 .69391 L p .707 .577 .707 r
F P
0 g
s
.5572 .74813 m .55751 .69252 L .53001 .68804 L p .707 .577 .707 r
F P
0 g
s
.55751 .69252 m .5572 .74813 L .58839 .75016 L p .707 .577 .707 r
F P
0 g
s
.64988 .6907 m .64956 .74631 L .67355 .74082 L p .707 .577 .707 r
F P
0 g
s
.67355 .74082 m .67387 .6852 L .64988 .6907 L p .707 .577 .707 r
F P
0 g
s
.53001 .68804 m .52969 .74365 L .5572 .74813 L p .707 .577 .707 r
F P
0 g
s
.52969 .74365 m .53001 .68804 L .50888 .68154 L p .707 .577 .707 r
F P
0 g
s
.60036 .81233 m .59802 .77563 L .56687 .77541 L p .707 .577 .707 r
F P
0 g
s
.59802 .77563 m .60036 .81233 L .63212 .80959 L p .707 .577 .707 r
F P
0 g
s
.63212 .80959 m .62978 .77288 L .59802 .77563 L p .707 .577 .707 r
F P
0 g
s
.62978 .77288 m .63212 .80959 L .66138 .80414 L p .707 .577 .707 r
F P
0 g
s
.66138 .80414 m .65904 .76744 L .62978 .77288 L p .707 .577 .707 r
F P
0 g
s
.56921 .81211 m .56687 .77541 L .53938 .77225 L p .707 .577 .707 r
F P
0 g
s
.56687 .77541 m .56921 .81211 L .60036 .81233 L p .707 .577 .707 r
F P
0 g
s
.67387 .6852 m .67355 .74082 L .68983 .73359 L p .707 .577 .707 r
F P
0 g
s
.68983 .73359 m .69015 .67797 L .67387 .6852 L p .707 .577 .707 r
F P
0 g
s
.50888 .68154 m .50856 .73716 L .52969 .74365 L p .707 .577 .707 r
F P
0 g
s
.65904 .76744 m .66138 .80414 L .68528 .79654 L p .707 .577 .707 r
F P
0 g
s
.68528 .79654 m .68294 .75983 L .65904 .76744 L p .707 .577 .707 r
F P
0 g
s
.59854 .82865 m .60651 .81122 L .57825 .79772 L p .707 .577 .707 r
F P
0 g
s
.60651 .81122 m .59854 .82865 L .62755 .84159 L p .707 .577 .707 r
F P
0 g
s
.62755 .84159 m .63552 .82416 L .60651 .81122 L p .707 .577 .707 r
F P
0 g
s
.57825 .79772 m .57028 .81515 L .59854 .82865 L p .707 .577 .707 r
F P
0 g
s
.53938 .77225 m .54171 .80895 L .56921 .81211 L p .707 .577 .707 r
F P
0 g
s
.50856 .73716 m .50888 .68154 L .4962 .67367 L p .707 .577 .707 r
F P
0 g
s
.63552 .82416 m .62755 .84159 L .65448 .85271 L p .707 .577 .707 r
F P
0 g
s
.65448 .85271 m .66245 .83528 L .63552 .82416 L p .707 .577 .707 r
F P
0 g
s
.57028 .81515 m .57825 .79772 L .55351 .78498 L p .707 .577 .707 r
F P
0 g
s
.54171 .80895 m .53938 .77225 L .51824 .76645 L p .707 .577 .707 r
F P
0 g
s
.55351 .78498 m .54554 .80241 L .57028 .81515 L p .707 .577 .707 r
F P
0 g
s
.66245 .83528 m .65448 .85271 L .67669 .86091 L p .707 .577 .707 r
F P
0 g
s
.67669 .86091 m .68466 .84348 L .66245 .83528 L p .707 .577 .707 r
F P
0 g
s
.68294 .75983 m .68528 .79654 L .70148 .78751 L p .707 .577 .707 r
F P
0 g
s
.70148 .78751 m .69914 .75081 L .68294 .75983 L p .707 .577 .707 r
F P
0 g
s
.4962 .67367 m .49588 .72929 L .50856 .73716 L p .707 .577 .707 r
F P
0 g
s
.51824 .76645 m .52057 .80315 L .54171 .80895 L p .707 .577 .707 r
F P
0 g
s
.69015 .67797 m .68983 .73359 L .69682 .72533 L p .707 .577 .707 r
F P
0 g
s
.69682 .72533 m .69714 .66971 L .69015 .67797 L p .707 .577 .707 r
F P
0 g
s
.54554 .80241 m .55351 .78498 L .53472 .77425 L p .707 .577 .707 r
F P
0 g
s
.53472 .77425 m .52675 .79168 L .54554 .80241 L p .707 .577 .707 r
F P
0 g
s
.52057 .80315 m .51824 .76645 L .50551 .75858 L p .707 .577 .707 r
F P
0 g
s
.49588 .72929 m .4962 .67367 L .49321 .66519 L p .707 .577 .707 r
F P
0 g
s
.68466 .84348 m .67669 .86091 L .692 .8654 L p .707 .577 .707 r
F P
0 g
s
.692 .8654 m .69997 .84797 L .68466 .84348 L p .707 .577 .707 r
F P
0 g
s
.50551 .75858 m .50785 .79529 L .52057 .80315 L p .707 .577 .707 r
F P
0 g
s
.69914 .75081 m .70148 .78751 L .70838 .77795 L p .707 .577 .707 r
F P
0 g
s
.70838 .77795 m .70605 .74125 L .69914 .75081 L p .707 .577 .707 r
F P
0 g
s
.52675 .79168 m .53472 .77425 L .5237 .76659 L p .707 .577 .707 r
F P
0 g
s
.49321 .66519 m .49289 .7208 L .49588 .72929 L p .707 .577 .707 r
F P
0 g
s
.5237 .76659 m .51573 .78402 L .52675 .79168 L p .707 .577 .707 r
F P
0 g
s
.69714 .66971 m .69682 .72533 L .69383 .71684 L p .707 .577 .707 r
F P
0 g
s
.69383 .71684 m .69415 .66123 L .69714 .66971 L p .707 .577 .707 r
F P
0 g
s
.50785 .79529 m .50551 .75858 L .50246 .74942 L p .707 .577 .707 r
F P
0 g
s
.49289 .7208 m .49321 .66519 L .5002 .65692 L p .707 .577 .707 r
F P
0 g
s
.48571 .82173 m .48571 .31984 L .44205 .31677 L p .707 .577 .707 r
F P
0 g
s
.50246 .74942 m .50479 .78613 L .50785 .79529 L p .707 .577 .707 r
F P
0 g
s
.51573 .78402 m .5237 .76659 L .52155 .76273 L p .707 .577 .707 r
F P
0 g
s
.52155 .76273 m .51358 .78016 L .51573 .78402 L p .707 .577 .707 r
F P
0 g
s
.5002 .65692 m .49988 .71254 L .49289 .7208 L p .707 .577 .707 r
F P
0 g
s
.50479 .78613 m .50246 .74942 L .50937 .73986 L p .707 .577 .707 r
F P
0 g
s
.49988 .71254 m .5002 .65692 L .51648 .64969 L p .707 .577 .707 r
F P
0 g
s
.50937 .73986 m .5117 .77656 L .50479 .78613 L p .707 .577 .707 r
F P
0 g
s
.51358 .78016 m .52155 .76273 L .52846 .76306 L p .707 .577 .707 r
F P
0 g
s
.51648 .64969 m .51617 .70531 L .49988 .71254 L p .707 .577 .707 r
F P
0 g
s
.52846 .76306 m .52049 .78049 L .51358 .78016 L p .707 .577 .707 r
F P
0 g
s
.51617 .70531 m .51648 .64969 L .54047 .6442 L p .707 .577 .707 r
F P
0 g
s
.5117 .77656 m .50937 .73986 L .52556 .73083 L p .707 .577 .707 r
F P
0 g
s
.52049 .78049 m .52846 .76306 L .54378 .76755 L p .707 .577 .707 r
F P
0 g
s
.52556 .73083 m .5279 .76754 L .5117 .77656 L p .707 .577 .707 r
F P
0 g
s
.54047 .6442 m .54015 .69982 L .51617 .70531 L p .707 .577 .707 r
F P
0 g
s
.54378 .76755 m .53581 .78498 L .52049 .78049 L p .707 .577 .707 r
F P
0 g
s
.48571 .31984 m .48571 .82173 L .53076 .82103 L p .707 .577 .707 r
F P
0 g
s
.5279 .76754 m .52556 .73083 L .54946 .72323 L p .707 .577 .707 r
F P
0 g
s
.54946 .72323 m .5518 .75993 L .5279 .76754 L p .707 .577 .707 r
F P
0 g
s
.53076 .82103 m .53076 .31914 L .48571 .31984 L p .707 .577 .707 r
F P
0 g
s
.54015 .69982 m .54047 .6442 L .56982 .64098 L p .707 .577 .707 r
F P
0 g
s
.56982 .64098 m .5695 .6966 L .54015 .69982 L p .707 .577 .707 r
F P
0 g
s
.5518 .75993 m .54946 .72323 L .57872 .71778 L p .707 .577 .707 r
F P
0 g
s
.53581 .78498 m .54378 .76755 L .56598 .77575 L p .707 .577 .707 r
F P
0 g
s
.56598 .77575 m .55801 .79318 L .53581 .78498 L p .707 .577 .707 r
F P
0 g
s
.57872 .71778 m .58106 .75449 L .5518 .75993 L p .707 .577 .707 r
F P
0 g
s
.55801 .79318 m .56598 .77575 L .59291 .78687 L p .707 .577 .707 r
F P
0 g
s
.59291 .78687 m .58494 .8043 L .55801 .79318 L p .707 .577 .707 r
F P
0 g
s
.53076 .31914 m .53076 .82103 L .5728 .81663 L p .707 .577 .707 r
F P
0 g
s
.5695 .6966 m .56982 .64098 L .60164 .64035 L p .707 .577 .707 r
F P
0 g
s
.60164 .64035 m .60132 .69597 L .5695 .6966 L p .707 .577 .707 r
F P
0 g
s
.5728 .81663 m .5728 .31474 L .53076 .31914 L p .707 .577 .707 r
F P
0 g
s
.69997 .84797 m .692 .8654 L .69891 .86573 L p .707 .577 .707 r
F P
0 g
s
.69891 .86573 m .70688 .8483 L .69997 .84797 L p .707 .577 .707 r
F P
0 g
s
.44205 .81866 m .44205 .31677 L .40407 .31023 L p .707 .577 .707 r
F P
0 g
s
.44205 .31677 m .44205 .81866 L .48571 .82173 L p .707 .577 .707 r
F P
0 g
s
.70605 .74125 m .70838 .77795 L .70533 .76879 L p .707 .577 .707 r
F P
0 g
s
.70533 .76879 m .70299 .73208 L .70605 .74125 L p .707 .577 .707 r
F P
0 g
s
.69415 .66123 m .69383 .71684 L .68115 .70897 L p .707 .577 .707 r
F P
0 g
s
.68115 .70897 m .68147 .65335 L .69415 .66123 L p .707 .577 .707 r
F P
0 g
s
.58106 .75449 m .57872 .71778 L .61049 .71504 L p .707 .577 .707 r
F P
0 g
s
.61049 .71504 m .61282 .75174 L .58106 .75449 L p .707 .577 .707 r
F P
0 g
s
.58494 .8043 m .59291 .78687 L .62192 .79981 L p .707 .577 .707 r
F P
0 g
s
.62192 .79981 m .61395 .81724 L .58494 .8043 L p .707 .577 .707 r
F P
0 g
s
.5728 .31474 m .5728 .81663 L .60772 .80896 L p .707 .577 .707 r
F P
0 g
s
.63283 .64238 m .63252 .698 L .60132 .69597 L p .707 .577 .707 r
F P
0 g
s
.60132 .69597 m .60164 .64035 L .63283 .64238 L p .707 .577 .707 r
F P
0 g
s
.60772 .80896 m .60772 .30707 L .5728 .31474 L p .707 .577 .707 r
F P
0 g
s
.40407 .81212 m .40407 .31023 L .37547 .30087 L p .707 .577 .707 r
F P
0 g
s
.40407 .31023 m .40407 .81212 L .44205 .81866 L p .707 .577 .707 r
F P
0 g
s
.70688 .8483 m .69891 .86573 L .69676 .86188 L p .707 .577 .707 r
F P
0 g
s
.69676 .86188 m .70473 .84444 L .70688 .8483 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24998 .71105 m .25011 .65555 L .21892 .65357 L p .707 .577 .707 r
F P
0 g
s
.25011 .65555 m .24998 .71105 L .2818 .7103 L p .707 .577 .707 r
F P
0 g
s
.2818 .7103 m .28194 .65481 L .25011 .65555 L p .707 .577 .707 r
F P
0 g
s
.28194 .65481 m .2818 .7103 L .31115 .7069 L p .707 .577 .707 r
F P
0 g
s
.31115 .7069 m .31128 .65141 L .28194 .65481 L p .707 .577 .707 r
F P
0 g
s
.70299 .73208 m .70533 .76879 L .69261 .76092 L p .707 .577 .707 r
F P
0 g
s
.69261 .76092 m .69027 .72422 L .70299 .73208 L p .707 .577 .707 r
F P
0 g
s
.21878 .70907 m .21892 .65357 L .19141 .64905 L p .707 .577 .707 r
F P
0 g
s
.21892 .65357 m .21878 .70907 L .24998 .71105 L p .707 .577 .707 r
F P
0 g
s
.64164 .71526 m .64397 .75196 L .61282 .75174 L p .707 .577 .707 r
F P
0 g
s
.61282 .75174 m .61049 .71504 L .64164 .71526 L p .707 .577 .707 r
F P
0 g
s
.61395 .81724 m .62192 .79981 L .65018 .81331 L p .707 .577 .707 r
F P
0 g
s
.60772 .30707 m .60772 .80896 L .63209 .79877 L p .707 .577 .707 r
F P
0 g
s
.63209 .79877 m .63209 .29688 L .60772 .30707 L p .707 .577 .707 r
F P
0 g
s
.68147 .65335 m .68115 .70897 L .66002 .70248 L p .707 .577 .707 r
F P
0 g
s
.66002 .70248 m .66034 .64686 L .68147 .65335 L p .707 .577 .707 r
F P
0 g
s
.25529 .76817 m .25429 .73058 L .22309 .72993 L p .707 .577 .707 r
F P
0 g
s
.25429 .73058 m .25529 .76817 L .2871 .76672 L p .707 .577 .707 r
F P
0 g
s
.2871 .76672 m .2861 .72912 L .25429 .73058 L p .707 .577 .707 r
F P
0 g
s
.2861 .72912 m .2871 .76672 L .3164 .76329 L p .707 .577 .707 r
F P
0 g
s
.3164 .76329 m .3154 .72569 L .2861 .72912 L p .707 .577 .707 r
F P
0 g
s
.31128 .65141 m .31115 .7069 L .33514 .70118 L p .707 .577 .707 r
F P
0 g
s
.33514 .70118 m .33527 .64568 L .31128 .65141 L p .707 .577 .707 r
F P
0 g
s
.22409 .76752 m .22309 .72993 L .19554 .72723 L p .707 .577 .707 r
F P
0 g
s
.22309 .72993 m .22409 .76752 L .25529 .76817 L p .707 .577 .707 r
F P
0 g
s
.19128 .70455 m .19141 .64905 L .17029 .64244 L p .707 .577 .707 r
F P
0 g
s
.19141 .64905 m .19128 .70455 L .21878 .70907 L p .707 .577 .707 r
F P
0 g
s
.19554 .72723 m .19655 .76483 L .22409 .76752 L p .707 .577 .707 r
F P
0 g
s
.3154 .72569 m .3164 .76329 L .34032 .75824 L p .707 .577 .707 r
F P
0 g
s
.34032 .75824 m .33932 .72064 L .3154 .72569 L p .707 .577 .707 r
F P
0 g
s
.70473 .84444 m .69676 .86188 L .68575 .85421 L p .707 .577 .707 r
F P
0 g
s
.68575 .85421 m .69372 .83678 L .70473 .84444 L p .707 .577 .707 r
F P
0 g
s
.37547 .80275 m .37547 .30087 L .35907 .28958 L p .707 .577 .707 r
F P
0 g
s
.37547 .30087 m .37547 .80275 L .40407 .81212 L p .707 .577 .707 r
F P
0 g
s
.66034 .64686 m .66002 .70248 L .63252 .698 L p .707 .577 .707 r
F P
0 g
s
.63252 .698 m .63283 .64238 L .66034 .64686 L p .707 .577 .707 r
F P
0 g
s
.69027 .72422 m .69261 .76092 L .67146 .75512 L p .707 .577 .707 r
F P
0 g
s
.67146 .75512 m .66913 .71842 L .69027 .72422 L p .707 .577 .707 r
F P
0 g
s
.19655 .76483 m .19554 .72723 L .17436 .72276 L p .707 .577 .707 r
F P
0 g
s
.33527 .64568 m .33514 .70118 L .35142 .69369 L p .707 .577 .707 r
F P
0 g
s
.35142 .69369 m .35156 .63819 L .33527 .64568 L p .707 .577 .707 r
F P
0 g
s
.17029 .64244 m .17015 .69794 L .19128 .70455 L p .707 .577 .707 r
F P
0 g
s
.25599 .85217 m .25958 .83767 L .22886 .82893 L p .707 .577 .707 r
F P
0 g
s
.25958 .83767 m .25599 .85217 L .28722 .85458 L p .707 .577 .707 r
F P
0 g
s
.28722 .85458 m .29081 .84008 L .25958 .83767 L p .707 .577 .707 r
F P
0 g
s
.22527 .84342 m .22886 .82893 L .20167 .81471 L p .707 .577 .707 r
F P
0 g
s
.22886 .82893 m .22527 .84342 L .25599 .85217 L p .707 .577 .707 r
F P
0 g
s
.17436 .72276 m .17536 .76035 L .19655 .76483 L p .707 .577 .707 r
F P
0 g
s
.64397 .75196 m .64164 .71526 L .66913 .71842 L p .707 .577 .707 r
F P
0 g
s
.63209 .29688 m .63209 .79877 L .64353 .78705 L p .707 .577 .707 r
F P
0 g
s
.64353 .78705 m .64353 .28516 L .63209 .29688 L p .707 .577 .707 r
F P
0 g
s
.17015 .69794 m .17029 .64244 L .1576 .63438 L p .707 .577 .707 r
F P
0 g
s
.29081 .84008 m .28722 .85458 L .31591 .85042 L p .707 .577 .707 r
F P
0 g
s
.31591 .85042 m .3195 .83593 L .29081 .84008 L p .707 .577 .707 r
F P
0 g
s
.33932 .72064 m .34032 .75824 L .35653 .75205 L p .707 .577 .707 r
F P
0 g
s
.35653 .75205 m .35552 .71445 L .33932 .72064 L p .707 .577 .707 r
F P
0 g
s
.19807 .8292 m .20167 .81471 L .18065 .7964 L p .707 .577 .707 r
F P
0 g
s
.20167 .81471 m .19807 .8292 L .22527 .84342 L p .707 .577 .707 r
F P
0 g
s
.66913 .71842 m .67146 .75512 L .64397 .75196 L p .707 .577 .707 r
F P
0 g
s
.17536 .76035 m .17436 .72276 L .1616 .71694 L p .707 .577 .707 r
F P
0 g
s
.69372 .83678 m .68575 .85421 L .66695 .84348 L p .707 .577 .707 r
F P
0 g
s
.66695 .84348 m .67492 .82605 L .69372 .83678 L p .707 .577 .707 r
F P
0 g
s
.3195 .83593 m .31591 .85042 L .33925 .8401 L p .707 .577 .707 r
F P
0 g
s
.33925 .8401 m .34284 .82561 L .3195 .83593 L p .707 .577 .707 r
F P
0 g
s
.1576 .63438 m .15747 .68988 L .17015 .69794 L p .707 .577 .707 r
F P
0 g
s
.35156 .63819 m .35142 .69369 L .35841 .68517 L p .707 .577 .707 r
F P
0 g
s
.35841 .68517 m .35855 .62967 L .35156 .63819 L p .707 .577 .707 r
F P
0 g
s
.18065 .7964 m .17706 .8109 L .19807 .8292 L p .707 .577 .707 r
F P
0 g
s
.17706 .8109 m .18065 .7964 L .16788 .77581 L p .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16788 .77581 L .16766 .77442 L p .707 .577 .707 r
F P
0 g
s
.1616 .71694 m .1626 .75453 L .17175 .75871 L p .707 .577 .707 r
F P
0 g
s
.16766 .77442 m .16459 .75493 L p .16431 .78729 L .707 .577 .707 r
F P
0 g
s
.16428 .7903 m .16766 .77442 L .16431 .78729 L .707 .577 .707 r
F
.17175 .75871 m .17536 .76035 L p .17314 .75336 L F P
0 g
s
.17314 .75336 m .1616 .71694 L .17175 .75871 L .707 .577 .707 r
F
.35552 .71445 m .35653 .75205 L .36343 .74533 L p F P
0 g
s
.36343 .74533 m .36242 .70773 L .35552 .71445 L p .707 .577 .707 r
F P
0 g
s
.35855 .62967 m .35841 .68517 L .35542 .67645 L p .707 .577 .707 r
F P
0 g
s
.35542 .67645 m .35556 .62096 L .35855 .62967 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .36507 .79103 L .35854 .81013 L p .707 .577 .707 r
F P
0 g
s
.36147 .80552 m .35819 .78465 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36507 .79103 m .36353 .79722 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.36353 .79722 m .36147 .80552 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35646 .27749 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36178 .77015 L .36235 .77375 L p .707 .577 .707 r
F P
0 g
s
.36235 .77375 m .36507 .79103 L p .36313 .78923 L .707 .577 .707 r
F P
0 g
s
.35819 .78465 m .36235 .77375 L .36313 .78923 L .707 .577 .707 r
F
.35934 .70114 m .36035 .73874 L .34759 .73292 L p F P
0 g
s
.34759 .73292 m .34658 .69532 L .35934 .70114 L p .707 .577 .707 r
F P
0 g
s
.36178 .77015 m .35819 .78465 L .34542 .76405 L p .707 .577 .707 r
F P
0 g
s
.34542 .76405 m .34901 .74955 L .36178 .77015 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35907 .79147 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .27749 m .35646 .65696 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35646 .65696 m .35646 .77938 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .79147 m .35907 .70871 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.35907 .70871 m .35907 .28958 L p .3586 .69945 L .707 .577 .707 r
F P
0 g
s
.36242 .70773 m .36343 .74533 L .36035 .73874 L p .707 .577 .707 r
F P
0 g
s
.36035 .73874 m .35934 .70114 L .36242 .70773 L p .707 .577 .707 r
F P
0 g
s
.35907 .28958 m .35907 .79147 L .37547 .80275 L p .707 .577 .707 r
F P
0 g
s
.15747 .68988 m .1576 .63438 L .15461 .62567 L p .707 .577 .707 r
F P
0 g
s
.16788 .77581 m .16428 .7903 L .17706 .8109 L p .707 .577 .707 r
F P
0 g
s
.34284 .82561 m .33925 .8401 L .35495 .82463 L p .707 .577 .707 r
F P
0 g
s
.35495 .82463 m .35854 .81013 L .34284 .82561 L p .707 .577 .707 r
F P
0 g
s
.67492 .82605 m .66695 .84348 L .64221 .83074 L p .707 .577 .707 r
F P
0 g
s
.64221 .83074 m .65018 .81331 L .67492 .82605 L p .707 .577 .707 r
F P
0 g
s
.64353 .28516 m .64353 .78705 L .64093 .77496 L p .707 .577 .707 r
F P
0 g
s
.64093 .77496 m .64093 .27308 L .64353 .28516 L p .707 .577 .707 r
F P
0 g
s
.1626 .75453 m .1616 .71694 L .15852 .71034 L p .707 .577 .707 r
F P
0 g
s
.15461 .62567 m .15448 .68116 L .15747 .68988 L p .707 .577 .707 r
F P
0 g
s
.15852 .71034 m .15952 .74794 L .1626 .75453 L p .707 .577 .707 r
F P
0 g
s
.65018 .81331 m .64221 .83074 L .61395 .81724 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16459 .75493 m .161 .76942 L .16428 .7903 L p .707 .577 .707 r
F P
0 g
s
.35854 .81013 m .35495 .82463 L .36147 .80552 L p .707 .577 .707 r
F P
0 g
s
.15448 .68116 m .15461 .62567 L .1616 .61715 L p .707 .577 .707 r
F P
0 g
s
.161 .76942 m .16459 .75493 L .17112 .73582 L p .707 .577 .707 r
F P
0 g
s
.35646 .77938 m .35646 .27749 L .36791 .26578 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15952 .74794 m .15852 .71034 L .16542 .70362 L p .707 .577 .707 r
F P
0 g
s
.1616 .61715 m .16146 .67265 L .15448 .68116 L p .707 .577 .707 r
F P
0 g
s
.35556 .62096 m .35542 .67645 L .34274 .66839 L p .707 .577 .707 r
F P
0 g
s
.34274 .66839 m .34288 .6129 L .35556 .62096 L p .707 .577 .707 r
F P
0 g
s
.17112 .73582 m .16753 .75032 L .161 .76942 L p .707 .577 .707 r
F P
0 g
s
.16542 .70362 m .16642 .74122 L .15952 .74794 L p .707 .577 .707 r
F P
0 g
s
.64093 .27308 m .64093 .77496 L .62452 .76368 L p .707 .577 .707 r
F P
0 g
s
.62452 .76368 m .62452 .26179 L .64093 .27308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16146 .67265 m .1616 .61715 L .17789 .60966 L p .707 .577 .707 r
F P
0 g
s
.16753 .75032 m .17112 .73582 L .18682 .72035 L p .707 .577 .707 r
F P
0 g
s
.18682 .72035 m .18323 .73484 L .16753 .75032 L p .707 .577 .707 r
F P
0 g
s
.16642 .74122 m .16542 .70362 L .18162 .69743 L p .707 .577 .707 r
F P
0 g
s
.17789 .60966 m .17775 .66516 L .16146 .67265 L p .707 .577 .707 r
F P
0 g
s
.34288 .6129 m .34274 .66839 L .32161 .66178 L p .707 .577 .707 r
F P
0 g
s
.32161 .66178 m .32175 .60629 L .34288 .6129 L p .707 .577 .707 r
F P
0 g
s
.36791 .76767 m .36791 .26578 L .39228 .25559 L p .707 .577 .707 r
F P
0 g
s
.36791 .26578 m .36791 .76767 L .35646 .77938 L p .707 .577 .707 r
F P
0 g
s
.18162 .69743 m .18263 .73503 L .16642 .74122 L p .707 .577 .707 r
F P
0 g
s
.18323 .73484 m .18682 .72035 L .21016 .71003 L p .707 .577 .707 r
F P
0 g
s
.17775 .66516 m .17789 .60966 L .20188 .60393 L p .707 .577 .707 r
F P
0 g
s
.34658 .69532 m .34759 .73292 L .3264 .72844 L p .707 .577 .707 r
F P
0 g
s
.3264 .72844 m .3254 .69084 L .34658 .69532 L p .707 .577 .707 r
F P
0 g
s
.62452 .26179 m .62452 .76368 L .59593 .75431 L p .707 .577 .707 r
F P
0 g
s
.59593 .75431 m .59593 .25242 L .62452 .26179 L p .707 .577 .707 r
F P
0 g
s
.21016 .71003 m .20656 .72452 L .18323 .73484 L p .707 .577 .707 r
F P
0 g
s
.34901 .74955 m .34542 .76405 L .3244 .74574 L p .707 .577 .707 r
F P
0 g
s
.3244 .74574 m .32799 .73125 L .34901 .74955 L p .707 .577 .707 r
F P
0 g
s
.32175 .60629 m .32161 .66178 L .2941 .65726 L p .707 .577 .707 r
F P
0 g
s
.2941 .65726 m .29424 .60177 L .32175 .60629 L p .707 .577 .707 r
F P
0 g
s
.18263 .73503 m .18162 .69743 L .20554 .69238 L p .707 .577 .707 r
F P
0 g
s
.20188 .60393 m .20174 .65943 L .17775 .66516 L p .707 .577 .707 r
F P
0 g
s
.20656 .72452 m .21016 .71003 L .23885 .70587 L p .707 .577 .707 r
F P
0 g
s
.20174 .65943 m .20188 .60393 L .23122 .60053 L p .707 .577 .707 r
F P
0 g
s
.73709 .6591 m .73695 .60343 L .70576 .60166 L p .707 .577 .707 r
F P
0 g
s
.73695 .60343 m .73709 .6591 L .76891 .65824 L p .707 .577 .707 r
F P
0 g
s
.76891 .65824 m .76878 .60257 L .73695 .60343 L p .707 .577 .707 r
F P
0 g
s
.20554 .69238 m .20655 .72998 L .18263 .73503 L p .707 .577 .707 r
F P
0 g
s
.76878 .60257 m .76891 .65824 L .79826 .65483 L p .707 .577 .707 r
F P
0 g
s
.79826 .65483 m .79812 .59917 L .76878 .60257 L p .707 .577 .707 r
F P
0 g
s
.32799 .73125 m .3244 .74574 L .2972 .73152 L p .707 .577 .707 r
F P
0 g
s
.2972 .73152 m .3008 .71703 L .32799 .73125 L p .707 .577 .707 r
F P
0 g
s
.3254 .69084 m .3264 .72844 L .29886 .72574 L p .707 .577 .707 r
F P
0 g
s
.3008 .71703 m .2972 .73152 L .26648 .72278 L p .707 .577 .707 r
F P
0 g
s
.26648 .72278 m .27008 .70828 L .3008 .71703 L p .707 .577 .707 r
F P
0 g
s
.29886 .72574 m .29785 .68815 L .3254 .69084 L p .707 .577 .707 r
F P
0 g
s
.29424 .60177 m .2941 .65726 L .26291 .65528 L p .707 .577 .707 r
F P
0 g
s
.26291 .65528 m .26305 .59978 L .29424 .60177 L p .707 .577 .707 r
F P
0 g
s
.70589 .65733 m .70576 .60166 L .67825 .59744 L p .707 .577 .707 r
F P
0 g
s
.70576 .60166 m .70589 .65733 L .73709 .6591 L p .707 .577 .707 r
F P
0 g
s
.23885 .70587 m .23525 .72037 L .20656 .72452 L p .707 .577 .707 r
F P
0 g
s
.23525 .72037 m .23885 .70587 L .27008 .70828 L p .707 .577 .707 r
F P
0 g
s
.39228 .25559 m .39228 .75748 L .36791 .76767 L p .707 .577 .707 r
F P
0 g
s
.39228 .75748 m .39228 .25559 L .42719 .24792 L p .707 .577 .707 r
F P
0 g
s
.23108 .65603 m .23122 .60053 L .26305 .59978 L p .707 .577 .707 r
F P
0 g
s
.23122 .60053 m .23108 .65603 L .20174 .65943 L p .707 .577 .707 r
F P
0 g
s
.20655 .72998 m .20554 .69238 L .23484 .68896 L p .707 .577 .707 r
F P
0 g
s
.26305 .59978 m .26291 .65528 L .23108 .65603 L p .707 .577 .707 r
F P
0 g
s
.27008 .70828 m .26648 .72278 L .23525 .72037 L p .707 .577 .707 r
F P
0 g
s
.79812 .59917 m .79826 .65483 L .82225 .64922 L p .707 .577 .707 r
F P
0 g
s
.82225 .64922 m .82211 .59356 L .79812 .59917 L p .707 .577 .707 r
F P
0 g
s
.23484 .68896 m .23585 .72655 L .20655 .72998 L p .707 .577 .707 r
F P
0 g
s
.29785 .68815 m .29886 .72574 L .26766 .72509 L p .707 .577 .707 r
F P
0 g
s
.26766 .72509 m .26665 .6875 L .29785 .68815 L p .707 .577 .707 r
F P
0 g
s
.59593 .25242 m .59593 .75431 L .55795 .74777 L p .707 .577 .707 r
F P
0 g
s
.55795 .74777 m .55795 .24588 L .59593 .25242 L p .707 .577 .707 r
F P
0 g
s
.67825 .59744 m .67839 .65311 L .70589 .65733 L p .707 .577 .707 r
F P
0 g
s
.67839 .65311 m .67825 .59744 L .65712 .59118 L p .707 .577 .707 r
F P
0 g
s
.23585 .72655 m .23484 .68896 L .26665 .6875 L p .707 .577 .707 r
F P
0 g
s
.26665 .6875 m .26766 .72509 L .23585 .72655 L p .707 .577 .707 r
F P
0 g
s
.73234 .72253 m .73335 .68618 L .70214 .68316 L p .707 .577 .707 r
F P
0 g
s
.73335 .68618 m .73234 .72253 L .76415 .72231 L p .707 .577 .707 r
F P
0 g
s
.76415 .72231 m .76515 .68596 L .73335 .68618 L p .707 .577 .707 r
F P
0 g
s
.82211 .59356 m .82225 .64922 L .83853 .64195 L p .707 .577 .707 r
F P
0 g
s
.83853 .64195 m .8384 .58628 L .82211 .59356 L p .707 .577 .707 r
F P
0 g
s
.76515 .68596 m .76415 .72231 L .79345 .71888 L p .707 .577 .707 r
F P
0 g
s
.79345 .71888 m .79445 .68253 L .76515 .68596 L p .707 .577 .707 r
F P
0 g
s
.42719 .74981 m .42719 .24792 L .46924 .24351 L p .707 .577 .707 r
F P
0 g
s
.42719 .24792 m .42719 .74981 L .39228 .75748 L p .707 .577 .707 r
F P
0 g
s
.65712 .59118 m .65726 .64685 L .67839 .65311 L p .707 .577 .707 r
F P
0 g
s
.70114 .71951 m .70214 .68316 L .6746 .6772 L p .707 .577 .707 r
F P
0 g
s
.70214 .68316 m .70114 .71951 L .73234 .72253 L p .707 .577 .707 r
F P
0 g
s
.55795 .24588 m .55795 .74777 L .51429 .7447 L p .707 .577 .707 r
F P
0 g
s
.51429 .7447 m .51429 .24281 L .55795 .24588 L p .707 .577 .707 r
F P
0 g
s
.65726 .64685 m .65712 .59118 L .64444 .58349 L p .707 .577 .707 r
F P
0 g
s
.79445 .68253 m .79345 .71888 L .81737 .71256 L p .707 .577 .707 r
F P
0 g
s
.81737 .71256 m .81838 .67621 L .79445 .68253 L p .707 .577 .707 r
F P
0 g
s
.6746 .6772 m .6736 .71355 L .70114 .71951 L p .707 .577 .707 r
F P
0 g
s
.6992 .70393 m .70279 .72261 L .73351 .71582 L p .707 .577 .707 r
F P
0 g
s
.73351 .71582 m .72992 .69715 L .6992 .70393 L p .707 .577 .707 r
F P
0 g
s
.72992 .69715 m .73351 .71582 L .76475 .71046 L p .707 .577 .707 r
F P
0 g
s
.46924 .7454 m .46924 .24351 L .51429 .24281 L p .707 .577 .707 r
F P
0 g
s
.46924 .24351 m .46924 .7454 L .42719 .74981 L p .707 .577 .707 r
F P
0 g
s
.6736 .71355 m .6746 .6772 L .65341 .66887 L p .707 .577 .707 r
F P
0 g
s
.76475 .71046 m .76115 .69179 L .72992 .69715 L p .707 .577 .707 r
F P
0 g
s
.51429 .24281 m .51429 .7447 L .46924 .7454 L p .707 .577 .707 r
F P
0 g
s
.76115 .69179 m .76475 .71046 L .79343 .70705 L p .707 .577 .707 r
F P
0 g
s
.65341 .66887 m .65241 .70522 L .6736 .71355 L p .707 .577 .707 r
F P
0 g
s
.672 .71148 m .6756 .73016 L .70279 .72261 L p .707 .577 .707 r
F P
0 g
s
.70279 .72261 m .6992 .70393 L .672 .71148 L p .707 .577 .707 r
F P
0 g
s
.79343 .70705 m .78984 .68838 L .76115 .69179 L p .707 .577 .707 r
F P
0 g
s
.64444 .58349 m .64458 .63916 L .65726 .64685 L p .707 .577 .707 r
F P
0 g
s
.8384 .58628 m .83853 .64195 L .84552 .63373 L p .707 .577 .707 r
F P
0 g
s
.84552 .63373 m .84539 .57806 L .8384 .58628 L p .707 .577 .707 r
F P
0 g
s
.81838 .67621 m .81737 .71256 L .83358 .70398 L p .707 .577 .707 r
F P
0 g
s
.83358 .70398 m .83458 .66762 L .81838 .67621 L p .707 .577 .707 r
F P
0 g
s
.78984 .68838 m .79343 .70705 L .81677 .70593 L p .707 .577 .707 r
F P
0 g
s
.65099 .71906 m .65458 .73773 L .6756 .73016 L p .707 .577 .707 r
F P
0 g
s
.6756 .73016 m .672 .71148 L .65099 .71906 L p .707 .577 .707 r
F P
0 g
s
.81677 .70593 m .81318 .68726 L .78984 .68838 L p .707 .577 .707 r
F P
0 g
s
.64458 .63916 m .64444 .58349 L .64145 .57512 L p .707 .577 .707 r
F P
0 g
s
.65241 .70522 m .65341 .66887 L .64066 .659 L p .707 .577 .707 r
F P
0 g
s
.64066 .659 m .63965 .69535 L .65241 .70522 L p .707 .577 .707 r
F P
0 g
s
.64145 .57512 m .64158 .63079 L .64458 .63916 L p .707 .577 .707 r
F P
0 g
s
.81318 .68726 m .81677 .70593 L .83247 .70721 L p .707 .577 .707 r
F P
0 g
s
.84539 .57806 m .84552 .63373 L .84253 .62536 L p .707 .577 .707 r
F P
0 g
s
.84253 .62536 m .84239 .5697 L .84539 .57806 L p .707 .577 .707 r
F P
0 g
s
.83247 .70721 m .82888 .68853 L .81318 .68726 L p .707 .577 .707 r
F P
0 g
s
.83458 .66762 m .83358 .70398 L .84048 .69397 L p .707 .577 .707 r
F P
0 g
s
.84048 .69397 m .84148 .65762 L .83458 .66762 L p .707 .577 .707 r
F P
0 g
s
.63821 .72592 m .64181 .74459 L .65458 .73773 L p .707 .577 .707 r
F P
0 g
s
.65458 .73773 m .65099 .71906 L .63821 .72592 L p .707 .577 .707 r
F P
0 g
s
.63965 .69535 m .64066 .659 L .63758 .64855 L p .707 .577 .707 r
F P
0 g
s
.64158 .63079 m .64145 .57512 L .64844 .5669 L p .707 .577 .707 r
F P
0 g
s
.63758 .64855 m .63657 .6849 L .63965 .69535 L p .707 .577 .707 r
F P
0 g
s
.82888 .68853 m .83247 .70721 L .839 .71075 L p .707 .577 .707 r
F P
0 g
s
.64844 .5669 m .64857 .62257 L .64158 .63079 L p .707 .577 .707 r
F P
0 g
s
.839 .71075 m .83541 .69208 L .82888 .68853 L p .707 .577 .707 r
F P
0 g
s
.84239 .5697 m .84253 .62536 L .82985 .61767 L p .707 .577 .707 r
F P
0 g
s
.82985 .61767 m .82971 .56201 L .84239 .5697 L p .707 .577 .707 r
F P
0 g
s
.63493 .73138 m .63852 .75006 L .64181 .74459 L p .707 .577 .707 r
F P
0 g
s
.64181 .74459 m .63821 .72592 L .63493 .73138 L p .707 .577 .707 r
F P
0 g
s
.84148 .65762 m .84048 .69397 L .8374 .68352 L p .707 .577 .707 r
F P
0 g
s
.8374 .68352 m .8384 .64717 L .84148 .65762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63657 .6849 m .63758 .64855 L .64448 .63855 L p .707 .577 .707 r
F P
0 g
s
.64857 .62257 m .64844 .5669 L .66472 .55963 L p .707 .577 .707 r
F P
0 g
s
.39867 .61999 m .39836 .56444 L .36716 .56272 L p .707 .577 .707 r
F P
0 g
s
.39836 .56444 m .39867 .61999 L .4305 .61901 L p .707 .577 .707 r
F P
0 g
s
.4305 .61901 m .43018 .56347 L .39836 .56444 L p .707 .577 .707 r
F P
0 g
s
.43018 .56347 m .4305 .61901 L .45984 .61542 L p .707 .577 .707 r
F P
0 g
s
.45984 .61542 m .45953 .55988 L .43018 .56347 L p .707 .577 .707 r
F P
0 g
s
.64448 .63855 m .64347 .6749 L .63657 .6849 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36748 .61826 m .36716 .56272 L .33966 .55846 L p .707 .577 .707 r
F P
0 g
s
.36716 .56272 m .36748 .61826 L .39867 .61999 L p .707 .577 .707 r
F P
0 g
s
.66472 .55963 m .66486 .6153 L .64857 .62257 L p .707 .577 .707 r
F P
0 g
s
.83541 .69208 m .839 .71075 L .83571 .71622 L p .707 .577 .707 r
F P
0 g
s
.82971 .56201 m .82985 .61767 L .80872 .61141 L p .707 .577 .707 r
F P
0 g
s
.80872 .61141 m .80859 .55575 L .82971 .56201 L p .707 .577 .707 r
F P
0 g
s
.83571 .71622 m .83212 .69755 L .83541 .69208 L p .707 .577 .707 r
F P
0 g
s
.8384 .64717 m .8374 .68352 L .82464 .67365 L p .707 .577 .707 r
F P
0 g
s
.82464 .67365 m .82564 .6373 L .8384 .64717 L p .707 .577 .707 r
F P
0 g
s
.64146 .73493 m .64505 .7536 L .63852 .75006 L p .707 .577 .707 r
F P
0 g
s
.63852 .75006 m .63493 .73138 L .64146 .73493 L p .707 .577 .707 r
F P
0 g
s
.45953 .55988 m .45984 .61542 L .48383 .60958 L p .707 .577 .707 r
F P
0 g
s
.48383 .60958 m .48351 .55403 L .45953 .55988 L p .707 .577 .707 r
F P
0 g
s
.38718 .67844 m .38951 .6412 L .35836 .63768 L p .707 .577 .707 r
F P
0 g
s
.38951 .6412 m .38718 .67844 L .41894 .67957 L p .707 .577 .707 r
F P
0 g
s
.41894 .67957 m .42127 .64233 L .38951 .6412 L p .707 .577 .707 r
F P
0 g
s
.66486 .6153 m .66472 .55963 L .68871 .55402 L p .707 .577 .707 r
F P
0 g
s
.64347 .6749 m .64448 .63855 L .66068 .62996 L p .707 .577 .707 r
F P
0 g
s
.42127 .64233 m .41894 .67957 L .4482 .6782 L p .707 .577 .707 r
F P
0 g
s
.4482 .6782 m .45054 .64096 L .42127 .64233 L p .707 .577 .707 r
F P
0 g
s
.33966 .55846 m .33997 .614 L .36748 .61826 L p .707 .577 .707 r
F P
0 g
s
.33997 .614 m .33966 .55846 L .31853 .55208 L p .707 .577 .707 r
F P
0 g
s
.35602 .67492 m .35836 .63768 L .33087 .63211 L p .707 .577 .707 r
F P
0 g
s
.35836 .63768 m .35602 .67492 L .38718 .67844 L p .707 .577 .707 r
F P
0 g
s
.80859 .55575 m .80872 .61141 L .78121 .60719 L p .707 .577 .707 r
F P
0 g
s
.78121 .60719 m .78108 .55152 L .80859 .55575 L p .707 .577 .707 r
F P
0 g
s
.33087 .63211 m .32853 .66936 L .35602 .67492 L p .707 .577 .707 r
F P
0 g
s
.66068 .62996 m .65968 .66632 L .64347 .6749 L p .707 .577 .707 r
F P
0 g
s
.68871 .55402 m .68885 .60969 L .66486 .6153 L p .707 .577 .707 r
F P
0 g
s
.45054 .64096 m .4482 .6782 L .4721 .67447 L p .707 .577 .707 r
F P
0 g
s
.4721 .67447 m .47443 .63722 L .45054 .64096 L p .707 .577 .707 r
F P
0 g
s
.48351 .55403 m .48383 .60958 L .50012 .60205 L p .707 .577 .707 r
F P
0 g
s
.50012 .60205 m .4998 .5465 L .48351 .55403 L p .707 .577 .707 r
F P
0 g
s
.41506 .72972 m .40709 .71399 L .37807 .7269 L p .707 .577 .707 r
F P
0 g
s
.40709 .71399 m .41506 .72972 L .44199 .7134 L p .707 .577 .707 r
F P
0 g
s
.44199 .7134 m .43402 .69767 L .40709 .71399 L p .707 .577 .707 r
F P
0 g
s
.31853 .55208 m .31885 .60762 L .33997 .614 L p .707 .577 .707 r
F P
0 g
s
.68885 .60969 m .68871 .55402 L .71806 .55062 L p .707 .577 .707 r
F P
0 g
s
.83212 .69755 m .83571 .71622 L .82294 .72308 L p .707 .577 .707 r
F P
0 g
s
.82564 .6373 m .82464 .67365 L .80345 .66533 L p .707 .577 .707 r
F P
0 g
s
.80345 .66533 m .80446 .62897 L .82564 .6373 L p .707 .577 .707 r
F P
0 g
s
.32853 .66936 m .33087 .63211 L .30973 .62505 L p .707 .577 .707 r
F P
0 g
s
.38604 .74264 m .37807 .7269 L .34982 .73514 L p .707 .577 .707 r
F P
0 g
s
.37807 .7269 m .38604 .74264 L .41506 .72972 L p .707 .577 .707 r
F P
0 g
s
.43402 .69767 m .44199 .7134 L .46419 .69528 L p .707 .577 .707 r
F P
0 g
s
.46419 .69528 m .45622 .67954 L .43402 .69767 L p .707 .577 .707 r
F P
0 g
s
.82294 .72308 m .81935 .70441 L .83212 .69755 L p .707 .577 .707 r
F P
0 g
s
.65716 .7362 m .66075 .75488 L .64505 .7536 L p .707 .577 .707 r
F P
0 g
s
.64505 .7536 m .64146 .73493 L .65716 .7362 L p .707 .577 .707 r
F P
0 g
s
.31885 .60762 m .31853 .55208 L .30585 .5442 L p .707 .577 .707 r
F P
0 g
s
.65968 .66632 m .66068 .62996 L .6846 .62364 L p .707 .577 .707 r
F P
0 g
s
.78108 .55152 m .78121 .60719 L .75002 .60542 L p .707 .577 .707 r
F P
0 g
s
.75002 .60542 m .74988 .54976 L .78108 .55152 L p .707 .577 .707 r
F P
0 g
s
.34982 .73514 m .35778 .75088 L .38604 .74264 L p .707 .577 .707 r
F P
0 g
s
.30973 .62505 m .30739 .66229 L .32853 .66936 L p .707 .577 .707 r
F P
0 g
s
.71819 .60628 m .71806 .55062 L .74988 .54976 L p .707 .577 .707 r
F P
0 g
s
.71806 .55062 m .71819 .60628 L .68885 .60969 L p .707 .577 .707 r
F P
0 g
s
.35778 .75088 m .34982 .73514 L .32508 .73791 L p .707 .577 .707 r
F P
0 g
s
.74988 .54976 m .75002 .60542 L .71819 .60628 L p .707 .577 .707 r
F P
0 g
s
.47443 .63722 m .4721 .67447 L .48829 .66873 L p .707 .577 .707 r
F P
0 g
s
.48829 .66873 m .49063 .63149 L .47443 .63722 L p .707 .577 .707 r
F P
0 g
s
.45622 .67954 m .46419 .69528 L .4795 .67711 L p .707 .577 .707 r
F P
0 g
s
.4795 .67711 m .47153 .66138 L .45622 .67954 L p .707 .577 .707 r
F P
0 g
s
.6846 .62364 m .6836 .66 L .65968 .66632 L p .707 .577 .707 r
F P
0 g
s
.32508 .73791 m .33305 .75365 L .35778 .75088 L p .707 .577 .707 r
F P
0 g
s
.80446 .62897 m .80345 .66533 L .77591 .65936 L p .707 .577 .707 r
F P
0 g
s
.77591 .65936 m .77691 .62301 L .80446 .62897 L p .707 .577 .707 r
F P
0 g
s
.30585 .5442 m .30616 .59975 L .31885 .60762 L p .707 .577 .707 r
F P
0 g
s
.4998 .5465 m .50012 .60205 L .50711 .59357 L p .707 .577 .707 r
F P
0 g
s
.50711 .59357 m .50679 .53803 L .4998 .5465 L p .707 .577 .707 r
F P
0 g
s
.30739 .66229 m .30973 .62505 L .29701 .61718 L p .707 .577 .707 r
F P
0 g
s
.6836 .66 m .6846 .62364 L .7139 .62021 L p .707 .577 .707 r
F P
0 g
s
.81935 .70441 m .82294 .72308 L .80193 .73065 L p .707 .577 .707 r
F P
0 g
s
.80193 .73065 m .79833 .71198 L .81935 .70441 L p .707 .577 .707 r
F P
0 g
s
.6805 .73508 m .68409 .75376 L .66075 .75488 L p .707 .577 .707 r
F P
0 g
s
.66075 .75488 m .65716 .7362 L .6805 .73508 L p .707 .577 .707 r
F P
0 g
s
.29701 .61718 m .29467 .65442 L .30739 .66229 L p .707 .577 .707 r
F P
0 g
s
.33305 .75365 m .32508 .73791 L .30628 .73493 L p .707 .577 .707 r
F P
0 g
s
.30616 .59975 m .30585 .5442 L .30285 .53561 L p .707 .577 .707 r
F P
0 g
s
.77691 .62301 m .77591 .65936 L .74471 .65634 L p .707 .577 .707 r
F P
0 g
s
.74471 .65634 m .74571 .61999 L .77691 .62301 L p .707 .577 .707 r
F P
0 g
s
.47153 .66138 m .4795 .67711 L .48642 .6607 L p .707 .577 .707 r
F P
0 g
s
.48642 .6607 m .47845 .64496 L .47153 .66138 L p .707 .577 .707 r
F P
0 g
s
.7129 .65656 m .7139 .62021 L .74571 .61999 L p .707 .577 .707 r
F P
0 g
s
.7139 .62021 m .7129 .65656 L .6836 .66 L p .707 .577 .707 r
F P
0 g
s
.30628 .73493 m .31425 .75067 L .33305 .75365 L p .707 .577 .707 r
F P
0 g
s
.49063 .63149 m .48829 .66873 L .4952 .66156 L p .707 .577 .707 r
F P
0 g
s
.4952 .66156 m .49754 .62431 L .49063 .63149 L p .707 .577 .707 r
F P
0 g
s
.74571 .61999 m .74471 .65634 L .7129 .65656 L p .707 .577 .707 r
F P
0 g
s
.30285 .53561 m .30317 .59115 L .30616 .59975 L p .707 .577 .707 r
F P
0 g
s
.79833 .71198 m .80193 .73065 L .77473 .7382 L p .707 .577 .707 r
F P
0 g
s
.29467 .65442 m .29701 .61718 L .29395 .60926 L p .707 .577 .707 r
F P
0 g
s
.50679 .53803 m .50711 .59357 L .50412 .58497 L p .707 .577 .707 r
F P
0 g
s
.50412 .58497 m .5038 .52943 L .50679 .53803 L p .707 .577 .707 r
F P
0 g
s
.70918 .73168 m .71278 .75035 L .68409 .75376 L p .707 .577 .707 r
F P
0 g
s
.68409 .75376 m .6805 .73508 L .70918 .73168 L p .707 .577 .707 r
F P
0 g
s
.77473 .7382 m .77113 .71953 L .79833 .71198 L p .707 .577 .707 r
F P
0 g
s
.31425 .75067 m .30628 .73493 L .29527 .72649 L p .707 .577 .707 r
F P
0 g
s
.29395 .60926 m .29161 .64651 L .29467 .65442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.47845 .64496 m .48642 .6607 L .48427 .64763 L p .707 .577 .707 r
F P
0 g
s
.48427 .64763 m .4763 .63189 L .47845 .64496 L p .707 .577 .707 r
F P
0 g
s
.30317 .59115 m .30285 .53561 L .30984 .52713 L p .707 .577 .707 r
F P
0 g
s
.77113 .71953 m .77473 .7382 L .74401 .74499 L p .707 .577 .707 r
F P
0 g
s
.29527 .72649 m .30324 .74223 L .31425 .75067 L p .707 .577 .707 r
F P
0 g
s
.74042 .72632 m .74401 .74499 L .71278 .75035 L p .707 .577 .707 r
F P
0 g
s
.71278 .75035 m .70918 .73168 L .74042 .72632 L p .707 .577 .707 r
F P
0 g
s
.74401 .74499 m .74042 .72632 L .77113 .71953 L p .707 .577 .707 r
F P
0 g
s
.49754 .62431 m .4952 .66156 L .49215 .65365 L p .707 .577 .707 r
F P
0 g
s
.49215 .65365 m .49448 .6164 L .49754 .62431 L p .707 .577 .707 r
F P
0 g
s
.30984 .52713 m .31016 .58267 L .30317 .59115 L p .707 .577 .707 r
F P
0 g
s
.29161 .64651 m .29395 .60926 L .30086 .60209 L p .707 .577 .707 r
F P
0 g
s
.5038 .52943 m .50412 .58497 L .49144 .5771 L p .707 .577 .707 r
F P
0 g
s
.49144 .5771 m .49112 .52156 L .5038 .52943 L p .707 .577 .707 r
F P
0 g
s
.30324 .74223 m .29527 .72649 L .29311 .71343 L p .707 .577 .707 r
F P
0 g
s
.30086 .60209 m .29852 .63933 L .29161 .64651 L p .707 .577 .707 r
F P
0 g
s
.4763 .63189 m .48427 .64763 L .47325 .63919 L p .707 .577 .707 r
F P
0 g
s
.47325 .63919 m .46528 .62346 L .4763 .63189 L p .707 .577 .707 r
F P
0 g
s
.29311 .71343 m .30108 .72917 L .30324 .74223 L p .707 .577 .707 r
F P
0 g
s
.31016 .58267 m .30984 .52713 L .32613 .5196 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49448 .6164 m .49215 .65365 L .47942 .64577 L p .707 .577 .707 r
F P
0 g
s
.47942 .64577 m .48176 .60853 L .49448 .6164 L p .707 .577 .707 r
F P
0 g
s
.32613 .5196 m .32645 .57514 L .31016 .58267 L p .707 .577 .707 r
F P
0 g
s
.49112 .52156 m .49144 .5771 L .47031 .57072 L p .707 .577 .707 r
F P
0 g
s
.47031 .57072 m .46999 .51518 L .49112 .52156 L p .707 .577 .707 r
F P
0 g
s
.29852 .63933 m .30086 .60209 L .31705 .59635 L p .707 .577 .707 r
F P
0 g
s
.30108 .72917 m .29311 .71343 L .30003 .69701 L p .707 .577 .707 r
F P
0 g
s
.31705 .59635 m .31472 .6336 L .29852 .63933 L p .707 .577 .707 r
F P
0 g
s
.32645 .57514 m .32613 .5196 L .35012 .51375 L p .707 .577 .707 r
F P
0 g
s
.46528 .62346 m .47325 .63919 L .45446 .63621 L p .707 .577 .707 r
F P
0 g
s
.45446 .63621 m .44649 .62047 L .46528 .62346 L p .707 .577 .707 r
F P
0 g
s
.30003 .69701 m .308 .71275 L .30108 .72917 L p .707 .577 .707 r
F P
0 g
s
.48176 .60853 m .47942 .64577 L .45828 .63871 L p .707 .577 .707 r
F P
0 g
s
.45828 .63871 m .46062 .60146 L .48176 .60853 L p .707 .577 .707 r
F P
0 g
s
.46999 .51518 m .47031 .57072 L .4428 .56646 L p .707 .577 .707 r
F P
0 g
s
.4428 .56646 m .44248 .51091 L .46999 .51518 L p .707 .577 .707 r
F P
0 g
s
.35012 .51375 m .35044 .5693 L .32645 .57514 L p .707 .577 .707 r
F P
0 g
s
.31472 .6336 m .31705 .59635 L .34095 .59262 L p .707 .577 .707 r
F P
0 g
s
.35044 .5693 m .35012 .51375 L .37946 .51017 L p .707 .577 .707 r
F P
0 g
s
.308 .71275 m .30003 .69701 L .31534 .67885 L p .707 .577 .707 r
F P
0 g
s
.44649 .62047 m .45446 .63621 L .42972 .63898 L p .707 .577 .707 r
F P
0 g
s
.42972 .63898 m .42175 .62324 L .44649 .62047 L p .707 .577 .707 r
F P
0 g
s
.34095 .59262 m .33862 .62986 L .31472 .6336 L p .707 .577 .707 r
F P
0 g
s
.44248 .51091 m .4428 .56646 L .41161 .56473 L p .707 .577 .707 r
F P
0 g
s
.41161 .56473 m .41129 .50919 L .44248 .51091 L p .707 .577 .707 r
F P
0 g
s
.31534 .67885 m .32331 .69459 L .308 .71275 L p .707 .577 .707 r
F P
0 g
s
.37978 .56571 m .37946 .51017 L .41129 .50919 L p .707 .577 .707 r
F P
0 g
s
.37946 .51017 m .37978 .56571 L .35044 .5693 L p .707 .577 .707 r
F P
0 g
s
.46062 .60146 m .45828 .63871 L .43079 .63314 L p .707 .577 .707 r
F P
0 g
s
.43079 .63314 m .43313 .5959 L .46062 .60146 L p .707 .577 .707 r
F P
0 g
s
.41129 .50919 m .41161 .56473 L .37978 .56571 L p .707 .577 .707 r
F P
0 g
s
.33862 .62986 m .34095 .59262 L .37021 .59125 L p .707 .577 .707 r
F P
0 g
s
.32331 .69459 m .31534 .67885 L .33755 .66072 L p .707 .577 .707 r
F P
0 g
s
.42175 .62324 m .42972 .63898 L .40146 .64723 L p .707 .577 .707 r
F P
0 g
s
.40146 .64723 m .39349 .63149 L .42175 .62324 L p .707 .577 .707 r
F P
0 g
s
.37021 .59125 m .36788 .62849 L .33862 .62986 L p .707 .577 .707 r
F P
0 g
s
.43313 .5959 m .43079 .63314 L .39964 .62962 L p .707 .577 .707 r
F P
0 g
s
.39964 .62962 m .40198 .59238 L .43313 .5959 L p .707 .577 .707 r
F P
0 g
s
.33755 .66072 m .34552 .67646 L .32331 .69459 L p .707 .577 .707 r
F P
0 g
s
.36788 .62849 m .37021 .59125 L .40198 .59238 L p .707 .577 .707 r
F P
0 g
s
.40198 .59238 m .39964 .62962 L .36788 .62849 L p .707 .577 .707 r
F P
0 g
s
.34552 .67646 m .33755 .66072 L .36447 .6444 L p .707 .577 .707 r
F P
0 g
s
.39349 .63149 m .40146 .64723 L .37244 .66014 L p .707 .577 .707 r
F P
0 g
s
.37244 .66014 m .36447 .6444 L .39349 .63149 L p .707 .577 .707 r
F P
0 g
s
.36447 .6444 m .37244 .66014 L .34552 .67646 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF2`002eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol00`00FUIJEP080004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0061oo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005aoo`@000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00FWoo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Aoo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00
EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo00mooaP003eoo`00EWoo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001oogoo00Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<003Uo
o`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Eoo`@00003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@003Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00@0035oo`00EWoo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001oogooOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000`Ool005Ioo`03001JEP0000=JEP03001JEUYF00=JEPL000EJEPD000IJEPP000AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000Ool000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000002ioo`00EWoo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH00eYF1@001eYF00<005YFFUH015YF1P0015YF00@005YFFUIJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`03001JEP0000=JEP80009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF009JEP80
0003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Ioo`04001JEP00FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH20000
0eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020000
1EYF000005YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P000UYF00@005YF
FUIJEQT000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo001FOol200000eYF000000030002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;7oo000nOolA0008Ool200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol60003FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH80003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH30005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P000UYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQX000=JEP03001JEUYF
00=JEP04001JEUYFFUH2000/Ool0035oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP@000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;7oo000_Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH2000/Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<000=JEP8002aoo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03
001JEUYF00AJEQ40009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH00000
02aoo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH70003FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF0`00;7oo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<0009JEP03001JEUYF009JEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF1P0000=J
EP00FUH0100000EJEP00FUIJEP0000AJEP800003FUH005YF00AJEPP000AJEP03001JEUYF00=JEP06
001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000AJEP00000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00<000AJEP03001JEP0002aoo`00:goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH0
15YF00<005YFFUH00eYF1P0000=JEP0000000eYF00<005YFFUH01UYF2`0015YF00H005YFFUH005YF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH2000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP04
001JEUYFFUH20006FUH00`00FUIJEP03FUH@00001eYF001JEUYF001JEP0000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH0000002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00@005YF000000QJEP03
001JEUYF00@000QJEP03001JEUYF00=JEP<0009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002]o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<000UJEP<000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0000@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP<000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH00000008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH00UYF5P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00@000QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000008000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH70008FUH50004FUH01000FUIJEUYF0P0000=J
EP00FUH015YF00@005YF000000QJEP8000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEPH000Iooa4000IJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002]oo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00=JEP<000AJEP800003FUH005YF00EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEP0000@000=JEP03001oogoo01Ioo`@0009JEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002]oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP@00005FUH005YFFUH00005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH30006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP<000AJEP05001JEUYFFUH0
000;Ool3000>Ool40004FUH01000FUIJEUYF0P00;Goo000[Ool01000FUH005YF0P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP05
001JEUYFFUH00008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001J
EP040005FUH01000FUIJEUYF0P002Goo1@004Goo0`0000=JEP00FUH00UYF0P00;Goo000[Ool01P00
FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYF0005FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH0
05YF00800003FUH005YF00<000=JEP04001JEUYFFUH20009Ool5000DOol20003FUH2000]Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000MJEP@0009JEP03001JEP0000P000AJEP03001JEUYF009JEPL000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=J
EP03001JEUYF009JEP@000=JEP8000Uoo`D0019oo`80009JEP04001JEUYF000^Ool002]oo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000IJEP800004FUH005YF0002FUH00`00FUIJEP04FUH300000eYF000000070005FUH00`00FUIJ
EP03FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP020003FUH00`00FUIJEP03FUH00`00FUH00005000:Ool3000?Ool400000eYF001JEP02FUH3000^
Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP07001JEUYFFUH005YF00000UYF00<005YFFUH00eYF1@001UYF00<0
05YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH00eYF1`004Woo1@001EYF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF6P000UYF00@005YFFUIJ
EP8000=JEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHQ00000eYF001oo`0]Ool002aoo`05001J
EUYFFUH00005FUH00`00FUIJEP060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YF00000`000eYF0`000UYF00<005YFFUH00eYF1@001UYF00@005YFFUIJEP8000=JEP04
001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<0
05YFFUH015YF00@005YFFUIJEP@002ioo`00;Goo0P0000=JEP00FUH00eYF100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF0P000UYF1@0000Eoo`00FUIJEP0000IJ
EP<000MJEP04001JEUYF0006FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;goo
0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YF00001EYF10000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF00001UYF00@005YFFUH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03000_Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000=JEP04001JEUYF0005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF0`00
1EYF00D005YFFUIJEP0000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP@000EJEP03001JEUYF00EJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000<002moo`00;goo0P000UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUH000EJEP04001J
EUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0015YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P0015YF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJ
EPD0009JEP03001JEP0002ioo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0`0000=J
EP00FUH0100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH00eYF
0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000EJEP03001JEUYF
00MJEP03001JEUYF009JEPT000=JEP<000AJEP03001JEUYF009JEP8002ioo`00;Goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJ
EP0000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP020007FUH2
0008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH400001UYF00000000FUH000MJEP03001JEUYF00AJEPL000AJEP04001JEUYFFUH400000eYF
001JEP05FUH01@00FUIJEUYF0000;goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00
15YF00<005YFFUH01EYF00<005YFFUH010000UYF1@0015YF10001EYF00<005YFFUH015YF00@005YF
0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000=JEP00FUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
009JEP<000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP03FUH40002Ool=0002FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000bOol002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEQD00004FUH000000004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF00000P00
1eYF00H005YF000005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH015YF00<005YF000010002Goo1@001UYF00<0
05YFFUH01EYF00<005YF00000P00=Goo000]Ool00`00FUH00003FUH00`00FUIJEP03FUHJ00000eYF
00000002FUH70003FUH01000FUIJEP000UYF0P0000=JEP00FUH025YF00D005YFFUIJEP0000]JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJ
EP03001JEUYF009JEP<0009JEP03001JEP0000Eoo`@0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP<003Qoo`00;Goo00<005YF00000eYF00<005YF00000`001UYF00<005YFFUH01EYF1@001EYF00<0
05YF00001P000eYF1P000UYF0`0015YF00<005YFFUH015YF0P0015YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH010000UYF00<0
05YF00000P001EYF00<005YF00001@001UYF00<005YFFUH01eYF00<005YF00000`00>goo000]Ool0
0`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH01`00FUIJEUYF001J
EP00009JEP/000MJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH03P000eYF00<005YF
FUH01eYF00<005YFFUH015YF1000?goo000]Ool00`00FUH000030004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<0
05YFFUH01eYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01000@goo000]Ool300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP07FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1@00Agoo
000]Ool50005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0003FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH01eYF00@005YFFUIJEPH000MJ
EP03001JEUYF00UJEP03001JEP0000P000QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01000C7oo000]Ool300000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH01000FUIJ
EUYF1`001UYF00<005YFFUH01EYF1`0035YF00<005YFFUH02EYF00<005YFFUH025YF1P000UYF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH6001@Ool0
02ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00H00004FUH000000002FUH00`00FUIJEP04FUH00`00FUIJEP050006FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40006FUH00`00FUIJ
EP02FUHA00000eYF001oo`1COol002ioo`@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF0080009JEP03001JEUYF00=J
EPD000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP8000AJ
EP03001JEUYF009JEP03001oogoo00Moo`<00003FUH005YF009JEP03001oogoo059oo`00;Goo0P00
0Woo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000`000Woo0P000UYF00@005YFFUH000=JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@00003FUH005YF00=JEP03001oogoo
00Qoo`@000=JEP8005=oo`00;Goo0P001Goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1@001goo00@005YFFUH0009JEP04001JEP000006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<0
07ooOol017oo100000AJEP00FUIJEP800003FUH0000005=oo`00;Goo00<005YF00002goo6`0037oo
00@005YFFUH0009JEP<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001oo`0000@000EJEP04001JEUYF
FUH4001COol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001COol002eoo`03001JEP00
01Moo`D001Moo`04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000Dgoo000]Ool01000FUH000005Woo1@0067oo
0`000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005=oo`00;Woo00<005YF00005Woo1@0067oo0`000eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00;Woo
00@005YFFUH001Ioo`<001Yoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1COol002ioo`05001JEUYFFUH0000bOol2
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP02001FOol002moo`04001JEUYF000bOol20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20006
FUH00`00FUIJEP04FUH3001HOol002moo`05001JEUYFFUH0000aOol00`00FUH00002FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP03FUH2001JOol0031oo`03001JEUYF0080035o
o`D000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000MJEP03001JEP0000<005aoo`00<Goo0P000UYF00<007ooOol0
;Woo00@007ooOomoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH40006FUH3001POol0035oo`8000=JEP8002eoo`80
00Eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP04001JEP000003FUH200000eYF00000002001SOol0039oo`03001JEUYF00=JEP03
001oogoo02Yoo`8000Uoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP@00003FUH005YF00AJEP8006Ioo`00<goo00<005YFFUH00eYF00<007ooOol0:7oo
0P003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02P00
25YF0`00Hgoo000dOol00`00FUIJEP02FUH3000WOol3000EOol90006FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH80004FUH60009FUH01000FUH00000HGoo000eOol200000eYF001JEP02FUH2000TOol0
0`00FUH0000OOolI0008Ool20002FUH500000eYF00000006FUH00`00FUIJEP02FUH2001OOol003Mo
o`8000EJEP80021oo`80009JEP03001oogoo041oo`800004FUH000000004FUH20004FUH00`00FUIJ
EP04FUH2001MOol003Qoo`03001JEUYF00EJEP<001]oo`800004FUH005YF0015Ool20008FUH20000
0eYF001JEP07FUH3001KOol003Uoo`8000IJEP04001JEP00000GOol20002FUH00`00FUH00018Ool2
0006FUH00`00FUH000020006FUH01000FUIJEUYF0P00FGoo000kOol20003FUH00`00FUIJEP02FUH3
000?Ool50004FUH2001;Ool20004FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH2001GOol0
03eoo`800003FUH005YF00IJEPl000=JEP03001JEUYF009JEP8004ioo`800003FUH005YF00IJEP80
0003FUH005YF00EJEP03001JEP0005Ioo`00?goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP80059oo`<000MJEP<000IJEP04001JEUYF001EOol0049oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00001GOol20005FUH00`00FUIJEP020003FUH00`00FUIJEP02
FUH00`00Oomoo`1BOol004Aoo`<00003FUH005YF00MJEP03001JEUYF009JEPD005]oo`<00003FUH0
05YF00AJEP800003FUH005YF00=JEP03001oogoo059oo`00Agoo3`00Hgoo0`001EYF0P0015YF0P00
E7oo002lOol300001EYF001JEUYF00000eYF00<007ooOol0Dgoo002oOol20003FUH4001EOol00<5o
o`800004FUH005YF001FOol00<=oo`@005Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59135 .74991 m .59154 .6943 L .56036 .69232 L p .707 .577 .707 r
F P
0 g
s
.59154 .6943 m .59135 .74991 L .62317 .74922 L p .707 .577 .707 r
F P
0 g
s
.62317 .74922 m .62337 .69362 L .59154 .6943 L p .707 .577 .707 r
F P
0 g
s
.62337 .69362 m .62317 .74922 L .65253 .74594 L p .707 .577 .707 r
F P
0 g
s
.65253 .74594 m .65273 .69034 L .62337 .69362 L p .707 .577 .707 r
F P
0 g
s
.56016 .74793 m .56036 .69232 L .53287 .68788 L p .707 .577 .707 r
F P
0 g
s
.56036 .69232 m .56016 .74793 L .59135 .74991 L p .707 .577 .707 r
F P
0 g
s
.65273 .69034 m .65253 .74594 L .67655 .74039 L p .707 .577 .707 r
F P
0 g
s
.67655 .74039 m .67674 .68478 L .65273 .69034 L p .707 .577 .707 r
F P
0 g
s
.53287 .68788 m .53267 .74348 L .56016 .74793 L p .707 .577 .707 r
F P
0 g
s
.53267 .74348 m .53287 .68788 L .51177 .6814 L p .707 .577 .707 r
F P
0 g
s
.59875 .8114 m .5973 .77454 L .56613 .77369 L p .707 .577 .707 r
F P
0 g
s
.5973 .77454 m .59875 .8114 L .63055 .8094 L p .707 .577 .707 r
F P
0 g
s
.63055 .8094 m .62911 .77255 L .5973 .77454 L p .707 .577 .707 r
F P
0 g
s
.62911 .77255 m .63055 .8094 L .65987 .80475 L p .707 .577 .707 r
F P
0 g
s
.65987 .80475 m .65843 .76789 L .62911 .77255 L p .707 .577 .707 r
F P
0 g
s
.56757 .81054 m .56613 .77369 L .53864 .77005 L p .707 .577 .707 r
F P
0 g
s
.56613 .77369 m .56757 .81054 L .59875 .8114 L p .707 .577 .707 r
F P
0 g
s
.67674 .68478 m .67655 .74039 L .69287 .7331 L p .707 .577 .707 r
F P
0 g
s
.69287 .7331 m .69306 .6775 L .67674 .68478 L p .707 .577 .707 r
F P
0 g
s
.51177 .6814 m .51157 .737 L .53267 .74348 L p .707 .577 .707 r
F P
0 g
s
.65843 .76789 m .65987 .80475 L .68384 .79788 L p .707 .577 .707 r
F P
0 g
s
.68384 .79788 m .68239 .76103 L .65843 .76789 L p .707 .577 .707 r
F P
0 g
s
.59776 .83791 m .60279 .81958 L .57275 .81039 L p .707 .577 .707 r
F P
0 g
s
.60279 .81958 m .59776 .83791 L .6285 .84571 L p .707 .577 .707 r
F P
0 g
s
.6285 .84571 m .63353 .82738 L .60279 .81958 L p .707 .577 .707 r
F P
0 g
s
.53864 .77005 m .54008 .80691 L .56757 .81054 L p .707 .577 .707 r
F P
0 g
s
.57275 .81039 m .56772 .82872 L .59776 .83791 L p .707 .577 .707 r
F P
0 g
s
.63353 .82738 m .6285 .84571 L .65694 .85135 L p .707 .577 .707 r
F P
0 g
s
.65694 .85135 m .66197 .83302 L .63353 .82738 L p .707 .577 .707 r
F P
0 g
s
.51157 .737 m .51177 .6814 L .49912 .67352 L p .707 .577 .707 r
F P
0 g
s
.56772 .82872 m .57275 .81039 L .54634 .80071 L p .707 .577 .707 r
F P
0 g
s
.54008 .80691 m .53864 .77005 L .51752 .76401 L p .707 .577 .707 r
F P
0 g
s
.54634 .80071 m .54131 .81904 L .56772 .82872 L p .707 .577 .707 r
F P
0 g
s
.66197 .83302 m .65694 .85135 L .68028 .8543 L p .707 .577 .707 r
F P
0 g
s
.68028 .8543 m .68531 .83597 L .66197 .83302 L p .707 .577 .707 r
F P
0 g
s
.51752 .76401 m .51896 .80086 L .54008 .80691 L p .707 .577 .707 r
F P
0 g
s
.68239 .76103 m .68384 .79788 L .7001 .78949 L p .707 .577 .707 r
F P
0 g
s
.7001 .78949 m .69866 .75263 L .68239 .76103 L p .707 .577 .707 r
F P
0 g
s
.49912 .67352 m .49892 .72913 L .51157 .737 L p .707 .577 .707 r
F P
0 g
s
.69306 .6775 m .69287 .7331 L .69989 .7248 L p .707 .577 .707 r
F P
0 g
s
.69989 .7248 m .70009 .6692 L .69306 .6775 L p .707 .577 .707 r
F P
0 g
s
.54131 .81904 m .54634 .80071 L .52617 .79149 L p .707 .577 .707 r
F P
0 g
s
.52617 .79149 m .52114 .80982 L .54131 .81904 L p .707 .577 .707 r
F P
0 g
s
.51896 .80086 m .51752 .76401 L .50484 .75613 L p .707 .577 .707 r
F P
0 g
s
.49892 .72913 m .49912 .67352 L .49617 .66502 L p .707 .577 .707 r
F P
0 g
s
.68531 .83597 m .68028 .8543 L .69625 .85424 L p .707 .577 .707 r
F P
0 g
s
.69625 .85424 m .70128 .83591 L .68531 .83597 L p .707 .577 .707 r
F P
0 g
s
.50484 .75613 m .50628 .79299 L .51896 .80086 L p .707 .577 .707 r
F P
0 g
s
.52114 .80982 m .52617 .79149 L .51419 .78363 L p .707 .577 .707 r
F P
0 g
s
.69866 .75263 m .7001 .78949 L .70708 .78038 L p .707 .577 .707 r
F P
0 g
s
.70708 .78038 m .70564 .74353 L .69866 .75263 L p .707 .577 .707 r
F P
0 g
s
.51419 .78363 m .50916 .80196 L .52114 .80982 L p .707 .577 .707 r
F P
0 g
s
.49617 .66502 m .49597 .72062 L .49892 .72913 L p .707 .577 .707 r
F P
0 g
s
.70009 .6692 m .69989 .7248 L .69693 .7163 L p .707 .577 .707 r
F P
0 g
s
.69693 .7163 m .69713 .66069 L .70009 .6692 L p .707 .577 .707 r
F P
0 g
s
.50628 .79299 m .50484 .75613 L .50184 .74721 L p .707 .577 .707 r
F P
0 g
s
.48751 .82178 m .48751 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.49597 .72062 m .49617 .66502 L .50319 .65671 L p .707 .577 .707 r
F P
0 g
s
.50184 .74721 m .50328 .78407 L .50628 .79299 L p .707 .577 .707 r
F P
0 g
s
.50916 .80196 m .51419 .78363 L .51159 .7779 L p .707 .577 .707 r
F P
0 g
s
.51159 .7779 m .50656 .79623 L .50916 .80196 L p .707 .577 .707 r
F P
0 g
s
.50319 .65671 m .50299 .71232 L .49597 .72062 L p .707 .577 .707 r
F P
0 g
s
.50328 .78407 m .50184 .74721 L .50881 .7381 L p .707 .577 .707 r
F P
0 g
s
.50299 .71232 m .50319 .65671 L .51951 .64943 L p .707 .577 .707 r
F P
0 g
s
.50881 .7381 m .51026 .77496 L .50328 .78407 L p .707 .577 .707 r
F P
0 g
s
.50656 .79623 m .51159 .7779 L .51861 .77486 L p .707 .577 .707 r
F P
0 g
s
.51861 .77486 m .51358 .79319 L .50656 .79623 L p .707 .577 .707 r
F P
0 g
s
.51951 .64943 m .51931 .70504 L .50299 .71232 L p .707 .577 .707 r
F P
0 g
s
.51026 .77496 m .50881 .7381 L .52508 .72971 L p .707 .577 .707 r
F P
0 g
s
.51931 .70504 m .51951 .64943 L .54352 .64388 L p .707 .577 .707 r
F P
0 g
s
.52508 .72971 m .52653 .76656 L .51026 .77496 L p .707 .577 .707 r
F P
0 g
s
.51358 .79319 m .51861 .77486 L .53458 .77481 L p .707 .577 .707 r
F P
0 g
s
.54352 .64388 m .54333 .69948 L .51931 .70504 L p .707 .577 .707 r
F P
0 g
s
.53458 .77481 m .52955 .79314 L .51358 .79319 L p .707 .577 .707 r
F P
0 g
s
.52653 .76656 m .52508 .72971 L .54905 .72285 L p .707 .577 .707 r
F P
0 g
s
.54905 .72285 m .55049 .7597 L .52653 .76656 L p .707 .577 .707 r
F P
0 g
s
.52955 .79314 m .53458 .77481 L .55792 .77775 L p .707 .577 .707 r
F P
0 g
s
.55792 .77775 m .55289 .79608 L .52955 .79314 L p .707 .577 .707 r
F P
0 g
s
.48751 .31989 m .48751 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48751 .31989 L p .707 .577 .707 r
F P
0 g
s
.54333 .69948 m .54352 .64388 L .57288 .6406 L p .707 .577 .707 r
F P
0 g
s
.57288 .6406 m .57268 .6962 L .54333 .69948 L p .707 .577 .707 r
F P
0 g
s
.55049 .7597 m .54905 .72285 L .57837 .71819 L p .707 .577 .707 r
F P
0 g
s
.57837 .71819 m .57981 .75504 L .55049 .7597 L p .707 .577 .707 r
F P
0 g
s
.55289 .79608 m .55792 .77775 L .58636 .7834 L p .707 .577 .707 r
F P
0 g
s
.58636 .7834 m .58133 .80173 L .55289 .79608 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57436 .81638 L p .707 .577 .707 r
F P
0 g
s
.57268 .6962 m .57288 .6406 L .60471 .63991 L p .707 .577 .707 r
F P
0 g
s
.60471 .63991 m .60451 .69552 L .57268 .6962 L p .707 .577 .707 r
F P
0 g
s
.57436 .81638 m .57436 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70128 .83591 m .69625 .85424 L .70327 .8512 L p .707 .577 .707 r
F P
0 g
s
.70327 .8512 m .7083 .83287 L .70128 .83591 L p .707 .577 .707 r
F P
0 g
s
.44371 .81885 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44371 .81885 L .48751 .82178 L p .707 .577 .707 r
F P
0 g
s
.70564 .74353 m .70708 .78038 L .70408 .77146 L p .707 .577 .707 r
F P
0 g
s
.70408 .77146 m .70264 .7346 L .70564 .74353 L p .707 .577 .707 r
F P
0 g
s
.69713 .66069 m .69693 .7163 L .68429 .70842 L p .707 .577 .707 r
F P
0 g
s
.68429 .70842 m .68448 .65282 L .69713 .66069 L p .707 .577 .707 r
F P
0 g
s
.57981 .75504 m .57837 .71819 L .61017 .71619 L p .707 .577 .707 r
F P
0 g
s
.61017 .71619 m .61162 .75305 L .57981 .75504 L p .707 .577 .707 r
F P
0 g
s
.58133 .80173 m .58636 .7834 L .6171 .7912 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .61207 .80953 L .58133 .80173 L p .707 .577 .707 r
F P
0 g
s
.57436 .31449 m .57436 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.6359 .64189 m .6357 .6975 L .60451 .69552 L p .707 .577 .707 r
F P
0 g
s
.60451 .69552 m .60471 .63991 L .6359 .64189 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .30671 L .57436 .31449 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44371 .81885 L p .707 .577 .707 r
F P
0 g
s
.25118 .71167 m .25126 .65614 L .22008 .65419 L p .707 .577 .707 r
F P
0 g
s
.25126 .65614 m .25118 .71167 L .28301 .71092 L p .707 .577 .707 r
F P
0 g
s
.28301 .71092 m .28309 .65539 L .25126 .65614 L p .707 .577 .707 r
F P
0 g
s
.7083 .83287 m .70327 .8512 L .70067 .84547 L p .707 .577 .707 r
F P
0 g
s
.70067 .84547 m .7057 .82714 L .7083 .83287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28309 .65539 m .28301 .71092 L .31237 .70752 L p .707 .577 .707 r
F P
0 g
s
.31237 .70752 m .31245 .65199 L .28309 .65539 L p .707 .577 .707 r
F P
0 g
s
.21999 .70972 m .22008 .65419 L .19259 .64972 L p .707 .577 .707 r
F P
0 g
s
.22008 .65419 m .21999 .70972 L .25118 .71167 L p .707 .577 .707 r
F P
0 g
s
.70264 .7346 m .70408 .77146 L .6914 .76358 L p .707 .577 .707 r
F P
0 g
s
.6914 .76358 m .68996 .72673 L .70264 .7346 L p .707 .577 .707 r
F P
0 g
s
.68448 .65282 m .68429 .70842 L .66319 .70194 L p .707 .577 .707 r
F P
0 g
s
.66319 .70194 m .66338 .64634 L .68448 .65282 L p .707 .577 .707 r
F P
0 g
s
.64135 .71705 m .64279 .75391 L .61162 .75305 L p .707 .577 .707 r
F P
0 g
s
.61162 .75305 m .61017 .71619 L .64135 .71705 L p .707 .577 .707 r
F P
0 g
s
.6171 .7912 m .64715 .80039 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61207 .80953 m .61249 .80803 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.61249 .80803 m .6171 .7912 L p .61243 .80944 L .707 .577 .707 r
F P
0 g
s
.66338 .64634 m .66319 .70194 L .6357 .6975 L p .707 .577 .707 r
F P
0 g
s
.6357 .6975 m .6359 .64189 L .66338 .64634 L p .707 .577 .707 r
F P
0 g
s
.66884 .72068 m .67028 .75754 L .64279 .75391 L p .707 .577 .707 r
F P
0 g
s
.64279 .75391 m .64135 .71705 L .66884 .72068 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .6437 .78657 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .31285 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.63281 .31285 m .63281 .79832 L p .63305 .30708 L .707 .577 .707 r
F P
0 g
s
.60892 .30671 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .30671 L p .707 .577 .707 r
F P
0 g
s
.31245 .65199 m .31237 .70752 L .33638 .70182 L p .707 .577 .707 r
F P
0 g
s
.33638 .70182 m .33646 .6463 L .31245 .65199 L p .707 .577 .707 r
F P
0 g
s
.25445 .77005 m .25383 .73264 L .22264 .73151 L p .707 .577 .707 r
F P
0 g
s
.25383 .73264 m .25445 .77005 L .28628 .76885 L p .707 .577 .707 r
F P
0 g
s
.28628 .76885 m .28566 .73144 L .25383 .73264 L p .707 .577 .707 r
F P
0 g
s
.28566 .73144 m .28628 .76885 L .31561 .76545 L p .707 .577 .707 r
F P
0 g
s
.31561 .76545 m .31499 .72804 L .28566 .73144 L p .707 .577 .707 r
F P
0 g
s
.19259 .64972 m .1925 .70525 L .21999 .70972 L p .707 .577 .707 r
F P
0 g
s
.22326 .76892 m .22264 .73151 L .19513 .72817 L p .707 .577 .707 r
F P
0 g
s
.22264 .73151 m .22326 .76892 L .25445 .77005 L p .707 .577 .707 r
F P
0 g
s
.1925 .70525 m .19259 .64972 L .17149 .64317 L p .707 .577 .707 r
F P
0 g
s
.31499 .72804 m .31561 .76545 L .33959 .76017 L p .707 .577 .707 r
F P
0 g
s
.33959 .76017 m .33897 .72276 L .31499 .72804 L p .707 .577 .707 r
F P
0 g
s
.7057 .82714 m .70067 .84547 L .6887 .83761 L p .707 .577 .707 r
F P
0 g
s
.6887 .83761 m .69373 .81928 L .7057 .82714 L p .707 .577 .707 r
F P
0 g
s
.19513 .72817 m .19575 .76558 L .22326 .76892 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.68996 .72673 m .6914 .76358 L .67028 .75754 L p .707 .577 .707 r
F P
0 g
s
.67028 .75754 m .66884 .72068 L .68996 .72673 L p .707 .577 .707 r
F P
0 g
s
.33646 .6463 m .33638 .70182 L .3527 .69438 L p .707 .577 .707 r
F P
0 g
s
.3527 .69438 m .35278 .63885 L .33646 .6463 L p .707 .577 .707 r
F P
0 g
s
.25454 .83913 m .25674 .8227 L .22573 .8161 L p .707 .577 .707 r
F P
0 g
s
.25674 .8227 m .25454 .83913 L .28615 .8407 L p .707 .577 .707 r
F P
0 g
s
.28615 .8407 m .28835 .82427 L .25674 .8227 L p .707 .577 .707 r
F P
0 g
s
.17149 .64317 m .1714 .6987 L .1925 .70525 L p .707 .577 .707 r
F P
0 g
s
.19575 .76558 m .19513 .72817 L .17399 .72293 L p .707 .577 .707 r
F P
0 g
s
.22353 .83253 m .22573 .8161 L .19837 .80512 L p .707 .577 .707 r
F P
0 g
s
.22573 .8161 m .22353 .83253 L .25454 .83913 L p .707 .577 .707 r
F P
0 g
s
.28835 .82427 m .28615 .8407 L .31527 .83707 L p .707 .577 .707 r
F P
0 g
s
.31527 .83707 m .31747 .82064 L .28835 .82427 L p .707 .577 .707 r
F P
0 g
s
.1714 .6987 m .17149 .64317 L .15884 .63518 L p .707 .577 .707 r
F P
0 g
s
.17399 .72293 m .17461 .76034 L .19575 .76558 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.33897 .72276 m .33959 .76017 L .35586 .75352 L p .707 .577 .707 r
F P
0 g
s
.35586 .75352 m .35524 .71611 L .33897 .72276 L p .707 .577 .707 r
F P
0 g
s
.19837 .80512 m .19617 .82155 L .22353 .83253 L p .707 .577 .707 r
F P
0 g
s
.19617 .82155 m .19837 .80512 L .17733 .79081 L p .707 .577 .707 r
F P
0 g
s
.31747 .82064 m .31527 .83707 L .33906 .82861 L p .707 .577 .707 r
F P
0 g
s
.33906 .82861 m .34126 .81218 L .31747 .82064 L p .707 .577 .707 r
F P
0 g
s
.69373 .81928 m .6887 .83761 L .66852 .82839 L p .707 .577 .707 r
F P
0 g
s
.66852 .82839 m .67355 .81006 L .69373 .81928 L p .707 .577 .707 r
F P
0 g
s
.15884 .63518 m .15876 .69071 L .1714 .6987 L p .707 .577 .707 r
F P
0 g
s
.17461 .76034 m .17399 .72293 L .1613 .71632 L p .707 .577 .707 r
F P
0 g
s
.35278 .63885 m .3527 .69438 L .35972 .68592 L p .707 .577 .707 r
F P
0 g
s
.35972 .68592 m .35981 .63039 L .35278 .63885 L p .707 .577 .707 r
F P
0 g
s
.17733 .79081 m .17513 .80724 L .19617 .82155 L p .707 .577 .707 r
F P
0 g
s
.1613 .71632 m .16192 .75373 L .17461 .76034 L p .707 .577 .707 r
F P
0 g
s
.35524 .71611 m .35586 .75352 L .36283 .74617 L p .707 .577 .707 r
F P
0 g
s
.36283 .74617 m .36221 .70876 L .35524 .71611 L p .707 .577 .707 r
F P
0 g
s
.35981 .63039 m .35972 .68592 L .35677 .67727 L p .707 .577 .707 r
F P
0 g
s
.35677 .67727 m .35685 .62174 L .35981 .63039 L p .707 .577 .707 r
F P
0 g
s
.35982 .73883 m .3592 .70142 L .36221 .70876 L p .707 .577 .707 r
F P
0 g
s
.36205 .80089 m .36425 .78446 L .35737 .79972 L p .707 .577 .707 r
F P
0 g
s
.36425 .78446 m .36205 .80089 L .35901 .78435 L p .707 .577 .707 r
F P
0 g
s
.35901 .78435 m .3612 .76792 L .36425 .78446 L p .707 .577 .707 r
F P
0 g
s
.3592 .70142 m .35982 .73883 L .34713 .73222 L p .707 .577 .707 r
F P
0 g
s
.34713 .73222 m .34651 .69481 L .3592 .70142 L p .707 .577 .707 r
F P
0 g
s
.3612 .76792 m .35901 .78435 L .34634 .76813 L p .707 .577 .707 r
F P
0 g
s
.34634 .76813 m .34854 .7517 L .3612 .76792 L p .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .29006 L .3563 .27798 L p .707 .577 .707 r
F P
0 g
s
.36221 .70876 m .36283 .74617 L .35982 .73883 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.17513 .80724 m .17733 .79081 L .16466 .7746 L p .707 .577 .707 r
F P
0 g
s
.15876 .69071 m .15884 .63518 L .15588 .62653 L p .707 .577 .707 r
F P
0 g
s
.34126 .81218 m .33906 .82861 L .35518 .81615 L p .707 .577 .707 r
F P
0 g
s
.35518 .81615 m .35737 .79972 L .34126 .81218 L p .707 .577 .707 r
F P
0 g
s
.67355 .81006 m .66852 .82839 L .64212 .81872 L p .707 .577 .707 r
F P
0 g
s
.64212 .81872 m .64715 .80039 L .67355 .81006 L p .707 .577 .707 r
F P
0 g
s
.16466 .7746 m .16246 .79103 L .17513 .80724 L p .707 .577 .707 r
F P
0 g
s
.15588 .62653 m .1558 .68206 L .15876 .69071 L p .707 .577 .707 r
F P
0 g
s
.16192 .75373 m .1613 .71632 L .15829 .70898 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .78657 L .64053 .77449 L p .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.16246 .79103 m .16466 .7746 L .16162 .75805 L p .707 .577 .707 r
F P
0 g
s
.64715 .80039 m .64212 .81872 L .61207 .80953 L p .707 .577 .707 r
F P
0 g
s
.35737 .79972 m .35518 .81615 L .36205 .80089 L p .707 .577 .707 r
F P
0 g
s
.15829 .70898 m .15891 .74639 L .16192 .75373 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1558 .68206 m .15588 .62653 L .16291 .61807 L p .707 .577 .707 r
F P
0 g
s
.16162 .75805 m .15942 .77448 L .16246 .79103 L p .707 .577 .707 r
F P
0 g
s
.35685 .62174 m .35677 .67727 L .34412 .66928 L p .707 .577 .707 r
F P
0 g
s
.34412 .66928 m .3442 .61375 L .35685 .62174 L p .707 .577 .707 r
F P
0 g
s
.3563 .27798 m .35629 .77987 L .35947 .79195 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .3563 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16291 .61807 m .16283 .6736 L .1558 .68206 L p .707 .577 .707 r
F P
0 g
s
.15891 .74639 m .15829 .70898 L .16526 .70163 L p .707 .577 .707 r
F P
0 g
s
.15942 .77448 m .16162 .75805 L .16849 .7428 L p .707 .577 .707 r
F P
0 g
s
.16526 .70163 m .16588 .73904 L .15891 .74639 L p .707 .577 .707 r
F P
0 g
s
.16283 .6736 m .16291 .61807 L .17923 .61063 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .6236 .76326 L p .707 .577 .707 r
F P
0 g
s
.6236 .76326 m .6236 .26138 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.16849 .7428 m .16629 .75923 L .15942 .77448 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17923 .61063 m .17914 .66616 L .16283 .6736 L p .707 .577 .707 r
F P
0 g
s
.3442 .61375 m .34412 .66928 L .32302 .66273 L p .707 .577 .707 r
F P
0 g
s
.32302 .66273 m .3231 .6072 L .3442 .61375 L p .707 .577 .707 r
F P
0 g
s
.16588 .73904 m .16526 .70163 L .18153 .69499 L p .707 .577 .707 r
F P
0 g
s
.16629 .75923 m .16849 .7428 L .18461 .73034 L p .707 .577 .707 r
F P
0 g
s
.36719 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36719 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18153 .69499 m .18215 .7324 L .16588 .73904 L p .707 .577 .707 r
F P
0 g
s
.17914 .66616 m .17923 .61063 L .20324 .60493 L p .707 .577 .707 r
F P
0 g
s
.18461 .73034 m .18241 .74677 L .16629 .75923 L p .707 .577 .707 r
F P
0 g
s
.34651 .69481 m .34713 .73222 L .32599 .72699 L p .707 .577 .707 r
F P
0 g
s
.32599 .72699 m .32537 .68958 L .34651 .69481 L p .707 .577 .707 r
F P
0 g
s
.3231 .6072 m .32302 .66273 L .29553 .65826 L p .707 .577 .707 r
F P
0 g
s
.29553 .65826 m .29562 .60273 L .3231 .6072 L p .707 .577 .707 r
F P
0 g
s
.6236 .26138 m .6236 .76326 L .59457 .75399 L p .707 .577 .707 r
F P
0 g
s
.59457 .75399 m .59457 .2521 L .6236 .26138 L p .707 .577 .707 r
F P
0 g
s
.20324 .60493 m .20316 .66046 L .17914 .66616 L p .707 .577 .707 r
F P
0 g
s
.18241 .74677 m .18461 .73034 L .20839 .72188 L p .707 .577 .707 r
F P
0 g
s
.34854 .7517 m .34634 .76813 L .3253 .75383 L p .707 .577 .707 r
F P
0 g
s
.3253 .75383 m .3275 .7374 L .34854 .7517 L p .707 .577 .707 r
F P
0 g
s
.18215 .7324 m .18153 .69499 L .20551 .68971 L p .707 .577 .707 r
F P
0 g
s
.20316 .66046 m .20324 .60493 L .2326 .60154 L p .707 .577 .707 r
F P
0 g
s
.20839 .72188 m .2062 .73831 L .18241 .74677 L p .707 .577 .707 r
F P
0 g
s
.20551 .68971 m .20613 .72712 L .18215 .7324 L p .707 .577 .707 r
F P
0 g
s
.73565 .65847 m .73557 .60284 L .70438 .60102 L p .707 .577 .707 r
F P
0 g
s
.73557 .60284 m .73565 .65847 L .76748 .65764 L p .707 .577 .707 r
F P
0 g
s
.76748 .65764 m .7674 .60201 L .73557 .60284 L p .707 .577 .707 r
F P
0 g
s
.29562 .60273 m .29553 .65826 L .26435 .65631 L p .707 .577 .707 r
F P
0 g
s
.26435 .65631 m .26443 .60078 L .29562 .60273 L p .707 .577 .707 r
F P
0 g
s
.32537 .68958 m .32599 .72699 L .29848 .72364 L p .707 .577 .707 r
F P
0 g
s
.29848 .72364 m .29786 .68623 L .32537 .68958 L p .707 .577 .707 r
F P
0 g
s
.7674 .60201 m .76748 .65764 L .79684 .65425 L p .707 .577 .707 r
F P
0 g
s
.79684 .65425 m .79676 .59861 L .7674 .60201 L p .707 .577 .707 r
F P
0 g
s
.23252 .65707 m .2326 .60154 L .26443 .60078 L p .707 .577 .707 r
F P
0 g
s
.2326 .60154 m .23252 .65707 L .20316 .66046 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36719 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42564 .24816 L p .707 .577 .707 r
F P
0 g
s
.70447 .65665 m .70438 .60102 L .67689 .59673 L p .707 .577 .707 r
F P
0 g
s
.70438 .60102 m .70447 .65665 L .73565 .65847 L p .707 .577 .707 r
F P
0 g
s
.26443 .60078 m .26435 .65631 L .23252 .65707 L p .707 .577 .707 r
F P
0 g
s
.2062 .73831 m .20839 .72188 L .23752 .71825 L p .707 .577 .707 r
F P
0 g
s
.3275 .7374 m .3253 .75383 L .29794 .74284 L p .707 .577 .707 r
F P
0 g
s
.29794 .74284 m .30013 .72641 L .3275 .7374 L p .707 .577 .707 r
F P
0 g
s
.20613 .72712 m .20551 .68971 L .23484 .6863 L p .707 .577 .707 r
F P
0 g
s
.79676 .59861 m .79684 .65425 L .82085 .64862 L p .707 .577 .707 r
F P
0 g
s
.82085 .64862 m .82077 .59299 L .79676 .59861 L p .707 .577 .707 r
F P
0 g
s
.23752 .71825 m .23532 .73468 L .2062 .73831 L p .707 .577 .707 r
F P
0 g
s
.26693 .73624 m .26913 .71981 L .30013 .72641 L p .707 .577 .707 r
F P
0 g
s
.26913 .71981 m .26693 .73624 L .23532 .73468 L p .707 .577 .707 r
F P
0 g
s
.29786 .68623 m .29848 .72364 L .26728 .72251 L p .707 .577 .707 r
F P
0 g
s
.23532 .73468 m .23752 .71825 L .26913 .71981 L p .707 .577 .707 r
F P
0 g
s
.26728 .72251 m .26666 .6851 L .29786 .68623 L p .707 .577 .707 r
F P
0 g
s
.23484 .6863 m .23546 .72371 L .20613 .72712 L p .707 .577 .707 r
F P
0 g
s
.59457 .2521 m .59457 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59457 .2521 L p .707 .577 .707 r
F P
0 g
s
.30013 .72641 m .29794 .74284 L .26693 .73624 L p .707 .577 .707 r
F P
0 g
s
.67689 .59673 m .67698 .65237 L .70447 .65665 L p .707 .577 .707 r
F P
0 g
s
.23546 .72371 m .23484 .6863 L .26666 .6851 L p .707 .577 .707 r
F P
0 g
s
.67698 .65237 m .67689 .59673 L .65579 .5904 L p .707 .577 .707 r
F P
0 g
s
.26666 .6851 m .26728 .72251 L .23546 .72371 L p .707 .577 .707 r
F P
0 g
s
.73271 .72076 m .73333 .68412 L .70214 .68152 L p .707 .577 .707 r
F P
0 g
s
.73333 .68412 m .73271 .72076 L .76453 .72033 L p .707 .577 .707 r
F P
0 g
s
.76453 .72033 m .76515 .68369 L .73333 .68412 L p .707 .577 .707 r
F P
0 g
s
.76515 .68369 m .76453 .72033 L .79387 .71692 L p .707 .577 .707 r
F P
0 g
s
.79387 .71692 m .79449 .68028 L .76515 .68369 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42564 .24816 L .46747 .24362 L p .707 .577 .707 r
F P
0 g
s
.42564 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.70152 .71816 m .70214 .68152 L .67463 .67615 L p .707 .577 .707 r
F P
0 g
s
.70214 .68152 m .70152 .71816 L .73271 .72076 L p .707 .577 .707 r
F P
0 g
s
.82077 .59299 m .82085 .64862 L .83717 .64131 L p .707 .577 .707 r
F P
0 g
s
.83717 .64131 m .83709 .58568 L .82077 .59299 L p .707 .577 .707 r
F P
0 g
s
.65579 .5904 m .65588 .64603 L .67698 .65237 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51249 .74466 L p .707 .577 .707 r
F P
0 g
s
.51249 .74466 m .51249 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.79449 .68028 m .79387 .71692 L .81784 .71086 L p .707 .577 .707 r
F P
0 g
s
.81784 .71086 m .81846 .67422 L .79449 .68028 L p .707 .577 .707 r
F P
0 g
s
.65588 .64603 m .65579 .5904 L .64315 .58263 L p .707 .577 .707 r
F P
0 g
s
.67463 .67615 m .67401 .71278 L .70152 .71816 L p .707 .577 .707 r
F P
0 g
s
.73307 .73286 m .73087 .71375 L .69986 .71727 L p .707 .577 .707 r
F P
0 g
s
.73087 .71375 m .73307 .73286 L .76468 .7292 L p .707 .577 .707 r
F P
0 g
s
.76468 .7292 m .76248 .71009 L .73087 .71375 L p .707 .577 .707 r
F P
0 g
s
.69986 .71727 m .70206 .73637 L .73307 .73286 L p .707 .577 .707 r
F P
0 g
s
.76248 .71009 m .76468 .7292 L .7938 .72575 L p .707 .577 .707 r
F P
0 g
s
.7938 .72575 m .7916 .70665 L .76248 .71009 L p .707 .577 .707 r
F P
0 g
s
.46747 .74551 m .46747 .24362 L .51249 .24277 L p .707 .577 .707 r
F P
0 g
s
.46747 .24362 m .46747 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.67401 .71278 m .67463 .67615 L .65349 .66853 L p .707 .577 .707 r
F P
0 g
s
.51249 .24277 m .51249 .74466 L .46747 .74551 L p .707 .577 .707 r
F P
0 g
s
.70206 .73637 m .69986 .71727 L .6725 .72029 L p .707 .577 .707 r
F P
0 g
s
.6725 .72029 m .6747 .7394 L .70206 .73637 L p .707 .577 .707 r
F P
0 g
s
.64315 .58263 m .64323 .63827 L .65588 .64603 L p .707 .577 .707 r
F P
0 g
s
.83709 .58568 m .83717 .64131 L .8442 .63304 L p .707 .577 .707 r
F P
0 g
s
.8442 .63304 m .84411 .5774 L .83709 .58568 L p .707 .577 .707 r
F P
0 g
s
.65349 .66853 m .65287 .70517 L .67401 .71278 L p .707 .577 .707 r
F P
0 g
s
.7916 .70665 m .7938 .72575 L .81759 .72286 L p .707 .577 .707 r
F P
0 g
s
.81759 .72286 m .81539 .70375 L .7916 .70665 L p .707 .577 .707 r
F P
0 g
s
.81846 .67422 m .81784 .71086 L .83411 .70274 L p .707 .577 .707 r
F P
0 g
s
.83411 .70274 m .83473 .6661 L .81846 .67422 L p .707 .577 .707 r
F P
0 g
s
.6747 .7394 m .6725 .72029 L .65146 .72253 L p .707 .577 .707 r
F P
0 g
s
.65146 .72253 m .65366 .74164 L .6747 .7394 L p .707 .577 .707 r
F P
0 g
s
.65287 .70517 m .65349 .66853 L .6408 .65941 L p .707 .577 .707 r
F P
0 g
s
.64323 .63827 m .64315 .58263 L .64019 .5742 L p .707 .577 .707 r
F P
0 g
s
.81539 .70375 m .81759 .72286 L .83371 .72079 L p .707 .577 .707 r
F P
0 g
s
.83371 .72079 m .83151 .70169 L .81539 .70375 L p .707 .577 .707 r
F P
0 g
s
.6408 .65941 m .64018 .69605 L .65287 .70517 L p .707 .577 .707 r
F P
0 g
s
.64019 .5742 m .64028 .62983 L .64323 .63827 L p .707 .577 .707 r
F P
0 g
s
.83473 .6661 m .83411 .70274 L .84109 .69335 L p .707 .577 .707 r
F P
0 g
s
.84109 .69335 m .84171 .65672 L .83473 .6661 L p .707 .577 .707 r
F P
0 g
s
.84411 .5774 m .8442 .63304 L .84124 .6246 L p .707 .577 .707 r
F P
0 g
s
.84124 .6246 m .84116 .56897 L .84411 .5774 L p .707 .577 .707 r
F P
0 g
s
.65366 .74164 m .65146 .72253 L .63879 .72377 L p .707 .577 .707 r
F P
0 g
s
.63879 .72377 m .64099 .74287 L .65366 .74164 L p .707 .577 .707 r
F P
0 g
s
.64018 .69605 m .6408 .65941 L .63779 .64968 L p .707 .577 .707 r
F P
0 g
s
.64028 .62983 m .64019 .5742 L .64722 .56592 L p .707 .577 .707 r
F P
0 g
s
.83151 .70169 m .83371 .72079 L .84058 .71977 L p .707 .577 .707 r
F P
0 g
s
.84058 .71977 m .83838 .70066 L .83151 .70169 L p .707 .577 .707 r
F P
0 g
s
.63779 .64968 m .63717 .68632 L .64018 .69605 L p .707 .577 .707 r
F P
0 g
s
.64722 .56592 m .6473 .62156 L .64028 .62983 L p .707 .577 .707 r
F P
0 g
s
.84171 .65672 m .84109 .69335 L .83808 .68363 L p .707 .577 .707 r
F P
0 g
s
.83808 .68363 m .8387 .64699 L .84171 .65672 L p .707 .577 .707 r
F P
0 g
s
.84116 .56897 m .84124 .6246 L .8286 .61684 L p .707 .577 .707 r
F P
0 g
s
.8286 .61684 m .82851 .56121 L .84116 .56897 L p .707 .577 .707 r
F P
0 g
s
.64099 .74287 m .63879 .72377 L .63575 .72387 L p .707 .577 .707 r
F P
0 g
s
.63575 .72387 m .63795 .74298 L .64099 .74287 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63717 .68632 m .63779 .64968 L .64476 .6403 L p .707 .577 .707 r
F P
0 g
s
.6473 .62156 m .64722 .56592 L .66353 .55861 L p .707 .577 .707 r
F P
0 g
s
.39548 .62024 m .39529 .56468 L .3641 .56289 L p .707 .577 .707 r
F P
0 g
s
.39529 .56468 m .39548 .62024 L .42731 .61934 L p .707 .577 .707 r
F P
0 g
s
.42731 .61934 m .42712 .56378 L .39529 .56468 L p .707 .577 .707 r
F P
0 g
s
.42712 .56378 m .42731 .61934 L .45667 .61583 L p .707 .577 .707 r
F P
0 g
s
.45667 .61583 m .45648 .56027 L .42712 .56378 L p .707 .577 .707 r
F P
0 g
s
.83838 .70066 m .84058 .71977 L .83753 .71987 L p .707 .577 .707 r
F P
0 g
s
.83753 .71987 m .83534 .70077 L .83838 .70066 L p .707 .577 .707 r
F P
0 g
s
.64476 .6403 m .64414 .67694 L .63717 .68632 L p .707 .577 .707 r
F P
0 g
s
.3643 .61845 m .3641 .56289 L .33661 .55857 L p .707 .577 .707 r
F P
0 g
s
.3641 .56289 m .3643 .61845 L .39548 .62024 L p .707 .577 .707 r
F P
0 g
s
.66353 .55861 m .66362 .61425 L .6473 .62156 L p .707 .577 .707 r
F P
0 g
s
.8387 .64699 m .83808 .68363 L .82539 .67451 L p .707 .577 .707 r
F P
0 g
s
.82539 .67451 m .82601 .63787 L .8387 .64699 L p .707 .577 .707 r
F P
0 g
s
.82851 .56121 m .8286 .61684 L .8075 .61051 L p .707 .577 .707 r
F P
0 g
s
.8075 .61051 m .80741 .55487 L .82851 .56121 L p .707 .577 .707 r
F P
0 g
s
.45648 .56027 m .45667 .61583 L .48069 .61006 L p .707 .577 .707 r
F P
0 g
s
.48069 .61006 m .48049 .5545 L .45648 .56027 L p .707 .577 .707 r
F P
0 g
s
.63795 .74298 m .63575 .72387 L .64262 .72285 L p .707 .577 .707 r
F P
0 g
s
.64262 .72285 m .64482 .74195 L .63795 .74298 L p .707 .577 .707 r
F P
0 g
s
.38838 .67943 m .38983 .64224 L .35865 .63934 L p .707 .577 .707 r
F P
0 g
s
.38983 .64224 m .38838 .67943 L .42019 .67983 L p .707 .577 .707 r
F P
0 g
s
.42019 .67983 m .42163 .64264 L .38983 .64224 L p .707 .577 .707 r
F P
0 g
s
.64414 .67694 m .64476 .6403 L .66103 .63218 L p .707 .577 .707 r
F P
0 g
s
.42163 .64264 m .42019 .67983 L .44951 .67769 L p .707 .577 .707 r
F P
0 g
s
.44951 .67769 m .45095 .6405 L .42163 .64264 L p .707 .577 .707 r
F P
0 g
s
.33661 .55857 m .33681 .61413 L .3643 .61845 L p .707 .577 .707 r
F P
0 g
s
.66362 .61425 m .66353 .55861 L .68755 .55299 L p .707 .577 .707 r
F P
0 g
s
.33681 .61413 m .33661 .55857 L .31551 .55217 L p .707 .577 .707 r
F P
0 g
s
.35721 .67654 m .35865 .63934 L .33116 .63423 L p .707 .577 .707 r
F P
0 g
s
.35865 .63934 m .35721 .67654 L .38838 .67943 L p .707 .577 .707 r
F P
0 g
s
.66103 .63218 m .66041 .66882 L .64414 .67694 L p .707 .577 .707 r
F P
0 g
s
.45095 .6405 m .44951 .67769 L .47347 .67322 L p .707 .577 .707 r
F P
0 g
s
.47347 .67322 m .47492 .63603 L .45095 .6405 L p .707 .577 .707 r
F P
0 g
s
.83534 .70077 m .83753 .71987 L .82487 .72111 L p .707 .577 .707 r
F P
0 g
s
.82487 .72111 m .82267 .702 L .83534 .70077 L p .707 .577 .707 r
F P
0 g
s
.80741 .55487 m .8075 .61051 L .78001 .60622 L p .707 .577 .707 r
F P
0 g
s
.78001 .60622 m .77992 .55058 L .80741 .55487 L p .707 .577 .707 r
F P
0 g
s
.48049 .5545 m .48069 .61006 L .497 .60259 L p .707 .577 .707 r
F P
0 g
s
.497 .60259 m .49681 .54703 L .48049 .5545 L p .707 .577 .707 r
F P
0 g
s
.33116 .63423 m .32972 .67142 L .35721 .67654 L p .707 .577 .707 r
F P
0 g
s
.68755 .55299 m .68763 .60862 L .66362 .61425 L p .707 .577 .707 r
F P
0 g
s
.41867 .72664 m .41364 .70944 L .38289 .71817 L p .707 .577 .707 r
F P
0 g
s
.41364 .70944 m .41867 .72664 L .4471 .71485 L p .707 .577 .707 r
F P
0 g
s
.4471 .71485 m .44207 .69764 L .41364 .70944 L p .707 .577 .707 r
F P
0 g
s
.31551 .55217 m .31571 .60773 L .33681 .61413 L p .707 .577 .707 r
F P
0 g
s
.38792 .73538 m .38289 .71817 L .35285 .72298 L p .707 .577 .707 r
F P
0 g
s
.38289 .71817 m .38792 .73538 L .41867 .72664 L p .707 .577 .707 r
F P
0 g
s
.82601 .63787 m .82539 .67451 L .80425 .66689 L p .707 .577 .707 r
F P
0 g
s
.80425 .66689 m .80487 .63025 L .82601 .63787 L p .707 .577 .707 r
F P
0 g
s
.32972 .67142 m .33116 .63423 L .31004 .6274 L p .707 .577 .707 r
F P
0 g
s
.68763 .60862 m .68755 .55299 L .71691 .54959 L p .707 .577 .707 r
F P
0 g
s
.35285 .72298 m .35788 .74019 L .38792 .73538 L p .707 .577 .707 r
F P
0 g
s
.31571 .60773 m .31551 .55217 L .30287 .54429 L p .707 .577 .707 r
F P
0 g
s
.44207 .69764 m .4471 .71485 L .47045 .70114 L p .707 .577 .707 r
F P
0 g
s
.47045 .70114 m .46542 .68393 L .44207 .69764 L p .707 .577 .707 r
F P
0 g
s
.64482 .74195 m .64262 .72285 L .65874 .72078 L p .707 .577 .707 r
F P
0 g
s
.65874 .72078 m .66094 .73989 L .64482 .74195 L p .707 .577 .707 r
F P
0 g
s
.35788 .74019 m .35285 .72298 L .32645 .72341 L p .707 .577 .707 r
F P
0 g
s
.66041 .66882 m .66103 .63218 L .68501 .62612 L p .707 .577 .707 r
F P
0 g
s
.31004 .6274 m .3086 .66459 L .32972 .67142 L p .707 .577 .707 r
F P
0 g
s
.77992 .55058 m .78001 .60622 L .74882 .6044 L p .707 .577 .707 r
F P
0 g
s
.74882 .6044 m .74874 .54877 L .77992 .55058 L p .707 .577 .707 r
F P
0 g
s
.71699 .60523 m .71691 .54959 L .74874 .54877 L p .707 .577 .707 r
F P
0 g
s
.71691 .54959 m .71699 .60523 L .68763 .60862 L p .707 .577 .707 r
F P
0 g
s
.32645 .72341 m .33148 .74062 L .35788 .74019 L p .707 .577 .707 r
F P
0 g
s
.47492 .63603 m .47347 .67322 L .48974 .66686 L p .707 .577 .707 r
F P
0 g
s
.48974 .66686 m .49118 .62967 L .47492 .63603 L p .707 .577 .707 r
F P
0 g
s
.74874 .54877 m .74882 .6044 L .71699 .60523 L p .707 .577 .707 r
F P
0 g
s
.68501 .62612 m .68439 .66276 L .66041 .66882 L p .707 .577 .707 r
F P
0 g
s
.30287 .54429 m .30306 .59985 L .31571 .60773 L p .707 .577 .707 r
F P
0 g
s
.49681 .54703 m .497 .60259 L .50403 .59416 L p .707 .577 .707 r
F P
0 g
s
.50403 .59416 m .50383 .5386 L .49681 .54703 L p .707 .577 .707 r
F P
0 g
s
.80487 .63025 m .80425 .66689 L .77674 .66152 L p .707 .577 .707 r
F P
0 g
s
.77674 .66152 m .77736 .62488 L .80487 .63025 L p .707 .577 .707 r
F P
0 g
s
.46542 .68393 m .47045 .70114 L .48641 .68687 L p .707 .577 .707 r
F P
0 g
s
.48641 .68687 m .48138 .66966 L .46542 .68393 L p .707 .577 .707 r
F P
0 g
s
.3086 .66459 m .31004 .6274 L .29736 .61953 L p .707 .577 .707 r
F P
0 g
s
.82267 .702 m .82487 .72111 L .80383 .72335 L p .707 .577 .707 r
F P
0 g
s
.80383 .72335 m .80163 .70424 L .82267 .702 L p .707 .577 .707 r
F P
0 g
s
.33148 .74062 m .32645 .72341 L .30627 .7194 L p .707 .577 .707 r
F P
0 g
s
.68439 .66276 m .68501 .62612 L .71434 .62271 L p .707 .577 .707 r
F P
0 g
s
.30627 .7194 m .3113 .73661 L .33148 .74062 L p .707 .577 .707 r
F P
0 g
s
.29736 .61953 m .29592 .65672 L .3086 .66459 L p .707 .577 .707 r
F P
0 g
s
.30306 .59985 m .30287 .54429 L .29991 .53571 L p .707 .577 .707 r
F P
0 g
s
.66094 .73989 m .65874 .72078 L .68253 .71789 L p .707 .577 .707 r
F P
0 g
s
.68253 .71789 m .68472 .73699 L .66094 .73989 L p .707 .577 .707 r
F P
0 g
s
.77736 .62488 m .77674 .66152 L .74554 .65892 L p .707 .577 .707 r
F P
0 g
s
.74554 .65892 m .74616 .62228 L .77736 .62488 L p .707 .577 .707 r
F P
0 g
s
.71434 .62271 m .71372 .65935 L .68439 .66276 L p .707 .577 .707 r
F P
0 g
s
.71372 .65935 m .71434 .62271 L .74616 .62228 L p .707 .577 .707 r
F P
0 g
s
.49118 .62967 m .48974 .66686 L .49672 .65923 L p .707 .577 .707 r
F P
0 g
s
.49672 .65923 m .49816 .62204 L .49118 .62967 L p .707 .577 .707 r
F P
0 g
s
.74616 .62228 m .74554 .65892 L .71372 .65935 L p .707 .577 .707 r
F P
0 g
s
.48138 .66966 m .48641 .68687 L .49344 .67342 L p .707 .577 .707 r
F P
0 g
s
.49344 .67342 m .48841 .65622 L .48138 .66966 L p .707 .577 .707 r
F P
0 g
s
.80163 .70424 m .80383 .72335 L .77646 .72637 L p .707 .577 .707 r
F P
0 g
s
.77646 .72637 m .77427 .70727 L .80163 .70424 L p .707 .577 .707 r
F P
0 g
s
.29991 .53571 m .30011 .59127 L .30306 .59985 L p .707 .577 .707 r
F P
0 g
s
.3113 .73661 m .30627 .7194 L .29429 .71136 L p .707 .577 .707 r
F P
0 g
s
.50383 .5386 m .50403 .59416 L .50107 .58558 L p .707 .577 .707 r
F P
0 g
s
.50107 .58558 m .50088 .53002 L .50383 .5386 L p .707 .577 .707 r
F P
0 g
s
.29592 .65672 m .29736 .61953 L .29436 .61137 L p .707 .577 .707 r
F P
0 g
s
.68472 .73699 m .68253 .71789 L .71165 .71444 L p .707 .577 .707 r
F P
0 g
s
.71165 .71444 m .71385 .73355 L .68472 .73699 L p .707 .577 .707 r
F P
0 g
s
.29429 .71136 m .29932 .72856 L .3113 .73661 L p .707 .577 .707 r
F P
0 g
s
.29436 .61137 m .29292 .64857 L .29592 .65672 L p .707 .577 .707 r
F P
0 g
s
.30011 .59127 m .29991 .53571 L .30694 .52728 L p .707 .577 .707 r
F P
0 g
s
.77427 .70727 m .77646 .72637 L .74546 .72989 L p .707 .577 .707 r
F P
0 g
s
.74546 .72989 m .74326 .71078 L .77427 .70727 L p .707 .577 .707 r
F P
0 g
s
.71385 .73355 m .71165 .71444 L .74326 .71078 L p .707 .577 .707 r
F P
0 g
s
.74326 .71078 m .74546 .72989 L .71385 .73355 L p .707 .577 .707 r
F P
0 g
s
.49816 .62204 m .49672 .65923 L .49372 .65107 L p .707 .577 .707 r
F P
0 g
s
.49372 .65107 m .49516 .61388 L .49816 .62204 L p .707 .577 .707 r
F P
0 g
s
.48841 .65622 m .49344 .67342 L .49084 .66213 L p .707 .577 .707 r
F P
0 g
s
.49084 .66213 m .48581 .64492 L .48841 .65622 L p .707 .577 .707 r
F P
0 g
s
.29932 .72856 m .29429 .71136 L .29169 .70006 L p .707 .577 .707 r
F P
0 g
s
.30694 .52728 m .30713 .58284 L .30011 .59127 L p .707 .577 .707 r
F P
0 g
s
.50088 .53002 m .50107 .58558 L .48843 .5777 L p .707 .577 .707 r
F P
0 g
s
.48843 .5777 m .48823 .52214 L .50088 .53002 L p .707 .577 .707 r
F P
0 g
s
.29292 .64857 m .29436 .61137 L .30134 .60374 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29169 .70006 m .29672 .71727 L .29932 .72856 L p .707 .577 .707 r
F P
0 g
s
.30134 .60374 m .29989 .64094 L .29292 .64857 L p .707 .577 .707 r
F P
0 g
s
.30713 .58284 m .30694 .52728 L .32325 .51981 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48581 .64492 m .49084 .66213 L .47886 .65408 L p .707 .577 .707 r
F P
0 g
s
.47886 .65408 m .47383 .63687 L .48581 .64492 L p .707 .577 .707 r
F P
0 g
s
.49516 .61388 m .49372 .65107 L .48104 .6432 L p .707 .577 .707 r
F P
0 g
s
.48104 .6432 m .48248 .60601 L .49516 .61388 L p .707 .577 .707 r
F P
0 g
s
.29672 .71727 m .29169 .70006 L .29872 .68661 L p .707 .577 .707 r
F P
0 g
s
.32325 .51981 m .32345 .57537 L .30713 .58284 L p .707 .577 .707 r
F P
0 g
s
.48823 .52214 m .48843 .5777 L .46733 .57129 L p .707 .577 .707 r
F P
0 g
s
.46733 .57129 m .46713 .51573 L .48823 .52214 L p .707 .577 .707 r
F P
0 g
s
.29989 .64094 m .30134 .60374 L .3176 .59738 L p .707 .577 .707 r
F P
0 g
s
.29872 .68661 m .30375 .70382 L .29672 .71727 L p .707 .577 .707 r
F P
0 g
s
.32345 .57537 m .32325 .51981 L .34727 .51404 L p .707 .577 .707 r
F P
0 g
s
.3176 .59738 m .31616 .63457 L .29989 .64094 L p .707 .577 .707 r
F P
0 g
s
.47383 .63687 m .47886 .65408 L .45868 .65007 L p .707 .577 .707 r
F P
0 g
s
.45868 .65007 m .45365 .63287 L .47383 .63687 L p .707 .577 .707 r
F P
0 g
s
.48248 .60601 m .48104 .6432 L .45992 .63637 L p .707 .577 .707 r
F P
0 g
s
.45992 .63637 m .46136 .59918 L .48248 .60601 L p .707 .577 .707 r
F P
0 g
s
.46713 .51573 m .46733 .57129 L .43984 .56698 L p .707 .577 .707 r
F P
0 g
s
.43984 .56698 m .43964 .51142 L .46713 .51573 L p .707 .577 .707 r
F P
0 g
s
.34727 .51404 m .34746 .5696 L .32345 .57537 L p .707 .577 .707 r
F P
0 g
s
.30375 .70382 m .29872 .68661 L .31468 .67234 L p .707 .577 .707 r
F P
0 g
s
.31616 .63457 m .3176 .59738 L .34157 .59291 L p .707 .577 .707 r
F P
0 g
s
.34746 .5696 m .34727 .51404 L .37663 .51053 L p .707 .577 .707 r
F P
0 g
s
.31468 .67234 m .31971 .68955 L .30375 .70382 L p .707 .577 .707 r
F P
0 g
s
.43964 .51142 m .43984 .56698 L .40865 .56519 L p .707 .577 .707 r
F P
0 g
s
.40865 .56519 m .40846 .50963 L .43964 .51142 L p .707 .577 .707 r
F P
0 g
s
.34157 .59291 m .34013 .6301 L .31616 .63457 L p .707 .577 .707 r
F P
0 g
s
.37682 .56609 m .37663 .51053 L .40846 .50963 L p .707 .577 .707 r
F P
0 g
s
.37663 .51053 m .37682 .56609 L .34746 .5696 L p .707 .577 .707 r
F P
0 g
s
.45365 .63287 m .45868 .65007 L .43228 .6505 L p .707 .577 .707 r
F P
0 g
s
.43228 .6505 m .42725 .63329 L .45365 .63287 L p .707 .577 .707 r
F P
0 g
s
.46136 .59918 m .45992 .63637 L .43243 .63126 L p .707 .577 .707 r
F P
0 g
s
.43243 .63126 m .43387 .59407 L .46136 .59918 L p .707 .577 .707 r
F P
0 g
s
.40846 .50963 m .40865 .56519 L .37682 .56609 L p .707 .577 .707 r
F P
0 g
s
.34013 .6301 m .34157 .59291 L .37089 .59077 L p .707 .577 .707 r
F P
0 g
s
.31971 .68955 m .31468 .67234 L .33803 .65864 L p .707 .577 .707 r
F P
0 g
s
.33803 .65864 m .34306 .67584 L .31971 .68955 L p .707 .577 .707 r
F P
0 g
s
.43387 .59407 m .43243 .63126 L .40125 .62836 L p .707 .577 .707 r
F P
0 g
s
.40125 .62836 m .4027 .59117 L .43387 .59407 L p .707 .577 .707 r
F P
0 g
s
.37089 .59077 m .36945 .62796 L .34013 .6301 L p .707 .577 .707 r
F P
0 g
s
.36945 .62796 m .37089 .59077 L .4027 .59117 L p .707 .577 .707 r
F P
0 g
s
.42725 .63329 m .43228 .6505 L .40224 .65531 L p .707 .577 .707 r
F P
0 g
s
.40224 .65531 m .39721 .63811 L .42725 .63329 L p .707 .577 .707 r
F P
0 g
s
.4027 .59117 m .40125 .62836 L .36945 .62796 L p .707 .577 .707 r
F P
0 g
s
.34306 .67584 m .33803 .65864 L .36646 .64684 L p .707 .577 .707 r
F P
0 g
s
.36646 .64684 m .37149 .66405 L .34306 .67584 L p .707 .577 .707 r
F P
0 g
s
.39721 .63811 m .40224 .65531 L .37149 .66405 L p .707 .577 .707 r
F P
0 g
s
.37149 .66405 m .36646 .64684 L .39721 .63811 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH:000;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`03001JEP0000P000AJEP04001JEUYFFUH80004FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005mo
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`@000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00008000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ao
o`00FGoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001GOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00EWoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00mooaT003aoo`00EGoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH6000fOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`02Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000cOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005Eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF009JEPX000QJEPP000=JEP03001JEUYF00=JEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000=JEP04001JEUYFFUH90008FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001E
Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP0200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001EOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo
0P000UYF00<005YFFUH00UYF7`0015YF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo0P000UYF1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF000010001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo0017Ool90006Ool300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40003FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool003ioo`T000AJEP03001JEUYF009JEPL000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000=JEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00=Woo200015YF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000eYF001JEP06FUH80004FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000;Goo000bOol40003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH90008FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF0000;Goo000`Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH6
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF
001JEP02FUH00`00Oomoo`0[Ool002ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003
FUH00`00Oomoo`0[Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P0000=JEP00Ool0;7oo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03
001JEUYF00AJEPT000AJEP04001JEUYFFUH60004FUH00`00FUIJEP04FUH01000FUIJEUYF0`00;Goo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000@000IJEP07001JEUYFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJ
EUYF2@000UYF00<005YFFUH00eYF1@000eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH50003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000eYF2@000eYF00@005YFFUH000EJEPD0009JEPP00003
FUH0000000@000AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000eYF0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YF00000`000eYF00<005YF0000;Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P00
1EYF00@005YFFUIJEPP000AJEPL000AJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF009J
EP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EP00001JEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03
001JEUYF009JEPD00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP8000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP@002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40008FUH0
0`00FUIJEP05FUH;0003FUH00`00FUIJEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP80009JEP03001JEUYF00MJEP03001JEUYF00@0
00MJEP04001JEUYFFUH300000eYF001JEP040003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ8000AJEP04001JEUYF0005FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00=J
EPL000QJEPD000AJEPP000EJEP03001JEUYF008000MJEP03001JEUYF00@000MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF
00<005YF00000`001UYF00<005YFFUH01UYF1@0015YF00<005YFFUH015YF0P0015YF100025YF0`00
0UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUH005YF008000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YF
FUH00eYF1P004Goo200015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF0000
0eYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF1P000UYF00<0
05YFFUH015YF0P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUH0000300000eYF001JEP02FUH00`00Oomoo`08Ool3000<Ool60004FUH0
1000FUIJEUYF0P00;Goo000/Ool01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJEP04001JEUYFFUH20007FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000EJEP05001J
EUYFFUH00009Ool5000AOol300000eYF001JEP02FUH2000]Ool002aoo`03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000MJEP03001JEP00
008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60003FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEUYF001JEP00FUH50004FUH0
1@00FUIJEUYF00002Goo1@004Woo10000eYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH90004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH7000015YF001JEP000UYF00<005YF00001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUH30004FUH50003FUH00`00Oomoo`07
Ool5000>Ool400001EYF001JEUYF00000UYF0P00;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP04FUH2
0003FUH20002FUH00`00FUH0000A0008FUH20003FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
00Eoo`<000Yoo`D000EJEP04001JEUYFFUH4000]Ool002aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEPX000AJEP03001JEUYF009JEP03001JEUYF00<000AJEP80009JEP03
001JEUYF00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYF0005FUH00`00FUIJEP05FUH90004FUH00`00FUIJEP02FUH50005FUH30002FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool01000FUIJEP001EYF2@000eYF00<005YFFUH01UYF
00<005YFFUH01EYF0P001EYF1P0015YF0P000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Woo0`0000=JEP0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000eYF00@005YFFUH0009JEPL0009JEP03001JEUYF00AJEP<000IJEP03001JEUYF00=JEP80
00EJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000`Ool200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00D005YF
FUIJEP0000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH2000:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP06001JEP00001JEP001eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF2000;Woo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJ
EUYF00001EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP<0
00AJEP03001JEUYF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH:0002FUH01000FUIJEUYF0P00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH00UYF0`001eYF00L005YFFUIJEP00FUH0000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP`000=JEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP08FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF0`001UYF00@005YFFUIJEPd0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001UYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP<000EJEP03001JEUYF00EJEP8000AJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00IJEPl000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000MJEP03001J
EP0000<0009JEP03001JEUYF00=JEP04001JEUYF0002FUH60008FUH00`00FUIJEP03FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP0>0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQH0
009JEP03001JEUYF00l000=JEP03001JEUYF00QJEP03001JEP00008000QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00D0009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP`0031oo`00;Goo
00<005YF00000eYF00<005YFFUH00eYF1P000eYF00<005YFFUH01eYF00<005YFFUH015YF0`0000=J
EP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000hOol002eoo`03001J
EP0000=JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPl003moo`00;Goo00<005YF
00000eYF0P001EYF00<005YFFUH00UYF200015YF00<005YFFUH01eYF100015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUH>0018Ool002eoo`04001JEP00FUH200000eYF001JEP03FUH70007FUH70006FUH01000
FUIJEUYF0`000eYF00<005YFFUH015YF00<005YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003
FUH01000FUIJEUYF3@00DGoo000]Ool01000FUH000000UYF00@005YFFUIJEP8000IJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEPl000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YF3P000UYF0P00E7oo000]Ool30003FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH50007FUH01000FUIJEP0015YF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00MJEQH000IJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002eoo`<000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF009JEP80009JEP04001JEUYF0006FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00E7oo000]Ool30002FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3
00000eYF001JEP05FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60002FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol002eoo`03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000006
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00D0
05YFFUIJEP0005Aoo`00;Goo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP<0009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP80
00AJEP03001JEUYF009JEP04001oogooOol60004FUH01@00FUIJEUYF0000E7oo000]Ool01000FUH0
07oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP<0009JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<0
07ooOol01goo0`0000=JEP00FUH00UYF00<007ooOol0DWoo000]Ool20005Ool70004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003Ool30002FUH01@00FUIJEP00FUH00P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<007ooOol017oo0`0000=JEP00FUH00P000eYF00<007ooOol0DWoo000]
Ool2000<OolK000<Ool01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
1`0015YF00@005YFFUIJEP800003FUH007oo05=oo`00;Goo0P006Goo0`0067oo00D005YF001JEP00
00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000AJEP03001JEUYF00=JEP03001JEUYF009JEP<0
05Aoo`00;Goo0P0067oo1@0067oo0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0005Aoo`00;Goo0`005goo1@0067oo0`00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEP0005Aoo`00;Goo0P0000=JEP00Ool05Goo1@006Goo0P0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYFFUH2001EOol002ioo`04
001JEUYF000FOol3000JOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00;Woo00D005YFFUIJEP0003=oo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00AJEP05001JEUYFFUH0
001FOol002moo`03001JEUYF00<0035oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000IJEP03001JEUYF00AJEP04001JEP00001GOol002moo`04001JEUYF0002FUH00`00Oomoo`0]
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP03FUH3001IOol0031o
o`8000AJEP8002eoo`80009oo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP80009JEP<0009JEP03001JEP0000<0
05aoo`00<7oo0P001UYF00<007ooOol0:Goo0`0017oo0P001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00<005YF
00000`00H7oo000aOol00`00FUIJEP04FUH3000WOol200000eYF001oo`06Ool20004FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30008FUH0
1000FUIJEUYF0`00Ggoo000bOol20004FUH00`00FUIJEP02000SOol20002FUH20009Ool300000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP05FUH3001LOol003Aoo`04001JEUYF0005FUH2000OOol200001EYF001JEUYF0000
3Goo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF000020000Woo
10000UYF00<005YFFUH01UYF00<005YF00000P00FGoo000eOol30007FUH5000HOol20003FUH01000
FUIJEP0057oo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF1`000UYF1`001Woo10001eYF00<0
05YFFUH00UYF0P00Egoo000gOol20007FUH01000FUIJEUYF2@002Goo1P0015YF00@005YFFUH0021o
oaX000=JEP03001JEUYF00EJEPD000Yoo`8000AJEP03001JEUYF00AJEP8005Ioo`00>Goo0P0015YF
00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF0`00>Woo0`0000=JEP00FUH0
1eYF0`0000=JEP0000000P0027oo0`0000=JEP00FUH015YF00@005YFFUH005Eoo`00>goo0`0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00?goo0`001eYF00<0
05YFFUH01EYF1P001Goo0P001EYF00D005YFFUIJEP0005Aoo`00?Woo10001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8004Aoo`8000EJEP03001JEUYF00MJEP04001JEUYFFUH90003
FUH01000FUIJEUYF0P00Dgoo0012Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH0
0000B7oo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01@0015YF0P00Dgoo0016Ool7
0004FUH00`00FUIJEP02FUH5001=Ool40007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH2
001DOol004eoo`T005Ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEP00001JEP02
001DOol00;1oo`@000MJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00]7oo10000UYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH0001EOol00;Qooa0005Eoo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]42\[InvisibleSpace]"     "\
\[InvisibleSpace]11.410790221356642`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 42, "     ", 11.410790221356642, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59737 .79074 m .5964 .75442 L .56748 .75296 L p .707 .577 .707 r
F P
0 g
s
.56748 .75296 m .56523 .75285 L p .56984 .75828 L .707 .577 .707 r
F P
0 g
s
.59737 .79074 m .56748 .75296 L .56984 .75828 L .707 .577 .707 r
F
.5662 .78916 m .56523 .75285 L .53964 .74845 L p F P
0 g
s
.53964 .74845 m .53777 .74813 L p .54127 .75317 L .707 .577 .707 r
F P
0 g
s
.5662 .78916 m .53964 .74845 L .54127 .75317 L .707 .577 .707 r
F
.53777 .74813 m .53874 .78445 L .5662 .78916 L p F P
0 g
s
.53874 .78445 m .53777 .74813 L .51802 .7412 L p .707 .577 .707 r
F P
0 g
s
.51802 .7412 m .5167 .74073 L p .51882 .74494 L .707 .577 .707 r
F P
0 g
s
.53874 .78445 m .51802 .7412 L .51882 .74494 L .707 .577 .707 r
F
.5167 .74073 m .51767 .77705 L .53874 .78445 L p F P
0 g
s
.51767 .77705 m .5167 .74073 L .5047 .73184 L p .707 .577 .707 r
F P
0 g
s
.5047 .73184 m .50409 .73138 L p .50494 .73425 L .707 .577 .707 r
F P
0 g
s
.51767 .77705 m .5047 .73184 L .50494 .73425 L .707 .577 .707 r
F
.50409 .73138 m .50506 .7677 L .51767 .77705 L p F P
0 g
s
.50506 .7677 m .50409 .73138 L .50123 .72121 L p .707 .577 .707 r
F P
0 g
s
.50123 .72121 m .50117 .72099 L p .50126 .72204 L .707 .577 .707 r
F P
0 g
s
.50506 .7677 m .50123 .72121 L .50126 .72204 L .707 .577 .707 r
F
.50618 .75189 m .50388 .72354 L p .49888 .68643 L F P
0 g
s
.50388 .72354 m .50199 .7002 L .50123 .69684 L p .707 .577 .707 r
F P
0 g
s
.50123 .69684 m .49888 .68643 L p .50388 .72354 L .707 .577 .707 r
F P
0 g
s
.51894 .76393 m .51653 .73427 L p .50199 .7002 L .707 .577 .707 r
F P
0 g
s
.51104 .70874 m .50199 .7002 L p .51653 .73427 L .707 .577 .707 r
F P
0 g
s
.50199 .7002 m .50618 .75189 L .51894 .76393 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50618 .75189 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.49888 .68643 m .50091 .71142 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50091 .71142 m .50308 .73812 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50117 .72099 m .50214 .75731 L .50506 .7677 L p .707 .577 .707 r
F P
0 g
s
.50214 .75731 m .50117 .72099 L .5016 .72036 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50091 .71142 L p .50574 .67226 L .707 .577 .707 r
F P
0 g
s
.50574 .67226 m .50792 .69908 L p .50308 .73812 L .707 .577 .707 r
F P
0 g
s
.51653 .73427 m .51474 .71224 L .51104 .70874 L p .707 .577 .707 r
F P
0 g
s
.5401 .77305 m .53762 .74255 L p .51474 .71224 L .707 .577 .707 r
F P
0 g
s
.52938 .71855 m .51474 .71224 L p .53762 .74255 L .707 .577 .707 r
F P
0 g
s
.51474 .71224 m .51894 .76393 L .5401 .77305 L p .707 .577 .707 r
F P
0 g
s
.50863 .71035 m .52457 .70116 L p .51067 .7425 L .707 .577 .707 r
F P
0 g
s
.50792 .69908 m .50994 .72395 L .50955 .72476 L p .707 .577 .707 r
F P
0 g
s
.50955 .72476 m .50308 .73812 L p .50792 .69908 L .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50822 .71058 L .50863 .71035 L p .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50863 .71035 L .51067 .7425 L .707 .577 .707 r
F
.5016 .72036 m .50822 .71058 L p .50358 .74626 L F P
0 g
s
.50214 .75731 m .5016 .72036 L .50358 .74626 L .707 .577 .707 r
F
.50091 .71142 m .49888 .68643 L .50003 .68406 L p F P
0 g
s
.50003 .68406 m .50574 .67226 L p .50091 .71142 L .707 .577 .707 r
F P
0 g
s
.53762 .74255 m .5359 .72136 L .52938 .71855 L p .707 .577 .707 r
F P
0 g
s
.56523 .75285 m .5662 .78916 L .59737 .79074 L p .707 .577 .707 r
F P
0 g
s
.56759 .77836 m .56509 .74758 L p .5359 .72136 L .707 .577 .707 r
F P
0 g
s
.56509 .74758 m .56339 .72667 L .55511 .72507 L p .707 .577 .707 r
F P
0 g
s
.55511 .72507 m .5359 .72136 L p .56509 .74758 L .707 .577 .707 r
F P
0 g
s
.5964 .75442 m .59737 .79074 L .61576 .78975 L p .707 .577 .707 r
F P
0 g
s
.61576 .78975 m .62919 .78902 L p .60145 .75975 L .707 .577 .707 r
F P
0 g
s
.60145 .75975 m .5964 .75442 L .61576 .78975 L .707 .577 .707 r
F
.62919 .78902 m .62822 .7527 L .5964 .75442 L p F P
0 g
s
.59873 .77935 m .59625 .74885 L p .56339 .72667 L .707 .577 .707 r
F P
0 g
s
.59625 .74885 m .59453 .72765 L .58601 .72738 L p .707 .577 .707 r
F P
0 g
s
.58601 .72738 m .56339 .72667 L p .59625 .74885 L .707 .577 .707 r
F P
0 g
s
.62822 .7527 m .62919 .78902 L .6449 .78643 L p .707 .577 .707 r
F P
0 g
s
.6449 .78643 m .65856 .78418 L p .63271 .75736 L .707 .577 .707 r
F P
0 g
s
.63271 .75736 m .62822 .7527 L .6449 .78643 L .707 .577 .707 r
F
.65856 .78418 m .65759 .74786 L .62822 .7527 L p F P
0 g
s
.63046 .7759 m .62805 .74624 L p .59453 .72765 L .707 .577 .707 r
F P
0 g
s
.62805 .74624 m .62626 .72421 L .61914 .72498 L p .707 .577 .707 r
F P
0 g
s
.61914 .72498 m .59453 .72765 L p .62805 .74624 L .707 .577 .707 r
F P
0 g
s
.59453 .72765 m .59873 .77935 L .63046 .7759 L p .707 .577 .707 r
F P
0 g
s
.65759 .74786 m .65856 .78418 L .66908 .78089 L p .707 .577 .707 r
F P
0 g
s
.66908 .78089 m .68258 .77668 L p .66063 .75136 L .707 .577 .707 r
F P
0 g
s
.66063 .75136 m .65759 .74786 L .66908 .78089 L .707 .577 .707 r
F
.68258 .77668 m .68161 .74036 L .65759 .74786 L p F P
0 g
s
.65968 .76837 m .65738 .74002 L p .62626 .72421 L .707 .577 .707 r
F P
0 g
s
.65738 .74002 m .65548 .71668 L .65102 .71783 L p .707 .577 .707 r
F P
0 g
s
.65102 .71783 m .62626 .72421 L p .65738 .74002 L .707 .577 .707 r
F P
0 g
s
.62626 .72421 m .63046 .7759 L .65968 .76837 L p .707 .577 .707 r
F P
0 g
s
.56339 .72667 m .56759 .77836 L .59873 .77935 L p .707 .577 .707 r
F P
0 g
s
.68161 .74036 m .68258 .77668 L .68734 .77394 L p .707 .577 .707 r
F P
0 g
s
.68734 .77394 m .69893 .76726 L p .68298 .74248 L .707 .577 .707 r
F P
0 g
s
.68298 .74248 m .68161 .74036 L .68734 .77394 L .707 .577 .707 r
F
.69893 .76726 m .69796 .73094 L .68161 .74036 L p F P
0 g
s
.68352 .75749 m .68136 .73078 L p .65548 .71668 L .707 .577 .707 r
F P
0 g
s
.68136 .73078 m .67933 .70579 L .67798 .70641 L p .707 .577 .707 r
F P
0 g
s
.67798 .70641 m .65548 .71668 L p .68136 .73078 L .707 .577 .707 r
F P
0 g
s
.65548 .71668 m .65968 .76837 L .68352 .75749 L p .707 .577 .707 r
F P
0 g
s
.5359 .72136 m .5401 .77305 L .56759 .77836 L p .707 .577 .707 r
F P
0 g
s
.59261 .86861 m .59309 .8498 L .56192 .84758 L p .707 .577 .707 r
F P
0 g
s
.59309 .8498 m .59261 .86861 L .62443 .86879 L p .707 .577 .707 r
F P
0 g
s
.62443 .86879 m .62491 .84998 L .59309 .8498 L p .707 .577 .707 r
F P
0 g
s
.69796 .73094 m .69893 .76726 L .69966 .76618 L p .707 .577 .707 r
F P
0 g
s
.69875 .74506 m .69967 .74432 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69817 .73164 m .69796 .73094 L .69966 .76618 L .707 .577 .707 r
F
.69547 .69262 m .67933 .70579 L p .69863 .74236 L F P
0 g
s
.69967 .74432 m .69765 .71944 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69813 .73068 m .69796 .73094 L p .69817 .73164 L .707 .577 .707 r
F P
0 g
s
.69765 .71944 m .69547 .69262 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69547 .69262 m .69967 .74432 L .70652 .73015 L p .707 .577 .707 r
F P
0 g
s
.70652 .73015 m .70233 .67846 L .69547 .69262 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .70501 .72053 L .69813 .73068 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .69813 .73068 L .69817 .73164 L .707 .577 .707 r
F
.69966 .76618 m .70598 .75685 L p .69817 .73164 L F P
0 g
s
.67933 .70579 m .68352 .75749 L .69875 .74506 L p .707 .577 .707 r
F P
0 g
s
.69863 .74236 m .67933 .70579 L .69875 .74506 L .707 .577 .707 r
F
.62491 .84998 m .62443 .86879 L .65379 .86689 L p F P
0 g
s
.65379 .86689 m .65428 .84808 L .62491 .84998 L p .707 .577 .707 r
F P
0 g
s
.56192 .84758 m .56144 .86638 L .59261 .86861 L p .707 .577 .707 r
F P
0 g
s
.56144 .86638 m .56192 .84758 L .53446 .84351 L p .707 .577 .707 r
F P
0 g
s
.53446 .84351 m .53398 .86232 L .56144 .86638 L p .707 .577 .707 r
F P
0 g
s
.65428 .84808 m .65379 .86689 L .67782 .86311 L p .707 .577 .707 r
F P
0 g
s
.67782 .86311 m .67831 .8443 L .65428 .84808 L p .707 .577 .707 r
F P
0 g
s
.53398 .86232 m .53446 .84351 L .51339 .83801 L p .707 .577 .707 r
F P
0 g
s
.51339 .83801 m .51291 .85682 L .53398 .86232 L p .707 .577 .707 r
F P
0 g
s
.67831 .8443 m .67782 .86311 L .69417 .85782 L p .707 .577 .707 r
F P
0 g
s
.69417 .85782 m .69465 .83901 L .67831 .8443 L p .707 .577 .707 r
F P
0 g
s
.51291 .85682 m .51339 .83801 L .50078 .83161 L p .707 .577 .707 r
F P
0 g
s
.50078 .83161 m .5003 .85042 L .51291 .85682 L p .707 .577 .707 r
F P
0 g
s
.70501 .72053 m .70598 .75685 L .70306 .74646 L p .707 .577 .707 r
F P
0 g
s
.70306 .74646 m .70209 .71014 L .70501 .72053 L p .707 .577 .707 r
F P
0 g
s
.70233 .67846 m .70652 .73015 L .70342 .71637 L p .707 .577 .707 r
F P
0 g
s
.70342 .71637 m .69923 .66468 L .70233 .67846 L p .707 .577 .707 r
F P
0 g
s
.69465 .83901 m .69417 .85782 L .70122 .85153 L p .707 .577 .707 r
F P
0 g
s
.70122 .85153 m .7017 .83272 L .69465 .83901 L p .707 .577 .707 r
F P
0 g
s
.4924 .82174 m .4906 .32109 L .44659 .31847 L p .707 .577 .707 r
F P
0 g
s
.50994 .72395 m .50574 .67226 L .52188 .65909 L p .707 .577 .707 r
F P
0 g
s
.50822 .71058 m .5092 .7469 L .50214 .75731 L p .707 .577 .707 r
F P
0 g
s
.5003 .85042 m .50078 .83161 L .49786 .82494 L p .707 .577 .707 r
F P
0 g
s
.49786 .82494 m .49738 .84375 L .5003 .85042 L p .707 .577 .707 r
F P
0 g
s
.49738 .84375 m .49786 .82494 L .50492 .81865 L p .707 .577 .707 r
F P
0 g
s
.50492 .81865 m .50443 .83745 L .49738 .84375 L p .707 .577 .707 r
F P
0 g
s
.52457 .70116 m .52554 .73748 L .5092 .7469 L p .707 .577 .707 r
F P
0 g
s
.52554 .73748 m .52457 .70116 L .54859 .69367 L p .707 .577 .707 r
F P
0 g
s
.52188 .65909 m .52608 .71078 L .50994 .72395 L p .707 .577 .707 r
F P
0 g
s
.52608 .71078 m .52188 .65909 L .54573 .64821 L p .707 .577 .707 r
F P
0 g
s
.50443 .83745 m .50492 .81865 L .52126 .81335 L p .707 .577 .707 r
F P
0 g
s
.54859 .69367 m .54957 .72998 L .52554 .73748 L p .707 .577 .707 r
F P
0 g
s
.54957 .72998 m .54859 .69367 L .57796 .68882 L p .707 .577 .707 r
F P
0 g
s
.54573 .64821 m .54993 .6999 L .52608 .71078 L p .707 .577 .707 r
F P
0 g
s
.52126 .81335 m .52078 .83216 L .50443 .83745 L p .707 .577 .707 r
F P
0 g
s
.52078 .83216 m .52126 .81335 L .54529 .80957 L p .707 .577 .707 r
F P
0 g
s
.54529 .80957 m .5448 .82838 L .52078 .83216 L p .707 .577 .707 r
F P
0 g
s
.4906 .32109 m .4924 .82174 L .53735 .82046 L p .707 .577 .707 r
F P
0 g
s
.53735 .82046 m .53554 .3198 L .4906 .32109 L p .707 .577 .707 r
F P
0 g
s
.54993 .6999 m .54573 .64821 L .57495 .64067 L p .707 .577 .707 r
F P
0 g
s
.57893 .72514 m .57796 .68882 L .60978 .6871 L p .707 .577 .707 r
F P
0 g
s
.57796 .68882 m .57893 .72514 L .54957 .72998 L p .707 .577 .707 r
F P
0 g
s
.57495 .64067 m .57915 .69237 L .54993 .6999 L p .707 .577 .707 r
F P
0 g
s
.5448 .82838 m .54529 .80957 L .57465 .80768 L p .707 .577 .707 r
F P
0 g
s
.57465 .80768 m .57417 .82648 L .5448 .82838 L p .707 .577 .707 r
F P
0 g
s
.57417 .82648 m .57465 .80768 L .60647 .80785 L p .707 .577 .707 r
F P
0 g
s
.53554 .3198 m .53735 .82046 L .57883 .8154 L p .707 .577 .707 r
F P
0 g
s
.57915 .69237 m .57495 .64067 L .60668 .63723 L p .707 .577 .707 r
F P
0 g
s
.57883 .8154 m .57702 .31475 L .53554 .3198 L p .707 .577 .707 r
F P
0 g
s
.44839 .81912 m .44659 .31847 L .40782 .3122 L p .707 .577 .707 r
F P
0 g
s
.44659 .31847 m .44839 .81912 L .4924 .82174 L p .707 .577 .707 r
F P
0 g
s
.70209 .71014 m .70306 .74646 L .69045 .73711 L p .707 .577 .707 r
F P
0 g
s
.69045 .73711 m .68948 .70079 L .70209 .71014 L p .707 .577 .707 r
F P
0 g
s
.69923 .66468 m .70342 .71637 L .69067 .70434 L p .707 .577 .707 r
F P
0 g
s
.69067 .70434 m .68647 .65264 L .69923 .66468 L p .707 .577 .707 r
F P
0 g
s
.61075 .72342 m .60978 .6871 L .64095 .68868 L p .707 .577 .707 r
F P
0 g
s
.60978 .6871 m .61075 .72342 L .57893 .72514 L p .707 .577 .707 r
F P
0 g
s
.60668 .63723 m .61088 .68892 L .57915 .69237 L p .707 .577 .707 r
F P
0 g
s
.60599 .82666 m .60647 .80785 L .63764 .81008 L p .707 .577 .707 r
F P
0 g
s
.60647 .80785 m .60599 .82666 L .57417 .82648 L p .707 .577 .707 r
F P
0 g
s
.57702 .31475 m .57883 .8154 L .61278 .80707 L p .707 .577 .707 r
F P
0 g
s
.64192 .725 m .64095 .68868 L .66841 .69339 L p .707 .577 .707 r
F P
0 g
s
.64095 .68868 m .64192 .725 L .61075 .72342 L p .707 .577 .707 r
F P
0 g
s
.63782 .63821 m .64201 .6899 L .61088 .68892 L p .707 .577 .707 r
F P
0 g
s
.61088 .68892 m .60668 .63723 L .63782 .63821 L p .707 .577 .707 r
F P
0 g
s
.61278 .80707 m .61098 .30641 L .57702 .31475 L p .707 .577 .707 r
F P
0 g
s
.7017 .83272 m .70122 .85153 L .6983 .84485 L p .707 .577 .707 r
F P
0 g
s
.6983 .84485 m .69878 .82605 L .7017 .83272 L p .707 .577 .707 r
F P
0 g
s
.40963 .81286 m .40782 .3122 L .3781 .30291 L p .707 .577 .707 r
F P
0 g
s
.40782 .3122 m .40963 .81286 L .44839 .81912 L p .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .25339 .71761 L .22447 .71614 L p .707 .577 .707 r
F P
0 g
s
.22447 .71614 m .22222 .71603 L p .22683 .72146 L .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .22447 .71614 L .22683 .72146 L .707 .577 .707 r
F
.22319 .75235 m .22222 .71603 L .19664 .71164 L p F P
0 g
s
.19664 .71164 m .19476 .71131 L p .19826 .71636 L .707 .577 .707 r
F P
0 g
s
.22319 .75235 m .19664 .71164 L .19826 .71636 L .707 .577 .707 r
F
.19476 .71131 m .19573 .74763 L .22319 .75235 L p F P
0 g
s
.19573 .74763 m .19476 .71131 L .17501 .70438 L p .707 .577 .707 r
F P
0 g
s
.17501 .70438 m .17369 .70392 L p .17581 .70813 L .707 .577 .707 r
F P
0 g
s
.19573 .74763 m .17501 .70438 L .17581 .70813 L .707 .577 .707 r
F
.17369 .70392 m .17466 .74024 L .19573 .74763 L p F P
0 g
s
.17466 .74024 m .17369 .70392 L .16169 .69502 L p .707 .577 .707 r
F P
0 g
s
.16169 .69502 m .16108 .69457 L p .16193 .69744 L .707 .577 .707 r
F P
0 g
s
.17466 .74024 m .16169 .69502 L .16193 .69744 L .707 .577 .707 r
F
.16108 .69457 m .16205 .73089 L .17466 .74024 L p F P
0 g
s
.16205 .73089 m .16108 .69457 L .15822 .68439 L p .707 .577 .707 r
F P
0 g
s
.15822 .68439 m .15816 .68418 L p .15825 .68522 L .707 .577 .707 r
F P
0 g
s
.16205 .73089 m .15822 .68439 L .15825 .68522 L .707 .577 .707 r
F
.16317 .71508 m .16087 .68673 L p .15588 .64961 L F P
0 g
s
.16087 .68673 m .15898 .66339 L .15822 .66002 L p .707 .577 .707 r
F P
0 g
s
.15822 .66002 m .15588 .64961 L p .16087 .68673 L .707 .577 .707 r
F P
0 g
s
.17593 .72712 m .17352 .69746 L p .15898 .66339 L .707 .577 .707 r
F P
0 g
s
.16803 .67193 m .15898 .66339 L p .17352 .69746 L .707 .577 .707 r
F P
0 g
s
.15898 .66339 m .16317 .71508 L .17593 .72712 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .16317 .71508 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15588 .64961 m .1579 .6746 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.1579 .6746 m .16007 .7013 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15816 .68418 m .15913 .7205 L .16205 .73089 L p .707 .577 .707 r
F P
0 g
s
.15913 .7205 m .15816 .68418 L .15859 .68355 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .1579 .6746 L p .16273 .63544 L .707 .577 .707 r
F P
0 g
s
.16273 .63544 m .16491 .66226 L p .16007 .7013 L .707 .577 .707 r
F P
0 g
s
.17352 .69746 m .17173 .67542 L .16803 .67193 L p .707 .577 .707 r
F P
0 g
s
.19709 .73624 m .19461 .70574 L p .17173 .67542 L .707 .577 .707 r
F P
0 g
s
.18637 .68174 m .17173 .67542 L p .19461 .70574 L .707 .577 .707 r
F P
0 g
s
.17173 .67542 m .17593 .72712 L .19709 .73624 L p .707 .577 .707 r
F P
0 g
s
.16562 .67353 m .18156 .66435 L p .16766 .70569 L .707 .577 .707 r
F P
0 g
s
.16491 .66226 m .16693 .68714 L .16654 .68794 L p .707 .577 .707 r
F P
0 g
s
.16654 .68794 m .16007 .7013 L p .16491 .66226 L .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16522 .67376 L .16562 .67353 L p .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16562 .67353 L .16766 .70569 L .707 .577 .707 r
F
.15859 .68355 m .16522 .67376 L p .16057 .70944 L F P
0 g
s
.15913 .7205 m .15859 .68355 L .16057 .70944 L .707 .577 .707 r
F
.1579 .6746 m .15588 .64961 L .15702 .64725 L p F P
0 g
s
.15702 .64725 m .16273 .63544 L p .1579 .6746 L .707 .577 .707 r
F P
0 g
s
.19461 .70574 m .19289 .68454 L .18637 .68174 L p .707 .577 .707 r
F P
0 g
s
.22222 .71603 m .22319 .75235 L .25436 .75393 L p .707 .577 .707 r
F P
0 g
s
.22458 .74155 m .22208 .71076 L p .19289 .68454 L .707 .577 .707 r
F P
0 g
s
.22208 .71076 m .22039 .68986 L .2121 .68826 L p .707 .577 .707 r
F P
0 g
s
.2121 .68826 m .19289 .68454 L p .22208 .71076 L .707 .577 .707 r
F P
0 g
s
.25339 .71761 m .25436 .75393 L .27275 .75293 L p .707 .577 .707 r
F P
0 g
s
.27275 .75293 m .28618 .75221 L p .25844 .72294 L .707 .577 .707 r
F P
0 g
s
.25844 .72294 m .25339 .71761 L .27275 .75293 L .707 .577 .707 r
F
.28618 .75221 m .28521 .71589 L .25339 .71761 L p F P
0 g
s
.25572 .74253 m .25324 .71203 L p .22039 .68986 L .707 .577 .707 r
F P
0 g
s
.25324 .71203 m .25152 .69084 L .24301 .69057 L p .707 .577 .707 r
F P
0 g
s
.24301 .69057 m .22039 .68986 L p .25324 .71203 L .707 .577 .707 r
F P
0 g
s
.28521 .71589 m .28618 .75221 L .30189 .74961 L p .707 .577 .707 r
F P
0 g
s
.30189 .74961 m .31555 .74736 L p .2897 .72055 L .707 .577 .707 r
F P
0 g
s
.2897 .72055 m .28521 .71589 L .30189 .74961 L .707 .577 .707 r
F
.31555 .74736 m .31458 .71104 L .28521 .71589 L p F P
0 g
s
.28745 .73909 m .28504 .70943 L p .25152 .69084 L .707 .577 .707 r
F P
0 g
s
.28504 .70943 m .28325 .68739 L .27613 .68817 L p .707 .577 .707 r
F P
0 g
s
.27613 .68817 m .25152 .69084 L p .28504 .70943 L .707 .577 .707 r
F P
0 g
s
.25152 .69084 m .25572 .74253 L .28745 .73909 L p .707 .577 .707 r
F P
0 g
s
.31458 .71104 m .31555 .74736 L .32608 .74408 L p .707 .577 .707 r
F P
0 g
s
.32608 .74408 m .33958 .73986 L p .31762 .71455 L .707 .577 .707 r
F P
0 g
s
.31762 .71455 m .31458 .71104 L .32608 .74408 L .707 .577 .707 r
F
.33958 .73986 m .33861 .70355 L .31458 .71104 L p F P
0 g
s
.31667 .73155 m .31437 .7032 L p .28325 .68739 L .707 .577 .707 r
F P
0 g
s
.31437 .7032 m .31247 .67986 L .30801 .68101 L p .707 .577 .707 r
F P
0 g
s
.30801 .68101 m .28325 .68739 L p .31437 .7032 L .707 .577 .707 r
F P
0 g
s
.28325 .68739 m .28745 .73909 L .31667 .73155 L p .707 .577 .707 r
F P
0 g
s
.68948 .70079 m .69045 .73711 L .66938 .72971 L p .707 .577 .707 r
F P
0 g
s
.66938 .72971 m .66841 .69339 L .68948 .70079 L p .707 .577 .707 r
F P
0 g
s
.68647 .65264 m .69067 .70434 L .66951 .69522 L p .707 .577 .707 r
F P
0 g
s
.66951 .69522 m .66531 .64352 L .68647 .65264 L p .707 .577 .707 r
F P
0 g
s
.22039 .68986 m .22458 .74155 L .25572 .74253 L p .707 .577 .707 r
F P
0 g
s
.33861 .70355 m .33958 .73986 L .34433 .73712 L p .707 .577 .707 r
F P
0 g
s
.34433 .73712 m .35592 .73045 L p .33997 .70567 L .707 .577 .707 r
F P
0 g
s
.33997 .70567 m .33861 .70355 L .34433 .73712 L .707 .577 .707 r
F
.35592 .73045 m .35495 .69413 L .33861 .70355 L p F P
0 g
s
.34052 .72067 m .33835 .69397 L p .31247 .67986 L .707 .577 .707 r
F P
0 g
s
.33835 .69397 m .33632 .66898 L .33497 .66959 L p .707 .577 .707 r
F P
0 g
s
.33497 .66959 m .31247 .67986 L p .33835 .69397 L .707 .577 .707 r
F P
0 g
s
.31247 .67986 m .31667 .73155 L .34052 .72067 L p .707 .577 .707 r
F P
0 g
s
.61098 .30641 m .61278 .80707 L .63589 .79626 L p .707 .577 .707 r
F P
0 g
s
.63589 .79626 m .63409 .29561 L .61098 .30641 L p .707 .577 .707 r
F P
0 g
s
.19289 .68454 m .19709 .73624 L .22458 .74155 L p .707 .577 .707 r
F P
0 g
s
.69878 .82605 m .6983 .84485 L .68569 .83845 L p .707 .577 .707 r
F P
0 g
s
.68569 .83845 m .68617 .81964 L .69878 .82605 L p .707 .577 .707 r
F P
0 g
s
.66841 .69339 m .66938 .72971 L .64192 .725 L p .707 .577 .707 r
F P
0 g
s
.66531 .64352 m .66951 .69522 L .64201 .6899 L p .707 .577 .707 r
F P
0 g
s
.64201 .6899 m .63782 .63821 L .66531 .64352 L p .707 .577 .707 r
F P
0 g
s
.3799 .80356 m .3781 .30291 L .36032 .29149 L p .707 .577 .707 r
F P
0 g
s
.3781 .30291 m .3799 .80356 L .40963 .81286 L p .707 .577 .707 r
F P
0 g
s
.2496 .8318 m .25008 .81299 L .21891 .81076 L p .707 .577 .707 r
F P
0 g
s
.25008 .81299 m .2496 .8318 L .28142 .83197 L p .707 .577 .707 r
F P
0 g
s
.28142 .83197 m .2819 .81317 L .25008 .81299 L p .707 .577 .707 r
F P
0 g
s
.35495 .69413 m .35592 .73045 L .35665 .72937 L p .707 .577 .707 r
F P
0 g
s
.35574 .70825 m .35666 .7075 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35516 .69483 m .35495 .69413 L .35665 .72937 L .707 .577 .707 r
F
.35246 .65581 m .33632 .66898 L p .35562 .70554 L F P
0 g
s
.35666 .7075 m .35464 .68263 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35512 .69387 m .35495 .69413 L p .35516 .69483 L .707 .577 .707 r
F P
0 g
s
.35464 .68263 m .35246 .65581 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35246 .65581 m .35666 .7075 L .36351 .69334 L p .707 .577 .707 r
F P
0 g
s
.36351 .69334 m .35932 .64164 L .35246 .65581 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .362 .68372 L .35512 .69387 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .35512 .69387 L .35516 .69483 L .707 .577 .707 r
F
.35665 .72937 m .36297 .72003 L p .35516 .69483 L F P
0 g
s
.33632 .66898 m .34052 .72067 L .35574 .70825 L p .707 .577 .707 r
F P
0 g
s
.35562 .70554 m .33632 .66898 L .35574 .70825 L .707 .577 .707 r
F
.2819 .81317 m .28142 .83197 L .31079 .83008 L p F P
0 g
s
.31079 .83008 m .31127 .81127 L .2819 .81317 L p .707 .577 .707 r
F P
0 g
s
.21891 .81076 m .21843 .82957 L .2496 .8318 L p .707 .577 .707 r
F P
0 g
s
.21843 .82957 m .21891 .81076 L .19145 .8067 L p .707 .577 .707 r
F P
0 g
s
.19145 .8067 m .19097 .82551 L .21843 .82957 L p .707 .577 .707 r
F P
0 g
s
.31127 .81127 m .31079 .83008 L .33481 .8263 L p .707 .577 .707 r
F P
0 g
s
.33481 .8263 m .3353 .80749 L .31127 .81127 L p .707 .577 .707 r
F P
0 g
s
.63409 .29561 m .63589 .79626 L .64589 .78406 L p .707 .577 .707 r
F P
0 g
s
.64589 .78406 m .64408 .2834 L .63409 .29561 L p .707 .577 .707 r
F P
0 g
s
.68617 .81964 m .68569 .83845 L .66462 .83295 L p .707 .577 .707 r
F P
0 g
s
.66462 .83295 m .6651 .81414 L .68617 .81964 L p .707 .577 .707 r
F P
0 g
s
.19097 .82551 m .19145 .8067 L .17038 .8012 L p .707 .577 .707 r
F P
0 g
s
.17038 .8012 m .1699 .82 L .19097 .82551 L p .707 .577 .707 r
F P
0 g
s
.3353 .80749 m .33481 .8263 L .35116 .821 L p .707 .577 .707 r
F P
0 g
s
.35116 .821 m .35164 .80219 L .3353 .80749 L p .707 .577 .707 r
F P
0 g
s
.362 .68372 m .36297 .72003 L .36005 .70964 L p .707 .577 .707 r
F P
0 g
s
.36005 .70964 m .35908 .67333 L .362 .68372 L p .707 .577 .707 r
F P
0 g
s
.35932 .64164 m .36351 .69334 L .36041 .67956 L p .707 .577 .707 r
F P
0 g
s
.36212 .79214 m .36032 .29149 L .35623 .27907 L p .707 .577 .707 r
F P
0 g
s
.36032 .29149 m .36212 .79214 L .3799 .80356 L p .707 .577 .707 r
F P
0 g
s
.6651 .81414 m .66462 .83295 L .63716 .82889 L p .707 .577 .707 r
F P
0 g
s
.63716 .82889 m .63764 .81008 L .6651 .81414 L p .707 .577 .707 r
F P
0 g
s
.1699 .82 m .17038 .8012 L .15777 .7948 L p .707 .577 .707 r
F P
0 g
s
.15777 .7948 m .15729 .8136 L .1699 .82 L p .707 .577 .707 r
F P
0 g
s
.36041 .67956 m .35622 .62787 L .35932 .64164 L p .707 .577 .707 r
F P
0 g
s
.63764 .81008 m .63716 .82889 L .60599 .82666 L p .707 .577 .707 r
F P
0 g
s
.35164 .80219 m .35116 .821 L .35821 .81471 L p .707 .577 .707 r
F P
0 g
s
.35821 .81471 m .35869 .7959 L .35164 .80219 L p .707 .577 .707 r
F P
0 g
s
.64408 .2834 m .64589 .78406 L .6418 .77164 L p .707 .577 .707 r
F P
0 g
s
.6418 .77164 m .63999 .27098 L .64408 .2834 L p .707 .577 .707 r
F P
0 g
s
.15729 .8136 m .15777 .7948 L .15485 .78812 L p .707 .577 .707 r
F P
0 g
s
.15485 .78812 m .15437 .80693 L .15729 .8136 L p .707 .577 .707 r
F P
0 g
s
.35908 .67333 m .36005 .70964 L .34744 .70029 L p .707 .577 .707 r
F P
0 g
s
.34744 .70029 m .34647 .66397 L .35908 .67333 L p .707 .577 .707 r
F P
0 g
s
.35622 .62787 m .36041 .67956 L .34766 .66752 L p .707 .577 .707 r
F P
0 g
s
.34766 .66752 m .34346 .61583 L .35622 .62787 L p .707 .577 .707 r
F P
0 g
s
.35623 .27907 m .35803 .77972 L .36212 .79214 L p .707 .577 .707 r
F P
0 g
s
.35803 .77972 m .35623 .27907 L .36623 .26686 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35869 .7959 m .35821 .81471 L .35529 .80804 L p .707 .577 .707 r
F P
0 g
s
.35529 .80804 m .35577 .78923 L .35869 .7959 L p .707 .577 .707 r
F P
0 g
s
.16693 .68714 m .16273 .63544 L .17887 .62227 L p .707 .577 .707 r
F P
0 g
s
.16522 .67376 m .16619 .71008 L .15913 .7205 L p .707 .577 .707 r
F P
0 g
s
.15437 .80693 m .15485 .78812 L .16191 .78183 L p .707 .577 .707 r
F P
0 g
s
.63999 .27098 m .6418 .77164 L .62402 .76022 L p .707 .577 .707 r
F P
0 g
s
.62402 .76022 m .62222 .25956 L .63999 .27098 L p .707 .577 .707 r
F P
0 g
s
.34647 .66397 m .34744 .70029 L .32637 .6929 L p .707 .577 .707 r
F P
0 g
s
.32637 .6929 m .3254 .65658 L .34647 .66397 L p .707 .577 .707 r
F P
0 g
s
.34346 .61583 m .34766 .66752 L .3265 .6584 L p .707 .577 .707 r
F P
0 g
s
.3265 .6584 m .3223 .60671 L .34346 .61583 L p .707 .577 .707 r
F P
0 g
s
.16191 .78183 m .16142 .80064 L .15437 .80693 L p .707 .577 .707 r
F P
0 g
s
.18156 .66435 m .18253 .70067 L .16619 .71008 L p .707 .577 .707 r
F P
0 g
s
.18253 .70067 m .18156 .66435 L .20559 .65685 L p .707 .577 .707 r
F P
0 g
s
.17887 .62227 m .18307 .67397 L .16693 .68714 L p .707 .577 .707 r
F P
0 g
s
.18307 .67397 m .17887 .62227 L .20272 .61139 L p .707 .577 .707 r
F P
0 g
s
.36803 .76752 m .36623 .26686 L .38934 .25606 L p .707 .577 .707 r
F P
0 g
s
.36623 .26686 m .36803 .76752 L .35803 .77972 L p .707 .577 .707 r
F P
0 g
s
.35577 .78923 m .35529 .80804 L .34268 .80164 L p .707 .577 .707 r
F P
0 g
s
.34268 .80164 m .34316 .78283 L .35577 .78923 L p .707 .577 .707 r
F P
0 g
s
.3254 .65658 m .32637 .6929 L .29891 .68818 L p .707 .577 .707 r
F P
0 g
s
.29891 .68818 m .29794 .65186 L .3254 .65658 L p .707 .577 .707 r
F P
0 g
s
.3223 .60671 m .3265 .6584 L .299 .65309 L p .707 .577 .707 r
F P
0 g
s
.299 .65309 m .29481 .6014 L .3223 .60671 L p .707 .577 .707 r
F P
0 g
s
.16142 .80064 m .16191 .78183 L .17825 .77654 L p .707 .577 .707 r
F P
0 g
s
.20656 .69317 m .20559 .65685 L .23495 .652 L p .707 .577 .707 r
F P
0 g
s
.20692 .66308 m .20272 .61139 L .23194 .60386 L p .707 .577 .707 r
F P
0 g
s
.20559 .65685 m .20656 .69317 L .18253 .70067 L p .707 .577 .707 r
F P
0 g
s
.20272 .61139 m .20692 .66308 L .18307 .67397 L p .707 .577 .707 r
F P
0 g
s
.17825 .77654 m .17777 .79534 L .16142 .80064 L p .707 .577 .707 r
F P
0 g
s
.29794 .65186 m .29891 .68818 L .26774 .6866 L p .707 .577 .707 r
F P
0 g
s
.26774 .6866 m .26677 .65029 L .29794 .65186 L p .707 .577 .707 r
F P
0 g
s
.29481 .6014 m .299 .65309 L .26787 .65211 L p .707 .577 .707 r
F P
0 g
s
.26787 .65211 m .26367 .60041 L .29481 .6014 L p .707 .577 .707 r
F P
0 g
s
.62222 .25956 m .62402 .76022 L .5943 .75092 L p .707 .577 .707 r
F P
0 g
s
.5943 .75092 m .59249 .25027 L .62222 .25956 L p .707 .577 .707 r
F P
0 g
s
.23592 .68832 m .23495 .652 L .26677 .65029 L p .707 .577 .707 r
F P
0 g
s
.23614 .65555 m .23194 .60386 L .26367 .60041 L p .707 .577 .707 r
F P
0 g
s
.23495 .652 m .23592 .68832 L .20656 .69317 L p .707 .577 .707 r
F P
0 g
s
.23194 .60386 m .23614 .65555 L .20692 .66308 L p .707 .577 .707 r
F P
0 g
s
.26677 .65029 m .26774 .6866 L .23592 .68832 L p .707 .577 .707 r
F P
0 g
s
.26367 .60041 m .26787 .65211 L .23614 .65555 L p .707 .577 .707 r
F P
0 g
s
.34316 .78283 m .34268 .80164 L .32161 .79614 L p .707 .577 .707 r
F P
0 g
s
.32161 .79614 m .32209 .77733 L .34316 .78283 L p .707 .577 .707 r
F P
0 g
s
.73593 .65969 m .73173 .608 L .7006 .60702 L p .707 .577 .707 r
F P
0 g
s
.73173 .608 m .73593 .65969 L .76766 .65625 L p .707 .577 .707 r
F P
0 g
s
.76766 .65625 m .76347 .60456 L .73173 .608 L p .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .36803 .76752 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.38972 .36245 m .39114 .75671 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .38934 .25606 L .42329 .24772 L p .707 .577 .707 r
F P
0 g
s
.42329 .24772 m .4251 .74838 L .39114 .75671 L p .707 .577 .707 r
F P
0 g
s
.38873 .57119 m .39292 .62288 L .42101 .61983 L p .707 .577 .707 r
F P
0 g
s
.4251 .74838 m .42329 .24772 L .46477 .24266 L p .707 .577 .707 r
F P
0 g
s
.42101 .61983 m .42465 .61944 L p .42025 .61352 L .707 .577 .707 r
F P
0 g
s
.42025 .61352 m .38873 .57119 L .42101 .61983 L .707 .577 .707 r
F
.38934 .25606 m .38972 .36245 L p .38613 .33295 L F P
0 g
s
.76347 .60456 m .76766 .65625 L .79688 .64872 L p .707 .577 .707 r
F P
0 g
s
.79688 .64872 m .79269 .59703 L .76347 .60456 L p .707 .577 .707 r
F P
0 g
s
.17777 .79534 m .17825 .77654 L .20228 .77276 L p .707 .577 .707 r
F P
0 g
s
.20228 .77276 m .2018 .79156 L .17777 .79534 L p .707 .577 .707 r
F P
0 g
s
.70479 .65871 m .7006 .60702 L .6731 .60171 L p .707 .577 .707 r
F P
0 g
s
.7006 .60702 m .70479 .65871 L .73593 .65969 L p .707 .577 .707 r
F P
0 g
s
.79269 .59703 m .79688 .64872 L .82073 .63783 L p .707 .577 .707 r
F P
0 g
s
.82073 .63783 m .81653 .58614 L .79269 .59703 L p .707 .577 .707 r
F P
0 g
s
.32209 .77733 m .32161 .79614 L .29415 .79207 L p .707 .577 .707 r
F P
0 g
s
.29415 .79207 m .29463 .77326 L .32209 .77733 L p .707 .577 .707 r
F P
0 g
s
.59249 .25027 m .5943 .75092 L .55553 .74466 L p .707 .577 .707 r
F P
0 g
s
.55553 .74466 m .55373 .244 L .59249 .25027 L p .707 .577 .707 r
F P
0 g
s
.6773 .6534 m .6731 .60171 L .65194 .59259 L p .707 .577 .707 r
F P
0 g
s
.6731 .60171 m .6773 .6534 L .70479 .65871 L p .707 .577 .707 r
F P
0 g
s
.2018 .79156 m .20228 .77276 L .23164 .77086 L p .707 .577 .707 r
F P
0 g
s
.72981 .73477 m .73029 .71596 L .69913 .71373 L p .707 .577 .707 r
F P
0 g
s
.73029 .71596 m .72981 .73477 L .76164 .73494 L p .707 .577 .707 r
F P
0 g
s
.76164 .73494 m .76212 .71613 L .73029 .71596 L p .707 .577 .707 r
F P
0 g
s
.23164 .77086 m .23116 .78967 L .2018 .79156 L p .707 .577 .707 r
F P
0 g
s
.76212 .71613 m .76164 .73494 L .791 .73305 L p .707 .577 .707 r
F P
0 g
s
.791 .73305 m .79148 .71424 L .76212 .71613 L p .707 .577 .707 r
F P
0 g
s
.69913 .71373 m .69864 .73254 L .72981 .73477 L p .707 .577 .707 r
F P
0 g
s
.81653 .58614 m .82073 .63783 L .83687 .62467 L p .707 .577 .707 r
F P
0 g
s
.83687 .62467 m .83268 .57297 L .81653 .58614 L p .707 .577 .707 r
F P
0 g
s
.29463 .77326 m .29415 .79207 L .26298 .78984 L p .707 .577 .707 r
F P
0 g
s
.26298 .78984 m .26346 .77104 L .29463 .77326 L p .707 .577 .707 r
F P
0 g
s
.69864 .73254 m .69913 .71373 L .67166 .70967 L p .707 .577 .707 r
F P
0 g
s
.73457 .74791 m .7336 .71159 L .70244 .71001 L p .707 .577 .707 r
F P
0 g
s
.7336 .71159 m .73457 .74791 L .7664 .74619 L p .707 .577 .707 r
F P
0 g
s
.7664 .74619 m .76543 .70987 L .7336 .71159 L p .707 .577 .707 r
F P
0 g
s
.76543 .70987 m .7664 .74619 L .79576 .74134 L p .707 .577 .707 r
F P
0 g
s
.79148 .71424 m .791 .73305 L .81503 .72927 L p .707 .577 .707 r
F P
0 g
s
.81503 .72927 m .81551 .71046 L .79148 .71424 L p .707 .577 .707 r
F P
0 g
s
.79576 .74134 m .79479 .70502 L .76543 .70987 L p .707 .577 .707 r
F P
0 g
s
.23116 .78967 m .23164 .77086 L .26346 .77104 L p .707 .577 .707 r
F P
0 g
s
.67166 .70967 m .67118 .72847 L .69864 .73254 L p .707 .577 .707 r
F P
0 g
s
.26346 .77104 m .26298 .78984 L .23116 .78967 L p .707 .577 .707 r
F P
0 g
s
.70341 .74633 m .70244 .71001 L .67497 .7053 L p .707 .577 .707 r
F P
0 g
s
.70244 .71001 m .70341 .74633 L .73457 .74791 L p .707 .577 .707 r
F P
0 g
s
.55373 .244 m .55553 .74466 L .51152 .74204 L p .707 .577 .707 r
F P
0 g
s
.51152 .74204 m .50972 .24138 L .55373 .244 L p .707 .577 .707 r
F P
0 g
s
.65614 .64428 m .65194 .59259 L .63919 .58055 L p .707 .577 .707 r
F P
0 g
s
.65194 .59259 m .65614 .64428 L .6773 .6534 L p .707 .577 .707 r
F P
0 g
s
.46658 .74332 m .46477 .24266 L .50972 .24138 L p .707 .577 .707 r
F P
0 g
s
.46477 .24266 m .46658 .74332 L .4251 .74838 L p .707 .577 .707 r
F P
0 g
s
.81551 .71046 m .81503 .72927 L .83137 .72397 L p .707 .577 .707 r
F P
0 g
s
.79479 .70502 m .79576 .74134 L .81979 .73384 L p .707 .577 .707 r
F P
0 g
s
.83137 .72397 m .83185 .70516 L .81551 .71046 L p .707 .577 .707 r
F P
0 g
s
.81979 .73384 m .81882 .69753 L .79479 .70502 L p .707 .577 .707 r
F P
0 g
s
.67118 .72847 m .67166 .70967 L .6506 .70416 L p .707 .577 .707 r
F P
0 g
s
.50972 .24138 m .51152 .74204 L .46658 .74332 L p .707 .577 .707 r
F P
0 g
s
.6506 .70416 m .65011 .72297 L .67118 .72847 L p .707 .577 .707 r
F P
0 g
s
.67497 .7053 m .67594 .74161 L .70341 .74633 L p .707 .577 .707 r
F P
0 g
s
.83268 .57297 m .83687 .62467 L .84373 .6105 L p .707 .577 .707 r
F P
0 g
s
.84373 .6105 m .83953 .55881 L .83268 .57297 L p .707 .577 .707 r
F P
0 g
s
.67594 .74161 m .67497 .7053 L .65391 .6979 L p .707 .577 .707 r
F P
0 g
s
.83185 .70516 m .83137 .72397 L .83278 .72272 L p .707 .577 .707 r
F P
0 g
s
.83274 .72638 m .83613 .72443 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83294 .70723 m .83185 .70516 L .83278 .72272 L .707 .577 .707 r
F
.83613 .72443 m .83516 .68811 L .83312 .68929 L p F P
0 g
s
.83297 .70417 m .83185 .70516 L p .83294 .70723 L .707 .577 .707 r
F P
0 g
s
.83312 .68929 m .81882 .69753 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83613 .72443 m .83312 .68929 L .83281 .71927 L .707 .577 .707 r
F
.83516 .68811 m .83613 .72443 L .84319 .71401 L p F P
0 g
s
.84319 .71401 m .84222 .6777 L .83516 .68811 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83891 .69887 L .83297 .70417 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83297 .70417 L .83294 .70723 L .707 .577 .707 r
F
.83278 .72272 m .83843 .71768 L p .83294 .70723 L F P
0 g
s
.81882 .69753 m .81979 .73384 L .83274 .72638 L p .707 .577 .707 r
F P
0 g
s
.83281 .71927 m .81882 .69753 L .83274 .72638 L .707 .577 .707 r
F
.65391 .6979 m .65488 .73422 L .67594 .74161 L p F P
0 g
s
.63919 .58055 m .64338 .63224 L .65614 .64428 L p .707 .577 .707 r
F P
0 g
s
.64338 .63224 m .63919 .58055 L .63609 .56677 L p .707 .577 .707 r
F P
0 g
s
.65011 .72297 m .6506 .70416 L .63798 .69776 L p .707 .577 .707 r
F P
0 g
s
.63798 .69776 m .6375 .71657 L .65011 .72297 L p .707 .577 .707 r
F P
0 g
s
.65488 .73422 m .65391 .6979 L .64129 .68855 L p .707 .577 .707 r
F P
0 g
s
.83953 .55881 m .84373 .6105 L .84063 .59672 L p .707 .577 .707 r
F P
0 g
s
.84063 .59672 m .83643 .54503 L .83953 .55881 L p .707 .577 .707 r
F P
0 g
s
.64129 .68855 m .64226 .72487 L .65488 .73422 L p .707 .577 .707 r
F P
0 g
s
.63609 .56677 m .64028 .61847 L .64338 .63224 L p .707 .577 .707 r
F P
0 g
s
.64028 .61847 m .63609 .56677 L .64294 .55261 L p .707 .577 .707 r
F P
0 g
s
.6375 .71657 m .63798 .69776 L .63506 .69109 L p .707 .577 .707 r
F P
0 g
s
.63506 .69109 m .63458 .7099 L .6375 .71657 L p .707 .577 .707 r
F P
0 g
s
.64226 .72487 m .64129 .68855 L .63837 .67816 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83643 .54503 m .84063 .59672 L .82787 .58469 L p .707 .577 .707 r
F P
0 g
s
.82787 .58469 m .82368 .53299 L .83643 .54503 L p .707 .577 .707 r
F P
0 g
s
.63837 .67816 m .63934 .71448 L .64226 .72487 L p .707 .577 .707 r
F P
0 g
s
.83891 .69887 m .83843 .71768 L .83551 .71101 L p .707 .577 .707 r
F P
0 g
s
.83551 .71101 m .83599 .6922 L .83891 .69887 L p .707 .577 .707 r
F P
0 g
s
.84222 .6777 m .84319 .71401 L .84027 .70362 L p .707 .577 .707 r
F P
0 g
s
.84027 .70362 m .8393 .66731 L .84222 .6777 L p .707 .577 .707 r
F P
0 g
s
.64294 .55261 m .64714 .6043 L .64028 .61847 L p .707 .577 .707 r
F P
0 g
s
.64714 .6043 m .64294 .55261 L .65909 .53944 L p .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .63837 .67816 L .64455 .66905 L p .707 .577 .707 r
F P
0 g
s
.64455 .66905 m .64543 .66775 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .64455 .66905 L .6446 .67411 L .707 .577 .707 r
F
.6447 .68396 m .65846 .6795 L p .64486 .69899 L F P
0 g
s
.65846 .6795 m .65798 .69831 L .6449 .70255 L p .707 .577 .707 r
F P
0 g
s
.64486 .69899 m .65846 .6795 L .6449 .70255 L .707 .577 .707 r
F
.64543 .66775 m .6464 .70406 L .64493 .70623 L p F P
0 g
s
.64493 .70623 m .63934 .71448 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.6446 .67411 m .64543 .66775 L .64493 .70623 L .707 .577 .707 r
F
.6449 .70255 m .64164 .70361 L p .64486 .69899 L F P
0 g
s
.64164 .70361 m .64212 .6848 L .6447 .68396 L p .707 .577 .707 r
F P
0 g
s
.64164 .70361 m .6447 .68396 L .64486 .69899 L .707 .577 .707 r
F
.63458 .7099 m .63506 .69109 L .64212 .6848 L p F P
0 g
s
.39292 .62288 m .38873 .57119 L .35759 .5702 L p .707 .577 .707 r
F P
0 g
s
.42465 .61944 m .42046 .56774 L .38873 .57119 L p .707 .577 .707 r
F P
0 g
s
.42046 .56774 m .42465 .61944 L .45387 .6119 L p .707 .577 .707 r
F P
0 g
s
.45387 .6119 m .44968 .56021 L .42046 .56774 L p .707 .577 .707 r
F P
0 g
s
.64212 .6848 m .64164 .70361 L .63458 .7099 L p .707 .577 .707 r
F P
0 g
s
.82368 .53299 m .82787 .58469 L .80671 .57556 L p .707 .577 .707 r
F P
0 g
s
.80671 .57556 m .80252 .52387 L .82368 .53299 L p .707 .577 .707 r
F P
0 g
s
.36178 .6219 m .35759 .5702 L .33009 .56489 L p .707 .577 .707 r
F P
0 g
s
.35759 .5702 m .36178 .6219 L .39292 .62288 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44968 .56021 m .45387 .6119 L .47772 .60102 L p .707 .577 .707 r
F P
0 g
s
.47772 .60102 m .47352 .54933 L .44968 .56021 L p .707 .577 .707 r
F P
0 g
s
.83599 .6922 m .83551 .71101 L .82289 .70461 L p .707 .577 .707 r
F P
0 g
s
.82289 .70461 m .82338 .6858 L .83599 .6922 L p .707 .577 .707 r
F P
0 g
s
.65909 .53944 m .66328 .59113 L .64714 .6043 L p .707 .577 .707 r
F P
0 g
s
.66328 .59113 m .65909 .53944 L .68294 .52856 L p .707 .577 .707 r
F P
0 g
s
.8393 .66731 m .84027 .70362 L .82765 .69427 L p .707 .577 .707 r
F P
0 g
s
.82765 .69427 m .82668 .65796 L .8393 .66731 L p .707 .577 .707 r
F P
0 g
s
.33429 .61659 m .33009 .56489 L .30893 .55577 L p .707 .577 .707 r
F P
0 g
s
.33009 .56489 m .33429 .61659 L .36178 .6219 L p .707 .577 .707 r
F P
0 g
s
.3868 .69795 m .38728 .67914 L .35612 .67691 L p .707 .577 .707 r
F P
0 g
s
.38728 .67914 m .3868 .69795 L .41863 .69813 L p .707 .577 .707 r
F P
0 g
s
.41863 .69813 m .41911 .67932 L .38728 .67914 L p .707 .577 .707 r
F P
0 g
s
.80252 .52387 m .80671 .57556 L .77922 .57025 L p .707 .577 .707 r
F P
0 g
s
.77922 .57025 m .77502 .51856 L .80252 .52387 L p .707 .577 .707 r
F P
0 g
s
.41911 .67932 m .41863 .69813 L .44799 .69623 L p .707 .577 .707 r
F P
0 g
s
.44799 .69623 m .44847 .67742 L .41911 .67932 L p .707 .577 .707 r
F P
0 g
s
.35612 .67691 m .35563 .69572 L .3868 .69795 L p .707 .577 .707 r
F P
0 g
s
.47352 .54933 m .47772 .60102 L .49386 .58785 L p .707 .577 .707 r
F P
0 g
s
.49386 .58785 m .48967 .53616 L .47352 .54933 L p .707 .577 .707 r
F P
0 g
s
.35563 .69572 m .35612 .67691 L .32865 .67285 L p .707 .577 .707 r
F P
0 g
s
.39156 .71109 m .39059 .67477 L .35943 .6732 L p .707 .577 .707 r
F P
0 g
s
.39059 .67477 m .39156 .71109 L .42339 .70937 L p .707 .577 .707 r
F P
0 g
s
.42339 .70937 m .42242 .67305 L .39059 .67477 L p .707 .577 .707 r
F P
0 g
s
.6464 .70406 m .64543 .66775 L .66177 .65833 L p .707 .577 .707 r
F P
0 g
s
.42242 .67305 m .42339 .70937 L .45275 .70453 L p .707 .577 .707 r
F P
0 g
s
.44847 .67742 m .44799 .69623 L .47202 .69245 L p .707 .577 .707 r
F P
0 g
s
.47202 .69245 m .4725 .67364 L .44847 .67742 L p .707 .577 .707 r
F P
0 g
s
.45275 .70453 m .45178 .66821 L .42242 .67305 L p .707 .577 .707 r
F P
0 g
s
.32865 .67285 m .32817 .69166 L .35563 .69572 L p .707 .577 .707 r
F P
0 g
s
.68713 .58025 m .68294 .52856 L .71216 .52102 L p .707 .577 .707 r
F P
0 g
s
.68294 .52856 m .68713 .58025 L .66328 .59113 L p .707 .577 .707 r
F P
0 g
s
.3604 .70951 m .35943 .6732 L .33196 .66848 L p .707 .577 .707 r
F P
0 g
s
.35943 .6732 m .3604 .70951 L .39156 .71109 L p .707 .577 .707 r
F P
0 g
s
.77502 .51856 m .77922 .57025 L .74808 .56927 L p .707 .577 .707 r
F P
0 g
s
.74808 .56927 m .74389 .51758 L .77502 .51856 L p .707 .577 .707 r
F P
0 g
s
.31313 .60747 m .30893 .55577 L .29618 .54373 L p .707 .577 .707 r
F P
0 g
s
.30893 .55577 m .31313 .60747 L .33429 .61659 L p .707 .577 .707 r
F P
0 g
s
.65798 .69831 m .65846 .6795 L .68249 .67572 L p .707 .577 .707 r
F P
0 g
s
.68249 .67572 m .68201 .69453 L .65798 .69831 L p .707 .577 .707 r
F P
0 g
s
.66177 .65833 m .66274 .69465 L .6464 .70406 L p .707 .577 .707 r
F P
0 g
s
.82338 .6858 m .82289 .70461 L .80183 .69911 L p .707 .577 .707 r
F P
0 g
s
.80183 .69911 m .80231 .6803 L .82338 .6858 L p .707 .577 .707 r
F P
0 g
s
.4725 .67364 m .47202 .69245 L .48836 .68716 L p .707 .577 .707 r
F P
0 g
s
.45178 .66821 m .45275 .70453 L .47678 .69703 L p .707 .577 .707 r
F P
0 g
s
.48836 .68716 m .48884 .66835 L .4725 .67364 L p .707 .577 .707 r
F P
0 g
s
.47678 .69703 m .47581 .66071 L .45178 .66821 L p .707 .577 .707 r
F P
0 g
s
.82668 .65796 m .82765 .69427 L .80659 .68688 L p .707 .577 .707 r
F P
0 g
s
.80659 .68688 m .80562 .65056 L .82668 .65796 L p .707 .577 .707 r
F P
0 g
s
.71635 .57272 m .71216 .52102 L .74389 .51758 L p .707 .577 .707 r
F P
0 g
s
.71216 .52102 m .71635 .57272 L .68713 .58025 L p .707 .577 .707 r
F P
0 g
s
.32817 .69166 m .32865 .67285 L .30759 .66735 L p .707 .577 .707 r
F P
0 g
s
.74389 .51758 m .74808 .56927 L .71635 .57272 L p .707 .577 .707 r
F P
0 g
s
.30759 .66735 m .3071 .68616 L .32817 .69166 L p .707 .577 .707 r
F P
0 g
s
.33196 .66848 m .33293 .7048 L .3604 .70951 L p .707 .577 .707 r
F P
0 g
s
.48967 .53616 m .49386 .58785 L .50072 .57368 L p .707 .577 .707 r
F P
0 g
s
.50072 .57368 m .49652 .52199 L .48967 .53616 L p .707 .577 .707 r
F P
0 g
s
.33293 .7048 m .33196 .66848 L .3109 .66108 L p .707 .577 .707 r
F P
0 g
s
.66274 .69465 m .66177 .65833 L .6858 .65083 L p .707 .577 .707 r
F P
0 g
s
.48884 .66835 m .48836 .68716 L .48977 .6859 L p .707 .577 .707 r
F P
0 g
s
.48973 .68957 m .49312 .68761 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.48993 .67041 m .48884 .66835 L .48977 .6859 L .707 .577 .707 r
F
.49312 .68761 m .49215 .65129 L .49011 .65247 L p F P
0 g
s
.48996 .66735 m .48884 .66835 L p .48993 .67041 L .707 .577 .707 r
F P
0 g
s
.49011 .65247 m .47581 .66071 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.49312 .68761 m .49011 .65247 L .4898 .68245 L .707 .577 .707 r
F
.49215 .65129 m .49312 .68761 L .50018 .6772 L p F P
0 g
s
.50018 .6772 m .49921 .64088 L .49215 .65129 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .4959 .66206 L .48996 .66735 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .48996 .66735 L .48993 .67041 L .707 .577 .707 r
F
.48977 .6859 m .49542 .68086 L p .48993 .67041 L F P
0 g
s
.47581 .66071 m .47678 .69703 L .48973 .68957 L p .707 .577 .707 r
F P
0 g
s
.4898 .68245 m .47581 .66071 L .48973 .68957 L .707 .577 .707 r
F
.3109 .66108 m .31187 .6974 L .33293 .7048 L p F P
0 g
s
.29618 .54373 m .30037 .59543 L .31313 .60747 L p .707 .577 .707 r
F P
0 g
s
.80231 .6803 m .80183 .69911 L .77436 .69504 L p .707 .577 .707 r
F P
0 g
s
.77436 .69504 m .77485 .67623 L .80231 .6803 L p .707 .577 .707 r
F P
0 g
s
.80562 .65056 m .80659 .68688 L .77912 .68216 L p .707 .577 .707 r
F P
0 g
s
.77912 .68216 m .77815 .64584 L .80562 .65056 L p .707 .577 .707 r
F P
0 g
s
.30037 .59543 m .29618 .54373 L .29308 .52996 L p .707 .577 .707 r
F P
0 g
s
.3071 .68616 m .30759 .66735 L .29497 .66095 L p .707 .577 .707 r
F P
0 g
s
.68201 .69453 m .68249 .67572 L .71185 .67383 L p .707 .577 .707 r
F P
0 g
s
.6858 .65083 m .68677 .68715 L .66274 .69465 L p .707 .577 .707 r
F P
0 g
s
.29497 .66095 m .29449 .67976 L .3071 .68616 L p .707 .577 .707 r
F P
0 g
s
.31187 .6974 m .3109 .66108 L .29828 .65173 L p .707 .577 .707 r
F P
0 g
s
.68677 .68715 m .6858 .65083 L .71516 .64599 L p .707 .577 .707 r
F P
0 g
s
.71185 .67383 m .71137 .69264 L .68201 .69453 L p .707 .577 .707 r
F P
0 g
s
.49652 .52199 m .50072 .57368 L .49762 .55991 L p .707 .577 .707 r
F P
0 g
s
.49762 .55991 m .49342 .50821 L .49652 .52199 L p .707 .577 .707 r
F P
0 g
s
.77485 .67623 m .77436 .69504 L .7432 .69281 L p .707 .577 .707 r
F P
0 g
s
.7432 .69281 m .74368 .674 L .77485 .67623 L p .707 .577 .707 r
F P
0 g
s
.77815 .64584 m .77912 .68216 L .74796 .68058 L p .707 .577 .707 r
F P
0 g
s
.74796 .68058 m .74699 .64427 L .77815 .64584 L p .707 .577 .707 r
F P
0 g
s
.71137 .69264 m .71185 .67383 L .74368 .674 L p .707 .577 .707 r
F P
0 g
s
.71613 .6823 m .71516 .64599 L .74699 .64427 L p .707 .577 .707 r
F P
0 g
s
.71516 .64599 m .71613 .6823 L .68677 .68715 L p .707 .577 .707 r
F P
0 g
s
.29828 .65173 m .29925 .68805 L .31187 .6974 L p .707 .577 .707 r
F P
0 g
s
.74368 .674 m .7432 .69281 L .71137 .69264 L p .707 .577 .707 r
F P
0 g
s
.74699 .64427 m .74796 .68058 L .71613 .6823 L p .707 .577 .707 r
F P
0 g
s
.29308 .52996 m .29727 .58165 L .30037 .59543 L p .707 .577 .707 r
F P
0 g
s
.29727 .58165 m .29308 .52996 L .29993 .51579 L p .707 .577 .707 r
F P
0 g
s
.29449 .67976 m .29497 .66095 L .29205 .65428 L p .707 .577 .707 r
F P
0 g
s
.29205 .65428 m .29157 .67308 L .29449 .67976 L p .707 .577 .707 r
F P
0 g
s
.29925 .68805 m .29828 .65173 L .29536 .64134 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49342 .50821 m .49762 .55991 L .48486 .54787 L p .707 .577 .707 r
F P
0 g
s
.48486 .54787 m .48067 .49618 L .49342 .50821 L p .707 .577 .707 r
F P
0 g
s
.29536 .64134 m .29633 .67766 L .29925 .68805 L p .707 .577 .707 r
F P
0 g
s
.4959 .66206 m .49542 .68086 L .4925 .67419 L p .707 .577 .707 r
F P
0 g
s
.4925 .67419 m .49298 .65538 L .4959 .66206 L p .707 .577 .707 r
F P
0 g
s
.49921 .64088 m .50018 .6772 L .49726 .66681 L p .707 .577 .707 r
F P
0 g
s
.49726 .66681 m .49629 .63049 L .49921 .64088 L p .707 .577 .707 r
F P
0 g
s
.29993 .51579 m .30413 .56749 L .29727 .58165 L p .707 .577 .707 r
F P
0 g
s
.30413 .56749 m .29993 .51579 L .31608 .50262 L p .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .29536 .64134 L .30154 .63223 L p .707 .577 .707 r
F P
0 g
s
.30154 .63223 m .30242 .63093 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .30154 .63223 L .30159 .63729 L .707 .577 .707 r
F
.30169 .64715 m .31545 .64269 L p .30185 .66218 L F P
0 g
s
.31545 .64269 m .31497 .6615 L .30189 .66574 L p .707 .577 .707 r
F P
0 g
s
.30185 .66218 m .31545 .64269 L .30189 .66574 L .707 .577 .707 r
F
.30242 .63093 m .30339 .66725 L .30192 .66941 L p F P
0 g
s
.30192 .66941 m .29633 .67766 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.30159 .63729 m .30242 .63093 L .30192 .66941 L .707 .577 .707 r
F
.30189 .66574 m .29863 .66679 L p .30185 .66218 L F P
0 g
s
.29863 .66679 m .29911 .64798 L .30169 .64715 L p .707 .577 .707 r
F P
0 g
s
.29863 .66679 m .30169 .64715 L .30185 .66218 L .707 .577 .707 r
F
.29157 .67308 m .29205 .65428 L .29911 .64798 L p F P
0 g
s
.29911 .64798 m .29863 .66679 L .29157 .67308 L p .707 .577 .707 r
F P
0 g
s
.48067 .49618 m .48486 .54787 L .4637 .53875 L p .707 .577 .707 r
F P
0 g
s
.4637 .53875 m .45951 .48706 L .48067 .49618 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49298 .65538 m .4925 .67419 L .47988 .66779 L p .707 .577 .707 r
F P
0 g
s
.47988 .66779 m .48037 .64898 L .49298 .65538 L p .707 .577 .707 r
F P
0 g
s
.31608 .50262 m .32027 .55432 L .30413 .56749 L p .707 .577 .707 r
F P
0 g
s
.32027 .55432 m .31608 .50262 L .33993 .49174 L p .707 .577 .707 r
F P
0 g
s
.49629 .63049 m .49726 .66681 L .48464 .65746 L p .707 .577 .707 r
F P
0 g
s
.48464 .65746 m .48367 .62114 L .49629 .63049 L p .707 .577 .707 r
F P
0 g
s
.45951 .48706 m .4637 .53875 L .43621 .53344 L p .707 .577 .707 r
F P
0 g
s
.43621 .53344 m .43201 .48174 L .45951 .48706 L p .707 .577 .707 r
F P
0 g
s
.30339 .66725 m .30242 .63093 L .31876 .62151 L p .707 .577 .707 r
F P
0 g
s
.34412 .54343 m .33993 .49174 L .36915 .48421 L p .707 .577 .707 r
F P
0 g
s
.33993 .49174 m .34412 .54343 L .32027 .55432 L p .707 .577 .707 r
F P
0 g
s
.43201 .48174 m .43621 .53344 L .40507 .53246 L p .707 .577 .707 r
F P
0 g
s
.40507 .53246 m .40088 .48076 L .43201 .48174 L p .707 .577 .707 r
F P
0 g
s
.31497 .6615 m .31545 .64269 L .33948 .63891 L p .707 .577 .707 r
F P
0 g
s
.33948 .63891 m .339 .65772 L .31497 .6615 L p .707 .577 .707 r
F P
0 g
s
.31876 .62151 m .31973 .65783 L .30339 .66725 L p .707 .577 .707 r
F P
0 g
s
.48037 .64898 m .47988 .66779 L .45882 .66229 L p .707 .577 .707 r
F P
0 g
s
.45882 .66229 m .4593 .64348 L .48037 .64898 L p .707 .577 .707 r
F P
0 g
s
.48367 .62114 m .48464 .65746 L .46358 .65006 L p .707 .577 .707 r
F P
0 g
s
.46358 .65006 m .46261 .61374 L .48367 .62114 L p .707 .577 .707 r
F P
0 g
s
.37334 .5359 m .36915 .48421 L .40088 .48076 L p .707 .577 .707 r
F P
0 g
s
.36915 .48421 m .37334 .5359 L .34412 .54343 L p .707 .577 .707 r
F P
0 g
s
.40088 .48076 m .40507 .53246 L .37334 .5359 L p .707 .577 .707 r
F P
0 g
s
.31973 .65783 m .31876 .62151 L .34279 .61402 L p .707 .577 .707 r
F P
0 g
s
.4593 .64348 m .45882 .66229 L .43135 .65823 L p .707 .577 .707 r
F P
0 g
s
.43135 .65823 m .43184 .63942 L .4593 .64348 L p .707 .577 .707 r
F P
0 g
s
.46261 .61374 m .46358 .65006 L .43611 .64535 L p .707 .577 .707 r
F P
0 g
s
.43611 .64535 m .43514 .60903 L .46261 .61374 L p .707 .577 .707 r
F P
0 g
s
.339 .65772 m .33948 .63891 L .36884 .63701 L p .707 .577 .707 r
F P
0 g
s
.34279 .61402 m .34376 .65033 L .31973 .65783 L p .707 .577 .707 r
F P
0 g
s
.34376 .65033 m .34279 .61402 L .37215 .60917 L p .707 .577 .707 r
F P
0 g
s
.36884 .63701 m .36836 .65582 L .339 .65772 L p .707 .577 .707 r
F P
0 g
s
.43184 .63942 m .43135 .65823 L .40018 .656 L p .707 .577 .707 r
F P
0 g
s
.40018 .656 m .40067 .63719 L .43184 .63942 L p .707 .577 .707 r
F P
0 g
s
.43514 .60903 m .43611 .64535 L .40495 .64377 L p .707 .577 .707 r
F P
0 g
s
.40495 .64377 m .40397 .60745 L .43514 .60903 L p .707 .577 .707 r
F P
0 g
s
.36836 .65582 m .36884 .63701 L .40067 .63719 L p .707 .577 .707 r
F P
0 g
s
.37312 .64549 m .37215 .60917 L .40397 .60745 L p .707 .577 .707 r
F P
0 g
s
.37215 .60917 m .37312 .64549 L .34376 .65033 L p .707 .577 .707 r
F P
0 g
s
.40067 .63719 m .40018 .656 L .36836 .65582 L p .707 .577 .707 r
F P
0 g
s
.40397 .60745 m .40495 .64377 L .37312 .64549 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001EYF00<005YFFUH015YF2@00OGoo001fOol90005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uo
o`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH90002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000D000AJEP03001JEUYF009JEPP000IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD00003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Ggoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001FOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol005Aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0001Moo`l003moo`00E7oo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00004Goo1P0015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000=Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH80008FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH20008FUH00`00FUIJEP06FUH40004FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP0015YF00<005YFFUH00eYF0`0000Eoo`00FUIJ
EP0000EJEP8000QJEP03001JEUYF00UJEP@00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=o
o`04001JEUYF0004FUH01000FUIJEUYF0P0017oo00@005YFFUH000EJEP8000QJEP03001JEUYF00UJ
EP03001JEUYF00<000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF00@005YF
000000Ioo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH30003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0P0027oo00@005YFFUH000EJEP8000QJ
EP03001JEUYF00QJEP800003FUH005YF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02000^Ool005Aoo`03001JEP0000=JEP03001oogoo00Qoo`04001JEUYF0005FUH20008FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol01000
FUH005YF10002Goo00@005YFFUH000EJEP@000IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009J
EP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00E7oo00@005YF000000AJEP<000Ioo`04001J
EUYF0005FUH50005FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000^Ool005Aoo`04001JEP000005FUH00`00FUH000030002Ool01000FUIJEP001EYF
30001EYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001DOol20002FUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`P000AJEP03001JEUYF00=JEP04
001JEP00000^Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH015YF00<0
05YFFUH00UYF0P005goo1@001EYF00@005YFFUH002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0005FUH00`00FUIJEP04FUH00`00FUH00002000NOol20003FUH01000FUIJEP00;Woo001DOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH00eYF0`008goo0P0000EJ
EP00FUIJEP0002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH2000UOol200000eYF00000002FUH2000]Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000009Goo0P0000=JEP00FUH00UYF00@005YF
000002eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH2000UOol20003FUH01000FUIJ
EUYF1000;Goo001EOol01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH2000EOol3000<Ool30005FUH01P00FUIJEUYF
001JEP8002eoo`00AWoo2@001goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`000UYF0P004Woo1@001goo100000=J
EP00FUH01EYF00<005YFFUH00UYF0`00;Goo0010Ool60004FUH00`00FUIJEP02FUH;0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00T005YFFUIJEP00FUH005YF000015YF
1@003Goo30001EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000lOol400000eYF001JEP07
FUH00`00FUIJEP06FUH01000FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF2@0000=J
EP00FUH01eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000hOol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH80002FUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000fOol200000eYF001JEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH300000eYF000000050003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool003Aoo`8000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00;Woo000bOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0002moo`00<Goo0P001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000;goo000`Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
<7oo000_Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000aOol002ioo`03001JEUYF
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000cOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00=Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0015YF00<005YFFUH01EYF5`000eYF00@005YF000003Moo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF
00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000AJEP<00003FUH005YF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000@003Uoo`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF3`000eYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUH000050006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000gOol002aoo`9JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00AJEPL000=JEP03001JEUYF00EJEP04001JEP000003FUH01000FUH000000UYF00<005YFFUH0
0UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo0UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01EYF0P0000=JEP00
FUH00UYF0P0000=JEP0000001`000UYF00<005YFFUH015YF00<005YFFUH015YF200015YF00<005YF
FUH00eYF00<005YF00000UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo0UYF0P0015YF00<005YFFUH00eYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH01@0000IJEP00000005YF0002FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<005YFFUH010000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00;7oo0eYF00<005YFFUH00UYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP0000@00004FUH000000004FUH20002FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH01eYF0P0000=JEP0000000P000UYF10000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool3FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH00UYF1`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF009JEPD000EJEP03001JEP0000D0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04
001JEP000004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00;Goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800005FUH0
05YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000]Ool002aoo`@00004FUH000000006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo
00<005YF00000P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80003FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUIJEP04FUHE0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=J
EPH0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF0080
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03P001EYF00<005YFFUH00eYF
00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05
001JEUYF001JEP020004FUH00`00FUH000030004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0000AJEP00FUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0015YF0P0000=JEP000000
1@0000=JEP00Ool01Woo4@000eYF00<005YFFUH015YF0P000UYF0P00;Goo000/Ool01000FUIJEP00
0eYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF0080009J
EPL000=JEP04001JEUYF000HOol50004FUH01@00FUIJEP00FUH00P00;Goo000/Ool01000FUIJEP00
0eYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF00@00004FUH0
00000003FUH200001EYF001JEUYF00006goo1@0000=JEP00FUH00UYF0`00;Goo000]Ool2FUH01000
FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP03FUH70002FUH2000EOol50005FUH20003FUH3000]Ool002eoo`9JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000P000AJEP03001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00=JEP04001JEUYFFUH90009Ool9
0003FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00;Goo000]Ool01EYF001JEUYF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00`000UYF00<005YFFUH02@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
02eoo`00;Goo00=JEP00FUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`<0009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP8000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`00;Woo000^Ool00`00FUIJEP02
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEP000UYF
00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02000_Ool002ioo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50005FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF10001EYF
00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000_Ool00`00FUH00003FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP030002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00<goo000`Ool20005
FUH50003FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0400000eYF001JEP05FUH30002Ool01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000aOol2
0004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP03FUH20004Ool0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000cOol300000eYF001JEP06
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUH000030006Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH015YF8@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P001EYF1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01000?Goo000fOol50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000:Ool01000FUIJEP001UYF00<005YF
FUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P001UYF00<005YFFUH05`00@Goo000kOol90004FUH00`00FUIJEP05FUH8000=
Ool01000FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YF00000`001eYF00<005YFFUH00UYF0P000UYF0P001UYF00<005YF00000UYF
0P00E7oo0014Ool<000EOol01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0P000UYF0P00
1UYF0P0015YF00<007ooOol0DWoo001UOol01000FUIJEP001EYF0`000eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
0P000eYF00<005YFFUH00eYF0P001EYF00<007ooOol0DWoo001UOol01000FUIJEP000eYF0P001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00Oomoo`1COol006Eo
o`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF00@005YF000000=JEP05001J
EUYFFUH0001FOol006Eoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP<0
00EJEP05001JEUYFFUH0001FOol003Iooal0011oo`03001JEP0000=JEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0000<00003FUH005YF00EJEP04001JEP00001GOol0039oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000aoo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH2001IOol0031oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000Moo`8000AJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP02FUH2001KOol002ioo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@000=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002
FUH6001MOol002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003Ool0000000AJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<006=oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0P00Igoo000/Ool20004FUH01000FUIJEUYF20004Goo200015YF00<005YF
FUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00;7oo0P00
0UYF1P008Goo1`000eYF00H005YFFUIJEP00Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00Oomoo`1VOol002]oo`03001JEP0000@002aoo`@000=JEP04001oogooOol30008FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JGoo000[Ool20003FUH00`00FUH00002000]Ool200000eYF001oo`04Ool20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUH00000Jgoo000[Ool20003FUH00`00FUIJEP02FUH5000ROol6000015YF000000001goo0`0015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1@00K7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@004Woo1`000eYF00L005YFFUIJ
EP00FUH0000:Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060004FUH8001TOol002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000eoo`L000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00IJEP04001JEUYFFUH6001N
Ool002eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000EOol;0006FUH00`00FUIJEP0:FUH01000
FUIJEUYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00Fgoo
000_Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02000QOolG0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3001HOol003=oo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EP00001FOol003Yoo`P000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03
001JEP0000AJEP04001JEUYFFUHQ0003FUH00`00FUIJEP04FUH01000FUIJEP00EWoo0012OolH000c
Ool00`00FUH00003FUH5000QOol50004FUH01000FUIJEUYF0P00EGoo002=Ool01000FUH005YF0P00
:goo0`0000=JEP00FUH00UYF0P00EGoo002=Ool00`00FUH00004000]Ool20003FUH2001EOol008eo
o`80009JEP03001JEUYF00D002Uoo`<00003FUH0000005Eoo`00SGoo0P000UYF00<005YFFUH00eYF
00<005YF00000`0087oo1@000eYF0`00EGoo002>Ool01000FUIJEP001EYF00<005YFFUH00eYF8000
0eYF00<005YFFUH00UYF0`00EGoo002?Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001EOol0095o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH3001FOol009=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001IOol009Ioo`D000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001KOol009]ooa8000AJEP03
001JEUYF009JEPL0061oo`00[Goo2@00Igoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59427 .74824 m .58418 .74809 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.58418 .74809 m .56319 .74779 L p .57475 .76269 L .707 .577 .707 r
F P
0 g
s
.5845 .77527 m .58418 .74809 L .57475 .76269 L .707 .577 .707 r
F
.55235 .74549 m .53564 .74195 L p .54569 .75782 L F P
0 g
s
.53564 .74195 m .51431 .73129 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53869 .77078 m .53865 .76901 L .53751 .7685 L .707 .577 .707 r
F
.53959 .77252 m .53945 .76936 L p .53869 .77078 L F P
0 g
s
.53945 .76936 m .53564 .74195 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .56706 .77744 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53959 .77252 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .56991 .79606 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53564 .74195 m .53945 .76936 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .54235 .79022 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .55235 .74549 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.55492 .7724 m .55235 .74549 L .54569 .75782 L .707 .577 .707 r
F
.56694 .77476 m .56319 .74779 L p .55492 .7724 L F P
0 g
s
.53802 .73674 m .53945 .76936 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53802 .73674 L p .53869 .77078 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .53751 .7685 L .5183 .75998 L .707 .577 .707 r
F
.52001 .76512 m .53959 .77252 L p .5183 .75998 L F P
0 g
s
.52103 .77957 m .54235 .79022 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.51431 .73129 m .5183 .75998 L p .5219 .74725 L .707 .577 .707 r
F P
0 g
s
.51334 .75513 m .5183 .75998 L .5013 .71687 L .707 .577 .707 r
F
.51772 .76203 m .51766 .75935 L .51657 .75829 L F
.5185 .76455 m .5183 .75998 L p .51772 .76203 L F P
0 g
s
.5183 .75998 m .51431 .73129 L .50558 .72162 L p .707 .577 .707 r
F P
0 g
s
.50558 .72162 m .5013 .71687 L p .5183 .75998 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .51693 .72878 L p .51772 .76203 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .5185 .76455 L .52001 .76512 L p .707 .577 .707 r
F P
0 g
s
.5185 .76455 m .51657 .75829 L .50556 .74754 L .707 .577 .707 r
F
.50672 .75501 m .5185 .76455 L p .50556 .74754 L F P
0 g
s
.50801 .76514 m .52103 .77957 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.5013 .71687 m .50556 .74754 L p .50568 .73079 L .707 .577 .707 r
F P
0 g
s
.50449 .74258 m .50556 .74754 L .49787 .70008 L .707 .578 .707 r
F
.50554 .75097 m .50537 .74666 L .50493 .74461 L .707 .577 .707 r
F
.50586 .75431 m .50556 .74754 L p .50554 .75097 L F P
0 g
s
.50556 .74754 m .5013 .71687 L .49934 .70732 L p .707 .578 .707 r
F P
0 g
s
.49934 .70732 m .49787 .70008 L p .50556 .74754 L .707 .578 .707 r
F P
0 g
s
.50556 .74754 m .50429 .71853 L p .50554 .75097 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50586 .75431 L .50672 .75501 L p .707 .577 .707 r
F P
0 g
s
.50586 .75431 m .50493 .74461 L .50248 .73325 L .707 .577 .707 r
F
.503 .74318 m .50586 .75431 L p .50248 .73325 L F P
0 g
s
.50458 .74836 m .50801 .76514 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.50449 .74258 m .49897 .70714 L .50248 .73325 L .707 .578 .707 r
F
.50248 .73325 m .50458 .74836 L p .50449 .74258 L F P
0 g
s
.50133 .70702 m .50248 .73325 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50429 .71853 m .50133 .70702 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50537 .74666 m .50429 .71853 L .50493 .74461 L .707 .577 .707 r
F
.51334 .75513 m .50568 .73079 L .50556 .74754 L F
.50429 .71853 m .50556 .74754 L p .51657 .75829 L F P
0 g
s
.51693 .72878 m .50429 .71853 L p .51657 .75829 L .707 .577 .707 r
F P
0 g
s
.50133 .70702 m .50776 .69633 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50661 .68023 m .52014 .66608 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50776 .69633 m .50834 .69537 L p .50794 .69884 L .707 .577 .707 r
F P
0 g
s
.50449 .72895 m .50776 .69633 L .50794 .69884 L .707 .577 .707 r
F
.51327 .7152 m .50936 .71852 L .52014 .66608 L F
.5105 .72929 m .50936 .71852 L .5156 .71321 L F
.50801 .76514 m .50556 .74754 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.51076 .73172 m .50458 .74836 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .50936 .71852 L p .5105 .72929 L .707 .577 .707 r
F P
0 g
s
.50458 .74836 m .50452 .72889 L .50936 .71852 L .707 .577 .707 r
F
.50458 .74836 m .50248 .73325 L p .50452 .72889 L F P
0 g
s
.50248 .73325 m .5029 .7428 L .503 .74318 L p .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .5029 .7428 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .50936 .71852 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50991 .73114 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50436 .68258 m .50936 .71852 L p .50452 .72889 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .50991 .73114 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52621 .72048 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .54366 .65219 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .52552 .70478 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.52685 .71435 m .52552 .70478 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52014 .66608 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .57262 .64227 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.55074 .69302 m .54366 .65219 L .5535 .69227 L .707 .577 .707 r
F
.57262 .64227 m .60418 .63729 L p .58189 .68507 L F P
0 g
s
.58006 .68528 m .57262 .64227 L .58189 .68507 L .707 .577 .707 r
F
.60418 .63729 m .63526 .63774 L p .61281 .68181 L F P
0 g
s
.61159 .68178 m .60418 .63729 L .61281 .68181 L .707 .577 .707 r
F
.63526 .63774 m .66281 .64358 L p .64345 .68302 L F P
0 g
s
.64252 .68283 m .63526 .63774 L .64345 .68302 L .707 .577 .707 r
F
.66281 .64358 m .68414 .65424 L p .67071 .6888 L F P
0 g
s
.68414 .65424 m .69715 .66866 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70319 .7301 m .70445 .71285 L .69807 .71573 L .707 .577 .707 r
F
.70509 .70407 m .7036 .70655 L p .70445 .71285 L F P
0 g
s
.7036 .70655 m .69807 .71573 L p .70445 .71285 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70509 .70407 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70058 .68545 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70058 .68545 m .69409 .70295 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .67831 .71945 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69909 .73888 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.70081 .75122 m .70657 .73569 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70635 .73151 m .70452 .72725 L .70657 .73569 L .707 .577 .707 r
F
.69807 .71573 m .69909 .73888 L p .70319 .7301 L F P
0 g
s
.69807 .71573 m .69673 .71661 L p .69722 .72128 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .69909 .73888 L p .69567 .70663 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69409 .70295 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69964 .75151 L .69996 .75098 L p .707 .577 .707 r
F P
0 g
s
.68334 .76217 m .68499 .76109 L p .68467 .75979 L .707 .577 .707 r
F P
0 g
s
.68293 .75262 m .68334 .76217 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.67505 .75638 m .68293 .75262 L .6647 .74013 L .707 .577 .707 r
F
.66387 .74366 m .6647 .74013 L .65479 .73334 L F
.67505 .75638 m .6647 .74013 L .66387 .74366 L F
.67528 .72124 m .65479 .73334 L p .68293 .75262 L F P
0 g
s
.64525 .73661 m .62583 .74326 L p .63707 .75535 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .59427 .74824 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.6285 .77499 m .62849 .77211 L .62592 .77241 L .707 .577 .707 r
F
.63002 .77652 m .62982 .77195 L p .6285 .77499 L F P
0 g
s
.62982 .77195 m .62583 .74326 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63002 .77652 m .65936 .77079 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63002 .77652 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .66151 .78162 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .62982 .77195 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63255 .79154 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .64525 .73661 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.64794 .76703 m .64525 .73661 L .63707 .75535 L .707 .577 .707 r
F
.65906 .76401 m .65479 .73334 L p .64794 .76703 L F P
0 g
s
.62845 .74075 m .62982 .77195 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .62845 .74075 L p .6285 .77499 L .707 .577 .707 r
F P
0 g
s
.59822 .77881 m .63002 .77652 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59427 .74824 m .59808 .77566 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59665 .74304 m .59808 .77566 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59822 .77881 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .63255 .79154 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .60098 .79652 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .62982 .77195 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.62845 .74075 m .59665 .74304 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.62849 .77211 m .62845 .74075 L .62592 .77241 L .707 .577 .707 r
F
.65781 .76929 m .65781 .76435 L .65384 .76543 L F
.65936 .77079 m .65906 .76401 L p .65781 .76929 L F P
0 g
s
.65936 .77079 m .68334 .76217 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65936 .77079 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .68503 .76773 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .65906 .76401 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .66151 .78162 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .65906 .76401 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65779 .73501 L p .65781 .76929 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .65906 .76401 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .62845 .74075 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.65781 .76435 m .65779 .73501 L .65384 .76543 L .707 .577 .707 r
F
.68293 .75262 m .67831 .71945 L .67528 .72124 L p F P
0 g
s
.67831 .71945 m .68293 .75262 L p .68391 .72735 L .707 .577 .707 r
F P
0 g
s
.68178 .72639 m .65779 .73501 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.68259 .76136 m .68239 .75287 L .67701 .75544 L .707 .577 .707 r
F
.68239 .75287 m .68178 .72639 L .67701 .75544 L F
.68334 .76217 m .68293 .75262 L p .68259 .76136 L F P
0 g
s
.68293 .75262 m .68178 .72639 L p .68259 .76136 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .68293 .75262 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69384 .74335 L .68467 .75979 L .707 .577 .707 r
F
.68499 .76109 m .69964 .75151 L p .68467 .75979 L F P
0 g
s
.69471 .74261 m .68391 .72735 L .68457 .75122 L .707 .577 .707 r
F
.68293 .75262 m .68503 .76773 L p .68391 .72735 L F P
0 g
s
.68178 .72639 m .68293 .75262 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .70081 .75122 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69471 .74261 m .68457 .75122 L .68503 .76773 L .707 .577 .707 r
F
.69909 .73888 m .69807 .71573 L p .69384 .74335 L F P
0 g
s
.70452 .72725 m .69567 .70663 L .69909 .73888 L .707 .577 .707 r
F
.69384 .74335 m .69722 .72128 L .68178 .72639 L F
.69673 .71661 m .68178 .72639 L p .69722 .72128 L F P
0 g
s
.69909 .73888 m .70081 .75122 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.7073 .73372 m .70597 .72415 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70597 .72415 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70369 .72834 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70436 .71671 m .70588 .72373 L .70665 .73985 L .707 .577 .707 r
F
.70058 .68545 m .70597 .72415 L p .70361 .71323 L .707 .578 .707 r
F P
0 g
s
.70597 .72415 m .70665 .73985 L p .705 .70559 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .69014 .69742 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70288 .70986 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70369 .72834 m .70288 .70986 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70364 .71476 m .70336 .71207 L .7041 .71774 L .707 .578 .707 r
F
.70336 .71207 m .70058 .68545 L .70361 .71323 L F
.70336 .71207 m .70361 .71323 L .7041 .71774 L F
.70369 .72834 m .69105 .7181 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70058 .68545 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70288 .70986 m .69715 .66866 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70213 .69256 m .70288 .70986 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70369 .72834 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70387 .71694 m .70288 .70986 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70436 .71671 m .70288 .70986 L .70509 .70407 L .707 .577 .707 r
F
.69085 .70251 m .69155 .69879 L .70288 .70986 L F
.70288 .70986 m .70387 .71694 L .70284 .7158 L p F P
0 g
s
.70284 .7158 m .69085 .70251 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70213 .69256 L .70298 .69588 L p .707 .577 .707 r
F P
0 g
s
.70298 .69588 m .70509 .70407 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.7041 .71774 m .70361 .71323 L .70597 .72415 L .707 .578 .707 r
F
.70436 .71671 m .705 .70559 L .70588 .72373 L .707 .577 .707 r
F
.70509 .70407 m .70597 .72415 L p .705 .70559 L F P
0 g
s
.70657 .73569 m .7073 .73372 L p .70635 .73151 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70319 .7301 L .69909 .73888 L .707 .577 .707 r
F
.70081 .75122 m .69909 .73888 L p .69988 .74992 L F P
0 g
s
.69996 .75098 m .70665 .73985 L p .69909 .73888 L .707 .577 .707 r
F P
0 g
s
.69988 .74992 m .69909 .73888 L .69471 .74261 L .707 .577 .707 r
F
.68948 .68232 m .69993 .69079 L p .69708 .70419 L F P
0 g
s
.69993 .69079 m .70213 .69256 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69708 .70419 m .69993 .69079 L .70071 .69582 L .707 .577 .707 r
F
.70387 .71694 m .70364 .71476 L .7041 .71774 L .707 .578 .707 r
F
.70597 .72415 m .7073 .73372 L .70717 .7331 L p F P
0 g
s
.70717 .7331 m .70387 .71694 L p .70597 .72415 L .707 .578 .707 r
F P
0 g
s
.69082 .69807 m .68414 .65424 L .69155 .69879 L .707 .577 .707 r
F
.69014 .69742 m .68414 .65424 L p .69121 .70062 L F P
0 g
s
.69014 .69742 m .68948 .68232 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69121 .70062 m .69082 .69807 L .69155 .69879 L .707 .577 .707 r
F
.69085 .70251 m .69014 .69742 L p .69121 .70062 L F P
0 g
s
.66996 .71013 m .66899 .68804 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .66996 .71013 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69105 .7181 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69085 .70251 m .66953 .69186 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68414 .65424 m .69014 .69742 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69085 .70251 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68948 .68232 m .69014 .69742 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .68452 .68044 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.68452 .68044 m .68948 .68232 L p .68653 .68652 L .707 .577 .707 r
F P
0 g
s
.68156 .69361 m .68452 .68044 L .68653 .68652 L .707 .577 .707 r
F
.66988 .68843 m .66281 .64358 L .67071 .6888 L F
.66899 .68804 m .66281 .64358 L p .67017 .69021 L F P
0 g
s
.66899 .68804 m .66839 .67435 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.67017 .69021 m .66988 .68843 L .67071 .6888 L .707 .577 .707 r
F
.66953 .69186 m .66899 .68804 L p .67017 .69021 L F P
0 g
s
.64249 .70522 m .6415 .68263 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66996 .71013 m .64249 .70522 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66996 .71013 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66953 .69186 m .64197 .68602 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66281 .64358 m .66899 .68804 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66953 .69186 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .66899 .68804 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .66091 .67301 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66091 .67301 m .66839 .67435 L p .66427 .67926 L .707 .577 .707 r
F P
0 g
s
.65862 .686 m .66091 .67301 L .66427 .67926 L .707 .577 .707 r
F
.6415 .68263 m .63526 .63774 L p .64277 .68439 L F P
0 g
s
.6415 .68263 m .64092 .66944 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64277 .68439 m .64252 .68283 L .64345 .68302 L .707 .577 .707 r
F
.64197 .68602 m .6415 .68263 L p .64277 .68439 L F P
0 g
s
.61133 .70384 m .61036 .68174 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64249 .70522 m .61133 .70384 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64249 .70522 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64197 .68602 m .6109 .68557 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.63526 .63774 m .6415 .68263 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64197 .68602 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .6415 .68263 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .63166 .66903 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.63166 .66903 m .64092 .66944 L p .63605 .6751 L .707 .577 .707 r
F P
0 g
s
.62986 .6823 m .63166 .66903 L .63605 .6751 L .707 .577 .707 r
F
.61036 .68174 m .60418 .63729 L p .61189 .68361 L F P
0 g
s
.61036 .68174 m .60976 .66806 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.61189 .68361 m .61159 .68178 L .61281 .68181 L .707 .577 .707 r
F
.6109 .68557 m .61036 .68174 L p .61189 .68361 L F P
0 g
s
.57953 .70613 m .57862 .68545 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61133 .70384 m .57953 .70613 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .61133 .70384 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.6109 .68557 m .57933 .69054 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60418 .63729 m .61036 .68174 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .6109 .68557 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .61036 .68174 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .59975 .66878 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.59975 .66878 m .60976 .66806 L p .60454 .67463 L .707 .577 .707 r
F P
0 g
s
.59772 .68322 m .59975 .66878 L .60454 .67463 L .707 .577 .707 r
F
.57862 .68545 m .57262 .64227 L p .58053 .68798 L F P
0 g
s
.57862 .68545 m .57796 .67035 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.58053 .68798 m .58006 .68528 L .58189 .68507 L .707 .577 .707 r
F
.57933 .69054 m .57862 .68545 L p .58053 .68798 L F P
0 g
s
.5502 .71186 m .54939 .69339 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57953 .70613 m .5502 .71186 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57953 .70613 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57933 .69054 m .55037 .70046 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57262 .64227 m .57862 .68545 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57933 .69054 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .57862 .68545 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .56865 .67217 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.56865 .67217 m .57796 .67035 L p .57293 .67787 L .707 .577 .707 r
F P
0 g
s
.56548 .68902 m .56865 .67217 L .57293 .67787 L .707 .577 .707 r
F
.54939 .69339 m .54366 .65219 L p .55151 .69748 L F P
0 g
s
.54939 .69339 m .54863 .67609 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.55151 .69748 m .55074 .69302 L .5535 .69227 L .707 .577 .707 r
F
.55037 .70046 m .54939 .69339 L p .55151 .69748 L F P
0 g
s
.5502 .71186 m .52621 .72048 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .5502 .71186 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.55037 .70046 m .52685 .71435 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .54939 .69339 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .55037 .70046 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .54939 .69339 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.53688 .69936 m .52552 .70478 L .54363 .68229 L .707 .577 .707 r
F
.54458 .68411 m .54363 .68229 L .54863 .67609 L F
.53688 .69936 m .54363 .68229 L .54458 .68411 L F
.52552 .70478 m .52464 .68471 L .52632 .6841 L p F P
0 g
s
.52632 .6841 m .54863 .67609 L p .52552 .70478 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .51327 .7152 L .52514 .71446 L .707 .577 .707 r
F
.52685 .71435 m .52508 .71621 L p .52514 .71446 L F P
0 g
s
.52508 .71621 m .51107 .73086 L p .52514 .71446 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .52552 .70478 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52685 .71435 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52464 .68471 m .52552 .70478 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .51107 .73086 L .51076 .73172 L p .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .52464 .68471 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50834 .69537 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .50936 .71852 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50436 .68258 L .50661 .68023 L p .707 .577 .707 r
F P
0 g
s
.50288 .7324 m .50133 .70702 L .50449 .72895 L .707 .577 .707 r
F
.50248 .73325 m .50133 .70702 L p .5033 .73933 L F P
0 g
s
.50452 .72889 m .50248 .73325 L .50436 .68258 L .707 .577 .707 r
F
.5033 .73933 m .50288 .7324 L .50449 .72895 L F
.5029 .7428 m .50248 .73325 L p .5033 .73933 L F P
0 g
s
.49787 .70008 m .50248 .73325 L p .49897 .70714 L .707 .578 .707 r
F P
0 g
s
.50248 .73325 m .49787 .70008 L .5004 .69326 L p .707 .577 .707 r
F P
0 g
s
.5004 .69326 m .50436 .68258 L p .50248 .73325 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50801 .76514 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.52103 .77957 m .5183 .75998 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.51766 .75935 m .51693 .72878 L .51657 .75829 L .707 .577 .707 r
F
.53055 .76541 m .5219 .74725 L .5183 .75998 L F
.5183 .75998 m .52103 .77957 L p .53055 .76541 L F P
0 g
s
.51693 .72878 m .5183 .75998 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .53945 .76936 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53802 .73674 m .51693 .72878 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.53865 .76901 m .53802 .73674 L .53751 .7685 L .707 .577 .707 r
F
.56609 .77608 m .56607 .77459 L .56486 .77436 L F
.56706 .77744 m .56694 .77476 L p .56609 .77608 L F P
0 g
s
.56706 .77744 m .59822 .77881 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56706 .77744 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .60098 .79652 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .56694 .77476 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56991 .79606 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59427 .74824 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .56694 .77476 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56549 .74166 L p .56609 .77608 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .56694 .77476 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .53802 .73674 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.56607 .77459 m .56549 .74166 L .56486 .77436 L .707 .577 .707 r
F
.59665 .74304 m .56549 .74166 L p .59537 .77558 L F P
0 g
s
.59822 .77881 m .59808 .77566 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59665 .74304 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .59808 .77566 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59052 .87901 m .59129 .86007 L .56013 .85763 L p .707 .577 .707 r
F P
0 g
s
.59129 .86007 m .59052 .87901 L .62232 .87978 L p .707 .577 .707 r
F P
0 g
s
.62232 .87978 m .6231 .86084 L .59129 .86007 L p .707 .577 .707 r
F P
0 g
s
.6231 .86084 m .62232 .87978 L .65165 .87881 L p .707 .577 .707 r
F P
0 g
s
.65165 .87881 m .65243 .85987 L .6231 .86084 L p .707 .577 .707 r
F P
0 g
s
.56013 .85763 m .55935 .87657 L .59052 .87901 L p .707 .577 .707 r
F P
0 g
s
.55935 .87657 m .56013 .85763 L .53266 .85377 L p .707 .577 .707 r
F P
0 g
s
.53266 .85377 m .53189 .87271 L .55935 .87657 L p .707 .577 .707 r
F P
0 g
s
.65243 .85987 m .65165 .87881 L .67564 .8762 L p .707 .577 .707 r
F P
0 g
s
.67564 .8762 m .67642 .85726 L .65243 .85987 L p .707 .577 .707 r
F P
0 g
s
.53189 .87271 m .53266 .85377 L .51158 .84887 L p .707 .577 .707 r
F P
0 g
s
.51158 .84887 m .5108 .86781 L .53189 .87271 L p .707 .577 .707 r
F P
0 g
s
.67642 .85726 m .67564 .8762 L .69194 .8722 L p .707 .577 .707 r
F P
0 g
s
.69194 .8722 m .69272 .85326 L .67642 .85726 L p .707 .577 .707 r
F P
0 g
s
.5108 .86781 m .51158 .84887 L .49893 .84339 L p .707 .577 .707 r
F P
0 g
s
.49893 .84339 m .49815 .86233 L .5108 .86781 L p .707 .577 .707 r
F P
0 g
s
.69272 .85326 m .69194 .8722 L .69895 .8672 L p .707 .577 .707 r
F P
0 g
s
.69895 .8672 m .69973 .84826 L .69272 .85326 L p .707 .577 .707 r
F P
0 g
s
.49362 .82167 m .4907 .3218 L .44669 .31922 L p .707 .577 .707 r
F P
0 g
s
.4907 .3218 m .49362 .82167 L .53856 .82027 L p .707 .577 .707 r
F P
0 g
s
.53856 .82027 m .53564 .3204 L .4907 .3218 L p .707 .577 .707 r
F P
0 g
s
.53564 .3204 m .53856 .82027 L .58004 .81504 L p .707 .577 .707 r
F P
0 g
s
.58004 .81504 m .57712 .31517 L .53564 .3204 L p .707 .577 .707 r
F P
0 g
s
.49815 .86233 m .49893 .84339 L .49597 .83789 L p .707 .577 .707 r
F P
0 g
s
.49597 .83789 m .49519 .85683 L .49815 .86233 L p .707 .577 .707 r
F P
0 g
s
.44961 .81909 m .44669 .31922 L .40793 .31291 L p .707 .577 .707 r
F P
0 g
s
.44669 .31922 m .44961 .81909 L .49362 .82167 L p .707 .577 .707 r
F P
0 g
s
.57712 .31517 m .58004 .81504 L .614 .80648 L p .707 .577 .707 r
F P
0 g
s
.614 .80648 m .61108 .30661 L .57712 .31517 L p .707 .577 .707 r
F P
0 g
s
.69973 .84826 m .69895 .8672 L .69599 .86169 L p .707 .577 .707 r
F P
0 g
s
.69599 .86169 m .69677 .84275 L .69973 .84826 L p .707 .577 .707 r
F P
0 g
s
.41085 .81278 m .40793 .31291 L .3782 .3035 L p .707 .577 .707 r
F P
0 g
s
.40793 .31291 m .41085 .81278 L .44961 .81909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.49519 .85683 m .49597 .83789 L .50299 .83289 L p .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .24117 .71128 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.24117 .71128 m .22018 .71097 L p .23174 .72587 L .707 .577 .707 r
F P
0 g
s
.2415 .73845 m .24117 .71128 L .23174 .72587 L .707 .577 .707 r
F
.20934 .70867 m .19263 .70513 L p .20268 .721 L F P
0 g
s
.19263 .70513 m .1713 .69448 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19568 .73396 m .19564 .73219 L .1945 .73169 L .707 .577 .707 r
F
.19658 .73571 m .19644 .73255 L p .19568 .73396 L F P
0 g
s
.19644 .73255 m .19263 .70513 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .22405 .74062 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19658 .73571 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .2269 .75925 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19263 .70513 m .19644 .73255 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19934 .75341 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .20934 .70867 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.21192 .73559 m .20934 .70867 L .20268 .721 L .707 .577 .707 r
F
.22393 .73795 m .22018 .71097 L p .21192 .73559 L F P
0 g
s
.19501 .69993 m .19644 .73255 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19501 .69993 L p .19568 .73396 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .1945 .73169 L .17529 .72317 L .707 .577 .707 r
F
.177 .72831 m .19658 .73571 L p .17529 .72317 L F P
0 g
s
.17802 .74275 m .19934 .75341 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.1713 .69448 m .17529 .72317 L p .1789 .71043 L .707 .577 .707 r
F P
0 g
s
.17033 .71832 m .17529 .72317 L .15829 .68005 L .707 .577 .707 r
F
.17471 .72521 m .17465 .72254 L .17356 .72147 L F
.17549 .72774 m .17529 .72317 L p .17471 .72521 L F P
0 g
s
.17529 .72317 m .1713 .69448 L .16257 .6848 L p .707 .577 .707 r
F P
0 g
s
.16257 .6848 m .15829 .68005 L p .17529 .72317 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17392 .69196 L p .17471 .72521 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17549 .72774 L .177 .72831 L p .707 .577 .707 r
F P
0 g
s
.17549 .72774 m .17356 .72147 L .16255 .71072 L .707 .577 .707 r
F
.16371 .71819 m .17549 .72774 L p .16255 .71072 L F P
0 g
s
.165 .72833 m .17802 .74275 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.15829 .68005 m .16255 .71072 L p .16267 .69398 L .707 .577 .707 r
F P
0 g
s
.16148 .70577 m .16255 .71072 L .15486 .66327 L .707 .578 .707 r
F
.16253 .71415 m .16236 .70985 L .16192 .70779 L .707 .577 .707 r
F
.16285 .7175 m .16255 .71072 L p .16253 .71415 L F P
0 g
s
.16255 .71072 m .15829 .68005 L .15633 .6705 L p .707 .578 .707 r
F P
0 g
s
.15633 .6705 m .15486 .66327 L p .16255 .71072 L .707 .578 .707 r
F P
0 g
s
.16255 .71072 m .16128 .68172 L p .16253 .71415 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .16285 .7175 L .16371 .71819 L p .707 .577 .707 r
F P
0 g
s
.16285 .7175 m .16192 .70779 L .15947 .69644 L .707 .577 .707 r
F
.15999 .70637 m .16285 .7175 L p .15947 .69644 L F P
0 g
s
.16157 .71154 m .165 .72833 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16148 .70577 m .15596 .67033 L .15947 .69644 L .707 .578 .707 r
F
.15947 .69644 m .16157 .71154 L p .16148 .70577 L F P
0 g
s
.15832 .67021 m .15947 .69644 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16128 .68172 m .15832 .67021 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16236 .70985 m .16128 .68172 L .16192 .70779 L .707 .577 .707 r
F
.17033 .71832 m .16267 .69398 L .16255 .71072 L F
.16128 .68172 m .16255 .71072 L p .17356 .72147 L F P
0 g
s
.17392 .69196 m .16128 .68172 L p .17356 .72147 L .707 .577 .707 r
F P
0 g
s
.15832 .67021 m .16475 .65951 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.1636 .64342 m .17713 .62926 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.16475 .65951 m .16533 .65855 L p .16493 .66202 L .707 .577 .707 r
F P
0 g
s
.16148 .69213 m .16475 .65951 L .16493 .66202 L .707 .577 .707 r
F
.17026 .67838 m .16635 .6817 L .17713 .62926 L F
.16749 .69247 m .16635 .6817 L .17259 .6764 L F
.165 .72833 m .16255 .71072 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16775 .6949 m .16157 .71154 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .16635 .6817 L p .16749 .69247 L .707 .577 .707 r
F P
0 g
s
.16157 .71154 m .16151 .69207 L .16635 .6817 L .707 .577 .707 r
F
.16157 .71154 m .15947 .69644 L p .16151 .69207 L F P
0 g
s
.15947 .69644 m .15989 .70599 L .15999 .70637 L p .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .15989 .70599 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .16635 .6817 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .1669 .69433 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16135 .64577 m .16635 .6817 L p .16151 .69207 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .1669 .69433 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .1832 .68367 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .20065 .61537 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .18251 .66797 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.18384 .67754 m .18251 .66797 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .17713 .62926 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .22961 .60545 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.20773 .6562 m .20065 .61537 L .2105 .65545 L .707 .577 .707 r
F
.22961 .60545 m .26117 .60047 L p .23888 .64825 L F P
0 g
s
.23705 .64846 m .22961 .60545 L .23888 .64825 L .707 .577 .707 r
F
.26117 .60047 m .29225 .60093 L p .2698 .645 L F P
0 g
s
.26858 .64496 m .26117 .60047 L .2698 .645 L .707 .577 .707 r
F
.29225 .60093 m .3198 .60677 L p .30044 .6462 L F P
0 g
s
.29951 .64602 m .29225 .60093 L .30044 .6462 L .707 .577 .707 r
F
.3198 .60677 m .34113 .61742 L p .32771 .65198 L F P
0 g
s
.34113 .61742 m .35414 .63185 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36018 .69329 m .36144 .67603 L .35506 .67891 L .707 .577 .707 r
F
.36208 .66726 m .36059 .66973 L p .36144 .67603 L F P
0 g
s
.36059 .66973 m .35506 .67891 L p .36144 .67603 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .36208 .66726 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .35757 .64863 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35757 .64863 m .35108 .66613 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .3353 .68264 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35608 .70207 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.3578 .71441 m .36356 .69888 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36334 .6947 m .36151 .69043 L .36356 .69888 L .707 .577 .707 r
F
.35506 .67891 m .35608 .70207 L p .36018 .69329 L F P
0 g
s
.35506 .67891 m .35372 .67979 L p .35421 .68446 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .35608 .70207 L p .35266 .66981 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35108 .66613 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35663 .71469 L .35695 .71417 L p .707 .577 .707 r
F P
0 g
s
.34034 .72535 m .34198 .72428 L p .34166 .72297 L .707 .577 .707 r
F P
0 g
s
.33992 .7158 m .34034 .72535 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.33204 .71956 m .33992 .7158 L .32169 .70332 L .707 .577 .707 r
F
.32086 .70685 m .32169 .70332 L .31178 .69653 L F
.33204 .71956 m .32169 .70332 L .32086 .70685 L F
.33227 .68443 m .31178 .69653 L p .33992 .7158 L F P
0 g
s
.30224 .69979 m .28282 .70645 L p .29406 .71853 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .25126 .71142 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28549 .73818 m .28548 .73529 L .28291 .73559 L .707 .577 .707 r
F
.28701 .73971 m .28681 .73514 L p .28549 .73818 L F P
0 g
s
.28681 .73514 m .28282 .70645 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28701 .73971 m .31635 .73397 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28701 .73971 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .3185 .7448 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .28681 .73514 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28954 .75472 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .30224 .69979 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.30493 .73022 m .30224 .69979 L .29406 .71853 L .707 .577 .707 r
F
.31605 .7272 m .31178 .69653 L p .30493 .73022 L F P
0 g
s
.28545 .70393 m .28681 .73514 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28545 .70393 L p .28549 .73818 L .707 .577 .707 r
F P
0 g
s
.25521 .742 m .28701 .73971 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .25507 .73884 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25364 .70622 m .25507 .73884 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25521 .742 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .28954 .75472 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25798 .7597 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .28681 .73514 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28545 .70393 m .25364 .70622 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.28548 .73529 m .28545 .70393 L .28291 .73559 L .707 .577 .707 r
F
.3148 .73247 m .3148 .72754 L .31083 .72861 L F
.31635 .73397 m .31605 .7272 L p .3148 .73247 L F P
0 g
s
.31635 .73397 m .34034 .72535 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31635 .73397 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .34202 .73091 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .31605 .7272 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .3185 .7448 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .31605 .7272 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31478 .69819 L p .3148 .73247 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .31605 .7272 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .28545 .70393 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.3148 .72754 m .31478 .69819 L .31083 .72861 L .707 .577 .707 r
F
.33992 .7158 m .3353 .68264 L .33227 .68443 L p F P
0 g
s
.3353 .68264 m .33992 .7158 L p .3409 .69054 L .707 .577 .707 r
F P
0 g
s
.33877 .68957 m .31478 .69819 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.33958 .72455 m .33938 .71606 L .334 .71863 L .707 .577 .707 r
F
.33938 .71606 m .33877 .68957 L .334 .71863 L F
.34034 .72535 m .33992 .7158 L p .33958 .72455 L F P
0 g
s
.33992 .7158 m .33877 .68957 L p .33958 .72455 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .33992 .7158 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35083 .70653 L .34166 .72297 L .707 .577 .707 r
F
.34198 .72428 m .35663 .71469 L p .34166 .72297 L F P
0 g
s
.3517 .70579 m .3409 .69054 L .34156 .71441 L .707 .577 .707 r
F
.33992 .7158 m .34202 .73091 L p .3409 .69054 L F P
0 g
s
.33877 .68957 m .33992 .7158 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .3578 .71441 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.3517 .70579 m .34156 .71441 L .34202 .73091 L .707 .577 .707 r
F
.35608 .70207 m .35506 .67891 L p .35083 .70653 L F P
0 g
s
.36151 .69043 m .35266 .66981 L .35608 .70207 L .707 .577 .707 r
F
.35083 .70653 m .35421 .68446 L .33877 .68957 L F
.35372 .67979 m .33877 .68957 L p .35421 .68446 L F P
0 g
s
.35608 .70207 m .3578 .71441 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36429 .69691 m .36296 .68733 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36296 .68733 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36068 .69152 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36135 .67989 m .36287 .68691 L .36365 .70304 L .707 .577 .707 r
F
.35757 .64863 m .36296 .68733 L p .3606 .67641 L .707 .578 .707 r
F P
0 g
s
.36296 .68733 m .36365 .70304 L p .36199 .66877 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .34713 .6606 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35987 .67305 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36068 .69152 m .35987 .67305 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36063 .67794 m .36035 .67525 L .36109 .68093 L .707 .578 .707 r
F
.36035 .67525 m .35757 .64863 L .3606 .67641 L F
.36035 .67525 m .3606 .67641 L .36109 .68093 L F
.36068 .69152 m .34804 .68128 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35757 .64863 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35987 .67305 m .35414 .63185 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35912 .65574 m .35987 .67305 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .36068 .69152 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.36086 .68012 m .35987 .67305 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.36135 .67989 m .35987 .67305 L .36208 .66726 L .707 .577 .707 r
F
.34784 .6657 m .34854 .66197 L .35987 .67305 L F
.35987 .67305 m .36086 .68012 L .35983 .67899 L p F P
0 g
s
.35983 .67899 m .34784 .6657 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .35912 .65574 L .35997 .65907 L p .707 .577 .707 r
F P
0 g
s
.35997 .65907 m .36208 .66726 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.36109 .68093 m .3606 .67641 L .36296 .68733 L .707 .578 .707 r
F
.36135 .67989 m .36199 .66877 L .36287 .68691 L .707 .577 .707 r
F
.36208 .66726 m .36296 .68733 L p .36199 .66877 L F P
0 g
s
.36356 .69888 m .36429 .69691 L p .36334 .6947 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36018 .69329 L .35608 .70207 L .707 .577 .707 r
F
.3578 .71441 m .35608 .70207 L p .35687 .7131 L F P
0 g
s
.35695 .71417 m .36365 .70304 L p .35608 .70207 L .707 .577 .707 r
F P
0 g
s
.35687 .7131 m .35608 .70207 L .3517 .70579 L .707 .577 .707 r
F
.34647 .6455 m .35693 .65397 L p .35407 .66738 L F P
0 g
s
.35693 .65397 m .35912 .65574 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35407 .66738 m .35693 .65397 L .3577 .659 L .707 .577 .707 r
F
.36086 .68012 m .36063 .67794 L .36109 .68093 L .707 .578 .707 r
F
.36296 .68733 m .36429 .69691 L .36416 .69628 L p F P
0 g
s
.36416 .69628 m .36086 .68012 L p .36296 .68733 L .707 .578 .707 r
F P
0 g
s
.34781 .66126 m .34113 .61742 L .34854 .66197 L .707 .577 .707 r
F
.34713 .6606 m .34113 .61742 L p .3482 .6638 L F P
0 g
s
.34713 .6606 m .34647 .6455 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.3482 .6638 m .34781 .66126 L .34854 .66197 L .707 .577 .707 r
F
.34784 .6657 m .34713 .6606 L p .3482 .6638 L F P
0 g
s
.32695 .67331 m .32598 .65122 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .32695 .67331 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34804 .68128 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34784 .6657 m .32652 .65504 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34113 .61742 m .34713 .6606 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34784 .6657 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34647 .6455 m .34713 .6606 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .34151 .64363 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34151 .64363 m .34647 .6455 L p .34352 .64971 L .707 .577 .707 r
F P
0 g
s
.33855 .65679 m .34151 .64363 L .34352 .64971 L .707 .577 .707 r
F
.32687 .65161 m .3198 .60677 L .32771 .65198 L F
.32598 .65122 m .3198 .60677 L p .32716 .6534 L F P
0 g
s
.32598 .65122 m .32538 .63754 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32716 .6534 m .32687 .65161 L .32771 .65198 L .707 .577 .707 r
F
.32652 .65504 m .32598 .65122 L p .32716 .6534 L F P
0 g
s
.29948 .6684 m .29849 .64582 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32695 .67331 m .29948 .6684 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32695 .67331 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32652 .65504 m .29896 .6492 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.3198 .60677 m .32598 .65122 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32652 .65504 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .32598 .65122 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .3179 .6362 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.3179 .6362 m .32538 .63754 L p .32126 .64245 L .707 .577 .707 r
F P
0 g
s
.31561 .64918 m .3179 .6362 L .32126 .64245 L .707 .577 .707 r
F
.29849 .64582 m .29225 .60093 L p .29976 .64758 L F P
0 g
s
.29849 .64582 m .29792 .63262 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29976 .64758 m .29951 .64602 L .30044 .6462 L .707 .577 .707 r
F
.29896 .6492 m .29849 .64582 L p .29976 .64758 L F P
0 g
s
.26832 .66702 m .26735 .64493 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29948 .6684 m .26832 .66702 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29948 .6684 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29896 .6492 m .26789 .64875 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29225 .60093 m .29849 .64582 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29896 .6492 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .29849 .64582 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .28865 .63221 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.28865 .63221 m .29792 .63262 L p .29304 .63828 L .707 .577 .707 r
F P
0 g
s
.28685 .64549 m .28865 .63221 L .29304 .63828 L .707 .577 .707 r
F
.26735 .64493 m .26117 .60047 L p .26888 .64679 L F P
0 g
s
.26735 .64493 m .26675 .63124 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26888 .64679 m .26858 .64496 L .2698 .645 L .707 .577 .707 r
F
.26789 .64875 m .26735 .64493 L p .26888 .64679 L F P
0 g
s
.23652 .66931 m .23561 .64863 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26832 .66702 m .23652 .66931 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26832 .66702 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26789 .64875 m .23632 .65373 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26117 .60047 m .26735 .64493 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26789 .64875 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .26735 .64493 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .25674 .63196 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.25674 .63196 m .26675 .63124 L p .26153 .63782 L .707 .577 .707 r
F P
0 g
s
.25472 .6464 m .25674 .63196 L .26153 .63782 L .707 .577 .707 r
F
.23561 .64863 m .22961 .60545 L p .23752 .65117 L F P
0 g
s
.23561 .64863 m .23495 .63353 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23752 .65117 m .23705 .64846 L .23888 .64825 L .707 .577 .707 r
F
.23632 .65373 m .23561 .64863 L p .23752 .65117 L F P
0 g
s
.20719 .67505 m .20638 .65657 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23652 .66931 m .20719 .67505 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23652 .66931 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23632 .65373 m .20736 .66365 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.22961 .60545 m .23561 .64863 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23632 .65373 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .23561 .64863 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .22564 .63536 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.22564 .63536 m .23495 .63353 L p .22992 .64106 L .707 .577 .707 r
F P
0 g
s
.22247 .6522 m .22564 .63536 L .22992 .64106 L .707 .577 .707 r
F
.20638 .65657 m .20065 .61537 L p .2085 .66067 L F P
0 g
s
.20638 .65657 m .20562 .63927 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.2085 .66067 m .20773 .6562 L .2105 .65545 L .707 .577 .707 r
F
.20736 .66365 m .20638 .65657 L p .2085 .66067 L F P
0 g
s
.20719 .67505 m .1832 .68367 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20719 .67505 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20736 .66365 m .18384 .67754 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .20638 .65657 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20736 .66365 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .20638 .65657 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.19387 .66254 m .18251 .66797 L .20062 .64548 L .707 .577 .707 r
F
.20157 .6473 m .20062 .64548 L .20562 .63927 L F
.19387 .66254 m .20062 .64548 L .20157 .6473 L F
.18251 .66797 m .18163 .64789 L .18331 .64729 L p F P
0 g
s
.18331 .64729 m .20562 .63927 L p .18251 .66797 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .17026 .67838 L .18214 .67765 L .707 .577 .707 r
F
.18384 .67754 m .18207 .6794 L p .18214 .67765 L F P
0 g
s
.18207 .6794 m .16806 .69404 L p .18214 .67765 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .18251 .66797 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .18384 .67754 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18163 .64789 m .18251 .66797 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16806 .69404 L .16775 .6949 L p .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .18163 .64789 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16533 .65855 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .16635 .6817 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16135 .64577 L .1636 .64342 L p .707 .577 .707 r
F P
0 g
s
.15987 .69559 m .15832 .67021 L .16148 .69213 L .707 .577 .707 r
F
.15947 .69644 m .15832 .67021 L p .16029 .70251 L F P
0 g
s
.16151 .69207 m .15947 .69644 L .16135 .64577 L .707 .577 .707 r
F
.16029 .70251 m .15987 .69559 L .16148 .69213 L F
.15989 .70599 m .15947 .69644 L p .16029 .70251 L F P
0 g
s
.15486 .66327 m .15947 .69644 L p .15596 .67033 L .707 .578 .707 r
F P
0 g
s
.15947 .69644 m .15486 .66327 L .15739 .65645 L p .707 .577 .707 r
F P
0 g
s
.15739 .65645 m .16135 .64577 L p .15947 .69644 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .165 .72833 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17802 .74275 m .17529 .72317 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17465 .72254 m .17392 .69196 L .17356 .72147 L .707 .577 .707 r
F
.18754 .7286 m .1789 .71043 L .17529 .72317 L F
.17529 .72317 m .17802 .74275 L p .18754 .7286 L F P
0 g
s
.17392 .69196 m .17529 .72317 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .19644 .73255 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19501 .69993 m .17392 .69196 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19564 .73219 m .19501 .69993 L .1945 .73169 L .707 .577 .707 r
F
.22308 .73926 m .22306 .73778 L .22185 .73754 L F
.22405 .74062 m .22393 .73795 L p .22308 .73926 L F P
0 g
s
.22405 .74062 m .25521 .742 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22405 .74062 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .25798 .7597 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .22393 .73795 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .2269 .75925 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25126 .71142 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .22393 .73795 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22248 .70484 L p .22308 .73926 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .22393 .73795 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .19501 .69993 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.22306 .73778 m .22248 .70484 L .22185 .73754 L .707 .577 .707 r
F
.25364 .70622 m .22248 .70484 L p .25236 .73876 L F P
0 g
s
.25521 .742 m .25507 .73884 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25364 .70622 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .25507 .73884 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.50299 .83289 m .50221 .85183 L .49519 .85683 L p .707 .577 .707 r
F P
0 g
s
.61108 .30661 m .614 .80648 L .6371 .79543 L p .707 .577 .707 r
F P
0 g
s
.6371 .79543 m .63418 .29556 L .61108 .30661 L p .707 .577 .707 r
F P
0 g
s
.69677 .84275 m .69599 .86169 L .68335 .85622 L p .707 .577 .707 r
F P
0 g
s
.68335 .85622 m .68413 .83728 L .69677 .84275 L p .707 .577 .707 r
F P
0 g
s
.24751 .84219 m .24829 .82325 L .21712 .82082 L p .707 .577 .707 r
F P
0 g
s
.24829 .82325 m .24751 .84219 L .27931 .84296 L p .707 .577 .707 r
F P
0 g
s
.27931 .84296 m .28009 .82402 L .24829 .82325 L p .707 .577 .707 r
F P
0 g
s
.38112 .80338 m .3782 .3035 L .36042 .29191 L p .707 .577 .707 r
F P
0 g
s
.3782 .3035 m .38112 .80338 L .41085 .81278 L p .707 .577 .707 r
F P
0 g
s
.28009 .82402 m .27931 .84296 L .30864 .84199 L p .707 .577 .707 r
F P
0 g
s
.30864 .84199 m .30942 .82305 L .28009 .82402 L p .707 .577 .707 r
F P
0 g
s
.21712 .82082 m .21635 .83976 L .24751 .84219 L p .707 .577 .707 r
F P
0 g
s
.50221 .85183 m .50299 .83289 L .51929 .82889 L p .707 .577 .707 r
F P
0 g
s
.21635 .83976 m .21712 .82082 L .18966 .81696 L p .707 .577 .707 r
F P
0 g
s
.51929 .82889 m .51851 .84783 L .50221 .85183 L p .707 .577 .707 r
F P
0 g
s
.18966 .81696 m .18888 .8359 L .21635 .83976 L p .707 .577 .707 r
F P
0 g
s
.30942 .82305 m .30864 .84199 L .33263 .83938 L p .707 .577 .707 r
F P
0 g
s
.33263 .83938 m .33341 .82044 L .30942 .82305 L p .707 .577 .707 r
F P
0 g
s
.18888 .8359 m .18966 .81696 L .16857 .81205 L p .707 .577 .707 r
F P
0 g
s
.68413 .83728 m .68335 .85622 L .66226 .85132 L p .707 .577 .707 r
F P
0 g
s
.66226 .85132 m .66304 .83238 L .68413 .83728 L p .707 .577 .707 r
F P
0 g
s
.63418 .29556 m .6371 .79543 L .6471 .78298 L p .707 .577 .707 r
F P
0 g
s
.6471 .78298 m .64418 .28311 L .63418 .29556 L p .707 .577 .707 r
F P
0 g
s
.16857 .81205 m .16779 .83099 L .18888 .8359 L p .707 .577 .707 r
F P
0 g
s
.51851 .84783 m .51929 .82889 L .54328 .82628 L p .707 .577 .707 r
F P
0 g
s
.54328 .82628 m .5425 .84522 L .51851 .84783 L p .707 .577 .707 r
F P
0 g
s
.33341 .82044 m .33263 .83938 L .34893 .83538 L p .707 .577 .707 r
F P
0 g
s
.34893 .83538 m .34971 .81644 L .33341 .82044 L p .707 .577 .707 r
F P
0 g
s
.36334 .79178 m .36042 .29191 L .35633 .27927 L p .707 .577 .707 r
F P
0 g
s
.36042 .29191 m .36334 .79178 L .38112 .80338 L p .707 .577 .707 r
F P
0 g
s
.16779 .83099 m .16857 .81205 L .15593 .80658 L p .707 .577 .707 r
F P
0 g
s
.66304 .83238 m .66226 .85132 L .63479 .84746 L p .707 .577 .707 r
F P
0 g
s
.63479 .84746 m .63557 .82852 L .66304 .83238 L p .707 .577 .707 r
F P
0 g
s
.15593 .80658 m .15515 .82552 L .16779 .83099 L p .707 .577 .707 r
F P
0 g
s
.5425 .84522 m .54328 .82628 L .57261 .82531 L p .707 .577 .707 r
F P
0 g
s
.57261 .82531 m .57183 .84425 L .5425 .84522 L p .707 .577 .707 r
F P
0 g
s
.63557 .82852 m .63479 .84746 L .60363 .84502 L p .707 .577 .707 r
F P
0 g
s
.60363 .84502 m .60441 .82608 L .63557 .82852 L p .707 .577 .707 r
F P
0 g
s
.34971 .81644 m .34893 .83538 L .35594 .83038 L p .707 .577 .707 r
F P
0 g
s
.35594 .83038 m .35672 .81144 L .34971 .81644 L p .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64301 .77033 L .62523 .75874 L p .707 .577 .707 r
F P
0 g
s
.6385 .58015 m .63507 .56337 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.6471 .78298 m .64423 .77411 L p .64379 .60541 L .707 .577 .707 r
F P
0 g
s
.64379 .60541 m .64469 .60948 L .6471 .78298 L .707 .577 .707 r
F
.64309 .73678 m .64359 .53011 L .64423 .77411 L F
.64549 .50744 m .6471 .78298 L p .64359 .53011 L F P
0 g
s
.64309 .73678 m .64189 .55032 L .64359 .53011 L .707 .577 .707 r
F
.64275 .72557 m .64009 .27046 L p .64309 .73678 L F P
0 g
s
.64379 .60541 m .64359 .53011 L .64469 .60948 L .707 .577 .707 r
F
.64522 .62843 m .65823 .64285 L p .6392 .58238 L F P
0 g
s
.6385 .58015 m .63905 .58413 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.63905 .58413 m .64522 .62843 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64418 .28311 L p .64359 .53011 L .707 .577 .707 r
F P
0 g
s
.64189 .55032 m .64009 .27046 L .64359 .53011 L .707 .577 .707 r
F
.64301 .77033 m .64275 .72557 L p .64309 .73678 L F P
0 g
s
.63614 .68371 m .63536 .70265 L .64214 .70559 L p .707 .577 .707 r
F P
0 g
s
.64214 .70559 m .648 .70812 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.64183 .69542 m .63614 .68371 L .64214 .70559 L .707 .577 .707 r
F
.64522 .62843 m .63905 .58413 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.63905 .58413 m .6385 .58015 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.64423 .77411 m .64301 .77033 L p .64309 .73678 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64878 .68918 L .64154 .68605 L p .707 .577 .707 r
F P
0 g
s
.64154 .68605 m .63614 .68371 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64154 .68605 L .64183 .69542 L .707 .577 .707 r
F
.65823 .64285 m .65151 .59458 L .63931 .58105 L p F P
0 g
s
.63931 .58105 m .6385 .58015 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.65823 .64285 m .63931 .58105 L .6392 .58238 L .707 .577 .707 r
F
.64418 .28311 m .64549 .50744 L p .64359 .53011 L F P
0 g
s
.57183 .84425 m .57261 .82531 L .60441 .82608 L p .707 .577 .707 r
F P
0 g
s
.60441 .82608 m .60363 .84502 L .57183 .84425 L p .707 .577 .707 r
F P
0 g
s
.15515 .82552 m .15593 .80658 L .15297 .80108 L p .707 .577 .707 r
F P
0 g
s
.15297 .80108 m .15219 .82001 L .15515 .82552 L p .707 .577 .707 r
F P
0 g
s
.35633 .27927 m .35925 .77914 L .36334 .79178 L p .707 .577 .707 r
F P
0 g
s
.35925 .77914 m .35633 .27927 L .36633 .26681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35672 .81144 m .35594 .83038 L .35298 .82488 L p .707 .577 .707 r
F P
0 g
s
.35298 .82488 m .35376 .80594 L .35672 .81144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15219 .82001 m .15297 .80108 L .15998 .79608 L p .707 .577 .707 r
F P
0 g
s
.62523 .75874 m .62231 .25887 L .64009 .27046 L p .707 .577 .707 r
F P
0 g
s
.15998 .79608 m .1592 .81502 L .15219 .82001 L p .707 .577 .707 r
F P
0 g
s
.35376 .80594 m .35298 .82488 L .34034 .81941 L p .707 .577 .707 r
F P
0 g
s
.34034 .81941 m .34112 .80047 L .35376 .80594 L p .707 .577 .707 r
F P
0 g
s
.36925 .76668 m .36633 .26681 L .38943 .25576 L p .707 .577 .707 r
F P
0 g
s
.36633 .26681 m .36925 .76668 L .35925 .77914 L p .707 .577 .707 r
F P
0 g
s
.1592 .81502 m .15998 .79608 L .17628 .79208 L p .707 .577 .707 r
F P
0 g
s
.17628 .79208 m .1755 .81102 L .1592 .81502 L p .707 .577 .707 r
F P
0 g
s
.62231 .25887 m .62523 .75874 L .59551 .74933 L p .707 .577 .707 r
F P
0 g
s
.59551 .74933 m .59258 .24946 L .62231 .25887 L p .707 .577 .707 r
F P
0 g
s
.34112 .80047 m .34034 .81941 L .31925 .8145 L p .707 .577 .707 r
F P
0 g
s
.31925 .8145 m .32003 .79556 L .34112 .80047 L p .707 .577 .707 r
F P
0 g
s
.73819 .6598 m .73147 .61152 L .70039 .61107 L p .707 .577 .707 r
F P
0 g
s
.73147 .61152 m .73819 .6598 L .76975 .65482 L p .707 .577 .707 r
F P
0 g
s
.76975 .65482 m .76304 .60655 L .73147 .61152 L p .707 .577 .707 r
F P
0 g
s
.76304 .60655 m .76975 .65482 L .79871 .6449 L p .707 .577 .707 r
F P
0 g
s
.79871 .6449 m .792 .59663 L .76304 .60655 L p .707 .577 .707 r
F P
0 g
s
.39063 .46038 m .39235 .75564 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .38943 .25576 L .42339 .2472 L p .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .4077 .50423 L .42373 .71342 L .707 .577 .707 r
F
.42504 .52891 m .42605 .70231 L p .4077 .50423 L F P
0 g
s
.42605 .70231 m .42631 .74708 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.4077 .50423 m .42605 .70231 L .42373 .71342 L .707 .577 .707 r
F
.46487 .24197 m .46779 .74184 L .42631 .74708 L p F P
0 g
s
.44585 .68231 m .44662 .66337 L .43409 .66378 L p .707 .577 .707 r
F P
0 g
s
.42631 .74708 m .42339 .2472 L .46487 .24197 L p .707 .577 .707 r
F P
0 g
s
.43409 .66378 m .41729 .66434 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.44585 .68231 m .43409 .66378 L .43203 .67362 L .707 .577 .707 r
F
.41729 .66434 m .41651 .68328 L .43011 .68283 L p F P
0 g
s
.43011 .68283 m .44585 .68231 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.43203 .67362 m .41729 .66434 L .43011 .68283 L .707 .577 .707 r
F
.42631 .74708 m .41618 .74963 L p .42373 .71342 L F P
0 g
s
.41618 .74963 m .39235 .75564 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.42339 .2472 m .42504 .52891 L p .4077 .50423 L .707 .577 .707 r
F P
0 g
s
.4557 .60809 m .44954 .56379 L p .42003 .56973 L .707 .577 .707 r
F P
0 g
s
.44954 .56379 m .44899 .55981 L .44718 .56043 L p .707 .577 .707 r
F P
0 g
s
.44718 .56043 m .42003 .56973 L p .44954 .56379 L .707 .577 .707 r
F P
0 g
s
.38846 .57471 m .39518 .62298 L .42372 .61848 L p .707 .577 .707 r
F P
0 g
s
.42372 .61848 m .42674 .61801 L p .42266 .61339 L .707 .577 .707 r
F P
0 g
s
.42266 .61339 m .38846 .57471 L .42372 .61848 L .707 .577 .707 r
F
.39235 .75564 m .36925 .76668 L p .38282 .42309 L F P
0 g
s
.38943 .25576 m .39063 .46038 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.1755 .81102 m .17628 .79208 L .20027 .78947 L p .707 .577 .707 r
F P
0 g
s
.20027 .78947 m .19949 .8084 L .1755 .81102 L p .707 .577 .707 r
F P
0 g
s
.70711 .65935 m .70039 .61107 L .67284 .60523 L p .707 .577 .707 r
F P
0 g
s
.70039 .61107 m .70711 .65935 L .73819 .6598 L p .707 .577 .707 r
F P
0 g
s
.792 .59663 m .79871 .6449 L .82223 .63101 L p .707 .577 .707 r
F P
0 g
s
.82223 .63101 m .81552 .58273 L .792 .59663 L p .707 .577 .707 r
F P
0 g
s
.32003 .79556 m .31925 .8145 L .29178 .81064 L p .707 .577 .707 r
F P
0 g
s
.29178 .81064 m .29256 .7917 L .32003 .79556 L p .707 .577 .707 r
F P
0 g
s
.72772 .71932 m .7285 .70038 L .69734 .69795 L p .707 .577 .707 r
F P
0 g
s
.7285 .70038 m .72772 .71932 L .75952 .72009 L p .707 .577 .707 r
F P
0 g
s
.75952 .72009 m .7603 .70115 L .7285 .70038 L p .707 .577 .707 r
F P
0 g
s
.59258 .24946 m .59551 .74933 L .55674 .74303 L p .707 .577 .707 r
F P
0 g
s
.55674 .74303 m .55382 .24316 L .59258 .24946 L p .707 .577 .707 r
F P
0 g
s
.7603 .70115 m .75952 .72009 L .78885 .71912 L p .707 .577 .707 r
F P
0 g
s
.78885 .71912 m .78963 .70018 L .7603 .70115 L p .707 .577 .707 r
F P
0 g
s
.69734 .69795 m .69656 .71689 L .72772 .71932 L p .707 .577 .707 r
F P
0 g
s
.67956 .65351 m .67284 .60523 L .65151 .59458 L p .707 .577 .707 r
F P
0 g
s
.67284 .60523 m .67956 .65351 L .70711 .65935 L p .707 .577 .707 r
F P
0 g
s
.19949 .8084 m .20027 .78947 L .2296 .7885 L p .707 .577 .707 r
F P
0 g
s
.69656 .71689 m .69734 .69795 L .66987 .69409 L p .707 .577 .707 r
F P
0 g
s
.2296 .7885 m .22882 .80744 L .19949 .8084 L p .707 .577 .707 r
F P
0 g
s
.81552 .58273 m .82223 .63101 L .83801 .61451 L p .707 .577 .707 r
F P
0 g
s
.83801 .61451 m .83129 .56623 L .81552 .58273 L p .707 .577 .707 r
F P
0 g
s
.66987 .69409 m .66909 .71303 L .69656 .71689 L p .707 .577 .707 r
F P
0 g
s
.29256 .7917 m .29178 .81064 L .26062 .80821 L p .707 .577 .707 r
F P
0 g
s
.26062 .80821 m .2614 .78927 L .29256 .7917 L p .707 .577 .707 r
F P
0 g
s
.78963 .70018 m .78885 .71912 L .81284 .71651 L p .707 .577 .707 r
F P
0 g
s
.81284 .71651 m .81362 .69757 L .78963 .70018 L p .707 .577 .707 r
F P
0 g
s
.22882 .80744 m .2296 .7885 L .2614 .78927 L p .707 .577 .707 r
F P
0 g
s
.2614 .78927 m .26062 .80821 L .22882 .80744 L p .707 .577 .707 r
F P
0 g
s
.73543 .76639 m .73386 .73061 L .7027 .72923 L p .707 .577 .707 r
F P
0 g
s
.73386 .73061 m .73543 .76639 L .76723 .7641 L p .707 .577 .707 r
F P
0 g
s
.76723 .7641 m .76566 .72832 L .73386 .73061 L p .707 .577 .707 r
F P
0 g
s
.66909 .71303 m .66987 .69409 L .64878 .68918 L p .707 .577 .707 r
F P
0 g
s
.55382 .24316 m .55674 .74303 L .51273 .74045 L p .707 .577 .707 r
F P
0 g
s
.51273 .74045 m .50981 .24057 L .55382 .24316 L p .707 .577 .707 r
F P
0 g
s
.76566 .72832 m .76723 .7641 L .79656 .75836 L p .707 .577 .707 r
F P
0 g
s
.79656 .75836 m .79499 .72258 L .76566 .72832 L p .707 .577 .707 r
F P
0 g
s
.64878 .68918 m .648 .70812 L .66909 .71303 L p .707 .577 .707 r
F P
0 g
s
.65151 .59458 m .65823 .64285 L .67956 .65351 L p .707 .577 .707 r
F P
0 g
s
.70426 .76501 m .7027 .72923 L .67523 .72432 L p .707 .577 .707 r
F P
0 g
s
.7027 .72923 m .70426 .76501 L .73543 .76639 L p .707 .577 .707 r
F P
0 g
s
.46779 .74184 m .46487 .24197 L .50981 .24057 L p .707 .577 .707 r
F P
0 g
s
.83129 .56623 m .83801 .61451 L .8445 .59701 L p .707 .577 .707 r
F P
0 g
s
.8445 .59701 m .83779 .54873 L .83129 .56623 L p .707 .577 .707 r
F P
0 g
s
.50981 .24057 m .51273 .74045 L .46779 .74184 L p .707 .577 .707 r
F P
0 g
s
.79499 .72258 m .79656 .75836 L .82055 .74974 L p .707 .577 .707 r
F P
0 g
s
.81362 .69757 m .81284 .71651 L .82914 .71251 L p .707 .577 .707 r
F P
0 g
s
.82055 .74974 m .81898 .71396 L .79499 .72258 L p .707 .577 .707 r
F P
0 g
s
.82914 .71251 m .82992 .69357 L .81362 .69757 L p .707 .577 .707 r
F P
0 g
s
.67523 .72432 m .67679 .7601 L .70426 .76501 L p .707 .577 .707 r
F P
0 g
s
.67679 .7601 m .67523 .72432 L .65414 .71635 L p .707 .577 .707 r
F P
0 g
s
.81898 .71396 m .82055 .74974 L .83685 .73908 L p .707 .577 .707 r
F P
0 g
s
.82992 .69357 m .82914 .71251 L .83105 .71115 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83528 .7033 L .83114 .70601 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83114 .70601 L .83073 .73049 L .707 .577 .707 r
F
.83528 .7033 m .83685 .73908 L .84386 .72743 L p F P
0 g
s
.83105 .71115 m .83616 .70751 L p .8313 .69664 L .707 .577 .707 r
F P
0 g
s
.8313 .69664 m .82992 .69357 L .83105 .71115 L .707 .577 .707 r
F
.83114 .70601 m .81898 .71396 L p .83073 .73049 L F P
0 g
s
.83779 .54873 m .8445 .59701 L .84107 .58022 L p .707 .578 .707 r
F P
0 g
s
.84107 .58022 m .83436 .53194 L .83779 .54873 L p .707 .578 .707 r
F P
0 g
s
.65414 .71635 m .65571 .75213 L .67679 .7601 L p .707 .577 .707 r
F P
0 g
s
.84386 .72743 m .84229 .69165 L .83528 .7033 L p .707 .577 .707 r
F P
0 g
s
.83616 .70751 m .83694 .68857 L .82992 .69357 L p .707 .577 .707 r
F P
0 g
s
.65571 .75213 m .65414 .71635 L .64149 .70611 L p .707 .577 .707 r
F P
0 g
s
.63536 .70265 m .63614 .68371 L .63318 .67821 L p .707 .577 .707 r
F P
0 g
s
.63318 .67821 m .6324 .69715 L .63536 .70265 L p .707 .577 .707 r
F P
0 g
s
.63507 .56337 m .64179 .61164 L .64522 .62843 L p .707 .578 .707 r
F P
0 g
s
.64179 .61164 m .63507 .56337 L .64156 .54587 L p .707 .577 .707 r
F P
0 g
s
.64149 .70611 m .64306 .74189 L .65571 .75213 L p .707 .577 .707 r
F P
0 g
s
.83436 .53194 m .84107 .58022 L .82806 .5658 L p .707 .577 .707 r
F P
0 g
s
.82806 .5658 m .82134 .51752 L .83436 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83694 .68857 m .83616 .70751 L .8332 .70201 L p .707 .577 .707 r
F P
0 g
s
.8332 .70201 m .83398 .68307 L .83694 .68857 L p .707 .577 .707 r
F P
0 g
s
.64306 .74189 m .64149 .70611 L .63853 .6946 L p .707 .577 .707 r
F P
0 g
s
.64828 .59414 m .64156 .54587 L .65734 .52936 L p .707 .577 .707 r
F P
0 g
s
.64156 .54587 m .64828 .59414 L .64179 .61164 L p .707 .577 .707 r
F P
0 g
s
.6324 .69715 m .63318 .67821 L .64019 .67321 L p .707 .577 .707 r
F P
0 g
s
.63853 .6946 m .6401 .73038 L .64306 .74189 L p .707 .577 .707 r
F P
0 g
s
.84229 .69165 m .84386 .72743 L .8409 .71591 L p .707 .577 .707 r
F P
0 g
s
.8409 .71591 m .83933 .68014 L .84229 .69165 L p .707 .577 .707 r
F P
0 g
s
.64019 .67321 m .63941 .69215 L .6324 .69715 L p .707 .577 .707 r
F P
0 g
s
.82134 .51752 m .82806 .5658 L .80673 .55514 L p .707 .577 .707 r
F P
0 g
s
.80673 .55514 m .80001 .50687 L .82134 .51752 L p .707 .577 .707 r
F P
0 g
s
.39518 .62298 m .38846 .57471 L .35738 .57425 L p .707 .577 .707 r
F P
0 g
s
.42674 .61801 m .42003 .56973 L .38846 .57471 L p .707 .577 .707 r
F P
0 g
s
.42003 .56973 m .42674 .61801 L .4557 .60809 L p .707 .577 .707 r
F P
0 g
s
.3641 .62253 m .35738 .57425 L .32983 .56841 L p .707 .577 .707 r
F P
0 g
s
.35738 .57425 m .3641 .62253 L .39518 .62298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63941 .69215 m .64019 .67321 L .64354 .67239 L p .707 .577 .707 r
F P
0 g
s
.64354 .67239 m .65649 .66921 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .63853 .6946 L .64377 .6859 L p .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .64377 .6859 L .64395 .69685 L .707 .577 .707 r
F
.63941 .69215 m .64354 .67239 L .64377 .68629 L F
.65649 .66921 m .65571 .68815 L .64385 .69106 L p F P
0 g
s
.64385 .69106 m .63941 .69215 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.64377 .68629 m .65649 .66921 L .64385 .69106 L .707 .577 .707 r
F
.64555 .68294 m .64712 .71872 L .64439 .72324 L p F P
0 g
s
.64439 .72324 m .6401 .73038 L p .64395 .69685 L .707 .577 .707 r
F P
0 g
s
.64395 .69685 m .64555 .68294 L .64439 .72324 L .707 .577 .707 r
F
.64377 .6859 m .64555 .68294 L p .64395 .69685 L F P
0 g
s
.44899 .55981 m .4557 .60809 L .47922 .59419 L p .707 .577 .707 r
F P
0 g
s
.47922 .59419 m .47251 .54592 L .44899 .55981 L p .707 .577 .707 r
F P
0 g
s
.83398 .68307 m .8332 .70201 L .82055 .69654 L p .707 .577 .707 r
F P
0 g
s
.82055 .69654 m .82133 .6776 L .83398 .68307 L p .707 .577 .707 r
F P
0 g
s
.65734 .52936 m .66406 .57764 L .64828 .59414 L p .707 .577 .707 r
F P
0 g
s
.66406 .57764 m .65734 .52936 L .68086 .51547 L p .707 .577 .707 r
F P
0 g
s
.80001 .50687 m .80673 .55514 L .77918 .5493 L p .707 .577 .707 r
F P
0 g
s
.77918 .5493 m .77246 .50103 L .80001 .50687 L p .707 .577 .707 r
F P
0 g
s
.38471 .68251 m .38549 .66357 L .35433 .66113 L p .707 .577 .707 r
F P
0 g
s
.38549 .66357 m .38471 .68251 L .41651 .68328 L p .707 .577 .707 r
F P
0 g
s
.41651 .68328 m .41729 .66434 L .38549 .66357 L p .707 .577 .707 r
F P
0 g
s
.35433 .66113 m .35355 .68007 L .38471 .68251 L p .707 .577 .707 r
F P
0 g
s
.33655 .61669 m .32983 .56841 L .3085 .55776 L p .707 .577 .707 r
F P
0 g
s
.32983 .56841 m .33655 .61669 L .3641 .62253 L p .707 .577 .707 r
F P
0 g
s
.35355 .68007 m .35433 .66113 L .32686 .65727 L p .707 .577 .707 r
F P
0 g
s
.83933 .68014 m .8409 .71591 L .82826 .70567 L p .707 .577 .707 r
F P
0 g
s
.82826 .70567 m .82669 .66989 L .83933 .68014 L p .707 .577 .707 r
F P
0 g
s
.47251 .54592 m .47922 .59419 L .495 .57769 L p .707 .577 .707 r
F P
0 g
s
.495 .57769 m .48828 .52941 L .47251 .54592 L p .707 .577 .707 r
F P
0 g
s
.32686 .65727 m .32608 .67621 L .35355 .68007 L p .707 .577 .707 r
F P
0 g
s
.68758 .56375 m .68086 .51547 L .70982 .50555 L p .707 .577 .707 r
F P
0 g
s
.68086 .51547 m .68758 .56375 L .66406 .57764 L p .707 .577 .707 r
F P
0 g
s
.77246 .50103 m .77918 .5493 L .7481 .54885 L p .707 .577 .707 r
F P
0 g
s
.7481 .54885 m .74138 .50057 L .77246 .50103 L p .707 .577 .707 r
F P
0 g
s
.44662 .66337 m .44585 .68231 L .46983 .6797 L p .707 .577 .707 r
F P
0 g
s
.46983 .6797 m .47061 .66076 L .44662 .66337 L p .707 .577 .707 r
F P
0 g
s
.71654 .55383 m .70982 .50555 L .74138 .50057 L p .707 .577 .707 r
F P
0 g
s
.70982 .50555 m .71654 .55383 L .68758 .56375 L p .707 .577 .707 r
F P
0 g
s
.65571 .68815 m .65649 .66921 L .68048 .6666 L p .707 .577 .707 r
F P
0 g
s
.68048 .6666 m .6797 .68553 L .65571 .68815 L p .707 .577 .707 r
F P
0 g
s
.64712 .71872 m .64555 .68294 L .66184 .67228 L p .707 .577 .707 r
F P
0 g
s
.74138 .50057 m .7481 .54885 L .71654 .55383 L p .707 .577 .707 r
F P
0 g
s
.39242 .72957 m .39085 .6938 L .35969 .69242 L p .707 .577 .707 r
F P
0 g
s
.39085 .6938 m .39242 .72957 L .42422 .72728 L p .707 .577 .707 r
F P
0 g
s
.42422 .72728 m .42265 .69151 L .39085 .6938 L p .707 .577 .707 r
F P
0 g
s
.32608 .67621 m .32686 .65727 L .30577 .65237 L p .707 .577 .707 r
F P
0 g
s
.82133 .6776 m .82055 .69654 L .79947 .69163 L p .707 .577 .707 r
F P
0 g
s
.79947 .69163 m .80025 .67269 L .82133 .6776 L p .707 .577 .707 r
F P
0 g
s
.42265 .69151 m .42422 .72728 L .45355 .72155 L p .707 .577 .707 r
F P
0 g
s
.45355 .72155 m .45198 .68577 L .42265 .69151 L p .707 .577 .707 r
F P
0 g
s
.30577 .65237 m .30499 .67131 L .32608 .67621 L p .707 .577 .707 r
F P
0 g
s
.31522 .60604 m .3085 .55776 L .29549 .54334 L p .707 .577 .707 r
F P
0 g
s
.3085 .55776 m .31522 .60604 L .33655 .61669 L p .707 .577 .707 r
F P
0 g
s
.36125 .7282 m .35969 .69242 L .33222 .6875 L p .707 .577 .707 r
F P
0 g
s
.35969 .69242 m .36125 .7282 L .39242 .72957 L p .707 .577 .707 r
F P
0 g
s
.48828 .52941 m .495 .57769 L .50149 .56019 L p .707 .577 .707 r
F P
0 g
s
.50149 .56019 m .49478 .51191 L .48828 .52941 L p .707 .577 .707 r
F P
0 g
s
.82669 .66989 m .82826 .70567 L .80717 .69771 L p .707 .577 .707 r
F P
0 g
s
.80717 .69771 m .8056 .66193 L .82669 .66989 L p .707 .577 .707 r
F P
0 g
s
.66184 .67228 m .66341 .70806 L .64712 .71872 L p .707 .577 .707 r
F P
0 g
s
.45198 .68577 m .45355 .72155 L .47754 .71293 L p .707 .577 .707 r
F P
0 g
s
.47061 .66076 m .46983 .6797 L .48613 .6757 L p .707 .577 .707 r
F P
0 g
s
.47754 .71293 m .47597 .67715 L .45198 .68577 L p .707 .577 .707 r
F P
0 g
s
.48613 .6757 m .48691 .65676 L .47061 .66076 L p .707 .577 .707 r
F P
0 g
s
.33222 .6875 m .33378 .72328 L .36125 .7282 L p .707 .577 .707 r
F P
0 g
s
.33378 .72328 m .33222 .6875 L .31113 .67954 L p .707 .577 .707 r
F P
0 g
s
.30499 .67131 m .30577 .65237 L .29313 .64689 L p .707 .577 .707 r
F P
0 g
s
.80025 .67269 m .79947 .69163 L .772 .68777 L p .707 .577 .707 r
F P
0 g
s
.772 .68777 m .77278 .66883 L .80025 .67269 L p .707 .577 .707 r
F P
0 g
s
.6797 .68553 m .68048 .6666 L .70981 .66563 L p .707 .577 .707 r
F P
0 g
s
.66341 .70806 m .66184 .67228 L .68583 .66366 L p .707 .577 .707 r
F P
0 g
s
.29313 .64689 m .29235 .66583 L .30499 .67131 L p .707 .577 .707 r
F P
0 g
s
.30221 .59161 m .29549 .54334 L .29206 .52655 L p .707 .578 .707 r
F P
0 g
s
.29549 .54334 m .30221 .59161 L .31522 .60604 L p .707 .577 .707 r
F P
0 g
s
.47597 .67715 m .47754 .71293 L .49384 .70227 L p .707 .577 .707 r
F P
0 g
s
.48691 .65676 m .48613 .6757 L .48804 .67433 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .49227 .66649 L .48813 .6692 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .48813 .6692 L .48772 .69367 L .707 .577 .707 r
F
.49227 .66649 m .49384 .70227 L .50085 .69061 L p F P
0 g
s
.48804 .67433 m .49315 .6707 L p .48829 .65983 L .707 .577 .707 r
F P
0 g
s
.48829 .65983 m .48691 .65676 L .48804 .67433 L .707 .577 .707 r
F
.48813 .6692 m .47597 .67715 L p .48772 .69367 L F P
0 g
s
.70981 .66563 m .70903 .68457 L .6797 .68553 L p .707 .577 .707 r
F P
0 g
s
.8056 .66193 m .80717 .69771 L .7797 .69279 L p .707 .577 .707 r
F P
0 g
s
.7797 .69279 m .77813 .65701 L .8056 .66193 L p .707 .577 .707 r
F P
0 g
s
.49478 .51191 m .50149 .56019 L .49806 .54341 L p .707 .578 .707 r
F P
0 g
s
.49806 .54341 m .49135 .49513 L .49478 .51191 L p .707 .578 .707 r
F P
0 g
s
.31113 .67954 m .3127 .71531 L .33378 .72328 L p .707 .577 .707 r
F P
0 g
s
.68583 .66366 m .6874 .69944 L .66341 .70806 L p .707 .577 .707 r
F P
0 g
s
.77278 .66883 m .772 .68777 L .74084 .68534 L p .707 .577 .707 r
F P
0 g
s
.74084 .68534 m .74162 .6664 L .77278 .66883 L p .707 .577 .707 r
F P
0 g
s
.50085 .69061 m .49928 .65483 L .49227 .66649 L p .707 .577 .707 r
F P
0 g
s
.49315 .6707 m .49393 .65176 L .48691 .65676 L p .707 .577 .707 r
F P
0 g
s
.70903 .68457 m .70981 .66563 L .74162 .6664 L p .707 .577 .707 r
F P
0 g
s
.6874 .69944 m .68583 .66366 L .71517 .65792 L p .707 .577 .707 r
F P
0 g
s
.3127 .71531 m .31113 .67954 L .29848 .66929 L p .707 .577 .707 r
F P
0 g
s
.74162 .6664 m .74084 .68534 L .70903 .68457 L p .707 .577 .707 r
F P
0 g
s
.77813 .65701 m .7797 .69279 L .74854 .69141 L p .707 .577 .707 r
F P
0 g
s
.74854 .69141 m .74697 .65563 L .77813 .65701 L p .707 .577 .707 r
F P
0 g
s
.29235 .66583 m .29313 .64689 L .29017 .64139 L p .707 .577 .707 r
F P
0 g
s
.71673 .6937 m .71517 .65792 L .74697 .65563 L p .707 .577 .707 r
F P
0 g
s
.71517 .65792 m .71673 .6937 L .6874 .69944 L p .707 .577 .707 r
F P
0 g
s
.29017 .64139 m .28939 .66033 L .29235 .66583 L p .707 .577 .707 r
F P
0 g
s
.29206 .52655 m .29878 .57483 L .30221 .59161 L p .707 .578 .707 r
F P
0 g
s
.29878 .57483 m .29206 .52655 L .29855 .50905 L p .707 .577 .707 r
F P
0 g
s
.74697 .65563 m .74854 .69141 L .71673 .6937 L p .707 .577 .707 r
F P
0 g
s
.29848 .66929 m .30005 .70507 L .3127 .71531 L p .707 .577 .707 r
F P
0 g
s
.49135 .49513 m .49806 .54341 L .48505 .52898 L p .707 .577 .707 r
F P
0 g
s
.48505 .52898 m .47833 .4807 L .49135 .49513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49393 .65176 m .49315 .6707 L .49019 .66519 L p .707 .577 .707 r
F P
0 g
s
.49019 .66519 m .49097 .64625 L .49393 .65176 L p .707 .577 .707 r
F P
0 g
s
.30005 .70507 m .29848 .66929 L .29552 .65778 L p .707 .577 .707 r
F P
0 g
s
.30527 .55733 m .29855 .50905 L .31433 .49255 L p .707 .577 .707 r
F P
0 g
s
.29855 .50905 m .30527 .55733 L .29878 .57483 L p .707 .577 .707 r
F P
0 g
s
.28939 .66033 m .29017 .64139 L .29718 .63639 L p .707 .577 .707 r
F P
0 g
s
.29552 .65778 m .29709 .69356 L .30005 .70507 L p .707 .577 .707 r
F P
0 g
s
.49928 .65483 m .50085 .69061 L .49789 .6791 L p .707 .577 .707 r
F P
0 g
s
.49789 .6791 m .49632 .64332 L .49928 .65483 L p .707 .577 .707 r
F P
0 g
s
.29718 .63639 m .2964 .65533 L .28939 .66033 L p .707 .577 .707 r
F P
0 g
s
.47833 .4807 m .48505 .52898 L .46372 .51833 L p .707 .577 .707 r
F P
0 g
s
.46372 .51833 m .457 .47005 L .47833 .4807 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2964 .65533 m .29718 .63639 L .30053 .63557 L p .707 .577 .707 r
F P
0 g
s
.30053 .63557 m .31348 .63239 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .29552 .65778 L .30076 .64908 L p .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .30076 .64908 L .30094 .66004 L .707 .577 .707 r
F
.2964 .65533 m .30053 .63557 L .30076 .64948 L F
.31348 .63239 m .3127 .65133 L .30084 .65424 L p F P
0 g
s
.30084 .65424 m .2964 .65533 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.30076 .64948 m .31348 .63239 L .30084 .65424 L .707 .577 .707 r
F
.30254 .64613 m .3041 .6819 L .30138 .68643 L p F P
0 g
s
.30138 .68643 m .29709 .69356 L p .30094 .66004 L .707 .577 .707 r
F P
0 g
s
.30094 .66004 m .30254 .64613 L .30138 .68643 L .707 .577 .707 r
F
.30076 .64908 m .30254 .64613 L p .30094 .66004 L F P
0 g
s
.49097 .64625 m .49019 .66519 L .47754 .65972 L p .707 .577 .707 r
F P
0 g
s
.47754 .65972 m .47832 .64078 L .49097 .64625 L p .707 .577 .707 r
F P
0 g
s
.31433 .49255 m .32105 .54082 L .30527 .55733 L p .707 .577 .707 r
F P
0 g
s
.32105 .54082 m .31433 .49255 L .33785 .47865 L p .707 .577 .707 r
F P
0 g
s
.457 .47005 m .46372 .51833 L .43617 .51249 L p .707 .577 .707 r
F P
0 g
s
.43617 .51249 m .42945 .46421 L .457 .47005 L p .707 .577 .707 r
F P
0 g
s
.49632 .64332 m .49789 .6791 L .48525 .66886 L p .707 .577 .707 r
F P
0 g
s
.48525 .66886 m .48368 .63308 L .49632 .64332 L p .707 .577 .707 r
F P
0 g
s
.34457 .52693 m .33785 .47865 L .36681 .46873 L p .707 .577 .707 r
F P
0 g
s
.33785 .47865 m .34457 .52693 L .32105 .54082 L p .707 .577 .707 r
F P
0 g
s
.42945 .46421 m .43617 .51249 L .40509 .51203 L p .707 .577 .707 r
F P
0 g
s
.40509 .51203 m .39837 .46376 L .42945 .46421 L p .707 .577 .707 r
F P
0 g
s
.37353 .51701 m .36681 .46873 L .39837 .46376 L p .707 .577 .707 r
F P
0 g
s
.36681 .46873 m .37353 .51701 L .34457 .52693 L p .707 .577 .707 r
F P
0 g
s
.3127 .65133 m .31348 .63239 L .33747 .62978 L p .707 .577 .707 r
F P
0 g
s
.33747 .62978 m .33669 .64872 L .3127 .65133 L p .707 .577 .707 r
F P
0 g
s
.3041 .6819 m .30254 .64613 L .31883 .63546 L p .707 .577 .707 r
F P
0 g
s
.39837 .46376 m .40509 .51203 L .37353 .51701 L p .707 .577 .707 r
F P
0 g
s
.47832 .64078 m .47754 .65972 L .45646 .65481 L p .707 .577 .707 r
F P
0 g
s
.45646 .65481 m .45724 .63587 L .47832 .64078 L p .707 .577 .707 r
F P
0 g
s
.48368 .63308 m .48525 .66886 L .46416 .66089 L p .707 .577 .707 r
F P
0 g
s
.46416 .66089 m .46259 .62511 L .48368 .63308 L p .707 .577 .707 r
F P
0 g
s
.31883 .63546 m .3204 .67124 L .3041 .6819 L p .707 .577 .707 r
F P
0 g
s
.45724 .63587 m .45646 .65481 L .42899 .65096 L p .707 .577 .707 r
F P
0 g
s
.42899 .65096 m .42977 .63202 L .45724 .63587 L p .707 .577 .707 r
F P
0 g
s
.33669 .64872 m .33747 .62978 L .3668 .62881 L p .707 .577 .707 r
F P
0 g
s
.3204 .67124 m .31883 .63546 L .34282 .62684 L p .707 .577 .707 r
F P
0 g
s
.3668 .62881 m .36602 .64775 L .33669 .64872 L p .707 .577 .707 r
F P
0 g
s
.46259 .62511 m .46416 .66089 L .43669 .65598 L p .707 .577 .707 r
F P
0 g
s
.43669 .65598 m .43512 .6202 L .46259 .62511 L p .707 .577 .707 r
F P
0 g
s
.34282 .62684 m .34439 .66262 L .3204 .67124 L p .707 .577 .707 r
F P
0 g
s
.42977 .63202 m .42899 .65096 L .39783 .64852 L p .707 .577 .707 r
F P
0 g
s
.39783 .64852 m .39861 .62958 L .42977 .63202 L p .707 .577 .707 r
F P
0 g
s
.36602 .64775 m .3668 .62881 L .39861 .62958 L p .707 .577 .707 r
F P
0 g
s
.34439 .66262 m .34282 .62684 L .37215 .62111 L p .707 .577 .707 r
F P
0 g
s
.39861 .62958 m .39783 .64852 L .36602 .64775 L p .707 .577 .707 r
F P
0 g
s
.43512 .6202 m .43669 .65598 L .40553 .6546 L p .707 .577 .707 r
F P
0 g
s
.40553 .6546 m .40396 .61882 L .43512 .6202 L p .707 .577 .707 r
F P
0 g
s
.37372 .65689 m .37215 .62111 L .40396 .61882 L p .707 .577 .707 r
F P
0 g
s
.37215 .62111 m .37372 .65689 L .34439 .66262 L p .707 .577 .707 r
F P
0 g
s
.40396 .61882 m .40553 .6546 L .37372 .65689 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00O7oo1P000UYF00<005YFFUH02EYF00<005YFFUH015YF2@00OGoo001fOol60008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1U
Ool006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF20000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP000UYF10000UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH000030006
FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00H7oo0P001UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00FWoo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00F7oo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EWoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Ioo`l0
041oo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00011oo`H000AJEP03001JEUYF00IJEP03
001JEP0000<003aoo`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Uoo`00E7oo00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00D005YF
FUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
00002goo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=goo001DOol0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH20003FUH40002
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00009Ool20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02000eOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD0
009JEP03001JEUYF00IJEP8000MJEP<000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000Moo`<000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01@001UYF00<005YFFUH01UYF0P002UYF0P000eYF00@005YFFUH000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF0`0000Eoo`00FUIJEP0000IJEP03
001JEUYF00IJEP8000YJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00@007ooOomoo`8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00035oo`00Dgoo
00<005YF00001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
1000FUIJEUYF0P000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000Woo00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@0
05YFFUH000Moo`03001JEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF009JEP80009JEP05
001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000Ool00000
1eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002moo`00Dgoo00<005YF00001EYF0`0027oo00<005YF00001UYF00<005YFFUH0
1UYF0P002UYF00H005YFFUIJEP00FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
0`00FUH00005FUH00`00Oomoo`08Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH02000FUIJ
EUYF001JEP00FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00004FUH00`00Oomoo`09
Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH01000FUIJEP000eYF00<005YF00000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF008002ioo`00Dgoo00@005YFFUH0009JEP03001oogoo00Yoo`03001JEP0000IJEP03
001JEUYF00IJEP8000YJEP03001JEP0000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000^Ool005=oo`06001JEUYF001JEP003Goo00<005YF00001UYF00<005YFFUH01UYF0P002UYF
0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`9JEP8000ioo`03001JEP0000IJEP03001J
EUYF00IJEP8000QJEP80009JEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
1P004Goo1@001EYF00@005YFFUH002ioo`00E7oo0UYF0P003Woo00<005YF00001UYF00<005YFFUH0
1UYF0P001UYF0P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000L
Ool20003FUH01000FUIJEP00;Woo001DOol2FUH4000<Ool00`00FUH00006FUH30006FUH20004FUH2
0007FUH01@00FUIJEUYF00000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYF0002FUH01@00FUIJEUYF00001eYF00<005YF00000P0087oo0P0000EJEP00FUIJEP0002io
o`00E7oo00AJEP00FUH0009JEP8000Yoo`03001JEP0000EJEPD000EJEP80009JEP800003FUH005YF
00IJEP05001JEUYFFUH00002FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUH0009JEP05001JEUYFFUH00007FUH2000UOol20002FUH2000]Ool005Aoo`04FUH005YF0004
FUH30007Ool00`00FUH00005FUH50005FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH00UYF0P00:Goo00@005YF000002eoo`00E7oo0P000UYF00<005YFFUH00UYF00<0
05YF00000`000goo00<005YF00001EYF2`001UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009J
EP03001JEUYF008002Yoo`<00003FUH007oo02aoo`00E7oo0P000UYF00<005YFFUH00UYF00<005YF
FUH00eYF400015YF00<005YFFUH01EYF0P001UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP<002Yo
o`800005FUH00000FUH0000]Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
15YF00<007ooOol0:Goo00H005YFFUIJEP00FUH2000]Ool005Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0UYF00@005YFFUH002]oo`03001JEUYF00=JEP03001JEP0002eoo`00EGoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUH0000ZOol30005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP8002Yoo`04001J
EUYF0005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001oogoo02Moo`8000=J
EP03001JEUYF00=JEP04001JEUYF000/Ool005Ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH20009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P005goo0`0037oo0P001UYF00<005YF
FUH00UYF00@005YFFUH002aoo`00B7oo3@000Woo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0057oo1@0027oo0`0000=J
EP00FUH01EYF00<005YFFUH00UYF00@005YFFUH002aoo`00A7oo10000UYF00<005YFFUH01UYF00<0
05YF0000100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000UYF0P004Woo1@001Goo0`0015YF00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo0010Ool4
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF1@003Goo2P001eYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo000nOol200000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00@005YFFUIJEQ4000AJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00>goo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH2000015YF000000001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00
>7oo0`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000IJ
EP03001JEUYF00AJEPd000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool0
03Ioo`800003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPD0009JEPL000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF000`Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP00Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF0000<Goo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000bOol0035oo`8000IJEP03001JEUYF
00IJEP04001JEUYFFUHA00000eYF0000000600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`0aOol0031oo`03001J
EP0000IJEP03001JEUYF009JEPP000EJEP8000MJEP@00004FUH000000005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8003Ao
o`00;goo00@005YFFUH000MJEP@000AJEP03001JEUYF00IJEP8000IJEP8000AJEP8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF000f
Ool002ioo`05001JEUYFFUH00005FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH400000goo001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH3000gOol002eoo`03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8003Uoo`00;Goo00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YF
FUH01eYF1`0000AJEP00000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH400000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000kOol002aoo`03001JEUYF00=JEP80
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00=JEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P00?Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF10002EYF00<005YF
FUH00eYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00AJEQP000=JEP03001JEUYF
00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP02FUH600000eYF001JEP06FUH?000nOol002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUH000020003FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30000
0eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40005FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P001EYF00<005YFFUH00UYF0P000goo2@0015YF00<005YFFUH01UYF00<005YF
00000`00>Woo000/Ool01000FUH000000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH00UYF8P000UYF0P000eYF00D005YFFUIJEP00
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Moo`00
;7oo00@005YF000000=JEP03001JEUYF009JEP<000QJEP03001JEUYF009JEPT0009JEP800003FUH0
05YF00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<00003FUH005YF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002000dOol002aoo`04001JEP000003FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF2@002Goo100000=JEP00FUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P000eYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEPX0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo00@005YFFUH000AJEP<0
00=JEPD001Eoo`03001JEP00009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<Goo000/Ool0
1000FUIJEP0015YF00@005YFFUIJEP8001Yoo`03001JEP000080009oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP@0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`04001JEUYF0003FUH200000eYF0000000LOol01000FUH005YF0P001Woo2@0015YF00<005YF
00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP04001JEP000002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000UYF00@005YF000001ioo`06001J
EUYFFUH005YF0`0000=oo`0000000eYF00D005YFFUH005YF01`000=JEP06001JEUYFFUH005YF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF001JEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool01000FUH005YF0`0087oo0P000UYF00<005YF
FUH00UYF1P0000IJEP00000005YF0005FUH50006FUH01000FUIJEUYF1@001EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`03001JEP000080029oo`80009JEP03
001JEUYF00=JEP04001JEUYFFUH90003FUH500000eYF000000070003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUH005YF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01000FUH005YF0`0087oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF20002Goo200015YF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool3000015YF001JEUYF0P007Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF2@005Woo1P0015YF00<005YFFUH0
0P00;Goo000]Ool20002FUH00`00FUIJEP02FUH5000HOol30002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001JEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF6@000eYF0`0000=JEP00
FUH00UYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP07FUHI00001EYF001JEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P000eYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP0D
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00Oomoo`0[
Ool002eoo`80009JEP03001JEUYF01AJEP03001JEUYF00IJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000UYF2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF0000
05YF00@002eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF1000
1Woo2@0015YF00<005YFFUH00`000eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEP00
02eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00X005YFFUIJEP00FUH005YF001JEP<0009o
o`03001JEUYF0080009JEP800003Ool0000001/00003FUH005YF00=JEP03001JEP0002eoo`00;Woo
00@005YFFUH001IJEP<000IJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00UYF0`0000EJEP00001JEP00
009JEP03001oogoo00Eoo`D000]oo`<000EJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@0
05YFFUH001EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUH0000300000eYF000000020006Ool5
0007Ool400000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000]Ool002ioo`04001JEUYF000E
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00Oomoo`0@0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH00eYF5`001EYF00<005YFFUH015YF00D005YFFUIooeYF0080
02ioo`00;goo00<005YF00005EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001Goo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUIo
o`02000^Ool0031oo`03001JEP0000AJEP03001JEUYF00iJEP<000IJEP03001JEUYF00IJEP03001J
EUYF008000Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000;goo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUHF
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YFFUIJEP0002moo`00<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P002goo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01P00
2UYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF000`Ool003=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF009JEP8000eoo`03001JEP0000IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
035oo`00=Goo0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
3goo00<005YF00001UYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000cOol003Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP@0019oo`03001JEP0000IJEP@00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00003000eOol003aoo`T000AJEP03001JEUYF00@001Ioo`03001JEP00
00AJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP@000EJEP06001JEUYFFUH005YF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`00>Goo0015Ool7000JOol00`00FUH00002FUH20007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00
FUIJEUYF000015YF00D005YFFUIJEP0000=JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@003aoo`00IWoo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
00D005YFFUIJEP0000MJEQX0041oo`00IWoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF00000eYF00<005YFFUH015YF00<007ooOol0F7oo0018Ool3000KOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP02FUH2001KOol004Moo`D001Yoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYF001MOol004Moo`D001Yo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP<005ioo`00Agoo1@006Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000eYF0P00H7oo0018Ool3000KOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF00000000HWoo000fOolI000HOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001UOol0031oo`H0009JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP0011oo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001oogoo06Eoo`00;Goo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]oo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP8006Moo`00:goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002Goo0`001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Uoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000006]oo`00:goo00<0
05YF00000eYF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00Uoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP@006eoo`00:goo00<005YF00000UYF1@006Goo200015YF00<005YFFUH00eYF00@0
05YFFUIJEP8000Yoo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00H0071oo`00:goo00<005YF00000P0000AJEP000000029oo`L000=JEP04001J
EUYFFUH2000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool5
001_Ool002]oo`80009JEP03001JEUYF009JEPD002Aoo`@000=JEP8001Aoo``000IJEP03001JEUYF
00YJEP03001JEUYF00H000Moo`D006moo`00:goo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
01Uoo`P00003FUH00000021ooaH000eoo`D006moo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF009JEQT000=JEP03001JEUYF009JEP<0035ooaT006eoo`00;Goo0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00:goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000IGoo
000_Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000XOol30002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00Ggoo000bOol70004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000XOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002001LOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH6000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001IOol0049ooaT0035oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP00008005Ioo`00S7oo00<005YF000015YF00@005YFFUIJEQl0
00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP00009JEPH001moo`@0009J
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP0000<0009JEPL001moo`D000=J
EP03001JEUYF008005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT001Uoo`H0009J
EP8005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF
00<005YFFUH01000EWoo002=Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002?Ool4
0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0005Ioo`00Tgoo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8005Moo`00UWoo1@000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000005Uo
o`00Vgoo4@0015YF00<005YFFUH00UYF3@00Fgoo002/Ool9001XOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59427 .74824 m .58418 .74809 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.58418 .74809 m .56319 .74779 L p .57475 .76269 L .707 .577 .707 r
F P
0 g
s
.5845 .77527 m .58418 .74809 L .57475 .76269 L .707 .577 .707 r
F
.55235 .74549 m .53564 .74195 L p .54569 .75782 L F P
0 g
s
.53564 .74195 m .51431 .73129 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53869 .77078 m .53865 .76901 L .53751 .7685 L .707 .577 .707 r
F
.53959 .77252 m .53945 .76936 L p .53869 .77078 L F P
0 g
s
.53945 .76936 m .53564 .74195 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .56706 .77744 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53959 .77252 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .56991 .79606 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53564 .74195 m .53945 .76936 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .54235 .79022 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .55235 .74549 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.55492 .7724 m .55235 .74549 L .54569 .75782 L .707 .577 .707 r
F
.56694 .77476 m .56319 .74779 L p .55492 .7724 L F P
0 g
s
.53802 .73674 m .53945 .76936 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53802 .73674 L p .53869 .77078 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .53751 .7685 L .5183 .75998 L .707 .577 .707 r
F
.52001 .76512 m .53959 .77252 L p .5183 .75998 L F P
0 g
s
.52103 .77957 m .54235 .79022 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.51431 .73129 m .5183 .75998 L p .5219 .74725 L .707 .577 .707 r
F P
0 g
s
.51334 .75513 m .5183 .75998 L .5013 .71687 L .707 .577 .707 r
F
.51772 .76203 m .51766 .75935 L .51657 .75829 L F
.5185 .76455 m .5183 .75998 L p .51772 .76203 L F P
0 g
s
.5183 .75998 m .51431 .73129 L .50558 .72162 L p .707 .577 .707 r
F P
0 g
s
.50558 .72162 m .5013 .71687 L p .5183 .75998 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .51693 .72878 L p .51772 .76203 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .5185 .76455 L .52001 .76512 L p .707 .577 .707 r
F P
0 g
s
.5185 .76455 m .51657 .75829 L .50556 .74754 L .707 .577 .707 r
F
.50672 .75501 m .5185 .76455 L p .50556 .74754 L F P
0 g
s
.50801 .76514 m .52103 .77957 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.5013 .71687 m .50556 .74754 L p .50568 .73079 L .707 .577 .707 r
F P
0 g
s
.50449 .74258 m .50556 .74754 L .49787 .70008 L .707 .578 .707 r
F
.50554 .75097 m .50537 .74666 L .50493 .74461 L .707 .577 .707 r
F
.50586 .75431 m .50556 .74754 L p .50554 .75097 L F P
0 g
s
.50556 .74754 m .5013 .71687 L .49934 .70732 L p .707 .578 .707 r
F P
0 g
s
.49934 .70732 m .49787 .70008 L p .50556 .74754 L .707 .578 .707 r
F P
0 g
s
.50556 .74754 m .50429 .71853 L p .50554 .75097 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50586 .75431 L .50672 .75501 L p .707 .577 .707 r
F P
0 g
s
.50586 .75431 m .50493 .74461 L .50248 .73325 L .707 .577 .707 r
F
.503 .74318 m .50586 .75431 L p .50248 .73325 L F P
0 g
s
.50458 .74836 m .50801 .76514 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.50449 .74258 m .49897 .70714 L .50248 .73325 L .707 .578 .707 r
F
.50248 .73325 m .50458 .74836 L p .50449 .74258 L F P
0 g
s
.50133 .70702 m .50248 .73325 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50429 .71853 m .50133 .70702 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50537 .74666 m .50429 .71853 L .50493 .74461 L .707 .577 .707 r
F
.51334 .75513 m .50568 .73079 L .50556 .74754 L F
.50429 .71853 m .50556 .74754 L p .51657 .75829 L F P
0 g
s
.51693 .72878 m .50429 .71853 L p .51657 .75829 L .707 .577 .707 r
F P
0 g
s
.50133 .70702 m .50776 .69633 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50661 .68023 m .52014 .66608 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50776 .69633 m .50834 .69537 L p .50794 .69884 L .707 .577 .707 r
F P
0 g
s
.50449 .72895 m .50776 .69633 L .50794 .69884 L .707 .577 .707 r
F
.51327 .7152 m .50936 .71852 L .52014 .66608 L F
.5105 .72929 m .50936 .71852 L .5156 .71321 L F
.50801 .76514 m .50556 .74754 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.51076 .73172 m .50458 .74836 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .50936 .71852 L p .5105 .72929 L .707 .577 .707 r
F P
0 g
s
.50458 .74836 m .50452 .72889 L .50936 .71852 L .707 .577 .707 r
F
.50458 .74836 m .50248 .73325 L p .50452 .72889 L F P
0 g
s
.50248 .73325 m .5029 .7428 L .503 .74318 L p .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .5029 .7428 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .50936 .71852 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50991 .73114 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50436 .68258 m .50936 .71852 L p .50452 .72889 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .50991 .73114 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52621 .72048 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .54366 .65219 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .52552 .70478 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.52685 .71435 m .52552 .70478 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52014 .66608 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .57262 .64227 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.55074 .69302 m .54366 .65219 L .5535 .69227 L .707 .577 .707 r
F
.57262 .64227 m .60418 .63729 L p .58189 .68507 L F P
0 g
s
.58006 .68528 m .57262 .64227 L .58189 .68507 L .707 .577 .707 r
F
.60418 .63729 m .63526 .63774 L p .61281 .68181 L F P
0 g
s
.61159 .68178 m .60418 .63729 L .61281 .68181 L .707 .577 .707 r
F
.63526 .63774 m .66281 .64358 L p .64345 .68302 L F P
0 g
s
.64252 .68283 m .63526 .63774 L .64345 .68302 L .707 .577 .707 r
F
.66281 .64358 m .68414 .65424 L p .67071 .6888 L F P
0 g
s
.68414 .65424 m .69715 .66866 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70319 .7301 m .70445 .71285 L .69807 .71573 L .707 .577 .707 r
F
.70509 .70407 m .7036 .70655 L p .70445 .71285 L F P
0 g
s
.7036 .70655 m .69807 .71573 L p .70445 .71285 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70509 .70407 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70058 .68545 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70058 .68545 m .69409 .70295 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .67831 .71945 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69909 .73888 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.70081 .75122 m .70657 .73569 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70635 .73151 m .70452 .72725 L .70657 .73569 L .707 .577 .707 r
F
.69807 .71573 m .69909 .73888 L p .70319 .7301 L F P
0 g
s
.69807 .71573 m .69673 .71661 L p .69722 .72128 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .69909 .73888 L p .69567 .70663 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69409 .70295 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69964 .75151 L .69996 .75098 L p .707 .577 .707 r
F P
0 g
s
.68334 .76217 m .68499 .76109 L p .68467 .75979 L .707 .577 .707 r
F P
0 g
s
.68293 .75262 m .68334 .76217 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.67505 .75638 m .68293 .75262 L .6647 .74013 L .707 .577 .707 r
F
.66387 .74366 m .6647 .74013 L .65479 .73334 L F
.67505 .75638 m .6647 .74013 L .66387 .74366 L F
.67528 .72124 m .65479 .73334 L p .68293 .75262 L F P
0 g
s
.64525 .73661 m .62583 .74326 L p .63707 .75535 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .59427 .74824 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.6285 .77499 m .62849 .77211 L .62592 .77241 L .707 .577 .707 r
F
.63002 .77652 m .62982 .77195 L p .6285 .77499 L F P
0 g
s
.62982 .77195 m .62583 .74326 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63002 .77652 m .65936 .77079 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63002 .77652 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .66151 .78162 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .62982 .77195 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63255 .79154 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .64525 .73661 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.64794 .76703 m .64525 .73661 L .63707 .75535 L .707 .577 .707 r
F
.65906 .76401 m .65479 .73334 L p .64794 .76703 L F P
0 g
s
.62845 .74075 m .62982 .77195 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .62845 .74075 L p .6285 .77499 L .707 .577 .707 r
F P
0 g
s
.59822 .77881 m .63002 .77652 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59427 .74824 m .59808 .77566 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59665 .74304 m .59808 .77566 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59822 .77881 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .63255 .79154 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .60098 .79652 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .62982 .77195 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.62845 .74075 m .59665 .74304 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.62849 .77211 m .62845 .74075 L .62592 .77241 L .707 .577 .707 r
F
.65781 .76929 m .65781 .76435 L .65384 .76543 L F
.65936 .77079 m .65906 .76401 L p .65781 .76929 L F P
0 g
s
.65936 .77079 m .68334 .76217 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65936 .77079 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .68503 .76773 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .65906 .76401 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .66151 .78162 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .65906 .76401 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65779 .73501 L p .65781 .76929 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .65906 .76401 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .62845 .74075 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.65781 .76435 m .65779 .73501 L .65384 .76543 L .707 .577 .707 r
F
.68293 .75262 m .67831 .71945 L .67528 .72124 L p F P
0 g
s
.67831 .71945 m .68293 .75262 L p .68391 .72735 L .707 .577 .707 r
F P
0 g
s
.68178 .72639 m .65779 .73501 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.68259 .76136 m .68239 .75287 L .67701 .75544 L .707 .577 .707 r
F
.68239 .75287 m .68178 .72639 L .67701 .75544 L F
.68334 .76217 m .68293 .75262 L p .68259 .76136 L F P
0 g
s
.68293 .75262 m .68178 .72639 L p .68259 .76136 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .68293 .75262 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69384 .74335 L .68467 .75979 L .707 .577 .707 r
F
.68499 .76109 m .69964 .75151 L p .68467 .75979 L F P
0 g
s
.69471 .74261 m .68391 .72735 L .68457 .75122 L .707 .577 .707 r
F
.68293 .75262 m .68503 .76773 L p .68391 .72735 L F P
0 g
s
.68178 .72639 m .68293 .75262 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .70081 .75122 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69471 .74261 m .68457 .75122 L .68503 .76773 L .707 .577 .707 r
F
.69909 .73888 m .69807 .71573 L p .69384 .74335 L F P
0 g
s
.70452 .72725 m .69567 .70663 L .69909 .73888 L .707 .577 .707 r
F
.69384 .74335 m .69722 .72128 L .68178 .72639 L F
.69673 .71661 m .68178 .72639 L p .69722 .72128 L F P
0 g
s
.69909 .73888 m .70081 .75122 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.7073 .73372 m .70597 .72415 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70597 .72415 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70369 .72834 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70436 .71671 m .70588 .72373 L .70665 .73985 L .707 .577 .707 r
F
.70058 .68545 m .70597 .72415 L p .70361 .71323 L .707 .578 .707 r
F P
0 g
s
.70597 .72415 m .70665 .73985 L p .705 .70559 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .69014 .69742 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70288 .70986 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70369 .72834 m .70288 .70986 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70364 .71476 m .70336 .71207 L .7041 .71774 L .707 .578 .707 r
F
.70336 .71207 m .70058 .68545 L .70361 .71323 L F
.70336 .71207 m .70361 .71323 L .7041 .71774 L F
.70369 .72834 m .69105 .7181 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70058 .68545 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70288 .70986 m .69715 .66866 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70213 .69256 m .70288 .70986 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70369 .72834 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70387 .71694 m .70288 .70986 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70436 .71671 m .70288 .70986 L .70509 .70407 L .707 .577 .707 r
F
.69085 .70251 m .69155 .69879 L .70288 .70986 L F
.70288 .70986 m .70387 .71694 L .70284 .7158 L p F P
0 g
s
.70284 .7158 m .69085 .70251 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70213 .69256 L .70298 .69588 L p .707 .577 .707 r
F P
0 g
s
.70298 .69588 m .70509 .70407 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.7041 .71774 m .70361 .71323 L .70597 .72415 L .707 .578 .707 r
F
.70436 .71671 m .705 .70559 L .70588 .72373 L .707 .577 .707 r
F
.70509 .70407 m .70597 .72415 L p .705 .70559 L F P
0 g
s
.70657 .73569 m .7073 .73372 L p .70635 .73151 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70319 .7301 L .69909 .73888 L .707 .577 .707 r
F
.70081 .75122 m .69909 .73888 L p .69988 .74992 L F P
0 g
s
.69996 .75098 m .70665 .73985 L p .69909 .73888 L .707 .577 .707 r
F P
0 g
s
.69988 .74992 m .69909 .73888 L .69471 .74261 L .707 .577 .707 r
F
.68948 .68232 m .69993 .69079 L p .69708 .70419 L F P
0 g
s
.69993 .69079 m .70213 .69256 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69708 .70419 m .69993 .69079 L .70071 .69582 L .707 .577 .707 r
F
.70387 .71694 m .70364 .71476 L .7041 .71774 L .707 .578 .707 r
F
.70597 .72415 m .7073 .73372 L .70717 .7331 L p F P
0 g
s
.70717 .7331 m .70387 .71694 L p .70597 .72415 L .707 .578 .707 r
F P
0 g
s
.69082 .69807 m .68414 .65424 L .69155 .69879 L .707 .577 .707 r
F
.69014 .69742 m .68414 .65424 L p .69121 .70062 L F P
0 g
s
.69014 .69742 m .68948 .68232 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69121 .70062 m .69082 .69807 L .69155 .69879 L .707 .577 .707 r
F
.69085 .70251 m .69014 .69742 L p .69121 .70062 L F P
0 g
s
.66996 .71013 m .66899 .68804 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .66996 .71013 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69105 .7181 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69085 .70251 m .66953 .69186 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68414 .65424 m .69014 .69742 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69085 .70251 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68948 .68232 m .69014 .69742 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .68452 .68044 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.68452 .68044 m .68948 .68232 L p .68653 .68652 L .707 .577 .707 r
F P
0 g
s
.68156 .69361 m .68452 .68044 L .68653 .68652 L .707 .577 .707 r
F
.66988 .68843 m .66281 .64358 L .67071 .6888 L F
.66899 .68804 m .66281 .64358 L p .67017 .69021 L F P
0 g
s
.66899 .68804 m .66839 .67435 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.67017 .69021 m .66988 .68843 L .67071 .6888 L .707 .577 .707 r
F
.66953 .69186 m .66899 .68804 L p .67017 .69021 L F P
0 g
s
.64249 .70522 m .6415 .68263 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66996 .71013 m .64249 .70522 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66996 .71013 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66953 .69186 m .64197 .68602 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66281 .64358 m .66899 .68804 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66953 .69186 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .66899 .68804 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .66091 .67301 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66091 .67301 m .66839 .67435 L p .66427 .67926 L .707 .577 .707 r
F P
0 g
s
.65862 .686 m .66091 .67301 L .66427 .67926 L .707 .577 .707 r
F
.6415 .68263 m .63526 .63774 L p .64277 .68439 L F P
0 g
s
.6415 .68263 m .64092 .66944 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64277 .68439 m .64252 .68283 L .64345 .68302 L .707 .577 .707 r
F
.64197 .68602 m .6415 .68263 L p .64277 .68439 L F P
0 g
s
.61133 .70384 m .61036 .68174 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64249 .70522 m .61133 .70384 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64249 .70522 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64197 .68602 m .6109 .68557 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.63526 .63774 m .6415 .68263 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64197 .68602 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .6415 .68263 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .63166 .66903 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.63166 .66903 m .64092 .66944 L p .63605 .6751 L .707 .577 .707 r
F P
0 g
s
.62986 .6823 m .63166 .66903 L .63605 .6751 L .707 .577 .707 r
F
.61036 .68174 m .60418 .63729 L p .61189 .68361 L F P
0 g
s
.61036 .68174 m .60976 .66806 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.61189 .68361 m .61159 .68178 L .61281 .68181 L .707 .577 .707 r
F
.6109 .68557 m .61036 .68174 L p .61189 .68361 L F P
0 g
s
.57953 .70613 m .57862 .68545 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61133 .70384 m .57953 .70613 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .61133 .70384 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.6109 .68557 m .57933 .69054 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60418 .63729 m .61036 .68174 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .6109 .68557 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .61036 .68174 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .59975 .66878 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.59975 .66878 m .60976 .66806 L p .60454 .67463 L .707 .577 .707 r
F P
0 g
s
.59772 .68322 m .59975 .66878 L .60454 .67463 L .707 .577 .707 r
F
.57862 .68545 m .57262 .64227 L p .58053 .68798 L F P
0 g
s
.57862 .68545 m .57796 .67035 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.58053 .68798 m .58006 .68528 L .58189 .68507 L .707 .577 .707 r
F
.57933 .69054 m .57862 .68545 L p .58053 .68798 L F P
0 g
s
.5502 .71186 m .54939 .69339 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57953 .70613 m .5502 .71186 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57953 .70613 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57933 .69054 m .55037 .70046 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57262 .64227 m .57862 .68545 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57933 .69054 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .57862 .68545 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .56865 .67217 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.56865 .67217 m .57796 .67035 L p .57293 .67787 L .707 .577 .707 r
F P
0 g
s
.56548 .68902 m .56865 .67217 L .57293 .67787 L .707 .577 .707 r
F
.54939 .69339 m .54366 .65219 L p .55151 .69748 L F P
0 g
s
.54939 .69339 m .54863 .67609 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.55151 .69748 m .55074 .69302 L .5535 .69227 L .707 .577 .707 r
F
.55037 .70046 m .54939 .69339 L p .55151 .69748 L F P
0 g
s
.5502 .71186 m .52621 .72048 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .5502 .71186 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.55037 .70046 m .52685 .71435 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .54939 .69339 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .55037 .70046 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .54939 .69339 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.53688 .69936 m .52552 .70478 L .54363 .68229 L .707 .577 .707 r
F
.54458 .68411 m .54363 .68229 L .54863 .67609 L F
.53688 .69936 m .54363 .68229 L .54458 .68411 L F
.52552 .70478 m .52464 .68471 L .52632 .6841 L p F P
0 g
s
.52632 .6841 m .54863 .67609 L p .52552 .70478 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .51327 .7152 L .52514 .71446 L .707 .577 .707 r
F
.52685 .71435 m .52508 .71621 L p .52514 .71446 L F P
0 g
s
.52508 .71621 m .51107 .73086 L p .52514 .71446 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .52552 .70478 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52685 .71435 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52464 .68471 m .52552 .70478 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .51107 .73086 L .51076 .73172 L p .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .52464 .68471 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50834 .69537 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .50936 .71852 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50436 .68258 L .50661 .68023 L p .707 .577 .707 r
F P
0 g
s
.50288 .7324 m .50133 .70702 L .50449 .72895 L .707 .577 .707 r
F
.50248 .73325 m .50133 .70702 L p .5033 .73933 L F P
0 g
s
.50452 .72889 m .50248 .73325 L .50436 .68258 L .707 .577 .707 r
F
.5033 .73933 m .50288 .7324 L .50449 .72895 L F
.5029 .7428 m .50248 .73325 L p .5033 .73933 L F P
0 g
s
.49787 .70008 m .50248 .73325 L p .49897 .70714 L .707 .578 .707 r
F P
0 g
s
.50248 .73325 m .49787 .70008 L .5004 .69326 L p .707 .577 .707 r
F P
0 g
s
.5004 .69326 m .50436 .68258 L p .50248 .73325 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50801 .76514 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.52103 .77957 m .5183 .75998 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.51766 .75935 m .51693 .72878 L .51657 .75829 L .707 .577 .707 r
F
.53055 .76541 m .5219 .74725 L .5183 .75998 L F
.5183 .75998 m .52103 .77957 L p .53055 .76541 L F P
0 g
s
.51693 .72878 m .5183 .75998 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .53945 .76936 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53802 .73674 m .51693 .72878 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.53865 .76901 m .53802 .73674 L .53751 .7685 L .707 .577 .707 r
F
.56609 .77608 m .56607 .77459 L .56486 .77436 L F
.56706 .77744 m .56694 .77476 L p .56609 .77608 L F P
0 g
s
.56706 .77744 m .59822 .77881 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56706 .77744 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .60098 .79652 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .56694 .77476 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56991 .79606 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59427 .74824 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .56694 .77476 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56549 .74166 L p .56609 .77608 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .56694 .77476 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .53802 .73674 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.56607 .77459 m .56549 .74166 L .56486 .77436 L .707 .577 .707 r
F
.59665 .74304 m .56549 .74166 L p .59537 .77558 L F P
0 g
s
.59822 .77881 m .59808 .77566 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59665 .74304 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .59808 .77566 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59052 .87901 m .59129 .86007 L .56013 .85763 L p .707 .577 .707 r
F P
0 g
s
.59129 .86007 m .59052 .87901 L .62232 .87978 L p .707 .577 .707 r
F P
0 g
s
.62232 .87978 m .6231 .86084 L .59129 .86007 L p .707 .577 .707 r
F P
0 g
s
.6231 .86084 m .62232 .87978 L .65165 .87881 L p .707 .577 .707 r
F P
0 g
s
.65165 .87881 m .65243 .85987 L .6231 .86084 L p .707 .577 .707 r
F P
0 g
s
.56013 .85763 m .55935 .87657 L .59052 .87901 L p .707 .577 .707 r
F P
0 g
s
.55935 .87657 m .56013 .85763 L .53266 .85377 L p .707 .577 .707 r
F P
0 g
s
.53266 .85377 m .53189 .87271 L .55935 .87657 L p .707 .577 .707 r
F P
0 g
s
.65243 .85987 m .65165 .87881 L .67564 .8762 L p .707 .577 .707 r
F P
0 g
s
.67564 .8762 m .67642 .85726 L .65243 .85987 L p .707 .577 .707 r
F P
0 g
s
.53189 .87271 m .53266 .85377 L .51158 .84887 L p .707 .577 .707 r
F P
0 g
s
.51158 .84887 m .5108 .86781 L .53189 .87271 L p .707 .577 .707 r
F P
0 g
s
.67642 .85726 m .67564 .8762 L .69194 .8722 L p .707 .577 .707 r
F P
0 g
s
.69194 .8722 m .69272 .85326 L .67642 .85726 L p .707 .577 .707 r
F P
0 g
s
.5108 .86781 m .51158 .84887 L .49893 .84339 L p .707 .577 .707 r
F P
0 g
s
.49893 .84339 m .49815 .86233 L .5108 .86781 L p .707 .577 .707 r
F P
0 g
s
.69272 .85326 m .69194 .8722 L .69895 .8672 L p .707 .577 .707 r
F P
0 g
s
.69895 .8672 m .69973 .84826 L .69272 .85326 L p .707 .577 .707 r
F P
0 g
s
.49362 .82167 m .4907 .3218 L .44669 .31922 L p .707 .577 .707 r
F P
0 g
s
.4907 .3218 m .49362 .82167 L .53856 .82027 L p .707 .577 .707 r
F P
0 g
s
.53856 .82027 m .53564 .3204 L .4907 .3218 L p .707 .577 .707 r
F P
0 g
s
.53564 .3204 m .53856 .82027 L .58004 .81504 L p .707 .577 .707 r
F P
0 g
s
.58004 .81504 m .57712 .31517 L .53564 .3204 L p .707 .577 .707 r
F P
0 g
s
.49815 .86233 m .49893 .84339 L .49597 .83789 L p .707 .577 .707 r
F P
0 g
s
.49597 .83789 m .49519 .85683 L .49815 .86233 L p .707 .577 .707 r
F P
0 g
s
.44961 .81909 m .44669 .31922 L .40793 .31291 L p .707 .577 .707 r
F P
0 g
s
.44669 .31922 m .44961 .81909 L .49362 .82167 L p .707 .577 .707 r
F P
0 g
s
.57712 .31517 m .58004 .81504 L .614 .80648 L p .707 .577 .707 r
F P
0 g
s
.614 .80648 m .61108 .30661 L .57712 .31517 L p .707 .577 .707 r
F P
0 g
s
.69973 .84826 m .69895 .8672 L .69599 .86169 L p .707 .577 .707 r
F P
0 g
s
.69599 .86169 m .69677 .84275 L .69973 .84826 L p .707 .577 .707 r
F P
0 g
s
.41085 .81278 m .40793 .31291 L .3782 .3035 L p .707 .577 .707 r
F P
0 g
s
.40793 .31291 m .41085 .81278 L .44961 .81909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.49519 .85683 m .49597 .83789 L .50299 .83289 L p .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .24117 .71128 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.24117 .71128 m .22018 .71097 L p .23174 .72587 L .707 .577 .707 r
F P
0 g
s
.2415 .73845 m .24117 .71128 L .23174 .72587 L .707 .577 .707 r
F
.20934 .70867 m .19263 .70513 L p .20268 .721 L F P
0 g
s
.19263 .70513 m .1713 .69448 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19568 .73396 m .19564 .73219 L .1945 .73169 L .707 .577 .707 r
F
.19658 .73571 m .19644 .73255 L p .19568 .73396 L F P
0 g
s
.19644 .73255 m .19263 .70513 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .22405 .74062 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19658 .73571 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .2269 .75925 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19263 .70513 m .19644 .73255 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19934 .75341 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .20934 .70867 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.21192 .73559 m .20934 .70867 L .20268 .721 L .707 .577 .707 r
F
.22393 .73795 m .22018 .71097 L p .21192 .73559 L F P
0 g
s
.19501 .69993 m .19644 .73255 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19501 .69993 L p .19568 .73396 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .1945 .73169 L .17529 .72317 L .707 .577 .707 r
F
.177 .72831 m .19658 .73571 L p .17529 .72317 L F P
0 g
s
.17802 .74275 m .19934 .75341 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.1713 .69448 m .17529 .72317 L p .1789 .71043 L .707 .577 .707 r
F P
0 g
s
.17033 .71832 m .17529 .72317 L .15829 .68005 L .707 .577 .707 r
F
.17471 .72521 m .17465 .72254 L .17356 .72147 L F
.17549 .72774 m .17529 .72317 L p .17471 .72521 L F P
0 g
s
.17529 .72317 m .1713 .69448 L .16257 .6848 L p .707 .577 .707 r
F P
0 g
s
.16257 .6848 m .15829 .68005 L p .17529 .72317 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17392 .69196 L p .17471 .72521 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17549 .72774 L .177 .72831 L p .707 .577 .707 r
F P
0 g
s
.17549 .72774 m .17356 .72147 L .16255 .71072 L .707 .577 .707 r
F
.16371 .71819 m .17549 .72774 L p .16255 .71072 L F P
0 g
s
.165 .72833 m .17802 .74275 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.15829 .68005 m .16255 .71072 L p .16267 .69398 L .707 .577 .707 r
F P
0 g
s
.16148 .70577 m .16255 .71072 L .15486 .66327 L .707 .578 .707 r
F
.16253 .71415 m .16236 .70985 L .16192 .70779 L .707 .577 .707 r
F
.16285 .7175 m .16255 .71072 L p .16253 .71415 L F P
0 g
s
.16255 .71072 m .15829 .68005 L .15633 .6705 L p .707 .578 .707 r
F P
0 g
s
.15633 .6705 m .15486 .66327 L p .16255 .71072 L .707 .578 .707 r
F P
0 g
s
.16255 .71072 m .16128 .68172 L p .16253 .71415 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .16285 .7175 L .16371 .71819 L p .707 .577 .707 r
F P
0 g
s
.16285 .7175 m .16192 .70779 L .15947 .69644 L .707 .577 .707 r
F
.15999 .70637 m .16285 .7175 L p .15947 .69644 L F P
0 g
s
.16157 .71154 m .165 .72833 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16148 .70577 m .15596 .67033 L .15947 .69644 L .707 .578 .707 r
F
.15947 .69644 m .16157 .71154 L p .16148 .70577 L F P
0 g
s
.15832 .67021 m .15947 .69644 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16128 .68172 m .15832 .67021 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16236 .70985 m .16128 .68172 L .16192 .70779 L .707 .577 .707 r
F
.17033 .71832 m .16267 .69398 L .16255 .71072 L F
.16128 .68172 m .16255 .71072 L p .17356 .72147 L F P
0 g
s
.17392 .69196 m .16128 .68172 L p .17356 .72147 L .707 .577 .707 r
F P
0 g
s
.15832 .67021 m .16475 .65951 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.1636 .64342 m .17713 .62926 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.16475 .65951 m .16533 .65855 L p .16493 .66202 L .707 .577 .707 r
F P
0 g
s
.16148 .69213 m .16475 .65951 L .16493 .66202 L .707 .577 .707 r
F
.17026 .67838 m .16635 .6817 L .17713 .62926 L F
.16749 .69247 m .16635 .6817 L .17259 .6764 L F
.165 .72833 m .16255 .71072 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16775 .6949 m .16157 .71154 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .16635 .6817 L p .16749 .69247 L .707 .577 .707 r
F P
0 g
s
.16157 .71154 m .16151 .69207 L .16635 .6817 L .707 .577 .707 r
F
.16157 .71154 m .15947 .69644 L p .16151 .69207 L F P
0 g
s
.15947 .69644 m .15989 .70599 L .15999 .70637 L p .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .15989 .70599 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .16635 .6817 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .1669 .69433 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16135 .64577 m .16635 .6817 L p .16151 .69207 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .1669 .69433 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .1832 .68367 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .20065 .61537 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .18251 .66797 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.18384 .67754 m .18251 .66797 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .17713 .62926 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .22961 .60545 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.20773 .6562 m .20065 .61537 L .2105 .65545 L .707 .577 .707 r
F
.22961 .60545 m .26117 .60047 L p .23888 .64825 L F P
0 g
s
.23705 .64846 m .22961 .60545 L .23888 .64825 L .707 .577 .707 r
F
.26117 .60047 m .29225 .60093 L p .2698 .645 L F P
0 g
s
.26858 .64496 m .26117 .60047 L .2698 .645 L .707 .577 .707 r
F
.29225 .60093 m .3198 .60677 L p .30044 .6462 L F P
0 g
s
.29951 .64602 m .29225 .60093 L .30044 .6462 L .707 .577 .707 r
F
.3198 .60677 m .34113 .61742 L p .32771 .65198 L F P
0 g
s
.34113 .61742 m .35414 .63185 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36018 .69329 m .36144 .67603 L .35506 .67891 L .707 .577 .707 r
F
.36208 .66726 m .36059 .66973 L p .36144 .67603 L F P
0 g
s
.36059 .66973 m .35506 .67891 L p .36144 .67603 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .36208 .66726 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .35757 .64863 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35757 .64863 m .35108 .66613 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .3353 .68264 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35608 .70207 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.3578 .71441 m .36356 .69888 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36334 .6947 m .36151 .69043 L .36356 .69888 L .707 .577 .707 r
F
.35506 .67891 m .35608 .70207 L p .36018 .69329 L F P
0 g
s
.35506 .67891 m .35372 .67979 L p .35421 .68446 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .35608 .70207 L p .35266 .66981 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35108 .66613 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35663 .71469 L .35695 .71417 L p .707 .577 .707 r
F P
0 g
s
.34034 .72535 m .34198 .72428 L p .34166 .72297 L .707 .577 .707 r
F P
0 g
s
.33992 .7158 m .34034 .72535 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.33204 .71956 m .33992 .7158 L .32169 .70332 L .707 .577 .707 r
F
.32086 .70685 m .32169 .70332 L .31178 .69653 L F
.33204 .71956 m .32169 .70332 L .32086 .70685 L F
.33227 .68443 m .31178 .69653 L p .33992 .7158 L F P
0 g
s
.30224 .69979 m .28282 .70645 L p .29406 .71853 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .25126 .71142 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28549 .73818 m .28548 .73529 L .28291 .73559 L .707 .577 .707 r
F
.28701 .73971 m .28681 .73514 L p .28549 .73818 L F P
0 g
s
.28681 .73514 m .28282 .70645 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28701 .73971 m .31635 .73397 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28701 .73971 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .3185 .7448 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .28681 .73514 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28954 .75472 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .30224 .69979 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.30493 .73022 m .30224 .69979 L .29406 .71853 L .707 .577 .707 r
F
.31605 .7272 m .31178 .69653 L p .30493 .73022 L F P
0 g
s
.28545 .70393 m .28681 .73514 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28545 .70393 L p .28549 .73818 L .707 .577 .707 r
F P
0 g
s
.25521 .742 m .28701 .73971 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .25507 .73884 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25364 .70622 m .25507 .73884 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25521 .742 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .28954 .75472 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25798 .7597 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .28681 .73514 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28545 .70393 m .25364 .70622 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.28548 .73529 m .28545 .70393 L .28291 .73559 L .707 .577 .707 r
F
.3148 .73247 m .3148 .72754 L .31083 .72861 L F
.31635 .73397 m .31605 .7272 L p .3148 .73247 L F P
0 g
s
.31635 .73397 m .34034 .72535 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31635 .73397 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .34202 .73091 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .31605 .7272 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .3185 .7448 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .31605 .7272 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31478 .69819 L p .3148 .73247 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .31605 .7272 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .28545 .70393 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.3148 .72754 m .31478 .69819 L .31083 .72861 L .707 .577 .707 r
F
.33992 .7158 m .3353 .68264 L .33227 .68443 L p F P
0 g
s
.3353 .68264 m .33992 .7158 L p .3409 .69054 L .707 .577 .707 r
F P
0 g
s
.33877 .68957 m .31478 .69819 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.33958 .72455 m .33938 .71606 L .334 .71863 L .707 .577 .707 r
F
.33938 .71606 m .33877 .68957 L .334 .71863 L F
.34034 .72535 m .33992 .7158 L p .33958 .72455 L F P
0 g
s
.33992 .7158 m .33877 .68957 L p .33958 .72455 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .33992 .7158 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35083 .70653 L .34166 .72297 L .707 .577 .707 r
F
.34198 .72428 m .35663 .71469 L p .34166 .72297 L F P
0 g
s
.3517 .70579 m .3409 .69054 L .34156 .71441 L .707 .577 .707 r
F
.33992 .7158 m .34202 .73091 L p .3409 .69054 L F P
0 g
s
.33877 .68957 m .33992 .7158 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .3578 .71441 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.3517 .70579 m .34156 .71441 L .34202 .73091 L .707 .577 .707 r
F
.35608 .70207 m .35506 .67891 L p .35083 .70653 L F P
0 g
s
.36151 .69043 m .35266 .66981 L .35608 .70207 L .707 .577 .707 r
F
.35083 .70653 m .35421 .68446 L .33877 .68957 L F
.35372 .67979 m .33877 .68957 L p .35421 .68446 L F P
0 g
s
.35608 .70207 m .3578 .71441 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36429 .69691 m .36296 .68733 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36296 .68733 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36068 .69152 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36135 .67989 m .36287 .68691 L .36365 .70304 L .707 .577 .707 r
F
.35757 .64863 m .36296 .68733 L p .3606 .67641 L .707 .578 .707 r
F P
0 g
s
.36296 .68733 m .36365 .70304 L p .36199 .66877 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .34713 .6606 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35987 .67305 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36068 .69152 m .35987 .67305 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36063 .67794 m .36035 .67525 L .36109 .68093 L .707 .578 .707 r
F
.36035 .67525 m .35757 .64863 L .3606 .67641 L F
.36035 .67525 m .3606 .67641 L .36109 .68093 L F
.36068 .69152 m .34804 .68128 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35757 .64863 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35987 .67305 m .35414 .63185 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35912 .65574 m .35987 .67305 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .36068 .69152 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.36086 .68012 m .35987 .67305 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.36135 .67989 m .35987 .67305 L .36208 .66726 L .707 .577 .707 r
F
.34784 .6657 m .34854 .66197 L .35987 .67305 L F
.35987 .67305 m .36086 .68012 L .35983 .67899 L p F P
0 g
s
.35983 .67899 m .34784 .6657 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .35912 .65574 L .35997 .65907 L p .707 .577 .707 r
F P
0 g
s
.35997 .65907 m .36208 .66726 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.36109 .68093 m .3606 .67641 L .36296 .68733 L .707 .578 .707 r
F
.36135 .67989 m .36199 .66877 L .36287 .68691 L .707 .577 .707 r
F
.36208 .66726 m .36296 .68733 L p .36199 .66877 L F P
0 g
s
.36356 .69888 m .36429 .69691 L p .36334 .6947 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36018 .69329 L .35608 .70207 L .707 .577 .707 r
F
.3578 .71441 m .35608 .70207 L p .35687 .7131 L F P
0 g
s
.35695 .71417 m .36365 .70304 L p .35608 .70207 L .707 .577 .707 r
F P
0 g
s
.35687 .7131 m .35608 .70207 L .3517 .70579 L .707 .577 .707 r
F
.34647 .6455 m .35693 .65397 L p .35407 .66738 L F P
0 g
s
.35693 .65397 m .35912 .65574 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35407 .66738 m .35693 .65397 L .3577 .659 L .707 .577 .707 r
F
.36086 .68012 m .36063 .67794 L .36109 .68093 L .707 .578 .707 r
F
.36296 .68733 m .36429 .69691 L .36416 .69628 L p F P
0 g
s
.36416 .69628 m .36086 .68012 L p .36296 .68733 L .707 .578 .707 r
F P
0 g
s
.34781 .66126 m .34113 .61742 L .34854 .66197 L .707 .577 .707 r
F
.34713 .6606 m .34113 .61742 L p .3482 .6638 L F P
0 g
s
.34713 .6606 m .34647 .6455 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.3482 .6638 m .34781 .66126 L .34854 .66197 L .707 .577 .707 r
F
.34784 .6657 m .34713 .6606 L p .3482 .6638 L F P
0 g
s
.32695 .67331 m .32598 .65122 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .32695 .67331 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34804 .68128 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34784 .6657 m .32652 .65504 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34113 .61742 m .34713 .6606 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34784 .6657 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34647 .6455 m .34713 .6606 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .34151 .64363 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34151 .64363 m .34647 .6455 L p .34352 .64971 L .707 .577 .707 r
F P
0 g
s
.33855 .65679 m .34151 .64363 L .34352 .64971 L .707 .577 .707 r
F
.32687 .65161 m .3198 .60677 L .32771 .65198 L F
.32598 .65122 m .3198 .60677 L p .32716 .6534 L F P
0 g
s
.32598 .65122 m .32538 .63754 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32716 .6534 m .32687 .65161 L .32771 .65198 L .707 .577 .707 r
F
.32652 .65504 m .32598 .65122 L p .32716 .6534 L F P
0 g
s
.29948 .6684 m .29849 .64582 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32695 .67331 m .29948 .6684 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32695 .67331 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32652 .65504 m .29896 .6492 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.3198 .60677 m .32598 .65122 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32652 .65504 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .32598 .65122 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .3179 .6362 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.3179 .6362 m .32538 .63754 L p .32126 .64245 L .707 .577 .707 r
F P
0 g
s
.31561 .64918 m .3179 .6362 L .32126 .64245 L .707 .577 .707 r
F
.29849 .64582 m .29225 .60093 L p .29976 .64758 L F P
0 g
s
.29849 .64582 m .29792 .63262 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29976 .64758 m .29951 .64602 L .30044 .6462 L .707 .577 .707 r
F
.29896 .6492 m .29849 .64582 L p .29976 .64758 L F P
0 g
s
.26832 .66702 m .26735 .64493 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29948 .6684 m .26832 .66702 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29948 .6684 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29896 .6492 m .26789 .64875 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29225 .60093 m .29849 .64582 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29896 .6492 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .29849 .64582 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .28865 .63221 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.28865 .63221 m .29792 .63262 L p .29304 .63828 L .707 .577 .707 r
F P
0 g
s
.28685 .64549 m .28865 .63221 L .29304 .63828 L .707 .577 .707 r
F
.26735 .64493 m .26117 .60047 L p .26888 .64679 L F P
0 g
s
.26735 .64493 m .26675 .63124 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26888 .64679 m .26858 .64496 L .2698 .645 L .707 .577 .707 r
F
.26789 .64875 m .26735 .64493 L p .26888 .64679 L F P
0 g
s
.23652 .66931 m .23561 .64863 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26832 .66702 m .23652 .66931 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26832 .66702 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26789 .64875 m .23632 .65373 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26117 .60047 m .26735 .64493 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26789 .64875 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .26735 .64493 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .25674 .63196 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.25674 .63196 m .26675 .63124 L p .26153 .63782 L .707 .577 .707 r
F P
0 g
s
.25472 .6464 m .25674 .63196 L .26153 .63782 L .707 .577 .707 r
F
.23561 .64863 m .22961 .60545 L p .23752 .65117 L F P
0 g
s
.23561 .64863 m .23495 .63353 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23752 .65117 m .23705 .64846 L .23888 .64825 L .707 .577 .707 r
F
.23632 .65373 m .23561 .64863 L p .23752 .65117 L F P
0 g
s
.20719 .67505 m .20638 .65657 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23652 .66931 m .20719 .67505 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23652 .66931 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23632 .65373 m .20736 .66365 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.22961 .60545 m .23561 .64863 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23632 .65373 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .23561 .64863 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .22564 .63536 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.22564 .63536 m .23495 .63353 L p .22992 .64106 L .707 .577 .707 r
F P
0 g
s
.22247 .6522 m .22564 .63536 L .22992 .64106 L .707 .577 .707 r
F
.20638 .65657 m .20065 .61537 L p .2085 .66067 L F P
0 g
s
.20638 .65657 m .20562 .63927 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.2085 .66067 m .20773 .6562 L .2105 .65545 L .707 .577 .707 r
F
.20736 .66365 m .20638 .65657 L p .2085 .66067 L F P
0 g
s
.20719 .67505 m .1832 .68367 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20719 .67505 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20736 .66365 m .18384 .67754 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .20638 .65657 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20736 .66365 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .20638 .65657 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.19387 .66254 m .18251 .66797 L .20062 .64548 L .707 .577 .707 r
F
.20157 .6473 m .20062 .64548 L .20562 .63927 L F
.19387 .66254 m .20062 .64548 L .20157 .6473 L F
.18251 .66797 m .18163 .64789 L .18331 .64729 L p F P
0 g
s
.18331 .64729 m .20562 .63927 L p .18251 .66797 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .17026 .67838 L .18214 .67765 L .707 .577 .707 r
F
.18384 .67754 m .18207 .6794 L p .18214 .67765 L F P
0 g
s
.18207 .6794 m .16806 .69404 L p .18214 .67765 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .18251 .66797 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .18384 .67754 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18163 .64789 m .18251 .66797 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16806 .69404 L .16775 .6949 L p .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .18163 .64789 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16533 .65855 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .16635 .6817 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16135 .64577 L .1636 .64342 L p .707 .577 .707 r
F P
0 g
s
.15987 .69559 m .15832 .67021 L .16148 .69213 L .707 .577 .707 r
F
.15947 .69644 m .15832 .67021 L p .16029 .70251 L F P
0 g
s
.16151 .69207 m .15947 .69644 L .16135 .64577 L .707 .577 .707 r
F
.16029 .70251 m .15987 .69559 L .16148 .69213 L F
.15989 .70599 m .15947 .69644 L p .16029 .70251 L F P
0 g
s
.15486 .66327 m .15947 .69644 L p .15596 .67033 L .707 .578 .707 r
F P
0 g
s
.15947 .69644 m .15486 .66327 L .15739 .65645 L p .707 .577 .707 r
F P
0 g
s
.15739 .65645 m .16135 .64577 L p .15947 .69644 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .165 .72833 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17802 .74275 m .17529 .72317 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17465 .72254 m .17392 .69196 L .17356 .72147 L .707 .577 .707 r
F
.18754 .7286 m .1789 .71043 L .17529 .72317 L F
.17529 .72317 m .17802 .74275 L p .18754 .7286 L F P
0 g
s
.17392 .69196 m .17529 .72317 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .19644 .73255 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19501 .69993 m .17392 .69196 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19564 .73219 m .19501 .69993 L .1945 .73169 L .707 .577 .707 r
F
.22308 .73926 m .22306 .73778 L .22185 .73754 L F
.22405 .74062 m .22393 .73795 L p .22308 .73926 L F P
0 g
s
.22405 .74062 m .25521 .742 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22405 .74062 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .25798 .7597 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .22393 .73795 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .2269 .75925 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25126 .71142 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .22393 .73795 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22248 .70484 L p .22308 .73926 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .22393 .73795 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .19501 .69993 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.22306 .73778 m .22248 .70484 L .22185 .73754 L .707 .577 .707 r
F
.25364 .70622 m .22248 .70484 L p .25236 .73876 L F P
0 g
s
.25521 .742 m .25507 .73884 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25364 .70622 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .25507 .73884 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.50299 .83289 m .50221 .85183 L .49519 .85683 L p .707 .577 .707 r
F P
0 g
s
.61108 .30661 m .614 .80648 L .6371 .79543 L p .707 .577 .707 r
F P
0 g
s
.6371 .79543 m .63418 .29556 L .61108 .30661 L p .707 .577 .707 r
F P
0 g
s
.69677 .84275 m .69599 .86169 L .68335 .85622 L p .707 .577 .707 r
F P
0 g
s
.68335 .85622 m .68413 .83728 L .69677 .84275 L p .707 .577 .707 r
F P
0 g
s
.24751 .84219 m .24829 .82325 L .21712 .82082 L p .707 .577 .707 r
F P
0 g
s
.24829 .82325 m .24751 .84219 L .27931 .84296 L p .707 .577 .707 r
F P
0 g
s
.27931 .84296 m .28009 .82402 L .24829 .82325 L p .707 .577 .707 r
F P
0 g
s
.38112 .80338 m .3782 .3035 L .36042 .29191 L p .707 .577 .707 r
F P
0 g
s
.3782 .3035 m .38112 .80338 L .41085 .81278 L p .707 .577 .707 r
F P
0 g
s
.28009 .82402 m .27931 .84296 L .30864 .84199 L p .707 .577 .707 r
F P
0 g
s
.30864 .84199 m .30942 .82305 L .28009 .82402 L p .707 .577 .707 r
F P
0 g
s
.21712 .82082 m .21635 .83976 L .24751 .84219 L p .707 .577 .707 r
F P
0 g
s
.50221 .85183 m .50299 .83289 L .51929 .82889 L p .707 .577 .707 r
F P
0 g
s
.21635 .83976 m .21712 .82082 L .18966 .81696 L p .707 .577 .707 r
F P
0 g
s
.51929 .82889 m .51851 .84783 L .50221 .85183 L p .707 .577 .707 r
F P
0 g
s
.18966 .81696 m .18888 .8359 L .21635 .83976 L p .707 .577 .707 r
F P
0 g
s
.30942 .82305 m .30864 .84199 L .33263 .83938 L p .707 .577 .707 r
F P
0 g
s
.33263 .83938 m .33341 .82044 L .30942 .82305 L p .707 .577 .707 r
F P
0 g
s
.18888 .8359 m .18966 .81696 L .16857 .81205 L p .707 .577 .707 r
F P
0 g
s
.68413 .83728 m .68335 .85622 L .66226 .85132 L p .707 .577 .707 r
F P
0 g
s
.66226 .85132 m .66304 .83238 L .68413 .83728 L p .707 .577 .707 r
F P
0 g
s
.63418 .29556 m .6371 .79543 L .6471 .78298 L p .707 .577 .707 r
F P
0 g
s
.6471 .78298 m .64418 .28311 L .63418 .29556 L p .707 .577 .707 r
F P
0 g
s
.16857 .81205 m .16779 .83099 L .18888 .8359 L p .707 .577 .707 r
F P
0 g
s
.51851 .84783 m .51929 .82889 L .54328 .82628 L p .707 .577 .707 r
F P
0 g
s
.54328 .82628 m .5425 .84522 L .51851 .84783 L p .707 .577 .707 r
F P
0 g
s
.33341 .82044 m .33263 .83938 L .34893 .83538 L p .707 .577 .707 r
F P
0 g
s
.34893 .83538 m .34971 .81644 L .33341 .82044 L p .707 .577 .707 r
F P
0 g
s
.36334 .79178 m .36042 .29191 L .35633 .27927 L p .707 .577 .707 r
F P
0 g
s
.36042 .29191 m .36334 .79178 L .38112 .80338 L p .707 .577 .707 r
F P
0 g
s
.16779 .83099 m .16857 .81205 L .15593 .80658 L p .707 .577 .707 r
F P
0 g
s
.66304 .83238 m .66226 .85132 L .63479 .84746 L p .707 .577 .707 r
F P
0 g
s
.63479 .84746 m .63557 .82852 L .66304 .83238 L p .707 .577 .707 r
F P
0 g
s
.15593 .80658 m .15515 .82552 L .16779 .83099 L p .707 .577 .707 r
F P
0 g
s
.5425 .84522 m .54328 .82628 L .57261 .82531 L p .707 .577 .707 r
F P
0 g
s
.57261 .82531 m .57183 .84425 L .5425 .84522 L p .707 .577 .707 r
F P
0 g
s
.63557 .82852 m .63479 .84746 L .60363 .84502 L p .707 .577 .707 r
F P
0 g
s
.60363 .84502 m .60441 .82608 L .63557 .82852 L p .707 .577 .707 r
F P
0 g
s
.34971 .81644 m .34893 .83538 L .35594 .83038 L p .707 .577 .707 r
F P
0 g
s
.35594 .83038 m .35672 .81144 L .34971 .81644 L p .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64301 .77033 L .62523 .75874 L p .707 .577 .707 r
F P
0 g
s
.6385 .58015 m .63507 .56337 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.6471 .78298 m .64423 .77411 L p .64379 .60541 L .707 .577 .707 r
F P
0 g
s
.64379 .60541 m .64469 .60948 L .6471 .78298 L .707 .577 .707 r
F
.64309 .73678 m .64359 .53011 L .64423 .77411 L F
.64549 .50744 m .6471 .78298 L p .64359 .53011 L F P
0 g
s
.64309 .73678 m .64189 .55032 L .64359 .53011 L .707 .577 .707 r
F
.64275 .72557 m .64009 .27046 L p .64309 .73678 L F P
0 g
s
.64379 .60541 m .64359 .53011 L .64469 .60948 L .707 .577 .707 r
F
.64522 .62843 m .65823 .64285 L p .6392 .58238 L F P
0 g
s
.6385 .58015 m .63905 .58413 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.63905 .58413 m .64522 .62843 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64418 .28311 L p .64359 .53011 L .707 .577 .707 r
F P
0 g
s
.64189 .55032 m .64009 .27046 L .64359 .53011 L .707 .577 .707 r
F
.64301 .77033 m .64275 .72557 L p .64309 .73678 L F P
0 g
s
.63614 .68371 m .63536 .70265 L .64214 .70559 L p .707 .577 .707 r
F P
0 g
s
.64214 .70559 m .648 .70812 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.64183 .69542 m .63614 .68371 L .64214 .70559 L .707 .577 .707 r
F
.64522 .62843 m .63905 .58413 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.63905 .58413 m .6385 .58015 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.64423 .77411 m .64301 .77033 L p .64309 .73678 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64878 .68918 L .64154 .68605 L p .707 .577 .707 r
F P
0 g
s
.64154 .68605 m .63614 .68371 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64154 .68605 L .64183 .69542 L .707 .577 .707 r
F
.65823 .64285 m .65151 .59458 L .63931 .58105 L p F P
0 g
s
.63931 .58105 m .6385 .58015 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.65823 .64285 m .63931 .58105 L .6392 .58238 L .707 .577 .707 r
F
.64418 .28311 m .64549 .50744 L p .64359 .53011 L F P
0 g
s
.57183 .84425 m .57261 .82531 L .60441 .82608 L p .707 .577 .707 r
F P
0 g
s
.60441 .82608 m .60363 .84502 L .57183 .84425 L p .707 .577 .707 r
F P
0 g
s
.15515 .82552 m .15593 .80658 L .15297 .80108 L p .707 .577 .707 r
F P
0 g
s
.15297 .80108 m .15219 .82001 L .15515 .82552 L p .707 .577 .707 r
F P
0 g
s
.35633 .27927 m .35925 .77914 L .36334 .79178 L p .707 .577 .707 r
F P
0 g
s
.35925 .77914 m .35633 .27927 L .36633 .26681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35672 .81144 m .35594 .83038 L .35298 .82488 L p .707 .577 .707 r
F P
0 g
s
.35298 .82488 m .35376 .80594 L .35672 .81144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15219 .82001 m .15297 .80108 L .15998 .79608 L p .707 .577 .707 r
F P
0 g
s
.62523 .75874 m .62231 .25887 L .64009 .27046 L p .707 .577 .707 r
F P
0 g
s
.15998 .79608 m .1592 .81502 L .15219 .82001 L p .707 .577 .707 r
F P
0 g
s
.35376 .80594 m .35298 .82488 L .34034 .81941 L p .707 .577 .707 r
F P
0 g
s
.34034 .81941 m .34112 .80047 L .35376 .80594 L p .707 .577 .707 r
F P
0 g
s
.36925 .76668 m .36633 .26681 L .38943 .25576 L p .707 .577 .707 r
F P
0 g
s
.36633 .26681 m .36925 .76668 L .35925 .77914 L p .707 .577 .707 r
F P
0 g
s
.1592 .81502 m .15998 .79608 L .17628 .79208 L p .707 .577 .707 r
F P
0 g
s
.17628 .79208 m .1755 .81102 L .1592 .81502 L p .707 .577 .707 r
F P
0 g
s
.62231 .25887 m .62523 .75874 L .59551 .74933 L p .707 .577 .707 r
F P
0 g
s
.59551 .74933 m .59258 .24946 L .62231 .25887 L p .707 .577 .707 r
F P
0 g
s
.34112 .80047 m .34034 .81941 L .31925 .8145 L p .707 .577 .707 r
F P
0 g
s
.31925 .8145 m .32003 .79556 L .34112 .80047 L p .707 .577 .707 r
F P
0 g
s
.73819 .6598 m .73147 .61152 L .70039 .61107 L p .707 .577 .707 r
F P
0 g
s
.73147 .61152 m .73819 .6598 L .76975 .65482 L p .707 .577 .707 r
F P
0 g
s
.76975 .65482 m .76304 .60655 L .73147 .61152 L p .707 .577 .707 r
F P
0 g
s
.76304 .60655 m .76975 .65482 L .79871 .6449 L p .707 .577 .707 r
F P
0 g
s
.79871 .6449 m .792 .59663 L .76304 .60655 L p .707 .577 .707 r
F P
0 g
s
.39063 .46038 m .39235 .75564 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .38943 .25576 L .42339 .2472 L p .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .4077 .50423 L .42373 .71342 L .707 .577 .707 r
F
.42504 .52891 m .42605 .70231 L p .4077 .50423 L F P
0 g
s
.42605 .70231 m .42631 .74708 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.4077 .50423 m .42605 .70231 L .42373 .71342 L .707 .577 .707 r
F
.46487 .24197 m .46779 .74184 L .42631 .74708 L p F P
0 g
s
.44585 .68231 m .44662 .66337 L .43409 .66378 L p .707 .577 .707 r
F P
0 g
s
.42631 .74708 m .42339 .2472 L .46487 .24197 L p .707 .577 .707 r
F P
0 g
s
.43409 .66378 m .41729 .66434 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.44585 .68231 m .43409 .66378 L .43203 .67362 L .707 .577 .707 r
F
.41729 .66434 m .41651 .68328 L .43011 .68283 L p F P
0 g
s
.43011 .68283 m .44585 .68231 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.43203 .67362 m .41729 .66434 L .43011 .68283 L .707 .577 .707 r
F
.42631 .74708 m .41618 .74963 L p .42373 .71342 L F P
0 g
s
.41618 .74963 m .39235 .75564 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.42339 .2472 m .42504 .52891 L p .4077 .50423 L .707 .577 .707 r
F P
0 g
s
.4557 .60809 m .44954 .56379 L p .42003 .56973 L .707 .577 .707 r
F P
0 g
s
.44954 .56379 m .44899 .55981 L .44718 .56043 L p .707 .577 .707 r
F P
0 g
s
.44718 .56043 m .42003 .56973 L p .44954 .56379 L .707 .577 .707 r
F P
0 g
s
.38846 .57471 m .39518 .62298 L .42372 .61848 L p .707 .577 .707 r
F P
0 g
s
.42372 .61848 m .42674 .61801 L p .42266 .61339 L .707 .577 .707 r
F P
0 g
s
.42266 .61339 m .38846 .57471 L .42372 .61848 L .707 .577 .707 r
F
.39235 .75564 m .36925 .76668 L p .38282 .42309 L F P
0 g
s
.38943 .25576 m .39063 .46038 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.1755 .81102 m .17628 .79208 L .20027 .78947 L p .707 .577 .707 r
F P
0 g
s
.20027 .78947 m .19949 .8084 L .1755 .81102 L p .707 .577 .707 r
F P
0 g
s
.70711 .65935 m .70039 .61107 L .67284 .60523 L p .707 .577 .707 r
F P
0 g
s
.70039 .61107 m .70711 .65935 L .73819 .6598 L p .707 .577 .707 r
F P
0 g
s
.792 .59663 m .79871 .6449 L .82223 .63101 L p .707 .577 .707 r
F P
0 g
s
.82223 .63101 m .81552 .58273 L .792 .59663 L p .707 .577 .707 r
F P
0 g
s
.32003 .79556 m .31925 .8145 L .29178 .81064 L p .707 .577 .707 r
F P
0 g
s
.29178 .81064 m .29256 .7917 L .32003 .79556 L p .707 .577 .707 r
F P
0 g
s
.72772 .71932 m .7285 .70038 L .69734 .69795 L p .707 .577 .707 r
F P
0 g
s
.7285 .70038 m .72772 .71932 L .75952 .72009 L p .707 .577 .707 r
F P
0 g
s
.75952 .72009 m .7603 .70115 L .7285 .70038 L p .707 .577 .707 r
F P
0 g
s
.59258 .24946 m .59551 .74933 L .55674 .74303 L p .707 .577 .707 r
F P
0 g
s
.55674 .74303 m .55382 .24316 L .59258 .24946 L p .707 .577 .707 r
F P
0 g
s
.7603 .70115 m .75952 .72009 L .78885 .71912 L p .707 .577 .707 r
F P
0 g
s
.78885 .71912 m .78963 .70018 L .7603 .70115 L p .707 .577 .707 r
F P
0 g
s
.69734 .69795 m .69656 .71689 L .72772 .71932 L p .707 .577 .707 r
F P
0 g
s
.67956 .65351 m .67284 .60523 L .65151 .59458 L p .707 .577 .707 r
F P
0 g
s
.67284 .60523 m .67956 .65351 L .70711 .65935 L p .707 .577 .707 r
F P
0 g
s
.19949 .8084 m .20027 .78947 L .2296 .7885 L p .707 .577 .707 r
F P
0 g
s
.69656 .71689 m .69734 .69795 L .66987 .69409 L p .707 .577 .707 r
F P
0 g
s
.2296 .7885 m .22882 .80744 L .19949 .8084 L p .707 .577 .707 r
F P
0 g
s
.81552 .58273 m .82223 .63101 L .83801 .61451 L p .707 .577 .707 r
F P
0 g
s
.83801 .61451 m .83129 .56623 L .81552 .58273 L p .707 .577 .707 r
F P
0 g
s
.66987 .69409 m .66909 .71303 L .69656 .71689 L p .707 .577 .707 r
F P
0 g
s
.29256 .7917 m .29178 .81064 L .26062 .80821 L p .707 .577 .707 r
F P
0 g
s
.26062 .80821 m .2614 .78927 L .29256 .7917 L p .707 .577 .707 r
F P
0 g
s
.78963 .70018 m .78885 .71912 L .81284 .71651 L p .707 .577 .707 r
F P
0 g
s
.81284 .71651 m .81362 .69757 L .78963 .70018 L p .707 .577 .707 r
F P
0 g
s
.22882 .80744 m .2296 .7885 L .2614 .78927 L p .707 .577 .707 r
F P
0 g
s
.2614 .78927 m .26062 .80821 L .22882 .80744 L p .707 .577 .707 r
F P
0 g
s
.73543 .76639 m .73386 .73061 L .7027 .72923 L p .707 .577 .707 r
F P
0 g
s
.73386 .73061 m .73543 .76639 L .76723 .7641 L p .707 .577 .707 r
F P
0 g
s
.76723 .7641 m .76566 .72832 L .73386 .73061 L p .707 .577 .707 r
F P
0 g
s
.66909 .71303 m .66987 .69409 L .64878 .68918 L p .707 .577 .707 r
F P
0 g
s
.55382 .24316 m .55674 .74303 L .51273 .74045 L p .707 .577 .707 r
F P
0 g
s
.51273 .74045 m .50981 .24057 L .55382 .24316 L p .707 .577 .707 r
F P
0 g
s
.76566 .72832 m .76723 .7641 L .79656 .75836 L p .707 .577 .707 r
F P
0 g
s
.79656 .75836 m .79499 .72258 L .76566 .72832 L p .707 .577 .707 r
F P
0 g
s
.64878 .68918 m .648 .70812 L .66909 .71303 L p .707 .577 .707 r
F P
0 g
s
.65151 .59458 m .65823 .64285 L .67956 .65351 L p .707 .577 .707 r
F P
0 g
s
.70426 .76501 m .7027 .72923 L .67523 .72432 L p .707 .577 .707 r
F P
0 g
s
.7027 .72923 m .70426 .76501 L .73543 .76639 L p .707 .577 .707 r
F P
0 g
s
.46779 .74184 m .46487 .24197 L .50981 .24057 L p .707 .577 .707 r
F P
0 g
s
.83129 .56623 m .83801 .61451 L .8445 .59701 L p .707 .577 .707 r
F P
0 g
s
.8445 .59701 m .83779 .54873 L .83129 .56623 L p .707 .577 .707 r
F P
0 g
s
.50981 .24057 m .51273 .74045 L .46779 .74184 L p .707 .577 .707 r
F P
0 g
s
.79499 .72258 m .79656 .75836 L .82055 .74974 L p .707 .577 .707 r
F P
0 g
s
.81362 .69757 m .81284 .71651 L .82914 .71251 L p .707 .577 .707 r
F P
0 g
s
.82055 .74974 m .81898 .71396 L .79499 .72258 L p .707 .577 .707 r
F P
0 g
s
.82914 .71251 m .82992 .69357 L .81362 .69757 L p .707 .577 .707 r
F P
0 g
s
.67523 .72432 m .67679 .7601 L .70426 .76501 L p .707 .577 .707 r
F P
0 g
s
.67679 .7601 m .67523 .72432 L .65414 .71635 L p .707 .577 .707 r
F P
0 g
s
.81898 .71396 m .82055 .74974 L .83685 .73908 L p .707 .577 .707 r
F P
0 g
s
.82992 .69357 m .82914 .71251 L .83105 .71115 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83528 .7033 L .83114 .70601 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83114 .70601 L .83073 .73049 L .707 .577 .707 r
F
.83528 .7033 m .83685 .73908 L .84386 .72743 L p F P
0 g
s
.83105 .71115 m .83616 .70751 L p .8313 .69664 L .707 .577 .707 r
F P
0 g
s
.8313 .69664 m .82992 .69357 L .83105 .71115 L .707 .577 .707 r
F
.83114 .70601 m .81898 .71396 L p .83073 .73049 L F P
0 g
s
.83779 .54873 m .8445 .59701 L .84107 .58022 L p .707 .578 .707 r
F P
0 g
s
.84107 .58022 m .83436 .53194 L .83779 .54873 L p .707 .578 .707 r
F P
0 g
s
.65414 .71635 m .65571 .75213 L .67679 .7601 L p .707 .577 .707 r
F P
0 g
s
.84386 .72743 m .84229 .69165 L .83528 .7033 L p .707 .577 .707 r
F P
0 g
s
.83616 .70751 m .83694 .68857 L .82992 .69357 L p .707 .577 .707 r
F P
0 g
s
.65571 .75213 m .65414 .71635 L .64149 .70611 L p .707 .577 .707 r
F P
0 g
s
.63536 .70265 m .63614 .68371 L .63318 .67821 L p .707 .577 .707 r
F P
0 g
s
.63318 .67821 m .6324 .69715 L .63536 .70265 L p .707 .577 .707 r
F P
0 g
s
.63507 .56337 m .64179 .61164 L .64522 .62843 L p .707 .578 .707 r
F P
0 g
s
.64179 .61164 m .63507 .56337 L .64156 .54587 L p .707 .577 .707 r
F P
0 g
s
.64149 .70611 m .64306 .74189 L .65571 .75213 L p .707 .577 .707 r
F P
0 g
s
.83436 .53194 m .84107 .58022 L .82806 .5658 L p .707 .577 .707 r
F P
0 g
s
.82806 .5658 m .82134 .51752 L .83436 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83694 .68857 m .83616 .70751 L .8332 .70201 L p .707 .577 .707 r
F P
0 g
s
.8332 .70201 m .83398 .68307 L .83694 .68857 L p .707 .577 .707 r
F P
0 g
s
.64306 .74189 m .64149 .70611 L .63853 .6946 L p .707 .577 .707 r
F P
0 g
s
.64828 .59414 m .64156 .54587 L .65734 .52936 L p .707 .577 .707 r
F P
0 g
s
.64156 .54587 m .64828 .59414 L .64179 .61164 L p .707 .577 .707 r
F P
0 g
s
.6324 .69715 m .63318 .67821 L .64019 .67321 L p .707 .577 .707 r
F P
0 g
s
.63853 .6946 m .6401 .73038 L .64306 .74189 L p .707 .577 .707 r
F P
0 g
s
.84229 .69165 m .84386 .72743 L .8409 .71591 L p .707 .577 .707 r
F P
0 g
s
.8409 .71591 m .83933 .68014 L .84229 .69165 L p .707 .577 .707 r
F P
0 g
s
.64019 .67321 m .63941 .69215 L .6324 .69715 L p .707 .577 .707 r
F P
0 g
s
.82134 .51752 m .82806 .5658 L .80673 .55514 L p .707 .577 .707 r
F P
0 g
s
.80673 .55514 m .80001 .50687 L .82134 .51752 L p .707 .577 .707 r
F P
0 g
s
.39518 .62298 m .38846 .57471 L .35738 .57425 L p .707 .577 .707 r
F P
0 g
s
.42674 .61801 m .42003 .56973 L .38846 .57471 L p .707 .577 .707 r
F P
0 g
s
.42003 .56973 m .42674 .61801 L .4557 .60809 L p .707 .577 .707 r
F P
0 g
s
.3641 .62253 m .35738 .57425 L .32983 .56841 L p .707 .577 .707 r
F P
0 g
s
.35738 .57425 m .3641 .62253 L .39518 .62298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63941 .69215 m .64019 .67321 L .64354 .67239 L p .707 .577 .707 r
F P
0 g
s
.64354 .67239 m .65649 .66921 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .63853 .6946 L .64377 .6859 L p .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .64377 .6859 L .64395 .69685 L .707 .577 .707 r
F
.63941 .69215 m .64354 .67239 L .64377 .68629 L F
.65649 .66921 m .65571 .68815 L .64385 .69106 L p F P
0 g
s
.64385 .69106 m .63941 .69215 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.64377 .68629 m .65649 .66921 L .64385 .69106 L .707 .577 .707 r
F
.64555 .68294 m .64712 .71872 L .64439 .72324 L p F P
0 g
s
.64439 .72324 m .6401 .73038 L p .64395 .69685 L .707 .577 .707 r
F P
0 g
s
.64395 .69685 m .64555 .68294 L .64439 .72324 L .707 .577 .707 r
F
.64377 .6859 m .64555 .68294 L p .64395 .69685 L F P
0 g
s
.44899 .55981 m .4557 .60809 L .47922 .59419 L p .707 .577 .707 r
F P
0 g
s
.47922 .59419 m .47251 .54592 L .44899 .55981 L p .707 .577 .707 r
F P
0 g
s
.83398 .68307 m .8332 .70201 L .82055 .69654 L p .707 .577 .707 r
F P
0 g
s
.82055 .69654 m .82133 .6776 L .83398 .68307 L p .707 .577 .707 r
F P
0 g
s
.65734 .52936 m .66406 .57764 L .64828 .59414 L p .707 .577 .707 r
F P
0 g
s
.66406 .57764 m .65734 .52936 L .68086 .51547 L p .707 .577 .707 r
F P
0 g
s
.80001 .50687 m .80673 .55514 L .77918 .5493 L p .707 .577 .707 r
F P
0 g
s
.77918 .5493 m .77246 .50103 L .80001 .50687 L p .707 .577 .707 r
F P
0 g
s
.38471 .68251 m .38549 .66357 L .35433 .66113 L p .707 .577 .707 r
F P
0 g
s
.38549 .66357 m .38471 .68251 L .41651 .68328 L p .707 .577 .707 r
F P
0 g
s
.41651 .68328 m .41729 .66434 L .38549 .66357 L p .707 .577 .707 r
F P
0 g
s
.35433 .66113 m .35355 .68007 L .38471 .68251 L p .707 .577 .707 r
F P
0 g
s
.33655 .61669 m .32983 .56841 L .3085 .55776 L p .707 .577 .707 r
F P
0 g
s
.32983 .56841 m .33655 .61669 L .3641 .62253 L p .707 .577 .707 r
F P
0 g
s
.35355 .68007 m .35433 .66113 L .32686 .65727 L p .707 .577 .707 r
F P
0 g
s
.83933 .68014 m .8409 .71591 L .82826 .70567 L p .707 .577 .707 r
F P
0 g
s
.82826 .70567 m .82669 .66989 L .83933 .68014 L p .707 .577 .707 r
F P
0 g
s
.47251 .54592 m .47922 .59419 L .495 .57769 L p .707 .577 .707 r
F P
0 g
s
.495 .57769 m .48828 .52941 L .47251 .54592 L p .707 .577 .707 r
F P
0 g
s
.32686 .65727 m .32608 .67621 L .35355 .68007 L p .707 .577 .707 r
F P
0 g
s
.68758 .56375 m .68086 .51547 L .70982 .50555 L p .707 .577 .707 r
F P
0 g
s
.68086 .51547 m .68758 .56375 L .66406 .57764 L p .707 .577 .707 r
F P
0 g
s
.77246 .50103 m .77918 .5493 L .7481 .54885 L p .707 .577 .707 r
F P
0 g
s
.7481 .54885 m .74138 .50057 L .77246 .50103 L p .707 .577 .707 r
F P
0 g
s
.44662 .66337 m .44585 .68231 L .46983 .6797 L p .707 .577 .707 r
F P
0 g
s
.46983 .6797 m .47061 .66076 L .44662 .66337 L p .707 .577 .707 r
F P
0 g
s
.71654 .55383 m .70982 .50555 L .74138 .50057 L p .707 .577 .707 r
F P
0 g
s
.70982 .50555 m .71654 .55383 L .68758 .56375 L p .707 .577 .707 r
F P
0 g
s
.65571 .68815 m .65649 .66921 L .68048 .6666 L p .707 .577 .707 r
F P
0 g
s
.68048 .6666 m .6797 .68553 L .65571 .68815 L p .707 .577 .707 r
F P
0 g
s
.64712 .71872 m .64555 .68294 L .66184 .67228 L p .707 .577 .707 r
F P
0 g
s
.74138 .50057 m .7481 .54885 L .71654 .55383 L p .707 .577 .707 r
F P
0 g
s
.39242 .72957 m .39085 .6938 L .35969 .69242 L p .707 .577 .707 r
F P
0 g
s
.39085 .6938 m .39242 .72957 L .42422 .72728 L p .707 .577 .707 r
F P
0 g
s
.42422 .72728 m .42265 .69151 L .39085 .6938 L p .707 .577 .707 r
F P
0 g
s
.32608 .67621 m .32686 .65727 L .30577 .65237 L p .707 .577 .707 r
F P
0 g
s
.82133 .6776 m .82055 .69654 L .79947 .69163 L p .707 .577 .707 r
F P
0 g
s
.79947 .69163 m .80025 .67269 L .82133 .6776 L p .707 .577 .707 r
F P
0 g
s
.42265 .69151 m .42422 .72728 L .45355 .72155 L p .707 .577 .707 r
F P
0 g
s
.45355 .72155 m .45198 .68577 L .42265 .69151 L p .707 .577 .707 r
F P
0 g
s
.30577 .65237 m .30499 .67131 L .32608 .67621 L p .707 .577 .707 r
F P
0 g
s
.31522 .60604 m .3085 .55776 L .29549 .54334 L p .707 .577 .707 r
F P
0 g
s
.3085 .55776 m .31522 .60604 L .33655 .61669 L p .707 .577 .707 r
F P
0 g
s
.36125 .7282 m .35969 .69242 L .33222 .6875 L p .707 .577 .707 r
F P
0 g
s
.35969 .69242 m .36125 .7282 L .39242 .72957 L p .707 .577 .707 r
F P
0 g
s
.48828 .52941 m .495 .57769 L .50149 .56019 L p .707 .577 .707 r
F P
0 g
s
.50149 .56019 m .49478 .51191 L .48828 .52941 L p .707 .577 .707 r
F P
0 g
s
.82669 .66989 m .82826 .70567 L .80717 .69771 L p .707 .577 .707 r
F P
0 g
s
.80717 .69771 m .8056 .66193 L .82669 .66989 L p .707 .577 .707 r
F P
0 g
s
.66184 .67228 m .66341 .70806 L .64712 .71872 L p .707 .577 .707 r
F P
0 g
s
.45198 .68577 m .45355 .72155 L .47754 .71293 L p .707 .577 .707 r
F P
0 g
s
.47061 .66076 m .46983 .6797 L .48613 .6757 L p .707 .577 .707 r
F P
0 g
s
.47754 .71293 m .47597 .67715 L .45198 .68577 L p .707 .577 .707 r
F P
0 g
s
.48613 .6757 m .48691 .65676 L .47061 .66076 L p .707 .577 .707 r
F P
0 g
s
.33222 .6875 m .33378 .72328 L .36125 .7282 L p .707 .577 .707 r
F P
0 g
s
.33378 .72328 m .33222 .6875 L .31113 .67954 L p .707 .577 .707 r
F P
0 g
s
.30499 .67131 m .30577 .65237 L .29313 .64689 L p .707 .577 .707 r
F P
0 g
s
.80025 .67269 m .79947 .69163 L .772 .68777 L p .707 .577 .707 r
F P
0 g
s
.772 .68777 m .77278 .66883 L .80025 .67269 L p .707 .577 .707 r
F P
0 g
s
.6797 .68553 m .68048 .6666 L .70981 .66563 L p .707 .577 .707 r
F P
0 g
s
.66341 .70806 m .66184 .67228 L .68583 .66366 L p .707 .577 .707 r
F P
0 g
s
.29313 .64689 m .29235 .66583 L .30499 .67131 L p .707 .577 .707 r
F P
0 g
s
.30221 .59161 m .29549 .54334 L .29206 .52655 L p .707 .578 .707 r
F P
0 g
s
.29549 .54334 m .30221 .59161 L .31522 .60604 L p .707 .577 .707 r
F P
0 g
s
.47597 .67715 m .47754 .71293 L .49384 .70227 L p .707 .577 .707 r
F P
0 g
s
.48691 .65676 m .48613 .6757 L .48804 .67433 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .49227 .66649 L .48813 .6692 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .48813 .6692 L .48772 .69367 L .707 .577 .707 r
F
.49227 .66649 m .49384 .70227 L .50085 .69061 L p F P
0 g
s
.48804 .67433 m .49315 .6707 L p .48829 .65983 L .707 .577 .707 r
F P
0 g
s
.48829 .65983 m .48691 .65676 L .48804 .67433 L .707 .577 .707 r
F
.48813 .6692 m .47597 .67715 L p .48772 .69367 L F P
0 g
s
.70981 .66563 m .70903 .68457 L .6797 .68553 L p .707 .577 .707 r
F P
0 g
s
.8056 .66193 m .80717 .69771 L .7797 .69279 L p .707 .577 .707 r
F P
0 g
s
.7797 .69279 m .77813 .65701 L .8056 .66193 L p .707 .577 .707 r
F P
0 g
s
.49478 .51191 m .50149 .56019 L .49806 .54341 L p .707 .578 .707 r
F P
0 g
s
.49806 .54341 m .49135 .49513 L .49478 .51191 L p .707 .578 .707 r
F P
0 g
s
.31113 .67954 m .3127 .71531 L .33378 .72328 L p .707 .577 .707 r
F P
0 g
s
.68583 .66366 m .6874 .69944 L .66341 .70806 L p .707 .577 .707 r
F P
0 g
s
.77278 .66883 m .772 .68777 L .74084 .68534 L p .707 .577 .707 r
F P
0 g
s
.74084 .68534 m .74162 .6664 L .77278 .66883 L p .707 .577 .707 r
F P
0 g
s
.50085 .69061 m .49928 .65483 L .49227 .66649 L p .707 .577 .707 r
F P
0 g
s
.49315 .6707 m .49393 .65176 L .48691 .65676 L p .707 .577 .707 r
F P
0 g
s
.70903 .68457 m .70981 .66563 L .74162 .6664 L p .707 .577 .707 r
F P
0 g
s
.6874 .69944 m .68583 .66366 L .71517 .65792 L p .707 .577 .707 r
F P
0 g
s
.3127 .71531 m .31113 .67954 L .29848 .66929 L p .707 .577 .707 r
F P
0 g
s
.74162 .6664 m .74084 .68534 L .70903 .68457 L p .707 .577 .707 r
F P
0 g
s
.77813 .65701 m .7797 .69279 L .74854 .69141 L p .707 .577 .707 r
F P
0 g
s
.74854 .69141 m .74697 .65563 L .77813 .65701 L p .707 .577 .707 r
F P
0 g
s
.29235 .66583 m .29313 .64689 L .29017 .64139 L p .707 .577 .707 r
F P
0 g
s
.71673 .6937 m .71517 .65792 L .74697 .65563 L p .707 .577 .707 r
F P
0 g
s
.71517 .65792 m .71673 .6937 L .6874 .69944 L p .707 .577 .707 r
F P
0 g
s
.29017 .64139 m .28939 .66033 L .29235 .66583 L p .707 .577 .707 r
F P
0 g
s
.29206 .52655 m .29878 .57483 L .30221 .59161 L p .707 .578 .707 r
F P
0 g
s
.29878 .57483 m .29206 .52655 L .29855 .50905 L p .707 .577 .707 r
F P
0 g
s
.74697 .65563 m .74854 .69141 L .71673 .6937 L p .707 .577 .707 r
F P
0 g
s
.29848 .66929 m .30005 .70507 L .3127 .71531 L p .707 .577 .707 r
F P
0 g
s
.49135 .49513 m .49806 .54341 L .48505 .52898 L p .707 .577 .707 r
F P
0 g
s
.48505 .52898 m .47833 .4807 L .49135 .49513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49393 .65176 m .49315 .6707 L .49019 .66519 L p .707 .577 .707 r
F P
0 g
s
.49019 .66519 m .49097 .64625 L .49393 .65176 L p .707 .577 .707 r
F P
0 g
s
.30005 .70507 m .29848 .66929 L .29552 .65778 L p .707 .577 .707 r
F P
0 g
s
.30527 .55733 m .29855 .50905 L .31433 .49255 L p .707 .577 .707 r
F P
0 g
s
.29855 .50905 m .30527 .55733 L .29878 .57483 L p .707 .577 .707 r
F P
0 g
s
.28939 .66033 m .29017 .64139 L .29718 .63639 L p .707 .577 .707 r
F P
0 g
s
.29552 .65778 m .29709 .69356 L .30005 .70507 L p .707 .577 .707 r
F P
0 g
s
.49928 .65483 m .50085 .69061 L .49789 .6791 L p .707 .577 .707 r
F P
0 g
s
.49789 .6791 m .49632 .64332 L .49928 .65483 L p .707 .577 .707 r
F P
0 g
s
.29718 .63639 m .2964 .65533 L .28939 .66033 L p .707 .577 .707 r
F P
0 g
s
.47833 .4807 m .48505 .52898 L .46372 .51833 L p .707 .577 .707 r
F P
0 g
s
.46372 .51833 m .457 .47005 L .47833 .4807 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2964 .65533 m .29718 .63639 L .30053 .63557 L p .707 .577 .707 r
F P
0 g
s
.30053 .63557 m .31348 .63239 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .29552 .65778 L .30076 .64908 L p .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .30076 .64908 L .30094 .66004 L .707 .577 .707 r
F
.2964 .65533 m .30053 .63557 L .30076 .64948 L F
.31348 .63239 m .3127 .65133 L .30084 .65424 L p F P
0 g
s
.30084 .65424 m .2964 .65533 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.30076 .64948 m .31348 .63239 L .30084 .65424 L .707 .577 .707 r
F
.30254 .64613 m .3041 .6819 L .30138 .68643 L p F P
0 g
s
.30138 .68643 m .29709 .69356 L p .30094 .66004 L .707 .577 .707 r
F P
0 g
s
.30094 .66004 m .30254 .64613 L .30138 .68643 L .707 .577 .707 r
F
.30076 .64908 m .30254 .64613 L p .30094 .66004 L F P
0 g
s
.49097 .64625 m .49019 .66519 L .47754 .65972 L p .707 .577 .707 r
F P
0 g
s
.47754 .65972 m .47832 .64078 L .49097 .64625 L p .707 .577 .707 r
F P
0 g
s
.31433 .49255 m .32105 .54082 L .30527 .55733 L p .707 .577 .707 r
F P
0 g
s
.32105 .54082 m .31433 .49255 L .33785 .47865 L p .707 .577 .707 r
F P
0 g
s
.457 .47005 m .46372 .51833 L .43617 .51249 L p .707 .577 .707 r
F P
0 g
s
.43617 .51249 m .42945 .46421 L .457 .47005 L p .707 .577 .707 r
F P
0 g
s
.49632 .64332 m .49789 .6791 L .48525 .66886 L p .707 .577 .707 r
F P
0 g
s
.48525 .66886 m .48368 .63308 L .49632 .64332 L p .707 .577 .707 r
F P
0 g
s
.34457 .52693 m .33785 .47865 L .36681 .46873 L p .707 .577 .707 r
F P
0 g
s
.33785 .47865 m .34457 .52693 L .32105 .54082 L p .707 .577 .707 r
F P
0 g
s
.42945 .46421 m .43617 .51249 L .40509 .51203 L p .707 .577 .707 r
F P
0 g
s
.40509 .51203 m .39837 .46376 L .42945 .46421 L p .707 .577 .707 r
F P
0 g
s
.37353 .51701 m .36681 .46873 L .39837 .46376 L p .707 .577 .707 r
F P
0 g
s
.36681 .46873 m .37353 .51701 L .34457 .52693 L p .707 .577 .707 r
F P
0 g
s
.3127 .65133 m .31348 .63239 L .33747 .62978 L p .707 .577 .707 r
F P
0 g
s
.33747 .62978 m .33669 .64872 L .3127 .65133 L p .707 .577 .707 r
F P
0 g
s
.3041 .6819 m .30254 .64613 L .31883 .63546 L p .707 .577 .707 r
F P
0 g
s
.39837 .46376 m .40509 .51203 L .37353 .51701 L p .707 .577 .707 r
F P
0 g
s
.47832 .64078 m .47754 .65972 L .45646 .65481 L p .707 .577 .707 r
F P
0 g
s
.45646 .65481 m .45724 .63587 L .47832 .64078 L p .707 .577 .707 r
F P
0 g
s
.48368 .63308 m .48525 .66886 L .46416 .66089 L p .707 .577 .707 r
F P
0 g
s
.46416 .66089 m .46259 .62511 L .48368 .63308 L p .707 .577 .707 r
F P
0 g
s
.31883 .63546 m .3204 .67124 L .3041 .6819 L p .707 .577 .707 r
F P
0 g
s
.45724 .63587 m .45646 .65481 L .42899 .65096 L p .707 .577 .707 r
F P
0 g
s
.42899 .65096 m .42977 .63202 L .45724 .63587 L p .707 .577 .707 r
F P
0 g
s
.33669 .64872 m .33747 .62978 L .3668 .62881 L p .707 .577 .707 r
F P
0 g
s
.3204 .67124 m .31883 .63546 L .34282 .62684 L p .707 .577 .707 r
F P
0 g
s
.3668 .62881 m .36602 .64775 L .33669 .64872 L p .707 .577 .707 r
F P
0 g
s
.46259 .62511 m .46416 .66089 L .43669 .65598 L p .707 .577 .707 r
F P
0 g
s
.43669 .65598 m .43512 .6202 L .46259 .62511 L p .707 .577 .707 r
F P
0 g
s
.34282 .62684 m .34439 .66262 L .3204 .67124 L p .707 .577 .707 r
F P
0 g
s
.42977 .63202 m .42899 .65096 L .39783 .64852 L p .707 .577 .707 r
F P
0 g
s
.39783 .64852 m .39861 .62958 L .42977 .63202 L p .707 .577 .707 r
F P
0 g
s
.36602 .64775 m .3668 .62881 L .39861 .62958 L p .707 .577 .707 r
F P
0 g
s
.34439 .66262 m .34282 .62684 L .37215 .62111 L p .707 .577 .707 r
F P
0 g
s
.39861 .62958 m .39783 .64852 L .36602 .64775 L p .707 .577 .707 r
F P
0 g
s
.43512 .6202 m .43669 .65598 L .40553 .6546 L p .707 .577 .707 r
F P
0 g
s
.40553 .6546 m .40396 .61882 L .43512 .6202 L p .707 .577 .707 r
F P
0 g
s
.37372 .65689 m .37215 .62111 L .40396 .61882 L p .707 .577 .707 r
F P
0 g
s
.37215 .62111 m .37372 .65689 L .34439 .66262 L p .707 .577 .707 r
F P
0 g
s
.40396 .61882 m .40553 .6546 L .37372 .65689 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00O7oo1P000UYF00<005YFFUH02EYF00<005YFFUH015YF2@00OGoo001fOol60008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1U
Ool006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF20000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP000UYF10000UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH000030006
FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00H7oo0P001UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00FWoo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00F7oo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EWoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Ioo`l0
041oo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00011oo`H000AJEP03001JEUYF00IJEP03
001JEP0000<003aoo`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Uoo`00E7oo00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00D005YF
FUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
00002goo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=goo001DOol0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH20003FUH40002
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00009Ool20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02000eOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD0
009JEP03001JEUYF00IJEP8000MJEP<000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000Moo`<000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01@001UYF00<005YFFUH01UYF0P002UYF0P000eYF00@005YFFUH000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF0`0000Eoo`00FUIJEP0000IJEP03
001JEUYF00IJEP8000YJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00@007ooOomoo`8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00035oo`00Dgoo
00<005YF00001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
1000FUIJEUYF0P000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000Woo00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@0
05YFFUH000Moo`03001JEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF009JEP80009JEP05
001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000Ool00000
1eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002moo`00Dgoo00<005YF00001EYF0`0027oo00<005YF00001UYF00<005YFFUH0
1UYF0P002UYF00H005YFFUIJEP00FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
0`00FUH00005FUH00`00Oomoo`08Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH02000FUIJ
EUYF001JEP00FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00004FUH00`00Oomoo`09
Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH01000FUIJEP000eYF00<005YF00000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF008002ioo`00Dgoo00@005YFFUH0009JEP03001oogoo00Yoo`03001JEP0000IJEP03
001JEUYF00IJEP8000YJEP03001JEP0000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000^Ool005=oo`06001JEUYF001JEP003Goo00<005YF00001UYF00<005YFFUH01UYF0P002UYF
0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`9JEP8000ioo`03001JEP0000IJEP03001J
EUYF00IJEP8000QJEP80009JEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
1P004Goo1@001EYF00@005YFFUH002ioo`00E7oo0UYF0P003Woo00<005YF00001UYF00<005YFFUH0
1UYF0P001UYF0P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000L
Ool20003FUH01000FUIJEP00;Woo001DOol2FUH4000<Ool00`00FUH00006FUH30006FUH20004FUH2
0007FUH01@00FUIJEUYF00000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYF0002FUH01@00FUIJEUYF00001eYF00<005YF00000P0087oo0P0000EJEP00FUIJEP0002io
o`00E7oo00AJEP00FUH0009JEP8000Yoo`03001JEP0000EJEPD000EJEP80009JEP800003FUH005YF
00IJEP05001JEUYFFUH00002FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUH0009JEP05001JEUYFFUH00007FUH2000UOol20002FUH2000]Ool005Aoo`04FUH005YF0004
FUH30007Ool00`00FUH00005FUH50005FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH00UYF0P00:Goo00@005YF000002eoo`00E7oo0P000UYF00<005YFFUH00UYF00<0
05YF00000`000goo00<005YF00001EYF2`001UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009J
EP03001JEUYF008002Yoo`<00003FUH007oo02aoo`00E7oo0P000UYF00<005YFFUH00UYF00<005YF
FUH00eYF400015YF00<005YFFUH01EYF0P001UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP<002Yo
o`800005FUH00000FUH0000]Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
15YF00<007ooOol0:Goo00H005YFFUIJEP00FUH2000]Ool005Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0UYF00@005YFFUH002]oo`03001JEUYF00=JEP03001JEP0002eoo`00EGoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUH0000ZOol30005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP8002Yoo`04001J
EUYF0005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001oogoo02Moo`8000=J
EP03001JEUYF00=JEP04001JEUYF000/Ool005Ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH20009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P005goo0`0037oo0P001UYF00<005YF
FUH00UYF00@005YFFUH002aoo`00B7oo3@000Woo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0057oo1@0027oo0`0000=J
EP00FUH01EYF00<005YFFUH00UYF00@005YFFUH002aoo`00A7oo10000UYF00<005YFFUH01UYF00<0
05YF0000100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000UYF0P004Woo1@001Goo0`0015YF00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo0010Ool4
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF1@003Goo2P001eYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo000nOol200000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00@005YFFUIJEQ4000AJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00>goo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH2000015YF000000001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00
>7oo0`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000IJ
EP03001JEUYF00AJEPd000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool0
03Ioo`800003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPD0009JEPL000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF000`Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP00Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF0000<Goo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000bOol0035oo`8000IJEP03001JEUYF
00IJEP04001JEUYFFUHA00000eYF0000000600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`0aOol0031oo`03001J
EP0000IJEP03001JEUYF009JEPP000EJEP8000MJEP@00004FUH000000005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8003Ao
o`00;goo00@005YFFUH000MJEP@000AJEP03001JEUYF00IJEP8000IJEP8000AJEP8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF000f
Ool002ioo`05001JEUYFFUH00005FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH400000goo001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH3000gOol002eoo`03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8003Uoo`00;Goo00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YF
FUH01eYF1`0000AJEP00000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH400000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000kOol002aoo`03001JEUYF00=JEP80
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00=JEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P00?Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF10002EYF00<005YF
FUH00eYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00AJEQP000=JEP03001JEUYF
00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP02FUH600000eYF001JEP06FUH?000nOol002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUH000020003FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30000
0eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40005FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P001EYF00<005YFFUH00UYF0P000goo2@0015YF00<005YFFUH01UYF00<005YF
00000`00>Woo000/Ool01000FUH000000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH00UYF8P000UYF0P000eYF00D005YFFUIJEP00
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Moo`00
;7oo00@005YF000000=JEP03001JEUYF009JEP<000QJEP03001JEUYF009JEPT0009JEP800003FUH0
05YF00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<00003FUH005YF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002000dOol002aoo`04001JEP000003FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF2@002Goo100000=JEP00FUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P000eYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEPX0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo00@005YFFUH000AJEP<0
00=JEPD001Eoo`03001JEP00009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<Goo000/Ool0
1000FUIJEP0015YF00@005YFFUIJEP8001Yoo`03001JEP000080009oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP@0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`04001JEUYF0003FUH200000eYF0000000LOol01000FUH005YF0P001Woo2@0015YF00<005YF
00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP04001JEP000002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000UYF00@005YF000001ioo`06001J
EUYFFUH005YF0`0000=oo`0000000eYF00D005YFFUH005YF01`000=JEP06001JEUYFFUH005YF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF001JEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool01000FUH005YF0`0087oo0P000UYF00<005YF
FUH00UYF1P0000IJEP00000005YF0005FUH50006FUH01000FUIJEUYF1@001EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`03001JEP000080029oo`80009JEP03
001JEUYF00=JEP04001JEUYFFUH90003FUH500000eYF000000070003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUH005YF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01000FUH005YF0`0087oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF20002Goo200015YF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool3000015YF001JEUYF0P007Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF2@005Woo1P0015YF00<005YFFUH0
0P00;Goo000]Ool20002FUH00`00FUIJEP02FUH5000HOol30002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001JEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF6@000eYF0`0000=JEP00
FUH00UYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP07FUHI00001EYF001JEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P000eYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP0D
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00Oomoo`0[
Ool002eoo`80009JEP03001JEUYF01AJEP03001JEUYF00IJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000UYF2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF0000
05YF00@002eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF1000
1Woo2@0015YF00<005YFFUH00`000eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEP00
02eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00X005YFFUIJEP00FUH005YF001JEP<0009o
o`03001JEUYF0080009JEP800003Ool0000001/00003FUH005YF00=JEP03001JEP0002eoo`00;Woo
00@005YFFUH001IJEP<000IJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00UYF0`0000EJEP00001JEP00
009JEP03001oogoo00Eoo`D000]oo`<000EJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@0
05YFFUH001EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUH0000300000eYF000000020006Ool5
0007Ool400000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000]Ool002ioo`04001JEUYF000E
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00Oomoo`0@0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH00eYF5`001EYF00<005YFFUH015YF00D005YFFUIooeYF0080
02ioo`00;goo00<005YF00005EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001Goo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUIo
o`02000^Ool0031oo`03001JEP0000AJEP03001JEUYF00iJEP<000IJEP03001JEUYF00IJEP03001J
EUYF008000Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000;goo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUHF
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YFFUIJEP0002moo`00<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P002goo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01P00
2UYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF000`Ool003=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF009JEP8000eoo`03001JEP0000IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
035oo`00=Goo0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
3goo00<005YF00001UYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000cOol003Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP@0019oo`03001JEP0000IJEP@00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00003000eOol003aoo`T000AJEP03001JEUYF00@001Ioo`03001JEP00
00AJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP@000EJEP06001JEUYFFUH005YF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`00>Goo0015Ool7000JOol00`00FUH00002FUH20007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00
FUIJEUYF000015YF00D005YFFUIJEP0000=JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@003aoo`00IWoo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
00D005YFFUIJEP0000MJEQX0041oo`00IWoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF00000eYF00<005YFFUH015YF00<007ooOol0F7oo0018Ool3000KOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP02FUH2001KOol004Moo`D001Yoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYF001MOol004Moo`D001Yo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP<005ioo`00Agoo1@006Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000eYF0P00H7oo0018Ool3000KOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF00000000HWoo000fOolI000HOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001UOol0031oo`H0009JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP0011oo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001oogoo06Eoo`00;Goo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]oo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP8006Moo`00:goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002Goo0`001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Uoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000006]oo`00:goo00<0
05YF00000eYF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00Uoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP@006eoo`00:goo00<005YF00000UYF1@006Goo200015YF00<005YFFUH00eYF00@0
05YFFUIJEP8000Yoo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00H0071oo`00:goo00<005YF00000P0000AJEP000000029oo`L000=JEP04001J
EUYFFUH2000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool5
001_Ool002]oo`80009JEP03001JEUYF009JEPD002Aoo`@000=JEP8001Aoo``000IJEP03001JEUYF
00YJEP03001JEUYF00H000Moo`D006moo`00:goo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
01Uoo`P00003FUH00000021ooaH000eoo`D006moo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF009JEQT000=JEP03001JEUYF009JEP<0035ooaT006eoo`00;Goo0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00:goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000IGoo
000_Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000XOol30002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00Ggoo000bOol70004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000XOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002001LOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH6000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001IOol0049ooaT0035oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP00008005Ioo`00S7oo00<005YF000015YF00@005YFFUIJEQl0
00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP00009JEPH001moo`@0009J
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP0000<0009JEPL001moo`D000=J
EP03001JEUYF008005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT001Uoo`H0009J
EP8005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF
00<005YFFUH01000EWoo002=Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002?Ool4
0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0005Ioo`00Tgoo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8005Moo`00UWoo1@000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000005Uo
o`00Vgoo4@0015YF00<005YFFUH00UYF3@00Fgoo002/Ool9001XOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59737 .79074 m .5964 .75442 L .56748 .75296 L p .707 .577 .707 r
F P
0 g
s
.56748 .75296 m .56523 .75285 L p .56984 .75828 L .707 .577 .707 r
F P
0 g
s
.59737 .79074 m .56748 .75296 L .56984 .75828 L .707 .577 .707 r
F
.5662 .78916 m .56523 .75285 L .53964 .74845 L p F P
0 g
s
.53964 .74845 m .53777 .74813 L p .54127 .75317 L .707 .577 .707 r
F P
0 g
s
.5662 .78916 m .53964 .74845 L .54127 .75317 L .707 .577 .707 r
F
.53777 .74813 m .53874 .78445 L .5662 .78916 L p F P
0 g
s
.53874 .78445 m .53777 .74813 L .51802 .7412 L p .707 .577 .707 r
F P
0 g
s
.51802 .7412 m .5167 .74073 L p .51882 .74494 L .707 .577 .707 r
F P
0 g
s
.53874 .78445 m .51802 .7412 L .51882 .74494 L .707 .577 .707 r
F
.5167 .74073 m .51767 .77705 L .53874 .78445 L p F P
0 g
s
.51767 .77705 m .5167 .74073 L .5047 .73184 L p .707 .577 .707 r
F P
0 g
s
.5047 .73184 m .50409 .73138 L p .50494 .73425 L .707 .577 .707 r
F P
0 g
s
.51767 .77705 m .5047 .73184 L .50494 .73425 L .707 .577 .707 r
F
.50409 .73138 m .50506 .7677 L .51767 .77705 L p F P
0 g
s
.50506 .7677 m .50409 .73138 L .50123 .72121 L p .707 .577 .707 r
F P
0 g
s
.50123 .72121 m .50117 .72099 L p .50126 .72204 L .707 .577 .707 r
F P
0 g
s
.50506 .7677 m .50123 .72121 L .50126 .72204 L .707 .577 .707 r
F
.50618 .75189 m .50388 .72354 L p .49888 .68643 L F P
0 g
s
.50388 .72354 m .50199 .7002 L .50123 .69684 L p .707 .577 .707 r
F P
0 g
s
.50123 .69684 m .49888 .68643 L p .50388 .72354 L .707 .577 .707 r
F P
0 g
s
.51894 .76393 m .51653 .73427 L p .50199 .7002 L .707 .577 .707 r
F P
0 g
s
.51104 .70874 m .50199 .7002 L p .51653 .73427 L .707 .577 .707 r
F P
0 g
s
.50199 .7002 m .50618 .75189 L .51894 .76393 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50618 .75189 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.49888 .68643 m .50091 .71142 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50091 .71142 m .50308 .73812 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50117 .72099 m .50214 .75731 L .50506 .7677 L p .707 .577 .707 r
F P
0 g
s
.50214 .75731 m .50117 .72099 L .5016 .72036 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50091 .71142 L p .50574 .67226 L .707 .577 .707 r
F P
0 g
s
.50574 .67226 m .50792 .69908 L p .50308 .73812 L .707 .577 .707 r
F P
0 g
s
.51653 .73427 m .51474 .71224 L .51104 .70874 L p .707 .577 .707 r
F P
0 g
s
.5401 .77305 m .53762 .74255 L p .51474 .71224 L .707 .577 .707 r
F P
0 g
s
.52938 .71855 m .51474 .71224 L p .53762 .74255 L .707 .577 .707 r
F P
0 g
s
.51474 .71224 m .51894 .76393 L .5401 .77305 L p .707 .577 .707 r
F P
0 g
s
.50863 .71035 m .52457 .70116 L p .51067 .7425 L .707 .577 .707 r
F P
0 g
s
.50792 .69908 m .50994 .72395 L .50955 .72476 L p .707 .577 .707 r
F P
0 g
s
.50955 .72476 m .50308 .73812 L p .50792 .69908 L .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50822 .71058 L .50863 .71035 L p .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50863 .71035 L .51067 .7425 L .707 .577 .707 r
F
.5016 .72036 m .50822 .71058 L p .50358 .74626 L F P
0 g
s
.50214 .75731 m .5016 .72036 L .50358 .74626 L .707 .577 .707 r
F
.50091 .71142 m .49888 .68643 L .50003 .68406 L p F P
0 g
s
.50003 .68406 m .50574 .67226 L p .50091 .71142 L .707 .577 .707 r
F P
0 g
s
.53762 .74255 m .5359 .72136 L .52938 .71855 L p .707 .577 .707 r
F P
0 g
s
.56523 .75285 m .5662 .78916 L .59737 .79074 L p .707 .577 .707 r
F P
0 g
s
.56759 .77836 m .56509 .74758 L p .5359 .72136 L .707 .577 .707 r
F P
0 g
s
.56509 .74758 m .56339 .72667 L .55511 .72507 L p .707 .577 .707 r
F P
0 g
s
.55511 .72507 m .5359 .72136 L p .56509 .74758 L .707 .577 .707 r
F P
0 g
s
.5964 .75442 m .59737 .79074 L .61576 .78975 L p .707 .577 .707 r
F P
0 g
s
.61576 .78975 m .62919 .78902 L p .60145 .75975 L .707 .577 .707 r
F P
0 g
s
.60145 .75975 m .5964 .75442 L .61576 .78975 L .707 .577 .707 r
F
.62919 .78902 m .62822 .7527 L .5964 .75442 L p F P
0 g
s
.59873 .77935 m .59625 .74885 L p .56339 .72667 L .707 .577 .707 r
F P
0 g
s
.59625 .74885 m .59453 .72765 L .58601 .72738 L p .707 .577 .707 r
F P
0 g
s
.58601 .72738 m .56339 .72667 L p .59625 .74885 L .707 .577 .707 r
F P
0 g
s
.62822 .7527 m .62919 .78902 L .6449 .78643 L p .707 .577 .707 r
F P
0 g
s
.6449 .78643 m .65856 .78418 L p .63271 .75736 L .707 .577 .707 r
F P
0 g
s
.63271 .75736 m .62822 .7527 L .6449 .78643 L .707 .577 .707 r
F
.65856 .78418 m .65759 .74786 L .62822 .7527 L p F P
0 g
s
.63046 .7759 m .62805 .74624 L p .59453 .72765 L .707 .577 .707 r
F P
0 g
s
.62805 .74624 m .62626 .72421 L .61914 .72498 L p .707 .577 .707 r
F P
0 g
s
.61914 .72498 m .59453 .72765 L p .62805 .74624 L .707 .577 .707 r
F P
0 g
s
.59453 .72765 m .59873 .77935 L .63046 .7759 L p .707 .577 .707 r
F P
0 g
s
.65759 .74786 m .65856 .78418 L .66908 .78089 L p .707 .577 .707 r
F P
0 g
s
.66908 .78089 m .68258 .77668 L p .66063 .75136 L .707 .577 .707 r
F P
0 g
s
.66063 .75136 m .65759 .74786 L .66908 .78089 L .707 .577 .707 r
F
.68258 .77668 m .68161 .74036 L .65759 .74786 L p F P
0 g
s
.65968 .76837 m .65738 .74002 L p .62626 .72421 L .707 .577 .707 r
F P
0 g
s
.65738 .74002 m .65548 .71668 L .65102 .71783 L p .707 .577 .707 r
F P
0 g
s
.65102 .71783 m .62626 .72421 L p .65738 .74002 L .707 .577 .707 r
F P
0 g
s
.62626 .72421 m .63046 .7759 L .65968 .76837 L p .707 .577 .707 r
F P
0 g
s
.56339 .72667 m .56759 .77836 L .59873 .77935 L p .707 .577 .707 r
F P
0 g
s
.68161 .74036 m .68258 .77668 L .68734 .77394 L p .707 .577 .707 r
F P
0 g
s
.68734 .77394 m .69893 .76726 L p .68298 .74248 L .707 .577 .707 r
F P
0 g
s
.68298 .74248 m .68161 .74036 L .68734 .77394 L .707 .577 .707 r
F
.69893 .76726 m .69796 .73094 L .68161 .74036 L p F P
0 g
s
.68352 .75749 m .68136 .73078 L p .65548 .71668 L .707 .577 .707 r
F P
0 g
s
.68136 .73078 m .67933 .70579 L .67798 .70641 L p .707 .577 .707 r
F P
0 g
s
.67798 .70641 m .65548 .71668 L p .68136 .73078 L .707 .577 .707 r
F P
0 g
s
.65548 .71668 m .65968 .76837 L .68352 .75749 L p .707 .577 .707 r
F P
0 g
s
.5359 .72136 m .5401 .77305 L .56759 .77836 L p .707 .577 .707 r
F P
0 g
s
.59261 .86861 m .59309 .8498 L .56192 .84758 L p .707 .577 .707 r
F P
0 g
s
.59309 .8498 m .59261 .86861 L .62443 .86879 L p .707 .577 .707 r
F P
0 g
s
.62443 .86879 m .62491 .84998 L .59309 .8498 L p .707 .577 .707 r
F P
0 g
s
.69796 .73094 m .69893 .76726 L .69966 .76618 L p .707 .577 .707 r
F P
0 g
s
.69875 .74506 m .69967 .74432 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69817 .73164 m .69796 .73094 L .69966 .76618 L .707 .577 .707 r
F
.69547 .69262 m .67933 .70579 L p .69863 .74236 L F P
0 g
s
.69967 .74432 m .69765 .71944 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69813 .73068 m .69796 .73094 L p .69817 .73164 L .707 .577 .707 r
F P
0 g
s
.69765 .71944 m .69547 .69262 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69547 .69262 m .69967 .74432 L .70652 .73015 L p .707 .577 .707 r
F P
0 g
s
.70652 .73015 m .70233 .67846 L .69547 .69262 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .70501 .72053 L .69813 .73068 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .69813 .73068 L .69817 .73164 L .707 .577 .707 r
F
.69966 .76618 m .70598 .75685 L p .69817 .73164 L F P
0 g
s
.67933 .70579 m .68352 .75749 L .69875 .74506 L p .707 .577 .707 r
F P
0 g
s
.69863 .74236 m .67933 .70579 L .69875 .74506 L .707 .577 .707 r
F
.62491 .84998 m .62443 .86879 L .65379 .86689 L p F P
0 g
s
.65379 .86689 m .65428 .84808 L .62491 .84998 L p .707 .577 .707 r
F P
0 g
s
.56192 .84758 m .56144 .86638 L .59261 .86861 L p .707 .577 .707 r
F P
0 g
s
.56144 .86638 m .56192 .84758 L .53446 .84351 L p .707 .577 .707 r
F P
0 g
s
.53446 .84351 m .53398 .86232 L .56144 .86638 L p .707 .577 .707 r
F P
0 g
s
.65428 .84808 m .65379 .86689 L .67782 .86311 L p .707 .577 .707 r
F P
0 g
s
.67782 .86311 m .67831 .8443 L .65428 .84808 L p .707 .577 .707 r
F P
0 g
s
.53398 .86232 m .53446 .84351 L .51339 .83801 L p .707 .577 .707 r
F P
0 g
s
.51339 .83801 m .51291 .85682 L .53398 .86232 L p .707 .577 .707 r
F P
0 g
s
.67831 .8443 m .67782 .86311 L .69417 .85782 L p .707 .577 .707 r
F P
0 g
s
.69417 .85782 m .69465 .83901 L .67831 .8443 L p .707 .577 .707 r
F P
0 g
s
.51291 .85682 m .51339 .83801 L .50078 .83161 L p .707 .577 .707 r
F P
0 g
s
.50078 .83161 m .5003 .85042 L .51291 .85682 L p .707 .577 .707 r
F P
0 g
s
.70501 .72053 m .70598 .75685 L .70306 .74646 L p .707 .577 .707 r
F P
0 g
s
.70306 .74646 m .70209 .71014 L .70501 .72053 L p .707 .577 .707 r
F P
0 g
s
.70233 .67846 m .70652 .73015 L .70342 .71637 L p .707 .577 .707 r
F P
0 g
s
.70342 .71637 m .69923 .66468 L .70233 .67846 L p .707 .577 .707 r
F P
0 g
s
.69465 .83901 m .69417 .85782 L .70122 .85153 L p .707 .577 .707 r
F P
0 g
s
.70122 .85153 m .7017 .83272 L .69465 .83901 L p .707 .577 .707 r
F P
0 g
s
.4924 .82174 m .4906 .32109 L .44659 .31847 L p .707 .577 .707 r
F P
0 g
s
.50994 .72395 m .50574 .67226 L .52188 .65909 L p .707 .577 .707 r
F P
0 g
s
.50822 .71058 m .5092 .7469 L .50214 .75731 L p .707 .577 .707 r
F P
0 g
s
.5003 .85042 m .50078 .83161 L .49786 .82494 L p .707 .577 .707 r
F P
0 g
s
.49786 .82494 m .49738 .84375 L .5003 .85042 L p .707 .577 .707 r
F P
0 g
s
.49738 .84375 m .49786 .82494 L .50492 .81865 L p .707 .577 .707 r
F P
0 g
s
.50492 .81865 m .50443 .83745 L .49738 .84375 L p .707 .577 .707 r
F P
0 g
s
.52457 .70116 m .52554 .73748 L .5092 .7469 L p .707 .577 .707 r
F P
0 g
s
.52554 .73748 m .52457 .70116 L .54859 .69367 L p .707 .577 .707 r
F P
0 g
s
.52188 .65909 m .52608 .71078 L .50994 .72395 L p .707 .577 .707 r
F P
0 g
s
.52608 .71078 m .52188 .65909 L .54573 .64821 L p .707 .577 .707 r
F P
0 g
s
.50443 .83745 m .50492 .81865 L .52126 .81335 L p .707 .577 .707 r
F P
0 g
s
.54859 .69367 m .54957 .72998 L .52554 .73748 L p .707 .577 .707 r
F P
0 g
s
.54957 .72998 m .54859 .69367 L .57796 .68882 L p .707 .577 .707 r
F P
0 g
s
.54573 .64821 m .54993 .6999 L .52608 .71078 L p .707 .577 .707 r
F P
0 g
s
.52126 .81335 m .52078 .83216 L .50443 .83745 L p .707 .577 .707 r
F P
0 g
s
.52078 .83216 m .52126 .81335 L .54529 .80957 L p .707 .577 .707 r
F P
0 g
s
.54529 .80957 m .5448 .82838 L .52078 .83216 L p .707 .577 .707 r
F P
0 g
s
.4906 .32109 m .4924 .82174 L .53735 .82046 L p .707 .577 .707 r
F P
0 g
s
.53735 .82046 m .53554 .3198 L .4906 .32109 L p .707 .577 .707 r
F P
0 g
s
.54993 .6999 m .54573 .64821 L .57495 .64067 L p .707 .577 .707 r
F P
0 g
s
.57893 .72514 m .57796 .68882 L .60978 .6871 L p .707 .577 .707 r
F P
0 g
s
.57796 .68882 m .57893 .72514 L .54957 .72998 L p .707 .577 .707 r
F P
0 g
s
.57495 .64067 m .57915 .69237 L .54993 .6999 L p .707 .577 .707 r
F P
0 g
s
.5448 .82838 m .54529 .80957 L .57465 .80768 L p .707 .577 .707 r
F P
0 g
s
.57465 .80768 m .57417 .82648 L .5448 .82838 L p .707 .577 .707 r
F P
0 g
s
.57417 .82648 m .57465 .80768 L .60647 .80785 L p .707 .577 .707 r
F P
0 g
s
.53554 .3198 m .53735 .82046 L .57883 .8154 L p .707 .577 .707 r
F P
0 g
s
.57915 .69237 m .57495 .64067 L .60668 .63723 L p .707 .577 .707 r
F P
0 g
s
.57883 .8154 m .57702 .31475 L .53554 .3198 L p .707 .577 .707 r
F P
0 g
s
.44839 .81912 m .44659 .31847 L .40782 .3122 L p .707 .577 .707 r
F P
0 g
s
.44659 .31847 m .44839 .81912 L .4924 .82174 L p .707 .577 .707 r
F P
0 g
s
.70209 .71014 m .70306 .74646 L .69045 .73711 L p .707 .577 .707 r
F P
0 g
s
.69045 .73711 m .68948 .70079 L .70209 .71014 L p .707 .577 .707 r
F P
0 g
s
.69923 .66468 m .70342 .71637 L .69067 .70434 L p .707 .577 .707 r
F P
0 g
s
.69067 .70434 m .68647 .65264 L .69923 .66468 L p .707 .577 .707 r
F P
0 g
s
.61075 .72342 m .60978 .6871 L .64095 .68868 L p .707 .577 .707 r
F P
0 g
s
.60978 .6871 m .61075 .72342 L .57893 .72514 L p .707 .577 .707 r
F P
0 g
s
.60668 .63723 m .61088 .68892 L .57915 .69237 L p .707 .577 .707 r
F P
0 g
s
.60599 .82666 m .60647 .80785 L .63764 .81008 L p .707 .577 .707 r
F P
0 g
s
.60647 .80785 m .60599 .82666 L .57417 .82648 L p .707 .577 .707 r
F P
0 g
s
.57702 .31475 m .57883 .8154 L .61278 .80707 L p .707 .577 .707 r
F P
0 g
s
.64192 .725 m .64095 .68868 L .66841 .69339 L p .707 .577 .707 r
F P
0 g
s
.64095 .68868 m .64192 .725 L .61075 .72342 L p .707 .577 .707 r
F P
0 g
s
.63782 .63821 m .64201 .6899 L .61088 .68892 L p .707 .577 .707 r
F P
0 g
s
.61088 .68892 m .60668 .63723 L .63782 .63821 L p .707 .577 .707 r
F P
0 g
s
.61278 .80707 m .61098 .30641 L .57702 .31475 L p .707 .577 .707 r
F P
0 g
s
.7017 .83272 m .70122 .85153 L .6983 .84485 L p .707 .577 .707 r
F P
0 g
s
.6983 .84485 m .69878 .82605 L .7017 .83272 L p .707 .577 .707 r
F P
0 g
s
.40963 .81286 m .40782 .3122 L .3781 .30291 L p .707 .577 .707 r
F P
0 g
s
.40782 .3122 m .40963 .81286 L .44839 .81912 L p .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .25339 .71761 L .22447 .71614 L p .707 .577 .707 r
F P
0 g
s
.22447 .71614 m .22222 .71603 L p .22683 .72146 L .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .22447 .71614 L .22683 .72146 L .707 .577 .707 r
F
.22319 .75235 m .22222 .71603 L .19664 .71164 L p F P
0 g
s
.19664 .71164 m .19476 .71131 L p .19826 .71636 L .707 .577 .707 r
F P
0 g
s
.22319 .75235 m .19664 .71164 L .19826 .71636 L .707 .577 .707 r
F
.19476 .71131 m .19573 .74763 L .22319 .75235 L p F P
0 g
s
.19573 .74763 m .19476 .71131 L .17501 .70438 L p .707 .577 .707 r
F P
0 g
s
.17501 .70438 m .17369 .70392 L p .17581 .70813 L .707 .577 .707 r
F P
0 g
s
.19573 .74763 m .17501 .70438 L .17581 .70813 L .707 .577 .707 r
F
.17369 .70392 m .17466 .74024 L .19573 .74763 L p F P
0 g
s
.17466 .74024 m .17369 .70392 L .16169 .69502 L p .707 .577 .707 r
F P
0 g
s
.16169 .69502 m .16108 .69457 L p .16193 .69744 L .707 .577 .707 r
F P
0 g
s
.17466 .74024 m .16169 .69502 L .16193 .69744 L .707 .577 .707 r
F
.16108 .69457 m .16205 .73089 L .17466 .74024 L p F P
0 g
s
.16205 .73089 m .16108 .69457 L .15822 .68439 L p .707 .577 .707 r
F P
0 g
s
.15822 .68439 m .15816 .68418 L p .15825 .68522 L .707 .577 .707 r
F P
0 g
s
.16205 .73089 m .15822 .68439 L .15825 .68522 L .707 .577 .707 r
F
.16317 .71508 m .16087 .68673 L p .15588 .64961 L F P
0 g
s
.16087 .68673 m .15898 .66339 L .15822 .66002 L p .707 .577 .707 r
F P
0 g
s
.15822 .66002 m .15588 .64961 L p .16087 .68673 L .707 .577 .707 r
F P
0 g
s
.17593 .72712 m .17352 .69746 L p .15898 .66339 L .707 .577 .707 r
F P
0 g
s
.16803 .67193 m .15898 .66339 L p .17352 .69746 L .707 .577 .707 r
F P
0 g
s
.15898 .66339 m .16317 .71508 L .17593 .72712 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .16317 .71508 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15588 .64961 m .1579 .6746 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.1579 .6746 m .16007 .7013 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15816 .68418 m .15913 .7205 L .16205 .73089 L p .707 .577 .707 r
F P
0 g
s
.15913 .7205 m .15816 .68418 L .15859 .68355 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .1579 .6746 L p .16273 .63544 L .707 .577 .707 r
F P
0 g
s
.16273 .63544 m .16491 .66226 L p .16007 .7013 L .707 .577 .707 r
F P
0 g
s
.17352 .69746 m .17173 .67542 L .16803 .67193 L p .707 .577 .707 r
F P
0 g
s
.19709 .73624 m .19461 .70574 L p .17173 .67542 L .707 .577 .707 r
F P
0 g
s
.18637 .68174 m .17173 .67542 L p .19461 .70574 L .707 .577 .707 r
F P
0 g
s
.17173 .67542 m .17593 .72712 L .19709 .73624 L p .707 .577 .707 r
F P
0 g
s
.16562 .67353 m .18156 .66435 L p .16766 .70569 L .707 .577 .707 r
F P
0 g
s
.16491 .66226 m .16693 .68714 L .16654 .68794 L p .707 .577 .707 r
F P
0 g
s
.16654 .68794 m .16007 .7013 L p .16491 .66226 L .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16522 .67376 L .16562 .67353 L p .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16562 .67353 L .16766 .70569 L .707 .577 .707 r
F
.15859 .68355 m .16522 .67376 L p .16057 .70944 L F P
0 g
s
.15913 .7205 m .15859 .68355 L .16057 .70944 L .707 .577 .707 r
F
.1579 .6746 m .15588 .64961 L .15702 .64725 L p F P
0 g
s
.15702 .64725 m .16273 .63544 L p .1579 .6746 L .707 .577 .707 r
F P
0 g
s
.19461 .70574 m .19289 .68454 L .18637 .68174 L p .707 .577 .707 r
F P
0 g
s
.22222 .71603 m .22319 .75235 L .25436 .75393 L p .707 .577 .707 r
F P
0 g
s
.22458 .74155 m .22208 .71076 L p .19289 .68454 L .707 .577 .707 r
F P
0 g
s
.22208 .71076 m .22039 .68986 L .2121 .68826 L p .707 .577 .707 r
F P
0 g
s
.2121 .68826 m .19289 .68454 L p .22208 .71076 L .707 .577 .707 r
F P
0 g
s
.25339 .71761 m .25436 .75393 L .27275 .75293 L p .707 .577 .707 r
F P
0 g
s
.27275 .75293 m .28618 .75221 L p .25844 .72294 L .707 .577 .707 r
F P
0 g
s
.25844 .72294 m .25339 .71761 L .27275 .75293 L .707 .577 .707 r
F
.28618 .75221 m .28521 .71589 L .25339 .71761 L p F P
0 g
s
.25572 .74253 m .25324 .71203 L p .22039 .68986 L .707 .577 .707 r
F P
0 g
s
.25324 .71203 m .25152 .69084 L .24301 .69057 L p .707 .577 .707 r
F P
0 g
s
.24301 .69057 m .22039 .68986 L p .25324 .71203 L .707 .577 .707 r
F P
0 g
s
.28521 .71589 m .28618 .75221 L .30189 .74961 L p .707 .577 .707 r
F P
0 g
s
.30189 .74961 m .31555 .74736 L p .2897 .72055 L .707 .577 .707 r
F P
0 g
s
.2897 .72055 m .28521 .71589 L .30189 .74961 L .707 .577 .707 r
F
.31555 .74736 m .31458 .71104 L .28521 .71589 L p F P
0 g
s
.28745 .73909 m .28504 .70943 L p .25152 .69084 L .707 .577 .707 r
F P
0 g
s
.28504 .70943 m .28325 .68739 L .27613 .68817 L p .707 .577 .707 r
F P
0 g
s
.27613 .68817 m .25152 .69084 L p .28504 .70943 L .707 .577 .707 r
F P
0 g
s
.25152 .69084 m .25572 .74253 L .28745 .73909 L p .707 .577 .707 r
F P
0 g
s
.31458 .71104 m .31555 .74736 L .32608 .74408 L p .707 .577 .707 r
F P
0 g
s
.32608 .74408 m .33958 .73986 L p .31762 .71455 L .707 .577 .707 r
F P
0 g
s
.31762 .71455 m .31458 .71104 L .32608 .74408 L .707 .577 .707 r
F
.33958 .73986 m .33861 .70355 L .31458 .71104 L p F P
0 g
s
.31667 .73155 m .31437 .7032 L p .28325 .68739 L .707 .577 .707 r
F P
0 g
s
.31437 .7032 m .31247 .67986 L .30801 .68101 L p .707 .577 .707 r
F P
0 g
s
.30801 .68101 m .28325 .68739 L p .31437 .7032 L .707 .577 .707 r
F P
0 g
s
.28325 .68739 m .28745 .73909 L .31667 .73155 L p .707 .577 .707 r
F P
0 g
s
.68948 .70079 m .69045 .73711 L .66938 .72971 L p .707 .577 .707 r
F P
0 g
s
.66938 .72971 m .66841 .69339 L .68948 .70079 L p .707 .577 .707 r
F P
0 g
s
.68647 .65264 m .69067 .70434 L .66951 .69522 L p .707 .577 .707 r
F P
0 g
s
.66951 .69522 m .66531 .64352 L .68647 .65264 L p .707 .577 .707 r
F P
0 g
s
.22039 .68986 m .22458 .74155 L .25572 .74253 L p .707 .577 .707 r
F P
0 g
s
.33861 .70355 m .33958 .73986 L .34433 .73712 L p .707 .577 .707 r
F P
0 g
s
.34433 .73712 m .35592 .73045 L p .33997 .70567 L .707 .577 .707 r
F P
0 g
s
.33997 .70567 m .33861 .70355 L .34433 .73712 L .707 .577 .707 r
F
.35592 .73045 m .35495 .69413 L .33861 .70355 L p F P
0 g
s
.34052 .72067 m .33835 .69397 L p .31247 .67986 L .707 .577 .707 r
F P
0 g
s
.33835 .69397 m .33632 .66898 L .33497 .66959 L p .707 .577 .707 r
F P
0 g
s
.33497 .66959 m .31247 .67986 L p .33835 .69397 L .707 .577 .707 r
F P
0 g
s
.31247 .67986 m .31667 .73155 L .34052 .72067 L p .707 .577 .707 r
F P
0 g
s
.61098 .30641 m .61278 .80707 L .63589 .79626 L p .707 .577 .707 r
F P
0 g
s
.63589 .79626 m .63409 .29561 L .61098 .30641 L p .707 .577 .707 r
F P
0 g
s
.19289 .68454 m .19709 .73624 L .22458 .74155 L p .707 .577 .707 r
F P
0 g
s
.69878 .82605 m .6983 .84485 L .68569 .83845 L p .707 .577 .707 r
F P
0 g
s
.68569 .83845 m .68617 .81964 L .69878 .82605 L p .707 .577 .707 r
F P
0 g
s
.66841 .69339 m .66938 .72971 L .64192 .725 L p .707 .577 .707 r
F P
0 g
s
.66531 .64352 m .66951 .69522 L .64201 .6899 L p .707 .577 .707 r
F P
0 g
s
.64201 .6899 m .63782 .63821 L .66531 .64352 L p .707 .577 .707 r
F P
0 g
s
.3799 .80356 m .3781 .30291 L .36032 .29149 L p .707 .577 .707 r
F P
0 g
s
.3781 .30291 m .3799 .80356 L .40963 .81286 L p .707 .577 .707 r
F P
0 g
s
.2496 .8318 m .25008 .81299 L .21891 .81076 L p .707 .577 .707 r
F P
0 g
s
.25008 .81299 m .2496 .8318 L .28142 .83197 L p .707 .577 .707 r
F P
0 g
s
.28142 .83197 m .2819 .81317 L .25008 .81299 L p .707 .577 .707 r
F P
0 g
s
.35495 .69413 m .35592 .73045 L .35665 .72937 L p .707 .577 .707 r
F P
0 g
s
.35574 .70825 m .35666 .7075 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35516 .69483 m .35495 .69413 L .35665 .72937 L .707 .577 .707 r
F
.35246 .65581 m .33632 .66898 L p .35562 .70554 L F P
0 g
s
.35666 .7075 m .35464 .68263 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35512 .69387 m .35495 .69413 L p .35516 .69483 L .707 .577 .707 r
F P
0 g
s
.35464 .68263 m .35246 .65581 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35246 .65581 m .35666 .7075 L .36351 .69334 L p .707 .577 .707 r
F P
0 g
s
.36351 .69334 m .35932 .64164 L .35246 .65581 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .362 .68372 L .35512 .69387 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .35512 .69387 L .35516 .69483 L .707 .577 .707 r
F
.35665 .72937 m .36297 .72003 L p .35516 .69483 L F P
0 g
s
.33632 .66898 m .34052 .72067 L .35574 .70825 L p .707 .577 .707 r
F P
0 g
s
.35562 .70554 m .33632 .66898 L .35574 .70825 L .707 .577 .707 r
F
.2819 .81317 m .28142 .83197 L .31079 .83008 L p F P
0 g
s
.31079 .83008 m .31127 .81127 L .2819 .81317 L p .707 .577 .707 r
F P
0 g
s
.21891 .81076 m .21843 .82957 L .2496 .8318 L p .707 .577 .707 r
F P
0 g
s
.21843 .82957 m .21891 .81076 L .19145 .8067 L p .707 .577 .707 r
F P
0 g
s
.19145 .8067 m .19097 .82551 L .21843 .82957 L p .707 .577 .707 r
F P
0 g
s
.31127 .81127 m .31079 .83008 L .33481 .8263 L p .707 .577 .707 r
F P
0 g
s
.33481 .8263 m .3353 .80749 L .31127 .81127 L p .707 .577 .707 r
F P
0 g
s
.63409 .29561 m .63589 .79626 L .64589 .78406 L p .707 .577 .707 r
F P
0 g
s
.64589 .78406 m .64408 .2834 L .63409 .29561 L p .707 .577 .707 r
F P
0 g
s
.68617 .81964 m .68569 .83845 L .66462 .83295 L p .707 .577 .707 r
F P
0 g
s
.66462 .83295 m .6651 .81414 L .68617 .81964 L p .707 .577 .707 r
F P
0 g
s
.19097 .82551 m .19145 .8067 L .17038 .8012 L p .707 .577 .707 r
F P
0 g
s
.17038 .8012 m .1699 .82 L .19097 .82551 L p .707 .577 .707 r
F P
0 g
s
.3353 .80749 m .33481 .8263 L .35116 .821 L p .707 .577 .707 r
F P
0 g
s
.35116 .821 m .35164 .80219 L .3353 .80749 L p .707 .577 .707 r
F P
0 g
s
.362 .68372 m .36297 .72003 L .36005 .70964 L p .707 .577 .707 r
F P
0 g
s
.36005 .70964 m .35908 .67333 L .362 .68372 L p .707 .577 .707 r
F P
0 g
s
.35932 .64164 m .36351 .69334 L .36041 .67956 L p .707 .577 .707 r
F P
0 g
s
.36212 .79214 m .36032 .29149 L .35623 .27907 L p .707 .577 .707 r
F P
0 g
s
.36032 .29149 m .36212 .79214 L .3799 .80356 L p .707 .577 .707 r
F P
0 g
s
.6651 .81414 m .66462 .83295 L .63716 .82889 L p .707 .577 .707 r
F P
0 g
s
.63716 .82889 m .63764 .81008 L .6651 .81414 L p .707 .577 .707 r
F P
0 g
s
.1699 .82 m .17038 .8012 L .15777 .7948 L p .707 .577 .707 r
F P
0 g
s
.15777 .7948 m .15729 .8136 L .1699 .82 L p .707 .577 .707 r
F P
0 g
s
.36041 .67956 m .35622 .62787 L .35932 .64164 L p .707 .577 .707 r
F P
0 g
s
.63764 .81008 m .63716 .82889 L .60599 .82666 L p .707 .577 .707 r
F P
0 g
s
.35164 .80219 m .35116 .821 L .35821 .81471 L p .707 .577 .707 r
F P
0 g
s
.35821 .81471 m .35869 .7959 L .35164 .80219 L p .707 .577 .707 r
F P
0 g
s
.64408 .2834 m .64589 .78406 L .6418 .77164 L p .707 .577 .707 r
F P
0 g
s
.6418 .77164 m .63999 .27098 L .64408 .2834 L p .707 .577 .707 r
F P
0 g
s
.15729 .8136 m .15777 .7948 L .15485 .78812 L p .707 .577 .707 r
F P
0 g
s
.15485 .78812 m .15437 .80693 L .15729 .8136 L p .707 .577 .707 r
F P
0 g
s
.35908 .67333 m .36005 .70964 L .34744 .70029 L p .707 .577 .707 r
F P
0 g
s
.34744 .70029 m .34647 .66397 L .35908 .67333 L p .707 .577 .707 r
F P
0 g
s
.35622 .62787 m .36041 .67956 L .34766 .66752 L p .707 .577 .707 r
F P
0 g
s
.34766 .66752 m .34346 .61583 L .35622 .62787 L p .707 .577 .707 r
F P
0 g
s
.35623 .27907 m .35803 .77972 L .36212 .79214 L p .707 .577 .707 r
F P
0 g
s
.35803 .77972 m .35623 .27907 L .36623 .26686 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35869 .7959 m .35821 .81471 L .35529 .80804 L p .707 .577 .707 r
F P
0 g
s
.35529 .80804 m .35577 .78923 L .35869 .7959 L p .707 .577 .707 r
F P
0 g
s
.16693 .68714 m .16273 .63544 L .17887 .62227 L p .707 .577 .707 r
F P
0 g
s
.16522 .67376 m .16619 .71008 L .15913 .7205 L p .707 .577 .707 r
F P
0 g
s
.15437 .80693 m .15485 .78812 L .16191 .78183 L p .707 .577 .707 r
F P
0 g
s
.63999 .27098 m .6418 .77164 L .62402 .76022 L p .707 .577 .707 r
F P
0 g
s
.62402 .76022 m .62222 .25956 L .63999 .27098 L p .707 .577 .707 r
F P
0 g
s
.34647 .66397 m .34744 .70029 L .32637 .6929 L p .707 .577 .707 r
F P
0 g
s
.32637 .6929 m .3254 .65658 L .34647 .66397 L p .707 .577 .707 r
F P
0 g
s
.34346 .61583 m .34766 .66752 L .3265 .6584 L p .707 .577 .707 r
F P
0 g
s
.3265 .6584 m .3223 .60671 L .34346 .61583 L p .707 .577 .707 r
F P
0 g
s
.16191 .78183 m .16142 .80064 L .15437 .80693 L p .707 .577 .707 r
F P
0 g
s
.18156 .66435 m .18253 .70067 L .16619 .71008 L p .707 .577 .707 r
F P
0 g
s
.18253 .70067 m .18156 .66435 L .20559 .65685 L p .707 .577 .707 r
F P
0 g
s
.17887 .62227 m .18307 .67397 L .16693 .68714 L p .707 .577 .707 r
F P
0 g
s
.18307 .67397 m .17887 .62227 L .20272 .61139 L p .707 .577 .707 r
F P
0 g
s
.36803 .76752 m .36623 .26686 L .38934 .25606 L p .707 .577 .707 r
F P
0 g
s
.36623 .26686 m .36803 .76752 L .35803 .77972 L p .707 .577 .707 r
F P
0 g
s
.35577 .78923 m .35529 .80804 L .34268 .80164 L p .707 .577 .707 r
F P
0 g
s
.34268 .80164 m .34316 .78283 L .35577 .78923 L p .707 .577 .707 r
F P
0 g
s
.3254 .65658 m .32637 .6929 L .29891 .68818 L p .707 .577 .707 r
F P
0 g
s
.29891 .68818 m .29794 .65186 L .3254 .65658 L p .707 .577 .707 r
F P
0 g
s
.3223 .60671 m .3265 .6584 L .299 .65309 L p .707 .577 .707 r
F P
0 g
s
.299 .65309 m .29481 .6014 L .3223 .60671 L p .707 .577 .707 r
F P
0 g
s
.16142 .80064 m .16191 .78183 L .17825 .77654 L p .707 .577 .707 r
F P
0 g
s
.20656 .69317 m .20559 .65685 L .23495 .652 L p .707 .577 .707 r
F P
0 g
s
.20692 .66308 m .20272 .61139 L .23194 .60386 L p .707 .577 .707 r
F P
0 g
s
.20559 .65685 m .20656 .69317 L .18253 .70067 L p .707 .577 .707 r
F P
0 g
s
.20272 .61139 m .20692 .66308 L .18307 .67397 L p .707 .577 .707 r
F P
0 g
s
.17825 .77654 m .17777 .79534 L .16142 .80064 L p .707 .577 .707 r
F P
0 g
s
.29794 .65186 m .29891 .68818 L .26774 .6866 L p .707 .577 .707 r
F P
0 g
s
.26774 .6866 m .26677 .65029 L .29794 .65186 L p .707 .577 .707 r
F P
0 g
s
.29481 .6014 m .299 .65309 L .26787 .65211 L p .707 .577 .707 r
F P
0 g
s
.26787 .65211 m .26367 .60041 L .29481 .6014 L p .707 .577 .707 r
F P
0 g
s
.62222 .25956 m .62402 .76022 L .5943 .75092 L p .707 .577 .707 r
F P
0 g
s
.5943 .75092 m .59249 .25027 L .62222 .25956 L p .707 .577 .707 r
F P
0 g
s
.23592 .68832 m .23495 .652 L .26677 .65029 L p .707 .577 .707 r
F P
0 g
s
.23614 .65555 m .23194 .60386 L .26367 .60041 L p .707 .577 .707 r
F P
0 g
s
.23495 .652 m .23592 .68832 L .20656 .69317 L p .707 .577 .707 r
F P
0 g
s
.23194 .60386 m .23614 .65555 L .20692 .66308 L p .707 .577 .707 r
F P
0 g
s
.26677 .65029 m .26774 .6866 L .23592 .68832 L p .707 .577 .707 r
F P
0 g
s
.26367 .60041 m .26787 .65211 L .23614 .65555 L p .707 .577 .707 r
F P
0 g
s
.34316 .78283 m .34268 .80164 L .32161 .79614 L p .707 .577 .707 r
F P
0 g
s
.32161 .79614 m .32209 .77733 L .34316 .78283 L p .707 .577 .707 r
F P
0 g
s
.73593 .65969 m .73173 .608 L .7006 .60702 L p .707 .577 .707 r
F P
0 g
s
.73173 .608 m .73593 .65969 L .76766 .65625 L p .707 .577 .707 r
F P
0 g
s
.76766 .65625 m .76347 .60456 L .73173 .608 L p .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .36803 .76752 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.38972 .36245 m .39114 .75671 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .38934 .25606 L .42329 .24772 L p .707 .577 .707 r
F P
0 g
s
.42329 .24772 m .4251 .74838 L .39114 .75671 L p .707 .577 .707 r
F P
0 g
s
.38873 .57119 m .39292 .62288 L .42101 .61983 L p .707 .577 .707 r
F P
0 g
s
.4251 .74838 m .42329 .24772 L .46477 .24266 L p .707 .577 .707 r
F P
0 g
s
.42101 .61983 m .42465 .61944 L p .42025 .61352 L .707 .577 .707 r
F P
0 g
s
.42025 .61352 m .38873 .57119 L .42101 .61983 L .707 .577 .707 r
F
.38934 .25606 m .38972 .36245 L p .38613 .33295 L F P
0 g
s
.76347 .60456 m .76766 .65625 L .79688 .64872 L p .707 .577 .707 r
F P
0 g
s
.79688 .64872 m .79269 .59703 L .76347 .60456 L p .707 .577 .707 r
F P
0 g
s
.17777 .79534 m .17825 .77654 L .20228 .77276 L p .707 .577 .707 r
F P
0 g
s
.20228 .77276 m .2018 .79156 L .17777 .79534 L p .707 .577 .707 r
F P
0 g
s
.70479 .65871 m .7006 .60702 L .6731 .60171 L p .707 .577 .707 r
F P
0 g
s
.7006 .60702 m .70479 .65871 L .73593 .65969 L p .707 .577 .707 r
F P
0 g
s
.79269 .59703 m .79688 .64872 L .82073 .63783 L p .707 .577 .707 r
F P
0 g
s
.82073 .63783 m .81653 .58614 L .79269 .59703 L p .707 .577 .707 r
F P
0 g
s
.32209 .77733 m .32161 .79614 L .29415 .79207 L p .707 .577 .707 r
F P
0 g
s
.29415 .79207 m .29463 .77326 L .32209 .77733 L p .707 .577 .707 r
F P
0 g
s
.59249 .25027 m .5943 .75092 L .55553 .74466 L p .707 .577 .707 r
F P
0 g
s
.55553 .74466 m .55373 .244 L .59249 .25027 L p .707 .577 .707 r
F P
0 g
s
.6773 .6534 m .6731 .60171 L .65194 .59259 L p .707 .577 .707 r
F P
0 g
s
.6731 .60171 m .6773 .6534 L .70479 .65871 L p .707 .577 .707 r
F P
0 g
s
.2018 .79156 m .20228 .77276 L .23164 .77086 L p .707 .577 .707 r
F P
0 g
s
.72981 .73477 m .73029 .71596 L .69913 .71373 L p .707 .577 .707 r
F P
0 g
s
.73029 .71596 m .72981 .73477 L .76164 .73494 L p .707 .577 .707 r
F P
0 g
s
.76164 .73494 m .76212 .71613 L .73029 .71596 L p .707 .577 .707 r
F P
0 g
s
.23164 .77086 m .23116 .78967 L .2018 .79156 L p .707 .577 .707 r
F P
0 g
s
.76212 .71613 m .76164 .73494 L .791 .73305 L p .707 .577 .707 r
F P
0 g
s
.791 .73305 m .79148 .71424 L .76212 .71613 L p .707 .577 .707 r
F P
0 g
s
.69913 .71373 m .69864 .73254 L .72981 .73477 L p .707 .577 .707 r
F P
0 g
s
.81653 .58614 m .82073 .63783 L .83687 .62467 L p .707 .577 .707 r
F P
0 g
s
.83687 .62467 m .83268 .57297 L .81653 .58614 L p .707 .577 .707 r
F P
0 g
s
.29463 .77326 m .29415 .79207 L .26298 .78984 L p .707 .577 .707 r
F P
0 g
s
.26298 .78984 m .26346 .77104 L .29463 .77326 L p .707 .577 .707 r
F P
0 g
s
.69864 .73254 m .69913 .71373 L .67166 .70967 L p .707 .577 .707 r
F P
0 g
s
.73457 .74791 m .7336 .71159 L .70244 .71001 L p .707 .577 .707 r
F P
0 g
s
.7336 .71159 m .73457 .74791 L .7664 .74619 L p .707 .577 .707 r
F P
0 g
s
.7664 .74619 m .76543 .70987 L .7336 .71159 L p .707 .577 .707 r
F P
0 g
s
.76543 .70987 m .7664 .74619 L .79576 .74134 L p .707 .577 .707 r
F P
0 g
s
.79148 .71424 m .791 .73305 L .81503 .72927 L p .707 .577 .707 r
F P
0 g
s
.81503 .72927 m .81551 .71046 L .79148 .71424 L p .707 .577 .707 r
F P
0 g
s
.79576 .74134 m .79479 .70502 L .76543 .70987 L p .707 .577 .707 r
F P
0 g
s
.23116 .78967 m .23164 .77086 L .26346 .77104 L p .707 .577 .707 r
F P
0 g
s
.67166 .70967 m .67118 .72847 L .69864 .73254 L p .707 .577 .707 r
F P
0 g
s
.26346 .77104 m .26298 .78984 L .23116 .78967 L p .707 .577 .707 r
F P
0 g
s
.70341 .74633 m .70244 .71001 L .67497 .7053 L p .707 .577 .707 r
F P
0 g
s
.70244 .71001 m .70341 .74633 L .73457 .74791 L p .707 .577 .707 r
F P
0 g
s
.55373 .244 m .55553 .74466 L .51152 .74204 L p .707 .577 .707 r
F P
0 g
s
.51152 .74204 m .50972 .24138 L .55373 .244 L p .707 .577 .707 r
F P
0 g
s
.65614 .64428 m .65194 .59259 L .63919 .58055 L p .707 .577 .707 r
F P
0 g
s
.65194 .59259 m .65614 .64428 L .6773 .6534 L p .707 .577 .707 r
F P
0 g
s
.46658 .74332 m .46477 .24266 L .50972 .24138 L p .707 .577 .707 r
F P
0 g
s
.46477 .24266 m .46658 .74332 L .4251 .74838 L p .707 .577 .707 r
F P
0 g
s
.81551 .71046 m .81503 .72927 L .83137 .72397 L p .707 .577 .707 r
F P
0 g
s
.79479 .70502 m .79576 .74134 L .81979 .73384 L p .707 .577 .707 r
F P
0 g
s
.83137 .72397 m .83185 .70516 L .81551 .71046 L p .707 .577 .707 r
F P
0 g
s
.81979 .73384 m .81882 .69753 L .79479 .70502 L p .707 .577 .707 r
F P
0 g
s
.67118 .72847 m .67166 .70967 L .6506 .70416 L p .707 .577 .707 r
F P
0 g
s
.50972 .24138 m .51152 .74204 L .46658 .74332 L p .707 .577 .707 r
F P
0 g
s
.6506 .70416 m .65011 .72297 L .67118 .72847 L p .707 .577 .707 r
F P
0 g
s
.67497 .7053 m .67594 .74161 L .70341 .74633 L p .707 .577 .707 r
F P
0 g
s
.83268 .57297 m .83687 .62467 L .84373 .6105 L p .707 .577 .707 r
F P
0 g
s
.84373 .6105 m .83953 .55881 L .83268 .57297 L p .707 .577 .707 r
F P
0 g
s
.67594 .74161 m .67497 .7053 L .65391 .6979 L p .707 .577 .707 r
F P
0 g
s
.83185 .70516 m .83137 .72397 L .83278 .72272 L p .707 .577 .707 r
F P
0 g
s
.83274 .72638 m .83613 .72443 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83294 .70723 m .83185 .70516 L .83278 .72272 L .707 .577 .707 r
F
.83613 .72443 m .83516 .68811 L .83312 .68929 L p F P
0 g
s
.83297 .70417 m .83185 .70516 L p .83294 .70723 L .707 .577 .707 r
F P
0 g
s
.83312 .68929 m .81882 .69753 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83613 .72443 m .83312 .68929 L .83281 .71927 L .707 .577 .707 r
F
.83516 .68811 m .83613 .72443 L .84319 .71401 L p F P
0 g
s
.84319 .71401 m .84222 .6777 L .83516 .68811 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83891 .69887 L .83297 .70417 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83297 .70417 L .83294 .70723 L .707 .577 .707 r
F
.83278 .72272 m .83843 .71768 L p .83294 .70723 L F P
0 g
s
.81882 .69753 m .81979 .73384 L .83274 .72638 L p .707 .577 .707 r
F P
0 g
s
.83281 .71927 m .81882 .69753 L .83274 .72638 L .707 .577 .707 r
F
.65391 .6979 m .65488 .73422 L .67594 .74161 L p F P
0 g
s
.63919 .58055 m .64338 .63224 L .65614 .64428 L p .707 .577 .707 r
F P
0 g
s
.64338 .63224 m .63919 .58055 L .63609 .56677 L p .707 .577 .707 r
F P
0 g
s
.65011 .72297 m .6506 .70416 L .63798 .69776 L p .707 .577 .707 r
F P
0 g
s
.63798 .69776 m .6375 .71657 L .65011 .72297 L p .707 .577 .707 r
F P
0 g
s
.65488 .73422 m .65391 .6979 L .64129 .68855 L p .707 .577 .707 r
F P
0 g
s
.83953 .55881 m .84373 .6105 L .84063 .59672 L p .707 .577 .707 r
F P
0 g
s
.84063 .59672 m .83643 .54503 L .83953 .55881 L p .707 .577 .707 r
F P
0 g
s
.64129 .68855 m .64226 .72487 L .65488 .73422 L p .707 .577 .707 r
F P
0 g
s
.63609 .56677 m .64028 .61847 L .64338 .63224 L p .707 .577 .707 r
F P
0 g
s
.64028 .61847 m .63609 .56677 L .64294 .55261 L p .707 .577 .707 r
F P
0 g
s
.6375 .71657 m .63798 .69776 L .63506 .69109 L p .707 .577 .707 r
F P
0 g
s
.63506 .69109 m .63458 .7099 L .6375 .71657 L p .707 .577 .707 r
F P
0 g
s
.64226 .72487 m .64129 .68855 L .63837 .67816 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83643 .54503 m .84063 .59672 L .82787 .58469 L p .707 .577 .707 r
F P
0 g
s
.82787 .58469 m .82368 .53299 L .83643 .54503 L p .707 .577 .707 r
F P
0 g
s
.63837 .67816 m .63934 .71448 L .64226 .72487 L p .707 .577 .707 r
F P
0 g
s
.83891 .69887 m .83843 .71768 L .83551 .71101 L p .707 .577 .707 r
F P
0 g
s
.83551 .71101 m .83599 .6922 L .83891 .69887 L p .707 .577 .707 r
F P
0 g
s
.84222 .6777 m .84319 .71401 L .84027 .70362 L p .707 .577 .707 r
F P
0 g
s
.84027 .70362 m .8393 .66731 L .84222 .6777 L p .707 .577 .707 r
F P
0 g
s
.64294 .55261 m .64714 .6043 L .64028 .61847 L p .707 .577 .707 r
F P
0 g
s
.64714 .6043 m .64294 .55261 L .65909 .53944 L p .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .63837 .67816 L .64455 .66905 L p .707 .577 .707 r
F P
0 g
s
.64455 .66905 m .64543 .66775 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .64455 .66905 L .6446 .67411 L .707 .577 .707 r
F
.6447 .68396 m .65846 .6795 L p .64486 .69899 L F P
0 g
s
.65846 .6795 m .65798 .69831 L .6449 .70255 L p .707 .577 .707 r
F P
0 g
s
.64486 .69899 m .65846 .6795 L .6449 .70255 L .707 .577 .707 r
F
.64543 .66775 m .6464 .70406 L .64493 .70623 L p F P
0 g
s
.64493 .70623 m .63934 .71448 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.6446 .67411 m .64543 .66775 L .64493 .70623 L .707 .577 .707 r
F
.6449 .70255 m .64164 .70361 L p .64486 .69899 L F P
0 g
s
.64164 .70361 m .64212 .6848 L .6447 .68396 L p .707 .577 .707 r
F P
0 g
s
.64164 .70361 m .6447 .68396 L .64486 .69899 L .707 .577 .707 r
F
.63458 .7099 m .63506 .69109 L .64212 .6848 L p F P
0 g
s
.39292 .62288 m .38873 .57119 L .35759 .5702 L p .707 .577 .707 r
F P
0 g
s
.42465 .61944 m .42046 .56774 L .38873 .57119 L p .707 .577 .707 r
F P
0 g
s
.42046 .56774 m .42465 .61944 L .45387 .6119 L p .707 .577 .707 r
F P
0 g
s
.45387 .6119 m .44968 .56021 L .42046 .56774 L p .707 .577 .707 r
F P
0 g
s
.64212 .6848 m .64164 .70361 L .63458 .7099 L p .707 .577 .707 r
F P
0 g
s
.82368 .53299 m .82787 .58469 L .80671 .57556 L p .707 .577 .707 r
F P
0 g
s
.80671 .57556 m .80252 .52387 L .82368 .53299 L p .707 .577 .707 r
F P
0 g
s
.36178 .6219 m .35759 .5702 L .33009 .56489 L p .707 .577 .707 r
F P
0 g
s
.35759 .5702 m .36178 .6219 L .39292 .62288 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44968 .56021 m .45387 .6119 L .47772 .60102 L p .707 .577 .707 r
F P
0 g
s
.47772 .60102 m .47352 .54933 L .44968 .56021 L p .707 .577 .707 r
F P
0 g
s
.83599 .6922 m .83551 .71101 L .82289 .70461 L p .707 .577 .707 r
F P
0 g
s
.82289 .70461 m .82338 .6858 L .83599 .6922 L p .707 .577 .707 r
F P
0 g
s
.65909 .53944 m .66328 .59113 L .64714 .6043 L p .707 .577 .707 r
F P
0 g
s
.66328 .59113 m .65909 .53944 L .68294 .52856 L p .707 .577 .707 r
F P
0 g
s
.8393 .66731 m .84027 .70362 L .82765 .69427 L p .707 .577 .707 r
F P
0 g
s
.82765 .69427 m .82668 .65796 L .8393 .66731 L p .707 .577 .707 r
F P
0 g
s
.33429 .61659 m .33009 .56489 L .30893 .55577 L p .707 .577 .707 r
F P
0 g
s
.33009 .56489 m .33429 .61659 L .36178 .6219 L p .707 .577 .707 r
F P
0 g
s
.3868 .69795 m .38728 .67914 L .35612 .67691 L p .707 .577 .707 r
F P
0 g
s
.38728 .67914 m .3868 .69795 L .41863 .69813 L p .707 .577 .707 r
F P
0 g
s
.41863 .69813 m .41911 .67932 L .38728 .67914 L p .707 .577 .707 r
F P
0 g
s
.80252 .52387 m .80671 .57556 L .77922 .57025 L p .707 .577 .707 r
F P
0 g
s
.77922 .57025 m .77502 .51856 L .80252 .52387 L p .707 .577 .707 r
F P
0 g
s
.41911 .67932 m .41863 .69813 L .44799 .69623 L p .707 .577 .707 r
F P
0 g
s
.44799 .69623 m .44847 .67742 L .41911 .67932 L p .707 .577 .707 r
F P
0 g
s
.35612 .67691 m .35563 .69572 L .3868 .69795 L p .707 .577 .707 r
F P
0 g
s
.47352 .54933 m .47772 .60102 L .49386 .58785 L p .707 .577 .707 r
F P
0 g
s
.49386 .58785 m .48967 .53616 L .47352 .54933 L p .707 .577 .707 r
F P
0 g
s
.35563 .69572 m .35612 .67691 L .32865 .67285 L p .707 .577 .707 r
F P
0 g
s
.39156 .71109 m .39059 .67477 L .35943 .6732 L p .707 .577 .707 r
F P
0 g
s
.39059 .67477 m .39156 .71109 L .42339 .70937 L p .707 .577 .707 r
F P
0 g
s
.42339 .70937 m .42242 .67305 L .39059 .67477 L p .707 .577 .707 r
F P
0 g
s
.6464 .70406 m .64543 .66775 L .66177 .65833 L p .707 .577 .707 r
F P
0 g
s
.42242 .67305 m .42339 .70937 L .45275 .70453 L p .707 .577 .707 r
F P
0 g
s
.44847 .67742 m .44799 .69623 L .47202 .69245 L p .707 .577 .707 r
F P
0 g
s
.47202 .69245 m .4725 .67364 L .44847 .67742 L p .707 .577 .707 r
F P
0 g
s
.45275 .70453 m .45178 .66821 L .42242 .67305 L p .707 .577 .707 r
F P
0 g
s
.32865 .67285 m .32817 .69166 L .35563 .69572 L p .707 .577 .707 r
F P
0 g
s
.68713 .58025 m .68294 .52856 L .71216 .52102 L p .707 .577 .707 r
F P
0 g
s
.68294 .52856 m .68713 .58025 L .66328 .59113 L p .707 .577 .707 r
F P
0 g
s
.3604 .70951 m .35943 .6732 L .33196 .66848 L p .707 .577 .707 r
F P
0 g
s
.35943 .6732 m .3604 .70951 L .39156 .71109 L p .707 .577 .707 r
F P
0 g
s
.77502 .51856 m .77922 .57025 L .74808 .56927 L p .707 .577 .707 r
F P
0 g
s
.74808 .56927 m .74389 .51758 L .77502 .51856 L p .707 .577 .707 r
F P
0 g
s
.31313 .60747 m .30893 .55577 L .29618 .54373 L p .707 .577 .707 r
F P
0 g
s
.30893 .55577 m .31313 .60747 L .33429 .61659 L p .707 .577 .707 r
F P
0 g
s
.65798 .69831 m .65846 .6795 L .68249 .67572 L p .707 .577 .707 r
F P
0 g
s
.68249 .67572 m .68201 .69453 L .65798 .69831 L p .707 .577 .707 r
F P
0 g
s
.66177 .65833 m .66274 .69465 L .6464 .70406 L p .707 .577 .707 r
F P
0 g
s
.82338 .6858 m .82289 .70461 L .80183 .69911 L p .707 .577 .707 r
F P
0 g
s
.80183 .69911 m .80231 .6803 L .82338 .6858 L p .707 .577 .707 r
F P
0 g
s
.4725 .67364 m .47202 .69245 L .48836 .68716 L p .707 .577 .707 r
F P
0 g
s
.45178 .66821 m .45275 .70453 L .47678 .69703 L p .707 .577 .707 r
F P
0 g
s
.48836 .68716 m .48884 .66835 L .4725 .67364 L p .707 .577 .707 r
F P
0 g
s
.47678 .69703 m .47581 .66071 L .45178 .66821 L p .707 .577 .707 r
F P
0 g
s
.82668 .65796 m .82765 .69427 L .80659 .68688 L p .707 .577 .707 r
F P
0 g
s
.80659 .68688 m .80562 .65056 L .82668 .65796 L p .707 .577 .707 r
F P
0 g
s
.71635 .57272 m .71216 .52102 L .74389 .51758 L p .707 .577 .707 r
F P
0 g
s
.71216 .52102 m .71635 .57272 L .68713 .58025 L p .707 .577 .707 r
F P
0 g
s
.32817 .69166 m .32865 .67285 L .30759 .66735 L p .707 .577 .707 r
F P
0 g
s
.74389 .51758 m .74808 .56927 L .71635 .57272 L p .707 .577 .707 r
F P
0 g
s
.30759 .66735 m .3071 .68616 L .32817 .69166 L p .707 .577 .707 r
F P
0 g
s
.33196 .66848 m .33293 .7048 L .3604 .70951 L p .707 .577 .707 r
F P
0 g
s
.48967 .53616 m .49386 .58785 L .50072 .57368 L p .707 .577 .707 r
F P
0 g
s
.50072 .57368 m .49652 .52199 L .48967 .53616 L p .707 .577 .707 r
F P
0 g
s
.33293 .7048 m .33196 .66848 L .3109 .66108 L p .707 .577 .707 r
F P
0 g
s
.66274 .69465 m .66177 .65833 L .6858 .65083 L p .707 .577 .707 r
F P
0 g
s
.48884 .66835 m .48836 .68716 L .48977 .6859 L p .707 .577 .707 r
F P
0 g
s
.48973 .68957 m .49312 .68761 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.48993 .67041 m .48884 .66835 L .48977 .6859 L .707 .577 .707 r
F
.49312 .68761 m .49215 .65129 L .49011 .65247 L p F P
0 g
s
.48996 .66735 m .48884 .66835 L p .48993 .67041 L .707 .577 .707 r
F P
0 g
s
.49011 .65247 m .47581 .66071 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.49312 .68761 m .49011 .65247 L .4898 .68245 L .707 .577 .707 r
F
.49215 .65129 m .49312 .68761 L .50018 .6772 L p F P
0 g
s
.50018 .6772 m .49921 .64088 L .49215 .65129 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .4959 .66206 L .48996 .66735 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .48996 .66735 L .48993 .67041 L .707 .577 .707 r
F
.48977 .6859 m .49542 .68086 L p .48993 .67041 L F P
0 g
s
.47581 .66071 m .47678 .69703 L .48973 .68957 L p .707 .577 .707 r
F P
0 g
s
.4898 .68245 m .47581 .66071 L .48973 .68957 L .707 .577 .707 r
F
.3109 .66108 m .31187 .6974 L .33293 .7048 L p F P
0 g
s
.29618 .54373 m .30037 .59543 L .31313 .60747 L p .707 .577 .707 r
F P
0 g
s
.80231 .6803 m .80183 .69911 L .77436 .69504 L p .707 .577 .707 r
F P
0 g
s
.77436 .69504 m .77485 .67623 L .80231 .6803 L p .707 .577 .707 r
F P
0 g
s
.80562 .65056 m .80659 .68688 L .77912 .68216 L p .707 .577 .707 r
F P
0 g
s
.77912 .68216 m .77815 .64584 L .80562 .65056 L p .707 .577 .707 r
F P
0 g
s
.30037 .59543 m .29618 .54373 L .29308 .52996 L p .707 .577 .707 r
F P
0 g
s
.3071 .68616 m .30759 .66735 L .29497 .66095 L p .707 .577 .707 r
F P
0 g
s
.68201 .69453 m .68249 .67572 L .71185 .67383 L p .707 .577 .707 r
F P
0 g
s
.6858 .65083 m .68677 .68715 L .66274 .69465 L p .707 .577 .707 r
F P
0 g
s
.29497 .66095 m .29449 .67976 L .3071 .68616 L p .707 .577 .707 r
F P
0 g
s
.31187 .6974 m .3109 .66108 L .29828 .65173 L p .707 .577 .707 r
F P
0 g
s
.68677 .68715 m .6858 .65083 L .71516 .64599 L p .707 .577 .707 r
F P
0 g
s
.71185 .67383 m .71137 .69264 L .68201 .69453 L p .707 .577 .707 r
F P
0 g
s
.49652 .52199 m .50072 .57368 L .49762 .55991 L p .707 .577 .707 r
F P
0 g
s
.49762 .55991 m .49342 .50821 L .49652 .52199 L p .707 .577 .707 r
F P
0 g
s
.77485 .67623 m .77436 .69504 L .7432 .69281 L p .707 .577 .707 r
F P
0 g
s
.7432 .69281 m .74368 .674 L .77485 .67623 L p .707 .577 .707 r
F P
0 g
s
.77815 .64584 m .77912 .68216 L .74796 .68058 L p .707 .577 .707 r
F P
0 g
s
.74796 .68058 m .74699 .64427 L .77815 .64584 L p .707 .577 .707 r
F P
0 g
s
.71137 .69264 m .71185 .67383 L .74368 .674 L p .707 .577 .707 r
F P
0 g
s
.71613 .6823 m .71516 .64599 L .74699 .64427 L p .707 .577 .707 r
F P
0 g
s
.71516 .64599 m .71613 .6823 L .68677 .68715 L p .707 .577 .707 r
F P
0 g
s
.29828 .65173 m .29925 .68805 L .31187 .6974 L p .707 .577 .707 r
F P
0 g
s
.74368 .674 m .7432 .69281 L .71137 .69264 L p .707 .577 .707 r
F P
0 g
s
.74699 .64427 m .74796 .68058 L .71613 .6823 L p .707 .577 .707 r
F P
0 g
s
.29308 .52996 m .29727 .58165 L .30037 .59543 L p .707 .577 .707 r
F P
0 g
s
.29727 .58165 m .29308 .52996 L .29993 .51579 L p .707 .577 .707 r
F P
0 g
s
.29449 .67976 m .29497 .66095 L .29205 .65428 L p .707 .577 .707 r
F P
0 g
s
.29205 .65428 m .29157 .67308 L .29449 .67976 L p .707 .577 .707 r
F P
0 g
s
.29925 .68805 m .29828 .65173 L .29536 .64134 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49342 .50821 m .49762 .55991 L .48486 .54787 L p .707 .577 .707 r
F P
0 g
s
.48486 .54787 m .48067 .49618 L .49342 .50821 L p .707 .577 .707 r
F P
0 g
s
.29536 .64134 m .29633 .67766 L .29925 .68805 L p .707 .577 .707 r
F P
0 g
s
.4959 .66206 m .49542 .68086 L .4925 .67419 L p .707 .577 .707 r
F P
0 g
s
.4925 .67419 m .49298 .65538 L .4959 .66206 L p .707 .577 .707 r
F P
0 g
s
.49921 .64088 m .50018 .6772 L .49726 .66681 L p .707 .577 .707 r
F P
0 g
s
.49726 .66681 m .49629 .63049 L .49921 .64088 L p .707 .577 .707 r
F P
0 g
s
.29993 .51579 m .30413 .56749 L .29727 .58165 L p .707 .577 .707 r
F P
0 g
s
.30413 .56749 m .29993 .51579 L .31608 .50262 L p .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .29536 .64134 L .30154 .63223 L p .707 .577 .707 r
F P
0 g
s
.30154 .63223 m .30242 .63093 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .30154 .63223 L .30159 .63729 L .707 .577 .707 r
F
.30169 .64715 m .31545 .64269 L p .30185 .66218 L F P
0 g
s
.31545 .64269 m .31497 .6615 L .30189 .66574 L p .707 .577 .707 r
F P
0 g
s
.30185 .66218 m .31545 .64269 L .30189 .66574 L .707 .577 .707 r
F
.30242 .63093 m .30339 .66725 L .30192 .66941 L p F P
0 g
s
.30192 .66941 m .29633 .67766 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.30159 .63729 m .30242 .63093 L .30192 .66941 L .707 .577 .707 r
F
.30189 .66574 m .29863 .66679 L p .30185 .66218 L F P
0 g
s
.29863 .66679 m .29911 .64798 L .30169 .64715 L p .707 .577 .707 r
F P
0 g
s
.29863 .66679 m .30169 .64715 L .30185 .66218 L .707 .577 .707 r
F
.29157 .67308 m .29205 .65428 L .29911 .64798 L p F P
0 g
s
.29911 .64798 m .29863 .66679 L .29157 .67308 L p .707 .577 .707 r
F P
0 g
s
.48067 .49618 m .48486 .54787 L .4637 .53875 L p .707 .577 .707 r
F P
0 g
s
.4637 .53875 m .45951 .48706 L .48067 .49618 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49298 .65538 m .4925 .67419 L .47988 .66779 L p .707 .577 .707 r
F P
0 g
s
.47988 .66779 m .48037 .64898 L .49298 .65538 L p .707 .577 .707 r
F P
0 g
s
.31608 .50262 m .32027 .55432 L .30413 .56749 L p .707 .577 .707 r
F P
0 g
s
.32027 .55432 m .31608 .50262 L .33993 .49174 L p .707 .577 .707 r
F P
0 g
s
.49629 .63049 m .49726 .66681 L .48464 .65746 L p .707 .577 .707 r
F P
0 g
s
.48464 .65746 m .48367 .62114 L .49629 .63049 L p .707 .577 .707 r
F P
0 g
s
.45951 .48706 m .4637 .53875 L .43621 .53344 L p .707 .577 .707 r
F P
0 g
s
.43621 .53344 m .43201 .48174 L .45951 .48706 L p .707 .577 .707 r
F P
0 g
s
.30339 .66725 m .30242 .63093 L .31876 .62151 L p .707 .577 .707 r
F P
0 g
s
.34412 .54343 m .33993 .49174 L .36915 .48421 L p .707 .577 .707 r
F P
0 g
s
.33993 .49174 m .34412 .54343 L .32027 .55432 L p .707 .577 .707 r
F P
0 g
s
.43201 .48174 m .43621 .53344 L .40507 .53246 L p .707 .577 .707 r
F P
0 g
s
.40507 .53246 m .40088 .48076 L .43201 .48174 L p .707 .577 .707 r
F P
0 g
s
.31497 .6615 m .31545 .64269 L .33948 .63891 L p .707 .577 .707 r
F P
0 g
s
.33948 .63891 m .339 .65772 L .31497 .6615 L p .707 .577 .707 r
F P
0 g
s
.31876 .62151 m .31973 .65783 L .30339 .66725 L p .707 .577 .707 r
F P
0 g
s
.48037 .64898 m .47988 .66779 L .45882 .66229 L p .707 .577 .707 r
F P
0 g
s
.45882 .66229 m .4593 .64348 L .48037 .64898 L p .707 .577 .707 r
F P
0 g
s
.48367 .62114 m .48464 .65746 L .46358 .65006 L p .707 .577 .707 r
F P
0 g
s
.46358 .65006 m .46261 .61374 L .48367 .62114 L p .707 .577 .707 r
F P
0 g
s
.37334 .5359 m .36915 .48421 L .40088 .48076 L p .707 .577 .707 r
F P
0 g
s
.36915 .48421 m .37334 .5359 L .34412 .54343 L p .707 .577 .707 r
F P
0 g
s
.40088 .48076 m .40507 .53246 L .37334 .5359 L p .707 .577 .707 r
F P
0 g
s
.31973 .65783 m .31876 .62151 L .34279 .61402 L p .707 .577 .707 r
F P
0 g
s
.4593 .64348 m .45882 .66229 L .43135 .65823 L p .707 .577 .707 r
F P
0 g
s
.43135 .65823 m .43184 .63942 L .4593 .64348 L p .707 .577 .707 r
F P
0 g
s
.46261 .61374 m .46358 .65006 L .43611 .64535 L p .707 .577 .707 r
F P
0 g
s
.43611 .64535 m .43514 .60903 L .46261 .61374 L p .707 .577 .707 r
F P
0 g
s
.339 .65772 m .33948 .63891 L .36884 .63701 L p .707 .577 .707 r
F P
0 g
s
.34279 .61402 m .34376 .65033 L .31973 .65783 L p .707 .577 .707 r
F P
0 g
s
.34376 .65033 m .34279 .61402 L .37215 .60917 L p .707 .577 .707 r
F P
0 g
s
.36884 .63701 m .36836 .65582 L .339 .65772 L p .707 .577 .707 r
F P
0 g
s
.43184 .63942 m .43135 .65823 L .40018 .656 L p .707 .577 .707 r
F P
0 g
s
.40018 .656 m .40067 .63719 L .43184 .63942 L p .707 .577 .707 r
F P
0 g
s
.43514 .60903 m .43611 .64535 L .40495 .64377 L p .707 .577 .707 r
F P
0 g
s
.40495 .64377 m .40397 .60745 L .43514 .60903 L p .707 .577 .707 r
F P
0 g
s
.36836 .65582 m .36884 .63701 L .40067 .63719 L p .707 .577 .707 r
F P
0 g
s
.37312 .64549 m .37215 .60917 L .40397 .60745 L p .707 .577 .707 r
F P
0 g
s
.37215 .60917 m .37312 .64549 L .34376 .65033 L p .707 .577 .707 r
F P
0 g
s
.40067 .63719 m .40018 .656 L .36836 .65582 L p .707 .577 .707 r
F P
0 g
s
.40397 .60745 m .40495 .64377 L .37312 .64549 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001EYF00<005YFFUH015YF2@00OGoo001fOol90005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uo
o`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH90002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000D000AJEP03001JEUYF009JEPP000IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD00003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Ggoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001FOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol005Aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0001Moo`l003moo`00E7oo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00004Goo1P0015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000=Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH80008FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH20008FUH00`00FUIJEP06FUH40004FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP0015YF00<005YFFUH00eYF0`0000Eoo`00FUIJ
EP0000EJEP8000QJEP03001JEUYF00UJEP@00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=o
o`04001JEUYF0004FUH01000FUIJEUYF0P0017oo00@005YFFUH000EJEP8000QJEP03001JEUYF00UJ
EP03001JEUYF00<000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF00@005YF
000000Ioo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH30003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0P0027oo00@005YFFUH000EJEP8000QJ
EP03001JEUYF00QJEP800003FUH005YF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02000^Ool005Aoo`03001JEP0000=JEP03001oogoo00Qoo`04001JEUYF0005FUH20008FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol01000
FUH005YF10002Goo00@005YFFUH000EJEP@000IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009J
EP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00E7oo00@005YF000000AJEP<000Ioo`04001J
EUYF0005FUH50005FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000^Ool005Aoo`04001JEP000005FUH00`00FUH000030002Ool01000FUIJEP001EYF
30001EYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001DOol20002FUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`P000AJEP03001JEUYF00=JEP04
001JEP00000^Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH015YF00<0
05YFFUH00UYF0P005goo1@001EYF00@005YFFUH002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0005FUH00`00FUIJEP04FUH00`00FUH00002000NOol20003FUH01000FUIJEP00;Woo001DOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH00eYF0`008goo0P0000EJ
EP00FUIJEP0002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH2000UOol200000eYF00000002FUH2000]Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000009Goo0P0000=JEP00FUH00UYF00@005YF
000002eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH2000UOol20003FUH01000FUIJ
EUYF1000;Goo001EOol01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH2000EOol3000<Ool30005FUH01P00FUIJEUYF
001JEP8002eoo`00AWoo2@001goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`000UYF0P004Woo1@001goo100000=J
EP00FUH01EYF00<005YFFUH00UYF0`00;Goo0010Ool60004FUH00`00FUIJEP02FUH;0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00T005YFFUIJEP00FUH005YF000015YF
1@003Goo30001EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000lOol400000eYF001JEP07
FUH00`00FUIJEP06FUH01000FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF2@0000=J
EP00FUH01eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000hOol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH80002FUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000fOol200000eYF001JEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH300000eYF000000050003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool003Aoo`8000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00;Woo000bOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0002moo`00<Goo0P001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000;goo000`Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
<7oo000_Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000aOol002ioo`03001JEUYF
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000cOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00=Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0015YF00<005YFFUH01EYF5`000eYF00@005YF000003Moo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF
00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000AJEP<00003FUH005YF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000@003Uoo`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF3`000eYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUH000050006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000gOol002aoo`9JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00AJEPL000=JEP03001JEUYF00EJEP04001JEP000003FUH01000FUH000000UYF00<005YFFUH0
0UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo0UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01EYF0P0000=JEP00
FUH00UYF0P0000=JEP0000001`000UYF00<005YFFUH015YF00<005YFFUH015YF200015YF00<005YF
FUH00eYF00<005YF00000UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo0UYF0P0015YF00<005YFFUH00eYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH01@0000IJEP00000005YF0002FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<005YFFUH010000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00;7oo0eYF00<005YFFUH00UYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP0000@00004FUH000000004FUH20002FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH01eYF0P0000=JEP0000000P000UYF10000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool3FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH00UYF1`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF009JEPD000EJEP03001JEP0000D0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04
001JEP000004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00;Goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800005FUH0
05YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000]Ool002aoo`@00004FUH000000006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo
00<005YF00000P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80003FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUIJEP04FUHE0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=J
EPH0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF0080
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03P001EYF00<005YFFUH00eYF
00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05
001JEUYF001JEP020004FUH00`00FUH000030004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0000AJEP00FUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0015YF0P0000=JEP000000
1@0000=JEP00Ool01Woo4@000eYF00<005YFFUH015YF0P000UYF0P00;Goo000/Ool01000FUIJEP00
0eYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF0080009J
EPL000=JEP04001JEUYF000HOol50004FUH01@00FUIJEP00FUH00P00;Goo000/Ool01000FUIJEP00
0eYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF00@00004FUH0
00000003FUH200001EYF001JEUYF00006goo1@0000=JEP00FUH00UYF0`00;Goo000]Ool2FUH01000
FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP03FUH70002FUH2000EOol50005FUH20003FUH3000]Ool002eoo`9JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000P000AJEP03001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00=JEP04001JEUYFFUH90009Ool9
0003FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00;Goo000]Ool01EYF001JEUYF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00`000UYF00<005YFFUH02@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
02eoo`00;Goo00=JEP00FUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`<0009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP8000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`00;Woo000^Ool00`00FUIJEP02
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEP000UYF
00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02000_Ool002ioo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50005FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF10001EYF
00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000_Ool00`00FUH00003FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP030002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00<goo000`Ool20005
FUH50003FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0400000eYF001JEP05FUH30002Ool01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000aOol2
0004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP03FUH20004Ool0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000cOol300000eYF001JEP06
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUH000030006Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH015YF8@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P001EYF1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01000?Goo000fOol50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000:Ool01000FUIJEP001UYF00<005YF
FUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P001UYF00<005YFFUH05`00@Goo000kOol90004FUH00`00FUIJEP05FUH8000=
Ool01000FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YF00000`001eYF00<005YFFUH00UYF0P000UYF0P001UYF00<005YF00000UYF
0P00E7oo0014Ool<000EOol01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0P000UYF0P00
1UYF0P0015YF00<007ooOol0DWoo001UOol01000FUIJEP001EYF0`000eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
0P000eYF00<005YFFUH00eYF0P001EYF00<007ooOol0DWoo001UOol01000FUIJEP000eYF0P001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00Oomoo`1COol006Eo
o`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF00@005YF000000=JEP05001J
EUYFFUH0001FOol006Eoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP<0
00EJEP05001JEUYFFUH0001FOol003Iooal0011oo`03001JEP0000=JEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0000<00003FUH005YF00EJEP04001JEP00001GOol0039oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000aoo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH2001IOol0031oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000Moo`8000AJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP02FUH2001KOol002ioo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@000=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002
FUH6001MOol002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003Ool0000000AJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<006=oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0P00Igoo000/Ool20004FUH01000FUIJEUYF20004Goo200015YF00<005YF
FUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00;7oo0P00
0UYF1P008Goo1`000eYF00H005YFFUIJEP00Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00Oomoo`1VOol002]oo`03001JEP0000@002aoo`@000=JEP04001oogooOol30008FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JGoo000[Ool20003FUH00`00FUH00002000]Ool200000eYF001oo`04Ool20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUH00000Jgoo000[Ool20003FUH00`00FUIJEP02FUH5000ROol6000015YF000000001goo0`0015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1@00K7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@004Woo1`000eYF00L005YFFUIJ
EP00FUH0000:Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060004FUH8001TOol002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000eoo`L000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00IJEP04001JEUYFFUH6001N
Ool002eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000EOol;0006FUH00`00FUIJEP0:FUH01000
FUIJEUYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00Fgoo
000_Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02000QOolG0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3001HOol003=oo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EP00001FOol003Yoo`P000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03
001JEP0000AJEP04001JEUYFFUHQ0003FUH00`00FUIJEP04FUH01000FUIJEP00EWoo0012OolH000c
Ool00`00FUH00003FUH5000QOol50004FUH01000FUIJEUYF0P00EGoo002=Ool01000FUH005YF0P00
:goo0`0000=JEP00FUH00UYF0P00EGoo002=Ool00`00FUH00004000]Ool20003FUH2001EOol008eo
o`80009JEP03001JEUYF00D002Uoo`<00003FUH0000005Eoo`00SGoo0P000UYF00<005YFFUH00eYF
00<005YF00000`0087oo1@000eYF0`00EGoo002>Ool01000FUIJEP001EYF00<005YFFUH00eYF8000
0eYF00<005YFFUH00UYF0`00EGoo002?Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001EOol0095o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH3001FOol009=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001IOol009Ioo`D000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001KOol009]ooa8000AJEP03
001JEUYF009JEPL0061oo`00[Goo2@00Igoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59493 .71763 m .59912 .66031 L .56798 .65745 L p .707 .577 .707 r
F P
0 g
s
.59912 .66031 m .59493 .71763 L .62666 .71966 L p .707 .577 .707 r
F P
0 g
s
.62666 .71966 m .63085 .66234 L .59912 .66031 L p .707 .577 .707 r
F P
0 g
s
.63085 .66234 m .62666 .71966 L .65588 .72066 L p .707 .577 .707 r
F P
0 g
s
.65588 .72066 m .66007 .66334 L .63085 .66234 L p .707 .577 .707 r
F P
0 g
s
.56798 .65745 m .56379 .71477 L .59493 .71763 L p .707 .577 .707 r
F P
0 g
s
.56379 .71477 m .56798 .65745 L .54049 .65402 L p .707 .577 .707 r
F P
0 g
s
.54049 .65402 m .5363 .71134 L .56379 .71477 L p .707 .577 .707 r
F P
0 g
s
.66007 .66334 m .65588 .72066 L .67972 .72051 L p .707 .577 .707 r
F P
0 g
s
.67972 .72051 m .68392 .66319 L .66007 .66334 L p .707 .577 .707 r
F P
0 g
s
.5363 .71134 m .54049 .65402 L .51933 .65037 L p .707 .577 .707 r
F P
0 g
s
.51933 .65037 m .51514 .70769 L .5363 .71134 L p .707 .577 .707 r
F P
0 g
s
.59505 .82878 m .59602 .79116 L .56485 .78893 L p .707 .577 .707 r
F P
0 g
s
.59602 .79116 m .59505 .82878 L .62687 .82896 L p .707 .577 .707 r
F P
0 g
s
.62687 .82896 m .62784 .79134 L .59602 .79116 L p .707 .577 .707 r
F P
0 g
s
.62784 .79134 m .62687 .82896 L .65624 .82707 L p .707 .577 .707 r
F P
0 g
s
.65624 .82707 m .65721 .78945 L .62784 .79134 L p .707 .577 .707 r
F P
0 g
s
.56388 .82655 m .56485 .78893 L .53739 .78486 L p .707 .577 .707 r
F P
0 g
s
.56485 .78893 m .56388 .82655 L .59505 .82878 L p .707 .577 .707 r
F P
0 g
s
.68392 .66319 m .67972 .72051 L .69587 .71925 L p .707 .577 .707 r
F P
0 g
s
.69587 .71925 m .70006 .66193 L .68392 .66319 L p .707 .577 .707 r
F P
0 g
s
.53739 .78486 m .53642 .82248 L .56388 .82655 L p .707 .577 .707 r
F P
0 g
s
.65721 .78945 m .65624 .82707 L .68027 .8233 L p .707 .577 .707 r
F P
0 g
s
.68027 .8233 m .68124 .78568 L .65721 .78945 L p .707 .577 .707 r
F P
0 g
s
.59981 .83462 m .59933 .81646 L .56816 .81488 L p .707 .577 .707 r
F P
0 g
s
.59933 .81646 m .59981 .83462 L .63164 .83291 L p .707 .577 .707 r
F P
0 g
s
.63164 .83291 m .63115 .81474 L .59933 .81646 L p .707 .577 .707 r
F P
0 g
s
.51514 .70769 m .51933 .65037 L .50658 .64686 L p .707 .577 .707 r
F P
0 g
s
.63115 .81474 m .63164 .83291 L .661 .82807 L p .707 .577 .707 r
F P
0 g
s
.661 .82807 m .66052 .80991 L .63115 .81474 L p .707 .577 .707 r
F P
0 g
s
.56816 .81488 m .56864 .83304 L .59981 .83462 L p .707 .577 .707 r
F P
0 g
s
.56864 .83304 m .56816 .81488 L .5407 .81016 L p .707 .577 .707 r
F P
0 g
s
.53642 .82248 m .53739 .78486 L .51632 .77937 L p .707 .577 .707 r
F P
0 g
s
.50658 .64686 m .50238 .70418 L .51514 .70769 L p .707 .577 .707 r
F P
0 g
s
.5407 .81016 m .54118 .82833 L .56864 .83304 L p .707 .577 .707 r
F P
0 g
s
.68124 .78568 m .68027 .8233 L .69661 .81802 L p .707 .577 .707 r
F P
0 g
s
.66052 .80991 m .661 .82807 L .68503 .82058 L p .707 .577 .707 r
F P
0 g
s
.68503 .82058 m .68454 .80242 L .66052 .80991 L p .707 .577 .707 r
F P
0 g
s
.51632 .77937 m .51535 .81699 L .53642 .82248 L p .707 .577 .707 r
F P
0 g
s
.69661 .81802 m .69758 .7804 L .68124 .78568 L p .707 .577 .707 r
F P
0 g
s
.70006 .66193 m .69587 .71925 L .70272 .71699 L p .707 .577 .707 r
F P
0 g
s
.70272 .71699 m .70692 .65967 L .70006 .66193 L p .707 .577 .707 r
F P
0 g
s
.54118 .82833 m .5407 .81016 L .51963 .80277 L p .707 .577 .707 r
F P
0 g
s
.51963 .80277 m .52011 .82094 L .54118 .82833 L p .707 .577 .707 r
F P
0 g
s
.51535 .81699 m .51632 .77937 L .50371 .77298 L p .707 .577 .707 r
F P
0 g
s
.50238 .70418 m .50658 .64686 L .50347 .64383 L p .707 .577 .707 r
F P
0 g
s
.69758 .7804 m .69661 .81802 L .69807 .81672 L p .707 .577 .707 r
F P
0 g
s
.69811 .81305 m .70137 .81118 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.69841 .78467 m .69758 .7804 L .69807 .81672 L .707 .577 .707 r
F
.70137 .81118 m .70089 .79302 L .6983 .7945 L p F P
0 g
s
.6983 .7945 m .68454 .80242 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.70137 .81118 m .6983 .7945 L .69815 .8095 L .707 .577 .707 r
F
.70089 .79302 m .70137 .81118 L .70843 .80078 L p F P
0 g
s
.70843 .80078 m .70794 .78262 L .70089 .79302 L p .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .70463 .77412 L .69846 .77962 L p .707 .577 .707 r
F P
0 g
s
.69846 .77962 m .69758 .7804 L p .69841 .78467 L .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .69846 .77962 L .69841 .78467 L .707 .577 .707 r
F
.69807 .81672 m .70366 .81174 L p .69841 .78467 L F P
0 g
s
.68454 .80242 m .68503 .82058 L .69811 .81305 L p .707 .577 .707 r
F P
0 g
s
.69815 .8095 m .68454 .80242 L .69811 .81305 L .707 .577 .707 r
F
.50347 .64383 m .49928 .70115 L .50238 .70418 L p F P
0 g
s
.50371 .77298 m .50274 .8106 L .51535 .81699 L p .707 .577 .707 r
F P
0 g
s
.52011 .82094 m .51963 .80277 L .50702 .79343 L p .707 .577 .707 r
F P
0 g
s
.50702 .79343 m .5075 .81159 L .52011 .82094 L p .707 .577 .707 r
F P
0 g
s
.70692 .65967 m .70272 .71699 L .69962 .71396 L p .707 .577 .707 r
F P
0 g
s
.69962 .71396 m .70382 .65664 L .70692 .65967 L p .707 .577 .707 r
F P
0 g
s
.48847 .82191 m .49028 .31883 L .44627 .31609 L p .707 .577 .707 r
F P
0 g
s
.50274 .8106 m .50371 .77298 L .50079 .76632 L p .707 .577 .707 r
F P
0 g
s
.49928 .70115 m .50347 .64383 L .51033 .64157 L p .707 .577 .707 r
F P
0 g
s
.50079 .76632 m .49982 .80394 L .50274 .8106 L p .707 .577 .707 r
F P
0 g
s
.51033 .64157 m .50614 .69889 L .49928 .70115 L p .707 .577 .707 r
F P
0 g
s
.5075 .81159 m .50702 .79343 L .5041 .78305 L p .707 .577 .707 r
F P
0 g
s
.5041 .78305 m .50458 .80121 L .5075 .81159 L p .707 .577 .707 r
F P
0 g
s
.49982 .80394 m .50079 .76632 L .50785 .76004 L p .707 .577 .707 r
F P
0 g
s
.50614 .69889 m .51033 .64157 L .52647 .64031 L p .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .5041 .78305 L .51004 .7743 L p .707 .577 .707 r
F P
0 g
s
.50989 .75938 m .52419 .75475 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.51004 .7743 m .51116 .77265 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .51004 .7743 L .51007 .77736 L .707 .577 .707 r
F
.5102 .78943 m .52419 .75475 L .51027 .79656 L F
.51116 .77265 m .51164 .79081 L .51023 .79289 L p F P
0 g
s
.51023 .79289 m .50458 .80121 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.51007 .77736 m .51116 .77265 L .51023 .79289 L .707 .577 .707 r
F
.52419 .75475 m .52322 .79237 L .51027 .79656 L p F P
0 g
s
.51027 .79656 m .50688 .79766 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50785 .76004 L .50989 .75938 L p .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50989 .75938 L .5102 .78943 L .707 .577 .707 r
F
.50785 .76004 m .50688 .79766 L .49982 .80394 L p F P
0 g
s
.52647 .64031 m .52228 .69763 L .50614 .69889 L p .707 .577 .707 r
F P
0 g
s
.52228 .69763 m .52647 .64031 L .55032 .64017 L p .707 .577 .707 r
F P
0 g
s
.55032 .64017 m .54613 .69749 L .52228 .69763 L p .707 .577 .707 r
F P
0 g
s
.52322 .79237 m .52419 .75475 L .54822 .75099 L p .707 .577 .707 r
F P
0 g
s
.51164 .79081 m .51116 .77265 L .5275 .76325 L p .707 .577 .707 r
F P
0 g
s
.5275 .76325 m .52798 .78141 L .51164 .79081 L p .707 .577 .707 r
F P
0 g
s
.54822 .75099 m .54725 .78861 L .52322 .79237 L p .707 .577 .707 r
F P
0 g
s
.54725 .78861 m .54822 .75099 L .57758 .7491 L p .707 .577 .707 r
F P
0 g
s
.52798 .78141 m .5275 .76325 L .55153 .75576 L p .707 .577 .707 r
F P
0 g
s
.55153 .75576 m .55201 .77392 L .52798 .78141 L p .707 .577 .707 r
F P
0 g
s
.49028 .31883 m .48847 .82191 L .53342 .821 L p .707 .577 .707 r
F P
0 g
s
.53342 .821 m .53522 .31792 L .49028 .31883 L p .707 .577 .707 r
F P
0 g
s
.54613 .69749 m .55032 .64017 L .57954 .64116 L p .707 .577 .707 r
F P
0 g
s
.57954 .64116 m .57535 .69848 L .54613 .69749 L p .707 .577 .707 r
F P
0 g
s
.57758 .7491 m .57661 .78672 L .54725 .78861 L p .707 .577 .707 r
F P
0 g
s
.57661 .78672 m .57758 .7491 L .6094 .74928 L p .707 .577 .707 r
F P
0 g
s
.55201 .77392 m .55153 .75576 L .58089 .75092 L p .707 .577 .707 r
F P
0 g
s
.58089 .75092 m .58137 .76909 L .55201 .77392 L p .707 .577 .707 r
F P
0 g
s
.53522 .31792 m .53342 .821 L .5749 .81651 L p .707 .577 .707 r
F P
0 g
s
.5749 .81651 m .5767 .31344 L .53522 .31792 L p .707 .577 .707 r
F P
0 g
s
.44447 .81916 m .44627 .31609 L .40751 .30995 L p .707 .577 .707 r
F P
0 g
s
.44627 .31609 m .44447 .81916 L .48847 .82191 L p .707 .577 .707 r
F P
0 g
s
.70463 .77412 m .70366 .81174 L .70074 .80508 L p .707 .577 .707 r
F P
0 g
s
.70074 .80508 m .70171 .76746 L .70463 .77412 L p .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .57954 .64116 L .58524 .64152 L p .707 .577 .707 r
F P
0 g
s
.58524 .64152 m .61127 .64319 L p .57975 .6917 L .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .58524 .64152 L .57975 .6917 L .707 .577 .707 r
F
.64241 .64605 m .63821 .70338 L .60708 .70051 L p F P
0 g
s
.60708 .70051 m .61127 .64319 L .64241 .64605 L p .707 .577 .707 r
F P
0 g
s
.61127 .64319 m .60708 .70051 L .57535 .69848 L p .707 .577 .707 r
F P
0 g
s
.64057 .75151 m .6396 .78913 L .60843 .7869 L p .707 .577 .707 r
F P
0 g
s
.60843 .7869 m .6094 .74928 L .64057 .75151 L p .707 .577 .707 r
F P
0 g
s
.6396 .78913 m .64057 .75151 L .66803 .75557 L p .707 .577 .707 r
F P
0 g
s
.64388 .75079 m .64436 .76895 L .6132 .76737 L p .707 .577 .707 r
F P
0 g
s
.6132 .76737 m .61271 .74921 L .64388 .75079 L p .707 .577 .707 r
F P
0 g
s
.6094 .74928 m .60843 .7869 L .57661 .78672 L p .707 .577 .707 r
F P
0 g
s
.58137 .76909 m .58089 .75092 L .61271 .74921 L p .707 .577 .707 r
F P
0 g
s
.61271 .74921 m .6132 .76737 L .58137 .76909 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .63196 .7989 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61066 .30582 m .61028 .41273 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61028 .41273 m .60886 .8089 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.5767 .31344 m .5749 .81651 L .60886 .8089 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .61066 .30582 L .5767 .31344 L p .707 .577 .707 r
F P
0 g
s
.70382 .65664 m .69962 .71396 L .68687 .71045 L p .707 .577 .707 r
F P
0 g
s
.68687 .71045 m .69106 .65313 L .70382 .65664 L p .707 .577 .707 r
F P
0 g
s
.25192 .68082 m .25611 .6235 L .22498 .62063 L p .707 .577 .707 r
F P
0 g
s
.25611 .6235 m .25192 .68082 L .28365 .68285 L p .707 .577 .707 r
F P
0 g
s
.28365 .68285 m .28784 .62553 L .25611 .6235 L p .707 .577 .707 r
F P
0 g
s
.70794 .78262 m .70843 .80078 L .70551 .7904 L p .707 .577 .707 r
F P
0 g
s
.70551 .7904 m .70502 .77224 L .70794 .78262 L p .707 .577 .707 r
F P
0 g
s
.4057 .81303 m .40751 .30995 L .37778 .30102 L p .707 .577 .707 r
F P
0 g
s
.40751 .30995 m .4057 .81303 L .44447 .81916 L p .707 .577 .707 r
F P
0 g
s
.28784 .62553 m .28365 .68285 L .31287 .68384 L p .707 .577 .707 r
F P
0 g
s
.31287 .68384 m .31706 .62652 L .28784 .62553 L p .707 .577 .707 r
F P
0 g
s
.22498 .62063 m .22078 .67795 L .25192 .68082 L p .707 .577 .707 r
F P
0 g
s
.22078 .67795 m .22498 .62063 L .19748 .6172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19748 .6172 m .19329 .67453 L .22078 .67795 L p .707 .577 .707 r
F P
0 g
s
.31706 .62652 m .31287 .68384 L .33672 .6837 L p .707 .577 .707 r
F P
0 g
s
.33672 .6837 m .34091 .62638 L .31706 .62652 L p .707 .577 .707 r
F P
0 g
s
.63196 .7989 m .63377 .29582 L .61066 .30582 L p .707 .577 .707 r
F P
0 g
s
.70171 .76746 m .70074 .80508 L .68813 .79869 L p .707 .577 .707 r
F P
0 g
s
.68813 .79869 m .6891 .76107 L .70171 .76746 L p .707 .577 .707 r
F P
0 g
s
.19329 .67453 m .19748 .6172 L .17632 .61356 L p .707 .577 .707 r
F P
0 g
s
.69106 .65313 m .68687 .71045 L .66571 .7068 L p .707 .577 .707 r
F P
0 g
s
.66571 .7068 m .6699 .64948 L .69106 .65313 L p .707 .577 .707 r
F P
0 g
s
.17632 .61356 m .17213 .67088 L .19329 .67453 L p .707 .577 .707 r
F P
0 g
s
.25204 .79196 m .25301 .75434 L .22185 .75211 L p .707 .577 .707 r
F P
0 g
s
.25301 .75434 m .25204 .79196 L .28387 .79214 L p .707 .577 .707 r
F P
0 g
s
.28387 .79214 m .28484 .75452 L .25301 .75434 L p .707 .577 .707 r
F P
0 g
s
.70502 .77224 m .70551 .7904 L .69289 .78106 L p .707 .577 .707 r
F P
0 g
s
.69289 .78106 m .69241 .76289 L .70502 .77224 L p .707 .577 .707 r
F P
0 g
s
.28484 .75452 m .28387 .79214 L .31323 .79026 L p .707 .577 .707 r
F P
0 g
s
.31323 .79026 m .3142 .75264 L .28484 .75452 L p .707 .577 .707 r
F P
0 g
s
.37598 .8041 m .37778 .30102 L .36 .29018 L p .707 .577 .707 r
F P
0 g
s
.37778 .30102 m .37598 .8041 L .4057 .81303 L p .707 .577 .707 r
F P
0 g
s
.22087 .78973 m .22185 .75211 L .19438 .74805 L p .707 .577 .707 r
F P
0 g
s
.22185 .75211 m .22087 .78973 L .25204 .79196 L p .707 .577 .707 r
F P
0 g
s
.34091 .62638 m .33672 .6837 L .35286 .68244 L p .707 .577 .707 r
F P
0 g
s
.35286 .68244 m .35705 .62512 L .34091 .62638 L p .707 .577 .707 r
F P
0 g
s
.19438 .74805 m .19341 .78567 L .22087 .78973 L p .707 .577 .707 r
F P
0 g
s
.3142 .75264 m .31323 .79026 L .33726 .78649 L p .707 .577 .707 r
F P
0 g
s
.33726 .78649 m .33823 .74887 L .3142 .75264 L p .707 .577 .707 r
F P
0 g
s
.2568 .7978 m .25632 .77964 L .22515 .77806 L p .707 .577 .707 r
F P
0 g
s
.25632 .77964 m .2568 .7978 L .28863 .79609 L p .707 .577 .707 r
F P
0 g
s
.28863 .79609 m .28814 .77793 L .25632 .77964 L p .707 .577 .707 r
F P
0 g
s
.17213 .67088 m .17632 .61356 L .16357 .61004 L p .707 .577 .707 r
F P
0 g
s
.28814 .77793 m .28863 .79609 L .31799 .79125 L p .707 .577 .707 r
F P
0 g
s
.31799 .79125 m .31751 .77309 L .28814 .77793 L p .707 .577 .707 r
F P
0 g
s
.6699 .64948 m .66571 .7068 L .63821 .70338 L p .707 .577 .707 r
F P
0 g
s
.63821 .70338 m .64241 .64605 L .6699 .64948 L p .707 .577 .707 r
F P
0 g
s
.6891 .76107 m .68813 .79869 L .66706 .79319 L p .707 .577 .707 r
F P
0 g
s
.66706 .79319 m .66803 .75557 L .6891 .76107 L p .707 .577 .707 r
F P
0 g
s
.22515 .77806 m .22563 .79623 L .2568 .7978 L p .707 .577 .707 r
F P
0 g
s
.22563 .79623 m .22515 .77806 L .19769 .77335 L p .707 .577 .707 r
F P
0 g
s
.19341 .78567 m .19438 .74805 L .17331 .74255 L p .707 .577 .707 r
F P
0 g
s
.16357 .61004 m .15937 .66737 L .17213 .67088 L p .707 .577 .707 r
F P
0 g
s
.19769 .77335 m .19817 .79151 L .22563 .79623 L p .707 .577 .707 r
F P
0 g
s
.66803 .75557 m .66706 .79319 L .6396 .78913 L p .707 .577 .707 r
F P
0 g
s
.63377 .29582 m .63196 .7989 L .64196 .78749 L p .707 .577 .707 r
F P
0 g
s
.64196 .78749 m .64377 .28441 L .63377 .29582 L p .707 .577 .707 r
F P
0 g
s
.33823 .74887 m .33726 .78649 L .3536 .78121 L p .707 .577 .707 r
F P
0 g
s
.31751 .77309 m .31799 .79125 L .34202 .78377 L p .707 .577 .707 r
F P
0 g
s
.34202 .78377 m .34154 .76561 L .31751 .77309 L p .707 .577 .707 r
F P
0 g
s
.69241 .76289 m .69289 .78106 L .67183 .77367 L p .707 .577 .707 r
F P
0 g
s
.67183 .77367 m .67134 .7555 L .69241 .76289 L p .707 .577 .707 r
F P
0 g
s
.17331 .74255 m .17234 .78017 L .19341 .78567 L p .707 .577 .707 r
F P
0 g
s
.3536 .78121 m .35457 .74359 L .33823 .74887 L p .707 .577 .707 r
F P
0 g
s
.35705 .62512 m .35286 .68244 L .35971 .68018 L p .707 .577 .707 r
F P
0 g
s
.35971 .68018 m .36391 .62286 L .35705 .62512 L p .707 .577 .707 r
F P
0 g
s
.19817 .79151 m .19769 .77335 L .17662 .76596 L p .707 .577 .707 r
F P
0 g
s
.17662 .76596 m .1771 .78412 L .19817 .79151 L p .707 .577 .707 r
F P
0 g
s
.17234 .78017 m .17331 .74255 L .1607 .73616 L p .707 .577 .707 r
F P
0 g
s
.35457 .74359 m .3536 .78121 L .35506 .7799 L p .707 .577 .707 r
F P
0 g
s
.3554 .74785 m .35457 .74359 L .35506 .7799 L .707 .577 .707 r
F
.34154 .76561 m .34202 .78377 L .3551 .77624 L p F P
0 g
s
.3551 .77624 m .35836 .77436 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35514 .77269 m .34154 .76561 L .3551 .77624 L .707 .577 .707 r
F
.35836 .77436 m .35788 .7562 L .3553 .75769 L p F P
0 g
s
.3553 .75769 m .34154 .76561 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35836 .77436 m .3553 .75769 L .35514 .77269 L .707 .577 .707 r
F
.35788 .7562 m .35836 .77436 L .36542 .76396 L p F P
0 g
s
.36542 .76396 m .36493 .7458 L .35788 .7562 L p .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .36163 .73731 L .35545 .7428 L p .707 .577 .707 r
F P
0 g
s
.35545 .7428 m .35457 .74359 L p .3554 .74785 L .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .35545 .7428 L .3554 .74785 L .707 .577 .707 r
F
.35506 .7799 m .36065 .77493 L p .3554 .74785 L F P
0 g
s
.36391 .62286 m .35971 .68018 L .35661 .67715 L p .707 .577 .707 r
F P
0 g
s
.35661 .67715 m .36081 .61982 L .36391 .62286 L p .707 .577 .707 r
F P
0 g
s
.36163 .73731 m .36065 .77493 L .35773 .76827 L p .707 .577 .707 r
F P
0 g
s
.35773 .76827 m .3587 .73065 L .36163 .73731 L p .707 .577 .707 r
F P
0 g
s
.36081 .61982 m .35661 .67715 L .34386 .67363 L p .707 .577 .707 r
F P
0 g
s
.34386 .67363 m .34805 .61631 L .36081 .61982 L p .707 .577 .707 r
F P
0 g
s
.3587 .73065 m .35773 .76827 L .34512 .76187 L p .707 .577 .707 r
F P
0 g
s
.34512 .76187 m .34609 .72425 L .3587 .73065 L p .707 .577 .707 r
F P
0 g
s
.36201 .73542 m .3625 .75358 L .34988 .74424 L p .707 .577 .707 r
F P
0 g
s
.34988 .74424 m .3494 .72608 L .36201 .73542 L p .707 .577 .707 r
F P
0 g
s
.3582 .79326 m .36 .29018 L .35591 .27848 L p .707 .577 .707 r
F P
0 g
s
.36493 .7458 m .36542 .76396 L .3625 .75358 L p .707 .577 .707 r
F P
0 g
s
.3625 .75358 m .36201 .73542 L .36493 .7458 L p .707 .577 .707 r
F P
0 g
s
.36 .29018 m .3582 .79326 L .37598 .8041 L p .707 .577 .707 r
F P
0 g
s
.15937 .66737 m .16357 .61004 L .16047 .60701 L p .707 .577 .707 r
F P
0 g
s
.16047 .60701 m .15627 .66433 L .15937 .66737 L p .707 .577 .707 r
F P
0 g
s
.67134 .7555 m .67183 .77367 L .64436 .76895 L p .707 .577 .707 r
F P
0 g
s
.64436 .76895 m .64388 .75079 L .67134 .7555 L p .707 .577 .707 r
F P
0 g
s
.1607 .73616 m .15973 .77378 L .17234 .78017 L p .707 .577 .707 r
F P
0 g
s
.1771 .78412 m .17662 .76596 L .16401 .75662 L p .707 .577 .707 r
F P
0 g
s
.16401 .75662 m .16449 .77478 L .1771 .78412 L p .707 .577 .707 r
F P
0 g
s
.64377 .28441 m .64196 .78749 L .63787 .77579 L p .707 .577 .707 r
F P
0 g
s
.63787 .77579 m .63968 .27272 L .64377 .28441 L p .707 .577 .707 r
F P
0 g
s
.15973 .77378 m .1607 .73616 L .15778 .7295 L p .707 .577 .707 r
F P
0 g
s
.15627 .66433 m .16047 .60701 L .16732 .60475 L p .707 .577 .707 r
F P
0 g
s
.15778 .7295 m .15681 .76712 L .15973 .77378 L p .707 .577 .707 r
F P
0 g
s
.16732 .60475 m .16313 .66207 L .15627 .66433 L p .707 .577 .707 r
F P
0 g
s
.16449 .77478 m .16401 .75662 L .16109 .74624 L p .707 .577 .707 r
F P
0 g
s
.35591 .27848 m .35411 .78156 L .3582 .79326 L p .707 .577 .707 r
F P
0 g
s
.35411 .78156 m .35591 .27848 L .36591 .26707 L p .707 .577 .707 r
F P
0 g
s
.16109 .74624 m .16157 .7644 L .16449 .77478 L p .707 .577 .707 r
F P
0 g
s
.15681 .76712 m .15778 .7295 L .16484 .72322 L p .707 .577 .707 r
F P
0 g
s
.16313 .66207 m .16732 .60475 L .18346 .60349 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16157 .7644 m .16109 .74624 L .16703 .73748 L p .707 .577 .707 r
F P
0 g
s
.16688 .72256 m .18118 .71794 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16703 .73748 m .16815 .73584 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16157 .7644 m .16703 .73748 L .16706 .74055 L .707 .577 .707 r
F
.16719 .75262 m .18118 .71794 L .16726 .75975 L F
.16815 .73584 m .16863 .754 L .16722 .75607 L p F P
0 g
s
.16722 .75607 m .16157 .7644 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16706 .74055 m .16815 .73584 L .16722 .75607 L .707 .577 .707 r
F
.18118 .71794 m .18021 .75556 L .16726 .75975 L p F P
0 g
s
.16726 .75975 m .16387 .76084 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16484 .72322 L .16688 .72256 L p .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16688 .72256 L .16719 .75262 L .707 .577 .707 r
F
.16484 .72322 m .16387 .76084 L .15681 .76712 L p F P
0 g
s
.18346 .60349 m .17927 .66081 L .16313 .66207 L p .707 .577 .707 r
F P
0 g
s
.63968 .27272 m .63787 .77579 L .62009 .76495 L p .707 .577 .707 r
F P
0 g
s
.62009 .76495 m .6219 .26187 L .63968 .27272 L p .707 .577 .707 r
F P
0 g
s
.34805 .61631 m .34386 .67363 L .3227 .66999 L p .707 .577 .707 r
F P
0 g
s
.3227 .66999 m .32689 .61266 L .34805 .61631 L p .707 .577 .707 r
F P
0 g
s
.36411 .77015 m .36591 .26707 L .38902 .25707 L p .707 .577 .707 r
F P
0 g
s
.36591 .26707 m .36411 .77015 L .35411 .78156 L p .707 .577 .707 r
F P
0 g
s
.17927 .66081 m .18346 .60349 L .20731 .60335 L p .707 .577 .707 r
F P
0 g
s
.20731 .60335 m .20312 .66067 L .17927 .66081 L p .707 .577 .707 r
F P
0 g
s
.18021 .75556 m .18118 .71794 L .20521 .71417 L p .707 .577 .707 r
F P
0 g
s
.16863 .754 m .16815 .73584 L .18449 .72643 L p .707 .577 .707 r
F P
0 g
s
.32689 .61266 m .3227 .66999 L .2952 .66656 L p .707 .577 .707 r
F P
0 g
s
.2952 .66656 m .2994 .60924 L .32689 .61266 L p .707 .577 .707 r
F P
0 g
s
.34609 .72425 m .34512 .76187 L .32405 .75638 L p .707 .577 .707 r
F P
0 g
s
.32405 .75638 m .32502 .71876 L .34609 .72425 L p .707 .577 .707 r
F P
0 g
s
.18449 .72643 m .18497 .74459 L .16863 .754 L p .707 .577 .707 r
F P
0 g
s
.6219 .26187 m .62009 .76495 L .59037 .75602 L p .707 .577 .707 r
F P
0 g
s
.59037 .75602 m .59217 .25294 L .6219 .26187 L p .707 .577 .707 r
F P
0 g
s
.20312 .66067 m .20731 .60335 L .23653 .60434 L p .707 .577 .707 r
F P
0 g
s
.3494 .72608 m .34988 .74424 L .32882 .73685 L p .707 .577 .707 r
F P
0 g
s
.32882 .73685 m .32833 .71869 L .3494 .72608 L p .707 .577 .707 r
F P
0 g
s
.23653 .60434 m .23234 .66166 L .20312 .66067 L p .707 .577 .707 r
F P
0 g
s
.2994 .60924 m .2952 .66656 L .26407 .66369 L p .707 .577 .707 r
F P
0 g
s
.26407 .66369 m .26826 .60637 L .2994 .60924 L p .707 .577 .707 r
F P
0 g
s
.38902 .25707 m .38722 .76015 L .36411 .77015 L p .707 .577 .707 r
F P
0 g
s
.38722 .76015 m .38902 .25707 L .42298 .24946 L p .707 .577 .707 r
F P
0 g
s
.20521 .71417 m .20424 .75179 L .18021 .75556 L p .707 .577 .707 r
F P
0 g
s
.23234 .66166 m .23653 .60434 L .26826 .60637 L p .707 .577 .707 r
F P
0 g
s
.20424 .75179 m .20521 .71417 L .23457 .71228 L p .707 .577 .707 r
F P
0 g
s
.18497 .74459 m .18449 .72643 L .20852 .71895 L p .707 .577 .707 r
F P
0 g
s
.26826 .60637 m .26407 .66369 L .23234 .66166 L p .707 .577 .707 r
F P
0 g
s
.32502 .71876 m .32405 .75638 L .29659 .75232 L p .707 .577 .707 r
F P
0 g
s
.29659 .75232 m .29756 .7147 L .32502 .71876 L p .707 .577 .707 r
F P
0 g
s
.73213 .65321 m .73632 .59589 L .70519 .59302 L p .707 .577 .707 r
F P
0 g
s
.73632 .59589 m .73213 .65321 L .76386 .65524 L p .707 .577 .707 r
F P
0 g
s
.76386 .65524 m .76806 .59792 L .73632 .59589 L p .707 .577 .707 r
F P
0 g
s
.20852 .71895 m .209 .73711 L .18497 .74459 L p .707 .577 .707 r
F P
0 g
s
.76806 .59792 m .76386 .65524 L .79308 .65623 L p .707 .577 .707 r
F P
0 g
s
.79308 .65623 m .79728 .59891 L .76806 .59792 L p .707 .577 .707 r
F P
0 g
s
.70519 .59302 m .70099 .65034 L .73213 .65321 L p .707 .577 .707 r
F P
0 g
s
.70099 .65034 m .70519 .59302 L .67769 .58959 L p .707 .577 .707 r
F P
0 g
s
.73226 .68754 m .73323 .64992 L .70206 .64768 L p .707 .577 .707 r
F P
0 g
s
.73323 .64992 m .73226 .68754 L .76408 .68772 L p .707 .577 .707 r
F P
0 g
s
.76408 .68772 m .76505 .6501 L .73323 .64992 L p .707 .577 .707 r
F P
0 g
s
.32833 .71869 m .32882 .73685 L .30135 .73214 L p .707 .577 .707 r
F P
0 g
s
.30135 .73214 m .30087 .71397 L .32833 .71869 L p .707 .577 .707 r
F P
0 g
s
.76505 .6501 m .76408 .68772 L .79344 .68583 L p .707 .577 .707 r
F P
0 g
s
.79728 .59891 m .79308 .65623 L .81693 .65609 L p .707 .577 .707 r
F P
0 g
s
.79344 .68583 m .79441 .64821 L .76505 .6501 L p .707 .577 .707 r
F P
0 g
s
.59217 .25294 m .59037 .75602 L .5516 .74989 L p .707 .577 .707 r
F P
0 g
s
.5516 .74989 m .55341 .24681 L .59217 .25294 L p .707 .577 .707 r
F P
0 g
s
.67769 .58959 m .6735 .64692 L .70099 .65034 L p .707 .577 .707 r
F P
0 g
s
.70109 .68531 m .70206 .64768 L .6746 .64362 L p .707 .577 .707 r
F P
0 g
s
.70206 .64768 m .70109 .68531 L .73226 .68754 L p .707 .577 .707 r
F P
0 g
s
.23457 .71228 m .2336 .7499 L .20424 .75179 L p .707 .577 .707 r
F P
0 g
s
.29756 .7147 m .29659 .75232 L .26542 .75009 L p .707 .577 .707 r
F P
0 g
s
.26542 .75009 m .26639 .71247 L .29756 .7147 L p .707 .577 .707 r
F P
0 g
s
.81693 .65609 m .82112 .59877 L .79728 .59891 L p .707 .577 .707 r
F P
0 g
s
.2336 .7499 m .23457 .71228 L .26639 .71247 L p .707 .577 .707 r
F P
0 g
s
.209 .73711 m .20852 .71895 L .23788 .71411 L p .707 .577 .707 r
F P
0 g
s
.42117 .75254 m .42298 .24946 L .46446 .24497 L p .707 .577 .707 r
F P
0 g
s
.42298 .24946 m .42117 .75254 L .38722 .76015 L p .707 .577 .707 r
F P
0 g
s
.6746 .64362 m .67363 .68124 L .70109 .68531 L p .707 .577 .707 r
F P
0 g
s
.26639 .71247 m .26542 .75009 L .2336 .7499 L p .707 .577 .707 r
F P
0 g
s
.79441 .64821 m .79344 .68583 L .81747 .68206 L p .707 .577 .707 r
F P
0 g
s
.82112 .59877 m .81693 .65609 L .83307 .65483 L p .707 .577 .707 r
F P
0 g
s
.81747 .68206 m .81844 .64444 L .79441 .64821 L p .707 .577 .707 r
F P
0 g
s
.6735 .64692 m .67769 .58959 L .65653 .58595 L p .707 .577 .707 r
F P
0 g
s
.23788 .71411 m .23836 .73227 L .209 .73711 L p .707 .577 .707 r
F P
0 g
s
.30087 .71397 m .30135 .73214 L .27019 .73056 L p .707 .577 .707 r
F P
0 g
s
.27019 .73056 m .2697 .7124 L .30087 .71397 L p .707 .577 .707 r
F P
0 g
s
.65653 .58595 m .65234 .64327 L .6735 .64692 L p .707 .577 .707 r
F P
0 g
s
.23836 .73227 m .23788 .71411 L .2697 .7124 L p .707 .577 .707 r
F P
0 g
s
.67363 .68124 m .6746 .64362 L .65353 .63813 L p .707 .577 .707 r
F P
0 g
s
.2697 .7124 m .27019 .73056 L .23836 .73227 L p .707 .577 .707 r
F P
0 g
s
.55341 .24681 m .5516 .74989 L .5076 .74714 L p .707 .577 .707 r
F P
0 g
s
.5076 .74714 m .5094 .24406 L .55341 .24681 L p .707 .577 .707 r
F P
0 g
s
.83307 .65483 m .83727 .59751 L .82112 .59877 L p .707 .577 .707 r
F P
0 g
s
.65353 .63813 m .65256 .67575 L .67363 .68124 L p .707 .577 .707 r
F P
0 g
s
.46265 .74805 m .46446 .24497 L .5094 .24406 L p .707 .577 .707 r
F P
0 g
s
.46446 .24497 m .46265 .74805 L .42117 .75254 L p .707 .577 .707 r
F P
0 g
s
.5094 .24406 m .5076 .74714 L .46265 .74805 L p .707 .577 .707 r
F P
0 g
s
.81844 .64444 m .81747 .68206 L .83381 .67678 L p .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84184 .63288 L .84141 .63326 L p .707 .577 .707 r
F P
0 g
s
.84141 .63326 m .83478 .63916 L p .83943 .66309 L .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84141 .63326 L .83943 .66309 L .707 .577 .707 r
F
.83727 .59751 m .83509 .62724 L p .83993 .65257 L F P
0 g
s
.83381 .67678 m .83478 .63916 L .83438 .63929 L p .707 .577 .707 r
F P
0 g
s
.83381 .67678 m .83438 .63929 L .83234 .67367 L .707 .577 .707 r
F
.83478 .63916 m .83381 .67678 L .84087 .6705 L p F P
0 g
s
.83346 .6547 m .83993 .65257 L p .83509 .62724 L .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .8421 .62296 L p .83727 .59751 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .84412 .59525 L .84298 .59562 L p .707 .577 .707 r
F P
0 g
s
.84298 .59562 m .83727 .59751 L p .8421 .62296 L .707 .577 .707 r
F P
0 g
s
.84184 .63288 m .84087 .6705 L .84058 .66984 L p .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .83683 .64953 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .83993 .65257 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.84058 .66984 m .83795 .66384 L p .84175 .63357 L .707 .577 .707 r
F P
0 g
s
.84175 .63357 m .84184 .63288 L .84058 .66984 L .707 .577 .707 r
F
.84412 .59525 m .8421 .62296 L p .84375 .598 L F P
0 g
s
.83509 .62724 m .83307 .65483 L .83346 .6547 L p .707 .577 .707 r
F P
0 g
s
.83438 .63929 m .81844 .64444 L p .83234 .67367 L .707 .577 .707 r
F P
0 g
s
.65234 .64327 m .65653 .58595 L .64378 .58243 L p .707 .577 .707 r
F P
0 g
s
.73702 .78439 m .73653 .76623 L .70537 .76465 L p .707 .577 .707 r
F P
0 g
s
.73653 .76623 m .73702 .78439 L .76884 .78268 L p .707 .577 .707 r
F P
0 g
s
.76884 .78268 m .76836 .76451 L .73653 .76623 L p .707 .577 .707 r
F P
0 g
s
.76836 .76451 m .76884 .78268 L .7982 .77784 L p .707 .577 .707 r
F P
0 g
s
.7982 .77784 m .79772 .75968 L .76836 .76451 L p .707 .577 .707 r
F P
0 g
s
.64378 .58243 m .63958 .63976 L .65234 .64327 L p .707 .577 .707 r
F P
0 g
s
.65256 .67575 m .65353 .63813 L .64092 .63174 L p .707 .577 .707 r
F P
0 g
s
.70537 .76465 m .70585 .78281 L .73702 .78439 L p .707 .577 .707 r
F P
0 g
s
.70585 .78281 m .70537 .76465 L .6779 .75993 L p .707 .577 .707 r
F P
0 g
s
.64092 .63174 m .63995 .66936 L .65256 .67575 L p .707 .577 .707 r
F P
0 g
s
.6779 .75993 m .67839 .7781 L .70585 .78281 L p .707 .577 .707 r
F P
0 g
s
.79772 .75968 m .7982 .77784 L .82223 .77035 L p .707 .577 .707 r
F P
0 g
s
.82223 .77035 m .82175 .75219 L .79772 .75968 L p .707 .577 .707 r
F P
0 g
s
.67839 .7781 m .6779 .75993 L .65684 .75254 L p .707 .577 .707 r
F P
0 g
s
.63958 .63976 m .64378 .58243 L .64068 .5794 L p .707 .577 .707 r
F P
0 g
s
.65684 .75254 m .65732 .77071 L .67839 .7781 L p .707 .577 .707 r
F P
0 g
s
.64068 .5794 m .63648 .63672 L .63958 .63976 L p .707 .577 .707 r
F P
0 g
s
.63995 .66936 m .64092 .63174 L .638 .62507 L p .707 .577 .707 r
F P
0 g
s
.82175 .75219 m .82223 .77035 L .83857 .76095 L p .707 .577 .707 r
F P
0 g
s
.83857 .76095 m .83809 .74279 L .82175 .75219 L p .707 .577 .707 r
F P
0 g
s
.638 .62507 m .63702 .66269 L .63995 .66936 L p .707 .577 .707 r
F P
0 g
s
.65732 .77071 m .65684 .75254 L .64422 .7432 L p .707 .577 .707 r
F P
0 g
s
.83683 .64953 m .83913 .6181 L p .84412 .59525 L .707 .577 .707 r
F P
0 g
s
.84102 .59221 m .83683 .64953 L .82407 .64602 L p .707 .577 .707 r
F P
0 g
s
.83892 .62622 m .83795 .66384 L .83449 .66209 L p .707 .577 .707 r
F P
0 g
s
.83449 .66209 m .82534 .65745 L p .83806 .62818 L .707 .577 .707 r
F P
0 g
s
.83806 .62818 m .83892 .62622 L .83449 .66209 L .707 .577 .707 r
F
.83913 .6181 m .84102 .59221 L .84178 .59295 L p F P
0 g
s
.84178 .59295 m .84412 .59525 L p .83913 .6181 L .707 .577 .707 r
F P
0 g
s
.64422 .7432 m .64471 .76136 L .65732 .77071 L p .707 .577 .707 r
F P
0 g
s
.83795 .66384 m .83892 .62622 L .84184 .63288 L p .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .638 .62507 L .64488 .61895 L p .707 .577 .707 r
F P
0 g
s
.64536 .60688 m .64753 .57714 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.64488 .61895 m .64505 .61879 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .64488 .61895 L .64483 .61998 L .707 .577 .707 r
F
.64753 .57714 m .66368 .57588 L p .64437 .63149 L F P
0 g
s
.66368 .57588 m .65948 .6332 L .64426 .63439 L p .707 .577 .707 r
F P
0 g
s
.64437 .63149 m .66368 .57588 L .64426 .63439 L .707 .577 .707 r
F
.64505 .61879 m .64408 .65642 L .64335 .65707 L p F P
0 g
s
.64335 .65707 m .63702 .66269 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.64483 .61998 m .64505 .61879 L .64335 .65707 L .707 .577 .707 r
F
.64426 .63439 m .64334 .63446 L p .64437 .63149 L F P
0 g
s
.64334 .63446 m .64536 .60688 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.63648 .63672 m .64068 .5794 L .64753 .57714 L p .707 .577 .707 r
F P
0 g
s
.83809 .74279 m .83857 .76095 L .84563 .75055 L p .707 .577 .707 r
F P
0 g
s
.84563 .75055 m .84515 .73239 L .83809 .74279 L p .707 .577 .707 r
F P
0 g
s
.64753 .57714 m .64334 .63446 L .63648 .63672 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64471 .76136 m .64422 .7432 L .6413 .73282 L p .707 .577 .707 r
F P
0 g
s
.6413 .73282 m .64179 .75098 L .64471 .76136 L p .707 .577 .707 r
F P
0 g
s
.82407 .64602 m .82648 .61313 L p .84102 .59221 L .707 .577 .707 r
F P
0 g
s
.82827 .5887 m .82407 .64602 L .80291 .64237 L p .707 .577 .707 r
F P
0 g
s
.82631 .61983 m .82534 .65745 L .81662 .65517 L p .707 .577 .707 r
F P
0 g
s
.81662 .65517 m .80427 .65195 L p .82418 .62292 L .707 .577 .707 r
F P
0 g
s
.82418 .62292 m .82631 .61983 L .81662 .65517 L .707 .577 .707 r
F
.82648 .61313 m .82827 .5887 L .83197 .58972 L p F P
0 g
s
.83197 .58972 m .84102 .59221 L p .82648 .61313 L .707 .577 .707 r
F P
0 g
s
.82534 .65745 m .82631 .61983 L .83892 .62622 L p .707 .577 .707 r
F P
0 g
s
.38912 .61639 m .39331 .55907 L .36218 .5562 L p .707 .577 .707 r
F P
0 g
s
.39331 .55907 m .38912 .61639 L .42085 .61842 L p .707 .577 .707 r
F P
0 g
s
.42085 .61842 m .42505 .5611 L .39331 .55907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42505 .5611 m .42085 .61842 L .45007 .61941 L p .707 .577 .707 r
F P
0 g
s
.45007 .61941 m .45427 .56209 L .42505 .5611 L p .707 .577 .707 r
F P
0 g
s
.84515 .73239 m .84563 .75055 L .84271 .74017 L p .707 .577 .707 r
F P
0 g
s
.84271 .74017 m .84223 .72201 L .84515 .73239 L p .707 .577 .707 r
F P
0 g
s
.36218 .5562 m .35798 .61352 L .38912 .61639 L p .707 .577 .707 r
F P
0 g
s
.35798 .61352 m .36218 .5562 L .33468 .55278 L p .707 .577 .707 r
F P
0 g
s
.38925 .65072 m .39022 .6131 L .35905 .61087 L p .707 .577 .707 r
F P
0 g
s
.39022 .6131 m .38925 .65072 L .42107 .6509 L p .707 .577 .707 r
F P
0 g
s
.42107 .6509 m .42204 .61328 L .39022 .6131 L p .707 .577 .707 r
F P
0 g
s
.42204 .61328 m .42107 .6509 L .45043 .64902 L p .707 .577 .707 r
F P
0 g
s
.45427 .56209 m .45007 .61941 L .47392 .61927 L p .707 .577 .707 r
F P
0 g
s
.45043 .64902 m .4514 .6114 L .42204 .61328 L p .707 .577 .707 r
F P
0 g
s
.65948 .6332 m .66165 .60359 L p .68753 .57574 L .707 .577 .707 r
F P
0 g
s
.66165 .60359 m .66368 .57588 L .66503 .57587 L p .707 .577 .707 r
F P
0 g
s
.66503 .57587 m .68753 .57574 L p .66165 .60359 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .64505 .61879 L .6604 .61383 L p .707 .577 .707 r
F P
0 g
s
.6604 .61383 m .66139 .61351 L p .66003 .6169 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .6604 .61383 L .66003 .6169 L .707 .577 .707 r
F
.33468 .55278 m .33049 .6101 L .35798 .61352 L p F P
0 g
s
.35808 .64849 m .35905 .61087 L .33159 .60681 L p .707 .577 .707 r
F P
0 g
s
.35905 .61087 m .35808 .64849 L .38925 .65072 L p .707 .577 .707 r
F P
0 g
s
.47392 .61927 m .47811 .56195 L .45427 .56209 L p .707 .577 .707 r
F P
0 g
s
.68753 .57574 m .68333 .63306 L .65948 .6332 L p .707 .577 .707 r
F P
0 g
s
.66139 .61351 m .66042 .65113 L .64408 .65642 L p .707 .577 .707 r
F P
0 g
s
.64179 .75098 m .6413 .73282 L .64836 .72242 L p .707 .577 .707 r
F P
0 g
s
.33159 .60681 m .33062 .64443 L .35808 .64849 L p .707 .577 .707 r
F P
0 g
s
.4514 .6114 m .45043 .64902 L .47446 .64525 L p .707 .577 .707 r
F P
0 g
s
.47811 .56195 m .47392 .61927 L .49006 .61801 L p .707 .577 .707 r
F P
0 g
s
.47446 .64525 m .47543 .60763 L .4514 .6114 L p .707 .577 .707 r
F P
0 g
s
.33049 .6101 m .33468 .55278 L .31352 .54913 L p .707 .577 .707 r
F P
0 g
s
.80291 .64237 m .80539 .60856 L p .82827 .5887 L .707 .577 .707 r
F P
0 g
s
.80711 .58505 m .80291 .64237 L .77542 .63895 L p .707 .577 .707 r
F P
0 g
s
.80524 .61433 m .80427 .65195 L .79018 .64987 L p .707 .577 .707 r
F P
0 g
s
.79018 .64987 m .77681 .64789 L p .80174 .61846 L .707 .577 .707 r
F P
0 g
s
.80174 .61846 m .80524 .61433 L .79018 .64987 L .707 .577 .707 r
F
.80539 .60856 m .80711 .58505 L .81363 .58618 L p F P
0 g
s
.81363 .58618 m .82827 .5887 L p .80539 .60856 L .707 .577 .707 r
F P
0 g
s
.64836 .72242 m .64884 .74058 L .64179 .75098 L p .707 .577 .707 r
F P
0 g
s
.31352 .54913 m .30933 .60645 L .33049 .6101 L p .707 .577 .707 r
F P
0 g
s
.80427 .65195 m .80524 .61433 L .82631 .61983 L p .707 .577 .707 r
F P
0 g
s
.33062 .64443 m .33159 .60681 L .31052 .60131 L p .707 .577 .707 r
F P
0 g
s
.84223 .72201 m .84271 .74017 L .8301 .73083 L p .707 .577 .707 r
F P
0 g
s
.8301 .73083 m .82962 .71266 L .84223 .72201 L p .707 .577 .707 r
F P
0 g
s
.49006 .61801 m .49426 .56069 L .47811 .56195 L p .707 .577 .707 r
F P
0 g
s
.31052 .60131 m .30955 .63893 L .33062 .64443 L p .707 .577 .707 r
F P
0 g
s
.68333 .63306 m .68563 .60162 L p .71675 .57673 L .707 .577 .707 r
F P
0 g
s
.68563 .60162 m .68753 .57574 L .69199 .57589 L p .707 .577 .707 r
F P
0 g
s
.69199 .57589 m .71675 .57673 L p .68563 .60162 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .66139 .61351 L .68355 .61004 L p .707 .577 .707 r
F P
0 g
s
.68355 .61004 m .68542 .60974 L p .68238 .61478 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .68355 .61004 L .68238 .61478 L .707 .577 .707 r
F
.47543 .60763 m .47446 .64525 L .4908 .63996 L p F P
0 g
s
.49786 .63368 m .49883 .59606 L .4984 .59645 L p .707 .577 .707 r
F P
0 g
s
.4984 .59645 m .49177 .60234 L p .49642 .62627 L .707 .577 .707 r
F P
0 g
s
.49786 .63368 m .4984 .59645 L .49642 .62627 L .707 .577 .707 r
F
.49426 .56069 m .49208 .59043 L p .49692 .61575 L F P
0 g
s
.4908 .63996 m .49177 .60234 L .49137 .60248 L p .707 .577 .707 r
F P
0 g
s
.4908 .63996 m .49137 .60248 L .48933 .63686 L .707 .577 .707 r
F
.49177 .60234 m .4908 .63996 L .49786 .63368 L p F P
0 g
s
.49045 .61788 m .49692 .61575 L p .49208 .59043 L .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49908 .58614 L p .49426 .56069 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .50111 .55843 L .49997 .55881 L p .707 .577 .707 r
F P
0 g
s
.49997 .55881 m .49426 .56069 L p .49908 .58614 L .707 .577 .707 r
F P
0 g
s
.49883 .59606 m .49786 .63368 L .49757 .63303 L p .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49382 .61272 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .49692 .61575 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49757 .63303 m .49494 .62702 L p .49874 .59676 L .707 .577 .707 r
F P
0 g
s
.49874 .59676 m .49883 .59606 L .49757 .63303 L .707 .577 .707 r
F
.50111 .55843 m .49908 .58614 L p .50074 .56118 L F P
0 g
s
.49208 .59043 m .49006 .61801 L .49045 .61788 L p .707 .577 .707 r
F P
0 g
s
.49137 .60248 m .47543 .60763 L p .48933 .63686 L .707 .577 .707 r
F P
0 g
s
.71675 .57673 m .71255 .63405 L .68333 .63306 L p .707 .577 .707 r
F P
0 g
s
.68542 .60974 m .68445 .64736 L .66042 .65113 L p .707 .577 .707 r
F P
0 g
s
.30933 .60645 m .31352 .54913 L .30077 .54562 L p .707 .577 .707 r
F P
0 g
s
.39401 .74757 m .39352 .72941 L .36236 .72783 L p .707 .577 .707 r
F P
0 g
s
.39352 .72941 m .39401 .74757 L .42583 .74586 L p .707 .577 .707 r
F P
0 g
s
.42583 .74586 m .42535 .7277 L .39352 .72941 L p .707 .577 .707 r
F P
0 g
s
.77542 .63895 m .77792 .60481 L p .80711 .58505 L .707 .577 .707 r
F P
0 g
s
.77961 .58163 m .77542 .63895 L .74428 .63608 L p .707 .577 .707 r
F P
0 g
s
.77778 .61027 m .77681 .64789 L .75907 .64662 L p .707 .577 .707 r
F P
0 g
s
.75907 .64662 m .74564 .64566 L p .77317 .61534 L .707 .577 .707 r
F P
0 g
s
.77317 .61534 m .77778 .61027 L .75907 .64662 L .707 .577 .707 r
F
.77792 .60481 m .77961 .58163 L .7879 .58266 L p F P
0 g
s
.7879 .58266 m .80711 .58505 L p .77792 .60481 L .707 .577 .707 r
F P
0 g
s
.64884 .74058 m .64836 .72242 L .6647 .71302 L p .707 .577 .707 r
F P
0 g
s
.42535 .7277 m .42583 .74586 L .45519 .74102 L p .707 .577 .707 r
F P
0 g
s
.45519 .74102 m .45471 .72286 L .42535 .7277 L p .707 .577 .707 r
F P
0 g
s
.30077 .54562 m .29657 .60294 L .30933 .60645 L p .707 .577 .707 r
F P
0 g
s
.77681 .64789 m .77778 .61027 L .80524 .61433 L p .707 .577 .707 r
F P
0 g
s
.30955 .63893 m .31052 .60131 L .29791 .59492 L p .707 .577 .707 r
F P
0 g
s
.36236 .72783 m .36284 .746 L .39401 .74757 L p .707 .577 .707 r
F P
0 g
s
.36284 .746 m .36236 .72783 L .33489 .72312 L p .707 .577 .707 r
F P
0 g
s
.6647 .71302 m .66518 .73118 L .64884 .74058 L p .707 .577 .707 r
F P
0 g
s
.71255 .63405 m .71496 .60116 L p .74848 .57876 L .707 .577 .707 r
F P
0 g
s
.71496 .60116 m .71675 .57673 L .72387 .57719 L p .707 .577 .707 r
F P
0 g
s
.72387 .57719 m .74848 .57876 L p .71496 .60116 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .68542 .60974 L .71241 .60801 L p .707 .577 .707 r
F P
0 g
s
.71241 .60801 m .71478 .60786 L p .7103 .6137 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .71241 .60801 L .7103 .6137 L .707 .577 .707 r
F
.29791 .59492 m .29693 .63254 L .30955 .63893 L p F P
0 g
s
.33489 .72312 m .33538 .74128 L .36284 .746 L p .707 .577 .707 r
F P
0 g
s
.45471 .72286 m .45519 .74102 L .47922 .73354 L p .707 .577 .707 r
F P
0 g
s
.47922 .73354 m .47874 .71538 L .45471 .72286 L p .707 .577 .707 r
F P
0 g
s
.82962 .71266 m .8301 .73083 L .80903 .72344 L p .707 .577 .707 r
F P
0 g
s
.80903 .72344 m .80855 .70527 L .82962 .71266 L p .707 .577 .707 r
F P
0 g
s
.74848 .57876 m .74428 .63608 L .71255 .63405 L p .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .71478 .60786 L .74416 .60802 L p .707 .577 .707 r
F P
0 g
s
.74428 .63608 m .74676 .60226 L p .77961 .58163 L .707 .577 .707 r
F P
0 g
s
.74416 .60802 m .74661 .60804 L p .74156 .61381 L .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .74416 .60802 L .74156 .61381 L .707 .577 .707 r
F
.74676 .60226 m .74848 .57876 L .75699 .57955 L p F P
0 g
s
.75699 .57955 m .77961 .58163 L p .74676 .60226 L .707 .577 .707 r
F P
0 g
s
.71478 .60786 m .71381 .64548 L .68445 .64736 L p .707 .577 .707 r
F P
0 g
s
.74564 .64566 m .74661 .60804 L .77778 .61027 L p .707 .577 .707 r
F P
0 g
s
.33538 .74128 m .33489 .72312 L .31383 .71573 L p .707 .577 .707 r
F P
0 g
s
.74661 .60804 m .74564 .64566 L .71381 .64548 L p .707 .577 .707 r
F P
0 g
s
.66518 .73118 m .6647 .71302 L .68873 .70553 L p .707 .577 .707 r
F P
0 g
s
.29657 .60294 m .30077 .54562 L .29767 .54258 L p .707 .577 .707 r
F P
0 g
s
.31383 .71573 m .31431 .73389 L .33538 .74128 L p .707 .577 .707 r
F P
0 g
s
.29767 .54258 m .29347 .59991 L .29657 .60294 L p .707 .577 .707 r
F P
0 g
s
.68873 .70553 m .68921 .72369 L .66518 .73118 L p .707 .577 .707 r
F P
0 g
s
.29693 .63254 m .29791 .59492 L .29498 .58826 L p .707 .577 .707 r
F P
0 g
s
.47874 .71538 m .47922 .73354 L .49556 .72413 L p .707 .577 .707 r
F P
0 g
s
.49556 .72413 m .49508 .70597 L .47874 .71538 L p .707 .577 .707 r
F P
0 g
s
.80855 .70527 m .80903 .72344 L .78157 .71872 L p .707 .577 .707 r
F P
0 g
s
.78157 .71872 m .78109 .70056 L .80855 .70527 L p .707 .577 .707 r
F P
0 g
s
.29498 .58826 m .29401 .62588 L .29693 .63254 L p .707 .577 .707 r
F P
0 g
s
.31431 .73389 m .31383 .71573 L .30121 .70639 L p .707 .577 .707 r
F P
0 g
s
.68921 .72369 m .68873 .70553 L .71809 .70069 L p .707 .577 .707 r
F P
0 g
s
.49382 .61272 m .49612 .58128 L p .50111 .55843 L .707 .577 .707 r
F P
0 g
s
.49801 .5554 m .49382 .61272 L .48106 .60921 L p .707 .577 .707 r
F P
0 g
s
.49591 .5894 m .49494 .62702 L .49148 .62527 L p .707 .577 .707 r
F P
0 g
s
.49148 .62527 m .48233 .62063 L p .49505 .59137 L .707 .577 .707 r
F P
0 g
s
.49505 .59137 m .49591 .5894 L .49148 .62527 L .707 .577 .707 r
F
.49612 .58128 m .49801 .5554 L .49877 .55614 L p F P
0 g
s
.49877 .55614 m .50111 .55843 L p .49612 .58128 L .707 .577 .707 r
F P
0 g
s
.30121 .70639 m .3017 .72455 L .31431 .73389 L p .707 .577 .707 r
F P
0 g
s
.71809 .70069 m .71858 .71886 L .68921 .72369 L p .707 .577 .707 r
F P
0 g
s
.49494 .62702 m .49591 .5894 L .49883 .59606 L p .707 .577 .707 r
F P
0 g
s
.78109 .70056 m .78157 .71872 L .7504 .71714 L p .707 .577 .707 r
F P
0 g
s
.7504 .71714 m .74992 .69898 L .78109 .70056 L p .707 .577 .707 r
F P
0 g
s
.71858 .71886 m .71809 .70069 L .74992 .69898 L p .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .29498 .58826 L .30186 .58214 L p .707 .577 .707 r
F P
0 g
s
.30235 .57006 m .30452 .54033 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.30186 .58214 m .30204 .58198 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .30186 .58214 L .30182 .58317 L .707 .577 .707 r
F
.30452 .54033 m .32067 .53906 L p .30136 .59467 L F P
0 g
s
.32067 .53906 m .31647 .59639 L .30125 .59758 L p .707 .577 .707 r
F P
0 g
s
.30136 .59467 m .32067 .53906 L .30125 .59758 L .707 .577 .707 r
F
.30204 .58198 m .30107 .6196 L .30034 .62025 L p F P
0 g
s
.30034 .62025 m .29401 .62588 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.30182 .58317 m .30204 .58198 L .30034 .62025 L .707 .577 .707 r
F
.30125 .59758 m .30033 .59765 L p .30136 .59467 L F P
0 g
s
.30033 .59765 m .30235 .57006 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.29347 .59991 m .29767 .54258 L .30452 .54033 L p .707 .577 .707 r
F P
0 g
s
.49508 .70597 m .49556 .72413 L .50262 .71373 L p .707 .577 .707 r
F P
0 g
s
.50262 .71373 m .50214 .69557 L .49508 .70597 L p .707 .577 .707 r
F P
0 g
s
.74992 .69898 m .7504 .71714 L .71858 .71886 L p .707 .577 .707 r
F P
0 g
s
.30452 .54033 m .30033 .59765 L .29347 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3017 .72455 m .30121 .70639 L .29829 .69601 L p .707 .577 .707 r
F P
0 g
s
.29829 .69601 m .29878 .71417 L .3017 .72455 L p .707 .577 .707 r
F P
0 g
s
.48106 .60921 m .48347 .57632 L p .49801 .5554 L .707 .577 .707 r
F P
0 g
s
.48526 .55189 m .48106 .60921 L .4599 .60556 L p .707 .577 .707 r
F P
0 g
s
.4833 .58301 m .48233 .62063 L .47361 .61836 L p .707 .577 .707 r
F P
0 g
s
.47361 .61836 m .46126 .61514 L p .48117 .5861 L .707 .577 .707 r
F P
0 g
s
.48117 .5861 m .4833 .58301 L .47361 .61836 L .707 .577 .707 r
F
.48347 .57632 m .48526 .55189 L .48896 .55291 L p F P
0 g
s
.48896 .55291 m .49801 .5554 L p .48347 .57632 L .707 .577 .707 r
F P
0 g
s
.48233 .62063 m .4833 .58301 L .49591 .5894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50214 .69557 m .50262 .71373 L .4997 .70335 L p .707 .577 .707 r
F P
0 g
s
.4997 .70335 m .49922 .68519 L .50214 .69557 L p .707 .577 .707 r
F P
0 g
s
.31647 .59639 m .31864 .56678 L p .34451 .53892 L .707 .577 .707 r
F P
0 g
s
.31864 .56678 m .32067 .53906 L .32202 .53906 L p .707 .577 .707 r
F P
0 g
s
.32202 .53906 m .34451 .53892 L p .31864 .56678 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .30204 .58198 L .31739 .57702 L p .707 .577 .707 r
F P
0 g
s
.31739 .57702 m .31838 .5767 L p .31702 .58008 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .31739 .57702 L .31702 .58008 L .707 .577 .707 r
F
.34451 .53892 m .34032 .59624 L .31647 .59639 L p F P
0 g
s
.31838 .5767 m .31741 .61432 L .30107 .6196 L p .707 .577 .707 r
F P
0 g
s
.29878 .71417 m .29829 .69601 L .30535 .68561 L p .707 .577 .707 r
F P
0 g
s
.4599 .60556 m .46238 .57174 L p .48526 .55189 L .707 .577 .707 r
F P
0 g
s
.4641 .54824 m .4599 .60556 L .43241 .60213 L p .707 .577 .707 r
F P
0 g
s
.46223 .57752 m .46126 .61514 L .44717 .61305 L p .707 .577 .707 r
F P
0 g
s
.44717 .61305 m .43379 .61107 L p .45873 .58164 L .707 .577 .707 r
F P
0 g
s
.45873 .58164 m .46223 .57752 L .44717 .61305 L .707 .577 .707 r
F
.46238 .57174 m .4641 .54824 L .47062 .54936 L p F P
0 g
s
.47062 .54936 m .48526 .55189 L p .46238 .57174 L .707 .577 .707 r
F P
0 g
s
.30535 .68561 m .30583 .70377 L .29878 .71417 L p .707 .577 .707 r
F P
0 g
s
.46126 .61514 m .46223 .57752 L .4833 .58301 L p .707 .577 .707 r
F P
0 g
s
.49922 .68519 m .4997 .70335 L .48709 .69401 L p .707 .577 .707 r
F P
0 g
s
.48709 .69401 m .48661 .67585 L .49922 .68519 L p .707 .577 .707 r
F P
0 g
s
.34032 .59624 m .34262 .56481 L p .37373 .53992 L .707 .577 .707 r
F P
0 g
s
.34262 .56481 m .34451 .53892 L .34898 .53907 L p .707 .577 .707 r
F P
0 g
s
.34898 .53907 m .37373 .53992 L p .34262 .56481 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .31838 .5767 L .34054 .57322 L p .707 .577 .707 r
F P
0 g
s
.34054 .57322 m .34241 .57293 L p .33937 .57796 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .34054 .57322 L .33937 .57796 L .707 .577 .707 r
F
.37373 .53992 m .36954 .59724 L .34032 .59624 L p F P
0 g
s
.34241 .57293 m .34144 .61055 L .31741 .61432 L p .707 .577 .707 r
F P
0 g
s
.43241 .60213 m .43491 .56799 L p .4641 .54824 L .707 .577 .707 r
F P
0 g
s
.4366 .54481 m .43241 .60213 L .40127 .59927 L p .707 .577 .707 r
F P
0 g
s
.43477 .57345 m .43379 .61107 L .41606 .6098 L p .707 .577 .707 r
F P
0 g
s
.41606 .6098 m .40263 .60884 L p .43016 .57853 L .707 .577 .707 r
F P
0 g
s
.43016 .57853 m .43477 .57345 L .41606 .6098 L .707 .577 .707 r
F
.43491 .56799 m .4366 .54481 L .44489 .54585 L p F P
0 g
s
.44489 .54585 m .4641 .54824 L p .43491 .56799 L .707 .577 .707 r
F P
0 g
s
.30583 .70377 m .30535 .68561 L .32169 .6762 L p .707 .577 .707 r
F P
0 g
s
.43379 .61107 m .43477 .57345 L .46223 .57752 L p .707 .577 .707 r
F P
0 g
s
.32169 .6762 m .32217 .69436 L .30583 .70377 L p .707 .577 .707 r
F P
0 g
s
.36954 .59724 m .37195 .56435 L p .40547 .54195 L .707 .577 .707 r
F P
0 g
s
.37195 .56435 m .37373 .53992 L .38086 .54037 L p .707 .577 .707 r
F P
0 g
s
.38086 .54037 m .40547 .54195 L p .37195 .56435 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .34241 .57293 L .3694 .57119 L p .707 .577 .707 r
F P
0 g
s
.3694 .57119 m .37177 .57104 L p .36729 .57689 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .3694 .57119 L .36729 .57689 L .707 .577 .707 r
F
.48661 .67585 m .48709 .69401 L .46602 .68662 L p F P
0 g
s
.46602 .68662 m .46554 .66846 L .48661 .67585 L p .707 .577 .707 r
F P
0 g
s
.40547 .54195 m .40127 .59927 L .36954 .59724 L p .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .37177 .57104 L .40115 .57121 L p .707 .577 .707 r
F P
0 g
s
.40127 .59927 m .40375 .56545 L p .4366 .54481 L .707 .577 .707 r
F P
0 g
s
.40115 .57121 m .4036 .57122 L p .39855 .57699 L .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .40115 .57121 L .39855 .57699 L .707 .577 .707 r
F
.40375 .56545 m .40547 .54195 L .41398 .54273 L p F P
0 g
s
.41398 .54273 m .4366 .54481 L p .40375 .56545 L .707 .577 .707 r
F P
0 g
s
.37177 .57104 m .3708 .60866 L .34144 .61055 L p .707 .577 .707 r
F P
0 g
s
.40263 .60884 m .4036 .57122 L .43477 .57345 L p .707 .577 .707 r
F P
0 g
s
.4036 .57122 m .40263 .60884 L .3708 .60866 L p .707 .577 .707 r
F P
0 g
s
.32217 .69436 m .32169 .6762 L .34572 .66872 L p .707 .577 .707 r
F P
0 g
s
.34572 .66872 m .3462 .68688 L .32217 .69436 L p .707 .577 .707 r
F P
0 g
s
.46554 .66846 m .46602 .68662 L .43856 .6819 L p .707 .577 .707 r
F P
0 g
s
.43856 .6819 m .43808 .66374 L .46554 .66846 L p .707 .577 .707 r
F P
0 g
s
.3462 .68688 m .34572 .66872 L .37508 .66388 L p .707 .577 .707 r
F P
0 g
s
.37508 .66388 m .37557 .68204 L .3462 .68688 L p .707 .577 .707 r
F P
0 g
s
.43808 .66374 m .43856 .6819 L .40739 .68033 L p .707 .577 .707 r
F P
0 g
s
.40739 .68033 m .40691 .66217 L .43808 .66374 L p .707 .577 .707 r
F P
0 g
s
.37557 .68204 m .37508 .66388 L .40691 .66217 L p .707 .577 .707 r
F P
0 g
s
.40691 .66217 m .40739 .68033 L .37557 .68204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005IooaX000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0`002UYF00<005YFFUH0
1UYF00<005YFFUH00eYF3@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH0000:FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol005Aoo`03001JEP0000YJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF1@000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0P0015YF00<005YFFUH0
0eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001COol00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005=oo`03001JEP0000AJEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool=001EOol005=oo`03001JEP00009JEPH000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUIJEP04
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600000eYF001J
EP05FUH00`00FUIJEP02FUHB0013Ool005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH8000kOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP00
02eoo`00;goo6@002goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP80
00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF0P000UYF20000eYF0P001eYF0P0015YF20000eYF0P0015YF0P000UYF0P00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH60007FUH01000FUIJEUYF4P0000=JEP0000001P0015YF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEPD000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH20002FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF001JEUYF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP05001JEUYFFUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00
0000;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<0
02eoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4`000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00UYF200035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00@005YFFUIJER<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP0B0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH50004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF0P00;Goo
000/Ool00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo1@001EYF00<005YFFUH0
1EYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEP0001@000EJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP03001JEUYF00D0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000]Ool002moo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000]Ool003=oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool003Yoo`T000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00@goo2@0015YF00<005YF
FUH01EYF0P0000=JEP00FUH01EYF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1`0015YF00<0
05YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF1000<Woo001<Ool<0003FUH00`00
FUIJEP04FUH00`00FUIJEP040005FUH50004FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Woo001EOol20004FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP08
FUH40004FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000AooaL003Yoo`00EGoo0P0015YF
00<005YF00000`000goo00@005YFFUH000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001DOol00`00FUH00004FUH20007Ool01000
FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P000UYF0P0000=JEP00FUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YF
FUIJEP0005Eoo`00E7oo00<005YF00000UYF0P002Goo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00EJEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000Uoo`T004=oo`00E7oo
00<005YF00000P002goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00=JEP03001JEUYF00/000AJEP03001JEUYF009JEPP003]oo`00E7oo00<005YF0000
3Goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00IJEP05001JEP00
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0003FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=Woo001DOol3000=Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF0P0000AJEP00FUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000cOol003mooa8000=o
o`800003FUH0000000]oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH200001UYF001JEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000aOol003Moo`P00003FUH0000000H000AJEP03001JEUYF009J
EPD000=JEP8000Uoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF
0P000eYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P00<7oo000bOol50003FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH000030005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF100000=JEP00
FUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH01EYF00<005YFFUH00UYF3@001Goo20000eYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Woo100000AJEP00FUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEUYFFUH00004FUH500001Goo001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF
1P001EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF009JEPH000Qoo`D000eoo`D000AJEP05001J
EUYFFUH0000]Ool002eoo`8000AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF2@0015YF00<005YF
FUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEP00008000ioo`D0019oo`<00003FUH005YF009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF0`0000=J
EP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJ
EP80019oo`<001Ioo`8000=JEP8002aoo`00;7oo00@005YF001JEP80009JEP03001JEUYF00AJEP03
001JEUYF009JEPP000=JEP03001JEUYF00=JEPX000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH2000_Ool00`00FUIJEP02000/
Ool002aoo`04001JEP000004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000015YF00000000<Woo1000;7oo000/Ool01000FUH0000015YF00<005YF00001000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00Ool0=Goo0P00;7oo000/Ool01000FUH00000
15YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00=Goo
1000;7oo000/Ool01000FUH000000UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00005`000UYF60001UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF1@00<Goo0P0000AJEP00FUH002aoo`00;7oo00<005YF
00000`0000=JEP00FUH00UYF7`001UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF2@002eYF00<005YFFUH02EYF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000UYF00<007ooOol0:goo0`000eYF00<005YF0000;7oo000/Ool01000FUH000000eYF1@001eYF
00@005YFFUIJEQL0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF
009JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001JEUYF
009JEP<0009JEPH002Ioo`800003FUH005YF00=JEP8002eoo`00;7oo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1P000eYF00<005YF
00000UYF00<005YFFUH015YF00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P0000AJ
EP000000025oo`8000=JEP03001JEUYF009JEP8002eoo`00;7oo00<005YF00000`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000EJ
EP00FUIJEP0000EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP<00003FUH005YF00=JEP<0009JEP03001JEUYF009JEPH001Yoo`D0
00EJEP03001JEUYF009JEP03001oogoo02aoo`00;7oo0`000UYF0`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YF0000
0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00@005YF000000AJEP@00003FUH005YF00AJEP04001JEUYFFUHK0003FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool002aoo`<000=JEP03001JEP00008000QJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00005FUH005YFFUH00002FUH200000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF1P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo000/Ool30003FUH00`00FUIJEP02FUH30004FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH40005FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP@000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8003=oo`00;Goo0P000eYF00<005YFFUH00eYF00<0
05YF0000100025YF1@0015YF00@005YFFUIJEP@0009JEP03001JEUYF00AJEP03001JEUYF008000AJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000eOol002moo`800003FUH005YF
00AJEP03001JEUYF00=JEQH000IJEP03001JEUYF00AJEPD000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP000006FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH5000iOol0035oo`8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001J
EUYF00IJEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006
FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP02FUH9000nOol003=oo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEP0000D0009oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH01@00FUH00000FUH00P000goo
2@00Agoo000eOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`00Dgoo000gOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000<Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH6
0004FUH01000FUIJEUYF0`00Dgoo000lOolI000AOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP02FUH300000eYF001JEP02FUH3001COol006Qoo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP<005=oo`00JWoo0P001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP8000MJEP03001JEUYF00AJEP80009JEP@005Aoo`00K7oo0`0015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0007FUH0
0`00FUIJEP0400000eYF001JEP03FUH2001DOol006moo`<00003FUH005YF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD000=JEP03001JEUYF00=JEPD000EJ
EP03001JEUYF00=JEP03001oogoo059oo`00LWoo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH0200000=JEP0000001`000eYF00<005YFFUH015YF00@005YFFUIJ
EP8005Eoo`00NGoo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF4@0015YF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000P00EWoo0024OolJ0003FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH4001HOol009Eoo`<00003FUH005YF00IJEP03001JEUYF00IJEP<0
00IJEP03001JEUYF00EJEP03001JEP0000D005Yoo`00V7oo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00Ggoo002MOol90004FUH00`00FUIJEP02FUH9001UOol00:Ioo`T0
06ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57054 .63648 m .56383 .69376 L .59491 .69724 L p .707 .577 .707 r
F P
0 g
s
.59491 .69724 m .60162 .63995 L .57054 .63648 L p .707 .577 .707 r
F P
0 g
s
.60162 .63995 m .59491 .69724 L .62647 .70102 L p .707 .577 .707 r
F P
0 g
s
.62647 .70102 m .63319 .64374 L .60162 .63995 L p .707 .577 .707 r
F P
0 g
s
.63319 .64374 m .62647 .70102 L .65543 .70475 L p .707 .577 .707 r
F P
0 g
s
.65543 .70475 m .66215 .64747 L .63319 .64374 L p .707 .577 .707 r
F P
0 g
s
.54299 .63366 m .53628 .69094 L .56383 .69376 L p .707 .577 .707 r
F P
0 g
s
.56383 .69376 m .57054 .63648 L .54299 .63366 L p .707 .577 .707 r
F P
0 g
s
.66215 .64747 m .65543 .70475 L .67895 .70806 L p .707 .577 .707 r
F P
0 g
s
.67895 .70806 m .68567 .65077 L .66215 .64747 L p .707 .577 .707 r
F P
0 g
s
.52167 .63177 m .51495 .68905 L .53628 .69094 L p .707 .577 .707 r
F P
0 g
s
.53628 .69094 m .54299 .63366 L .52167 .63177 L p .707 .577 .707 r
F P
0 g
s
.59447 .84038 m .59604 .8025 L .56488 .80006 L p .707 .577 .707 r
F P
0 g
s
.59604 .8025 m .59447 .84038 L .62627 .84116 L p .707 .577 .707 r
F P
0 g
s
.62627 .84116 m .62784 .80328 L .59604 .8025 L p .707 .577 .707 r
F P
0 g
s
.62784 .80328 m .62627 .84116 L .6556 .84021 L p .707 .577 .707 r
F P
0 g
s
.6556 .84021 m .65717 .80233 L .62784 .80328 L p .707 .577 .707 r
F P
0 g
s
.68567 .65077 m .67895 .70806 L .69473 .71062 L p .707 .577 .707 r
F P
0 g
s
.56488 .80006 m .56331 .83795 L .59447 .84038 L p .707 .577 .707 r
F P
0 g
s
.56331 .83795 m .56488 .80006 L .53741 .79621 L p .707 .577 .707 r
F P
0 g
s
.69473 .71062 m .70144 .65333 L .68567 .65077 L p .707 .577 .707 r
F P
0 g
s
.53741 .79621 m .53584 .83409 L .56331 .83795 L p .707 .577 .707 r
F P
0 g
s
.50865 .63099 m .50193 .68828 L .51495 .68905 L p .707 .577 .707 r
F P
0 g
s
.51495 .68905 m .52167 .63177 L .50865 .63099 L p .707 .577 .707 r
F P
0 g
s
.60217 .82398 m .60139 .80608 L .57023 .8047 L p .707 .577 .707 r
F P
0 g
s
.60139 .80608 m .60217 .82398 L .63397 .8217 L p .707 .577 .707 r
F P
0 g
s
.63397 .8217 m .63319 .8038 L .60139 .80608 L p .707 .577 .707 r
F P
0 g
s
.65717 .80233 m .6556 .84021 L .67959 .83762 L p .707 .577 .707 r
F P
0 g
s
.67959 .83762 m .68116 .79973 L .65717 .80233 L p .707 .577 .707 r
F P
0 g
s
.63319 .8038 m .63397 .8217 L .66331 .81597 L p .707 .577 .707 r
F P
0 g
s
.66331 .81597 m .66253 .79808 L .63319 .8038 L p .707 .577 .707 r
F P
0 g
s
.57101 .8226 m .57023 .8047 L .54276 .79979 L p .707 .577 .707 r
F P
0 g
s
.57023 .8047 m .57101 .8226 L .60217 .82398 L p .707 .577 .707 r
F P
0 g
s
.53584 .83409 m .53741 .79621 L .51632 .79131 L p .707 .577 .707 r
F P
0 g
s
.68116 .79973 m .67959 .83762 L .69589 .83364 L p .707 .577 .707 r
F P
0 g
s
.69589 .83364 m .69746 .79575 L .68116 .79973 L p .707 .577 .707 r
F P
0 g
s
.66253 .79808 m .66331 .81597 L .6873 .80737 L p .707 .577 .707 r
F P
0 g
s
.6873 .80737 m .68652 .78948 L .66253 .79808 L p .707 .577 .707 r
F P
0 g
s
.54276 .79979 m .54354 .81769 L .57101 .8226 L p .707 .577 .707 r
F P
0 g
s
.51632 .79131 m .51475 .82919 L .53584 .83409 L p .707 .577 .707 r
F P
0 g
s
.70144 .65333 m .69473 .71062 L .70122 .71219 L p .707 .577 .707 r
F P
0 g
s
.70122 .71219 m .70794 .6549 L .70144 .65333 L p .707 .577 .707 r
F P
0 g
s
.54354 .81769 m .54276 .79979 L .52167 .79183 L p .707 .577 .707 r
F P
0 g
s
.50522 .63141 m .49851 .68869 L .50193 .68828 L p .707 .577 .707 r
F P
0 g
s
.50193 .68828 m .50865 .63099 L .50522 .63141 L p .707 .577 .707 r
F P
0 g
s
.52167 .79183 m .52245 .80973 L .54354 .81769 L p .707 .577 .707 r
F P
0 g
s
.51475 .82919 m .51632 .79131 L .50368 .78585 L p .707 .577 .707 r
F P
0 g
s
.69746 .79575 m .69589 .83364 L .69861 .83171 L p .707 .577 .707 r
F P
0 g
s
.69861 .83171 m .7029 .82866 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.69906 .8054 m .69746 .79575 L .69861 .83171 L .707 .577 .707 r
F
.69915 .79963 m .7036 .79673 L p .69923 .79488 L F P
0 g
s
.7036 .79673 m .70282 .77884 L .69947 .78102 L p .707 .577 .707 r
F P
0 g
s
.7036 .79673 m .69947 .78102 L .69923 .79488 L .707 .577 .707 r
F
.70282 .77884 m .7036 .79673 L .71061 .78509 L p F P
0 g
s
.7029 .82866 m .70447 .79078 L .69924 .79449 L p .707 .577 .707 r
F P
0 g
s
.69924 .79449 m .69746 .79575 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.7029 .82866 m .69924 .79449 L .69906 .8054 L .707 .577 .707 r
F
.69947 .78102 m .68652 .78948 L p .69923 .79488 L F P
0 g
s
.68652 .78948 m .6873 .80737 L .69915 .79963 L p .707 .577 .707 r
F P
0 g
s
.69923 .79488 m .68652 .78948 L .69915 .79963 L .707 .577 .707 r
F
.50368 .78585 m .50211 .82374 L .51475 .82919 L p F P
0 g
s
.52245 .80973 m .52167 .79183 L .50903 .78161 L p .707 .577 .707 r
F P
0 g
s
.70794 .6549 m .70122 .71219 L .69779 .7126 L p .707 .577 .707 r
F P
0 g
s
.69779 .7126 m .70451 .65531 L .70794 .6549 L p .707 .577 .707 r
F P
0 g
s
.50903 .78161 m .50981 .7995 L .52245 .80973 L p .707 .577 .707 r
F P
0 g
s
.48726 .82194 m .49019 .31815 L .44618 .31537 L p .707 .577 .707 r
F P
0 g
s
.50211 .82374 m .50368 .78585 L .50072 .78037 L p .707 .577 .707 r
F P
0 g
s
.51171 .63297 m .505 .69026 L .49851 .68869 L p .707 .577 .707 r
F P
0 g
s
.49851 .68869 m .50522 .63141 L .51171 .63297 L p .707 .577 .707 r
F P
0 g
s
.50072 .78037 m .49915 .81825 L .50211 .82374 L p .707 .577 .707 r
F P
0 g
s
.50981 .7995 m .50903 .78161 L .50607 .77011 L p .707 .577 .707 r
F P
0 g
s
.50607 .77011 m .50685 .788 L .50981 .7995 L p .707 .577 .707 r
F P
0 g
s
.52749 .63553 m .52078 .69282 L .505 .69026 L p .707 .577 .707 r
F P
0 g
s
.505 .69026 m .51171 .63297 L .52749 .63553 L p .707 .577 .707 r
F P
0 g
s
.50685 .788 m .50607 .77011 L .51164 .76086 L p .707 .577 .707 r
F P
0 g
s
.51164 .76086 m .51308 .75847 L p .51171 .76497 L .707 .577 .707 r
F P
0 g
s
.50685 .788 m .51164 .76086 L .51171 .76497 L .707 .577 .707 r
F
.51187 .77438 m .52403 .77141 L p .51227 .79895 L F P
0 g
s
.51308 .75847 m .51386 .77637 L .50685 .788 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .50773 .77539 L .51187 .77438 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .51187 .77438 L .51227 .79895 L .707 .577 .707 r
F
.49915 .81825 m .50072 .78037 L .50773 .77539 L p F P
0 g
s
.50773 .77539 m .50616 .81327 L .49915 .81825 L p .707 .577 .707 r
F P
0 g
s
.55101 .63884 m .5443 .69613 L .52078 .69282 L p .707 .577 .707 r
F P
0 g
s
.52078 .69282 m .52749 .63553 L .55101 .63884 L p .707 .577 .707 r
F P
0 g
s
.52403 .77141 m .52246 .80929 L .50616 .81327 L p .707 .577 .707 r
F P
0 g
s
.51386 .77637 m .51308 .75847 L .52938 .74783 L p .707 .577 .707 r
F P
0 g
s
.52938 .74783 m .53016 .76573 L .51386 .77637 L p .707 .577 .707 r
F P
0 g
s
.52246 .80929 m .52403 .77141 L .54802 .76882 L p .707 .577 .707 r
F P
0 g
s
.54802 .76882 m .54645 .8067 L .52246 .80929 L p .707 .577 .707 r
F P
0 g
s
.49019 .31815 m .48726 .82194 L .53221 .82114 L p .707 .577 .707 r
F P
0 g
s
.53016 .76573 m .52938 .74783 L .55337 .73923 L p .707 .577 .707 r
F P
0 g
s
.55337 .73923 m .55415 .75712 L .53016 .76573 L p .707 .577 .707 r
F P
0 g
s
.53221 .82114 m .53513 .31735 L .49019 .31815 L p .707 .577 .707 r
F P
0 g
s
.71061 .78509 m .70983 .7672 L .70282 .77884 L p .707 .577 .707 r
F P
0 g
s
.57997 .64257 m .57325 .69986 L .5443 .69613 L p .707 .577 .707 r
F P
0 g
s
.5443 .69613 m .55046 .64356 L p .57997 .64257 L .707 .577 .707 r
F P
0 g
s
.55046 .64356 m .55101 .63884 L .55282 .63907 L p .707 .577 .707 r
F P
0 g
s
.55282 .63907 m .57997 .64257 L p .55046 .64356 L .707 .577 .707 r
F P
0 g
s
.61153 .64636 m .60482 .70364 L .57627 .70022 L p .707 .577 .707 r
F P
0 g
s
.57627 .70022 m .57325 .69986 L p .57734 .69415 L .707 .577 .707 r
F P
0 g
s
.57734 .69415 m .61153 .64636 L .57627 .70022 L .707 .577 .707 r
F
.64261 .64983 m .6359 .70712 L .61057 .70428 L p F P
0 g
s
.61057 .70428 m .60482 .70364 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.61127 .69446 m .64261 .64983 L .61057 .70428 L .707 .577 .707 r
F
.67017 .65265 m .66345 .70994 L .6359 .70712 L p F P
0 g
s
.6359 .70712 m .64261 .64983 L .67017 .65265 L p .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61153 .64636 L .61466 .6467 L p .707 .577 .707 r
F P
0 g
s
.61466 .6467 m .64261 .64983 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61466 .6467 L .61127 .69446 L .707 .577 .707 r
F
.63874 .80896 m .64031 .77108 L .66778 .77494 L p F P
0 g
s
.64567 .73261 m .64645 .7505 L .61529 .74912 L p .707 .577 .707 r
F P
0 g
s
.61529 .74912 m .61451 .73123 L .64567 .73261 L p .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64367 .28475 L .64008 .28876 L p .707 .577 .707 r
F P
0 g
s
.64008 .28876 m .63367 .2959 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64008 .28876 L .63466 .36497 L .707 .577 .707 r
F
.64031 .77108 m .63874 .80896 L .60758 .80653 L p F P
0 g
s
.60758 .80653 m .60915 .76864 L .64031 .77108 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .64075 .78854 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63367 .2959 m .63315 .38633 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63315 .38633 m .63075 .7997 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.57578 .80575 m .57735 .76786 L .60915 .76864 L p .707 .577 .707 r
F P
0 g
s
.60915 .76864 m .60758 .80653 L .57578 .80575 L p .707 .577 .707 r
F P
0 g
s
.58348 .7514 m .5827 .73351 L .61451 .73123 L p .707 .577 .707 r
F P
0 g
s
.61451 .73123 m .61529 .74912 L .58348 .7514 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .63075 .7997 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.61056 .30566 m .60937 .51188 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.57325 .69986 m .57997 .64257 L .61153 .64636 L p .707 .577 .707 r
F P
0 g
s
.60937 .51188 m .60764 .80945 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.54645 .8067 m .54802 .76882 L .57735 .76786 L p .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .55337 .73923 L .56591 .73678 L p .707 .577 .707 r
F P
0 g
s
.56591 .73678 m .5827 .73351 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .56591 .73678 L .56796 .7457 L .707 .577 .707 r
F
.57735 .76786 m .57578 .80575 L .54645 .8067 L p F P
0 g
s
.5827 .73351 m .58348 .7514 L .56988 .75405 L p .707 .577 .707 r
F P
0 g
s
.56988 .75405 m .55415 .75712 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.56796 .7457 m .5827 .73351 L .56988 .75405 L .707 .577 .707 r
F
.57496 .59696 m .57395 .77173 L p .5923 .56399 L F P
0 g
s
.57395 .77173 m .57369 .81684 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.5923 .56399 m .57395 .77173 L .57627 .7818 L .707 .577 .707 r
F
.60764 .80945 m .5923 .56399 L .57627 .7818 L F
.57369 .81684 m .58382 .81463 L p .57627 .7818 L F P
0 g
s
.58382 .81463 m .60764 .80945 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.57661 .31305 m .57496 .59696 L p .5923 .56399 L .707 .577 .707 r
F P
0 g
s
.53513 .31735 m .53221 .82114 L .57369 .81684 L p .707 .577 .707 r
F P
0 g
s
.57369 .81684 m .57661 .31305 L .53513 .31735 L p .707 .577 .707 r
F P
0 g
s
.44326 .81916 m .44618 .31537 L .40741 .30927 L p .707 .577 .707 r
F P
0 g
s
.44618 .31537 m .44326 .81916 L .48726 .82194 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .61056 .30566 L .57661 .31305 L p .707 .577 .707 r
F P
0 g
s
.70447 .79078 m .7029 .82866 L .69994 .82317 L p .707 .577 .707 r
F P
0 g
s
.69994 .82317 m .70151 .78529 L .70447 .79078 L p .707 .577 .707 r
F P
0 g
s
.70451 .65531 m .69779 .7126 L .68478 .71183 L p .707 .577 .707 r
F P
0 g
s
.68478 .71183 m .69149 .65454 L .70451 .65531 L p .707 .577 .707 r
F P
0 g
s
.22754 .59966 m .22082 .65695 L .2519 .66042 L p .707 .577 .707 r
F P
0 g
s
.2519 .66042 m .25861 .60313 L .22754 .59966 L p .707 .577 .707 r
F P
0 g
s
.25861 .60313 m .2519 .66042 L .28346 .66421 L p .707 .577 .707 r
F P
0 g
s
.28346 .66421 m .29018 .60692 L .25861 .60313 L p .707 .577 .707 r
F P
0 g
s
.70983 .7672 m .71061 .78509 L .70765 .7736 L p .707 .577 .707 r
F P
0 g
s
.70765 .7736 m .70687 .75571 L .70983 .7672 L p .707 .577 .707 r
F P
0 g
s
.40449 .81306 m .40741 .30927 L .37769 .30045 L p .707 .577 .707 r
F P
0 g
s
.40741 .30927 m .40449 .81306 L .44326 .81916 L p .707 .577 .707 r
F P
0 g
s
.29018 .60692 m .28346 .66421 L .31242 .66794 L p .707 .577 .707 r
F P
0 g
s
.31242 .66794 m .31914 .61065 L .29018 .60692 L p .707 .577 .707 r
F P
0 g
s
.19998 .59684 m .19327 .65413 L .22082 .65695 L p .707 .577 .707 r
F P
0 g
s
.22082 .65695 m .22754 .59966 L .19998 .59684 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31914 .61065 m .31242 .66794 L .33594 .67124 L p .707 .577 .707 r
F P
0 g
s
.33594 .67124 m .34266 .61396 L .31914 .61065 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .63367 .2959 L .61056 .30566 L p .707 .577 .707 r
F P
0 g
s
.17866 .59495 m .17194 .65224 L .19327 .65413 L p .707 .577 .707 r
F P
0 g
s
.19327 .65413 m .19998 .59684 L .17866 .59495 L p .707 .577 .707 r
F P
0 g
s
.69149 .65454 m .68478 .71183 L .66345 .70994 L p .707 .577 .707 r
F P
0 g
s
.70151 .78529 m .69994 .82317 L .6873 .81772 L p .707 .577 .707 r
F P
0 g
s
.6873 .81772 m .68887 .77983 L .70151 .78529 L p .707 .577 .707 r
F P
0 g
s
.66345 .70994 m .67017 .65265 L .69149 .65454 L p .707 .577 .707 r
F P
0 g
s
.70687 .75571 m .70765 .7736 L .69501 .76337 L p .707 .577 .707 r
F P
0 g
s
.69501 .76337 m .69423 .74548 L .70687 .75571 L p .707 .577 .707 r
F P
0 g
s
.25146 .80357 m .25303 .76569 L .22187 .76325 L p .707 .577 .707 r
F P
0 g
s
.25303 .76569 m .25146 .80357 L .28326 .80435 L p .707 .577 .707 r
F P
0 g
s
.28326 .80435 m .28483 .76647 L .25303 .76569 L p .707 .577 .707 r
F P
0 g
s
.37477 .80424 m .37769 .30045 L .35991 .28979 L p .707 .577 .707 r
F P
0 g
s
.37769 .30045 m .37477 .80424 L .40449 .81306 L p .707 .577 .707 r
F P
0 g
s
.28483 .76647 m .28326 .80435 L .3126 .8034 L p .707 .577 .707 r
F P
0 g
s
.3126 .8034 m .31416 .76551 L .28483 .76647 L p .707 .577 .707 r
F P
0 g
s
.34266 .61396 m .33594 .67124 L .35172 .67381 L p .707 .577 .707 r
F P
0 g
s
.22187 .76325 m .2203 .80113 L .25146 .80357 L p .707 .577 .707 r
F P
0 g
s
.2203 .80113 m .22187 .76325 L .1944 .75939 L p .707 .577 .707 r
F P
0 g
s
.35172 .67381 m .35844 .61652 L .34266 .61396 L p .707 .577 .707 r
F P
0 g
s
.1944 .75939 m .19283 .79728 L .2203 .80113 L p .707 .577 .707 r
F P
0 g
s
.16564 .59418 m .15893 .65146 L .17194 .65224 L p .707 .577 .707 r
F P
0 g
s
.17194 .65224 m .17866 .59495 L .16564 .59418 L p .707 .577 .707 r
F P
0 g
s
.25916 .78716 m .25838 .76927 L .22722 .76789 L p .707 .577 .707 r
F P
0 g
s
.25838 .76927 m .25916 .78716 L .29097 .78488 L p .707 .577 .707 r
F P
0 g
s
.29097 .78488 m .29019 .76699 L .25838 .76927 L p .707 .577 .707 r
F P
0 g
s
.31416 .76551 m .3126 .8034 L .33658 .8008 L p .707 .577 .707 r
F P
0 g
s
.33658 .8008 m .33815 .76292 L .31416 .76551 L p .707 .577 .707 r
F P
0 g
s
.29019 .76699 m .29097 .78488 L .3203 .77916 L p .707 .577 .707 r
F P
0 g
s
.3203 .77916 m .31952 .76127 L .29019 .76699 L p .707 .577 .707 r
F P
0 g
s
.228 .78578 m .22722 .76789 L .19975 .76298 L p .707 .577 .707 r
F P
0 g
s
.22722 .76789 m .228 .78578 L .25916 .78716 L p .707 .577 .707 r
F P
0 g
s
.19283 .79728 m .1944 .75939 L .17331 .7545 L p .707 .577 .707 r
F P
0 g
s
.68887 .77983 m .6873 .81772 L .66621 .81282 L p .707 .577 .707 r
F P
0 g
s
.66621 .81282 m .66778 .77494 L .68887 .77983 L p .707 .577 .707 r
F P
0 g
s
.69423 .74548 m .69501 .76337 L .67392 .75541 L p .707 .577 .707 r
F P
0 g
s
.67392 .75541 m .67314 .73752 L .69423 .74548 L p .707 .577 .707 r
F P
0 g
s
.33815 .76292 m .33658 .8008 L .35288 .79682 L p .707 .577 .707 r
F P
0 g
s
.35288 .79682 m .35445 .75894 L .33815 .76292 L p .707 .577 .707 r
F P
0 g
s
.31952 .76127 m .3203 .77916 L .34429 .77056 L p .707 .577 .707 r
F P
0 g
s
.34429 .77056 m .34351 .75266 L .31952 .76127 L p .707 .577 .707 r
F P
0 g
s
.19975 .76298 m .20053 .78087 L .228 .78578 L p .707 .577 .707 r
F P
0 g
s
.17331 .7545 m .17174 .79238 L .19283 .79728 L p .707 .577 .707 r
F P
0 g
s
.35844 .61652 m .35172 .67381 L .35821 .67537 L p .707 .577 .707 r
F P
0 g
s
.35821 .67537 m .36493 .61808 L .35844 .61652 L p .707 .577 .707 r
F P
0 g
s
.20053 .78087 m .19975 .76298 L .17866 .75502 L p .707 .577 .707 r
F P
0 g
s
.35445 .75894 m .35288 .79682 L .3556 .79489 L p .707 .577 .707 r
F P
0 g
s
.35605 .76859 m .35445 .75894 L .3556 .79489 L .707 .577 .707 r
F
.35615 .76281 m .36059 .75992 L p .35623 .75806 L F P
0 g
s
.36059 .75992 m .35981 .74202 L .35646 .74421 L p .707 .577 .707 r
F P
0 g
s
.36059 .75992 m .35646 .74421 L .35623 .75806 L .707 .577 .707 r
F
.35981 .74202 m .36059 .75992 L .3676 .74828 L p F P
0 g
s
.3599 .79184 m .36146 .75396 L .35623 .75768 L p .707 .577 .707 r
F P
0 g
s
.35623 .75768 m .35445 .75894 L p .35605 .76859 L .707 .577 .707 r
F P
0 g
s
.3599 .79184 m .35623 .75768 L .35605 .76859 L .707 .577 .707 r
F
.35646 .74421 m .34351 .75266 L p .35623 .75806 L F P
0 g
s
.34351 .75266 m .34429 .77056 L .35615 .76281 L p .707 .577 .707 r
F P
0 g
s
.35623 .75806 m .34351 .75266 L .35615 .76281 L .707 .577 .707 r
F
.3556 .79489 m .3599 .79184 L p .35605 .76859 L F P
0 g
s
.35821 .67537 m .35478 .67579 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36493 .61808 m .36387 .62713 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36387 .62713 m .35821 .67537 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35582 .27831 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .36493 .61808 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35478 .67579 m .36095 .62322 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36095 .62322 m .3615 .6185 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36146 .75396 m .3599 .79184 L .35693 .78636 L p .707 .577 .707 r
F P
0 g
s
.35693 .78636 m .3585 .74848 L .36146 .75396 L p .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .35478 .67579 L .34177 .67501 L p .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .34848 .61772 L .36069 .61845 L p .707 .577 .707 r
F P
0 g
s
.36069 .61845 m .3615 .6185 L p .3608 .6205 L .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .36069 .61845 L .3608 .6205 L .707 .577 .707 r
F
.358 .61927 m .35826 .5737 L p .35659 .61738 L F P
0 g
s
.35826 .5737 m .35991 .28979 L p .35722 .55455 L .707 .577 .707 r
F P
0 g
s
.35826 .5737 m .35722 .55455 L .35659 .61738 L .707 .577 .707 r
F
.3585 .74848 m .35693 .78636 L .34429 .7809 L p F P
0 g
s
.34429 .7809 m .34586 .74302 L .3585 .74848 L p .707 .577 .707 r
F P
0 g
s
.3676 .74828 m .36682 .73038 L .35981 .74202 L p .707 .577 .707 r
F P
0 g
s
.36386 .71889 m .36464 .73678 L .35786 .7313 L p .707 .577 .707 r
F P
0 g
s
.35786 .7313 m .352 .72656 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.35817 .72257 m .36386 .71889 L .35786 .7313 L .707 .577 .707 r
F
.352 .72656 m .35122 .70866 L .35846 .71452 L p F P
0 g
s
.35846 .71452 m .36386 .71889 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.352 .72656 m .35846 .71452 L .35817 .72257 L .707 .577 .707 r
F
.35691 .75809 m .358 .61927 L .35659 .61738 L F
.35699 .79358 m .35725 .74847 L p .35691 .75809 L F P
0 g
s
.35725 .74847 m .358 .61927 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35577 .79016 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.35577 .79016 m .35699 .79358 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.35691 .75809 m .35659 .61738 L .35577 .79016 L .707 .577 .707 r
F
.35582 .27831 m .35387 .61375 L p .35659 .61738 L F P
0 g
s
.35387 .61375 m .3529 .78211 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.36682 .73038 m .3676 .74828 L .36464 .73678 L p .707 .577 .707 r
F P
0 g
s
.36464 .73678 m .36386 .71889 L .36682 .73038 L p .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35699 .79358 L .37477 .80424 L p .707 .577 .707 r
F P
0 g
s
.16221 .59459 m .1555 .65188 L .15893 .65146 L p .707 .577 .707 r
F P
0 g
s
.15893 .65146 m .16564 .59418 L .16221 .59459 L p .707 .577 .707 r
F P
0 g
s
.17866 .75502 m .17944 .77291 L .20053 .78087 L p .707 .577 .707 r
F P
0 g
s
.17174 .79238 m .17331 .7545 L .16067 .74904 L p .707 .577 .707 r
F P
0 g
s
.66778 .77494 m .66621 .81282 L .63874 .80896 L p .707 .577 .707 r
F P
0 g
s
.67314 .73752 m .67392 .75541 L .64645 .7505 L p .707 .577 .707 r
F P
0 g
s
.64645 .7505 m .64567 .73261 L .67314 .73752 L p .707 .577 .707 r
F P
0 g
s
.16067 .74904 m .1591 .78692 L .17174 .79238 L p .707 .577 .707 r
F P
0 g
s
.17944 .77291 m .17866 .75502 L .16602 .74479 L p .707 .577 .707 r
F P
0 g
s
.16602 .74479 m .1668 .76268 L .17944 .77291 L p .707 .577 .707 r
F P
0 g
s
.64367 .28475 m .64075 .78854 L .63666 .77706 L p .707 .577 .707 r
F P
0 g
s
.63666 .77706 m .63958 .27327 L .64367 .28475 L p .707 .577 .707 r
F P
0 g
s
.1591 .78692 m .16067 .74904 L .15771 .74355 L p .707 .577 .707 r
F P
0 g
s
.1687 .59615 m .16199 .65344 L .1555 .65188 L p .707 .577 .707 r
F P
0 g
s
.1555 .65188 m .16221 .59459 L .1687 .59615 L p .707 .577 .707 r
F P
0 g
s
.15771 .74355 m .15614 .78143 L .1591 .78692 L p .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35582 .27831 L .36581 .26716 L p .707 .577 .707 r
F P
0 g
s
.1668 .76268 m .16602 .74479 L .16306 .7333 L p .707 .577 .707 r
F P
0 g
s
.16306 .7333 m .16384 .75119 L .1668 .76268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.18448 .59872 m .17777 .656 L .16199 .65344 L p .707 .577 .707 r
F P
0 g
s
.16199 .65344 m .1687 .59615 L .18448 .59872 L p .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16306 .7333 L .16863 .72405 L p .707 .577 .707 r
F P
0 g
s
.16863 .72405 m .17007 .72166 L p .1687 .72816 L .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16863 .72405 L .1687 .72816 L .707 .577 .707 r
F
.16886 .73756 m .18102 .73459 L p .16926 .76213 L F P
0 g
s
.17007 .72166 m .17085 .73955 L .16384 .75119 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16472 .73857 L .16886 .73756 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16886 .73756 L .16926 .76213 L .707 .577 .707 r
F
.15614 .78143 m .15771 .74355 L .16472 .73857 L p F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63958 .27327 m .63666 .77706 L .61888 .7664 L p .707 .577 .707 r
F P
0 g
s
.61888 .7664 m .6218 .26261 L .63958 .27327 L p .707 .577 .707 r
F P
0 g
s
.16472 .73857 m .16315 .77646 L .15614 .78143 L p .707 .577 .707 r
F P
0 g
s
.34848 .61772 m .34177 .67501 L .32044 .67312 L p .707 .577 .707 r
F P
0 g
s
.32044 .67312 m .32716 .61583 L .34848 .61772 L p .707 .577 .707 r
F P
0 g
s
.36289 .77095 m .36581 .26716 L .38892 .2574 L p .707 .577 .707 r
F P
0 g
s
.36581 .26716 m .36289 .77095 L .3529 .78211 L p .707 .577 .707 r
F P
0 g
s
.208 .60202 m .20129 .65931 L .17777 .656 L p .707 .577 .707 r
F P
0 g
s
.17777 .656 m .18448 .59872 L .208 .60202 L p .707 .577 .707 r
F P
0 g
s
.18102 .73459 m .17945 .77248 L .16315 .77646 L p .707 .577 .707 r
F P
0 g
s
.17085 .73955 m .17007 .72166 L .18637 .71102 L p .707 .577 .707 r
F P
0 g
s
.32716 .61583 m .32044 .67312 L .29289 .6703 L p .707 .577 .707 r
F P
0 g
s
.29289 .6703 m .2996 .61301 L .32716 .61583 L p .707 .577 .707 r
F P
0 g
s
.6218 .26261 m .61888 .7664 L .58915 .75758 L p .707 .577 .707 r
F P
0 g
s
.58915 .75758 m .59207 .25379 L .6218 .26261 L p .707 .577 .707 r
F P
0 g
s
.18637 .71102 m .18715 .72891 L .17085 .73955 L p .707 .577 .707 r
F P
0 g
s
.34586 .74302 m .34429 .7809 L .3232 .776 L p .707 .577 .707 r
F P
0 g
s
.3232 .776 m .32477 .73812 L .34586 .74302 L p .707 .577 .707 r
F P
0 g
s
.23696 .60575 m .23025 .66304 L .20129 .65931 L p .707 .577 .707 r
F P
0 g
s
.20129 .65931 m .208 .60202 L .23696 .60575 L p .707 .577 .707 r
F P
0 g
s
.35122 .70866 m .352 .72656 L .33091 .7186 L p .707 .577 .707 r
F P
0 g
s
.33091 .7186 m .33013 .7007 L .35122 .70866 L p .707 .577 .707 r
F P
0 g
s
.17945 .77248 m .18102 .73459 L .20501 .732 L p .707 .577 .707 r
F P
0 g
s
.2996 .61301 m .29289 .6703 L .26181 .66683 L p .707 .577 .707 r
F P
0 g
s
.38892 .2574 m .386 .76119 L .36289 .77095 L p .707 .577 .707 r
F P
0 g
s
.386 .76119 m .38892 .2574 L .42288 .25001 L p .707 .577 .707 r
F P
0 g
s
.26181 .66683 m .26853 .60954 L .2996 .61301 L p .707 .577 .707 r
F P
0 g
s
.26853 .60954 m .26181 .66683 L .23025 .66304 L p .707 .577 .707 r
F P
0 g
s
.23025 .66304 m .23696 .60575 L .26853 .60954 L p .707 .577 .707 r
F P
0 g
s
.20501 .732 m .20344 .76988 L .17945 .77248 L p .707 .577 .707 r
F P
0 g
s
.18715 .72891 m .18637 .71102 L .21036 .70241 L p .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .70367 .6467 L p .70346 .64629 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70103 .6464 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67581 .64382 L p .67568 .64346 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67348 .64358 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65404 .64186 L p .65396 .64143 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65215 .64169 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64016 .64098 L p .64016 .64045 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63914 .64092 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .63965 .63213 L .63588 .64094 L .707 .577 .707 r
F
.63584 .64132 m .63914 .64092 L p .63588 .64094 L F P
0 g
s
.63865 .6313 m .64012 .63252 L .63792 .60871 L .707 .577 .707 r
F
.64012 .63252 m .64088 .6142 L .64003 .61262 L p F P
0 g
s
.64003 .61262 m .63792 .60871 L p .64012 .63252 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63571 .64133 L p .63965 .63213 L .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63931 .65208 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63792 .60871 m .63704 .62997 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63635 .6466 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63965 .63213 m .64004 .6254 L .63871 .63135 L .707 .577 .707 r
F
.64004 .6254 m .64243 .58405 L .63871 .63135 L F
.64243 .58405 m .63704 .62997 L p .63871 .63135 L F P
0 g
s
.64593 .63394 m .65286 .63565 L .64088 .6142 L .707 .577 .707 r
F
.65286 .63565 m .65352 .61966 L .64951 .61793 L p F P
0 g
s
.64951 .61793 m .64088 .6142 L p .65286 .63565 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65146 .6353 L .64016 .64045 L .707 .577 .707 r
F
.64016 .64098 m .65215 .64169 L p .64016 .64045 L F P
0 g
s
.63931 .65208 m .65196 .65754 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64088 .6142 m .64012 .63252 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63931 .65208 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64243 .58405 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64012 .63252 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .64585 .58363 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64012 .63252 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.66145 .63703 m .67401 .63905 L .65352 .61966 L .707 .577 .707 r
F
.66798 .62302 m .65352 .61966 L p .67401 .63905 L F P
0 g
s
.65352 .61966 m .65286 .63565 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65887 .58441 m .64585 .58363 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65286 .63565 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65887 .58441 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67229 .63877 L .65396 .64143 L .707 .577 .707 r
F
.65404 .64186 m .67348 .64358 L p .65396 .64143 L F P
0 g
s
.65196 .65754 m .67304 .66244 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65196 .65754 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.63913 .62945 m .64727 .59299 L .64392 .62825 L .707 .577 .707 r
F
.67401 .63905 m .67461 .62456 L .66798 .62302 L p F P
0 g
s
.65887 .58441 m .65286 .63565 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.64628 .60341 m .66123 .59976 L p .64392 .62825 L .707 .577 .707 r
F P
0 g
s
.64892 .58561 m .64392 .62825 L p .64727 .59299 L .707 .577 .707 r
F P
0 g
s
.65196 .65754 m .65286 .63565 L p .64593 .63394 L .707 .577 .707 r
F P
0 g
s
.63931 .65208 m .64012 .63252 L p .63865 .6313 L .707 .577 .707 r
F P
0 g
s
.64493 .60374 m .64392 .62825 L p .63635 .6466 L .707 .577 .707 r
F P
0 g
s
.64313 .64065 m .6483 .62806 L .64297 .64302 L .707 .577 .707 r
F
.64305 .64185 m .63635 .6466 L p .64392 .62825 L F P
0 g
s
.64917 .62802 m .64392 .62825 L .66123 .59976 L .707 .577 .707 r
F
.68439 .64031 m .7015 .64239 L .67461 .62456 L F
.69392 .62727 m .67461 .62456 L p .7015 .64239 L F P
0 g
s
.67461 .62456 m .67401 .63905 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .65887 .58441 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67401 .63905 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .6802 .5863 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .69956 .64215 L .67568 .64346 L .707 .577 .707 r
F
.67581 .64382 m .70103 .6464 L p .67568 .64346 L F P
0 g
s
.67304 .66244 m .70051 .6663 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67304 .66244 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6422 .6429 m .64892 .58561 L .6647 .58817 L p .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64336 .64162 L .64305 .64185 L p .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .64297 .64302 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64297 .64302 m .6422 .6429 L p .64313 .64065 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .65798 .64546 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .66008 .62753 L p .64336 .64162 L .707 .577 .707 r
F P
0 g
s
.67304 .66244 m .67401 .63905 L p .66145 .63703 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70208 .62841 L .69392 .62727 L p .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .67401 .63905 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .70208 .62841 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70208 .62841 m .7015 .64239 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .6802 .5863 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .7015 .64239 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70775 .58912 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .7302 .64511 L .70346 .64629 L .707 .577 .707 r
F
.70367 .6467 m .73211 .64988 L p .70346 .64629 L F P
0 g
s
.70051 .6663 m .73167 .66873 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70051 .6663 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .68522 .59716 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .66123 .59976 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .66008 .62753 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .65798 .64546 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .6815 .64877 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.70051 .6663 m .7015 .64239 L p .68439 .64031 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73324 .63085 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .7015 .64239 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .73264 .64534 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .73324 .63085 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .76368 .65366 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73211 .64988 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76505 .63163 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .76438 .64762 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .76505 .63163 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .79263 .65739 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76368 .65366 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79438 .63068 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .79362 .64899 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .79438 .63068 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .81615 .6607 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79263 .65739 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81837 .62808 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .81749 .64934 L p .82064 .6333 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .81837 .62808 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .83193 .66326 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81615 .6607 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83467 .6241 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .83365 .64862 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83865 .60597 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.83524 .62369 m .83467 .6241 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83537 .62174 L .82974 .64879 L .707 .577 .707 r
F
.83865 .60597 m .83365 .64862 L p .83849 .64741 L F P
0 g
s
.8331 .66199 m .8394 .65751 L p .83852 .6474 L .707 .577 .707 r
F P
0 g
s
.83971 .6546 m .83852 .6474 L .8394 .65751 L .707 .577 .707 r
F
.83849 .64741 m .84141 .62989 L .83865 .60597 L F
.84514 .60754 m .84261 .60693 L p .84141 .62989 L F P
0 g
s
.84261 .60693 m .83865 .60597 L p .84141 .62989 L .707 .577 .707 r
F P
0 g
s
.84053 .6469 m .84514 .60754 L p .83849 .64741 L .707 .577 .707 r
F P
0 g
s
.83852 .6474 m .83809 .6448 L .8377 .6476 L .707 .577 .707 r
F
.83809 .6448 m .83506 .62651 L .8377 .6476 L F
.8377 .6476 m .83506 .62651 L .83384 .64857 L F
.83852 .6474 m .83384 .64857 L .8331 .66199 L F
.84011 .65701 m .84053 .6469 L p .8387 .64735 L F P
0 g
s
.83971 .6546 m .83524 .62369 L .83506 .62651 L .707 .577 .707 r
F
.84011 .65701 m .83973 .65441 L .83971 .6546 L F
.83973 .65441 m .83524 .62369 L .83971 .6546 L F
.84168 .61913 m .83524 .62369 L p .8387 .64735 L F P
0 g
s
.84053 .6469 m .84168 .61913 L p .8387 .64735 L .707 .577 .707 r
F P
0 g
s
.84168 .61913 m .84053 .6469 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .8331 .66199 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83236 .66216 m .8331 .66199 L p .83251 .66063 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83193 .66326 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.83193 .66326 m .83365 .64862 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .83365 .64862 L .82741 .6489 L .707 .577 .707 r
F
.8331 .66199 m .83365 .64862 L p .83251 .66063 L F P
0 g
s
.83849 .64741 m .83365 .64862 L .83236 .66224 L .707 .577 .707 r
F
.83843 .66483 m .83849 .64741 L .83236 .66224 L F
.83193 .66326 m .83225 .66334 L p .83236 .66224 L F P
0 g
s
.83225 .66334 m .83843 .66483 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .83236 .66216 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .82741 .6489 L .83236 .66216 L .707 .577 .707 r
F
.83872 .61364 m .84168 .61913 L p .83808 .64487 L F P
0 g
s
.835 .66524 m .83745 .64435 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .83745 .64435 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83872 .61364 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .8447 .60759 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .84171 .60795 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.8447 .60759 m .84514 .60754 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .8447 .60759 L .84404 .6138 L .707 .577 .707 r
F
.83843 .66483 m .84053 .6469 L p .83849 .64741 L F P
0 g
s
.83843 .66483 m .835 .66524 L p .83851 .64523 L .707 .577 .707 r
F P
0 g
s
.83851 .64523 m .84404 .6138 L .84041 .6468 L .707 .577 .707 r
F
.83851 .64523 m .84041 .6468 L .83843 .66483 L F
.84053 .6469 m .83843 .66483 L p .84404 .6138 L F P
0 g
s
.83715 .65152 m .83808 .64487 L .84053 .6469 L .707 .577 .707 r
F
.84053 .6469 m .84011 .65701 L .84001 .65683 L p F P
0 g
s
.8394 .65751 m .84011 .65701 L p .83971 .6546 L .707 .577 .707 r
F P
0 g
s
.84001 .65683 m .83715 .65152 L p .84053 .6469 L .707 .577 .707 r
F P
0 g
s
.84514 .60754 m .84053 .6469 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.82974 .64879 m .83537 .62174 L .82287 .60341 L .707 .577 .707 r
F
.83865 .60597 m .8364 .60561 L p .83537 .62174 L F P
0 g
s
.8364 .60561 m .82287 .60341 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.82741 .6489 m .82064 .6333 L .81876 .64928 L .707 .577 .707 r
F
.82741 .6489 m .81876 .64928 L .8168 .66597 L F
.81749 .64934 m .8168 .66597 L p .82064 .6333 L F P
0 g
s
.82287 .60341 m .81749 .64934 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.82287 .60341 m .79935 .60011 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .81749 .64934 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .82287 .60341 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .81749 .64934 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .8168 .66597 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79281 .66856 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .79362 .64899 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .77039 .59638 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .79362 .64899 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79935 .60011 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .79362 .64899 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .79281 .66856 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76348 .66951 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .76438 .64762 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .73883 .59259 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .76438 .64762 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .77039 .59638 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .76438 .64762 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .76348 .66951 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73167 .66873 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .73264 .64534 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .70775 .58912 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .73264 .64534 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73883 .59259 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .71455 .59621 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .68395 .62787 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68395 .62787 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68522 .59716 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .6815 .64877 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71046 .6525 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .73264 .64534 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.74636 .59699 m .77752 .59943 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .80499 .60328 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .77607 .63448 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .77607 .63448 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77752 .59943 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .82607 .60818 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .80356 .63782 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .80356 .63782 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80499 .60328 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .83872 .61364 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .82471 .64122 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .82471 .64122 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82607 .60818 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .82198 .66447 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .835 .66524 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .82451 .64606 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83872 .61364 m .83745 .64435 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83715 .65152 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .83745 .64435 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .84171 .60795 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .8287 .60718 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .80065 .66258 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82198 .66447 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .80342 .64117 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .82471 .64122 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82451 .64606 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .82471 .64122 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .8287 .60718 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80737 .60529 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .7731 .65976 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80065 .66258 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .77595 .63731 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .80356 .63782 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80342 .64117 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .80356 .63782 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .80737 .60529 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77982 .60247 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.74202 .65628 m .74493 .63153 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .74202 .65628 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .7731 .65976 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .74479 .63487 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .77607 .63448 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77595 .63731 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .77607 .63448 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74874 .599 m .77982 .60247 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74601 .63163 m .74636 .59699 L .74764 .63179 L .707 .577 .707 r
F
.74493 .63153 m .74636 .59699 L p .74599 .63357 L F P
0 g
s
.74493 .63153 m .74874 .599 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74599 .63357 m .74601 .63163 L .74764 .63179 L .707 .577 .707 r
F
.74479 .63487 m .74493 .63153 L p .74599 .63357 L F P
0 g
s
.71455 .59621 m .74636 .59699 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .71318 .62925 L p .72349 .62999 L .707 .577 .707 r
F P
0 g
s
.71298 .63409 m .71318 .62925 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71455 .59621 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .72349 .62999 L .72641 .6302 L .707 .577 .707 r
F
.74636 .59699 m .74493 .63153 L p .71709 .62953 L F P
0 g
s
.74874 .599 m .74202 .65628 L .71046 .6525 L p .707 .577 .707 r
F P
0 g
s
.74479 .63487 m .71298 .63409 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.74493 .63153 m .74479 .63487 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.72641 .6302 m .73436 .61123 L .73673 .61578 L .707 .577 .707 r
F
.72349 .62999 m .73436 .61123 L .72641 .6302 L F
.72349 .62999 m .71318 .62925 L .73436 .61123 L F
.73673 .61578 m .73436 .61123 L .74874 .599 L F
.71318 .62925 m .71718 .59521 L .73288 .59709 L p F P
0 g
s
.73288 .59709 m .74874 .599 L p .71318 .62925 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68916 .62812 L .71059 .63349 L .707 .577 .707 r
F
.71298 .63409 m .71016 .63419 L p .71059 .63349 L F P
0 g
s
.71016 .63419 m .68365 .63505 L p .71059 .63349 L .707 .577 .707 r
F P
0 g
s
.71455 .59621 m .71318 .62925 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71298 .63409 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71718 .59521 m .71318 .62925 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.69507 .6284 m .68395 .62787 L .71718 .59521 L .707 .577 .707 r
F
.68395 .62787 m .68822 .59148 L .6981 .59275 L p F P
0 g
s
.6981 .59275 m .71718 .59521 L p .68395 .62787 L .707 .577 .707 r
F P
0 g
s
.65966 .63764 m .66599 .62761 L .68143 .63411 L .707 .577 .707 r
F
.68365 .63505 m .68094 .63534 L p .68143 .63411 L F P
0 g
s
.68094 .63534 m .65966 .63764 L p .68143 .63411 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .68395 .62787 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68365 .63505 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68822 .59148 m .68395 .62787 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.66796 .62764 m .66008 .62753 L .68822 .59148 L .707 .577 .707 r
F
.65966 .63764 m .66008 .62753 L p .66599 .62761 L F P
0 g
s
.66008 .62753 m .65966 .63764 L .65802 .63804 L p .707 .577 .707 r
F P
0 g
s
.65802 .63804 m .64336 .64162 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .6647 .58817 L .66773 .5886 L p .707 .577 .707 r
F P
0 g
s
.66773 .5886 m .68822 .59148 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.6647 .58817 m .66008 .62753 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64336 .64162 m .64392 .62825 L p .64917 .62802 L .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64493 .60374 L .64628 .60341 L p .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63704 .62997 L p .63982 .62928 L .707 .577 .707 r
F P
0 g
s
.63666 .63733 m .64892 .58561 L .63644 .64151 L .707 .577 .707 r
F
.63571 .64133 m .64243 .58405 L .64892 .58561 L p F P
0 g
s
.63982 .62928 m .63704 .62997 L .64493 .60374 L .707 .577 .707 r
F
.6422 .6429 m .63644 .64151 L p .63913 .62945 L F P
0 g
s
.64392 .62825 m .6422 .6429 L p .63913 .62945 L .707 .577 .707 r
F P
0 g
s
.63571 .64133 m .63584 .64132 L p .63588 .64094 L .707 .577 .707 r
F P
0 g
s
.63644 .64151 m .63571 .64133 L p .63666 .63733 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63792 .60871 L .63941 .60766 L p .707 .577 .707 r
F P
0 g
s
.63941 .60766 m .64493 .60374 L p .63704 .62997 L .707 .577 .707 r
F P
0 g
s
.32477 .73812 m .3232 .776 L .29573 .77215 L p .707 .577 .707 r
F P
0 g
s
.29573 .77215 m .2973 .73426 L .32477 .73812 L p .707 .577 .707 r
F P
0 g
s
.21036 .70241 m .21114 .72031 L .18715 .72891 L p .707 .577 .707 r
F P
0 g
s
.33013 .7007 m .33091 .7186 L .30344 .71369 L p .707 .577 .707 r
F P
0 g
s
.30344 .71369 m .30266 .69579 L .33013 .7007 L p .707 .577 .707 r
F P
0 g
s
.59207 .25379 m .58915 .75758 L .55039 .75149 L p .707 .577 .707 r
F P
0 g
s
.55039 .75149 m .55331 .24769 L .59207 .25379 L p .707 .577 .707 r
F P
0 g
s
.20344 .76988 m .20501 .732 L .23434 .73105 L p .707 .577 .707 r
F P
0 g
s
.21114 .72031 m .21036 .70241 L .2397 .69669 L p .707 .577 .707 r
F P
0 g
s
.23434 .73105 m .23277 .76893 L .20344 .76988 L p .707 .577 .707 r
F P
0 g
s
.2973 .73426 m .29573 .77215 L .26457 .76971 L p .707 .577 .707 r
F P
0 g
s
.26457 .76971 m .26614 .73183 L .2973 .73426 L p .707 .577 .707 r
F P
0 g
s
.41996 .7538 m .42288 .25001 L .46436 .24571 L p .707 .577 .707 r
F P
0 g
s
.42288 .25001 m .41996 .7538 L .386 .76119 L p .707 .577 .707 r
F P
0 g
s
.30266 .69579 m .30344 .71369 L .27228 .7123 L p .707 .577 .707 r
F P
0 g
s
.27228 .7123 m .2715 .69441 L .30266 .69579 L p .707 .577 .707 r
F P
0 g
s
.2397 .69669 m .24047 .71459 L .21114 .72031 L p .707 .577 .707 r
F P
0 g
s
.23277 .76893 m .23434 .73105 L .26614 .73183 L p .707 .577 .707 r
F P
0 g
s
.26614 .73183 m .26457 .76971 L .23277 .76893 L p .707 .577 .707 r
F P
0 g
s
.24047 .71459 m .2397 .69669 L .2715 .69441 L p .707 .577 .707 r
F P
0 g
s
.2715 .69441 m .27228 .7123 L .24047 .71459 L p .707 .577 .707 r
F P
0 g
s
.55331 .24769 m .55039 .75149 L .50638 .7487 L p .707 .577 .707 r
F P
0 g
s
.50638 .7487 m .5093 .24491 L .55331 .24769 L p .707 .577 .707 r
F P
0 g
s
.46144 .7495 m .46436 .24571 L .5093 .24491 L p .707 .577 .707 r
F P
0 g
s
.46436 .24571 m .46144 .7495 L .41996 .7538 L p .707 .577 .707 r
F P
0 g
s
.5093 .24491 m .50638 .7487 L .46144 .7495 L p .707 .577 .707 r
F P
0 g
s
.73938 .79959 m .7386 .78169 L .70743 .78031 L p .707 .577 .707 r
F P
0 g
s
.7386 .78169 m .73938 .79959 L .77118 .79731 L p .707 .577 .707 r
F P
0 g
s
.77118 .79731 m .7704 .77941 L .7386 .78169 L p .707 .577 .707 r
F P
0 g
s
.7704 .77941 m .77118 .79731 L .80051 .79158 L p .707 .577 .707 r
F P
0 g
s
.80051 .79158 m .79973 .77369 L .7704 .77941 L p .707 .577 .707 r
F P
0 g
s
.70821 .7982 m .70743 .78031 L .67997 .7754 L p .707 .577 .707 r
F P
0 g
s
.70743 .78031 m .70821 .7982 L .73938 .79959 L p .707 .577 .707 r
F P
0 g
s
.79973 .77369 m .80051 .79158 L .8245 .78298 L p .707 .577 .707 r
F P
0 g
s
.8245 .78298 m .82372 .76509 L .79973 .77369 L p .707 .577 .707 r
F P
0 g
s
.67997 .7754 m .68074 .79329 L .70821 .7982 L p .707 .577 .707 r
F P
0 g
s
.68074 .79329 m .67997 .7754 L .65888 .76744 L p .707 .577 .707 r
F P
0 g
s
.65888 .76744 m .65966 .78534 L .68074 .79329 L p .707 .577 .707 r
F P
0 g
s
.82372 .76509 m .8245 .78298 L .8408 .77234 L p .707 .577 .707 r
F P
0 g
s
.8408 .77234 m .84002 .75445 L .82372 .76509 L p .707 .577 .707 r
F P
0 g
s
.65966 .78534 m .65888 .76744 L .64623 .75721 L p .707 .577 .707 r
F P
0 g
s
.64623 .75721 m .64701 .77511 L .65966 .78534 L p .707 .577 .707 r
F P
0 g
s
.84002 .75445 m .8408 .77234 L .84781 .7607 L p .707 .577 .707 r
F P
0 g
s
.84781 .7607 m .84703 .74281 L .84002 .75445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64701 .77511 m .64623 .75721 L .64328 .74572 L p .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .36066 .60988 L p .36046 .60948 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35802 .60959 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .3328 .60701 L p .33267 .60665 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33047 .60677 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .31103 .60504 L p .31095 .60462 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30914 .60488 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29715 .60416 L p .29715 .60364 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .29613 .6041 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29664 .59531 L .29287 .60412 L .707 .577 .707 r
F
.29283 .6045 m .29613 .6041 L p .29287 .60412 L F P
0 g
s
.29564 .59448 m .29711 .5957 L .29491 .5719 L .707 .577 .707 r
F
.29711 .5957 m .29787 .57739 L .29702 .5758 L p F P
0 g
s
.29702 .5758 m .29491 .5719 L p .29711 .5957 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .2927 .60452 L p .29664 .59531 L .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .2963 .61527 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29491 .5719 m .29403 .59316 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29334 .60978 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29664 .59531 m .29702 .58858 L .2957 .59453 L .707 .577 .707 r
F
.29702 .58858 m .29941 .54723 L .2957 .59453 L F
.29941 .54723 m .29403 .59316 L p .2957 .59453 L F P
0 g
s
.30292 .59713 m .30985 .59883 L .29787 .57739 L .707 .577 .707 r
F
.30985 .59883 m .31051 .58284 L .3065 .58111 L p F P
0 g
s
.3065 .58111 m .29787 .57739 L p .30985 .59883 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30845 .59849 L .29715 .60364 L .707 .577 .707 r
F
.29715 .60416 m .30914 .60488 L p .29715 .60364 L F P
0 g
s
.2963 .61527 m .30895 .62073 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29787 .57739 m .29711 .5957 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .2963 .61527 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29941 .54723 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29711 .5957 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .30284 .54681 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29711 .5957 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.31844 .60021 m .331 .60223 L .31051 .58284 L .707 .577 .707 r
F
.32497 .5862 m .31051 .58284 L p .331 .60223 L F P
0 g
s
.31051 .58284 m .30985 .59883 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.31586 .54759 m .30284 .54681 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30985 .59883 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .31586 .54759 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .32928 .60195 L .31095 .60462 L .707 .577 .707 r
F
.31103 .60504 m .33047 .60677 L p .31095 .60462 L F P
0 g
s
.30895 .62073 m .33003 .62562 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30895 .62073 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.29612 .59263 m .30426 .55618 L .30091 .59144 L .707 .577 .707 r
F
.331 .60223 m .3316 .58774 L .32497 .5862 L p F P
0 g
s
.31586 .54759 m .30985 .59883 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.30327 .56659 m .31822 .56294 L p .30091 .59144 L .707 .577 .707 r
F P
0 g
s
.30591 .54879 m .30091 .59144 L p .30426 .55618 L .707 .577 .707 r
F P
0 g
s
.30895 .62073 m .30985 .59883 L p .30292 .59713 L .707 .577 .707 r
F P
0 g
s
.2963 .61527 m .29711 .5957 L p .29564 .59448 L .707 .577 .707 r
F P
0 g
s
.30192 .56692 m .30091 .59144 L p .29334 .60978 L .707 .577 .707 r
F P
0 g
s
.30011 .60383 m .30529 .59124 L .29996 .60621 L .707 .577 .707 r
F
.30004 .60503 m .29334 .60978 L p .30091 .59144 L F P
0 g
s
.30616 .5912 m .30091 .59144 L .31822 .56294 L .707 .577 .707 r
F
.34138 .60349 m .35849 .60557 L .3316 .58774 L F
.35091 .59045 m .3316 .58774 L p .35849 .60557 L F P
0 g
s
.3316 .58774 m .331 .60223 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .31586 .54759 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .331 .60223 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33719 .54948 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35655 .60533 L .33267 .60665 L .707 .577 .707 r
F
.3328 .60701 m .35802 .60959 L p .33267 .60665 L F P
0 g
s
.33003 .62562 m .3575 .62948 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33003 .62562 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.29919 .60608 m .30591 .54879 L .32169 .55136 L p .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30035 .60481 L .30004 .60503 L p .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .29996 .60621 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.29996 .60621 m .29919 .60608 L p .30011 .60383 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31497 .60864 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .31707 .59071 L p .30035 .60481 L .707 .577 .707 r
F P
0 g
s
.33003 .62562 m .331 .60223 L p .31844 .60021 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35907 .5916 L .35091 .59045 L p .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .331 .60223 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .35907 .5916 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.35907 .5916 m .35849 .60557 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .33719 .54948 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35849 .60557 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .36474 .5523 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38719 .60829 L .36046 .60948 L .707 .577 .707 r
F
.36066 .60988 m .3891 .61306 L p .36046 .60948 L F P
0 g
s
.3575 .62948 m .38866 .63192 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .3575 .62948 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .34221 .56035 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31822 .56294 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .31707 .59071 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .31497 .60864 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .33849 .61195 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.3575 .62948 m .35849 .60557 L p .34138 .60349 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39023 .59403 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .35849 .60557 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .38963 .60852 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .39023 .59403 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .42067 .61685 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .3891 .61306 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42204 .59481 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .42137 .6108 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .42204 .59481 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .44963 .62058 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42067 .61685 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45137 .59386 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .45061 .61218 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .45137 .59386 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .47315 .62388 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .44963 .62058 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47536 .59127 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .47448 .61252 L p .47763 .59649 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .47536 .59127 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .48892 .62645 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47315 .62388 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49166 .58729 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .49064 .6118 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49564 .56916 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.49223 .58688 m .49166 .58729 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49236 .58493 L .48673 .61198 L .707 .577 .707 r
F
.49564 .56916 m .49064 .6118 L p .49548 .61059 L F P
0 g
s
.49009 .62517 m .49639 .6207 L p .49551 .61058 L .707 .577 .707 r
F P
0 g
s
.4967 .61778 m .49551 .61058 L .49639 .6207 L .707 .577 .707 r
F
.49548 .61059 m .4984 .59307 L .49564 .56916 L F
.50213 .57072 m .4996 .57011 L p .4984 .59307 L F P
0 g
s
.4996 .57011 m .49564 .56916 L p .4984 .59307 L .707 .577 .707 r
F P
0 g
s
.49752 .61008 m .50213 .57072 L p .49548 .61059 L .707 .577 .707 r
F P
0 g
s
.49551 .61058 m .49508 .60798 L .49469 .61079 L .707 .577 .707 r
F
.49508 .60798 m .49205 .5897 L .49469 .61079 L F
.49469 .61079 m .49205 .5897 L .49083 .61175 L F
.49551 .61058 m .49083 .61175 L .49009 .62517 L F
.4971 .62019 m .49752 .61008 L p .49569 .61054 L F P
0 g
s
.4967 .61778 m .49223 .58688 L .49205 .5897 L .707 .577 .707 r
F
.4971 .62019 m .49672 .6176 L .4967 .61778 L F
.49672 .6176 m .49223 .58688 L .4967 .61778 L F
.49867 .58231 m .49223 .58688 L p .49569 .61054 L F P
0 g
s
.49752 .61008 m .49867 .58231 L p .49569 .61054 L .707 .577 .707 r
F P
0 g
s
.49867 .58231 m .49752 .61008 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49009 .62517 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.48935 .62535 m .49009 .62517 L p .4895 .62382 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .48892 .62645 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.48892 .62645 m .49064 .6118 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .49064 .6118 L .4844 .61208 L .707 .577 .707 r
F
.49009 .62517 m .49064 .6118 L p .4895 .62382 L F P
0 g
s
.49548 .61059 m .49064 .6118 L .48935 .62543 L .707 .577 .707 r
F
.49542 .62801 m .49548 .61059 L .48935 .62543 L F
.48892 .62645 m .48924 .62652 L p .48935 .62543 L F P
0 g
s
.48924 .62652 m .49542 .62801 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .48935 .62535 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .4844 .61208 L .48935 .62535 L .707 .577 .707 r
F
.49571 .57682 m .49867 .58231 L p .49507 .60806 L F P
0 g
s
.49199 .62843 m .49444 .60753 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .49444 .60753 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49571 .57682 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .50169 .57078 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .4987 .57114 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.50169 .57078 m .50213 .57072 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .50169 .57078 L .50103 .57698 L .707 .577 .707 r
F
.49542 .62801 m .49752 .61008 L p .49548 .61059 L F P
0 g
s
.49542 .62801 m .49199 .62843 L p .4955 .60842 L .707 .577 .707 r
F P
0 g
s
.4955 .60842 m .50103 .57698 L .4974 .60998 L .707 .577 .707 r
F
.4955 .60842 m .4974 .60998 L .49542 .62801 L F
.49752 .61008 m .49542 .62801 L p .50103 .57698 L F P
0 g
s
.49414 .61471 m .49507 .60806 L .49752 .61008 L .707 .577 .707 r
F
.49752 .61008 m .4971 .62019 L .497 .62001 L p F P
0 g
s
.49639 .6207 m .4971 .62019 L p .4967 .61778 L .707 .577 .707 r
F P
0 g
s
.497 .62001 m .49414 .61471 L p .49752 .61008 L .707 .577 .707 r
F P
0 g
s
.50213 .57072 m .49752 .61008 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.48673 .61198 m .49236 .58493 L .47986 .5666 L .707 .577 .707 r
F
.49564 .56916 m .49339 .56879 L p .49236 .58493 L F P
0 g
s
.49339 .56879 m .47986 .5666 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.4844 .61208 m .47763 .59649 L .47575 .61247 L .707 .577 .707 r
F
.4844 .61208 m .47575 .61247 L .47379 .62915 L F
.47448 .61252 m .47379 .62915 L p .47763 .59649 L F P
0 g
s
.47986 .5666 m .47448 .61252 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47986 .5666 m .45634 .56329 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .47448 .61252 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47986 .5666 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .47448 .61252 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .47379 .62915 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .4498 .63174 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .45061 .61218 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .42738 .55956 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .45061 .61218 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45634 .56329 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .45061 .61218 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .4498 .63174 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42047 .6327 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .42137 .6108 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .39582 .55577 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .42137 .6108 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42738 .55956 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .42137 .6108 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .42047 .6327 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .38866 .63192 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .38963 .60852 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .36474 .5523 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38963 .60852 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39582 .55577 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .37154 .55939 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .34094 .59106 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34094 .59106 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34221 .56035 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .33849 .61195 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36745 .61568 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .38963 .60852 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.40334 .56017 m .43451 .56261 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .46198 .56647 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .43305 .59767 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .43305 .59767 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43451 .56261 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .48306 .57136 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .46055 .60101 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .46055 .60101 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46198 .56647 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .49571 .57682 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .4817 .60441 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .4817 .60441 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48306 .57136 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .47897 .62765 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49199 .62843 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .4815 .60925 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49571 .57682 m .49444 .60753 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49414 .61471 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .49444 .60753 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4987 .57114 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48569 .57036 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .45764 .62576 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .47897 .62765 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .46041 .60435 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .4817 .60441 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .4815 .60925 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4817 .60441 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .48569 .57036 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46436 .56847 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .43009 .62294 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .45764 .62576 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .43294 .60049 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .46055 .60101 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46041 .60435 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .46055 .60101 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .46436 .56847 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43681 .56565 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.39901 .61947 m .40191 .59471 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .39901 .61947 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43009 .62294 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .40178 .59806 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .43305 .59767 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43294 .60049 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .43305 .59767 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40573 .56218 m .43681 .56565 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.403 .59482 m .40334 .56017 L .40463 .59497 L .707 .577 .707 r
F
.40191 .59471 m .40334 .56017 L p .40298 .59676 L F P
0 g
s
.40191 .59471 m .40573 .56218 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40298 .59676 m .403 .59482 L .40463 .59497 L .707 .577 .707 r
F
.40178 .59806 m .40191 .59471 L p .40298 .59676 L F P
0 g
s
.37154 .55939 m .40334 .56017 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .37017 .59244 L p .38048 .59318 L .707 .577 .707 r
F P
0 g
s
.36997 .59728 m .37017 .59244 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .37154 .55939 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .38048 .59318 L .3834 .59339 L .707 .577 .707 r
F
.40334 .56017 m .40191 .59471 L p .37408 .59272 L F P
0 g
s
.40573 .56218 m .39901 .61947 L .36745 .61568 L p .707 .577 .707 r
F P
0 g
s
.40178 .59806 m .36997 .59728 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.40191 .59471 m .40178 .59806 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.3834 .59339 m .39135 .57442 L .39372 .57897 L .707 .577 .707 r
F
.38048 .59318 m .39135 .57442 L .3834 .59339 L F
.38048 .59318 m .37017 .59244 L .39135 .57442 L F
.39372 .57897 m .39135 .57442 L .40573 .56218 L F
.37017 .59244 m .37416 .55839 L .38987 .56028 L p F P
0 g
s
.38987 .56028 m .40573 .56218 L p .37017 .59244 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34615 .5913 L .36758 .59668 L .707 .577 .707 r
F
.36997 .59728 m .36715 .59737 L p .36758 .59668 L F P
0 g
s
.36715 .59737 m .34064 .59823 L p .36758 .59668 L .707 .577 .707 r
F P
0 g
s
.37154 .55939 m .37017 .59244 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36997 .59728 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37416 .55839 m .37017 .59244 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.35206 .59158 m .34094 .59106 L .37416 .55839 L .707 .577 .707 r
F
.34094 .59106 m .34521 .55466 L .35509 .55594 L p F P
0 g
s
.35509 .55594 m .37416 .55839 L p .34094 .59106 L .707 .577 .707 r
F P
0 g
s
.31665 .60083 m .32298 .5908 L .33842 .5973 L .707 .577 .707 r
F
.34064 .59823 m .33793 .59852 L p .33842 .5973 L F P
0 g
s
.33793 .59852 m .31665 .60083 L p .33842 .5973 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .34094 .59106 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34064 .59823 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34521 .55466 m .34094 .59106 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.32495 .59083 m .31707 .59071 L .34521 .55466 L .707 .577 .707 r
F
.31665 .60083 m .31707 .59071 L p .32298 .5908 L F P
0 g
s
.31707 .59071 m .31665 .60083 L .31501 .60123 L p .707 .577 .707 r
F P
0 g
s
.31501 .60123 m .30035 .60481 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .32169 .55136 L .32472 .55178 L p .707 .577 .707 r
F P
0 g
s
.32472 .55178 m .34521 .55466 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.32169 .55136 m .31707 .59071 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.30035 .60481 m .30091 .59144 L p .30616 .5912 L .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30192 .56692 L .30327 .56659 L p .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .29403 .59316 L p .29681 .59246 L .707 .577 .707 r
F P
0 g
s
.29365 .60052 m .30591 .54879 L .29343 .60469 L .707 .577 .707 r
F
.2927 .60452 m .29941 .54723 L .30591 .54879 L p F P
0 g
s
.29681 .59246 m .29403 .59316 L .30192 .56692 L .707 .577 .707 r
F
.29919 .60608 m .29343 .60469 L p .29612 .59263 L F P
0 g
s
.30091 .59144 m .29919 .60608 L p .29612 .59263 L .707 .577 .707 r
F P
0 g
s
.2927 .60452 m .29283 .6045 L p .29287 .60412 L .707 .577 .707 r
F P
0 g
s
.29343 .60469 m .2927 .60452 L p .29365 .60052 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29491 .5719 L .2964 .57084 L p .707 .577 .707 r
F P
0 g
s
.2964 .57084 m .30192 .56692 L p .29403 .59316 L .707 .577 .707 r
F P
0 g
s
.64328 .74572 m .64405 .76361 L .64701 .77511 L p .707 .577 .707 r
F P
0 g
s
.84703 .74281 m .84781 .7607 L .84485 .74921 L p .707 .577 .707 r
F P
0 g
s
.84485 .74921 m .84407 .73131 L .84703 .74281 L p .707 .577 .707 r
F P
0 g
s
.64405 .76361 m .64328 .74572 L .65029 .73408 L p .707 .577 .707 r
F P
0 g
s
.65029 .73408 m .65107 .75198 L .64405 .76361 L p .707 .577 .707 r
F P
0 g
s
.84407 .73131 m .84485 .74921 L .83221 .73898 L p .707 .577 .707 r
F P
0 g
s
.83221 .73898 m .83143 .72109 L .84407 .73131 L p .707 .577 .707 r
F P
0 g
s
.65107 .75198 m .65029 .73408 L .66659 .72344 L p .707 .577 .707 r
F P
0 g
s
.39637 .76277 m .39559 .74488 L .36442 .7435 L p .707 .577 .707 r
F P
0 g
s
.39559 .74488 m .39637 .76277 L .42817 .76049 L p .707 .577 .707 r
F P
0 g
s
.42817 .76049 m .42739 .7426 L .39559 .74488 L p .707 .577 .707 r
F P
0 g
s
.42739 .7426 m .42817 .76049 L .4575 .75477 L p .707 .577 .707 r
F P
0 g
s
.4575 .75477 m .45672 .73687 L .42739 .7426 L p .707 .577 .707 r
F P
0 g
s
.66659 .72344 m .66737 .74134 L .65107 .75198 L p .707 .577 .707 r
F P
0 g
s
.3652 .76139 m .36442 .7435 L .33695 .73859 L p .707 .577 .707 r
F P
0 g
s
.36442 .7435 m .3652 .76139 L .39637 .76277 L p .707 .577 .707 r
F P
0 g
s
.83143 .72109 m .83221 .73898 L .81112 .73102 L p .707 .577 .707 r
F P
0 g
s
.81112 .73102 m .81034 .71313 L .83143 .72109 L p .707 .577 .707 r
F P
0 g
s
.45672 .73687 m .4575 .75477 L .48149 .74617 L p .707 .577 .707 r
F P
0 g
s
.48149 .74617 m .48071 .72827 L .45672 .73687 L p .707 .577 .707 r
F P
0 g
s
.33695 .73859 m .33773 .75648 L .3652 .76139 L p .707 .577 .707 r
F P
0 g
s
.33773 .75648 m .33695 .73859 L .31587 .73063 L p .707 .577 .707 r
F P
0 g
s
.66737 .74134 m .66659 .72344 L .69058 .71484 L p .707 .577 .707 r
F P
0 g
s
.31587 .73063 m .31665 .74852 L .33773 .75648 L p .707 .577 .707 r
F P
0 g
s
.69058 .71484 m .69136 .73273 L .66737 .74134 L p .707 .577 .707 r
F P
0 g
s
.48071 .72827 m .48149 .74617 L .49779 .73552 L p .707 .577 .707 r
F P
0 g
s
.49779 .73552 m .49701 .71763 L .48071 .72827 L p .707 .577 .707 r
F P
0 g
s
.81034 .71313 m .81112 .73102 L .78365 .72611 L p .707 .577 .707 r
F P
0 g
s
.78365 .72611 m .78287 .70822 L .81034 .71313 L p .707 .577 .707 r
F P
0 g
s
.69136 .73273 m .69058 .71484 L .71991 .70912 L p .707 .577 .707 r
F P
0 g
s
.31665 .74852 m .31587 .73063 L .30322 .7204 L p .707 .577 .707 r
F P
0 g
s
.78287 .70822 m .78365 .72611 L .75249 .72473 L p .707 .577 .707 r
F P
0 g
s
.75249 .72473 m .75171 .70683 L .78287 .70822 L p .707 .577 .707 r
F P
0 g
s
.71991 .70912 m .72069 .72701 L .69136 .73273 L p .707 .577 .707 r
F P
0 g
s
.30322 .7204 m .304 .73829 L .31665 .74852 L p .707 .577 .707 r
F P
0 g
s
.72069 .72701 m .71991 .70912 L .75171 .70683 L p .707 .577 .707 r
F P
0 g
s
.75171 .70683 m .75249 .72473 L .72069 .72701 L p .707 .577 .707 r
F P
0 g
s
.49701 .71763 m .49779 .73552 L .5048 .72389 L p .707 .577 .707 r
F P
0 g
s
.5048 .72389 m .50402 .70599 L .49701 .71763 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.304 .73829 m .30322 .7204 L .30026 .7089 L p .707 .577 .707 r
F P
0 g
s
.30026 .7089 m .30104 .7268 L .304 .73829 L p .707 .577 .707 r
F P
0 g
s
.50402 .70599 m .5048 .72389 L .50184 .71239 L p .707 .577 .707 r
F P
0 g
s
.50184 .71239 m .50106 .6945 L .50402 .70599 L p .707 .577 .707 r
F P
0 g
s
.30104 .7268 m .30026 .7089 L .30728 .69727 L p .707 .577 .707 r
F P
0 g
s
.30728 .69727 m .30806 .71516 L .30104 .7268 L p .707 .577 .707 r
F P
0 g
s
.50106 .6945 m .50184 .71239 L .4892 .70216 L p .707 .577 .707 r
F P
0 g
s
.4892 .70216 m .48842 .68427 L .50106 .6945 L p .707 .577 .707 r
F P
0 g
s
.30806 .71516 m .30728 .69727 L .32358 .68663 L p .707 .577 .707 r
F P
0 g
s
.32358 .68663 m .32436 .70452 L .30806 .71516 L p .707 .577 .707 r
F P
0 g
s
.48842 .68427 m .4892 .70216 L .46811 .69421 L p .707 .577 .707 r
F P
0 g
s
.46811 .69421 m .46733 .67631 L .48842 .68427 L p .707 .577 .707 r
F P
0 g
s
.32436 .70452 m .32358 .68663 L .34757 .67802 L p .707 .577 .707 r
F P
0 g
s
.34757 .67802 m .34835 .69592 L .32436 .70452 L p .707 .577 .707 r
F P
0 g
s
.46733 .67631 m .46811 .69421 L .44064 .6893 L p .707 .577 .707 r
F P
0 g
s
.44064 .6893 m .43986 .6714 L .46733 .67631 L p .707 .577 .707 r
F P
0 g
s
.34835 .69592 m .34757 .67802 L .3769 .6723 L p .707 .577 .707 r
F P
0 g
s
.43986 .6714 m .44064 .6893 L .40948 .68791 L p .707 .577 .707 r
F P
0 g
s
.40948 .68791 m .4087 .67002 L .43986 .6714 L p .707 .577 .707 r
F P
0 g
s
.3769 .6723 m .37768 .69019 L .34835 .69592 L p .707 .577 .707 r
F P
0 g
s
.37768 .69019 m .3769 .6723 L .4087 .67002 L p .707 .577 .707 r
F P
0 g
s
.4087 .67002 m .40948 .68791 L .37768 .69019 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo5P00QWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001mOol007Ioo`D000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001]Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP<006aoo`00JGoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`8000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol70008Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol>00001Goo001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH01000FUIJEUYF3@00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH00`00FUIJEP04FUHC
0002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00010000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol30004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001COol40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF2@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002001TOol0
05=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000>001HOol005=oo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH005YF001JEPH00003FUH005YF009JEPT004moo`00;goo0P008Woo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH:0004FUH80017Ool002ioo`h001Moo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00eYF5P00
?Woo000^Ool20002FUH70003FUH9000>Ool2FUH01000FUIJEUYF300015YF00<005YFFUH00UYF3P00
1UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ@003Moo`00;Woo0P0015YF00@005YFFUIJEPL00003FUH005YF00=JEPT000Eoo`04001J
EP00FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEQ80039oo`00;Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT00003FUH005YF00=J
EPT0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000QJEP03001JEUYF00AJ
EP04001JEP000002FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEQ0002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000AJEP000000009JEPH000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`001EYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEP00008000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH?0003FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF2P000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JER8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=J
EPH000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHE000015YF0000000015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF0P0025YF00@005YFFUIJEPL000=JEP05001JEUYFFUH0000^Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH0000002ioo`00;7oo10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH00eYF
2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
<7oo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010000eYF0P001eYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00=Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00EJEPP000AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool003eoo`T000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH<
0002FUH2000^Ool004Ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH8
0004FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF2P00;Woo001?Ool80004FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH03`0015YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2OolJ000hOol005Moo``00004FUH005YFFUH90004
FUH00`00FUIJEP06FUH00`00FUH00004000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPMoo`D0
04Qoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<0
05YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00Ggoo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YF
FUIJEP8000Qoo`<004Uoo`00GGoo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00Fgoo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00FWoo0P001eYF00<005YFFUH0
0UYF20001eYF00<005YF00001`0015YF00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0019OolA00000eYF001JEP05FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH6
0004FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00E7oo0010Ool90004FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH3000015YF001JEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00>Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00@005YF000000Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH20002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000hOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH2000015YF000000000Woo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00EGoo000fOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002FUH200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000080003FUH01000FUIJEUYF0P000goo5`00>goo000dOol20006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH=000015YF0000000015YF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF0P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo300000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Ioo`00<goo0P001eYF00<005YFFUH00UYF200037oo00<005YF00001000
0UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH01eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
37oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=7oo000aOol20000
0eYF001JEP05FUH6000DOol20005Ool40004FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000027oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00P00<Woo000_Ool20004FUH01000FUIJEUYF0P003Goo0`002Woo0`00
27oo0`0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP80031oo`00;goo00=JEP00FUH00eYF00@005YF000000ioo`D000Uoo`800003FUH007oo
00Uoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP80
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<0
00IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP<002ioo`00;Woo00<007oo000015YF0P00
27oo3@002Goo0P000UYF00<007ooOol027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEUYFFUH20004FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP04000GOol50005FUH01000FUIJ
EP00;Goo000^Ool00`00Ool00002FUH<0003FUH00`00FUIJEP02FUH@0002FUH30008Ool01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF100000=JEP00FUH00eYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH00eYF
100087oo0P000eYF00@005YFFUH002eoo`00;Woo00<005YF00000`001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00P001Woo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03001JEP0000<002Io
o`800005FUH005YFFUH0000]Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH01000FUIJEUYF1@0000Eoo`00FUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP<0
0004FUH00000000WOol20002FUH2000/Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH01000FUIJEUYF6@001EYF00<0
05YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEUYF009JEP8002Moo`04001JEUYF000/Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000X000IJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP<000=JEP03001JEUYF00=JEP8002Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001P002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF0P0015YF00<005YFFUH00eYF00<005YF00009goo0P00;7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000Woo1@001EYF00@005YFFUH002Eoo`03001JEP0002aoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00008000Mo
o`8000=JEP04001JEUYF000TOol200000eYF001oo`0[Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEP0001L0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00008000Uoo`800005FUH005YFFUH0000ROol2
000015YF001JEP00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP05001JEP00001JEP020009Ool20003FUH00`00Oomoo`0MOol20003
FUH2000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
0P002Goo0P0000=JEP00Ool077oo0P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH00002FUH6
00000eYF001JEP06FUH00`00FUIJEP05FUH30005FUH80003FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF0P0000=JEP00FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP0000000eYF00<005YF00000P0027oo
0P006goo0P000eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P000eYF0P000eYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF1@0015YF00H005YFFUH005YF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF00000003FUH00`00FUIJEP02FUH50003Ool2000E
Ool60005FUH01000FUIJEP00;goo000/Ool20002FUH00`00FUIJEP03FUH200000eYF001JEP05FUH0
0`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH7000015YF001JEUYF0P0015YF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000AJEP00FUH0009JEP03001JEUYF00=JEP04001JEUYFFUH80009Ool90004
FUH00`00FUIJEP04FUH3000`Ool002aoo`80009JEP03001JEUYF00=JEP03001JEP0000@000=JEP03
001JEUYF00AJEPD000IJEP03001JEUYF00D000EJEP@00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP000002FUH30005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00<Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF6000
0eYF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EP000004FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00=7oo000^Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP001UYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000003Ioo`00<7oo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00001eYF00<005YFFUH01@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@00>7oo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP060002FUH00`00FUIJEP05FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP03FUH00`00FUH000080004FUH00`00FUIJEP02FUH9000mOol0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60006Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001Goo2@00AWoo0013
OolI000>Ool20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00K7oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YFFUH005YF001DOol006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00=JEPD000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
05Eoo`00LGoo1`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
20001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P00EGoo001hOol<0006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH70004FUH50006FUH00`00FUIJEP02FUH50002FUH40002FUH2001EOol008Ao
ob<0009JEPD0009JEPT00003FUH005YF00EJEP03001JEUYF00@005Eoo`00SWoo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<005Eoo`00T7oo100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009Aoo`<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYFFUH005YFEWoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001GOol009aooa4000EJEP03001JEUYF009JEPd005Uoo`00[Goo
2P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57054 .63648 m .56383 .69376 L .59491 .69724 L p .707 .577 .707 r
F P
0 g
s
.59491 .69724 m .60162 .63995 L .57054 .63648 L p .707 .577 .707 r
F P
0 g
s
.60162 .63995 m .59491 .69724 L .62647 .70102 L p .707 .577 .707 r
F P
0 g
s
.62647 .70102 m .63319 .64374 L .60162 .63995 L p .707 .577 .707 r
F P
0 g
s
.63319 .64374 m .62647 .70102 L .65543 .70475 L p .707 .577 .707 r
F P
0 g
s
.65543 .70475 m .66215 .64747 L .63319 .64374 L p .707 .577 .707 r
F P
0 g
s
.54299 .63366 m .53628 .69094 L .56383 .69376 L p .707 .577 .707 r
F P
0 g
s
.56383 .69376 m .57054 .63648 L .54299 .63366 L p .707 .577 .707 r
F P
0 g
s
.66215 .64747 m .65543 .70475 L .67895 .70806 L p .707 .577 .707 r
F P
0 g
s
.67895 .70806 m .68567 .65077 L .66215 .64747 L p .707 .577 .707 r
F P
0 g
s
.52167 .63177 m .51495 .68905 L .53628 .69094 L p .707 .577 .707 r
F P
0 g
s
.53628 .69094 m .54299 .63366 L .52167 .63177 L p .707 .577 .707 r
F P
0 g
s
.59447 .84038 m .59604 .8025 L .56488 .80006 L p .707 .577 .707 r
F P
0 g
s
.59604 .8025 m .59447 .84038 L .62627 .84116 L p .707 .577 .707 r
F P
0 g
s
.62627 .84116 m .62784 .80328 L .59604 .8025 L p .707 .577 .707 r
F P
0 g
s
.62784 .80328 m .62627 .84116 L .6556 .84021 L p .707 .577 .707 r
F P
0 g
s
.6556 .84021 m .65717 .80233 L .62784 .80328 L p .707 .577 .707 r
F P
0 g
s
.68567 .65077 m .67895 .70806 L .69473 .71062 L p .707 .577 .707 r
F P
0 g
s
.56488 .80006 m .56331 .83795 L .59447 .84038 L p .707 .577 .707 r
F P
0 g
s
.56331 .83795 m .56488 .80006 L .53741 .79621 L p .707 .577 .707 r
F P
0 g
s
.69473 .71062 m .70144 .65333 L .68567 .65077 L p .707 .577 .707 r
F P
0 g
s
.53741 .79621 m .53584 .83409 L .56331 .83795 L p .707 .577 .707 r
F P
0 g
s
.50865 .63099 m .50193 .68828 L .51495 .68905 L p .707 .577 .707 r
F P
0 g
s
.51495 .68905 m .52167 .63177 L .50865 .63099 L p .707 .577 .707 r
F P
0 g
s
.60217 .82398 m .60139 .80608 L .57023 .8047 L p .707 .577 .707 r
F P
0 g
s
.60139 .80608 m .60217 .82398 L .63397 .8217 L p .707 .577 .707 r
F P
0 g
s
.63397 .8217 m .63319 .8038 L .60139 .80608 L p .707 .577 .707 r
F P
0 g
s
.65717 .80233 m .6556 .84021 L .67959 .83762 L p .707 .577 .707 r
F P
0 g
s
.67959 .83762 m .68116 .79973 L .65717 .80233 L p .707 .577 .707 r
F P
0 g
s
.63319 .8038 m .63397 .8217 L .66331 .81597 L p .707 .577 .707 r
F P
0 g
s
.66331 .81597 m .66253 .79808 L .63319 .8038 L p .707 .577 .707 r
F P
0 g
s
.57101 .8226 m .57023 .8047 L .54276 .79979 L p .707 .577 .707 r
F P
0 g
s
.57023 .8047 m .57101 .8226 L .60217 .82398 L p .707 .577 .707 r
F P
0 g
s
.53584 .83409 m .53741 .79621 L .51632 .79131 L p .707 .577 .707 r
F P
0 g
s
.68116 .79973 m .67959 .83762 L .69589 .83364 L p .707 .577 .707 r
F P
0 g
s
.69589 .83364 m .69746 .79575 L .68116 .79973 L p .707 .577 .707 r
F P
0 g
s
.66253 .79808 m .66331 .81597 L .6873 .80737 L p .707 .577 .707 r
F P
0 g
s
.6873 .80737 m .68652 .78948 L .66253 .79808 L p .707 .577 .707 r
F P
0 g
s
.54276 .79979 m .54354 .81769 L .57101 .8226 L p .707 .577 .707 r
F P
0 g
s
.51632 .79131 m .51475 .82919 L .53584 .83409 L p .707 .577 .707 r
F P
0 g
s
.70144 .65333 m .69473 .71062 L .70122 .71219 L p .707 .577 .707 r
F P
0 g
s
.70122 .71219 m .70794 .6549 L .70144 .65333 L p .707 .577 .707 r
F P
0 g
s
.54354 .81769 m .54276 .79979 L .52167 .79183 L p .707 .577 .707 r
F P
0 g
s
.50522 .63141 m .49851 .68869 L .50193 .68828 L p .707 .577 .707 r
F P
0 g
s
.50193 .68828 m .50865 .63099 L .50522 .63141 L p .707 .577 .707 r
F P
0 g
s
.52167 .79183 m .52245 .80973 L .54354 .81769 L p .707 .577 .707 r
F P
0 g
s
.51475 .82919 m .51632 .79131 L .50368 .78585 L p .707 .577 .707 r
F P
0 g
s
.69746 .79575 m .69589 .83364 L .69861 .83171 L p .707 .577 .707 r
F P
0 g
s
.69861 .83171 m .7029 .82866 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.69906 .8054 m .69746 .79575 L .69861 .83171 L .707 .577 .707 r
F
.69915 .79963 m .7036 .79673 L p .69923 .79488 L F P
0 g
s
.7036 .79673 m .70282 .77884 L .69947 .78102 L p .707 .577 .707 r
F P
0 g
s
.7036 .79673 m .69947 .78102 L .69923 .79488 L .707 .577 .707 r
F
.70282 .77884 m .7036 .79673 L .71061 .78509 L p F P
0 g
s
.7029 .82866 m .70447 .79078 L .69924 .79449 L p .707 .577 .707 r
F P
0 g
s
.69924 .79449 m .69746 .79575 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.7029 .82866 m .69924 .79449 L .69906 .8054 L .707 .577 .707 r
F
.69947 .78102 m .68652 .78948 L p .69923 .79488 L F P
0 g
s
.68652 .78948 m .6873 .80737 L .69915 .79963 L p .707 .577 .707 r
F P
0 g
s
.69923 .79488 m .68652 .78948 L .69915 .79963 L .707 .577 .707 r
F
.50368 .78585 m .50211 .82374 L .51475 .82919 L p F P
0 g
s
.52245 .80973 m .52167 .79183 L .50903 .78161 L p .707 .577 .707 r
F P
0 g
s
.70794 .6549 m .70122 .71219 L .69779 .7126 L p .707 .577 .707 r
F P
0 g
s
.69779 .7126 m .70451 .65531 L .70794 .6549 L p .707 .577 .707 r
F P
0 g
s
.50903 .78161 m .50981 .7995 L .52245 .80973 L p .707 .577 .707 r
F P
0 g
s
.48726 .82194 m .49019 .31815 L .44618 .31537 L p .707 .577 .707 r
F P
0 g
s
.50211 .82374 m .50368 .78585 L .50072 .78037 L p .707 .577 .707 r
F P
0 g
s
.51171 .63297 m .505 .69026 L .49851 .68869 L p .707 .577 .707 r
F P
0 g
s
.49851 .68869 m .50522 .63141 L .51171 .63297 L p .707 .577 .707 r
F P
0 g
s
.50072 .78037 m .49915 .81825 L .50211 .82374 L p .707 .577 .707 r
F P
0 g
s
.50981 .7995 m .50903 .78161 L .50607 .77011 L p .707 .577 .707 r
F P
0 g
s
.50607 .77011 m .50685 .788 L .50981 .7995 L p .707 .577 .707 r
F P
0 g
s
.52749 .63553 m .52078 .69282 L .505 .69026 L p .707 .577 .707 r
F P
0 g
s
.505 .69026 m .51171 .63297 L .52749 .63553 L p .707 .577 .707 r
F P
0 g
s
.50685 .788 m .50607 .77011 L .51164 .76086 L p .707 .577 .707 r
F P
0 g
s
.51164 .76086 m .51308 .75847 L p .51171 .76497 L .707 .577 .707 r
F P
0 g
s
.50685 .788 m .51164 .76086 L .51171 .76497 L .707 .577 .707 r
F
.51187 .77438 m .52403 .77141 L p .51227 .79895 L F P
0 g
s
.51308 .75847 m .51386 .77637 L .50685 .788 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .50773 .77539 L .51187 .77438 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .51187 .77438 L .51227 .79895 L .707 .577 .707 r
F
.49915 .81825 m .50072 .78037 L .50773 .77539 L p F P
0 g
s
.50773 .77539 m .50616 .81327 L .49915 .81825 L p .707 .577 .707 r
F P
0 g
s
.55101 .63884 m .5443 .69613 L .52078 .69282 L p .707 .577 .707 r
F P
0 g
s
.52078 .69282 m .52749 .63553 L .55101 .63884 L p .707 .577 .707 r
F P
0 g
s
.52403 .77141 m .52246 .80929 L .50616 .81327 L p .707 .577 .707 r
F P
0 g
s
.51386 .77637 m .51308 .75847 L .52938 .74783 L p .707 .577 .707 r
F P
0 g
s
.52938 .74783 m .53016 .76573 L .51386 .77637 L p .707 .577 .707 r
F P
0 g
s
.52246 .80929 m .52403 .77141 L .54802 .76882 L p .707 .577 .707 r
F P
0 g
s
.54802 .76882 m .54645 .8067 L .52246 .80929 L p .707 .577 .707 r
F P
0 g
s
.49019 .31815 m .48726 .82194 L .53221 .82114 L p .707 .577 .707 r
F P
0 g
s
.53016 .76573 m .52938 .74783 L .55337 .73923 L p .707 .577 .707 r
F P
0 g
s
.55337 .73923 m .55415 .75712 L .53016 .76573 L p .707 .577 .707 r
F P
0 g
s
.53221 .82114 m .53513 .31735 L .49019 .31815 L p .707 .577 .707 r
F P
0 g
s
.71061 .78509 m .70983 .7672 L .70282 .77884 L p .707 .577 .707 r
F P
0 g
s
.57997 .64257 m .57325 .69986 L .5443 .69613 L p .707 .577 .707 r
F P
0 g
s
.5443 .69613 m .55046 .64356 L p .57997 .64257 L .707 .577 .707 r
F P
0 g
s
.55046 .64356 m .55101 .63884 L .55282 .63907 L p .707 .577 .707 r
F P
0 g
s
.55282 .63907 m .57997 .64257 L p .55046 .64356 L .707 .577 .707 r
F P
0 g
s
.61153 .64636 m .60482 .70364 L .57627 .70022 L p .707 .577 .707 r
F P
0 g
s
.57627 .70022 m .57325 .69986 L p .57734 .69415 L .707 .577 .707 r
F P
0 g
s
.57734 .69415 m .61153 .64636 L .57627 .70022 L .707 .577 .707 r
F
.64261 .64983 m .6359 .70712 L .61057 .70428 L p F P
0 g
s
.61057 .70428 m .60482 .70364 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.61127 .69446 m .64261 .64983 L .61057 .70428 L .707 .577 .707 r
F
.67017 .65265 m .66345 .70994 L .6359 .70712 L p F P
0 g
s
.6359 .70712 m .64261 .64983 L .67017 .65265 L p .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61153 .64636 L .61466 .6467 L p .707 .577 .707 r
F P
0 g
s
.61466 .6467 m .64261 .64983 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61466 .6467 L .61127 .69446 L .707 .577 .707 r
F
.63874 .80896 m .64031 .77108 L .66778 .77494 L p F P
0 g
s
.64567 .73261 m .64645 .7505 L .61529 .74912 L p .707 .577 .707 r
F P
0 g
s
.61529 .74912 m .61451 .73123 L .64567 .73261 L p .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64367 .28475 L .64008 .28876 L p .707 .577 .707 r
F P
0 g
s
.64008 .28876 m .63367 .2959 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64008 .28876 L .63466 .36497 L .707 .577 .707 r
F
.64031 .77108 m .63874 .80896 L .60758 .80653 L p F P
0 g
s
.60758 .80653 m .60915 .76864 L .64031 .77108 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .64075 .78854 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63367 .2959 m .63315 .38633 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63315 .38633 m .63075 .7997 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.57578 .80575 m .57735 .76786 L .60915 .76864 L p .707 .577 .707 r
F P
0 g
s
.60915 .76864 m .60758 .80653 L .57578 .80575 L p .707 .577 .707 r
F P
0 g
s
.58348 .7514 m .5827 .73351 L .61451 .73123 L p .707 .577 .707 r
F P
0 g
s
.61451 .73123 m .61529 .74912 L .58348 .7514 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .63075 .7997 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.61056 .30566 m .60937 .51188 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.57325 .69986 m .57997 .64257 L .61153 .64636 L p .707 .577 .707 r
F P
0 g
s
.60937 .51188 m .60764 .80945 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.54645 .8067 m .54802 .76882 L .57735 .76786 L p .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .55337 .73923 L .56591 .73678 L p .707 .577 .707 r
F P
0 g
s
.56591 .73678 m .5827 .73351 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .56591 .73678 L .56796 .7457 L .707 .577 .707 r
F
.57735 .76786 m .57578 .80575 L .54645 .8067 L p F P
0 g
s
.5827 .73351 m .58348 .7514 L .56988 .75405 L p .707 .577 .707 r
F P
0 g
s
.56988 .75405 m .55415 .75712 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.56796 .7457 m .5827 .73351 L .56988 .75405 L .707 .577 .707 r
F
.57496 .59696 m .57395 .77173 L p .5923 .56399 L F P
0 g
s
.57395 .77173 m .57369 .81684 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.5923 .56399 m .57395 .77173 L .57627 .7818 L .707 .577 .707 r
F
.60764 .80945 m .5923 .56399 L .57627 .7818 L F
.57369 .81684 m .58382 .81463 L p .57627 .7818 L F P
0 g
s
.58382 .81463 m .60764 .80945 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.57661 .31305 m .57496 .59696 L p .5923 .56399 L .707 .577 .707 r
F P
0 g
s
.53513 .31735 m .53221 .82114 L .57369 .81684 L p .707 .577 .707 r
F P
0 g
s
.57369 .81684 m .57661 .31305 L .53513 .31735 L p .707 .577 .707 r
F P
0 g
s
.44326 .81916 m .44618 .31537 L .40741 .30927 L p .707 .577 .707 r
F P
0 g
s
.44618 .31537 m .44326 .81916 L .48726 .82194 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .61056 .30566 L .57661 .31305 L p .707 .577 .707 r
F P
0 g
s
.70447 .79078 m .7029 .82866 L .69994 .82317 L p .707 .577 .707 r
F P
0 g
s
.69994 .82317 m .70151 .78529 L .70447 .79078 L p .707 .577 .707 r
F P
0 g
s
.70451 .65531 m .69779 .7126 L .68478 .71183 L p .707 .577 .707 r
F P
0 g
s
.68478 .71183 m .69149 .65454 L .70451 .65531 L p .707 .577 .707 r
F P
0 g
s
.22754 .59966 m .22082 .65695 L .2519 .66042 L p .707 .577 .707 r
F P
0 g
s
.2519 .66042 m .25861 .60313 L .22754 .59966 L p .707 .577 .707 r
F P
0 g
s
.25861 .60313 m .2519 .66042 L .28346 .66421 L p .707 .577 .707 r
F P
0 g
s
.28346 .66421 m .29018 .60692 L .25861 .60313 L p .707 .577 .707 r
F P
0 g
s
.70983 .7672 m .71061 .78509 L .70765 .7736 L p .707 .577 .707 r
F P
0 g
s
.70765 .7736 m .70687 .75571 L .70983 .7672 L p .707 .577 .707 r
F P
0 g
s
.40449 .81306 m .40741 .30927 L .37769 .30045 L p .707 .577 .707 r
F P
0 g
s
.40741 .30927 m .40449 .81306 L .44326 .81916 L p .707 .577 .707 r
F P
0 g
s
.29018 .60692 m .28346 .66421 L .31242 .66794 L p .707 .577 .707 r
F P
0 g
s
.31242 .66794 m .31914 .61065 L .29018 .60692 L p .707 .577 .707 r
F P
0 g
s
.19998 .59684 m .19327 .65413 L .22082 .65695 L p .707 .577 .707 r
F P
0 g
s
.22082 .65695 m .22754 .59966 L .19998 .59684 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31914 .61065 m .31242 .66794 L .33594 .67124 L p .707 .577 .707 r
F P
0 g
s
.33594 .67124 m .34266 .61396 L .31914 .61065 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .63367 .2959 L .61056 .30566 L p .707 .577 .707 r
F P
0 g
s
.17866 .59495 m .17194 .65224 L .19327 .65413 L p .707 .577 .707 r
F P
0 g
s
.19327 .65413 m .19998 .59684 L .17866 .59495 L p .707 .577 .707 r
F P
0 g
s
.69149 .65454 m .68478 .71183 L .66345 .70994 L p .707 .577 .707 r
F P
0 g
s
.70151 .78529 m .69994 .82317 L .6873 .81772 L p .707 .577 .707 r
F P
0 g
s
.6873 .81772 m .68887 .77983 L .70151 .78529 L p .707 .577 .707 r
F P
0 g
s
.66345 .70994 m .67017 .65265 L .69149 .65454 L p .707 .577 .707 r
F P
0 g
s
.70687 .75571 m .70765 .7736 L .69501 .76337 L p .707 .577 .707 r
F P
0 g
s
.69501 .76337 m .69423 .74548 L .70687 .75571 L p .707 .577 .707 r
F P
0 g
s
.25146 .80357 m .25303 .76569 L .22187 .76325 L p .707 .577 .707 r
F P
0 g
s
.25303 .76569 m .25146 .80357 L .28326 .80435 L p .707 .577 .707 r
F P
0 g
s
.28326 .80435 m .28483 .76647 L .25303 .76569 L p .707 .577 .707 r
F P
0 g
s
.37477 .80424 m .37769 .30045 L .35991 .28979 L p .707 .577 .707 r
F P
0 g
s
.37769 .30045 m .37477 .80424 L .40449 .81306 L p .707 .577 .707 r
F P
0 g
s
.28483 .76647 m .28326 .80435 L .3126 .8034 L p .707 .577 .707 r
F P
0 g
s
.3126 .8034 m .31416 .76551 L .28483 .76647 L p .707 .577 .707 r
F P
0 g
s
.34266 .61396 m .33594 .67124 L .35172 .67381 L p .707 .577 .707 r
F P
0 g
s
.22187 .76325 m .2203 .80113 L .25146 .80357 L p .707 .577 .707 r
F P
0 g
s
.2203 .80113 m .22187 .76325 L .1944 .75939 L p .707 .577 .707 r
F P
0 g
s
.35172 .67381 m .35844 .61652 L .34266 .61396 L p .707 .577 .707 r
F P
0 g
s
.1944 .75939 m .19283 .79728 L .2203 .80113 L p .707 .577 .707 r
F P
0 g
s
.16564 .59418 m .15893 .65146 L .17194 .65224 L p .707 .577 .707 r
F P
0 g
s
.17194 .65224 m .17866 .59495 L .16564 .59418 L p .707 .577 .707 r
F P
0 g
s
.25916 .78716 m .25838 .76927 L .22722 .76789 L p .707 .577 .707 r
F P
0 g
s
.25838 .76927 m .25916 .78716 L .29097 .78488 L p .707 .577 .707 r
F P
0 g
s
.29097 .78488 m .29019 .76699 L .25838 .76927 L p .707 .577 .707 r
F P
0 g
s
.31416 .76551 m .3126 .8034 L .33658 .8008 L p .707 .577 .707 r
F P
0 g
s
.33658 .8008 m .33815 .76292 L .31416 .76551 L p .707 .577 .707 r
F P
0 g
s
.29019 .76699 m .29097 .78488 L .3203 .77916 L p .707 .577 .707 r
F P
0 g
s
.3203 .77916 m .31952 .76127 L .29019 .76699 L p .707 .577 .707 r
F P
0 g
s
.228 .78578 m .22722 .76789 L .19975 .76298 L p .707 .577 .707 r
F P
0 g
s
.22722 .76789 m .228 .78578 L .25916 .78716 L p .707 .577 .707 r
F P
0 g
s
.19283 .79728 m .1944 .75939 L .17331 .7545 L p .707 .577 .707 r
F P
0 g
s
.68887 .77983 m .6873 .81772 L .66621 .81282 L p .707 .577 .707 r
F P
0 g
s
.66621 .81282 m .66778 .77494 L .68887 .77983 L p .707 .577 .707 r
F P
0 g
s
.69423 .74548 m .69501 .76337 L .67392 .75541 L p .707 .577 .707 r
F P
0 g
s
.67392 .75541 m .67314 .73752 L .69423 .74548 L p .707 .577 .707 r
F P
0 g
s
.33815 .76292 m .33658 .8008 L .35288 .79682 L p .707 .577 .707 r
F P
0 g
s
.35288 .79682 m .35445 .75894 L .33815 .76292 L p .707 .577 .707 r
F P
0 g
s
.31952 .76127 m .3203 .77916 L .34429 .77056 L p .707 .577 .707 r
F P
0 g
s
.34429 .77056 m .34351 .75266 L .31952 .76127 L p .707 .577 .707 r
F P
0 g
s
.19975 .76298 m .20053 .78087 L .228 .78578 L p .707 .577 .707 r
F P
0 g
s
.17331 .7545 m .17174 .79238 L .19283 .79728 L p .707 .577 .707 r
F P
0 g
s
.35844 .61652 m .35172 .67381 L .35821 .67537 L p .707 .577 .707 r
F P
0 g
s
.35821 .67537 m .36493 .61808 L .35844 .61652 L p .707 .577 .707 r
F P
0 g
s
.20053 .78087 m .19975 .76298 L .17866 .75502 L p .707 .577 .707 r
F P
0 g
s
.35445 .75894 m .35288 .79682 L .3556 .79489 L p .707 .577 .707 r
F P
0 g
s
.35605 .76859 m .35445 .75894 L .3556 .79489 L .707 .577 .707 r
F
.35615 .76281 m .36059 .75992 L p .35623 .75806 L F P
0 g
s
.36059 .75992 m .35981 .74202 L .35646 .74421 L p .707 .577 .707 r
F P
0 g
s
.36059 .75992 m .35646 .74421 L .35623 .75806 L .707 .577 .707 r
F
.35981 .74202 m .36059 .75992 L .3676 .74828 L p F P
0 g
s
.3599 .79184 m .36146 .75396 L .35623 .75768 L p .707 .577 .707 r
F P
0 g
s
.35623 .75768 m .35445 .75894 L p .35605 .76859 L .707 .577 .707 r
F P
0 g
s
.3599 .79184 m .35623 .75768 L .35605 .76859 L .707 .577 .707 r
F
.35646 .74421 m .34351 .75266 L p .35623 .75806 L F P
0 g
s
.34351 .75266 m .34429 .77056 L .35615 .76281 L p .707 .577 .707 r
F P
0 g
s
.35623 .75806 m .34351 .75266 L .35615 .76281 L .707 .577 .707 r
F
.3556 .79489 m .3599 .79184 L p .35605 .76859 L F P
0 g
s
.35821 .67537 m .35478 .67579 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36493 .61808 m .36387 .62713 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36387 .62713 m .35821 .67537 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35582 .27831 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .36493 .61808 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35478 .67579 m .36095 .62322 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36095 .62322 m .3615 .6185 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36146 .75396 m .3599 .79184 L .35693 .78636 L p .707 .577 .707 r
F P
0 g
s
.35693 .78636 m .3585 .74848 L .36146 .75396 L p .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .35478 .67579 L .34177 .67501 L p .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .34848 .61772 L .36069 .61845 L p .707 .577 .707 r
F P
0 g
s
.36069 .61845 m .3615 .6185 L p .3608 .6205 L .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .36069 .61845 L .3608 .6205 L .707 .577 .707 r
F
.358 .61927 m .35826 .5737 L p .35659 .61738 L F P
0 g
s
.35826 .5737 m .35991 .28979 L p .35722 .55455 L .707 .577 .707 r
F P
0 g
s
.35826 .5737 m .35722 .55455 L .35659 .61738 L .707 .577 .707 r
F
.3585 .74848 m .35693 .78636 L .34429 .7809 L p F P
0 g
s
.34429 .7809 m .34586 .74302 L .3585 .74848 L p .707 .577 .707 r
F P
0 g
s
.3676 .74828 m .36682 .73038 L .35981 .74202 L p .707 .577 .707 r
F P
0 g
s
.36386 .71889 m .36464 .73678 L .35786 .7313 L p .707 .577 .707 r
F P
0 g
s
.35786 .7313 m .352 .72656 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.35817 .72257 m .36386 .71889 L .35786 .7313 L .707 .577 .707 r
F
.352 .72656 m .35122 .70866 L .35846 .71452 L p F P
0 g
s
.35846 .71452 m .36386 .71889 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.352 .72656 m .35846 .71452 L .35817 .72257 L .707 .577 .707 r
F
.35691 .75809 m .358 .61927 L .35659 .61738 L F
.35699 .79358 m .35725 .74847 L p .35691 .75809 L F P
0 g
s
.35725 .74847 m .358 .61927 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35577 .79016 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.35577 .79016 m .35699 .79358 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.35691 .75809 m .35659 .61738 L .35577 .79016 L .707 .577 .707 r
F
.35582 .27831 m .35387 .61375 L p .35659 .61738 L F P
0 g
s
.35387 .61375 m .3529 .78211 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.36682 .73038 m .3676 .74828 L .36464 .73678 L p .707 .577 .707 r
F P
0 g
s
.36464 .73678 m .36386 .71889 L .36682 .73038 L p .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35699 .79358 L .37477 .80424 L p .707 .577 .707 r
F P
0 g
s
.16221 .59459 m .1555 .65188 L .15893 .65146 L p .707 .577 .707 r
F P
0 g
s
.15893 .65146 m .16564 .59418 L .16221 .59459 L p .707 .577 .707 r
F P
0 g
s
.17866 .75502 m .17944 .77291 L .20053 .78087 L p .707 .577 .707 r
F P
0 g
s
.17174 .79238 m .17331 .7545 L .16067 .74904 L p .707 .577 .707 r
F P
0 g
s
.66778 .77494 m .66621 .81282 L .63874 .80896 L p .707 .577 .707 r
F P
0 g
s
.67314 .73752 m .67392 .75541 L .64645 .7505 L p .707 .577 .707 r
F P
0 g
s
.64645 .7505 m .64567 .73261 L .67314 .73752 L p .707 .577 .707 r
F P
0 g
s
.16067 .74904 m .1591 .78692 L .17174 .79238 L p .707 .577 .707 r
F P
0 g
s
.17944 .77291 m .17866 .75502 L .16602 .74479 L p .707 .577 .707 r
F P
0 g
s
.16602 .74479 m .1668 .76268 L .17944 .77291 L p .707 .577 .707 r
F P
0 g
s
.64367 .28475 m .64075 .78854 L .63666 .77706 L p .707 .577 .707 r
F P
0 g
s
.63666 .77706 m .63958 .27327 L .64367 .28475 L p .707 .577 .707 r
F P
0 g
s
.1591 .78692 m .16067 .74904 L .15771 .74355 L p .707 .577 .707 r
F P
0 g
s
.1687 .59615 m .16199 .65344 L .1555 .65188 L p .707 .577 .707 r
F P
0 g
s
.1555 .65188 m .16221 .59459 L .1687 .59615 L p .707 .577 .707 r
F P
0 g
s
.15771 .74355 m .15614 .78143 L .1591 .78692 L p .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35582 .27831 L .36581 .26716 L p .707 .577 .707 r
F P
0 g
s
.1668 .76268 m .16602 .74479 L .16306 .7333 L p .707 .577 .707 r
F P
0 g
s
.16306 .7333 m .16384 .75119 L .1668 .76268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.18448 .59872 m .17777 .656 L .16199 .65344 L p .707 .577 .707 r
F P
0 g
s
.16199 .65344 m .1687 .59615 L .18448 .59872 L p .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16306 .7333 L .16863 .72405 L p .707 .577 .707 r
F P
0 g
s
.16863 .72405 m .17007 .72166 L p .1687 .72816 L .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16863 .72405 L .1687 .72816 L .707 .577 .707 r
F
.16886 .73756 m .18102 .73459 L p .16926 .76213 L F P
0 g
s
.17007 .72166 m .17085 .73955 L .16384 .75119 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16472 .73857 L .16886 .73756 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16886 .73756 L .16926 .76213 L .707 .577 .707 r
F
.15614 .78143 m .15771 .74355 L .16472 .73857 L p F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63958 .27327 m .63666 .77706 L .61888 .7664 L p .707 .577 .707 r
F P
0 g
s
.61888 .7664 m .6218 .26261 L .63958 .27327 L p .707 .577 .707 r
F P
0 g
s
.16472 .73857 m .16315 .77646 L .15614 .78143 L p .707 .577 .707 r
F P
0 g
s
.34848 .61772 m .34177 .67501 L .32044 .67312 L p .707 .577 .707 r
F P
0 g
s
.32044 .67312 m .32716 .61583 L .34848 .61772 L p .707 .577 .707 r
F P
0 g
s
.36289 .77095 m .36581 .26716 L .38892 .2574 L p .707 .577 .707 r
F P
0 g
s
.36581 .26716 m .36289 .77095 L .3529 .78211 L p .707 .577 .707 r
F P
0 g
s
.208 .60202 m .20129 .65931 L .17777 .656 L p .707 .577 .707 r
F P
0 g
s
.17777 .656 m .18448 .59872 L .208 .60202 L p .707 .577 .707 r
F P
0 g
s
.18102 .73459 m .17945 .77248 L .16315 .77646 L p .707 .577 .707 r
F P
0 g
s
.17085 .73955 m .17007 .72166 L .18637 .71102 L p .707 .577 .707 r
F P
0 g
s
.32716 .61583 m .32044 .67312 L .29289 .6703 L p .707 .577 .707 r
F P
0 g
s
.29289 .6703 m .2996 .61301 L .32716 .61583 L p .707 .577 .707 r
F P
0 g
s
.6218 .26261 m .61888 .7664 L .58915 .75758 L p .707 .577 .707 r
F P
0 g
s
.58915 .75758 m .59207 .25379 L .6218 .26261 L p .707 .577 .707 r
F P
0 g
s
.18637 .71102 m .18715 .72891 L .17085 .73955 L p .707 .577 .707 r
F P
0 g
s
.34586 .74302 m .34429 .7809 L .3232 .776 L p .707 .577 .707 r
F P
0 g
s
.3232 .776 m .32477 .73812 L .34586 .74302 L p .707 .577 .707 r
F P
0 g
s
.23696 .60575 m .23025 .66304 L .20129 .65931 L p .707 .577 .707 r
F P
0 g
s
.20129 .65931 m .208 .60202 L .23696 .60575 L p .707 .577 .707 r
F P
0 g
s
.35122 .70866 m .352 .72656 L .33091 .7186 L p .707 .577 .707 r
F P
0 g
s
.33091 .7186 m .33013 .7007 L .35122 .70866 L p .707 .577 .707 r
F P
0 g
s
.17945 .77248 m .18102 .73459 L .20501 .732 L p .707 .577 .707 r
F P
0 g
s
.2996 .61301 m .29289 .6703 L .26181 .66683 L p .707 .577 .707 r
F P
0 g
s
.38892 .2574 m .386 .76119 L .36289 .77095 L p .707 .577 .707 r
F P
0 g
s
.386 .76119 m .38892 .2574 L .42288 .25001 L p .707 .577 .707 r
F P
0 g
s
.26181 .66683 m .26853 .60954 L .2996 .61301 L p .707 .577 .707 r
F P
0 g
s
.26853 .60954 m .26181 .66683 L .23025 .66304 L p .707 .577 .707 r
F P
0 g
s
.23025 .66304 m .23696 .60575 L .26853 .60954 L p .707 .577 .707 r
F P
0 g
s
.20501 .732 m .20344 .76988 L .17945 .77248 L p .707 .577 .707 r
F P
0 g
s
.18715 .72891 m .18637 .71102 L .21036 .70241 L p .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .70367 .6467 L p .70346 .64629 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70103 .6464 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67581 .64382 L p .67568 .64346 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67348 .64358 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65404 .64186 L p .65396 .64143 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65215 .64169 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64016 .64098 L p .64016 .64045 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63914 .64092 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .63965 .63213 L .63588 .64094 L .707 .577 .707 r
F
.63584 .64132 m .63914 .64092 L p .63588 .64094 L F P
0 g
s
.63865 .6313 m .64012 .63252 L .63792 .60871 L .707 .577 .707 r
F
.64012 .63252 m .64088 .6142 L .64003 .61262 L p F P
0 g
s
.64003 .61262 m .63792 .60871 L p .64012 .63252 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63571 .64133 L p .63965 .63213 L .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63931 .65208 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63792 .60871 m .63704 .62997 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63635 .6466 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63965 .63213 m .64004 .6254 L .63871 .63135 L .707 .577 .707 r
F
.64004 .6254 m .64243 .58405 L .63871 .63135 L F
.64243 .58405 m .63704 .62997 L p .63871 .63135 L F P
0 g
s
.64593 .63394 m .65286 .63565 L .64088 .6142 L .707 .577 .707 r
F
.65286 .63565 m .65352 .61966 L .64951 .61793 L p F P
0 g
s
.64951 .61793 m .64088 .6142 L p .65286 .63565 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65146 .6353 L .64016 .64045 L .707 .577 .707 r
F
.64016 .64098 m .65215 .64169 L p .64016 .64045 L F P
0 g
s
.63931 .65208 m .65196 .65754 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64088 .6142 m .64012 .63252 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63931 .65208 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64243 .58405 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64012 .63252 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .64585 .58363 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64012 .63252 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.66145 .63703 m .67401 .63905 L .65352 .61966 L .707 .577 .707 r
F
.66798 .62302 m .65352 .61966 L p .67401 .63905 L F P
0 g
s
.65352 .61966 m .65286 .63565 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65887 .58441 m .64585 .58363 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65286 .63565 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65887 .58441 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67229 .63877 L .65396 .64143 L .707 .577 .707 r
F
.65404 .64186 m .67348 .64358 L p .65396 .64143 L F P
0 g
s
.65196 .65754 m .67304 .66244 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65196 .65754 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.63913 .62945 m .64727 .59299 L .64392 .62825 L .707 .577 .707 r
F
.67401 .63905 m .67461 .62456 L .66798 .62302 L p F P
0 g
s
.65887 .58441 m .65286 .63565 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.64628 .60341 m .66123 .59976 L p .64392 .62825 L .707 .577 .707 r
F P
0 g
s
.64892 .58561 m .64392 .62825 L p .64727 .59299 L .707 .577 .707 r
F P
0 g
s
.65196 .65754 m .65286 .63565 L p .64593 .63394 L .707 .577 .707 r
F P
0 g
s
.63931 .65208 m .64012 .63252 L p .63865 .6313 L .707 .577 .707 r
F P
0 g
s
.64493 .60374 m .64392 .62825 L p .63635 .6466 L .707 .577 .707 r
F P
0 g
s
.64313 .64065 m .6483 .62806 L .64297 .64302 L .707 .577 .707 r
F
.64305 .64185 m .63635 .6466 L p .64392 .62825 L F P
0 g
s
.64917 .62802 m .64392 .62825 L .66123 .59976 L .707 .577 .707 r
F
.68439 .64031 m .7015 .64239 L .67461 .62456 L F
.69392 .62727 m .67461 .62456 L p .7015 .64239 L F P
0 g
s
.67461 .62456 m .67401 .63905 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .65887 .58441 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67401 .63905 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .6802 .5863 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .69956 .64215 L .67568 .64346 L .707 .577 .707 r
F
.67581 .64382 m .70103 .6464 L p .67568 .64346 L F P
0 g
s
.67304 .66244 m .70051 .6663 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67304 .66244 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6422 .6429 m .64892 .58561 L .6647 .58817 L p .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64336 .64162 L .64305 .64185 L p .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .64297 .64302 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64297 .64302 m .6422 .6429 L p .64313 .64065 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .65798 .64546 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .66008 .62753 L p .64336 .64162 L .707 .577 .707 r
F P
0 g
s
.67304 .66244 m .67401 .63905 L p .66145 .63703 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70208 .62841 L .69392 .62727 L p .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .67401 .63905 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .70208 .62841 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70208 .62841 m .7015 .64239 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .6802 .5863 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .7015 .64239 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70775 .58912 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .7302 .64511 L .70346 .64629 L .707 .577 .707 r
F
.70367 .6467 m .73211 .64988 L p .70346 .64629 L F P
0 g
s
.70051 .6663 m .73167 .66873 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70051 .6663 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .68522 .59716 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .66123 .59976 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .66008 .62753 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .65798 .64546 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .6815 .64877 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.70051 .6663 m .7015 .64239 L p .68439 .64031 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73324 .63085 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .7015 .64239 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .73264 .64534 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .73324 .63085 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .76368 .65366 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73211 .64988 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76505 .63163 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .76438 .64762 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .76505 .63163 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .79263 .65739 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76368 .65366 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79438 .63068 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .79362 .64899 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .79438 .63068 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .81615 .6607 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79263 .65739 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81837 .62808 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .81749 .64934 L p .82064 .6333 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .81837 .62808 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .83193 .66326 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81615 .6607 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83467 .6241 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .83365 .64862 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83865 .60597 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.83524 .62369 m .83467 .6241 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83537 .62174 L .82974 .64879 L .707 .577 .707 r
F
.83865 .60597 m .83365 .64862 L p .83849 .64741 L F P
0 g
s
.8331 .66199 m .8394 .65751 L p .83852 .6474 L .707 .577 .707 r
F P
0 g
s
.83971 .6546 m .83852 .6474 L .8394 .65751 L .707 .577 .707 r
F
.83849 .64741 m .84141 .62989 L .83865 .60597 L F
.84514 .60754 m .84261 .60693 L p .84141 .62989 L F P
0 g
s
.84261 .60693 m .83865 .60597 L p .84141 .62989 L .707 .577 .707 r
F P
0 g
s
.84053 .6469 m .84514 .60754 L p .83849 .64741 L .707 .577 .707 r
F P
0 g
s
.83852 .6474 m .83809 .6448 L .8377 .6476 L .707 .577 .707 r
F
.83809 .6448 m .83506 .62651 L .8377 .6476 L F
.8377 .6476 m .83506 .62651 L .83384 .64857 L F
.83852 .6474 m .83384 .64857 L .8331 .66199 L F
.84011 .65701 m .84053 .6469 L p .8387 .64735 L F P
0 g
s
.83971 .6546 m .83524 .62369 L .83506 .62651 L .707 .577 .707 r
F
.84011 .65701 m .83973 .65441 L .83971 .6546 L F
.83973 .65441 m .83524 .62369 L .83971 .6546 L F
.84168 .61913 m .83524 .62369 L p .8387 .64735 L F P
0 g
s
.84053 .6469 m .84168 .61913 L p .8387 .64735 L .707 .577 .707 r
F P
0 g
s
.84168 .61913 m .84053 .6469 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .8331 .66199 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83236 .66216 m .8331 .66199 L p .83251 .66063 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83193 .66326 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.83193 .66326 m .83365 .64862 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .83365 .64862 L .82741 .6489 L .707 .577 .707 r
F
.8331 .66199 m .83365 .64862 L p .83251 .66063 L F P
0 g
s
.83849 .64741 m .83365 .64862 L .83236 .66224 L .707 .577 .707 r
F
.83843 .66483 m .83849 .64741 L .83236 .66224 L F
.83193 .66326 m .83225 .66334 L p .83236 .66224 L F P
0 g
s
.83225 .66334 m .83843 .66483 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .83236 .66216 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .82741 .6489 L .83236 .66216 L .707 .577 .707 r
F
.83872 .61364 m .84168 .61913 L p .83808 .64487 L F P
0 g
s
.835 .66524 m .83745 .64435 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .83745 .64435 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83872 .61364 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .8447 .60759 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .84171 .60795 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.8447 .60759 m .84514 .60754 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .8447 .60759 L .84404 .6138 L .707 .577 .707 r
F
.83843 .66483 m .84053 .6469 L p .83849 .64741 L F P
0 g
s
.83843 .66483 m .835 .66524 L p .83851 .64523 L .707 .577 .707 r
F P
0 g
s
.83851 .64523 m .84404 .6138 L .84041 .6468 L .707 .577 .707 r
F
.83851 .64523 m .84041 .6468 L .83843 .66483 L F
.84053 .6469 m .83843 .66483 L p .84404 .6138 L F P
0 g
s
.83715 .65152 m .83808 .64487 L .84053 .6469 L .707 .577 .707 r
F
.84053 .6469 m .84011 .65701 L .84001 .65683 L p F P
0 g
s
.8394 .65751 m .84011 .65701 L p .83971 .6546 L .707 .577 .707 r
F P
0 g
s
.84001 .65683 m .83715 .65152 L p .84053 .6469 L .707 .577 .707 r
F P
0 g
s
.84514 .60754 m .84053 .6469 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.82974 .64879 m .83537 .62174 L .82287 .60341 L .707 .577 .707 r
F
.83865 .60597 m .8364 .60561 L p .83537 .62174 L F P
0 g
s
.8364 .60561 m .82287 .60341 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.82741 .6489 m .82064 .6333 L .81876 .64928 L .707 .577 .707 r
F
.82741 .6489 m .81876 .64928 L .8168 .66597 L F
.81749 .64934 m .8168 .66597 L p .82064 .6333 L F P
0 g
s
.82287 .60341 m .81749 .64934 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.82287 .60341 m .79935 .60011 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .81749 .64934 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .82287 .60341 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .81749 .64934 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .8168 .66597 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79281 .66856 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .79362 .64899 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .77039 .59638 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .79362 .64899 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79935 .60011 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .79362 .64899 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .79281 .66856 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76348 .66951 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .76438 .64762 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .73883 .59259 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .76438 .64762 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .77039 .59638 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .76438 .64762 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .76348 .66951 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73167 .66873 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .73264 .64534 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .70775 .58912 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .73264 .64534 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73883 .59259 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .71455 .59621 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .68395 .62787 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68395 .62787 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68522 .59716 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .6815 .64877 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71046 .6525 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .73264 .64534 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.74636 .59699 m .77752 .59943 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .80499 .60328 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .77607 .63448 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .77607 .63448 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77752 .59943 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .82607 .60818 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .80356 .63782 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .80356 .63782 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80499 .60328 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .83872 .61364 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .82471 .64122 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .82471 .64122 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82607 .60818 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .82198 .66447 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .835 .66524 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .82451 .64606 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83872 .61364 m .83745 .64435 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83715 .65152 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .83745 .64435 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .84171 .60795 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .8287 .60718 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .80065 .66258 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82198 .66447 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .80342 .64117 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .82471 .64122 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82451 .64606 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .82471 .64122 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .8287 .60718 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80737 .60529 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .7731 .65976 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80065 .66258 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .77595 .63731 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .80356 .63782 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80342 .64117 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .80356 .63782 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .80737 .60529 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77982 .60247 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.74202 .65628 m .74493 .63153 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .74202 .65628 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .7731 .65976 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .74479 .63487 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .77607 .63448 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77595 .63731 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .77607 .63448 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74874 .599 m .77982 .60247 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74601 .63163 m .74636 .59699 L .74764 .63179 L .707 .577 .707 r
F
.74493 .63153 m .74636 .59699 L p .74599 .63357 L F P
0 g
s
.74493 .63153 m .74874 .599 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74599 .63357 m .74601 .63163 L .74764 .63179 L .707 .577 .707 r
F
.74479 .63487 m .74493 .63153 L p .74599 .63357 L F P
0 g
s
.71455 .59621 m .74636 .59699 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .71318 .62925 L p .72349 .62999 L .707 .577 .707 r
F P
0 g
s
.71298 .63409 m .71318 .62925 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71455 .59621 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .72349 .62999 L .72641 .6302 L .707 .577 .707 r
F
.74636 .59699 m .74493 .63153 L p .71709 .62953 L F P
0 g
s
.74874 .599 m .74202 .65628 L .71046 .6525 L p .707 .577 .707 r
F P
0 g
s
.74479 .63487 m .71298 .63409 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.74493 .63153 m .74479 .63487 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.72641 .6302 m .73436 .61123 L .73673 .61578 L .707 .577 .707 r
F
.72349 .62999 m .73436 .61123 L .72641 .6302 L F
.72349 .62999 m .71318 .62925 L .73436 .61123 L F
.73673 .61578 m .73436 .61123 L .74874 .599 L F
.71318 .62925 m .71718 .59521 L .73288 .59709 L p F P
0 g
s
.73288 .59709 m .74874 .599 L p .71318 .62925 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68916 .62812 L .71059 .63349 L .707 .577 .707 r
F
.71298 .63409 m .71016 .63419 L p .71059 .63349 L F P
0 g
s
.71016 .63419 m .68365 .63505 L p .71059 .63349 L .707 .577 .707 r
F P
0 g
s
.71455 .59621 m .71318 .62925 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71298 .63409 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71718 .59521 m .71318 .62925 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.69507 .6284 m .68395 .62787 L .71718 .59521 L .707 .577 .707 r
F
.68395 .62787 m .68822 .59148 L .6981 .59275 L p F P
0 g
s
.6981 .59275 m .71718 .59521 L p .68395 .62787 L .707 .577 .707 r
F P
0 g
s
.65966 .63764 m .66599 .62761 L .68143 .63411 L .707 .577 .707 r
F
.68365 .63505 m .68094 .63534 L p .68143 .63411 L F P
0 g
s
.68094 .63534 m .65966 .63764 L p .68143 .63411 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .68395 .62787 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68365 .63505 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68822 .59148 m .68395 .62787 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.66796 .62764 m .66008 .62753 L .68822 .59148 L .707 .577 .707 r
F
.65966 .63764 m .66008 .62753 L p .66599 .62761 L F P
0 g
s
.66008 .62753 m .65966 .63764 L .65802 .63804 L p .707 .577 .707 r
F P
0 g
s
.65802 .63804 m .64336 .64162 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .6647 .58817 L .66773 .5886 L p .707 .577 .707 r
F P
0 g
s
.66773 .5886 m .68822 .59148 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.6647 .58817 m .66008 .62753 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64336 .64162 m .64392 .62825 L p .64917 .62802 L .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64493 .60374 L .64628 .60341 L p .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63704 .62997 L p .63982 .62928 L .707 .577 .707 r
F P
0 g
s
.63666 .63733 m .64892 .58561 L .63644 .64151 L .707 .577 .707 r
F
.63571 .64133 m .64243 .58405 L .64892 .58561 L p F P
0 g
s
.63982 .62928 m .63704 .62997 L .64493 .60374 L .707 .577 .707 r
F
.6422 .6429 m .63644 .64151 L p .63913 .62945 L F P
0 g
s
.64392 .62825 m .6422 .6429 L p .63913 .62945 L .707 .577 .707 r
F P
0 g
s
.63571 .64133 m .63584 .64132 L p .63588 .64094 L .707 .577 .707 r
F P
0 g
s
.63644 .64151 m .63571 .64133 L p .63666 .63733 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63792 .60871 L .63941 .60766 L p .707 .577 .707 r
F P
0 g
s
.63941 .60766 m .64493 .60374 L p .63704 .62997 L .707 .577 .707 r
F P
0 g
s
.32477 .73812 m .3232 .776 L .29573 .77215 L p .707 .577 .707 r
F P
0 g
s
.29573 .77215 m .2973 .73426 L .32477 .73812 L p .707 .577 .707 r
F P
0 g
s
.21036 .70241 m .21114 .72031 L .18715 .72891 L p .707 .577 .707 r
F P
0 g
s
.33013 .7007 m .33091 .7186 L .30344 .71369 L p .707 .577 .707 r
F P
0 g
s
.30344 .71369 m .30266 .69579 L .33013 .7007 L p .707 .577 .707 r
F P
0 g
s
.59207 .25379 m .58915 .75758 L .55039 .75149 L p .707 .577 .707 r
F P
0 g
s
.55039 .75149 m .55331 .24769 L .59207 .25379 L p .707 .577 .707 r
F P
0 g
s
.20344 .76988 m .20501 .732 L .23434 .73105 L p .707 .577 .707 r
F P
0 g
s
.21114 .72031 m .21036 .70241 L .2397 .69669 L p .707 .577 .707 r
F P
0 g
s
.23434 .73105 m .23277 .76893 L .20344 .76988 L p .707 .577 .707 r
F P
0 g
s
.2973 .73426 m .29573 .77215 L .26457 .76971 L p .707 .577 .707 r
F P
0 g
s
.26457 .76971 m .26614 .73183 L .2973 .73426 L p .707 .577 .707 r
F P
0 g
s
.41996 .7538 m .42288 .25001 L .46436 .24571 L p .707 .577 .707 r
F P
0 g
s
.42288 .25001 m .41996 .7538 L .386 .76119 L p .707 .577 .707 r
F P
0 g
s
.30266 .69579 m .30344 .71369 L .27228 .7123 L p .707 .577 .707 r
F P
0 g
s
.27228 .7123 m .2715 .69441 L .30266 .69579 L p .707 .577 .707 r
F P
0 g
s
.2397 .69669 m .24047 .71459 L .21114 .72031 L p .707 .577 .707 r
F P
0 g
s
.23277 .76893 m .23434 .73105 L .26614 .73183 L p .707 .577 .707 r
F P
0 g
s
.26614 .73183 m .26457 .76971 L .23277 .76893 L p .707 .577 .707 r
F P
0 g
s
.24047 .71459 m .2397 .69669 L .2715 .69441 L p .707 .577 .707 r
F P
0 g
s
.2715 .69441 m .27228 .7123 L .24047 .71459 L p .707 .577 .707 r
F P
0 g
s
.55331 .24769 m .55039 .75149 L .50638 .7487 L p .707 .577 .707 r
F P
0 g
s
.50638 .7487 m .5093 .24491 L .55331 .24769 L p .707 .577 .707 r
F P
0 g
s
.46144 .7495 m .46436 .24571 L .5093 .24491 L p .707 .577 .707 r
F P
0 g
s
.46436 .24571 m .46144 .7495 L .41996 .7538 L p .707 .577 .707 r
F P
0 g
s
.5093 .24491 m .50638 .7487 L .46144 .7495 L p .707 .577 .707 r
F P
0 g
s
.73938 .79959 m .7386 .78169 L .70743 .78031 L p .707 .577 .707 r
F P
0 g
s
.7386 .78169 m .73938 .79959 L .77118 .79731 L p .707 .577 .707 r
F P
0 g
s
.77118 .79731 m .7704 .77941 L .7386 .78169 L p .707 .577 .707 r
F P
0 g
s
.7704 .77941 m .77118 .79731 L .80051 .79158 L p .707 .577 .707 r
F P
0 g
s
.80051 .79158 m .79973 .77369 L .7704 .77941 L p .707 .577 .707 r
F P
0 g
s
.70821 .7982 m .70743 .78031 L .67997 .7754 L p .707 .577 .707 r
F P
0 g
s
.70743 .78031 m .70821 .7982 L .73938 .79959 L p .707 .577 .707 r
F P
0 g
s
.79973 .77369 m .80051 .79158 L .8245 .78298 L p .707 .577 .707 r
F P
0 g
s
.8245 .78298 m .82372 .76509 L .79973 .77369 L p .707 .577 .707 r
F P
0 g
s
.67997 .7754 m .68074 .79329 L .70821 .7982 L p .707 .577 .707 r
F P
0 g
s
.68074 .79329 m .67997 .7754 L .65888 .76744 L p .707 .577 .707 r
F P
0 g
s
.65888 .76744 m .65966 .78534 L .68074 .79329 L p .707 .577 .707 r
F P
0 g
s
.82372 .76509 m .8245 .78298 L .8408 .77234 L p .707 .577 .707 r
F P
0 g
s
.8408 .77234 m .84002 .75445 L .82372 .76509 L p .707 .577 .707 r
F P
0 g
s
.65966 .78534 m .65888 .76744 L .64623 .75721 L p .707 .577 .707 r
F P
0 g
s
.64623 .75721 m .64701 .77511 L .65966 .78534 L p .707 .577 .707 r
F P
0 g
s
.84002 .75445 m .8408 .77234 L .84781 .7607 L p .707 .577 .707 r
F P
0 g
s
.84781 .7607 m .84703 .74281 L .84002 .75445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64701 .77511 m .64623 .75721 L .64328 .74572 L p .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .36066 .60988 L p .36046 .60948 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35802 .60959 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .3328 .60701 L p .33267 .60665 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33047 .60677 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .31103 .60504 L p .31095 .60462 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30914 .60488 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29715 .60416 L p .29715 .60364 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .29613 .6041 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29664 .59531 L .29287 .60412 L .707 .577 .707 r
F
.29283 .6045 m .29613 .6041 L p .29287 .60412 L F P
0 g
s
.29564 .59448 m .29711 .5957 L .29491 .5719 L .707 .577 .707 r
F
.29711 .5957 m .29787 .57739 L .29702 .5758 L p F P
0 g
s
.29702 .5758 m .29491 .5719 L p .29711 .5957 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .2927 .60452 L p .29664 .59531 L .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .2963 .61527 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29491 .5719 m .29403 .59316 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29334 .60978 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29664 .59531 m .29702 .58858 L .2957 .59453 L .707 .577 .707 r
F
.29702 .58858 m .29941 .54723 L .2957 .59453 L F
.29941 .54723 m .29403 .59316 L p .2957 .59453 L F P
0 g
s
.30292 .59713 m .30985 .59883 L .29787 .57739 L .707 .577 .707 r
F
.30985 .59883 m .31051 .58284 L .3065 .58111 L p F P
0 g
s
.3065 .58111 m .29787 .57739 L p .30985 .59883 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30845 .59849 L .29715 .60364 L .707 .577 .707 r
F
.29715 .60416 m .30914 .60488 L p .29715 .60364 L F P
0 g
s
.2963 .61527 m .30895 .62073 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29787 .57739 m .29711 .5957 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .2963 .61527 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29941 .54723 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29711 .5957 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .30284 .54681 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29711 .5957 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.31844 .60021 m .331 .60223 L .31051 .58284 L .707 .577 .707 r
F
.32497 .5862 m .31051 .58284 L p .331 .60223 L F P
0 g
s
.31051 .58284 m .30985 .59883 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.31586 .54759 m .30284 .54681 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30985 .59883 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .31586 .54759 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .32928 .60195 L .31095 .60462 L .707 .577 .707 r
F
.31103 .60504 m .33047 .60677 L p .31095 .60462 L F P
0 g
s
.30895 .62073 m .33003 .62562 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30895 .62073 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.29612 .59263 m .30426 .55618 L .30091 .59144 L .707 .577 .707 r
F
.331 .60223 m .3316 .58774 L .32497 .5862 L p F P
0 g
s
.31586 .54759 m .30985 .59883 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.30327 .56659 m .31822 .56294 L p .30091 .59144 L .707 .577 .707 r
F P
0 g
s
.30591 .54879 m .30091 .59144 L p .30426 .55618 L .707 .577 .707 r
F P
0 g
s
.30895 .62073 m .30985 .59883 L p .30292 .59713 L .707 .577 .707 r
F P
0 g
s
.2963 .61527 m .29711 .5957 L p .29564 .59448 L .707 .577 .707 r
F P
0 g
s
.30192 .56692 m .30091 .59144 L p .29334 .60978 L .707 .577 .707 r
F P
0 g
s
.30011 .60383 m .30529 .59124 L .29996 .60621 L .707 .577 .707 r
F
.30004 .60503 m .29334 .60978 L p .30091 .59144 L F P
0 g
s
.30616 .5912 m .30091 .59144 L .31822 .56294 L .707 .577 .707 r
F
.34138 .60349 m .35849 .60557 L .3316 .58774 L F
.35091 .59045 m .3316 .58774 L p .35849 .60557 L F P
0 g
s
.3316 .58774 m .331 .60223 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .31586 .54759 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .331 .60223 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33719 .54948 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35655 .60533 L .33267 .60665 L .707 .577 .707 r
F
.3328 .60701 m .35802 .60959 L p .33267 .60665 L F P
0 g
s
.33003 .62562 m .3575 .62948 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33003 .62562 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.29919 .60608 m .30591 .54879 L .32169 .55136 L p .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30035 .60481 L .30004 .60503 L p .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .29996 .60621 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.29996 .60621 m .29919 .60608 L p .30011 .60383 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31497 .60864 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .31707 .59071 L p .30035 .60481 L .707 .577 .707 r
F P
0 g
s
.33003 .62562 m .331 .60223 L p .31844 .60021 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35907 .5916 L .35091 .59045 L p .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .331 .60223 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .35907 .5916 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.35907 .5916 m .35849 .60557 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .33719 .54948 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35849 .60557 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .36474 .5523 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38719 .60829 L .36046 .60948 L .707 .577 .707 r
F
.36066 .60988 m .3891 .61306 L p .36046 .60948 L F P
0 g
s
.3575 .62948 m .38866 .63192 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .3575 .62948 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .34221 .56035 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31822 .56294 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .31707 .59071 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .31497 .60864 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .33849 .61195 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.3575 .62948 m .35849 .60557 L p .34138 .60349 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39023 .59403 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .35849 .60557 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .38963 .60852 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .39023 .59403 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .42067 .61685 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .3891 .61306 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42204 .59481 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .42137 .6108 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .42204 .59481 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .44963 .62058 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42067 .61685 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45137 .59386 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .45061 .61218 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .45137 .59386 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .47315 .62388 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .44963 .62058 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47536 .59127 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .47448 .61252 L p .47763 .59649 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .47536 .59127 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .48892 .62645 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47315 .62388 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49166 .58729 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .49064 .6118 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49564 .56916 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.49223 .58688 m .49166 .58729 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49236 .58493 L .48673 .61198 L .707 .577 .707 r
F
.49564 .56916 m .49064 .6118 L p .49548 .61059 L F P
0 g
s
.49009 .62517 m .49639 .6207 L p .49551 .61058 L .707 .577 .707 r
F P
0 g
s
.4967 .61778 m .49551 .61058 L .49639 .6207 L .707 .577 .707 r
F
.49548 .61059 m .4984 .59307 L .49564 .56916 L F
.50213 .57072 m .4996 .57011 L p .4984 .59307 L F P
0 g
s
.4996 .57011 m .49564 .56916 L p .4984 .59307 L .707 .577 .707 r
F P
0 g
s
.49752 .61008 m .50213 .57072 L p .49548 .61059 L .707 .577 .707 r
F P
0 g
s
.49551 .61058 m .49508 .60798 L .49469 .61079 L .707 .577 .707 r
F
.49508 .60798 m .49205 .5897 L .49469 .61079 L F
.49469 .61079 m .49205 .5897 L .49083 .61175 L F
.49551 .61058 m .49083 .61175 L .49009 .62517 L F
.4971 .62019 m .49752 .61008 L p .49569 .61054 L F P
0 g
s
.4967 .61778 m .49223 .58688 L .49205 .5897 L .707 .577 .707 r
F
.4971 .62019 m .49672 .6176 L .4967 .61778 L F
.49672 .6176 m .49223 .58688 L .4967 .61778 L F
.49867 .58231 m .49223 .58688 L p .49569 .61054 L F P
0 g
s
.49752 .61008 m .49867 .58231 L p .49569 .61054 L .707 .577 .707 r
F P
0 g
s
.49867 .58231 m .49752 .61008 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49009 .62517 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.48935 .62535 m .49009 .62517 L p .4895 .62382 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .48892 .62645 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.48892 .62645 m .49064 .6118 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .49064 .6118 L .4844 .61208 L .707 .577 .707 r
F
.49009 .62517 m .49064 .6118 L p .4895 .62382 L F P
0 g
s
.49548 .61059 m .49064 .6118 L .48935 .62543 L .707 .577 .707 r
F
.49542 .62801 m .49548 .61059 L .48935 .62543 L F
.48892 .62645 m .48924 .62652 L p .48935 .62543 L F P
0 g
s
.48924 .62652 m .49542 .62801 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .48935 .62535 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .4844 .61208 L .48935 .62535 L .707 .577 .707 r
F
.49571 .57682 m .49867 .58231 L p .49507 .60806 L F P
0 g
s
.49199 .62843 m .49444 .60753 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .49444 .60753 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49571 .57682 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .50169 .57078 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .4987 .57114 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.50169 .57078 m .50213 .57072 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .50169 .57078 L .50103 .57698 L .707 .577 .707 r
F
.49542 .62801 m .49752 .61008 L p .49548 .61059 L F P
0 g
s
.49542 .62801 m .49199 .62843 L p .4955 .60842 L .707 .577 .707 r
F P
0 g
s
.4955 .60842 m .50103 .57698 L .4974 .60998 L .707 .577 .707 r
F
.4955 .60842 m .4974 .60998 L .49542 .62801 L F
.49752 .61008 m .49542 .62801 L p .50103 .57698 L F P
0 g
s
.49414 .61471 m .49507 .60806 L .49752 .61008 L .707 .577 .707 r
F
.49752 .61008 m .4971 .62019 L .497 .62001 L p F P
0 g
s
.49639 .6207 m .4971 .62019 L p .4967 .61778 L .707 .577 .707 r
F P
0 g
s
.497 .62001 m .49414 .61471 L p .49752 .61008 L .707 .577 .707 r
F P
0 g
s
.50213 .57072 m .49752 .61008 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.48673 .61198 m .49236 .58493 L .47986 .5666 L .707 .577 .707 r
F
.49564 .56916 m .49339 .56879 L p .49236 .58493 L F P
0 g
s
.49339 .56879 m .47986 .5666 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.4844 .61208 m .47763 .59649 L .47575 .61247 L .707 .577 .707 r
F
.4844 .61208 m .47575 .61247 L .47379 .62915 L F
.47448 .61252 m .47379 .62915 L p .47763 .59649 L F P
0 g
s
.47986 .5666 m .47448 .61252 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47986 .5666 m .45634 .56329 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .47448 .61252 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47986 .5666 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .47448 .61252 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .47379 .62915 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .4498 .63174 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .45061 .61218 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .42738 .55956 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .45061 .61218 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45634 .56329 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .45061 .61218 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .4498 .63174 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42047 .6327 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .42137 .6108 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .39582 .55577 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .42137 .6108 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42738 .55956 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .42137 .6108 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .42047 .6327 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .38866 .63192 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .38963 .60852 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .36474 .5523 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38963 .60852 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39582 .55577 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .37154 .55939 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .34094 .59106 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34094 .59106 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34221 .56035 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .33849 .61195 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36745 .61568 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .38963 .60852 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.40334 .56017 m .43451 .56261 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .46198 .56647 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .43305 .59767 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .43305 .59767 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43451 .56261 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .48306 .57136 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .46055 .60101 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .46055 .60101 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46198 .56647 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .49571 .57682 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .4817 .60441 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .4817 .60441 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48306 .57136 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .47897 .62765 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49199 .62843 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .4815 .60925 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49571 .57682 m .49444 .60753 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49414 .61471 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .49444 .60753 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4987 .57114 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48569 .57036 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .45764 .62576 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .47897 .62765 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .46041 .60435 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .4817 .60441 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .4815 .60925 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4817 .60441 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .48569 .57036 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46436 .56847 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .43009 .62294 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .45764 .62576 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .43294 .60049 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .46055 .60101 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46041 .60435 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .46055 .60101 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .46436 .56847 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43681 .56565 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.39901 .61947 m .40191 .59471 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .39901 .61947 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43009 .62294 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .40178 .59806 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .43305 .59767 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43294 .60049 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .43305 .59767 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40573 .56218 m .43681 .56565 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.403 .59482 m .40334 .56017 L .40463 .59497 L .707 .577 .707 r
F
.40191 .59471 m .40334 .56017 L p .40298 .59676 L F P
0 g
s
.40191 .59471 m .40573 .56218 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40298 .59676 m .403 .59482 L .40463 .59497 L .707 .577 .707 r
F
.40178 .59806 m .40191 .59471 L p .40298 .59676 L F P
0 g
s
.37154 .55939 m .40334 .56017 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .37017 .59244 L p .38048 .59318 L .707 .577 .707 r
F P
0 g
s
.36997 .59728 m .37017 .59244 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .37154 .55939 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .38048 .59318 L .3834 .59339 L .707 .577 .707 r
F
.40334 .56017 m .40191 .59471 L p .37408 .59272 L F P
0 g
s
.40573 .56218 m .39901 .61947 L .36745 .61568 L p .707 .577 .707 r
F P
0 g
s
.40178 .59806 m .36997 .59728 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.40191 .59471 m .40178 .59806 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.3834 .59339 m .39135 .57442 L .39372 .57897 L .707 .577 .707 r
F
.38048 .59318 m .39135 .57442 L .3834 .59339 L F
.38048 .59318 m .37017 .59244 L .39135 .57442 L F
.39372 .57897 m .39135 .57442 L .40573 .56218 L F
.37017 .59244 m .37416 .55839 L .38987 .56028 L p F P
0 g
s
.38987 .56028 m .40573 .56218 L p .37017 .59244 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34615 .5913 L .36758 .59668 L .707 .577 .707 r
F
.36997 .59728 m .36715 .59737 L p .36758 .59668 L F P
0 g
s
.36715 .59737 m .34064 .59823 L p .36758 .59668 L .707 .577 .707 r
F P
0 g
s
.37154 .55939 m .37017 .59244 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36997 .59728 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37416 .55839 m .37017 .59244 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.35206 .59158 m .34094 .59106 L .37416 .55839 L .707 .577 .707 r
F
.34094 .59106 m .34521 .55466 L .35509 .55594 L p F P
0 g
s
.35509 .55594 m .37416 .55839 L p .34094 .59106 L .707 .577 .707 r
F P
0 g
s
.31665 .60083 m .32298 .5908 L .33842 .5973 L .707 .577 .707 r
F
.34064 .59823 m .33793 .59852 L p .33842 .5973 L F P
0 g
s
.33793 .59852 m .31665 .60083 L p .33842 .5973 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .34094 .59106 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34064 .59823 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34521 .55466 m .34094 .59106 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.32495 .59083 m .31707 .59071 L .34521 .55466 L .707 .577 .707 r
F
.31665 .60083 m .31707 .59071 L p .32298 .5908 L F P
0 g
s
.31707 .59071 m .31665 .60083 L .31501 .60123 L p .707 .577 .707 r
F P
0 g
s
.31501 .60123 m .30035 .60481 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .32169 .55136 L .32472 .55178 L p .707 .577 .707 r
F P
0 g
s
.32472 .55178 m .34521 .55466 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.32169 .55136 m .31707 .59071 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.30035 .60481 m .30091 .59144 L p .30616 .5912 L .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30192 .56692 L .30327 .56659 L p .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .29403 .59316 L p .29681 .59246 L .707 .577 .707 r
F P
0 g
s
.29365 .60052 m .30591 .54879 L .29343 .60469 L .707 .577 .707 r
F
.2927 .60452 m .29941 .54723 L .30591 .54879 L p F P
0 g
s
.29681 .59246 m .29403 .59316 L .30192 .56692 L .707 .577 .707 r
F
.29919 .60608 m .29343 .60469 L p .29612 .59263 L F P
0 g
s
.30091 .59144 m .29919 .60608 L p .29612 .59263 L .707 .577 .707 r
F P
0 g
s
.2927 .60452 m .29283 .6045 L p .29287 .60412 L .707 .577 .707 r
F P
0 g
s
.29343 .60469 m .2927 .60452 L p .29365 .60052 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29491 .5719 L .2964 .57084 L p .707 .577 .707 r
F P
0 g
s
.2964 .57084 m .30192 .56692 L p .29403 .59316 L .707 .577 .707 r
F P
0 g
s
.64328 .74572 m .64405 .76361 L .64701 .77511 L p .707 .577 .707 r
F P
0 g
s
.84703 .74281 m .84781 .7607 L .84485 .74921 L p .707 .577 .707 r
F P
0 g
s
.84485 .74921 m .84407 .73131 L .84703 .74281 L p .707 .577 .707 r
F P
0 g
s
.64405 .76361 m .64328 .74572 L .65029 .73408 L p .707 .577 .707 r
F P
0 g
s
.65029 .73408 m .65107 .75198 L .64405 .76361 L p .707 .577 .707 r
F P
0 g
s
.84407 .73131 m .84485 .74921 L .83221 .73898 L p .707 .577 .707 r
F P
0 g
s
.83221 .73898 m .83143 .72109 L .84407 .73131 L p .707 .577 .707 r
F P
0 g
s
.65107 .75198 m .65029 .73408 L .66659 .72344 L p .707 .577 .707 r
F P
0 g
s
.39637 .76277 m .39559 .74488 L .36442 .7435 L p .707 .577 .707 r
F P
0 g
s
.39559 .74488 m .39637 .76277 L .42817 .76049 L p .707 .577 .707 r
F P
0 g
s
.42817 .76049 m .42739 .7426 L .39559 .74488 L p .707 .577 .707 r
F P
0 g
s
.42739 .7426 m .42817 .76049 L .4575 .75477 L p .707 .577 .707 r
F P
0 g
s
.4575 .75477 m .45672 .73687 L .42739 .7426 L p .707 .577 .707 r
F P
0 g
s
.66659 .72344 m .66737 .74134 L .65107 .75198 L p .707 .577 .707 r
F P
0 g
s
.3652 .76139 m .36442 .7435 L .33695 .73859 L p .707 .577 .707 r
F P
0 g
s
.36442 .7435 m .3652 .76139 L .39637 .76277 L p .707 .577 .707 r
F P
0 g
s
.83143 .72109 m .83221 .73898 L .81112 .73102 L p .707 .577 .707 r
F P
0 g
s
.81112 .73102 m .81034 .71313 L .83143 .72109 L p .707 .577 .707 r
F P
0 g
s
.45672 .73687 m .4575 .75477 L .48149 .74617 L p .707 .577 .707 r
F P
0 g
s
.48149 .74617 m .48071 .72827 L .45672 .73687 L p .707 .577 .707 r
F P
0 g
s
.33695 .73859 m .33773 .75648 L .3652 .76139 L p .707 .577 .707 r
F P
0 g
s
.33773 .75648 m .33695 .73859 L .31587 .73063 L p .707 .577 .707 r
F P
0 g
s
.66737 .74134 m .66659 .72344 L .69058 .71484 L p .707 .577 .707 r
F P
0 g
s
.31587 .73063 m .31665 .74852 L .33773 .75648 L p .707 .577 .707 r
F P
0 g
s
.69058 .71484 m .69136 .73273 L .66737 .74134 L p .707 .577 .707 r
F P
0 g
s
.48071 .72827 m .48149 .74617 L .49779 .73552 L p .707 .577 .707 r
F P
0 g
s
.49779 .73552 m .49701 .71763 L .48071 .72827 L p .707 .577 .707 r
F P
0 g
s
.81034 .71313 m .81112 .73102 L .78365 .72611 L p .707 .577 .707 r
F P
0 g
s
.78365 .72611 m .78287 .70822 L .81034 .71313 L p .707 .577 .707 r
F P
0 g
s
.69136 .73273 m .69058 .71484 L .71991 .70912 L p .707 .577 .707 r
F P
0 g
s
.31665 .74852 m .31587 .73063 L .30322 .7204 L p .707 .577 .707 r
F P
0 g
s
.78287 .70822 m .78365 .72611 L .75249 .72473 L p .707 .577 .707 r
F P
0 g
s
.75249 .72473 m .75171 .70683 L .78287 .70822 L p .707 .577 .707 r
F P
0 g
s
.71991 .70912 m .72069 .72701 L .69136 .73273 L p .707 .577 .707 r
F P
0 g
s
.30322 .7204 m .304 .73829 L .31665 .74852 L p .707 .577 .707 r
F P
0 g
s
.72069 .72701 m .71991 .70912 L .75171 .70683 L p .707 .577 .707 r
F P
0 g
s
.75171 .70683 m .75249 .72473 L .72069 .72701 L p .707 .577 .707 r
F P
0 g
s
.49701 .71763 m .49779 .73552 L .5048 .72389 L p .707 .577 .707 r
F P
0 g
s
.5048 .72389 m .50402 .70599 L .49701 .71763 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.304 .73829 m .30322 .7204 L .30026 .7089 L p .707 .577 .707 r
F P
0 g
s
.30026 .7089 m .30104 .7268 L .304 .73829 L p .707 .577 .707 r
F P
0 g
s
.50402 .70599 m .5048 .72389 L .50184 .71239 L p .707 .577 .707 r
F P
0 g
s
.50184 .71239 m .50106 .6945 L .50402 .70599 L p .707 .577 .707 r
F P
0 g
s
.30104 .7268 m .30026 .7089 L .30728 .69727 L p .707 .577 .707 r
F P
0 g
s
.30728 .69727 m .30806 .71516 L .30104 .7268 L p .707 .577 .707 r
F P
0 g
s
.50106 .6945 m .50184 .71239 L .4892 .70216 L p .707 .577 .707 r
F P
0 g
s
.4892 .70216 m .48842 .68427 L .50106 .6945 L p .707 .577 .707 r
F P
0 g
s
.30806 .71516 m .30728 .69727 L .32358 .68663 L p .707 .577 .707 r
F P
0 g
s
.32358 .68663 m .32436 .70452 L .30806 .71516 L p .707 .577 .707 r
F P
0 g
s
.48842 .68427 m .4892 .70216 L .46811 .69421 L p .707 .577 .707 r
F P
0 g
s
.46811 .69421 m .46733 .67631 L .48842 .68427 L p .707 .577 .707 r
F P
0 g
s
.32436 .70452 m .32358 .68663 L .34757 .67802 L p .707 .577 .707 r
F P
0 g
s
.34757 .67802 m .34835 .69592 L .32436 .70452 L p .707 .577 .707 r
F P
0 g
s
.46733 .67631 m .46811 .69421 L .44064 .6893 L p .707 .577 .707 r
F P
0 g
s
.44064 .6893 m .43986 .6714 L .46733 .67631 L p .707 .577 .707 r
F P
0 g
s
.34835 .69592 m .34757 .67802 L .3769 .6723 L p .707 .577 .707 r
F P
0 g
s
.43986 .6714 m .44064 .6893 L .40948 .68791 L p .707 .577 .707 r
F P
0 g
s
.40948 .68791 m .4087 .67002 L .43986 .6714 L p .707 .577 .707 r
F P
0 g
s
.3769 .6723 m .37768 .69019 L .34835 .69592 L p .707 .577 .707 r
F P
0 g
s
.37768 .69019 m .3769 .6723 L .4087 .67002 L p .707 .577 .707 r
F P
0 g
s
.4087 .67002 m .40948 .68791 L .37768 .69019 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo5P00QWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001mOol007Ioo`D000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001]Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP<006aoo`00JGoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`8000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol70008Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol>00001Goo001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH01000FUIJEUYF3@00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH00`00FUIJEP04FUHC
0002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00010000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol30004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001COol40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF2@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002001TOol0
05=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000>001HOol005=oo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH005YF001JEPH00003FUH005YF009JEPT004moo`00;goo0P008Woo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH:0004FUH80017Ool002ioo`h001Moo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00eYF5P00
?Woo000^Ool20002FUH70003FUH9000>Ool2FUH01000FUIJEUYF300015YF00<005YFFUH00UYF3P00
1UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ@003Moo`00;Woo0P0015YF00@005YFFUIJEPL00003FUH005YF00=JEPT000Eoo`04001J
EP00FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEQ80039oo`00;Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT00003FUH005YF00=J
EPT0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000QJEP03001JEUYF00AJ
EP04001JEP000002FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEQ0002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000AJEP000000009JEPH000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`001EYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEP00008000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH?0003FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF2P000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JER8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=J
EPH000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHE000015YF0000000015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF0P0025YF00@005YFFUIJEPL000=JEP05001JEUYFFUH0000^Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH0000002ioo`00;7oo10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH00eYF
2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
<7oo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010000eYF0P001eYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00=Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00EJEPP000AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool003eoo`T000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH<
0002FUH2000^Ool004Ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH8
0004FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF2P00;Woo001?Ool80004FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH03`0015YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2OolJ000hOol005Moo``00004FUH005YFFUH90004
FUH00`00FUIJEP06FUH00`00FUH00004000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPMoo`D0
04Qoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<0
05YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00Ggoo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YF
FUIJEP8000Qoo`<004Uoo`00GGoo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00Fgoo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00FWoo0P001eYF00<005YFFUH0
0UYF20001eYF00<005YF00001`0015YF00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0019OolA00000eYF001JEP05FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH6
0004FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00E7oo0010Ool90004FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH3000015YF001JEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00>Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00@005YF000000Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH20002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000hOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH2000015YF000000000Woo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00EGoo000fOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002FUH200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000080003FUH01000FUIJEUYF0P000goo5`00>goo000dOol20006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH=000015YF0000000015YF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF0P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo300000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Ioo`00<goo0P001eYF00<005YFFUH00UYF200037oo00<005YF00001000
0UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH01eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
37oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=7oo000aOol20000
0eYF001JEP05FUH6000DOol20005Ool40004FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000027oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00P00<Woo000_Ool20004FUH01000FUIJEUYF0P003Goo0`002Woo0`00
27oo0`0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP80031oo`00;goo00=JEP00FUH00eYF00@005YF000000ioo`D000Uoo`800003FUH007oo
00Uoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP80
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<0
00IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP<002ioo`00;Woo00<007oo000015YF0P00
27oo3@002Goo0P000UYF00<007ooOol027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEUYFFUH20004FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP04000GOol50005FUH01000FUIJ
EP00;Goo000^Ool00`00Ool00002FUH<0003FUH00`00FUIJEP02FUH@0002FUH30008Ool01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF100000=JEP00FUH00eYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH00eYF
100087oo0P000eYF00@005YFFUH002eoo`00;Woo00<005YF00000`001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00P001Woo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03001JEP0000<002Io
o`800005FUH005YFFUH0000]Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH01000FUIJEUYF1@0000Eoo`00FUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP<0
0004FUH00000000WOol20002FUH2000/Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH01000FUIJEUYF6@001EYF00<0
05YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEUYF009JEP8002Moo`04001JEUYF000/Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000X000IJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP<000=JEP03001JEUYF00=JEP8002Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001P002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF0P0015YF00<005YFFUH00eYF00<005YF00009goo0P00;7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000Woo1@001EYF00@005YFFUH002Eoo`03001JEP0002aoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00008000Mo
o`8000=JEP04001JEUYF000TOol200000eYF001oo`0[Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEP0001L0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00008000Uoo`800005FUH005YFFUH0000ROol2
000015YF001JEP00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP05001JEP00001JEP020009Ool20003FUH00`00Oomoo`0MOol20003
FUH2000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
0P002Goo0P0000=JEP00Ool077oo0P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH00002FUH6
00000eYF001JEP06FUH00`00FUIJEP05FUH30005FUH80003FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF0P0000=JEP00FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP0000000eYF00<005YF00000P0027oo
0P006goo0P000eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P000eYF0P000eYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF1@0015YF00H005YFFUH005YF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF00000003FUH00`00FUIJEP02FUH50003Ool2000E
Ool60005FUH01000FUIJEP00;goo000/Ool20002FUH00`00FUIJEP03FUH200000eYF001JEP05FUH0
0`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH7000015YF001JEUYF0P0015YF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000AJEP00FUH0009JEP03001JEUYF00=JEP04001JEUYFFUH80009Ool90004
FUH00`00FUIJEP04FUH3000`Ool002aoo`80009JEP03001JEUYF00=JEP03001JEP0000@000=JEP03
001JEUYF00AJEPD000IJEP03001JEUYF00D000EJEP@00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP000002FUH30005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00<Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF6000
0eYF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EP000004FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00=7oo000^Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP001UYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000003Ioo`00<7oo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00001eYF00<005YFFUH01@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@00>7oo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP060002FUH00`00FUIJEP05FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP03FUH00`00FUH000080004FUH00`00FUIJEP02FUH9000mOol0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60006Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001Goo2@00AWoo0013
OolI000>Ool20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00K7oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YFFUH005YF001DOol006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00=JEPD000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
05Eoo`00LGoo1`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
20001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P00EGoo001hOol<0006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH70004FUH50006FUH00`00FUIJEP02FUH50002FUH40002FUH2001EOol008Ao
ob<0009JEPD0009JEPT00003FUH005YF00EJEP03001JEUYF00@005Eoo`00SWoo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<005Eoo`00T7oo100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009Aoo`<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYFFUH005YFEWoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001GOol009aooa4000EJEP03001JEUYF009JEPd005Uoo`00[Goo
2P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59493 .71763 m .59912 .66031 L .56798 .65745 L p .707 .577 .707 r
F P
0 g
s
.59912 .66031 m .59493 .71763 L .62666 .71966 L p .707 .577 .707 r
F P
0 g
s
.62666 .71966 m .63085 .66234 L .59912 .66031 L p .707 .577 .707 r
F P
0 g
s
.63085 .66234 m .62666 .71966 L .65588 .72066 L p .707 .577 .707 r
F P
0 g
s
.65588 .72066 m .66007 .66334 L .63085 .66234 L p .707 .577 .707 r
F P
0 g
s
.56798 .65745 m .56379 .71477 L .59493 .71763 L p .707 .577 .707 r
F P
0 g
s
.56379 .71477 m .56798 .65745 L .54049 .65402 L p .707 .577 .707 r
F P
0 g
s
.54049 .65402 m .5363 .71134 L .56379 .71477 L p .707 .577 .707 r
F P
0 g
s
.66007 .66334 m .65588 .72066 L .67972 .72051 L p .707 .577 .707 r
F P
0 g
s
.67972 .72051 m .68392 .66319 L .66007 .66334 L p .707 .577 .707 r
F P
0 g
s
.5363 .71134 m .54049 .65402 L .51933 .65037 L p .707 .577 .707 r
F P
0 g
s
.51933 .65037 m .51514 .70769 L .5363 .71134 L p .707 .577 .707 r
F P
0 g
s
.59505 .82878 m .59602 .79116 L .56485 .78893 L p .707 .577 .707 r
F P
0 g
s
.59602 .79116 m .59505 .82878 L .62687 .82896 L p .707 .577 .707 r
F P
0 g
s
.62687 .82896 m .62784 .79134 L .59602 .79116 L p .707 .577 .707 r
F P
0 g
s
.62784 .79134 m .62687 .82896 L .65624 .82707 L p .707 .577 .707 r
F P
0 g
s
.65624 .82707 m .65721 .78945 L .62784 .79134 L p .707 .577 .707 r
F P
0 g
s
.56388 .82655 m .56485 .78893 L .53739 .78486 L p .707 .577 .707 r
F P
0 g
s
.56485 .78893 m .56388 .82655 L .59505 .82878 L p .707 .577 .707 r
F P
0 g
s
.68392 .66319 m .67972 .72051 L .69587 .71925 L p .707 .577 .707 r
F P
0 g
s
.69587 .71925 m .70006 .66193 L .68392 .66319 L p .707 .577 .707 r
F P
0 g
s
.53739 .78486 m .53642 .82248 L .56388 .82655 L p .707 .577 .707 r
F P
0 g
s
.65721 .78945 m .65624 .82707 L .68027 .8233 L p .707 .577 .707 r
F P
0 g
s
.68027 .8233 m .68124 .78568 L .65721 .78945 L p .707 .577 .707 r
F P
0 g
s
.59981 .83462 m .59933 .81646 L .56816 .81488 L p .707 .577 .707 r
F P
0 g
s
.59933 .81646 m .59981 .83462 L .63164 .83291 L p .707 .577 .707 r
F P
0 g
s
.63164 .83291 m .63115 .81474 L .59933 .81646 L p .707 .577 .707 r
F P
0 g
s
.51514 .70769 m .51933 .65037 L .50658 .64686 L p .707 .577 .707 r
F P
0 g
s
.63115 .81474 m .63164 .83291 L .661 .82807 L p .707 .577 .707 r
F P
0 g
s
.661 .82807 m .66052 .80991 L .63115 .81474 L p .707 .577 .707 r
F P
0 g
s
.56816 .81488 m .56864 .83304 L .59981 .83462 L p .707 .577 .707 r
F P
0 g
s
.56864 .83304 m .56816 .81488 L .5407 .81016 L p .707 .577 .707 r
F P
0 g
s
.53642 .82248 m .53739 .78486 L .51632 .77937 L p .707 .577 .707 r
F P
0 g
s
.50658 .64686 m .50238 .70418 L .51514 .70769 L p .707 .577 .707 r
F P
0 g
s
.5407 .81016 m .54118 .82833 L .56864 .83304 L p .707 .577 .707 r
F P
0 g
s
.68124 .78568 m .68027 .8233 L .69661 .81802 L p .707 .577 .707 r
F P
0 g
s
.66052 .80991 m .661 .82807 L .68503 .82058 L p .707 .577 .707 r
F P
0 g
s
.68503 .82058 m .68454 .80242 L .66052 .80991 L p .707 .577 .707 r
F P
0 g
s
.51632 .77937 m .51535 .81699 L .53642 .82248 L p .707 .577 .707 r
F P
0 g
s
.69661 .81802 m .69758 .7804 L .68124 .78568 L p .707 .577 .707 r
F P
0 g
s
.70006 .66193 m .69587 .71925 L .70272 .71699 L p .707 .577 .707 r
F P
0 g
s
.70272 .71699 m .70692 .65967 L .70006 .66193 L p .707 .577 .707 r
F P
0 g
s
.54118 .82833 m .5407 .81016 L .51963 .80277 L p .707 .577 .707 r
F P
0 g
s
.51963 .80277 m .52011 .82094 L .54118 .82833 L p .707 .577 .707 r
F P
0 g
s
.51535 .81699 m .51632 .77937 L .50371 .77298 L p .707 .577 .707 r
F P
0 g
s
.50238 .70418 m .50658 .64686 L .50347 .64383 L p .707 .577 .707 r
F P
0 g
s
.69758 .7804 m .69661 .81802 L .69807 .81672 L p .707 .577 .707 r
F P
0 g
s
.69811 .81305 m .70137 .81118 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.69841 .78467 m .69758 .7804 L .69807 .81672 L .707 .577 .707 r
F
.70137 .81118 m .70089 .79302 L .6983 .7945 L p F P
0 g
s
.6983 .7945 m .68454 .80242 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.70137 .81118 m .6983 .7945 L .69815 .8095 L .707 .577 .707 r
F
.70089 .79302 m .70137 .81118 L .70843 .80078 L p F P
0 g
s
.70843 .80078 m .70794 .78262 L .70089 .79302 L p .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .70463 .77412 L .69846 .77962 L p .707 .577 .707 r
F P
0 g
s
.69846 .77962 m .69758 .7804 L p .69841 .78467 L .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .69846 .77962 L .69841 .78467 L .707 .577 .707 r
F
.69807 .81672 m .70366 .81174 L p .69841 .78467 L F P
0 g
s
.68454 .80242 m .68503 .82058 L .69811 .81305 L p .707 .577 .707 r
F P
0 g
s
.69815 .8095 m .68454 .80242 L .69811 .81305 L .707 .577 .707 r
F
.50347 .64383 m .49928 .70115 L .50238 .70418 L p F P
0 g
s
.50371 .77298 m .50274 .8106 L .51535 .81699 L p .707 .577 .707 r
F P
0 g
s
.52011 .82094 m .51963 .80277 L .50702 .79343 L p .707 .577 .707 r
F P
0 g
s
.50702 .79343 m .5075 .81159 L .52011 .82094 L p .707 .577 .707 r
F P
0 g
s
.70692 .65967 m .70272 .71699 L .69962 .71396 L p .707 .577 .707 r
F P
0 g
s
.69962 .71396 m .70382 .65664 L .70692 .65967 L p .707 .577 .707 r
F P
0 g
s
.48847 .82191 m .49028 .31883 L .44627 .31609 L p .707 .577 .707 r
F P
0 g
s
.50274 .8106 m .50371 .77298 L .50079 .76632 L p .707 .577 .707 r
F P
0 g
s
.49928 .70115 m .50347 .64383 L .51033 .64157 L p .707 .577 .707 r
F P
0 g
s
.50079 .76632 m .49982 .80394 L .50274 .8106 L p .707 .577 .707 r
F P
0 g
s
.51033 .64157 m .50614 .69889 L .49928 .70115 L p .707 .577 .707 r
F P
0 g
s
.5075 .81159 m .50702 .79343 L .5041 .78305 L p .707 .577 .707 r
F P
0 g
s
.5041 .78305 m .50458 .80121 L .5075 .81159 L p .707 .577 .707 r
F P
0 g
s
.49982 .80394 m .50079 .76632 L .50785 .76004 L p .707 .577 .707 r
F P
0 g
s
.50614 .69889 m .51033 .64157 L .52647 .64031 L p .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .5041 .78305 L .51004 .7743 L p .707 .577 .707 r
F P
0 g
s
.50989 .75938 m .52419 .75475 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.51004 .7743 m .51116 .77265 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .51004 .7743 L .51007 .77736 L .707 .577 .707 r
F
.5102 .78943 m .52419 .75475 L .51027 .79656 L F
.51116 .77265 m .51164 .79081 L .51023 .79289 L p F P
0 g
s
.51023 .79289 m .50458 .80121 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.51007 .77736 m .51116 .77265 L .51023 .79289 L .707 .577 .707 r
F
.52419 .75475 m .52322 .79237 L .51027 .79656 L p F P
0 g
s
.51027 .79656 m .50688 .79766 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50785 .76004 L .50989 .75938 L p .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50989 .75938 L .5102 .78943 L .707 .577 .707 r
F
.50785 .76004 m .50688 .79766 L .49982 .80394 L p F P
0 g
s
.52647 .64031 m .52228 .69763 L .50614 .69889 L p .707 .577 .707 r
F P
0 g
s
.52228 .69763 m .52647 .64031 L .55032 .64017 L p .707 .577 .707 r
F P
0 g
s
.55032 .64017 m .54613 .69749 L .52228 .69763 L p .707 .577 .707 r
F P
0 g
s
.52322 .79237 m .52419 .75475 L .54822 .75099 L p .707 .577 .707 r
F P
0 g
s
.51164 .79081 m .51116 .77265 L .5275 .76325 L p .707 .577 .707 r
F P
0 g
s
.5275 .76325 m .52798 .78141 L .51164 .79081 L p .707 .577 .707 r
F P
0 g
s
.54822 .75099 m .54725 .78861 L .52322 .79237 L p .707 .577 .707 r
F P
0 g
s
.54725 .78861 m .54822 .75099 L .57758 .7491 L p .707 .577 .707 r
F P
0 g
s
.52798 .78141 m .5275 .76325 L .55153 .75576 L p .707 .577 .707 r
F P
0 g
s
.55153 .75576 m .55201 .77392 L .52798 .78141 L p .707 .577 .707 r
F P
0 g
s
.49028 .31883 m .48847 .82191 L .53342 .821 L p .707 .577 .707 r
F P
0 g
s
.53342 .821 m .53522 .31792 L .49028 .31883 L p .707 .577 .707 r
F P
0 g
s
.54613 .69749 m .55032 .64017 L .57954 .64116 L p .707 .577 .707 r
F P
0 g
s
.57954 .64116 m .57535 .69848 L .54613 .69749 L p .707 .577 .707 r
F P
0 g
s
.57758 .7491 m .57661 .78672 L .54725 .78861 L p .707 .577 .707 r
F P
0 g
s
.57661 .78672 m .57758 .7491 L .6094 .74928 L p .707 .577 .707 r
F P
0 g
s
.55201 .77392 m .55153 .75576 L .58089 .75092 L p .707 .577 .707 r
F P
0 g
s
.58089 .75092 m .58137 .76909 L .55201 .77392 L p .707 .577 .707 r
F P
0 g
s
.53522 .31792 m .53342 .821 L .5749 .81651 L p .707 .577 .707 r
F P
0 g
s
.5749 .81651 m .5767 .31344 L .53522 .31792 L p .707 .577 .707 r
F P
0 g
s
.44447 .81916 m .44627 .31609 L .40751 .30995 L p .707 .577 .707 r
F P
0 g
s
.44627 .31609 m .44447 .81916 L .48847 .82191 L p .707 .577 .707 r
F P
0 g
s
.70463 .77412 m .70366 .81174 L .70074 .80508 L p .707 .577 .707 r
F P
0 g
s
.70074 .80508 m .70171 .76746 L .70463 .77412 L p .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .57954 .64116 L .58524 .64152 L p .707 .577 .707 r
F P
0 g
s
.58524 .64152 m .61127 .64319 L p .57975 .6917 L .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .58524 .64152 L .57975 .6917 L .707 .577 .707 r
F
.64241 .64605 m .63821 .70338 L .60708 .70051 L p F P
0 g
s
.60708 .70051 m .61127 .64319 L .64241 .64605 L p .707 .577 .707 r
F P
0 g
s
.61127 .64319 m .60708 .70051 L .57535 .69848 L p .707 .577 .707 r
F P
0 g
s
.64057 .75151 m .6396 .78913 L .60843 .7869 L p .707 .577 .707 r
F P
0 g
s
.60843 .7869 m .6094 .74928 L .64057 .75151 L p .707 .577 .707 r
F P
0 g
s
.6396 .78913 m .64057 .75151 L .66803 .75557 L p .707 .577 .707 r
F P
0 g
s
.64388 .75079 m .64436 .76895 L .6132 .76737 L p .707 .577 .707 r
F P
0 g
s
.6132 .76737 m .61271 .74921 L .64388 .75079 L p .707 .577 .707 r
F P
0 g
s
.6094 .74928 m .60843 .7869 L .57661 .78672 L p .707 .577 .707 r
F P
0 g
s
.58137 .76909 m .58089 .75092 L .61271 .74921 L p .707 .577 .707 r
F P
0 g
s
.61271 .74921 m .6132 .76737 L .58137 .76909 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .63196 .7989 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61066 .30582 m .61028 .41273 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61028 .41273 m .60886 .8089 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.5767 .31344 m .5749 .81651 L .60886 .8089 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .61066 .30582 L .5767 .31344 L p .707 .577 .707 r
F P
0 g
s
.70382 .65664 m .69962 .71396 L .68687 .71045 L p .707 .577 .707 r
F P
0 g
s
.68687 .71045 m .69106 .65313 L .70382 .65664 L p .707 .577 .707 r
F P
0 g
s
.25192 .68082 m .25611 .6235 L .22498 .62063 L p .707 .577 .707 r
F P
0 g
s
.25611 .6235 m .25192 .68082 L .28365 .68285 L p .707 .577 .707 r
F P
0 g
s
.28365 .68285 m .28784 .62553 L .25611 .6235 L p .707 .577 .707 r
F P
0 g
s
.70794 .78262 m .70843 .80078 L .70551 .7904 L p .707 .577 .707 r
F P
0 g
s
.70551 .7904 m .70502 .77224 L .70794 .78262 L p .707 .577 .707 r
F P
0 g
s
.4057 .81303 m .40751 .30995 L .37778 .30102 L p .707 .577 .707 r
F P
0 g
s
.40751 .30995 m .4057 .81303 L .44447 .81916 L p .707 .577 .707 r
F P
0 g
s
.28784 .62553 m .28365 .68285 L .31287 .68384 L p .707 .577 .707 r
F P
0 g
s
.31287 .68384 m .31706 .62652 L .28784 .62553 L p .707 .577 .707 r
F P
0 g
s
.22498 .62063 m .22078 .67795 L .25192 .68082 L p .707 .577 .707 r
F P
0 g
s
.22078 .67795 m .22498 .62063 L .19748 .6172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19748 .6172 m .19329 .67453 L .22078 .67795 L p .707 .577 .707 r
F P
0 g
s
.31706 .62652 m .31287 .68384 L .33672 .6837 L p .707 .577 .707 r
F P
0 g
s
.33672 .6837 m .34091 .62638 L .31706 .62652 L p .707 .577 .707 r
F P
0 g
s
.63196 .7989 m .63377 .29582 L .61066 .30582 L p .707 .577 .707 r
F P
0 g
s
.70171 .76746 m .70074 .80508 L .68813 .79869 L p .707 .577 .707 r
F P
0 g
s
.68813 .79869 m .6891 .76107 L .70171 .76746 L p .707 .577 .707 r
F P
0 g
s
.19329 .67453 m .19748 .6172 L .17632 .61356 L p .707 .577 .707 r
F P
0 g
s
.69106 .65313 m .68687 .71045 L .66571 .7068 L p .707 .577 .707 r
F P
0 g
s
.66571 .7068 m .6699 .64948 L .69106 .65313 L p .707 .577 .707 r
F P
0 g
s
.17632 .61356 m .17213 .67088 L .19329 .67453 L p .707 .577 .707 r
F P
0 g
s
.25204 .79196 m .25301 .75434 L .22185 .75211 L p .707 .577 .707 r
F P
0 g
s
.25301 .75434 m .25204 .79196 L .28387 .79214 L p .707 .577 .707 r
F P
0 g
s
.28387 .79214 m .28484 .75452 L .25301 .75434 L p .707 .577 .707 r
F P
0 g
s
.70502 .77224 m .70551 .7904 L .69289 .78106 L p .707 .577 .707 r
F P
0 g
s
.69289 .78106 m .69241 .76289 L .70502 .77224 L p .707 .577 .707 r
F P
0 g
s
.28484 .75452 m .28387 .79214 L .31323 .79026 L p .707 .577 .707 r
F P
0 g
s
.31323 .79026 m .3142 .75264 L .28484 .75452 L p .707 .577 .707 r
F P
0 g
s
.37598 .8041 m .37778 .30102 L .36 .29018 L p .707 .577 .707 r
F P
0 g
s
.37778 .30102 m .37598 .8041 L .4057 .81303 L p .707 .577 .707 r
F P
0 g
s
.22087 .78973 m .22185 .75211 L .19438 .74805 L p .707 .577 .707 r
F P
0 g
s
.22185 .75211 m .22087 .78973 L .25204 .79196 L p .707 .577 .707 r
F P
0 g
s
.34091 .62638 m .33672 .6837 L .35286 .68244 L p .707 .577 .707 r
F P
0 g
s
.35286 .68244 m .35705 .62512 L .34091 .62638 L p .707 .577 .707 r
F P
0 g
s
.19438 .74805 m .19341 .78567 L .22087 .78973 L p .707 .577 .707 r
F P
0 g
s
.3142 .75264 m .31323 .79026 L .33726 .78649 L p .707 .577 .707 r
F P
0 g
s
.33726 .78649 m .33823 .74887 L .3142 .75264 L p .707 .577 .707 r
F P
0 g
s
.2568 .7978 m .25632 .77964 L .22515 .77806 L p .707 .577 .707 r
F P
0 g
s
.25632 .77964 m .2568 .7978 L .28863 .79609 L p .707 .577 .707 r
F P
0 g
s
.28863 .79609 m .28814 .77793 L .25632 .77964 L p .707 .577 .707 r
F P
0 g
s
.17213 .67088 m .17632 .61356 L .16357 .61004 L p .707 .577 .707 r
F P
0 g
s
.28814 .77793 m .28863 .79609 L .31799 .79125 L p .707 .577 .707 r
F P
0 g
s
.31799 .79125 m .31751 .77309 L .28814 .77793 L p .707 .577 .707 r
F P
0 g
s
.6699 .64948 m .66571 .7068 L .63821 .70338 L p .707 .577 .707 r
F P
0 g
s
.63821 .70338 m .64241 .64605 L .6699 .64948 L p .707 .577 .707 r
F P
0 g
s
.6891 .76107 m .68813 .79869 L .66706 .79319 L p .707 .577 .707 r
F P
0 g
s
.66706 .79319 m .66803 .75557 L .6891 .76107 L p .707 .577 .707 r
F P
0 g
s
.22515 .77806 m .22563 .79623 L .2568 .7978 L p .707 .577 .707 r
F P
0 g
s
.22563 .79623 m .22515 .77806 L .19769 .77335 L p .707 .577 .707 r
F P
0 g
s
.19341 .78567 m .19438 .74805 L .17331 .74255 L p .707 .577 .707 r
F P
0 g
s
.16357 .61004 m .15937 .66737 L .17213 .67088 L p .707 .577 .707 r
F P
0 g
s
.19769 .77335 m .19817 .79151 L .22563 .79623 L p .707 .577 .707 r
F P
0 g
s
.66803 .75557 m .66706 .79319 L .6396 .78913 L p .707 .577 .707 r
F P
0 g
s
.63377 .29582 m .63196 .7989 L .64196 .78749 L p .707 .577 .707 r
F P
0 g
s
.64196 .78749 m .64377 .28441 L .63377 .29582 L p .707 .577 .707 r
F P
0 g
s
.33823 .74887 m .33726 .78649 L .3536 .78121 L p .707 .577 .707 r
F P
0 g
s
.31751 .77309 m .31799 .79125 L .34202 .78377 L p .707 .577 .707 r
F P
0 g
s
.34202 .78377 m .34154 .76561 L .31751 .77309 L p .707 .577 .707 r
F P
0 g
s
.69241 .76289 m .69289 .78106 L .67183 .77367 L p .707 .577 .707 r
F P
0 g
s
.67183 .77367 m .67134 .7555 L .69241 .76289 L p .707 .577 .707 r
F P
0 g
s
.17331 .74255 m .17234 .78017 L .19341 .78567 L p .707 .577 .707 r
F P
0 g
s
.3536 .78121 m .35457 .74359 L .33823 .74887 L p .707 .577 .707 r
F P
0 g
s
.35705 .62512 m .35286 .68244 L .35971 .68018 L p .707 .577 .707 r
F P
0 g
s
.35971 .68018 m .36391 .62286 L .35705 .62512 L p .707 .577 .707 r
F P
0 g
s
.19817 .79151 m .19769 .77335 L .17662 .76596 L p .707 .577 .707 r
F P
0 g
s
.17662 .76596 m .1771 .78412 L .19817 .79151 L p .707 .577 .707 r
F P
0 g
s
.17234 .78017 m .17331 .74255 L .1607 .73616 L p .707 .577 .707 r
F P
0 g
s
.35457 .74359 m .3536 .78121 L .35506 .7799 L p .707 .577 .707 r
F P
0 g
s
.3554 .74785 m .35457 .74359 L .35506 .7799 L .707 .577 .707 r
F
.34154 .76561 m .34202 .78377 L .3551 .77624 L p F P
0 g
s
.3551 .77624 m .35836 .77436 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35514 .77269 m .34154 .76561 L .3551 .77624 L .707 .577 .707 r
F
.35836 .77436 m .35788 .7562 L .3553 .75769 L p F P
0 g
s
.3553 .75769 m .34154 .76561 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35836 .77436 m .3553 .75769 L .35514 .77269 L .707 .577 .707 r
F
.35788 .7562 m .35836 .77436 L .36542 .76396 L p F P
0 g
s
.36542 .76396 m .36493 .7458 L .35788 .7562 L p .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .36163 .73731 L .35545 .7428 L p .707 .577 .707 r
F P
0 g
s
.35545 .7428 m .35457 .74359 L p .3554 .74785 L .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .35545 .7428 L .3554 .74785 L .707 .577 .707 r
F
.35506 .7799 m .36065 .77493 L p .3554 .74785 L F P
0 g
s
.36391 .62286 m .35971 .68018 L .35661 .67715 L p .707 .577 .707 r
F P
0 g
s
.35661 .67715 m .36081 .61982 L .36391 .62286 L p .707 .577 .707 r
F P
0 g
s
.36163 .73731 m .36065 .77493 L .35773 .76827 L p .707 .577 .707 r
F P
0 g
s
.35773 .76827 m .3587 .73065 L .36163 .73731 L p .707 .577 .707 r
F P
0 g
s
.36081 .61982 m .35661 .67715 L .34386 .67363 L p .707 .577 .707 r
F P
0 g
s
.34386 .67363 m .34805 .61631 L .36081 .61982 L p .707 .577 .707 r
F P
0 g
s
.3587 .73065 m .35773 .76827 L .34512 .76187 L p .707 .577 .707 r
F P
0 g
s
.34512 .76187 m .34609 .72425 L .3587 .73065 L p .707 .577 .707 r
F P
0 g
s
.36201 .73542 m .3625 .75358 L .34988 .74424 L p .707 .577 .707 r
F P
0 g
s
.34988 .74424 m .3494 .72608 L .36201 .73542 L p .707 .577 .707 r
F P
0 g
s
.3582 .79326 m .36 .29018 L .35591 .27848 L p .707 .577 .707 r
F P
0 g
s
.36493 .7458 m .36542 .76396 L .3625 .75358 L p .707 .577 .707 r
F P
0 g
s
.3625 .75358 m .36201 .73542 L .36493 .7458 L p .707 .577 .707 r
F P
0 g
s
.36 .29018 m .3582 .79326 L .37598 .8041 L p .707 .577 .707 r
F P
0 g
s
.15937 .66737 m .16357 .61004 L .16047 .60701 L p .707 .577 .707 r
F P
0 g
s
.16047 .60701 m .15627 .66433 L .15937 .66737 L p .707 .577 .707 r
F P
0 g
s
.67134 .7555 m .67183 .77367 L .64436 .76895 L p .707 .577 .707 r
F P
0 g
s
.64436 .76895 m .64388 .75079 L .67134 .7555 L p .707 .577 .707 r
F P
0 g
s
.1607 .73616 m .15973 .77378 L .17234 .78017 L p .707 .577 .707 r
F P
0 g
s
.1771 .78412 m .17662 .76596 L .16401 .75662 L p .707 .577 .707 r
F P
0 g
s
.16401 .75662 m .16449 .77478 L .1771 .78412 L p .707 .577 .707 r
F P
0 g
s
.64377 .28441 m .64196 .78749 L .63787 .77579 L p .707 .577 .707 r
F P
0 g
s
.63787 .77579 m .63968 .27272 L .64377 .28441 L p .707 .577 .707 r
F P
0 g
s
.15973 .77378 m .1607 .73616 L .15778 .7295 L p .707 .577 .707 r
F P
0 g
s
.15627 .66433 m .16047 .60701 L .16732 .60475 L p .707 .577 .707 r
F P
0 g
s
.15778 .7295 m .15681 .76712 L .15973 .77378 L p .707 .577 .707 r
F P
0 g
s
.16732 .60475 m .16313 .66207 L .15627 .66433 L p .707 .577 .707 r
F P
0 g
s
.16449 .77478 m .16401 .75662 L .16109 .74624 L p .707 .577 .707 r
F P
0 g
s
.35591 .27848 m .35411 .78156 L .3582 .79326 L p .707 .577 .707 r
F P
0 g
s
.35411 .78156 m .35591 .27848 L .36591 .26707 L p .707 .577 .707 r
F P
0 g
s
.16109 .74624 m .16157 .7644 L .16449 .77478 L p .707 .577 .707 r
F P
0 g
s
.15681 .76712 m .15778 .7295 L .16484 .72322 L p .707 .577 .707 r
F P
0 g
s
.16313 .66207 m .16732 .60475 L .18346 .60349 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16157 .7644 m .16109 .74624 L .16703 .73748 L p .707 .577 .707 r
F P
0 g
s
.16688 .72256 m .18118 .71794 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16703 .73748 m .16815 .73584 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16157 .7644 m .16703 .73748 L .16706 .74055 L .707 .577 .707 r
F
.16719 .75262 m .18118 .71794 L .16726 .75975 L F
.16815 .73584 m .16863 .754 L .16722 .75607 L p F P
0 g
s
.16722 .75607 m .16157 .7644 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16706 .74055 m .16815 .73584 L .16722 .75607 L .707 .577 .707 r
F
.18118 .71794 m .18021 .75556 L .16726 .75975 L p F P
0 g
s
.16726 .75975 m .16387 .76084 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16484 .72322 L .16688 .72256 L p .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16688 .72256 L .16719 .75262 L .707 .577 .707 r
F
.16484 .72322 m .16387 .76084 L .15681 .76712 L p F P
0 g
s
.18346 .60349 m .17927 .66081 L .16313 .66207 L p .707 .577 .707 r
F P
0 g
s
.63968 .27272 m .63787 .77579 L .62009 .76495 L p .707 .577 .707 r
F P
0 g
s
.62009 .76495 m .6219 .26187 L .63968 .27272 L p .707 .577 .707 r
F P
0 g
s
.34805 .61631 m .34386 .67363 L .3227 .66999 L p .707 .577 .707 r
F P
0 g
s
.3227 .66999 m .32689 .61266 L .34805 .61631 L p .707 .577 .707 r
F P
0 g
s
.36411 .77015 m .36591 .26707 L .38902 .25707 L p .707 .577 .707 r
F P
0 g
s
.36591 .26707 m .36411 .77015 L .35411 .78156 L p .707 .577 .707 r
F P
0 g
s
.17927 .66081 m .18346 .60349 L .20731 .60335 L p .707 .577 .707 r
F P
0 g
s
.20731 .60335 m .20312 .66067 L .17927 .66081 L p .707 .577 .707 r
F P
0 g
s
.18021 .75556 m .18118 .71794 L .20521 .71417 L p .707 .577 .707 r
F P
0 g
s
.16863 .754 m .16815 .73584 L .18449 .72643 L p .707 .577 .707 r
F P
0 g
s
.32689 .61266 m .3227 .66999 L .2952 .66656 L p .707 .577 .707 r
F P
0 g
s
.2952 .66656 m .2994 .60924 L .32689 .61266 L p .707 .577 .707 r
F P
0 g
s
.34609 .72425 m .34512 .76187 L .32405 .75638 L p .707 .577 .707 r
F P
0 g
s
.32405 .75638 m .32502 .71876 L .34609 .72425 L p .707 .577 .707 r
F P
0 g
s
.18449 .72643 m .18497 .74459 L .16863 .754 L p .707 .577 .707 r
F P
0 g
s
.6219 .26187 m .62009 .76495 L .59037 .75602 L p .707 .577 .707 r
F P
0 g
s
.59037 .75602 m .59217 .25294 L .6219 .26187 L p .707 .577 .707 r
F P
0 g
s
.20312 .66067 m .20731 .60335 L .23653 .60434 L p .707 .577 .707 r
F P
0 g
s
.3494 .72608 m .34988 .74424 L .32882 .73685 L p .707 .577 .707 r
F P
0 g
s
.32882 .73685 m .32833 .71869 L .3494 .72608 L p .707 .577 .707 r
F P
0 g
s
.23653 .60434 m .23234 .66166 L .20312 .66067 L p .707 .577 .707 r
F P
0 g
s
.2994 .60924 m .2952 .66656 L .26407 .66369 L p .707 .577 .707 r
F P
0 g
s
.26407 .66369 m .26826 .60637 L .2994 .60924 L p .707 .577 .707 r
F P
0 g
s
.38902 .25707 m .38722 .76015 L .36411 .77015 L p .707 .577 .707 r
F P
0 g
s
.38722 .76015 m .38902 .25707 L .42298 .24946 L p .707 .577 .707 r
F P
0 g
s
.20521 .71417 m .20424 .75179 L .18021 .75556 L p .707 .577 .707 r
F P
0 g
s
.23234 .66166 m .23653 .60434 L .26826 .60637 L p .707 .577 .707 r
F P
0 g
s
.20424 .75179 m .20521 .71417 L .23457 .71228 L p .707 .577 .707 r
F P
0 g
s
.18497 .74459 m .18449 .72643 L .20852 .71895 L p .707 .577 .707 r
F P
0 g
s
.26826 .60637 m .26407 .66369 L .23234 .66166 L p .707 .577 .707 r
F P
0 g
s
.32502 .71876 m .32405 .75638 L .29659 .75232 L p .707 .577 .707 r
F P
0 g
s
.29659 .75232 m .29756 .7147 L .32502 .71876 L p .707 .577 .707 r
F P
0 g
s
.73213 .65321 m .73632 .59589 L .70519 .59302 L p .707 .577 .707 r
F P
0 g
s
.73632 .59589 m .73213 .65321 L .76386 .65524 L p .707 .577 .707 r
F P
0 g
s
.76386 .65524 m .76806 .59792 L .73632 .59589 L p .707 .577 .707 r
F P
0 g
s
.20852 .71895 m .209 .73711 L .18497 .74459 L p .707 .577 .707 r
F P
0 g
s
.76806 .59792 m .76386 .65524 L .79308 .65623 L p .707 .577 .707 r
F P
0 g
s
.79308 .65623 m .79728 .59891 L .76806 .59792 L p .707 .577 .707 r
F P
0 g
s
.70519 .59302 m .70099 .65034 L .73213 .65321 L p .707 .577 .707 r
F P
0 g
s
.70099 .65034 m .70519 .59302 L .67769 .58959 L p .707 .577 .707 r
F P
0 g
s
.73226 .68754 m .73323 .64992 L .70206 .64768 L p .707 .577 .707 r
F P
0 g
s
.73323 .64992 m .73226 .68754 L .76408 .68772 L p .707 .577 .707 r
F P
0 g
s
.76408 .68772 m .76505 .6501 L .73323 .64992 L p .707 .577 .707 r
F P
0 g
s
.32833 .71869 m .32882 .73685 L .30135 .73214 L p .707 .577 .707 r
F P
0 g
s
.30135 .73214 m .30087 .71397 L .32833 .71869 L p .707 .577 .707 r
F P
0 g
s
.76505 .6501 m .76408 .68772 L .79344 .68583 L p .707 .577 .707 r
F P
0 g
s
.79728 .59891 m .79308 .65623 L .81693 .65609 L p .707 .577 .707 r
F P
0 g
s
.79344 .68583 m .79441 .64821 L .76505 .6501 L p .707 .577 .707 r
F P
0 g
s
.59217 .25294 m .59037 .75602 L .5516 .74989 L p .707 .577 .707 r
F P
0 g
s
.5516 .74989 m .55341 .24681 L .59217 .25294 L p .707 .577 .707 r
F P
0 g
s
.67769 .58959 m .6735 .64692 L .70099 .65034 L p .707 .577 .707 r
F P
0 g
s
.70109 .68531 m .70206 .64768 L .6746 .64362 L p .707 .577 .707 r
F P
0 g
s
.70206 .64768 m .70109 .68531 L .73226 .68754 L p .707 .577 .707 r
F P
0 g
s
.23457 .71228 m .2336 .7499 L .20424 .75179 L p .707 .577 .707 r
F P
0 g
s
.29756 .7147 m .29659 .75232 L .26542 .75009 L p .707 .577 .707 r
F P
0 g
s
.26542 .75009 m .26639 .71247 L .29756 .7147 L p .707 .577 .707 r
F P
0 g
s
.81693 .65609 m .82112 .59877 L .79728 .59891 L p .707 .577 .707 r
F P
0 g
s
.2336 .7499 m .23457 .71228 L .26639 .71247 L p .707 .577 .707 r
F P
0 g
s
.209 .73711 m .20852 .71895 L .23788 .71411 L p .707 .577 .707 r
F P
0 g
s
.42117 .75254 m .42298 .24946 L .46446 .24497 L p .707 .577 .707 r
F P
0 g
s
.42298 .24946 m .42117 .75254 L .38722 .76015 L p .707 .577 .707 r
F P
0 g
s
.6746 .64362 m .67363 .68124 L .70109 .68531 L p .707 .577 .707 r
F P
0 g
s
.26639 .71247 m .26542 .75009 L .2336 .7499 L p .707 .577 .707 r
F P
0 g
s
.79441 .64821 m .79344 .68583 L .81747 .68206 L p .707 .577 .707 r
F P
0 g
s
.82112 .59877 m .81693 .65609 L .83307 .65483 L p .707 .577 .707 r
F P
0 g
s
.81747 .68206 m .81844 .64444 L .79441 .64821 L p .707 .577 .707 r
F P
0 g
s
.6735 .64692 m .67769 .58959 L .65653 .58595 L p .707 .577 .707 r
F P
0 g
s
.23788 .71411 m .23836 .73227 L .209 .73711 L p .707 .577 .707 r
F P
0 g
s
.30087 .71397 m .30135 .73214 L .27019 .73056 L p .707 .577 .707 r
F P
0 g
s
.27019 .73056 m .2697 .7124 L .30087 .71397 L p .707 .577 .707 r
F P
0 g
s
.65653 .58595 m .65234 .64327 L .6735 .64692 L p .707 .577 .707 r
F P
0 g
s
.23836 .73227 m .23788 .71411 L .2697 .7124 L p .707 .577 .707 r
F P
0 g
s
.67363 .68124 m .6746 .64362 L .65353 .63813 L p .707 .577 .707 r
F P
0 g
s
.2697 .7124 m .27019 .73056 L .23836 .73227 L p .707 .577 .707 r
F P
0 g
s
.55341 .24681 m .5516 .74989 L .5076 .74714 L p .707 .577 .707 r
F P
0 g
s
.5076 .74714 m .5094 .24406 L .55341 .24681 L p .707 .577 .707 r
F P
0 g
s
.83307 .65483 m .83727 .59751 L .82112 .59877 L p .707 .577 .707 r
F P
0 g
s
.65353 .63813 m .65256 .67575 L .67363 .68124 L p .707 .577 .707 r
F P
0 g
s
.46265 .74805 m .46446 .24497 L .5094 .24406 L p .707 .577 .707 r
F P
0 g
s
.46446 .24497 m .46265 .74805 L .42117 .75254 L p .707 .577 .707 r
F P
0 g
s
.5094 .24406 m .5076 .74714 L .46265 .74805 L p .707 .577 .707 r
F P
0 g
s
.81844 .64444 m .81747 .68206 L .83381 .67678 L p .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84184 .63288 L .84141 .63326 L p .707 .577 .707 r
F P
0 g
s
.84141 .63326 m .83478 .63916 L p .83943 .66309 L .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84141 .63326 L .83943 .66309 L .707 .577 .707 r
F
.83727 .59751 m .83509 .62724 L p .83993 .65257 L F P
0 g
s
.83381 .67678 m .83478 .63916 L .83438 .63929 L p .707 .577 .707 r
F P
0 g
s
.83381 .67678 m .83438 .63929 L .83234 .67367 L .707 .577 .707 r
F
.83478 .63916 m .83381 .67678 L .84087 .6705 L p F P
0 g
s
.83346 .6547 m .83993 .65257 L p .83509 .62724 L .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .8421 .62296 L p .83727 .59751 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .84412 .59525 L .84298 .59562 L p .707 .577 .707 r
F P
0 g
s
.84298 .59562 m .83727 .59751 L p .8421 .62296 L .707 .577 .707 r
F P
0 g
s
.84184 .63288 m .84087 .6705 L .84058 .66984 L p .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .83683 .64953 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .83993 .65257 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.84058 .66984 m .83795 .66384 L p .84175 .63357 L .707 .577 .707 r
F P
0 g
s
.84175 .63357 m .84184 .63288 L .84058 .66984 L .707 .577 .707 r
F
.84412 .59525 m .8421 .62296 L p .84375 .598 L F P
0 g
s
.83509 .62724 m .83307 .65483 L .83346 .6547 L p .707 .577 .707 r
F P
0 g
s
.83438 .63929 m .81844 .64444 L p .83234 .67367 L .707 .577 .707 r
F P
0 g
s
.65234 .64327 m .65653 .58595 L .64378 .58243 L p .707 .577 .707 r
F P
0 g
s
.73702 .78439 m .73653 .76623 L .70537 .76465 L p .707 .577 .707 r
F P
0 g
s
.73653 .76623 m .73702 .78439 L .76884 .78268 L p .707 .577 .707 r
F P
0 g
s
.76884 .78268 m .76836 .76451 L .73653 .76623 L p .707 .577 .707 r
F P
0 g
s
.76836 .76451 m .76884 .78268 L .7982 .77784 L p .707 .577 .707 r
F P
0 g
s
.7982 .77784 m .79772 .75968 L .76836 .76451 L p .707 .577 .707 r
F P
0 g
s
.64378 .58243 m .63958 .63976 L .65234 .64327 L p .707 .577 .707 r
F P
0 g
s
.65256 .67575 m .65353 .63813 L .64092 .63174 L p .707 .577 .707 r
F P
0 g
s
.70537 .76465 m .70585 .78281 L .73702 .78439 L p .707 .577 .707 r
F P
0 g
s
.70585 .78281 m .70537 .76465 L .6779 .75993 L p .707 .577 .707 r
F P
0 g
s
.64092 .63174 m .63995 .66936 L .65256 .67575 L p .707 .577 .707 r
F P
0 g
s
.6779 .75993 m .67839 .7781 L .70585 .78281 L p .707 .577 .707 r
F P
0 g
s
.79772 .75968 m .7982 .77784 L .82223 .77035 L p .707 .577 .707 r
F P
0 g
s
.82223 .77035 m .82175 .75219 L .79772 .75968 L p .707 .577 .707 r
F P
0 g
s
.67839 .7781 m .6779 .75993 L .65684 .75254 L p .707 .577 .707 r
F P
0 g
s
.63958 .63976 m .64378 .58243 L .64068 .5794 L p .707 .577 .707 r
F P
0 g
s
.65684 .75254 m .65732 .77071 L .67839 .7781 L p .707 .577 .707 r
F P
0 g
s
.64068 .5794 m .63648 .63672 L .63958 .63976 L p .707 .577 .707 r
F P
0 g
s
.63995 .66936 m .64092 .63174 L .638 .62507 L p .707 .577 .707 r
F P
0 g
s
.82175 .75219 m .82223 .77035 L .83857 .76095 L p .707 .577 .707 r
F P
0 g
s
.83857 .76095 m .83809 .74279 L .82175 .75219 L p .707 .577 .707 r
F P
0 g
s
.638 .62507 m .63702 .66269 L .63995 .66936 L p .707 .577 .707 r
F P
0 g
s
.65732 .77071 m .65684 .75254 L .64422 .7432 L p .707 .577 .707 r
F P
0 g
s
.83683 .64953 m .83913 .6181 L p .84412 .59525 L .707 .577 .707 r
F P
0 g
s
.84102 .59221 m .83683 .64953 L .82407 .64602 L p .707 .577 .707 r
F P
0 g
s
.83892 .62622 m .83795 .66384 L .83449 .66209 L p .707 .577 .707 r
F P
0 g
s
.83449 .66209 m .82534 .65745 L p .83806 .62818 L .707 .577 .707 r
F P
0 g
s
.83806 .62818 m .83892 .62622 L .83449 .66209 L .707 .577 .707 r
F
.83913 .6181 m .84102 .59221 L .84178 .59295 L p F P
0 g
s
.84178 .59295 m .84412 .59525 L p .83913 .6181 L .707 .577 .707 r
F P
0 g
s
.64422 .7432 m .64471 .76136 L .65732 .77071 L p .707 .577 .707 r
F P
0 g
s
.83795 .66384 m .83892 .62622 L .84184 .63288 L p .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .638 .62507 L .64488 .61895 L p .707 .577 .707 r
F P
0 g
s
.64536 .60688 m .64753 .57714 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.64488 .61895 m .64505 .61879 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .64488 .61895 L .64483 .61998 L .707 .577 .707 r
F
.64753 .57714 m .66368 .57588 L p .64437 .63149 L F P
0 g
s
.66368 .57588 m .65948 .6332 L .64426 .63439 L p .707 .577 .707 r
F P
0 g
s
.64437 .63149 m .66368 .57588 L .64426 .63439 L .707 .577 .707 r
F
.64505 .61879 m .64408 .65642 L .64335 .65707 L p F P
0 g
s
.64335 .65707 m .63702 .66269 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.64483 .61998 m .64505 .61879 L .64335 .65707 L .707 .577 .707 r
F
.64426 .63439 m .64334 .63446 L p .64437 .63149 L F P
0 g
s
.64334 .63446 m .64536 .60688 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.63648 .63672 m .64068 .5794 L .64753 .57714 L p .707 .577 .707 r
F P
0 g
s
.83809 .74279 m .83857 .76095 L .84563 .75055 L p .707 .577 .707 r
F P
0 g
s
.84563 .75055 m .84515 .73239 L .83809 .74279 L p .707 .577 .707 r
F P
0 g
s
.64753 .57714 m .64334 .63446 L .63648 .63672 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64471 .76136 m .64422 .7432 L .6413 .73282 L p .707 .577 .707 r
F P
0 g
s
.6413 .73282 m .64179 .75098 L .64471 .76136 L p .707 .577 .707 r
F P
0 g
s
.82407 .64602 m .82648 .61313 L p .84102 .59221 L .707 .577 .707 r
F P
0 g
s
.82827 .5887 m .82407 .64602 L .80291 .64237 L p .707 .577 .707 r
F P
0 g
s
.82631 .61983 m .82534 .65745 L .81662 .65517 L p .707 .577 .707 r
F P
0 g
s
.81662 .65517 m .80427 .65195 L p .82418 .62292 L .707 .577 .707 r
F P
0 g
s
.82418 .62292 m .82631 .61983 L .81662 .65517 L .707 .577 .707 r
F
.82648 .61313 m .82827 .5887 L .83197 .58972 L p F P
0 g
s
.83197 .58972 m .84102 .59221 L p .82648 .61313 L .707 .577 .707 r
F P
0 g
s
.82534 .65745 m .82631 .61983 L .83892 .62622 L p .707 .577 .707 r
F P
0 g
s
.38912 .61639 m .39331 .55907 L .36218 .5562 L p .707 .577 .707 r
F P
0 g
s
.39331 .55907 m .38912 .61639 L .42085 .61842 L p .707 .577 .707 r
F P
0 g
s
.42085 .61842 m .42505 .5611 L .39331 .55907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42505 .5611 m .42085 .61842 L .45007 .61941 L p .707 .577 .707 r
F P
0 g
s
.45007 .61941 m .45427 .56209 L .42505 .5611 L p .707 .577 .707 r
F P
0 g
s
.84515 .73239 m .84563 .75055 L .84271 .74017 L p .707 .577 .707 r
F P
0 g
s
.84271 .74017 m .84223 .72201 L .84515 .73239 L p .707 .577 .707 r
F P
0 g
s
.36218 .5562 m .35798 .61352 L .38912 .61639 L p .707 .577 .707 r
F P
0 g
s
.35798 .61352 m .36218 .5562 L .33468 .55278 L p .707 .577 .707 r
F P
0 g
s
.38925 .65072 m .39022 .6131 L .35905 .61087 L p .707 .577 .707 r
F P
0 g
s
.39022 .6131 m .38925 .65072 L .42107 .6509 L p .707 .577 .707 r
F P
0 g
s
.42107 .6509 m .42204 .61328 L .39022 .6131 L p .707 .577 .707 r
F P
0 g
s
.42204 .61328 m .42107 .6509 L .45043 .64902 L p .707 .577 .707 r
F P
0 g
s
.45427 .56209 m .45007 .61941 L .47392 .61927 L p .707 .577 .707 r
F P
0 g
s
.45043 .64902 m .4514 .6114 L .42204 .61328 L p .707 .577 .707 r
F P
0 g
s
.65948 .6332 m .66165 .60359 L p .68753 .57574 L .707 .577 .707 r
F P
0 g
s
.66165 .60359 m .66368 .57588 L .66503 .57587 L p .707 .577 .707 r
F P
0 g
s
.66503 .57587 m .68753 .57574 L p .66165 .60359 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .64505 .61879 L .6604 .61383 L p .707 .577 .707 r
F P
0 g
s
.6604 .61383 m .66139 .61351 L p .66003 .6169 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .6604 .61383 L .66003 .6169 L .707 .577 .707 r
F
.33468 .55278 m .33049 .6101 L .35798 .61352 L p F P
0 g
s
.35808 .64849 m .35905 .61087 L .33159 .60681 L p .707 .577 .707 r
F P
0 g
s
.35905 .61087 m .35808 .64849 L .38925 .65072 L p .707 .577 .707 r
F P
0 g
s
.47392 .61927 m .47811 .56195 L .45427 .56209 L p .707 .577 .707 r
F P
0 g
s
.68753 .57574 m .68333 .63306 L .65948 .6332 L p .707 .577 .707 r
F P
0 g
s
.66139 .61351 m .66042 .65113 L .64408 .65642 L p .707 .577 .707 r
F P
0 g
s
.64179 .75098 m .6413 .73282 L .64836 .72242 L p .707 .577 .707 r
F P
0 g
s
.33159 .60681 m .33062 .64443 L .35808 .64849 L p .707 .577 .707 r
F P
0 g
s
.4514 .6114 m .45043 .64902 L .47446 .64525 L p .707 .577 .707 r
F P
0 g
s
.47811 .56195 m .47392 .61927 L .49006 .61801 L p .707 .577 .707 r
F P
0 g
s
.47446 .64525 m .47543 .60763 L .4514 .6114 L p .707 .577 .707 r
F P
0 g
s
.33049 .6101 m .33468 .55278 L .31352 .54913 L p .707 .577 .707 r
F P
0 g
s
.80291 .64237 m .80539 .60856 L p .82827 .5887 L .707 .577 .707 r
F P
0 g
s
.80711 .58505 m .80291 .64237 L .77542 .63895 L p .707 .577 .707 r
F P
0 g
s
.80524 .61433 m .80427 .65195 L .79018 .64987 L p .707 .577 .707 r
F P
0 g
s
.79018 .64987 m .77681 .64789 L p .80174 .61846 L .707 .577 .707 r
F P
0 g
s
.80174 .61846 m .80524 .61433 L .79018 .64987 L .707 .577 .707 r
F
.80539 .60856 m .80711 .58505 L .81363 .58618 L p F P
0 g
s
.81363 .58618 m .82827 .5887 L p .80539 .60856 L .707 .577 .707 r
F P
0 g
s
.64836 .72242 m .64884 .74058 L .64179 .75098 L p .707 .577 .707 r
F P
0 g
s
.31352 .54913 m .30933 .60645 L .33049 .6101 L p .707 .577 .707 r
F P
0 g
s
.80427 .65195 m .80524 .61433 L .82631 .61983 L p .707 .577 .707 r
F P
0 g
s
.33062 .64443 m .33159 .60681 L .31052 .60131 L p .707 .577 .707 r
F P
0 g
s
.84223 .72201 m .84271 .74017 L .8301 .73083 L p .707 .577 .707 r
F P
0 g
s
.8301 .73083 m .82962 .71266 L .84223 .72201 L p .707 .577 .707 r
F P
0 g
s
.49006 .61801 m .49426 .56069 L .47811 .56195 L p .707 .577 .707 r
F P
0 g
s
.31052 .60131 m .30955 .63893 L .33062 .64443 L p .707 .577 .707 r
F P
0 g
s
.68333 .63306 m .68563 .60162 L p .71675 .57673 L .707 .577 .707 r
F P
0 g
s
.68563 .60162 m .68753 .57574 L .69199 .57589 L p .707 .577 .707 r
F P
0 g
s
.69199 .57589 m .71675 .57673 L p .68563 .60162 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .66139 .61351 L .68355 .61004 L p .707 .577 .707 r
F P
0 g
s
.68355 .61004 m .68542 .60974 L p .68238 .61478 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .68355 .61004 L .68238 .61478 L .707 .577 .707 r
F
.47543 .60763 m .47446 .64525 L .4908 .63996 L p F P
0 g
s
.49786 .63368 m .49883 .59606 L .4984 .59645 L p .707 .577 .707 r
F P
0 g
s
.4984 .59645 m .49177 .60234 L p .49642 .62627 L .707 .577 .707 r
F P
0 g
s
.49786 .63368 m .4984 .59645 L .49642 .62627 L .707 .577 .707 r
F
.49426 .56069 m .49208 .59043 L p .49692 .61575 L F P
0 g
s
.4908 .63996 m .49177 .60234 L .49137 .60248 L p .707 .577 .707 r
F P
0 g
s
.4908 .63996 m .49137 .60248 L .48933 .63686 L .707 .577 .707 r
F
.49177 .60234 m .4908 .63996 L .49786 .63368 L p F P
0 g
s
.49045 .61788 m .49692 .61575 L p .49208 .59043 L .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49908 .58614 L p .49426 .56069 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .50111 .55843 L .49997 .55881 L p .707 .577 .707 r
F P
0 g
s
.49997 .55881 m .49426 .56069 L p .49908 .58614 L .707 .577 .707 r
F P
0 g
s
.49883 .59606 m .49786 .63368 L .49757 .63303 L p .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49382 .61272 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .49692 .61575 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49757 .63303 m .49494 .62702 L p .49874 .59676 L .707 .577 .707 r
F P
0 g
s
.49874 .59676 m .49883 .59606 L .49757 .63303 L .707 .577 .707 r
F
.50111 .55843 m .49908 .58614 L p .50074 .56118 L F P
0 g
s
.49208 .59043 m .49006 .61801 L .49045 .61788 L p .707 .577 .707 r
F P
0 g
s
.49137 .60248 m .47543 .60763 L p .48933 .63686 L .707 .577 .707 r
F P
0 g
s
.71675 .57673 m .71255 .63405 L .68333 .63306 L p .707 .577 .707 r
F P
0 g
s
.68542 .60974 m .68445 .64736 L .66042 .65113 L p .707 .577 .707 r
F P
0 g
s
.30933 .60645 m .31352 .54913 L .30077 .54562 L p .707 .577 .707 r
F P
0 g
s
.39401 .74757 m .39352 .72941 L .36236 .72783 L p .707 .577 .707 r
F P
0 g
s
.39352 .72941 m .39401 .74757 L .42583 .74586 L p .707 .577 .707 r
F P
0 g
s
.42583 .74586 m .42535 .7277 L .39352 .72941 L p .707 .577 .707 r
F P
0 g
s
.77542 .63895 m .77792 .60481 L p .80711 .58505 L .707 .577 .707 r
F P
0 g
s
.77961 .58163 m .77542 .63895 L .74428 .63608 L p .707 .577 .707 r
F P
0 g
s
.77778 .61027 m .77681 .64789 L .75907 .64662 L p .707 .577 .707 r
F P
0 g
s
.75907 .64662 m .74564 .64566 L p .77317 .61534 L .707 .577 .707 r
F P
0 g
s
.77317 .61534 m .77778 .61027 L .75907 .64662 L .707 .577 .707 r
F
.77792 .60481 m .77961 .58163 L .7879 .58266 L p F P
0 g
s
.7879 .58266 m .80711 .58505 L p .77792 .60481 L .707 .577 .707 r
F P
0 g
s
.64884 .74058 m .64836 .72242 L .6647 .71302 L p .707 .577 .707 r
F P
0 g
s
.42535 .7277 m .42583 .74586 L .45519 .74102 L p .707 .577 .707 r
F P
0 g
s
.45519 .74102 m .45471 .72286 L .42535 .7277 L p .707 .577 .707 r
F P
0 g
s
.30077 .54562 m .29657 .60294 L .30933 .60645 L p .707 .577 .707 r
F P
0 g
s
.77681 .64789 m .77778 .61027 L .80524 .61433 L p .707 .577 .707 r
F P
0 g
s
.30955 .63893 m .31052 .60131 L .29791 .59492 L p .707 .577 .707 r
F P
0 g
s
.36236 .72783 m .36284 .746 L .39401 .74757 L p .707 .577 .707 r
F P
0 g
s
.36284 .746 m .36236 .72783 L .33489 .72312 L p .707 .577 .707 r
F P
0 g
s
.6647 .71302 m .66518 .73118 L .64884 .74058 L p .707 .577 .707 r
F P
0 g
s
.71255 .63405 m .71496 .60116 L p .74848 .57876 L .707 .577 .707 r
F P
0 g
s
.71496 .60116 m .71675 .57673 L .72387 .57719 L p .707 .577 .707 r
F P
0 g
s
.72387 .57719 m .74848 .57876 L p .71496 .60116 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .68542 .60974 L .71241 .60801 L p .707 .577 .707 r
F P
0 g
s
.71241 .60801 m .71478 .60786 L p .7103 .6137 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .71241 .60801 L .7103 .6137 L .707 .577 .707 r
F
.29791 .59492 m .29693 .63254 L .30955 .63893 L p F P
0 g
s
.33489 .72312 m .33538 .74128 L .36284 .746 L p .707 .577 .707 r
F P
0 g
s
.45471 .72286 m .45519 .74102 L .47922 .73354 L p .707 .577 .707 r
F P
0 g
s
.47922 .73354 m .47874 .71538 L .45471 .72286 L p .707 .577 .707 r
F P
0 g
s
.82962 .71266 m .8301 .73083 L .80903 .72344 L p .707 .577 .707 r
F P
0 g
s
.80903 .72344 m .80855 .70527 L .82962 .71266 L p .707 .577 .707 r
F P
0 g
s
.74848 .57876 m .74428 .63608 L .71255 .63405 L p .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .71478 .60786 L .74416 .60802 L p .707 .577 .707 r
F P
0 g
s
.74428 .63608 m .74676 .60226 L p .77961 .58163 L .707 .577 .707 r
F P
0 g
s
.74416 .60802 m .74661 .60804 L p .74156 .61381 L .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .74416 .60802 L .74156 .61381 L .707 .577 .707 r
F
.74676 .60226 m .74848 .57876 L .75699 .57955 L p F P
0 g
s
.75699 .57955 m .77961 .58163 L p .74676 .60226 L .707 .577 .707 r
F P
0 g
s
.71478 .60786 m .71381 .64548 L .68445 .64736 L p .707 .577 .707 r
F P
0 g
s
.74564 .64566 m .74661 .60804 L .77778 .61027 L p .707 .577 .707 r
F P
0 g
s
.33538 .74128 m .33489 .72312 L .31383 .71573 L p .707 .577 .707 r
F P
0 g
s
.74661 .60804 m .74564 .64566 L .71381 .64548 L p .707 .577 .707 r
F P
0 g
s
.66518 .73118 m .6647 .71302 L .68873 .70553 L p .707 .577 .707 r
F P
0 g
s
.29657 .60294 m .30077 .54562 L .29767 .54258 L p .707 .577 .707 r
F P
0 g
s
.31383 .71573 m .31431 .73389 L .33538 .74128 L p .707 .577 .707 r
F P
0 g
s
.29767 .54258 m .29347 .59991 L .29657 .60294 L p .707 .577 .707 r
F P
0 g
s
.68873 .70553 m .68921 .72369 L .66518 .73118 L p .707 .577 .707 r
F P
0 g
s
.29693 .63254 m .29791 .59492 L .29498 .58826 L p .707 .577 .707 r
F P
0 g
s
.47874 .71538 m .47922 .73354 L .49556 .72413 L p .707 .577 .707 r
F P
0 g
s
.49556 .72413 m .49508 .70597 L .47874 .71538 L p .707 .577 .707 r
F P
0 g
s
.80855 .70527 m .80903 .72344 L .78157 .71872 L p .707 .577 .707 r
F P
0 g
s
.78157 .71872 m .78109 .70056 L .80855 .70527 L p .707 .577 .707 r
F P
0 g
s
.29498 .58826 m .29401 .62588 L .29693 .63254 L p .707 .577 .707 r
F P
0 g
s
.31431 .73389 m .31383 .71573 L .30121 .70639 L p .707 .577 .707 r
F P
0 g
s
.68921 .72369 m .68873 .70553 L .71809 .70069 L p .707 .577 .707 r
F P
0 g
s
.49382 .61272 m .49612 .58128 L p .50111 .55843 L .707 .577 .707 r
F P
0 g
s
.49801 .5554 m .49382 .61272 L .48106 .60921 L p .707 .577 .707 r
F P
0 g
s
.49591 .5894 m .49494 .62702 L .49148 .62527 L p .707 .577 .707 r
F P
0 g
s
.49148 .62527 m .48233 .62063 L p .49505 .59137 L .707 .577 .707 r
F P
0 g
s
.49505 .59137 m .49591 .5894 L .49148 .62527 L .707 .577 .707 r
F
.49612 .58128 m .49801 .5554 L .49877 .55614 L p F P
0 g
s
.49877 .55614 m .50111 .55843 L p .49612 .58128 L .707 .577 .707 r
F P
0 g
s
.30121 .70639 m .3017 .72455 L .31431 .73389 L p .707 .577 .707 r
F P
0 g
s
.71809 .70069 m .71858 .71886 L .68921 .72369 L p .707 .577 .707 r
F P
0 g
s
.49494 .62702 m .49591 .5894 L .49883 .59606 L p .707 .577 .707 r
F P
0 g
s
.78109 .70056 m .78157 .71872 L .7504 .71714 L p .707 .577 .707 r
F P
0 g
s
.7504 .71714 m .74992 .69898 L .78109 .70056 L p .707 .577 .707 r
F P
0 g
s
.71858 .71886 m .71809 .70069 L .74992 .69898 L p .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .29498 .58826 L .30186 .58214 L p .707 .577 .707 r
F P
0 g
s
.30235 .57006 m .30452 .54033 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.30186 .58214 m .30204 .58198 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .30186 .58214 L .30182 .58317 L .707 .577 .707 r
F
.30452 .54033 m .32067 .53906 L p .30136 .59467 L F P
0 g
s
.32067 .53906 m .31647 .59639 L .30125 .59758 L p .707 .577 .707 r
F P
0 g
s
.30136 .59467 m .32067 .53906 L .30125 .59758 L .707 .577 .707 r
F
.30204 .58198 m .30107 .6196 L .30034 .62025 L p F P
0 g
s
.30034 .62025 m .29401 .62588 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.30182 .58317 m .30204 .58198 L .30034 .62025 L .707 .577 .707 r
F
.30125 .59758 m .30033 .59765 L p .30136 .59467 L F P
0 g
s
.30033 .59765 m .30235 .57006 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.29347 .59991 m .29767 .54258 L .30452 .54033 L p .707 .577 .707 r
F P
0 g
s
.49508 .70597 m .49556 .72413 L .50262 .71373 L p .707 .577 .707 r
F P
0 g
s
.50262 .71373 m .50214 .69557 L .49508 .70597 L p .707 .577 .707 r
F P
0 g
s
.74992 .69898 m .7504 .71714 L .71858 .71886 L p .707 .577 .707 r
F P
0 g
s
.30452 .54033 m .30033 .59765 L .29347 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3017 .72455 m .30121 .70639 L .29829 .69601 L p .707 .577 .707 r
F P
0 g
s
.29829 .69601 m .29878 .71417 L .3017 .72455 L p .707 .577 .707 r
F P
0 g
s
.48106 .60921 m .48347 .57632 L p .49801 .5554 L .707 .577 .707 r
F P
0 g
s
.48526 .55189 m .48106 .60921 L .4599 .60556 L p .707 .577 .707 r
F P
0 g
s
.4833 .58301 m .48233 .62063 L .47361 .61836 L p .707 .577 .707 r
F P
0 g
s
.47361 .61836 m .46126 .61514 L p .48117 .5861 L .707 .577 .707 r
F P
0 g
s
.48117 .5861 m .4833 .58301 L .47361 .61836 L .707 .577 .707 r
F
.48347 .57632 m .48526 .55189 L .48896 .55291 L p F P
0 g
s
.48896 .55291 m .49801 .5554 L p .48347 .57632 L .707 .577 .707 r
F P
0 g
s
.48233 .62063 m .4833 .58301 L .49591 .5894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50214 .69557 m .50262 .71373 L .4997 .70335 L p .707 .577 .707 r
F P
0 g
s
.4997 .70335 m .49922 .68519 L .50214 .69557 L p .707 .577 .707 r
F P
0 g
s
.31647 .59639 m .31864 .56678 L p .34451 .53892 L .707 .577 .707 r
F P
0 g
s
.31864 .56678 m .32067 .53906 L .32202 .53906 L p .707 .577 .707 r
F P
0 g
s
.32202 .53906 m .34451 .53892 L p .31864 .56678 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .30204 .58198 L .31739 .57702 L p .707 .577 .707 r
F P
0 g
s
.31739 .57702 m .31838 .5767 L p .31702 .58008 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .31739 .57702 L .31702 .58008 L .707 .577 .707 r
F
.34451 .53892 m .34032 .59624 L .31647 .59639 L p F P
0 g
s
.31838 .5767 m .31741 .61432 L .30107 .6196 L p .707 .577 .707 r
F P
0 g
s
.29878 .71417 m .29829 .69601 L .30535 .68561 L p .707 .577 .707 r
F P
0 g
s
.4599 .60556 m .46238 .57174 L p .48526 .55189 L .707 .577 .707 r
F P
0 g
s
.4641 .54824 m .4599 .60556 L .43241 .60213 L p .707 .577 .707 r
F P
0 g
s
.46223 .57752 m .46126 .61514 L .44717 .61305 L p .707 .577 .707 r
F P
0 g
s
.44717 .61305 m .43379 .61107 L p .45873 .58164 L .707 .577 .707 r
F P
0 g
s
.45873 .58164 m .46223 .57752 L .44717 .61305 L .707 .577 .707 r
F
.46238 .57174 m .4641 .54824 L .47062 .54936 L p F P
0 g
s
.47062 .54936 m .48526 .55189 L p .46238 .57174 L .707 .577 .707 r
F P
0 g
s
.30535 .68561 m .30583 .70377 L .29878 .71417 L p .707 .577 .707 r
F P
0 g
s
.46126 .61514 m .46223 .57752 L .4833 .58301 L p .707 .577 .707 r
F P
0 g
s
.49922 .68519 m .4997 .70335 L .48709 .69401 L p .707 .577 .707 r
F P
0 g
s
.48709 .69401 m .48661 .67585 L .49922 .68519 L p .707 .577 .707 r
F P
0 g
s
.34032 .59624 m .34262 .56481 L p .37373 .53992 L .707 .577 .707 r
F P
0 g
s
.34262 .56481 m .34451 .53892 L .34898 .53907 L p .707 .577 .707 r
F P
0 g
s
.34898 .53907 m .37373 .53992 L p .34262 .56481 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .31838 .5767 L .34054 .57322 L p .707 .577 .707 r
F P
0 g
s
.34054 .57322 m .34241 .57293 L p .33937 .57796 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .34054 .57322 L .33937 .57796 L .707 .577 .707 r
F
.37373 .53992 m .36954 .59724 L .34032 .59624 L p F P
0 g
s
.34241 .57293 m .34144 .61055 L .31741 .61432 L p .707 .577 .707 r
F P
0 g
s
.43241 .60213 m .43491 .56799 L p .4641 .54824 L .707 .577 .707 r
F P
0 g
s
.4366 .54481 m .43241 .60213 L .40127 .59927 L p .707 .577 .707 r
F P
0 g
s
.43477 .57345 m .43379 .61107 L .41606 .6098 L p .707 .577 .707 r
F P
0 g
s
.41606 .6098 m .40263 .60884 L p .43016 .57853 L .707 .577 .707 r
F P
0 g
s
.43016 .57853 m .43477 .57345 L .41606 .6098 L .707 .577 .707 r
F
.43491 .56799 m .4366 .54481 L .44489 .54585 L p F P
0 g
s
.44489 .54585 m .4641 .54824 L p .43491 .56799 L .707 .577 .707 r
F P
0 g
s
.30583 .70377 m .30535 .68561 L .32169 .6762 L p .707 .577 .707 r
F P
0 g
s
.43379 .61107 m .43477 .57345 L .46223 .57752 L p .707 .577 .707 r
F P
0 g
s
.32169 .6762 m .32217 .69436 L .30583 .70377 L p .707 .577 .707 r
F P
0 g
s
.36954 .59724 m .37195 .56435 L p .40547 .54195 L .707 .577 .707 r
F P
0 g
s
.37195 .56435 m .37373 .53992 L .38086 .54037 L p .707 .577 .707 r
F P
0 g
s
.38086 .54037 m .40547 .54195 L p .37195 .56435 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .34241 .57293 L .3694 .57119 L p .707 .577 .707 r
F P
0 g
s
.3694 .57119 m .37177 .57104 L p .36729 .57689 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .3694 .57119 L .36729 .57689 L .707 .577 .707 r
F
.48661 .67585 m .48709 .69401 L .46602 .68662 L p F P
0 g
s
.46602 .68662 m .46554 .66846 L .48661 .67585 L p .707 .577 .707 r
F P
0 g
s
.40547 .54195 m .40127 .59927 L .36954 .59724 L p .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .37177 .57104 L .40115 .57121 L p .707 .577 .707 r
F P
0 g
s
.40127 .59927 m .40375 .56545 L p .4366 .54481 L .707 .577 .707 r
F P
0 g
s
.40115 .57121 m .4036 .57122 L p .39855 .57699 L .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .40115 .57121 L .39855 .57699 L .707 .577 .707 r
F
.40375 .56545 m .40547 .54195 L .41398 .54273 L p F P
0 g
s
.41398 .54273 m .4366 .54481 L p .40375 .56545 L .707 .577 .707 r
F P
0 g
s
.37177 .57104 m .3708 .60866 L .34144 .61055 L p .707 .577 .707 r
F P
0 g
s
.40263 .60884 m .4036 .57122 L .43477 .57345 L p .707 .577 .707 r
F P
0 g
s
.4036 .57122 m .40263 .60884 L .3708 .60866 L p .707 .577 .707 r
F P
0 g
s
.32217 .69436 m .32169 .6762 L .34572 .66872 L p .707 .577 .707 r
F P
0 g
s
.34572 .66872 m .3462 .68688 L .32217 .69436 L p .707 .577 .707 r
F P
0 g
s
.46554 .66846 m .46602 .68662 L .43856 .6819 L p .707 .577 .707 r
F P
0 g
s
.43856 .6819 m .43808 .66374 L .46554 .66846 L p .707 .577 .707 r
F P
0 g
s
.3462 .68688 m .34572 .66872 L .37508 .66388 L p .707 .577 .707 r
F P
0 g
s
.37508 .66388 m .37557 .68204 L .3462 .68688 L p .707 .577 .707 r
F P
0 g
s
.43808 .66374 m .43856 .6819 L .40739 .68033 L p .707 .577 .707 r
F P
0 g
s
.40739 .68033 m .40691 .66217 L .43808 .66374 L p .707 .577 .707 r
F P
0 g
s
.37557 .68204 m .37508 .66388 L .40691 .66217 L p .707 .577 .707 r
F P
0 g
s
.40691 .66217 m .40739 .68033 L .37557 .68204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005IooaX000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0`002UYF00<005YFFUH0
1UYF00<005YFFUH00eYF3@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH0000:FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol005Aoo`03001JEP0000YJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF1@000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0P0015YF00<005YFFUH0
0eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001COol00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005=oo`03001JEP0000AJEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool=001EOol005=oo`03001JEP00009JEPH000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUIJEP04
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600000eYF001J
EP05FUH00`00FUIJEP02FUHB0013Ool005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH8000kOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP00
02eoo`00;goo6@002goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP80
00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF0P000UYF20000eYF0P001eYF0P0015YF20000eYF0P0015YF0P000UYF0P00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH60007FUH01000FUIJEUYF4P0000=JEP0000001P0015YF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEPD000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH20002FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF001JEUYF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP05001JEUYFFUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00
0000;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<0
02eoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4`000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00UYF200035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00@005YFFUIJER<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP0B0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH50004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF0P00;Goo
000/Ool00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo1@001EYF00<005YFFUH0
1EYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEP0001@000EJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP03001JEUYF00D0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000]Ool002moo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000]Ool003=oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool003Yoo`T000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00@goo2@0015YF00<005YF
FUH01EYF0P0000=JEP00FUH01EYF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1`0015YF00<0
05YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF1000<Woo001<Ool<0003FUH00`00
FUIJEP04FUH00`00FUIJEP040005FUH50004FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Woo001EOol20004FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP08
FUH40004FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000AooaL003Yoo`00EGoo0P0015YF
00<005YF00000`000goo00@005YFFUH000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001DOol00`00FUH00004FUH20007Ool01000
FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P000UYF0P0000=JEP00FUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YF
FUIJEP0005Eoo`00E7oo00<005YF00000UYF0P002Goo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00EJEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000Uoo`T004=oo`00E7oo
00<005YF00000P002goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00=JEP03001JEUYF00/000AJEP03001JEUYF009JEPP003]oo`00E7oo00<005YF0000
3Goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00IJEP05001JEP00
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0003FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=Woo001DOol3000=Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF0P0000AJEP00FUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000cOol003mooa8000=o
o`800003FUH0000000]oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH200001UYF001JEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000aOol003Moo`P00003FUH0000000H000AJEP03001JEUYF009J
EPD000=JEP8000Uoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF
0P000eYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P00<7oo000bOol50003FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH000030005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF100000=JEP00
FUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH01EYF00<005YFFUH00UYF3@001Goo20000eYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Woo100000AJEP00FUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEUYFFUH00004FUH500001Goo001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF
1P001EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF009JEPH000Qoo`D000eoo`D000AJEP05001J
EUYFFUH0000]Ool002eoo`8000AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF2@0015YF00<005YF
FUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEP00008000ioo`D0019oo`<00003FUH005YF009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF0`0000=J
EP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJ
EP80019oo`<001Ioo`8000=JEP8002aoo`00;7oo00@005YF001JEP80009JEP03001JEUYF00AJEP03
001JEUYF009JEPP000=JEP03001JEUYF00=JEPX000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH2000_Ool00`00FUIJEP02000/
Ool002aoo`04001JEP000004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000015YF00000000<Woo1000;7oo000/Ool01000FUH0000015YF00<005YF00001000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00Ool0=Goo0P00;7oo000/Ool01000FUH00000
15YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00=Goo
1000;7oo000/Ool01000FUH000000UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00005`000UYF60001UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF1@00<Goo0P0000AJEP00FUH002aoo`00;7oo00<005YF
00000`0000=JEP00FUH00UYF7`001UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF2@002eYF00<005YFFUH02EYF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000UYF00<007ooOol0:goo0`000eYF00<005YF0000;7oo000/Ool01000FUH000000eYF1@001eYF
00@005YFFUIJEQL0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF
009JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001JEUYF
009JEP<0009JEPH002Ioo`800003FUH005YF00=JEP8002eoo`00;7oo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1P000eYF00<005YF
00000UYF00<005YFFUH015YF00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P0000AJ
EP000000025oo`8000=JEP03001JEUYF009JEP8002eoo`00;7oo00<005YF00000`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000EJ
EP00FUIJEP0000EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP<00003FUH005YF00=JEP<0009JEP03001JEUYF009JEPH001Yoo`D0
00EJEP03001JEUYF009JEP03001oogoo02aoo`00;7oo0`000UYF0`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YF0000
0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00@005YF000000AJEP@00003FUH005YF00AJEP04001JEUYFFUHK0003FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool002aoo`<000=JEP03001JEP00008000QJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00005FUH005YFFUH00002FUH200000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF1P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo000/Ool30003FUH00`00FUIJEP02FUH30004FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH40005FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP@000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8003=oo`00;Goo0P000eYF00<005YFFUH00eYF00<0
05YF0000100025YF1@0015YF00@005YFFUIJEP@0009JEP03001JEUYF00AJEP03001JEUYF008000AJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000eOol002moo`800003FUH005YF
00AJEP03001JEUYF00=JEQH000IJEP03001JEUYF00AJEPD000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP000006FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH5000iOol0035oo`8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001J
EUYF00IJEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006
FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP02FUH9000nOol003=oo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEP0000D0009oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH01@00FUH00000FUH00P000goo
2@00Agoo000eOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`00Dgoo000gOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000<Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH6
0004FUH01000FUIJEUYF0`00Dgoo000lOolI000AOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP02FUH300000eYF001JEP02FUH3001COol006Qoo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP<005=oo`00JWoo0P001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP8000MJEP03001JEUYF00AJEP80009JEP@005Aoo`00K7oo0`0015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0007FUH0
0`00FUIJEP0400000eYF001JEP03FUH2001DOol006moo`<00003FUH005YF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD000=JEP03001JEUYF00=JEPD000EJ
EP03001JEUYF00=JEP03001oogoo059oo`00LWoo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH0200000=JEP0000001`000eYF00<005YFFUH015YF00@005YFFUIJ
EP8005Eoo`00NGoo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF4@0015YF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000P00EWoo0024OolJ0003FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH4001HOol009Eoo`<00003FUH005YF00IJEP03001JEUYF00IJEP<0
00IJEP03001JEUYF00EJEP03001JEP0000D005Yoo`00V7oo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00Ggoo002MOol90004FUH00`00FUIJEP02FUH9001UOol00:Ioo`T0
06ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59737 .79074 m .5964 .75442 L .56748 .75296 L p .707 .577 .707 r
F P
0 g
s
.56748 .75296 m .56523 .75285 L p .56984 .75828 L .707 .577 .707 r
F P
0 g
s
.59737 .79074 m .56748 .75296 L .56984 .75828 L .707 .577 .707 r
F
.5662 .78916 m .56523 .75285 L .53964 .74845 L p F P
0 g
s
.53964 .74845 m .53777 .74813 L p .54127 .75317 L .707 .577 .707 r
F P
0 g
s
.5662 .78916 m .53964 .74845 L .54127 .75317 L .707 .577 .707 r
F
.53777 .74813 m .53874 .78445 L .5662 .78916 L p F P
0 g
s
.53874 .78445 m .53777 .74813 L .51802 .7412 L p .707 .577 .707 r
F P
0 g
s
.51802 .7412 m .5167 .74073 L p .51882 .74494 L .707 .577 .707 r
F P
0 g
s
.53874 .78445 m .51802 .7412 L .51882 .74494 L .707 .577 .707 r
F
.5167 .74073 m .51767 .77705 L .53874 .78445 L p F P
0 g
s
.51767 .77705 m .5167 .74073 L .5047 .73184 L p .707 .577 .707 r
F P
0 g
s
.5047 .73184 m .50409 .73138 L p .50494 .73425 L .707 .577 .707 r
F P
0 g
s
.51767 .77705 m .5047 .73184 L .50494 .73425 L .707 .577 .707 r
F
.50409 .73138 m .50506 .7677 L .51767 .77705 L p F P
0 g
s
.50506 .7677 m .50409 .73138 L .50123 .72121 L p .707 .577 .707 r
F P
0 g
s
.50123 .72121 m .50117 .72099 L p .50126 .72204 L .707 .577 .707 r
F P
0 g
s
.50506 .7677 m .50123 .72121 L .50126 .72204 L .707 .577 .707 r
F
.50618 .75189 m .50388 .72354 L p .49888 .68643 L F P
0 g
s
.50388 .72354 m .50199 .7002 L .50123 .69684 L p .707 .577 .707 r
F P
0 g
s
.50123 .69684 m .49888 .68643 L p .50388 .72354 L .707 .577 .707 r
F P
0 g
s
.51894 .76393 m .51653 .73427 L p .50199 .7002 L .707 .577 .707 r
F P
0 g
s
.51104 .70874 m .50199 .7002 L p .51653 .73427 L .707 .577 .707 r
F P
0 g
s
.50199 .7002 m .50618 .75189 L .51894 .76393 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50618 .75189 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.49888 .68643 m .50091 .71142 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50091 .71142 m .50308 .73812 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50117 .72099 m .50214 .75731 L .50506 .7677 L p .707 .577 .707 r
F P
0 g
s
.50214 .75731 m .50117 .72099 L .5016 .72036 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50091 .71142 L p .50574 .67226 L .707 .577 .707 r
F P
0 g
s
.50574 .67226 m .50792 .69908 L p .50308 .73812 L .707 .577 .707 r
F P
0 g
s
.51653 .73427 m .51474 .71224 L .51104 .70874 L p .707 .577 .707 r
F P
0 g
s
.5401 .77305 m .53762 .74255 L p .51474 .71224 L .707 .577 .707 r
F P
0 g
s
.52938 .71855 m .51474 .71224 L p .53762 .74255 L .707 .577 .707 r
F P
0 g
s
.51474 .71224 m .51894 .76393 L .5401 .77305 L p .707 .577 .707 r
F P
0 g
s
.50863 .71035 m .52457 .70116 L p .51067 .7425 L .707 .577 .707 r
F P
0 g
s
.50792 .69908 m .50994 .72395 L .50955 .72476 L p .707 .577 .707 r
F P
0 g
s
.50955 .72476 m .50308 .73812 L p .50792 .69908 L .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50822 .71058 L .50863 .71035 L p .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50863 .71035 L .51067 .7425 L .707 .577 .707 r
F
.5016 .72036 m .50822 .71058 L p .50358 .74626 L F P
0 g
s
.50214 .75731 m .5016 .72036 L .50358 .74626 L .707 .577 .707 r
F
.50091 .71142 m .49888 .68643 L .50003 .68406 L p F P
0 g
s
.50003 .68406 m .50574 .67226 L p .50091 .71142 L .707 .577 .707 r
F P
0 g
s
.53762 .74255 m .5359 .72136 L .52938 .71855 L p .707 .577 .707 r
F P
0 g
s
.56523 .75285 m .5662 .78916 L .59737 .79074 L p .707 .577 .707 r
F P
0 g
s
.56759 .77836 m .56509 .74758 L p .5359 .72136 L .707 .577 .707 r
F P
0 g
s
.56509 .74758 m .56339 .72667 L .55511 .72507 L p .707 .577 .707 r
F P
0 g
s
.55511 .72507 m .5359 .72136 L p .56509 .74758 L .707 .577 .707 r
F P
0 g
s
.5964 .75442 m .59737 .79074 L .61576 .78975 L p .707 .577 .707 r
F P
0 g
s
.61576 .78975 m .62919 .78902 L p .60145 .75975 L .707 .577 .707 r
F P
0 g
s
.60145 .75975 m .5964 .75442 L .61576 .78975 L .707 .577 .707 r
F
.62919 .78902 m .62822 .7527 L .5964 .75442 L p F P
0 g
s
.59873 .77935 m .59625 .74885 L p .56339 .72667 L .707 .577 .707 r
F P
0 g
s
.59625 .74885 m .59453 .72765 L .58601 .72738 L p .707 .577 .707 r
F P
0 g
s
.58601 .72738 m .56339 .72667 L p .59625 .74885 L .707 .577 .707 r
F P
0 g
s
.62822 .7527 m .62919 .78902 L .6449 .78643 L p .707 .577 .707 r
F P
0 g
s
.6449 .78643 m .65856 .78418 L p .63271 .75736 L .707 .577 .707 r
F P
0 g
s
.63271 .75736 m .62822 .7527 L .6449 .78643 L .707 .577 .707 r
F
.65856 .78418 m .65759 .74786 L .62822 .7527 L p F P
0 g
s
.63046 .7759 m .62805 .74624 L p .59453 .72765 L .707 .577 .707 r
F P
0 g
s
.62805 .74624 m .62626 .72421 L .61914 .72498 L p .707 .577 .707 r
F P
0 g
s
.61914 .72498 m .59453 .72765 L p .62805 .74624 L .707 .577 .707 r
F P
0 g
s
.59453 .72765 m .59873 .77935 L .63046 .7759 L p .707 .577 .707 r
F P
0 g
s
.65759 .74786 m .65856 .78418 L .66908 .78089 L p .707 .577 .707 r
F P
0 g
s
.66908 .78089 m .68258 .77668 L p .66063 .75136 L .707 .577 .707 r
F P
0 g
s
.66063 .75136 m .65759 .74786 L .66908 .78089 L .707 .577 .707 r
F
.68258 .77668 m .68161 .74036 L .65759 .74786 L p F P
0 g
s
.65968 .76837 m .65738 .74002 L p .62626 .72421 L .707 .577 .707 r
F P
0 g
s
.65738 .74002 m .65548 .71668 L .65102 .71783 L p .707 .577 .707 r
F P
0 g
s
.65102 .71783 m .62626 .72421 L p .65738 .74002 L .707 .577 .707 r
F P
0 g
s
.62626 .72421 m .63046 .7759 L .65968 .76837 L p .707 .577 .707 r
F P
0 g
s
.56339 .72667 m .56759 .77836 L .59873 .77935 L p .707 .577 .707 r
F P
0 g
s
.68161 .74036 m .68258 .77668 L .68734 .77394 L p .707 .577 .707 r
F P
0 g
s
.68734 .77394 m .69893 .76726 L p .68298 .74248 L .707 .577 .707 r
F P
0 g
s
.68298 .74248 m .68161 .74036 L .68734 .77394 L .707 .577 .707 r
F
.69893 .76726 m .69796 .73094 L .68161 .74036 L p F P
0 g
s
.68352 .75749 m .68136 .73078 L p .65548 .71668 L .707 .577 .707 r
F P
0 g
s
.68136 .73078 m .67933 .70579 L .67798 .70641 L p .707 .577 .707 r
F P
0 g
s
.67798 .70641 m .65548 .71668 L p .68136 .73078 L .707 .577 .707 r
F P
0 g
s
.65548 .71668 m .65968 .76837 L .68352 .75749 L p .707 .577 .707 r
F P
0 g
s
.5359 .72136 m .5401 .77305 L .56759 .77836 L p .707 .577 .707 r
F P
0 g
s
.59261 .86861 m .59309 .8498 L .56192 .84758 L p .707 .577 .707 r
F P
0 g
s
.59309 .8498 m .59261 .86861 L .62443 .86879 L p .707 .577 .707 r
F P
0 g
s
.62443 .86879 m .62491 .84998 L .59309 .8498 L p .707 .577 .707 r
F P
0 g
s
.69796 .73094 m .69893 .76726 L .69966 .76618 L p .707 .577 .707 r
F P
0 g
s
.69875 .74506 m .69967 .74432 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69817 .73164 m .69796 .73094 L .69966 .76618 L .707 .577 .707 r
F
.69547 .69262 m .67933 .70579 L p .69863 .74236 L F P
0 g
s
.69967 .74432 m .69765 .71944 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69813 .73068 m .69796 .73094 L p .69817 .73164 L .707 .577 .707 r
F P
0 g
s
.69765 .71944 m .69547 .69262 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69547 .69262 m .69967 .74432 L .70652 .73015 L p .707 .577 .707 r
F P
0 g
s
.70652 .73015 m .70233 .67846 L .69547 .69262 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .70501 .72053 L .69813 .73068 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .69813 .73068 L .69817 .73164 L .707 .577 .707 r
F
.69966 .76618 m .70598 .75685 L p .69817 .73164 L F P
0 g
s
.67933 .70579 m .68352 .75749 L .69875 .74506 L p .707 .577 .707 r
F P
0 g
s
.69863 .74236 m .67933 .70579 L .69875 .74506 L .707 .577 .707 r
F
.62491 .84998 m .62443 .86879 L .65379 .86689 L p F P
0 g
s
.65379 .86689 m .65428 .84808 L .62491 .84998 L p .707 .577 .707 r
F P
0 g
s
.56192 .84758 m .56144 .86638 L .59261 .86861 L p .707 .577 .707 r
F P
0 g
s
.56144 .86638 m .56192 .84758 L .53446 .84351 L p .707 .577 .707 r
F P
0 g
s
.53446 .84351 m .53398 .86232 L .56144 .86638 L p .707 .577 .707 r
F P
0 g
s
.65428 .84808 m .65379 .86689 L .67782 .86311 L p .707 .577 .707 r
F P
0 g
s
.67782 .86311 m .67831 .8443 L .65428 .84808 L p .707 .577 .707 r
F P
0 g
s
.53398 .86232 m .53446 .84351 L .51339 .83801 L p .707 .577 .707 r
F P
0 g
s
.51339 .83801 m .51291 .85682 L .53398 .86232 L p .707 .577 .707 r
F P
0 g
s
.67831 .8443 m .67782 .86311 L .69417 .85782 L p .707 .577 .707 r
F P
0 g
s
.69417 .85782 m .69465 .83901 L .67831 .8443 L p .707 .577 .707 r
F P
0 g
s
.51291 .85682 m .51339 .83801 L .50078 .83161 L p .707 .577 .707 r
F P
0 g
s
.50078 .83161 m .5003 .85042 L .51291 .85682 L p .707 .577 .707 r
F P
0 g
s
.70501 .72053 m .70598 .75685 L .70306 .74646 L p .707 .577 .707 r
F P
0 g
s
.70306 .74646 m .70209 .71014 L .70501 .72053 L p .707 .577 .707 r
F P
0 g
s
.70233 .67846 m .70652 .73015 L .70342 .71637 L p .707 .577 .707 r
F P
0 g
s
.70342 .71637 m .69923 .66468 L .70233 .67846 L p .707 .577 .707 r
F P
0 g
s
.69465 .83901 m .69417 .85782 L .70122 .85153 L p .707 .577 .707 r
F P
0 g
s
.70122 .85153 m .7017 .83272 L .69465 .83901 L p .707 .577 .707 r
F P
0 g
s
.4924 .82174 m .4906 .32109 L .44659 .31847 L p .707 .577 .707 r
F P
0 g
s
.50994 .72395 m .50574 .67226 L .52188 .65909 L p .707 .577 .707 r
F P
0 g
s
.50822 .71058 m .5092 .7469 L .50214 .75731 L p .707 .577 .707 r
F P
0 g
s
.5003 .85042 m .50078 .83161 L .49786 .82494 L p .707 .577 .707 r
F P
0 g
s
.49786 .82494 m .49738 .84375 L .5003 .85042 L p .707 .577 .707 r
F P
0 g
s
.49738 .84375 m .49786 .82494 L .50492 .81865 L p .707 .577 .707 r
F P
0 g
s
.50492 .81865 m .50443 .83745 L .49738 .84375 L p .707 .577 .707 r
F P
0 g
s
.52457 .70116 m .52554 .73748 L .5092 .7469 L p .707 .577 .707 r
F P
0 g
s
.52554 .73748 m .52457 .70116 L .54859 .69367 L p .707 .577 .707 r
F P
0 g
s
.52188 .65909 m .52608 .71078 L .50994 .72395 L p .707 .577 .707 r
F P
0 g
s
.52608 .71078 m .52188 .65909 L .54573 .64821 L p .707 .577 .707 r
F P
0 g
s
.50443 .83745 m .50492 .81865 L .52126 .81335 L p .707 .577 .707 r
F P
0 g
s
.54859 .69367 m .54957 .72998 L .52554 .73748 L p .707 .577 .707 r
F P
0 g
s
.54957 .72998 m .54859 .69367 L .57796 .68882 L p .707 .577 .707 r
F P
0 g
s
.54573 .64821 m .54993 .6999 L .52608 .71078 L p .707 .577 .707 r
F P
0 g
s
.52126 .81335 m .52078 .83216 L .50443 .83745 L p .707 .577 .707 r
F P
0 g
s
.52078 .83216 m .52126 .81335 L .54529 .80957 L p .707 .577 .707 r
F P
0 g
s
.54529 .80957 m .5448 .82838 L .52078 .83216 L p .707 .577 .707 r
F P
0 g
s
.4906 .32109 m .4924 .82174 L .53735 .82046 L p .707 .577 .707 r
F P
0 g
s
.53735 .82046 m .53554 .3198 L .4906 .32109 L p .707 .577 .707 r
F P
0 g
s
.54993 .6999 m .54573 .64821 L .57495 .64067 L p .707 .577 .707 r
F P
0 g
s
.57893 .72514 m .57796 .68882 L .60978 .6871 L p .707 .577 .707 r
F P
0 g
s
.57796 .68882 m .57893 .72514 L .54957 .72998 L p .707 .577 .707 r
F P
0 g
s
.57495 .64067 m .57915 .69237 L .54993 .6999 L p .707 .577 .707 r
F P
0 g
s
.5448 .82838 m .54529 .80957 L .57465 .80768 L p .707 .577 .707 r
F P
0 g
s
.57465 .80768 m .57417 .82648 L .5448 .82838 L p .707 .577 .707 r
F P
0 g
s
.57417 .82648 m .57465 .80768 L .60647 .80785 L p .707 .577 .707 r
F P
0 g
s
.53554 .3198 m .53735 .82046 L .57883 .8154 L p .707 .577 .707 r
F P
0 g
s
.57915 .69237 m .57495 .64067 L .60668 .63723 L p .707 .577 .707 r
F P
0 g
s
.57883 .8154 m .57702 .31475 L .53554 .3198 L p .707 .577 .707 r
F P
0 g
s
.44839 .81912 m .44659 .31847 L .40782 .3122 L p .707 .577 .707 r
F P
0 g
s
.44659 .31847 m .44839 .81912 L .4924 .82174 L p .707 .577 .707 r
F P
0 g
s
.70209 .71014 m .70306 .74646 L .69045 .73711 L p .707 .577 .707 r
F P
0 g
s
.69045 .73711 m .68948 .70079 L .70209 .71014 L p .707 .577 .707 r
F P
0 g
s
.69923 .66468 m .70342 .71637 L .69067 .70434 L p .707 .577 .707 r
F P
0 g
s
.69067 .70434 m .68647 .65264 L .69923 .66468 L p .707 .577 .707 r
F P
0 g
s
.61075 .72342 m .60978 .6871 L .64095 .68868 L p .707 .577 .707 r
F P
0 g
s
.60978 .6871 m .61075 .72342 L .57893 .72514 L p .707 .577 .707 r
F P
0 g
s
.60668 .63723 m .61088 .68892 L .57915 .69237 L p .707 .577 .707 r
F P
0 g
s
.60599 .82666 m .60647 .80785 L .63764 .81008 L p .707 .577 .707 r
F P
0 g
s
.60647 .80785 m .60599 .82666 L .57417 .82648 L p .707 .577 .707 r
F P
0 g
s
.57702 .31475 m .57883 .8154 L .61278 .80707 L p .707 .577 .707 r
F P
0 g
s
.64192 .725 m .64095 .68868 L .66841 .69339 L p .707 .577 .707 r
F P
0 g
s
.64095 .68868 m .64192 .725 L .61075 .72342 L p .707 .577 .707 r
F P
0 g
s
.63782 .63821 m .64201 .6899 L .61088 .68892 L p .707 .577 .707 r
F P
0 g
s
.61088 .68892 m .60668 .63723 L .63782 .63821 L p .707 .577 .707 r
F P
0 g
s
.61278 .80707 m .61098 .30641 L .57702 .31475 L p .707 .577 .707 r
F P
0 g
s
.7017 .83272 m .70122 .85153 L .6983 .84485 L p .707 .577 .707 r
F P
0 g
s
.6983 .84485 m .69878 .82605 L .7017 .83272 L p .707 .577 .707 r
F P
0 g
s
.40963 .81286 m .40782 .3122 L .3781 .30291 L p .707 .577 .707 r
F P
0 g
s
.40782 .3122 m .40963 .81286 L .44839 .81912 L p .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .25339 .71761 L .22447 .71614 L p .707 .577 .707 r
F P
0 g
s
.22447 .71614 m .22222 .71603 L p .22683 .72146 L .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .22447 .71614 L .22683 .72146 L .707 .577 .707 r
F
.22319 .75235 m .22222 .71603 L .19664 .71164 L p F P
0 g
s
.19664 .71164 m .19476 .71131 L p .19826 .71636 L .707 .577 .707 r
F P
0 g
s
.22319 .75235 m .19664 .71164 L .19826 .71636 L .707 .577 .707 r
F
.19476 .71131 m .19573 .74763 L .22319 .75235 L p F P
0 g
s
.19573 .74763 m .19476 .71131 L .17501 .70438 L p .707 .577 .707 r
F P
0 g
s
.17501 .70438 m .17369 .70392 L p .17581 .70813 L .707 .577 .707 r
F P
0 g
s
.19573 .74763 m .17501 .70438 L .17581 .70813 L .707 .577 .707 r
F
.17369 .70392 m .17466 .74024 L .19573 .74763 L p F P
0 g
s
.17466 .74024 m .17369 .70392 L .16169 .69502 L p .707 .577 .707 r
F P
0 g
s
.16169 .69502 m .16108 .69457 L p .16193 .69744 L .707 .577 .707 r
F P
0 g
s
.17466 .74024 m .16169 .69502 L .16193 .69744 L .707 .577 .707 r
F
.16108 .69457 m .16205 .73089 L .17466 .74024 L p F P
0 g
s
.16205 .73089 m .16108 .69457 L .15822 .68439 L p .707 .577 .707 r
F P
0 g
s
.15822 .68439 m .15816 .68418 L p .15825 .68522 L .707 .577 .707 r
F P
0 g
s
.16205 .73089 m .15822 .68439 L .15825 .68522 L .707 .577 .707 r
F
.16317 .71508 m .16087 .68673 L p .15588 .64961 L F P
0 g
s
.16087 .68673 m .15898 .66339 L .15822 .66002 L p .707 .577 .707 r
F P
0 g
s
.15822 .66002 m .15588 .64961 L p .16087 .68673 L .707 .577 .707 r
F P
0 g
s
.17593 .72712 m .17352 .69746 L p .15898 .66339 L .707 .577 .707 r
F P
0 g
s
.16803 .67193 m .15898 .66339 L p .17352 .69746 L .707 .577 .707 r
F P
0 g
s
.15898 .66339 m .16317 .71508 L .17593 .72712 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .16317 .71508 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15588 .64961 m .1579 .6746 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.1579 .6746 m .16007 .7013 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15816 .68418 m .15913 .7205 L .16205 .73089 L p .707 .577 .707 r
F P
0 g
s
.15913 .7205 m .15816 .68418 L .15859 .68355 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .1579 .6746 L p .16273 .63544 L .707 .577 .707 r
F P
0 g
s
.16273 .63544 m .16491 .66226 L p .16007 .7013 L .707 .577 .707 r
F P
0 g
s
.17352 .69746 m .17173 .67542 L .16803 .67193 L p .707 .577 .707 r
F P
0 g
s
.19709 .73624 m .19461 .70574 L p .17173 .67542 L .707 .577 .707 r
F P
0 g
s
.18637 .68174 m .17173 .67542 L p .19461 .70574 L .707 .577 .707 r
F P
0 g
s
.17173 .67542 m .17593 .72712 L .19709 .73624 L p .707 .577 .707 r
F P
0 g
s
.16562 .67353 m .18156 .66435 L p .16766 .70569 L .707 .577 .707 r
F P
0 g
s
.16491 .66226 m .16693 .68714 L .16654 .68794 L p .707 .577 .707 r
F P
0 g
s
.16654 .68794 m .16007 .7013 L p .16491 .66226 L .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16522 .67376 L .16562 .67353 L p .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16562 .67353 L .16766 .70569 L .707 .577 .707 r
F
.15859 .68355 m .16522 .67376 L p .16057 .70944 L F P
0 g
s
.15913 .7205 m .15859 .68355 L .16057 .70944 L .707 .577 .707 r
F
.1579 .6746 m .15588 .64961 L .15702 .64725 L p F P
0 g
s
.15702 .64725 m .16273 .63544 L p .1579 .6746 L .707 .577 .707 r
F P
0 g
s
.19461 .70574 m .19289 .68454 L .18637 .68174 L p .707 .577 .707 r
F P
0 g
s
.22222 .71603 m .22319 .75235 L .25436 .75393 L p .707 .577 .707 r
F P
0 g
s
.22458 .74155 m .22208 .71076 L p .19289 .68454 L .707 .577 .707 r
F P
0 g
s
.22208 .71076 m .22039 .68986 L .2121 .68826 L p .707 .577 .707 r
F P
0 g
s
.2121 .68826 m .19289 .68454 L p .22208 .71076 L .707 .577 .707 r
F P
0 g
s
.25339 .71761 m .25436 .75393 L .27275 .75293 L p .707 .577 .707 r
F P
0 g
s
.27275 .75293 m .28618 .75221 L p .25844 .72294 L .707 .577 .707 r
F P
0 g
s
.25844 .72294 m .25339 .71761 L .27275 .75293 L .707 .577 .707 r
F
.28618 .75221 m .28521 .71589 L .25339 .71761 L p F P
0 g
s
.25572 .74253 m .25324 .71203 L p .22039 .68986 L .707 .577 .707 r
F P
0 g
s
.25324 .71203 m .25152 .69084 L .24301 .69057 L p .707 .577 .707 r
F P
0 g
s
.24301 .69057 m .22039 .68986 L p .25324 .71203 L .707 .577 .707 r
F P
0 g
s
.28521 .71589 m .28618 .75221 L .30189 .74961 L p .707 .577 .707 r
F P
0 g
s
.30189 .74961 m .31555 .74736 L p .2897 .72055 L .707 .577 .707 r
F P
0 g
s
.2897 .72055 m .28521 .71589 L .30189 .74961 L .707 .577 .707 r
F
.31555 .74736 m .31458 .71104 L .28521 .71589 L p F P
0 g
s
.28745 .73909 m .28504 .70943 L p .25152 .69084 L .707 .577 .707 r
F P
0 g
s
.28504 .70943 m .28325 .68739 L .27613 .68817 L p .707 .577 .707 r
F P
0 g
s
.27613 .68817 m .25152 .69084 L p .28504 .70943 L .707 .577 .707 r
F P
0 g
s
.25152 .69084 m .25572 .74253 L .28745 .73909 L p .707 .577 .707 r
F P
0 g
s
.31458 .71104 m .31555 .74736 L .32608 .74408 L p .707 .577 .707 r
F P
0 g
s
.32608 .74408 m .33958 .73986 L p .31762 .71455 L .707 .577 .707 r
F P
0 g
s
.31762 .71455 m .31458 .71104 L .32608 .74408 L .707 .577 .707 r
F
.33958 .73986 m .33861 .70355 L .31458 .71104 L p F P
0 g
s
.31667 .73155 m .31437 .7032 L p .28325 .68739 L .707 .577 .707 r
F P
0 g
s
.31437 .7032 m .31247 .67986 L .30801 .68101 L p .707 .577 .707 r
F P
0 g
s
.30801 .68101 m .28325 .68739 L p .31437 .7032 L .707 .577 .707 r
F P
0 g
s
.28325 .68739 m .28745 .73909 L .31667 .73155 L p .707 .577 .707 r
F P
0 g
s
.68948 .70079 m .69045 .73711 L .66938 .72971 L p .707 .577 .707 r
F P
0 g
s
.66938 .72971 m .66841 .69339 L .68948 .70079 L p .707 .577 .707 r
F P
0 g
s
.68647 .65264 m .69067 .70434 L .66951 .69522 L p .707 .577 .707 r
F P
0 g
s
.66951 .69522 m .66531 .64352 L .68647 .65264 L p .707 .577 .707 r
F P
0 g
s
.22039 .68986 m .22458 .74155 L .25572 .74253 L p .707 .577 .707 r
F P
0 g
s
.33861 .70355 m .33958 .73986 L .34433 .73712 L p .707 .577 .707 r
F P
0 g
s
.34433 .73712 m .35592 .73045 L p .33997 .70567 L .707 .577 .707 r
F P
0 g
s
.33997 .70567 m .33861 .70355 L .34433 .73712 L .707 .577 .707 r
F
.35592 .73045 m .35495 .69413 L .33861 .70355 L p F P
0 g
s
.34052 .72067 m .33835 .69397 L p .31247 .67986 L .707 .577 .707 r
F P
0 g
s
.33835 .69397 m .33632 .66898 L .33497 .66959 L p .707 .577 .707 r
F P
0 g
s
.33497 .66959 m .31247 .67986 L p .33835 .69397 L .707 .577 .707 r
F P
0 g
s
.31247 .67986 m .31667 .73155 L .34052 .72067 L p .707 .577 .707 r
F P
0 g
s
.61098 .30641 m .61278 .80707 L .63589 .79626 L p .707 .577 .707 r
F P
0 g
s
.63589 .79626 m .63409 .29561 L .61098 .30641 L p .707 .577 .707 r
F P
0 g
s
.19289 .68454 m .19709 .73624 L .22458 .74155 L p .707 .577 .707 r
F P
0 g
s
.69878 .82605 m .6983 .84485 L .68569 .83845 L p .707 .577 .707 r
F P
0 g
s
.68569 .83845 m .68617 .81964 L .69878 .82605 L p .707 .577 .707 r
F P
0 g
s
.66841 .69339 m .66938 .72971 L .64192 .725 L p .707 .577 .707 r
F P
0 g
s
.66531 .64352 m .66951 .69522 L .64201 .6899 L p .707 .577 .707 r
F P
0 g
s
.64201 .6899 m .63782 .63821 L .66531 .64352 L p .707 .577 .707 r
F P
0 g
s
.3799 .80356 m .3781 .30291 L .36032 .29149 L p .707 .577 .707 r
F P
0 g
s
.3781 .30291 m .3799 .80356 L .40963 .81286 L p .707 .577 .707 r
F P
0 g
s
.2496 .8318 m .25008 .81299 L .21891 .81076 L p .707 .577 .707 r
F P
0 g
s
.25008 .81299 m .2496 .8318 L .28142 .83197 L p .707 .577 .707 r
F P
0 g
s
.28142 .83197 m .2819 .81317 L .25008 .81299 L p .707 .577 .707 r
F P
0 g
s
.35495 .69413 m .35592 .73045 L .35665 .72937 L p .707 .577 .707 r
F P
0 g
s
.35574 .70825 m .35666 .7075 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35516 .69483 m .35495 .69413 L .35665 .72937 L .707 .577 .707 r
F
.35246 .65581 m .33632 .66898 L p .35562 .70554 L F P
0 g
s
.35666 .7075 m .35464 .68263 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35512 .69387 m .35495 .69413 L p .35516 .69483 L .707 .577 .707 r
F P
0 g
s
.35464 .68263 m .35246 .65581 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35246 .65581 m .35666 .7075 L .36351 .69334 L p .707 .577 .707 r
F P
0 g
s
.36351 .69334 m .35932 .64164 L .35246 .65581 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .362 .68372 L .35512 .69387 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .35512 .69387 L .35516 .69483 L .707 .577 .707 r
F
.35665 .72937 m .36297 .72003 L p .35516 .69483 L F P
0 g
s
.33632 .66898 m .34052 .72067 L .35574 .70825 L p .707 .577 .707 r
F P
0 g
s
.35562 .70554 m .33632 .66898 L .35574 .70825 L .707 .577 .707 r
F
.2819 .81317 m .28142 .83197 L .31079 .83008 L p F P
0 g
s
.31079 .83008 m .31127 .81127 L .2819 .81317 L p .707 .577 .707 r
F P
0 g
s
.21891 .81076 m .21843 .82957 L .2496 .8318 L p .707 .577 .707 r
F P
0 g
s
.21843 .82957 m .21891 .81076 L .19145 .8067 L p .707 .577 .707 r
F P
0 g
s
.19145 .8067 m .19097 .82551 L .21843 .82957 L p .707 .577 .707 r
F P
0 g
s
.31127 .81127 m .31079 .83008 L .33481 .8263 L p .707 .577 .707 r
F P
0 g
s
.33481 .8263 m .3353 .80749 L .31127 .81127 L p .707 .577 .707 r
F P
0 g
s
.63409 .29561 m .63589 .79626 L .64589 .78406 L p .707 .577 .707 r
F P
0 g
s
.64589 .78406 m .64408 .2834 L .63409 .29561 L p .707 .577 .707 r
F P
0 g
s
.68617 .81964 m .68569 .83845 L .66462 .83295 L p .707 .577 .707 r
F P
0 g
s
.66462 .83295 m .6651 .81414 L .68617 .81964 L p .707 .577 .707 r
F P
0 g
s
.19097 .82551 m .19145 .8067 L .17038 .8012 L p .707 .577 .707 r
F P
0 g
s
.17038 .8012 m .1699 .82 L .19097 .82551 L p .707 .577 .707 r
F P
0 g
s
.3353 .80749 m .33481 .8263 L .35116 .821 L p .707 .577 .707 r
F P
0 g
s
.35116 .821 m .35164 .80219 L .3353 .80749 L p .707 .577 .707 r
F P
0 g
s
.362 .68372 m .36297 .72003 L .36005 .70964 L p .707 .577 .707 r
F P
0 g
s
.36005 .70964 m .35908 .67333 L .362 .68372 L p .707 .577 .707 r
F P
0 g
s
.35932 .64164 m .36351 .69334 L .36041 .67956 L p .707 .577 .707 r
F P
0 g
s
.36212 .79214 m .36032 .29149 L .35623 .27907 L p .707 .577 .707 r
F P
0 g
s
.36032 .29149 m .36212 .79214 L .3799 .80356 L p .707 .577 .707 r
F P
0 g
s
.6651 .81414 m .66462 .83295 L .63716 .82889 L p .707 .577 .707 r
F P
0 g
s
.63716 .82889 m .63764 .81008 L .6651 .81414 L p .707 .577 .707 r
F P
0 g
s
.1699 .82 m .17038 .8012 L .15777 .7948 L p .707 .577 .707 r
F P
0 g
s
.15777 .7948 m .15729 .8136 L .1699 .82 L p .707 .577 .707 r
F P
0 g
s
.36041 .67956 m .35622 .62787 L .35932 .64164 L p .707 .577 .707 r
F P
0 g
s
.63764 .81008 m .63716 .82889 L .60599 .82666 L p .707 .577 .707 r
F P
0 g
s
.35164 .80219 m .35116 .821 L .35821 .81471 L p .707 .577 .707 r
F P
0 g
s
.35821 .81471 m .35869 .7959 L .35164 .80219 L p .707 .577 .707 r
F P
0 g
s
.64408 .2834 m .64589 .78406 L .6418 .77164 L p .707 .577 .707 r
F P
0 g
s
.6418 .77164 m .63999 .27098 L .64408 .2834 L p .707 .577 .707 r
F P
0 g
s
.15729 .8136 m .15777 .7948 L .15485 .78812 L p .707 .577 .707 r
F P
0 g
s
.15485 .78812 m .15437 .80693 L .15729 .8136 L p .707 .577 .707 r
F P
0 g
s
.35908 .67333 m .36005 .70964 L .34744 .70029 L p .707 .577 .707 r
F P
0 g
s
.34744 .70029 m .34647 .66397 L .35908 .67333 L p .707 .577 .707 r
F P
0 g
s
.35622 .62787 m .36041 .67956 L .34766 .66752 L p .707 .577 .707 r
F P
0 g
s
.34766 .66752 m .34346 .61583 L .35622 .62787 L p .707 .577 .707 r
F P
0 g
s
.35623 .27907 m .35803 .77972 L .36212 .79214 L p .707 .577 .707 r
F P
0 g
s
.35803 .77972 m .35623 .27907 L .36623 .26686 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35869 .7959 m .35821 .81471 L .35529 .80804 L p .707 .577 .707 r
F P
0 g
s
.35529 .80804 m .35577 .78923 L .35869 .7959 L p .707 .577 .707 r
F P
0 g
s
.16693 .68714 m .16273 .63544 L .17887 .62227 L p .707 .577 .707 r
F P
0 g
s
.16522 .67376 m .16619 .71008 L .15913 .7205 L p .707 .577 .707 r
F P
0 g
s
.15437 .80693 m .15485 .78812 L .16191 .78183 L p .707 .577 .707 r
F P
0 g
s
.63999 .27098 m .6418 .77164 L .62402 .76022 L p .707 .577 .707 r
F P
0 g
s
.62402 .76022 m .62222 .25956 L .63999 .27098 L p .707 .577 .707 r
F P
0 g
s
.34647 .66397 m .34744 .70029 L .32637 .6929 L p .707 .577 .707 r
F P
0 g
s
.32637 .6929 m .3254 .65658 L .34647 .66397 L p .707 .577 .707 r
F P
0 g
s
.34346 .61583 m .34766 .66752 L .3265 .6584 L p .707 .577 .707 r
F P
0 g
s
.3265 .6584 m .3223 .60671 L .34346 .61583 L p .707 .577 .707 r
F P
0 g
s
.16191 .78183 m .16142 .80064 L .15437 .80693 L p .707 .577 .707 r
F P
0 g
s
.18156 .66435 m .18253 .70067 L .16619 .71008 L p .707 .577 .707 r
F P
0 g
s
.18253 .70067 m .18156 .66435 L .20559 .65685 L p .707 .577 .707 r
F P
0 g
s
.17887 .62227 m .18307 .67397 L .16693 .68714 L p .707 .577 .707 r
F P
0 g
s
.18307 .67397 m .17887 .62227 L .20272 .61139 L p .707 .577 .707 r
F P
0 g
s
.36803 .76752 m .36623 .26686 L .38934 .25606 L p .707 .577 .707 r
F P
0 g
s
.36623 .26686 m .36803 .76752 L .35803 .77972 L p .707 .577 .707 r
F P
0 g
s
.35577 .78923 m .35529 .80804 L .34268 .80164 L p .707 .577 .707 r
F P
0 g
s
.34268 .80164 m .34316 .78283 L .35577 .78923 L p .707 .577 .707 r
F P
0 g
s
.3254 .65658 m .32637 .6929 L .29891 .68818 L p .707 .577 .707 r
F P
0 g
s
.29891 .68818 m .29794 .65186 L .3254 .65658 L p .707 .577 .707 r
F P
0 g
s
.3223 .60671 m .3265 .6584 L .299 .65309 L p .707 .577 .707 r
F P
0 g
s
.299 .65309 m .29481 .6014 L .3223 .60671 L p .707 .577 .707 r
F P
0 g
s
.16142 .80064 m .16191 .78183 L .17825 .77654 L p .707 .577 .707 r
F P
0 g
s
.20656 .69317 m .20559 .65685 L .23495 .652 L p .707 .577 .707 r
F P
0 g
s
.20692 .66308 m .20272 .61139 L .23194 .60386 L p .707 .577 .707 r
F P
0 g
s
.20559 .65685 m .20656 .69317 L .18253 .70067 L p .707 .577 .707 r
F P
0 g
s
.20272 .61139 m .20692 .66308 L .18307 .67397 L p .707 .577 .707 r
F P
0 g
s
.17825 .77654 m .17777 .79534 L .16142 .80064 L p .707 .577 .707 r
F P
0 g
s
.29794 .65186 m .29891 .68818 L .26774 .6866 L p .707 .577 .707 r
F P
0 g
s
.26774 .6866 m .26677 .65029 L .29794 .65186 L p .707 .577 .707 r
F P
0 g
s
.29481 .6014 m .299 .65309 L .26787 .65211 L p .707 .577 .707 r
F P
0 g
s
.26787 .65211 m .26367 .60041 L .29481 .6014 L p .707 .577 .707 r
F P
0 g
s
.62222 .25956 m .62402 .76022 L .5943 .75092 L p .707 .577 .707 r
F P
0 g
s
.5943 .75092 m .59249 .25027 L .62222 .25956 L p .707 .577 .707 r
F P
0 g
s
.23592 .68832 m .23495 .652 L .26677 .65029 L p .707 .577 .707 r
F P
0 g
s
.23614 .65555 m .23194 .60386 L .26367 .60041 L p .707 .577 .707 r
F P
0 g
s
.23495 .652 m .23592 .68832 L .20656 .69317 L p .707 .577 .707 r
F P
0 g
s
.23194 .60386 m .23614 .65555 L .20692 .66308 L p .707 .577 .707 r
F P
0 g
s
.26677 .65029 m .26774 .6866 L .23592 .68832 L p .707 .577 .707 r
F P
0 g
s
.26367 .60041 m .26787 .65211 L .23614 .65555 L p .707 .577 .707 r
F P
0 g
s
.34316 .78283 m .34268 .80164 L .32161 .79614 L p .707 .577 .707 r
F P
0 g
s
.32161 .79614 m .32209 .77733 L .34316 .78283 L p .707 .577 .707 r
F P
0 g
s
.73593 .65969 m .73173 .608 L .7006 .60702 L p .707 .577 .707 r
F P
0 g
s
.73173 .608 m .73593 .65969 L .76766 .65625 L p .707 .577 .707 r
F P
0 g
s
.76766 .65625 m .76347 .60456 L .73173 .608 L p .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .36803 .76752 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.38972 .36245 m .39114 .75671 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .38934 .25606 L .42329 .24772 L p .707 .577 .707 r
F P
0 g
s
.42329 .24772 m .4251 .74838 L .39114 .75671 L p .707 .577 .707 r
F P
0 g
s
.38873 .57119 m .39292 .62288 L .42101 .61983 L p .707 .577 .707 r
F P
0 g
s
.4251 .74838 m .42329 .24772 L .46477 .24266 L p .707 .577 .707 r
F P
0 g
s
.42101 .61983 m .42465 .61944 L p .42025 .61352 L .707 .577 .707 r
F P
0 g
s
.42025 .61352 m .38873 .57119 L .42101 .61983 L .707 .577 .707 r
F
.38934 .25606 m .38972 .36245 L p .38613 .33295 L F P
0 g
s
.76347 .60456 m .76766 .65625 L .79688 .64872 L p .707 .577 .707 r
F P
0 g
s
.79688 .64872 m .79269 .59703 L .76347 .60456 L p .707 .577 .707 r
F P
0 g
s
.17777 .79534 m .17825 .77654 L .20228 .77276 L p .707 .577 .707 r
F P
0 g
s
.20228 .77276 m .2018 .79156 L .17777 .79534 L p .707 .577 .707 r
F P
0 g
s
.70479 .65871 m .7006 .60702 L .6731 .60171 L p .707 .577 .707 r
F P
0 g
s
.7006 .60702 m .70479 .65871 L .73593 .65969 L p .707 .577 .707 r
F P
0 g
s
.79269 .59703 m .79688 .64872 L .82073 .63783 L p .707 .577 .707 r
F P
0 g
s
.82073 .63783 m .81653 .58614 L .79269 .59703 L p .707 .577 .707 r
F P
0 g
s
.32209 .77733 m .32161 .79614 L .29415 .79207 L p .707 .577 .707 r
F P
0 g
s
.29415 .79207 m .29463 .77326 L .32209 .77733 L p .707 .577 .707 r
F P
0 g
s
.59249 .25027 m .5943 .75092 L .55553 .74466 L p .707 .577 .707 r
F P
0 g
s
.55553 .74466 m .55373 .244 L .59249 .25027 L p .707 .577 .707 r
F P
0 g
s
.6773 .6534 m .6731 .60171 L .65194 .59259 L p .707 .577 .707 r
F P
0 g
s
.6731 .60171 m .6773 .6534 L .70479 .65871 L p .707 .577 .707 r
F P
0 g
s
.2018 .79156 m .20228 .77276 L .23164 .77086 L p .707 .577 .707 r
F P
0 g
s
.72981 .73477 m .73029 .71596 L .69913 .71373 L p .707 .577 .707 r
F P
0 g
s
.73029 .71596 m .72981 .73477 L .76164 .73494 L p .707 .577 .707 r
F P
0 g
s
.76164 .73494 m .76212 .71613 L .73029 .71596 L p .707 .577 .707 r
F P
0 g
s
.23164 .77086 m .23116 .78967 L .2018 .79156 L p .707 .577 .707 r
F P
0 g
s
.76212 .71613 m .76164 .73494 L .791 .73305 L p .707 .577 .707 r
F P
0 g
s
.791 .73305 m .79148 .71424 L .76212 .71613 L p .707 .577 .707 r
F P
0 g
s
.69913 .71373 m .69864 .73254 L .72981 .73477 L p .707 .577 .707 r
F P
0 g
s
.81653 .58614 m .82073 .63783 L .83687 .62467 L p .707 .577 .707 r
F P
0 g
s
.83687 .62467 m .83268 .57297 L .81653 .58614 L p .707 .577 .707 r
F P
0 g
s
.29463 .77326 m .29415 .79207 L .26298 .78984 L p .707 .577 .707 r
F P
0 g
s
.26298 .78984 m .26346 .77104 L .29463 .77326 L p .707 .577 .707 r
F P
0 g
s
.69864 .73254 m .69913 .71373 L .67166 .70967 L p .707 .577 .707 r
F P
0 g
s
.73457 .74791 m .7336 .71159 L .70244 .71001 L p .707 .577 .707 r
F P
0 g
s
.7336 .71159 m .73457 .74791 L .7664 .74619 L p .707 .577 .707 r
F P
0 g
s
.7664 .74619 m .76543 .70987 L .7336 .71159 L p .707 .577 .707 r
F P
0 g
s
.76543 .70987 m .7664 .74619 L .79576 .74134 L p .707 .577 .707 r
F P
0 g
s
.79148 .71424 m .791 .73305 L .81503 .72927 L p .707 .577 .707 r
F P
0 g
s
.81503 .72927 m .81551 .71046 L .79148 .71424 L p .707 .577 .707 r
F P
0 g
s
.79576 .74134 m .79479 .70502 L .76543 .70987 L p .707 .577 .707 r
F P
0 g
s
.23116 .78967 m .23164 .77086 L .26346 .77104 L p .707 .577 .707 r
F P
0 g
s
.67166 .70967 m .67118 .72847 L .69864 .73254 L p .707 .577 .707 r
F P
0 g
s
.26346 .77104 m .26298 .78984 L .23116 .78967 L p .707 .577 .707 r
F P
0 g
s
.70341 .74633 m .70244 .71001 L .67497 .7053 L p .707 .577 .707 r
F P
0 g
s
.70244 .71001 m .70341 .74633 L .73457 .74791 L p .707 .577 .707 r
F P
0 g
s
.55373 .244 m .55553 .74466 L .51152 .74204 L p .707 .577 .707 r
F P
0 g
s
.51152 .74204 m .50972 .24138 L .55373 .244 L p .707 .577 .707 r
F P
0 g
s
.65614 .64428 m .65194 .59259 L .63919 .58055 L p .707 .577 .707 r
F P
0 g
s
.65194 .59259 m .65614 .64428 L .6773 .6534 L p .707 .577 .707 r
F P
0 g
s
.46658 .74332 m .46477 .24266 L .50972 .24138 L p .707 .577 .707 r
F P
0 g
s
.46477 .24266 m .46658 .74332 L .4251 .74838 L p .707 .577 .707 r
F P
0 g
s
.81551 .71046 m .81503 .72927 L .83137 .72397 L p .707 .577 .707 r
F P
0 g
s
.79479 .70502 m .79576 .74134 L .81979 .73384 L p .707 .577 .707 r
F P
0 g
s
.83137 .72397 m .83185 .70516 L .81551 .71046 L p .707 .577 .707 r
F P
0 g
s
.81979 .73384 m .81882 .69753 L .79479 .70502 L p .707 .577 .707 r
F P
0 g
s
.67118 .72847 m .67166 .70967 L .6506 .70416 L p .707 .577 .707 r
F P
0 g
s
.50972 .24138 m .51152 .74204 L .46658 .74332 L p .707 .577 .707 r
F P
0 g
s
.6506 .70416 m .65011 .72297 L .67118 .72847 L p .707 .577 .707 r
F P
0 g
s
.67497 .7053 m .67594 .74161 L .70341 .74633 L p .707 .577 .707 r
F P
0 g
s
.83268 .57297 m .83687 .62467 L .84373 .6105 L p .707 .577 .707 r
F P
0 g
s
.84373 .6105 m .83953 .55881 L .83268 .57297 L p .707 .577 .707 r
F P
0 g
s
.67594 .74161 m .67497 .7053 L .65391 .6979 L p .707 .577 .707 r
F P
0 g
s
.83185 .70516 m .83137 .72397 L .83278 .72272 L p .707 .577 .707 r
F P
0 g
s
.83274 .72638 m .83613 .72443 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83294 .70723 m .83185 .70516 L .83278 .72272 L .707 .577 .707 r
F
.83613 .72443 m .83516 .68811 L .83312 .68929 L p F P
0 g
s
.83297 .70417 m .83185 .70516 L p .83294 .70723 L .707 .577 .707 r
F P
0 g
s
.83312 .68929 m .81882 .69753 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83613 .72443 m .83312 .68929 L .83281 .71927 L .707 .577 .707 r
F
.83516 .68811 m .83613 .72443 L .84319 .71401 L p F P
0 g
s
.84319 .71401 m .84222 .6777 L .83516 .68811 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83891 .69887 L .83297 .70417 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83297 .70417 L .83294 .70723 L .707 .577 .707 r
F
.83278 .72272 m .83843 .71768 L p .83294 .70723 L F P
0 g
s
.81882 .69753 m .81979 .73384 L .83274 .72638 L p .707 .577 .707 r
F P
0 g
s
.83281 .71927 m .81882 .69753 L .83274 .72638 L .707 .577 .707 r
F
.65391 .6979 m .65488 .73422 L .67594 .74161 L p F P
0 g
s
.63919 .58055 m .64338 .63224 L .65614 .64428 L p .707 .577 .707 r
F P
0 g
s
.64338 .63224 m .63919 .58055 L .63609 .56677 L p .707 .577 .707 r
F P
0 g
s
.65011 .72297 m .6506 .70416 L .63798 .69776 L p .707 .577 .707 r
F P
0 g
s
.63798 .69776 m .6375 .71657 L .65011 .72297 L p .707 .577 .707 r
F P
0 g
s
.65488 .73422 m .65391 .6979 L .64129 .68855 L p .707 .577 .707 r
F P
0 g
s
.83953 .55881 m .84373 .6105 L .84063 .59672 L p .707 .577 .707 r
F P
0 g
s
.84063 .59672 m .83643 .54503 L .83953 .55881 L p .707 .577 .707 r
F P
0 g
s
.64129 .68855 m .64226 .72487 L .65488 .73422 L p .707 .577 .707 r
F P
0 g
s
.63609 .56677 m .64028 .61847 L .64338 .63224 L p .707 .577 .707 r
F P
0 g
s
.64028 .61847 m .63609 .56677 L .64294 .55261 L p .707 .577 .707 r
F P
0 g
s
.6375 .71657 m .63798 .69776 L .63506 .69109 L p .707 .577 .707 r
F P
0 g
s
.63506 .69109 m .63458 .7099 L .6375 .71657 L p .707 .577 .707 r
F P
0 g
s
.64226 .72487 m .64129 .68855 L .63837 .67816 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83643 .54503 m .84063 .59672 L .82787 .58469 L p .707 .577 .707 r
F P
0 g
s
.82787 .58469 m .82368 .53299 L .83643 .54503 L p .707 .577 .707 r
F P
0 g
s
.63837 .67816 m .63934 .71448 L .64226 .72487 L p .707 .577 .707 r
F P
0 g
s
.83891 .69887 m .83843 .71768 L .83551 .71101 L p .707 .577 .707 r
F P
0 g
s
.83551 .71101 m .83599 .6922 L .83891 .69887 L p .707 .577 .707 r
F P
0 g
s
.84222 .6777 m .84319 .71401 L .84027 .70362 L p .707 .577 .707 r
F P
0 g
s
.84027 .70362 m .8393 .66731 L .84222 .6777 L p .707 .577 .707 r
F P
0 g
s
.64294 .55261 m .64714 .6043 L .64028 .61847 L p .707 .577 .707 r
F P
0 g
s
.64714 .6043 m .64294 .55261 L .65909 .53944 L p .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .63837 .67816 L .64455 .66905 L p .707 .577 .707 r
F P
0 g
s
.64455 .66905 m .64543 .66775 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .64455 .66905 L .6446 .67411 L .707 .577 .707 r
F
.6447 .68396 m .65846 .6795 L p .64486 .69899 L F P
0 g
s
.65846 .6795 m .65798 .69831 L .6449 .70255 L p .707 .577 .707 r
F P
0 g
s
.64486 .69899 m .65846 .6795 L .6449 .70255 L .707 .577 .707 r
F
.64543 .66775 m .6464 .70406 L .64493 .70623 L p F P
0 g
s
.64493 .70623 m .63934 .71448 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.6446 .67411 m .64543 .66775 L .64493 .70623 L .707 .577 .707 r
F
.6449 .70255 m .64164 .70361 L p .64486 .69899 L F P
0 g
s
.64164 .70361 m .64212 .6848 L .6447 .68396 L p .707 .577 .707 r
F P
0 g
s
.64164 .70361 m .6447 .68396 L .64486 .69899 L .707 .577 .707 r
F
.63458 .7099 m .63506 .69109 L .64212 .6848 L p F P
0 g
s
.39292 .62288 m .38873 .57119 L .35759 .5702 L p .707 .577 .707 r
F P
0 g
s
.42465 .61944 m .42046 .56774 L .38873 .57119 L p .707 .577 .707 r
F P
0 g
s
.42046 .56774 m .42465 .61944 L .45387 .6119 L p .707 .577 .707 r
F P
0 g
s
.45387 .6119 m .44968 .56021 L .42046 .56774 L p .707 .577 .707 r
F P
0 g
s
.64212 .6848 m .64164 .70361 L .63458 .7099 L p .707 .577 .707 r
F P
0 g
s
.82368 .53299 m .82787 .58469 L .80671 .57556 L p .707 .577 .707 r
F P
0 g
s
.80671 .57556 m .80252 .52387 L .82368 .53299 L p .707 .577 .707 r
F P
0 g
s
.36178 .6219 m .35759 .5702 L .33009 .56489 L p .707 .577 .707 r
F P
0 g
s
.35759 .5702 m .36178 .6219 L .39292 .62288 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44968 .56021 m .45387 .6119 L .47772 .60102 L p .707 .577 .707 r
F P
0 g
s
.47772 .60102 m .47352 .54933 L .44968 .56021 L p .707 .577 .707 r
F P
0 g
s
.83599 .6922 m .83551 .71101 L .82289 .70461 L p .707 .577 .707 r
F P
0 g
s
.82289 .70461 m .82338 .6858 L .83599 .6922 L p .707 .577 .707 r
F P
0 g
s
.65909 .53944 m .66328 .59113 L .64714 .6043 L p .707 .577 .707 r
F P
0 g
s
.66328 .59113 m .65909 .53944 L .68294 .52856 L p .707 .577 .707 r
F P
0 g
s
.8393 .66731 m .84027 .70362 L .82765 .69427 L p .707 .577 .707 r
F P
0 g
s
.82765 .69427 m .82668 .65796 L .8393 .66731 L p .707 .577 .707 r
F P
0 g
s
.33429 .61659 m .33009 .56489 L .30893 .55577 L p .707 .577 .707 r
F P
0 g
s
.33009 .56489 m .33429 .61659 L .36178 .6219 L p .707 .577 .707 r
F P
0 g
s
.3868 .69795 m .38728 .67914 L .35612 .67691 L p .707 .577 .707 r
F P
0 g
s
.38728 .67914 m .3868 .69795 L .41863 .69813 L p .707 .577 .707 r
F P
0 g
s
.41863 .69813 m .41911 .67932 L .38728 .67914 L p .707 .577 .707 r
F P
0 g
s
.80252 .52387 m .80671 .57556 L .77922 .57025 L p .707 .577 .707 r
F P
0 g
s
.77922 .57025 m .77502 .51856 L .80252 .52387 L p .707 .577 .707 r
F P
0 g
s
.41911 .67932 m .41863 .69813 L .44799 .69623 L p .707 .577 .707 r
F P
0 g
s
.44799 .69623 m .44847 .67742 L .41911 .67932 L p .707 .577 .707 r
F P
0 g
s
.35612 .67691 m .35563 .69572 L .3868 .69795 L p .707 .577 .707 r
F P
0 g
s
.47352 .54933 m .47772 .60102 L .49386 .58785 L p .707 .577 .707 r
F P
0 g
s
.49386 .58785 m .48967 .53616 L .47352 .54933 L p .707 .577 .707 r
F P
0 g
s
.35563 .69572 m .35612 .67691 L .32865 .67285 L p .707 .577 .707 r
F P
0 g
s
.39156 .71109 m .39059 .67477 L .35943 .6732 L p .707 .577 .707 r
F P
0 g
s
.39059 .67477 m .39156 .71109 L .42339 .70937 L p .707 .577 .707 r
F P
0 g
s
.42339 .70937 m .42242 .67305 L .39059 .67477 L p .707 .577 .707 r
F P
0 g
s
.6464 .70406 m .64543 .66775 L .66177 .65833 L p .707 .577 .707 r
F P
0 g
s
.42242 .67305 m .42339 .70937 L .45275 .70453 L p .707 .577 .707 r
F P
0 g
s
.44847 .67742 m .44799 .69623 L .47202 .69245 L p .707 .577 .707 r
F P
0 g
s
.47202 .69245 m .4725 .67364 L .44847 .67742 L p .707 .577 .707 r
F P
0 g
s
.45275 .70453 m .45178 .66821 L .42242 .67305 L p .707 .577 .707 r
F P
0 g
s
.32865 .67285 m .32817 .69166 L .35563 .69572 L p .707 .577 .707 r
F P
0 g
s
.68713 .58025 m .68294 .52856 L .71216 .52102 L p .707 .577 .707 r
F P
0 g
s
.68294 .52856 m .68713 .58025 L .66328 .59113 L p .707 .577 .707 r
F P
0 g
s
.3604 .70951 m .35943 .6732 L .33196 .66848 L p .707 .577 .707 r
F P
0 g
s
.35943 .6732 m .3604 .70951 L .39156 .71109 L p .707 .577 .707 r
F P
0 g
s
.77502 .51856 m .77922 .57025 L .74808 .56927 L p .707 .577 .707 r
F P
0 g
s
.74808 .56927 m .74389 .51758 L .77502 .51856 L p .707 .577 .707 r
F P
0 g
s
.31313 .60747 m .30893 .55577 L .29618 .54373 L p .707 .577 .707 r
F P
0 g
s
.30893 .55577 m .31313 .60747 L .33429 .61659 L p .707 .577 .707 r
F P
0 g
s
.65798 .69831 m .65846 .6795 L .68249 .67572 L p .707 .577 .707 r
F P
0 g
s
.68249 .67572 m .68201 .69453 L .65798 .69831 L p .707 .577 .707 r
F P
0 g
s
.66177 .65833 m .66274 .69465 L .6464 .70406 L p .707 .577 .707 r
F P
0 g
s
.82338 .6858 m .82289 .70461 L .80183 .69911 L p .707 .577 .707 r
F P
0 g
s
.80183 .69911 m .80231 .6803 L .82338 .6858 L p .707 .577 .707 r
F P
0 g
s
.4725 .67364 m .47202 .69245 L .48836 .68716 L p .707 .577 .707 r
F P
0 g
s
.45178 .66821 m .45275 .70453 L .47678 .69703 L p .707 .577 .707 r
F P
0 g
s
.48836 .68716 m .48884 .66835 L .4725 .67364 L p .707 .577 .707 r
F P
0 g
s
.47678 .69703 m .47581 .66071 L .45178 .66821 L p .707 .577 .707 r
F P
0 g
s
.82668 .65796 m .82765 .69427 L .80659 .68688 L p .707 .577 .707 r
F P
0 g
s
.80659 .68688 m .80562 .65056 L .82668 .65796 L p .707 .577 .707 r
F P
0 g
s
.71635 .57272 m .71216 .52102 L .74389 .51758 L p .707 .577 .707 r
F P
0 g
s
.71216 .52102 m .71635 .57272 L .68713 .58025 L p .707 .577 .707 r
F P
0 g
s
.32817 .69166 m .32865 .67285 L .30759 .66735 L p .707 .577 .707 r
F P
0 g
s
.74389 .51758 m .74808 .56927 L .71635 .57272 L p .707 .577 .707 r
F P
0 g
s
.30759 .66735 m .3071 .68616 L .32817 .69166 L p .707 .577 .707 r
F P
0 g
s
.33196 .66848 m .33293 .7048 L .3604 .70951 L p .707 .577 .707 r
F P
0 g
s
.48967 .53616 m .49386 .58785 L .50072 .57368 L p .707 .577 .707 r
F P
0 g
s
.50072 .57368 m .49652 .52199 L .48967 .53616 L p .707 .577 .707 r
F P
0 g
s
.33293 .7048 m .33196 .66848 L .3109 .66108 L p .707 .577 .707 r
F P
0 g
s
.66274 .69465 m .66177 .65833 L .6858 .65083 L p .707 .577 .707 r
F P
0 g
s
.48884 .66835 m .48836 .68716 L .48977 .6859 L p .707 .577 .707 r
F P
0 g
s
.48973 .68957 m .49312 .68761 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.48993 .67041 m .48884 .66835 L .48977 .6859 L .707 .577 .707 r
F
.49312 .68761 m .49215 .65129 L .49011 .65247 L p F P
0 g
s
.48996 .66735 m .48884 .66835 L p .48993 .67041 L .707 .577 .707 r
F P
0 g
s
.49011 .65247 m .47581 .66071 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.49312 .68761 m .49011 .65247 L .4898 .68245 L .707 .577 .707 r
F
.49215 .65129 m .49312 .68761 L .50018 .6772 L p F P
0 g
s
.50018 .6772 m .49921 .64088 L .49215 .65129 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .4959 .66206 L .48996 .66735 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .48996 .66735 L .48993 .67041 L .707 .577 .707 r
F
.48977 .6859 m .49542 .68086 L p .48993 .67041 L F P
0 g
s
.47581 .66071 m .47678 .69703 L .48973 .68957 L p .707 .577 .707 r
F P
0 g
s
.4898 .68245 m .47581 .66071 L .48973 .68957 L .707 .577 .707 r
F
.3109 .66108 m .31187 .6974 L .33293 .7048 L p F P
0 g
s
.29618 .54373 m .30037 .59543 L .31313 .60747 L p .707 .577 .707 r
F P
0 g
s
.80231 .6803 m .80183 .69911 L .77436 .69504 L p .707 .577 .707 r
F P
0 g
s
.77436 .69504 m .77485 .67623 L .80231 .6803 L p .707 .577 .707 r
F P
0 g
s
.80562 .65056 m .80659 .68688 L .77912 .68216 L p .707 .577 .707 r
F P
0 g
s
.77912 .68216 m .77815 .64584 L .80562 .65056 L p .707 .577 .707 r
F P
0 g
s
.30037 .59543 m .29618 .54373 L .29308 .52996 L p .707 .577 .707 r
F P
0 g
s
.3071 .68616 m .30759 .66735 L .29497 .66095 L p .707 .577 .707 r
F P
0 g
s
.68201 .69453 m .68249 .67572 L .71185 .67383 L p .707 .577 .707 r
F P
0 g
s
.6858 .65083 m .68677 .68715 L .66274 .69465 L p .707 .577 .707 r
F P
0 g
s
.29497 .66095 m .29449 .67976 L .3071 .68616 L p .707 .577 .707 r
F P
0 g
s
.31187 .6974 m .3109 .66108 L .29828 .65173 L p .707 .577 .707 r
F P
0 g
s
.68677 .68715 m .6858 .65083 L .71516 .64599 L p .707 .577 .707 r
F P
0 g
s
.71185 .67383 m .71137 .69264 L .68201 .69453 L p .707 .577 .707 r
F P
0 g
s
.49652 .52199 m .50072 .57368 L .49762 .55991 L p .707 .577 .707 r
F P
0 g
s
.49762 .55991 m .49342 .50821 L .49652 .52199 L p .707 .577 .707 r
F P
0 g
s
.77485 .67623 m .77436 .69504 L .7432 .69281 L p .707 .577 .707 r
F P
0 g
s
.7432 .69281 m .74368 .674 L .77485 .67623 L p .707 .577 .707 r
F P
0 g
s
.77815 .64584 m .77912 .68216 L .74796 .68058 L p .707 .577 .707 r
F P
0 g
s
.74796 .68058 m .74699 .64427 L .77815 .64584 L p .707 .577 .707 r
F P
0 g
s
.71137 .69264 m .71185 .67383 L .74368 .674 L p .707 .577 .707 r
F P
0 g
s
.71613 .6823 m .71516 .64599 L .74699 .64427 L p .707 .577 .707 r
F P
0 g
s
.71516 .64599 m .71613 .6823 L .68677 .68715 L p .707 .577 .707 r
F P
0 g
s
.29828 .65173 m .29925 .68805 L .31187 .6974 L p .707 .577 .707 r
F P
0 g
s
.74368 .674 m .7432 .69281 L .71137 .69264 L p .707 .577 .707 r
F P
0 g
s
.74699 .64427 m .74796 .68058 L .71613 .6823 L p .707 .577 .707 r
F P
0 g
s
.29308 .52996 m .29727 .58165 L .30037 .59543 L p .707 .577 .707 r
F P
0 g
s
.29727 .58165 m .29308 .52996 L .29993 .51579 L p .707 .577 .707 r
F P
0 g
s
.29449 .67976 m .29497 .66095 L .29205 .65428 L p .707 .577 .707 r
F P
0 g
s
.29205 .65428 m .29157 .67308 L .29449 .67976 L p .707 .577 .707 r
F P
0 g
s
.29925 .68805 m .29828 .65173 L .29536 .64134 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49342 .50821 m .49762 .55991 L .48486 .54787 L p .707 .577 .707 r
F P
0 g
s
.48486 .54787 m .48067 .49618 L .49342 .50821 L p .707 .577 .707 r
F P
0 g
s
.29536 .64134 m .29633 .67766 L .29925 .68805 L p .707 .577 .707 r
F P
0 g
s
.4959 .66206 m .49542 .68086 L .4925 .67419 L p .707 .577 .707 r
F P
0 g
s
.4925 .67419 m .49298 .65538 L .4959 .66206 L p .707 .577 .707 r
F P
0 g
s
.49921 .64088 m .50018 .6772 L .49726 .66681 L p .707 .577 .707 r
F P
0 g
s
.49726 .66681 m .49629 .63049 L .49921 .64088 L p .707 .577 .707 r
F P
0 g
s
.29993 .51579 m .30413 .56749 L .29727 .58165 L p .707 .577 .707 r
F P
0 g
s
.30413 .56749 m .29993 .51579 L .31608 .50262 L p .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .29536 .64134 L .30154 .63223 L p .707 .577 .707 r
F P
0 g
s
.30154 .63223 m .30242 .63093 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .30154 .63223 L .30159 .63729 L .707 .577 .707 r
F
.30169 .64715 m .31545 .64269 L p .30185 .66218 L F P
0 g
s
.31545 .64269 m .31497 .6615 L .30189 .66574 L p .707 .577 .707 r
F P
0 g
s
.30185 .66218 m .31545 .64269 L .30189 .66574 L .707 .577 .707 r
F
.30242 .63093 m .30339 .66725 L .30192 .66941 L p F P
0 g
s
.30192 .66941 m .29633 .67766 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.30159 .63729 m .30242 .63093 L .30192 .66941 L .707 .577 .707 r
F
.30189 .66574 m .29863 .66679 L p .30185 .66218 L F P
0 g
s
.29863 .66679 m .29911 .64798 L .30169 .64715 L p .707 .577 .707 r
F P
0 g
s
.29863 .66679 m .30169 .64715 L .30185 .66218 L .707 .577 .707 r
F
.29157 .67308 m .29205 .65428 L .29911 .64798 L p F P
0 g
s
.29911 .64798 m .29863 .66679 L .29157 .67308 L p .707 .577 .707 r
F P
0 g
s
.48067 .49618 m .48486 .54787 L .4637 .53875 L p .707 .577 .707 r
F P
0 g
s
.4637 .53875 m .45951 .48706 L .48067 .49618 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49298 .65538 m .4925 .67419 L .47988 .66779 L p .707 .577 .707 r
F P
0 g
s
.47988 .66779 m .48037 .64898 L .49298 .65538 L p .707 .577 .707 r
F P
0 g
s
.31608 .50262 m .32027 .55432 L .30413 .56749 L p .707 .577 .707 r
F P
0 g
s
.32027 .55432 m .31608 .50262 L .33993 .49174 L p .707 .577 .707 r
F P
0 g
s
.49629 .63049 m .49726 .66681 L .48464 .65746 L p .707 .577 .707 r
F P
0 g
s
.48464 .65746 m .48367 .62114 L .49629 .63049 L p .707 .577 .707 r
F P
0 g
s
.45951 .48706 m .4637 .53875 L .43621 .53344 L p .707 .577 .707 r
F P
0 g
s
.43621 .53344 m .43201 .48174 L .45951 .48706 L p .707 .577 .707 r
F P
0 g
s
.30339 .66725 m .30242 .63093 L .31876 .62151 L p .707 .577 .707 r
F P
0 g
s
.34412 .54343 m .33993 .49174 L .36915 .48421 L p .707 .577 .707 r
F P
0 g
s
.33993 .49174 m .34412 .54343 L .32027 .55432 L p .707 .577 .707 r
F P
0 g
s
.43201 .48174 m .43621 .53344 L .40507 .53246 L p .707 .577 .707 r
F P
0 g
s
.40507 .53246 m .40088 .48076 L .43201 .48174 L p .707 .577 .707 r
F P
0 g
s
.31497 .6615 m .31545 .64269 L .33948 .63891 L p .707 .577 .707 r
F P
0 g
s
.33948 .63891 m .339 .65772 L .31497 .6615 L p .707 .577 .707 r
F P
0 g
s
.31876 .62151 m .31973 .65783 L .30339 .66725 L p .707 .577 .707 r
F P
0 g
s
.48037 .64898 m .47988 .66779 L .45882 .66229 L p .707 .577 .707 r
F P
0 g
s
.45882 .66229 m .4593 .64348 L .48037 .64898 L p .707 .577 .707 r
F P
0 g
s
.48367 .62114 m .48464 .65746 L .46358 .65006 L p .707 .577 .707 r
F P
0 g
s
.46358 .65006 m .46261 .61374 L .48367 .62114 L p .707 .577 .707 r
F P
0 g
s
.37334 .5359 m .36915 .48421 L .40088 .48076 L p .707 .577 .707 r
F P
0 g
s
.36915 .48421 m .37334 .5359 L .34412 .54343 L p .707 .577 .707 r
F P
0 g
s
.40088 .48076 m .40507 .53246 L .37334 .5359 L p .707 .577 .707 r
F P
0 g
s
.31973 .65783 m .31876 .62151 L .34279 .61402 L p .707 .577 .707 r
F P
0 g
s
.4593 .64348 m .45882 .66229 L .43135 .65823 L p .707 .577 .707 r
F P
0 g
s
.43135 .65823 m .43184 .63942 L .4593 .64348 L p .707 .577 .707 r
F P
0 g
s
.46261 .61374 m .46358 .65006 L .43611 .64535 L p .707 .577 .707 r
F P
0 g
s
.43611 .64535 m .43514 .60903 L .46261 .61374 L p .707 .577 .707 r
F P
0 g
s
.339 .65772 m .33948 .63891 L .36884 .63701 L p .707 .577 .707 r
F P
0 g
s
.34279 .61402 m .34376 .65033 L .31973 .65783 L p .707 .577 .707 r
F P
0 g
s
.34376 .65033 m .34279 .61402 L .37215 .60917 L p .707 .577 .707 r
F P
0 g
s
.36884 .63701 m .36836 .65582 L .339 .65772 L p .707 .577 .707 r
F P
0 g
s
.43184 .63942 m .43135 .65823 L .40018 .656 L p .707 .577 .707 r
F P
0 g
s
.40018 .656 m .40067 .63719 L .43184 .63942 L p .707 .577 .707 r
F P
0 g
s
.43514 .60903 m .43611 .64535 L .40495 .64377 L p .707 .577 .707 r
F P
0 g
s
.40495 .64377 m .40397 .60745 L .43514 .60903 L p .707 .577 .707 r
F P
0 g
s
.36836 .65582 m .36884 .63701 L .40067 .63719 L p .707 .577 .707 r
F P
0 g
s
.37312 .64549 m .37215 .60917 L .40397 .60745 L p .707 .577 .707 r
F P
0 g
s
.37215 .60917 m .37312 .64549 L .34376 .65033 L p .707 .577 .707 r
F P
0 g
s
.40067 .63719 m .40018 .656 L .36836 .65582 L p .707 .577 .707 r
F P
0 g
s
.40397 .60745 m .40495 .64377 L .37312 .64549 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001EYF00<005YFFUH015YF2@00OGoo001fOol90005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uo
o`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH90002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000D000AJEP03001JEUYF009JEPP000IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD00003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Ggoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001FOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol005Aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0001Moo`l003moo`00E7oo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00004Goo1P0015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000=Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH80008FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH20008FUH00`00FUIJEP06FUH40004FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP0015YF00<005YFFUH00eYF0`0000Eoo`00FUIJ
EP0000EJEP8000QJEP03001JEUYF00UJEP@00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=o
o`04001JEUYF0004FUH01000FUIJEUYF0P0017oo00@005YFFUH000EJEP8000QJEP03001JEUYF00UJ
EP03001JEUYF00<000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF00@005YF
000000Ioo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH30003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0P0027oo00@005YFFUH000EJEP8000QJ
EP03001JEUYF00QJEP800003FUH005YF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02000^Ool005Aoo`03001JEP0000=JEP03001oogoo00Qoo`04001JEUYF0005FUH20008FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol01000
FUH005YF10002Goo00@005YFFUH000EJEP@000IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009J
EP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00E7oo00@005YF000000AJEP<000Ioo`04001J
EUYF0005FUH50005FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000^Ool005Aoo`04001JEP000005FUH00`00FUH000030002Ool01000FUIJEP001EYF
30001EYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001DOol20002FUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`P000AJEP03001JEUYF00=JEP04
001JEP00000^Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH015YF00<0
05YFFUH00UYF0P005goo1@001EYF00@005YFFUH002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0005FUH00`00FUIJEP04FUH00`00FUH00002000NOol20003FUH01000FUIJEP00;Woo001DOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH00eYF0`008goo0P0000EJ
EP00FUIJEP0002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH2000UOol200000eYF00000002FUH2000]Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000009Goo0P0000=JEP00FUH00UYF00@005YF
000002eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH2000UOol20003FUH01000FUIJ
EUYF1000;Goo001EOol01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH2000EOol3000<Ool30005FUH01P00FUIJEUYF
001JEP8002eoo`00AWoo2@001goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`000UYF0P004Woo1@001goo100000=J
EP00FUH01EYF00<005YFFUH00UYF0`00;Goo0010Ool60004FUH00`00FUIJEP02FUH;0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00T005YFFUIJEP00FUH005YF000015YF
1@003Goo30001EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000lOol400000eYF001JEP07
FUH00`00FUIJEP06FUH01000FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF2@0000=J
EP00FUH01eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000hOol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH80002FUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000fOol200000eYF001JEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH300000eYF000000050003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool003Aoo`8000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00;Woo000bOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0002moo`00<Goo0P001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000;goo000`Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
<7oo000_Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000aOol002ioo`03001JEUYF
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000cOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00=Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0015YF00<005YFFUH01EYF5`000eYF00@005YF000003Moo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF
00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000AJEP<00003FUH005YF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000@003Uoo`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF3`000eYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUH000050006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000gOol002aoo`9JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00AJEPL000=JEP03001JEUYF00EJEP04001JEP000003FUH01000FUH000000UYF00<005YFFUH0
0UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo0UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01EYF0P0000=JEP00
FUH00UYF0P0000=JEP0000001`000UYF00<005YFFUH015YF00<005YFFUH015YF200015YF00<005YF
FUH00eYF00<005YF00000UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo0UYF0P0015YF00<005YFFUH00eYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH01@0000IJEP00000005YF0002FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<005YFFUH010000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00;7oo0eYF00<005YFFUH00UYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP0000@00004FUH000000004FUH20002FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH01eYF0P0000=JEP0000000P000UYF10000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool3FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH00UYF1`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF009JEPD000EJEP03001JEP0000D0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04
001JEP000004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00;Goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800005FUH0
05YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000]Ool002aoo`@00004FUH000000006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo
00<005YF00000P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80003FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUIJEP04FUHE0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=J
EPH0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF0080
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03P001EYF00<005YFFUH00eYF
00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05
001JEUYF001JEP020004FUH00`00FUH000030004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0000AJEP00FUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0015YF0P0000=JEP000000
1@0000=JEP00Ool01Woo4@000eYF00<005YFFUH015YF0P000UYF0P00;Goo000/Ool01000FUIJEP00
0eYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF0080009J
EPL000=JEP04001JEUYF000HOol50004FUH01@00FUIJEP00FUH00P00;Goo000/Ool01000FUIJEP00
0eYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF00@00004FUH0
00000003FUH200001EYF001JEUYF00006goo1@0000=JEP00FUH00UYF0`00;Goo000]Ool2FUH01000
FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP03FUH70002FUH2000EOol50005FUH20003FUH3000]Ool002eoo`9JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000P000AJEP03001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00=JEP04001JEUYFFUH90009Ool9
0003FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00;Goo000]Ool01EYF001JEUYF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00`000UYF00<005YFFUH02@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
02eoo`00;Goo00=JEP00FUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`<0009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP8000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`00;Woo000^Ool00`00FUIJEP02
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEP000UYF
00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02000_Ool002ioo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50005FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF10001EYF
00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000_Ool00`00FUH00003FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP030002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00<goo000`Ool20005
FUH50003FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0400000eYF001JEP05FUH30002Ool01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000aOol2
0004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP03FUH20004Ool0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000cOol300000eYF001JEP06
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUH000030006Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH015YF8@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P001EYF1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01000?Goo000fOol50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000:Ool01000FUIJEP001UYF00<005YF
FUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P001UYF00<005YFFUH05`00@Goo000kOol90004FUH00`00FUIJEP05FUH8000=
Ool01000FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YF00000`001eYF00<005YFFUH00UYF0P000UYF0P001UYF00<005YF00000UYF
0P00E7oo0014Ool<000EOol01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0P000UYF0P00
1UYF0P0015YF00<007ooOol0DWoo001UOol01000FUIJEP001EYF0`000eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
0P000eYF00<005YFFUH00eYF0P001EYF00<007ooOol0DWoo001UOol01000FUIJEP000eYF0P001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00Oomoo`1COol006Eo
o`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF00@005YF000000=JEP05001J
EUYFFUH0001FOol006Eoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP<0
00EJEP05001JEUYFFUH0001FOol003Iooal0011oo`03001JEP0000=JEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0000<00003FUH005YF00EJEP04001JEP00001GOol0039oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000aoo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH2001IOol0031oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000Moo`8000AJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP02FUH2001KOol002ioo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@000=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002
FUH6001MOol002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003Ool0000000AJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<006=oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0P00Igoo000/Ool20004FUH01000FUIJEUYF20004Goo200015YF00<005YF
FUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00;7oo0P00
0UYF1P008Goo1`000eYF00H005YFFUIJEP00Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00Oomoo`1VOol002]oo`03001JEP0000@002aoo`@000=JEP04001oogooOol30008FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JGoo000[Ool20003FUH00`00FUH00002000]Ool200000eYF001oo`04Ool20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUH00000Jgoo000[Ool20003FUH00`00FUIJEP02FUH5000ROol6000015YF000000001goo0`0015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1@00K7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@004Woo1`000eYF00L005YFFUIJ
EP00FUH0000:Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060004FUH8001TOol002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000eoo`L000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00IJEP04001JEUYFFUH6001N
Ool002eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000EOol;0006FUH00`00FUIJEP0:FUH01000
FUIJEUYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00Fgoo
000_Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02000QOolG0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3001HOol003=oo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EP00001FOol003Yoo`P000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03
001JEP0000AJEP04001JEUYFFUHQ0003FUH00`00FUIJEP04FUH01000FUIJEP00EWoo0012OolH000c
Ool00`00FUH00003FUH5000QOol50004FUH01000FUIJEUYF0P00EGoo002=Ool01000FUH005YF0P00
:goo0`0000=JEP00FUH00UYF0P00EGoo002=Ool00`00FUH00004000]Ool20003FUH2001EOol008eo
o`80009JEP03001JEUYF00D002Uoo`<00003FUH0000005Eoo`00SGoo0P000UYF00<005YFFUH00eYF
00<005YF00000`0087oo1@000eYF0`00EGoo002>Ool01000FUIJEP001EYF00<005YFFUH00eYF8000
0eYF00<005YFFUH00UYF0`00EGoo002?Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001EOol0095o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH3001FOol009=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001IOol009Ioo`D000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001KOol009]ooa8000AJEP03
001JEUYF009JEPL0061oo`00[Goo2@00Igoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59427 .74824 m .58418 .74809 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.58418 .74809 m .56319 .74779 L p .57475 .76269 L .707 .577 .707 r
F P
0 g
s
.5845 .77527 m .58418 .74809 L .57475 .76269 L .707 .577 .707 r
F
.55235 .74549 m .53564 .74195 L p .54569 .75782 L F P
0 g
s
.53564 .74195 m .51431 .73129 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53869 .77078 m .53865 .76901 L .53751 .7685 L .707 .577 .707 r
F
.53959 .77252 m .53945 .76936 L p .53869 .77078 L F P
0 g
s
.53945 .76936 m .53564 .74195 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .56706 .77744 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53959 .77252 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .56991 .79606 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53564 .74195 m .53945 .76936 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .54235 .79022 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .55235 .74549 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.55492 .7724 m .55235 .74549 L .54569 .75782 L .707 .577 .707 r
F
.56694 .77476 m .56319 .74779 L p .55492 .7724 L F P
0 g
s
.53802 .73674 m .53945 .76936 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53802 .73674 L p .53869 .77078 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .53751 .7685 L .5183 .75998 L .707 .577 .707 r
F
.52001 .76512 m .53959 .77252 L p .5183 .75998 L F P
0 g
s
.52103 .77957 m .54235 .79022 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.51431 .73129 m .5183 .75998 L p .5219 .74725 L .707 .577 .707 r
F P
0 g
s
.51334 .75513 m .5183 .75998 L .5013 .71687 L .707 .577 .707 r
F
.51772 .76203 m .51766 .75935 L .51657 .75829 L F
.5185 .76455 m .5183 .75998 L p .51772 .76203 L F P
0 g
s
.5183 .75998 m .51431 .73129 L .50558 .72162 L p .707 .577 .707 r
F P
0 g
s
.50558 .72162 m .5013 .71687 L p .5183 .75998 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .51693 .72878 L p .51772 .76203 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .5185 .76455 L .52001 .76512 L p .707 .577 .707 r
F P
0 g
s
.5185 .76455 m .51657 .75829 L .50556 .74754 L .707 .577 .707 r
F
.50672 .75501 m .5185 .76455 L p .50556 .74754 L F P
0 g
s
.50801 .76514 m .52103 .77957 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.5013 .71687 m .50556 .74754 L p .50568 .73079 L .707 .577 .707 r
F P
0 g
s
.50449 .74258 m .50556 .74754 L .49787 .70008 L .707 .578 .707 r
F
.50554 .75097 m .50537 .74666 L .50493 .74461 L .707 .577 .707 r
F
.50586 .75431 m .50556 .74754 L p .50554 .75097 L F P
0 g
s
.50556 .74754 m .5013 .71687 L .49934 .70732 L p .707 .578 .707 r
F P
0 g
s
.49934 .70732 m .49787 .70008 L p .50556 .74754 L .707 .578 .707 r
F P
0 g
s
.50556 .74754 m .50429 .71853 L p .50554 .75097 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50586 .75431 L .50672 .75501 L p .707 .577 .707 r
F P
0 g
s
.50586 .75431 m .50493 .74461 L .50248 .73325 L .707 .577 .707 r
F
.503 .74318 m .50586 .75431 L p .50248 .73325 L F P
0 g
s
.50458 .74836 m .50801 .76514 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.50449 .74258 m .49897 .70714 L .50248 .73325 L .707 .578 .707 r
F
.50248 .73325 m .50458 .74836 L p .50449 .74258 L F P
0 g
s
.50133 .70702 m .50248 .73325 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50429 .71853 m .50133 .70702 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50537 .74666 m .50429 .71853 L .50493 .74461 L .707 .577 .707 r
F
.51334 .75513 m .50568 .73079 L .50556 .74754 L F
.50429 .71853 m .50556 .74754 L p .51657 .75829 L F P
0 g
s
.51693 .72878 m .50429 .71853 L p .51657 .75829 L .707 .577 .707 r
F P
0 g
s
.50133 .70702 m .50776 .69633 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50661 .68023 m .52014 .66608 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50776 .69633 m .50834 .69537 L p .50794 .69884 L .707 .577 .707 r
F P
0 g
s
.50449 .72895 m .50776 .69633 L .50794 .69884 L .707 .577 .707 r
F
.51327 .7152 m .50936 .71852 L .52014 .66608 L F
.5105 .72929 m .50936 .71852 L .5156 .71321 L F
.50801 .76514 m .50556 .74754 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.51076 .73172 m .50458 .74836 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .50936 .71852 L p .5105 .72929 L .707 .577 .707 r
F P
0 g
s
.50458 .74836 m .50452 .72889 L .50936 .71852 L .707 .577 .707 r
F
.50458 .74836 m .50248 .73325 L p .50452 .72889 L F P
0 g
s
.50248 .73325 m .5029 .7428 L .503 .74318 L p .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .5029 .7428 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .50936 .71852 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50991 .73114 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50436 .68258 m .50936 .71852 L p .50452 .72889 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .50991 .73114 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52621 .72048 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .54366 .65219 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .52552 .70478 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.52685 .71435 m .52552 .70478 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52014 .66608 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .57262 .64227 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.55074 .69302 m .54366 .65219 L .5535 .69227 L .707 .577 .707 r
F
.57262 .64227 m .60418 .63729 L p .58189 .68507 L F P
0 g
s
.58006 .68528 m .57262 .64227 L .58189 .68507 L .707 .577 .707 r
F
.60418 .63729 m .63526 .63774 L p .61281 .68181 L F P
0 g
s
.61159 .68178 m .60418 .63729 L .61281 .68181 L .707 .577 .707 r
F
.63526 .63774 m .66281 .64358 L p .64345 .68302 L F P
0 g
s
.64252 .68283 m .63526 .63774 L .64345 .68302 L .707 .577 .707 r
F
.66281 .64358 m .68414 .65424 L p .67071 .6888 L F P
0 g
s
.68414 .65424 m .69715 .66866 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70319 .7301 m .70445 .71285 L .69807 .71573 L .707 .577 .707 r
F
.70509 .70407 m .7036 .70655 L p .70445 .71285 L F P
0 g
s
.7036 .70655 m .69807 .71573 L p .70445 .71285 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70509 .70407 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70058 .68545 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70058 .68545 m .69409 .70295 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .67831 .71945 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69909 .73888 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.70081 .75122 m .70657 .73569 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70635 .73151 m .70452 .72725 L .70657 .73569 L .707 .577 .707 r
F
.69807 .71573 m .69909 .73888 L p .70319 .7301 L F P
0 g
s
.69807 .71573 m .69673 .71661 L p .69722 .72128 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .69909 .73888 L p .69567 .70663 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69409 .70295 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69964 .75151 L .69996 .75098 L p .707 .577 .707 r
F P
0 g
s
.68334 .76217 m .68499 .76109 L p .68467 .75979 L .707 .577 .707 r
F P
0 g
s
.68293 .75262 m .68334 .76217 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.67505 .75638 m .68293 .75262 L .6647 .74013 L .707 .577 .707 r
F
.66387 .74366 m .6647 .74013 L .65479 .73334 L F
.67505 .75638 m .6647 .74013 L .66387 .74366 L F
.67528 .72124 m .65479 .73334 L p .68293 .75262 L F P
0 g
s
.64525 .73661 m .62583 .74326 L p .63707 .75535 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .59427 .74824 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.6285 .77499 m .62849 .77211 L .62592 .77241 L .707 .577 .707 r
F
.63002 .77652 m .62982 .77195 L p .6285 .77499 L F P
0 g
s
.62982 .77195 m .62583 .74326 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63002 .77652 m .65936 .77079 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63002 .77652 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .66151 .78162 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .62982 .77195 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63255 .79154 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .64525 .73661 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.64794 .76703 m .64525 .73661 L .63707 .75535 L .707 .577 .707 r
F
.65906 .76401 m .65479 .73334 L p .64794 .76703 L F P
0 g
s
.62845 .74075 m .62982 .77195 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .62845 .74075 L p .6285 .77499 L .707 .577 .707 r
F P
0 g
s
.59822 .77881 m .63002 .77652 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59427 .74824 m .59808 .77566 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59665 .74304 m .59808 .77566 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59822 .77881 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .63255 .79154 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .60098 .79652 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .62982 .77195 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.62845 .74075 m .59665 .74304 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.62849 .77211 m .62845 .74075 L .62592 .77241 L .707 .577 .707 r
F
.65781 .76929 m .65781 .76435 L .65384 .76543 L F
.65936 .77079 m .65906 .76401 L p .65781 .76929 L F P
0 g
s
.65936 .77079 m .68334 .76217 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65936 .77079 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .68503 .76773 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .65906 .76401 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .66151 .78162 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .65906 .76401 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65779 .73501 L p .65781 .76929 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .65906 .76401 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .62845 .74075 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.65781 .76435 m .65779 .73501 L .65384 .76543 L .707 .577 .707 r
F
.68293 .75262 m .67831 .71945 L .67528 .72124 L p F P
0 g
s
.67831 .71945 m .68293 .75262 L p .68391 .72735 L .707 .577 .707 r
F P
0 g
s
.68178 .72639 m .65779 .73501 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.68259 .76136 m .68239 .75287 L .67701 .75544 L .707 .577 .707 r
F
.68239 .75287 m .68178 .72639 L .67701 .75544 L F
.68334 .76217 m .68293 .75262 L p .68259 .76136 L F P
0 g
s
.68293 .75262 m .68178 .72639 L p .68259 .76136 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .68293 .75262 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69384 .74335 L .68467 .75979 L .707 .577 .707 r
F
.68499 .76109 m .69964 .75151 L p .68467 .75979 L F P
0 g
s
.69471 .74261 m .68391 .72735 L .68457 .75122 L .707 .577 .707 r
F
.68293 .75262 m .68503 .76773 L p .68391 .72735 L F P
0 g
s
.68178 .72639 m .68293 .75262 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .70081 .75122 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69471 .74261 m .68457 .75122 L .68503 .76773 L .707 .577 .707 r
F
.69909 .73888 m .69807 .71573 L p .69384 .74335 L F P
0 g
s
.70452 .72725 m .69567 .70663 L .69909 .73888 L .707 .577 .707 r
F
.69384 .74335 m .69722 .72128 L .68178 .72639 L F
.69673 .71661 m .68178 .72639 L p .69722 .72128 L F P
0 g
s
.69909 .73888 m .70081 .75122 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.7073 .73372 m .70597 .72415 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70597 .72415 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70369 .72834 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70436 .71671 m .70588 .72373 L .70665 .73985 L .707 .577 .707 r
F
.70058 .68545 m .70597 .72415 L p .70361 .71323 L .707 .578 .707 r
F P
0 g
s
.70597 .72415 m .70665 .73985 L p .705 .70559 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .69014 .69742 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70288 .70986 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70369 .72834 m .70288 .70986 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70364 .71476 m .70336 .71207 L .7041 .71774 L .707 .578 .707 r
F
.70336 .71207 m .70058 .68545 L .70361 .71323 L F
.70336 .71207 m .70361 .71323 L .7041 .71774 L F
.70369 .72834 m .69105 .7181 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70058 .68545 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70288 .70986 m .69715 .66866 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70213 .69256 m .70288 .70986 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70369 .72834 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70387 .71694 m .70288 .70986 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70436 .71671 m .70288 .70986 L .70509 .70407 L .707 .577 .707 r
F
.69085 .70251 m .69155 .69879 L .70288 .70986 L F
.70288 .70986 m .70387 .71694 L .70284 .7158 L p F P
0 g
s
.70284 .7158 m .69085 .70251 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70213 .69256 L .70298 .69588 L p .707 .577 .707 r
F P
0 g
s
.70298 .69588 m .70509 .70407 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.7041 .71774 m .70361 .71323 L .70597 .72415 L .707 .578 .707 r
F
.70436 .71671 m .705 .70559 L .70588 .72373 L .707 .577 .707 r
F
.70509 .70407 m .70597 .72415 L p .705 .70559 L F P
0 g
s
.70657 .73569 m .7073 .73372 L p .70635 .73151 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70319 .7301 L .69909 .73888 L .707 .577 .707 r
F
.70081 .75122 m .69909 .73888 L p .69988 .74992 L F P
0 g
s
.69996 .75098 m .70665 .73985 L p .69909 .73888 L .707 .577 .707 r
F P
0 g
s
.69988 .74992 m .69909 .73888 L .69471 .74261 L .707 .577 .707 r
F
.68948 .68232 m .69993 .69079 L p .69708 .70419 L F P
0 g
s
.69993 .69079 m .70213 .69256 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69708 .70419 m .69993 .69079 L .70071 .69582 L .707 .577 .707 r
F
.70387 .71694 m .70364 .71476 L .7041 .71774 L .707 .578 .707 r
F
.70597 .72415 m .7073 .73372 L .70717 .7331 L p F P
0 g
s
.70717 .7331 m .70387 .71694 L p .70597 .72415 L .707 .578 .707 r
F P
0 g
s
.69082 .69807 m .68414 .65424 L .69155 .69879 L .707 .577 .707 r
F
.69014 .69742 m .68414 .65424 L p .69121 .70062 L F P
0 g
s
.69014 .69742 m .68948 .68232 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69121 .70062 m .69082 .69807 L .69155 .69879 L .707 .577 .707 r
F
.69085 .70251 m .69014 .69742 L p .69121 .70062 L F P
0 g
s
.66996 .71013 m .66899 .68804 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .66996 .71013 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69105 .7181 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69085 .70251 m .66953 .69186 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68414 .65424 m .69014 .69742 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69085 .70251 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68948 .68232 m .69014 .69742 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .68452 .68044 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.68452 .68044 m .68948 .68232 L p .68653 .68652 L .707 .577 .707 r
F P
0 g
s
.68156 .69361 m .68452 .68044 L .68653 .68652 L .707 .577 .707 r
F
.66988 .68843 m .66281 .64358 L .67071 .6888 L F
.66899 .68804 m .66281 .64358 L p .67017 .69021 L F P
0 g
s
.66899 .68804 m .66839 .67435 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.67017 .69021 m .66988 .68843 L .67071 .6888 L .707 .577 .707 r
F
.66953 .69186 m .66899 .68804 L p .67017 .69021 L F P
0 g
s
.64249 .70522 m .6415 .68263 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66996 .71013 m .64249 .70522 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66996 .71013 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66953 .69186 m .64197 .68602 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66281 .64358 m .66899 .68804 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66953 .69186 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .66899 .68804 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .66091 .67301 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66091 .67301 m .66839 .67435 L p .66427 .67926 L .707 .577 .707 r
F P
0 g
s
.65862 .686 m .66091 .67301 L .66427 .67926 L .707 .577 .707 r
F
.6415 .68263 m .63526 .63774 L p .64277 .68439 L F P
0 g
s
.6415 .68263 m .64092 .66944 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64277 .68439 m .64252 .68283 L .64345 .68302 L .707 .577 .707 r
F
.64197 .68602 m .6415 .68263 L p .64277 .68439 L F P
0 g
s
.61133 .70384 m .61036 .68174 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64249 .70522 m .61133 .70384 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64249 .70522 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64197 .68602 m .6109 .68557 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.63526 .63774 m .6415 .68263 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64197 .68602 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .6415 .68263 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .63166 .66903 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.63166 .66903 m .64092 .66944 L p .63605 .6751 L .707 .577 .707 r
F P
0 g
s
.62986 .6823 m .63166 .66903 L .63605 .6751 L .707 .577 .707 r
F
.61036 .68174 m .60418 .63729 L p .61189 .68361 L F P
0 g
s
.61036 .68174 m .60976 .66806 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.61189 .68361 m .61159 .68178 L .61281 .68181 L .707 .577 .707 r
F
.6109 .68557 m .61036 .68174 L p .61189 .68361 L F P
0 g
s
.57953 .70613 m .57862 .68545 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61133 .70384 m .57953 .70613 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .61133 .70384 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.6109 .68557 m .57933 .69054 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60418 .63729 m .61036 .68174 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .6109 .68557 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .61036 .68174 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .59975 .66878 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.59975 .66878 m .60976 .66806 L p .60454 .67463 L .707 .577 .707 r
F P
0 g
s
.59772 .68322 m .59975 .66878 L .60454 .67463 L .707 .577 .707 r
F
.57862 .68545 m .57262 .64227 L p .58053 .68798 L F P
0 g
s
.57862 .68545 m .57796 .67035 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.58053 .68798 m .58006 .68528 L .58189 .68507 L .707 .577 .707 r
F
.57933 .69054 m .57862 .68545 L p .58053 .68798 L F P
0 g
s
.5502 .71186 m .54939 .69339 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57953 .70613 m .5502 .71186 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57953 .70613 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57933 .69054 m .55037 .70046 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57262 .64227 m .57862 .68545 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57933 .69054 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .57862 .68545 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .56865 .67217 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.56865 .67217 m .57796 .67035 L p .57293 .67787 L .707 .577 .707 r
F P
0 g
s
.56548 .68902 m .56865 .67217 L .57293 .67787 L .707 .577 .707 r
F
.54939 .69339 m .54366 .65219 L p .55151 .69748 L F P
0 g
s
.54939 .69339 m .54863 .67609 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.55151 .69748 m .55074 .69302 L .5535 .69227 L .707 .577 .707 r
F
.55037 .70046 m .54939 .69339 L p .55151 .69748 L F P
0 g
s
.5502 .71186 m .52621 .72048 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .5502 .71186 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.55037 .70046 m .52685 .71435 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .54939 .69339 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .55037 .70046 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .54939 .69339 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.53688 .69936 m .52552 .70478 L .54363 .68229 L .707 .577 .707 r
F
.54458 .68411 m .54363 .68229 L .54863 .67609 L F
.53688 .69936 m .54363 .68229 L .54458 .68411 L F
.52552 .70478 m .52464 .68471 L .52632 .6841 L p F P
0 g
s
.52632 .6841 m .54863 .67609 L p .52552 .70478 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .51327 .7152 L .52514 .71446 L .707 .577 .707 r
F
.52685 .71435 m .52508 .71621 L p .52514 .71446 L F P
0 g
s
.52508 .71621 m .51107 .73086 L p .52514 .71446 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .52552 .70478 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52685 .71435 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52464 .68471 m .52552 .70478 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .51107 .73086 L .51076 .73172 L p .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .52464 .68471 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50834 .69537 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .50936 .71852 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50436 .68258 L .50661 .68023 L p .707 .577 .707 r
F P
0 g
s
.50288 .7324 m .50133 .70702 L .50449 .72895 L .707 .577 .707 r
F
.50248 .73325 m .50133 .70702 L p .5033 .73933 L F P
0 g
s
.50452 .72889 m .50248 .73325 L .50436 .68258 L .707 .577 .707 r
F
.5033 .73933 m .50288 .7324 L .50449 .72895 L F
.5029 .7428 m .50248 .73325 L p .5033 .73933 L F P
0 g
s
.49787 .70008 m .50248 .73325 L p .49897 .70714 L .707 .578 .707 r
F P
0 g
s
.50248 .73325 m .49787 .70008 L .5004 .69326 L p .707 .577 .707 r
F P
0 g
s
.5004 .69326 m .50436 .68258 L p .50248 .73325 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50801 .76514 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.52103 .77957 m .5183 .75998 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.51766 .75935 m .51693 .72878 L .51657 .75829 L .707 .577 .707 r
F
.53055 .76541 m .5219 .74725 L .5183 .75998 L F
.5183 .75998 m .52103 .77957 L p .53055 .76541 L F P
0 g
s
.51693 .72878 m .5183 .75998 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .53945 .76936 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53802 .73674 m .51693 .72878 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.53865 .76901 m .53802 .73674 L .53751 .7685 L .707 .577 .707 r
F
.56609 .77608 m .56607 .77459 L .56486 .77436 L F
.56706 .77744 m .56694 .77476 L p .56609 .77608 L F P
0 g
s
.56706 .77744 m .59822 .77881 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56706 .77744 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .60098 .79652 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .56694 .77476 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56991 .79606 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59427 .74824 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .56694 .77476 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56549 .74166 L p .56609 .77608 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .56694 .77476 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .53802 .73674 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.56607 .77459 m .56549 .74166 L .56486 .77436 L .707 .577 .707 r
F
.59665 .74304 m .56549 .74166 L p .59537 .77558 L F P
0 g
s
.59822 .77881 m .59808 .77566 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59665 .74304 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .59808 .77566 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59052 .87901 m .59129 .86007 L .56013 .85763 L p .707 .577 .707 r
F P
0 g
s
.59129 .86007 m .59052 .87901 L .62232 .87978 L p .707 .577 .707 r
F P
0 g
s
.62232 .87978 m .6231 .86084 L .59129 .86007 L p .707 .577 .707 r
F P
0 g
s
.6231 .86084 m .62232 .87978 L .65165 .87881 L p .707 .577 .707 r
F P
0 g
s
.65165 .87881 m .65243 .85987 L .6231 .86084 L p .707 .577 .707 r
F P
0 g
s
.56013 .85763 m .55935 .87657 L .59052 .87901 L p .707 .577 .707 r
F P
0 g
s
.55935 .87657 m .56013 .85763 L .53266 .85377 L p .707 .577 .707 r
F P
0 g
s
.53266 .85377 m .53189 .87271 L .55935 .87657 L p .707 .577 .707 r
F P
0 g
s
.65243 .85987 m .65165 .87881 L .67564 .8762 L p .707 .577 .707 r
F P
0 g
s
.67564 .8762 m .67642 .85726 L .65243 .85987 L p .707 .577 .707 r
F P
0 g
s
.53189 .87271 m .53266 .85377 L .51158 .84887 L p .707 .577 .707 r
F P
0 g
s
.51158 .84887 m .5108 .86781 L .53189 .87271 L p .707 .577 .707 r
F P
0 g
s
.67642 .85726 m .67564 .8762 L .69194 .8722 L p .707 .577 .707 r
F P
0 g
s
.69194 .8722 m .69272 .85326 L .67642 .85726 L p .707 .577 .707 r
F P
0 g
s
.5108 .86781 m .51158 .84887 L .49893 .84339 L p .707 .577 .707 r
F P
0 g
s
.49893 .84339 m .49815 .86233 L .5108 .86781 L p .707 .577 .707 r
F P
0 g
s
.69272 .85326 m .69194 .8722 L .69895 .8672 L p .707 .577 .707 r
F P
0 g
s
.69895 .8672 m .69973 .84826 L .69272 .85326 L p .707 .577 .707 r
F P
0 g
s
.49362 .82167 m .4907 .3218 L .44669 .31922 L p .707 .577 .707 r
F P
0 g
s
.4907 .3218 m .49362 .82167 L .53856 .82027 L p .707 .577 .707 r
F P
0 g
s
.53856 .82027 m .53564 .3204 L .4907 .3218 L p .707 .577 .707 r
F P
0 g
s
.53564 .3204 m .53856 .82027 L .58004 .81504 L p .707 .577 .707 r
F P
0 g
s
.58004 .81504 m .57712 .31517 L .53564 .3204 L p .707 .577 .707 r
F P
0 g
s
.49815 .86233 m .49893 .84339 L .49597 .83789 L p .707 .577 .707 r
F P
0 g
s
.49597 .83789 m .49519 .85683 L .49815 .86233 L p .707 .577 .707 r
F P
0 g
s
.44961 .81909 m .44669 .31922 L .40793 .31291 L p .707 .577 .707 r
F P
0 g
s
.44669 .31922 m .44961 .81909 L .49362 .82167 L p .707 .577 .707 r
F P
0 g
s
.57712 .31517 m .58004 .81504 L .614 .80648 L p .707 .577 .707 r
F P
0 g
s
.614 .80648 m .61108 .30661 L .57712 .31517 L p .707 .577 .707 r
F P
0 g
s
.69973 .84826 m .69895 .8672 L .69599 .86169 L p .707 .577 .707 r
F P
0 g
s
.69599 .86169 m .69677 .84275 L .69973 .84826 L p .707 .577 .707 r
F P
0 g
s
.41085 .81278 m .40793 .31291 L .3782 .3035 L p .707 .577 .707 r
F P
0 g
s
.40793 .31291 m .41085 .81278 L .44961 .81909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.49519 .85683 m .49597 .83789 L .50299 .83289 L p .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .24117 .71128 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.24117 .71128 m .22018 .71097 L p .23174 .72587 L .707 .577 .707 r
F P
0 g
s
.2415 .73845 m .24117 .71128 L .23174 .72587 L .707 .577 .707 r
F
.20934 .70867 m .19263 .70513 L p .20268 .721 L F P
0 g
s
.19263 .70513 m .1713 .69448 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19568 .73396 m .19564 .73219 L .1945 .73169 L .707 .577 .707 r
F
.19658 .73571 m .19644 .73255 L p .19568 .73396 L F P
0 g
s
.19644 .73255 m .19263 .70513 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .22405 .74062 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19658 .73571 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .2269 .75925 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19263 .70513 m .19644 .73255 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19934 .75341 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .20934 .70867 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.21192 .73559 m .20934 .70867 L .20268 .721 L .707 .577 .707 r
F
.22393 .73795 m .22018 .71097 L p .21192 .73559 L F P
0 g
s
.19501 .69993 m .19644 .73255 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19501 .69993 L p .19568 .73396 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .1945 .73169 L .17529 .72317 L .707 .577 .707 r
F
.177 .72831 m .19658 .73571 L p .17529 .72317 L F P
0 g
s
.17802 .74275 m .19934 .75341 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.1713 .69448 m .17529 .72317 L p .1789 .71043 L .707 .577 .707 r
F P
0 g
s
.17033 .71832 m .17529 .72317 L .15829 .68005 L .707 .577 .707 r
F
.17471 .72521 m .17465 .72254 L .17356 .72147 L F
.17549 .72774 m .17529 .72317 L p .17471 .72521 L F P
0 g
s
.17529 .72317 m .1713 .69448 L .16257 .6848 L p .707 .577 .707 r
F P
0 g
s
.16257 .6848 m .15829 .68005 L p .17529 .72317 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17392 .69196 L p .17471 .72521 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17549 .72774 L .177 .72831 L p .707 .577 .707 r
F P
0 g
s
.17549 .72774 m .17356 .72147 L .16255 .71072 L .707 .577 .707 r
F
.16371 .71819 m .17549 .72774 L p .16255 .71072 L F P
0 g
s
.165 .72833 m .17802 .74275 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.15829 .68005 m .16255 .71072 L p .16267 .69398 L .707 .577 .707 r
F P
0 g
s
.16148 .70577 m .16255 .71072 L .15486 .66327 L .707 .578 .707 r
F
.16253 .71415 m .16236 .70985 L .16192 .70779 L .707 .577 .707 r
F
.16285 .7175 m .16255 .71072 L p .16253 .71415 L F P
0 g
s
.16255 .71072 m .15829 .68005 L .15633 .6705 L p .707 .578 .707 r
F P
0 g
s
.15633 .6705 m .15486 .66327 L p .16255 .71072 L .707 .578 .707 r
F P
0 g
s
.16255 .71072 m .16128 .68172 L p .16253 .71415 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .16285 .7175 L .16371 .71819 L p .707 .577 .707 r
F P
0 g
s
.16285 .7175 m .16192 .70779 L .15947 .69644 L .707 .577 .707 r
F
.15999 .70637 m .16285 .7175 L p .15947 .69644 L F P
0 g
s
.16157 .71154 m .165 .72833 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16148 .70577 m .15596 .67033 L .15947 .69644 L .707 .578 .707 r
F
.15947 .69644 m .16157 .71154 L p .16148 .70577 L F P
0 g
s
.15832 .67021 m .15947 .69644 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16128 .68172 m .15832 .67021 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16236 .70985 m .16128 .68172 L .16192 .70779 L .707 .577 .707 r
F
.17033 .71832 m .16267 .69398 L .16255 .71072 L F
.16128 .68172 m .16255 .71072 L p .17356 .72147 L F P
0 g
s
.17392 .69196 m .16128 .68172 L p .17356 .72147 L .707 .577 .707 r
F P
0 g
s
.15832 .67021 m .16475 .65951 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.1636 .64342 m .17713 .62926 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.16475 .65951 m .16533 .65855 L p .16493 .66202 L .707 .577 .707 r
F P
0 g
s
.16148 .69213 m .16475 .65951 L .16493 .66202 L .707 .577 .707 r
F
.17026 .67838 m .16635 .6817 L .17713 .62926 L F
.16749 .69247 m .16635 .6817 L .17259 .6764 L F
.165 .72833 m .16255 .71072 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16775 .6949 m .16157 .71154 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .16635 .6817 L p .16749 .69247 L .707 .577 .707 r
F P
0 g
s
.16157 .71154 m .16151 .69207 L .16635 .6817 L .707 .577 .707 r
F
.16157 .71154 m .15947 .69644 L p .16151 .69207 L F P
0 g
s
.15947 .69644 m .15989 .70599 L .15999 .70637 L p .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .15989 .70599 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .16635 .6817 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .1669 .69433 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16135 .64577 m .16635 .6817 L p .16151 .69207 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .1669 .69433 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .1832 .68367 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .20065 .61537 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .18251 .66797 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.18384 .67754 m .18251 .66797 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .17713 .62926 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .22961 .60545 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.20773 .6562 m .20065 .61537 L .2105 .65545 L .707 .577 .707 r
F
.22961 .60545 m .26117 .60047 L p .23888 .64825 L F P
0 g
s
.23705 .64846 m .22961 .60545 L .23888 .64825 L .707 .577 .707 r
F
.26117 .60047 m .29225 .60093 L p .2698 .645 L F P
0 g
s
.26858 .64496 m .26117 .60047 L .2698 .645 L .707 .577 .707 r
F
.29225 .60093 m .3198 .60677 L p .30044 .6462 L F P
0 g
s
.29951 .64602 m .29225 .60093 L .30044 .6462 L .707 .577 .707 r
F
.3198 .60677 m .34113 .61742 L p .32771 .65198 L F P
0 g
s
.34113 .61742 m .35414 .63185 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36018 .69329 m .36144 .67603 L .35506 .67891 L .707 .577 .707 r
F
.36208 .66726 m .36059 .66973 L p .36144 .67603 L F P
0 g
s
.36059 .66973 m .35506 .67891 L p .36144 .67603 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .36208 .66726 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .35757 .64863 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35757 .64863 m .35108 .66613 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .3353 .68264 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35608 .70207 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.3578 .71441 m .36356 .69888 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36334 .6947 m .36151 .69043 L .36356 .69888 L .707 .577 .707 r
F
.35506 .67891 m .35608 .70207 L p .36018 .69329 L F P
0 g
s
.35506 .67891 m .35372 .67979 L p .35421 .68446 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .35608 .70207 L p .35266 .66981 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35108 .66613 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35663 .71469 L .35695 .71417 L p .707 .577 .707 r
F P
0 g
s
.34034 .72535 m .34198 .72428 L p .34166 .72297 L .707 .577 .707 r
F P
0 g
s
.33992 .7158 m .34034 .72535 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.33204 .71956 m .33992 .7158 L .32169 .70332 L .707 .577 .707 r
F
.32086 .70685 m .32169 .70332 L .31178 .69653 L F
.33204 .71956 m .32169 .70332 L .32086 .70685 L F
.33227 .68443 m .31178 .69653 L p .33992 .7158 L F P
0 g
s
.30224 .69979 m .28282 .70645 L p .29406 .71853 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .25126 .71142 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28549 .73818 m .28548 .73529 L .28291 .73559 L .707 .577 .707 r
F
.28701 .73971 m .28681 .73514 L p .28549 .73818 L F P
0 g
s
.28681 .73514 m .28282 .70645 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28701 .73971 m .31635 .73397 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28701 .73971 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .3185 .7448 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .28681 .73514 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28954 .75472 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .30224 .69979 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.30493 .73022 m .30224 .69979 L .29406 .71853 L .707 .577 .707 r
F
.31605 .7272 m .31178 .69653 L p .30493 .73022 L F P
0 g
s
.28545 .70393 m .28681 .73514 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28545 .70393 L p .28549 .73818 L .707 .577 .707 r
F P
0 g
s
.25521 .742 m .28701 .73971 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .25507 .73884 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25364 .70622 m .25507 .73884 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25521 .742 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .28954 .75472 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25798 .7597 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .28681 .73514 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28545 .70393 m .25364 .70622 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.28548 .73529 m .28545 .70393 L .28291 .73559 L .707 .577 .707 r
F
.3148 .73247 m .3148 .72754 L .31083 .72861 L F
.31635 .73397 m .31605 .7272 L p .3148 .73247 L F P
0 g
s
.31635 .73397 m .34034 .72535 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31635 .73397 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .34202 .73091 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .31605 .7272 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .3185 .7448 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .31605 .7272 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31478 .69819 L p .3148 .73247 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .31605 .7272 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .28545 .70393 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.3148 .72754 m .31478 .69819 L .31083 .72861 L .707 .577 .707 r
F
.33992 .7158 m .3353 .68264 L .33227 .68443 L p F P
0 g
s
.3353 .68264 m .33992 .7158 L p .3409 .69054 L .707 .577 .707 r
F P
0 g
s
.33877 .68957 m .31478 .69819 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.33958 .72455 m .33938 .71606 L .334 .71863 L .707 .577 .707 r
F
.33938 .71606 m .33877 .68957 L .334 .71863 L F
.34034 .72535 m .33992 .7158 L p .33958 .72455 L F P
0 g
s
.33992 .7158 m .33877 .68957 L p .33958 .72455 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .33992 .7158 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35083 .70653 L .34166 .72297 L .707 .577 .707 r
F
.34198 .72428 m .35663 .71469 L p .34166 .72297 L F P
0 g
s
.3517 .70579 m .3409 .69054 L .34156 .71441 L .707 .577 .707 r
F
.33992 .7158 m .34202 .73091 L p .3409 .69054 L F P
0 g
s
.33877 .68957 m .33992 .7158 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .3578 .71441 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.3517 .70579 m .34156 .71441 L .34202 .73091 L .707 .577 .707 r
F
.35608 .70207 m .35506 .67891 L p .35083 .70653 L F P
0 g
s
.36151 .69043 m .35266 .66981 L .35608 .70207 L .707 .577 .707 r
F
.35083 .70653 m .35421 .68446 L .33877 .68957 L F
.35372 .67979 m .33877 .68957 L p .35421 .68446 L F P
0 g
s
.35608 .70207 m .3578 .71441 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36429 .69691 m .36296 .68733 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36296 .68733 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36068 .69152 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36135 .67989 m .36287 .68691 L .36365 .70304 L .707 .577 .707 r
F
.35757 .64863 m .36296 .68733 L p .3606 .67641 L .707 .578 .707 r
F P
0 g
s
.36296 .68733 m .36365 .70304 L p .36199 .66877 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .34713 .6606 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35987 .67305 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36068 .69152 m .35987 .67305 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36063 .67794 m .36035 .67525 L .36109 .68093 L .707 .578 .707 r
F
.36035 .67525 m .35757 .64863 L .3606 .67641 L F
.36035 .67525 m .3606 .67641 L .36109 .68093 L F
.36068 .69152 m .34804 .68128 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35757 .64863 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35987 .67305 m .35414 .63185 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35912 .65574 m .35987 .67305 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .36068 .69152 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.36086 .68012 m .35987 .67305 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.36135 .67989 m .35987 .67305 L .36208 .66726 L .707 .577 .707 r
F
.34784 .6657 m .34854 .66197 L .35987 .67305 L F
.35987 .67305 m .36086 .68012 L .35983 .67899 L p F P
0 g
s
.35983 .67899 m .34784 .6657 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .35912 .65574 L .35997 .65907 L p .707 .577 .707 r
F P
0 g
s
.35997 .65907 m .36208 .66726 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.36109 .68093 m .3606 .67641 L .36296 .68733 L .707 .578 .707 r
F
.36135 .67989 m .36199 .66877 L .36287 .68691 L .707 .577 .707 r
F
.36208 .66726 m .36296 .68733 L p .36199 .66877 L F P
0 g
s
.36356 .69888 m .36429 .69691 L p .36334 .6947 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36018 .69329 L .35608 .70207 L .707 .577 .707 r
F
.3578 .71441 m .35608 .70207 L p .35687 .7131 L F P
0 g
s
.35695 .71417 m .36365 .70304 L p .35608 .70207 L .707 .577 .707 r
F P
0 g
s
.35687 .7131 m .35608 .70207 L .3517 .70579 L .707 .577 .707 r
F
.34647 .6455 m .35693 .65397 L p .35407 .66738 L F P
0 g
s
.35693 .65397 m .35912 .65574 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35407 .66738 m .35693 .65397 L .3577 .659 L .707 .577 .707 r
F
.36086 .68012 m .36063 .67794 L .36109 .68093 L .707 .578 .707 r
F
.36296 .68733 m .36429 .69691 L .36416 .69628 L p F P
0 g
s
.36416 .69628 m .36086 .68012 L p .36296 .68733 L .707 .578 .707 r
F P
0 g
s
.34781 .66126 m .34113 .61742 L .34854 .66197 L .707 .577 .707 r
F
.34713 .6606 m .34113 .61742 L p .3482 .6638 L F P
0 g
s
.34713 .6606 m .34647 .6455 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.3482 .6638 m .34781 .66126 L .34854 .66197 L .707 .577 .707 r
F
.34784 .6657 m .34713 .6606 L p .3482 .6638 L F P
0 g
s
.32695 .67331 m .32598 .65122 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .32695 .67331 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34804 .68128 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34784 .6657 m .32652 .65504 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34113 .61742 m .34713 .6606 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34784 .6657 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34647 .6455 m .34713 .6606 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .34151 .64363 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34151 .64363 m .34647 .6455 L p .34352 .64971 L .707 .577 .707 r
F P
0 g
s
.33855 .65679 m .34151 .64363 L .34352 .64971 L .707 .577 .707 r
F
.32687 .65161 m .3198 .60677 L .32771 .65198 L F
.32598 .65122 m .3198 .60677 L p .32716 .6534 L F P
0 g
s
.32598 .65122 m .32538 .63754 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32716 .6534 m .32687 .65161 L .32771 .65198 L .707 .577 .707 r
F
.32652 .65504 m .32598 .65122 L p .32716 .6534 L F P
0 g
s
.29948 .6684 m .29849 .64582 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32695 .67331 m .29948 .6684 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32695 .67331 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32652 .65504 m .29896 .6492 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.3198 .60677 m .32598 .65122 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32652 .65504 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .32598 .65122 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .3179 .6362 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.3179 .6362 m .32538 .63754 L p .32126 .64245 L .707 .577 .707 r
F P
0 g
s
.31561 .64918 m .3179 .6362 L .32126 .64245 L .707 .577 .707 r
F
.29849 .64582 m .29225 .60093 L p .29976 .64758 L F P
0 g
s
.29849 .64582 m .29792 .63262 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29976 .64758 m .29951 .64602 L .30044 .6462 L .707 .577 .707 r
F
.29896 .6492 m .29849 .64582 L p .29976 .64758 L F P
0 g
s
.26832 .66702 m .26735 .64493 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29948 .6684 m .26832 .66702 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29948 .6684 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29896 .6492 m .26789 .64875 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29225 .60093 m .29849 .64582 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29896 .6492 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .29849 .64582 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .28865 .63221 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.28865 .63221 m .29792 .63262 L p .29304 .63828 L .707 .577 .707 r
F P
0 g
s
.28685 .64549 m .28865 .63221 L .29304 .63828 L .707 .577 .707 r
F
.26735 .64493 m .26117 .60047 L p .26888 .64679 L F P
0 g
s
.26735 .64493 m .26675 .63124 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26888 .64679 m .26858 .64496 L .2698 .645 L .707 .577 .707 r
F
.26789 .64875 m .26735 .64493 L p .26888 .64679 L F P
0 g
s
.23652 .66931 m .23561 .64863 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26832 .66702 m .23652 .66931 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26832 .66702 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26789 .64875 m .23632 .65373 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26117 .60047 m .26735 .64493 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26789 .64875 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .26735 .64493 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .25674 .63196 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.25674 .63196 m .26675 .63124 L p .26153 .63782 L .707 .577 .707 r
F P
0 g
s
.25472 .6464 m .25674 .63196 L .26153 .63782 L .707 .577 .707 r
F
.23561 .64863 m .22961 .60545 L p .23752 .65117 L F P
0 g
s
.23561 .64863 m .23495 .63353 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23752 .65117 m .23705 .64846 L .23888 .64825 L .707 .577 .707 r
F
.23632 .65373 m .23561 .64863 L p .23752 .65117 L F P
0 g
s
.20719 .67505 m .20638 .65657 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23652 .66931 m .20719 .67505 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23652 .66931 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23632 .65373 m .20736 .66365 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.22961 .60545 m .23561 .64863 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23632 .65373 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .23561 .64863 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .22564 .63536 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.22564 .63536 m .23495 .63353 L p .22992 .64106 L .707 .577 .707 r
F P
0 g
s
.22247 .6522 m .22564 .63536 L .22992 .64106 L .707 .577 .707 r
F
.20638 .65657 m .20065 .61537 L p .2085 .66067 L F P
0 g
s
.20638 .65657 m .20562 .63927 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.2085 .66067 m .20773 .6562 L .2105 .65545 L .707 .577 .707 r
F
.20736 .66365 m .20638 .65657 L p .2085 .66067 L F P
0 g
s
.20719 .67505 m .1832 .68367 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20719 .67505 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20736 .66365 m .18384 .67754 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .20638 .65657 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20736 .66365 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .20638 .65657 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.19387 .66254 m .18251 .66797 L .20062 .64548 L .707 .577 .707 r
F
.20157 .6473 m .20062 .64548 L .20562 .63927 L F
.19387 .66254 m .20062 .64548 L .20157 .6473 L F
.18251 .66797 m .18163 .64789 L .18331 .64729 L p F P
0 g
s
.18331 .64729 m .20562 .63927 L p .18251 .66797 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .17026 .67838 L .18214 .67765 L .707 .577 .707 r
F
.18384 .67754 m .18207 .6794 L p .18214 .67765 L F P
0 g
s
.18207 .6794 m .16806 .69404 L p .18214 .67765 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .18251 .66797 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .18384 .67754 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18163 .64789 m .18251 .66797 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16806 .69404 L .16775 .6949 L p .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .18163 .64789 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16533 .65855 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .16635 .6817 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16135 .64577 L .1636 .64342 L p .707 .577 .707 r
F P
0 g
s
.15987 .69559 m .15832 .67021 L .16148 .69213 L .707 .577 .707 r
F
.15947 .69644 m .15832 .67021 L p .16029 .70251 L F P
0 g
s
.16151 .69207 m .15947 .69644 L .16135 .64577 L .707 .577 .707 r
F
.16029 .70251 m .15987 .69559 L .16148 .69213 L F
.15989 .70599 m .15947 .69644 L p .16029 .70251 L F P
0 g
s
.15486 .66327 m .15947 .69644 L p .15596 .67033 L .707 .578 .707 r
F P
0 g
s
.15947 .69644 m .15486 .66327 L .15739 .65645 L p .707 .577 .707 r
F P
0 g
s
.15739 .65645 m .16135 .64577 L p .15947 .69644 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .165 .72833 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17802 .74275 m .17529 .72317 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17465 .72254 m .17392 .69196 L .17356 .72147 L .707 .577 .707 r
F
.18754 .7286 m .1789 .71043 L .17529 .72317 L F
.17529 .72317 m .17802 .74275 L p .18754 .7286 L F P
0 g
s
.17392 .69196 m .17529 .72317 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .19644 .73255 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19501 .69993 m .17392 .69196 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19564 .73219 m .19501 .69993 L .1945 .73169 L .707 .577 .707 r
F
.22308 .73926 m .22306 .73778 L .22185 .73754 L F
.22405 .74062 m .22393 .73795 L p .22308 .73926 L F P
0 g
s
.22405 .74062 m .25521 .742 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22405 .74062 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .25798 .7597 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .22393 .73795 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .2269 .75925 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25126 .71142 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .22393 .73795 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22248 .70484 L p .22308 .73926 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .22393 .73795 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .19501 .69993 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.22306 .73778 m .22248 .70484 L .22185 .73754 L .707 .577 .707 r
F
.25364 .70622 m .22248 .70484 L p .25236 .73876 L F P
0 g
s
.25521 .742 m .25507 .73884 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25364 .70622 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .25507 .73884 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.50299 .83289 m .50221 .85183 L .49519 .85683 L p .707 .577 .707 r
F P
0 g
s
.61108 .30661 m .614 .80648 L .6371 .79543 L p .707 .577 .707 r
F P
0 g
s
.6371 .79543 m .63418 .29556 L .61108 .30661 L p .707 .577 .707 r
F P
0 g
s
.69677 .84275 m .69599 .86169 L .68335 .85622 L p .707 .577 .707 r
F P
0 g
s
.68335 .85622 m .68413 .83728 L .69677 .84275 L p .707 .577 .707 r
F P
0 g
s
.24751 .84219 m .24829 .82325 L .21712 .82082 L p .707 .577 .707 r
F P
0 g
s
.24829 .82325 m .24751 .84219 L .27931 .84296 L p .707 .577 .707 r
F P
0 g
s
.27931 .84296 m .28009 .82402 L .24829 .82325 L p .707 .577 .707 r
F P
0 g
s
.38112 .80338 m .3782 .3035 L .36042 .29191 L p .707 .577 .707 r
F P
0 g
s
.3782 .3035 m .38112 .80338 L .41085 .81278 L p .707 .577 .707 r
F P
0 g
s
.28009 .82402 m .27931 .84296 L .30864 .84199 L p .707 .577 .707 r
F P
0 g
s
.30864 .84199 m .30942 .82305 L .28009 .82402 L p .707 .577 .707 r
F P
0 g
s
.21712 .82082 m .21635 .83976 L .24751 .84219 L p .707 .577 .707 r
F P
0 g
s
.50221 .85183 m .50299 .83289 L .51929 .82889 L p .707 .577 .707 r
F P
0 g
s
.21635 .83976 m .21712 .82082 L .18966 .81696 L p .707 .577 .707 r
F P
0 g
s
.51929 .82889 m .51851 .84783 L .50221 .85183 L p .707 .577 .707 r
F P
0 g
s
.18966 .81696 m .18888 .8359 L .21635 .83976 L p .707 .577 .707 r
F P
0 g
s
.30942 .82305 m .30864 .84199 L .33263 .83938 L p .707 .577 .707 r
F P
0 g
s
.33263 .83938 m .33341 .82044 L .30942 .82305 L p .707 .577 .707 r
F P
0 g
s
.18888 .8359 m .18966 .81696 L .16857 .81205 L p .707 .577 .707 r
F P
0 g
s
.68413 .83728 m .68335 .85622 L .66226 .85132 L p .707 .577 .707 r
F P
0 g
s
.66226 .85132 m .66304 .83238 L .68413 .83728 L p .707 .577 .707 r
F P
0 g
s
.63418 .29556 m .6371 .79543 L .6471 .78298 L p .707 .577 .707 r
F P
0 g
s
.6471 .78298 m .64418 .28311 L .63418 .29556 L p .707 .577 .707 r
F P
0 g
s
.16857 .81205 m .16779 .83099 L .18888 .8359 L p .707 .577 .707 r
F P
0 g
s
.51851 .84783 m .51929 .82889 L .54328 .82628 L p .707 .577 .707 r
F P
0 g
s
.54328 .82628 m .5425 .84522 L .51851 .84783 L p .707 .577 .707 r
F P
0 g
s
.33341 .82044 m .33263 .83938 L .34893 .83538 L p .707 .577 .707 r
F P
0 g
s
.34893 .83538 m .34971 .81644 L .33341 .82044 L p .707 .577 .707 r
F P
0 g
s
.36334 .79178 m .36042 .29191 L .35633 .27927 L p .707 .577 .707 r
F P
0 g
s
.36042 .29191 m .36334 .79178 L .38112 .80338 L p .707 .577 .707 r
F P
0 g
s
.16779 .83099 m .16857 .81205 L .15593 .80658 L p .707 .577 .707 r
F P
0 g
s
.66304 .83238 m .66226 .85132 L .63479 .84746 L p .707 .577 .707 r
F P
0 g
s
.63479 .84746 m .63557 .82852 L .66304 .83238 L p .707 .577 .707 r
F P
0 g
s
.15593 .80658 m .15515 .82552 L .16779 .83099 L p .707 .577 .707 r
F P
0 g
s
.5425 .84522 m .54328 .82628 L .57261 .82531 L p .707 .577 .707 r
F P
0 g
s
.57261 .82531 m .57183 .84425 L .5425 .84522 L p .707 .577 .707 r
F P
0 g
s
.63557 .82852 m .63479 .84746 L .60363 .84502 L p .707 .577 .707 r
F P
0 g
s
.60363 .84502 m .60441 .82608 L .63557 .82852 L p .707 .577 .707 r
F P
0 g
s
.34971 .81644 m .34893 .83538 L .35594 .83038 L p .707 .577 .707 r
F P
0 g
s
.35594 .83038 m .35672 .81144 L .34971 .81644 L p .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64301 .77033 L .62523 .75874 L p .707 .577 .707 r
F P
0 g
s
.6385 .58015 m .63507 .56337 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.6471 .78298 m .64423 .77411 L p .64379 .60541 L .707 .577 .707 r
F P
0 g
s
.64379 .60541 m .64469 .60948 L .6471 .78298 L .707 .577 .707 r
F
.64309 .73678 m .64359 .53011 L .64423 .77411 L F
.64549 .50744 m .6471 .78298 L p .64359 .53011 L F P
0 g
s
.64309 .73678 m .64189 .55032 L .64359 .53011 L .707 .577 .707 r
F
.64275 .72557 m .64009 .27046 L p .64309 .73678 L F P
0 g
s
.64379 .60541 m .64359 .53011 L .64469 .60948 L .707 .577 .707 r
F
.64522 .62843 m .65823 .64285 L p .6392 .58238 L F P
0 g
s
.6385 .58015 m .63905 .58413 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.63905 .58413 m .64522 .62843 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64418 .28311 L p .64359 .53011 L .707 .577 .707 r
F P
0 g
s
.64189 .55032 m .64009 .27046 L .64359 .53011 L .707 .577 .707 r
F
.64301 .77033 m .64275 .72557 L p .64309 .73678 L F P
0 g
s
.63614 .68371 m .63536 .70265 L .64214 .70559 L p .707 .577 .707 r
F P
0 g
s
.64214 .70559 m .648 .70812 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.64183 .69542 m .63614 .68371 L .64214 .70559 L .707 .577 .707 r
F
.64522 .62843 m .63905 .58413 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.63905 .58413 m .6385 .58015 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.64423 .77411 m .64301 .77033 L p .64309 .73678 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64878 .68918 L .64154 .68605 L p .707 .577 .707 r
F P
0 g
s
.64154 .68605 m .63614 .68371 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64154 .68605 L .64183 .69542 L .707 .577 .707 r
F
.65823 .64285 m .65151 .59458 L .63931 .58105 L p F P
0 g
s
.63931 .58105 m .6385 .58015 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.65823 .64285 m .63931 .58105 L .6392 .58238 L .707 .577 .707 r
F
.64418 .28311 m .64549 .50744 L p .64359 .53011 L F P
0 g
s
.57183 .84425 m .57261 .82531 L .60441 .82608 L p .707 .577 .707 r
F P
0 g
s
.60441 .82608 m .60363 .84502 L .57183 .84425 L p .707 .577 .707 r
F P
0 g
s
.15515 .82552 m .15593 .80658 L .15297 .80108 L p .707 .577 .707 r
F P
0 g
s
.15297 .80108 m .15219 .82001 L .15515 .82552 L p .707 .577 .707 r
F P
0 g
s
.35633 .27927 m .35925 .77914 L .36334 .79178 L p .707 .577 .707 r
F P
0 g
s
.35925 .77914 m .35633 .27927 L .36633 .26681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35672 .81144 m .35594 .83038 L .35298 .82488 L p .707 .577 .707 r
F P
0 g
s
.35298 .82488 m .35376 .80594 L .35672 .81144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15219 .82001 m .15297 .80108 L .15998 .79608 L p .707 .577 .707 r
F P
0 g
s
.62523 .75874 m .62231 .25887 L .64009 .27046 L p .707 .577 .707 r
F P
0 g
s
.15998 .79608 m .1592 .81502 L .15219 .82001 L p .707 .577 .707 r
F P
0 g
s
.35376 .80594 m .35298 .82488 L .34034 .81941 L p .707 .577 .707 r
F P
0 g
s
.34034 .81941 m .34112 .80047 L .35376 .80594 L p .707 .577 .707 r
F P
0 g
s
.36925 .76668 m .36633 .26681 L .38943 .25576 L p .707 .577 .707 r
F P
0 g
s
.36633 .26681 m .36925 .76668 L .35925 .77914 L p .707 .577 .707 r
F P
0 g
s
.1592 .81502 m .15998 .79608 L .17628 .79208 L p .707 .577 .707 r
F P
0 g
s
.17628 .79208 m .1755 .81102 L .1592 .81502 L p .707 .577 .707 r
F P
0 g
s
.62231 .25887 m .62523 .75874 L .59551 .74933 L p .707 .577 .707 r
F P
0 g
s
.59551 .74933 m .59258 .24946 L .62231 .25887 L p .707 .577 .707 r
F P
0 g
s
.34112 .80047 m .34034 .81941 L .31925 .8145 L p .707 .577 .707 r
F P
0 g
s
.31925 .8145 m .32003 .79556 L .34112 .80047 L p .707 .577 .707 r
F P
0 g
s
.73819 .6598 m .73147 .61152 L .70039 .61107 L p .707 .577 .707 r
F P
0 g
s
.73147 .61152 m .73819 .6598 L .76975 .65482 L p .707 .577 .707 r
F P
0 g
s
.76975 .65482 m .76304 .60655 L .73147 .61152 L p .707 .577 .707 r
F P
0 g
s
.76304 .60655 m .76975 .65482 L .79871 .6449 L p .707 .577 .707 r
F P
0 g
s
.79871 .6449 m .792 .59663 L .76304 .60655 L p .707 .577 .707 r
F P
0 g
s
.39063 .46038 m .39235 .75564 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .38943 .25576 L .42339 .2472 L p .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .4077 .50423 L .42373 .71342 L .707 .577 .707 r
F
.42504 .52891 m .42605 .70231 L p .4077 .50423 L F P
0 g
s
.42605 .70231 m .42631 .74708 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.4077 .50423 m .42605 .70231 L .42373 .71342 L .707 .577 .707 r
F
.46487 .24197 m .46779 .74184 L .42631 .74708 L p F P
0 g
s
.44585 .68231 m .44662 .66337 L .43409 .66378 L p .707 .577 .707 r
F P
0 g
s
.42631 .74708 m .42339 .2472 L .46487 .24197 L p .707 .577 .707 r
F P
0 g
s
.43409 .66378 m .41729 .66434 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.44585 .68231 m .43409 .66378 L .43203 .67362 L .707 .577 .707 r
F
.41729 .66434 m .41651 .68328 L .43011 .68283 L p F P
0 g
s
.43011 .68283 m .44585 .68231 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.43203 .67362 m .41729 .66434 L .43011 .68283 L .707 .577 .707 r
F
.42631 .74708 m .41618 .74963 L p .42373 .71342 L F P
0 g
s
.41618 .74963 m .39235 .75564 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.42339 .2472 m .42504 .52891 L p .4077 .50423 L .707 .577 .707 r
F P
0 g
s
.4557 .60809 m .44954 .56379 L p .42003 .56973 L .707 .577 .707 r
F P
0 g
s
.44954 .56379 m .44899 .55981 L .44718 .56043 L p .707 .577 .707 r
F P
0 g
s
.44718 .56043 m .42003 .56973 L p .44954 .56379 L .707 .577 .707 r
F P
0 g
s
.38846 .57471 m .39518 .62298 L .42372 .61848 L p .707 .577 .707 r
F P
0 g
s
.42372 .61848 m .42674 .61801 L p .42266 .61339 L .707 .577 .707 r
F P
0 g
s
.42266 .61339 m .38846 .57471 L .42372 .61848 L .707 .577 .707 r
F
.39235 .75564 m .36925 .76668 L p .38282 .42309 L F P
0 g
s
.38943 .25576 m .39063 .46038 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.1755 .81102 m .17628 .79208 L .20027 .78947 L p .707 .577 .707 r
F P
0 g
s
.20027 .78947 m .19949 .8084 L .1755 .81102 L p .707 .577 .707 r
F P
0 g
s
.70711 .65935 m .70039 .61107 L .67284 .60523 L p .707 .577 .707 r
F P
0 g
s
.70039 .61107 m .70711 .65935 L .73819 .6598 L p .707 .577 .707 r
F P
0 g
s
.792 .59663 m .79871 .6449 L .82223 .63101 L p .707 .577 .707 r
F P
0 g
s
.82223 .63101 m .81552 .58273 L .792 .59663 L p .707 .577 .707 r
F P
0 g
s
.32003 .79556 m .31925 .8145 L .29178 .81064 L p .707 .577 .707 r
F P
0 g
s
.29178 .81064 m .29256 .7917 L .32003 .79556 L p .707 .577 .707 r
F P
0 g
s
.72772 .71932 m .7285 .70038 L .69734 .69795 L p .707 .577 .707 r
F P
0 g
s
.7285 .70038 m .72772 .71932 L .75952 .72009 L p .707 .577 .707 r
F P
0 g
s
.75952 .72009 m .7603 .70115 L .7285 .70038 L p .707 .577 .707 r
F P
0 g
s
.59258 .24946 m .59551 .74933 L .55674 .74303 L p .707 .577 .707 r
F P
0 g
s
.55674 .74303 m .55382 .24316 L .59258 .24946 L p .707 .577 .707 r
F P
0 g
s
.7603 .70115 m .75952 .72009 L .78885 .71912 L p .707 .577 .707 r
F P
0 g
s
.78885 .71912 m .78963 .70018 L .7603 .70115 L p .707 .577 .707 r
F P
0 g
s
.69734 .69795 m .69656 .71689 L .72772 .71932 L p .707 .577 .707 r
F P
0 g
s
.67956 .65351 m .67284 .60523 L .65151 .59458 L p .707 .577 .707 r
F P
0 g
s
.67284 .60523 m .67956 .65351 L .70711 .65935 L p .707 .577 .707 r
F P
0 g
s
.19949 .8084 m .20027 .78947 L .2296 .7885 L p .707 .577 .707 r
F P
0 g
s
.69656 .71689 m .69734 .69795 L .66987 .69409 L p .707 .577 .707 r
F P
0 g
s
.2296 .7885 m .22882 .80744 L .19949 .8084 L p .707 .577 .707 r
F P
0 g
s
.81552 .58273 m .82223 .63101 L .83801 .61451 L p .707 .577 .707 r
F P
0 g
s
.83801 .61451 m .83129 .56623 L .81552 .58273 L p .707 .577 .707 r
F P
0 g
s
.66987 .69409 m .66909 .71303 L .69656 .71689 L p .707 .577 .707 r
F P
0 g
s
.29256 .7917 m .29178 .81064 L .26062 .80821 L p .707 .577 .707 r
F P
0 g
s
.26062 .80821 m .2614 .78927 L .29256 .7917 L p .707 .577 .707 r
F P
0 g
s
.78963 .70018 m .78885 .71912 L .81284 .71651 L p .707 .577 .707 r
F P
0 g
s
.81284 .71651 m .81362 .69757 L .78963 .70018 L p .707 .577 .707 r
F P
0 g
s
.22882 .80744 m .2296 .7885 L .2614 .78927 L p .707 .577 .707 r
F P
0 g
s
.2614 .78927 m .26062 .80821 L .22882 .80744 L p .707 .577 .707 r
F P
0 g
s
.73543 .76639 m .73386 .73061 L .7027 .72923 L p .707 .577 .707 r
F P
0 g
s
.73386 .73061 m .73543 .76639 L .76723 .7641 L p .707 .577 .707 r
F P
0 g
s
.76723 .7641 m .76566 .72832 L .73386 .73061 L p .707 .577 .707 r
F P
0 g
s
.66909 .71303 m .66987 .69409 L .64878 .68918 L p .707 .577 .707 r
F P
0 g
s
.55382 .24316 m .55674 .74303 L .51273 .74045 L p .707 .577 .707 r
F P
0 g
s
.51273 .74045 m .50981 .24057 L .55382 .24316 L p .707 .577 .707 r
F P
0 g
s
.76566 .72832 m .76723 .7641 L .79656 .75836 L p .707 .577 .707 r
F P
0 g
s
.79656 .75836 m .79499 .72258 L .76566 .72832 L p .707 .577 .707 r
F P
0 g
s
.64878 .68918 m .648 .70812 L .66909 .71303 L p .707 .577 .707 r
F P
0 g
s
.65151 .59458 m .65823 .64285 L .67956 .65351 L p .707 .577 .707 r
F P
0 g
s
.70426 .76501 m .7027 .72923 L .67523 .72432 L p .707 .577 .707 r
F P
0 g
s
.7027 .72923 m .70426 .76501 L .73543 .76639 L p .707 .577 .707 r
F P
0 g
s
.46779 .74184 m .46487 .24197 L .50981 .24057 L p .707 .577 .707 r
F P
0 g
s
.83129 .56623 m .83801 .61451 L .8445 .59701 L p .707 .577 .707 r
F P
0 g
s
.8445 .59701 m .83779 .54873 L .83129 .56623 L p .707 .577 .707 r
F P
0 g
s
.50981 .24057 m .51273 .74045 L .46779 .74184 L p .707 .577 .707 r
F P
0 g
s
.79499 .72258 m .79656 .75836 L .82055 .74974 L p .707 .577 .707 r
F P
0 g
s
.81362 .69757 m .81284 .71651 L .82914 .71251 L p .707 .577 .707 r
F P
0 g
s
.82055 .74974 m .81898 .71396 L .79499 .72258 L p .707 .577 .707 r
F P
0 g
s
.82914 .71251 m .82992 .69357 L .81362 .69757 L p .707 .577 .707 r
F P
0 g
s
.67523 .72432 m .67679 .7601 L .70426 .76501 L p .707 .577 .707 r
F P
0 g
s
.67679 .7601 m .67523 .72432 L .65414 .71635 L p .707 .577 .707 r
F P
0 g
s
.81898 .71396 m .82055 .74974 L .83685 .73908 L p .707 .577 .707 r
F P
0 g
s
.82992 .69357 m .82914 .71251 L .83105 .71115 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83528 .7033 L .83114 .70601 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83114 .70601 L .83073 .73049 L .707 .577 .707 r
F
.83528 .7033 m .83685 .73908 L .84386 .72743 L p F P
0 g
s
.83105 .71115 m .83616 .70751 L p .8313 .69664 L .707 .577 .707 r
F P
0 g
s
.8313 .69664 m .82992 .69357 L .83105 .71115 L .707 .577 .707 r
F
.83114 .70601 m .81898 .71396 L p .83073 .73049 L F P
0 g
s
.83779 .54873 m .8445 .59701 L .84107 .58022 L p .707 .578 .707 r
F P
0 g
s
.84107 .58022 m .83436 .53194 L .83779 .54873 L p .707 .578 .707 r
F P
0 g
s
.65414 .71635 m .65571 .75213 L .67679 .7601 L p .707 .577 .707 r
F P
0 g
s
.84386 .72743 m .84229 .69165 L .83528 .7033 L p .707 .577 .707 r
F P
0 g
s
.83616 .70751 m .83694 .68857 L .82992 .69357 L p .707 .577 .707 r
F P
0 g
s
.65571 .75213 m .65414 .71635 L .64149 .70611 L p .707 .577 .707 r
F P
0 g
s
.63536 .70265 m .63614 .68371 L .63318 .67821 L p .707 .577 .707 r
F P
0 g
s
.63318 .67821 m .6324 .69715 L .63536 .70265 L p .707 .577 .707 r
F P
0 g
s
.63507 .56337 m .64179 .61164 L .64522 .62843 L p .707 .578 .707 r
F P
0 g
s
.64179 .61164 m .63507 .56337 L .64156 .54587 L p .707 .577 .707 r
F P
0 g
s
.64149 .70611 m .64306 .74189 L .65571 .75213 L p .707 .577 .707 r
F P
0 g
s
.83436 .53194 m .84107 .58022 L .82806 .5658 L p .707 .577 .707 r
F P
0 g
s
.82806 .5658 m .82134 .51752 L .83436 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83694 .68857 m .83616 .70751 L .8332 .70201 L p .707 .577 .707 r
F P
0 g
s
.8332 .70201 m .83398 .68307 L .83694 .68857 L p .707 .577 .707 r
F P
0 g
s
.64306 .74189 m .64149 .70611 L .63853 .6946 L p .707 .577 .707 r
F P
0 g
s
.64828 .59414 m .64156 .54587 L .65734 .52936 L p .707 .577 .707 r
F P
0 g
s
.64156 .54587 m .64828 .59414 L .64179 .61164 L p .707 .577 .707 r
F P
0 g
s
.6324 .69715 m .63318 .67821 L .64019 .67321 L p .707 .577 .707 r
F P
0 g
s
.63853 .6946 m .6401 .73038 L .64306 .74189 L p .707 .577 .707 r
F P
0 g
s
.84229 .69165 m .84386 .72743 L .8409 .71591 L p .707 .577 .707 r
F P
0 g
s
.8409 .71591 m .83933 .68014 L .84229 .69165 L p .707 .577 .707 r
F P
0 g
s
.64019 .67321 m .63941 .69215 L .6324 .69715 L p .707 .577 .707 r
F P
0 g
s
.82134 .51752 m .82806 .5658 L .80673 .55514 L p .707 .577 .707 r
F P
0 g
s
.80673 .55514 m .80001 .50687 L .82134 .51752 L p .707 .577 .707 r
F P
0 g
s
.39518 .62298 m .38846 .57471 L .35738 .57425 L p .707 .577 .707 r
F P
0 g
s
.42674 .61801 m .42003 .56973 L .38846 .57471 L p .707 .577 .707 r
F P
0 g
s
.42003 .56973 m .42674 .61801 L .4557 .60809 L p .707 .577 .707 r
F P
0 g
s
.3641 .62253 m .35738 .57425 L .32983 .56841 L p .707 .577 .707 r
F P
0 g
s
.35738 .57425 m .3641 .62253 L .39518 .62298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63941 .69215 m .64019 .67321 L .64354 .67239 L p .707 .577 .707 r
F P
0 g
s
.64354 .67239 m .65649 .66921 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .63853 .6946 L .64377 .6859 L p .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .64377 .6859 L .64395 .69685 L .707 .577 .707 r
F
.63941 .69215 m .64354 .67239 L .64377 .68629 L F
.65649 .66921 m .65571 .68815 L .64385 .69106 L p F P
0 g
s
.64385 .69106 m .63941 .69215 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.64377 .68629 m .65649 .66921 L .64385 .69106 L .707 .577 .707 r
F
.64555 .68294 m .64712 .71872 L .64439 .72324 L p F P
0 g
s
.64439 .72324 m .6401 .73038 L p .64395 .69685 L .707 .577 .707 r
F P
0 g
s
.64395 .69685 m .64555 .68294 L .64439 .72324 L .707 .577 .707 r
F
.64377 .6859 m .64555 .68294 L p .64395 .69685 L F P
0 g
s
.44899 .55981 m .4557 .60809 L .47922 .59419 L p .707 .577 .707 r
F P
0 g
s
.47922 .59419 m .47251 .54592 L .44899 .55981 L p .707 .577 .707 r
F P
0 g
s
.83398 .68307 m .8332 .70201 L .82055 .69654 L p .707 .577 .707 r
F P
0 g
s
.82055 .69654 m .82133 .6776 L .83398 .68307 L p .707 .577 .707 r
F P
0 g
s
.65734 .52936 m .66406 .57764 L .64828 .59414 L p .707 .577 .707 r
F P
0 g
s
.66406 .57764 m .65734 .52936 L .68086 .51547 L p .707 .577 .707 r
F P
0 g
s
.80001 .50687 m .80673 .55514 L .77918 .5493 L p .707 .577 .707 r
F P
0 g
s
.77918 .5493 m .77246 .50103 L .80001 .50687 L p .707 .577 .707 r
F P
0 g
s
.38471 .68251 m .38549 .66357 L .35433 .66113 L p .707 .577 .707 r
F P
0 g
s
.38549 .66357 m .38471 .68251 L .41651 .68328 L p .707 .577 .707 r
F P
0 g
s
.41651 .68328 m .41729 .66434 L .38549 .66357 L p .707 .577 .707 r
F P
0 g
s
.35433 .66113 m .35355 .68007 L .38471 .68251 L p .707 .577 .707 r
F P
0 g
s
.33655 .61669 m .32983 .56841 L .3085 .55776 L p .707 .577 .707 r
F P
0 g
s
.32983 .56841 m .33655 .61669 L .3641 .62253 L p .707 .577 .707 r
F P
0 g
s
.35355 .68007 m .35433 .66113 L .32686 .65727 L p .707 .577 .707 r
F P
0 g
s
.83933 .68014 m .8409 .71591 L .82826 .70567 L p .707 .577 .707 r
F P
0 g
s
.82826 .70567 m .82669 .66989 L .83933 .68014 L p .707 .577 .707 r
F P
0 g
s
.47251 .54592 m .47922 .59419 L .495 .57769 L p .707 .577 .707 r
F P
0 g
s
.495 .57769 m .48828 .52941 L .47251 .54592 L p .707 .577 .707 r
F P
0 g
s
.32686 .65727 m .32608 .67621 L .35355 .68007 L p .707 .577 .707 r
F P
0 g
s
.68758 .56375 m .68086 .51547 L .70982 .50555 L p .707 .577 .707 r
F P
0 g
s
.68086 .51547 m .68758 .56375 L .66406 .57764 L p .707 .577 .707 r
F P
0 g
s
.77246 .50103 m .77918 .5493 L .7481 .54885 L p .707 .577 .707 r
F P
0 g
s
.7481 .54885 m .74138 .50057 L .77246 .50103 L p .707 .577 .707 r
F P
0 g
s
.44662 .66337 m .44585 .68231 L .46983 .6797 L p .707 .577 .707 r
F P
0 g
s
.46983 .6797 m .47061 .66076 L .44662 .66337 L p .707 .577 .707 r
F P
0 g
s
.71654 .55383 m .70982 .50555 L .74138 .50057 L p .707 .577 .707 r
F P
0 g
s
.70982 .50555 m .71654 .55383 L .68758 .56375 L p .707 .577 .707 r
F P
0 g
s
.65571 .68815 m .65649 .66921 L .68048 .6666 L p .707 .577 .707 r
F P
0 g
s
.68048 .6666 m .6797 .68553 L .65571 .68815 L p .707 .577 .707 r
F P
0 g
s
.64712 .71872 m .64555 .68294 L .66184 .67228 L p .707 .577 .707 r
F P
0 g
s
.74138 .50057 m .7481 .54885 L .71654 .55383 L p .707 .577 .707 r
F P
0 g
s
.39242 .72957 m .39085 .6938 L .35969 .69242 L p .707 .577 .707 r
F P
0 g
s
.39085 .6938 m .39242 .72957 L .42422 .72728 L p .707 .577 .707 r
F P
0 g
s
.42422 .72728 m .42265 .69151 L .39085 .6938 L p .707 .577 .707 r
F P
0 g
s
.32608 .67621 m .32686 .65727 L .30577 .65237 L p .707 .577 .707 r
F P
0 g
s
.82133 .6776 m .82055 .69654 L .79947 .69163 L p .707 .577 .707 r
F P
0 g
s
.79947 .69163 m .80025 .67269 L .82133 .6776 L p .707 .577 .707 r
F P
0 g
s
.42265 .69151 m .42422 .72728 L .45355 .72155 L p .707 .577 .707 r
F P
0 g
s
.45355 .72155 m .45198 .68577 L .42265 .69151 L p .707 .577 .707 r
F P
0 g
s
.30577 .65237 m .30499 .67131 L .32608 .67621 L p .707 .577 .707 r
F P
0 g
s
.31522 .60604 m .3085 .55776 L .29549 .54334 L p .707 .577 .707 r
F P
0 g
s
.3085 .55776 m .31522 .60604 L .33655 .61669 L p .707 .577 .707 r
F P
0 g
s
.36125 .7282 m .35969 .69242 L .33222 .6875 L p .707 .577 .707 r
F P
0 g
s
.35969 .69242 m .36125 .7282 L .39242 .72957 L p .707 .577 .707 r
F P
0 g
s
.48828 .52941 m .495 .57769 L .50149 .56019 L p .707 .577 .707 r
F P
0 g
s
.50149 .56019 m .49478 .51191 L .48828 .52941 L p .707 .577 .707 r
F P
0 g
s
.82669 .66989 m .82826 .70567 L .80717 .69771 L p .707 .577 .707 r
F P
0 g
s
.80717 .69771 m .8056 .66193 L .82669 .66989 L p .707 .577 .707 r
F P
0 g
s
.66184 .67228 m .66341 .70806 L .64712 .71872 L p .707 .577 .707 r
F P
0 g
s
.45198 .68577 m .45355 .72155 L .47754 .71293 L p .707 .577 .707 r
F P
0 g
s
.47061 .66076 m .46983 .6797 L .48613 .6757 L p .707 .577 .707 r
F P
0 g
s
.47754 .71293 m .47597 .67715 L .45198 .68577 L p .707 .577 .707 r
F P
0 g
s
.48613 .6757 m .48691 .65676 L .47061 .66076 L p .707 .577 .707 r
F P
0 g
s
.33222 .6875 m .33378 .72328 L .36125 .7282 L p .707 .577 .707 r
F P
0 g
s
.33378 .72328 m .33222 .6875 L .31113 .67954 L p .707 .577 .707 r
F P
0 g
s
.30499 .67131 m .30577 .65237 L .29313 .64689 L p .707 .577 .707 r
F P
0 g
s
.80025 .67269 m .79947 .69163 L .772 .68777 L p .707 .577 .707 r
F P
0 g
s
.772 .68777 m .77278 .66883 L .80025 .67269 L p .707 .577 .707 r
F P
0 g
s
.6797 .68553 m .68048 .6666 L .70981 .66563 L p .707 .577 .707 r
F P
0 g
s
.66341 .70806 m .66184 .67228 L .68583 .66366 L p .707 .577 .707 r
F P
0 g
s
.29313 .64689 m .29235 .66583 L .30499 .67131 L p .707 .577 .707 r
F P
0 g
s
.30221 .59161 m .29549 .54334 L .29206 .52655 L p .707 .578 .707 r
F P
0 g
s
.29549 .54334 m .30221 .59161 L .31522 .60604 L p .707 .577 .707 r
F P
0 g
s
.47597 .67715 m .47754 .71293 L .49384 .70227 L p .707 .577 .707 r
F P
0 g
s
.48691 .65676 m .48613 .6757 L .48804 .67433 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .49227 .66649 L .48813 .6692 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .48813 .6692 L .48772 .69367 L .707 .577 .707 r
F
.49227 .66649 m .49384 .70227 L .50085 .69061 L p F P
0 g
s
.48804 .67433 m .49315 .6707 L p .48829 .65983 L .707 .577 .707 r
F P
0 g
s
.48829 .65983 m .48691 .65676 L .48804 .67433 L .707 .577 .707 r
F
.48813 .6692 m .47597 .67715 L p .48772 .69367 L F P
0 g
s
.70981 .66563 m .70903 .68457 L .6797 .68553 L p .707 .577 .707 r
F P
0 g
s
.8056 .66193 m .80717 .69771 L .7797 .69279 L p .707 .577 .707 r
F P
0 g
s
.7797 .69279 m .77813 .65701 L .8056 .66193 L p .707 .577 .707 r
F P
0 g
s
.49478 .51191 m .50149 .56019 L .49806 .54341 L p .707 .578 .707 r
F P
0 g
s
.49806 .54341 m .49135 .49513 L .49478 .51191 L p .707 .578 .707 r
F P
0 g
s
.31113 .67954 m .3127 .71531 L .33378 .72328 L p .707 .577 .707 r
F P
0 g
s
.68583 .66366 m .6874 .69944 L .66341 .70806 L p .707 .577 .707 r
F P
0 g
s
.77278 .66883 m .772 .68777 L .74084 .68534 L p .707 .577 .707 r
F P
0 g
s
.74084 .68534 m .74162 .6664 L .77278 .66883 L p .707 .577 .707 r
F P
0 g
s
.50085 .69061 m .49928 .65483 L .49227 .66649 L p .707 .577 .707 r
F P
0 g
s
.49315 .6707 m .49393 .65176 L .48691 .65676 L p .707 .577 .707 r
F P
0 g
s
.70903 .68457 m .70981 .66563 L .74162 .6664 L p .707 .577 .707 r
F P
0 g
s
.6874 .69944 m .68583 .66366 L .71517 .65792 L p .707 .577 .707 r
F P
0 g
s
.3127 .71531 m .31113 .67954 L .29848 .66929 L p .707 .577 .707 r
F P
0 g
s
.74162 .6664 m .74084 .68534 L .70903 .68457 L p .707 .577 .707 r
F P
0 g
s
.77813 .65701 m .7797 .69279 L .74854 .69141 L p .707 .577 .707 r
F P
0 g
s
.74854 .69141 m .74697 .65563 L .77813 .65701 L p .707 .577 .707 r
F P
0 g
s
.29235 .66583 m .29313 .64689 L .29017 .64139 L p .707 .577 .707 r
F P
0 g
s
.71673 .6937 m .71517 .65792 L .74697 .65563 L p .707 .577 .707 r
F P
0 g
s
.71517 .65792 m .71673 .6937 L .6874 .69944 L p .707 .577 .707 r
F P
0 g
s
.29017 .64139 m .28939 .66033 L .29235 .66583 L p .707 .577 .707 r
F P
0 g
s
.29206 .52655 m .29878 .57483 L .30221 .59161 L p .707 .578 .707 r
F P
0 g
s
.29878 .57483 m .29206 .52655 L .29855 .50905 L p .707 .577 .707 r
F P
0 g
s
.74697 .65563 m .74854 .69141 L .71673 .6937 L p .707 .577 .707 r
F P
0 g
s
.29848 .66929 m .30005 .70507 L .3127 .71531 L p .707 .577 .707 r
F P
0 g
s
.49135 .49513 m .49806 .54341 L .48505 .52898 L p .707 .577 .707 r
F P
0 g
s
.48505 .52898 m .47833 .4807 L .49135 .49513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49393 .65176 m .49315 .6707 L .49019 .66519 L p .707 .577 .707 r
F P
0 g
s
.49019 .66519 m .49097 .64625 L .49393 .65176 L p .707 .577 .707 r
F P
0 g
s
.30005 .70507 m .29848 .66929 L .29552 .65778 L p .707 .577 .707 r
F P
0 g
s
.30527 .55733 m .29855 .50905 L .31433 .49255 L p .707 .577 .707 r
F P
0 g
s
.29855 .50905 m .30527 .55733 L .29878 .57483 L p .707 .577 .707 r
F P
0 g
s
.28939 .66033 m .29017 .64139 L .29718 .63639 L p .707 .577 .707 r
F P
0 g
s
.29552 .65778 m .29709 .69356 L .30005 .70507 L p .707 .577 .707 r
F P
0 g
s
.49928 .65483 m .50085 .69061 L .49789 .6791 L p .707 .577 .707 r
F P
0 g
s
.49789 .6791 m .49632 .64332 L .49928 .65483 L p .707 .577 .707 r
F P
0 g
s
.29718 .63639 m .2964 .65533 L .28939 .66033 L p .707 .577 .707 r
F P
0 g
s
.47833 .4807 m .48505 .52898 L .46372 .51833 L p .707 .577 .707 r
F P
0 g
s
.46372 .51833 m .457 .47005 L .47833 .4807 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2964 .65533 m .29718 .63639 L .30053 .63557 L p .707 .577 .707 r
F P
0 g
s
.30053 .63557 m .31348 .63239 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .29552 .65778 L .30076 .64908 L p .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .30076 .64908 L .30094 .66004 L .707 .577 .707 r
F
.2964 .65533 m .30053 .63557 L .30076 .64948 L F
.31348 .63239 m .3127 .65133 L .30084 .65424 L p F P
0 g
s
.30084 .65424 m .2964 .65533 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.30076 .64948 m .31348 .63239 L .30084 .65424 L .707 .577 .707 r
F
.30254 .64613 m .3041 .6819 L .30138 .68643 L p F P
0 g
s
.30138 .68643 m .29709 .69356 L p .30094 .66004 L .707 .577 .707 r
F P
0 g
s
.30094 .66004 m .30254 .64613 L .30138 .68643 L .707 .577 .707 r
F
.30076 .64908 m .30254 .64613 L p .30094 .66004 L F P
0 g
s
.49097 .64625 m .49019 .66519 L .47754 .65972 L p .707 .577 .707 r
F P
0 g
s
.47754 .65972 m .47832 .64078 L .49097 .64625 L p .707 .577 .707 r
F P
0 g
s
.31433 .49255 m .32105 .54082 L .30527 .55733 L p .707 .577 .707 r
F P
0 g
s
.32105 .54082 m .31433 .49255 L .33785 .47865 L p .707 .577 .707 r
F P
0 g
s
.457 .47005 m .46372 .51833 L .43617 .51249 L p .707 .577 .707 r
F P
0 g
s
.43617 .51249 m .42945 .46421 L .457 .47005 L p .707 .577 .707 r
F P
0 g
s
.49632 .64332 m .49789 .6791 L .48525 .66886 L p .707 .577 .707 r
F P
0 g
s
.48525 .66886 m .48368 .63308 L .49632 .64332 L p .707 .577 .707 r
F P
0 g
s
.34457 .52693 m .33785 .47865 L .36681 .46873 L p .707 .577 .707 r
F P
0 g
s
.33785 .47865 m .34457 .52693 L .32105 .54082 L p .707 .577 .707 r
F P
0 g
s
.42945 .46421 m .43617 .51249 L .40509 .51203 L p .707 .577 .707 r
F P
0 g
s
.40509 .51203 m .39837 .46376 L .42945 .46421 L p .707 .577 .707 r
F P
0 g
s
.37353 .51701 m .36681 .46873 L .39837 .46376 L p .707 .577 .707 r
F P
0 g
s
.36681 .46873 m .37353 .51701 L .34457 .52693 L p .707 .577 .707 r
F P
0 g
s
.3127 .65133 m .31348 .63239 L .33747 .62978 L p .707 .577 .707 r
F P
0 g
s
.33747 .62978 m .33669 .64872 L .3127 .65133 L p .707 .577 .707 r
F P
0 g
s
.3041 .6819 m .30254 .64613 L .31883 .63546 L p .707 .577 .707 r
F P
0 g
s
.39837 .46376 m .40509 .51203 L .37353 .51701 L p .707 .577 .707 r
F P
0 g
s
.47832 .64078 m .47754 .65972 L .45646 .65481 L p .707 .577 .707 r
F P
0 g
s
.45646 .65481 m .45724 .63587 L .47832 .64078 L p .707 .577 .707 r
F P
0 g
s
.48368 .63308 m .48525 .66886 L .46416 .66089 L p .707 .577 .707 r
F P
0 g
s
.46416 .66089 m .46259 .62511 L .48368 .63308 L p .707 .577 .707 r
F P
0 g
s
.31883 .63546 m .3204 .67124 L .3041 .6819 L p .707 .577 .707 r
F P
0 g
s
.45724 .63587 m .45646 .65481 L .42899 .65096 L p .707 .577 .707 r
F P
0 g
s
.42899 .65096 m .42977 .63202 L .45724 .63587 L p .707 .577 .707 r
F P
0 g
s
.33669 .64872 m .33747 .62978 L .3668 .62881 L p .707 .577 .707 r
F P
0 g
s
.3204 .67124 m .31883 .63546 L .34282 .62684 L p .707 .577 .707 r
F P
0 g
s
.3668 .62881 m .36602 .64775 L .33669 .64872 L p .707 .577 .707 r
F P
0 g
s
.46259 .62511 m .46416 .66089 L .43669 .65598 L p .707 .577 .707 r
F P
0 g
s
.43669 .65598 m .43512 .6202 L .46259 .62511 L p .707 .577 .707 r
F P
0 g
s
.34282 .62684 m .34439 .66262 L .3204 .67124 L p .707 .577 .707 r
F P
0 g
s
.42977 .63202 m .42899 .65096 L .39783 .64852 L p .707 .577 .707 r
F P
0 g
s
.39783 .64852 m .39861 .62958 L .42977 .63202 L p .707 .577 .707 r
F P
0 g
s
.36602 .64775 m .3668 .62881 L .39861 .62958 L p .707 .577 .707 r
F P
0 g
s
.34439 .66262 m .34282 .62684 L .37215 .62111 L p .707 .577 .707 r
F P
0 g
s
.39861 .62958 m .39783 .64852 L .36602 .64775 L p .707 .577 .707 r
F P
0 g
s
.43512 .6202 m .43669 .65598 L .40553 .6546 L p .707 .577 .707 r
F P
0 g
s
.40553 .6546 m .40396 .61882 L .43512 .6202 L p .707 .577 .707 r
F P
0 g
s
.37372 .65689 m .37215 .62111 L .40396 .61882 L p .707 .577 .707 r
F P
0 g
s
.37215 .62111 m .37372 .65689 L .34439 .66262 L p .707 .577 .707 r
F P
0 g
s
.40396 .61882 m .40553 .6546 L .37372 .65689 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00O7oo1P000UYF00<005YFFUH02EYF00<005YFFUH015YF2@00OGoo001fOol60008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1U
Ool006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF20000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP000UYF10000UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH000030006
FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00H7oo0P001UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00FWoo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00F7oo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EWoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Ioo`l0
041oo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00011oo`H000AJEP03001JEUYF00IJEP03
001JEP0000<003aoo`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Uoo`00E7oo00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00D005YF
FUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
00002goo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=goo001DOol0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH20003FUH40002
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00009Ool20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02000eOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD0
009JEP03001JEUYF00IJEP8000MJEP<000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000Moo`<000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01@001UYF00<005YFFUH01UYF0P002UYF0P000eYF00@005YFFUH000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF0`0000Eoo`00FUIJEP0000IJEP03
001JEUYF00IJEP8000YJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00@007ooOomoo`8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00035oo`00Dgoo
00<005YF00001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
1000FUIJEUYF0P000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000Woo00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@0
05YFFUH000Moo`03001JEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF009JEP80009JEP05
001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000Ool00000
1eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002moo`00Dgoo00<005YF00001EYF0`0027oo00<005YF00001UYF00<005YFFUH0
1UYF0P002UYF00H005YFFUIJEP00FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
0`00FUH00005FUH00`00Oomoo`08Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH02000FUIJ
EUYF001JEP00FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00004FUH00`00Oomoo`09
Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH01000FUIJEP000eYF00<005YF00000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF008002ioo`00Dgoo00@005YFFUH0009JEP03001oogoo00Yoo`03001JEP0000IJEP03
001JEUYF00IJEP8000YJEP03001JEP0000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000^Ool005=oo`06001JEUYF001JEP003Goo00<005YF00001UYF00<005YFFUH01UYF0P002UYF
0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`9JEP8000ioo`03001JEP0000IJEP03001J
EUYF00IJEP8000QJEP80009JEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
1P004Goo1@001EYF00@005YFFUH002ioo`00E7oo0UYF0P003Woo00<005YF00001UYF00<005YFFUH0
1UYF0P001UYF0P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000L
Ool20003FUH01000FUIJEP00;Woo001DOol2FUH4000<Ool00`00FUH00006FUH30006FUH20004FUH2
0007FUH01@00FUIJEUYF00000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYF0002FUH01@00FUIJEUYF00001eYF00<005YF00000P0087oo0P0000EJEP00FUIJEP0002io
o`00E7oo00AJEP00FUH0009JEP8000Yoo`03001JEP0000EJEPD000EJEP80009JEP800003FUH005YF
00IJEP05001JEUYFFUH00002FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUH0009JEP05001JEUYFFUH00007FUH2000UOol20002FUH2000]Ool005Aoo`04FUH005YF0004
FUH30007Ool00`00FUH00005FUH50005FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH00UYF0P00:Goo00@005YF000002eoo`00E7oo0P000UYF00<005YFFUH00UYF00<0
05YF00000`000goo00<005YF00001EYF2`001UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009J
EP03001JEUYF008002Yoo`<00003FUH007oo02aoo`00E7oo0P000UYF00<005YFFUH00UYF00<005YF
FUH00eYF400015YF00<005YFFUH01EYF0P001UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP<002Yo
o`800005FUH00000FUH0000]Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
15YF00<007ooOol0:Goo00H005YFFUIJEP00FUH2000]Ool005Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0UYF00@005YFFUH002]oo`03001JEUYF00=JEP03001JEP0002eoo`00EGoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUH0000ZOol30005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP8002Yoo`04001J
EUYF0005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001oogoo02Moo`8000=J
EP03001JEUYF00=JEP04001JEUYF000/Ool005Ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH20009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P005goo0`0037oo0P001UYF00<005YF
FUH00UYF00@005YFFUH002aoo`00B7oo3@000Woo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0057oo1@0027oo0`0000=J
EP00FUH01EYF00<005YFFUH00UYF00@005YFFUH002aoo`00A7oo10000UYF00<005YFFUH01UYF00<0
05YF0000100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000UYF0P004Woo1@001Goo0`0015YF00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo0010Ool4
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF1@003Goo2P001eYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo000nOol200000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00@005YFFUIJEQ4000AJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00>goo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH2000015YF000000001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00
>7oo0`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000IJ
EP03001JEUYF00AJEPd000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool0
03Ioo`800003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPD0009JEPL000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF000`Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP00Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF0000<Goo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000bOol0035oo`8000IJEP03001JEUYF
00IJEP04001JEUYFFUHA00000eYF0000000600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`0aOol0031oo`03001J
EP0000IJEP03001JEUYF009JEPP000EJEP8000MJEP@00004FUH000000005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8003Ao
o`00;goo00@005YFFUH000MJEP@000AJEP03001JEUYF00IJEP8000IJEP8000AJEP8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF000f
Ool002ioo`05001JEUYFFUH00005FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH400000goo001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH3000gOol002eoo`03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8003Uoo`00;Goo00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YF
FUH01eYF1`0000AJEP00000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH400000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000kOol002aoo`03001JEUYF00=JEP80
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00=JEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P00?Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF10002EYF00<005YF
FUH00eYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00AJEQP000=JEP03001JEUYF
00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP02FUH600000eYF001JEP06FUH?000nOol002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUH000020003FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30000
0eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40005FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P001EYF00<005YFFUH00UYF0P000goo2@0015YF00<005YFFUH01UYF00<005YF
00000`00>Woo000/Ool01000FUH000000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH00UYF8P000UYF0P000eYF00D005YFFUIJEP00
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Moo`00
;7oo00@005YF000000=JEP03001JEUYF009JEP<000QJEP03001JEUYF009JEPT0009JEP800003FUH0
05YF00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<00003FUH005YF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002000dOol002aoo`04001JEP000003FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF2@002Goo100000=JEP00FUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P000eYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEPX0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo00@005YFFUH000AJEP<0
00=JEPD001Eoo`03001JEP00009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<Goo000/Ool0
1000FUIJEP0015YF00@005YFFUIJEP8001Yoo`03001JEP000080009oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP@0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`04001JEUYF0003FUH200000eYF0000000LOol01000FUH005YF0P001Woo2@0015YF00<005YF
00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP04001JEP000002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000UYF00@005YF000001ioo`06001J
EUYFFUH005YF0`0000=oo`0000000eYF00D005YFFUH005YF01`000=JEP06001JEUYFFUH005YF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF001JEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool01000FUH005YF0`0087oo0P000UYF00<005YF
FUH00UYF1P0000IJEP00000005YF0005FUH50006FUH01000FUIJEUYF1@001EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`03001JEP000080029oo`80009JEP03
001JEUYF00=JEP04001JEUYFFUH90003FUH500000eYF000000070003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUH005YF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01000FUH005YF0`0087oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF20002Goo200015YF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool3000015YF001JEUYF0P007Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF2@005Woo1P0015YF00<005YFFUH0
0P00;Goo000]Ool20002FUH00`00FUIJEP02FUH5000HOol30002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001JEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF6@000eYF0`0000=JEP00
FUH00UYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP07FUHI00001EYF001JEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P000eYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP0D
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00Oomoo`0[
Ool002eoo`80009JEP03001JEUYF01AJEP03001JEUYF00IJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000UYF2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF0000
05YF00@002eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF1000
1Woo2@0015YF00<005YFFUH00`000eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEP00
02eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00X005YFFUIJEP00FUH005YF001JEP<0009o
o`03001JEUYF0080009JEP800003Ool0000001/00003FUH005YF00=JEP03001JEP0002eoo`00;Woo
00@005YFFUH001IJEP<000IJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00UYF0`0000EJEP00001JEP00
009JEP03001oogoo00Eoo`D000]oo`<000EJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@0
05YFFUH001EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUH0000300000eYF000000020006Ool5
0007Ool400000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000]Ool002ioo`04001JEUYF000E
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00Oomoo`0@0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH00eYF5`001EYF00<005YFFUH015YF00D005YFFUIooeYF0080
02ioo`00;goo00<005YF00005EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001Goo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUIo
o`02000^Ool0031oo`03001JEP0000AJEP03001JEUYF00iJEP<000IJEP03001JEUYF00IJEP03001J
EUYF008000Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000;goo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUHF
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YFFUIJEP0002moo`00<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P002goo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01P00
2UYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF000`Ool003=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF009JEP8000eoo`03001JEP0000IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
035oo`00=Goo0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
3goo00<005YF00001UYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000cOol003Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP@0019oo`03001JEP0000IJEP@00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00003000eOol003aoo`T000AJEP03001JEUYF00@001Ioo`03001JEP00
00AJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP@000EJEP06001JEUYFFUH005YF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`00>Goo0015Ool7000JOol00`00FUH00002FUH20007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00
FUIJEUYF000015YF00D005YFFUIJEP0000=JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@003aoo`00IWoo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
00D005YFFUIJEP0000MJEQX0041oo`00IWoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF00000eYF00<005YFFUH015YF00<007ooOol0F7oo0018Ool3000KOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP02FUH2001KOol004Moo`D001Yoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYF001MOol004Moo`D001Yo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP<005ioo`00Agoo1@006Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000eYF0P00H7oo0018Ool3000KOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF00000000HWoo000fOolI000HOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001UOol0031oo`H0009JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP0011oo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001oogoo06Eoo`00;Goo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]oo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP8006Moo`00:goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002Goo0`001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Uoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000006]oo`00:goo00<0
05YF00000eYF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00Uoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP@006eoo`00:goo00<005YF00000UYF1@006Goo200015YF00<005YFFUH00eYF00@0
05YFFUIJEP8000Yoo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00H0071oo`00:goo00<005YF00000P0000AJEP000000029oo`L000=JEP04001J
EUYFFUH2000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool5
001_Ool002]oo`80009JEP03001JEUYF009JEPD002Aoo`@000=JEP8001Aoo``000IJEP03001JEUYF
00YJEP03001JEUYF00H000Moo`D006moo`00:goo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
01Uoo`P00003FUH00000021ooaH000eoo`D006moo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF009JEQT000=JEP03001JEUYF009JEP<0035ooaT006eoo`00;Goo0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00:goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000IGoo
000_Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000XOol30002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00Ggoo000bOol70004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000XOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002001LOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH6000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001IOol0049ooaT0035oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP00008005Ioo`00S7oo00<005YF000015YF00@005YFFUIJEQl0
00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP00009JEPH001moo`@0009J
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP0000<0009JEPL001moo`D000=J
EP03001JEUYF008005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT001Uoo`H0009J
EP8005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF
00<005YFFUH01000EWoo002=Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002?Ool4
0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0005Ioo`00Tgoo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8005Moo`00UWoo1@000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000005Uo
o`00Vgoo4@0015YF00<005YFFUH00UYF3@00Fgoo002/Ool9001XOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59427 .74824 m .58418 .74809 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.58418 .74809 m .56319 .74779 L p .57475 .76269 L .707 .577 .707 r
F P
0 g
s
.5845 .77527 m .58418 .74809 L .57475 .76269 L .707 .577 .707 r
F
.55235 .74549 m .53564 .74195 L p .54569 .75782 L F P
0 g
s
.53564 .74195 m .51431 .73129 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53869 .77078 m .53865 .76901 L .53751 .7685 L .707 .577 .707 r
F
.53959 .77252 m .53945 .76936 L p .53869 .77078 L F P
0 g
s
.53945 .76936 m .53564 .74195 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .56706 .77744 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53959 .77252 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .56991 .79606 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53564 .74195 m .53945 .76936 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .54235 .79022 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .55235 .74549 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.55492 .7724 m .55235 .74549 L .54569 .75782 L .707 .577 .707 r
F
.56694 .77476 m .56319 .74779 L p .55492 .7724 L F P
0 g
s
.53802 .73674 m .53945 .76936 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.53945 .76936 m .53802 .73674 L p .53869 .77078 L .707 .577 .707 r
F P
0 g
s
.53959 .77252 m .53751 .7685 L .5183 .75998 L .707 .577 .707 r
F
.52001 .76512 m .53959 .77252 L p .5183 .75998 L F P
0 g
s
.52103 .77957 m .54235 .79022 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.51431 .73129 m .5183 .75998 L p .5219 .74725 L .707 .577 .707 r
F P
0 g
s
.51334 .75513 m .5183 .75998 L .5013 .71687 L .707 .577 .707 r
F
.51772 .76203 m .51766 .75935 L .51657 .75829 L F
.5185 .76455 m .5183 .75998 L p .51772 .76203 L F P
0 g
s
.5183 .75998 m .51431 .73129 L .50558 .72162 L p .707 .577 .707 r
F P
0 g
s
.50558 .72162 m .5013 .71687 L p .5183 .75998 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .51693 .72878 L p .51772 .76203 L .707 .577 .707 r
F P
0 g
s
.5183 .75998 m .5185 .76455 L .52001 .76512 L p .707 .577 .707 r
F P
0 g
s
.5185 .76455 m .51657 .75829 L .50556 .74754 L .707 .577 .707 r
F
.50672 .75501 m .5185 .76455 L p .50556 .74754 L F P
0 g
s
.50801 .76514 m .52103 .77957 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.5013 .71687 m .50556 .74754 L p .50568 .73079 L .707 .577 .707 r
F P
0 g
s
.50449 .74258 m .50556 .74754 L .49787 .70008 L .707 .578 .707 r
F
.50554 .75097 m .50537 .74666 L .50493 .74461 L .707 .577 .707 r
F
.50586 .75431 m .50556 .74754 L p .50554 .75097 L F P
0 g
s
.50556 .74754 m .5013 .71687 L .49934 .70732 L p .707 .578 .707 r
F P
0 g
s
.49934 .70732 m .49787 .70008 L p .50556 .74754 L .707 .578 .707 r
F P
0 g
s
.50556 .74754 m .50429 .71853 L p .50554 .75097 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50586 .75431 L .50672 .75501 L p .707 .577 .707 r
F P
0 g
s
.50586 .75431 m .50493 .74461 L .50248 .73325 L .707 .577 .707 r
F
.503 .74318 m .50586 .75431 L p .50248 .73325 L F P
0 g
s
.50458 .74836 m .50801 .76514 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.50449 .74258 m .49897 .70714 L .50248 .73325 L .707 .578 .707 r
F
.50248 .73325 m .50458 .74836 L p .50449 .74258 L F P
0 g
s
.50133 .70702 m .50248 .73325 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50429 .71853 m .50133 .70702 L p .50493 .74461 L .707 .577 .707 r
F P
0 g
s
.50537 .74666 m .50429 .71853 L .50493 .74461 L .707 .577 .707 r
F
.51334 .75513 m .50568 .73079 L .50556 .74754 L F
.50429 .71853 m .50556 .74754 L p .51657 .75829 L F P
0 g
s
.51693 .72878 m .50429 .71853 L p .51657 .75829 L .707 .577 .707 r
F P
0 g
s
.50133 .70702 m .50776 .69633 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50661 .68023 m .52014 .66608 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50776 .69633 m .50834 .69537 L p .50794 .69884 L .707 .577 .707 r
F P
0 g
s
.50449 .72895 m .50776 .69633 L .50794 .69884 L .707 .577 .707 r
F
.51327 .7152 m .50936 .71852 L .52014 .66608 L F
.5105 .72929 m .50936 .71852 L .5156 .71321 L F
.50801 .76514 m .50556 .74754 L p .50449 .74258 L .707 .578 .707 r
F P
0 g
s
.51076 .73172 m .50458 .74836 L p .50936 .71852 L .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .50936 .71852 L p .5105 .72929 L .707 .577 .707 r
F P
0 g
s
.50458 .74836 m .50452 .72889 L .50936 .71852 L .707 .577 .707 r
F
.50458 .74836 m .50248 .73325 L p .50452 .72889 L F P
0 g
s
.50248 .73325 m .5029 .7428 L .503 .74318 L p .707 .577 .707 r
F P
0 g
s
.50991 .73114 m .5029 .7428 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .50936 .71852 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50991 .73114 L p .50449 .72895 L .707 .577 .707 r
F P
0 g
s
.50436 .68258 m .50936 .71852 L p .50452 .72889 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .50991 .73114 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52621 .72048 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .54366 .65219 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52621 .72048 m .52552 .70478 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.52685 .71435 m .52552 .70478 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52014 .66608 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .57262 .64227 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.55074 .69302 m .54366 .65219 L .5535 .69227 L .707 .577 .707 r
F
.57262 .64227 m .60418 .63729 L p .58189 .68507 L F P
0 g
s
.58006 .68528 m .57262 .64227 L .58189 .68507 L .707 .577 .707 r
F
.60418 .63729 m .63526 .63774 L p .61281 .68181 L F P
0 g
s
.61159 .68178 m .60418 .63729 L .61281 .68181 L .707 .577 .707 r
F
.63526 .63774 m .66281 .64358 L p .64345 .68302 L F P
0 g
s
.64252 .68283 m .63526 .63774 L .64345 .68302 L .707 .577 .707 r
F
.66281 .64358 m .68414 .65424 L p .67071 .6888 L F P
0 g
s
.68414 .65424 m .69715 .66866 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70319 .7301 m .70445 .71285 L .69807 .71573 L .707 .577 .707 r
F
.70509 .70407 m .7036 .70655 L p .70445 .71285 L F P
0 g
s
.7036 .70655 m .69807 .71573 L p .70445 .71285 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70509 .70407 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70597 .72415 m .70058 .68545 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70058 .68545 m .69409 .70295 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .67831 .71945 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69909 .73888 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.70081 .75122 m .70657 .73569 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70635 .73151 m .70452 .72725 L .70657 .73569 L .707 .577 .707 r
F
.69807 .71573 m .69909 .73888 L p .70319 .7301 L F P
0 g
s
.69807 .71573 m .69673 .71661 L p .69722 .72128 L .707 .577 .707 r
F P
0 g
s
.69409 .70295 m .69909 .73888 L p .69567 .70663 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69409 .70295 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69909 .73888 m .69964 .75151 L .69996 .75098 L p .707 .577 .707 r
F P
0 g
s
.68334 .76217 m .68499 .76109 L p .68467 .75979 L .707 .577 .707 r
F P
0 g
s
.68293 .75262 m .68334 .76217 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.67505 .75638 m .68293 .75262 L .6647 .74013 L .707 .577 .707 r
F
.66387 .74366 m .6647 .74013 L .65479 .73334 L F
.67505 .75638 m .6647 .74013 L .66387 .74366 L F
.67528 .72124 m .65479 .73334 L p .68293 .75262 L F P
0 g
s
.64525 .73661 m .62583 .74326 L p .63707 .75535 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .59427 .74824 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.6285 .77499 m .62849 .77211 L .62592 .77241 L .707 .577 .707 r
F
.63002 .77652 m .62982 .77195 L p .6285 .77499 L F P
0 g
s
.62982 .77195 m .62583 .74326 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63002 .77652 m .65936 .77079 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63002 .77652 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .66151 .78162 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62583 .74326 m .62982 .77195 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .63255 .79154 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .64525 .73661 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.64794 .76703 m .64525 .73661 L .63707 .75535 L .707 .577 .707 r
F
.65906 .76401 m .65479 .73334 L p .64794 .76703 L F P
0 g
s
.62845 .74075 m .62982 .77195 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.62982 .77195 m .62845 .74075 L p .6285 .77499 L .707 .577 .707 r
F P
0 g
s
.59822 .77881 m .63002 .77652 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59427 .74824 m .59808 .77566 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59665 .74304 m .59808 .77566 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59822 .77881 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .63255 .79154 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .60098 .79652 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.63255 .79154 m .62982 .77195 L p .6166 .7735 L .707 .577 .707 r
F P
0 g
s
.62845 .74075 m .59665 .74304 L p .62592 .77241 L .707 .577 .707 r
F P
0 g
s
.62849 .77211 m .62845 .74075 L .62592 .77241 L .707 .577 .707 r
F
.65781 .76929 m .65781 .76435 L .65384 .76543 L F
.65936 .77079 m .65906 .76401 L p .65781 .76929 L F P
0 g
s
.65936 .77079 m .68334 .76217 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65936 .77079 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .68503 .76773 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65479 .73334 m .65906 .76401 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .66151 .78162 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .65906 .76401 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.65906 .76401 m .65779 .73501 L p .65781 .76929 L .707 .577 .707 r
F P
0 g
s
.66151 .78162 m .65906 .76401 L p .64794 .76703 L .707 .577 .707 r
F P
0 g
s
.65779 .73501 m .62845 .74075 L p .65384 .76543 L .707 .577 .707 r
F P
0 g
s
.65781 .76435 m .65779 .73501 L .65384 .76543 L .707 .577 .707 r
F
.68293 .75262 m .67831 .71945 L .67528 .72124 L p F P
0 g
s
.67831 .71945 m .68293 .75262 L p .68391 .72735 L .707 .577 .707 r
F P
0 g
s
.68178 .72639 m .65779 .73501 L p .67701 .75544 L .707 .577 .707 r
F P
0 g
s
.68259 .76136 m .68239 .75287 L .67701 .75544 L .707 .577 .707 r
F
.68239 .75287 m .68178 .72639 L .67701 .75544 L F
.68334 .76217 m .68293 .75262 L p .68259 .76136 L F P
0 g
s
.68293 .75262 m .68178 .72639 L p .68259 .76136 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .68293 .75262 L p .67505 .75638 L .707 .577 .707 r
F P
0 g
s
.69964 .75151 m .69384 .74335 L .68467 .75979 L .707 .577 .707 r
F
.68499 .76109 m .69964 .75151 L p .68467 .75979 L F P
0 g
s
.69471 .74261 m .68391 .72735 L .68457 .75122 L .707 .577 .707 r
F
.68293 .75262 m .68503 .76773 L p .68391 .72735 L F P
0 g
s
.68178 .72639 m .68293 .75262 L p .69384 .74335 L .707 .577 .707 r
F P
0 g
s
.68503 .76773 m .70081 .75122 L p .69471 .74261 L .707 .577 .707 r
F P
0 g
s
.69471 .74261 m .68457 .75122 L .68503 .76773 L .707 .577 .707 r
F
.69909 .73888 m .69807 .71573 L p .69384 .74335 L F P
0 g
s
.70452 .72725 m .69567 .70663 L .69909 .73888 L .707 .577 .707 r
F
.69384 .74335 m .69722 .72128 L .68178 .72639 L F
.69673 .71661 m .68178 .72639 L p .69722 .72128 L F P
0 g
s
.69909 .73888 m .70081 .75122 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.7073 .73372 m .70597 .72415 L p .70452 .72725 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70597 .72415 L p .70319 .7301 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70369 .72834 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70436 .71671 m .70588 .72373 L .70665 .73985 L .707 .577 .707 r
F
.70058 .68545 m .70597 .72415 L p .70361 .71323 L .707 .578 .707 r
F P
0 g
s
.70597 .72415 m .70665 .73985 L p .705 .70559 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .69014 .69742 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70288 .70986 L p .69155 .69879 L .707 .577 .707 r
F P
0 g
s
.70369 .72834 m .70288 .70986 L p .70436 .71671 L .707 .577 .707 r
F P
0 g
s
.70364 .71476 m .70336 .71207 L .7041 .71774 L .707 .578 .707 r
F
.70336 .71207 m .70058 .68545 L .70361 .71323 L F
.70336 .71207 m .70361 .71323 L .7041 .71774 L F
.70369 .72834 m .69105 .7181 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69715 .66866 m .70058 .68545 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70288 .70986 m .69715 .66866 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70213 .69256 m .70288 .70986 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70369 .72834 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.70387 .71694 m .70288 .70986 L p .70364 .71476 L .707 .578 .707 r
F P
0 g
s
.70436 .71671 m .70288 .70986 L .70509 .70407 L .707 .577 .707 r
F
.69085 .70251 m .69155 .69879 L .70288 .70986 L F
.70288 .70986 m .70387 .71694 L .70284 .7158 L p F P
0 g
s
.70284 .7158 m .69085 .70251 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.70288 .70986 m .70213 .69256 L .70298 .69588 L p .707 .577 .707 r
F P
0 g
s
.70298 .69588 m .70509 .70407 L p .70288 .70986 L .707 .577 .707 r
F P
0 g
s
.7041 .71774 m .70361 .71323 L .70597 .72415 L .707 .578 .707 r
F
.70436 .71671 m .705 .70559 L .70588 .72373 L .707 .577 .707 r
F
.70509 .70407 m .70597 .72415 L p .705 .70559 L F P
0 g
s
.70657 .73569 m .7073 .73372 L p .70635 .73151 L .707 .577 .707 r
F P
0 g
s
.70665 .73985 m .70319 .7301 L .69909 .73888 L .707 .577 .707 r
F
.70081 .75122 m .69909 .73888 L p .69988 .74992 L F P
0 g
s
.69996 .75098 m .70665 .73985 L p .69909 .73888 L .707 .577 .707 r
F P
0 g
s
.69988 .74992 m .69909 .73888 L .69471 .74261 L .707 .577 .707 r
F
.68948 .68232 m .69993 .69079 L p .69708 .70419 L F P
0 g
s
.69993 .69079 m .70213 .69256 L p .70071 .69582 L .707 .577 .707 r
F P
0 g
s
.69708 .70419 m .69993 .69079 L .70071 .69582 L .707 .577 .707 r
F
.70387 .71694 m .70364 .71476 L .7041 .71774 L .707 .578 .707 r
F
.70597 .72415 m .7073 .73372 L .70717 .7331 L p F P
0 g
s
.70717 .7331 m .70387 .71694 L p .70597 .72415 L .707 .578 .707 r
F P
0 g
s
.69082 .69807 m .68414 .65424 L .69155 .69879 L .707 .577 .707 r
F
.69014 .69742 m .68414 .65424 L p .69121 .70062 L F P
0 g
s
.69014 .69742 m .68948 .68232 L p .69708 .70419 L .707 .577 .707 r
F P
0 g
s
.69121 .70062 m .69082 .69807 L .69155 .69879 L .707 .577 .707 r
F
.69085 .70251 m .69014 .69742 L p .69121 .70062 L F P
0 g
s
.66996 .71013 m .66899 .68804 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69105 .7181 m .66996 .71013 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69105 .7181 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.69085 .70251 m .66953 .69186 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68414 .65424 m .69014 .69742 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.69014 .69742 m .69085 .70251 L p .67071 .6888 L .707 .577 .707 r
F P
0 g
s
.68948 .68232 m .69014 .69742 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .68452 .68044 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.68452 .68044 m .68948 .68232 L p .68653 .68652 L .707 .577 .707 r
F P
0 g
s
.68156 .69361 m .68452 .68044 L .68653 .68652 L .707 .577 .707 r
F
.66988 .68843 m .66281 .64358 L .67071 .6888 L F
.66899 .68804 m .66281 .64358 L p .67017 .69021 L F P
0 g
s
.66899 .68804 m .66839 .67435 L p .68156 .69361 L .707 .577 .707 r
F P
0 g
s
.67017 .69021 m .66988 .68843 L .67071 .6888 L .707 .577 .707 r
F
.66953 .69186 m .66899 .68804 L p .67017 .69021 L F P
0 g
s
.64249 .70522 m .6415 .68263 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66996 .71013 m .64249 .70522 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66996 .71013 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66953 .69186 m .64197 .68602 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66281 .64358 m .66899 .68804 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66899 .68804 m .66953 .69186 L p .64345 .68302 L .707 .577 .707 r
F P
0 g
s
.66839 .67435 m .66899 .68804 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .66091 .67301 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.66091 .67301 m .66839 .67435 L p .66427 .67926 L .707 .577 .707 r
F P
0 g
s
.65862 .686 m .66091 .67301 L .66427 .67926 L .707 .577 .707 r
F
.6415 .68263 m .63526 .63774 L p .64277 .68439 L F P
0 g
s
.6415 .68263 m .64092 .66944 L p .65862 .686 L .707 .577 .707 r
F P
0 g
s
.64277 .68439 m .64252 .68283 L .64345 .68302 L .707 .577 .707 r
F
.64197 .68602 m .6415 .68263 L p .64277 .68439 L F P
0 g
s
.61133 .70384 m .61036 .68174 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64249 .70522 m .61133 .70384 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64249 .70522 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.64197 .68602 m .6109 .68557 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.63526 .63774 m .6415 .68263 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.6415 .68263 m .64197 .68602 L p .61281 .68181 L .707 .577 .707 r
F P
0 g
s
.64092 .66944 m .6415 .68263 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .63166 .66903 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.63166 .66903 m .64092 .66944 L p .63605 .6751 L .707 .577 .707 r
F P
0 g
s
.62986 .6823 m .63166 .66903 L .63605 .6751 L .707 .577 .707 r
F
.61036 .68174 m .60418 .63729 L p .61189 .68361 L F P
0 g
s
.61036 .68174 m .60976 .66806 L p .62986 .6823 L .707 .577 .707 r
F P
0 g
s
.61189 .68361 m .61159 .68178 L .61281 .68181 L .707 .577 .707 r
F
.6109 .68557 m .61036 .68174 L p .61189 .68361 L F P
0 g
s
.57953 .70613 m .57862 .68545 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61133 .70384 m .57953 .70613 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .61133 .70384 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.6109 .68557 m .57933 .69054 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60418 .63729 m .61036 .68174 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.61036 .68174 m .6109 .68557 L p .58189 .68507 L .707 .577 .707 r
F P
0 g
s
.60976 .66806 m .61036 .68174 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .59975 .66878 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.59975 .66878 m .60976 .66806 L p .60454 .67463 L .707 .577 .707 r
F P
0 g
s
.59772 .68322 m .59975 .66878 L .60454 .67463 L .707 .577 .707 r
F
.57862 .68545 m .57262 .64227 L p .58053 .68798 L F P
0 g
s
.57862 .68545 m .57796 .67035 L p .59772 .68322 L .707 .577 .707 r
F P
0 g
s
.58053 .68798 m .58006 .68528 L .58189 .68507 L .707 .577 .707 r
F
.57933 .69054 m .57862 .68545 L p .58053 .68798 L F P
0 g
s
.5502 .71186 m .54939 .69339 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57953 .70613 m .5502 .71186 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57953 .70613 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.57933 .69054 m .55037 .70046 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57262 .64227 m .57862 .68545 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57862 .68545 m .57933 .69054 L p .5535 .69227 L .707 .577 .707 r
F P
0 g
s
.57796 .67035 m .57862 .68545 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .56865 .67217 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.56865 .67217 m .57796 .67035 L p .57293 .67787 L .707 .577 .707 r
F P
0 g
s
.56548 .68902 m .56865 .67217 L .57293 .67787 L .707 .577 .707 r
F
.54939 .69339 m .54366 .65219 L p .55151 .69748 L F P
0 g
s
.54939 .69339 m .54863 .67609 L p .56548 .68902 L .707 .577 .707 r
F P
0 g
s
.55151 .69748 m .55074 .69302 L .5535 .69227 L .707 .577 .707 r
F
.55037 .70046 m .54939 .69339 L p .55151 .69748 L F P
0 g
s
.5502 .71186 m .52621 .72048 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .5502 .71186 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.55037 .70046 m .52685 .71435 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54366 .65219 m .54939 .69339 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54939 .69339 m .55037 .70046 L p .53002 .70263 L .707 .577 .707 r
F P
0 g
s
.54863 .67609 m .54939 .69339 L p .53688 .69936 L .707 .577 .707 r
F P
0 g
s
.53688 .69936 m .52552 .70478 L .54363 .68229 L .707 .577 .707 r
F
.54458 .68411 m .54363 .68229 L .54863 .67609 L F
.53688 .69936 m .54363 .68229 L .54458 .68411 L F
.52552 .70478 m .52464 .68471 L .52632 .6841 L p F P
0 g
s
.52632 .6841 m .54863 .67609 L p .52552 .70478 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .51327 .7152 L .52514 .71446 L .707 .577 .707 r
F
.52685 .71435 m .52508 .71621 L p .52514 .71446 L F P
0 g
s
.52508 .71621 m .51107 .73086 L p .52514 .71446 L .707 .577 .707 r
F P
0 g
s
.52014 .66608 m .52552 .70478 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52552 .70478 m .52685 .71435 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.52464 .68471 m .52552 .70478 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .51107 .73086 L .51076 .73172 L p .707 .577 .707 r
F P
0 g
s
.50834 .69537 m .52464 .68471 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50834 .69537 L p .5156 .71321 L .707 .577 .707 r
F P
0 g
s
.51107 .73086 m .50936 .71852 L p .51327 .7152 L .707 .577 .707 r
F P
0 g
s
.50936 .71852 m .50436 .68258 L .50661 .68023 L p .707 .577 .707 r
F P
0 g
s
.50288 .7324 m .50133 .70702 L .50449 .72895 L .707 .577 .707 r
F
.50248 .73325 m .50133 .70702 L p .5033 .73933 L F P
0 g
s
.50452 .72889 m .50248 .73325 L .50436 .68258 L .707 .577 .707 r
F
.5033 .73933 m .50288 .7324 L .50449 .72895 L F
.5029 .7428 m .50248 .73325 L p .5033 .73933 L F P
0 g
s
.49787 .70008 m .50248 .73325 L p .49897 .70714 L .707 .578 .707 r
F P
0 g
s
.50248 .73325 m .49787 .70008 L .5004 .69326 L p .707 .577 .707 r
F P
0 g
s
.5004 .69326 m .50436 .68258 L p .50248 .73325 L .707 .577 .707 r
F P
0 g
s
.50556 .74754 m .50801 .76514 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.52103 .77957 m .5183 .75998 L p .51334 .75513 L .707 .577 .707 r
F P
0 g
s
.51766 .75935 m .51693 .72878 L .51657 .75829 L .707 .577 .707 r
F
.53055 .76541 m .5219 .74725 L .5183 .75998 L F
.5183 .75998 m .52103 .77957 L p .53055 .76541 L F P
0 g
s
.51693 .72878 m .5183 .75998 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.54235 .79022 m .53945 .76936 L p .53055 .76541 L .707 .577 .707 r
F P
0 g
s
.53802 .73674 m .51693 .72878 L p .53751 .7685 L .707 .577 .707 r
F P
0 g
s
.53865 .76901 m .53802 .73674 L .53751 .7685 L .707 .577 .707 r
F
.56609 .77608 m .56607 .77459 L .56486 .77436 L F
.56706 .77744 m .56694 .77476 L p .56609 .77608 L F P
0 g
s
.56706 .77744 m .59822 .77881 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56706 .77744 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .60098 .79652 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56319 .74779 m .56694 .77476 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56991 .79606 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59427 .74824 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .56694 .77476 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.56694 .77476 m .56549 .74166 L p .56609 .77608 L .707 .577 .707 r
F P
0 g
s
.56991 .79606 m .56694 .77476 L p .55492 .7724 L .707 .577 .707 r
F P
0 g
s
.56549 .74166 m .53802 .73674 L p .56486 .77436 L .707 .577 .707 r
F P
0 g
s
.56607 .77459 m .56549 .74166 L .56486 .77436 L .707 .577 .707 r
F
.59665 .74304 m .56549 .74166 L p .59537 .77558 L F P
0 g
s
.59822 .77881 m .59808 .77566 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.59808 .77566 m .59665 .74304 L p .59537 .77558 L .707 .577 .707 r
F P
0 g
s
.60098 .79652 m .59808 .77566 L p .5845 .77527 L .707 .577 .707 r
F P
0 g
s
.59052 .87901 m .59129 .86007 L .56013 .85763 L p .707 .577 .707 r
F P
0 g
s
.59129 .86007 m .59052 .87901 L .62232 .87978 L p .707 .577 .707 r
F P
0 g
s
.62232 .87978 m .6231 .86084 L .59129 .86007 L p .707 .577 .707 r
F P
0 g
s
.6231 .86084 m .62232 .87978 L .65165 .87881 L p .707 .577 .707 r
F P
0 g
s
.65165 .87881 m .65243 .85987 L .6231 .86084 L p .707 .577 .707 r
F P
0 g
s
.56013 .85763 m .55935 .87657 L .59052 .87901 L p .707 .577 .707 r
F P
0 g
s
.55935 .87657 m .56013 .85763 L .53266 .85377 L p .707 .577 .707 r
F P
0 g
s
.53266 .85377 m .53189 .87271 L .55935 .87657 L p .707 .577 .707 r
F P
0 g
s
.65243 .85987 m .65165 .87881 L .67564 .8762 L p .707 .577 .707 r
F P
0 g
s
.67564 .8762 m .67642 .85726 L .65243 .85987 L p .707 .577 .707 r
F P
0 g
s
.53189 .87271 m .53266 .85377 L .51158 .84887 L p .707 .577 .707 r
F P
0 g
s
.51158 .84887 m .5108 .86781 L .53189 .87271 L p .707 .577 .707 r
F P
0 g
s
.67642 .85726 m .67564 .8762 L .69194 .8722 L p .707 .577 .707 r
F P
0 g
s
.69194 .8722 m .69272 .85326 L .67642 .85726 L p .707 .577 .707 r
F P
0 g
s
.5108 .86781 m .51158 .84887 L .49893 .84339 L p .707 .577 .707 r
F P
0 g
s
.49893 .84339 m .49815 .86233 L .5108 .86781 L p .707 .577 .707 r
F P
0 g
s
.69272 .85326 m .69194 .8722 L .69895 .8672 L p .707 .577 .707 r
F P
0 g
s
.69895 .8672 m .69973 .84826 L .69272 .85326 L p .707 .577 .707 r
F P
0 g
s
.49362 .82167 m .4907 .3218 L .44669 .31922 L p .707 .577 .707 r
F P
0 g
s
.4907 .3218 m .49362 .82167 L .53856 .82027 L p .707 .577 .707 r
F P
0 g
s
.53856 .82027 m .53564 .3204 L .4907 .3218 L p .707 .577 .707 r
F P
0 g
s
.53564 .3204 m .53856 .82027 L .58004 .81504 L p .707 .577 .707 r
F P
0 g
s
.58004 .81504 m .57712 .31517 L .53564 .3204 L p .707 .577 .707 r
F P
0 g
s
.49815 .86233 m .49893 .84339 L .49597 .83789 L p .707 .577 .707 r
F P
0 g
s
.49597 .83789 m .49519 .85683 L .49815 .86233 L p .707 .577 .707 r
F P
0 g
s
.44961 .81909 m .44669 .31922 L .40793 .31291 L p .707 .577 .707 r
F P
0 g
s
.44669 .31922 m .44961 .81909 L .49362 .82167 L p .707 .577 .707 r
F P
0 g
s
.57712 .31517 m .58004 .81504 L .614 .80648 L p .707 .577 .707 r
F P
0 g
s
.614 .80648 m .61108 .30661 L .57712 .31517 L p .707 .577 .707 r
F P
0 g
s
.69973 .84826 m .69895 .8672 L .69599 .86169 L p .707 .577 .707 r
F P
0 g
s
.69599 .86169 m .69677 .84275 L .69973 .84826 L p .707 .577 .707 r
F P
0 g
s
.41085 .81278 m .40793 .31291 L .3782 .3035 L p .707 .577 .707 r
F P
0 g
s
.40793 .31291 m .41085 .81278 L .44961 .81909 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.49519 .85683 m .49597 .83789 L .50299 .83289 L p .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .24117 .71128 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.24117 .71128 m .22018 .71097 L p .23174 .72587 L .707 .577 .707 r
F P
0 g
s
.2415 .73845 m .24117 .71128 L .23174 .72587 L .707 .577 .707 r
F
.20934 .70867 m .19263 .70513 L p .20268 .721 L F P
0 g
s
.19263 .70513 m .1713 .69448 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19568 .73396 m .19564 .73219 L .1945 .73169 L .707 .577 .707 r
F
.19658 .73571 m .19644 .73255 L p .19568 .73396 L F P
0 g
s
.19644 .73255 m .19263 .70513 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .22405 .74062 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19658 .73571 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .2269 .75925 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19263 .70513 m .19644 .73255 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19934 .75341 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .20934 .70867 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.21192 .73559 m .20934 .70867 L .20268 .721 L .707 .577 .707 r
F
.22393 .73795 m .22018 .71097 L p .21192 .73559 L F P
0 g
s
.19501 .69993 m .19644 .73255 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.19644 .73255 m .19501 .69993 L p .19568 .73396 L .707 .577 .707 r
F P
0 g
s
.19658 .73571 m .1945 .73169 L .17529 .72317 L .707 .577 .707 r
F
.177 .72831 m .19658 .73571 L p .17529 .72317 L F P
0 g
s
.17802 .74275 m .19934 .75341 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.1713 .69448 m .17529 .72317 L p .1789 .71043 L .707 .577 .707 r
F P
0 g
s
.17033 .71832 m .17529 .72317 L .15829 .68005 L .707 .577 .707 r
F
.17471 .72521 m .17465 .72254 L .17356 .72147 L F
.17549 .72774 m .17529 .72317 L p .17471 .72521 L F P
0 g
s
.17529 .72317 m .1713 .69448 L .16257 .6848 L p .707 .577 .707 r
F P
0 g
s
.16257 .6848 m .15829 .68005 L p .17529 .72317 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17392 .69196 L p .17471 .72521 L .707 .577 .707 r
F P
0 g
s
.17529 .72317 m .17549 .72774 L .177 .72831 L p .707 .577 .707 r
F P
0 g
s
.17549 .72774 m .17356 .72147 L .16255 .71072 L .707 .577 .707 r
F
.16371 .71819 m .17549 .72774 L p .16255 .71072 L F P
0 g
s
.165 .72833 m .17802 .74275 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.15829 .68005 m .16255 .71072 L p .16267 .69398 L .707 .577 .707 r
F P
0 g
s
.16148 .70577 m .16255 .71072 L .15486 .66327 L .707 .578 .707 r
F
.16253 .71415 m .16236 .70985 L .16192 .70779 L .707 .577 .707 r
F
.16285 .7175 m .16255 .71072 L p .16253 .71415 L F P
0 g
s
.16255 .71072 m .15829 .68005 L .15633 .6705 L p .707 .578 .707 r
F P
0 g
s
.15633 .6705 m .15486 .66327 L p .16255 .71072 L .707 .578 .707 r
F P
0 g
s
.16255 .71072 m .16128 .68172 L p .16253 .71415 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .16285 .7175 L .16371 .71819 L p .707 .577 .707 r
F P
0 g
s
.16285 .7175 m .16192 .70779 L .15947 .69644 L .707 .577 .707 r
F
.15999 .70637 m .16285 .7175 L p .15947 .69644 L F P
0 g
s
.16157 .71154 m .165 .72833 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16148 .70577 m .15596 .67033 L .15947 .69644 L .707 .578 .707 r
F
.15947 .69644 m .16157 .71154 L p .16148 .70577 L F P
0 g
s
.15832 .67021 m .15947 .69644 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16128 .68172 m .15832 .67021 L p .16192 .70779 L .707 .577 .707 r
F P
0 g
s
.16236 .70985 m .16128 .68172 L .16192 .70779 L .707 .577 .707 r
F
.17033 .71832 m .16267 .69398 L .16255 .71072 L F
.16128 .68172 m .16255 .71072 L p .17356 .72147 L F P
0 g
s
.17392 .69196 m .16128 .68172 L p .17356 .72147 L .707 .577 .707 r
F P
0 g
s
.15832 .67021 m .16475 .65951 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.1636 .64342 m .17713 .62926 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.16475 .65951 m .16533 .65855 L p .16493 .66202 L .707 .577 .707 r
F P
0 g
s
.16148 .69213 m .16475 .65951 L .16493 .66202 L .707 .577 .707 r
F
.17026 .67838 m .16635 .6817 L .17713 .62926 L F
.16749 .69247 m .16635 .6817 L .17259 .6764 L F
.165 .72833 m .16255 .71072 L p .16148 .70577 L .707 .578 .707 r
F P
0 g
s
.16775 .6949 m .16157 .71154 L p .16635 .6817 L .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .16635 .6817 L p .16749 .69247 L .707 .577 .707 r
F P
0 g
s
.16157 .71154 m .16151 .69207 L .16635 .6817 L .707 .577 .707 r
F
.16157 .71154 m .15947 .69644 L p .16151 .69207 L F P
0 g
s
.15947 .69644 m .15989 .70599 L .15999 .70637 L p .707 .577 .707 r
F P
0 g
s
.1669 .69433 m .15989 .70599 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .16635 .6817 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .1669 .69433 L p .16148 .69213 L .707 .577 .707 r
F P
0 g
s
.16135 .64577 m .16635 .6817 L p .16151 .69207 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .1669 .69433 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .1832 .68367 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .20065 .61537 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.1832 .68367 m .18251 .66797 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.18384 .67754 m .18251 .66797 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .17713 .62926 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .22961 .60545 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.20773 .6562 m .20065 .61537 L .2105 .65545 L .707 .577 .707 r
F
.22961 .60545 m .26117 .60047 L p .23888 .64825 L F P
0 g
s
.23705 .64846 m .22961 .60545 L .23888 .64825 L .707 .577 .707 r
F
.26117 .60047 m .29225 .60093 L p .2698 .645 L F P
0 g
s
.26858 .64496 m .26117 .60047 L .2698 .645 L .707 .577 .707 r
F
.29225 .60093 m .3198 .60677 L p .30044 .6462 L F P
0 g
s
.29951 .64602 m .29225 .60093 L .30044 .6462 L .707 .577 .707 r
F
.3198 .60677 m .34113 .61742 L p .32771 .65198 L F P
0 g
s
.34113 .61742 m .35414 .63185 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36018 .69329 m .36144 .67603 L .35506 .67891 L .707 .577 .707 r
F
.36208 .66726 m .36059 .66973 L p .36144 .67603 L F P
0 g
s
.36059 .66973 m .35506 .67891 L p .36144 .67603 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .36208 .66726 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36296 .68733 m .35757 .64863 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35757 .64863 m .35108 .66613 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .3353 .68264 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35608 .70207 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.3578 .71441 m .36356 .69888 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36334 .6947 m .36151 .69043 L .36356 .69888 L .707 .577 .707 r
F
.35506 .67891 m .35608 .70207 L p .36018 .69329 L F P
0 g
s
.35506 .67891 m .35372 .67979 L p .35421 .68446 L .707 .577 .707 r
F P
0 g
s
.35108 .66613 m .35608 .70207 L p .35266 .66981 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35108 .66613 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.35608 .70207 m .35663 .71469 L .35695 .71417 L p .707 .577 .707 r
F P
0 g
s
.34034 .72535 m .34198 .72428 L p .34166 .72297 L .707 .577 .707 r
F P
0 g
s
.33992 .7158 m .34034 .72535 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.33204 .71956 m .33992 .7158 L .32169 .70332 L .707 .577 .707 r
F
.32086 .70685 m .32169 .70332 L .31178 .69653 L F
.33204 .71956 m .32169 .70332 L .32086 .70685 L F
.33227 .68443 m .31178 .69653 L p .33992 .7158 L F P
0 g
s
.30224 .69979 m .28282 .70645 L p .29406 .71853 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .25126 .71142 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28549 .73818 m .28548 .73529 L .28291 .73559 L .707 .577 .707 r
F
.28701 .73971 m .28681 .73514 L p .28549 .73818 L F P
0 g
s
.28681 .73514 m .28282 .70645 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28701 .73971 m .31635 .73397 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28701 .73971 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .3185 .7448 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28282 .70645 m .28681 .73514 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28954 .75472 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .30224 .69979 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.30493 .73022 m .30224 .69979 L .29406 .71853 L .707 .577 .707 r
F
.31605 .7272 m .31178 .69653 L p .30493 .73022 L F P
0 g
s
.28545 .70393 m .28681 .73514 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.28681 .73514 m .28545 .70393 L p .28549 .73818 L .707 .577 .707 r
F P
0 g
s
.25521 .742 m .28701 .73971 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25126 .71142 m .25507 .73884 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25364 .70622 m .25507 .73884 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25521 .742 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .28954 .75472 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25798 .7597 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28954 .75472 m .28681 .73514 L p .27359 .73668 L .707 .577 .707 r
F P
0 g
s
.28545 .70393 m .25364 .70622 L p .28291 .73559 L .707 .577 .707 r
F P
0 g
s
.28548 .73529 m .28545 .70393 L .28291 .73559 L .707 .577 .707 r
F
.3148 .73247 m .3148 .72754 L .31083 .72861 L F
.31635 .73397 m .31605 .7272 L p .3148 .73247 L F P
0 g
s
.31635 .73397 m .34034 .72535 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31635 .73397 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .34202 .73091 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31178 .69653 m .31605 .7272 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .3185 .7448 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .31605 .7272 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.31605 .7272 m .31478 .69819 L p .3148 .73247 L .707 .577 .707 r
F P
0 g
s
.3185 .7448 m .31605 .7272 L p .30493 .73022 L .707 .577 .707 r
F P
0 g
s
.31478 .69819 m .28545 .70393 L p .31083 .72861 L .707 .577 .707 r
F P
0 g
s
.3148 .72754 m .31478 .69819 L .31083 .72861 L .707 .577 .707 r
F
.33992 .7158 m .3353 .68264 L .33227 .68443 L p F P
0 g
s
.3353 .68264 m .33992 .7158 L p .3409 .69054 L .707 .577 .707 r
F P
0 g
s
.33877 .68957 m .31478 .69819 L p .334 .71863 L .707 .577 .707 r
F P
0 g
s
.33958 .72455 m .33938 .71606 L .334 .71863 L .707 .577 .707 r
F
.33938 .71606 m .33877 .68957 L .334 .71863 L F
.34034 .72535 m .33992 .7158 L p .33958 .72455 L F P
0 g
s
.33992 .7158 m .33877 .68957 L p .33958 .72455 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .33992 .7158 L p .33204 .71956 L .707 .577 .707 r
F P
0 g
s
.35663 .71469 m .35083 .70653 L .34166 .72297 L .707 .577 .707 r
F
.34198 .72428 m .35663 .71469 L p .34166 .72297 L F P
0 g
s
.3517 .70579 m .3409 .69054 L .34156 .71441 L .707 .577 .707 r
F
.33992 .7158 m .34202 .73091 L p .3409 .69054 L F P
0 g
s
.33877 .68957 m .33992 .7158 L p .35083 .70653 L .707 .577 .707 r
F P
0 g
s
.34202 .73091 m .3578 .71441 L p .3517 .70579 L .707 .577 .707 r
F P
0 g
s
.3517 .70579 m .34156 .71441 L .34202 .73091 L .707 .577 .707 r
F
.35608 .70207 m .35506 .67891 L p .35083 .70653 L F P
0 g
s
.36151 .69043 m .35266 .66981 L .35608 .70207 L .707 .577 .707 r
F
.35083 .70653 m .35421 .68446 L .33877 .68957 L F
.35372 .67979 m .33877 .68957 L p .35421 .68446 L F P
0 g
s
.35608 .70207 m .3578 .71441 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36429 .69691 m .36296 .68733 L p .36151 .69043 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36296 .68733 L p .36018 .69329 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36068 .69152 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36135 .67989 m .36287 .68691 L .36365 .70304 L .707 .577 .707 r
F
.35757 .64863 m .36296 .68733 L p .3606 .67641 L .707 .578 .707 r
F P
0 g
s
.36296 .68733 m .36365 .70304 L p .36199 .66877 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .34713 .6606 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35987 .67305 L p .34854 .66197 L .707 .577 .707 r
F P
0 g
s
.36068 .69152 m .35987 .67305 L p .36135 .67989 L .707 .577 .707 r
F P
0 g
s
.36063 .67794 m .36035 .67525 L .36109 .68093 L .707 .578 .707 r
F
.36035 .67525 m .35757 .64863 L .3606 .67641 L F
.36035 .67525 m .3606 .67641 L .36109 .68093 L F
.36068 .69152 m .34804 .68128 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35414 .63185 m .35757 .64863 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35987 .67305 m .35414 .63185 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.35912 .65574 m .35987 .67305 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .36068 .69152 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.36086 .68012 m .35987 .67305 L p .36063 .67794 L .707 .578 .707 r
F P
0 g
s
.36135 .67989 m .35987 .67305 L .36208 .66726 L .707 .577 .707 r
F
.34784 .6657 m .34854 .66197 L .35987 .67305 L F
.35987 .67305 m .36086 .68012 L .35983 .67899 L p F P
0 g
s
.35983 .67899 m .34784 .6657 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.35987 .67305 m .35912 .65574 L .35997 .65907 L p .707 .577 .707 r
F P
0 g
s
.35997 .65907 m .36208 .66726 L p .35987 .67305 L .707 .577 .707 r
F P
0 g
s
.36109 .68093 m .3606 .67641 L .36296 .68733 L .707 .578 .707 r
F
.36135 .67989 m .36199 .66877 L .36287 .68691 L .707 .577 .707 r
F
.36208 .66726 m .36296 .68733 L p .36199 .66877 L F P
0 g
s
.36356 .69888 m .36429 .69691 L p .36334 .6947 L .707 .577 .707 r
F P
0 g
s
.36365 .70304 m .36018 .69329 L .35608 .70207 L .707 .577 .707 r
F
.3578 .71441 m .35608 .70207 L p .35687 .7131 L F P
0 g
s
.35695 .71417 m .36365 .70304 L p .35608 .70207 L .707 .577 .707 r
F P
0 g
s
.35687 .7131 m .35608 .70207 L .3517 .70579 L .707 .577 .707 r
F
.34647 .6455 m .35693 .65397 L p .35407 .66738 L F P
0 g
s
.35693 .65397 m .35912 .65574 L p .3577 .659 L .707 .577 .707 r
F P
0 g
s
.35407 .66738 m .35693 .65397 L .3577 .659 L .707 .577 .707 r
F
.36086 .68012 m .36063 .67794 L .36109 .68093 L .707 .578 .707 r
F
.36296 .68733 m .36429 .69691 L .36416 .69628 L p F P
0 g
s
.36416 .69628 m .36086 .68012 L p .36296 .68733 L .707 .578 .707 r
F P
0 g
s
.34781 .66126 m .34113 .61742 L .34854 .66197 L .707 .577 .707 r
F
.34713 .6606 m .34113 .61742 L p .3482 .6638 L F P
0 g
s
.34713 .6606 m .34647 .6455 L p .35407 .66738 L .707 .577 .707 r
F P
0 g
s
.3482 .6638 m .34781 .66126 L .34854 .66197 L .707 .577 .707 r
F
.34784 .6657 m .34713 .6606 L p .3482 .6638 L F P
0 g
s
.32695 .67331 m .32598 .65122 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34804 .68128 m .32695 .67331 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34804 .68128 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34784 .6657 m .32652 .65504 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34113 .61742 m .34713 .6606 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34713 .6606 m .34784 .6657 L p .32771 .65198 L .707 .577 .707 r
F P
0 g
s
.34647 .6455 m .34713 .6606 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .34151 .64363 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.34151 .64363 m .34647 .6455 L p .34352 .64971 L .707 .577 .707 r
F P
0 g
s
.33855 .65679 m .34151 .64363 L .34352 .64971 L .707 .577 .707 r
F
.32687 .65161 m .3198 .60677 L .32771 .65198 L F
.32598 .65122 m .3198 .60677 L p .32716 .6534 L F P
0 g
s
.32598 .65122 m .32538 .63754 L p .33855 .65679 L .707 .577 .707 r
F P
0 g
s
.32716 .6534 m .32687 .65161 L .32771 .65198 L .707 .577 .707 r
F
.32652 .65504 m .32598 .65122 L p .32716 .6534 L F P
0 g
s
.29948 .6684 m .29849 .64582 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32695 .67331 m .29948 .6684 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32695 .67331 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.32652 .65504 m .29896 .6492 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.3198 .60677 m .32598 .65122 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32598 .65122 m .32652 .65504 L p .30044 .6462 L .707 .577 .707 r
F P
0 g
s
.32538 .63754 m .32598 .65122 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .3179 .6362 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.3179 .6362 m .32538 .63754 L p .32126 .64245 L .707 .577 .707 r
F P
0 g
s
.31561 .64918 m .3179 .6362 L .32126 .64245 L .707 .577 .707 r
F
.29849 .64582 m .29225 .60093 L p .29976 .64758 L F P
0 g
s
.29849 .64582 m .29792 .63262 L p .31561 .64918 L .707 .577 .707 r
F P
0 g
s
.29976 .64758 m .29951 .64602 L .30044 .6462 L .707 .577 .707 r
F
.29896 .6492 m .29849 .64582 L p .29976 .64758 L F P
0 g
s
.26832 .66702 m .26735 .64493 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29948 .6684 m .26832 .66702 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29948 .6684 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.29896 .6492 m .26789 .64875 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29225 .60093 m .29849 .64582 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29849 .64582 m .29896 .6492 L p .2698 .645 L .707 .577 .707 r
F P
0 g
s
.29792 .63262 m .29849 .64582 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .28865 .63221 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.28865 .63221 m .29792 .63262 L p .29304 .63828 L .707 .577 .707 r
F P
0 g
s
.28685 .64549 m .28865 .63221 L .29304 .63828 L .707 .577 .707 r
F
.26735 .64493 m .26117 .60047 L p .26888 .64679 L F P
0 g
s
.26735 .64493 m .26675 .63124 L p .28685 .64549 L .707 .577 .707 r
F P
0 g
s
.26888 .64679 m .26858 .64496 L .2698 .645 L .707 .577 .707 r
F
.26789 .64875 m .26735 .64493 L p .26888 .64679 L F P
0 g
s
.23652 .66931 m .23561 .64863 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26832 .66702 m .23652 .66931 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26832 .66702 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.26789 .64875 m .23632 .65373 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26117 .60047 m .26735 .64493 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26735 .64493 m .26789 .64875 L p .23888 .64825 L .707 .577 .707 r
F P
0 g
s
.26675 .63124 m .26735 .64493 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .25674 .63196 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.25674 .63196 m .26675 .63124 L p .26153 .63782 L .707 .577 .707 r
F P
0 g
s
.25472 .6464 m .25674 .63196 L .26153 .63782 L .707 .577 .707 r
F
.23561 .64863 m .22961 .60545 L p .23752 .65117 L F P
0 g
s
.23561 .64863 m .23495 .63353 L p .25472 .6464 L .707 .577 .707 r
F P
0 g
s
.23752 .65117 m .23705 .64846 L .23888 .64825 L .707 .577 .707 r
F
.23632 .65373 m .23561 .64863 L p .23752 .65117 L F P
0 g
s
.20719 .67505 m .20638 .65657 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23652 .66931 m .20719 .67505 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23652 .66931 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.23632 .65373 m .20736 .66365 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.22961 .60545 m .23561 .64863 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23561 .64863 m .23632 .65373 L p .2105 .65545 L .707 .577 .707 r
F P
0 g
s
.23495 .63353 m .23561 .64863 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .22564 .63536 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.22564 .63536 m .23495 .63353 L p .22992 .64106 L .707 .577 .707 r
F P
0 g
s
.22247 .6522 m .22564 .63536 L .22992 .64106 L .707 .577 .707 r
F
.20638 .65657 m .20065 .61537 L p .2085 .66067 L F P
0 g
s
.20638 .65657 m .20562 .63927 L p .22247 .6522 L .707 .577 .707 r
F P
0 g
s
.2085 .66067 m .20773 .6562 L .2105 .65545 L .707 .577 .707 r
F
.20736 .66365 m .20638 .65657 L p .2085 .66067 L F P
0 g
s
.20719 .67505 m .1832 .68367 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20719 .67505 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.20736 .66365 m .18384 .67754 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20065 .61537 m .20638 .65657 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20638 .65657 m .20736 .66365 L p .18701 .66582 L .707 .577 .707 r
F P
0 g
s
.20562 .63927 m .20638 .65657 L p .19387 .66254 L .707 .577 .707 r
F P
0 g
s
.19387 .66254 m .18251 .66797 L .20062 .64548 L .707 .577 .707 r
F
.20157 .6473 m .20062 .64548 L .20562 .63927 L F
.19387 .66254 m .20062 .64548 L .20157 .6473 L F
.18251 .66797 m .18163 .64789 L .18331 .64729 L p F P
0 g
s
.18331 .64729 m .20562 .63927 L p .18251 .66797 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .17026 .67838 L .18214 .67765 L .707 .577 .707 r
F
.18384 .67754 m .18207 .6794 L p .18214 .67765 L F P
0 g
s
.18207 .6794 m .16806 .69404 L p .18214 .67765 L .707 .577 .707 r
F P
0 g
s
.17713 .62926 m .18251 .66797 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18251 .66797 m .18384 .67754 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.18163 .64789 m .18251 .66797 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16806 .69404 L .16775 .6949 L p .707 .577 .707 r
F P
0 g
s
.16533 .65855 m .18163 .64789 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16533 .65855 L p .17259 .6764 L .707 .577 .707 r
F P
0 g
s
.16806 .69404 m .16635 .6817 L p .17026 .67838 L .707 .577 .707 r
F P
0 g
s
.16635 .6817 m .16135 .64577 L .1636 .64342 L p .707 .577 .707 r
F P
0 g
s
.15987 .69559 m .15832 .67021 L .16148 .69213 L .707 .577 .707 r
F
.15947 .69644 m .15832 .67021 L p .16029 .70251 L F P
0 g
s
.16151 .69207 m .15947 .69644 L .16135 .64577 L .707 .577 .707 r
F
.16029 .70251 m .15987 .69559 L .16148 .69213 L F
.15989 .70599 m .15947 .69644 L p .16029 .70251 L F P
0 g
s
.15486 .66327 m .15947 .69644 L p .15596 .67033 L .707 .578 .707 r
F P
0 g
s
.15947 .69644 m .15486 .66327 L .15739 .65645 L p .707 .577 .707 r
F P
0 g
s
.15739 .65645 m .16135 .64577 L p .15947 .69644 L .707 .577 .707 r
F P
0 g
s
.16255 .71072 m .165 .72833 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17802 .74275 m .17529 .72317 L p .17033 .71832 L .707 .577 .707 r
F P
0 g
s
.17465 .72254 m .17392 .69196 L .17356 .72147 L .707 .577 .707 r
F
.18754 .7286 m .1789 .71043 L .17529 .72317 L F
.17529 .72317 m .17802 .74275 L p .18754 .7286 L F P
0 g
s
.17392 .69196 m .17529 .72317 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19934 .75341 m .19644 .73255 L p .18754 .7286 L .707 .577 .707 r
F P
0 g
s
.19501 .69993 m .17392 .69196 L p .1945 .73169 L .707 .577 .707 r
F P
0 g
s
.19564 .73219 m .19501 .69993 L .1945 .73169 L .707 .577 .707 r
F
.22308 .73926 m .22306 .73778 L .22185 .73754 L F
.22405 .74062 m .22393 .73795 L p .22308 .73926 L F P
0 g
s
.22405 .74062 m .25521 .742 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22405 .74062 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .25798 .7597 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22018 .71097 m .22393 .73795 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .2269 .75925 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25126 .71142 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .22393 .73795 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.22393 .73795 m .22248 .70484 L p .22308 .73926 L .707 .577 .707 r
F P
0 g
s
.2269 .75925 m .22393 .73795 L p .21192 .73559 L .707 .577 .707 r
F P
0 g
s
.22248 .70484 m .19501 .69993 L p .22185 .73754 L .707 .577 .707 r
F P
0 g
s
.22306 .73778 m .22248 .70484 L .22185 .73754 L .707 .577 .707 r
F
.25364 .70622 m .22248 .70484 L p .25236 .73876 L F P
0 g
s
.25521 .742 m .25507 .73884 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25507 .73884 m .25364 .70622 L p .25236 .73876 L .707 .577 .707 r
F P
0 g
s
.25798 .7597 m .25507 .73884 L p .2415 .73845 L .707 .577 .707 r
F P
0 g
s
.50299 .83289 m .50221 .85183 L .49519 .85683 L p .707 .577 .707 r
F P
0 g
s
.61108 .30661 m .614 .80648 L .6371 .79543 L p .707 .577 .707 r
F P
0 g
s
.6371 .79543 m .63418 .29556 L .61108 .30661 L p .707 .577 .707 r
F P
0 g
s
.69677 .84275 m .69599 .86169 L .68335 .85622 L p .707 .577 .707 r
F P
0 g
s
.68335 .85622 m .68413 .83728 L .69677 .84275 L p .707 .577 .707 r
F P
0 g
s
.24751 .84219 m .24829 .82325 L .21712 .82082 L p .707 .577 .707 r
F P
0 g
s
.24829 .82325 m .24751 .84219 L .27931 .84296 L p .707 .577 .707 r
F P
0 g
s
.27931 .84296 m .28009 .82402 L .24829 .82325 L p .707 .577 .707 r
F P
0 g
s
.38112 .80338 m .3782 .3035 L .36042 .29191 L p .707 .577 .707 r
F P
0 g
s
.3782 .3035 m .38112 .80338 L .41085 .81278 L p .707 .577 .707 r
F P
0 g
s
.28009 .82402 m .27931 .84296 L .30864 .84199 L p .707 .577 .707 r
F P
0 g
s
.30864 .84199 m .30942 .82305 L .28009 .82402 L p .707 .577 .707 r
F P
0 g
s
.21712 .82082 m .21635 .83976 L .24751 .84219 L p .707 .577 .707 r
F P
0 g
s
.50221 .85183 m .50299 .83289 L .51929 .82889 L p .707 .577 .707 r
F P
0 g
s
.21635 .83976 m .21712 .82082 L .18966 .81696 L p .707 .577 .707 r
F P
0 g
s
.51929 .82889 m .51851 .84783 L .50221 .85183 L p .707 .577 .707 r
F P
0 g
s
.18966 .81696 m .18888 .8359 L .21635 .83976 L p .707 .577 .707 r
F P
0 g
s
.30942 .82305 m .30864 .84199 L .33263 .83938 L p .707 .577 .707 r
F P
0 g
s
.33263 .83938 m .33341 .82044 L .30942 .82305 L p .707 .577 .707 r
F P
0 g
s
.18888 .8359 m .18966 .81696 L .16857 .81205 L p .707 .577 .707 r
F P
0 g
s
.68413 .83728 m .68335 .85622 L .66226 .85132 L p .707 .577 .707 r
F P
0 g
s
.66226 .85132 m .66304 .83238 L .68413 .83728 L p .707 .577 .707 r
F P
0 g
s
.63418 .29556 m .6371 .79543 L .6471 .78298 L p .707 .577 .707 r
F P
0 g
s
.6471 .78298 m .64418 .28311 L .63418 .29556 L p .707 .577 .707 r
F P
0 g
s
.16857 .81205 m .16779 .83099 L .18888 .8359 L p .707 .577 .707 r
F P
0 g
s
.51851 .84783 m .51929 .82889 L .54328 .82628 L p .707 .577 .707 r
F P
0 g
s
.54328 .82628 m .5425 .84522 L .51851 .84783 L p .707 .577 .707 r
F P
0 g
s
.33341 .82044 m .33263 .83938 L .34893 .83538 L p .707 .577 .707 r
F P
0 g
s
.34893 .83538 m .34971 .81644 L .33341 .82044 L p .707 .577 .707 r
F P
0 g
s
.36334 .79178 m .36042 .29191 L .35633 .27927 L p .707 .577 .707 r
F P
0 g
s
.36042 .29191 m .36334 .79178 L .38112 .80338 L p .707 .577 .707 r
F P
0 g
s
.16779 .83099 m .16857 .81205 L .15593 .80658 L p .707 .577 .707 r
F P
0 g
s
.66304 .83238 m .66226 .85132 L .63479 .84746 L p .707 .577 .707 r
F P
0 g
s
.63479 .84746 m .63557 .82852 L .66304 .83238 L p .707 .577 .707 r
F P
0 g
s
.15593 .80658 m .15515 .82552 L .16779 .83099 L p .707 .577 .707 r
F P
0 g
s
.5425 .84522 m .54328 .82628 L .57261 .82531 L p .707 .577 .707 r
F P
0 g
s
.57261 .82531 m .57183 .84425 L .5425 .84522 L p .707 .577 .707 r
F P
0 g
s
.63557 .82852 m .63479 .84746 L .60363 .84502 L p .707 .577 .707 r
F P
0 g
s
.60363 .84502 m .60441 .82608 L .63557 .82852 L p .707 .577 .707 r
F P
0 g
s
.34971 .81644 m .34893 .83538 L .35594 .83038 L p .707 .577 .707 r
F P
0 g
s
.35594 .83038 m .35672 .81144 L .34971 .81644 L p .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64301 .77033 L .62523 .75874 L p .707 .577 .707 r
F P
0 g
s
.6385 .58015 m .63507 .56337 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.6471 .78298 m .64423 .77411 L p .64379 .60541 L .707 .577 .707 r
F P
0 g
s
.64379 .60541 m .64469 .60948 L .6471 .78298 L .707 .577 .707 r
F
.64309 .73678 m .64359 .53011 L .64423 .77411 L F
.64549 .50744 m .6471 .78298 L p .64359 .53011 L F P
0 g
s
.64309 .73678 m .64189 .55032 L .64359 .53011 L .707 .577 .707 r
F
.64275 .72557 m .64009 .27046 L p .64309 .73678 L F P
0 g
s
.64379 .60541 m .64359 .53011 L .64469 .60948 L .707 .577 .707 r
F
.64522 .62843 m .65823 .64285 L p .6392 .58238 L F P
0 g
s
.6385 .58015 m .63905 .58413 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.63905 .58413 m .64522 .62843 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.64009 .27046 m .64418 .28311 L p .64359 .53011 L .707 .577 .707 r
F P
0 g
s
.64189 .55032 m .64009 .27046 L .64359 .53011 L .707 .577 .707 r
F
.64301 .77033 m .64275 .72557 L p .64309 .73678 L F P
0 g
s
.63614 .68371 m .63536 .70265 L .64214 .70559 L p .707 .577 .707 r
F P
0 g
s
.64214 .70559 m .648 .70812 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.64183 .69542 m .63614 .68371 L .64214 .70559 L .707 .577 .707 r
F
.64522 .62843 m .63905 .58413 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.63905 .58413 m .6385 .58015 L p .63656 .57292 L .707 .578 .707 r
F P
0 g
s
.64423 .77411 m .64301 .77033 L p .64309 .73678 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64878 .68918 L .64154 .68605 L p .707 .577 .707 r
F P
0 g
s
.64154 .68605 m .63614 .68371 L p .64183 .69542 L .707 .577 .707 r
F P
0 g
s
.648 .70812 m .64154 .68605 L .64183 .69542 L .707 .577 .707 r
F
.65823 .64285 m .65151 .59458 L .63931 .58105 L p F P
0 g
s
.63931 .58105 m .6385 .58015 L p .6392 .58238 L .707 .577 .707 r
F P
0 g
s
.65823 .64285 m .63931 .58105 L .6392 .58238 L .707 .577 .707 r
F
.64418 .28311 m .64549 .50744 L p .64359 .53011 L F P
0 g
s
.57183 .84425 m .57261 .82531 L .60441 .82608 L p .707 .577 .707 r
F P
0 g
s
.60441 .82608 m .60363 .84502 L .57183 .84425 L p .707 .577 .707 r
F P
0 g
s
.15515 .82552 m .15593 .80658 L .15297 .80108 L p .707 .577 .707 r
F P
0 g
s
.15297 .80108 m .15219 .82001 L .15515 .82552 L p .707 .577 .707 r
F P
0 g
s
.35633 .27927 m .35925 .77914 L .36334 .79178 L p .707 .577 .707 r
F P
0 g
s
.35925 .77914 m .35633 .27927 L .36633 .26681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35672 .81144 m .35594 .83038 L .35298 .82488 L p .707 .577 .707 r
F P
0 g
s
.35298 .82488 m .35376 .80594 L .35672 .81144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15219 .82001 m .15297 .80108 L .15998 .79608 L p .707 .577 .707 r
F P
0 g
s
.62523 .75874 m .62231 .25887 L .64009 .27046 L p .707 .577 .707 r
F P
0 g
s
.15998 .79608 m .1592 .81502 L .15219 .82001 L p .707 .577 .707 r
F P
0 g
s
.35376 .80594 m .35298 .82488 L .34034 .81941 L p .707 .577 .707 r
F P
0 g
s
.34034 .81941 m .34112 .80047 L .35376 .80594 L p .707 .577 .707 r
F P
0 g
s
.36925 .76668 m .36633 .26681 L .38943 .25576 L p .707 .577 .707 r
F P
0 g
s
.36633 .26681 m .36925 .76668 L .35925 .77914 L p .707 .577 .707 r
F P
0 g
s
.1592 .81502 m .15998 .79608 L .17628 .79208 L p .707 .577 .707 r
F P
0 g
s
.17628 .79208 m .1755 .81102 L .1592 .81502 L p .707 .577 .707 r
F P
0 g
s
.62231 .25887 m .62523 .75874 L .59551 .74933 L p .707 .577 .707 r
F P
0 g
s
.59551 .74933 m .59258 .24946 L .62231 .25887 L p .707 .577 .707 r
F P
0 g
s
.34112 .80047 m .34034 .81941 L .31925 .8145 L p .707 .577 .707 r
F P
0 g
s
.31925 .8145 m .32003 .79556 L .34112 .80047 L p .707 .577 .707 r
F P
0 g
s
.73819 .6598 m .73147 .61152 L .70039 .61107 L p .707 .577 .707 r
F P
0 g
s
.73147 .61152 m .73819 .6598 L .76975 .65482 L p .707 .577 .707 r
F P
0 g
s
.76975 .65482 m .76304 .60655 L .73147 .61152 L p .707 .577 .707 r
F P
0 g
s
.76304 .60655 m .76975 .65482 L .79871 .6449 L p .707 .577 .707 r
F P
0 g
s
.79871 .6449 m .792 .59663 L .76304 .60655 L p .707 .577 .707 r
F P
0 g
s
.39063 .46038 m .39235 .75564 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .38943 .25576 L .42339 .2472 L p .707 .577 .707 r
F P
0 g
s
.39235 .75564 m .4077 .50423 L .42373 .71342 L .707 .577 .707 r
F
.42504 .52891 m .42605 .70231 L p .4077 .50423 L F P
0 g
s
.42605 .70231 m .42631 .74708 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.4077 .50423 m .42605 .70231 L .42373 .71342 L .707 .577 .707 r
F
.46487 .24197 m .46779 .74184 L .42631 .74708 L p F P
0 g
s
.44585 .68231 m .44662 .66337 L .43409 .66378 L p .707 .577 .707 r
F P
0 g
s
.42631 .74708 m .42339 .2472 L .46487 .24197 L p .707 .577 .707 r
F P
0 g
s
.43409 .66378 m .41729 .66434 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.44585 .68231 m .43409 .66378 L .43203 .67362 L .707 .577 .707 r
F
.41729 .66434 m .41651 .68328 L .43011 .68283 L p F P
0 g
s
.43011 .68283 m .44585 .68231 L p .43203 .67362 L .707 .577 .707 r
F P
0 g
s
.43203 .67362 m .41729 .66434 L .43011 .68283 L .707 .577 .707 r
F
.42631 .74708 m .41618 .74963 L p .42373 .71342 L F P
0 g
s
.41618 .74963 m .39235 .75564 L p .42373 .71342 L .707 .577 .707 r
F P
0 g
s
.42339 .2472 m .42504 .52891 L p .4077 .50423 L .707 .577 .707 r
F P
0 g
s
.4557 .60809 m .44954 .56379 L p .42003 .56973 L .707 .577 .707 r
F P
0 g
s
.44954 .56379 m .44899 .55981 L .44718 .56043 L p .707 .577 .707 r
F P
0 g
s
.44718 .56043 m .42003 .56973 L p .44954 .56379 L .707 .577 .707 r
F P
0 g
s
.38846 .57471 m .39518 .62298 L .42372 .61848 L p .707 .577 .707 r
F P
0 g
s
.42372 .61848 m .42674 .61801 L p .42266 .61339 L .707 .577 .707 r
F P
0 g
s
.42266 .61339 m .38846 .57471 L .42372 .61848 L .707 .577 .707 r
F
.39235 .75564 m .36925 .76668 L p .38282 .42309 L F P
0 g
s
.38943 .25576 m .39063 .46038 L p .38282 .42309 L .707 .577 .707 r
F P
0 g
s
.1755 .81102 m .17628 .79208 L .20027 .78947 L p .707 .577 .707 r
F P
0 g
s
.20027 .78947 m .19949 .8084 L .1755 .81102 L p .707 .577 .707 r
F P
0 g
s
.70711 .65935 m .70039 .61107 L .67284 .60523 L p .707 .577 .707 r
F P
0 g
s
.70039 .61107 m .70711 .65935 L .73819 .6598 L p .707 .577 .707 r
F P
0 g
s
.792 .59663 m .79871 .6449 L .82223 .63101 L p .707 .577 .707 r
F P
0 g
s
.82223 .63101 m .81552 .58273 L .792 .59663 L p .707 .577 .707 r
F P
0 g
s
.32003 .79556 m .31925 .8145 L .29178 .81064 L p .707 .577 .707 r
F P
0 g
s
.29178 .81064 m .29256 .7917 L .32003 .79556 L p .707 .577 .707 r
F P
0 g
s
.72772 .71932 m .7285 .70038 L .69734 .69795 L p .707 .577 .707 r
F P
0 g
s
.7285 .70038 m .72772 .71932 L .75952 .72009 L p .707 .577 .707 r
F P
0 g
s
.75952 .72009 m .7603 .70115 L .7285 .70038 L p .707 .577 .707 r
F P
0 g
s
.59258 .24946 m .59551 .74933 L .55674 .74303 L p .707 .577 .707 r
F P
0 g
s
.55674 .74303 m .55382 .24316 L .59258 .24946 L p .707 .577 .707 r
F P
0 g
s
.7603 .70115 m .75952 .72009 L .78885 .71912 L p .707 .577 .707 r
F P
0 g
s
.78885 .71912 m .78963 .70018 L .7603 .70115 L p .707 .577 .707 r
F P
0 g
s
.69734 .69795 m .69656 .71689 L .72772 .71932 L p .707 .577 .707 r
F P
0 g
s
.67956 .65351 m .67284 .60523 L .65151 .59458 L p .707 .577 .707 r
F P
0 g
s
.67284 .60523 m .67956 .65351 L .70711 .65935 L p .707 .577 .707 r
F P
0 g
s
.19949 .8084 m .20027 .78947 L .2296 .7885 L p .707 .577 .707 r
F P
0 g
s
.69656 .71689 m .69734 .69795 L .66987 .69409 L p .707 .577 .707 r
F P
0 g
s
.2296 .7885 m .22882 .80744 L .19949 .8084 L p .707 .577 .707 r
F P
0 g
s
.81552 .58273 m .82223 .63101 L .83801 .61451 L p .707 .577 .707 r
F P
0 g
s
.83801 .61451 m .83129 .56623 L .81552 .58273 L p .707 .577 .707 r
F P
0 g
s
.66987 .69409 m .66909 .71303 L .69656 .71689 L p .707 .577 .707 r
F P
0 g
s
.29256 .7917 m .29178 .81064 L .26062 .80821 L p .707 .577 .707 r
F P
0 g
s
.26062 .80821 m .2614 .78927 L .29256 .7917 L p .707 .577 .707 r
F P
0 g
s
.78963 .70018 m .78885 .71912 L .81284 .71651 L p .707 .577 .707 r
F P
0 g
s
.81284 .71651 m .81362 .69757 L .78963 .70018 L p .707 .577 .707 r
F P
0 g
s
.22882 .80744 m .2296 .7885 L .2614 .78927 L p .707 .577 .707 r
F P
0 g
s
.2614 .78927 m .26062 .80821 L .22882 .80744 L p .707 .577 .707 r
F P
0 g
s
.73543 .76639 m .73386 .73061 L .7027 .72923 L p .707 .577 .707 r
F P
0 g
s
.73386 .73061 m .73543 .76639 L .76723 .7641 L p .707 .577 .707 r
F P
0 g
s
.76723 .7641 m .76566 .72832 L .73386 .73061 L p .707 .577 .707 r
F P
0 g
s
.66909 .71303 m .66987 .69409 L .64878 .68918 L p .707 .577 .707 r
F P
0 g
s
.55382 .24316 m .55674 .74303 L .51273 .74045 L p .707 .577 .707 r
F P
0 g
s
.51273 .74045 m .50981 .24057 L .55382 .24316 L p .707 .577 .707 r
F P
0 g
s
.76566 .72832 m .76723 .7641 L .79656 .75836 L p .707 .577 .707 r
F P
0 g
s
.79656 .75836 m .79499 .72258 L .76566 .72832 L p .707 .577 .707 r
F P
0 g
s
.64878 .68918 m .648 .70812 L .66909 .71303 L p .707 .577 .707 r
F P
0 g
s
.65151 .59458 m .65823 .64285 L .67956 .65351 L p .707 .577 .707 r
F P
0 g
s
.70426 .76501 m .7027 .72923 L .67523 .72432 L p .707 .577 .707 r
F P
0 g
s
.7027 .72923 m .70426 .76501 L .73543 .76639 L p .707 .577 .707 r
F P
0 g
s
.46779 .74184 m .46487 .24197 L .50981 .24057 L p .707 .577 .707 r
F P
0 g
s
.83129 .56623 m .83801 .61451 L .8445 .59701 L p .707 .577 .707 r
F P
0 g
s
.8445 .59701 m .83779 .54873 L .83129 .56623 L p .707 .577 .707 r
F P
0 g
s
.50981 .24057 m .51273 .74045 L .46779 .74184 L p .707 .577 .707 r
F P
0 g
s
.79499 .72258 m .79656 .75836 L .82055 .74974 L p .707 .577 .707 r
F P
0 g
s
.81362 .69757 m .81284 .71651 L .82914 .71251 L p .707 .577 .707 r
F P
0 g
s
.82055 .74974 m .81898 .71396 L .79499 .72258 L p .707 .577 .707 r
F P
0 g
s
.82914 .71251 m .82992 .69357 L .81362 .69757 L p .707 .577 .707 r
F P
0 g
s
.67523 .72432 m .67679 .7601 L .70426 .76501 L p .707 .577 .707 r
F P
0 g
s
.67679 .7601 m .67523 .72432 L .65414 .71635 L p .707 .577 .707 r
F P
0 g
s
.81898 .71396 m .82055 .74974 L .83685 .73908 L p .707 .577 .707 r
F P
0 g
s
.82992 .69357 m .82914 .71251 L .83105 .71115 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83528 .7033 L .83114 .70601 L p .707 .577 .707 r
F P
0 g
s
.83685 .73908 m .83114 .70601 L .83073 .73049 L .707 .577 .707 r
F
.83528 .7033 m .83685 .73908 L .84386 .72743 L p F P
0 g
s
.83105 .71115 m .83616 .70751 L p .8313 .69664 L .707 .577 .707 r
F P
0 g
s
.8313 .69664 m .82992 .69357 L .83105 .71115 L .707 .577 .707 r
F
.83114 .70601 m .81898 .71396 L p .83073 .73049 L F P
0 g
s
.83779 .54873 m .8445 .59701 L .84107 .58022 L p .707 .578 .707 r
F P
0 g
s
.84107 .58022 m .83436 .53194 L .83779 .54873 L p .707 .578 .707 r
F P
0 g
s
.65414 .71635 m .65571 .75213 L .67679 .7601 L p .707 .577 .707 r
F P
0 g
s
.84386 .72743 m .84229 .69165 L .83528 .7033 L p .707 .577 .707 r
F P
0 g
s
.83616 .70751 m .83694 .68857 L .82992 .69357 L p .707 .577 .707 r
F P
0 g
s
.65571 .75213 m .65414 .71635 L .64149 .70611 L p .707 .577 .707 r
F P
0 g
s
.63536 .70265 m .63614 .68371 L .63318 .67821 L p .707 .577 .707 r
F P
0 g
s
.63318 .67821 m .6324 .69715 L .63536 .70265 L p .707 .577 .707 r
F P
0 g
s
.63507 .56337 m .64179 .61164 L .64522 .62843 L p .707 .578 .707 r
F P
0 g
s
.64179 .61164 m .63507 .56337 L .64156 .54587 L p .707 .577 .707 r
F P
0 g
s
.64149 .70611 m .64306 .74189 L .65571 .75213 L p .707 .577 .707 r
F P
0 g
s
.83436 .53194 m .84107 .58022 L .82806 .5658 L p .707 .577 .707 r
F P
0 g
s
.82806 .5658 m .82134 .51752 L .83436 .53194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83694 .68857 m .83616 .70751 L .8332 .70201 L p .707 .577 .707 r
F P
0 g
s
.8332 .70201 m .83398 .68307 L .83694 .68857 L p .707 .577 .707 r
F P
0 g
s
.64306 .74189 m .64149 .70611 L .63853 .6946 L p .707 .577 .707 r
F P
0 g
s
.64828 .59414 m .64156 .54587 L .65734 .52936 L p .707 .577 .707 r
F P
0 g
s
.64156 .54587 m .64828 .59414 L .64179 .61164 L p .707 .577 .707 r
F P
0 g
s
.6324 .69715 m .63318 .67821 L .64019 .67321 L p .707 .577 .707 r
F P
0 g
s
.63853 .6946 m .6401 .73038 L .64306 .74189 L p .707 .577 .707 r
F P
0 g
s
.84229 .69165 m .84386 .72743 L .8409 .71591 L p .707 .577 .707 r
F P
0 g
s
.8409 .71591 m .83933 .68014 L .84229 .69165 L p .707 .577 .707 r
F P
0 g
s
.64019 .67321 m .63941 .69215 L .6324 .69715 L p .707 .577 .707 r
F P
0 g
s
.82134 .51752 m .82806 .5658 L .80673 .55514 L p .707 .577 .707 r
F P
0 g
s
.80673 .55514 m .80001 .50687 L .82134 .51752 L p .707 .577 .707 r
F P
0 g
s
.39518 .62298 m .38846 .57471 L .35738 .57425 L p .707 .577 .707 r
F P
0 g
s
.42674 .61801 m .42003 .56973 L .38846 .57471 L p .707 .577 .707 r
F P
0 g
s
.42003 .56973 m .42674 .61801 L .4557 .60809 L p .707 .577 .707 r
F P
0 g
s
.3641 .62253 m .35738 .57425 L .32983 .56841 L p .707 .577 .707 r
F P
0 g
s
.35738 .57425 m .3641 .62253 L .39518 .62298 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63941 .69215 m .64019 .67321 L .64354 .67239 L p .707 .577 .707 r
F P
0 g
s
.64354 .67239 m .65649 .66921 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .63853 .6946 L .64377 .6859 L p .707 .577 .707 r
F P
0 g
s
.6401 .73038 m .64377 .6859 L .64395 .69685 L .707 .577 .707 r
F
.63941 .69215 m .64354 .67239 L .64377 .68629 L F
.65649 .66921 m .65571 .68815 L .64385 .69106 L p F P
0 g
s
.64385 .69106 m .63941 .69215 L p .64377 .68629 L .707 .577 .707 r
F P
0 g
s
.64377 .68629 m .65649 .66921 L .64385 .69106 L .707 .577 .707 r
F
.64555 .68294 m .64712 .71872 L .64439 .72324 L p F P
0 g
s
.64439 .72324 m .6401 .73038 L p .64395 .69685 L .707 .577 .707 r
F P
0 g
s
.64395 .69685 m .64555 .68294 L .64439 .72324 L .707 .577 .707 r
F
.64377 .6859 m .64555 .68294 L p .64395 .69685 L F P
0 g
s
.44899 .55981 m .4557 .60809 L .47922 .59419 L p .707 .577 .707 r
F P
0 g
s
.47922 .59419 m .47251 .54592 L .44899 .55981 L p .707 .577 .707 r
F P
0 g
s
.83398 .68307 m .8332 .70201 L .82055 .69654 L p .707 .577 .707 r
F P
0 g
s
.82055 .69654 m .82133 .6776 L .83398 .68307 L p .707 .577 .707 r
F P
0 g
s
.65734 .52936 m .66406 .57764 L .64828 .59414 L p .707 .577 .707 r
F P
0 g
s
.66406 .57764 m .65734 .52936 L .68086 .51547 L p .707 .577 .707 r
F P
0 g
s
.80001 .50687 m .80673 .55514 L .77918 .5493 L p .707 .577 .707 r
F P
0 g
s
.77918 .5493 m .77246 .50103 L .80001 .50687 L p .707 .577 .707 r
F P
0 g
s
.38471 .68251 m .38549 .66357 L .35433 .66113 L p .707 .577 .707 r
F P
0 g
s
.38549 .66357 m .38471 .68251 L .41651 .68328 L p .707 .577 .707 r
F P
0 g
s
.41651 .68328 m .41729 .66434 L .38549 .66357 L p .707 .577 .707 r
F P
0 g
s
.35433 .66113 m .35355 .68007 L .38471 .68251 L p .707 .577 .707 r
F P
0 g
s
.33655 .61669 m .32983 .56841 L .3085 .55776 L p .707 .577 .707 r
F P
0 g
s
.32983 .56841 m .33655 .61669 L .3641 .62253 L p .707 .577 .707 r
F P
0 g
s
.35355 .68007 m .35433 .66113 L .32686 .65727 L p .707 .577 .707 r
F P
0 g
s
.83933 .68014 m .8409 .71591 L .82826 .70567 L p .707 .577 .707 r
F P
0 g
s
.82826 .70567 m .82669 .66989 L .83933 .68014 L p .707 .577 .707 r
F P
0 g
s
.47251 .54592 m .47922 .59419 L .495 .57769 L p .707 .577 .707 r
F P
0 g
s
.495 .57769 m .48828 .52941 L .47251 .54592 L p .707 .577 .707 r
F P
0 g
s
.32686 .65727 m .32608 .67621 L .35355 .68007 L p .707 .577 .707 r
F P
0 g
s
.68758 .56375 m .68086 .51547 L .70982 .50555 L p .707 .577 .707 r
F P
0 g
s
.68086 .51547 m .68758 .56375 L .66406 .57764 L p .707 .577 .707 r
F P
0 g
s
.77246 .50103 m .77918 .5493 L .7481 .54885 L p .707 .577 .707 r
F P
0 g
s
.7481 .54885 m .74138 .50057 L .77246 .50103 L p .707 .577 .707 r
F P
0 g
s
.44662 .66337 m .44585 .68231 L .46983 .6797 L p .707 .577 .707 r
F P
0 g
s
.46983 .6797 m .47061 .66076 L .44662 .66337 L p .707 .577 .707 r
F P
0 g
s
.71654 .55383 m .70982 .50555 L .74138 .50057 L p .707 .577 .707 r
F P
0 g
s
.70982 .50555 m .71654 .55383 L .68758 .56375 L p .707 .577 .707 r
F P
0 g
s
.65571 .68815 m .65649 .66921 L .68048 .6666 L p .707 .577 .707 r
F P
0 g
s
.68048 .6666 m .6797 .68553 L .65571 .68815 L p .707 .577 .707 r
F P
0 g
s
.64712 .71872 m .64555 .68294 L .66184 .67228 L p .707 .577 .707 r
F P
0 g
s
.74138 .50057 m .7481 .54885 L .71654 .55383 L p .707 .577 .707 r
F P
0 g
s
.39242 .72957 m .39085 .6938 L .35969 .69242 L p .707 .577 .707 r
F P
0 g
s
.39085 .6938 m .39242 .72957 L .42422 .72728 L p .707 .577 .707 r
F P
0 g
s
.42422 .72728 m .42265 .69151 L .39085 .6938 L p .707 .577 .707 r
F P
0 g
s
.32608 .67621 m .32686 .65727 L .30577 .65237 L p .707 .577 .707 r
F P
0 g
s
.82133 .6776 m .82055 .69654 L .79947 .69163 L p .707 .577 .707 r
F P
0 g
s
.79947 .69163 m .80025 .67269 L .82133 .6776 L p .707 .577 .707 r
F P
0 g
s
.42265 .69151 m .42422 .72728 L .45355 .72155 L p .707 .577 .707 r
F P
0 g
s
.45355 .72155 m .45198 .68577 L .42265 .69151 L p .707 .577 .707 r
F P
0 g
s
.30577 .65237 m .30499 .67131 L .32608 .67621 L p .707 .577 .707 r
F P
0 g
s
.31522 .60604 m .3085 .55776 L .29549 .54334 L p .707 .577 .707 r
F P
0 g
s
.3085 .55776 m .31522 .60604 L .33655 .61669 L p .707 .577 .707 r
F P
0 g
s
.36125 .7282 m .35969 .69242 L .33222 .6875 L p .707 .577 .707 r
F P
0 g
s
.35969 .69242 m .36125 .7282 L .39242 .72957 L p .707 .577 .707 r
F P
0 g
s
.48828 .52941 m .495 .57769 L .50149 .56019 L p .707 .577 .707 r
F P
0 g
s
.50149 .56019 m .49478 .51191 L .48828 .52941 L p .707 .577 .707 r
F P
0 g
s
.82669 .66989 m .82826 .70567 L .80717 .69771 L p .707 .577 .707 r
F P
0 g
s
.80717 .69771 m .8056 .66193 L .82669 .66989 L p .707 .577 .707 r
F P
0 g
s
.66184 .67228 m .66341 .70806 L .64712 .71872 L p .707 .577 .707 r
F P
0 g
s
.45198 .68577 m .45355 .72155 L .47754 .71293 L p .707 .577 .707 r
F P
0 g
s
.47061 .66076 m .46983 .6797 L .48613 .6757 L p .707 .577 .707 r
F P
0 g
s
.47754 .71293 m .47597 .67715 L .45198 .68577 L p .707 .577 .707 r
F P
0 g
s
.48613 .6757 m .48691 .65676 L .47061 .66076 L p .707 .577 .707 r
F P
0 g
s
.33222 .6875 m .33378 .72328 L .36125 .7282 L p .707 .577 .707 r
F P
0 g
s
.33378 .72328 m .33222 .6875 L .31113 .67954 L p .707 .577 .707 r
F P
0 g
s
.30499 .67131 m .30577 .65237 L .29313 .64689 L p .707 .577 .707 r
F P
0 g
s
.80025 .67269 m .79947 .69163 L .772 .68777 L p .707 .577 .707 r
F P
0 g
s
.772 .68777 m .77278 .66883 L .80025 .67269 L p .707 .577 .707 r
F P
0 g
s
.6797 .68553 m .68048 .6666 L .70981 .66563 L p .707 .577 .707 r
F P
0 g
s
.66341 .70806 m .66184 .67228 L .68583 .66366 L p .707 .577 .707 r
F P
0 g
s
.29313 .64689 m .29235 .66583 L .30499 .67131 L p .707 .577 .707 r
F P
0 g
s
.30221 .59161 m .29549 .54334 L .29206 .52655 L p .707 .578 .707 r
F P
0 g
s
.29549 .54334 m .30221 .59161 L .31522 .60604 L p .707 .577 .707 r
F P
0 g
s
.47597 .67715 m .47754 .71293 L .49384 .70227 L p .707 .577 .707 r
F P
0 g
s
.48691 .65676 m .48613 .6757 L .48804 .67433 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .49227 .66649 L .48813 .6692 L p .707 .577 .707 r
F P
0 g
s
.49384 .70227 m .48813 .6692 L .48772 .69367 L .707 .577 .707 r
F
.49227 .66649 m .49384 .70227 L .50085 .69061 L p F P
0 g
s
.48804 .67433 m .49315 .6707 L p .48829 .65983 L .707 .577 .707 r
F P
0 g
s
.48829 .65983 m .48691 .65676 L .48804 .67433 L .707 .577 .707 r
F
.48813 .6692 m .47597 .67715 L p .48772 .69367 L F P
0 g
s
.70981 .66563 m .70903 .68457 L .6797 .68553 L p .707 .577 .707 r
F P
0 g
s
.8056 .66193 m .80717 .69771 L .7797 .69279 L p .707 .577 .707 r
F P
0 g
s
.7797 .69279 m .77813 .65701 L .8056 .66193 L p .707 .577 .707 r
F P
0 g
s
.49478 .51191 m .50149 .56019 L .49806 .54341 L p .707 .578 .707 r
F P
0 g
s
.49806 .54341 m .49135 .49513 L .49478 .51191 L p .707 .578 .707 r
F P
0 g
s
.31113 .67954 m .3127 .71531 L .33378 .72328 L p .707 .577 .707 r
F P
0 g
s
.68583 .66366 m .6874 .69944 L .66341 .70806 L p .707 .577 .707 r
F P
0 g
s
.77278 .66883 m .772 .68777 L .74084 .68534 L p .707 .577 .707 r
F P
0 g
s
.74084 .68534 m .74162 .6664 L .77278 .66883 L p .707 .577 .707 r
F P
0 g
s
.50085 .69061 m .49928 .65483 L .49227 .66649 L p .707 .577 .707 r
F P
0 g
s
.49315 .6707 m .49393 .65176 L .48691 .65676 L p .707 .577 .707 r
F P
0 g
s
.70903 .68457 m .70981 .66563 L .74162 .6664 L p .707 .577 .707 r
F P
0 g
s
.6874 .69944 m .68583 .66366 L .71517 .65792 L p .707 .577 .707 r
F P
0 g
s
.3127 .71531 m .31113 .67954 L .29848 .66929 L p .707 .577 .707 r
F P
0 g
s
.74162 .6664 m .74084 .68534 L .70903 .68457 L p .707 .577 .707 r
F P
0 g
s
.77813 .65701 m .7797 .69279 L .74854 .69141 L p .707 .577 .707 r
F P
0 g
s
.74854 .69141 m .74697 .65563 L .77813 .65701 L p .707 .577 .707 r
F P
0 g
s
.29235 .66583 m .29313 .64689 L .29017 .64139 L p .707 .577 .707 r
F P
0 g
s
.71673 .6937 m .71517 .65792 L .74697 .65563 L p .707 .577 .707 r
F P
0 g
s
.71517 .65792 m .71673 .6937 L .6874 .69944 L p .707 .577 .707 r
F P
0 g
s
.29017 .64139 m .28939 .66033 L .29235 .66583 L p .707 .577 .707 r
F P
0 g
s
.29206 .52655 m .29878 .57483 L .30221 .59161 L p .707 .578 .707 r
F P
0 g
s
.29878 .57483 m .29206 .52655 L .29855 .50905 L p .707 .577 .707 r
F P
0 g
s
.74697 .65563 m .74854 .69141 L .71673 .6937 L p .707 .577 .707 r
F P
0 g
s
.29848 .66929 m .30005 .70507 L .3127 .71531 L p .707 .577 .707 r
F P
0 g
s
.49135 .49513 m .49806 .54341 L .48505 .52898 L p .707 .577 .707 r
F P
0 g
s
.48505 .52898 m .47833 .4807 L .49135 .49513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49393 .65176 m .49315 .6707 L .49019 .66519 L p .707 .577 .707 r
F P
0 g
s
.49019 .66519 m .49097 .64625 L .49393 .65176 L p .707 .577 .707 r
F P
0 g
s
.30005 .70507 m .29848 .66929 L .29552 .65778 L p .707 .577 .707 r
F P
0 g
s
.30527 .55733 m .29855 .50905 L .31433 .49255 L p .707 .577 .707 r
F P
0 g
s
.29855 .50905 m .30527 .55733 L .29878 .57483 L p .707 .577 .707 r
F P
0 g
s
.28939 .66033 m .29017 .64139 L .29718 .63639 L p .707 .577 .707 r
F P
0 g
s
.29552 .65778 m .29709 .69356 L .30005 .70507 L p .707 .577 .707 r
F P
0 g
s
.49928 .65483 m .50085 .69061 L .49789 .6791 L p .707 .577 .707 r
F P
0 g
s
.49789 .6791 m .49632 .64332 L .49928 .65483 L p .707 .577 .707 r
F P
0 g
s
.29718 .63639 m .2964 .65533 L .28939 .66033 L p .707 .577 .707 r
F P
0 g
s
.47833 .4807 m .48505 .52898 L .46372 .51833 L p .707 .577 .707 r
F P
0 g
s
.46372 .51833 m .457 .47005 L .47833 .4807 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2964 .65533 m .29718 .63639 L .30053 .63557 L p .707 .577 .707 r
F P
0 g
s
.30053 .63557 m .31348 .63239 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .29552 .65778 L .30076 .64908 L p .707 .577 .707 r
F P
0 g
s
.29709 .69356 m .30076 .64908 L .30094 .66004 L .707 .577 .707 r
F
.2964 .65533 m .30053 .63557 L .30076 .64948 L F
.31348 .63239 m .3127 .65133 L .30084 .65424 L p F P
0 g
s
.30084 .65424 m .2964 .65533 L p .30076 .64948 L .707 .577 .707 r
F P
0 g
s
.30076 .64948 m .31348 .63239 L .30084 .65424 L .707 .577 .707 r
F
.30254 .64613 m .3041 .6819 L .30138 .68643 L p F P
0 g
s
.30138 .68643 m .29709 .69356 L p .30094 .66004 L .707 .577 .707 r
F P
0 g
s
.30094 .66004 m .30254 .64613 L .30138 .68643 L .707 .577 .707 r
F
.30076 .64908 m .30254 .64613 L p .30094 .66004 L F P
0 g
s
.49097 .64625 m .49019 .66519 L .47754 .65972 L p .707 .577 .707 r
F P
0 g
s
.47754 .65972 m .47832 .64078 L .49097 .64625 L p .707 .577 .707 r
F P
0 g
s
.31433 .49255 m .32105 .54082 L .30527 .55733 L p .707 .577 .707 r
F P
0 g
s
.32105 .54082 m .31433 .49255 L .33785 .47865 L p .707 .577 .707 r
F P
0 g
s
.457 .47005 m .46372 .51833 L .43617 .51249 L p .707 .577 .707 r
F P
0 g
s
.43617 .51249 m .42945 .46421 L .457 .47005 L p .707 .577 .707 r
F P
0 g
s
.49632 .64332 m .49789 .6791 L .48525 .66886 L p .707 .577 .707 r
F P
0 g
s
.48525 .66886 m .48368 .63308 L .49632 .64332 L p .707 .577 .707 r
F P
0 g
s
.34457 .52693 m .33785 .47865 L .36681 .46873 L p .707 .577 .707 r
F P
0 g
s
.33785 .47865 m .34457 .52693 L .32105 .54082 L p .707 .577 .707 r
F P
0 g
s
.42945 .46421 m .43617 .51249 L .40509 .51203 L p .707 .577 .707 r
F P
0 g
s
.40509 .51203 m .39837 .46376 L .42945 .46421 L p .707 .577 .707 r
F P
0 g
s
.37353 .51701 m .36681 .46873 L .39837 .46376 L p .707 .577 .707 r
F P
0 g
s
.36681 .46873 m .37353 .51701 L .34457 .52693 L p .707 .577 .707 r
F P
0 g
s
.3127 .65133 m .31348 .63239 L .33747 .62978 L p .707 .577 .707 r
F P
0 g
s
.33747 .62978 m .33669 .64872 L .3127 .65133 L p .707 .577 .707 r
F P
0 g
s
.3041 .6819 m .30254 .64613 L .31883 .63546 L p .707 .577 .707 r
F P
0 g
s
.39837 .46376 m .40509 .51203 L .37353 .51701 L p .707 .577 .707 r
F P
0 g
s
.47832 .64078 m .47754 .65972 L .45646 .65481 L p .707 .577 .707 r
F P
0 g
s
.45646 .65481 m .45724 .63587 L .47832 .64078 L p .707 .577 .707 r
F P
0 g
s
.48368 .63308 m .48525 .66886 L .46416 .66089 L p .707 .577 .707 r
F P
0 g
s
.46416 .66089 m .46259 .62511 L .48368 .63308 L p .707 .577 .707 r
F P
0 g
s
.31883 .63546 m .3204 .67124 L .3041 .6819 L p .707 .577 .707 r
F P
0 g
s
.45724 .63587 m .45646 .65481 L .42899 .65096 L p .707 .577 .707 r
F P
0 g
s
.42899 .65096 m .42977 .63202 L .45724 .63587 L p .707 .577 .707 r
F P
0 g
s
.33669 .64872 m .33747 .62978 L .3668 .62881 L p .707 .577 .707 r
F P
0 g
s
.3204 .67124 m .31883 .63546 L .34282 .62684 L p .707 .577 .707 r
F P
0 g
s
.3668 .62881 m .36602 .64775 L .33669 .64872 L p .707 .577 .707 r
F P
0 g
s
.46259 .62511 m .46416 .66089 L .43669 .65598 L p .707 .577 .707 r
F P
0 g
s
.43669 .65598 m .43512 .6202 L .46259 .62511 L p .707 .577 .707 r
F P
0 g
s
.34282 .62684 m .34439 .66262 L .3204 .67124 L p .707 .577 .707 r
F P
0 g
s
.42977 .63202 m .42899 .65096 L .39783 .64852 L p .707 .577 .707 r
F P
0 g
s
.39783 .64852 m .39861 .62958 L .42977 .63202 L p .707 .577 .707 r
F P
0 g
s
.36602 .64775 m .3668 .62881 L .39861 .62958 L p .707 .577 .707 r
F P
0 g
s
.34439 .66262 m .34282 .62684 L .37215 .62111 L p .707 .577 .707 r
F P
0 g
s
.39861 .62958 m .39783 .64852 L .36602 .64775 L p .707 .577 .707 r
F P
0 g
s
.43512 .6202 m .43669 .65598 L .40553 .6546 L p .707 .577 .707 r
F P
0 g
s
.40553 .6546 m .40396 .61882 L .43512 .6202 L p .707 .577 .707 r
F P
0 g
s
.37372 .65689 m .37215 .62111 L .40396 .61882 L p .707 .577 .707 r
F P
0 g
s
.37215 .62111 m .37372 .65689 L .34439 .66262 L p .707 .577 .707 r
F P
0 g
s
.40396 .61882 m .40553 .6546 L .37372 .65689 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00O7oo1P000UYF00<005YFFUH02EYF00<005YFFUH015YF2@00OGoo001fOol60008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1U
Ool006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF20000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP000UYF10000UYF00<005YFFUH00UYF20001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH000030006
FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF008000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00H7oo0P001UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001NOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`80009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00FWoo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00F7oo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EWoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0001Ioo`l0
041oo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00011oo`H000AJEP03001JEUYF00IJEP03
001JEP0000<003aoo`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000ioo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Uoo`00E7oo00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00D005YF
FUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF
00002goo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=goo001DOol0
0`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH20003FUH40002
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00L005YFFUIJEP00FUH00009Ool20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02000eOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD0
009JEP03001JEUYF00IJEP8000MJEP<000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000Moo`<000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8003=oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01@001UYF00<005YFFUH01UYF0P002UYF0P000eYF00@005YFFUH000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF0`0000Eoo`00FUIJEP0000IJEP03
001JEUYF00IJEP8000YJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00@007ooOomoo`8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00035oo`00Dgoo
00<005YF00001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
1000FUIJEUYF0P000UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000Woo00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@0
05YFFUH000Moo`03001JEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF009JEP80009JEP05
001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000Ool00000
1eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH002moo`00Dgoo00<005YF00001EYF0`0027oo00<005YF00001UYF00<005YFFUH0
1UYF0P002UYF00H005YFFUIJEP00FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
0`00FUH00005FUH00`00Oomoo`08Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH02000FUIJ
EUYF001JEP00FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00004FUH00`00Oomoo`09
Ool00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH01000FUIJEP000eYF00<005YF00000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF008002ioo`00Dgoo00@005YFFUH0009JEP03001oogoo00Yoo`03001JEP0000IJEP03
001JEUYF00IJEP8000YJEP03001JEP0000AJEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000^Ool005=oo`06001JEUYF001JEP003Goo00<005YF00001UYF00<005YFFUH01UYF0P002UYF
0`0015YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`9JEP8000ioo`03001JEP0000IJEP03001J
EUYF00IJEP8000QJEP80009JEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH015YF
1P004Goo1@001EYF00@005YFFUH002ioo`00E7oo0UYF0P003Woo00<005YF00001UYF00<005YFFUH0
1UYF0P001UYF0P0015YF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000L
Ool20003FUH01000FUIJEP00;Woo001DOol2FUH4000<Ool00`00FUH00006FUH30006FUH20004FUH2
0007FUH01@00FUIJEUYF00000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYF0002FUH01@00FUIJEUYF00001eYF00<005YF00000P0087oo0P0000EJEP00FUIJEP0002io
o`00E7oo00AJEP00FUH0009JEP8000Yoo`03001JEP0000EJEPD000EJEP80009JEP800003FUH005YF
00IJEP05001JEUYFFUH00002FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUH0009JEP05001JEUYFFUH00007FUH2000UOol20002FUH2000]Ool005Aoo`04FUH005YF0004
FUH30007Ool00`00FUH00005FUH50005FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH00UYF0P00:Goo00@005YF000002eoo`00E7oo0P000UYF00<005YFFUH00UYF00<0
05YF00000`000goo00<005YF00001EYF2`001UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009J
EP03001JEUYF008002Yoo`<00003FUH007oo02aoo`00E7oo0P000UYF00<005YFFUH00UYF00<005YF
FUH00eYF400015YF00<005YFFUH01EYF0P001UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP<002Yo
o`800005FUH00000FUH0000]Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
15YF00<007ooOol0:Goo00H005YFFUIJEP00FUH2000]Ool005Aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0UYF00@005YFFUH002]oo`03001JEUYF00=JEP03001JEP0002eoo`00EGoo00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUH0000ZOol30005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP8002Yoo`04001J
EUYF0005FUH01000FUH00000;7oo001EOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001oogoo02Moo`8000=J
EP03001JEUYF00=JEP04001JEUYF000/Ool005Ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH20009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P005goo0`0037oo0P001UYF00<005YF
FUH00UYF00@005YFFUH002aoo`00B7oo3@000Woo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0057oo1@0027oo0`0000=J
EP00FUH01EYF00<005YFFUH00UYF00@005YFFUH002aoo`00A7oo10000UYF00<005YFFUH01UYF00<0
05YF0000100015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000UYF0P004Woo1@001Goo0`0015YF00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo0010Ool4
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF1@003Goo2P001eYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;Goo000nOol200000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00@005YFFUIJEQ4000AJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00>goo0`000eYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00H005YF000005YF0007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH2000015YF000000001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00=JEP03001oogoo02aoo`00
>7oo0`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000IJ
EP03001JEUYF00AJEPd000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool0
03Ioo`800003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEPD0009JEPL000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF000`Ool003Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP04001JEP00Ool400000eYF001JEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF0000<Goo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000bOol0035oo`8000IJEP03001JEUYF
00IJEP04001JEUYFFUHA00000eYF0000000600000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`0aOol0031oo`03001J
EP0000IJEP03001JEUYF009JEPP000EJEP8000MJEP@00004FUH000000005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8003Ao
o`00;goo00@005YFFUH000MJEP@000AJEP03001JEUYF00IJEP8000IJEP8000AJEP8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF000f
Ool002ioo`05001JEUYFFUH00005FUH30007FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
0002FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH400000goo001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH3000gOol002eoo`03001JEUYF009JEP04001JEUYFFUH2
0002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8003Uoo`00;Goo00<005YFFUH00eYF0`0015YF00<005YFFUH01EYF00<005YF
FUH01eYF1`0000AJEP00000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH400000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000kOol002aoo`03001JEUYF00=JEP80
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00=JEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P00?Woo000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF10002EYF00<005YF
FUH00eYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00AJEQP000=JEP03001JEUYF
00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP02FUH600000eYF001JEP06FUH?000nOol002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUH000020003FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30000
0eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40005FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P001EYF00<005YFFUH00UYF0P000goo2@0015YF00<005YFFUH01UYF00<005YF
00000`00>Woo000/Ool01000FUH000000eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH00eYF00<005YFFUH00UYF8P000UYF0P000eYF00D005YFFUIJEP00
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Moo`00
;7oo00@005YF000000=JEP03001JEUYF009JEP<000QJEP03001JEUYF009JEPT0009JEP800003FUH0
05YF00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP<00003FUH005YF009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005FUH60008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00002000dOol002aoo`04001JEP000003FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF2@002Goo100000=JEP00FUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P000eYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEPX0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo00@005YFFUH000AJEP<0
00=JEPD001Eoo`03001JEP00009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<Goo000/Ool0
1000FUIJEP0015YF00@005YFFUIJEP8001Yoo`03001JEP000080009oo`D000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP@0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`04001JEUYF0003FUH200000eYF0000000LOol01000FUH005YF0P001Woo2@0015YF00<005YF
00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP04001JEP000002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000UYF00@005YF000001ioo`06001J
EUYFFUH005YF0`0000=oo`0000000eYF00D005YFFUH005YF01`000=JEP06001JEUYFFUH005YF0P00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF001JEP00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool01000FUH005YF0`0087oo0P000UYF00<005YF
FUH00UYF1P0000IJEP00000005YF0005FUH50006FUH01000FUIJEUYF1@001EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`03001JEP000080029oo`80009JEP03
001JEUYF00=JEP04001JEUYFFUH90003FUH500000eYF000000070003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUH005YF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool01000FUH005YF0`0087oo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF20002Goo200015YF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool3000015YF001JEUYF0P007Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH00eYF2@005Woo1P0015YF00<005YFFUH0
0P00;Goo000]Ool20002FUH00`00FUIJEP02FUH5000HOol30002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP0200000eYF001JEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF6@000eYF0`0000=JEP00
FUH00UYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP07FUHI00001EYF001JEUYF00001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJ
EP00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00P000eYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP0D
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00Oomoo`0[
Ool002eoo`80009JEP03001JEUYF01AJEP03001JEUYF00IJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000UYF2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF0000
05YF00@002eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH015YF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YF1000
1Woo2@0015YF00<005YFFUH00`000eYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEP00
02eoo`00;Goo0P000UYF00<005YFFUH055YF00<005YFFUH01UYF00<005YFFUH01EYF100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0035YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00X005YFFUIJEP00FUH005YF001JEP<0009o
o`03001JEUYF0080009JEP800003Ool0000001/00003FUH005YF00=JEP03001JEP0002eoo`00;Woo
00@005YFFUH001IJEP<000IJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH00UYF0`0000EJEP00001JEP00
009JEP03001oogoo00Eoo`D000]oo`<000EJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@0
05YFFUH001EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUH0000300000eYF000000020006Ool5
0007Ool400000eYF001JEP05FUH00`00FUIJEP02FUH00`00FUH0000]Ool002ioo`04001JEUYF000E
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00Oomoo`0@0005FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH00eYF5`001EYF00<005YFFUH015YF00D005YFFUIooeYF0080
02ioo`00;goo00<005YF00005EYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001Goo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUIo
o`02000^Ool0031oo`03001JEP0000AJEP03001JEUYF00iJEP<000IJEP03001JEUYF00IJEP03001J
EUYF008000Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000;goo000aOol20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30009Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUHF
0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D0
05YFFUIJEP0002moo`00<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P002goo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH01P00
2UYF00<005YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF000`Ool003=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF009JEP8000eoo`03001JEP0000IJEP03001JEUYF00IJEP@000=JEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF00=JEP@000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
035oo`00=Goo0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
3goo00<005YF00001UYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000cOol003Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP@0019oo`03001JEP0000IJEP@00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00003000eOol003aoo`T000AJEP03001JEUYF00@001Ioo`03001JEP00
00AJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP@000EJEP06001JEUYFFUH005YF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0`00>Goo0015Ool7000JOol00`00FUH00002FUH20007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01@00
FUIJEUYF000015YF00D005YFFUIJEP0000=JEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@003aoo`00IWoo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF
00D005YFFUIJEP0000MJEQX0041oo`00IWoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YF00000eYF00<005YFFUH015YF00<007ooOol0F7oo0018Ool3000KOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP02FUH2001KOol004Moo`D001Yoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYF001MOol004Moo`D001Yo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP<005ioo`00Agoo1@006Woo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000eYF0P00H7oo0018Ool3000KOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF00000000HWoo000fOolI000HOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001UOol0031oo`H0009JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP0011oo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001oogoo06Eoo`00;Goo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]oo`80009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP8006Moo`00:goo0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002Goo0`001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Uoo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000006]oo`00:goo00<0
05YF00000eYF00@005YFFUIJEQT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00Uoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP@006eoo`00:goo00<005YF00000UYF1@006Goo200015YF00<005YFFUH00eYF00@0
05YFFUIJEP8000Yoo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00H0071oo`00:goo00<005YF00000P0000AJEP000000029oo`L000=JEP04001J
EUYFFUH2000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50002Ool5
001_Ool002]oo`80009JEP03001JEUYF009JEPD002Aoo`@000=JEP8001Aoo``000IJEP03001JEUYF
00YJEP03001JEUYF00H000Moo`D006moo`00:goo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT0
01Uoo`P00003FUH00000021ooaH000eoo`D006moo`00;7oo00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF009JEQT000=JEP03001JEUYF009JEP<0035ooaT006eoo`00;Goo0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00:goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000IGoo
000_Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000XOol30002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00Ggoo000bOol70004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000XOol2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002001LOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH6000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001IOol0049ooaT0035oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP00008005Ioo`00S7oo00<005YF000015YF00@005YFFUIJEQl0
00IJEP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP00009JEPH001moo`@0009J
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol008aoo`03001JEP0000<0009JEPL001moo`D000=J
EP03001JEUYF008005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPT001Uoo`H0009J
EP8005Ioo`00S7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@000eYF
00<005YFFUH01000EWoo002=Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002?Ool4
0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0005Ioo`00Tgoo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8005Moo`00UWoo1@000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000005Uo
o`00Vgoo4@0015YF00<005YFFUH00UYF3@00Fgoo002/Ool9001XOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59737 .79074 m .5964 .75442 L .56748 .75296 L p .707 .577 .707 r
F P
0 g
s
.56748 .75296 m .56523 .75285 L p .56984 .75828 L .707 .577 .707 r
F P
0 g
s
.59737 .79074 m .56748 .75296 L .56984 .75828 L .707 .577 .707 r
F
.5662 .78916 m .56523 .75285 L .53964 .74845 L p F P
0 g
s
.53964 .74845 m .53777 .74813 L p .54127 .75317 L .707 .577 .707 r
F P
0 g
s
.5662 .78916 m .53964 .74845 L .54127 .75317 L .707 .577 .707 r
F
.53777 .74813 m .53874 .78445 L .5662 .78916 L p F P
0 g
s
.53874 .78445 m .53777 .74813 L .51802 .7412 L p .707 .577 .707 r
F P
0 g
s
.51802 .7412 m .5167 .74073 L p .51882 .74494 L .707 .577 .707 r
F P
0 g
s
.53874 .78445 m .51802 .7412 L .51882 .74494 L .707 .577 .707 r
F
.5167 .74073 m .51767 .77705 L .53874 .78445 L p F P
0 g
s
.51767 .77705 m .5167 .74073 L .5047 .73184 L p .707 .577 .707 r
F P
0 g
s
.5047 .73184 m .50409 .73138 L p .50494 .73425 L .707 .577 .707 r
F P
0 g
s
.51767 .77705 m .5047 .73184 L .50494 .73425 L .707 .577 .707 r
F
.50409 .73138 m .50506 .7677 L .51767 .77705 L p F P
0 g
s
.50506 .7677 m .50409 .73138 L .50123 .72121 L p .707 .577 .707 r
F P
0 g
s
.50123 .72121 m .50117 .72099 L p .50126 .72204 L .707 .577 .707 r
F P
0 g
s
.50506 .7677 m .50123 .72121 L .50126 .72204 L .707 .577 .707 r
F
.50618 .75189 m .50388 .72354 L p .49888 .68643 L F P
0 g
s
.50388 .72354 m .50199 .7002 L .50123 .69684 L p .707 .577 .707 r
F P
0 g
s
.50123 .69684 m .49888 .68643 L p .50388 .72354 L .707 .577 .707 r
F P
0 g
s
.51894 .76393 m .51653 .73427 L p .50199 .7002 L .707 .577 .707 r
F P
0 g
s
.51104 .70874 m .50199 .7002 L p .51653 .73427 L .707 .577 .707 r
F P
0 g
s
.50199 .7002 m .50618 .75189 L .51894 .76393 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50618 .75189 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.49888 .68643 m .50091 .71142 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50091 .71142 m .50308 .73812 L p .49925 .68974 L .707 .577 .707 r
F P
0 g
s
.50117 .72099 m .50214 .75731 L .50506 .7677 L p .707 .577 .707 r
F P
0 g
s
.50214 .75731 m .50117 .72099 L .5016 .72036 L p .707 .577 .707 r
F P
0 g
s
.50308 .73812 m .50091 .71142 L p .50574 .67226 L .707 .577 .707 r
F P
0 g
s
.50574 .67226 m .50792 .69908 L p .50308 .73812 L .707 .577 .707 r
F P
0 g
s
.51653 .73427 m .51474 .71224 L .51104 .70874 L p .707 .577 .707 r
F P
0 g
s
.5401 .77305 m .53762 .74255 L p .51474 .71224 L .707 .577 .707 r
F P
0 g
s
.52938 .71855 m .51474 .71224 L p .53762 .74255 L .707 .577 .707 r
F P
0 g
s
.51474 .71224 m .51894 .76393 L .5401 .77305 L p .707 .577 .707 r
F P
0 g
s
.50863 .71035 m .52457 .70116 L p .51067 .7425 L .707 .577 .707 r
F P
0 g
s
.50792 .69908 m .50994 .72395 L .50955 .72476 L p .707 .577 .707 r
F P
0 g
s
.50955 .72476 m .50308 .73812 L p .50792 .69908 L .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50822 .71058 L .50863 .71035 L p .707 .577 .707 r
F P
0 g
s
.5092 .7469 m .50863 .71035 L .51067 .7425 L .707 .577 .707 r
F
.5016 .72036 m .50822 .71058 L p .50358 .74626 L F P
0 g
s
.50214 .75731 m .5016 .72036 L .50358 .74626 L .707 .577 .707 r
F
.50091 .71142 m .49888 .68643 L .50003 .68406 L p F P
0 g
s
.50003 .68406 m .50574 .67226 L p .50091 .71142 L .707 .577 .707 r
F P
0 g
s
.53762 .74255 m .5359 .72136 L .52938 .71855 L p .707 .577 .707 r
F P
0 g
s
.56523 .75285 m .5662 .78916 L .59737 .79074 L p .707 .577 .707 r
F P
0 g
s
.56759 .77836 m .56509 .74758 L p .5359 .72136 L .707 .577 .707 r
F P
0 g
s
.56509 .74758 m .56339 .72667 L .55511 .72507 L p .707 .577 .707 r
F P
0 g
s
.55511 .72507 m .5359 .72136 L p .56509 .74758 L .707 .577 .707 r
F P
0 g
s
.5964 .75442 m .59737 .79074 L .61576 .78975 L p .707 .577 .707 r
F P
0 g
s
.61576 .78975 m .62919 .78902 L p .60145 .75975 L .707 .577 .707 r
F P
0 g
s
.60145 .75975 m .5964 .75442 L .61576 .78975 L .707 .577 .707 r
F
.62919 .78902 m .62822 .7527 L .5964 .75442 L p F P
0 g
s
.59873 .77935 m .59625 .74885 L p .56339 .72667 L .707 .577 .707 r
F P
0 g
s
.59625 .74885 m .59453 .72765 L .58601 .72738 L p .707 .577 .707 r
F P
0 g
s
.58601 .72738 m .56339 .72667 L p .59625 .74885 L .707 .577 .707 r
F P
0 g
s
.62822 .7527 m .62919 .78902 L .6449 .78643 L p .707 .577 .707 r
F P
0 g
s
.6449 .78643 m .65856 .78418 L p .63271 .75736 L .707 .577 .707 r
F P
0 g
s
.63271 .75736 m .62822 .7527 L .6449 .78643 L .707 .577 .707 r
F
.65856 .78418 m .65759 .74786 L .62822 .7527 L p F P
0 g
s
.63046 .7759 m .62805 .74624 L p .59453 .72765 L .707 .577 .707 r
F P
0 g
s
.62805 .74624 m .62626 .72421 L .61914 .72498 L p .707 .577 .707 r
F P
0 g
s
.61914 .72498 m .59453 .72765 L p .62805 .74624 L .707 .577 .707 r
F P
0 g
s
.59453 .72765 m .59873 .77935 L .63046 .7759 L p .707 .577 .707 r
F P
0 g
s
.65759 .74786 m .65856 .78418 L .66908 .78089 L p .707 .577 .707 r
F P
0 g
s
.66908 .78089 m .68258 .77668 L p .66063 .75136 L .707 .577 .707 r
F P
0 g
s
.66063 .75136 m .65759 .74786 L .66908 .78089 L .707 .577 .707 r
F
.68258 .77668 m .68161 .74036 L .65759 .74786 L p F P
0 g
s
.65968 .76837 m .65738 .74002 L p .62626 .72421 L .707 .577 .707 r
F P
0 g
s
.65738 .74002 m .65548 .71668 L .65102 .71783 L p .707 .577 .707 r
F P
0 g
s
.65102 .71783 m .62626 .72421 L p .65738 .74002 L .707 .577 .707 r
F P
0 g
s
.62626 .72421 m .63046 .7759 L .65968 .76837 L p .707 .577 .707 r
F P
0 g
s
.56339 .72667 m .56759 .77836 L .59873 .77935 L p .707 .577 .707 r
F P
0 g
s
.68161 .74036 m .68258 .77668 L .68734 .77394 L p .707 .577 .707 r
F P
0 g
s
.68734 .77394 m .69893 .76726 L p .68298 .74248 L .707 .577 .707 r
F P
0 g
s
.68298 .74248 m .68161 .74036 L .68734 .77394 L .707 .577 .707 r
F
.69893 .76726 m .69796 .73094 L .68161 .74036 L p F P
0 g
s
.68352 .75749 m .68136 .73078 L p .65548 .71668 L .707 .577 .707 r
F P
0 g
s
.68136 .73078 m .67933 .70579 L .67798 .70641 L p .707 .577 .707 r
F P
0 g
s
.67798 .70641 m .65548 .71668 L p .68136 .73078 L .707 .577 .707 r
F P
0 g
s
.65548 .71668 m .65968 .76837 L .68352 .75749 L p .707 .577 .707 r
F P
0 g
s
.5359 .72136 m .5401 .77305 L .56759 .77836 L p .707 .577 .707 r
F P
0 g
s
.59261 .86861 m .59309 .8498 L .56192 .84758 L p .707 .577 .707 r
F P
0 g
s
.59309 .8498 m .59261 .86861 L .62443 .86879 L p .707 .577 .707 r
F P
0 g
s
.62443 .86879 m .62491 .84998 L .59309 .8498 L p .707 .577 .707 r
F P
0 g
s
.69796 .73094 m .69893 .76726 L .69966 .76618 L p .707 .577 .707 r
F P
0 g
s
.69875 .74506 m .69967 .74432 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69817 .73164 m .69796 .73094 L .69966 .76618 L .707 .577 .707 r
F
.69547 .69262 m .67933 .70579 L p .69863 .74236 L F P
0 g
s
.69967 .74432 m .69765 .71944 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69813 .73068 m .69796 .73094 L p .69817 .73164 L .707 .577 .707 r
F P
0 g
s
.69765 .71944 m .69547 .69262 L p .69863 .74236 L .707 .577 .707 r
F P
0 g
s
.69547 .69262 m .69967 .74432 L .70652 .73015 L p .707 .577 .707 r
F P
0 g
s
.70652 .73015 m .70233 .67846 L .69547 .69262 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .70501 .72053 L .69813 .73068 L p .707 .577 .707 r
F P
0 g
s
.70598 .75685 m .69813 .73068 L .69817 .73164 L .707 .577 .707 r
F
.69966 .76618 m .70598 .75685 L p .69817 .73164 L F P
0 g
s
.67933 .70579 m .68352 .75749 L .69875 .74506 L p .707 .577 .707 r
F P
0 g
s
.69863 .74236 m .67933 .70579 L .69875 .74506 L .707 .577 .707 r
F
.62491 .84998 m .62443 .86879 L .65379 .86689 L p F P
0 g
s
.65379 .86689 m .65428 .84808 L .62491 .84998 L p .707 .577 .707 r
F P
0 g
s
.56192 .84758 m .56144 .86638 L .59261 .86861 L p .707 .577 .707 r
F P
0 g
s
.56144 .86638 m .56192 .84758 L .53446 .84351 L p .707 .577 .707 r
F P
0 g
s
.53446 .84351 m .53398 .86232 L .56144 .86638 L p .707 .577 .707 r
F P
0 g
s
.65428 .84808 m .65379 .86689 L .67782 .86311 L p .707 .577 .707 r
F P
0 g
s
.67782 .86311 m .67831 .8443 L .65428 .84808 L p .707 .577 .707 r
F P
0 g
s
.53398 .86232 m .53446 .84351 L .51339 .83801 L p .707 .577 .707 r
F P
0 g
s
.51339 .83801 m .51291 .85682 L .53398 .86232 L p .707 .577 .707 r
F P
0 g
s
.67831 .8443 m .67782 .86311 L .69417 .85782 L p .707 .577 .707 r
F P
0 g
s
.69417 .85782 m .69465 .83901 L .67831 .8443 L p .707 .577 .707 r
F P
0 g
s
.51291 .85682 m .51339 .83801 L .50078 .83161 L p .707 .577 .707 r
F P
0 g
s
.50078 .83161 m .5003 .85042 L .51291 .85682 L p .707 .577 .707 r
F P
0 g
s
.70501 .72053 m .70598 .75685 L .70306 .74646 L p .707 .577 .707 r
F P
0 g
s
.70306 .74646 m .70209 .71014 L .70501 .72053 L p .707 .577 .707 r
F P
0 g
s
.70233 .67846 m .70652 .73015 L .70342 .71637 L p .707 .577 .707 r
F P
0 g
s
.70342 .71637 m .69923 .66468 L .70233 .67846 L p .707 .577 .707 r
F P
0 g
s
.69465 .83901 m .69417 .85782 L .70122 .85153 L p .707 .577 .707 r
F P
0 g
s
.70122 .85153 m .7017 .83272 L .69465 .83901 L p .707 .577 .707 r
F P
0 g
s
.4924 .82174 m .4906 .32109 L .44659 .31847 L p .707 .577 .707 r
F P
0 g
s
.50994 .72395 m .50574 .67226 L .52188 .65909 L p .707 .577 .707 r
F P
0 g
s
.50822 .71058 m .5092 .7469 L .50214 .75731 L p .707 .577 .707 r
F P
0 g
s
.5003 .85042 m .50078 .83161 L .49786 .82494 L p .707 .577 .707 r
F P
0 g
s
.49786 .82494 m .49738 .84375 L .5003 .85042 L p .707 .577 .707 r
F P
0 g
s
.49738 .84375 m .49786 .82494 L .50492 .81865 L p .707 .577 .707 r
F P
0 g
s
.50492 .81865 m .50443 .83745 L .49738 .84375 L p .707 .577 .707 r
F P
0 g
s
.52457 .70116 m .52554 .73748 L .5092 .7469 L p .707 .577 .707 r
F P
0 g
s
.52554 .73748 m .52457 .70116 L .54859 .69367 L p .707 .577 .707 r
F P
0 g
s
.52188 .65909 m .52608 .71078 L .50994 .72395 L p .707 .577 .707 r
F P
0 g
s
.52608 .71078 m .52188 .65909 L .54573 .64821 L p .707 .577 .707 r
F P
0 g
s
.50443 .83745 m .50492 .81865 L .52126 .81335 L p .707 .577 .707 r
F P
0 g
s
.54859 .69367 m .54957 .72998 L .52554 .73748 L p .707 .577 .707 r
F P
0 g
s
.54957 .72998 m .54859 .69367 L .57796 .68882 L p .707 .577 .707 r
F P
0 g
s
.54573 .64821 m .54993 .6999 L .52608 .71078 L p .707 .577 .707 r
F P
0 g
s
.52126 .81335 m .52078 .83216 L .50443 .83745 L p .707 .577 .707 r
F P
0 g
s
.52078 .83216 m .52126 .81335 L .54529 .80957 L p .707 .577 .707 r
F P
0 g
s
.54529 .80957 m .5448 .82838 L .52078 .83216 L p .707 .577 .707 r
F P
0 g
s
.4906 .32109 m .4924 .82174 L .53735 .82046 L p .707 .577 .707 r
F P
0 g
s
.53735 .82046 m .53554 .3198 L .4906 .32109 L p .707 .577 .707 r
F P
0 g
s
.54993 .6999 m .54573 .64821 L .57495 .64067 L p .707 .577 .707 r
F P
0 g
s
.57893 .72514 m .57796 .68882 L .60978 .6871 L p .707 .577 .707 r
F P
0 g
s
.57796 .68882 m .57893 .72514 L .54957 .72998 L p .707 .577 .707 r
F P
0 g
s
.57495 .64067 m .57915 .69237 L .54993 .6999 L p .707 .577 .707 r
F P
0 g
s
.5448 .82838 m .54529 .80957 L .57465 .80768 L p .707 .577 .707 r
F P
0 g
s
.57465 .80768 m .57417 .82648 L .5448 .82838 L p .707 .577 .707 r
F P
0 g
s
.57417 .82648 m .57465 .80768 L .60647 .80785 L p .707 .577 .707 r
F P
0 g
s
.53554 .3198 m .53735 .82046 L .57883 .8154 L p .707 .577 .707 r
F P
0 g
s
.57915 .69237 m .57495 .64067 L .60668 .63723 L p .707 .577 .707 r
F P
0 g
s
.57883 .8154 m .57702 .31475 L .53554 .3198 L p .707 .577 .707 r
F P
0 g
s
.44839 .81912 m .44659 .31847 L .40782 .3122 L p .707 .577 .707 r
F P
0 g
s
.44659 .31847 m .44839 .81912 L .4924 .82174 L p .707 .577 .707 r
F P
0 g
s
.70209 .71014 m .70306 .74646 L .69045 .73711 L p .707 .577 .707 r
F P
0 g
s
.69045 .73711 m .68948 .70079 L .70209 .71014 L p .707 .577 .707 r
F P
0 g
s
.69923 .66468 m .70342 .71637 L .69067 .70434 L p .707 .577 .707 r
F P
0 g
s
.69067 .70434 m .68647 .65264 L .69923 .66468 L p .707 .577 .707 r
F P
0 g
s
.61075 .72342 m .60978 .6871 L .64095 .68868 L p .707 .577 .707 r
F P
0 g
s
.60978 .6871 m .61075 .72342 L .57893 .72514 L p .707 .577 .707 r
F P
0 g
s
.60668 .63723 m .61088 .68892 L .57915 .69237 L p .707 .577 .707 r
F P
0 g
s
.60599 .82666 m .60647 .80785 L .63764 .81008 L p .707 .577 .707 r
F P
0 g
s
.60647 .80785 m .60599 .82666 L .57417 .82648 L p .707 .577 .707 r
F P
0 g
s
.57702 .31475 m .57883 .8154 L .61278 .80707 L p .707 .577 .707 r
F P
0 g
s
.64192 .725 m .64095 .68868 L .66841 .69339 L p .707 .577 .707 r
F P
0 g
s
.64095 .68868 m .64192 .725 L .61075 .72342 L p .707 .577 .707 r
F P
0 g
s
.63782 .63821 m .64201 .6899 L .61088 .68892 L p .707 .577 .707 r
F P
0 g
s
.61088 .68892 m .60668 .63723 L .63782 .63821 L p .707 .577 .707 r
F P
0 g
s
.61278 .80707 m .61098 .30641 L .57702 .31475 L p .707 .577 .707 r
F P
0 g
s
.7017 .83272 m .70122 .85153 L .6983 .84485 L p .707 .577 .707 r
F P
0 g
s
.6983 .84485 m .69878 .82605 L .7017 .83272 L p .707 .577 .707 r
F P
0 g
s
.40963 .81286 m .40782 .3122 L .3781 .30291 L p .707 .577 .707 r
F P
0 g
s
.40782 .3122 m .40963 .81286 L .44839 .81912 L p .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .25339 .71761 L .22447 .71614 L p .707 .577 .707 r
F P
0 g
s
.22447 .71614 m .22222 .71603 L p .22683 .72146 L .707 .577 .707 r
F P
0 g
s
.25436 .75393 m .22447 .71614 L .22683 .72146 L .707 .577 .707 r
F
.22319 .75235 m .22222 .71603 L .19664 .71164 L p F P
0 g
s
.19664 .71164 m .19476 .71131 L p .19826 .71636 L .707 .577 .707 r
F P
0 g
s
.22319 .75235 m .19664 .71164 L .19826 .71636 L .707 .577 .707 r
F
.19476 .71131 m .19573 .74763 L .22319 .75235 L p F P
0 g
s
.19573 .74763 m .19476 .71131 L .17501 .70438 L p .707 .577 .707 r
F P
0 g
s
.17501 .70438 m .17369 .70392 L p .17581 .70813 L .707 .577 .707 r
F P
0 g
s
.19573 .74763 m .17501 .70438 L .17581 .70813 L .707 .577 .707 r
F
.17369 .70392 m .17466 .74024 L .19573 .74763 L p F P
0 g
s
.17466 .74024 m .17369 .70392 L .16169 .69502 L p .707 .577 .707 r
F P
0 g
s
.16169 .69502 m .16108 .69457 L p .16193 .69744 L .707 .577 .707 r
F P
0 g
s
.17466 .74024 m .16169 .69502 L .16193 .69744 L .707 .577 .707 r
F
.16108 .69457 m .16205 .73089 L .17466 .74024 L p F P
0 g
s
.16205 .73089 m .16108 .69457 L .15822 .68439 L p .707 .577 .707 r
F P
0 g
s
.15822 .68439 m .15816 .68418 L p .15825 .68522 L .707 .577 .707 r
F P
0 g
s
.16205 .73089 m .15822 .68439 L .15825 .68522 L .707 .577 .707 r
F
.16317 .71508 m .16087 .68673 L p .15588 .64961 L F P
0 g
s
.16087 .68673 m .15898 .66339 L .15822 .66002 L p .707 .577 .707 r
F P
0 g
s
.15822 .66002 m .15588 .64961 L p .16087 .68673 L .707 .577 .707 r
F P
0 g
s
.17593 .72712 m .17352 .69746 L p .15898 .66339 L .707 .577 .707 r
F P
0 g
s
.16803 .67193 m .15898 .66339 L p .17352 .69746 L .707 .577 .707 r
F P
0 g
s
.15898 .66339 m .16317 .71508 L .17593 .72712 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .16317 .71508 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15588 .64961 m .1579 .6746 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.1579 .6746 m .16007 .7013 L p .15625 .65293 L .707 .577 .707 r
F P
0 g
s
.15816 .68418 m .15913 .7205 L .16205 .73089 L p .707 .577 .707 r
F P
0 g
s
.15913 .7205 m .15816 .68418 L .15859 .68355 L p .707 .577 .707 r
F P
0 g
s
.16007 .7013 m .1579 .6746 L p .16273 .63544 L .707 .577 .707 r
F P
0 g
s
.16273 .63544 m .16491 .66226 L p .16007 .7013 L .707 .577 .707 r
F P
0 g
s
.17352 .69746 m .17173 .67542 L .16803 .67193 L p .707 .577 .707 r
F P
0 g
s
.19709 .73624 m .19461 .70574 L p .17173 .67542 L .707 .577 .707 r
F P
0 g
s
.18637 .68174 m .17173 .67542 L p .19461 .70574 L .707 .577 .707 r
F P
0 g
s
.17173 .67542 m .17593 .72712 L .19709 .73624 L p .707 .577 .707 r
F P
0 g
s
.16562 .67353 m .18156 .66435 L p .16766 .70569 L .707 .577 .707 r
F P
0 g
s
.16491 .66226 m .16693 .68714 L .16654 .68794 L p .707 .577 .707 r
F P
0 g
s
.16654 .68794 m .16007 .7013 L p .16491 .66226 L .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16522 .67376 L .16562 .67353 L p .707 .577 .707 r
F P
0 g
s
.16619 .71008 m .16562 .67353 L .16766 .70569 L .707 .577 .707 r
F
.15859 .68355 m .16522 .67376 L p .16057 .70944 L F P
0 g
s
.15913 .7205 m .15859 .68355 L .16057 .70944 L .707 .577 .707 r
F
.1579 .6746 m .15588 .64961 L .15702 .64725 L p F P
0 g
s
.15702 .64725 m .16273 .63544 L p .1579 .6746 L .707 .577 .707 r
F P
0 g
s
.19461 .70574 m .19289 .68454 L .18637 .68174 L p .707 .577 .707 r
F P
0 g
s
.22222 .71603 m .22319 .75235 L .25436 .75393 L p .707 .577 .707 r
F P
0 g
s
.22458 .74155 m .22208 .71076 L p .19289 .68454 L .707 .577 .707 r
F P
0 g
s
.22208 .71076 m .22039 .68986 L .2121 .68826 L p .707 .577 .707 r
F P
0 g
s
.2121 .68826 m .19289 .68454 L p .22208 .71076 L .707 .577 .707 r
F P
0 g
s
.25339 .71761 m .25436 .75393 L .27275 .75293 L p .707 .577 .707 r
F P
0 g
s
.27275 .75293 m .28618 .75221 L p .25844 .72294 L .707 .577 .707 r
F P
0 g
s
.25844 .72294 m .25339 .71761 L .27275 .75293 L .707 .577 .707 r
F
.28618 .75221 m .28521 .71589 L .25339 .71761 L p F P
0 g
s
.25572 .74253 m .25324 .71203 L p .22039 .68986 L .707 .577 .707 r
F P
0 g
s
.25324 .71203 m .25152 .69084 L .24301 .69057 L p .707 .577 .707 r
F P
0 g
s
.24301 .69057 m .22039 .68986 L p .25324 .71203 L .707 .577 .707 r
F P
0 g
s
.28521 .71589 m .28618 .75221 L .30189 .74961 L p .707 .577 .707 r
F P
0 g
s
.30189 .74961 m .31555 .74736 L p .2897 .72055 L .707 .577 .707 r
F P
0 g
s
.2897 .72055 m .28521 .71589 L .30189 .74961 L .707 .577 .707 r
F
.31555 .74736 m .31458 .71104 L .28521 .71589 L p F P
0 g
s
.28745 .73909 m .28504 .70943 L p .25152 .69084 L .707 .577 .707 r
F P
0 g
s
.28504 .70943 m .28325 .68739 L .27613 .68817 L p .707 .577 .707 r
F P
0 g
s
.27613 .68817 m .25152 .69084 L p .28504 .70943 L .707 .577 .707 r
F P
0 g
s
.25152 .69084 m .25572 .74253 L .28745 .73909 L p .707 .577 .707 r
F P
0 g
s
.31458 .71104 m .31555 .74736 L .32608 .74408 L p .707 .577 .707 r
F P
0 g
s
.32608 .74408 m .33958 .73986 L p .31762 .71455 L .707 .577 .707 r
F P
0 g
s
.31762 .71455 m .31458 .71104 L .32608 .74408 L .707 .577 .707 r
F
.33958 .73986 m .33861 .70355 L .31458 .71104 L p F P
0 g
s
.31667 .73155 m .31437 .7032 L p .28325 .68739 L .707 .577 .707 r
F P
0 g
s
.31437 .7032 m .31247 .67986 L .30801 .68101 L p .707 .577 .707 r
F P
0 g
s
.30801 .68101 m .28325 .68739 L p .31437 .7032 L .707 .577 .707 r
F P
0 g
s
.28325 .68739 m .28745 .73909 L .31667 .73155 L p .707 .577 .707 r
F P
0 g
s
.68948 .70079 m .69045 .73711 L .66938 .72971 L p .707 .577 .707 r
F P
0 g
s
.66938 .72971 m .66841 .69339 L .68948 .70079 L p .707 .577 .707 r
F P
0 g
s
.68647 .65264 m .69067 .70434 L .66951 .69522 L p .707 .577 .707 r
F P
0 g
s
.66951 .69522 m .66531 .64352 L .68647 .65264 L p .707 .577 .707 r
F P
0 g
s
.22039 .68986 m .22458 .74155 L .25572 .74253 L p .707 .577 .707 r
F P
0 g
s
.33861 .70355 m .33958 .73986 L .34433 .73712 L p .707 .577 .707 r
F P
0 g
s
.34433 .73712 m .35592 .73045 L p .33997 .70567 L .707 .577 .707 r
F P
0 g
s
.33997 .70567 m .33861 .70355 L .34433 .73712 L .707 .577 .707 r
F
.35592 .73045 m .35495 .69413 L .33861 .70355 L p F P
0 g
s
.34052 .72067 m .33835 .69397 L p .31247 .67986 L .707 .577 .707 r
F P
0 g
s
.33835 .69397 m .33632 .66898 L .33497 .66959 L p .707 .577 .707 r
F P
0 g
s
.33497 .66959 m .31247 .67986 L p .33835 .69397 L .707 .577 .707 r
F P
0 g
s
.31247 .67986 m .31667 .73155 L .34052 .72067 L p .707 .577 .707 r
F P
0 g
s
.61098 .30641 m .61278 .80707 L .63589 .79626 L p .707 .577 .707 r
F P
0 g
s
.63589 .79626 m .63409 .29561 L .61098 .30641 L p .707 .577 .707 r
F P
0 g
s
.19289 .68454 m .19709 .73624 L .22458 .74155 L p .707 .577 .707 r
F P
0 g
s
.69878 .82605 m .6983 .84485 L .68569 .83845 L p .707 .577 .707 r
F P
0 g
s
.68569 .83845 m .68617 .81964 L .69878 .82605 L p .707 .577 .707 r
F P
0 g
s
.66841 .69339 m .66938 .72971 L .64192 .725 L p .707 .577 .707 r
F P
0 g
s
.66531 .64352 m .66951 .69522 L .64201 .6899 L p .707 .577 .707 r
F P
0 g
s
.64201 .6899 m .63782 .63821 L .66531 .64352 L p .707 .577 .707 r
F P
0 g
s
.3799 .80356 m .3781 .30291 L .36032 .29149 L p .707 .577 .707 r
F P
0 g
s
.3781 .30291 m .3799 .80356 L .40963 .81286 L p .707 .577 .707 r
F P
0 g
s
.2496 .8318 m .25008 .81299 L .21891 .81076 L p .707 .577 .707 r
F P
0 g
s
.25008 .81299 m .2496 .8318 L .28142 .83197 L p .707 .577 .707 r
F P
0 g
s
.28142 .83197 m .2819 .81317 L .25008 .81299 L p .707 .577 .707 r
F P
0 g
s
.35495 .69413 m .35592 .73045 L .35665 .72937 L p .707 .577 .707 r
F P
0 g
s
.35574 .70825 m .35666 .7075 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35516 .69483 m .35495 .69413 L .35665 .72937 L .707 .577 .707 r
F
.35246 .65581 m .33632 .66898 L p .35562 .70554 L F P
0 g
s
.35666 .7075 m .35464 .68263 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35512 .69387 m .35495 .69413 L p .35516 .69483 L .707 .577 .707 r
F P
0 g
s
.35464 .68263 m .35246 .65581 L p .35562 .70554 L .707 .577 .707 r
F P
0 g
s
.35246 .65581 m .35666 .7075 L .36351 .69334 L p .707 .577 .707 r
F P
0 g
s
.36351 .69334 m .35932 .64164 L .35246 .65581 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .362 .68372 L .35512 .69387 L p .707 .577 .707 r
F P
0 g
s
.36297 .72003 m .35512 .69387 L .35516 .69483 L .707 .577 .707 r
F
.35665 .72937 m .36297 .72003 L p .35516 .69483 L F P
0 g
s
.33632 .66898 m .34052 .72067 L .35574 .70825 L p .707 .577 .707 r
F P
0 g
s
.35562 .70554 m .33632 .66898 L .35574 .70825 L .707 .577 .707 r
F
.2819 .81317 m .28142 .83197 L .31079 .83008 L p F P
0 g
s
.31079 .83008 m .31127 .81127 L .2819 .81317 L p .707 .577 .707 r
F P
0 g
s
.21891 .81076 m .21843 .82957 L .2496 .8318 L p .707 .577 .707 r
F P
0 g
s
.21843 .82957 m .21891 .81076 L .19145 .8067 L p .707 .577 .707 r
F P
0 g
s
.19145 .8067 m .19097 .82551 L .21843 .82957 L p .707 .577 .707 r
F P
0 g
s
.31127 .81127 m .31079 .83008 L .33481 .8263 L p .707 .577 .707 r
F P
0 g
s
.33481 .8263 m .3353 .80749 L .31127 .81127 L p .707 .577 .707 r
F P
0 g
s
.63409 .29561 m .63589 .79626 L .64589 .78406 L p .707 .577 .707 r
F P
0 g
s
.64589 .78406 m .64408 .2834 L .63409 .29561 L p .707 .577 .707 r
F P
0 g
s
.68617 .81964 m .68569 .83845 L .66462 .83295 L p .707 .577 .707 r
F P
0 g
s
.66462 .83295 m .6651 .81414 L .68617 .81964 L p .707 .577 .707 r
F P
0 g
s
.19097 .82551 m .19145 .8067 L .17038 .8012 L p .707 .577 .707 r
F P
0 g
s
.17038 .8012 m .1699 .82 L .19097 .82551 L p .707 .577 .707 r
F P
0 g
s
.3353 .80749 m .33481 .8263 L .35116 .821 L p .707 .577 .707 r
F P
0 g
s
.35116 .821 m .35164 .80219 L .3353 .80749 L p .707 .577 .707 r
F P
0 g
s
.362 .68372 m .36297 .72003 L .36005 .70964 L p .707 .577 .707 r
F P
0 g
s
.36005 .70964 m .35908 .67333 L .362 .68372 L p .707 .577 .707 r
F P
0 g
s
.35932 .64164 m .36351 .69334 L .36041 .67956 L p .707 .577 .707 r
F P
0 g
s
.36212 .79214 m .36032 .29149 L .35623 .27907 L p .707 .577 .707 r
F P
0 g
s
.36032 .29149 m .36212 .79214 L .3799 .80356 L p .707 .577 .707 r
F P
0 g
s
.6651 .81414 m .66462 .83295 L .63716 .82889 L p .707 .577 .707 r
F P
0 g
s
.63716 .82889 m .63764 .81008 L .6651 .81414 L p .707 .577 .707 r
F P
0 g
s
.1699 .82 m .17038 .8012 L .15777 .7948 L p .707 .577 .707 r
F P
0 g
s
.15777 .7948 m .15729 .8136 L .1699 .82 L p .707 .577 .707 r
F P
0 g
s
.36041 .67956 m .35622 .62787 L .35932 .64164 L p .707 .577 .707 r
F P
0 g
s
.63764 .81008 m .63716 .82889 L .60599 .82666 L p .707 .577 .707 r
F P
0 g
s
.35164 .80219 m .35116 .821 L .35821 .81471 L p .707 .577 .707 r
F P
0 g
s
.35821 .81471 m .35869 .7959 L .35164 .80219 L p .707 .577 .707 r
F P
0 g
s
.64408 .2834 m .64589 .78406 L .6418 .77164 L p .707 .577 .707 r
F P
0 g
s
.6418 .77164 m .63999 .27098 L .64408 .2834 L p .707 .577 .707 r
F P
0 g
s
.15729 .8136 m .15777 .7948 L .15485 .78812 L p .707 .577 .707 r
F P
0 g
s
.15485 .78812 m .15437 .80693 L .15729 .8136 L p .707 .577 .707 r
F P
0 g
s
.35908 .67333 m .36005 .70964 L .34744 .70029 L p .707 .577 .707 r
F P
0 g
s
.34744 .70029 m .34647 .66397 L .35908 .67333 L p .707 .577 .707 r
F P
0 g
s
.35622 .62787 m .36041 .67956 L .34766 .66752 L p .707 .577 .707 r
F P
0 g
s
.34766 .66752 m .34346 .61583 L .35622 .62787 L p .707 .577 .707 r
F P
0 g
s
.35623 .27907 m .35803 .77972 L .36212 .79214 L p .707 .577 .707 r
F P
0 g
s
.35803 .77972 m .35623 .27907 L .36623 .26686 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35869 .7959 m .35821 .81471 L .35529 .80804 L p .707 .577 .707 r
F P
0 g
s
.35529 .80804 m .35577 .78923 L .35869 .7959 L p .707 .577 .707 r
F P
0 g
s
.16693 .68714 m .16273 .63544 L .17887 .62227 L p .707 .577 .707 r
F P
0 g
s
.16522 .67376 m .16619 .71008 L .15913 .7205 L p .707 .577 .707 r
F P
0 g
s
.15437 .80693 m .15485 .78812 L .16191 .78183 L p .707 .577 .707 r
F P
0 g
s
.63999 .27098 m .6418 .77164 L .62402 .76022 L p .707 .577 .707 r
F P
0 g
s
.62402 .76022 m .62222 .25956 L .63999 .27098 L p .707 .577 .707 r
F P
0 g
s
.34647 .66397 m .34744 .70029 L .32637 .6929 L p .707 .577 .707 r
F P
0 g
s
.32637 .6929 m .3254 .65658 L .34647 .66397 L p .707 .577 .707 r
F P
0 g
s
.34346 .61583 m .34766 .66752 L .3265 .6584 L p .707 .577 .707 r
F P
0 g
s
.3265 .6584 m .3223 .60671 L .34346 .61583 L p .707 .577 .707 r
F P
0 g
s
.16191 .78183 m .16142 .80064 L .15437 .80693 L p .707 .577 .707 r
F P
0 g
s
.18156 .66435 m .18253 .70067 L .16619 .71008 L p .707 .577 .707 r
F P
0 g
s
.18253 .70067 m .18156 .66435 L .20559 .65685 L p .707 .577 .707 r
F P
0 g
s
.17887 .62227 m .18307 .67397 L .16693 .68714 L p .707 .577 .707 r
F P
0 g
s
.18307 .67397 m .17887 .62227 L .20272 .61139 L p .707 .577 .707 r
F P
0 g
s
.36803 .76752 m .36623 .26686 L .38934 .25606 L p .707 .577 .707 r
F P
0 g
s
.36623 .26686 m .36803 .76752 L .35803 .77972 L p .707 .577 .707 r
F P
0 g
s
.35577 .78923 m .35529 .80804 L .34268 .80164 L p .707 .577 .707 r
F P
0 g
s
.34268 .80164 m .34316 .78283 L .35577 .78923 L p .707 .577 .707 r
F P
0 g
s
.3254 .65658 m .32637 .6929 L .29891 .68818 L p .707 .577 .707 r
F P
0 g
s
.29891 .68818 m .29794 .65186 L .3254 .65658 L p .707 .577 .707 r
F P
0 g
s
.3223 .60671 m .3265 .6584 L .299 .65309 L p .707 .577 .707 r
F P
0 g
s
.299 .65309 m .29481 .6014 L .3223 .60671 L p .707 .577 .707 r
F P
0 g
s
.16142 .80064 m .16191 .78183 L .17825 .77654 L p .707 .577 .707 r
F P
0 g
s
.20656 .69317 m .20559 .65685 L .23495 .652 L p .707 .577 .707 r
F P
0 g
s
.20692 .66308 m .20272 .61139 L .23194 .60386 L p .707 .577 .707 r
F P
0 g
s
.20559 .65685 m .20656 .69317 L .18253 .70067 L p .707 .577 .707 r
F P
0 g
s
.20272 .61139 m .20692 .66308 L .18307 .67397 L p .707 .577 .707 r
F P
0 g
s
.17825 .77654 m .17777 .79534 L .16142 .80064 L p .707 .577 .707 r
F P
0 g
s
.29794 .65186 m .29891 .68818 L .26774 .6866 L p .707 .577 .707 r
F P
0 g
s
.26774 .6866 m .26677 .65029 L .29794 .65186 L p .707 .577 .707 r
F P
0 g
s
.29481 .6014 m .299 .65309 L .26787 .65211 L p .707 .577 .707 r
F P
0 g
s
.26787 .65211 m .26367 .60041 L .29481 .6014 L p .707 .577 .707 r
F P
0 g
s
.62222 .25956 m .62402 .76022 L .5943 .75092 L p .707 .577 .707 r
F P
0 g
s
.5943 .75092 m .59249 .25027 L .62222 .25956 L p .707 .577 .707 r
F P
0 g
s
.23592 .68832 m .23495 .652 L .26677 .65029 L p .707 .577 .707 r
F P
0 g
s
.23614 .65555 m .23194 .60386 L .26367 .60041 L p .707 .577 .707 r
F P
0 g
s
.23495 .652 m .23592 .68832 L .20656 .69317 L p .707 .577 .707 r
F P
0 g
s
.23194 .60386 m .23614 .65555 L .20692 .66308 L p .707 .577 .707 r
F P
0 g
s
.26677 .65029 m .26774 .6866 L .23592 .68832 L p .707 .577 .707 r
F P
0 g
s
.26367 .60041 m .26787 .65211 L .23614 .65555 L p .707 .577 .707 r
F P
0 g
s
.34316 .78283 m .34268 .80164 L .32161 .79614 L p .707 .577 .707 r
F P
0 g
s
.32161 .79614 m .32209 .77733 L .34316 .78283 L p .707 .577 .707 r
F P
0 g
s
.73593 .65969 m .73173 .608 L .7006 .60702 L p .707 .577 .707 r
F P
0 g
s
.73173 .608 m .73593 .65969 L .76766 .65625 L p .707 .577 .707 r
F P
0 g
s
.76766 .65625 m .76347 .60456 L .73173 .608 L p .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .36803 .76752 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.38972 .36245 m .39114 .75671 L p .38613 .33295 L .707 .577 .707 r
F P
0 g
s
.39114 .75671 m .38934 .25606 L .42329 .24772 L p .707 .577 .707 r
F P
0 g
s
.42329 .24772 m .4251 .74838 L .39114 .75671 L p .707 .577 .707 r
F P
0 g
s
.38873 .57119 m .39292 .62288 L .42101 .61983 L p .707 .577 .707 r
F P
0 g
s
.4251 .74838 m .42329 .24772 L .46477 .24266 L p .707 .577 .707 r
F P
0 g
s
.42101 .61983 m .42465 .61944 L p .42025 .61352 L .707 .577 .707 r
F P
0 g
s
.42025 .61352 m .38873 .57119 L .42101 .61983 L .707 .577 .707 r
F
.38934 .25606 m .38972 .36245 L p .38613 .33295 L F P
0 g
s
.76347 .60456 m .76766 .65625 L .79688 .64872 L p .707 .577 .707 r
F P
0 g
s
.79688 .64872 m .79269 .59703 L .76347 .60456 L p .707 .577 .707 r
F P
0 g
s
.17777 .79534 m .17825 .77654 L .20228 .77276 L p .707 .577 .707 r
F P
0 g
s
.20228 .77276 m .2018 .79156 L .17777 .79534 L p .707 .577 .707 r
F P
0 g
s
.70479 .65871 m .7006 .60702 L .6731 .60171 L p .707 .577 .707 r
F P
0 g
s
.7006 .60702 m .70479 .65871 L .73593 .65969 L p .707 .577 .707 r
F P
0 g
s
.79269 .59703 m .79688 .64872 L .82073 .63783 L p .707 .577 .707 r
F P
0 g
s
.82073 .63783 m .81653 .58614 L .79269 .59703 L p .707 .577 .707 r
F P
0 g
s
.32209 .77733 m .32161 .79614 L .29415 .79207 L p .707 .577 .707 r
F P
0 g
s
.29415 .79207 m .29463 .77326 L .32209 .77733 L p .707 .577 .707 r
F P
0 g
s
.59249 .25027 m .5943 .75092 L .55553 .74466 L p .707 .577 .707 r
F P
0 g
s
.55553 .74466 m .55373 .244 L .59249 .25027 L p .707 .577 .707 r
F P
0 g
s
.6773 .6534 m .6731 .60171 L .65194 .59259 L p .707 .577 .707 r
F P
0 g
s
.6731 .60171 m .6773 .6534 L .70479 .65871 L p .707 .577 .707 r
F P
0 g
s
.2018 .79156 m .20228 .77276 L .23164 .77086 L p .707 .577 .707 r
F P
0 g
s
.72981 .73477 m .73029 .71596 L .69913 .71373 L p .707 .577 .707 r
F P
0 g
s
.73029 .71596 m .72981 .73477 L .76164 .73494 L p .707 .577 .707 r
F P
0 g
s
.76164 .73494 m .76212 .71613 L .73029 .71596 L p .707 .577 .707 r
F P
0 g
s
.23164 .77086 m .23116 .78967 L .2018 .79156 L p .707 .577 .707 r
F P
0 g
s
.76212 .71613 m .76164 .73494 L .791 .73305 L p .707 .577 .707 r
F P
0 g
s
.791 .73305 m .79148 .71424 L .76212 .71613 L p .707 .577 .707 r
F P
0 g
s
.69913 .71373 m .69864 .73254 L .72981 .73477 L p .707 .577 .707 r
F P
0 g
s
.81653 .58614 m .82073 .63783 L .83687 .62467 L p .707 .577 .707 r
F P
0 g
s
.83687 .62467 m .83268 .57297 L .81653 .58614 L p .707 .577 .707 r
F P
0 g
s
.29463 .77326 m .29415 .79207 L .26298 .78984 L p .707 .577 .707 r
F P
0 g
s
.26298 .78984 m .26346 .77104 L .29463 .77326 L p .707 .577 .707 r
F P
0 g
s
.69864 .73254 m .69913 .71373 L .67166 .70967 L p .707 .577 .707 r
F P
0 g
s
.73457 .74791 m .7336 .71159 L .70244 .71001 L p .707 .577 .707 r
F P
0 g
s
.7336 .71159 m .73457 .74791 L .7664 .74619 L p .707 .577 .707 r
F P
0 g
s
.7664 .74619 m .76543 .70987 L .7336 .71159 L p .707 .577 .707 r
F P
0 g
s
.76543 .70987 m .7664 .74619 L .79576 .74134 L p .707 .577 .707 r
F P
0 g
s
.79148 .71424 m .791 .73305 L .81503 .72927 L p .707 .577 .707 r
F P
0 g
s
.81503 .72927 m .81551 .71046 L .79148 .71424 L p .707 .577 .707 r
F P
0 g
s
.79576 .74134 m .79479 .70502 L .76543 .70987 L p .707 .577 .707 r
F P
0 g
s
.23116 .78967 m .23164 .77086 L .26346 .77104 L p .707 .577 .707 r
F P
0 g
s
.67166 .70967 m .67118 .72847 L .69864 .73254 L p .707 .577 .707 r
F P
0 g
s
.26346 .77104 m .26298 .78984 L .23116 .78967 L p .707 .577 .707 r
F P
0 g
s
.70341 .74633 m .70244 .71001 L .67497 .7053 L p .707 .577 .707 r
F P
0 g
s
.70244 .71001 m .70341 .74633 L .73457 .74791 L p .707 .577 .707 r
F P
0 g
s
.55373 .244 m .55553 .74466 L .51152 .74204 L p .707 .577 .707 r
F P
0 g
s
.51152 .74204 m .50972 .24138 L .55373 .244 L p .707 .577 .707 r
F P
0 g
s
.65614 .64428 m .65194 .59259 L .63919 .58055 L p .707 .577 .707 r
F P
0 g
s
.65194 .59259 m .65614 .64428 L .6773 .6534 L p .707 .577 .707 r
F P
0 g
s
.46658 .74332 m .46477 .24266 L .50972 .24138 L p .707 .577 .707 r
F P
0 g
s
.46477 .24266 m .46658 .74332 L .4251 .74838 L p .707 .577 .707 r
F P
0 g
s
.81551 .71046 m .81503 .72927 L .83137 .72397 L p .707 .577 .707 r
F P
0 g
s
.79479 .70502 m .79576 .74134 L .81979 .73384 L p .707 .577 .707 r
F P
0 g
s
.83137 .72397 m .83185 .70516 L .81551 .71046 L p .707 .577 .707 r
F P
0 g
s
.81979 .73384 m .81882 .69753 L .79479 .70502 L p .707 .577 .707 r
F P
0 g
s
.67118 .72847 m .67166 .70967 L .6506 .70416 L p .707 .577 .707 r
F P
0 g
s
.50972 .24138 m .51152 .74204 L .46658 .74332 L p .707 .577 .707 r
F P
0 g
s
.6506 .70416 m .65011 .72297 L .67118 .72847 L p .707 .577 .707 r
F P
0 g
s
.67497 .7053 m .67594 .74161 L .70341 .74633 L p .707 .577 .707 r
F P
0 g
s
.83268 .57297 m .83687 .62467 L .84373 .6105 L p .707 .577 .707 r
F P
0 g
s
.84373 .6105 m .83953 .55881 L .83268 .57297 L p .707 .577 .707 r
F P
0 g
s
.67594 .74161 m .67497 .7053 L .65391 .6979 L p .707 .577 .707 r
F P
0 g
s
.83185 .70516 m .83137 .72397 L .83278 .72272 L p .707 .577 .707 r
F P
0 g
s
.83274 .72638 m .83613 .72443 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83294 .70723 m .83185 .70516 L .83278 .72272 L .707 .577 .707 r
F
.83613 .72443 m .83516 .68811 L .83312 .68929 L p F P
0 g
s
.83297 .70417 m .83185 .70516 L p .83294 .70723 L .707 .577 .707 r
F P
0 g
s
.83312 .68929 m .81882 .69753 L p .83281 .71927 L .707 .577 .707 r
F P
0 g
s
.83613 .72443 m .83312 .68929 L .83281 .71927 L .707 .577 .707 r
F
.83516 .68811 m .83613 .72443 L .84319 .71401 L p F P
0 g
s
.84319 .71401 m .84222 .6777 L .83516 .68811 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83891 .69887 L .83297 .70417 L p .707 .577 .707 r
F P
0 g
s
.83843 .71768 m .83297 .70417 L .83294 .70723 L .707 .577 .707 r
F
.83278 .72272 m .83843 .71768 L p .83294 .70723 L F P
0 g
s
.81882 .69753 m .81979 .73384 L .83274 .72638 L p .707 .577 .707 r
F P
0 g
s
.83281 .71927 m .81882 .69753 L .83274 .72638 L .707 .577 .707 r
F
.65391 .6979 m .65488 .73422 L .67594 .74161 L p F P
0 g
s
.63919 .58055 m .64338 .63224 L .65614 .64428 L p .707 .577 .707 r
F P
0 g
s
.64338 .63224 m .63919 .58055 L .63609 .56677 L p .707 .577 .707 r
F P
0 g
s
.65011 .72297 m .6506 .70416 L .63798 .69776 L p .707 .577 .707 r
F P
0 g
s
.63798 .69776 m .6375 .71657 L .65011 .72297 L p .707 .577 .707 r
F P
0 g
s
.65488 .73422 m .65391 .6979 L .64129 .68855 L p .707 .577 .707 r
F P
0 g
s
.83953 .55881 m .84373 .6105 L .84063 .59672 L p .707 .577 .707 r
F P
0 g
s
.84063 .59672 m .83643 .54503 L .83953 .55881 L p .707 .577 .707 r
F P
0 g
s
.64129 .68855 m .64226 .72487 L .65488 .73422 L p .707 .577 .707 r
F P
0 g
s
.63609 .56677 m .64028 .61847 L .64338 .63224 L p .707 .577 .707 r
F P
0 g
s
.64028 .61847 m .63609 .56677 L .64294 .55261 L p .707 .577 .707 r
F P
0 g
s
.6375 .71657 m .63798 .69776 L .63506 .69109 L p .707 .577 .707 r
F P
0 g
s
.63506 .69109 m .63458 .7099 L .6375 .71657 L p .707 .577 .707 r
F P
0 g
s
.64226 .72487 m .64129 .68855 L .63837 .67816 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83643 .54503 m .84063 .59672 L .82787 .58469 L p .707 .577 .707 r
F P
0 g
s
.82787 .58469 m .82368 .53299 L .83643 .54503 L p .707 .577 .707 r
F P
0 g
s
.63837 .67816 m .63934 .71448 L .64226 .72487 L p .707 .577 .707 r
F P
0 g
s
.83891 .69887 m .83843 .71768 L .83551 .71101 L p .707 .577 .707 r
F P
0 g
s
.83551 .71101 m .83599 .6922 L .83891 .69887 L p .707 .577 .707 r
F P
0 g
s
.84222 .6777 m .84319 .71401 L .84027 .70362 L p .707 .577 .707 r
F P
0 g
s
.84027 .70362 m .8393 .66731 L .84222 .6777 L p .707 .577 .707 r
F P
0 g
s
.64294 .55261 m .64714 .6043 L .64028 .61847 L p .707 .577 .707 r
F P
0 g
s
.64714 .6043 m .64294 .55261 L .65909 .53944 L p .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .63837 .67816 L .64455 .66905 L p .707 .577 .707 r
F P
0 g
s
.64455 .66905 m .64543 .66775 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.63934 .71448 m .64455 .66905 L .6446 .67411 L .707 .577 .707 r
F
.6447 .68396 m .65846 .6795 L p .64486 .69899 L F P
0 g
s
.65846 .6795 m .65798 .69831 L .6449 .70255 L p .707 .577 .707 r
F P
0 g
s
.64486 .69899 m .65846 .6795 L .6449 .70255 L .707 .577 .707 r
F
.64543 .66775 m .6464 .70406 L .64493 .70623 L p F P
0 g
s
.64493 .70623 m .63934 .71448 L p .6446 .67411 L .707 .577 .707 r
F P
0 g
s
.6446 .67411 m .64543 .66775 L .64493 .70623 L .707 .577 .707 r
F
.6449 .70255 m .64164 .70361 L p .64486 .69899 L F P
0 g
s
.64164 .70361 m .64212 .6848 L .6447 .68396 L p .707 .577 .707 r
F P
0 g
s
.64164 .70361 m .6447 .68396 L .64486 .69899 L .707 .577 .707 r
F
.63458 .7099 m .63506 .69109 L .64212 .6848 L p F P
0 g
s
.39292 .62288 m .38873 .57119 L .35759 .5702 L p .707 .577 .707 r
F P
0 g
s
.42465 .61944 m .42046 .56774 L .38873 .57119 L p .707 .577 .707 r
F P
0 g
s
.42046 .56774 m .42465 .61944 L .45387 .6119 L p .707 .577 .707 r
F P
0 g
s
.45387 .6119 m .44968 .56021 L .42046 .56774 L p .707 .577 .707 r
F P
0 g
s
.64212 .6848 m .64164 .70361 L .63458 .7099 L p .707 .577 .707 r
F P
0 g
s
.82368 .53299 m .82787 .58469 L .80671 .57556 L p .707 .577 .707 r
F P
0 g
s
.80671 .57556 m .80252 .52387 L .82368 .53299 L p .707 .577 .707 r
F P
0 g
s
.36178 .6219 m .35759 .5702 L .33009 .56489 L p .707 .577 .707 r
F P
0 g
s
.35759 .5702 m .36178 .6219 L .39292 .62288 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44968 .56021 m .45387 .6119 L .47772 .60102 L p .707 .577 .707 r
F P
0 g
s
.47772 .60102 m .47352 .54933 L .44968 .56021 L p .707 .577 .707 r
F P
0 g
s
.83599 .6922 m .83551 .71101 L .82289 .70461 L p .707 .577 .707 r
F P
0 g
s
.82289 .70461 m .82338 .6858 L .83599 .6922 L p .707 .577 .707 r
F P
0 g
s
.65909 .53944 m .66328 .59113 L .64714 .6043 L p .707 .577 .707 r
F P
0 g
s
.66328 .59113 m .65909 .53944 L .68294 .52856 L p .707 .577 .707 r
F P
0 g
s
.8393 .66731 m .84027 .70362 L .82765 .69427 L p .707 .577 .707 r
F P
0 g
s
.82765 .69427 m .82668 .65796 L .8393 .66731 L p .707 .577 .707 r
F P
0 g
s
.33429 .61659 m .33009 .56489 L .30893 .55577 L p .707 .577 .707 r
F P
0 g
s
.33009 .56489 m .33429 .61659 L .36178 .6219 L p .707 .577 .707 r
F P
0 g
s
.3868 .69795 m .38728 .67914 L .35612 .67691 L p .707 .577 .707 r
F P
0 g
s
.38728 .67914 m .3868 .69795 L .41863 .69813 L p .707 .577 .707 r
F P
0 g
s
.41863 .69813 m .41911 .67932 L .38728 .67914 L p .707 .577 .707 r
F P
0 g
s
.80252 .52387 m .80671 .57556 L .77922 .57025 L p .707 .577 .707 r
F P
0 g
s
.77922 .57025 m .77502 .51856 L .80252 .52387 L p .707 .577 .707 r
F P
0 g
s
.41911 .67932 m .41863 .69813 L .44799 .69623 L p .707 .577 .707 r
F P
0 g
s
.44799 .69623 m .44847 .67742 L .41911 .67932 L p .707 .577 .707 r
F P
0 g
s
.35612 .67691 m .35563 .69572 L .3868 .69795 L p .707 .577 .707 r
F P
0 g
s
.47352 .54933 m .47772 .60102 L .49386 .58785 L p .707 .577 .707 r
F P
0 g
s
.49386 .58785 m .48967 .53616 L .47352 .54933 L p .707 .577 .707 r
F P
0 g
s
.35563 .69572 m .35612 .67691 L .32865 .67285 L p .707 .577 .707 r
F P
0 g
s
.39156 .71109 m .39059 .67477 L .35943 .6732 L p .707 .577 .707 r
F P
0 g
s
.39059 .67477 m .39156 .71109 L .42339 .70937 L p .707 .577 .707 r
F P
0 g
s
.42339 .70937 m .42242 .67305 L .39059 .67477 L p .707 .577 .707 r
F P
0 g
s
.6464 .70406 m .64543 .66775 L .66177 .65833 L p .707 .577 .707 r
F P
0 g
s
.42242 .67305 m .42339 .70937 L .45275 .70453 L p .707 .577 .707 r
F P
0 g
s
.44847 .67742 m .44799 .69623 L .47202 .69245 L p .707 .577 .707 r
F P
0 g
s
.47202 .69245 m .4725 .67364 L .44847 .67742 L p .707 .577 .707 r
F P
0 g
s
.45275 .70453 m .45178 .66821 L .42242 .67305 L p .707 .577 .707 r
F P
0 g
s
.32865 .67285 m .32817 .69166 L .35563 .69572 L p .707 .577 .707 r
F P
0 g
s
.68713 .58025 m .68294 .52856 L .71216 .52102 L p .707 .577 .707 r
F P
0 g
s
.68294 .52856 m .68713 .58025 L .66328 .59113 L p .707 .577 .707 r
F P
0 g
s
.3604 .70951 m .35943 .6732 L .33196 .66848 L p .707 .577 .707 r
F P
0 g
s
.35943 .6732 m .3604 .70951 L .39156 .71109 L p .707 .577 .707 r
F P
0 g
s
.77502 .51856 m .77922 .57025 L .74808 .56927 L p .707 .577 .707 r
F P
0 g
s
.74808 .56927 m .74389 .51758 L .77502 .51856 L p .707 .577 .707 r
F P
0 g
s
.31313 .60747 m .30893 .55577 L .29618 .54373 L p .707 .577 .707 r
F P
0 g
s
.30893 .55577 m .31313 .60747 L .33429 .61659 L p .707 .577 .707 r
F P
0 g
s
.65798 .69831 m .65846 .6795 L .68249 .67572 L p .707 .577 .707 r
F P
0 g
s
.68249 .67572 m .68201 .69453 L .65798 .69831 L p .707 .577 .707 r
F P
0 g
s
.66177 .65833 m .66274 .69465 L .6464 .70406 L p .707 .577 .707 r
F P
0 g
s
.82338 .6858 m .82289 .70461 L .80183 .69911 L p .707 .577 .707 r
F P
0 g
s
.80183 .69911 m .80231 .6803 L .82338 .6858 L p .707 .577 .707 r
F P
0 g
s
.4725 .67364 m .47202 .69245 L .48836 .68716 L p .707 .577 .707 r
F P
0 g
s
.45178 .66821 m .45275 .70453 L .47678 .69703 L p .707 .577 .707 r
F P
0 g
s
.48836 .68716 m .48884 .66835 L .4725 .67364 L p .707 .577 .707 r
F P
0 g
s
.47678 .69703 m .47581 .66071 L .45178 .66821 L p .707 .577 .707 r
F P
0 g
s
.82668 .65796 m .82765 .69427 L .80659 .68688 L p .707 .577 .707 r
F P
0 g
s
.80659 .68688 m .80562 .65056 L .82668 .65796 L p .707 .577 .707 r
F P
0 g
s
.71635 .57272 m .71216 .52102 L .74389 .51758 L p .707 .577 .707 r
F P
0 g
s
.71216 .52102 m .71635 .57272 L .68713 .58025 L p .707 .577 .707 r
F P
0 g
s
.32817 .69166 m .32865 .67285 L .30759 .66735 L p .707 .577 .707 r
F P
0 g
s
.74389 .51758 m .74808 .56927 L .71635 .57272 L p .707 .577 .707 r
F P
0 g
s
.30759 .66735 m .3071 .68616 L .32817 .69166 L p .707 .577 .707 r
F P
0 g
s
.33196 .66848 m .33293 .7048 L .3604 .70951 L p .707 .577 .707 r
F P
0 g
s
.48967 .53616 m .49386 .58785 L .50072 .57368 L p .707 .577 .707 r
F P
0 g
s
.50072 .57368 m .49652 .52199 L .48967 .53616 L p .707 .577 .707 r
F P
0 g
s
.33293 .7048 m .33196 .66848 L .3109 .66108 L p .707 .577 .707 r
F P
0 g
s
.66274 .69465 m .66177 .65833 L .6858 .65083 L p .707 .577 .707 r
F P
0 g
s
.48884 .66835 m .48836 .68716 L .48977 .6859 L p .707 .577 .707 r
F P
0 g
s
.48973 .68957 m .49312 .68761 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.48993 .67041 m .48884 .66835 L .48977 .6859 L .707 .577 .707 r
F
.49312 .68761 m .49215 .65129 L .49011 .65247 L p F P
0 g
s
.48996 .66735 m .48884 .66835 L p .48993 .67041 L .707 .577 .707 r
F P
0 g
s
.49011 .65247 m .47581 .66071 L p .4898 .68245 L .707 .577 .707 r
F P
0 g
s
.49312 .68761 m .49011 .65247 L .4898 .68245 L .707 .577 .707 r
F
.49215 .65129 m .49312 .68761 L .50018 .6772 L p F P
0 g
s
.50018 .6772 m .49921 .64088 L .49215 .65129 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .4959 .66206 L .48996 .66735 L p .707 .577 .707 r
F P
0 g
s
.49542 .68086 m .48996 .66735 L .48993 .67041 L .707 .577 .707 r
F
.48977 .6859 m .49542 .68086 L p .48993 .67041 L F P
0 g
s
.47581 .66071 m .47678 .69703 L .48973 .68957 L p .707 .577 .707 r
F P
0 g
s
.4898 .68245 m .47581 .66071 L .48973 .68957 L .707 .577 .707 r
F
.3109 .66108 m .31187 .6974 L .33293 .7048 L p F P
0 g
s
.29618 .54373 m .30037 .59543 L .31313 .60747 L p .707 .577 .707 r
F P
0 g
s
.80231 .6803 m .80183 .69911 L .77436 .69504 L p .707 .577 .707 r
F P
0 g
s
.77436 .69504 m .77485 .67623 L .80231 .6803 L p .707 .577 .707 r
F P
0 g
s
.80562 .65056 m .80659 .68688 L .77912 .68216 L p .707 .577 .707 r
F P
0 g
s
.77912 .68216 m .77815 .64584 L .80562 .65056 L p .707 .577 .707 r
F P
0 g
s
.30037 .59543 m .29618 .54373 L .29308 .52996 L p .707 .577 .707 r
F P
0 g
s
.3071 .68616 m .30759 .66735 L .29497 .66095 L p .707 .577 .707 r
F P
0 g
s
.68201 .69453 m .68249 .67572 L .71185 .67383 L p .707 .577 .707 r
F P
0 g
s
.6858 .65083 m .68677 .68715 L .66274 .69465 L p .707 .577 .707 r
F P
0 g
s
.29497 .66095 m .29449 .67976 L .3071 .68616 L p .707 .577 .707 r
F P
0 g
s
.31187 .6974 m .3109 .66108 L .29828 .65173 L p .707 .577 .707 r
F P
0 g
s
.68677 .68715 m .6858 .65083 L .71516 .64599 L p .707 .577 .707 r
F P
0 g
s
.71185 .67383 m .71137 .69264 L .68201 .69453 L p .707 .577 .707 r
F P
0 g
s
.49652 .52199 m .50072 .57368 L .49762 .55991 L p .707 .577 .707 r
F P
0 g
s
.49762 .55991 m .49342 .50821 L .49652 .52199 L p .707 .577 .707 r
F P
0 g
s
.77485 .67623 m .77436 .69504 L .7432 .69281 L p .707 .577 .707 r
F P
0 g
s
.7432 .69281 m .74368 .674 L .77485 .67623 L p .707 .577 .707 r
F P
0 g
s
.77815 .64584 m .77912 .68216 L .74796 .68058 L p .707 .577 .707 r
F P
0 g
s
.74796 .68058 m .74699 .64427 L .77815 .64584 L p .707 .577 .707 r
F P
0 g
s
.71137 .69264 m .71185 .67383 L .74368 .674 L p .707 .577 .707 r
F P
0 g
s
.71613 .6823 m .71516 .64599 L .74699 .64427 L p .707 .577 .707 r
F P
0 g
s
.71516 .64599 m .71613 .6823 L .68677 .68715 L p .707 .577 .707 r
F P
0 g
s
.29828 .65173 m .29925 .68805 L .31187 .6974 L p .707 .577 .707 r
F P
0 g
s
.74368 .674 m .7432 .69281 L .71137 .69264 L p .707 .577 .707 r
F P
0 g
s
.74699 .64427 m .74796 .68058 L .71613 .6823 L p .707 .577 .707 r
F P
0 g
s
.29308 .52996 m .29727 .58165 L .30037 .59543 L p .707 .577 .707 r
F P
0 g
s
.29727 .58165 m .29308 .52996 L .29993 .51579 L p .707 .577 .707 r
F P
0 g
s
.29449 .67976 m .29497 .66095 L .29205 .65428 L p .707 .577 .707 r
F P
0 g
s
.29205 .65428 m .29157 .67308 L .29449 .67976 L p .707 .577 .707 r
F P
0 g
s
.29925 .68805 m .29828 .65173 L .29536 .64134 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49342 .50821 m .49762 .55991 L .48486 .54787 L p .707 .577 .707 r
F P
0 g
s
.48486 .54787 m .48067 .49618 L .49342 .50821 L p .707 .577 .707 r
F P
0 g
s
.29536 .64134 m .29633 .67766 L .29925 .68805 L p .707 .577 .707 r
F P
0 g
s
.4959 .66206 m .49542 .68086 L .4925 .67419 L p .707 .577 .707 r
F P
0 g
s
.4925 .67419 m .49298 .65538 L .4959 .66206 L p .707 .577 .707 r
F P
0 g
s
.49921 .64088 m .50018 .6772 L .49726 .66681 L p .707 .577 .707 r
F P
0 g
s
.49726 .66681 m .49629 .63049 L .49921 .64088 L p .707 .577 .707 r
F P
0 g
s
.29993 .51579 m .30413 .56749 L .29727 .58165 L p .707 .577 .707 r
F P
0 g
s
.30413 .56749 m .29993 .51579 L .31608 .50262 L p .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .29536 .64134 L .30154 .63223 L p .707 .577 .707 r
F P
0 g
s
.30154 .63223 m .30242 .63093 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.29633 .67766 m .30154 .63223 L .30159 .63729 L .707 .577 .707 r
F
.30169 .64715 m .31545 .64269 L p .30185 .66218 L F P
0 g
s
.31545 .64269 m .31497 .6615 L .30189 .66574 L p .707 .577 .707 r
F P
0 g
s
.30185 .66218 m .31545 .64269 L .30189 .66574 L .707 .577 .707 r
F
.30242 .63093 m .30339 .66725 L .30192 .66941 L p F P
0 g
s
.30192 .66941 m .29633 .67766 L p .30159 .63729 L .707 .577 .707 r
F P
0 g
s
.30159 .63729 m .30242 .63093 L .30192 .66941 L .707 .577 .707 r
F
.30189 .66574 m .29863 .66679 L p .30185 .66218 L F P
0 g
s
.29863 .66679 m .29911 .64798 L .30169 .64715 L p .707 .577 .707 r
F P
0 g
s
.29863 .66679 m .30169 .64715 L .30185 .66218 L .707 .577 .707 r
F
.29157 .67308 m .29205 .65428 L .29911 .64798 L p F P
0 g
s
.29911 .64798 m .29863 .66679 L .29157 .67308 L p .707 .577 .707 r
F P
0 g
s
.48067 .49618 m .48486 .54787 L .4637 .53875 L p .707 .577 .707 r
F P
0 g
s
.4637 .53875 m .45951 .48706 L .48067 .49618 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49298 .65538 m .4925 .67419 L .47988 .66779 L p .707 .577 .707 r
F P
0 g
s
.47988 .66779 m .48037 .64898 L .49298 .65538 L p .707 .577 .707 r
F P
0 g
s
.31608 .50262 m .32027 .55432 L .30413 .56749 L p .707 .577 .707 r
F P
0 g
s
.32027 .55432 m .31608 .50262 L .33993 .49174 L p .707 .577 .707 r
F P
0 g
s
.49629 .63049 m .49726 .66681 L .48464 .65746 L p .707 .577 .707 r
F P
0 g
s
.48464 .65746 m .48367 .62114 L .49629 .63049 L p .707 .577 .707 r
F P
0 g
s
.45951 .48706 m .4637 .53875 L .43621 .53344 L p .707 .577 .707 r
F P
0 g
s
.43621 .53344 m .43201 .48174 L .45951 .48706 L p .707 .577 .707 r
F P
0 g
s
.30339 .66725 m .30242 .63093 L .31876 .62151 L p .707 .577 .707 r
F P
0 g
s
.34412 .54343 m .33993 .49174 L .36915 .48421 L p .707 .577 .707 r
F P
0 g
s
.33993 .49174 m .34412 .54343 L .32027 .55432 L p .707 .577 .707 r
F P
0 g
s
.43201 .48174 m .43621 .53344 L .40507 .53246 L p .707 .577 .707 r
F P
0 g
s
.40507 .53246 m .40088 .48076 L .43201 .48174 L p .707 .577 .707 r
F P
0 g
s
.31497 .6615 m .31545 .64269 L .33948 .63891 L p .707 .577 .707 r
F P
0 g
s
.33948 .63891 m .339 .65772 L .31497 .6615 L p .707 .577 .707 r
F P
0 g
s
.31876 .62151 m .31973 .65783 L .30339 .66725 L p .707 .577 .707 r
F P
0 g
s
.48037 .64898 m .47988 .66779 L .45882 .66229 L p .707 .577 .707 r
F P
0 g
s
.45882 .66229 m .4593 .64348 L .48037 .64898 L p .707 .577 .707 r
F P
0 g
s
.48367 .62114 m .48464 .65746 L .46358 .65006 L p .707 .577 .707 r
F P
0 g
s
.46358 .65006 m .46261 .61374 L .48367 .62114 L p .707 .577 .707 r
F P
0 g
s
.37334 .5359 m .36915 .48421 L .40088 .48076 L p .707 .577 .707 r
F P
0 g
s
.36915 .48421 m .37334 .5359 L .34412 .54343 L p .707 .577 .707 r
F P
0 g
s
.40088 .48076 m .40507 .53246 L .37334 .5359 L p .707 .577 .707 r
F P
0 g
s
.31973 .65783 m .31876 .62151 L .34279 .61402 L p .707 .577 .707 r
F P
0 g
s
.4593 .64348 m .45882 .66229 L .43135 .65823 L p .707 .577 .707 r
F P
0 g
s
.43135 .65823 m .43184 .63942 L .4593 .64348 L p .707 .577 .707 r
F P
0 g
s
.46261 .61374 m .46358 .65006 L .43611 .64535 L p .707 .577 .707 r
F P
0 g
s
.43611 .64535 m .43514 .60903 L .46261 .61374 L p .707 .577 .707 r
F P
0 g
s
.339 .65772 m .33948 .63891 L .36884 .63701 L p .707 .577 .707 r
F P
0 g
s
.34279 .61402 m .34376 .65033 L .31973 .65783 L p .707 .577 .707 r
F P
0 g
s
.34376 .65033 m .34279 .61402 L .37215 .60917 L p .707 .577 .707 r
F P
0 g
s
.36884 .63701 m .36836 .65582 L .339 .65772 L p .707 .577 .707 r
F P
0 g
s
.43184 .63942 m .43135 .65823 L .40018 .656 L p .707 .577 .707 r
F P
0 g
s
.40018 .656 m .40067 .63719 L .43184 .63942 L p .707 .577 .707 r
F P
0 g
s
.43514 .60903 m .43611 .64535 L .40495 .64377 L p .707 .577 .707 r
F P
0 g
s
.40495 .64377 m .40397 .60745 L .43514 .60903 L p .707 .577 .707 r
F P
0 g
s
.36836 .65582 m .36884 .63701 L .40067 .63719 L p .707 .577 .707 r
F P
0 g
s
.37312 .64549 m .37215 .60917 L .40397 .60745 L p .707 .577 .707 r
F P
0 g
s
.37215 .60917 m .37312 .64549 L .34376 .65033 L p .707 .577 .707 r
F P
0 g
s
.40067 .63719 m .40018 .656 L .36836 .65582 L p .707 .577 .707 r
F P
0 g
s
.40397 .60745 m .40495 .64377 L .37312 .64549 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Io
o`00Ogoo30001EYF00<005YFFUH015YF2@00OGoo001fOol90005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001/Ool30009FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006Yo
o`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uo
o`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH90002FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000D000AJEP03001JEUYF009JEPP000IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD00003FUH0
05YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00Ggoo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001MOol200000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol20006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001FOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol005Aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0001Moo`l003moo`00E7oo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00004Goo1P0015YF00<005YFFUH01UYF00<005YF00000`00>goo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000=Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`@000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001goo
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH80008FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP050005FUH20008FUH00`00FUIJEP06FUH40004FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP0015YF00<005YFFUH00eYF0`0000Eoo`00FUIJ
EP0000EJEP8000QJEP03001JEUYF00UJEP@00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000`Ool005=o
o`04001JEUYF0004FUH01000FUIJEUYF0P0017oo00@005YFFUH000EJEP8000QJEP03001JEUYF00UJ
EP03001JEUYF00<000=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF00@005YF
000000Ioo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH30003FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0P0027oo00@005YFFUH000EJEP8000QJ
EP03001JEUYF00QJEP800003FUH005YF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP02000^Ool005Aoo`03001JEP0000=JEP03001oogoo00Qoo`04001JEUYF0005FUH20008FUH00`00
FUIJEP06FUH20003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol01000
FUH005YF10002Goo00@005YFFUH000EJEP@000IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009J
EP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00E7oo00@005YF000000AJEP<000Ioo`04001J
EUYF0005FUH50005FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP03FUH30002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000^Ool005Aoo`04001JEP000005FUH00`00FUH000030002Ool01000FUIJEP001EYF
30001EYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001DOol20002FUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`P000AJEP03001JEUYF00=JEP04
001JEP00000^Ool005Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH015YF00<0
05YFFUH00UYF0P005goo1@001EYF00@005YFFUH002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0005FUH00`00FUIJEP04FUH00`00FUH00002000NOol20003FUH01000FUIJEP00;Woo001DOol2
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH00eYF0`008goo0P0000EJ
EP00FUIJEP0002ioo`00E7oo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF009J
EP04001JEUYFFUH2000UOol200000eYF00000002FUH2000]Ool005Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUH000009Goo0P0000=JEP00FUH00UYF00@005YF
000002eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH2000UOol20003FUH01000FUIJ
EUYF1000;Goo001EOol01@00FUIJEUYF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH2000EOol3000<Ool30005FUH01P00FUIJEUYF
001JEP8002eoo`00AWoo2@001goo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`000UYF0P004Woo1@001goo100000=J
EP00FUH01EYF00<005YFFUH00UYF0`00;Goo0010Ool60004FUH00`00FUIJEP02FUH;0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P002UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00T005YFFUIJEP00FUH005YF000015YF
1@003Goo30001EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000lOol400000eYF001JEP07
FUH00`00FUIJEP06FUH01000FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF2@0000=J
EP00FUH01eYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000;Goo000hOol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH80002FUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000fOol200000eYF001JEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH300000eYF000000050003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool003Aoo`8000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00;Woo000bOol20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00D005YFFUIJEP0002moo`00<Goo0P001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000;goo000`Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00
<7oo000_Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000aOol002ioo`03001JEUYF
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol002eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2000cOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00=Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF0P0015YF00<005YFFUH01EYF5`000eYF00@005YF000003Moo`00;7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF
00<005YFFUH00eYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF
00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000AJEP<00003FUH005YF00=JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000@003Uoo`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF3`000eYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00<00003FUH005YF009JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUH000050006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH3000gOol002aoo`9JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00AJEPL000=JEP03001JEUYF00EJEP04001JEP000003FUH01000FUH000000UYF00<005YFFUH0
0UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;7oo0UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH01EYF0P0000=JEP00
FUH00UYF0P0000=JEP0000001`000UYF00<005YFFUH015YF00<005YFFUH015YF200015YF00<005YF
FUH00eYF00<005YF00000UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo0UYF0P0015YF00<005YFFUH00eYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH01@0000IJEP00000005YF0002FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH00eYF1`000eYF00<005YFFUH010000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00;7oo0eYF00<005YFFUH00UYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP0000@00004FUH000000004FUH20002FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH01eYF0P0000=JEP0000000P000UYF10000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo
000/Ool3FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH00UYF1`0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03
001JEUYF009JEPD000EJEP03001JEP0000D0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04
001JEP000004FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00;Goo000/Ool01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800005FUH0
05YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYFFUH2000]Ool002aoo`@00004FUH000000006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo
00<005YF00000P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80003FUH00`00FUIJ
EP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUIJEP04FUHE0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00=J
EPH0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF0080
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03P001EYF00<005YFFUH00eYF
00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05
001JEUYF001JEP020004FUH00`00FUH000030004FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0000AJEP00FUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00=J
EP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0015YF0P0000=JEP000000
1@0000=JEP00Ool01Woo4@000eYF00<005YFFUH015YF0P000UYF0P00;Goo000/Ool01000FUIJEP00
0eYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF0080009J
EPL000=JEP04001JEUYF000HOol50004FUH01@00FUIJEP00FUH00P00;Goo000/Ool01000FUIJEP00
0eYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF00@00004FUH0
00000003FUH200001EYF001JEUYF00006goo1@0000=JEP00FUH00UYF0`00;Goo000]Ool2FUH01000
FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF001JEP03FUH70002FUH2000EOol50005FUH20003FUH3000]Ool002eoo`9JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000P000AJEP03001JEUYF009JEPT000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00=JEP04001JEUYFFUH90009Ool9
0003FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00;Goo000]Ool01EYF001JEUYF00001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00`000UYF00<005YFFUH02@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP@0
02eoo`00;Goo00=JEP00FUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`000UYF00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`<0009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP8000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0;7oo000]Ool2000015YF0000000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01UYF
1@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`00;Woo000^Ool00`00FUIJEP02
0005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUIJEP000UYF
00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02000_Ool002ioo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH50005FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF10001EYF
00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000_Ool00`00FUH00003FUH200000eYF001JEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP030002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00<goo000`Ool20005
FUH50003FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0400000eYF001JEP05FUH30002Ool01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=Goo000aOol2
0004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP03FUH20004Ool0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF0`001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo000cOol300000eYF001JEP06
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUH000030006Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH015YF8@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P001EYF1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01000?Goo000fOol50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000:Ool01000FUIJEP001UYF00<005YF
FUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P001UYF00<005YFFUH05`00@Goo000kOol90004FUH00`00FUIJEP05FUH8000=
Ool01000FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YF00000`001eYF00<005YFFUH00UYF0P000UYF0P001UYF00<005YF00000UYF
0P00E7oo0014Ool<000EOol01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0P000UYF0P00
1UYF0P0015YF00<007ooOol0DWoo001UOol01000FUIJEP001EYF0`000eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF
0P000eYF00<005YFFUH00eYF0P001EYF00<007ooOol0DWoo001UOol01000FUIJEP000eYF0P001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YF000000AJEP8000=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00Oomoo`1COol006Eo
o`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000eYF00@005YF000000=JEP05001J
EUYFFUH0001FOol006Eoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP<0
00EJEP05001JEUYFFUH0001FOol003Iooal0011oo`03001JEP0000=JEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0000<00003FUH005YF00EJEP04001JEP00001GOol0039oo`@000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000aoo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04FUH2001IOol0031oo`<000IJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEPD000Moo`8000AJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP02FUH2001KOol002ioo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00@000=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002
FUH6001MOol002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003Ool0000000AJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<006=oo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00eYF0P00Igoo000/Ool20004FUH01000FUIJEUYF20004Goo200015YF00<005YF
FUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00;7oo0P00
0UYF1P008Goo1`000eYF00H005YFFUIJEP00Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00Oomoo`1VOol002]oo`03001JEP0000@002aoo`@000=JEP04001oogooOol30008FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P00JGoo000[Ool20003FUH00`00FUH00002000]Ool200000eYF001oo`04Ool20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000
FUH00000Jgoo000[Ool20003FUH00`00FUIJEP02FUH5000ROol6000015YF000000001goo0`0015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
1@00K7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@004Woo1`000eYF00L005YFFUIJ
EP00FUH0000:Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP060004FUH8001TOol002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHB0003FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000eoo`L000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD000EJEP03001JEUYF00IJEP04001JEUYFFUH6001N
Ool002eoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000EOol;0006FUH00`00FUIJEP0:FUH01000
FUIJEUYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00Fgoo
000_Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02000QOolG0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3001HOol003=oo`L000AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@002]oo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001J
EP00001FOol003Yoo`P000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<002moo`03
001JEP0000AJEP04001JEUYFFUHQ0003FUH00`00FUIJEP04FUH01000FUIJEP00EWoo0012OolH000c
Ool00`00FUH00003FUH5000QOol50004FUH01000FUIJEUYF0P00EGoo002=Ool01000FUH005YF0P00
:goo0`0000=JEP00FUH00UYF0P00EGoo002=Ool00`00FUH00004000]Ool20003FUH2001EOol008eo
o`80009JEP03001JEUYF00D002Uoo`<00003FUH0000005Eoo`00SGoo0P000UYF00<005YFFUH00eYF
00<005YF00000`0087oo1@000eYF0`00EGoo002>Ool01000FUIJEP001EYF00<005YFFUH00eYF8000
0eYF00<005YFFUH00UYF0`00EGoo002?Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001EOol0095o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH3001FOol009=oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001IOol009Ioo`D000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001KOol009]ooa8000AJEP03
001JEUYF009JEPL0061oo`00[Goo2@00Igoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59493 .71763 m .59912 .66031 L .56798 .65745 L p .707 .577 .707 r
F P
0 g
s
.59912 .66031 m .59493 .71763 L .62666 .71966 L p .707 .577 .707 r
F P
0 g
s
.62666 .71966 m .63085 .66234 L .59912 .66031 L p .707 .577 .707 r
F P
0 g
s
.63085 .66234 m .62666 .71966 L .65588 .72066 L p .707 .577 .707 r
F P
0 g
s
.65588 .72066 m .66007 .66334 L .63085 .66234 L p .707 .577 .707 r
F P
0 g
s
.56798 .65745 m .56379 .71477 L .59493 .71763 L p .707 .577 .707 r
F P
0 g
s
.56379 .71477 m .56798 .65745 L .54049 .65402 L p .707 .577 .707 r
F P
0 g
s
.54049 .65402 m .5363 .71134 L .56379 .71477 L p .707 .577 .707 r
F P
0 g
s
.66007 .66334 m .65588 .72066 L .67972 .72051 L p .707 .577 .707 r
F P
0 g
s
.67972 .72051 m .68392 .66319 L .66007 .66334 L p .707 .577 .707 r
F P
0 g
s
.5363 .71134 m .54049 .65402 L .51933 .65037 L p .707 .577 .707 r
F P
0 g
s
.51933 .65037 m .51514 .70769 L .5363 .71134 L p .707 .577 .707 r
F P
0 g
s
.59505 .82878 m .59602 .79116 L .56485 .78893 L p .707 .577 .707 r
F P
0 g
s
.59602 .79116 m .59505 .82878 L .62687 .82896 L p .707 .577 .707 r
F P
0 g
s
.62687 .82896 m .62784 .79134 L .59602 .79116 L p .707 .577 .707 r
F P
0 g
s
.62784 .79134 m .62687 .82896 L .65624 .82707 L p .707 .577 .707 r
F P
0 g
s
.65624 .82707 m .65721 .78945 L .62784 .79134 L p .707 .577 .707 r
F P
0 g
s
.56388 .82655 m .56485 .78893 L .53739 .78486 L p .707 .577 .707 r
F P
0 g
s
.56485 .78893 m .56388 .82655 L .59505 .82878 L p .707 .577 .707 r
F P
0 g
s
.68392 .66319 m .67972 .72051 L .69587 .71925 L p .707 .577 .707 r
F P
0 g
s
.69587 .71925 m .70006 .66193 L .68392 .66319 L p .707 .577 .707 r
F P
0 g
s
.53739 .78486 m .53642 .82248 L .56388 .82655 L p .707 .577 .707 r
F P
0 g
s
.65721 .78945 m .65624 .82707 L .68027 .8233 L p .707 .577 .707 r
F P
0 g
s
.68027 .8233 m .68124 .78568 L .65721 .78945 L p .707 .577 .707 r
F P
0 g
s
.59981 .83462 m .59933 .81646 L .56816 .81488 L p .707 .577 .707 r
F P
0 g
s
.59933 .81646 m .59981 .83462 L .63164 .83291 L p .707 .577 .707 r
F P
0 g
s
.63164 .83291 m .63115 .81474 L .59933 .81646 L p .707 .577 .707 r
F P
0 g
s
.51514 .70769 m .51933 .65037 L .50658 .64686 L p .707 .577 .707 r
F P
0 g
s
.63115 .81474 m .63164 .83291 L .661 .82807 L p .707 .577 .707 r
F P
0 g
s
.661 .82807 m .66052 .80991 L .63115 .81474 L p .707 .577 .707 r
F P
0 g
s
.56816 .81488 m .56864 .83304 L .59981 .83462 L p .707 .577 .707 r
F P
0 g
s
.56864 .83304 m .56816 .81488 L .5407 .81016 L p .707 .577 .707 r
F P
0 g
s
.53642 .82248 m .53739 .78486 L .51632 .77937 L p .707 .577 .707 r
F P
0 g
s
.50658 .64686 m .50238 .70418 L .51514 .70769 L p .707 .577 .707 r
F P
0 g
s
.5407 .81016 m .54118 .82833 L .56864 .83304 L p .707 .577 .707 r
F P
0 g
s
.68124 .78568 m .68027 .8233 L .69661 .81802 L p .707 .577 .707 r
F P
0 g
s
.66052 .80991 m .661 .82807 L .68503 .82058 L p .707 .577 .707 r
F P
0 g
s
.68503 .82058 m .68454 .80242 L .66052 .80991 L p .707 .577 .707 r
F P
0 g
s
.51632 .77937 m .51535 .81699 L .53642 .82248 L p .707 .577 .707 r
F P
0 g
s
.69661 .81802 m .69758 .7804 L .68124 .78568 L p .707 .577 .707 r
F P
0 g
s
.70006 .66193 m .69587 .71925 L .70272 .71699 L p .707 .577 .707 r
F P
0 g
s
.70272 .71699 m .70692 .65967 L .70006 .66193 L p .707 .577 .707 r
F P
0 g
s
.54118 .82833 m .5407 .81016 L .51963 .80277 L p .707 .577 .707 r
F P
0 g
s
.51963 .80277 m .52011 .82094 L .54118 .82833 L p .707 .577 .707 r
F P
0 g
s
.51535 .81699 m .51632 .77937 L .50371 .77298 L p .707 .577 .707 r
F P
0 g
s
.50238 .70418 m .50658 .64686 L .50347 .64383 L p .707 .577 .707 r
F P
0 g
s
.69758 .7804 m .69661 .81802 L .69807 .81672 L p .707 .577 .707 r
F P
0 g
s
.69811 .81305 m .70137 .81118 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.69841 .78467 m .69758 .7804 L .69807 .81672 L .707 .577 .707 r
F
.70137 .81118 m .70089 .79302 L .6983 .7945 L p F P
0 g
s
.6983 .7945 m .68454 .80242 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.70137 .81118 m .6983 .7945 L .69815 .8095 L .707 .577 .707 r
F
.70089 .79302 m .70137 .81118 L .70843 .80078 L p F P
0 g
s
.70843 .80078 m .70794 .78262 L .70089 .79302 L p .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .70463 .77412 L .69846 .77962 L p .707 .577 .707 r
F P
0 g
s
.69846 .77962 m .69758 .7804 L p .69841 .78467 L .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .69846 .77962 L .69841 .78467 L .707 .577 .707 r
F
.69807 .81672 m .70366 .81174 L p .69841 .78467 L F P
0 g
s
.68454 .80242 m .68503 .82058 L .69811 .81305 L p .707 .577 .707 r
F P
0 g
s
.69815 .8095 m .68454 .80242 L .69811 .81305 L .707 .577 .707 r
F
.50347 .64383 m .49928 .70115 L .50238 .70418 L p F P
0 g
s
.50371 .77298 m .50274 .8106 L .51535 .81699 L p .707 .577 .707 r
F P
0 g
s
.52011 .82094 m .51963 .80277 L .50702 .79343 L p .707 .577 .707 r
F P
0 g
s
.50702 .79343 m .5075 .81159 L .52011 .82094 L p .707 .577 .707 r
F P
0 g
s
.70692 .65967 m .70272 .71699 L .69962 .71396 L p .707 .577 .707 r
F P
0 g
s
.69962 .71396 m .70382 .65664 L .70692 .65967 L p .707 .577 .707 r
F P
0 g
s
.48847 .82191 m .49028 .31883 L .44627 .31609 L p .707 .577 .707 r
F P
0 g
s
.50274 .8106 m .50371 .77298 L .50079 .76632 L p .707 .577 .707 r
F P
0 g
s
.49928 .70115 m .50347 .64383 L .51033 .64157 L p .707 .577 .707 r
F P
0 g
s
.50079 .76632 m .49982 .80394 L .50274 .8106 L p .707 .577 .707 r
F P
0 g
s
.51033 .64157 m .50614 .69889 L .49928 .70115 L p .707 .577 .707 r
F P
0 g
s
.5075 .81159 m .50702 .79343 L .5041 .78305 L p .707 .577 .707 r
F P
0 g
s
.5041 .78305 m .50458 .80121 L .5075 .81159 L p .707 .577 .707 r
F P
0 g
s
.49982 .80394 m .50079 .76632 L .50785 .76004 L p .707 .577 .707 r
F P
0 g
s
.50614 .69889 m .51033 .64157 L .52647 .64031 L p .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .5041 .78305 L .51004 .7743 L p .707 .577 .707 r
F P
0 g
s
.50989 .75938 m .52419 .75475 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.51004 .7743 m .51116 .77265 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .51004 .7743 L .51007 .77736 L .707 .577 .707 r
F
.5102 .78943 m .52419 .75475 L .51027 .79656 L F
.51116 .77265 m .51164 .79081 L .51023 .79289 L p F P
0 g
s
.51023 .79289 m .50458 .80121 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.51007 .77736 m .51116 .77265 L .51023 .79289 L .707 .577 .707 r
F
.52419 .75475 m .52322 .79237 L .51027 .79656 L p F P
0 g
s
.51027 .79656 m .50688 .79766 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50785 .76004 L .50989 .75938 L p .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50989 .75938 L .5102 .78943 L .707 .577 .707 r
F
.50785 .76004 m .50688 .79766 L .49982 .80394 L p F P
0 g
s
.52647 .64031 m .52228 .69763 L .50614 .69889 L p .707 .577 .707 r
F P
0 g
s
.52228 .69763 m .52647 .64031 L .55032 .64017 L p .707 .577 .707 r
F P
0 g
s
.55032 .64017 m .54613 .69749 L .52228 .69763 L p .707 .577 .707 r
F P
0 g
s
.52322 .79237 m .52419 .75475 L .54822 .75099 L p .707 .577 .707 r
F P
0 g
s
.51164 .79081 m .51116 .77265 L .5275 .76325 L p .707 .577 .707 r
F P
0 g
s
.5275 .76325 m .52798 .78141 L .51164 .79081 L p .707 .577 .707 r
F P
0 g
s
.54822 .75099 m .54725 .78861 L .52322 .79237 L p .707 .577 .707 r
F P
0 g
s
.54725 .78861 m .54822 .75099 L .57758 .7491 L p .707 .577 .707 r
F P
0 g
s
.52798 .78141 m .5275 .76325 L .55153 .75576 L p .707 .577 .707 r
F P
0 g
s
.55153 .75576 m .55201 .77392 L .52798 .78141 L p .707 .577 .707 r
F P
0 g
s
.49028 .31883 m .48847 .82191 L .53342 .821 L p .707 .577 .707 r
F P
0 g
s
.53342 .821 m .53522 .31792 L .49028 .31883 L p .707 .577 .707 r
F P
0 g
s
.54613 .69749 m .55032 .64017 L .57954 .64116 L p .707 .577 .707 r
F P
0 g
s
.57954 .64116 m .57535 .69848 L .54613 .69749 L p .707 .577 .707 r
F P
0 g
s
.57758 .7491 m .57661 .78672 L .54725 .78861 L p .707 .577 .707 r
F P
0 g
s
.57661 .78672 m .57758 .7491 L .6094 .74928 L p .707 .577 .707 r
F P
0 g
s
.55201 .77392 m .55153 .75576 L .58089 .75092 L p .707 .577 .707 r
F P
0 g
s
.58089 .75092 m .58137 .76909 L .55201 .77392 L p .707 .577 .707 r
F P
0 g
s
.53522 .31792 m .53342 .821 L .5749 .81651 L p .707 .577 .707 r
F P
0 g
s
.5749 .81651 m .5767 .31344 L .53522 .31792 L p .707 .577 .707 r
F P
0 g
s
.44447 .81916 m .44627 .31609 L .40751 .30995 L p .707 .577 .707 r
F P
0 g
s
.44627 .31609 m .44447 .81916 L .48847 .82191 L p .707 .577 .707 r
F P
0 g
s
.70463 .77412 m .70366 .81174 L .70074 .80508 L p .707 .577 .707 r
F P
0 g
s
.70074 .80508 m .70171 .76746 L .70463 .77412 L p .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .57954 .64116 L .58524 .64152 L p .707 .577 .707 r
F P
0 g
s
.58524 .64152 m .61127 .64319 L p .57975 .6917 L .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .58524 .64152 L .57975 .6917 L .707 .577 .707 r
F
.64241 .64605 m .63821 .70338 L .60708 .70051 L p F P
0 g
s
.60708 .70051 m .61127 .64319 L .64241 .64605 L p .707 .577 .707 r
F P
0 g
s
.61127 .64319 m .60708 .70051 L .57535 .69848 L p .707 .577 .707 r
F P
0 g
s
.64057 .75151 m .6396 .78913 L .60843 .7869 L p .707 .577 .707 r
F P
0 g
s
.60843 .7869 m .6094 .74928 L .64057 .75151 L p .707 .577 .707 r
F P
0 g
s
.6396 .78913 m .64057 .75151 L .66803 .75557 L p .707 .577 .707 r
F P
0 g
s
.64388 .75079 m .64436 .76895 L .6132 .76737 L p .707 .577 .707 r
F P
0 g
s
.6132 .76737 m .61271 .74921 L .64388 .75079 L p .707 .577 .707 r
F P
0 g
s
.6094 .74928 m .60843 .7869 L .57661 .78672 L p .707 .577 .707 r
F P
0 g
s
.58137 .76909 m .58089 .75092 L .61271 .74921 L p .707 .577 .707 r
F P
0 g
s
.61271 .74921 m .6132 .76737 L .58137 .76909 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .63196 .7989 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61066 .30582 m .61028 .41273 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61028 .41273 m .60886 .8089 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.5767 .31344 m .5749 .81651 L .60886 .8089 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .61066 .30582 L .5767 .31344 L p .707 .577 .707 r
F P
0 g
s
.70382 .65664 m .69962 .71396 L .68687 .71045 L p .707 .577 .707 r
F P
0 g
s
.68687 .71045 m .69106 .65313 L .70382 .65664 L p .707 .577 .707 r
F P
0 g
s
.25192 .68082 m .25611 .6235 L .22498 .62063 L p .707 .577 .707 r
F P
0 g
s
.25611 .6235 m .25192 .68082 L .28365 .68285 L p .707 .577 .707 r
F P
0 g
s
.28365 .68285 m .28784 .62553 L .25611 .6235 L p .707 .577 .707 r
F P
0 g
s
.70794 .78262 m .70843 .80078 L .70551 .7904 L p .707 .577 .707 r
F P
0 g
s
.70551 .7904 m .70502 .77224 L .70794 .78262 L p .707 .577 .707 r
F P
0 g
s
.4057 .81303 m .40751 .30995 L .37778 .30102 L p .707 .577 .707 r
F P
0 g
s
.40751 .30995 m .4057 .81303 L .44447 .81916 L p .707 .577 .707 r
F P
0 g
s
.28784 .62553 m .28365 .68285 L .31287 .68384 L p .707 .577 .707 r
F P
0 g
s
.31287 .68384 m .31706 .62652 L .28784 .62553 L p .707 .577 .707 r
F P
0 g
s
.22498 .62063 m .22078 .67795 L .25192 .68082 L p .707 .577 .707 r
F P
0 g
s
.22078 .67795 m .22498 .62063 L .19748 .6172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19748 .6172 m .19329 .67453 L .22078 .67795 L p .707 .577 .707 r
F P
0 g
s
.31706 .62652 m .31287 .68384 L .33672 .6837 L p .707 .577 .707 r
F P
0 g
s
.33672 .6837 m .34091 .62638 L .31706 .62652 L p .707 .577 .707 r
F P
0 g
s
.63196 .7989 m .63377 .29582 L .61066 .30582 L p .707 .577 .707 r
F P
0 g
s
.70171 .76746 m .70074 .80508 L .68813 .79869 L p .707 .577 .707 r
F P
0 g
s
.68813 .79869 m .6891 .76107 L .70171 .76746 L p .707 .577 .707 r
F P
0 g
s
.19329 .67453 m .19748 .6172 L .17632 .61356 L p .707 .577 .707 r
F P
0 g
s
.69106 .65313 m .68687 .71045 L .66571 .7068 L p .707 .577 .707 r
F P
0 g
s
.66571 .7068 m .6699 .64948 L .69106 .65313 L p .707 .577 .707 r
F P
0 g
s
.17632 .61356 m .17213 .67088 L .19329 .67453 L p .707 .577 .707 r
F P
0 g
s
.25204 .79196 m .25301 .75434 L .22185 .75211 L p .707 .577 .707 r
F P
0 g
s
.25301 .75434 m .25204 .79196 L .28387 .79214 L p .707 .577 .707 r
F P
0 g
s
.28387 .79214 m .28484 .75452 L .25301 .75434 L p .707 .577 .707 r
F P
0 g
s
.70502 .77224 m .70551 .7904 L .69289 .78106 L p .707 .577 .707 r
F P
0 g
s
.69289 .78106 m .69241 .76289 L .70502 .77224 L p .707 .577 .707 r
F P
0 g
s
.28484 .75452 m .28387 .79214 L .31323 .79026 L p .707 .577 .707 r
F P
0 g
s
.31323 .79026 m .3142 .75264 L .28484 .75452 L p .707 .577 .707 r
F P
0 g
s
.37598 .8041 m .37778 .30102 L .36 .29018 L p .707 .577 .707 r
F P
0 g
s
.37778 .30102 m .37598 .8041 L .4057 .81303 L p .707 .577 .707 r
F P
0 g
s
.22087 .78973 m .22185 .75211 L .19438 .74805 L p .707 .577 .707 r
F P
0 g
s
.22185 .75211 m .22087 .78973 L .25204 .79196 L p .707 .577 .707 r
F P
0 g
s
.34091 .62638 m .33672 .6837 L .35286 .68244 L p .707 .577 .707 r
F P
0 g
s
.35286 .68244 m .35705 .62512 L .34091 .62638 L p .707 .577 .707 r
F P
0 g
s
.19438 .74805 m .19341 .78567 L .22087 .78973 L p .707 .577 .707 r
F P
0 g
s
.3142 .75264 m .31323 .79026 L .33726 .78649 L p .707 .577 .707 r
F P
0 g
s
.33726 .78649 m .33823 .74887 L .3142 .75264 L p .707 .577 .707 r
F P
0 g
s
.2568 .7978 m .25632 .77964 L .22515 .77806 L p .707 .577 .707 r
F P
0 g
s
.25632 .77964 m .2568 .7978 L .28863 .79609 L p .707 .577 .707 r
F P
0 g
s
.28863 .79609 m .28814 .77793 L .25632 .77964 L p .707 .577 .707 r
F P
0 g
s
.17213 .67088 m .17632 .61356 L .16357 .61004 L p .707 .577 .707 r
F P
0 g
s
.28814 .77793 m .28863 .79609 L .31799 .79125 L p .707 .577 .707 r
F P
0 g
s
.31799 .79125 m .31751 .77309 L .28814 .77793 L p .707 .577 .707 r
F P
0 g
s
.6699 .64948 m .66571 .7068 L .63821 .70338 L p .707 .577 .707 r
F P
0 g
s
.63821 .70338 m .64241 .64605 L .6699 .64948 L p .707 .577 .707 r
F P
0 g
s
.6891 .76107 m .68813 .79869 L .66706 .79319 L p .707 .577 .707 r
F P
0 g
s
.66706 .79319 m .66803 .75557 L .6891 .76107 L p .707 .577 .707 r
F P
0 g
s
.22515 .77806 m .22563 .79623 L .2568 .7978 L p .707 .577 .707 r
F P
0 g
s
.22563 .79623 m .22515 .77806 L .19769 .77335 L p .707 .577 .707 r
F P
0 g
s
.19341 .78567 m .19438 .74805 L .17331 .74255 L p .707 .577 .707 r
F P
0 g
s
.16357 .61004 m .15937 .66737 L .17213 .67088 L p .707 .577 .707 r
F P
0 g
s
.19769 .77335 m .19817 .79151 L .22563 .79623 L p .707 .577 .707 r
F P
0 g
s
.66803 .75557 m .66706 .79319 L .6396 .78913 L p .707 .577 .707 r
F P
0 g
s
.63377 .29582 m .63196 .7989 L .64196 .78749 L p .707 .577 .707 r
F P
0 g
s
.64196 .78749 m .64377 .28441 L .63377 .29582 L p .707 .577 .707 r
F P
0 g
s
.33823 .74887 m .33726 .78649 L .3536 .78121 L p .707 .577 .707 r
F P
0 g
s
.31751 .77309 m .31799 .79125 L .34202 .78377 L p .707 .577 .707 r
F P
0 g
s
.34202 .78377 m .34154 .76561 L .31751 .77309 L p .707 .577 .707 r
F P
0 g
s
.69241 .76289 m .69289 .78106 L .67183 .77367 L p .707 .577 .707 r
F P
0 g
s
.67183 .77367 m .67134 .7555 L .69241 .76289 L p .707 .577 .707 r
F P
0 g
s
.17331 .74255 m .17234 .78017 L .19341 .78567 L p .707 .577 .707 r
F P
0 g
s
.3536 .78121 m .35457 .74359 L .33823 .74887 L p .707 .577 .707 r
F P
0 g
s
.35705 .62512 m .35286 .68244 L .35971 .68018 L p .707 .577 .707 r
F P
0 g
s
.35971 .68018 m .36391 .62286 L .35705 .62512 L p .707 .577 .707 r
F P
0 g
s
.19817 .79151 m .19769 .77335 L .17662 .76596 L p .707 .577 .707 r
F P
0 g
s
.17662 .76596 m .1771 .78412 L .19817 .79151 L p .707 .577 .707 r
F P
0 g
s
.17234 .78017 m .17331 .74255 L .1607 .73616 L p .707 .577 .707 r
F P
0 g
s
.35457 .74359 m .3536 .78121 L .35506 .7799 L p .707 .577 .707 r
F P
0 g
s
.3554 .74785 m .35457 .74359 L .35506 .7799 L .707 .577 .707 r
F
.34154 .76561 m .34202 .78377 L .3551 .77624 L p F P
0 g
s
.3551 .77624 m .35836 .77436 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35514 .77269 m .34154 .76561 L .3551 .77624 L .707 .577 .707 r
F
.35836 .77436 m .35788 .7562 L .3553 .75769 L p F P
0 g
s
.3553 .75769 m .34154 .76561 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35836 .77436 m .3553 .75769 L .35514 .77269 L .707 .577 .707 r
F
.35788 .7562 m .35836 .77436 L .36542 .76396 L p F P
0 g
s
.36542 .76396 m .36493 .7458 L .35788 .7562 L p .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .36163 .73731 L .35545 .7428 L p .707 .577 .707 r
F P
0 g
s
.35545 .7428 m .35457 .74359 L p .3554 .74785 L .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .35545 .7428 L .3554 .74785 L .707 .577 .707 r
F
.35506 .7799 m .36065 .77493 L p .3554 .74785 L F P
0 g
s
.36391 .62286 m .35971 .68018 L .35661 .67715 L p .707 .577 .707 r
F P
0 g
s
.35661 .67715 m .36081 .61982 L .36391 .62286 L p .707 .577 .707 r
F P
0 g
s
.36163 .73731 m .36065 .77493 L .35773 .76827 L p .707 .577 .707 r
F P
0 g
s
.35773 .76827 m .3587 .73065 L .36163 .73731 L p .707 .577 .707 r
F P
0 g
s
.36081 .61982 m .35661 .67715 L .34386 .67363 L p .707 .577 .707 r
F P
0 g
s
.34386 .67363 m .34805 .61631 L .36081 .61982 L p .707 .577 .707 r
F P
0 g
s
.3587 .73065 m .35773 .76827 L .34512 .76187 L p .707 .577 .707 r
F P
0 g
s
.34512 .76187 m .34609 .72425 L .3587 .73065 L p .707 .577 .707 r
F P
0 g
s
.36201 .73542 m .3625 .75358 L .34988 .74424 L p .707 .577 .707 r
F P
0 g
s
.34988 .74424 m .3494 .72608 L .36201 .73542 L p .707 .577 .707 r
F P
0 g
s
.3582 .79326 m .36 .29018 L .35591 .27848 L p .707 .577 .707 r
F P
0 g
s
.36493 .7458 m .36542 .76396 L .3625 .75358 L p .707 .577 .707 r
F P
0 g
s
.3625 .75358 m .36201 .73542 L .36493 .7458 L p .707 .577 .707 r
F P
0 g
s
.36 .29018 m .3582 .79326 L .37598 .8041 L p .707 .577 .707 r
F P
0 g
s
.15937 .66737 m .16357 .61004 L .16047 .60701 L p .707 .577 .707 r
F P
0 g
s
.16047 .60701 m .15627 .66433 L .15937 .66737 L p .707 .577 .707 r
F P
0 g
s
.67134 .7555 m .67183 .77367 L .64436 .76895 L p .707 .577 .707 r
F P
0 g
s
.64436 .76895 m .64388 .75079 L .67134 .7555 L p .707 .577 .707 r
F P
0 g
s
.1607 .73616 m .15973 .77378 L .17234 .78017 L p .707 .577 .707 r
F P
0 g
s
.1771 .78412 m .17662 .76596 L .16401 .75662 L p .707 .577 .707 r
F P
0 g
s
.16401 .75662 m .16449 .77478 L .1771 .78412 L p .707 .577 .707 r
F P
0 g
s
.64377 .28441 m .64196 .78749 L .63787 .77579 L p .707 .577 .707 r
F P
0 g
s
.63787 .77579 m .63968 .27272 L .64377 .28441 L p .707 .577 .707 r
F P
0 g
s
.15973 .77378 m .1607 .73616 L .15778 .7295 L p .707 .577 .707 r
F P
0 g
s
.15627 .66433 m .16047 .60701 L .16732 .60475 L p .707 .577 .707 r
F P
0 g
s
.15778 .7295 m .15681 .76712 L .15973 .77378 L p .707 .577 .707 r
F P
0 g
s
.16732 .60475 m .16313 .66207 L .15627 .66433 L p .707 .577 .707 r
F P
0 g
s
.16449 .77478 m .16401 .75662 L .16109 .74624 L p .707 .577 .707 r
F P
0 g
s
.35591 .27848 m .35411 .78156 L .3582 .79326 L p .707 .577 .707 r
F P
0 g
s
.35411 .78156 m .35591 .27848 L .36591 .26707 L p .707 .577 .707 r
F P
0 g
s
.16109 .74624 m .16157 .7644 L .16449 .77478 L p .707 .577 .707 r
F P
0 g
s
.15681 .76712 m .15778 .7295 L .16484 .72322 L p .707 .577 .707 r
F P
0 g
s
.16313 .66207 m .16732 .60475 L .18346 .60349 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16157 .7644 m .16109 .74624 L .16703 .73748 L p .707 .577 .707 r
F P
0 g
s
.16688 .72256 m .18118 .71794 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16703 .73748 m .16815 .73584 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16157 .7644 m .16703 .73748 L .16706 .74055 L .707 .577 .707 r
F
.16719 .75262 m .18118 .71794 L .16726 .75975 L F
.16815 .73584 m .16863 .754 L .16722 .75607 L p F P
0 g
s
.16722 .75607 m .16157 .7644 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16706 .74055 m .16815 .73584 L .16722 .75607 L .707 .577 .707 r
F
.18118 .71794 m .18021 .75556 L .16726 .75975 L p F P
0 g
s
.16726 .75975 m .16387 .76084 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16484 .72322 L .16688 .72256 L p .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16688 .72256 L .16719 .75262 L .707 .577 .707 r
F
.16484 .72322 m .16387 .76084 L .15681 .76712 L p F P
0 g
s
.18346 .60349 m .17927 .66081 L .16313 .66207 L p .707 .577 .707 r
F P
0 g
s
.63968 .27272 m .63787 .77579 L .62009 .76495 L p .707 .577 .707 r
F P
0 g
s
.62009 .76495 m .6219 .26187 L .63968 .27272 L p .707 .577 .707 r
F P
0 g
s
.34805 .61631 m .34386 .67363 L .3227 .66999 L p .707 .577 .707 r
F P
0 g
s
.3227 .66999 m .32689 .61266 L .34805 .61631 L p .707 .577 .707 r
F P
0 g
s
.36411 .77015 m .36591 .26707 L .38902 .25707 L p .707 .577 .707 r
F P
0 g
s
.36591 .26707 m .36411 .77015 L .35411 .78156 L p .707 .577 .707 r
F P
0 g
s
.17927 .66081 m .18346 .60349 L .20731 .60335 L p .707 .577 .707 r
F P
0 g
s
.20731 .60335 m .20312 .66067 L .17927 .66081 L p .707 .577 .707 r
F P
0 g
s
.18021 .75556 m .18118 .71794 L .20521 .71417 L p .707 .577 .707 r
F P
0 g
s
.16863 .754 m .16815 .73584 L .18449 .72643 L p .707 .577 .707 r
F P
0 g
s
.32689 .61266 m .3227 .66999 L .2952 .66656 L p .707 .577 .707 r
F P
0 g
s
.2952 .66656 m .2994 .60924 L .32689 .61266 L p .707 .577 .707 r
F P
0 g
s
.34609 .72425 m .34512 .76187 L .32405 .75638 L p .707 .577 .707 r
F P
0 g
s
.32405 .75638 m .32502 .71876 L .34609 .72425 L p .707 .577 .707 r
F P
0 g
s
.18449 .72643 m .18497 .74459 L .16863 .754 L p .707 .577 .707 r
F P
0 g
s
.6219 .26187 m .62009 .76495 L .59037 .75602 L p .707 .577 .707 r
F P
0 g
s
.59037 .75602 m .59217 .25294 L .6219 .26187 L p .707 .577 .707 r
F P
0 g
s
.20312 .66067 m .20731 .60335 L .23653 .60434 L p .707 .577 .707 r
F P
0 g
s
.3494 .72608 m .34988 .74424 L .32882 .73685 L p .707 .577 .707 r
F P
0 g
s
.32882 .73685 m .32833 .71869 L .3494 .72608 L p .707 .577 .707 r
F P
0 g
s
.23653 .60434 m .23234 .66166 L .20312 .66067 L p .707 .577 .707 r
F P
0 g
s
.2994 .60924 m .2952 .66656 L .26407 .66369 L p .707 .577 .707 r
F P
0 g
s
.26407 .66369 m .26826 .60637 L .2994 .60924 L p .707 .577 .707 r
F P
0 g
s
.38902 .25707 m .38722 .76015 L .36411 .77015 L p .707 .577 .707 r
F P
0 g
s
.38722 .76015 m .38902 .25707 L .42298 .24946 L p .707 .577 .707 r
F P
0 g
s
.20521 .71417 m .20424 .75179 L .18021 .75556 L p .707 .577 .707 r
F P
0 g
s
.23234 .66166 m .23653 .60434 L .26826 .60637 L p .707 .577 .707 r
F P
0 g
s
.20424 .75179 m .20521 .71417 L .23457 .71228 L p .707 .577 .707 r
F P
0 g
s
.18497 .74459 m .18449 .72643 L .20852 .71895 L p .707 .577 .707 r
F P
0 g
s
.26826 .60637 m .26407 .66369 L .23234 .66166 L p .707 .577 .707 r
F P
0 g
s
.32502 .71876 m .32405 .75638 L .29659 .75232 L p .707 .577 .707 r
F P
0 g
s
.29659 .75232 m .29756 .7147 L .32502 .71876 L p .707 .577 .707 r
F P
0 g
s
.73213 .65321 m .73632 .59589 L .70519 .59302 L p .707 .577 .707 r
F P
0 g
s
.73632 .59589 m .73213 .65321 L .76386 .65524 L p .707 .577 .707 r
F P
0 g
s
.76386 .65524 m .76806 .59792 L .73632 .59589 L p .707 .577 .707 r
F P
0 g
s
.20852 .71895 m .209 .73711 L .18497 .74459 L p .707 .577 .707 r
F P
0 g
s
.76806 .59792 m .76386 .65524 L .79308 .65623 L p .707 .577 .707 r
F P
0 g
s
.79308 .65623 m .79728 .59891 L .76806 .59792 L p .707 .577 .707 r
F P
0 g
s
.70519 .59302 m .70099 .65034 L .73213 .65321 L p .707 .577 .707 r
F P
0 g
s
.70099 .65034 m .70519 .59302 L .67769 .58959 L p .707 .577 .707 r
F P
0 g
s
.73226 .68754 m .73323 .64992 L .70206 .64768 L p .707 .577 .707 r
F P
0 g
s
.73323 .64992 m .73226 .68754 L .76408 .68772 L p .707 .577 .707 r
F P
0 g
s
.76408 .68772 m .76505 .6501 L .73323 .64992 L p .707 .577 .707 r
F P
0 g
s
.32833 .71869 m .32882 .73685 L .30135 .73214 L p .707 .577 .707 r
F P
0 g
s
.30135 .73214 m .30087 .71397 L .32833 .71869 L p .707 .577 .707 r
F P
0 g
s
.76505 .6501 m .76408 .68772 L .79344 .68583 L p .707 .577 .707 r
F P
0 g
s
.79728 .59891 m .79308 .65623 L .81693 .65609 L p .707 .577 .707 r
F P
0 g
s
.79344 .68583 m .79441 .64821 L .76505 .6501 L p .707 .577 .707 r
F P
0 g
s
.59217 .25294 m .59037 .75602 L .5516 .74989 L p .707 .577 .707 r
F P
0 g
s
.5516 .74989 m .55341 .24681 L .59217 .25294 L p .707 .577 .707 r
F P
0 g
s
.67769 .58959 m .6735 .64692 L .70099 .65034 L p .707 .577 .707 r
F P
0 g
s
.70109 .68531 m .70206 .64768 L .6746 .64362 L p .707 .577 .707 r
F P
0 g
s
.70206 .64768 m .70109 .68531 L .73226 .68754 L p .707 .577 .707 r
F P
0 g
s
.23457 .71228 m .2336 .7499 L .20424 .75179 L p .707 .577 .707 r
F P
0 g
s
.29756 .7147 m .29659 .75232 L .26542 .75009 L p .707 .577 .707 r
F P
0 g
s
.26542 .75009 m .26639 .71247 L .29756 .7147 L p .707 .577 .707 r
F P
0 g
s
.81693 .65609 m .82112 .59877 L .79728 .59891 L p .707 .577 .707 r
F P
0 g
s
.2336 .7499 m .23457 .71228 L .26639 .71247 L p .707 .577 .707 r
F P
0 g
s
.209 .73711 m .20852 .71895 L .23788 .71411 L p .707 .577 .707 r
F P
0 g
s
.42117 .75254 m .42298 .24946 L .46446 .24497 L p .707 .577 .707 r
F P
0 g
s
.42298 .24946 m .42117 .75254 L .38722 .76015 L p .707 .577 .707 r
F P
0 g
s
.6746 .64362 m .67363 .68124 L .70109 .68531 L p .707 .577 .707 r
F P
0 g
s
.26639 .71247 m .26542 .75009 L .2336 .7499 L p .707 .577 .707 r
F P
0 g
s
.79441 .64821 m .79344 .68583 L .81747 .68206 L p .707 .577 .707 r
F P
0 g
s
.82112 .59877 m .81693 .65609 L .83307 .65483 L p .707 .577 .707 r
F P
0 g
s
.81747 .68206 m .81844 .64444 L .79441 .64821 L p .707 .577 .707 r
F P
0 g
s
.6735 .64692 m .67769 .58959 L .65653 .58595 L p .707 .577 .707 r
F P
0 g
s
.23788 .71411 m .23836 .73227 L .209 .73711 L p .707 .577 .707 r
F P
0 g
s
.30087 .71397 m .30135 .73214 L .27019 .73056 L p .707 .577 .707 r
F P
0 g
s
.27019 .73056 m .2697 .7124 L .30087 .71397 L p .707 .577 .707 r
F P
0 g
s
.65653 .58595 m .65234 .64327 L .6735 .64692 L p .707 .577 .707 r
F P
0 g
s
.23836 .73227 m .23788 .71411 L .2697 .7124 L p .707 .577 .707 r
F P
0 g
s
.67363 .68124 m .6746 .64362 L .65353 .63813 L p .707 .577 .707 r
F P
0 g
s
.2697 .7124 m .27019 .73056 L .23836 .73227 L p .707 .577 .707 r
F P
0 g
s
.55341 .24681 m .5516 .74989 L .5076 .74714 L p .707 .577 .707 r
F P
0 g
s
.5076 .74714 m .5094 .24406 L .55341 .24681 L p .707 .577 .707 r
F P
0 g
s
.83307 .65483 m .83727 .59751 L .82112 .59877 L p .707 .577 .707 r
F P
0 g
s
.65353 .63813 m .65256 .67575 L .67363 .68124 L p .707 .577 .707 r
F P
0 g
s
.46265 .74805 m .46446 .24497 L .5094 .24406 L p .707 .577 .707 r
F P
0 g
s
.46446 .24497 m .46265 .74805 L .42117 .75254 L p .707 .577 .707 r
F P
0 g
s
.5094 .24406 m .5076 .74714 L .46265 .74805 L p .707 .577 .707 r
F P
0 g
s
.81844 .64444 m .81747 .68206 L .83381 .67678 L p .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84184 .63288 L .84141 .63326 L p .707 .577 .707 r
F P
0 g
s
.84141 .63326 m .83478 .63916 L p .83943 .66309 L .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84141 .63326 L .83943 .66309 L .707 .577 .707 r
F
.83727 .59751 m .83509 .62724 L p .83993 .65257 L F P
0 g
s
.83381 .67678 m .83478 .63916 L .83438 .63929 L p .707 .577 .707 r
F P
0 g
s
.83381 .67678 m .83438 .63929 L .83234 .67367 L .707 .577 .707 r
F
.83478 .63916 m .83381 .67678 L .84087 .6705 L p F P
0 g
s
.83346 .6547 m .83993 .65257 L p .83509 .62724 L .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .8421 .62296 L p .83727 .59751 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .84412 .59525 L .84298 .59562 L p .707 .577 .707 r
F P
0 g
s
.84298 .59562 m .83727 .59751 L p .8421 .62296 L .707 .577 .707 r
F P
0 g
s
.84184 .63288 m .84087 .6705 L .84058 .66984 L p .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .83683 .64953 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .83993 .65257 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.84058 .66984 m .83795 .66384 L p .84175 .63357 L .707 .577 .707 r
F P
0 g
s
.84175 .63357 m .84184 .63288 L .84058 .66984 L .707 .577 .707 r
F
.84412 .59525 m .8421 .62296 L p .84375 .598 L F P
0 g
s
.83509 .62724 m .83307 .65483 L .83346 .6547 L p .707 .577 .707 r
F P
0 g
s
.83438 .63929 m .81844 .64444 L p .83234 .67367 L .707 .577 .707 r
F P
0 g
s
.65234 .64327 m .65653 .58595 L .64378 .58243 L p .707 .577 .707 r
F P
0 g
s
.73702 .78439 m .73653 .76623 L .70537 .76465 L p .707 .577 .707 r
F P
0 g
s
.73653 .76623 m .73702 .78439 L .76884 .78268 L p .707 .577 .707 r
F P
0 g
s
.76884 .78268 m .76836 .76451 L .73653 .76623 L p .707 .577 .707 r
F P
0 g
s
.76836 .76451 m .76884 .78268 L .7982 .77784 L p .707 .577 .707 r
F P
0 g
s
.7982 .77784 m .79772 .75968 L .76836 .76451 L p .707 .577 .707 r
F P
0 g
s
.64378 .58243 m .63958 .63976 L .65234 .64327 L p .707 .577 .707 r
F P
0 g
s
.65256 .67575 m .65353 .63813 L .64092 .63174 L p .707 .577 .707 r
F P
0 g
s
.70537 .76465 m .70585 .78281 L .73702 .78439 L p .707 .577 .707 r
F P
0 g
s
.70585 .78281 m .70537 .76465 L .6779 .75993 L p .707 .577 .707 r
F P
0 g
s
.64092 .63174 m .63995 .66936 L .65256 .67575 L p .707 .577 .707 r
F P
0 g
s
.6779 .75993 m .67839 .7781 L .70585 .78281 L p .707 .577 .707 r
F P
0 g
s
.79772 .75968 m .7982 .77784 L .82223 .77035 L p .707 .577 .707 r
F P
0 g
s
.82223 .77035 m .82175 .75219 L .79772 .75968 L p .707 .577 .707 r
F P
0 g
s
.67839 .7781 m .6779 .75993 L .65684 .75254 L p .707 .577 .707 r
F P
0 g
s
.63958 .63976 m .64378 .58243 L .64068 .5794 L p .707 .577 .707 r
F P
0 g
s
.65684 .75254 m .65732 .77071 L .67839 .7781 L p .707 .577 .707 r
F P
0 g
s
.64068 .5794 m .63648 .63672 L .63958 .63976 L p .707 .577 .707 r
F P
0 g
s
.63995 .66936 m .64092 .63174 L .638 .62507 L p .707 .577 .707 r
F P
0 g
s
.82175 .75219 m .82223 .77035 L .83857 .76095 L p .707 .577 .707 r
F P
0 g
s
.83857 .76095 m .83809 .74279 L .82175 .75219 L p .707 .577 .707 r
F P
0 g
s
.638 .62507 m .63702 .66269 L .63995 .66936 L p .707 .577 .707 r
F P
0 g
s
.65732 .77071 m .65684 .75254 L .64422 .7432 L p .707 .577 .707 r
F P
0 g
s
.83683 .64953 m .83913 .6181 L p .84412 .59525 L .707 .577 .707 r
F P
0 g
s
.84102 .59221 m .83683 .64953 L .82407 .64602 L p .707 .577 .707 r
F P
0 g
s
.83892 .62622 m .83795 .66384 L .83449 .66209 L p .707 .577 .707 r
F P
0 g
s
.83449 .66209 m .82534 .65745 L p .83806 .62818 L .707 .577 .707 r
F P
0 g
s
.83806 .62818 m .83892 .62622 L .83449 .66209 L .707 .577 .707 r
F
.83913 .6181 m .84102 .59221 L .84178 .59295 L p F P
0 g
s
.84178 .59295 m .84412 .59525 L p .83913 .6181 L .707 .577 .707 r
F P
0 g
s
.64422 .7432 m .64471 .76136 L .65732 .77071 L p .707 .577 .707 r
F P
0 g
s
.83795 .66384 m .83892 .62622 L .84184 .63288 L p .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .638 .62507 L .64488 .61895 L p .707 .577 .707 r
F P
0 g
s
.64536 .60688 m .64753 .57714 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.64488 .61895 m .64505 .61879 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .64488 .61895 L .64483 .61998 L .707 .577 .707 r
F
.64753 .57714 m .66368 .57588 L p .64437 .63149 L F P
0 g
s
.66368 .57588 m .65948 .6332 L .64426 .63439 L p .707 .577 .707 r
F P
0 g
s
.64437 .63149 m .66368 .57588 L .64426 .63439 L .707 .577 .707 r
F
.64505 .61879 m .64408 .65642 L .64335 .65707 L p F P
0 g
s
.64335 .65707 m .63702 .66269 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.64483 .61998 m .64505 .61879 L .64335 .65707 L .707 .577 .707 r
F
.64426 .63439 m .64334 .63446 L p .64437 .63149 L F P
0 g
s
.64334 .63446 m .64536 .60688 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.63648 .63672 m .64068 .5794 L .64753 .57714 L p .707 .577 .707 r
F P
0 g
s
.83809 .74279 m .83857 .76095 L .84563 .75055 L p .707 .577 .707 r
F P
0 g
s
.84563 .75055 m .84515 .73239 L .83809 .74279 L p .707 .577 .707 r
F P
0 g
s
.64753 .57714 m .64334 .63446 L .63648 .63672 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64471 .76136 m .64422 .7432 L .6413 .73282 L p .707 .577 .707 r
F P
0 g
s
.6413 .73282 m .64179 .75098 L .64471 .76136 L p .707 .577 .707 r
F P
0 g
s
.82407 .64602 m .82648 .61313 L p .84102 .59221 L .707 .577 .707 r
F P
0 g
s
.82827 .5887 m .82407 .64602 L .80291 .64237 L p .707 .577 .707 r
F P
0 g
s
.82631 .61983 m .82534 .65745 L .81662 .65517 L p .707 .577 .707 r
F P
0 g
s
.81662 .65517 m .80427 .65195 L p .82418 .62292 L .707 .577 .707 r
F P
0 g
s
.82418 .62292 m .82631 .61983 L .81662 .65517 L .707 .577 .707 r
F
.82648 .61313 m .82827 .5887 L .83197 .58972 L p F P
0 g
s
.83197 .58972 m .84102 .59221 L p .82648 .61313 L .707 .577 .707 r
F P
0 g
s
.82534 .65745 m .82631 .61983 L .83892 .62622 L p .707 .577 .707 r
F P
0 g
s
.38912 .61639 m .39331 .55907 L .36218 .5562 L p .707 .577 .707 r
F P
0 g
s
.39331 .55907 m .38912 .61639 L .42085 .61842 L p .707 .577 .707 r
F P
0 g
s
.42085 .61842 m .42505 .5611 L .39331 .55907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42505 .5611 m .42085 .61842 L .45007 .61941 L p .707 .577 .707 r
F P
0 g
s
.45007 .61941 m .45427 .56209 L .42505 .5611 L p .707 .577 .707 r
F P
0 g
s
.84515 .73239 m .84563 .75055 L .84271 .74017 L p .707 .577 .707 r
F P
0 g
s
.84271 .74017 m .84223 .72201 L .84515 .73239 L p .707 .577 .707 r
F P
0 g
s
.36218 .5562 m .35798 .61352 L .38912 .61639 L p .707 .577 .707 r
F P
0 g
s
.35798 .61352 m .36218 .5562 L .33468 .55278 L p .707 .577 .707 r
F P
0 g
s
.38925 .65072 m .39022 .6131 L .35905 .61087 L p .707 .577 .707 r
F P
0 g
s
.39022 .6131 m .38925 .65072 L .42107 .6509 L p .707 .577 .707 r
F P
0 g
s
.42107 .6509 m .42204 .61328 L .39022 .6131 L p .707 .577 .707 r
F P
0 g
s
.42204 .61328 m .42107 .6509 L .45043 .64902 L p .707 .577 .707 r
F P
0 g
s
.45427 .56209 m .45007 .61941 L .47392 .61927 L p .707 .577 .707 r
F P
0 g
s
.45043 .64902 m .4514 .6114 L .42204 .61328 L p .707 .577 .707 r
F P
0 g
s
.65948 .6332 m .66165 .60359 L p .68753 .57574 L .707 .577 .707 r
F P
0 g
s
.66165 .60359 m .66368 .57588 L .66503 .57587 L p .707 .577 .707 r
F P
0 g
s
.66503 .57587 m .68753 .57574 L p .66165 .60359 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .64505 .61879 L .6604 .61383 L p .707 .577 .707 r
F P
0 g
s
.6604 .61383 m .66139 .61351 L p .66003 .6169 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .6604 .61383 L .66003 .6169 L .707 .577 .707 r
F
.33468 .55278 m .33049 .6101 L .35798 .61352 L p F P
0 g
s
.35808 .64849 m .35905 .61087 L .33159 .60681 L p .707 .577 .707 r
F P
0 g
s
.35905 .61087 m .35808 .64849 L .38925 .65072 L p .707 .577 .707 r
F P
0 g
s
.47392 .61927 m .47811 .56195 L .45427 .56209 L p .707 .577 .707 r
F P
0 g
s
.68753 .57574 m .68333 .63306 L .65948 .6332 L p .707 .577 .707 r
F P
0 g
s
.66139 .61351 m .66042 .65113 L .64408 .65642 L p .707 .577 .707 r
F P
0 g
s
.64179 .75098 m .6413 .73282 L .64836 .72242 L p .707 .577 .707 r
F P
0 g
s
.33159 .60681 m .33062 .64443 L .35808 .64849 L p .707 .577 .707 r
F P
0 g
s
.4514 .6114 m .45043 .64902 L .47446 .64525 L p .707 .577 .707 r
F P
0 g
s
.47811 .56195 m .47392 .61927 L .49006 .61801 L p .707 .577 .707 r
F P
0 g
s
.47446 .64525 m .47543 .60763 L .4514 .6114 L p .707 .577 .707 r
F P
0 g
s
.33049 .6101 m .33468 .55278 L .31352 .54913 L p .707 .577 .707 r
F P
0 g
s
.80291 .64237 m .80539 .60856 L p .82827 .5887 L .707 .577 .707 r
F P
0 g
s
.80711 .58505 m .80291 .64237 L .77542 .63895 L p .707 .577 .707 r
F P
0 g
s
.80524 .61433 m .80427 .65195 L .79018 .64987 L p .707 .577 .707 r
F P
0 g
s
.79018 .64987 m .77681 .64789 L p .80174 .61846 L .707 .577 .707 r
F P
0 g
s
.80174 .61846 m .80524 .61433 L .79018 .64987 L .707 .577 .707 r
F
.80539 .60856 m .80711 .58505 L .81363 .58618 L p F P
0 g
s
.81363 .58618 m .82827 .5887 L p .80539 .60856 L .707 .577 .707 r
F P
0 g
s
.64836 .72242 m .64884 .74058 L .64179 .75098 L p .707 .577 .707 r
F P
0 g
s
.31352 .54913 m .30933 .60645 L .33049 .6101 L p .707 .577 .707 r
F P
0 g
s
.80427 .65195 m .80524 .61433 L .82631 .61983 L p .707 .577 .707 r
F P
0 g
s
.33062 .64443 m .33159 .60681 L .31052 .60131 L p .707 .577 .707 r
F P
0 g
s
.84223 .72201 m .84271 .74017 L .8301 .73083 L p .707 .577 .707 r
F P
0 g
s
.8301 .73083 m .82962 .71266 L .84223 .72201 L p .707 .577 .707 r
F P
0 g
s
.49006 .61801 m .49426 .56069 L .47811 .56195 L p .707 .577 .707 r
F P
0 g
s
.31052 .60131 m .30955 .63893 L .33062 .64443 L p .707 .577 .707 r
F P
0 g
s
.68333 .63306 m .68563 .60162 L p .71675 .57673 L .707 .577 .707 r
F P
0 g
s
.68563 .60162 m .68753 .57574 L .69199 .57589 L p .707 .577 .707 r
F P
0 g
s
.69199 .57589 m .71675 .57673 L p .68563 .60162 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .66139 .61351 L .68355 .61004 L p .707 .577 .707 r
F P
0 g
s
.68355 .61004 m .68542 .60974 L p .68238 .61478 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .68355 .61004 L .68238 .61478 L .707 .577 .707 r
F
.47543 .60763 m .47446 .64525 L .4908 .63996 L p F P
0 g
s
.49786 .63368 m .49883 .59606 L .4984 .59645 L p .707 .577 .707 r
F P
0 g
s
.4984 .59645 m .49177 .60234 L p .49642 .62627 L .707 .577 .707 r
F P
0 g
s
.49786 .63368 m .4984 .59645 L .49642 .62627 L .707 .577 .707 r
F
.49426 .56069 m .49208 .59043 L p .49692 .61575 L F P
0 g
s
.4908 .63996 m .49177 .60234 L .49137 .60248 L p .707 .577 .707 r
F P
0 g
s
.4908 .63996 m .49137 .60248 L .48933 .63686 L .707 .577 .707 r
F
.49177 .60234 m .4908 .63996 L .49786 .63368 L p F P
0 g
s
.49045 .61788 m .49692 .61575 L p .49208 .59043 L .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49908 .58614 L p .49426 .56069 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .50111 .55843 L .49997 .55881 L p .707 .577 .707 r
F P
0 g
s
.49997 .55881 m .49426 .56069 L p .49908 .58614 L .707 .577 .707 r
F P
0 g
s
.49883 .59606 m .49786 .63368 L .49757 .63303 L p .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49382 .61272 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .49692 .61575 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49757 .63303 m .49494 .62702 L p .49874 .59676 L .707 .577 .707 r
F P
0 g
s
.49874 .59676 m .49883 .59606 L .49757 .63303 L .707 .577 .707 r
F
.50111 .55843 m .49908 .58614 L p .50074 .56118 L F P
0 g
s
.49208 .59043 m .49006 .61801 L .49045 .61788 L p .707 .577 .707 r
F P
0 g
s
.49137 .60248 m .47543 .60763 L p .48933 .63686 L .707 .577 .707 r
F P
0 g
s
.71675 .57673 m .71255 .63405 L .68333 .63306 L p .707 .577 .707 r
F P
0 g
s
.68542 .60974 m .68445 .64736 L .66042 .65113 L p .707 .577 .707 r
F P
0 g
s
.30933 .60645 m .31352 .54913 L .30077 .54562 L p .707 .577 .707 r
F P
0 g
s
.39401 .74757 m .39352 .72941 L .36236 .72783 L p .707 .577 .707 r
F P
0 g
s
.39352 .72941 m .39401 .74757 L .42583 .74586 L p .707 .577 .707 r
F P
0 g
s
.42583 .74586 m .42535 .7277 L .39352 .72941 L p .707 .577 .707 r
F P
0 g
s
.77542 .63895 m .77792 .60481 L p .80711 .58505 L .707 .577 .707 r
F P
0 g
s
.77961 .58163 m .77542 .63895 L .74428 .63608 L p .707 .577 .707 r
F P
0 g
s
.77778 .61027 m .77681 .64789 L .75907 .64662 L p .707 .577 .707 r
F P
0 g
s
.75907 .64662 m .74564 .64566 L p .77317 .61534 L .707 .577 .707 r
F P
0 g
s
.77317 .61534 m .77778 .61027 L .75907 .64662 L .707 .577 .707 r
F
.77792 .60481 m .77961 .58163 L .7879 .58266 L p F P
0 g
s
.7879 .58266 m .80711 .58505 L p .77792 .60481 L .707 .577 .707 r
F P
0 g
s
.64884 .74058 m .64836 .72242 L .6647 .71302 L p .707 .577 .707 r
F P
0 g
s
.42535 .7277 m .42583 .74586 L .45519 .74102 L p .707 .577 .707 r
F P
0 g
s
.45519 .74102 m .45471 .72286 L .42535 .7277 L p .707 .577 .707 r
F P
0 g
s
.30077 .54562 m .29657 .60294 L .30933 .60645 L p .707 .577 .707 r
F P
0 g
s
.77681 .64789 m .77778 .61027 L .80524 .61433 L p .707 .577 .707 r
F P
0 g
s
.30955 .63893 m .31052 .60131 L .29791 .59492 L p .707 .577 .707 r
F P
0 g
s
.36236 .72783 m .36284 .746 L .39401 .74757 L p .707 .577 .707 r
F P
0 g
s
.36284 .746 m .36236 .72783 L .33489 .72312 L p .707 .577 .707 r
F P
0 g
s
.6647 .71302 m .66518 .73118 L .64884 .74058 L p .707 .577 .707 r
F P
0 g
s
.71255 .63405 m .71496 .60116 L p .74848 .57876 L .707 .577 .707 r
F P
0 g
s
.71496 .60116 m .71675 .57673 L .72387 .57719 L p .707 .577 .707 r
F P
0 g
s
.72387 .57719 m .74848 .57876 L p .71496 .60116 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .68542 .60974 L .71241 .60801 L p .707 .577 .707 r
F P
0 g
s
.71241 .60801 m .71478 .60786 L p .7103 .6137 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .71241 .60801 L .7103 .6137 L .707 .577 .707 r
F
.29791 .59492 m .29693 .63254 L .30955 .63893 L p F P
0 g
s
.33489 .72312 m .33538 .74128 L .36284 .746 L p .707 .577 .707 r
F P
0 g
s
.45471 .72286 m .45519 .74102 L .47922 .73354 L p .707 .577 .707 r
F P
0 g
s
.47922 .73354 m .47874 .71538 L .45471 .72286 L p .707 .577 .707 r
F P
0 g
s
.82962 .71266 m .8301 .73083 L .80903 .72344 L p .707 .577 .707 r
F P
0 g
s
.80903 .72344 m .80855 .70527 L .82962 .71266 L p .707 .577 .707 r
F P
0 g
s
.74848 .57876 m .74428 .63608 L .71255 .63405 L p .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .71478 .60786 L .74416 .60802 L p .707 .577 .707 r
F P
0 g
s
.74428 .63608 m .74676 .60226 L p .77961 .58163 L .707 .577 .707 r
F P
0 g
s
.74416 .60802 m .74661 .60804 L p .74156 .61381 L .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .74416 .60802 L .74156 .61381 L .707 .577 .707 r
F
.74676 .60226 m .74848 .57876 L .75699 .57955 L p F P
0 g
s
.75699 .57955 m .77961 .58163 L p .74676 .60226 L .707 .577 .707 r
F P
0 g
s
.71478 .60786 m .71381 .64548 L .68445 .64736 L p .707 .577 .707 r
F P
0 g
s
.74564 .64566 m .74661 .60804 L .77778 .61027 L p .707 .577 .707 r
F P
0 g
s
.33538 .74128 m .33489 .72312 L .31383 .71573 L p .707 .577 .707 r
F P
0 g
s
.74661 .60804 m .74564 .64566 L .71381 .64548 L p .707 .577 .707 r
F P
0 g
s
.66518 .73118 m .6647 .71302 L .68873 .70553 L p .707 .577 .707 r
F P
0 g
s
.29657 .60294 m .30077 .54562 L .29767 .54258 L p .707 .577 .707 r
F P
0 g
s
.31383 .71573 m .31431 .73389 L .33538 .74128 L p .707 .577 .707 r
F P
0 g
s
.29767 .54258 m .29347 .59991 L .29657 .60294 L p .707 .577 .707 r
F P
0 g
s
.68873 .70553 m .68921 .72369 L .66518 .73118 L p .707 .577 .707 r
F P
0 g
s
.29693 .63254 m .29791 .59492 L .29498 .58826 L p .707 .577 .707 r
F P
0 g
s
.47874 .71538 m .47922 .73354 L .49556 .72413 L p .707 .577 .707 r
F P
0 g
s
.49556 .72413 m .49508 .70597 L .47874 .71538 L p .707 .577 .707 r
F P
0 g
s
.80855 .70527 m .80903 .72344 L .78157 .71872 L p .707 .577 .707 r
F P
0 g
s
.78157 .71872 m .78109 .70056 L .80855 .70527 L p .707 .577 .707 r
F P
0 g
s
.29498 .58826 m .29401 .62588 L .29693 .63254 L p .707 .577 .707 r
F P
0 g
s
.31431 .73389 m .31383 .71573 L .30121 .70639 L p .707 .577 .707 r
F P
0 g
s
.68921 .72369 m .68873 .70553 L .71809 .70069 L p .707 .577 .707 r
F P
0 g
s
.49382 .61272 m .49612 .58128 L p .50111 .55843 L .707 .577 .707 r
F P
0 g
s
.49801 .5554 m .49382 .61272 L .48106 .60921 L p .707 .577 .707 r
F P
0 g
s
.49591 .5894 m .49494 .62702 L .49148 .62527 L p .707 .577 .707 r
F P
0 g
s
.49148 .62527 m .48233 .62063 L p .49505 .59137 L .707 .577 .707 r
F P
0 g
s
.49505 .59137 m .49591 .5894 L .49148 .62527 L .707 .577 .707 r
F
.49612 .58128 m .49801 .5554 L .49877 .55614 L p F P
0 g
s
.49877 .55614 m .50111 .55843 L p .49612 .58128 L .707 .577 .707 r
F P
0 g
s
.30121 .70639 m .3017 .72455 L .31431 .73389 L p .707 .577 .707 r
F P
0 g
s
.71809 .70069 m .71858 .71886 L .68921 .72369 L p .707 .577 .707 r
F P
0 g
s
.49494 .62702 m .49591 .5894 L .49883 .59606 L p .707 .577 .707 r
F P
0 g
s
.78109 .70056 m .78157 .71872 L .7504 .71714 L p .707 .577 .707 r
F P
0 g
s
.7504 .71714 m .74992 .69898 L .78109 .70056 L p .707 .577 .707 r
F P
0 g
s
.71858 .71886 m .71809 .70069 L .74992 .69898 L p .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .29498 .58826 L .30186 .58214 L p .707 .577 .707 r
F P
0 g
s
.30235 .57006 m .30452 .54033 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.30186 .58214 m .30204 .58198 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .30186 .58214 L .30182 .58317 L .707 .577 .707 r
F
.30452 .54033 m .32067 .53906 L p .30136 .59467 L F P
0 g
s
.32067 .53906 m .31647 .59639 L .30125 .59758 L p .707 .577 .707 r
F P
0 g
s
.30136 .59467 m .32067 .53906 L .30125 .59758 L .707 .577 .707 r
F
.30204 .58198 m .30107 .6196 L .30034 .62025 L p F P
0 g
s
.30034 .62025 m .29401 .62588 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.30182 .58317 m .30204 .58198 L .30034 .62025 L .707 .577 .707 r
F
.30125 .59758 m .30033 .59765 L p .30136 .59467 L F P
0 g
s
.30033 .59765 m .30235 .57006 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.29347 .59991 m .29767 .54258 L .30452 .54033 L p .707 .577 .707 r
F P
0 g
s
.49508 .70597 m .49556 .72413 L .50262 .71373 L p .707 .577 .707 r
F P
0 g
s
.50262 .71373 m .50214 .69557 L .49508 .70597 L p .707 .577 .707 r
F P
0 g
s
.74992 .69898 m .7504 .71714 L .71858 .71886 L p .707 .577 .707 r
F P
0 g
s
.30452 .54033 m .30033 .59765 L .29347 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3017 .72455 m .30121 .70639 L .29829 .69601 L p .707 .577 .707 r
F P
0 g
s
.29829 .69601 m .29878 .71417 L .3017 .72455 L p .707 .577 .707 r
F P
0 g
s
.48106 .60921 m .48347 .57632 L p .49801 .5554 L .707 .577 .707 r
F P
0 g
s
.48526 .55189 m .48106 .60921 L .4599 .60556 L p .707 .577 .707 r
F P
0 g
s
.4833 .58301 m .48233 .62063 L .47361 .61836 L p .707 .577 .707 r
F P
0 g
s
.47361 .61836 m .46126 .61514 L p .48117 .5861 L .707 .577 .707 r
F P
0 g
s
.48117 .5861 m .4833 .58301 L .47361 .61836 L .707 .577 .707 r
F
.48347 .57632 m .48526 .55189 L .48896 .55291 L p F P
0 g
s
.48896 .55291 m .49801 .5554 L p .48347 .57632 L .707 .577 .707 r
F P
0 g
s
.48233 .62063 m .4833 .58301 L .49591 .5894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50214 .69557 m .50262 .71373 L .4997 .70335 L p .707 .577 .707 r
F P
0 g
s
.4997 .70335 m .49922 .68519 L .50214 .69557 L p .707 .577 .707 r
F P
0 g
s
.31647 .59639 m .31864 .56678 L p .34451 .53892 L .707 .577 .707 r
F P
0 g
s
.31864 .56678 m .32067 .53906 L .32202 .53906 L p .707 .577 .707 r
F P
0 g
s
.32202 .53906 m .34451 .53892 L p .31864 .56678 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .30204 .58198 L .31739 .57702 L p .707 .577 .707 r
F P
0 g
s
.31739 .57702 m .31838 .5767 L p .31702 .58008 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .31739 .57702 L .31702 .58008 L .707 .577 .707 r
F
.34451 .53892 m .34032 .59624 L .31647 .59639 L p F P
0 g
s
.31838 .5767 m .31741 .61432 L .30107 .6196 L p .707 .577 .707 r
F P
0 g
s
.29878 .71417 m .29829 .69601 L .30535 .68561 L p .707 .577 .707 r
F P
0 g
s
.4599 .60556 m .46238 .57174 L p .48526 .55189 L .707 .577 .707 r
F P
0 g
s
.4641 .54824 m .4599 .60556 L .43241 .60213 L p .707 .577 .707 r
F P
0 g
s
.46223 .57752 m .46126 .61514 L .44717 .61305 L p .707 .577 .707 r
F P
0 g
s
.44717 .61305 m .43379 .61107 L p .45873 .58164 L .707 .577 .707 r
F P
0 g
s
.45873 .58164 m .46223 .57752 L .44717 .61305 L .707 .577 .707 r
F
.46238 .57174 m .4641 .54824 L .47062 .54936 L p F P
0 g
s
.47062 .54936 m .48526 .55189 L p .46238 .57174 L .707 .577 .707 r
F P
0 g
s
.30535 .68561 m .30583 .70377 L .29878 .71417 L p .707 .577 .707 r
F P
0 g
s
.46126 .61514 m .46223 .57752 L .4833 .58301 L p .707 .577 .707 r
F P
0 g
s
.49922 .68519 m .4997 .70335 L .48709 .69401 L p .707 .577 .707 r
F P
0 g
s
.48709 .69401 m .48661 .67585 L .49922 .68519 L p .707 .577 .707 r
F P
0 g
s
.34032 .59624 m .34262 .56481 L p .37373 .53992 L .707 .577 .707 r
F P
0 g
s
.34262 .56481 m .34451 .53892 L .34898 .53907 L p .707 .577 .707 r
F P
0 g
s
.34898 .53907 m .37373 .53992 L p .34262 .56481 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .31838 .5767 L .34054 .57322 L p .707 .577 .707 r
F P
0 g
s
.34054 .57322 m .34241 .57293 L p .33937 .57796 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .34054 .57322 L .33937 .57796 L .707 .577 .707 r
F
.37373 .53992 m .36954 .59724 L .34032 .59624 L p F P
0 g
s
.34241 .57293 m .34144 .61055 L .31741 .61432 L p .707 .577 .707 r
F P
0 g
s
.43241 .60213 m .43491 .56799 L p .4641 .54824 L .707 .577 .707 r
F P
0 g
s
.4366 .54481 m .43241 .60213 L .40127 .59927 L p .707 .577 .707 r
F P
0 g
s
.43477 .57345 m .43379 .61107 L .41606 .6098 L p .707 .577 .707 r
F P
0 g
s
.41606 .6098 m .40263 .60884 L p .43016 .57853 L .707 .577 .707 r
F P
0 g
s
.43016 .57853 m .43477 .57345 L .41606 .6098 L .707 .577 .707 r
F
.43491 .56799 m .4366 .54481 L .44489 .54585 L p F P
0 g
s
.44489 .54585 m .4641 .54824 L p .43491 .56799 L .707 .577 .707 r
F P
0 g
s
.30583 .70377 m .30535 .68561 L .32169 .6762 L p .707 .577 .707 r
F P
0 g
s
.43379 .61107 m .43477 .57345 L .46223 .57752 L p .707 .577 .707 r
F P
0 g
s
.32169 .6762 m .32217 .69436 L .30583 .70377 L p .707 .577 .707 r
F P
0 g
s
.36954 .59724 m .37195 .56435 L p .40547 .54195 L .707 .577 .707 r
F P
0 g
s
.37195 .56435 m .37373 .53992 L .38086 .54037 L p .707 .577 .707 r
F P
0 g
s
.38086 .54037 m .40547 .54195 L p .37195 .56435 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .34241 .57293 L .3694 .57119 L p .707 .577 .707 r
F P
0 g
s
.3694 .57119 m .37177 .57104 L p .36729 .57689 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .3694 .57119 L .36729 .57689 L .707 .577 .707 r
F
.48661 .67585 m .48709 .69401 L .46602 .68662 L p F P
0 g
s
.46602 .68662 m .46554 .66846 L .48661 .67585 L p .707 .577 .707 r
F P
0 g
s
.40547 .54195 m .40127 .59927 L .36954 .59724 L p .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .37177 .57104 L .40115 .57121 L p .707 .577 .707 r
F P
0 g
s
.40127 .59927 m .40375 .56545 L p .4366 .54481 L .707 .577 .707 r
F P
0 g
s
.40115 .57121 m .4036 .57122 L p .39855 .57699 L .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .40115 .57121 L .39855 .57699 L .707 .577 .707 r
F
.40375 .56545 m .40547 .54195 L .41398 .54273 L p F P
0 g
s
.41398 .54273 m .4366 .54481 L p .40375 .56545 L .707 .577 .707 r
F P
0 g
s
.37177 .57104 m .3708 .60866 L .34144 .61055 L p .707 .577 .707 r
F P
0 g
s
.40263 .60884 m .4036 .57122 L .43477 .57345 L p .707 .577 .707 r
F P
0 g
s
.4036 .57122 m .40263 .60884 L .3708 .60866 L p .707 .577 .707 r
F P
0 g
s
.32217 .69436 m .32169 .6762 L .34572 .66872 L p .707 .577 .707 r
F P
0 g
s
.34572 .66872 m .3462 .68688 L .32217 .69436 L p .707 .577 .707 r
F P
0 g
s
.46554 .66846 m .46602 .68662 L .43856 .6819 L p .707 .577 .707 r
F P
0 g
s
.43856 .6819 m .43808 .66374 L .46554 .66846 L p .707 .577 .707 r
F P
0 g
s
.3462 .68688 m .34572 .66872 L .37508 .66388 L p .707 .577 .707 r
F P
0 g
s
.37508 .66388 m .37557 .68204 L .3462 .68688 L p .707 .577 .707 r
F P
0 g
s
.43808 .66374 m .43856 .6819 L .40739 .68033 L p .707 .577 .707 r
F P
0 g
s
.40739 .68033 m .40691 .66217 L .43808 .66374 L p .707 .577 .707 r
F P
0 g
s
.37557 .68204 m .37508 .66388 L .40691 .66217 L p .707 .577 .707 r
F P
0 g
s
.40691 .66217 m .40739 .68033 L .37557 .68204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005IooaX000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0`002UYF00<005YFFUH0
1UYF00<005YFFUH00eYF3@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH0000:FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol005Aoo`03001JEP0000YJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF1@000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0P0015YF00<005YFFUH0
0eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001COol00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005=oo`03001JEP0000AJEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool=001EOol005=oo`03001JEP00009JEPH000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUIJEP04
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600000eYF001J
EP05FUH00`00FUIJEP02FUHB0013Ool005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH8000kOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP00
02eoo`00;goo6@002goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP80
00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF0P000UYF20000eYF0P001eYF0P0015YF20000eYF0P0015YF0P000UYF0P00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH60007FUH01000FUIJEUYF4P0000=JEP0000001P0015YF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEPD000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH20002FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF001JEUYF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP05001JEUYFFUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00
0000;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<0
02eoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4`000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00UYF200035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00@005YFFUIJER<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP0B0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH50004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF0P00;Goo
000/Ool00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo1@001EYF00<005YFFUH0
1EYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEP0001@000EJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP03001JEUYF00D0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000]Ool002moo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000]Ool003=oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool003Yoo`T000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00@goo2@0015YF00<005YF
FUH01EYF0P0000=JEP00FUH01EYF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1`0015YF00<0
05YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF1000<Woo001<Ool<0003FUH00`00
FUIJEP04FUH00`00FUIJEP040005FUH50004FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Woo001EOol20004FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP08
FUH40004FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000AooaL003Yoo`00EGoo0P0015YF
00<005YF00000`000goo00@005YFFUH000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001DOol00`00FUH00004FUH20007Ool01000
FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P000UYF0P0000=JEP00FUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YF
FUIJEP0005Eoo`00E7oo00<005YF00000UYF0P002Goo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00EJEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000Uoo`T004=oo`00E7oo
00<005YF00000P002goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00=JEP03001JEUYF00/000AJEP03001JEUYF009JEPP003]oo`00E7oo00<005YF0000
3Goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00IJEP05001JEP00
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0003FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=Woo001DOol3000=Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF0P0000AJEP00FUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000cOol003mooa8000=o
o`800003FUH0000000]oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH200001UYF001JEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000aOol003Moo`P00003FUH0000000H000AJEP03001JEUYF009J
EPD000=JEP8000Uoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF
0P000eYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P00<7oo000bOol50003FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH000030005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF100000=JEP00
FUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH01EYF00<005YFFUH00UYF3@001Goo20000eYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Woo100000AJEP00FUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEUYFFUH00004FUH500001Goo001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF
1P001EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF009JEPH000Qoo`D000eoo`D000AJEP05001J
EUYFFUH0000]Ool002eoo`8000AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF2@0015YF00<005YF
FUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEP00008000ioo`D0019oo`<00003FUH005YF009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF0`0000=J
EP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJ
EP80019oo`<001Ioo`8000=JEP8002aoo`00;7oo00@005YF001JEP80009JEP03001JEUYF00AJEP03
001JEUYF009JEPP000=JEP03001JEUYF00=JEPX000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH2000_Ool00`00FUIJEP02000/
Ool002aoo`04001JEP000004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000015YF00000000<Woo1000;7oo000/Ool01000FUH0000015YF00<005YF00001000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00Ool0=Goo0P00;7oo000/Ool01000FUH00000
15YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00=Goo
1000;7oo000/Ool01000FUH000000UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00005`000UYF60001UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF1@00<Goo0P0000AJEP00FUH002aoo`00;7oo00<005YF
00000`0000=JEP00FUH00UYF7`001UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF2@002eYF00<005YFFUH02EYF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000UYF00<007ooOol0:goo0`000eYF00<005YF0000;7oo000/Ool01000FUH000000eYF1@001eYF
00@005YFFUIJEQL0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF
009JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001JEUYF
009JEP<0009JEPH002Ioo`800003FUH005YF00=JEP8002eoo`00;7oo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1P000eYF00<005YF
00000UYF00<005YFFUH015YF00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P0000AJ
EP000000025oo`8000=JEP03001JEUYF009JEP8002eoo`00;7oo00<005YF00000`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000EJ
EP00FUIJEP0000EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP<00003FUH005YF00=JEP<0009JEP03001JEUYF009JEPH001Yoo`D0
00EJEP03001JEUYF009JEP03001oogoo02aoo`00;7oo0`000UYF0`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YF0000
0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00@005YF000000AJEP@00003FUH005YF00AJEP04001JEUYFFUHK0003FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool002aoo`<000=JEP03001JEP00008000QJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00005FUH005YFFUH00002FUH200000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF1P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo000/Ool30003FUH00`00FUIJEP02FUH30004FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH40005FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP@000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8003=oo`00;Goo0P000eYF00<005YFFUH00eYF00<0
05YF0000100025YF1@0015YF00@005YFFUIJEP@0009JEP03001JEUYF00AJEP03001JEUYF008000AJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000eOol002moo`800003FUH005YF
00AJEP03001JEUYF00=JEQH000IJEP03001JEUYF00AJEPD000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP000006FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH5000iOol0035oo`8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001J
EUYF00IJEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006
FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP02FUH9000nOol003=oo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEP0000D0009oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH01@00FUH00000FUH00P000goo
2@00Agoo000eOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`00Dgoo000gOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000<Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH6
0004FUH01000FUIJEUYF0`00Dgoo000lOolI000AOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP02FUH300000eYF001JEP02FUH3001COol006Qoo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP<005=oo`00JWoo0P001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP8000MJEP03001JEUYF00AJEP80009JEP@005Aoo`00K7oo0`0015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0007FUH0
0`00FUIJEP0400000eYF001JEP03FUH2001DOol006moo`<00003FUH005YF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD000=JEP03001JEUYF00=JEPD000EJ
EP03001JEUYF00=JEP03001oogoo059oo`00LWoo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH0200000=JEP0000001`000eYF00<005YFFUH015YF00@005YFFUIJ
EP8005Eoo`00NGoo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF4@0015YF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000P00EWoo0024OolJ0003FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH4001HOol009Eoo`<00003FUH005YF00IJEP03001JEUYF00IJEP<0
00IJEP03001JEUYF00EJEP03001JEP0000D005Yoo`00V7oo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00Ggoo002MOol90004FUH00`00FUIJEP02FUH9001UOol00:Ioo`T0
06ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57054 .63648 m .56383 .69376 L .59491 .69724 L p .707 .577 .707 r
F P
0 g
s
.59491 .69724 m .60162 .63995 L .57054 .63648 L p .707 .577 .707 r
F P
0 g
s
.60162 .63995 m .59491 .69724 L .62647 .70102 L p .707 .577 .707 r
F P
0 g
s
.62647 .70102 m .63319 .64374 L .60162 .63995 L p .707 .577 .707 r
F P
0 g
s
.63319 .64374 m .62647 .70102 L .65543 .70475 L p .707 .577 .707 r
F P
0 g
s
.65543 .70475 m .66215 .64747 L .63319 .64374 L p .707 .577 .707 r
F P
0 g
s
.54299 .63366 m .53628 .69094 L .56383 .69376 L p .707 .577 .707 r
F P
0 g
s
.56383 .69376 m .57054 .63648 L .54299 .63366 L p .707 .577 .707 r
F P
0 g
s
.66215 .64747 m .65543 .70475 L .67895 .70806 L p .707 .577 .707 r
F P
0 g
s
.67895 .70806 m .68567 .65077 L .66215 .64747 L p .707 .577 .707 r
F P
0 g
s
.52167 .63177 m .51495 .68905 L .53628 .69094 L p .707 .577 .707 r
F P
0 g
s
.53628 .69094 m .54299 .63366 L .52167 .63177 L p .707 .577 .707 r
F P
0 g
s
.59447 .84038 m .59604 .8025 L .56488 .80006 L p .707 .577 .707 r
F P
0 g
s
.59604 .8025 m .59447 .84038 L .62627 .84116 L p .707 .577 .707 r
F P
0 g
s
.62627 .84116 m .62784 .80328 L .59604 .8025 L p .707 .577 .707 r
F P
0 g
s
.62784 .80328 m .62627 .84116 L .6556 .84021 L p .707 .577 .707 r
F P
0 g
s
.6556 .84021 m .65717 .80233 L .62784 .80328 L p .707 .577 .707 r
F P
0 g
s
.68567 .65077 m .67895 .70806 L .69473 .71062 L p .707 .577 .707 r
F P
0 g
s
.56488 .80006 m .56331 .83795 L .59447 .84038 L p .707 .577 .707 r
F P
0 g
s
.56331 .83795 m .56488 .80006 L .53741 .79621 L p .707 .577 .707 r
F P
0 g
s
.69473 .71062 m .70144 .65333 L .68567 .65077 L p .707 .577 .707 r
F P
0 g
s
.53741 .79621 m .53584 .83409 L .56331 .83795 L p .707 .577 .707 r
F P
0 g
s
.50865 .63099 m .50193 .68828 L .51495 .68905 L p .707 .577 .707 r
F P
0 g
s
.51495 .68905 m .52167 .63177 L .50865 .63099 L p .707 .577 .707 r
F P
0 g
s
.60217 .82398 m .60139 .80608 L .57023 .8047 L p .707 .577 .707 r
F P
0 g
s
.60139 .80608 m .60217 .82398 L .63397 .8217 L p .707 .577 .707 r
F P
0 g
s
.63397 .8217 m .63319 .8038 L .60139 .80608 L p .707 .577 .707 r
F P
0 g
s
.65717 .80233 m .6556 .84021 L .67959 .83762 L p .707 .577 .707 r
F P
0 g
s
.67959 .83762 m .68116 .79973 L .65717 .80233 L p .707 .577 .707 r
F P
0 g
s
.63319 .8038 m .63397 .8217 L .66331 .81597 L p .707 .577 .707 r
F P
0 g
s
.66331 .81597 m .66253 .79808 L .63319 .8038 L p .707 .577 .707 r
F P
0 g
s
.57101 .8226 m .57023 .8047 L .54276 .79979 L p .707 .577 .707 r
F P
0 g
s
.57023 .8047 m .57101 .8226 L .60217 .82398 L p .707 .577 .707 r
F P
0 g
s
.53584 .83409 m .53741 .79621 L .51632 .79131 L p .707 .577 .707 r
F P
0 g
s
.68116 .79973 m .67959 .83762 L .69589 .83364 L p .707 .577 .707 r
F P
0 g
s
.69589 .83364 m .69746 .79575 L .68116 .79973 L p .707 .577 .707 r
F P
0 g
s
.66253 .79808 m .66331 .81597 L .6873 .80737 L p .707 .577 .707 r
F P
0 g
s
.6873 .80737 m .68652 .78948 L .66253 .79808 L p .707 .577 .707 r
F P
0 g
s
.54276 .79979 m .54354 .81769 L .57101 .8226 L p .707 .577 .707 r
F P
0 g
s
.51632 .79131 m .51475 .82919 L .53584 .83409 L p .707 .577 .707 r
F P
0 g
s
.70144 .65333 m .69473 .71062 L .70122 .71219 L p .707 .577 .707 r
F P
0 g
s
.70122 .71219 m .70794 .6549 L .70144 .65333 L p .707 .577 .707 r
F P
0 g
s
.54354 .81769 m .54276 .79979 L .52167 .79183 L p .707 .577 .707 r
F P
0 g
s
.50522 .63141 m .49851 .68869 L .50193 .68828 L p .707 .577 .707 r
F P
0 g
s
.50193 .68828 m .50865 .63099 L .50522 .63141 L p .707 .577 .707 r
F P
0 g
s
.52167 .79183 m .52245 .80973 L .54354 .81769 L p .707 .577 .707 r
F P
0 g
s
.51475 .82919 m .51632 .79131 L .50368 .78585 L p .707 .577 .707 r
F P
0 g
s
.69746 .79575 m .69589 .83364 L .69861 .83171 L p .707 .577 .707 r
F P
0 g
s
.69861 .83171 m .7029 .82866 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.69906 .8054 m .69746 .79575 L .69861 .83171 L .707 .577 .707 r
F
.69915 .79963 m .7036 .79673 L p .69923 .79488 L F P
0 g
s
.7036 .79673 m .70282 .77884 L .69947 .78102 L p .707 .577 .707 r
F P
0 g
s
.7036 .79673 m .69947 .78102 L .69923 .79488 L .707 .577 .707 r
F
.70282 .77884 m .7036 .79673 L .71061 .78509 L p F P
0 g
s
.7029 .82866 m .70447 .79078 L .69924 .79449 L p .707 .577 .707 r
F P
0 g
s
.69924 .79449 m .69746 .79575 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.7029 .82866 m .69924 .79449 L .69906 .8054 L .707 .577 .707 r
F
.69947 .78102 m .68652 .78948 L p .69923 .79488 L F P
0 g
s
.68652 .78948 m .6873 .80737 L .69915 .79963 L p .707 .577 .707 r
F P
0 g
s
.69923 .79488 m .68652 .78948 L .69915 .79963 L .707 .577 .707 r
F
.50368 .78585 m .50211 .82374 L .51475 .82919 L p F P
0 g
s
.52245 .80973 m .52167 .79183 L .50903 .78161 L p .707 .577 .707 r
F P
0 g
s
.70794 .6549 m .70122 .71219 L .69779 .7126 L p .707 .577 .707 r
F P
0 g
s
.69779 .7126 m .70451 .65531 L .70794 .6549 L p .707 .577 .707 r
F P
0 g
s
.50903 .78161 m .50981 .7995 L .52245 .80973 L p .707 .577 .707 r
F P
0 g
s
.48726 .82194 m .49019 .31815 L .44618 .31537 L p .707 .577 .707 r
F P
0 g
s
.50211 .82374 m .50368 .78585 L .50072 .78037 L p .707 .577 .707 r
F P
0 g
s
.51171 .63297 m .505 .69026 L .49851 .68869 L p .707 .577 .707 r
F P
0 g
s
.49851 .68869 m .50522 .63141 L .51171 .63297 L p .707 .577 .707 r
F P
0 g
s
.50072 .78037 m .49915 .81825 L .50211 .82374 L p .707 .577 .707 r
F P
0 g
s
.50981 .7995 m .50903 .78161 L .50607 .77011 L p .707 .577 .707 r
F P
0 g
s
.50607 .77011 m .50685 .788 L .50981 .7995 L p .707 .577 .707 r
F P
0 g
s
.52749 .63553 m .52078 .69282 L .505 .69026 L p .707 .577 .707 r
F P
0 g
s
.505 .69026 m .51171 .63297 L .52749 .63553 L p .707 .577 .707 r
F P
0 g
s
.50685 .788 m .50607 .77011 L .51164 .76086 L p .707 .577 .707 r
F P
0 g
s
.51164 .76086 m .51308 .75847 L p .51171 .76497 L .707 .577 .707 r
F P
0 g
s
.50685 .788 m .51164 .76086 L .51171 .76497 L .707 .577 .707 r
F
.51187 .77438 m .52403 .77141 L p .51227 .79895 L F P
0 g
s
.51308 .75847 m .51386 .77637 L .50685 .788 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .50773 .77539 L .51187 .77438 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .51187 .77438 L .51227 .79895 L .707 .577 .707 r
F
.49915 .81825 m .50072 .78037 L .50773 .77539 L p F P
0 g
s
.50773 .77539 m .50616 .81327 L .49915 .81825 L p .707 .577 .707 r
F P
0 g
s
.55101 .63884 m .5443 .69613 L .52078 .69282 L p .707 .577 .707 r
F P
0 g
s
.52078 .69282 m .52749 .63553 L .55101 .63884 L p .707 .577 .707 r
F P
0 g
s
.52403 .77141 m .52246 .80929 L .50616 .81327 L p .707 .577 .707 r
F P
0 g
s
.51386 .77637 m .51308 .75847 L .52938 .74783 L p .707 .577 .707 r
F P
0 g
s
.52938 .74783 m .53016 .76573 L .51386 .77637 L p .707 .577 .707 r
F P
0 g
s
.52246 .80929 m .52403 .77141 L .54802 .76882 L p .707 .577 .707 r
F P
0 g
s
.54802 .76882 m .54645 .8067 L .52246 .80929 L p .707 .577 .707 r
F P
0 g
s
.49019 .31815 m .48726 .82194 L .53221 .82114 L p .707 .577 .707 r
F P
0 g
s
.53016 .76573 m .52938 .74783 L .55337 .73923 L p .707 .577 .707 r
F P
0 g
s
.55337 .73923 m .55415 .75712 L .53016 .76573 L p .707 .577 .707 r
F P
0 g
s
.53221 .82114 m .53513 .31735 L .49019 .31815 L p .707 .577 .707 r
F P
0 g
s
.71061 .78509 m .70983 .7672 L .70282 .77884 L p .707 .577 .707 r
F P
0 g
s
.57997 .64257 m .57325 .69986 L .5443 .69613 L p .707 .577 .707 r
F P
0 g
s
.5443 .69613 m .55046 .64356 L p .57997 .64257 L .707 .577 .707 r
F P
0 g
s
.55046 .64356 m .55101 .63884 L .55282 .63907 L p .707 .577 .707 r
F P
0 g
s
.55282 .63907 m .57997 .64257 L p .55046 .64356 L .707 .577 .707 r
F P
0 g
s
.61153 .64636 m .60482 .70364 L .57627 .70022 L p .707 .577 .707 r
F P
0 g
s
.57627 .70022 m .57325 .69986 L p .57734 .69415 L .707 .577 .707 r
F P
0 g
s
.57734 .69415 m .61153 .64636 L .57627 .70022 L .707 .577 .707 r
F
.64261 .64983 m .6359 .70712 L .61057 .70428 L p F P
0 g
s
.61057 .70428 m .60482 .70364 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.61127 .69446 m .64261 .64983 L .61057 .70428 L .707 .577 .707 r
F
.67017 .65265 m .66345 .70994 L .6359 .70712 L p F P
0 g
s
.6359 .70712 m .64261 .64983 L .67017 .65265 L p .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61153 .64636 L .61466 .6467 L p .707 .577 .707 r
F P
0 g
s
.61466 .6467 m .64261 .64983 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61466 .6467 L .61127 .69446 L .707 .577 .707 r
F
.63874 .80896 m .64031 .77108 L .66778 .77494 L p F P
0 g
s
.64567 .73261 m .64645 .7505 L .61529 .74912 L p .707 .577 .707 r
F P
0 g
s
.61529 .74912 m .61451 .73123 L .64567 .73261 L p .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64367 .28475 L .64008 .28876 L p .707 .577 .707 r
F P
0 g
s
.64008 .28876 m .63367 .2959 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64008 .28876 L .63466 .36497 L .707 .577 .707 r
F
.64031 .77108 m .63874 .80896 L .60758 .80653 L p F P
0 g
s
.60758 .80653 m .60915 .76864 L .64031 .77108 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .64075 .78854 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63367 .2959 m .63315 .38633 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63315 .38633 m .63075 .7997 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.57578 .80575 m .57735 .76786 L .60915 .76864 L p .707 .577 .707 r
F P
0 g
s
.60915 .76864 m .60758 .80653 L .57578 .80575 L p .707 .577 .707 r
F P
0 g
s
.58348 .7514 m .5827 .73351 L .61451 .73123 L p .707 .577 .707 r
F P
0 g
s
.61451 .73123 m .61529 .74912 L .58348 .7514 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .63075 .7997 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.61056 .30566 m .60937 .51188 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.57325 .69986 m .57997 .64257 L .61153 .64636 L p .707 .577 .707 r
F P
0 g
s
.60937 .51188 m .60764 .80945 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.54645 .8067 m .54802 .76882 L .57735 .76786 L p .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .55337 .73923 L .56591 .73678 L p .707 .577 .707 r
F P
0 g
s
.56591 .73678 m .5827 .73351 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .56591 .73678 L .56796 .7457 L .707 .577 .707 r
F
.57735 .76786 m .57578 .80575 L .54645 .8067 L p F P
0 g
s
.5827 .73351 m .58348 .7514 L .56988 .75405 L p .707 .577 .707 r
F P
0 g
s
.56988 .75405 m .55415 .75712 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.56796 .7457 m .5827 .73351 L .56988 .75405 L .707 .577 .707 r
F
.57496 .59696 m .57395 .77173 L p .5923 .56399 L F P
0 g
s
.57395 .77173 m .57369 .81684 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.5923 .56399 m .57395 .77173 L .57627 .7818 L .707 .577 .707 r
F
.60764 .80945 m .5923 .56399 L .57627 .7818 L F
.57369 .81684 m .58382 .81463 L p .57627 .7818 L F P
0 g
s
.58382 .81463 m .60764 .80945 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.57661 .31305 m .57496 .59696 L p .5923 .56399 L .707 .577 .707 r
F P
0 g
s
.53513 .31735 m .53221 .82114 L .57369 .81684 L p .707 .577 .707 r
F P
0 g
s
.57369 .81684 m .57661 .31305 L .53513 .31735 L p .707 .577 .707 r
F P
0 g
s
.44326 .81916 m .44618 .31537 L .40741 .30927 L p .707 .577 .707 r
F P
0 g
s
.44618 .31537 m .44326 .81916 L .48726 .82194 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .61056 .30566 L .57661 .31305 L p .707 .577 .707 r
F P
0 g
s
.70447 .79078 m .7029 .82866 L .69994 .82317 L p .707 .577 .707 r
F P
0 g
s
.69994 .82317 m .70151 .78529 L .70447 .79078 L p .707 .577 .707 r
F P
0 g
s
.70451 .65531 m .69779 .7126 L .68478 .71183 L p .707 .577 .707 r
F P
0 g
s
.68478 .71183 m .69149 .65454 L .70451 .65531 L p .707 .577 .707 r
F P
0 g
s
.22754 .59966 m .22082 .65695 L .2519 .66042 L p .707 .577 .707 r
F P
0 g
s
.2519 .66042 m .25861 .60313 L .22754 .59966 L p .707 .577 .707 r
F P
0 g
s
.25861 .60313 m .2519 .66042 L .28346 .66421 L p .707 .577 .707 r
F P
0 g
s
.28346 .66421 m .29018 .60692 L .25861 .60313 L p .707 .577 .707 r
F P
0 g
s
.70983 .7672 m .71061 .78509 L .70765 .7736 L p .707 .577 .707 r
F P
0 g
s
.70765 .7736 m .70687 .75571 L .70983 .7672 L p .707 .577 .707 r
F P
0 g
s
.40449 .81306 m .40741 .30927 L .37769 .30045 L p .707 .577 .707 r
F P
0 g
s
.40741 .30927 m .40449 .81306 L .44326 .81916 L p .707 .577 .707 r
F P
0 g
s
.29018 .60692 m .28346 .66421 L .31242 .66794 L p .707 .577 .707 r
F P
0 g
s
.31242 .66794 m .31914 .61065 L .29018 .60692 L p .707 .577 .707 r
F P
0 g
s
.19998 .59684 m .19327 .65413 L .22082 .65695 L p .707 .577 .707 r
F P
0 g
s
.22082 .65695 m .22754 .59966 L .19998 .59684 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31914 .61065 m .31242 .66794 L .33594 .67124 L p .707 .577 .707 r
F P
0 g
s
.33594 .67124 m .34266 .61396 L .31914 .61065 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .63367 .2959 L .61056 .30566 L p .707 .577 .707 r
F P
0 g
s
.17866 .59495 m .17194 .65224 L .19327 .65413 L p .707 .577 .707 r
F P
0 g
s
.19327 .65413 m .19998 .59684 L .17866 .59495 L p .707 .577 .707 r
F P
0 g
s
.69149 .65454 m .68478 .71183 L .66345 .70994 L p .707 .577 .707 r
F P
0 g
s
.70151 .78529 m .69994 .82317 L .6873 .81772 L p .707 .577 .707 r
F P
0 g
s
.6873 .81772 m .68887 .77983 L .70151 .78529 L p .707 .577 .707 r
F P
0 g
s
.66345 .70994 m .67017 .65265 L .69149 .65454 L p .707 .577 .707 r
F P
0 g
s
.70687 .75571 m .70765 .7736 L .69501 .76337 L p .707 .577 .707 r
F P
0 g
s
.69501 .76337 m .69423 .74548 L .70687 .75571 L p .707 .577 .707 r
F P
0 g
s
.25146 .80357 m .25303 .76569 L .22187 .76325 L p .707 .577 .707 r
F P
0 g
s
.25303 .76569 m .25146 .80357 L .28326 .80435 L p .707 .577 .707 r
F P
0 g
s
.28326 .80435 m .28483 .76647 L .25303 .76569 L p .707 .577 .707 r
F P
0 g
s
.37477 .80424 m .37769 .30045 L .35991 .28979 L p .707 .577 .707 r
F P
0 g
s
.37769 .30045 m .37477 .80424 L .40449 .81306 L p .707 .577 .707 r
F P
0 g
s
.28483 .76647 m .28326 .80435 L .3126 .8034 L p .707 .577 .707 r
F P
0 g
s
.3126 .8034 m .31416 .76551 L .28483 .76647 L p .707 .577 .707 r
F P
0 g
s
.34266 .61396 m .33594 .67124 L .35172 .67381 L p .707 .577 .707 r
F P
0 g
s
.22187 .76325 m .2203 .80113 L .25146 .80357 L p .707 .577 .707 r
F P
0 g
s
.2203 .80113 m .22187 .76325 L .1944 .75939 L p .707 .577 .707 r
F P
0 g
s
.35172 .67381 m .35844 .61652 L .34266 .61396 L p .707 .577 .707 r
F P
0 g
s
.1944 .75939 m .19283 .79728 L .2203 .80113 L p .707 .577 .707 r
F P
0 g
s
.16564 .59418 m .15893 .65146 L .17194 .65224 L p .707 .577 .707 r
F P
0 g
s
.17194 .65224 m .17866 .59495 L .16564 .59418 L p .707 .577 .707 r
F P
0 g
s
.25916 .78716 m .25838 .76927 L .22722 .76789 L p .707 .577 .707 r
F P
0 g
s
.25838 .76927 m .25916 .78716 L .29097 .78488 L p .707 .577 .707 r
F P
0 g
s
.29097 .78488 m .29019 .76699 L .25838 .76927 L p .707 .577 .707 r
F P
0 g
s
.31416 .76551 m .3126 .8034 L .33658 .8008 L p .707 .577 .707 r
F P
0 g
s
.33658 .8008 m .33815 .76292 L .31416 .76551 L p .707 .577 .707 r
F P
0 g
s
.29019 .76699 m .29097 .78488 L .3203 .77916 L p .707 .577 .707 r
F P
0 g
s
.3203 .77916 m .31952 .76127 L .29019 .76699 L p .707 .577 .707 r
F P
0 g
s
.228 .78578 m .22722 .76789 L .19975 .76298 L p .707 .577 .707 r
F P
0 g
s
.22722 .76789 m .228 .78578 L .25916 .78716 L p .707 .577 .707 r
F P
0 g
s
.19283 .79728 m .1944 .75939 L .17331 .7545 L p .707 .577 .707 r
F P
0 g
s
.68887 .77983 m .6873 .81772 L .66621 .81282 L p .707 .577 .707 r
F P
0 g
s
.66621 .81282 m .66778 .77494 L .68887 .77983 L p .707 .577 .707 r
F P
0 g
s
.69423 .74548 m .69501 .76337 L .67392 .75541 L p .707 .577 .707 r
F P
0 g
s
.67392 .75541 m .67314 .73752 L .69423 .74548 L p .707 .577 .707 r
F P
0 g
s
.33815 .76292 m .33658 .8008 L .35288 .79682 L p .707 .577 .707 r
F P
0 g
s
.35288 .79682 m .35445 .75894 L .33815 .76292 L p .707 .577 .707 r
F P
0 g
s
.31952 .76127 m .3203 .77916 L .34429 .77056 L p .707 .577 .707 r
F P
0 g
s
.34429 .77056 m .34351 .75266 L .31952 .76127 L p .707 .577 .707 r
F P
0 g
s
.19975 .76298 m .20053 .78087 L .228 .78578 L p .707 .577 .707 r
F P
0 g
s
.17331 .7545 m .17174 .79238 L .19283 .79728 L p .707 .577 .707 r
F P
0 g
s
.35844 .61652 m .35172 .67381 L .35821 .67537 L p .707 .577 .707 r
F P
0 g
s
.35821 .67537 m .36493 .61808 L .35844 .61652 L p .707 .577 .707 r
F P
0 g
s
.20053 .78087 m .19975 .76298 L .17866 .75502 L p .707 .577 .707 r
F P
0 g
s
.35445 .75894 m .35288 .79682 L .3556 .79489 L p .707 .577 .707 r
F P
0 g
s
.35605 .76859 m .35445 .75894 L .3556 .79489 L .707 .577 .707 r
F
.35615 .76281 m .36059 .75992 L p .35623 .75806 L F P
0 g
s
.36059 .75992 m .35981 .74202 L .35646 .74421 L p .707 .577 .707 r
F P
0 g
s
.36059 .75992 m .35646 .74421 L .35623 .75806 L .707 .577 .707 r
F
.35981 .74202 m .36059 .75992 L .3676 .74828 L p F P
0 g
s
.3599 .79184 m .36146 .75396 L .35623 .75768 L p .707 .577 .707 r
F P
0 g
s
.35623 .75768 m .35445 .75894 L p .35605 .76859 L .707 .577 .707 r
F P
0 g
s
.3599 .79184 m .35623 .75768 L .35605 .76859 L .707 .577 .707 r
F
.35646 .74421 m .34351 .75266 L p .35623 .75806 L F P
0 g
s
.34351 .75266 m .34429 .77056 L .35615 .76281 L p .707 .577 .707 r
F P
0 g
s
.35623 .75806 m .34351 .75266 L .35615 .76281 L .707 .577 .707 r
F
.3556 .79489 m .3599 .79184 L p .35605 .76859 L F P
0 g
s
.35821 .67537 m .35478 .67579 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36493 .61808 m .36387 .62713 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36387 .62713 m .35821 .67537 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35582 .27831 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .36493 .61808 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35478 .67579 m .36095 .62322 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36095 .62322 m .3615 .6185 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36146 .75396 m .3599 .79184 L .35693 .78636 L p .707 .577 .707 r
F P
0 g
s
.35693 .78636 m .3585 .74848 L .36146 .75396 L p .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .35478 .67579 L .34177 .67501 L p .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .34848 .61772 L .36069 .61845 L p .707 .577 .707 r
F P
0 g
s
.36069 .61845 m .3615 .6185 L p .3608 .6205 L .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .36069 .61845 L .3608 .6205 L .707 .577 .707 r
F
.358 .61927 m .35826 .5737 L p .35659 .61738 L F P
0 g
s
.35826 .5737 m .35991 .28979 L p .35722 .55455 L .707 .577 .707 r
F P
0 g
s
.35826 .5737 m .35722 .55455 L .35659 .61738 L .707 .577 .707 r
F
.3585 .74848 m .35693 .78636 L .34429 .7809 L p F P
0 g
s
.34429 .7809 m .34586 .74302 L .3585 .74848 L p .707 .577 .707 r
F P
0 g
s
.3676 .74828 m .36682 .73038 L .35981 .74202 L p .707 .577 .707 r
F P
0 g
s
.36386 .71889 m .36464 .73678 L .35786 .7313 L p .707 .577 .707 r
F P
0 g
s
.35786 .7313 m .352 .72656 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.35817 .72257 m .36386 .71889 L .35786 .7313 L .707 .577 .707 r
F
.352 .72656 m .35122 .70866 L .35846 .71452 L p F P
0 g
s
.35846 .71452 m .36386 .71889 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.352 .72656 m .35846 .71452 L .35817 .72257 L .707 .577 .707 r
F
.35691 .75809 m .358 .61927 L .35659 .61738 L F
.35699 .79358 m .35725 .74847 L p .35691 .75809 L F P
0 g
s
.35725 .74847 m .358 .61927 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35577 .79016 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.35577 .79016 m .35699 .79358 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.35691 .75809 m .35659 .61738 L .35577 .79016 L .707 .577 .707 r
F
.35582 .27831 m .35387 .61375 L p .35659 .61738 L F P
0 g
s
.35387 .61375 m .3529 .78211 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.36682 .73038 m .3676 .74828 L .36464 .73678 L p .707 .577 .707 r
F P
0 g
s
.36464 .73678 m .36386 .71889 L .36682 .73038 L p .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35699 .79358 L .37477 .80424 L p .707 .577 .707 r
F P
0 g
s
.16221 .59459 m .1555 .65188 L .15893 .65146 L p .707 .577 .707 r
F P
0 g
s
.15893 .65146 m .16564 .59418 L .16221 .59459 L p .707 .577 .707 r
F P
0 g
s
.17866 .75502 m .17944 .77291 L .20053 .78087 L p .707 .577 .707 r
F P
0 g
s
.17174 .79238 m .17331 .7545 L .16067 .74904 L p .707 .577 .707 r
F P
0 g
s
.66778 .77494 m .66621 .81282 L .63874 .80896 L p .707 .577 .707 r
F P
0 g
s
.67314 .73752 m .67392 .75541 L .64645 .7505 L p .707 .577 .707 r
F P
0 g
s
.64645 .7505 m .64567 .73261 L .67314 .73752 L p .707 .577 .707 r
F P
0 g
s
.16067 .74904 m .1591 .78692 L .17174 .79238 L p .707 .577 .707 r
F P
0 g
s
.17944 .77291 m .17866 .75502 L .16602 .74479 L p .707 .577 .707 r
F P
0 g
s
.16602 .74479 m .1668 .76268 L .17944 .77291 L p .707 .577 .707 r
F P
0 g
s
.64367 .28475 m .64075 .78854 L .63666 .77706 L p .707 .577 .707 r
F P
0 g
s
.63666 .77706 m .63958 .27327 L .64367 .28475 L p .707 .577 .707 r
F P
0 g
s
.1591 .78692 m .16067 .74904 L .15771 .74355 L p .707 .577 .707 r
F P
0 g
s
.1687 .59615 m .16199 .65344 L .1555 .65188 L p .707 .577 .707 r
F P
0 g
s
.1555 .65188 m .16221 .59459 L .1687 .59615 L p .707 .577 .707 r
F P
0 g
s
.15771 .74355 m .15614 .78143 L .1591 .78692 L p .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35582 .27831 L .36581 .26716 L p .707 .577 .707 r
F P
0 g
s
.1668 .76268 m .16602 .74479 L .16306 .7333 L p .707 .577 .707 r
F P
0 g
s
.16306 .7333 m .16384 .75119 L .1668 .76268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.18448 .59872 m .17777 .656 L .16199 .65344 L p .707 .577 .707 r
F P
0 g
s
.16199 .65344 m .1687 .59615 L .18448 .59872 L p .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16306 .7333 L .16863 .72405 L p .707 .577 .707 r
F P
0 g
s
.16863 .72405 m .17007 .72166 L p .1687 .72816 L .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16863 .72405 L .1687 .72816 L .707 .577 .707 r
F
.16886 .73756 m .18102 .73459 L p .16926 .76213 L F P
0 g
s
.17007 .72166 m .17085 .73955 L .16384 .75119 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16472 .73857 L .16886 .73756 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16886 .73756 L .16926 .76213 L .707 .577 .707 r
F
.15614 .78143 m .15771 .74355 L .16472 .73857 L p F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63958 .27327 m .63666 .77706 L .61888 .7664 L p .707 .577 .707 r
F P
0 g
s
.61888 .7664 m .6218 .26261 L .63958 .27327 L p .707 .577 .707 r
F P
0 g
s
.16472 .73857 m .16315 .77646 L .15614 .78143 L p .707 .577 .707 r
F P
0 g
s
.34848 .61772 m .34177 .67501 L .32044 .67312 L p .707 .577 .707 r
F P
0 g
s
.32044 .67312 m .32716 .61583 L .34848 .61772 L p .707 .577 .707 r
F P
0 g
s
.36289 .77095 m .36581 .26716 L .38892 .2574 L p .707 .577 .707 r
F P
0 g
s
.36581 .26716 m .36289 .77095 L .3529 .78211 L p .707 .577 .707 r
F P
0 g
s
.208 .60202 m .20129 .65931 L .17777 .656 L p .707 .577 .707 r
F P
0 g
s
.17777 .656 m .18448 .59872 L .208 .60202 L p .707 .577 .707 r
F P
0 g
s
.18102 .73459 m .17945 .77248 L .16315 .77646 L p .707 .577 .707 r
F P
0 g
s
.17085 .73955 m .17007 .72166 L .18637 .71102 L p .707 .577 .707 r
F P
0 g
s
.32716 .61583 m .32044 .67312 L .29289 .6703 L p .707 .577 .707 r
F P
0 g
s
.29289 .6703 m .2996 .61301 L .32716 .61583 L p .707 .577 .707 r
F P
0 g
s
.6218 .26261 m .61888 .7664 L .58915 .75758 L p .707 .577 .707 r
F P
0 g
s
.58915 .75758 m .59207 .25379 L .6218 .26261 L p .707 .577 .707 r
F P
0 g
s
.18637 .71102 m .18715 .72891 L .17085 .73955 L p .707 .577 .707 r
F P
0 g
s
.34586 .74302 m .34429 .7809 L .3232 .776 L p .707 .577 .707 r
F P
0 g
s
.3232 .776 m .32477 .73812 L .34586 .74302 L p .707 .577 .707 r
F P
0 g
s
.23696 .60575 m .23025 .66304 L .20129 .65931 L p .707 .577 .707 r
F P
0 g
s
.20129 .65931 m .208 .60202 L .23696 .60575 L p .707 .577 .707 r
F P
0 g
s
.35122 .70866 m .352 .72656 L .33091 .7186 L p .707 .577 .707 r
F P
0 g
s
.33091 .7186 m .33013 .7007 L .35122 .70866 L p .707 .577 .707 r
F P
0 g
s
.17945 .77248 m .18102 .73459 L .20501 .732 L p .707 .577 .707 r
F P
0 g
s
.2996 .61301 m .29289 .6703 L .26181 .66683 L p .707 .577 .707 r
F P
0 g
s
.38892 .2574 m .386 .76119 L .36289 .77095 L p .707 .577 .707 r
F P
0 g
s
.386 .76119 m .38892 .2574 L .42288 .25001 L p .707 .577 .707 r
F P
0 g
s
.26181 .66683 m .26853 .60954 L .2996 .61301 L p .707 .577 .707 r
F P
0 g
s
.26853 .60954 m .26181 .66683 L .23025 .66304 L p .707 .577 .707 r
F P
0 g
s
.23025 .66304 m .23696 .60575 L .26853 .60954 L p .707 .577 .707 r
F P
0 g
s
.20501 .732 m .20344 .76988 L .17945 .77248 L p .707 .577 .707 r
F P
0 g
s
.18715 .72891 m .18637 .71102 L .21036 .70241 L p .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .70367 .6467 L p .70346 .64629 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70103 .6464 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67581 .64382 L p .67568 .64346 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67348 .64358 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65404 .64186 L p .65396 .64143 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65215 .64169 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64016 .64098 L p .64016 .64045 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63914 .64092 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .63965 .63213 L .63588 .64094 L .707 .577 .707 r
F
.63584 .64132 m .63914 .64092 L p .63588 .64094 L F P
0 g
s
.63865 .6313 m .64012 .63252 L .63792 .60871 L .707 .577 .707 r
F
.64012 .63252 m .64088 .6142 L .64003 .61262 L p F P
0 g
s
.64003 .61262 m .63792 .60871 L p .64012 .63252 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63571 .64133 L p .63965 .63213 L .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63931 .65208 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63792 .60871 m .63704 .62997 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63635 .6466 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63965 .63213 m .64004 .6254 L .63871 .63135 L .707 .577 .707 r
F
.64004 .6254 m .64243 .58405 L .63871 .63135 L F
.64243 .58405 m .63704 .62997 L p .63871 .63135 L F P
0 g
s
.64593 .63394 m .65286 .63565 L .64088 .6142 L .707 .577 .707 r
F
.65286 .63565 m .65352 .61966 L .64951 .61793 L p F P
0 g
s
.64951 .61793 m .64088 .6142 L p .65286 .63565 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65146 .6353 L .64016 .64045 L .707 .577 .707 r
F
.64016 .64098 m .65215 .64169 L p .64016 .64045 L F P
0 g
s
.63931 .65208 m .65196 .65754 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64088 .6142 m .64012 .63252 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63931 .65208 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64243 .58405 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64012 .63252 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .64585 .58363 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64012 .63252 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.66145 .63703 m .67401 .63905 L .65352 .61966 L .707 .577 .707 r
F
.66798 .62302 m .65352 .61966 L p .67401 .63905 L F P
0 g
s
.65352 .61966 m .65286 .63565 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65887 .58441 m .64585 .58363 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65286 .63565 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65887 .58441 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67229 .63877 L .65396 .64143 L .707 .577 .707 r
F
.65404 .64186 m .67348 .64358 L p .65396 .64143 L F P
0 g
s
.65196 .65754 m .67304 .66244 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65196 .65754 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.63913 .62945 m .64727 .59299 L .64392 .62825 L .707 .577 .707 r
F
.67401 .63905 m .67461 .62456 L .66798 .62302 L p F P
0 g
s
.65887 .58441 m .65286 .63565 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.64628 .60341 m .66123 .59976 L p .64392 .62825 L .707 .577 .707 r
F P
0 g
s
.64892 .58561 m .64392 .62825 L p .64727 .59299 L .707 .577 .707 r
F P
0 g
s
.65196 .65754 m .65286 .63565 L p .64593 .63394 L .707 .577 .707 r
F P
0 g
s
.63931 .65208 m .64012 .63252 L p .63865 .6313 L .707 .577 .707 r
F P
0 g
s
.64493 .60374 m .64392 .62825 L p .63635 .6466 L .707 .577 .707 r
F P
0 g
s
.64313 .64065 m .6483 .62806 L .64297 .64302 L .707 .577 .707 r
F
.64305 .64185 m .63635 .6466 L p .64392 .62825 L F P
0 g
s
.64917 .62802 m .64392 .62825 L .66123 .59976 L .707 .577 .707 r
F
.68439 .64031 m .7015 .64239 L .67461 .62456 L F
.69392 .62727 m .67461 .62456 L p .7015 .64239 L F P
0 g
s
.67461 .62456 m .67401 .63905 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .65887 .58441 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67401 .63905 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .6802 .5863 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .69956 .64215 L .67568 .64346 L .707 .577 .707 r
F
.67581 .64382 m .70103 .6464 L p .67568 .64346 L F P
0 g
s
.67304 .66244 m .70051 .6663 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67304 .66244 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6422 .6429 m .64892 .58561 L .6647 .58817 L p .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64336 .64162 L .64305 .64185 L p .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .64297 .64302 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64297 .64302 m .6422 .6429 L p .64313 .64065 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .65798 .64546 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .66008 .62753 L p .64336 .64162 L .707 .577 .707 r
F P
0 g
s
.67304 .66244 m .67401 .63905 L p .66145 .63703 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70208 .62841 L .69392 .62727 L p .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .67401 .63905 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .70208 .62841 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70208 .62841 m .7015 .64239 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .6802 .5863 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .7015 .64239 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70775 .58912 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .7302 .64511 L .70346 .64629 L .707 .577 .707 r
F
.70367 .6467 m .73211 .64988 L p .70346 .64629 L F P
0 g
s
.70051 .6663 m .73167 .66873 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70051 .6663 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .68522 .59716 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .66123 .59976 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .66008 .62753 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .65798 .64546 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .6815 .64877 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.70051 .6663 m .7015 .64239 L p .68439 .64031 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73324 .63085 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .7015 .64239 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .73264 .64534 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .73324 .63085 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .76368 .65366 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73211 .64988 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76505 .63163 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .76438 .64762 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .76505 .63163 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .79263 .65739 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76368 .65366 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79438 .63068 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .79362 .64899 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .79438 .63068 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .81615 .6607 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79263 .65739 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81837 .62808 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .81749 .64934 L p .82064 .6333 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .81837 .62808 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .83193 .66326 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81615 .6607 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83467 .6241 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .83365 .64862 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83865 .60597 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.83524 .62369 m .83467 .6241 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83537 .62174 L .82974 .64879 L .707 .577 .707 r
F
.83865 .60597 m .83365 .64862 L p .83849 .64741 L F P
0 g
s
.8331 .66199 m .8394 .65751 L p .83852 .6474 L .707 .577 .707 r
F P
0 g
s
.83971 .6546 m .83852 .6474 L .8394 .65751 L .707 .577 .707 r
F
.83849 .64741 m .84141 .62989 L .83865 .60597 L F
.84514 .60754 m .84261 .60693 L p .84141 .62989 L F P
0 g
s
.84261 .60693 m .83865 .60597 L p .84141 .62989 L .707 .577 .707 r
F P
0 g
s
.84053 .6469 m .84514 .60754 L p .83849 .64741 L .707 .577 .707 r
F P
0 g
s
.83852 .6474 m .83809 .6448 L .8377 .6476 L .707 .577 .707 r
F
.83809 .6448 m .83506 .62651 L .8377 .6476 L F
.8377 .6476 m .83506 .62651 L .83384 .64857 L F
.83852 .6474 m .83384 .64857 L .8331 .66199 L F
.84011 .65701 m .84053 .6469 L p .8387 .64735 L F P
0 g
s
.83971 .6546 m .83524 .62369 L .83506 .62651 L .707 .577 .707 r
F
.84011 .65701 m .83973 .65441 L .83971 .6546 L F
.83973 .65441 m .83524 .62369 L .83971 .6546 L F
.84168 .61913 m .83524 .62369 L p .8387 .64735 L F P
0 g
s
.84053 .6469 m .84168 .61913 L p .8387 .64735 L .707 .577 .707 r
F P
0 g
s
.84168 .61913 m .84053 .6469 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .8331 .66199 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83236 .66216 m .8331 .66199 L p .83251 .66063 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83193 .66326 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.83193 .66326 m .83365 .64862 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .83365 .64862 L .82741 .6489 L .707 .577 .707 r
F
.8331 .66199 m .83365 .64862 L p .83251 .66063 L F P
0 g
s
.83849 .64741 m .83365 .64862 L .83236 .66224 L .707 .577 .707 r
F
.83843 .66483 m .83849 .64741 L .83236 .66224 L F
.83193 .66326 m .83225 .66334 L p .83236 .66224 L F P
0 g
s
.83225 .66334 m .83843 .66483 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .83236 .66216 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .82741 .6489 L .83236 .66216 L .707 .577 .707 r
F
.83872 .61364 m .84168 .61913 L p .83808 .64487 L F P
0 g
s
.835 .66524 m .83745 .64435 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .83745 .64435 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83872 .61364 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .8447 .60759 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .84171 .60795 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.8447 .60759 m .84514 .60754 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .8447 .60759 L .84404 .6138 L .707 .577 .707 r
F
.83843 .66483 m .84053 .6469 L p .83849 .64741 L F P
0 g
s
.83843 .66483 m .835 .66524 L p .83851 .64523 L .707 .577 .707 r
F P
0 g
s
.83851 .64523 m .84404 .6138 L .84041 .6468 L .707 .577 .707 r
F
.83851 .64523 m .84041 .6468 L .83843 .66483 L F
.84053 .6469 m .83843 .66483 L p .84404 .6138 L F P
0 g
s
.83715 .65152 m .83808 .64487 L .84053 .6469 L .707 .577 .707 r
F
.84053 .6469 m .84011 .65701 L .84001 .65683 L p F P
0 g
s
.8394 .65751 m .84011 .65701 L p .83971 .6546 L .707 .577 .707 r
F P
0 g
s
.84001 .65683 m .83715 .65152 L p .84053 .6469 L .707 .577 .707 r
F P
0 g
s
.84514 .60754 m .84053 .6469 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.82974 .64879 m .83537 .62174 L .82287 .60341 L .707 .577 .707 r
F
.83865 .60597 m .8364 .60561 L p .83537 .62174 L F P
0 g
s
.8364 .60561 m .82287 .60341 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.82741 .6489 m .82064 .6333 L .81876 .64928 L .707 .577 .707 r
F
.82741 .6489 m .81876 .64928 L .8168 .66597 L F
.81749 .64934 m .8168 .66597 L p .82064 .6333 L F P
0 g
s
.82287 .60341 m .81749 .64934 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.82287 .60341 m .79935 .60011 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .81749 .64934 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .82287 .60341 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .81749 .64934 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .8168 .66597 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79281 .66856 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .79362 .64899 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .77039 .59638 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .79362 .64899 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79935 .60011 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .79362 .64899 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .79281 .66856 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76348 .66951 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .76438 .64762 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .73883 .59259 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .76438 .64762 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .77039 .59638 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .76438 .64762 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .76348 .66951 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73167 .66873 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .73264 .64534 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .70775 .58912 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .73264 .64534 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73883 .59259 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .71455 .59621 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .68395 .62787 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68395 .62787 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68522 .59716 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .6815 .64877 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71046 .6525 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .73264 .64534 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.74636 .59699 m .77752 .59943 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .80499 .60328 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .77607 .63448 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .77607 .63448 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77752 .59943 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .82607 .60818 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .80356 .63782 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .80356 .63782 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80499 .60328 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .83872 .61364 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .82471 .64122 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .82471 .64122 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82607 .60818 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .82198 .66447 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .835 .66524 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .82451 .64606 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83872 .61364 m .83745 .64435 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83715 .65152 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .83745 .64435 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .84171 .60795 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .8287 .60718 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .80065 .66258 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82198 .66447 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .80342 .64117 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .82471 .64122 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82451 .64606 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .82471 .64122 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .8287 .60718 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80737 .60529 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .7731 .65976 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80065 .66258 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .77595 .63731 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .80356 .63782 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80342 .64117 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .80356 .63782 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .80737 .60529 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77982 .60247 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.74202 .65628 m .74493 .63153 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .74202 .65628 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .7731 .65976 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .74479 .63487 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .77607 .63448 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77595 .63731 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .77607 .63448 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74874 .599 m .77982 .60247 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74601 .63163 m .74636 .59699 L .74764 .63179 L .707 .577 .707 r
F
.74493 .63153 m .74636 .59699 L p .74599 .63357 L F P
0 g
s
.74493 .63153 m .74874 .599 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74599 .63357 m .74601 .63163 L .74764 .63179 L .707 .577 .707 r
F
.74479 .63487 m .74493 .63153 L p .74599 .63357 L F P
0 g
s
.71455 .59621 m .74636 .59699 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .71318 .62925 L p .72349 .62999 L .707 .577 .707 r
F P
0 g
s
.71298 .63409 m .71318 .62925 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71455 .59621 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .72349 .62999 L .72641 .6302 L .707 .577 .707 r
F
.74636 .59699 m .74493 .63153 L p .71709 .62953 L F P
0 g
s
.74874 .599 m .74202 .65628 L .71046 .6525 L p .707 .577 .707 r
F P
0 g
s
.74479 .63487 m .71298 .63409 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.74493 .63153 m .74479 .63487 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.72641 .6302 m .73436 .61123 L .73673 .61578 L .707 .577 .707 r
F
.72349 .62999 m .73436 .61123 L .72641 .6302 L F
.72349 .62999 m .71318 .62925 L .73436 .61123 L F
.73673 .61578 m .73436 .61123 L .74874 .599 L F
.71318 .62925 m .71718 .59521 L .73288 .59709 L p F P
0 g
s
.73288 .59709 m .74874 .599 L p .71318 .62925 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68916 .62812 L .71059 .63349 L .707 .577 .707 r
F
.71298 .63409 m .71016 .63419 L p .71059 .63349 L F P
0 g
s
.71016 .63419 m .68365 .63505 L p .71059 .63349 L .707 .577 .707 r
F P
0 g
s
.71455 .59621 m .71318 .62925 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71298 .63409 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71718 .59521 m .71318 .62925 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.69507 .6284 m .68395 .62787 L .71718 .59521 L .707 .577 .707 r
F
.68395 .62787 m .68822 .59148 L .6981 .59275 L p F P
0 g
s
.6981 .59275 m .71718 .59521 L p .68395 .62787 L .707 .577 .707 r
F P
0 g
s
.65966 .63764 m .66599 .62761 L .68143 .63411 L .707 .577 .707 r
F
.68365 .63505 m .68094 .63534 L p .68143 .63411 L F P
0 g
s
.68094 .63534 m .65966 .63764 L p .68143 .63411 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .68395 .62787 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68365 .63505 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68822 .59148 m .68395 .62787 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.66796 .62764 m .66008 .62753 L .68822 .59148 L .707 .577 .707 r
F
.65966 .63764 m .66008 .62753 L p .66599 .62761 L F P
0 g
s
.66008 .62753 m .65966 .63764 L .65802 .63804 L p .707 .577 .707 r
F P
0 g
s
.65802 .63804 m .64336 .64162 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .6647 .58817 L .66773 .5886 L p .707 .577 .707 r
F P
0 g
s
.66773 .5886 m .68822 .59148 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.6647 .58817 m .66008 .62753 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64336 .64162 m .64392 .62825 L p .64917 .62802 L .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64493 .60374 L .64628 .60341 L p .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63704 .62997 L p .63982 .62928 L .707 .577 .707 r
F P
0 g
s
.63666 .63733 m .64892 .58561 L .63644 .64151 L .707 .577 .707 r
F
.63571 .64133 m .64243 .58405 L .64892 .58561 L p F P
0 g
s
.63982 .62928 m .63704 .62997 L .64493 .60374 L .707 .577 .707 r
F
.6422 .6429 m .63644 .64151 L p .63913 .62945 L F P
0 g
s
.64392 .62825 m .6422 .6429 L p .63913 .62945 L .707 .577 .707 r
F P
0 g
s
.63571 .64133 m .63584 .64132 L p .63588 .64094 L .707 .577 .707 r
F P
0 g
s
.63644 .64151 m .63571 .64133 L p .63666 .63733 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63792 .60871 L .63941 .60766 L p .707 .577 .707 r
F P
0 g
s
.63941 .60766 m .64493 .60374 L p .63704 .62997 L .707 .577 .707 r
F P
0 g
s
.32477 .73812 m .3232 .776 L .29573 .77215 L p .707 .577 .707 r
F P
0 g
s
.29573 .77215 m .2973 .73426 L .32477 .73812 L p .707 .577 .707 r
F P
0 g
s
.21036 .70241 m .21114 .72031 L .18715 .72891 L p .707 .577 .707 r
F P
0 g
s
.33013 .7007 m .33091 .7186 L .30344 .71369 L p .707 .577 .707 r
F P
0 g
s
.30344 .71369 m .30266 .69579 L .33013 .7007 L p .707 .577 .707 r
F P
0 g
s
.59207 .25379 m .58915 .75758 L .55039 .75149 L p .707 .577 .707 r
F P
0 g
s
.55039 .75149 m .55331 .24769 L .59207 .25379 L p .707 .577 .707 r
F P
0 g
s
.20344 .76988 m .20501 .732 L .23434 .73105 L p .707 .577 .707 r
F P
0 g
s
.21114 .72031 m .21036 .70241 L .2397 .69669 L p .707 .577 .707 r
F P
0 g
s
.23434 .73105 m .23277 .76893 L .20344 .76988 L p .707 .577 .707 r
F P
0 g
s
.2973 .73426 m .29573 .77215 L .26457 .76971 L p .707 .577 .707 r
F P
0 g
s
.26457 .76971 m .26614 .73183 L .2973 .73426 L p .707 .577 .707 r
F P
0 g
s
.41996 .7538 m .42288 .25001 L .46436 .24571 L p .707 .577 .707 r
F P
0 g
s
.42288 .25001 m .41996 .7538 L .386 .76119 L p .707 .577 .707 r
F P
0 g
s
.30266 .69579 m .30344 .71369 L .27228 .7123 L p .707 .577 .707 r
F P
0 g
s
.27228 .7123 m .2715 .69441 L .30266 .69579 L p .707 .577 .707 r
F P
0 g
s
.2397 .69669 m .24047 .71459 L .21114 .72031 L p .707 .577 .707 r
F P
0 g
s
.23277 .76893 m .23434 .73105 L .26614 .73183 L p .707 .577 .707 r
F P
0 g
s
.26614 .73183 m .26457 .76971 L .23277 .76893 L p .707 .577 .707 r
F P
0 g
s
.24047 .71459 m .2397 .69669 L .2715 .69441 L p .707 .577 .707 r
F P
0 g
s
.2715 .69441 m .27228 .7123 L .24047 .71459 L p .707 .577 .707 r
F P
0 g
s
.55331 .24769 m .55039 .75149 L .50638 .7487 L p .707 .577 .707 r
F P
0 g
s
.50638 .7487 m .5093 .24491 L .55331 .24769 L p .707 .577 .707 r
F P
0 g
s
.46144 .7495 m .46436 .24571 L .5093 .24491 L p .707 .577 .707 r
F P
0 g
s
.46436 .24571 m .46144 .7495 L .41996 .7538 L p .707 .577 .707 r
F P
0 g
s
.5093 .24491 m .50638 .7487 L .46144 .7495 L p .707 .577 .707 r
F P
0 g
s
.73938 .79959 m .7386 .78169 L .70743 .78031 L p .707 .577 .707 r
F P
0 g
s
.7386 .78169 m .73938 .79959 L .77118 .79731 L p .707 .577 .707 r
F P
0 g
s
.77118 .79731 m .7704 .77941 L .7386 .78169 L p .707 .577 .707 r
F P
0 g
s
.7704 .77941 m .77118 .79731 L .80051 .79158 L p .707 .577 .707 r
F P
0 g
s
.80051 .79158 m .79973 .77369 L .7704 .77941 L p .707 .577 .707 r
F P
0 g
s
.70821 .7982 m .70743 .78031 L .67997 .7754 L p .707 .577 .707 r
F P
0 g
s
.70743 .78031 m .70821 .7982 L .73938 .79959 L p .707 .577 .707 r
F P
0 g
s
.79973 .77369 m .80051 .79158 L .8245 .78298 L p .707 .577 .707 r
F P
0 g
s
.8245 .78298 m .82372 .76509 L .79973 .77369 L p .707 .577 .707 r
F P
0 g
s
.67997 .7754 m .68074 .79329 L .70821 .7982 L p .707 .577 .707 r
F P
0 g
s
.68074 .79329 m .67997 .7754 L .65888 .76744 L p .707 .577 .707 r
F P
0 g
s
.65888 .76744 m .65966 .78534 L .68074 .79329 L p .707 .577 .707 r
F P
0 g
s
.82372 .76509 m .8245 .78298 L .8408 .77234 L p .707 .577 .707 r
F P
0 g
s
.8408 .77234 m .84002 .75445 L .82372 .76509 L p .707 .577 .707 r
F P
0 g
s
.65966 .78534 m .65888 .76744 L .64623 .75721 L p .707 .577 .707 r
F P
0 g
s
.64623 .75721 m .64701 .77511 L .65966 .78534 L p .707 .577 .707 r
F P
0 g
s
.84002 .75445 m .8408 .77234 L .84781 .7607 L p .707 .577 .707 r
F P
0 g
s
.84781 .7607 m .84703 .74281 L .84002 .75445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64701 .77511 m .64623 .75721 L .64328 .74572 L p .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .36066 .60988 L p .36046 .60948 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35802 .60959 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .3328 .60701 L p .33267 .60665 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33047 .60677 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .31103 .60504 L p .31095 .60462 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30914 .60488 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29715 .60416 L p .29715 .60364 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .29613 .6041 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29664 .59531 L .29287 .60412 L .707 .577 .707 r
F
.29283 .6045 m .29613 .6041 L p .29287 .60412 L F P
0 g
s
.29564 .59448 m .29711 .5957 L .29491 .5719 L .707 .577 .707 r
F
.29711 .5957 m .29787 .57739 L .29702 .5758 L p F P
0 g
s
.29702 .5758 m .29491 .5719 L p .29711 .5957 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .2927 .60452 L p .29664 .59531 L .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .2963 .61527 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29491 .5719 m .29403 .59316 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29334 .60978 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29664 .59531 m .29702 .58858 L .2957 .59453 L .707 .577 .707 r
F
.29702 .58858 m .29941 .54723 L .2957 .59453 L F
.29941 .54723 m .29403 .59316 L p .2957 .59453 L F P
0 g
s
.30292 .59713 m .30985 .59883 L .29787 .57739 L .707 .577 .707 r
F
.30985 .59883 m .31051 .58284 L .3065 .58111 L p F P
0 g
s
.3065 .58111 m .29787 .57739 L p .30985 .59883 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30845 .59849 L .29715 .60364 L .707 .577 .707 r
F
.29715 .60416 m .30914 .60488 L p .29715 .60364 L F P
0 g
s
.2963 .61527 m .30895 .62073 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29787 .57739 m .29711 .5957 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .2963 .61527 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29941 .54723 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29711 .5957 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .30284 .54681 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29711 .5957 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.31844 .60021 m .331 .60223 L .31051 .58284 L .707 .577 .707 r
F
.32497 .5862 m .31051 .58284 L p .331 .60223 L F P
0 g
s
.31051 .58284 m .30985 .59883 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.31586 .54759 m .30284 .54681 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30985 .59883 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .31586 .54759 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .32928 .60195 L .31095 .60462 L .707 .577 .707 r
F
.31103 .60504 m .33047 .60677 L p .31095 .60462 L F P
0 g
s
.30895 .62073 m .33003 .62562 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30895 .62073 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.29612 .59263 m .30426 .55618 L .30091 .59144 L .707 .577 .707 r
F
.331 .60223 m .3316 .58774 L .32497 .5862 L p F P
0 g
s
.31586 .54759 m .30985 .59883 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.30327 .56659 m .31822 .56294 L p .30091 .59144 L .707 .577 .707 r
F P
0 g
s
.30591 .54879 m .30091 .59144 L p .30426 .55618 L .707 .577 .707 r
F P
0 g
s
.30895 .62073 m .30985 .59883 L p .30292 .59713 L .707 .577 .707 r
F P
0 g
s
.2963 .61527 m .29711 .5957 L p .29564 .59448 L .707 .577 .707 r
F P
0 g
s
.30192 .56692 m .30091 .59144 L p .29334 .60978 L .707 .577 .707 r
F P
0 g
s
.30011 .60383 m .30529 .59124 L .29996 .60621 L .707 .577 .707 r
F
.30004 .60503 m .29334 .60978 L p .30091 .59144 L F P
0 g
s
.30616 .5912 m .30091 .59144 L .31822 .56294 L .707 .577 .707 r
F
.34138 .60349 m .35849 .60557 L .3316 .58774 L F
.35091 .59045 m .3316 .58774 L p .35849 .60557 L F P
0 g
s
.3316 .58774 m .331 .60223 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .31586 .54759 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .331 .60223 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33719 .54948 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35655 .60533 L .33267 .60665 L .707 .577 .707 r
F
.3328 .60701 m .35802 .60959 L p .33267 .60665 L F P
0 g
s
.33003 .62562 m .3575 .62948 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33003 .62562 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.29919 .60608 m .30591 .54879 L .32169 .55136 L p .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30035 .60481 L .30004 .60503 L p .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .29996 .60621 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.29996 .60621 m .29919 .60608 L p .30011 .60383 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31497 .60864 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .31707 .59071 L p .30035 .60481 L .707 .577 .707 r
F P
0 g
s
.33003 .62562 m .331 .60223 L p .31844 .60021 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35907 .5916 L .35091 .59045 L p .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .331 .60223 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .35907 .5916 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.35907 .5916 m .35849 .60557 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .33719 .54948 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35849 .60557 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .36474 .5523 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38719 .60829 L .36046 .60948 L .707 .577 .707 r
F
.36066 .60988 m .3891 .61306 L p .36046 .60948 L F P
0 g
s
.3575 .62948 m .38866 .63192 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .3575 .62948 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .34221 .56035 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31822 .56294 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .31707 .59071 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .31497 .60864 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .33849 .61195 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.3575 .62948 m .35849 .60557 L p .34138 .60349 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39023 .59403 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .35849 .60557 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .38963 .60852 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .39023 .59403 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .42067 .61685 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .3891 .61306 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42204 .59481 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .42137 .6108 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .42204 .59481 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .44963 .62058 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42067 .61685 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45137 .59386 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .45061 .61218 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .45137 .59386 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .47315 .62388 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .44963 .62058 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47536 .59127 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .47448 .61252 L p .47763 .59649 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .47536 .59127 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .48892 .62645 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47315 .62388 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49166 .58729 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .49064 .6118 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49564 .56916 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.49223 .58688 m .49166 .58729 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49236 .58493 L .48673 .61198 L .707 .577 .707 r
F
.49564 .56916 m .49064 .6118 L p .49548 .61059 L F P
0 g
s
.49009 .62517 m .49639 .6207 L p .49551 .61058 L .707 .577 .707 r
F P
0 g
s
.4967 .61778 m .49551 .61058 L .49639 .6207 L .707 .577 .707 r
F
.49548 .61059 m .4984 .59307 L .49564 .56916 L F
.50213 .57072 m .4996 .57011 L p .4984 .59307 L F P
0 g
s
.4996 .57011 m .49564 .56916 L p .4984 .59307 L .707 .577 .707 r
F P
0 g
s
.49752 .61008 m .50213 .57072 L p .49548 .61059 L .707 .577 .707 r
F P
0 g
s
.49551 .61058 m .49508 .60798 L .49469 .61079 L .707 .577 .707 r
F
.49508 .60798 m .49205 .5897 L .49469 .61079 L F
.49469 .61079 m .49205 .5897 L .49083 .61175 L F
.49551 .61058 m .49083 .61175 L .49009 .62517 L F
.4971 .62019 m .49752 .61008 L p .49569 .61054 L F P
0 g
s
.4967 .61778 m .49223 .58688 L .49205 .5897 L .707 .577 .707 r
F
.4971 .62019 m .49672 .6176 L .4967 .61778 L F
.49672 .6176 m .49223 .58688 L .4967 .61778 L F
.49867 .58231 m .49223 .58688 L p .49569 .61054 L F P
0 g
s
.49752 .61008 m .49867 .58231 L p .49569 .61054 L .707 .577 .707 r
F P
0 g
s
.49867 .58231 m .49752 .61008 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49009 .62517 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.48935 .62535 m .49009 .62517 L p .4895 .62382 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .48892 .62645 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.48892 .62645 m .49064 .6118 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .49064 .6118 L .4844 .61208 L .707 .577 .707 r
F
.49009 .62517 m .49064 .6118 L p .4895 .62382 L F P
0 g
s
.49548 .61059 m .49064 .6118 L .48935 .62543 L .707 .577 .707 r
F
.49542 .62801 m .49548 .61059 L .48935 .62543 L F
.48892 .62645 m .48924 .62652 L p .48935 .62543 L F P
0 g
s
.48924 .62652 m .49542 .62801 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .48935 .62535 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .4844 .61208 L .48935 .62535 L .707 .577 .707 r
F
.49571 .57682 m .49867 .58231 L p .49507 .60806 L F P
0 g
s
.49199 .62843 m .49444 .60753 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .49444 .60753 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49571 .57682 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .50169 .57078 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .4987 .57114 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.50169 .57078 m .50213 .57072 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .50169 .57078 L .50103 .57698 L .707 .577 .707 r
F
.49542 .62801 m .49752 .61008 L p .49548 .61059 L F P
0 g
s
.49542 .62801 m .49199 .62843 L p .4955 .60842 L .707 .577 .707 r
F P
0 g
s
.4955 .60842 m .50103 .57698 L .4974 .60998 L .707 .577 .707 r
F
.4955 .60842 m .4974 .60998 L .49542 .62801 L F
.49752 .61008 m .49542 .62801 L p .50103 .57698 L F P
0 g
s
.49414 .61471 m .49507 .60806 L .49752 .61008 L .707 .577 .707 r
F
.49752 .61008 m .4971 .62019 L .497 .62001 L p F P
0 g
s
.49639 .6207 m .4971 .62019 L p .4967 .61778 L .707 .577 .707 r
F P
0 g
s
.497 .62001 m .49414 .61471 L p .49752 .61008 L .707 .577 .707 r
F P
0 g
s
.50213 .57072 m .49752 .61008 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.48673 .61198 m .49236 .58493 L .47986 .5666 L .707 .577 .707 r
F
.49564 .56916 m .49339 .56879 L p .49236 .58493 L F P
0 g
s
.49339 .56879 m .47986 .5666 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.4844 .61208 m .47763 .59649 L .47575 .61247 L .707 .577 .707 r
F
.4844 .61208 m .47575 .61247 L .47379 .62915 L F
.47448 .61252 m .47379 .62915 L p .47763 .59649 L F P
0 g
s
.47986 .5666 m .47448 .61252 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47986 .5666 m .45634 .56329 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .47448 .61252 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47986 .5666 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .47448 .61252 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .47379 .62915 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .4498 .63174 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .45061 .61218 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .42738 .55956 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .45061 .61218 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45634 .56329 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .45061 .61218 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .4498 .63174 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42047 .6327 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .42137 .6108 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .39582 .55577 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .42137 .6108 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42738 .55956 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .42137 .6108 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .42047 .6327 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .38866 .63192 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .38963 .60852 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .36474 .5523 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38963 .60852 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39582 .55577 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .37154 .55939 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .34094 .59106 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34094 .59106 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34221 .56035 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .33849 .61195 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36745 .61568 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .38963 .60852 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.40334 .56017 m .43451 .56261 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .46198 .56647 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .43305 .59767 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .43305 .59767 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43451 .56261 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .48306 .57136 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .46055 .60101 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .46055 .60101 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46198 .56647 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .49571 .57682 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .4817 .60441 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .4817 .60441 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48306 .57136 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .47897 .62765 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49199 .62843 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .4815 .60925 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49571 .57682 m .49444 .60753 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49414 .61471 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .49444 .60753 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4987 .57114 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48569 .57036 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .45764 .62576 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .47897 .62765 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .46041 .60435 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .4817 .60441 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .4815 .60925 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4817 .60441 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .48569 .57036 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46436 .56847 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .43009 .62294 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .45764 .62576 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .43294 .60049 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .46055 .60101 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46041 .60435 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .46055 .60101 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .46436 .56847 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43681 .56565 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.39901 .61947 m .40191 .59471 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .39901 .61947 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43009 .62294 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .40178 .59806 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .43305 .59767 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43294 .60049 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .43305 .59767 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40573 .56218 m .43681 .56565 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.403 .59482 m .40334 .56017 L .40463 .59497 L .707 .577 .707 r
F
.40191 .59471 m .40334 .56017 L p .40298 .59676 L F P
0 g
s
.40191 .59471 m .40573 .56218 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40298 .59676 m .403 .59482 L .40463 .59497 L .707 .577 .707 r
F
.40178 .59806 m .40191 .59471 L p .40298 .59676 L F P
0 g
s
.37154 .55939 m .40334 .56017 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .37017 .59244 L p .38048 .59318 L .707 .577 .707 r
F P
0 g
s
.36997 .59728 m .37017 .59244 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .37154 .55939 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .38048 .59318 L .3834 .59339 L .707 .577 .707 r
F
.40334 .56017 m .40191 .59471 L p .37408 .59272 L F P
0 g
s
.40573 .56218 m .39901 .61947 L .36745 .61568 L p .707 .577 .707 r
F P
0 g
s
.40178 .59806 m .36997 .59728 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.40191 .59471 m .40178 .59806 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.3834 .59339 m .39135 .57442 L .39372 .57897 L .707 .577 .707 r
F
.38048 .59318 m .39135 .57442 L .3834 .59339 L F
.38048 .59318 m .37017 .59244 L .39135 .57442 L F
.39372 .57897 m .39135 .57442 L .40573 .56218 L F
.37017 .59244 m .37416 .55839 L .38987 .56028 L p F P
0 g
s
.38987 .56028 m .40573 .56218 L p .37017 .59244 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34615 .5913 L .36758 .59668 L .707 .577 .707 r
F
.36997 .59728 m .36715 .59737 L p .36758 .59668 L F P
0 g
s
.36715 .59737 m .34064 .59823 L p .36758 .59668 L .707 .577 .707 r
F P
0 g
s
.37154 .55939 m .37017 .59244 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36997 .59728 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37416 .55839 m .37017 .59244 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.35206 .59158 m .34094 .59106 L .37416 .55839 L .707 .577 .707 r
F
.34094 .59106 m .34521 .55466 L .35509 .55594 L p F P
0 g
s
.35509 .55594 m .37416 .55839 L p .34094 .59106 L .707 .577 .707 r
F P
0 g
s
.31665 .60083 m .32298 .5908 L .33842 .5973 L .707 .577 .707 r
F
.34064 .59823 m .33793 .59852 L p .33842 .5973 L F P
0 g
s
.33793 .59852 m .31665 .60083 L p .33842 .5973 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .34094 .59106 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34064 .59823 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34521 .55466 m .34094 .59106 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.32495 .59083 m .31707 .59071 L .34521 .55466 L .707 .577 .707 r
F
.31665 .60083 m .31707 .59071 L p .32298 .5908 L F P
0 g
s
.31707 .59071 m .31665 .60083 L .31501 .60123 L p .707 .577 .707 r
F P
0 g
s
.31501 .60123 m .30035 .60481 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .32169 .55136 L .32472 .55178 L p .707 .577 .707 r
F P
0 g
s
.32472 .55178 m .34521 .55466 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.32169 .55136 m .31707 .59071 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.30035 .60481 m .30091 .59144 L p .30616 .5912 L .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30192 .56692 L .30327 .56659 L p .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .29403 .59316 L p .29681 .59246 L .707 .577 .707 r
F P
0 g
s
.29365 .60052 m .30591 .54879 L .29343 .60469 L .707 .577 .707 r
F
.2927 .60452 m .29941 .54723 L .30591 .54879 L p F P
0 g
s
.29681 .59246 m .29403 .59316 L .30192 .56692 L .707 .577 .707 r
F
.29919 .60608 m .29343 .60469 L p .29612 .59263 L F P
0 g
s
.30091 .59144 m .29919 .60608 L p .29612 .59263 L .707 .577 .707 r
F P
0 g
s
.2927 .60452 m .29283 .6045 L p .29287 .60412 L .707 .577 .707 r
F P
0 g
s
.29343 .60469 m .2927 .60452 L p .29365 .60052 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29491 .5719 L .2964 .57084 L p .707 .577 .707 r
F P
0 g
s
.2964 .57084 m .30192 .56692 L p .29403 .59316 L .707 .577 .707 r
F P
0 g
s
.64328 .74572 m .64405 .76361 L .64701 .77511 L p .707 .577 .707 r
F P
0 g
s
.84703 .74281 m .84781 .7607 L .84485 .74921 L p .707 .577 .707 r
F P
0 g
s
.84485 .74921 m .84407 .73131 L .84703 .74281 L p .707 .577 .707 r
F P
0 g
s
.64405 .76361 m .64328 .74572 L .65029 .73408 L p .707 .577 .707 r
F P
0 g
s
.65029 .73408 m .65107 .75198 L .64405 .76361 L p .707 .577 .707 r
F P
0 g
s
.84407 .73131 m .84485 .74921 L .83221 .73898 L p .707 .577 .707 r
F P
0 g
s
.83221 .73898 m .83143 .72109 L .84407 .73131 L p .707 .577 .707 r
F P
0 g
s
.65107 .75198 m .65029 .73408 L .66659 .72344 L p .707 .577 .707 r
F P
0 g
s
.39637 .76277 m .39559 .74488 L .36442 .7435 L p .707 .577 .707 r
F P
0 g
s
.39559 .74488 m .39637 .76277 L .42817 .76049 L p .707 .577 .707 r
F P
0 g
s
.42817 .76049 m .42739 .7426 L .39559 .74488 L p .707 .577 .707 r
F P
0 g
s
.42739 .7426 m .42817 .76049 L .4575 .75477 L p .707 .577 .707 r
F P
0 g
s
.4575 .75477 m .45672 .73687 L .42739 .7426 L p .707 .577 .707 r
F P
0 g
s
.66659 .72344 m .66737 .74134 L .65107 .75198 L p .707 .577 .707 r
F P
0 g
s
.3652 .76139 m .36442 .7435 L .33695 .73859 L p .707 .577 .707 r
F P
0 g
s
.36442 .7435 m .3652 .76139 L .39637 .76277 L p .707 .577 .707 r
F P
0 g
s
.83143 .72109 m .83221 .73898 L .81112 .73102 L p .707 .577 .707 r
F P
0 g
s
.81112 .73102 m .81034 .71313 L .83143 .72109 L p .707 .577 .707 r
F P
0 g
s
.45672 .73687 m .4575 .75477 L .48149 .74617 L p .707 .577 .707 r
F P
0 g
s
.48149 .74617 m .48071 .72827 L .45672 .73687 L p .707 .577 .707 r
F P
0 g
s
.33695 .73859 m .33773 .75648 L .3652 .76139 L p .707 .577 .707 r
F P
0 g
s
.33773 .75648 m .33695 .73859 L .31587 .73063 L p .707 .577 .707 r
F P
0 g
s
.66737 .74134 m .66659 .72344 L .69058 .71484 L p .707 .577 .707 r
F P
0 g
s
.31587 .73063 m .31665 .74852 L .33773 .75648 L p .707 .577 .707 r
F P
0 g
s
.69058 .71484 m .69136 .73273 L .66737 .74134 L p .707 .577 .707 r
F P
0 g
s
.48071 .72827 m .48149 .74617 L .49779 .73552 L p .707 .577 .707 r
F P
0 g
s
.49779 .73552 m .49701 .71763 L .48071 .72827 L p .707 .577 .707 r
F P
0 g
s
.81034 .71313 m .81112 .73102 L .78365 .72611 L p .707 .577 .707 r
F P
0 g
s
.78365 .72611 m .78287 .70822 L .81034 .71313 L p .707 .577 .707 r
F P
0 g
s
.69136 .73273 m .69058 .71484 L .71991 .70912 L p .707 .577 .707 r
F P
0 g
s
.31665 .74852 m .31587 .73063 L .30322 .7204 L p .707 .577 .707 r
F P
0 g
s
.78287 .70822 m .78365 .72611 L .75249 .72473 L p .707 .577 .707 r
F P
0 g
s
.75249 .72473 m .75171 .70683 L .78287 .70822 L p .707 .577 .707 r
F P
0 g
s
.71991 .70912 m .72069 .72701 L .69136 .73273 L p .707 .577 .707 r
F P
0 g
s
.30322 .7204 m .304 .73829 L .31665 .74852 L p .707 .577 .707 r
F P
0 g
s
.72069 .72701 m .71991 .70912 L .75171 .70683 L p .707 .577 .707 r
F P
0 g
s
.75171 .70683 m .75249 .72473 L .72069 .72701 L p .707 .577 .707 r
F P
0 g
s
.49701 .71763 m .49779 .73552 L .5048 .72389 L p .707 .577 .707 r
F P
0 g
s
.5048 .72389 m .50402 .70599 L .49701 .71763 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.304 .73829 m .30322 .7204 L .30026 .7089 L p .707 .577 .707 r
F P
0 g
s
.30026 .7089 m .30104 .7268 L .304 .73829 L p .707 .577 .707 r
F P
0 g
s
.50402 .70599 m .5048 .72389 L .50184 .71239 L p .707 .577 .707 r
F P
0 g
s
.50184 .71239 m .50106 .6945 L .50402 .70599 L p .707 .577 .707 r
F P
0 g
s
.30104 .7268 m .30026 .7089 L .30728 .69727 L p .707 .577 .707 r
F P
0 g
s
.30728 .69727 m .30806 .71516 L .30104 .7268 L p .707 .577 .707 r
F P
0 g
s
.50106 .6945 m .50184 .71239 L .4892 .70216 L p .707 .577 .707 r
F P
0 g
s
.4892 .70216 m .48842 .68427 L .50106 .6945 L p .707 .577 .707 r
F P
0 g
s
.30806 .71516 m .30728 .69727 L .32358 .68663 L p .707 .577 .707 r
F P
0 g
s
.32358 .68663 m .32436 .70452 L .30806 .71516 L p .707 .577 .707 r
F P
0 g
s
.48842 .68427 m .4892 .70216 L .46811 .69421 L p .707 .577 .707 r
F P
0 g
s
.46811 .69421 m .46733 .67631 L .48842 .68427 L p .707 .577 .707 r
F P
0 g
s
.32436 .70452 m .32358 .68663 L .34757 .67802 L p .707 .577 .707 r
F P
0 g
s
.34757 .67802 m .34835 .69592 L .32436 .70452 L p .707 .577 .707 r
F P
0 g
s
.46733 .67631 m .46811 .69421 L .44064 .6893 L p .707 .577 .707 r
F P
0 g
s
.44064 .6893 m .43986 .6714 L .46733 .67631 L p .707 .577 .707 r
F P
0 g
s
.34835 .69592 m .34757 .67802 L .3769 .6723 L p .707 .577 .707 r
F P
0 g
s
.43986 .6714 m .44064 .6893 L .40948 .68791 L p .707 .577 .707 r
F P
0 g
s
.40948 .68791 m .4087 .67002 L .43986 .6714 L p .707 .577 .707 r
F P
0 g
s
.3769 .6723 m .37768 .69019 L .34835 .69592 L p .707 .577 .707 r
F P
0 g
s
.37768 .69019 m .3769 .6723 L .4087 .67002 L p .707 .577 .707 r
F P
0 g
s
.4087 .67002 m .40948 .68791 L .37768 .69019 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo5P00QWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001mOol007Ioo`D000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001]Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP<006aoo`00JGoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`8000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol70008Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol>00001Goo001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH01000FUIJEUYF3@00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH00`00FUIJEP04FUHC
0002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00010000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol30004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001COol40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF2@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002001TOol0
05=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000>001HOol005=oo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH005YF001JEPH00003FUH005YF009JEPT004moo`00;goo0P008Woo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH:0004FUH80017Ool002ioo`h001Moo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00eYF5P00
?Woo000^Ool20002FUH70003FUH9000>Ool2FUH01000FUIJEUYF300015YF00<005YFFUH00UYF3P00
1UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ@003Moo`00;Woo0P0015YF00@005YFFUIJEPL00003FUH005YF00=JEPT000Eoo`04001J
EP00FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEQ80039oo`00;Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT00003FUH005YF00=J
EPT0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000QJEP03001JEUYF00AJ
EP04001JEP000002FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEQ0002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000AJEP000000009JEPH000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`001EYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEP00008000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH?0003FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF2P000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JER8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=J
EPH000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHE000015YF0000000015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF0P0025YF00@005YFFUIJEPL000=JEP05001JEUYFFUH0000^Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH0000002ioo`00;7oo10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH00eYF
2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
<7oo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010000eYF0P001eYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00=Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00EJEPP000AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool003eoo`T000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH<
0002FUH2000^Ool004Ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH8
0004FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF2P00;Woo001?Ool80004FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH03`0015YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2OolJ000hOol005Moo``00004FUH005YFFUH90004
FUH00`00FUIJEP06FUH00`00FUH00004000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPMoo`D0
04Qoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<0
05YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00Ggoo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YF
FUIJEP8000Qoo`<004Uoo`00GGoo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00Fgoo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00FWoo0P001eYF00<005YFFUH0
0UYF20001eYF00<005YF00001`0015YF00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0019OolA00000eYF001JEP05FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH6
0004FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00E7oo0010Ool90004FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH3000015YF001JEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00>Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00@005YF000000Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH20002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000hOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH2000015YF000000000Woo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00EGoo000fOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002FUH200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000080003FUH01000FUIJEUYF0P000goo5`00>goo000dOol20006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH=000015YF0000000015YF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF0P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo300000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Ioo`00<goo0P001eYF00<005YFFUH00UYF200037oo00<005YF00001000
0UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH01eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
37oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=7oo000aOol20000
0eYF001JEP05FUH6000DOol20005Ool40004FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000027oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00P00<Woo000_Ool20004FUH01000FUIJEUYF0P003Goo0`002Woo0`00
27oo0`0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP80031oo`00;goo00=JEP00FUH00eYF00@005YF000000ioo`D000Uoo`800003FUH007oo
00Uoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP80
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<0
00IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP<002ioo`00;Woo00<007oo000015YF0P00
27oo3@002Goo0P000UYF00<007ooOol027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEUYFFUH20004FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP04000GOol50005FUH01000FUIJ
EP00;Goo000^Ool00`00Ool00002FUH<0003FUH00`00FUIJEP02FUH@0002FUH30008Ool01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF100000=JEP00FUH00eYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH00eYF
100087oo0P000eYF00@005YFFUH002eoo`00;Woo00<005YF00000`001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00P001Woo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03001JEP0000<002Io
o`800005FUH005YFFUH0000]Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH01000FUIJEUYF1@0000Eoo`00FUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP<0
0004FUH00000000WOol20002FUH2000/Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH01000FUIJEUYF6@001EYF00<0
05YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEUYF009JEP8002Moo`04001JEUYF000/Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000X000IJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP<000=JEP03001JEUYF00=JEP8002Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001P002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF0P0015YF00<005YFFUH00eYF00<005YF00009goo0P00;7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000Woo1@001EYF00@005YFFUH002Eoo`03001JEP0002aoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00008000Mo
o`8000=JEP04001JEUYF000TOol200000eYF001oo`0[Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEP0001L0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00008000Uoo`800005FUH005YFFUH0000ROol2
000015YF001JEP00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP05001JEP00001JEP020009Ool20003FUH00`00Oomoo`0MOol20003
FUH2000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
0P002Goo0P0000=JEP00Ool077oo0P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH00002FUH6
00000eYF001JEP06FUH00`00FUIJEP05FUH30005FUH80003FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF0P0000=JEP00FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP0000000eYF00<005YF00000P0027oo
0P006goo0P000eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P000eYF0P000eYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF1@0015YF00H005YFFUH005YF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF00000003FUH00`00FUIJEP02FUH50003Ool2000E
Ool60005FUH01000FUIJEP00;goo000/Ool20002FUH00`00FUIJEP03FUH200000eYF001JEP05FUH0
0`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH7000015YF001JEUYF0P0015YF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000AJEP00FUH0009JEP03001JEUYF00=JEP04001JEUYFFUH80009Ool90004
FUH00`00FUIJEP04FUH3000`Ool002aoo`80009JEP03001JEUYF00=JEP03001JEP0000@000=JEP03
001JEUYF00AJEPD000IJEP03001JEUYF00D000EJEP@00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP000002FUH30005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00<Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF6000
0eYF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EP000004FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00=7oo000^Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP001UYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000003Ioo`00<7oo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00001eYF00<005YFFUH01@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@00>7oo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP060002FUH00`00FUIJEP05FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP03FUH00`00FUH000080004FUH00`00FUIJEP02FUH9000mOol0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60006Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001Goo2@00AWoo0013
OolI000>Ool20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00K7oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YFFUH005YF001DOol006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00=JEPD000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
05Eoo`00LGoo1`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
20001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P00EGoo001hOol<0006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH70004FUH50006FUH00`00FUIJEP02FUH50002FUH40002FUH2001EOol008Ao
ob<0009JEPD0009JEPT00003FUH005YF00EJEP03001JEUYF00@005Eoo`00SWoo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<005Eoo`00T7oo100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009Aoo`<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYFFUH005YFEWoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001GOol009aooa4000EJEP03001JEUYF009JEPd005Uoo`00[Goo
2P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57054 .63648 m .56383 .69376 L .59491 .69724 L p .707 .577 .707 r
F P
0 g
s
.59491 .69724 m .60162 .63995 L .57054 .63648 L p .707 .577 .707 r
F P
0 g
s
.60162 .63995 m .59491 .69724 L .62647 .70102 L p .707 .577 .707 r
F P
0 g
s
.62647 .70102 m .63319 .64374 L .60162 .63995 L p .707 .577 .707 r
F P
0 g
s
.63319 .64374 m .62647 .70102 L .65543 .70475 L p .707 .577 .707 r
F P
0 g
s
.65543 .70475 m .66215 .64747 L .63319 .64374 L p .707 .577 .707 r
F P
0 g
s
.54299 .63366 m .53628 .69094 L .56383 .69376 L p .707 .577 .707 r
F P
0 g
s
.56383 .69376 m .57054 .63648 L .54299 .63366 L p .707 .577 .707 r
F P
0 g
s
.66215 .64747 m .65543 .70475 L .67895 .70806 L p .707 .577 .707 r
F P
0 g
s
.67895 .70806 m .68567 .65077 L .66215 .64747 L p .707 .577 .707 r
F P
0 g
s
.52167 .63177 m .51495 .68905 L .53628 .69094 L p .707 .577 .707 r
F P
0 g
s
.53628 .69094 m .54299 .63366 L .52167 .63177 L p .707 .577 .707 r
F P
0 g
s
.59447 .84038 m .59604 .8025 L .56488 .80006 L p .707 .577 .707 r
F P
0 g
s
.59604 .8025 m .59447 .84038 L .62627 .84116 L p .707 .577 .707 r
F P
0 g
s
.62627 .84116 m .62784 .80328 L .59604 .8025 L p .707 .577 .707 r
F P
0 g
s
.62784 .80328 m .62627 .84116 L .6556 .84021 L p .707 .577 .707 r
F P
0 g
s
.6556 .84021 m .65717 .80233 L .62784 .80328 L p .707 .577 .707 r
F P
0 g
s
.68567 .65077 m .67895 .70806 L .69473 .71062 L p .707 .577 .707 r
F P
0 g
s
.56488 .80006 m .56331 .83795 L .59447 .84038 L p .707 .577 .707 r
F P
0 g
s
.56331 .83795 m .56488 .80006 L .53741 .79621 L p .707 .577 .707 r
F P
0 g
s
.69473 .71062 m .70144 .65333 L .68567 .65077 L p .707 .577 .707 r
F P
0 g
s
.53741 .79621 m .53584 .83409 L .56331 .83795 L p .707 .577 .707 r
F P
0 g
s
.50865 .63099 m .50193 .68828 L .51495 .68905 L p .707 .577 .707 r
F P
0 g
s
.51495 .68905 m .52167 .63177 L .50865 .63099 L p .707 .577 .707 r
F P
0 g
s
.60217 .82398 m .60139 .80608 L .57023 .8047 L p .707 .577 .707 r
F P
0 g
s
.60139 .80608 m .60217 .82398 L .63397 .8217 L p .707 .577 .707 r
F P
0 g
s
.63397 .8217 m .63319 .8038 L .60139 .80608 L p .707 .577 .707 r
F P
0 g
s
.65717 .80233 m .6556 .84021 L .67959 .83762 L p .707 .577 .707 r
F P
0 g
s
.67959 .83762 m .68116 .79973 L .65717 .80233 L p .707 .577 .707 r
F P
0 g
s
.63319 .8038 m .63397 .8217 L .66331 .81597 L p .707 .577 .707 r
F P
0 g
s
.66331 .81597 m .66253 .79808 L .63319 .8038 L p .707 .577 .707 r
F P
0 g
s
.57101 .8226 m .57023 .8047 L .54276 .79979 L p .707 .577 .707 r
F P
0 g
s
.57023 .8047 m .57101 .8226 L .60217 .82398 L p .707 .577 .707 r
F P
0 g
s
.53584 .83409 m .53741 .79621 L .51632 .79131 L p .707 .577 .707 r
F P
0 g
s
.68116 .79973 m .67959 .83762 L .69589 .83364 L p .707 .577 .707 r
F P
0 g
s
.69589 .83364 m .69746 .79575 L .68116 .79973 L p .707 .577 .707 r
F P
0 g
s
.66253 .79808 m .66331 .81597 L .6873 .80737 L p .707 .577 .707 r
F P
0 g
s
.6873 .80737 m .68652 .78948 L .66253 .79808 L p .707 .577 .707 r
F P
0 g
s
.54276 .79979 m .54354 .81769 L .57101 .8226 L p .707 .577 .707 r
F P
0 g
s
.51632 .79131 m .51475 .82919 L .53584 .83409 L p .707 .577 .707 r
F P
0 g
s
.70144 .65333 m .69473 .71062 L .70122 .71219 L p .707 .577 .707 r
F P
0 g
s
.70122 .71219 m .70794 .6549 L .70144 .65333 L p .707 .577 .707 r
F P
0 g
s
.54354 .81769 m .54276 .79979 L .52167 .79183 L p .707 .577 .707 r
F P
0 g
s
.50522 .63141 m .49851 .68869 L .50193 .68828 L p .707 .577 .707 r
F P
0 g
s
.50193 .68828 m .50865 .63099 L .50522 .63141 L p .707 .577 .707 r
F P
0 g
s
.52167 .79183 m .52245 .80973 L .54354 .81769 L p .707 .577 .707 r
F P
0 g
s
.51475 .82919 m .51632 .79131 L .50368 .78585 L p .707 .577 .707 r
F P
0 g
s
.69746 .79575 m .69589 .83364 L .69861 .83171 L p .707 .577 .707 r
F P
0 g
s
.69861 .83171 m .7029 .82866 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.69906 .8054 m .69746 .79575 L .69861 .83171 L .707 .577 .707 r
F
.69915 .79963 m .7036 .79673 L p .69923 .79488 L F P
0 g
s
.7036 .79673 m .70282 .77884 L .69947 .78102 L p .707 .577 .707 r
F P
0 g
s
.7036 .79673 m .69947 .78102 L .69923 .79488 L .707 .577 .707 r
F
.70282 .77884 m .7036 .79673 L .71061 .78509 L p F P
0 g
s
.7029 .82866 m .70447 .79078 L .69924 .79449 L p .707 .577 .707 r
F P
0 g
s
.69924 .79449 m .69746 .79575 L p .69906 .8054 L .707 .577 .707 r
F P
0 g
s
.7029 .82866 m .69924 .79449 L .69906 .8054 L .707 .577 .707 r
F
.69947 .78102 m .68652 .78948 L p .69923 .79488 L F P
0 g
s
.68652 .78948 m .6873 .80737 L .69915 .79963 L p .707 .577 .707 r
F P
0 g
s
.69923 .79488 m .68652 .78948 L .69915 .79963 L .707 .577 .707 r
F
.50368 .78585 m .50211 .82374 L .51475 .82919 L p F P
0 g
s
.52245 .80973 m .52167 .79183 L .50903 .78161 L p .707 .577 .707 r
F P
0 g
s
.70794 .6549 m .70122 .71219 L .69779 .7126 L p .707 .577 .707 r
F P
0 g
s
.69779 .7126 m .70451 .65531 L .70794 .6549 L p .707 .577 .707 r
F P
0 g
s
.50903 .78161 m .50981 .7995 L .52245 .80973 L p .707 .577 .707 r
F P
0 g
s
.48726 .82194 m .49019 .31815 L .44618 .31537 L p .707 .577 .707 r
F P
0 g
s
.50211 .82374 m .50368 .78585 L .50072 .78037 L p .707 .577 .707 r
F P
0 g
s
.51171 .63297 m .505 .69026 L .49851 .68869 L p .707 .577 .707 r
F P
0 g
s
.49851 .68869 m .50522 .63141 L .51171 .63297 L p .707 .577 .707 r
F P
0 g
s
.50072 .78037 m .49915 .81825 L .50211 .82374 L p .707 .577 .707 r
F P
0 g
s
.50981 .7995 m .50903 .78161 L .50607 .77011 L p .707 .577 .707 r
F P
0 g
s
.50607 .77011 m .50685 .788 L .50981 .7995 L p .707 .577 .707 r
F P
0 g
s
.52749 .63553 m .52078 .69282 L .505 .69026 L p .707 .577 .707 r
F P
0 g
s
.505 .69026 m .51171 .63297 L .52749 .63553 L p .707 .577 .707 r
F P
0 g
s
.50685 .788 m .50607 .77011 L .51164 .76086 L p .707 .577 .707 r
F P
0 g
s
.51164 .76086 m .51308 .75847 L p .51171 .76497 L .707 .577 .707 r
F P
0 g
s
.50685 .788 m .51164 .76086 L .51171 .76497 L .707 .577 .707 r
F
.51187 .77438 m .52403 .77141 L p .51227 .79895 L F P
0 g
s
.51308 .75847 m .51386 .77637 L .50685 .788 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .50773 .77539 L .51187 .77438 L p .707 .577 .707 r
F P
0 g
s
.50616 .81327 m .51187 .77438 L .51227 .79895 L .707 .577 .707 r
F
.49915 .81825 m .50072 .78037 L .50773 .77539 L p F P
0 g
s
.50773 .77539 m .50616 .81327 L .49915 .81825 L p .707 .577 .707 r
F P
0 g
s
.55101 .63884 m .5443 .69613 L .52078 .69282 L p .707 .577 .707 r
F P
0 g
s
.52078 .69282 m .52749 .63553 L .55101 .63884 L p .707 .577 .707 r
F P
0 g
s
.52403 .77141 m .52246 .80929 L .50616 .81327 L p .707 .577 .707 r
F P
0 g
s
.51386 .77637 m .51308 .75847 L .52938 .74783 L p .707 .577 .707 r
F P
0 g
s
.52938 .74783 m .53016 .76573 L .51386 .77637 L p .707 .577 .707 r
F P
0 g
s
.52246 .80929 m .52403 .77141 L .54802 .76882 L p .707 .577 .707 r
F P
0 g
s
.54802 .76882 m .54645 .8067 L .52246 .80929 L p .707 .577 .707 r
F P
0 g
s
.49019 .31815 m .48726 .82194 L .53221 .82114 L p .707 .577 .707 r
F P
0 g
s
.53016 .76573 m .52938 .74783 L .55337 .73923 L p .707 .577 .707 r
F P
0 g
s
.55337 .73923 m .55415 .75712 L .53016 .76573 L p .707 .577 .707 r
F P
0 g
s
.53221 .82114 m .53513 .31735 L .49019 .31815 L p .707 .577 .707 r
F P
0 g
s
.71061 .78509 m .70983 .7672 L .70282 .77884 L p .707 .577 .707 r
F P
0 g
s
.57997 .64257 m .57325 .69986 L .5443 .69613 L p .707 .577 .707 r
F P
0 g
s
.5443 .69613 m .55046 .64356 L p .57997 .64257 L .707 .577 .707 r
F P
0 g
s
.55046 .64356 m .55101 .63884 L .55282 .63907 L p .707 .577 .707 r
F P
0 g
s
.55282 .63907 m .57997 .64257 L p .55046 .64356 L .707 .577 .707 r
F P
0 g
s
.61153 .64636 m .60482 .70364 L .57627 .70022 L p .707 .577 .707 r
F P
0 g
s
.57627 .70022 m .57325 .69986 L p .57734 .69415 L .707 .577 .707 r
F P
0 g
s
.57734 .69415 m .61153 .64636 L .57627 .70022 L .707 .577 .707 r
F
.64261 .64983 m .6359 .70712 L .61057 .70428 L p F P
0 g
s
.61057 .70428 m .60482 .70364 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.61127 .69446 m .64261 .64983 L .61057 .70428 L .707 .577 .707 r
F
.67017 .65265 m .66345 .70994 L .6359 .70712 L p F P
0 g
s
.6359 .70712 m .64261 .64983 L .67017 .65265 L p .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61153 .64636 L .61466 .6467 L p .707 .577 .707 r
F P
0 g
s
.61466 .6467 m .64261 .64983 L p .61127 .69446 L .707 .577 .707 r
F P
0 g
s
.60482 .70364 m .61466 .6467 L .61127 .69446 L .707 .577 .707 r
F
.63874 .80896 m .64031 .77108 L .66778 .77494 L p F P
0 g
s
.64567 .73261 m .64645 .7505 L .61529 .74912 L p .707 .577 .707 r
F P
0 g
s
.61529 .74912 m .61451 .73123 L .64567 .73261 L p .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64367 .28475 L .64008 .28876 L p .707 .577 .707 r
F P
0 g
s
.64008 .28876 m .63367 .2959 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.64075 .78854 m .64008 .28876 L .63466 .36497 L .707 .577 .707 r
F
.64031 .77108 m .63874 .80896 L .60758 .80653 L p F P
0 g
s
.60758 .80653 m .60915 .76864 L .64031 .77108 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .64075 .78854 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63367 .2959 m .63315 .38633 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.63315 .38633 m .63075 .7997 L p .63466 .36497 L .707 .577 .707 r
F P
0 g
s
.57578 .80575 m .57735 .76786 L .60915 .76864 L p .707 .577 .707 r
F P
0 g
s
.60915 .76864 m .60758 .80653 L .57578 .80575 L p .707 .577 .707 r
F P
0 g
s
.58348 .7514 m .5827 .73351 L .61451 .73123 L p .707 .577 .707 r
F P
0 g
s
.61451 .73123 m .61529 .74912 L .58348 .7514 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .63075 .7997 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.61056 .30566 m .60937 .51188 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.57325 .69986 m .57997 .64257 L .61153 .64636 L p .707 .577 .707 r
F P
0 g
s
.60937 .51188 m .60764 .80945 L p .61717 .46745 L .707 .577 .707 r
F P
0 g
s
.54645 .8067 m .54802 .76882 L .57735 .76786 L p .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .55337 .73923 L .56591 .73678 L p .707 .577 .707 r
F P
0 g
s
.56591 .73678 m .5827 .73351 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.55415 .75712 m .56591 .73678 L .56796 .7457 L .707 .577 .707 r
F
.57735 .76786 m .57578 .80575 L .54645 .8067 L p F P
0 g
s
.5827 .73351 m .58348 .7514 L .56988 .75405 L p .707 .577 .707 r
F P
0 g
s
.56988 .75405 m .55415 .75712 L p .56796 .7457 L .707 .577 .707 r
F P
0 g
s
.56796 .7457 m .5827 .73351 L .56988 .75405 L .707 .577 .707 r
F
.57496 .59696 m .57395 .77173 L p .5923 .56399 L F P
0 g
s
.57395 .77173 m .57369 .81684 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.5923 .56399 m .57395 .77173 L .57627 .7818 L .707 .577 .707 r
F
.60764 .80945 m .5923 .56399 L .57627 .7818 L F
.57369 .81684 m .58382 .81463 L p .57627 .7818 L F P
0 g
s
.58382 .81463 m .60764 .80945 L p .57627 .7818 L .707 .577 .707 r
F P
0 g
s
.57661 .31305 m .57496 .59696 L p .5923 .56399 L .707 .577 .707 r
F P
0 g
s
.53513 .31735 m .53221 .82114 L .57369 .81684 L p .707 .577 .707 r
F P
0 g
s
.57369 .81684 m .57661 .31305 L .53513 .31735 L p .707 .577 .707 r
F P
0 g
s
.44326 .81916 m .44618 .31537 L .40741 .30927 L p .707 .577 .707 r
F P
0 g
s
.44618 .31537 m .44326 .81916 L .48726 .82194 L p .707 .577 .707 r
F P
0 g
s
.60764 .80945 m .61056 .30566 L .57661 .31305 L p .707 .577 .707 r
F P
0 g
s
.70447 .79078 m .7029 .82866 L .69994 .82317 L p .707 .577 .707 r
F P
0 g
s
.69994 .82317 m .70151 .78529 L .70447 .79078 L p .707 .577 .707 r
F P
0 g
s
.70451 .65531 m .69779 .7126 L .68478 .71183 L p .707 .577 .707 r
F P
0 g
s
.68478 .71183 m .69149 .65454 L .70451 .65531 L p .707 .577 .707 r
F P
0 g
s
.22754 .59966 m .22082 .65695 L .2519 .66042 L p .707 .577 .707 r
F P
0 g
s
.2519 .66042 m .25861 .60313 L .22754 .59966 L p .707 .577 .707 r
F P
0 g
s
.25861 .60313 m .2519 .66042 L .28346 .66421 L p .707 .577 .707 r
F P
0 g
s
.28346 .66421 m .29018 .60692 L .25861 .60313 L p .707 .577 .707 r
F P
0 g
s
.70983 .7672 m .71061 .78509 L .70765 .7736 L p .707 .577 .707 r
F P
0 g
s
.70765 .7736 m .70687 .75571 L .70983 .7672 L p .707 .577 .707 r
F P
0 g
s
.40449 .81306 m .40741 .30927 L .37769 .30045 L p .707 .577 .707 r
F P
0 g
s
.40741 .30927 m .40449 .81306 L .44326 .81916 L p .707 .577 .707 r
F P
0 g
s
.29018 .60692 m .28346 .66421 L .31242 .66794 L p .707 .577 .707 r
F P
0 g
s
.31242 .66794 m .31914 .61065 L .29018 .60692 L p .707 .577 .707 r
F P
0 g
s
.19998 .59684 m .19327 .65413 L .22082 .65695 L p .707 .577 .707 r
F P
0 g
s
.22082 .65695 m .22754 .59966 L .19998 .59684 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31914 .61065 m .31242 .66794 L .33594 .67124 L p .707 .577 .707 r
F P
0 g
s
.33594 .67124 m .34266 .61396 L .31914 .61065 L p .707 .577 .707 r
F P
0 g
s
.63075 .7997 m .63367 .2959 L .61056 .30566 L p .707 .577 .707 r
F P
0 g
s
.17866 .59495 m .17194 .65224 L .19327 .65413 L p .707 .577 .707 r
F P
0 g
s
.19327 .65413 m .19998 .59684 L .17866 .59495 L p .707 .577 .707 r
F P
0 g
s
.69149 .65454 m .68478 .71183 L .66345 .70994 L p .707 .577 .707 r
F P
0 g
s
.70151 .78529 m .69994 .82317 L .6873 .81772 L p .707 .577 .707 r
F P
0 g
s
.6873 .81772 m .68887 .77983 L .70151 .78529 L p .707 .577 .707 r
F P
0 g
s
.66345 .70994 m .67017 .65265 L .69149 .65454 L p .707 .577 .707 r
F P
0 g
s
.70687 .75571 m .70765 .7736 L .69501 .76337 L p .707 .577 .707 r
F P
0 g
s
.69501 .76337 m .69423 .74548 L .70687 .75571 L p .707 .577 .707 r
F P
0 g
s
.25146 .80357 m .25303 .76569 L .22187 .76325 L p .707 .577 .707 r
F P
0 g
s
.25303 .76569 m .25146 .80357 L .28326 .80435 L p .707 .577 .707 r
F P
0 g
s
.28326 .80435 m .28483 .76647 L .25303 .76569 L p .707 .577 .707 r
F P
0 g
s
.37477 .80424 m .37769 .30045 L .35991 .28979 L p .707 .577 .707 r
F P
0 g
s
.37769 .30045 m .37477 .80424 L .40449 .81306 L p .707 .577 .707 r
F P
0 g
s
.28483 .76647 m .28326 .80435 L .3126 .8034 L p .707 .577 .707 r
F P
0 g
s
.3126 .8034 m .31416 .76551 L .28483 .76647 L p .707 .577 .707 r
F P
0 g
s
.34266 .61396 m .33594 .67124 L .35172 .67381 L p .707 .577 .707 r
F P
0 g
s
.22187 .76325 m .2203 .80113 L .25146 .80357 L p .707 .577 .707 r
F P
0 g
s
.2203 .80113 m .22187 .76325 L .1944 .75939 L p .707 .577 .707 r
F P
0 g
s
.35172 .67381 m .35844 .61652 L .34266 .61396 L p .707 .577 .707 r
F P
0 g
s
.1944 .75939 m .19283 .79728 L .2203 .80113 L p .707 .577 .707 r
F P
0 g
s
.16564 .59418 m .15893 .65146 L .17194 .65224 L p .707 .577 .707 r
F P
0 g
s
.17194 .65224 m .17866 .59495 L .16564 .59418 L p .707 .577 .707 r
F P
0 g
s
.25916 .78716 m .25838 .76927 L .22722 .76789 L p .707 .577 .707 r
F P
0 g
s
.25838 .76927 m .25916 .78716 L .29097 .78488 L p .707 .577 .707 r
F P
0 g
s
.29097 .78488 m .29019 .76699 L .25838 .76927 L p .707 .577 .707 r
F P
0 g
s
.31416 .76551 m .3126 .8034 L .33658 .8008 L p .707 .577 .707 r
F P
0 g
s
.33658 .8008 m .33815 .76292 L .31416 .76551 L p .707 .577 .707 r
F P
0 g
s
.29019 .76699 m .29097 .78488 L .3203 .77916 L p .707 .577 .707 r
F P
0 g
s
.3203 .77916 m .31952 .76127 L .29019 .76699 L p .707 .577 .707 r
F P
0 g
s
.228 .78578 m .22722 .76789 L .19975 .76298 L p .707 .577 .707 r
F P
0 g
s
.22722 .76789 m .228 .78578 L .25916 .78716 L p .707 .577 .707 r
F P
0 g
s
.19283 .79728 m .1944 .75939 L .17331 .7545 L p .707 .577 .707 r
F P
0 g
s
.68887 .77983 m .6873 .81772 L .66621 .81282 L p .707 .577 .707 r
F P
0 g
s
.66621 .81282 m .66778 .77494 L .68887 .77983 L p .707 .577 .707 r
F P
0 g
s
.69423 .74548 m .69501 .76337 L .67392 .75541 L p .707 .577 .707 r
F P
0 g
s
.67392 .75541 m .67314 .73752 L .69423 .74548 L p .707 .577 .707 r
F P
0 g
s
.33815 .76292 m .33658 .8008 L .35288 .79682 L p .707 .577 .707 r
F P
0 g
s
.35288 .79682 m .35445 .75894 L .33815 .76292 L p .707 .577 .707 r
F P
0 g
s
.31952 .76127 m .3203 .77916 L .34429 .77056 L p .707 .577 .707 r
F P
0 g
s
.34429 .77056 m .34351 .75266 L .31952 .76127 L p .707 .577 .707 r
F P
0 g
s
.19975 .76298 m .20053 .78087 L .228 .78578 L p .707 .577 .707 r
F P
0 g
s
.17331 .7545 m .17174 .79238 L .19283 .79728 L p .707 .577 .707 r
F P
0 g
s
.35844 .61652 m .35172 .67381 L .35821 .67537 L p .707 .577 .707 r
F P
0 g
s
.35821 .67537 m .36493 .61808 L .35844 .61652 L p .707 .577 .707 r
F P
0 g
s
.20053 .78087 m .19975 .76298 L .17866 .75502 L p .707 .577 .707 r
F P
0 g
s
.35445 .75894 m .35288 .79682 L .3556 .79489 L p .707 .577 .707 r
F P
0 g
s
.35605 .76859 m .35445 .75894 L .3556 .79489 L .707 .577 .707 r
F
.35615 .76281 m .36059 .75992 L p .35623 .75806 L F P
0 g
s
.36059 .75992 m .35981 .74202 L .35646 .74421 L p .707 .577 .707 r
F P
0 g
s
.36059 .75992 m .35646 .74421 L .35623 .75806 L .707 .577 .707 r
F
.35981 .74202 m .36059 .75992 L .3676 .74828 L p F P
0 g
s
.3599 .79184 m .36146 .75396 L .35623 .75768 L p .707 .577 .707 r
F P
0 g
s
.35623 .75768 m .35445 .75894 L p .35605 .76859 L .707 .577 .707 r
F P
0 g
s
.3599 .79184 m .35623 .75768 L .35605 .76859 L .707 .577 .707 r
F
.35646 .74421 m .34351 .75266 L p .35623 .75806 L F P
0 g
s
.34351 .75266 m .34429 .77056 L .35615 .76281 L p .707 .577 .707 r
F P
0 g
s
.35623 .75806 m .34351 .75266 L .35615 .76281 L .707 .577 .707 r
F
.3556 .79489 m .3599 .79184 L p .35605 .76859 L F P
0 g
s
.35821 .67537 m .35478 .67579 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36493 .61808 m .36387 .62713 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36387 .62713 m .35821 .67537 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35582 .27831 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .36493 .61808 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.35478 .67579 m .36095 .62322 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36095 .62322 m .3615 .6185 L p .36344 .62656 L .707 .577 .707 r
F P
0 g
s
.36146 .75396 m .3599 .79184 L .35693 .78636 L p .707 .577 .707 r
F P
0 g
s
.35693 .78636 m .3585 .74848 L .36146 .75396 L p .707 .577 .707 r
F P
0 g
s
.3615 .6185 m .35478 .67579 L .34177 .67501 L p .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .34848 .61772 L .36069 .61845 L p .707 .577 .707 r
F P
0 g
s
.36069 .61845 m .3615 .6185 L p .3608 .6205 L .707 .577 .707 r
F P
0 g
s
.34177 .67501 m .36069 .61845 L .3608 .6205 L .707 .577 .707 r
F
.358 .61927 m .35826 .5737 L p .35659 .61738 L F P
0 g
s
.35826 .5737 m .35991 .28979 L p .35722 .55455 L .707 .577 .707 r
F P
0 g
s
.35826 .5737 m .35722 .55455 L .35659 .61738 L .707 .577 .707 r
F
.3585 .74848 m .35693 .78636 L .34429 .7809 L p F P
0 g
s
.34429 .7809 m .34586 .74302 L .3585 .74848 L p .707 .577 .707 r
F P
0 g
s
.3676 .74828 m .36682 .73038 L .35981 .74202 L p .707 .577 .707 r
F P
0 g
s
.36386 .71889 m .36464 .73678 L .35786 .7313 L p .707 .577 .707 r
F P
0 g
s
.35786 .7313 m .352 .72656 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.35817 .72257 m .36386 .71889 L .35786 .7313 L .707 .577 .707 r
F
.352 .72656 m .35122 .70866 L .35846 .71452 L p F P
0 g
s
.35846 .71452 m .36386 .71889 L p .35817 .72257 L .707 .577 .707 r
F P
0 g
s
.352 .72656 m .35846 .71452 L .35817 .72257 L .707 .577 .707 r
F
.35691 .75809 m .358 .61927 L .35659 .61738 L F
.35699 .79358 m .35725 .74847 L p .35691 .75809 L F P
0 g
s
.35725 .74847 m .358 .61927 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35577 .79016 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.35577 .79016 m .35699 .79358 L p .35691 .75809 L .707 .577 .707 r
F P
0 g
s
.35691 .75809 m .35659 .61738 L .35577 .79016 L .707 .577 .707 r
F
.35582 .27831 m .35387 .61375 L p .35659 .61738 L F P
0 g
s
.35387 .61375 m .3529 .78211 L p .35659 .61738 L .707 .577 .707 r
F P
0 g
s
.36682 .73038 m .3676 .74828 L .36464 .73678 L p .707 .577 .707 r
F P
0 g
s
.36464 .73678 m .36386 .71889 L .36682 .73038 L p .707 .577 .707 r
F P
0 g
s
.35991 .28979 m .35699 .79358 L .37477 .80424 L p .707 .577 .707 r
F P
0 g
s
.16221 .59459 m .1555 .65188 L .15893 .65146 L p .707 .577 .707 r
F P
0 g
s
.15893 .65146 m .16564 .59418 L .16221 .59459 L p .707 .577 .707 r
F P
0 g
s
.17866 .75502 m .17944 .77291 L .20053 .78087 L p .707 .577 .707 r
F P
0 g
s
.17174 .79238 m .17331 .7545 L .16067 .74904 L p .707 .577 .707 r
F P
0 g
s
.66778 .77494 m .66621 .81282 L .63874 .80896 L p .707 .577 .707 r
F P
0 g
s
.67314 .73752 m .67392 .75541 L .64645 .7505 L p .707 .577 .707 r
F P
0 g
s
.64645 .7505 m .64567 .73261 L .67314 .73752 L p .707 .577 .707 r
F P
0 g
s
.16067 .74904 m .1591 .78692 L .17174 .79238 L p .707 .577 .707 r
F P
0 g
s
.17944 .77291 m .17866 .75502 L .16602 .74479 L p .707 .577 .707 r
F P
0 g
s
.16602 .74479 m .1668 .76268 L .17944 .77291 L p .707 .577 .707 r
F P
0 g
s
.64367 .28475 m .64075 .78854 L .63666 .77706 L p .707 .577 .707 r
F P
0 g
s
.63666 .77706 m .63958 .27327 L .64367 .28475 L p .707 .577 .707 r
F P
0 g
s
.1591 .78692 m .16067 .74904 L .15771 .74355 L p .707 .577 .707 r
F P
0 g
s
.1687 .59615 m .16199 .65344 L .1555 .65188 L p .707 .577 .707 r
F P
0 g
s
.1555 .65188 m .16221 .59459 L .1687 .59615 L p .707 .577 .707 r
F P
0 g
s
.15771 .74355 m .15614 .78143 L .1591 .78692 L p .707 .577 .707 r
F P
0 g
s
.3529 .78211 m .35582 .27831 L .36581 .26716 L p .707 .577 .707 r
F P
0 g
s
.1668 .76268 m .16602 .74479 L .16306 .7333 L p .707 .577 .707 r
F P
0 g
s
.16306 .7333 m .16384 .75119 L .1668 .76268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.18448 .59872 m .17777 .656 L .16199 .65344 L p .707 .577 .707 r
F P
0 g
s
.16199 .65344 m .1687 .59615 L .18448 .59872 L p .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16306 .7333 L .16863 .72405 L p .707 .577 .707 r
F P
0 g
s
.16863 .72405 m .17007 .72166 L p .1687 .72816 L .707 .577 .707 r
F P
0 g
s
.16384 .75119 m .16863 .72405 L .1687 .72816 L .707 .577 .707 r
F
.16886 .73756 m .18102 .73459 L p .16926 .76213 L F P
0 g
s
.17007 .72166 m .17085 .73955 L .16384 .75119 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16472 .73857 L .16886 .73756 L p .707 .577 .707 r
F P
0 g
s
.16315 .77646 m .16886 .73756 L .16926 .76213 L .707 .577 .707 r
F
.15614 .78143 m .15771 .74355 L .16472 .73857 L p F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63958 .27327 m .63666 .77706 L .61888 .7664 L p .707 .577 .707 r
F P
0 g
s
.61888 .7664 m .6218 .26261 L .63958 .27327 L p .707 .577 .707 r
F P
0 g
s
.16472 .73857 m .16315 .77646 L .15614 .78143 L p .707 .577 .707 r
F P
0 g
s
.34848 .61772 m .34177 .67501 L .32044 .67312 L p .707 .577 .707 r
F P
0 g
s
.32044 .67312 m .32716 .61583 L .34848 .61772 L p .707 .577 .707 r
F P
0 g
s
.36289 .77095 m .36581 .26716 L .38892 .2574 L p .707 .577 .707 r
F P
0 g
s
.36581 .26716 m .36289 .77095 L .3529 .78211 L p .707 .577 .707 r
F P
0 g
s
.208 .60202 m .20129 .65931 L .17777 .656 L p .707 .577 .707 r
F P
0 g
s
.17777 .656 m .18448 .59872 L .208 .60202 L p .707 .577 .707 r
F P
0 g
s
.18102 .73459 m .17945 .77248 L .16315 .77646 L p .707 .577 .707 r
F P
0 g
s
.17085 .73955 m .17007 .72166 L .18637 .71102 L p .707 .577 .707 r
F P
0 g
s
.32716 .61583 m .32044 .67312 L .29289 .6703 L p .707 .577 .707 r
F P
0 g
s
.29289 .6703 m .2996 .61301 L .32716 .61583 L p .707 .577 .707 r
F P
0 g
s
.6218 .26261 m .61888 .7664 L .58915 .75758 L p .707 .577 .707 r
F P
0 g
s
.58915 .75758 m .59207 .25379 L .6218 .26261 L p .707 .577 .707 r
F P
0 g
s
.18637 .71102 m .18715 .72891 L .17085 .73955 L p .707 .577 .707 r
F P
0 g
s
.34586 .74302 m .34429 .7809 L .3232 .776 L p .707 .577 .707 r
F P
0 g
s
.3232 .776 m .32477 .73812 L .34586 .74302 L p .707 .577 .707 r
F P
0 g
s
.23696 .60575 m .23025 .66304 L .20129 .65931 L p .707 .577 .707 r
F P
0 g
s
.20129 .65931 m .208 .60202 L .23696 .60575 L p .707 .577 .707 r
F P
0 g
s
.35122 .70866 m .352 .72656 L .33091 .7186 L p .707 .577 .707 r
F P
0 g
s
.33091 .7186 m .33013 .7007 L .35122 .70866 L p .707 .577 .707 r
F P
0 g
s
.17945 .77248 m .18102 .73459 L .20501 .732 L p .707 .577 .707 r
F P
0 g
s
.2996 .61301 m .29289 .6703 L .26181 .66683 L p .707 .577 .707 r
F P
0 g
s
.38892 .2574 m .386 .76119 L .36289 .77095 L p .707 .577 .707 r
F P
0 g
s
.386 .76119 m .38892 .2574 L .42288 .25001 L p .707 .577 .707 r
F P
0 g
s
.26181 .66683 m .26853 .60954 L .2996 .61301 L p .707 .577 .707 r
F P
0 g
s
.26853 .60954 m .26181 .66683 L .23025 .66304 L p .707 .577 .707 r
F P
0 g
s
.23025 .66304 m .23696 .60575 L .26853 .60954 L p .707 .577 .707 r
F P
0 g
s
.20501 .732 m .20344 .76988 L .17945 .77248 L p .707 .577 .707 r
F P
0 g
s
.18715 .72891 m .18637 .71102 L .21036 .70241 L p .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .70367 .6467 L p .70346 .64629 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70103 .6464 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67581 .64382 L p .67568 .64346 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67348 .64358 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65404 .64186 L p .65396 .64143 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65215 .64169 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64016 .64098 L p .64016 .64045 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63914 .64092 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .63965 .63213 L .63588 .64094 L .707 .577 .707 r
F
.63584 .64132 m .63914 .64092 L p .63588 .64094 L F P
0 g
s
.63865 .6313 m .64012 .63252 L .63792 .60871 L .707 .577 .707 r
F
.64012 .63252 m .64088 .6142 L .64003 .61262 L p F P
0 g
s
.64003 .61262 m .63792 .60871 L p .64012 .63252 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63571 .64133 L p .63965 .63213 L .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63931 .65208 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63792 .60871 m .63704 .62997 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63635 .6466 L p .63801 .61142 L .707 .577 .707 r
F P
0 g
s
.63965 .63213 m .64004 .6254 L .63871 .63135 L .707 .577 .707 r
F
.64004 .6254 m .64243 .58405 L .63871 .63135 L F
.64243 .58405 m .63704 .62997 L p .63871 .63135 L F P
0 g
s
.64593 .63394 m .65286 .63565 L .64088 .6142 L .707 .577 .707 r
F
.65286 .63565 m .65352 .61966 L .64951 .61793 L p F P
0 g
s
.64951 .61793 m .64088 .6142 L p .65286 .63565 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65146 .6353 L .64016 .64045 L .707 .577 .707 r
F
.64016 .64098 m .65215 .64169 L p .64016 .64045 L F P
0 g
s
.63931 .65208 m .65196 .65754 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64088 .6142 m .64012 .63252 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .63931 .65208 L p .64229 .61973 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64243 .58405 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.63914 .64092 m .64012 .63252 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64012 .63252 m .64585 .58363 L p .63937 .63698 L .707 .577 .707 r
F P
0 g
s
.64585 .58363 m .64012 .63252 L p .65146 .6353 L .707 .577 .707 r
F P
0 g
s
.66145 .63703 m .67401 .63905 L .65352 .61966 L .707 .577 .707 r
F
.66798 .62302 m .65352 .61966 L p .67401 .63905 L F P
0 g
s
.65352 .61966 m .65286 .63565 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65887 .58441 m .64585 .58363 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65215 .64169 m .65286 .63565 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65887 .58441 L p .6518 .63844 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67229 .63877 L .65396 .64143 L .707 .577 .707 r
F
.65404 .64186 m .67348 .64358 L p .65396 .64143 L F P
0 g
s
.65196 .65754 m .67304 .66244 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.65286 .63565 m .65196 .65754 L p .65647 .62613 L .707 .577 .707 r
F P
0 g
s
.63913 .62945 m .64727 .59299 L .64392 .62825 L .707 .577 .707 r
F
.67401 .63905 m .67461 .62456 L .66798 .62302 L p F P
0 g
s
.65887 .58441 m .65286 .63565 L p .67229 .63877 L .707 .577 .707 r
F P
0 g
s
.64628 .60341 m .66123 .59976 L p .64392 .62825 L .707 .577 .707 r
F P
0 g
s
.64892 .58561 m .64392 .62825 L p .64727 .59299 L .707 .577 .707 r
F P
0 g
s
.65196 .65754 m .65286 .63565 L p .64593 .63394 L .707 .577 .707 r
F P
0 g
s
.63931 .65208 m .64012 .63252 L p .63865 .6313 L .707 .577 .707 r
F P
0 g
s
.64493 .60374 m .64392 .62825 L p .63635 .6466 L .707 .577 .707 r
F P
0 g
s
.64313 .64065 m .6483 .62806 L .64297 .64302 L .707 .577 .707 r
F
.64305 .64185 m .63635 .6466 L p .64392 .62825 L F P
0 g
s
.64917 .62802 m .64392 .62825 L .66123 .59976 L .707 .577 .707 r
F
.68439 .64031 m .7015 .64239 L .67461 .62456 L F
.69392 .62727 m .67461 .62456 L p .7015 .64239 L F P
0 g
s
.67461 .62456 m .67401 .63905 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .65887 .58441 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67348 .64358 m .67401 .63905 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .6802 .5863 L p .67284 .64099 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .69956 .64215 L .67568 .64346 L .707 .577 .707 r
F
.67581 .64382 m .70103 .6464 L p .67568 .64346 L F P
0 g
s
.67304 .66244 m .70051 .6663 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.67401 .63905 m .67304 .66244 L p .67873 .6312 L .707 .577 .707 r
F P
0 g
s
.6422 .6429 m .64892 .58561 L .6647 .58817 L p .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64336 .64162 L .64305 .64185 L p .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .64297 .64302 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64297 .64302 m .6422 .6429 L p .64313 .64065 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .65798 .64546 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .66008 .62753 L p .64336 .64162 L .707 .577 .707 r
F P
0 g
s
.67304 .66244 m .67401 .63905 L p .66145 .63703 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70208 .62841 L .69392 .62727 L p .707 .577 .707 r
F P
0 g
s
.6802 .5863 m .67401 .63905 L p .69956 .64215 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .70208 .62841 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70208 .62841 m .7015 .64239 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .6802 .5863 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.70103 .6464 m .7015 .64239 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70775 .58912 L p .70023 .6441 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .7302 .64511 L .70346 .64629 L .707 .577 .707 r
F
.70367 .6467 m .73211 .64988 L p .70346 .64629 L F P
0 g
s
.70051 .6663 m .73167 .66873 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.7015 .64239 m .70051 .6663 L p .70695 .63505 L .707 .577 .707 r
F P
0 g
s
.66123 .59976 m .68522 .59716 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .66123 .59976 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.65798 .64546 m .66008 .62753 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .65798 .64546 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .6815 .64877 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.70051 .6663 m .7015 .64239 L p .68439 .64031 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73324 .63085 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.70775 .58912 m .7015 .64239 L p .7302 .64511 L .707 .577 .707 r
F P
0 g
s
.73324 .63085 m .73264 .64534 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .73324 .63085 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .76368 .65366 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73211 .64988 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76505 .63163 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.76505 .63163 m .76438 .64762 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .76505 .63163 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .79263 .65739 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76368 .65366 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79438 .63068 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.79438 .63068 m .79362 .64899 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .79438 .63068 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .81615 .6607 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79263 .65739 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81837 .62808 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.81837 .62808 m .81749 .64934 L p .82064 .6333 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .81837 .62808 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .83193 .66326 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .81615 .6607 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83467 .6241 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83467 .6241 m .83365 .64862 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83865 .60597 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.83524 .62369 m .83467 .6241 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83537 .62174 L .82974 .64879 L .707 .577 .707 r
F
.83865 .60597 m .83365 .64862 L p .83849 .64741 L F P
0 g
s
.8331 .66199 m .8394 .65751 L p .83852 .6474 L .707 .577 .707 r
F P
0 g
s
.83971 .6546 m .83852 .6474 L .8394 .65751 L .707 .577 .707 r
F
.83849 .64741 m .84141 .62989 L .83865 .60597 L F
.84514 .60754 m .84261 .60693 L p .84141 .62989 L F P
0 g
s
.84261 .60693 m .83865 .60597 L p .84141 .62989 L .707 .577 .707 r
F P
0 g
s
.84053 .6469 m .84514 .60754 L p .83849 .64741 L .707 .577 .707 r
F P
0 g
s
.83852 .6474 m .83809 .6448 L .8377 .6476 L .707 .577 .707 r
F
.83809 .6448 m .83506 .62651 L .8377 .6476 L F
.8377 .6476 m .83506 .62651 L .83384 .64857 L F
.83852 .6474 m .83384 .64857 L .8331 .66199 L F
.84011 .65701 m .84053 .6469 L p .8387 .64735 L F P
0 g
s
.83971 .6546 m .83524 .62369 L .83506 .62651 L .707 .577 .707 r
F
.84011 .65701 m .83973 .65441 L .83971 .6546 L F
.83973 .65441 m .83524 .62369 L .83971 .6546 L F
.84168 .61913 m .83524 .62369 L p .8387 .64735 L F P
0 g
s
.84053 .6469 m .84168 .61913 L p .8387 .64735 L .707 .577 .707 r
F P
0 g
s
.84168 .61913 m .84053 .6469 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .8331 .66199 L p .83506 .62651 L .707 .577 .707 r
F P
0 g
s
.83236 .66216 m .8331 .66199 L p .83251 .66063 L .707 .577 .707 r
F P
0 g
s
.83365 .64862 m .83193 .66326 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.83193 .66326 m .83365 .64862 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .83365 .64862 L .82741 .6489 L .707 .577 .707 r
F
.8331 .66199 m .83365 .64862 L p .83251 .66063 L F P
0 g
s
.83849 .64741 m .83365 .64862 L .83236 .66224 L .707 .577 .707 r
F
.83843 .66483 m .83849 .64741 L .83236 .66224 L F
.83193 .66326 m .83225 .66334 L p .83236 .66224 L F P
0 g
s
.83225 .66334 m .83843 .66483 L p .83236 .66224 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .83236 .66216 L p .82741 .6489 L .707 .577 .707 r
F P
0 g
s
.83251 .66063 m .82741 .6489 L .83236 .66216 L .707 .577 .707 r
F
.83872 .61364 m .84168 .61913 L p .83808 .64487 L F P
0 g
s
.835 .66524 m .83745 .64435 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .83745 .64435 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83872 .61364 L p .83808 .64487 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .8447 .60759 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .84171 .60795 L p .83838 .64512 L .707 .577 .707 r
F P
0 g
s
.8447 .60759 m .84514 .60754 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .8447 .60759 L .84404 .6138 L .707 .577 .707 r
F
.83843 .66483 m .84053 .6469 L p .83849 .64741 L F P
0 g
s
.83843 .66483 m .835 .66524 L p .83851 .64523 L .707 .577 .707 r
F P
0 g
s
.83851 .64523 m .84404 .6138 L .84041 .6468 L .707 .577 .707 r
F
.83851 .64523 m .84041 .6468 L .83843 .66483 L F
.84053 .6469 m .83843 .66483 L p .84404 .6138 L F P
0 g
s
.83715 .65152 m .83808 .64487 L .84053 .6469 L .707 .577 .707 r
F
.84053 .6469 m .84011 .65701 L .84001 .65683 L p F P
0 g
s
.8394 .65751 m .84011 .65701 L p .83971 .6546 L .707 .577 .707 r
F P
0 g
s
.84001 .65683 m .83715 .65152 L p .84053 .6469 L .707 .577 .707 r
F P
0 g
s
.84514 .60754 m .84053 .6469 L p .84404 .6138 L .707 .577 .707 r
F P
0 g
s
.82974 .64879 m .83537 .62174 L .82287 .60341 L .707 .577 .707 r
F
.83865 .60597 m .8364 .60561 L p .83537 .62174 L F P
0 g
s
.8364 .60561 m .82287 .60341 L p .83537 .62174 L .707 .577 .707 r
F P
0 g
s
.82741 .6489 m .82064 .6333 L .81876 .64928 L .707 .577 .707 r
F
.82741 .6489 m .81876 .64928 L .8168 .66597 L F
.81749 .64934 m .8168 .66597 L p .82064 .6333 L F P
0 g
s
.82287 .60341 m .81749 .64934 L p .82974 .64879 L .707 .577 .707 r
F P
0 g
s
.82287 .60341 m .79935 .60011 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81615 .6607 m .81749 .64934 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.81749 .64934 m .82287 .60341 L p .81563 .6588 L .707 .577 .707 r
F P
0 g
s
.8168 .66597 m .81749 .64934 L p .80613 .64917 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .8168 .66597 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79281 .66856 L p .79843 .63706 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .79362 .64899 L p .81299 .64927 L .707 .577 .707 r
F P
0 g
s
.79935 .60011 m .77039 .59638 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79263 .65739 m .79362 .64899 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79362 .64899 m .79935 .60011 L p .7915 .65427 L .707 .577 .707 r
F P
0 g
s
.79281 .66856 m .79362 .64899 L p .77753 .64824 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .79281 .66856 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .76348 .66951 L p .77008 .63832 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .76438 .64762 L p .7895 .6488 L .707 .577 .707 r
F P
0 g
s
.77039 .59638 m .73883 .59259 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76368 .65366 m .76438 .64762 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76438 .64762 m .77039 .59638 L p .76248 .65073 L .707 .577 .707 r
F P
0 g
s
.76348 .66951 m .76438 .64762 L p .74528 .64625 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .76348 .66951 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73167 .66873 L p .73846 .63753 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .73264 .64534 L p .76112 .64738 L .707 .577 .707 r
F P
0 g
s
.73883 .59259 m .70775 .58912 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73211 .64988 m .73264 .64534 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.73264 .64534 m .73883 .59259 L p .73111 .64739 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .71455 .59621 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.6815 .64877 m .68395 .62787 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68395 .62787 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68522 .59716 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .6815 .64877 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71046 .6525 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.73167 .66873 m .73264 .64534 L p .71315 .64349 L .707 .577 .707 r
F P
0 g
s
.74636 .59699 m .77752 .59943 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .80499 .60328 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .77607 .63448 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .77607 .63448 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77752 .59943 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .82607 .60818 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .80356 .63782 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .80356 .63782 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80499 .60328 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .83872 .61364 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .82471 .64122 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .82471 .64122 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82607 .60818 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.835 .66524 m .82198 .66447 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .835 .66524 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.83715 .65152 m .82451 .64606 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83872 .61364 m .83745 .64435 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.83745 .64435 m .83715 .65152 L p .82644 .64165 L .707 .577 .707 r
F P
0 g
s
.84171 .60795 m .83745 .64435 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .84171 .60795 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .8287 .60718 L p .82967 .64244 L .707 .577 .707 r
F P
0 g
s
.82198 .66447 m .80065 .66258 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82198 .66447 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.82451 .64606 m .80342 .64117 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82607 .60818 m .82471 .64122 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.82471 .64122 m .82451 .64606 L p .8055 .63814 L .707 .577 .707 r
F P
0 g
s
.8287 .60718 m .82471 .64122 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .8287 .60718 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80737 .60529 L p .81246 .63925 L .707 .577 .707 r
F P
0 g
s
.80065 .66258 m .7731 .65976 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80065 .66258 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.80342 .64117 m .77595 .63731 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80499 .60328 m .80356 .63782 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80356 .63782 m .80342 .64117 L p .77815 .63474 L .707 .577 .707 r
F P
0 g
s
.80737 .60529 m .80356 .63782 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .80737 .60529 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77982 .60247 L p .78808 .63594 L .707 .577 .707 r
F P
0 g
s
.74202 .65628 m .74493 .63153 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.7731 .65976 m .74202 .65628 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .7731 .65976 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.77595 .63731 m .74479 .63487 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77752 .59943 m .77607 .63448 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77607 .63448 m .77595 .63731 L p .74764 .63179 L .707 .577 .707 r
F P
0 g
s
.77982 .60247 m .77607 .63448 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74874 .599 m .77982 .60247 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74601 .63163 m .74636 .59699 L .74764 .63179 L .707 .577 .707 r
F
.74493 .63153 m .74636 .59699 L p .74599 .63357 L F P
0 g
s
.74493 .63153 m .74874 .599 L p .7585 .63282 L .707 .577 .707 r
F P
0 g
s
.74599 .63357 m .74601 .63163 L .74764 .63179 L .707 .577 .707 r
F
.74479 .63487 m .74493 .63153 L p .74599 .63357 L F P
0 g
s
.71455 .59621 m .74636 .59699 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .71318 .62925 L p .72349 .62999 L .707 .577 .707 r
F P
0 g
s
.71298 .63409 m .71318 .62925 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71455 .59621 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.71046 .6525 m .72349 .62999 L .72641 .6302 L .707 .577 .707 r
F
.74636 .59699 m .74493 .63153 L p .71709 .62953 L F P
0 g
s
.74874 .599 m .74202 .65628 L .71046 .6525 L p .707 .577 .707 r
F P
0 g
s
.74479 .63487 m .71298 .63409 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.74493 .63153 m .74479 .63487 L p .71709 .62953 L .707 .577 .707 r
F P
0 g
s
.72641 .6302 m .73436 .61123 L .73673 .61578 L .707 .577 .707 r
F
.72349 .62999 m .73436 .61123 L .72641 .6302 L F
.72349 .62999 m .71318 .62925 L .73436 .61123 L F
.73673 .61578 m .73436 .61123 L .74874 .599 L F
.71318 .62925 m .71718 .59521 L .73288 .59709 L p F P
0 g
s
.73288 .59709 m .74874 .599 L p .71318 .62925 L .707 .577 .707 r
F P
0 g
s
.68365 .63505 m .68916 .62812 L .71059 .63349 L .707 .577 .707 r
F
.71298 .63409 m .71016 .63419 L p .71059 .63349 L F P
0 g
s
.71016 .63419 m .68365 .63505 L p .71059 .63349 L .707 .577 .707 r
F P
0 g
s
.71455 .59621 m .71318 .62925 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71318 .62925 m .71298 .63409 L p .68916 .62812 L .707 .577 .707 r
F P
0 g
s
.71718 .59521 m .71318 .62925 L p .69507 .6284 L .707 .577 .707 r
F P
0 g
s
.69507 .6284 m .68395 .62787 L .71718 .59521 L .707 .577 .707 r
F
.68395 .62787 m .68822 .59148 L .6981 .59275 L p F P
0 g
s
.6981 .59275 m .71718 .59521 L p .68395 .62787 L .707 .577 .707 r
F P
0 g
s
.65966 .63764 m .66599 .62761 L .68143 .63411 L .707 .577 .707 r
F
.68365 .63505 m .68094 .63534 L p .68143 .63411 L F P
0 g
s
.68094 .63534 m .65966 .63764 L p .68143 .63411 L .707 .577 .707 r
F P
0 g
s
.68522 .59716 m .68395 .62787 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68395 .62787 m .68365 .63505 L p .66599 .62761 L .707 .577 .707 r
F P
0 g
s
.68822 .59148 m .68395 .62787 L p .66796 .62764 L .707 .577 .707 r
F P
0 g
s
.66796 .62764 m .66008 .62753 L .68822 .59148 L .707 .577 .707 r
F
.65966 .63764 m .66008 .62753 L p .66599 .62761 L F P
0 g
s
.66008 .62753 m .65966 .63764 L .65802 .63804 L p .707 .577 .707 r
F P
0 g
s
.65802 .63804 m .64336 .64162 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.66008 .62753 m .6647 .58817 L .66773 .5886 L p .707 .577 .707 r
F P
0 g
s
.66773 .5886 m .68822 .59148 L p .66008 .62753 L .707 .577 .707 r
F P
0 g
s
.6647 .58817 m .66008 .62753 L p .6483 .62806 L .707 .577 .707 r
F P
0 g
s
.64336 .64162 m .64392 .62825 L p .64917 .62802 L .707 .577 .707 r
F P
0 g
s
.64392 .62825 m .64493 .60374 L .64628 .60341 L p .707 .577 .707 r
F P
0 g
s
.63635 .6466 m .63704 .62997 L p .63982 .62928 L .707 .577 .707 r
F P
0 g
s
.63666 .63733 m .64892 .58561 L .63644 .64151 L .707 .577 .707 r
F
.63571 .64133 m .64243 .58405 L .64892 .58561 L p F P
0 g
s
.63982 .62928 m .63704 .62997 L .64493 .60374 L .707 .577 .707 r
F
.6422 .6429 m .63644 .64151 L p .63913 .62945 L F P
0 g
s
.64392 .62825 m .6422 .6429 L p .63913 .62945 L .707 .577 .707 r
F P
0 g
s
.63571 .64133 m .63584 .64132 L p .63588 .64094 L .707 .577 .707 r
F P
0 g
s
.63644 .64151 m .63571 .64133 L p .63666 .63733 L .707 .577 .707 r
F P
0 g
s
.63704 .62997 m .63792 .60871 L .63941 .60766 L p .707 .577 .707 r
F P
0 g
s
.63941 .60766 m .64493 .60374 L p .63704 .62997 L .707 .577 .707 r
F P
0 g
s
.32477 .73812 m .3232 .776 L .29573 .77215 L p .707 .577 .707 r
F P
0 g
s
.29573 .77215 m .2973 .73426 L .32477 .73812 L p .707 .577 .707 r
F P
0 g
s
.21036 .70241 m .21114 .72031 L .18715 .72891 L p .707 .577 .707 r
F P
0 g
s
.33013 .7007 m .33091 .7186 L .30344 .71369 L p .707 .577 .707 r
F P
0 g
s
.30344 .71369 m .30266 .69579 L .33013 .7007 L p .707 .577 .707 r
F P
0 g
s
.59207 .25379 m .58915 .75758 L .55039 .75149 L p .707 .577 .707 r
F P
0 g
s
.55039 .75149 m .55331 .24769 L .59207 .25379 L p .707 .577 .707 r
F P
0 g
s
.20344 .76988 m .20501 .732 L .23434 .73105 L p .707 .577 .707 r
F P
0 g
s
.21114 .72031 m .21036 .70241 L .2397 .69669 L p .707 .577 .707 r
F P
0 g
s
.23434 .73105 m .23277 .76893 L .20344 .76988 L p .707 .577 .707 r
F P
0 g
s
.2973 .73426 m .29573 .77215 L .26457 .76971 L p .707 .577 .707 r
F P
0 g
s
.26457 .76971 m .26614 .73183 L .2973 .73426 L p .707 .577 .707 r
F P
0 g
s
.41996 .7538 m .42288 .25001 L .46436 .24571 L p .707 .577 .707 r
F P
0 g
s
.42288 .25001 m .41996 .7538 L .386 .76119 L p .707 .577 .707 r
F P
0 g
s
.30266 .69579 m .30344 .71369 L .27228 .7123 L p .707 .577 .707 r
F P
0 g
s
.27228 .7123 m .2715 .69441 L .30266 .69579 L p .707 .577 .707 r
F P
0 g
s
.2397 .69669 m .24047 .71459 L .21114 .72031 L p .707 .577 .707 r
F P
0 g
s
.23277 .76893 m .23434 .73105 L .26614 .73183 L p .707 .577 .707 r
F P
0 g
s
.26614 .73183 m .26457 .76971 L .23277 .76893 L p .707 .577 .707 r
F P
0 g
s
.24047 .71459 m .2397 .69669 L .2715 .69441 L p .707 .577 .707 r
F P
0 g
s
.2715 .69441 m .27228 .7123 L .24047 .71459 L p .707 .577 .707 r
F P
0 g
s
.55331 .24769 m .55039 .75149 L .50638 .7487 L p .707 .577 .707 r
F P
0 g
s
.50638 .7487 m .5093 .24491 L .55331 .24769 L p .707 .577 .707 r
F P
0 g
s
.46144 .7495 m .46436 .24571 L .5093 .24491 L p .707 .577 .707 r
F P
0 g
s
.46436 .24571 m .46144 .7495 L .41996 .7538 L p .707 .577 .707 r
F P
0 g
s
.5093 .24491 m .50638 .7487 L .46144 .7495 L p .707 .577 .707 r
F P
0 g
s
.73938 .79959 m .7386 .78169 L .70743 .78031 L p .707 .577 .707 r
F P
0 g
s
.7386 .78169 m .73938 .79959 L .77118 .79731 L p .707 .577 .707 r
F P
0 g
s
.77118 .79731 m .7704 .77941 L .7386 .78169 L p .707 .577 .707 r
F P
0 g
s
.7704 .77941 m .77118 .79731 L .80051 .79158 L p .707 .577 .707 r
F P
0 g
s
.80051 .79158 m .79973 .77369 L .7704 .77941 L p .707 .577 .707 r
F P
0 g
s
.70821 .7982 m .70743 .78031 L .67997 .7754 L p .707 .577 .707 r
F P
0 g
s
.70743 .78031 m .70821 .7982 L .73938 .79959 L p .707 .577 .707 r
F P
0 g
s
.79973 .77369 m .80051 .79158 L .8245 .78298 L p .707 .577 .707 r
F P
0 g
s
.8245 .78298 m .82372 .76509 L .79973 .77369 L p .707 .577 .707 r
F P
0 g
s
.67997 .7754 m .68074 .79329 L .70821 .7982 L p .707 .577 .707 r
F P
0 g
s
.68074 .79329 m .67997 .7754 L .65888 .76744 L p .707 .577 .707 r
F P
0 g
s
.65888 .76744 m .65966 .78534 L .68074 .79329 L p .707 .577 .707 r
F P
0 g
s
.82372 .76509 m .8245 .78298 L .8408 .77234 L p .707 .577 .707 r
F P
0 g
s
.8408 .77234 m .84002 .75445 L .82372 .76509 L p .707 .577 .707 r
F P
0 g
s
.65966 .78534 m .65888 .76744 L .64623 .75721 L p .707 .577 .707 r
F P
0 g
s
.64623 .75721 m .64701 .77511 L .65966 .78534 L p .707 .577 .707 r
F P
0 g
s
.84002 .75445 m .8408 .77234 L .84781 .7607 L p .707 .577 .707 r
F P
0 g
s
.84781 .7607 m .84703 .74281 L .84002 .75445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64701 .77511 m .64623 .75721 L .64328 .74572 L p .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .36066 .60988 L p .36046 .60948 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35802 .60959 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .3328 .60701 L p .33267 .60665 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33047 .60677 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .31103 .60504 L p .31095 .60462 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30914 .60488 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29715 .60416 L p .29715 .60364 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .29613 .6041 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29664 .59531 L .29287 .60412 L .707 .577 .707 r
F
.29283 .6045 m .29613 .6041 L p .29287 .60412 L F P
0 g
s
.29564 .59448 m .29711 .5957 L .29491 .5719 L .707 .577 .707 r
F
.29711 .5957 m .29787 .57739 L .29702 .5758 L p F P
0 g
s
.29702 .5758 m .29491 .5719 L p .29711 .5957 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .2927 .60452 L p .29664 .59531 L .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .2963 .61527 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29491 .5719 m .29403 .59316 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29334 .60978 L p .295 .5746 L .707 .577 .707 r
F P
0 g
s
.29664 .59531 m .29702 .58858 L .2957 .59453 L .707 .577 .707 r
F
.29702 .58858 m .29941 .54723 L .2957 .59453 L F
.29941 .54723 m .29403 .59316 L p .2957 .59453 L F P
0 g
s
.30292 .59713 m .30985 .59883 L .29787 .57739 L .707 .577 .707 r
F
.30985 .59883 m .31051 .58284 L .3065 .58111 L p F P
0 g
s
.3065 .58111 m .29787 .57739 L p .30985 .59883 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30845 .59849 L .29715 .60364 L .707 .577 .707 r
F
.29715 .60416 m .30914 .60488 L p .29715 .60364 L F P
0 g
s
.2963 .61527 m .30895 .62073 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29787 .57739 m .29711 .5957 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .2963 .61527 L p .29928 .58291 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29941 .54723 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29613 .6041 m .29711 .5957 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.29711 .5957 m .30284 .54681 L p .29636 .60016 L .707 .577 .707 r
F P
0 g
s
.30284 .54681 m .29711 .5957 L p .30845 .59849 L .707 .577 .707 r
F P
0 g
s
.31844 .60021 m .331 .60223 L .31051 .58284 L .707 .577 .707 r
F
.32497 .5862 m .31051 .58284 L p .331 .60223 L F P
0 g
s
.31051 .58284 m .30985 .59883 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.31586 .54759 m .30284 .54681 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30914 .60488 m .30985 .59883 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .31586 .54759 L p .30879 .60163 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .32928 .60195 L .31095 .60462 L .707 .577 .707 r
F
.31103 .60504 m .33047 .60677 L p .31095 .60462 L F P
0 g
s
.30895 .62073 m .33003 .62562 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.30985 .59883 m .30895 .62073 L p .31346 .58931 L .707 .577 .707 r
F P
0 g
s
.29612 .59263 m .30426 .55618 L .30091 .59144 L .707 .577 .707 r
F
.331 .60223 m .3316 .58774 L .32497 .5862 L p F P
0 g
s
.31586 .54759 m .30985 .59883 L p .32928 .60195 L .707 .577 .707 r
F P
0 g
s
.30327 .56659 m .31822 .56294 L p .30091 .59144 L .707 .577 .707 r
F P
0 g
s
.30591 .54879 m .30091 .59144 L p .30426 .55618 L .707 .577 .707 r
F P
0 g
s
.30895 .62073 m .30985 .59883 L p .30292 .59713 L .707 .577 .707 r
F P
0 g
s
.2963 .61527 m .29711 .5957 L p .29564 .59448 L .707 .577 .707 r
F P
0 g
s
.30192 .56692 m .30091 .59144 L p .29334 .60978 L .707 .577 .707 r
F P
0 g
s
.30011 .60383 m .30529 .59124 L .29996 .60621 L .707 .577 .707 r
F
.30004 .60503 m .29334 .60978 L p .30091 .59144 L F P
0 g
s
.30616 .5912 m .30091 .59144 L .31822 .56294 L .707 .577 .707 r
F
.34138 .60349 m .35849 .60557 L .3316 .58774 L F
.35091 .59045 m .3316 .58774 L p .35849 .60557 L F P
0 g
s
.3316 .58774 m .331 .60223 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .31586 .54759 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.33047 .60677 m .331 .60223 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33719 .54948 L p .32983 .60418 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35655 .60533 L .33267 .60665 L .707 .577 .707 r
F
.3328 .60701 m .35802 .60959 L p .33267 .60665 L F P
0 g
s
.33003 .62562 m .3575 .62948 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.331 .60223 m .33003 .62562 L p .33572 .59438 L .707 .577 .707 r
F P
0 g
s
.29919 .60608 m .30591 .54879 L .32169 .55136 L p .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30035 .60481 L .30004 .60503 L p .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .29996 .60621 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.29996 .60621 m .29919 .60608 L p .30011 .60383 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31497 .60864 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .31707 .59071 L p .30035 .60481 L .707 .577 .707 r
F P
0 g
s
.33003 .62562 m .331 .60223 L p .31844 .60021 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .35907 .5916 L .35091 .59045 L p .707 .577 .707 r
F P
0 g
s
.33719 .54948 m .331 .60223 L p .35655 .60533 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .35907 .5916 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.35907 .5916 m .35849 .60557 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .33719 .54948 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35802 .60959 m .35849 .60557 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .36474 .5523 L p .35722 .60728 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38719 .60829 L .36046 .60948 L .707 .577 .707 r
F
.36066 .60988 m .3891 .61306 L p .36046 .60948 L F P
0 g
s
.3575 .62948 m .38866 .63192 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.35849 .60557 m .3575 .62948 L p .36394 .59823 L .707 .577 .707 r
F P
0 g
s
.31822 .56294 m .34221 .56035 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .31822 .56294 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.31497 .60864 m .31707 .59071 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .31497 .60864 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .33849 .61195 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.3575 .62948 m .35849 .60557 L p .34138 .60349 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39023 .59403 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.36474 .5523 m .35849 .60557 L p .38719 .60829 L .707 .577 .707 r
F P
0 g
s
.39023 .59403 m .38963 .60852 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .39023 .59403 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .42067 .61685 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .3891 .61306 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42204 .59481 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.42204 .59481 m .42137 .6108 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .42204 .59481 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .44963 .62058 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42067 .61685 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45137 .59386 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.45137 .59386 m .45061 .61218 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .45137 .59386 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .47315 .62388 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .44963 .62058 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47536 .59127 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.47536 .59127 m .47448 .61252 L p .47763 .59649 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .47536 .59127 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .48892 .62645 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47315 .62388 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49166 .58729 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.49166 .58729 m .49064 .6118 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49564 .56916 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.49223 .58688 m .49166 .58729 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49236 .58493 L .48673 .61198 L .707 .577 .707 r
F
.49564 .56916 m .49064 .6118 L p .49548 .61059 L F P
0 g
s
.49009 .62517 m .49639 .6207 L p .49551 .61058 L .707 .577 .707 r
F P
0 g
s
.4967 .61778 m .49551 .61058 L .49639 .6207 L .707 .577 .707 r
F
.49548 .61059 m .4984 .59307 L .49564 .56916 L F
.50213 .57072 m .4996 .57011 L p .4984 .59307 L F P
0 g
s
.4996 .57011 m .49564 .56916 L p .4984 .59307 L .707 .577 .707 r
F P
0 g
s
.49752 .61008 m .50213 .57072 L p .49548 .61059 L .707 .577 .707 r
F P
0 g
s
.49551 .61058 m .49508 .60798 L .49469 .61079 L .707 .577 .707 r
F
.49508 .60798 m .49205 .5897 L .49469 .61079 L F
.49469 .61079 m .49205 .5897 L .49083 .61175 L F
.49551 .61058 m .49083 .61175 L .49009 .62517 L F
.4971 .62019 m .49752 .61008 L p .49569 .61054 L F P
0 g
s
.4967 .61778 m .49223 .58688 L .49205 .5897 L .707 .577 .707 r
F
.4971 .62019 m .49672 .6176 L .4967 .61778 L F
.49672 .6176 m .49223 .58688 L .4967 .61778 L F
.49867 .58231 m .49223 .58688 L p .49569 .61054 L F P
0 g
s
.49752 .61008 m .49867 .58231 L p .49569 .61054 L .707 .577 .707 r
F P
0 g
s
.49867 .58231 m .49752 .61008 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .49009 .62517 L p .49205 .5897 L .707 .577 .707 r
F P
0 g
s
.48935 .62535 m .49009 .62517 L p .4895 .62382 L .707 .577 .707 r
F P
0 g
s
.49064 .6118 m .48892 .62645 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.48892 .62645 m .49064 .6118 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .49064 .6118 L .4844 .61208 L .707 .577 .707 r
F
.49009 .62517 m .49064 .6118 L p .4895 .62382 L F P
0 g
s
.49548 .61059 m .49064 .6118 L .48935 .62543 L .707 .577 .707 r
F
.49542 .62801 m .49548 .61059 L .48935 .62543 L F
.48892 .62645 m .48924 .62652 L p .48935 .62543 L F P
0 g
s
.48924 .62652 m .49542 .62801 L p .48935 .62543 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .48935 .62535 L p .4844 .61208 L .707 .577 .707 r
F P
0 g
s
.4895 .62382 m .4844 .61208 L .48935 .62535 L .707 .577 .707 r
F
.49571 .57682 m .49867 .58231 L p .49507 .60806 L F P
0 g
s
.49199 .62843 m .49444 .60753 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .49444 .60753 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49571 .57682 L p .49507 .60806 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .50169 .57078 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .4987 .57114 L p .49537 .60831 L .707 .577 .707 r
F P
0 g
s
.50169 .57078 m .50213 .57072 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .50169 .57078 L .50103 .57698 L .707 .577 .707 r
F
.49542 .62801 m .49752 .61008 L p .49548 .61059 L F P
0 g
s
.49542 .62801 m .49199 .62843 L p .4955 .60842 L .707 .577 .707 r
F P
0 g
s
.4955 .60842 m .50103 .57698 L .4974 .60998 L .707 .577 .707 r
F
.4955 .60842 m .4974 .60998 L .49542 .62801 L F
.49752 .61008 m .49542 .62801 L p .50103 .57698 L F P
0 g
s
.49414 .61471 m .49507 .60806 L .49752 .61008 L .707 .577 .707 r
F
.49752 .61008 m .4971 .62019 L .497 .62001 L p F P
0 g
s
.49639 .6207 m .4971 .62019 L p .4967 .61778 L .707 .577 .707 r
F P
0 g
s
.497 .62001 m .49414 .61471 L p .49752 .61008 L .707 .577 .707 r
F P
0 g
s
.50213 .57072 m .49752 .61008 L p .50103 .57698 L .707 .577 .707 r
F P
0 g
s
.48673 .61198 m .49236 .58493 L .47986 .5666 L .707 .577 .707 r
F
.49564 .56916 m .49339 .56879 L p .49236 .58493 L F P
0 g
s
.49339 .56879 m .47986 .5666 L p .49236 .58493 L .707 .577 .707 r
F P
0 g
s
.4844 .61208 m .47763 .59649 L .47575 .61247 L .707 .577 .707 r
F
.4844 .61208 m .47575 .61247 L .47379 .62915 L F
.47448 .61252 m .47379 .62915 L p .47763 .59649 L F P
0 g
s
.47986 .5666 m .47448 .61252 L p .48673 .61198 L .707 .577 .707 r
F P
0 g
s
.47986 .5666 m .45634 .56329 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47315 .62388 m .47448 .61252 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47448 .61252 m .47986 .5666 L p .47262 .62199 L .707 .577 .707 r
F P
0 g
s
.47379 .62915 m .47448 .61252 L p .46312 .61236 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .47379 .62915 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .4498 .63174 L p .45542 .60024 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .45061 .61218 L p .46998 .61246 L .707 .577 .707 r
F P
0 g
s
.45634 .56329 m .42738 .55956 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.44963 .62058 m .45061 .61218 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.45061 .61218 m .45634 .56329 L p .44849 .61745 L .707 .577 .707 r
F P
0 g
s
.4498 .63174 m .45061 .61218 L p .43452 .61142 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .4498 .63174 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42047 .6327 L p .42707 .6015 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .42137 .6108 L p .44649 .61198 L .707 .577 .707 r
F P
0 g
s
.42738 .55956 m .39582 .55577 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42067 .61685 m .42137 .6108 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42137 .6108 m .42738 .55956 L p .41947 .61391 L .707 .577 .707 r
F P
0 g
s
.42047 .6327 m .42137 .6108 L p .40227 .60943 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .42047 .6327 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .38866 .63192 L p .39545 .60071 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .38963 .60852 L p .41811 .61057 L .707 .577 .707 r
F P
0 g
s
.39582 .55577 m .36474 .5523 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.3891 .61306 m .38963 .60852 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.38963 .60852 m .39582 .55577 L p .38811 .61057 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .37154 .55939 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.33849 .61195 m .34094 .59106 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34094 .59106 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34221 .56035 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .33849 .61195 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36745 .61568 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.38866 .63192 m .38963 .60852 L p .37014 .60667 L .707 .577 .707 r
F P
0 g
s
.40334 .56017 m .43451 .56261 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .46198 .56647 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .43305 .59767 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .43305 .59767 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43451 .56261 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .48306 .57136 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .46055 .60101 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .46055 .60101 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46198 .56647 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .49571 .57682 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .4817 .60441 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .4817 .60441 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48306 .57136 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49199 .62843 m .47897 .62765 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49199 .62843 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.49414 .61471 m .4815 .60925 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49571 .57682 m .49444 .60753 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.49444 .60753 m .49414 .61471 L p .48343 .60483 L .707 .577 .707 r
F P
0 g
s
.4987 .57114 m .49444 .60753 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4987 .57114 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .48569 .57036 L p .48666 .60563 L .707 .577 .707 r
F P
0 g
s
.47897 .62765 m .45764 .62576 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .47897 .62765 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.4815 .60925 m .46041 .60435 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48306 .57136 m .4817 .60441 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.4817 .60441 m .4815 .60925 L p .46249 .60132 L .707 .577 .707 r
F P
0 g
s
.48569 .57036 m .4817 .60441 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .48569 .57036 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46436 .56847 L p .46945 .60244 L .707 .577 .707 r
F P
0 g
s
.45764 .62576 m .43009 .62294 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .45764 .62576 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.46041 .60435 m .43294 .60049 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46198 .56647 m .46055 .60101 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46055 .60101 m .46041 .60435 L p .43513 .59792 L .707 .577 .707 r
F P
0 g
s
.46436 .56847 m .46055 .60101 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .46436 .56847 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43681 .56565 L p .44507 .59913 L .707 .577 .707 r
F P
0 g
s
.39901 .61947 m .40191 .59471 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43009 .62294 m .39901 .61947 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43009 .62294 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.43294 .60049 m .40178 .59806 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43451 .56261 m .43305 .59767 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43305 .59767 m .43294 .60049 L p .40463 .59497 L .707 .577 .707 r
F P
0 g
s
.43681 .56565 m .43305 .59767 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40573 .56218 m .43681 .56565 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.403 .59482 m .40334 .56017 L .40463 .59497 L .707 .577 .707 r
F
.40191 .59471 m .40334 .56017 L p .40298 .59676 L F P
0 g
s
.40191 .59471 m .40573 .56218 L p .41549 .596 L .707 .577 .707 r
F P
0 g
s
.40298 .59676 m .403 .59482 L .40463 .59497 L .707 .577 .707 r
F
.40178 .59806 m .40191 .59471 L p .40298 .59676 L F P
0 g
s
.37154 .55939 m .40334 .56017 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .37017 .59244 L p .38048 .59318 L .707 .577 .707 r
F P
0 g
s
.36997 .59728 m .37017 .59244 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .37154 .55939 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.36745 .61568 m .38048 .59318 L .3834 .59339 L .707 .577 .707 r
F
.40334 .56017 m .40191 .59471 L p .37408 .59272 L F P
0 g
s
.40573 .56218 m .39901 .61947 L .36745 .61568 L p .707 .577 .707 r
F P
0 g
s
.40178 .59806 m .36997 .59728 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.40191 .59471 m .40178 .59806 L p .37408 .59272 L .707 .577 .707 r
F P
0 g
s
.3834 .59339 m .39135 .57442 L .39372 .57897 L .707 .577 .707 r
F
.38048 .59318 m .39135 .57442 L .3834 .59339 L F
.38048 .59318 m .37017 .59244 L .39135 .57442 L F
.39372 .57897 m .39135 .57442 L .40573 .56218 L F
.37017 .59244 m .37416 .55839 L .38987 .56028 L p F P
0 g
s
.38987 .56028 m .40573 .56218 L p .37017 .59244 L .707 .577 .707 r
F P
0 g
s
.34064 .59823 m .34615 .5913 L .36758 .59668 L .707 .577 .707 r
F
.36997 .59728 m .36715 .59737 L p .36758 .59668 L F P
0 g
s
.36715 .59737 m .34064 .59823 L p .36758 .59668 L .707 .577 .707 r
F P
0 g
s
.37154 .55939 m .37017 .59244 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37017 .59244 m .36997 .59728 L p .34615 .5913 L .707 .577 .707 r
F P
0 g
s
.37416 .55839 m .37017 .59244 L p .35206 .59158 L .707 .577 .707 r
F P
0 g
s
.35206 .59158 m .34094 .59106 L .37416 .55839 L .707 .577 .707 r
F
.34094 .59106 m .34521 .55466 L .35509 .55594 L p F P
0 g
s
.35509 .55594 m .37416 .55839 L p .34094 .59106 L .707 .577 .707 r
F P
0 g
s
.31665 .60083 m .32298 .5908 L .33842 .5973 L .707 .577 .707 r
F
.34064 .59823 m .33793 .59852 L p .33842 .5973 L F P
0 g
s
.33793 .59852 m .31665 .60083 L p .33842 .5973 L .707 .577 .707 r
F P
0 g
s
.34221 .56035 m .34094 .59106 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34094 .59106 m .34064 .59823 L p .32298 .5908 L .707 .577 .707 r
F P
0 g
s
.34521 .55466 m .34094 .59106 L p .32495 .59083 L .707 .577 .707 r
F P
0 g
s
.32495 .59083 m .31707 .59071 L .34521 .55466 L .707 .577 .707 r
F
.31665 .60083 m .31707 .59071 L p .32298 .5908 L F P
0 g
s
.31707 .59071 m .31665 .60083 L .31501 .60123 L p .707 .577 .707 r
F P
0 g
s
.31501 .60123 m .30035 .60481 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.31707 .59071 m .32169 .55136 L .32472 .55178 L p .707 .577 .707 r
F P
0 g
s
.32472 .55178 m .34521 .55466 L p .31707 .59071 L .707 .577 .707 r
F P
0 g
s
.32169 .55136 m .31707 .59071 L p .30529 .59124 L .707 .577 .707 r
F P
0 g
s
.30035 .60481 m .30091 .59144 L p .30616 .5912 L .707 .577 .707 r
F P
0 g
s
.30091 .59144 m .30192 .56692 L .30327 .56659 L p .707 .577 .707 r
F P
0 g
s
.29334 .60978 m .29403 .59316 L p .29681 .59246 L .707 .577 .707 r
F P
0 g
s
.29365 .60052 m .30591 .54879 L .29343 .60469 L .707 .577 .707 r
F
.2927 .60452 m .29941 .54723 L .30591 .54879 L p F P
0 g
s
.29681 .59246 m .29403 .59316 L .30192 .56692 L .707 .577 .707 r
F
.29919 .60608 m .29343 .60469 L p .29612 .59263 L F P
0 g
s
.30091 .59144 m .29919 .60608 L p .29612 .59263 L .707 .577 .707 r
F P
0 g
s
.2927 .60452 m .29283 .6045 L p .29287 .60412 L .707 .577 .707 r
F P
0 g
s
.29343 .60469 m .2927 .60452 L p .29365 .60052 L .707 .577 .707 r
F P
0 g
s
.29403 .59316 m .29491 .5719 L .2964 .57084 L p .707 .577 .707 r
F P
0 g
s
.2964 .57084 m .30192 .56692 L p .29403 .59316 L .707 .577 .707 r
F P
0 g
s
.64328 .74572 m .64405 .76361 L .64701 .77511 L p .707 .577 .707 r
F P
0 g
s
.84703 .74281 m .84781 .7607 L .84485 .74921 L p .707 .577 .707 r
F P
0 g
s
.84485 .74921 m .84407 .73131 L .84703 .74281 L p .707 .577 .707 r
F P
0 g
s
.64405 .76361 m .64328 .74572 L .65029 .73408 L p .707 .577 .707 r
F P
0 g
s
.65029 .73408 m .65107 .75198 L .64405 .76361 L p .707 .577 .707 r
F P
0 g
s
.84407 .73131 m .84485 .74921 L .83221 .73898 L p .707 .577 .707 r
F P
0 g
s
.83221 .73898 m .83143 .72109 L .84407 .73131 L p .707 .577 .707 r
F P
0 g
s
.65107 .75198 m .65029 .73408 L .66659 .72344 L p .707 .577 .707 r
F P
0 g
s
.39637 .76277 m .39559 .74488 L .36442 .7435 L p .707 .577 .707 r
F P
0 g
s
.39559 .74488 m .39637 .76277 L .42817 .76049 L p .707 .577 .707 r
F P
0 g
s
.42817 .76049 m .42739 .7426 L .39559 .74488 L p .707 .577 .707 r
F P
0 g
s
.42739 .7426 m .42817 .76049 L .4575 .75477 L p .707 .577 .707 r
F P
0 g
s
.4575 .75477 m .45672 .73687 L .42739 .7426 L p .707 .577 .707 r
F P
0 g
s
.66659 .72344 m .66737 .74134 L .65107 .75198 L p .707 .577 .707 r
F P
0 g
s
.3652 .76139 m .36442 .7435 L .33695 .73859 L p .707 .577 .707 r
F P
0 g
s
.36442 .7435 m .3652 .76139 L .39637 .76277 L p .707 .577 .707 r
F P
0 g
s
.83143 .72109 m .83221 .73898 L .81112 .73102 L p .707 .577 .707 r
F P
0 g
s
.81112 .73102 m .81034 .71313 L .83143 .72109 L p .707 .577 .707 r
F P
0 g
s
.45672 .73687 m .4575 .75477 L .48149 .74617 L p .707 .577 .707 r
F P
0 g
s
.48149 .74617 m .48071 .72827 L .45672 .73687 L p .707 .577 .707 r
F P
0 g
s
.33695 .73859 m .33773 .75648 L .3652 .76139 L p .707 .577 .707 r
F P
0 g
s
.33773 .75648 m .33695 .73859 L .31587 .73063 L p .707 .577 .707 r
F P
0 g
s
.66737 .74134 m .66659 .72344 L .69058 .71484 L p .707 .577 .707 r
F P
0 g
s
.31587 .73063 m .31665 .74852 L .33773 .75648 L p .707 .577 .707 r
F P
0 g
s
.69058 .71484 m .69136 .73273 L .66737 .74134 L p .707 .577 .707 r
F P
0 g
s
.48071 .72827 m .48149 .74617 L .49779 .73552 L p .707 .577 .707 r
F P
0 g
s
.49779 .73552 m .49701 .71763 L .48071 .72827 L p .707 .577 .707 r
F P
0 g
s
.81034 .71313 m .81112 .73102 L .78365 .72611 L p .707 .577 .707 r
F P
0 g
s
.78365 .72611 m .78287 .70822 L .81034 .71313 L p .707 .577 .707 r
F P
0 g
s
.69136 .73273 m .69058 .71484 L .71991 .70912 L p .707 .577 .707 r
F P
0 g
s
.31665 .74852 m .31587 .73063 L .30322 .7204 L p .707 .577 .707 r
F P
0 g
s
.78287 .70822 m .78365 .72611 L .75249 .72473 L p .707 .577 .707 r
F P
0 g
s
.75249 .72473 m .75171 .70683 L .78287 .70822 L p .707 .577 .707 r
F P
0 g
s
.71991 .70912 m .72069 .72701 L .69136 .73273 L p .707 .577 .707 r
F P
0 g
s
.30322 .7204 m .304 .73829 L .31665 .74852 L p .707 .577 .707 r
F P
0 g
s
.72069 .72701 m .71991 .70912 L .75171 .70683 L p .707 .577 .707 r
F P
0 g
s
.75171 .70683 m .75249 .72473 L .72069 .72701 L p .707 .577 .707 r
F P
0 g
s
.49701 .71763 m .49779 .73552 L .5048 .72389 L p .707 .577 .707 r
F P
0 g
s
.5048 .72389 m .50402 .70599 L .49701 .71763 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.304 .73829 m .30322 .7204 L .30026 .7089 L p .707 .577 .707 r
F P
0 g
s
.30026 .7089 m .30104 .7268 L .304 .73829 L p .707 .577 .707 r
F P
0 g
s
.50402 .70599 m .5048 .72389 L .50184 .71239 L p .707 .577 .707 r
F P
0 g
s
.50184 .71239 m .50106 .6945 L .50402 .70599 L p .707 .577 .707 r
F P
0 g
s
.30104 .7268 m .30026 .7089 L .30728 .69727 L p .707 .577 .707 r
F P
0 g
s
.30728 .69727 m .30806 .71516 L .30104 .7268 L p .707 .577 .707 r
F P
0 g
s
.50106 .6945 m .50184 .71239 L .4892 .70216 L p .707 .577 .707 r
F P
0 g
s
.4892 .70216 m .48842 .68427 L .50106 .6945 L p .707 .577 .707 r
F P
0 g
s
.30806 .71516 m .30728 .69727 L .32358 .68663 L p .707 .577 .707 r
F P
0 g
s
.32358 .68663 m .32436 .70452 L .30806 .71516 L p .707 .577 .707 r
F P
0 g
s
.48842 .68427 m .4892 .70216 L .46811 .69421 L p .707 .577 .707 r
F P
0 g
s
.46811 .69421 m .46733 .67631 L .48842 .68427 L p .707 .577 .707 r
F P
0 g
s
.32436 .70452 m .32358 .68663 L .34757 .67802 L p .707 .577 .707 r
F P
0 g
s
.34757 .67802 m .34835 .69592 L .32436 .70452 L p .707 .577 .707 r
F P
0 g
s
.46733 .67631 m .46811 .69421 L .44064 .6893 L p .707 .577 .707 r
F P
0 g
s
.44064 .6893 m .43986 .6714 L .46733 .67631 L p .707 .577 .707 r
F P
0 g
s
.34835 .69592 m .34757 .67802 L .3769 .6723 L p .707 .577 .707 r
F P
0 g
s
.43986 .6714 m .44064 .6893 L .40948 .68791 L p .707 .577 .707 r
F P
0 g
s
.40948 .68791 m .4087 .67002 L .43986 .6714 L p .707 .577 .707 r
F P
0 g
s
.3769 .6723 m .37768 .69019 L .34835 .69592 L p .707 .577 .707 r
F P
0 g
s
.37768 .69019 m .3769 .6723 L .4087 .67002 L p .707 .577 .707 r
F P
0 g
s
.4087 .67002 m .40948 .68791 L .37768 .69019 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo5P00QWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001mOol007Ioo`D000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001]Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP<006aoo`00JGoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`8000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol70008Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol>00001Goo001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH01000FUIJEUYF3@00
00=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol20004FUH00`00FUIJEP04FUHC
0002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEP00010000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3@002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001DOol30004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001COol40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01000FUIJEUYF2@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001COol01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002001TOol0
05=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000>001HOol005=oo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP05001JEUYF001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH005YF001JEPH00003FUH005YF009JEPT004moo`00;goo0P008Woo00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH:0004FUH80017Ool002ioo`h001Moo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000AJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00eYF5P00
?Woo000^Ool20002FUH70003FUH9000>Ool2FUH01000FUIJEUYF300015YF00<005YFFUH00UYF3P00
1UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEQ@003Moo`00;Woo0P0015YF00@005YFFUIJEPL00003FUH005YF00=JEPT000Eoo`04001J
EP00FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEQ80039oo`00;Woo0P0015YF00<005YFFUH015YF00@005YFFUIJEPT00003FUH005YF00=J
EPT0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000QJEP03001JEUYF00AJ
EP04001JEP000002FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEQ0002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@0000AJEP000000009JEPH000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`001EYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEP00008000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH?0003FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:goo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF2P000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JER8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=J
EPH000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHE000015YF0000000015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01P00
0UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF0P0025YF00@005YFFUIJEPL000=JEP05001JEUYFFUH0000^Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001oogoo02aoo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH0000002ioo`00;7oo10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH00eYF
2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
<7oo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000010000eYF0P001eYF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00=Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00EJEPP000AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000^Ool003eoo`T000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH<
0002FUH2000^Ool004Ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH8
0004FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000FUIJEUYF2P00;Woo001?Ool80004FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH03`0015YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2OolJ000hOol005Moo``00004FUH005YFFUH90004
FUH00`00FUIJEP06FUH00`00FUH00004000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPMoo`D0
04Qoo`00HGoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<0
05YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00Ggoo0P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YF
FUIJEP8000Qoo`<004Uoo`00GGoo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00Fgoo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00FWoo0P001eYF00<005YFFUH0
0UYF20001eYF00<005YF00001`0015YF00<005YFFUH00UYF00H005YF000005YF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo0019OolA00000eYF001JEP05FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH6
0004FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00E7oo0010Ool90004FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH3000015YF001JEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00>Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00@005YF000000Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH20002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000hOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH2000015YF000000000Woo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00EGoo000fOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH00002FUH200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000080003FUH01000FUIJEUYF0P000goo5`00>goo000dOol20006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH=000015YF0000000015YF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH025YF0P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo300000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPD003Ioo`00<goo0P001eYF00<005YFFUH00UYF200037oo00<005YF00001000
0UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH01eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
37oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=7oo000aOol20000
0eYF001JEP05FUH6000DOol20005Ool40004FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000027oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00P00<Woo000_Ool20004FUH01000FUIJEUYF0P003Goo0`002Woo0`00
27oo0`0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP<0
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP80031oo`00;goo00=JEP00FUH00eYF00@005YF000000ioo`D000Uoo`800003FUH007oo
00Uoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP80
009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Aoo`<0
00IJEP03001JEUYF00AJEQL000AJEP03001JEUYF00=JEP<002ioo`00;Woo00<007oo000015YF0P00
27oo3@002Goo0P000UYF00<007ooOol027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEUYFFUH20004FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP04000GOol50005FUH01000FUIJ
EP00;Goo000^Ool00`00Ool00002FUH<0003FUH00`00FUIJEP02FUH@0002FUH30008Ool01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF100000=JEP00FUH00eYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH00eYF
100087oo0P000eYF00@005YFFUH002eoo`00;Woo00<005YF00000`001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00P001Woo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03001JEP0000<002Io
o`800005FUH005YFFUH0000]Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH01000FUIJEUYF1@0000Eoo`00FUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF0080009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP<0
0004FUH00000000WOol20002FUH2000/Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH01000FUIJEUYF6@001EYF00<0
05YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEUYF009JEP8002Moo`04001JEUYF000/Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000X000IJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP<000=JEP03001JEUYF00=JEP8002Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001P002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF0P0015YF00<005YFFUH00eYF00<005YF00009goo0P00;7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000Woo1@001EYF00@005YFFUH002Eoo`03001JEP0002aoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00008000Mo
o`8000=JEP04001JEUYF000TOol200000eYF001oo`0[Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEP0001L0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00008000Uoo`800005FUH005YFFUH0000ROol2
000015YF001JEP00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@0
05YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP@000AJEP05001JEP00001JEP020009Ool20003FUH00`00Oomoo`0MOol20003
FUH2000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH01000FUH000000eYF
0P002Goo0P0000=JEP00Ool077oo0P0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH00002FUH6
00000eYF001JEP06FUH00`00FUIJEP05FUH30005FUH80003FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF0P0000=JEP00FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP0000000eYF00<005YF00000P0027oo
0P006goo0P000eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P000eYF0P000eYF00<005YF
FUH015YF00<005YFFUH015YF1@001UYF00<005YFFUH00eYF1@0015YF00H005YFFUH005YF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF00000003FUH00`00FUIJEP02FUH50003Ool2000E
Ool60005FUH01000FUIJEP00;goo000/Ool20002FUH00`00FUIJEP03FUH200000eYF001JEP05FUH0
0`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH7000015YF001JEUYF0P0015YF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF0P0000AJEP00FUH0009JEP03001JEUYF00=JEP04001JEUYFFUH80009Ool90004
FUH00`00FUIJEP04FUH3000`Ool002aoo`80009JEP03001JEUYF00=JEP03001JEP0000@000=JEP03
001JEUYF00AJEPD000IJEP03001JEUYF00D000EJEP@00003FUH0000000AJEP03001JEUYF00EJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP000002FUH30005FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00<Woo000]Ool01000FUIJEP001EYF00<005YFFUH015YF6000
0eYF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EP000004FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00=7oo000^Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUIJEP001UYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YF000003Ioo`00<7oo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0015YF00<0
05YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00001eYF00<005YFFUH01@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1@00>7oo000cOol70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP060002FUH00`00FUIJEP05FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP03FUH00`00FUH000080004FUH00`00FUIJEP02FUH9000mOol0
03Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH60006Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001Goo2@00AWoo0013
OolI000>Ool20006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00K7oo0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YFFUH005YF001DOol006ioo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00=JEPD000=JEPP000AJEP03001JEUYF00=JEP03001JEUYF0080
05Eoo`00LGoo1`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
20001UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P00EGoo001hOol<0006FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUH70004FUH50006FUH00`00FUIJEP02FUH50002FUH40002FUH2001EOol008Ao
ob<0009JEPD0009JEPT00003FUH005YF00EJEP03001JEUYF00@005Eoo`00SWoo0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH015YF2@000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<005Eoo`00T7oo100015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001EOol009Aoo`<00003FUH0
05YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EUYFFUH005YFEWoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001GOol009aooa4000EJEP03001JEUYF009JEPd005Uoo`00[Goo
2P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59493 .71763 m .59912 .66031 L .56798 .65745 L p .707 .577 .707 r
F P
0 g
s
.59912 .66031 m .59493 .71763 L .62666 .71966 L p .707 .577 .707 r
F P
0 g
s
.62666 .71966 m .63085 .66234 L .59912 .66031 L p .707 .577 .707 r
F P
0 g
s
.63085 .66234 m .62666 .71966 L .65588 .72066 L p .707 .577 .707 r
F P
0 g
s
.65588 .72066 m .66007 .66334 L .63085 .66234 L p .707 .577 .707 r
F P
0 g
s
.56798 .65745 m .56379 .71477 L .59493 .71763 L p .707 .577 .707 r
F P
0 g
s
.56379 .71477 m .56798 .65745 L .54049 .65402 L p .707 .577 .707 r
F P
0 g
s
.54049 .65402 m .5363 .71134 L .56379 .71477 L p .707 .577 .707 r
F P
0 g
s
.66007 .66334 m .65588 .72066 L .67972 .72051 L p .707 .577 .707 r
F P
0 g
s
.67972 .72051 m .68392 .66319 L .66007 .66334 L p .707 .577 .707 r
F P
0 g
s
.5363 .71134 m .54049 .65402 L .51933 .65037 L p .707 .577 .707 r
F P
0 g
s
.51933 .65037 m .51514 .70769 L .5363 .71134 L p .707 .577 .707 r
F P
0 g
s
.59505 .82878 m .59602 .79116 L .56485 .78893 L p .707 .577 .707 r
F P
0 g
s
.59602 .79116 m .59505 .82878 L .62687 .82896 L p .707 .577 .707 r
F P
0 g
s
.62687 .82896 m .62784 .79134 L .59602 .79116 L p .707 .577 .707 r
F P
0 g
s
.62784 .79134 m .62687 .82896 L .65624 .82707 L p .707 .577 .707 r
F P
0 g
s
.65624 .82707 m .65721 .78945 L .62784 .79134 L p .707 .577 .707 r
F P
0 g
s
.56388 .82655 m .56485 .78893 L .53739 .78486 L p .707 .577 .707 r
F P
0 g
s
.56485 .78893 m .56388 .82655 L .59505 .82878 L p .707 .577 .707 r
F P
0 g
s
.68392 .66319 m .67972 .72051 L .69587 .71925 L p .707 .577 .707 r
F P
0 g
s
.69587 .71925 m .70006 .66193 L .68392 .66319 L p .707 .577 .707 r
F P
0 g
s
.53739 .78486 m .53642 .82248 L .56388 .82655 L p .707 .577 .707 r
F P
0 g
s
.65721 .78945 m .65624 .82707 L .68027 .8233 L p .707 .577 .707 r
F P
0 g
s
.68027 .8233 m .68124 .78568 L .65721 .78945 L p .707 .577 .707 r
F P
0 g
s
.59981 .83462 m .59933 .81646 L .56816 .81488 L p .707 .577 .707 r
F P
0 g
s
.59933 .81646 m .59981 .83462 L .63164 .83291 L p .707 .577 .707 r
F P
0 g
s
.63164 .83291 m .63115 .81474 L .59933 .81646 L p .707 .577 .707 r
F P
0 g
s
.51514 .70769 m .51933 .65037 L .50658 .64686 L p .707 .577 .707 r
F P
0 g
s
.63115 .81474 m .63164 .83291 L .661 .82807 L p .707 .577 .707 r
F P
0 g
s
.661 .82807 m .66052 .80991 L .63115 .81474 L p .707 .577 .707 r
F P
0 g
s
.56816 .81488 m .56864 .83304 L .59981 .83462 L p .707 .577 .707 r
F P
0 g
s
.56864 .83304 m .56816 .81488 L .5407 .81016 L p .707 .577 .707 r
F P
0 g
s
.53642 .82248 m .53739 .78486 L .51632 .77937 L p .707 .577 .707 r
F P
0 g
s
.50658 .64686 m .50238 .70418 L .51514 .70769 L p .707 .577 .707 r
F P
0 g
s
.5407 .81016 m .54118 .82833 L .56864 .83304 L p .707 .577 .707 r
F P
0 g
s
.68124 .78568 m .68027 .8233 L .69661 .81802 L p .707 .577 .707 r
F P
0 g
s
.66052 .80991 m .661 .82807 L .68503 .82058 L p .707 .577 .707 r
F P
0 g
s
.68503 .82058 m .68454 .80242 L .66052 .80991 L p .707 .577 .707 r
F P
0 g
s
.51632 .77937 m .51535 .81699 L .53642 .82248 L p .707 .577 .707 r
F P
0 g
s
.69661 .81802 m .69758 .7804 L .68124 .78568 L p .707 .577 .707 r
F P
0 g
s
.70006 .66193 m .69587 .71925 L .70272 .71699 L p .707 .577 .707 r
F P
0 g
s
.70272 .71699 m .70692 .65967 L .70006 .66193 L p .707 .577 .707 r
F P
0 g
s
.54118 .82833 m .5407 .81016 L .51963 .80277 L p .707 .577 .707 r
F P
0 g
s
.51963 .80277 m .52011 .82094 L .54118 .82833 L p .707 .577 .707 r
F P
0 g
s
.51535 .81699 m .51632 .77937 L .50371 .77298 L p .707 .577 .707 r
F P
0 g
s
.50238 .70418 m .50658 .64686 L .50347 .64383 L p .707 .577 .707 r
F P
0 g
s
.69758 .7804 m .69661 .81802 L .69807 .81672 L p .707 .577 .707 r
F P
0 g
s
.69811 .81305 m .70137 .81118 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.69841 .78467 m .69758 .7804 L .69807 .81672 L .707 .577 .707 r
F
.70137 .81118 m .70089 .79302 L .6983 .7945 L p F P
0 g
s
.6983 .7945 m .68454 .80242 L p .69815 .8095 L .707 .577 .707 r
F P
0 g
s
.70137 .81118 m .6983 .7945 L .69815 .8095 L .707 .577 .707 r
F
.70089 .79302 m .70137 .81118 L .70843 .80078 L p F P
0 g
s
.70843 .80078 m .70794 .78262 L .70089 .79302 L p .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .70463 .77412 L .69846 .77962 L p .707 .577 .707 r
F P
0 g
s
.69846 .77962 m .69758 .7804 L p .69841 .78467 L .707 .577 .707 r
F P
0 g
s
.70366 .81174 m .69846 .77962 L .69841 .78467 L .707 .577 .707 r
F
.69807 .81672 m .70366 .81174 L p .69841 .78467 L F P
0 g
s
.68454 .80242 m .68503 .82058 L .69811 .81305 L p .707 .577 .707 r
F P
0 g
s
.69815 .8095 m .68454 .80242 L .69811 .81305 L .707 .577 .707 r
F
.50347 .64383 m .49928 .70115 L .50238 .70418 L p F P
0 g
s
.50371 .77298 m .50274 .8106 L .51535 .81699 L p .707 .577 .707 r
F P
0 g
s
.52011 .82094 m .51963 .80277 L .50702 .79343 L p .707 .577 .707 r
F P
0 g
s
.50702 .79343 m .5075 .81159 L .52011 .82094 L p .707 .577 .707 r
F P
0 g
s
.70692 .65967 m .70272 .71699 L .69962 .71396 L p .707 .577 .707 r
F P
0 g
s
.69962 .71396 m .70382 .65664 L .70692 .65967 L p .707 .577 .707 r
F P
0 g
s
.48847 .82191 m .49028 .31883 L .44627 .31609 L p .707 .577 .707 r
F P
0 g
s
.50274 .8106 m .50371 .77298 L .50079 .76632 L p .707 .577 .707 r
F P
0 g
s
.49928 .70115 m .50347 .64383 L .51033 .64157 L p .707 .577 .707 r
F P
0 g
s
.50079 .76632 m .49982 .80394 L .50274 .8106 L p .707 .577 .707 r
F P
0 g
s
.51033 .64157 m .50614 .69889 L .49928 .70115 L p .707 .577 .707 r
F P
0 g
s
.5075 .81159 m .50702 .79343 L .5041 .78305 L p .707 .577 .707 r
F P
0 g
s
.5041 .78305 m .50458 .80121 L .5075 .81159 L p .707 .577 .707 r
F P
0 g
s
.49982 .80394 m .50079 .76632 L .50785 .76004 L p .707 .577 .707 r
F P
0 g
s
.50614 .69889 m .51033 .64157 L .52647 .64031 L p .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .5041 .78305 L .51004 .7743 L p .707 .577 .707 r
F P
0 g
s
.50989 .75938 m .52419 .75475 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.51004 .7743 m .51116 .77265 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.50458 .80121 m .51004 .7743 L .51007 .77736 L .707 .577 .707 r
F
.5102 .78943 m .52419 .75475 L .51027 .79656 L F
.51116 .77265 m .51164 .79081 L .51023 .79289 L p F P
0 g
s
.51023 .79289 m .50458 .80121 L p .51007 .77736 L .707 .577 .707 r
F P
0 g
s
.51007 .77736 m .51116 .77265 L .51023 .79289 L .707 .577 .707 r
F
.52419 .75475 m .52322 .79237 L .51027 .79656 L p F P
0 g
s
.51027 .79656 m .50688 .79766 L p .5102 .78943 L .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50785 .76004 L .50989 .75938 L p .707 .577 .707 r
F P
0 g
s
.50688 .79766 m .50989 .75938 L .5102 .78943 L .707 .577 .707 r
F
.50785 .76004 m .50688 .79766 L .49982 .80394 L p F P
0 g
s
.52647 .64031 m .52228 .69763 L .50614 .69889 L p .707 .577 .707 r
F P
0 g
s
.52228 .69763 m .52647 .64031 L .55032 .64017 L p .707 .577 .707 r
F P
0 g
s
.55032 .64017 m .54613 .69749 L .52228 .69763 L p .707 .577 .707 r
F P
0 g
s
.52322 .79237 m .52419 .75475 L .54822 .75099 L p .707 .577 .707 r
F P
0 g
s
.51164 .79081 m .51116 .77265 L .5275 .76325 L p .707 .577 .707 r
F P
0 g
s
.5275 .76325 m .52798 .78141 L .51164 .79081 L p .707 .577 .707 r
F P
0 g
s
.54822 .75099 m .54725 .78861 L .52322 .79237 L p .707 .577 .707 r
F P
0 g
s
.54725 .78861 m .54822 .75099 L .57758 .7491 L p .707 .577 .707 r
F P
0 g
s
.52798 .78141 m .5275 .76325 L .55153 .75576 L p .707 .577 .707 r
F P
0 g
s
.55153 .75576 m .55201 .77392 L .52798 .78141 L p .707 .577 .707 r
F P
0 g
s
.49028 .31883 m .48847 .82191 L .53342 .821 L p .707 .577 .707 r
F P
0 g
s
.53342 .821 m .53522 .31792 L .49028 .31883 L p .707 .577 .707 r
F P
0 g
s
.54613 .69749 m .55032 .64017 L .57954 .64116 L p .707 .577 .707 r
F P
0 g
s
.57954 .64116 m .57535 .69848 L .54613 .69749 L p .707 .577 .707 r
F P
0 g
s
.57758 .7491 m .57661 .78672 L .54725 .78861 L p .707 .577 .707 r
F P
0 g
s
.57661 .78672 m .57758 .7491 L .6094 .74928 L p .707 .577 .707 r
F P
0 g
s
.55201 .77392 m .55153 .75576 L .58089 .75092 L p .707 .577 .707 r
F P
0 g
s
.58089 .75092 m .58137 .76909 L .55201 .77392 L p .707 .577 .707 r
F P
0 g
s
.53522 .31792 m .53342 .821 L .5749 .81651 L p .707 .577 .707 r
F P
0 g
s
.5749 .81651 m .5767 .31344 L .53522 .31792 L p .707 .577 .707 r
F P
0 g
s
.44447 .81916 m .44627 .31609 L .40751 .30995 L p .707 .577 .707 r
F P
0 g
s
.44627 .31609 m .44447 .81916 L .48847 .82191 L p .707 .577 .707 r
F P
0 g
s
.70463 .77412 m .70366 .81174 L .70074 .80508 L p .707 .577 .707 r
F P
0 g
s
.70074 .80508 m .70171 .76746 L .70463 .77412 L p .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .57954 .64116 L .58524 .64152 L p .707 .577 .707 r
F P
0 g
s
.58524 .64152 m .61127 .64319 L p .57975 .6917 L .707 .577 .707 r
F P
0 g
s
.57535 .69848 m .58524 .64152 L .57975 .6917 L .707 .577 .707 r
F
.64241 .64605 m .63821 .70338 L .60708 .70051 L p F P
0 g
s
.60708 .70051 m .61127 .64319 L .64241 .64605 L p .707 .577 .707 r
F P
0 g
s
.61127 .64319 m .60708 .70051 L .57535 .69848 L p .707 .577 .707 r
F P
0 g
s
.64057 .75151 m .6396 .78913 L .60843 .7869 L p .707 .577 .707 r
F P
0 g
s
.60843 .7869 m .6094 .74928 L .64057 .75151 L p .707 .577 .707 r
F P
0 g
s
.6396 .78913 m .64057 .75151 L .66803 .75557 L p .707 .577 .707 r
F P
0 g
s
.64388 .75079 m .64436 .76895 L .6132 .76737 L p .707 .577 .707 r
F P
0 g
s
.6132 .76737 m .61271 .74921 L .64388 .75079 L p .707 .577 .707 r
F P
0 g
s
.6094 .74928 m .60843 .7869 L .57661 .78672 L p .707 .577 .707 r
F P
0 g
s
.58137 .76909 m .58089 .75092 L .61271 .74921 L p .707 .577 .707 r
F P
0 g
s
.61271 .74921 m .6132 .76737 L .58137 .76909 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .63196 .7989 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61066 .30582 m .61028 .41273 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.61028 .41273 m .60886 .8089 L p .61386 .37995 L .707 .577 .707 r
F P
0 g
s
.5767 .31344 m .5749 .81651 L .60886 .8089 L p .707 .577 .707 r
F P
0 g
s
.60886 .8089 m .61066 .30582 L .5767 .31344 L p .707 .577 .707 r
F P
0 g
s
.70382 .65664 m .69962 .71396 L .68687 .71045 L p .707 .577 .707 r
F P
0 g
s
.68687 .71045 m .69106 .65313 L .70382 .65664 L p .707 .577 .707 r
F P
0 g
s
.25192 .68082 m .25611 .6235 L .22498 .62063 L p .707 .577 .707 r
F P
0 g
s
.25611 .6235 m .25192 .68082 L .28365 .68285 L p .707 .577 .707 r
F P
0 g
s
.28365 .68285 m .28784 .62553 L .25611 .6235 L p .707 .577 .707 r
F P
0 g
s
.70794 .78262 m .70843 .80078 L .70551 .7904 L p .707 .577 .707 r
F P
0 g
s
.70551 .7904 m .70502 .77224 L .70794 .78262 L p .707 .577 .707 r
F P
0 g
s
.4057 .81303 m .40751 .30995 L .37778 .30102 L p .707 .577 .707 r
F P
0 g
s
.40751 .30995 m .4057 .81303 L .44447 .81916 L p .707 .577 .707 r
F P
0 g
s
.28784 .62553 m .28365 .68285 L .31287 .68384 L p .707 .577 .707 r
F P
0 g
s
.31287 .68384 m .31706 .62652 L .28784 .62553 L p .707 .577 .707 r
F P
0 g
s
.22498 .62063 m .22078 .67795 L .25192 .68082 L p .707 .577 .707 r
F P
0 g
s
.22078 .67795 m .22498 .62063 L .19748 .6172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19748 .6172 m .19329 .67453 L .22078 .67795 L p .707 .577 .707 r
F P
0 g
s
.31706 .62652 m .31287 .68384 L .33672 .6837 L p .707 .577 .707 r
F P
0 g
s
.33672 .6837 m .34091 .62638 L .31706 .62652 L p .707 .577 .707 r
F P
0 g
s
.63196 .7989 m .63377 .29582 L .61066 .30582 L p .707 .577 .707 r
F P
0 g
s
.70171 .76746 m .70074 .80508 L .68813 .79869 L p .707 .577 .707 r
F P
0 g
s
.68813 .79869 m .6891 .76107 L .70171 .76746 L p .707 .577 .707 r
F P
0 g
s
.19329 .67453 m .19748 .6172 L .17632 .61356 L p .707 .577 .707 r
F P
0 g
s
.69106 .65313 m .68687 .71045 L .66571 .7068 L p .707 .577 .707 r
F P
0 g
s
.66571 .7068 m .6699 .64948 L .69106 .65313 L p .707 .577 .707 r
F P
0 g
s
.17632 .61356 m .17213 .67088 L .19329 .67453 L p .707 .577 .707 r
F P
0 g
s
.25204 .79196 m .25301 .75434 L .22185 .75211 L p .707 .577 .707 r
F P
0 g
s
.25301 .75434 m .25204 .79196 L .28387 .79214 L p .707 .577 .707 r
F P
0 g
s
.28387 .79214 m .28484 .75452 L .25301 .75434 L p .707 .577 .707 r
F P
0 g
s
.70502 .77224 m .70551 .7904 L .69289 .78106 L p .707 .577 .707 r
F P
0 g
s
.69289 .78106 m .69241 .76289 L .70502 .77224 L p .707 .577 .707 r
F P
0 g
s
.28484 .75452 m .28387 .79214 L .31323 .79026 L p .707 .577 .707 r
F P
0 g
s
.31323 .79026 m .3142 .75264 L .28484 .75452 L p .707 .577 .707 r
F P
0 g
s
.37598 .8041 m .37778 .30102 L .36 .29018 L p .707 .577 .707 r
F P
0 g
s
.37778 .30102 m .37598 .8041 L .4057 .81303 L p .707 .577 .707 r
F P
0 g
s
.22087 .78973 m .22185 .75211 L .19438 .74805 L p .707 .577 .707 r
F P
0 g
s
.22185 .75211 m .22087 .78973 L .25204 .79196 L p .707 .577 .707 r
F P
0 g
s
.34091 .62638 m .33672 .6837 L .35286 .68244 L p .707 .577 .707 r
F P
0 g
s
.35286 .68244 m .35705 .62512 L .34091 .62638 L p .707 .577 .707 r
F P
0 g
s
.19438 .74805 m .19341 .78567 L .22087 .78973 L p .707 .577 .707 r
F P
0 g
s
.3142 .75264 m .31323 .79026 L .33726 .78649 L p .707 .577 .707 r
F P
0 g
s
.33726 .78649 m .33823 .74887 L .3142 .75264 L p .707 .577 .707 r
F P
0 g
s
.2568 .7978 m .25632 .77964 L .22515 .77806 L p .707 .577 .707 r
F P
0 g
s
.25632 .77964 m .2568 .7978 L .28863 .79609 L p .707 .577 .707 r
F P
0 g
s
.28863 .79609 m .28814 .77793 L .25632 .77964 L p .707 .577 .707 r
F P
0 g
s
.17213 .67088 m .17632 .61356 L .16357 .61004 L p .707 .577 .707 r
F P
0 g
s
.28814 .77793 m .28863 .79609 L .31799 .79125 L p .707 .577 .707 r
F P
0 g
s
.31799 .79125 m .31751 .77309 L .28814 .77793 L p .707 .577 .707 r
F P
0 g
s
.6699 .64948 m .66571 .7068 L .63821 .70338 L p .707 .577 .707 r
F P
0 g
s
.63821 .70338 m .64241 .64605 L .6699 .64948 L p .707 .577 .707 r
F P
0 g
s
.6891 .76107 m .68813 .79869 L .66706 .79319 L p .707 .577 .707 r
F P
0 g
s
.66706 .79319 m .66803 .75557 L .6891 .76107 L p .707 .577 .707 r
F P
0 g
s
.22515 .77806 m .22563 .79623 L .2568 .7978 L p .707 .577 .707 r
F P
0 g
s
.22563 .79623 m .22515 .77806 L .19769 .77335 L p .707 .577 .707 r
F P
0 g
s
.19341 .78567 m .19438 .74805 L .17331 .74255 L p .707 .577 .707 r
F P
0 g
s
.16357 .61004 m .15937 .66737 L .17213 .67088 L p .707 .577 .707 r
F P
0 g
s
.19769 .77335 m .19817 .79151 L .22563 .79623 L p .707 .577 .707 r
F P
0 g
s
.66803 .75557 m .66706 .79319 L .6396 .78913 L p .707 .577 .707 r
F P
0 g
s
.63377 .29582 m .63196 .7989 L .64196 .78749 L p .707 .577 .707 r
F P
0 g
s
.64196 .78749 m .64377 .28441 L .63377 .29582 L p .707 .577 .707 r
F P
0 g
s
.33823 .74887 m .33726 .78649 L .3536 .78121 L p .707 .577 .707 r
F P
0 g
s
.31751 .77309 m .31799 .79125 L .34202 .78377 L p .707 .577 .707 r
F P
0 g
s
.34202 .78377 m .34154 .76561 L .31751 .77309 L p .707 .577 .707 r
F P
0 g
s
.69241 .76289 m .69289 .78106 L .67183 .77367 L p .707 .577 .707 r
F P
0 g
s
.67183 .77367 m .67134 .7555 L .69241 .76289 L p .707 .577 .707 r
F P
0 g
s
.17331 .74255 m .17234 .78017 L .19341 .78567 L p .707 .577 .707 r
F P
0 g
s
.3536 .78121 m .35457 .74359 L .33823 .74887 L p .707 .577 .707 r
F P
0 g
s
.35705 .62512 m .35286 .68244 L .35971 .68018 L p .707 .577 .707 r
F P
0 g
s
.35971 .68018 m .36391 .62286 L .35705 .62512 L p .707 .577 .707 r
F P
0 g
s
.19817 .79151 m .19769 .77335 L .17662 .76596 L p .707 .577 .707 r
F P
0 g
s
.17662 .76596 m .1771 .78412 L .19817 .79151 L p .707 .577 .707 r
F P
0 g
s
.17234 .78017 m .17331 .74255 L .1607 .73616 L p .707 .577 .707 r
F P
0 g
s
.35457 .74359 m .3536 .78121 L .35506 .7799 L p .707 .577 .707 r
F P
0 g
s
.3554 .74785 m .35457 .74359 L .35506 .7799 L .707 .577 .707 r
F
.34154 .76561 m .34202 .78377 L .3551 .77624 L p F P
0 g
s
.3551 .77624 m .35836 .77436 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35514 .77269 m .34154 .76561 L .3551 .77624 L .707 .577 .707 r
F
.35836 .77436 m .35788 .7562 L .3553 .75769 L p F P
0 g
s
.3553 .75769 m .34154 .76561 L p .35514 .77269 L .707 .577 .707 r
F P
0 g
s
.35836 .77436 m .3553 .75769 L .35514 .77269 L .707 .577 .707 r
F
.35788 .7562 m .35836 .77436 L .36542 .76396 L p F P
0 g
s
.36542 .76396 m .36493 .7458 L .35788 .7562 L p .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .36163 .73731 L .35545 .7428 L p .707 .577 .707 r
F P
0 g
s
.35545 .7428 m .35457 .74359 L p .3554 .74785 L .707 .577 .707 r
F P
0 g
s
.36065 .77493 m .35545 .7428 L .3554 .74785 L .707 .577 .707 r
F
.35506 .7799 m .36065 .77493 L p .3554 .74785 L F P
0 g
s
.36391 .62286 m .35971 .68018 L .35661 .67715 L p .707 .577 .707 r
F P
0 g
s
.35661 .67715 m .36081 .61982 L .36391 .62286 L p .707 .577 .707 r
F P
0 g
s
.36163 .73731 m .36065 .77493 L .35773 .76827 L p .707 .577 .707 r
F P
0 g
s
.35773 .76827 m .3587 .73065 L .36163 .73731 L p .707 .577 .707 r
F P
0 g
s
.36081 .61982 m .35661 .67715 L .34386 .67363 L p .707 .577 .707 r
F P
0 g
s
.34386 .67363 m .34805 .61631 L .36081 .61982 L p .707 .577 .707 r
F P
0 g
s
.3587 .73065 m .35773 .76827 L .34512 .76187 L p .707 .577 .707 r
F P
0 g
s
.34512 .76187 m .34609 .72425 L .3587 .73065 L p .707 .577 .707 r
F P
0 g
s
.36201 .73542 m .3625 .75358 L .34988 .74424 L p .707 .577 .707 r
F P
0 g
s
.34988 .74424 m .3494 .72608 L .36201 .73542 L p .707 .577 .707 r
F P
0 g
s
.3582 .79326 m .36 .29018 L .35591 .27848 L p .707 .577 .707 r
F P
0 g
s
.36493 .7458 m .36542 .76396 L .3625 .75358 L p .707 .577 .707 r
F P
0 g
s
.3625 .75358 m .36201 .73542 L .36493 .7458 L p .707 .577 .707 r
F P
0 g
s
.36 .29018 m .3582 .79326 L .37598 .8041 L p .707 .577 .707 r
F P
0 g
s
.15937 .66737 m .16357 .61004 L .16047 .60701 L p .707 .577 .707 r
F P
0 g
s
.16047 .60701 m .15627 .66433 L .15937 .66737 L p .707 .577 .707 r
F P
0 g
s
.67134 .7555 m .67183 .77367 L .64436 .76895 L p .707 .577 .707 r
F P
0 g
s
.64436 .76895 m .64388 .75079 L .67134 .7555 L p .707 .577 .707 r
F P
0 g
s
.1607 .73616 m .15973 .77378 L .17234 .78017 L p .707 .577 .707 r
F P
0 g
s
.1771 .78412 m .17662 .76596 L .16401 .75662 L p .707 .577 .707 r
F P
0 g
s
.16401 .75662 m .16449 .77478 L .1771 .78412 L p .707 .577 .707 r
F P
0 g
s
.64377 .28441 m .64196 .78749 L .63787 .77579 L p .707 .577 .707 r
F P
0 g
s
.63787 .77579 m .63968 .27272 L .64377 .28441 L p .707 .577 .707 r
F P
0 g
s
.15973 .77378 m .1607 .73616 L .15778 .7295 L p .707 .577 .707 r
F P
0 g
s
.15627 .66433 m .16047 .60701 L .16732 .60475 L p .707 .577 .707 r
F P
0 g
s
.15778 .7295 m .15681 .76712 L .15973 .77378 L p .707 .577 .707 r
F P
0 g
s
.16732 .60475 m .16313 .66207 L .15627 .66433 L p .707 .577 .707 r
F P
0 g
s
.16449 .77478 m .16401 .75662 L .16109 .74624 L p .707 .577 .707 r
F P
0 g
s
.35591 .27848 m .35411 .78156 L .3582 .79326 L p .707 .577 .707 r
F P
0 g
s
.35411 .78156 m .35591 .27848 L .36591 .26707 L p .707 .577 .707 r
F P
0 g
s
.16109 .74624 m .16157 .7644 L .16449 .77478 L p .707 .577 .707 r
F P
0 g
s
.15681 .76712 m .15778 .7295 L .16484 .72322 L p .707 .577 .707 r
F P
0 g
s
.16313 .66207 m .16732 .60475 L .18346 .60349 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16157 .7644 m .16109 .74624 L .16703 .73748 L p .707 .577 .707 r
F P
0 g
s
.16688 .72256 m .18118 .71794 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16703 .73748 m .16815 .73584 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16157 .7644 m .16703 .73748 L .16706 .74055 L .707 .577 .707 r
F
.16719 .75262 m .18118 .71794 L .16726 .75975 L F
.16815 .73584 m .16863 .754 L .16722 .75607 L p F P
0 g
s
.16722 .75607 m .16157 .7644 L p .16706 .74055 L .707 .577 .707 r
F P
0 g
s
.16706 .74055 m .16815 .73584 L .16722 .75607 L .707 .577 .707 r
F
.18118 .71794 m .18021 .75556 L .16726 .75975 L p F P
0 g
s
.16726 .75975 m .16387 .76084 L p .16719 .75262 L .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16484 .72322 L .16688 .72256 L p .707 .577 .707 r
F P
0 g
s
.16387 .76084 m .16688 .72256 L .16719 .75262 L .707 .577 .707 r
F
.16484 .72322 m .16387 .76084 L .15681 .76712 L p F P
0 g
s
.18346 .60349 m .17927 .66081 L .16313 .66207 L p .707 .577 .707 r
F P
0 g
s
.63968 .27272 m .63787 .77579 L .62009 .76495 L p .707 .577 .707 r
F P
0 g
s
.62009 .76495 m .6219 .26187 L .63968 .27272 L p .707 .577 .707 r
F P
0 g
s
.34805 .61631 m .34386 .67363 L .3227 .66999 L p .707 .577 .707 r
F P
0 g
s
.3227 .66999 m .32689 .61266 L .34805 .61631 L p .707 .577 .707 r
F P
0 g
s
.36411 .77015 m .36591 .26707 L .38902 .25707 L p .707 .577 .707 r
F P
0 g
s
.36591 .26707 m .36411 .77015 L .35411 .78156 L p .707 .577 .707 r
F P
0 g
s
.17927 .66081 m .18346 .60349 L .20731 .60335 L p .707 .577 .707 r
F P
0 g
s
.20731 .60335 m .20312 .66067 L .17927 .66081 L p .707 .577 .707 r
F P
0 g
s
.18021 .75556 m .18118 .71794 L .20521 .71417 L p .707 .577 .707 r
F P
0 g
s
.16863 .754 m .16815 .73584 L .18449 .72643 L p .707 .577 .707 r
F P
0 g
s
.32689 .61266 m .3227 .66999 L .2952 .66656 L p .707 .577 .707 r
F P
0 g
s
.2952 .66656 m .2994 .60924 L .32689 .61266 L p .707 .577 .707 r
F P
0 g
s
.34609 .72425 m .34512 .76187 L .32405 .75638 L p .707 .577 .707 r
F P
0 g
s
.32405 .75638 m .32502 .71876 L .34609 .72425 L p .707 .577 .707 r
F P
0 g
s
.18449 .72643 m .18497 .74459 L .16863 .754 L p .707 .577 .707 r
F P
0 g
s
.6219 .26187 m .62009 .76495 L .59037 .75602 L p .707 .577 .707 r
F P
0 g
s
.59037 .75602 m .59217 .25294 L .6219 .26187 L p .707 .577 .707 r
F P
0 g
s
.20312 .66067 m .20731 .60335 L .23653 .60434 L p .707 .577 .707 r
F P
0 g
s
.3494 .72608 m .34988 .74424 L .32882 .73685 L p .707 .577 .707 r
F P
0 g
s
.32882 .73685 m .32833 .71869 L .3494 .72608 L p .707 .577 .707 r
F P
0 g
s
.23653 .60434 m .23234 .66166 L .20312 .66067 L p .707 .577 .707 r
F P
0 g
s
.2994 .60924 m .2952 .66656 L .26407 .66369 L p .707 .577 .707 r
F P
0 g
s
.26407 .66369 m .26826 .60637 L .2994 .60924 L p .707 .577 .707 r
F P
0 g
s
.38902 .25707 m .38722 .76015 L .36411 .77015 L p .707 .577 .707 r
F P
0 g
s
.38722 .76015 m .38902 .25707 L .42298 .24946 L p .707 .577 .707 r
F P
0 g
s
.20521 .71417 m .20424 .75179 L .18021 .75556 L p .707 .577 .707 r
F P
0 g
s
.23234 .66166 m .23653 .60434 L .26826 .60637 L p .707 .577 .707 r
F P
0 g
s
.20424 .75179 m .20521 .71417 L .23457 .71228 L p .707 .577 .707 r
F P
0 g
s
.18497 .74459 m .18449 .72643 L .20852 .71895 L p .707 .577 .707 r
F P
0 g
s
.26826 .60637 m .26407 .66369 L .23234 .66166 L p .707 .577 .707 r
F P
0 g
s
.32502 .71876 m .32405 .75638 L .29659 .75232 L p .707 .577 .707 r
F P
0 g
s
.29659 .75232 m .29756 .7147 L .32502 .71876 L p .707 .577 .707 r
F P
0 g
s
.73213 .65321 m .73632 .59589 L .70519 .59302 L p .707 .577 .707 r
F P
0 g
s
.73632 .59589 m .73213 .65321 L .76386 .65524 L p .707 .577 .707 r
F P
0 g
s
.76386 .65524 m .76806 .59792 L .73632 .59589 L p .707 .577 .707 r
F P
0 g
s
.20852 .71895 m .209 .73711 L .18497 .74459 L p .707 .577 .707 r
F P
0 g
s
.76806 .59792 m .76386 .65524 L .79308 .65623 L p .707 .577 .707 r
F P
0 g
s
.79308 .65623 m .79728 .59891 L .76806 .59792 L p .707 .577 .707 r
F P
0 g
s
.70519 .59302 m .70099 .65034 L .73213 .65321 L p .707 .577 .707 r
F P
0 g
s
.70099 .65034 m .70519 .59302 L .67769 .58959 L p .707 .577 .707 r
F P
0 g
s
.73226 .68754 m .73323 .64992 L .70206 .64768 L p .707 .577 .707 r
F P
0 g
s
.73323 .64992 m .73226 .68754 L .76408 .68772 L p .707 .577 .707 r
F P
0 g
s
.76408 .68772 m .76505 .6501 L .73323 .64992 L p .707 .577 .707 r
F P
0 g
s
.32833 .71869 m .32882 .73685 L .30135 .73214 L p .707 .577 .707 r
F P
0 g
s
.30135 .73214 m .30087 .71397 L .32833 .71869 L p .707 .577 .707 r
F P
0 g
s
.76505 .6501 m .76408 .68772 L .79344 .68583 L p .707 .577 .707 r
F P
0 g
s
.79728 .59891 m .79308 .65623 L .81693 .65609 L p .707 .577 .707 r
F P
0 g
s
.79344 .68583 m .79441 .64821 L .76505 .6501 L p .707 .577 .707 r
F P
0 g
s
.59217 .25294 m .59037 .75602 L .5516 .74989 L p .707 .577 .707 r
F P
0 g
s
.5516 .74989 m .55341 .24681 L .59217 .25294 L p .707 .577 .707 r
F P
0 g
s
.67769 .58959 m .6735 .64692 L .70099 .65034 L p .707 .577 .707 r
F P
0 g
s
.70109 .68531 m .70206 .64768 L .6746 .64362 L p .707 .577 .707 r
F P
0 g
s
.70206 .64768 m .70109 .68531 L .73226 .68754 L p .707 .577 .707 r
F P
0 g
s
.23457 .71228 m .2336 .7499 L .20424 .75179 L p .707 .577 .707 r
F P
0 g
s
.29756 .7147 m .29659 .75232 L .26542 .75009 L p .707 .577 .707 r
F P
0 g
s
.26542 .75009 m .26639 .71247 L .29756 .7147 L p .707 .577 .707 r
F P
0 g
s
.81693 .65609 m .82112 .59877 L .79728 .59891 L p .707 .577 .707 r
F P
0 g
s
.2336 .7499 m .23457 .71228 L .26639 .71247 L p .707 .577 .707 r
F P
0 g
s
.209 .73711 m .20852 .71895 L .23788 .71411 L p .707 .577 .707 r
F P
0 g
s
.42117 .75254 m .42298 .24946 L .46446 .24497 L p .707 .577 .707 r
F P
0 g
s
.42298 .24946 m .42117 .75254 L .38722 .76015 L p .707 .577 .707 r
F P
0 g
s
.6746 .64362 m .67363 .68124 L .70109 .68531 L p .707 .577 .707 r
F P
0 g
s
.26639 .71247 m .26542 .75009 L .2336 .7499 L p .707 .577 .707 r
F P
0 g
s
.79441 .64821 m .79344 .68583 L .81747 .68206 L p .707 .577 .707 r
F P
0 g
s
.82112 .59877 m .81693 .65609 L .83307 .65483 L p .707 .577 .707 r
F P
0 g
s
.81747 .68206 m .81844 .64444 L .79441 .64821 L p .707 .577 .707 r
F P
0 g
s
.6735 .64692 m .67769 .58959 L .65653 .58595 L p .707 .577 .707 r
F P
0 g
s
.23788 .71411 m .23836 .73227 L .209 .73711 L p .707 .577 .707 r
F P
0 g
s
.30087 .71397 m .30135 .73214 L .27019 .73056 L p .707 .577 .707 r
F P
0 g
s
.27019 .73056 m .2697 .7124 L .30087 .71397 L p .707 .577 .707 r
F P
0 g
s
.65653 .58595 m .65234 .64327 L .6735 .64692 L p .707 .577 .707 r
F P
0 g
s
.23836 .73227 m .23788 .71411 L .2697 .7124 L p .707 .577 .707 r
F P
0 g
s
.67363 .68124 m .6746 .64362 L .65353 .63813 L p .707 .577 .707 r
F P
0 g
s
.2697 .7124 m .27019 .73056 L .23836 .73227 L p .707 .577 .707 r
F P
0 g
s
.55341 .24681 m .5516 .74989 L .5076 .74714 L p .707 .577 .707 r
F P
0 g
s
.5076 .74714 m .5094 .24406 L .55341 .24681 L p .707 .577 .707 r
F P
0 g
s
.83307 .65483 m .83727 .59751 L .82112 .59877 L p .707 .577 .707 r
F P
0 g
s
.65353 .63813 m .65256 .67575 L .67363 .68124 L p .707 .577 .707 r
F P
0 g
s
.46265 .74805 m .46446 .24497 L .5094 .24406 L p .707 .577 .707 r
F P
0 g
s
.46446 .24497 m .46265 .74805 L .42117 .75254 L p .707 .577 .707 r
F P
0 g
s
.5094 .24406 m .5076 .74714 L .46265 .74805 L p .707 .577 .707 r
F P
0 g
s
.81844 .64444 m .81747 .68206 L .83381 .67678 L p .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84184 .63288 L .84141 .63326 L p .707 .577 .707 r
F P
0 g
s
.84141 .63326 m .83478 .63916 L p .83943 .66309 L .707 .577 .707 r
F P
0 g
s
.84087 .6705 m .84141 .63326 L .83943 .66309 L .707 .577 .707 r
F
.83727 .59751 m .83509 .62724 L p .83993 .65257 L F P
0 g
s
.83381 .67678 m .83478 .63916 L .83438 .63929 L p .707 .577 .707 r
F P
0 g
s
.83381 .67678 m .83438 .63929 L .83234 .67367 L .707 .577 .707 r
F
.83478 .63916 m .83381 .67678 L .84087 .6705 L p F P
0 g
s
.83346 .6547 m .83993 .65257 L p .83509 .62724 L .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .8421 .62296 L p .83727 .59751 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .84412 .59525 L .84298 .59562 L p .707 .577 .707 r
F P
0 g
s
.84298 .59562 m .83727 .59751 L p .8421 .62296 L .707 .577 .707 r
F P
0 g
s
.84184 .63288 m .84087 .6705 L .84058 .66984 L p .707 .577 .707 r
F P
0 g
s
.83993 .65257 m .83683 .64953 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.8421 .62296 m .83993 .65257 L p .84375 .598 L .707 .577 .707 r
F P
0 g
s
.84058 .66984 m .83795 .66384 L p .84175 .63357 L .707 .577 .707 r
F P
0 g
s
.84175 .63357 m .84184 .63288 L .84058 .66984 L .707 .577 .707 r
F
.84412 .59525 m .8421 .62296 L p .84375 .598 L F P
0 g
s
.83509 .62724 m .83307 .65483 L .83346 .6547 L p .707 .577 .707 r
F P
0 g
s
.83438 .63929 m .81844 .64444 L p .83234 .67367 L .707 .577 .707 r
F P
0 g
s
.65234 .64327 m .65653 .58595 L .64378 .58243 L p .707 .577 .707 r
F P
0 g
s
.73702 .78439 m .73653 .76623 L .70537 .76465 L p .707 .577 .707 r
F P
0 g
s
.73653 .76623 m .73702 .78439 L .76884 .78268 L p .707 .577 .707 r
F P
0 g
s
.76884 .78268 m .76836 .76451 L .73653 .76623 L p .707 .577 .707 r
F P
0 g
s
.76836 .76451 m .76884 .78268 L .7982 .77784 L p .707 .577 .707 r
F P
0 g
s
.7982 .77784 m .79772 .75968 L .76836 .76451 L p .707 .577 .707 r
F P
0 g
s
.64378 .58243 m .63958 .63976 L .65234 .64327 L p .707 .577 .707 r
F P
0 g
s
.65256 .67575 m .65353 .63813 L .64092 .63174 L p .707 .577 .707 r
F P
0 g
s
.70537 .76465 m .70585 .78281 L .73702 .78439 L p .707 .577 .707 r
F P
0 g
s
.70585 .78281 m .70537 .76465 L .6779 .75993 L p .707 .577 .707 r
F P
0 g
s
.64092 .63174 m .63995 .66936 L .65256 .67575 L p .707 .577 .707 r
F P
0 g
s
.6779 .75993 m .67839 .7781 L .70585 .78281 L p .707 .577 .707 r
F P
0 g
s
.79772 .75968 m .7982 .77784 L .82223 .77035 L p .707 .577 .707 r
F P
0 g
s
.82223 .77035 m .82175 .75219 L .79772 .75968 L p .707 .577 .707 r
F P
0 g
s
.67839 .7781 m .6779 .75993 L .65684 .75254 L p .707 .577 .707 r
F P
0 g
s
.63958 .63976 m .64378 .58243 L .64068 .5794 L p .707 .577 .707 r
F P
0 g
s
.65684 .75254 m .65732 .77071 L .67839 .7781 L p .707 .577 .707 r
F P
0 g
s
.64068 .5794 m .63648 .63672 L .63958 .63976 L p .707 .577 .707 r
F P
0 g
s
.63995 .66936 m .64092 .63174 L .638 .62507 L p .707 .577 .707 r
F P
0 g
s
.82175 .75219 m .82223 .77035 L .83857 .76095 L p .707 .577 .707 r
F P
0 g
s
.83857 .76095 m .83809 .74279 L .82175 .75219 L p .707 .577 .707 r
F P
0 g
s
.638 .62507 m .63702 .66269 L .63995 .66936 L p .707 .577 .707 r
F P
0 g
s
.65732 .77071 m .65684 .75254 L .64422 .7432 L p .707 .577 .707 r
F P
0 g
s
.83683 .64953 m .83913 .6181 L p .84412 .59525 L .707 .577 .707 r
F P
0 g
s
.84102 .59221 m .83683 .64953 L .82407 .64602 L p .707 .577 .707 r
F P
0 g
s
.83892 .62622 m .83795 .66384 L .83449 .66209 L p .707 .577 .707 r
F P
0 g
s
.83449 .66209 m .82534 .65745 L p .83806 .62818 L .707 .577 .707 r
F P
0 g
s
.83806 .62818 m .83892 .62622 L .83449 .66209 L .707 .577 .707 r
F
.83913 .6181 m .84102 .59221 L .84178 .59295 L p F P
0 g
s
.84178 .59295 m .84412 .59525 L p .83913 .6181 L .707 .577 .707 r
F P
0 g
s
.64422 .7432 m .64471 .76136 L .65732 .77071 L p .707 .577 .707 r
F P
0 g
s
.83795 .66384 m .83892 .62622 L .84184 .63288 L p .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .638 .62507 L .64488 .61895 L p .707 .577 .707 r
F P
0 g
s
.64536 .60688 m .64753 .57714 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.64488 .61895 m .64505 .61879 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.63702 .66269 m .64488 .61895 L .64483 .61998 L .707 .577 .707 r
F
.64753 .57714 m .66368 .57588 L p .64437 .63149 L F P
0 g
s
.66368 .57588 m .65948 .6332 L .64426 .63439 L p .707 .577 .707 r
F P
0 g
s
.64437 .63149 m .66368 .57588 L .64426 .63439 L .707 .577 .707 r
F
.64505 .61879 m .64408 .65642 L .64335 .65707 L p F P
0 g
s
.64335 .65707 m .63702 .66269 L p .64483 .61998 L .707 .577 .707 r
F P
0 g
s
.64483 .61998 m .64505 .61879 L .64335 .65707 L .707 .577 .707 r
F
.64426 .63439 m .64334 .63446 L p .64437 .63149 L F P
0 g
s
.64334 .63446 m .64536 .60688 L p .64437 .63149 L .707 .577 .707 r
F P
0 g
s
.63648 .63672 m .64068 .5794 L .64753 .57714 L p .707 .577 .707 r
F P
0 g
s
.83809 .74279 m .83857 .76095 L .84563 .75055 L p .707 .577 .707 r
F P
0 g
s
.84563 .75055 m .84515 .73239 L .83809 .74279 L p .707 .577 .707 r
F P
0 g
s
.64753 .57714 m .64334 .63446 L .63648 .63672 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64471 .76136 m .64422 .7432 L .6413 .73282 L p .707 .577 .707 r
F P
0 g
s
.6413 .73282 m .64179 .75098 L .64471 .76136 L p .707 .577 .707 r
F P
0 g
s
.82407 .64602 m .82648 .61313 L p .84102 .59221 L .707 .577 .707 r
F P
0 g
s
.82827 .5887 m .82407 .64602 L .80291 .64237 L p .707 .577 .707 r
F P
0 g
s
.82631 .61983 m .82534 .65745 L .81662 .65517 L p .707 .577 .707 r
F P
0 g
s
.81662 .65517 m .80427 .65195 L p .82418 .62292 L .707 .577 .707 r
F P
0 g
s
.82418 .62292 m .82631 .61983 L .81662 .65517 L .707 .577 .707 r
F
.82648 .61313 m .82827 .5887 L .83197 .58972 L p F P
0 g
s
.83197 .58972 m .84102 .59221 L p .82648 .61313 L .707 .577 .707 r
F P
0 g
s
.82534 .65745 m .82631 .61983 L .83892 .62622 L p .707 .577 .707 r
F P
0 g
s
.38912 .61639 m .39331 .55907 L .36218 .5562 L p .707 .577 .707 r
F P
0 g
s
.39331 .55907 m .38912 .61639 L .42085 .61842 L p .707 .577 .707 r
F P
0 g
s
.42085 .61842 m .42505 .5611 L .39331 .55907 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42505 .5611 m .42085 .61842 L .45007 .61941 L p .707 .577 .707 r
F P
0 g
s
.45007 .61941 m .45427 .56209 L .42505 .5611 L p .707 .577 .707 r
F P
0 g
s
.84515 .73239 m .84563 .75055 L .84271 .74017 L p .707 .577 .707 r
F P
0 g
s
.84271 .74017 m .84223 .72201 L .84515 .73239 L p .707 .577 .707 r
F P
0 g
s
.36218 .5562 m .35798 .61352 L .38912 .61639 L p .707 .577 .707 r
F P
0 g
s
.35798 .61352 m .36218 .5562 L .33468 .55278 L p .707 .577 .707 r
F P
0 g
s
.38925 .65072 m .39022 .6131 L .35905 .61087 L p .707 .577 .707 r
F P
0 g
s
.39022 .6131 m .38925 .65072 L .42107 .6509 L p .707 .577 .707 r
F P
0 g
s
.42107 .6509 m .42204 .61328 L .39022 .6131 L p .707 .577 .707 r
F P
0 g
s
.42204 .61328 m .42107 .6509 L .45043 .64902 L p .707 .577 .707 r
F P
0 g
s
.45427 .56209 m .45007 .61941 L .47392 .61927 L p .707 .577 .707 r
F P
0 g
s
.45043 .64902 m .4514 .6114 L .42204 .61328 L p .707 .577 .707 r
F P
0 g
s
.65948 .6332 m .66165 .60359 L p .68753 .57574 L .707 .577 .707 r
F P
0 g
s
.66165 .60359 m .66368 .57588 L .66503 .57587 L p .707 .577 .707 r
F P
0 g
s
.66503 .57587 m .68753 .57574 L p .66165 .60359 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .64505 .61879 L .6604 .61383 L p .707 .577 .707 r
F P
0 g
s
.6604 .61383 m .66139 .61351 L p .66003 .6169 L .707 .577 .707 r
F P
0 g
s
.64408 .65642 m .6604 .61383 L .66003 .6169 L .707 .577 .707 r
F
.33468 .55278 m .33049 .6101 L .35798 .61352 L p F P
0 g
s
.35808 .64849 m .35905 .61087 L .33159 .60681 L p .707 .577 .707 r
F P
0 g
s
.35905 .61087 m .35808 .64849 L .38925 .65072 L p .707 .577 .707 r
F P
0 g
s
.47392 .61927 m .47811 .56195 L .45427 .56209 L p .707 .577 .707 r
F P
0 g
s
.68753 .57574 m .68333 .63306 L .65948 .6332 L p .707 .577 .707 r
F P
0 g
s
.66139 .61351 m .66042 .65113 L .64408 .65642 L p .707 .577 .707 r
F P
0 g
s
.64179 .75098 m .6413 .73282 L .64836 .72242 L p .707 .577 .707 r
F P
0 g
s
.33159 .60681 m .33062 .64443 L .35808 .64849 L p .707 .577 .707 r
F P
0 g
s
.4514 .6114 m .45043 .64902 L .47446 .64525 L p .707 .577 .707 r
F P
0 g
s
.47811 .56195 m .47392 .61927 L .49006 .61801 L p .707 .577 .707 r
F P
0 g
s
.47446 .64525 m .47543 .60763 L .4514 .6114 L p .707 .577 .707 r
F P
0 g
s
.33049 .6101 m .33468 .55278 L .31352 .54913 L p .707 .577 .707 r
F P
0 g
s
.80291 .64237 m .80539 .60856 L p .82827 .5887 L .707 .577 .707 r
F P
0 g
s
.80711 .58505 m .80291 .64237 L .77542 .63895 L p .707 .577 .707 r
F P
0 g
s
.80524 .61433 m .80427 .65195 L .79018 .64987 L p .707 .577 .707 r
F P
0 g
s
.79018 .64987 m .77681 .64789 L p .80174 .61846 L .707 .577 .707 r
F P
0 g
s
.80174 .61846 m .80524 .61433 L .79018 .64987 L .707 .577 .707 r
F
.80539 .60856 m .80711 .58505 L .81363 .58618 L p F P
0 g
s
.81363 .58618 m .82827 .5887 L p .80539 .60856 L .707 .577 .707 r
F P
0 g
s
.64836 .72242 m .64884 .74058 L .64179 .75098 L p .707 .577 .707 r
F P
0 g
s
.31352 .54913 m .30933 .60645 L .33049 .6101 L p .707 .577 .707 r
F P
0 g
s
.80427 .65195 m .80524 .61433 L .82631 .61983 L p .707 .577 .707 r
F P
0 g
s
.33062 .64443 m .33159 .60681 L .31052 .60131 L p .707 .577 .707 r
F P
0 g
s
.84223 .72201 m .84271 .74017 L .8301 .73083 L p .707 .577 .707 r
F P
0 g
s
.8301 .73083 m .82962 .71266 L .84223 .72201 L p .707 .577 .707 r
F P
0 g
s
.49006 .61801 m .49426 .56069 L .47811 .56195 L p .707 .577 .707 r
F P
0 g
s
.31052 .60131 m .30955 .63893 L .33062 .64443 L p .707 .577 .707 r
F P
0 g
s
.68333 .63306 m .68563 .60162 L p .71675 .57673 L .707 .577 .707 r
F P
0 g
s
.68563 .60162 m .68753 .57574 L .69199 .57589 L p .707 .577 .707 r
F P
0 g
s
.69199 .57589 m .71675 .57673 L p .68563 .60162 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .66139 .61351 L .68355 .61004 L p .707 .577 .707 r
F P
0 g
s
.68355 .61004 m .68542 .60974 L p .68238 .61478 L .707 .577 .707 r
F P
0 g
s
.66042 .65113 m .68355 .61004 L .68238 .61478 L .707 .577 .707 r
F
.47543 .60763 m .47446 .64525 L .4908 .63996 L p F P
0 g
s
.49786 .63368 m .49883 .59606 L .4984 .59645 L p .707 .577 .707 r
F P
0 g
s
.4984 .59645 m .49177 .60234 L p .49642 .62627 L .707 .577 .707 r
F P
0 g
s
.49786 .63368 m .4984 .59645 L .49642 .62627 L .707 .577 .707 r
F
.49426 .56069 m .49208 .59043 L p .49692 .61575 L F P
0 g
s
.4908 .63996 m .49177 .60234 L .49137 .60248 L p .707 .577 .707 r
F P
0 g
s
.4908 .63996 m .49137 .60248 L .48933 .63686 L .707 .577 .707 r
F
.49177 .60234 m .4908 .63996 L .49786 .63368 L p F P
0 g
s
.49045 .61788 m .49692 .61575 L p .49208 .59043 L .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49908 .58614 L p .49426 .56069 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .50111 .55843 L .49997 .55881 L p .707 .577 .707 r
F P
0 g
s
.49997 .55881 m .49426 .56069 L p .49908 .58614 L .707 .577 .707 r
F P
0 g
s
.49883 .59606 m .49786 .63368 L .49757 .63303 L p .707 .577 .707 r
F P
0 g
s
.49692 .61575 m .49382 .61272 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49908 .58614 m .49692 .61575 L p .50074 .56118 L .707 .577 .707 r
F P
0 g
s
.49757 .63303 m .49494 .62702 L p .49874 .59676 L .707 .577 .707 r
F P
0 g
s
.49874 .59676 m .49883 .59606 L .49757 .63303 L .707 .577 .707 r
F
.50111 .55843 m .49908 .58614 L p .50074 .56118 L F P
0 g
s
.49208 .59043 m .49006 .61801 L .49045 .61788 L p .707 .577 .707 r
F P
0 g
s
.49137 .60248 m .47543 .60763 L p .48933 .63686 L .707 .577 .707 r
F P
0 g
s
.71675 .57673 m .71255 .63405 L .68333 .63306 L p .707 .577 .707 r
F P
0 g
s
.68542 .60974 m .68445 .64736 L .66042 .65113 L p .707 .577 .707 r
F P
0 g
s
.30933 .60645 m .31352 .54913 L .30077 .54562 L p .707 .577 .707 r
F P
0 g
s
.39401 .74757 m .39352 .72941 L .36236 .72783 L p .707 .577 .707 r
F P
0 g
s
.39352 .72941 m .39401 .74757 L .42583 .74586 L p .707 .577 .707 r
F P
0 g
s
.42583 .74586 m .42535 .7277 L .39352 .72941 L p .707 .577 .707 r
F P
0 g
s
.77542 .63895 m .77792 .60481 L p .80711 .58505 L .707 .577 .707 r
F P
0 g
s
.77961 .58163 m .77542 .63895 L .74428 .63608 L p .707 .577 .707 r
F P
0 g
s
.77778 .61027 m .77681 .64789 L .75907 .64662 L p .707 .577 .707 r
F P
0 g
s
.75907 .64662 m .74564 .64566 L p .77317 .61534 L .707 .577 .707 r
F P
0 g
s
.77317 .61534 m .77778 .61027 L .75907 .64662 L .707 .577 .707 r
F
.77792 .60481 m .77961 .58163 L .7879 .58266 L p F P
0 g
s
.7879 .58266 m .80711 .58505 L p .77792 .60481 L .707 .577 .707 r
F P
0 g
s
.64884 .74058 m .64836 .72242 L .6647 .71302 L p .707 .577 .707 r
F P
0 g
s
.42535 .7277 m .42583 .74586 L .45519 .74102 L p .707 .577 .707 r
F P
0 g
s
.45519 .74102 m .45471 .72286 L .42535 .7277 L p .707 .577 .707 r
F P
0 g
s
.30077 .54562 m .29657 .60294 L .30933 .60645 L p .707 .577 .707 r
F P
0 g
s
.77681 .64789 m .77778 .61027 L .80524 .61433 L p .707 .577 .707 r
F P
0 g
s
.30955 .63893 m .31052 .60131 L .29791 .59492 L p .707 .577 .707 r
F P
0 g
s
.36236 .72783 m .36284 .746 L .39401 .74757 L p .707 .577 .707 r
F P
0 g
s
.36284 .746 m .36236 .72783 L .33489 .72312 L p .707 .577 .707 r
F P
0 g
s
.6647 .71302 m .66518 .73118 L .64884 .74058 L p .707 .577 .707 r
F P
0 g
s
.71255 .63405 m .71496 .60116 L p .74848 .57876 L .707 .577 .707 r
F P
0 g
s
.71496 .60116 m .71675 .57673 L .72387 .57719 L p .707 .577 .707 r
F P
0 g
s
.72387 .57719 m .74848 .57876 L p .71496 .60116 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .68542 .60974 L .71241 .60801 L p .707 .577 .707 r
F P
0 g
s
.71241 .60801 m .71478 .60786 L p .7103 .6137 L .707 .577 .707 r
F P
0 g
s
.68445 .64736 m .71241 .60801 L .7103 .6137 L .707 .577 .707 r
F
.29791 .59492 m .29693 .63254 L .30955 .63893 L p F P
0 g
s
.33489 .72312 m .33538 .74128 L .36284 .746 L p .707 .577 .707 r
F P
0 g
s
.45471 .72286 m .45519 .74102 L .47922 .73354 L p .707 .577 .707 r
F P
0 g
s
.47922 .73354 m .47874 .71538 L .45471 .72286 L p .707 .577 .707 r
F P
0 g
s
.82962 .71266 m .8301 .73083 L .80903 .72344 L p .707 .577 .707 r
F P
0 g
s
.80903 .72344 m .80855 .70527 L .82962 .71266 L p .707 .577 .707 r
F P
0 g
s
.74848 .57876 m .74428 .63608 L .71255 .63405 L p .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .71478 .60786 L .74416 .60802 L p .707 .577 .707 r
F P
0 g
s
.74428 .63608 m .74676 .60226 L p .77961 .58163 L .707 .577 .707 r
F P
0 g
s
.74416 .60802 m .74661 .60804 L p .74156 .61381 L .707 .577 .707 r
F P
0 g
s
.71381 .64548 m .74416 .60802 L .74156 .61381 L .707 .577 .707 r
F
.74676 .60226 m .74848 .57876 L .75699 .57955 L p F P
0 g
s
.75699 .57955 m .77961 .58163 L p .74676 .60226 L .707 .577 .707 r
F P
0 g
s
.71478 .60786 m .71381 .64548 L .68445 .64736 L p .707 .577 .707 r
F P
0 g
s
.74564 .64566 m .74661 .60804 L .77778 .61027 L p .707 .577 .707 r
F P
0 g
s
.33538 .74128 m .33489 .72312 L .31383 .71573 L p .707 .577 .707 r
F P
0 g
s
.74661 .60804 m .74564 .64566 L .71381 .64548 L p .707 .577 .707 r
F P
0 g
s
.66518 .73118 m .6647 .71302 L .68873 .70553 L p .707 .577 .707 r
F P
0 g
s
.29657 .60294 m .30077 .54562 L .29767 .54258 L p .707 .577 .707 r
F P
0 g
s
.31383 .71573 m .31431 .73389 L .33538 .74128 L p .707 .577 .707 r
F P
0 g
s
.29767 .54258 m .29347 .59991 L .29657 .60294 L p .707 .577 .707 r
F P
0 g
s
.68873 .70553 m .68921 .72369 L .66518 .73118 L p .707 .577 .707 r
F P
0 g
s
.29693 .63254 m .29791 .59492 L .29498 .58826 L p .707 .577 .707 r
F P
0 g
s
.47874 .71538 m .47922 .73354 L .49556 .72413 L p .707 .577 .707 r
F P
0 g
s
.49556 .72413 m .49508 .70597 L .47874 .71538 L p .707 .577 .707 r
F P
0 g
s
.80855 .70527 m .80903 .72344 L .78157 .71872 L p .707 .577 .707 r
F P
0 g
s
.78157 .71872 m .78109 .70056 L .80855 .70527 L p .707 .577 .707 r
F P
0 g
s
.29498 .58826 m .29401 .62588 L .29693 .63254 L p .707 .577 .707 r
F P
0 g
s
.31431 .73389 m .31383 .71573 L .30121 .70639 L p .707 .577 .707 r
F P
0 g
s
.68921 .72369 m .68873 .70553 L .71809 .70069 L p .707 .577 .707 r
F P
0 g
s
.49382 .61272 m .49612 .58128 L p .50111 .55843 L .707 .577 .707 r
F P
0 g
s
.49801 .5554 m .49382 .61272 L .48106 .60921 L p .707 .577 .707 r
F P
0 g
s
.49591 .5894 m .49494 .62702 L .49148 .62527 L p .707 .577 .707 r
F P
0 g
s
.49148 .62527 m .48233 .62063 L p .49505 .59137 L .707 .577 .707 r
F P
0 g
s
.49505 .59137 m .49591 .5894 L .49148 .62527 L .707 .577 .707 r
F
.49612 .58128 m .49801 .5554 L .49877 .55614 L p F P
0 g
s
.49877 .55614 m .50111 .55843 L p .49612 .58128 L .707 .577 .707 r
F P
0 g
s
.30121 .70639 m .3017 .72455 L .31431 .73389 L p .707 .577 .707 r
F P
0 g
s
.71809 .70069 m .71858 .71886 L .68921 .72369 L p .707 .577 .707 r
F P
0 g
s
.49494 .62702 m .49591 .5894 L .49883 .59606 L p .707 .577 .707 r
F P
0 g
s
.78109 .70056 m .78157 .71872 L .7504 .71714 L p .707 .577 .707 r
F P
0 g
s
.7504 .71714 m .74992 .69898 L .78109 .70056 L p .707 .577 .707 r
F P
0 g
s
.71858 .71886 m .71809 .70069 L .74992 .69898 L p .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .29498 .58826 L .30186 .58214 L p .707 .577 .707 r
F P
0 g
s
.30235 .57006 m .30452 .54033 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.30186 .58214 m .30204 .58198 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.29401 .62588 m .30186 .58214 L .30182 .58317 L .707 .577 .707 r
F
.30452 .54033 m .32067 .53906 L p .30136 .59467 L F P
0 g
s
.32067 .53906 m .31647 .59639 L .30125 .59758 L p .707 .577 .707 r
F P
0 g
s
.30136 .59467 m .32067 .53906 L .30125 .59758 L .707 .577 .707 r
F
.30204 .58198 m .30107 .6196 L .30034 .62025 L p F P
0 g
s
.30034 .62025 m .29401 .62588 L p .30182 .58317 L .707 .577 .707 r
F P
0 g
s
.30182 .58317 m .30204 .58198 L .30034 .62025 L .707 .577 .707 r
F
.30125 .59758 m .30033 .59765 L p .30136 .59467 L F P
0 g
s
.30033 .59765 m .30235 .57006 L p .30136 .59467 L .707 .577 .707 r
F P
0 g
s
.29347 .59991 m .29767 .54258 L .30452 .54033 L p .707 .577 .707 r
F P
0 g
s
.49508 .70597 m .49556 .72413 L .50262 .71373 L p .707 .577 .707 r
F P
0 g
s
.50262 .71373 m .50214 .69557 L .49508 .70597 L p .707 .577 .707 r
F P
0 g
s
.74992 .69898 m .7504 .71714 L .71858 .71886 L p .707 .577 .707 r
F P
0 g
s
.30452 .54033 m .30033 .59765 L .29347 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.3017 .72455 m .30121 .70639 L .29829 .69601 L p .707 .577 .707 r
F P
0 g
s
.29829 .69601 m .29878 .71417 L .3017 .72455 L p .707 .577 .707 r
F P
0 g
s
.48106 .60921 m .48347 .57632 L p .49801 .5554 L .707 .577 .707 r
F P
0 g
s
.48526 .55189 m .48106 .60921 L .4599 .60556 L p .707 .577 .707 r
F P
0 g
s
.4833 .58301 m .48233 .62063 L .47361 .61836 L p .707 .577 .707 r
F P
0 g
s
.47361 .61836 m .46126 .61514 L p .48117 .5861 L .707 .577 .707 r
F P
0 g
s
.48117 .5861 m .4833 .58301 L .47361 .61836 L .707 .577 .707 r
F
.48347 .57632 m .48526 .55189 L .48896 .55291 L p F P
0 g
s
.48896 .55291 m .49801 .5554 L p .48347 .57632 L .707 .577 .707 r
F P
0 g
s
.48233 .62063 m .4833 .58301 L .49591 .5894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50214 .69557 m .50262 .71373 L .4997 .70335 L p .707 .577 .707 r
F P
0 g
s
.4997 .70335 m .49922 .68519 L .50214 .69557 L p .707 .577 .707 r
F P
0 g
s
.31647 .59639 m .31864 .56678 L p .34451 .53892 L .707 .577 .707 r
F P
0 g
s
.31864 .56678 m .32067 .53906 L .32202 .53906 L p .707 .577 .707 r
F P
0 g
s
.32202 .53906 m .34451 .53892 L p .31864 .56678 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .30204 .58198 L .31739 .57702 L p .707 .577 .707 r
F P
0 g
s
.31739 .57702 m .31838 .5767 L p .31702 .58008 L .707 .577 .707 r
F P
0 g
s
.30107 .6196 m .31739 .57702 L .31702 .58008 L .707 .577 .707 r
F
.34451 .53892 m .34032 .59624 L .31647 .59639 L p F P
0 g
s
.31838 .5767 m .31741 .61432 L .30107 .6196 L p .707 .577 .707 r
F P
0 g
s
.29878 .71417 m .29829 .69601 L .30535 .68561 L p .707 .577 .707 r
F P
0 g
s
.4599 .60556 m .46238 .57174 L p .48526 .55189 L .707 .577 .707 r
F P
0 g
s
.4641 .54824 m .4599 .60556 L .43241 .60213 L p .707 .577 .707 r
F P
0 g
s
.46223 .57752 m .46126 .61514 L .44717 .61305 L p .707 .577 .707 r
F P
0 g
s
.44717 .61305 m .43379 .61107 L p .45873 .58164 L .707 .577 .707 r
F P
0 g
s
.45873 .58164 m .46223 .57752 L .44717 .61305 L .707 .577 .707 r
F
.46238 .57174 m .4641 .54824 L .47062 .54936 L p F P
0 g
s
.47062 .54936 m .48526 .55189 L p .46238 .57174 L .707 .577 .707 r
F P
0 g
s
.30535 .68561 m .30583 .70377 L .29878 .71417 L p .707 .577 .707 r
F P
0 g
s
.46126 .61514 m .46223 .57752 L .4833 .58301 L p .707 .577 .707 r
F P
0 g
s
.49922 .68519 m .4997 .70335 L .48709 .69401 L p .707 .577 .707 r
F P
0 g
s
.48709 .69401 m .48661 .67585 L .49922 .68519 L p .707 .577 .707 r
F P
0 g
s
.34032 .59624 m .34262 .56481 L p .37373 .53992 L .707 .577 .707 r
F P
0 g
s
.34262 .56481 m .34451 .53892 L .34898 .53907 L p .707 .577 .707 r
F P
0 g
s
.34898 .53907 m .37373 .53992 L p .34262 .56481 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .31838 .5767 L .34054 .57322 L p .707 .577 .707 r
F P
0 g
s
.34054 .57322 m .34241 .57293 L p .33937 .57796 L .707 .577 .707 r
F P
0 g
s
.31741 .61432 m .34054 .57322 L .33937 .57796 L .707 .577 .707 r
F
.37373 .53992 m .36954 .59724 L .34032 .59624 L p F P
0 g
s
.34241 .57293 m .34144 .61055 L .31741 .61432 L p .707 .577 .707 r
F P
0 g
s
.43241 .60213 m .43491 .56799 L p .4641 .54824 L .707 .577 .707 r
F P
0 g
s
.4366 .54481 m .43241 .60213 L .40127 .59927 L p .707 .577 .707 r
F P
0 g
s
.43477 .57345 m .43379 .61107 L .41606 .6098 L p .707 .577 .707 r
F P
0 g
s
.41606 .6098 m .40263 .60884 L p .43016 .57853 L .707 .577 .707 r
F P
0 g
s
.43016 .57853 m .43477 .57345 L .41606 .6098 L .707 .577 .707 r
F
.43491 .56799 m .4366 .54481 L .44489 .54585 L p F P
0 g
s
.44489 .54585 m .4641 .54824 L p .43491 .56799 L .707 .577 .707 r
F P
0 g
s
.30583 .70377 m .30535 .68561 L .32169 .6762 L p .707 .577 .707 r
F P
0 g
s
.43379 .61107 m .43477 .57345 L .46223 .57752 L p .707 .577 .707 r
F P
0 g
s
.32169 .6762 m .32217 .69436 L .30583 .70377 L p .707 .577 .707 r
F P
0 g
s
.36954 .59724 m .37195 .56435 L p .40547 .54195 L .707 .577 .707 r
F P
0 g
s
.37195 .56435 m .37373 .53992 L .38086 .54037 L p .707 .577 .707 r
F P
0 g
s
.38086 .54037 m .40547 .54195 L p .37195 .56435 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .34241 .57293 L .3694 .57119 L p .707 .577 .707 r
F P
0 g
s
.3694 .57119 m .37177 .57104 L p .36729 .57689 L .707 .577 .707 r
F P
0 g
s
.34144 .61055 m .3694 .57119 L .36729 .57689 L .707 .577 .707 r
F
.48661 .67585 m .48709 .69401 L .46602 .68662 L p F P
0 g
s
.46602 .68662 m .46554 .66846 L .48661 .67585 L p .707 .577 .707 r
F P
0 g
s
.40547 .54195 m .40127 .59927 L .36954 .59724 L p .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .37177 .57104 L .40115 .57121 L p .707 .577 .707 r
F P
0 g
s
.40127 .59927 m .40375 .56545 L p .4366 .54481 L .707 .577 .707 r
F P
0 g
s
.40115 .57121 m .4036 .57122 L p .39855 .57699 L .707 .577 .707 r
F P
0 g
s
.3708 .60866 m .40115 .57121 L .39855 .57699 L .707 .577 .707 r
F
.40375 .56545 m .40547 .54195 L .41398 .54273 L p F P
0 g
s
.41398 .54273 m .4366 .54481 L p .40375 .56545 L .707 .577 .707 r
F P
0 g
s
.37177 .57104 m .3708 .60866 L .34144 .61055 L p .707 .577 .707 r
F P
0 g
s
.40263 .60884 m .4036 .57122 L .43477 .57345 L p .707 .577 .707 r
F P
0 g
s
.4036 .57122 m .40263 .60884 L .3708 .60866 L p .707 .577 .707 r
F P
0 g
s
.32217 .69436 m .32169 .6762 L .34572 .66872 L p .707 .577 .707 r
F P
0 g
s
.34572 .66872 m .3462 .68688 L .32217 .69436 L p .707 .577 .707 r
F P
0 g
s
.46554 .66846 m .46602 .68662 L .43856 .6819 L p .707 .577 .707 r
F P
0 g
s
.43856 .6819 m .43808 .66374 L .46554 .66846 L p .707 .577 .707 r
F P
0 g
s
.3462 .68688 m .34572 .66872 L .37508 .66388 L p .707 .577 .707 r
F P
0 g
s
.37508 .66388 m .37557 .68204 L .3462 .68688 L p .707 .577 .707 r
F P
0 g
s
.43808 .66374 m .43856 .6819 L .40739 .68033 L p .707 .577 .707 r
F P
0 g
s
.40739 .68033 m .40691 .66217 L .43808 .66374 L p .707 .577 .707 r
F P
0 g
s
.37557 .68204 m .37508 .66388 L .40691 .66217 L p .707 .577 .707 r
F P
0 g
s
.40691 .66217 m .40739 .68033 L .37557 .68204 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001^Ool30007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00=JEP<006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005IooaX000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0`002UYF00<005YFFUH0
1UYF00<005YFFUH00eYF3@001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH0000:FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol005Aoo`03001JEP0000YJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF1@000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo0P0015YF00<005YFFUH0
0eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001COol00`00FUH00004FUH00`00FUIJEP03FUHG0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005=oo`03001JEP0000AJEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool=001EOol005=oo`03001JEP00009JEPH000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUIJEP04
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600000eYF001J
EP05FUH00`00FUIJEP02FUHB0013Ool005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP04
001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH8000kOol005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP00
02eoo`00;goo6@002goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00;Goo0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@000Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP80
00EJEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01000FUIJEP00
0eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF0P000UYF20000eYF0P001eYF0P0015YF20000eYF0P0015YF0P000UYF0P00;Goo000]Ool00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00003FUH60007FUH01000FUIJEUYF4P0000=JEP0000001P0015YF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEPD000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH20002FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF001JEUYF00000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=J
EP00FUH00UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009JEP05001JEUYFFUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2
000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP00
0000;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<0
02eoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF4`000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00UYF200035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00@005YFFUIJER<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJ
EP0B0007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH50004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000eYF0P00;Goo
000/Ool00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;7oo1@001EYF00<005YFFUH0
1EYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEP0001@000EJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP03001JEUYF00D0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00]JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
000]Ool002moo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEPL000=JEP@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@000YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000]Ool003=oo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH3000^Ool003Yoo`T000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH00000008000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00@goo2@0015YF00<005YF
FUH01EYF0P0000=JEP00FUH01EYF00<005YFFUH015YF5@001UYF00<005YFFUH00eYF0`000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1`0015YF00<0
05YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH00eYF1000<Woo001<Ool<0003FUH00`00
FUIJEP04FUH00`00FUIJEP040005FUH50004FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P001UYF00<005YFFUH00eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Woo001EOol20004FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP08
FUH40004FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000AooaL003Yoo`00EGoo0P0015YF
00<005YF00000`000goo00@005YFFUH000IJEPD000AJEP03001JEUYF00UJEP03001JEUYF00<00004
FUH005YFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001DOol00`00FUH00004FUH20007Ool01000
FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P000UYF0P0000=JEP00FUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YF
FUIJEP0005Eoo`00E7oo00<005YF00000UYF0P002Goo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00EJEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001UYF00<005YFFUH00eYF00D005YFFUIJEP0000Uoo`T004=oo`00E7oo
00<005YF00000P002goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00=JEP03001JEUYF00/000AJEP03001JEUYF009JEPP003]oo`00E7oo00<005YF0000
3Goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00IJEP05001JEP00
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0003FUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=Woo001DOol3000=Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF0P0000AJEP00FUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000cOol003mooa8000=o
o`800003FUH0000000]oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH200001UYF001JEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000aOol003Moo`P00003FUH0000000H000AJEP03001JEUYF009J
EPD000=JEP8000Uoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF
0P000eYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P00<7oo000bOol50003FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUH000030005Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF100000=JEP00
FUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH01EYF00<005YFFUH00UYF3@001Goo20000eYF00<005YFFUH00eYF00@005YF0000
02ioo`00;Woo100000AJEP00FUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP05001JEUYFFUH00004FUH500001Goo001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH00eYF
1P001EYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003Ool005YF00=JEP03001JEUYF009JEPH000Qoo`D000eoo`D000AJEP05001J
EUYFFUH0000]Ool002eoo`8000AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF2@0015YF00<005YF
FUH015YF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000AJEP03001JEP00008000ioo`D0019oo`<00003FUH005YF009JEP03001oogoo02]o
o`00;7oo00<005YF00000eYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF0`0000=J
EP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP<000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJ
EP80019oo`<001Ioo`8000=JEP8002aoo`00;7oo00@005YF001JEP80009JEP03001JEUYF00AJEP03
001JEUYF009JEPP000=JEP03001JEUYF00=JEPX000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH2000_Ool00`00FUIJEP02000/
Ool002aoo`04001JEP000004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000015YF00000000<Woo1000;7oo000/Ool01000FUH0000015YF00<005YF00001000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00Ool0=Goo0P00;7oo000/Ool01000FUH00000
15YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00=Goo
1000;7oo000/Ool01000FUH000000UYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00005`000UYF60001UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF1@00<Goo0P0000AJEP00FUH002aoo`00;7oo00<005YF
00000`0000=JEP00FUH00UYF7`001UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF2@002eYF00<005YFFUH02EYF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`000UYF00<007ooOol0:goo0`000eYF00<005YF0000;7oo000/Ool01000FUH000000eYF1@001eYF
00@005YFFUIJEQL0009JEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF
009JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPL000MJEP03001JEUYF
009JEP<0009JEPH002Ioo`800003FUH005YF00=JEP8002eoo`00;7oo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF1P000eYF00<005YF
00000UYF00<005YFFUH015YF00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P0000AJ
EP000000025oo`8000=JEP03001JEUYF009JEP8002eoo`00;7oo00<005YF00000`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000EJ
EP00FUIJEP0000EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP<00003FUH005YF00=JEP<0009JEP03001JEUYF009JEPH001Yoo`D0
00EJEP03001JEUYF009JEP03001oogoo02aoo`00;7oo0`000UYF0`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1@000UYF00<005YF0000
0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00@005YF000000AJEP@00003FUH005YF00AJEP04001JEUYFFUHK0003FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool002aoo`<000=JEP03001JEP00008000QJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00005FUH005YFFUH00002FUH200000eYF001JEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF1P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`00<Goo000/Ool30003FUH00`00FUIJEP02FUH30004FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH40005FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP@000=JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8003=oo`00;Goo0P000eYF00<005YFFUH00eYF00<0
05YF0000100025YF1@0015YF00@005YFFUIJEP@0009JEP03001JEUYF00AJEP03001JEUYF008000AJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000005FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000eOol002moo`800003FUH005YF
00AJEP03001JEUYF00=JEQH000IJEP03001JEUYF00AJEPD000AJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP000006FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH5000iOol0035oo`8000EJEP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001J
EUYF00IJEP03001JEUYF00=JEPH000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006
FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP02FUH9000nOol003=oo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP<000IJEP03001JEUYF00IJEP03001JEP0000D0009oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH01@00FUH00000FUH00P000goo
2@00Agoo000eOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40008Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000030004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0`00Dgoo000gOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04000<Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH6
0004FUH01000FUIJEUYF0`00Dgoo000lOolI000AOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP02FUH300000eYF001JEP02FUH3001COol006Qoo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP@0009JEP<005=oo`00JWoo0P001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP8000MJEP03001JEUYF00AJEP80009JEP@005Aoo`00K7oo0`0015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF000005YF0007FUH0
0`00FUIJEP0400000eYF001JEP03FUH2001DOol006moo`<00003FUH005YF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD000=JEP03001JEUYF00=JEPD000EJ
EP03001JEUYF00=JEP03001oogoo059oo`00LWoo1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH0200000=JEP0000001`000eYF00<005YFFUH015YF00@005YFFUIJ
EP8005Eoo`00NGoo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF4@0015YF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000P00EWoo0024OolJ0003FUH00`00FUIJEP05FUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH4001HOol009Eoo`<00003FUH005YF00IJEP03001JEUYF00IJEP<0
00IJEP03001JEUYF00EJEP03001JEP0000D005Yoo`00V7oo1@0015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00Ggoo002MOol90004FUH00`00FUIJEP02FUH9001UOol00:Ioo`T0
06ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]47\[InvisibleSpace]"     "\
\[InvisibleSpace]12.859254392790367`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 47, "     ", 12.859254392790367, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59801 .73071 m .59021 .67488 L .55935 .67744 L p .707 .577 .707 r
F P
0 g
s
.59021 .67488 m .59801 .73071 L .62956 .7259 L p .707 .577 .707 r
F P
0 g
s
.62956 .7259 m .62176 .67007 L .59021 .67488 L p .707 .577 .707 r
F P
0 g
s
.62176 .67007 m .62956 .7259 L .65872 .71933 L p .707 .577 .707 r
F P
0 g
s
.65872 .71933 m .65092 .6635 L .62176 .67007 L p .707 .577 .707 r
F P
0 g
s
.56715 .73327 m .55935 .67744 L .5322 .67751 L p .707 .577 .707 r
F P
0 g
s
.55935 .67744 m .56715 .73327 L .59801 .73071 L p .707 .577 .707 r
F P
0 g
s
.65092 .6635 m .65872 .71933 L .68263 .71162 L p .707 .577 .707 r
F P
0 g
s
.68263 .71162 m .67483 .6558 L .65092 .6635 L p .707 .577 .707 r
F P
0 g
s
.5322 .67751 m .54 .73334 L .56715 .73327 L p .707 .577 .707 r
F P
0 g
s
.54 .73334 m .5322 .67751 L .51143 .67509 L p .707 .577 .707 r
F P
0 g
s
.59992 .83211 m .59564 .79487 L .56468 .79663 L p .707 .577 .707 r
F P
0 g
s
.59564 .79487 m .59992 .83211 L .63157 .82803 L p .707 .577 .707 r
F P
0 g
s
.63157 .82803 m .62729 .79078 L .59564 .79487 L p .707 .577 .707 r
F P
0 g
s
.67483 .6558 m .68263 .71162 L .69895 .70355 L p .707 .577 .707 r
F P
0 g
s
.69895 .70355 m .69115 .64772 L .67483 .6558 L p .707 .577 .707 r
F P
0 g
s
.62729 .79078 m .63157 .82803 L .6608 .82202 L p .707 .577 .707 r
F P
0 g
s
.6608 .82202 m .65652 .78478 L .62729 .79078 L p .707 .577 .707 r
F P
0 g
s
.51143 .67509 m .51923 .73091 L .54 .73334 L p .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56468 .79663 L .56307 .79659 L p .707 .577 .707 r
F P
0 g
s
.56328 .80889 m .56007 .80838 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56307 .79659 L .5636 .82742 L .707 .577 .707 r
F
.56468 .79663 m .56896 .83388 L .59992 .83211 L p F P
0 g
s
.56007 .80838 m .55832 .82663 L .5636 .82746 L p .707 .577 .707 r
F P
0 g
s
.56371 .83374 m .56896 .83388 L p .5636 .82742 L .707 .577 .707 r
F P
0 g
s
.5636 .82746 m .58935 .8315 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56331 .81095 m .56007 .80838 L .5636 .82746 L .707 .577 .707 r
F
.55832 .82663 m .56007 .80838 L .53275 .80103 L p F P
0 g
s
.53275 .80103 m .531 .81928 L .55832 .82663 L p .707 .577 .707 r
F P
0 g
s
.53744 .79591 m .54172 .83316 L .56371 .83374 L p .707 .577 .707 r
F P
0 g
s
.5636 .82742 m .53744 .79591 L .56371 .83374 L .707 .577 .707 r
F
.56307 .79659 m .53744 .79591 L p .5636 .82742 L F P
0 g
s
.58935 .8315 m .5911 .81325 L .56328 .80889 L p .707 .577 .707 r
F P
0 g
s
.58935 .8315 m .56328 .80889 L .56331 .81095 L .707 .577 .707 r
F
.5911 .81325 m .58935 .8315 L .62106 .83339 L p F P
0 g
s
.62106 .83339 m .62281 .81514 L .5911 .81325 L p .707 .577 .707 r
F P
0 g
s
.62281 .81514 m .62106 .83339 L .65034 .83213 L p .707 .577 .707 r
F P
0 g
s
.65034 .83213 m .65209 .81388 L .62281 .81514 L p .707 .577 .707 r
F P
0 g
s
.65652 .78478 m .6608 .82202 L .68475 .81469 L p .707 .577 .707 r
F P
0 g
s
.68475 .81469 m .68047 .77744 L .65652 .78478 L p .707 .577 .707 r
F P
0 g
s
.51923 .73091 m .51143 .67509 L .49906 .6704 L p .707 .577 .707 r
F P
0 g
s
.65209 .81388 m .65034 .83213 L .67433 .82785 L p .707 .577 .707 r
F P
0 g
s
.67433 .82785 m .67608 .8096 L .65209 .81388 L p .707 .577 .707 r
F P
0 g
s
.531 .81928 m .53275 .80103 L .51182 .7919 L p .707 .577 .707 r
F P
0 g
s
.54172 .83316 m .53744 .79591 L .51657 .79276 L p .707 .577 .707 r
F P
0 g
s
.69115 .64772 m .69895 .70355 L .70608 .69589 L p .707 .577 .707 r
F P
0 g
s
.70608 .69589 m .69828 .64007 L .69115 .64772 L p .707 .577 .707 r
F P
0 g
s
.49906 .6704 m .50686 .72622 L .51923 .73091 L p .707 .577 .707 r
F P
0 g
s
.51182 .7919 m .51007 .81015 L .531 .81928 L p .707 .577 .707 r
F P
0 g
s
.51657 .79276 m .52085 .83001 L .54172 .83316 L p .707 .577 .707 r
F P
0 g
s
.68047 .77744 m .68475 .81469 L .70109 .80674 L p .707 .577 .707 r
F P
0 g
s
.70109 .80674 m .69681 .76949 L .68047 .77744 L p .707 .577 .707 r
F P
0 g
s
.67608 .8096 m .67433 .82785 L .69068 .82095 L p .707 .577 .707 r
F P
0 g
s
.69068 .82095 m .69242 .8027 L .67608 .8096 L p .707 .577 .707 r
F P
0 g
s
.50686 .72622 m .49906 .6704 L .49631 .66391 L p .707 .577 .707 r
F P
0 g
s
.51007 .81015 m .51182 .7919 L .49933 .7819 L p .707 .577 .707 r
F P
0 g
s
.52085 .83001 m .51657 .79276 L .50413 .7875 L p .707 .577 .707 r
F P
0 g
s
.49933 .7819 m .49758 .80015 L .51007 .81015 L p .707 .577 .707 r
F P
0 g
s
.50413 .7875 m .50841 .82475 L .52085 .83001 L p .707 .577 .707 r
F P
0 g
s
.69828 .64007 m .70608 .69589 L .70333 .6894 L p .707 .577 .707 r
F P
0 g
s
.70333 .6894 m .69553 .63358 L .69828 .64007 L p .707 .577 .707 r
F P
0 g
s
.49631 .66391 m .50411 .71973 L .50686 .72622 L p .707 .577 .707 r
F P
0 g
s
.69681 .76949 m .70109 .80674 L .70821 .79895 L p .707 .577 .707 r
F P
0 g
s
.70821 .79895 m .70393 .76171 L .69681 .76949 L p .707 .577 .707 r
F P
0 g
s
.69242 .8027 m .69068 .82095 L .69778 .81211 L p .707 .577 .707 r
F P
0 g
s
.69778 .81211 m .69953 .79386 L .69242 .8027 L p .707 .577 .707 r
F P
0 g
s
.4904 .8221 m .49342 .32054 L .44941 .31759 L p .707 .577 .707 r
F P
0 g
s
.50841 .82475 m .50413 .7875 L .50133 .78065 L p .707 .577 .707 r
F P
0 g
s
.49758 .80015 m .49933 .7819 L .4965 .77199 L p .707 .577 .707 r
F P
0 g
s
.50411 .71973 m .49631 .66391 L .50344 .65625 L p .707 .577 .707 r
F P
0 g
s
.4965 .77199 m .49475 .79024 L .49758 .80015 L p .707 .577 .707 r
F P
0 g
s
.50133 .78065 m .50561 .8179 L .50841 .82475 L p .707 .577 .707 r
F P
0 g
s
.50344 .65625 m .51124 .71208 L .50411 .71973 L p .707 .577 .707 r
F P
0 g
s
.49475 .79024 m .4965 .77199 L .5036 .76316 L p .707 .577 .707 r
F P
0 g
s
.51124 .71208 m .50344 .65625 L .51976 .64818 L p .707 .577 .707 r
F P
0 g
s
.50561 .8179 m .50133 .78065 L .50845 .77286 L p .707 .577 .707 r
F P
0 g
s
.5036 .76316 m .50186 .78141 L .49475 .79024 L p .707 .577 .707 r
F P
0 g
s
.50845 .77286 m .51273 .81011 L .50561 .8179 L p .707 .577 .707 r
F P
0 g
s
.51976 .64818 m .52756 .704 L .51124 .71208 L p .707 .577 .707 r
F P
0 g
s
.52756 .704 m .51976 .64818 L .54367 .64047 L p .707 .577 .707 r
F P
0 g
s
.50186 .78141 m .5036 .76316 L .51995 .75626 L p .707 .577 .707 r
F P
0 g
s
.51273 .81011 m .50845 .77286 L .52478 .76492 L p .707 .577 .707 r
F P
0 g
s
.51995 .75626 m .5182 .77451 L .50186 .78141 L p .707 .577 .707 r
F P
0 g
s
.52478 .76492 m .52906 .80216 L .51273 .81011 L p .707 .577 .707 r
F P
0 g
s
.52906 .80216 m .52478 .76492 L .54874 .75758 L p .707 .577 .707 r
F P
0 g
s
.5182 .77451 m .51995 .75626 L .54394 .75197 L p .707 .577 .707 r
F P
0 g
s
.54394 .75197 m .54219 .77022 L .5182 .77451 L p .707 .577 .707 r
F P
0 g
s
.54874 .75758 m .55302 .79483 L .52906 .80216 L p .707 .577 .707 r
F P
0 g
s
.49342 .32054 m .4904 .8221 L .53534 .82124 L p .707 .577 .707 r
F P
0 g
s
.54367 .64047 m .55147 .6963 L .52756 .704 L p .707 .577 .707 r
F P
0 g
s
.53534 .82124 m .53836 .31969 L .49342 .32054 L p .707 .577 .707 r
F P
0 g
s
.55147 .6963 m .54367 .64047 L .57283 .6339 L p .707 .577 .707 r
F P
0 g
s
.57283 .6339 m .58063 .68973 L .55147 .6963 L p .707 .577 .707 r
F P
0 g
s
.55302 .79483 m .54874 .75758 L .57797 .75158 L p .707 .577 .707 r
F P
0 g
s
.54219 .77022 m .54394 .75197 L .57322 .75071 L p .707 .577 .707 r
F P
0 g
s
.57797 .75158 m .58225 .78882 L .55302 .79483 L p .707 .577 .707 r
F P
0 g
s
.57322 .75071 m .57147 .76897 L .54219 .77022 L p .707 .577 .707 r
F P
0 g
s
.58225 .78882 m .57797 .75158 L .60961 .74749 L p .707 .577 .707 r
F P
0 g
s
.57147 .76897 m .57322 .75071 L .60493 .75261 L p .707 .577 .707 r
F P
0 g
s
.60961 .74749 m .61389 .78474 L .58225 .78882 L p .707 .577 .707 r
F P
0 g
s
.60493 .75261 m .60318 .77086 L .57147 .76897 L p .707 .577 .707 r
F P
0 g
s
.53836 .31969 m .53534 .82124 L .57682 .81666 L p .707 .577 .707 r
F P
0 g
s
.58063 .68973 m .57283 .6339 L .60438 .6291 L p .707 .577 .707 r
F P
0 g
s
.57682 .81666 m .57984 .31511 L .53836 .31969 L p .707 .577 .707 r
F P
0 g
s
.44639 .81915 m .44941 .31759 L .41065 .31112 L p .707 .577 .707 r
F P
0 g
s
.44941 .31759 m .44639 .81915 L .4904 .8221 L p .707 .577 .707 r
F P
0 g
s
.69553 .63358 m .70333 .6894 L .69096 .68471 L p .707 .577 .707 r
F P
0 g
s
.69096 .68471 m .68316 .62889 L .69553 .63358 L p .707 .577 .707 r
F P
0 g
s
.70393 .76171 m .70821 .79895 L .70541 .7921 L p .707 .577 .707 r
F P
0 g
s
.70541 .7921 m .70113 .75485 L .70393 .76171 L p .707 .577 .707 r
F P
0 g
s
.60438 .6291 m .61218 .68492 L .58063 .68973 L p .707 .577 .707 r
F P
0 g
s
.66328 .76483 m .66153 .78308 L .63886 .77698 L p .707 .577 .707 r
F P
0 g
s
.63885 .77399 m .66328 .76483 L .63886 .77698 L .707 .577 .707 r
F
.63889 .78331 m .61389 .78474 L p .63875 .74839 L F P
0 g
s
.63421 .77572 m .63596 .75747 L .66328 .76483 L p .707 .577 .707 r
F P
0 g
s
.64057 .74572 m .64485 .78297 L .63889 .78331 L p .707 .577 .707 r
F P
0 g
s
.63875 .74839 m .64057 .74572 L .63889 .78331 L .707 .577 .707 r
F
.63886 .77698 m .63421 .77572 L p .63885 .77399 L F P
0 g
s
.61389 .78474 m .60961 .74749 L .64057 .74572 L p .707 .577 .707 r
F P
0 g
s
.63596 .75747 m .63421 .77572 L .60318 .77086 L p .707 .577 .707 r
F P
0 g
s
.60318 .77086 m .60493 .75261 L .63596 .75747 L p .707 .577 .707 r
F P
0 g
s
.57984 .31511 m .57682 .81666 L .61078 .80881 L p .707 .577 .707 r
F P
0 g
s
.61218 .68492 m .60438 .6291 L .63524 .62653 L p .707 .577 .707 r
F P
0 g
s
.61078 .80881 m .6138 .30726 L .57984 .31511 L p .707 .577 .707 r
F P
0 g
s
.69953 .79386 m .69778 .81211 L .69495 .80221 L p .707 .577 .707 r
F P
0 g
s
.69495 .80221 m .6967 .78396 L .69953 .79386 L p .707 .577 .707 r
F P
0 g
s
.40763 .81268 m .41065 .31112 L .38092 .30177 L p .707 .577 .707 r
F P
0 g
s
.41065 .31112 m .40763 .81268 L .44639 .81915 L p .707 .577 .707 r
F P
0 g
s
.255 .72242 m .2472 .66659 L .21634 .66916 L p .707 .577 .707 r
F P
0 g
s
.2472 .66659 m .255 .72242 L .28655 .71762 L p .707 .577 .707 r
F P
0 g
s
.28655 .71762 m .27875 .66179 L .2472 .66659 L p .707 .577 .707 r
F P
0 g
s
.27875 .66179 m .28655 .71762 L .31571 .71104 L p .707 .577 .707 r
F P
0 g
s
.31571 .71104 m .30791 .65522 L .27875 .66179 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22414 .72498 m .22088 .70163 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.21634 .66916 m .22414 .72498 L .255 .72242 L p .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .25263 .7068 L .22176 .70856 L p .707 .577 .707 r
F P
0 g
s
.22176 .70856 m .22167 .70857 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .22176 .70856 L .22178 .70867 L .707 .577 .707 r
F
.22595 .74581 m .22167 .70857 L .19465 .70785 L p F P
0 g
s
.19465 .70785 m .19443 .70784 L p .19469 .70816 L .707 .577 .707 r
F P
0 g
s
.22595 .74581 m .19465 .70785 L .19469 .70816 L .707 .577 .707 r
F
.19443 .70784 m .19871 .74509 L .22595 .74581 L p F P
0 g
s
.19871 .74509 m .19443 .70784 L .17381 .70473 L p .707 .577 .707 r
F P
0 g
s
.17381 .70473 m .17356 .7047 L p .17388 .70521 L .707 .577 .707 r
F P
0 g
s
.19871 .74509 m .17381 .70473 L .17388 .70521 L .707 .577 .707 r
F
.17356 .7047 m .17784 .74194 L .19871 .74509 L p F P
0 g
s
.17784 .74194 m .17356 .7047 L .1613 .69951 L p .707 .577 .707 r
F P
0 g
s
.1613 .69951 m .16112 .69944 L p .16138 .70011 L .707 .577 .707 r
F P
0 g
s
.17784 .74194 m .1613 .69951 L .16138 .70011 L .707 .577 .707 r
F
.16112 .69944 m .1654 .73668 L .17784 .74194 L p F P
0 g
s
.1654 .73668 m .16112 .69944 L .15836 .69269 L p .707 .577 .707 r
F P
0 g
s
.15836 .69269 m .15832 .69258 L p .15844 .69333 L .707 .577 .707 r
F P
0 g
s
.1654 .73668 m .15836 .69269 L .15844 .69333 L .707 .577 .707 r
F
.16385 .71794 m .16044 .69354 L p .1533 .65562 L F P
0 g
s
.16044 .69354 m .15605 .66211 L .15588 .66172 L p .707 .577 .707 r
F P
0 g
s
.15588 .66172 m .1533 .65562 L p .16044 .69354 L .707 .577 .707 r
F P
0 g
s
.17622 .72263 m .17285 .69851 L p .15605 .66211 L .707 .577 .707 r
F P
0 g
s
.16793 .66662 m .15605 .66211 L p .17285 .69851 L .707 .577 .707 r
F P
0 g
s
.15605 .66211 m .16385 .71794 L .17622 .72263 L p .707 .577 .707 r
F P
0 g
s
.15832 .69258 m .1626 .72983 L .1654 .73668 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .16385 .71794 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1533 .65562 m .15766 .68687 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.15766 .68687 m .1611 .71145 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1626 .72983 m .15832 .69258 L .15842 .69247 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .15766 .68687 L p .16043 .64797 L .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .1611 .71145 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16043 .64797 m .16479 .67915 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16479 .67915 m .16823 .70379 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.17285 .69851 m .16842 .6668 L .16793 .66662 L p .707 .577 .707 r
F P
0 g
s
.197 .72506 m .19367 .7013 L p .16842 .6668 L .707 .577 .707 r
F P
0 g
s
.18891 .6692 m .16842 .6668 L p .19367 .7013 L .707 .577 .707 r
F P
0 g
s
.16842 .6668 m .17622 .72263 L .197 .72506 L p .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .16043 .64797 L .17675 .63989 L p .707 .577 .707 r
F P
0 g
s
.16972 .72204 m .16544 .6848 L .16569 .68468 L p .707 .577 .707 r
F P
0 g
s
.18455 .69572 m .16823 .70379 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.17675 .63989 m .18112 .67114 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.18112 .67114 m .18455 .69572 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.19367 .7013 m .18919 .66923 L .18891 .6692 L p .707 .577 .707 r
F P
0 g
s
.22167 .70857 m .22595 .74581 L .22654 .74578 L p .707 .577 .707 r
F P
0 g
s
.22387 .72499 m .22414 .72498 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.22654 .74578 m .25691 .74405 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.22178 .70867 m .22167 .70857 L .22654 .74578 L .707 .577 .707 r
F
.18919 .66923 m .197 .72506 L .22387 .72499 L p F P
0 g
s
.2238 .72444 m .18919 .66923 L .22387 .72499 L .707 .577 .707 r
F
.21634 .66916 m .18919 .66923 L p .2238 .72444 L F P
0 g
s
.18455 .69572 m .17675 .63989 L .20066 .63219 L p .707 .577 .707 r
F P
0 g
s
.18605 .7141 m .18177 .67685 L .18214 .67674 L p .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .18455 .69572 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20066 .63219 m .20505 .66362 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20505 .66362 m .20846 .68802 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .20066 .63219 L .22982 .62562 L p .707 .577 .707 r
F P
0 g
s
.21001 .70676 m .20573 .66951 L .20615 .66943 L p .707 .577 .707 r
F P
0 g
s
.22088 .70163 m .21634 .66916 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .20846 .68802 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.22982 .62562 m .23425 .65733 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23425 .65733 m .23762 .68144 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .22982 .62562 L .26137 .62081 L p .707 .577 .707 r
F P
0 g
s
.23924 .70076 m .23496 .66351 L .23534 .66346 L p .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .23762 .68144 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26137 .62081 m .26585 .65288 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26585 .65288 m .26917 .67664 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .26137 .62081 L .29223 .61825 L p .707 .577 .707 r
F P
0 g
s
.27088 .69667 m .2666 .65942 L .26685 .65941 L p .707 .577 .707 r
F P
0 g
s
.29223 .61825 m .29677 .65072 L p .26917 .67664 L .707 .577 .707 r
F P
0 g
s
.30791 .65522 m .31571 .71104 L .33962 .70334 L p .707 .577 .707 r
F P
0 g
s
.33962 .70334 m .33182 .64751 L .30791 .65522 L p .707 .577 .707 r
F P
0 g
s
.29765 .65766 m .32481 .65838 L p .30227 .69423 L .707 .577 .707 r
F P
0 g
s
.29677 .65072 m .30003 .67407 L .29973 .6741 L p .707 .577 .707 r
F P
0 g
s
.29973 .6741 m .26917 .67664 L p .29677 .65072 L .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29757 .65766 L .29765 .65766 L p .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29765 .65766 L .30227 .69423 L .707 .577 .707 r
F
.26685 .65941 m .29757 .65766 L p .27227 .69465 L F P
0 g
s
.27088 .69667 m .26685 .65941 L .27227 .69465 L .707 .577 .707 r
F
.23534 .66346 m .2666 .65942 L p .24138 .69753 L F P
0 g
s
.23924 .70076 m .23534 .66346 L .24138 .69753 L .707 .577 .707 r
F
.20615 .66943 m .23496 .66351 L p .21241 .7026 L F P
0 g
s
.21001 .70676 m .20615 .66943 L .21241 .7026 L .707 .577 .707 r
F
.18214 .67674 m .20573 .66951 L p .18812 .70941 L F P
0 g
s
.18605 .7141 m .18214 .67674 L .18812 .70941 L .707 .577 .707 r
F
.16569 .68468 m .18177 .67685 L p .17098 .7173 L F P
0 g
s
.16972 .72204 m .16569 .68468 L .17098 .7173 L .707 .577 .707 r
F
.15842 .69247 m .16544 .6848 L p .16287 .72552 L F P
0 g
s
.1626 .72983 m .15842 .69247 L .16287 .72552 L .707 .577 .707 r
F
.15766 .68687 m .1533 .65562 L .15384 .65504 L p F P
0 g
s
.15384 .65504 m .16043 .64797 L p .15766 .68687 L .707 .577 .707 r
F P
0 g
s
.25263 .7068 m .25691 .74405 L .28856 .73996 L p .707 .577 .707 r
F P
0 g
s
.28856 .73996 m .28428 .70271 L .25263 .7068 L p .707 .577 .707 r
F P
0 g
s
.68316 .62889 m .69096 .68471 L .67019 .68229 L p .707 .577 .707 r
F P
0 g
s
.67019 .68229 m .66238 .62646 L .68316 .62889 L p .707 .577 .707 r
F P
0 g
s
.28428 .70271 m .28856 .73996 L .31779 .73396 L p .707 .577 .707 r
F P
0 g
s
.31779 .73396 m .31351 .69671 L .28428 .70271 L p .707 .577 .707 r
F P
0 g
s
.6967 .78396 m .69495 .80221 L .68246 .79221 L p .707 .577 .707 r
F P
0 g
s
.68246 .79221 m .68421 .77396 L .6967 .78396 L p .707 .577 .707 r
F P
0 g
s
.70113 .75485 m .70541 .7921 L .69297 .78684 L p .707 .577 .707 r
F P
0 g
s
.69297 .78684 m .68869 .74959 L .70113 .75485 L p .707 .577 .707 r
F P
0 g
s
.63524 .62653 m .64304 .68236 L .61218 .68492 L p .707 .577 .707 r
F P
0 g
s
.6138 .30726 m .61078 .80881 L .63389 .79845 L p .707 .577 .707 r
F P
0 g
s
.63389 .79845 m .63691 .2969 L .6138 .30726 L p .707 .577 .707 r
F P
0 g
s
.31351 .69671 m .31779 .73396 L .34175 .72662 L p .707 .577 .707 r
F P
0 g
s
.34175 .72662 m .33747 .68937 L .31351 .69671 L p .707 .577 .707 r
F P
0 g
s
.3779 .80332 m .38092 .30177 L .36315 .29045 L p .707 .577 .707 r
F P
0 g
s
.38092 .30177 m .3779 .80332 L .40763 .81268 L p .707 .577 .707 r
F P
0 g
s
.33182 .64751 m .33962 .70334 L .35594 .69527 L p .707 .577 .707 r
F P
0 g
s
.35594 .69527 m .34814 .63944 L .33182 .64751 L p .707 .577 .707 r
F P
0 g
s
.66238 .62646 m .67019 .68229 L .64304 .68236 L p .707 .577 .707 r
F P
0 g
s
.64304 .68236 m .63524 .62653 L .66238 .62646 L p .707 .577 .707 r
F P
0 g
s
.68421 .77396 m .68246 .79221 L .66153 .78308 L p .707 .577 .707 r
F P
0 g
s
.66153 .78308 m .66328 .76483 L .68421 .77396 L p .707 .577 .707 r
F P
0 g
s
.68869 .74959 m .69297 .78684 L .6721 .78369 L p .707 .577 .707 r
F P
0 g
s
.6721 .78369 m .66782 .74645 L .68869 .74959 L p .707 .577 .707 r
F P
0 g
s
.33747 .68937 m .34175 .72662 L .35808 .71867 L p .707 .577 .707 r
F P
0 g
s
.35808 .71867 m .3538 .68142 L .33747 .68937 L p .707 .577 .707 r
F P
0 g
s
.24634 .83948 m .24809 .82123 L .21706 .81637 L p .707 .577 .707 r
F P
0 g
s
.24809 .82123 m .24634 .83948 L .27805 .84138 L p .707 .577 .707 r
F P
0 g
s
.27805 .84138 m .2798 .82313 L .24809 .82123 L p .707 .577 .707 r
F P
0 g
s
.2798 .82313 m .27805 .84138 L .30733 .84012 L p .707 .577 .707 r
F P
0 g
s
.30733 .84012 m .30908 .82187 L .2798 .82313 L p .707 .577 .707 r
F P
0 g
s
.21706 .81637 m .21531 .83462 L .24634 .83948 L p .707 .577 .707 r
F P
0 g
s
.21531 .83462 m .21706 .81637 L .18974 .80902 L p .707 .577 .707 r
F P
0 g
s
.64485 .78297 m .64057 .74572 L .66782 .74645 L p .707 .577 .707 r
F P
0 g
s
.63691 .2969 m .63389 .79845 L .64389 .7866 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .64691 .28505 L .63691 .2969 L p .707 .577 .707 r
F P
0 g
s
.18974 .80902 m .18799 .82727 L .21531 .83462 L p .707 .577 .707 r
F P
0 g
s
.30908 .82187 m .30733 .84012 L .33132 .83583 L p .707 .577 .707 r
F P
0 g
s
.33132 .83583 m .33307 .81758 L .30908 .82187 L p .707 .577 .707 r
F P
0 g
s
.34814 .63944 m .35594 .69527 L .36307 .68761 L p .707 .577 .707 r
F P
0 g
s
.36307 .68761 m .35527 .63178 L .34814 .63944 L p .707 .577 .707 r
F P
0 g
s
.18799 .82727 m .18974 .80902 L .16881 .79989 L p .707 .577 .707 r
F P
0 g
s
.66782 .74645 m .6721 .78369 L .64485 .78297 L p .707 .577 .707 r
F P
0 g
s
.3538 .68142 m .35808 .71867 L .3652 .71089 L p .707 .577 .707 r
F P
0 g
s
.3652 .71089 m .36092 .67364 L .3538 .68142 L p .707 .577 .707 r
F P
0 g
s
.36092 .67364 m .3652 .71089 L .3624 .70403 L p .707 .577 .707 r
F P
0 g
s
.3624 .70403 m .35812 .66678 L .36092 .67364 L p .707 .577 .707 r
F P
0 g
s
.35527 .63178 m .36307 .68761 L .36032 .68112 L p .707 .577 .707 r
F P
0 g
s
.36032 .68112 m .35252 .62529 L .35527 .63178 L p .707 .577 .707 r
F P
0 g
s
.35812 .66678 m .3624 .70403 L .34996 .69877 L p .707 .577 .707 r
F P
0 g
s
.34996 .69877 m .34568 .66153 L .35812 .66678 L p .707 .577 .707 r
F P
0 g
s
.35252 .62529 m .36032 .68112 L .34795 .67643 L p .707 .577 .707 r
F P
0 g
s
.36012 .792 m .36315 .29045 L .35906 .27826 L p .707 .577 .707 r
F P
0 g
s
.36315 .29045 m .36012 .792 L .3779 .80332 L p .707 .577 .707 r
F P
0 g
s
.16881 .79989 m .16706 .81814 L .18799 .82727 L p .707 .577 .707 r
F P
0 g
s
.33307 .81758 m .33132 .83583 L .34767 .82894 L p .707 .577 .707 r
F P
0 g
s
.34767 .82894 m .34941 .81069 L .33307 .81758 L p .707 .577 .707 r
F P
0 g
s
.16706 .81814 m .16881 .79989 L .15632 .78988 L p .707 .577 .707 r
F P
0 g
s
.15632 .78988 m .15457 .80814 L .16706 .81814 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .6398 .77442 L p .64238 .59686 L .707 .577 .707 r
F P
0 g
s
.64238 .59686 m .64559 .37583 L .64465 .60277 L .707 .577 .707 r
F
.64238 .59686 m .64465 .60277 L .64389 .7866 L F
.64282 .27286 m .6398 .77442 L .62202 .7631 L p F P
0 g
s
.63626 .57836 m .63351 .57187 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.64282 .27286 m .64691 .28505 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.6398 .77442 m .64164 .46898 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64164 .46898 m .64282 .27286 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64649 .35462 m .64389 .7866 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .65643 .63887 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63626 .57836 m .63683 .58239 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .64407 .63419 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .63683 .58239 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .63626 .57836 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .64863 .58305 L .63699 .57863 L p .707 .577 .707 r
F P
0 g
s
.63699 .57863 m .63626 .57836 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .63699 .57863 L .63692 .58032 L .707 .577 .707 r
F
.64691 .28505 m .64649 .35462 L p .64559 .37583 L F P
0 g
s
.34941 .81069 m .34767 .82894 L .35477 .8201 L p .707 .577 .707 r
F P
0 g
s
.35477 .8201 m .35652 .80185 L .34941 .81069 L p .707 .577 .707 r
F P
0 g
s
.35906 .27826 m .35603 .77982 L .36012 .792 L p .707 .577 .707 r
F P
0 g
s
.35603 .77982 m .35906 .27826 L .36906 .26641 L p .707 .577 .707 r
F P
0 g
s
.15457 .80814 m .15632 .78988 L .15349 .77998 L p .707 .577 .707 r
F P
0 g
s
.15349 .77998 m .15174 .79823 L .15457 .80814 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34795 .67643 m .34015 .6206 L .35252 .62529 L p .707 .577 .707 r
F P
0 g
s
.16544 .6848 m .16972 .72204 L .1626 .72983 L p .707 .577 .707 r
F P
0 g
s
.62202 .7631 m .62504 .26154 L .64282 .27286 L p .707 .577 .707 r
F P
0 g
s
.35652 .80185 m .35477 .8201 L .35194 .8102 L p .707 .577 .707 r
F P
0 g
s
.35194 .8102 m .35369 .79195 L .35652 .80185 L p .707 .577 .707 r
F P
0 g
s
.15174 .79823 m .15349 .77998 L .16059 .77115 L p .707 .577 .707 r
F P
0 g
s
.16059 .77115 m .15885 .7894 L .15174 .79823 L p .707 .577 .707 r
F P
0 g
s
.34568 .66153 m .34996 .69877 L .32909 .69563 L p .707 .577 .707 r
F P
0 g
s
.32909 .69563 m .32481 .65838 L .34568 .66153 L p .707 .577 .707 r
F P
0 g
s
.34015 .6206 m .34795 .67643 L .32718 .674 L p .707 .577 .707 r
F P
0 g
s
.32718 .674 m .31938 .61818 L .34015 .6206 L p .707 .577 .707 r
F P
0 g
s
.36603 .76797 m .36906 .26641 L .39217 .25605 L p .707 .577 .707 r
F P
0 g
s
.36906 .26641 m .36603 .76797 L .35603 .77982 L p .707 .577 .707 r
F P
0 g
s
.18177 .67685 m .18605 .7141 L .16972 .72204 L p .707 .577 .707 r
F P
0 g
s
.35369 .79195 m .35194 .8102 L .33945 .80019 L p .707 .577 .707 r
F P
0 g
s
.33945 .80019 m .3412 .78194 L .35369 .79195 L p .707 .577 .707 r
F P
0 g
s
.15885 .7894 m .16059 .77115 L .17694 .76425 L p .707 .577 .707 r
F P
0 g
s
.32481 .65838 m .32909 .69563 L .30185 .6949 L p .707 .577 .707 r
F P
0 g
s
.31938 .61818 m .32718 .674 L .30003 .67407 L p .707 .577 .707 r
F P
0 g
s
.30003 .67407 m .29223 .61825 L .31938 .61818 L p .707 .577 .707 r
F P
0 g
s
.62504 .26154 m .62202 .7631 L .5923 .75374 L p .707 .577 .707 r
F P
0 g
s
.5923 .75374 m .59532 .25219 L .62504 .26154 L p .707 .577 .707 r
F P
0 g
s
.17694 .76425 m .17519 .7825 L .15885 .7894 L p .707 .577 .707 r
F P
0 g
s
.20573 .66951 m .21001 .70676 L .18605 .7141 L p .707 .577 .707 r
F P
0 g
s
.73521 .63867 m .72741 .58284 L .69655 .5854 L p .707 .577 .707 r
F P
0 g
s
.72741 .58284 m .73521 .63867 L .76677 .63386 L p .707 .577 .707 r
F P
0 g
s
.76677 .63386 m .75896 .57804 L .72741 .58284 L p .707 .577 .707 r
F P
0 g
s
.39217 .25605 m .38914 .75761 L .36603 .76797 L p .707 .577 .707 r
F P
0 g
s
.38914 .75761 m .39217 .25605 L .42612 .2482 L p .707 .577 .707 r
F P
0 g
s
.75896 .57804 m .76677 .63386 L .79593 .62729 L p .707 .577 .707 r
F P
0 g
s
.79593 .62729 m .78812 .57146 L .75896 .57804 L p .707 .577 .707 r
F P
0 g
s
.3412 .78194 m .33945 .80019 L .31852 .79107 L p .707 .577 .707 r
F P
0 g
s
.31852 .79107 m .32027 .77282 L .3412 .78194 L p .707 .577 .707 r
F P
0 g
s
.70435 .64123 m .69655 .5854 L .66941 .58547 L p .707 .577 .707 r
F P
0 g
s
.69655 .5854 m .70435 .64123 L .73521 .63867 L p .707 .577 .707 r
F P
0 g
s
.29757 .65766 m .30185 .6949 L .27088 .69667 L p .707 .577 .707 r
F P
0 g
s
.17519 .7825 m .17694 .76425 L .20093 .75996 L p .707 .577 .707 r
F P
0 g
s
.23496 .66351 m .23924 .70076 L .21001 .70676 L p .707 .577 .707 r
F P
0 g
s
.78812 .57146 m .79593 .62729 L .81983 .61959 L p .707 .577 .707 r
F P
0 g
s
.81983 .61959 m .81203 .56376 L .78812 .57146 L p .707 .577 .707 r
F P
0 g
s
.20093 .75996 m .19918 .77821 L .17519 .7825 L p .707 .577 .707 r
F P
0 g
s
.2666 .65942 m .27088 .69667 L .23924 .70076 L p .707 .577 .707 r
F P
0 g
s
.59532 .25219 m .5923 .75374 L .55353 .74727 L p .707 .577 .707 r
F P
0 g
s
.55353 .74727 m .55655 .24572 L .59532 .25219 L p .707 .577 .707 r
F P
0 g
s
.66941 .58547 m .67721 .6413 L .70435 .64123 L p .707 .577 .707 r
F P
0 g
s
.67721 .6413 m .66941 .58547 L .64863 .58305 L p .707 .577 .707 r
F P
0 g
s
.32027 .77282 m .31852 .79107 L .2912 .78371 L p .707 .577 .707 r
F P
0 g
s
.2912 .78371 m .29295 .76546 L .32027 .77282 L p .707 .577 .707 r
F P
0 g
s
.4231 .74975 m .42612 .2482 L .4676 .24362 L p .707 .577 .707 r
F P
0 g
s
.42612 .2482 m .4231 .74975 L .38914 .75761 L p .707 .577 .707 r
F P
0 g
s
.19918 .77821 m .20093 .75996 L .23021 .7587 L p .707 .577 .707 r
F P
0 g
s
.73713 .74007 m .73285 .70283 L .70189 .70459 L p .707 .577 .707 r
F P
0 g
s
.73285 .70283 m .73713 .74007 L .76877 .73599 L p .707 .577 .707 r
F P
0 g
s
.76877 .73599 m .76449 .69874 L .73285 .70283 L p .707 .577 .707 r
F P
0 g
s
.81203 .56376 m .81983 .61959 L .83615 .61151 L p .707 .577 .707 r
F P
0 g
s
.83615 .61151 m .82835 .55568 L .81203 .56376 L p .707 .577 .707 r
F P
0 g
s
.76449 .69874 m .76877 .73599 L .798 .72998 L p .707 .577 .707 r
F P
0 g
s
.798 .72998 m .79372 .69274 L .76449 .69874 L p .707 .577 .707 r
F P
0 g
s
.23021 .7587 m .22846 .77695 L .19918 .77821 L p .707 .577 .707 r
F P
0 g
s
.64863 .58305 m .65643 .63887 L .67721 .6413 L p .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70189 .70459 L .70027 .70455 L p .707 .577 .707 r
F P
0 g
s
.70048 .71685 m .69727 .71635 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70027 .70455 L .7008 .73538 L .707 .577 .707 r
F
.70189 .70459 m .70617 .74184 L .73713 .74007 L p F P
0 g
s
.69727 .71635 m .69552 .7346 L .7008 .73542 L p .707 .577 .707 r
F P
0 g
s
.70091 .7417 m .70617 .74184 L p .7008 .73538 L .707 .577 .707 r
F P
0 g
s
.7008 .73542 m .72655 .73946 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70052 .71891 m .69727 .71635 L .7008 .73542 L .707 .577 .707 r
F
.69552 .7346 m .69727 .71635 L .66995 .70899 L p F P
0 g
s
.66995 .70899 m .66821 .72724 L .69552 .7346 L p .707 .577 .707 r
F P
0 g
s
.67464 .70387 m .67892 .74112 L .70091 .7417 L p .707 .577 .707 r
F P
0 g
s
.7008 .73538 m .67464 .70387 L .70091 .7417 L .707 .577 .707 r
F
.70027 .70455 m .67464 .70387 L p .7008 .73538 L F P
0 g
s
.72655 .73946 m .7283 .72121 L .70048 .71685 L p .707 .577 .707 r
F P
0 g
s
.72655 .73946 m .70048 .71685 L .70052 .71891 L .707 .577 .707 r
F
.7283 .72121 m .72655 .73946 L .75826 .74135 L p F P
0 g
s
.75826 .74135 m .76001 .7231 L .7283 .72121 L p .707 .577 .707 r
F P
0 g
s
.55655 .24572 m .55353 .74727 L .50952 .74432 L p .707 .577 .707 r
F P
0 g
s
.50952 .74432 m .51255 .24277 L .55655 .24572 L p .707 .577 .707 r
F P
0 g
s
.29295 .76546 m .2912 .78371 L .26017 .77885 L p .707 .577 .707 r
F P
0 g
s
.26017 .77885 m .26192 .7606 L .29295 .76546 L p .707 .577 .707 r
F P
0 g
s
.76001 .7231 m .75826 .74135 L .78754 .7401 L p .707 .577 .707 r
F P
0 g
s
.78754 .7401 m .78929 .72185 L .76001 .7231 L p .707 .577 .707 r
F P
0 g
s
.22846 .77695 m .23021 .7587 L .26192 .7606 L p .707 .577 .707 r
F P
0 g
s
.79372 .69274 m .798 .72998 L .82196 .72265 L p .707 .577 .707 r
F P
0 g
s
.82196 .72265 m .81768 .6854 L .79372 .69274 L p .707 .577 .707 r
F P
0 g
s
.46458 .74518 m .4676 .24362 L .51255 .24277 L p .707 .577 .707 r
F P
0 g
s
.4676 .24362 m .46458 .74518 L .4231 .74975 L p .707 .577 .707 r
F P
0 g
s
.26192 .7606 m .26017 .77885 L .22846 .77695 L p .707 .577 .707 r
F P
0 g
s
.51255 .24277 m .50952 .74432 L .46458 .74518 L p .707 .577 .707 r
F P
0 g
s
.78929 .72185 m .78754 .7401 L .81153 .73581 L p .707 .577 .707 r
F P
0 g
s
.81153 .73581 m .81328 .71756 L .78929 .72185 L p .707 .577 .707 r
F P
0 g
s
.66821 .72724 m .66995 .70899 L .64903 .69986 L p .707 .577 .707 r
F P
0 g
s
.67892 .74112 m .67464 .70387 L .65377 .70072 L p .707 .577 .707 r
F P
0 g
s
.82835 .55568 m .83615 .61151 L .84329 .60385 L p .707 .577 .707 r
F P
0 g
s
.84329 .60385 m .83548 .54803 L .82835 .55568 L p .707 .577 .707 r
F P
0 g
s
.64903 .69986 m .64728 .71811 L .66821 .72724 L p .707 .577 .707 r
F P
0 g
s
.65377 .70072 m .65805 .73797 L .67892 .74112 L p .707 .577 .707 r
F P
0 g
s
.81768 .6854 m .82196 .72265 L .8383 .7147 L p .707 .577 .707 r
F P
0 g
s
.8383 .7147 m .83402 .67745 L .81768 .6854 L p .707 .577 .707 r
F P
0 g
s
.81328 .71756 m .81153 .73581 L .82788 .72891 L p .707 .577 .707 r
F P
0 g
s
.82788 .72891 m .82963 .71066 L .81328 .71756 L p .707 .577 .707 r
F P
0 g
s
.64728 .71811 m .64903 .69986 L .63653 .68986 L p .707 .577 .707 r
F P
0 g
s
.65805 .73797 m .65377 .70072 L .64133 .69547 L p .707 .577 .707 r
F P
0 g
s
.63653 .68986 m .63479 .70811 L .64728 .71811 L p .707 .577 .707 r
F P
0 g
s
.64133 .69547 m .64561 .73271 L .65805 .73797 L p .707 .577 .707 r
F P
0 g
s
.83548 .54803 m .84329 .60385 L .84053 .59736 L p .707 .577 .707 r
F P
0 g
s
.84053 .59736 m .83273 .54154 L .83548 .54803 L p .707 .577 .707 r
F P
0 g
s
.63351 .57187 m .64131 .6277 L .64407 .63419 L p .707 .577 .707 r
F P
0 g
s
.83402 .67745 m .8383 .7147 L .84541 .70692 L p .707 .577 .707 r
F P
0 g
s
.84541 .70692 m .84113 .66967 L .83402 .67745 L p .707 .577 .707 r
F P
0 g
s
.82963 .71066 m .82788 .72891 L .83499 .72008 L p .707 .577 .707 r
F P
0 g
s
.83499 .72008 m .83673 .70183 L .82963 .71066 L p .707 .577 .707 r
F P
0 g
s
.64561 .73271 m .64133 .69547 L .63853 .68861 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63479 .70811 m .63653 .68986 L .6337 .67995 L p .707 .577 .707 r
F P
0 g
s
.64131 .6277 m .63351 .57187 L .64064 .56421 L p .707 .577 .707 r
F P
0 g
s
.6337 .67995 m .63195 .69821 L .63479 .70811 L p .707 .577 .707 r
F P
0 g
s
.63853 .68861 m .64281 .72586 L .64561 .73271 L p .707 .577 .707 r
F P
0 g
s
.83273 .54154 m .84053 .59736 L .82817 .59268 L p .707 .577 .707 r
F P
0 g
s
.82817 .59268 m .82036 .53685 L .83273 .54154 L p .707 .577 .707 r
F P
0 g
s
.84113 .66967 m .84541 .70692 L .84261 .70006 L p .707 .577 .707 r
F P
0 g
s
.84261 .70006 m .83833 .66281 L .84113 .66967 L p .707 .577 .707 r
F P
0 g
s
.64064 .56421 m .64845 .62004 L .64131 .6277 L p .707 .577 .707 r
F P
0 g
s
.83673 .70183 m .83499 .72008 L .83215 .71017 L p .707 .577 .707 r
F P
0 g
s
.83215 .71017 m .8339 .69192 L .83673 .70183 L p .707 .577 .707 r
F P
0 g
s
.63195 .69821 m .6337 .67995 L .64081 .67112 L p .707 .577 .707 r
F P
0 g
s
.64845 .62004 m .64064 .56421 L .65696 .55614 L p .707 .577 .707 r
F P
0 g
s
.64281 .72586 m .63853 .68861 L .64565 .68083 L p .707 .577 .707 r
F P
0 g
s
.3922 .63038 m .3844 .57456 L .35354 .57712 L p .707 .577 .707 r
F P
0 g
s
.3844 .57456 m .3922 .63038 L .42376 .62558 L p .707 .577 .707 r
F P
0 g
s
.42376 .62558 m .41595 .56975 L .3844 .57456 L p .707 .577 .707 r
F P
0 g
s
.41595 .56975 m .42376 .62558 L .45292 .619 L p .707 .577 .707 r
F P
0 g
s
.45292 .619 m .44511 .56318 L .41595 .56975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64081 .67112 m .63906 .68937 L .63195 .69821 L p .707 .577 .707 r
F P
0 g
s
.36134 .63295 m .35808 .60959 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.35354 .57712 m .36134 .63295 L .3922 .63038 L p .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .38984 .61476 L .35897 .61652 L p .707 .577 .707 r
F P
0 g
s
.35897 .61652 m .35888 .61653 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .35897 .61652 L .35898 .61663 L .707 .577 .707 r
F
.36316 .65377 m .35888 .61653 L .33185 .61581 L p F P
0 g
s
.33185 .61581 m .33163 .6158 L p .3319 .61612 L .707 .577 .707 r
F P
0 g
s
.36316 .65377 m .33185 .61581 L .3319 .61612 L .707 .577 .707 r
F
.33163 .6158 m .33591 .65305 L .36316 .65377 L p F P
0 g
s
.33591 .65305 m .33163 .6158 L .31101 .61269 L p .707 .577 .707 r
F P
0 g
s
.31101 .61269 m .31076 .61266 L p .31109 .61318 L .707 .577 .707 r
F P
0 g
s
.33591 .65305 m .31101 .61269 L .31109 .61318 L .707 .577 .707 r
F
.31076 .61266 m .31504 .6499 L .33591 .65305 L p F P
0 g
s
.31504 .6499 m .31076 .61266 L .2985 .60747 L p .707 .577 .707 r
F P
0 g
s
.2985 .60747 m .29832 .6074 L p .29859 .60807 L .707 .577 .707 r
F P
0 g
s
.31504 .6499 m .2985 .60747 L .29859 .60807 L .707 .577 .707 r
F
.29832 .6074 m .3026 .64465 L .31504 .6499 L p F P
0 g
s
.3026 .64465 m .29832 .6074 L .29557 .60065 L p .707 .577 .707 r
F P
0 g
s
.29557 .60065 m .29552 .60054 L p .29564 .6013 L .707 .577 .707 r
F P
0 g
s
.3026 .64465 m .29557 .60065 L .29564 .6013 L .707 .577 .707 r
F
.30106 .6259 m .29765 .6015 L p .2905 .56359 L F P
0 g
s
.29765 .6015 m .29325 .57008 L .29309 .56968 L p .707 .577 .707 r
F P
0 g
s
.29309 .56968 m .2905 .56359 L p .29765 .6015 L .707 .577 .707 r
F P
0 g
s
.31342 .63059 m .31005 .60648 L p .29325 .57008 L .707 .577 .707 r
F P
0 g
s
.30514 .57458 m .29325 .57008 L p .31005 .60648 L .707 .577 .707 r
F P
0 g
s
.29325 .57008 m .30106 .6259 L .31342 .63059 L p .707 .577 .707 r
F P
0 g
s
.29552 .60054 m .2998 .63779 L .3026 .64465 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .30106 .6259 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2905 .56359 m .29487 .59483 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.29487 .59483 m .2983 .61941 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2998 .63779 m .29552 .60054 L .29562 .60043 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .29487 .59483 L p .29763 .55593 L .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .2983 .61941 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.29763 .55593 m .30199 .58711 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.30199 .58711 m .30544 .61175 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.31005 .60648 m .30562 .57476 L .30514 .57458 L p .707 .577 .707 r
F P
0 g
s
.3342 .63302 m .33088 .60926 L p .30562 .57476 L .707 .577 .707 r
F P
0 g
s
.32611 .57716 m .30562 .57476 L p .33088 .60926 L .707 .577 .707 r
F P
0 g
s
.30562 .57476 m .31342 .63059 L .3342 .63302 L p .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .29763 .55593 L .31395 .54785 L p .707 .577 .707 r
F P
0 g
s
.30692 .63001 m .30264 .59276 L .30289 .59264 L p .707 .577 .707 r
F P
0 g
s
.32176 .60368 m .30544 .61175 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31395 .54785 m .31832 .5791 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31832 .5791 m .32176 .60368 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.33088 .60926 m .3264 .57719 L .32611 .57716 L p .707 .577 .707 r
F P
0 g
s
.35888 .61653 m .36316 .65377 L .36374 .65374 L p .707 .577 .707 r
F P
0 g
s
.36107 .63295 m .36134 .63295 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.36374 .65374 m .39412 .65201 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.35898 .61663 m .35888 .61653 L .36374 .65374 L .707 .577 .707 r
F
.3264 .57719 m .3342 .63302 L .36107 .63295 L p F P
0 g
s
.361 .6324 m .3264 .57719 L .36107 .63295 L .707 .577 .707 r
F
.35354 .57712 m .3264 .57719 L p .361 .6324 L F P
0 g
s
.32176 .60368 m .31395 .54785 L .33786 .54015 L p .707 .577 .707 r
F P
0 g
s
.32326 .62206 m .31898 .58481 L .31934 .5847 L p .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .32176 .60368 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.33786 .54015 m .34225 .57158 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34225 .57158 m .34566 .59598 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .33786 .54015 L .36702 .53358 L p .707 .577 .707 r
F P
0 g
s
.34721 .61472 m .34293 .57747 L .34335 .57739 L p .707 .577 .707 r
F P
0 g
s
.35808 .60959 m .35354 .57712 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .34566 .59598 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.36702 .53358 m .37145 .56529 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37145 .56529 m .37482 .5894 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .36702 .53358 L .39857 .52877 L p .707 .577 .707 r
F P
0 g
s
.37644 .60872 m .37216 .57147 L .37254 .57142 L p .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .37482 .5894 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.39857 .52877 m .40306 .56084 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40306 .56084 m .40638 .5846 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .39857 .52877 L .42943 .52621 L p .707 .577 .707 r
F P
0 g
s
.40809 .60463 m .40381 .56738 L .40406 .56737 L p .707 .577 .707 r
F P
0 g
s
.42943 .52621 m .43397 .55868 L p .40638 .5846 L .707 .577 .707 r
F P
0 g
s
.44511 .56318 m .45292 .619 L .47682 .6113 L p .707 .577 .707 r
F P
0 g
s
.47682 .6113 m .46902 .55548 L .44511 .56318 L p .707 .577 .707 r
F P
0 g
s
.43485 .56562 m .46202 .56634 L p .43947 .60219 L .707 .577 .707 r
F P
0 g
s
.43397 .55868 m .43724 .58204 L .43693 .58206 L p .707 .577 .707 r
F P
0 g
s
.43693 .58206 m .40638 .5846 L p .43397 .55868 L .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43477 .56562 L .43485 .56562 L p .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43485 .56562 L .43947 .60219 L .707 .577 .707 r
F
.40406 .56737 m .43477 .56562 L p .40947 .60261 L F P
0 g
s
.40809 .60463 m .40406 .56737 L .40947 .60261 L .707 .577 .707 r
F
.37254 .57142 m .40381 .56738 L p .37858 .60549 L F P
0 g
s
.37644 .60872 m .37254 .57142 L .37858 .60549 L .707 .577 .707 r
F
.34335 .57739 m .37216 .57147 L p .34961 .61057 L F P
0 g
s
.34721 .61472 m .34335 .57739 L .34961 .61057 L .707 .577 .707 r
F
.31934 .5847 m .34293 .57747 L p .32532 .61737 L F P
0 g
s
.32326 .62206 m .31934 .5847 L .32532 .61737 L .707 .577 .707 r
F
.30289 .59264 m .31898 .58481 L p .30818 .62526 L F P
0 g
s
.30692 .63001 m .30289 .59264 L .30818 .62526 L .707 .577 .707 r
F
.29562 .60043 m .30264 .59276 L p .30007 .63348 L F P
0 g
s
.2998 .63779 m .29562 .60043 L .30007 .63348 L .707 .577 .707 r
F
.29487 .59483 m .2905 .56359 L .29104 .563 L p F P
0 g
s
.29104 .563 m .29763 .55593 L p .29487 .59483 L .707 .577 .707 r
F P
0 g
s
.64565 .68083 m .64993 .71807 L .64281 .72586 L p .707 .577 .707 r
F P
0 g
s
.38984 .61476 m .39412 .65201 L .42576 .64792 L p .707 .577 .707 r
F P
0 g
s
.42576 .64792 m .42148 .61067 L .38984 .61476 L p .707 .577 .707 r
F P
0 g
s
.82036 .53685 m .82817 .59268 L .80739 .59025 L p .707 .577 .707 r
F P
0 g
s
.80739 .59025 m .79959 .53442 L .82036 .53685 L p .707 .577 .707 r
F P
0 g
s
.42148 .61067 m .42576 .64792 L .45499 .64192 L p .707 .577 .707 r
F P
0 g
s
.45499 .64192 m .45071 .60467 L .42148 .61067 L p .707 .577 .707 r
F P
0 g
s
.65696 .55614 m .66477 .61196 L .64845 .62004 L p .707 .577 .707 r
F P
0 g
s
.8339 .69192 m .83215 .71017 L .81966 .70017 L p .707 .577 .707 r
F P
0 g
s
.81966 .70017 m .82141 .68192 L .8339 .69192 L p .707 .577 .707 r
F P
0 g
s
.83833 .66281 m .84261 .70006 L .83017 .6948 L p .707 .577 .707 r
F P
0 g
s
.83017 .6948 m .82589 .65755 L .83833 .66281 L p .707 .577 .707 r
F P
0 g
s
.45071 .60467 m .45499 .64192 L .47895 .63458 L p .707 .577 .707 r
F P
0 g
s
.47895 .63458 m .47467 .59733 L .45071 .60467 L p .707 .577 .707 r
F P
0 g
s
.66477 .61196 m .65696 .55614 L .68087 .54844 L p .707 .577 .707 r
F P
0 g
s
.63906 .68937 m .64081 .67112 L .65715 .66422 L p .707 .577 .707 r
F P
0 g
s
.64993 .71807 m .64565 .68083 L .66199 .67288 L p .707 .577 .707 r
F P
0 g
s
.46902 .55548 m .47682 .6113 L .49314 .60323 L p .707 .577 .707 r
F P
0 g
s
.49314 .60323 m .48534 .5474 L .46902 .55548 L p .707 .577 .707 r
F P
0 g
s
.79959 .53442 m .80739 .59025 L .78025 .59032 L p .707 .577 .707 r
F P
0 g
s
.78025 .59032 m .77244 .53449 L .79959 .53442 L p .707 .577 .707 r
F P
0 g
s
.65715 .66422 m .65541 .68247 L .63906 .68937 L p .707 .577 .707 r
F P
0 g
s
.68087 .54844 m .68868 .60426 L .66477 .61196 L p .707 .577 .707 r
F P
0 g
s
.66199 .67288 m .66627 .71012 L .64993 .71807 L p .707 .577 .707 r
F P
0 g
s
.82141 .68192 m .81966 .70017 L .79873 .69104 L p .707 .577 .707 r
F P
0 g
s
.79873 .69104 m .80048 .67279 L .82141 .68192 L p .707 .577 .707 r
F P
0 g
s
.82589 .65755 m .83017 .6948 L .80931 .69166 L p .707 .577 .707 r
F P
0 g
s
.80931 .69166 m .80503 .65441 L .82589 .65755 L p .707 .577 .707 r
F P
0 g
s
.47467 .59733 m .47895 .63458 L .49529 .62663 L p .707 .577 .707 r
F P
0 g
s
.49529 .62663 m .49101 .58939 L .47467 .59733 L p .707 .577 .707 r
F P
0 g
s
.38354 .74745 m .38529 .7292 L .35426 .72433 L p .707 .577 .707 r
F P
0 g
s
.38529 .7292 m .38354 .74745 L .41525 .74934 L p .707 .577 .707 r
F P
0 g
s
.41525 .74934 m .417 .73109 L .38529 .7292 L p .707 .577 .707 r
F P
0 g
s
.68868 .60426 m .68087 .54844 L .71003 .54186 L p .707 .577 .707 r
F P
0 g
s
.417 .73109 m .41525 .74934 L .44453 .74808 L p .707 .577 .707 r
F P
0 g
s
.44453 .74808 m .44628 .72983 L .417 .73109 L p .707 .577 .707 r
F P
0 g
s
.35426 .72433 m .35251 .74258 L .38354 .74745 L p .707 .577 .707 r
F P
0 g
s
.35251 .74258 m .35426 .72433 L .32694 .71698 L p .707 .577 .707 r
F P
0 g
s
.77244 .53449 m .78025 .59032 L .74939 .59288 L p .707 .577 .707 r
F P
0 g
s
.74939 .59288 m .74158 .53706 L .77244 .53449 L p .707 .577 .707 r
F P
0 g
s
.32694 .71698 m .3252 .73523 L .35251 .74258 L p .707 .577 .707 r
F P
0 g
s
.66627 .71012 m .66199 .67288 L .68594 .66554 L p .707 .577 .707 r
F P
0 g
s
.65541 .68247 m .65715 .66422 L .68114 .65993 L p .707 .577 .707 r
F P
0 g
s
.71783 .59769 m .71003 .54186 L .74158 .53706 L p .707 .577 .707 r
F P
0 g
s
.71003 .54186 m .71783 .59769 L .68868 .60426 L p .707 .577 .707 r
F P
0 g
s
.74158 .53706 m .74939 .59288 L .71783 .59769 L p .707 .577 .707 r
F P
0 g
s
.44628 .72983 m .44453 .74808 L .46852 .7438 L p .707 .577 .707 r
F P
0 g
s
.46852 .7438 m .47027 .72555 L .44628 .72983 L p .707 .577 .707 r
F P
0 g
s
.48534 .5474 m .49314 .60323 L .50028 .59557 L p .707 .577 .707 r
F P
0 g
s
.50028 .59557 m .49247 .53974 L .48534 .5474 L p .707 .577 .707 r
F P
0 g
s
.68114 .65993 m .67939 .67819 L .65541 .68247 L p .707 .577 .707 r
F P
0 g
s
.3252 .73523 m .32694 .71698 L .30602 .70785 L p .707 .577 .707 r
F P
0 g
s
.68594 .66554 m .69022 .70279 L .66627 .71012 L p .707 .577 .707 r
F P
0 g
s
.80048 .67279 m .79873 .69104 L .77607 .68494 L p .707 .577 .707 r
F P
0 g
s
.77609 .69127 m .7511 .6927 L p .77595 .65636 L .707 .577 .707 r
F P
0 g
s
.77607 .68494 m .77142 .68369 L p .77605 .68195 L .707 .577 .707 r
F P
0 g
s
.77605 .68195 m .80048 .67279 L .77607 .68494 L .707 .577 .707 r
F
.77142 .68369 m .77316 .66544 L .80048 .67279 L p F P
0 g
s
.77778 .65368 m .78206 .69093 L .77609 .69127 L p .707 .577 .707 r
F P
0 g
s
.77595 .65636 m .77778 .65368 L .77609 .69127 L .707 .577 .707 r
F
.80503 .65441 m .80931 .69166 L .78206 .69093 L p F P
0 g
s
.78206 .69093 m .77778 .65368 L .80503 .65441 L p .707 .577 .707 r
F P
0 g
s
.49101 .58939 m .49529 .62663 L .5024 .61885 L p .707 .577 .707 r
F P
0 g
s
.5024 .61885 m .49812 .5816 L .49101 .58939 L p .707 .577 .707 r
F P
0 g
s
.30602 .70785 m .30427 .7261 L .3252 .73523 L p .707 .577 .707 r
F P
0 g
s
.69022 .70279 m .68594 .66554 L .71517 .65954 L p .707 .577 .707 r
F P
0 g
s
.67939 .67819 m .68114 .65993 L .71042 .65868 L p .707 .577 .707 r
F P
0 g
s
.47027 .72555 m .46852 .7438 L .48487 .7369 L p .707 .577 .707 r
F P
0 g
s
.48487 .7369 m .48662 .71865 L .47027 .72555 L p .707 .577 .707 r
F P
0 g
s
.7511 .6927 m .74682 .65545 L .77778 .65368 L p .707 .577 .707 r
F P
0 g
s
.71517 .65954 m .71945 .69678 L .69022 .70279 L p .707 .577 .707 r
F P
0 g
s
.71042 .65868 m .70868 .67693 L .67939 .67819 L p .707 .577 .707 r
F P
0 g
s
.30427 .7261 m .30602 .70785 L .29352 .69785 L p .707 .577 .707 r
F P
0 g
s
.74682 .65545 m .7511 .6927 L .71945 .69678 L p .707 .577 .707 r
F P
0 g
s
.77316 .66544 m .77142 .68369 L .74038 .67882 L p .707 .577 .707 r
F P
0 g
s
.71945 .69678 m .71517 .65954 L .74682 .65545 L p .707 .577 .707 r
F P
0 g
s
.74038 .67882 m .74213 .66057 L .77316 .66544 L p .707 .577 .707 r
F P
0 g
s
.70868 .67693 m .71042 .65868 L .74213 .66057 L p .707 .577 .707 r
F P
0 g
s
.49812 .5816 m .5024 .61885 L .4996 .61199 L p .707 .577 .707 r
F P
0 g
s
.4996 .61199 m .49532 .57475 L .49812 .5816 L p .707 .577 .707 r
F P
0 g
s
.49247 .53974 m .50028 .59557 L .49752 .58908 L p .707 .577 .707 r
F P
0 g
s
.49752 .58908 m .48972 .53325 L .49247 .53974 L p .707 .577 .707 r
F P
0 g
s
.29352 .69785 m .29178 .7161 L .30427 .7261 L p .707 .577 .707 r
F P
0 g
s
.74213 .66057 m .74038 .67882 L .70868 .67693 L p .707 .577 .707 r
F P
0 g
s
.48662 .71865 m .48487 .7369 L .49198 .72806 L p .707 .577 .707 r
F P
0 g
s
.49198 .72806 m .49372 .70981 L .48662 .71865 L p .707 .577 .707 r
F P
0 g
s
.29178 .7161 m .29352 .69785 L .29069 .68794 L p .707 .577 .707 r
F P
0 g
s
.29069 .68794 m .28894 .70619 L .29178 .7161 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49532 .57475 m .4996 .61199 L .48716 .60673 L p .707 .577 .707 r
F P
0 g
s
.48716 .60673 m .48288 .56949 L .49532 .57475 L p .707 .577 .707 r
F P
0 g
s
.48972 .53325 m .49752 .58908 L .48516 .58439 L p .707 .577 .707 r
F P
0 g
s
.48516 .58439 m .47735 .52856 L .48972 .53325 L p .707 .577 .707 r
F P
0 g
s
.30264 .59276 m .30692 .63001 L .2998 .63779 L p .707 .577 .707 r
F P
0 g
s
.49372 .70981 m .49198 .72806 L .48914 .71816 L p .707 .577 .707 r
F P
0 g
s
.48914 .71816 m .49089 .69991 L .49372 .70981 L p .707 .577 .707 r
F P
0 g
s
.28894 .70619 m .29069 .68794 L .2978 .67911 L p .707 .577 .707 r
F P
0 g
s
.2978 .67911 m .29605 .69736 L .28894 .70619 L p .707 .577 .707 r
F P
0 g
s
.48288 .56949 m .48716 .60673 L .4663 .60359 L p .707 .577 .707 r
F P
0 g
s
.4663 .60359 m .46202 .56634 L .48288 .56949 L p .707 .577 .707 r
F P
0 g
s
.47735 .52856 m .48516 .58439 L .46438 .58196 L p .707 .577 .707 r
F P
0 g
s
.46438 .58196 m .45658 .52614 L .47735 .52856 L p .707 .577 .707 r
F P
0 g
s
.31898 .58481 m .32326 .62206 L .30692 .63001 L p .707 .577 .707 r
F P
0 g
s
.49089 .69991 m .48914 .71816 L .47665 .70815 L p .707 .577 .707 r
F P
0 g
s
.47665 .70815 m .4784 .6899 L .49089 .69991 L p .707 .577 .707 r
F P
0 g
s
.29605 .69736 m .2978 .67911 L .31414 .67221 L p .707 .577 .707 r
F P
0 g
s
.46202 .56634 m .4663 .60359 L .43905 .60286 L p .707 .577 .707 r
F P
0 g
s
.45658 .52614 m .46438 .58196 L .43724 .58204 L p .707 .577 .707 r
F P
0 g
s
.43724 .58204 m .42943 .52621 L .45658 .52614 L p .707 .577 .707 r
F P
0 g
s
.31414 .67221 m .3124 .69046 L .29605 .69736 L p .707 .577 .707 r
F P
0 g
s
.34293 .57747 m .34721 .61472 L .32326 .62206 L p .707 .577 .707 r
F P
0 g
s
.4784 .6899 m .47665 .70815 L .45572 .69903 L p .707 .577 .707 r
F P
0 g
s
.45572 .69903 m .45747 .68078 L .4784 .6899 L p .707 .577 .707 r
F P
0 g
s
.43477 .56562 m .43905 .60286 L .40809 .60463 L p .707 .577 .707 r
F P
0 g
s
.3124 .69046 m .31414 .67221 L .33813 .66792 L p .707 .577 .707 r
F P
0 g
s
.37216 .57147 m .37644 .60872 L .34721 .61472 L p .707 .577 .707 r
F P
0 g
s
.33813 .66792 m .33638 .68617 L .3124 .69046 L p .707 .577 .707 r
F P
0 g
s
.40381 .56738 m .40809 .60463 L .37644 .60872 L p .707 .577 .707 r
F P
0 g
s
.45747 .68078 m .45572 .69903 L .42841 .69167 L p .707 .577 .707 r
F P
0 g
s
.42841 .69167 m .43015 .67342 L .45747 .68078 L p .707 .577 .707 r
F P
0 g
s
.33638 .68617 m .33813 .66792 L .36741 .66666 L p .707 .577 .707 r
F P
0 g
s
.36741 .66666 m .36567 .68491 L .33638 .68617 L p .707 .577 .707 r
F P
0 g
s
.43015 .67342 m .42841 .69167 L .39737 .68681 L p .707 .577 .707 r
F P
0 g
s
.39737 .68681 m .39912 .66856 L .43015 .67342 L p .707 .577 .707 r
F P
0 g
s
.36567 .68491 m .36741 .66666 L .39912 .66856 L p .707 .577 .707 r
F P
0 g
s
.39912 .66856 m .39737 .68681 L .36567 .68491 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00Igoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01EYF3`00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool01000FUIJEP0015YF2@0015YF00<005YFFUH015YF00<005YFFUH01@001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH000050004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006=oo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000HOolJ000cOol0
05moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3000DOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000aOol005]o
o`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000>Ool60006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<7oo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0027oo1P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001GOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001Woo0P00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUH005YF02moo`00EGoo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000Aoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00FUH_Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00IJEP03001JEUYF009J
EPD000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`03001JEP0000=JEP03OomJEP0000IJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`04001J
EP000002FUH00gooFUH00006FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH20006FUH00`00
FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001J
EUYF009JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol01000FUIJEP00
15YF00<005YFFUH00eYF10001EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001eYF00<005YFFUH0
0UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol2FUH00`00FUIJEP02
FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH<0002FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001COol2FUH00`00FUIJEP02FUH20005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH015YF00@005YFFUIJ
EP@0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`9JEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP04001JEUYF000^
Ool005=oo`9JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00=JEPH00003FUH0000002eoo`00Dgoo00@005YF
000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00AJEPX000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool005=oo`800003FUH005YF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool005=oo`04001JEUYF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP0200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH50008FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005
FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH40003FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH0
1UYF1P000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001DOol2FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH70006FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0003FUH01000FUH000001UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;Goo001DOol3FUH20002FUH00`00
FUIJEP03FUH60004FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUH0031oo`00Cgoo1@000eYF00H005YFFUIJEP00FUH40005FUH50003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF008000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<0035oo`00
AWoo2@0015YF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP8003=oo`00@7oo
1P0015YF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000e
Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo
000hOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH0
35YF1@001EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003eoo`00=7oo100000=JEP00FUH0
1EYF00=oo`00FUH01eYF00<005YFFUH01UYF10000UYF00<005YFFUH02`001eYF1@001EYF00<005YF
FUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70011Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<0
009JEP03001JEUYF00=JEP03001JEUYF00aJEPD000EJEP03001JEUYF00IJEP03001JEP0000<000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH4
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80018Ool0031oo`<000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00eJEP<000MJEP03
001JEUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEQ40051oo`00;Woo0P000UYF00<005YFFUH015YF00<005YF
FUH00eYF00AooeYFFUH000QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH03UYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YF001J
EUIoo`00;Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00iJEP03001JEUYF009JEPL000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000EJEP03001JEUYF00=JEP04001JEP00FUIFOol002aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEQT000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF000BOol8000lOol002]oo`03001JEP0000EJ
EP03001JEUYF00AJEP05001JEUYFFUIoo`03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0027oo2@0015YF00@005YF
FUIJEPX0039oo`00:goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF3P001eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEQP000QJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00:goo00<005YF00000eYF00=ooeYF00001UYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF
0P001UYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00009JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00:goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001JEP0000d0
0003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
0005FUH400000eYF001JEP06FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00
FUIJEP02FUH01000FUIJEUYF0P00;Goo000/Ool2FUH00`00FUIJEP02FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo
0UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
00000`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000IJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0UYF00<005YFFUH00`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUH000030003FUH00`00
FUIJEP06FUH00`00FUH000080004FUH01000FUIJEP001UYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool2FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0eYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH80000
1EYF001JEUYF00000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0000000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000]Ool002aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP@00003FUH005YF00AJEP03001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF001JEP030004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHF0002FUH01000FUIJEUYF0P00;7oo000/Ool01000
FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEPX000=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@0
009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000Uo
o`@00004FUH005YFFUH20002FUH40003FUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:00000eYF000000050004FUH500001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001EYF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF009JEPH000Ioo`L000EJEP03001JEUYF009JEP<000=JEP800003FUH0000002aoo`00;Goo
0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF2@000eYF2@0015YF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEP8000=J
EP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP030002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH60003Ool90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF1@00;7oo000]Ool3FUH20002FUH00`00FUIJEP03FUH60004FUH80004
FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YF0000
300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P0000=JEP0000000`00;7oo
000]Ool3FUH01@00FUIJEUYF00000eYF0P001EYF1@000eYF00<005YFFUH01UYF00<005YF00000eYF
0P0000=JEP00FUH01EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
2@00FUIJEUYF001JEP00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001oo`0[Ool002eoo`04001JEUYF0003FUH0
1000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01eYF0P000eYF00<005YF00000P001EYF00<0
05YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
15YF001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00001000;Goo000]Ool01000FUIJEP000eYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP@000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH000000004
FUH00`00FUIJEP05FUH20007FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF0000
000^Ool002ioo`9JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030003FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH000AJEP03001JEUYF00MJEP@000=JEPD0
00EJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEP0002moo`00;Woo0UYF1@000eYF00<0
05YFFUH015YF00<005YFFUH01UYF0`001UYF00<005YFFUH00`001EYF00<005YFFUH00eYF1@0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH02eYF5`000eYF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH02`00
1eYF1@001EYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF
00<005YFFUH01eYF00<005YFFUH01eYF1@000eYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH035YF1P000eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH035YF1@001EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH0
15YF5`000eYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP0<FUH00`00FUH000020004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Goo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP0<FUH50006FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EUYF009JEP03001JEUYF00]JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000cOol002moo`800003FUH005YF00AJEP03001JEUYF00eJEP<000MJEP03001JEUYF00@0009o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH007oo1@000UYF00<005YFFUH015YF10000eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEPD003Eoo`00<Goo10000eYF00<005YFFUH03UYF00<005YFFUH00UYF1`002Goo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000MJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
obD003Yoo`00=Goo1`002EYF2@0057oo1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
?7oo2@0087oo00<005YFFUH02P0015YF00<005YFFUH00UYF1`002EYF00<005YFFUH02EYF2@0025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002000GGoo001UOol01000FUIJEP001EYF00@0
05YFFUIJEPX0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00D005Qoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00?Woo20007goo00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000IJ
EP03001JEUYF009JEP05001JEUYFFUH0001EOol003Ioo`P000=JEP03001JEUYF009JEPT001Ioo`04
001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000aOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000@Ool01@00
FUIJEP00FUH00P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP03001JEUYF009JEP04001J
EUYFFUH2001DOol002moo`800003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEP0000<000aoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80
0004FUH005YF0006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00E7oo000]Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30009Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP80
0003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0001DOol002]oo`03001JEP0000=JEP04
001JEUYFFUH80008Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP020005Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<005YFFUH00UYF00D005YFFUIJEP0005Aoo`00
:goo00<005YF00000eYF10006Goo1P001UYF00<005YFFUH00eYF00<007ooOol00Woo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF00002`000UYF00@005YFFUIJEP8005=oo`00:goo00@0
05YF001JEP8002=oo`@0009JEP03001JEUYF00=JEP8000=oo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00D00003FUH00000009JEP@000=JEP8005=oo`00:goo00@005YF000002Uo
o`<000EJEP04001JEP000002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP02FUH30003FUH200000eYF0000001COol002]oo`<002eoo`8000=JEP07
001JEUYFFUH007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF
00@005YFFUIJEPD005=oo`00:goo0P0000=JEP000000;Goo0P0000=JEP00FUH00UYF00<007ooOol0
0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P000UYF1@00Dgoo
000[Ool00`00FUIJEP02FUH00`00Oomoo`0/Ool20003FUH20003Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
0005FUH00`00FUIJEP05FUH600000eYF001oo`1BOol002]oo`03001JEUYF009JEP<002ioo`03001J
EUYF008000Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEP0000@005Aoo`00
:goo00<005YFFUH00UYF00<005YFFUH00P00;Goo10001goo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`000eYF00<005YFFUH01UYF
00<005YFFUH015YF1P00EGoo000/Ool01000FUIJEP001EYF0P00:goo10002Goo0`0000=JEP00FUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01EYF00<005YF000010000UYF00<005YF0000EWoo000]Ool30005FUH00`00FUH00003000U
Ool200000eYF0000000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUH0000G0003FUH01000FUIJEUYF0P00Egoo000_Ool00`00FUIJEP03FUH00`00FUIJEP03FUH7
000IOol50003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH70003FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00Egoo000`Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90009Ool70003FUH01`00FUIJEUYF001JEP00021ooaT000YJEPH000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001HOol0039oo`800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool01@00
FUIJEUYF000015YF00<005YFFUH02eYF00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Yoo`00=7oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002ioo`800003FUH005YF00=JEP03001JEUYF00AJEP@0
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001LOol003Moo`@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol:0004
FUH00`00FUIJEP0H001QOol003]oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000mOol9001gOol0049oo`T000AJEP03001JEUYF009JEPL00<9oo`00Bgoo2@00bGoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59883 .7188 m .58627 .66342 L .55592 .66873 L p .707 .577 .707 r
F P
0 g
s
.58627 .66342 m .59883 .7188 L .62992 .71152 L p .707 .577 .707 r
F P
0 g
s
.62992 .71152 m .61737 .65613 L .58627 .66342 L p .707 .577 .707 r
F P
0 g
s
.61737 .65613 m .62992 .71152 L .65872 .70297 L p .707 .577 .707 r
F P
0 g
s
.65872 .70297 m .64617 .64759 L .61737 .65613 L p .707 .577 .707 r
F P
0 g
s
.56847 .72412 m .55592 .66873 L .52927 .67156 L p .707 .577 .707 r
F P
0 g
s
.55592 .66873 m .56847 .72412 L .59883 .7188 L p .707 .577 .707 r
F P
0 g
s
.64617 .64759 m .65872 .70297 L .6824 .69401 L p .707 .577 .707 r
F P
0 g
s
.6824 .69401 m .66985 .63862 L .64617 .64759 L p .707 .577 .707 r
F P
0 g
s
.52927 .67156 m .54183 .72694 L .56847 .72412 L p .707 .577 .707 r
F P
0 g
s
.54183 .72694 m .52927 .67156 L .50896 .67161 L p .707 .577 .707 r
F P
0 g
s
.66985 .63862 m .6824 .69401 L .69864 .6855 L p .707 .577 .707 r
F P
0 g
s
.69864 .6855 m .68609 .63011 L .66985 .63862 L p .707 .577 .707 r
F P
0 g
s
.50896 .67161 m .52151 .72699 L .54183 .72694 L p .707 .577 .707 r
F P
0 g
s
.60205 .84573 m .59515 .80864 L .56453 .81267 L p .707 .577 .707 r
F P
0 g
s
.59515 .80864 m .60205 .84573 L .63338 .8396 L p .707 .577 .707 r
F P
0 g
s
.63338 .8396 m .62648 .80251 L .59515 .80864 L p .707 .577 .707 r
F P
0 g
s
.58503 .81894 m .58785 .80095 L .55704 .79429 L p .707 .577 .707 r
F P
0 g
s
.58785 .80095 m .58503 .81894 L .61653 .82247 L p .707 .577 .707 r
F P
0 g
s
.61653 .82247 m .61935 .80447 L .58785 .80095 L p .707 .577 .707 r
F P
0 g
s
.62648 .80251 m .63338 .8396 L .66237 .83198 L p .707 .577 .707 r
F P
0 g
s
.66237 .83198 m .65547 .79488 L .62648 .80251 L p .707 .577 .707 r
F P
0 g
s
.61935 .80447 m .61653 .82247 L .64565 .8225 L p .707 .577 .707 r
F P
0 g
s
.64565 .8225 m .64847 .80451 L .61935 .80447 L p .707 .577 .707 r
F P
0 g
s
.55422 .81228 m .55704 .79429 L .52995 .78513 L p .707 .577 .707 r
F P
0 g
s
.56453 .81267 m .57142 .84977 L .60205 .84573 L p .707 .577 .707 r
F P
0 g
s
.57142 .84977 m .56453 .81267 L .55976 .81294 L p .707 .577 .707 r
F P
0 g
s
.55704 .79429 m .55422 .81228 L .55977 .81348 L p .707 .577 .707 r
F P
0 g
s
.55929 .79627 m .55704 .79429 L .55977 .81348 L .707 .577 .707 r
F
.55976 .81294 m .53762 .81421 L p .56047 .83824 L F P
0 g
s
.57142 .84977 m .55976 .81294 L .56047 .83824 L .707 .577 .707 r
F
.55977 .81348 m .58503 .81894 L p .55929 .79627 L F P
0 g
s
.52995 .78513 m .52713 .80312 L .55422 .81228 L p .707 .577 .707 r
F P
0 g
s
.65547 .79488 m .66237 .83198 L .68617 .8236 L p .707 .577 .707 r
F P
0 g
s
.68617 .8236 m .67927 .7865 L .65547 .79488 L p .707 .577 .707 r
F P
0 g
s
.52151 .72699 m .50896 .67161 L .49695 .66889 L p .707 .577 .707 r
F P
0 g
s
.53762 .81421 m .54452 .85131 L .57142 .84977 L p .707 .577 .707 r
F P
0 g
s
.64847 .80451 m .64565 .8225 L .66953 .81904 L p .707 .577 .707 r
F P
0 g
s
.66953 .81904 m .67235 .80105 L .64847 .80451 L p .707 .577 .707 r
F P
0 g
s
.52713 .80312 m .52995 .78513 L .50923 .77437 L p .707 .577 .707 r
F P
0 g
s
.68609 .63011 m .69864 .6855 L .70585 .67827 L p .707 .577 .707 r
F P
0 g
s
.70585 .67827 m .6933 .62289 L .68609 .63011 L p .707 .577 .707 r
F P
0 g
s
.49695 .66889 m .5095 .72427 L .52151 .72699 L p .707 .577 .707 r
F P
0 g
s
.54452 .85131 m .53762 .81421 L .51706 .81311 L p .707 .577 .707 r
F P
0 g
s
.50923 .77437 m .50641 .79237 L .52713 .80312 L p .707 .577 .707 r
F P
0 g
s
.67927 .7865 m .68617 .8236 L .70245 .81529 L p .707 .577 .707 r
F P
0 g
s
.70245 .81529 m .69555 .77819 L .67927 .7865 L p .707 .577 .707 r
F P
0 g
s
.51706 .81311 m .52396 .85021 L .54452 .85131 L p .707 .577 .707 r
F P
0 g
s
.67235 .80105 m .66953 .81904 L .68584 .81243 L p .707 .577 .707 r
F P
0 g
s
.68584 .81243 m .68866 .79444 L .67235 .80105 L p .707 .577 .707 r
F P
0 g
s
.50641 .79237 m .50923 .77437 L .4969 .76308 L p .707 .577 .707 r
F P
0 g
s
.5095 .72427 m .49695 .66889 L .49443 .66367 L p .707 .577 .707 r
F P
0 g
s
.4969 .76308 m .49408 .78107 L .50641 .79237 L p .707 .577 .707 r
F P
0 g
s
.52396 .85021 m .51706 .81311 L .50487 .80947 L p .707 .577 .707 r
F P
0 g
s
.6933 .62289 m .70585 .67827 L .70333 .67305 L p .707 .577 .707 r
F P
0 g
s
.70333 .67305 m .69078 .61767 L .6933 .62289 L p .707 .577 .707 r
F P
0 g
s
.49443 .66367 m .50698 .71905 L .5095 .72427 L p .707 .577 .707 r
F P
0 g
s
.50487 .80947 m .51176 .84657 L .52396 .85021 L p .707 .577 .707 r
F P
0 g
s
.69555 .77819 m .70245 .81529 L .70962 .80787 L p .707 .577 .707 r
F P
0 g
s
.70962 .80787 m .70272 .77077 L .69555 .77819 L p .707 .577 .707 r
F P
0 g
s
.68866 .79444 m .68584 .81243 L .69298 .80331 L p .707 .577 .707 r
F P
0 g
s
.69298 .80331 m .6958 .78532 L .68866 .79444 L p .707 .577 .707 r
F P
0 g
s
.49037 .82225 m .49526 .32091 L .45125 .3178 L p .707 .577 .707 r
F P
0 g
s
.49408 .78107 m .4969 .76308 L .49417 .75234 L p .707 .577 .707 r
F P
0 g
s
.50698 .71905 m .49443 .66367 L .50164 .65644 L p .707 .577 .707 r
F P
0 g
s
.49417 .75234 m .49135 .77034 L .49408 .78107 L p .707 .577 .707 r
F P
0 g
s
.51176 .84657 m .50487 .80947 L .50222 .80366 L p .707 .577 .707 r
F P
0 g
s
.50164 .65644 m .51419 .71183 L .50698 .71905 L p .707 .577 .707 r
F P
0 g
s
.50222 .80366 m .50912 .84076 L .51176 .84657 L p .707 .577 .707 r
F P
0 g
s
.49135 .77034 m .49417 .75234 L .50131 .74323 L p .707 .577 .707 r
F P
0 g
s
.51419 .71183 m .50164 .65644 L .51788 .64793 L p .707 .577 .707 r
F P
0 g
s
.50131 .74323 m .49849 .76122 L .49135 .77034 L p .707 .577 .707 r
F P
0 g
s
.50912 .84076 m .50222 .80366 L .50939 .79623 L p .707 .577 .707 r
F P
0 g
s
.51788 .64793 m .53043 .70332 L .51419 .71183 L p .707 .577 .707 r
F P
0 g
s
.50939 .79623 m .51629 .83333 L .50912 .84076 L p .707 .577 .707 r
F P
0 g
s
.49849 .76122 m .50131 .74323 L .51763 .73661 L p .707 .577 .707 r
F P
0 g
s
.53043 .70332 m .51788 .64793 L .54156 .63897 L p .707 .577 .707 r
F P
0 g
s
.51763 .73661 m .5148 .7546 L .49849 .76122 L p .707 .577 .707 r
F P
0 g
s
.51629 .83333 m .50939 .79623 L .52568 .78793 L p .707 .577 .707 r
F P
0 g
s
.52568 .78793 m .53257 .82502 L .51629 .83333 L p .707 .577 .707 r
F P
0 g
s
.5148 .7546 m .51763 .73661 L .54151 .73315 L p .707 .577 .707 r
F P
0 g
s
.54151 .73315 m .53869 .75115 L .5148 .7546 L p .707 .577 .707 r
F P
0 g
s
.53257 .82502 m .52568 .78793 L .54947 .77955 L p .707 .577 .707 r
F P
0 g
s
.54947 .77955 m .55637 .81665 L .53257 .82502 L p .707 .577 .707 r
F P
0 g
s
.49526 .32091 m .49037 .82225 L .53531 .82155 L p .707 .577 .707 r
F P
0 g
s
.54156 .63897 m .55411 .69435 L .53043 .70332 L p .707 .577 .707 r
F P
0 g
s
.53531 .82155 m .5402 .32021 L .49526 .32091 L p .707 .577 .707 r
F P
0 g
s
.55411 .69435 m .54156 .63897 L .57035 .63042 L p .707 .577 .707 r
F P
0 g
s
.57035 .63042 m .58291 .68581 L .55411 .69435 L p .707 .577 .707 r
F P
0 g
s
.53869 .75115 m .54151 .73315 L .57063 .73319 L p .707 .577 .707 r
F P
0 g
s
.57063 .73319 m .56781 .75118 L .53869 .75115 L p .707 .577 .707 r
F P
0 g
s
.55637 .81665 m .54947 .77955 L .57846 .77192 L p .707 .577 .707 r
F P
0 g
s
.56781 .75118 m .57063 .73319 L .60213 .73671 L p .707 .577 .707 r
F P
0 g
s
.57846 .77192 m .58536 .80902 L .55637 .81665 L p .707 .577 .707 r
F P
0 g
s
.60213 .73671 m .59931 .7547 L .56781 .75118 L p .707 .577 .707 r
F P
0 g
s
.5402 .32021 m .53531 .82155 L .57679 .81709 L p .707 .577 .707 r
F P
0 g
s
.58291 .68581 m .57035 .63042 L .60145 .62314 L p .707 .577 .707 r
F P
0 g
s
.57679 .81709 m .58168 .31575 L .5402 .32021 L p .707 .577 .707 r
F P
0 g
s
.44637 .81914 m .45125 .3178 L .41249 .31116 L p .707 .577 .707 r
F P
0 g
s
.45125 .3178 m .44637 .81914 L .49037 .82225 L p .707 .577 .707 r
F P
0 g
s
.69078 .61767 m .70333 .67305 L .69132 .67033 L p .707 .577 .707 r
F P
0 g
s
.69132 .67033 m .67877 .61495 L .69078 .61767 L p .707 .577 .707 r
F P
0 g
s
.60145 .62314 m .61401 .67852 L .58291 .68581 L p .707 .577 .707 r
F P
0 g
s
.63294 .74338 m .63011 .76137 L .59931 .7547 L p .707 .577 .707 r
F P
0 g
s
.59931 .7547 m .60213 .73671 L .63294 .74338 L p .707 .577 .707 r
F P
0 g
s
.58536 .80902 m .57846 .77192 L .6098 .76579 L p .707 .577 .707 r
F P
0 g
s
.6098 .76579 m .6167 .80289 L .58536 .80902 L p .707 .577 .707 r
F P
0 g
s
.58168 .31575 m .57679 .81709 L .61075 .80931 L p .707 .577 .707 r
F P
0 g
s
.61401 .67852 m .60145 .62314 L .63181 .61782 L p .707 .577 .707 r
F P
0 g
s
.6167 .80289 m .6098 .76579 L .63499 .76247 L p .707 .577 .707 r
F P
0 g
s
.66002 .75253 m .6572 .77053 L .635 .76302 L p .707 .577 .707 r
F P
0 g
s
.63498 .75993 m .66002 .75253 L .635 .76302 L .707 .577 .707 r
F
.63499 .76247 m .64042 .76176 L p .63505 .77107 L F P
0 g
s
.6167 .80289 m .63499 .76247 L .63505 .77107 L .707 .577 .707 r
F
.635 .76302 m .63011 .76137 L p .63498 .75993 L F P
0 g
s
.61075 .80931 m .61564 .30797 L .58168 .31575 L p .707 .577 .707 r
F P
0 g
s
.70272 .77077 m .70962 .80787 L .70698 .80205 L p .707 .577 .707 r
F P
0 g
s
.70698 .80205 m .70008 .76495 L .70272 .77077 L p .707 .577 .707 r
F P
0 g
s
.6958 .78532 m .69298 .80331 L .69026 .79258 L p .707 .577 .707 r
F P
0 g
s
.69026 .79258 m .69308 .77458 L .6958 .78532 L p .707 .577 .707 r
F P
0 g
s
.4076 .8125 m .41249 .31116 L .38277 .30166 L p .707 .577 .707 r
F P
0 g
s
.41249 .31116 m .4076 .8125 L .44637 .81914 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25904 .72599 m .25214 .68889 L .22152 .69293 L p .707 .577 .707 r
F P
0 g
s
.22152 .69293 m .22842 .73002 L .25904 .72599 L p .707 .577 .707 r
F P
0 g
s
.25582 .72815 m .24326 .67277 L .21291 .67808 L p .707 .577 .707 r
F P
0 g
s
.25214 .68889 m .25904 .72599 L .29037 .71986 L p .707 .577 .707 r
F P
0 g
s
.29037 .71986 m .28348 .68276 L .25214 .68889 L p .707 .577 .707 r
F P
0 g
s
.24326 .67277 m .25582 .72815 L .28692 .72087 L p .707 .577 .707 r
F P
0 g
s
.28692 .72087 m .27436 .66548 L .24326 .67277 L p .707 .577 .707 r
F P
0 g
s
.28348 .68276 m .29037 .71986 L .31936 .71223 L p .707 .577 .707 r
F P
0 g
s
.31936 .71223 m .31246 .67514 L .28348 .68276 L p .707 .577 .707 r
F P
0 g
s
.27436 .66548 m .28692 .72087 L .31571 .71232 L p .707 .577 .707 r
F P
0 g
s
.31571 .71232 m .30316 .65694 L .27436 .66548 L p .707 .577 .707 r
F P
0 g
s
.67877 .61495 m .69132 .67033 L .671 .67038 L p .707 .577 .707 r
F P
0 g
s
.671 .67038 m .65845 .615 L .67877 .61495 L p .707 .577 .707 r
F P
0 g
s
.22546 .73347 m .21291 .67808 L .18627 .68091 L p .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .22152 .69293 L .21912 .69306 L p .707 .577 .707 r
F P
0 g
s
.21291 .67808 m .22546 .73347 L .22733 .73314 L p .707 .577 .707 r
F P
0 g
s
.21704 .6829 m .21291 .67808 L .22733 .73314 L .707 .577 .707 r
F
.18627 .68091 m .19882 .73629 L .22546 .73347 L p F P
0 g
s
.21912 .69306 m .19461 .69447 L p .22621 .72771 L .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .21912 .69306 L .22621 .72771 L .707 .577 .707 r
F
.19461 .69447 m .20151 .73157 L .22842 .73002 L p F P
0 g
s
.22733 .73314 m .25582 .72815 L p .21704 .6829 L .707 .577 .707 r
F P
0 g
s
.63181 .61782 m .64436 .67321 L .61401 .67852 L p .707 .577 .707 r
F P
0 g
s
.63011 .76137 m .63294 .74338 L .66002 .75253 L p .707 .577 .707 r
F P
0 g
s
.64042 .76176 m .64732 .79886 L .6167 .80289 L p .707 .577 .707 r
F P
0 g
s
.61564 .30797 m .61075 .80931 L .63386 .79898 L p .707 .577 .707 r
F P
0 g
s
.64436 .67321 m .63181 .61782 L .65845 .615 L p .707 .577 .707 r
F P
0 g
s
.63386 .79898 m .63875 .29764 L .61564 .30797 L p .707 .577 .707 r
F P
0 g
s
.70008 .76495 m .70698 .80205 L .69478 .79842 L p .707 .577 .707 r
F P
0 g
s
.69308 .77458 m .69026 .79258 L .67793 .78128 L p .707 .577 .707 r
F P
0 g
s
.67793 .78128 m .68075 .76329 L .69308 .77458 L p .707 .577 .707 r
F P
0 g
s
.69478 .79842 m .68788 .76132 L .70008 .76495 L p .707 .577 .707 r
F P
0 g
s
.31246 .67514 m .31936 .71223 L .34316 .70386 L p .707 .577 .707 r
F P
0 g
s
.34316 .70386 m .33626 .66676 L .31246 .67514 L p .707 .577 .707 r
F P
0 g
s
.30316 .65694 m .31571 .71232 L .33939 .70336 L p .707 .577 .707 r
F P
0 g
s
.33939 .70336 m .32684 .64797 L .30316 .65694 L p .707 .577 .707 r
F P
0 g
s
.37788 .803 m .38277 .30166 L .36499 .29022 L p .707 .577 .707 r
F P
0 g
s
.38277 .30166 m .37788 .803 L .4076 .8125 L p .707 .577 .707 r
F P
0 g
s
.19882 .73629 m .18627 .68091 L .16595 .68096 L p .707 .577 .707 r
F P
0 g
s
.20151 .73157 m .19461 .69447 L .17405 .69337 L p .707 .577 .707 r
F P
0 g
s
.65845 .615 m .671 .67038 L .64436 .67321 L p .707 .577 .707 r
F P
0 g
s
.33626 .66676 m .34316 .70386 L .35944 .69555 L p .707 .577 .707 r
F P
0 g
s
.35944 .69555 m .35254 .65845 L .33626 .66676 L p .707 .577 .707 r
F P
0 g
s
.32684 .64797 m .33939 .70336 L .35563 .69485 L p .707 .577 .707 r
F P
0 g
s
.35563 .69485 m .34308 .63946 L .32684 .64797 L p .707 .577 .707 r
F P
0 g
s
.16595 .68096 m .1785 .73634 L .19882 .73629 L p .707 .577 .707 r
F P
0 g
s
.17405 .69337 m .18095 .73046 L .20151 .73157 L p .707 .577 .707 r
F P
0 g
s
.68788 .76132 m .69478 .79842 L .67422 .79732 L p .707 .577 .707 r
F P
0 g
s
.68075 .76329 m .67793 .78128 L .6572 .77053 L p .707 .577 .707 r
F P
0 g
s
.6572 .77053 m .66002 .75253 L .68075 .76329 L p .707 .577 .707 r
F P
0 g
s
.67422 .79732 m .66733 .76022 L .68788 .76132 L p .707 .577 .707 r
F P
0 g
s
.24202 .85462 m .24484 .83663 L .21403 .82996 L p .707 .577 .707 r
F P
0 g
s
.24484 .83663 m .24202 .85462 L .27352 .85814 L p .707 .577 .707 r
F P
0 g
s
.27352 .85814 m .27634 .84015 L .24484 .83663 L p .707 .577 .707 r
F P
0 g
s
.64732 .79886 m .64042 .76176 L .66733 .76022 L p .707 .577 .707 r
F P
0 g
s
.63875 .29764 m .63386 .79898 L .64386 .7871 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .64875 .28576 L .63875 .29764 L p .707 .577 .707 r
F P
0 g
s
.27634 .84015 m .27352 .85814 L .30264 .85818 L p .707 .577 .707 r
F P
0 g
s
.30264 .85818 m .30546 .84019 L .27634 .84015 L p .707 .577 .707 r
F P
0 g
s
.21121 .84795 m .21403 .82996 L .18694 .8208 L p .707 .577 .707 r
F P
0 g
s
.21403 .82996 m .21121 .84795 L .24202 .85462 L p .707 .577 .707 r
F P
0 g
s
.1785 .73634 m .16595 .68096 L .15394 .67824 L p .707 .577 .707 r
F P
0 g
s
.18095 .73046 m .17405 .69337 L .16186 .68973 L p .707 .577 .707 r
F P
0 g
s
.18694 .8208 m .18412 .8388 L .21121 .84795 L p .707 .577 .707 r
F P
0 g
s
.35254 .65845 m .35944 .69555 L .36661 .68812 L p .707 .577 .707 r
F P
0 g
s
.34308 .63946 m .35563 .69485 L .36284 .68762 L p .707 .577 .707 r
F P
0 g
s
.36661 .68812 m .35971 .65103 L .35254 .65845 L p .707 .577 .707 r
F P
0 g
s
.36284 .68762 m .35029 .63224 L .34308 .63946 L p .707 .577 .707 r
F P
0 g
s
.15394 .67824 m .16649 .73362 L .1785 .73634 L p .707 .577 .707 r
F P
0 g
s
.16186 .68973 m .16875 .72683 L .18095 .73046 L p .707 .577 .707 r
F P
0 g
s
.30546 .84019 m .30264 .85818 L .32652 .85472 L p .707 .577 .707 r
F P
0 g
s
.32652 .85472 m .32934 .83673 L .30546 .84019 L p .707 .577 .707 r
F P
0 g
s
.35029 .63224 m .36284 .68762 L .36032 .6824 L p .707 .577 .707 r
F P
0 g
s
.36032 .6824 m .34777 .62702 L .35029 .63224 L p .707 .577 .707 r
F P
0 g
s
.35971 .65103 m .36661 .68812 L .36397 .68231 L p .707 .577 .707 r
F P
0 g
s
.36397 .68231 m .35707 .64521 L .35971 .65103 L p .707 .577 .707 r
F P
0 g
s
.34777 .62702 m .36032 .6824 L .34831 .67968 L p .707 .577 .707 r
F P
0 g
s
.35707 .64521 m .36397 .68231 L .35177 .67867 L p .707 .577 .707 r
F P
0 g
s
.3601 .79156 m .36499 .29022 L .3609 .27796 L p .707 .577 .707 r
F P
0 g
s
.36499 .29022 m .3601 .79156 L .37788 .803 L p .707 .577 .707 r
F P
0 g
s
.18412 .8388 m .18694 .8208 L .16622 .81005 L p .707 .577 .707 r
F P
0 g
s
.66733 .76022 m .67422 .79732 L .64732 .79886 L p .707 .577 .707 r
F P
0 g
s
.16622 .81005 m .1634 .82804 L .18412 .8388 L p .707 .577 .707 r
F P
0 g
s
.16875 .72683 m .16186 .68973 L .15921 .68392 L p .707 .577 .707 r
F P
0 g
s
.16649 .73362 m .15394 .67824 L .15142 .67302 L p .707 .577 .707 r
F P
0 g
s
.32934 .83673 m .32652 .85472 L .34283 .84811 L p .707 .577 .707 r
F P
0 g
s
.34283 .84811 m .34565 .83011 L .32934 .83673 L p .707 .577 .707 r
F P
0 g
s
.1634 .82804 m .16622 .81005 L .15389 .79875 L p .707 .577 .707 r
F P
0 g
s
.15921 .68392 m .16611 .72101 L .16875 .72683 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .63977 .77484 L p .6429 .6043 L .707 .577 .707 r
F P
0 g
s
.6429 .6043 m .64512 .4833 L .6446 .60836 L .707 .577 .707 r
F
.6429 .6043 m .6446 .60836 L .64386 .7871 L F
.64466 .2735 m .63977 .77484 L .62199 .7634 L p F P
0 g
s
.63415 .57685 m .63163 .57163 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.64709 .45587 m .64386 .7871 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64466 .2735 m .64875 .28576 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.63977 .77484 m .64222 .52379 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64222 .52379 m .64466 .2735 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .65871 .63495 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63415 .57685 m .63739 .59114 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .6467 .63224 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .63739 .59114 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .63415 .57685 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .64616 .57957 L .63835 .5778 L p .707 .577 .707 r
F P
0 g
s
.63835 .5778 m .63415 .57685 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .63835 .5778 L .6378 .58547 L .707 .577 .707 r
F
.64875 .28576 m .64709 .45587 L p .64512 .4833 L F P
0 g
s
.15142 .67302 m .16397 .7284 L .16649 .73362 L p .707 .577 .707 r
F P
0 g
s
.15389 .79875 m .15107 .81675 L .1634 .82804 L p .707 .577 .707 r
F P
0 g
s
.3609 .27796 m .35602 .7793 L .3601 .79156 L p .707 .577 .707 r
F P
0 g
s
.35602 .7793 m .3609 .27796 L .3709 .26608 L p .707 .577 .707 r
F P
0 g
s
.34565 .83011 m .34283 .84811 L .34997 .83899 L p .707 .577 .707 r
F P
0 g
s
.34997 .83899 m .3528 .82099 L .34565 .83011 L p .707 .577 .707 r
F P
0 g
s
.16611 .72101 m .15921 .68392 L .16638 .67649 L p .707 .577 .707 r
F P
0 g
s
.16397 .7284 m .15142 .67302 L .15863 .66579 L p .707 .577 .707 r
F P
0 g
s
.15107 .81675 m .15389 .79875 L .15116 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16638 .67649 m .17328 .71359 L .16611 .72101 L p .707 .577 .707 r
F P
0 g
s
.34831 .67968 m .33576 .6243 L .34777 .62702 L p .707 .577 .707 r
F P
0 g
s
.15116 .78802 m .14834 .80601 L .15107 .81675 L p .707 .577 .707 r
F P
0 g
s
.35177 .67867 m .34487 .64158 L .35707 .64521 L p .707 .577 .707 r
F P
0 g
s
.15863 .66579 m .17118 .72118 L .16397 .7284 L p .707 .577 .707 r
F P
0 g
s
.62199 .7634 m .62688 .26206 L .64466 .2735 L p .707 .577 .707 r
F P
0 g
s
.3528 .82099 m .34997 .83899 L .34725 .82825 L p .707 .577 .707 r
F P
0 g
s
.34725 .82825 m .35007 .81026 L .3528 .82099 L p .707 .577 .707 r
F P
0 g
s
.17328 .71359 m .16638 .67649 L .18267 .66818 L p .707 .577 .707 r
F P
0 g
s
.17118 .72118 m .15863 .66579 L .17487 .65728 L p .707 .577 .707 r
F P
0 g
s
.14834 .80601 m .15116 .78802 L .15831 .7789 L p .707 .577 .707 r
F P
0 g
s
.36602 .76742 m .3709 .26608 L .39401 .25575 L p .707 .577 .707 r
F P
0 g
s
.3709 .26608 m .36602 .76742 L .35602 .7793 L p .707 .577 .707 r
F P
0 g
s
.18267 .66818 m .18956 .70528 L .17328 .71359 L p .707 .577 .707 r
F P
0 g
s
.33576 .6243 m .34831 .67968 L .32799 .67973 L p .707 .577 .707 r
F P
0 g
s
.32799 .67973 m .31544 .62435 L .33576 .6243 L p .707 .577 .707 r
F P
0 g
s
.15831 .7789 m .15548 .79689 L .14834 .80601 L p .707 .577 .707 r
F P
0 g
s
.34487 .64158 m .35177 .67867 L .33121 .67757 L p .707 .577 .707 r
F P
0 g
s
.33121 .67757 m .32432 .64047 L .34487 .64158 L p .707 .577 .707 r
F P
0 g
s
.17487 .65728 m .18742 .71267 L .17118 .72118 L p .707 .577 .707 r
F P
0 g
s
.18956 .70528 m .18267 .66818 L .20646 .65981 L p .707 .577 .707 r
F P
0 g
s
.18742 .71267 m .17487 .65728 L .19855 .64832 L p .707 .577 .707 r
F P
0 g
s
.35007 .81026 m .34725 .82825 L .33492 .81696 L p .707 .577 .707 r
F P
0 g
s
.33492 .81696 m .33774 .79896 L .35007 .81026 L p .707 .577 .707 r
F P
0 g
s
.62688 .26206 m .62199 .7634 L .59227 .7539 L p .707 .577 .707 r
F P
0 g
s
.59227 .7539 m .59716 .25256 L .62688 .26206 L p .707 .577 .707 r
F P
0 g
s
.15548 .79689 m .15831 .7789 L .17462 .77229 L p .707 .577 .707 r
F P
0 g
s
.31544 .62435 m .32799 .67973 L .30299 .68238 L p .707 .577 .707 r
F P
0 g
s
.30225 .67884 m .31544 .62435 L .30299 .68238 L .707 .577 .707 r
F
.30236 .67937 m .27369 .68315 L p .29535 .64559 L F P
0 g
s
.27369 .68315 m .26679 .64605 L .29468 .64238 L p .707 .577 .707 r
F P
0 g
s
.27369 .68315 m .29468 .64238 L .29535 .64559 L .707 .577 .707 r
F
.30135 .68256 m .2888 .62717 L .29146 .62689 L p F P
0 g
s
.29146 .62689 m .31544 .62435 L p .30225 .67884 L .707 .577 .707 r
F P
0 g
s
.30135 .68256 m .29146 .62689 L .30225 .67884 L .707 .577 .707 r
F
.29468 .64238 m .29741 .64202 L p .29535 .64559 L F P
0 g
s
.29741 .64202 m .30431 .67911 L .30236 .67937 L p .707 .577 .707 r
F P
0 g
s
.29535 .64559 m .29741 .64202 L .30236 .67937 L .707 .577 .707 r
F
.30299 .68238 m .30135 .68256 L p .30225 .67884 L F P
0 g
s
.32432 .64047 m .33121 .67757 L .30431 .67911 L p .707 .577 .707 r
F P
0 g
s
.30431 .67911 m .29741 .64202 L .32432 .64047 L p .707 .577 .707 r
F P
0 g
s
.20646 .65981 m .21336 .6969 L .18956 .70528 L p .707 .577 .707 r
F P
0 g
s
.19855 .64832 m .2111 .7037 L .18742 .71267 L p .707 .577 .707 r
F P
0 g
s
.17462 .77229 m .17179 .79028 L .15548 .79689 L p .707 .577 .707 r
F P
0 g
s
.73603 .62676 m .72348 .57138 L .69312 .5767 L p .707 .577 .707 r
F P
0 g
s
.72348 .57138 m .73603 .62676 L .76713 .61948 L p .707 .577 .707 r
F P
0 g
s
.76713 .61948 m .75458 .5641 L .72348 .57138 L p .707 .577 .707 r
F P
0 g
s
.39401 .25575 m .38912 .75709 L .36602 .76742 L p .707 .577 .707 r
F P
0 g
s
.38912 .75709 m .39401 .25575 L .42797 .24797 L p .707 .577 .707 r
F P
0 g
s
.75458 .5641 m .76713 .61948 L .79593 .61093 L p .707 .577 .707 r
F P
0 g
s
.79593 .61093 m .78337 .55555 L .75458 .5641 L p .707 .577 .707 r
F P
0 g
s
.21336 .6969 m .20646 .65981 L .23545 .65218 L p .707 .577 .707 r
F P
0 g
s
.2111 .7037 m .19855 .64832 L .22734 .63977 L p .707 .577 .707 r
F P
0 g
s
.26679 .64605 m .27369 .68315 L .24235 .68928 L p .707 .577 .707 r
F P
0 g
s
.2888 .62717 m .30135 .68256 L .271 .68787 L p .707 .577 .707 r
F P
0 g
s
.24235 .68928 m .23545 .65218 L .26679 .64605 L p .707 .577 .707 r
F P
0 g
s
.271 .68787 m .25844 .63249 L .2888 .62717 L p .707 .577 .707 r
F P
0 g
s
.70567 .63208 m .69312 .5767 L .66648 .57952 L p .707 .577 .707 r
F P
0 g
s
.69312 .5767 m .70567 .63208 L .73603 .62676 L p .707 .577 .707 r
F P
0 g
s
.23545 .65218 m .24235 .68928 L .21336 .6969 L p .707 .577 .707 r
F P
0 g
s
.33774 .79896 m .33492 .81696 L .31419 .8062 L p .707 .577 .707 r
F P
0 g
s
.31419 .8062 m .31702 .78821 L .33774 .79896 L p .707 .577 .707 r
F P
0 g
s
.78337 .55555 m .79593 .61093 L .8196 .60197 L p .707 .577 .707 r
F P
0 g
s
.8196 .60197 m .80705 .54659 L .78337 .55555 L p .707 .577 .707 r
F P
0 g
s
.22734 .63977 m .2399 .69516 L .2111 .7037 L p .707 .577 .707 r
F P
0 g
s
.2399 .69516 m .22734 .63977 L .25844 .63249 L p .707 .577 .707 r
F P
0 g
s
.25844 .63249 m .271 .68787 L .2399 .69516 L p .707 .577 .707 r
F P
0 g
s
.17179 .79028 m .17462 .77229 L .1985 .76883 L p .707 .577 .707 r
F P
0 g
s
.66648 .57952 m .67903 .6349 L .70567 .63208 L p .707 .577 .707 r
F P
0 g
s
.59716 .25256 m .59227 .7539 L .55351 .74726 L p .707 .577 .707 r
F P
0 g
s
.55351 .74726 m .5584 .24592 L .59716 .25256 L p .707 .577 .707 r
F P
0 g
s
.1985 .76883 m .19568 .78682 L .17179 .79028 L p .707 .577 .707 r
F P
0 g
s
.67903 .6349 m .66648 .57952 L .64616 .57957 L p .707 .577 .707 r
F P
0 g
s
.42308 .74931 m .42797 .24797 L .46945 .24351 L p .707 .577 .707 r
F P
0 g
s
.42797 .24797 m .42308 .74931 L .38912 .75709 L p .707 .577 .707 r
F P
0 g
s
.80705 .54659 m .8196 .60197 L .83584 .59346 L p .707 .577 .707 r
F P
0 g
s
.83584 .59346 m .82329 .53807 L .80705 .54659 L p .707 .577 .707 r
F P
0 g
s
.31702 .78821 m .31419 .8062 L .2871 .79705 L p .707 .577 .707 r
F P
0 g
s
.2871 .79705 m .28993 .77905 L .31702 .78821 L p .707 .577 .707 r
F P
0 g
s
.19568 .78682 m .1985 .76883 L .22762 .76886 L p .707 .577 .707 r
F P
0 g
s
.64616 .57957 m .65871 .63495 L .67903 .6349 L p .707 .577 .707 r
F P
0 g
s
.73925 .7537 m .73235 .7166 L .70173 .72063 L p .707 .577 .707 r
F P
0 g
s
.73235 .7166 m .73925 .7537 L .77059 .74756 L p .707 .577 .707 r
F P
0 g
s
.77059 .74756 m .76369 .71047 L .73235 .7166 L p .707 .577 .707 r
F P
0 g
s
.72223 .72691 m .72505 .70891 L .69425 .70225 L p .707 .577 .707 r
F P
0 g
s
.72505 .70891 m .72223 .72691 L .75373 .73043 L p .707 .577 .707 r
F P
0 g
s
.75373 .73043 m .75655 .71244 L .72505 .70891 L p .707 .577 .707 r
F P
0 g
s
.76369 .71047 m .77059 .74756 L .79957 .73994 L p .707 .577 .707 r
F P
0 g
s
.79957 .73994 m .79268 .70284 L .76369 .71047 L p .707 .577 .707 r
F P
0 g
s
.5584 .24592 m .55351 .74726 L .5095 .74415 L p .707 .577 .707 r
F P
0 g
s
.5095 .74415 m .51439 .24281 L .5584 .24592 L p .707 .577 .707 r
F P
0 g
s
.75655 .71244 m .75373 .73043 L .78285 .73046 L p .707 .577 .707 r
F P
0 g
s
.78285 .73046 m .78567 .71247 L .75655 .71244 L p .707 .577 .707 r
F P
0 g
s
.22762 .76886 m .2248 .78686 L .19568 .78682 L p .707 .577 .707 r
F P
0 g
s
.69143 .72024 m .69425 .70225 L .66716 .69309 L p .707 .577 .707 r
F P
0 g
s
.70173 .72063 m .70863 .75773 L .73925 .7537 L p .707 .577 .707 r
F P
0 g
s
.70863 .75773 m .70173 .72063 L .69696 .7209 L p .707 .577 .707 r
F P
0 g
s
.69425 .70225 m .69143 .72024 L .69698 .72144 L p .707 .577 .707 r
F P
0 g
s
.6965 .70423 m .69425 .70225 L .69698 .72144 L .707 .577 .707 r
F
.69696 .7209 m .67482 .72217 L p .69767 .74621 L F P
0 g
s
.70863 .75773 m .69696 .7209 L .69767 .74621 L .707 .577 .707 r
F
.69698 .72144 m .72223 .72691 L p .6965 .70423 L F P
0 g
s
.46456 .74485 m .46945 .24351 L .51439 .24281 L p .707 .577 .707 r
F P
0 g
s
.46945 .24351 m .46456 .74485 L .42308 .74931 L p .707 .577 .707 r
F P
0 g
s
.28993 .77905 m .2871 .79705 L .2563 .79038 L p .707 .577 .707 r
F P
0 g
s
.2563 .79038 m .25912 .77239 L .28993 .77905 L p .707 .577 .707 r
F P
0 g
s
.2248 .78686 m .22762 .76886 L .25912 .77239 L p .707 .577 .707 r
F P
0 g
s
.66716 .69309 m .66434 .71108 L .69143 .72024 L p .707 .577 .707 r
F P
0 g
s
.79268 .70284 m .79957 .73994 L .82337 .73156 L p .707 .577 .707 r
F P
0 g
s
.82337 .73156 m .81648 .69446 L .79268 .70284 L p .707 .577 .707 r
F P
0 g
s
.51439 .24281 m .5095 .74415 L .46456 .74485 L p .707 .577 .707 r
F P
0 g
s
.67482 .72217 m .68172 .75927 L .70863 .75773 L p .707 .577 .707 r
F P
0 g
s
.25912 .77239 m .2563 .79038 L .2248 .78686 L p .707 .577 .707 r
F P
0 g
s
.78567 .71247 m .78285 .73046 L .80674 .727 L p .707 .577 .707 r
F P
0 g
s
.80674 .727 m .80956 .70901 L .78567 .71247 L p .707 .577 .707 r
F P
0 g
s
.66434 .71108 m .66716 .69309 L .64643 .68234 L p .707 .577 .707 r
F P
0 g
s
.82329 .53807 m .83584 .59346 L .84306 .58624 L p .707 .577 .707 r
F P
0 g
s
.84306 .58624 m .8305 .53085 L .82329 .53807 L p .707 .577 .707 r
F P
0 g
s
.68172 .75927 m .67482 .72217 L .65427 .72107 L p .707 .577 .707 r
F P
0 g
s
.64643 .68234 m .64361 .70033 L .66434 .71108 L p .707 .577 .707 r
F P
0 g
s
.81648 .69446 m .82337 .73156 L .83966 .72325 L p .707 .577 .707 r
F P
0 g
s
.83966 .72325 m .83276 .68616 L .81648 .69446 L p .707 .577 .707 r
F P
0 g
s
.65427 .72107 m .66117 .75817 L .68172 .75927 L p .707 .577 .707 r
F P
0 g
s
.80956 .70901 m .80674 .727 L .82305 .72039 L p .707 .577 .707 r
F P
0 g
s
.82305 .72039 m .82587 .7024 L .80956 .70901 L p .707 .577 .707 r
F P
0 g
s
.64361 .70033 m .64643 .68234 L .6341 .67104 L p .707 .577 .707 r
F P
0 g
s
.6341 .67104 m .63128 .68903 L .64361 .70033 L p .707 .577 .707 r
F P
0 g
s
.66117 .75817 m .65427 .72107 L .64207 .71744 L p .707 .577 .707 r
F P
0 g
s
.8305 .53085 m .84306 .58624 L .84054 .58101 L p .707 .577 .707 r
F P
0 g
s
.84054 .58101 m .82798 .52563 L .8305 .53085 L p .707 .577 .707 r
F P
0 g
s
.63163 .57163 m .64418 .62701 L .6467 .63224 L p .707 .577 .707 r
F P
0 g
s
.64207 .71744 m .64897 .75453 L .66117 .75817 L p .707 .577 .707 r
F P
0 g
s
.83276 .68616 m .83966 .72325 L .84683 .71583 L p .707 .577 .707 r
F P
0 g
s
.84683 .71583 m .83993 .67873 L .83276 .68616 L p .707 .577 .707 r
F P
0 g
s
.82587 .7024 m .82305 .72039 L .83019 .71127 L p .707 .577 .707 r
F P
0 g
s
.83019 .71127 m .83301 .69328 L .82587 .7024 L p .707 .577 .707 r
F P
0 g
s
.63128 .68903 m .6341 .67104 L .63138 .66031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64418 .62701 m .63163 .57163 L .63884 .56441 L p .707 .577 .707 r
F P
0 g
s
.63138 .66031 m .62856 .6783 L .63128 .68903 L p .707 .577 .707 r
F P
0 g
s
.64897 .75453 m .64207 .71744 L .63943 .71162 L p .707 .577 .707 r
F P
0 g
s
.82798 .52563 m .84054 .58101 L .82853 .57829 L p .707 .577 .707 r
F P
0 g
s
.82853 .57829 m .81597 .52291 L .82798 .52563 L p .707 .577 .707 r
F P
0 g
s
.63884 .56441 m .6514 .61979 L .64418 .62701 L p .707 .577 .707 r
F P
0 g
s
.63943 .71162 m .64633 .74872 L .64897 .75453 L p .707 .577 .707 r
F P
0 g
s
.83993 .67873 m .84683 .71583 L .84418 .71001 L p .707 .577 .707 r
F P
0 g
s
.84418 .71001 m .83729 .67292 L .83993 .67873 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83301 .69328 m .83019 .71127 L .82746 .70054 L p .707 .577 .707 r
F P
0 g
s
.82746 .70054 m .83028 .68255 L .83301 .69328 L p .707 .577 .707 r
F P
0 g
s
.62856 .6783 m .63138 .66031 L .63852 .65119 L p .707 .577 .707 r
F P
0 g
s
.6514 .61979 m .63884 .56441 L .65508 .5559 L p .707 .577 .707 r
F P
0 g
s
.63852 .65119 m .6357 .66918 L .62856 .6783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39624 .63395 m .38934 .59685 L .35872 .60089 L p .707 .577 .707 r
F P
0 g
s
.35872 .60089 m .36562 .63799 L .39624 .63395 L p .707 .577 .707 r
F P
0 g
s
.39302 .63611 m .38047 .58073 L .35011 .58605 L p .707 .577 .707 r
F P
0 g
s
.38934 .59685 m .39624 .63395 L .42758 .62782 L p .707 .577 .707 r
F P
0 g
s
.42758 .62782 m .42068 .59072 L .38934 .59685 L p .707 .577 .707 r
F P
0 g
s
.38047 .58073 m .39302 .63611 L .42412 .62883 L p .707 .577 .707 r
F P
0 g
s
.42412 .62883 m .41157 .57345 L .38047 .58073 L p .707 .577 .707 r
F P
0 g
s
.42068 .59072 m .42758 .62782 L .45656 .62019 L p .707 .577 .707 r
F P
0 g
s
.45656 .62019 m .44967 .5831 L .42068 .59072 L p .707 .577 .707 r
F P
0 g
s
.41157 .57345 m .42412 .62883 L .45292 .62028 L p .707 .577 .707 r
F P
0 g
s
.45292 .62028 m .44036 .5649 L .41157 .57345 L p .707 .577 .707 r
F P
0 g
s
.64633 .74872 m .63943 .71162 L .6466 .7042 L p .707 .577 .707 r
F P
0 g
s
.81597 .52291 m .82853 .57829 L .80821 .57834 L p .707 .577 .707 r
F P
0 g
s
.80821 .57834 m .79566 .52296 L .81597 .52291 L p .707 .577 .707 r
F P
0 g
s
.65508 .5559 m .66764 .61128 L .6514 .61979 L p .707 .577 .707 r
F P
0 g
s
.36266 .64143 m .35011 .58605 L .32347 .58887 L p .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35872 .60089 L .35632 .60103 L p .707 .577 .707 r
F P
0 g
s
.35011 .58605 m .36266 .64143 L .36453 .6411 L p .707 .577 .707 r
F P
0 g
s
.35424 .59086 m .35011 .58605 L .36453 .6411 L .707 .577 .707 r
F
.32347 .58887 m .33602 .64425 L .36266 .64143 L p F P
0 g
s
.35632 .60103 m .33181 .60243 L p .36342 .63567 L .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35632 .60103 L .36342 .63567 L .707 .577 .707 r
F
.33181 .60243 m .33871 .63953 L .36562 .63799 L p F P
0 g
s
.36453 .6411 m .39302 .63611 L p .35424 .59086 L .707 .577 .707 r
F P
0 g
s
.6466 .7042 m .6535 .74129 L .64633 .74872 L p .707 .577 .707 r
F P
0 g
s
.83729 .67292 m .84418 .71001 L .83199 .70638 L p .707 .577 .707 r
F P
0 g
s
.83028 .68255 m .82746 .70054 L .81513 .68924 L p .707 .577 .707 r
F P
0 g
s
.81513 .68924 m .81795 .67125 L .83028 .68255 L p .707 .577 .707 r
F P
0 g
s
.83199 .70638 m .82509 .66928 L .83729 .67292 L p .707 .577 .707 r
F P
0 g
s
.44967 .5831 m .45656 .62019 L .48036 .61182 L p .707 .577 .707 r
F P
0 g
s
.48036 .61182 m .47347 .57472 L .44967 .5831 L p .707 .577 .707 r
F P
0 g
s
.44036 .5649 m .45292 .62028 L .4766 .61132 L p .707 .577 .707 r
F P
0 g
s
.4766 .61132 m .46404 .55594 L .44036 .5649 L p .707 .577 .707 r
F P
0 g
s
.6357 .66918 m .63852 .65119 L .65483 .64457 L p .707 .577 .707 r
F P
0 g
s
.66764 .61128 m .65508 .5559 L .67876 .54693 L p .707 .577 .707 r
F P
0 g
s
.33602 .64425 m .32347 .58887 L .30315 .58892 L p .707 .577 .707 r
F P
0 g
s
.33871 .63953 m .33181 .60243 L .31126 .60133 L p .707 .577 .707 r
F P
0 g
s
.65483 .64457 m .65201 .66257 L .6357 .66918 L p .707 .577 .707 r
F P
0 g
s
.79566 .52296 m .80821 .57834 L .78157 .58117 L p .707 .577 .707 r
F P
0 g
s
.78157 .58117 m .76901 .52579 L .79566 .52296 L p .707 .577 .707 r
F P
0 g
s
.47347 .57472 m .48036 .61182 L .49665 .60351 L p .707 .577 .707 r
F P
0 g
s
.49665 .60351 m .48975 .56641 L .47347 .57472 L p .707 .577 .707 r
F P
0 g
s
.46404 .55594 m .4766 .61132 L .49284 .60281 L p .707 .577 .707 r
F P
0 g
s
.49284 .60281 m .48028 .54742 L .46404 .55594 L p .707 .577 .707 r
F P
0 g
s
.6535 .74129 m .6466 .7042 L .66288 .69589 L p .707 .577 .707 r
F P
0 g
s
.67876 .54693 m .69131 .60231 L .66764 .61128 L p .707 .577 .707 r
F P
0 g
s
.30315 .58892 m .3157 .6443 L .33602 .64425 L p .707 .577 .707 r
F P
0 g
s
.31126 .60133 m .31816 .63843 L .33871 .63953 L p .707 .577 .707 r
F P
0 g
s
.66288 .69589 m .66978 .73299 L .6535 .74129 L p .707 .577 .707 r
F P
0 g
s
.82509 .66928 m .83199 .70638 L .81143 .70528 L p .707 .577 .707 r
F P
0 g
s
.81795 .67125 m .81513 .68924 L .79441 .67849 L p .707 .577 .707 r
F P
0 g
s
.79441 .67849 m .79723 .6605 L .81795 .67125 L p .707 .577 .707 r
F P
0 g
s
.81143 .70528 m .80453 .66818 L .82509 .66928 L p .707 .577 .707 r
F P
0 g
s
.69131 .60231 m .67876 .54693 L .70756 .53839 L p .707 .577 .707 r
F P
0 g
s
.37922 .76258 m .38204 .74459 L .35124 .73792 L p .707 .577 .707 r
F P
0 g
s
.38204 .74459 m .37922 .76258 L .41072 .76611 L p .707 .577 .707 r
F P
0 g
s
.41072 .76611 m .41354 .74811 L .38204 .74459 L p .707 .577 .707 r
F P
0 g
s
.76901 .52579 m .78157 .58117 L .75121 .58648 L p .707 .577 .707 r
F P
0 g
s
.75121 .58648 m .73866 .5311 L .76901 .52579 L p .707 .577 .707 r
F P
0 g
s
.65201 .66257 m .65483 .64457 L .67871 .64112 L p .707 .577 .707 r
F P
0 g
s
.41354 .74811 m .41072 .76611 L .43984 .76614 L p .707 .577 .707 r
F P
0 g
s
.43984 .76614 m .44266 .74815 L .41354 .74811 L p .707 .577 .707 r
F P
0 g
s
.34842 .75592 m .35124 .73792 L .32415 .72877 L p .707 .577 .707 r
F P
0 g
s
.35124 .73792 m .34842 .75592 L .37922 .76258 L p .707 .577 .707 r
F P
0 g
s
.3157 .6443 m .30315 .58892 L .29114 .5862 L p .707 .577 .707 r
F P
0 g
s
.31816 .63843 m .31126 .60133 L .29906 .59769 L p .707 .577 .707 r
F P
0 g
s
.70756 .53839 m .72011 .59377 L .69131 .60231 L p .707 .577 .707 r
F P
0 g
s
.72011 .59377 m .70756 .53839 L .73866 .5311 L p .707 .577 .707 r
F P
0 g
s
.67871 .64112 m .67589 .65911 L .65201 .66257 L p .707 .577 .707 r
F P
0 g
s
.73866 .5311 m .75121 .58648 L .72011 .59377 L p .707 .577 .707 r
F P
0 g
s
.32415 .72877 m .32133 .74676 L .34842 .75592 L p .707 .577 .707 r
F P
0 g
s
.48975 .56641 m .49665 .60351 L .50382 .59609 L p .707 .577 .707 r
F P
0 g
s
.48028 .54742 m .49284 .60281 L .50005 .59559 L p .707 .577 .707 r
F P
0 g
s
.50382 .59609 m .49692 .55899 L .48975 .56641 L p .707 .577 .707 r
F P
0 g
s
.50005 .59559 m .48749 .5402 L .48028 .54742 L p .707 .577 .707 r
F P
0 g
s
.29114 .5862 m .30369 .64159 L .3157 .6443 L p .707 .577 .707 r
F P
0 g
s
.29906 .59769 m .30596 .63479 L .31816 .63843 L p .707 .577 .707 r
F P
0 g
s
.66978 .73299 m .66288 .69589 L .68668 .68751 L p .707 .577 .707 r
F P
0 g
s
.44266 .74815 m .43984 .76614 L .46373 .76268 L p .707 .577 .707 r
F P
0 g
s
.46373 .76268 m .46655 .74469 L .44266 .74815 L p .707 .577 .707 r
F P
0 g
s
.32133 .74676 m .32415 .72877 L .30342 .71801 L p .707 .577 .707 r
F P
0 g
s
.80453 .66818 m .81143 .70528 L .78452 .70682 L p .707 .577 .707 r
F P
0 g
s
.79723 .6605 m .79441 .67849 L .7722 .67098 L p .707 .577 .707 r
F P
0 g
s
.77218 .66789 m .79723 .6605 L .7722 .67098 L .707 .577 .707 r
F
.7539 .71085 m .747 .67375 L .77762 .66972 L p F P
0 g
s
.7722 .67098 m .76732 .66933 L p .77218 .66789 L .707 .577 .707 r
F P
0 g
s
.77762 .66972 m .78452 .70682 L .77244 .70841 L p .707 .577 .707 r
F P
0 g
s
.77244 .70841 m .7539 .71085 L p .77225 .67903 L .707 .577 .707 r
F P
0 g
s
.77225 .67903 m .77762 .66972 L .77244 .70841 L .707 .577 .707 r
F
.78452 .70682 m .77762 .66972 L .80453 .66818 L p F P
0 g
s
.68668 .68751 m .69358 .72461 L .66978 .73299 L p .707 .577 .707 r
F P
0 g
s
.76732 .66933 m .77014 .65134 L .79723 .6605 L p .707 .577 .707 r
F P
0 g
s
.67589 .65911 m .67871 .64112 L .70783 .64115 L p .707 .577 .707 r
F P
0 g
s
.30342 .71801 m .3006 .736 L .32133 .74676 L p .707 .577 .707 r
F P
0 g
s
.70783 .64115 m .70501 .65914 L .67589 .65911 L p .707 .577 .707 r
F P
0 g
s
.69358 .72461 m .68668 .68751 L .71567 .67988 L p .707 .577 .707 r
F P
0 g
s
.30596 .63479 m .29906 .59769 L .29642 .59188 L p .707 .577 .707 r
F P
0 g
s
.30369 .64159 m .29114 .5862 L .28862 .58098 L p .707 .577 .707 r
F P
0 g
s
.77014 .65134 m .76732 .66933 L .73651 .66266 L p .707 .577 .707 r
F P
0 g
s
.73651 .66266 m .73934 .64467 L .77014 .65134 L p .707 .577 .707 r
F P
0 g
s
.70501 .65914 m .70783 .64115 L .73934 .64467 L p .707 .577 .707 r
F P
0 g
s
.46655 .74469 m .46373 .76268 L .48004 .75607 L p .707 .577 .707 r
F P
0 g
s
.48004 .75607 m .48286 .73808 L .46655 .74469 L p .707 .577 .707 r
F P
0 g
s
.71567 .67988 m .72256 .71698 L .69358 .72461 L p .707 .577 .707 r
F P
0 g
s
.73934 .64467 m .73651 .66266 L .70501 .65914 L p .707 .577 .707 r
F P
0 g
s
.3006 .736 m .30342 .71801 L .29109 .70672 L p .707 .577 .707 r
F P
0 g
s
.29642 .59188 m .30331 .62898 L .30596 .63479 L p .707 .577 .707 r
F P
0 g
s
.48749 .5402 m .50005 .59559 L .49753 .59036 L p .707 .577 .707 r
F P
0 g
s
.49753 .59036 m .48497 .53498 L .48749 .5402 L p .707 .577 .707 r
F P
0 g
s
.72256 .71698 m .71567 .67988 L .747 .67375 L p .707 .577 .707 r
F P
0 g
s
.49692 .55899 m .50382 .59609 L .50117 .59027 L p .707 .577 .707 r
F P
0 g
s
.50117 .59027 m .49427 .55317 L .49692 .55899 L p .707 .577 .707 r
F P
0 g
s
.28862 .58098 m .30117 .63636 L .30369 .64159 L p .707 .577 .707 r
F P
0 g
s
.747 .67375 m .7539 .71085 L .72256 .71698 L p .707 .577 .707 r
F P
0 g
s
.29109 .70672 m .28827 .72471 L .3006 .736 L p .707 .577 .707 r
F P
0 g
s
.48286 .73808 m .48004 .75607 L .48718 .74695 L p .707 .577 .707 r
F P
0 g
s
.48718 .74695 m .49 .72896 L .48286 .73808 L p .707 .577 .707 r
F P
0 g
s
.30331 .62898 m .29642 .59188 L .30359 .58445 L p .707 .577 .707 r
F P
0 g
s
.30117 .63636 m .28862 .58098 L .29583 .57376 L p .707 .577 .707 r
F P
0 g
s
.28827 .72471 m .29109 .70672 L .28837 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30359 .58445 m .31049 .62155 L .30331 .62898 L p .707 .577 .707 r
F P
0 g
s
.48497 .53498 m .49753 .59036 L .48552 .58764 L p .707 .577 .707 r
F P
0 g
s
.48552 .58764 m .47296 .53226 L .48497 .53498 L p .707 .577 .707 r
F P
0 g
s
.28837 .69598 m .28555 .71398 L .28827 .72471 L p .707 .577 .707 r
F P
0 g
s
.49427 .55317 m .50117 .59027 L .48898 .58663 L p .707 .577 .707 r
F P
0 g
s
.48898 .58663 m .48208 .54954 L .49427 .55317 L p .707 .577 .707 r
F P
0 g
s
.29583 .57376 m .30839 .62914 L .30117 .63636 L p .707 .577 .707 r
F P
0 g
s
.49 .72896 m .48718 .74695 L .48445 .73621 L p .707 .577 .707 r
F P
0 g
s
.48445 .73621 m .48727 .71822 L .49 .72896 L p .707 .577 .707 r
F P
0 g
s
.31049 .62155 m .30359 .58445 L .31987 .57615 L p .707 .577 .707 r
F P
0 g
s
.30839 .62914 m .29583 .57376 L .31207 .56525 L p .707 .577 .707 r
F P
0 g
s
.28555 .71398 m .28837 .69598 L .29551 .68686 L p .707 .577 .707 r
F P
0 g
s
.31987 .57615 m .32677 .61324 L .31049 .62155 L p .707 .577 .707 r
F P
0 g
s
.47296 .53226 m .48552 .58764 L .4652 .58769 L p .707 .577 .707 r
F P
0 g
s
.4652 .58769 m .45265 .53231 L .47296 .53226 L p .707 .577 .707 r
F P
0 g
s
.29551 .68686 m .29269 .70486 L .28555 .71398 L p .707 .577 .707 r
F P
0 g
s
.48208 .54954 m .48898 .58663 L .46842 .58553 L p .707 .577 .707 r
F P
0 g
s
.46842 .58553 m .46152 .54844 L .48208 .54954 L p .707 .577 .707 r
F P
0 g
s
.31207 .56525 m .32462 .62063 L .30839 .62914 L p .707 .577 .707 r
F P
0 g
s
.32677 .61324 m .31987 .57615 L .34367 .56777 L p .707 .577 .707 r
F P
0 g
s
.32462 .62063 m .31207 .56525 L .33575 .55628 L p .707 .577 .707 r
F P
0 g
s
.48727 .71822 m .48445 .73621 L .47212 .72492 L p .707 .577 .707 r
F P
0 g
s
.47212 .72492 m .47494 .70693 L .48727 .71822 L p .707 .577 .707 r
F P
0 g
s
.29269 .70486 m .29551 .68686 L .31182 .68025 L p .707 .577 .707 r
F P
0 g
s
.45265 .53231 m .4652 .58769 L .44019 .59034 L p .707 .577 .707 r
F P
0 g
s
.43946 .5868 m .45265 .53231 L .44019 .59034 L .707 .577 .707 r
F
.43957 .58733 m .41089 .59111 L p .43255 .55355 L F P
0 g
s
.41089 .59111 m .40399 .55401 L .43188 .55034 L p .707 .577 .707 r
F P
0 g
s
.41089 .59111 m .43188 .55034 L .43255 .55355 L .707 .577 .707 r
F
.43856 .59052 m .426 .53513 L .42867 .53485 L p F P
0 g
s
.42867 .53485 m .45265 .53231 L p .43946 .5868 L .707 .577 .707 r
F P
0 g
s
.43856 .59052 m .42867 .53485 L .43946 .5868 L .707 .577 .707 r
F
.43188 .55034 m .43461 .54998 L p .43255 .55355 L F P
0 g
s
.43461 .54998 m .44151 .58708 L .43957 .58733 L p .707 .577 .707 r
F P
0 g
s
.43255 .55355 m .43461 .54998 L .43957 .58733 L .707 .577 .707 r
F
.44019 .59034 m .43856 .59052 L p .43946 .5868 L F P
0 g
s
.46152 .54844 m .46842 .58553 L .44151 .58708 L p .707 .577 .707 r
F P
0 g
s
.44151 .58708 m .43461 .54998 L .46152 .54844 L p .707 .577 .707 r
F P
0 g
s
.34367 .56777 m .35057 .60487 L .32677 .61324 L p .707 .577 .707 r
F P
0 g
s
.33575 .55628 m .3483 .61166 L .32462 .62063 L p .707 .577 .707 r
F P
0 g
s
.31182 .68025 m .309 .69824 L .29269 .70486 L p .707 .577 .707 r
F P
0 g
s
.35057 .60487 m .34367 .56777 L .37266 .56014 L p .707 .577 .707 r
F P
0 g
s
.3483 .61166 m .33575 .55628 L .36455 .54774 L p .707 .577 .707 r
F P
0 g
s
.40399 .55401 m .41089 .59111 L .37955 .59724 L p .707 .577 .707 r
F P
0 g
s
.426 .53513 m .43856 .59052 L .4082 .59583 L p .707 .577 .707 r
F P
0 g
s
.37955 .59724 m .37266 .56014 L .40399 .55401 L p .707 .577 .707 r
F P
0 g
s
.4082 .59583 m .39565 .54045 L .426 .53513 L p .707 .577 .707 r
F P
0 g
s
.37266 .56014 m .37955 .59724 L .35057 .60487 L p .707 .577 .707 r
F P
0 g
s
.47494 .70693 m .47212 .72492 L .4514 .71416 L p .707 .577 .707 r
F P
0 g
s
.4514 .71416 m .45422 .69617 L .47494 .70693 L p .707 .577 .707 r
F P
0 g
s
.36455 .54774 m .3771 .60312 L .3483 .61166 L p .707 .577 .707 r
F P
0 g
s
.3771 .60312 m .36455 .54774 L .39565 .54045 L p .707 .577 .707 r
F P
0 g
s
.39565 .54045 m .4082 .59583 L .3771 .60312 L p .707 .577 .707 r
F P
0 g
s
.309 .69824 m .31182 .68025 L .3357 .67679 L p .707 .577 .707 r
F P
0 g
s
.3357 .67679 m .33288 .69478 L .309 .69824 L p .707 .577 .707 r
F P
0 g
s
.45422 .69617 m .4514 .71416 L .42431 .70501 L p .707 .577 .707 r
F P
0 g
s
.42431 .70501 m .42713 .68701 L .45422 .69617 L p .707 .577 .707 r
F P
0 g
s
.33288 .69478 m .3357 .67679 L .36482 .67683 L p .707 .577 .707 r
F P
0 g
s
.36482 .67683 m .362 .69482 L .33288 .69478 L p .707 .577 .707 r
F P
0 g
s
.42713 .68701 m .42431 .70501 L .3935 .69834 L p .707 .577 .707 r
F P
0 g
s
.3935 .69834 m .39632 .68035 L .42713 .68701 L p .707 .577 .707 r
F P
0 g
s
.362 .69482 m .36482 .67683 L .39632 .68035 L p .707 .577 .707 r
F P
0 g
s
.39632 .68035 m .3935 .69834 L .362 .69482 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol007=oo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00Kgoo
10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
00000P00Kgoo001]Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001/Ool006]oo`8000=JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06Yoo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00J7oo001XOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001TOol006Io
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<002Ioo`X003Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`007goo1`000eYF00<005YFFUH00UYF00<005YF
00000P00<Goo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`006goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80031oo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF009JEP/000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<001Moo`@000IJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EUYF001JEP0`Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP03FUH0
1000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0057oo100000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00IGoo00@005YFFUH000EJEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;goo001U
Ool01@00FUIJEP00FUH010000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000_Ool006Eoo`D000IJEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH005YF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool006Aoo`800003FUH005YF00QJEP03001JEUYF00IJEPH000=JEP03001JEUYF00H0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<0
00UJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
008002moo`00HGoo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF
00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Aoo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002moo`00GWoo0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0025YF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000_Ool005Yo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001JEUYF
009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Qoo`8000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001GOol20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20007FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001EOol2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00
FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF2`0000=JEP000000;Goo001BOol00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP02FUH4000]Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH@0002FUH01000FUIJEP002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUHE00000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00;Woo001BOol200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YFFUH00eYF00<007ooOol0;Goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00=JEP8000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF0080031oo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP05
FUH00`00FUH000020006FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000bOol005=oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF100025YF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00=7oo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00IJEP03001JEP00008003Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF1@001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000015YF0`001eYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF0`00>Goo
001DOol00`00FUH00004FUH20003FUH2000<FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P0000=JEP00000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP8003aoo`00E7oo00<005YF00001EYF00@005YF000000iJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP00008003ioo`00E7oo00@005YFFUH000=JEP<00003FUH005YF00eJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00EJEP@0045oo`00E7oo00D005YFFUH005YF008000AJEP03001JEUYF00aJEP03001JEUYF00MJ
EP03001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool004ioo`L0009JEP<000EJEP03001JEUYF00eJEP<000AJEPH000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPL004Uoo`00Agoo1`0015YF00D005YFFUIJ
EP0000=JEP03001JEUYF00=JEP03001JEUYF00]JEPT00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP04001JEUYFFUH8001@Ool004=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEUYF00]JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000`005Ioo`00
?goo10001UYF00<005YFFUH01eYF00D005YF000005YF00l000=JEPT000EJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00AJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00?Goo0P0000=JEP00FUH025YF00<005YFFUH0
1UYF1@0000=JEP00FUH015YF00<005YFFUH00UYF1P0015YF10001UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF
00<005YF00003`00Cgoo000jOol30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH>0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH60019Ool003Moo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030015
Ool003=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@0045oo`00
<Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
03eoo`00<7oo0P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Woo000^Ool200000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH500000eYF
001JEP03FUH00`00FUIJEP020005Ool70006FUH00`00FUIJEP05FUH3000hOol002eoo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00800003
FUH0000000IJEP03001JEUYF00=JEP04001JEUYF0009Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP02000fOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EP00FUH200000eYF001JEP02FUH;00000eYF00000007Ool50003OolD000aOol002]oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003
FUH00000008000EJEP03001JEUYF009JEP@000Moo`T000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP00000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUHA0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P0000AJ
EP00FUH000IJEP03001JEUYF00=JEP03001JEP0000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH000000UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF0P000Woo1000
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00:goo0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF
1`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYF0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH70002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF10001UYF1@001EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF0080009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF10002EYF0P000UYF00@005YFFUH000=JEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00001EYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF0P0015YF0P000eYF00<005YFFUH01eYF0P0000=JEP00FUH00UYF100015YF00@005YF
FUIJEP<0009JEP03001JEUYF00L000IJEP03001JEUYF00IJEP@000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]Ool002ao
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP07FUH200000eYF
001JEP0200000eYF001JEP06FUH400001Goo001JEUYF00001EYF00@005YFFUIJEP@0009JEP03001J
EUYF00IJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH0
0004FUH20005FUH30009FUH00`00FUIJEP06FUH200000eYF00000004FUH00`00FUIJEP03FUH30003
Ool01000FUIJEP001EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0P002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF4@0000=JEP00Ool0;7oo000]Ool0
0`00FUH00005FUH00`00FUH00003000<FUH00`00FUIJEP06FUH40005FUH00`00FUH000040005Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001JEP0000@0009J
EP800003FUH00000008002aoo`00;Goo00<005YF00001EYF0P0000=JEP00FUH03EYF00<005YFFUH0
1eYF0P0000=JEP00FUH00UYF10002Goo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003
FUH02@00FUIJEP00FUH005YF001JEP02000/Ool002eoo`04001JEUYF0002FUH20003FUH00`00FUIJ
EP0<FUH00`00FUIJEP07FUH01000FUIJEUYF100037oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00AJEP8000IJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH80003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0000/Ool002eoo`03001J
EUYF00<000EJEP03001JEUYF00aJEP03001JEUYF00IJEP8000AJEP03001oogoo00aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH005YFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF000015YF0P00;Goo000^Ool2FUH01000FUIJEP0015YF00<005YFFUH03EYF0`000UYF
0`0000=oo`00FUH00eYF0`0037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP80
0003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00D00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00008000AJEP03001oogoo02aoo`00
;Woo00=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH02eYF1P0017oo00<005YFFUH00UYF00<0
05YFFUH00P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP<000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
00AJEP03001JEUYF00=JEP@0009JEP/00003FUH005YF00IJEP04001JEUYFFUH50003FUH01000FUIJ
EP00;goo000^Ool200000eYF000000030003FUH01000FUIJEUYF0`001EYF1`001Woo00@005YFFUH0
00EJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH02000FUIJEP00FUH0
05YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUH000030004FUH00`00FUIJEP06FUHB0007FUH3000`Ool002moo`800003
FUH005YF009JEPl0009oo`D000Moo`<000IJEP03001JEP0000<000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUIJEP@000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80039oo`00<Goo30002goo
0`002Woo00<005YFFUH015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000dOol005Ioo`8000=JEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEP00001J
EP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
0`00>7oo001HOol200000eYF001JEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH50003
FUH>0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@003]oo`00FWoo0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00H005YFFUIJEP00FUH2000;FUH90008FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00mJEP03001JEUYF
00AJEPD003moo`00GGoo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040014Ool0065oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70018Ool006Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02
FUH00`00FUH00002FUHD001?Ool006Eoo`03001JEUYF00P000AJEP03001JEUYF00IJEP04001JEUYF
FUH40006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH0
0`00FUH0000=001HOol006Eoo`05001JEUYF001JEP020004FUHA000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00001EYF00<005YFFUH00eYF00@0
05YF000005Ioo`00=Goo400087oo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF001FOol0035oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL001Uoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003
FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001EOol002moo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@001Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH005YF00EJEP03001JEUYF00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0015oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000/Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000003goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF00=JEP03001J
EUYF008005Aoo`00:goo00<005YF00000UYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP04001J
EUYFFUH3000<Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YF
FUH00eYF00<005YFFUH00P00E7oo000ZOol00`00FUH00003FUH4000@Ool70006FUH00`00FUIJEP05
FUH2000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<0
05YFFUH00UYF00<005YFFUH00P00E7oo000ZOol01000FUH005YF0P006goo10000UYF00<005YFFUH0
1UYF0`002Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01UYF
00<005YFFUH00eYF00@005YF000005Aoo`00:Woo00@005YF0000025oo`@000MJEP03001JEUYF0080
00Qoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEPH000=JEP04001J
EUYF001DOol002Yoo`8002Moo`8000AJEP03001JEUYF00=JEP8000Qoo`<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EPh00003FUH0000000<00003FUH0000005=oo`00:Woo0`00:7oo0`0000=JEP00FUH01EYF0P002Goo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP/000=JEP07001JEUYF001JEP00FUH01000Dgoo000ZOol200000eYF0000
000YOol20006FUH00`00FUH0000:Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001eYF00<005YFFUH015YF00<005YF
FUH00P000eYF00<005YF0000Dgoo000ZOol00`00FUIJEP02FUH00`00Oomoo`0XOol20003FUH01@00
FUIJEUYF00002goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF1@0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP80
05Aoo`00:Woo00<005YFFUH00UYF0`00:Woo0P0000=JEP00FUH00UYF00<007ooOol037oo1`001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0200000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00P0015YF00<007ooOol0Dgoo000ZOol00`00FUIJEP02FUH00`00
FUIJEP02000ZOol20003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH@00000eYF
001JEP06FUH01000FUIJEUYF1P000UYF00@005YFFUH005Ioo`00:goo00@005YFFUH000EJEP<002Uo
o`05001JEP00FUH0000POolI0002FUH00`00FUIJEP06FUHC0007FUH3001GOol002aoo`<000IJEP03
001JEP0000<002Ioo`800003FUH007oo02Uoo`04001JEUYF0003FUH40007FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001IOol002ioo`03001JEUYF00AJEP03001JEUYF
00=JEP@002=oo`03001JEP0002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001KOol002moo`8000=JEP03001J
EUYF00EJEP03001JEUYF00@001eoo`@002]oo`03001JEUYF008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<005moo`00<Goo0P0000=JEP00FUH01UYF00<0
05YFFUH015YF1`0047oo1P000UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00@0069oo`00<goo0`001UYF00<005YFFUH01UYF00<005YF
FUH00UYF40000eYF00<005YFFUH00UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00mJEP03001J
EUYF00AJEPD006Ioo`00=Woo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8002eoo`80009JEP03001JEUYF009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00@006]oo`00>7oo0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo0P0000=JEP00FUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF1`00Kgoo000kOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00<Goo10000eYF00<005YFFUH00UYF2000MWoo000nOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000=goo2000OWoo0012
Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000_goo0019OolA0033Ool00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59883 .7188 m .58627 .66342 L .55592 .66873 L p .707 .577 .707 r
F P
0 g
s
.58627 .66342 m .59883 .7188 L .62992 .71152 L p .707 .577 .707 r
F P
0 g
s
.62992 .71152 m .61737 .65613 L .58627 .66342 L p .707 .577 .707 r
F P
0 g
s
.61737 .65613 m .62992 .71152 L .65872 .70297 L p .707 .577 .707 r
F P
0 g
s
.65872 .70297 m .64617 .64759 L .61737 .65613 L p .707 .577 .707 r
F P
0 g
s
.56847 .72412 m .55592 .66873 L .52927 .67156 L p .707 .577 .707 r
F P
0 g
s
.55592 .66873 m .56847 .72412 L .59883 .7188 L p .707 .577 .707 r
F P
0 g
s
.64617 .64759 m .65872 .70297 L .6824 .69401 L p .707 .577 .707 r
F P
0 g
s
.6824 .69401 m .66985 .63862 L .64617 .64759 L p .707 .577 .707 r
F P
0 g
s
.52927 .67156 m .54183 .72694 L .56847 .72412 L p .707 .577 .707 r
F P
0 g
s
.54183 .72694 m .52927 .67156 L .50896 .67161 L p .707 .577 .707 r
F P
0 g
s
.66985 .63862 m .6824 .69401 L .69864 .6855 L p .707 .577 .707 r
F P
0 g
s
.69864 .6855 m .68609 .63011 L .66985 .63862 L p .707 .577 .707 r
F P
0 g
s
.50896 .67161 m .52151 .72699 L .54183 .72694 L p .707 .577 .707 r
F P
0 g
s
.60205 .84573 m .59515 .80864 L .56453 .81267 L p .707 .577 .707 r
F P
0 g
s
.59515 .80864 m .60205 .84573 L .63338 .8396 L p .707 .577 .707 r
F P
0 g
s
.63338 .8396 m .62648 .80251 L .59515 .80864 L p .707 .577 .707 r
F P
0 g
s
.58503 .81894 m .58785 .80095 L .55704 .79429 L p .707 .577 .707 r
F P
0 g
s
.58785 .80095 m .58503 .81894 L .61653 .82247 L p .707 .577 .707 r
F P
0 g
s
.61653 .82247 m .61935 .80447 L .58785 .80095 L p .707 .577 .707 r
F P
0 g
s
.62648 .80251 m .63338 .8396 L .66237 .83198 L p .707 .577 .707 r
F P
0 g
s
.66237 .83198 m .65547 .79488 L .62648 .80251 L p .707 .577 .707 r
F P
0 g
s
.61935 .80447 m .61653 .82247 L .64565 .8225 L p .707 .577 .707 r
F P
0 g
s
.64565 .8225 m .64847 .80451 L .61935 .80447 L p .707 .577 .707 r
F P
0 g
s
.55422 .81228 m .55704 .79429 L .52995 .78513 L p .707 .577 .707 r
F P
0 g
s
.56453 .81267 m .57142 .84977 L .60205 .84573 L p .707 .577 .707 r
F P
0 g
s
.57142 .84977 m .56453 .81267 L .55976 .81294 L p .707 .577 .707 r
F P
0 g
s
.55704 .79429 m .55422 .81228 L .55977 .81348 L p .707 .577 .707 r
F P
0 g
s
.55929 .79627 m .55704 .79429 L .55977 .81348 L .707 .577 .707 r
F
.55976 .81294 m .53762 .81421 L p .56047 .83824 L F P
0 g
s
.57142 .84977 m .55976 .81294 L .56047 .83824 L .707 .577 .707 r
F
.55977 .81348 m .58503 .81894 L p .55929 .79627 L F P
0 g
s
.52995 .78513 m .52713 .80312 L .55422 .81228 L p .707 .577 .707 r
F P
0 g
s
.65547 .79488 m .66237 .83198 L .68617 .8236 L p .707 .577 .707 r
F P
0 g
s
.68617 .8236 m .67927 .7865 L .65547 .79488 L p .707 .577 .707 r
F P
0 g
s
.52151 .72699 m .50896 .67161 L .49695 .66889 L p .707 .577 .707 r
F P
0 g
s
.53762 .81421 m .54452 .85131 L .57142 .84977 L p .707 .577 .707 r
F P
0 g
s
.64847 .80451 m .64565 .8225 L .66953 .81904 L p .707 .577 .707 r
F P
0 g
s
.66953 .81904 m .67235 .80105 L .64847 .80451 L p .707 .577 .707 r
F P
0 g
s
.52713 .80312 m .52995 .78513 L .50923 .77437 L p .707 .577 .707 r
F P
0 g
s
.68609 .63011 m .69864 .6855 L .70585 .67827 L p .707 .577 .707 r
F P
0 g
s
.70585 .67827 m .6933 .62289 L .68609 .63011 L p .707 .577 .707 r
F P
0 g
s
.49695 .66889 m .5095 .72427 L .52151 .72699 L p .707 .577 .707 r
F P
0 g
s
.54452 .85131 m .53762 .81421 L .51706 .81311 L p .707 .577 .707 r
F P
0 g
s
.50923 .77437 m .50641 .79237 L .52713 .80312 L p .707 .577 .707 r
F P
0 g
s
.67927 .7865 m .68617 .8236 L .70245 .81529 L p .707 .577 .707 r
F P
0 g
s
.70245 .81529 m .69555 .77819 L .67927 .7865 L p .707 .577 .707 r
F P
0 g
s
.51706 .81311 m .52396 .85021 L .54452 .85131 L p .707 .577 .707 r
F P
0 g
s
.67235 .80105 m .66953 .81904 L .68584 .81243 L p .707 .577 .707 r
F P
0 g
s
.68584 .81243 m .68866 .79444 L .67235 .80105 L p .707 .577 .707 r
F P
0 g
s
.50641 .79237 m .50923 .77437 L .4969 .76308 L p .707 .577 .707 r
F P
0 g
s
.5095 .72427 m .49695 .66889 L .49443 .66367 L p .707 .577 .707 r
F P
0 g
s
.4969 .76308 m .49408 .78107 L .50641 .79237 L p .707 .577 .707 r
F P
0 g
s
.52396 .85021 m .51706 .81311 L .50487 .80947 L p .707 .577 .707 r
F P
0 g
s
.6933 .62289 m .70585 .67827 L .70333 .67305 L p .707 .577 .707 r
F P
0 g
s
.70333 .67305 m .69078 .61767 L .6933 .62289 L p .707 .577 .707 r
F P
0 g
s
.49443 .66367 m .50698 .71905 L .5095 .72427 L p .707 .577 .707 r
F P
0 g
s
.50487 .80947 m .51176 .84657 L .52396 .85021 L p .707 .577 .707 r
F P
0 g
s
.69555 .77819 m .70245 .81529 L .70962 .80787 L p .707 .577 .707 r
F P
0 g
s
.70962 .80787 m .70272 .77077 L .69555 .77819 L p .707 .577 .707 r
F P
0 g
s
.68866 .79444 m .68584 .81243 L .69298 .80331 L p .707 .577 .707 r
F P
0 g
s
.69298 .80331 m .6958 .78532 L .68866 .79444 L p .707 .577 .707 r
F P
0 g
s
.49037 .82225 m .49526 .32091 L .45125 .3178 L p .707 .577 .707 r
F P
0 g
s
.49408 .78107 m .4969 .76308 L .49417 .75234 L p .707 .577 .707 r
F P
0 g
s
.50698 .71905 m .49443 .66367 L .50164 .65644 L p .707 .577 .707 r
F P
0 g
s
.49417 .75234 m .49135 .77034 L .49408 .78107 L p .707 .577 .707 r
F P
0 g
s
.51176 .84657 m .50487 .80947 L .50222 .80366 L p .707 .577 .707 r
F P
0 g
s
.50164 .65644 m .51419 .71183 L .50698 .71905 L p .707 .577 .707 r
F P
0 g
s
.50222 .80366 m .50912 .84076 L .51176 .84657 L p .707 .577 .707 r
F P
0 g
s
.49135 .77034 m .49417 .75234 L .50131 .74323 L p .707 .577 .707 r
F P
0 g
s
.51419 .71183 m .50164 .65644 L .51788 .64793 L p .707 .577 .707 r
F P
0 g
s
.50131 .74323 m .49849 .76122 L .49135 .77034 L p .707 .577 .707 r
F P
0 g
s
.50912 .84076 m .50222 .80366 L .50939 .79623 L p .707 .577 .707 r
F P
0 g
s
.51788 .64793 m .53043 .70332 L .51419 .71183 L p .707 .577 .707 r
F P
0 g
s
.50939 .79623 m .51629 .83333 L .50912 .84076 L p .707 .577 .707 r
F P
0 g
s
.49849 .76122 m .50131 .74323 L .51763 .73661 L p .707 .577 .707 r
F P
0 g
s
.53043 .70332 m .51788 .64793 L .54156 .63897 L p .707 .577 .707 r
F P
0 g
s
.51763 .73661 m .5148 .7546 L .49849 .76122 L p .707 .577 .707 r
F P
0 g
s
.51629 .83333 m .50939 .79623 L .52568 .78793 L p .707 .577 .707 r
F P
0 g
s
.52568 .78793 m .53257 .82502 L .51629 .83333 L p .707 .577 .707 r
F P
0 g
s
.5148 .7546 m .51763 .73661 L .54151 .73315 L p .707 .577 .707 r
F P
0 g
s
.54151 .73315 m .53869 .75115 L .5148 .7546 L p .707 .577 .707 r
F P
0 g
s
.53257 .82502 m .52568 .78793 L .54947 .77955 L p .707 .577 .707 r
F P
0 g
s
.54947 .77955 m .55637 .81665 L .53257 .82502 L p .707 .577 .707 r
F P
0 g
s
.49526 .32091 m .49037 .82225 L .53531 .82155 L p .707 .577 .707 r
F P
0 g
s
.54156 .63897 m .55411 .69435 L .53043 .70332 L p .707 .577 .707 r
F P
0 g
s
.53531 .82155 m .5402 .32021 L .49526 .32091 L p .707 .577 .707 r
F P
0 g
s
.55411 .69435 m .54156 .63897 L .57035 .63042 L p .707 .577 .707 r
F P
0 g
s
.57035 .63042 m .58291 .68581 L .55411 .69435 L p .707 .577 .707 r
F P
0 g
s
.53869 .75115 m .54151 .73315 L .57063 .73319 L p .707 .577 .707 r
F P
0 g
s
.57063 .73319 m .56781 .75118 L .53869 .75115 L p .707 .577 .707 r
F P
0 g
s
.55637 .81665 m .54947 .77955 L .57846 .77192 L p .707 .577 .707 r
F P
0 g
s
.56781 .75118 m .57063 .73319 L .60213 .73671 L p .707 .577 .707 r
F P
0 g
s
.57846 .77192 m .58536 .80902 L .55637 .81665 L p .707 .577 .707 r
F P
0 g
s
.60213 .73671 m .59931 .7547 L .56781 .75118 L p .707 .577 .707 r
F P
0 g
s
.5402 .32021 m .53531 .82155 L .57679 .81709 L p .707 .577 .707 r
F P
0 g
s
.58291 .68581 m .57035 .63042 L .60145 .62314 L p .707 .577 .707 r
F P
0 g
s
.57679 .81709 m .58168 .31575 L .5402 .32021 L p .707 .577 .707 r
F P
0 g
s
.44637 .81914 m .45125 .3178 L .41249 .31116 L p .707 .577 .707 r
F P
0 g
s
.45125 .3178 m .44637 .81914 L .49037 .82225 L p .707 .577 .707 r
F P
0 g
s
.69078 .61767 m .70333 .67305 L .69132 .67033 L p .707 .577 .707 r
F P
0 g
s
.69132 .67033 m .67877 .61495 L .69078 .61767 L p .707 .577 .707 r
F P
0 g
s
.60145 .62314 m .61401 .67852 L .58291 .68581 L p .707 .577 .707 r
F P
0 g
s
.63294 .74338 m .63011 .76137 L .59931 .7547 L p .707 .577 .707 r
F P
0 g
s
.59931 .7547 m .60213 .73671 L .63294 .74338 L p .707 .577 .707 r
F P
0 g
s
.58536 .80902 m .57846 .77192 L .6098 .76579 L p .707 .577 .707 r
F P
0 g
s
.6098 .76579 m .6167 .80289 L .58536 .80902 L p .707 .577 .707 r
F P
0 g
s
.58168 .31575 m .57679 .81709 L .61075 .80931 L p .707 .577 .707 r
F P
0 g
s
.61401 .67852 m .60145 .62314 L .63181 .61782 L p .707 .577 .707 r
F P
0 g
s
.6167 .80289 m .6098 .76579 L .63499 .76247 L p .707 .577 .707 r
F P
0 g
s
.66002 .75253 m .6572 .77053 L .635 .76302 L p .707 .577 .707 r
F P
0 g
s
.63498 .75993 m .66002 .75253 L .635 .76302 L .707 .577 .707 r
F
.63499 .76247 m .64042 .76176 L p .63505 .77107 L F P
0 g
s
.6167 .80289 m .63499 .76247 L .63505 .77107 L .707 .577 .707 r
F
.635 .76302 m .63011 .76137 L p .63498 .75993 L F P
0 g
s
.61075 .80931 m .61564 .30797 L .58168 .31575 L p .707 .577 .707 r
F P
0 g
s
.70272 .77077 m .70962 .80787 L .70698 .80205 L p .707 .577 .707 r
F P
0 g
s
.70698 .80205 m .70008 .76495 L .70272 .77077 L p .707 .577 .707 r
F P
0 g
s
.6958 .78532 m .69298 .80331 L .69026 .79258 L p .707 .577 .707 r
F P
0 g
s
.69026 .79258 m .69308 .77458 L .6958 .78532 L p .707 .577 .707 r
F P
0 g
s
.4076 .8125 m .41249 .31116 L .38277 .30166 L p .707 .577 .707 r
F P
0 g
s
.41249 .31116 m .4076 .8125 L .44637 .81914 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25904 .72599 m .25214 .68889 L .22152 .69293 L p .707 .577 .707 r
F P
0 g
s
.22152 .69293 m .22842 .73002 L .25904 .72599 L p .707 .577 .707 r
F P
0 g
s
.25582 .72815 m .24326 .67277 L .21291 .67808 L p .707 .577 .707 r
F P
0 g
s
.25214 .68889 m .25904 .72599 L .29037 .71986 L p .707 .577 .707 r
F P
0 g
s
.29037 .71986 m .28348 .68276 L .25214 .68889 L p .707 .577 .707 r
F P
0 g
s
.24326 .67277 m .25582 .72815 L .28692 .72087 L p .707 .577 .707 r
F P
0 g
s
.28692 .72087 m .27436 .66548 L .24326 .67277 L p .707 .577 .707 r
F P
0 g
s
.28348 .68276 m .29037 .71986 L .31936 .71223 L p .707 .577 .707 r
F P
0 g
s
.31936 .71223 m .31246 .67514 L .28348 .68276 L p .707 .577 .707 r
F P
0 g
s
.27436 .66548 m .28692 .72087 L .31571 .71232 L p .707 .577 .707 r
F P
0 g
s
.31571 .71232 m .30316 .65694 L .27436 .66548 L p .707 .577 .707 r
F P
0 g
s
.67877 .61495 m .69132 .67033 L .671 .67038 L p .707 .577 .707 r
F P
0 g
s
.671 .67038 m .65845 .615 L .67877 .61495 L p .707 .577 .707 r
F P
0 g
s
.22546 .73347 m .21291 .67808 L .18627 .68091 L p .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .22152 .69293 L .21912 .69306 L p .707 .577 .707 r
F P
0 g
s
.21291 .67808 m .22546 .73347 L .22733 .73314 L p .707 .577 .707 r
F P
0 g
s
.21704 .6829 m .21291 .67808 L .22733 .73314 L .707 .577 .707 r
F
.18627 .68091 m .19882 .73629 L .22546 .73347 L p F P
0 g
s
.21912 .69306 m .19461 .69447 L p .22621 .72771 L .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .21912 .69306 L .22621 .72771 L .707 .577 .707 r
F
.19461 .69447 m .20151 .73157 L .22842 .73002 L p F P
0 g
s
.22733 .73314 m .25582 .72815 L p .21704 .6829 L .707 .577 .707 r
F P
0 g
s
.63181 .61782 m .64436 .67321 L .61401 .67852 L p .707 .577 .707 r
F P
0 g
s
.63011 .76137 m .63294 .74338 L .66002 .75253 L p .707 .577 .707 r
F P
0 g
s
.64042 .76176 m .64732 .79886 L .6167 .80289 L p .707 .577 .707 r
F P
0 g
s
.61564 .30797 m .61075 .80931 L .63386 .79898 L p .707 .577 .707 r
F P
0 g
s
.64436 .67321 m .63181 .61782 L .65845 .615 L p .707 .577 .707 r
F P
0 g
s
.63386 .79898 m .63875 .29764 L .61564 .30797 L p .707 .577 .707 r
F P
0 g
s
.70008 .76495 m .70698 .80205 L .69478 .79842 L p .707 .577 .707 r
F P
0 g
s
.69308 .77458 m .69026 .79258 L .67793 .78128 L p .707 .577 .707 r
F P
0 g
s
.67793 .78128 m .68075 .76329 L .69308 .77458 L p .707 .577 .707 r
F P
0 g
s
.69478 .79842 m .68788 .76132 L .70008 .76495 L p .707 .577 .707 r
F P
0 g
s
.31246 .67514 m .31936 .71223 L .34316 .70386 L p .707 .577 .707 r
F P
0 g
s
.34316 .70386 m .33626 .66676 L .31246 .67514 L p .707 .577 .707 r
F P
0 g
s
.30316 .65694 m .31571 .71232 L .33939 .70336 L p .707 .577 .707 r
F P
0 g
s
.33939 .70336 m .32684 .64797 L .30316 .65694 L p .707 .577 .707 r
F P
0 g
s
.37788 .803 m .38277 .30166 L .36499 .29022 L p .707 .577 .707 r
F P
0 g
s
.38277 .30166 m .37788 .803 L .4076 .8125 L p .707 .577 .707 r
F P
0 g
s
.19882 .73629 m .18627 .68091 L .16595 .68096 L p .707 .577 .707 r
F P
0 g
s
.20151 .73157 m .19461 .69447 L .17405 .69337 L p .707 .577 .707 r
F P
0 g
s
.65845 .615 m .671 .67038 L .64436 .67321 L p .707 .577 .707 r
F P
0 g
s
.33626 .66676 m .34316 .70386 L .35944 .69555 L p .707 .577 .707 r
F P
0 g
s
.35944 .69555 m .35254 .65845 L .33626 .66676 L p .707 .577 .707 r
F P
0 g
s
.32684 .64797 m .33939 .70336 L .35563 .69485 L p .707 .577 .707 r
F P
0 g
s
.35563 .69485 m .34308 .63946 L .32684 .64797 L p .707 .577 .707 r
F P
0 g
s
.16595 .68096 m .1785 .73634 L .19882 .73629 L p .707 .577 .707 r
F P
0 g
s
.17405 .69337 m .18095 .73046 L .20151 .73157 L p .707 .577 .707 r
F P
0 g
s
.68788 .76132 m .69478 .79842 L .67422 .79732 L p .707 .577 .707 r
F P
0 g
s
.68075 .76329 m .67793 .78128 L .6572 .77053 L p .707 .577 .707 r
F P
0 g
s
.6572 .77053 m .66002 .75253 L .68075 .76329 L p .707 .577 .707 r
F P
0 g
s
.67422 .79732 m .66733 .76022 L .68788 .76132 L p .707 .577 .707 r
F P
0 g
s
.24202 .85462 m .24484 .83663 L .21403 .82996 L p .707 .577 .707 r
F P
0 g
s
.24484 .83663 m .24202 .85462 L .27352 .85814 L p .707 .577 .707 r
F P
0 g
s
.27352 .85814 m .27634 .84015 L .24484 .83663 L p .707 .577 .707 r
F P
0 g
s
.64732 .79886 m .64042 .76176 L .66733 .76022 L p .707 .577 .707 r
F P
0 g
s
.63875 .29764 m .63386 .79898 L .64386 .7871 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .64875 .28576 L .63875 .29764 L p .707 .577 .707 r
F P
0 g
s
.27634 .84015 m .27352 .85814 L .30264 .85818 L p .707 .577 .707 r
F P
0 g
s
.30264 .85818 m .30546 .84019 L .27634 .84015 L p .707 .577 .707 r
F P
0 g
s
.21121 .84795 m .21403 .82996 L .18694 .8208 L p .707 .577 .707 r
F P
0 g
s
.21403 .82996 m .21121 .84795 L .24202 .85462 L p .707 .577 .707 r
F P
0 g
s
.1785 .73634 m .16595 .68096 L .15394 .67824 L p .707 .577 .707 r
F P
0 g
s
.18095 .73046 m .17405 .69337 L .16186 .68973 L p .707 .577 .707 r
F P
0 g
s
.18694 .8208 m .18412 .8388 L .21121 .84795 L p .707 .577 .707 r
F P
0 g
s
.35254 .65845 m .35944 .69555 L .36661 .68812 L p .707 .577 .707 r
F P
0 g
s
.34308 .63946 m .35563 .69485 L .36284 .68762 L p .707 .577 .707 r
F P
0 g
s
.36661 .68812 m .35971 .65103 L .35254 .65845 L p .707 .577 .707 r
F P
0 g
s
.36284 .68762 m .35029 .63224 L .34308 .63946 L p .707 .577 .707 r
F P
0 g
s
.15394 .67824 m .16649 .73362 L .1785 .73634 L p .707 .577 .707 r
F P
0 g
s
.16186 .68973 m .16875 .72683 L .18095 .73046 L p .707 .577 .707 r
F P
0 g
s
.30546 .84019 m .30264 .85818 L .32652 .85472 L p .707 .577 .707 r
F P
0 g
s
.32652 .85472 m .32934 .83673 L .30546 .84019 L p .707 .577 .707 r
F P
0 g
s
.35029 .63224 m .36284 .68762 L .36032 .6824 L p .707 .577 .707 r
F P
0 g
s
.36032 .6824 m .34777 .62702 L .35029 .63224 L p .707 .577 .707 r
F P
0 g
s
.35971 .65103 m .36661 .68812 L .36397 .68231 L p .707 .577 .707 r
F P
0 g
s
.36397 .68231 m .35707 .64521 L .35971 .65103 L p .707 .577 .707 r
F P
0 g
s
.34777 .62702 m .36032 .6824 L .34831 .67968 L p .707 .577 .707 r
F P
0 g
s
.35707 .64521 m .36397 .68231 L .35177 .67867 L p .707 .577 .707 r
F P
0 g
s
.3601 .79156 m .36499 .29022 L .3609 .27796 L p .707 .577 .707 r
F P
0 g
s
.36499 .29022 m .3601 .79156 L .37788 .803 L p .707 .577 .707 r
F P
0 g
s
.18412 .8388 m .18694 .8208 L .16622 .81005 L p .707 .577 .707 r
F P
0 g
s
.66733 .76022 m .67422 .79732 L .64732 .79886 L p .707 .577 .707 r
F P
0 g
s
.16622 .81005 m .1634 .82804 L .18412 .8388 L p .707 .577 .707 r
F P
0 g
s
.16875 .72683 m .16186 .68973 L .15921 .68392 L p .707 .577 .707 r
F P
0 g
s
.16649 .73362 m .15394 .67824 L .15142 .67302 L p .707 .577 .707 r
F P
0 g
s
.32934 .83673 m .32652 .85472 L .34283 .84811 L p .707 .577 .707 r
F P
0 g
s
.34283 .84811 m .34565 .83011 L .32934 .83673 L p .707 .577 .707 r
F P
0 g
s
.1634 .82804 m .16622 .81005 L .15389 .79875 L p .707 .577 .707 r
F P
0 g
s
.15921 .68392 m .16611 .72101 L .16875 .72683 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .63977 .77484 L p .6429 .6043 L .707 .577 .707 r
F P
0 g
s
.6429 .6043 m .64512 .4833 L .6446 .60836 L .707 .577 .707 r
F
.6429 .6043 m .6446 .60836 L .64386 .7871 L F
.64466 .2735 m .63977 .77484 L .62199 .7634 L p F P
0 g
s
.63415 .57685 m .63163 .57163 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.64709 .45587 m .64386 .7871 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64466 .2735 m .64875 .28576 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.63977 .77484 m .64222 .52379 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64222 .52379 m .64466 .2735 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .65871 .63495 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63415 .57685 m .63739 .59114 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .6467 .63224 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .63739 .59114 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .63415 .57685 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .64616 .57957 L .63835 .5778 L p .707 .577 .707 r
F P
0 g
s
.63835 .5778 m .63415 .57685 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .63835 .5778 L .6378 .58547 L .707 .577 .707 r
F
.64875 .28576 m .64709 .45587 L p .64512 .4833 L F P
0 g
s
.15142 .67302 m .16397 .7284 L .16649 .73362 L p .707 .577 .707 r
F P
0 g
s
.15389 .79875 m .15107 .81675 L .1634 .82804 L p .707 .577 .707 r
F P
0 g
s
.3609 .27796 m .35602 .7793 L .3601 .79156 L p .707 .577 .707 r
F P
0 g
s
.35602 .7793 m .3609 .27796 L .3709 .26608 L p .707 .577 .707 r
F P
0 g
s
.34565 .83011 m .34283 .84811 L .34997 .83899 L p .707 .577 .707 r
F P
0 g
s
.34997 .83899 m .3528 .82099 L .34565 .83011 L p .707 .577 .707 r
F P
0 g
s
.16611 .72101 m .15921 .68392 L .16638 .67649 L p .707 .577 .707 r
F P
0 g
s
.16397 .7284 m .15142 .67302 L .15863 .66579 L p .707 .577 .707 r
F P
0 g
s
.15107 .81675 m .15389 .79875 L .15116 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16638 .67649 m .17328 .71359 L .16611 .72101 L p .707 .577 .707 r
F P
0 g
s
.34831 .67968 m .33576 .6243 L .34777 .62702 L p .707 .577 .707 r
F P
0 g
s
.15116 .78802 m .14834 .80601 L .15107 .81675 L p .707 .577 .707 r
F P
0 g
s
.35177 .67867 m .34487 .64158 L .35707 .64521 L p .707 .577 .707 r
F P
0 g
s
.15863 .66579 m .17118 .72118 L .16397 .7284 L p .707 .577 .707 r
F P
0 g
s
.62199 .7634 m .62688 .26206 L .64466 .2735 L p .707 .577 .707 r
F P
0 g
s
.3528 .82099 m .34997 .83899 L .34725 .82825 L p .707 .577 .707 r
F P
0 g
s
.34725 .82825 m .35007 .81026 L .3528 .82099 L p .707 .577 .707 r
F P
0 g
s
.17328 .71359 m .16638 .67649 L .18267 .66818 L p .707 .577 .707 r
F P
0 g
s
.17118 .72118 m .15863 .66579 L .17487 .65728 L p .707 .577 .707 r
F P
0 g
s
.14834 .80601 m .15116 .78802 L .15831 .7789 L p .707 .577 .707 r
F P
0 g
s
.36602 .76742 m .3709 .26608 L .39401 .25575 L p .707 .577 .707 r
F P
0 g
s
.3709 .26608 m .36602 .76742 L .35602 .7793 L p .707 .577 .707 r
F P
0 g
s
.18267 .66818 m .18956 .70528 L .17328 .71359 L p .707 .577 .707 r
F P
0 g
s
.33576 .6243 m .34831 .67968 L .32799 .67973 L p .707 .577 .707 r
F P
0 g
s
.32799 .67973 m .31544 .62435 L .33576 .6243 L p .707 .577 .707 r
F P
0 g
s
.15831 .7789 m .15548 .79689 L .14834 .80601 L p .707 .577 .707 r
F P
0 g
s
.34487 .64158 m .35177 .67867 L .33121 .67757 L p .707 .577 .707 r
F P
0 g
s
.33121 .67757 m .32432 .64047 L .34487 .64158 L p .707 .577 .707 r
F P
0 g
s
.17487 .65728 m .18742 .71267 L .17118 .72118 L p .707 .577 .707 r
F P
0 g
s
.18956 .70528 m .18267 .66818 L .20646 .65981 L p .707 .577 .707 r
F P
0 g
s
.18742 .71267 m .17487 .65728 L .19855 .64832 L p .707 .577 .707 r
F P
0 g
s
.35007 .81026 m .34725 .82825 L .33492 .81696 L p .707 .577 .707 r
F P
0 g
s
.33492 .81696 m .33774 .79896 L .35007 .81026 L p .707 .577 .707 r
F P
0 g
s
.62688 .26206 m .62199 .7634 L .59227 .7539 L p .707 .577 .707 r
F P
0 g
s
.59227 .7539 m .59716 .25256 L .62688 .26206 L p .707 .577 .707 r
F P
0 g
s
.15548 .79689 m .15831 .7789 L .17462 .77229 L p .707 .577 .707 r
F P
0 g
s
.31544 .62435 m .32799 .67973 L .30299 .68238 L p .707 .577 .707 r
F P
0 g
s
.30225 .67884 m .31544 .62435 L .30299 .68238 L .707 .577 .707 r
F
.30236 .67937 m .27369 .68315 L p .29535 .64559 L F P
0 g
s
.27369 .68315 m .26679 .64605 L .29468 .64238 L p .707 .577 .707 r
F P
0 g
s
.27369 .68315 m .29468 .64238 L .29535 .64559 L .707 .577 .707 r
F
.30135 .68256 m .2888 .62717 L .29146 .62689 L p F P
0 g
s
.29146 .62689 m .31544 .62435 L p .30225 .67884 L .707 .577 .707 r
F P
0 g
s
.30135 .68256 m .29146 .62689 L .30225 .67884 L .707 .577 .707 r
F
.29468 .64238 m .29741 .64202 L p .29535 .64559 L F P
0 g
s
.29741 .64202 m .30431 .67911 L .30236 .67937 L p .707 .577 .707 r
F P
0 g
s
.29535 .64559 m .29741 .64202 L .30236 .67937 L .707 .577 .707 r
F
.30299 .68238 m .30135 .68256 L p .30225 .67884 L F P
0 g
s
.32432 .64047 m .33121 .67757 L .30431 .67911 L p .707 .577 .707 r
F P
0 g
s
.30431 .67911 m .29741 .64202 L .32432 .64047 L p .707 .577 .707 r
F P
0 g
s
.20646 .65981 m .21336 .6969 L .18956 .70528 L p .707 .577 .707 r
F P
0 g
s
.19855 .64832 m .2111 .7037 L .18742 .71267 L p .707 .577 .707 r
F P
0 g
s
.17462 .77229 m .17179 .79028 L .15548 .79689 L p .707 .577 .707 r
F P
0 g
s
.73603 .62676 m .72348 .57138 L .69312 .5767 L p .707 .577 .707 r
F P
0 g
s
.72348 .57138 m .73603 .62676 L .76713 .61948 L p .707 .577 .707 r
F P
0 g
s
.76713 .61948 m .75458 .5641 L .72348 .57138 L p .707 .577 .707 r
F P
0 g
s
.39401 .25575 m .38912 .75709 L .36602 .76742 L p .707 .577 .707 r
F P
0 g
s
.38912 .75709 m .39401 .25575 L .42797 .24797 L p .707 .577 .707 r
F P
0 g
s
.75458 .5641 m .76713 .61948 L .79593 .61093 L p .707 .577 .707 r
F P
0 g
s
.79593 .61093 m .78337 .55555 L .75458 .5641 L p .707 .577 .707 r
F P
0 g
s
.21336 .6969 m .20646 .65981 L .23545 .65218 L p .707 .577 .707 r
F P
0 g
s
.2111 .7037 m .19855 .64832 L .22734 .63977 L p .707 .577 .707 r
F P
0 g
s
.26679 .64605 m .27369 .68315 L .24235 .68928 L p .707 .577 .707 r
F P
0 g
s
.2888 .62717 m .30135 .68256 L .271 .68787 L p .707 .577 .707 r
F P
0 g
s
.24235 .68928 m .23545 .65218 L .26679 .64605 L p .707 .577 .707 r
F P
0 g
s
.271 .68787 m .25844 .63249 L .2888 .62717 L p .707 .577 .707 r
F P
0 g
s
.70567 .63208 m .69312 .5767 L .66648 .57952 L p .707 .577 .707 r
F P
0 g
s
.69312 .5767 m .70567 .63208 L .73603 .62676 L p .707 .577 .707 r
F P
0 g
s
.23545 .65218 m .24235 .68928 L .21336 .6969 L p .707 .577 .707 r
F P
0 g
s
.33774 .79896 m .33492 .81696 L .31419 .8062 L p .707 .577 .707 r
F P
0 g
s
.31419 .8062 m .31702 .78821 L .33774 .79896 L p .707 .577 .707 r
F P
0 g
s
.78337 .55555 m .79593 .61093 L .8196 .60197 L p .707 .577 .707 r
F P
0 g
s
.8196 .60197 m .80705 .54659 L .78337 .55555 L p .707 .577 .707 r
F P
0 g
s
.22734 .63977 m .2399 .69516 L .2111 .7037 L p .707 .577 .707 r
F P
0 g
s
.2399 .69516 m .22734 .63977 L .25844 .63249 L p .707 .577 .707 r
F P
0 g
s
.25844 .63249 m .271 .68787 L .2399 .69516 L p .707 .577 .707 r
F P
0 g
s
.17179 .79028 m .17462 .77229 L .1985 .76883 L p .707 .577 .707 r
F P
0 g
s
.66648 .57952 m .67903 .6349 L .70567 .63208 L p .707 .577 .707 r
F P
0 g
s
.59716 .25256 m .59227 .7539 L .55351 .74726 L p .707 .577 .707 r
F P
0 g
s
.55351 .74726 m .5584 .24592 L .59716 .25256 L p .707 .577 .707 r
F P
0 g
s
.1985 .76883 m .19568 .78682 L .17179 .79028 L p .707 .577 .707 r
F P
0 g
s
.67903 .6349 m .66648 .57952 L .64616 .57957 L p .707 .577 .707 r
F P
0 g
s
.42308 .74931 m .42797 .24797 L .46945 .24351 L p .707 .577 .707 r
F P
0 g
s
.42797 .24797 m .42308 .74931 L .38912 .75709 L p .707 .577 .707 r
F P
0 g
s
.80705 .54659 m .8196 .60197 L .83584 .59346 L p .707 .577 .707 r
F P
0 g
s
.83584 .59346 m .82329 .53807 L .80705 .54659 L p .707 .577 .707 r
F P
0 g
s
.31702 .78821 m .31419 .8062 L .2871 .79705 L p .707 .577 .707 r
F P
0 g
s
.2871 .79705 m .28993 .77905 L .31702 .78821 L p .707 .577 .707 r
F P
0 g
s
.19568 .78682 m .1985 .76883 L .22762 .76886 L p .707 .577 .707 r
F P
0 g
s
.64616 .57957 m .65871 .63495 L .67903 .6349 L p .707 .577 .707 r
F P
0 g
s
.73925 .7537 m .73235 .7166 L .70173 .72063 L p .707 .577 .707 r
F P
0 g
s
.73235 .7166 m .73925 .7537 L .77059 .74756 L p .707 .577 .707 r
F P
0 g
s
.77059 .74756 m .76369 .71047 L .73235 .7166 L p .707 .577 .707 r
F P
0 g
s
.72223 .72691 m .72505 .70891 L .69425 .70225 L p .707 .577 .707 r
F P
0 g
s
.72505 .70891 m .72223 .72691 L .75373 .73043 L p .707 .577 .707 r
F P
0 g
s
.75373 .73043 m .75655 .71244 L .72505 .70891 L p .707 .577 .707 r
F P
0 g
s
.76369 .71047 m .77059 .74756 L .79957 .73994 L p .707 .577 .707 r
F P
0 g
s
.79957 .73994 m .79268 .70284 L .76369 .71047 L p .707 .577 .707 r
F P
0 g
s
.5584 .24592 m .55351 .74726 L .5095 .74415 L p .707 .577 .707 r
F P
0 g
s
.5095 .74415 m .51439 .24281 L .5584 .24592 L p .707 .577 .707 r
F P
0 g
s
.75655 .71244 m .75373 .73043 L .78285 .73046 L p .707 .577 .707 r
F P
0 g
s
.78285 .73046 m .78567 .71247 L .75655 .71244 L p .707 .577 .707 r
F P
0 g
s
.22762 .76886 m .2248 .78686 L .19568 .78682 L p .707 .577 .707 r
F P
0 g
s
.69143 .72024 m .69425 .70225 L .66716 .69309 L p .707 .577 .707 r
F P
0 g
s
.70173 .72063 m .70863 .75773 L .73925 .7537 L p .707 .577 .707 r
F P
0 g
s
.70863 .75773 m .70173 .72063 L .69696 .7209 L p .707 .577 .707 r
F P
0 g
s
.69425 .70225 m .69143 .72024 L .69698 .72144 L p .707 .577 .707 r
F P
0 g
s
.6965 .70423 m .69425 .70225 L .69698 .72144 L .707 .577 .707 r
F
.69696 .7209 m .67482 .72217 L p .69767 .74621 L F P
0 g
s
.70863 .75773 m .69696 .7209 L .69767 .74621 L .707 .577 .707 r
F
.69698 .72144 m .72223 .72691 L p .6965 .70423 L F P
0 g
s
.46456 .74485 m .46945 .24351 L .51439 .24281 L p .707 .577 .707 r
F P
0 g
s
.46945 .24351 m .46456 .74485 L .42308 .74931 L p .707 .577 .707 r
F P
0 g
s
.28993 .77905 m .2871 .79705 L .2563 .79038 L p .707 .577 .707 r
F P
0 g
s
.2563 .79038 m .25912 .77239 L .28993 .77905 L p .707 .577 .707 r
F P
0 g
s
.2248 .78686 m .22762 .76886 L .25912 .77239 L p .707 .577 .707 r
F P
0 g
s
.66716 .69309 m .66434 .71108 L .69143 .72024 L p .707 .577 .707 r
F P
0 g
s
.79268 .70284 m .79957 .73994 L .82337 .73156 L p .707 .577 .707 r
F P
0 g
s
.82337 .73156 m .81648 .69446 L .79268 .70284 L p .707 .577 .707 r
F P
0 g
s
.51439 .24281 m .5095 .74415 L .46456 .74485 L p .707 .577 .707 r
F P
0 g
s
.67482 .72217 m .68172 .75927 L .70863 .75773 L p .707 .577 .707 r
F P
0 g
s
.25912 .77239 m .2563 .79038 L .2248 .78686 L p .707 .577 .707 r
F P
0 g
s
.78567 .71247 m .78285 .73046 L .80674 .727 L p .707 .577 .707 r
F P
0 g
s
.80674 .727 m .80956 .70901 L .78567 .71247 L p .707 .577 .707 r
F P
0 g
s
.66434 .71108 m .66716 .69309 L .64643 .68234 L p .707 .577 .707 r
F P
0 g
s
.82329 .53807 m .83584 .59346 L .84306 .58624 L p .707 .577 .707 r
F P
0 g
s
.84306 .58624 m .8305 .53085 L .82329 .53807 L p .707 .577 .707 r
F P
0 g
s
.68172 .75927 m .67482 .72217 L .65427 .72107 L p .707 .577 .707 r
F P
0 g
s
.64643 .68234 m .64361 .70033 L .66434 .71108 L p .707 .577 .707 r
F P
0 g
s
.81648 .69446 m .82337 .73156 L .83966 .72325 L p .707 .577 .707 r
F P
0 g
s
.83966 .72325 m .83276 .68616 L .81648 .69446 L p .707 .577 .707 r
F P
0 g
s
.65427 .72107 m .66117 .75817 L .68172 .75927 L p .707 .577 .707 r
F P
0 g
s
.80956 .70901 m .80674 .727 L .82305 .72039 L p .707 .577 .707 r
F P
0 g
s
.82305 .72039 m .82587 .7024 L .80956 .70901 L p .707 .577 .707 r
F P
0 g
s
.64361 .70033 m .64643 .68234 L .6341 .67104 L p .707 .577 .707 r
F P
0 g
s
.6341 .67104 m .63128 .68903 L .64361 .70033 L p .707 .577 .707 r
F P
0 g
s
.66117 .75817 m .65427 .72107 L .64207 .71744 L p .707 .577 .707 r
F P
0 g
s
.8305 .53085 m .84306 .58624 L .84054 .58101 L p .707 .577 .707 r
F P
0 g
s
.84054 .58101 m .82798 .52563 L .8305 .53085 L p .707 .577 .707 r
F P
0 g
s
.63163 .57163 m .64418 .62701 L .6467 .63224 L p .707 .577 .707 r
F P
0 g
s
.64207 .71744 m .64897 .75453 L .66117 .75817 L p .707 .577 .707 r
F P
0 g
s
.83276 .68616 m .83966 .72325 L .84683 .71583 L p .707 .577 .707 r
F P
0 g
s
.84683 .71583 m .83993 .67873 L .83276 .68616 L p .707 .577 .707 r
F P
0 g
s
.82587 .7024 m .82305 .72039 L .83019 .71127 L p .707 .577 .707 r
F P
0 g
s
.83019 .71127 m .83301 .69328 L .82587 .7024 L p .707 .577 .707 r
F P
0 g
s
.63128 .68903 m .6341 .67104 L .63138 .66031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64418 .62701 m .63163 .57163 L .63884 .56441 L p .707 .577 .707 r
F P
0 g
s
.63138 .66031 m .62856 .6783 L .63128 .68903 L p .707 .577 .707 r
F P
0 g
s
.64897 .75453 m .64207 .71744 L .63943 .71162 L p .707 .577 .707 r
F P
0 g
s
.82798 .52563 m .84054 .58101 L .82853 .57829 L p .707 .577 .707 r
F P
0 g
s
.82853 .57829 m .81597 .52291 L .82798 .52563 L p .707 .577 .707 r
F P
0 g
s
.63884 .56441 m .6514 .61979 L .64418 .62701 L p .707 .577 .707 r
F P
0 g
s
.63943 .71162 m .64633 .74872 L .64897 .75453 L p .707 .577 .707 r
F P
0 g
s
.83993 .67873 m .84683 .71583 L .84418 .71001 L p .707 .577 .707 r
F P
0 g
s
.84418 .71001 m .83729 .67292 L .83993 .67873 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83301 .69328 m .83019 .71127 L .82746 .70054 L p .707 .577 .707 r
F P
0 g
s
.82746 .70054 m .83028 .68255 L .83301 .69328 L p .707 .577 .707 r
F P
0 g
s
.62856 .6783 m .63138 .66031 L .63852 .65119 L p .707 .577 .707 r
F P
0 g
s
.6514 .61979 m .63884 .56441 L .65508 .5559 L p .707 .577 .707 r
F P
0 g
s
.63852 .65119 m .6357 .66918 L .62856 .6783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39624 .63395 m .38934 .59685 L .35872 .60089 L p .707 .577 .707 r
F P
0 g
s
.35872 .60089 m .36562 .63799 L .39624 .63395 L p .707 .577 .707 r
F P
0 g
s
.39302 .63611 m .38047 .58073 L .35011 .58605 L p .707 .577 .707 r
F P
0 g
s
.38934 .59685 m .39624 .63395 L .42758 .62782 L p .707 .577 .707 r
F P
0 g
s
.42758 .62782 m .42068 .59072 L .38934 .59685 L p .707 .577 .707 r
F P
0 g
s
.38047 .58073 m .39302 .63611 L .42412 .62883 L p .707 .577 .707 r
F P
0 g
s
.42412 .62883 m .41157 .57345 L .38047 .58073 L p .707 .577 .707 r
F P
0 g
s
.42068 .59072 m .42758 .62782 L .45656 .62019 L p .707 .577 .707 r
F P
0 g
s
.45656 .62019 m .44967 .5831 L .42068 .59072 L p .707 .577 .707 r
F P
0 g
s
.41157 .57345 m .42412 .62883 L .45292 .62028 L p .707 .577 .707 r
F P
0 g
s
.45292 .62028 m .44036 .5649 L .41157 .57345 L p .707 .577 .707 r
F P
0 g
s
.64633 .74872 m .63943 .71162 L .6466 .7042 L p .707 .577 .707 r
F P
0 g
s
.81597 .52291 m .82853 .57829 L .80821 .57834 L p .707 .577 .707 r
F P
0 g
s
.80821 .57834 m .79566 .52296 L .81597 .52291 L p .707 .577 .707 r
F P
0 g
s
.65508 .5559 m .66764 .61128 L .6514 .61979 L p .707 .577 .707 r
F P
0 g
s
.36266 .64143 m .35011 .58605 L .32347 .58887 L p .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35872 .60089 L .35632 .60103 L p .707 .577 .707 r
F P
0 g
s
.35011 .58605 m .36266 .64143 L .36453 .6411 L p .707 .577 .707 r
F P
0 g
s
.35424 .59086 m .35011 .58605 L .36453 .6411 L .707 .577 .707 r
F
.32347 .58887 m .33602 .64425 L .36266 .64143 L p F P
0 g
s
.35632 .60103 m .33181 .60243 L p .36342 .63567 L .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35632 .60103 L .36342 .63567 L .707 .577 .707 r
F
.33181 .60243 m .33871 .63953 L .36562 .63799 L p F P
0 g
s
.36453 .6411 m .39302 .63611 L p .35424 .59086 L .707 .577 .707 r
F P
0 g
s
.6466 .7042 m .6535 .74129 L .64633 .74872 L p .707 .577 .707 r
F P
0 g
s
.83729 .67292 m .84418 .71001 L .83199 .70638 L p .707 .577 .707 r
F P
0 g
s
.83028 .68255 m .82746 .70054 L .81513 .68924 L p .707 .577 .707 r
F P
0 g
s
.81513 .68924 m .81795 .67125 L .83028 .68255 L p .707 .577 .707 r
F P
0 g
s
.83199 .70638 m .82509 .66928 L .83729 .67292 L p .707 .577 .707 r
F P
0 g
s
.44967 .5831 m .45656 .62019 L .48036 .61182 L p .707 .577 .707 r
F P
0 g
s
.48036 .61182 m .47347 .57472 L .44967 .5831 L p .707 .577 .707 r
F P
0 g
s
.44036 .5649 m .45292 .62028 L .4766 .61132 L p .707 .577 .707 r
F P
0 g
s
.4766 .61132 m .46404 .55594 L .44036 .5649 L p .707 .577 .707 r
F P
0 g
s
.6357 .66918 m .63852 .65119 L .65483 .64457 L p .707 .577 .707 r
F P
0 g
s
.66764 .61128 m .65508 .5559 L .67876 .54693 L p .707 .577 .707 r
F P
0 g
s
.33602 .64425 m .32347 .58887 L .30315 .58892 L p .707 .577 .707 r
F P
0 g
s
.33871 .63953 m .33181 .60243 L .31126 .60133 L p .707 .577 .707 r
F P
0 g
s
.65483 .64457 m .65201 .66257 L .6357 .66918 L p .707 .577 .707 r
F P
0 g
s
.79566 .52296 m .80821 .57834 L .78157 .58117 L p .707 .577 .707 r
F P
0 g
s
.78157 .58117 m .76901 .52579 L .79566 .52296 L p .707 .577 .707 r
F P
0 g
s
.47347 .57472 m .48036 .61182 L .49665 .60351 L p .707 .577 .707 r
F P
0 g
s
.49665 .60351 m .48975 .56641 L .47347 .57472 L p .707 .577 .707 r
F P
0 g
s
.46404 .55594 m .4766 .61132 L .49284 .60281 L p .707 .577 .707 r
F P
0 g
s
.49284 .60281 m .48028 .54742 L .46404 .55594 L p .707 .577 .707 r
F P
0 g
s
.6535 .74129 m .6466 .7042 L .66288 .69589 L p .707 .577 .707 r
F P
0 g
s
.67876 .54693 m .69131 .60231 L .66764 .61128 L p .707 .577 .707 r
F P
0 g
s
.30315 .58892 m .3157 .6443 L .33602 .64425 L p .707 .577 .707 r
F P
0 g
s
.31126 .60133 m .31816 .63843 L .33871 .63953 L p .707 .577 .707 r
F P
0 g
s
.66288 .69589 m .66978 .73299 L .6535 .74129 L p .707 .577 .707 r
F P
0 g
s
.82509 .66928 m .83199 .70638 L .81143 .70528 L p .707 .577 .707 r
F P
0 g
s
.81795 .67125 m .81513 .68924 L .79441 .67849 L p .707 .577 .707 r
F P
0 g
s
.79441 .67849 m .79723 .6605 L .81795 .67125 L p .707 .577 .707 r
F P
0 g
s
.81143 .70528 m .80453 .66818 L .82509 .66928 L p .707 .577 .707 r
F P
0 g
s
.69131 .60231 m .67876 .54693 L .70756 .53839 L p .707 .577 .707 r
F P
0 g
s
.37922 .76258 m .38204 .74459 L .35124 .73792 L p .707 .577 .707 r
F P
0 g
s
.38204 .74459 m .37922 .76258 L .41072 .76611 L p .707 .577 .707 r
F P
0 g
s
.41072 .76611 m .41354 .74811 L .38204 .74459 L p .707 .577 .707 r
F P
0 g
s
.76901 .52579 m .78157 .58117 L .75121 .58648 L p .707 .577 .707 r
F P
0 g
s
.75121 .58648 m .73866 .5311 L .76901 .52579 L p .707 .577 .707 r
F P
0 g
s
.65201 .66257 m .65483 .64457 L .67871 .64112 L p .707 .577 .707 r
F P
0 g
s
.41354 .74811 m .41072 .76611 L .43984 .76614 L p .707 .577 .707 r
F P
0 g
s
.43984 .76614 m .44266 .74815 L .41354 .74811 L p .707 .577 .707 r
F P
0 g
s
.34842 .75592 m .35124 .73792 L .32415 .72877 L p .707 .577 .707 r
F P
0 g
s
.35124 .73792 m .34842 .75592 L .37922 .76258 L p .707 .577 .707 r
F P
0 g
s
.3157 .6443 m .30315 .58892 L .29114 .5862 L p .707 .577 .707 r
F P
0 g
s
.31816 .63843 m .31126 .60133 L .29906 .59769 L p .707 .577 .707 r
F P
0 g
s
.70756 .53839 m .72011 .59377 L .69131 .60231 L p .707 .577 .707 r
F P
0 g
s
.72011 .59377 m .70756 .53839 L .73866 .5311 L p .707 .577 .707 r
F P
0 g
s
.67871 .64112 m .67589 .65911 L .65201 .66257 L p .707 .577 .707 r
F P
0 g
s
.73866 .5311 m .75121 .58648 L .72011 .59377 L p .707 .577 .707 r
F P
0 g
s
.32415 .72877 m .32133 .74676 L .34842 .75592 L p .707 .577 .707 r
F P
0 g
s
.48975 .56641 m .49665 .60351 L .50382 .59609 L p .707 .577 .707 r
F P
0 g
s
.48028 .54742 m .49284 .60281 L .50005 .59559 L p .707 .577 .707 r
F P
0 g
s
.50382 .59609 m .49692 .55899 L .48975 .56641 L p .707 .577 .707 r
F P
0 g
s
.50005 .59559 m .48749 .5402 L .48028 .54742 L p .707 .577 .707 r
F P
0 g
s
.29114 .5862 m .30369 .64159 L .3157 .6443 L p .707 .577 .707 r
F P
0 g
s
.29906 .59769 m .30596 .63479 L .31816 .63843 L p .707 .577 .707 r
F P
0 g
s
.66978 .73299 m .66288 .69589 L .68668 .68751 L p .707 .577 .707 r
F P
0 g
s
.44266 .74815 m .43984 .76614 L .46373 .76268 L p .707 .577 .707 r
F P
0 g
s
.46373 .76268 m .46655 .74469 L .44266 .74815 L p .707 .577 .707 r
F P
0 g
s
.32133 .74676 m .32415 .72877 L .30342 .71801 L p .707 .577 .707 r
F P
0 g
s
.80453 .66818 m .81143 .70528 L .78452 .70682 L p .707 .577 .707 r
F P
0 g
s
.79723 .6605 m .79441 .67849 L .7722 .67098 L p .707 .577 .707 r
F P
0 g
s
.77218 .66789 m .79723 .6605 L .7722 .67098 L .707 .577 .707 r
F
.7539 .71085 m .747 .67375 L .77762 .66972 L p F P
0 g
s
.7722 .67098 m .76732 .66933 L p .77218 .66789 L .707 .577 .707 r
F P
0 g
s
.77762 .66972 m .78452 .70682 L .77244 .70841 L p .707 .577 .707 r
F P
0 g
s
.77244 .70841 m .7539 .71085 L p .77225 .67903 L .707 .577 .707 r
F P
0 g
s
.77225 .67903 m .77762 .66972 L .77244 .70841 L .707 .577 .707 r
F
.78452 .70682 m .77762 .66972 L .80453 .66818 L p F P
0 g
s
.68668 .68751 m .69358 .72461 L .66978 .73299 L p .707 .577 .707 r
F P
0 g
s
.76732 .66933 m .77014 .65134 L .79723 .6605 L p .707 .577 .707 r
F P
0 g
s
.67589 .65911 m .67871 .64112 L .70783 .64115 L p .707 .577 .707 r
F P
0 g
s
.30342 .71801 m .3006 .736 L .32133 .74676 L p .707 .577 .707 r
F P
0 g
s
.70783 .64115 m .70501 .65914 L .67589 .65911 L p .707 .577 .707 r
F P
0 g
s
.69358 .72461 m .68668 .68751 L .71567 .67988 L p .707 .577 .707 r
F P
0 g
s
.30596 .63479 m .29906 .59769 L .29642 .59188 L p .707 .577 .707 r
F P
0 g
s
.30369 .64159 m .29114 .5862 L .28862 .58098 L p .707 .577 .707 r
F P
0 g
s
.77014 .65134 m .76732 .66933 L .73651 .66266 L p .707 .577 .707 r
F P
0 g
s
.73651 .66266 m .73934 .64467 L .77014 .65134 L p .707 .577 .707 r
F P
0 g
s
.70501 .65914 m .70783 .64115 L .73934 .64467 L p .707 .577 .707 r
F P
0 g
s
.46655 .74469 m .46373 .76268 L .48004 .75607 L p .707 .577 .707 r
F P
0 g
s
.48004 .75607 m .48286 .73808 L .46655 .74469 L p .707 .577 .707 r
F P
0 g
s
.71567 .67988 m .72256 .71698 L .69358 .72461 L p .707 .577 .707 r
F P
0 g
s
.73934 .64467 m .73651 .66266 L .70501 .65914 L p .707 .577 .707 r
F P
0 g
s
.3006 .736 m .30342 .71801 L .29109 .70672 L p .707 .577 .707 r
F P
0 g
s
.29642 .59188 m .30331 .62898 L .30596 .63479 L p .707 .577 .707 r
F P
0 g
s
.48749 .5402 m .50005 .59559 L .49753 .59036 L p .707 .577 .707 r
F P
0 g
s
.49753 .59036 m .48497 .53498 L .48749 .5402 L p .707 .577 .707 r
F P
0 g
s
.72256 .71698 m .71567 .67988 L .747 .67375 L p .707 .577 .707 r
F P
0 g
s
.49692 .55899 m .50382 .59609 L .50117 .59027 L p .707 .577 .707 r
F P
0 g
s
.50117 .59027 m .49427 .55317 L .49692 .55899 L p .707 .577 .707 r
F P
0 g
s
.28862 .58098 m .30117 .63636 L .30369 .64159 L p .707 .577 .707 r
F P
0 g
s
.747 .67375 m .7539 .71085 L .72256 .71698 L p .707 .577 .707 r
F P
0 g
s
.29109 .70672 m .28827 .72471 L .3006 .736 L p .707 .577 .707 r
F P
0 g
s
.48286 .73808 m .48004 .75607 L .48718 .74695 L p .707 .577 .707 r
F P
0 g
s
.48718 .74695 m .49 .72896 L .48286 .73808 L p .707 .577 .707 r
F P
0 g
s
.30331 .62898 m .29642 .59188 L .30359 .58445 L p .707 .577 .707 r
F P
0 g
s
.30117 .63636 m .28862 .58098 L .29583 .57376 L p .707 .577 .707 r
F P
0 g
s
.28827 .72471 m .29109 .70672 L .28837 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30359 .58445 m .31049 .62155 L .30331 .62898 L p .707 .577 .707 r
F P
0 g
s
.48497 .53498 m .49753 .59036 L .48552 .58764 L p .707 .577 .707 r
F P
0 g
s
.48552 .58764 m .47296 .53226 L .48497 .53498 L p .707 .577 .707 r
F P
0 g
s
.28837 .69598 m .28555 .71398 L .28827 .72471 L p .707 .577 .707 r
F P
0 g
s
.49427 .55317 m .50117 .59027 L .48898 .58663 L p .707 .577 .707 r
F P
0 g
s
.48898 .58663 m .48208 .54954 L .49427 .55317 L p .707 .577 .707 r
F P
0 g
s
.29583 .57376 m .30839 .62914 L .30117 .63636 L p .707 .577 .707 r
F P
0 g
s
.49 .72896 m .48718 .74695 L .48445 .73621 L p .707 .577 .707 r
F P
0 g
s
.48445 .73621 m .48727 .71822 L .49 .72896 L p .707 .577 .707 r
F P
0 g
s
.31049 .62155 m .30359 .58445 L .31987 .57615 L p .707 .577 .707 r
F P
0 g
s
.30839 .62914 m .29583 .57376 L .31207 .56525 L p .707 .577 .707 r
F P
0 g
s
.28555 .71398 m .28837 .69598 L .29551 .68686 L p .707 .577 .707 r
F P
0 g
s
.31987 .57615 m .32677 .61324 L .31049 .62155 L p .707 .577 .707 r
F P
0 g
s
.47296 .53226 m .48552 .58764 L .4652 .58769 L p .707 .577 .707 r
F P
0 g
s
.4652 .58769 m .45265 .53231 L .47296 .53226 L p .707 .577 .707 r
F P
0 g
s
.29551 .68686 m .29269 .70486 L .28555 .71398 L p .707 .577 .707 r
F P
0 g
s
.48208 .54954 m .48898 .58663 L .46842 .58553 L p .707 .577 .707 r
F P
0 g
s
.46842 .58553 m .46152 .54844 L .48208 .54954 L p .707 .577 .707 r
F P
0 g
s
.31207 .56525 m .32462 .62063 L .30839 .62914 L p .707 .577 .707 r
F P
0 g
s
.32677 .61324 m .31987 .57615 L .34367 .56777 L p .707 .577 .707 r
F P
0 g
s
.32462 .62063 m .31207 .56525 L .33575 .55628 L p .707 .577 .707 r
F P
0 g
s
.48727 .71822 m .48445 .73621 L .47212 .72492 L p .707 .577 .707 r
F P
0 g
s
.47212 .72492 m .47494 .70693 L .48727 .71822 L p .707 .577 .707 r
F P
0 g
s
.29269 .70486 m .29551 .68686 L .31182 .68025 L p .707 .577 .707 r
F P
0 g
s
.45265 .53231 m .4652 .58769 L .44019 .59034 L p .707 .577 .707 r
F P
0 g
s
.43946 .5868 m .45265 .53231 L .44019 .59034 L .707 .577 .707 r
F
.43957 .58733 m .41089 .59111 L p .43255 .55355 L F P
0 g
s
.41089 .59111 m .40399 .55401 L .43188 .55034 L p .707 .577 .707 r
F P
0 g
s
.41089 .59111 m .43188 .55034 L .43255 .55355 L .707 .577 .707 r
F
.43856 .59052 m .426 .53513 L .42867 .53485 L p F P
0 g
s
.42867 .53485 m .45265 .53231 L p .43946 .5868 L .707 .577 .707 r
F P
0 g
s
.43856 .59052 m .42867 .53485 L .43946 .5868 L .707 .577 .707 r
F
.43188 .55034 m .43461 .54998 L p .43255 .55355 L F P
0 g
s
.43461 .54998 m .44151 .58708 L .43957 .58733 L p .707 .577 .707 r
F P
0 g
s
.43255 .55355 m .43461 .54998 L .43957 .58733 L .707 .577 .707 r
F
.44019 .59034 m .43856 .59052 L p .43946 .5868 L F P
0 g
s
.46152 .54844 m .46842 .58553 L .44151 .58708 L p .707 .577 .707 r
F P
0 g
s
.44151 .58708 m .43461 .54998 L .46152 .54844 L p .707 .577 .707 r
F P
0 g
s
.34367 .56777 m .35057 .60487 L .32677 .61324 L p .707 .577 .707 r
F P
0 g
s
.33575 .55628 m .3483 .61166 L .32462 .62063 L p .707 .577 .707 r
F P
0 g
s
.31182 .68025 m .309 .69824 L .29269 .70486 L p .707 .577 .707 r
F P
0 g
s
.35057 .60487 m .34367 .56777 L .37266 .56014 L p .707 .577 .707 r
F P
0 g
s
.3483 .61166 m .33575 .55628 L .36455 .54774 L p .707 .577 .707 r
F P
0 g
s
.40399 .55401 m .41089 .59111 L .37955 .59724 L p .707 .577 .707 r
F P
0 g
s
.426 .53513 m .43856 .59052 L .4082 .59583 L p .707 .577 .707 r
F P
0 g
s
.37955 .59724 m .37266 .56014 L .40399 .55401 L p .707 .577 .707 r
F P
0 g
s
.4082 .59583 m .39565 .54045 L .426 .53513 L p .707 .577 .707 r
F P
0 g
s
.37266 .56014 m .37955 .59724 L .35057 .60487 L p .707 .577 .707 r
F P
0 g
s
.47494 .70693 m .47212 .72492 L .4514 .71416 L p .707 .577 .707 r
F P
0 g
s
.4514 .71416 m .45422 .69617 L .47494 .70693 L p .707 .577 .707 r
F P
0 g
s
.36455 .54774 m .3771 .60312 L .3483 .61166 L p .707 .577 .707 r
F P
0 g
s
.3771 .60312 m .36455 .54774 L .39565 .54045 L p .707 .577 .707 r
F P
0 g
s
.39565 .54045 m .4082 .59583 L .3771 .60312 L p .707 .577 .707 r
F P
0 g
s
.309 .69824 m .31182 .68025 L .3357 .67679 L p .707 .577 .707 r
F P
0 g
s
.3357 .67679 m .33288 .69478 L .309 .69824 L p .707 .577 .707 r
F P
0 g
s
.45422 .69617 m .4514 .71416 L .42431 .70501 L p .707 .577 .707 r
F P
0 g
s
.42431 .70501 m .42713 .68701 L .45422 .69617 L p .707 .577 .707 r
F P
0 g
s
.33288 .69478 m .3357 .67679 L .36482 .67683 L p .707 .577 .707 r
F P
0 g
s
.36482 .67683 m .362 .69482 L .33288 .69478 L p .707 .577 .707 r
F P
0 g
s
.42713 .68701 m .42431 .70501 L .3935 .69834 L p .707 .577 .707 r
F P
0 g
s
.3935 .69834 m .39632 .68035 L .42713 .68701 L p .707 .577 .707 r
F P
0 g
s
.362 .69482 m .36482 .67683 L .39632 .68035 L p .707 .577 .707 r
F P
0 g
s
.39632 .68035 m .3935 .69834 L .362 .69482 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol007=oo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00Kgoo
10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
00000P00Kgoo001]Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001/Ool006]oo`8000=JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06Yoo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00J7oo001XOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001TOol006Io
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<002Ioo`X003Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`007goo1`000eYF00<005YFFUH00UYF00<005YF
00000P00<Goo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`006goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80031oo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF009JEP/000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<001Moo`@000IJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EUYF001JEP0`Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP03FUH0
1000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0057oo100000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00IGoo00@005YFFUH000EJEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;goo001U
Ool01@00FUIJEP00FUH010000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000_Ool006Eoo`D000IJEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH005YF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool006Aoo`800003FUH005YF00QJEP03001JEUYF00IJEPH000=JEP03001JEUYF00H0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<0
00UJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
008002moo`00HGoo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF
00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Aoo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002moo`00GWoo0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0025YF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000_Ool005Yo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001JEUYF
009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Qoo`8000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001GOol20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20007FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001EOol2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00
FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF2`0000=JEP000000;Goo001BOol00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP02FUH4000]Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH@0002FUH01000FUIJEP002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUHE00000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00;Woo001BOol200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YFFUH00eYF00<007ooOol0;Goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00=JEP8000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF0080031oo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP05
FUH00`00FUH000020006FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000bOol005=oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF100025YF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00=7oo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00IJEP03001JEP00008003Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF1@001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000015YF0`001eYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF0`00>Goo
001DOol00`00FUH00004FUH20003FUH2000<FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P0000=JEP00000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP8003aoo`00E7oo00<005YF00001EYF00@005YF000000iJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP00008003ioo`00E7oo00@005YFFUH000=JEP<00003FUH005YF00eJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00EJEP@0045oo`00E7oo00D005YFFUH005YF008000AJEP03001JEUYF00aJEP03001JEUYF00MJ
EP03001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool004ioo`L0009JEP<000EJEP03001JEUYF00eJEP<000AJEPH000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPL004Uoo`00Agoo1`0015YF00D005YFFUIJ
EP0000=JEP03001JEUYF00=JEP03001JEUYF00]JEPT00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP04001JEUYFFUH8001@Ool004=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEUYF00]JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000`005Ioo`00
?goo10001UYF00<005YFFUH01eYF00D005YF000005YF00l000=JEPT000EJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00AJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00?Goo0P0000=JEP00FUH025YF00<005YFFUH0
1UYF1@0000=JEP00FUH015YF00<005YFFUH00UYF1P0015YF10001UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF
00<005YF00003`00Cgoo000jOol30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH>0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH60019Ool003Moo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030015
Ool003=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@0045oo`00
<Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
03eoo`00<7oo0P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Woo000^Ool200000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH500000eYF
001JEP03FUH00`00FUIJEP020005Ool70006FUH00`00FUIJEP05FUH3000hOol002eoo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00800003
FUH0000000IJEP03001JEUYF00=JEP04001JEUYF0009Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP02000fOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EP00FUH200000eYF001JEP02FUH;00000eYF00000007Ool50003OolD000aOol002]oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003
FUH00000008000EJEP03001JEUYF009JEP@000Moo`T000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP00000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUHA0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P0000AJ
EP00FUH000IJEP03001JEUYF00=JEP03001JEP0000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH000000UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF0P000Woo1000
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00:goo0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF
1`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYF0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH70002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF10001UYF1@001EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF0080009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF10002EYF0P000UYF00@005YFFUH000=JEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00001EYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF0P0015YF0P000eYF00<005YFFUH01eYF0P0000=JEP00FUH00UYF100015YF00@005YF
FUIJEP<0009JEP03001JEUYF00L000IJEP03001JEUYF00IJEP@000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]Ool002ao
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP07FUH200000eYF
001JEP0200000eYF001JEP06FUH400001Goo001JEUYF00001EYF00@005YFFUIJEP@0009JEP03001J
EUYF00IJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH0
0004FUH20005FUH30009FUH00`00FUIJEP06FUH200000eYF00000004FUH00`00FUIJEP03FUH30003
Ool01000FUIJEP001EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0P002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF4@0000=JEP00Ool0;7oo000]Ool0
0`00FUH00005FUH00`00FUH00003000<FUH00`00FUIJEP06FUH40005FUH00`00FUH000040005Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001JEP0000@0009J
EP800003FUH00000008002aoo`00;Goo00<005YF00001EYF0P0000=JEP00FUH03EYF00<005YFFUH0
1eYF0P0000=JEP00FUH00UYF10002Goo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003
FUH02@00FUIJEP00FUH005YF001JEP02000/Ool002eoo`04001JEUYF0002FUH20003FUH00`00FUIJ
EP0<FUH00`00FUIJEP07FUH01000FUIJEUYF100037oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00AJEP8000IJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH80003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0000/Ool002eoo`03001J
EUYF00<000EJEP03001JEUYF00aJEP03001JEUYF00IJEP8000AJEP03001oogoo00aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH005YFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF000015YF0P00;Goo000^Ool2FUH01000FUIJEP0015YF00<005YFFUH03EYF0`000UYF
0`0000=oo`00FUH00eYF0`0037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP80
0003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00D00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00008000AJEP03001oogoo02aoo`00
;Woo00=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH02eYF1P0017oo00<005YFFUH00UYF00<0
05YFFUH00P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP<000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
00AJEP03001JEUYF00=JEP@0009JEP/00003FUH005YF00IJEP04001JEUYFFUH50003FUH01000FUIJ
EP00;goo000^Ool200000eYF000000030003FUH01000FUIJEUYF0`001EYF1`001Woo00@005YFFUH0
00EJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH02000FUIJEP00FUH0
05YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUH000030004FUH00`00FUIJEP06FUHB0007FUH3000`Ool002moo`800003
FUH005YF009JEPl0009oo`D000Moo`<000IJEP03001JEP0000<000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUIJEP@000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80039oo`00<Goo30002goo
0`002Woo00<005YFFUH015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000dOol005Ioo`8000=JEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEP00001J
EP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
0`00>7oo001HOol200000eYF001JEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH50003
FUH>0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@003]oo`00FWoo0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00H005YFFUIJEP00FUH2000;FUH90008FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00mJEP03001JEUYF
00AJEPD003moo`00GGoo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040014Ool0065oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70018Ool006Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02
FUH00`00FUH00002FUHD001?Ool006Eoo`03001JEUYF00P000AJEP03001JEUYF00IJEP04001JEUYF
FUH40006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH0
0`00FUH0000=001HOol006Eoo`05001JEUYF001JEP020004FUHA000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00001EYF00<005YFFUH00eYF00@0
05YF000005Ioo`00=Goo400087oo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF001FOol0035oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL001Uoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003
FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001EOol002moo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@001Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH005YF00EJEP03001JEUYF00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0015oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000/Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000003goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF00=JEP03001J
EUYF008005Aoo`00:goo00<005YF00000UYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP04001J
EUYFFUH3000<Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YF
FUH00eYF00<005YFFUH00P00E7oo000ZOol00`00FUH00003FUH4000@Ool70006FUH00`00FUIJEP05
FUH2000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<0
05YFFUH00UYF00<005YFFUH00P00E7oo000ZOol01000FUH005YF0P006goo10000UYF00<005YFFUH0
1UYF0`002Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01UYF
00<005YFFUH00eYF00@005YF000005Aoo`00:Woo00@005YF0000025oo`@000MJEP03001JEUYF0080
00Qoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEPH000=JEP04001J
EUYF001DOol002Yoo`8002Moo`8000AJEP03001JEUYF00=JEP8000Qoo`<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EPh00003FUH0000000<00003FUH0000005=oo`00:Woo0`00:7oo0`0000=JEP00FUH01EYF0P002Goo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP/000=JEP07001JEUYF001JEP00FUH01000Dgoo000ZOol200000eYF0000
000YOol20006FUH00`00FUH0000:Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001eYF00<005YFFUH015YF00<005YF
FUH00P000eYF00<005YF0000Dgoo000ZOol00`00FUIJEP02FUH00`00Oomoo`0XOol20003FUH01@00
FUIJEUYF00002goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF1@0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP80
05Aoo`00:Woo00<005YFFUH00UYF0`00:Woo0P0000=JEP00FUH00UYF00<007ooOol037oo1`001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0200000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00P0015YF00<007ooOol0Dgoo000ZOol00`00FUIJEP02FUH00`00
FUIJEP02000ZOol20003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH@00000eYF
001JEP06FUH01000FUIJEUYF1P000UYF00@005YFFUH005Ioo`00:goo00@005YFFUH000EJEP<002Uo
o`05001JEP00FUH0000POolI0002FUH00`00FUIJEP06FUHC0007FUH3001GOol002aoo`<000IJEP03
001JEP0000<002Ioo`800003FUH007oo02Uoo`04001JEUYF0003FUH40007FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001IOol002ioo`03001JEUYF00AJEP03001JEUYF
00=JEP@002=oo`03001JEP0002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001KOol002moo`8000=JEP03001J
EUYF00EJEP03001JEUYF00@001eoo`@002]oo`03001JEUYF008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<005moo`00<Goo0P0000=JEP00FUH01UYF00<0
05YFFUH015YF1`0047oo1P000UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00@0069oo`00<goo0`001UYF00<005YFFUH01UYF00<005YF
FUH00UYF40000eYF00<005YFFUH00UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00mJEP03001J
EUYF00AJEPD006Ioo`00=Woo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8002eoo`80009JEP03001JEUYF009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00@006]oo`00>7oo0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo0P0000=JEP00FUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF1`00Kgoo000kOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00<Goo10000eYF00<005YFFUH00UYF2000MWoo000nOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000=goo2000OWoo0012
Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000_goo0019OolA0033Ool00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59801 .73071 m .59021 .67488 L .55935 .67744 L p .707 .577 .707 r
F P
0 g
s
.59021 .67488 m .59801 .73071 L .62956 .7259 L p .707 .577 .707 r
F P
0 g
s
.62956 .7259 m .62176 .67007 L .59021 .67488 L p .707 .577 .707 r
F P
0 g
s
.62176 .67007 m .62956 .7259 L .65872 .71933 L p .707 .577 .707 r
F P
0 g
s
.65872 .71933 m .65092 .6635 L .62176 .67007 L p .707 .577 .707 r
F P
0 g
s
.56715 .73327 m .55935 .67744 L .5322 .67751 L p .707 .577 .707 r
F P
0 g
s
.55935 .67744 m .56715 .73327 L .59801 .73071 L p .707 .577 .707 r
F P
0 g
s
.65092 .6635 m .65872 .71933 L .68263 .71162 L p .707 .577 .707 r
F P
0 g
s
.68263 .71162 m .67483 .6558 L .65092 .6635 L p .707 .577 .707 r
F P
0 g
s
.5322 .67751 m .54 .73334 L .56715 .73327 L p .707 .577 .707 r
F P
0 g
s
.54 .73334 m .5322 .67751 L .51143 .67509 L p .707 .577 .707 r
F P
0 g
s
.59992 .83211 m .59564 .79487 L .56468 .79663 L p .707 .577 .707 r
F P
0 g
s
.59564 .79487 m .59992 .83211 L .63157 .82803 L p .707 .577 .707 r
F P
0 g
s
.63157 .82803 m .62729 .79078 L .59564 .79487 L p .707 .577 .707 r
F P
0 g
s
.67483 .6558 m .68263 .71162 L .69895 .70355 L p .707 .577 .707 r
F P
0 g
s
.69895 .70355 m .69115 .64772 L .67483 .6558 L p .707 .577 .707 r
F P
0 g
s
.62729 .79078 m .63157 .82803 L .6608 .82202 L p .707 .577 .707 r
F P
0 g
s
.6608 .82202 m .65652 .78478 L .62729 .79078 L p .707 .577 .707 r
F P
0 g
s
.51143 .67509 m .51923 .73091 L .54 .73334 L p .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56468 .79663 L .56307 .79659 L p .707 .577 .707 r
F P
0 g
s
.56328 .80889 m .56007 .80838 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56307 .79659 L .5636 .82742 L .707 .577 .707 r
F
.56468 .79663 m .56896 .83388 L .59992 .83211 L p F P
0 g
s
.56007 .80838 m .55832 .82663 L .5636 .82746 L p .707 .577 .707 r
F P
0 g
s
.56371 .83374 m .56896 .83388 L p .5636 .82742 L .707 .577 .707 r
F P
0 g
s
.5636 .82746 m .58935 .8315 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56331 .81095 m .56007 .80838 L .5636 .82746 L .707 .577 .707 r
F
.55832 .82663 m .56007 .80838 L .53275 .80103 L p F P
0 g
s
.53275 .80103 m .531 .81928 L .55832 .82663 L p .707 .577 .707 r
F P
0 g
s
.53744 .79591 m .54172 .83316 L .56371 .83374 L p .707 .577 .707 r
F P
0 g
s
.5636 .82742 m .53744 .79591 L .56371 .83374 L .707 .577 .707 r
F
.56307 .79659 m .53744 .79591 L p .5636 .82742 L F P
0 g
s
.58935 .8315 m .5911 .81325 L .56328 .80889 L p .707 .577 .707 r
F P
0 g
s
.58935 .8315 m .56328 .80889 L .56331 .81095 L .707 .577 .707 r
F
.5911 .81325 m .58935 .8315 L .62106 .83339 L p F P
0 g
s
.62106 .83339 m .62281 .81514 L .5911 .81325 L p .707 .577 .707 r
F P
0 g
s
.62281 .81514 m .62106 .83339 L .65034 .83213 L p .707 .577 .707 r
F P
0 g
s
.65034 .83213 m .65209 .81388 L .62281 .81514 L p .707 .577 .707 r
F P
0 g
s
.65652 .78478 m .6608 .82202 L .68475 .81469 L p .707 .577 .707 r
F P
0 g
s
.68475 .81469 m .68047 .77744 L .65652 .78478 L p .707 .577 .707 r
F P
0 g
s
.51923 .73091 m .51143 .67509 L .49906 .6704 L p .707 .577 .707 r
F P
0 g
s
.65209 .81388 m .65034 .83213 L .67433 .82785 L p .707 .577 .707 r
F P
0 g
s
.67433 .82785 m .67608 .8096 L .65209 .81388 L p .707 .577 .707 r
F P
0 g
s
.531 .81928 m .53275 .80103 L .51182 .7919 L p .707 .577 .707 r
F P
0 g
s
.54172 .83316 m .53744 .79591 L .51657 .79276 L p .707 .577 .707 r
F P
0 g
s
.69115 .64772 m .69895 .70355 L .70608 .69589 L p .707 .577 .707 r
F P
0 g
s
.70608 .69589 m .69828 .64007 L .69115 .64772 L p .707 .577 .707 r
F P
0 g
s
.49906 .6704 m .50686 .72622 L .51923 .73091 L p .707 .577 .707 r
F P
0 g
s
.51182 .7919 m .51007 .81015 L .531 .81928 L p .707 .577 .707 r
F P
0 g
s
.51657 .79276 m .52085 .83001 L .54172 .83316 L p .707 .577 .707 r
F P
0 g
s
.68047 .77744 m .68475 .81469 L .70109 .80674 L p .707 .577 .707 r
F P
0 g
s
.70109 .80674 m .69681 .76949 L .68047 .77744 L p .707 .577 .707 r
F P
0 g
s
.67608 .8096 m .67433 .82785 L .69068 .82095 L p .707 .577 .707 r
F P
0 g
s
.69068 .82095 m .69242 .8027 L .67608 .8096 L p .707 .577 .707 r
F P
0 g
s
.50686 .72622 m .49906 .6704 L .49631 .66391 L p .707 .577 .707 r
F P
0 g
s
.51007 .81015 m .51182 .7919 L .49933 .7819 L p .707 .577 .707 r
F P
0 g
s
.52085 .83001 m .51657 .79276 L .50413 .7875 L p .707 .577 .707 r
F P
0 g
s
.49933 .7819 m .49758 .80015 L .51007 .81015 L p .707 .577 .707 r
F P
0 g
s
.50413 .7875 m .50841 .82475 L .52085 .83001 L p .707 .577 .707 r
F P
0 g
s
.69828 .64007 m .70608 .69589 L .70333 .6894 L p .707 .577 .707 r
F P
0 g
s
.70333 .6894 m .69553 .63358 L .69828 .64007 L p .707 .577 .707 r
F P
0 g
s
.49631 .66391 m .50411 .71973 L .50686 .72622 L p .707 .577 .707 r
F P
0 g
s
.69681 .76949 m .70109 .80674 L .70821 .79895 L p .707 .577 .707 r
F P
0 g
s
.70821 .79895 m .70393 .76171 L .69681 .76949 L p .707 .577 .707 r
F P
0 g
s
.69242 .8027 m .69068 .82095 L .69778 .81211 L p .707 .577 .707 r
F P
0 g
s
.69778 .81211 m .69953 .79386 L .69242 .8027 L p .707 .577 .707 r
F P
0 g
s
.4904 .8221 m .49342 .32054 L .44941 .31759 L p .707 .577 .707 r
F P
0 g
s
.50841 .82475 m .50413 .7875 L .50133 .78065 L p .707 .577 .707 r
F P
0 g
s
.49758 .80015 m .49933 .7819 L .4965 .77199 L p .707 .577 .707 r
F P
0 g
s
.50411 .71973 m .49631 .66391 L .50344 .65625 L p .707 .577 .707 r
F P
0 g
s
.4965 .77199 m .49475 .79024 L .49758 .80015 L p .707 .577 .707 r
F P
0 g
s
.50133 .78065 m .50561 .8179 L .50841 .82475 L p .707 .577 .707 r
F P
0 g
s
.50344 .65625 m .51124 .71208 L .50411 .71973 L p .707 .577 .707 r
F P
0 g
s
.49475 .79024 m .4965 .77199 L .5036 .76316 L p .707 .577 .707 r
F P
0 g
s
.51124 .71208 m .50344 .65625 L .51976 .64818 L p .707 .577 .707 r
F P
0 g
s
.50561 .8179 m .50133 .78065 L .50845 .77286 L p .707 .577 .707 r
F P
0 g
s
.5036 .76316 m .50186 .78141 L .49475 .79024 L p .707 .577 .707 r
F P
0 g
s
.50845 .77286 m .51273 .81011 L .50561 .8179 L p .707 .577 .707 r
F P
0 g
s
.51976 .64818 m .52756 .704 L .51124 .71208 L p .707 .577 .707 r
F P
0 g
s
.52756 .704 m .51976 .64818 L .54367 .64047 L p .707 .577 .707 r
F P
0 g
s
.50186 .78141 m .5036 .76316 L .51995 .75626 L p .707 .577 .707 r
F P
0 g
s
.51273 .81011 m .50845 .77286 L .52478 .76492 L p .707 .577 .707 r
F P
0 g
s
.51995 .75626 m .5182 .77451 L .50186 .78141 L p .707 .577 .707 r
F P
0 g
s
.52478 .76492 m .52906 .80216 L .51273 .81011 L p .707 .577 .707 r
F P
0 g
s
.52906 .80216 m .52478 .76492 L .54874 .75758 L p .707 .577 .707 r
F P
0 g
s
.5182 .77451 m .51995 .75626 L .54394 .75197 L p .707 .577 .707 r
F P
0 g
s
.54394 .75197 m .54219 .77022 L .5182 .77451 L p .707 .577 .707 r
F P
0 g
s
.54874 .75758 m .55302 .79483 L .52906 .80216 L p .707 .577 .707 r
F P
0 g
s
.49342 .32054 m .4904 .8221 L .53534 .82124 L p .707 .577 .707 r
F P
0 g
s
.54367 .64047 m .55147 .6963 L .52756 .704 L p .707 .577 .707 r
F P
0 g
s
.53534 .82124 m .53836 .31969 L .49342 .32054 L p .707 .577 .707 r
F P
0 g
s
.55147 .6963 m .54367 .64047 L .57283 .6339 L p .707 .577 .707 r
F P
0 g
s
.57283 .6339 m .58063 .68973 L .55147 .6963 L p .707 .577 .707 r
F P
0 g
s
.55302 .79483 m .54874 .75758 L .57797 .75158 L p .707 .577 .707 r
F P
0 g
s
.54219 .77022 m .54394 .75197 L .57322 .75071 L p .707 .577 .707 r
F P
0 g
s
.57797 .75158 m .58225 .78882 L .55302 .79483 L p .707 .577 .707 r
F P
0 g
s
.57322 .75071 m .57147 .76897 L .54219 .77022 L p .707 .577 .707 r
F P
0 g
s
.58225 .78882 m .57797 .75158 L .60961 .74749 L p .707 .577 .707 r
F P
0 g
s
.57147 .76897 m .57322 .75071 L .60493 .75261 L p .707 .577 .707 r
F P
0 g
s
.60961 .74749 m .61389 .78474 L .58225 .78882 L p .707 .577 .707 r
F P
0 g
s
.60493 .75261 m .60318 .77086 L .57147 .76897 L p .707 .577 .707 r
F P
0 g
s
.53836 .31969 m .53534 .82124 L .57682 .81666 L p .707 .577 .707 r
F P
0 g
s
.58063 .68973 m .57283 .6339 L .60438 .6291 L p .707 .577 .707 r
F P
0 g
s
.57682 .81666 m .57984 .31511 L .53836 .31969 L p .707 .577 .707 r
F P
0 g
s
.44639 .81915 m .44941 .31759 L .41065 .31112 L p .707 .577 .707 r
F P
0 g
s
.44941 .31759 m .44639 .81915 L .4904 .8221 L p .707 .577 .707 r
F P
0 g
s
.69553 .63358 m .70333 .6894 L .69096 .68471 L p .707 .577 .707 r
F P
0 g
s
.69096 .68471 m .68316 .62889 L .69553 .63358 L p .707 .577 .707 r
F P
0 g
s
.70393 .76171 m .70821 .79895 L .70541 .7921 L p .707 .577 .707 r
F P
0 g
s
.70541 .7921 m .70113 .75485 L .70393 .76171 L p .707 .577 .707 r
F P
0 g
s
.60438 .6291 m .61218 .68492 L .58063 .68973 L p .707 .577 .707 r
F P
0 g
s
.66328 .76483 m .66153 .78308 L .63886 .77698 L p .707 .577 .707 r
F P
0 g
s
.63885 .77399 m .66328 .76483 L .63886 .77698 L .707 .577 .707 r
F
.63889 .78331 m .61389 .78474 L p .63875 .74839 L F P
0 g
s
.63421 .77572 m .63596 .75747 L .66328 .76483 L p .707 .577 .707 r
F P
0 g
s
.64057 .74572 m .64485 .78297 L .63889 .78331 L p .707 .577 .707 r
F P
0 g
s
.63875 .74839 m .64057 .74572 L .63889 .78331 L .707 .577 .707 r
F
.63886 .77698 m .63421 .77572 L p .63885 .77399 L F P
0 g
s
.61389 .78474 m .60961 .74749 L .64057 .74572 L p .707 .577 .707 r
F P
0 g
s
.63596 .75747 m .63421 .77572 L .60318 .77086 L p .707 .577 .707 r
F P
0 g
s
.60318 .77086 m .60493 .75261 L .63596 .75747 L p .707 .577 .707 r
F P
0 g
s
.57984 .31511 m .57682 .81666 L .61078 .80881 L p .707 .577 .707 r
F P
0 g
s
.61218 .68492 m .60438 .6291 L .63524 .62653 L p .707 .577 .707 r
F P
0 g
s
.61078 .80881 m .6138 .30726 L .57984 .31511 L p .707 .577 .707 r
F P
0 g
s
.69953 .79386 m .69778 .81211 L .69495 .80221 L p .707 .577 .707 r
F P
0 g
s
.69495 .80221 m .6967 .78396 L .69953 .79386 L p .707 .577 .707 r
F P
0 g
s
.40763 .81268 m .41065 .31112 L .38092 .30177 L p .707 .577 .707 r
F P
0 g
s
.41065 .31112 m .40763 .81268 L .44639 .81915 L p .707 .577 .707 r
F P
0 g
s
.255 .72242 m .2472 .66659 L .21634 .66916 L p .707 .577 .707 r
F P
0 g
s
.2472 .66659 m .255 .72242 L .28655 .71762 L p .707 .577 .707 r
F P
0 g
s
.28655 .71762 m .27875 .66179 L .2472 .66659 L p .707 .577 .707 r
F P
0 g
s
.27875 .66179 m .28655 .71762 L .31571 .71104 L p .707 .577 .707 r
F P
0 g
s
.31571 .71104 m .30791 .65522 L .27875 .66179 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22414 .72498 m .22088 .70163 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.21634 .66916 m .22414 .72498 L .255 .72242 L p .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .25263 .7068 L .22176 .70856 L p .707 .577 .707 r
F P
0 g
s
.22176 .70856 m .22167 .70857 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .22176 .70856 L .22178 .70867 L .707 .577 .707 r
F
.22595 .74581 m .22167 .70857 L .19465 .70785 L p F P
0 g
s
.19465 .70785 m .19443 .70784 L p .19469 .70816 L .707 .577 .707 r
F P
0 g
s
.22595 .74581 m .19465 .70785 L .19469 .70816 L .707 .577 .707 r
F
.19443 .70784 m .19871 .74509 L .22595 .74581 L p F P
0 g
s
.19871 .74509 m .19443 .70784 L .17381 .70473 L p .707 .577 .707 r
F P
0 g
s
.17381 .70473 m .17356 .7047 L p .17388 .70521 L .707 .577 .707 r
F P
0 g
s
.19871 .74509 m .17381 .70473 L .17388 .70521 L .707 .577 .707 r
F
.17356 .7047 m .17784 .74194 L .19871 .74509 L p F P
0 g
s
.17784 .74194 m .17356 .7047 L .1613 .69951 L p .707 .577 .707 r
F P
0 g
s
.1613 .69951 m .16112 .69944 L p .16138 .70011 L .707 .577 .707 r
F P
0 g
s
.17784 .74194 m .1613 .69951 L .16138 .70011 L .707 .577 .707 r
F
.16112 .69944 m .1654 .73668 L .17784 .74194 L p F P
0 g
s
.1654 .73668 m .16112 .69944 L .15836 .69269 L p .707 .577 .707 r
F P
0 g
s
.15836 .69269 m .15832 .69258 L p .15844 .69333 L .707 .577 .707 r
F P
0 g
s
.1654 .73668 m .15836 .69269 L .15844 .69333 L .707 .577 .707 r
F
.16385 .71794 m .16044 .69354 L p .1533 .65562 L F P
0 g
s
.16044 .69354 m .15605 .66211 L .15588 .66172 L p .707 .577 .707 r
F P
0 g
s
.15588 .66172 m .1533 .65562 L p .16044 .69354 L .707 .577 .707 r
F P
0 g
s
.17622 .72263 m .17285 .69851 L p .15605 .66211 L .707 .577 .707 r
F P
0 g
s
.16793 .66662 m .15605 .66211 L p .17285 .69851 L .707 .577 .707 r
F P
0 g
s
.15605 .66211 m .16385 .71794 L .17622 .72263 L p .707 .577 .707 r
F P
0 g
s
.15832 .69258 m .1626 .72983 L .1654 .73668 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .16385 .71794 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1533 .65562 m .15766 .68687 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.15766 .68687 m .1611 .71145 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1626 .72983 m .15832 .69258 L .15842 .69247 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .15766 .68687 L p .16043 .64797 L .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .1611 .71145 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16043 .64797 m .16479 .67915 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16479 .67915 m .16823 .70379 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.17285 .69851 m .16842 .6668 L .16793 .66662 L p .707 .577 .707 r
F P
0 g
s
.197 .72506 m .19367 .7013 L p .16842 .6668 L .707 .577 .707 r
F P
0 g
s
.18891 .6692 m .16842 .6668 L p .19367 .7013 L .707 .577 .707 r
F P
0 g
s
.16842 .6668 m .17622 .72263 L .197 .72506 L p .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .16043 .64797 L .17675 .63989 L p .707 .577 .707 r
F P
0 g
s
.16972 .72204 m .16544 .6848 L .16569 .68468 L p .707 .577 .707 r
F P
0 g
s
.18455 .69572 m .16823 .70379 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.17675 .63989 m .18112 .67114 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.18112 .67114 m .18455 .69572 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.19367 .7013 m .18919 .66923 L .18891 .6692 L p .707 .577 .707 r
F P
0 g
s
.22167 .70857 m .22595 .74581 L .22654 .74578 L p .707 .577 .707 r
F P
0 g
s
.22387 .72499 m .22414 .72498 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.22654 .74578 m .25691 .74405 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.22178 .70867 m .22167 .70857 L .22654 .74578 L .707 .577 .707 r
F
.18919 .66923 m .197 .72506 L .22387 .72499 L p F P
0 g
s
.2238 .72444 m .18919 .66923 L .22387 .72499 L .707 .577 .707 r
F
.21634 .66916 m .18919 .66923 L p .2238 .72444 L F P
0 g
s
.18455 .69572 m .17675 .63989 L .20066 .63219 L p .707 .577 .707 r
F P
0 g
s
.18605 .7141 m .18177 .67685 L .18214 .67674 L p .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .18455 .69572 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20066 .63219 m .20505 .66362 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20505 .66362 m .20846 .68802 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .20066 .63219 L .22982 .62562 L p .707 .577 .707 r
F P
0 g
s
.21001 .70676 m .20573 .66951 L .20615 .66943 L p .707 .577 .707 r
F P
0 g
s
.22088 .70163 m .21634 .66916 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .20846 .68802 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.22982 .62562 m .23425 .65733 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23425 .65733 m .23762 .68144 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .22982 .62562 L .26137 .62081 L p .707 .577 .707 r
F P
0 g
s
.23924 .70076 m .23496 .66351 L .23534 .66346 L p .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .23762 .68144 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26137 .62081 m .26585 .65288 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26585 .65288 m .26917 .67664 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .26137 .62081 L .29223 .61825 L p .707 .577 .707 r
F P
0 g
s
.27088 .69667 m .2666 .65942 L .26685 .65941 L p .707 .577 .707 r
F P
0 g
s
.29223 .61825 m .29677 .65072 L p .26917 .67664 L .707 .577 .707 r
F P
0 g
s
.30791 .65522 m .31571 .71104 L .33962 .70334 L p .707 .577 .707 r
F P
0 g
s
.33962 .70334 m .33182 .64751 L .30791 .65522 L p .707 .577 .707 r
F P
0 g
s
.29765 .65766 m .32481 .65838 L p .30227 .69423 L .707 .577 .707 r
F P
0 g
s
.29677 .65072 m .30003 .67407 L .29973 .6741 L p .707 .577 .707 r
F P
0 g
s
.29973 .6741 m .26917 .67664 L p .29677 .65072 L .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29757 .65766 L .29765 .65766 L p .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29765 .65766 L .30227 .69423 L .707 .577 .707 r
F
.26685 .65941 m .29757 .65766 L p .27227 .69465 L F P
0 g
s
.27088 .69667 m .26685 .65941 L .27227 .69465 L .707 .577 .707 r
F
.23534 .66346 m .2666 .65942 L p .24138 .69753 L F P
0 g
s
.23924 .70076 m .23534 .66346 L .24138 .69753 L .707 .577 .707 r
F
.20615 .66943 m .23496 .66351 L p .21241 .7026 L F P
0 g
s
.21001 .70676 m .20615 .66943 L .21241 .7026 L .707 .577 .707 r
F
.18214 .67674 m .20573 .66951 L p .18812 .70941 L F P
0 g
s
.18605 .7141 m .18214 .67674 L .18812 .70941 L .707 .577 .707 r
F
.16569 .68468 m .18177 .67685 L p .17098 .7173 L F P
0 g
s
.16972 .72204 m .16569 .68468 L .17098 .7173 L .707 .577 .707 r
F
.15842 .69247 m .16544 .6848 L p .16287 .72552 L F P
0 g
s
.1626 .72983 m .15842 .69247 L .16287 .72552 L .707 .577 .707 r
F
.15766 .68687 m .1533 .65562 L .15384 .65504 L p F P
0 g
s
.15384 .65504 m .16043 .64797 L p .15766 .68687 L .707 .577 .707 r
F P
0 g
s
.25263 .7068 m .25691 .74405 L .28856 .73996 L p .707 .577 .707 r
F P
0 g
s
.28856 .73996 m .28428 .70271 L .25263 .7068 L p .707 .577 .707 r
F P
0 g
s
.68316 .62889 m .69096 .68471 L .67019 .68229 L p .707 .577 .707 r
F P
0 g
s
.67019 .68229 m .66238 .62646 L .68316 .62889 L p .707 .577 .707 r
F P
0 g
s
.28428 .70271 m .28856 .73996 L .31779 .73396 L p .707 .577 .707 r
F P
0 g
s
.31779 .73396 m .31351 .69671 L .28428 .70271 L p .707 .577 .707 r
F P
0 g
s
.6967 .78396 m .69495 .80221 L .68246 .79221 L p .707 .577 .707 r
F P
0 g
s
.68246 .79221 m .68421 .77396 L .6967 .78396 L p .707 .577 .707 r
F P
0 g
s
.70113 .75485 m .70541 .7921 L .69297 .78684 L p .707 .577 .707 r
F P
0 g
s
.69297 .78684 m .68869 .74959 L .70113 .75485 L p .707 .577 .707 r
F P
0 g
s
.63524 .62653 m .64304 .68236 L .61218 .68492 L p .707 .577 .707 r
F P
0 g
s
.6138 .30726 m .61078 .80881 L .63389 .79845 L p .707 .577 .707 r
F P
0 g
s
.63389 .79845 m .63691 .2969 L .6138 .30726 L p .707 .577 .707 r
F P
0 g
s
.31351 .69671 m .31779 .73396 L .34175 .72662 L p .707 .577 .707 r
F P
0 g
s
.34175 .72662 m .33747 .68937 L .31351 .69671 L p .707 .577 .707 r
F P
0 g
s
.3779 .80332 m .38092 .30177 L .36315 .29045 L p .707 .577 .707 r
F P
0 g
s
.38092 .30177 m .3779 .80332 L .40763 .81268 L p .707 .577 .707 r
F P
0 g
s
.33182 .64751 m .33962 .70334 L .35594 .69527 L p .707 .577 .707 r
F P
0 g
s
.35594 .69527 m .34814 .63944 L .33182 .64751 L p .707 .577 .707 r
F P
0 g
s
.66238 .62646 m .67019 .68229 L .64304 .68236 L p .707 .577 .707 r
F P
0 g
s
.64304 .68236 m .63524 .62653 L .66238 .62646 L p .707 .577 .707 r
F P
0 g
s
.68421 .77396 m .68246 .79221 L .66153 .78308 L p .707 .577 .707 r
F P
0 g
s
.66153 .78308 m .66328 .76483 L .68421 .77396 L p .707 .577 .707 r
F P
0 g
s
.68869 .74959 m .69297 .78684 L .6721 .78369 L p .707 .577 .707 r
F P
0 g
s
.6721 .78369 m .66782 .74645 L .68869 .74959 L p .707 .577 .707 r
F P
0 g
s
.33747 .68937 m .34175 .72662 L .35808 .71867 L p .707 .577 .707 r
F P
0 g
s
.35808 .71867 m .3538 .68142 L .33747 .68937 L p .707 .577 .707 r
F P
0 g
s
.24634 .83948 m .24809 .82123 L .21706 .81637 L p .707 .577 .707 r
F P
0 g
s
.24809 .82123 m .24634 .83948 L .27805 .84138 L p .707 .577 .707 r
F P
0 g
s
.27805 .84138 m .2798 .82313 L .24809 .82123 L p .707 .577 .707 r
F P
0 g
s
.2798 .82313 m .27805 .84138 L .30733 .84012 L p .707 .577 .707 r
F P
0 g
s
.30733 .84012 m .30908 .82187 L .2798 .82313 L p .707 .577 .707 r
F P
0 g
s
.21706 .81637 m .21531 .83462 L .24634 .83948 L p .707 .577 .707 r
F P
0 g
s
.21531 .83462 m .21706 .81637 L .18974 .80902 L p .707 .577 .707 r
F P
0 g
s
.64485 .78297 m .64057 .74572 L .66782 .74645 L p .707 .577 .707 r
F P
0 g
s
.63691 .2969 m .63389 .79845 L .64389 .7866 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .64691 .28505 L .63691 .2969 L p .707 .577 .707 r
F P
0 g
s
.18974 .80902 m .18799 .82727 L .21531 .83462 L p .707 .577 .707 r
F P
0 g
s
.30908 .82187 m .30733 .84012 L .33132 .83583 L p .707 .577 .707 r
F P
0 g
s
.33132 .83583 m .33307 .81758 L .30908 .82187 L p .707 .577 .707 r
F P
0 g
s
.34814 .63944 m .35594 .69527 L .36307 .68761 L p .707 .577 .707 r
F P
0 g
s
.36307 .68761 m .35527 .63178 L .34814 .63944 L p .707 .577 .707 r
F P
0 g
s
.18799 .82727 m .18974 .80902 L .16881 .79989 L p .707 .577 .707 r
F P
0 g
s
.66782 .74645 m .6721 .78369 L .64485 .78297 L p .707 .577 .707 r
F P
0 g
s
.3538 .68142 m .35808 .71867 L .3652 .71089 L p .707 .577 .707 r
F P
0 g
s
.3652 .71089 m .36092 .67364 L .3538 .68142 L p .707 .577 .707 r
F P
0 g
s
.36092 .67364 m .3652 .71089 L .3624 .70403 L p .707 .577 .707 r
F P
0 g
s
.3624 .70403 m .35812 .66678 L .36092 .67364 L p .707 .577 .707 r
F P
0 g
s
.35527 .63178 m .36307 .68761 L .36032 .68112 L p .707 .577 .707 r
F P
0 g
s
.36032 .68112 m .35252 .62529 L .35527 .63178 L p .707 .577 .707 r
F P
0 g
s
.35812 .66678 m .3624 .70403 L .34996 .69877 L p .707 .577 .707 r
F P
0 g
s
.34996 .69877 m .34568 .66153 L .35812 .66678 L p .707 .577 .707 r
F P
0 g
s
.35252 .62529 m .36032 .68112 L .34795 .67643 L p .707 .577 .707 r
F P
0 g
s
.36012 .792 m .36315 .29045 L .35906 .27826 L p .707 .577 .707 r
F P
0 g
s
.36315 .29045 m .36012 .792 L .3779 .80332 L p .707 .577 .707 r
F P
0 g
s
.16881 .79989 m .16706 .81814 L .18799 .82727 L p .707 .577 .707 r
F P
0 g
s
.33307 .81758 m .33132 .83583 L .34767 .82894 L p .707 .577 .707 r
F P
0 g
s
.34767 .82894 m .34941 .81069 L .33307 .81758 L p .707 .577 .707 r
F P
0 g
s
.16706 .81814 m .16881 .79989 L .15632 .78988 L p .707 .577 .707 r
F P
0 g
s
.15632 .78988 m .15457 .80814 L .16706 .81814 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .6398 .77442 L p .64238 .59686 L .707 .577 .707 r
F P
0 g
s
.64238 .59686 m .64559 .37583 L .64465 .60277 L .707 .577 .707 r
F
.64238 .59686 m .64465 .60277 L .64389 .7866 L F
.64282 .27286 m .6398 .77442 L .62202 .7631 L p F P
0 g
s
.63626 .57836 m .63351 .57187 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.64282 .27286 m .64691 .28505 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.6398 .77442 m .64164 .46898 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64164 .46898 m .64282 .27286 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64649 .35462 m .64389 .7866 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .65643 .63887 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63626 .57836 m .63683 .58239 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .64407 .63419 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .63683 .58239 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .63626 .57836 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .64863 .58305 L .63699 .57863 L p .707 .577 .707 r
F P
0 g
s
.63699 .57863 m .63626 .57836 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .63699 .57863 L .63692 .58032 L .707 .577 .707 r
F
.64691 .28505 m .64649 .35462 L p .64559 .37583 L F P
0 g
s
.34941 .81069 m .34767 .82894 L .35477 .8201 L p .707 .577 .707 r
F P
0 g
s
.35477 .8201 m .35652 .80185 L .34941 .81069 L p .707 .577 .707 r
F P
0 g
s
.35906 .27826 m .35603 .77982 L .36012 .792 L p .707 .577 .707 r
F P
0 g
s
.35603 .77982 m .35906 .27826 L .36906 .26641 L p .707 .577 .707 r
F P
0 g
s
.15457 .80814 m .15632 .78988 L .15349 .77998 L p .707 .577 .707 r
F P
0 g
s
.15349 .77998 m .15174 .79823 L .15457 .80814 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34795 .67643 m .34015 .6206 L .35252 .62529 L p .707 .577 .707 r
F P
0 g
s
.16544 .6848 m .16972 .72204 L .1626 .72983 L p .707 .577 .707 r
F P
0 g
s
.62202 .7631 m .62504 .26154 L .64282 .27286 L p .707 .577 .707 r
F P
0 g
s
.35652 .80185 m .35477 .8201 L .35194 .8102 L p .707 .577 .707 r
F P
0 g
s
.35194 .8102 m .35369 .79195 L .35652 .80185 L p .707 .577 .707 r
F P
0 g
s
.15174 .79823 m .15349 .77998 L .16059 .77115 L p .707 .577 .707 r
F P
0 g
s
.16059 .77115 m .15885 .7894 L .15174 .79823 L p .707 .577 .707 r
F P
0 g
s
.34568 .66153 m .34996 .69877 L .32909 .69563 L p .707 .577 .707 r
F P
0 g
s
.32909 .69563 m .32481 .65838 L .34568 .66153 L p .707 .577 .707 r
F P
0 g
s
.34015 .6206 m .34795 .67643 L .32718 .674 L p .707 .577 .707 r
F P
0 g
s
.32718 .674 m .31938 .61818 L .34015 .6206 L p .707 .577 .707 r
F P
0 g
s
.36603 .76797 m .36906 .26641 L .39217 .25605 L p .707 .577 .707 r
F P
0 g
s
.36906 .26641 m .36603 .76797 L .35603 .77982 L p .707 .577 .707 r
F P
0 g
s
.18177 .67685 m .18605 .7141 L .16972 .72204 L p .707 .577 .707 r
F P
0 g
s
.35369 .79195 m .35194 .8102 L .33945 .80019 L p .707 .577 .707 r
F P
0 g
s
.33945 .80019 m .3412 .78194 L .35369 .79195 L p .707 .577 .707 r
F P
0 g
s
.15885 .7894 m .16059 .77115 L .17694 .76425 L p .707 .577 .707 r
F P
0 g
s
.32481 .65838 m .32909 .69563 L .30185 .6949 L p .707 .577 .707 r
F P
0 g
s
.31938 .61818 m .32718 .674 L .30003 .67407 L p .707 .577 .707 r
F P
0 g
s
.30003 .67407 m .29223 .61825 L .31938 .61818 L p .707 .577 .707 r
F P
0 g
s
.62504 .26154 m .62202 .7631 L .5923 .75374 L p .707 .577 .707 r
F P
0 g
s
.5923 .75374 m .59532 .25219 L .62504 .26154 L p .707 .577 .707 r
F P
0 g
s
.17694 .76425 m .17519 .7825 L .15885 .7894 L p .707 .577 .707 r
F P
0 g
s
.20573 .66951 m .21001 .70676 L .18605 .7141 L p .707 .577 .707 r
F P
0 g
s
.73521 .63867 m .72741 .58284 L .69655 .5854 L p .707 .577 .707 r
F P
0 g
s
.72741 .58284 m .73521 .63867 L .76677 .63386 L p .707 .577 .707 r
F P
0 g
s
.76677 .63386 m .75896 .57804 L .72741 .58284 L p .707 .577 .707 r
F P
0 g
s
.39217 .25605 m .38914 .75761 L .36603 .76797 L p .707 .577 .707 r
F P
0 g
s
.38914 .75761 m .39217 .25605 L .42612 .2482 L p .707 .577 .707 r
F P
0 g
s
.75896 .57804 m .76677 .63386 L .79593 .62729 L p .707 .577 .707 r
F P
0 g
s
.79593 .62729 m .78812 .57146 L .75896 .57804 L p .707 .577 .707 r
F P
0 g
s
.3412 .78194 m .33945 .80019 L .31852 .79107 L p .707 .577 .707 r
F P
0 g
s
.31852 .79107 m .32027 .77282 L .3412 .78194 L p .707 .577 .707 r
F P
0 g
s
.70435 .64123 m .69655 .5854 L .66941 .58547 L p .707 .577 .707 r
F P
0 g
s
.69655 .5854 m .70435 .64123 L .73521 .63867 L p .707 .577 .707 r
F P
0 g
s
.29757 .65766 m .30185 .6949 L .27088 .69667 L p .707 .577 .707 r
F P
0 g
s
.17519 .7825 m .17694 .76425 L .20093 .75996 L p .707 .577 .707 r
F P
0 g
s
.23496 .66351 m .23924 .70076 L .21001 .70676 L p .707 .577 .707 r
F P
0 g
s
.78812 .57146 m .79593 .62729 L .81983 .61959 L p .707 .577 .707 r
F P
0 g
s
.81983 .61959 m .81203 .56376 L .78812 .57146 L p .707 .577 .707 r
F P
0 g
s
.20093 .75996 m .19918 .77821 L .17519 .7825 L p .707 .577 .707 r
F P
0 g
s
.2666 .65942 m .27088 .69667 L .23924 .70076 L p .707 .577 .707 r
F P
0 g
s
.59532 .25219 m .5923 .75374 L .55353 .74727 L p .707 .577 .707 r
F P
0 g
s
.55353 .74727 m .55655 .24572 L .59532 .25219 L p .707 .577 .707 r
F P
0 g
s
.66941 .58547 m .67721 .6413 L .70435 .64123 L p .707 .577 .707 r
F P
0 g
s
.67721 .6413 m .66941 .58547 L .64863 .58305 L p .707 .577 .707 r
F P
0 g
s
.32027 .77282 m .31852 .79107 L .2912 .78371 L p .707 .577 .707 r
F P
0 g
s
.2912 .78371 m .29295 .76546 L .32027 .77282 L p .707 .577 .707 r
F P
0 g
s
.4231 .74975 m .42612 .2482 L .4676 .24362 L p .707 .577 .707 r
F P
0 g
s
.42612 .2482 m .4231 .74975 L .38914 .75761 L p .707 .577 .707 r
F P
0 g
s
.19918 .77821 m .20093 .75996 L .23021 .7587 L p .707 .577 .707 r
F P
0 g
s
.73713 .74007 m .73285 .70283 L .70189 .70459 L p .707 .577 .707 r
F P
0 g
s
.73285 .70283 m .73713 .74007 L .76877 .73599 L p .707 .577 .707 r
F P
0 g
s
.76877 .73599 m .76449 .69874 L .73285 .70283 L p .707 .577 .707 r
F P
0 g
s
.81203 .56376 m .81983 .61959 L .83615 .61151 L p .707 .577 .707 r
F P
0 g
s
.83615 .61151 m .82835 .55568 L .81203 .56376 L p .707 .577 .707 r
F P
0 g
s
.76449 .69874 m .76877 .73599 L .798 .72998 L p .707 .577 .707 r
F P
0 g
s
.798 .72998 m .79372 .69274 L .76449 .69874 L p .707 .577 .707 r
F P
0 g
s
.23021 .7587 m .22846 .77695 L .19918 .77821 L p .707 .577 .707 r
F P
0 g
s
.64863 .58305 m .65643 .63887 L .67721 .6413 L p .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70189 .70459 L .70027 .70455 L p .707 .577 .707 r
F P
0 g
s
.70048 .71685 m .69727 .71635 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70027 .70455 L .7008 .73538 L .707 .577 .707 r
F
.70189 .70459 m .70617 .74184 L .73713 .74007 L p F P
0 g
s
.69727 .71635 m .69552 .7346 L .7008 .73542 L p .707 .577 .707 r
F P
0 g
s
.70091 .7417 m .70617 .74184 L p .7008 .73538 L .707 .577 .707 r
F P
0 g
s
.7008 .73542 m .72655 .73946 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70052 .71891 m .69727 .71635 L .7008 .73542 L .707 .577 .707 r
F
.69552 .7346 m .69727 .71635 L .66995 .70899 L p F P
0 g
s
.66995 .70899 m .66821 .72724 L .69552 .7346 L p .707 .577 .707 r
F P
0 g
s
.67464 .70387 m .67892 .74112 L .70091 .7417 L p .707 .577 .707 r
F P
0 g
s
.7008 .73538 m .67464 .70387 L .70091 .7417 L .707 .577 .707 r
F
.70027 .70455 m .67464 .70387 L p .7008 .73538 L F P
0 g
s
.72655 .73946 m .7283 .72121 L .70048 .71685 L p .707 .577 .707 r
F P
0 g
s
.72655 .73946 m .70048 .71685 L .70052 .71891 L .707 .577 .707 r
F
.7283 .72121 m .72655 .73946 L .75826 .74135 L p F P
0 g
s
.75826 .74135 m .76001 .7231 L .7283 .72121 L p .707 .577 .707 r
F P
0 g
s
.55655 .24572 m .55353 .74727 L .50952 .74432 L p .707 .577 .707 r
F P
0 g
s
.50952 .74432 m .51255 .24277 L .55655 .24572 L p .707 .577 .707 r
F P
0 g
s
.29295 .76546 m .2912 .78371 L .26017 .77885 L p .707 .577 .707 r
F P
0 g
s
.26017 .77885 m .26192 .7606 L .29295 .76546 L p .707 .577 .707 r
F P
0 g
s
.76001 .7231 m .75826 .74135 L .78754 .7401 L p .707 .577 .707 r
F P
0 g
s
.78754 .7401 m .78929 .72185 L .76001 .7231 L p .707 .577 .707 r
F P
0 g
s
.22846 .77695 m .23021 .7587 L .26192 .7606 L p .707 .577 .707 r
F P
0 g
s
.79372 .69274 m .798 .72998 L .82196 .72265 L p .707 .577 .707 r
F P
0 g
s
.82196 .72265 m .81768 .6854 L .79372 .69274 L p .707 .577 .707 r
F P
0 g
s
.46458 .74518 m .4676 .24362 L .51255 .24277 L p .707 .577 .707 r
F P
0 g
s
.4676 .24362 m .46458 .74518 L .4231 .74975 L p .707 .577 .707 r
F P
0 g
s
.26192 .7606 m .26017 .77885 L .22846 .77695 L p .707 .577 .707 r
F P
0 g
s
.51255 .24277 m .50952 .74432 L .46458 .74518 L p .707 .577 .707 r
F P
0 g
s
.78929 .72185 m .78754 .7401 L .81153 .73581 L p .707 .577 .707 r
F P
0 g
s
.81153 .73581 m .81328 .71756 L .78929 .72185 L p .707 .577 .707 r
F P
0 g
s
.66821 .72724 m .66995 .70899 L .64903 .69986 L p .707 .577 .707 r
F P
0 g
s
.67892 .74112 m .67464 .70387 L .65377 .70072 L p .707 .577 .707 r
F P
0 g
s
.82835 .55568 m .83615 .61151 L .84329 .60385 L p .707 .577 .707 r
F P
0 g
s
.84329 .60385 m .83548 .54803 L .82835 .55568 L p .707 .577 .707 r
F P
0 g
s
.64903 .69986 m .64728 .71811 L .66821 .72724 L p .707 .577 .707 r
F P
0 g
s
.65377 .70072 m .65805 .73797 L .67892 .74112 L p .707 .577 .707 r
F P
0 g
s
.81768 .6854 m .82196 .72265 L .8383 .7147 L p .707 .577 .707 r
F P
0 g
s
.8383 .7147 m .83402 .67745 L .81768 .6854 L p .707 .577 .707 r
F P
0 g
s
.81328 .71756 m .81153 .73581 L .82788 .72891 L p .707 .577 .707 r
F P
0 g
s
.82788 .72891 m .82963 .71066 L .81328 .71756 L p .707 .577 .707 r
F P
0 g
s
.64728 .71811 m .64903 .69986 L .63653 .68986 L p .707 .577 .707 r
F P
0 g
s
.65805 .73797 m .65377 .70072 L .64133 .69547 L p .707 .577 .707 r
F P
0 g
s
.63653 .68986 m .63479 .70811 L .64728 .71811 L p .707 .577 .707 r
F P
0 g
s
.64133 .69547 m .64561 .73271 L .65805 .73797 L p .707 .577 .707 r
F P
0 g
s
.83548 .54803 m .84329 .60385 L .84053 .59736 L p .707 .577 .707 r
F P
0 g
s
.84053 .59736 m .83273 .54154 L .83548 .54803 L p .707 .577 .707 r
F P
0 g
s
.63351 .57187 m .64131 .6277 L .64407 .63419 L p .707 .577 .707 r
F P
0 g
s
.83402 .67745 m .8383 .7147 L .84541 .70692 L p .707 .577 .707 r
F P
0 g
s
.84541 .70692 m .84113 .66967 L .83402 .67745 L p .707 .577 .707 r
F P
0 g
s
.82963 .71066 m .82788 .72891 L .83499 .72008 L p .707 .577 .707 r
F P
0 g
s
.83499 .72008 m .83673 .70183 L .82963 .71066 L p .707 .577 .707 r
F P
0 g
s
.64561 .73271 m .64133 .69547 L .63853 .68861 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63479 .70811 m .63653 .68986 L .6337 .67995 L p .707 .577 .707 r
F P
0 g
s
.64131 .6277 m .63351 .57187 L .64064 .56421 L p .707 .577 .707 r
F P
0 g
s
.6337 .67995 m .63195 .69821 L .63479 .70811 L p .707 .577 .707 r
F P
0 g
s
.63853 .68861 m .64281 .72586 L .64561 .73271 L p .707 .577 .707 r
F P
0 g
s
.83273 .54154 m .84053 .59736 L .82817 .59268 L p .707 .577 .707 r
F P
0 g
s
.82817 .59268 m .82036 .53685 L .83273 .54154 L p .707 .577 .707 r
F P
0 g
s
.84113 .66967 m .84541 .70692 L .84261 .70006 L p .707 .577 .707 r
F P
0 g
s
.84261 .70006 m .83833 .66281 L .84113 .66967 L p .707 .577 .707 r
F P
0 g
s
.64064 .56421 m .64845 .62004 L .64131 .6277 L p .707 .577 .707 r
F P
0 g
s
.83673 .70183 m .83499 .72008 L .83215 .71017 L p .707 .577 .707 r
F P
0 g
s
.83215 .71017 m .8339 .69192 L .83673 .70183 L p .707 .577 .707 r
F P
0 g
s
.63195 .69821 m .6337 .67995 L .64081 .67112 L p .707 .577 .707 r
F P
0 g
s
.64845 .62004 m .64064 .56421 L .65696 .55614 L p .707 .577 .707 r
F P
0 g
s
.64281 .72586 m .63853 .68861 L .64565 .68083 L p .707 .577 .707 r
F P
0 g
s
.3922 .63038 m .3844 .57456 L .35354 .57712 L p .707 .577 .707 r
F P
0 g
s
.3844 .57456 m .3922 .63038 L .42376 .62558 L p .707 .577 .707 r
F P
0 g
s
.42376 .62558 m .41595 .56975 L .3844 .57456 L p .707 .577 .707 r
F P
0 g
s
.41595 .56975 m .42376 .62558 L .45292 .619 L p .707 .577 .707 r
F P
0 g
s
.45292 .619 m .44511 .56318 L .41595 .56975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64081 .67112 m .63906 .68937 L .63195 .69821 L p .707 .577 .707 r
F P
0 g
s
.36134 .63295 m .35808 .60959 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.35354 .57712 m .36134 .63295 L .3922 .63038 L p .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .38984 .61476 L .35897 .61652 L p .707 .577 .707 r
F P
0 g
s
.35897 .61652 m .35888 .61653 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .35897 .61652 L .35898 .61663 L .707 .577 .707 r
F
.36316 .65377 m .35888 .61653 L .33185 .61581 L p F P
0 g
s
.33185 .61581 m .33163 .6158 L p .3319 .61612 L .707 .577 .707 r
F P
0 g
s
.36316 .65377 m .33185 .61581 L .3319 .61612 L .707 .577 .707 r
F
.33163 .6158 m .33591 .65305 L .36316 .65377 L p F P
0 g
s
.33591 .65305 m .33163 .6158 L .31101 .61269 L p .707 .577 .707 r
F P
0 g
s
.31101 .61269 m .31076 .61266 L p .31109 .61318 L .707 .577 .707 r
F P
0 g
s
.33591 .65305 m .31101 .61269 L .31109 .61318 L .707 .577 .707 r
F
.31076 .61266 m .31504 .6499 L .33591 .65305 L p F P
0 g
s
.31504 .6499 m .31076 .61266 L .2985 .60747 L p .707 .577 .707 r
F P
0 g
s
.2985 .60747 m .29832 .6074 L p .29859 .60807 L .707 .577 .707 r
F P
0 g
s
.31504 .6499 m .2985 .60747 L .29859 .60807 L .707 .577 .707 r
F
.29832 .6074 m .3026 .64465 L .31504 .6499 L p F P
0 g
s
.3026 .64465 m .29832 .6074 L .29557 .60065 L p .707 .577 .707 r
F P
0 g
s
.29557 .60065 m .29552 .60054 L p .29564 .6013 L .707 .577 .707 r
F P
0 g
s
.3026 .64465 m .29557 .60065 L .29564 .6013 L .707 .577 .707 r
F
.30106 .6259 m .29765 .6015 L p .2905 .56359 L F P
0 g
s
.29765 .6015 m .29325 .57008 L .29309 .56968 L p .707 .577 .707 r
F P
0 g
s
.29309 .56968 m .2905 .56359 L p .29765 .6015 L .707 .577 .707 r
F P
0 g
s
.31342 .63059 m .31005 .60648 L p .29325 .57008 L .707 .577 .707 r
F P
0 g
s
.30514 .57458 m .29325 .57008 L p .31005 .60648 L .707 .577 .707 r
F P
0 g
s
.29325 .57008 m .30106 .6259 L .31342 .63059 L p .707 .577 .707 r
F P
0 g
s
.29552 .60054 m .2998 .63779 L .3026 .64465 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .30106 .6259 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2905 .56359 m .29487 .59483 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.29487 .59483 m .2983 .61941 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2998 .63779 m .29552 .60054 L .29562 .60043 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .29487 .59483 L p .29763 .55593 L .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .2983 .61941 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.29763 .55593 m .30199 .58711 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.30199 .58711 m .30544 .61175 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.31005 .60648 m .30562 .57476 L .30514 .57458 L p .707 .577 .707 r
F P
0 g
s
.3342 .63302 m .33088 .60926 L p .30562 .57476 L .707 .577 .707 r
F P
0 g
s
.32611 .57716 m .30562 .57476 L p .33088 .60926 L .707 .577 .707 r
F P
0 g
s
.30562 .57476 m .31342 .63059 L .3342 .63302 L p .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .29763 .55593 L .31395 .54785 L p .707 .577 .707 r
F P
0 g
s
.30692 .63001 m .30264 .59276 L .30289 .59264 L p .707 .577 .707 r
F P
0 g
s
.32176 .60368 m .30544 .61175 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31395 .54785 m .31832 .5791 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31832 .5791 m .32176 .60368 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.33088 .60926 m .3264 .57719 L .32611 .57716 L p .707 .577 .707 r
F P
0 g
s
.35888 .61653 m .36316 .65377 L .36374 .65374 L p .707 .577 .707 r
F P
0 g
s
.36107 .63295 m .36134 .63295 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.36374 .65374 m .39412 .65201 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.35898 .61663 m .35888 .61653 L .36374 .65374 L .707 .577 .707 r
F
.3264 .57719 m .3342 .63302 L .36107 .63295 L p F P
0 g
s
.361 .6324 m .3264 .57719 L .36107 .63295 L .707 .577 .707 r
F
.35354 .57712 m .3264 .57719 L p .361 .6324 L F P
0 g
s
.32176 .60368 m .31395 .54785 L .33786 .54015 L p .707 .577 .707 r
F P
0 g
s
.32326 .62206 m .31898 .58481 L .31934 .5847 L p .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .32176 .60368 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.33786 .54015 m .34225 .57158 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34225 .57158 m .34566 .59598 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .33786 .54015 L .36702 .53358 L p .707 .577 .707 r
F P
0 g
s
.34721 .61472 m .34293 .57747 L .34335 .57739 L p .707 .577 .707 r
F P
0 g
s
.35808 .60959 m .35354 .57712 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .34566 .59598 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.36702 .53358 m .37145 .56529 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37145 .56529 m .37482 .5894 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .36702 .53358 L .39857 .52877 L p .707 .577 .707 r
F P
0 g
s
.37644 .60872 m .37216 .57147 L .37254 .57142 L p .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .37482 .5894 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.39857 .52877 m .40306 .56084 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40306 .56084 m .40638 .5846 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .39857 .52877 L .42943 .52621 L p .707 .577 .707 r
F P
0 g
s
.40809 .60463 m .40381 .56738 L .40406 .56737 L p .707 .577 .707 r
F P
0 g
s
.42943 .52621 m .43397 .55868 L p .40638 .5846 L .707 .577 .707 r
F P
0 g
s
.44511 .56318 m .45292 .619 L .47682 .6113 L p .707 .577 .707 r
F P
0 g
s
.47682 .6113 m .46902 .55548 L .44511 .56318 L p .707 .577 .707 r
F P
0 g
s
.43485 .56562 m .46202 .56634 L p .43947 .60219 L .707 .577 .707 r
F P
0 g
s
.43397 .55868 m .43724 .58204 L .43693 .58206 L p .707 .577 .707 r
F P
0 g
s
.43693 .58206 m .40638 .5846 L p .43397 .55868 L .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43477 .56562 L .43485 .56562 L p .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43485 .56562 L .43947 .60219 L .707 .577 .707 r
F
.40406 .56737 m .43477 .56562 L p .40947 .60261 L F P
0 g
s
.40809 .60463 m .40406 .56737 L .40947 .60261 L .707 .577 .707 r
F
.37254 .57142 m .40381 .56738 L p .37858 .60549 L F P
0 g
s
.37644 .60872 m .37254 .57142 L .37858 .60549 L .707 .577 .707 r
F
.34335 .57739 m .37216 .57147 L p .34961 .61057 L F P
0 g
s
.34721 .61472 m .34335 .57739 L .34961 .61057 L .707 .577 .707 r
F
.31934 .5847 m .34293 .57747 L p .32532 .61737 L F P
0 g
s
.32326 .62206 m .31934 .5847 L .32532 .61737 L .707 .577 .707 r
F
.30289 .59264 m .31898 .58481 L p .30818 .62526 L F P
0 g
s
.30692 .63001 m .30289 .59264 L .30818 .62526 L .707 .577 .707 r
F
.29562 .60043 m .30264 .59276 L p .30007 .63348 L F P
0 g
s
.2998 .63779 m .29562 .60043 L .30007 .63348 L .707 .577 .707 r
F
.29487 .59483 m .2905 .56359 L .29104 .563 L p F P
0 g
s
.29104 .563 m .29763 .55593 L p .29487 .59483 L .707 .577 .707 r
F P
0 g
s
.64565 .68083 m .64993 .71807 L .64281 .72586 L p .707 .577 .707 r
F P
0 g
s
.38984 .61476 m .39412 .65201 L .42576 .64792 L p .707 .577 .707 r
F P
0 g
s
.42576 .64792 m .42148 .61067 L .38984 .61476 L p .707 .577 .707 r
F P
0 g
s
.82036 .53685 m .82817 .59268 L .80739 .59025 L p .707 .577 .707 r
F P
0 g
s
.80739 .59025 m .79959 .53442 L .82036 .53685 L p .707 .577 .707 r
F P
0 g
s
.42148 .61067 m .42576 .64792 L .45499 .64192 L p .707 .577 .707 r
F P
0 g
s
.45499 .64192 m .45071 .60467 L .42148 .61067 L p .707 .577 .707 r
F P
0 g
s
.65696 .55614 m .66477 .61196 L .64845 .62004 L p .707 .577 .707 r
F P
0 g
s
.8339 .69192 m .83215 .71017 L .81966 .70017 L p .707 .577 .707 r
F P
0 g
s
.81966 .70017 m .82141 .68192 L .8339 .69192 L p .707 .577 .707 r
F P
0 g
s
.83833 .66281 m .84261 .70006 L .83017 .6948 L p .707 .577 .707 r
F P
0 g
s
.83017 .6948 m .82589 .65755 L .83833 .66281 L p .707 .577 .707 r
F P
0 g
s
.45071 .60467 m .45499 .64192 L .47895 .63458 L p .707 .577 .707 r
F P
0 g
s
.47895 .63458 m .47467 .59733 L .45071 .60467 L p .707 .577 .707 r
F P
0 g
s
.66477 .61196 m .65696 .55614 L .68087 .54844 L p .707 .577 .707 r
F P
0 g
s
.63906 .68937 m .64081 .67112 L .65715 .66422 L p .707 .577 .707 r
F P
0 g
s
.64993 .71807 m .64565 .68083 L .66199 .67288 L p .707 .577 .707 r
F P
0 g
s
.46902 .55548 m .47682 .6113 L .49314 .60323 L p .707 .577 .707 r
F P
0 g
s
.49314 .60323 m .48534 .5474 L .46902 .55548 L p .707 .577 .707 r
F P
0 g
s
.79959 .53442 m .80739 .59025 L .78025 .59032 L p .707 .577 .707 r
F P
0 g
s
.78025 .59032 m .77244 .53449 L .79959 .53442 L p .707 .577 .707 r
F P
0 g
s
.65715 .66422 m .65541 .68247 L .63906 .68937 L p .707 .577 .707 r
F P
0 g
s
.68087 .54844 m .68868 .60426 L .66477 .61196 L p .707 .577 .707 r
F P
0 g
s
.66199 .67288 m .66627 .71012 L .64993 .71807 L p .707 .577 .707 r
F P
0 g
s
.82141 .68192 m .81966 .70017 L .79873 .69104 L p .707 .577 .707 r
F P
0 g
s
.79873 .69104 m .80048 .67279 L .82141 .68192 L p .707 .577 .707 r
F P
0 g
s
.82589 .65755 m .83017 .6948 L .80931 .69166 L p .707 .577 .707 r
F P
0 g
s
.80931 .69166 m .80503 .65441 L .82589 .65755 L p .707 .577 .707 r
F P
0 g
s
.47467 .59733 m .47895 .63458 L .49529 .62663 L p .707 .577 .707 r
F P
0 g
s
.49529 .62663 m .49101 .58939 L .47467 .59733 L p .707 .577 .707 r
F P
0 g
s
.38354 .74745 m .38529 .7292 L .35426 .72433 L p .707 .577 .707 r
F P
0 g
s
.38529 .7292 m .38354 .74745 L .41525 .74934 L p .707 .577 .707 r
F P
0 g
s
.41525 .74934 m .417 .73109 L .38529 .7292 L p .707 .577 .707 r
F P
0 g
s
.68868 .60426 m .68087 .54844 L .71003 .54186 L p .707 .577 .707 r
F P
0 g
s
.417 .73109 m .41525 .74934 L .44453 .74808 L p .707 .577 .707 r
F P
0 g
s
.44453 .74808 m .44628 .72983 L .417 .73109 L p .707 .577 .707 r
F P
0 g
s
.35426 .72433 m .35251 .74258 L .38354 .74745 L p .707 .577 .707 r
F P
0 g
s
.35251 .74258 m .35426 .72433 L .32694 .71698 L p .707 .577 .707 r
F P
0 g
s
.77244 .53449 m .78025 .59032 L .74939 .59288 L p .707 .577 .707 r
F P
0 g
s
.74939 .59288 m .74158 .53706 L .77244 .53449 L p .707 .577 .707 r
F P
0 g
s
.32694 .71698 m .3252 .73523 L .35251 .74258 L p .707 .577 .707 r
F P
0 g
s
.66627 .71012 m .66199 .67288 L .68594 .66554 L p .707 .577 .707 r
F P
0 g
s
.65541 .68247 m .65715 .66422 L .68114 .65993 L p .707 .577 .707 r
F P
0 g
s
.71783 .59769 m .71003 .54186 L .74158 .53706 L p .707 .577 .707 r
F P
0 g
s
.71003 .54186 m .71783 .59769 L .68868 .60426 L p .707 .577 .707 r
F P
0 g
s
.74158 .53706 m .74939 .59288 L .71783 .59769 L p .707 .577 .707 r
F P
0 g
s
.44628 .72983 m .44453 .74808 L .46852 .7438 L p .707 .577 .707 r
F P
0 g
s
.46852 .7438 m .47027 .72555 L .44628 .72983 L p .707 .577 .707 r
F P
0 g
s
.48534 .5474 m .49314 .60323 L .50028 .59557 L p .707 .577 .707 r
F P
0 g
s
.50028 .59557 m .49247 .53974 L .48534 .5474 L p .707 .577 .707 r
F P
0 g
s
.68114 .65993 m .67939 .67819 L .65541 .68247 L p .707 .577 .707 r
F P
0 g
s
.3252 .73523 m .32694 .71698 L .30602 .70785 L p .707 .577 .707 r
F P
0 g
s
.68594 .66554 m .69022 .70279 L .66627 .71012 L p .707 .577 .707 r
F P
0 g
s
.80048 .67279 m .79873 .69104 L .77607 .68494 L p .707 .577 .707 r
F P
0 g
s
.77609 .69127 m .7511 .6927 L p .77595 .65636 L .707 .577 .707 r
F P
0 g
s
.77607 .68494 m .77142 .68369 L p .77605 .68195 L .707 .577 .707 r
F P
0 g
s
.77605 .68195 m .80048 .67279 L .77607 .68494 L .707 .577 .707 r
F
.77142 .68369 m .77316 .66544 L .80048 .67279 L p F P
0 g
s
.77778 .65368 m .78206 .69093 L .77609 .69127 L p .707 .577 .707 r
F P
0 g
s
.77595 .65636 m .77778 .65368 L .77609 .69127 L .707 .577 .707 r
F
.80503 .65441 m .80931 .69166 L .78206 .69093 L p F P
0 g
s
.78206 .69093 m .77778 .65368 L .80503 .65441 L p .707 .577 .707 r
F P
0 g
s
.49101 .58939 m .49529 .62663 L .5024 .61885 L p .707 .577 .707 r
F P
0 g
s
.5024 .61885 m .49812 .5816 L .49101 .58939 L p .707 .577 .707 r
F P
0 g
s
.30602 .70785 m .30427 .7261 L .3252 .73523 L p .707 .577 .707 r
F P
0 g
s
.69022 .70279 m .68594 .66554 L .71517 .65954 L p .707 .577 .707 r
F P
0 g
s
.67939 .67819 m .68114 .65993 L .71042 .65868 L p .707 .577 .707 r
F P
0 g
s
.47027 .72555 m .46852 .7438 L .48487 .7369 L p .707 .577 .707 r
F P
0 g
s
.48487 .7369 m .48662 .71865 L .47027 .72555 L p .707 .577 .707 r
F P
0 g
s
.7511 .6927 m .74682 .65545 L .77778 .65368 L p .707 .577 .707 r
F P
0 g
s
.71517 .65954 m .71945 .69678 L .69022 .70279 L p .707 .577 .707 r
F P
0 g
s
.71042 .65868 m .70868 .67693 L .67939 .67819 L p .707 .577 .707 r
F P
0 g
s
.30427 .7261 m .30602 .70785 L .29352 .69785 L p .707 .577 .707 r
F P
0 g
s
.74682 .65545 m .7511 .6927 L .71945 .69678 L p .707 .577 .707 r
F P
0 g
s
.77316 .66544 m .77142 .68369 L .74038 .67882 L p .707 .577 .707 r
F P
0 g
s
.71945 .69678 m .71517 .65954 L .74682 .65545 L p .707 .577 .707 r
F P
0 g
s
.74038 .67882 m .74213 .66057 L .77316 .66544 L p .707 .577 .707 r
F P
0 g
s
.70868 .67693 m .71042 .65868 L .74213 .66057 L p .707 .577 .707 r
F P
0 g
s
.49812 .5816 m .5024 .61885 L .4996 .61199 L p .707 .577 .707 r
F P
0 g
s
.4996 .61199 m .49532 .57475 L .49812 .5816 L p .707 .577 .707 r
F P
0 g
s
.49247 .53974 m .50028 .59557 L .49752 .58908 L p .707 .577 .707 r
F P
0 g
s
.49752 .58908 m .48972 .53325 L .49247 .53974 L p .707 .577 .707 r
F P
0 g
s
.29352 .69785 m .29178 .7161 L .30427 .7261 L p .707 .577 .707 r
F P
0 g
s
.74213 .66057 m .74038 .67882 L .70868 .67693 L p .707 .577 .707 r
F P
0 g
s
.48662 .71865 m .48487 .7369 L .49198 .72806 L p .707 .577 .707 r
F P
0 g
s
.49198 .72806 m .49372 .70981 L .48662 .71865 L p .707 .577 .707 r
F P
0 g
s
.29178 .7161 m .29352 .69785 L .29069 .68794 L p .707 .577 .707 r
F P
0 g
s
.29069 .68794 m .28894 .70619 L .29178 .7161 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49532 .57475 m .4996 .61199 L .48716 .60673 L p .707 .577 .707 r
F P
0 g
s
.48716 .60673 m .48288 .56949 L .49532 .57475 L p .707 .577 .707 r
F P
0 g
s
.48972 .53325 m .49752 .58908 L .48516 .58439 L p .707 .577 .707 r
F P
0 g
s
.48516 .58439 m .47735 .52856 L .48972 .53325 L p .707 .577 .707 r
F P
0 g
s
.30264 .59276 m .30692 .63001 L .2998 .63779 L p .707 .577 .707 r
F P
0 g
s
.49372 .70981 m .49198 .72806 L .48914 .71816 L p .707 .577 .707 r
F P
0 g
s
.48914 .71816 m .49089 .69991 L .49372 .70981 L p .707 .577 .707 r
F P
0 g
s
.28894 .70619 m .29069 .68794 L .2978 .67911 L p .707 .577 .707 r
F P
0 g
s
.2978 .67911 m .29605 .69736 L .28894 .70619 L p .707 .577 .707 r
F P
0 g
s
.48288 .56949 m .48716 .60673 L .4663 .60359 L p .707 .577 .707 r
F P
0 g
s
.4663 .60359 m .46202 .56634 L .48288 .56949 L p .707 .577 .707 r
F P
0 g
s
.47735 .52856 m .48516 .58439 L .46438 .58196 L p .707 .577 .707 r
F P
0 g
s
.46438 .58196 m .45658 .52614 L .47735 .52856 L p .707 .577 .707 r
F P
0 g
s
.31898 .58481 m .32326 .62206 L .30692 .63001 L p .707 .577 .707 r
F P
0 g
s
.49089 .69991 m .48914 .71816 L .47665 .70815 L p .707 .577 .707 r
F P
0 g
s
.47665 .70815 m .4784 .6899 L .49089 .69991 L p .707 .577 .707 r
F P
0 g
s
.29605 .69736 m .2978 .67911 L .31414 .67221 L p .707 .577 .707 r
F P
0 g
s
.46202 .56634 m .4663 .60359 L .43905 .60286 L p .707 .577 .707 r
F P
0 g
s
.45658 .52614 m .46438 .58196 L .43724 .58204 L p .707 .577 .707 r
F P
0 g
s
.43724 .58204 m .42943 .52621 L .45658 .52614 L p .707 .577 .707 r
F P
0 g
s
.31414 .67221 m .3124 .69046 L .29605 .69736 L p .707 .577 .707 r
F P
0 g
s
.34293 .57747 m .34721 .61472 L .32326 .62206 L p .707 .577 .707 r
F P
0 g
s
.4784 .6899 m .47665 .70815 L .45572 .69903 L p .707 .577 .707 r
F P
0 g
s
.45572 .69903 m .45747 .68078 L .4784 .6899 L p .707 .577 .707 r
F P
0 g
s
.43477 .56562 m .43905 .60286 L .40809 .60463 L p .707 .577 .707 r
F P
0 g
s
.3124 .69046 m .31414 .67221 L .33813 .66792 L p .707 .577 .707 r
F P
0 g
s
.37216 .57147 m .37644 .60872 L .34721 .61472 L p .707 .577 .707 r
F P
0 g
s
.33813 .66792 m .33638 .68617 L .3124 .69046 L p .707 .577 .707 r
F P
0 g
s
.40381 .56738 m .40809 .60463 L .37644 .60872 L p .707 .577 .707 r
F P
0 g
s
.45747 .68078 m .45572 .69903 L .42841 .69167 L p .707 .577 .707 r
F P
0 g
s
.42841 .69167 m .43015 .67342 L .45747 .68078 L p .707 .577 .707 r
F P
0 g
s
.33638 .68617 m .33813 .66792 L .36741 .66666 L p .707 .577 .707 r
F P
0 g
s
.36741 .66666 m .36567 .68491 L .33638 .68617 L p .707 .577 .707 r
F P
0 g
s
.43015 .67342 m .42841 .69167 L .39737 .68681 L p .707 .577 .707 r
F P
0 g
s
.39737 .68681 m .39912 .66856 L .43015 .67342 L p .707 .577 .707 r
F P
0 g
s
.36567 .68491 m .36741 .66666 L .39912 .66856 L p .707 .577 .707 r
F P
0 g
s
.39912 .66856 m .39737 .68681 L .36567 .68491 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00Igoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01EYF3`00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool01000FUIJEP0015YF2@0015YF00<005YFFUH015YF00<005YFFUH01@001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH000050004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006=oo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000HOolJ000cOol0
05moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3000DOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000aOol005]o
o`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000>Ool60006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<7oo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0027oo1P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001GOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001Woo0P00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUH005YF02moo`00EGoo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000Aoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00FUH_Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00IJEP03001JEUYF009J
EPD000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`03001JEP0000=JEP03OomJEP0000IJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`04001J
EP000002FUH00gooFUH00006FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH20006FUH00`00
FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001J
EUYF009JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol01000FUIJEP00
15YF00<005YFFUH00eYF10001EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001eYF00<005YFFUH0
0UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol2FUH00`00FUIJEP02
FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH<0002FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001COol2FUH00`00FUIJEP02FUH20005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH015YF00@005YFFUIJ
EP@0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`9JEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP04001JEUYF000^
Ool005=oo`9JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00=JEPH00003FUH0000002eoo`00Dgoo00@005YF
000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00AJEPX000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool005=oo`800003FUH005YF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool005=oo`04001JEUYF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP0200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH50008FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005
FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH40003FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH0
1UYF1P000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001DOol2FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH70006FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0003FUH01000FUH000001UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;Goo001DOol3FUH20002FUH00`00
FUIJEP03FUH60004FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUH0031oo`00Cgoo1@000eYF00H005YFFUIJEP00FUH40005FUH50003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF008000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<0035oo`00
AWoo2@0015YF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP8003=oo`00@7oo
1P0015YF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000e
Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo
000hOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH0
35YF1@001EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003eoo`00=7oo100000=JEP00FUH0
1EYF00=oo`00FUH01eYF00<005YFFUH01UYF10000UYF00<005YFFUH02`001eYF1@001EYF00<005YF
FUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70011Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<0
009JEP03001JEUYF00=JEP03001JEUYF00aJEPD000EJEP03001JEUYF00IJEP03001JEP0000<000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH4
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80018Ool0031oo`<000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00eJEP<000MJEP03
001JEUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEQ40051oo`00;Woo0P000UYF00<005YFFUH015YF00<005YF
FUH00eYF00AooeYFFUH000QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH03UYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YF001J
EUIoo`00;Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00iJEP03001JEUYF009JEPL000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000EJEP03001JEUYF00=JEP04001JEP00FUIFOol002aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEQT000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF000BOol8000lOol002]oo`03001JEP0000EJ
EP03001JEUYF00AJEP05001JEUYFFUIoo`03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0027oo2@0015YF00@005YF
FUIJEPX0039oo`00:goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF3P001eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEQP000QJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00:goo00<005YF00000eYF00=ooeYF00001UYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF
0P001UYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00009JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00:goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001JEP0000d0
0003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
0005FUH400000eYF001JEP06FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00
FUIJEP02FUH01000FUIJEUYF0P00;Goo000/Ool2FUH00`00FUIJEP02FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo
0UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
00000`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000IJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0UYF00<005YFFUH00`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUH000030003FUH00`00
FUIJEP06FUH00`00FUH000080004FUH01000FUIJEP001UYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool2FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0eYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH80000
1EYF001JEUYF00000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0000000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000]Ool002aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP@00003FUH005YF00AJEP03001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF001JEP030004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHF0002FUH01000FUIJEUYF0P00;7oo000/Ool01000
FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEPX000=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@0
009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000Uo
o`@00004FUH005YFFUH20002FUH40003FUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:00000eYF000000050004FUH500001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001EYF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF009JEPH000Ioo`L000EJEP03001JEUYF009JEP<000=JEP800003FUH0000002aoo`00;Goo
0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF2@000eYF2@0015YF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEP8000=J
EP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP030002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH60003Ool90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF1@00;7oo000]Ool3FUH20002FUH00`00FUIJEP03FUH60004FUH80004
FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YF0000
300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P0000=JEP0000000`00;7oo
000]Ool3FUH01@00FUIJEUYF00000eYF0P001EYF1@000eYF00<005YFFUH01UYF00<005YF00000eYF
0P0000=JEP00FUH01EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
2@00FUIJEUYF001JEP00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001oo`0[Ool002eoo`04001JEUYF0003FUH0
1000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01eYF0P000eYF00<005YF00000P001EYF00<0
05YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
15YF001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00001000;Goo000]Ool01000FUIJEP000eYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP@000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH000000004
FUH00`00FUIJEP05FUH20007FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF0000
000^Ool002ioo`9JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030003FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH000AJEP03001JEUYF00MJEP@000=JEPD0
00EJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEP0002moo`00;Woo0UYF1@000eYF00<0
05YFFUH015YF00<005YFFUH01UYF0`001UYF00<005YFFUH00`001EYF00<005YFFUH00eYF1@0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH02eYF5`000eYF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH02`00
1eYF1@001EYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF
00<005YFFUH01eYF00<005YFFUH01eYF1@000eYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH035YF1P000eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH035YF1@001EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH0
15YF5`000eYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP0<FUH00`00FUH000020004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Goo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP0<FUH50006FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EUYF009JEP03001JEUYF00]JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000cOol002moo`800003FUH005YF00AJEP03001JEUYF00eJEP<000MJEP03001JEUYF00@0009o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH007oo1@000UYF00<005YFFUH015YF10000eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEPD003Eoo`00<Goo10000eYF00<005YFFUH03UYF00<005YFFUH00UYF1`002Goo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000MJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
obD003Yoo`00=Goo1`002EYF2@0057oo1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
?7oo2@0087oo00<005YFFUH02P0015YF00<005YFFUH00UYF1`002EYF00<005YFFUH02EYF2@0025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002000GGoo001UOol01000FUIJEP001EYF00@0
05YFFUIJEPX0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00D005Qoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00?Woo20007goo00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000IJ
EP03001JEUYF009JEP05001JEUYFFUH0001EOol003Ioo`P000=JEP03001JEUYF009JEPT001Ioo`04
001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000aOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000@Ool01@00
FUIJEP00FUH00P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP03001JEUYF009JEP04001J
EUYFFUH2001DOol002moo`800003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEP0000<000aoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80
0004FUH005YF0006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00E7oo000]Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30009Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP80
0003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0001DOol002]oo`03001JEP0000=JEP04
001JEUYFFUH80008Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP020005Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<005YFFUH00UYF00D005YFFUIJEP0005Aoo`00
:goo00<005YF00000eYF10006Goo1P001UYF00<005YFFUH00eYF00<007ooOol00Woo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF00002`000UYF00@005YFFUIJEP8005=oo`00:goo00@0
05YF001JEP8002=oo`@0009JEP03001JEUYF00=JEP8000=oo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00D00003FUH00000009JEP@000=JEP8005=oo`00:goo00@005YF000002Uo
o`<000EJEP04001JEP000002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP02FUH30003FUH200000eYF0000001COol002]oo`<002eoo`8000=JEP07
001JEUYFFUH007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF
00@005YFFUIJEPD005=oo`00:goo0P0000=JEP000000;Goo0P0000=JEP00FUH00UYF00<007ooOol0
0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P000UYF1@00Dgoo
000[Ool00`00FUIJEP02FUH00`00Oomoo`0/Ool20003FUH20003Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
0005FUH00`00FUIJEP05FUH600000eYF001oo`1BOol002]oo`03001JEUYF009JEP<002ioo`03001J
EUYF008000Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEP0000@005Aoo`00
:goo00<005YFFUH00UYF00<005YFFUH00P00;Goo10001goo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`000eYF00<005YFFUH01UYF
00<005YFFUH015YF1P00EGoo000/Ool01000FUIJEP001EYF0P00:goo10002Goo0`0000=JEP00FUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01EYF00<005YF000010000UYF00<005YF0000EWoo000]Ool30005FUH00`00FUH00003000U
Ool200000eYF0000000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUH0000G0003FUH01000FUIJEUYF0P00Egoo000_Ool00`00FUIJEP03FUH00`00FUIJEP03FUH7
000IOol50003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH70003FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00Egoo000`Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90009Ool70003FUH01`00FUIJEUYF001JEP00021ooaT000YJEPH000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001HOol0039oo`800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool01@00
FUIJEUYF000015YF00<005YFFUH02eYF00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Yoo`00=7oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002ioo`800003FUH005YF00=JEP03001JEUYF00AJEP@0
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001LOol003Moo`@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol:0004
FUH00`00FUIJEP0H001QOol003]oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000mOol9001gOol0049oo`T000AJEP03001JEUYF009JEPL00<9oo`00Bgoo2@00bGoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59191 .78729 m .59619 .75096 L .59594 .75092 L p .707 .577 .707 r
F P
0 g
s
.59594 .75092 m .56523 .74544 L p .59053 .78512 L .707 .577 .707 r
F P
0 g
s
.59191 .78729 m .59594 .75092 L .59053 .78512 L .707 .577 .707 r
F
.59619 .75096 m .59191 .78729 L .62355 .78978 L p F P
0 g
s
.62355 .78978 m .62783 .75345 L .62746 .75342 L p .707 .577 .707 r
F P
0 g
s
.62746 .75342 m .59619 .75096 L p .62142 .78675 L .707 .577 .707 r
F P
0 g
s
.62355 .78978 m .62746 .75342 L .62142 .78675 L .707 .577 .707 r
F
.62783 .75345 m .62355 .78978 L .65279 .789 L p F P
0 g
s
.65279 .789 m .65707 .75267 L .65665 .75268 L p .707 .577 .707 r
F P
0 g
s
.65665 .75268 m .62783 .75345 L p .65039 .78558 L .707 .577 .707 r
F P
0 g
s
.65279 .789 m .65665 .75268 L .65039 .78558 L .707 .577 .707 r
F
.65707 .75267 m .65279 .789 L .67674 .78501 L p F P
0 g
s
.67674 .78501 m .68102 .74868 L .68065 .74874 L p .707 .577 .707 r
F P
0 g
s
.68065 .74874 m .65707 .75267 L p .67467 .78161 L .707 .577 .707 r
F P
0 g
s
.67674 .78501 m .68065 .74874 L .67467 .78161 L .707 .577 .707 r
F
.68102 .74868 m .67674 .78501 L .69308 .77822 L p F P
0 g
s
.69308 .77822 m .69736 .74189 L .69711 .74199 L p .707 .577 .707 r
F P
0 g
s
.69711 .74199 m .68102 .74868 L p .69181 .77512 L .707 .577 .707 r
F P
0 g
s
.69308 .77822 m .69711 .74199 L .69181 .77512 L .707 .577 .707 r
F
.69736 .74189 m .69308 .77822 L .70019 .76928 L p F P
0 g
s
.70019 .76928 m .70447 .73295 L .70437 .73307 L p .707 .577 .707 r
F P
0 g
s
.70437 .73307 m .69736 .74189 L p .69992 .76666 L .707 .577 .707 r
F P
0 g
s
.70019 .76928 m .70437 .73307 L .69992 .76666 L .707 .577 .707 r
F
.69456 .76028 m .70169 .75122 L p .70232 .70942 L F P
0 g
s
.70169 .75122 m .70513 .72738 L p .70236 .70613 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .7095 .69707 L .70896 .69776 L p .707 .577 .707 r
F P
0 g
s
.70896 .69776 m .70236 .70613 L p .70513 .72738 L .707 .577 .707 r
F P
0 g
s
.70447 .73295 m .70019 .76928 L .69987 .7681 L p .707 .577 .707 r
F P
0 g
s
.70169 .75122 m .69894 .74066 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .70169 .75122 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.69987 .7681 m .69739 .75907 L p .70435 .7334 L .707 .577 .707 r
F P
0 g
s
.70435 .7334 m .70447 .73295 L .69987 .7681 L .707 .577 .707 r
F
.7095 .69707 m .70513 .72738 L p .70872 .70026 L F P
0 g
s
.70236 .70613 m .69801 .73638 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.69801 .73638 m .69456 .76028 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .69456 .76028 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68604 .7128 m .68168 .74311 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68168 .74311 m .67824 .76696 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .67824 .76696 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.66214 .71643 m .65774 .74692 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.65774 .74692 m .65433 .77058 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .65433 .77058 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.63298 .71666 m .62854 .74742 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.62854 .74742 m .62517 .77082 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .62517 .77082 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.60142 .71347 m .59694 .74458 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59694 .74458 m .59362 .76763 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .60142 .71347 L .57056 .70718 L p .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .63298 .71666 L .60142 .71347 L p .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .66214 .71643 L .63298 .71666 L p .707 .577 .707 r
F P
0 g
s
.56276 .76133 m .57056 .70718 L .54342 .69839 L p .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56523 .74544 L .56515 .74542 L p .707 .577 .707 r
F P
0 g
s
.56603 .73867 m .56276 .76133 L .56307 .76139 L p .707 .577 .707 r
F P
0 g
s
.54342 .69839 m .53562 .75254 L .56276 .76133 L p .707 .577 .707 r
F P
0 g
s
.56515 .74542 m .53798 .73742 L p .56052 .78095 L .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56515 .74542 L .56052 .78095 L .707 .577 .707 r
F
.57056 .70718 m .56603 .73867 L p .59362 .76763 L F P
0 g
s
.56523 .74544 m .56095 .78177 L .59191 .78729 L p .707 .577 .707 r
F P
0 g
s
.56307 .76139 m .59362 .76763 L p .56603 .73867 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .68604 .7128 L .66214 .71643 L p .707 .577 .707 r
F P
0 g
s
.53562 .75254 m .54342 .69839 L .52265 .68797 L p .707 .577 .707 r
F P
0 g
s
.53798 .73742 m .5337 .77375 L .56095 .78177 L p .707 .577 .707 r
F P
0 g
s
.52265 .68797 m .51484 .74212 L .53562 .75254 L p .707 .577 .707 r
F P
0 g
s
.5337 .77375 m .53798 .73742 L .51712 .7277 L p .707 .577 .707 r
F P
0 g
s
.69456 .76028 m .70236 .70613 L .68604 .7128 L p .707 .577 .707 r
F P
0 g
s
.60262 .87177 m .60087 .85314 L .56984 .85424 L p .707 .577 .707 r
F P
0 g
s
.60087 .85314 m .60262 .87177 L .63433 .86829 L p .707 .577 .707 r
F P
0 g
s
.63433 .86829 m .63258 .84967 L .60087 .85314 L p .707 .577 .707 r
F P
0 g
s
.63258 .84967 m .63433 .86829 L .66361 .86277 L p .707 .577 .707 r
F P
0 g
s
.66361 .86277 m .66186 .84414 L .63258 .84967 L p .707 .577 .707 r
F P
0 g
s
.51484 .74212 m .52265 .68797 L .51028 .67694 L p .707 .577 .707 r
F P
0 g
s
.56984 .85424 m .57159 .87286 L .60262 .87177 L p .707 .577 .707 r
F P
0 g
s
.51712 .7277 m .51284 .76403 L .5337 .77375 L p .707 .577 .707 r
F P
0 g
s
.57159 .87286 m .56984 .85424 L .54253 .85284 L p .707 .577 .707 r
F P
0 g
s
.54253 .85284 m .54427 .87146 L .57159 .87286 L p .707 .577 .707 r
F P
0 g
s
.66186 .84414 m .66361 .86277 L .6876 .85574 L p .707 .577 .707 r
F P
0 g
s
.6876 .85574 m .68585 .83712 L .66186 .84414 L p .707 .577 .707 r
F P
0 g
s
.51028 .67694 m .50247 .73109 L .51484 .74212 L p .707 .577 .707 r
F P
0 g
s
.51284 .76403 m .51712 .7277 L .50468 .71723 L p .707 .577 .707 r
F P
0 g
s
.54427 .87146 m .54253 .85284 L .5216 .84908 L p .707 .577 .707 r
F P
0 g
s
.50468 .71723 m .5004 .75355 L .51284 .76403 L p .707 .577 .707 r
F P
0 g
s
.5216 .84908 m .52335 .86771 L .54427 .87146 L p .707 .577 .707 r
F P
0 g
s
.50247 .73109 m .51028 .67694 L .50752 .66637 L p .707 .577 .707 r
F P
0 g
s
.68585 .83712 m .6876 .85574 L .70395 .8479 L p .707 .577 .707 r
F P
0 g
s
.70395 .8479 m .7022 .82928 L .68585 .83712 L p .707 .577 .707 r
F P
0 g
s
.50752 .66637 m .49972 .72052 L .50247 .73109 L p .707 .577 .707 r
F P
0 g
s
.5004 .75355 m .50468 .71723 L .50188 .70702 L p .707 .577 .707 r
F P
0 g
s
.52335 .86771 m .5216 .84908 L .50911 .84334 L p .707 .577 .707 r
F P
0 g
s
.50911 .84334 m .51085 .86197 L .52335 .86771 L p .707 .577 .707 r
F P
0 g
s
.69894 .74066 m .70235 .71699 L p .7095 .69707 L .707 .577 .707 r
F P
0 g
s
.70674 .68651 m .69894 .74066 L .68657 .72963 L p .707 .577 .707 r
F P
0 g
s
.70167 .72274 m .69739 .75907 L .69609 .75797 L p .707 .577 .707 r
F P
0 g
s
.69609 .75797 m .68495 .74859 L p .70141 .72315 L .707 .577 .707 r
F P
0 g
s
.70141 .72315 m .70167 .72274 L .69609 .75797 L .707 .577 .707 r
F
.70235 .71699 m .70674 .68651 L .70691 .68715 L p F P
0 g
s
.70691 .68715 m .7095 .69707 L p .70235 .71699 L .707 .577 .707 r
F P
0 g
s
.50188 .70702 m .4976 .74335 L .5004 .75355 L p .707 .577 .707 r
F P
0 g
s
.7022 .82928 m .70395 .8479 L .71105 .84001 L p .707 .577 .707 r
F P
0 g
s
.71105 .84001 m .7093 .82139 L .7022 .82928 L p .707 .577 .707 r
F P
0 g
s
.4976 .74335 m .50188 .70702 L .50899 .69808 L p .707 .577 .707 r
F P
0 g
s
.49972 .72052 m .50752 .66637 L .51466 .65731 L p .707 .577 .707 r
F P
0 g
s
.49047 .82157 m .48745 .31937 L .44344 .31695 L p .707 .577 .707 r
F P
0 g
s
.50899 .69808 m .50471 .73441 L .4976 .74335 L p .707 .577 .707 r
F P
0 g
s
.51466 .65731 m .50685 .71146 L .49972 .72052 L p .707 .577 .707 r
F P
0 g
s
.50471 .73441 m .50899 .69808 L .52533 .69129 L p .707 .577 .707 r
F P
0 g
s
.50685 .71146 m .51466 .65731 L .53098 .65064 L p .707 .577 .707 r
F P
0 g
s
.52533 .69129 m .52105 .72762 L .50471 .73441 L p .707 .577 .707 r
F P
0 g
s
.53098 .65064 m .52317 .70479 L .50685 .71146 L p .707 .577 .707 r
F P
0 g
s
.52105 .72762 m .52533 .69129 L .54928 .6873 L p .707 .577 .707 r
F P
0 g
s
.52317 .70479 m .53098 .65064 L .55489 .64701 L p .707 .577 .707 r
F P
0 g
s
.54928 .6873 m .545 .72363 L .52105 .72762 L p .707 .577 .707 r
F P
0 g
s
.55489 .64701 m .54708 .70116 L .52317 .70479 L p .707 .577 .707 r
F P
0 g
s
.53147 .83907 m .52973 .82044 L .55371 .81342 L p .707 .577 .707 r
F P
0 g
s
.48745 .31937 m .49047 .82157 L .53542 .82023 L p .707 .577 .707 r
F P
0 g
s
.53542 .82023 m .53239 .31803 L .48745 .31937 L p .707 .577 .707 r
F P
0 g
s
.545 .72363 m .54928 .6873 L .57851 .68652 L p .707 .577 .707 r
F P
0 g
s
.54708 .70116 m .55489 .64701 L .58404 .64678 L p .707 .577 .707 r
F P
0 g
s
.57851 .68652 m .57424 .72284 L .545 .72363 L p .707 .577 .707 r
F P
0 g
s
.58404 .64678 m .57624 .70093 L .54708 .70116 L p .707 .577 .707 r
F P
0 g
s
.55371 .81342 m .55546 .83204 L .53147 .83907 L p .707 .577 .707 r
F P
0 g
s
.55546 .83204 m .55371 .81342 L .583 .80789 L p .707 .577 .707 r
F P
0 g
s
.583 .80789 m .58474 .82652 L .55546 .83204 L p .707 .577 .707 r
F P
0 g
s
.53239 .31803 m .53542 .82023 L .5769 .81527 L p .707 .577 .707 r
F P
0 g
s
.57424 .72284 m .57851 .68652 L .61016 .68901 L p .707 .577 .707 r
F P
0 g
s
.61016 .68901 m .60588 .72534 L .57424 .72284 L p .707 .577 .707 r
F P
0 g
s
.5769 .81527 m .57387 .31306 L .53239 .31803 L p .707 .577 .707 r
F P
0 g
s
.69739 .75907 m .70167 .72274 L .70447 .73295 L p .707 .577 .707 r
F P
0 g
s
.44647 .81915 m .44344 .31695 L .40468 .31102 L p .707 .577 .707 r
F P
0 g
s
.44344 .31695 m .44647 .81915 L .49047 .82157 L p .707 .577 .707 r
F P
0 g
s
.51085 .86197 m .50911 .84334 L .50627 .83617 L p .707 .577 .707 r
F P
0 g
s
.57624 .70093 m .58404 .64678 L .6156 .64997 L p .707 .577 .707 r
F P
0 g
s
.6156 .64997 m .60779 .70412 L .57624 .70093 L p .707 .577 .707 r
F P
0 g
s
.58474 .82652 m .583 .80789 L .6147 .80442 L p .707 .577 .707 r
F P
0 g
s
.57387 .31306 m .5769 .81527 L .61085 .80717 L p .707 .577 .707 r
F P
0 g
s
.6736 .66506 m .6658 .71921 L .63892 .71051 L p .707 .577 .707 r
F P
0 g
s
.63899 .70998 m .6736 .66506 L .63892 .71051 L .707 .577 .707 r
F
.63626 .73075 m .60588 .72534 L p .64102 .69462 L F P
0 g
s
.64646 .65627 m .6736 .66506 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .61016 .68901 L .64103 .69451 L p .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .64103 .69451 L .64102 .69462 L .707 .577 .707 r
F
.63865 .71042 m .64192 .68776 L p .63899 .70998 L F P
0 g
s
.64192 .68776 m .64646 .65627 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.64103 .69451 m .64112 .69453 L p .64102 .69462 L .707 .577 .707 r
F P
0 g
s
.64112 .69453 m .63684 .73086 L .63626 .73075 L p .707 .577 .707 r
F P
0 g
s
.64102 .69462 m .64112 .69453 L .63626 .73075 L .707 .577 .707 r
F
.63892 .71051 m .63865 .71042 L p .63899 .70998 L F P
0 g
s
.64646 .65627 m .63865 .71042 L .60779 .70412 L p .707 .577 .707 r
F P
0 g
s
.60779 .70412 m .6156 .64997 L .64646 .65627 L p .707 .577 .707 r
F P
0 g
s
.61085 .80717 m .60783 .30496 L .57387 .31306 L p .707 .577 .707 r
F P
0 g
s
.50627 .83617 m .50802 .8548 L .51085 .86197 L p .707 .577 .707 r
F P
0 g
s
.25061 .70228 m .25841 .64813 L .22756 .64183 L p .707 .577 .707 r
F P
0 g
s
.25841 .64813 m .25061 .70228 L .28216 .70547 L p .707 .577 .707 r
F P
0 g
s
.28216 .70547 m .28997 .65132 L .25841 .64813 L p .707 .577 .707 r
F P
0 g
s
.68657 .72963 m .68994 .70624 L p .70674 .68651 L .707 .577 .707 r
F P
0 g
s
.69438 .67548 m .68657 .72963 L .6658 .71921 L p .707 .577 .707 r
F P
0 g
s
.68923 .71227 m .68495 .74859 L .68321 .74778 L p .707 .577 .707 r
F P
0 g
s
.68321 .74778 m .66409 .73887 L p .68891 .71261 L .707 .577 .707 r
F P
0 g
s
.68891 .71261 m .68923 .71227 L .68321 .74778 L .707 .577 .707 r
F
.68994 .70624 m .69438 .67548 L .69486 .67591 L p F P
0 g
s
.69486 .67591 m .70674 .68651 L p .68994 .70624 L .707 .577 .707 r
F P
0 g
s
.28997 .65132 m .28216 .70547 L .31132 .70524 L p .707 .577 .707 r
F P
0 g
s
.31132 .70524 m .31913 .65109 L .28997 .65132 L p .707 .577 .707 r
F P
0 g
s
.7093 .82139 m .71105 .84001 L .70822 .83285 L p .707 .577 .707 r
F P
0 g
s
.70822 .83285 m .70647 .81422 L .7093 .82139 L p .707 .577 .707 r
F P
0 g
s
.21975 .69598 m .22756 .64183 L .20041 .63304 L p .707 .577 .707 r
F P
0 g
s
.22756 .64183 m .21975 .69598 L .25061 .70228 L p .707 .577 .707 r
F P
0 g
s
.4077 .81322 m .40468 .31102 L .37496 .30215 L p .707 .577 .707 r
F P
0 g
s
.40468 .31102 m .4077 .81322 L .44647 .81915 L p .707 .577 .707 r
F P
0 g
s
.68495 .74859 m .68923 .71227 L .70167 .72274 L p .707 .577 .707 r
F P
0 g
s
.31913 .65109 m .31132 .70524 L .33523 .70161 L p .707 .577 .707 r
F P
0 g
s
.33523 .70161 m .34304 .64746 L .31913 .65109 L p .707 .577 .707 r
F P
0 g
s
.19261 .68719 m .20041 .63304 L .17964 .62262 L p .707 .577 .707 r
F P
0 g
s
.20041 .63304 m .19261 .68719 L .21975 .69598 L p .707 .577 .707 r
F P
0 g
s
.50802 .8548 m .50627 .83617 L .51338 .82828 L p .707 .577 .707 r
F P
0 g
s
.61645 .82304 m .6147 .80442 L .64574 .80333 L p .707 .577 .707 r
F P
0 g
s
.6147 .80442 m .61645 .82304 L .58474 .82652 L p .707 .577 .707 r
F P
0 g
s
.60783 .30496 m .61085 .80717 L .63396 .79672 L p .707 .577 .707 r
F P
0 g
s
.63396 .79672 m .63094 .29452 L .60783 .30496 L p .707 .577 .707 r
F P
0 g
s
.51338 .82828 m .51513 .84691 L .50802 .8548 L p .707 .577 .707 r
F P
0 g
s
.6658 .71921 m .66912 .69616 L p .69438 .67548 L .707 .577 .707 r
F P
0 g
s
.66837 .70254 m .66409 .73887 L .66261 .73844 L p .707 .577 .707 r
F P
0 g
s
.66261 .73844 m .63684 .73086 L p .6681 .70278 L .707 .577 .707 r
F P
0 g
s
.6681 .70278 m .66837 .70254 L .66261 .73844 L .707 .577 .707 r
F
.66912 .69616 m .6736 .66506 L .67389 .6652 L p F P
0 g
s
.67389 .6652 m .69438 .67548 L p .66912 .69616 L .707 .577 .707 r
F P
0 g
s
.25961 .79015 m .25787 .77153 L .22683 .77262 L p .707 .577 .707 r
F P
0 g
s
.25787 .77153 m .25961 .79015 L .29132 .78667 L p .707 .577 .707 r
F P
0 g
s
.29132 .78667 m .28957 .76805 L .25787 .77153 L p .707 .577 .707 r
F P
0 g
s
.22683 .77262 m .22858 .79124 L .25961 .79015 L p .707 .577 .707 r
F P
0 g
s
.2489 .80173 m .25318 .7654 L .22222 .75988 L p .707 .577 .707 r
F P
0 g
s
.25318 .7654 m .2489 .80173 L .28055 .80422 L p .707 .577 .707 r
F P
0 g
s
.28055 .80422 m .28483 .76789 L .25318 .7654 L p .707 .577 .707 r
F P
0 g
s
.70647 .81422 m .70822 .83285 L .69573 .82711 L p .707 .577 .707 r
F P
0 g
s
.69573 .82711 m .69398 .80848 L .70647 .81422 L p .707 .577 .707 r
F P
0 g
s
.28957 .76805 m .29132 .78667 L .3206 .78115 L p .707 .577 .707 r
F P
0 g
s
.3206 .78115 m .31886 .76253 L .28957 .76805 L p .707 .577 .707 r
F P
0 g
s
.34304 .64746 m .33523 .70161 L .35155 .69494 L p .707 .577 .707 r
F P
0 g
s
.35155 .69494 m .35936 .64079 L .34304 .64746 L p .707 .577 .707 r
F P
0 g
s
.17964 .62262 m .17183 .67677 L .19261 .68719 L p .707 .577 .707 r
F P
0 g
s
.28483 .76789 m .28055 .80422 L .30978 .80343 L p .707 .577 .707 r
F P
0 g
s
.30978 .80343 m .31406 .7671 L .28483 .76789 L p .707 .577 .707 r
F P
0 g
s
.37798 .80435 m .37496 .30215 L .35718 .29121 L p .707 .577 .707 r
F P
0 g
s
.37496 .30215 m .37798 .80435 L .4077 .81322 L p .707 .577 .707 r
F P
0 g
s
.66409 .73887 m .66837 .70254 L .68923 .71227 L p .707 .577 .707 r
F P
0 g
s
.21794 .7962 m .22222 .75988 L .19497 .75186 L p .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22683 .77262 L .22401 .77247 L p .707 .577 .707 r
F P
0 g
s
.22222 .75988 m .21794 .7962 L .22391 .79727 L p .707 .577 .707 r
F P
0 g
s
.22405 .76274 m .22222 .75988 L .22391 .79727 L .707 .577 .707 r
F
.19497 .75186 m .19069 .78819 L .21794 .7962 L p F P
0 g
s
.22401 .77247 m .19952 .77122 L p .22394 .78805 L .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22401 .77247 L .22394 .78805 L .707 .577 .707 r
F
.19952 .77122 m .20127 .78984 L .22858 .79124 L p F P
0 g
s
.22391 .79727 m .2489 .80173 L p .22405 .76274 L .707 .577 .707 r
F P
0 g
s
.17183 .67677 m .17964 .62262 L .16727 .61159 L p .707 .577 .707 r
F P
0 g
s
.31886 .76253 m .3206 .78115 L .34459 .77413 L p .707 .577 .707 r
F P
0 g
s
.34459 .77413 m .34284 .7555 L .31886 .76253 L p .707 .577 .707 r
F P
0 g
s
.31406 .7671 m .30978 .80343 L .33373 .79945 L p .707 .577 .707 r
F P
0 g
s
.33373 .79945 m .33801 .76312 L .31406 .7671 L p .707 .577 .707 r
F P
0 g
s
.51513 .84691 m .51338 .82828 L .52973 .82044 L p .707 .577 .707 r
F P
0 g
s
.19069 .78819 m .19497 .75186 L .17411 .74214 L p .707 .577 .707 r
F P
0 g
s
.52973 .82044 m .53147 .83907 L .51513 .84691 L p .707 .577 .707 r
F P
0 g
s
.17411 .74214 m .16983 .77847 L .19069 .78819 L p .707 .577 .707 r
F P
0 g
s
.20127 .78984 m .19952 .77122 L .17859 .76746 L p .707 .577 .707 r
F P
0 g
s
.16727 .61159 m .15946 .66574 L .17183 .67677 L p .707 .577 .707 r
F P
0 g
s
.63684 .73086 m .64112 .69453 L .66837 .70254 L p .707 .577 .707 r
F P
0 g
s
.63094 .29452 m .63396 .79672 L .64396 .78496 L p .707 .577 .707 r
F P
0 g
s
.64396 .78496 m .64094 .28275 L .63094 .29452 L p .707 .577 .707 r
F P
0 g
s
.17859 .76746 m .18034 .78609 L .20127 .78984 L p .707 .577 .707 r
F P
0 g
s
.35936 .64079 m .35155 .69494 L .35868 .68588 L p .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .36607 .6346 L p .35936 .64079 L .707 .577 .707 r
F P
0 g
s
.34284 .7555 m .34459 .77413 L .36094 .76629 L p .707 .577 .707 r
F P
0 g
s
.36094 .76629 m .35919 .74766 L .34284 .7555 L p .707 .577 .707 r
F P
0 g
s
.36619 .6321 m .35936 .64079 L p .36607 .6346 L .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .35593 .67531 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .36649 .63173 L .36619 .6321 L p .707 .577 .707 r
F P
0 g
s
.36649 .63173 m .36607 .6346 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .35868 .68588 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .35309 .27927 L p .35762 .60687 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36649 .63173 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .36317 .62508 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .36373 .62116 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35919 .74766 m .36094 .76629 L .3672 .75933 L p .707 .577 .707 r
F P
0 g
s
.3672 .75933 m .36804 .7584 L p .36714 .75729 L .707 .577 .707 r
F P
0 g
s
.36714 .75729 m .35919 .74766 L .3672 .75933 L .707 .577 .707 r
F
.36804 .7584 m .3663 .73977 L .35919 .74766 L p F P
0 g
s
.35435 .75633 m .35007 .79265 L .35718 .78372 L p .707 .577 .707 r
F P
0 g
s
.35718 .78372 m .36146 .74739 L .35435 .75633 L p .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .34356 .66428 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36317 .62508 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .35593 .67531 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .35137 .61013 L .36301 .62052 L p .707 .577 .707 r
F P
0 g
s
.36301 .62052 m .36373 .62116 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .36301 .62052 L .36308 .62256 L .707 .577 .707 r
F
.3533 .31385 m .35351 .34894 L p .35378 .3294 L F P
0 g
s
.36146 .74739 m .35718 .78372 L .35438 .77351 L p .707 .577 .707 r
F P
0 g
s
.35438 .77351 m .35866 .73718 L .36146 .74739 L p .707 .577 .707 r
F P
0 g
s
.35007 .79265 m .35435 .75633 L .33801 .76312 L p .707 .577 .707 r
F P
0 g
s
.35866 .73718 m .35438 .77351 L .34271 .76367 L p .707 .577 .707 r
F P
0 g
s
.34271 .76367 m .34194 .76303 L p .34276 .76177 L .707 .577 .707 r
F P
0 g
s
.34276 .76177 m .35866 .73718 L .34271 .76367 L .707 .577 .707 r
F
.34194 .76303 m .34622 .7267 L .35866 .73718 L p F P
0 g
s
.3559 .74695 m .35272 .74549 L p .35587 .74171 L .707 .577 .707 r
F P
0 g
s
.35587 .74171 m .36346 .7326 L .3559 .74695 L .707 .577 .707 r
F
.36346 .7326 m .36521 .75123 L .3559 .74695 L p F P
0 g
s
.35272 .74549 m .35097 .72686 L .36346 .7326 L p .707 .577 .707 r
F P
0 g
s
.35351 .34894 m .35611 .78148 L p .35395 .36149 L .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .3602 .79341 L p .35441 .37466 L .707 .577 .707 r
F P
0 g
s
.35441 .37466 m .35378 .3294 L .35395 .36149 L .707 .577 .707 r
F
.35441 .37466 m .35395 .36149 L .35611 .78148 L F
.35911 .61174 m .35718 .29121 L p .35897 .6113 L F P
0 g
s
.35985 .7679 m .35897 .6113 L .35762 .60687 L .707 .577 .707 r
F
.35897 .6113 m .35718 .29121 L .35762 .60687 L F
.3663 .73977 m .36804 .7584 L .36521 .75123 L p F P
0 g
s
.36521 .75123 m .36346 .7326 L .3663 .73977 L p .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .3602 .79341 L .37798 .80435 L p .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .35363 .36867 L p .36309 .26751 L .707 .577 .707 r
F P
0 g
s
.35378 .3294 m .35351 .34894 L .35395 .36149 L .707 .577 .707 r
F
.35309 .27927 m .3533 .31385 L p .35378 .3294 L F P
0 g
s
.35363 .36867 m .35309 .27927 L .3562 .27561 L p .707 .577 .707 r
F P
0 g
s
.3562 .27561 m .36309 .26751 L p .35363 .36867 L .707 .577 .707 r
F P
0 g
s
.36002 .76412 m .35911 .61174 L p .35985 .7679 L .707 .577 .707 r
F P
0 g
s
.35911 .61174 m .35897 .6113 L .35985 .7679 L .707 .577 .707 r
F
.3602 .79341 m .36002 .76412 L p .35985 .7679 L F P
0 g
s
.69398 .80848 m .69573 .82711 L .6748 .82335 L p .707 .577 .707 r
F P
0 g
s
.6748 .82335 m .67305 .80472 L .69398 .80848 L p .707 .577 .707 r
F P
0 g
s
.15946 .66574 m .16727 .61159 L .16451 .60103 L p .707 .577 .707 r
F P
0 g
s
.33801 .76312 m .33373 .79945 L .35007 .79265 L p .707 .577 .707 r
F P
0 g
s
.16983 .77847 m .17411 .74214 L .16167 .73166 L p .707 .577 .707 r
F P
0 g
s
.16167 .73166 m .15739 .76799 L .16983 .77847 L p .707 .577 .707 r
F P
0 g
s
.18034 .78609 m .17859 .76746 L .1661 .76172 L p .707 .577 .707 r
F P
0 g
s
.1661 .76172 m .16784 .78035 L .18034 .78609 L p .707 .577 .707 r
F P
0 g
s
.16451 .60103 m .15671 .65518 L .15946 .66574 L p .707 .577 .707 r
F P
0 g
s
.67305 .80472 m .6748 .82335 L .64748 .82195 L p .707 .577 .707 r
F P
0 g
s
.64748 .82195 m .64574 .80333 L .67305 .80472 L p .707 .577 .707 r
F P
0 g
s
.15671 .65518 m .16451 .60103 L .17165 .59196 L p .707 .577 .707 r
F P
0 g
s
.64094 .28275 m .64396 .78496 L .63987 .77302 L p .707 .577 .707 r
F P
0 g
s
.63987 .77302 m .63685 .27082 L .64094 .28275 L p .707 .577 .707 r
F P
0 g
s
.15739 .76799 m .16167 .73166 L .15887 .72146 L p .707 .577 .707 r
F P
0 g
s
.64574 .80333 m .64748 .82195 L .61645 .82304 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16784 .78035 m .1661 .76172 L .16326 .75456 L p .707 .577 .707 r
F P
0 g
s
.16326 .75456 m .16501 .77318 L .16784 .78035 L p .707 .577 .707 r
F P
0 g
s
.15887 .72146 m .15459 .75778 L .15739 .76799 L p .707 .577 .707 r
F P
0 g
s
.17165 .59196 m .16384 .64612 L .15671 .65518 L p .707 .577 .707 r
F P
0 g
s
.16384 .64612 m .17165 .59196 L .18797 .58529 L p .707 .577 .707 r
F P
0 g
s
.15459 .75778 m .15887 .72146 L .16598 .71252 L p .707 .577 .707 r
F P
0 g
s
.16501 .77318 m .16326 .75456 L .17037 .74667 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17037 .74667 m .17212 .76529 L .16501 .77318 L p .707 .577 .707 r
F P
0 g
s
.16598 .71252 m .1617 .74885 L .15459 .75778 L p .707 .577 .707 r
F P
0 g
s
.18797 .58529 m .18016 .63945 L .16384 .64612 L p .707 .577 .707 r
F P
0 g
s
.63685 .27082 m .63987 .77302 L .6221 .76208 L p .707 .577 .707 r
F P
0 g
s
.6221 .76208 m .61908 .25988 L .63685 .27082 L p .707 .577 .707 r
F P
0 g
s
.35137 .61013 m .34356 .66428 L .32279 .65386 L p .707 .577 .707 r
F P
0 g
s
.32279 .65386 m .33059 .59971 L .35137 .61013 L p .707 .577 .707 r
F P
0 g
s
.18016 .63945 m .18797 .58529 L .21188 .58166 L p .707 .577 .707 r
F P
0 g
s
.1617 .74885 m .16598 .71252 L .18232 .70572 L p .707 .577 .707 r
F P
0 g
s
.36611 .76971 m .36309 .26751 L .3862 .25706 L p .707 .577 .707 r
F P
0 g
s
.36309 .26751 m .36611 .76971 L .35611 .78148 L p .707 .577 .707 r
F P
0 g
s
.17212 .76529 m .17037 .74667 L .18672 .73882 L p .707 .577 .707 r
F P
0 g
s
.33059 .59971 m .32279 .65386 L .29564 .64507 L p .707 .577 .707 r
F P
0 g
s
.29564 .64507 m .30345 .59092 L .33059 .59971 L p .707 .577 .707 r
F P
0 g
s
.21188 .58166 m .20407 .63582 L .18016 .63945 L p .707 .577 .707 r
F P
0 g
s
.20407 .63582 m .21188 .58166 L .24103 .58143 L p .707 .577 .707 r
F P
0 g
s
.18232 .70572 m .17804 .74205 L .1617 .74885 L p .707 .577 .707 r
F P
0 g
s
.18672 .73882 m .18846 .75745 L .17212 .76529 L p .707 .577 .707 r
F P
0 g
s
.34622 .7267 m .34194 .76303 L .32108 .75331 L p .707 .577 .707 r
F P
0 g
s
.32108 .75331 m .32536 .71698 L .34622 .7267 L p .707 .577 .707 r
F P
0 g
s
.35097 .72686 m .35272 .74549 L .33179 .74173 L p .707 .577 .707 r
F P
0 g
s
.33179 .74173 m .33004 .72311 L .35097 .72686 L p .707 .577 .707 r
F P
0 g
s
.61908 .25988 m .6221 .76208 L .59237 .75321 L p .707 .577 .707 r
F P
0 g
s
.59237 .75321 m .58935 .25101 L .61908 .25988 L p .707 .577 .707 r
F P
0 g
s
.30345 .59092 m .29564 .64507 L .26478 .63877 L p .707 .577 .707 r
F P
0 g
s
.26478 .63877 m .27259 .58462 L .30345 .59092 L p .707 .577 .707 r
F P
0 g
s
.23323 .63559 m .24103 .58143 L .27259 .58462 L p .707 .577 .707 r
F P
0 g
s
.24103 .58143 m .23323 .63559 L .20407 .63582 L p .707 .577 .707 r
F P
0 g
s
.17804 .74205 m .18232 .70572 L .20627 .70174 L p .707 .577 .707 r
F P
0 g
s
.27259 .58462 m .26478 .63877 L .23323 .63559 L p .707 .577 .707 r
F P
0 g
s
.18846 .75745 m .18672 .73882 L .2107 .7318 L p .707 .577 .707 r
F P
0 g
s
.3862 .25706 m .38922 .75927 L .36611 .76971 L p .707 .577 .707 r
F P
0 g
s
.38922 .75927 m .3862 .25706 L .42016 .24896 L p .707 .577 .707 r
F P
0 g
s
.2107 .7318 m .21245 .75042 L .18846 .75745 L p .707 .577 .707 r
F P
0 g
s
.20627 .70174 m .20199 .73807 L .17804 .74205 L p .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73339 .65892 L .73314 .65888 L p .707 .577 .707 r
F P
0 g
s
.73314 .65888 m .70243 .6534 L p .72773 .69309 L .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73314 .65888 L .72773 .69309 L .707 .577 .707 r
F
.73339 .65892 m .72911 .69525 L .76076 .69774 L p F P
0 g
s
.76076 .69774 m .76504 .66141 L .76466 .66138 L p .707 .577 .707 r
F P
0 g
s
.76466 .66138 m .73339 .65892 L p .75862 .69471 L .707 .577 .707 r
F P
0 g
s
.76076 .69774 m .76466 .66138 L .75862 .69471 L .707 .577 .707 r
F
.76504 .66141 m .76076 .69774 L .78999 .69696 L p F P
0 g
s
.78999 .69696 m .79427 .66063 L .79385 .66064 L p .707 .577 .707 r
F P
0 g
s
.79385 .66064 m .76504 .66141 L p .78759 .69354 L .707 .577 .707 r
F P
0 g
s
.78999 .69696 m .79385 .66064 L .78759 .69354 L .707 .577 .707 r
F
.79427 .66063 m .78999 .69696 L .81395 .69297 L p F P
0 g
s
.81395 .69297 m .81823 .65664 L .81786 .65671 L p .707 .577 .707 r
F P
0 g
s
.81786 .65671 m .79427 .66063 L p .81188 .68957 L .707 .577 .707 r
F P
0 g
s
.81395 .69297 m .81786 .65671 L .81188 .68957 L .707 .577 .707 r
F
.81823 .65664 m .81395 .69297 L .83028 .68618 L p F P
0 g
s
.83028 .68618 m .83456 .64985 L .83431 .64995 L p .707 .577 .707 r
F P
0 g
s
.83431 .64995 m .81823 .65664 L p .82902 .68308 L .707 .577 .707 r
F P
0 g
s
.83028 .68618 m .83431 .64995 L .82902 .68308 L .707 .577 .707 r
F
.83456 .64985 m .83028 .68618 L .8374 .67724 L p F P
0 g
s
.8374 .67724 m .84168 .64091 L .84158 .64104 L p .707 .577 .707 r
F P
0 g
s
.84158 .64104 m .83456 .64985 L p .83713 .67462 L .707 .577 .707 r
F P
0 g
s
.8374 .67724 m .84158 .64104 L .83713 .67462 L .707 .577 .707 r
F
.83177 .66825 m .8389 .65919 L p .83952 .61739 L F P
0 g
s
.8389 .65919 m .84233 .63534 L p .83957 .61409 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8467 .60503 L .84616 .60572 L p .707 .577 .707 r
F P
0 g
s
.84616 .60572 m .83957 .61409 L p .84233 .63534 L .707 .577 .707 r
F P
0 g
s
.84168 .64091 m .8374 .67724 L .83707 .67606 L p .707 .577 .707 r
F P
0 g
s
.8389 .65919 m .83615 .64862 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8389 .65919 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.83707 .67606 m .8346 .66703 L p .84156 .64136 L .707 .577 .707 r
F P
0 g
s
.84156 .64136 m .84168 .64091 L .83707 .67606 L .707 .577 .707 r
F
.8467 .60503 m .84233 .63534 L p .84593 .60822 L F P
0 g
s
.83957 .61409 m .83521 .64434 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.83521 .64434 m .83177 .66825 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .83177 .66825 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.82325 .62077 m .81888 .65107 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.81888 .65107 m .81545 .67492 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .81545 .67492 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79934 .62439 m .79495 .65488 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79495 .65488 m .79154 .67855 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .79154 .67855 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.77018 .62463 m .76575 .65539 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.76575 .65539 m .76238 .67878 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .76238 .67878 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73863 .62144 m .73414 .65254 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73414 .65254 m .73082 .67559 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .73863 .62144 L .70777 .61514 L p .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .77018 .62463 L .73863 .62144 L p .707 .577 .707 r
F P
0 g
s
.32536 .71698 m .32108 .75331 L .29908 .74684 L p .707 .577 .707 r
F P
0 g
s
.29919 .74052 m .27344 .74143 L p .29948 .72389 L .707 .577 .707 r
F P
0 g
s
.29908 .74684 m .29383 .74529 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29919 .74048 m .32536 .71698 L .29908 .74684 L .707 .577 .707 r
F
.27344 .74143 m .27169 .7228 L .29951 .72182 L p F P
0 g
s
.27344 .74143 m .29951 .72182 L .29948 .72389 L .707 .577 .707 r
F
.29383 .74529 m .29811 .70897 L .29973 .70944 L p F P
0 g
s
.29973 .70944 m .32536 .71698 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29383 .74529 m .29973 .70944 L .29919 .74048 L .707 .577 .707 r
F
.29951 .72182 m .30273 .72171 L p .29948 .72389 L F P
0 g
s
.30273 .72171 m .30447 .74033 L .29919 .74052 L p .707 .577 .707 r
F P
0 g
s
.29948 .72389 m .30273 .72171 L .29919 .74052 L .707 .577 .707 r
F
.33004 .72311 m .33179 .74173 L .30447 .74033 L p F P
0 g
s
.30447 .74033 m .30273 .72171 L .33004 .72311 L p .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .79934 .62439 L .77018 .62463 L p .707 .577 .707 r
F P
0 g
s
.69996 .66929 m .70777 .61514 L .68062 .60635 L p .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70243 .6534 L .70235 .65338 L p .707 .577 .707 r
F P
0 g
s
.70323 .64663 m .69996 .66929 L .70027 .66935 L p .707 .577 .707 r
F P
0 g
s
.68062 .60635 m .67282 .6605 L .69996 .66929 L p .707 .577 .707 r
F P
0 g
s
.70235 .65338 m .67519 .64539 L p .69773 .68891 L .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70235 .65338 L .69773 .68891 L .707 .577 .707 r
F
.70777 .61514 m .70323 .64663 L p .73082 .67559 L F P
0 g
s
.70243 .6534 m .69815 .68973 L .72911 .69525 L p .707 .577 .707 r
F P
0 g
s
.70027 .66935 m .73082 .67559 L p .70323 .64663 L .707 .577 .707 r
F P
0 g
s
.20199 .73807 m .20627 .70174 L .23551 .70095 L p .707 .577 .707 r
F P
0 g
s
.21245 .75042 m .2107 .7318 L .23999 .72628 L p .707 .577 .707 r
F P
0 g
s
.58935 .25101 m .59237 .75321 L .55361 .74728 L p .707 .577 .707 r
F P
0 g
s
.55361 .74728 m .55059 .24508 L .58935 .25101 L p .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .82325 .62077 L .79934 .62439 L p .707 .577 .707 r
F P
0 g
s
.27169 .7228 m .27344 .74143 L .24173 .7449 L p .707 .577 .707 r
F P
0 g
s
.29811 .70897 m .29383 .74529 L .26287 .73977 L p .707 .577 .707 r
F P
0 g
s
.24173 .7449 m .23999 .72628 L .27169 .7228 L p .707 .577 .707 r
F P
0 g
s
.26287 .73977 m .26715 .70344 L .29811 .70897 L p .707 .577 .707 r
F P
0 g
s
.23999 .72628 m .24173 .7449 L .21245 .75042 L p .707 .577 .707 r
F P
0 g
s
.23551 .70095 m .23123 .73728 L .20199 .73807 L p .707 .577 .707 r
F P
0 g
s
.23123 .73728 m .23551 .70095 L .26715 .70344 L p .707 .577 .707 r
F P
0 g
s
.67282 .6605 m .68062 .60635 L .65985 .59593 L p .707 .577 .707 r
F P
0 g
s
.26715 .70344 m .26287 .73977 L .23123 .73728 L p .707 .577 .707 r
F P
0 g
s
.42318 .75117 m .42016 .24896 L .46164 .244 L p .707 .577 .707 r
F P
0 g
s
.42016 .24896 m .42318 .75117 L .38922 .75927 L p .707 .577 .707 r
F P
0 g
s
.67519 .64539 m .67091 .68172 L .69815 .68973 L p .707 .577 .707 r
F P
0 g
s
.65985 .59593 m .65205 .65008 L .67282 .6605 L p .707 .577 .707 r
F P
0 g
s
.67091 .68172 m .67519 .64539 L .65432 .63566 L p .707 .577 .707 r
F P
0 g
s
.55059 .24508 m .55361 .74728 L .5096 .74487 L p .707 .577 .707 r
F P
0 g
s
.5096 .74487 m .50658 .24266 L .55059 .24508 L p .707 .577 .707 r
F P
0 g
s
.83177 .66825 m .83957 .61409 L .82325 .62077 L p .707 .577 .707 r
F P
0 g
s
.73983 .77973 m .73808 .76111 L .70705 .7622 L p .707 .577 .707 r
F P
0 g
s
.73808 .76111 m .73983 .77973 L .77154 .77625 L p .707 .577 .707 r
F P
0 g
s
.77154 .77625 m .76979 .75763 L .73808 .76111 L p .707 .577 .707 r
F P
0 g
s
.76979 .75763 m .77154 .77625 L .80082 .77073 L p .707 .577 .707 r
F P
0 g
s
.80082 .77073 m .79907 .75211 L .76979 .75763 L p .707 .577 .707 r
F P
0 g
s
.65205 .65008 m .65985 .59593 L .64748 .5849 L p .707 .577 .707 r
F P
0 g
s
.46466 .74621 m .46164 .244 L .50658 .24266 L p .707 .577 .707 r
F P
0 g
s
.46164 .244 m .46466 .74621 L .42318 .75117 L p .707 .577 .707 r
F P
0 g
s
.70705 .7622 m .7088 .78082 L .73983 .77973 L p .707 .577 .707 r
F P
0 g
s
.65432 .63566 m .65004 .67199 L .67091 .68172 L p .707 .577 .707 r
F P
0 g
s
.50658 .24266 m .5096 .74487 L .46466 .74621 L p .707 .577 .707 r
F P
0 g
s
.7088 .78082 m .70705 .7622 L .67973 .7608 L p .707 .577 .707 r
F P
0 g
s
.67973 .7608 m .68148 .77942 L .7088 .78082 L p .707 .577 .707 r
F P
0 g
s
.79907 .75211 m .80082 .77073 L .82481 .76371 L p .707 .577 .707 r
F P
0 g
s
.82481 .76371 m .82306 .74508 L .79907 .75211 L p .707 .577 .707 r
F P
0 g
s
.64748 .5849 m .63968 .63905 L .65205 .65008 L p .707 .577 .707 r
F P
0 g
s
.65004 .67199 m .65432 .63566 L .64188 .62519 L p .707 .577 .707 r
F P
0 g
s
.68148 .77942 m .67973 .7608 L .6588 .75704 L p .707 .577 .707 r
F P
0 g
s
.64188 .62519 m .6376 .66152 L .65004 .67199 L p .707 .577 .707 r
F P
0 g
s
.6588 .75704 m .66055 .77567 L .68148 .77942 L p .707 .577 .707 r
F P
0 g
s
.63968 .63905 m .64748 .5849 L .64473 .57433 L p .707 .577 .707 r
F P
0 g
s
.82306 .74508 m .82481 .76371 L .84115 .75587 L p .707 .577 .707 r
F P
0 g
s
.84115 .75587 m .8394 .73724 L .82306 .74508 L p .707 .577 .707 r
F P
0 g
s
.64473 .57433 m .63692 .62849 L .63968 .63905 L p .707 .577 .707 r
F P
0 g
s
.6376 .66152 m .64188 .62519 L .63908 .61498 L p .707 .577 .707 r
F P
0 g
s
.66055 .77567 m .6588 .75704 L .64631 .7513 L p .707 .577 .707 r
F P
0 g
s
.64631 .7513 m .64806 .76993 L .66055 .77567 L p .707 .577 .707 r
F P
0 g
s
.83615 .64862 m .83956 .62495 L p .8467 .60503 L .707 .577 .707 r
F P
0 g
s
.84395 .59447 m .83615 .64862 L .82378 .63759 L p .707 .577 .707 r
F P
0 g
s
.83888 .6307 m .8346 .66703 L .8333 .66594 L p .707 .577 .707 r
F P
0 g
s
.8333 .66594 m .82216 .65656 L p .83862 .63111 L .707 .577 .707 r
F P
0 g
s
.83862 .63111 m .83888 .6307 L .8333 .66594 L .707 .577 .707 r
F
.83956 .62495 m .84395 .59447 L .84412 .59511 L p F P
0 g
s
.84412 .59511 m .8467 .60503 L p .83956 .62495 L .707 .577 .707 r
F P
0 g
s
.63908 .61498 m .6348 .65131 L .6376 .66152 L p .707 .577 .707 r
F P
0 g
s
.8394 .73724 m .84115 .75587 L .84826 .74797 L p .707 .577 .707 r
F P
0 g
s
.84826 .74797 m .84651 .72935 L .8394 .73724 L p .707 .577 .707 r
F P
0 g
s
.6348 .65131 m .63908 .61498 L .6462 .60604 L p .707 .577 .707 r
F P
0 g
s
.63692 .62849 m .64473 .57433 L .65186 .56527 L p .707 .577 .707 r
F P
0 g
s
.8346 .66703 m .83888 .6307 L .84168 .64091 L p .707 .577 .707 r
F P
0 g
s
.64806 .76993 m .64631 .7513 L .64348 .74414 L p .707 .577 .707 r
F P
0 g
s
.6462 .60604 m .64192 .64237 L .6348 .65131 L p .707 .577 .707 r
F P
0 g
s
.65186 .56527 m .64406 .61943 L .63692 .62849 L p .707 .577 .707 r
F P
0 g
s
.64348 .74414 m .64523 .76276 L .64806 .76993 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38781 .61024 m .39562 .55609 L .36476 .54979 L p .707 .577 .707 r
F P
0 g
s
.39562 .55609 m .38781 .61024 L .41937 .61343 L p .707 .577 .707 r
F P
0 g
s
.41937 .61343 m .42717 .55928 L .39562 .55609 L p .707 .577 .707 r
F P
0 g
s
.82378 .63759 m .82715 .6142 L p .84395 .59447 L .707 .577 .707 r
F P
0 g
s
.83158 .58344 m .82378 .63759 L .803 .62717 L p .707 .577 .707 r
F P
0 g
s
.82644 .62023 m .82216 .65656 L .82041 .65574 L p .707 .577 .707 r
F P
0 g
s
.82041 .65574 m .80129 .64683 L p .82611 .62057 L .707 .577 .707 r
F P
0 g
s
.82611 .62057 m .82644 .62023 L .82041 .65574 L .707 .577 .707 r
F
.82715 .6142 m .83158 .58344 L .83207 .58387 L p F P
0 g
s
.83207 .58387 m .84395 .59447 L p .82715 .6142 L .707 .577 .707 r
F P
0 g
s
.42717 .55928 m .41937 .61343 L .44853 .6132 L p .707 .577 .707 r
F P
0 g
s
.44853 .6132 m .45633 .55905 L .42717 .55928 L p .707 .577 .707 r
F P
0 g
s
.64192 .64237 m .6462 .60604 L .66253 .59925 L p .707 .577 .707 r
F P
0 g
s
.64406 .61943 m .65186 .56527 L .66818 .5586 L p .707 .577 .707 r
F P
0 g
s
.84651 .72935 m .84826 .74797 L .84543 .74081 L p .707 .577 .707 r
F P
0 g
s
.84543 .74081 m .84368 .72218 L .84651 .72935 L p .707 .577 .707 r
F P
0 g
s
.35695 .60394 m .36476 .54979 L .33761 .541 L p .707 .577 .707 r
F P
0 g
s
.36476 .54979 m .35695 .60394 L .38781 .61024 L p .707 .577 .707 r
F P
0 g
s
.82216 .65656 m .82644 .62023 L .83888 .6307 L p .707 .577 .707 r
F P
0 g
s
.45633 .55905 m .44853 .6132 L .47244 .60957 L p .707 .577 .707 r
F P
0 g
s
.47244 .60957 m .48024 .55542 L .45633 .55905 L p .707 .577 .707 r
F P
0 g
s
.32981 .59515 m .33761 .541 L .31684 .53058 L p .707 .577 .707 r
F P
0 g
s
.33761 .541 m .32981 .59515 L .35695 .60394 L p .707 .577 .707 r
F P
0 g
s
.64523 .76276 m .64348 .74414 L .65058 .73625 L p .707 .577 .707 r
F P
0 g
s
.66253 .59925 m .65825 .63558 L .64192 .64237 L p .707 .577 .707 r
F P
0 g
s
.66818 .5586 m .66038 .61275 L .64406 .61943 L p .707 .577 .707 r
F P
0 g
s
.65058 .73625 m .65233 .75487 L .64523 .76276 L p .707 .577 .707 r
F P
0 g
s
.803 .62717 m .80632 .60413 L p .83158 .58344 L .707 .577 .707 r
F P
0 g
s
.81081 .57302 m .803 .62717 L .77613 .61847 L p .707 .577 .707 r
F P
0 g
s
.77346 .63872 m .74308 .6333 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77613 .61847 m .77586 .61838 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.7762 .61794 m .81081 .57302 L .77613 .61847 L .707 .577 .707 r
F
.78366 .56423 m .81081 .57302 L p .7762 .61794 L F P
0 g
s
.74308 .6333 m .74736 .59697 L .77823 .60247 L p .707 .577 .707 r
F P
0 g
s
.74308 .6333 m .77823 .60247 L .77822 .60258 L .707 .577 .707 r
F
.77586 .61838 m .77912 .59572 L p .7762 .61794 L F P
0 g
s
.77912 .59572 m .78366 .56423 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.77823 .60247 m .77833 .60249 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77833 .60249 m .77405 .63882 L .77346 .63872 L p .707 .577 .707 r
F P
0 g
s
.77822 .60258 m .77833 .60249 L .77346 .63872 L .707 .577 .707 r
F
.80557 .61051 m .80129 .64683 L .79982 .6464 L p F P
0 g
s
.79982 .6464 m .77405 .63882 L p .80531 .61075 L .707 .577 .707 r
F P
0 g
s
.80531 .61075 m .80557 .61051 L .79982 .6464 L .707 .577 .707 r
F
.80632 .60413 m .81081 .57302 L .81109 .57316 L p F P
0 g
s
.81109 .57316 m .83158 .58344 L p .80632 .60413 L .707 .577 .707 r
F P
0 g
s
.65825 .63558 m .66253 .59925 L .68649 .59526 L p .707 .577 .707 r
F P
0 g
s
.66038 .61275 m .66818 .5586 L .69209 .55497 L p .707 .577 .707 r
F P
0 g
s
.39682 .69811 m .39507 .67949 L .36404 .68058 L p .707 .577 .707 r
F P
0 g
s
.39507 .67949 m .39682 .69811 L .42853 .69464 L p .707 .577 .707 r
F P
0 g
s
.42853 .69464 m .42678 .67601 L .39507 .67949 L p .707 .577 .707 r
F P
0 g
s
.36404 .68058 m .36579 .69921 L .39682 .69811 L p .707 .577 .707 r
F P
0 g
s
.3861 .70969 m .39038 .67336 L .35942 .66784 L p .707 .577 .707 r
F P
0 g
s
.39038 .67336 m .3861 .70969 L .41775 .71218 L p .707 .577 .707 r
F P
0 g
s
.41775 .71218 m .42203 .67585 L .39038 .67336 L p .707 .577 .707 r
F P
0 g
s
.84368 .72218 m .84543 .74081 L .83293 .73507 L p .707 .577 .707 r
F P
0 g
s
.83293 .73507 m .83119 .71644 L .84368 .72218 L p .707 .577 .707 r
F P
0 g
s
.42678 .67601 m .42853 .69464 L .45781 .68911 L p .707 .577 .707 r
F P
0 g
s
.45781 .68911 m .45606 .67049 L .42678 .67601 L p .707 .577 .707 r
F P
0 g
s
.48024 .55542 m .47244 .60957 L .48876 .6029 L p .707 .577 .707 r
F P
0 g
s
.48876 .6029 m .49656 .54875 L .48024 .55542 L p .707 .577 .707 r
F P
0 g
s
.31684 .53058 m .30904 .58473 L .32981 .59515 L p .707 .577 .707 r
F P
0 g
s
.42203 .67585 m .41775 .71218 L .44698 .71139 L p .707 .577 .707 r
F P
0 g
s
.44698 .71139 m .45126 .67507 L .42203 .67585 L p .707 .577 .707 r
F P
0 g
s
.80129 .64683 m .80557 .61051 L .82644 .62023 L p .707 .577 .707 r
F P
0 g
s
.35514 .70417 m .35942 .66784 L .33218 .65982 L p .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36404 .68058 L .36121 .68043 L p .707 .577 .707 r
F P
0 g
s
.35942 .66784 m .35514 .70417 L .36111 .70523 L p .707 .577 .707 r
F P
0 g
s
.36125 .6707 m .35942 .66784 L .36111 .70523 L .707 .577 .707 r
F
.33218 .65982 m .3279 .69615 L .35514 .70417 L p F P
0 g
s
.36121 .68043 m .33672 .67918 L p .36115 .69601 L .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36121 .68043 L .36115 .69601 L .707 .577 .707 r
F
.33672 .67918 m .33847 .69781 L .36579 .69921 L p F P
0 g
s
.36111 .70523 m .3861 .70969 L p .36125 .6707 L .707 .577 .707 r
F P
0 g
s
.30904 .58473 m .31684 .53058 L .30447 .51955 L p .707 .577 .707 r
F P
0 g
s
.45606 .67049 m .45781 .68911 L .4818 .68209 L p .707 .577 .707 r
F P
0 g
s
.4818 .68209 m .48005 .66346 L .45606 .67049 L p .707 .577 .707 r
F P
0 g
s
.68649 .59526 m .68221 .63159 L .65825 .63558 L p .707 .577 .707 r
F P
0 g
s
.69209 .55497 m .68429 .60913 L .66038 .61275 L p .707 .577 .707 r
F P
0 g
s
.45126 .67507 m .44698 .71139 L .47094 .70741 L p .707 .577 .707 r
F P
0 g
s
.47094 .70741 m .47522 .67108 L .45126 .67507 L p .707 .577 .707 r
F P
0 g
s
.68221 .63159 m .68649 .59526 L .71572 .59448 L p .707 .577 .707 r
F P
0 g
s
.68429 .60913 m .69209 .55497 L .72125 .55474 L p .707 .577 .707 r
F P
0 g
s
.65233 .75487 m .65058 .73625 L .66693 .7284 L p .707 .577 .707 r
F P
0 g
s
.3279 .69615 m .33218 .65982 L .31131 .6501 L p .707 .577 .707 r
F P
0 g
s
.66693 .7284 m .66868 .74703 L .65233 .75487 L p .707 .577 .707 r
F P
0 g
s
.31131 .6501 m .30703 .68643 L .3279 .69615 L p .707 .577 .707 r
F P
0 g
s
.33847 .69781 m .33672 .67918 L .31579 .67543 L p .707 .577 .707 r
F P
0 g
s
.30447 .51955 m .29667 .5737 L .30904 .58473 L p .707 .577 .707 r
F P
0 g
s
.77405 .63882 m .77833 .60249 L .80557 .61051 L p .707 .577 .707 r
F P
0 g
s
.31579 .67543 m .31754 .69405 L .33847 .69781 L p .707 .577 .707 r
F P
0 g
s
.74736 .59697 m .74308 .6333 L .71144 .63081 L p .707 .577 .707 r
F P
0 g
s
.78366 .56423 m .77586 .61838 L .745 .61208 L p .707 .577 .707 r
F P
0 g
s
.71144 .63081 m .71572 .59448 L .74736 .59697 L p .707 .577 .707 r
F P
0 g
s
.745 .61208 m .7528 .55793 L .78366 .56423 L p .707 .577 .707 r
F P
0 g
s
.49656 .54875 m .48876 .6029 L .49589 .59384 L p .707 .577 .707 r
F P
0 g
s
.49589 .59384 m .50369 .53969 L .49656 .54875 L p .707 .577 .707 r
F P
0 g
s
.83119 .71644 m .83293 .73507 L .81201 .73131 L p .707 .577 .707 r
F P
0 g
s
.81201 .73131 m .81026 .71269 L .83119 .71644 L p .707 .577 .707 r
F P
0 g
s
.71572 .59448 m .71144 .63081 L .68221 .63159 L p .707 .577 .707 r
F P
0 g
s
.71344 .60889 m .72125 .55474 L .7528 .55793 L p .707 .577 .707 r
F P
0 g
s
.72125 .55474 m .71344 .60889 L .68429 .60913 L p .707 .577 .707 r
F P
0 g
s
.48005 .66346 m .4818 .68209 L .49814 .67425 L p .707 .577 .707 r
F P
0 g
s
.49814 .67425 m .49639 .65562 L .48005 .66346 L p .707 .577 .707 r
F P
0 g
s
.29667 .5737 m .30447 .51955 L .30172 .50899 L p .707 .577 .707 r
F P
0 g
s
.7528 .55793 m .745 .61208 L .71344 .60889 L p .707 .577 .707 r
F P
0 g
s
.47522 .67108 m .47094 .70741 L .48727 .70062 L p .707 .577 .707 r
F P
0 g
s
.48727 .70062 m .49155 .66429 L .47522 .67108 L p .707 .577 .707 r
F P
0 g
s
.30703 .68643 m .31131 .6501 L .29887 .63962 L p .707 .577 .707 r
F P
0 g
s
.66868 .74703 m .66693 .7284 L .69092 .72138 L p .707 .577 .707 r
F P
0 g
s
.29887 .63962 m .29459 .67595 L .30703 .68643 L p .707 .577 .707 r
F P
0 g
s
.31754 .69405 m .31579 .67543 L .3033 .66968 L p .707 .577 .707 r
F P
0 g
s
.69092 .72138 m .69267 .74 L .66868 .74703 L p .707 .577 .707 r
F P
0 g
s
.3033 .66968 m .30505 .68831 L .31754 .69405 L p .707 .577 .707 r
F P
0 g
s
.30172 .50899 m .29391 .56314 L .29667 .5737 L p .707 .577 .707 r
F P
0 g
s
.81026 .71269 m .81201 .73131 L .78469 .72991 L p .707 .577 .707 r
F P
0 g
s
.78469 .72991 m .78294 .71129 L .81026 .71269 L p .707 .577 .707 r
F P
0 g
s
.50369 .53969 m .49589 .59384 L .49314 .58327 L p .707 .577 .707 r
F P
0 g
s
.49314 .58327 m .50094 .52912 L .50369 .53969 L p .707 .577 .707 r
F P
0 g
s
.49639 .65562 m .49814 .67425 L .50525 .66636 L p .707 .577 .707 r
F P
0 g
s
.50525 .66636 m .5035 .64773 L .49639 .65562 L p .707 .577 .707 r
F P
0 g
s
.49155 .66429 m .48727 .70062 L .49439 .69168 L p .707 .577 .707 r
F P
0 g
s
.49439 .69168 m .49867 .65535 L .49155 .66429 L p .707 .577 .707 r
F P
0 g
s
.69267 .74 m .69092 .72138 L .7202 .71586 L p .707 .577 .707 r
F P
0 g
s
.29391 .56314 m .30172 .50899 L .30885 .49993 L p .707 .577 .707 r
F P
0 g
s
.7202 .71586 m .72195 .73448 L .69267 .74 L p .707 .577 .707 r
F P
0 g
s
.29459 .67595 m .29887 .63962 L .29607 .62942 L p .707 .577 .707 r
F P
0 g
s
.78294 .71129 m .78469 .72991 L .75366 .73101 L p .707 .577 .707 r
F P
0 g
s
.75366 .73101 m .75191 .71238 L .78294 .71129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.72195 .73448 m .7202 .71586 L .75191 .71238 L p .707 .577 .707 r
F P
0 g
s
.30505 .68831 m .3033 .66968 L .30047 .66252 L p .707 .577 .707 r
F P
0 g
s
.75191 .71238 m .75366 .73101 L .72195 .73448 L p .707 .577 .707 r
F P
0 g
s
.30047 .66252 m .30222 .68114 L .30505 .68831 L p .707 .577 .707 r
F P
0 g
s
.29607 .62942 m .29179 .66575 L .29459 .67595 L p .707 .577 .707 r
F P
0 g
s
.30885 .49993 m .30105 .55408 L .29391 .56314 L p .707 .577 .707 r
F P
0 g
s
.50094 .52912 m .49314 .58327 L .48077 .57224 L p .707 .577 .707 r
F P
0 g
s
.48077 .57224 m .48857 .51809 L .50094 .52912 L p .707 .577 .707 r
F P
0 g
s
.5035 .64773 m .50525 .66636 L .50242 .65919 L p .707 .577 .707 r
F P
0 g
s
.50242 .65919 m .50067 .64056 L .5035 .64773 L p .707 .577 .707 r
F P
0 g
s
.49867 .65535 m .49439 .69168 L .49159 .68147 L p .707 .577 .707 r
F P
0 g
s
.49159 .68147 m .49587 .64514 L .49867 .65535 L p .707 .577 .707 r
F P
0 g
s
.30105 .55408 m .30885 .49993 L .32517 .49325 L p .707 .577 .707 r
F P
0 g
s
.29179 .66575 m .29607 .62942 L .30319 .62048 L p .707 .577 .707 r
F P
0 g
s
.30222 .68114 m .30047 .66252 L .30757 .65463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30757 .65463 m .30932 .67325 L .30222 .68114 L p .707 .577 .707 r
F P
0 g
s
.30319 .62048 m .29891 .65681 L .29179 .66575 L p .707 .577 .707 r
F P
0 g
s
.32517 .49325 m .31737 .54741 L .30105 .55408 L p .707 .577 .707 r
F P
0 g
s
.48857 .51809 m .48077 .57224 L .45999 .56182 L p .707 .577 .707 r
F P
0 g
s
.45999 .56182 m .4678 .50767 L .48857 .51809 L p .707 .577 .707 r
F P
0 g
s
.31737 .54741 m .32517 .49325 L .34908 .48963 L p .707 .577 .707 r
F P
0 g
s
.49587 .64514 m .49159 .68147 L .47915 .67099 L p .707 .577 .707 r
F P
0 g
s
.47915 .67099 m .48343 .63466 L .49587 .64514 L p .707 .577 .707 r
F P
0 g
s
.50067 .64056 m .50242 .65919 L .48992 .65345 L p .707 .577 .707 r
F P
0 g
s
.48992 .65345 m .48818 .63482 L .50067 .64056 L p .707 .577 .707 r
F P
0 g
s
.29891 .65681 m .30319 .62048 L .31952 .61368 L p .707 .577 .707 r
F P
0 g
s
.30932 .67325 m .30757 .65463 L .32392 .64679 L p .707 .577 .707 r
F P
0 g
s
.4678 .50767 m .45999 .56182 L .43285 .55303 L p .707 .577 .707 r
F P
0 g
s
.43285 .55303 m .44065 .49888 L .4678 .50767 L p .707 .577 .707 r
F P
0 g
s
.34908 .48963 m .34128 .54378 L .31737 .54741 L p .707 .577 .707 r
F P
0 g
s
.34128 .54378 m .34908 .48963 L .37824 .48939 L p .707 .577 .707 r
F P
0 g
s
.31952 .61368 m .31524 .65001 L .29891 .65681 L p .707 .577 .707 r
F P
0 g
s
.32392 .64679 m .32567 .66541 L .30932 .67325 L p .707 .577 .707 r
F P
0 g
s
.48343 .63466 m .47915 .67099 L .45828 .66127 L p .707 .577 .707 r
F P
0 g
s
.45828 .66127 m .46256 .62494 L .48343 .63466 L p .707 .577 .707 r
F P
0 g
s
.48818 .63482 m .48992 .65345 L .469 .64969 L p .707 .577 .707 r
F P
0 g
s
.469 .64969 m .46725 .63107 L .48818 .63482 L p .707 .577 .707 r
F P
0 g
s
.44065 .49888 m .43285 .55303 L .40199 .54674 L p .707 .577 .707 r
F P
0 g
s
.40199 .54674 m .40979 .49258 L .44065 .49888 L p .707 .577 .707 r
F P
0 g
s
.37043 .54355 m .37824 .48939 L .40979 .49258 L p .707 .577 .707 r
F P
0 g
s
.37824 .48939 m .37043 .54355 L .34128 .54378 L p .707 .577 .707 r
F P
0 g
s
.31524 .65001 m .31952 .61368 L .34348 .6097 L p .707 .577 .707 r
F P
0 g
s
.40979 .49258 m .40199 .54674 L .37043 .54355 L p .707 .577 .707 r
F P
0 g
s
.32567 .66541 m .32392 .64679 L .34791 .63976 L p .707 .577 .707 r
F P
0 g
s
.34791 .63976 m .34966 .65839 L .32567 .66541 L p .707 .577 .707 r
F P
0 g
s
.34348 .6097 m .3392 .64603 L .31524 .65001 L p .707 .577 .707 r
F P
0 g
s
.46256 .62494 m .45828 .66127 L .43629 .6548 L p .707 .577 .707 r
F P
0 g
s
.4364 .64848 m .41065 .64939 L p .43668 .63186 L .707 .577 .707 r
F P
0 g
s
.43629 .6548 m .43104 .65326 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.4364 .64844 m .46256 .62494 L .43629 .6548 L .707 .577 .707 r
F
.41065 .64939 m .4089 .63076 L .43672 .62978 L p F P
0 g
s
.41065 .64939 m .43672 .62978 L .43668 .63186 L .707 .577 .707 r
F
.43104 .65326 m .43532 .61693 L .43693 .6174 L p F P
0 g
s
.43693 .6174 m .46256 .62494 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.43104 .65326 m .43693 .6174 L .4364 .64844 L .707 .577 .707 r
F
.43672 .62978 m .43993 .62967 L p .43668 .63186 L F P
0 g
s
.43993 .62967 m .44168 .64829 L .4364 .64848 L p .707 .577 .707 r
F P
0 g
s
.43668 .63186 m .43993 .62967 L .4364 .64848 L .707 .577 .707 r
F
.46725 .63107 m .469 .64969 L .44168 .64829 L p F P
0 g
s
.44168 .64829 m .43993 .62967 L .46725 .63107 L p .707 .577 .707 r
F P
0 g
s
.3392 .64603 m .34348 .6097 L .37271 .60891 L p .707 .577 .707 r
F P
0 g
s
.34966 .65839 m .34791 .63976 L .37719 .63424 L p .707 .577 .707 r
F P
0 g
s
.4089 .63076 m .41065 .64939 L .37894 .65286 L p .707 .577 .707 r
F P
0 g
s
.43532 .61693 m .43104 .65326 L .40007 .64773 L p .707 .577 .707 r
F P
0 g
s
.37894 .65286 m .37719 .63424 L .4089 .63076 L p .707 .577 .707 r
F P
0 g
s
.40007 .64773 m .40435 .6114 L .43532 .61693 L p .707 .577 .707 r
F P
0 g
s
.37719 .63424 m .37894 .65286 L .34966 .65839 L p .707 .577 .707 r
F P
0 g
s
.37271 .60891 m .36843 .64524 L .3392 .64603 L p .707 .577 .707 r
F P
0 g
s
.36843 .64524 m .37271 .60891 L .40435 .6114 L p .707 .577 .707 r
F P
0 g
s
.40435 .6114 m .40007 .64773 L .36843 .64524 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007Ao
o`00Kgoo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`00L7oo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001]Ool006]oo`<000UJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH006Yoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0061ooa0000MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@002UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001IOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001VOol005Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Io
o`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH500000eYF001JEP02FUH3
0002FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001J
EP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00@005YF001JEP<000EJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`04001JEP000002FUH00`00FUIJEP02
FUH00`00FUIJEP06FUH00`00FUIJEP050009FUH50005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
4000C7oo001COol30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP02FUH400000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo10000eYF00<005YFFUH01UYF00@0
05YFFUIJEPL004Eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF3P001EYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01000@Goo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50006FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00Dgoo00<005YF
FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH005YF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH3000fOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P00=Goo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF0P002EYF0`00<Woo000iOol@000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00]JEP80
031oo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`0^Ool0039oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000Aoo`8000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00Oomoo`0]Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00Oomoo`0/Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000goo000000020002FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=oo`D000IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP020003Ool00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P0000=JEP0000000P000UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo
000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHH0002FUH00`00FUIJEP05FUH01000FUIJEUYF1@0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP8000EJEP<000EJEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0>00000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH40003FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH20006FUH30004FUH01P00FUIJEP00FUH002aoo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF
0080009JEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`000UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEP0000<002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP04001JEUYFFUH@0004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH010001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH500000eYF001JEP06FUH00`00FUIJEP04FUH8
0005FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000]Ool20003FUH50000
0eYF001JEP040009Ool70006FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo000/
Ool01000FUH005YF0`001EYF00<005YFFUH00eYF1@002goo100000AJEP00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0007FUH00`00FUIJ
EP02FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EUYF001JEP800004FUH005YFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool200000eYF001JEP02FUH0
1000FUIJEUYF400015YF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF00=JEP06001JEUYF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF009J
EP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF009J
EP8002eoo`00;7oo0`000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH015YF1`001Goo
0P000eYF1@001EYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF00<005YF
FUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=J
EP03001JEP0000<000]JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF1`0000=JEP0000000P000UYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF1@001eYF
00<005YFFUH00eYF10000UYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP8000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00H005YF000005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP040004FUH00`00FUIJEP07FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEP03001JEUYF00iJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF1@001UYF0P000UYF0P0015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00@005YFFUIJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP0>FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH2000^Ool002eoo`05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50006FUH2000015YF001JEP0015YF00<005YF0000
1@0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJEP05001JEUYF001J
EP04000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<0
05YFFUH03UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000^Ool0
02eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH20002FUH00`00
FUH00003FUH40005FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000025YF
001JEUYF001JEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUIJEP0>FUH00`00FUH000020004FUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH3000^Ool002ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP80009JEP04001JEP00FUH20003FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH300000eYF000000030002FUH01P00FUH00000FUH000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP02FUH017ooFUIJEUYF0P00
1UYF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01@00;Woo000_Ool20006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000EJEP03001J
EUYF00]JEPL000EJEP04001JEUYFFUH80003FUH01000FUH005YF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH010000UYF1P000eYF00<005YFFUH01EYF00@005YFFUIJEPH0009JEP<002ioo`00<7oo
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80
009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP<00003FUH005YF00AJEP03001JEP0000IJEPP000=JEP03001JEUYF009J
EPL000=JEP05001JEUYFOomJEP03000^Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00X0009JEP03001JEUYF00=JEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000IJEP03001JEUYF00IJ
EP03001JEP0000/000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;goo000cOol200000eYF
001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP04
001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00<7oo000eOol30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01@00FUIJEUYF000015YF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006FUH01000FUIJEUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00>7oo10000UYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH02UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000lOol50006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUH000020004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<007oo0000200015YF00<005YFFUH01EYF00@005YFFUIJEPD003Aoo`00@Goo10000UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo00Qooa0003Uoo`00=goo5@0015YF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH30005FUH0
1P00FUIJEP00FUH005=oo`00<goo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF5@001goo1`00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000AJEP06
001JEUYF001JEP00Dgoo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000>Ool01@00FUIJEP00FUH0200015YF00<005YFFUH01UYF00@005YFFUIJEP@000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF0080009JEP06001JEUYF001JEP00Dgoo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool01000FUIJEP001EYF00@005YF
FUIJEQ400003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<0009JEP8000QooaP003Aoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P0027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00=JEP80009JEP80009oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00=JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJ
EP0400001Goo001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH002eoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP03001JEUYF00=JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF009JEQH000AJEP03001JEUYF008002aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF009J
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00EJEP03001JEUYF00AJEPL001Ioo`<00003FUH005YF009JEP03001oogoo02Yoo`00
;7oo00<005YF00000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000MJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00AJEP03001JEUYF00@0021oo`<0009JEP03001oogoo02Yoo`00;7oo0P00
15YF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJEP03001J
EUYF009JEP@00003FUH007oo025oo`800003FUH00000008002]oo`00;7oo0P000UYF100000=JEP00
FUH01EYF00<005YFFUH015YF1P001Woo1@001eYF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YF00007goo
0`000eYF00@005YF000002]oo`00;7oo00=JEP0000000`000eYF00<005YFFUH015YF00<005YFFUH0
10004Goo0`0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04
001JEUYFFUH300000eYF00000003FUH00`00FUH0000LOol300000eYF001JEP04FUH00`00FUH0000[
Ool002]oo`80009JEP8000AJEP03001JEUYF00=JEP@001Qoo`<00003FUH005YF00AJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUH0000015YF00<005YF0000
0UYF0P006Goo100015YF00<005YFFUH00eYF0P00;7oo000[Ool2000015YF001JEP0015YF00<005YF
00000`007goo0`0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF
00@005YF001JEP8000EJEP80009JEP04001JEP00000EOol40002FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH00`00Oomoo`0[Ool002]oo`06001JEUYF001JEP000eYF10000eYF0`007Woo100000AJEP00
FUIJEP80009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP05001JEP00001JEP04
0002FUH00`00FUIJEP02FUH3000>Ool70006FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002]o
o`07001JEUYF001JEP00FUH00P000eYF00<005YFFUH015YF00<005YF00000P005Woo0`000eYF0`00
0UYF0P000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP04001JEP000002FUH00`00FUIJEP0H0004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH3000`Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP09
FUH90009Ool400000eYF0000000300000eYF00000002FUH20002FUH01000FUH000001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000bOol002aoo`04001JEP000002FUH3
0002FUH00`00FUIJEP0=FUH00`00FUIJEP02FUH?0005FUH00`00FUH000030002FUH200000eYF001J
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000dOol002eoo`<0009JEP03
001JEUYF00X000QJEP@000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000<000EJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD003Qoo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF001JEP030003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000mOol002moo`05001JEUYFFUH00004FUH00`00
FUIJEP0<FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP0015YF1`0015YF00<005YFFUH00UYF2@00
AWoo000`Ool200000eYF001JEP04FUH00`00FUIJEP0:FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001J
EP001UYF00D005YF000007oo00T004moo`00<Woo10000eYF00<005YFFUH02UYF00<005YF00000P00
15YF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP06001JEUYF001JEP000eYF1@00Fgoo000eOol:0007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=oo`00FUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001P00H7oo000hOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P00Igoo000lOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH000001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P00J7oo0013Ool80004
FUH00`00FUIJEP06FUH01000FUIJEUYF10002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Bgoo4@00
3goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YF00004P00Fgoo001]Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05FUH00`00FUIJ
EP04001GOol006moo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<005Eo
o`00LWoo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH005Aoo`00NGoo30001UYF00<005YF
FUH02UYF00<005YFFUH01P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH005Aoo`00QGoo5P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF20000eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo002COol200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90008Ool60003FUH01@00FUIJEUYF0000Dgoo002AOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9000GOol50002FUH00`00Oomoo`1AOol0091oo`80
00EJEP03001JEUYF009JEPH002=oo`H0059oo`00Sgoo00<005YF00001EYF00<005YF00000P009goo
0P000UYF00@005YF0000059oo`00Sgoo00@005YFFUH000=JEP<002Qoo`8000AJEP04001JEUYF001B
Ool008moo`05001JEUYF001JEP02000XOol300000eYF001JEP04FUH2001COol008moo`03001JEUYF
008002Aoo`H000AJEP03001JEUYF00=JEP8005=oo`00T7oo0P0000=JEP0000000P0067oo2@0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00T7oo0P000UYF00<005YFFUH0600015YF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000005Ioo`00T7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00F7oo
002@Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00003001KOol0095oo`800003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD005moo`00Tgoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00I7oo002GOol70004FUH00`00FUIJEP02FUH9001]
Ool009ioo`T007Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5918 .77847 m .60435 .72578 L .57399 .71684 L p .707 .577 .707 r
F P
0 g
s
.60435 .72578 m .5918 .77847 L .6229 .78404 L p .707 .577 .707 r
F P
0 g
s
.6229 .78404 m .63545 .73135 L .60435 .72578 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57399 .71684 L .57133 .7157 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57133 .7157 L .56054 .76543 L .707 .577 .707 r
F
.57399 .71684 m .56144 .76953 L .5918 .77847 L p F P
0 g
s
.58911 .77317 m .596 .73755 L .56811 .73052 L p .707 .577 .707 r
F P
0 g
s
.56811 .73052 m .56538 .72983 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.58911 .77317 m .56811 .73052 L .56745 .7336 L .707 .577 .707 r
F
.55849 .76545 m .56538 .72983 L .53848 .71963 L p F P
0 g
s
.56538 .72983 m .55849 .76545 L .56043 .76594 L p .707 .577 .707 r
F P
0 g
s
.5598 .76882 m .56144 .76953 L p .56054 .76543 L .707 .577 .707 r
F P
0 g
s
.56043 .76594 m .58911 .77317 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.56745 .7336 m .56538 .72983 L .56043 .76594 L .707 .577 .707 r
F
.53848 .71963 m .53158 .75524 L .55849 .76545 L p F P
0 g
s
.54735 .70541 m .5348 .75809 L .5598 .76882 L p .707 .577 .707 r
F P
0 g
s
.56054 .76543 m .54735 .70541 L .5598 .76882 L .707 .577 .707 r
F
.57133 .7157 m .54735 .70541 L p .56054 .76543 L F P
0 g
s
.63545 .73135 m .6229 .78404 L .65169 .7857 L p .707 .577 .707 r
F P
0 g
s
.65169 .7857 m .66425 .73301 L .63545 .73135 L p .707 .577 .707 r
F P
0 g
s
.596 .73755 m .58911 .77317 L .62044 .77764 L p .707 .577 .707 r
F P
0 g
s
.62044 .77764 m .62734 .74202 L .596 .73755 L p .707 .577 .707 r
F P
0 g
s
.62734 .74202 m .62044 .77764 L .64943 .77842 L p .707 .577 .707 r
F P
0 g
s
.64943 .77842 m .65633 .7428 L .62734 .74202 L p .707 .577 .707 r
F P
0 g
s
.53158 .75524 m .53848 .71963 L .51792 .70793 L p .707 .577 .707 r
F P
0 g
s
.5348 .75809 m .54735 .70541 L .52703 .6926 L p .707 .577 .707 r
F P
0 g
s
.66425 .73301 m .65169 .7857 L .67537 .78329 L p .707 .577 .707 r
F P
0 g
s
.67537 .78329 m .68792 .7306 L .66425 .73301 L p .707 .577 .707 r
F P
0 g
s
.65633 .7428 m .64943 .77842 L .67323 .77544 L p .707 .577 .707 r
F P
0 g
s
.67323 .77544 m .68013 .73983 L .65633 .7428 L p .707 .577 .707 r
F P
0 g
s
.51792 .70793 m .51102 .74354 L .53158 .75524 L p .707 .577 .707 r
F P
0 g
s
.52703 .6926 m .51448 .74529 L .5348 .75809 L p .707 .577 .707 r
F P
0 g
s
.51102 .74354 m .51792 .70793 L .50572 .69588 L p .707 .577 .707 r
F P
0 g
s
.51448 .74529 m .52703 .6926 L .51502 .67968 L p .707 .577 .707 r
F P
0 g
s
.60649 .88413 m .60367 .86553 L .57287 .86848 L p .707 .577 .707 r
F P
0 g
s
.60367 .86553 m .60649 .88413 L .638 .87898 L p .707 .577 .707 r
F P
0 g
s
.638 .87898 m .63518 .86038 L .60367 .86553 L p .707 .577 .707 r
F P
0 g
s
.68792 .7306 m .67537 .78329 L .69161 .77703 L p .707 .577 .707 r
F P
0 g
s
.69161 .77703 m .70416 .72435 L .68792 .7306 L p .707 .577 .707 r
F P
0 g
s
.63518 .86038 m .638 .87898 L .66712 .87213 L p .707 .577 .707 r
F P
0 g
s
.66712 .87213 m .66429 .85354 L .63518 .86038 L p .707 .577 .707 r
F P
0 g
s
.57287 .86848 m .57569 .88707 L .60649 .88413 L p .707 .577 .707 r
F P
0 g
s
.68013 .73983 m .67323 .77544 L .68951 .769 L p .707 .577 .707 r
F P
0 g
s
.68951 .769 m .69641 .73338 L .68013 .73983 L p .707 .577 .707 r
F P
0 g
s
.57569 .88707 m .57287 .86848 L .54578 .86893 L p .707 .577 .707 r
F P
0 g
s
.54578 .86893 m .5486 .88753 L .57569 .88707 L p .707 .577 .707 r
F P
0 g
s
.66429 .85354 m .66712 .87213 L .691 .86426 L p .707 .577 .707 r
F P
0 g
s
.691 .86426 m .68818 .84566 L .66429 .85354 L p .707 .577 .707 r
F P
0 g
s
.50572 .69588 m .49882 .7315 L .51102 .74354 L p .707 .577 .707 r
F P
0 g
s
.51502 .67968 m .50247 .73237 L .51448 .74529 L p .707 .577 .707 r
F P
0 g
s
.5486 .88753 m .54578 .86893 L .52505 .86685 L p .707 .577 .707 r
F P
0 g
s
.50247 .73237 m .51502 .67968 L .5125 .6679 L p .707 .577 .707 r
F P
0 g
s
.70416 .72435 m .69161 .77703 L .69882 .76756 L p .707 .577 .707 r
F P
0 g
s
.69882 .76756 m .71138 .71487 L .70416 .72435 L p .707 .577 .707 r
F P
0 g
s
.52505 .86685 m .52788 .88544 L .5486 .88753 L p .707 .577 .707 r
F P
0 g
s
.68818 .84566 m .691 .86426 L .70731 .85612 L p .707 .577 .707 r
F P
0 g
s
.70731 .85612 m .70449 .83752 L .68818 .84566 L p .707 .577 .707 r
F P
0 g
s
.69641 .73338 m .68951 .769 L .69668 .75971 L p .707 .577 .707 r
F P
0 g
s
.69668 .75971 m .70358 .72409 L .69641 .73338 L p .707 .577 .707 r
F P
0 g
s
.49882 .7315 m .50572 .69588 L .50308 .68466 L p .707 .577 .707 r
F P
0 g
s
.5125 .6679 m .49995 .72059 L .50247 .73237 L p .707 .577 .707 r
F P
0 g
s
.50308 .68466 m .49618 .72028 L .49882 .7315 L p .707 .577 .707 r
F P
0 g
s
.52788 .88544 m .52505 .86685 L .51273 .86243 L p .707 .577 .707 r
F P
0 g
s
.51273 .86243 m .51555 .88103 L .52788 .88544 L p .707 .577 .707 r
F P
0 g
s
.49995 .72059 m .5125 .6679 L .51972 .65842 L p .707 .577 .707 r
F P
0 g
s
.70358 .72409 m .69668 .75971 L .69404 .7485 L p .707 .577 .707 r
F P
0 g
s
.71138 .71487 m .69882 .76756 L .6963 .75578 L p .707 .577 .707 r
F P
0 g
s
.6963 .75578 m .70886 .70309 L .71138 .71487 L p .707 .577 .707 r
F P
0 g
s
.4905 .8214 m .48561 .31901 L .4416 .31676 L p .707 .577 .707 r
F P
0 g
s
.49618 .72028 m .50308 .68466 L .51025 .67538 L p .707 .577 .707 r
F P
0 g
s
.51972 .65842 m .50716 .71111 L .49995 .72059 L p .707 .577 .707 r
F P
0 g
s
.51025 .67538 m .50335 .71099 L .49618 .72028 L p .707 .577 .707 r
F P
0 g
s
.50716 .71111 m .51972 .65842 L .53596 .65217 L p .707 .577 .707 r
F P
0 g
s
.50335 .71099 m .51025 .67538 L .52653 .66893 L p .707 .577 .707 r
F P
0 g
s
.53596 .65217 m .5234 .70486 L .50716 .71111 L p .707 .577 .707 r
F P
0 g
s
.52653 .66893 m .51963 .70455 L .50335 .71099 L p .707 .577 .707 r
F P
0 g
s
.5234 .70486 m .53596 .65217 L .55963 .64976 L p .707 .577 .707 r
F P
0 g
s
.55963 .64976 m .54708 .70244 L .5234 .70486 L p .707 .577 .707 r
F P
0 g
s
.51963 .70455 m .52653 .66893 L .55033 .66595 L p .707 .577 .707 r
F P
0 g
s
.55033 .66595 m .54343 .70157 L .51963 .70455 L p .707 .577 .707 r
F P
0 g
s
.48561 .31901 m .4905 .8214 L .53544 .81991 L p .707 .577 .707 r
F P
0 g
s
.53544 .81991 m .53055 .31752 L .48561 .31901 L p .707 .577 .707 r
F P
0 g
s
.70449 .83752 m .70731 .85612 L .71445 .84853 L p .707 .577 .707 r
F P
0 g
s
.71445 .84853 m .71163 .82993 L .70449 .83752 L p .707 .577 .707 r
F P
0 g
s
.54708 .70244 m .55963 .64976 L .58843 .65142 L p .707 .577 .707 r
F P
0 g
s
.58843 .65142 m .57588 .7041 L .54708 .70244 L p .707 .577 .707 r
F P
0 g
s
.54343 .70157 m .55033 .66595 L .57932 .66674 L p .707 .577 .707 r
F P
0 g
s
.57932 .66674 m .57242 .70236 L .54343 .70157 L p .707 .577 .707 r
F P
0 g
s
.53055 .31752 m .53544 .81991 L .57692 .81483 L p .707 .577 .707 r
F P
0 g
s
.57588 .7041 m .58843 .65142 L .61953 .65699 L p .707 .577 .707 r
F P
0 g
s
.61953 .65699 m .60698 .70968 L .57588 .7041 L p .707 .577 .707 r
F P
0 g
s
.57242 .70236 m .57932 .66674 L .61066 .67121 L p .707 .577 .707 r
F P
0 g
s
.61066 .67121 m .60376 .70682 L .57242 .70236 L p .707 .577 .707 r
F P
0 g
s
.57692 .81483 m .57203 .31244 L .53055 .31752 L p .707 .577 .707 r
F P
0 g
s
.69404 .7485 m .70094 .71288 L .70358 .72409 L p .707 .577 .707 r
F P
0 g
s
.44649 .81915 m .4416 .31676 L .40284 .31099 L p .707 .577 .707 r
F P
0 g
s
.4416 .31676 m .44649 .81915 L .4905 .8214 L p .707 .577 .707 r
F P
0 g
s
.51555 .88103 m .51273 .86243 L .51 .85612 L p .707 .577 .707 r
F P
0 g
s
.57203 .31244 m .57692 .81483 L .61087 .80665 L p .707 .577 .707 r
F P
0 g
s
.66818 .68913 m .66128 .72475 L .63609 .71519 L p .707 .577 .707 r
F P
0 g
s
.63658 .71288 m .66818 .68913 L .63609 .71519 L .707 .577 .707 r
F
.63547 .71807 m .60698 .70968 L p .64576 .67014 L F P
0 g
s
.63438 .71454 m .64128 .67892 L .66818 .68913 L p .707 .577 .707 r
F P
0 g
s
.64989 .66593 m .63733 .71862 L .63547 .71807 L p .707 .577 .707 r
F P
0 g
s
.64576 .67014 m .64989 .66593 L .63547 .71807 L .707 .577 .707 r
F
.63609 .71519 m .63438 .71454 L p .63658 .71288 L F P
0 g
s
.60698 .70968 m .61953 .65699 L .64989 .66593 L p .707 .577 .707 r
F P
0 g
s
.64128 .67892 m .63438 .71454 L .60376 .70682 L p .707 .577 .707 r
F P
0 g
s
.60376 .70682 m .61066 .67121 L .64128 .67892 L p .707 .577 .707 r
F P
0 g
s
.61087 .80665 m .60598 .30426 L .57203 .31244 L p .707 .577 .707 r
F P
0 g
s
.24879 .69549 m .26134 .6428 L .23099 .63386 L p .707 .577 .707 r
F P
0 g
s
.26134 .6428 m .24879 .69549 L .27989 .70106 L p .707 .577 .707 r
F P
0 g
s
.27989 .70106 m .29244 .64837 L .26134 .6428 L p .707 .577 .707 r
F P
0 g
s
.51 .85612 m .51282 .87471 L .51555 .88103 L p .707 .577 .707 r
F P
0 g
s
.21843 .68655 m .23099 .63386 L .20434 .62243 L p .707 .577 .707 r
F P
0 g
s
.23099 .63386 m .21843 .68655 L .24879 .69549 L p .707 .577 .707 r
F P
0 g
s
.29244 .64837 m .27989 .70106 L .30869 .70272 L p .707 .577 .707 r
F P
0 g
s
.30869 .70272 m .32124 .65003 L .29244 .64837 L p .707 .577 .707 r
F P
0 g
s
.70094 .71288 m .69404 .7485 L .68184 .73645 L p .707 .577 .707 r
F P
0 g
s
.70886 .70309 m .6963 .75578 L .68429 .74285 L p .707 .577 .707 r
F P
0 g
s
.68184 .73645 m .68874 .70083 L .70094 .71288 L p .707 .577 .707 r
F P
0 g
s
.68429 .74285 m .69685 .69017 L .70886 .70309 L p .707 .577 .707 r
F P
0 g
s
.71163 .82993 m .71445 .84853 L .71172 .84221 L p .707 .577 .707 r
F P
0 g
s
.71172 .84221 m .7089 .82361 L .71163 .82993 L p .707 .577 .707 r
F P
0 g
s
.40773 .81338 m .40284 .31099 L .37311 .30227 L p .707 .577 .707 r
F P
0 g
s
.40284 .31099 m .40773 .81338 L .44649 .81915 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19179 .67511 m .20434 .62243 L .18402 .60962 L p .707 .577 .707 r
F P
0 g
s
.20434 .62243 m .19179 .67511 L .21843 .68655 L p .707 .577 .707 r
F P
0 g
s
.32124 .65003 m .30869 .70272 L .33236 .70031 L p .707 .577 .707 r
F P
0 g
s
.33236 .70031 m .34492 .64762 L .32124 .65003 L p .707 .577 .707 r
F P
0 g
s
.60598 .30426 m .61087 .80665 L .63398 .79618 L p .707 .577 .707 r
F P
0 g
s
.63398 .79618 m .62909 .29379 L .60598 .30426 L p .707 .577 .707 r
F P
0 g
s
.51282 .87471 m .51 .85612 L .51714 .84852 L p .707 .577 .707 r
F P
0 g
s
.26348 .77482 m .26066 .75622 L .22986 .75917 L p .707 .577 .707 r
F P
0 g
s
.26066 .75622 m .26348 .77482 L .29499 .76967 L p .707 .577 .707 r
F P
0 g
s
.29499 .76967 m .29217 .75108 L .26066 .75622 L p .707 .577 .707 r
F P
0 g
s
.68874 .70083 m .68184 .73645 L .66128 .72475 L p .707 .577 .707 r
F P
0 g
s
.66128 .72475 m .66818 .68913 L .68874 .70083 L p .707 .577 .707 r
F P
0 g
s
.69685 .69017 m .68429 .74285 L .66398 .73005 L p .707 .577 .707 r
F P
0 g
s
.66398 .73005 m .67653 .67736 L .69685 .69017 L p .707 .577 .707 r
F P
0 g
s
.51714 .84852 m .51996 .86712 L .51282 .87471 L p .707 .577 .707 r
F P
0 g
s
.29217 .75108 m .29499 .76967 L .32411 .76283 L p .707 .577 .707 r
F P
0 g
s
.32411 .76283 m .32128 .74423 L .29217 .75108 L p .707 .577 .707 r
F P
0 g
s
.22986 .75917 m .23268 .77777 L .26348 .77482 L p .707 .577 .707 r
F P
0 g
s
.18402 .60962 m .17147 .66231 L .19179 .67511 L p .707 .577 .707 r
F P
0 g
s
.17147 .66231 m .18402 .60962 L .17202 .5967 L p .707 .577 .707 r
F P
0 g
s
.23268 .77777 m .22986 .75917 L .20277 .75962 L p .707 .577 .707 r
F P
0 g
s
.34492 .64762 m .33236 .70031 L .3486 .69405 L p .707 .577 .707 r
F P
0 g
s
.3486 .69405 m .36116 .64137 L .34492 .64762 L p .707 .577 .707 r
F P
0 g
s
.7089 .82361 m .71172 .84221 L .6994 .83779 L p .707 .577 .707 r
F P
0 g
s
.6994 .83779 m .69657 .8192 L .7089 .82361 L p .707 .577 .707 r
F P
0 g
s
.2278 .77731 m .22237 .77595 L p .22774 .78575 L .707 .577 .707 r
F P
0 g
s
.21548 .81156 m .22237 .77595 L .19547 .76574 L p .707 .577 .707 r
F P
0 g
s
.22237 .77595 m .21548 .81156 L .2461 .81928 L p .707 .577 .707 r
F P
0 g
s
.20277 .75962 m .20559 .77822 L .2278 .77785 L p .707 .577 .707 r
F P
0 g
s
.2278 .77785 m .23268 .77777 L p .22782 .77482 L .707 .577 .707 r
F P
0 g
s
.22782 .77482 m .20277 .75962 L .2278 .77785 L .707 .577 .707 r
F
.2461 .81928 m .25299 .78366 L .2278 .77731 L p F P
0 g
s
.2461 .81928 m .2278 .77731 L .22774 .78575 L .707 .577 .707 r
F
.25299 .78366 m .2461 .81928 L .27743 .82375 L p F P
0 g
s
.27743 .82375 m .28433 .78813 L .25299 .78366 L p .707 .577 .707 r
F P
0 g
s
.378 .80466 m .37311 .30227 L .35534 .29145 L p .707 .577 .707 r
F P
0 g
s
.37311 .30227 m .378 .80466 L .40773 .81338 L p .707 .577 .707 r
F P
0 g
s
.32128 .74423 m .32411 .76283 L .34799 .75495 L p .707 .577 .707 r
F P
0 g
s
.34799 .75495 m .34517 .73635 L .32128 .74423 L p .707 .577 .707 r
F P
0 g
s
.28433 .78813 m .27743 .82375 L .30642 .82453 L p .707 .577 .707 r
F P
0 g
s
.30642 .82453 m .31332 .78892 L .28433 .78813 L p .707 .577 .707 r
F P
0 g
s
.67653 .67736 m .66398 .73005 L .63733 .71862 L p .707 .577 .707 r
F P
0 g
s
.63733 .71862 m .64989 .66593 L .67653 .67736 L p .707 .577 .707 r
F P
0 g
s
.19547 .76574 m .18857 .80135 L .21548 .81156 L p .707 .577 .707 r
F P
0 g
s
.18857 .80135 m .19547 .76574 L .17491 .75404 L p .707 .577 .707 r
F P
0 g
s
.20559 .77822 m .20277 .75962 L .18205 .75754 L p .707 .577 .707 r
F P
0 g
s
.17202 .5967 m .15946 .64939 L .17147 .66231 L p .707 .577 .707 r
F P
0 g
s
.51996 .86712 m .51714 .84852 L .53345 .84038 L p .707 .577 .707 r
F P
0 g
s
.31332 .78892 m .30642 .82453 L .33022 .82156 L p .707 .577 .707 r
F P
0 g
s
.33022 .82156 m .33712 .78594 L .31332 .78892 L p .707 .577 .707 r
F P
0 g
s
.18205 .75754 m .18487 .77614 L .20559 .77822 L p .707 .577 .707 r
F P
0 g
s
.53345 .84038 m .53627 .85898 L .51996 .86712 L p .707 .577 .707 r
F P
0 g
s
.34517 .73635 m .34799 .75495 L .3643 .74681 L p .707 .577 .707 r
F P
0 g
s
.3643 .74681 m .36148 .72822 L .34517 .73635 L p .707 .577 .707 r
F P
0 g
s
.62909 .29379 m .63398 .79618 L .64398 .78444 L p .707 .577 .707 r
F P
0 g
s
.64398 .78444 m .63909 .28205 L .62909 .29379 L p .707 .577 .707 r
F P
0 g
s
.15946 .64939 m .17202 .5967 L .16949 .58492 L p .707 .577 .707 r
F P
0 g
s
.36116 .64137 m .3486 .69405 L .35581 .68457 L p .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .36552 .64384 L p .36116 .64137 L .707 .577 .707 r
F P
0 g
s
.36632 .63458 m .36116 .64137 L p .36552 .64384 L .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .35329 .6728 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .36837 .63189 L .36632 .63458 L p .707 .577 .707 r
F P
0 g
s
.36837 .63189 m .36552 .64384 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .35581 .68457 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .36125 .26785 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .36165 .6156 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34179 .65905 m .36165 .6156 L .3622 .62601 L .707 .577 .707 r
F
.34129 .65987 m .34181 .65873 L .34179 .65905 L F
.34181 .65873 m .36165 .6156 L .34179 .65905 L F
.36165 .6156 m .36585 .62011 L p .3622 .62601 L F P
0 g
s
.36585 .62011 m .36837 .63189 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .36261 .6337 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .36585 .62011 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .34129 .65987 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36585 .62011 m .36261 .6337 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .35329 .6728 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.35367 .80582 m .36057 .77021 L .3534 .77949 L p .707 .577 .707 r
F P
0 g
s
.3534 .77949 m .3465 .81511 L .35367 .80582 L p .707 .577 .707 r
F P
0 g
s
.36057 .77021 m .35367 .80582 L .35103 .79461 L p .707 .577 .707 r
F P
0 g
s
.35103 .79461 m .35793 .75899 L .36057 .77021 L p .707 .577 .707 r
F P
0 g
s
.36148 .72822 m .3643 .74681 L .37144 .73922 L p .707 .577 .707 r
F P
0 g
s
.37144 .73922 m .36862 .72062 L .36148 .72822 L p .707 .577 .707 r
F P
0 g
s
.36589 .7143 m .36871 .7329 L .35639 .72849 L p .707 .577 .707 r
F P
0 g
s
.35639 .72849 m .35356 .70989 L .36589 .7143 L p .707 .577 .707 r
F P
0 g
s
.3465 .81511 m .3534 .77949 L .33712 .78594 L p .707 .577 .707 r
F P
0 g
s
.35793 .75899 m .35103 .79461 L .34186 .78555 L p .707 .577 .707 r
F P
0 g
s
.34186 .78555 m .33883 .78256 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.34217 .77845 m .35793 .75899 L .34186 .78555 L .707 .577 .707 r
F
.34573 .74694 m .35793 .75899 L p .34217 .77845 L F P
0 g
s
.33883 .78256 m .3429 .76157 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.3429 .76157 m .34573 .74694 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .35291 .45006 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35534 .29145 L p .35808 .61795 L .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .35125 .27959 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35658 .51956 m .35534 .29145 L .35488 .4873 L .707 .577 .707 r
F
.35808 .61795 m .35534 .29145 L .3571 .61452 L F
.36862 .72062 m .37144 .73922 L .36871 .7329 L p F P
0 g
s
.36871 .7329 m .36589 .7143 L .36862 .72062 L p .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .36023 .79384 L .378 .80466 L p .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .35291 .45006 L .36094 .29906 L .707 .577 .707 r
F
.35356 .70989 m .35639 .72849 L .33566 .7264 L p F P
0 g
s
.35755 .64032 m .35488 .4873 L .35614 .78198 L .707 .577 .707 r
F
.35614 .78198 m .36023 .79384 L p .35755 .64032 L F P
0 g
s
.35291 .45006 m .35614 .78198 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35755 .64032 m .35778 .6169 L .3571 .61452 L .707 .577 .707 r
F
.35894 .72025 m .35778 .6169 L .35755 .64032 L F
.35894 .72025 m .35808 .61795 L .35778 .6169 L F
.3571 .61452 m .35658 .51956 L .35488 .4873 L F
.35614 .78198 m .35355 .51579 L p .36034 .35898 L F P
0 g
s
.35355 .51579 m .35291 .45006 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.35945 .71432 m .35853 .61951 L p .35894 .72025 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35808 .61795 L .35894 .72025 L .707 .577 .707 r
F
.36023 .79384 m .35945 .71432 L p .35894 .72025 L F P
0 g
s
.36614 .77024 m .35614 .78198 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .36094 .29906 L .36135 .33587 L .707 .577 .707 r
F
.36034 .35898 m .36135 .33587 L .36614 .77024 L F
.36125 .26785 m .36146 .2893 L p .36094 .29906 L F P
0 g
s
.36146 .2893 m .36614 .77024 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35291 .45006 m .35125 .27959 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.34129 .65987 m .34188 .65736 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34188 .65736 m .35384 .60719 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.69657 .8192 m .6994 .83779 L .67867 .83571 L p .707 .577 .707 r
F P
0 g
s
.67867 .83571 m .67585 .81711 L .69657 .8192 L p .707 .577 .707 r
F P
0 g
s
.17491 .75404 m .16801 .78965 L .18857 .80135 L p .707 .577 .707 r
F P
0 g
s
.16801 .78965 m .17491 .75404 L .16271 .74199 L p .707 .577 .707 r
F P
0 g
s
.18487 .77614 m .18205 .75754 L .16972 .75312 L p .707 .577 .707 r
F P
0 g
s
.33712 .78594 m .33022 .82156 L .3465 .81511 L p .707 .577 .707 r
F P
0 g
s
.16972 .75312 m .17254 .77172 L .18487 .77614 L p .707 .577 .707 r
F P
0 g
s
.16949 .58492 m .15694 .63761 L .15946 .64939 L p .707 .577 .707 r
F P
0 g
s
.53627 .85898 m .53345 .84038 L .55733 .83251 L p .707 .577 .707 r
F P
0 g
s
.55733 .83251 m .56016 .8511 L .53627 .85898 L p .707 .577 .707 r
F P
0 g
s
.67585 .81711 m .67867 .83571 L .65158 .83616 L p .707 .577 .707 r
F P
0 g
s
.65158 .83616 m .64876 .81757 L .67585 .81711 L p .707 .577 .707 r
F P
0 g
s
.15694 .63761 m .16949 .58492 L .17671 .57544 L p .707 .577 .707 r
F P
0 g
s
.16271 .74199 m .15582 .77761 L .16801 .78965 L p .707 .577 .707 r
F P
0 g
s
.56016 .8511 m .55733 .83251 L .58645 .82566 L p .707 .577 .707 r
F P
0 g
s
.63909 .28205 m .64398 .78444 L .63989 .77258 L p .707 .577 .707 r
F P
0 g
s
.63989 .77258 m .635 .27019 L .63909 .28205 L p .707 .577 .707 r
F P
0 g
s
.58645 .82566 m .58927 .84426 L .56016 .8511 L p .707 .577 .707 r
F P
0 g
s
.15582 .77761 m .16271 .74199 L .16007 .73078 L p .707 .577 .707 r
F P
0 g
s
.17254 .77172 m .16972 .75312 L .16699 .74681 L p .707 .577 .707 r
F P
0 g
s
.64876 .81757 m .65158 .83616 L .62078 .83911 L p .707 .577 .707 r
F P
0 g
s
.62078 .83911 m .61796 .82051 L .64876 .81757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16699 .74681 m .16981 .76541 L .17254 .77172 L p .707 .577 .707 r
F P
0 g
s
.17671 .57544 m .16415 .62813 L .15694 .63761 L p .707 .577 .707 r
F P
0 g
s
.58927 .84426 m .58645 .82566 L .61796 .82051 L p .707 .577 .707 r
F P
0 g
s
.61796 .82051 m .62078 .83911 L .58927 .84426 L p .707 .577 .707 r
F P
0 g
s
.16007 .73078 m .15317 .76639 L .15582 .77761 L p .707 .577 .707 r
F P
0 g
s
.16415 .62813 m .17671 .57544 L .19295 .56919 L p .707 .577 .707 r
F P
0 g
s
.15317 .76639 m .16007 .73078 L .16724 .72149 L p .707 .577 .707 r
F P
0 g
s
.16981 .76541 m .16699 .74681 L .17413 .73921 L p .707 .577 .707 r
F P
0 g
s
.19295 .56919 m .18039 .62188 L .16415 .62813 L p .707 .577 .707 r
F P
0 g
s
.17413 .73921 m .17695 .75781 L .16981 .76541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.635 .27019 m .63989 .77258 L .62212 .76176 L p .707 .577 .707 r
F P
0 g
s
.62212 .76176 m .61723 .25937 L .635 .27019 L p .707 .577 .707 r
F P
0 g
s
.18039 .62188 m .19295 .56919 L .21662 .56677 L p .707 .577 .707 r
F P
0 g
s
.16724 .72149 m .16034 .75711 L .15317 .76639 L p .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .34129 .65987 L .32097 .64707 L p .707 .577 .707 r
F P
0 g
s
.32097 .64707 m .33352 .59438 L .35384 .60719 L p .707 .577 .707 r
F P
0 g
s
.36614 .77024 m .36125 .26785 L .38436 .25738 L p .707 .577 .707 r
F P
0 g
s
.16034 .75711 m .16724 .72149 L .18352 .71504 L p .707 .577 .707 r
F P
0 g
s
.17695 .75781 m .17413 .73921 L .19044 .73108 L p .707 .577 .707 r
F P
0 g
s
.21662 .56677 m .20407 .61946 L .18039 .62188 L p .707 .577 .707 r
F P
0 g
s
.20407 .61946 m .21662 .56677 L .24542 .56844 L p .707 .577 .707 r
F P
0 g
s
.33352 .59438 m .32097 .64707 L .29432 .63564 L p .707 .577 .707 r
F P
0 g
s
.29432 .63564 m .30688 .58295 L .33352 .59438 L p .707 .577 .707 r
F P
0 g
s
.19044 .73108 m .19326 .74967 L .17695 .75781 L p .707 .577 .707 r
F P
0 g
s
.33566 .7264 m .33284 .70781 L .35356 .70989 L p .707 .577 .707 r
F P
0 g
s
.18352 .71504 m .17662 .75066 L .16034 .75711 L p .707 .577 .707 r
F P
0 g
s
.23287 .62112 m .24542 .56844 L .27652 .57401 L p .707 .577 .707 r
F P
0 g
s
.24542 .56844 m .23287 .62112 L .20407 .61946 L p .707 .577 .707 r
F P
0 g
s
.30688 .58295 m .29432 .63564 L .26397 .6267 L p .707 .577 .707 r
F P
0 g
s
.26397 .6267 m .27652 .57401 L .30688 .58295 L p .707 .577 .707 r
F P
0 g
s
.61723 .25937 m .62212 .76176 L .59239 .75304 L p .707 .577 .707 r
F P
0 g
s
.59239 .75304 m .5875 .25065 L .61723 .25937 L p .707 .577 .707 r
F P
0 g
s
.27652 .57401 m .26397 .6267 L .23287 .62112 L p .707 .577 .707 r
F P
0 g
s
.34573 .74694 m .33883 .78256 L .31827 .77086 L p .707 .577 .707 r
F P
0 g
s
.31827 .77086 m .32517 .73524 L .34573 .74694 L p .707 .577 .707 r
F P
0 g
s
.19326 .74967 m .19044 .73108 L .21432 .7232 L p .707 .577 .707 r
F P
0 g
s
.17662 .75066 m .18352 .71504 L .20732 .71207 L p .707 .577 .707 r
F P
0 g
s
.21432 .7232 m .21715 .7418 L .19326 .74967 L p .707 .577 .707 r
F P
0 g
s
.33284 .70781 m .33566 .7264 L .30857 .72686 L p .707 .577 .707 r
F P
0 g
s
.30857 .72686 m .30575 .70826 L .33284 .70781 L p .707 .577 .707 r
F P
0 g
s
.38436 .25738 m .38925 .75977 L .36614 .77024 L p .707 .577 .707 r
F P
0 g
s
.38925 .75977 m .38436 .25738 L .41832 .24921 L p .707 .577 .707 r
F P
0 g
s
.20732 .71207 m .20042 .74768 L .17662 .75066 L p .707 .577 .707 r
F P
0 g
s
.729 .68643 m .74155 .63374 L .7112 .6248 L p .707 .577 .707 r
F P
0 g
s
.74155 .63374 m .729 .68643 L .7601 .692 L p .707 .577 .707 r
F P
0 g
s
.7601 .692 m .77265 .63931 L .74155 .63374 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .7112 .6248 L .70854 .62366 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .70854 .62366 L .69774 .67339 L .707 .577 .707 r
F
.7112 .6248 m .69864 .67749 L .729 .68643 L p F P
0 g
s
.72631 .68113 m .73321 .64551 L .70532 .63848 L p .707 .577 .707 r
F P
0 g
s
.70532 .63848 m .70259 .6378 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.72631 .68113 m .70532 .63848 L .70465 .64156 L .707 .577 .707 r
F
.69569 .67341 m .70259 .6378 L .67568 .62759 L p F P
0 g
s
.70259 .6378 m .69569 .67341 L .69763 .6739 L p .707 .577 .707 r
F P
0 g
s
.69701 .67679 m .69864 .67749 L p .69774 .67339 L .707 .577 .707 r
F P
0 g
s
.69763 .6739 m .72631 .68113 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.70465 .64156 m .70259 .6378 L .69763 .6739 L .707 .577 .707 r
F
.67568 .62759 m .66878 .6632 L .69569 .67341 L p F P
0 g
s
.68456 .61337 m .672 .66606 L .69701 .67679 L p .707 .577 .707 r
F P
0 g
s
.69774 .67339 m .68456 .61337 L .69701 .67679 L .707 .577 .707 r
F
.70854 .62366 m .68456 .61337 L p .69774 .67339 L F P
0 g
s
.77265 .63931 m .7601 .692 L .7889 .69366 L p .707 .577 .707 r
F P
0 g
s
.7889 .69366 m .80145 .64098 L .77265 .63931 L p .707 .577 .707 r
F P
0 g
s
.32517 .73524 m .31827 .77086 L .29137 .76065 L p .707 .577 .707 r
F P
0 g
s
.30303 .72684 m .32517 .73524 L p .30232 .75242 L .707 .577 .707 r
F P
0 g
s
.30575 .70826 m .30857 .72686 L .30302 .72739 L p .707 .577 .707 r
F P
0 g
s
.30302 .72739 m .27777 .7298 L p .3035 .70999 L .707 .577 .707 r
F P
0 g
s
.3035 .70999 m .30575 .70826 L .30302 .72739 L .707 .577 .707 r
F
.29137 .76065 m .29827 .72504 L .30303 .72684 L p F P
0 g
s
.29137 .76065 m .30303 .72684 L .30232 .75242 L .707 .577 .707 r
F
.21715 .7418 m .21432 .7232 L .24344 .71635 L p F P
0 g
s
.20042 .74768 m .20732 .71207 L .23631 .71285 L p .707 .577 .707 r
F P
0 g
s
.73321 .64551 m .72631 .68113 L .75765 .6856 L p .707 .577 .707 r
F P
0 g
s
.75765 .6856 m .76455 .64998 L .73321 .64551 L p .707 .577 .707 r
F P
0 g
s
.24344 .71635 m .24626 .73495 L .21715 .7418 L p .707 .577 .707 r
F P
0 g
s
.76455 .64998 m .75765 .6856 L .78663 .68638 L p .707 .577 .707 r
F P
0 g
s
.78663 .68638 m .79353 .65076 L .76455 .64998 L p .707 .577 .707 r
F P
0 g
s
.27777 .7298 m .27495 .7112 L .30575 .70826 L p .707 .577 .707 r
F P
0 g
s
.5875 .25065 m .59239 .75304 L .55363 .74728 L p .707 .577 .707 r
F P
0 g
s
.55363 .74728 m .54874 .24489 L .5875 .25065 L p .707 .577 .707 r
F P
0 g
s
.24626 .73495 m .24344 .71635 L .27495 .7112 L p .707 .577 .707 r
F P
0 g
s
.66878 .6632 m .67568 .62759 L .65512 .61589 L p .707 .577 .707 r
F P
0 g
s
.672 .66606 m .68456 .61337 L .66424 .60056 L p .707 .577 .707 r
F P
0 g
s
.80145 .64098 m .7889 .69366 L .81258 .69125 L p .707 .577 .707 r
F P
0 g
s
.81258 .69125 m .82513 .63856 L .80145 .64098 L p .707 .577 .707 r
F P
0 g
s
.23631 .71285 m .22941 .74847 L .20042 .74768 L p .707 .577 .707 r
F P
0 g
s
.29827 .72504 m .29137 .76065 L .26075 .75294 L p .707 .577 .707 r
F P
0 g
s
.27495 .7112 m .27777 .7298 L .24626 .73495 L p .707 .577 .707 r
F P
0 g
s
.26075 .75294 m .26765 .71732 L .29827 .72504 L p .707 .577 .707 r
F P
0 g
s
.22941 .74847 m .23631 .71285 L .26765 .71732 L p .707 .577 .707 r
F P
0 g
s
.4232 .7516 m .41832 .24921 L .45979 .24413 L p .707 .577 .707 r
F P
0 g
s
.41832 .24921 m .4232 .7516 L .38925 .75977 L p .707 .577 .707 r
F P
0 g
s
.26765 .71732 m .26075 .75294 L .22941 .74847 L p .707 .577 .707 r
F P
0 g
s
.79353 .65076 m .78663 .68638 L .81043 .6834 L p .707 .577 .707 r
F P
0 g
s
.81043 .6834 m .81733 .64779 L .79353 .65076 L p .707 .577 .707 r
F P
0 g
s
.54874 .24489 m .55363 .74728 L .50963 .74503 L p .707 .577 .707 r
F P
0 g
s
.50963 .74503 m .50474 .24264 L .54874 .24489 L p .707 .577 .707 r
F P
0 g
s
.65512 .61589 m .64823 .6515 L .66878 .6632 L p .707 .577 .707 r
F P
0 g
s
.66424 .60056 m .65168 .65325 L .672 .66606 L p .707 .577 .707 r
F P
0 g
s
.64823 .6515 m .65512 .61589 L .64293 .60384 L p .707 .577 .707 r
F P
0 g
s
.65168 .65325 m .66424 .60056 L .65223 .58764 L p .707 .577 .707 r
F P
0 g
s
.7437 .79209 m .74088 .77349 L .71007 .77644 L p .707 .577 .707 r
F P
0 g
s
.74088 .77349 m .7437 .79209 L .7752 .78694 L p .707 .577 .707 r
F P
0 g
s
.7752 .78694 m .77238 .76835 L .74088 .77349 L p .707 .577 .707 r
F P
0 g
s
.82513 .63856 m .81258 .69125 L .82882 .685 L p .707 .577 .707 r
F P
0 g
s
.82882 .685 m .84137 .63231 L .82513 .63856 L p .707 .577 .707 r
F P
0 g
s
.77238 .76835 m .7752 .78694 L .80432 .7801 L p .707 .577 .707 r
F P
0 g
s
.80432 .7801 m .8015 .7615 L .77238 .76835 L p .707 .577 .707 r
F P
0 g
s
.46468 .74652 m .45979 .24413 L .50474 .24264 L p .707 .577 .707 r
F P
0 g
s
.45979 .24413 m .46468 .74652 L .4232 .7516 L p .707 .577 .707 r
F P
0 g
s
.71007 .77644 m .71289 .79504 L .7437 .79209 L p .707 .577 .707 r
F P
0 g
s
.50474 .24264 m .50963 .74503 L .46468 .74652 L p .707 .577 .707 r
F P
0 g
s
.81733 .64779 m .81043 .6834 L .82672 .67696 L p .707 .577 .707 r
F P
0 g
s
.82672 .67696 m .83361 .64134 L .81733 .64779 L p .707 .577 .707 r
F P
0 g
s
.71289 .79504 m .71007 .77644 L .68298 .77689 L p .707 .577 .707 r
F P
0 g
s
.68298 .77689 m .6858 .79549 L .71289 .79504 L p .707 .577 .707 r
F P
0 g
s
.8015 .7615 m .80432 .7801 L .8282 .77222 L p .707 .577 .707 r
F P
0 g
s
.8282 .77222 m .82538 .75362 L .8015 .7615 L p .707 .577 .707 r
F P
0 g
s
.64293 .60384 m .63603 .63946 L .64823 .6515 L p .707 .577 .707 r
F P
0 g
s
.65223 .58764 m .63968 .64033 L .65168 .65325 L p .707 .577 .707 r
F P
0 g
s
.6858 .79549 m .68298 .77689 L .66226 .77481 L p .707 .577 .707 r
F P
0 g
s
.63968 .64033 m .65223 .58764 L .64971 .57586 L p .707 .577 .707 r
F P
0 g
s
.84137 .63231 m .82882 .685 L .83603 .67552 L p .707 .577 .707 r
F P
0 g
s
.83603 .67552 m .84858 .62283 L .84137 .63231 L p .707 .577 .707 r
F P
0 g
s
.66226 .77481 m .66508 .79341 L .6858 .79549 L p .707 .577 .707 r
F P
0 g
s
.82538 .75362 m .8282 .77222 L .84451 .76408 L p .707 .577 .707 r
F P
0 g
s
.84451 .76408 m .84169 .74549 L .82538 .75362 L p .707 .577 .707 r
F P
0 g
s
.83361 .64134 m .82672 .67696 L .83389 .66767 L p .707 .577 .707 r
F P
0 g
s
.83389 .66767 m .84078 .63206 L .83361 .64134 L p .707 .577 .707 r
F P
0 g
s
.63603 .63946 m .64293 .60384 L .64028 .59262 L p .707 .577 .707 r
F P
0 g
s
.64971 .57586 m .63715 .62855 L .63968 .64033 L p .707 .577 .707 r
F P
0 g
s
.64028 .59262 m .63339 .62824 L .63603 .63946 L p .707 .577 .707 r
F P
0 g
s
.66508 .79341 m .66226 .77481 L .64993 .77039 L p .707 .577 .707 r
F P
0 g
s
.64993 .77039 m .65275 .78899 L .66508 .79341 L p .707 .577 .707 r
F P
0 g
s
.63715 .62855 m .64971 .57586 L .65692 .56638 L p .707 .577 .707 r
F P
0 g
s
.84078 .63206 m .83389 .66767 L .83124 .65646 L p .707 .577 .707 r
F P
0 g
s
.84858 .62283 m .83603 .67552 L .83351 .66374 L p .707 .577 .707 r
F P
0 g
s
.83351 .66374 m .84606 .61105 L .84858 .62283 L p .707 .577 .707 r
F P
0 g
s
.84169 .74549 m .84451 .76408 L .85166 .75649 L p .707 .577 .707 r
F P
0 g
s
.85166 .75649 m .84883 .73789 L .84169 .74549 L p .707 .577 .707 r
F P
0 g
s
.83124 .65646 m .83814 .62084 L .84078 .63206 L p .707 .577 .707 r
F P
0 g
s
.63339 .62824 m .64028 .59262 L .64745 .58334 L p .707 .577 .707 r
F P
0 g
s
.65692 .56638 m .64437 .61907 L .63715 .62855 L p .707 .577 .707 r
F P
0 g
s
.64745 .58334 m .64056 .61896 L .63339 .62824 L p .707 .577 .707 r
F P
0 g
s
.65275 .78899 m .64993 .77039 L .6472 .76408 L p .707 .577 .707 r
F P
0 g
s
.38599 .60345 m .39854 .55076 L .36819 .54182 L p .707 .577 .707 r
F P
0 g
s
.39854 .55076 m .38599 .60345 L .41709 .60902 L p .707 .577 .707 r
F P
0 g
s
.41709 .60902 m .42964 .55633 L .39854 .55076 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6472 .76408 m .65002 .78268 L .65275 .78899 L p .707 .577 .707 r
F P
0 g
s
.35563 .59451 m .36819 .54182 L .34155 .53039 L p .707 .577 .707 r
F P
0 g
s
.36819 .54182 m .35563 .59451 L .38599 .60345 L p .707 .577 .707 r
F P
0 g
s
.42964 .55633 m .41709 .60902 L .44589 .61068 L p .707 .577 .707 r
F P
0 g
s
.44589 .61068 m .45844 .55799 L .42964 .55633 L p .707 .577 .707 r
F P
0 g
s
.64437 .61907 m .65692 .56638 L .67316 .56013 L p .707 .577 .707 r
F P
0 g
s
.83814 .62084 m .83124 .65646 L .81905 .64441 L p .707 .577 .707 r
F P
0 g
s
.84606 .61105 m .83351 .66374 L .8215 .65081 L p .707 .577 .707 r
F P
0 g
s
.81905 .64441 m .82594 .60879 L .83814 .62084 L p .707 .577 .707 r
F P
0 g
s
.8215 .65081 m .83405 .59813 L .84606 .61105 L p .707 .577 .707 r
F P
0 g
s
.84883 .73789 m .85166 .75649 L .84893 .75017 L p .707 .577 .707 r
F P
0 g
s
.84893 .75017 m .84611 .73157 L .84883 .73789 L p .707 .577 .707 r
F P
0 g
s
.64056 .61896 m .64745 .58334 L .66374 .57689 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32899 .58308 m .34155 .53039 L .32123 .51758 L p .707 .577 .707 r
F P
0 g
s
.34155 .53039 m .32899 .58308 L .35563 .59451 L p .707 .577 .707 r
F P
0 g
s
.45844 .55799 m .44589 .61068 L .46957 .60827 L p .707 .577 .707 r
F P
0 g
s
.46957 .60827 m .48212 .55558 L .45844 .55799 L p .707 .577 .707 r
F P
0 g
s
.67316 .56013 m .66061 .61282 L .64437 .61907 L p .707 .577 .707 r
F P
0 g
s
.66374 .57689 m .65684 .61251 L .64056 .61896 L p .707 .577 .707 r
F P
0 g
s
.65002 .78268 m .6472 .76408 L .65434 .75648 L p .707 .577 .707 r
F P
0 g
s
.40069 .68278 m .39787 .66419 L .36706 .66713 L p .707 .577 .707 r
F P
0 g
s
.39787 .66419 m .40069 .68278 L .43219 .67764 L p .707 .577 .707 r
F P
0 g
s
.43219 .67764 m .42937 .65904 L .39787 .66419 L p .707 .577 .707 r
F P
0 g
s
.66061 .61282 m .67316 .56013 L .69684 .55772 L p .707 .577 .707 r
F P
0 g
s
.82594 .60879 m .81905 .64441 L .79849 .63271 L p .707 .577 .707 r
F P
0 g
s
.79849 .63271 m .80539 .59709 L .82594 .60879 L p .707 .577 .707 r
F P
0 g
s
.83405 .59813 m .8215 .65081 L .80118 .63801 L p .707 .577 .707 r
F P
0 g
s
.80118 .63801 m .81373 .58532 L .83405 .59813 L p .707 .577 .707 r
F P
0 g
s
.65434 .75648 m .65717 .77508 L .65002 .78268 L p .707 .577 .707 r
F P
0 g
s
.42937 .65904 m .43219 .67764 L .46131 .67079 L p .707 .577 .707 r
F P
0 g
s
.46131 .67079 m .45849 .65219 L .42937 .65904 L p .707 .577 .707 r
F P
0 g
s
.36706 .66713 m .36988 .68573 L .40069 .68278 L p .707 .577 .707 r
F P
0 g
s
.32123 .51758 m .30867 .57027 L .32899 .58308 L p .707 .577 .707 r
F P
0 g
s
.30867 .57027 m .32123 .51758 L .30922 .50466 L p .707 .577 .707 r
F P
0 g
s
.36988 .68573 m .36706 .66713 L .33997 .66758 L p .707 .577 .707 r
F P
0 g
s
.48212 .55558 m .46957 .60827 L .48581 .60202 L p .707 .577 .707 r
F P
0 g
s
.48581 .60202 m .49836 .54933 L .48212 .55558 L p .707 .577 .707 r
F P
0 g
s
.84611 .73157 m .84893 .75017 L .8366 .74576 L p .707 .577 .707 r
F P
0 g
s
.8366 .74576 m .83378 .72716 L .84611 .73157 L p .707 .577 .707 r
F P
0 g
s
.69684 .55772 m .68428 .6104 L .66061 .61282 L p .707 .577 .707 r
F P
0 g
s
.65684 .61251 m .66374 .57689 L .68754 .57392 L p .707 .577 .707 r
F P
0 g
s
.365 .68527 m .35958 .68391 L p .36495 .69372 L .707 .577 .707 r
F P
0 g
s
.35268 .71952 m .35958 .68391 L .33267 .6737 L p .707 .577 .707 r
F P
0 g
s
.35958 .68391 m .35268 .71952 L .3833 .72724 L p .707 .577 .707 r
F P
0 g
s
.33997 .66758 m .34279 .68618 L .365 .68581 L p .707 .577 .707 r
F P
0 g
s
.365 .68581 m .36988 .68573 L p .36502 .68278 L .707 .577 .707 r
F P
0 g
s
.36502 .68278 m .33997 .66758 L .365 .68581 L .707 .577 .707 r
F
.3833 .72724 m .3902 .69162 L .365 .68527 L p F P
0 g
s
.3833 .72724 m .365 .68527 L .36495 .69372 L .707 .577 .707 r
F
.3902 .69162 m .3833 .72724 L .41464 .73171 L p F P
0 g
s
.41464 .73171 m .42154 .69609 L .3902 .69162 L p .707 .577 .707 r
F P
0 g
s
.45849 .65219 m .46131 .67079 L .48519 .66291 L p .707 .577 .707 r
F P
0 g
s
.48519 .66291 m .48237 .64431 L .45849 .65219 L p .707 .577 .707 r
F P
0 g
s
.42154 .69609 m .41464 .73171 L .44362 .73249 L p .707 .577 .707 r
F P
0 g
s
.44362 .73249 m .45052 .69688 L .42154 .69609 L p .707 .577 .707 r
F P
0 g
s
.68428 .6104 m .69684 .55772 L .72564 .55938 L p .707 .577 .707 r
F P
0 g
s
.68754 .57392 m .68064 .60953 L .65684 .61251 L p .707 .577 .707 r
F P
0 g
s
.80539 .59709 m .79849 .63271 L .77329 .62315 L p .707 .577 .707 r
F P
0 g
s
.77267 .62603 m .74418 .61764 L p .78296 .5781 L .707 .577 .707 r
F P
0 g
s
.77329 .62315 m .77158 .6225 L p .77379 .62085 L .707 .577 .707 r
F P
0 g
s
.77379 .62085 m .80539 .59709 L .77329 .62315 L .707 .577 .707 r
F
.77158 .6225 m .77848 .58689 L .80539 .59709 L p F P
0 g
s
.78709 .57389 m .77454 .62658 L .77267 .62603 L p .707 .577 .707 r
F P
0 g
s
.78296 .5781 m .78709 .57389 L .77267 .62603 L .707 .577 .707 r
F
.81373 .58532 m .80118 .63801 L .77454 .62658 L p F P
0 g
s
.77454 .62658 m .78709 .57389 L .81373 .58532 L p .707 .577 .707 r
F P
0 g
s
.33267 .6737 m .32577 .70932 L .35268 .71952 L p .707 .577 .707 r
F P
0 g
s
.32577 .70932 m .33267 .6737 L .31211 .662 L p .707 .577 .707 r
F P
0 g
s
.34279 .68618 m .33997 .66758 L .31925 .6655 L p .707 .577 .707 r
F P
0 g
s
.30922 .50466 m .29667 .55735 L .30867 .57027 L p .707 .577 .707 r
F P
0 g
s
.65717 .77508 m .65434 .75648 L .67066 .74835 L p .707 .577 .707 r
F P
0 g
s
.45052 .69688 m .44362 .73249 L .46742 .72952 L p .707 .577 .707 r
F P
0 g
s
.46742 .72952 m .47432 .6939 L .45052 .69688 L p .707 .577 .707 r
F P
0 g
s
.31925 .6655 m .32207 .6841 L .34279 .68618 L p .707 .577 .707 r
F P
0 g
s
.72564 .55938 m .71308 .61206 L .68428 .6104 L p .707 .577 .707 r
F P
0 g
s
.68064 .60953 m .68754 .57392 L .71652 .5747 L p .707 .577 .707 r
F P
0 g
s
.67066 .74835 m .67348 .76694 L .65717 .77508 L p .707 .577 .707 r
F P
0 g
s
.48237 .64431 m .48519 .66291 L .5015 .65478 L p .707 .577 .707 r
F P
0 g
s
.5015 .65478 m .49868 .63618 L .48237 .64431 L p .707 .577 .707 r
F P
0 g
s
.29667 .55735 m .30922 .50466 L .3067 .49288 L p .707 .577 .707 r
F P
0 g
s
.49836 .54933 m .48581 .60202 L .49302 .59254 L p .707 .577 .707 r
F P
0 g
s
.49302 .59254 m .50557 .53985 L .49836 .54933 L p .707 .577 .707 r
F P
0 g
s
.71308 .61206 m .72564 .55938 L .75674 .56495 L p .707 .577 .707 r
F P
0 g
s
.74418 .61764 m .75674 .56495 L .78709 .57389 L p .707 .577 .707 r
F P
0 g
s
.83378 .72716 m .8366 .74576 L .81588 .74367 L p .707 .577 .707 r
F P
0 g
s
.81588 .74367 m .81306 .72508 L .83378 .72716 L p .707 .577 .707 r
F P
0 g
s
.75674 .56495 m .74418 .61764 L .71308 .61206 L p .707 .577 .707 r
F P
0 g
s
.31211 .662 m .30522 .69762 L .32577 .70932 L p .707 .577 .707 r
F P
0 g
s
.71652 .5747 m .70962 .61032 L .68064 .60953 L p .707 .577 .707 r
F P
0 g
s
.77848 .58689 m .77158 .6225 L .74096 .61479 L p .707 .577 .707 r
F P
0 g
s
.74096 .61479 m .74786 .57917 L .77848 .58689 L p .707 .577 .707 r
F P
0 g
s
.70962 .61032 m .71652 .5747 L .74786 .57917 L p .707 .577 .707 r
F P
0 g
s
.74786 .57917 m .74096 .61479 L .70962 .61032 L p .707 .577 .707 r
F P
0 g
s
.30522 .69762 m .31211 .662 L .29992 .64995 L p .707 .577 .707 r
F P
0 g
s
.32207 .6841 m .31925 .6655 L .30692 .66109 L p .707 .577 .707 r
F P
0 g
s
.47432 .6939 m .46742 .72952 L .48371 .72307 L p .707 .577 .707 r
F P
0 g
s
.48371 .72307 m .4906 .68745 L .47432 .6939 L p .707 .577 .707 r
F P
0 g
s
.30692 .66109 m .30974 .67968 L .32207 .6841 L p .707 .577 .707 r
F P
0 g
s
.3067 .49288 m .29414 .54557 L .29667 .55735 L p .707 .577 .707 r
F P
0 g
s
.67348 .76694 m .67066 .74835 L .69454 .74047 L p .707 .577 .707 r
F P
0 g
s
.69454 .74047 m .69736 .75907 L .67348 .76694 L p .707 .577 .707 r
F P
0 g
s
.49868 .63618 m .5015 .65478 L .50865 .64718 L p .707 .577 .707 r
F P
0 g
s
.50865 .64718 m .50582 .62858 L .49868 .63618 L p .707 .577 .707 r
F P
0 g
s
.81306 .72508 m .81588 .74367 L .78879 .74413 L p .707 .577 .707 r
F P
0 g
s
.78879 .74413 m .78597 .72553 L .81306 .72508 L p .707 .577 .707 r
F P
0 g
s
.29414 .54557 m .3067 .49288 L .31391 .4834 L p .707 .577 .707 r
F P
0 g
s
.29992 .64995 m .29302 .68557 L .30522 .69762 L p .707 .577 .707 r
F P
0 g
s
.50557 .53985 m .49302 .59254 L .4905 .58076 L p .707 .577 .707 r
F P
0 g
s
.4905 .58076 m .50305 .52807 L .50557 .53985 L p .707 .577 .707 r
F P
0 g
s
.69736 .75907 m .69454 .74047 L .72366 .73362 L p .707 .577 .707 r
F P
0 g
s
.4906 .68745 m .48371 .72307 L .49088 .71379 L p .707 .577 .707 r
F P
0 g
s
.49088 .71379 m .49777 .67817 L .4906 .68745 L p .707 .577 .707 r
F P
0 g
s
.72366 .73362 m .72648 .75222 L .69736 .75907 L p .707 .577 .707 r
F P
0 g
s
.29302 .68557 m .29992 .64995 L .29727 .63874 L p .707 .577 .707 r
F P
0 g
s
.30974 .67968 m .30692 .66109 L .30419 .65477 L p .707 .577 .707 r
F P
0 g
s
.78597 .72553 m .78879 .74413 L .75798 .74707 L p .707 .577 .707 r
F P
0 g
s
.75798 .74707 m .75516 .72847 L .78597 .72553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30419 .65477 m .30701 .67337 L .30974 .67968 L p .707 .577 .707 r
F P
0 g
s
.31391 .4834 m .30136 .53609 L .29414 .54557 L p .707 .577 .707 r
F P
0 g
s
.72648 .75222 m .72366 .73362 L .75516 .72847 L p .707 .577 .707 r
F P
0 g
s
.75516 .72847 m .75798 .74707 L .72648 .75222 L p .707 .577 .707 r
F P
0 g
s
.50582 .62858 m .50865 .64718 L .50592 .64086 L p .707 .577 .707 r
F P
0 g
s
.50592 .64086 m .5031 .62227 L .50582 .62858 L p .707 .577 .707 r
F P
0 g
s
.29727 .63874 m .29038 .67435 L .29302 .68557 L p .707 .577 .707 r
F P
0 g
s
.30136 .53609 m .31391 .4834 L .33015 .47715 L p .707 .577 .707 r
F P
0 g
s
.50305 .52807 m .4905 .58076 L .47849 .56783 L p .707 .577 .707 r
F P
0 g
s
.47849 .56783 m .49104 .51515 L .50305 .52807 L p .707 .577 .707 r
F P
0 g
s
.49777 .67817 m .49088 .71379 L .48823 .70257 L p .707 .577 .707 r
F P
0 g
s
.48823 .70257 m .49513 .66695 L .49777 .67817 L p .707 .577 .707 r
F P
0 g
s
.29038 .67435 m .29727 .63874 L .30444 .62945 L p .707 .577 .707 r
F P
0 g
s
.30701 .67337 m .30419 .65477 L .31133 .64717 L p .707 .577 .707 r
F P
0 g
s
.33015 .47715 m .3176 .52984 L .30136 .53609 L p .707 .577 .707 r
F P
0 g
s
.31133 .64717 m .31415 .66577 L .30701 .67337 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3176 .52984 m .33015 .47715 L .35383 .47474 L p .707 .577 .707 r
F P
0 g
s
.5031 .62227 m .50592 .64086 L .49359 .63645 L p .707 .577 .707 r
F P
0 g
s
.49359 .63645 m .49077 .61785 L .5031 .62227 L p .707 .577 .707 r
F P
0 g
s
.30444 .62945 m .29755 .66507 L .29038 .67435 L p .707 .577 .707 r
F P
0 g
s
.49104 .51515 m .47849 .56783 L .45817 .55503 L p .707 .577 .707 r
F P
0 g
s
.45817 .55503 m .47072 .50234 L .49104 .51515 L p .707 .577 .707 r
F P
0 g
s
.49513 .66695 m .48823 .70257 L .47604 .69052 L p .707 .577 .707 r
F P
0 g
s
.47604 .69052 m .48293 .65491 L .49513 .66695 L p .707 .577 .707 r
F P
0 g
s
.29755 .66507 m .30444 .62945 L .32073 .623 L p .707 .577 .707 r
F P
0 g
s
.31415 .66577 m .31133 .64717 L .32764 .63904 L p .707 .577 .707 r
F P
0 g
s
.35383 .47474 m .34127 .52742 L .3176 .52984 L p .707 .577 .707 r
F P
0 g
s
.34127 .52742 m .35383 .47474 L .38263 .4764 L p .707 .577 .707 r
F P
0 g
s
.47072 .50234 m .45817 .55503 L .43153 .5436 L p .707 .577 .707 r
F P
0 g
s
.43153 .5436 m .44408 .49091 L .47072 .50234 L p .707 .577 .707 r
F P
0 g
s
.32764 .63904 m .33047 .65764 L .31415 .66577 L p .707 .577 .707 r
F P
0 g
s
.49077 .61785 m .49359 .63645 L .47287 .63437 L p .707 .577 .707 r
F P
0 g
s
.47287 .63437 m .47004 .61577 L .49077 .61785 L p .707 .577 .707 r
F P
0 g
s
.32073 .623 m .31383 .65862 L .29755 .66507 L p .707 .577 .707 r
F P
0 g
s
.37007 .52908 m .38263 .4764 L .41372 .48197 L p .707 .577 .707 r
F P
0 g
s
.38263 .4764 m .37007 .52908 L .34127 .52742 L p .707 .577 .707 r
F P
0 g
s
.44408 .49091 m .43153 .5436 L .40117 .53466 L p .707 .577 .707 r
F P
0 g
s
.40117 .53466 m .41372 .48197 L .44408 .49091 L p .707 .577 .707 r
F P
0 g
s
.41372 .48197 m .40117 .53466 L .37007 .52908 L p .707 .577 .707 r
F P
0 g
s
.48293 .65491 m .47604 .69052 L .45548 .67882 L p .707 .577 .707 r
F P
0 g
s
.45548 .67882 m .46238 .64321 L .48293 .65491 L p .707 .577 .707 r
F P
0 g
s
.33047 .65764 m .32764 .63904 L .35153 .63116 L p .707 .577 .707 r
F P
0 g
s
.31383 .65862 m .32073 .623 L .34453 .62003 L p .707 .577 .707 r
F P
0 g
s
.35153 .63116 m .35435 .64976 L .33047 .65764 L p .707 .577 .707 r
F P
0 g
s
.47004 .61577 m .47287 .63437 L .44578 .63482 L p .707 .577 .707 r
F P
0 g
s
.44578 .63482 m .44295 .61622 L .47004 .61577 L p .707 .577 .707 r
F P
0 g
s
.34453 .62003 m .33763 .65564 L .31383 .65862 L p .707 .577 .707 r
F P
0 g
s
.46238 .64321 m .45548 .67882 L .42857 .66861 L p .707 .577 .707 r
F P
0 g
s
.44024 .63481 m .46238 .64321 L p .43953 .66038 L .707 .577 .707 r
F P
0 g
s
.44295 .61622 m .44578 .63482 L .44022 .63535 L p .707 .577 .707 r
F P
0 g
s
.44022 .63535 m .41497 .63776 L p .44071 .61795 L .707 .577 .707 r
F P
0 g
s
.44071 .61795 m .44295 .61622 L .44022 .63535 L .707 .577 .707 r
F
.42857 .66861 m .43547 .633 L .44024 .63481 L p F P
0 g
s
.42857 .66861 m .44024 .63481 L .43953 .66038 L .707 .577 .707 r
F
.35435 .64976 m .35153 .63116 L .38065 .62431 L p F P
0 g
s
.33763 .65564 m .34453 .62003 L .37351 .62081 L p .707 .577 .707 r
F P
0 g
s
.38065 .62431 m .38347 .64291 L .35435 .64976 L p .707 .577 .707 r
F P
0 g
s
.41497 .63776 m .41215 .61916 L .44295 .61622 L p .707 .577 .707 r
F P
0 g
s
.38347 .64291 m .38065 .62431 L .41215 .61916 L p .707 .577 .707 r
F P
0 g
s
.37351 .62081 m .36661 .65643 L .33763 .65564 L p .707 .577 .707 r
F P
0 g
s
.43547 .633 m .42857 .66861 L .39795 .6609 L p .707 .577 .707 r
F P
0 g
s
.41215 .61916 m .41497 .63776 L .38347 .64291 L p .707 .577 .707 r
F P
0 g
s
.39795 .6609 m .40485 .62528 L .43547 .633 L p .707 .577 .707 r
F P
0 g
s
.36661 .65643 m .37351 .62081 L .40485 .62528 L p .707 .577 .707 r
F P
0 g
s
.40485 .62528 m .39795 .6609 L .36661 .65643 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001eOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol0
079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007Ao
o`00Kgoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01000L7oo001/Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001]Ool006Yoo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00
J7oo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001VOol20005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001TOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005eooa8000QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo0`001UYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001IOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005Qoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00F7oo00D005YFFUIJEP0000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Egoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00H005YF0000
05YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Ioo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001FOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00EGoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001VOol005Eo
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00EGoo00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo
00<005YFFUH00UYF4`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Ao
o`800005FUH00000FUH00006FUH40002FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00E7oo00=JEP0000000eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00EJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP8000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00IJEPD000MJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH01P00
FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00<0
05YFFUH015YF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00@000UJEP8000IJEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH=0004FUH02000FUIJEP00FUH0
05YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool7001COol005Eo
o`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001goo1@000eYF00@005YFFUIJEPT004Yoo`00EGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP05001J
EP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60014Ool003Iooa8000ioo`8000IJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000@Woo000dOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20002FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000oOol0039oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000Moo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP800004FUH005YF0002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<0
05YF00003`001UYF00<005YFFUH01EYF0`00?7oo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP040005Ool200000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00001JEPD000=JEP03
001JEUYF00EJEP03001JEUYF009JEPL000QJEP04001JEP00000jOol0035oo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004Ool20008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800006Ool00000001J
EP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YFFUIJEP<003Mo
o`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0`0017oo0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0
00MJEP8003Eoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH20008FUH3000cOol002moo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000MJEP05
001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001oogoo00=oo`<000MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00FUIJEP02FUH2000`Ool002moo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000=oo`03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0]Ool002moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800005Ool005YFFUH00003FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20008FUH0
0`00FUIJEP04FUH2000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF
00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP04001JEUYFFUH60008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH00eYF3P0000=J
EP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP04001JEUYF0003FUH@0004FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH50003FUH20002Ool>0008FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP0C0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02000
FUIJEUYF001JEP00FUH40006FUH01000FUH000002Goo200015YF00<005YF00001eYF00<005YFFUH0
15YF00<005YFFUH00P00;7oo000]Ool00`00FUIJEP02FUHC0006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH0000?0002FUH9000;FUH00`00FUIJEP03FUH00`00FUH00003000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00AJEP04001JEUYFFUH2
000=Ool500000eYF00000007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00;Goo0P00
00EJEP00001JEP0000IJEP8000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH015YF
10002goo1P001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000[Ool002eoo`03FUH0000000=J
EP03001JEUYF00AJEP04001JEP00000;Ool40007FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YF
FUH015YF00<005YFFUH01UYF00@005YF000000aoo`@000IJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF0000:goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00
FUIJEP020003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00eoo`8000AJEP03001JEUYF00AJEP04001JEUYF0002FUH/Ool002aoo`<000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@000eoo`<00003FUH0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEPl000=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH6
0009Ool200000eYF001JEP05FUH01`00FUIJEUYF001JEP0002aoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100037oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF
009JEPD00003FUH0000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool20006FUH0
1`00FUIJEUYF001JEP0002aoo`00;7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH015YF1@001goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0`001EYF0P0000=JEP0000000P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
100015YF00<005YFFUH01UYF00@005YFFUIJEPL000AJEP07001JEUYFFUH005YF0000;7oo000]Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010000goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
0`000UYF0P000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00AJEP03001JEUYF00]JEPL000IJEP03001JEUYF00EJEP04001JEUYF0003
FUH01P00FUIJEP00FUH002eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00=JEP03001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00eJ
EP03001JEUYF009JEPP000IJEP03001JEP0000@000=JEP03001JEP0002eoo`00;Woo00@005YFFUH0
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<000QJEP03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000IJ
EP03001JEUYF00eJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH20003FUH00`00FUH0000]Ool0
02ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50006FUH200000eYF001JEP02
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009o
o`<000AJEP03001JEUYF00aJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EP00009JEP03001JEP0002eoo`00;goo0P001UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF
0`000eYF1`0000=JEP0000000eYF00@005YFFUH000AJEPH000MJEP03001JEP0000EJEP03001JEUYF
00AJEP@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Aoo`80009JEP03001JEUYF00eJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH200000eYF001oo`0]Ool0031oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00EJEPD000IJEP04001JEP00FUH200000eYF001JEP020004FUH20002FUH01000FUIJEP0015YF2000
15YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo0`003eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH007oo02eoo`00<Goo0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF0`001eYF00L005YF000005YF001JEP0D0004FUH01000FUIJEUYF
0`0000=JEP0000001eYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000Eoo`8000iJEP03001JEP00
008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`0]Ool003=o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000MJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUH00000FUH00P001Goo0P0035YF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YF
FUH005YF001JEP00;Woo000eOol20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF001J
EUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH30004Ool200000eYF00000006FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000_Ool003Moo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP8000AJEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPP00003FUH005YF00EJEP06001JEUYF001JEP000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0P0017oo1`00
0UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000_
Ool003Uoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP<00003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEPD000MJEP8000IJEP06001JEUYF001JEP00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
25YF0`001Goo0`0000=JEP0000001P000eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF0000
05YF0080031oo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUH000=JEP03001J
EUYF00@000=JEP03001JEUYF00=JEP<000AJEPH000AJEP03001JEUYF00MJEP8000=JEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001eYF00D005YFFUIJEP0000Moo`<00003FUH005YF009JEPP000AJEP04001JEUYFFUH5
0002FUH2000aOol003eoo`<000MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH:0002FUH:0005FUH00`00FUIJEP09FUH200000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH2
0008Ool60004FUH00`00FUIJEP080003FUH01000FUH00000<goo0010Ool40002FUH00`00FUIJEP07
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0;Ool80004FUH01000FUIJ
EUYF1000=Goo0014Ool50007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH400000eYF000000070008FUH5000015YF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH015YF0P0057oo2000>Goo
0019Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJ
EP04FUH01000FUIJEP00E7oo001=Ool<0003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJ
EP05001JEUYFFUH0001COol005Uoo`800003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05001J
EUYFFUH0001COol005=oo`/000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP03001JEUYF008005=oo`00>7oo
40000Woo2@002eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001BOol003=o
o`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEP0000800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0000Ioo`<004Uoo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005Ool50018Ool002moo`8000=JEP03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF
00AJEP04001JEUYF0002FUH6Ool50018Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPl000=JEP05001JEUYF001JEP050006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001oo`800003FUH005YF00EJEP07001JEUYFFUH005YF00001Woo
1@001Woo4P00<7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP020009Ool40002FUH00`00FUIJEP03FUH50002FUH00`00
FUIJEP06FUH01000FUIJEUYF10002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000goo0P001UYF00L005YFFUIJEP00FUH00007Ool:0004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000^Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80009JEP03001JEUYF00=J
EP03001JEUYF009JEPl0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000L000AJEP07001JEUYFFUH005YF00000Woo1P0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo000]Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH20004Ool300001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00@005YFFUH000=JEP05001JEUYF001JEP0400000eYF001JEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00:goo000/Ool00`00FUH00004FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH500001EYF
001JEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YF0000100000=JEP0000000P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH017ooFUIJEP000UYF
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
000[Ool002aoo`03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH2
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000>Ool50002FUH00`00Oomoo`0YOol002aoo`80
00=JEPL000aoo`@0009JEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00=JEP03001JEUYF00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP00008000MJEP03001JEUYF00AJ
EPH001Qoo`80009JEP@002Yoo`00;7oo00=JEP00FUH00P0000=JEP00FUH00P004Woo10001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00=JEP<0
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP04001JEP00FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20004FUH01000
FUH00000:Woo000[Ool01`00FUH00000FUH005YF00@000Qooa80009JEP8000MJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF
000015YF00<005YFFUH015YF100077oo100000=JEP00FUH015YF00<005YF0000:Woo000[Ool30002
FUH2000015YF001JEUYF20000eYF00<005YFFUH01UYF00<005YFFUH00eYF10001eYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001JEP00008000EJEP04
001JEUYFFUH300000eYF001oo`0IOol30005FUH00`00FUIJEP03FUH2000[Ool002]oo`03001JEP00
009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00AJEP05001JEUYFFUH00002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP05001JEP00FUH00005FUH00`00FUH00005000GOol400000eYF001JEP06FUH01000FUIJEUYF0P00
;7oo000[Ool00`00FUH00002FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH800000eYF001JEP05FUH00`00FUIJEP020002FUH01000FUH000001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP<0009JEP04001JEP00000@Ool70005FUH00`00FUIJ
EP05FUH01000FUH00000;Woo000[Ool00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH40008Ool20006FUH00`00FUIJEP020002FUH200000eYF001JEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200001UYF001JEUYF001JEP800003FUH005YF00800003FUH0000000Qoo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00;7oo00D005YFFUIJEP00009JEP@000=J
EP03001JEUYF00=JEP03OomJEP0000AJEPH000ioo`8000=JEP04001JEUYFFUH200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000005YF500015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00<goo000/Ool01@00FUIJEUYF00001EYF5P004Goo0P0000=JEP00
FUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00=goo000]
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000COol20003FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04000jOol002ioo`8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEPL000moo`D00003FUH00000008000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEPD003ioo`00;goo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF3`000UYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF00000Woo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1000@goo000`Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000Eoo`D0009JEP03001JEUYF00EJEP03001JEUYF009JEPL004Moo`00<Woo0P0000=JEP00FUH0
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YF001oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000]oo`l004ioo`00=7oo
0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00=goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P001Woo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000006aoo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH4001^Ool003aoo`<000IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000;Ool300000eYF001JEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07001`Ool003moo`@0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000?Ool70005FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50003Ool5001_Ool004=oo`D000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEP00000HOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP06
0008Ool50006OolB001GOol004Qoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH4000VOolF000>
Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001EOol004aoo`l004Yoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008005=oo`00XGoo100000=JEP00
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00
WGoo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00DWoo002IOol400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003
FUH01@00FUIJEUYF0000DWoo002GOol20005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000>Ool5
0002FUH00`00Oomoo`1@Ool009Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00@001Moo`800003
FUH000000080055oo`00Tgoo0P000UYF00<005YFFUH01EYF00<005YFFUH015YF100067oo0`000eYF
00@005YF0000055oo`00TWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0100067oo1000
00=JEP00FUH015YF00<005YF0000DGoo002AOol20005FUH00`00FUIJEP03FUH4000IOol30005FUH0
0`00FUIJEP03FUH2001BOol0091oo`03001JEP0000EJEP03001JEP0000<001Uoo`@00003FUH005YF
00IJEP04001JEUYFFUH2001COol0091oo`04001JEUYF0003FUH3000HOol50005FUH00`00FUIJEP05
FUH01000FUH00000EGoo002@Ool01@00FUIJEP00FUH00P005goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`00Egoo002AOol00`00FUH000040007Ool?0006FUH00`00FUIJEP06FUH00`00FUH0
0003001JOol0095oo`80009JEP03001JEUYF00L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP<005ioo`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01000HGoo002AOol20003FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5001UOol0099oo`80009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006Yoo`00U7oo1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF1`00KWoo002IOol?001eOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5918 .77847 m .60435 .72578 L .57399 .71684 L p .707 .577 .707 r
F P
0 g
s
.60435 .72578 m .5918 .77847 L .6229 .78404 L p .707 .577 .707 r
F P
0 g
s
.6229 .78404 m .63545 .73135 L .60435 .72578 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57399 .71684 L .57133 .7157 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57133 .7157 L .56054 .76543 L .707 .577 .707 r
F
.57399 .71684 m .56144 .76953 L .5918 .77847 L p F P
0 g
s
.58911 .77317 m .596 .73755 L .56811 .73052 L p .707 .577 .707 r
F P
0 g
s
.56811 .73052 m .56538 .72983 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.58911 .77317 m .56811 .73052 L .56745 .7336 L .707 .577 .707 r
F
.55849 .76545 m .56538 .72983 L .53848 .71963 L p F P
0 g
s
.56538 .72983 m .55849 .76545 L .56043 .76594 L p .707 .577 .707 r
F P
0 g
s
.5598 .76882 m .56144 .76953 L p .56054 .76543 L .707 .577 .707 r
F P
0 g
s
.56043 .76594 m .58911 .77317 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.56745 .7336 m .56538 .72983 L .56043 .76594 L .707 .577 .707 r
F
.53848 .71963 m .53158 .75524 L .55849 .76545 L p F P
0 g
s
.54735 .70541 m .5348 .75809 L .5598 .76882 L p .707 .577 .707 r
F P
0 g
s
.56054 .76543 m .54735 .70541 L .5598 .76882 L .707 .577 .707 r
F
.57133 .7157 m .54735 .70541 L p .56054 .76543 L F P
0 g
s
.63545 .73135 m .6229 .78404 L .65169 .7857 L p .707 .577 .707 r
F P
0 g
s
.65169 .7857 m .66425 .73301 L .63545 .73135 L p .707 .577 .707 r
F P
0 g
s
.596 .73755 m .58911 .77317 L .62044 .77764 L p .707 .577 .707 r
F P
0 g
s
.62044 .77764 m .62734 .74202 L .596 .73755 L p .707 .577 .707 r
F P
0 g
s
.62734 .74202 m .62044 .77764 L .64943 .77842 L p .707 .577 .707 r
F P
0 g
s
.64943 .77842 m .65633 .7428 L .62734 .74202 L p .707 .577 .707 r
F P
0 g
s
.53158 .75524 m .53848 .71963 L .51792 .70793 L p .707 .577 .707 r
F P
0 g
s
.5348 .75809 m .54735 .70541 L .52703 .6926 L p .707 .577 .707 r
F P
0 g
s
.66425 .73301 m .65169 .7857 L .67537 .78329 L p .707 .577 .707 r
F P
0 g
s
.67537 .78329 m .68792 .7306 L .66425 .73301 L p .707 .577 .707 r
F P
0 g
s
.65633 .7428 m .64943 .77842 L .67323 .77544 L p .707 .577 .707 r
F P
0 g
s
.67323 .77544 m .68013 .73983 L .65633 .7428 L p .707 .577 .707 r
F P
0 g
s
.51792 .70793 m .51102 .74354 L .53158 .75524 L p .707 .577 .707 r
F P
0 g
s
.52703 .6926 m .51448 .74529 L .5348 .75809 L p .707 .577 .707 r
F P
0 g
s
.51102 .74354 m .51792 .70793 L .50572 .69588 L p .707 .577 .707 r
F P
0 g
s
.51448 .74529 m .52703 .6926 L .51502 .67968 L p .707 .577 .707 r
F P
0 g
s
.60649 .88413 m .60367 .86553 L .57287 .86848 L p .707 .577 .707 r
F P
0 g
s
.60367 .86553 m .60649 .88413 L .638 .87898 L p .707 .577 .707 r
F P
0 g
s
.638 .87898 m .63518 .86038 L .60367 .86553 L p .707 .577 .707 r
F P
0 g
s
.68792 .7306 m .67537 .78329 L .69161 .77703 L p .707 .577 .707 r
F P
0 g
s
.69161 .77703 m .70416 .72435 L .68792 .7306 L p .707 .577 .707 r
F P
0 g
s
.63518 .86038 m .638 .87898 L .66712 .87213 L p .707 .577 .707 r
F P
0 g
s
.66712 .87213 m .66429 .85354 L .63518 .86038 L p .707 .577 .707 r
F P
0 g
s
.57287 .86848 m .57569 .88707 L .60649 .88413 L p .707 .577 .707 r
F P
0 g
s
.68013 .73983 m .67323 .77544 L .68951 .769 L p .707 .577 .707 r
F P
0 g
s
.68951 .769 m .69641 .73338 L .68013 .73983 L p .707 .577 .707 r
F P
0 g
s
.57569 .88707 m .57287 .86848 L .54578 .86893 L p .707 .577 .707 r
F P
0 g
s
.54578 .86893 m .5486 .88753 L .57569 .88707 L p .707 .577 .707 r
F P
0 g
s
.66429 .85354 m .66712 .87213 L .691 .86426 L p .707 .577 .707 r
F P
0 g
s
.691 .86426 m .68818 .84566 L .66429 .85354 L p .707 .577 .707 r
F P
0 g
s
.50572 .69588 m .49882 .7315 L .51102 .74354 L p .707 .577 .707 r
F P
0 g
s
.51502 .67968 m .50247 .73237 L .51448 .74529 L p .707 .577 .707 r
F P
0 g
s
.5486 .88753 m .54578 .86893 L .52505 .86685 L p .707 .577 .707 r
F P
0 g
s
.50247 .73237 m .51502 .67968 L .5125 .6679 L p .707 .577 .707 r
F P
0 g
s
.70416 .72435 m .69161 .77703 L .69882 .76756 L p .707 .577 .707 r
F P
0 g
s
.69882 .76756 m .71138 .71487 L .70416 .72435 L p .707 .577 .707 r
F P
0 g
s
.52505 .86685 m .52788 .88544 L .5486 .88753 L p .707 .577 .707 r
F P
0 g
s
.68818 .84566 m .691 .86426 L .70731 .85612 L p .707 .577 .707 r
F P
0 g
s
.70731 .85612 m .70449 .83752 L .68818 .84566 L p .707 .577 .707 r
F P
0 g
s
.69641 .73338 m .68951 .769 L .69668 .75971 L p .707 .577 .707 r
F P
0 g
s
.69668 .75971 m .70358 .72409 L .69641 .73338 L p .707 .577 .707 r
F P
0 g
s
.49882 .7315 m .50572 .69588 L .50308 .68466 L p .707 .577 .707 r
F P
0 g
s
.5125 .6679 m .49995 .72059 L .50247 .73237 L p .707 .577 .707 r
F P
0 g
s
.50308 .68466 m .49618 .72028 L .49882 .7315 L p .707 .577 .707 r
F P
0 g
s
.52788 .88544 m .52505 .86685 L .51273 .86243 L p .707 .577 .707 r
F P
0 g
s
.51273 .86243 m .51555 .88103 L .52788 .88544 L p .707 .577 .707 r
F P
0 g
s
.49995 .72059 m .5125 .6679 L .51972 .65842 L p .707 .577 .707 r
F P
0 g
s
.70358 .72409 m .69668 .75971 L .69404 .7485 L p .707 .577 .707 r
F P
0 g
s
.71138 .71487 m .69882 .76756 L .6963 .75578 L p .707 .577 .707 r
F P
0 g
s
.6963 .75578 m .70886 .70309 L .71138 .71487 L p .707 .577 .707 r
F P
0 g
s
.4905 .8214 m .48561 .31901 L .4416 .31676 L p .707 .577 .707 r
F P
0 g
s
.49618 .72028 m .50308 .68466 L .51025 .67538 L p .707 .577 .707 r
F P
0 g
s
.51972 .65842 m .50716 .71111 L .49995 .72059 L p .707 .577 .707 r
F P
0 g
s
.51025 .67538 m .50335 .71099 L .49618 .72028 L p .707 .577 .707 r
F P
0 g
s
.50716 .71111 m .51972 .65842 L .53596 .65217 L p .707 .577 .707 r
F P
0 g
s
.50335 .71099 m .51025 .67538 L .52653 .66893 L p .707 .577 .707 r
F P
0 g
s
.53596 .65217 m .5234 .70486 L .50716 .71111 L p .707 .577 .707 r
F P
0 g
s
.52653 .66893 m .51963 .70455 L .50335 .71099 L p .707 .577 .707 r
F P
0 g
s
.5234 .70486 m .53596 .65217 L .55963 .64976 L p .707 .577 .707 r
F P
0 g
s
.55963 .64976 m .54708 .70244 L .5234 .70486 L p .707 .577 .707 r
F P
0 g
s
.51963 .70455 m .52653 .66893 L .55033 .66595 L p .707 .577 .707 r
F P
0 g
s
.55033 .66595 m .54343 .70157 L .51963 .70455 L p .707 .577 .707 r
F P
0 g
s
.48561 .31901 m .4905 .8214 L .53544 .81991 L p .707 .577 .707 r
F P
0 g
s
.53544 .81991 m .53055 .31752 L .48561 .31901 L p .707 .577 .707 r
F P
0 g
s
.70449 .83752 m .70731 .85612 L .71445 .84853 L p .707 .577 .707 r
F P
0 g
s
.71445 .84853 m .71163 .82993 L .70449 .83752 L p .707 .577 .707 r
F P
0 g
s
.54708 .70244 m .55963 .64976 L .58843 .65142 L p .707 .577 .707 r
F P
0 g
s
.58843 .65142 m .57588 .7041 L .54708 .70244 L p .707 .577 .707 r
F P
0 g
s
.54343 .70157 m .55033 .66595 L .57932 .66674 L p .707 .577 .707 r
F P
0 g
s
.57932 .66674 m .57242 .70236 L .54343 .70157 L p .707 .577 .707 r
F P
0 g
s
.53055 .31752 m .53544 .81991 L .57692 .81483 L p .707 .577 .707 r
F P
0 g
s
.57588 .7041 m .58843 .65142 L .61953 .65699 L p .707 .577 .707 r
F P
0 g
s
.61953 .65699 m .60698 .70968 L .57588 .7041 L p .707 .577 .707 r
F P
0 g
s
.57242 .70236 m .57932 .66674 L .61066 .67121 L p .707 .577 .707 r
F P
0 g
s
.61066 .67121 m .60376 .70682 L .57242 .70236 L p .707 .577 .707 r
F P
0 g
s
.57692 .81483 m .57203 .31244 L .53055 .31752 L p .707 .577 .707 r
F P
0 g
s
.69404 .7485 m .70094 .71288 L .70358 .72409 L p .707 .577 .707 r
F P
0 g
s
.44649 .81915 m .4416 .31676 L .40284 .31099 L p .707 .577 .707 r
F P
0 g
s
.4416 .31676 m .44649 .81915 L .4905 .8214 L p .707 .577 .707 r
F P
0 g
s
.51555 .88103 m .51273 .86243 L .51 .85612 L p .707 .577 .707 r
F P
0 g
s
.57203 .31244 m .57692 .81483 L .61087 .80665 L p .707 .577 .707 r
F P
0 g
s
.66818 .68913 m .66128 .72475 L .63609 .71519 L p .707 .577 .707 r
F P
0 g
s
.63658 .71288 m .66818 .68913 L .63609 .71519 L .707 .577 .707 r
F
.63547 .71807 m .60698 .70968 L p .64576 .67014 L F P
0 g
s
.63438 .71454 m .64128 .67892 L .66818 .68913 L p .707 .577 .707 r
F P
0 g
s
.64989 .66593 m .63733 .71862 L .63547 .71807 L p .707 .577 .707 r
F P
0 g
s
.64576 .67014 m .64989 .66593 L .63547 .71807 L .707 .577 .707 r
F
.63609 .71519 m .63438 .71454 L p .63658 .71288 L F P
0 g
s
.60698 .70968 m .61953 .65699 L .64989 .66593 L p .707 .577 .707 r
F P
0 g
s
.64128 .67892 m .63438 .71454 L .60376 .70682 L p .707 .577 .707 r
F P
0 g
s
.60376 .70682 m .61066 .67121 L .64128 .67892 L p .707 .577 .707 r
F P
0 g
s
.61087 .80665 m .60598 .30426 L .57203 .31244 L p .707 .577 .707 r
F P
0 g
s
.24879 .69549 m .26134 .6428 L .23099 .63386 L p .707 .577 .707 r
F P
0 g
s
.26134 .6428 m .24879 .69549 L .27989 .70106 L p .707 .577 .707 r
F P
0 g
s
.27989 .70106 m .29244 .64837 L .26134 .6428 L p .707 .577 .707 r
F P
0 g
s
.51 .85612 m .51282 .87471 L .51555 .88103 L p .707 .577 .707 r
F P
0 g
s
.21843 .68655 m .23099 .63386 L .20434 .62243 L p .707 .577 .707 r
F P
0 g
s
.23099 .63386 m .21843 .68655 L .24879 .69549 L p .707 .577 .707 r
F P
0 g
s
.29244 .64837 m .27989 .70106 L .30869 .70272 L p .707 .577 .707 r
F P
0 g
s
.30869 .70272 m .32124 .65003 L .29244 .64837 L p .707 .577 .707 r
F P
0 g
s
.70094 .71288 m .69404 .7485 L .68184 .73645 L p .707 .577 .707 r
F P
0 g
s
.70886 .70309 m .6963 .75578 L .68429 .74285 L p .707 .577 .707 r
F P
0 g
s
.68184 .73645 m .68874 .70083 L .70094 .71288 L p .707 .577 .707 r
F P
0 g
s
.68429 .74285 m .69685 .69017 L .70886 .70309 L p .707 .577 .707 r
F P
0 g
s
.71163 .82993 m .71445 .84853 L .71172 .84221 L p .707 .577 .707 r
F P
0 g
s
.71172 .84221 m .7089 .82361 L .71163 .82993 L p .707 .577 .707 r
F P
0 g
s
.40773 .81338 m .40284 .31099 L .37311 .30227 L p .707 .577 .707 r
F P
0 g
s
.40284 .31099 m .40773 .81338 L .44649 .81915 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19179 .67511 m .20434 .62243 L .18402 .60962 L p .707 .577 .707 r
F P
0 g
s
.20434 .62243 m .19179 .67511 L .21843 .68655 L p .707 .577 .707 r
F P
0 g
s
.32124 .65003 m .30869 .70272 L .33236 .70031 L p .707 .577 .707 r
F P
0 g
s
.33236 .70031 m .34492 .64762 L .32124 .65003 L p .707 .577 .707 r
F P
0 g
s
.60598 .30426 m .61087 .80665 L .63398 .79618 L p .707 .577 .707 r
F P
0 g
s
.63398 .79618 m .62909 .29379 L .60598 .30426 L p .707 .577 .707 r
F P
0 g
s
.51282 .87471 m .51 .85612 L .51714 .84852 L p .707 .577 .707 r
F P
0 g
s
.26348 .77482 m .26066 .75622 L .22986 .75917 L p .707 .577 .707 r
F P
0 g
s
.26066 .75622 m .26348 .77482 L .29499 .76967 L p .707 .577 .707 r
F P
0 g
s
.29499 .76967 m .29217 .75108 L .26066 .75622 L p .707 .577 .707 r
F P
0 g
s
.68874 .70083 m .68184 .73645 L .66128 .72475 L p .707 .577 .707 r
F P
0 g
s
.66128 .72475 m .66818 .68913 L .68874 .70083 L p .707 .577 .707 r
F P
0 g
s
.69685 .69017 m .68429 .74285 L .66398 .73005 L p .707 .577 .707 r
F P
0 g
s
.66398 .73005 m .67653 .67736 L .69685 .69017 L p .707 .577 .707 r
F P
0 g
s
.51714 .84852 m .51996 .86712 L .51282 .87471 L p .707 .577 .707 r
F P
0 g
s
.29217 .75108 m .29499 .76967 L .32411 .76283 L p .707 .577 .707 r
F P
0 g
s
.32411 .76283 m .32128 .74423 L .29217 .75108 L p .707 .577 .707 r
F P
0 g
s
.22986 .75917 m .23268 .77777 L .26348 .77482 L p .707 .577 .707 r
F P
0 g
s
.18402 .60962 m .17147 .66231 L .19179 .67511 L p .707 .577 .707 r
F P
0 g
s
.17147 .66231 m .18402 .60962 L .17202 .5967 L p .707 .577 .707 r
F P
0 g
s
.23268 .77777 m .22986 .75917 L .20277 .75962 L p .707 .577 .707 r
F P
0 g
s
.34492 .64762 m .33236 .70031 L .3486 .69405 L p .707 .577 .707 r
F P
0 g
s
.3486 .69405 m .36116 .64137 L .34492 .64762 L p .707 .577 .707 r
F P
0 g
s
.7089 .82361 m .71172 .84221 L .6994 .83779 L p .707 .577 .707 r
F P
0 g
s
.6994 .83779 m .69657 .8192 L .7089 .82361 L p .707 .577 .707 r
F P
0 g
s
.2278 .77731 m .22237 .77595 L p .22774 .78575 L .707 .577 .707 r
F P
0 g
s
.21548 .81156 m .22237 .77595 L .19547 .76574 L p .707 .577 .707 r
F P
0 g
s
.22237 .77595 m .21548 .81156 L .2461 .81928 L p .707 .577 .707 r
F P
0 g
s
.20277 .75962 m .20559 .77822 L .2278 .77785 L p .707 .577 .707 r
F P
0 g
s
.2278 .77785 m .23268 .77777 L p .22782 .77482 L .707 .577 .707 r
F P
0 g
s
.22782 .77482 m .20277 .75962 L .2278 .77785 L .707 .577 .707 r
F
.2461 .81928 m .25299 .78366 L .2278 .77731 L p F P
0 g
s
.2461 .81928 m .2278 .77731 L .22774 .78575 L .707 .577 .707 r
F
.25299 .78366 m .2461 .81928 L .27743 .82375 L p F P
0 g
s
.27743 .82375 m .28433 .78813 L .25299 .78366 L p .707 .577 .707 r
F P
0 g
s
.378 .80466 m .37311 .30227 L .35534 .29145 L p .707 .577 .707 r
F P
0 g
s
.37311 .30227 m .378 .80466 L .40773 .81338 L p .707 .577 .707 r
F P
0 g
s
.32128 .74423 m .32411 .76283 L .34799 .75495 L p .707 .577 .707 r
F P
0 g
s
.34799 .75495 m .34517 .73635 L .32128 .74423 L p .707 .577 .707 r
F P
0 g
s
.28433 .78813 m .27743 .82375 L .30642 .82453 L p .707 .577 .707 r
F P
0 g
s
.30642 .82453 m .31332 .78892 L .28433 .78813 L p .707 .577 .707 r
F P
0 g
s
.67653 .67736 m .66398 .73005 L .63733 .71862 L p .707 .577 .707 r
F P
0 g
s
.63733 .71862 m .64989 .66593 L .67653 .67736 L p .707 .577 .707 r
F P
0 g
s
.19547 .76574 m .18857 .80135 L .21548 .81156 L p .707 .577 .707 r
F P
0 g
s
.18857 .80135 m .19547 .76574 L .17491 .75404 L p .707 .577 .707 r
F P
0 g
s
.20559 .77822 m .20277 .75962 L .18205 .75754 L p .707 .577 .707 r
F P
0 g
s
.17202 .5967 m .15946 .64939 L .17147 .66231 L p .707 .577 .707 r
F P
0 g
s
.51996 .86712 m .51714 .84852 L .53345 .84038 L p .707 .577 .707 r
F P
0 g
s
.31332 .78892 m .30642 .82453 L .33022 .82156 L p .707 .577 .707 r
F P
0 g
s
.33022 .82156 m .33712 .78594 L .31332 .78892 L p .707 .577 .707 r
F P
0 g
s
.18205 .75754 m .18487 .77614 L .20559 .77822 L p .707 .577 .707 r
F P
0 g
s
.53345 .84038 m .53627 .85898 L .51996 .86712 L p .707 .577 .707 r
F P
0 g
s
.34517 .73635 m .34799 .75495 L .3643 .74681 L p .707 .577 .707 r
F P
0 g
s
.3643 .74681 m .36148 .72822 L .34517 .73635 L p .707 .577 .707 r
F P
0 g
s
.62909 .29379 m .63398 .79618 L .64398 .78444 L p .707 .577 .707 r
F P
0 g
s
.64398 .78444 m .63909 .28205 L .62909 .29379 L p .707 .577 .707 r
F P
0 g
s
.15946 .64939 m .17202 .5967 L .16949 .58492 L p .707 .577 .707 r
F P
0 g
s
.36116 .64137 m .3486 .69405 L .35581 .68457 L p .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .36552 .64384 L p .36116 .64137 L .707 .577 .707 r
F P
0 g
s
.36632 .63458 m .36116 .64137 L p .36552 .64384 L .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .35329 .6728 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .36837 .63189 L .36632 .63458 L p .707 .577 .707 r
F P
0 g
s
.36837 .63189 m .36552 .64384 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .35581 .68457 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .36125 .26785 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .36165 .6156 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34179 .65905 m .36165 .6156 L .3622 .62601 L .707 .577 .707 r
F
.34129 .65987 m .34181 .65873 L .34179 .65905 L F
.34181 .65873 m .36165 .6156 L .34179 .65905 L F
.36165 .6156 m .36585 .62011 L p .3622 .62601 L F P
0 g
s
.36585 .62011 m .36837 .63189 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .36261 .6337 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .36585 .62011 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .34129 .65987 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36585 .62011 m .36261 .6337 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .35329 .6728 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.35367 .80582 m .36057 .77021 L .3534 .77949 L p .707 .577 .707 r
F P
0 g
s
.3534 .77949 m .3465 .81511 L .35367 .80582 L p .707 .577 .707 r
F P
0 g
s
.36057 .77021 m .35367 .80582 L .35103 .79461 L p .707 .577 .707 r
F P
0 g
s
.35103 .79461 m .35793 .75899 L .36057 .77021 L p .707 .577 .707 r
F P
0 g
s
.36148 .72822 m .3643 .74681 L .37144 .73922 L p .707 .577 .707 r
F P
0 g
s
.37144 .73922 m .36862 .72062 L .36148 .72822 L p .707 .577 .707 r
F P
0 g
s
.36589 .7143 m .36871 .7329 L .35639 .72849 L p .707 .577 .707 r
F P
0 g
s
.35639 .72849 m .35356 .70989 L .36589 .7143 L p .707 .577 .707 r
F P
0 g
s
.3465 .81511 m .3534 .77949 L .33712 .78594 L p .707 .577 .707 r
F P
0 g
s
.35793 .75899 m .35103 .79461 L .34186 .78555 L p .707 .577 .707 r
F P
0 g
s
.34186 .78555 m .33883 .78256 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.34217 .77845 m .35793 .75899 L .34186 .78555 L .707 .577 .707 r
F
.34573 .74694 m .35793 .75899 L p .34217 .77845 L F P
0 g
s
.33883 .78256 m .3429 .76157 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.3429 .76157 m .34573 .74694 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .35291 .45006 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35534 .29145 L p .35808 .61795 L .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .35125 .27959 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35658 .51956 m .35534 .29145 L .35488 .4873 L .707 .577 .707 r
F
.35808 .61795 m .35534 .29145 L .3571 .61452 L F
.36862 .72062 m .37144 .73922 L .36871 .7329 L p F P
0 g
s
.36871 .7329 m .36589 .7143 L .36862 .72062 L p .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .36023 .79384 L .378 .80466 L p .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .35291 .45006 L .36094 .29906 L .707 .577 .707 r
F
.35356 .70989 m .35639 .72849 L .33566 .7264 L p F P
0 g
s
.35755 .64032 m .35488 .4873 L .35614 .78198 L .707 .577 .707 r
F
.35614 .78198 m .36023 .79384 L p .35755 .64032 L F P
0 g
s
.35291 .45006 m .35614 .78198 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35755 .64032 m .35778 .6169 L .3571 .61452 L .707 .577 .707 r
F
.35894 .72025 m .35778 .6169 L .35755 .64032 L F
.35894 .72025 m .35808 .61795 L .35778 .6169 L F
.3571 .61452 m .35658 .51956 L .35488 .4873 L F
.35614 .78198 m .35355 .51579 L p .36034 .35898 L F P
0 g
s
.35355 .51579 m .35291 .45006 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.35945 .71432 m .35853 .61951 L p .35894 .72025 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35808 .61795 L .35894 .72025 L .707 .577 .707 r
F
.36023 .79384 m .35945 .71432 L p .35894 .72025 L F P
0 g
s
.36614 .77024 m .35614 .78198 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .36094 .29906 L .36135 .33587 L .707 .577 .707 r
F
.36034 .35898 m .36135 .33587 L .36614 .77024 L F
.36125 .26785 m .36146 .2893 L p .36094 .29906 L F P
0 g
s
.36146 .2893 m .36614 .77024 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35291 .45006 m .35125 .27959 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.34129 .65987 m .34188 .65736 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34188 .65736 m .35384 .60719 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.69657 .8192 m .6994 .83779 L .67867 .83571 L p .707 .577 .707 r
F P
0 g
s
.67867 .83571 m .67585 .81711 L .69657 .8192 L p .707 .577 .707 r
F P
0 g
s
.17491 .75404 m .16801 .78965 L .18857 .80135 L p .707 .577 .707 r
F P
0 g
s
.16801 .78965 m .17491 .75404 L .16271 .74199 L p .707 .577 .707 r
F P
0 g
s
.18487 .77614 m .18205 .75754 L .16972 .75312 L p .707 .577 .707 r
F P
0 g
s
.33712 .78594 m .33022 .82156 L .3465 .81511 L p .707 .577 .707 r
F P
0 g
s
.16972 .75312 m .17254 .77172 L .18487 .77614 L p .707 .577 .707 r
F P
0 g
s
.16949 .58492 m .15694 .63761 L .15946 .64939 L p .707 .577 .707 r
F P
0 g
s
.53627 .85898 m .53345 .84038 L .55733 .83251 L p .707 .577 .707 r
F P
0 g
s
.55733 .83251 m .56016 .8511 L .53627 .85898 L p .707 .577 .707 r
F P
0 g
s
.67585 .81711 m .67867 .83571 L .65158 .83616 L p .707 .577 .707 r
F P
0 g
s
.65158 .83616 m .64876 .81757 L .67585 .81711 L p .707 .577 .707 r
F P
0 g
s
.15694 .63761 m .16949 .58492 L .17671 .57544 L p .707 .577 .707 r
F P
0 g
s
.16271 .74199 m .15582 .77761 L .16801 .78965 L p .707 .577 .707 r
F P
0 g
s
.56016 .8511 m .55733 .83251 L .58645 .82566 L p .707 .577 .707 r
F P
0 g
s
.63909 .28205 m .64398 .78444 L .63989 .77258 L p .707 .577 .707 r
F P
0 g
s
.63989 .77258 m .635 .27019 L .63909 .28205 L p .707 .577 .707 r
F P
0 g
s
.58645 .82566 m .58927 .84426 L .56016 .8511 L p .707 .577 .707 r
F P
0 g
s
.15582 .77761 m .16271 .74199 L .16007 .73078 L p .707 .577 .707 r
F P
0 g
s
.17254 .77172 m .16972 .75312 L .16699 .74681 L p .707 .577 .707 r
F P
0 g
s
.64876 .81757 m .65158 .83616 L .62078 .83911 L p .707 .577 .707 r
F P
0 g
s
.62078 .83911 m .61796 .82051 L .64876 .81757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16699 .74681 m .16981 .76541 L .17254 .77172 L p .707 .577 .707 r
F P
0 g
s
.17671 .57544 m .16415 .62813 L .15694 .63761 L p .707 .577 .707 r
F P
0 g
s
.58927 .84426 m .58645 .82566 L .61796 .82051 L p .707 .577 .707 r
F P
0 g
s
.61796 .82051 m .62078 .83911 L .58927 .84426 L p .707 .577 .707 r
F P
0 g
s
.16007 .73078 m .15317 .76639 L .15582 .77761 L p .707 .577 .707 r
F P
0 g
s
.16415 .62813 m .17671 .57544 L .19295 .56919 L p .707 .577 .707 r
F P
0 g
s
.15317 .76639 m .16007 .73078 L .16724 .72149 L p .707 .577 .707 r
F P
0 g
s
.16981 .76541 m .16699 .74681 L .17413 .73921 L p .707 .577 .707 r
F P
0 g
s
.19295 .56919 m .18039 .62188 L .16415 .62813 L p .707 .577 .707 r
F P
0 g
s
.17413 .73921 m .17695 .75781 L .16981 .76541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.635 .27019 m .63989 .77258 L .62212 .76176 L p .707 .577 .707 r
F P
0 g
s
.62212 .76176 m .61723 .25937 L .635 .27019 L p .707 .577 .707 r
F P
0 g
s
.18039 .62188 m .19295 .56919 L .21662 .56677 L p .707 .577 .707 r
F P
0 g
s
.16724 .72149 m .16034 .75711 L .15317 .76639 L p .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .34129 .65987 L .32097 .64707 L p .707 .577 .707 r
F P
0 g
s
.32097 .64707 m .33352 .59438 L .35384 .60719 L p .707 .577 .707 r
F P
0 g
s
.36614 .77024 m .36125 .26785 L .38436 .25738 L p .707 .577 .707 r
F P
0 g
s
.16034 .75711 m .16724 .72149 L .18352 .71504 L p .707 .577 .707 r
F P
0 g
s
.17695 .75781 m .17413 .73921 L .19044 .73108 L p .707 .577 .707 r
F P
0 g
s
.21662 .56677 m .20407 .61946 L .18039 .62188 L p .707 .577 .707 r
F P
0 g
s
.20407 .61946 m .21662 .56677 L .24542 .56844 L p .707 .577 .707 r
F P
0 g
s
.33352 .59438 m .32097 .64707 L .29432 .63564 L p .707 .577 .707 r
F P
0 g
s
.29432 .63564 m .30688 .58295 L .33352 .59438 L p .707 .577 .707 r
F P
0 g
s
.19044 .73108 m .19326 .74967 L .17695 .75781 L p .707 .577 .707 r
F P
0 g
s
.33566 .7264 m .33284 .70781 L .35356 .70989 L p .707 .577 .707 r
F P
0 g
s
.18352 .71504 m .17662 .75066 L .16034 .75711 L p .707 .577 .707 r
F P
0 g
s
.23287 .62112 m .24542 .56844 L .27652 .57401 L p .707 .577 .707 r
F P
0 g
s
.24542 .56844 m .23287 .62112 L .20407 .61946 L p .707 .577 .707 r
F P
0 g
s
.30688 .58295 m .29432 .63564 L .26397 .6267 L p .707 .577 .707 r
F P
0 g
s
.26397 .6267 m .27652 .57401 L .30688 .58295 L p .707 .577 .707 r
F P
0 g
s
.61723 .25937 m .62212 .76176 L .59239 .75304 L p .707 .577 .707 r
F P
0 g
s
.59239 .75304 m .5875 .25065 L .61723 .25937 L p .707 .577 .707 r
F P
0 g
s
.27652 .57401 m .26397 .6267 L .23287 .62112 L p .707 .577 .707 r
F P
0 g
s
.34573 .74694 m .33883 .78256 L .31827 .77086 L p .707 .577 .707 r
F P
0 g
s
.31827 .77086 m .32517 .73524 L .34573 .74694 L p .707 .577 .707 r
F P
0 g
s
.19326 .74967 m .19044 .73108 L .21432 .7232 L p .707 .577 .707 r
F P
0 g
s
.17662 .75066 m .18352 .71504 L .20732 .71207 L p .707 .577 .707 r
F P
0 g
s
.21432 .7232 m .21715 .7418 L .19326 .74967 L p .707 .577 .707 r
F P
0 g
s
.33284 .70781 m .33566 .7264 L .30857 .72686 L p .707 .577 .707 r
F P
0 g
s
.30857 .72686 m .30575 .70826 L .33284 .70781 L p .707 .577 .707 r
F P
0 g
s
.38436 .25738 m .38925 .75977 L .36614 .77024 L p .707 .577 .707 r
F P
0 g
s
.38925 .75977 m .38436 .25738 L .41832 .24921 L p .707 .577 .707 r
F P
0 g
s
.20732 .71207 m .20042 .74768 L .17662 .75066 L p .707 .577 .707 r
F P
0 g
s
.729 .68643 m .74155 .63374 L .7112 .6248 L p .707 .577 .707 r
F P
0 g
s
.74155 .63374 m .729 .68643 L .7601 .692 L p .707 .577 .707 r
F P
0 g
s
.7601 .692 m .77265 .63931 L .74155 .63374 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .7112 .6248 L .70854 .62366 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .70854 .62366 L .69774 .67339 L .707 .577 .707 r
F
.7112 .6248 m .69864 .67749 L .729 .68643 L p F P
0 g
s
.72631 .68113 m .73321 .64551 L .70532 .63848 L p .707 .577 .707 r
F P
0 g
s
.70532 .63848 m .70259 .6378 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.72631 .68113 m .70532 .63848 L .70465 .64156 L .707 .577 .707 r
F
.69569 .67341 m .70259 .6378 L .67568 .62759 L p F P
0 g
s
.70259 .6378 m .69569 .67341 L .69763 .6739 L p .707 .577 .707 r
F P
0 g
s
.69701 .67679 m .69864 .67749 L p .69774 .67339 L .707 .577 .707 r
F P
0 g
s
.69763 .6739 m .72631 .68113 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.70465 .64156 m .70259 .6378 L .69763 .6739 L .707 .577 .707 r
F
.67568 .62759 m .66878 .6632 L .69569 .67341 L p F P
0 g
s
.68456 .61337 m .672 .66606 L .69701 .67679 L p .707 .577 .707 r
F P
0 g
s
.69774 .67339 m .68456 .61337 L .69701 .67679 L .707 .577 .707 r
F
.70854 .62366 m .68456 .61337 L p .69774 .67339 L F P
0 g
s
.77265 .63931 m .7601 .692 L .7889 .69366 L p .707 .577 .707 r
F P
0 g
s
.7889 .69366 m .80145 .64098 L .77265 .63931 L p .707 .577 .707 r
F P
0 g
s
.32517 .73524 m .31827 .77086 L .29137 .76065 L p .707 .577 .707 r
F P
0 g
s
.30303 .72684 m .32517 .73524 L p .30232 .75242 L .707 .577 .707 r
F P
0 g
s
.30575 .70826 m .30857 .72686 L .30302 .72739 L p .707 .577 .707 r
F P
0 g
s
.30302 .72739 m .27777 .7298 L p .3035 .70999 L .707 .577 .707 r
F P
0 g
s
.3035 .70999 m .30575 .70826 L .30302 .72739 L .707 .577 .707 r
F
.29137 .76065 m .29827 .72504 L .30303 .72684 L p F P
0 g
s
.29137 .76065 m .30303 .72684 L .30232 .75242 L .707 .577 .707 r
F
.21715 .7418 m .21432 .7232 L .24344 .71635 L p F P
0 g
s
.20042 .74768 m .20732 .71207 L .23631 .71285 L p .707 .577 .707 r
F P
0 g
s
.73321 .64551 m .72631 .68113 L .75765 .6856 L p .707 .577 .707 r
F P
0 g
s
.75765 .6856 m .76455 .64998 L .73321 .64551 L p .707 .577 .707 r
F P
0 g
s
.24344 .71635 m .24626 .73495 L .21715 .7418 L p .707 .577 .707 r
F P
0 g
s
.76455 .64998 m .75765 .6856 L .78663 .68638 L p .707 .577 .707 r
F P
0 g
s
.78663 .68638 m .79353 .65076 L .76455 .64998 L p .707 .577 .707 r
F P
0 g
s
.27777 .7298 m .27495 .7112 L .30575 .70826 L p .707 .577 .707 r
F P
0 g
s
.5875 .25065 m .59239 .75304 L .55363 .74728 L p .707 .577 .707 r
F P
0 g
s
.55363 .74728 m .54874 .24489 L .5875 .25065 L p .707 .577 .707 r
F P
0 g
s
.24626 .73495 m .24344 .71635 L .27495 .7112 L p .707 .577 .707 r
F P
0 g
s
.66878 .6632 m .67568 .62759 L .65512 .61589 L p .707 .577 .707 r
F P
0 g
s
.672 .66606 m .68456 .61337 L .66424 .60056 L p .707 .577 .707 r
F P
0 g
s
.80145 .64098 m .7889 .69366 L .81258 .69125 L p .707 .577 .707 r
F P
0 g
s
.81258 .69125 m .82513 .63856 L .80145 .64098 L p .707 .577 .707 r
F P
0 g
s
.23631 .71285 m .22941 .74847 L .20042 .74768 L p .707 .577 .707 r
F P
0 g
s
.29827 .72504 m .29137 .76065 L .26075 .75294 L p .707 .577 .707 r
F P
0 g
s
.27495 .7112 m .27777 .7298 L .24626 .73495 L p .707 .577 .707 r
F P
0 g
s
.26075 .75294 m .26765 .71732 L .29827 .72504 L p .707 .577 .707 r
F P
0 g
s
.22941 .74847 m .23631 .71285 L .26765 .71732 L p .707 .577 .707 r
F P
0 g
s
.4232 .7516 m .41832 .24921 L .45979 .24413 L p .707 .577 .707 r
F P
0 g
s
.41832 .24921 m .4232 .7516 L .38925 .75977 L p .707 .577 .707 r
F P
0 g
s
.26765 .71732 m .26075 .75294 L .22941 .74847 L p .707 .577 .707 r
F P
0 g
s
.79353 .65076 m .78663 .68638 L .81043 .6834 L p .707 .577 .707 r
F P
0 g
s
.81043 .6834 m .81733 .64779 L .79353 .65076 L p .707 .577 .707 r
F P
0 g
s
.54874 .24489 m .55363 .74728 L .50963 .74503 L p .707 .577 .707 r
F P
0 g
s
.50963 .74503 m .50474 .24264 L .54874 .24489 L p .707 .577 .707 r
F P
0 g
s
.65512 .61589 m .64823 .6515 L .66878 .6632 L p .707 .577 .707 r
F P
0 g
s
.66424 .60056 m .65168 .65325 L .672 .66606 L p .707 .577 .707 r
F P
0 g
s
.64823 .6515 m .65512 .61589 L .64293 .60384 L p .707 .577 .707 r
F P
0 g
s
.65168 .65325 m .66424 .60056 L .65223 .58764 L p .707 .577 .707 r
F P
0 g
s
.7437 .79209 m .74088 .77349 L .71007 .77644 L p .707 .577 .707 r
F P
0 g
s
.74088 .77349 m .7437 .79209 L .7752 .78694 L p .707 .577 .707 r
F P
0 g
s
.7752 .78694 m .77238 .76835 L .74088 .77349 L p .707 .577 .707 r
F P
0 g
s
.82513 .63856 m .81258 .69125 L .82882 .685 L p .707 .577 .707 r
F P
0 g
s
.82882 .685 m .84137 .63231 L .82513 .63856 L p .707 .577 .707 r
F P
0 g
s
.77238 .76835 m .7752 .78694 L .80432 .7801 L p .707 .577 .707 r
F P
0 g
s
.80432 .7801 m .8015 .7615 L .77238 .76835 L p .707 .577 .707 r
F P
0 g
s
.46468 .74652 m .45979 .24413 L .50474 .24264 L p .707 .577 .707 r
F P
0 g
s
.45979 .24413 m .46468 .74652 L .4232 .7516 L p .707 .577 .707 r
F P
0 g
s
.71007 .77644 m .71289 .79504 L .7437 .79209 L p .707 .577 .707 r
F P
0 g
s
.50474 .24264 m .50963 .74503 L .46468 .74652 L p .707 .577 .707 r
F P
0 g
s
.81733 .64779 m .81043 .6834 L .82672 .67696 L p .707 .577 .707 r
F P
0 g
s
.82672 .67696 m .83361 .64134 L .81733 .64779 L p .707 .577 .707 r
F P
0 g
s
.71289 .79504 m .71007 .77644 L .68298 .77689 L p .707 .577 .707 r
F P
0 g
s
.68298 .77689 m .6858 .79549 L .71289 .79504 L p .707 .577 .707 r
F P
0 g
s
.8015 .7615 m .80432 .7801 L .8282 .77222 L p .707 .577 .707 r
F P
0 g
s
.8282 .77222 m .82538 .75362 L .8015 .7615 L p .707 .577 .707 r
F P
0 g
s
.64293 .60384 m .63603 .63946 L .64823 .6515 L p .707 .577 .707 r
F P
0 g
s
.65223 .58764 m .63968 .64033 L .65168 .65325 L p .707 .577 .707 r
F P
0 g
s
.6858 .79549 m .68298 .77689 L .66226 .77481 L p .707 .577 .707 r
F P
0 g
s
.63968 .64033 m .65223 .58764 L .64971 .57586 L p .707 .577 .707 r
F P
0 g
s
.84137 .63231 m .82882 .685 L .83603 .67552 L p .707 .577 .707 r
F P
0 g
s
.83603 .67552 m .84858 .62283 L .84137 .63231 L p .707 .577 .707 r
F P
0 g
s
.66226 .77481 m .66508 .79341 L .6858 .79549 L p .707 .577 .707 r
F P
0 g
s
.82538 .75362 m .8282 .77222 L .84451 .76408 L p .707 .577 .707 r
F P
0 g
s
.84451 .76408 m .84169 .74549 L .82538 .75362 L p .707 .577 .707 r
F P
0 g
s
.83361 .64134 m .82672 .67696 L .83389 .66767 L p .707 .577 .707 r
F P
0 g
s
.83389 .66767 m .84078 .63206 L .83361 .64134 L p .707 .577 .707 r
F P
0 g
s
.63603 .63946 m .64293 .60384 L .64028 .59262 L p .707 .577 .707 r
F P
0 g
s
.64971 .57586 m .63715 .62855 L .63968 .64033 L p .707 .577 .707 r
F P
0 g
s
.64028 .59262 m .63339 .62824 L .63603 .63946 L p .707 .577 .707 r
F P
0 g
s
.66508 .79341 m .66226 .77481 L .64993 .77039 L p .707 .577 .707 r
F P
0 g
s
.64993 .77039 m .65275 .78899 L .66508 .79341 L p .707 .577 .707 r
F P
0 g
s
.63715 .62855 m .64971 .57586 L .65692 .56638 L p .707 .577 .707 r
F P
0 g
s
.84078 .63206 m .83389 .66767 L .83124 .65646 L p .707 .577 .707 r
F P
0 g
s
.84858 .62283 m .83603 .67552 L .83351 .66374 L p .707 .577 .707 r
F P
0 g
s
.83351 .66374 m .84606 .61105 L .84858 .62283 L p .707 .577 .707 r
F P
0 g
s
.84169 .74549 m .84451 .76408 L .85166 .75649 L p .707 .577 .707 r
F P
0 g
s
.85166 .75649 m .84883 .73789 L .84169 .74549 L p .707 .577 .707 r
F P
0 g
s
.83124 .65646 m .83814 .62084 L .84078 .63206 L p .707 .577 .707 r
F P
0 g
s
.63339 .62824 m .64028 .59262 L .64745 .58334 L p .707 .577 .707 r
F P
0 g
s
.65692 .56638 m .64437 .61907 L .63715 .62855 L p .707 .577 .707 r
F P
0 g
s
.64745 .58334 m .64056 .61896 L .63339 .62824 L p .707 .577 .707 r
F P
0 g
s
.65275 .78899 m .64993 .77039 L .6472 .76408 L p .707 .577 .707 r
F P
0 g
s
.38599 .60345 m .39854 .55076 L .36819 .54182 L p .707 .577 .707 r
F P
0 g
s
.39854 .55076 m .38599 .60345 L .41709 .60902 L p .707 .577 .707 r
F P
0 g
s
.41709 .60902 m .42964 .55633 L .39854 .55076 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6472 .76408 m .65002 .78268 L .65275 .78899 L p .707 .577 .707 r
F P
0 g
s
.35563 .59451 m .36819 .54182 L .34155 .53039 L p .707 .577 .707 r
F P
0 g
s
.36819 .54182 m .35563 .59451 L .38599 .60345 L p .707 .577 .707 r
F P
0 g
s
.42964 .55633 m .41709 .60902 L .44589 .61068 L p .707 .577 .707 r
F P
0 g
s
.44589 .61068 m .45844 .55799 L .42964 .55633 L p .707 .577 .707 r
F P
0 g
s
.64437 .61907 m .65692 .56638 L .67316 .56013 L p .707 .577 .707 r
F P
0 g
s
.83814 .62084 m .83124 .65646 L .81905 .64441 L p .707 .577 .707 r
F P
0 g
s
.84606 .61105 m .83351 .66374 L .8215 .65081 L p .707 .577 .707 r
F P
0 g
s
.81905 .64441 m .82594 .60879 L .83814 .62084 L p .707 .577 .707 r
F P
0 g
s
.8215 .65081 m .83405 .59813 L .84606 .61105 L p .707 .577 .707 r
F P
0 g
s
.84883 .73789 m .85166 .75649 L .84893 .75017 L p .707 .577 .707 r
F P
0 g
s
.84893 .75017 m .84611 .73157 L .84883 .73789 L p .707 .577 .707 r
F P
0 g
s
.64056 .61896 m .64745 .58334 L .66374 .57689 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32899 .58308 m .34155 .53039 L .32123 .51758 L p .707 .577 .707 r
F P
0 g
s
.34155 .53039 m .32899 .58308 L .35563 .59451 L p .707 .577 .707 r
F P
0 g
s
.45844 .55799 m .44589 .61068 L .46957 .60827 L p .707 .577 .707 r
F P
0 g
s
.46957 .60827 m .48212 .55558 L .45844 .55799 L p .707 .577 .707 r
F P
0 g
s
.67316 .56013 m .66061 .61282 L .64437 .61907 L p .707 .577 .707 r
F P
0 g
s
.66374 .57689 m .65684 .61251 L .64056 .61896 L p .707 .577 .707 r
F P
0 g
s
.65002 .78268 m .6472 .76408 L .65434 .75648 L p .707 .577 .707 r
F P
0 g
s
.40069 .68278 m .39787 .66419 L .36706 .66713 L p .707 .577 .707 r
F P
0 g
s
.39787 .66419 m .40069 .68278 L .43219 .67764 L p .707 .577 .707 r
F P
0 g
s
.43219 .67764 m .42937 .65904 L .39787 .66419 L p .707 .577 .707 r
F P
0 g
s
.66061 .61282 m .67316 .56013 L .69684 .55772 L p .707 .577 .707 r
F P
0 g
s
.82594 .60879 m .81905 .64441 L .79849 .63271 L p .707 .577 .707 r
F P
0 g
s
.79849 .63271 m .80539 .59709 L .82594 .60879 L p .707 .577 .707 r
F P
0 g
s
.83405 .59813 m .8215 .65081 L .80118 .63801 L p .707 .577 .707 r
F P
0 g
s
.80118 .63801 m .81373 .58532 L .83405 .59813 L p .707 .577 .707 r
F P
0 g
s
.65434 .75648 m .65717 .77508 L .65002 .78268 L p .707 .577 .707 r
F P
0 g
s
.42937 .65904 m .43219 .67764 L .46131 .67079 L p .707 .577 .707 r
F P
0 g
s
.46131 .67079 m .45849 .65219 L .42937 .65904 L p .707 .577 .707 r
F P
0 g
s
.36706 .66713 m .36988 .68573 L .40069 .68278 L p .707 .577 .707 r
F P
0 g
s
.32123 .51758 m .30867 .57027 L .32899 .58308 L p .707 .577 .707 r
F P
0 g
s
.30867 .57027 m .32123 .51758 L .30922 .50466 L p .707 .577 .707 r
F P
0 g
s
.36988 .68573 m .36706 .66713 L .33997 .66758 L p .707 .577 .707 r
F P
0 g
s
.48212 .55558 m .46957 .60827 L .48581 .60202 L p .707 .577 .707 r
F P
0 g
s
.48581 .60202 m .49836 .54933 L .48212 .55558 L p .707 .577 .707 r
F P
0 g
s
.84611 .73157 m .84893 .75017 L .8366 .74576 L p .707 .577 .707 r
F P
0 g
s
.8366 .74576 m .83378 .72716 L .84611 .73157 L p .707 .577 .707 r
F P
0 g
s
.69684 .55772 m .68428 .6104 L .66061 .61282 L p .707 .577 .707 r
F P
0 g
s
.65684 .61251 m .66374 .57689 L .68754 .57392 L p .707 .577 .707 r
F P
0 g
s
.365 .68527 m .35958 .68391 L p .36495 .69372 L .707 .577 .707 r
F P
0 g
s
.35268 .71952 m .35958 .68391 L .33267 .6737 L p .707 .577 .707 r
F P
0 g
s
.35958 .68391 m .35268 .71952 L .3833 .72724 L p .707 .577 .707 r
F P
0 g
s
.33997 .66758 m .34279 .68618 L .365 .68581 L p .707 .577 .707 r
F P
0 g
s
.365 .68581 m .36988 .68573 L p .36502 .68278 L .707 .577 .707 r
F P
0 g
s
.36502 .68278 m .33997 .66758 L .365 .68581 L .707 .577 .707 r
F
.3833 .72724 m .3902 .69162 L .365 .68527 L p F P
0 g
s
.3833 .72724 m .365 .68527 L .36495 .69372 L .707 .577 .707 r
F
.3902 .69162 m .3833 .72724 L .41464 .73171 L p F P
0 g
s
.41464 .73171 m .42154 .69609 L .3902 .69162 L p .707 .577 .707 r
F P
0 g
s
.45849 .65219 m .46131 .67079 L .48519 .66291 L p .707 .577 .707 r
F P
0 g
s
.48519 .66291 m .48237 .64431 L .45849 .65219 L p .707 .577 .707 r
F P
0 g
s
.42154 .69609 m .41464 .73171 L .44362 .73249 L p .707 .577 .707 r
F P
0 g
s
.44362 .73249 m .45052 .69688 L .42154 .69609 L p .707 .577 .707 r
F P
0 g
s
.68428 .6104 m .69684 .55772 L .72564 .55938 L p .707 .577 .707 r
F P
0 g
s
.68754 .57392 m .68064 .60953 L .65684 .61251 L p .707 .577 .707 r
F P
0 g
s
.80539 .59709 m .79849 .63271 L .77329 .62315 L p .707 .577 .707 r
F P
0 g
s
.77267 .62603 m .74418 .61764 L p .78296 .5781 L .707 .577 .707 r
F P
0 g
s
.77329 .62315 m .77158 .6225 L p .77379 .62085 L .707 .577 .707 r
F P
0 g
s
.77379 .62085 m .80539 .59709 L .77329 .62315 L .707 .577 .707 r
F
.77158 .6225 m .77848 .58689 L .80539 .59709 L p F P
0 g
s
.78709 .57389 m .77454 .62658 L .77267 .62603 L p .707 .577 .707 r
F P
0 g
s
.78296 .5781 m .78709 .57389 L .77267 .62603 L .707 .577 .707 r
F
.81373 .58532 m .80118 .63801 L .77454 .62658 L p F P
0 g
s
.77454 .62658 m .78709 .57389 L .81373 .58532 L p .707 .577 .707 r
F P
0 g
s
.33267 .6737 m .32577 .70932 L .35268 .71952 L p .707 .577 .707 r
F P
0 g
s
.32577 .70932 m .33267 .6737 L .31211 .662 L p .707 .577 .707 r
F P
0 g
s
.34279 .68618 m .33997 .66758 L .31925 .6655 L p .707 .577 .707 r
F P
0 g
s
.30922 .50466 m .29667 .55735 L .30867 .57027 L p .707 .577 .707 r
F P
0 g
s
.65717 .77508 m .65434 .75648 L .67066 .74835 L p .707 .577 .707 r
F P
0 g
s
.45052 .69688 m .44362 .73249 L .46742 .72952 L p .707 .577 .707 r
F P
0 g
s
.46742 .72952 m .47432 .6939 L .45052 .69688 L p .707 .577 .707 r
F P
0 g
s
.31925 .6655 m .32207 .6841 L .34279 .68618 L p .707 .577 .707 r
F P
0 g
s
.72564 .55938 m .71308 .61206 L .68428 .6104 L p .707 .577 .707 r
F P
0 g
s
.68064 .60953 m .68754 .57392 L .71652 .5747 L p .707 .577 .707 r
F P
0 g
s
.67066 .74835 m .67348 .76694 L .65717 .77508 L p .707 .577 .707 r
F P
0 g
s
.48237 .64431 m .48519 .66291 L .5015 .65478 L p .707 .577 .707 r
F P
0 g
s
.5015 .65478 m .49868 .63618 L .48237 .64431 L p .707 .577 .707 r
F P
0 g
s
.29667 .55735 m .30922 .50466 L .3067 .49288 L p .707 .577 .707 r
F P
0 g
s
.49836 .54933 m .48581 .60202 L .49302 .59254 L p .707 .577 .707 r
F P
0 g
s
.49302 .59254 m .50557 .53985 L .49836 .54933 L p .707 .577 .707 r
F P
0 g
s
.71308 .61206 m .72564 .55938 L .75674 .56495 L p .707 .577 .707 r
F P
0 g
s
.74418 .61764 m .75674 .56495 L .78709 .57389 L p .707 .577 .707 r
F P
0 g
s
.83378 .72716 m .8366 .74576 L .81588 .74367 L p .707 .577 .707 r
F P
0 g
s
.81588 .74367 m .81306 .72508 L .83378 .72716 L p .707 .577 .707 r
F P
0 g
s
.75674 .56495 m .74418 .61764 L .71308 .61206 L p .707 .577 .707 r
F P
0 g
s
.31211 .662 m .30522 .69762 L .32577 .70932 L p .707 .577 .707 r
F P
0 g
s
.71652 .5747 m .70962 .61032 L .68064 .60953 L p .707 .577 .707 r
F P
0 g
s
.77848 .58689 m .77158 .6225 L .74096 .61479 L p .707 .577 .707 r
F P
0 g
s
.74096 .61479 m .74786 .57917 L .77848 .58689 L p .707 .577 .707 r
F P
0 g
s
.70962 .61032 m .71652 .5747 L .74786 .57917 L p .707 .577 .707 r
F P
0 g
s
.74786 .57917 m .74096 .61479 L .70962 .61032 L p .707 .577 .707 r
F P
0 g
s
.30522 .69762 m .31211 .662 L .29992 .64995 L p .707 .577 .707 r
F P
0 g
s
.32207 .6841 m .31925 .6655 L .30692 .66109 L p .707 .577 .707 r
F P
0 g
s
.47432 .6939 m .46742 .72952 L .48371 .72307 L p .707 .577 .707 r
F P
0 g
s
.48371 .72307 m .4906 .68745 L .47432 .6939 L p .707 .577 .707 r
F P
0 g
s
.30692 .66109 m .30974 .67968 L .32207 .6841 L p .707 .577 .707 r
F P
0 g
s
.3067 .49288 m .29414 .54557 L .29667 .55735 L p .707 .577 .707 r
F P
0 g
s
.67348 .76694 m .67066 .74835 L .69454 .74047 L p .707 .577 .707 r
F P
0 g
s
.69454 .74047 m .69736 .75907 L .67348 .76694 L p .707 .577 .707 r
F P
0 g
s
.49868 .63618 m .5015 .65478 L .50865 .64718 L p .707 .577 .707 r
F P
0 g
s
.50865 .64718 m .50582 .62858 L .49868 .63618 L p .707 .577 .707 r
F P
0 g
s
.81306 .72508 m .81588 .74367 L .78879 .74413 L p .707 .577 .707 r
F P
0 g
s
.78879 .74413 m .78597 .72553 L .81306 .72508 L p .707 .577 .707 r
F P
0 g
s
.29414 .54557 m .3067 .49288 L .31391 .4834 L p .707 .577 .707 r
F P
0 g
s
.29992 .64995 m .29302 .68557 L .30522 .69762 L p .707 .577 .707 r
F P
0 g
s
.50557 .53985 m .49302 .59254 L .4905 .58076 L p .707 .577 .707 r
F P
0 g
s
.4905 .58076 m .50305 .52807 L .50557 .53985 L p .707 .577 .707 r
F P
0 g
s
.69736 .75907 m .69454 .74047 L .72366 .73362 L p .707 .577 .707 r
F P
0 g
s
.4906 .68745 m .48371 .72307 L .49088 .71379 L p .707 .577 .707 r
F P
0 g
s
.49088 .71379 m .49777 .67817 L .4906 .68745 L p .707 .577 .707 r
F P
0 g
s
.72366 .73362 m .72648 .75222 L .69736 .75907 L p .707 .577 .707 r
F P
0 g
s
.29302 .68557 m .29992 .64995 L .29727 .63874 L p .707 .577 .707 r
F P
0 g
s
.30974 .67968 m .30692 .66109 L .30419 .65477 L p .707 .577 .707 r
F P
0 g
s
.78597 .72553 m .78879 .74413 L .75798 .74707 L p .707 .577 .707 r
F P
0 g
s
.75798 .74707 m .75516 .72847 L .78597 .72553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30419 .65477 m .30701 .67337 L .30974 .67968 L p .707 .577 .707 r
F P
0 g
s
.31391 .4834 m .30136 .53609 L .29414 .54557 L p .707 .577 .707 r
F P
0 g
s
.72648 .75222 m .72366 .73362 L .75516 .72847 L p .707 .577 .707 r
F P
0 g
s
.75516 .72847 m .75798 .74707 L .72648 .75222 L p .707 .577 .707 r
F P
0 g
s
.50582 .62858 m .50865 .64718 L .50592 .64086 L p .707 .577 .707 r
F P
0 g
s
.50592 .64086 m .5031 .62227 L .50582 .62858 L p .707 .577 .707 r
F P
0 g
s
.29727 .63874 m .29038 .67435 L .29302 .68557 L p .707 .577 .707 r
F P
0 g
s
.30136 .53609 m .31391 .4834 L .33015 .47715 L p .707 .577 .707 r
F P
0 g
s
.50305 .52807 m .4905 .58076 L .47849 .56783 L p .707 .577 .707 r
F P
0 g
s
.47849 .56783 m .49104 .51515 L .50305 .52807 L p .707 .577 .707 r
F P
0 g
s
.49777 .67817 m .49088 .71379 L .48823 .70257 L p .707 .577 .707 r
F P
0 g
s
.48823 .70257 m .49513 .66695 L .49777 .67817 L p .707 .577 .707 r
F P
0 g
s
.29038 .67435 m .29727 .63874 L .30444 .62945 L p .707 .577 .707 r
F P
0 g
s
.30701 .67337 m .30419 .65477 L .31133 .64717 L p .707 .577 .707 r
F P
0 g
s
.33015 .47715 m .3176 .52984 L .30136 .53609 L p .707 .577 .707 r
F P
0 g
s
.31133 .64717 m .31415 .66577 L .30701 .67337 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3176 .52984 m .33015 .47715 L .35383 .47474 L p .707 .577 .707 r
F P
0 g
s
.5031 .62227 m .50592 .64086 L .49359 .63645 L p .707 .577 .707 r
F P
0 g
s
.49359 .63645 m .49077 .61785 L .5031 .62227 L p .707 .577 .707 r
F P
0 g
s
.30444 .62945 m .29755 .66507 L .29038 .67435 L p .707 .577 .707 r
F P
0 g
s
.49104 .51515 m .47849 .56783 L .45817 .55503 L p .707 .577 .707 r
F P
0 g
s
.45817 .55503 m .47072 .50234 L .49104 .51515 L p .707 .577 .707 r
F P
0 g
s
.49513 .66695 m .48823 .70257 L .47604 .69052 L p .707 .577 .707 r
F P
0 g
s
.47604 .69052 m .48293 .65491 L .49513 .66695 L p .707 .577 .707 r
F P
0 g
s
.29755 .66507 m .30444 .62945 L .32073 .623 L p .707 .577 .707 r
F P
0 g
s
.31415 .66577 m .31133 .64717 L .32764 .63904 L p .707 .577 .707 r
F P
0 g
s
.35383 .47474 m .34127 .52742 L .3176 .52984 L p .707 .577 .707 r
F P
0 g
s
.34127 .52742 m .35383 .47474 L .38263 .4764 L p .707 .577 .707 r
F P
0 g
s
.47072 .50234 m .45817 .55503 L .43153 .5436 L p .707 .577 .707 r
F P
0 g
s
.43153 .5436 m .44408 .49091 L .47072 .50234 L p .707 .577 .707 r
F P
0 g
s
.32764 .63904 m .33047 .65764 L .31415 .66577 L p .707 .577 .707 r
F P
0 g
s
.49077 .61785 m .49359 .63645 L .47287 .63437 L p .707 .577 .707 r
F P
0 g
s
.47287 .63437 m .47004 .61577 L .49077 .61785 L p .707 .577 .707 r
F P
0 g
s
.32073 .623 m .31383 .65862 L .29755 .66507 L p .707 .577 .707 r
F P
0 g
s
.37007 .52908 m .38263 .4764 L .41372 .48197 L p .707 .577 .707 r
F P
0 g
s
.38263 .4764 m .37007 .52908 L .34127 .52742 L p .707 .577 .707 r
F P
0 g
s
.44408 .49091 m .43153 .5436 L .40117 .53466 L p .707 .577 .707 r
F P
0 g
s
.40117 .53466 m .41372 .48197 L .44408 .49091 L p .707 .577 .707 r
F P
0 g
s
.41372 .48197 m .40117 .53466 L .37007 .52908 L p .707 .577 .707 r
F P
0 g
s
.48293 .65491 m .47604 .69052 L .45548 .67882 L p .707 .577 .707 r
F P
0 g
s
.45548 .67882 m .46238 .64321 L .48293 .65491 L p .707 .577 .707 r
F P
0 g
s
.33047 .65764 m .32764 .63904 L .35153 .63116 L p .707 .577 .707 r
F P
0 g
s
.31383 .65862 m .32073 .623 L .34453 .62003 L p .707 .577 .707 r
F P
0 g
s
.35153 .63116 m .35435 .64976 L .33047 .65764 L p .707 .577 .707 r
F P
0 g
s
.47004 .61577 m .47287 .63437 L .44578 .63482 L p .707 .577 .707 r
F P
0 g
s
.44578 .63482 m .44295 .61622 L .47004 .61577 L p .707 .577 .707 r
F P
0 g
s
.34453 .62003 m .33763 .65564 L .31383 .65862 L p .707 .577 .707 r
F P
0 g
s
.46238 .64321 m .45548 .67882 L .42857 .66861 L p .707 .577 .707 r
F P
0 g
s
.44024 .63481 m .46238 .64321 L p .43953 .66038 L .707 .577 .707 r
F P
0 g
s
.44295 .61622 m .44578 .63482 L .44022 .63535 L p .707 .577 .707 r
F P
0 g
s
.44022 .63535 m .41497 .63776 L p .44071 .61795 L .707 .577 .707 r
F P
0 g
s
.44071 .61795 m .44295 .61622 L .44022 .63535 L .707 .577 .707 r
F
.42857 .66861 m .43547 .633 L .44024 .63481 L p F P
0 g
s
.42857 .66861 m .44024 .63481 L .43953 .66038 L .707 .577 .707 r
F
.35435 .64976 m .35153 .63116 L .38065 .62431 L p F P
0 g
s
.33763 .65564 m .34453 .62003 L .37351 .62081 L p .707 .577 .707 r
F P
0 g
s
.38065 .62431 m .38347 .64291 L .35435 .64976 L p .707 .577 .707 r
F P
0 g
s
.41497 .63776 m .41215 .61916 L .44295 .61622 L p .707 .577 .707 r
F P
0 g
s
.38347 .64291 m .38065 .62431 L .41215 .61916 L p .707 .577 .707 r
F P
0 g
s
.37351 .62081 m .36661 .65643 L .33763 .65564 L p .707 .577 .707 r
F P
0 g
s
.43547 .633 m .42857 .66861 L .39795 .6609 L p .707 .577 .707 r
F P
0 g
s
.41215 .61916 m .41497 .63776 L .38347 .64291 L p .707 .577 .707 r
F P
0 g
s
.39795 .6609 m .40485 .62528 L .43547 .633 L p .707 .577 .707 r
F P
0 g
s
.36661 .65643 m .37351 .62081 L .40485 .62528 L p .707 .577 .707 r
F P
0 g
s
.40485 .62528 m .39795 .6609 L .36661 .65643 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001eOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol0
079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007Ao
o`00Kgoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01000L7oo001/Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001]Ool006Yoo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00
J7oo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001VOol20005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001TOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005eooa8000QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo0`001UYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001IOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005Qoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00F7oo00D005YFFUIJEP0000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Egoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00H005YF0000
05YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Ioo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001FOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00EGoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001VOol005Eo
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00EGoo00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo
00<005YFFUH00UYF4`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Ao
o`800005FUH00000FUH00006FUH40002FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00E7oo00=JEP0000000eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00EJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP8000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00IJEPD000MJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH01P00
FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00<0
05YFFUH015YF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00@000UJEP8000IJEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH=0004FUH02000FUIJEP00FUH0
05YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool7001COol005Eo
o`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001goo1@000eYF00@005YFFUIJEPT004Yoo`00EGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP05001J
EP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60014Ool003Iooa8000ioo`8000IJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000@Woo000dOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20002FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000oOol0039oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000Moo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP800004FUH005YF0002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<0
05YF00003`001UYF00<005YFFUH01EYF0`00?7oo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP040005Ool200000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00001JEPD000=JEP03
001JEUYF00EJEP03001JEUYF009JEPL000QJEP04001JEP00000jOol0035oo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004Ool20008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800006Ool00000001J
EP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YFFUIJEP<003Mo
o`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0`0017oo0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0
00MJEP8003Eoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH20008FUH3000cOol002moo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000MJEP05
001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001oogoo00=oo`<000MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00FUIJEP02FUH2000`Ool002moo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000=oo`03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0]Ool002moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800005Ool005YFFUH00003FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20008FUH0
0`00FUIJEP04FUH2000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF
00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP04001JEUYFFUH60008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH00eYF3P0000=J
EP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP04001JEUYF0003FUH@0004FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH50003FUH20002Ool>0008FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP0C0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02000
FUIJEUYF001JEP00FUH40006FUH01000FUH000002Goo200015YF00<005YF00001eYF00<005YFFUH0
15YF00<005YFFUH00P00;7oo000]Ool00`00FUIJEP02FUHC0006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH0000?0002FUH9000;FUH00`00FUIJEP03FUH00`00FUH00003000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00AJEP04001JEUYFFUH2
000=Ool500000eYF00000007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00;Goo0P00
00EJEP00001JEP0000IJEP8000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH015YF
10002goo1P001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000[Ool002eoo`03FUH0000000=J
EP03001JEUYF00AJEP04001JEP00000;Ool40007FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YF
FUH015YF00<005YFFUH01UYF00@005YF000000aoo`@000IJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF0000:goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00
FUIJEP020003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00eoo`8000AJEP03001JEUYF00AJEP04001JEUYF0002FUH/Ool002aoo`<000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@000eoo`<00003FUH0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEPl000=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH6
0009Ool200000eYF001JEP05FUH01`00FUIJEUYF001JEP0002aoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100037oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF
009JEPD00003FUH0000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool20006FUH0
1`00FUIJEUYF001JEP0002aoo`00;7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH015YF1@001goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0`001EYF0P0000=JEP0000000P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
100015YF00<005YFFUH01UYF00@005YFFUIJEPL000AJEP07001JEUYFFUH005YF0000;7oo000]Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010000goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
0`000UYF0P000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00AJEP03001JEUYF00]JEPL000IJEP03001JEUYF00EJEP04001JEUYF0003
FUH01P00FUIJEP00FUH002eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00=JEP03001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00eJ
EP03001JEUYF009JEPP000IJEP03001JEP0000@000=JEP03001JEP0002eoo`00;Woo00@005YFFUH0
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<000QJEP03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000IJ
EP03001JEUYF00eJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH20003FUH00`00FUH0000]Ool0
02ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50006FUH200000eYF001JEP02
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009o
o`<000AJEP03001JEUYF00aJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EP00009JEP03001JEP0002eoo`00;goo0P001UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF
0`000eYF1`0000=JEP0000000eYF00@005YFFUH000AJEPH000MJEP03001JEP0000EJEP03001JEUYF
00AJEP@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Aoo`80009JEP03001JEUYF00eJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH200000eYF001oo`0]Ool0031oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00EJEPD000IJEP04001JEP00FUH200000eYF001JEP020004FUH20002FUH01000FUIJEP0015YF2000
15YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo0`003eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH007oo02eoo`00<Goo0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF0`001eYF00L005YF000005YF001JEP0D0004FUH01000FUIJEUYF
0`0000=JEP0000001eYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000Eoo`8000iJEP03001JEP00
008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`0]Ool003=o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000MJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUH00000FUH00P001Goo0P0035YF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YF
FUH005YF001JEP00;Woo000eOol20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF001J
EUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH30004Ool200000eYF00000006FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000_Ool003Moo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP8000AJEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPP00003FUH005YF00EJEP06001JEUYF001JEP000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0P0017oo1`00
0UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000_
Ool003Uoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP<00003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEPD000MJEP8000IJEP06001JEUYF001JEP00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
25YF0`001Goo0`0000=JEP0000001P000eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF0000
05YF0080031oo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUH000=JEP03001J
EUYF00@000=JEP03001JEUYF00=JEP<000AJEPH000AJEP03001JEUYF00MJEP8000=JEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001eYF00D005YFFUIJEP0000Moo`<00003FUH005YF009JEPP000AJEP04001JEUYFFUH5
0002FUH2000aOol003eoo`<000MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH:0002FUH:0005FUH00`00FUIJEP09FUH200000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH2
0008Ool60004FUH00`00FUIJEP080003FUH01000FUH00000<goo0010Ool40002FUH00`00FUIJEP07
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0;Ool80004FUH01000FUIJ
EUYF1000=Goo0014Ool50007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH400000eYF000000070008FUH5000015YF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH015YF0P0057oo2000>Goo
0019Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJ
EP04FUH01000FUIJEP00E7oo001=Ool<0003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJ
EP05001JEUYFFUH0001COol005Uoo`800003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05001J
EUYFFUH0001COol005=oo`/000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP03001JEUYF008005=oo`00>7oo
40000Woo2@002eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001BOol003=o
o`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEP0000800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0000Ioo`<004Uoo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005Ool50018Ool002moo`8000=JEP03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF
00AJEP04001JEUYF0002FUH6Ool50018Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPl000=JEP05001JEUYF001JEP050006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001oo`800003FUH005YF00EJEP07001JEUYFFUH005YF00001Woo
1@001Woo4P00<7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP020009Ool40002FUH00`00FUIJEP03FUH50002FUH00`00
FUIJEP06FUH01000FUIJEUYF10002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000goo0P001UYF00L005YFFUIJEP00FUH00007Ool:0004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000^Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80009JEP03001JEUYF00=J
EP03001JEUYF009JEPl0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000L000AJEP07001JEUYFFUH005YF00000Woo1P0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo000]Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH20004Ool300001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00@005YFFUH000=JEP05001JEUYF001JEP0400000eYF001JEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00:goo000/Ool00`00FUH00004FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH500001EYF
001JEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YF0000100000=JEP0000000P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH017ooFUIJEP000UYF
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
000[Ool002aoo`03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH2
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000>Ool50002FUH00`00Oomoo`0YOol002aoo`80
00=JEPL000aoo`@0009JEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00=JEP03001JEUYF00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP00008000MJEP03001JEUYF00AJ
EPH001Qoo`80009JEP@002Yoo`00;7oo00=JEP00FUH00P0000=JEP00FUH00P004Woo10001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00=JEP<0
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP04001JEP00FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20004FUH01000
FUH00000:Woo000[Ool01`00FUH00000FUH005YF00@000Qooa80009JEP8000MJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF
000015YF00<005YFFUH015YF100077oo100000=JEP00FUH015YF00<005YF0000:Woo000[Ool30002
FUH2000015YF001JEUYF20000eYF00<005YFFUH01UYF00<005YFFUH00eYF10001eYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001JEP00008000EJEP04
001JEUYFFUH300000eYF001oo`0IOol30005FUH00`00FUIJEP03FUH2000[Ool002]oo`03001JEP00
009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00AJEP05001JEUYFFUH00002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP05001JEP00FUH00005FUH00`00FUH00005000GOol400000eYF001JEP06FUH01000FUIJEUYF0P00
;7oo000[Ool00`00FUH00002FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH800000eYF001JEP05FUH00`00FUIJEP020002FUH01000FUH000001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP<0009JEP04001JEP00000@Ool70005FUH00`00FUIJ
EP05FUH01000FUH00000;Woo000[Ool00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH40008Ool20006FUH00`00FUIJEP020002FUH200000eYF001JEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200001UYF001JEUYF001JEP800003FUH005YF00800003FUH0000000Qoo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00;7oo00D005YFFUIJEP00009JEP@000=J
EP03001JEUYF00=JEP03OomJEP0000AJEPH000ioo`8000=JEP04001JEUYFFUH200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000005YF500015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00<goo000/Ool01@00FUIJEUYF00001EYF5P004Goo0P0000=JEP00
FUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00=goo000]
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000COol20003FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04000jOol002ioo`8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEPL000moo`D00003FUH00000008000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEPD003ioo`00;goo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF3`000UYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF00000Woo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1000@goo000`Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000Eoo`D0009JEP03001JEUYF00EJEP03001JEUYF009JEPL004Moo`00<Woo0P0000=JEP00FUH0
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YF001oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000]oo`l004ioo`00=7oo
0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00=goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P001Woo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000006aoo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH4001^Ool003aoo`<000IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000;Ool300000eYF001JEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07001`Ool003moo`@0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000?Ool70005FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50003Ool5001_Ool004=oo`D000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEP00000HOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP06
0008Ool50006OolB001GOol004Qoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH4000VOolF000>
Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001EOol004aoo`l004Yoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008005=oo`00XGoo100000=JEP00
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00
WGoo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00DWoo002IOol400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003
FUH01@00FUIJEUYF0000DWoo002GOol20005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000>Ool5
0002FUH00`00Oomoo`1@Ool009Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00@001Moo`800003
FUH000000080055oo`00Tgoo0P000UYF00<005YFFUH01EYF00<005YFFUH015YF100067oo0`000eYF
00@005YF0000055oo`00TWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0100067oo1000
00=JEP00FUH015YF00<005YF0000DGoo002AOol20005FUH00`00FUIJEP03FUH4000IOol30005FUH0
0`00FUIJEP03FUH2001BOol0091oo`03001JEP0000EJEP03001JEP0000<001Uoo`@00003FUH005YF
00IJEP04001JEUYFFUH2001COol0091oo`04001JEUYF0003FUH3000HOol50005FUH00`00FUIJEP05
FUH01000FUH00000EGoo002@Ool01@00FUIJEP00FUH00P005goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`00Egoo002AOol00`00FUH000040007Ool?0006FUH00`00FUIJEP06FUH00`00FUH0
0003001JOol0095oo`80009JEP03001JEUYF00L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP<005ioo`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01000HGoo002AOol20003FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5001UOol0099oo`80009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006Yoo`00U7oo1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF1`00KWoo002IOol?001eOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59191 .78729 m .59619 .75096 L .59594 .75092 L p .707 .577 .707 r
F P
0 g
s
.59594 .75092 m .56523 .74544 L p .59053 .78512 L .707 .577 .707 r
F P
0 g
s
.59191 .78729 m .59594 .75092 L .59053 .78512 L .707 .577 .707 r
F
.59619 .75096 m .59191 .78729 L .62355 .78978 L p F P
0 g
s
.62355 .78978 m .62783 .75345 L .62746 .75342 L p .707 .577 .707 r
F P
0 g
s
.62746 .75342 m .59619 .75096 L p .62142 .78675 L .707 .577 .707 r
F P
0 g
s
.62355 .78978 m .62746 .75342 L .62142 .78675 L .707 .577 .707 r
F
.62783 .75345 m .62355 .78978 L .65279 .789 L p F P
0 g
s
.65279 .789 m .65707 .75267 L .65665 .75268 L p .707 .577 .707 r
F P
0 g
s
.65665 .75268 m .62783 .75345 L p .65039 .78558 L .707 .577 .707 r
F P
0 g
s
.65279 .789 m .65665 .75268 L .65039 .78558 L .707 .577 .707 r
F
.65707 .75267 m .65279 .789 L .67674 .78501 L p F P
0 g
s
.67674 .78501 m .68102 .74868 L .68065 .74874 L p .707 .577 .707 r
F P
0 g
s
.68065 .74874 m .65707 .75267 L p .67467 .78161 L .707 .577 .707 r
F P
0 g
s
.67674 .78501 m .68065 .74874 L .67467 .78161 L .707 .577 .707 r
F
.68102 .74868 m .67674 .78501 L .69308 .77822 L p F P
0 g
s
.69308 .77822 m .69736 .74189 L .69711 .74199 L p .707 .577 .707 r
F P
0 g
s
.69711 .74199 m .68102 .74868 L p .69181 .77512 L .707 .577 .707 r
F P
0 g
s
.69308 .77822 m .69711 .74199 L .69181 .77512 L .707 .577 .707 r
F
.69736 .74189 m .69308 .77822 L .70019 .76928 L p F P
0 g
s
.70019 .76928 m .70447 .73295 L .70437 .73307 L p .707 .577 .707 r
F P
0 g
s
.70437 .73307 m .69736 .74189 L p .69992 .76666 L .707 .577 .707 r
F P
0 g
s
.70019 .76928 m .70437 .73307 L .69992 .76666 L .707 .577 .707 r
F
.69456 .76028 m .70169 .75122 L p .70232 .70942 L F P
0 g
s
.70169 .75122 m .70513 .72738 L p .70236 .70613 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .7095 .69707 L .70896 .69776 L p .707 .577 .707 r
F P
0 g
s
.70896 .69776 m .70236 .70613 L p .70513 .72738 L .707 .577 .707 r
F P
0 g
s
.70447 .73295 m .70019 .76928 L .69987 .7681 L p .707 .577 .707 r
F P
0 g
s
.70169 .75122 m .69894 .74066 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .70169 .75122 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.69987 .7681 m .69739 .75907 L p .70435 .7334 L .707 .577 .707 r
F P
0 g
s
.70435 .7334 m .70447 .73295 L .69987 .7681 L .707 .577 .707 r
F
.7095 .69707 m .70513 .72738 L p .70872 .70026 L F P
0 g
s
.70236 .70613 m .69801 .73638 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.69801 .73638 m .69456 .76028 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .69456 .76028 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68604 .7128 m .68168 .74311 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68168 .74311 m .67824 .76696 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .67824 .76696 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.66214 .71643 m .65774 .74692 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.65774 .74692 m .65433 .77058 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .65433 .77058 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.63298 .71666 m .62854 .74742 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.62854 .74742 m .62517 .77082 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .62517 .77082 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.60142 .71347 m .59694 .74458 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59694 .74458 m .59362 .76763 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .60142 .71347 L .57056 .70718 L p .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .63298 .71666 L .60142 .71347 L p .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .66214 .71643 L .63298 .71666 L p .707 .577 .707 r
F P
0 g
s
.56276 .76133 m .57056 .70718 L .54342 .69839 L p .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56523 .74544 L .56515 .74542 L p .707 .577 .707 r
F P
0 g
s
.56603 .73867 m .56276 .76133 L .56307 .76139 L p .707 .577 .707 r
F P
0 g
s
.54342 .69839 m .53562 .75254 L .56276 .76133 L p .707 .577 .707 r
F P
0 g
s
.56515 .74542 m .53798 .73742 L p .56052 .78095 L .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56515 .74542 L .56052 .78095 L .707 .577 .707 r
F
.57056 .70718 m .56603 .73867 L p .59362 .76763 L F P
0 g
s
.56523 .74544 m .56095 .78177 L .59191 .78729 L p .707 .577 .707 r
F P
0 g
s
.56307 .76139 m .59362 .76763 L p .56603 .73867 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .68604 .7128 L .66214 .71643 L p .707 .577 .707 r
F P
0 g
s
.53562 .75254 m .54342 .69839 L .52265 .68797 L p .707 .577 .707 r
F P
0 g
s
.53798 .73742 m .5337 .77375 L .56095 .78177 L p .707 .577 .707 r
F P
0 g
s
.52265 .68797 m .51484 .74212 L .53562 .75254 L p .707 .577 .707 r
F P
0 g
s
.5337 .77375 m .53798 .73742 L .51712 .7277 L p .707 .577 .707 r
F P
0 g
s
.69456 .76028 m .70236 .70613 L .68604 .7128 L p .707 .577 .707 r
F P
0 g
s
.60262 .87177 m .60087 .85314 L .56984 .85424 L p .707 .577 .707 r
F P
0 g
s
.60087 .85314 m .60262 .87177 L .63433 .86829 L p .707 .577 .707 r
F P
0 g
s
.63433 .86829 m .63258 .84967 L .60087 .85314 L p .707 .577 .707 r
F P
0 g
s
.63258 .84967 m .63433 .86829 L .66361 .86277 L p .707 .577 .707 r
F P
0 g
s
.66361 .86277 m .66186 .84414 L .63258 .84967 L p .707 .577 .707 r
F P
0 g
s
.51484 .74212 m .52265 .68797 L .51028 .67694 L p .707 .577 .707 r
F P
0 g
s
.56984 .85424 m .57159 .87286 L .60262 .87177 L p .707 .577 .707 r
F P
0 g
s
.51712 .7277 m .51284 .76403 L .5337 .77375 L p .707 .577 .707 r
F P
0 g
s
.57159 .87286 m .56984 .85424 L .54253 .85284 L p .707 .577 .707 r
F P
0 g
s
.54253 .85284 m .54427 .87146 L .57159 .87286 L p .707 .577 .707 r
F P
0 g
s
.66186 .84414 m .66361 .86277 L .6876 .85574 L p .707 .577 .707 r
F P
0 g
s
.6876 .85574 m .68585 .83712 L .66186 .84414 L p .707 .577 .707 r
F P
0 g
s
.51028 .67694 m .50247 .73109 L .51484 .74212 L p .707 .577 .707 r
F P
0 g
s
.51284 .76403 m .51712 .7277 L .50468 .71723 L p .707 .577 .707 r
F P
0 g
s
.54427 .87146 m .54253 .85284 L .5216 .84908 L p .707 .577 .707 r
F P
0 g
s
.50468 .71723 m .5004 .75355 L .51284 .76403 L p .707 .577 .707 r
F P
0 g
s
.5216 .84908 m .52335 .86771 L .54427 .87146 L p .707 .577 .707 r
F P
0 g
s
.50247 .73109 m .51028 .67694 L .50752 .66637 L p .707 .577 .707 r
F P
0 g
s
.68585 .83712 m .6876 .85574 L .70395 .8479 L p .707 .577 .707 r
F P
0 g
s
.70395 .8479 m .7022 .82928 L .68585 .83712 L p .707 .577 .707 r
F P
0 g
s
.50752 .66637 m .49972 .72052 L .50247 .73109 L p .707 .577 .707 r
F P
0 g
s
.5004 .75355 m .50468 .71723 L .50188 .70702 L p .707 .577 .707 r
F P
0 g
s
.52335 .86771 m .5216 .84908 L .50911 .84334 L p .707 .577 .707 r
F P
0 g
s
.50911 .84334 m .51085 .86197 L .52335 .86771 L p .707 .577 .707 r
F P
0 g
s
.69894 .74066 m .70235 .71699 L p .7095 .69707 L .707 .577 .707 r
F P
0 g
s
.70674 .68651 m .69894 .74066 L .68657 .72963 L p .707 .577 .707 r
F P
0 g
s
.70167 .72274 m .69739 .75907 L .69609 .75797 L p .707 .577 .707 r
F P
0 g
s
.69609 .75797 m .68495 .74859 L p .70141 .72315 L .707 .577 .707 r
F P
0 g
s
.70141 .72315 m .70167 .72274 L .69609 .75797 L .707 .577 .707 r
F
.70235 .71699 m .70674 .68651 L .70691 .68715 L p F P
0 g
s
.70691 .68715 m .7095 .69707 L p .70235 .71699 L .707 .577 .707 r
F P
0 g
s
.50188 .70702 m .4976 .74335 L .5004 .75355 L p .707 .577 .707 r
F P
0 g
s
.7022 .82928 m .70395 .8479 L .71105 .84001 L p .707 .577 .707 r
F P
0 g
s
.71105 .84001 m .7093 .82139 L .7022 .82928 L p .707 .577 .707 r
F P
0 g
s
.4976 .74335 m .50188 .70702 L .50899 .69808 L p .707 .577 .707 r
F P
0 g
s
.49972 .72052 m .50752 .66637 L .51466 .65731 L p .707 .577 .707 r
F P
0 g
s
.49047 .82157 m .48745 .31937 L .44344 .31695 L p .707 .577 .707 r
F P
0 g
s
.50899 .69808 m .50471 .73441 L .4976 .74335 L p .707 .577 .707 r
F P
0 g
s
.51466 .65731 m .50685 .71146 L .49972 .72052 L p .707 .577 .707 r
F P
0 g
s
.50471 .73441 m .50899 .69808 L .52533 .69129 L p .707 .577 .707 r
F P
0 g
s
.50685 .71146 m .51466 .65731 L .53098 .65064 L p .707 .577 .707 r
F P
0 g
s
.52533 .69129 m .52105 .72762 L .50471 .73441 L p .707 .577 .707 r
F P
0 g
s
.53098 .65064 m .52317 .70479 L .50685 .71146 L p .707 .577 .707 r
F P
0 g
s
.52105 .72762 m .52533 .69129 L .54928 .6873 L p .707 .577 .707 r
F P
0 g
s
.52317 .70479 m .53098 .65064 L .55489 .64701 L p .707 .577 .707 r
F P
0 g
s
.54928 .6873 m .545 .72363 L .52105 .72762 L p .707 .577 .707 r
F P
0 g
s
.55489 .64701 m .54708 .70116 L .52317 .70479 L p .707 .577 .707 r
F P
0 g
s
.53147 .83907 m .52973 .82044 L .55371 .81342 L p .707 .577 .707 r
F P
0 g
s
.48745 .31937 m .49047 .82157 L .53542 .82023 L p .707 .577 .707 r
F P
0 g
s
.53542 .82023 m .53239 .31803 L .48745 .31937 L p .707 .577 .707 r
F P
0 g
s
.545 .72363 m .54928 .6873 L .57851 .68652 L p .707 .577 .707 r
F P
0 g
s
.54708 .70116 m .55489 .64701 L .58404 .64678 L p .707 .577 .707 r
F P
0 g
s
.57851 .68652 m .57424 .72284 L .545 .72363 L p .707 .577 .707 r
F P
0 g
s
.58404 .64678 m .57624 .70093 L .54708 .70116 L p .707 .577 .707 r
F P
0 g
s
.55371 .81342 m .55546 .83204 L .53147 .83907 L p .707 .577 .707 r
F P
0 g
s
.55546 .83204 m .55371 .81342 L .583 .80789 L p .707 .577 .707 r
F P
0 g
s
.583 .80789 m .58474 .82652 L .55546 .83204 L p .707 .577 .707 r
F P
0 g
s
.53239 .31803 m .53542 .82023 L .5769 .81527 L p .707 .577 .707 r
F P
0 g
s
.57424 .72284 m .57851 .68652 L .61016 .68901 L p .707 .577 .707 r
F P
0 g
s
.61016 .68901 m .60588 .72534 L .57424 .72284 L p .707 .577 .707 r
F P
0 g
s
.5769 .81527 m .57387 .31306 L .53239 .31803 L p .707 .577 .707 r
F P
0 g
s
.69739 .75907 m .70167 .72274 L .70447 .73295 L p .707 .577 .707 r
F P
0 g
s
.44647 .81915 m .44344 .31695 L .40468 .31102 L p .707 .577 .707 r
F P
0 g
s
.44344 .31695 m .44647 .81915 L .49047 .82157 L p .707 .577 .707 r
F P
0 g
s
.51085 .86197 m .50911 .84334 L .50627 .83617 L p .707 .577 .707 r
F P
0 g
s
.57624 .70093 m .58404 .64678 L .6156 .64997 L p .707 .577 .707 r
F P
0 g
s
.6156 .64997 m .60779 .70412 L .57624 .70093 L p .707 .577 .707 r
F P
0 g
s
.58474 .82652 m .583 .80789 L .6147 .80442 L p .707 .577 .707 r
F P
0 g
s
.57387 .31306 m .5769 .81527 L .61085 .80717 L p .707 .577 .707 r
F P
0 g
s
.6736 .66506 m .6658 .71921 L .63892 .71051 L p .707 .577 .707 r
F P
0 g
s
.63899 .70998 m .6736 .66506 L .63892 .71051 L .707 .577 .707 r
F
.63626 .73075 m .60588 .72534 L p .64102 .69462 L F P
0 g
s
.64646 .65627 m .6736 .66506 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .61016 .68901 L .64103 .69451 L p .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .64103 .69451 L .64102 .69462 L .707 .577 .707 r
F
.63865 .71042 m .64192 .68776 L p .63899 .70998 L F P
0 g
s
.64192 .68776 m .64646 .65627 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.64103 .69451 m .64112 .69453 L p .64102 .69462 L .707 .577 .707 r
F P
0 g
s
.64112 .69453 m .63684 .73086 L .63626 .73075 L p .707 .577 .707 r
F P
0 g
s
.64102 .69462 m .64112 .69453 L .63626 .73075 L .707 .577 .707 r
F
.63892 .71051 m .63865 .71042 L p .63899 .70998 L F P
0 g
s
.64646 .65627 m .63865 .71042 L .60779 .70412 L p .707 .577 .707 r
F P
0 g
s
.60779 .70412 m .6156 .64997 L .64646 .65627 L p .707 .577 .707 r
F P
0 g
s
.61085 .80717 m .60783 .30496 L .57387 .31306 L p .707 .577 .707 r
F P
0 g
s
.50627 .83617 m .50802 .8548 L .51085 .86197 L p .707 .577 .707 r
F P
0 g
s
.25061 .70228 m .25841 .64813 L .22756 .64183 L p .707 .577 .707 r
F P
0 g
s
.25841 .64813 m .25061 .70228 L .28216 .70547 L p .707 .577 .707 r
F P
0 g
s
.28216 .70547 m .28997 .65132 L .25841 .64813 L p .707 .577 .707 r
F P
0 g
s
.68657 .72963 m .68994 .70624 L p .70674 .68651 L .707 .577 .707 r
F P
0 g
s
.69438 .67548 m .68657 .72963 L .6658 .71921 L p .707 .577 .707 r
F P
0 g
s
.68923 .71227 m .68495 .74859 L .68321 .74778 L p .707 .577 .707 r
F P
0 g
s
.68321 .74778 m .66409 .73887 L p .68891 .71261 L .707 .577 .707 r
F P
0 g
s
.68891 .71261 m .68923 .71227 L .68321 .74778 L .707 .577 .707 r
F
.68994 .70624 m .69438 .67548 L .69486 .67591 L p F P
0 g
s
.69486 .67591 m .70674 .68651 L p .68994 .70624 L .707 .577 .707 r
F P
0 g
s
.28997 .65132 m .28216 .70547 L .31132 .70524 L p .707 .577 .707 r
F P
0 g
s
.31132 .70524 m .31913 .65109 L .28997 .65132 L p .707 .577 .707 r
F P
0 g
s
.7093 .82139 m .71105 .84001 L .70822 .83285 L p .707 .577 .707 r
F P
0 g
s
.70822 .83285 m .70647 .81422 L .7093 .82139 L p .707 .577 .707 r
F P
0 g
s
.21975 .69598 m .22756 .64183 L .20041 .63304 L p .707 .577 .707 r
F P
0 g
s
.22756 .64183 m .21975 .69598 L .25061 .70228 L p .707 .577 .707 r
F P
0 g
s
.4077 .81322 m .40468 .31102 L .37496 .30215 L p .707 .577 .707 r
F P
0 g
s
.40468 .31102 m .4077 .81322 L .44647 .81915 L p .707 .577 .707 r
F P
0 g
s
.68495 .74859 m .68923 .71227 L .70167 .72274 L p .707 .577 .707 r
F P
0 g
s
.31913 .65109 m .31132 .70524 L .33523 .70161 L p .707 .577 .707 r
F P
0 g
s
.33523 .70161 m .34304 .64746 L .31913 .65109 L p .707 .577 .707 r
F P
0 g
s
.19261 .68719 m .20041 .63304 L .17964 .62262 L p .707 .577 .707 r
F P
0 g
s
.20041 .63304 m .19261 .68719 L .21975 .69598 L p .707 .577 .707 r
F P
0 g
s
.50802 .8548 m .50627 .83617 L .51338 .82828 L p .707 .577 .707 r
F P
0 g
s
.61645 .82304 m .6147 .80442 L .64574 .80333 L p .707 .577 .707 r
F P
0 g
s
.6147 .80442 m .61645 .82304 L .58474 .82652 L p .707 .577 .707 r
F P
0 g
s
.60783 .30496 m .61085 .80717 L .63396 .79672 L p .707 .577 .707 r
F P
0 g
s
.63396 .79672 m .63094 .29452 L .60783 .30496 L p .707 .577 .707 r
F P
0 g
s
.51338 .82828 m .51513 .84691 L .50802 .8548 L p .707 .577 .707 r
F P
0 g
s
.6658 .71921 m .66912 .69616 L p .69438 .67548 L .707 .577 .707 r
F P
0 g
s
.66837 .70254 m .66409 .73887 L .66261 .73844 L p .707 .577 .707 r
F P
0 g
s
.66261 .73844 m .63684 .73086 L p .6681 .70278 L .707 .577 .707 r
F P
0 g
s
.6681 .70278 m .66837 .70254 L .66261 .73844 L .707 .577 .707 r
F
.66912 .69616 m .6736 .66506 L .67389 .6652 L p F P
0 g
s
.67389 .6652 m .69438 .67548 L p .66912 .69616 L .707 .577 .707 r
F P
0 g
s
.25961 .79015 m .25787 .77153 L .22683 .77262 L p .707 .577 .707 r
F P
0 g
s
.25787 .77153 m .25961 .79015 L .29132 .78667 L p .707 .577 .707 r
F P
0 g
s
.29132 .78667 m .28957 .76805 L .25787 .77153 L p .707 .577 .707 r
F P
0 g
s
.22683 .77262 m .22858 .79124 L .25961 .79015 L p .707 .577 .707 r
F P
0 g
s
.2489 .80173 m .25318 .7654 L .22222 .75988 L p .707 .577 .707 r
F P
0 g
s
.25318 .7654 m .2489 .80173 L .28055 .80422 L p .707 .577 .707 r
F P
0 g
s
.28055 .80422 m .28483 .76789 L .25318 .7654 L p .707 .577 .707 r
F P
0 g
s
.70647 .81422 m .70822 .83285 L .69573 .82711 L p .707 .577 .707 r
F P
0 g
s
.69573 .82711 m .69398 .80848 L .70647 .81422 L p .707 .577 .707 r
F P
0 g
s
.28957 .76805 m .29132 .78667 L .3206 .78115 L p .707 .577 .707 r
F P
0 g
s
.3206 .78115 m .31886 .76253 L .28957 .76805 L p .707 .577 .707 r
F P
0 g
s
.34304 .64746 m .33523 .70161 L .35155 .69494 L p .707 .577 .707 r
F P
0 g
s
.35155 .69494 m .35936 .64079 L .34304 .64746 L p .707 .577 .707 r
F P
0 g
s
.17964 .62262 m .17183 .67677 L .19261 .68719 L p .707 .577 .707 r
F P
0 g
s
.28483 .76789 m .28055 .80422 L .30978 .80343 L p .707 .577 .707 r
F P
0 g
s
.30978 .80343 m .31406 .7671 L .28483 .76789 L p .707 .577 .707 r
F P
0 g
s
.37798 .80435 m .37496 .30215 L .35718 .29121 L p .707 .577 .707 r
F P
0 g
s
.37496 .30215 m .37798 .80435 L .4077 .81322 L p .707 .577 .707 r
F P
0 g
s
.66409 .73887 m .66837 .70254 L .68923 .71227 L p .707 .577 .707 r
F P
0 g
s
.21794 .7962 m .22222 .75988 L .19497 .75186 L p .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22683 .77262 L .22401 .77247 L p .707 .577 .707 r
F P
0 g
s
.22222 .75988 m .21794 .7962 L .22391 .79727 L p .707 .577 .707 r
F P
0 g
s
.22405 .76274 m .22222 .75988 L .22391 .79727 L .707 .577 .707 r
F
.19497 .75186 m .19069 .78819 L .21794 .7962 L p F P
0 g
s
.22401 .77247 m .19952 .77122 L p .22394 .78805 L .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22401 .77247 L .22394 .78805 L .707 .577 .707 r
F
.19952 .77122 m .20127 .78984 L .22858 .79124 L p F P
0 g
s
.22391 .79727 m .2489 .80173 L p .22405 .76274 L .707 .577 .707 r
F P
0 g
s
.17183 .67677 m .17964 .62262 L .16727 .61159 L p .707 .577 .707 r
F P
0 g
s
.31886 .76253 m .3206 .78115 L .34459 .77413 L p .707 .577 .707 r
F P
0 g
s
.34459 .77413 m .34284 .7555 L .31886 .76253 L p .707 .577 .707 r
F P
0 g
s
.31406 .7671 m .30978 .80343 L .33373 .79945 L p .707 .577 .707 r
F P
0 g
s
.33373 .79945 m .33801 .76312 L .31406 .7671 L p .707 .577 .707 r
F P
0 g
s
.51513 .84691 m .51338 .82828 L .52973 .82044 L p .707 .577 .707 r
F P
0 g
s
.19069 .78819 m .19497 .75186 L .17411 .74214 L p .707 .577 .707 r
F P
0 g
s
.52973 .82044 m .53147 .83907 L .51513 .84691 L p .707 .577 .707 r
F P
0 g
s
.17411 .74214 m .16983 .77847 L .19069 .78819 L p .707 .577 .707 r
F P
0 g
s
.20127 .78984 m .19952 .77122 L .17859 .76746 L p .707 .577 .707 r
F P
0 g
s
.16727 .61159 m .15946 .66574 L .17183 .67677 L p .707 .577 .707 r
F P
0 g
s
.63684 .73086 m .64112 .69453 L .66837 .70254 L p .707 .577 .707 r
F P
0 g
s
.63094 .29452 m .63396 .79672 L .64396 .78496 L p .707 .577 .707 r
F P
0 g
s
.64396 .78496 m .64094 .28275 L .63094 .29452 L p .707 .577 .707 r
F P
0 g
s
.17859 .76746 m .18034 .78609 L .20127 .78984 L p .707 .577 .707 r
F P
0 g
s
.35936 .64079 m .35155 .69494 L .35868 .68588 L p .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .36607 .6346 L p .35936 .64079 L .707 .577 .707 r
F P
0 g
s
.34284 .7555 m .34459 .77413 L .36094 .76629 L p .707 .577 .707 r
F P
0 g
s
.36094 .76629 m .35919 .74766 L .34284 .7555 L p .707 .577 .707 r
F P
0 g
s
.36619 .6321 m .35936 .64079 L p .36607 .6346 L .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .35593 .67531 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .36649 .63173 L .36619 .6321 L p .707 .577 .707 r
F P
0 g
s
.36649 .63173 m .36607 .6346 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .35868 .68588 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .35309 .27927 L p .35762 .60687 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36649 .63173 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .36317 .62508 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .36373 .62116 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35919 .74766 m .36094 .76629 L .3672 .75933 L p .707 .577 .707 r
F P
0 g
s
.3672 .75933 m .36804 .7584 L p .36714 .75729 L .707 .577 .707 r
F P
0 g
s
.36714 .75729 m .35919 .74766 L .3672 .75933 L .707 .577 .707 r
F
.36804 .7584 m .3663 .73977 L .35919 .74766 L p F P
0 g
s
.35435 .75633 m .35007 .79265 L .35718 .78372 L p .707 .577 .707 r
F P
0 g
s
.35718 .78372 m .36146 .74739 L .35435 .75633 L p .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .34356 .66428 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36317 .62508 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .35593 .67531 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .35137 .61013 L .36301 .62052 L p .707 .577 .707 r
F P
0 g
s
.36301 .62052 m .36373 .62116 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .36301 .62052 L .36308 .62256 L .707 .577 .707 r
F
.3533 .31385 m .35351 .34894 L p .35378 .3294 L F P
0 g
s
.36146 .74739 m .35718 .78372 L .35438 .77351 L p .707 .577 .707 r
F P
0 g
s
.35438 .77351 m .35866 .73718 L .36146 .74739 L p .707 .577 .707 r
F P
0 g
s
.35007 .79265 m .35435 .75633 L .33801 .76312 L p .707 .577 .707 r
F P
0 g
s
.35866 .73718 m .35438 .77351 L .34271 .76367 L p .707 .577 .707 r
F P
0 g
s
.34271 .76367 m .34194 .76303 L p .34276 .76177 L .707 .577 .707 r
F P
0 g
s
.34276 .76177 m .35866 .73718 L .34271 .76367 L .707 .577 .707 r
F
.34194 .76303 m .34622 .7267 L .35866 .73718 L p F P
0 g
s
.3559 .74695 m .35272 .74549 L p .35587 .74171 L .707 .577 .707 r
F P
0 g
s
.35587 .74171 m .36346 .7326 L .3559 .74695 L .707 .577 .707 r
F
.36346 .7326 m .36521 .75123 L .3559 .74695 L p F P
0 g
s
.35272 .74549 m .35097 .72686 L .36346 .7326 L p .707 .577 .707 r
F P
0 g
s
.35351 .34894 m .35611 .78148 L p .35395 .36149 L .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .3602 .79341 L p .35441 .37466 L .707 .577 .707 r
F P
0 g
s
.35441 .37466 m .35378 .3294 L .35395 .36149 L .707 .577 .707 r
F
.35441 .37466 m .35395 .36149 L .35611 .78148 L F
.35911 .61174 m .35718 .29121 L p .35897 .6113 L F P
0 g
s
.35985 .7679 m .35897 .6113 L .35762 .60687 L .707 .577 .707 r
F
.35897 .6113 m .35718 .29121 L .35762 .60687 L F
.3663 .73977 m .36804 .7584 L .36521 .75123 L p F P
0 g
s
.36521 .75123 m .36346 .7326 L .3663 .73977 L p .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .3602 .79341 L .37798 .80435 L p .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .35363 .36867 L p .36309 .26751 L .707 .577 .707 r
F P
0 g
s
.35378 .3294 m .35351 .34894 L .35395 .36149 L .707 .577 .707 r
F
.35309 .27927 m .3533 .31385 L p .35378 .3294 L F P
0 g
s
.35363 .36867 m .35309 .27927 L .3562 .27561 L p .707 .577 .707 r
F P
0 g
s
.3562 .27561 m .36309 .26751 L p .35363 .36867 L .707 .577 .707 r
F P
0 g
s
.36002 .76412 m .35911 .61174 L p .35985 .7679 L .707 .577 .707 r
F P
0 g
s
.35911 .61174 m .35897 .6113 L .35985 .7679 L .707 .577 .707 r
F
.3602 .79341 m .36002 .76412 L p .35985 .7679 L F P
0 g
s
.69398 .80848 m .69573 .82711 L .6748 .82335 L p .707 .577 .707 r
F P
0 g
s
.6748 .82335 m .67305 .80472 L .69398 .80848 L p .707 .577 .707 r
F P
0 g
s
.15946 .66574 m .16727 .61159 L .16451 .60103 L p .707 .577 .707 r
F P
0 g
s
.33801 .76312 m .33373 .79945 L .35007 .79265 L p .707 .577 .707 r
F P
0 g
s
.16983 .77847 m .17411 .74214 L .16167 .73166 L p .707 .577 .707 r
F P
0 g
s
.16167 .73166 m .15739 .76799 L .16983 .77847 L p .707 .577 .707 r
F P
0 g
s
.18034 .78609 m .17859 .76746 L .1661 .76172 L p .707 .577 .707 r
F P
0 g
s
.1661 .76172 m .16784 .78035 L .18034 .78609 L p .707 .577 .707 r
F P
0 g
s
.16451 .60103 m .15671 .65518 L .15946 .66574 L p .707 .577 .707 r
F P
0 g
s
.67305 .80472 m .6748 .82335 L .64748 .82195 L p .707 .577 .707 r
F P
0 g
s
.64748 .82195 m .64574 .80333 L .67305 .80472 L p .707 .577 .707 r
F P
0 g
s
.15671 .65518 m .16451 .60103 L .17165 .59196 L p .707 .577 .707 r
F P
0 g
s
.64094 .28275 m .64396 .78496 L .63987 .77302 L p .707 .577 .707 r
F P
0 g
s
.63987 .77302 m .63685 .27082 L .64094 .28275 L p .707 .577 .707 r
F P
0 g
s
.15739 .76799 m .16167 .73166 L .15887 .72146 L p .707 .577 .707 r
F P
0 g
s
.64574 .80333 m .64748 .82195 L .61645 .82304 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16784 .78035 m .1661 .76172 L .16326 .75456 L p .707 .577 .707 r
F P
0 g
s
.16326 .75456 m .16501 .77318 L .16784 .78035 L p .707 .577 .707 r
F P
0 g
s
.15887 .72146 m .15459 .75778 L .15739 .76799 L p .707 .577 .707 r
F P
0 g
s
.17165 .59196 m .16384 .64612 L .15671 .65518 L p .707 .577 .707 r
F P
0 g
s
.16384 .64612 m .17165 .59196 L .18797 .58529 L p .707 .577 .707 r
F P
0 g
s
.15459 .75778 m .15887 .72146 L .16598 .71252 L p .707 .577 .707 r
F P
0 g
s
.16501 .77318 m .16326 .75456 L .17037 .74667 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17037 .74667 m .17212 .76529 L .16501 .77318 L p .707 .577 .707 r
F P
0 g
s
.16598 .71252 m .1617 .74885 L .15459 .75778 L p .707 .577 .707 r
F P
0 g
s
.18797 .58529 m .18016 .63945 L .16384 .64612 L p .707 .577 .707 r
F P
0 g
s
.63685 .27082 m .63987 .77302 L .6221 .76208 L p .707 .577 .707 r
F P
0 g
s
.6221 .76208 m .61908 .25988 L .63685 .27082 L p .707 .577 .707 r
F P
0 g
s
.35137 .61013 m .34356 .66428 L .32279 .65386 L p .707 .577 .707 r
F P
0 g
s
.32279 .65386 m .33059 .59971 L .35137 .61013 L p .707 .577 .707 r
F P
0 g
s
.18016 .63945 m .18797 .58529 L .21188 .58166 L p .707 .577 .707 r
F P
0 g
s
.1617 .74885 m .16598 .71252 L .18232 .70572 L p .707 .577 .707 r
F P
0 g
s
.36611 .76971 m .36309 .26751 L .3862 .25706 L p .707 .577 .707 r
F P
0 g
s
.36309 .26751 m .36611 .76971 L .35611 .78148 L p .707 .577 .707 r
F P
0 g
s
.17212 .76529 m .17037 .74667 L .18672 .73882 L p .707 .577 .707 r
F P
0 g
s
.33059 .59971 m .32279 .65386 L .29564 .64507 L p .707 .577 .707 r
F P
0 g
s
.29564 .64507 m .30345 .59092 L .33059 .59971 L p .707 .577 .707 r
F P
0 g
s
.21188 .58166 m .20407 .63582 L .18016 .63945 L p .707 .577 .707 r
F P
0 g
s
.20407 .63582 m .21188 .58166 L .24103 .58143 L p .707 .577 .707 r
F P
0 g
s
.18232 .70572 m .17804 .74205 L .1617 .74885 L p .707 .577 .707 r
F P
0 g
s
.18672 .73882 m .18846 .75745 L .17212 .76529 L p .707 .577 .707 r
F P
0 g
s
.34622 .7267 m .34194 .76303 L .32108 .75331 L p .707 .577 .707 r
F P
0 g
s
.32108 .75331 m .32536 .71698 L .34622 .7267 L p .707 .577 .707 r
F P
0 g
s
.35097 .72686 m .35272 .74549 L .33179 .74173 L p .707 .577 .707 r
F P
0 g
s
.33179 .74173 m .33004 .72311 L .35097 .72686 L p .707 .577 .707 r
F P
0 g
s
.61908 .25988 m .6221 .76208 L .59237 .75321 L p .707 .577 .707 r
F P
0 g
s
.59237 .75321 m .58935 .25101 L .61908 .25988 L p .707 .577 .707 r
F P
0 g
s
.30345 .59092 m .29564 .64507 L .26478 .63877 L p .707 .577 .707 r
F P
0 g
s
.26478 .63877 m .27259 .58462 L .30345 .59092 L p .707 .577 .707 r
F P
0 g
s
.23323 .63559 m .24103 .58143 L .27259 .58462 L p .707 .577 .707 r
F P
0 g
s
.24103 .58143 m .23323 .63559 L .20407 .63582 L p .707 .577 .707 r
F P
0 g
s
.17804 .74205 m .18232 .70572 L .20627 .70174 L p .707 .577 .707 r
F P
0 g
s
.27259 .58462 m .26478 .63877 L .23323 .63559 L p .707 .577 .707 r
F P
0 g
s
.18846 .75745 m .18672 .73882 L .2107 .7318 L p .707 .577 .707 r
F P
0 g
s
.3862 .25706 m .38922 .75927 L .36611 .76971 L p .707 .577 .707 r
F P
0 g
s
.38922 .75927 m .3862 .25706 L .42016 .24896 L p .707 .577 .707 r
F P
0 g
s
.2107 .7318 m .21245 .75042 L .18846 .75745 L p .707 .577 .707 r
F P
0 g
s
.20627 .70174 m .20199 .73807 L .17804 .74205 L p .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73339 .65892 L .73314 .65888 L p .707 .577 .707 r
F P
0 g
s
.73314 .65888 m .70243 .6534 L p .72773 .69309 L .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73314 .65888 L .72773 .69309 L .707 .577 .707 r
F
.73339 .65892 m .72911 .69525 L .76076 .69774 L p F P
0 g
s
.76076 .69774 m .76504 .66141 L .76466 .66138 L p .707 .577 .707 r
F P
0 g
s
.76466 .66138 m .73339 .65892 L p .75862 .69471 L .707 .577 .707 r
F P
0 g
s
.76076 .69774 m .76466 .66138 L .75862 .69471 L .707 .577 .707 r
F
.76504 .66141 m .76076 .69774 L .78999 .69696 L p F P
0 g
s
.78999 .69696 m .79427 .66063 L .79385 .66064 L p .707 .577 .707 r
F P
0 g
s
.79385 .66064 m .76504 .66141 L p .78759 .69354 L .707 .577 .707 r
F P
0 g
s
.78999 .69696 m .79385 .66064 L .78759 .69354 L .707 .577 .707 r
F
.79427 .66063 m .78999 .69696 L .81395 .69297 L p F P
0 g
s
.81395 .69297 m .81823 .65664 L .81786 .65671 L p .707 .577 .707 r
F P
0 g
s
.81786 .65671 m .79427 .66063 L p .81188 .68957 L .707 .577 .707 r
F P
0 g
s
.81395 .69297 m .81786 .65671 L .81188 .68957 L .707 .577 .707 r
F
.81823 .65664 m .81395 .69297 L .83028 .68618 L p F P
0 g
s
.83028 .68618 m .83456 .64985 L .83431 .64995 L p .707 .577 .707 r
F P
0 g
s
.83431 .64995 m .81823 .65664 L p .82902 .68308 L .707 .577 .707 r
F P
0 g
s
.83028 .68618 m .83431 .64995 L .82902 .68308 L .707 .577 .707 r
F
.83456 .64985 m .83028 .68618 L .8374 .67724 L p F P
0 g
s
.8374 .67724 m .84168 .64091 L .84158 .64104 L p .707 .577 .707 r
F P
0 g
s
.84158 .64104 m .83456 .64985 L p .83713 .67462 L .707 .577 .707 r
F P
0 g
s
.8374 .67724 m .84158 .64104 L .83713 .67462 L .707 .577 .707 r
F
.83177 .66825 m .8389 .65919 L p .83952 .61739 L F P
0 g
s
.8389 .65919 m .84233 .63534 L p .83957 .61409 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8467 .60503 L .84616 .60572 L p .707 .577 .707 r
F P
0 g
s
.84616 .60572 m .83957 .61409 L p .84233 .63534 L .707 .577 .707 r
F P
0 g
s
.84168 .64091 m .8374 .67724 L .83707 .67606 L p .707 .577 .707 r
F P
0 g
s
.8389 .65919 m .83615 .64862 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8389 .65919 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.83707 .67606 m .8346 .66703 L p .84156 .64136 L .707 .577 .707 r
F P
0 g
s
.84156 .64136 m .84168 .64091 L .83707 .67606 L .707 .577 .707 r
F
.8467 .60503 m .84233 .63534 L p .84593 .60822 L F P
0 g
s
.83957 .61409 m .83521 .64434 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.83521 .64434 m .83177 .66825 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .83177 .66825 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.82325 .62077 m .81888 .65107 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.81888 .65107 m .81545 .67492 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .81545 .67492 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79934 .62439 m .79495 .65488 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79495 .65488 m .79154 .67855 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .79154 .67855 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.77018 .62463 m .76575 .65539 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.76575 .65539 m .76238 .67878 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .76238 .67878 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73863 .62144 m .73414 .65254 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73414 .65254 m .73082 .67559 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .73863 .62144 L .70777 .61514 L p .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .77018 .62463 L .73863 .62144 L p .707 .577 .707 r
F P
0 g
s
.32536 .71698 m .32108 .75331 L .29908 .74684 L p .707 .577 .707 r
F P
0 g
s
.29919 .74052 m .27344 .74143 L p .29948 .72389 L .707 .577 .707 r
F P
0 g
s
.29908 .74684 m .29383 .74529 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29919 .74048 m .32536 .71698 L .29908 .74684 L .707 .577 .707 r
F
.27344 .74143 m .27169 .7228 L .29951 .72182 L p F P
0 g
s
.27344 .74143 m .29951 .72182 L .29948 .72389 L .707 .577 .707 r
F
.29383 .74529 m .29811 .70897 L .29973 .70944 L p F P
0 g
s
.29973 .70944 m .32536 .71698 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29383 .74529 m .29973 .70944 L .29919 .74048 L .707 .577 .707 r
F
.29951 .72182 m .30273 .72171 L p .29948 .72389 L F P
0 g
s
.30273 .72171 m .30447 .74033 L .29919 .74052 L p .707 .577 .707 r
F P
0 g
s
.29948 .72389 m .30273 .72171 L .29919 .74052 L .707 .577 .707 r
F
.33004 .72311 m .33179 .74173 L .30447 .74033 L p F P
0 g
s
.30447 .74033 m .30273 .72171 L .33004 .72311 L p .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .79934 .62439 L .77018 .62463 L p .707 .577 .707 r
F P
0 g
s
.69996 .66929 m .70777 .61514 L .68062 .60635 L p .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70243 .6534 L .70235 .65338 L p .707 .577 .707 r
F P
0 g
s
.70323 .64663 m .69996 .66929 L .70027 .66935 L p .707 .577 .707 r
F P
0 g
s
.68062 .60635 m .67282 .6605 L .69996 .66929 L p .707 .577 .707 r
F P
0 g
s
.70235 .65338 m .67519 .64539 L p .69773 .68891 L .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70235 .65338 L .69773 .68891 L .707 .577 .707 r
F
.70777 .61514 m .70323 .64663 L p .73082 .67559 L F P
0 g
s
.70243 .6534 m .69815 .68973 L .72911 .69525 L p .707 .577 .707 r
F P
0 g
s
.70027 .66935 m .73082 .67559 L p .70323 .64663 L .707 .577 .707 r
F P
0 g
s
.20199 .73807 m .20627 .70174 L .23551 .70095 L p .707 .577 .707 r
F P
0 g
s
.21245 .75042 m .2107 .7318 L .23999 .72628 L p .707 .577 .707 r
F P
0 g
s
.58935 .25101 m .59237 .75321 L .55361 .74728 L p .707 .577 .707 r
F P
0 g
s
.55361 .74728 m .55059 .24508 L .58935 .25101 L p .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .82325 .62077 L .79934 .62439 L p .707 .577 .707 r
F P
0 g
s
.27169 .7228 m .27344 .74143 L .24173 .7449 L p .707 .577 .707 r
F P
0 g
s
.29811 .70897 m .29383 .74529 L .26287 .73977 L p .707 .577 .707 r
F P
0 g
s
.24173 .7449 m .23999 .72628 L .27169 .7228 L p .707 .577 .707 r
F P
0 g
s
.26287 .73977 m .26715 .70344 L .29811 .70897 L p .707 .577 .707 r
F P
0 g
s
.23999 .72628 m .24173 .7449 L .21245 .75042 L p .707 .577 .707 r
F P
0 g
s
.23551 .70095 m .23123 .73728 L .20199 .73807 L p .707 .577 .707 r
F P
0 g
s
.23123 .73728 m .23551 .70095 L .26715 .70344 L p .707 .577 .707 r
F P
0 g
s
.67282 .6605 m .68062 .60635 L .65985 .59593 L p .707 .577 .707 r
F P
0 g
s
.26715 .70344 m .26287 .73977 L .23123 .73728 L p .707 .577 .707 r
F P
0 g
s
.42318 .75117 m .42016 .24896 L .46164 .244 L p .707 .577 .707 r
F P
0 g
s
.42016 .24896 m .42318 .75117 L .38922 .75927 L p .707 .577 .707 r
F P
0 g
s
.67519 .64539 m .67091 .68172 L .69815 .68973 L p .707 .577 .707 r
F P
0 g
s
.65985 .59593 m .65205 .65008 L .67282 .6605 L p .707 .577 .707 r
F P
0 g
s
.67091 .68172 m .67519 .64539 L .65432 .63566 L p .707 .577 .707 r
F P
0 g
s
.55059 .24508 m .55361 .74728 L .5096 .74487 L p .707 .577 .707 r
F P
0 g
s
.5096 .74487 m .50658 .24266 L .55059 .24508 L p .707 .577 .707 r
F P
0 g
s
.83177 .66825 m .83957 .61409 L .82325 .62077 L p .707 .577 .707 r
F P
0 g
s
.73983 .77973 m .73808 .76111 L .70705 .7622 L p .707 .577 .707 r
F P
0 g
s
.73808 .76111 m .73983 .77973 L .77154 .77625 L p .707 .577 .707 r
F P
0 g
s
.77154 .77625 m .76979 .75763 L .73808 .76111 L p .707 .577 .707 r
F P
0 g
s
.76979 .75763 m .77154 .77625 L .80082 .77073 L p .707 .577 .707 r
F P
0 g
s
.80082 .77073 m .79907 .75211 L .76979 .75763 L p .707 .577 .707 r
F P
0 g
s
.65205 .65008 m .65985 .59593 L .64748 .5849 L p .707 .577 .707 r
F P
0 g
s
.46466 .74621 m .46164 .244 L .50658 .24266 L p .707 .577 .707 r
F P
0 g
s
.46164 .244 m .46466 .74621 L .42318 .75117 L p .707 .577 .707 r
F P
0 g
s
.70705 .7622 m .7088 .78082 L .73983 .77973 L p .707 .577 .707 r
F P
0 g
s
.65432 .63566 m .65004 .67199 L .67091 .68172 L p .707 .577 .707 r
F P
0 g
s
.50658 .24266 m .5096 .74487 L .46466 .74621 L p .707 .577 .707 r
F P
0 g
s
.7088 .78082 m .70705 .7622 L .67973 .7608 L p .707 .577 .707 r
F P
0 g
s
.67973 .7608 m .68148 .77942 L .7088 .78082 L p .707 .577 .707 r
F P
0 g
s
.79907 .75211 m .80082 .77073 L .82481 .76371 L p .707 .577 .707 r
F P
0 g
s
.82481 .76371 m .82306 .74508 L .79907 .75211 L p .707 .577 .707 r
F P
0 g
s
.64748 .5849 m .63968 .63905 L .65205 .65008 L p .707 .577 .707 r
F P
0 g
s
.65004 .67199 m .65432 .63566 L .64188 .62519 L p .707 .577 .707 r
F P
0 g
s
.68148 .77942 m .67973 .7608 L .6588 .75704 L p .707 .577 .707 r
F P
0 g
s
.64188 .62519 m .6376 .66152 L .65004 .67199 L p .707 .577 .707 r
F P
0 g
s
.6588 .75704 m .66055 .77567 L .68148 .77942 L p .707 .577 .707 r
F P
0 g
s
.63968 .63905 m .64748 .5849 L .64473 .57433 L p .707 .577 .707 r
F P
0 g
s
.82306 .74508 m .82481 .76371 L .84115 .75587 L p .707 .577 .707 r
F P
0 g
s
.84115 .75587 m .8394 .73724 L .82306 .74508 L p .707 .577 .707 r
F P
0 g
s
.64473 .57433 m .63692 .62849 L .63968 .63905 L p .707 .577 .707 r
F P
0 g
s
.6376 .66152 m .64188 .62519 L .63908 .61498 L p .707 .577 .707 r
F P
0 g
s
.66055 .77567 m .6588 .75704 L .64631 .7513 L p .707 .577 .707 r
F P
0 g
s
.64631 .7513 m .64806 .76993 L .66055 .77567 L p .707 .577 .707 r
F P
0 g
s
.83615 .64862 m .83956 .62495 L p .8467 .60503 L .707 .577 .707 r
F P
0 g
s
.84395 .59447 m .83615 .64862 L .82378 .63759 L p .707 .577 .707 r
F P
0 g
s
.83888 .6307 m .8346 .66703 L .8333 .66594 L p .707 .577 .707 r
F P
0 g
s
.8333 .66594 m .82216 .65656 L p .83862 .63111 L .707 .577 .707 r
F P
0 g
s
.83862 .63111 m .83888 .6307 L .8333 .66594 L .707 .577 .707 r
F
.83956 .62495 m .84395 .59447 L .84412 .59511 L p F P
0 g
s
.84412 .59511 m .8467 .60503 L p .83956 .62495 L .707 .577 .707 r
F P
0 g
s
.63908 .61498 m .6348 .65131 L .6376 .66152 L p .707 .577 .707 r
F P
0 g
s
.8394 .73724 m .84115 .75587 L .84826 .74797 L p .707 .577 .707 r
F P
0 g
s
.84826 .74797 m .84651 .72935 L .8394 .73724 L p .707 .577 .707 r
F P
0 g
s
.6348 .65131 m .63908 .61498 L .6462 .60604 L p .707 .577 .707 r
F P
0 g
s
.63692 .62849 m .64473 .57433 L .65186 .56527 L p .707 .577 .707 r
F P
0 g
s
.8346 .66703 m .83888 .6307 L .84168 .64091 L p .707 .577 .707 r
F P
0 g
s
.64806 .76993 m .64631 .7513 L .64348 .74414 L p .707 .577 .707 r
F P
0 g
s
.6462 .60604 m .64192 .64237 L .6348 .65131 L p .707 .577 .707 r
F P
0 g
s
.65186 .56527 m .64406 .61943 L .63692 .62849 L p .707 .577 .707 r
F P
0 g
s
.64348 .74414 m .64523 .76276 L .64806 .76993 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38781 .61024 m .39562 .55609 L .36476 .54979 L p .707 .577 .707 r
F P
0 g
s
.39562 .55609 m .38781 .61024 L .41937 .61343 L p .707 .577 .707 r
F P
0 g
s
.41937 .61343 m .42717 .55928 L .39562 .55609 L p .707 .577 .707 r
F P
0 g
s
.82378 .63759 m .82715 .6142 L p .84395 .59447 L .707 .577 .707 r
F P
0 g
s
.83158 .58344 m .82378 .63759 L .803 .62717 L p .707 .577 .707 r
F P
0 g
s
.82644 .62023 m .82216 .65656 L .82041 .65574 L p .707 .577 .707 r
F P
0 g
s
.82041 .65574 m .80129 .64683 L p .82611 .62057 L .707 .577 .707 r
F P
0 g
s
.82611 .62057 m .82644 .62023 L .82041 .65574 L .707 .577 .707 r
F
.82715 .6142 m .83158 .58344 L .83207 .58387 L p F P
0 g
s
.83207 .58387 m .84395 .59447 L p .82715 .6142 L .707 .577 .707 r
F P
0 g
s
.42717 .55928 m .41937 .61343 L .44853 .6132 L p .707 .577 .707 r
F P
0 g
s
.44853 .6132 m .45633 .55905 L .42717 .55928 L p .707 .577 .707 r
F P
0 g
s
.64192 .64237 m .6462 .60604 L .66253 .59925 L p .707 .577 .707 r
F P
0 g
s
.64406 .61943 m .65186 .56527 L .66818 .5586 L p .707 .577 .707 r
F P
0 g
s
.84651 .72935 m .84826 .74797 L .84543 .74081 L p .707 .577 .707 r
F P
0 g
s
.84543 .74081 m .84368 .72218 L .84651 .72935 L p .707 .577 .707 r
F P
0 g
s
.35695 .60394 m .36476 .54979 L .33761 .541 L p .707 .577 .707 r
F P
0 g
s
.36476 .54979 m .35695 .60394 L .38781 .61024 L p .707 .577 .707 r
F P
0 g
s
.82216 .65656 m .82644 .62023 L .83888 .6307 L p .707 .577 .707 r
F P
0 g
s
.45633 .55905 m .44853 .6132 L .47244 .60957 L p .707 .577 .707 r
F P
0 g
s
.47244 .60957 m .48024 .55542 L .45633 .55905 L p .707 .577 .707 r
F P
0 g
s
.32981 .59515 m .33761 .541 L .31684 .53058 L p .707 .577 .707 r
F P
0 g
s
.33761 .541 m .32981 .59515 L .35695 .60394 L p .707 .577 .707 r
F P
0 g
s
.64523 .76276 m .64348 .74414 L .65058 .73625 L p .707 .577 .707 r
F P
0 g
s
.66253 .59925 m .65825 .63558 L .64192 .64237 L p .707 .577 .707 r
F P
0 g
s
.66818 .5586 m .66038 .61275 L .64406 .61943 L p .707 .577 .707 r
F P
0 g
s
.65058 .73625 m .65233 .75487 L .64523 .76276 L p .707 .577 .707 r
F P
0 g
s
.803 .62717 m .80632 .60413 L p .83158 .58344 L .707 .577 .707 r
F P
0 g
s
.81081 .57302 m .803 .62717 L .77613 .61847 L p .707 .577 .707 r
F P
0 g
s
.77346 .63872 m .74308 .6333 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77613 .61847 m .77586 .61838 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.7762 .61794 m .81081 .57302 L .77613 .61847 L .707 .577 .707 r
F
.78366 .56423 m .81081 .57302 L p .7762 .61794 L F P
0 g
s
.74308 .6333 m .74736 .59697 L .77823 .60247 L p .707 .577 .707 r
F P
0 g
s
.74308 .6333 m .77823 .60247 L .77822 .60258 L .707 .577 .707 r
F
.77586 .61838 m .77912 .59572 L p .7762 .61794 L F P
0 g
s
.77912 .59572 m .78366 .56423 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.77823 .60247 m .77833 .60249 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77833 .60249 m .77405 .63882 L .77346 .63872 L p .707 .577 .707 r
F P
0 g
s
.77822 .60258 m .77833 .60249 L .77346 .63872 L .707 .577 .707 r
F
.80557 .61051 m .80129 .64683 L .79982 .6464 L p F P
0 g
s
.79982 .6464 m .77405 .63882 L p .80531 .61075 L .707 .577 .707 r
F P
0 g
s
.80531 .61075 m .80557 .61051 L .79982 .6464 L .707 .577 .707 r
F
.80632 .60413 m .81081 .57302 L .81109 .57316 L p F P
0 g
s
.81109 .57316 m .83158 .58344 L p .80632 .60413 L .707 .577 .707 r
F P
0 g
s
.65825 .63558 m .66253 .59925 L .68649 .59526 L p .707 .577 .707 r
F P
0 g
s
.66038 .61275 m .66818 .5586 L .69209 .55497 L p .707 .577 .707 r
F P
0 g
s
.39682 .69811 m .39507 .67949 L .36404 .68058 L p .707 .577 .707 r
F P
0 g
s
.39507 .67949 m .39682 .69811 L .42853 .69464 L p .707 .577 .707 r
F P
0 g
s
.42853 .69464 m .42678 .67601 L .39507 .67949 L p .707 .577 .707 r
F P
0 g
s
.36404 .68058 m .36579 .69921 L .39682 .69811 L p .707 .577 .707 r
F P
0 g
s
.3861 .70969 m .39038 .67336 L .35942 .66784 L p .707 .577 .707 r
F P
0 g
s
.39038 .67336 m .3861 .70969 L .41775 .71218 L p .707 .577 .707 r
F P
0 g
s
.41775 .71218 m .42203 .67585 L .39038 .67336 L p .707 .577 .707 r
F P
0 g
s
.84368 .72218 m .84543 .74081 L .83293 .73507 L p .707 .577 .707 r
F P
0 g
s
.83293 .73507 m .83119 .71644 L .84368 .72218 L p .707 .577 .707 r
F P
0 g
s
.42678 .67601 m .42853 .69464 L .45781 .68911 L p .707 .577 .707 r
F P
0 g
s
.45781 .68911 m .45606 .67049 L .42678 .67601 L p .707 .577 .707 r
F P
0 g
s
.48024 .55542 m .47244 .60957 L .48876 .6029 L p .707 .577 .707 r
F P
0 g
s
.48876 .6029 m .49656 .54875 L .48024 .55542 L p .707 .577 .707 r
F P
0 g
s
.31684 .53058 m .30904 .58473 L .32981 .59515 L p .707 .577 .707 r
F P
0 g
s
.42203 .67585 m .41775 .71218 L .44698 .71139 L p .707 .577 .707 r
F P
0 g
s
.44698 .71139 m .45126 .67507 L .42203 .67585 L p .707 .577 .707 r
F P
0 g
s
.80129 .64683 m .80557 .61051 L .82644 .62023 L p .707 .577 .707 r
F P
0 g
s
.35514 .70417 m .35942 .66784 L .33218 .65982 L p .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36404 .68058 L .36121 .68043 L p .707 .577 .707 r
F P
0 g
s
.35942 .66784 m .35514 .70417 L .36111 .70523 L p .707 .577 .707 r
F P
0 g
s
.36125 .6707 m .35942 .66784 L .36111 .70523 L .707 .577 .707 r
F
.33218 .65982 m .3279 .69615 L .35514 .70417 L p F P
0 g
s
.36121 .68043 m .33672 .67918 L p .36115 .69601 L .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36121 .68043 L .36115 .69601 L .707 .577 .707 r
F
.33672 .67918 m .33847 .69781 L .36579 .69921 L p F P
0 g
s
.36111 .70523 m .3861 .70969 L p .36125 .6707 L .707 .577 .707 r
F P
0 g
s
.30904 .58473 m .31684 .53058 L .30447 .51955 L p .707 .577 .707 r
F P
0 g
s
.45606 .67049 m .45781 .68911 L .4818 .68209 L p .707 .577 .707 r
F P
0 g
s
.4818 .68209 m .48005 .66346 L .45606 .67049 L p .707 .577 .707 r
F P
0 g
s
.68649 .59526 m .68221 .63159 L .65825 .63558 L p .707 .577 .707 r
F P
0 g
s
.69209 .55497 m .68429 .60913 L .66038 .61275 L p .707 .577 .707 r
F P
0 g
s
.45126 .67507 m .44698 .71139 L .47094 .70741 L p .707 .577 .707 r
F P
0 g
s
.47094 .70741 m .47522 .67108 L .45126 .67507 L p .707 .577 .707 r
F P
0 g
s
.68221 .63159 m .68649 .59526 L .71572 .59448 L p .707 .577 .707 r
F P
0 g
s
.68429 .60913 m .69209 .55497 L .72125 .55474 L p .707 .577 .707 r
F P
0 g
s
.65233 .75487 m .65058 .73625 L .66693 .7284 L p .707 .577 .707 r
F P
0 g
s
.3279 .69615 m .33218 .65982 L .31131 .6501 L p .707 .577 .707 r
F P
0 g
s
.66693 .7284 m .66868 .74703 L .65233 .75487 L p .707 .577 .707 r
F P
0 g
s
.31131 .6501 m .30703 .68643 L .3279 .69615 L p .707 .577 .707 r
F P
0 g
s
.33847 .69781 m .33672 .67918 L .31579 .67543 L p .707 .577 .707 r
F P
0 g
s
.30447 .51955 m .29667 .5737 L .30904 .58473 L p .707 .577 .707 r
F P
0 g
s
.77405 .63882 m .77833 .60249 L .80557 .61051 L p .707 .577 .707 r
F P
0 g
s
.31579 .67543 m .31754 .69405 L .33847 .69781 L p .707 .577 .707 r
F P
0 g
s
.74736 .59697 m .74308 .6333 L .71144 .63081 L p .707 .577 .707 r
F P
0 g
s
.78366 .56423 m .77586 .61838 L .745 .61208 L p .707 .577 .707 r
F P
0 g
s
.71144 .63081 m .71572 .59448 L .74736 .59697 L p .707 .577 .707 r
F P
0 g
s
.745 .61208 m .7528 .55793 L .78366 .56423 L p .707 .577 .707 r
F P
0 g
s
.49656 .54875 m .48876 .6029 L .49589 .59384 L p .707 .577 .707 r
F P
0 g
s
.49589 .59384 m .50369 .53969 L .49656 .54875 L p .707 .577 .707 r
F P
0 g
s
.83119 .71644 m .83293 .73507 L .81201 .73131 L p .707 .577 .707 r
F P
0 g
s
.81201 .73131 m .81026 .71269 L .83119 .71644 L p .707 .577 .707 r
F P
0 g
s
.71572 .59448 m .71144 .63081 L .68221 .63159 L p .707 .577 .707 r
F P
0 g
s
.71344 .60889 m .72125 .55474 L .7528 .55793 L p .707 .577 .707 r
F P
0 g
s
.72125 .55474 m .71344 .60889 L .68429 .60913 L p .707 .577 .707 r
F P
0 g
s
.48005 .66346 m .4818 .68209 L .49814 .67425 L p .707 .577 .707 r
F P
0 g
s
.49814 .67425 m .49639 .65562 L .48005 .66346 L p .707 .577 .707 r
F P
0 g
s
.29667 .5737 m .30447 .51955 L .30172 .50899 L p .707 .577 .707 r
F P
0 g
s
.7528 .55793 m .745 .61208 L .71344 .60889 L p .707 .577 .707 r
F P
0 g
s
.47522 .67108 m .47094 .70741 L .48727 .70062 L p .707 .577 .707 r
F P
0 g
s
.48727 .70062 m .49155 .66429 L .47522 .67108 L p .707 .577 .707 r
F P
0 g
s
.30703 .68643 m .31131 .6501 L .29887 .63962 L p .707 .577 .707 r
F P
0 g
s
.66868 .74703 m .66693 .7284 L .69092 .72138 L p .707 .577 .707 r
F P
0 g
s
.29887 .63962 m .29459 .67595 L .30703 .68643 L p .707 .577 .707 r
F P
0 g
s
.31754 .69405 m .31579 .67543 L .3033 .66968 L p .707 .577 .707 r
F P
0 g
s
.69092 .72138 m .69267 .74 L .66868 .74703 L p .707 .577 .707 r
F P
0 g
s
.3033 .66968 m .30505 .68831 L .31754 .69405 L p .707 .577 .707 r
F P
0 g
s
.30172 .50899 m .29391 .56314 L .29667 .5737 L p .707 .577 .707 r
F P
0 g
s
.81026 .71269 m .81201 .73131 L .78469 .72991 L p .707 .577 .707 r
F P
0 g
s
.78469 .72991 m .78294 .71129 L .81026 .71269 L p .707 .577 .707 r
F P
0 g
s
.50369 .53969 m .49589 .59384 L .49314 .58327 L p .707 .577 .707 r
F P
0 g
s
.49314 .58327 m .50094 .52912 L .50369 .53969 L p .707 .577 .707 r
F P
0 g
s
.49639 .65562 m .49814 .67425 L .50525 .66636 L p .707 .577 .707 r
F P
0 g
s
.50525 .66636 m .5035 .64773 L .49639 .65562 L p .707 .577 .707 r
F P
0 g
s
.49155 .66429 m .48727 .70062 L .49439 .69168 L p .707 .577 .707 r
F P
0 g
s
.49439 .69168 m .49867 .65535 L .49155 .66429 L p .707 .577 .707 r
F P
0 g
s
.69267 .74 m .69092 .72138 L .7202 .71586 L p .707 .577 .707 r
F P
0 g
s
.29391 .56314 m .30172 .50899 L .30885 .49993 L p .707 .577 .707 r
F P
0 g
s
.7202 .71586 m .72195 .73448 L .69267 .74 L p .707 .577 .707 r
F P
0 g
s
.29459 .67595 m .29887 .63962 L .29607 .62942 L p .707 .577 .707 r
F P
0 g
s
.78294 .71129 m .78469 .72991 L .75366 .73101 L p .707 .577 .707 r
F P
0 g
s
.75366 .73101 m .75191 .71238 L .78294 .71129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.72195 .73448 m .7202 .71586 L .75191 .71238 L p .707 .577 .707 r
F P
0 g
s
.30505 .68831 m .3033 .66968 L .30047 .66252 L p .707 .577 .707 r
F P
0 g
s
.75191 .71238 m .75366 .73101 L .72195 .73448 L p .707 .577 .707 r
F P
0 g
s
.30047 .66252 m .30222 .68114 L .30505 .68831 L p .707 .577 .707 r
F P
0 g
s
.29607 .62942 m .29179 .66575 L .29459 .67595 L p .707 .577 .707 r
F P
0 g
s
.30885 .49993 m .30105 .55408 L .29391 .56314 L p .707 .577 .707 r
F P
0 g
s
.50094 .52912 m .49314 .58327 L .48077 .57224 L p .707 .577 .707 r
F P
0 g
s
.48077 .57224 m .48857 .51809 L .50094 .52912 L p .707 .577 .707 r
F P
0 g
s
.5035 .64773 m .50525 .66636 L .50242 .65919 L p .707 .577 .707 r
F P
0 g
s
.50242 .65919 m .50067 .64056 L .5035 .64773 L p .707 .577 .707 r
F P
0 g
s
.49867 .65535 m .49439 .69168 L .49159 .68147 L p .707 .577 .707 r
F P
0 g
s
.49159 .68147 m .49587 .64514 L .49867 .65535 L p .707 .577 .707 r
F P
0 g
s
.30105 .55408 m .30885 .49993 L .32517 .49325 L p .707 .577 .707 r
F P
0 g
s
.29179 .66575 m .29607 .62942 L .30319 .62048 L p .707 .577 .707 r
F P
0 g
s
.30222 .68114 m .30047 .66252 L .30757 .65463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30757 .65463 m .30932 .67325 L .30222 .68114 L p .707 .577 .707 r
F P
0 g
s
.30319 .62048 m .29891 .65681 L .29179 .66575 L p .707 .577 .707 r
F P
0 g
s
.32517 .49325 m .31737 .54741 L .30105 .55408 L p .707 .577 .707 r
F P
0 g
s
.48857 .51809 m .48077 .57224 L .45999 .56182 L p .707 .577 .707 r
F P
0 g
s
.45999 .56182 m .4678 .50767 L .48857 .51809 L p .707 .577 .707 r
F P
0 g
s
.31737 .54741 m .32517 .49325 L .34908 .48963 L p .707 .577 .707 r
F P
0 g
s
.49587 .64514 m .49159 .68147 L .47915 .67099 L p .707 .577 .707 r
F P
0 g
s
.47915 .67099 m .48343 .63466 L .49587 .64514 L p .707 .577 .707 r
F P
0 g
s
.50067 .64056 m .50242 .65919 L .48992 .65345 L p .707 .577 .707 r
F P
0 g
s
.48992 .65345 m .48818 .63482 L .50067 .64056 L p .707 .577 .707 r
F P
0 g
s
.29891 .65681 m .30319 .62048 L .31952 .61368 L p .707 .577 .707 r
F P
0 g
s
.30932 .67325 m .30757 .65463 L .32392 .64679 L p .707 .577 .707 r
F P
0 g
s
.4678 .50767 m .45999 .56182 L .43285 .55303 L p .707 .577 .707 r
F P
0 g
s
.43285 .55303 m .44065 .49888 L .4678 .50767 L p .707 .577 .707 r
F P
0 g
s
.34908 .48963 m .34128 .54378 L .31737 .54741 L p .707 .577 .707 r
F P
0 g
s
.34128 .54378 m .34908 .48963 L .37824 .48939 L p .707 .577 .707 r
F P
0 g
s
.31952 .61368 m .31524 .65001 L .29891 .65681 L p .707 .577 .707 r
F P
0 g
s
.32392 .64679 m .32567 .66541 L .30932 .67325 L p .707 .577 .707 r
F P
0 g
s
.48343 .63466 m .47915 .67099 L .45828 .66127 L p .707 .577 .707 r
F P
0 g
s
.45828 .66127 m .46256 .62494 L .48343 .63466 L p .707 .577 .707 r
F P
0 g
s
.48818 .63482 m .48992 .65345 L .469 .64969 L p .707 .577 .707 r
F P
0 g
s
.469 .64969 m .46725 .63107 L .48818 .63482 L p .707 .577 .707 r
F P
0 g
s
.44065 .49888 m .43285 .55303 L .40199 .54674 L p .707 .577 .707 r
F P
0 g
s
.40199 .54674 m .40979 .49258 L .44065 .49888 L p .707 .577 .707 r
F P
0 g
s
.37043 .54355 m .37824 .48939 L .40979 .49258 L p .707 .577 .707 r
F P
0 g
s
.37824 .48939 m .37043 .54355 L .34128 .54378 L p .707 .577 .707 r
F P
0 g
s
.31524 .65001 m .31952 .61368 L .34348 .6097 L p .707 .577 .707 r
F P
0 g
s
.40979 .49258 m .40199 .54674 L .37043 .54355 L p .707 .577 .707 r
F P
0 g
s
.32567 .66541 m .32392 .64679 L .34791 .63976 L p .707 .577 .707 r
F P
0 g
s
.34791 .63976 m .34966 .65839 L .32567 .66541 L p .707 .577 .707 r
F P
0 g
s
.34348 .6097 m .3392 .64603 L .31524 .65001 L p .707 .577 .707 r
F P
0 g
s
.46256 .62494 m .45828 .66127 L .43629 .6548 L p .707 .577 .707 r
F P
0 g
s
.4364 .64848 m .41065 .64939 L p .43668 .63186 L .707 .577 .707 r
F P
0 g
s
.43629 .6548 m .43104 .65326 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.4364 .64844 m .46256 .62494 L .43629 .6548 L .707 .577 .707 r
F
.41065 .64939 m .4089 .63076 L .43672 .62978 L p F P
0 g
s
.41065 .64939 m .43672 .62978 L .43668 .63186 L .707 .577 .707 r
F
.43104 .65326 m .43532 .61693 L .43693 .6174 L p F P
0 g
s
.43693 .6174 m .46256 .62494 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.43104 .65326 m .43693 .6174 L .4364 .64844 L .707 .577 .707 r
F
.43672 .62978 m .43993 .62967 L p .43668 .63186 L F P
0 g
s
.43993 .62967 m .44168 .64829 L .4364 .64848 L p .707 .577 .707 r
F P
0 g
s
.43668 .63186 m .43993 .62967 L .4364 .64848 L .707 .577 .707 r
F
.46725 .63107 m .469 .64969 L .44168 .64829 L p F P
0 g
s
.44168 .64829 m .43993 .62967 L .46725 .63107 L p .707 .577 .707 r
F P
0 g
s
.3392 .64603 m .34348 .6097 L .37271 .60891 L p .707 .577 .707 r
F P
0 g
s
.34966 .65839 m .34791 .63976 L .37719 .63424 L p .707 .577 .707 r
F P
0 g
s
.4089 .63076 m .41065 .64939 L .37894 .65286 L p .707 .577 .707 r
F P
0 g
s
.43532 .61693 m .43104 .65326 L .40007 .64773 L p .707 .577 .707 r
F P
0 g
s
.37894 .65286 m .37719 .63424 L .4089 .63076 L p .707 .577 .707 r
F P
0 g
s
.40007 .64773 m .40435 .6114 L .43532 .61693 L p .707 .577 .707 r
F P
0 g
s
.37719 .63424 m .37894 .65286 L .34966 .65839 L p .707 .577 .707 r
F P
0 g
s
.37271 .60891 m .36843 .64524 L .3392 .64603 L p .707 .577 .707 r
F P
0 g
s
.36843 .64524 m .37271 .60891 L .40435 .6114 L p .707 .577 .707 r
F P
0 g
s
.40435 .6114 m .40007 .64773 L .36843 .64524 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007Ao
o`00Kgoo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`00L7oo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001]Ool006]oo`<000UJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH006Yoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0061ooa0000MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@002UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001IOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001VOol005Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Io
o`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH500000eYF001JEP02FUH3
0002FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001J
EP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00@005YF001JEP<000EJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`04001JEP000002FUH00`00FUIJEP02
FUH00`00FUIJEP06FUH00`00FUIJEP050009FUH50005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
4000C7oo001COol30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP02FUH400000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo10000eYF00<005YFFUH01UYF00@0
05YFFUIJEPL004Eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF3P001EYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01000@Goo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50006FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00Dgoo00<005YF
FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH005YF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH3000fOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P00=Goo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF0P002EYF0`00<Woo000iOol@000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00]JEP80
031oo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`0^Ool0039oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000Aoo`8000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00Oomoo`0]Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00Oomoo`0/Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000goo000000020002FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=oo`D000IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP020003Ool00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P0000=JEP0000000P000UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo
000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHH0002FUH00`00FUIJEP05FUH01000FUIJEUYF1@0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP8000EJEP<000EJEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0>00000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH40003FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH20006FUH30004FUH01P00FUIJEP00FUH002aoo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF
0080009JEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`000UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEP0000<002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP04001JEUYFFUH@0004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH010001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH500000eYF001JEP06FUH00`00FUIJEP04FUH8
0005FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000]Ool20003FUH50000
0eYF001JEP040009Ool70006FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo000/
Ool01000FUH005YF0`001EYF00<005YFFUH00eYF1@002goo100000AJEP00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0007FUH00`00FUIJ
EP02FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EUYF001JEP800004FUH005YFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool200000eYF001JEP02FUH0
1000FUIJEUYF400015YF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF00=JEP06001JEUYF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF009J
EP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF009J
EP8002eoo`00;7oo0`000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH015YF1`001Goo
0P000eYF1@001EYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF00<005YF
FUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=J
EP03001JEP0000<000]JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF1`0000=JEP0000000P000UYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF1@001eYF
00<005YFFUH00eYF10000UYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP8000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00H005YF000005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP040004FUH00`00FUIJEP07FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEP03001JEUYF00iJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF1@001UYF0P000UYF0P0015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00@005YFFUIJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP0>FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH2000^Ool002eoo`05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50006FUH2000015YF001JEP0015YF00<005YF0000
1@0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJEP05001JEUYF001J
EP04000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<0
05YFFUH03UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000^Ool0
02eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH20002FUH00`00
FUH00003FUH40005FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000025YF
001JEUYF001JEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUIJEP0>FUH00`00FUH000020004FUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH3000^Ool002ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP80009JEP04001JEP00FUH20003FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH300000eYF000000030002FUH01P00FUH00000FUH000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP02FUH017ooFUIJEUYF0P00
1UYF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01@00;Woo000_Ool20006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000EJEP03001J
EUYF00]JEPL000EJEP04001JEUYFFUH80003FUH01000FUH005YF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH010000UYF1P000eYF00<005YFFUH01EYF00@005YFFUIJEPH0009JEP<002ioo`00<7oo
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80
009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP<00003FUH005YF00AJEP03001JEP0000IJEPP000=JEP03001JEUYF009J
EPL000=JEP05001JEUYFOomJEP03000^Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00X0009JEP03001JEUYF00=JEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000IJEP03001JEUYF00IJ
EP03001JEP0000/000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;goo000cOol200000eYF
001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP04
001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00<7oo000eOol30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01@00FUIJEUYF000015YF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006FUH01000FUIJEUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00>7oo10000UYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH02UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000lOol50006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUH000020004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<007oo0000200015YF00<005YFFUH01EYF00@005YFFUIJEPD003Aoo`00@Goo10000UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo00Qooa0003Uoo`00=goo5@0015YF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH30005FUH0
1P00FUIJEP00FUH005=oo`00<goo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF5@001goo1`00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000AJEP06
001JEUYF001JEP00Dgoo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000>Ool01@00FUIJEP00FUH0200015YF00<005YFFUH01UYF00@005YFFUIJEP@000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF0080009JEP06001JEUYF001JEP00Dgoo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool01000FUIJEP001EYF00@005YF
FUIJEQ400003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<0009JEP8000QooaP003Aoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P0027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00=JEP80009JEP80009oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00=JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJ
EP0400001Goo001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH002eoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP03001JEUYF00=JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF009JEQH000AJEP03001JEUYF008002aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF009J
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00EJEP03001JEUYF00AJEPL001Ioo`<00003FUH005YF009JEP03001oogoo02Yoo`00
;7oo00<005YF00000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000MJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00AJEP03001JEUYF00@0021oo`<0009JEP03001oogoo02Yoo`00;7oo0P00
15YF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJEP03001J
EUYF009JEP@00003FUH007oo025oo`800003FUH00000008002]oo`00;7oo0P000UYF100000=JEP00
FUH01EYF00<005YFFUH015YF1P001Woo1@001eYF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YF00007goo
0`000eYF00@005YF000002]oo`00;7oo00=JEP0000000`000eYF00<005YFFUH015YF00<005YFFUH0
10004Goo0`0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04
001JEUYFFUH300000eYF00000003FUH00`00FUH0000LOol300000eYF001JEP04FUH00`00FUH0000[
Ool002]oo`80009JEP8000AJEP03001JEUYF00=JEP@001Qoo`<00003FUH005YF00AJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUH0000015YF00<005YF0000
0UYF0P006Goo100015YF00<005YFFUH00eYF0P00;7oo000[Ool2000015YF001JEP0015YF00<005YF
00000`007goo0`0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF
00@005YF001JEP8000EJEP80009JEP04001JEP00000EOol40002FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH00`00Oomoo`0[Ool002]oo`06001JEUYF001JEP000eYF10000eYF0`007Woo100000AJEP00
FUIJEP80009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP05001JEP00001JEP04
0002FUH00`00FUIJEP02FUH3000>Ool70006FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002]o
o`07001JEUYF001JEP00FUH00P000eYF00<005YFFUH015YF00<005YF00000P005Woo0`000eYF0`00
0UYF0P000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP04001JEP000002FUH00`00FUIJEP0H0004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH3000`Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP09
FUH90009Ool400000eYF0000000300000eYF00000002FUH20002FUH01000FUH000001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000bOol002aoo`04001JEP000002FUH3
0002FUH00`00FUIJEP0=FUH00`00FUIJEP02FUH?0005FUH00`00FUH000030002FUH200000eYF001J
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000dOol002eoo`<0009JEP03
001JEUYF00X000QJEP@000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000<000EJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD003Qoo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF001JEP030003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000mOol002moo`05001JEUYFFUH00004FUH00`00
FUIJEP0<FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP0015YF1`0015YF00<005YFFUH00UYF2@00
AWoo000`Ool200000eYF001JEP04FUH00`00FUIJEP0:FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001J
EP001UYF00D005YF000007oo00T004moo`00<Woo10000eYF00<005YFFUH02UYF00<005YF00000P00
15YF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP06001JEUYF001JEP000eYF1@00Fgoo000eOol:0007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=oo`00FUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001P00H7oo000hOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P00Igoo000lOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH000001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P00J7oo0013Ool80004
FUH00`00FUIJEP06FUH01000FUIJEUYF10002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Bgoo4@00
3goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YF00004P00Fgoo001]Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05FUH00`00FUIJ
EP04001GOol006moo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<005Eo
o`00LWoo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH005Aoo`00NGoo30001UYF00<005YF
FUH02UYF00<005YFFUH01P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH005Aoo`00QGoo5P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF20000eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo002COol200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90008Ool60003FUH01@00FUIJEUYF0000Dgoo002AOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9000GOol50002FUH00`00Oomoo`1AOol0091oo`80
00EJEP03001JEUYF009JEPH002=oo`H0059oo`00Sgoo00<005YF00001EYF00<005YF00000P009goo
0P000UYF00@005YF0000059oo`00Sgoo00@005YFFUH000=JEP<002Qoo`8000AJEP04001JEUYF001B
Ool008moo`05001JEUYF001JEP02000XOol300000eYF001JEP04FUH2001COol008moo`03001JEUYF
008002Aoo`H000AJEP03001JEUYF00=JEP8005=oo`00T7oo0P0000=JEP0000000P0067oo2@0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00T7oo0P000UYF00<005YFFUH0600015YF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000005Ioo`00T7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00F7oo
002@Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00003001KOol0095oo`800003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD005moo`00Tgoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00I7oo002GOol70004FUH00`00FUIJEP02FUH9001]
Ool009ioo`T007Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59801 .73071 m .59021 .67488 L .55935 .67744 L p .707 .577 .707 r
F P
0 g
s
.59021 .67488 m .59801 .73071 L .62956 .7259 L p .707 .577 .707 r
F P
0 g
s
.62956 .7259 m .62176 .67007 L .59021 .67488 L p .707 .577 .707 r
F P
0 g
s
.62176 .67007 m .62956 .7259 L .65872 .71933 L p .707 .577 .707 r
F P
0 g
s
.65872 .71933 m .65092 .6635 L .62176 .67007 L p .707 .577 .707 r
F P
0 g
s
.56715 .73327 m .55935 .67744 L .5322 .67751 L p .707 .577 .707 r
F P
0 g
s
.55935 .67744 m .56715 .73327 L .59801 .73071 L p .707 .577 .707 r
F P
0 g
s
.65092 .6635 m .65872 .71933 L .68263 .71162 L p .707 .577 .707 r
F P
0 g
s
.68263 .71162 m .67483 .6558 L .65092 .6635 L p .707 .577 .707 r
F P
0 g
s
.5322 .67751 m .54 .73334 L .56715 .73327 L p .707 .577 .707 r
F P
0 g
s
.54 .73334 m .5322 .67751 L .51143 .67509 L p .707 .577 .707 r
F P
0 g
s
.59992 .83211 m .59564 .79487 L .56468 .79663 L p .707 .577 .707 r
F P
0 g
s
.59564 .79487 m .59992 .83211 L .63157 .82803 L p .707 .577 .707 r
F P
0 g
s
.63157 .82803 m .62729 .79078 L .59564 .79487 L p .707 .577 .707 r
F P
0 g
s
.67483 .6558 m .68263 .71162 L .69895 .70355 L p .707 .577 .707 r
F P
0 g
s
.69895 .70355 m .69115 .64772 L .67483 .6558 L p .707 .577 .707 r
F P
0 g
s
.62729 .79078 m .63157 .82803 L .6608 .82202 L p .707 .577 .707 r
F P
0 g
s
.6608 .82202 m .65652 .78478 L .62729 .79078 L p .707 .577 .707 r
F P
0 g
s
.51143 .67509 m .51923 .73091 L .54 .73334 L p .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56468 .79663 L .56307 .79659 L p .707 .577 .707 r
F P
0 g
s
.56328 .80889 m .56007 .80838 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56307 .79659 L .5636 .82742 L .707 .577 .707 r
F
.56468 .79663 m .56896 .83388 L .59992 .83211 L p F P
0 g
s
.56007 .80838 m .55832 .82663 L .5636 .82746 L p .707 .577 .707 r
F P
0 g
s
.56371 .83374 m .56896 .83388 L p .5636 .82742 L .707 .577 .707 r
F P
0 g
s
.5636 .82746 m .58935 .8315 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56331 .81095 m .56007 .80838 L .5636 .82746 L .707 .577 .707 r
F
.55832 .82663 m .56007 .80838 L .53275 .80103 L p F P
0 g
s
.53275 .80103 m .531 .81928 L .55832 .82663 L p .707 .577 .707 r
F P
0 g
s
.53744 .79591 m .54172 .83316 L .56371 .83374 L p .707 .577 .707 r
F P
0 g
s
.5636 .82742 m .53744 .79591 L .56371 .83374 L .707 .577 .707 r
F
.56307 .79659 m .53744 .79591 L p .5636 .82742 L F P
0 g
s
.58935 .8315 m .5911 .81325 L .56328 .80889 L p .707 .577 .707 r
F P
0 g
s
.58935 .8315 m .56328 .80889 L .56331 .81095 L .707 .577 .707 r
F
.5911 .81325 m .58935 .8315 L .62106 .83339 L p F P
0 g
s
.62106 .83339 m .62281 .81514 L .5911 .81325 L p .707 .577 .707 r
F P
0 g
s
.62281 .81514 m .62106 .83339 L .65034 .83213 L p .707 .577 .707 r
F P
0 g
s
.65034 .83213 m .65209 .81388 L .62281 .81514 L p .707 .577 .707 r
F P
0 g
s
.65652 .78478 m .6608 .82202 L .68475 .81469 L p .707 .577 .707 r
F P
0 g
s
.68475 .81469 m .68047 .77744 L .65652 .78478 L p .707 .577 .707 r
F P
0 g
s
.51923 .73091 m .51143 .67509 L .49906 .6704 L p .707 .577 .707 r
F P
0 g
s
.65209 .81388 m .65034 .83213 L .67433 .82785 L p .707 .577 .707 r
F P
0 g
s
.67433 .82785 m .67608 .8096 L .65209 .81388 L p .707 .577 .707 r
F P
0 g
s
.531 .81928 m .53275 .80103 L .51182 .7919 L p .707 .577 .707 r
F P
0 g
s
.54172 .83316 m .53744 .79591 L .51657 .79276 L p .707 .577 .707 r
F P
0 g
s
.69115 .64772 m .69895 .70355 L .70608 .69589 L p .707 .577 .707 r
F P
0 g
s
.70608 .69589 m .69828 .64007 L .69115 .64772 L p .707 .577 .707 r
F P
0 g
s
.49906 .6704 m .50686 .72622 L .51923 .73091 L p .707 .577 .707 r
F P
0 g
s
.51182 .7919 m .51007 .81015 L .531 .81928 L p .707 .577 .707 r
F P
0 g
s
.51657 .79276 m .52085 .83001 L .54172 .83316 L p .707 .577 .707 r
F P
0 g
s
.68047 .77744 m .68475 .81469 L .70109 .80674 L p .707 .577 .707 r
F P
0 g
s
.70109 .80674 m .69681 .76949 L .68047 .77744 L p .707 .577 .707 r
F P
0 g
s
.67608 .8096 m .67433 .82785 L .69068 .82095 L p .707 .577 .707 r
F P
0 g
s
.69068 .82095 m .69242 .8027 L .67608 .8096 L p .707 .577 .707 r
F P
0 g
s
.50686 .72622 m .49906 .6704 L .49631 .66391 L p .707 .577 .707 r
F P
0 g
s
.51007 .81015 m .51182 .7919 L .49933 .7819 L p .707 .577 .707 r
F P
0 g
s
.52085 .83001 m .51657 .79276 L .50413 .7875 L p .707 .577 .707 r
F P
0 g
s
.49933 .7819 m .49758 .80015 L .51007 .81015 L p .707 .577 .707 r
F P
0 g
s
.50413 .7875 m .50841 .82475 L .52085 .83001 L p .707 .577 .707 r
F P
0 g
s
.69828 .64007 m .70608 .69589 L .70333 .6894 L p .707 .577 .707 r
F P
0 g
s
.70333 .6894 m .69553 .63358 L .69828 .64007 L p .707 .577 .707 r
F P
0 g
s
.49631 .66391 m .50411 .71973 L .50686 .72622 L p .707 .577 .707 r
F P
0 g
s
.69681 .76949 m .70109 .80674 L .70821 .79895 L p .707 .577 .707 r
F P
0 g
s
.70821 .79895 m .70393 .76171 L .69681 .76949 L p .707 .577 .707 r
F P
0 g
s
.69242 .8027 m .69068 .82095 L .69778 .81211 L p .707 .577 .707 r
F P
0 g
s
.69778 .81211 m .69953 .79386 L .69242 .8027 L p .707 .577 .707 r
F P
0 g
s
.4904 .8221 m .49342 .32054 L .44941 .31759 L p .707 .577 .707 r
F P
0 g
s
.50841 .82475 m .50413 .7875 L .50133 .78065 L p .707 .577 .707 r
F P
0 g
s
.49758 .80015 m .49933 .7819 L .4965 .77199 L p .707 .577 .707 r
F P
0 g
s
.50411 .71973 m .49631 .66391 L .50344 .65625 L p .707 .577 .707 r
F P
0 g
s
.4965 .77199 m .49475 .79024 L .49758 .80015 L p .707 .577 .707 r
F P
0 g
s
.50133 .78065 m .50561 .8179 L .50841 .82475 L p .707 .577 .707 r
F P
0 g
s
.50344 .65625 m .51124 .71208 L .50411 .71973 L p .707 .577 .707 r
F P
0 g
s
.49475 .79024 m .4965 .77199 L .5036 .76316 L p .707 .577 .707 r
F P
0 g
s
.51124 .71208 m .50344 .65625 L .51976 .64818 L p .707 .577 .707 r
F P
0 g
s
.50561 .8179 m .50133 .78065 L .50845 .77286 L p .707 .577 .707 r
F P
0 g
s
.5036 .76316 m .50186 .78141 L .49475 .79024 L p .707 .577 .707 r
F P
0 g
s
.50845 .77286 m .51273 .81011 L .50561 .8179 L p .707 .577 .707 r
F P
0 g
s
.51976 .64818 m .52756 .704 L .51124 .71208 L p .707 .577 .707 r
F P
0 g
s
.52756 .704 m .51976 .64818 L .54367 .64047 L p .707 .577 .707 r
F P
0 g
s
.50186 .78141 m .5036 .76316 L .51995 .75626 L p .707 .577 .707 r
F P
0 g
s
.51273 .81011 m .50845 .77286 L .52478 .76492 L p .707 .577 .707 r
F P
0 g
s
.51995 .75626 m .5182 .77451 L .50186 .78141 L p .707 .577 .707 r
F P
0 g
s
.52478 .76492 m .52906 .80216 L .51273 .81011 L p .707 .577 .707 r
F P
0 g
s
.52906 .80216 m .52478 .76492 L .54874 .75758 L p .707 .577 .707 r
F P
0 g
s
.5182 .77451 m .51995 .75626 L .54394 .75197 L p .707 .577 .707 r
F P
0 g
s
.54394 .75197 m .54219 .77022 L .5182 .77451 L p .707 .577 .707 r
F P
0 g
s
.54874 .75758 m .55302 .79483 L .52906 .80216 L p .707 .577 .707 r
F P
0 g
s
.49342 .32054 m .4904 .8221 L .53534 .82124 L p .707 .577 .707 r
F P
0 g
s
.54367 .64047 m .55147 .6963 L .52756 .704 L p .707 .577 .707 r
F P
0 g
s
.53534 .82124 m .53836 .31969 L .49342 .32054 L p .707 .577 .707 r
F P
0 g
s
.55147 .6963 m .54367 .64047 L .57283 .6339 L p .707 .577 .707 r
F P
0 g
s
.57283 .6339 m .58063 .68973 L .55147 .6963 L p .707 .577 .707 r
F P
0 g
s
.55302 .79483 m .54874 .75758 L .57797 .75158 L p .707 .577 .707 r
F P
0 g
s
.54219 .77022 m .54394 .75197 L .57322 .75071 L p .707 .577 .707 r
F P
0 g
s
.57797 .75158 m .58225 .78882 L .55302 .79483 L p .707 .577 .707 r
F P
0 g
s
.57322 .75071 m .57147 .76897 L .54219 .77022 L p .707 .577 .707 r
F P
0 g
s
.58225 .78882 m .57797 .75158 L .60961 .74749 L p .707 .577 .707 r
F P
0 g
s
.57147 .76897 m .57322 .75071 L .60493 .75261 L p .707 .577 .707 r
F P
0 g
s
.60961 .74749 m .61389 .78474 L .58225 .78882 L p .707 .577 .707 r
F P
0 g
s
.60493 .75261 m .60318 .77086 L .57147 .76897 L p .707 .577 .707 r
F P
0 g
s
.53836 .31969 m .53534 .82124 L .57682 .81666 L p .707 .577 .707 r
F P
0 g
s
.58063 .68973 m .57283 .6339 L .60438 .6291 L p .707 .577 .707 r
F P
0 g
s
.57682 .81666 m .57984 .31511 L .53836 .31969 L p .707 .577 .707 r
F P
0 g
s
.44639 .81915 m .44941 .31759 L .41065 .31112 L p .707 .577 .707 r
F P
0 g
s
.44941 .31759 m .44639 .81915 L .4904 .8221 L p .707 .577 .707 r
F P
0 g
s
.69553 .63358 m .70333 .6894 L .69096 .68471 L p .707 .577 .707 r
F P
0 g
s
.69096 .68471 m .68316 .62889 L .69553 .63358 L p .707 .577 .707 r
F P
0 g
s
.70393 .76171 m .70821 .79895 L .70541 .7921 L p .707 .577 .707 r
F P
0 g
s
.70541 .7921 m .70113 .75485 L .70393 .76171 L p .707 .577 .707 r
F P
0 g
s
.60438 .6291 m .61218 .68492 L .58063 .68973 L p .707 .577 .707 r
F P
0 g
s
.66328 .76483 m .66153 .78308 L .63886 .77698 L p .707 .577 .707 r
F P
0 g
s
.63885 .77399 m .66328 .76483 L .63886 .77698 L .707 .577 .707 r
F
.63889 .78331 m .61389 .78474 L p .63875 .74839 L F P
0 g
s
.63421 .77572 m .63596 .75747 L .66328 .76483 L p .707 .577 .707 r
F P
0 g
s
.64057 .74572 m .64485 .78297 L .63889 .78331 L p .707 .577 .707 r
F P
0 g
s
.63875 .74839 m .64057 .74572 L .63889 .78331 L .707 .577 .707 r
F
.63886 .77698 m .63421 .77572 L p .63885 .77399 L F P
0 g
s
.61389 .78474 m .60961 .74749 L .64057 .74572 L p .707 .577 .707 r
F P
0 g
s
.63596 .75747 m .63421 .77572 L .60318 .77086 L p .707 .577 .707 r
F P
0 g
s
.60318 .77086 m .60493 .75261 L .63596 .75747 L p .707 .577 .707 r
F P
0 g
s
.57984 .31511 m .57682 .81666 L .61078 .80881 L p .707 .577 .707 r
F P
0 g
s
.61218 .68492 m .60438 .6291 L .63524 .62653 L p .707 .577 .707 r
F P
0 g
s
.61078 .80881 m .6138 .30726 L .57984 .31511 L p .707 .577 .707 r
F P
0 g
s
.69953 .79386 m .69778 .81211 L .69495 .80221 L p .707 .577 .707 r
F P
0 g
s
.69495 .80221 m .6967 .78396 L .69953 .79386 L p .707 .577 .707 r
F P
0 g
s
.40763 .81268 m .41065 .31112 L .38092 .30177 L p .707 .577 .707 r
F P
0 g
s
.41065 .31112 m .40763 .81268 L .44639 .81915 L p .707 .577 .707 r
F P
0 g
s
.255 .72242 m .2472 .66659 L .21634 .66916 L p .707 .577 .707 r
F P
0 g
s
.2472 .66659 m .255 .72242 L .28655 .71762 L p .707 .577 .707 r
F P
0 g
s
.28655 .71762 m .27875 .66179 L .2472 .66659 L p .707 .577 .707 r
F P
0 g
s
.27875 .66179 m .28655 .71762 L .31571 .71104 L p .707 .577 .707 r
F P
0 g
s
.31571 .71104 m .30791 .65522 L .27875 .66179 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22414 .72498 m .22088 .70163 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.21634 .66916 m .22414 .72498 L .255 .72242 L p .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .25263 .7068 L .22176 .70856 L p .707 .577 .707 r
F P
0 g
s
.22176 .70856 m .22167 .70857 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .22176 .70856 L .22178 .70867 L .707 .577 .707 r
F
.22595 .74581 m .22167 .70857 L .19465 .70785 L p F P
0 g
s
.19465 .70785 m .19443 .70784 L p .19469 .70816 L .707 .577 .707 r
F P
0 g
s
.22595 .74581 m .19465 .70785 L .19469 .70816 L .707 .577 .707 r
F
.19443 .70784 m .19871 .74509 L .22595 .74581 L p F P
0 g
s
.19871 .74509 m .19443 .70784 L .17381 .70473 L p .707 .577 .707 r
F P
0 g
s
.17381 .70473 m .17356 .7047 L p .17388 .70521 L .707 .577 .707 r
F P
0 g
s
.19871 .74509 m .17381 .70473 L .17388 .70521 L .707 .577 .707 r
F
.17356 .7047 m .17784 .74194 L .19871 .74509 L p F P
0 g
s
.17784 .74194 m .17356 .7047 L .1613 .69951 L p .707 .577 .707 r
F P
0 g
s
.1613 .69951 m .16112 .69944 L p .16138 .70011 L .707 .577 .707 r
F P
0 g
s
.17784 .74194 m .1613 .69951 L .16138 .70011 L .707 .577 .707 r
F
.16112 .69944 m .1654 .73668 L .17784 .74194 L p F P
0 g
s
.1654 .73668 m .16112 .69944 L .15836 .69269 L p .707 .577 .707 r
F P
0 g
s
.15836 .69269 m .15832 .69258 L p .15844 .69333 L .707 .577 .707 r
F P
0 g
s
.1654 .73668 m .15836 .69269 L .15844 .69333 L .707 .577 .707 r
F
.16385 .71794 m .16044 .69354 L p .1533 .65562 L F P
0 g
s
.16044 .69354 m .15605 .66211 L .15588 .66172 L p .707 .577 .707 r
F P
0 g
s
.15588 .66172 m .1533 .65562 L p .16044 .69354 L .707 .577 .707 r
F P
0 g
s
.17622 .72263 m .17285 .69851 L p .15605 .66211 L .707 .577 .707 r
F P
0 g
s
.16793 .66662 m .15605 .66211 L p .17285 .69851 L .707 .577 .707 r
F P
0 g
s
.15605 .66211 m .16385 .71794 L .17622 .72263 L p .707 .577 .707 r
F P
0 g
s
.15832 .69258 m .1626 .72983 L .1654 .73668 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .16385 .71794 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1533 .65562 m .15766 .68687 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.15766 .68687 m .1611 .71145 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1626 .72983 m .15832 .69258 L .15842 .69247 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .15766 .68687 L p .16043 .64797 L .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .1611 .71145 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16043 .64797 m .16479 .67915 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16479 .67915 m .16823 .70379 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.17285 .69851 m .16842 .6668 L .16793 .66662 L p .707 .577 .707 r
F P
0 g
s
.197 .72506 m .19367 .7013 L p .16842 .6668 L .707 .577 .707 r
F P
0 g
s
.18891 .6692 m .16842 .6668 L p .19367 .7013 L .707 .577 .707 r
F P
0 g
s
.16842 .6668 m .17622 .72263 L .197 .72506 L p .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .16043 .64797 L .17675 .63989 L p .707 .577 .707 r
F P
0 g
s
.16972 .72204 m .16544 .6848 L .16569 .68468 L p .707 .577 .707 r
F P
0 g
s
.18455 .69572 m .16823 .70379 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.17675 .63989 m .18112 .67114 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.18112 .67114 m .18455 .69572 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.19367 .7013 m .18919 .66923 L .18891 .6692 L p .707 .577 .707 r
F P
0 g
s
.22167 .70857 m .22595 .74581 L .22654 .74578 L p .707 .577 .707 r
F P
0 g
s
.22387 .72499 m .22414 .72498 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.22654 .74578 m .25691 .74405 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.22178 .70867 m .22167 .70857 L .22654 .74578 L .707 .577 .707 r
F
.18919 .66923 m .197 .72506 L .22387 .72499 L p F P
0 g
s
.2238 .72444 m .18919 .66923 L .22387 .72499 L .707 .577 .707 r
F
.21634 .66916 m .18919 .66923 L p .2238 .72444 L F P
0 g
s
.18455 .69572 m .17675 .63989 L .20066 .63219 L p .707 .577 .707 r
F P
0 g
s
.18605 .7141 m .18177 .67685 L .18214 .67674 L p .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .18455 .69572 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20066 .63219 m .20505 .66362 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20505 .66362 m .20846 .68802 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .20066 .63219 L .22982 .62562 L p .707 .577 .707 r
F P
0 g
s
.21001 .70676 m .20573 .66951 L .20615 .66943 L p .707 .577 .707 r
F P
0 g
s
.22088 .70163 m .21634 .66916 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .20846 .68802 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.22982 .62562 m .23425 .65733 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23425 .65733 m .23762 .68144 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .22982 .62562 L .26137 .62081 L p .707 .577 .707 r
F P
0 g
s
.23924 .70076 m .23496 .66351 L .23534 .66346 L p .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .23762 .68144 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26137 .62081 m .26585 .65288 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26585 .65288 m .26917 .67664 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .26137 .62081 L .29223 .61825 L p .707 .577 .707 r
F P
0 g
s
.27088 .69667 m .2666 .65942 L .26685 .65941 L p .707 .577 .707 r
F P
0 g
s
.29223 .61825 m .29677 .65072 L p .26917 .67664 L .707 .577 .707 r
F P
0 g
s
.30791 .65522 m .31571 .71104 L .33962 .70334 L p .707 .577 .707 r
F P
0 g
s
.33962 .70334 m .33182 .64751 L .30791 .65522 L p .707 .577 .707 r
F P
0 g
s
.29765 .65766 m .32481 .65838 L p .30227 .69423 L .707 .577 .707 r
F P
0 g
s
.29677 .65072 m .30003 .67407 L .29973 .6741 L p .707 .577 .707 r
F P
0 g
s
.29973 .6741 m .26917 .67664 L p .29677 .65072 L .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29757 .65766 L .29765 .65766 L p .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29765 .65766 L .30227 .69423 L .707 .577 .707 r
F
.26685 .65941 m .29757 .65766 L p .27227 .69465 L F P
0 g
s
.27088 .69667 m .26685 .65941 L .27227 .69465 L .707 .577 .707 r
F
.23534 .66346 m .2666 .65942 L p .24138 .69753 L F P
0 g
s
.23924 .70076 m .23534 .66346 L .24138 .69753 L .707 .577 .707 r
F
.20615 .66943 m .23496 .66351 L p .21241 .7026 L F P
0 g
s
.21001 .70676 m .20615 .66943 L .21241 .7026 L .707 .577 .707 r
F
.18214 .67674 m .20573 .66951 L p .18812 .70941 L F P
0 g
s
.18605 .7141 m .18214 .67674 L .18812 .70941 L .707 .577 .707 r
F
.16569 .68468 m .18177 .67685 L p .17098 .7173 L F P
0 g
s
.16972 .72204 m .16569 .68468 L .17098 .7173 L .707 .577 .707 r
F
.15842 .69247 m .16544 .6848 L p .16287 .72552 L F P
0 g
s
.1626 .72983 m .15842 .69247 L .16287 .72552 L .707 .577 .707 r
F
.15766 .68687 m .1533 .65562 L .15384 .65504 L p F P
0 g
s
.15384 .65504 m .16043 .64797 L p .15766 .68687 L .707 .577 .707 r
F P
0 g
s
.25263 .7068 m .25691 .74405 L .28856 .73996 L p .707 .577 .707 r
F P
0 g
s
.28856 .73996 m .28428 .70271 L .25263 .7068 L p .707 .577 .707 r
F P
0 g
s
.68316 .62889 m .69096 .68471 L .67019 .68229 L p .707 .577 .707 r
F P
0 g
s
.67019 .68229 m .66238 .62646 L .68316 .62889 L p .707 .577 .707 r
F P
0 g
s
.28428 .70271 m .28856 .73996 L .31779 .73396 L p .707 .577 .707 r
F P
0 g
s
.31779 .73396 m .31351 .69671 L .28428 .70271 L p .707 .577 .707 r
F P
0 g
s
.6967 .78396 m .69495 .80221 L .68246 .79221 L p .707 .577 .707 r
F P
0 g
s
.68246 .79221 m .68421 .77396 L .6967 .78396 L p .707 .577 .707 r
F P
0 g
s
.70113 .75485 m .70541 .7921 L .69297 .78684 L p .707 .577 .707 r
F P
0 g
s
.69297 .78684 m .68869 .74959 L .70113 .75485 L p .707 .577 .707 r
F P
0 g
s
.63524 .62653 m .64304 .68236 L .61218 .68492 L p .707 .577 .707 r
F P
0 g
s
.6138 .30726 m .61078 .80881 L .63389 .79845 L p .707 .577 .707 r
F P
0 g
s
.63389 .79845 m .63691 .2969 L .6138 .30726 L p .707 .577 .707 r
F P
0 g
s
.31351 .69671 m .31779 .73396 L .34175 .72662 L p .707 .577 .707 r
F P
0 g
s
.34175 .72662 m .33747 .68937 L .31351 .69671 L p .707 .577 .707 r
F P
0 g
s
.3779 .80332 m .38092 .30177 L .36315 .29045 L p .707 .577 .707 r
F P
0 g
s
.38092 .30177 m .3779 .80332 L .40763 .81268 L p .707 .577 .707 r
F P
0 g
s
.33182 .64751 m .33962 .70334 L .35594 .69527 L p .707 .577 .707 r
F P
0 g
s
.35594 .69527 m .34814 .63944 L .33182 .64751 L p .707 .577 .707 r
F P
0 g
s
.66238 .62646 m .67019 .68229 L .64304 .68236 L p .707 .577 .707 r
F P
0 g
s
.64304 .68236 m .63524 .62653 L .66238 .62646 L p .707 .577 .707 r
F P
0 g
s
.68421 .77396 m .68246 .79221 L .66153 .78308 L p .707 .577 .707 r
F P
0 g
s
.66153 .78308 m .66328 .76483 L .68421 .77396 L p .707 .577 .707 r
F P
0 g
s
.68869 .74959 m .69297 .78684 L .6721 .78369 L p .707 .577 .707 r
F P
0 g
s
.6721 .78369 m .66782 .74645 L .68869 .74959 L p .707 .577 .707 r
F P
0 g
s
.33747 .68937 m .34175 .72662 L .35808 .71867 L p .707 .577 .707 r
F P
0 g
s
.35808 .71867 m .3538 .68142 L .33747 .68937 L p .707 .577 .707 r
F P
0 g
s
.24634 .83948 m .24809 .82123 L .21706 .81637 L p .707 .577 .707 r
F P
0 g
s
.24809 .82123 m .24634 .83948 L .27805 .84138 L p .707 .577 .707 r
F P
0 g
s
.27805 .84138 m .2798 .82313 L .24809 .82123 L p .707 .577 .707 r
F P
0 g
s
.2798 .82313 m .27805 .84138 L .30733 .84012 L p .707 .577 .707 r
F P
0 g
s
.30733 .84012 m .30908 .82187 L .2798 .82313 L p .707 .577 .707 r
F P
0 g
s
.21706 .81637 m .21531 .83462 L .24634 .83948 L p .707 .577 .707 r
F P
0 g
s
.21531 .83462 m .21706 .81637 L .18974 .80902 L p .707 .577 .707 r
F P
0 g
s
.64485 .78297 m .64057 .74572 L .66782 .74645 L p .707 .577 .707 r
F P
0 g
s
.63691 .2969 m .63389 .79845 L .64389 .7866 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .64691 .28505 L .63691 .2969 L p .707 .577 .707 r
F P
0 g
s
.18974 .80902 m .18799 .82727 L .21531 .83462 L p .707 .577 .707 r
F P
0 g
s
.30908 .82187 m .30733 .84012 L .33132 .83583 L p .707 .577 .707 r
F P
0 g
s
.33132 .83583 m .33307 .81758 L .30908 .82187 L p .707 .577 .707 r
F P
0 g
s
.34814 .63944 m .35594 .69527 L .36307 .68761 L p .707 .577 .707 r
F P
0 g
s
.36307 .68761 m .35527 .63178 L .34814 .63944 L p .707 .577 .707 r
F P
0 g
s
.18799 .82727 m .18974 .80902 L .16881 .79989 L p .707 .577 .707 r
F P
0 g
s
.66782 .74645 m .6721 .78369 L .64485 .78297 L p .707 .577 .707 r
F P
0 g
s
.3538 .68142 m .35808 .71867 L .3652 .71089 L p .707 .577 .707 r
F P
0 g
s
.3652 .71089 m .36092 .67364 L .3538 .68142 L p .707 .577 .707 r
F P
0 g
s
.36092 .67364 m .3652 .71089 L .3624 .70403 L p .707 .577 .707 r
F P
0 g
s
.3624 .70403 m .35812 .66678 L .36092 .67364 L p .707 .577 .707 r
F P
0 g
s
.35527 .63178 m .36307 .68761 L .36032 .68112 L p .707 .577 .707 r
F P
0 g
s
.36032 .68112 m .35252 .62529 L .35527 .63178 L p .707 .577 .707 r
F P
0 g
s
.35812 .66678 m .3624 .70403 L .34996 .69877 L p .707 .577 .707 r
F P
0 g
s
.34996 .69877 m .34568 .66153 L .35812 .66678 L p .707 .577 .707 r
F P
0 g
s
.35252 .62529 m .36032 .68112 L .34795 .67643 L p .707 .577 .707 r
F P
0 g
s
.36012 .792 m .36315 .29045 L .35906 .27826 L p .707 .577 .707 r
F P
0 g
s
.36315 .29045 m .36012 .792 L .3779 .80332 L p .707 .577 .707 r
F P
0 g
s
.16881 .79989 m .16706 .81814 L .18799 .82727 L p .707 .577 .707 r
F P
0 g
s
.33307 .81758 m .33132 .83583 L .34767 .82894 L p .707 .577 .707 r
F P
0 g
s
.34767 .82894 m .34941 .81069 L .33307 .81758 L p .707 .577 .707 r
F P
0 g
s
.16706 .81814 m .16881 .79989 L .15632 .78988 L p .707 .577 .707 r
F P
0 g
s
.15632 .78988 m .15457 .80814 L .16706 .81814 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .6398 .77442 L p .64238 .59686 L .707 .577 .707 r
F P
0 g
s
.64238 .59686 m .64559 .37583 L .64465 .60277 L .707 .577 .707 r
F
.64238 .59686 m .64465 .60277 L .64389 .7866 L F
.64282 .27286 m .6398 .77442 L .62202 .7631 L p F P
0 g
s
.63626 .57836 m .63351 .57187 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.64282 .27286 m .64691 .28505 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.6398 .77442 m .64164 .46898 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64164 .46898 m .64282 .27286 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64649 .35462 m .64389 .7866 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .65643 .63887 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63626 .57836 m .63683 .58239 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .64407 .63419 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .63683 .58239 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .63626 .57836 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .64863 .58305 L .63699 .57863 L p .707 .577 .707 r
F P
0 g
s
.63699 .57863 m .63626 .57836 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .63699 .57863 L .63692 .58032 L .707 .577 .707 r
F
.64691 .28505 m .64649 .35462 L p .64559 .37583 L F P
0 g
s
.34941 .81069 m .34767 .82894 L .35477 .8201 L p .707 .577 .707 r
F P
0 g
s
.35477 .8201 m .35652 .80185 L .34941 .81069 L p .707 .577 .707 r
F P
0 g
s
.35906 .27826 m .35603 .77982 L .36012 .792 L p .707 .577 .707 r
F P
0 g
s
.35603 .77982 m .35906 .27826 L .36906 .26641 L p .707 .577 .707 r
F P
0 g
s
.15457 .80814 m .15632 .78988 L .15349 .77998 L p .707 .577 .707 r
F P
0 g
s
.15349 .77998 m .15174 .79823 L .15457 .80814 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34795 .67643 m .34015 .6206 L .35252 .62529 L p .707 .577 .707 r
F P
0 g
s
.16544 .6848 m .16972 .72204 L .1626 .72983 L p .707 .577 .707 r
F P
0 g
s
.62202 .7631 m .62504 .26154 L .64282 .27286 L p .707 .577 .707 r
F P
0 g
s
.35652 .80185 m .35477 .8201 L .35194 .8102 L p .707 .577 .707 r
F P
0 g
s
.35194 .8102 m .35369 .79195 L .35652 .80185 L p .707 .577 .707 r
F P
0 g
s
.15174 .79823 m .15349 .77998 L .16059 .77115 L p .707 .577 .707 r
F P
0 g
s
.16059 .77115 m .15885 .7894 L .15174 .79823 L p .707 .577 .707 r
F P
0 g
s
.34568 .66153 m .34996 .69877 L .32909 .69563 L p .707 .577 .707 r
F P
0 g
s
.32909 .69563 m .32481 .65838 L .34568 .66153 L p .707 .577 .707 r
F P
0 g
s
.34015 .6206 m .34795 .67643 L .32718 .674 L p .707 .577 .707 r
F P
0 g
s
.32718 .674 m .31938 .61818 L .34015 .6206 L p .707 .577 .707 r
F P
0 g
s
.36603 .76797 m .36906 .26641 L .39217 .25605 L p .707 .577 .707 r
F P
0 g
s
.36906 .26641 m .36603 .76797 L .35603 .77982 L p .707 .577 .707 r
F P
0 g
s
.18177 .67685 m .18605 .7141 L .16972 .72204 L p .707 .577 .707 r
F P
0 g
s
.35369 .79195 m .35194 .8102 L .33945 .80019 L p .707 .577 .707 r
F P
0 g
s
.33945 .80019 m .3412 .78194 L .35369 .79195 L p .707 .577 .707 r
F P
0 g
s
.15885 .7894 m .16059 .77115 L .17694 .76425 L p .707 .577 .707 r
F P
0 g
s
.32481 .65838 m .32909 .69563 L .30185 .6949 L p .707 .577 .707 r
F P
0 g
s
.31938 .61818 m .32718 .674 L .30003 .67407 L p .707 .577 .707 r
F P
0 g
s
.30003 .67407 m .29223 .61825 L .31938 .61818 L p .707 .577 .707 r
F P
0 g
s
.62504 .26154 m .62202 .7631 L .5923 .75374 L p .707 .577 .707 r
F P
0 g
s
.5923 .75374 m .59532 .25219 L .62504 .26154 L p .707 .577 .707 r
F P
0 g
s
.17694 .76425 m .17519 .7825 L .15885 .7894 L p .707 .577 .707 r
F P
0 g
s
.20573 .66951 m .21001 .70676 L .18605 .7141 L p .707 .577 .707 r
F P
0 g
s
.73521 .63867 m .72741 .58284 L .69655 .5854 L p .707 .577 .707 r
F P
0 g
s
.72741 .58284 m .73521 .63867 L .76677 .63386 L p .707 .577 .707 r
F P
0 g
s
.76677 .63386 m .75896 .57804 L .72741 .58284 L p .707 .577 .707 r
F P
0 g
s
.39217 .25605 m .38914 .75761 L .36603 .76797 L p .707 .577 .707 r
F P
0 g
s
.38914 .75761 m .39217 .25605 L .42612 .2482 L p .707 .577 .707 r
F P
0 g
s
.75896 .57804 m .76677 .63386 L .79593 .62729 L p .707 .577 .707 r
F P
0 g
s
.79593 .62729 m .78812 .57146 L .75896 .57804 L p .707 .577 .707 r
F P
0 g
s
.3412 .78194 m .33945 .80019 L .31852 .79107 L p .707 .577 .707 r
F P
0 g
s
.31852 .79107 m .32027 .77282 L .3412 .78194 L p .707 .577 .707 r
F P
0 g
s
.70435 .64123 m .69655 .5854 L .66941 .58547 L p .707 .577 .707 r
F P
0 g
s
.69655 .5854 m .70435 .64123 L .73521 .63867 L p .707 .577 .707 r
F P
0 g
s
.29757 .65766 m .30185 .6949 L .27088 .69667 L p .707 .577 .707 r
F P
0 g
s
.17519 .7825 m .17694 .76425 L .20093 .75996 L p .707 .577 .707 r
F P
0 g
s
.23496 .66351 m .23924 .70076 L .21001 .70676 L p .707 .577 .707 r
F P
0 g
s
.78812 .57146 m .79593 .62729 L .81983 .61959 L p .707 .577 .707 r
F P
0 g
s
.81983 .61959 m .81203 .56376 L .78812 .57146 L p .707 .577 .707 r
F P
0 g
s
.20093 .75996 m .19918 .77821 L .17519 .7825 L p .707 .577 .707 r
F P
0 g
s
.2666 .65942 m .27088 .69667 L .23924 .70076 L p .707 .577 .707 r
F P
0 g
s
.59532 .25219 m .5923 .75374 L .55353 .74727 L p .707 .577 .707 r
F P
0 g
s
.55353 .74727 m .55655 .24572 L .59532 .25219 L p .707 .577 .707 r
F P
0 g
s
.66941 .58547 m .67721 .6413 L .70435 .64123 L p .707 .577 .707 r
F P
0 g
s
.67721 .6413 m .66941 .58547 L .64863 .58305 L p .707 .577 .707 r
F P
0 g
s
.32027 .77282 m .31852 .79107 L .2912 .78371 L p .707 .577 .707 r
F P
0 g
s
.2912 .78371 m .29295 .76546 L .32027 .77282 L p .707 .577 .707 r
F P
0 g
s
.4231 .74975 m .42612 .2482 L .4676 .24362 L p .707 .577 .707 r
F P
0 g
s
.42612 .2482 m .4231 .74975 L .38914 .75761 L p .707 .577 .707 r
F P
0 g
s
.19918 .77821 m .20093 .75996 L .23021 .7587 L p .707 .577 .707 r
F P
0 g
s
.73713 .74007 m .73285 .70283 L .70189 .70459 L p .707 .577 .707 r
F P
0 g
s
.73285 .70283 m .73713 .74007 L .76877 .73599 L p .707 .577 .707 r
F P
0 g
s
.76877 .73599 m .76449 .69874 L .73285 .70283 L p .707 .577 .707 r
F P
0 g
s
.81203 .56376 m .81983 .61959 L .83615 .61151 L p .707 .577 .707 r
F P
0 g
s
.83615 .61151 m .82835 .55568 L .81203 .56376 L p .707 .577 .707 r
F P
0 g
s
.76449 .69874 m .76877 .73599 L .798 .72998 L p .707 .577 .707 r
F P
0 g
s
.798 .72998 m .79372 .69274 L .76449 .69874 L p .707 .577 .707 r
F P
0 g
s
.23021 .7587 m .22846 .77695 L .19918 .77821 L p .707 .577 .707 r
F P
0 g
s
.64863 .58305 m .65643 .63887 L .67721 .6413 L p .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70189 .70459 L .70027 .70455 L p .707 .577 .707 r
F P
0 g
s
.70048 .71685 m .69727 .71635 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70027 .70455 L .7008 .73538 L .707 .577 .707 r
F
.70189 .70459 m .70617 .74184 L .73713 .74007 L p F P
0 g
s
.69727 .71635 m .69552 .7346 L .7008 .73542 L p .707 .577 .707 r
F P
0 g
s
.70091 .7417 m .70617 .74184 L p .7008 .73538 L .707 .577 .707 r
F P
0 g
s
.7008 .73542 m .72655 .73946 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70052 .71891 m .69727 .71635 L .7008 .73542 L .707 .577 .707 r
F
.69552 .7346 m .69727 .71635 L .66995 .70899 L p F P
0 g
s
.66995 .70899 m .66821 .72724 L .69552 .7346 L p .707 .577 .707 r
F P
0 g
s
.67464 .70387 m .67892 .74112 L .70091 .7417 L p .707 .577 .707 r
F P
0 g
s
.7008 .73538 m .67464 .70387 L .70091 .7417 L .707 .577 .707 r
F
.70027 .70455 m .67464 .70387 L p .7008 .73538 L F P
0 g
s
.72655 .73946 m .7283 .72121 L .70048 .71685 L p .707 .577 .707 r
F P
0 g
s
.72655 .73946 m .70048 .71685 L .70052 .71891 L .707 .577 .707 r
F
.7283 .72121 m .72655 .73946 L .75826 .74135 L p F P
0 g
s
.75826 .74135 m .76001 .7231 L .7283 .72121 L p .707 .577 .707 r
F P
0 g
s
.55655 .24572 m .55353 .74727 L .50952 .74432 L p .707 .577 .707 r
F P
0 g
s
.50952 .74432 m .51255 .24277 L .55655 .24572 L p .707 .577 .707 r
F P
0 g
s
.29295 .76546 m .2912 .78371 L .26017 .77885 L p .707 .577 .707 r
F P
0 g
s
.26017 .77885 m .26192 .7606 L .29295 .76546 L p .707 .577 .707 r
F P
0 g
s
.76001 .7231 m .75826 .74135 L .78754 .7401 L p .707 .577 .707 r
F P
0 g
s
.78754 .7401 m .78929 .72185 L .76001 .7231 L p .707 .577 .707 r
F P
0 g
s
.22846 .77695 m .23021 .7587 L .26192 .7606 L p .707 .577 .707 r
F P
0 g
s
.79372 .69274 m .798 .72998 L .82196 .72265 L p .707 .577 .707 r
F P
0 g
s
.82196 .72265 m .81768 .6854 L .79372 .69274 L p .707 .577 .707 r
F P
0 g
s
.46458 .74518 m .4676 .24362 L .51255 .24277 L p .707 .577 .707 r
F P
0 g
s
.4676 .24362 m .46458 .74518 L .4231 .74975 L p .707 .577 .707 r
F P
0 g
s
.26192 .7606 m .26017 .77885 L .22846 .77695 L p .707 .577 .707 r
F P
0 g
s
.51255 .24277 m .50952 .74432 L .46458 .74518 L p .707 .577 .707 r
F P
0 g
s
.78929 .72185 m .78754 .7401 L .81153 .73581 L p .707 .577 .707 r
F P
0 g
s
.81153 .73581 m .81328 .71756 L .78929 .72185 L p .707 .577 .707 r
F P
0 g
s
.66821 .72724 m .66995 .70899 L .64903 .69986 L p .707 .577 .707 r
F P
0 g
s
.67892 .74112 m .67464 .70387 L .65377 .70072 L p .707 .577 .707 r
F P
0 g
s
.82835 .55568 m .83615 .61151 L .84329 .60385 L p .707 .577 .707 r
F P
0 g
s
.84329 .60385 m .83548 .54803 L .82835 .55568 L p .707 .577 .707 r
F P
0 g
s
.64903 .69986 m .64728 .71811 L .66821 .72724 L p .707 .577 .707 r
F P
0 g
s
.65377 .70072 m .65805 .73797 L .67892 .74112 L p .707 .577 .707 r
F P
0 g
s
.81768 .6854 m .82196 .72265 L .8383 .7147 L p .707 .577 .707 r
F P
0 g
s
.8383 .7147 m .83402 .67745 L .81768 .6854 L p .707 .577 .707 r
F P
0 g
s
.81328 .71756 m .81153 .73581 L .82788 .72891 L p .707 .577 .707 r
F P
0 g
s
.82788 .72891 m .82963 .71066 L .81328 .71756 L p .707 .577 .707 r
F P
0 g
s
.64728 .71811 m .64903 .69986 L .63653 .68986 L p .707 .577 .707 r
F P
0 g
s
.65805 .73797 m .65377 .70072 L .64133 .69547 L p .707 .577 .707 r
F P
0 g
s
.63653 .68986 m .63479 .70811 L .64728 .71811 L p .707 .577 .707 r
F P
0 g
s
.64133 .69547 m .64561 .73271 L .65805 .73797 L p .707 .577 .707 r
F P
0 g
s
.83548 .54803 m .84329 .60385 L .84053 .59736 L p .707 .577 .707 r
F P
0 g
s
.84053 .59736 m .83273 .54154 L .83548 .54803 L p .707 .577 .707 r
F P
0 g
s
.63351 .57187 m .64131 .6277 L .64407 .63419 L p .707 .577 .707 r
F P
0 g
s
.83402 .67745 m .8383 .7147 L .84541 .70692 L p .707 .577 .707 r
F P
0 g
s
.84541 .70692 m .84113 .66967 L .83402 .67745 L p .707 .577 .707 r
F P
0 g
s
.82963 .71066 m .82788 .72891 L .83499 .72008 L p .707 .577 .707 r
F P
0 g
s
.83499 .72008 m .83673 .70183 L .82963 .71066 L p .707 .577 .707 r
F P
0 g
s
.64561 .73271 m .64133 .69547 L .63853 .68861 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63479 .70811 m .63653 .68986 L .6337 .67995 L p .707 .577 .707 r
F P
0 g
s
.64131 .6277 m .63351 .57187 L .64064 .56421 L p .707 .577 .707 r
F P
0 g
s
.6337 .67995 m .63195 .69821 L .63479 .70811 L p .707 .577 .707 r
F P
0 g
s
.63853 .68861 m .64281 .72586 L .64561 .73271 L p .707 .577 .707 r
F P
0 g
s
.83273 .54154 m .84053 .59736 L .82817 .59268 L p .707 .577 .707 r
F P
0 g
s
.82817 .59268 m .82036 .53685 L .83273 .54154 L p .707 .577 .707 r
F P
0 g
s
.84113 .66967 m .84541 .70692 L .84261 .70006 L p .707 .577 .707 r
F P
0 g
s
.84261 .70006 m .83833 .66281 L .84113 .66967 L p .707 .577 .707 r
F P
0 g
s
.64064 .56421 m .64845 .62004 L .64131 .6277 L p .707 .577 .707 r
F P
0 g
s
.83673 .70183 m .83499 .72008 L .83215 .71017 L p .707 .577 .707 r
F P
0 g
s
.83215 .71017 m .8339 .69192 L .83673 .70183 L p .707 .577 .707 r
F P
0 g
s
.63195 .69821 m .6337 .67995 L .64081 .67112 L p .707 .577 .707 r
F P
0 g
s
.64845 .62004 m .64064 .56421 L .65696 .55614 L p .707 .577 .707 r
F P
0 g
s
.64281 .72586 m .63853 .68861 L .64565 .68083 L p .707 .577 .707 r
F P
0 g
s
.3922 .63038 m .3844 .57456 L .35354 .57712 L p .707 .577 .707 r
F P
0 g
s
.3844 .57456 m .3922 .63038 L .42376 .62558 L p .707 .577 .707 r
F P
0 g
s
.42376 .62558 m .41595 .56975 L .3844 .57456 L p .707 .577 .707 r
F P
0 g
s
.41595 .56975 m .42376 .62558 L .45292 .619 L p .707 .577 .707 r
F P
0 g
s
.45292 .619 m .44511 .56318 L .41595 .56975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64081 .67112 m .63906 .68937 L .63195 .69821 L p .707 .577 .707 r
F P
0 g
s
.36134 .63295 m .35808 .60959 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.35354 .57712 m .36134 .63295 L .3922 .63038 L p .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .38984 .61476 L .35897 .61652 L p .707 .577 .707 r
F P
0 g
s
.35897 .61652 m .35888 .61653 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .35897 .61652 L .35898 .61663 L .707 .577 .707 r
F
.36316 .65377 m .35888 .61653 L .33185 .61581 L p F P
0 g
s
.33185 .61581 m .33163 .6158 L p .3319 .61612 L .707 .577 .707 r
F P
0 g
s
.36316 .65377 m .33185 .61581 L .3319 .61612 L .707 .577 .707 r
F
.33163 .6158 m .33591 .65305 L .36316 .65377 L p F P
0 g
s
.33591 .65305 m .33163 .6158 L .31101 .61269 L p .707 .577 .707 r
F P
0 g
s
.31101 .61269 m .31076 .61266 L p .31109 .61318 L .707 .577 .707 r
F P
0 g
s
.33591 .65305 m .31101 .61269 L .31109 .61318 L .707 .577 .707 r
F
.31076 .61266 m .31504 .6499 L .33591 .65305 L p F P
0 g
s
.31504 .6499 m .31076 .61266 L .2985 .60747 L p .707 .577 .707 r
F P
0 g
s
.2985 .60747 m .29832 .6074 L p .29859 .60807 L .707 .577 .707 r
F P
0 g
s
.31504 .6499 m .2985 .60747 L .29859 .60807 L .707 .577 .707 r
F
.29832 .6074 m .3026 .64465 L .31504 .6499 L p F P
0 g
s
.3026 .64465 m .29832 .6074 L .29557 .60065 L p .707 .577 .707 r
F P
0 g
s
.29557 .60065 m .29552 .60054 L p .29564 .6013 L .707 .577 .707 r
F P
0 g
s
.3026 .64465 m .29557 .60065 L .29564 .6013 L .707 .577 .707 r
F
.30106 .6259 m .29765 .6015 L p .2905 .56359 L F P
0 g
s
.29765 .6015 m .29325 .57008 L .29309 .56968 L p .707 .577 .707 r
F P
0 g
s
.29309 .56968 m .2905 .56359 L p .29765 .6015 L .707 .577 .707 r
F P
0 g
s
.31342 .63059 m .31005 .60648 L p .29325 .57008 L .707 .577 .707 r
F P
0 g
s
.30514 .57458 m .29325 .57008 L p .31005 .60648 L .707 .577 .707 r
F P
0 g
s
.29325 .57008 m .30106 .6259 L .31342 .63059 L p .707 .577 .707 r
F P
0 g
s
.29552 .60054 m .2998 .63779 L .3026 .64465 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .30106 .6259 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2905 .56359 m .29487 .59483 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.29487 .59483 m .2983 .61941 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2998 .63779 m .29552 .60054 L .29562 .60043 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .29487 .59483 L p .29763 .55593 L .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .2983 .61941 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.29763 .55593 m .30199 .58711 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.30199 .58711 m .30544 .61175 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.31005 .60648 m .30562 .57476 L .30514 .57458 L p .707 .577 .707 r
F P
0 g
s
.3342 .63302 m .33088 .60926 L p .30562 .57476 L .707 .577 .707 r
F P
0 g
s
.32611 .57716 m .30562 .57476 L p .33088 .60926 L .707 .577 .707 r
F P
0 g
s
.30562 .57476 m .31342 .63059 L .3342 .63302 L p .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .29763 .55593 L .31395 .54785 L p .707 .577 .707 r
F P
0 g
s
.30692 .63001 m .30264 .59276 L .30289 .59264 L p .707 .577 .707 r
F P
0 g
s
.32176 .60368 m .30544 .61175 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31395 .54785 m .31832 .5791 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31832 .5791 m .32176 .60368 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.33088 .60926 m .3264 .57719 L .32611 .57716 L p .707 .577 .707 r
F P
0 g
s
.35888 .61653 m .36316 .65377 L .36374 .65374 L p .707 .577 .707 r
F P
0 g
s
.36107 .63295 m .36134 .63295 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.36374 .65374 m .39412 .65201 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.35898 .61663 m .35888 .61653 L .36374 .65374 L .707 .577 .707 r
F
.3264 .57719 m .3342 .63302 L .36107 .63295 L p F P
0 g
s
.361 .6324 m .3264 .57719 L .36107 .63295 L .707 .577 .707 r
F
.35354 .57712 m .3264 .57719 L p .361 .6324 L F P
0 g
s
.32176 .60368 m .31395 .54785 L .33786 .54015 L p .707 .577 .707 r
F P
0 g
s
.32326 .62206 m .31898 .58481 L .31934 .5847 L p .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .32176 .60368 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.33786 .54015 m .34225 .57158 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34225 .57158 m .34566 .59598 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .33786 .54015 L .36702 .53358 L p .707 .577 .707 r
F P
0 g
s
.34721 .61472 m .34293 .57747 L .34335 .57739 L p .707 .577 .707 r
F P
0 g
s
.35808 .60959 m .35354 .57712 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .34566 .59598 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.36702 .53358 m .37145 .56529 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37145 .56529 m .37482 .5894 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .36702 .53358 L .39857 .52877 L p .707 .577 .707 r
F P
0 g
s
.37644 .60872 m .37216 .57147 L .37254 .57142 L p .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .37482 .5894 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.39857 .52877 m .40306 .56084 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40306 .56084 m .40638 .5846 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .39857 .52877 L .42943 .52621 L p .707 .577 .707 r
F P
0 g
s
.40809 .60463 m .40381 .56738 L .40406 .56737 L p .707 .577 .707 r
F P
0 g
s
.42943 .52621 m .43397 .55868 L p .40638 .5846 L .707 .577 .707 r
F P
0 g
s
.44511 .56318 m .45292 .619 L .47682 .6113 L p .707 .577 .707 r
F P
0 g
s
.47682 .6113 m .46902 .55548 L .44511 .56318 L p .707 .577 .707 r
F P
0 g
s
.43485 .56562 m .46202 .56634 L p .43947 .60219 L .707 .577 .707 r
F P
0 g
s
.43397 .55868 m .43724 .58204 L .43693 .58206 L p .707 .577 .707 r
F P
0 g
s
.43693 .58206 m .40638 .5846 L p .43397 .55868 L .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43477 .56562 L .43485 .56562 L p .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43485 .56562 L .43947 .60219 L .707 .577 .707 r
F
.40406 .56737 m .43477 .56562 L p .40947 .60261 L F P
0 g
s
.40809 .60463 m .40406 .56737 L .40947 .60261 L .707 .577 .707 r
F
.37254 .57142 m .40381 .56738 L p .37858 .60549 L F P
0 g
s
.37644 .60872 m .37254 .57142 L .37858 .60549 L .707 .577 .707 r
F
.34335 .57739 m .37216 .57147 L p .34961 .61057 L F P
0 g
s
.34721 .61472 m .34335 .57739 L .34961 .61057 L .707 .577 .707 r
F
.31934 .5847 m .34293 .57747 L p .32532 .61737 L F P
0 g
s
.32326 .62206 m .31934 .5847 L .32532 .61737 L .707 .577 .707 r
F
.30289 .59264 m .31898 .58481 L p .30818 .62526 L F P
0 g
s
.30692 .63001 m .30289 .59264 L .30818 .62526 L .707 .577 .707 r
F
.29562 .60043 m .30264 .59276 L p .30007 .63348 L F P
0 g
s
.2998 .63779 m .29562 .60043 L .30007 .63348 L .707 .577 .707 r
F
.29487 .59483 m .2905 .56359 L .29104 .563 L p F P
0 g
s
.29104 .563 m .29763 .55593 L p .29487 .59483 L .707 .577 .707 r
F P
0 g
s
.64565 .68083 m .64993 .71807 L .64281 .72586 L p .707 .577 .707 r
F P
0 g
s
.38984 .61476 m .39412 .65201 L .42576 .64792 L p .707 .577 .707 r
F P
0 g
s
.42576 .64792 m .42148 .61067 L .38984 .61476 L p .707 .577 .707 r
F P
0 g
s
.82036 .53685 m .82817 .59268 L .80739 .59025 L p .707 .577 .707 r
F P
0 g
s
.80739 .59025 m .79959 .53442 L .82036 .53685 L p .707 .577 .707 r
F P
0 g
s
.42148 .61067 m .42576 .64792 L .45499 .64192 L p .707 .577 .707 r
F P
0 g
s
.45499 .64192 m .45071 .60467 L .42148 .61067 L p .707 .577 .707 r
F P
0 g
s
.65696 .55614 m .66477 .61196 L .64845 .62004 L p .707 .577 .707 r
F P
0 g
s
.8339 .69192 m .83215 .71017 L .81966 .70017 L p .707 .577 .707 r
F P
0 g
s
.81966 .70017 m .82141 .68192 L .8339 .69192 L p .707 .577 .707 r
F P
0 g
s
.83833 .66281 m .84261 .70006 L .83017 .6948 L p .707 .577 .707 r
F P
0 g
s
.83017 .6948 m .82589 .65755 L .83833 .66281 L p .707 .577 .707 r
F P
0 g
s
.45071 .60467 m .45499 .64192 L .47895 .63458 L p .707 .577 .707 r
F P
0 g
s
.47895 .63458 m .47467 .59733 L .45071 .60467 L p .707 .577 .707 r
F P
0 g
s
.66477 .61196 m .65696 .55614 L .68087 .54844 L p .707 .577 .707 r
F P
0 g
s
.63906 .68937 m .64081 .67112 L .65715 .66422 L p .707 .577 .707 r
F P
0 g
s
.64993 .71807 m .64565 .68083 L .66199 .67288 L p .707 .577 .707 r
F P
0 g
s
.46902 .55548 m .47682 .6113 L .49314 .60323 L p .707 .577 .707 r
F P
0 g
s
.49314 .60323 m .48534 .5474 L .46902 .55548 L p .707 .577 .707 r
F P
0 g
s
.79959 .53442 m .80739 .59025 L .78025 .59032 L p .707 .577 .707 r
F P
0 g
s
.78025 .59032 m .77244 .53449 L .79959 .53442 L p .707 .577 .707 r
F P
0 g
s
.65715 .66422 m .65541 .68247 L .63906 .68937 L p .707 .577 .707 r
F P
0 g
s
.68087 .54844 m .68868 .60426 L .66477 .61196 L p .707 .577 .707 r
F P
0 g
s
.66199 .67288 m .66627 .71012 L .64993 .71807 L p .707 .577 .707 r
F P
0 g
s
.82141 .68192 m .81966 .70017 L .79873 .69104 L p .707 .577 .707 r
F P
0 g
s
.79873 .69104 m .80048 .67279 L .82141 .68192 L p .707 .577 .707 r
F P
0 g
s
.82589 .65755 m .83017 .6948 L .80931 .69166 L p .707 .577 .707 r
F P
0 g
s
.80931 .69166 m .80503 .65441 L .82589 .65755 L p .707 .577 .707 r
F P
0 g
s
.47467 .59733 m .47895 .63458 L .49529 .62663 L p .707 .577 .707 r
F P
0 g
s
.49529 .62663 m .49101 .58939 L .47467 .59733 L p .707 .577 .707 r
F P
0 g
s
.38354 .74745 m .38529 .7292 L .35426 .72433 L p .707 .577 .707 r
F P
0 g
s
.38529 .7292 m .38354 .74745 L .41525 .74934 L p .707 .577 .707 r
F P
0 g
s
.41525 .74934 m .417 .73109 L .38529 .7292 L p .707 .577 .707 r
F P
0 g
s
.68868 .60426 m .68087 .54844 L .71003 .54186 L p .707 .577 .707 r
F P
0 g
s
.417 .73109 m .41525 .74934 L .44453 .74808 L p .707 .577 .707 r
F P
0 g
s
.44453 .74808 m .44628 .72983 L .417 .73109 L p .707 .577 .707 r
F P
0 g
s
.35426 .72433 m .35251 .74258 L .38354 .74745 L p .707 .577 .707 r
F P
0 g
s
.35251 .74258 m .35426 .72433 L .32694 .71698 L p .707 .577 .707 r
F P
0 g
s
.77244 .53449 m .78025 .59032 L .74939 .59288 L p .707 .577 .707 r
F P
0 g
s
.74939 .59288 m .74158 .53706 L .77244 .53449 L p .707 .577 .707 r
F P
0 g
s
.32694 .71698 m .3252 .73523 L .35251 .74258 L p .707 .577 .707 r
F P
0 g
s
.66627 .71012 m .66199 .67288 L .68594 .66554 L p .707 .577 .707 r
F P
0 g
s
.65541 .68247 m .65715 .66422 L .68114 .65993 L p .707 .577 .707 r
F P
0 g
s
.71783 .59769 m .71003 .54186 L .74158 .53706 L p .707 .577 .707 r
F P
0 g
s
.71003 .54186 m .71783 .59769 L .68868 .60426 L p .707 .577 .707 r
F P
0 g
s
.74158 .53706 m .74939 .59288 L .71783 .59769 L p .707 .577 .707 r
F P
0 g
s
.44628 .72983 m .44453 .74808 L .46852 .7438 L p .707 .577 .707 r
F P
0 g
s
.46852 .7438 m .47027 .72555 L .44628 .72983 L p .707 .577 .707 r
F P
0 g
s
.48534 .5474 m .49314 .60323 L .50028 .59557 L p .707 .577 .707 r
F P
0 g
s
.50028 .59557 m .49247 .53974 L .48534 .5474 L p .707 .577 .707 r
F P
0 g
s
.68114 .65993 m .67939 .67819 L .65541 .68247 L p .707 .577 .707 r
F P
0 g
s
.3252 .73523 m .32694 .71698 L .30602 .70785 L p .707 .577 .707 r
F P
0 g
s
.68594 .66554 m .69022 .70279 L .66627 .71012 L p .707 .577 .707 r
F P
0 g
s
.80048 .67279 m .79873 .69104 L .77607 .68494 L p .707 .577 .707 r
F P
0 g
s
.77609 .69127 m .7511 .6927 L p .77595 .65636 L .707 .577 .707 r
F P
0 g
s
.77607 .68494 m .77142 .68369 L p .77605 .68195 L .707 .577 .707 r
F P
0 g
s
.77605 .68195 m .80048 .67279 L .77607 .68494 L .707 .577 .707 r
F
.77142 .68369 m .77316 .66544 L .80048 .67279 L p F P
0 g
s
.77778 .65368 m .78206 .69093 L .77609 .69127 L p .707 .577 .707 r
F P
0 g
s
.77595 .65636 m .77778 .65368 L .77609 .69127 L .707 .577 .707 r
F
.80503 .65441 m .80931 .69166 L .78206 .69093 L p F P
0 g
s
.78206 .69093 m .77778 .65368 L .80503 .65441 L p .707 .577 .707 r
F P
0 g
s
.49101 .58939 m .49529 .62663 L .5024 .61885 L p .707 .577 .707 r
F P
0 g
s
.5024 .61885 m .49812 .5816 L .49101 .58939 L p .707 .577 .707 r
F P
0 g
s
.30602 .70785 m .30427 .7261 L .3252 .73523 L p .707 .577 .707 r
F P
0 g
s
.69022 .70279 m .68594 .66554 L .71517 .65954 L p .707 .577 .707 r
F P
0 g
s
.67939 .67819 m .68114 .65993 L .71042 .65868 L p .707 .577 .707 r
F P
0 g
s
.47027 .72555 m .46852 .7438 L .48487 .7369 L p .707 .577 .707 r
F P
0 g
s
.48487 .7369 m .48662 .71865 L .47027 .72555 L p .707 .577 .707 r
F P
0 g
s
.7511 .6927 m .74682 .65545 L .77778 .65368 L p .707 .577 .707 r
F P
0 g
s
.71517 .65954 m .71945 .69678 L .69022 .70279 L p .707 .577 .707 r
F P
0 g
s
.71042 .65868 m .70868 .67693 L .67939 .67819 L p .707 .577 .707 r
F P
0 g
s
.30427 .7261 m .30602 .70785 L .29352 .69785 L p .707 .577 .707 r
F P
0 g
s
.74682 .65545 m .7511 .6927 L .71945 .69678 L p .707 .577 .707 r
F P
0 g
s
.77316 .66544 m .77142 .68369 L .74038 .67882 L p .707 .577 .707 r
F P
0 g
s
.71945 .69678 m .71517 .65954 L .74682 .65545 L p .707 .577 .707 r
F P
0 g
s
.74038 .67882 m .74213 .66057 L .77316 .66544 L p .707 .577 .707 r
F P
0 g
s
.70868 .67693 m .71042 .65868 L .74213 .66057 L p .707 .577 .707 r
F P
0 g
s
.49812 .5816 m .5024 .61885 L .4996 .61199 L p .707 .577 .707 r
F P
0 g
s
.4996 .61199 m .49532 .57475 L .49812 .5816 L p .707 .577 .707 r
F P
0 g
s
.49247 .53974 m .50028 .59557 L .49752 .58908 L p .707 .577 .707 r
F P
0 g
s
.49752 .58908 m .48972 .53325 L .49247 .53974 L p .707 .577 .707 r
F P
0 g
s
.29352 .69785 m .29178 .7161 L .30427 .7261 L p .707 .577 .707 r
F P
0 g
s
.74213 .66057 m .74038 .67882 L .70868 .67693 L p .707 .577 .707 r
F P
0 g
s
.48662 .71865 m .48487 .7369 L .49198 .72806 L p .707 .577 .707 r
F P
0 g
s
.49198 .72806 m .49372 .70981 L .48662 .71865 L p .707 .577 .707 r
F P
0 g
s
.29178 .7161 m .29352 .69785 L .29069 .68794 L p .707 .577 .707 r
F P
0 g
s
.29069 .68794 m .28894 .70619 L .29178 .7161 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49532 .57475 m .4996 .61199 L .48716 .60673 L p .707 .577 .707 r
F P
0 g
s
.48716 .60673 m .48288 .56949 L .49532 .57475 L p .707 .577 .707 r
F P
0 g
s
.48972 .53325 m .49752 .58908 L .48516 .58439 L p .707 .577 .707 r
F P
0 g
s
.48516 .58439 m .47735 .52856 L .48972 .53325 L p .707 .577 .707 r
F P
0 g
s
.30264 .59276 m .30692 .63001 L .2998 .63779 L p .707 .577 .707 r
F P
0 g
s
.49372 .70981 m .49198 .72806 L .48914 .71816 L p .707 .577 .707 r
F P
0 g
s
.48914 .71816 m .49089 .69991 L .49372 .70981 L p .707 .577 .707 r
F P
0 g
s
.28894 .70619 m .29069 .68794 L .2978 .67911 L p .707 .577 .707 r
F P
0 g
s
.2978 .67911 m .29605 .69736 L .28894 .70619 L p .707 .577 .707 r
F P
0 g
s
.48288 .56949 m .48716 .60673 L .4663 .60359 L p .707 .577 .707 r
F P
0 g
s
.4663 .60359 m .46202 .56634 L .48288 .56949 L p .707 .577 .707 r
F P
0 g
s
.47735 .52856 m .48516 .58439 L .46438 .58196 L p .707 .577 .707 r
F P
0 g
s
.46438 .58196 m .45658 .52614 L .47735 .52856 L p .707 .577 .707 r
F P
0 g
s
.31898 .58481 m .32326 .62206 L .30692 .63001 L p .707 .577 .707 r
F P
0 g
s
.49089 .69991 m .48914 .71816 L .47665 .70815 L p .707 .577 .707 r
F P
0 g
s
.47665 .70815 m .4784 .6899 L .49089 .69991 L p .707 .577 .707 r
F P
0 g
s
.29605 .69736 m .2978 .67911 L .31414 .67221 L p .707 .577 .707 r
F P
0 g
s
.46202 .56634 m .4663 .60359 L .43905 .60286 L p .707 .577 .707 r
F P
0 g
s
.45658 .52614 m .46438 .58196 L .43724 .58204 L p .707 .577 .707 r
F P
0 g
s
.43724 .58204 m .42943 .52621 L .45658 .52614 L p .707 .577 .707 r
F P
0 g
s
.31414 .67221 m .3124 .69046 L .29605 .69736 L p .707 .577 .707 r
F P
0 g
s
.34293 .57747 m .34721 .61472 L .32326 .62206 L p .707 .577 .707 r
F P
0 g
s
.4784 .6899 m .47665 .70815 L .45572 .69903 L p .707 .577 .707 r
F P
0 g
s
.45572 .69903 m .45747 .68078 L .4784 .6899 L p .707 .577 .707 r
F P
0 g
s
.43477 .56562 m .43905 .60286 L .40809 .60463 L p .707 .577 .707 r
F P
0 g
s
.3124 .69046 m .31414 .67221 L .33813 .66792 L p .707 .577 .707 r
F P
0 g
s
.37216 .57147 m .37644 .60872 L .34721 .61472 L p .707 .577 .707 r
F P
0 g
s
.33813 .66792 m .33638 .68617 L .3124 .69046 L p .707 .577 .707 r
F P
0 g
s
.40381 .56738 m .40809 .60463 L .37644 .60872 L p .707 .577 .707 r
F P
0 g
s
.45747 .68078 m .45572 .69903 L .42841 .69167 L p .707 .577 .707 r
F P
0 g
s
.42841 .69167 m .43015 .67342 L .45747 .68078 L p .707 .577 .707 r
F P
0 g
s
.33638 .68617 m .33813 .66792 L .36741 .66666 L p .707 .577 .707 r
F P
0 g
s
.36741 .66666 m .36567 .68491 L .33638 .68617 L p .707 .577 .707 r
F P
0 g
s
.43015 .67342 m .42841 .69167 L .39737 .68681 L p .707 .577 .707 r
F P
0 g
s
.39737 .68681 m .39912 .66856 L .43015 .67342 L p .707 .577 .707 r
F P
0 g
s
.36567 .68491 m .36741 .66666 L .39912 .66856 L p .707 .577 .707 r
F P
0 g
s
.39912 .66856 m .39737 .68681 L .36567 .68491 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00Igoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01EYF3`00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool01000FUIJEP0015YF2@0015YF00<005YFFUH015YF00<005YFFUH01@001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH000050004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006=oo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000HOolJ000cOol0
05moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3000DOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000aOol005]o
o`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000>Ool60006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<7oo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0027oo1P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001GOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001Woo0P00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUH005YF02moo`00EGoo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000Aoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00FUH_Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00IJEP03001JEUYF009J
EPD000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`03001JEP0000=JEP03OomJEP0000IJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`04001J
EP000002FUH00gooFUH00006FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH20006FUH00`00
FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001J
EUYF009JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol01000FUIJEP00
15YF00<005YFFUH00eYF10001EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001eYF00<005YFFUH0
0UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol2FUH00`00FUIJEP02
FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH<0002FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001COol2FUH00`00FUIJEP02FUH20005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH015YF00@005YFFUIJ
EP@0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`9JEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP04001JEUYF000^
Ool005=oo`9JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00=JEPH00003FUH0000002eoo`00Dgoo00@005YF
000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00AJEPX000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool005=oo`800003FUH005YF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool005=oo`04001JEUYF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP0200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH50008FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005
FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH40003FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH0
1UYF1P000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001DOol2FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH70006FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0003FUH01000FUH000001UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;Goo001DOol3FUH20002FUH00`00
FUIJEP03FUH60004FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUH0031oo`00Cgoo1@000eYF00H005YFFUIJEP00FUH40005FUH50003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF008000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<0035oo`00
AWoo2@0015YF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP8003=oo`00@7oo
1P0015YF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000e
Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo
000hOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH0
35YF1@001EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003eoo`00=7oo100000=JEP00FUH0
1EYF00=oo`00FUH01eYF00<005YFFUH01UYF10000UYF00<005YFFUH02`001eYF1@001EYF00<005YF
FUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70011Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<0
009JEP03001JEUYF00=JEP03001JEUYF00aJEPD000EJEP03001JEUYF00IJEP03001JEP0000<000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH4
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80018Ool0031oo`<000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00eJEP<000MJEP03
001JEUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEQ40051oo`00;Woo0P000UYF00<005YFFUH015YF00<005YF
FUH00eYF00AooeYFFUH000QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH03UYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YF001J
EUIoo`00;Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00iJEP03001JEUYF009JEPL000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000EJEP03001JEUYF00=JEP04001JEP00FUIFOol002aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEQT000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF000BOol8000lOol002]oo`03001JEP0000EJ
EP03001JEUYF00AJEP05001JEUYFFUIoo`03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0027oo2@0015YF00@005YF
FUIJEPX0039oo`00:goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF3P001eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEQP000QJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00:goo00<005YF00000eYF00=ooeYF00001UYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF
0P001UYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00009JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00:goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001JEP0000d0
0003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
0005FUH400000eYF001JEP06FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00
FUIJEP02FUH01000FUIJEUYF0P00;Goo000/Ool2FUH00`00FUIJEP02FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo
0UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
00000`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000IJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0UYF00<005YFFUH00`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUH000030003FUH00`00
FUIJEP06FUH00`00FUH000080004FUH01000FUIJEP001UYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool2FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0eYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH80000
1EYF001JEUYF00000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0000000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000]Ool002aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP@00003FUH005YF00AJEP03001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF001JEP030004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHF0002FUH01000FUIJEUYF0P00;7oo000/Ool01000
FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEPX000=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@0
009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000Uo
o`@00004FUH005YFFUH20002FUH40003FUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:00000eYF000000050004FUH500001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001EYF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF009JEPH000Ioo`L000EJEP03001JEUYF009JEP<000=JEP800003FUH0000002aoo`00;Goo
0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF2@000eYF2@0015YF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEP8000=J
EP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP030002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH60003Ool90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF1@00;7oo000]Ool3FUH20002FUH00`00FUIJEP03FUH60004FUH80004
FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YF0000
300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P0000=JEP0000000`00;7oo
000]Ool3FUH01@00FUIJEUYF00000eYF0P001EYF1@000eYF00<005YFFUH01UYF00<005YF00000eYF
0P0000=JEP00FUH01EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
2@00FUIJEUYF001JEP00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001oo`0[Ool002eoo`04001JEUYF0003FUH0
1000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01eYF0P000eYF00<005YF00000P001EYF00<0
05YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
15YF001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00001000;Goo000]Ool01000FUIJEP000eYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP@000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH000000004
FUH00`00FUIJEP05FUH20007FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF0000
000^Ool002ioo`9JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030003FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH000AJEP03001JEUYF00MJEP@000=JEPD0
00EJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEP0002moo`00;Woo0UYF1@000eYF00<0
05YFFUH015YF00<005YFFUH01UYF0`001UYF00<005YFFUH00`001EYF00<005YFFUH00eYF1@0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH02eYF5`000eYF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH02`00
1eYF1@001EYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF
00<005YFFUH01eYF00<005YFFUH01eYF1@000eYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH035YF1P000eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH035YF1@001EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH0
15YF5`000eYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP0<FUH00`00FUH000020004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Goo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP0<FUH50006FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EUYF009JEP03001JEUYF00]JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000cOol002moo`800003FUH005YF00AJEP03001JEUYF00eJEP<000MJEP03001JEUYF00@0009o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH007oo1@000UYF00<005YFFUH015YF10000eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEPD003Eoo`00<Goo10000eYF00<005YFFUH03UYF00<005YFFUH00UYF1`002Goo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000MJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
obD003Yoo`00=Goo1`002EYF2@0057oo1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
?7oo2@0087oo00<005YFFUH02P0015YF00<005YFFUH00UYF1`002EYF00<005YFFUH02EYF2@0025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002000GGoo001UOol01000FUIJEP001EYF00@0
05YFFUIJEPX0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00D005Qoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00?Woo20007goo00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000IJ
EP03001JEUYF009JEP05001JEUYFFUH0001EOol003Ioo`P000=JEP03001JEUYF009JEPT001Ioo`04
001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000aOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000@Ool01@00
FUIJEP00FUH00P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP03001JEUYF009JEP04001J
EUYFFUH2001DOol002moo`800003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEP0000<000aoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80
0004FUH005YF0006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00E7oo000]Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30009Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP80
0003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0001DOol002]oo`03001JEP0000=JEP04
001JEUYFFUH80008Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP020005Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<005YFFUH00UYF00D005YFFUIJEP0005Aoo`00
:goo00<005YF00000eYF10006Goo1P001UYF00<005YFFUH00eYF00<007ooOol00Woo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF00002`000UYF00@005YFFUIJEP8005=oo`00:goo00@0
05YF001JEP8002=oo`@0009JEP03001JEUYF00=JEP8000=oo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00D00003FUH00000009JEP@000=JEP8005=oo`00:goo00@005YF000002Uo
o`<000EJEP04001JEP000002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP02FUH30003FUH200000eYF0000001COol002]oo`<002eoo`8000=JEP07
001JEUYFFUH007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF
00@005YFFUIJEPD005=oo`00:goo0P0000=JEP000000;Goo0P0000=JEP00FUH00UYF00<007ooOol0
0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P000UYF1@00Dgoo
000[Ool00`00FUIJEP02FUH00`00Oomoo`0/Ool20003FUH20003Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
0005FUH00`00FUIJEP05FUH600000eYF001oo`1BOol002]oo`03001JEUYF009JEP<002ioo`03001J
EUYF008000Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEP0000@005Aoo`00
:goo00<005YFFUH00UYF00<005YFFUH00P00;Goo10001goo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`000eYF00<005YFFUH01UYF
00<005YFFUH015YF1P00EGoo000/Ool01000FUIJEP001EYF0P00:goo10002Goo0`0000=JEP00FUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01EYF00<005YF000010000UYF00<005YF0000EWoo000]Ool30005FUH00`00FUH00003000U
Ool200000eYF0000000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUH0000G0003FUH01000FUIJEUYF0P00Egoo000_Ool00`00FUIJEP03FUH00`00FUIJEP03FUH7
000IOol50003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH70003FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00Egoo000`Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90009Ool70003FUH01`00FUIJEUYF001JEP00021ooaT000YJEPH000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001HOol0039oo`800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool01@00
FUIJEUYF000015YF00<005YFFUH02eYF00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Yoo`00=7oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002ioo`800003FUH005YF00=JEP03001JEUYF00AJEP@0
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001LOol003Moo`@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol:0004
FUH00`00FUIJEP0H001QOol003]oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000mOol9001gOol0049oo`T000AJEP03001JEUYF009JEPL00<9oo`00Bgoo2@00bGoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59883 .7188 m .58627 .66342 L .55592 .66873 L p .707 .577 .707 r
F P
0 g
s
.58627 .66342 m .59883 .7188 L .62992 .71152 L p .707 .577 .707 r
F P
0 g
s
.62992 .71152 m .61737 .65613 L .58627 .66342 L p .707 .577 .707 r
F P
0 g
s
.61737 .65613 m .62992 .71152 L .65872 .70297 L p .707 .577 .707 r
F P
0 g
s
.65872 .70297 m .64617 .64759 L .61737 .65613 L p .707 .577 .707 r
F P
0 g
s
.56847 .72412 m .55592 .66873 L .52927 .67156 L p .707 .577 .707 r
F P
0 g
s
.55592 .66873 m .56847 .72412 L .59883 .7188 L p .707 .577 .707 r
F P
0 g
s
.64617 .64759 m .65872 .70297 L .6824 .69401 L p .707 .577 .707 r
F P
0 g
s
.6824 .69401 m .66985 .63862 L .64617 .64759 L p .707 .577 .707 r
F P
0 g
s
.52927 .67156 m .54183 .72694 L .56847 .72412 L p .707 .577 .707 r
F P
0 g
s
.54183 .72694 m .52927 .67156 L .50896 .67161 L p .707 .577 .707 r
F P
0 g
s
.66985 .63862 m .6824 .69401 L .69864 .6855 L p .707 .577 .707 r
F P
0 g
s
.69864 .6855 m .68609 .63011 L .66985 .63862 L p .707 .577 .707 r
F P
0 g
s
.50896 .67161 m .52151 .72699 L .54183 .72694 L p .707 .577 .707 r
F P
0 g
s
.60205 .84573 m .59515 .80864 L .56453 .81267 L p .707 .577 .707 r
F P
0 g
s
.59515 .80864 m .60205 .84573 L .63338 .8396 L p .707 .577 .707 r
F P
0 g
s
.63338 .8396 m .62648 .80251 L .59515 .80864 L p .707 .577 .707 r
F P
0 g
s
.58503 .81894 m .58785 .80095 L .55704 .79429 L p .707 .577 .707 r
F P
0 g
s
.58785 .80095 m .58503 .81894 L .61653 .82247 L p .707 .577 .707 r
F P
0 g
s
.61653 .82247 m .61935 .80447 L .58785 .80095 L p .707 .577 .707 r
F P
0 g
s
.62648 .80251 m .63338 .8396 L .66237 .83198 L p .707 .577 .707 r
F P
0 g
s
.66237 .83198 m .65547 .79488 L .62648 .80251 L p .707 .577 .707 r
F P
0 g
s
.61935 .80447 m .61653 .82247 L .64565 .8225 L p .707 .577 .707 r
F P
0 g
s
.64565 .8225 m .64847 .80451 L .61935 .80447 L p .707 .577 .707 r
F P
0 g
s
.55422 .81228 m .55704 .79429 L .52995 .78513 L p .707 .577 .707 r
F P
0 g
s
.56453 .81267 m .57142 .84977 L .60205 .84573 L p .707 .577 .707 r
F P
0 g
s
.57142 .84977 m .56453 .81267 L .55976 .81294 L p .707 .577 .707 r
F P
0 g
s
.55704 .79429 m .55422 .81228 L .55977 .81348 L p .707 .577 .707 r
F P
0 g
s
.55929 .79627 m .55704 .79429 L .55977 .81348 L .707 .577 .707 r
F
.55976 .81294 m .53762 .81421 L p .56047 .83824 L F P
0 g
s
.57142 .84977 m .55976 .81294 L .56047 .83824 L .707 .577 .707 r
F
.55977 .81348 m .58503 .81894 L p .55929 .79627 L F P
0 g
s
.52995 .78513 m .52713 .80312 L .55422 .81228 L p .707 .577 .707 r
F P
0 g
s
.65547 .79488 m .66237 .83198 L .68617 .8236 L p .707 .577 .707 r
F P
0 g
s
.68617 .8236 m .67927 .7865 L .65547 .79488 L p .707 .577 .707 r
F P
0 g
s
.52151 .72699 m .50896 .67161 L .49695 .66889 L p .707 .577 .707 r
F P
0 g
s
.53762 .81421 m .54452 .85131 L .57142 .84977 L p .707 .577 .707 r
F P
0 g
s
.64847 .80451 m .64565 .8225 L .66953 .81904 L p .707 .577 .707 r
F P
0 g
s
.66953 .81904 m .67235 .80105 L .64847 .80451 L p .707 .577 .707 r
F P
0 g
s
.52713 .80312 m .52995 .78513 L .50923 .77437 L p .707 .577 .707 r
F P
0 g
s
.68609 .63011 m .69864 .6855 L .70585 .67827 L p .707 .577 .707 r
F P
0 g
s
.70585 .67827 m .6933 .62289 L .68609 .63011 L p .707 .577 .707 r
F P
0 g
s
.49695 .66889 m .5095 .72427 L .52151 .72699 L p .707 .577 .707 r
F P
0 g
s
.54452 .85131 m .53762 .81421 L .51706 .81311 L p .707 .577 .707 r
F P
0 g
s
.50923 .77437 m .50641 .79237 L .52713 .80312 L p .707 .577 .707 r
F P
0 g
s
.67927 .7865 m .68617 .8236 L .70245 .81529 L p .707 .577 .707 r
F P
0 g
s
.70245 .81529 m .69555 .77819 L .67927 .7865 L p .707 .577 .707 r
F P
0 g
s
.51706 .81311 m .52396 .85021 L .54452 .85131 L p .707 .577 .707 r
F P
0 g
s
.67235 .80105 m .66953 .81904 L .68584 .81243 L p .707 .577 .707 r
F P
0 g
s
.68584 .81243 m .68866 .79444 L .67235 .80105 L p .707 .577 .707 r
F P
0 g
s
.50641 .79237 m .50923 .77437 L .4969 .76308 L p .707 .577 .707 r
F P
0 g
s
.5095 .72427 m .49695 .66889 L .49443 .66367 L p .707 .577 .707 r
F P
0 g
s
.4969 .76308 m .49408 .78107 L .50641 .79237 L p .707 .577 .707 r
F P
0 g
s
.52396 .85021 m .51706 .81311 L .50487 .80947 L p .707 .577 .707 r
F P
0 g
s
.6933 .62289 m .70585 .67827 L .70333 .67305 L p .707 .577 .707 r
F P
0 g
s
.70333 .67305 m .69078 .61767 L .6933 .62289 L p .707 .577 .707 r
F P
0 g
s
.49443 .66367 m .50698 .71905 L .5095 .72427 L p .707 .577 .707 r
F P
0 g
s
.50487 .80947 m .51176 .84657 L .52396 .85021 L p .707 .577 .707 r
F P
0 g
s
.69555 .77819 m .70245 .81529 L .70962 .80787 L p .707 .577 .707 r
F P
0 g
s
.70962 .80787 m .70272 .77077 L .69555 .77819 L p .707 .577 .707 r
F P
0 g
s
.68866 .79444 m .68584 .81243 L .69298 .80331 L p .707 .577 .707 r
F P
0 g
s
.69298 .80331 m .6958 .78532 L .68866 .79444 L p .707 .577 .707 r
F P
0 g
s
.49037 .82225 m .49526 .32091 L .45125 .3178 L p .707 .577 .707 r
F P
0 g
s
.49408 .78107 m .4969 .76308 L .49417 .75234 L p .707 .577 .707 r
F P
0 g
s
.50698 .71905 m .49443 .66367 L .50164 .65644 L p .707 .577 .707 r
F P
0 g
s
.49417 .75234 m .49135 .77034 L .49408 .78107 L p .707 .577 .707 r
F P
0 g
s
.51176 .84657 m .50487 .80947 L .50222 .80366 L p .707 .577 .707 r
F P
0 g
s
.50164 .65644 m .51419 .71183 L .50698 .71905 L p .707 .577 .707 r
F P
0 g
s
.50222 .80366 m .50912 .84076 L .51176 .84657 L p .707 .577 .707 r
F P
0 g
s
.49135 .77034 m .49417 .75234 L .50131 .74323 L p .707 .577 .707 r
F P
0 g
s
.51419 .71183 m .50164 .65644 L .51788 .64793 L p .707 .577 .707 r
F P
0 g
s
.50131 .74323 m .49849 .76122 L .49135 .77034 L p .707 .577 .707 r
F P
0 g
s
.50912 .84076 m .50222 .80366 L .50939 .79623 L p .707 .577 .707 r
F P
0 g
s
.51788 .64793 m .53043 .70332 L .51419 .71183 L p .707 .577 .707 r
F P
0 g
s
.50939 .79623 m .51629 .83333 L .50912 .84076 L p .707 .577 .707 r
F P
0 g
s
.49849 .76122 m .50131 .74323 L .51763 .73661 L p .707 .577 .707 r
F P
0 g
s
.53043 .70332 m .51788 .64793 L .54156 .63897 L p .707 .577 .707 r
F P
0 g
s
.51763 .73661 m .5148 .7546 L .49849 .76122 L p .707 .577 .707 r
F P
0 g
s
.51629 .83333 m .50939 .79623 L .52568 .78793 L p .707 .577 .707 r
F P
0 g
s
.52568 .78793 m .53257 .82502 L .51629 .83333 L p .707 .577 .707 r
F P
0 g
s
.5148 .7546 m .51763 .73661 L .54151 .73315 L p .707 .577 .707 r
F P
0 g
s
.54151 .73315 m .53869 .75115 L .5148 .7546 L p .707 .577 .707 r
F P
0 g
s
.53257 .82502 m .52568 .78793 L .54947 .77955 L p .707 .577 .707 r
F P
0 g
s
.54947 .77955 m .55637 .81665 L .53257 .82502 L p .707 .577 .707 r
F P
0 g
s
.49526 .32091 m .49037 .82225 L .53531 .82155 L p .707 .577 .707 r
F P
0 g
s
.54156 .63897 m .55411 .69435 L .53043 .70332 L p .707 .577 .707 r
F P
0 g
s
.53531 .82155 m .5402 .32021 L .49526 .32091 L p .707 .577 .707 r
F P
0 g
s
.55411 .69435 m .54156 .63897 L .57035 .63042 L p .707 .577 .707 r
F P
0 g
s
.57035 .63042 m .58291 .68581 L .55411 .69435 L p .707 .577 .707 r
F P
0 g
s
.53869 .75115 m .54151 .73315 L .57063 .73319 L p .707 .577 .707 r
F P
0 g
s
.57063 .73319 m .56781 .75118 L .53869 .75115 L p .707 .577 .707 r
F P
0 g
s
.55637 .81665 m .54947 .77955 L .57846 .77192 L p .707 .577 .707 r
F P
0 g
s
.56781 .75118 m .57063 .73319 L .60213 .73671 L p .707 .577 .707 r
F P
0 g
s
.57846 .77192 m .58536 .80902 L .55637 .81665 L p .707 .577 .707 r
F P
0 g
s
.60213 .73671 m .59931 .7547 L .56781 .75118 L p .707 .577 .707 r
F P
0 g
s
.5402 .32021 m .53531 .82155 L .57679 .81709 L p .707 .577 .707 r
F P
0 g
s
.58291 .68581 m .57035 .63042 L .60145 .62314 L p .707 .577 .707 r
F P
0 g
s
.57679 .81709 m .58168 .31575 L .5402 .32021 L p .707 .577 .707 r
F P
0 g
s
.44637 .81914 m .45125 .3178 L .41249 .31116 L p .707 .577 .707 r
F P
0 g
s
.45125 .3178 m .44637 .81914 L .49037 .82225 L p .707 .577 .707 r
F P
0 g
s
.69078 .61767 m .70333 .67305 L .69132 .67033 L p .707 .577 .707 r
F P
0 g
s
.69132 .67033 m .67877 .61495 L .69078 .61767 L p .707 .577 .707 r
F P
0 g
s
.60145 .62314 m .61401 .67852 L .58291 .68581 L p .707 .577 .707 r
F P
0 g
s
.63294 .74338 m .63011 .76137 L .59931 .7547 L p .707 .577 .707 r
F P
0 g
s
.59931 .7547 m .60213 .73671 L .63294 .74338 L p .707 .577 .707 r
F P
0 g
s
.58536 .80902 m .57846 .77192 L .6098 .76579 L p .707 .577 .707 r
F P
0 g
s
.6098 .76579 m .6167 .80289 L .58536 .80902 L p .707 .577 .707 r
F P
0 g
s
.58168 .31575 m .57679 .81709 L .61075 .80931 L p .707 .577 .707 r
F P
0 g
s
.61401 .67852 m .60145 .62314 L .63181 .61782 L p .707 .577 .707 r
F P
0 g
s
.6167 .80289 m .6098 .76579 L .63499 .76247 L p .707 .577 .707 r
F P
0 g
s
.66002 .75253 m .6572 .77053 L .635 .76302 L p .707 .577 .707 r
F P
0 g
s
.63498 .75993 m .66002 .75253 L .635 .76302 L .707 .577 .707 r
F
.63499 .76247 m .64042 .76176 L p .63505 .77107 L F P
0 g
s
.6167 .80289 m .63499 .76247 L .63505 .77107 L .707 .577 .707 r
F
.635 .76302 m .63011 .76137 L p .63498 .75993 L F P
0 g
s
.61075 .80931 m .61564 .30797 L .58168 .31575 L p .707 .577 .707 r
F P
0 g
s
.70272 .77077 m .70962 .80787 L .70698 .80205 L p .707 .577 .707 r
F P
0 g
s
.70698 .80205 m .70008 .76495 L .70272 .77077 L p .707 .577 .707 r
F P
0 g
s
.6958 .78532 m .69298 .80331 L .69026 .79258 L p .707 .577 .707 r
F P
0 g
s
.69026 .79258 m .69308 .77458 L .6958 .78532 L p .707 .577 .707 r
F P
0 g
s
.4076 .8125 m .41249 .31116 L .38277 .30166 L p .707 .577 .707 r
F P
0 g
s
.41249 .31116 m .4076 .8125 L .44637 .81914 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25904 .72599 m .25214 .68889 L .22152 .69293 L p .707 .577 .707 r
F P
0 g
s
.22152 .69293 m .22842 .73002 L .25904 .72599 L p .707 .577 .707 r
F P
0 g
s
.25582 .72815 m .24326 .67277 L .21291 .67808 L p .707 .577 .707 r
F P
0 g
s
.25214 .68889 m .25904 .72599 L .29037 .71986 L p .707 .577 .707 r
F P
0 g
s
.29037 .71986 m .28348 .68276 L .25214 .68889 L p .707 .577 .707 r
F P
0 g
s
.24326 .67277 m .25582 .72815 L .28692 .72087 L p .707 .577 .707 r
F P
0 g
s
.28692 .72087 m .27436 .66548 L .24326 .67277 L p .707 .577 .707 r
F P
0 g
s
.28348 .68276 m .29037 .71986 L .31936 .71223 L p .707 .577 .707 r
F P
0 g
s
.31936 .71223 m .31246 .67514 L .28348 .68276 L p .707 .577 .707 r
F P
0 g
s
.27436 .66548 m .28692 .72087 L .31571 .71232 L p .707 .577 .707 r
F P
0 g
s
.31571 .71232 m .30316 .65694 L .27436 .66548 L p .707 .577 .707 r
F P
0 g
s
.67877 .61495 m .69132 .67033 L .671 .67038 L p .707 .577 .707 r
F P
0 g
s
.671 .67038 m .65845 .615 L .67877 .61495 L p .707 .577 .707 r
F P
0 g
s
.22546 .73347 m .21291 .67808 L .18627 .68091 L p .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .22152 .69293 L .21912 .69306 L p .707 .577 .707 r
F P
0 g
s
.21291 .67808 m .22546 .73347 L .22733 .73314 L p .707 .577 .707 r
F P
0 g
s
.21704 .6829 m .21291 .67808 L .22733 .73314 L .707 .577 .707 r
F
.18627 .68091 m .19882 .73629 L .22546 .73347 L p F P
0 g
s
.21912 .69306 m .19461 .69447 L p .22621 .72771 L .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .21912 .69306 L .22621 .72771 L .707 .577 .707 r
F
.19461 .69447 m .20151 .73157 L .22842 .73002 L p F P
0 g
s
.22733 .73314 m .25582 .72815 L p .21704 .6829 L .707 .577 .707 r
F P
0 g
s
.63181 .61782 m .64436 .67321 L .61401 .67852 L p .707 .577 .707 r
F P
0 g
s
.63011 .76137 m .63294 .74338 L .66002 .75253 L p .707 .577 .707 r
F P
0 g
s
.64042 .76176 m .64732 .79886 L .6167 .80289 L p .707 .577 .707 r
F P
0 g
s
.61564 .30797 m .61075 .80931 L .63386 .79898 L p .707 .577 .707 r
F P
0 g
s
.64436 .67321 m .63181 .61782 L .65845 .615 L p .707 .577 .707 r
F P
0 g
s
.63386 .79898 m .63875 .29764 L .61564 .30797 L p .707 .577 .707 r
F P
0 g
s
.70008 .76495 m .70698 .80205 L .69478 .79842 L p .707 .577 .707 r
F P
0 g
s
.69308 .77458 m .69026 .79258 L .67793 .78128 L p .707 .577 .707 r
F P
0 g
s
.67793 .78128 m .68075 .76329 L .69308 .77458 L p .707 .577 .707 r
F P
0 g
s
.69478 .79842 m .68788 .76132 L .70008 .76495 L p .707 .577 .707 r
F P
0 g
s
.31246 .67514 m .31936 .71223 L .34316 .70386 L p .707 .577 .707 r
F P
0 g
s
.34316 .70386 m .33626 .66676 L .31246 .67514 L p .707 .577 .707 r
F P
0 g
s
.30316 .65694 m .31571 .71232 L .33939 .70336 L p .707 .577 .707 r
F P
0 g
s
.33939 .70336 m .32684 .64797 L .30316 .65694 L p .707 .577 .707 r
F P
0 g
s
.37788 .803 m .38277 .30166 L .36499 .29022 L p .707 .577 .707 r
F P
0 g
s
.38277 .30166 m .37788 .803 L .4076 .8125 L p .707 .577 .707 r
F P
0 g
s
.19882 .73629 m .18627 .68091 L .16595 .68096 L p .707 .577 .707 r
F P
0 g
s
.20151 .73157 m .19461 .69447 L .17405 .69337 L p .707 .577 .707 r
F P
0 g
s
.65845 .615 m .671 .67038 L .64436 .67321 L p .707 .577 .707 r
F P
0 g
s
.33626 .66676 m .34316 .70386 L .35944 .69555 L p .707 .577 .707 r
F P
0 g
s
.35944 .69555 m .35254 .65845 L .33626 .66676 L p .707 .577 .707 r
F P
0 g
s
.32684 .64797 m .33939 .70336 L .35563 .69485 L p .707 .577 .707 r
F P
0 g
s
.35563 .69485 m .34308 .63946 L .32684 .64797 L p .707 .577 .707 r
F P
0 g
s
.16595 .68096 m .1785 .73634 L .19882 .73629 L p .707 .577 .707 r
F P
0 g
s
.17405 .69337 m .18095 .73046 L .20151 .73157 L p .707 .577 .707 r
F P
0 g
s
.68788 .76132 m .69478 .79842 L .67422 .79732 L p .707 .577 .707 r
F P
0 g
s
.68075 .76329 m .67793 .78128 L .6572 .77053 L p .707 .577 .707 r
F P
0 g
s
.6572 .77053 m .66002 .75253 L .68075 .76329 L p .707 .577 .707 r
F P
0 g
s
.67422 .79732 m .66733 .76022 L .68788 .76132 L p .707 .577 .707 r
F P
0 g
s
.24202 .85462 m .24484 .83663 L .21403 .82996 L p .707 .577 .707 r
F P
0 g
s
.24484 .83663 m .24202 .85462 L .27352 .85814 L p .707 .577 .707 r
F P
0 g
s
.27352 .85814 m .27634 .84015 L .24484 .83663 L p .707 .577 .707 r
F P
0 g
s
.64732 .79886 m .64042 .76176 L .66733 .76022 L p .707 .577 .707 r
F P
0 g
s
.63875 .29764 m .63386 .79898 L .64386 .7871 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .64875 .28576 L .63875 .29764 L p .707 .577 .707 r
F P
0 g
s
.27634 .84015 m .27352 .85814 L .30264 .85818 L p .707 .577 .707 r
F P
0 g
s
.30264 .85818 m .30546 .84019 L .27634 .84015 L p .707 .577 .707 r
F P
0 g
s
.21121 .84795 m .21403 .82996 L .18694 .8208 L p .707 .577 .707 r
F P
0 g
s
.21403 .82996 m .21121 .84795 L .24202 .85462 L p .707 .577 .707 r
F P
0 g
s
.1785 .73634 m .16595 .68096 L .15394 .67824 L p .707 .577 .707 r
F P
0 g
s
.18095 .73046 m .17405 .69337 L .16186 .68973 L p .707 .577 .707 r
F P
0 g
s
.18694 .8208 m .18412 .8388 L .21121 .84795 L p .707 .577 .707 r
F P
0 g
s
.35254 .65845 m .35944 .69555 L .36661 .68812 L p .707 .577 .707 r
F P
0 g
s
.34308 .63946 m .35563 .69485 L .36284 .68762 L p .707 .577 .707 r
F P
0 g
s
.36661 .68812 m .35971 .65103 L .35254 .65845 L p .707 .577 .707 r
F P
0 g
s
.36284 .68762 m .35029 .63224 L .34308 .63946 L p .707 .577 .707 r
F P
0 g
s
.15394 .67824 m .16649 .73362 L .1785 .73634 L p .707 .577 .707 r
F P
0 g
s
.16186 .68973 m .16875 .72683 L .18095 .73046 L p .707 .577 .707 r
F P
0 g
s
.30546 .84019 m .30264 .85818 L .32652 .85472 L p .707 .577 .707 r
F P
0 g
s
.32652 .85472 m .32934 .83673 L .30546 .84019 L p .707 .577 .707 r
F P
0 g
s
.35029 .63224 m .36284 .68762 L .36032 .6824 L p .707 .577 .707 r
F P
0 g
s
.36032 .6824 m .34777 .62702 L .35029 .63224 L p .707 .577 .707 r
F P
0 g
s
.35971 .65103 m .36661 .68812 L .36397 .68231 L p .707 .577 .707 r
F P
0 g
s
.36397 .68231 m .35707 .64521 L .35971 .65103 L p .707 .577 .707 r
F P
0 g
s
.34777 .62702 m .36032 .6824 L .34831 .67968 L p .707 .577 .707 r
F P
0 g
s
.35707 .64521 m .36397 .68231 L .35177 .67867 L p .707 .577 .707 r
F P
0 g
s
.3601 .79156 m .36499 .29022 L .3609 .27796 L p .707 .577 .707 r
F P
0 g
s
.36499 .29022 m .3601 .79156 L .37788 .803 L p .707 .577 .707 r
F P
0 g
s
.18412 .8388 m .18694 .8208 L .16622 .81005 L p .707 .577 .707 r
F P
0 g
s
.66733 .76022 m .67422 .79732 L .64732 .79886 L p .707 .577 .707 r
F P
0 g
s
.16622 .81005 m .1634 .82804 L .18412 .8388 L p .707 .577 .707 r
F P
0 g
s
.16875 .72683 m .16186 .68973 L .15921 .68392 L p .707 .577 .707 r
F P
0 g
s
.16649 .73362 m .15394 .67824 L .15142 .67302 L p .707 .577 .707 r
F P
0 g
s
.32934 .83673 m .32652 .85472 L .34283 .84811 L p .707 .577 .707 r
F P
0 g
s
.34283 .84811 m .34565 .83011 L .32934 .83673 L p .707 .577 .707 r
F P
0 g
s
.1634 .82804 m .16622 .81005 L .15389 .79875 L p .707 .577 .707 r
F P
0 g
s
.15921 .68392 m .16611 .72101 L .16875 .72683 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .63977 .77484 L p .6429 .6043 L .707 .577 .707 r
F P
0 g
s
.6429 .6043 m .64512 .4833 L .6446 .60836 L .707 .577 .707 r
F
.6429 .6043 m .6446 .60836 L .64386 .7871 L F
.64466 .2735 m .63977 .77484 L .62199 .7634 L p F P
0 g
s
.63415 .57685 m .63163 .57163 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.64709 .45587 m .64386 .7871 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64466 .2735 m .64875 .28576 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.63977 .77484 m .64222 .52379 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64222 .52379 m .64466 .2735 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .65871 .63495 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63415 .57685 m .63739 .59114 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .6467 .63224 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .63739 .59114 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .63415 .57685 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .64616 .57957 L .63835 .5778 L p .707 .577 .707 r
F P
0 g
s
.63835 .5778 m .63415 .57685 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .63835 .5778 L .6378 .58547 L .707 .577 .707 r
F
.64875 .28576 m .64709 .45587 L p .64512 .4833 L F P
0 g
s
.15142 .67302 m .16397 .7284 L .16649 .73362 L p .707 .577 .707 r
F P
0 g
s
.15389 .79875 m .15107 .81675 L .1634 .82804 L p .707 .577 .707 r
F P
0 g
s
.3609 .27796 m .35602 .7793 L .3601 .79156 L p .707 .577 .707 r
F P
0 g
s
.35602 .7793 m .3609 .27796 L .3709 .26608 L p .707 .577 .707 r
F P
0 g
s
.34565 .83011 m .34283 .84811 L .34997 .83899 L p .707 .577 .707 r
F P
0 g
s
.34997 .83899 m .3528 .82099 L .34565 .83011 L p .707 .577 .707 r
F P
0 g
s
.16611 .72101 m .15921 .68392 L .16638 .67649 L p .707 .577 .707 r
F P
0 g
s
.16397 .7284 m .15142 .67302 L .15863 .66579 L p .707 .577 .707 r
F P
0 g
s
.15107 .81675 m .15389 .79875 L .15116 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16638 .67649 m .17328 .71359 L .16611 .72101 L p .707 .577 .707 r
F P
0 g
s
.34831 .67968 m .33576 .6243 L .34777 .62702 L p .707 .577 .707 r
F P
0 g
s
.15116 .78802 m .14834 .80601 L .15107 .81675 L p .707 .577 .707 r
F P
0 g
s
.35177 .67867 m .34487 .64158 L .35707 .64521 L p .707 .577 .707 r
F P
0 g
s
.15863 .66579 m .17118 .72118 L .16397 .7284 L p .707 .577 .707 r
F P
0 g
s
.62199 .7634 m .62688 .26206 L .64466 .2735 L p .707 .577 .707 r
F P
0 g
s
.3528 .82099 m .34997 .83899 L .34725 .82825 L p .707 .577 .707 r
F P
0 g
s
.34725 .82825 m .35007 .81026 L .3528 .82099 L p .707 .577 .707 r
F P
0 g
s
.17328 .71359 m .16638 .67649 L .18267 .66818 L p .707 .577 .707 r
F P
0 g
s
.17118 .72118 m .15863 .66579 L .17487 .65728 L p .707 .577 .707 r
F P
0 g
s
.14834 .80601 m .15116 .78802 L .15831 .7789 L p .707 .577 .707 r
F P
0 g
s
.36602 .76742 m .3709 .26608 L .39401 .25575 L p .707 .577 .707 r
F P
0 g
s
.3709 .26608 m .36602 .76742 L .35602 .7793 L p .707 .577 .707 r
F P
0 g
s
.18267 .66818 m .18956 .70528 L .17328 .71359 L p .707 .577 .707 r
F P
0 g
s
.33576 .6243 m .34831 .67968 L .32799 .67973 L p .707 .577 .707 r
F P
0 g
s
.32799 .67973 m .31544 .62435 L .33576 .6243 L p .707 .577 .707 r
F P
0 g
s
.15831 .7789 m .15548 .79689 L .14834 .80601 L p .707 .577 .707 r
F P
0 g
s
.34487 .64158 m .35177 .67867 L .33121 .67757 L p .707 .577 .707 r
F P
0 g
s
.33121 .67757 m .32432 .64047 L .34487 .64158 L p .707 .577 .707 r
F P
0 g
s
.17487 .65728 m .18742 .71267 L .17118 .72118 L p .707 .577 .707 r
F P
0 g
s
.18956 .70528 m .18267 .66818 L .20646 .65981 L p .707 .577 .707 r
F P
0 g
s
.18742 .71267 m .17487 .65728 L .19855 .64832 L p .707 .577 .707 r
F P
0 g
s
.35007 .81026 m .34725 .82825 L .33492 .81696 L p .707 .577 .707 r
F P
0 g
s
.33492 .81696 m .33774 .79896 L .35007 .81026 L p .707 .577 .707 r
F P
0 g
s
.62688 .26206 m .62199 .7634 L .59227 .7539 L p .707 .577 .707 r
F P
0 g
s
.59227 .7539 m .59716 .25256 L .62688 .26206 L p .707 .577 .707 r
F P
0 g
s
.15548 .79689 m .15831 .7789 L .17462 .77229 L p .707 .577 .707 r
F P
0 g
s
.31544 .62435 m .32799 .67973 L .30299 .68238 L p .707 .577 .707 r
F P
0 g
s
.30225 .67884 m .31544 .62435 L .30299 .68238 L .707 .577 .707 r
F
.30236 .67937 m .27369 .68315 L p .29535 .64559 L F P
0 g
s
.27369 .68315 m .26679 .64605 L .29468 .64238 L p .707 .577 .707 r
F P
0 g
s
.27369 .68315 m .29468 .64238 L .29535 .64559 L .707 .577 .707 r
F
.30135 .68256 m .2888 .62717 L .29146 .62689 L p F P
0 g
s
.29146 .62689 m .31544 .62435 L p .30225 .67884 L .707 .577 .707 r
F P
0 g
s
.30135 .68256 m .29146 .62689 L .30225 .67884 L .707 .577 .707 r
F
.29468 .64238 m .29741 .64202 L p .29535 .64559 L F P
0 g
s
.29741 .64202 m .30431 .67911 L .30236 .67937 L p .707 .577 .707 r
F P
0 g
s
.29535 .64559 m .29741 .64202 L .30236 .67937 L .707 .577 .707 r
F
.30299 .68238 m .30135 .68256 L p .30225 .67884 L F P
0 g
s
.32432 .64047 m .33121 .67757 L .30431 .67911 L p .707 .577 .707 r
F P
0 g
s
.30431 .67911 m .29741 .64202 L .32432 .64047 L p .707 .577 .707 r
F P
0 g
s
.20646 .65981 m .21336 .6969 L .18956 .70528 L p .707 .577 .707 r
F P
0 g
s
.19855 .64832 m .2111 .7037 L .18742 .71267 L p .707 .577 .707 r
F P
0 g
s
.17462 .77229 m .17179 .79028 L .15548 .79689 L p .707 .577 .707 r
F P
0 g
s
.73603 .62676 m .72348 .57138 L .69312 .5767 L p .707 .577 .707 r
F P
0 g
s
.72348 .57138 m .73603 .62676 L .76713 .61948 L p .707 .577 .707 r
F P
0 g
s
.76713 .61948 m .75458 .5641 L .72348 .57138 L p .707 .577 .707 r
F P
0 g
s
.39401 .25575 m .38912 .75709 L .36602 .76742 L p .707 .577 .707 r
F P
0 g
s
.38912 .75709 m .39401 .25575 L .42797 .24797 L p .707 .577 .707 r
F P
0 g
s
.75458 .5641 m .76713 .61948 L .79593 .61093 L p .707 .577 .707 r
F P
0 g
s
.79593 .61093 m .78337 .55555 L .75458 .5641 L p .707 .577 .707 r
F P
0 g
s
.21336 .6969 m .20646 .65981 L .23545 .65218 L p .707 .577 .707 r
F P
0 g
s
.2111 .7037 m .19855 .64832 L .22734 .63977 L p .707 .577 .707 r
F P
0 g
s
.26679 .64605 m .27369 .68315 L .24235 .68928 L p .707 .577 .707 r
F P
0 g
s
.2888 .62717 m .30135 .68256 L .271 .68787 L p .707 .577 .707 r
F P
0 g
s
.24235 .68928 m .23545 .65218 L .26679 .64605 L p .707 .577 .707 r
F P
0 g
s
.271 .68787 m .25844 .63249 L .2888 .62717 L p .707 .577 .707 r
F P
0 g
s
.70567 .63208 m .69312 .5767 L .66648 .57952 L p .707 .577 .707 r
F P
0 g
s
.69312 .5767 m .70567 .63208 L .73603 .62676 L p .707 .577 .707 r
F P
0 g
s
.23545 .65218 m .24235 .68928 L .21336 .6969 L p .707 .577 .707 r
F P
0 g
s
.33774 .79896 m .33492 .81696 L .31419 .8062 L p .707 .577 .707 r
F P
0 g
s
.31419 .8062 m .31702 .78821 L .33774 .79896 L p .707 .577 .707 r
F P
0 g
s
.78337 .55555 m .79593 .61093 L .8196 .60197 L p .707 .577 .707 r
F P
0 g
s
.8196 .60197 m .80705 .54659 L .78337 .55555 L p .707 .577 .707 r
F P
0 g
s
.22734 .63977 m .2399 .69516 L .2111 .7037 L p .707 .577 .707 r
F P
0 g
s
.2399 .69516 m .22734 .63977 L .25844 .63249 L p .707 .577 .707 r
F P
0 g
s
.25844 .63249 m .271 .68787 L .2399 .69516 L p .707 .577 .707 r
F P
0 g
s
.17179 .79028 m .17462 .77229 L .1985 .76883 L p .707 .577 .707 r
F P
0 g
s
.66648 .57952 m .67903 .6349 L .70567 .63208 L p .707 .577 .707 r
F P
0 g
s
.59716 .25256 m .59227 .7539 L .55351 .74726 L p .707 .577 .707 r
F P
0 g
s
.55351 .74726 m .5584 .24592 L .59716 .25256 L p .707 .577 .707 r
F P
0 g
s
.1985 .76883 m .19568 .78682 L .17179 .79028 L p .707 .577 .707 r
F P
0 g
s
.67903 .6349 m .66648 .57952 L .64616 .57957 L p .707 .577 .707 r
F P
0 g
s
.42308 .74931 m .42797 .24797 L .46945 .24351 L p .707 .577 .707 r
F P
0 g
s
.42797 .24797 m .42308 .74931 L .38912 .75709 L p .707 .577 .707 r
F P
0 g
s
.80705 .54659 m .8196 .60197 L .83584 .59346 L p .707 .577 .707 r
F P
0 g
s
.83584 .59346 m .82329 .53807 L .80705 .54659 L p .707 .577 .707 r
F P
0 g
s
.31702 .78821 m .31419 .8062 L .2871 .79705 L p .707 .577 .707 r
F P
0 g
s
.2871 .79705 m .28993 .77905 L .31702 .78821 L p .707 .577 .707 r
F P
0 g
s
.19568 .78682 m .1985 .76883 L .22762 .76886 L p .707 .577 .707 r
F P
0 g
s
.64616 .57957 m .65871 .63495 L .67903 .6349 L p .707 .577 .707 r
F P
0 g
s
.73925 .7537 m .73235 .7166 L .70173 .72063 L p .707 .577 .707 r
F P
0 g
s
.73235 .7166 m .73925 .7537 L .77059 .74756 L p .707 .577 .707 r
F P
0 g
s
.77059 .74756 m .76369 .71047 L .73235 .7166 L p .707 .577 .707 r
F P
0 g
s
.72223 .72691 m .72505 .70891 L .69425 .70225 L p .707 .577 .707 r
F P
0 g
s
.72505 .70891 m .72223 .72691 L .75373 .73043 L p .707 .577 .707 r
F P
0 g
s
.75373 .73043 m .75655 .71244 L .72505 .70891 L p .707 .577 .707 r
F P
0 g
s
.76369 .71047 m .77059 .74756 L .79957 .73994 L p .707 .577 .707 r
F P
0 g
s
.79957 .73994 m .79268 .70284 L .76369 .71047 L p .707 .577 .707 r
F P
0 g
s
.5584 .24592 m .55351 .74726 L .5095 .74415 L p .707 .577 .707 r
F P
0 g
s
.5095 .74415 m .51439 .24281 L .5584 .24592 L p .707 .577 .707 r
F P
0 g
s
.75655 .71244 m .75373 .73043 L .78285 .73046 L p .707 .577 .707 r
F P
0 g
s
.78285 .73046 m .78567 .71247 L .75655 .71244 L p .707 .577 .707 r
F P
0 g
s
.22762 .76886 m .2248 .78686 L .19568 .78682 L p .707 .577 .707 r
F P
0 g
s
.69143 .72024 m .69425 .70225 L .66716 .69309 L p .707 .577 .707 r
F P
0 g
s
.70173 .72063 m .70863 .75773 L .73925 .7537 L p .707 .577 .707 r
F P
0 g
s
.70863 .75773 m .70173 .72063 L .69696 .7209 L p .707 .577 .707 r
F P
0 g
s
.69425 .70225 m .69143 .72024 L .69698 .72144 L p .707 .577 .707 r
F P
0 g
s
.6965 .70423 m .69425 .70225 L .69698 .72144 L .707 .577 .707 r
F
.69696 .7209 m .67482 .72217 L p .69767 .74621 L F P
0 g
s
.70863 .75773 m .69696 .7209 L .69767 .74621 L .707 .577 .707 r
F
.69698 .72144 m .72223 .72691 L p .6965 .70423 L F P
0 g
s
.46456 .74485 m .46945 .24351 L .51439 .24281 L p .707 .577 .707 r
F P
0 g
s
.46945 .24351 m .46456 .74485 L .42308 .74931 L p .707 .577 .707 r
F P
0 g
s
.28993 .77905 m .2871 .79705 L .2563 .79038 L p .707 .577 .707 r
F P
0 g
s
.2563 .79038 m .25912 .77239 L .28993 .77905 L p .707 .577 .707 r
F P
0 g
s
.2248 .78686 m .22762 .76886 L .25912 .77239 L p .707 .577 .707 r
F P
0 g
s
.66716 .69309 m .66434 .71108 L .69143 .72024 L p .707 .577 .707 r
F P
0 g
s
.79268 .70284 m .79957 .73994 L .82337 .73156 L p .707 .577 .707 r
F P
0 g
s
.82337 .73156 m .81648 .69446 L .79268 .70284 L p .707 .577 .707 r
F P
0 g
s
.51439 .24281 m .5095 .74415 L .46456 .74485 L p .707 .577 .707 r
F P
0 g
s
.67482 .72217 m .68172 .75927 L .70863 .75773 L p .707 .577 .707 r
F P
0 g
s
.25912 .77239 m .2563 .79038 L .2248 .78686 L p .707 .577 .707 r
F P
0 g
s
.78567 .71247 m .78285 .73046 L .80674 .727 L p .707 .577 .707 r
F P
0 g
s
.80674 .727 m .80956 .70901 L .78567 .71247 L p .707 .577 .707 r
F P
0 g
s
.66434 .71108 m .66716 .69309 L .64643 .68234 L p .707 .577 .707 r
F P
0 g
s
.82329 .53807 m .83584 .59346 L .84306 .58624 L p .707 .577 .707 r
F P
0 g
s
.84306 .58624 m .8305 .53085 L .82329 .53807 L p .707 .577 .707 r
F P
0 g
s
.68172 .75927 m .67482 .72217 L .65427 .72107 L p .707 .577 .707 r
F P
0 g
s
.64643 .68234 m .64361 .70033 L .66434 .71108 L p .707 .577 .707 r
F P
0 g
s
.81648 .69446 m .82337 .73156 L .83966 .72325 L p .707 .577 .707 r
F P
0 g
s
.83966 .72325 m .83276 .68616 L .81648 .69446 L p .707 .577 .707 r
F P
0 g
s
.65427 .72107 m .66117 .75817 L .68172 .75927 L p .707 .577 .707 r
F P
0 g
s
.80956 .70901 m .80674 .727 L .82305 .72039 L p .707 .577 .707 r
F P
0 g
s
.82305 .72039 m .82587 .7024 L .80956 .70901 L p .707 .577 .707 r
F P
0 g
s
.64361 .70033 m .64643 .68234 L .6341 .67104 L p .707 .577 .707 r
F P
0 g
s
.6341 .67104 m .63128 .68903 L .64361 .70033 L p .707 .577 .707 r
F P
0 g
s
.66117 .75817 m .65427 .72107 L .64207 .71744 L p .707 .577 .707 r
F P
0 g
s
.8305 .53085 m .84306 .58624 L .84054 .58101 L p .707 .577 .707 r
F P
0 g
s
.84054 .58101 m .82798 .52563 L .8305 .53085 L p .707 .577 .707 r
F P
0 g
s
.63163 .57163 m .64418 .62701 L .6467 .63224 L p .707 .577 .707 r
F P
0 g
s
.64207 .71744 m .64897 .75453 L .66117 .75817 L p .707 .577 .707 r
F P
0 g
s
.83276 .68616 m .83966 .72325 L .84683 .71583 L p .707 .577 .707 r
F P
0 g
s
.84683 .71583 m .83993 .67873 L .83276 .68616 L p .707 .577 .707 r
F P
0 g
s
.82587 .7024 m .82305 .72039 L .83019 .71127 L p .707 .577 .707 r
F P
0 g
s
.83019 .71127 m .83301 .69328 L .82587 .7024 L p .707 .577 .707 r
F P
0 g
s
.63128 .68903 m .6341 .67104 L .63138 .66031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64418 .62701 m .63163 .57163 L .63884 .56441 L p .707 .577 .707 r
F P
0 g
s
.63138 .66031 m .62856 .6783 L .63128 .68903 L p .707 .577 .707 r
F P
0 g
s
.64897 .75453 m .64207 .71744 L .63943 .71162 L p .707 .577 .707 r
F P
0 g
s
.82798 .52563 m .84054 .58101 L .82853 .57829 L p .707 .577 .707 r
F P
0 g
s
.82853 .57829 m .81597 .52291 L .82798 .52563 L p .707 .577 .707 r
F P
0 g
s
.63884 .56441 m .6514 .61979 L .64418 .62701 L p .707 .577 .707 r
F P
0 g
s
.63943 .71162 m .64633 .74872 L .64897 .75453 L p .707 .577 .707 r
F P
0 g
s
.83993 .67873 m .84683 .71583 L .84418 .71001 L p .707 .577 .707 r
F P
0 g
s
.84418 .71001 m .83729 .67292 L .83993 .67873 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83301 .69328 m .83019 .71127 L .82746 .70054 L p .707 .577 .707 r
F P
0 g
s
.82746 .70054 m .83028 .68255 L .83301 .69328 L p .707 .577 .707 r
F P
0 g
s
.62856 .6783 m .63138 .66031 L .63852 .65119 L p .707 .577 .707 r
F P
0 g
s
.6514 .61979 m .63884 .56441 L .65508 .5559 L p .707 .577 .707 r
F P
0 g
s
.63852 .65119 m .6357 .66918 L .62856 .6783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39624 .63395 m .38934 .59685 L .35872 .60089 L p .707 .577 .707 r
F P
0 g
s
.35872 .60089 m .36562 .63799 L .39624 .63395 L p .707 .577 .707 r
F P
0 g
s
.39302 .63611 m .38047 .58073 L .35011 .58605 L p .707 .577 .707 r
F P
0 g
s
.38934 .59685 m .39624 .63395 L .42758 .62782 L p .707 .577 .707 r
F P
0 g
s
.42758 .62782 m .42068 .59072 L .38934 .59685 L p .707 .577 .707 r
F P
0 g
s
.38047 .58073 m .39302 .63611 L .42412 .62883 L p .707 .577 .707 r
F P
0 g
s
.42412 .62883 m .41157 .57345 L .38047 .58073 L p .707 .577 .707 r
F P
0 g
s
.42068 .59072 m .42758 .62782 L .45656 .62019 L p .707 .577 .707 r
F P
0 g
s
.45656 .62019 m .44967 .5831 L .42068 .59072 L p .707 .577 .707 r
F P
0 g
s
.41157 .57345 m .42412 .62883 L .45292 .62028 L p .707 .577 .707 r
F P
0 g
s
.45292 .62028 m .44036 .5649 L .41157 .57345 L p .707 .577 .707 r
F P
0 g
s
.64633 .74872 m .63943 .71162 L .6466 .7042 L p .707 .577 .707 r
F P
0 g
s
.81597 .52291 m .82853 .57829 L .80821 .57834 L p .707 .577 .707 r
F P
0 g
s
.80821 .57834 m .79566 .52296 L .81597 .52291 L p .707 .577 .707 r
F P
0 g
s
.65508 .5559 m .66764 .61128 L .6514 .61979 L p .707 .577 .707 r
F P
0 g
s
.36266 .64143 m .35011 .58605 L .32347 .58887 L p .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35872 .60089 L .35632 .60103 L p .707 .577 .707 r
F P
0 g
s
.35011 .58605 m .36266 .64143 L .36453 .6411 L p .707 .577 .707 r
F P
0 g
s
.35424 .59086 m .35011 .58605 L .36453 .6411 L .707 .577 .707 r
F
.32347 .58887 m .33602 .64425 L .36266 .64143 L p F P
0 g
s
.35632 .60103 m .33181 .60243 L p .36342 .63567 L .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35632 .60103 L .36342 .63567 L .707 .577 .707 r
F
.33181 .60243 m .33871 .63953 L .36562 .63799 L p F P
0 g
s
.36453 .6411 m .39302 .63611 L p .35424 .59086 L .707 .577 .707 r
F P
0 g
s
.6466 .7042 m .6535 .74129 L .64633 .74872 L p .707 .577 .707 r
F P
0 g
s
.83729 .67292 m .84418 .71001 L .83199 .70638 L p .707 .577 .707 r
F P
0 g
s
.83028 .68255 m .82746 .70054 L .81513 .68924 L p .707 .577 .707 r
F P
0 g
s
.81513 .68924 m .81795 .67125 L .83028 .68255 L p .707 .577 .707 r
F P
0 g
s
.83199 .70638 m .82509 .66928 L .83729 .67292 L p .707 .577 .707 r
F P
0 g
s
.44967 .5831 m .45656 .62019 L .48036 .61182 L p .707 .577 .707 r
F P
0 g
s
.48036 .61182 m .47347 .57472 L .44967 .5831 L p .707 .577 .707 r
F P
0 g
s
.44036 .5649 m .45292 .62028 L .4766 .61132 L p .707 .577 .707 r
F P
0 g
s
.4766 .61132 m .46404 .55594 L .44036 .5649 L p .707 .577 .707 r
F P
0 g
s
.6357 .66918 m .63852 .65119 L .65483 .64457 L p .707 .577 .707 r
F P
0 g
s
.66764 .61128 m .65508 .5559 L .67876 .54693 L p .707 .577 .707 r
F P
0 g
s
.33602 .64425 m .32347 .58887 L .30315 .58892 L p .707 .577 .707 r
F P
0 g
s
.33871 .63953 m .33181 .60243 L .31126 .60133 L p .707 .577 .707 r
F P
0 g
s
.65483 .64457 m .65201 .66257 L .6357 .66918 L p .707 .577 .707 r
F P
0 g
s
.79566 .52296 m .80821 .57834 L .78157 .58117 L p .707 .577 .707 r
F P
0 g
s
.78157 .58117 m .76901 .52579 L .79566 .52296 L p .707 .577 .707 r
F P
0 g
s
.47347 .57472 m .48036 .61182 L .49665 .60351 L p .707 .577 .707 r
F P
0 g
s
.49665 .60351 m .48975 .56641 L .47347 .57472 L p .707 .577 .707 r
F P
0 g
s
.46404 .55594 m .4766 .61132 L .49284 .60281 L p .707 .577 .707 r
F P
0 g
s
.49284 .60281 m .48028 .54742 L .46404 .55594 L p .707 .577 .707 r
F P
0 g
s
.6535 .74129 m .6466 .7042 L .66288 .69589 L p .707 .577 .707 r
F P
0 g
s
.67876 .54693 m .69131 .60231 L .66764 .61128 L p .707 .577 .707 r
F P
0 g
s
.30315 .58892 m .3157 .6443 L .33602 .64425 L p .707 .577 .707 r
F P
0 g
s
.31126 .60133 m .31816 .63843 L .33871 .63953 L p .707 .577 .707 r
F P
0 g
s
.66288 .69589 m .66978 .73299 L .6535 .74129 L p .707 .577 .707 r
F P
0 g
s
.82509 .66928 m .83199 .70638 L .81143 .70528 L p .707 .577 .707 r
F P
0 g
s
.81795 .67125 m .81513 .68924 L .79441 .67849 L p .707 .577 .707 r
F P
0 g
s
.79441 .67849 m .79723 .6605 L .81795 .67125 L p .707 .577 .707 r
F P
0 g
s
.81143 .70528 m .80453 .66818 L .82509 .66928 L p .707 .577 .707 r
F P
0 g
s
.69131 .60231 m .67876 .54693 L .70756 .53839 L p .707 .577 .707 r
F P
0 g
s
.37922 .76258 m .38204 .74459 L .35124 .73792 L p .707 .577 .707 r
F P
0 g
s
.38204 .74459 m .37922 .76258 L .41072 .76611 L p .707 .577 .707 r
F P
0 g
s
.41072 .76611 m .41354 .74811 L .38204 .74459 L p .707 .577 .707 r
F P
0 g
s
.76901 .52579 m .78157 .58117 L .75121 .58648 L p .707 .577 .707 r
F P
0 g
s
.75121 .58648 m .73866 .5311 L .76901 .52579 L p .707 .577 .707 r
F P
0 g
s
.65201 .66257 m .65483 .64457 L .67871 .64112 L p .707 .577 .707 r
F P
0 g
s
.41354 .74811 m .41072 .76611 L .43984 .76614 L p .707 .577 .707 r
F P
0 g
s
.43984 .76614 m .44266 .74815 L .41354 .74811 L p .707 .577 .707 r
F P
0 g
s
.34842 .75592 m .35124 .73792 L .32415 .72877 L p .707 .577 .707 r
F P
0 g
s
.35124 .73792 m .34842 .75592 L .37922 .76258 L p .707 .577 .707 r
F P
0 g
s
.3157 .6443 m .30315 .58892 L .29114 .5862 L p .707 .577 .707 r
F P
0 g
s
.31816 .63843 m .31126 .60133 L .29906 .59769 L p .707 .577 .707 r
F P
0 g
s
.70756 .53839 m .72011 .59377 L .69131 .60231 L p .707 .577 .707 r
F P
0 g
s
.72011 .59377 m .70756 .53839 L .73866 .5311 L p .707 .577 .707 r
F P
0 g
s
.67871 .64112 m .67589 .65911 L .65201 .66257 L p .707 .577 .707 r
F P
0 g
s
.73866 .5311 m .75121 .58648 L .72011 .59377 L p .707 .577 .707 r
F P
0 g
s
.32415 .72877 m .32133 .74676 L .34842 .75592 L p .707 .577 .707 r
F P
0 g
s
.48975 .56641 m .49665 .60351 L .50382 .59609 L p .707 .577 .707 r
F P
0 g
s
.48028 .54742 m .49284 .60281 L .50005 .59559 L p .707 .577 .707 r
F P
0 g
s
.50382 .59609 m .49692 .55899 L .48975 .56641 L p .707 .577 .707 r
F P
0 g
s
.50005 .59559 m .48749 .5402 L .48028 .54742 L p .707 .577 .707 r
F P
0 g
s
.29114 .5862 m .30369 .64159 L .3157 .6443 L p .707 .577 .707 r
F P
0 g
s
.29906 .59769 m .30596 .63479 L .31816 .63843 L p .707 .577 .707 r
F P
0 g
s
.66978 .73299 m .66288 .69589 L .68668 .68751 L p .707 .577 .707 r
F P
0 g
s
.44266 .74815 m .43984 .76614 L .46373 .76268 L p .707 .577 .707 r
F P
0 g
s
.46373 .76268 m .46655 .74469 L .44266 .74815 L p .707 .577 .707 r
F P
0 g
s
.32133 .74676 m .32415 .72877 L .30342 .71801 L p .707 .577 .707 r
F P
0 g
s
.80453 .66818 m .81143 .70528 L .78452 .70682 L p .707 .577 .707 r
F P
0 g
s
.79723 .6605 m .79441 .67849 L .7722 .67098 L p .707 .577 .707 r
F P
0 g
s
.77218 .66789 m .79723 .6605 L .7722 .67098 L .707 .577 .707 r
F
.7539 .71085 m .747 .67375 L .77762 .66972 L p F P
0 g
s
.7722 .67098 m .76732 .66933 L p .77218 .66789 L .707 .577 .707 r
F P
0 g
s
.77762 .66972 m .78452 .70682 L .77244 .70841 L p .707 .577 .707 r
F P
0 g
s
.77244 .70841 m .7539 .71085 L p .77225 .67903 L .707 .577 .707 r
F P
0 g
s
.77225 .67903 m .77762 .66972 L .77244 .70841 L .707 .577 .707 r
F
.78452 .70682 m .77762 .66972 L .80453 .66818 L p F P
0 g
s
.68668 .68751 m .69358 .72461 L .66978 .73299 L p .707 .577 .707 r
F P
0 g
s
.76732 .66933 m .77014 .65134 L .79723 .6605 L p .707 .577 .707 r
F P
0 g
s
.67589 .65911 m .67871 .64112 L .70783 .64115 L p .707 .577 .707 r
F P
0 g
s
.30342 .71801 m .3006 .736 L .32133 .74676 L p .707 .577 .707 r
F P
0 g
s
.70783 .64115 m .70501 .65914 L .67589 .65911 L p .707 .577 .707 r
F P
0 g
s
.69358 .72461 m .68668 .68751 L .71567 .67988 L p .707 .577 .707 r
F P
0 g
s
.30596 .63479 m .29906 .59769 L .29642 .59188 L p .707 .577 .707 r
F P
0 g
s
.30369 .64159 m .29114 .5862 L .28862 .58098 L p .707 .577 .707 r
F P
0 g
s
.77014 .65134 m .76732 .66933 L .73651 .66266 L p .707 .577 .707 r
F P
0 g
s
.73651 .66266 m .73934 .64467 L .77014 .65134 L p .707 .577 .707 r
F P
0 g
s
.70501 .65914 m .70783 .64115 L .73934 .64467 L p .707 .577 .707 r
F P
0 g
s
.46655 .74469 m .46373 .76268 L .48004 .75607 L p .707 .577 .707 r
F P
0 g
s
.48004 .75607 m .48286 .73808 L .46655 .74469 L p .707 .577 .707 r
F P
0 g
s
.71567 .67988 m .72256 .71698 L .69358 .72461 L p .707 .577 .707 r
F P
0 g
s
.73934 .64467 m .73651 .66266 L .70501 .65914 L p .707 .577 .707 r
F P
0 g
s
.3006 .736 m .30342 .71801 L .29109 .70672 L p .707 .577 .707 r
F P
0 g
s
.29642 .59188 m .30331 .62898 L .30596 .63479 L p .707 .577 .707 r
F P
0 g
s
.48749 .5402 m .50005 .59559 L .49753 .59036 L p .707 .577 .707 r
F P
0 g
s
.49753 .59036 m .48497 .53498 L .48749 .5402 L p .707 .577 .707 r
F P
0 g
s
.72256 .71698 m .71567 .67988 L .747 .67375 L p .707 .577 .707 r
F P
0 g
s
.49692 .55899 m .50382 .59609 L .50117 .59027 L p .707 .577 .707 r
F P
0 g
s
.50117 .59027 m .49427 .55317 L .49692 .55899 L p .707 .577 .707 r
F P
0 g
s
.28862 .58098 m .30117 .63636 L .30369 .64159 L p .707 .577 .707 r
F P
0 g
s
.747 .67375 m .7539 .71085 L .72256 .71698 L p .707 .577 .707 r
F P
0 g
s
.29109 .70672 m .28827 .72471 L .3006 .736 L p .707 .577 .707 r
F P
0 g
s
.48286 .73808 m .48004 .75607 L .48718 .74695 L p .707 .577 .707 r
F P
0 g
s
.48718 .74695 m .49 .72896 L .48286 .73808 L p .707 .577 .707 r
F P
0 g
s
.30331 .62898 m .29642 .59188 L .30359 .58445 L p .707 .577 .707 r
F P
0 g
s
.30117 .63636 m .28862 .58098 L .29583 .57376 L p .707 .577 .707 r
F P
0 g
s
.28827 .72471 m .29109 .70672 L .28837 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30359 .58445 m .31049 .62155 L .30331 .62898 L p .707 .577 .707 r
F P
0 g
s
.48497 .53498 m .49753 .59036 L .48552 .58764 L p .707 .577 .707 r
F P
0 g
s
.48552 .58764 m .47296 .53226 L .48497 .53498 L p .707 .577 .707 r
F P
0 g
s
.28837 .69598 m .28555 .71398 L .28827 .72471 L p .707 .577 .707 r
F P
0 g
s
.49427 .55317 m .50117 .59027 L .48898 .58663 L p .707 .577 .707 r
F P
0 g
s
.48898 .58663 m .48208 .54954 L .49427 .55317 L p .707 .577 .707 r
F P
0 g
s
.29583 .57376 m .30839 .62914 L .30117 .63636 L p .707 .577 .707 r
F P
0 g
s
.49 .72896 m .48718 .74695 L .48445 .73621 L p .707 .577 .707 r
F P
0 g
s
.48445 .73621 m .48727 .71822 L .49 .72896 L p .707 .577 .707 r
F P
0 g
s
.31049 .62155 m .30359 .58445 L .31987 .57615 L p .707 .577 .707 r
F P
0 g
s
.30839 .62914 m .29583 .57376 L .31207 .56525 L p .707 .577 .707 r
F P
0 g
s
.28555 .71398 m .28837 .69598 L .29551 .68686 L p .707 .577 .707 r
F P
0 g
s
.31987 .57615 m .32677 .61324 L .31049 .62155 L p .707 .577 .707 r
F P
0 g
s
.47296 .53226 m .48552 .58764 L .4652 .58769 L p .707 .577 .707 r
F P
0 g
s
.4652 .58769 m .45265 .53231 L .47296 .53226 L p .707 .577 .707 r
F P
0 g
s
.29551 .68686 m .29269 .70486 L .28555 .71398 L p .707 .577 .707 r
F P
0 g
s
.48208 .54954 m .48898 .58663 L .46842 .58553 L p .707 .577 .707 r
F P
0 g
s
.46842 .58553 m .46152 .54844 L .48208 .54954 L p .707 .577 .707 r
F P
0 g
s
.31207 .56525 m .32462 .62063 L .30839 .62914 L p .707 .577 .707 r
F P
0 g
s
.32677 .61324 m .31987 .57615 L .34367 .56777 L p .707 .577 .707 r
F P
0 g
s
.32462 .62063 m .31207 .56525 L .33575 .55628 L p .707 .577 .707 r
F P
0 g
s
.48727 .71822 m .48445 .73621 L .47212 .72492 L p .707 .577 .707 r
F P
0 g
s
.47212 .72492 m .47494 .70693 L .48727 .71822 L p .707 .577 .707 r
F P
0 g
s
.29269 .70486 m .29551 .68686 L .31182 .68025 L p .707 .577 .707 r
F P
0 g
s
.45265 .53231 m .4652 .58769 L .44019 .59034 L p .707 .577 .707 r
F P
0 g
s
.43946 .5868 m .45265 .53231 L .44019 .59034 L .707 .577 .707 r
F
.43957 .58733 m .41089 .59111 L p .43255 .55355 L F P
0 g
s
.41089 .59111 m .40399 .55401 L .43188 .55034 L p .707 .577 .707 r
F P
0 g
s
.41089 .59111 m .43188 .55034 L .43255 .55355 L .707 .577 .707 r
F
.43856 .59052 m .426 .53513 L .42867 .53485 L p F P
0 g
s
.42867 .53485 m .45265 .53231 L p .43946 .5868 L .707 .577 .707 r
F P
0 g
s
.43856 .59052 m .42867 .53485 L .43946 .5868 L .707 .577 .707 r
F
.43188 .55034 m .43461 .54998 L p .43255 .55355 L F P
0 g
s
.43461 .54998 m .44151 .58708 L .43957 .58733 L p .707 .577 .707 r
F P
0 g
s
.43255 .55355 m .43461 .54998 L .43957 .58733 L .707 .577 .707 r
F
.44019 .59034 m .43856 .59052 L p .43946 .5868 L F P
0 g
s
.46152 .54844 m .46842 .58553 L .44151 .58708 L p .707 .577 .707 r
F P
0 g
s
.44151 .58708 m .43461 .54998 L .46152 .54844 L p .707 .577 .707 r
F P
0 g
s
.34367 .56777 m .35057 .60487 L .32677 .61324 L p .707 .577 .707 r
F P
0 g
s
.33575 .55628 m .3483 .61166 L .32462 .62063 L p .707 .577 .707 r
F P
0 g
s
.31182 .68025 m .309 .69824 L .29269 .70486 L p .707 .577 .707 r
F P
0 g
s
.35057 .60487 m .34367 .56777 L .37266 .56014 L p .707 .577 .707 r
F P
0 g
s
.3483 .61166 m .33575 .55628 L .36455 .54774 L p .707 .577 .707 r
F P
0 g
s
.40399 .55401 m .41089 .59111 L .37955 .59724 L p .707 .577 .707 r
F P
0 g
s
.426 .53513 m .43856 .59052 L .4082 .59583 L p .707 .577 .707 r
F P
0 g
s
.37955 .59724 m .37266 .56014 L .40399 .55401 L p .707 .577 .707 r
F P
0 g
s
.4082 .59583 m .39565 .54045 L .426 .53513 L p .707 .577 .707 r
F P
0 g
s
.37266 .56014 m .37955 .59724 L .35057 .60487 L p .707 .577 .707 r
F P
0 g
s
.47494 .70693 m .47212 .72492 L .4514 .71416 L p .707 .577 .707 r
F P
0 g
s
.4514 .71416 m .45422 .69617 L .47494 .70693 L p .707 .577 .707 r
F P
0 g
s
.36455 .54774 m .3771 .60312 L .3483 .61166 L p .707 .577 .707 r
F P
0 g
s
.3771 .60312 m .36455 .54774 L .39565 .54045 L p .707 .577 .707 r
F P
0 g
s
.39565 .54045 m .4082 .59583 L .3771 .60312 L p .707 .577 .707 r
F P
0 g
s
.309 .69824 m .31182 .68025 L .3357 .67679 L p .707 .577 .707 r
F P
0 g
s
.3357 .67679 m .33288 .69478 L .309 .69824 L p .707 .577 .707 r
F P
0 g
s
.45422 .69617 m .4514 .71416 L .42431 .70501 L p .707 .577 .707 r
F P
0 g
s
.42431 .70501 m .42713 .68701 L .45422 .69617 L p .707 .577 .707 r
F P
0 g
s
.33288 .69478 m .3357 .67679 L .36482 .67683 L p .707 .577 .707 r
F P
0 g
s
.36482 .67683 m .362 .69482 L .33288 .69478 L p .707 .577 .707 r
F P
0 g
s
.42713 .68701 m .42431 .70501 L .3935 .69834 L p .707 .577 .707 r
F P
0 g
s
.3935 .69834 m .39632 .68035 L .42713 .68701 L p .707 .577 .707 r
F P
0 g
s
.362 .69482 m .36482 .67683 L .39632 .68035 L p .707 .577 .707 r
F P
0 g
s
.39632 .68035 m .3935 .69834 L .362 .69482 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol007=oo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00Kgoo
10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
00000P00Kgoo001]Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001/Ool006]oo`8000=JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06Yoo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00J7oo001XOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001TOol006Io
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<002Ioo`X003Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`007goo1`000eYF00<005YFFUH00UYF00<005YF
00000P00<Goo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`006goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80031oo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF009JEP/000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<001Moo`@000IJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EUYF001JEP0`Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP03FUH0
1000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0057oo100000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00IGoo00@005YFFUH000EJEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;goo001U
Ool01@00FUIJEP00FUH010000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000_Ool006Eoo`D000IJEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH005YF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool006Aoo`800003FUH005YF00QJEP03001JEUYF00IJEPH000=JEP03001JEUYF00H0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<0
00UJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
008002moo`00HGoo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF
00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Aoo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002moo`00GWoo0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0025YF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000_Ool005Yo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001JEUYF
009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Qoo`8000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001GOol20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20007FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001EOol2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00
FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF2`0000=JEP000000;Goo001BOol00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP02FUH4000]Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH@0002FUH01000FUIJEP002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUHE00000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00;Woo001BOol200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YFFUH00eYF00<007ooOol0;Goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00=JEP8000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF0080031oo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP05
FUH00`00FUH000020006FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000bOol005=oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF100025YF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00=7oo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00IJEP03001JEP00008003Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF1@001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000015YF0`001eYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF0`00>Goo
001DOol00`00FUH00004FUH20003FUH2000<FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P0000=JEP00000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP8003aoo`00E7oo00<005YF00001EYF00@005YF000000iJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP00008003ioo`00E7oo00@005YFFUH000=JEP<00003FUH005YF00eJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00EJEP@0045oo`00E7oo00D005YFFUH005YF008000AJEP03001JEUYF00aJEP03001JEUYF00MJ
EP03001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool004ioo`L0009JEP<000EJEP03001JEUYF00eJEP<000AJEPH000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPL004Uoo`00Agoo1`0015YF00D005YFFUIJ
EP0000=JEP03001JEUYF00=JEP03001JEUYF00]JEPT00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP04001JEUYFFUH8001@Ool004=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEUYF00]JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000`005Ioo`00
?goo10001UYF00<005YFFUH01eYF00D005YF000005YF00l000=JEPT000EJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00AJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00?Goo0P0000=JEP00FUH025YF00<005YFFUH0
1UYF1@0000=JEP00FUH015YF00<005YFFUH00UYF1P0015YF10001UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF
00<005YF00003`00Cgoo000jOol30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH>0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH60019Ool003Moo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030015
Ool003=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@0045oo`00
<Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
03eoo`00<7oo0P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Woo000^Ool200000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH500000eYF
001JEP03FUH00`00FUIJEP020005Ool70006FUH00`00FUIJEP05FUH3000hOol002eoo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00800003
FUH0000000IJEP03001JEUYF00=JEP04001JEUYF0009Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP02000fOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EP00FUH200000eYF001JEP02FUH;00000eYF00000007Ool50003OolD000aOol002]oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003
FUH00000008000EJEP03001JEUYF009JEP@000Moo`T000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP00000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUHA0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P0000AJ
EP00FUH000IJEP03001JEUYF00=JEP03001JEP0000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH000000UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF0P000Woo1000
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00:goo0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF
1`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYF0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH70002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF10001UYF1@001EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF0080009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF10002EYF0P000UYF00@005YFFUH000=JEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00001EYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF0P0015YF0P000eYF00<005YFFUH01eYF0P0000=JEP00FUH00UYF100015YF00@005YF
FUIJEP<0009JEP03001JEUYF00L000IJEP03001JEUYF00IJEP@000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]Ool002ao
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP07FUH200000eYF
001JEP0200000eYF001JEP06FUH400001Goo001JEUYF00001EYF00@005YFFUIJEP@0009JEP03001J
EUYF00IJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH0
0004FUH20005FUH30009FUH00`00FUIJEP06FUH200000eYF00000004FUH00`00FUIJEP03FUH30003
Ool01000FUIJEP001EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0P002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF4@0000=JEP00Ool0;7oo000]Ool0
0`00FUH00005FUH00`00FUH00003000<FUH00`00FUIJEP06FUH40005FUH00`00FUH000040005Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001JEP0000@0009J
EP800003FUH00000008002aoo`00;Goo00<005YF00001EYF0P0000=JEP00FUH03EYF00<005YFFUH0
1eYF0P0000=JEP00FUH00UYF10002Goo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003
FUH02@00FUIJEP00FUH005YF001JEP02000/Ool002eoo`04001JEUYF0002FUH20003FUH00`00FUIJ
EP0<FUH00`00FUIJEP07FUH01000FUIJEUYF100037oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00AJEP8000IJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH80003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0000/Ool002eoo`03001J
EUYF00<000EJEP03001JEUYF00aJEP03001JEUYF00IJEP8000AJEP03001oogoo00aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH005YFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF000015YF0P00;Goo000^Ool2FUH01000FUIJEP0015YF00<005YFFUH03EYF0`000UYF
0`0000=oo`00FUH00eYF0`0037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP80
0003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00D00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00008000AJEP03001oogoo02aoo`00
;Woo00=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH02eYF1P0017oo00<005YFFUH00UYF00<0
05YFFUH00P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP<000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
00AJEP03001JEUYF00=JEP@0009JEP/00003FUH005YF00IJEP04001JEUYFFUH50003FUH01000FUIJ
EP00;goo000^Ool200000eYF000000030003FUH01000FUIJEUYF0`001EYF1`001Woo00@005YFFUH0
00EJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH02000FUIJEP00FUH0
05YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUH000030004FUH00`00FUIJEP06FUHB0007FUH3000`Ool002moo`800003
FUH005YF009JEPl0009oo`D000Moo`<000IJEP03001JEP0000<000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUIJEP@000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80039oo`00<Goo30002goo
0`002Woo00<005YFFUH015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000dOol005Ioo`8000=JEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEP00001J
EP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
0`00>7oo001HOol200000eYF001JEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH50003
FUH>0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@003]oo`00FWoo0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00H005YFFUIJEP00FUH2000;FUH90008FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00mJEP03001JEUYF
00AJEPD003moo`00GGoo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040014Ool0065oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70018Ool006Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02
FUH00`00FUH00002FUHD001?Ool006Eoo`03001JEUYF00P000AJEP03001JEUYF00IJEP04001JEUYF
FUH40006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH0
0`00FUH0000=001HOol006Eoo`05001JEUYF001JEP020004FUHA000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00001EYF00<005YFFUH00eYF00@0
05YF000005Ioo`00=Goo400087oo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF001FOol0035oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL001Uoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003
FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001EOol002moo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@001Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH005YF00EJEP03001JEUYF00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0015oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000/Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000003goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF00=JEP03001J
EUYF008005Aoo`00:goo00<005YF00000UYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP04001J
EUYFFUH3000<Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YF
FUH00eYF00<005YFFUH00P00E7oo000ZOol00`00FUH00003FUH4000@Ool70006FUH00`00FUIJEP05
FUH2000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<0
05YFFUH00UYF00<005YFFUH00P00E7oo000ZOol01000FUH005YF0P006goo10000UYF00<005YFFUH0
1UYF0`002Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01UYF
00<005YFFUH00eYF00@005YF000005Aoo`00:Woo00@005YF0000025oo`@000MJEP03001JEUYF0080
00Qoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEPH000=JEP04001J
EUYF001DOol002Yoo`8002Moo`8000AJEP03001JEUYF00=JEP8000Qoo`<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EPh00003FUH0000000<00003FUH0000005=oo`00:Woo0`00:7oo0`0000=JEP00FUH01EYF0P002Goo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP/000=JEP07001JEUYF001JEP00FUH01000Dgoo000ZOol200000eYF0000
000YOol20006FUH00`00FUH0000:Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001eYF00<005YFFUH015YF00<005YF
FUH00P000eYF00<005YF0000Dgoo000ZOol00`00FUIJEP02FUH00`00Oomoo`0XOol20003FUH01@00
FUIJEUYF00002goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF1@0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP80
05Aoo`00:Woo00<005YFFUH00UYF0`00:Woo0P0000=JEP00FUH00UYF00<007ooOol037oo1`001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0200000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00P0015YF00<007ooOol0Dgoo000ZOol00`00FUIJEP02FUH00`00
FUIJEP02000ZOol20003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH@00000eYF
001JEP06FUH01000FUIJEUYF1P000UYF00@005YFFUH005Ioo`00:goo00@005YFFUH000EJEP<002Uo
o`05001JEP00FUH0000POolI0002FUH00`00FUIJEP06FUHC0007FUH3001GOol002aoo`<000IJEP03
001JEP0000<002Ioo`800003FUH007oo02Uoo`04001JEUYF0003FUH40007FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001IOol002ioo`03001JEUYF00AJEP03001JEUYF
00=JEP@002=oo`03001JEP0002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001KOol002moo`8000=JEP03001J
EUYF00EJEP03001JEUYF00@001eoo`@002]oo`03001JEUYF008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<005moo`00<Goo0P0000=JEP00FUH01UYF00<0
05YFFUH015YF1`0047oo1P000UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00@0069oo`00<goo0`001UYF00<005YFFUH01UYF00<005YF
FUH00UYF40000eYF00<005YFFUH00UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00mJEP03001J
EUYF00AJEPD006Ioo`00=Woo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8002eoo`80009JEP03001JEUYF009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00@006]oo`00>7oo0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo0P0000=JEP00FUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF1`00Kgoo000kOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00<Goo10000eYF00<005YFFUH00UYF2000MWoo000nOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000=goo2000OWoo0012
Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000_goo0019OolA0033Ool00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59883 .7188 m .58627 .66342 L .55592 .66873 L p .707 .577 .707 r
F P
0 g
s
.58627 .66342 m .59883 .7188 L .62992 .71152 L p .707 .577 .707 r
F P
0 g
s
.62992 .71152 m .61737 .65613 L .58627 .66342 L p .707 .577 .707 r
F P
0 g
s
.61737 .65613 m .62992 .71152 L .65872 .70297 L p .707 .577 .707 r
F P
0 g
s
.65872 .70297 m .64617 .64759 L .61737 .65613 L p .707 .577 .707 r
F P
0 g
s
.56847 .72412 m .55592 .66873 L .52927 .67156 L p .707 .577 .707 r
F P
0 g
s
.55592 .66873 m .56847 .72412 L .59883 .7188 L p .707 .577 .707 r
F P
0 g
s
.64617 .64759 m .65872 .70297 L .6824 .69401 L p .707 .577 .707 r
F P
0 g
s
.6824 .69401 m .66985 .63862 L .64617 .64759 L p .707 .577 .707 r
F P
0 g
s
.52927 .67156 m .54183 .72694 L .56847 .72412 L p .707 .577 .707 r
F P
0 g
s
.54183 .72694 m .52927 .67156 L .50896 .67161 L p .707 .577 .707 r
F P
0 g
s
.66985 .63862 m .6824 .69401 L .69864 .6855 L p .707 .577 .707 r
F P
0 g
s
.69864 .6855 m .68609 .63011 L .66985 .63862 L p .707 .577 .707 r
F P
0 g
s
.50896 .67161 m .52151 .72699 L .54183 .72694 L p .707 .577 .707 r
F P
0 g
s
.60205 .84573 m .59515 .80864 L .56453 .81267 L p .707 .577 .707 r
F P
0 g
s
.59515 .80864 m .60205 .84573 L .63338 .8396 L p .707 .577 .707 r
F P
0 g
s
.63338 .8396 m .62648 .80251 L .59515 .80864 L p .707 .577 .707 r
F P
0 g
s
.58503 .81894 m .58785 .80095 L .55704 .79429 L p .707 .577 .707 r
F P
0 g
s
.58785 .80095 m .58503 .81894 L .61653 .82247 L p .707 .577 .707 r
F P
0 g
s
.61653 .82247 m .61935 .80447 L .58785 .80095 L p .707 .577 .707 r
F P
0 g
s
.62648 .80251 m .63338 .8396 L .66237 .83198 L p .707 .577 .707 r
F P
0 g
s
.66237 .83198 m .65547 .79488 L .62648 .80251 L p .707 .577 .707 r
F P
0 g
s
.61935 .80447 m .61653 .82247 L .64565 .8225 L p .707 .577 .707 r
F P
0 g
s
.64565 .8225 m .64847 .80451 L .61935 .80447 L p .707 .577 .707 r
F P
0 g
s
.55422 .81228 m .55704 .79429 L .52995 .78513 L p .707 .577 .707 r
F P
0 g
s
.56453 .81267 m .57142 .84977 L .60205 .84573 L p .707 .577 .707 r
F P
0 g
s
.57142 .84977 m .56453 .81267 L .55976 .81294 L p .707 .577 .707 r
F P
0 g
s
.55704 .79429 m .55422 .81228 L .55977 .81348 L p .707 .577 .707 r
F P
0 g
s
.55929 .79627 m .55704 .79429 L .55977 .81348 L .707 .577 .707 r
F
.55976 .81294 m .53762 .81421 L p .56047 .83824 L F P
0 g
s
.57142 .84977 m .55976 .81294 L .56047 .83824 L .707 .577 .707 r
F
.55977 .81348 m .58503 .81894 L p .55929 .79627 L F P
0 g
s
.52995 .78513 m .52713 .80312 L .55422 .81228 L p .707 .577 .707 r
F P
0 g
s
.65547 .79488 m .66237 .83198 L .68617 .8236 L p .707 .577 .707 r
F P
0 g
s
.68617 .8236 m .67927 .7865 L .65547 .79488 L p .707 .577 .707 r
F P
0 g
s
.52151 .72699 m .50896 .67161 L .49695 .66889 L p .707 .577 .707 r
F P
0 g
s
.53762 .81421 m .54452 .85131 L .57142 .84977 L p .707 .577 .707 r
F P
0 g
s
.64847 .80451 m .64565 .8225 L .66953 .81904 L p .707 .577 .707 r
F P
0 g
s
.66953 .81904 m .67235 .80105 L .64847 .80451 L p .707 .577 .707 r
F P
0 g
s
.52713 .80312 m .52995 .78513 L .50923 .77437 L p .707 .577 .707 r
F P
0 g
s
.68609 .63011 m .69864 .6855 L .70585 .67827 L p .707 .577 .707 r
F P
0 g
s
.70585 .67827 m .6933 .62289 L .68609 .63011 L p .707 .577 .707 r
F P
0 g
s
.49695 .66889 m .5095 .72427 L .52151 .72699 L p .707 .577 .707 r
F P
0 g
s
.54452 .85131 m .53762 .81421 L .51706 .81311 L p .707 .577 .707 r
F P
0 g
s
.50923 .77437 m .50641 .79237 L .52713 .80312 L p .707 .577 .707 r
F P
0 g
s
.67927 .7865 m .68617 .8236 L .70245 .81529 L p .707 .577 .707 r
F P
0 g
s
.70245 .81529 m .69555 .77819 L .67927 .7865 L p .707 .577 .707 r
F P
0 g
s
.51706 .81311 m .52396 .85021 L .54452 .85131 L p .707 .577 .707 r
F P
0 g
s
.67235 .80105 m .66953 .81904 L .68584 .81243 L p .707 .577 .707 r
F P
0 g
s
.68584 .81243 m .68866 .79444 L .67235 .80105 L p .707 .577 .707 r
F P
0 g
s
.50641 .79237 m .50923 .77437 L .4969 .76308 L p .707 .577 .707 r
F P
0 g
s
.5095 .72427 m .49695 .66889 L .49443 .66367 L p .707 .577 .707 r
F P
0 g
s
.4969 .76308 m .49408 .78107 L .50641 .79237 L p .707 .577 .707 r
F P
0 g
s
.52396 .85021 m .51706 .81311 L .50487 .80947 L p .707 .577 .707 r
F P
0 g
s
.6933 .62289 m .70585 .67827 L .70333 .67305 L p .707 .577 .707 r
F P
0 g
s
.70333 .67305 m .69078 .61767 L .6933 .62289 L p .707 .577 .707 r
F P
0 g
s
.49443 .66367 m .50698 .71905 L .5095 .72427 L p .707 .577 .707 r
F P
0 g
s
.50487 .80947 m .51176 .84657 L .52396 .85021 L p .707 .577 .707 r
F P
0 g
s
.69555 .77819 m .70245 .81529 L .70962 .80787 L p .707 .577 .707 r
F P
0 g
s
.70962 .80787 m .70272 .77077 L .69555 .77819 L p .707 .577 .707 r
F P
0 g
s
.68866 .79444 m .68584 .81243 L .69298 .80331 L p .707 .577 .707 r
F P
0 g
s
.69298 .80331 m .6958 .78532 L .68866 .79444 L p .707 .577 .707 r
F P
0 g
s
.49037 .82225 m .49526 .32091 L .45125 .3178 L p .707 .577 .707 r
F P
0 g
s
.49408 .78107 m .4969 .76308 L .49417 .75234 L p .707 .577 .707 r
F P
0 g
s
.50698 .71905 m .49443 .66367 L .50164 .65644 L p .707 .577 .707 r
F P
0 g
s
.49417 .75234 m .49135 .77034 L .49408 .78107 L p .707 .577 .707 r
F P
0 g
s
.51176 .84657 m .50487 .80947 L .50222 .80366 L p .707 .577 .707 r
F P
0 g
s
.50164 .65644 m .51419 .71183 L .50698 .71905 L p .707 .577 .707 r
F P
0 g
s
.50222 .80366 m .50912 .84076 L .51176 .84657 L p .707 .577 .707 r
F P
0 g
s
.49135 .77034 m .49417 .75234 L .50131 .74323 L p .707 .577 .707 r
F P
0 g
s
.51419 .71183 m .50164 .65644 L .51788 .64793 L p .707 .577 .707 r
F P
0 g
s
.50131 .74323 m .49849 .76122 L .49135 .77034 L p .707 .577 .707 r
F P
0 g
s
.50912 .84076 m .50222 .80366 L .50939 .79623 L p .707 .577 .707 r
F P
0 g
s
.51788 .64793 m .53043 .70332 L .51419 .71183 L p .707 .577 .707 r
F P
0 g
s
.50939 .79623 m .51629 .83333 L .50912 .84076 L p .707 .577 .707 r
F P
0 g
s
.49849 .76122 m .50131 .74323 L .51763 .73661 L p .707 .577 .707 r
F P
0 g
s
.53043 .70332 m .51788 .64793 L .54156 .63897 L p .707 .577 .707 r
F P
0 g
s
.51763 .73661 m .5148 .7546 L .49849 .76122 L p .707 .577 .707 r
F P
0 g
s
.51629 .83333 m .50939 .79623 L .52568 .78793 L p .707 .577 .707 r
F P
0 g
s
.52568 .78793 m .53257 .82502 L .51629 .83333 L p .707 .577 .707 r
F P
0 g
s
.5148 .7546 m .51763 .73661 L .54151 .73315 L p .707 .577 .707 r
F P
0 g
s
.54151 .73315 m .53869 .75115 L .5148 .7546 L p .707 .577 .707 r
F P
0 g
s
.53257 .82502 m .52568 .78793 L .54947 .77955 L p .707 .577 .707 r
F P
0 g
s
.54947 .77955 m .55637 .81665 L .53257 .82502 L p .707 .577 .707 r
F P
0 g
s
.49526 .32091 m .49037 .82225 L .53531 .82155 L p .707 .577 .707 r
F P
0 g
s
.54156 .63897 m .55411 .69435 L .53043 .70332 L p .707 .577 .707 r
F P
0 g
s
.53531 .82155 m .5402 .32021 L .49526 .32091 L p .707 .577 .707 r
F P
0 g
s
.55411 .69435 m .54156 .63897 L .57035 .63042 L p .707 .577 .707 r
F P
0 g
s
.57035 .63042 m .58291 .68581 L .55411 .69435 L p .707 .577 .707 r
F P
0 g
s
.53869 .75115 m .54151 .73315 L .57063 .73319 L p .707 .577 .707 r
F P
0 g
s
.57063 .73319 m .56781 .75118 L .53869 .75115 L p .707 .577 .707 r
F P
0 g
s
.55637 .81665 m .54947 .77955 L .57846 .77192 L p .707 .577 .707 r
F P
0 g
s
.56781 .75118 m .57063 .73319 L .60213 .73671 L p .707 .577 .707 r
F P
0 g
s
.57846 .77192 m .58536 .80902 L .55637 .81665 L p .707 .577 .707 r
F P
0 g
s
.60213 .73671 m .59931 .7547 L .56781 .75118 L p .707 .577 .707 r
F P
0 g
s
.5402 .32021 m .53531 .82155 L .57679 .81709 L p .707 .577 .707 r
F P
0 g
s
.58291 .68581 m .57035 .63042 L .60145 .62314 L p .707 .577 .707 r
F P
0 g
s
.57679 .81709 m .58168 .31575 L .5402 .32021 L p .707 .577 .707 r
F P
0 g
s
.44637 .81914 m .45125 .3178 L .41249 .31116 L p .707 .577 .707 r
F P
0 g
s
.45125 .3178 m .44637 .81914 L .49037 .82225 L p .707 .577 .707 r
F P
0 g
s
.69078 .61767 m .70333 .67305 L .69132 .67033 L p .707 .577 .707 r
F P
0 g
s
.69132 .67033 m .67877 .61495 L .69078 .61767 L p .707 .577 .707 r
F P
0 g
s
.60145 .62314 m .61401 .67852 L .58291 .68581 L p .707 .577 .707 r
F P
0 g
s
.63294 .74338 m .63011 .76137 L .59931 .7547 L p .707 .577 .707 r
F P
0 g
s
.59931 .7547 m .60213 .73671 L .63294 .74338 L p .707 .577 .707 r
F P
0 g
s
.58536 .80902 m .57846 .77192 L .6098 .76579 L p .707 .577 .707 r
F P
0 g
s
.6098 .76579 m .6167 .80289 L .58536 .80902 L p .707 .577 .707 r
F P
0 g
s
.58168 .31575 m .57679 .81709 L .61075 .80931 L p .707 .577 .707 r
F P
0 g
s
.61401 .67852 m .60145 .62314 L .63181 .61782 L p .707 .577 .707 r
F P
0 g
s
.6167 .80289 m .6098 .76579 L .63499 .76247 L p .707 .577 .707 r
F P
0 g
s
.66002 .75253 m .6572 .77053 L .635 .76302 L p .707 .577 .707 r
F P
0 g
s
.63498 .75993 m .66002 .75253 L .635 .76302 L .707 .577 .707 r
F
.63499 .76247 m .64042 .76176 L p .63505 .77107 L F P
0 g
s
.6167 .80289 m .63499 .76247 L .63505 .77107 L .707 .577 .707 r
F
.635 .76302 m .63011 .76137 L p .63498 .75993 L F P
0 g
s
.61075 .80931 m .61564 .30797 L .58168 .31575 L p .707 .577 .707 r
F P
0 g
s
.70272 .77077 m .70962 .80787 L .70698 .80205 L p .707 .577 .707 r
F P
0 g
s
.70698 .80205 m .70008 .76495 L .70272 .77077 L p .707 .577 .707 r
F P
0 g
s
.6958 .78532 m .69298 .80331 L .69026 .79258 L p .707 .577 .707 r
F P
0 g
s
.69026 .79258 m .69308 .77458 L .6958 .78532 L p .707 .577 .707 r
F P
0 g
s
.4076 .8125 m .41249 .31116 L .38277 .30166 L p .707 .577 .707 r
F P
0 g
s
.41249 .31116 m .4076 .8125 L .44637 .81914 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25904 .72599 m .25214 .68889 L .22152 .69293 L p .707 .577 .707 r
F P
0 g
s
.22152 .69293 m .22842 .73002 L .25904 .72599 L p .707 .577 .707 r
F P
0 g
s
.25582 .72815 m .24326 .67277 L .21291 .67808 L p .707 .577 .707 r
F P
0 g
s
.25214 .68889 m .25904 .72599 L .29037 .71986 L p .707 .577 .707 r
F P
0 g
s
.29037 .71986 m .28348 .68276 L .25214 .68889 L p .707 .577 .707 r
F P
0 g
s
.24326 .67277 m .25582 .72815 L .28692 .72087 L p .707 .577 .707 r
F P
0 g
s
.28692 .72087 m .27436 .66548 L .24326 .67277 L p .707 .577 .707 r
F P
0 g
s
.28348 .68276 m .29037 .71986 L .31936 .71223 L p .707 .577 .707 r
F P
0 g
s
.31936 .71223 m .31246 .67514 L .28348 .68276 L p .707 .577 .707 r
F P
0 g
s
.27436 .66548 m .28692 .72087 L .31571 .71232 L p .707 .577 .707 r
F P
0 g
s
.31571 .71232 m .30316 .65694 L .27436 .66548 L p .707 .577 .707 r
F P
0 g
s
.67877 .61495 m .69132 .67033 L .671 .67038 L p .707 .577 .707 r
F P
0 g
s
.671 .67038 m .65845 .615 L .67877 .61495 L p .707 .577 .707 r
F P
0 g
s
.22546 .73347 m .21291 .67808 L .18627 .68091 L p .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .22152 .69293 L .21912 .69306 L p .707 .577 .707 r
F P
0 g
s
.21291 .67808 m .22546 .73347 L .22733 .73314 L p .707 .577 .707 r
F P
0 g
s
.21704 .6829 m .21291 .67808 L .22733 .73314 L .707 .577 .707 r
F
.18627 .68091 m .19882 .73629 L .22546 .73347 L p F P
0 g
s
.21912 .69306 m .19461 .69447 L p .22621 .72771 L .707 .577 .707 r
F P
0 g
s
.22842 .73002 m .21912 .69306 L .22621 .72771 L .707 .577 .707 r
F
.19461 .69447 m .20151 .73157 L .22842 .73002 L p F P
0 g
s
.22733 .73314 m .25582 .72815 L p .21704 .6829 L .707 .577 .707 r
F P
0 g
s
.63181 .61782 m .64436 .67321 L .61401 .67852 L p .707 .577 .707 r
F P
0 g
s
.63011 .76137 m .63294 .74338 L .66002 .75253 L p .707 .577 .707 r
F P
0 g
s
.64042 .76176 m .64732 .79886 L .6167 .80289 L p .707 .577 .707 r
F P
0 g
s
.61564 .30797 m .61075 .80931 L .63386 .79898 L p .707 .577 .707 r
F P
0 g
s
.64436 .67321 m .63181 .61782 L .65845 .615 L p .707 .577 .707 r
F P
0 g
s
.63386 .79898 m .63875 .29764 L .61564 .30797 L p .707 .577 .707 r
F P
0 g
s
.70008 .76495 m .70698 .80205 L .69478 .79842 L p .707 .577 .707 r
F P
0 g
s
.69308 .77458 m .69026 .79258 L .67793 .78128 L p .707 .577 .707 r
F P
0 g
s
.67793 .78128 m .68075 .76329 L .69308 .77458 L p .707 .577 .707 r
F P
0 g
s
.69478 .79842 m .68788 .76132 L .70008 .76495 L p .707 .577 .707 r
F P
0 g
s
.31246 .67514 m .31936 .71223 L .34316 .70386 L p .707 .577 .707 r
F P
0 g
s
.34316 .70386 m .33626 .66676 L .31246 .67514 L p .707 .577 .707 r
F P
0 g
s
.30316 .65694 m .31571 .71232 L .33939 .70336 L p .707 .577 .707 r
F P
0 g
s
.33939 .70336 m .32684 .64797 L .30316 .65694 L p .707 .577 .707 r
F P
0 g
s
.37788 .803 m .38277 .30166 L .36499 .29022 L p .707 .577 .707 r
F P
0 g
s
.38277 .30166 m .37788 .803 L .4076 .8125 L p .707 .577 .707 r
F P
0 g
s
.19882 .73629 m .18627 .68091 L .16595 .68096 L p .707 .577 .707 r
F P
0 g
s
.20151 .73157 m .19461 .69447 L .17405 .69337 L p .707 .577 .707 r
F P
0 g
s
.65845 .615 m .671 .67038 L .64436 .67321 L p .707 .577 .707 r
F P
0 g
s
.33626 .66676 m .34316 .70386 L .35944 .69555 L p .707 .577 .707 r
F P
0 g
s
.35944 .69555 m .35254 .65845 L .33626 .66676 L p .707 .577 .707 r
F P
0 g
s
.32684 .64797 m .33939 .70336 L .35563 .69485 L p .707 .577 .707 r
F P
0 g
s
.35563 .69485 m .34308 .63946 L .32684 .64797 L p .707 .577 .707 r
F P
0 g
s
.16595 .68096 m .1785 .73634 L .19882 .73629 L p .707 .577 .707 r
F P
0 g
s
.17405 .69337 m .18095 .73046 L .20151 .73157 L p .707 .577 .707 r
F P
0 g
s
.68788 .76132 m .69478 .79842 L .67422 .79732 L p .707 .577 .707 r
F P
0 g
s
.68075 .76329 m .67793 .78128 L .6572 .77053 L p .707 .577 .707 r
F P
0 g
s
.6572 .77053 m .66002 .75253 L .68075 .76329 L p .707 .577 .707 r
F P
0 g
s
.67422 .79732 m .66733 .76022 L .68788 .76132 L p .707 .577 .707 r
F P
0 g
s
.24202 .85462 m .24484 .83663 L .21403 .82996 L p .707 .577 .707 r
F P
0 g
s
.24484 .83663 m .24202 .85462 L .27352 .85814 L p .707 .577 .707 r
F P
0 g
s
.27352 .85814 m .27634 .84015 L .24484 .83663 L p .707 .577 .707 r
F P
0 g
s
.64732 .79886 m .64042 .76176 L .66733 .76022 L p .707 .577 .707 r
F P
0 g
s
.63875 .29764 m .63386 .79898 L .64386 .7871 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .64875 .28576 L .63875 .29764 L p .707 .577 .707 r
F P
0 g
s
.27634 .84015 m .27352 .85814 L .30264 .85818 L p .707 .577 .707 r
F P
0 g
s
.30264 .85818 m .30546 .84019 L .27634 .84015 L p .707 .577 .707 r
F P
0 g
s
.21121 .84795 m .21403 .82996 L .18694 .8208 L p .707 .577 .707 r
F P
0 g
s
.21403 .82996 m .21121 .84795 L .24202 .85462 L p .707 .577 .707 r
F P
0 g
s
.1785 .73634 m .16595 .68096 L .15394 .67824 L p .707 .577 .707 r
F P
0 g
s
.18095 .73046 m .17405 .69337 L .16186 .68973 L p .707 .577 .707 r
F P
0 g
s
.18694 .8208 m .18412 .8388 L .21121 .84795 L p .707 .577 .707 r
F P
0 g
s
.35254 .65845 m .35944 .69555 L .36661 .68812 L p .707 .577 .707 r
F P
0 g
s
.34308 .63946 m .35563 .69485 L .36284 .68762 L p .707 .577 .707 r
F P
0 g
s
.36661 .68812 m .35971 .65103 L .35254 .65845 L p .707 .577 .707 r
F P
0 g
s
.36284 .68762 m .35029 .63224 L .34308 .63946 L p .707 .577 .707 r
F P
0 g
s
.15394 .67824 m .16649 .73362 L .1785 .73634 L p .707 .577 .707 r
F P
0 g
s
.16186 .68973 m .16875 .72683 L .18095 .73046 L p .707 .577 .707 r
F P
0 g
s
.30546 .84019 m .30264 .85818 L .32652 .85472 L p .707 .577 .707 r
F P
0 g
s
.32652 .85472 m .32934 .83673 L .30546 .84019 L p .707 .577 .707 r
F P
0 g
s
.35029 .63224 m .36284 .68762 L .36032 .6824 L p .707 .577 .707 r
F P
0 g
s
.36032 .6824 m .34777 .62702 L .35029 .63224 L p .707 .577 .707 r
F P
0 g
s
.35971 .65103 m .36661 .68812 L .36397 .68231 L p .707 .577 .707 r
F P
0 g
s
.36397 .68231 m .35707 .64521 L .35971 .65103 L p .707 .577 .707 r
F P
0 g
s
.34777 .62702 m .36032 .6824 L .34831 .67968 L p .707 .577 .707 r
F P
0 g
s
.35707 .64521 m .36397 .68231 L .35177 .67867 L p .707 .577 .707 r
F P
0 g
s
.3601 .79156 m .36499 .29022 L .3609 .27796 L p .707 .577 .707 r
F P
0 g
s
.36499 .29022 m .3601 .79156 L .37788 .803 L p .707 .577 .707 r
F P
0 g
s
.18412 .8388 m .18694 .8208 L .16622 .81005 L p .707 .577 .707 r
F P
0 g
s
.66733 .76022 m .67422 .79732 L .64732 .79886 L p .707 .577 .707 r
F P
0 g
s
.16622 .81005 m .1634 .82804 L .18412 .8388 L p .707 .577 .707 r
F P
0 g
s
.16875 .72683 m .16186 .68973 L .15921 .68392 L p .707 .577 .707 r
F P
0 g
s
.16649 .73362 m .15394 .67824 L .15142 .67302 L p .707 .577 .707 r
F P
0 g
s
.32934 .83673 m .32652 .85472 L .34283 .84811 L p .707 .577 .707 r
F P
0 g
s
.34283 .84811 m .34565 .83011 L .32934 .83673 L p .707 .577 .707 r
F P
0 g
s
.1634 .82804 m .16622 .81005 L .15389 .79875 L p .707 .577 .707 r
F P
0 g
s
.15921 .68392 m .16611 .72101 L .16875 .72683 L p .707 .577 .707 r
F P
0 g
s
.64386 .7871 m .63977 .77484 L p .6429 .6043 L .707 .577 .707 r
F P
0 g
s
.6429 .6043 m .64512 .4833 L .6446 .60836 L .707 .577 .707 r
F
.6429 .6043 m .6446 .60836 L .64386 .7871 L F
.64466 .2735 m .63977 .77484 L .62199 .7634 L p F P
0 g
s
.63415 .57685 m .63163 .57163 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.64709 .45587 m .64386 .7871 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64466 .2735 m .64875 .28576 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.63977 .77484 m .64222 .52379 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.64222 .52379 m .64466 .2735 L p .64512 .4833 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .65871 .63495 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63415 .57685 m .63739 .59114 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .6467 .63224 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.6467 .63224 m .63739 .59114 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.63739 .59114 m .63415 .57685 L p .63516 .58581 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .64616 .57957 L .63835 .5778 L p .707 .577 .707 r
F P
0 g
s
.63835 .5778 m .63415 .57685 L p .6378 .58547 L .707 .577 .707 r
F P
0 g
s
.65871 .63495 m .63835 .5778 L .6378 .58547 L .707 .577 .707 r
F
.64875 .28576 m .64709 .45587 L p .64512 .4833 L F P
0 g
s
.15142 .67302 m .16397 .7284 L .16649 .73362 L p .707 .577 .707 r
F P
0 g
s
.15389 .79875 m .15107 .81675 L .1634 .82804 L p .707 .577 .707 r
F P
0 g
s
.3609 .27796 m .35602 .7793 L .3601 .79156 L p .707 .577 .707 r
F P
0 g
s
.35602 .7793 m .3609 .27796 L .3709 .26608 L p .707 .577 .707 r
F P
0 g
s
.34565 .83011 m .34283 .84811 L .34997 .83899 L p .707 .577 .707 r
F P
0 g
s
.34997 .83899 m .3528 .82099 L .34565 .83011 L p .707 .577 .707 r
F P
0 g
s
.16611 .72101 m .15921 .68392 L .16638 .67649 L p .707 .577 .707 r
F P
0 g
s
.16397 .7284 m .15142 .67302 L .15863 .66579 L p .707 .577 .707 r
F P
0 g
s
.15107 .81675 m .15389 .79875 L .15116 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16638 .67649 m .17328 .71359 L .16611 .72101 L p .707 .577 .707 r
F P
0 g
s
.34831 .67968 m .33576 .6243 L .34777 .62702 L p .707 .577 .707 r
F P
0 g
s
.15116 .78802 m .14834 .80601 L .15107 .81675 L p .707 .577 .707 r
F P
0 g
s
.35177 .67867 m .34487 .64158 L .35707 .64521 L p .707 .577 .707 r
F P
0 g
s
.15863 .66579 m .17118 .72118 L .16397 .7284 L p .707 .577 .707 r
F P
0 g
s
.62199 .7634 m .62688 .26206 L .64466 .2735 L p .707 .577 .707 r
F P
0 g
s
.3528 .82099 m .34997 .83899 L .34725 .82825 L p .707 .577 .707 r
F P
0 g
s
.34725 .82825 m .35007 .81026 L .3528 .82099 L p .707 .577 .707 r
F P
0 g
s
.17328 .71359 m .16638 .67649 L .18267 .66818 L p .707 .577 .707 r
F P
0 g
s
.17118 .72118 m .15863 .66579 L .17487 .65728 L p .707 .577 .707 r
F P
0 g
s
.14834 .80601 m .15116 .78802 L .15831 .7789 L p .707 .577 .707 r
F P
0 g
s
.36602 .76742 m .3709 .26608 L .39401 .25575 L p .707 .577 .707 r
F P
0 g
s
.3709 .26608 m .36602 .76742 L .35602 .7793 L p .707 .577 .707 r
F P
0 g
s
.18267 .66818 m .18956 .70528 L .17328 .71359 L p .707 .577 .707 r
F P
0 g
s
.33576 .6243 m .34831 .67968 L .32799 .67973 L p .707 .577 .707 r
F P
0 g
s
.32799 .67973 m .31544 .62435 L .33576 .6243 L p .707 .577 .707 r
F P
0 g
s
.15831 .7789 m .15548 .79689 L .14834 .80601 L p .707 .577 .707 r
F P
0 g
s
.34487 .64158 m .35177 .67867 L .33121 .67757 L p .707 .577 .707 r
F P
0 g
s
.33121 .67757 m .32432 .64047 L .34487 .64158 L p .707 .577 .707 r
F P
0 g
s
.17487 .65728 m .18742 .71267 L .17118 .72118 L p .707 .577 .707 r
F P
0 g
s
.18956 .70528 m .18267 .66818 L .20646 .65981 L p .707 .577 .707 r
F P
0 g
s
.18742 .71267 m .17487 .65728 L .19855 .64832 L p .707 .577 .707 r
F P
0 g
s
.35007 .81026 m .34725 .82825 L .33492 .81696 L p .707 .577 .707 r
F P
0 g
s
.33492 .81696 m .33774 .79896 L .35007 .81026 L p .707 .577 .707 r
F P
0 g
s
.62688 .26206 m .62199 .7634 L .59227 .7539 L p .707 .577 .707 r
F P
0 g
s
.59227 .7539 m .59716 .25256 L .62688 .26206 L p .707 .577 .707 r
F P
0 g
s
.15548 .79689 m .15831 .7789 L .17462 .77229 L p .707 .577 .707 r
F P
0 g
s
.31544 .62435 m .32799 .67973 L .30299 .68238 L p .707 .577 .707 r
F P
0 g
s
.30225 .67884 m .31544 .62435 L .30299 .68238 L .707 .577 .707 r
F
.30236 .67937 m .27369 .68315 L p .29535 .64559 L F P
0 g
s
.27369 .68315 m .26679 .64605 L .29468 .64238 L p .707 .577 .707 r
F P
0 g
s
.27369 .68315 m .29468 .64238 L .29535 .64559 L .707 .577 .707 r
F
.30135 .68256 m .2888 .62717 L .29146 .62689 L p F P
0 g
s
.29146 .62689 m .31544 .62435 L p .30225 .67884 L .707 .577 .707 r
F P
0 g
s
.30135 .68256 m .29146 .62689 L .30225 .67884 L .707 .577 .707 r
F
.29468 .64238 m .29741 .64202 L p .29535 .64559 L F P
0 g
s
.29741 .64202 m .30431 .67911 L .30236 .67937 L p .707 .577 .707 r
F P
0 g
s
.29535 .64559 m .29741 .64202 L .30236 .67937 L .707 .577 .707 r
F
.30299 .68238 m .30135 .68256 L p .30225 .67884 L F P
0 g
s
.32432 .64047 m .33121 .67757 L .30431 .67911 L p .707 .577 .707 r
F P
0 g
s
.30431 .67911 m .29741 .64202 L .32432 .64047 L p .707 .577 .707 r
F P
0 g
s
.20646 .65981 m .21336 .6969 L .18956 .70528 L p .707 .577 .707 r
F P
0 g
s
.19855 .64832 m .2111 .7037 L .18742 .71267 L p .707 .577 .707 r
F P
0 g
s
.17462 .77229 m .17179 .79028 L .15548 .79689 L p .707 .577 .707 r
F P
0 g
s
.73603 .62676 m .72348 .57138 L .69312 .5767 L p .707 .577 .707 r
F P
0 g
s
.72348 .57138 m .73603 .62676 L .76713 .61948 L p .707 .577 .707 r
F P
0 g
s
.76713 .61948 m .75458 .5641 L .72348 .57138 L p .707 .577 .707 r
F P
0 g
s
.39401 .25575 m .38912 .75709 L .36602 .76742 L p .707 .577 .707 r
F P
0 g
s
.38912 .75709 m .39401 .25575 L .42797 .24797 L p .707 .577 .707 r
F P
0 g
s
.75458 .5641 m .76713 .61948 L .79593 .61093 L p .707 .577 .707 r
F P
0 g
s
.79593 .61093 m .78337 .55555 L .75458 .5641 L p .707 .577 .707 r
F P
0 g
s
.21336 .6969 m .20646 .65981 L .23545 .65218 L p .707 .577 .707 r
F P
0 g
s
.2111 .7037 m .19855 .64832 L .22734 .63977 L p .707 .577 .707 r
F P
0 g
s
.26679 .64605 m .27369 .68315 L .24235 .68928 L p .707 .577 .707 r
F P
0 g
s
.2888 .62717 m .30135 .68256 L .271 .68787 L p .707 .577 .707 r
F P
0 g
s
.24235 .68928 m .23545 .65218 L .26679 .64605 L p .707 .577 .707 r
F P
0 g
s
.271 .68787 m .25844 .63249 L .2888 .62717 L p .707 .577 .707 r
F P
0 g
s
.70567 .63208 m .69312 .5767 L .66648 .57952 L p .707 .577 .707 r
F P
0 g
s
.69312 .5767 m .70567 .63208 L .73603 .62676 L p .707 .577 .707 r
F P
0 g
s
.23545 .65218 m .24235 .68928 L .21336 .6969 L p .707 .577 .707 r
F P
0 g
s
.33774 .79896 m .33492 .81696 L .31419 .8062 L p .707 .577 .707 r
F P
0 g
s
.31419 .8062 m .31702 .78821 L .33774 .79896 L p .707 .577 .707 r
F P
0 g
s
.78337 .55555 m .79593 .61093 L .8196 .60197 L p .707 .577 .707 r
F P
0 g
s
.8196 .60197 m .80705 .54659 L .78337 .55555 L p .707 .577 .707 r
F P
0 g
s
.22734 .63977 m .2399 .69516 L .2111 .7037 L p .707 .577 .707 r
F P
0 g
s
.2399 .69516 m .22734 .63977 L .25844 .63249 L p .707 .577 .707 r
F P
0 g
s
.25844 .63249 m .271 .68787 L .2399 .69516 L p .707 .577 .707 r
F P
0 g
s
.17179 .79028 m .17462 .77229 L .1985 .76883 L p .707 .577 .707 r
F P
0 g
s
.66648 .57952 m .67903 .6349 L .70567 .63208 L p .707 .577 .707 r
F P
0 g
s
.59716 .25256 m .59227 .7539 L .55351 .74726 L p .707 .577 .707 r
F P
0 g
s
.55351 .74726 m .5584 .24592 L .59716 .25256 L p .707 .577 .707 r
F P
0 g
s
.1985 .76883 m .19568 .78682 L .17179 .79028 L p .707 .577 .707 r
F P
0 g
s
.67903 .6349 m .66648 .57952 L .64616 .57957 L p .707 .577 .707 r
F P
0 g
s
.42308 .74931 m .42797 .24797 L .46945 .24351 L p .707 .577 .707 r
F P
0 g
s
.42797 .24797 m .42308 .74931 L .38912 .75709 L p .707 .577 .707 r
F P
0 g
s
.80705 .54659 m .8196 .60197 L .83584 .59346 L p .707 .577 .707 r
F P
0 g
s
.83584 .59346 m .82329 .53807 L .80705 .54659 L p .707 .577 .707 r
F P
0 g
s
.31702 .78821 m .31419 .8062 L .2871 .79705 L p .707 .577 .707 r
F P
0 g
s
.2871 .79705 m .28993 .77905 L .31702 .78821 L p .707 .577 .707 r
F P
0 g
s
.19568 .78682 m .1985 .76883 L .22762 .76886 L p .707 .577 .707 r
F P
0 g
s
.64616 .57957 m .65871 .63495 L .67903 .6349 L p .707 .577 .707 r
F P
0 g
s
.73925 .7537 m .73235 .7166 L .70173 .72063 L p .707 .577 .707 r
F P
0 g
s
.73235 .7166 m .73925 .7537 L .77059 .74756 L p .707 .577 .707 r
F P
0 g
s
.77059 .74756 m .76369 .71047 L .73235 .7166 L p .707 .577 .707 r
F P
0 g
s
.72223 .72691 m .72505 .70891 L .69425 .70225 L p .707 .577 .707 r
F P
0 g
s
.72505 .70891 m .72223 .72691 L .75373 .73043 L p .707 .577 .707 r
F P
0 g
s
.75373 .73043 m .75655 .71244 L .72505 .70891 L p .707 .577 .707 r
F P
0 g
s
.76369 .71047 m .77059 .74756 L .79957 .73994 L p .707 .577 .707 r
F P
0 g
s
.79957 .73994 m .79268 .70284 L .76369 .71047 L p .707 .577 .707 r
F P
0 g
s
.5584 .24592 m .55351 .74726 L .5095 .74415 L p .707 .577 .707 r
F P
0 g
s
.5095 .74415 m .51439 .24281 L .5584 .24592 L p .707 .577 .707 r
F P
0 g
s
.75655 .71244 m .75373 .73043 L .78285 .73046 L p .707 .577 .707 r
F P
0 g
s
.78285 .73046 m .78567 .71247 L .75655 .71244 L p .707 .577 .707 r
F P
0 g
s
.22762 .76886 m .2248 .78686 L .19568 .78682 L p .707 .577 .707 r
F P
0 g
s
.69143 .72024 m .69425 .70225 L .66716 .69309 L p .707 .577 .707 r
F P
0 g
s
.70173 .72063 m .70863 .75773 L .73925 .7537 L p .707 .577 .707 r
F P
0 g
s
.70863 .75773 m .70173 .72063 L .69696 .7209 L p .707 .577 .707 r
F P
0 g
s
.69425 .70225 m .69143 .72024 L .69698 .72144 L p .707 .577 .707 r
F P
0 g
s
.6965 .70423 m .69425 .70225 L .69698 .72144 L .707 .577 .707 r
F
.69696 .7209 m .67482 .72217 L p .69767 .74621 L F P
0 g
s
.70863 .75773 m .69696 .7209 L .69767 .74621 L .707 .577 .707 r
F
.69698 .72144 m .72223 .72691 L p .6965 .70423 L F P
0 g
s
.46456 .74485 m .46945 .24351 L .51439 .24281 L p .707 .577 .707 r
F P
0 g
s
.46945 .24351 m .46456 .74485 L .42308 .74931 L p .707 .577 .707 r
F P
0 g
s
.28993 .77905 m .2871 .79705 L .2563 .79038 L p .707 .577 .707 r
F P
0 g
s
.2563 .79038 m .25912 .77239 L .28993 .77905 L p .707 .577 .707 r
F P
0 g
s
.2248 .78686 m .22762 .76886 L .25912 .77239 L p .707 .577 .707 r
F P
0 g
s
.66716 .69309 m .66434 .71108 L .69143 .72024 L p .707 .577 .707 r
F P
0 g
s
.79268 .70284 m .79957 .73994 L .82337 .73156 L p .707 .577 .707 r
F P
0 g
s
.82337 .73156 m .81648 .69446 L .79268 .70284 L p .707 .577 .707 r
F P
0 g
s
.51439 .24281 m .5095 .74415 L .46456 .74485 L p .707 .577 .707 r
F P
0 g
s
.67482 .72217 m .68172 .75927 L .70863 .75773 L p .707 .577 .707 r
F P
0 g
s
.25912 .77239 m .2563 .79038 L .2248 .78686 L p .707 .577 .707 r
F P
0 g
s
.78567 .71247 m .78285 .73046 L .80674 .727 L p .707 .577 .707 r
F P
0 g
s
.80674 .727 m .80956 .70901 L .78567 .71247 L p .707 .577 .707 r
F P
0 g
s
.66434 .71108 m .66716 .69309 L .64643 .68234 L p .707 .577 .707 r
F P
0 g
s
.82329 .53807 m .83584 .59346 L .84306 .58624 L p .707 .577 .707 r
F P
0 g
s
.84306 .58624 m .8305 .53085 L .82329 .53807 L p .707 .577 .707 r
F P
0 g
s
.68172 .75927 m .67482 .72217 L .65427 .72107 L p .707 .577 .707 r
F P
0 g
s
.64643 .68234 m .64361 .70033 L .66434 .71108 L p .707 .577 .707 r
F P
0 g
s
.81648 .69446 m .82337 .73156 L .83966 .72325 L p .707 .577 .707 r
F P
0 g
s
.83966 .72325 m .83276 .68616 L .81648 .69446 L p .707 .577 .707 r
F P
0 g
s
.65427 .72107 m .66117 .75817 L .68172 .75927 L p .707 .577 .707 r
F P
0 g
s
.80956 .70901 m .80674 .727 L .82305 .72039 L p .707 .577 .707 r
F P
0 g
s
.82305 .72039 m .82587 .7024 L .80956 .70901 L p .707 .577 .707 r
F P
0 g
s
.64361 .70033 m .64643 .68234 L .6341 .67104 L p .707 .577 .707 r
F P
0 g
s
.6341 .67104 m .63128 .68903 L .64361 .70033 L p .707 .577 .707 r
F P
0 g
s
.66117 .75817 m .65427 .72107 L .64207 .71744 L p .707 .577 .707 r
F P
0 g
s
.8305 .53085 m .84306 .58624 L .84054 .58101 L p .707 .577 .707 r
F P
0 g
s
.84054 .58101 m .82798 .52563 L .8305 .53085 L p .707 .577 .707 r
F P
0 g
s
.63163 .57163 m .64418 .62701 L .6467 .63224 L p .707 .577 .707 r
F P
0 g
s
.64207 .71744 m .64897 .75453 L .66117 .75817 L p .707 .577 .707 r
F P
0 g
s
.83276 .68616 m .83966 .72325 L .84683 .71583 L p .707 .577 .707 r
F P
0 g
s
.84683 .71583 m .83993 .67873 L .83276 .68616 L p .707 .577 .707 r
F P
0 g
s
.82587 .7024 m .82305 .72039 L .83019 .71127 L p .707 .577 .707 r
F P
0 g
s
.83019 .71127 m .83301 .69328 L .82587 .7024 L p .707 .577 .707 r
F P
0 g
s
.63128 .68903 m .6341 .67104 L .63138 .66031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64418 .62701 m .63163 .57163 L .63884 .56441 L p .707 .577 .707 r
F P
0 g
s
.63138 .66031 m .62856 .6783 L .63128 .68903 L p .707 .577 .707 r
F P
0 g
s
.64897 .75453 m .64207 .71744 L .63943 .71162 L p .707 .577 .707 r
F P
0 g
s
.82798 .52563 m .84054 .58101 L .82853 .57829 L p .707 .577 .707 r
F P
0 g
s
.82853 .57829 m .81597 .52291 L .82798 .52563 L p .707 .577 .707 r
F P
0 g
s
.63884 .56441 m .6514 .61979 L .64418 .62701 L p .707 .577 .707 r
F P
0 g
s
.63943 .71162 m .64633 .74872 L .64897 .75453 L p .707 .577 .707 r
F P
0 g
s
.83993 .67873 m .84683 .71583 L .84418 .71001 L p .707 .577 .707 r
F P
0 g
s
.84418 .71001 m .83729 .67292 L .83993 .67873 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83301 .69328 m .83019 .71127 L .82746 .70054 L p .707 .577 .707 r
F P
0 g
s
.82746 .70054 m .83028 .68255 L .83301 .69328 L p .707 .577 .707 r
F P
0 g
s
.62856 .6783 m .63138 .66031 L .63852 .65119 L p .707 .577 .707 r
F P
0 g
s
.6514 .61979 m .63884 .56441 L .65508 .5559 L p .707 .577 .707 r
F P
0 g
s
.63852 .65119 m .6357 .66918 L .62856 .6783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39624 .63395 m .38934 .59685 L .35872 .60089 L p .707 .577 .707 r
F P
0 g
s
.35872 .60089 m .36562 .63799 L .39624 .63395 L p .707 .577 .707 r
F P
0 g
s
.39302 .63611 m .38047 .58073 L .35011 .58605 L p .707 .577 .707 r
F P
0 g
s
.38934 .59685 m .39624 .63395 L .42758 .62782 L p .707 .577 .707 r
F P
0 g
s
.42758 .62782 m .42068 .59072 L .38934 .59685 L p .707 .577 .707 r
F P
0 g
s
.38047 .58073 m .39302 .63611 L .42412 .62883 L p .707 .577 .707 r
F P
0 g
s
.42412 .62883 m .41157 .57345 L .38047 .58073 L p .707 .577 .707 r
F P
0 g
s
.42068 .59072 m .42758 .62782 L .45656 .62019 L p .707 .577 .707 r
F P
0 g
s
.45656 .62019 m .44967 .5831 L .42068 .59072 L p .707 .577 .707 r
F P
0 g
s
.41157 .57345 m .42412 .62883 L .45292 .62028 L p .707 .577 .707 r
F P
0 g
s
.45292 .62028 m .44036 .5649 L .41157 .57345 L p .707 .577 .707 r
F P
0 g
s
.64633 .74872 m .63943 .71162 L .6466 .7042 L p .707 .577 .707 r
F P
0 g
s
.81597 .52291 m .82853 .57829 L .80821 .57834 L p .707 .577 .707 r
F P
0 g
s
.80821 .57834 m .79566 .52296 L .81597 .52291 L p .707 .577 .707 r
F P
0 g
s
.65508 .5559 m .66764 .61128 L .6514 .61979 L p .707 .577 .707 r
F P
0 g
s
.36266 .64143 m .35011 .58605 L .32347 .58887 L p .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35872 .60089 L .35632 .60103 L p .707 .577 .707 r
F P
0 g
s
.35011 .58605 m .36266 .64143 L .36453 .6411 L p .707 .577 .707 r
F P
0 g
s
.35424 .59086 m .35011 .58605 L .36453 .6411 L .707 .577 .707 r
F
.32347 .58887 m .33602 .64425 L .36266 .64143 L p F P
0 g
s
.35632 .60103 m .33181 .60243 L p .36342 .63567 L .707 .577 .707 r
F P
0 g
s
.36562 .63799 m .35632 .60103 L .36342 .63567 L .707 .577 .707 r
F
.33181 .60243 m .33871 .63953 L .36562 .63799 L p F P
0 g
s
.36453 .6411 m .39302 .63611 L p .35424 .59086 L .707 .577 .707 r
F P
0 g
s
.6466 .7042 m .6535 .74129 L .64633 .74872 L p .707 .577 .707 r
F P
0 g
s
.83729 .67292 m .84418 .71001 L .83199 .70638 L p .707 .577 .707 r
F P
0 g
s
.83028 .68255 m .82746 .70054 L .81513 .68924 L p .707 .577 .707 r
F P
0 g
s
.81513 .68924 m .81795 .67125 L .83028 .68255 L p .707 .577 .707 r
F P
0 g
s
.83199 .70638 m .82509 .66928 L .83729 .67292 L p .707 .577 .707 r
F P
0 g
s
.44967 .5831 m .45656 .62019 L .48036 .61182 L p .707 .577 .707 r
F P
0 g
s
.48036 .61182 m .47347 .57472 L .44967 .5831 L p .707 .577 .707 r
F P
0 g
s
.44036 .5649 m .45292 .62028 L .4766 .61132 L p .707 .577 .707 r
F P
0 g
s
.4766 .61132 m .46404 .55594 L .44036 .5649 L p .707 .577 .707 r
F P
0 g
s
.6357 .66918 m .63852 .65119 L .65483 .64457 L p .707 .577 .707 r
F P
0 g
s
.66764 .61128 m .65508 .5559 L .67876 .54693 L p .707 .577 .707 r
F P
0 g
s
.33602 .64425 m .32347 .58887 L .30315 .58892 L p .707 .577 .707 r
F P
0 g
s
.33871 .63953 m .33181 .60243 L .31126 .60133 L p .707 .577 .707 r
F P
0 g
s
.65483 .64457 m .65201 .66257 L .6357 .66918 L p .707 .577 .707 r
F P
0 g
s
.79566 .52296 m .80821 .57834 L .78157 .58117 L p .707 .577 .707 r
F P
0 g
s
.78157 .58117 m .76901 .52579 L .79566 .52296 L p .707 .577 .707 r
F P
0 g
s
.47347 .57472 m .48036 .61182 L .49665 .60351 L p .707 .577 .707 r
F P
0 g
s
.49665 .60351 m .48975 .56641 L .47347 .57472 L p .707 .577 .707 r
F P
0 g
s
.46404 .55594 m .4766 .61132 L .49284 .60281 L p .707 .577 .707 r
F P
0 g
s
.49284 .60281 m .48028 .54742 L .46404 .55594 L p .707 .577 .707 r
F P
0 g
s
.6535 .74129 m .6466 .7042 L .66288 .69589 L p .707 .577 .707 r
F P
0 g
s
.67876 .54693 m .69131 .60231 L .66764 .61128 L p .707 .577 .707 r
F P
0 g
s
.30315 .58892 m .3157 .6443 L .33602 .64425 L p .707 .577 .707 r
F P
0 g
s
.31126 .60133 m .31816 .63843 L .33871 .63953 L p .707 .577 .707 r
F P
0 g
s
.66288 .69589 m .66978 .73299 L .6535 .74129 L p .707 .577 .707 r
F P
0 g
s
.82509 .66928 m .83199 .70638 L .81143 .70528 L p .707 .577 .707 r
F P
0 g
s
.81795 .67125 m .81513 .68924 L .79441 .67849 L p .707 .577 .707 r
F P
0 g
s
.79441 .67849 m .79723 .6605 L .81795 .67125 L p .707 .577 .707 r
F P
0 g
s
.81143 .70528 m .80453 .66818 L .82509 .66928 L p .707 .577 .707 r
F P
0 g
s
.69131 .60231 m .67876 .54693 L .70756 .53839 L p .707 .577 .707 r
F P
0 g
s
.37922 .76258 m .38204 .74459 L .35124 .73792 L p .707 .577 .707 r
F P
0 g
s
.38204 .74459 m .37922 .76258 L .41072 .76611 L p .707 .577 .707 r
F P
0 g
s
.41072 .76611 m .41354 .74811 L .38204 .74459 L p .707 .577 .707 r
F P
0 g
s
.76901 .52579 m .78157 .58117 L .75121 .58648 L p .707 .577 .707 r
F P
0 g
s
.75121 .58648 m .73866 .5311 L .76901 .52579 L p .707 .577 .707 r
F P
0 g
s
.65201 .66257 m .65483 .64457 L .67871 .64112 L p .707 .577 .707 r
F P
0 g
s
.41354 .74811 m .41072 .76611 L .43984 .76614 L p .707 .577 .707 r
F P
0 g
s
.43984 .76614 m .44266 .74815 L .41354 .74811 L p .707 .577 .707 r
F P
0 g
s
.34842 .75592 m .35124 .73792 L .32415 .72877 L p .707 .577 .707 r
F P
0 g
s
.35124 .73792 m .34842 .75592 L .37922 .76258 L p .707 .577 .707 r
F P
0 g
s
.3157 .6443 m .30315 .58892 L .29114 .5862 L p .707 .577 .707 r
F P
0 g
s
.31816 .63843 m .31126 .60133 L .29906 .59769 L p .707 .577 .707 r
F P
0 g
s
.70756 .53839 m .72011 .59377 L .69131 .60231 L p .707 .577 .707 r
F P
0 g
s
.72011 .59377 m .70756 .53839 L .73866 .5311 L p .707 .577 .707 r
F P
0 g
s
.67871 .64112 m .67589 .65911 L .65201 .66257 L p .707 .577 .707 r
F P
0 g
s
.73866 .5311 m .75121 .58648 L .72011 .59377 L p .707 .577 .707 r
F P
0 g
s
.32415 .72877 m .32133 .74676 L .34842 .75592 L p .707 .577 .707 r
F P
0 g
s
.48975 .56641 m .49665 .60351 L .50382 .59609 L p .707 .577 .707 r
F P
0 g
s
.48028 .54742 m .49284 .60281 L .50005 .59559 L p .707 .577 .707 r
F P
0 g
s
.50382 .59609 m .49692 .55899 L .48975 .56641 L p .707 .577 .707 r
F P
0 g
s
.50005 .59559 m .48749 .5402 L .48028 .54742 L p .707 .577 .707 r
F P
0 g
s
.29114 .5862 m .30369 .64159 L .3157 .6443 L p .707 .577 .707 r
F P
0 g
s
.29906 .59769 m .30596 .63479 L .31816 .63843 L p .707 .577 .707 r
F P
0 g
s
.66978 .73299 m .66288 .69589 L .68668 .68751 L p .707 .577 .707 r
F P
0 g
s
.44266 .74815 m .43984 .76614 L .46373 .76268 L p .707 .577 .707 r
F P
0 g
s
.46373 .76268 m .46655 .74469 L .44266 .74815 L p .707 .577 .707 r
F P
0 g
s
.32133 .74676 m .32415 .72877 L .30342 .71801 L p .707 .577 .707 r
F P
0 g
s
.80453 .66818 m .81143 .70528 L .78452 .70682 L p .707 .577 .707 r
F P
0 g
s
.79723 .6605 m .79441 .67849 L .7722 .67098 L p .707 .577 .707 r
F P
0 g
s
.77218 .66789 m .79723 .6605 L .7722 .67098 L .707 .577 .707 r
F
.7539 .71085 m .747 .67375 L .77762 .66972 L p F P
0 g
s
.7722 .67098 m .76732 .66933 L p .77218 .66789 L .707 .577 .707 r
F P
0 g
s
.77762 .66972 m .78452 .70682 L .77244 .70841 L p .707 .577 .707 r
F P
0 g
s
.77244 .70841 m .7539 .71085 L p .77225 .67903 L .707 .577 .707 r
F P
0 g
s
.77225 .67903 m .77762 .66972 L .77244 .70841 L .707 .577 .707 r
F
.78452 .70682 m .77762 .66972 L .80453 .66818 L p F P
0 g
s
.68668 .68751 m .69358 .72461 L .66978 .73299 L p .707 .577 .707 r
F P
0 g
s
.76732 .66933 m .77014 .65134 L .79723 .6605 L p .707 .577 .707 r
F P
0 g
s
.67589 .65911 m .67871 .64112 L .70783 .64115 L p .707 .577 .707 r
F P
0 g
s
.30342 .71801 m .3006 .736 L .32133 .74676 L p .707 .577 .707 r
F P
0 g
s
.70783 .64115 m .70501 .65914 L .67589 .65911 L p .707 .577 .707 r
F P
0 g
s
.69358 .72461 m .68668 .68751 L .71567 .67988 L p .707 .577 .707 r
F P
0 g
s
.30596 .63479 m .29906 .59769 L .29642 .59188 L p .707 .577 .707 r
F P
0 g
s
.30369 .64159 m .29114 .5862 L .28862 .58098 L p .707 .577 .707 r
F P
0 g
s
.77014 .65134 m .76732 .66933 L .73651 .66266 L p .707 .577 .707 r
F P
0 g
s
.73651 .66266 m .73934 .64467 L .77014 .65134 L p .707 .577 .707 r
F P
0 g
s
.70501 .65914 m .70783 .64115 L .73934 .64467 L p .707 .577 .707 r
F P
0 g
s
.46655 .74469 m .46373 .76268 L .48004 .75607 L p .707 .577 .707 r
F P
0 g
s
.48004 .75607 m .48286 .73808 L .46655 .74469 L p .707 .577 .707 r
F P
0 g
s
.71567 .67988 m .72256 .71698 L .69358 .72461 L p .707 .577 .707 r
F P
0 g
s
.73934 .64467 m .73651 .66266 L .70501 .65914 L p .707 .577 .707 r
F P
0 g
s
.3006 .736 m .30342 .71801 L .29109 .70672 L p .707 .577 .707 r
F P
0 g
s
.29642 .59188 m .30331 .62898 L .30596 .63479 L p .707 .577 .707 r
F P
0 g
s
.48749 .5402 m .50005 .59559 L .49753 .59036 L p .707 .577 .707 r
F P
0 g
s
.49753 .59036 m .48497 .53498 L .48749 .5402 L p .707 .577 .707 r
F P
0 g
s
.72256 .71698 m .71567 .67988 L .747 .67375 L p .707 .577 .707 r
F P
0 g
s
.49692 .55899 m .50382 .59609 L .50117 .59027 L p .707 .577 .707 r
F P
0 g
s
.50117 .59027 m .49427 .55317 L .49692 .55899 L p .707 .577 .707 r
F P
0 g
s
.28862 .58098 m .30117 .63636 L .30369 .64159 L p .707 .577 .707 r
F P
0 g
s
.747 .67375 m .7539 .71085 L .72256 .71698 L p .707 .577 .707 r
F P
0 g
s
.29109 .70672 m .28827 .72471 L .3006 .736 L p .707 .577 .707 r
F P
0 g
s
.48286 .73808 m .48004 .75607 L .48718 .74695 L p .707 .577 .707 r
F P
0 g
s
.48718 .74695 m .49 .72896 L .48286 .73808 L p .707 .577 .707 r
F P
0 g
s
.30331 .62898 m .29642 .59188 L .30359 .58445 L p .707 .577 .707 r
F P
0 g
s
.30117 .63636 m .28862 .58098 L .29583 .57376 L p .707 .577 .707 r
F P
0 g
s
.28827 .72471 m .29109 .70672 L .28837 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30359 .58445 m .31049 .62155 L .30331 .62898 L p .707 .577 .707 r
F P
0 g
s
.48497 .53498 m .49753 .59036 L .48552 .58764 L p .707 .577 .707 r
F P
0 g
s
.48552 .58764 m .47296 .53226 L .48497 .53498 L p .707 .577 .707 r
F P
0 g
s
.28837 .69598 m .28555 .71398 L .28827 .72471 L p .707 .577 .707 r
F P
0 g
s
.49427 .55317 m .50117 .59027 L .48898 .58663 L p .707 .577 .707 r
F P
0 g
s
.48898 .58663 m .48208 .54954 L .49427 .55317 L p .707 .577 .707 r
F P
0 g
s
.29583 .57376 m .30839 .62914 L .30117 .63636 L p .707 .577 .707 r
F P
0 g
s
.49 .72896 m .48718 .74695 L .48445 .73621 L p .707 .577 .707 r
F P
0 g
s
.48445 .73621 m .48727 .71822 L .49 .72896 L p .707 .577 .707 r
F P
0 g
s
.31049 .62155 m .30359 .58445 L .31987 .57615 L p .707 .577 .707 r
F P
0 g
s
.30839 .62914 m .29583 .57376 L .31207 .56525 L p .707 .577 .707 r
F P
0 g
s
.28555 .71398 m .28837 .69598 L .29551 .68686 L p .707 .577 .707 r
F P
0 g
s
.31987 .57615 m .32677 .61324 L .31049 .62155 L p .707 .577 .707 r
F P
0 g
s
.47296 .53226 m .48552 .58764 L .4652 .58769 L p .707 .577 .707 r
F P
0 g
s
.4652 .58769 m .45265 .53231 L .47296 .53226 L p .707 .577 .707 r
F P
0 g
s
.29551 .68686 m .29269 .70486 L .28555 .71398 L p .707 .577 .707 r
F P
0 g
s
.48208 .54954 m .48898 .58663 L .46842 .58553 L p .707 .577 .707 r
F P
0 g
s
.46842 .58553 m .46152 .54844 L .48208 .54954 L p .707 .577 .707 r
F P
0 g
s
.31207 .56525 m .32462 .62063 L .30839 .62914 L p .707 .577 .707 r
F P
0 g
s
.32677 .61324 m .31987 .57615 L .34367 .56777 L p .707 .577 .707 r
F P
0 g
s
.32462 .62063 m .31207 .56525 L .33575 .55628 L p .707 .577 .707 r
F P
0 g
s
.48727 .71822 m .48445 .73621 L .47212 .72492 L p .707 .577 .707 r
F P
0 g
s
.47212 .72492 m .47494 .70693 L .48727 .71822 L p .707 .577 .707 r
F P
0 g
s
.29269 .70486 m .29551 .68686 L .31182 .68025 L p .707 .577 .707 r
F P
0 g
s
.45265 .53231 m .4652 .58769 L .44019 .59034 L p .707 .577 .707 r
F P
0 g
s
.43946 .5868 m .45265 .53231 L .44019 .59034 L .707 .577 .707 r
F
.43957 .58733 m .41089 .59111 L p .43255 .55355 L F P
0 g
s
.41089 .59111 m .40399 .55401 L .43188 .55034 L p .707 .577 .707 r
F P
0 g
s
.41089 .59111 m .43188 .55034 L .43255 .55355 L .707 .577 .707 r
F
.43856 .59052 m .426 .53513 L .42867 .53485 L p F P
0 g
s
.42867 .53485 m .45265 .53231 L p .43946 .5868 L .707 .577 .707 r
F P
0 g
s
.43856 .59052 m .42867 .53485 L .43946 .5868 L .707 .577 .707 r
F
.43188 .55034 m .43461 .54998 L p .43255 .55355 L F P
0 g
s
.43461 .54998 m .44151 .58708 L .43957 .58733 L p .707 .577 .707 r
F P
0 g
s
.43255 .55355 m .43461 .54998 L .43957 .58733 L .707 .577 .707 r
F
.44019 .59034 m .43856 .59052 L p .43946 .5868 L F P
0 g
s
.46152 .54844 m .46842 .58553 L .44151 .58708 L p .707 .577 .707 r
F P
0 g
s
.44151 .58708 m .43461 .54998 L .46152 .54844 L p .707 .577 .707 r
F P
0 g
s
.34367 .56777 m .35057 .60487 L .32677 .61324 L p .707 .577 .707 r
F P
0 g
s
.33575 .55628 m .3483 .61166 L .32462 .62063 L p .707 .577 .707 r
F P
0 g
s
.31182 .68025 m .309 .69824 L .29269 .70486 L p .707 .577 .707 r
F P
0 g
s
.35057 .60487 m .34367 .56777 L .37266 .56014 L p .707 .577 .707 r
F P
0 g
s
.3483 .61166 m .33575 .55628 L .36455 .54774 L p .707 .577 .707 r
F P
0 g
s
.40399 .55401 m .41089 .59111 L .37955 .59724 L p .707 .577 .707 r
F P
0 g
s
.426 .53513 m .43856 .59052 L .4082 .59583 L p .707 .577 .707 r
F P
0 g
s
.37955 .59724 m .37266 .56014 L .40399 .55401 L p .707 .577 .707 r
F P
0 g
s
.4082 .59583 m .39565 .54045 L .426 .53513 L p .707 .577 .707 r
F P
0 g
s
.37266 .56014 m .37955 .59724 L .35057 .60487 L p .707 .577 .707 r
F P
0 g
s
.47494 .70693 m .47212 .72492 L .4514 .71416 L p .707 .577 .707 r
F P
0 g
s
.4514 .71416 m .45422 .69617 L .47494 .70693 L p .707 .577 .707 r
F P
0 g
s
.36455 .54774 m .3771 .60312 L .3483 .61166 L p .707 .577 .707 r
F P
0 g
s
.3771 .60312 m .36455 .54774 L .39565 .54045 L p .707 .577 .707 r
F P
0 g
s
.39565 .54045 m .4082 .59583 L .3771 .60312 L p .707 .577 .707 r
F P
0 g
s
.309 .69824 m .31182 .68025 L .3357 .67679 L p .707 .577 .707 r
F P
0 g
s
.3357 .67679 m .33288 .69478 L .309 .69824 L p .707 .577 .707 r
F P
0 g
s
.45422 .69617 m .4514 .71416 L .42431 .70501 L p .707 .577 .707 r
F P
0 g
s
.42431 .70501 m .42713 .68701 L .45422 .69617 L p .707 .577 .707 r
F P
0 g
s
.33288 .69478 m .3357 .67679 L .36482 .67683 L p .707 .577 .707 r
F P
0 g
s
.36482 .67683 m .362 .69482 L .33288 .69478 L p .707 .577 .707 r
F P
0 g
s
.42713 .68701 m .42431 .70501 L .3935 .69834 L p .707 .577 .707 r
F P
0 g
s
.3935 .69834 m .39632 .68035 L .42713 .68701 L p .707 .577 .707 r
F P
0 g
s
.362 .69482 m .36482 .67683 L .39632 .68035 L p .707 .577 .707 r
F P
0 g
s
.39632 .68035 m .3935 .69834 L .362 .69482 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol007=oo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00Kgoo
10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
00000P00Kgoo001]Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001/Ool006]oo`8000=JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06Yoo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00J7oo001XOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001TOol006Io
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<002Ioo`X003Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`007goo1`000eYF00<005YFFUH00UYF00<005YF
00000P00<Goo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`006goo1000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80031oo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF009JEP/000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<001Moo`@000IJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EUYF001JEP0`Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP03FUH0
1000FUH000001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0057oo100000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00IGoo00@005YFFUH000EJEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool5
0006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;goo001U
Ool01@00FUIJEP00FUH010000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000_Ool006Eoo`D000IJEP03001JEUYF00MJEP03001JEUYF00=JEPH00005FUH005YF
FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool006Aoo`800003FUH005YF00QJEP03001JEUYF00IJEPH000=JEP03001JEUYF00H0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<0
00UJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
008002moo`00HGoo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF
00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000Aoo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF008002moo`00GWoo0`001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0025YF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000_Ool005Yo
o`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001JEUYF
009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Qoo`8000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP8000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;Woo001GOol20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH20007FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001EOol2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001DOol00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001COol20004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00
FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF2`0000=JEP000000;Goo001BOol00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP02FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP02FUH4000]Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH@0002FUH01000FUIJEP002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000]Ool0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUHE00000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00eYF0P00;Woo001BOol200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YFFUH00eYF00<007ooOol0;Goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP0200000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00=JEP8000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF0080031oo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`000UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP05
FUH00`00FUH000020006FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000bOol005=oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH00eYF100025YF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00=7oo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF009J
EP03001JEP0000<000AJEP03001JEUYF00EJEPH000AJEP03001JEUYF00IJEP03001JEP00008003Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF1@001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000015YF0`001eYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF0`00>Goo
001DOol00`00FUH00004FUH20003FUH2000<FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P0000=JEP00000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP8003aoo`00E7oo00<005YF00001EYF00@005YF000000iJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000@000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEP00008003ioo`00E7oo00@005YFFUH000=JEP<00003FUH005YF00eJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00EJEP@0045oo`00E7oo00D005YFFUH005YF008000AJEP03001JEUYF00aJEP03001JEUYF00MJ
EP03001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP040015Ool004ioo`L0009JEP<000EJEP03001JEUYF00eJEP<000AJEPH000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPL004Uoo`00Agoo1`0015YF00D005YFFUIJ
EP0000=JEP03001JEUYF00=JEP03001JEUYF00]JEPT00003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF
00=JEP04001JEUYFFUH8001@Ool004=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00<0009JEP03
001JEUYF00=JEP03001JEUYF00]JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000`005Ioo`00
?goo10001UYF00<005YFFUH01eYF00D005YF000005YF00l000=JEPT000EJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00AJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00?Goo0P0000=JEP00FUH025YF00<005YFFUH0
1UYF1@0000=JEP00FUH015YF00<005YFFUH00UYF1P0015YF10001UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF
00<005YF00003`00Cgoo000jOol30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH>0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF000000030002FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH60019Ool003Moo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP8000MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030015
Ool003=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@0045oo`00
<Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0
03eoo`00<7oo0P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001eYF00<0
05YFFUH00eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH00eYF0`00>Woo000^Ool200000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH500000eYF
001JEP03FUH00`00FUIJEP020005Ool70006FUH00`00FUIJEP05FUH3000hOol002eoo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000MJEP03
001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00800003
FUH0000000IJEP03001JEUYF00=JEP04001JEUYF0009Ool70002FUH00`00FUIJEP05FUH00`00FUIJ
EP02000fOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EP00FUH200000eYF001JEP02FUH;00000eYF00000007Ool50003OolD000aOol002]oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003
FUH00000008000EJEP03001JEUYF009JEP@000Moo`T000AJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP00000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20004FUHA0002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0P0000AJ
EP00FUH000IJEP03001JEUYF00=JEP03001JEP0000Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUH000000UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF0P000Woo1000
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00:goo0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF
1`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP04001J
EUYF0005FUH00`00FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH70002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEP000eYF10001UYF1@001EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00;7oo00<005YF000015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH00`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF0080009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF10002EYF0P000UYF00@005YFFUH000=JEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00=JEP<0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00001EYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF0P0015YF0P000eYF00<005YFFUH01eYF0P0000=JEP00FUH00UYF100015YF00@005YF
FUIJEP<0009JEP03001JEUYF00L000IJEP03001JEUYF00IJEP@000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]Ool002ao
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP07FUH200000eYF
001JEP0200000eYF001JEP06FUH400001Goo001JEUYF00001EYF00@005YFFUIJEP@0009JEP03001J
EUYF00IJEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000]Ool00`00FUH0
0004FUH20005FUH30009FUH00`00FUIJEP06FUH200000eYF00000004FUH00`00FUIJEP03FUH30003
Ool01000FUIJEP001EYF00<005YFFUH01EYF10001UYF00<005YFFUH00UYF0P002EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF4@0000=JEP00Ool0;7oo000]Ool0
0`00FUH00005FUH00`00FUH00003000<FUH00`00FUIJEP06FUH40005FUH00`00FUH000040005Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00D000=JEP03001JEP0000@0009J
EP800003FUH00000008002aoo`00;Goo00<005YF00001EYF0P0000=JEP00FUH03EYF00<005YFFUH0
1eYF0P0000=JEP00FUH00UYF10002Goo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH3
00000eYF001JEP05FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHA0003
FUH02@00FUIJEP00FUH005YF001JEP02000/Ool002eoo`04001JEUYF0002FUH20003FUH00`00FUIJ
EP0<FUH00`00FUIJEP07FUH01000FUIJEUYF100037oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00AJEP8000IJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH80003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0000/Ool002eoo`03001J
EUYF00<000EJEP03001JEUYF00aJEP03001JEUYF00IJEP8000AJEP03001oogoo00aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF009JEP800004FUH005YFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF000015YF0P00;Goo000^Ool2FUH01000FUIJEP0015YF00<005YFFUH03EYF0`000UYF
0`0000=oo`00FUH00eYF0`0037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP80
0003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00D00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00008000AJEP03001oogoo02aoo`00
;Woo00=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH02eYF1P0017oo00<005YFFUH00UYF00<0
05YFFUH00P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP<000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
00AJEP03001JEUYF00=JEP@0009JEP/00003FUH005YF00IJEP04001JEUYFFUH50003FUH01000FUIJ
EP00;goo000^Ool200000eYF000000030003FUH01000FUIJEUYF0`001EYF1`001Woo00@005YFFUH0
00EJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH02000FUIJEP00FUH0
05YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUH000030004FUH00`00FUIJEP06FUHB0007FUH3000`Ool002moo`800003
FUH005YF009JEPl0009oo`D000Moo`<000IJEP03001JEP0000<000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YFFUIJEP@000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80039oo`00<Goo30002goo
0`002Woo00<005YFFUH015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04001JEP000003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000dOol005Ioo`8000=JEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEP00001J
EP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEUYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
0`00>7oo001HOol200000eYF001JEP06FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH50003
FUH>0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@003]oo`00FWoo0`00
1UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00H005YFFUIJEP00FUH2000;FUH90008FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000EJEP03001JEUYF00mJEP03001JEUYF
00AJEPD003moo`00GGoo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040014Ool0065oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70018Ool006Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02
FUH00`00FUH00002FUHD001?Ool006Eoo`03001JEUYF00P000AJEP03001JEUYF00IJEP04001JEUYF
FUH40006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH0
0`00FUH0000=001HOol006Eoo`05001JEUYF001JEP020004FUHA000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00001EYF00<005YFFUH00eYF00@0
05YF000005Ioo`00=Goo400087oo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF001FOol0035oo`@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPL001Uoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003
FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001EOol002moo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00@001Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003
FUH005YF00EJEP03001JEUYF00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0015oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000/Ool20002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000003goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF00=JEP03001J
EUYF008005Aoo`00:goo00<005YF00000UYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP04001J
EUYFFUH3000<Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YF
FUH00eYF00<005YFFUH00P00E7oo000ZOol00`00FUH00003FUH4000@Ool70006FUH00`00FUIJEP05
FUH2000;Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<0
05YFFUH00UYF00<005YFFUH00P00E7oo000ZOol01000FUH005YF0P006goo10000UYF00<005YFFUH0
1UYF0`002Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01UYF
00<005YFFUH00eYF00@005YF000005Aoo`00:Woo00@005YF0000025oo`@000MJEP03001JEUYF0080
00Qoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEPH000=JEP04001J
EUYF001DOol002Yoo`8002Moo`8000AJEP03001JEUYF00=JEP8000Qoo`<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EPh00003FUH0000000<00003FUH0000005=oo`00:Woo0`00:7oo0`0000=JEP00FUH01EYF0P002Goo
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP/000=JEP07001JEUYF001JEP00FUH01000Dgoo000ZOol200000eYF0000
000YOol20006FUH00`00FUH0000:Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001eYF00<005YFFUH015YF00<005YF
FUH00P000eYF00<005YF0000Dgoo000ZOol00`00FUIJEP02FUH00`00Oomoo`0XOol20003FUH01@00
FUIJEUYF00002goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF1@0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP80
05Aoo`00:Woo00<005YFFUH00UYF0`00:Woo0P0000=JEP00FUH00UYF00<007ooOol037oo1`001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0200000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00P0015YF00<007ooOol0Dgoo000ZOol00`00FUIJEP02FUH00`00
FUIJEP02000ZOol20003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH@00000eYF
001JEP06FUH01000FUIJEUYF1P000UYF00@005YFFUH005Ioo`00:goo00@005YFFUH000EJEP<002Uo
o`05001JEP00FUH0000POolI0002FUH00`00FUIJEP06FUHC0007FUH3001GOol002aoo`<000IJEP03
001JEP0000<002Ioo`800003FUH007oo02Uoo`04001JEUYF0003FUH40007FUH00`00FUIJEP06FUH3
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001IOol002ioo`03001JEUYF00AJEP03001JEUYF
00=JEP@002=oo`03001JEP0002Yoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003001KOol002moo`8000=JEP03001J
EUYF00EJEP03001JEUYF00@001eoo`@002]oo`03001JEUYF008000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<005moo`00<Goo0P0000=JEP00FUH01UYF00<0
05YFFUH015YF1`0047oo1P000UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00@0069oo`00<goo0`001UYF00<005YFFUH01UYF00<005YF
FUH00UYF40000eYF00<005YFFUH00UYF0P00;7oo00AJEP00FUH000EJEP03001JEUYF00mJEP03001J
EUYF00AJEPD006Ioo`00=Woo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8002eoo`80009JEP03001JEUYF009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00@006]oo`00>7oo0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Woo0P0000=JEP00FUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF1`00Kgoo000kOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00<Goo10000eYF00<005YFFUH00UYF2000MWoo000nOol40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000=goo2000OWoo0012
Ool70004FUH00`00FUIJEP06FUH01000FUIJEUYF1000_goo0019OolA0033Ool00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59801 .73071 m .59021 .67488 L .55935 .67744 L p .707 .577 .707 r
F P
0 g
s
.59021 .67488 m .59801 .73071 L .62956 .7259 L p .707 .577 .707 r
F P
0 g
s
.62956 .7259 m .62176 .67007 L .59021 .67488 L p .707 .577 .707 r
F P
0 g
s
.62176 .67007 m .62956 .7259 L .65872 .71933 L p .707 .577 .707 r
F P
0 g
s
.65872 .71933 m .65092 .6635 L .62176 .67007 L p .707 .577 .707 r
F P
0 g
s
.56715 .73327 m .55935 .67744 L .5322 .67751 L p .707 .577 .707 r
F P
0 g
s
.55935 .67744 m .56715 .73327 L .59801 .73071 L p .707 .577 .707 r
F P
0 g
s
.65092 .6635 m .65872 .71933 L .68263 .71162 L p .707 .577 .707 r
F P
0 g
s
.68263 .71162 m .67483 .6558 L .65092 .6635 L p .707 .577 .707 r
F P
0 g
s
.5322 .67751 m .54 .73334 L .56715 .73327 L p .707 .577 .707 r
F P
0 g
s
.54 .73334 m .5322 .67751 L .51143 .67509 L p .707 .577 .707 r
F P
0 g
s
.59992 .83211 m .59564 .79487 L .56468 .79663 L p .707 .577 .707 r
F P
0 g
s
.59564 .79487 m .59992 .83211 L .63157 .82803 L p .707 .577 .707 r
F P
0 g
s
.63157 .82803 m .62729 .79078 L .59564 .79487 L p .707 .577 .707 r
F P
0 g
s
.67483 .6558 m .68263 .71162 L .69895 .70355 L p .707 .577 .707 r
F P
0 g
s
.69895 .70355 m .69115 .64772 L .67483 .6558 L p .707 .577 .707 r
F P
0 g
s
.62729 .79078 m .63157 .82803 L .6608 .82202 L p .707 .577 .707 r
F P
0 g
s
.6608 .82202 m .65652 .78478 L .62729 .79078 L p .707 .577 .707 r
F P
0 g
s
.51143 .67509 m .51923 .73091 L .54 .73334 L p .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56468 .79663 L .56307 .79659 L p .707 .577 .707 r
F P
0 g
s
.56328 .80889 m .56007 .80838 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56896 .83388 m .56307 .79659 L .5636 .82742 L .707 .577 .707 r
F
.56468 .79663 m .56896 .83388 L .59992 .83211 L p F P
0 g
s
.56007 .80838 m .55832 .82663 L .5636 .82746 L p .707 .577 .707 r
F P
0 g
s
.56371 .83374 m .56896 .83388 L p .5636 .82742 L .707 .577 .707 r
F P
0 g
s
.5636 .82746 m .58935 .8315 L p .56331 .81095 L .707 .577 .707 r
F P
0 g
s
.56331 .81095 m .56007 .80838 L .5636 .82746 L .707 .577 .707 r
F
.55832 .82663 m .56007 .80838 L .53275 .80103 L p F P
0 g
s
.53275 .80103 m .531 .81928 L .55832 .82663 L p .707 .577 .707 r
F P
0 g
s
.53744 .79591 m .54172 .83316 L .56371 .83374 L p .707 .577 .707 r
F P
0 g
s
.5636 .82742 m .53744 .79591 L .56371 .83374 L .707 .577 .707 r
F
.56307 .79659 m .53744 .79591 L p .5636 .82742 L F P
0 g
s
.58935 .8315 m .5911 .81325 L .56328 .80889 L p .707 .577 .707 r
F P
0 g
s
.58935 .8315 m .56328 .80889 L .56331 .81095 L .707 .577 .707 r
F
.5911 .81325 m .58935 .8315 L .62106 .83339 L p F P
0 g
s
.62106 .83339 m .62281 .81514 L .5911 .81325 L p .707 .577 .707 r
F P
0 g
s
.62281 .81514 m .62106 .83339 L .65034 .83213 L p .707 .577 .707 r
F P
0 g
s
.65034 .83213 m .65209 .81388 L .62281 .81514 L p .707 .577 .707 r
F P
0 g
s
.65652 .78478 m .6608 .82202 L .68475 .81469 L p .707 .577 .707 r
F P
0 g
s
.68475 .81469 m .68047 .77744 L .65652 .78478 L p .707 .577 .707 r
F P
0 g
s
.51923 .73091 m .51143 .67509 L .49906 .6704 L p .707 .577 .707 r
F P
0 g
s
.65209 .81388 m .65034 .83213 L .67433 .82785 L p .707 .577 .707 r
F P
0 g
s
.67433 .82785 m .67608 .8096 L .65209 .81388 L p .707 .577 .707 r
F P
0 g
s
.531 .81928 m .53275 .80103 L .51182 .7919 L p .707 .577 .707 r
F P
0 g
s
.54172 .83316 m .53744 .79591 L .51657 .79276 L p .707 .577 .707 r
F P
0 g
s
.69115 .64772 m .69895 .70355 L .70608 .69589 L p .707 .577 .707 r
F P
0 g
s
.70608 .69589 m .69828 .64007 L .69115 .64772 L p .707 .577 .707 r
F P
0 g
s
.49906 .6704 m .50686 .72622 L .51923 .73091 L p .707 .577 .707 r
F P
0 g
s
.51182 .7919 m .51007 .81015 L .531 .81928 L p .707 .577 .707 r
F P
0 g
s
.51657 .79276 m .52085 .83001 L .54172 .83316 L p .707 .577 .707 r
F P
0 g
s
.68047 .77744 m .68475 .81469 L .70109 .80674 L p .707 .577 .707 r
F P
0 g
s
.70109 .80674 m .69681 .76949 L .68047 .77744 L p .707 .577 .707 r
F P
0 g
s
.67608 .8096 m .67433 .82785 L .69068 .82095 L p .707 .577 .707 r
F P
0 g
s
.69068 .82095 m .69242 .8027 L .67608 .8096 L p .707 .577 .707 r
F P
0 g
s
.50686 .72622 m .49906 .6704 L .49631 .66391 L p .707 .577 .707 r
F P
0 g
s
.51007 .81015 m .51182 .7919 L .49933 .7819 L p .707 .577 .707 r
F P
0 g
s
.52085 .83001 m .51657 .79276 L .50413 .7875 L p .707 .577 .707 r
F P
0 g
s
.49933 .7819 m .49758 .80015 L .51007 .81015 L p .707 .577 .707 r
F P
0 g
s
.50413 .7875 m .50841 .82475 L .52085 .83001 L p .707 .577 .707 r
F P
0 g
s
.69828 .64007 m .70608 .69589 L .70333 .6894 L p .707 .577 .707 r
F P
0 g
s
.70333 .6894 m .69553 .63358 L .69828 .64007 L p .707 .577 .707 r
F P
0 g
s
.49631 .66391 m .50411 .71973 L .50686 .72622 L p .707 .577 .707 r
F P
0 g
s
.69681 .76949 m .70109 .80674 L .70821 .79895 L p .707 .577 .707 r
F P
0 g
s
.70821 .79895 m .70393 .76171 L .69681 .76949 L p .707 .577 .707 r
F P
0 g
s
.69242 .8027 m .69068 .82095 L .69778 .81211 L p .707 .577 .707 r
F P
0 g
s
.69778 .81211 m .69953 .79386 L .69242 .8027 L p .707 .577 .707 r
F P
0 g
s
.4904 .8221 m .49342 .32054 L .44941 .31759 L p .707 .577 .707 r
F P
0 g
s
.50841 .82475 m .50413 .7875 L .50133 .78065 L p .707 .577 .707 r
F P
0 g
s
.49758 .80015 m .49933 .7819 L .4965 .77199 L p .707 .577 .707 r
F P
0 g
s
.50411 .71973 m .49631 .66391 L .50344 .65625 L p .707 .577 .707 r
F P
0 g
s
.4965 .77199 m .49475 .79024 L .49758 .80015 L p .707 .577 .707 r
F P
0 g
s
.50133 .78065 m .50561 .8179 L .50841 .82475 L p .707 .577 .707 r
F P
0 g
s
.50344 .65625 m .51124 .71208 L .50411 .71973 L p .707 .577 .707 r
F P
0 g
s
.49475 .79024 m .4965 .77199 L .5036 .76316 L p .707 .577 .707 r
F P
0 g
s
.51124 .71208 m .50344 .65625 L .51976 .64818 L p .707 .577 .707 r
F P
0 g
s
.50561 .8179 m .50133 .78065 L .50845 .77286 L p .707 .577 .707 r
F P
0 g
s
.5036 .76316 m .50186 .78141 L .49475 .79024 L p .707 .577 .707 r
F P
0 g
s
.50845 .77286 m .51273 .81011 L .50561 .8179 L p .707 .577 .707 r
F P
0 g
s
.51976 .64818 m .52756 .704 L .51124 .71208 L p .707 .577 .707 r
F P
0 g
s
.52756 .704 m .51976 .64818 L .54367 .64047 L p .707 .577 .707 r
F P
0 g
s
.50186 .78141 m .5036 .76316 L .51995 .75626 L p .707 .577 .707 r
F P
0 g
s
.51273 .81011 m .50845 .77286 L .52478 .76492 L p .707 .577 .707 r
F P
0 g
s
.51995 .75626 m .5182 .77451 L .50186 .78141 L p .707 .577 .707 r
F P
0 g
s
.52478 .76492 m .52906 .80216 L .51273 .81011 L p .707 .577 .707 r
F P
0 g
s
.52906 .80216 m .52478 .76492 L .54874 .75758 L p .707 .577 .707 r
F P
0 g
s
.5182 .77451 m .51995 .75626 L .54394 .75197 L p .707 .577 .707 r
F P
0 g
s
.54394 .75197 m .54219 .77022 L .5182 .77451 L p .707 .577 .707 r
F P
0 g
s
.54874 .75758 m .55302 .79483 L .52906 .80216 L p .707 .577 .707 r
F P
0 g
s
.49342 .32054 m .4904 .8221 L .53534 .82124 L p .707 .577 .707 r
F P
0 g
s
.54367 .64047 m .55147 .6963 L .52756 .704 L p .707 .577 .707 r
F P
0 g
s
.53534 .82124 m .53836 .31969 L .49342 .32054 L p .707 .577 .707 r
F P
0 g
s
.55147 .6963 m .54367 .64047 L .57283 .6339 L p .707 .577 .707 r
F P
0 g
s
.57283 .6339 m .58063 .68973 L .55147 .6963 L p .707 .577 .707 r
F P
0 g
s
.55302 .79483 m .54874 .75758 L .57797 .75158 L p .707 .577 .707 r
F P
0 g
s
.54219 .77022 m .54394 .75197 L .57322 .75071 L p .707 .577 .707 r
F P
0 g
s
.57797 .75158 m .58225 .78882 L .55302 .79483 L p .707 .577 .707 r
F P
0 g
s
.57322 .75071 m .57147 .76897 L .54219 .77022 L p .707 .577 .707 r
F P
0 g
s
.58225 .78882 m .57797 .75158 L .60961 .74749 L p .707 .577 .707 r
F P
0 g
s
.57147 .76897 m .57322 .75071 L .60493 .75261 L p .707 .577 .707 r
F P
0 g
s
.60961 .74749 m .61389 .78474 L .58225 .78882 L p .707 .577 .707 r
F P
0 g
s
.60493 .75261 m .60318 .77086 L .57147 .76897 L p .707 .577 .707 r
F P
0 g
s
.53836 .31969 m .53534 .82124 L .57682 .81666 L p .707 .577 .707 r
F P
0 g
s
.58063 .68973 m .57283 .6339 L .60438 .6291 L p .707 .577 .707 r
F P
0 g
s
.57682 .81666 m .57984 .31511 L .53836 .31969 L p .707 .577 .707 r
F P
0 g
s
.44639 .81915 m .44941 .31759 L .41065 .31112 L p .707 .577 .707 r
F P
0 g
s
.44941 .31759 m .44639 .81915 L .4904 .8221 L p .707 .577 .707 r
F P
0 g
s
.69553 .63358 m .70333 .6894 L .69096 .68471 L p .707 .577 .707 r
F P
0 g
s
.69096 .68471 m .68316 .62889 L .69553 .63358 L p .707 .577 .707 r
F P
0 g
s
.70393 .76171 m .70821 .79895 L .70541 .7921 L p .707 .577 .707 r
F P
0 g
s
.70541 .7921 m .70113 .75485 L .70393 .76171 L p .707 .577 .707 r
F P
0 g
s
.60438 .6291 m .61218 .68492 L .58063 .68973 L p .707 .577 .707 r
F P
0 g
s
.66328 .76483 m .66153 .78308 L .63886 .77698 L p .707 .577 .707 r
F P
0 g
s
.63885 .77399 m .66328 .76483 L .63886 .77698 L .707 .577 .707 r
F
.63889 .78331 m .61389 .78474 L p .63875 .74839 L F P
0 g
s
.63421 .77572 m .63596 .75747 L .66328 .76483 L p .707 .577 .707 r
F P
0 g
s
.64057 .74572 m .64485 .78297 L .63889 .78331 L p .707 .577 .707 r
F P
0 g
s
.63875 .74839 m .64057 .74572 L .63889 .78331 L .707 .577 .707 r
F
.63886 .77698 m .63421 .77572 L p .63885 .77399 L F P
0 g
s
.61389 .78474 m .60961 .74749 L .64057 .74572 L p .707 .577 .707 r
F P
0 g
s
.63596 .75747 m .63421 .77572 L .60318 .77086 L p .707 .577 .707 r
F P
0 g
s
.60318 .77086 m .60493 .75261 L .63596 .75747 L p .707 .577 .707 r
F P
0 g
s
.57984 .31511 m .57682 .81666 L .61078 .80881 L p .707 .577 .707 r
F P
0 g
s
.61218 .68492 m .60438 .6291 L .63524 .62653 L p .707 .577 .707 r
F P
0 g
s
.61078 .80881 m .6138 .30726 L .57984 .31511 L p .707 .577 .707 r
F P
0 g
s
.69953 .79386 m .69778 .81211 L .69495 .80221 L p .707 .577 .707 r
F P
0 g
s
.69495 .80221 m .6967 .78396 L .69953 .79386 L p .707 .577 .707 r
F P
0 g
s
.40763 .81268 m .41065 .31112 L .38092 .30177 L p .707 .577 .707 r
F P
0 g
s
.41065 .31112 m .40763 .81268 L .44639 .81915 L p .707 .577 .707 r
F P
0 g
s
.255 .72242 m .2472 .66659 L .21634 .66916 L p .707 .577 .707 r
F P
0 g
s
.2472 .66659 m .255 .72242 L .28655 .71762 L p .707 .577 .707 r
F P
0 g
s
.28655 .71762 m .27875 .66179 L .2472 .66659 L p .707 .577 .707 r
F P
0 g
s
.27875 .66179 m .28655 .71762 L .31571 .71104 L p .707 .577 .707 r
F P
0 g
s
.31571 .71104 m .30791 .65522 L .27875 .66179 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22414 .72498 m .22088 .70163 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.21634 .66916 m .22414 .72498 L .255 .72242 L p .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .25263 .7068 L .22176 .70856 L p .707 .577 .707 r
F P
0 g
s
.22176 .70856 m .22167 .70857 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.25691 .74405 m .22176 .70856 L .22178 .70867 L .707 .577 .707 r
F
.22595 .74581 m .22167 .70857 L .19465 .70785 L p F P
0 g
s
.19465 .70785 m .19443 .70784 L p .19469 .70816 L .707 .577 .707 r
F P
0 g
s
.22595 .74581 m .19465 .70785 L .19469 .70816 L .707 .577 .707 r
F
.19443 .70784 m .19871 .74509 L .22595 .74581 L p F P
0 g
s
.19871 .74509 m .19443 .70784 L .17381 .70473 L p .707 .577 .707 r
F P
0 g
s
.17381 .70473 m .17356 .7047 L p .17388 .70521 L .707 .577 .707 r
F P
0 g
s
.19871 .74509 m .17381 .70473 L .17388 .70521 L .707 .577 .707 r
F
.17356 .7047 m .17784 .74194 L .19871 .74509 L p F P
0 g
s
.17784 .74194 m .17356 .7047 L .1613 .69951 L p .707 .577 .707 r
F P
0 g
s
.1613 .69951 m .16112 .69944 L p .16138 .70011 L .707 .577 .707 r
F P
0 g
s
.17784 .74194 m .1613 .69951 L .16138 .70011 L .707 .577 .707 r
F
.16112 .69944 m .1654 .73668 L .17784 .74194 L p F P
0 g
s
.1654 .73668 m .16112 .69944 L .15836 .69269 L p .707 .577 .707 r
F P
0 g
s
.15836 .69269 m .15832 .69258 L p .15844 .69333 L .707 .577 .707 r
F P
0 g
s
.1654 .73668 m .15836 .69269 L .15844 .69333 L .707 .577 .707 r
F
.16385 .71794 m .16044 .69354 L p .1533 .65562 L F P
0 g
s
.16044 .69354 m .15605 .66211 L .15588 .66172 L p .707 .577 .707 r
F P
0 g
s
.15588 .66172 m .1533 .65562 L p .16044 .69354 L .707 .577 .707 r
F P
0 g
s
.17622 .72263 m .17285 .69851 L p .15605 .66211 L .707 .577 .707 r
F P
0 g
s
.16793 .66662 m .15605 .66211 L p .17285 .69851 L .707 .577 .707 r
F P
0 g
s
.15605 .66211 m .16385 .71794 L .17622 .72263 L p .707 .577 .707 r
F P
0 g
s
.15832 .69258 m .1626 .72983 L .1654 .73668 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .16385 .71794 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1533 .65562 m .15766 .68687 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.15766 .68687 m .1611 .71145 L p .15407 .66018 L .707 .577 .707 r
F P
0 g
s
.1626 .72983 m .15832 .69258 L .15842 .69247 L p .707 .577 .707 r
F P
0 g
s
.1611 .71145 m .15766 .68687 L p .16043 .64797 L .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .1611 .71145 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16043 .64797 m .16479 .67915 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.16479 .67915 m .16823 .70379 L p .16048 .6526 L .707 .577 .707 r
F P
0 g
s
.17285 .69851 m .16842 .6668 L .16793 .66662 L p .707 .577 .707 r
F P
0 g
s
.197 .72506 m .19367 .7013 L p .16842 .6668 L .707 .577 .707 r
F P
0 g
s
.18891 .6692 m .16842 .6668 L p .19367 .7013 L .707 .577 .707 r
F P
0 g
s
.16842 .6668 m .17622 .72263 L .197 .72506 L p .707 .577 .707 r
F P
0 g
s
.16823 .70379 m .16043 .64797 L .17675 .63989 L p .707 .577 .707 r
F P
0 g
s
.16972 .72204 m .16544 .6848 L .16569 .68468 L p .707 .577 .707 r
F P
0 g
s
.18455 .69572 m .16823 .70379 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.17675 .63989 m .18112 .67114 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.18112 .67114 m .18455 .69572 L p .17618 .64416 L .707 .577 .707 r
F P
0 g
s
.19367 .7013 m .18919 .66923 L .18891 .6692 L p .707 .577 .707 r
F P
0 g
s
.22167 .70857 m .22595 .74581 L .22654 .74578 L p .707 .577 .707 r
F P
0 g
s
.22387 .72499 m .22414 .72498 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.22654 .74578 m .25691 .74405 L p .22178 .70867 L .707 .577 .707 r
F P
0 g
s
.22178 .70867 m .22167 .70857 L .22654 .74578 L .707 .577 .707 r
F
.18919 .66923 m .197 .72506 L .22387 .72499 L p F P
0 g
s
.2238 .72444 m .18919 .66923 L .22387 .72499 L .707 .577 .707 r
F
.21634 .66916 m .18919 .66923 L p .2238 .72444 L F P
0 g
s
.18455 .69572 m .17675 .63989 L .20066 .63219 L p .707 .577 .707 r
F P
0 g
s
.18605 .7141 m .18177 .67685 L .18214 .67674 L p .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .18455 .69572 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20066 .63219 m .20505 .66362 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20505 .66362 m .20846 .68802 L p .19978 .63566 L .707 .577 .707 r
F P
0 g
s
.20846 .68802 m .20066 .63219 L .22982 .62562 L p .707 .577 .707 r
F P
0 g
s
.21001 .70676 m .20573 .66951 L .20615 .66943 L p .707 .577 .707 r
F P
0 g
s
.22088 .70163 m .21634 .66916 L p .2238 .72444 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .20846 .68802 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.22982 .62562 m .23425 .65733 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23425 .65733 m .23762 .68144 L p .22903 .62791 L .707 .577 .707 r
F P
0 g
s
.23762 .68144 m .22982 .62562 L .26137 .62081 L p .707 .577 .707 r
F P
0 g
s
.23924 .70076 m .23496 .66351 L .23534 .66346 L p .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .23762 .68144 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26137 .62081 m .26585 .65288 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26585 .65288 m .26917 .67664 L p .26105 .62162 L .707 .577 .707 r
F P
0 g
s
.26917 .67664 m .26137 .62081 L .29223 .61825 L p .707 .577 .707 r
F P
0 g
s
.27088 .69667 m .2666 .65942 L .26685 .65941 L p .707 .577 .707 r
F P
0 g
s
.29223 .61825 m .29677 .65072 L p .26917 .67664 L .707 .577 .707 r
F P
0 g
s
.30791 .65522 m .31571 .71104 L .33962 .70334 L p .707 .577 .707 r
F P
0 g
s
.33962 .70334 m .33182 .64751 L .30791 .65522 L p .707 .577 .707 r
F P
0 g
s
.29765 .65766 m .32481 .65838 L p .30227 .69423 L .707 .577 .707 r
F P
0 g
s
.29677 .65072 m .30003 .67407 L .29973 .6741 L p .707 .577 .707 r
F P
0 g
s
.29973 .6741 m .26917 .67664 L p .29677 .65072 L .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29757 .65766 L .29765 .65766 L p .707 .577 .707 r
F P
0 g
s
.30185 .6949 m .29765 .65766 L .30227 .69423 L .707 .577 .707 r
F
.26685 .65941 m .29757 .65766 L p .27227 .69465 L F P
0 g
s
.27088 .69667 m .26685 .65941 L .27227 .69465 L .707 .577 .707 r
F
.23534 .66346 m .2666 .65942 L p .24138 .69753 L F P
0 g
s
.23924 .70076 m .23534 .66346 L .24138 .69753 L .707 .577 .707 r
F
.20615 .66943 m .23496 .66351 L p .21241 .7026 L F P
0 g
s
.21001 .70676 m .20615 .66943 L .21241 .7026 L .707 .577 .707 r
F
.18214 .67674 m .20573 .66951 L p .18812 .70941 L F P
0 g
s
.18605 .7141 m .18214 .67674 L .18812 .70941 L .707 .577 .707 r
F
.16569 .68468 m .18177 .67685 L p .17098 .7173 L F P
0 g
s
.16972 .72204 m .16569 .68468 L .17098 .7173 L .707 .577 .707 r
F
.15842 .69247 m .16544 .6848 L p .16287 .72552 L F P
0 g
s
.1626 .72983 m .15842 .69247 L .16287 .72552 L .707 .577 .707 r
F
.15766 .68687 m .1533 .65562 L .15384 .65504 L p F P
0 g
s
.15384 .65504 m .16043 .64797 L p .15766 .68687 L .707 .577 .707 r
F P
0 g
s
.25263 .7068 m .25691 .74405 L .28856 .73996 L p .707 .577 .707 r
F P
0 g
s
.28856 .73996 m .28428 .70271 L .25263 .7068 L p .707 .577 .707 r
F P
0 g
s
.68316 .62889 m .69096 .68471 L .67019 .68229 L p .707 .577 .707 r
F P
0 g
s
.67019 .68229 m .66238 .62646 L .68316 .62889 L p .707 .577 .707 r
F P
0 g
s
.28428 .70271 m .28856 .73996 L .31779 .73396 L p .707 .577 .707 r
F P
0 g
s
.31779 .73396 m .31351 .69671 L .28428 .70271 L p .707 .577 .707 r
F P
0 g
s
.6967 .78396 m .69495 .80221 L .68246 .79221 L p .707 .577 .707 r
F P
0 g
s
.68246 .79221 m .68421 .77396 L .6967 .78396 L p .707 .577 .707 r
F P
0 g
s
.70113 .75485 m .70541 .7921 L .69297 .78684 L p .707 .577 .707 r
F P
0 g
s
.69297 .78684 m .68869 .74959 L .70113 .75485 L p .707 .577 .707 r
F P
0 g
s
.63524 .62653 m .64304 .68236 L .61218 .68492 L p .707 .577 .707 r
F P
0 g
s
.6138 .30726 m .61078 .80881 L .63389 .79845 L p .707 .577 .707 r
F P
0 g
s
.63389 .79845 m .63691 .2969 L .6138 .30726 L p .707 .577 .707 r
F P
0 g
s
.31351 .69671 m .31779 .73396 L .34175 .72662 L p .707 .577 .707 r
F P
0 g
s
.34175 .72662 m .33747 .68937 L .31351 .69671 L p .707 .577 .707 r
F P
0 g
s
.3779 .80332 m .38092 .30177 L .36315 .29045 L p .707 .577 .707 r
F P
0 g
s
.38092 .30177 m .3779 .80332 L .40763 .81268 L p .707 .577 .707 r
F P
0 g
s
.33182 .64751 m .33962 .70334 L .35594 .69527 L p .707 .577 .707 r
F P
0 g
s
.35594 .69527 m .34814 .63944 L .33182 .64751 L p .707 .577 .707 r
F P
0 g
s
.66238 .62646 m .67019 .68229 L .64304 .68236 L p .707 .577 .707 r
F P
0 g
s
.64304 .68236 m .63524 .62653 L .66238 .62646 L p .707 .577 .707 r
F P
0 g
s
.68421 .77396 m .68246 .79221 L .66153 .78308 L p .707 .577 .707 r
F P
0 g
s
.66153 .78308 m .66328 .76483 L .68421 .77396 L p .707 .577 .707 r
F P
0 g
s
.68869 .74959 m .69297 .78684 L .6721 .78369 L p .707 .577 .707 r
F P
0 g
s
.6721 .78369 m .66782 .74645 L .68869 .74959 L p .707 .577 .707 r
F P
0 g
s
.33747 .68937 m .34175 .72662 L .35808 .71867 L p .707 .577 .707 r
F P
0 g
s
.35808 .71867 m .3538 .68142 L .33747 .68937 L p .707 .577 .707 r
F P
0 g
s
.24634 .83948 m .24809 .82123 L .21706 .81637 L p .707 .577 .707 r
F P
0 g
s
.24809 .82123 m .24634 .83948 L .27805 .84138 L p .707 .577 .707 r
F P
0 g
s
.27805 .84138 m .2798 .82313 L .24809 .82123 L p .707 .577 .707 r
F P
0 g
s
.2798 .82313 m .27805 .84138 L .30733 .84012 L p .707 .577 .707 r
F P
0 g
s
.30733 .84012 m .30908 .82187 L .2798 .82313 L p .707 .577 .707 r
F P
0 g
s
.21706 .81637 m .21531 .83462 L .24634 .83948 L p .707 .577 .707 r
F P
0 g
s
.21531 .83462 m .21706 .81637 L .18974 .80902 L p .707 .577 .707 r
F P
0 g
s
.64485 .78297 m .64057 .74572 L .66782 .74645 L p .707 .577 .707 r
F P
0 g
s
.63691 .2969 m .63389 .79845 L .64389 .7866 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .64691 .28505 L .63691 .2969 L p .707 .577 .707 r
F P
0 g
s
.18974 .80902 m .18799 .82727 L .21531 .83462 L p .707 .577 .707 r
F P
0 g
s
.30908 .82187 m .30733 .84012 L .33132 .83583 L p .707 .577 .707 r
F P
0 g
s
.33132 .83583 m .33307 .81758 L .30908 .82187 L p .707 .577 .707 r
F P
0 g
s
.34814 .63944 m .35594 .69527 L .36307 .68761 L p .707 .577 .707 r
F P
0 g
s
.36307 .68761 m .35527 .63178 L .34814 .63944 L p .707 .577 .707 r
F P
0 g
s
.18799 .82727 m .18974 .80902 L .16881 .79989 L p .707 .577 .707 r
F P
0 g
s
.66782 .74645 m .6721 .78369 L .64485 .78297 L p .707 .577 .707 r
F P
0 g
s
.3538 .68142 m .35808 .71867 L .3652 .71089 L p .707 .577 .707 r
F P
0 g
s
.3652 .71089 m .36092 .67364 L .3538 .68142 L p .707 .577 .707 r
F P
0 g
s
.36092 .67364 m .3652 .71089 L .3624 .70403 L p .707 .577 .707 r
F P
0 g
s
.3624 .70403 m .35812 .66678 L .36092 .67364 L p .707 .577 .707 r
F P
0 g
s
.35527 .63178 m .36307 .68761 L .36032 .68112 L p .707 .577 .707 r
F P
0 g
s
.36032 .68112 m .35252 .62529 L .35527 .63178 L p .707 .577 .707 r
F P
0 g
s
.35812 .66678 m .3624 .70403 L .34996 .69877 L p .707 .577 .707 r
F P
0 g
s
.34996 .69877 m .34568 .66153 L .35812 .66678 L p .707 .577 .707 r
F P
0 g
s
.35252 .62529 m .36032 .68112 L .34795 .67643 L p .707 .577 .707 r
F P
0 g
s
.36012 .792 m .36315 .29045 L .35906 .27826 L p .707 .577 .707 r
F P
0 g
s
.36315 .29045 m .36012 .792 L .3779 .80332 L p .707 .577 .707 r
F P
0 g
s
.16881 .79989 m .16706 .81814 L .18799 .82727 L p .707 .577 .707 r
F P
0 g
s
.33307 .81758 m .33132 .83583 L .34767 .82894 L p .707 .577 .707 r
F P
0 g
s
.34767 .82894 m .34941 .81069 L .33307 .81758 L p .707 .577 .707 r
F P
0 g
s
.16706 .81814 m .16881 .79989 L .15632 .78988 L p .707 .577 .707 r
F P
0 g
s
.15632 .78988 m .15457 .80814 L .16706 .81814 L p .707 .577 .707 r
F P
0 g
s
.64389 .7866 m .6398 .77442 L p .64238 .59686 L .707 .577 .707 r
F P
0 g
s
.64238 .59686 m .64559 .37583 L .64465 .60277 L .707 .577 .707 r
F
.64238 .59686 m .64465 .60277 L .64389 .7866 L F
.64282 .27286 m .6398 .77442 L .62202 .7631 L p F P
0 g
s
.63626 .57836 m .63351 .57187 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.64282 .27286 m .64691 .28505 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.6398 .77442 m .64164 .46898 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64164 .46898 m .64282 .27286 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64649 .35462 m .64389 .7866 L p .64559 .37583 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .65643 .63887 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63626 .57836 m .63683 .58239 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .64407 .63419 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.64407 .63419 m .63683 .58239 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.63683 .58239 m .63626 .57836 L p .63408 .57524 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .64863 .58305 L .63699 .57863 L p .707 .577 .707 r
F P
0 g
s
.63699 .57863 m .63626 .57836 L p .63692 .58032 L .707 .577 .707 r
F P
0 g
s
.65643 .63887 m .63699 .57863 L .63692 .58032 L .707 .577 .707 r
F
.64691 .28505 m .64649 .35462 L p .64559 .37583 L F P
0 g
s
.34941 .81069 m .34767 .82894 L .35477 .8201 L p .707 .577 .707 r
F P
0 g
s
.35477 .8201 m .35652 .80185 L .34941 .81069 L p .707 .577 .707 r
F P
0 g
s
.35906 .27826 m .35603 .77982 L .36012 .792 L p .707 .577 .707 r
F P
0 g
s
.35603 .77982 m .35906 .27826 L .36906 .26641 L p .707 .577 .707 r
F P
0 g
s
.15457 .80814 m .15632 .78988 L .15349 .77998 L p .707 .577 .707 r
F P
0 g
s
.15349 .77998 m .15174 .79823 L .15457 .80814 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34795 .67643 m .34015 .6206 L .35252 .62529 L p .707 .577 .707 r
F P
0 g
s
.16544 .6848 m .16972 .72204 L .1626 .72983 L p .707 .577 .707 r
F P
0 g
s
.62202 .7631 m .62504 .26154 L .64282 .27286 L p .707 .577 .707 r
F P
0 g
s
.35652 .80185 m .35477 .8201 L .35194 .8102 L p .707 .577 .707 r
F P
0 g
s
.35194 .8102 m .35369 .79195 L .35652 .80185 L p .707 .577 .707 r
F P
0 g
s
.15174 .79823 m .15349 .77998 L .16059 .77115 L p .707 .577 .707 r
F P
0 g
s
.16059 .77115 m .15885 .7894 L .15174 .79823 L p .707 .577 .707 r
F P
0 g
s
.34568 .66153 m .34996 .69877 L .32909 .69563 L p .707 .577 .707 r
F P
0 g
s
.32909 .69563 m .32481 .65838 L .34568 .66153 L p .707 .577 .707 r
F P
0 g
s
.34015 .6206 m .34795 .67643 L .32718 .674 L p .707 .577 .707 r
F P
0 g
s
.32718 .674 m .31938 .61818 L .34015 .6206 L p .707 .577 .707 r
F P
0 g
s
.36603 .76797 m .36906 .26641 L .39217 .25605 L p .707 .577 .707 r
F P
0 g
s
.36906 .26641 m .36603 .76797 L .35603 .77982 L p .707 .577 .707 r
F P
0 g
s
.18177 .67685 m .18605 .7141 L .16972 .72204 L p .707 .577 .707 r
F P
0 g
s
.35369 .79195 m .35194 .8102 L .33945 .80019 L p .707 .577 .707 r
F P
0 g
s
.33945 .80019 m .3412 .78194 L .35369 .79195 L p .707 .577 .707 r
F P
0 g
s
.15885 .7894 m .16059 .77115 L .17694 .76425 L p .707 .577 .707 r
F P
0 g
s
.32481 .65838 m .32909 .69563 L .30185 .6949 L p .707 .577 .707 r
F P
0 g
s
.31938 .61818 m .32718 .674 L .30003 .67407 L p .707 .577 .707 r
F P
0 g
s
.30003 .67407 m .29223 .61825 L .31938 .61818 L p .707 .577 .707 r
F P
0 g
s
.62504 .26154 m .62202 .7631 L .5923 .75374 L p .707 .577 .707 r
F P
0 g
s
.5923 .75374 m .59532 .25219 L .62504 .26154 L p .707 .577 .707 r
F P
0 g
s
.17694 .76425 m .17519 .7825 L .15885 .7894 L p .707 .577 .707 r
F P
0 g
s
.20573 .66951 m .21001 .70676 L .18605 .7141 L p .707 .577 .707 r
F P
0 g
s
.73521 .63867 m .72741 .58284 L .69655 .5854 L p .707 .577 .707 r
F P
0 g
s
.72741 .58284 m .73521 .63867 L .76677 .63386 L p .707 .577 .707 r
F P
0 g
s
.76677 .63386 m .75896 .57804 L .72741 .58284 L p .707 .577 .707 r
F P
0 g
s
.39217 .25605 m .38914 .75761 L .36603 .76797 L p .707 .577 .707 r
F P
0 g
s
.38914 .75761 m .39217 .25605 L .42612 .2482 L p .707 .577 .707 r
F P
0 g
s
.75896 .57804 m .76677 .63386 L .79593 .62729 L p .707 .577 .707 r
F P
0 g
s
.79593 .62729 m .78812 .57146 L .75896 .57804 L p .707 .577 .707 r
F P
0 g
s
.3412 .78194 m .33945 .80019 L .31852 .79107 L p .707 .577 .707 r
F P
0 g
s
.31852 .79107 m .32027 .77282 L .3412 .78194 L p .707 .577 .707 r
F P
0 g
s
.70435 .64123 m .69655 .5854 L .66941 .58547 L p .707 .577 .707 r
F P
0 g
s
.69655 .5854 m .70435 .64123 L .73521 .63867 L p .707 .577 .707 r
F P
0 g
s
.29757 .65766 m .30185 .6949 L .27088 .69667 L p .707 .577 .707 r
F P
0 g
s
.17519 .7825 m .17694 .76425 L .20093 .75996 L p .707 .577 .707 r
F P
0 g
s
.23496 .66351 m .23924 .70076 L .21001 .70676 L p .707 .577 .707 r
F P
0 g
s
.78812 .57146 m .79593 .62729 L .81983 .61959 L p .707 .577 .707 r
F P
0 g
s
.81983 .61959 m .81203 .56376 L .78812 .57146 L p .707 .577 .707 r
F P
0 g
s
.20093 .75996 m .19918 .77821 L .17519 .7825 L p .707 .577 .707 r
F P
0 g
s
.2666 .65942 m .27088 .69667 L .23924 .70076 L p .707 .577 .707 r
F P
0 g
s
.59532 .25219 m .5923 .75374 L .55353 .74727 L p .707 .577 .707 r
F P
0 g
s
.55353 .74727 m .55655 .24572 L .59532 .25219 L p .707 .577 .707 r
F P
0 g
s
.66941 .58547 m .67721 .6413 L .70435 .64123 L p .707 .577 .707 r
F P
0 g
s
.67721 .6413 m .66941 .58547 L .64863 .58305 L p .707 .577 .707 r
F P
0 g
s
.32027 .77282 m .31852 .79107 L .2912 .78371 L p .707 .577 .707 r
F P
0 g
s
.2912 .78371 m .29295 .76546 L .32027 .77282 L p .707 .577 .707 r
F P
0 g
s
.4231 .74975 m .42612 .2482 L .4676 .24362 L p .707 .577 .707 r
F P
0 g
s
.42612 .2482 m .4231 .74975 L .38914 .75761 L p .707 .577 .707 r
F P
0 g
s
.19918 .77821 m .20093 .75996 L .23021 .7587 L p .707 .577 .707 r
F P
0 g
s
.73713 .74007 m .73285 .70283 L .70189 .70459 L p .707 .577 .707 r
F P
0 g
s
.73285 .70283 m .73713 .74007 L .76877 .73599 L p .707 .577 .707 r
F P
0 g
s
.76877 .73599 m .76449 .69874 L .73285 .70283 L p .707 .577 .707 r
F P
0 g
s
.81203 .56376 m .81983 .61959 L .83615 .61151 L p .707 .577 .707 r
F P
0 g
s
.83615 .61151 m .82835 .55568 L .81203 .56376 L p .707 .577 .707 r
F P
0 g
s
.76449 .69874 m .76877 .73599 L .798 .72998 L p .707 .577 .707 r
F P
0 g
s
.798 .72998 m .79372 .69274 L .76449 .69874 L p .707 .577 .707 r
F P
0 g
s
.23021 .7587 m .22846 .77695 L .19918 .77821 L p .707 .577 .707 r
F P
0 g
s
.64863 .58305 m .65643 .63887 L .67721 .6413 L p .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70189 .70459 L .70027 .70455 L p .707 .577 .707 r
F P
0 g
s
.70048 .71685 m .69727 .71635 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70617 .74184 m .70027 .70455 L .7008 .73538 L .707 .577 .707 r
F
.70189 .70459 m .70617 .74184 L .73713 .74007 L p F P
0 g
s
.69727 .71635 m .69552 .7346 L .7008 .73542 L p .707 .577 .707 r
F P
0 g
s
.70091 .7417 m .70617 .74184 L p .7008 .73538 L .707 .577 .707 r
F P
0 g
s
.7008 .73542 m .72655 .73946 L p .70052 .71891 L .707 .577 .707 r
F P
0 g
s
.70052 .71891 m .69727 .71635 L .7008 .73542 L .707 .577 .707 r
F
.69552 .7346 m .69727 .71635 L .66995 .70899 L p F P
0 g
s
.66995 .70899 m .66821 .72724 L .69552 .7346 L p .707 .577 .707 r
F P
0 g
s
.67464 .70387 m .67892 .74112 L .70091 .7417 L p .707 .577 .707 r
F P
0 g
s
.7008 .73538 m .67464 .70387 L .70091 .7417 L .707 .577 .707 r
F
.70027 .70455 m .67464 .70387 L p .7008 .73538 L F P
0 g
s
.72655 .73946 m .7283 .72121 L .70048 .71685 L p .707 .577 .707 r
F P
0 g
s
.72655 .73946 m .70048 .71685 L .70052 .71891 L .707 .577 .707 r
F
.7283 .72121 m .72655 .73946 L .75826 .74135 L p F P
0 g
s
.75826 .74135 m .76001 .7231 L .7283 .72121 L p .707 .577 .707 r
F P
0 g
s
.55655 .24572 m .55353 .74727 L .50952 .74432 L p .707 .577 .707 r
F P
0 g
s
.50952 .74432 m .51255 .24277 L .55655 .24572 L p .707 .577 .707 r
F P
0 g
s
.29295 .76546 m .2912 .78371 L .26017 .77885 L p .707 .577 .707 r
F P
0 g
s
.26017 .77885 m .26192 .7606 L .29295 .76546 L p .707 .577 .707 r
F P
0 g
s
.76001 .7231 m .75826 .74135 L .78754 .7401 L p .707 .577 .707 r
F P
0 g
s
.78754 .7401 m .78929 .72185 L .76001 .7231 L p .707 .577 .707 r
F P
0 g
s
.22846 .77695 m .23021 .7587 L .26192 .7606 L p .707 .577 .707 r
F P
0 g
s
.79372 .69274 m .798 .72998 L .82196 .72265 L p .707 .577 .707 r
F P
0 g
s
.82196 .72265 m .81768 .6854 L .79372 .69274 L p .707 .577 .707 r
F P
0 g
s
.46458 .74518 m .4676 .24362 L .51255 .24277 L p .707 .577 .707 r
F P
0 g
s
.4676 .24362 m .46458 .74518 L .4231 .74975 L p .707 .577 .707 r
F P
0 g
s
.26192 .7606 m .26017 .77885 L .22846 .77695 L p .707 .577 .707 r
F P
0 g
s
.51255 .24277 m .50952 .74432 L .46458 .74518 L p .707 .577 .707 r
F P
0 g
s
.78929 .72185 m .78754 .7401 L .81153 .73581 L p .707 .577 .707 r
F P
0 g
s
.81153 .73581 m .81328 .71756 L .78929 .72185 L p .707 .577 .707 r
F P
0 g
s
.66821 .72724 m .66995 .70899 L .64903 .69986 L p .707 .577 .707 r
F P
0 g
s
.67892 .74112 m .67464 .70387 L .65377 .70072 L p .707 .577 .707 r
F P
0 g
s
.82835 .55568 m .83615 .61151 L .84329 .60385 L p .707 .577 .707 r
F P
0 g
s
.84329 .60385 m .83548 .54803 L .82835 .55568 L p .707 .577 .707 r
F P
0 g
s
.64903 .69986 m .64728 .71811 L .66821 .72724 L p .707 .577 .707 r
F P
0 g
s
.65377 .70072 m .65805 .73797 L .67892 .74112 L p .707 .577 .707 r
F P
0 g
s
.81768 .6854 m .82196 .72265 L .8383 .7147 L p .707 .577 .707 r
F P
0 g
s
.8383 .7147 m .83402 .67745 L .81768 .6854 L p .707 .577 .707 r
F P
0 g
s
.81328 .71756 m .81153 .73581 L .82788 .72891 L p .707 .577 .707 r
F P
0 g
s
.82788 .72891 m .82963 .71066 L .81328 .71756 L p .707 .577 .707 r
F P
0 g
s
.64728 .71811 m .64903 .69986 L .63653 .68986 L p .707 .577 .707 r
F P
0 g
s
.65805 .73797 m .65377 .70072 L .64133 .69547 L p .707 .577 .707 r
F P
0 g
s
.63653 .68986 m .63479 .70811 L .64728 .71811 L p .707 .577 .707 r
F P
0 g
s
.64133 .69547 m .64561 .73271 L .65805 .73797 L p .707 .577 .707 r
F P
0 g
s
.83548 .54803 m .84329 .60385 L .84053 .59736 L p .707 .577 .707 r
F P
0 g
s
.84053 .59736 m .83273 .54154 L .83548 .54803 L p .707 .577 .707 r
F P
0 g
s
.63351 .57187 m .64131 .6277 L .64407 .63419 L p .707 .577 .707 r
F P
0 g
s
.83402 .67745 m .8383 .7147 L .84541 .70692 L p .707 .577 .707 r
F P
0 g
s
.84541 .70692 m .84113 .66967 L .83402 .67745 L p .707 .577 .707 r
F P
0 g
s
.82963 .71066 m .82788 .72891 L .83499 .72008 L p .707 .577 .707 r
F P
0 g
s
.83499 .72008 m .83673 .70183 L .82963 .71066 L p .707 .577 .707 r
F P
0 g
s
.64561 .73271 m .64133 .69547 L .63853 .68861 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63479 .70811 m .63653 .68986 L .6337 .67995 L p .707 .577 .707 r
F P
0 g
s
.64131 .6277 m .63351 .57187 L .64064 .56421 L p .707 .577 .707 r
F P
0 g
s
.6337 .67995 m .63195 .69821 L .63479 .70811 L p .707 .577 .707 r
F P
0 g
s
.63853 .68861 m .64281 .72586 L .64561 .73271 L p .707 .577 .707 r
F P
0 g
s
.83273 .54154 m .84053 .59736 L .82817 .59268 L p .707 .577 .707 r
F P
0 g
s
.82817 .59268 m .82036 .53685 L .83273 .54154 L p .707 .577 .707 r
F P
0 g
s
.84113 .66967 m .84541 .70692 L .84261 .70006 L p .707 .577 .707 r
F P
0 g
s
.84261 .70006 m .83833 .66281 L .84113 .66967 L p .707 .577 .707 r
F P
0 g
s
.64064 .56421 m .64845 .62004 L .64131 .6277 L p .707 .577 .707 r
F P
0 g
s
.83673 .70183 m .83499 .72008 L .83215 .71017 L p .707 .577 .707 r
F P
0 g
s
.83215 .71017 m .8339 .69192 L .83673 .70183 L p .707 .577 .707 r
F P
0 g
s
.63195 .69821 m .6337 .67995 L .64081 .67112 L p .707 .577 .707 r
F P
0 g
s
.64845 .62004 m .64064 .56421 L .65696 .55614 L p .707 .577 .707 r
F P
0 g
s
.64281 .72586 m .63853 .68861 L .64565 .68083 L p .707 .577 .707 r
F P
0 g
s
.3922 .63038 m .3844 .57456 L .35354 .57712 L p .707 .577 .707 r
F P
0 g
s
.3844 .57456 m .3922 .63038 L .42376 .62558 L p .707 .577 .707 r
F P
0 g
s
.42376 .62558 m .41595 .56975 L .3844 .57456 L p .707 .577 .707 r
F P
0 g
s
.41595 .56975 m .42376 .62558 L .45292 .619 L p .707 .577 .707 r
F P
0 g
s
.45292 .619 m .44511 .56318 L .41595 .56975 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64081 .67112 m .63906 .68937 L .63195 .69821 L p .707 .577 .707 r
F P
0 g
s
.36134 .63295 m .35808 .60959 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.35354 .57712 m .36134 .63295 L .3922 .63038 L p .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .38984 .61476 L .35897 .61652 L p .707 .577 .707 r
F P
0 g
s
.35897 .61652 m .35888 .61653 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.39412 .65201 m .35897 .61652 L .35898 .61663 L .707 .577 .707 r
F
.36316 .65377 m .35888 .61653 L .33185 .61581 L p F P
0 g
s
.33185 .61581 m .33163 .6158 L p .3319 .61612 L .707 .577 .707 r
F P
0 g
s
.36316 .65377 m .33185 .61581 L .3319 .61612 L .707 .577 .707 r
F
.33163 .6158 m .33591 .65305 L .36316 .65377 L p F P
0 g
s
.33591 .65305 m .33163 .6158 L .31101 .61269 L p .707 .577 .707 r
F P
0 g
s
.31101 .61269 m .31076 .61266 L p .31109 .61318 L .707 .577 .707 r
F P
0 g
s
.33591 .65305 m .31101 .61269 L .31109 .61318 L .707 .577 .707 r
F
.31076 .61266 m .31504 .6499 L .33591 .65305 L p F P
0 g
s
.31504 .6499 m .31076 .61266 L .2985 .60747 L p .707 .577 .707 r
F P
0 g
s
.2985 .60747 m .29832 .6074 L p .29859 .60807 L .707 .577 .707 r
F P
0 g
s
.31504 .6499 m .2985 .60747 L .29859 .60807 L .707 .577 .707 r
F
.29832 .6074 m .3026 .64465 L .31504 .6499 L p F P
0 g
s
.3026 .64465 m .29832 .6074 L .29557 .60065 L p .707 .577 .707 r
F P
0 g
s
.29557 .60065 m .29552 .60054 L p .29564 .6013 L .707 .577 .707 r
F P
0 g
s
.3026 .64465 m .29557 .60065 L .29564 .6013 L .707 .577 .707 r
F
.30106 .6259 m .29765 .6015 L p .2905 .56359 L F P
0 g
s
.29765 .6015 m .29325 .57008 L .29309 .56968 L p .707 .577 .707 r
F P
0 g
s
.29309 .56968 m .2905 .56359 L p .29765 .6015 L .707 .577 .707 r
F P
0 g
s
.31342 .63059 m .31005 .60648 L p .29325 .57008 L .707 .577 .707 r
F P
0 g
s
.30514 .57458 m .29325 .57008 L p .31005 .60648 L .707 .577 .707 r
F P
0 g
s
.29325 .57008 m .30106 .6259 L .31342 .63059 L p .707 .577 .707 r
F P
0 g
s
.29552 .60054 m .2998 .63779 L .3026 .64465 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .30106 .6259 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2905 .56359 m .29487 .59483 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.29487 .59483 m .2983 .61941 L p .29127 .56814 L .707 .577 .707 r
F P
0 g
s
.2998 .63779 m .29552 .60054 L .29562 .60043 L p .707 .577 .707 r
F P
0 g
s
.2983 .61941 m .29487 .59483 L p .29763 .55593 L .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .2983 .61941 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.29763 .55593 m .30199 .58711 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.30199 .58711 m .30544 .61175 L p .29768 .56056 L .707 .577 .707 r
F P
0 g
s
.31005 .60648 m .30562 .57476 L .30514 .57458 L p .707 .577 .707 r
F P
0 g
s
.3342 .63302 m .33088 .60926 L p .30562 .57476 L .707 .577 .707 r
F P
0 g
s
.32611 .57716 m .30562 .57476 L p .33088 .60926 L .707 .577 .707 r
F P
0 g
s
.30562 .57476 m .31342 .63059 L .3342 .63302 L p .707 .577 .707 r
F P
0 g
s
.30544 .61175 m .29763 .55593 L .31395 .54785 L p .707 .577 .707 r
F P
0 g
s
.30692 .63001 m .30264 .59276 L .30289 .59264 L p .707 .577 .707 r
F P
0 g
s
.32176 .60368 m .30544 .61175 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31395 .54785 m .31832 .5791 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.31832 .5791 m .32176 .60368 L p .31338 .55212 L .707 .577 .707 r
F P
0 g
s
.33088 .60926 m .3264 .57719 L .32611 .57716 L p .707 .577 .707 r
F P
0 g
s
.35888 .61653 m .36316 .65377 L .36374 .65374 L p .707 .577 .707 r
F P
0 g
s
.36107 .63295 m .36134 .63295 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.36374 .65374 m .39412 .65201 L p .35898 .61663 L .707 .577 .707 r
F P
0 g
s
.35898 .61663 m .35888 .61653 L .36374 .65374 L .707 .577 .707 r
F
.3264 .57719 m .3342 .63302 L .36107 .63295 L p F P
0 g
s
.361 .6324 m .3264 .57719 L .36107 .63295 L .707 .577 .707 r
F
.35354 .57712 m .3264 .57719 L p .361 .6324 L F P
0 g
s
.32176 .60368 m .31395 .54785 L .33786 .54015 L p .707 .577 .707 r
F P
0 g
s
.32326 .62206 m .31898 .58481 L .31934 .5847 L p .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .32176 .60368 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.33786 .54015 m .34225 .57158 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34225 .57158 m .34566 .59598 L p .33698 .54362 L .707 .577 .707 r
F P
0 g
s
.34566 .59598 m .33786 .54015 L .36702 .53358 L p .707 .577 .707 r
F P
0 g
s
.34721 .61472 m .34293 .57747 L .34335 .57739 L p .707 .577 .707 r
F P
0 g
s
.35808 .60959 m .35354 .57712 L p .361 .6324 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .34566 .59598 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.36702 .53358 m .37145 .56529 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37145 .56529 m .37482 .5894 L p .36624 .53587 L .707 .577 .707 r
F P
0 g
s
.37482 .5894 m .36702 .53358 L .39857 .52877 L p .707 .577 .707 r
F P
0 g
s
.37644 .60872 m .37216 .57147 L .37254 .57142 L p .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .37482 .5894 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.39857 .52877 m .40306 .56084 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40306 .56084 m .40638 .5846 L p .39826 .52958 L .707 .577 .707 r
F P
0 g
s
.40638 .5846 m .39857 .52877 L .42943 .52621 L p .707 .577 .707 r
F P
0 g
s
.40809 .60463 m .40381 .56738 L .40406 .56737 L p .707 .577 .707 r
F P
0 g
s
.42943 .52621 m .43397 .55868 L p .40638 .5846 L .707 .577 .707 r
F P
0 g
s
.44511 .56318 m .45292 .619 L .47682 .6113 L p .707 .577 .707 r
F P
0 g
s
.47682 .6113 m .46902 .55548 L .44511 .56318 L p .707 .577 .707 r
F P
0 g
s
.43485 .56562 m .46202 .56634 L p .43947 .60219 L .707 .577 .707 r
F P
0 g
s
.43397 .55868 m .43724 .58204 L .43693 .58206 L p .707 .577 .707 r
F P
0 g
s
.43693 .58206 m .40638 .5846 L p .43397 .55868 L .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43477 .56562 L .43485 .56562 L p .707 .577 .707 r
F P
0 g
s
.43905 .60286 m .43485 .56562 L .43947 .60219 L .707 .577 .707 r
F
.40406 .56737 m .43477 .56562 L p .40947 .60261 L F P
0 g
s
.40809 .60463 m .40406 .56737 L .40947 .60261 L .707 .577 .707 r
F
.37254 .57142 m .40381 .56738 L p .37858 .60549 L F P
0 g
s
.37644 .60872 m .37254 .57142 L .37858 .60549 L .707 .577 .707 r
F
.34335 .57739 m .37216 .57147 L p .34961 .61057 L F P
0 g
s
.34721 .61472 m .34335 .57739 L .34961 .61057 L .707 .577 .707 r
F
.31934 .5847 m .34293 .57747 L p .32532 .61737 L F P
0 g
s
.32326 .62206 m .31934 .5847 L .32532 .61737 L .707 .577 .707 r
F
.30289 .59264 m .31898 .58481 L p .30818 .62526 L F P
0 g
s
.30692 .63001 m .30289 .59264 L .30818 .62526 L .707 .577 .707 r
F
.29562 .60043 m .30264 .59276 L p .30007 .63348 L F P
0 g
s
.2998 .63779 m .29562 .60043 L .30007 .63348 L .707 .577 .707 r
F
.29487 .59483 m .2905 .56359 L .29104 .563 L p F P
0 g
s
.29104 .563 m .29763 .55593 L p .29487 .59483 L .707 .577 .707 r
F P
0 g
s
.64565 .68083 m .64993 .71807 L .64281 .72586 L p .707 .577 .707 r
F P
0 g
s
.38984 .61476 m .39412 .65201 L .42576 .64792 L p .707 .577 .707 r
F P
0 g
s
.42576 .64792 m .42148 .61067 L .38984 .61476 L p .707 .577 .707 r
F P
0 g
s
.82036 .53685 m .82817 .59268 L .80739 .59025 L p .707 .577 .707 r
F P
0 g
s
.80739 .59025 m .79959 .53442 L .82036 .53685 L p .707 .577 .707 r
F P
0 g
s
.42148 .61067 m .42576 .64792 L .45499 .64192 L p .707 .577 .707 r
F P
0 g
s
.45499 .64192 m .45071 .60467 L .42148 .61067 L p .707 .577 .707 r
F P
0 g
s
.65696 .55614 m .66477 .61196 L .64845 .62004 L p .707 .577 .707 r
F P
0 g
s
.8339 .69192 m .83215 .71017 L .81966 .70017 L p .707 .577 .707 r
F P
0 g
s
.81966 .70017 m .82141 .68192 L .8339 .69192 L p .707 .577 .707 r
F P
0 g
s
.83833 .66281 m .84261 .70006 L .83017 .6948 L p .707 .577 .707 r
F P
0 g
s
.83017 .6948 m .82589 .65755 L .83833 .66281 L p .707 .577 .707 r
F P
0 g
s
.45071 .60467 m .45499 .64192 L .47895 .63458 L p .707 .577 .707 r
F P
0 g
s
.47895 .63458 m .47467 .59733 L .45071 .60467 L p .707 .577 .707 r
F P
0 g
s
.66477 .61196 m .65696 .55614 L .68087 .54844 L p .707 .577 .707 r
F P
0 g
s
.63906 .68937 m .64081 .67112 L .65715 .66422 L p .707 .577 .707 r
F P
0 g
s
.64993 .71807 m .64565 .68083 L .66199 .67288 L p .707 .577 .707 r
F P
0 g
s
.46902 .55548 m .47682 .6113 L .49314 .60323 L p .707 .577 .707 r
F P
0 g
s
.49314 .60323 m .48534 .5474 L .46902 .55548 L p .707 .577 .707 r
F P
0 g
s
.79959 .53442 m .80739 .59025 L .78025 .59032 L p .707 .577 .707 r
F P
0 g
s
.78025 .59032 m .77244 .53449 L .79959 .53442 L p .707 .577 .707 r
F P
0 g
s
.65715 .66422 m .65541 .68247 L .63906 .68937 L p .707 .577 .707 r
F P
0 g
s
.68087 .54844 m .68868 .60426 L .66477 .61196 L p .707 .577 .707 r
F P
0 g
s
.66199 .67288 m .66627 .71012 L .64993 .71807 L p .707 .577 .707 r
F P
0 g
s
.82141 .68192 m .81966 .70017 L .79873 .69104 L p .707 .577 .707 r
F P
0 g
s
.79873 .69104 m .80048 .67279 L .82141 .68192 L p .707 .577 .707 r
F P
0 g
s
.82589 .65755 m .83017 .6948 L .80931 .69166 L p .707 .577 .707 r
F P
0 g
s
.80931 .69166 m .80503 .65441 L .82589 .65755 L p .707 .577 .707 r
F P
0 g
s
.47467 .59733 m .47895 .63458 L .49529 .62663 L p .707 .577 .707 r
F P
0 g
s
.49529 .62663 m .49101 .58939 L .47467 .59733 L p .707 .577 .707 r
F P
0 g
s
.38354 .74745 m .38529 .7292 L .35426 .72433 L p .707 .577 .707 r
F P
0 g
s
.38529 .7292 m .38354 .74745 L .41525 .74934 L p .707 .577 .707 r
F P
0 g
s
.41525 .74934 m .417 .73109 L .38529 .7292 L p .707 .577 .707 r
F P
0 g
s
.68868 .60426 m .68087 .54844 L .71003 .54186 L p .707 .577 .707 r
F P
0 g
s
.417 .73109 m .41525 .74934 L .44453 .74808 L p .707 .577 .707 r
F P
0 g
s
.44453 .74808 m .44628 .72983 L .417 .73109 L p .707 .577 .707 r
F P
0 g
s
.35426 .72433 m .35251 .74258 L .38354 .74745 L p .707 .577 .707 r
F P
0 g
s
.35251 .74258 m .35426 .72433 L .32694 .71698 L p .707 .577 .707 r
F P
0 g
s
.77244 .53449 m .78025 .59032 L .74939 .59288 L p .707 .577 .707 r
F P
0 g
s
.74939 .59288 m .74158 .53706 L .77244 .53449 L p .707 .577 .707 r
F P
0 g
s
.32694 .71698 m .3252 .73523 L .35251 .74258 L p .707 .577 .707 r
F P
0 g
s
.66627 .71012 m .66199 .67288 L .68594 .66554 L p .707 .577 .707 r
F P
0 g
s
.65541 .68247 m .65715 .66422 L .68114 .65993 L p .707 .577 .707 r
F P
0 g
s
.71783 .59769 m .71003 .54186 L .74158 .53706 L p .707 .577 .707 r
F P
0 g
s
.71003 .54186 m .71783 .59769 L .68868 .60426 L p .707 .577 .707 r
F P
0 g
s
.74158 .53706 m .74939 .59288 L .71783 .59769 L p .707 .577 .707 r
F P
0 g
s
.44628 .72983 m .44453 .74808 L .46852 .7438 L p .707 .577 .707 r
F P
0 g
s
.46852 .7438 m .47027 .72555 L .44628 .72983 L p .707 .577 .707 r
F P
0 g
s
.48534 .5474 m .49314 .60323 L .50028 .59557 L p .707 .577 .707 r
F P
0 g
s
.50028 .59557 m .49247 .53974 L .48534 .5474 L p .707 .577 .707 r
F P
0 g
s
.68114 .65993 m .67939 .67819 L .65541 .68247 L p .707 .577 .707 r
F P
0 g
s
.3252 .73523 m .32694 .71698 L .30602 .70785 L p .707 .577 .707 r
F P
0 g
s
.68594 .66554 m .69022 .70279 L .66627 .71012 L p .707 .577 .707 r
F P
0 g
s
.80048 .67279 m .79873 .69104 L .77607 .68494 L p .707 .577 .707 r
F P
0 g
s
.77609 .69127 m .7511 .6927 L p .77595 .65636 L .707 .577 .707 r
F P
0 g
s
.77607 .68494 m .77142 .68369 L p .77605 .68195 L .707 .577 .707 r
F P
0 g
s
.77605 .68195 m .80048 .67279 L .77607 .68494 L .707 .577 .707 r
F
.77142 .68369 m .77316 .66544 L .80048 .67279 L p F P
0 g
s
.77778 .65368 m .78206 .69093 L .77609 .69127 L p .707 .577 .707 r
F P
0 g
s
.77595 .65636 m .77778 .65368 L .77609 .69127 L .707 .577 .707 r
F
.80503 .65441 m .80931 .69166 L .78206 .69093 L p F P
0 g
s
.78206 .69093 m .77778 .65368 L .80503 .65441 L p .707 .577 .707 r
F P
0 g
s
.49101 .58939 m .49529 .62663 L .5024 .61885 L p .707 .577 .707 r
F P
0 g
s
.5024 .61885 m .49812 .5816 L .49101 .58939 L p .707 .577 .707 r
F P
0 g
s
.30602 .70785 m .30427 .7261 L .3252 .73523 L p .707 .577 .707 r
F P
0 g
s
.69022 .70279 m .68594 .66554 L .71517 .65954 L p .707 .577 .707 r
F P
0 g
s
.67939 .67819 m .68114 .65993 L .71042 .65868 L p .707 .577 .707 r
F P
0 g
s
.47027 .72555 m .46852 .7438 L .48487 .7369 L p .707 .577 .707 r
F P
0 g
s
.48487 .7369 m .48662 .71865 L .47027 .72555 L p .707 .577 .707 r
F P
0 g
s
.7511 .6927 m .74682 .65545 L .77778 .65368 L p .707 .577 .707 r
F P
0 g
s
.71517 .65954 m .71945 .69678 L .69022 .70279 L p .707 .577 .707 r
F P
0 g
s
.71042 .65868 m .70868 .67693 L .67939 .67819 L p .707 .577 .707 r
F P
0 g
s
.30427 .7261 m .30602 .70785 L .29352 .69785 L p .707 .577 .707 r
F P
0 g
s
.74682 .65545 m .7511 .6927 L .71945 .69678 L p .707 .577 .707 r
F P
0 g
s
.77316 .66544 m .77142 .68369 L .74038 .67882 L p .707 .577 .707 r
F P
0 g
s
.71945 .69678 m .71517 .65954 L .74682 .65545 L p .707 .577 .707 r
F P
0 g
s
.74038 .67882 m .74213 .66057 L .77316 .66544 L p .707 .577 .707 r
F P
0 g
s
.70868 .67693 m .71042 .65868 L .74213 .66057 L p .707 .577 .707 r
F P
0 g
s
.49812 .5816 m .5024 .61885 L .4996 .61199 L p .707 .577 .707 r
F P
0 g
s
.4996 .61199 m .49532 .57475 L .49812 .5816 L p .707 .577 .707 r
F P
0 g
s
.49247 .53974 m .50028 .59557 L .49752 .58908 L p .707 .577 .707 r
F P
0 g
s
.49752 .58908 m .48972 .53325 L .49247 .53974 L p .707 .577 .707 r
F P
0 g
s
.29352 .69785 m .29178 .7161 L .30427 .7261 L p .707 .577 .707 r
F P
0 g
s
.74213 .66057 m .74038 .67882 L .70868 .67693 L p .707 .577 .707 r
F P
0 g
s
.48662 .71865 m .48487 .7369 L .49198 .72806 L p .707 .577 .707 r
F P
0 g
s
.49198 .72806 m .49372 .70981 L .48662 .71865 L p .707 .577 .707 r
F P
0 g
s
.29178 .7161 m .29352 .69785 L .29069 .68794 L p .707 .577 .707 r
F P
0 g
s
.29069 .68794 m .28894 .70619 L .29178 .7161 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49532 .57475 m .4996 .61199 L .48716 .60673 L p .707 .577 .707 r
F P
0 g
s
.48716 .60673 m .48288 .56949 L .49532 .57475 L p .707 .577 .707 r
F P
0 g
s
.48972 .53325 m .49752 .58908 L .48516 .58439 L p .707 .577 .707 r
F P
0 g
s
.48516 .58439 m .47735 .52856 L .48972 .53325 L p .707 .577 .707 r
F P
0 g
s
.30264 .59276 m .30692 .63001 L .2998 .63779 L p .707 .577 .707 r
F P
0 g
s
.49372 .70981 m .49198 .72806 L .48914 .71816 L p .707 .577 .707 r
F P
0 g
s
.48914 .71816 m .49089 .69991 L .49372 .70981 L p .707 .577 .707 r
F P
0 g
s
.28894 .70619 m .29069 .68794 L .2978 .67911 L p .707 .577 .707 r
F P
0 g
s
.2978 .67911 m .29605 .69736 L .28894 .70619 L p .707 .577 .707 r
F P
0 g
s
.48288 .56949 m .48716 .60673 L .4663 .60359 L p .707 .577 .707 r
F P
0 g
s
.4663 .60359 m .46202 .56634 L .48288 .56949 L p .707 .577 .707 r
F P
0 g
s
.47735 .52856 m .48516 .58439 L .46438 .58196 L p .707 .577 .707 r
F P
0 g
s
.46438 .58196 m .45658 .52614 L .47735 .52856 L p .707 .577 .707 r
F P
0 g
s
.31898 .58481 m .32326 .62206 L .30692 .63001 L p .707 .577 .707 r
F P
0 g
s
.49089 .69991 m .48914 .71816 L .47665 .70815 L p .707 .577 .707 r
F P
0 g
s
.47665 .70815 m .4784 .6899 L .49089 .69991 L p .707 .577 .707 r
F P
0 g
s
.29605 .69736 m .2978 .67911 L .31414 .67221 L p .707 .577 .707 r
F P
0 g
s
.46202 .56634 m .4663 .60359 L .43905 .60286 L p .707 .577 .707 r
F P
0 g
s
.45658 .52614 m .46438 .58196 L .43724 .58204 L p .707 .577 .707 r
F P
0 g
s
.43724 .58204 m .42943 .52621 L .45658 .52614 L p .707 .577 .707 r
F P
0 g
s
.31414 .67221 m .3124 .69046 L .29605 .69736 L p .707 .577 .707 r
F P
0 g
s
.34293 .57747 m .34721 .61472 L .32326 .62206 L p .707 .577 .707 r
F P
0 g
s
.4784 .6899 m .47665 .70815 L .45572 .69903 L p .707 .577 .707 r
F P
0 g
s
.45572 .69903 m .45747 .68078 L .4784 .6899 L p .707 .577 .707 r
F P
0 g
s
.43477 .56562 m .43905 .60286 L .40809 .60463 L p .707 .577 .707 r
F P
0 g
s
.3124 .69046 m .31414 .67221 L .33813 .66792 L p .707 .577 .707 r
F P
0 g
s
.37216 .57147 m .37644 .60872 L .34721 .61472 L p .707 .577 .707 r
F P
0 g
s
.33813 .66792 m .33638 .68617 L .3124 .69046 L p .707 .577 .707 r
F P
0 g
s
.40381 .56738 m .40809 .60463 L .37644 .60872 L p .707 .577 .707 r
F P
0 g
s
.45747 .68078 m .45572 .69903 L .42841 .69167 L p .707 .577 .707 r
F P
0 g
s
.42841 .69167 m .43015 .67342 L .45747 .68078 L p .707 .577 .707 r
F P
0 g
s
.33638 .68617 m .33813 .66792 L .36741 .66666 L p .707 .577 .707 r
F P
0 g
s
.36741 .66666 m .36567 .68491 L .33638 .68617 L p .707 .577 .707 r
F P
0 g
s
.43015 .67342 m .42841 .69167 L .39737 .68681 L p .707 .577 .707 r
F P
0 g
s
.39737 .68681 m .39912 .66856 L .43015 .67342 L p .707 .577 .707 r
F P
0 g
s
.36567 .68491 m .36741 .66666 L .39912 .66856 L p .707 .577 .707 r
F P
0 g
s
.39912 .66856 m .39737 .68681 L .36567 .68491 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00Igoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001V
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Io
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01EYF3`00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool01000FUIJEP0015YF2@0015YF00<005YFFUH015YF00<005YFFUH01@001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH000050004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006=oo`@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000HOolJ000cOol0
05moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3000DOol40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000aOol005]o
o`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
009JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH3000>Ool60006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<7oo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0027oo1P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo001GOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001Woo0P00
00=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUH005YF02moo`00EGoo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000Aoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EP00FUH_Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00IJEP03001JEUYF009J
EPD000MJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059o
o`03001JEP0000=JEP03OomJEP0000IJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`04001J
EP000002FUH00gooFUH00006FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06FUH20006FUH00`00
FUIJEP02FUH20002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00
FUIJEUYF001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001J
EUYF009JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol01000FUIJEP00
15YF00<005YFFUH00eYF10001EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001eYF00<005YFFUH0
0UYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Woo001COol2FUH00`00FUIJEP02
FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH<0002FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Woo001COol2FUH00`00FUIJEP02FUH20005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF000025YF00<005YFFUH015YF00@005YFFUIJ
EP@0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`9JEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP04001JEUYF000^
Ool005=oo`9JEP<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00=JEPH00003FUH0000002eoo`00Dgoo00@005YF
000000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00AJEPX000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool005=oo`800003FUH005YF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP040005FUH60003FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool005=oo`04001JEUYF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH00`00FUIJEP0200000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH50008FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000]Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005
FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH40003FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF0P0015YF00<005YFFUH0
1UYF1P000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001DOol2FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH70006FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000AJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0003FUH01000FUH000001UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;Goo001DOol3FUH20002FUH00`00
FUIJEP03FUH60004FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000eYF
0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUH0031oo`00Cgoo1@000eYF00H005YFFUIJEP00FUH40005FUH50003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF008000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<0035oo`00
AWoo2@0015YF0P000UYF00@005YFFUIJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP8003=oo`00@7oo
1P0015YF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000e
Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>Goo
000hOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00<005YFFUH0
35YF1@001EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003eoo`00=7oo100000=JEP00FUH0
1EYF00=oo`00FUH01eYF00<005YFFUH01UYF10000UYF00<005YFFUH02`001eYF1@001EYF00<005YF
FUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70011Ool0039oo`8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<0
009JEP03001JEUYF00=JEP03001JEUYF00aJEPD000EJEP03001JEUYF00IJEP03001JEP0000<000UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH4
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80018Ool0031oo`<000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF00=JEP03001JEUYF00eJEP<000MJEP03
001JEUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEQ40051oo`00;Woo0P000UYF00<005YFFUH015YF00<005YF
FUH00eYF00AooeYFFUH000QJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH03UYF
00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YF001J
EUIoo`00;Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00iJEP03001JEUYF009JEPL000QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000EJEP03001JEUYF00=JEP04001JEP00FUIFOol002aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEQT000=JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF000BOol8000lOol002]oo`03001JEP0000EJ
EP03001JEUYF00AJEP05001JEUYFFUIoo`03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0027oo2@0015YF00@005YF
FUIJEPX0039oo`00:goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF3P001eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEQP000QJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031o
o`00:goo00<005YF00000eYF00=ooeYF00001UYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF
0P001UYF00<005YFFUH00UYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00009JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00:goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00@00003FUH005YF00MJEP03001JEUYF00IJEP8000MJEP03001JEP0000d0
0003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP<00003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
0005FUH400000eYF001JEP06FUH00`00FUIJEP02FUH90002FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00
FUIJEP02FUH01000FUIJEUYF0P00;Goo000/Ool2FUH00`00FUIJEP02FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo
0UYF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
00000`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000IJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0UYF00<005YFFUH00`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH005YF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUH000030003FUH00`00
FUIJEP06FUH00`00FUH000080004FUH01000FUIJEP001UYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool2FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0eYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;7oo00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH80000
1EYF001JEUYF00000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800003FUH0000000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000]Ool002aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP@00003FUH005YF00AJEP03001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF001JEP030004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHF0002FUH01000FUIJEUYF0P00;7oo000/Ool01000
FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEPX000=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@0
009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000Uo
o`@00004FUH005YFFUH20002FUH40003FUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:00000eYF000000050004FUH500001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH015YF0`001EYF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF009JEPH000Ioo`L000EJEP03001JEUYF009JEP<000=JEP800003FUH0000002aoo`00;Goo
0UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF2@000eYF2@0015YF00<005YFFUH0
15YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEP8000=J
EP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP030002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH60003Ool90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF1@00;7oo000]Ool3FUH20002FUH00`00FUIJEP03FUH60004FUH80004
FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH200000eYF001JEP02FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF00<005YF0000
300015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0P0000=JEP0000000`00;7oo
000]Ool3FUH01@00FUIJEUYF00000eYF0P001EYF1@000eYF00<005YFFUH01UYF00<005YF00000eYF
0P0000=JEP00FUH01EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
2@00FUIJEUYF001JEP00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001oo`0[Ool002eoo`04001JEUYF0003FUH0
1000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01eYF0P000eYF00<005YF00000P001EYF00<0
05YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
15YF001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00001000;Goo000]Ool01000FUIJEP000eYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP@000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH000000004
FUH00`00FUIJEP05FUH20007FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF0000
000^Ool002ioo`9JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000030003FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH000AJEP03001JEUYF00MJEP@000=JEPD0
00EJEP03001JEUYF00EJEP03001JEP0000@0009JEP03001JEP0002moo`00;Woo0UYF1@000eYF00<0
05YFFUH015YF00<005YFFUH01UYF0`001UYF00<005YFFUH00`001EYF00<005YFFUH00eYF1@0000=J
EP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00P0000=JEP00000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF00<005YFFUH02eYF5`000eYF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH02`00
1eYF1@001EYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH010000eYF
00<005YFFUH01eYF00<005YFFUH01eYF1@000eYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH035YF1P000eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80031oo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH035YF1@001EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH0
15YF5`000eYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP0<FUH00`00FUH000020004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Goo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP0<FUH50006FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EUYF009JEP03001JEUYF00]JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000cOol002moo`800003FUH005YF00AJEP03001JEUYF00eJEP<000MJEP03001JEUYF00@0009o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001J
EUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH007oo1@000UYF00<005YFFUH015YF10000eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEPD003Eoo`00<Goo10000eYF00<005YFFUH03UYF00<005YFFUH00UYF1`002Goo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000MJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Io
obD003Yoo`00=Goo1`002EYF2@0057oo1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEQD000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
?7oo2@0087oo00<005YFFUH02P0015YF00<005YFFUH00UYF1`002EYF00<005YFFUH02EYF2@0025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002000GGoo001UOol01000FUIJEP001EYF00@0
05YFFUIJEPX0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00D005Qoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP03001JEP00008005Eo
o`00?Woo20007goo00@005YFFUH000EJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000IJ
EP03001JEUYF009JEP05001JEUYFFUH0001EOol003Ioo`P000=JEP03001JEUYF009JEPT001Ioo`04
001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH40004FUH00`00FUH00006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000aOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000@Ool01@00
FUIJEP00FUH00P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP03001JEUYF009JEP04001J
EUYFFUH2001DOol002moo`800003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEP0000<000aoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80
0004FUH005YF0006FUH00`00FUIJEP02FUH01000FUIJEUYF0P00E7oo000]Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30009Ool0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02001DOol002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000Moo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP80
0003FUH005YF00IJEP03001JEUYF009JEP05001JEUYFFUH0001DOol002]oo`03001JEP0000=JEP04
001JEUYFFUH80008Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP020005Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001eYF00<005YFFUH00UYF00D005YFFUIJEP0005Aoo`00
:goo00<005YF00000eYF10006Goo1P001UYF00<005YFFUH00eYF00<007ooOol00Woo0P0015YF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF00002`000UYF00@005YFFUIJEP8005=oo`00:goo00@0
05YF001JEP8002=oo`@0009JEP03001JEUYF00=JEP8000=oo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00D00003FUH00000009JEP@000=JEP8005=oo`00:goo00@005YF000002Uo
o`<000EJEP04001JEP000002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00003FUH00`00FUIJEP02FUH30003FUH200000eYF0000001COol002]oo`<002eoo`8000=JEP07
001JEUYFFUH007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF
00@005YFFUIJEPD005=oo`00:goo0P0000=JEP000000;Goo0P0000=JEP00FUH00UYF00<007ooOol0
0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH015YF0P000UYF1@00Dgoo
000[Ool00`00FUIJEP02FUH00`00Oomoo`0/Ool20003FUH20003Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
0005FUH00`00FUIJEP05FUH600000eYF001oo`1BOol002]oo`03001JEUYF009JEP<002ioo`03001J
EUYF008000Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEP0000@005Aoo`00
:goo00<005YFFUH00UYF00<005YFFUH00P00;Goo10001goo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`000eYF00<005YFFUH01UYF
00<005YFFUH015YF1P00EGoo000/Ool01000FUIJEP001EYF0P00:goo10002Goo0`0000=JEP00FUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01EYF00<005YF000010000UYF00<005YF0000EWoo000]Ool30005FUH00`00FUH00003000U
Ool200000eYF0000000=Ool70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUH0000G0003FUH01000FUIJEUYF0P00Egoo000_Ool00`00FUIJEP03FUH00`00FUIJEP03FUH7
000IOol50003FUH2000DOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH70003FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00Egoo000`Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90009Ool70003FUH01`00FUIJEUYF001JEP00021ooaT000YJEPH000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001HOol0039oo`800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool01@00
FUIJEUYF000015YF00<005YFFUH02eYF00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Yoo`00=7oo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00D005YFFUIJEP0002ioo`800003FUH005YF00=JEP03001JEUYF00AJEP@0
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001LOol003Moo`@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol:0004
FUH00`00FUIJEP0H001QOol003]oo`L000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000mOol9001gOol0049oo`T000AJEP03001JEUYF009JEPL00<9oo`00Bgoo2@00bGoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59191 .78729 m .59619 .75096 L .59594 .75092 L p .707 .577 .707 r
F P
0 g
s
.59594 .75092 m .56523 .74544 L p .59053 .78512 L .707 .577 .707 r
F P
0 g
s
.59191 .78729 m .59594 .75092 L .59053 .78512 L .707 .577 .707 r
F
.59619 .75096 m .59191 .78729 L .62355 .78978 L p F P
0 g
s
.62355 .78978 m .62783 .75345 L .62746 .75342 L p .707 .577 .707 r
F P
0 g
s
.62746 .75342 m .59619 .75096 L p .62142 .78675 L .707 .577 .707 r
F P
0 g
s
.62355 .78978 m .62746 .75342 L .62142 .78675 L .707 .577 .707 r
F
.62783 .75345 m .62355 .78978 L .65279 .789 L p F P
0 g
s
.65279 .789 m .65707 .75267 L .65665 .75268 L p .707 .577 .707 r
F P
0 g
s
.65665 .75268 m .62783 .75345 L p .65039 .78558 L .707 .577 .707 r
F P
0 g
s
.65279 .789 m .65665 .75268 L .65039 .78558 L .707 .577 .707 r
F
.65707 .75267 m .65279 .789 L .67674 .78501 L p F P
0 g
s
.67674 .78501 m .68102 .74868 L .68065 .74874 L p .707 .577 .707 r
F P
0 g
s
.68065 .74874 m .65707 .75267 L p .67467 .78161 L .707 .577 .707 r
F P
0 g
s
.67674 .78501 m .68065 .74874 L .67467 .78161 L .707 .577 .707 r
F
.68102 .74868 m .67674 .78501 L .69308 .77822 L p F P
0 g
s
.69308 .77822 m .69736 .74189 L .69711 .74199 L p .707 .577 .707 r
F P
0 g
s
.69711 .74199 m .68102 .74868 L p .69181 .77512 L .707 .577 .707 r
F P
0 g
s
.69308 .77822 m .69711 .74199 L .69181 .77512 L .707 .577 .707 r
F
.69736 .74189 m .69308 .77822 L .70019 .76928 L p F P
0 g
s
.70019 .76928 m .70447 .73295 L .70437 .73307 L p .707 .577 .707 r
F P
0 g
s
.70437 .73307 m .69736 .74189 L p .69992 .76666 L .707 .577 .707 r
F P
0 g
s
.70019 .76928 m .70437 .73307 L .69992 .76666 L .707 .577 .707 r
F
.69456 .76028 m .70169 .75122 L p .70232 .70942 L F P
0 g
s
.70169 .75122 m .70513 .72738 L p .70236 .70613 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .7095 .69707 L .70896 .69776 L p .707 .577 .707 r
F P
0 g
s
.70896 .69776 m .70236 .70613 L p .70513 .72738 L .707 .577 .707 r
F P
0 g
s
.70447 .73295 m .70019 .76928 L .69987 .7681 L p .707 .577 .707 r
F P
0 g
s
.70169 .75122 m .69894 .74066 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .70169 .75122 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.69987 .7681 m .69739 .75907 L p .70435 .7334 L .707 .577 .707 r
F P
0 g
s
.70435 .7334 m .70447 .73295 L .69987 .7681 L .707 .577 .707 r
F
.7095 .69707 m .70513 .72738 L p .70872 .70026 L F P
0 g
s
.70236 .70613 m .69801 .73638 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.69801 .73638 m .69456 .76028 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .69456 .76028 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68604 .7128 m .68168 .74311 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68168 .74311 m .67824 .76696 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .67824 .76696 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.66214 .71643 m .65774 .74692 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.65774 .74692 m .65433 .77058 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .65433 .77058 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.63298 .71666 m .62854 .74742 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.62854 .74742 m .62517 .77082 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .62517 .77082 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.60142 .71347 m .59694 .74458 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59694 .74458 m .59362 .76763 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .60142 .71347 L .57056 .70718 L p .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .63298 .71666 L .60142 .71347 L p .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .66214 .71643 L .63298 .71666 L p .707 .577 .707 r
F P
0 g
s
.56276 .76133 m .57056 .70718 L .54342 .69839 L p .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56523 .74544 L .56515 .74542 L p .707 .577 .707 r
F P
0 g
s
.56603 .73867 m .56276 .76133 L .56307 .76139 L p .707 .577 .707 r
F P
0 g
s
.54342 .69839 m .53562 .75254 L .56276 .76133 L p .707 .577 .707 r
F P
0 g
s
.56515 .74542 m .53798 .73742 L p .56052 .78095 L .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56515 .74542 L .56052 .78095 L .707 .577 .707 r
F
.57056 .70718 m .56603 .73867 L p .59362 .76763 L F P
0 g
s
.56523 .74544 m .56095 .78177 L .59191 .78729 L p .707 .577 .707 r
F P
0 g
s
.56307 .76139 m .59362 .76763 L p .56603 .73867 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .68604 .7128 L .66214 .71643 L p .707 .577 .707 r
F P
0 g
s
.53562 .75254 m .54342 .69839 L .52265 .68797 L p .707 .577 .707 r
F P
0 g
s
.53798 .73742 m .5337 .77375 L .56095 .78177 L p .707 .577 .707 r
F P
0 g
s
.52265 .68797 m .51484 .74212 L .53562 .75254 L p .707 .577 .707 r
F P
0 g
s
.5337 .77375 m .53798 .73742 L .51712 .7277 L p .707 .577 .707 r
F P
0 g
s
.69456 .76028 m .70236 .70613 L .68604 .7128 L p .707 .577 .707 r
F P
0 g
s
.60262 .87177 m .60087 .85314 L .56984 .85424 L p .707 .577 .707 r
F P
0 g
s
.60087 .85314 m .60262 .87177 L .63433 .86829 L p .707 .577 .707 r
F P
0 g
s
.63433 .86829 m .63258 .84967 L .60087 .85314 L p .707 .577 .707 r
F P
0 g
s
.63258 .84967 m .63433 .86829 L .66361 .86277 L p .707 .577 .707 r
F P
0 g
s
.66361 .86277 m .66186 .84414 L .63258 .84967 L p .707 .577 .707 r
F P
0 g
s
.51484 .74212 m .52265 .68797 L .51028 .67694 L p .707 .577 .707 r
F P
0 g
s
.56984 .85424 m .57159 .87286 L .60262 .87177 L p .707 .577 .707 r
F P
0 g
s
.51712 .7277 m .51284 .76403 L .5337 .77375 L p .707 .577 .707 r
F P
0 g
s
.57159 .87286 m .56984 .85424 L .54253 .85284 L p .707 .577 .707 r
F P
0 g
s
.54253 .85284 m .54427 .87146 L .57159 .87286 L p .707 .577 .707 r
F P
0 g
s
.66186 .84414 m .66361 .86277 L .6876 .85574 L p .707 .577 .707 r
F P
0 g
s
.6876 .85574 m .68585 .83712 L .66186 .84414 L p .707 .577 .707 r
F P
0 g
s
.51028 .67694 m .50247 .73109 L .51484 .74212 L p .707 .577 .707 r
F P
0 g
s
.51284 .76403 m .51712 .7277 L .50468 .71723 L p .707 .577 .707 r
F P
0 g
s
.54427 .87146 m .54253 .85284 L .5216 .84908 L p .707 .577 .707 r
F P
0 g
s
.50468 .71723 m .5004 .75355 L .51284 .76403 L p .707 .577 .707 r
F P
0 g
s
.5216 .84908 m .52335 .86771 L .54427 .87146 L p .707 .577 .707 r
F P
0 g
s
.50247 .73109 m .51028 .67694 L .50752 .66637 L p .707 .577 .707 r
F P
0 g
s
.68585 .83712 m .6876 .85574 L .70395 .8479 L p .707 .577 .707 r
F P
0 g
s
.70395 .8479 m .7022 .82928 L .68585 .83712 L p .707 .577 .707 r
F P
0 g
s
.50752 .66637 m .49972 .72052 L .50247 .73109 L p .707 .577 .707 r
F P
0 g
s
.5004 .75355 m .50468 .71723 L .50188 .70702 L p .707 .577 .707 r
F P
0 g
s
.52335 .86771 m .5216 .84908 L .50911 .84334 L p .707 .577 .707 r
F P
0 g
s
.50911 .84334 m .51085 .86197 L .52335 .86771 L p .707 .577 .707 r
F P
0 g
s
.69894 .74066 m .70235 .71699 L p .7095 .69707 L .707 .577 .707 r
F P
0 g
s
.70674 .68651 m .69894 .74066 L .68657 .72963 L p .707 .577 .707 r
F P
0 g
s
.70167 .72274 m .69739 .75907 L .69609 .75797 L p .707 .577 .707 r
F P
0 g
s
.69609 .75797 m .68495 .74859 L p .70141 .72315 L .707 .577 .707 r
F P
0 g
s
.70141 .72315 m .70167 .72274 L .69609 .75797 L .707 .577 .707 r
F
.70235 .71699 m .70674 .68651 L .70691 .68715 L p F P
0 g
s
.70691 .68715 m .7095 .69707 L p .70235 .71699 L .707 .577 .707 r
F P
0 g
s
.50188 .70702 m .4976 .74335 L .5004 .75355 L p .707 .577 .707 r
F P
0 g
s
.7022 .82928 m .70395 .8479 L .71105 .84001 L p .707 .577 .707 r
F P
0 g
s
.71105 .84001 m .7093 .82139 L .7022 .82928 L p .707 .577 .707 r
F P
0 g
s
.4976 .74335 m .50188 .70702 L .50899 .69808 L p .707 .577 .707 r
F P
0 g
s
.49972 .72052 m .50752 .66637 L .51466 .65731 L p .707 .577 .707 r
F P
0 g
s
.49047 .82157 m .48745 .31937 L .44344 .31695 L p .707 .577 .707 r
F P
0 g
s
.50899 .69808 m .50471 .73441 L .4976 .74335 L p .707 .577 .707 r
F P
0 g
s
.51466 .65731 m .50685 .71146 L .49972 .72052 L p .707 .577 .707 r
F P
0 g
s
.50471 .73441 m .50899 .69808 L .52533 .69129 L p .707 .577 .707 r
F P
0 g
s
.50685 .71146 m .51466 .65731 L .53098 .65064 L p .707 .577 .707 r
F P
0 g
s
.52533 .69129 m .52105 .72762 L .50471 .73441 L p .707 .577 .707 r
F P
0 g
s
.53098 .65064 m .52317 .70479 L .50685 .71146 L p .707 .577 .707 r
F P
0 g
s
.52105 .72762 m .52533 .69129 L .54928 .6873 L p .707 .577 .707 r
F P
0 g
s
.52317 .70479 m .53098 .65064 L .55489 .64701 L p .707 .577 .707 r
F P
0 g
s
.54928 .6873 m .545 .72363 L .52105 .72762 L p .707 .577 .707 r
F P
0 g
s
.55489 .64701 m .54708 .70116 L .52317 .70479 L p .707 .577 .707 r
F P
0 g
s
.53147 .83907 m .52973 .82044 L .55371 .81342 L p .707 .577 .707 r
F P
0 g
s
.48745 .31937 m .49047 .82157 L .53542 .82023 L p .707 .577 .707 r
F P
0 g
s
.53542 .82023 m .53239 .31803 L .48745 .31937 L p .707 .577 .707 r
F P
0 g
s
.545 .72363 m .54928 .6873 L .57851 .68652 L p .707 .577 .707 r
F P
0 g
s
.54708 .70116 m .55489 .64701 L .58404 .64678 L p .707 .577 .707 r
F P
0 g
s
.57851 .68652 m .57424 .72284 L .545 .72363 L p .707 .577 .707 r
F P
0 g
s
.58404 .64678 m .57624 .70093 L .54708 .70116 L p .707 .577 .707 r
F P
0 g
s
.55371 .81342 m .55546 .83204 L .53147 .83907 L p .707 .577 .707 r
F P
0 g
s
.55546 .83204 m .55371 .81342 L .583 .80789 L p .707 .577 .707 r
F P
0 g
s
.583 .80789 m .58474 .82652 L .55546 .83204 L p .707 .577 .707 r
F P
0 g
s
.53239 .31803 m .53542 .82023 L .5769 .81527 L p .707 .577 .707 r
F P
0 g
s
.57424 .72284 m .57851 .68652 L .61016 .68901 L p .707 .577 .707 r
F P
0 g
s
.61016 .68901 m .60588 .72534 L .57424 .72284 L p .707 .577 .707 r
F P
0 g
s
.5769 .81527 m .57387 .31306 L .53239 .31803 L p .707 .577 .707 r
F P
0 g
s
.69739 .75907 m .70167 .72274 L .70447 .73295 L p .707 .577 .707 r
F P
0 g
s
.44647 .81915 m .44344 .31695 L .40468 .31102 L p .707 .577 .707 r
F P
0 g
s
.44344 .31695 m .44647 .81915 L .49047 .82157 L p .707 .577 .707 r
F P
0 g
s
.51085 .86197 m .50911 .84334 L .50627 .83617 L p .707 .577 .707 r
F P
0 g
s
.57624 .70093 m .58404 .64678 L .6156 .64997 L p .707 .577 .707 r
F P
0 g
s
.6156 .64997 m .60779 .70412 L .57624 .70093 L p .707 .577 .707 r
F P
0 g
s
.58474 .82652 m .583 .80789 L .6147 .80442 L p .707 .577 .707 r
F P
0 g
s
.57387 .31306 m .5769 .81527 L .61085 .80717 L p .707 .577 .707 r
F P
0 g
s
.6736 .66506 m .6658 .71921 L .63892 .71051 L p .707 .577 .707 r
F P
0 g
s
.63899 .70998 m .6736 .66506 L .63892 .71051 L .707 .577 .707 r
F
.63626 .73075 m .60588 .72534 L p .64102 .69462 L F P
0 g
s
.64646 .65627 m .6736 .66506 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .61016 .68901 L .64103 .69451 L p .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .64103 .69451 L .64102 .69462 L .707 .577 .707 r
F
.63865 .71042 m .64192 .68776 L p .63899 .70998 L F P
0 g
s
.64192 .68776 m .64646 .65627 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.64103 .69451 m .64112 .69453 L p .64102 .69462 L .707 .577 .707 r
F P
0 g
s
.64112 .69453 m .63684 .73086 L .63626 .73075 L p .707 .577 .707 r
F P
0 g
s
.64102 .69462 m .64112 .69453 L .63626 .73075 L .707 .577 .707 r
F
.63892 .71051 m .63865 .71042 L p .63899 .70998 L F P
0 g
s
.64646 .65627 m .63865 .71042 L .60779 .70412 L p .707 .577 .707 r
F P
0 g
s
.60779 .70412 m .6156 .64997 L .64646 .65627 L p .707 .577 .707 r
F P
0 g
s
.61085 .80717 m .60783 .30496 L .57387 .31306 L p .707 .577 .707 r
F P
0 g
s
.50627 .83617 m .50802 .8548 L .51085 .86197 L p .707 .577 .707 r
F P
0 g
s
.25061 .70228 m .25841 .64813 L .22756 .64183 L p .707 .577 .707 r
F P
0 g
s
.25841 .64813 m .25061 .70228 L .28216 .70547 L p .707 .577 .707 r
F P
0 g
s
.28216 .70547 m .28997 .65132 L .25841 .64813 L p .707 .577 .707 r
F P
0 g
s
.68657 .72963 m .68994 .70624 L p .70674 .68651 L .707 .577 .707 r
F P
0 g
s
.69438 .67548 m .68657 .72963 L .6658 .71921 L p .707 .577 .707 r
F P
0 g
s
.68923 .71227 m .68495 .74859 L .68321 .74778 L p .707 .577 .707 r
F P
0 g
s
.68321 .74778 m .66409 .73887 L p .68891 .71261 L .707 .577 .707 r
F P
0 g
s
.68891 .71261 m .68923 .71227 L .68321 .74778 L .707 .577 .707 r
F
.68994 .70624 m .69438 .67548 L .69486 .67591 L p F P
0 g
s
.69486 .67591 m .70674 .68651 L p .68994 .70624 L .707 .577 .707 r
F P
0 g
s
.28997 .65132 m .28216 .70547 L .31132 .70524 L p .707 .577 .707 r
F P
0 g
s
.31132 .70524 m .31913 .65109 L .28997 .65132 L p .707 .577 .707 r
F P
0 g
s
.7093 .82139 m .71105 .84001 L .70822 .83285 L p .707 .577 .707 r
F P
0 g
s
.70822 .83285 m .70647 .81422 L .7093 .82139 L p .707 .577 .707 r
F P
0 g
s
.21975 .69598 m .22756 .64183 L .20041 .63304 L p .707 .577 .707 r
F P
0 g
s
.22756 .64183 m .21975 .69598 L .25061 .70228 L p .707 .577 .707 r
F P
0 g
s
.4077 .81322 m .40468 .31102 L .37496 .30215 L p .707 .577 .707 r
F P
0 g
s
.40468 .31102 m .4077 .81322 L .44647 .81915 L p .707 .577 .707 r
F P
0 g
s
.68495 .74859 m .68923 .71227 L .70167 .72274 L p .707 .577 .707 r
F P
0 g
s
.31913 .65109 m .31132 .70524 L .33523 .70161 L p .707 .577 .707 r
F P
0 g
s
.33523 .70161 m .34304 .64746 L .31913 .65109 L p .707 .577 .707 r
F P
0 g
s
.19261 .68719 m .20041 .63304 L .17964 .62262 L p .707 .577 .707 r
F P
0 g
s
.20041 .63304 m .19261 .68719 L .21975 .69598 L p .707 .577 .707 r
F P
0 g
s
.50802 .8548 m .50627 .83617 L .51338 .82828 L p .707 .577 .707 r
F P
0 g
s
.61645 .82304 m .6147 .80442 L .64574 .80333 L p .707 .577 .707 r
F P
0 g
s
.6147 .80442 m .61645 .82304 L .58474 .82652 L p .707 .577 .707 r
F P
0 g
s
.60783 .30496 m .61085 .80717 L .63396 .79672 L p .707 .577 .707 r
F P
0 g
s
.63396 .79672 m .63094 .29452 L .60783 .30496 L p .707 .577 .707 r
F P
0 g
s
.51338 .82828 m .51513 .84691 L .50802 .8548 L p .707 .577 .707 r
F P
0 g
s
.6658 .71921 m .66912 .69616 L p .69438 .67548 L .707 .577 .707 r
F P
0 g
s
.66837 .70254 m .66409 .73887 L .66261 .73844 L p .707 .577 .707 r
F P
0 g
s
.66261 .73844 m .63684 .73086 L p .6681 .70278 L .707 .577 .707 r
F P
0 g
s
.6681 .70278 m .66837 .70254 L .66261 .73844 L .707 .577 .707 r
F
.66912 .69616 m .6736 .66506 L .67389 .6652 L p F P
0 g
s
.67389 .6652 m .69438 .67548 L p .66912 .69616 L .707 .577 .707 r
F P
0 g
s
.25961 .79015 m .25787 .77153 L .22683 .77262 L p .707 .577 .707 r
F P
0 g
s
.25787 .77153 m .25961 .79015 L .29132 .78667 L p .707 .577 .707 r
F P
0 g
s
.29132 .78667 m .28957 .76805 L .25787 .77153 L p .707 .577 .707 r
F P
0 g
s
.22683 .77262 m .22858 .79124 L .25961 .79015 L p .707 .577 .707 r
F P
0 g
s
.2489 .80173 m .25318 .7654 L .22222 .75988 L p .707 .577 .707 r
F P
0 g
s
.25318 .7654 m .2489 .80173 L .28055 .80422 L p .707 .577 .707 r
F P
0 g
s
.28055 .80422 m .28483 .76789 L .25318 .7654 L p .707 .577 .707 r
F P
0 g
s
.70647 .81422 m .70822 .83285 L .69573 .82711 L p .707 .577 .707 r
F P
0 g
s
.69573 .82711 m .69398 .80848 L .70647 .81422 L p .707 .577 .707 r
F P
0 g
s
.28957 .76805 m .29132 .78667 L .3206 .78115 L p .707 .577 .707 r
F P
0 g
s
.3206 .78115 m .31886 .76253 L .28957 .76805 L p .707 .577 .707 r
F P
0 g
s
.34304 .64746 m .33523 .70161 L .35155 .69494 L p .707 .577 .707 r
F P
0 g
s
.35155 .69494 m .35936 .64079 L .34304 .64746 L p .707 .577 .707 r
F P
0 g
s
.17964 .62262 m .17183 .67677 L .19261 .68719 L p .707 .577 .707 r
F P
0 g
s
.28483 .76789 m .28055 .80422 L .30978 .80343 L p .707 .577 .707 r
F P
0 g
s
.30978 .80343 m .31406 .7671 L .28483 .76789 L p .707 .577 .707 r
F P
0 g
s
.37798 .80435 m .37496 .30215 L .35718 .29121 L p .707 .577 .707 r
F P
0 g
s
.37496 .30215 m .37798 .80435 L .4077 .81322 L p .707 .577 .707 r
F P
0 g
s
.66409 .73887 m .66837 .70254 L .68923 .71227 L p .707 .577 .707 r
F P
0 g
s
.21794 .7962 m .22222 .75988 L .19497 .75186 L p .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22683 .77262 L .22401 .77247 L p .707 .577 .707 r
F P
0 g
s
.22222 .75988 m .21794 .7962 L .22391 .79727 L p .707 .577 .707 r
F P
0 g
s
.22405 .76274 m .22222 .75988 L .22391 .79727 L .707 .577 .707 r
F
.19497 .75186 m .19069 .78819 L .21794 .7962 L p F P
0 g
s
.22401 .77247 m .19952 .77122 L p .22394 .78805 L .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22401 .77247 L .22394 .78805 L .707 .577 .707 r
F
.19952 .77122 m .20127 .78984 L .22858 .79124 L p F P
0 g
s
.22391 .79727 m .2489 .80173 L p .22405 .76274 L .707 .577 .707 r
F P
0 g
s
.17183 .67677 m .17964 .62262 L .16727 .61159 L p .707 .577 .707 r
F P
0 g
s
.31886 .76253 m .3206 .78115 L .34459 .77413 L p .707 .577 .707 r
F P
0 g
s
.34459 .77413 m .34284 .7555 L .31886 .76253 L p .707 .577 .707 r
F P
0 g
s
.31406 .7671 m .30978 .80343 L .33373 .79945 L p .707 .577 .707 r
F P
0 g
s
.33373 .79945 m .33801 .76312 L .31406 .7671 L p .707 .577 .707 r
F P
0 g
s
.51513 .84691 m .51338 .82828 L .52973 .82044 L p .707 .577 .707 r
F P
0 g
s
.19069 .78819 m .19497 .75186 L .17411 .74214 L p .707 .577 .707 r
F P
0 g
s
.52973 .82044 m .53147 .83907 L .51513 .84691 L p .707 .577 .707 r
F P
0 g
s
.17411 .74214 m .16983 .77847 L .19069 .78819 L p .707 .577 .707 r
F P
0 g
s
.20127 .78984 m .19952 .77122 L .17859 .76746 L p .707 .577 .707 r
F P
0 g
s
.16727 .61159 m .15946 .66574 L .17183 .67677 L p .707 .577 .707 r
F P
0 g
s
.63684 .73086 m .64112 .69453 L .66837 .70254 L p .707 .577 .707 r
F P
0 g
s
.63094 .29452 m .63396 .79672 L .64396 .78496 L p .707 .577 .707 r
F P
0 g
s
.64396 .78496 m .64094 .28275 L .63094 .29452 L p .707 .577 .707 r
F P
0 g
s
.17859 .76746 m .18034 .78609 L .20127 .78984 L p .707 .577 .707 r
F P
0 g
s
.35936 .64079 m .35155 .69494 L .35868 .68588 L p .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .36607 .6346 L p .35936 .64079 L .707 .577 .707 r
F P
0 g
s
.34284 .7555 m .34459 .77413 L .36094 .76629 L p .707 .577 .707 r
F P
0 g
s
.36094 .76629 m .35919 .74766 L .34284 .7555 L p .707 .577 .707 r
F P
0 g
s
.36619 .6321 m .35936 .64079 L p .36607 .6346 L .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .35593 .67531 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .36649 .63173 L .36619 .6321 L p .707 .577 .707 r
F P
0 g
s
.36649 .63173 m .36607 .6346 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .35868 .68588 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .35309 .27927 L p .35762 .60687 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36649 .63173 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .36317 .62508 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .36373 .62116 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35919 .74766 m .36094 .76629 L .3672 .75933 L p .707 .577 .707 r
F P
0 g
s
.3672 .75933 m .36804 .7584 L p .36714 .75729 L .707 .577 .707 r
F P
0 g
s
.36714 .75729 m .35919 .74766 L .3672 .75933 L .707 .577 .707 r
F
.36804 .7584 m .3663 .73977 L .35919 .74766 L p F P
0 g
s
.35435 .75633 m .35007 .79265 L .35718 .78372 L p .707 .577 .707 r
F P
0 g
s
.35718 .78372 m .36146 .74739 L .35435 .75633 L p .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .34356 .66428 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36317 .62508 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .35593 .67531 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .35137 .61013 L .36301 .62052 L p .707 .577 .707 r
F P
0 g
s
.36301 .62052 m .36373 .62116 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .36301 .62052 L .36308 .62256 L .707 .577 .707 r
F
.3533 .31385 m .35351 .34894 L p .35378 .3294 L F P
0 g
s
.36146 .74739 m .35718 .78372 L .35438 .77351 L p .707 .577 .707 r
F P
0 g
s
.35438 .77351 m .35866 .73718 L .36146 .74739 L p .707 .577 .707 r
F P
0 g
s
.35007 .79265 m .35435 .75633 L .33801 .76312 L p .707 .577 .707 r
F P
0 g
s
.35866 .73718 m .35438 .77351 L .34271 .76367 L p .707 .577 .707 r
F P
0 g
s
.34271 .76367 m .34194 .76303 L p .34276 .76177 L .707 .577 .707 r
F P
0 g
s
.34276 .76177 m .35866 .73718 L .34271 .76367 L .707 .577 .707 r
F
.34194 .76303 m .34622 .7267 L .35866 .73718 L p F P
0 g
s
.3559 .74695 m .35272 .74549 L p .35587 .74171 L .707 .577 .707 r
F P
0 g
s
.35587 .74171 m .36346 .7326 L .3559 .74695 L .707 .577 .707 r
F
.36346 .7326 m .36521 .75123 L .3559 .74695 L p F P
0 g
s
.35272 .74549 m .35097 .72686 L .36346 .7326 L p .707 .577 .707 r
F P
0 g
s
.35351 .34894 m .35611 .78148 L p .35395 .36149 L .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .3602 .79341 L p .35441 .37466 L .707 .577 .707 r
F P
0 g
s
.35441 .37466 m .35378 .3294 L .35395 .36149 L .707 .577 .707 r
F
.35441 .37466 m .35395 .36149 L .35611 .78148 L F
.35911 .61174 m .35718 .29121 L p .35897 .6113 L F P
0 g
s
.35985 .7679 m .35897 .6113 L .35762 .60687 L .707 .577 .707 r
F
.35897 .6113 m .35718 .29121 L .35762 .60687 L F
.3663 .73977 m .36804 .7584 L .36521 .75123 L p F P
0 g
s
.36521 .75123 m .36346 .7326 L .3663 .73977 L p .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .3602 .79341 L .37798 .80435 L p .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .35363 .36867 L p .36309 .26751 L .707 .577 .707 r
F P
0 g
s
.35378 .3294 m .35351 .34894 L .35395 .36149 L .707 .577 .707 r
F
.35309 .27927 m .3533 .31385 L p .35378 .3294 L F P
0 g
s
.35363 .36867 m .35309 .27927 L .3562 .27561 L p .707 .577 .707 r
F P
0 g
s
.3562 .27561 m .36309 .26751 L p .35363 .36867 L .707 .577 .707 r
F P
0 g
s
.36002 .76412 m .35911 .61174 L p .35985 .7679 L .707 .577 .707 r
F P
0 g
s
.35911 .61174 m .35897 .6113 L .35985 .7679 L .707 .577 .707 r
F
.3602 .79341 m .36002 .76412 L p .35985 .7679 L F P
0 g
s
.69398 .80848 m .69573 .82711 L .6748 .82335 L p .707 .577 .707 r
F P
0 g
s
.6748 .82335 m .67305 .80472 L .69398 .80848 L p .707 .577 .707 r
F P
0 g
s
.15946 .66574 m .16727 .61159 L .16451 .60103 L p .707 .577 .707 r
F P
0 g
s
.33801 .76312 m .33373 .79945 L .35007 .79265 L p .707 .577 .707 r
F P
0 g
s
.16983 .77847 m .17411 .74214 L .16167 .73166 L p .707 .577 .707 r
F P
0 g
s
.16167 .73166 m .15739 .76799 L .16983 .77847 L p .707 .577 .707 r
F P
0 g
s
.18034 .78609 m .17859 .76746 L .1661 .76172 L p .707 .577 .707 r
F P
0 g
s
.1661 .76172 m .16784 .78035 L .18034 .78609 L p .707 .577 .707 r
F P
0 g
s
.16451 .60103 m .15671 .65518 L .15946 .66574 L p .707 .577 .707 r
F P
0 g
s
.67305 .80472 m .6748 .82335 L .64748 .82195 L p .707 .577 .707 r
F P
0 g
s
.64748 .82195 m .64574 .80333 L .67305 .80472 L p .707 .577 .707 r
F P
0 g
s
.15671 .65518 m .16451 .60103 L .17165 .59196 L p .707 .577 .707 r
F P
0 g
s
.64094 .28275 m .64396 .78496 L .63987 .77302 L p .707 .577 .707 r
F P
0 g
s
.63987 .77302 m .63685 .27082 L .64094 .28275 L p .707 .577 .707 r
F P
0 g
s
.15739 .76799 m .16167 .73166 L .15887 .72146 L p .707 .577 .707 r
F P
0 g
s
.64574 .80333 m .64748 .82195 L .61645 .82304 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16784 .78035 m .1661 .76172 L .16326 .75456 L p .707 .577 .707 r
F P
0 g
s
.16326 .75456 m .16501 .77318 L .16784 .78035 L p .707 .577 .707 r
F P
0 g
s
.15887 .72146 m .15459 .75778 L .15739 .76799 L p .707 .577 .707 r
F P
0 g
s
.17165 .59196 m .16384 .64612 L .15671 .65518 L p .707 .577 .707 r
F P
0 g
s
.16384 .64612 m .17165 .59196 L .18797 .58529 L p .707 .577 .707 r
F P
0 g
s
.15459 .75778 m .15887 .72146 L .16598 .71252 L p .707 .577 .707 r
F P
0 g
s
.16501 .77318 m .16326 .75456 L .17037 .74667 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17037 .74667 m .17212 .76529 L .16501 .77318 L p .707 .577 .707 r
F P
0 g
s
.16598 .71252 m .1617 .74885 L .15459 .75778 L p .707 .577 .707 r
F P
0 g
s
.18797 .58529 m .18016 .63945 L .16384 .64612 L p .707 .577 .707 r
F P
0 g
s
.63685 .27082 m .63987 .77302 L .6221 .76208 L p .707 .577 .707 r
F P
0 g
s
.6221 .76208 m .61908 .25988 L .63685 .27082 L p .707 .577 .707 r
F P
0 g
s
.35137 .61013 m .34356 .66428 L .32279 .65386 L p .707 .577 .707 r
F P
0 g
s
.32279 .65386 m .33059 .59971 L .35137 .61013 L p .707 .577 .707 r
F P
0 g
s
.18016 .63945 m .18797 .58529 L .21188 .58166 L p .707 .577 .707 r
F P
0 g
s
.1617 .74885 m .16598 .71252 L .18232 .70572 L p .707 .577 .707 r
F P
0 g
s
.36611 .76971 m .36309 .26751 L .3862 .25706 L p .707 .577 .707 r
F P
0 g
s
.36309 .26751 m .36611 .76971 L .35611 .78148 L p .707 .577 .707 r
F P
0 g
s
.17212 .76529 m .17037 .74667 L .18672 .73882 L p .707 .577 .707 r
F P
0 g
s
.33059 .59971 m .32279 .65386 L .29564 .64507 L p .707 .577 .707 r
F P
0 g
s
.29564 .64507 m .30345 .59092 L .33059 .59971 L p .707 .577 .707 r
F P
0 g
s
.21188 .58166 m .20407 .63582 L .18016 .63945 L p .707 .577 .707 r
F P
0 g
s
.20407 .63582 m .21188 .58166 L .24103 .58143 L p .707 .577 .707 r
F P
0 g
s
.18232 .70572 m .17804 .74205 L .1617 .74885 L p .707 .577 .707 r
F P
0 g
s
.18672 .73882 m .18846 .75745 L .17212 .76529 L p .707 .577 .707 r
F P
0 g
s
.34622 .7267 m .34194 .76303 L .32108 .75331 L p .707 .577 .707 r
F P
0 g
s
.32108 .75331 m .32536 .71698 L .34622 .7267 L p .707 .577 .707 r
F P
0 g
s
.35097 .72686 m .35272 .74549 L .33179 .74173 L p .707 .577 .707 r
F P
0 g
s
.33179 .74173 m .33004 .72311 L .35097 .72686 L p .707 .577 .707 r
F P
0 g
s
.61908 .25988 m .6221 .76208 L .59237 .75321 L p .707 .577 .707 r
F P
0 g
s
.59237 .75321 m .58935 .25101 L .61908 .25988 L p .707 .577 .707 r
F P
0 g
s
.30345 .59092 m .29564 .64507 L .26478 .63877 L p .707 .577 .707 r
F P
0 g
s
.26478 .63877 m .27259 .58462 L .30345 .59092 L p .707 .577 .707 r
F P
0 g
s
.23323 .63559 m .24103 .58143 L .27259 .58462 L p .707 .577 .707 r
F P
0 g
s
.24103 .58143 m .23323 .63559 L .20407 .63582 L p .707 .577 .707 r
F P
0 g
s
.17804 .74205 m .18232 .70572 L .20627 .70174 L p .707 .577 .707 r
F P
0 g
s
.27259 .58462 m .26478 .63877 L .23323 .63559 L p .707 .577 .707 r
F P
0 g
s
.18846 .75745 m .18672 .73882 L .2107 .7318 L p .707 .577 .707 r
F P
0 g
s
.3862 .25706 m .38922 .75927 L .36611 .76971 L p .707 .577 .707 r
F P
0 g
s
.38922 .75927 m .3862 .25706 L .42016 .24896 L p .707 .577 .707 r
F P
0 g
s
.2107 .7318 m .21245 .75042 L .18846 .75745 L p .707 .577 .707 r
F P
0 g
s
.20627 .70174 m .20199 .73807 L .17804 .74205 L p .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73339 .65892 L .73314 .65888 L p .707 .577 .707 r
F P
0 g
s
.73314 .65888 m .70243 .6534 L p .72773 .69309 L .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73314 .65888 L .72773 .69309 L .707 .577 .707 r
F
.73339 .65892 m .72911 .69525 L .76076 .69774 L p F P
0 g
s
.76076 .69774 m .76504 .66141 L .76466 .66138 L p .707 .577 .707 r
F P
0 g
s
.76466 .66138 m .73339 .65892 L p .75862 .69471 L .707 .577 .707 r
F P
0 g
s
.76076 .69774 m .76466 .66138 L .75862 .69471 L .707 .577 .707 r
F
.76504 .66141 m .76076 .69774 L .78999 .69696 L p F P
0 g
s
.78999 .69696 m .79427 .66063 L .79385 .66064 L p .707 .577 .707 r
F P
0 g
s
.79385 .66064 m .76504 .66141 L p .78759 .69354 L .707 .577 .707 r
F P
0 g
s
.78999 .69696 m .79385 .66064 L .78759 .69354 L .707 .577 .707 r
F
.79427 .66063 m .78999 .69696 L .81395 .69297 L p F P
0 g
s
.81395 .69297 m .81823 .65664 L .81786 .65671 L p .707 .577 .707 r
F P
0 g
s
.81786 .65671 m .79427 .66063 L p .81188 .68957 L .707 .577 .707 r
F P
0 g
s
.81395 .69297 m .81786 .65671 L .81188 .68957 L .707 .577 .707 r
F
.81823 .65664 m .81395 .69297 L .83028 .68618 L p F P
0 g
s
.83028 .68618 m .83456 .64985 L .83431 .64995 L p .707 .577 .707 r
F P
0 g
s
.83431 .64995 m .81823 .65664 L p .82902 .68308 L .707 .577 .707 r
F P
0 g
s
.83028 .68618 m .83431 .64995 L .82902 .68308 L .707 .577 .707 r
F
.83456 .64985 m .83028 .68618 L .8374 .67724 L p F P
0 g
s
.8374 .67724 m .84168 .64091 L .84158 .64104 L p .707 .577 .707 r
F P
0 g
s
.84158 .64104 m .83456 .64985 L p .83713 .67462 L .707 .577 .707 r
F P
0 g
s
.8374 .67724 m .84158 .64104 L .83713 .67462 L .707 .577 .707 r
F
.83177 .66825 m .8389 .65919 L p .83952 .61739 L F P
0 g
s
.8389 .65919 m .84233 .63534 L p .83957 .61409 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8467 .60503 L .84616 .60572 L p .707 .577 .707 r
F P
0 g
s
.84616 .60572 m .83957 .61409 L p .84233 .63534 L .707 .577 .707 r
F P
0 g
s
.84168 .64091 m .8374 .67724 L .83707 .67606 L p .707 .577 .707 r
F P
0 g
s
.8389 .65919 m .83615 .64862 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8389 .65919 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.83707 .67606 m .8346 .66703 L p .84156 .64136 L .707 .577 .707 r
F P
0 g
s
.84156 .64136 m .84168 .64091 L .83707 .67606 L .707 .577 .707 r
F
.8467 .60503 m .84233 .63534 L p .84593 .60822 L F P
0 g
s
.83957 .61409 m .83521 .64434 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.83521 .64434 m .83177 .66825 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .83177 .66825 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.82325 .62077 m .81888 .65107 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.81888 .65107 m .81545 .67492 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .81545 .67492 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79934 .62439 m .79495 .65488 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79495 .65488 m .79154 .67855 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .79154 .67855 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.77018 .62463 m .76575 .65539 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.76575 .65539 m .76238 .67878 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .76238 .67878 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73863 .62144 m .73414 .65254 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73414 .65254 m .73082 .67559 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .73863 .62144 L .70777 .61514 L p .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .77018 .62463 L .73863 .62144 L p .707 .577 .707 r
F P
0 g
s
.32536 .71698 m .32108 .75331 L .29908 .74684 L p .707 .577 .707 r
F P
0 g
s
.29919 .74052 m .27344 .74143 L p .29948 .72389 L .707 .577 .707 r
F P
0 g
s
.29908 .74684 m .29383 .74529 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29919 .74048 m .32536 .71698 L .29908 .74684 L .707 .577 .707 r
F
.27344 .74143 m .27169 .7228 L .29951 .72182 L p F P
0 g
s
.27344 .74143 m .29951 .72182 L .29948 .72389 L .707 .577 .707 r
F
.29383 .74529 m .29811 .70897 L .29973 .70944 L p F P
0 g
s
.29973 .70944 m .32536 .71698 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29383 .74529 m .29973 .70944 L .29919 .74048 L .707 .577 .707 r
F
.29951 .72182 m .30273 .72171 L p .29948 .72389 L F P
0 g
s
.30273 .72171 m .30447 .74033 L .29919 .74052 L p .707 .577 .707 r
F P
0 g
s
.29948 .72389 m .30273 .72171 L .29919 .74052 L .707 .577 .707 r
F
.33004 .72311 m .33179 .74173 L .30447 .74033 L p F P
0 g
s
.30447 .74033 m .30273 .72171 L .33004 .72311 L p .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .79934 .62439 L .77018 .62463 L p .707 .577 .707 r
F P
0 g
s
.69996 .66929 m .70777 .61514 L .68062 .60635 L p .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70243 .6534 L .70235 .65338 L p .707 .577 .707 r
F P
0 g
s
.70323 .64663 m .69996 .66929 L .70027 .66935 L p .707 .577 .707 r
F P
0 g
s
.68062 .60635 m .67282 .6605 L .69996 .66929 L p .707 .577 .707 r
F P
0 g
s
.70235 .65338 m .67519 .64539 L p .69773 .68891 L .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70235 .65338 L .69773 .68891 L .707 .577 .707 r
F
.70777 .61514 m .70323 .64663 L p .73082 .67559 L F P
0 g
s
.70243 .6534 m .69815 .68973 L .72911 .69525 L p .707 .577 .707 r
F P
0 g
s
.70027 .66935 m .73082 .67559 L p .70323 .64663 L .707 .577 .707 r
F P
0 g
s
.20199 .73807 m .20627 .70174 L .23551 .70095 L p .707 .577 .707 r
F P
0 g
s
.21245 .75042 m .2107 .7318 L .23999 .72628 L p .707 .577 .707 r
F P
0 g
s
.58935 .25101 m .59237 .75321 L .55361 .74728 L p .707 .577 .707 r
F P
0 g
s
.55361 .74728 m .55059 .24508 L .58935 .25101 L p .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .82325 .62077 L .79934 .62439 L p .707 .577 .707 r
F P
0 g
s
.27169 .7228 m .27344 .74143 L .24173 .7449 L p .707 .577 .707 r
F P
0 g
s
.29811 .70897 m .29383 .74529 L .26287 .73977 L p .707 .577 .707 r
F P
0 g
s
.24173 .7449 m .23999 .72628 L .27169 .7228 L p .707 .577 .707 r
F P
0 g
s
.26287 .73977 m .26715 .70344 L .29811 .70897 L p .707 .577 .707 r
F P
0 g
s
.23999 .72628 m .24173 .7449 L .21245 .75042 L p .707 .577 .707 r
F P
0 g
s
.23551 .70095 m .23123 .73728 L .20199 .73807 L p .707 .577 .707 r
F P
0 g
s
.23123 .73728 m .23551 .70095 L .26715 .70344 L p .707 .577 .707 r
F P
0 g
s
.67282 .6605 m .68062 .60635 L .65985 .59593 L p .707 .577 .707 r
F P
0 g
s
.26715 .70344 m .26287 .73977 L .23123 .73728 L p .707 .577 .707 r
F P
0 g
s
.42318 .75117 m .42016 .24896 L .46164 .244 L p .707 .577 .707 r
F P
0 g
s
.42016 .24896 m .42318 .75117 L .38922 .75927 L p .707 .577 .707 r
F P
0 g
s
.67519 .64539 m .67091 .68172 L .69815 .68973 L p .707 .577 .707 r
F P
0 g
s
.65985 .59593 m .65205 .65008 L .67282 .6605 L p .707 .577 .707 r
F P
0 g
s
.67091 .68172 m .67519 .64539 L .65432 .63566 L p .707 .577 .707 r
F P
0 g
s
.55059 .24508 m .55361 .74728 L .5096 .74487 L p .707 .577 .707 r
F P
0 g
s
.5096 .74487 m .50658 .24266 L .55059 .24508 L p .707 .577 .707 r
F P
0 g
s
.83177 .66825 m .83957 .61409 L .82325 .62077 L p .707 .577 .707 r
F P
0 g
s
.73983 .77973 m .73808 .76111 L .70705 .7622 L p .707 .577 .707 r
F P
0 g
s
.73808 .76111 m .73983 .77973 L .77154 .77625 L p .707 .577 .707 r
F P
0 g
s
.77154 .77625 m .76979 .75763 L .73808 .76111 L p .707 .577 .707 r
F P
0 g
s
.76979 .75763 m .77154 .77625 L .80082 .77073 L p .707 .577 .707 r
F P
0 g
s
.80082 .77073 m .79907 .75211 L .76979 .75763 L p .707 .577 .707 r
F P
0 g
s
.65205 .65008 m .65985 .59593 L .64748 .5849 L p .707 .577 .707 r
F P
0 g
s
.46466 .74621 m .46164 .244 L .50658 .24266 L p .707 .577 .707 r
F P
0 g
s
.46164 .244 m .46466 .74621 L .42318 .75117 L p .707 .577 .707 r
F P
0 g
s
.70705 .7622 m .7088 .78082 L .73983 .77973 L p .707 .577 .707 r
F P
0 g
s
.65432 .63566 m .65004 .67199 L .67091 .68172 L p .707 .577 .707 r
F P
0 g
s
.50658 .24266 m .5096 .74487 L .46466 .74621 L p .707 .577 .707 r
F P
0 g
s
.7088 .78082 m .70705 .7622 L .67973 .7608 L p .707 .577 .707 r
F P
0 g
s
.67973 .7608 m .68148 .77942 L .7088 .78082 L p .707 .577 .707 r
F P
0 g
s
.79907 .75211 m .80082 .77073 L .82481 .76371 L p .707 .577 .707 r
F P
0 g
s
.82481 .76371 m .82306 .74508 L .79907 .75211 L p .707 .577 .707 r
F P
0 g
s
.64748 .5849 m .63968 .63905 L .65205 .65008 L p .707 .577 .707 r
F P
0 g
s
.65004 .67199 m .65432 .63566 L .64188 .62519 L p .707 .577 .707 r
F P
0 g
s
.68148 .77942 m .67973 .7608 L .6588 .75704 L p .707 .577 .707 r
F P
0 g
s
.64188 .62519 m .6376 .66152 L .65004 .67199 L p .707 .577 .707 r
F P
0 g
s
.6588 .75704 m .66055 .77567 L .68148 .77942 L p .707 .577 .707 r
F P
0 g
s
.63968 .63905 m .64748 .5849 L .64473 .57433 L p .707 .577 .707 r
F P
0 g
s
.82306 .74508 m .82481 .76371 L .84115 .75587 L p .707 .577 .707 r
F P
0 g
s
.84115 .75587 m .8394 .73724 L .82306 .74508 L p .707 .577 .707 r
F P
0 g
s
.64473 .57433 m .63692 .62849 L .63968 .63905 L p .707 .577 .707 r
F P
0 g
s
.6376 .66152 m .64188 .62519 L .63908 .61498 L p .707 .577 .707 r
F P
0 g
s
.66055 .77567 m .6588 .75704 L .64631 .7513 L p .707 .577 .707 r
F P
0 g
s
.64631 .7513 m .64806 .76993 L .66055 .77567 L p .707 .577 .707 r
F P
0 g
s
.83615 .64862 m .83956 .62495 L p .8467 .60503 L .707 .577 .707 r
F P
0 g
s
.84395 .59447 m .83615 .64862 L .82378 .63759 L p .707 .577 .707 r
F P
0 g
s
.83888 .6307 m .8346 .66703 L .8333 .66594 L p .707 .577 .707 r
F P
0 g
s
.8333 .66594 m .82216 .65656 L p .83862 .63111 L .707 .577 .707 r
F P
0 g
s
.83862 .63111 m .83888 .6307 L .8333 .66594 L .707 .577 .707 r
F
.83956 .62495 m .84395 .59447 L .84412 .59511 L p F P
0 g
s
.84412 .59511 m .8467 .60503 L p .83956 .62495 L .707 .577 .707 r
F P
0 g
s
.63908 .61498 m .6348 .65131 L .6376 .66152 L p .707 .577 .707 r
F P
0 g
s
.8394 .73724 m .84115 .75587 L .84826 .74797 L p .707 .577 .707 r
F P
0 g
s
.84826 .74797 m .84651 .72935 L .8394 .73724 L p .707 .577 .707 r
F P
0 g
s
.6348 .65131 m .63908 .61498 L .6462 .60604 L p .707 .577 .707 r
F P
0 g
s
.63692 .62849 m .64473 .57433 L .65186 .56527 L p .707 .577 .707 r
F P
0 g
s
.8346 .66703 m .83888 .6307 L .84168 .64091 L p .707 .577 .707 r
F P
0 g
s
.64806 .76993 m .64631 .7513 L .64348 .74414 L p .707 .577 .707 r
F P
0 g
s
.6462 .60604 m .64192 .64237 L .6348 .65131 L p .707 .577 .707 r
F P
0 g
s
.65186 .56527 m .64406 .61943 L .63692 .62849 L p .707 .577 .707 r
F P
0 g
s
.64348 .74414 m .64523 .76276 L .64806 .76993 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38781 .61024 m .39562 .55609 L .36476 .54979 L p .707 .577 .707 r
F P
0 g
s
.39562 .55609 m .38781 .61024 L .41937 .61343 L p .707 .577 .707 r
F P
0 g
s
.41937 .61343 m .42717 .55928 L .39562 .55609 L p .707 .577 .707 r
F P
0 g
s
.82378 .63759 m .82715 .6142 L p .84395 .59447 L .707 .577 .707 r
F P
0 g
s
.83158 .58344 m .82378 .63759 L .803 .62717 L p .707 .577 .707 r
F P
0 g
s
.82644 .62023 m .82216 .65656 L .82041 .65574 L p .707 .577 .707 r
F P
0 g
s
.82041 .65574 m .80129 .64683 L p .82611 .62057 L .707 .577 .707 r
F P
0 g
s
.82611 .62057 m .82644 .62023 L .82041 .65574 L .707 .577 .707 r
F
.82715 .6142 m .83158 .58344 L .83207 .58387 L p F P
0 g
s
.83207 .58387 m .84395 .59447 L p .82715 .6142 L .707 .577 .707 r
F P
0 g
s
.42717 .55928 m .41937 .61343 L .44853 .6132 L p .707 .577 .707 r
F P
0 g
s
.44853 .6132 m .45633 .55905 L .42717 .55928 L p .707 .577 .707 r
F P
0 g
s
.64192 .64237 m .6462 .60604 L .66253 .59925 L p .707 .577 .707 r
F P
0 g
s
.64406 .61943 m .65186 .56527 L .66818 .5586 L p .707 .577 .707 r
F P
0 g
s
.84651 .72935 m .84826 .74797 L .84543 .74081 L p .707 .577 .707 r
F P
0 g
s
.84543 .74081 m .84368 .72218 L .84651 .72935 L p .707 .577 .707 r
F P
0 g
s
.35695 .60394 m .36476 .54979 L .33761 .541 L p .707 .577 .707 r
F P
0 g
s
.36476 .54979 m .35695 .60394 L .38781 .61024 L p .707 .577 .707 r
F P
0 g
s
.82216 .65656 m .82644 .62023 L .83888 .6307 L p .707 .577 .707 r
F P
0 g
s
.45633 .55905 m .44853 .6132 L .47244 .60957 L p .707 .577 .707 r
F P
0 g
s
.47244 .60957 m .48024 .55542 L .45633 .55905 L p .707 .577 .707 r
F P
0 g
s
.32981 .59515 m .33761 .541 L .31684 .53058 L p .707 .577 .707 r
F P
0 g
s
.33761 .541 m .32981 .59515 L .35695 .60394 L p .707 .577 .707 r
F P
0 g
s
.64523 .76276 m .64348 .74414 L .65058 .73625 L p .707 .577 .707 r
F P
0 g
s
.66253 .59925 m .65825 .63558 L .64192 .64237 L p .707 .577 .707 r
F P
0 g
s
.66818 .5586 m .66038 .61275 L .64406 .61943 L p .707 .577 .707 r
F P
0 g
s
.65058 .73625 m .65233 .75487 L .64523 .76276 L p .707 .577 .707 r
F P
0 g
s
.803 .62717 m .80632 .60413 L p .83158 .58344 L .707 .577 .707 r
F P
0 g
s
.81081 .57302 m .803 .62717 L .77613 .61847 L p .707 .577 .707 r
F P
0 g
s
.77346 .63872 m .74308 .6333 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77613 .61847 m .77586 .61838 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.7762 .61794 m .81081 .57302 L .77613 .61847 L .707 .577 .707 r
F
.78366 .56423 m .81081 .57302 L p .7762 .61794 L F P
0 g
s
.74308 .6333 m .74736 .59697 L .77823 .60247 L p .707 .577 .707 r
F P
0 g
s
.74308 .6333 m .77823 .60247 L .77822 .60258 L .707 .577 .707 r
F
.77586 .61838 m .77912 .59572 L p .7762 .61794 L F P
0 g
s
.77912 .59572 m .78366 .56423 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.77823 .60247 m .77833 .60249 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77833 .60249 m .77405 .63882 L .77346 .63872 L p .707 .577 .707 r
F P
0 g
s
.77822 .60258 m .77833 .60249 L .77346 .63872 L .707 .577 .707 r
F
.80557 .61051 m .80129 .64683 L .79982 .6464 L p F P
0 g
s
.79982 .6464 m .77405 .63882 L p .80531 .61075 L .707 .577 .707 r
F P
0 g
s
.80531 .61075 m .80557 .61051 L .79982 .6464 L .707 .577 .707 r
F
.80632 .60413 m .81081 .57302 L .81109 .57316 L p F P
0 g
s
.81109 .57316 m .83158 .58344 L p .80632 .60413 L .707 .577 .707 r
F P
0 g
s
.65825 .63558 m .66253 .59925 L .68649 .59526 L p .707 .577 .707 r
F P
0 g
s
.66038 .61275 m .66818 .5586 L .69209 .55497 L p .707 .577 .707 r
F P
0 g
s
.39682 .69811 m .39507 .67949 L .36404 .68058 L p .707 .577 .707 r
F P
0 g
s
.39507 .67949 m .39682 .69811 L .42853 .69464 L p .707 .577 .707 r
F P
0 g
s
.42853 .69464 m .42678 .67601 L .39507 .67949 L p .707 .577 .707 r
F P
0 g
s
.36404 .68058 m .36579 .69921 L .39682 .69811 L p .707 .577 .707 r
F P
0 g
s
.3861 .70969 m .39038 .67336 L .35942 .66784 L p .707 .577 .707 r
F P
0 g
s
.39038 .67336 m .3861 .70969 L .41775 .71218 L p .707 .577 .707 r
F P
0 g
s
.41775 .71218 m .42203 .67585 L .39038 .67336 L p .707 .577 .707 r
F P
0 g
s
.84368 .72218 m .84543 .74081 L .83293 .73507 L p .707 .577 .707 r
F P
0 g
s
.83293 .73507 m .83119 .71644 L .84368 .72218 L p .707 .577 .707 r
F P
0 g
s
.42678 .67601 m .42853 .69464 L .45781 .68911 L p .707 .577 .707 r
F P
0 g
s
.45781 .68911 m .45606 .67049 L .42678 .67601 L p .707 .577 .707 r
F P
0 g
s
.48024 .55542 m .47244 .60957 L .48876 .6029 L p .707 .577 .707 r
F P
0 g
s
.48876 .6029 m .49656 .54875 L .48024 .55542 L p .707 .577 .707 r
F P
0 g
s
.31684 .53058 m .30904 .58473 L .32981 .59515 L p .707 .577 .707 r
F P
0 g
s
.42203 .67585 m .41775 .71218 L .44698 .71139 L p .707 .577 .707 r
F P
0 g
s
.44698 .71139 m .45126 .67507 L .42203 .67585 L p .707 .577 .707 r
F P
0 g
s
.80129 .64683 m .80557 .61051 L .82644 .62023 L p .707 .577 .707 r
F P
0 g
s
.35514 .70417 m .35942 .66784 L .33218 .65982 L p .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36404 .68058 L .36121 .68043 L p .707 .577 .707 r
F P
0 g
s
.35942 .66784 m .35514 .70417 L .36111 .70523 L p .707 .577 .707 r
F P
0 g
s
.36125 .6707 m .35942 .66784 L .36111 .70523 L .707 .577 .707 r
F
.33218 .65982 m .3279 .69615 L .35514 .70417 L p F P
0 g
s
.36121 .68043 m .33672 .67918 L p .36115 .69601 L .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36121 .68043 L .36115 .69601 L .707 .577 .707 r
F
.33672 .67918 m .33847 .69781 L .36579 .69921 L p F P
0 g
s
.36111 .70523 m .3861 .70969 L p .36125 .6707 L .707 .577 .707 r
F P
0 g
s
.30904 .58473 m .31684 .53058 L .30447 .51955 L p .707 .577 .707 r
F P
0 g
s
.45606 .67049 m .45781 .68911 L .4818 .68209 L p .707 .577 .707 r
F P
0 g
s
.4818 .68209 m .48005 .66346 L .45606 .67049 L p .707 .577 .707 r
F P
0 g
s
.68649 .59526 m .68221 .63159 L .65825 .63558 L p .707 .577 .707 r
F P
0 g
s
.69209 .55497 m .68429 .60913 L .66038 .61275 L p .707 .577 .707 r
F P
0 g
s
.45126 .67507 m .44698 .71139 L .47094 .70741 L p .707 .577 .707 r
F P
0 g
s
.47094 .70741 m .47522 .67108 L .45126 .67507 L p .707 .577 .707 r
F P
0 g
s
.68221 .63159 m .68649 .59526 L .71572 .59448 L p .707 .577 .707 r
F P
0 g
s
.68429 .60913 m .69209 .55497 L .72125 .55474 L p .707 .577 .707 r
F P
0 g
s
.65233 .75487 m .65058 .73625 L .66693 .7284 L p .707 .577 .707 r
F P
0 g
s
.3279 .69615 m .33218 .65982 L .31131 .6501 L p .707 .577 .707 r
F P
0 g
s
.66693 .7284 m .66868 .74703 L .65233 .75487 L p .707 .577 .707 r
F P
0 g
s
.31131 .6501 m .30703 .68643 L .3279 .69615 L p .707 .577 .707 r
F P
0 g
s
.33847 .69781 m .33672 .67918 L .31579 .67543 L p .707 .577 .707 r
F P
0 g
s
.30447 .51955 m .29667 .5737 L .30904 .58473 L p .707 .577 .707 r
F P
0 g
s
.77405 .63882 m .77833 .60249 L .80557 .61051 L p .707 .577 .707 r
F P
0 g
s
.31579 .67543 m .31754 .69405 L .33847 .69781 L p .707 .577 .707 r
F P
0 g
s
.74736 .59697 m .74308 .6333 L .71144 .63081 L p .707 .577 .707 r
F P
0 g
s
.78366 .56423 m .77586 .61838 L .745 .61208 L p .707 .577 .707 r
F P
0 g
s
.71144 .63081 m .71572 .59448 L .74736 .59697 L p .707 .577 .707 r
F P
0 g
s
.745 .61208 m .7528 .55793 L .78366 .56423 L p .707 .577 .707 r
F P
0 g
s
.49656 .54875 m .48876 .6029 L .49589 .59384 L p .707 .577 .707 r
F P
0 g
s
.49589 .59384 m .50369 .53969 L .49656 .54875 L p .707 .577 .707 r
F P
0 g
s
.83119 .71644 m .83293 .73507 L .81201 .73131 L p .707 .577 .707 r
F P
0 g
s
.81201 .73131 m .81026 .71269 L .83119 .71644 L p .707 .577 .707 r
F P
0 g
s
.71572 .59448 m .71144 .63081 L .68221 .63159 L p .707 .577 .707 r
F P
0 g
s
.71344 .60889 m .72125 .55474 L .7528 .55793 L p .707 .577 .707 r
F P
0 g
s
.72125 .55474 m .71344 .60889 L .68429 .60913 L p .707 .577 .707 r
F P
0 g
s
.48005 .66346 m .4818 .68209 L .49814 .67425 L p .707 .577 .707 r
F P
0 g
s
.49814 .67425 m .49639 .65562 L .48005 .66346 L p .707 .577 .707 r
F P
0 g
s
.29667 .5737 m .30447 .51955 L .30172 .50899 L p .707 .577 .707 r
F P
0 g
s
.7528 .55793 m .745 .61208 L .71344 .60889 L p .707 .577 .707 r
F P
0 g
s
.47522 .67108 m .47094 .70741 L .48727 .70062 L p .707 .577 .707 r
F P
0 g
s
.48727 .70062 m .49155 .66429 L .47522 .67108 L p .707 .577 .707 r
F P
0 g
s
.30703 .68643 m .31131 .6501 L .29887 .63962 L p .707 .577 .707 r
F P
0 g
s
.66868 .74703 m .66693 .7284 L .69092 .72138 L p .707 .577 .707 r
F P
0 g
s
.29887 .63962 m .29459 .67595 L .30703 .68643 L p .707 .577 .707 r
F P
0 g
s
.31754 .69405 m .31579 .67543 L .3033 .66968 L p .707 .577 .707 r
F P
0 g
s
.69092 .72138 m .69267 .74 L .66868 .74703 L p .707 .577 .707 r
F P
0 g
s
.3033 .66968 m .30505 .68831 L .31754 .69405 L p .707 .577 .707 r
F P
0 g
s
.30172 .50899 m .29391 .56314 L .29667 .5737 L p .707 .577 .707 r
F P
0 g
s
.81026 .71269 m .81201 .73131 L .78469 .72991 L p .707 .577 .707 r
F P
0 g
s
.78469 .72991 m .78294 .71129 L .81026 .71269 L p .707 .577 .707 r
F P
0 g
s
.50369 .53969 m .49589 .59384 L .49314 .58327 L p .707 .577 .707 r
F P
0 g
s
.49314 .58327 m .50094 .52912 L .50369 .53969 L p .707 .577 .707 r
F P
0 g
s
.49639 .65562 m .49814 .67425 L .50525 .66636 L p .707 .577 .707 r
F P
0 g
s
.50525 .66636 m .5035 .64773 L .49639 .65562 L p .707 .577 .707 r
F P
0 g
s
.49155 .66429 m .48727 .70062 L .49439 .69168 L p .707 .577 .707 r
F P
0 g
s
.49439 .69168 m .49867 .65535 L .49155 .66429 L p .707 .577 .707 r
F P
0 g
s
.69267 .74 m .69092 .72138 L .7202 .71586 L p .707 .577 .707 r
F P
0 g
s
.29391 .56314 m .30172 .50899 L .30885 .49993 L p .707 .577 .707 r
F P
0 g
s
.7202 .71586 m .72195 .73448 L .69267 .74 L p .707 .577 .707 r
F P
0 g
s
.29459 .67595 m .29887 .63962 L .29607 .62942 L p .707 .577 .707 r
F P
0 g
s
.78294 .71129 m .78469 .72991 L .75366 .73101 L p .707 .577 .707 r
F P
0 g
s
.75366 .73101 m .75191 .71238 L .78294 .71129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.72195 .73448 m .7202 .71586 L .75191 .71238 L p .707 .577 .707 r
F P
0 g
s
.30505 .68831 m .3033 .66968 L .30047 .66252 L p .707 .577 .707 r
F P
0 g
s
.75191 .71238 m .75366 .73101 L .72195 .73448 L p .707 .577 .707 r
F P
0 g
s
.30047 .66252 m .30222 .68114 L .30505 .68831 L p .707 .577 .707 r
F P
0 g
s
.29607 .62942 m .29179 .66575 L .29459 .67595 L p .707 .577 .707 r
F P
0 g
s
.30885 .49993 m .30105 .55408 L .29391 .56314 L p .707 .577 .707 r
F P
0 g
s
.50094 .52912 m .49314 .58327 L .48077 .57224 L p .707 .577 .707 r
F P
0 g
s
.48077 .57224 m .48857 .51809 L .50094 .52912 L p .707 .577 .707 r
F P
0 g
s
.5035 .64773 m .50525 .66636 L .50242 .65919 L p .707 .577 .707 r
F P
0 g
s
.50242 .65919 m .50067 .64056 L .5035 .64773 L p .707 .577 .707 r
F P
0 g
s
.49867 .65535 m .49439 .69168 L .49159 .68147 L p .707 .577 .707 r
F P
0 g
s
.49159 .68147 m .49587 .64514 L .49867 .65535 L p .707 .577 .707 r
F P
0 g
s
.30105 .55408 m .30885 .49993 L .32517 .49325 L p .707 .577 .707 r
F P
0 g
s
.29179 .66575 m .29607 .62942 L .30319 .62048 L p .707 .577 .707 r
F P
0 g
s
.30222 .68114 m .30047 .66252 L .30757 .65463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30757 .65463 m .30932 .67325 L .30222 .68114 L p .707 .577 .707 r
F P
0 g
s
.30319 .62048 m .29891 .65681 L .29179 .66575 L p .707 .577 .707 r
F P
0 g
s
.32517 .49325 m .31737 .54741 L .30105 .55408 L p .707 .577 .707 r
F P
0 g
s
.48857 .51809 m .48077 .57224 L .45999 .56182 L p .707 .577 .707 r
F P
0 g
s
.45999 .56182 m .4678 .50767 L .48857 .51809 L p .707 .577 .707 r
F P
0 g
s
.31737 .54741 m .32517 .49325 L .34908 .48963 L p .707 .577 .707 r
F P
0 g
s
.49587 .64514 m .49159 .68147 L .47915 .67099 L p .707 .577 .707 r
F P
0 g
s
.47915 .67099 m .48343 .63466 L .49587 .64514 L p .707 .577 .707 r
F P
0 g
s
.50067 .64056 m .50242 .65919 L .48992 .65345 L p .707 .577 .707 r
F P
0 g
s
.48992 .65345 m .48818 .63482 L .50067 .64056 L p .707 .577 .707 r
F P
0 g
s
.29891 .65681 m .30319 .62048 L .31952 .61368 L p .707 .577 .707 r
F P
0 g
s
.30932 .67325 m .30757 .65463 L .32392 .64679 L p .707 .577 .707 r
F P
0 g
s
.4678 .50767 m .45999 .56182 L .43285 .55303 L p .707 .577 .707 r
F P
0 g
s
.43285 .55303 m .44065 .49888 L .4678 .50767 L p .707 .577 .707 r
F P
0 g
s
.34908 .48963 m .34128 .54378 L .31737 .54741 L p .707 .577 .707 r
F P
0 g
s
.34128 .54378 m .34908 .48963 L .37824 .48939 L p .707 .577 .707 r
F P
0 g
s
.31952 .61368 m .31524 .65001 L .29891 .65681 L p .707 .577 .707 r
F P
0 g
s
.32392 .64679 m .32567 .66541 L .30932 .67325 L p .707 .577 .707 r
F P
0 g
s
.48343 .63466 m .47915 .67099 L .45828 .66127 L p .707 .577 .707 r
F P
0 g
s
.45828 .66127 m .46256 .62494 L .48343 .63466 L p .707 .577 .707 r
F P
0 g
s
.48818 .63482 m .48992 .65345 L .469 .64969 L p .707 .577 .707 r
F P
0 g
s
.469 .64969 m .46725 .63107 L .48818 .63482 L p .707 .577 .707 r
F P
0 g
s
.44065 .49888 m .43285 .55303 L .40199 .54674 L p .707 .577 .707 r
F P
0 g
s
.40199 .54674 m .40979 .49258 L .44065 .49888 L p .707 .577 .707 r
F P
0 g
s
.37043 .54355 m .37824 .48939 L .40979 .49258 L p .707 .577 .707 r
F P
0 g
s
.37824 .48939 m .37043 .54355 L .34128 .54378 L p .707 .577 .707 r
F P
0 g
s
.31524 .65001 m .31952 .61368 L .34348 .6097 L p .707 .577 .707 r
F P
0 g
s
.40979 .49258 m .40199 .54674 L .37043 .54355 L p .707 .577 .707 r
F P
0 g
s
.32567 .66541 m .32392 .64679 L .34791 .63976 L p .707 .577 .707 r
F P
0 g
s
.34791 .63976 m .34966 .65839 L .32567 .66541 L p .707 .577 .707 r
F P
0 g
s
.34348 .6097 m .3392 .64603 L .31524 .65001 L p .707 .577 .707 r
F P
0 g
s
.46256 .62494 m .45828 .66127 L .43629 .6548 L p .707 .577 .707 r
F P
0 g
s
.4364 .64848 m .41065 .64939 L p .43668 .63186 L .707 .577 .707 r
F P
0 g
s
.43629 .6548 m .43104 .65326 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.4364 .64844 m .46256 .62494 L .43629 .6548 L .707 .577 .707 r
F
.41065 .64939 m .4089 .63076 L .43672 .62978 L p F P
0 g
s
.41065 .64939 m .43672 .62978 L .43668 .63186 L .707 .577 .707 r
F
.43104 .65326 m .43532 .61693 L .43693 .6174 L p F P
0 g
s
.43693 .6174 m .46256 .62494 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.43104 .65326 m .43693 .6174 L .4364 .64844 L .707 .577 .707 r
F
.43672 .62978 m .43993 .62967 L p .43668 .63186 L F P
0 g
s
.43993 .62967 m .44168 .64829 L .4364 .64848 L p .707 .577 .707 r
F P
0 g
s
.43668 .63186 m .43993 .62967 L .4364 .64848 L .707 .577 .707 r
F
.46725 .63107 m .469 .64969 L .44168 .64829 L p F P
0 g
s
.44168 .64829 m .43993 .62967 L .46725 .63107 L p .707 .577 .707 r
F P
0 g
s
.3392 .64603 m .34348 .6097 L .37271 .60891 L p .707 .577 .707 r
F P
0 g
s
.34966 .65839 m .34791 .63976 L .37719 .63424 L p .707 .577 .707 r
F P
0 g
s
.4089 .63076 m .41065 .64939 L .37894 .65286 L p .707 .577 .707 r
F P
0 g
s
.43532 .61693 m .43104 .65326 L .40007 .64773 L p .707 .577 .707 r
F P
0 g
s
.37894 .65286 m .37719 .63424 L .4089 .63076 L p .707 .577 .707 r
F P
0 g
s
.40007 .64773 m .40435 .6114 L .43532 .61693 L p .707 .577 .707 r
F P
0 g
s
.37719 .63424 m .37894 .65286 L .34966 .65839 L p .707 .577 .707 r
F P
0 g
s
.37271 .60891 m .36843 .64524 L .3392 .64603 L p .707 .577 .707 r
F P
0 g
s
.36843 .64524 m .37271 .60891 L .40435 .6114 L p .707 .577 .707 r
F P
0 g
s
.40435 .6114 m .40007 .64773 L .36843 .64524 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007Ao
o`00Kgoo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`00L7oo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001]Ool006]oo`<000UJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH006Yoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0061ooa0000MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@002UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001IOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001VOol005Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Io
o`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH500000eYF001JEP02FUH3
0002FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001J
EP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00@005YF001JEP<000EJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`04001JEP000002FUH00`00FUIJEP02
FUH00`00FUIJEP06FUH00`00FUIJEP050009FUH50005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
4000C7oo001COol30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP02FUH400000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo10000eYF00<005YFFUH01UYF00@0
05YFFUIJEPL004Eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF3P001EYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01000@Goo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50006FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00Dgoo00<005YF
FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH005YF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH3000fOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P00=Goo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF0P002EYF0`00<Woo000iOol@000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00]JEP80
031oo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`0^Ool0039oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000Aoo`8000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00Oomoo`0]Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00Oomoo`0/Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000goo000000020002FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=oo`D000IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP020003Ool00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P0000=JEP0000000P000UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo
000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHH0002FUH00`00FUIJEP05FUH01000FUIJEUYF1@0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP8000EJEP<000EJEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0>00000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH40003FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH20006FUH30004FUH01P00FUIJEP00FUH002aoo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF
0080009JEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`000UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEP0000<002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP04001JEUYFFUH@0004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH010001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH500000eYF001JEP06FUH00`00FUIJEP04FUH8
0005FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000]Ool20003FUH50000
0eYF001JEP040009Ool70006FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo000/
Ool01000FUH005YF0`001EYF00<005YFFUH00eYF1@002goo100000AJEP00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0007FUH00`00FUIJ
EP02FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EUYF001JEP800004FUH005YFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool200000eYF001JEP02FUH0
1000FUIJEUYF400015YF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF00=JEP06001JEUYF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF009J
EP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF009J
EP8002eoo`00;7oo0`000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH015YF1`001Goo
0P000eYF1@001EYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF00<005YF
FUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=J
EP03001JEP0000<000]JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF1`0000=JEP0000000P000UYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF1@001eYF
00<005YFFUH00eYF10000UYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP8000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00H005YF000005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP040004FUH00`00FUIJEP07FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEP03001JEUYF00iJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF1@001UYF0P000UYF0P0015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00@005YFFUIJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP0>FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH2000^Ool002eoo`05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50006FUH2000015YF001JEP0015YF00<005YF0000
1@0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJEP05001JEUYF001J
EP04000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<0
05YFFUH03UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000^Ool0
02eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH20002FUH00`00
FUH00003FUH40005FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000025YF
001JEUYF001JEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUIJEP0>FUH00`00FUH000020004FUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH3000^Ool002ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP80009JEP04001JEP00FUH20003FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH300000eYF000000030002FUH01P00FUH00000FUH000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP02FUH017ooFUIJEUYF0P00
1UYF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01@00;Woo000_Ool20006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000EJEP03001J
EUYF00]JEPL000EJEP04001JEUYFFUH80003FUH01000FUH005YF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH010000UYF1P000eYF00<005YFFUH01EYF00@005YFFUIJEPH0009JEP<002ioo`00<7oo
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80
009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP<00003FUH005YF00AJEP03001JEP0000IJEPP000=JEP03001JEUYF009J
EPL000=JEP05001JEUYFOomJEP03000^Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00X0009JEP03001JEUYF00=JEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000IJEP03001JEUYF00IJ
EP03001JEP0000/000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;goo000cOol200000eYF
001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP04
001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00<7oo000eOol30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01@00FUIJEUYF000015YF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006FUH01000FUIJEUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00>7oo10000UYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH02UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000lOol50006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUH000020004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<007oo0000200015YF00<005YFFUH01EYF00@005YFFUIJEPD003Aoo`00@Goo10000UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo00Qooa0003Uoo`00=goo5@0015YF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH30005FUH0
1P00FUIJEP00FUH005=oo`00<goo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF5@001goo1`00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000AJEP06
001JEUYF001JEP00Dgoo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000>Ool01@00FUIJEP00FUH0200015YF00<005YFFUH01UYF00@005YFFUIJEP@000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF0080009JEP06001JEUYF001JEP00Dgoo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool01000FUIJEP001EYF00@005YF
FUIJEQ400003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<0009JEP8000QooaP003Aoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P0027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00=JEP80009JEP80009oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00=JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJ
EP0400001Goo001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH002eoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP03001JEUYF00=JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF009JEQH000AJEP03001JEUYF008002aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF009J
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00EJEP03001JEUYF00AJEPL001Ioo`<00003FUH005YF009JEP03001oogoo02Yoo`00
;7oo00<005YF00000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000MJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00AJEP03001JEUYF00@0021oo`<0009JEP03001oogoo02Yoo`00;7oo0P00
15YF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJEP03001J
EUYF009JEP@00003FUH007oo025oo`800003FUH00000008002]oo`00;7oo0P000UYF100000=JEP00
FUH01EYF00<005YFFUH015YF1P001Woo1@001eYF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YF00007goo
0`000eYF00@005YF000002]oo`00;7oo00=JEP0000000`000eYF00<005YFFUH015YF00<005YFFUH0
10004Goo0`0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04
001JEUYFFUH300000eYF00000003FUH00`00FUH0000LOol300000eYF001JEP04FUH00`00FUH0000[
Ool002]oo`80009JEP8000AJEP03001JEUYF00=JEP@001Qoo`<00003FUH005YF00AJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUH0000015YF00<005YF0000
0UYF0P006Goo100015YF00<005YFFUH00eYF0P00;7oo000[Ool2000015YF001JEP0015YF00<005YF
00000`007goo0`0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF
00@005YF001JEP8000EJEP80009JEP04001JEP00000EOol40002FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH00`00Oomoo`0[Ool002]oo`06001JEUYF001JEP000eYF10000eYF0`007Woo100000AJEP00
FUIJEP80009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP05001JEP00001JEP04
0002FUH00`00FUIJEP02FUH3000>Ool70006FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002]o
o`07001JEUYF001JEP00FUH00P000eYF00<005YFFUH015YF00<005YF00000P005Woo0`000eYF0`00
0UYF0P000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP04001JEP000002FUH00`00FUIJEP0H0004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH3000`Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP09
FUH90009Ool400000eYF0000000300000eYF00000002FUH20002FUH01000FUH000001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000bOol002aoo`04001JEP000002FUH3
0002FUH00`00FUIJEP0=FUH00`00FUIJEP02FUH?0005FUH00`00FUH000030002FUH200000eYF001J
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000dOol002eoo`<0009JEP03
001JEUYF00X000QJEP@000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000<000EJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD003Qoo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF001JEP030003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000mOol002moo`05001JEUYFFUH00004FUH00`00
FUIJEP0<FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP0015YF1`0015YF00<005YFFUH00UYF2@00
AWoo000`Ool200000eYF001JEP04FUH00`00FUIJEP0:FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001J
EP001UYF00D005YF000007oo00T004moo`00<Woo10000eYF00<005YFFUH02UYF00<005YF00000P00
15YF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP06001JEUYF001JEP000eYF1@00Fgoo000eOol:0007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=oo`00FUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001P00H7oo000hOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P00Igoo000lOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH000001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P00J7oo0013Ool80004
FUH00`00FUIJEP06FUH01000FUIJEUYF10002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Bgoo4@00
3goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YF00004P00Fgoo001]Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05FUH00`00FUIJ
EP04001GOol006moo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<005Eo
o`00LWoo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH005Aoo`00NGoo30001UYF00<005YF
FUH02UYF00<005YFFUH01P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH005Aoo`00QGoo5P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF20000eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo002COol200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90008Ool60003FUH01@00FUIJEUYF0000Dgoo002AOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9000GOol50002FUH00`00Oomoo`1AOol0091oo`80
00EJEP03001JEUYF009JEPH002=oo`H0059oo`00Sgoo00<005YF00001EYF00<005YF00000P009goo
0P000UYF00@005YF0000059oo`00Sgoo00@005YFFUH000=JEP<002Qoo`8000AJEP04001JEUYF001B
Ool008moo`05001JEUYF001JEP02000XOol300000eYF001JEP04FUH2001COol008moo`03001JEUYF
008002Aoo`H000AJEP03001JEUYF00=JEP8005=oo`00T7oo0P0000=JEP0000000P0067oo2@0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00T7oo0P000UYF00<005YFFUH0600015YF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000005Ioo`00T7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00F7oo
002@Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00003001KOol0095oo`800003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD005moo`00Tgoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00I7oo002GOol70004FUH00`00FUIJEP02FUH9001]
Ool009ioo`T007Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5918 .77847 m .60435 .72578 L .57399 .71684 L p .707 .577 .707 r
F P
0 g
s
.60435 .72578 m .5918 .77847 L .6229 .78404 L p .707 .577 .707 r
F P
0 g
s
.6229 .78404 m .63545 .73135 L .60435 .72578 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57399 .71684 L .57133 .7157 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57133 .7157 L .56054 .76543 L .707 .577 .707 r
F
.57399 .71684 m .56144 .76953 L .5918 .77847 L p F P
0 g
s
.58911 .77317 m .596 .73755 L .56811 .73052 L p .707 .577 .707 r
F P
0 g
s
.56811 .73052 m .56538 .72983 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.58911 .77317 m .56811 .73052 L .56745 .7336 L .707 .577 .707 r
F
.55849 .76545 m .56538 .72983 L .53848 .71963 L p F P
0 g
s
.56538 .72983 m .55849 .76545 L .56043 .76594 L p .707 .577 .707 r
F P
0 g
s
.5598 .76882 m .56144 .76953 L p .56054 .76543 L .707 .577 .707 r
F P
0 g
s
.56043 .76594 m .58911 .77317 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.56745 .7336 m .56538 .72983 L .56043 .76594 L .707 .577 .707 r
F
.53848 .71963 m .53158 .75524 L .55849 .76545 L p F P
0 g
s
.54735 .70541 m .5348 .75809 L .5598 .76882 L p .707 .577 .707 r
F P
0 g
s
.56054 .76543 m .54735 .70541 L .5598 .76882 L .707 .577 .707 r
F
.57133 .7157 m .54735 .70541 L p .56054 .76543 L F P
0 g
s
.63545 .73135 m .6229 .78404 L .65169 .7857 L p .707 .577 .707 r
F P
0 g
s
.65169 .7857 m .66425 .73301 L .63545 .73135 L p .707 .577 .707 r
F P
0 g
s
.596 .73755 m .58911 .77317 L .62044 .77764 L p .707 .577 .707 r
F P
0 g
s
.62044 .77764 m .62734 .74202 L .596 .73755 L p .707 .577 .707 r
F P
0 g
s
.62734 .74202 m .62044 .77764 L .64943 .77842 L p .707 .577 .707 r
F P
0 g
s
.64943 .77842 m .65633 .7428 L .62734 .74202 L p .707 .577 .707 r
F P
0 g
s
.53158 .75524 m .53848 .71963 L .51792 .70793 L p .707 .577 .707 r
F P
0 g
s
.5348 .75809 m .54735 .70541 L .52703 .6926 L p .707 .577 .707 r
F P
0 g
s
.66425 .73301 m .65169 .7857 L .67537 .78329 L p .707 .577 .707 r
F P
0 g
s
.67537 .78329 m .68792 .7306 L .66425 .73301 L p .707 .577 .707 r
F P
0 g
s
.65633 .7428 m .64943 .77842 L .67323 .77544 L p .707 .577 .707 r
F P
0 g
s
.67323 .77544 m .68013 .73983 L .65633 .7428 L p .707 .577 .707 r
F P
0 g
s
.51792 .70793 m .51102 .74354 L .53158 .75524 L p .707 .577 .707 r
F P
0 g
s
.52703 .6926 m .51448 .74529 L .5348 .75809 L p .707 .577 .707 r
F P
0 g
s
.51102 .74354 m .51792 .70793 L .50572 .69588 L p .707 .577 .707 r
F P
0 g
s
.51448 .74529 m .52703 .6926 L .51502 .67968 L p .707 .577 .707 r
F P
0 g
s
.60649 .88413 m .60367 .86553 L .57287 .86848 L p .707 .577 .707 r
F P
0 g
s
.60367 .86553 m .60649 .88413 L .638 .87898 L p .707 .577 .707 r
F P
0 g
s
.638 .87898 m .63518 .86038 L .60367 .86553 L p .707 .577 .707 r
F P
0 g
s
.68792 .7306 m .67537 .78329 L .69161 .77703 L p .707 .577 .707 r
F P
0 g
s
.69161 .77703 m .70416 .72435 L .68792 .7306 L p .707 .577 .707 r
F P
0 g
s
.63518 .86038 m .638 .87898 L .66712 .87213 L p .707 .577 .707 r
F P
0 g
s
.66712 .87213 m .66429 .85354 L .63518 .86038 L p .707 .577 .707 r
F P
0 g
s
.57287 .86848 m .57569 .88707 L .60649 .88413 L p .707 .577 .707 r
F P
0 g
s
.68013 .73983 m .67323 .77544 L .68951 .769 L p .707 .577 .707 r
F P
0 g
s
.68951 .769 m .69641 .73338 L .68013 .73983 L p .707 .577 .707 r
F P
0 g
s
.57569 .88707 m .57287 .86848 L .54578 .86893 L p .707 .577 .707 r
F P
0 g
s
.54578 .86893 m .5486 .88753 L .57569 .88707 L p .707 .577 .707 r
F P
0 g
s
.66429 .85354 m .66712 .87213 L .691 .86426 L p .707 .577 .707 r
F P
0 g
s
.691 .86426 m .68818 .84566 L .66429 .85354 L p .707 .577 .707 r
F P
0 g
s
.50572 .69588 m .49882 .7315 L .51102 .74354 L p .707 .577 .707 r
F P
0 g
s
.51502 .67968 m .50247 .73237 L .51448 .74529 L p .707 .577 .707 r
F P
0 g
s
.5486 .88753 m .54578 .86893 L .52505 .86685 L p .707 .577 .707 r
F P
0 g
s
.50247 .73237 m .51502 .67968 L .5125 .6679 L p .707 .577 .707 r
F P
0 g
s
.70416 .72435 m .69161 .77703 L .69882 .76756 L p .707 .577 .707 r
F P
0 g
s
.69882 .76756 m .71138 .71487 L .70416 .72435 L p .707 .577 .707 r
F P
0 g
s
.52505 .86685 m .52788 .88544 L .5486 .88753 L p .707 .577 .707 r
F P
0 g
s
.68818 .84566 m .691 .86426 L .70731 .85612 L p .707 .577 .707 r
F P
0 g
s
.70731 .85612 m .70449 .83752 L .68818 .84566 L p .707 .577 .707 r
F P
0 g
s
.69641 .73338 m .68951 .769 L .69668 .75971 L p .707 .577 .707 r
F P
0 g
s
.69668 .75971 m .70358 .72409 L .69641 .73338 L p .707 .577 .707 r
F P
0 g
s
.49882 .7315 m .50572 .69588 L .50308 .68466 L p .707 .577 .707 r
F P
0 g
s
.5125 .6679 m .49995 .72059 L .50247 .73237 L p .707 .577 .707 r
F P
0 g
s
.50308 .68466 m .49618 .72028 L .49882 .7315 L p .707 .577 .707 r
F P
0 g
s
.52788 .88544 m .52505 .86685 L .51273 .86243 L p .707 .577 .707 r
F P
0 g
s
.51273 .86243 m .51555 .88103 L .52788 .88544 L p .707 .577 .707 r
F P
0 g
s
.49995 .72059 m .5125 .6679 L .51972 .65842 L p .707 .577 .707 r
F P
0 g
s
.70358 .72409 m .69668 .75971 L .69404 .7485 L p .707 .577 .707 r
F P
0 g
s
.71138 .71487 m .69882 .76756 L .6963 .75578 L p .707 .577 .707 r
F P
0 g
s
.6963 .75578 m .70886 .70309 L .71138 .71487 L p .707 .577 .707 r
F P
0 g
s
.4905 .8214 m .48561 .31901 L .4416 .31676 L p .707 .577 .707 r
F P
0 g
s
.49618 .72028 m .50308 .68466 L .51025 .67538 L p .707 .577 .707 r
F P
0 g
s
.51972 .65842 m .50716 .71111 L .49995 .72059 L p .707 .577 .707 r
F P
0 g
s
.51025 .67538 m .50335 .71099 L .49618 .72028 L p .707 .577 .707 r
F P
0 g
s
.50716 .71111 m .51972 .65842 L .53596 .65217 L p .707 .577 .707 r
F P
0 g
s
.50335 .71099 m .51025 .67538 L .52653 .66893 L p .707 .577 .707 r
F P
0 g
s
.53596 .65217 m .5234 .70486 L .50716 .71111 L p .707 .577 .707 r
F P
0 g
s
.52653 .66893 m .51963 .70455 L .50335 .71099 L p .707 .577 .707 r
F P
0 g
s
.5234 .70486 m .53596 .65217 L .55963 .64976 L p .707 .577 .707 r
F P
0 g
s
.55963 .64976 m .54708 .70244 L .5234 .70486 L p .707 .577 .707 r
F P
0 g
s
.51963 .70455 m .52653 .66893 L .55033 .66595 L p .707 .577 .707 r
F P
0 g
s
.55033 .66595 m .54343 .70157 L .51963 .70455 L p .707 .577 .707 r
F P
0 g
s
.48561 .31901 m .4905 .8214 L .53544 .81991 L p .707 .577 .707 r
F P
0 g
s
.53544 .81991 m .53055 .31752 L .48561 .31901 L p .707 .577 .707 r
F P
0 g
s
.70449 .83752 m .70731 .85612 L .71445 .84853 L p .707 .577 .707 r
F P
0 g
s
.71445 .84853 m .71163 .82993 L .70449 .83752 L p .707 .577 .707 r
F P
0 g
s
.54708 .70244 m .55963 .64976 L .58843 .65142 L p .707 .577 .707 r
F P
0 g
s
.58843 .65142 m .57588 .7041 L .54708 .70244 L p .707 .577 .707 r
F P
0 g
s
.54343 .70157 m .55033 .66595 L .57932 .66674 L p .707 .577 .707 r
F P
0 g
s
.57932 .66674 m .57242 .70236 L .54343 .70157 L p .707 .577 .707 r
F P
0 g
s
.53055 .31752 m .53544 .81991 L .57692 .81483 L p .707 .577 .707 r
F P
0 g
s
.57588 .7041 m .58843 .65142 L .61953 .65699 L p .707 .577 .707 r
F P
0 g
s
.61953 .65699 m .60698 .70968 L .57588 .7041 L p .707 .577 .707 r
F P
0 g
s
.57242 .70236 m .57932 .66674 L .61066 .67121 L p .707 .577 .707 r
F P
0 g
s
.61066 .67121 m .60376 .70682 L .57242 .70236 L p .707 .577 .707 r
F P
0 g
s
.57692 .81483 m .57203 .31244 L .53055 .31752 L p .707 .577 .707 r
F P
0 g
s
.69404 .7485 m .70094 .71288 L .70358 .72409 L p .707 .577 .707 r
F P
0 g
s
.44649 .81915 m .4416 .31676 L .40284 .31099 L p .707 .577 .707 r
F P
0 g
s
.4416 .31676 m .44649 .81915 L .4905 .8214 L p .707 .577 .707 r
F P
0 g
s
.51555 .88103 m .51273 .86243 L .51 .85612 L p .707 .577 .707 r
F P
0 g
s
.57203 .31244 m .57692 .81483 L .61087 .80665 L p .707 .577 .707 r
F P
0 g
s
.66818 .68913 m .66128 .72475 L .63609 .71519 L p .707 .577 .707 r
F P
0 g
s
.63658 .71288 m .66818 .68913 L .63609 .71519 L .707 .577 .707 r
F
.63547 .71807 m .60698 .70968 L p .64576 .67014 L F P
0 g
s
.63438 .71454 m .64128 .67892 L .66818 .68913 L p .707 .577 .707 r
F P
0 g
s
.64989 .66593 m .63733 .71862 L .63547 .71807 L p .707 .577 .707 r
F P
0 g
s
.64576 .67014 m .64989 .66593 L .63547 .71807 L .707 .577 .707 r
F
.63609 .71519 m .63438 .71454 L p .63658 .71288 L F P
0 g
s
.60698 .70968 m .61953 .65699 L .64989 .66593 L p .707 .577 .707 r
F P
0 g
s
.64128 .67892 m .63438 .71454 L .60376 .70682 L p .707 .577 .707 r
F P
0 g
s
.60376 .70682 m .61066 .67121 L .64128 .67892 L p .707 .577 .707 r
F P
0 g
s
.61087 .80665 m .60598 .30426 L .57203 .31244 L p .707 .577 .707 r
F P
0 g
s
.24879 .69549 m .26134 .6428 L .23099 .63386 L p .707 .577 .707 r
F P
0 g
s
.26134 .6428 m .24879 .69549 L .27989 .70106 L p .707 .577 .707 r
F P
0 g
s
.27989 .70106 m .29244 .64837 L .26134 .6428 L p .707 .577 .707 r
F P
0 g
s
.51 .85612 m .51282 .87471 L .51555 .88103 L p .707 .577 .707 r
F P
0 g
s
.21843 .68655 m .23099 .63386 L .20434 .62243 L p .707 .577 .707 r
F P
0 g
s
.23099 .63386 m .21843 .68655 L .24879 .69549 L p .707 .577 .707 r
F P
0 g
s
.29244 .64837 m .27989 .70106 L .30869 .70272 L p .707 .577 .707 r
F P
0 g
s
.30869 .70272 m .32124 .65003 L .29244 .64837 L p .707 .577 .707 r
F P
0 g
s
.70094 .71288 m .69404 .7485 L .68184 .73645 L p .707 .577 .707 r
F P
0 g
s
.70886 .70309 m .6963 .75578 L .68429 .74285 L p .707 .577 .707 r
F P
0 g
s
.68184 .73645 m .68874 .70083 L .70094 .71288 L p .707 .577 .707 r
F P
0 g
s
.68429 .74285 m .69685 .69017 L .70886 .70309 L p .707 .577 .707 r
F P
0 g
s
.71163 .82993 m .71445 .84853 L .71172 .84221 L p .707 .577 .707 r
F P
0 g
s
.71172 .84221 m .7089 .82361 L .71163 .82993 L p .707 .577 .707 r
F P
0 g
s
.40773 .81338 m .40284 .31099 L .37311 .30227 L p .707 .577 .707 r
F P
0 g
s
.40284 .31099 m .40773 .81338 L .44649 .81915 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19179 .67511 m .20434 .62243 L .18402 .60962 L p .707 .577 .707 r
F P
0 g
s
.20434 .62243 m .19179 .67511 L .21843 .68655 L p .707 .577 .707 r
F P
0 g
s
.32124 .65003 m .30869 .70272 L .33236 .70031 L p .707 .577 .707 r
F P
0 g
s
.33236 .70031 m .34492 .64762 L .32124 .65003 L p .707 .577 .707 r
F P
0 g
s
.60598 .30426 m .61087 .80665 L .63398 .79618 L p .707 .577 .707 r
F P
0 g
s
.63398 .79618 m .62909 .29379 L .60598 .30426 L p .707 .577 .707 r
F P
0 g
s
.51282 .87471 m .51 .85612 L .51714 .84852 L p .707 .577 .707 r
F P
0 g
s
.26348 .77482 m .26066 .75622 L .22986 .75917 L p .707 .577 .707 r
F P
0 g
s
.26066 .75622 m .26348 .77482 L .29499 .76967 L p .707 .577 .707 r
F P
0 g
s
.29499 .76967 m .29217 .75108 L .26066 .75622 L p .707 .577 .707 r
F P
0 g
s
.68874 .70083 m .68184 .73645 L .66128 .72475 L p .707 .577 .707 r
F P
0 g
s
.66128 .72475 m .66818 .68913 L .68874 .70083 L p .707 .577 .707 r
F P
0 g
s
.69685 .69017 m .68429 .74285 L .66398 .73005 L p .707 .577 .707 r
F P
0 g
s
.66398 .73005 m .67653 .67736 L .69685 .69017 L p .707 .577 .707 r
F P
0 g
s
.51714 .84852 m .51996 .86712 L .51282 .87471 L p .707 .577 .707 r
F P
0 g
s
.29217 .75108 m .29499 .76967 L .32411 .76283 L p .707 .577 .707 r
F P
0 g
s
.32411 .76283 m .32128 .74423 L .29217 .75108 L p .707 .577 .707 r
F P
0 g
s
.22986 .75917 m .23268 .77777 L .26348 .77482 L p .707 .577 .707 r
F P
0 g
s
.18402 .60962 m .17147 .66231 L .19179 .67511 L p .707 .577 .707 r
F P
0 g
s
.17147 .66231 m .18402 .60962 L .17202 .5967 L p .707 .577 .707 r
F P
0 g
s
.23268 .77777 m .22986 .75917 L .20277 .75962 L p .707 .577 .707 r
F P
0 g
s
.34492 .64762 m .33236 .70031 L .3486 .69405 L p .707 .577 .707 r
F P
0 g
s
.3486 .69405 m .36116 .64137 L .34492 .64762 L p .707 .577 .707 r
F P
0 g
s
.7089 .82361 m .71172 .84221 L .6994 .83779 L p .707 .577 .707 r
F P
0 g
s
.6994 .83779 m .69657 .8192 L .7089 .82361 L p .707 .577 .707 r
F P
0 g
s
.2278 .77731 m .22237 .77595 L p .22774 .78575 L .707 .577 .707 r
F P
0 g
s
.21548 .81156 m .22237 .77595 L .19547 .76574 L p .707 .577 .707 r
F P
0 g
s
.22237 .77595 m .21548 .81156 L .2461 .81928 L p .707 .577 .707 r
F P
0 g
s
.20277 .75962 m .20559 .77822 L .2278 .77785 L p .707 .577 .707 r
F P
0 g
s
.2278 .77785 m .23268 .77777 L p .22782 .77482 L .707 .577 .707 r
F P
0 g
s
.22782 .77482 m .20277 .75962 L .2278 .77785 L .707 .577 .707 r
F
.2461 .81928 m .25299 .78366 L .2278 .77731 L p F P
0 g
s
.2461 .81928 m .2278 .77731 L .22774 .78575 L .707 .577 .707 r
F
.25299 .78366 m .2461 .81928 L .27743 .82375 L p F P
0 g
s
.27743 .82375 m .28433 .78813 L .25299 .78366 L p .707 .577 .707 r
F P
0 g
s
.378 .80466 m .37311 .30227 L .35534 .29145 L p .707 .577 .707 r
F P
0 g
s
.37311 .30227 m .378 .80466 L .40773 .81338 L p .707 .577 .707 r
F P
0 g
s
.32128 .74423 m .32411 .76283 L .34799 .75495 L p .707 .577 .707 r
F P
0 g
s
.34799 .75495 m .34517 .73635 L .32128 .74423 L p .707 .577 .707 r
F P
0 g
s
.28433 .78813 m .27743 .82375 L .30642 .82453 L p .707 .577 .707 r
F P
0 g
s
.30642 .82453 m .31332 .78892 L .28433 .78813 L p .707 .577 .707 r
F P
0 g
s
.67653 .67736 m .66398 .73005 L .63733 .71862 L p .707 .577 .707 r
F P
0 g
s
.63733 .71862 m .64989 .66593 L .67653 .67736 L p .707 .577 .707 r
F P
0 g
s
.19547 .76574 m .18857 .80135 L .21548 .81156 L p .707 .577 .707 r
F P
0 g
s
.18857 .80135 m .19547 .76574 L .17491 .75404 L p .707 .577 .707 r
F P
0 g
s
.20559 .77822 m .20277 .75962 L .18205 .75754 L p .707 .577 .707 r
F P
0 g
s
.17202 .5967 m .15946 .64939 L .17147 .66231 L p .707 .577 .707 r
F P
0 g
s
.51996 .86712 m .51714 .84852 L .53345 .84038 L p .707 .577 .707 r
F P
0 g
s
.31332 .78892 m .30642 .82453 L .33022 .82156 L p .707 .577 .707 r
F P
0 g
s
.33022 .82156 m .33712 .78594 L .31332 .78892 L p .707 .577 .707 r
F P
0 g
s
.18205 .75754 m .18487 .77614 L .20559 .77822 L p .707 .577 .707 r
F P
0 g
s
.53345 .84038 m .53627 .85898 L .51996 .86712 L p .707 .577 .707 r
F P
0 g
s
.34517 .73635 m .34799 .75495 L .3643 .74681 L p .707 .577 .707 r
F P
0 g
s
.3643 .74681 m .36148 .72822 L .34517 .73635 L p .707 .577 .707 r
F P
0 g
s
.62909 .29379 m .63398 .79618 L .64398 .78444 L p .707 .577 .707 r
F P
0 g
s
.64398 .78444 m .63909 .28205 L .62909 .29379 L p .707 .577 .707 r
F P
0 g
s
.15946 .64939 m .17202 .5967 L .16949 .58492 L p .707 .577 .707 r
F P
0 g
s
.36116 .64137 m .3486 .69405 L .35581 .68457 L p .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .36552 .64384 L p .36116 .64137 L .707 .577 .707 r
F P
0 g
s
.36632 .63458 m .36116 .64137 L p .36552 .64384 L .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .35329 .6728 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .36837 .63189 L .36632 .63458 L p .707 .577 .707 r
F P
0 g
s
.36837 .63189 m .36552 .64384 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .35581 .68457 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .36125 .26785 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .36165 .6156 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34179 .65905 m .36165 .6156 L .3622 .62601 L .707 .577 .707 r
F
.34129 .65987 m .34181 .65873 L .34179 .65905 L F
.34181 .65873 m .36165 .6156 L .34179 .65905 L F
.36165 .6156 m .36585 .62011 L p .3622 .62601 L F P
0 g
s
.36585 .62011 m .36837 .63189 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .36261 .6337 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .36585 .62011 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .34129 .65987 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36585 .62011 m .36261 .6337 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .35329 .6728 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.35367 .80582 m .36057 .77021 L .3534 .77949 L p .707 .577 .707 r
F P
0 g
s
.3534 .77949 m .3465 .81511 L .35367 .80582 L p .707 .577 .707 r
F P
0 g
s
.36057 .77021 m .35367 .80582 L .35103 .79461 L p .707 .577 .707 r
F P
0 g
s
.35103 .79461 m .35793 .75899 L .36057 .77021 L p .707 .577 .707 r
F P
0 g
s
.36148 .72822 m .3643 .74681 L .37144 .73922 L p .707 .577 .707 r
F P
0 g
s
.37144 .73922 m .36862 .72062 L .36148 .72822 L p .707 .577 .707 r
F P
0 g
s
.36589 .7143 m .36871 .7329 L .35639 .72849 L p .707 .577 .707 r
F P
0 g
s
.35639 .72849 m .35356 .70989 L .36589 .7143 L p .707 .577 .707 r
F P
0 g
s
.3465 .81511 m .3534 .77949 L .33712 .78594 L p .707 .577 .707 r
F P
0 g
s
.35793 .75899 m .35103 .79461 L .34186 .78555 L p .707 .577 .707 r
F P
0 g
s
.34186 .78555 m .33883 .78256 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.34217 .77845 m .35793 .75899 L .34186 .78555 L .707 .577 .707 r
F
.34573 .74694 m .35793 .75899 L p .34217 .77845 L F P
0 g
s
.33883 .78256 m .3429 .76157 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.3429 .76157 m .34573 .74694 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .35291 .45006 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35534 .29145 L p .35808 .61795 L .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .35125 .27959 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35658 .51956 m .35534 .29145 L .35488 .4873 L .707 .577 .707 r
F
.35808 .61795 m .35534 .29145 L .3571 .61452 L F
.36862 .72062 m .37144 .73922 L .36871 .7329 L p F P
0 g
s
.36871 .7329 m .36589 .7143 L .36862 .72062 L p .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .36023 .79384 L .378 .80466 L p .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .35291 .45006 L .36094 .29906 L .707 .577 .707 r
F
.35356 .70989 m .35639 .72849 L .33566 .7264 L p F P
0 g
s
.35755 .64032 m .35488 .4873 L .35614 .78198 L .707 .577 .707 r
F
.35614 .78198 m .36023 .79384 L p .35755 .64032 L F P
0 g
s
.35291 .45006 m .35614 .78198 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35755 .64032 m .35778 .6169 L .3571 .61452 L .707 .577 .707 r
F
.35894 .72025 m .35778 .6169 L .35755 .64032 L F
.35894 .72025 m .35808 .61795 L .35778 .6169 L F
.3571 .61452 m .35658 .51956 L .35488 .4873 L F
.35614 .78198 m .35355 .51579 L p .36034 .35898 L F P
0 g
s
.35355 .51579 m .35291 .45006 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.35945 .71432 m .35853 .61951 L p .35894 .72025 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35808 .61795 L .35894 .72025 L .707 .577 .707 r
F
.36023 .79384 m .35945 .71432 L p .35894 .72025 L F P
0 g
s
.36614 .77024 m .35614 .78198 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .36094 .29906 L .36135 .33587 L .707 .577 .707 r
F
.36034 .35898 m .36135 .33587 L .36614 .77024 L F
.36125 .26785 m .36146 .2893 L p .36094 .29906 L F P
0 g
s
.36146 .2893 m .36614 .77024 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35291 .45006 m .35125 .27959 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.34129 .65987 m .34188 .65736 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34188 .65736 m .35384 .60719 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.69657 .8192 m .6994 .83779 L .67867 .83571 L p .707 .577 .707 r
F P
0 g
s
.67867 .83571 m .67585 .81711 L .69657 .8192 L p .707 .577 .707 r
F P
0 g
s
.17491 .75404 m .16801 .78965 L .18857 .80135 L p .707 .577 .707 r
F P
0 g
s
.16801 .78965 m .17491 .75404 L .16271 .74199 L p .707 .577 .707 r
F P
0 g
s
.18487 .77614 m .18205 .75754 L .16972 .75312 L p .707 .577 .707 r
F P
0 g
s
.33712 .78594 m .33022 .82156 L .3465 .81511 L p .707 .577 .707 r
F P
0 g
s
.16972 .75312 m .17254 .77172 L .18487 .77614 L p .707 .577 .707 r
F P
0 g
s
.16949 .58492 m .15694 .63761 L .15946 .64939 L p .707 .577 .707 r
F P
0 g
s
.53627 .85898 m .53345 .84038 L .55733 .83251 L p .707 .577 .707 r
F P
0 g
s
.55733 .83251 m .56016 .8511 L .53627 .85898 L p .707 .577 .707 r
F P
0 g
s
.67585 .81711 m .67867 .83571 L .65158 .83616 L p .707 .577 .707 r
F P
0 g
s
.65158 .83616 m .64876 .81757 L .67585 .81711 L p .707 .577 .707 r
F P
0 g
s
.15694 .63761 m .16949 .58492 L .17671 .57544 L p .707 .577 .707 r
F P
0 g
s
.16271 .74199 m .15582 .77761 L .16801 .78965 L p .707 .577 .707 r
F P
0 g
s
.56016 .8511 m .55733 .83251 L .58645 .82566 L p .707 .577 .707 r
F P
0 g
s
.63909 .28205 m .64398 .78444 L .63989 .77258 L p .707 .577 .707 r
F P
0 g
s
.63989 .77258 m .635 .27019 L .63909 .28205 L p .707 .577 .707 r
F P
0 g
s
.58645 .82566 m .58927 .84426 L .56016 .8511 L p .707 .577 .707 r
F P
0 g
s
.15582 .77761 m .16271 .74199 L .16007 .73078 L p .707 .577 .707 r
F P
0 g
s
.17254 .77172 m .16972 .75312 L .16699 .74681 L p .707 .577 .707 r
F P
0 g
s
.64876 .81757 m .65158 .83616 L .62078 .83911 L p .707 .577 .707 r
F P
0 g
s
.62078 .83911 m .61796 .82051 L .64876 .81757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16699 .74681 m .16981 .76541 L .17254 .77172 L p .707 .577 .707 r
F P
0 g
s
.17671 .57544 m .16415 .62813 L .15694 .63761 L p .707 .577 .707 r
F P
0 g
s
.58927 .84426 m .58645 .82566 L .61796 .82051 L p .707 .577 .707 r
F P
0 g
s
.61796 .82051 m .62078 .83911 L .58927 .84426 L p .707 .577 .707 r
F P
0 g
s
.16007 .73078 m .15317 .76639 L .15582 .77761 L p .707 .577 .707 r
F P
0 g
s
.16415 .62813 m .17671 .57544 L .19295 .56919 L p .707 .577 .707 r
F P
0 g
s
.15317 .76639 m .16007 .73078 L .16724 .72149 L p .707 .577 .707 r
F P
0 g
s
.16981 .76541 m .16699 .74681 L .17413 .73921 L p .707 .577 .707 r
F P
0 g
s
.19295 .56919 m .18039 .62188 L .16415 .62813 L p .707 .577 .707 r
F P
0 g
s
.17413 .73921 m .17695 .75781 L .16981 .76541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.635 .27019 m .63989 .77258 L .62212 .76176 L p .707 .577 .707 r
F P
0 g
s
.62212 .76176 m .61723 .25937 L .635 .27019 L p .707 .577 .707 r
F P
0 g
s
.18039 .62188 m .19295 .56919 L .21662 .56677 L p .707 .577 .707 r
F P
0 g
s
.16724 .72149 m .16034 .75711 L .15317 .76639 L p .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .34129 .65987 L .32097 .64707 L p .707 .577 .707 r
F P
0 g
s
.32097 .64707 m .33352 .59438 L .35384 .60719 L p .707 .577 .707 r
F P
0 g
s
.36614 .77024 m .36125 .26785 L .38436 .25738 L p .707 .577 .707 r
F P
0 g
s
.16034 .75711 m .16724 .72149 L .18352 .71504 L p .707 .577 .707 r
F P
0 g
s
.17695 .75781 m .17413 .73921 L .19044 .73108 L p .707 .577 .707 r
F P
0 g
s
.21662 .56677 m .20407 .61946 L .18039 .62188 L p .707 .577 .707 r
F P
0 g
s
.20407 .61946 m .21662 .56677 L .24542 .56844 L p .707 .577 .707 r
F P
0 g
s
.33352 .59438 m .32097 .64707 L .29432 .63564 L p .707 .577 .707 r
F P
0 g
s
.29432 .63564 m .30688 .58295 L .33352 .59438 L p .707 .577 .707 r
F P
0 g
s
.19044 .73108 m .19326 .74967 L .17695 .75781 L p .707 .577 .707 r
F P
0 g
s
.33566 .7264 m .33284 .70781 L .35356 .70989 L p .707 .577 .707 r
F P
0 g
s
.18352 .71504 m .17662 .75066 L .16034 .75711 L p .707 .577 .707 r
F P
0 g
s
.23287 .62112 m .24542 .56844 L .27652 .57401 L p .707 .577 .707 r
F P
0 g
s
.24542 .56844 m .23287 .62112 L .20407 .61946 L p .707 .577 .707 r
F P
0 g
s
.30688 .58295 m .29432 .63564 L .26397 .6267 L p .707 .577 .707 r
F P
0 g
s
.26397 .6267 m .27652 .57401 L .30688 .58295 L p .707 .577 .707 r
F P
0 g
s
.61723 .25937 m .62212 .76176 L .59239 .75304 L p .707 .577 .707 r
F P
0 g
s
.59239 .75304 m .5875 .25065 L .61723 .25937 L p .707 .577 .707 r
F P
0 g
s
.27652 .57401 m .26397 .6267 L .23287 .62112 L p .707 .577 .707 r
F P
0 g
s
.34573 .74694 m .33883 .78256 L .31827 .77086 L p .707 .577 .707 r
F P
0 g
s
.31827 .77086 m .32517 .73524 L .34573 .74694 L p .707 .577 .707 r
F P
0 g
s
.19326 .74967 m .19044 .73108 L .21432 .7232 L p .707 .577 .707 r
F P
0 g
s
.17662 .75066 m .18352 .71504 L .20732 .71207 L p .707 .577 .707 r
F P
0 g
s
.21432 .7232 m .21715 .7418 L .19326 .74967 L p .707 .577 .707 r
F P
0 g
s
.33284 .70781 m .33566 .7264 L .30857 .72686 L p .707 .577 .707 r
F P
0 g
s
.30857 .72686 m .30575 .70826 L .33284 .70781 L p .707 .577 .707 r
F P
0 g
s
.38436 .25738 m .38925 .75977 L .36614 .77024 L p .707 .577 .707 r
F P
0 g
s
.38925 .75977 m .38436 .25738 L .41832 .24921 L p .707 .577 .707 r
F P
0 g
s
.20732 .71207 m .20042 .74768 L .17662 .75066 L p .707 .577 .707 r
F P
0 g
s
.729 .68643 m .74155 .63374 L .7112 .6248 L p .707 .577 .707 r
F P
0 g
s
.74155 .63374 m .729 .68643 L .7601 .692 L p .707 .577 .707 r
F P
0 g
s
.7601 .692 m .77265 .63931 L .74155 .63374 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .7112 .6248 L .70854 .62366 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .70854 .62366 L .69774 .67339 L .707 .577 .707 r
F
.7112 .6248 m .69864 .67749 L .729 .68643 L p F P
0 g
s
.72631 .68113 m .73321 .64551 L .70532 .63848 L p .707 .577 .707 r
F P
0 g
s
.70532 .63848 m .70259 .6378 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.72631 .68113 m .70532 .63848 L .70465 .64156 L .707 .577 .707 r
F
.69569 .67341 m .70259 .6378 L .67568 .62759 L p F P
0 g
s
.70259 .6378 m .69569 .67341 L .69763 .6739 L p .707 .577 .707 r
F P
0 g
s
.69701 .67679 m .69864 .67749 L p .69774 .67339 L .707 .577 .707 r
F P
0 g
s
.69763 .6739 m .72631 .68113 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.70465 .64156 m .70259 .6378 L .69763 .6739 L .707 .577 .707 r
F
.67568 .62759 m .66878 .6632 L .69569 .67341 L p F P
0 g
s
.68456 .61337 m .672 .66606 L .69701 .67679 L p .707 .577 .707 r
F P
0 g
s
.69774 .67339 m .68456 .61337 L .69701 .67679 L .707 .577 .707 r
F
.70854 .62366 m .68456 .61337 L p .69774 .67339 L F P
0 g
s
.77265 .63931 m .7601 .692 L .7889 .69366 L p .707 .577 .707 r
F P
0 g
s
.7889 .69366 m .80145 .64098 L .77265 .63931 L p .707 .577 .707 r
F P
0 g
s
.32517 .73524 m .31827 .77086 L .29137 .76065 L p .707 .577 .707 r
F P
0 g
s
.30303 .72684 m .32517 .73524 L p .30232 .75242 L .707 .577 .707 r
F P
0 g
s
.30575 .70826 m .30857 .72686 L .30302 .72739 L p .707 .577 .707 r
F P
0 g
s
.30302 .72739 m .27777 .7298 L p .3035 .70999 L .707 .577 .707 r
F P
0 g
s
.3035 .70999 m .30575 .70826 L .30302 .72739 L .707 .577 .707 r
F
.29137 .76065 m .29827 .72504 L .30303 .72684 L p F P
0 g
s
.29137 .76065 m .30303 .72684 L .30232 .75242 L .707 .577 .707 r
F
.21715 .7418 m .21432 .7232 L .24344 .71635 L p F P
0 g
s
.20042 .74768 m .20732 .71207 L .23631 .71285 L p .707 .577 .707 r
F P
0 g
s
.73321 .64551 m .72631 .68113 L .75765 .6856 L p .707 .577 .707 r
F P
0 g
s
.75765 .6856 m .76455 .64998 L .73321 .64551 L p .707 .577 .707 r
F P
0 g
s
.24344 .71635 m .24626 .73495 L .21715 .7418 L p .707 .577 .707 r
F P
0 g
s
.76455 .64998 m .75765 .6856 L .78663 .68638 L p .707 .577 .707 r
F P
0 g
s
.78663 .68638 m .79353 .65076 L .76455 .64998 L p .707 .577 .707 r
F P
0 g
s
.27777 .7298 m .27495 .7112 L .30575 .70826 L p .707 .577 .707 r
F P
0 g
s
.5875 .25065 m .59239 .75304 L .55363 .74728 L p .707 .577 .707 r
F P
0 g
s
.55363 .74728 m .54874 .24489 L .5875 .25065 L p .707 .577 .707 r
F P
0 g
s
.24626 .73495 m .24344 .71635 L .27495 .7112 L p .707 .577 .707 r
F P
0 g
s
.66878 .6632 m .67568 .62759 L .65512 .61589 L p .707 .577 .707 r
F P
0 g
s
.672 .66606 m .68456 .61337 L .66424 .60056 L p .707 .577 .707 r
F P
0 g
s
.80145 .64098 m .7889 .69366 L .81258 .69125 L p .707 .577 .707 r
F P
0 g
s
.81258 .69125 m .82513 .63856 L .80145 .64098 L p .707 .577 .707 r
F P
0 g
s
.23631 .71285 m .22941 .74847 L .20042 .74768 L p .707 .577 .707 r
F P
0 g
s
.29827 .72504 m .29137 .76065 L .26075 .75294 L p .707 .577 .707 r
F P
0 g
s
.27495 .7112 m .27777 .7298 L .24626 .73495 L p .707 .577 .707 r
F P
0 g
s
.26075 .75294 m .26765 .71732 L .29827 .72504 L p .707 .577 .707 r
F P
0 g
s
.22941 .74847 m .23631 .71285 L .26765 .71732 L p .707 .577 .707 r
F P
0 g
s
.4232 .7516 m .41832 .24921 L .45979 .24413 L p .707 .577 .707 r
F P
0 g
s
.41832 .24921 m .4232 .7516 L .38925 .75977 L p .707 .577 .707 r
F P
0 g
s
.26765 .71732 m .26075 .75294 L .22941 .74847 L p .707 .577 .707 r
F P
0 g
s
.79353 .65076 m .78663 .68638 L .81043 .6834 L p .707 .577 .707 r
F P
0 g
s
.81043 .6834 m .81733 .64779 L .79353 .65076 L p .707 .577 .707 r
F P
0 g
s
.54874 .24489 m .55363 .74728 L .50963 .74503 L p .707 .577 .707 r
F P
0 g
s
.50963 .74503 m .50474 .24264 L .54874 .24489 L p .707 .577 .707 r
F P
0 g
s
.65512 .61589 m .64823 .6515 L .66878 .6632 L p .707 .577 .707 r
F P
0 g
s
.66424 .60056 m .65168 .65325 L .672 .66606 L p .707 .577 .707 r
F P
0 g
s
.64823 .6515 m .65512 .61589 L .64293 .60384 L p .707 .577 .707 r
F P
0 g
s
.65168 .65325 m .66424 .60056 L .65223 .58764 L p .707 .577 .707 r
F P
0 g
s
.7437 .79209 m .74088 .77349 L .71007 .77644 L p .707 .577 .707 r
F P
0 g
s
.74088 .77349 m .7437 .79209 L .7752 .78694 L p .707 .577 .707 r
F P
0 g
s
.7752 .78694 m .77238 .76835 L .74088 .77349 L p .707 .577 .707 r
F P
0 g
s
.82513 .63856 m .81258 .69125 L .82882 .685 L p .707 .577 .707 r
F P
0 g
s
.82882 .685 m .84137 .63231 L .82513 .63856 L p .707 .577 .707 r
F P
0 g
s
.77238 .76835 m .7752 .78694 L .80432 .7801 L p .707 .577 .707 r
F P
0 g
s
.80432 .7801 m .8015 .7615 L .77238 .76835 L p .707 .577 .707 r
F P
0 g
s
.46468 .74652 m .45979 .24413 L .50474 .24264 L p .707 .577 .707 r
F P
0 g
s
.45979 .24413 m .46468 .74652 L .4232 .7516 L p .707 .577 .707 r
F P
0 g
s
.71007 .77644 m .71289 .79504 L .7437 .79209 L p .707 .577 .707 r
F P
0 g
s
.50474 .24264 m .50963 .74503 L .46468 .74652 L p .707 .577 .707 r
F P
0 g
s
.81733 .64779 m .81043 .6834 L .82672 .67696 L p .707 .577 .707 r
F P
0 g
s
.82672 .67696 m .83361 .64134 L .81733 .64779 L p .707 .577 .707 r
F P
0 g
s
.71289 .79504 m .71007 .77644 L .68298 .77689 L p .707 .577 .707 r
F P
0 g
s
.68298 .77689 m .6858 .79549 L .71289 .79504 L p .707 .577 .707 r
F P
0 g
s
.8015 .7615 m .80432 .7801 L .8282 .77222 L p .707 .577 .707 r
F P
0 g
s
.8282 .77222 m .82538 .75362 L .8015 .7615 L p .707 .577 .707 r
F P
0 g
s
.64293 .60384 m .63603 .63946 L .64823 .6515 L p .707 .577 .707 r
F P
0 g
s
.65223 .58764 m .63968 .64033 L .65168 .65325 L p .707 .577 .707 r
F P
0 g
s
.6858 .79549 m .68298 .77689 L .66226 .77481 L p .707 .577 .707 r
F P
0 g
s
.63968 .64033 m .65223 .58764 L .64971 .57586 L p .707 .577 .707 r
F P
0 g
s
.84137 .63231 m .82882 .685 L .83603 .67552 L p .707 .577 .707 r
F P
0 g
s
.83603 .67552 m .84858 .62283 L .84137 .63231 L p .707 .577 .707 r
F P
0 g
s
.66226 .77481 m .66508 .79341 L .6858 .79549 L p .707 .577 .707 r
F P
0 g
s
.82538 .75362 m .8282 .77222 L .84451 .76408 L p .707 .577 .707 r
F P
0 g
s
.84451 .76408 m .84169 .74549 L .82538 .75362 L p .707 .577 .707 r
F P
0 g
s
.83361 .64134 m .82672 .67696 L .83389 .66767 L p .707 .577 .707 r
F P
0 g
s
.83389 .66767 m .84078 .63206 L .83361 .64134 L p .707 .577 .707 r
F P
0 g
s
.63603 .63946 m .64293 .60384 L .64028 .59262 L p .707 .577 .707 r
F P
0 g
s
.64971 .57586 m .63715 .62855 L .63968 .64033 L p .707 .577 .707 r
F P
0 g
s
.64028 .59262 m .63339 .62824 L .63603 .63946 L p .707 .577 .707 r
F P
0 g
s
.66508 .79341 m .66226 .77481 L .64993 .77039 L p .707 .577 .707 r
F P
0 g
s
.64993 .77039 m .65275 .78899 L .66508 .79341 L p .707 .577 .707 r
F P
0 g
s
.63715 .62855 m .64971 .57586 L .65692 .56638 L p .707 .577 .707 r
F P
0 g
s
.84078 .63206 m .83389 .66767 L .83124 .65646 L p .707 .577 .707 r
F P
0 g
s
.84858 .62283 m .83603 .67552 L .83351 .66374 L p .707 .577 .707 r
F P
0 g
s
.83351 .66374 m .84606 .61105 L .84858 .62283 L p .707 .577 .707 r
F P
0 g
s
.84169 .74549 m .84451 .76408 L .85166 .75649 L p .707 .577 .707 r
F P
0 g
s
.85166 .75649 m .84883 .73789 L .84169 .74549 L p .707 .577 .707 r
F P
0 g
s
.83124 .65646 m .83814 .62084 L .84078 .63206 L p .707 .577 .707 r
F P
0 g
s
.63339 .62824 m .64028 .59262 L .64745 .58334 L p .707 .577 .707 r
F P
0 g
s
.65692 .56638 m .64437 .61907 L .63715 .62855 L p .707 .577 .707 r
F P
0 g
s
.64745 .58334 m .64056 .61896 L .63339 .62824 L p .707 .577 .707 r
F P
0 g
s
.65275 .78899 m .64993 .77039 L .6472 .76408 L p .707 .577 .707 r
F P
0 g
s
.38599 .60345 m .39854 .55076 L .36819 .54182 L p .707 .577 .707 r
F P
0 g
s
.39854 .55076 m .38599 .60345 L .41709 .60902 L p .707 .577 .707 r
F P
0 g
s
.41709 .60902 m .42964 .55633 L .39854 .55076 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6472 .76408 m .65002 .78268 L .65275 .78899 L p .707 .577 .707 r
F P
0 g
s
.35563 .59451 m .36819 .54182 L .34155 .53039 L p .707 .577 .707 r
F P
0 g
s
.36819 .54182 m .35563 .59451 L .38599 .60345 L p .707 .577 .707 r
F P
0 g
s
.42964 .55633 m .41709 .60902 L .44589 .61068 L p .707 .577 .707 r
F P
0 g
s
.44589 .61068 m .45844 .55799 L .42964 .55633 L p .707 .577 .707 r
F P
0 g
s
.64437 .61907 m .65692 .56638 L .67316 .56013 L p .707 .577 .707 r
F P
0 g
s
.83814 .62084 m .83124 .65646 L .81905 .64441 L p .707 .577 .707 r
F P
0 g
s
.84606 .61105 m .83351 .66374 L .8215 .65081 L p .707 .577 .707 r
F P
0 g
s
.81905 .64441 m .82594 .60879 L .83814 .62084 L p .707 .577 .707 r
F P
0 g
s
.8215 .65081 m .83405 .59813 L .84606 .61105 L p .707 .577 .707 r
F P
0 g
s
.84883 .73789 m .85166 .75649 L .84893 .75017 L p .707 .577 .707 r
F P
0 g
s
.84893 .75017 m .84611 .73157 L .84883 .73789 L p .707 .577 .707 r
F P
0 g
s
.64056 .61896 m .64745 .58334 L .66374 .57689 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32899 .58308 m .34155 .53039 L .32123 .51758 L p .707 .577 .707 r
F P
0 g
s
.34155 .53039 m .32899 .58308 L .35563 .59451 L p .707 .577 .707 r
F P
0 g
s
.45844 .55799 m .44589 .61068 L .46957 .60827 L p .707 .577 .707 r
F P
0 g
s
.46957 .60827 m .48212 .55558 L .45844 .55799 L p .707 .577 .707 r
F P
0 g
s
.67316 .56013 m .66061 .61282 L .64437 .61907 L p .707 .577 .707 r
F P
0 g
s
.66374 .57689 m .65684 .61251 L .64056 .61896 L p .707 .577 .707 r
F P
0 g
s
.65002 .78268 m .6472 .76408 L .65434 .75648 L p .707 .577 .707 r
F P
0 g
s
.40069 .68278 m .39787 .66419 L .36706 .66713 L p .707 .577 .707 r
F P
0 g
s
.39787 .66419 m .40069 .68278 L .43219 .67764 L p .707 .577 .707 r
F P
0 g
s
.43219 .67764 m .42937 .65904 L .39787 .66419 L p .707 .577 .707 r
F P
0 g
s
.66061 .61282 m .67316 .56013 L .69684 .55772 L p .707 .577 .707 r
F P
0 g
s
.82594 .60879 m .81905 .64441 L .79849 .63271 L p .707 .577 .707 r
F P
0 g
s
.79849 .63271 m .80539 .59709 L .82594 .60879 L p .707 .577 .707 r
F P
0 g
s
.83405 .59813 m .8215 .65081 L .80118 .63801 L p .707 .577 .707 r
F P
0 g
s
.80118 .63801 m .81373 .58532 L .83405 .59813 L p .707 .577 .707 r
F P
0 g
s
.65434 .75648 m .65717 .77508 L .65002 .78268 L p .707 .577 .707 r
F P
0 g
s
.42937 .65904 m .43219 .67764 L .46131 .67079 L p .707 .577 .707 r
F P
0 g
s
.46131 .67079 m .45849 .65219 L .42937 .65904 L p .707 .577 .707 r
F P
0 g
s
.36706 .66713 m .36988 .68573 L .40069 .68278 L p .707 .577 .707 r
F P
0 g
s
.32123 .51758 m .30867 .57027 L .32899 .58308 L p .707 .577 .707 r
F P
0 g
s
.30867 .57027 m .32123 .51758 L .30922 .50466 L p .707 .577 .707 r
F P
0 g
s
.36988 .68573 m .36706 .66713 L .33997 .66758 L p .707 .577 .707 r
F P
0 g
s
.48212 .55558 m .46957 .60827 L .48581 .60202 L p .707 .577 .707 r
F P
0 g
s
.48581 .60202 m .49836 .54933 L .48212 .55558 L p .707 .577 .707 r
F P
0 g
s
.84611 .73157 m .84893 .75017 L .8366 .74576 L p .707 .577 .707 r
F P
0 g
s
.8366 .74576 m .83378 .72716 L .84611 .73157 L p .707 .577 .707 r
F P
0 g
s
.69684 .55772 m .68428 .6104 L .66061 .61282 L p .707 .577 .707 r
F P
0 g
s
.65684 .61251 m .66374 .57689 L .68754 .57392 L p .707 .577 .707 r
F P
0 g
s
.365 .68527 m .35958 .68391 L p .36495 .69372 L .707 .577 .707 r
F P
0 g
s
.35268 .71952 m .35958 .68391 L .33267 .6737 L p .707 .577 .707 r
F P
0 g
s
.35958 .68391 m .35268 .71952 L .3833 .72724 L p .707 .577 .707 r
F P
0 g
s
.33997 .66758 m .34279 .68618 L .365 .68581 L p .707 .577 .707 r
F P
0 g
s
.365 .68581 m .36988 .68573 L p .36502 .68278 L .707 .577 .707 r
F P
0 g
s
.36502 .68278 m .33997 .66758 L .365 .68581 L .707 .577 .707 r
F
.3833 .72724 m .3902 .69162 L .365 .68527 L p F P
0 g
s
.3833 .72724 m .365 .68527 L .36495 .69372 L .707 .577 .707 r
F
.3902 .69162 m .3833 .72724 L .41464 .73171 L p F P
0 g
s
.41464 .73171 m .42154 .69609 L .3902 .69162 L p .707 .577 .707 r
F P
0 g
s
.45849 .65219 m .46131 .67079 L .48519 .66291 L p .707 .577 .707 r
F P
0 g
s
.48519 .66291 m .48237 .64431 L .45849 .65219 L p .707 .577 .707 r
F P
0 g
s
.42154 .69609 m .41464 .73171 L .44362 .73249 L p .707 .577 .707 r
F P
0 g
s
.44362 .73249 m .45052 .69688 L .42154 .69609 L p .707 .577 .707 r
F P
0 g
s
.68428 .6104 m .69684 .55772 L .72564 .55938 L p .707 .577 .707 r
F P
0 g
s
.68754 .57392 m .68064 .60953 L .65684 .61251 L p .707 .577 .707 r
F P
0 g
s
.80539 .59709 m .79849 .63271 L .77329 .62315 L p .707 .577 .707 r
F P
0 g
s
.77267 .62603 m .74418 .61764 L p .78296 .5781 L .707 .577 .707 r
F P
0 g
s
.77329 .62315 m .77158 .6225 L p .77379 .62085 L .707 .577 .707 r
F P
0 g
s
.77379 .62085 m .80539 .59709 L .77329 .62315 L .707 .577 .707 r
F
.77158 .6225 m .77848 .58689 L .80539 .59709 L p F P
0 g
s
.78709 .57389 m .77454 .62658 L .77267 .62603 L p .707 .577 .707 r
F P
0 g
s
.78296 .5781 m .78709 .57389 L .77267 .62603 L .707 .577 .707 r
F
.81373 .58532 m .80118 .63801 L .77454 .62658 L p F P
0 g
s
.77454 .62658 m .78709 .57389 L .81373 .58532 L p .707 .577 .707 r
F P
0 g
s
.33267 .6737 m .32577 .70932 L .35268 .71952 L p .707 .577 .707 r
F P
0 g
s
.32577 .70932 m .33267 .6737 L .31211 .662 L p .707 .577 .707 r
F P
0 g
s
.34279 .68618 m .33997 .66758 L .31925 .6655 L p .707 .577 .707 r
F P
0 g
s
.30922 .50466 m .29667 .55735 L .30867 .57027 L p .707 .577 .707 r
F P
0 g
s
.65717 .77508 m .65434 .75648 L .67066 .74835 L p .707 .577 .707 r
F P
0 g
s
.45052 .69688 m .44362 .73249 L .46742 .72952 L p .707 .577 .707 r
F P
0 g
s
.46742 .72952 m .47432 .6939 L .45052 .69688 L p .707 .577 .707 r
F P
0 g
s
.31925 .6655 m .32207 .6841 L .34279 .68618 L p .707 .577 .707 r
F P
0 g
s
.72564 .55938 m .71308 .61206 L .68428 .6104 L p .707 .577 .707 r
F P
0 g
s
.68064 .60953 m .68754 .57392 L .71652 .5747 L p .707 .577 .707 r
F P
0 g
s
.67066 .74835 m .67348 .76694 L .65717 .77508 L p .707 .577 .707 r
F P
0 g
s
.48237 .64431 m .48519 .66291 L .5015 .65478 L p .707 .577 .707 r
F P
0 g
s
.5015 .65478 m .49868 .63618 L .48237 .64431 L p .707 .577 .707 r
F P
0 g
s
.29667 .55735 m .30922 .50466 L .3067 .49288 L p .707 .577 .707 r
F P
0 g
s
.49836 .54933 m .48581 .60202 L .49302 .59254 L p .707 .577 .707 r
F P
0 g
s
.49302 .59254 m .50557 .53985 L .49836 .54933 L p .707 .577 .707 r
F P
0 g
s
.71308 .61206 m .72564 .55938 L .75674 .56495 L p .707 .577 .707 r
F P
0 g
s
.74418 .61764 m .75674 .56495 L .78709 .57389 L p .707 .577 .707 r
F P
0 g
s
.83378 .72716 m .8366 .74576 L .81588 .74367 L p .707 .577 .707 r
F P
0 g
s
.81588 .74367 m .81306 .72508 L .83378 .72716 L p .707 .577 .707 r
F P
0 g
s
.75674 .56495 m .74418 .61764 L .71308 .61206 L p .707 .577 .707 r
F P
0 g
s
.31211 .662 m .30522 .69762 L .32577 .70932 L p .707 .577 .707 r
F P
0 g
s
.71652 .5747 m .70962 .61032 L .68064 .60953 L p .707 .577 .707 r
F P
0 g
s
.77848 .58689 m .77158 .6225 L .74096 .61479 L p .707 .577 .707 r
F P
0 g
s
.74096 .61479 m .74786 .57917 L .77848 .58689 L p .707 .577 .707 r
F P
0 g
s
.70962 .61032 m .71652 .5747 L .74786 .57917 L p .707 .577 .707 r
F P
0 g
s
.74786 .57917 m .74096 .61479 L .70962 .61032 L p .707 .577 .707 r
F P
0 g
s
.30522 .69762 m .31211 .662 L .29992 .64995 L p .707 .577 .707 r
F P
0 g
s
.32207 .6841 m .31925 .6655 L .30692 .66109 L p .707 .577 .707 r
F P
0 g
s
.47432 .6939 m .46742 .72952 L .48371 .72307 L p .707 .577 .707 r
F P
0 g
s
.48371 .72307 m .4906 .68745 L .47432 .6939 L p .707 .577 .707 r
F P
0 g
s
.30692 .66109 m .30974 .67968 L .32207 .6841 L p .707 .577 .707 r
F P
0 g
s
.3067 .49288 m .29414 .54557 L .29667 .55735 L p .707 .577 .707 r
F P
0 g
s
.67348 .76694 m .67066 .74835 L .69454 .74047 L p .707 .577 .707 r
F P
0 g
s
.69454 .74047 m .69736 .75907 L .67348 .76694 L p .707 .577 .707 r
F P
0 g
s
.49868 .63618 m .5015 .65478 L .50865 .64718 L p .707 .577 .707 r
F P
0 g
s
.50865 .64718 m .50582 .62858 L .49868 .63618 L p .707 .577 .707 r
F P
0 g
s
.81306 .72508 m .81588 .74367 L .78879 .74413 L p .707 .577 .707 r
F P
0 g
s
.78879 .74413 m .78597 .72553 L .81306 .72508 L p .707 .577 .707 r
F P
0 g
s
.29414 .54557 m .3067 .49288 L .31391 .4834 L p .707 .577 .707 r
F P
0 g
s
.29992 .64995 m .29302 .68557 L .30522 .69762 L p .707 .577 .707 r
F P
0 g
s
.50557 .53985 m .49302 .59254 L .4905 .58076 L p .707 .577 .707 r
F P
0 g
s
.4905 .58076 m .50305 .52807 L .50557 .53985 L p .707 .577 .707 r
F P
0 g
s
.69736 .75907 m .69454 .74047 L .72366 .73362 L p .707 .577 .707 r
F P
0 g
s
.4906 .68745 m .48371 .72307 L .49088 .71379 L p .707 .577 .707 r
F P
0 g
s
.49088 .71379 m .49777 .67817 L .4906 .68745 L p .707 .577 .707 r
F P
0 g
s
.72366 .73362 m .72648 .75222 L .69736 .75907 L p .707 .577 .707 r
F P
0 g
s
.29302 .68557 m .29992 .64995 L .29727 .63874 L p .707 .577 .707 r
F P
0 g
s
.30974 .67968 m .30692 .66109 L .30419 .65477 L p .707 .577 .707 r
F P
0 g
s
.78597 .72553 m .78879 .74413 L .75798 .74707 L p .707 .577 .707 r
F P
0 g
s
.75798 .74707 m .75516 .72847 L .78597 .72553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30419 .65477 m .30701 .67337 L .30974 .67968 L p .707 .577 .707 r
F P
0 g
s
.31391 .4834 m .30136 .53609 L .29414 .54557 L p .707 .577 .707 r
F P
0 g
s
.72648 .75222 m .72366 .73362 L .75516 .72847 L p .707 .577 .707 r
F P
0 g
s
.75516 .72847 m .75798 .74707 L .72648 .75222 L p .707 .577 .707 r
F P
0 g
s
.50582 .62858 m .50865 .64718 L .50592 .64086 L p .707 .577 .707 r
F P
0 g
s
.50592 .64086 m .5031 .62227 L .50582 .62858 L p .707 .577 .707 r
F P
0 g
s
.29727 .63874 m .29038 .67435 L .29302 .68557 L p .707 .577 .707 r
F P
0 g
s
.30136 .53609 m .31391 .4834 L .33015 .47715 L p .707 .577 .707 r
F P
0 g
s
.50305 .52807 m .4905 .58076 L .47849 .56783 L p .707 .577 .707 r
F P
0 g
s
.47849 .56783 m .49104 .51515 L .50305 .52807 L p .707 .577 .707 r
F P
0 g
s
.49777 .67817 m .49088 .71379 L .48823 .70257 L p .707 .577 .707 r
F P
0 g
s
.48823 .70257 m .49513 .66695 L .49777 .67817 L p .707 .577 .707 r
F P
0 g
s
.29038 .67435 m .29727 .63874 L .30444 .62945 L p .707 .577 .707 r
F P
0 g
s
.30701 .67337 m .30419 .65477 L .31133 .64717 L p .707 .577 .707 r
F P
0 g
s
.33015 .47715 m .3176 .52984 L .30136 .53609 L p .707 .577 .707 r
F P
0 g
s
.31133 .64717 m .31415 .66577 L .30701 .67337 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3176 .52984 m .33015 .47715 L .35383 .47474 L p .707 .577 .707 r
F P
0 g
s
.5031 .62227 m .50592 .64086 L .49359 .63645 L p .707 .577 .707 r
F P
0 g
s
.49359 .63645 m .49077 .61785 L .5031 .62227 L p .707 .577 .707 r
F P
0 g
s
.30444 .62945 m .29755 .66507 L .29038 .67435 L p .707 .577 .707 r
F P
0 g
s
.49104 .51515 m .47849 .56783 L .45817 .55503 L p .707 .577 .707 r
F P
0 g
s
.45817 .55503 m .47072 .50234 L .49104 .51515 L p .707 .577 .707 r
F P
0 g
s
.49513 .66695 m .48823 .70257 L .47604 .69052 L p .707 .577 .707 r
F P
0 g
s
.47604 .69052 m .48293 .65491 L .49513 .66695 L p .707 .577 .707 r
F P
0 g
s
.29755 .66507 m .30444 .62945 L .32073 .623 L p .707 .577 .707 r
F P
0 g
s
.31415 .66577 m .31133 .64717 L .32764 .63904 L p .707 .577 .707 r
F P
0 g
s
.35383 .47474 m .34127 .52742 L .3176 .52984 L p .707 .577 .707 r
F P
0 g
s
.34127 .52742 m .35383 .47474 L .38263 .4764 L p .707 .577 .707 r
F P
0 g
s
.47072 .50234 m .45817 .55503 L .43153 .5436 L p .707 .577 .707 r
F P
0 g
s
.43153 .5436 m .44408 .49091 L .47072 .50234 L p .707 .577 .707 r
F P
0 g
s
.32764 .63904 m .33047 .65764 L .31415 .66577 L p .707 .577 .707 r
F P
0 g
s
.49077 .61785 m .49359 .63645 L .47287 .63437 L p .707 .577 .707 r
F P
0 g
s
.47287 .63437 m .47004 .61577 L .49077 .61785 L p .707 .577 .707 r
F P
0 g
s
.32073 .623 m .31383 .65862 L .29755 .66507 L p .707 .577 .707 r
F P
0 g
s
.37007 .52908 m .38263 .4764 L .41372 .48197 L p .707 .577 .707 r
F P
0 g
s
.38263 .4764 m .37007 .52908 L .34127 .52742 L p .707 .577 .707 r
F P
0 g
s
.44408 .49091 m .43153 .5436 L .40117 .53466 L p .707 .577 .707 r
F P
0 g
s
.40117 .53466 m .41372 .48197 L .44408 .49091 L p .707 .577 .707 r
F P
0 g
s
.41372 .48197 m .40117 .53466 L .37007 .52908 L p .707 .577 .707 r
F P
0 g
s
.48293 .65491 m .47604 .69052 L .45548 .67882 L p .707 .577 .707 r
F P
0 g
s
.45548 .67882 m .46238 .64321 L .48293 .65491 L p .707 .577 .707 r
F P
0 g
s
.33047 .65764 m .32764 .63904 L .35153 .63116 L p .707 .577 .707 r
F P
0 g
s
.31383 .65862 m .32073 .623 L .34453 .62003 L p .707 .577 .707 r
F P
0 g
s
.35153 .63116 m .35435 .64976 L .33047 .65764 L p .707 .577 .707 r
F P
0 g
s
.47004 .61577 m .47287 .63437 L .44578 .63482 L p .707 .577 .707 r
F P
0 g
s
.44578 .63482 m .44295 .61622 L .47004 .61577 L p .707 .577 .707 r
F P
0 g
s
.34453 .62003 m .33763 .65564 L .31383 .65862 L p .707 .577 .707 r
F P
0 g
s
.46238 .64321 m .45548 .67882 L .42857 .66861 L p .707 .577 .707 r
F P
0 g
s
.44024 .63481 m .46238 .64321 L p .43953 .66038 L .707 .577 .707 r
F P
0 g
s
.44295 .61622 m .44578 .63482 L .44022 .63535 L p .707 .577 .707 r
F P
0 g
s
.44022 .63535 m .41497 .63776 L p .44071 .61795 L .707 .577 .707 r
F P
0 g
s
.44071 .61795 m .44295 .61622 L .44022 .63535 L .707 .577 .707 r
F
.42857 .66861 m .43547 .633 L .44024 .63481 L p F P
0 g
s
.42857 .66861 m .44024 .63481 L .43953 .66038 L .707 .577 .707 r
F
.35435 .64976 m .35153 .63116 L .38065 .62431 L p F P
0 g
s
.33763 .65564 m .34453 .62003 L .37351 .62081 L p .707 .577 .707 r
F P
0 g
s
.38065 .62431 m .38347 .64291 L .35435 .64976 L p .707 .577 .707 r
F P
0 g
s
.41497 .63776 m .41215 .61916 L .44295 .61622 L p .707 .577 .707 r
F P
0 g
s
.38347 .64291 m .38065 .62431 L .41215 .61916 L p .707 .577 .707 r
F P
0 g
s
.37351 .62081 m .36661 .65643 L .33763 .65564 L p .707 .577 .707 r
F P
0 g
s
.43547 .633 m .42857 .66861 L .39795 .6609 L p .707 .577 .707 r
F P
0 g
s
.41215 .61916 m .41497 .63776 L .38347 .64291 L p .707 .577 .707 r
F P
0 g
s
.39795 .6609 m .40485 .62528 L .43547 .633 L p .707 .577 .707 r
F P
0 g
s
.36661 .65643 m .37351 .62081 L .40485 .62528 L p .707 .577 .707 r
F P
0 g
s
.40485 .62528 m .39795 .6609 L .36661 .65643 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001eOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol0
079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007Ao
o`00Kgoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01000L7oo001/Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001]Ool006Yoo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00
J7oo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001VOol20005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001TOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005eooa8000QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo0`001UYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001IOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005Qoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00F7oo00D005YFFUIJEP0000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Egoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00H005YF0000
05YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Ioo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001FOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00EGoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001VOol005Eo
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00EGoo00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo
00<005YFFUH00UYF4`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Ao
o`800005FUH00000FUH00006FUH40002FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00E7oo00=JEP0000000eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00EJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP8000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00IJEPD000MJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH01P00
FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00<0
05YFFUH015YF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00@000UJEP8000IJEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH=0004FUH02000FUIJEP00FUH0
05YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool7001COol005Eo
o`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001goo1@000eYF00@005YFFUIJEPT004Yoo`00EGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP05001J
EP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60014Ool003Iooa8000ioo`8000IJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000@Woo000dOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20002FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000oOol0039oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000Moo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP800004FUH005YF0002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<0
05YF00003`001UYF00<005YFFUH01EYF0`00?7oo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP040005Ool200000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00001JEPD000=JEP03
001JEUYF00EJEP03001JEUYF009JEPL000QJEP04001JEP00000jOol0035oo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004Ool20008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800006Ool00000001J
EP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YFFUIJEP<003Mo
o`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0`0017oo0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0
00MJEP8003Eoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH20008FUH3000cOol002moo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000MJEP05
001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001oogoo00=oo`<000MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00FUIJEP02FUH2000`Ool002moo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000=oo`03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0]Ool002moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800005Ool005YFFUH00003FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20008FUH0
0`00FUIJEP04FUH2000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF
00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP04001JEUYFFUH60008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH00eYF3P0000=J
EP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP04001JEUYF0003FUH@0004FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH50003FUH20002Ool>0008FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP0C0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02000
FUIJEUYF001JEP00FUH40006FUH01000FUH000002Goo200015YF00<005YF00001eYF00<005YFFUH0
15YF00<005YFFUH00P00;7oo000]Ool00`00FUIJEP02FUHC0006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH0000?0002FUH9000;FUH00`00FUIJEP03FUH00`00FUH00003000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00AJEP04001JEUYFFUH2
000=Ool500000eYF00000007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00;Goo0P00
00EJEP00001JEP0000IJEP8000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH015YF
10002goo1P001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000[Ool002eoo`03FUH0000000=J
EP03001JEUYF00AJEP04001JEP00000;Ool40007FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YF
FUH015YF00<005YFFUH01UYF00@005YF000000aoo`@000IJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF0000:goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00
FUIJEP020003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00eoo`8000AJEP03001JEUYF00AJEP04001JEUYF0002FUH/Ool002aoo`<000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@000eoo`<00003FUH0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEPl000=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH6
0009Ool200000eYF001JEP05FUH01`00FUIJEUYF001JEP0002aoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100037oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF
009JEPD00003FUH0000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool20006FUH0
1`00FUIJEUYF001JEP0002aoo`00;7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH015YF1@001goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0`001EYF0P0000=JEP0000000P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
100015YF00<005YFFUH01UYF00@005YFFUIJEPL000AJEP07001JEUYFFUH005YF0000;7oo000]Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010000goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
0`000UYF0P000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00AJEP03001JEUYF00]JEPL000IJEP03001JEUYF00EJEP04001JEUYF0003
FUH01P00FUIJEP00FUH002eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00=JEP03001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00eJ
EP03001JEUYF009JEPP000IJEP03001JEP0000@000=JEP03001JEP0002eoo`00;Woo00@005YFFUH0
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<000QJEP03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000IJ
EP03001JEUYF00eJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH20003FUH00`00FUH0000]Ool0
02ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50006FUH200000eYF001JEP02
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009o
o`<000AJEP03001JEUYF00aJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EP00009JEP03001JEP0002eoo`00;goo0P001UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF
0`000eYF1`0000=JEP0000000eYF00@005YFFUH000AJEPH000MJEP03001JEP0000EJEP03001JEUYF
00AJEP@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Aoo`80009JEP03001JEUYF00eJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH200000eYF001oo`0]Ool0031oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00EJEPD000IJEP04001JEP00FUH200000eYF001JEP020004FUH20002FUH01000FUIJEP0015YF2000
15YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo0`003eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH007oo02eoo`00<Goo0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF0`001eYF00L005YF000005YF001JEP0D0004FUH01000FUIJEUYF
0`0000=JEP0000001eYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000Eoo`8000iJEP03001JEP00
008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`0]Ool003=o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000MJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUH00000FUH00P001Goo0P0035YF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YF
FUH005YF001JEP00;Woo000eOol20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF001J
EUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH30004Ool200000eYF00000006FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000_Ool003Moo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP8000AJEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPP00003FUH005YF00EJEP06001JEUYF001JEP000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0P0017oo1`00
0UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000_
Ool003Uoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP<00003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEPD000MJEP8000IJEP06001JEUYF001JEP00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
25YF0`001Goo0`0000=JEP0000001P000eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF0000
05YF0080031oo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUH000=JEP03001J
EUYF00@000=JEP03001JEUYF00=JEP<000AJEPH000AJEP03001JEUYF00MJEP8000=JEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001eYF00D005YFFUIJEP0000Moo`<00003FUH005YF009JEPP000AJEP04001JEUYFFUH5
0002FUH2000aOol003eoo`<000MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH:0002FUH:0005FUH00`00FUIJEP09FUH200000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH2
0008Ool60004FUH00`00FUIJEP080003FUH01000FUH00000<goo0010Ool40002FUH00`00FUIJEP07
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0;Ool80004FUH01000FUIJ
EUYF1000=Goo0014Ool50007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH400000eYF000000070008FUH5000015YF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH015YF0P0057oo2000>Goo
0019Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJ
EP04FUH01000FUIJEP00E7oo001=Ool<0003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJ
EP05001JEUYFFUH0001COol005Uoo`800003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05001J
EUYFFUH0001COol005=oo`/000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP03001JEUYF008005=oo`00>7oo
40000Woo2@002eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001BOol003=o
o`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEP0000800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0000Ioo`<004Uoo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005Ool50018Ool002moo`8000=JEP03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF
00AJEP04001JEUYF0002FUH6Ool50018Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPl000=JEP05001JEUYF001JEP050006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001oo`800003FUH005YF00EJEP07001JEUYFFUH005YF00001Woo
1@001Woo4P00<7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP020009Ool40002FUH00`00FUIJEP03FUH50002FUH00`00
FUIJEP06FUH01000FUIJEUYF10002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000goo0P001UYF00L005YFFUIJEP00FUH00007Ool:0004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000^Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80009JEP03001JEUYF00=J
EP03001JEUYF009JEPl0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000L000AJEP07001JEUYFFUH005YF00000Woo1P0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo000]Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH20004Ool300001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00@005YFFUH000=JEP05001JEUYF001JEP0400000eYF001JEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00:goo000/Ool00`00FUH00004FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH500001EYF
001JEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YF0000100000=JEP0000000P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH017ooFUIJEP000UYF
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
000[Ool002aoo`03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH2
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000>Ool50002FUH00`00Oomoo`0YOol002aoo`80
00=JEPL000aoo`@0009JEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00=JEP03001JEUYF00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP00008000MJEP03001JEUYF00AJ
EPH001Qoo`80009JEP@002Yoo`00;7oo00=JEP00FUH00P0000=JEP00FUH00P004Woo10001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00=JEP<0
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP04001JEP00FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20004FUH01000
FUH00000:Woo000[Ool01`00FUH00000FUH005YF00@000Qooa80009JEP8000MJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF
000015YF00<005YFFUH015YF100077oo100000=JEP00FUH015YF00<005YF0000:Woo000[Ool30002
FUH2000015YF001JEUYF20000eYF00<005YFFUH01UYF00<005YFFUH00eYF10001eYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001JEP00008000EJEP04
001JEUYFFUH300000eYF001oo`0IOol30005FUH00`00FUIJEP03FUH2000[Ool002]oo`03001JEP00
009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00AJEP05001JEUYFFUH00002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP05001JEP00FUH00005FUH00`00FUH00005000GOol400000eYF001JEP06FUH01000FUIJEUYF0P00
;7oo000[Ool00`00FUH00002FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH800000eYF001JEP05FUH00`00FUIJEP020002FUH01000FUH000001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP<0009JEP04001JEP00000@Ool70005FUH00`00FUIJ
EP05FUH01000FUH00000;Woo000[Ool00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH40008Ool20006FUH00`00FUIJEP020002FUH200000eYF001JEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200001UYF001JEUYF001JEP800003FUH005YF00800003FUH0000000Qoo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00;7oo00D005YFFUIJEP00009JEP@000=J
EP03001JEUYF00=JEP03OomJEP0000AJEPH000ioo`8000=JEP04001JEUYFFUH200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000005YF500015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00<goo000/Ool01@00FUIJEUYF00001EYF5P004Goo0P0000=JEP00
FUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00=goo000]
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000COol20003FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04000jOol002ioo`8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEPL000moo`D00003FUH00000008000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEPD003ioo`00;goo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF3`000UYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF00000Woo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1000@goo000`Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000Eoo`D0009JEP03001JEUYF00EJEP03001JEUYF009JEPL004Moo`00<Woo0P0000=JEP00FUH0
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YF001oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000]oo`l004ioo`00=7oo
0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00=goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P001Woo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000006aoo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH4001^Ool003aoo`<000IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000;Ool300000eYF001JEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07001`Ool003moo`@0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000?Ool70005FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50003Ool5001_Ool004=oo`D000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEP00000HOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP06
0008Ool50006OolB001GOol004Qoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH4000VOolF000>
Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001EOol004aoo`l004Yoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008005=oo`00XGoo100000=JEP00
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00
WGoo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00DWoo002IOol400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003
FUH01@00FUIJEUYF0000DWoo002GOol20005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000>Ool5
0002FUH00`00Oomoo`1@Ool009Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00@001Moo`800003
FUH000000080055oo`00Tgoo0P000UYF00<005YFFUH01EYF00<005YFFUH015YF100067oo0`000eYF
00@005YF0000055oo`00TWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0100067oo1000
00=JEP00FUH015YF00<005YF0000DGoo002AOol20005FUH00`00FUIJEP03FUH4000IOol30005FUH0
0`00FUIJEP03FUH2001BOol0091oo`03001JEP0000EJEP03001JEP0000<001Uoo`@00003FUH005YF
00IJEP04001JEUYFFUH2001COol0091oo`04001JEUYF0003FUH3000HOol50005FUH00`00FUIJEP05
FUH01000FUH00000EGoo002@Ool01@00FUIJEP00FUH00P005goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`00Egoo002AOol00`00FUH000040007Ool?0006FUH00`00FUIJEP06FUH00`00FUH0
0003001JOol0095oo`80009JEP03001JEUYF00L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP<005ioo`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01000HGoo002AOol20003FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5001UOol0099oo`80009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006Yoo`00U7oo1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF1`00KWoo002IOol?001eOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5918 .77847 m .60435 .72578 L .57399 .71684 L p .707 .577 .707 r
F P
0 g
s
.60435 .72578 m .5918 .77847 L .6229 .78404 L p .707 .577 .707 r
F P
0 g
s
.6229 .78404 m .63545 .73135 L .60435 .72578 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57399 .71684 L .57133 .7157 L p .707 .577 .707 r
F P
0 g
s
.56144 .76953 m .57133 .7157 L .56054 .76543 L .707 .577 .707 r
F
.57399 .71684 m .56144 .76953 L .5918 .77847 L p F P
0 g
s
.58911 .77317 m .596 .73755 L .56811 .73052 L p .707 .577 .707 r
F P
0 g
s
.56811 .73052 m .56538 .72983 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.58911 .77317 m .56811 .73052 L .56745 .7336 L .707 .577 .707 r
F
.55849 .76545 m .56538 .72983 L .53848 .71963 L p F P
0 g
s
.56538 .72983 m .55849 .76545 L .56043 .76594 L p .707 .577 .707 r
F P
0 g
s
.5598 .76882 m .56144 .76953 L p .56054 .76543 L .707 .577 .707 r
F P
0 g
s
.56043 .76594 m .58911 .77317 L p .56745 .7336 L .707 .577 .707 r
F P
0 g
s
.56745 .7336 m .56538 .72983 L .56043 .76594 L .707 .577 .707 r
F
.53848 .71963 m .53158 .75524 L .55849 .76545 L p F P
0 g
s
.54735 .70541 m .5348 .75809 L .5598 .76882 L p .707 .577 .707 r
F P
0 g
s
.56054 .76543 m .54735 .70541 L .5598 .76882 L .707 .577 .707 r
F
.57133 .7157 m .54735 .70541 L p .56054 .76543 L F P
0 g
s
.63545 .73135 m .6229 .78404 L .65169 .7857 L p .707 .577 .707 r
F P
0 g
s
.65169 .7857 m .66425 .73301 L .63545 .73135 L p .707 .577 .707 r
F P
0 g
s
.596 .73755 m .58911 .77317 L .62044 .77764 L p .707 .577 .707 r
F P
0 g
s
.62044 .77764 m .62734 .74202 L .596 .73755 L p .707 .577 .707 r
F P
0 g
s
.62734 .74202 m .62044 .77764 L .64943 .77842 L p .707 .577 .707 r
F P
0 g
s
.64943 .77842 m .65633 .7428 L .62734 .74202 L p .707 .577 .707 r
F P
0 g
s
.53158 .75524 m .53848 .71963 L .51792 .70793 L p .707 .577 .707 r
F P
0 g
s
.5348 .75809 m .54735 .70541 L .52703 .6926 L p .707 .577 .707 r
F P
0 g
s
.66425 .73301 m .65169 .7857 L .67537 .78329 L p .707 .577 .707 r
F P
0 g
s
.67537 .78329 m .68792 .7306 L .66425 .73301 L p .707 .577 .707 r
F P
0 g
s
.65633 .7428 m .64943 .77842 L .67323 .77544 L p .707 .577 .707 r
F P
0 g
s
.67323 .77544 m .68013 .73983 L .65633 .7428 L p .707 .577 .707 r
F P
0 g
s
.51792 .70793 m .51102 .74354 L .53158 .75524 L p .707 .577 .707 r
F P
0 g
s
.52703 .6926 m .51448 .74529 L .5348 .75809 L p .707 .577 .707 r
F P
0 g
s
.51102 .74354 m .51792 .70793 L .50572 .69588 L p .707 .577 .707 r
F P
0 g
s
.51448 .74529 m .52703 .6926 L .51502 .67968 L p .707 .577 .707 r
F P
0 g
s
.60649 .88413 m .60367 .86553 L .57287 .86848 L p .707 .577 .707 r
F P
0 g
s
.60367 .86553 m .60649 .88413 L .638 .87898 L p .707 .577 .707 r
F P
0 g
s
.638 .87898 m .63518 .86038 L .60367 .86553 L p .707 .577 .707 r
F P
0 g
s
.68792 .7306 m .67537 .78329 L .69161 .77703 L p .707 .577 .707 r
F P
0 g
s
.69161 .77703 m .70416 .72435 L .68792 .7306 L p .707 .577 .707 r
F P
0 g
s
.63518 .86038 m .638 .87898 L .66712 .87213 L p .707 .577 .707 r
F P
0 g
s
.66712 .87213 m .66429 .85354 L .63518 .86038 L p .707 .577 .707 r
F P
0 g
s
.57287 .86848 m .57569 .88707 L .60649 .88413 L p .707 .577 .707 r
F P
0 g
s
.68013 .73983 m .67323 .77544 L .68951 .769 L p .707 .577 .707 r
F P
0 g
s
.68951 .769 m .69641 .73338 L .68013 .73983 L p .707 .577 .707 r
F P
0 g
s
.57569 .88707 m .57287 .86848 L .54578 .86893 L p .707 .577 .707 r
F P
0 g
s
.54578 .86893 m .5486 .88753 L .57569 .88707 L p .707 .577 .707 r
F P
0 g
s
.66429 .85354 m .66712 .87213 L .691 .86426 L p .707 .577 .707 r
F P
0 g
s
.691 .86426 m .68818 .84566 L .66429 .85354 L p .707 .577 .707 r
F P
0 g
s
.50572 .69588 m .49882 .7315 L .51102 .74354 L p .707 .577 .707 r
F P
0 g
s
.51502 .67968 m .50247 .73237 L .51448 .74529 L p .707 .577 .707 r
F P
0 g
s
.5486 .88753 m .54578 .86893 L .52505 .86685 L p .707 .577 .707 r
F P
0 g
s
.50247 .73237 m .51502 .67968 L .5125 .6679 L p .707 .577 .707 r
F P
0 g
s
.70416 .72435 m .69161 .77703 L .69882 .76756 L p .707 .577 .707 r
F P
0 g
s
.69882 .76756 m .71138 .71487 L .70416 .72435 L p .707 .577 .707 r
F P
0 g
s
.52505 .86685 m .52788 .88544 L .5486 .88753 L p .707 .577 .707 r
F P
0 g
s
.68818 .84566 m .691 .86426 L .70731 .85612 L p .707 .577 .707 r
F P
0 g
s
.70731 .85612 m .70449 .83752 L .68818 .84566 L p .707 .577 .707 r
F P
0 g
s
.69641 .73338 m .68951 .769 L .69668 .75971 L p .707 .577 .707 r
F P
0 g
s
.69668 .75971 m .70358 .72409 L .69641 .73338 L p .707 .577 .707 r
F P
0 g
s
.49882 .7315 m .50572 .69588 L .50308 .68466 L p .707 .577 .707 r
F P
0 g
s
.5125 .6679 m .49995 .72059 L .50247 .73237 L p .707 .577 .707 r
F P
0 g
s
.50308 .68466 m .49618 .72028 L .49882 .7315 L p .707 .577 .707 r
F P
0 g
s
.52788 .88544 m .52505 .86685 L .51273 .86243 L p .707 .577 .707 r
F P
0 g
s
.51273 .86243 m .51555 .88103 L .52788 .88544 L p .707 .577 .707 r
F P
0 g
s
.49995 .72059 m .5125 .6679 L .51972 .65842 L p .707 .577 .707 r
F P
0 g
s
.70358 .72409 m .69668 .75971 L .69404 .7485 L p .707 .577 .707 r
F P
0 g
s
.71138 .71487 m .69882 .76756 L .6963 .75578 L p .707 .577 .707 r
F P
0 g
s
.6963 .75578 m .70886 .70309 L .71138 .71487 L p .707 .577 .707 r
F P
0 g
s
.4905 .8214 m .48561 .31901 L .4416 .31676 L p .707 .577 .707 r
F P
0 g
s
.49618 .72028 m .50308 .68466 L .51025 .67538 L p .707 .577 .707 r
F P
0 g
s
.51972 .65842 m .50716 .71111 L .49995 .72059 L p .707 .577 .707 r
F P
0 g
s
.51025 .67538 m .50335 .71099 L .49618 .72028 L p .707 .577 .707 r
F P
0 g
s
.50716 .71111 m .51972 .65842 L .53596 .65217 L p .707 .577 .707 r
F P
0 g
s
.50335 .71099 m .51025 .67538 L .52653 .66893 L p .707 .577 .707 r
F P
0 g
s
.53596 .65217 m .5234 .70486 L .50716 .71111 L p .707 .577 .707 r
F P
0 g
s
.52653 .66893 m .51963 .70455 L .50335 .71099 L p .707 .577 .707 r
F P
0 g
s
.5234 .70486 m .53596 .65217 L .55963 .64976 L p .707 .577 .707 r
F P
0 g
s
.55963 .64976 m .54708 .70244 L .5234 .70486 L p .707 .577 .707 r
F P
0 g
s
.51963 .70455 m .52653 .66893 L .55033 .66595 L p .707 .577 .707 r
F P
0 g
s
.55033 .66595 m .54343 .70157 L .51963 .70455 L p .707 .577 .707 r
F P
0 g
s
.48561 .31901 m .4905 .8214 L .53544 .81991 L p .707 .577 .707 r
F P
0 g
s
.53544 .81991 m .53055 .31752 L .48561 .31901 L p .707 .577 .707 r
F P
0 g
s
.70449 .83752 m .70731 .85612 L .71445 .84853 L p .707 .577 .707 r
F P
0 g
s
.71445 .84853 m .71163 .82993 L .70449 .83752 L p .707 .577 .707 r
F P
0 g
s
.54708 .70244 m .55963 .64976 L .58843 .65142 L p .707 .577 .707 r
F P
0 g
s
.58843 .65142 m .57588 .7041 L .54708 .70244 L p .707 .577 .707 r
F P
0 g
s
.54343 .70157 m .55033 .66595 L .57932 .66674 L p .707 .577 .707 r
F P
0 g
s
.57932 .66674 m .57242 .70236 L .54343 .70157 L p .707 .577 .707 r
F P
0 g
s
.53055 .31752 m .53544 .81991 L .57692 .81483 L p .707 .577 .707 r
F P
0 g
s
.57588 .7041 m .58843 .65142 L .61953 .65699 L p .707 .577 .707 r
F P
0 g
s
.61953 .65699 m .60698 .70968 L .57588 .7041 L p .707 .577 .707 r
F P
0 g
s
.57242 .70236 m .57932 .66674 L .61066 .67121 L p .707 .577 .707 r
F P
0 g
s
.61066 .67121 m .60376 .70682 L .57242 .70236 L p .707 .577 .707 r
F P
0 g
s
.57692 .81483 m .57203 .31244 L .53055 .31752 L p .707 .577 .707 r
F P
0 g
s
.69404 .7485 m .70094 .71288 L .70358 .72409 L p .707 .577 .707 r
F P
0 g
s
.44649 .81915 m .4416 .31676 L .40284 .31099 L p .707 .577 .707 r
F P
0 g
s
.4416 .31676 m .44649 .81915 L .4905 .8214 L p .707 .577 .707 r
F P
0 g
s
.51555 .88103 m .51273 .86243 L .51 .85612 L p .707 .577 .707 r
F P
0 g
s
.57203 .31244 m .57692 .81483 L .61087 .80665 L p .707 .577 .707 r
F P
0 g
s
.66818 .68913 m .66128 .72475 L .63609 .71519 L p .707 .577 .707 r
F P
0 g
s
.63658 .71288 m .66818 .68913 L .63609 .71519 L .707 .577 .707 r
F
.63547 .71807 m .60698 .70968 L p .64576 .67014 L F P
0 g
s
.63438 .71454 m .64128 .67892 L .66818 .68913 L p .707 .577 .707 r
F P
0 g
s
.64989 .66593 m .63733 .71862 L .63547 .71807 L p .707 .577 .707 r
F P
0 g
s
.64576 .67014 m .64989 .66593 L .63547 .71807 L .707 .577 .707 r
F
.63609 .71519 m .63438 .71454 L p .63658 .71288 L F P
0 g
s
.60698 .70968 m .61953 .65699 L .64989 .66593 L p .707 .577 .707 r
F P
0 g
s
.64128 .67892 m .63438 .71454 L .60376 .70682 L p .707 .577 .707 r
F P
0 g
s
.60376 .70682 m .61066 .67121 L .64128 .67892 L p .707 .577 .707 r
F P
0 g
s
.61087 .80665 m .60598 .30426 L .57203 .31244 L p .707 .577 .707 r
F P
0 g
s
.24879 .69549 m .26134 .6428 L .23099 .63386 L p .707 .577 .707 r
F P
0 g
s
.26134 .6428 m .24879 .69549 L .27989 .70106 L p .707 .577 .707 r
F P
0 g
s
.27989 .70106 m .29244 .64837 L .26134 .6428 L p .707 .577 .707 r
F P
0 g
s
.51 .85612 m .51282 .87471 L .51555 .88103 L p .707 .577 .707 r
F P
0 g
s
.21843 .68655 m .23099 .63386 L .20434 .62243 L p .707 .577 .707 r
F P
0 g
s
.23099 .63386 m .21843 .68655 L .24879 .69549 L p .707 .577 .707 r
F P
0 g
s
.29244 .64837 m .27989 .70106 L .30869 .70272 L p .707 .577 .707 r
F P
0 g
s
.30869 .70272 m .32124 .65003 L .29244 .64837 L p .707 .577 .707 r
F P
0 g
s
.70094 .71288 m .69404 .7485 L .68184 .73645 L p .707 .577 .707 r
F P
0 g
s
.70886 .70309 m .6963 .75578 L .68429 .74285 L p .707 .577 .707 r
F P
0 g
s
.68184 .73645 m .68874 .70083 L .70094 .71288 L p .707 .577 .707 r
F P
0 g
s
.68429 .74285 m .69685 .69017 L .70886 .70309 L p .707 .577 .707 r
F P
0 g
s
.71163 .82993 m .71445 .84853 L .71172 .84221 L p .707 .577 .707 r
F P
0 g
s
.71172 .84221 m .7089 .82361 L .71163 .82993 L p .707 .577 .707 r
F P
0 g
s
.40773 .81338 m .40284 .31099 L .37311 .30227 L p .707 .577 .707 r
F P
0 g
s
.40284 .31099 m .40773 .81338 L .44649 .81915 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19179 .67511 m .20434 .62243 L .18402 .60962 L p .707 .577 .707 r
F P
0 g
s
.20434 .62243 m .19179 .67511 L .21843 .68655 L p .707 .577 .707 r
F P
0 g
s
.32124 .65003 m .30869 .70272 L .33236 .70031 L p .707 .577 .707 r
F P
0 g
s
.33236 .70031 m .34492 .64762 L .32124 .65003 L p .707 .577 .707 r
F P
0 g
s
.60598 .30426 m .61087 .80665 L .63398 .79618 L p .707 .577 .707 r
F P
0 g
s
.63398 .79618 m .62909 .29379 L .60598 .30426 L p .707 .577 .707 r
F P
0 g
s
.51282 .87471 m .51 .85612 L .51714 .84852 L p .707 .577 .707 r
F P
0 g
s
.26348 .77482 m .26066 .75622 L .22986 .75917 L p .707 .577 .707 r
F P
0 g
s
.26066 .75622 m .26348 .77482 L .29499 .76967 L p .707 .577 .707 r
F P
0 g
s
.29499 .76967 m .29217 .75108 L .26066 .75622 L p .707 .577 .707 r
F P
0 g
s
.68874 .70083 m .68184 .73645 L .66128 .72475 L p .707 .577 .707 r
F P
0 g
s
.66128 .72475 m .66818 .68913 L .68874 .70083 L p .707 .577 .707 r
F P
0 g
s
.69685 .69017 m .68429 .74285 L .66398 .73005 L p .707 .577 .707 r
F P
0 g
s
.66398 .73005 m .67653 .67736 L .69685 .69017 L p .707 .577 .707 r
F P
0 g
s
.51714 .84852 m .51996 .86712 L .51282 .87471 L p .707 .577 .707 r
F P
0 g
s
.29217 .75108 m .29499 .76967 L .32411 .76283 L p .707 .577 .707 r
F P
0 g
s
.32411 .76283 m .32128 .74423 L .29217 .75108 L p .707 .577 .707 r
F P
0 g
s
.22986 .75917 m .23268 .77777 L .26348 .77482 L p .707 .577 .707 r
F P
0 g
s
.18402 .60962 m .17147 .66231 L .19179 .67511 L p .707 .577 .707 r
F P
0 g
s
.17147 .66231 m .18402 .60962 L .17202 .5967 L p .707 .577 .707 r
F P
0 g
s
.23268 .77777 m .22986 .75917 L .20277 .75962 L p .707 .577 .707 r
F P
0 g
s
.34492 .64762 m .33236 .70031 L .3486 .69405 L p .707 .577 .707 r
F P
0 g
s
.3486 .69405 m .36116 .64137 L .34492 .64762 L p .707 .577 .707 r
F P
0 g
s
.7089 .82361 m .71172 .84221 L .6994 .83779 L p .707 .577 .707 r
F P
0 g
s
.6994 .83779 m .69657 .8192 L .7089 .82361 L p .707 .577 .707 r
F P
0 g
s
.2278 .77731 m .22237 .77595 L p .22774 .78575 L .707 .577 .707 r
F P
0 g
s
.21548 .81156 m .22237 .77595 L .19547 .76574 L p .707 .577 .707 r
F P
0 g
s
.22237 .77595 m .21548 .81156 L .2461 .81928 L p .707 .577 .707 r
F P
0 g
s
.20277 .75962 m .20559 .77822 L .2278 .77785 L p .707 .577 .707 r
F P
0 g
s
.2278 .77785 m .23268 .77777 L p .22782 .77482 L .707 .577 .707 r
F P
0 g
s
.22782 .77482 m .20277 .75962 L .2278 .77785 L .707 .577 .707 r
F
.2461 .81928 m .25299 .78366 L .2278 .77731 L p F P
0 g
s
.2461 .81928 m .2278 .77731 L .22774 .78575 L .707 .577 .707 r
F
.25299 .78366 m .2461 .81928 L .27743 .82375 L p F P
0 g
s
.27743 .82375 m .28433 .78813 L .25299 .78366 L p .707 .577 .707 r
F P
0 g
s
.378 .80466 m .37311 .30227 L .35534 .29145 L p .707 .577 .707 r
F P
0 g
s
.37311 .30227 m .378 .80466 L .40773 .81338 L p .707 .577 .707 r
F P
0 g
s
.32128 .74423 m .32411 .76283 L .34799 .75495 L p .707 .577 .707 r
F P
0 g
s
.34799 .75495 m .34517 .73635 L .32128 .74423 L p .707 .577 .707 r
F P
0 g
s
.28433 .78813 m .27743 .82375 L .30642 .82453 L p .707 .577 .707 r
F P
0 g
s
.30642 .82453 m .31332 .78892 L .28433 .78813 L p .707 .577 .707 r
F P
0 g
s
.67653 .67736 m .66398 .73005 L .63733 .71862 L p .707 .577 .707 r
F P
0 g
s
.63733 .71862 m .64989 .66593 L .67653 .67736 L p .707 .577 .707 r
F P
0 g
s
.19547 .76574 m .18857 .80135 L .21548 .81156 L p .707 .577 .707 r
F P
0 g
s
.18857 .80135 m .19547 .76574 L .17491 .75404 L p .707 .577 .707 r
F P
0 g
s
.20559 .77822 m .20277 .75962 L .18205 .75754 L p .707 .577 .707 r
F P
0 g
s
.17202 .5967 m .15946 .64939 L .17147 .66231 L p .707 .577 .707 r
F P
0 g
s
.51996 .86712 m .51714 .84852 L .53345 .84038 L p .707 .577 .707 r
F P
0 g
s
.31332 .78892 m .30642 .82453 L .33022 .82156 L p .707 .577 .707 r
F P
0 g
s
.33022 .82156 m .33712 .78594 L .31332 .78892 L p .707 .577 .707 r
F P
0 g
s
.18205 .75754 m .18487 .77614 L .20559 .77822 L p .707 .577 .707 r
F P
0 g
s
.53345 .84038 m .53627 .85898 L .51996 .86712 L p .707 .577 .707 r
F P
0 g
s
.34517 .73635 m .34799 .75495 L .3643 .74681 L p .707 .577 .707 r
F P
0 g
s
.3643 .74681 m .36148 .72822 L .34517 .73635 L p .707 .577 .707 r
F P
0 g
s
.62909 .29379 m .63398 .79618 L .64398 .78444 L p .707 .577 .707 r
F P
0 g
s
.64398 .78444 m .63909 .28205 L .62909 .29379 L p .707 .577 .707 r
F P
0 g
s
.15946 .64939 m .17202 .5967 L .16949 .58492 L p .707 .577 .707 r
F P
0 g
s
.36116 .64137 m .3486 .69405 L .35581 .68457 L p .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .36552 .64384 L p .36116 .64137 L .707 .577 .707 r
F P
0 g
s
.36632 .63458 m .36116 .64137 L p .36552 .64384 L .707 .577 .707 r
F P
0 g
s
.35581 .68457 m .35329 .6728 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .36837 .63189 L .36632 .63458 L p .707 .577 .707 r
F P
0 g
s
.36837 .63189 m .36552 .64384 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36552 .64384 m .35581 .68457 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .36125 .26785 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .36165 .6156 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34179 .65905 m .36165 .6156 L .3622 .62601 L .707 .577 .707 r
F
.34129 .65987 m .34181 .65873 L .34179 .65905 L F
.34181 .65873 m .36165 .6156 L .34179 .65905 L F
.36165 .6156 m .36585 .62011 L p .3622 .62601 L F P
0 g
s
.36585 .62011 m .36837 .63189 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .36261 .6337 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .36585 .62011 L p .36484 .64146 L .707 .577 .707 r
F P
0 g
s
.35329 .6728 m .34129 .65987 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36585 .62011 m .36261 .6337 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.36261 .6337 m .35329 .6728 L p .3622 .62601 L .707 .577 .707 r
F P
0 g
s
.35367 .80582 m .36057 .77021 L .3534 .77949 L p .707 .577 .707 r
F P
0 g
s
.3534 .77949 m .3465 .81511 L .35367 .80582 L p .707 .577 .707 r
F P
0 g
s
.36057 .77021 m .35367 .80582 L .35103 .79461 L p .707 .577 .707 r
F P
0 g
s
.35103 .79461 m .35793 .75899 L .36057 .77021 L p .707 .577 .707 r
F P
0 g
s
.36148 .72822 m .3643 .74681 L .37144 .73922 L p .707 .577 .707 r
F P
0 g
s
.37144 .73922 m .36862 .72062 L .36148 .72822 L p .707 .577 .707 r
F P
0 g
s
.36589 .7143 m .36871 .7329 L .35639 .72849 L p .707 .577 .707 r
F P
0 g
s
.35639 .72849 m .35356 .70989 L .36589 .7143 L p .707 .577 .707 r
F P
0 g
s
.3465 .81511 m .3534 .77949 L .33712 .78594 L p .707 .577 .707 r
F P
0 g
s
.35793 .75899 m .35103 .79461 L .34186 .78555 L p .707 .577 .707 r
F P
0 g
s
.34186 .78555 m .33883 .78256 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.34217 .77845 m .35793 .75899 L .34186 .78555 L .707 .577 .707 r
F
.34573 .74694 m .35793 .75899 L p .34217 .77845 L F P
0 g
s
.33883 .78256 m .3429 .76157 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.3429 .76157 m .34573 .74694 L p .34217 .77845 L .707 .577 .707 r
F P
0 g
s
.35125 .27959 m .35291 .45006 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35534 .29145 L p .35808 .61795 L .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .35125 .27959 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35658 .51956 m .35534 .29145 L .35488 .4873 L .707 .577 .707 r
F
.35808 .61795 m .35534 .29145 L .3571 .61452 L F
.36862 .72062 m .37144 .73922 L .36871 .7329 L p F P
0 g
s
.36871 .7329 m .36589 .7143 L .36862 .72062 L p .707 .577 .707 r
F P
0 g
s
.35534 .29145 m .36023 .79384 L .378 .80466 L p .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .35291 .45006 L .36094 .29906 L .707 .577 .707 r
F
.35356 .70989 m .35639 .72849 L .33566 .7264 L p F P
0 g
s
.35755 .64032 m .35488 .4873 L .35614 .78198 L .707 .577 .707 r
F
.35614 .78198 m .36023 .79384 L p .35755 .64032 L F P
0 g
s
.35291 .45006 m .35614 .78198 L p .35488 .4873 L .707 .577 .707 r
F P
0 g
s
.35755 .64032 m .35778 .6169 L .3571 .61452 L .707 .577 .707 r
F
.35894 .72025 m .35778 .6169 L .35755 .64032 L F
.35894 .72025 m .35808 .61795 L .35778 .6169 L F
.3571 .61452 m .35658 .51956 L .35488 .4873 L F
.35614 .78198 m .35355 .51579 L p .36034 .35898 L F P
0 g
s
.35355 .51579 m .35291 .45006 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.35945 .71432 m .35853 .61951 L p .35894 .72025 L .707 .577 .707 r
F P
0 g
s
.35853 .61951 m .35808 .61795 L .35894 .72025 L .707 .577 .707 r
F
.36023 .79384 m .35945 .71432 L p .35894 .72025 L F P
0 g
s
.36614 .77024 m .35614 .78198 L p .36034 .35898 L .707 .577 .707 r
F P
0 g
s
.36034 .35898 m .36094 .29906 L .36135 .33587 L .707 .577 .707 r
F
.36034 .35898 m .36135 .33587 L .36614 .77024 L F
.36125 .26785 m .36146 .2893 L p .36094 .29906 L F P
0 g
s
.36146 .2893 m .36614 .77024 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.35291 .45006 m .35125 .27959 L p .36094 .29906 L .707 .577 .707 r
F P
0 g
s
.34129 .65987 m .34188 .65736 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.34188 .65736 m .35384 .60719 L p .34181 .65873 L .707 .577 .707 r
F P
0 g
s
.69657 .8192 m .6994 .83779 L .67867 .83571 L p .707 .577 .707 r
F P
0 g
s
.67867 .83571 m .67585 .81711 L .69657 .8192 L p .707 .577 .707 r
F P
0 g
s
.17491 .75404 m .16801 .78965 L .18857 .80135 L p .707 .577 .707 r
F P
0 g
s
.16801 .78965 m .17491 .75404 L .16271 .74199 L p .707 .577 .707 r
F P
0 g
s
.18487 .77614 m .18205 .75754 L .16972 .75312 L p .707 .577 .707 r
F P
0 g
s
.33712 .78594 m .33022 .82156 L .3465 .81511 L p .707 .577 .707 r
F P
0 g
s
.16972 .75312 m .17254 .77172 L .18487 .77614 L p .707 .577 .707 r
F P
0 g
s
.16949 .58492 m .15694 .63761 L .15946 .64939 L p .707 .577 .707 r
F P
0 g
s
.53627 .85898 m .53345 .84038 L .55733 .83251 L p .707 .577 .707 r
F P
0 g
s
.55733 .83251 m .56016 .8511 L .53627 .85898 L p .707 .577 .707 r
F P
0 g
s
.67585 .81711 m .67867 .83571 L .65158 .83616 L p .707 .577 .707 r
F P
0 g
s
.65158 .83616 m .64876 .81757 L .67585 .81711 L p .707 .577 .707 r
F P
0 g
s
.15694 .63761 m .16949 .58492 L .17671 .57544 L p .707 .577 .707 r
F P
0 g
s
.16271 .74199 m .15582 .77761 L .16801 .78965 L p .707 .577 .707 r
F P
0 g
s
.56016 .8511 m .55733 .83251 L .58645 .82566 L p .707 .577 .707 r
F P
0 g
s
.63909 .28205 m .64398 .78444 L .63989 .77258 L p .707 .577 .707 r
F P
0 g
s
.63989 .77258 m .635 .27019 L .63909 .28205 L p .707 .577 .707 r
F P
0 g
s
.58645 .82566 m .58927 .84426 L .56016 .8511 L p .707 .577 .707 r
F P
0 g
s
.15582 .77761 m .16271 .74199 L .16007 .73078 L p .707 .577 .707 r
F P
0 g
s
.17254 .77172 m .16972 .75312 L .16699 .74681 L p .707 .577 .707 r
F P
0 g
s
.64876 .81757 m .65158 .83616 L .62078 .83911 L p .707 .577 .707 r
F P
0 g
s
.62078 .83911 m .61796 .82051 L .64876 .81757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16699 .74681 m .16981 .76541 L .17254 .77172 L p .707 .577 .707 r
F P
0 g
s
.17671 .57544 m .16415 .62813 L .15694 .63761 L p .707 .577 .707 r
F P
0 g
s
.58927 .84426 m .58645 .82566 L .61796 .82051 L p .707 .577 .707 r
F P
0 g
s
.61796 .82051 m .62078 .83911 L .58927 .84426 L p .707 .577 .707 r
F P
0 g
s
.16007 .73078 m .15317 .76639 L .15582 .77761 L p .707 .577 .707 r
F P
0 g
s
.16415 .62813 m .17671 .57544 L .19295 .56919 L p .707 .577 .707 r
F P
0 g
s
.15317 .76639 m .16007 .73078 L .16724 .72149 L p .707 .577 .707 r
F P
0 g
s
.16981 .76541 m .16699 .74681 L .17413 .73921 L p .707 .577 .707 r
F P
0 g
s
.19295 .56919 m .18039 .62188 L .16415 .62813 L p .707 .577 .707 r
F P
0 g
s
.17413 .73921 m .17695 .75781 L .16981 .76541 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.635 .27019 m .63989 .77258 L .62212 .76176 L p .707 .577 .707 r
F P
0 g
s
.62212 .76176 m .61723 .25937 L .635 .27019 L p .707 .577 .707 r
F P
0 g
s
.18039 .62188 m .19295 .56919 L .21662 .56677 L p .707 .577 .707 r
F P
0 g
s
.16724 .72149 m .16034 .75711 L .15317 .76639 L p .707 .577 .707 r
F P
0 g
s
.35384 .60719 m .34129 .65987 L .32097 .64707 L p .707 .577 .707 r
F P
0 g
s
.32097 .64707 m .33352 .59438 L .35384 .60719 L p .707 .577 .707 r
F P
0 g
s
.36614 .77024 m .36125 .26785 L .38436 .25738 L p .707 .577 .707 r
F P
0 g
s
.16034 .75711 m .16724 .72149 L .18352 .71504 L p .707 .577 .707 r
F P
0 g
s
.17695 .75781 m .17413 .73921 L .19044 .73108 L p .707 .577 .707 r
F P
0 g
s
.21662 .56677 m .20407 .61946 L .18039 .62188 L p .707 .577 .707 r
F P
0 g
s
.20407 .61946 m .21662 .56677 L .24542 .56844 L p .707 .577 .707 r
F P
0 g
s
.33352 .59438 m .32097 .64707 L .29432 .63564 L p .707 .577 .707 r
F P
0 g
s
.29432 .63564 m .30688 .58295 L .33352 .59438 L p .707 .577 .707 r
F P
0 g
s
.19044 .73108 m .19326 .74967 L .17695 .75781 L p .707 .577 .707 r
F P
0 g
s
.33566 .7264 m .33284 .70781 L .35356 .70989 L p .707 .577 .707 r
F P
0 g
s
.18352 .71504 m .17662 .75066 L .16034 .75711 L p .707 .577 .707 r
F P
0 g
s
.23287 .62112 m .24542 .56844 L .27652 .57401 L p .707 .577 .707 r
F P
0 g
s
.24542 .56844 m .23287 .62112 L .20407 .61946 L p .707 .577 .707 r
F P
0 g
s
.30688 .58295 m .29432 .63564 L .26397 .6267 L p .707 .577 .707 r
F P
0 g
s
.26397 .6267 m .27652 .57401 L .30688 .58295 L p .707 .577 .707 r
F P
0 g
s
.61723 .25937 m .62212 .76176 L .59239 .75304 L p .707 .577 .707 r
F P
0 g
s
.59239 .75304 m .5875 .25065 L .61723 .25937 L p .707 .577 .707 r
F P
0 g
s
.27652 .57401 m .26397 .6267 L .23287 .62112 L p .707 .577 .707 r
F P
0 g
s
.34573 .74694 m .33883 .78256 L .31827 .77086 L p .707 .577 .707 r
F P
0 g
s
.31827 .77086 m .32517 .73524 L .34573 .74694 L p .707 .577 .707 r
F P
0 g
s
.19326 .74967 m .19044 .73108 L .21432 .7232 L p .707 .577 .707 r
F P
0 g
s
.17662 .75066 m .18352 .71504 L .20732 .71207 L p .707 .577 .707 r
F P
0 g
s
.21432 .7232 m .21715 .7418 L .19326 .74967 L p .707 .577 .707 r
F P
0 g
s
.33284 .70781 m .33566 .7264 L .30857 .72686 L p .707 .577 .707 r
F P
0 g
s
.30857 .72686 m .30575 .70826 L .33284 .70781 L p .707 .577 .707 r
F P
0 g
s
.38436 .25738 m .38925 .75977 L .36614 .77024 L p .707 .577 .707 r
F P
0 g
s
.38925 .75977 m .38436 .25738 L .41832 .24921 L p .707 .577 .707 r
F P
0 g
s
.20732 .71207 m .20042 .74768 L .17662 .75066 L p .707 .577 .707 r
F P
0 g
s
.729 .68643 m .74155 .63374 L .7112 .6248 L p .707 .577 .707 r
F P
0 g
s
.74155 .63374 m .729 .68643 L .7601 .692 L p .707 .577 .707 r
F P
0 g
s
.7601 .692 m .77265 .63931 L .74155 .63374 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .7112 .6248 L .70854 .62366 L p .707 .577 .707 r
F P
0 g
s
.69864 .67749 m .70854 .62366 L .69774 .67339 L .707 .577 .707 r
F
.7112 .6248 m .69864 .67749 L .729 .68643 L p F P
0 g
s
.72631 .68113 m .73321 .64551 L .70532 .63848 L p .707 .577 .707 r
F P
0 g
s
.70532 .63848 m .70259 .6378 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.72631 .68113 m .70532 .63848 L .70465 .64156 L .707 .577 .707 r
F
.69569 .67341 m .70259 .6378 L .67568 .62759 L p F P
0 g
s
.70259 .6378 m .69569 .67341 L .69763 .6739 L p .707 .577 .707 r
F P
0 g
s
.69701 .67679 m .69864 .67749 L p .69774 .67339 L .707 .577 .707 r
F P
0 g
s
.69763 .6739 m .72631 .68113 L p .70465 .64156 L .707 .577 .707 r
F P
0 g
s
.70465 .64156 m .70259 .6378 L .69763 .6739 L .707 .577 .707 r
F
.67568 .62759 m .66878 .6632 L .69569 .67341 L p F P
0 g
s
.68456 .61337 m .672 .66606 L .69701 .67679 L p .707 .577 .707 r
F P
0 g
s
.69774 .67339 m .68456 .61337 L .69701 .67679 L .707 .577 .707 r
F
.70854 .62366 m .68456 .61337 L p .69774 .67339 L F P
0 g
s
.77265 .63931 m .7601 .692 L .7889 .69366 L p .707 .577 .707 r
F P
0 g
s
.7889 .69366 m .80145 .64098 L .77265 .63931 L p .707 .577 .707 r
F P
0 g
s
.32517 .73524 m .31827 .77086 L .29137 .76065 L p .707 .577 .707 r
F P
0 g
s
.30303 .72684 m .32517 .73524 L p .30232 .75242 L .707 .577 .707 r
F P
0 g
s
.30575 .70826 m .30857 .72686 L .30302 .72739 L p .707 .577 .707 r
F P
0 g
s
.30302 .72739 m .27777 .7298 L p .3035 .70999 L .707 .577 .707 r
F P
0 g
s
.3035 .70999 m .30575 .70826 L .30302 .72739 L .707 .577 .707 r
F
.29137 .76065 m .29827 .72504 L .30303 .72684 L p F P
0 g
s
.29137 .76065 m .30303 .72684 L .30232 .75242 L .707 .577 .707 r
F
.21715 .7418 m .21432 .7232 L .24344 .71635 L p F P
0 g
s
.20042 .74768 m .20732 .71207 L .23631 .71285 L p .707 .577 .707 r
F P
0 g
s
.73321 .64551 m .72631 .68113 L .75765 .6856 L p .707 .577 .707 r
F P
0 g
s
.75765 .6856 m .76455 .64998 L .73321 .64551 L p .707 .577 .707 r
F P
0 g
s
.24344 .71635 m .24626 .73495 L .21715 .7418 L p .707 .577 .707 r
F P
0 g
s
.76455 .64998 m .75765 .6856 L .78663 .68638 L p .707 .577 .707 r
F P
0 g
s
.78663 .68638 m .79353 .65076 L .76455 .64998 L p .707 .577 .707 r
F P
0 g
s
.27777 .7298 m .27495 .7112 L .30575 .70826 L p .707 .577 .707 r
F P
0 g
s
.5875 .25065 m .59239 .75304 L .55363 .74728 L p .707 .577 .707 r
F P
0 g
s
.55363 .74728 m .54874 .24489 L .5875 .25065 L p .707 .577 .707 r
F P
0 g
s
.24626 .73495 m .24344 .71635 L .27495 .7112 L p .707 .577 .707 r
F P
0 g
s
.66878 .6632 m .67568 .62759 L .65512 .61589 L p .707 .577 .707 r
F P
0 g
s
.672 .66606 m .68456 .61337 L .66424 .60056 L p .707 .577 .707 r
F P
0 g
s
.80145 .64098 m .7889 .69366 L .81258 .69125 L p .707 .577 .707 r
F P
0 g
s
.81258 .69125 m .82513 .63856 L .80145 .64098 L p .707 .577 .707 r
F P
0 g
s
.23631 .71285 m .22941 .74847 L .20042 .74768 L p .707 .577 .707 r
F P
0 g
s
.29827 .72504 m .29137 .76065 L .26075 .75294 L p .707 .577 .707 r
F P
0 g
s
.27495 .7112 m .27777 .7298 L .24626 .73495 L p .707 .577 .707 r
F P
0 g
s
.26075 .75294 m .26765 .71732 L .29827 .72504 L p .707 .577 .707 r
F P
0 g
s
.22941 .74847 m .23631 .71285 L .26765 .71732 L p .707 .577 .707 r
F P
0 g
s
.4232 .7516 m .41832 .24921 L .45979 .24413 L p .707 .577 .707 r
F P
0 g
s
.41832 .24921 m .4232 .7516 L .38925 .75977 L p .707 .577 .707 r
F P
0 g
s
.26765 .71732 m .26075 .75294 L .22941 .74847 L p .707 .577 .707 r
F P
0 g
s
.79353 .65076 m .78663 .68638 L .81043 .6834 L p .707 .577 .707 r
F P
0 g
s
.81043 .6834 m .81733 .64779 L .79353 .65076 L p .707 .577 .707 r
F P
0 g
s
.54874 .24489 m .55363 .74728 L .50963 .74503 L p .707 .577 .707 r
F P
0 g
s
.50963 .74503 m .50474 .24264 L .54874 .24489 L p .707 .577 .707 r
F P
0 g
s
.65512 .61589 m .64823 .6515 L .66878 .6632 L p .707 .577 .707 r
F P
0 g
s
.66424 .60056 m .65168 .65325 L .672 .66606 L p .707 .577 .707 r
F P
0 g
s
.64823 .6515 m .65512 .61589 L .64293 .60384 L p .707 .577 .707 r
F P
0 g
s
.65168 .65325 m .66424 .60056 L .65223 .58764 L p .707 .577 .707 r
F P
0 g
s
.7437 .79209 m .74088 .77349 L .71007 .77644 L p .707 .577 .707 r
F P
0 g
s
.74088 .77349 m .7437 .79209 L .7752 .78694 L p .707 .577 .707 r
F P
0 g
s
.7752 .78694 m .77238 .76835 L .74088 .77349 L p .707 .577 .707 r
F P
0 g
s
.82513 .63856 m .81258 .69125 L .82882 .685 L p .707 .577 .707 r
F P
0 g
s
.82882 .685 m .84137 .63231 L .82513 .63856 L p .707 .577 .707 r
F P
0 g
s
.77238 .76835 m .7752 .78694 L .80432 .7801 L p .707 .577 .707 r
F P
0 g
s
.80432 .7801 m .8015 .7615 L .77238 .76835 L p .707 .577 .707 r
F P
0 g
s
.46468 .74652 m .45979 .24413 L .50474 .24264 L p .707 .577 .707 r
F P
0 g
s
.45979 .24413 m .46468 .74652 L .4232 .7516 L p .707 .577 .707 r
F P
0 g
s
.71007 .77644 m .71289 .79504 L .7437 .79209 L p .707 .577 .707 r
F P
0 g
s
.50474 .24264 m .50963 .74503 L .46468 .74652 L p .707 .577 .707 r
F P
0 g
s
.81733 .64779 m .81043 .6834 L .82672 .67696 L p .707 .577 .707 r
F P
0 g
s
.82672 .67696 m .83361 .64134 L .81733 .64779 L p .707 .577 .707 r
F P
0 g
s
.71289 .79504 m .71007 .77644 L .68298 .77689 L p .707 .577 .707 r
F P
0 g
s
.68298 .77689 m .6858 .79549 L .71289 .79504 L p .707 .577 .707 r
F P
0 g
s
.8015 .7615 m .80432 .7801 L .8282 .77222 L p .707 .577 .707 r
F P
0 g
s
.8282 .77222 m .82538 .75362 L .8015 .7615 L p .707 .577 .707 r
F P
0 g
s
.64293 .60384 m .63603 .63946 L .64823 .6515 L p .707 .577 .707 r
F P
0 g
s
.65223 .58764 m .63968 .64033 L .65168 .65325 L p .707 .577 .707 r
F P
0 g
s
.6858 .79549 m .68298 .77689 L .66226 .77481 L p .707 .577 .707 r
F P
0 g
s
.63968 .64033 m .65223 .58764 L .64971 .57586 L p .707 .577 .707 r
F P
0 g
s
.84137 .63231 m .82882 .685 L .83603 .67552 L p .707 .577 .707 r
F P
0 g
s
.83603 .67552 m .84858 .62283 L .84137 .63231 L p .707 .577 .707 r
F P
0 g
s
.66226 .77481 m .66508 .79341 L .6858 .79549 L p .707 .577 .707 r
F P
0 g
s
.82538 .75362 m .8282 .77222 L .84451 .76408 L p .707 .577 .707 r
F P
0 g
s
.84451 .76408 m .84169 .74549 L .82538 .75362 L p .707 .577 .707 r
F P
0 g
s
.83361 .64134 m .82672 .67696 L .83389 .66767 L p .707 .577 .707 r
F P
0 g
s
.83389 .66767 m .84078 .63206 L .83361 .64134 L p .707 .577 .707 r
F P
0 g
s
.63603 .63946 m .64293 .60384 L .64028 .59262 L p .707 .577 .707 r
F P
0 g
s
.64971 .57586 m .63715 .62855 L .63968 .64033 L p .707 .577 .707 r
F P
0 g
s
.64028 .59262 m .63339 .62824 L .63603 .63946 L p .707 .577 .707 r
F P
0 g
s
.66508 .79341 m .66226 .77481 L .64993 .77039 L p .707 .577 .707 r
F P
0 g
s
.64993 .77039 m .65275 .78899 L .66508 .79341 L p .707 .577 .707 r
F P
0 g
s
.63715 .62855 m .64971 .57586 L .65692 .56638 L p .707 .577 .707 r
F P
0 g
s
.84078 .63206 m .83389 .66767 L .83124 .65646 L p .707 .577 .707 r
F P
0 g
s
.84858 .62283 m .83603 .67552 L .83351 .66374 L p .707 .577 .707 r
F P
0 g
s
.83351 .66374 m .84606 .61105 L .84858 .62283 L p .707 .577 .707 r
F P
0 g
s
.84169 .74549 m .84451 .76408 L .85166 .75649 L p .707 .577 .707 r
F P
0 g
s
.85166 .75649 m .84883 .73789 L .84169 .74549 L p .707 .577 .707 r
F P
0 g
s
.83124 .65646 m .83814 .62084 L .84078 .63206 L p .707 .577 .707 r
F P
0 g
s
.63339 .62824 m .64028 .59262 L .64745 .58334 L p .707 .577 .707 r
F P
0 g
s
.65692 .56638 m .64437 .61907 L .63715 .62855 L p .707 .577 .707 r
F P
0 g
s
.64745 .58334 m .64056 .61896 L .63339 .62824 L p .707 .577 .707 r
F P
0 g
s
.65275 .78899 m .64993 .77039 L .6472 .76408 L p .707 .577 .707 r
F P
0 g
s
.38599 .60345 m .39854 .55076 L .36819 .54182 L p .707 .577 .707 r
F P
0 g
s
.39854 .55076 m .38599 .60345 L .41709 .60902 L p .707 .577 .707 r
F P
0 g
s
.41709 .60902 m .42964 .55633 L .39854 .55076 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6472 .76408 m .65002 .78268 L .65275 .78899 L p .707 .577 .707 r
F P
0 g
s
.35563 .59451 m .36819 .54182 L .34155 .53039 L p .707 .577 .707 r
F P
0 g
s
.36819 .54182 m .35563 .59451 L .38599 .60345 L p .707 .577 .707 r
F P
0 g
s
.42964 .55633 m .41709 .60902 L .44589 .61068 L p .707 .577 .707 r
F P
0 g
s
.44589 .61068 m .45844 .55799 L .42964 .55633 L p .707 .577 .707 r
F P
0 g
s
.64437 .61907 m .65692 .56638 L .67316 .56013 L p .707 .577 .707 r
F P
0 g
s
.83814 .62084 m .83124 .65646 L .81905 .64441 L p .707 .577 .707 r
F P
0 g
s
.84606 .61105 m .83351 .66374 L .8215 .65081 L p .707 .577 .707 r
F P
0 g
s
.81905 .64441 m .82594 .60879 L .83814 .62084 L p .707 .577 .707 r
F P
0 g
s
.8215 .65081 m .83405 .59813 L .84606 .61105 L p .707 .577 .707 r
F P
0 g
s
.84883 .73789 m .85166 .75649 L .84893 .75017 L p .707 .577 .707 r
F P
0 g
s
.84893 .75017 m .84611 .73157 L .84883 .73789 L p .707 .577 .707 r
F P
0 g
s
.64056 .61896 m .64745 .58334 L .66374 .57689 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.32899 .58308 m .34155 .53039 L .32123 .51758 L p .707 .577 .707 r
F P
0 g
s
.34155 .53039 m .32899 .58308 L .35563 .59451 L p .707 .577 .707 r
F P
0 g
s
.45844 .55799 m .44589 .61068 L .46957 .60827 L p .707 .577 .707 r
F P
0 g
s
.46957 .60827 m .48212 .55558 L .45844 .55799 L p .707 .577 .707 r
F P
0 g
s
.67316 .56013 m .66061 .61282 L .64437 .61907 L p .707 .577 .707 r
F P
0 g
s
.66374 .57689 m .65684 .61251 L .64056 .61896 L p .707 .577 .707 r
F P
0 g
s
.65002 .78268 m .6472 .76408 L .65434 .75648 L p .707 .577 .707 r
F P
0 g
s
.40069 .68278 m .39787 .66419 L .36706 .66713 L p .707 .577 .707 r
F P
0 g
s
.39787 .66419 m .40069 .68278 L .43219 .67764 L p .707 .577 .707 r
F P
0 g
s
.43219 .67764 m .42937 .65904 L .39787 .66419 L p .707 .577 .707 r
F P
0 g
s
.66061 .61282 m .67316 .56013 L .69684 .55772 L p .707 .577 .707 r
F P
0 g
s
.82594 .60879 m .81905 .64441 L .79849 .63271 L p .707 .577 .707 r
F P
0 g
s
.79849 .63271 m .80539 .59709 L .82594 .60879 L p .707 .577 .707 r
F P
0 g
s
.83405 .59813 m .8215 .65081 L .80118 .63801 L p .707 .577 .707 r
F P
0 g
s
.80118 .63801 m .81373 .58532 L .83405 .59813 L p .707 .577 .707 r
F P
0 g
s
.65434 .75648 m .65717 .77508 L .65002 .78268 L p .707 .577 .707 r
F P
0 g
s
.42937 .65904 m .43219 .67764 L .46131 .67079 L p .707 .577 .707 r
F P
0 g
s
.46131 .67079 m .45849 .65219 L .42937 .65904 L p .707 .577 .707 r
F P
0 g
s
.36706 .66713 m .36988 .68573 L .40069 .68278 L p .707 .577 .707 r
F P
0 g
s
.32123 .51758 m .30867 .57027 L .32899 .58308 L p .707 .577 .707 r
F P
0 g
s
.30867 .57027 m .32123 .51758 L .30922 .50466 L p .707 .577 .707 r
F P
0 g
s
.36988 .68573 m .36706 .66713 L .33997 .66758 L p .707 .577 .707 r
F P
0 g
s
.48212 .55558 m .46957 .60827 L .48581 .60202 L p .707 .577 .707 r
F P
0 g
s
.48581 .60202 m .49836 .54933 L .48212 .55558 L p .707 .577 .707 r
F P
0 g
s
.84611 .73157 m .84893 .75017 L .8366 .74576 L p .707 .577 .707 r
F P
0 g
s
.8366 .74576 m .83378 .72716 L .84611 .73157 L p .707 .577 .707 r
F P
0 g
s
.69684 .55772 m .68428 .6104 L .66061 .61282 L p .707 .577 .707 r
F P
0 g
s
.65684 .61251 m .66374 .57689 L .68754 .57392 L p .707 .577 .707 r
F P
0 g
s
.365 .68527 m .35958 .68391 L p .36495 .69372 L .707 .577 .707 r
F P
0 g
s
.35268 .71952 m .35958 .68391 L .33267 .6737 L p .707 .577 .707 r
F P
0 g
s
.35958 .68391 m .35268 .71952 L .3833 .72724 L p .707 .577 .707 r
F P
0 g
s
.33997 .66758 m .34279 .68618 L .365 .68581 L p .707 .577 .707 r
F P
0 g
s
.365 .68581 m .36988 .68573 L p .36502 .68278 L .707 .577 .707 r
F P
0 g
s
.36502 .68278 m .33997 .66758 L .365 .68581 L .707 .577 .707 r
F
.3833 .72724 m .3902 .69162 L .365 .68527 L p F P
0 g
s
.3833 .72724 m .365 .68527 L .36495 .69372 L .707 .577 .707 r
F
.3902 .69162 m .3833 .72724 L .41464 .73171 L p F P
0 g
s
.41464 .73171 m .42154 .69609 L .3902 .69162 L p .707 .577 .707 r
F P
0 g
s
.45849 .65219 m .46131 .67079 L .48519 .66291 L p .707 .577 .707 r
F P
0 g
s
.48519 .66291 m .48237 .64431 L .45849 .65219 L p .707 .577 .707 r
F P
0 g
s
.42154 .69609 m .41464 .73171 L .44362 .73249 L p .707 .577 .707 r
F P
0 g
s
.44362 .73249 m .45052 .69688 L .42154 .69609 L p .707 .577 .707 r
F P
0 g
s
.68428 .6104 m .69684 .55772 L .72564 .55938 L p .707 .577 .707 r
F P
0 g
s
.68754 .57392 m .68064 .60953 L .65684 .61251 L p .707 .577 .707 r
F P
0 g
s
.80539 .59709 m .79849 .63271 L .77329 .62315 L p .707 .577 .707 r
F P
0 g
s
.77267 .62603 m .74418 .61764 L p .78296 .5781 L .707 .577 .707 r
F P
0 g
s
.77329 .62315 m .77158 .6225 L p .77379 .62085 L .707 .577 .707 r
F P
0 g
s
.77379 .62085 m .80539 .59709 L .77329 .62315 L .707 .577 .707 r
F
.77158 .6225 m .77848 .58689 L .80539 .59709 L p F P
0 g
s
.78709 .57389 m .77454 .62658 L .77267 .62603 L p .707 .577 .707 r
F P
0 g
s
.78296 .5781 m .78709 .57389 L .77267 .62603 L .707 .577 .707 r
F
.81373 .58532 m .80118 .63801 L .77454 .62658 L p F P
0 g
s
.77454 .62658 m .78709 .57389 L .81373 .58532 L p .707 .577 .707 r
F P
0 g
s
.33267 .6737 m .32577 .70932 L .35268 .71952 L p .707 .577 .707 r
F P
0 g
s
.32577 .70932 m .33267 .6737 L .31211 .662 L p .707 .577 .707 r
F P
0 g
s
.34279 .68618 m .33997 .66758 L .31925 .6655 L p .707 .577 .707 r
F P
0 g
s
.30922 .50466 m .29667 .55735 L .30867 .57027 L p .707 .577 .707 r
F P
0 g
s
.65717 .77508 m .65434 .75648 L .67066 .74835 L p .707 .577 .707 r
F P
0 g
s
.45052 .69688 m .44362 .73249 L .46742 .72952 L p .707 .577 .707 r
F P
0 g
s
.46742 .72952 m .47432 .6939 L .45052 .69688 L p .707 .577 .707 r
F P
0 g
s
.31925 .6655 m .32207 .6841 L .34279 .68618 L p .707 .577 .707 r
F P
0 g
s
.72564 .55938 m .71308 .61206 L .68428 .6104 L p .707 .577 .707 r
F P
0 g
s
.68064 .60953 m .68754 .57392 L .71652 .5747 L p .707 .577 .707 r
F P
0 g
s
.67066 .74835 m .67348 .76694 L .65717 .77508 L p .707 .577 .707 r
F P
0 g
s
.48237 .64431 m .48519 .66291 L .5015 .65478 L p .707 .577 .707 r
F P
0 g
s
.5015 .65478 m .49868 .63618 L .48237 .64431 L p .707 .577 .707 r
F P
0 g
s
.29667 .55735 m .30922 .50466 L .3067 .49288 L p .707 .577 .707 r
F P
0 g
s
.49836 .54933 m .48581 .60202 L .49302 .59254 L p .707 .577 .707 r
F P
0 g
s
.49302 .59254 m .50557 .53985 L .49836 .54933 L p .707 .577 .707 r
F P
0 g
s
.71308 .61206 m .72564 .55938 L .75674 .56495 L p .707 .577 .707 r
F P
0 g
s
.74418 .61764 m .75674 .56495 L .78709 .57389 L p .707 .577 .707 r
F P
0 g
s
.83378 .72716 m .8366 .74576 L .81588 .74367 L p .707 .577 .707 r
F P
0 g
s
.81588 .74367 m .81306 .72508 L .83378 .72716 L p .707 .577 .707 r
F P
0 g
s
.75674 .56495 m .74418 .61764 L .71308 .61206 L p .707 .577 .707 r
F P
0 g
s
.31211 .662 m .30522 .69762 L .32577 .70932 L p .707 .577 .707 r
F P
0 g
s
.71652 .5747 m .70962 .61032 L .68064 .60953 L p .707 .577 .707 r
F P
0 g
s
.77848 .58689 m .77158 .6225 L .74096 .61479 L p .707 .577 .707 r
F P
0 g
s
.74096 .61479 m .74786 .57917 L .77848 .58689 L p .707 .577 .707 r
F P
0 g
s
.70962 .61032 m .71652 .5747 L .74786 .57917 L p .707 .577 .707 r
F P
0 g
s
.74786 .57917 m .74096 .61479 L .70962 .61032 L p .707 .577 .707 r
F P
0 g
s
.30522 .69762 m .31211 .662 L .29992 .64995 L p .707 .577 .707 r
F P
0 g
s
.32207 .6841 m .31925 .6655 L .30692 .66109 L p .707 .577 .707 r
F P
0 g
s
.47432 .6939 m .46742 .72952 L .48371 .72307 L p .707 .577 .707 r
F P
0 g
s
.48371 .72307 m .4906 .68745 L .47432 .6939 L p .707 .577 .707 r
F P
0 g
s
.30692 .66109 m .30974 .67968 L .32207 .6841 L p .707 .577 .707 r
F P
0 g
s
.3067 .49288 m .29414 .54557 L .29667 .55735 L p .707 .577 .707 r
F P
0 g
s
.67348 .76694 m .67066 .74835 L .69454 .74047 L p .707 .577 .707 r
F P
0 g
s
.69454 .74047 m .69736 .75907 L .67348 .76694 L p .707 .577 .707 r
F P
0 g
s
.49868 .63618 m .5015 .65478 L .50865 .64718 L p .707 .577 .707 r
F P
0 g
s
.50865 .64718 m .50582 .62858 L .49868 .63618 L p .707 .577 .707 r
F P
0 g
s
.81306 .72508 m .81588 .74367 L .78879 .74413 L p .707 .577 .707 r
F P
0 g
s
.78879 .74413 m .78597 .72553 L .81306 .72508 L p .707 .577 .707 r
F P
0 g
s
.29414 .54557 m .3067 .49288 L .31391 .4834 L p .707 .577 .707 r
F P
0 g
s
.29992 .64995 m .29302 .68557 L .30522 .69762 L p .707 .577 .707 r
F P
0 g
s
.50557 .53985 m .49302 .59254 L .4905 .58076 L p .707 .577 .707 r
F P
0 g
s
.4905 .58076 m .50305 .52807 L .50557 .53985 L p .707 .577 .707 r
F P
0 g
s
.69736 .75907 m .69454 .74047 L .72366 .73362 L p .707 .577 .707 r
F P
0 g
s
.4906 .68745 m .48371 .72307 L .49088 .71379 L p .707 .577 .707 r
F P
0 g
s
.49088 .71379 m .49777 .67817 L .4906 .68745 L p .707 .577 .707 r
F P
0 g
s
.72366 .73362 m .72648 .75222 L .69736 .75907 L p .707 .577 .707 r
F P
0 g
s
.29302 .68557 m .29992 .64995 L .29727 .63874 L p .707 .577 .707 r
F P
0 g
s
.30974 .67968 m .30692 .66109 L .30419 .65477 L p .707 .577 .707 r
F P
0 g
s
.78597 .72553 m .78879 .74413 L .75798 .74707 L p .707 .577 .707 r
F P
0 g
s
.75798 .74707 m .75516 .72847 L .78597 .72553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30419 .65477 m .30701 .67337 L .30974 .67968 L p .707 .577 .707 r
F P
0 g
s
.31391 .4834 m .30136 .53609 L .29414 .54557 L p .707 .577 .707 r
F P
0 g
s
.72648 .75222 m .72366 .73362 L .75516 .72847 L p .707 .577 .707 r
F P
0 g
s
.75516 .72847 m .75798 .74707 L .72648 .75222 L p .707 .577 .707 r
F P
0 g
s
.50582 .62858 m .50865 .64718 L .50592 .64086 L p .707 .577 .707 r
F P
0 g
s
.50592 .64086 m .5031 .62227 L .50582 .62858 L p .707 .577 .707 r
F P
0 g
s
.29727 .63874 m .29038 .67435 L .29302 .68557 L p .707 .577 .707 r
F P
0 g
s
.30136 .53609 m .31391 .4834 L .33015 .47715 L p .707 .577 .707 r
F P
0 g
s
.50305 .52807 m .4905 .58076 L .47849 .56783 L p .707 .577 .707 r
F P
0 g
s
.47849 .56783 m .49104 .51515 L .50305 .52807 L p .707 .577 .707 r
F P
0 g
s
.49777 .67817 m .49088 .71379 L .48823 .70257 L p .707 .577 .707 r
F P
0 g
s
.48823 .70257 m .49513 .66695 L .49777 .67817 L p .707 .577 .707 r
F P
0 g
s
.29038 .67435 m .29727 .63874 L .30444 .62945 L p .707 .577 .707 r
F P
0 g
s
.30701 .67337 m .30419 .65477 L .31133 .64717 L p .707 .577 .707 r
F P
0 g
s
.33015 .47715 m .3176 .52984 L .30136 .53609 L p .707 .577 .707 r
F P
0 g
s
.31133 .64717 m .31415 .66577 L .30701 .67337 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3176 .52984 m .33015 .47715 L .35383 .47474 L p .707 .577 .707 r
F P
0 g
s
.5031 .62227 m .50592 .64086 L .49359 .63645 L p .707 .577 .707 r
F P
0 g
s
.49359 .63645 m .49077 .61785 L .5031 .62227 L p .707 .577 .707 r
F P
0 g
s
.30444 .62945 m .29755 .66507 L .29038 .67435 L p .707 .577 .707 r
F P
0 g
s
.49104 .51515 m .47849 .56783 L .45817 .55503 L p .707 .577 .707 r
F P
0 g
s
.45817 .55503 m .47072 .50234 L .49104 .51515 L p .707 .577 .707 r
F P
0 g
s
.49513 .66695 m .48823 .70257 L .47604 .69052 L p .707 .577 .707 r
F P
0 g
s
.47604 .69052 m .48293 .65491 L .49513 .66695 L p .707 .577 .707 r
F P
0 g
s
.29755 .66507 m .30444 .62945 L .32073 .623 L p .707 .577 .707 r
F P
0 g
s
.31415 .66577 m .31133 .64717 L .32764 .63904 L p .707 .577 .707 r
F P
0 g
s
.35383 .47474 m .34127 .52742 L .3176 .52984 L p .707 .577 .707 r
F P
0 g
s
.34127 .52742 m .35383 .47474 L .38263 .4764 L p .707 .577 .707 r
F P
0 g
s
.47072 .50234 m .45817 .55503 L .43153 .5436 L p .707 .577 .707 r
F P
0 g
s
.43153 .5436 m .44408 .49091 L .47072 .50234 L p .707 .577 .707 r
F P
0 g
s
.32764 .63904 m .33047 .65764 L .31415 .66577 L p .707 .577 .707 r
F P
0 g
s
.49077 .61785 m .49359 .63645 L .47287 .63437 L p .707 .577 .707 r
F P
0 g
s
.47287 .63437 m .47004 .61577 L .49077 .61785 L p .707 .577 .707 r
F P
0 g
s
.32073 .623 m .31383 .65862 L .29755 .66507 L p .707 .577 .707 r
F P
0 g
s
.37007 .52908 m .38263 .4764 L .41372 .48197 L p .707 .577 .707 r
F P
0 g
s
.38263 .4764 m .37007 .52908 L .34127 .52742 L p .707 .577 .707 r
F P
0 g
s
.44408 .49091 m .43153 .5436 L .40117 .53466 L p .707 .577 .707 r
F P
0 g
s
.40117 .53466 m .41372 .48197 L .44408 .49091 L p .707 .577 .707 r
F P
0 g
s
.41372 .48197 m .40117 .53466 L .37007 .52908 L p .707 .577 .707 r
F P
0 g
s
.48293 .65491 m .47604 .69052 L .45548 .67882 L p .707 .577 .707 r
F P
0 g
s
.45548 .67882 m .46238 .64321 L .48293 .65491 L p .707 .577 .707 r
F P
0 g
s
.33047 .65764 m .32764 .63904 L .35153 .63116 L p .707 .577 .707 r
F P
0 g
s
.31383 .65862 m .32073 .623 L .34453 .62003 L p .707 .577 .707 r
F P
0 g
s
.35153 .63116 m .35435 .64976 L .33047 .65764 L p .707 .577 .707 r
F P
0 g
s
.47004 .61577 m .47287 .63437 L .44578 .63482 L p .707 .577 .707 r
F P
0 g
s
.44578 .63482 m .44295 .61622 L .47004 .61577 L p .707 .577 .707 r
F P
0 g
s
.34453 .62003 m .33763 .65564 L .31383 .65862 L p .707 .577 .707 r
F P
0 g
s
.46238 .64321 m .45548 .67882 L .42857 .66861 L p .707 .577 .707 r
F P
0 g
s
.44024 .63481 m .46238 .64321 L p .43953 .66038 L .707 .577 .707 r
F P
0 g
s
.44295 .61622 m .44578 .63482 L .44022 .63535 L p .707 .577 .707 r
F P
0 g
s
.44022 .63535 m .41497 .63776 L p .44071 .61795 L .707 .577 .707 r
F P
0 g
s
.44071 .61795 m .44295 .61622 L .44022 .63535 L .707 .577 .707 r
F
.42857 .66861 m .43547 .633 L .44024 .63481 L p F P
0 g
s
.42857 .66861 m .44024 .63481 L .43953 .66038 L .707 .577 .707 r
F
.35435 .64976 m .35153 .63116 L .38065 .62431 L p F P
0 g
s
.33763 .65564 m .34453 .62003 L .37351 .62081 L p .707 .577 .707 r
F P
0 g
s
.38065 .62431 m .38347 .64291 L .35435 .64976 L p .707 .577 .707 r
F P
0 g
s
.41497 .63776 m .41215 .61916 L .44295 .61622 L p .707 .577 .707 r
F P
0 g
s
.38347 .64291 m .38065 .62431 L .41215 .61916 L p .707 .577 .707 r
F P
0 g
s
.37351 .62081 m .36661 .65643 L .33763 .65564 L p .707 .577 .707 r
F P
0 g
s
.43547 .633 m .42857 .66861 L .39795 .6609 L p .707 .577 .707 r
F P
0 g
s
.41215 .61916 m .41497 .63776 L .38347 .64291 L p .707 .577 .707 r
F P
0 g
s
.39795 .6609 m .40485 .62528 L .43547 .633 L p .707 .577 .707 r
F P
0 g
s
.36661 .65643 m .37351 .62081 L .40485 .62528 L p .707 .577 .707 r
F P
0 g
s
.40485 .62528 m .39795 .6609 L .36661 .65643 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001eOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol0
079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007Ao
o`00Kgoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01000L7oo001/Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001]Ool006Yoo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00
J7oo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001VOol20005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001TOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001W
Ool006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0
06Aoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005eooa8000QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Ioo`00Fgoo0`001UYF00<005YFFUH01EYF00<005YFFUH0100015YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IWoo001IOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH5000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001VOol005Qoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00F7oo00D005YFFUIJEP0000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Egoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00H005YF0000
05YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Ioo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001FOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Ioo`00EGoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001VOol005Eo
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00EGoo00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo
00<005YFFUH00UYF4`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Ao
o`800005FUH00000FUH00006FUH40002FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00E7oo00=JEP0000000eYF00<005YFFUH00eYF00@005YFFUIJ
EP800003FUH005YF00EJEP03001JEP0000<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP8000IJEP03001JEUYF00=JEP@0009JEP03001JEUYF
00IJEP03001JEUYF00AJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol005=oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00IJEPD000MJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH01P00
FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00<0
05YFFUH015YF0`0000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00@000UJEP8000IJEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Aoo`05001JEUYFFUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH=0004FUH02000FUIJEP00FUH0
05YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000<Ool7001COol005Eo
o`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP05FUH01000
FUIJEP000UYF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001goo1@000eYF00@005YFFUIJEPT004Yoo`00EGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP05001J
EP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool200000eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60014Ool003Iooa8000ioo`8000IJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000@Woo000dOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20002FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000oOol0039oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD000Moo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP800004FUH005YF0002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<0
05YF00003`001UYF00<005YFFUH01EYF0`00?7oo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP040005Ool200000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00001JEPD000=JEP03
001JEUYF00EJEP03001JEUYF009JEPL000QJEP04001JEP00000jOol0035oo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30004Ool20008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800006Ool00000001J
EP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YFFUIJEP<003Mo
o`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0`0017oo0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0
00MJEP8003Eoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP8000Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH00006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH20008FUH3000cOol002moo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`800003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000MJEP05
001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001oogoo00=oo`<000MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00FUIJEP02FUH2000`Ool002moo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000=oo`03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0]Ool002moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800005Ool005YFFUH00003FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20008FUH0
0`00FUIJEP04FUH2000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF
00AJEP03001JEP0000<0009JEP03001JEUYF00EJEP04001JEUYFFUH60008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH00eYF3P0000=J
EP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP04001JEUYF0003FUH@0004FUH00`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH50003FUH20002Ool>0008FUH20007FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;7oo000^Ool00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP0C0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02000
FUIJEUYF001JEP00FUH40006FUH01000FUH000002Goo200015YF00<005YF00001eYF00<005YFFUH0
15YF00<005YFFUH00P00;7oo000]Ool00`00FUIJEP02FUHC0006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH0000?0002FUH9000;FUH00`00FUIJEP03FUH00`00FUH00003000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00AJEP04001JEUYFFUH2
000=Ool500000eYF00000007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00;Goo0P00
00EJEP00001JEP0000IJEP8000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH015YF
10002goo1P001eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000[Ool002eoo`03FUH0000000=J
EP03001JEUYF00AJEP04001JEP00000;Ool40007FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YF
FUH015YF00<005YFFUH01UYF00@005YF000000aoo`@000IJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF0000:goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000=Ool40002FUH00`00
FUIJEP020003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00eoo`8000AJEP03001JEUYF00AJEP04001JEUYF0002FUH/Ool002aoo`<000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP@000eoo`<00003FUH0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEPl000=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH6
0009Ool200000eYF001JEP05FUH01`00FUIJEUYF001JEP0002aoo`00;7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100037oo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP03001JEUYF
009JEPD00003FUH0000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool20006FUH0
1`00FUIJEUYF001JEP0002aoo`00;7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH015YF1@001goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF0`001EYF0P0000=JEP0000000P0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
100015YF00<005YFFUH01UYF00@005YFFUIJEPL000AJEP07001JEUYFFUH005YF0000;7oo000]Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010000goo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
0`000UYF0P000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00AJEP03001JEUYF00]JEPL000IJEP03001JEUYF00EJEP04001JEUYF0003
FUH01P00FUIJEP00FUH002eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00=JEP03001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00eJ
EP03001JEUYF009JEPP000IJEP03001JEP0000@000=JEP03001JEP0002eoo`00;Woo00@005YFFUH0
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP<000QJEP03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
00AJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000IJ
EP03001JEUYF00eJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH20003FUH00`00FUH0000]Ool0
02ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50006FUH200000eYF001JEP02
FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009o
o`<000AJEP03001JEUYF00aJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EP00009JEP03001JEP0002eoo`00;goo0P001UYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF
0`000eYF1`0000=JEP0000000eYF00@005YFFUH000AJEPH000MJEP03001JEP0000EJEP03001JEUYF
00AJEP@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
00Aoo`80009JEP03001JEUYF00eJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH200000eYF001oo`0]Ool0031oo`03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00EJEPD000IJEP04001JEP00FUH200000eYF001JEP020004FUH20002FUH01000FUIJEP0015YF2000
15YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo0`003eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH007oo02eoo`00<Goo0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF0`001eYF00L005YF000005YF001JEP0D0004FUH01000FUIJEUYF
0`0000=JEP0000001eYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000Eoo`8000iJEP03001JEP00
008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`0]Ool003=o
o`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000MJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUH00000FUH00P001Goo0P0035YF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00P005YF
FUH005YF001JEP00;Woo000eOol20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF001J
EUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF
00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000003FUH30004Ool200000eYF00000006FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000_Ool003Moo`8000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP8000AJEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00AJEPP00003FUH005YF00EJEP06001JEUYF001JEP000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0P0017oo1`00
0UYF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000_
Ool003Uoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP<00003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEPD000MJEP8000IJEP06001JEUYF001JEP00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
25YF0`001Goo0`0000=JEP0000001P000eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF0000
05YF0080031oo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUH000=JEP03001J
EUYF00@000=JEP03001JEUYF00=JEP<000AJEPH000AJEP03001JEUYF00MJEP8000=JEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001eYF00D005YFFUIJEP0000Moo`<00003FUH005YF009JEPP000AJEP04001JEUYFFUH5
0002FUH2000aOol003eoo`<000MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH:0002FUH:0005FUH00`00FUIJEP09FUH200000eYF001JEP02FUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP02FUH2
0008Ool60004FUH00`00FUIJEP080003FUH01000FUH00000<goo0010Ool40002FUH00`00FUIJEP07
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF
00UJEP04001JEP000003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP04FUH00`00Oomoo`0;Ool80004FUH01000FUIJ
EUYF1000=Goo0014Ool50007FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH400000eYF000000070008FUH5000015YF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH015YF0P0057oo2000>Goo
0019Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJ
EP04FUH01000FUIJEP00E7oo001=Ool<0003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJ
EP05001JEUYFFUH0001COol005Uoo`800003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05001J
EUYFFUH0001COol005=oo`/000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP03001JEUYF008005=oo`00>7oo
40000Woo2@002eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0001BOol003=o
o`D0009JEP03001JEUYF00IJEP03001JEUYF009JEPL000mJEP03001JEP0000800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP0000Ioo`<004Uoo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00EJEP04001JEUYFFUH30006FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00005Ool50018Ool002moo`8000=JEP03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00MJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P001UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF
00AJEP04001JEUYF0002FUH6Ool50018Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPl000=JEP05001JEUYF001JEP050006FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH0000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001oo`800003FUH005YF00EJEP07001JEUYFFUH005YF00001Woo
1@001Woo4P00<7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP020009Ool40002FUH00`00FUIJEP03FUH50002FUH00`00
FUIJEP06FUH01000FUIJEUYF10002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000goo0P001UYF00L005YFFUIJEP00FUH00007Ool:0004FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3000^Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`80009JEP03001JEUYF00=J
EP03001JEUYF009JEPl0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000L000AJEP07001JEUYFFUH005YF00000Woo1P0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;7oo000]Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH20004Ool300001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00@005YFFUH000=JEP05001JEUYF001JEP0400000eYF001JEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00:goo000/Ool00`00FUH00004FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH500001EYF
001JEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YF0000100000=JEP0000000P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00:goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH017ooFUIJEP000UYF
0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H0
009JEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
000[Ool002aoo`03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH01@00FUIJEUYF
00000eYF00<005YFFUH00eYF0P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH2
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000>Ool50002FUH00`00Oomoo`0YOol002aoo`80
00=JEPL000aoo`@0009JEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF00AJEP@0009JEP03
001JEUYF00=JEP03001JEUYF00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEP00008000MJEP03001JEUYF00AJ
EPH001Qoo`80009JEP@002Yoo`00;7oo00=JEP00FUH00P0000=JEP00FUH00P004Woo10001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00=JEP<0
00MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001J
EUYF009JEP04001JEP00FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04000LOol20004FUH01000
FUH00000:Woo000[Ool01`00FUH00000FUH005YF00@000Qooa80009JEP8000MJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH01@00FUH005YF
000015YF00<005YFFUH015YF100077oo100000=JEP00FUH015YF00<005YF0000:Woo000[Ool30002
FUH2000015YF001JEUYF20000eYF00<005YFFUH01UYF00<005YFFUH00eYF10001eYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP8000=JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03001JEP00008000EJEP04
001JEUYFFUH300000eYF001oo`0IOol30005FUH00`00FUIJEP03FUH2000[Ool002]oo`03001JEP00
009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00AJEP05001JEUYFFUH00002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP05001JEP00FUH00005FUH00`00FUH00005000GOol400000eYF001JEP06FUH01000FUIJEUYF0P00
;7oo000[Ool00`00FUH00002FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH800000eYF001JEP05FUH00`00FUIJEP020002FUH01000FUH000001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF0`0000EJEP00FUIJEP0000=JEP<0009JEP04001JEP00000@Ool70005FUH00`00FUIJ
EP05FUH01000FUH00000;Woo000[Ool00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH40008Ool20006FUH00`00FUIJEP020002FUH200000eYF001JEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200001UYF001JEUYF001JEP800003FUH005YF00800003FUH0000000Qoo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00;7oo00D005YFFUIJEP00009JEP@000=J
EP03001JEUYF00=JEP03OomJEP0000AJEPH000ioo`8000=JEP04001JEUYFFUH200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF000005YF500015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`00<goo000/Ool01@00FUIJEUYF00001EYF5P004Goo0P0000=JEP00
FUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`00=goo000]
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000COol20003FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04000jOol002ioo`8000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEPL000moo`D00003FUH00000008000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEPD003ioo`00;goo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF3`000UYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF00000Woo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1000@goo000`Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000Eoo`D0009JEP03001JEUYF00EJEP03001JEUYF009JEPL004Moo`00<Woo0P0000=JEP00FUH0
1eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00@005YF001oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000]oo`l004ioo`00=7oo
0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P0017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00=goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P001Woo0P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000006aoo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH4001^Ool003aoo`<000IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000;Ool300000eYF001JEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07001`Ool003moo`@0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH2000?Ool70005FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50003Ool5001_Ool004=oo`D000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEP00000HOol<0006FUH00`00FUIJEP0:FUH00`00FUIJEP06
0008Ool50006OolB001GOol004Qoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH4000VOolF000>
Ool;0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001EOol004aoo`l004Yoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008005=oo`00XGoo100000=JEP00
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00
WGoo10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00DWoo002IOol400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003
FUH01@00FUIJEUYF0000DWoo002GOol20005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000>Ool5
0002FUH00`00Oomoo`1@Ool009Eoo`<000IJEP03001JEUYF00IJEP03001JEUYF00@001Moo`800003
FUH000000080055oo`00Tgoo0P000UYF00<005YFFUH01EYF00<005YFFUH015YF100067oo0`000eYF
00@005YF0000055oo`00TWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0100067oo1000
00=JEP00FUH015YF00<005YF0000DGoo002AOol20005FUH00`00FUIJEP03FUH4000IOol30005FUH0
0`00FUIJEP03FUH2001BOol0091oo`03001JEP0000EJEP03001JEP0000<001Uoo`@00003FUH005YF
00IJEP04001JEUYFFUH2001COol0091oo`04001JEUYF0003FUH3000HOol50005FUH00`00FUIJEP05
FUH01000FUH00000EGoo002@Ool01@00FUIJEP00FUH00P005goo10000UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`00Egoo002AOol00`00FUH000040007Ool?0006FUH00`00FUIJEP06FUH00`00FUH0
0003001JOol0095oo`80009JEP03001JEUYF00L000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP<005ioo`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01000HGoo002AOol20003FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5001UOol0099oo`80009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@006Yoo`00U7oo1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF1`00KWoo002IOol?001eOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59191 .78729 m .59619 .75096 L .59594 .75092 L p .707 .577 .707 r
F P
0 g
s
.59594 .75092 m .56523 .74544 L p .59053 .78512 L .707 .577 .707 r
F P
0 g
s
.59191 .78729 m .59594 .75092 L .59053 .78512 L .707 .577 .707 r
F
.59619 .75096 m .59191 .78729 L .62355 .78978 L p F P
0 g
s
.62355 .78978 m .62783 .75345 L .62746 .75342 L p .707 .577 .707 r
F P
0 g
s
.62746 .75342 m .59619 .75096 L p .62142 .78675 L .707 .577 .707 r
F P
0 g
s
.62355 .78978 m .62746 .75342 L .62142 .78675 L .707 .577 .707 r
F
.62783 .75345 m .62355 .78978 L .65279 .789 L p F P
0 g
s
.65279 .789 m .65707 .75267 L .65665 .75268 L p .707 .577 .707 r
F P
0 g
s
.65665 .75268 m .62783 .75345 L p .65039 .78558 L .707 .577 .707 r
F P
0 g
s
.65279 .789 m .65665 .75268 L .65039 .78558 L .707 .577 .707 r
F
.65707 .75267 m .65279 .789 L .67674 .78501 L p F P
0 g
s
.67674 .78501 m .68102 .74868 L .68065 .74874 L p .707 .577 .707 r
F P
0 g
s
.68065 .74874 m .65707 .75267 L p .67467 .78161 L .707 .577 .707 r
F P
0 g
s
.67674 .78501 m .68065 .74874 L .67467 .78161 L .707 .577 .707 r
F
.68102 .74868 m .67674 .78501 L .69308 .77822 L p F P
0 g
s
.69308 .77822 m .69736 .74189 L .69711 .74199 L p .707 .577 .707 r
F P
0 g
s
.69711 .74199 m .68102 .74868 L p .69181 .77512 L .707 .577 .707 r
F P
0 g
s
.69308 .77822 m .69711 .74199 L .69181 .77512 L .707 .577 .707 r
F
.69736 .74189 m .69308 .77822 L .70019 .76928 L p F P
0 g
s
.70019 .76928 m .70447 .73295 L .70437 .73307 L p .707 .577 .707 r
F P
0 g
s
.70437 .73307 m .69736 .74189 L p .69992 .76666 L .707 .577 .707 r
F P
0 g
s
.70019 .76928 m .70437 .73307 L .69992 .76666 L .707 .577 .707 r
F
.69456 .76028 m .70169 .75122 L p .70232 .70942 L F P
0 g
s
.70169 .75122 m .70513 .72738 L p .70236 .70613 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .7095 .69707 L .70896 .69776 L p .707 .577 .707 r
F P
0 g
s
.70896 .69776 m .70236 .70613 L p .70513 .72738 L .707 .577 .707 r
F P
0 g
s
.70447 .73295 m .70019 .76928 L .69987 .7681 L p .707 .577 .707 r
F P
0 g
s
.70169 .75122 m .69894 .74066 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.70513 .72738 m .70169 .75122 L p .70872 .70026 L .707 .577 .707 r
F P
0 g
s
.69987 .7681 m .69739 .75907 L p .70435 .7334 L .707 .577 .707 r
F P
0 g
s
.70435 .7334 m .70447 .73295 L .69987 .7681 L .707 .577 .707 r
F
.7095 .69707 m .70513 .72738 L p .70872 .70026 L F P
0 g
s
.70236 .70613 m .69801 .73638 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.69801 .73638 m .69456 .76028 L p .70232 .70942 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .69456 .76028 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68604 .7128 m .68168 .74311 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.68168 .74311 m .67824 .76696 L p .68661 .71598 L .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .67824 .76696 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.66214 .71643 m .65774 .74692 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.65774 .74692 m .65433 .77058 L p .66302 .71919 L .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .65433 .77058 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.63298 .71666 m .62854 .74742 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.62854 .74742 m .62517 .77082 L p .63376 .71864 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .62517 .77082 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.60142 .71347 m .59694 .74458 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59694 .74458 m .59362 .76763 L p .60174 .71424 L .707 .577 .707 r
F P
0 g
s
.59362 .76763 m .60142 .71347 L .57056 .70718 L p .707 .577 .707 r
F P
0 g
s
.62517 .77082 m .63298 .71666 L .60142 .71347 L p .707 .577 .707 r
F P
0 g
s
.65433 .77058 m .66214 .71643 L .63298 .71666 L p .707 .577 .707 r
F P
0 g
s
.56276 .76133 m .57056 .70718 L .54342 .69839 L p .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56523 .74544 L .56515 .74542 L p .707 .577 .707 r
F P
0 g
s
.56603 .73867 m .56276 .76133 L .56307 .76139 L p .707 .577 .707 r
F P
0 g
s
.54342 .69839 m .53562 .75254 L .56276 .76133 L p .707 .577 .707 r
F P
0 g
s
.56515 .74542 m .53798 .73742 L p .56052 .78095 L .707 .577 .707 r
F P
0 g
s
.56095 .78177 m .56515 .74542 L .56052 .78095 L .707 .577 .707 r
F
.57056 .70718 m .56603 .73867 L p .59362 .76763 L F P
0 g
s
.56523 .74544 m .56095 .78177 L .59191 .78729 L p .707 .577 .707 r
F P
0 g
s
.56307 .76139 m .59362 .76763 L p .56603 .73867 L .707 .577 .707 r
F P
0 g
s
.67824 .76696 m .68604 .7128 L .66214 .71643 L p .707 .577 .707 r
F P
0 g
s
.53562 .75254 m .54342 .69839 L .52265 .68797 L p .707 .577 .707 r
F P
0 g
s
.53798 .73742 m .5337 .77375 L .56095 .78177 L p .707 .577 .707 r
F P
0 g
s
.52265 .68797 m .51484 .74212 L .53562 .75254 L p .707 .577 .707 r
F P
0 g
s
.5337 .77375 m .53798 .73742 L .51712 .7277 L p .707 .577 .707 r
F P
0 g
s
.69456 .76028 m .70236 .70613 L .68604 .7128 L p .707 .577 .707 r
F P
0 g
s
.60262 .87177 m .60087 .85314 L .56984 .85424 L p .707 .577 .707 r
F P
0 g
s
.60087 .85314 m .60262 .87177 L .63433 .86829 L p .707 .577 .707 r
F P
0 g
s
.63433 .86829 m .63258 .84967 L .60087 .85314 L p .707 .577 .707 r
F P
0 g
s
.63258 .84967 m .63433 .86829 L .66361 .86277 L p .707 .577 .707 r
F P
0 g
s
.66361 .86277 m .66186 .84414 L .63258 .84967 L p .707 .577 .707 r
F P
0 g
s
.51484 .74212 m .52265 .68797 L .51028 .67694 L p .707 .577 .707 r
F P
0 g
s
.56984 .85424 m .57159 .87286 L .60262 .87177 L p .707 .577 .707 r
F P
0 g
s
.51712 .7277 m .51284 .76403 L .5337 .77375 L p .707 .577 .707 r
F P
0 g
s
.57159 .87286 m .56984 .85424 L .54253 .85284 L p .707 .577 .707 r
F P
0 g
s
.54253 .85284 m .54427 .87146 L .57159 .87286 L p .707 .577 .707 r
F P
0 g
s
.66186 .84414 m .66361 .86277 L .6876 .85574 L p .707 .577 .707 r
F P
0 g
s
.6876 .85574 m .68585 .83712 L .66186 .84414 L p .707 .577 .707 r
F P
0 g
s
.51028 .67694 m .50247 .73109 L .51484 .74212 L p .707 .577 .707 r
F P
0 g
s
.51284 .76403 m .51712 .7277 L .50468 .71723 L p .707 .577 .707 r
F P
0 g
s
.54427 .87146 m .54253 .85284 L .5216 .84908 L p .707 .577 .707 r
F P
0 g
s
.50468 .71723 m .5004 .75355 L .51284 .76403 L p .707 .577 .707 r
F P
0 g
s
.5216 .84908 m .52335 .86771 L .54427 .87146 L p .707 .577 .707 r
F P
0 g
s
.50247 .73109 m .51028 .67694 L .50752 .66637 L p .707 .577 .707 r
F P
0 g
s
.68585 .83712 m .6876 .85574 L .70395 .8479 L p .707 .577 .707 r
F P
0 g
s
.70395 .8479 m .7022 .82928 L .68585 .83712 L p .707 .577 .707 r
F P
0 g
s
.50752 .66637 m .49972 .72052 L .50247 .73109 L p .707 .577 .707 r
F P
0 g
s
.5004 .75355 m .50468 .71723 L .50188 .70702 L p .707 .577 .707 r
F P
0 g
s
.52335 .86771 m .5216 .84908 L .50911 .84334 L p .707 .577 .707 r
F P
0 g
s
.50911 .84334 m .51085 .86197 L .52335 .86771 L p .707 .577 .707 r
F P
0 g
s
.69894 .74066 m .70235 .71699 L p .7095 .69707 L .707 .577 .707 r
F P
0 g
s
.70674 .68651 m .69894 .74066 L .68657 .72963 L p .707 .577 .707 r
F P
0 g
s
.70167 .72274 m .69739 .75907 L .69609 .75797 L p .707 .577 .707 r
F P
0 g
s
.69609 .75797 m .68495 .74859 L p .70141 .72315 L .707 .577 .707 r
F P
0 g
s
.70141 .72315 m .70167 .72274 L .69609 .75797 L .707 .577 .707 r
F
.70235 .71699 m .70674 .68651 L .70691 .68715 L p F P
0 g
s
.70691 .68715 m .7095 .69707 L p .70235 .71699 L .707 .577 .707 r
F P
0 g
s
.50188 .70702 m .4976 .74335 L .5004 .75355 L p .707 .577 .707 r
F P
0 g
s
.7022 .82928 m .70395 .8479 L .71105 .84001 L p .707 .577 .707 r
F P
0 g
s
.71105 .84001 m .7093 .82139 L .7022 .82928 L p .707 .577 .707 r
F P
0 g
s
.4976 .74335 m .50188 .70702 L .50899 .69808 L p .707 .577 .707 r
F P
0 g
s
.49972 .72052 m .50752 .66637 L .51466 .65731 L p .707 .577 .707 r
F P
0 g
s
.49047 .82157 m .48745 .31937 L .44344 .31695 L p .707 .577 .707 r
F P
0 g
s
.50899 .69808 m .50471 .73441 L .4976 .74335 L p .707 .577 .707 r
F P
0 g
s
.51466 .65731 m .50685 .71146 L .49972 .72052 L p .707 .577 .707 r
F P
0 g
s
.50471 .73441 m .50899 .69808 L .52533 .69129 L p .707 .577 .707 r
F P
0 g
s
.50685 .71146 m .51466 .65731 L .53098 .65064 L p .707 .577 .707 r
F P
0 g
s
.52533 .69129 m .52105 .72762 L .50471 .73441 L p .707 .577 .707 r
F P
0 g
s
.53098 .65064 m .52317 .70479 L .50685 .71146 L p .707 .577 .707 r
F P
0 g
s
.52105 .72762 m .52533 .69129 L .54928 .6873 L p .707 .577 .707 r
F P
0 g
s
.52317 .70479 m .53098 .65064 L .55489 .64701 L p .707 .577 .707 r
F P
0 g
s
.54928 .6873 m .545 .72363 L .52105 .72762 L p .707 .577 .707 r
F P
0 g
s
.55489 .64701 m .54708 .70116 L .52317 .70479 L p .707 .577 .707 r
F P
0 g
s
.53147 .83907 m .52973 .82044 L .55371 .81342 L p .707 .577 .707 r
F P
0 g
s
.48745 .31937 m .49047 .82157 L .53542 .82023 L p .707 .577 .707 r
F P
0 g
s
.53542 .82023 m .53239 .31803 L .48745 .31937 L p .707 .577 .707 r
F P
0 g
s
.545 .72363 m .54928 .6873 L .57851 .68652 L p .707 .577 .707 r
F P
0 g
s
.54708 .70116 m .55489 .64701 L .58404 .64678 L p .707 .577 .707 r
F P
0 g
s
.57851 .68652 m .57424 .72284 L .545 .72363 L p .707 .577 .707 r
F P
0 g
s
.58404 .64678 m .57624 .70093 L .54708 .70116 L p .707 .577 .707 r
F P
0 g
s
.55371 .81342 m .55546 .83204 L .53147 .83907 L p .707 .577 .707 r
F P
0 g
s
.55546 .83204 m .55371 .81342 L .583 .80789 L p .707 .577 .707 r
F P
0 g
s
.583 .80789 m .58474 .82652 L .55546 .83204 L p .707 .577 .707 r
F P
0 g
s
.53239 .31803 m .53542 .82023 L .5769 .81527 L p .707 .577 .707 r
F P
0 g
s
.57424 .72284 m .57851 .68652 L .61016 .68901 L p .707 .577 .707 r
F P
0 g
s
.61016 .68901 m .60588 .72534 L .57424 .72284 L p .707 .577 .707 r
F P
0 g
s
.5769 .81527 m .57387 .31306 L .53239 .31803 L p .707 .577 .707 r
F P
0 g
s
.69739 .75907 m .70167 .72274 L .70447 .73295 L p .707 .577 .707 r
F P
0 g
s
.44647 .81915 m .44344 .31695 L .40468 .31102 L p .707 .577 .707 r
F P
0 g
s
.44344 .31695 m .44647 .81915 L .49047 .82157 L p .707 .577 .707 r
F P
0 g
s
.51085 .86197 m .50911 .84334 L .50627 .83617 L p .707 .577 .707 r
F P
0 g
s
.57624 .70093 m .58404 .64678 L .6156 .64997 L p .707 .577 .707 r
F P
0 g
s
.6156 .64997 m .60779 .70412 L .57624 .70093 L p .707 .577 .707 r
F P
0 g
s
.58474 .82652 m .583 .80789 L .6147 .80442 L p .707 .577 .707 r
F P
0 g
s
.57387 .31306 m .5769 .81527 L .61085 .80717 L p .707 .577 .707 r
F P
0 g
s
.6736 .66506 m .6658 .71921 L .63892 .71051 L p .707 .577 .707 r
F P
0 g
s
.63899 .70998 m .6736 .66506 L .63892 .71051 L .707 .577 .707 r
F
.63626 .73075 m .60588 .72534 L p .64102 .69462 L F P
0 g
s
.64646 .65627 m .6736 .66506 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .61016 .68901 L .64103 .69451 L p .707 .577 .707 r
F P
0 g
s
.60588 .72534 m .64103 .69451 L .64102 .69462 L .707 .577 .707 r
F
.63865 .71042 m .64192 .68776 L p .63899 .70998 L F P
0 g
s
.64192 .68776 m .64646 .65627 L p .63899 .70998 L .707 .577 .707 r
F P
0 g
s
.64103 .69451 m .64112 .69453 L p .64102 .69462 L .707 .577 .707 r
F P
0 g
s
.64112 .69453 m .63684 .73086 L .63626 .73075 L p .707 .577 .707 r
F P
0 g
s
.64102 .69462 m .64112 .69453 L .63626 .73075 L .707 .577 .707 r
F
.63892 .71051 m .63865 .71042 L p .63899 .70998 L F P
0 g
s
.64646 .65627 m .63865 .71042 L .60779 .70412 L p .707 .577 .707 r
F P
0 g
s
.60779 .70412 m .6156 .64997 L .64646 .65627 L p .707 .577 .707 r
F P
0 g
s
.61085 .80717 m .60783 .30496 L .57387 .31306 L p .707 .577 .707 r
F P
0 g
s
.50627 .83617 m .50802 .8548 L .51085 .86197 L p .707 .577 .707 r
F P
0 g
s
.25061 .70228 m .25841 .64813 L .22756 .64183 L p .707 .577 .707 r
F P
0 g
s
.25841 .64813 m .25061 .70228 L .28216 .70547 L p .707 .577 .707 r
F P
0 g
s
.28216 .70547 m .28997 .65132 L .25841 .64813 L p .707 .577 .707 r
F P
0 g
s
.68657 .72963 m .68994 .70624 L p .70674 .68651 L .707 .577 .707 r
F P
0 g
s
.69438 .67548 m .68657 .72963 L .6658 .71921 L p .707 .577 .707 r
F P
0 g
s
.68923 .71227 m .68495 .74859 L .68321 .74778 L p .707 .577 .707 r
F P
0 g
s
.68321 .74778 m .66409 .73887 L p .68891 .71261 L .707 .577 .707 r
F P
0 g
s
.68891 .71261 m .68923 .71227 L .68321 .74778 L .707 .577 .707 r
F
.68994 .70624 m .69438 .67548 L .69486 .67591 L p F P
0 g
s
.69486 .67591 m .70674 .68651 L p .68994 .70624 L .707 .577 .707 r
F P
0 g
s
.28997 .65132 m .28216 .70547 L .31132 .70524 L p .707 .577 .707 r
F P
0 g
s
.31132 .70524 m .31913 .65109 L .28997 .65132 L p .707 .577 .707 r
F P
0 g
s
.7093 .82139 m .71105 .84001 L .70822 .83285 L p .707 .577 .707 r
F P
0 g
s
.70822 .83285 m .70647 .81422 L .7093 .82139 L p .707 .577 .707 r
F P
0 g
s
.21975 .69598 m .22756 .64183 L .20041 .63304 L p .707 .577 .707 r
F P
0 g
s
.22756 .64183 m .21975 .69598 L .25061 .70228 L p .707 .577 .707 r
F P
0 g
s
.4077 .81322 m .40468 .31102 L .37496 .30215 L p .707 .577 .707 r
F P
0 g
s
.40468 .31102 m .4077 .81322 L .44647 .81915 L p .707 .577 .707 r
F P
0 g
s
.68495 .74859 m .68923 .71227 L .70167 .72274 L p .707 .577 .707 r
F P
0 g
s
.31913 .65109 m .31132 .70524 L .33523 .70161 L p .707 .577 .707 r
F P
0 g
s
.33523 .70161 m .34304 .64746 L .31913 .65109 L p .707 .577 .707 r
F P
0 g
s
.19261 .68719 m .20041 .63304 L .17964 .62262 L p .707 .577 .707 r
F P
0 g
s
.20041 .63304 m .19261 .68719 L .21975 .69598 L p .707 .577 .707 r
F P
0 g
s
.50802 .8548 m .50627 .83617 L .51338 .82828 L p .707 .577 .707 r
F P
0 g
s
.61645 .82304 m .6147 .80442 L .64574 .80333 L p .707 .577 .707 r
F P
0 g
s
.6147 .80442 m .61645 .82304 L .58474 .82652 L p .707 .577 .707 r
F P
0 g
s
.60783 .30496 m .61085 .80717 L .63396 .79672 L p .707 .577 .707 r
F P
0 g
s
.63396 .79672 m .63094 .29452 L .60783 .30496 L p .707 .577 .707 r
F P
0 g
s
.51338 .82828 m .51513 .84691 L .50802 .8548 L p .707 .577 .707 r
F P
0 g
s
.6658 .71921 m .66912 .69616 L p .69438 .67548 L .707 .577 .707 r
F P
0 g
s
.66837 .70254 m .66409 .73887 L .66261 .73844 L p .707 .577 .707 r
F P
0 g
s
.66261 .73844 m .63684 .73086 L p .6681 .70278 L .707 .577 .707 r
F P
0 g
s
.6681 .70278 m .66837 .70254 L .66261 .73844 L .707 .577 .707 r
F
.66912 .69616 m .6736 .66506 L .67389 .6652 L p F P
0 g
s
.67389 .6652 m .69438 .67548 L p .66912 .69616 L .707 .577 .707 r
F P
0 g
s
.25961 .79015 m .25787 .77153 L .22683 .77262 L p .707 .577 .707 r
F P
0 g
s
.25787 .77153 m .25961 .79015 L .29132 .78667 L p .707 .577 .707 r
F P
0 g
s
.29132 .78667 m .28957 .76805 L .25787 .77153 L p .707 .577 .707 r
F P
0 g
s
.22683 .77262 m .22858 .79124 L .25961 .79015 L p .707 .577 .707 r
F P
0 g
s
.2489 .80173 m .25318 .7654 L .22222 .75988 L p .707 .577 .707 r
F P
0 g
s
.25318 .7654 m .2489 .80173 L .28055 .80422 L p .707 .577 .707 r
F P
0 g
s
.28055 .80422 m .28483 .76789 L .25318 .7654 L p .707 .577 .707 r
F P
0 g
s
.70647 .81422 m .70822 .83285 L .69573 .82711 L p .707 .577 .707 r
F P
0 g
s
.69573 .82711 m .69398 .80848 L .70647 .81422 L p .707 .577 .707 r
F P
0 g
s
.28957 .76805 m .29132 .78667 L .3206 .78115 L p .707 .577 .707 r
F P
0 g
s
.3206 .78115 m .31886 .76253 L .28957 .76805 L p .707 .577 .707 r
F P
0 g
s
.34304 .64746 m .33523 .70161 L .35155 .69494 L p .707 .577 .707 r
F P
0 g
s
.35155 .69494 m .35936 .64079 L .34304 .64746 L p .707 .577 .707 r
F P
0 g
s
.17964 .62262 m .17183 .67677 L .19261 .68719 L p .707 .577 .707 r
F P
0 g
s
.28483 .76789 m .28055 .80422 L .30978 .80343 L p .707 .577 .707 r
F P
0 g
s
.30978 .80343 m .31406 .7671 L .28483 .76789 L p .707 .577 .707 r
F P
0 g
s
.37798 .80435 m .37496 .30215 L .35718 .29121 L p .707 .577 .707 r
F P
0 g
s
.37496 .30215 m .37798 .80435 L .4077 .81322 L p .707 .577 .707 r
F P
0 g
s
.66409 .73887 m .66837 .70254 L .68923 .71227 L p .707 .577 .707 r
F P
0 g
s
.21794 .7962 m .22222 .75988 L .19497 .75186 L p .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22683 .77262 L .22401 .77247 L p .707 .577 .707 r
F P
0 g
s
.22222 .75988 m .21794 .7962 L .22391 .79727 L p .707 .577 .707 r
F P
0 g
s
.22405 .76274 m .22222 .75988 L .22391 .79727 L .707 .577 .707 r
F
.19497 .75186 m .19069 .78819 L .21794 .7962 L p F P
0 g
s
.22401 .77247 m .19952 .77122 L p .22394 .78805 L .707 .577 .707 r
F P
0 g
s
.22858 .79124 m .22401 .77247 L .22394 .78805 L .707 .577 .707 r
F
.19952 .77122 m .20127 .78984 L .22858 .79124 L p F P
0 g
s
.22391 .79727 m .2489 .80173 L p .22405 .76274 L .707 .577 .707 r
F P
0 g
s
.17183 .67677 m .17964 .62262 L .16727 .61159 L p .707 .577 .707 r
F P
0 g
s
.31886 .76253 m .3206 .78115 L .34459 .77413 L p .707 .577 .707 r
F P
0 g
s
.34459 .77413 m .34284 .7555 L .31886 .76253 L p .707 .577 .707 r
F P
0 g
s
.31406 .7671 m .30978 .80343 L .33373 .79945 L p .707 .577 .707 r
F P
0 g
s
.33373 .79945 m .33801 .76312 L .31406 .7671 L p .707 .577 .707 r
F P
0 g
s
.51513 .84691 m .51338 .82828 L .52973 .82044 L p .707 .577 .707 r
F P
0 g
s
.19069 .78819 m .19497 .75186 L .17411 .74214 L p .707 .577 .707 r
F P
0 g
s
.52973 .82044 m .53147 .83907 L .51513 .84691 L p .707 .577 .707 r
F P
0 g
s
.17411 .74214 m .16983 .77847 L .19069 .78819 L p .707 .577 .707 r
F P
0 g
s
.20127 .78984 m .19952 .77122 L .17859 .76746 L p .707 .577 .707 r
F P
0 g
s
.16727 .61159 m .15946 .66574 L .17183 .67677 L p .707 .577 .707 r
F P
0 g
s
.63684 .73086 m .64112 .69453 L .66837 .70254 L p .707 .577 .707 r
F P
0 g
s
.63094 .29452 m .63396 .79672 L .64396 .78496 L p .707 .577 .707 r
F P
0 g
s
.64396 .78496 m .64094 .28275 L .63094 .29452 L p .707 .577 .707 r
F P
0 g
s
.17859 .76746 m .18034 .78609 L .20127 .78984 L p .707 .577 .707 r
F P
0 g
s
.35936 .64079 m .35155 .69494 L .35868 .68588 L p .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .36607 .6346 L p .35936 .64079 L .707 .577 .707 r
F P
0 g
s
.34284 .7555 m .34459 .77413 L .36094 .76629 L p .707 .577 .707 r
F P
0 g
s
.36094 .76629 m .35919 .74766 L .34284 .7555 L p .707 .577 .707 r
F P
0 g
s
.36619 .6321 m .35936 .64079 L p .36607 .6346 L .707 .577 .707 r
F P
0 g
s
.35868 .68588 m .35593 .67531 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .36649 .63173 L .36619 .6321 L p .707 .577 .707 r
F P
0 g
s
.36649 .63173 m .36607 .6346 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36607 .6346 m .35868 .68588 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .35309 .27927 L p .35762 .60687 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36649 .63173 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .36317 .62508 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .36373 .62116 L p .36592 .63408 L .707 .577 .707 r
F P
0 g
s
.35919 .74766 m .36094 .76629 L .3672 .75933 L p .707 .577 .707 r
F P
0 g
s
.3672 .75933 m .36804 .7584 L p .36714 .75729 L .707 .577 .707 r
F P
0 g
s
.36714 .75729 m .35919 .74766 L .3672 .75933 L .707 .577 .707 r
F
.36804 .7584 m .3663 .73977 L .35919 .74766 L p F P
0 g
s
.35435 .75633 m .35007 .79265 L .35718 .78372 L p .707 .577 .707 r
F P
0 g
s
.35718 .78372 m .36146 .74739 L .35435 .75633 L p .707 .577 .707 r
F P
0 g
s
.35593 .67531 m .34356 .66428 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36373 .62116 m .36317 .62508 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.36317 .62508 m .35593 .67531 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .35137 .61013 L .36301 .62052 L p .707 .577 .707 r
F P
0 g
s
.36301 .62052 m .36373 .62116 L p .36308 .62256 L .707 .577 .707 r
F P
0 g
s
.34356 .66428 m .36301 .62052 L .36308 .62256 L .707 .577 .707 r
F
.3533 .31385 m .35351 .34894 L p .35378 .3294 L F P
0 g
s
.36146 .74739 m .35718 .78372 L .35438 .77351 L p .707 .577 .707 r
F P
0 g
s
.35438 .77351 m .35866 .73718 L .36146 .74739 L p .707 .577 .707 r
F P
0 g
s
.35007 .79265 m .35435 .75633 L .33801 .76312 L p .707 .577 .707 r
F P
0 g
s
.35866 .73718 m .35438 .77351 L .34271 .76367 L p .707 .577 .707 r
F P
0 g
s
.34271 .76367 m .34194 .76303 L p .34276 .76177 L .707 .577 .707 r
F P
0 g
s
.34276 .76177 m .35866 .73718 L .34271 .76367 L .707 .577 .707 r
F
.34194 .76303 m .34622 .7267 L .35866 .73718 L p F P
0 g
s
.3559 .74695 m .35272 .74549 L p .35587 .74171 L .707 .577 .707 r
F P
0 g
s
.35587 .74171 m .36346 .7326 L .3559 .74695 L .707 .577 .707 r
F
.36346 .7326 m .36521 .75123 L .3559 .74695 L p F P
0 g
s
.35272 .74549 m .35097 .72686 L .36346 .7326 L p .707 .577 .707 r
F P
0 g
s
.35351 .34894 m .35611 .78148 L p .35395 .36149 L .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .3602 .79341 L p .35441 .37466 L .707 .577 .707 r
F P
0 g
s
.35441 .37466 m .35378 .3294 L .35395 .36149 L .707 .577 .707 r
F
.35441 .37466 m .35395 .36149 L .35611 .78148 L F
.35911 .61174 m .35718 .29121 L p .35897 .6113 L F P
0 g
s
.35985 .7679 m .35897 .6113 L .35762 .60687 L .707 .577 .707 r
F
.35897 .6113 m .35718 .29121 L .35762 .60687 L F
.3663 .73977 m .36804 .7584 L .36521 .75123 L p F P
0 g
s
.36521 .75123 m .36346 .7326 L .3663 .73977 L p .707 .577 .707 r
F P
0 g
s
.35718 .29121 m .3602 .79341 L .37798 .80435 L p .707 .577 .707 r
F P
0 g
s
.35611 .78148 m .35363 .36867 L p .36309 .26751 L .707 .577 .707 r
F P
0 g
s
.35378 .3294 m .35351 .34894 L .35395 .36149 L .707 .577 .707 r
F
.35309 .27927 m .3533 .31385 L p .35378 .3294 L F P
0 g
s
.35363 .36867 m .35309 .27927 L .3562 .27561 L p .707 .577 .707 r
F P
0 g
s
.3562 .27561 m .36309 .26751 L p .35363 .36867 L .707 .577 .707 r
F P
0 g
s
.36002 .76412 m .35911 .61174 L p .35985 .7679 L .707 .577 .707 r
F P
0 g
s
.35911 .61174 m .35897 .6113 L .35985 .7679 L .707 .577 .707 r
F
.3602 .79341 m .36002 .76412 L p .35985 .7679 L F P
0 g
s
.69398 .80848 m .69573 .82711 L .6748 .82335 L p .707 .577 .707 r
F P
0 g
s
.6748 .82335 m .67305 .80472 L .69398 .80848 L p .707 .577 .707 r
F P
0 g
s
.15946 .66574 m .16727 .61159 L .16451 .60103 L p .707 .577 .707 r
F P
0 g
s
.33801 .76312 m .33373 .79945 L .35007 .79265 L p .707 .577 .707 r
F P
0 g
s
.16983 .77847 m .17411 .74214 L .16167 .73166 L p .707 .577 .707 r
F P
0 g
s
.16167 .73166 m .15739 .76799 L .16983 .77847 L p .707 .577 .707 r
F P
0 g
s
.18034 .78609 m .17859 .76746 L .1661 .76172 L p .707 .577 .707 r
F P
0 g
s
.1661 .76172 m .16784 .78035 L .18034 .78609 L p .707 .577 .707 r
F P
0 g
s
.16451 .60103 m .15671 .65518 L .15946 .66574 L p .707 .577 .707 r
F P
0 g
s
.67305 .80472 m .6748 .82335 L .64748 .82195 L p .707 .577 .707 r
F P
0 g
s
.64748 .82195 m .64574 .80333 L .67305 .80472 L p .707 .577 .707 r
F P
0 g
s
.15671 .65518 m .16451 .60103 L .17165 .59196 L p .707 .577 .707 r
F P
0 g
s
.64094 .28275 m .64396 .78496 L .63987 .77302 L p .707 .577 .707 r
F P
0 g
s
.63987 .77302 m .63685 .27082 L .64094 .28275 L p .707 .577 .707 r
F P
0 g
s
.15739 .76799 m .16167 .73166 L .15887 .72146 L p .707 .577 .707 r
F P
0 g
s
.64574 .80333 m .64748 .82195 L .61645 .82304 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16784 .78035 m .1661 .76172 L .16326 .75456 L p .707 .577 .707 r
F P
0 g
s
.16326 .75456 m .16501 .77318 L .16784 .78035 L p .707 .577 .707 r
F P
0 g
s
.15887 .72146 m .15459 .75778 L .15739 .76799 L p .707 .577 .707 r
F P
0 g
s
.17165 .59196 m .16384 .64612 L .15671 .65518 L p .707 .577 .707 r
F P
0 g
s
.16384 .64612 m .17165 .59196 L .18797 .58529 L p .707 .577 .707 r
F P
0 g
s
.15459 .75778 m .15887 .72146 L .16598 .71252 L p .707 .577 .707 r
F P
0 g
s
.16501 .77318 m .16326 .75456 L .17037 .74667 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17037 .74667 m .17212 .76529 L .16501 .77318 L p .707 .577 .707 r
F P
0 g
s
.16598 .71252 m .1617 .74885 L .15459 .75778 L p .707 .577 .707 r
F P
0 g
s
.18797 .58529 m .18016 .63945 L .16384 .64612 L p .707 .577 .707 r
F P
0 g
s
.63685 .27082 m .63987 .77302 L .6221 .76208 L p .707 .577 .707 r
F P
0 g
s
.6221 .76208 m .61908 .25988 L .63685 .27082 L p .707 .577 .707 r
F P
0 g
s
.35137 .61013 m .34356 .66428 L .32279 .65386 L p .707 .577 .707 r
F P
0 g
s
.32279 .65386 m .33059 .59971 L .35137 .61013 L p .707 .577 .707 r
F P
0 g
s
.18016 .63945 m .18797 .58529 L .21188 .58166 L p .707 .577 .707 r
F P
0 g
s
.1617 .74885 m .16598 .71252 L .18232 .70572 L p .707 .577 .707 r
F P
0 g
s
.36611 .76971 m .36309 .26751 L .3862 .25706 L p .707 .577 .707 r
F P
0 g
s
.36309 .26751 m .36611 .76971 L .35611 .78148 L p .707 .577 .707 r
F P
0 g
s
.17212 .76529 m .17037 .74667 L .18672 .73882 L p .707 .577 .707 r
F P
0 g
s
.33059 .59971 m .32279 .65386 L .29564 .64507 L p .707 .577 .707 r
F P
0 g
s
.29564 .64507 m .30345 .59092 L .33059 .59971 L p .707 .577 .707 r
F P
0 g
s
.21188 .58166 m .20407 .63582 L .18016 .63945 L p .707 .577 .707 r
F P
0 g
s
.20407 .63582 m .21188 .58166 L .24103 .58143 L p .707 .577 .707 r
F P
0 g
s
.18232 .70572 m .17804 .74205 L .1617 .74885 L p .707 .577 .707 r
F P
0 g
s
.18672 .73882 m .18846 .75745 L .17212 .76529 L p .707 .577 .707 r
F P
0 g
s
.34622 .7267 m .34194 .76303 L .32108 .75331 L p .707 .577 .707 r
F P
0 g
s
.32108 .75331 m .32536 .71698 L .34622 .7267 L p .707 .577 .707 r
F P
0 g
s
.35097 .72686 m .35272 .74549 L .33179 .74173 L p .707 .577 .707 r
F P
0 g
s
.33179 .74173 m .33004 .72311 L .35097 .72686 L p .707 .577 .707 r
F P
0 g
s
.61908 .25988 m .6221 .76208 L .59237 .75321 L p .707 .577 .707 r
F P
0 g
s
.59237 .75321 m .58935 .25101 L .61908 .25988 L p .707 .577 .707 r
F P
0 g
s
.30345 .59092 m .29564 .64507 L .26478 .63877 L p .707 .577 .707 r
F P
0 g
s
.26478 .63877 m .27259 .58462 L .30345 .59092 L p .707 .577 .707 r
F P
0 g
s
.23323 .63559 m .24103 .58143 L .27259 .58462 L p .707 .577 .707 r
F P
0 g
s
.24103 .58143 m .23323 .63559 L .20407 .63582 L p .707 .577 .707 r
F P
0 g
s
.17804 .74205 m .18232 .70572 L .20627 .70174 L p .707 .577 .707 r
F P
0 g
s
.27259 .58462 m .26478 .63877 L .23323 .63559 L p .707 .577 .707 r
F P
0 g
s
.18846 .75745 m .18672 .73882 L .2107 .7318 L p .707 .577 .707 r
F P
0 g
s
.3862 .25706 m .38922 .75927 L .36611 .76971 L p .707 .577 .707 r
F P
0 g
s
.38922 .75927 m .3862 .25706 L .42016 .24896 L p .707 .577 .707 r
F P
0 g
s
.2107 .7318 m .21245 .75042 L .18846 .75745 L p .707 .577 .707 r
F P
0 g
s
.20627 .70174 m .20199 .73807 L .17804 .74205 L p .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73339 .65892 L .73314 .65888 L p .707 .577 .707 r
F P
0 g
s
.73314 .65888 m .70243 .6534 L p .72773 .69309 L .707 .577 .707 r
F P
0 g
s
.72911 .69525 m .73314 .65888 L .72773 .69309 L .707 .577 .707 r
F
.73339 .65892 m .72911 .69525 L .76076 .69774 L p F P
0 g
s
.76076 .69774 m .76504 .66141 L .76466 .66138 L p .707 .577 .707 r
F P
0 g
s
.76466 .66138 m .73339 .65892 L p .75862 .69471 L .707 .577 .707 r
F P
0 g
s
.76076 .69774 m .76466 .66138 L .75862 .69471 L .707 .577 .707 r
F
.76504 .66141 m .76076 .69774 L .78999 .69696 L p F P
0 g
s
.78999 .69696 m .79427 .66063 L .79385 .66064 L p .707 .577 .707 r
F P
0 g
s
.79385 .66064 m .76504 .66141 L p .78759 .69354 L .707 .577 .707 r
F P
0 g
s
.78999 .69696 m .79385 .66064 L .78759 .69354 L .707 .577 .707 r
F
.79427 .66063 m .78999 .69696 L .81395 .69297 L p F P
0 g
s
.81395 .69297 m .81823 .65664 L .81786 .65671 L p .707 .577 .707 r
F P
0 g
s
.81786 .65671 m .79427 .66063 L p .81188 .68957 L .707 .577 .707 r
F P
0 g
s
.81395 .69297 m .81786 .65671 L .81188 .68957 L .707 .577 .707 r
F
.81823 .65664 m .81395 .69297 L .83028 .68618 L p F P
0 g
s
.83028 .68618 m .83456 .64985 L .83431 .64995 L p .707 .577 .707 r
F P
0 g
s
.83431 .64995 m .81823 .65664 L p .82902 .68308 L .707 .577 .707 r
F P
0 g
s
.83028 .68618 m .83431 .64995 L .82902 .68308 L .707 .577 .707 r
F
.83456 .64985 m .83028 .68618 L .8374 .67724 L p F P
0 g
s
.8374 .67724 m .84168 .64091 L .84158 .64104 L p .707 .577 .707 r
F P
0 g
s
.84158 .64104 m .83456 .64985 L p .83713 .67462 L .707 .577 .707 r
F P
0 g
s
.8374 .67724 m .84158 .64104 L .83713 .67462 L .707 .577 .707 r
F
.83177 .66825 m .8389 .65919 L p .83952 .61739 L F P
0 g
s
.8389 .65919 m .84233 .63534 L p .83957 .61409 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8467 .60503 L .84616 .60572 L p .707 .577 .707 r
F P
0 g
s
.84616 .60572 m .83957 .61409 L p .84233 .63534 L .707 .577 .707 r
F P
0 g
s
.84168 .64091 m .8374 .67724 L .83707 .67606 L p .707 .577 .707 r
F P
0 g
s
.8389 .65919 m .83615 .64862 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.84233 .63534 m .8389 .65919 L p .84593 .60822 L .707 .577 .707 r
F P
0 g
s
.83707 .67606 m .8346 .66703 L p .84156 .64136 L .707 .577 .707 r
F P
0 g
s
.84156 .64136 m .84168 .64091 L .83707 .67606 L .707 .577 .707 r
F
.8467 .60503 m .84233 .63534 L p .84593 .60822 L F P
0 g
s
.83957 .61409 m .83521 .64434 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.83521 .64434 m .83177 .66825 L p .83952 .61739 L .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .83177 .66825 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.82325 .62077 m .81888 .65107 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.81888 .65107 m .81545 .67492 L p .82382 .62394 L .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .81545 .67492 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79934 .62439 m .79495 .65488 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.79495 .65488 m .79154 .67855 L p .80022 .62716 L .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .79154 .67855 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.77018 .62463 m .76575 .65539 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.76575 .65539 m .76238 .67878 L p .77096 .6266 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .76238 .67878 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73863 .62144 m .73414 .65254 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73414 .65254 m .73082 .67559 L p .73894 .6222 L .707 .577 .707 r
F P
0 g
s
.73082 .67559 m .73863 .62144 L .70777 .61514 L p .707 .577 .707 r
F P
0 g
s
.76238 .67878 m .77018 .62463 L .73863 .62144 L p .707 .577 .707 r
F P
0 g
s
.32536 .71698 m .32108 .75331 L .29908 .74684 L p .707 .577 .707 r
F P
0 g
s
.29919 .74052 m .27344 .74143 L p .29948 .72389 L .707 .577 .707 r
F P
0 g
s
.29908 .74684 m .29383 .74529 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29919 .74048 m .32536 .71698 L .29908 .74684 L .707 .577 .707 r
F
.27344 .74143 m .27169 .7228 L .29951 .72182 L p F P
0 g
s
.27344 .74143 m .29951 .72182 L .29948 .72389 L .707 .577 .707 r
F
.29383 .74529 m .29811 .70897 L .29973 .70944 L p F P
0 g
s
.29973 .70944 m .32536 .71698 L p .29919 .74048 L .707 .577 .707 r
F P
0 g
s
.29383 .74529 m .29973 .70944 L .29919 .74048 L .707 .577 .707 r
F
.29951 .72182 m .30273 .72171 L p .29948 .72389 L F P
0 g
s
.30273 .72171 m .30447 .74033 L .29919 .74052 L p .707 .577 .707 r
F P
0 g
s
.29948 .72389 m .30273 .72171 L .29919 .74052 L .707 .577 .707 r
F
.33004 .72311 m .33179 .74173 L .30447 .74033 L p F P
0 g
s
.30447 .74033 m .30273 .72171 L .33004 .72311 L p .707 .577 .707 r
F P
0 g
s
.79154 .67855 m .79934 .62439 L .77018 .62463 L p .707 .577 .707 r
F P
0 g
s
.69996 .66929 m .70777 .61514 L .68062 .60635 L p .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70243 .6534 L .70235 .65338 L p .707 .577 .707 r
F P
0 g
s
.70323 .64663 m .69996 .66929 L .70027 .66935 L p .707 .577 .707 r
F P
0 g
s
.68062 .60635 m .67282 .6605 L .69996 .66929 L p .707 .577 .707 r
F P
0 g
s
.70235 .65338 m .67519 .64539 L p .69773 .68891 L .707 .577 .707 r
F P
0 g
s
.69815 .68973 m .70235 .65338 L .69773 .68891 L .707 .577 .707 r
F
.70777 .61514 m .70323 .64663 L p .73082 .67559 L F P
0 g
s
.70243 .6534 m .69815 .68973 L .72911 .69525 L p .707 .577 .707 r
F P
0 g
s
.70027 .66935 m .73082 .67559 L p .70323 .64663 L .707 .577 .707 r
F P
0 g
s
.20199 .73807 m .20627 .70174 L .23551 .70095 L p .707 .577 .707 r
F P
0 g
s
.21245 .75042 m .2107 .7318 L .23999 .72628 L p .707 .577 .707 r
F P
0 g
s
.58935 .25101 m .59237 .75321 L .55361 .74728 L p .707 .577 .707 r
F P
0 g
s
.55361 .74728 m .55059 .24508 L .58935 .25101 L p .707 .577 .707 r
F P
0 g
s
.81545 .67492 m .82325 .62077 L .79934 .62439 L p .707 .577 .707 r
F P
0 g
s
.27169 .7228 m .27344 .74143 L .24173 .7449 L p .707 .577 .707 r
F P
0 g
s
.29811 .70897 m .29383 .74529 L .26287 .73977 L p .707 .577 .707 r
F P
0 g
s
.24173 .7449 m .23999 .72628 L .27169 .7228 L p .707 .577 .707 r
F P
0 g
s
.26287 .73977 m .26715 .70344 L .29811 .70897 L p .707 .577 .707 r
F P
0 g
s
.23999 .72628 m .24173 .7449 L .21245 .75042 L p .707 .577 .707 r
F P
0 g
s
.23551 .70095 m .23123 .73728 L .20199 .73807 L p .707 .577 .707 r
F P
0 g
s
.23123 .73728 m .23551 .70095 L .26715 .70344 L p .707 .577 .707 r
F P
0 g
s
.67282 .6605 m .68062 .60635 L .65985 .59593 L p .707 .577 .707 r
F P
0 g
s
.26715 .70344 m .26287 .73977 L .23123 .73728 L p .707 .577 .707 r
F P
0 g
s
.42318 .75117 m .42016 .24896 L .46164 .244 L p .707 .577 .707 r
F P
0 g
s
.42016 .24896 m .42318 .75117 L .38922 .75927 L p .707 .577 .707 r
F P
0 g
s
.67519 .64539 m .67091 .68172 L .69815 .68973 L p .707 .577 .707 r
F P
0 g
s
.65985 .59593 m .65205 .65008 L .67282 .6605 L p .707 .577 .707 r
F P
0 g
s
.67091 .68172 m .67519 .64539 L .65432 .63566 L p .707 .577 .707 r
F P
0 g
s
.55059 .24508 m .55361 .74728 L .5096 .74487 L p .707 .577 .707 r
F P
0 g
s
.5096 .74487 m .50658 .24266 L .55059 .24508 L p .707 .577 .707 r
F P
0 g
s
.83177 .66825 m .83957 .61409 L .82325 .62077 L p .707 .577 .707 r
F P
0 g
s
.73983 .77973 m .73808 .76111 L .70705 .7622 L p .707 .577 .707 r
F P
0 g
s
.73808 .76111 m .73983 .77973 L .77154 .77625 L p .707 .577 .707 r
F P
0 g
s
.77154 .77625 m .76979 .75763 L .73808 .76111 L p .707 .577 .707 r
F P
0 g
s
.76979 .75763 m .77154 .77625 L .80082 .77073 L p .707 .577 .707 r
F P
0 g
s
.80082 .77073 m .79907 .75211 L .76979 .75763 L p .707 .577 .707 r
F P
0 g
s
.65205 .65008 m .65985 .59593 L .64748 .5849 L p .707 .577 .707 r
F P
0 g
s
.46466 .74621 m .46164 .244 L .50658 .24266 L p .707 .577 .707 r
F P
0 g
s
.46164 .244 m .46466 .74621 L .42318 .75117 L p .707 .577 .707 r
F P
0 g
s
.70705 .7622 m .7088 .78082 L .73983 .77973 L p .707 .577 .707 r
F P
0 g
s
.65432 .63566 m .65004 .67199 L .67091 .68172 L p .707 .577 .707 r
F P
0 g
s
.50658 .24266 m .5096 .74487 L .46466 .74621 L p .707 .577 .707 r
F P
0 g
s
.7088 .78082 m .70705 .7622 L .67973 .7608 L p .707 .577 .707 r
F P
0 g
s
.67973 .7608 m .68148 .77942 L .7088 .78082 L p .707 .577 .707 r
F P
0 g
s
.79907 .75211 m .80082 .77073 L .82481 .76371 L p .707 .577 .707 r
F P
0 g
s
.82481 .76371 m .82306 .74508 L .79907 .75211 L p .707 .577 .707 r
F P
0 g
s
.64748 .5849 m .63968 .63905 L .65205 .65008 L p .707 .577 .707 r
F P
0 g
s
.65004 .67199 m .65432 .63566 L .64188 .62519 L p .707 .577 .707 r
F P
0 g
s
.68148 .77942 m .67973 .7608 L .6588 .75704 L p .707 .577 .707 r
F P
0 g
s
.64188 .62519 m .6376 .66152 L .65004 .67199 L p .707 .577 .707 r
F P
0 g
s
.6588 .75704 m .66055 .77567 L .68148 .77942 L p .707 .577 .707 r
F P
0 g
s
.63968 .63905 m .64748 .5849 L .64473 .57433 L p .707 .577 .707 r
F P
0 g
s
.82306 .74508 m .82481 .76371 L .84115 .75587 L p .707 .577 .707 r
F P
0 g
s
.84115 .75587 m .8394 .73724 L .82306 .74508 L p .707 .577 .707 r
F P
0 g
s
.64473 .57433 m .63692 .62849 L .63968 .63905 L p .707 .577 .707 r
F P
0 g
s
.6376 .66152 m .64188 .62519 L .63908 .61498 L p .707 .577 .707 r
F P
0 g
s
.66055 .77567 m .6588 .75704 L .64631 .7513 L p .707 .577 .707 r
F P
0 g
s
.64631 .7513 m .64806 .76993 L .66055 .77567 L p .707 .577 .707 r
F P
0 g
s
.83615 .64862 m .83956 .62495 L p .8467 .60503 L .707 .577 .707 r
F P
0 g
s
.84395 .59447 m .83615 .64862 L .82378 .63759 L p .707 .577 .707 r
F P
0 g
s
.83888 .6307 m .8346 .66703 L .8333 .66594 L p .707 .577 .707 r
F P
0 g
s
.8333 .66594 m .82216 .65656 L p .83862 .63111 L .707 .577 .707 r
F P
0 g
s
.83862 .63111 m .83888 .6307 L .8333 .66594 L .707 .577 .707 r
F
.83956 .62495 m .84395 .59447 L .84412 .59511 L p F P
0 g
s
.84412 .59511 m .8467 .60503 L p .83956 .62495 L .707 .577 .707 r
F P
0 g
s
.63908 .61498 m .6348 .65131 L .6376 .66152 L p .707 .577 .707 r
F P
0 g
s
.8394 .73724 m .84115 .75587 L .84826 .74797 L p .707 .577 .707 r
F P
0 g
s
.84826 .74797 m .84651 .72935 L .8394 .73724 L p .707 .577 .707 r
F P
0 g
s
.6348 .65131 m .63908 .61498 L .6462 .60604 L p .707 .577 .707 r
F P
0 g
s
.63692 .62849 m .64473 .57433 L .65186 .56527 L p .707 .577 .707 r
F P
0 g
s
.8346 .66703 m .83888 .6307 L .84168 .64091 L p .707 .577 .707 r
F P
0 g
s
.64806 .76993 m .64631 .7513 L .64348 .74414 L p .707 .577 .707 r
F P
0 g
s
.6462 .60604 m .64192 .64237 L .6348 .65131 L p .707 .577 .707 r
F P
0 g
s
.65186 .56527 m .64406 .61943 L .63692 .62849 L p .707 .577 .707 r
F P
0 g
s
.64348 .74414 m .64523 .76276 L .64806 .76993 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38781 .61024 m .39562 .55609 L .36476 .54979 L p .707 .577 .707 r
F P
0 g
s
.39562 .55609 m .38781 .61024 L .41937 .61343 L p .707 .577 .707 r
F P
0 g
s
.41937 .61343 m .42717 .55928 L .39562 .55609 L p .707 .577 .707 r
F P
0 g
s
.82378 .63759 m .82715 .6142 L p .84395 .59447 L .707 .577 .707 r
F P
0 g
s
.83158 .58344 m .82378 .63759 L .803 .62717 L p .707 .577 .707 r
F P
0 g
s
.82644 .62023 m .82216 .65656 L .82041 .65574 L p .707 .577 .707 r
F P
0 g
s
.82041 .65574 m .80129 .64683 L p .82611 .62057 L .707 .577 .707 r
F P
0 g
s
.82611 .62057 m .82644 .62023 L .82041 .65574 L .707 .577 .707 r
F
.82715 .6142 m .83158 .58344 L .83207 .58387 L p F P
0 g
s
.83207 .58387 m .84395 .59447 L p .82715 .6142 L .707 .577 .707 r
F P
0 g
s
.42717 .55928 m .41937 .61343 L .44853 .6132 L p .707 .577 .707 r
F P
0 g
s
.44853 .6132 m .45633 .55905 L .42717 .55928 L p .707 .577 .707 r
F P
0 g
s
.64192 .64237 m .6462 .60604 L .66253 .59925 L p .707 .577 .707 r
F P
0 g
s
.64406 .61943 m .65186 .56527 L .66818 .5586 L p .707 .577 .707 r
F P
0 g
s
.84651 .72935 m .84826 .74797 L .84543 .74081 L p .707 .577 .707 r
F P
0 g
s
.84543 .74081 m .84368 .72218 L .84651 .72935 L p .707 .577 .707 r
F P
0 g
s
.35695 .60394 m .36476 .54979 L .33761 .541 L p .707 .577 .707 r
F P
0 g
s
.36476 .54979 m .35695 .60394 L .38781 .61024 L p .707 .577 .707 r
F P
0 g
s
.82216 .65656 m .82644 .62023 L .83888 .6307 L p .707 .577 .707 r
F P
0 g
s
.45633 .55905 m .44853 .6132 L .47244 .60957 L p .707 .577 .707 r
F P
0 g
s
.47244 .60957 m .48024 .55542 L .45633 .55905 L p .707 .577 .707 r
F P
0 g
s
.32981 .59515 m .33761 .541 L .31684 .53058 L p .707 .577 .707 r
F P
0 g
s
.33761 .541 m .32981 .59515 L .35695 .60394 L p .707 .577 .707 r
F P
0 g
s
.64523 .76276 m .64348 .74414 L .65058 .73625 L p .707 .577 .707 r
F P
0 g
s
.66253 .59925 m .65825 .63558 L .64192 .64237 L p .707 .577 .707 r
F P
0 g
s
.66818 .5586 m .66038 .61275 L .64406 .61943 L p .707 .577 .707 r
F P
0 g
s
.65058 .73625 m .65233 .75487 L .64523 .76276 L p .707 .577 .707 r
F P
0 g
s
.803 .62717 m .80632 .60413 L p .83158 .58344 L .707 .577 .707 r
F P
0 g
s
.81081 .57302 m .803 .62717 L .77613 .61847 L p .707 .577 .707 r
F P
0 g
s
.77346 .63872 m .74308 .6333 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77613 .61847 m .77586 .61838 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.7762 .61794 m .81081 .57302 L .77613 .61847 L .707 .577 .707 r
F
.78366 .56423 m .81081 .57302 L p .7762 .61794 L F P
0 g
s
.74308 .6333 m .74736 .59697 L .77823 .60247 L p .707 .577 .707 r
F P
0 g
s
.74308 .6333 m .77823 .60247 L .77822 .60258 L .707 .577 .707 r
F
.77586 .61838 m .77912 .59572 L p .7762 .61794 L F P
0 g
s
.77912 .59572 m .78366 .56423 L p .7762 .61794 L .707 .577 .707 r
F P
0 g
s
.77823 .60247 m .77833 .60249 L p .77822 .60258 L .707 .577 .707 r
F P
0 g
s
.77833 .60249 m .77405 .63882 L .77346 .63872 L p .707 .577 .707 r
F P
0 g
s
.77822 .60258 m .77833 .60249 L .77346 .63872 L .707 .577 .707 r
F
.80557 .61051 m .80129 .64683 L .79982 .6464 L p F P
0 g
s
.79982 .6464 m .77405 .63882 L p .80531 .61075 L .707 .577 .707 r
F P
0 g
s
.80531 .61075 m .80557 .61051 L .79982 .6464 L .707 .577 .707 r
F
.80632 .60413 m .81081 .57302 L .81109 .57316 L p F P
0 g
s
.81109 .57316 m .83158 .58344 L p .80632 .60413 L .707 .577 .707 r
F P
0 g
s
.65825 .63558 m .66253 .59925 L .68649 .59526 L p .707 .577 .707 r
F P
0 g
s
.66038 .61275 m .66818 .5586 L .69209 .55497 L p .707 .577 .707 r
F P
0 g
s
.39682 .69811 m .39507 .67949 L .36404 .68058 L p .707 .577 .707 r
F P
0 g
s
.39507 .67949 m .39682 .69811 L .42853 .69464 L p .707 .577 .707 r
F P
0 g
s
.42853 .69464 m .42678 .67601 L .39507 .67949 L p .707 .577 .707 r
F P
0 g
s
.36404 .68058 m .36579 .69921 L .39682 .69811 L p .707 .577 .707 r
F P
0 g
s
.3861 .70969 m .39038 .67336 L .35942 .66784 L p .707 .577 .707 r
F P
0 g
s
.39038 .67336 m .3861 .70969 L .41775 .71218 L p .707 .577 .707 r
F P
0 g
s
.41775 .71218 m .42203 .67585 L .39038 .67336 L p .707 .577 .707 r
F P
0 g
s
.84368 .72218 m .84543 .74081 L .83293 .73507 L p .707 .577 .707 r
F P
0 g
s
.83293 .73507 m .83119 .71644 L .84368 .72218 L p .707 .577 .707 r
F P
0 g
s
.42678 .67601 m .42853 .69464 L .45781 .68911 L p .707 .577 .707 r
F P
0 g
s
.45781 .68911 m .45606 .67049 L .42678 .67601 L p .707 .577 .707 r
F P
0 g
s
.48024 .55542 m .47244 .60957 L .48876 .6029 L p .707 .577 .707 r
F P
0 g
s
.48876 .6029 m .49656 .54875 L .48024 .55542 L p .707 .577 .707 r
F P
0 g
s
.31684 .53058 m .30904 .58473 L .32981 .59515 L p .707 .577 .707 r
F P
0 g
s
.42203 .67585 m .41775 .71218 L .44698 .71139 L p .707 .577 .707 r
F P
0 g
s
.44698 .71139 m .45126 .67507 L .42203 .67585 L p .707 .577 .707 r
F P
0 g
s
.80129 .64683 m .80557 .61051 L .82644 .62023 L p .707 .577 .707 r
F P
0 g
s
.35514 .70417 m .35942 .66784 L .33218 .65982 L p .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36404 .68058 L .36121 .68043 L p .707 .577 .707 r
F P
0 g
s
.35942 .66784 m .35514 .70417 L .36111 .70523 L p .707 .577 .707 r
F P
0 g
s
.36125 .6707 m .35942 .66784 L .36111 .70523 L .707 .577 .707 r
F
.33218 .65982 m .3279 .69615 L .35514 .70417 L p F P
0 g
s
.36121 .68043 m .33672 .67918 L p .36115 .69601 L .707 .577 .707 r
F P
0 g
s
.36579 .69921 m .36121 .68043 L .36115 .69601 L .707 .577 .707 r
F
.33672 .67918 m .33847 .69781 L .36579 .69921 L p F P
0 g
s
.36111 .70523 m .3861 .70969 L p .36125 .6707 L .707 .577 .707 r
F P
0 g
s
.30904 .58473 m .31684 .53058 L .30447 .51955 L p .707 .577 .707 r
F P
0 g
s
.45606 .67049 m .45781 .68911 L .4818 .68209 L p .707 .577 .707 r
F P
0 g
s
.4818 .68209 m .48005 .66346 L .45606 .67049 L p .707 .577 .707 r
F P
0 g
s
.68649 .59526 m .68221 .63159 L .65825 .63558 L p .707 .577 .707 r
F P
0 g
s
.69209 .55497 m .68429 .60913 L .66038 .61275 L p .707 .577 .707 r
F P
0 g
s
.45126 .67507 m .44698 .71139 L .47094 .70741 L p .707 .577 .707 r
F P
0 g
s
.47094 .70741 m .47522 .67108 L .45126 .67507 L p .707 .577 .707 r
F P
0 g
s
.68221 .63159 m .68649 .59526 L .71572 .59448 L p .707 .577 .707 r
F P
0 g
s
.68429 .60913 m .69209 .55497 L .72125 .55474 L p .707 .577 .707 r
F P
0 g
s
.65233 .75487 m .65058 .73625 L .66693 .7284 L p .707 .577 .707 r
F P
0 g
s
.3279 .69615 m .33218 .65982 L .31131 .6501 L p .707 .577 .707 r
F P
0 g
s
.66693 .7284 m .66868 .74703 L .65233 .75487 L p .707 .577 .707 r
F P
0 g
s
.31131 .6501 m .30703 .68643 L .3279 .69615 L p .707 .577 .707 r
F P
0 g
s
.33847 .69781 m .33672 .67918 L .31579 .67543 L p .707 .577 .707 r
F P
0 g
s
.30447 .51955 m .29667 .5737 L .30904 .58473 L p .707 .577 .707 r
F P
0 g
s
.77405 .63882 m .77833 .60249 L .80557 .61051 L p .707 .577 .707 r
F P
0 g
s
.31579 .67543 m .31754 .69405 L .33847 .69781 L p .707 .577 .707 r
F P
0 g
s
.74736 .59697 m .74308 .6333 L .71144 .63081 L p .707 .577 .707 r
F P
0 g
s
.78366 .56423 m .77586 .61838 L .745 .61208 L p .707 .577 .707 r
F P
0 g
s
.71144 .63081 m .71572 .59448 L .74736 .59697 L p .707 .577 .707 r
F P
0 g
s
.745 .61208 m .7528 .55793 L .78366 .56423 L p .707 .577 .707 r
F P
0 g
s
.49656 .54875 m .48876 .6029 L .49589 .59384 L p .707 .577 .707 r
F P
0 g
s
.49589 .59384 m .50369 .53969 L .49656 .54875 L p .707 .577 .707 r
F P
0 g
s
.83119 .71644 m .83293 .73507 L .81201 .73131 L p .707 .577 .707 r
F P
0 g
s
.81201 .73131 m .81026 .71269 L .83119 .71644 L p .707 .577 .707 r
F P
0 g
s
.71572 .59448 m .71144 .63081 L .68221 .63159 L p .707 .577 .707 r
F P
0 g
s
.71344 .60889 m .72125 .55474 L .7528 .55793 L p .707 .577 .707 r
F P
0 g
s
.72125 .55474 m .71344 .60889 L .68429 .60913 L p .707 .577 .707 r
F P
0 g
s
.48005 .66346 m .4818 .68209 L .49814 .67425 L p .707 .577 .707 r
F P
0 g
s
.49814 .67425 m .49639 .65562 L .48005 .66346 L p .707 .577 .707 r
F P
0 g
s
.29667 .5737 m .30447 .51955 L .30172 .50899 L p .707 .577 .707 r
F P
0 g
s
.7528 .55793 m .745 .61208 L .71344 .60889 L p .707 .577 .707 r
F P
0 g
s
.47522 .67108 m .47094 .70741 L .48727 .70062 L p .707 .577 .707 r
F P
0 g
s
.48727 .70062 m .49155 .66429 L .47522 .67108 L p .707 .577 .707 r
F P
0 g
s
.30703 .68643 m .31131 .6501 L .29887 .63962 L p .707 .577 .707 r
F P
0 g
s
.66868 .74703 m .66693 .7284 L .69092 .72138 L p .707 .577 .707 r
F P
0 g
s
.29887 .63962 m .29459 .67595 L .30703 .68643 L p .707 .577 .707 r
F P
0 g
s
.31754 .69405 m .31579 .67543 L .3033 .66968 L p .707 .577 .707 r
F P
0 g
s
.69092 .72138 m .69267 .74 L .66868 .74703 L p .707 .577 .707 r
F P
0 g
s
.3033 .66968 m .30505 .68831 L .31754 .69405 L p .707 .577 .707 r
F P
0 g
s
.30172 .50899 m .29391 .56314 L .29667 .5737 L p .707 .577 .707 r
F P
0 g
s
.81026 .71269 m .81201 .73131 L .78469 .72991 L p .707 .577 .707 r
F P
0 g
s
.78469 .72991 m .78294 .71129 L .81026 .71269 L p .707 .577 .707 r
F P
0 g
s
.50369 .53969 m .49589 .59384 L .49314 .58327 L p .707 .577 .707 r
F P
0 g
s
.49314 .58327 m .50094 .52912 L .50369 .53969 L p .707 .577 .707 r
F P
0 g
s
.49639 .65562 m .49814 .67425 L .50525 .66636 L p .707 .577 .707 r
F P
0 g
s
.50525 .66636 m .5035 .64773 L .49639 .65562 L p .707 .577 .707 r
F P
0 g
s
.49155 .66429 m .48727 .70062 L .49439 .69168 L p .707 .577 .707 r
F P
0 g
s
.49439 .69168 m .49867 .65535 L .49155 .66429 L p .707 .577 .707 r
F P
0 g
s
.69267 .74 m .69092 .72138 L .7202 .71586 L p .707 .577 .707 r
F P
0 g
s
.29391 .56314 m .30172 .50899 L .30885 .49993 L p .707 .577 .707 r
F P
0 g
s
.7202 .71586 m .72195 .73448 L .69267 .74 L p .707 .577 .707 r
F P
0 g
s
.29459 .67595 m .29887 .63962 L .29607 .62942 L p .707 .577 .707 r
F P
0 g
s
.78294 .71129 m .78469 .72991 L .75366 .73101 L p .707 .577 .707 r
F P
0 g
s
.75366 .73101 m .75191 .71238 L .78294 .71129 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.72195 .73448 m .7202 .71586 L .75191 .71238 L p .707 .577 .707 r
F P
0 g
s
.30505 .68831 m .3033 .66968 L .30047 .66252 L p .707 .577 .707 r
F P
0 g
s
.75191 .71238 m .75366 .73101 L .72195 .73448 L p .707 .577 .707 r
F P
0 g
s
.30047 .66252 m .30222 .68114 L .30505 .68831 L p .707 .577 .707 r
F P
0 g
s
.29607 .62942 m .29179 .66575 L .29459 .67595 L p .707 .577 .707 r
F P
0 g
s
.30885 .49993 m .30105 .55408 L .29391 .56314 L p .707 .577 .707 r
F P
0 g
s
.50094 .52912 m .49314 .58327 L .48077 .57224 L p .707 .577 .707 r
F P
0 g
s
.48077 .57224 m .48857 .51809 L .50094 .52912 L p .707 .577 .707 r
F P
0 g
s
.5035 .64773 m .50525 .66636 L .50242 .65919 L p .707 .577 .707 r
F P
0 g
s
.50242 .65919 m .50067 .64056 L .5035 .64773 L p .707 .577 .707 r
F P
0 g
s
.49867 .65535 m .49439 .69168 L .49159 .68147 L p .707 .577 .707 r
F P
0 g
s
.49159 .68147 m .49587 .64514 L .49867 .65535 L p .707 .577 .707 r
F P
0 g
s
.30105 .55408 m .30885 .49993 L .32517 .49325 L p .707 .577 .707 r
F P
0 g
s
.29179 .66575 m .29607 .62942 L .30319 .62048 L p .707 .577 .707 r
F P
0 g
s
.30222 .68114 m .30047 .66252 L .30757 .65463 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30757 .65463 m .30932 .67325 L .30222 .68114 L p .707 .577 .707 r
F P
0 g
s
.30319 .62048 m .29891 .65681 L .29179 .66575 L p .707 .577 .707 r
F P
0 g
s
.32517 .49325 m .31737 .54741 L .30105 .55408 L p .707 .577 .707 r
F P
0 g
s
.48857 .51809 m .48077 .57224 L .45999 .56182 L p .707 .577 .707 r
F P
0 g
s
.45999 .56182 m .4678 .50767 L .48857 .51809 L p .707 .577 .707 r
F P
0 g
s
.31737 .54741 m .32517 .49325 L .34908 .48963 L p .707 .577 .707 r
F P
0 g
s
.49587 .64514 m .49159 .68147 L .47915 .67099 L p .707 .577 .707 r
F P
0 g
s
.47915 .67099 m .48343 .63466 L .49587 .64514 L p .707 .577 .707 r
F P
0 g
s
.50067 .64056 m .50242 .65919 L .48992 .65345 L p .707 .577 .707 r
F P
0 g
s
.48992 .65345 m .48818 .63482 L .50067 .64056 L p .707 .577 .707 r
F P
0 g
s
.29891 .65681 m .30319 .62048 L .31952 .61368 L p .707 .577 .707 r
F P
0 g
s
.30932 .67325 m .30757 .65463 L .32392 .64679 L p .707 .577 .707 r
F P
0 g
s
.4678 .50767 m .45999 .56182 L .43285 .55303 L p .707 .577 .707 r
F P
0 g
s
.43285 .55303 m .44065 .49888 L .4678 .50767 L p .707 .577 .707 r
F P
0 g
s
.34908 .48963 m .34128 .54378 L .31737 .54741 L p .707 .577 .707 r
F P
0 g
s
.34128 .54378 m .34908 .48963 L .37824 .48939 L p .707 .577 .707 r
F P
0 g
s
.31952 .61368 m .31524 .65001 L .29891 .65681 L p .707 .577 .707 r
F P
0 g
s
.32392 .64679 m .32567 .66541 L .30932 .67325 L p .707 .577 .707 r
F P
0 g
s
.48343 .63466 m .47915 .67099 L .45828 .66127 L p .707 .577 .707 r
F P
0 g
s
.45828 .66127 m .46256 .62494 L .48343 .63466 L p .707 .577 .707 r
F P
0 g
s
.48818 .63482 m .48992 .65345 L .469 .64969 L p .707 .577 .707 r
F P
0 g
s
.469 .64969 m .46725 .63107 L .48818 .63482 L p .707 .577 .707 r
F P
0 g
s
.44065 .49888 m .43285 .55303 L .40199 .54674 L p .707 .577 .707 r
F P
0 g
s
.40199 .54674 m .40979 .49258 L .44065 .49888 L p .707 .577 .707 r
F P
0 g
s
.37043 .54355 m .37824 .48939 L .40979 .49258 L p .707 .577 .707 r
F P
0 g
s
.37824 .48939 m .37043 .54355 L .34128 .54378 L p .707 .577 .707 r
F P
0 g
s
.31524 .65001 m .31952 .61368 L .34348 .6097 L p .707 .577 .707 r
F P
0 g
s
.40979 .49258 m .40199 .54674 L .37043 .54355 L p .707 .577 .707 r
F P
0 g
s
.32567 .66541 m .32392 .64679 L .34791 .63976 L p .707 .577 .707 r
F P
0 g
s
.34791 .63976 m .34966 .65839 L .32567 .66541 L p .707 .577 .707 r
F P
0 g
s
.34348 .6097 m .3392 .64603 L .31524 .65001 L p .707 .577 .707 r
F P
0 g
s
.46256 .62494 m .45828 .66127 L .43629 .6548 L p .707 .577 .707 r
F P
0 g
s
.4364 .64848 m .41065 .64939 L p .43668 .63186 L .707 .577 .707 r
F P
0 g
s
.43629 .6548 m .43104 .65326 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.4364 .64844 m .46256 .62494 L .43629 .6548 L .707 .577 .707 r
F
.41065 .64939 m .4089 .63076 L .43672 .62978 L p F P
0 g
s
.41065 .64939 m .43672 .62978 L .43668 .63186 L .707 .577 .707 r
F
.43104 .65326 m .43532 .61693 L .43693 .6174 L p F P
0 g
s
.43693 .6174 m .46256 .62494 L p .4364 .64844 L .707 .577 .707 r
F P
0 g
s
.43104 .65326 m .43693 .6174 L .4364 .64844 L .707 .577 .707 r
F
.43672 .62978 m .43993 .62967 L p .43668 .63186 L F P
0 g
s
.43993 .62967 m .44168 .64829 L .4364 .64848 L p .707 .577 .707 r
F P
0 g
s
.43668 .63186 m .43993 .62967 L .4364 .64848 L .707 .577 .707 r
F
.46725 .63107 m .469 .64969 L .44168 .64829 L p F P
0 g
s
.44168 .64829 m .43993 .62967 L .46725 .63107 L p .707 .577 .707 r
F P
0 g
s
.3392 .64603 m .34348 .6097 L .37271 .60891 L p .707 .577 .707 r
F P
0 g
s
.34966 .65839 m .34791 .63976 L .37719 .63424 L p .707 .577 .707 r
F P
0 g
s
.4089 .63076 m .41065 .64939 L .37894 .65286 L p .707 .577 .707 r
F P
0 g
s
.43532 .61693 m .43104 .65326 L .40007 .64773 L p .707 .577 .707 r
F P
0 g
s
.37894 .65286 m .37719 .63424 L .4089 .63076 L p .707 .577 .707 r
F P
0 g
s
.40007 .64773 m .40435 .6114 L .43532 .61693 L p .707 .577 .707 r
F P
0 g
s
.37719 .63424 m .37894 .65286 L .34966 .65839 L p .707 .577 .707 r
F P
0 g
s
.37271 .60891 m .36843 .64524 L .3392 .64603 L p .707 .577 .707 r
F P
0 g
s
.36843 .64524 m .37271 .60891 L .40435 .6114 L p .707 .577 .707 r
F P
0 g
s
.40435 .6114 m .40007 .64773 L .36843 .64524 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007Ao
o`00Kgoo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`00L7oo001]Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001]Ool006]oo`<000UJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH006Yoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol0061ooa0000MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00Fgoo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@002UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001IOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001VOol005Eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=J
EP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP8006Io
o`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005Eoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00E7oo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20003FUH500000eYF001JEP02FUH3
0002FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001J
EP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00@005YF001JEP<000EJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`04001JEP000002FUH00`00FUIJEP02
FUH00`00FUIJEP06FUH00`00FUIJEP050009FUH50005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
4000C7oo001COol30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP02FUH400000eYF001JEP05FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo10000eYF00<005YFFUH01UYF00@0
05YFFUIJEPL004Eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF3P001EYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01000@Goo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50006FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00UYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00Dgoo00<005YF
FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF
00@005YFFUIJEP800003FUH005YF00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00003000iOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH3000fOol005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P00=Goo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF0P002EYF0`00<Woo000iOol@000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00]JEP80
031oo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`0^Ool0039oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000Aoo`8000=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00Oomoo`0]Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009oo`800003FUH005YF00IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00Oomoo`0/Ool002moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEP0000H000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000goo000000020002FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=oo`D000IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo000^Ool2
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP020003Ool00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P0000=JEP0000000P000UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0:Woo
000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUHH0002FUH00`00FUIJEP05FUH01000FUIJEUYF1@0025YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00@005YFFUIJEQ0000AJEP03001J
EUYF00IJEP8000EJEP<000EJEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0>00000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH40003FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH20006FUH30004FUH01P00FUIJEP00FUH002aoo`00;Goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF
0080009JEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`000UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH2000]Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEP0000<002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP04001JEUYFFUH@0004
FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH010001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH500000eYF001JEP06FUH00`00FUIJEP04FUH8
0005FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000]Ool20003FUH50000
0eYF001JEP040009Ool70006FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEP001UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00P005YFFUIJEP00FUH005YF100015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH015YF1`001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;Goo000/
Ool01000FUH005YF0`001EYF00<005YFFUH00eYF1@002goo100000AJEP00FUH000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0007FUH00`00FUIJ
EP02FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EUYF001JEP800004FUH005YFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH400000eYF001JEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEP00
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool200000eYF001JEP02FUH0
1000FUIJEUYF400015YF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF00=JEP06001JEUYF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF009J
EP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEUYF009J
EP8002eoo`00;7oo0`000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH015YF1`001Goo
0P000eYF1@001EYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF00<005YF
FUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00=J
EP03001JEP0000<000]JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH01`00FUIJ
EUYF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
0`000eYF1`0000=JEP0000000P000UYF00<005YFFUH015YF00<005YFFUH015YF1P001UYF1@001eYF
00<005YFFUH00eYF10000UYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP8000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00H005YF000005YF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP040004FUH00`00FUIJEP07FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH0
1000FUIJEUYF1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEP03001JEUYF00iJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=J
EP03001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF1@001UYF0P000UYF0P0015YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00@005YFFUIJEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP0>FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002FUH2000^Ool002eoo`05001JEUYFFUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50006FUH2000015YF001JEP0015YF00<005YF0000
1@0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJEP05001JEUYF001J
EP04000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<0
05YFFUH03UYF0P0025YF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH2000^Ool0
02eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30006FUH20002FUH00`00
FUH00003FUH40005FUH200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH4000025YF
001JEUYF001JEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH00`00FUIJEP0>FUH00`00FUH000020004FUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH3000^Ool002ioo`03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP80009JEP04001JEP00FUH20003FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH300000eYF000000030002FUH01P00FUH00000FUH000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP02FUH017ooFUIJEUYF0P00
1UYF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01@00;Woo000_Ool20006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000EJEP03001J
EUYF00]JEPL000EJEP04001JEUYFFUH80003FUH01000FUH005YF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH010000UYF1P000eYF00<005YFFUH01EYF00@005YFFUIJEPH0009JEP<002ioo`00<7oo
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEP80
009JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJ
EP03001JEUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP<00003FUH005YF00AJEP03001JEP0000IJEPP000=JEP03001JEUYF009J
EPL000=JEP05001JEUYFOomJEP03000^Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00<0009JEP03001JEUYF00X0009JEP03001JEUYF00=JEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000IJEP03001JEUYF00IJ
EP03001JEP0000/000=JEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;goo000cOol200000eYF
001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP04
001JEP000004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P00<7oo000eOol30006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01@00FUIJEUYF000015YF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00006FUH01000FUIJEUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00035oo`00>7oo10000UYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH02UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000lOol50006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUH000020004FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<007oo0000200015YF00<005YFFUH01EYF00@005YFFUIJEPD003Aoo`00@Goo10000UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2@001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000@0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo00Qooa0003Uoo`00=goo5@0015YF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH30005FUH0
1P00FUIJEP00FUH005=oo`00<goo10000eYF00<005YFFUH01EYF00<005YFFUH00UYF5@001goo1`00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP<000AJEP06
001JEUYF001JEP00Dgoo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000>Ool01@00FUIJEP00FUH0200015YF00<005YFFUH01UYF00@005YFFUIJEP@000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF0080009JEP06001JEUYF001JEP00Dgoo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool01000FUIJEP001EYF00@005YF
FUIJEQ400003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF009JEP<0009JEP8000QooaP003Aoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
0P0027oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001J
EUYF00=JEP80009JEP80009oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
031oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00=JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF3@0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP@000EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJ
EP0400001Goo001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH0100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH002eoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP03001JEUYF00=JEP<0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP<000EJEP03001JEUYF00IJEP03
001JEUYF009JEQH000AJEP03001JEUYF008002aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000MJEP03001JEUYF009J
EP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000@0
0003FUH005YF00EJEP03001JEUYF00AJEPL001Ioo`<00003FUH005YF009JEP03001oogoo02Yoo`00
;7oo00<005YF00000eYF00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00@005YFFUH000MJEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000=JEP03001JEUYF00AJEP03001JEUYF00@0021oo`<0009JEP03001oogoo02Yoo`00;7oo0P00
15YF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF0000200015YF00<005YF00002`000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJEP03001J
EUYF009JEP@00003FUH007oo025oo`800003FUH00000008002]oo`00;7oo0P000UYF100000=JEP00
FUH01EYF00<005YFFUH015YF1P001Woo1@001eYF00<005YFFUH00eYF1@000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF00000P000eYF00<005YF00007goo
0`000eYF00@005YF000002]oo`00;7oo00=JEP0000000`000eYF00<005YFFUH015YF00<005YFFUH0
10004Goo0`0015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP04
001JEUYFFUH300000eYF00000003FUH00`00FUH0000LOol300000eYF001JEP04FUH00`00FUH0000[
Ool002]oo`80009JEP8000AJEP03001JEUYF00=JEP@001Qoo`<00003FUH005YF00AJEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUH0000015YF00<005YF0000
0UYF0P006Goo100015YF00<005YFFUH00eYF0P00;7oo000[Ool2000015YF001JEP0015YF00<005YF
00000`007goo0`0015YF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF
00@005YF001JEP8000EJEP80009JEP04001JEP00000EOol40002FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH00`00Oomoo`0[Ool002]oo`06001JEUYF001JEP000eYF10000eYF0`007Woo100000AJEP00
FUIJEP80009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP05001JEP00001JEP04
0002FUH00`00FUIJEP02FUH3000>Ool70006FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002]o
o`07001JEUYF001JEP00FUH00P000eYF00<005YFFUH015YF00<005YF00000P005Woo0`000eYF0`00
0UYF0P000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP04001JEP000002FUH00`00FUIJEP0H0004FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH3000`Ool002aoo`04001JEP00FUH20005FUH00`00FUIJEP09
FUH90009Ool400000eYF0000000300000eYF00000002FUH20002FUH01000FUH000001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF
FUIJEP80009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000bOol002aoo`04001JEP000002FUH3
0002FUH00`00FUIJEP0=FUH00`00FUIJEP02FUH?0005FUH00`00FUH000030002FUH200000eYF001J
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000dOol002eoo`<0009JEP03
001JEUYF00X000QJEP@000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH0000000<000EJEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD003Qoo`00;Woo0P000UYF00<0
05YFFUH00eYF00<005YFFUH035YF1@0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800005FUH005YF001JEP030003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000mOol002moo`05001JEUYFFUH00004FUH00`00
FUIJEP0<FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001JEP0015YF1`0015YF00<005YFFUH00UYF2@00
AWoo000`Ool200000eYF001JEP04FUH00`00FUIJEP0:FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01P00FUIJEUYF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEP00001J
EP001UYF00D005YF000007oo00T004moo`00<Woo10000eYF00<005YFFUH02UYF00<005YF00000P00
15YF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP@000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP06001JEUYF001JEP000eYF1@00Fgoo000eOol:0007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=oo`00FUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001P00H7oo000hOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P00Igoo000lOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH000001Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P00J7oo0013Ool80004
FUH00`00FUIJEP06FUH01000FUIJEUYF10002Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Yoo`00Bgoo4@00
3goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YF00004P00Fgoo001]Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05FUH00`00FUIJ
EP04001GOol006moo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00D000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<005Eo
o`00LWoo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0025YF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH005Aoo`00NGoo30001UYF00<005YF
FUH02UYF00<005YFFUH01P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH005Aoo`00QGoo5P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF20000eYF00<005YFFUH00eYF00<005YFFUH00P00Dgoo002COol200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90008Ool60003FUH01@00FUIJEUYF0000Dgoo002AOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH9000GOol50002FUH00`00Oomoo`1AOol0091oo`80
00EJEP03001JEUYF009JEPH002=oo`H0059oo`00Sgoo00<005YF00001EYF00<005YF00000P009goo
0P000UYF00@005YF0000059oo`00Sgoo00@005YFFUH000=JEP<002Qoo`8000AJEP04001JEUYF001B
Ool008moo`05001JEUYF001JEP02000XOol300000eYF001JEP04FUH2001COol008moo`03001JEUYF
008002Aoo`H000AJEP03001JEUYF00=JEP8005=oo`00T7oo0P0000=JEP0000000P0067oo2@0015YF
00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00T7oo0P000UYF00<005YFFUH0600015YF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000005Ioo`00T7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00F7oo
002@Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUH00003001KOol0095oo`800003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEPD005moo`00Tgoo10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00I7oo002GOol70004FUH00`00FUIJEP02FUH9001]
Ool009ioo`T007Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]48\[InvisibleSpace]"     "\
\[InvisibleSpace]12.883764565444826`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 48, "     ", 12.883764565444826, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72951 m .59613 .67393 L .56496 .67202 L p .707 .577 .707 r
F P
0 g
s
.59613 .67393 m .59613 .72951 L .62796 .72873 L p .707 .577 .707 r
F P
0 g
s
.62796 .72873 m .62796 .67315 L .59613 .67393 L p .707 .577 .707 r
F P
0 g
s
.62796 .67315 m .62796 .72873 L .65734 .72535 L p .707 .577 .707 r
F P
0 g
s
.65734 .72535 m .65734 .66977 L .62796 .67315 L p .707 .577 .707 r
F P
0 g
s
.56496 .72761 m .56496 .67202 L .5375 .66763 L p .707 .577 .707 r
F P
0 g
s
.56496 .67202 m .56496 .72761 L .59613 .72951 L p .707 .577 .707 r
F P
0 g
s
.65734 .66977 m .65734 .72535 L .6814 .7197 L p .707 .577 .707 r
F P
0 g
s
.6814 .7197 m .6814 .66412 L .65734 .66977 L p .707 .577 .707 r
F P
0 g
s
.5375 .66763 m .5375 .72321 L .56496 .72761 L p .707 .577 .707 r
F P
0 g
s
.5375 .72321 m .5375 .66763 L .51644 .66118 L p .707 .577 .707 r
F P
0 g
s
.59613 .81705 m .59613 .79852 L .56496 .79662 L p .707 .577 .707 r
F P
0 g
s
.59613 .79852 m .59613 .81705 L .62796 .81627 L p .707 .577 .707 r
F P
0 g
s
.62796 .81627 m .62796 .79774 L .59613 .79852 L p .707 .577 .707 r
F P
0 g
s
.6814 .66412 m .6814 .7197 L .69777 .71233 L p .707 .577 .707 r
F P
0 g
s
.69777 .71233 m .69777 .65675 L .6814 .66412 L p .707 .577 .707 r
F P
0 g
s
.62796 .79774 m .62796 .81627 L .65735 .81289 L p .707 .577 .707 r
F P
0 g
s
.65735 .81289 m .65735 .79436 L .62796 .79774 L p .707 .577 .707 r
F P
0 g
s
.59613 .84665 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84665 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.51644 .66118 m .51644 .71676 L .5375 .72321 L p .707 .577 .707 r
F P
0 g
s
.56496 .79662 m .56496 .81515 L .59613 .81705 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80544 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .81515 m .56496 .79662 L .5375 .79223 L p .707 .577 .707 r
F P
0 g
s
.56496 .84475 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84475 L .59613 .84665 L p .707 .577 .707 r
F P
0 g
s
.51644 .71676 m .51644 .66118 L .50385 .65329 L p .707 .577 .707 r
F P
0 g
s
.5375 .79223 m .5375 .81075 L .56496 .81515 L p .707 .577 .707 r
F P
0 g
s
.65735 .79436 m .65735 .81289 L .6814 .80724 L p .707 .577 .707 r
F P
0 g
s
.6814 .80724 m .6814 .78871 L .65735 .79436 L p .707 .577 .707 r
F P
0 g
s
.65735 .80544 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .79979 L .65735 .80544 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84475 L p .707 .577 .707 r
F P
0 g
s
.5375 .81075 m .5375 .79223 L .51644 .78577 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79685 L p .707 .577 .707 r
F P
0 g
s
.50385 .65329 m .50385 .70888 L .51644 .71676 L p .707 .577 .707 r
F P
0 g
s
.69777 .65675 m .69777 .71233 L .70485 .70397 L p .707 .577 .707 r
F P
0 g
s
.70485 .70397 m .70485 .64839 L .69777 .65675 L p .707 .577 .707 r
F P
0 g
s
.51644 .78577 m .51644 .8043 L .5375 .81075 L p .707 .577 .707 r
F P
0 g
s
.6814 .78871 m .6814 .80724 L .69777 .79987 L p .707 .577 .707 r
F P
0 g
s
.69777 .79987 m .69777 .78135 L .6814 .78871 L p .707 .577 .707 r
F P
0 g
s
.51644 .79685 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.6814 .79979 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .79979 L p .707 .577 .707 r
F P
0 g
s
.50385 .70888 m .50385 .65329 L .50095 .64475 L p .707 .577 .707 r
F P
0 g
s
.51644 .8043 m .51644 .78577 L .50385 .77789 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79685 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .77789 m .50385 .79642 L .51644 .8043 L p .707 .577 .707 r
F P
0 g
s
.50095 .64475 m .50095 .70033 L .50385 .70888 L p .707 .577 .707 r
F P
0 g
s
.70485 .64839 m .70485 .70397 L .70195 .69543 L p .707 .577 .707 r
F P
0 g
s
.70195 .69543 m .70195 .63985 L .70485 .64839 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82602 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.69777 .78135 m .69777 .79987 L .70485 .79151 L p .707 .577 .707 r
F P
0 g
s
.70485 .79151 m .70485 .77298 L .69777 .78135 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70033 m .50095 .64475 L .50804 .63639 L p .707 .577 .707 r
F P
0 g
s
.50385 .79642 m .50385 .77789 L .50095 .76935 L p .707 .577 .707 r
F P
0 g
s
.49044 .82844 m .49044 .32655 L .44643 .32387 L p .707 .577 .707 r
F P
0 g
s
.50385 .82602 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50095 .76935 m .50095 .78787 L .50385 .79642 L p .707 .577 .707 r
F P
0 g
s
.50804 .63639 m .50804 .69197 L .50095 .70033 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82602 L p .707 .577 .707 r
F P
0 g
s
.50804 .69197 m .50804 .63639 L .5244 .62902 L p .707 .577 .707 r
F P
0 g
s
.50095 .78787 m .50095 .76935 L .50804 .76098 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .76098 m .50804 .77951 L .50095 .78787 L p .707 .577 .707 r
F P
0 g
s
.5244 .62902 m .5244 .6846 L .50804 .69197 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.50804 .77951 m .50804 .76098 L .5244 .75361 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .76469 L p .707 .577 .707 r
F P
0 g
s
.5244 .75361 m .5244 .77214 L .50804 .77951 L p .707 .577 .707 r
F P
0 g
s
.5244 .76469 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.5244 .77214 m .5244 .75361 L .54846 .74797 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .76469 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.54846 .74797 m .54846 .76649 L .5244 .77214 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.49044 .32655 m .49044 .82844 L .53538 .82734 L p .707 .577 .707 r
F P
0 g
s
.5244 .6846 m .5244 .62902 L .54846 .62337 L p .707 .577 .707 r
F P
0 g
s
.54846 .62337 m .54846 .67895 L .5244 .6846 L p .707 .577 .707 r
F P
0 g
s
.53538 .82734 m .53538 .32545 L .49044 .32655 L p .707 .577 .707 r
F P
0 g
s
.54846 .67895 m .54846 .62337 L .57784 .61999 L p .707 .577 .707 r
F P
0 g
s
.57784 .61999 m .57784 .67557 L .54846 .67895 L p .707 .577 .707 r
F P
0 g
s
.54846 .76649 m .54846 .74797 L .57784 .74459 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .74459 m .57784 .76311 L .54846 .76649 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.53538 .32545 m .53538 .82734 L .57686 .82257 L p .707 .577 .707 r
F P
0 g
s
.57686 .82257 m .57686 .32068 L .53538 .32545 L p .707 .577 .707 r
F P
0 g
s
.44643 .82576 m .44643 .32387 L .40766 .31767 L p .707 .577 .707 r
F P
0 g
s
.44643 .32387 m .44643 .82576 L .49044 .82844 L p .707 .577 .707 r
F P
0 g
s
.70195 .63985 m .70195 .69543 L .68936 .68754 L p .707 .577 .707 r
F P
0 g
s
.68936 .68754 m .68936 .63196 L .70195 .63985 L p .707 .577 .707 r
F P
0 g
s
.70485 .77298 m .70485 .79151 L .70195 .78297 L p .707 .577 .707 r
F P
0 g
s
.70195 .78297 m .70195 .76444 L .70485 .77298 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81257 L p .707 .577 .707 r
F P
0 g
s
.70195 .81257 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.57784 .67557 m .57784 .61999 L .60968 .61921 L p .707 .577 .707 r
F P
0 g
s
.60968 .61921 m .60968 .6748 L .57784 .67557 L p .707 .577 .707 r
F P
0 g
s
.57784 .76311 m .57784 .74459 L .60968 .74381 L p .707 .577 .707 r
F P
0 g
s
.60968 .74381 m .60968 .76234 L .57784 .76311 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79194 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57686 .32068 m .57686 .82257 L .61082 .8146 L p .707 .577 .707 r
F P
0 g
s
.64085 .62111 m .64085 .6767 L .60968 .6748 L p .707 .577 .707 r
F P
0 g
s
.60968 .6748 m .60968 .61921 L .64085 .62111 L p .707 .577 .707 r
F P
0 g
s
.64085 .74571 m .64085 .76424 L .60968 .76234 L p .707 .577 .707 r
F P
0 g
s
.60968 .76234 m .60968 .74381 L .64085 .74571 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79384 L .60968 .79194 L p .707 .577 .707 r
F P
0 g
s
.60968 .79194 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.61082 .8146 m .61082 .31271 L .57686 .32068 L p .707 .577 .707 r
F P
0 g
s
.25312 .69269 m .25312 .63711 L .22195 .63521 L p .707 .577 .707 r
F P
0 g
s
.25312 .63711 m .25312 .69269 L .28495 .69192 L p .707 .577 .707 r
F P
0 g
s
.28495 .69192 m .28495 .63633 L .25312 .63711 L p .707 .577 .707 r
F P
0 g
s
.28495 .63633 m .28495 .69192 L .31434 .68854 L p .707 .577 .707 r
F P
0 g
s
.31434 .68854 m .31434 .63295 L .28495 .63633 L p .707 .577 .707 r
F P
0 g
s
.22195 .69079 m .22195 .63521 L .19449 .63082 L p .707 .577 .707 r
F P
0 g
s
.22195 .63521 m .22195 .69079 L .25312 .69269 L p .707 .577 .707 r
F P
0 g
s
.40766 .81956 m .40766 .31767 L .37794 .30856 L p .707 .577 .707 r
F P
0 g
s
.40766 .31767 m .40766 .81956 L .44643 .82576 L p .707 .577 .707 r
F P
0 g
s
.31434 .63295 m .31434 .68854 L .33839 .68289 L p .707 .577 .707 r
F P
0 g
s
.33839 .68289 m .33839 .6273 L .31434 .63295 L p .707 .577 .707 r
F P
0 g
s
.68936 .63196 m .68936 .68754 L .66831 .68109 L p .707 .577 .707 r
F P
0 g
s
.66831 .68109 m .66831 .62551 L .68936 .63196 L p .707 .577 .707 r
F P
0 g
s
.19449 .63082 m .19449 .6864 L .22195 .69079 L p .707 .577 .707 r
F P
0 g
s
.19449 .6864 m .19449 .63082 L .17343 .62436 L p .707 .577 .707 r
F P
0 g
s
.70195 .76444 m .70195 .78297 L .68936 .77508 L p .707 .577 .707 r
F P
0 g
s
.68936 .77508 m .68936 .75656 L .70195 .76444 L p .707 .577 .707 r
F P
0 g
s
.61082 .31271 m .61082 .8146 L .63393 .8042 L p .707 .577 .707 r
F P
0 g
s
.63393 .8042 m .63393 .30231 L .61082 .31271 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81257 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.25312 .78023 m .25312 .7617 L .22195 .7598 L p .707 .577 .707 r
F P
0 g
s
.25312 .7617 m .25312 .78023 L .28495 .77946 L p .707 .577 .707 r
F P
0 g
s
.28495 .77946 m .28495 .76093 L .25312 .7617 L p .707 .577 .707 r
F P
0 g
s
.33839 .6273 m .33839 .68289 L .35476 .67552 L p .707 .577 .707 r
F P
0 g
s
.35476 .67552 m .35476 .61994 L .33839 .6273 L p .707 .577 .707 r
F P
0 g
s
.28495 .76093 m .28495 .77946 L .31434 .77608 L p .707 .577 .707 r
F P
0 g
s
.31434 .77608 m .31434 .75755 L .28495 .76093 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77278 L .22195 .77088 L p .707 .577 .707 r
F P
0 g
s
.25312 .77278 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77278 L p .707 .577 .707 r
F P
0 g
s
.17343 .62436 m .17343 .67995 L .19449 .6864 L p .707 .577 .707 r
F P
0 g
s
.22195 .7598 m .22195 .77833 L .25312 .78023 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80568 L p .707 .577 .707 r
F P
0 g
s
.31434 .80568 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.37794 .81044 m .37794 .30856 L .36016 .29743 L p .707 .577 .707 r
F P
0 g
s
.37794 .30856 m .37794 .81044 L .40766 .81956 L p .707 .577 .707 r
F P
0 g
s
.22195 .77833 m .22195 .7598 L .19449 .75541 L p .707 .577 .707 r
F P
0 g
s
.66831 .62551 m .66831 .68109 L .64085 .6767 L p .707 .577 .707 r
F P
0 g
s
.64085 .6767 m .64085 .62111 L .66831 .62551 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77088 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77088 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.17343 .67995 m .17343 .62436 L .16084 .61648 L p .707 .577 .707 r
F P
0 g
s
.19449 .75541 m .19449 .77394 L .22195 .77833 L p .707 .577 .707 r
F P
0 g
s
.31434 .75755 m .31434 .77608 L .33839 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .77043 m .33839 .7519 L .31434 .75755 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80568 L .33839 .80003 L p .707 .577 .707 r
F P
0 g
s
.33839 .80003 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.68936 .75656 m .68936 .77508 L .66831 .76863 L p .707 .577 .707 r
F P
0 g
s
.66831 .76863 m .66831 .7501 L .68936 .75656 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .77394 m .19449 .75541 L .17343 .74896 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.16084 .61648 m .16084 .67206 L .17343 .67995 L p .707 .577 .707 r
F P
0 g
s
.35476 .61994 m .35476 .67552 L .36184 .66715 L p .707 .577 .707 r
F P
0 g
s
.36184 .66715 m .36184 .61157 L .35476 .61994 L p .707 .577 .707 r
F P
0 g
s
.17343 .74896 m .17343 .76749 L .19449 .77394 L p .707 .577 .707 r
F P
0 g
s
.66831 .7501 m .66831 .76863 L .64085 .76424 L p .707 .577 .707 r
F P
0 g
s
.64085 .76424 m .64085 .74571 L .66831 .7501 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79384 L p .707 .577 .707 r
F P
0 g
s
.64085 .79384 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.63393 .30231 m .63393 .8042 L .64393 .79239 L p .707 .577 .707 r
F P
0 g
s
.64393 .79239 m .64393 .2905 L .63393 .30231 L p .707 .577 .707 r
F P
0 g
s
.33839 .7519 m .33839 .77043 L .35476 .76306 L p .707 .577 .707 r
F P
0 g
s
.35476 .76306 m .35476 .74453 L .33839 .7519 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80003 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.16084 .67206 m .16084 .61648 L .15794 .60794 L p .707 .577 .707 r
F P
0 g
s
.17343 .76749 m .17343 .74896 L .16084 .74107 L p .707 .577 .707 r
F P
0 g
s
.36184 .61157 m .36184 .66715 L .35894 .65861 L p .707 .577 .707 r
F P
0 g
s
.35894 .65861 m .35894 .60303 L .36184 .61157 L p .707 .577 .707 r
F P
0 g
s
.35476 .74453 m .35476 .76306 L .36184 .75469 L p .707 .577 .707 r
F P
0 g
s
.36184 .75469 m .36184 .73617 L .35476 .74453 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.35894 .60303 m .35894 .65861 L .34635 .65073 L p .707 .577 .707 r
F P
0 g
s
.34635 .65073 m .34635 .59515 L .35894 .60303 L p .707 .577 .707 r
F P
0 g
s
.36184 .73617 m .36184 .75469 L .35894 .74615 L p .707 .577 .707 r
F P
0 g
s
.35894 .74615 m .35894 .72762 L .36184 .73617 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .7387 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.36016 .79931 m .36016 .29743 L .35607 .28537 L p .707 .577 .707 r
F P
0 g
s
.36016 .29743 m .36016 .79931 L .37794 .81044 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75215 L p .707 .577 .707 r
F P
0 g
s
.16084 .74107 m .16084 .7596 L .17343 .76749 L p .707 .577 .707 r
F P
0 g
s
.15794 .60794 m .15794 .66352 L .16084 .67206 L p .707 .577 .707 r
F P
0 g
s
.16084 .75215 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.15794 .66352 m .15794 .60794 L .16503 .59957 L p .707 .577 .707 r
F P
0 g
s
.64393 .2905 m .64393 .79239 L .63984 .78033 L p .707 .577 .707 r
F P
0 g
s
.63984 .78033 m .63984 .27844 L .64393 .2905 L p .707 .577 .707 r
F P
0 g
s
.16084 .7596 m .16084 .74107 L .15794 .73253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16084 .78921 m .16084 .75215 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.15794 .73253 m .15794 .75106 L .16084 .7596 L p .707 .577 .707 r
F P
0 g
s
.16503 .59957 m .16503 .65515 L .15794 .66352 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.35894 .72762 m .35894 .74615 L .34635 .73827 L p .707 .577 .707 r
F P
0 g
s
.34635 .73827 m .34635 .71974 L .35894 .72762 L p .707 .577 .707 r
F P
0 g
s
.35894 .7387 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .7387 L p .707 .577 .707 r
F P
0 g
s
.35607 .28537 m .35607 .78725 L .36016 .79931 L p .707 .577 .707 r
F P
0 g
s
.35607 .78725 m .35607 .28537 L .36607 .27356 L p .707 .577 .707 r
F P
0 g
s
.16503 .65515 m .16503 .59957 L .1814 .5922 L p .707 .577 .707 r
F P
0 g
s
.15794 .75106 m .15794 .73253 L .16503 .72417 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .72417 m .16503 .74269 L .15794 .75106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27844 m .63984 .78033 L .62206 .7692 L p .707 .577 .707 r
F P
0 g
s
.62206 .7692 m .62206 .26731 L .63984 .27844 L p .707 .577 .707 r
F P
0 g
s
.1814 .5922 m .1814 .64779 L .16503 .65515 L p .707 .577 .707 r
F P
0 g
s
.34635 .59515 m .34635 .65073 L .3253 .64427 L p .707 .577 .707 r
F P
0 g
s
.3253 .64427 m .3253 .58869 L .34635 .59515 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .64779 m .1814 .5922 L .20545 .58655 L p .707 .577 .707 r
F P
0 g
s
.36607 .77545 m .36607 .27356 L .38918 .26316 L p .707 .577 .707 r
F P
0 g
s
.36607 .27356 m .36607 .77545 L .35607 .78725 L p .707 .577 .707 r
F P
0 g
s
.16503 .74269 m .16503 .72417 L .1814 .7168 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.3253 .58869 m .3253 .64427 L .29784 .63988 L p .707 .577 .707 r
F P
0 g
s
.29784 .63988 m .29784 .5843 L .3253 .58869 L p .707 .577 .707 r
F P
0 g
s
.1814 .7168 m .1814 .73533 L .16503 .74269 L p .707 .577 .707 r
F P
0 g
s
.20545 .58655 m .20545 .64214 L .1814 .64779 L p .707 .577 .707 r
F P
0 g
s
.20545 .64214 m .20545 .58655 L .23483 .58318 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76493 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.34635 .71974 m .34635 .73827 L .3253 .73181 L p .707 .577 .707 r
F P
0 g
s
.3253 .73181 m .3253 .71329 L .34635 .71974 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.62206 .26731 m .62206 .7692 L .59233 .76008 L p .707 .577 .707 r
F P
0 g
s
.59233 .76008 m .59233 .2582 L .62206 .26731 L p .707 .577 .707 r
F P
0 g
s
.29784 .5843 m .29784 .63988 L .26667 .63798 L p .707 .577 .707 r
F P
0 g
s
.26667 .63798 m .26667 .5824 L .29784 .5843 L p .707 .577 .707 r
F P
0 g
s
.23483 .63876 m .23483 .58318 L .26667 .5824 L p .707 .577 .707 r
F P
0 g
s
.23483 .58318 m .23483 .63876 L .20545 .64214 L p .707 .577 .707 r
F P
0 g
s
.1814 .73533 m .1814 .7168 L .20545 .71115 L p .707 .577 .707 r
F P
0 g
s
.26667 .5824 m .26667 .63798 L .23483 .63876 L p .707 .577 .707 r
F P
0 g
s
.73333 .63747 m .73333 .58189 L .70216 .57999 L p .707 .577 .707 r
F P
0 g
s
.73333 .58189 m .73333 .63747 L .76517 .63669 L p .707 .577 .707 r
F P
0 g
s
.76517 .63669 m .76517 .58111 L .73333 .58189 L p .707 .577 .707 r
F P
0 g
s
.1814 .76493 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.76517 .58111 m .76517 .63669 L .79455 .63331 L p .707 .577 .707 r
F P
0 g
s
.79455 .63331 m .79455 .57773 L .76517 .58111 L p .707 .577 .707 r
F P
0 g
s
.20545 .71115 m .20545 .72968 L .1814 .73533 L p .707 .577 .707 r
F P
0 g
s
.38918 .26316 m .38918 .76504 L .36607 .77545 L p .707 .577 .707 r
F P
0 g
s
.38918 .76504 m .38918 .26316 L .42314 .25518 L p .707 .577 .707 r
F P
0 g
s
.70216 .63557 m .70216 .57999 L .6747 .57559 L p .707 .577 .707 r
F P
0 g
s
.70216 .57999 m .70216 .63557 L .73333 .63747 L p .707 .577 .707 r
F P
0 g
s
.3253 .71329 m .3253 .73181 L .29784 .72742 L p .707 .577 .707 r
F P
0 g
s
.29784 .72742 m .29784 .70889 L .3253 .71329 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75928 L .1814 .76493 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71997 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.79455 .57773 m .79455 .63331 L .8186 .62766 L p .707 .577 .707 r
F P
0 g
s
.8186 .62766 m .8186 .57208 L .79455 .57773 L p .707 .577 .707 r
F P
0 g
s
.20545 .72968 m .20545 .71115 L .23483 .70777 L p .707 .577 .707 r
F P
0 g
s
.20545 .75928 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.6747 .57559 m .6747 .63118 L .70216 .63557 L p .707 .577 .707 r
F P
0 g
s
.6747 .63118 m .6747 .57559 L .65365 .56914 L p .707 .577 .707 r
F P
0 g
s
.23483 .70777 m .23483 .7263 L .20545 .72968 L p .707 .577 .707 r
F P
0 g
s
.59233 .2582 m .59233 .76008 L .55357 .75388 L p .707 .577 .707 r
F P
0 g
s
.55357 .75388 m .55357 .25199 L .59233 .2582 L p .707 .577 .707 r
F P
0 g
s
.29784 .70889 m .29784 .72742 L .26667 .72552 L p .707 .577 .707 r
F P
0 g
s
.26667 .72552 m .26667 .70699 L .29784 .70889 L p .707 .577 .707 r
F P
0 g
s
.29784 .71997 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71807 L .29784 .71997 L p .707 .577 .707 r
F P
0 g
s
.23483 .7263 m .23483 .70777 L .26667 .70699 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75928 L p .707 .577 .707 r
F P
0 g
s
.26667 .70699 m .26667 .72552 L .23483 .7263 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71807 L p .707 .577 .707 r
F P
0 g
s
.73333 .72501 m .73333 .70648 L .70216 .70458 L p .707 .577 .707 r
F P
0 g
s
.73333 .70648 m .73333 .72501 L .76517 .72423 L p .707 .577 .707 r
F P
0 g
s
.76517 .72423 m .76517 .7057 L .73333 .70648 L p .707 .577 .707 r
F P
0 g
s
.42314 .75707 m .42314 .25518 L .46462 .25041 L p .707 .577 .707 r
F P
0 g
s
.42314 .25518 m .42314 .75707 L .38918 .76504 L p .707 .577 .707 r
F P
0 g
s
.8186 .57208 m .8186 .62766 L .83497 .6203 L p .707 .577 .707 r
F P
0 g
s
.83497 .6203 m .83497 .56471 L .8186 .57208 L p .707 .577 .707 r
F P
0 g
s
.26667 .71807 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.76517 .7057 m .76517 .72423 L .79455 .72085 L p .707 .577 .707 r
F P
0 g
s
.79455 .72085 m .79455 .70233 L .76517 .7057 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71678 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.65365 .56914 m .65365 .62472 L .6747 .63118 L p .707 .577 .707 r
F P
0 g
s
.70216 .70458 m .70216 .72311 L .73333 .72501 L p .707 .577 .707 r
F P
0 g
s
.76517 .71678 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71678 L p .707 .577 .707 r
F P
0 g
s
.70216 .72311 m .70216 .70458 L .6747 .70019 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.65365 .62472 m .65365 .56914 L .64105 .56126 L p .707 .577 .707 r
F P
0 g
s
.55357 .25199 m .55357 .75388 L .50956 .7512 L p .707 .577 .707 r
F P
0 g
s
.50956 .7512 m .50956 .24931 L .55357 .25199 L p .707 .577 .707 r
F P
0 g
s
.6747 .70019 m .6747 .71872 L .70216 .72311 L p .707 .577 .707 r
F P
0 g
s
.79455 .70233 m .79455 .72085 L .8186 .7152 L p .707 .577 .707 r
F P
0 g
s
.8186 .7152 m .8186 .69668 L .79455 .70233 L p .707 .577 .707 r
F P
0 g
s
.46462 .7523 m .46462 .25041 L .50956 .24931 L p .707 .577 .707 r
F P
0 g
s
.46462 .25041 m .46462 .7523 L .42314 .75707 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74832 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.50956 .24931 m .50956 .7512 L .46462 .7523 L p .707 .577 .707 r
F P
0 g
s
.6747 .71872 m .6747 .70019 L .65365 .69374 L p .707 .577 .707 r
F P
0 g
s
.6747 .74832 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.64105 .56126 m .64105 .61684 L .65365 .62472 L p .707 .577 .707 r
F P
0 g
s
.83497 .56471 m .83497 .6203 L .84205 .61193 L p .707 .577 .707 r
F P
0 g
s
.84205 .61193 m .84205 .55635 L .83497 .56471 L p .707 .577 .707 r
F P
0 g
s
.65365 .69374 m .65365 .71226 L .6747 .71872 L p .707 .577 .707 r
F P
0 g
s
.8186 .69668 m .8186 .7152 L .83497 .70784 L p .707 .577 .707 r
F P
0 g
s
.83497 .70784 m .83497 .68931 L .8186 .69668 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74832 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73744 L p .707 .577 .707 r
F P
0 g
s
.83497 .73744 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.64105 .61684 m .64105 .56126 L .63816 .55271 L p .707 .577 .707 r
F P
0 g
s
.65365 .71226 m .65365 .69374 L .64105 .68585 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .68585 m .64105 .70438 L .65365 .71226 L p .707 .577 .707 r
F P
0 g
s
.63816 .55271 m .63816 .6083 L .64105 .61684 L p .707 .577 .707 r
F P
0 g
s
.84205 .55635 m .84205 .61193 L .83916 .60339 L p .707 .577 .707 r
F P
0 g
s
.83916 .60339 m .83916 .54781 L .84205 .55635 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.83497 .68931 m .83497 .70784 L .84206 .69947 L p .707 .577 .707 r
F P
0 g
s
.84206 .69947 m .84206 .68094 L .83497 .68931 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73744 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69202 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .6083 m .63816 .55271 L .64524 .54435 L p .707 .577 .707 r
F P
0 g
s
.64105 .70438 m .64105 .68585 L .63816 .67731 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.63816 .67731 m .63816 .69584 L .64105 .70438 L p .707 .577 .707 r
F P
0 g
s
.64524 .54435 m .64524 .59993 L .63816 .6083 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72544 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83916 .54781 m .83916 .60339 L .82657 .5955 L p .707 .577 .707 r
F P
0 g
s
.82657 .5955 m .82657 .53992 L .83916 .54781 L p .707 .577 .707 r
F P
0 g
s
.84206 .68094 m .84206 .69947 L .83916 .69093 L p .707 .577 .707 r
F P
0 g
s
.83916 .69093 m .83916 .6724 L .84206 .68094 L p .707 .577 .707 r
F P
0 g
s
.84206 .69202 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69202 L p .707 .577 .707 r
F P
0 g
s
.39032 .60065 m .39032 .54507 L .35915 .54317 L p .707 .577 .707 r
F P
0 g
s
.39032 .54507 m .39032 .60065 L .42216 .59988 L p .707 .577 .707 r
F P
0 g
s
.42216 .59988 m .42216 .54429 L .39032 .54507 L p .707 .577 .707 r
F P
0 g
s
.64524 .59993 m .64524 .54435 L .66161 .53698 L p .707 .577 .707 r
F P
0 g
s
.42216 .54429 m .42216 .59988 L .45154 .5965 L p .707 .577 .707 r
F P
0 g
s
.45154 .5965 m .45154 .54092 L .42216 .54429 L p .707 .577 .707 r
F P
0 g
s
.35915 .59875 m .35915 .54317 L .33169 .53878 L p .707 .577 .707 r
F P
0 g
s
.35915 .54317 m .35915 .59875 L .39032 .60065 L p .707 .577 .707 r
F P
0 g
s
.63816 .69584 m .63816 .67731 L .64524 .66894 L p .707 .577 .707 r
F P
0 g
s
.63816 .72544 m .63816 .68839 L .64524 .68002 L p .707 .577 .707 r
F P
0 g
s
.64524 .66894 m .64524 .68747 L .63816 .69584 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54092 m .45154 .5965 L .47559 .59085 L p .707 .577 .707 r
F P
0 g
s
.47559 .59085 m .47559 .53527 L .45154 .54092 L p .707 .577 .707 r
F P
0 g
s
.66161 .53698 m .66161 .59256 L .64524 .59993 L p .707 .577 .707 r
F P
0 g
s
.82657 .53992 m .82657 .5955 L .80551 .58905 L p .707 .577 .707 r
F P
0 g
s
.80551 .58905 m .80551 .53347 L .82657 .53992 L p .707 .577 .707 r
F P
0 g
s
.64524 .68002 m .64524 .71708 L .63816 .72544 L p .707 .577 .707 r
F P
0 g
s
.33169 .53878 m .33169 .59436 L .35915 .59875 L p .707 .577 .707 r
F P
0 g
s
.33169 .59436 m .33169 .53878 L .31064 .53232 L p .707 .577 .707 r
F P
0 g
s
.83916 .6724 m .83916 .69093 L .82657 .68305 L p .707 .577 .707 r
F P
0 g
s
.82657 .68305 m .82657 .66452 L .83916 .6724 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59256 m .66161 .53698 L .68566 .53133 L p .707 .577 .707 r
F P
0 g
s
.39032 .68819 m .39032 .66967 L .35915 .66777 L p .707 .577 .707 r
F P
0 g
s
.39032 .66967 m .39032 .68819 L .42216 .68742 L p .707 .577 .707 r
F P
0 g
s
.42216 .68742 m .42216 .66889 L .39032 .66967 L p .707 .577 .707 r
F P
0 g
s
.47559 .53527 m .47559 .59085 L .49196 .58348 L p .707 .577 .707 r
F P
0 g
s
.49196 .58348 m .49196 .5279 L .47559 .53527 L p .707 .577 .707 r
F P
0 g
s
.64524 .68747 m .64524 .66894 L .66161 .66158 L p .707 .577 .707 r
F P
0 g
s
.42216 .66889 m .42216 .68742 L .45154 .68404 L p .707 .577 .707 r
F P
0 g
s
.45154 .68404 m .45154 .66551 L .42216 .66889 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71702 L p .707 .577 .707 r
F P
0 g
s
.42216 .71702 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.31064 .53232 m .31064 .58791 L .33169 .59436 L p .707 .577 .707 r
F P
0 g
s
.35915 .66777 m .35915 .68629 L .39032 .68819 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68002 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71702 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .68629 m .35915 .66777 L .33169 .66337 L p .707 .577 .707 r
F P
0 g
s
.80551 .53347 m .80551 .58905 L .77805 .58466 L p .707 .577 .707 r
F P
0 g
s
.77805 .58466 m .77805 .52908 L .80551 .53347 L p .707 .577 .707 r
F P
0 g
s
.66161 .66158 m .66161 .6801 L .64524 .68747 L p .707 .577 .707 r
F P
0 g
s
.68566 .53133 m .68566 .58691 L .66161 .59256 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67445 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.31064 .58791 m .31064 .53232 L .29804 .52444 L p .707 .577 .707 r
F P
0 g
s
.33169 .66337 m .33169 .6819 L .35915 .68629 L p .707 .577 .707 r
F P
0 g
s
.68566 .58691 m .68566 .53133 L .71504 .52795 L p .707 .577 .707 r
F P
0 g
s
.45154 .66551 m .45154 .68404 L .47559 .67839 L p .707 .577 .707 r
F P
0 g
s
.47559 .67839 m .47559 .65986 L .45154 .66551 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.82657 .66452 m .82657 .68305 L .80551 .67659 L p .707 .577 .707 r
F P
0 g
s
.80551 .67659 m .80551 .65806 L .82657 .66452 L p .707 .577 .707 r
F P
0 g
s
.33169 .67445 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66914 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.33169 .6819 m .33169 .66337 L .31064 .65692 L p .707 .577 .707 r
F P
0 g
s
.77805 .52908 m .77805 .58466 L .74688 .58276 L p .707 .577 .707 r
F P
0 g
s
.74688 .58276 m .74688 .52718 L .77805 .52908 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67445 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.29804 .52444 m .29804 .58002 L .31064 .58791 L p .707 .577 .707 r
F P
0 g
s
.71504 .58354 m .71504 .52795 L .74688 .52718 L p .707 .577 .707 r
F P
0 g
s
.71504 .52795 m .71504 .58354 L .68566 .58691 L p .707 .577 .707 r
F P
0 g
s
.49196 .5279 m .49196 .58348 L .49904 .57512 L p .707 .577 .707 r
F P
0 g
s
.49904 .57512 m .49904 .51953 L .49196 .5279 L p .707 .577 .707 r
F P
0 g
s
.31064 .65692 m .31064 .67545 L .33169 .6819 L p .707 .577 .707 r
F P
0 g
s
.66161 .6801 m .66161 .66158 L .68566 .65593 L p .707 .577 .707 r
F P
0 g
s
.74688 .52718 m .74688 .58276 L .71504 .58354 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.68566 .65593 m .68566 .67445 L .66161 .6801 L p .707 .577 .707 r
F P
0 g
s
.47559 .65986 m .47559 .67839 L .49196 .67102 L p .707 .577 .707 r
F P
0 g
s
.49196 .67102 m .49196 .65249 L .47559 .65986 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70505 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66357 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.29804 .58002 m .29804 .52444 L .29515 .5159 L p .707 .577 .707 r
F P
0 g
s
.80551 .65806 m .80551 .67659 L .77805 .6722 L p .707 .577 .707 r
F P
0 g
s
.77805 .6722 m .77805 .65367 L .80551 .65806 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66914 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66914 L p .707 .577 .707 r
F P
0 g
s
.31064 .67545 m .31064 .65692 L .29804 .64904 L p .707 .577 .707 r
F P
0 g
s
.31064 .70505 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.68566 .67445 m .68566 .65593 L .71504 .65255 L p .707 .577 .707 r
F P
0 g
s
.29804 .64904 m .29804 .66756 L .31064 .67545 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.71504 .65255 m .71504 .67108 L .68566 .67445 L p .707 .577 .707 r
F P
0 g
s
.29515 .5159 m .29515 .57148 L .29804 .58002 L p .707 .577 .707 r
F P
0 g
s
.49904 .51953 m .49904 .57512 L .49615 .56657 L p .707 .577 .707 r
F P
0 g
s
.49615 .56657 m .49615 .51099 L .49904 .51953 L p .707 .577 .707 r
F P
0 g
s
.77805 .65367 m .77805 .6722 L .74688 .6703 L p .707 .577 .707 r
F P
0 g
s
.74688 .6703 m .74688 .65177 L .77805 .65367 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70505 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.71504 .67108 m .71504 .65255 L .74688 .65177 L p .707 .577 .707 r
F P
0 g
s
.49196 .65249 m .49196 .67102 L .49904 .66266 L p .707 .577 .707 r
F P
0 g
s
.49904 .66266 m .49904 .64413 L .49196 .65249 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.74688 .65177 m .74688 .6703 L .71504 .67108 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66357 m .49196 .70063 L .49904 .69226 L p .707 .577 .707 r
F P
0 g
s
.49904 .69226 m .49904 .65521 L .49196 .66357 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.29515 .57148 m .29515 .5159 L .30223 .50753 L p .707 .577 .707 r
F P
0 g
s
.29804 .66756 m .29804 .64904 L .29515 .64049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29804 .69717 m .29804 .66012 L .29515 .65157 L p .707 .577 .707 r
F P
0 g
s
.29515 .64049 m .29515 .65902 L .29804 .66756 L p .707 .577 .707 r
F P
0 g
s
.30223 .50753 m .30223 .56312 L .29515 .57148 L p .707 .577 .707 r
F P
0 g
s
.29515 .65157 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.49615 .51099 m .49615 .56657 L .48356 .55869 L p .707 .577 .707 r
F P
0 g
s
.48356 .55869 m .48356 .50311 L .49615 .51099 L p .707 .577 .707 r
F P
0 g
s
.49904 .64413 m .49904 .66266 L .49615 .65411 L p .707 .577 .707 r
F P
0 g
s
.49615 .65411 m .49615 .63559 L .49904 .64413 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69226 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .56312 m .30223 .50753 L .3186 .50017 L p .707 .577 .707 r
F P
0 g
s
.29515 .65902 m .29515 .64049 L .30223 .63213 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65157 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .63213 m .30223 .65066 L .29515 .65902 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .50017 m .3186 .55575 L .30223 .56312 L p .707 .577 .707 r
F P
0 g
s
.48356 .50311 m .48356 .55869 L .4625 .55224 L p .707 .577 .707 r
F P
0 g
s
.4625 .55224 m .4625 .49665 L .48356 .50311 L p .707 .577 .707 r
F P
0 g
s
.30223 .64321 m .30223 .68026 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49615 .63559 m .49615 .65411 L .48356 .64623 L p .707 .577 .707 r
F P
0 g
s
.48356 .64623 m .48356 .6277 L .49615 .63559 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55575 m .3186 .50017 L .34265 .49452 L p .707 .577 .707 r
F P
0 g
s
.30223 .65066 m .30223 .63213 L .3186 .62476 L p .707 .577 .707 r
F P
0 g
s
.30223 .68026 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.4625 .49665 m .4625 .55224 L .43504 .54784 L p .707 .577 .707 r
F P
0 g
s
.43504 .54784 m .43504 .49226 L .4625 .49665 L p .707 .577 .707 r
F P
0 g
s
.3186 .62476 m .3186 .64329 L .30223 .65066 L p .707 .577 .707 r
F P
0 g
s
.34265 .49452 m .34265 .5501 L .3186 .55575 L p .707 .577 .707 r
F P
0 g
s
.34265 .5501 m .34265 .49452 L .37203 .49114 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68026 L p .707 .577 .707 r
F P
0 g
s
.48356 .6277 m .48356 .64623 L .4625 .63978 L p .707 .577 .707 r
F P
0 g
s
.4625 .63978 m .4625 .62125 L .48356 .6277 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66938 L p .707 .577 .707 r
F P
0 g
s
.4625 .66938 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.43504 .49226 m .43504 .54784 L .40387 .54594 L p .707 .577 .707 r
F P
0 g
s
.40387 .54594 m .40387 .49036 L .43504 .49226 L p .707 .577 .707 r
F P
0 g
s
.37203 .54672 m .37203 .49114 L .40387 .49036 L p .707 .577 .707 r
F P
0 g
s
.37203 .49114 m .37203 .54672 L .34265 .5501 L p .707 .577 .707 r
F P
0 g
s
.3186 .64329 m .3186 .62476 L .34265 .61911 L p .707 .577 .707 r
F P
0 g
s
.40387 .49036 m .40387 .54594 L .37203 .54672 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.34265 .61911 m .34265 .63764 L .3186 .64329 L p .707 .577 .707 r
F P
0 g
s
.4625 .62125 m .4625 .63978 L .43504 .63538 L p .707 .577 .707 r
F P
0 g
s
.43504 .63538 m .43504 .61686 L .4625 .62125 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66938 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.34265 .63764 m .34265 .61911 L .37203 .61573 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.37203 .61573 m .37203 .63426 L .34265 .63764 L p .707 .577 .707 r
F P
0 g
s
.43504 .61686 m .43504 .63538 L .40387 .63348 L p .707 .577 .707 r
F P
0 g
s
.40387 .63348 m .40387 .61496 L .43504 .61686 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.37203 .63426 m .37203 .61573 L .40387 .61496 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.40387 .61496 m .40387 .63348 L .37203 .63426 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo002;Ool<0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<0
00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001^Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo2@00A7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<005YFFUH00UYF2000?7oo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool003mooa4000Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH5
0004FUH01000FUIJEUYF0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF100025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH8000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUHK0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH900000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00T000AJEP03
001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUHF0004FUH00`00FUIJ
EP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60004FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP<000AJEP03001JEUYF009J
EP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800004FUH005YF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL00005FUH005YFFUH00003FUH20000
0eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo4P00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH01000FUH005YF0P000eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00002FUH00`00FUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH00003FUH30002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`04001JEP00FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH01@00FUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol002aoo`06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF00000P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00003000jOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP<000AJEP03001JEUYF00IJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@0039o
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF0P00<Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEP0000<000IJEP04001JEUYFFUHC
0002FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEP0000=JEP03001JEUYF009JEP<00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUH00000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EP<00003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH20004FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP02FUH00`00Oomoo`0/Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP06001JEP00FUH005YF0P0000=JEP00FUH00UYF
00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=J
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF
00000UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<007ooOol0;7oo000`Ool30004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P0000AJEP00FUIJEP@000EJEP<000EJEQ40
00=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YF00000`000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool003Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30000
0eYF000000090005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000kOolJ0003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Egoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHN0003FUH50004FUH01000FUIJEUYF
0P00;Goo000oOolI0002Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP8002eoo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPX000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003
FUH30003FUH2000]Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003Ool0000000H000AJEP03001JEUYF00=JEPT000MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000800006FUH00000001JEP001EYF0`0025YF100000=JEP0000001`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUHF
0004FUH00`00FUIJEP02FUH20002Ool01@00FUIJEP00FUH02P0015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P0000=JEP00000015YF00<005YFFUH00eYF200015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000^Ool20003FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD00004FUH000000004
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJ
EP<000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000800005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`04001JEP000003FUH00`00FUH0000300000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00@005YF001J
EP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00@005YF000000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000cOol002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004Ool30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50002Ool40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF
2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P000goo6@00
?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH6000AOol80004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF1P000UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000eYF
00<005YFFUH00UYF0P00FGoo000/Ool00`00FUH00004FUH00`00FUH000030004FUHI0002FUH60004
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF1@00
15YF0`00Egoo000/Ool00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH0000500001EYF001JEUYF00000UYF00<005YFFUH00eYF0`000UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P0000AJEP00FUIJEP8005Eoo`00;7oo00@0
05YF001JEP<000AJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50005FUH30002FUH01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00001EYF00<005YFFUH0
0UYF0P000eYF00<007ooOol0Dgoo000/Ool01`00FUH00000FUH005YF00<00003FUH005YF00AJEP<0
00AJEQ8000=JEP03001JEUYF00AJEP03001JEUYF00<0009JEP04001JEP000007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF00<005YF00001EYF00<005YFFUH00eYF0`0000=JEP000000E7oo000/Ool20003FUH00`00
FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH0
15YF00<005YFFUH00eYF00<005YFFUH00`00E7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF1@0000=JEP0000002@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF0000009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP0000=JEPD000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Aoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Ao
o`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00
27oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001EYF00<005YF00000`0000AJEP000000
00=JEP8005Aoo`00>goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@003Woo0`001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUIJEP/000EJEP04001JEUYF0002FUH2001DOol004=ooa<001Eoo`8000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001J
EP001eYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00E7oo001_Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol0079oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Aoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH01P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo0025OolF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002AOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000F7oo002BOol30003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Eoo`D000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00VWoo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002NOolI001VOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .71715 m .59613 .66157 L .56496 .65967 L p .707 .577 .707 r
F P
0 g
s
.59613 .66157 m .59613 .71715 L .62796 .71638 L p .707 .577 .707 r
F P
0 g
s
.62796 .71638 m .62796 .66079 L .59613 .66157 L p .707 .577 .707 r
F P
0 g
s
.62796 .66079 m .62796 .71638 L .65734 .713 L p .707 .577 .707 r
F P
0 g
s
.65734 .713 m .65734 .65742 L .62796 .66079 L p .707 .577 .707 r
F P
0 g
s
.56496 .71525 m .56496 .65967 L .5375 .65528 L p .707 .577 .707 r
F P
0 g
s
.56496 .65967 m .56496 .71525 L .59613 .71715 L p .707 .577 .707 r
F P
0 g
s
.65734 .65742 m .65734 .713 L .6814 .70735 L p .707 .577 .707 r
F P
0 g
s
.6814 .70735 m .6814 .65177 L .65734 .65742 L p .707 .577 .707 r
F P
0 g
s
.5375 .65528 m .5375 .71086 L .56496 .71525 L p .707 .577 .707 r
F P
0 g
s
.5375 .71086 m .5375 .65528 L .51644 .64883 L p .707 .577 .707 r
F P
0 g
s
.59613 .79564 m .59613 .77711 L .56496 .77521 L p .707 .577 .707 r
F P
0 g
s
.59613 .77711 m .59613 .79564 L .62796 .79486 L p .707 .577 .707 r
F P
0 g
s
.62796 .79486 m .62796 .77633 L .59613 .77711 L p .707 .577 .707 r
F P
0 g
s
.62796 .77633 m .62796 .79486 L .65735 .79148 L p .707 .577 .707 r
F P
0 g
s
.65735 .79148 m .65735 .77295 L .62796 .77633 L p .707 .577 .707 r
F P
0 g
s
.6814 .65177 m .6814 .70735 L .69777 .69998 L p .707 .577 .707 r
F P
0 g
s
.69777 .69998 m .69777 .6444 L .6814 .65177 L p .707 .577 .707 r
F P
0 g
s
.56496 .77521 m .56496 .79373 L .59613 .79564 L p .707 .577 .707 r
F P
0 g
s
.51644 .64883 m .51644 .70441 L .5375 .71086 L p .707 .577 .707 r
F P
0 g
s
.56496 .79373 m .56496 .77521 L .5375 .77082 L p .707 .577 .707 r
F P
0 g
s
.5375 .77082 m .5375 .78934 L .56496 .79373 L p .707 .577 .707 r
F P
0 g
s
.51644 .70441 m .51644 .64883 L .50385 .64094 L p .707 .577 .707 r
F P
0 g
s
.65735 .77295 m .65735 .79148 L .6814 .78583 L p .707 .577 .707 r
F P
0 g
s
.6814 .78583 m .6814 .7673 L .65735 .77295 L p .707 .577 .707 r
F P
0 g
s
.59613 .8694 m .59613 .83234 L .56496 .83044 L p .707 .577 .707 r
F P
0 g
s
.59613 .83234 m .59613 .8694 L .62796 .86862 L p .707 .577 .707 r
F P
0 g
s
.62796 .86862 m .62796 .83156 L .59613 .83234 L p .707 .577 .707 r
F P
0 g
s
.62796 .83156 m .62796 .86862 L .65735 .86524 L p .707 .577 .707 r
F P
0 g
s
.65735 .86524 m .65735 .82819 L .62796 .83156 L p .707 .577 .707 r
F P
0 g
s
.56496 .8675 m .56496 .83044 L .5375 .82605 L p .707 .577 .707 r
F P
0 g
s
.56496 .83044 m .56496 .8675 L .59613 .8694 L p .707 .577 .707 r
F P
0 g
s
.5375 .78934 m .5375 .77082 L .51644 .76436 L p .707 .577 .707 r
F P
0 g
s
.51644 .76436 m .51644 .78289 L .5375 .78934 L p .707 .577 .707 r
F P
0 g
s
.50385 .64094 m .50385 .69652 L .51644 .70441 L p .707 .577 .707 r
F P
0 g
s
.69777 .6444 m .69777 .69998 L .70485 .69162 L p .707 .577 .707 r
F P
0 g
s
.70485 .69162 m .70485 .63603 L .69777 .6444 L p .707 .577 .707 r
F P
0 g
s
.65735 .82819 m .65735 .86524 L .6814 .85959 L p .707 .577 .707 r
F P
0 g
s
.6814 .85959 m .6814 .82254 L .65735 .82819 L p .707 .577 .707 r
F P
0 g
s
.5375 .82605 m .5375 .8631 L .56496 .8675 L p .707 .577 .707 r
F P
0 g
s
.6814 .7673 m .6814 .78583 L .69777 .77846 L p .707 .577 .707 r
F P
0 g
s
.69777 .77846 m .69777 .75993 L .6814 .7673 L p .707 .577 .707 r
F P
0 g
s
.5375 .8631 m .5375 .82605 L .51644 .81959 L p .707 .577 .707 r
F P
0 g
s
.50385 .69652 m .50385 .64094 L .50095 .6324 L p .707 .577 .707 r
F P
0 g
s
.51644 .78289 m .51644 .76436 L .50385 .75648 L p .707 .577 .707 r
F P
0 g
s
.51644 .81959 m .51644 .85665 L .5375 .8631 L p .707 .577 .707 r
F P
0 g
s
.6814 .82254 m .6814 .85959 L .69777 .85222 L p .707 .577 .707 r
F P
0 g
s
.69777 .85222 m .69777 .81517 L .6814 .82254 L p .707 .577 .707 r
F P
0 g
s
.50385 .75648 m .50385 .775 L .51644 .78289 L p .707 .577 .707 r
F P
0 g
s
.50095 .6324 m .50095 .68798 L .50385 .69652 L p .707 .577 .707 r
F P
0 g
s
.70485 .63603 m .70485 .69162 L .70195 .68307 L p .707 .577 .707 r
F P
0 g
s
.70195 .68307 m .70195 .62749 L .70485 .63603 L p .707 .577 .707 r
F P
0 g
s
.51644 .85665 m .51644 .81959 L .50385 .81171 L p .707 .577 .707 r
F P
0 g
s
.69777 .75993 m .69777 .77846 L .70485 .7701 L p .707 .577 .707 r
F P
0 g
s
.70485 .7701 m .70485 .75157 L .69777 .75993 L p .707 .577 .707 r
F P
0 g
s
.50385 .81171 m .50385 .84877 L .51644 .85665 L p .707 .577 .707 r
F P
0 g
s
.50095 .68798 m .50095 .6324 L .50804 .62403 L p .707 .577 .707 r
F P
0 g
s
.50385 .775 m .50385 .75648 L .50095 .74794 L p .707 .577 .707 r
F P
0 g
s
.69777 .81517 m .69777 .85222 L .70485 .84386 L p .707 .577 .707 r
F P
0 g
s
.70485 .84386 m .70485 .8068 L .69777 .81517 L p .707 .577 .707 r
F P
0 g
s
.50095 .74794 m .50095 .76646 L .50385 .775 L p .707 .577 .707 r
F P
0 g
s
.49044 .83252 m .49044 .33063 L .44643 .32795 L p .707 .577 .707 r
F P
0 g
s
.50804 .62403 m .50804 .67962 L .50095 .68798 L p .707 .577 .707 r
F P
0 g
s
.50385 .84877 m .50385 .81171 L .50095 .80317 L p .707 .577 .707 r
F P
0 g
s
.50095 .80317 m .50095 .84022 L .50385 .84877 L p .707 .577 .707 r
F P
0 g
s
.50804 .67962 m .50804 .62403 L .5244 .61667 L p .707 .577 .707 r
F P
0 g
s
.50095 .76646 m .50095 .74794 L .50804 .73957 L p .707 .577 .707 r
F P
0 g
s
.50804 .73957 m .50804 .7581 L .50095 .76646 L p .707 .577 .707 r
F P
0 g
s
.5244 .61667 m .5244 .67225 L .50804 .67962 L p .707 .577 .707 r
F P
0 g
s
.50095 .84022 m .50095 .80317 L .50804 .7948 L p .707 .577 .707 r
F P
0 g
s
.50804 .7948 m .50804 .83186 L .50095 .84022 L p .707 .577 .707 r
F P
0 g
s
.50804 .7581 m .50804 .73957 L .5244 .7322 L p .707 .577 .707 r
F P
0 g
s
.5244 .7322 m .5244 .75073 L .50804 .7581 L p .707 .577 .707 r
F P
0 g
s
.50804 .83186 m .50804 .7948 L .5244 .78744 L p .707 .577 .707 r
F P
0 g
s
.5244 .78744 m .5244 .82449 L .50804 .83186 L p .707 .577 .707 r
F P
0 g
s
.5244 .75073 m .5244 .7322 L .54846 .72655 L p .707 .577 .707 r
F P
0 g
s
.54846 .72655 m .54846 .74508 L .5244 .75073 L p .707 .577 .707 r
F P
0 g
s
.5244 .82449 m .5244 .78744 L .54846 .78179 L p .707 .577 .707 r
F P
0 g
s
.54846 .78179 m .54846 .81884 L .5244 .82449 L p .707 .577 .707 r
F P
0 g
s
.49044 .33063 m .49044 .83252 L .53538 .83142 L p .707 .577 .707 r
F P
0 g
s
.5244 .67225 m .5244 .61667 L .54846 .61102 L p .707 .577 .707 r
F P
0 g
s
.54846 .61102 m .54846 .6666 L .5244 .67225 L p .707 .577 .707 r
F P
0 g
s
.53538 .83142 m .53538 .32954 L .49044 .33063 L p .707 .577 .707 r
F P
0 g
s
.54846 .6666 m .54846 .61102 L .57784 .60764 L p .707 .577 .707 r
F P
0 g
s
.57784 .60764 m .57784 .66322 L .54846 .6666 L p .707 .577 .707 r
F P
0 g
s
.54846 .74508 m .54846 .72655 L .57784 .72317 L p .707 .577 .707 r
F P
0 g
s
.57784 .72317 m .57784 .7417 L .54846 .74508 L p .707 .577 .707 r
F P
0 g
s
.54846 .81884 m .54846 .78179 L .57784 .77841 L p .707 .577 .707 r
F P
0 g
s
.57784 .77841 m .57784 .81546 L .54846 .81884 L p .707 .577 .707 r
F P
0 g
s
.53538 .32954 m .53538 .83142 L .57686 .82665 L p .707 .577 .707 r
F P
0 g
s
.57686 .82665 m .57686 .32476 L .53538 .32954 L p .707 .577 .707 r
F P
0 g
s
.70195 .62749 m .70195 .68307 L .68936 .67519 L p .707 .577 .707 r
F P
0 g
s
.68936 .67519 m .68936 .61961 L .70195 .62749 L p .707 .577 .707 r
F P
0 g
s
.44643 .82984 m .44643 .32795 L .40766 .32175 L p .707 .577 .707 r
F P
0 g
s
.44643 .32795 m .44643 .82984 L .49044 .83252 L p .707 .577 .707 r
F P
0 g
s
.70485 .75157 m .70485 .7701 L .70195 .76156 L p .707 .577 .707 r
F P
0 g
s
.70195 .76156 m .70195 .74303 L .70485 .75157 L p .707 .577 .707 r
F P
0 g
s
.25312 .68034 m .25312 .62476 L .22195 .62286 L p .707 .577 .707 r
F P
0 g
s
.25312 .62476 m .25312 .68034 L .28495 .67956 L p .707 .577 .707 r
F P
0 g
s
.28495 .67956 m .28495 .62398 L .25312 .62476 L p .707 .577 .707 r
F P
0 g
s
.57784 .66322 m .57784 .60764 L .60968 .60686 L p .707 .577 .707 r
F P
0 g
s
.60968 .60686 m .60968 .66244 L .57784 .66322 L p .707 .577 .707 r
F P
0 g
s
.57784 .7417 m .57784 .72317 L .60968 .7224 L p .707 .577 .707 r
F P
0 g
s
.60968 .7224 m .60968 .74092 L .57784 .7417 L p .707 .577 .707 r
F P
0 g
s
.64085 .77953 m .64085 .81659 L .60968 .81469 L p .707 .577 .707 r
F P
0 g
s
.60968 .81469 m .60968 .77763 L .64085 .77953 L p .707 .577 .707 r
F P
0 g
s
.57784 .81546 m .57784 .77841 L .60968 .77763 L p .707 .577 .707 r
F P
0 g
s
.60968 .77763 m .60968 .81469 L .57784 .81546 L p .707 .577 .707 r
F P
0 g
s
.57686 .32476 m .57686 .82665 L .61082 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .60876 m .64085 .66434 L .60968 .66244 L p .707 .577 .707 r
F P
0 g
s
.60968 .66244 m .60968 .60686 L .64085 .60876 L p .707 .577 .707 r
F P
0 g
s
.64085 .7243 m .64085 .74283 L .60968 .74092 L p .707 .577 .707 r
F P
0 g
s
.60968 .74092 m .60968 .7224 L .64085 .7243 L p .707 .577 .707 r
F P
0 g
s
.61082 .81868 m .61082 .31679 L .57686 .32476 L p .707 .577 .707 r
F P
0 g
s
.28495 .62398 m .28495 .67956 L .31434 .67618 L p .707 .577 .707 r
F P
0 g
s
.31434 .67618 m .31434 .6206 L .28495 .62398 L p .707 .577 .707 r
F P
0 g
s
.22195 .67844 m .22195 .62286 L .19449 .61846 L p .707 .577 .707 r
F P
0 g
s
.22195 .62286 m .22195 .67844 L .25312 .68034 L p .707 .577 .707 r
F P
0 g
s
.70485 .8068 m .70485 .84386 L .70195 .83532 L p .707 .577 .707 r
F P
0 g
s
.70195 .83532 m .70195 .79826 L .70485 .8068 L p .707 .577 .707 r
F P
0 g
s
.40766 .82364 m .40766 .32175 L .37794 .31264 L p .707 .577 .707 r
F P
0 g
s
.40766 .32175 m .40766 .82364 L .44643 .82984 L p .707 .577 .707 r
F P
0 g
s
.31434 .6206 m .31434 .67618 L .33839 .67053 L p .707 .577 .707 r
F P
0 g
s
.33839 .67053 m .33839 .61495 L .31434 .6206 L p .707 .577 .707 r
F P
0 g
s
.68936 .61961 m .68936 .67519 L .66831 .66874 L p .707 .577 .707 r
F P
0 g
s
.66831 .66874 m .66831 .61315 L .68936 .61961 L p .707 .577 .707 r
F P
0 g
s
.19449 .61846 m .19449 .67405 L .22195 .67844 L p .707 .577 .707 r
F P
0 g
s
.70195 .74303 m .70195 .76156 L .68936 .75367 L p .707 .577 .707 r
F P
0 g
s
.68936 .75367 m .68936 .73514 L .70195 .74303 L p .707 .577 .707 r
F P
0 g
s
.19449 .67405 m .19449 .61846 L .17343 .61201 L p .707 .577 .707 r
F P
0 g
s
.61082 .31679 m .61082 .81868 L .63393 .80828 L p .707 .577 .707 r
F P
0 g
s
.63393 .80828 m .63393 .30639 L .61082 .31679 L p .707 .577 .707 r
F P
0 g
s
.25312 .75882 m .25312 .74029 L .22195 .73839 L p .707 .577 .707 r
F P
0 g
s
.25312 .74029 m .25312 .75882 L .28495 .75804 L p .707 .577 .707 r
F P
0 g
s
.28495 .75804 m .28495 .73952 L .25312 .74029 L p .707 .577 .707 r
F P
0 g
s
.28495 .73952 m .28495 .75804 L .31434 .75466 L p .707 .577 .707 r
F P
0 g
s
.31434 .75466 m .31434 .73614 L .28495 .73952 L p .707 .577 .707 r
F P
0 g
s
.33839 .61495 m .33839 .67053 L .35476 .66317 L p .707 .577 .707 r
F P
0 g
s
.35476 .66317 m .35476 .60758 L .33839 .61495 L p .707 .577 .707 r
F P
0 g
s
.22195 .73839 m .22195 .75692 L .25312 .75882 L p .707 .577 .707 r
F P
0 g
s
.70195 .79826 m .70195 .83532 L .68936 .82743 L p .707 .577 .707 r
F P
0 g
s
.68936 .82743 m .68936 .79038 L .70195 .79826 L p .707 .577 .707 r
F P
0 g
s
.17343 .61201 m .17343 .66759 L .19449 .67405 L p .707 .577 .707 r
F P
0 g
s
.22195 .75692 m .22195 .73839 L .19449 .734 L p .707 .577 .707 r
F P
0 g
s
.66831 .61315 m .66831 .66874 L .64085 .66434 L p .707 .577 .707 r
F P
0 g
s
.64085 .66434 m .64085 .60876 L .66831 .61315 L p .707 .577 .707 r
F P
0 g
s
.19449 .734 m .19449 .75253 L .22195 .75692 L p .707 .577 .707 r
F P
0 g
s
.17343 .66759 m .17343 .61201 L .16084 .60413 L p .707 .577 .707 r
F P
0 g
s
.37794 .81452 m .37794 .31264 L .36016 .30151 L p .707 .577 .707 r
F P
0 g
s
.37794 .31264 m .37794 .81452 L .40766 .82364 L p .707 .577 .707 r
F P
0 g
s
.31434 .73614 m .31434 .75466 L .33839 .74901 L p .707 .577 .707 r
F P
0 g
s
.33839 .74901 m .33839 .73049 L .31434 .73614 L p .707 .577 .707 r
F P
0 g
s
.25312 .83258 m .25312 .79553 L .22195 .79363 L p .707 .577 .707 r
F P
0 g
s
.25312 .79553 m .25312 .83258 L .28495 .8318 L p .707 .577 .707 r
F P
0 g
s
.28495 .8318 m .28495 .79475 L .25312 .79553 L p .707 .577 .707 r
F P
0 g
s
.28495 .79475 m .28495 .8318 L .31434 .82843 L p .707 .577 .707 r
F P
0 g
s
.31434 .82843 m .31434 .79137 L .28495 .79475 L p .707 .577 .707 r
F P
0 g
s
.68936 .73514 m .68936 .75367 L .66831 .74722 L p .707 .577 .707 r
F P
0 g
s
.66831 .74722 m .66831 .72869 L .68936 .73514 L p .707 .577 .707 r
F P
0 g
s
.22195 .83068 m .22195 .79363 L .19449 .78923 L p .707 .577 .707 r
F P
0 g
s
.22195 .79363 m .22195 .83068 L .25312 .83258 L p .707 .577 .707 r
F P
0 g
s
.19449 .75253 m .19449 .734 L .17343 .72755 L p .707 .577 .707 r
F P
0 g
s
.17343 .72755 m .17343 .74607 L .19449 .75253 L p .707 .577 .707 r
F P
0 g
s
.16084 .60413 m .16084 .65971 L .17343 .66759 L p .707 .577 .707 r
F P
0 g
s
.35476 .60758 m .35476 .66317 L .36184 .6548 L p .707 .577 .707 r
F P
0 g
s
.36184 .6548 m .36184 .59922 L .35476 .60758 L p .707 .577 .707 r
F P
0 g
s
.31434 .79137 m .31434 .82843 L .33839 .82278 L p .707 .577 .707 r
F P
0 g
s
.33839 .82278 m .33839 .78572 L .31434 .79137 L p .707 .577 .707 r
F P
0 g
s
.19449 .78923 m .19449 .82629 L .22195 .83068 L p .707 .577 .707 r
F P
0 g
s
.68936 .79038 m .68936 .82743 L .66831 .82098 L p .707 .577 .707 r
F P
0 g
s
.66831 .82098 m .66831 .78392 L .68936 .79038 L p .707 .577 .707 r
F P
0 g
s
.33839 .73049 m .33839 .74901 L .35476 .74165 L p .707 .577 .707 r
F P
0 g
s
.35476 .74165 m .35476 .72312 L .33839 .73049 L p .707 .577 .707 r
F P
0 g
s
.66831 .72869 m .66831 .74722 L .64085 .74283 L p .707 .577 .707 r
F P
0 g
s
.64085 .74283 m .64085 .7243 L .66831 .72869 L p .707 .577 .707 r
F P
0 g
s
.64085 .81659 m .64085 .77953 L .66831 .78392 L p .707 .577 .707 r
F P
0 g
s
.63393 .30639 m .63393 .80828 L .64393 .79647 L p .707 .577 .707 r
F P
0 g
s
.64393 .79647 m .64393 .29458 L .63393 .30639 L p .707 .577 .707 r
F P
0 g
s
.19449 .82629 m .19449 .78923 L .17343 .78278 L p .707 .577 .707 r
F P
0 g
s
.16084 .65971 m .16084 .60413 L .15794 .59558 L p .707 .577 .707 r
F P
0 g
s
.17343 .74607 m .17343 .72755 L .16084 .71966 L p .707 .577 .707 r
F P
0 g
s
.17343 .78278 m .17343 .81983 L .19449 .82629 L p .707 .577 .707 r
F P
0 g
s
.33839 .78572 m .33839 .82278 L .35476 .81541 L p .707 .577 .707 r
F P
0 g
s
.35476 .81541 m .35476 .77835 L .33839 .78572 L p .707 .577 .707 r
F P
0 g
s
.16084 .71966 m .16084 .73819 L .17343 .74607 L p .707 .577 .707 r
F P
0 g
s
.36184 .59922 m .36184 .6548 L .35894 .64626 L p .707 .577 .707 r
F P
0 g
s
.35894 .64626 m .35894 .59068 L .36184 .59922 L p .707 .577 .707 r
F P
0 g
s
.35476 .72312 m .35476 .74165 L .36184 .73328 L p .707 .577 .707 r
F P
0 g
s
.36184 .73328 m .36184 .71476 L .35476 .72312 L p .707 .577 .707 r
F P
0 g
s
.35476 .77835 m .35476 .81541 L .36184 .80704 L p .707 .577 .707 r
F P
0 g
s
.36184 .80704 m .36184 .76999 L .35476 .77835 L p .707 .577 .707 r
F P
0 g
s
.35894 .59068 m .35894 .64626 L .34635 .63837 L p .707 .577 .707 r
F P
0 g
s
.34635 .63837 m .34635 .58279 L .35894 .59068 L p .707 .577 .707 r
F P
0 g
s
.36184 .71476 m .36184 .73328 L .35894 .72474 L p .707 .577 .707 r
F P
0 g
s
.35894 .72474 m .35894 .70621 L .36184 .71476 L p .707 .577 .707 r
F P
0 g
s
.36184 .76999 m .36184 .80704 L .35894 .7985 L p .707 .577 .707 r
F P
0 g
s
.35894 .7985 m .35894 .76145 L .36184 .76999 L p .707 .577 .707 r
F P
0 g
s
.36016 .80339 m .36016 .30151 L .35607 .28945 L p .707 .577 .707 r
F P
0 g
s
.36016 .30151 m .36016 .80339 L .37794 .81452 L p .707 .577 .707 r
F P
0 g
s
.66831 .78392 m .66831 .82098 L .64085 .81659 L p .707 .577 .707 r
F P
0 g
s
.15794 .59558 m .15794 .65117 L .16084 .65971 L p .707 .577 .707 r
F P
0 g
s
.17343 .81983 m .17343 .78278 L .16084 .7749 L p .707 .577 .707 r
F P
0 g
s
.16084 .7749 m .16084 .81195 L .17343 .81983 L p .707 .577 .707 r
F P
0 g
s
.15794 .65117 m .15794 .59558 L .16503 .58722 L p .707 .577 .707 r
F P
0 g
s
.16084 .73819 m .16084 .71966 L .15794 .71112 L p .707 .577 .707 r
F P
0 g
s
.64393 .29458 m .64393 .79647 L .63984 .78441 L p .707 .577 .707 r
F P
0 g
s
.63984 .78441 m .63984 .28252 L .64393 .29458 L p .707 .577 .707 r
F P
0 g
s
.15794 .71112 m .15794 .72965 L .16084 .73819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .58722 m .16503 .6428 L .15794 .65117 L p .707 .577 .707 r
F P
0 g
s
.16084 .81195 m .16084 .7749 L .15794 .76635 L p .707 .577 .707 r
F P
0 g
s
.35894 .70621 m .35894 .72474 L .34635 .71686 L p .707 .577 .707 r
F P
0 g
s
.34635 .71686 m .34635 .69833 L .35894 .70621 L p .707 .577 .707 r
F P
0 g
s
.35894 .76145 m .35894 .7985 L .34635 .79062 L p .707 .577 .707 r
F P
0 g
s
.34635 .79062 m .34635 .75356 L .35894 .76145 L p .707 .577 .707 r
F P
0 g
s
.35607 .28945 m .35607 .79133 L .36016 .80339 L p .707 .577 .707 r
F P
0 g
s
.35607 .79133 m .35607 .28945 L .36607 .27764 L p .707 .577 .707 r
F P
0 g
s
.15794 .76635 m .15794 .80341 L .16084 .81195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .6428 m .16503 .58722 L .1814 .57985 L p .707 .577 .707 r
F P
0 g
s
.15794 .72965 m .15794 .71112 L .16503 .70276 L p .707 .577 .707 r
F P
0 g
s
.16503 .70276 m .16503 .72128 L .15794 .72965 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .57985 m .1814 .63543 L .16503 .6428 L p .707 .577 .707 r
F P
0 g
s
.34635 .58279 m .34635 .63837 L .3253 .63192 L p .707 .577 .707 r
F P
0 g
s
.3253 .63192 m .3253 .57634 L .34635 .58279 L p .707 .577 .707 r
F P
0 g
s
.15794 .80341 m .15794 .76635 L .16503 .75799 L p .707 .577 .707 r
F P
0 g
s
.63984 .28252 m .63984 .78441 L .62206 .77328 L p .707 .577 .707 r
F P
0 g
s
.62206 .77328 m .62206 .27139 L .63984 .28252 L p .707 .577 .707 r
F P
0 g
s
.1814 .63543 m .1814 .57985 L .20545 .5742 L p .707 .577 .707 r
F P
0 g
s
.16503 .75799 m .16503 .79504 L .15794 .80341 L p .707 .577 .707 r
F P
0 g
s
.16503 .72128 m .16503 .70276 L .1814 .69539 L p .707 .577 .707 r
F P
0 g
s
.36607 .77953 m .36607 .27764 L .38918 .26724 L p .707 .577 .707 r
F P
0 g
s
.36607 .27764 m .36607 .77953 L .35607 .79133 L p .707 .577 .707 r
F P
0 g
s
.1814 .69539 m .1814 .71392 L .16503 .72128 L p .707 .577 .707 r
F P
0 g
s
.3253 .57634 m .3253 .63192 L .29784 .62753 L p .707 .577 .707 r
F P
0 g
s
.29784 .62753 m .29784 .57195 L .3253 .57634 L p .707 .577 .707 r
F P
0 g
s
.20545 .5742 m .20545 .62978 L .1814 .63543 L p .707 .577 .707 r
F P
0 g
s
.20545 .62978 m .20545 .5742 L .23483 .57082 L p .707 .577 .707 r
F P
0 g
s
.16503 .79504 m .16503 .75799 L .1814 .75062 L p .707 .577 .707 r
F P
0 g
s
.34635 .69833 m .34635 .71686 L .3253 .7104 L p .707 .577 .707 r
F P
0 g
s
.3253 .7104 m .3253 .69187 L .34635 .69833 L p .707 .577 .707 r
F P
0 g
s
.29784 .57195 m .29784 .62753 L .26667 .62563 L p .707 .577 .707 r
F P
0 g
s
.26667 .62563 m .26667 .57005 L .29784 .57195 L p .707 .577 .707 r
F P
0 g
s
.1814 .75062 m .1814 .78768 L .16503 .79504 L p .707 .577 .707 r
F P
0 g
s
.1814 .71392 m .1814 .69539 L .20545 .68974 L p .707 .577 .707 r
F P
0 g
s
.23483 .6264 m .23483 .57082 L .26667 .57005 L p .707 .577 .707 r
F P
0 g
s
.23483 .57082 m .23483 .6264 L .20545 .62978 L p .707 .577 .707 r
F P
0 g
s
.62206 .27139 m .62206 .77328 L .59233 .76417 L p .707 .577 .707 r
F P
0 g
s
.59233 .76417 m .59233 .26228 L .62206 .27139 L p .707 .577 .707 r
F P
0 g
s
.26667 .57005 m .26667 .62563 L .23483 .6264 L p .707 .577 .707 r
F P
0 g
s
.34635 .75356 m .34635 .79062 L .3253 .78416 L p .707 .577 .707 r
F P
0 g
s
.3253 .78416 m .3253 .74711 L .34635 .75356 L p .707 .577 .707 r
F P
0 g
s
.73333 .62512 m .73333 .56953 L .70216 .56763 L p .707 .577 .707 r
F P
0 g
s
.73333 .56953 m .73333 .62512 L .76517 .62434 L p .707 .577 .707 r
F P
0 g
s
.76517 .62434 m .76517 .56876 L .73333 .56953 L p .707 .577 .707 r
F P
0 g
s
.20545 .68974 m .20545 .70827 L .1814 .71392 L p .707 .577 .707 r
F P
0 g
s
.76517 .56876 m .76517 .62434 L .79455 .62096 L p .707 .577 .707 r
F P
0 g
s
.79455 .62096 m .79455 .56538 L .76517 .56876 L p .707 .577 .707 r
F P
0 g
s
.70216 .62322 m .70216 .56763 L .6747 .56324 L p .707 .577 .707 r
F P
0 g
s
.70216 .56763 m .70216 .62322 L .73333 .62512 L p .707 .577 .707 r
F P
0 g
s
.3253 .69187 m .3253 .7104 L .29784 .70601 L p .707 .577 .707 r
F P
0 g
s
.29784 .70601 m .29784 .68748 L .3253 .69187 L p .707 .577 .707 r
F P
0 g
s
.1814 .78768 m .1814 .75062 L .20545 .74497 L p .707 .577 .707 r
F P
0 g
s
.38918 .26724 m .38918 .76912 L .36607 .77953 L p .707 .577 .707 r
F P
0 g
s
.38918 .76912 m .38918 .26724 L .42314 .25926 L p .707 .577 .707 r
F P
0 g
s
.79455 .56538 m .79455 .62096 L .8186 .61531 L p .707 .577 .707 r
F P
0 g
s
.8186 .61531 m .8186 .55973 L .79455 .56538 L p .707 .577 .707 r
F P
0 g
s
.20545 .70827 m .20545 .68974 L .23483 .68636 L p .707 .577 .707 r
F P
0 g
s
.23483 .68636 m .23483 .70489 L .20545 .70827 L p .707 .577 .707 r
F P
0 g
s
.20545 .74497 m .20545 .78203 L .1814 .78768 L p .707 .577 .707 r
F P
0 g
s
.6747 .56324 m .6747 .61882 L .70216 .62322 L p .707 .577 .707 r
F P
0 g
s
.6747 .61882 m .6747 .56324 L .65365 .55679 L p .707 .577 .707 r
F P
0 g
s
.3253 .74711 m .3253 .78416 L .29784 .77977 L p .707 .577 .707 r
F P
0 g
s
.29784 .77977 m .29784 .74272 L .3253 .74711 L p .707 .577 .707 r
F P
0 g
s
.29784 .68748 m .29784 .70601 L .26667 .70411 L p .707 .577 .707 r
F P
0 g
s
.26667 .70411 m .26667 .68558 L .29784 .68748 L p .707 .577 .707 r
F P
0 g
s
.23483 .70489 m .23483 .68636 L .26667 .68558 L p .707 .577 .707 r
F P
0 g
s
.59233 .26228 m .59233 .76417 L .55357 .75796 L p .707 .577 .707 r
F P
0 g
s
.55357 .75796 m .55357 .25608 L .59233 .26228 L p .707 .577 .707 r
F P
0 g
s
.26667 .68558 m .26667 .70411 L .23483 .70489 L p .707 .577 .707 r
F P
0 g
s
.20545 .78203 m .20545 .74497 L .23483 .74159 L p .707 .577 .707 r
F P
0 g
s
.73333 .7036 m .73333 .68507 L .70216 .68317 L p .707 .577 .707 r
F P
0 g
s
.73333 .68507 m .73333 .7036 L .76517 .70282 L p .707 .577 .707 r
F P
0 g
s
.76517 .70282 m .76517 .68429 L .73333 .68507 L p .707 .577 .707 r
F P
0 g
s
.76517 .68429 m .76517 .70282 L .79455 .69944 L p .707 .577 .707 r
F P
0 g
s
.79455 .69944 m .79455 .68091 L .76517 .68429 L p .707 .577 .707 r
F P
0 g
s
.8186 .55973 m .8186 .61531 L .83497 .60794 L p .707 .577 .707 r
F P
0 g
s
.83497 .60794 m .83497 .55236 L .8186 .55973 L p .707 .577 .707 r
F P
0 g
s
.70216 .68317 m .70216 .7017 L .73333 .7036 L p .707 .577 .707 r
F P
0 g
s
.65365 .55679 m .65365 .61237 L .6747 .61882 L p .707 .577 .707 r
F P
0 g
s
.29784 .74272 m .29784 .77977 L .26667 .77787 L p .707 .577 .707 r
F P
0 g
s
.26667 .77787 m .26667 .74082 L .29784 .74272 L p .707 .577 .707 r
F P
0 g
s
.70216 .7017 m .70216 .68317 L .6747 .67878 L p .707 .577 .707 r
F P
0 g
s
.42314 .76115 m .42314 .25926 L .46462 .25449 L p .707 .577 .707 r
F P
0 g
s
.42314 .25926 m .42314 .76115 L .38918 .76912 L p .707 .577 .707 r
F P
0 g
s
.23483 .74159 m .23483 .77865 L .20545 .78203 L p .707 .577 .707 r
F P
0 g
s
.23483 .77865 m .23483 .74159 L .26667 .74082 L p .707 .577 .707 r
F P
0 g
s
.6747 .67878 m .6747 .6973 L .70216 .7017 L p .707 .577 .707 r
F P
0 g
s
.26667 .74082 m .26667 .77787 L .23483 .77865 L p .707 .577 .707 r
F P
0 g
s
.65365 .61237 m .65365 .55679 L .64105 .5489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68091 m .79455 .69944 L .8186 .69379 L p .707 .577 .707 r
F P
0 g
s
.8186 .69379 m .8186 .67526 L .79455 .68091 L p .707 .577 .707 r
F P
0 g
s
.73333 .77736 m .73333 .7403 L .70216 .7384 L p .707 .577 .707 r
F P
0 g
s
.73333 .7403 m .73333 .77736 L .76517 .77658 L p .707 .577 .707 r
F P
0 g
s
.76517 .77658 m .76517 .73953 L .73333 .7403 L p .707 .577 .707 r
F P
0 g
s
.76517 .73953 m .76517 .77658 L .79455 .7732 L p .707 .577 .707 r
F P
0 g
s
.79455 .7732 m .79455 .73615 L .76517 .73953 L p .707 .577 .707 r
F P
0 g
s
.55357 .25608 m .55357 .75796 L .50956 .75528 L p .707 .577 .707 r
F P
0 g
s
.50956 .75528 m .50956 .25339 L .55357 .25608 L p .707 .577 .707 r
F P
0 g
s
.70216 .77546 m .70216 .7384 L .6747 .73401 L p .707 .577 .707 r
F P
0 g
s
.70216 .7384 m .70216 .77546 L .73333 .77736 L p .707 .577 .707 r
F P
0 g
s
.6747 .6973 m .6747 .67878 L .65365 .67232 L p .707 .577 .707 r
F P
0 g
s
.46462 .75638 m .46462 .25449 L .50956 .25339 L p .707 .577 .707 r
F P
0 g
s
.46462 .25449 m .46462 .75638 L .42314 .76115 L p .707 .577 .707 r
F P
0 g
s
.65365 .67232 m .65365 .69085 L .6747 .6973 L p .707 .577 .707 r
F P
0 g
s
.50956 .25339 m .50956 .75528 L .46462 .75638 L p .707 .577 .707 r
F P
0 g
s
.64105 .5489 m .64105 .60448 L .65365 .61237 L p .707 .577 .707 r
F P
0 g
s
.83497 .55236 m .83497 .60794 L .84205 .59958 L p .707 .577 .707 r
F P
0 g
s
.84205 .59958 m .84205 .544 L .83497 .55236 L p .707 .577 .707 r
F P
0 g
s
.79455 .73615 m .79455 .7732 L .8186 .76755 L p .707 .577 .707 r
F P
0 g
s
.8186 .76755 m .8186 .7305 L .79455 .73615 L p .707 .577 .707 r
F P
0 g
s
.6747 .73401 m .6747 .77107 L .70216 .77546 L p .707 .577 .707 r
F P
0 g
s
.8186 .67526 m .8186 .69379 L .83497 .68642 L p .707 .577 .707 r
F P
0 g
s
.83497 .68642 m .83497 .6679 L .8186 .67526 L p .707 .577 .707 r
F P
0 g
s
.6747 .77107 m .6747 .73401 L .65365 .72756 L p .707 .577 .707 r
F P
0 g
s
.64105 .60448 m .64105 .5489 L .63816 .54036 L p .707 .577 .707 r
F P
0 g
s
.65365 .69085 m .65365 .67232 L .64105 .66444 L p .707 .577 .707 r
F P
0 g
s
.65365 .72756 m .65365 .76461 L .6747 .77107 L p .707 .577 .707 r
F P
0 g
s
.8186 .7305 m .8186 .76755 L .83497 .76019 L p .707 .577 .707 r
F P
0 g
s
.83497 .76019 m .83497 .72313 L .8186 .7305 L p .707 .577 .707 r
F P
0 g
s
.64105 .66444 m .64105 .68297 L .65365 .69085 L p .707 .577 .707 r
F P
0 g
s
.63816 .54036 m .63816 .59594 L .64105 .60448 L p .707 .577 .707 r
F P
0 g
s
.84205 .544 m .84205 .59958 L .83916 .59104 L p .707 .577 .707 r
F P
0 g
s
.83916 .59104 m .83916 .53545 L .84205 .544 L p .707 .577 .707 r
F P
0 g
s
.65365 .76461 m .65365 .72756 L .64105 .71967 L p .707 .577 .707 r
F P
0 g
s
.83497 .6679 m .83497 .68642 L .84206 .67806 L p .707 .577 .707 r
F P
0 g
s
.84206 .67806 m .84205 .65953 L .83497 .6679 L p .707 .577 .707 r
F P
0 g
s
.64105 .71967 m .64105 .75673 L .65365 .76461 L p .707 .577 .707 r
F P
0 g
s
.63816 .59594 m .63816 .54036 L .64524 .532 L p .707 .577 .707 r
F P
0 g
s
.64105 .68297 m .64105 .66444 L .63816 .6559 L p .707 .577 .707 r
F P
0 g
s
.83497 .72313 m .83497 .76019 L .84206 .75182 L p .707 .577 .707 r
F P
0 g
s
.84206 .75182 m .84206 .71477 L .83497 .72313 L p .707 .577 .707 r
F P
0 g
s
.63816 .6559 m .63816 .67442 L .64105 .68297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .532 m .64524 .58758 L .63816 .59594 L p .707 .577 .707 r
F P
0 g
s
.64105 .75673 m .64105 .71967 L .63816 .71113 L p .707 .577 .707 r
F P
0 g
s
.83916 .53545 m .83916 .59104 L .82657 .58315 L p .707 .577 .707 r
F P
0 g
s
.82657 .58315 m .82657 .52757 L .83916 .53545 L p .707 .577 .707 r
F P
0 g
s
.84205 .65953 m .84206 .67806 L .83916 .66952 L p .707 .577 .707 r
F P
0 g
s
.83916 .66952 m .83916 .65099 L .84205 .65953 L p .707 .577 .707 r
F P
0 g
s
.63816 .71113 m .63816 .74819 L .64105 .75673 L p .707 .577 .707 r
F P
0 g
s
.39032 .5883 m .39032 .53272 L .35915 .53082 L p .707 .577 .707 r
F P
0 g
s
.39032 .53272 m .39032 .5883 L .42216 .58752 L p .707 .577 .707 r
F P
0 g
s
.42216 .58752 m .42216 .53194 L .39032 .53272 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58758 m .64524 .532 L .66161 .52463 L p .707 .577 .707 r
F P
0 g
s
.42216 .53194 m .42216 .58752 L .45154 .58414 L p .707 .577 .707 r
F P
0 g
s
.45154 .58414 m .45154 .52856 L .42216 .53194 L p .707 .577 .707 r
F P
0 g
s
.63816 .67442 m .63816 .6559 L .64524 .64753 L p .707 .577 .707 r
F P
0 g
s
.35915 .5864 m .35915 .53082 L .33169 .52643 L p .707 .577 .707 r
F P
0 g
s
.35915 .53082 m .35915 .5864 L .39032 .5883 L p .707 .577 .707 r
F P
0 g
s
.84206 .71477 m .84206 .75182 L .83916 .74328 L p .707 .577 .707 r
F P
0 g
s
.83916 .74328 m .83916 .70622 L .84206 .71477 L p .707 .577 .707 r
F P
0 g
s
.64524 .64753 m .64524 .66606 L .63816 .67442 L p .707 .577 .707 r
F P
0 g
s
.45154 .52856 m .45154 .58414 L .47559 .57849 L p .707 .577 .707 r
F P
0 g
s
.47559 .57849 m .47559 .52291 L .45154 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52463 m .66161 .58021 L .64524 .58758 L p .707 .577 .707 r
F P
0 g
s
.82657 .52757 m .82657 .58315 L .80551 .5767 L p .707 .577 .707 r
F P
0 g
s
.80551 .5767 m .80551 .52111 L .82657 .52757 L p .707 .577 .707 r
F P
0 g
s
.63816 .74819 m .63816 .71113 L .64524 .70277 L p .707 .577 .707 r
F P
0 g
s
.33169 .52643 m .33169 .58201 L .35915 .5864 L p .707 .577 .707 r
F P
0 g
s
.83916 .65099 m .83916 .66952 L .82657 .66163 L p .707 .577 .707 r
F P
0 g
s
.82657 .66163 m .82657 .64311 L .83916 .65099 L p .707 .577 .707 r
F P
0 g
s
.33169 .58201 m .33169 .52643 L .31064 .51997 L p .707 .577 .707 r
F P
0 g
s
.66161 .58021 m .66161 .52463 L .68566 .51898 L p .707 .577 .707 r
F P
0 g
s
.64524 .70277 m .64524 .73982 L .63816 .74819 L p .707 .577 .707 r
F P
0 g
s
.39032 .66678 m .39032 .64825 L .35915 .64635 L p .707 .577 .707 r
F P
0 g
s
.39032 .64825 m .39032 .66678 L .42216 .666 L p .707 .577 .707 r
F P
0 g
s
.42216 .666 m .42216 .64748 L .39032 .64825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66606 m .64524 .64753 L .66161 .64016 L p .707 .577 .707 r
F P
0 g
s
.42216 .64748 m .42216 .666 L .45154 .66263 L p .707 .577 .707 r
F P
0 g
s
.45154 .66263 m .45154 .6441 L .42216 .64748 L p .707 .577 .707 r
F P
0 g
s
.47559 .52291 m .47559 .57849 L .49196 .57113 L p .707 .577 .707 r
F P
0 g
s
.49196 .57113 m .49196 .51554 L .47559 .52291 L p .707 .577 .707 r
F P
0 g
s
.35915 .64635 m .35915 .66488 L .39032 .66678 L p .707 .577 .707 r
F P
0 g
s
.83916 .70622 m .83916 .74328 L .82657 .73539 L p .707 .577 .707 r
F P
0 g
s
.82657 .73539 m .82657 .69834 L .83916 .70622 L p .707 .577 .707 r
F P
0 g
s
.31064 .51997 m .31064 .57555 L .33169 .58201 L p .707 .577 .707 r
F P
0 g
s
.35915 .66488 m .35915 .64635 L .33169 .64196 L p .707 .577 .707 r
F P
0 g
s
.66161 .64016 m .66161 .65869 L .64524 .66606 L p .707 .577 .707 r
F P
0 g
s
.80551 .52111 m .80551 .5767 L .77805 .5723 L p .707 .577 .707 r
F P
0 g
s
.77805 .5723 m .77805 .51672 L .80551 .52111 L p .707 .577 .707 r
F P
0 g
s
.33169 .64196 m .33169 .66049 L .35915 .66488 L p .707 .577 .707 r
F P
0 g
s
.68566 .51898 m .68566 .57456 L .66161 .58021 L p .707 .577 .707 r
F P
0 g
s
.31064 .57555 m .31064 .51997 L .29804 .51209 L p .707 .577 .707 r
F P
0 g
s
.45154 .6441 m .45154 .66263 L .47559 .65698 L p .707 .577 .707 r
F P
0 g
s
.47559 .65698 m .47559 .63845 L .45154 .6441 L p .707 .577 .707 r
F P
0 g
s
.39032 .74054 m .39032 .70349 L .35915 .70159 L p .707 .577 .707 r
F P
0 g
s
.39032 .70349 m .39032 .74054 L .42216 .73977 L p .707 .577 .707 r
F P
0 g
s
.42216 .73977 m .42216 .70271 L .39032 .70349 L p .707 .577 .707 r
F P
0 g
s
.68566 .57456 m .68566 .51898 L .71504 .5156 L p .707 .577 .707 r
F P
0 g
s
.64524 .73982 m .64524 .70277 L .66161 .6954 L p .707 .577 .707 r
F P
0 g
s
.42216 .70271 m .42216 .73977 L .45154 .73639 L p .707 .577 .707 r
F P
0 g
s
.45154 .73639 m .45154 .69933 L .42216 .70271 L p .707 .577 .707 r
F P
0 g
s
.82657 .64311 m .82657 .66163 L .80551 .65518 L p .707 .577 .707 r
F P
0 g
s
.80551 .65518 m .80551 .63665 L .82657 .64311 L p .707 .577 .707 r
F P
0 g
s
.35915 .73864 m .35915 .70159 L .33169 .6972 L p .707 .577 .707 r
F P
0 g
s
.35915 .70159 m .35915 .73864 L .39032 .74054 L p .707 .577 .707 r
F P
0 g
s
.33169 .66049 m .33169 .64196 L .31064 .63551 L p .707 .577 .707 r
F P
0 g
s
.77805 .51672 m .77805 .5723 L .74688 .5704 L p .707 .577 .707 r
F P
0 g
s
.74688 .5704 m .74688 .51482 L .77805 .51672 L p .707 .577 .707 r
F P
0 g
s
.31064 .63551 m .31064 .65404 L .33169 .66049 L p .707 .577 .707 r
F P
0 g
s
.66161 .6954 m .66161 .73245 L .64524 .73982 L p .707 .577 .707 r
F P
0 g
s
.66161 .65869 m .66161 .64016 L .68566 .63451 L p .707 .577 .707 r
F P
0 g
s
.29804 .51209 m .29804 .56767 L .31064 .57555 L p .707 .577 .707 r
F P
0 g
s
.71504 .57118 m .71504 .5156 L .74688 .51482 L p .707 .577 .707 r
F P
0 g
s
.71504 .5156 m .71504 .57118 L .68566 .57456 L p .707 .577 .707 r
F P
0 g
s
.49196 .51554 m .49196 .57113 L .49904 .56276 L p .707 .577 .707 r
F P
0 g
s
.49904 .56276 m .49904 .50718 L .49196 .51554 L p .707 .577 .707 r
F P
0 g
s
.45154 .69933 m .45154 .73639 L .47559 .73074 L p .707 .577 .707 r
F P
0 g
s
.47559 .73074 m .47559 .69368 L .45154 .69933 L p .707 .577 .707 r
F P
0 g
s
.74688 .51482 m .74688 .5704 L .71504 .57118 L p .707 .577 .707 r
F P
0 g
s
.33169 .6972 m .33169 .73425 L .35915 .73864 L p .707 .577 .707 r
F P
0 g
s
.82657 .69834 m .82657 .73539 L .80551 .72894 L p .707 .577 .707 r
F P
0 g
s
.80551 .72894 m .80551 .69189 L .82657 .69834 L p .707 .577 .707 r
F P
0 g
s
.68566 .63451 m .68566 .65304 L .66161 .65869 L p .707 .577 .707 r
F P
0 g
s
.47559 .63845 m .47559 .65698 L .49196 .64961 L p .707 .577 .707 r
F P
0 g
s
.49196 .64961 m .49196 .63108 L .47559 .63845 L p .707 .577 .707 r
F P
0 g
s
.33169 .73425 m .33169 .6972 L .31064 .69074 L p .707 .577 .707 r
F P
0 g
s
.80551 .63665 m .80551 .65518 L .77805 .65079 L p .707 .577 .707 r
F P
0 g
s
.77805 .65079 m .77805 .63226 L .80551 .63665 L p .707 .577 .707 r
F P
0 g
s
.29804 .56767 m .29804 .51209 L .29515 .50354 L p .707 .577 .707 r
F P
0 g
s
.66161 .73245 m .66161 .6954 L .68566 .68975 L p .707 .577 .707 r
F P
0 g
s
.31064 .65404 m .31064 .63551 L .29804 .62762 L p .707 .577 .707 r
F P
0 g
s
.31064 .69074 m .31064 .7278 L .33169 .73425 L p .707 .577 .707 r
F P
0 g
s
.68566 .65304 m .68566 .63451 L .71504 .63114 L p .707 .577 .707 r
F P
0 g
s
.47559 .69368 m .47559 .73074 L .49196 .72337 L p .707 .577 .707 r
F P
0 g
s
.49196 .72337 m .49196 .68631 L .47559 .69368 L p .707 .577 .707 r
F P
0 g
s
.29804 .62762 m .29804 .64615 L .31064 .65404 L p .707 .577 .707 r
F P
0 g
s
.71504 .63114 m .71504 .64966 L .68566 .65304 L p .707 .577 .707 r
F P
0 g
s
.68566 .68975 m .68566 .7268 L .66161 .73245 L p .707 .577 .707 r
F P
0 g
s
.80551 .69189 m .80551 .72894 L .77805 .72455 L p .707 .577 .707 r
F P
0 g
s
.77805 .72455 m .77805 .68749 L .80551 .69189 L p .707 .577 .707 r
F P
0 g
s
.29515 .50354 m .29515 .55913 L .29804 .56767 L p .707 .577 .707 r
F P
0 g
s
.77805 .63226 m .77805 .65079 L .74688 .64889 L p .707 .577 .707 r
F P
0 g
s
.74688 .64889 m .74688 .63036 L .77805 .63226 L p .707 .577 .707 r
F P
0 g
s
.49904 .50718 m .49904 .56276 L .49615 .55422 L p .707 .577 .707 r
F P
0 g
s
.49615 .55422 m .49615 .49864 L .49904 .50718 L p .707 .577 .707 r
F P
0 g
s
.31064 .7278 m .31064 .69074 L .29804 .68286 L p .707 .577 .707 r
F P
0 g
s
.71504 .64966 m .71504 .63114 L .74688 .63036 L p .707 .577 .707 r
F P
0 g
s
.49196 .63108 m .49196 .64961 L .49904 .64124 L p .707 .577 .707 r
F P
0 g
s
.49904 .64124 m .49904 .62272 L .49196 .63108 L p .707 .577 .707 r
F P
0 g
s
.74688 .63036 m .74688 .64889 L .71504 .64966 L p .707 .577 .707 r
F P
0 g
s
.68566 .7268 m .68566 .68975 L .71504 .68637 L p .707 .577 .707 r
F P
0 g
s
.29804 .68286 m .29804 .71991 L .31064 .7278 L p .707 .577 .707 r
F P
0 g
s
.29515 .55913 m .29515 .50354 L .30223 .49518 L p .707 .577 .707 r
F P
0 g
s
.77805 .68749 m .77805 .72455 L .74688 .72265 L p .707 .577 .707 r
F P
0 g
s
.74688 .72265 m .74688 .68559 L .77805 .68749 L p .707 .577 .707 r
F P
0 g
s
.29804 .64615 m .29804 .62762 L .29515 .61908 L p .707 .577 .707 r
F P
0 g
s
.71504 .68637 m .71504 .72342 L .68566 .7268 L p .707 .577 .707 r
F P
0 g
s
.71504 .72342 m .71504 .68637 L .74688 .68559 L p .707 .577 .707 r
F P
0 g
s
.49196 .68631 m .49196 .72337 L .49904 .71501 L p .707 .577 .707 r
F P
0 g
s
.49904 .71501 m .49904 .67795 L .49196 .68631 L p .707 .577 .707 r
F P
0 g
s
.29515 .61908 m .29515 .63761 L .29804 .64615 L p .707 .577 .707 r
F P
0 g
s
.74688 .68559 m .74688 .72265 L .71504 .72342 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .49518 m .30223 .55076 L .29515 .55913 L p .707 .577 .707 r
F P
0 g
s
.29804 .71991 m .29804 .68286 L .29515 .67432 L p .707 .577 .707 r
F P
0 g
s
.49615 .49864 m .49615 .55422 L .48356 .54634 L p .707 .577 .707 r
F P
0 g
s
.48356 .54634 m .48356 .49075 L .49615 .49864 L p .707 .577 .707 r
F P
0 g
s
.49904 .62272 m .49904 .64124 L .49615 .6327 L p .707 .577 .707 r
F P
0 g
s
.49615 .6327 m .49615 .61417 L .49904 .62272 L p .707 .577 .707 r
F P
0 g
s
.29515 .67432 m .29515 .71137 L .29804 .71991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55076 m .30223 .49518 L .3186 .48781 L p .707 .577 .707 r
F P
0 g
s
.29515 .63761 m .29515 .61908 L .30223 .61072 L p .707 .577 .707 r
F P
0 g
s
.49904 .67795 m .49904 .71501 L .49615 .70646 L p .707 .577 .707 r
F P
0 g
s
.49615 .70646 m .49615 .66941 L .49904 .67795 L p .707 .577 .707 r
F P
0 g
s
.30223 .61072 m .30223 .62924 L .29515 .63761 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .48781 m .3186 .54339 L .30223 .55076 L p .707 .577 .707 r
F P
0 g
s
.48356 .49075 m .48356 .54634 L .4625 .53988 L p .707 .577 .707 r
F P
0 g
s
.4625 .53988 m .4625 .4843 L .48356 .49075 L p .707 .577 .707 r
F P
0 g
s
.29515 .71137 m .29515 .67432 L .30223 .66595 L p .707 .577 .707 r
F P
0 g
s
.49615 .61417 m .49615 .6327 L .48356 .62482 L p .707 .577 .707 r
F P
0 g
s
.48356 .62482 m .48356 .60629 L .49615 .61417 L p .707 .577 .707 r
F P
0 g
s
.3186 .54339 m .3186 .48781 L .34265 .48216 L p .707 .577 .707 r
F P
0 g
s
.30223 .66595 m .30223 .70301 L .29515 .71137 L p .707 .577 .707 r
F P
0 g
s
.30223 .62924 m .30223 .61072 L .3186 .60335 L p .707 .577 .707 r
F P
0 g
s
.49615 .66941 m .49615 .70646 L .48356 .69858 L p .707 .577 .707 r
F P
0 g
s
.48356 .69858 m .48356 .66152 L .49615 .66941 L p .707 .577 .707 r
F P
0 g
s
.3186 .60335 m .3186 .62188 L .30223 .62924 L p .707 .577 .707 r
F P
0 g
s
.4625 .4843 m .4625 .53988 L .43504 .53549 L p .707 .577 .707 r
F P
0 g
s
.43504 .53549 m .43504 .47991 L .4625 .4843 L p .707 .577 .707 r
F P
0 g
s
.34265 .48216 m .34265 .53774 L .3186 .54339 L p .707 .577 .707 r
F P
0 g
s
.34265 .53774 m .34265 .48216 L .37203 .47878 L p .707 .577 .707 r
F P
0 g
s
.30223 .70301 m .30223 .66595 L .3186 .65858 L p .707 .577 .707 r
F P
0 g
s
.48356 .60629 m .48356 .62482 L .4625 .61836 L p .707 .577 .707 r
F P
0 g
s
.4625 .61836 m .4625 .59984 L .48356 .60629 L p .707 .577 .707 r
F P
0 g
s
.43504 .47991 m .43504 .53549 L .40387 .53359 L p .707 .577 .707 r
F P
0 g
s
.40387 .53359 m .40387 .47801 L .43504 .47991 L p .707 .577 .707 r
F P
0 g
s
.3186 .65858 m .3186 .69564 L .30223 .70301 L p .707 .577 .707 r
F P
0 g
s
.3186 .62188 m .3186 .60335 L .34265 .5977 L p .707 .577 .707 r
F P
0 g
s
.37203 .53437 m .37203 .47878 L .40387 .47801 L p .707 .577 .707 r
F P
0 g
s
.37203 .47878 m .37203 .53437 L .34265 .53774 L p .707 .577 .707 r
F P
0 g
s
.40387 .47801 m .40387 .53359 L .37203 .53437 L p .707 .577 .707 r
F P
0 g
s
.48356 .66152 m .48356 .69858 L .4625 .69212 L p .707 .577 .707 r
F P
0 g
s
.4625 .69212 m .4625 .65507 L .48356 .66152 L p .707 .577 .707 r
F P
0 g
s
.34265 .5977 m .34265 .61623 L .3186 .62188 L p .707 .577 .707 r
F P
0 g
s
.4625 .59984 m .4625 .61836 L .43504 .61397 L p .707 .577 .707 r
F P
0 g
s
.43504 .61397 m .43504 .59544 L .4625 .59984 L p .707 .577 .707 r
F P
0 g
s
.3186 .69564 m .3186 .65858 L .34265 .65293 L p .707 .577 .707 r
F P
0 g
s
.34265 .61623 m .34265 .5977 L .37203 .59432 L p .707 .577 .707 r
F P
0 g
s
.37203 .59432 m .37203 .61285 L .34265 .61623 L p .707 .577 .707 r
F P
0 g
s
.34265 .65293 m .34265 .68999 L .3186 .69564 L p .707 .577 .707 r
F P
0 g
s
.4625 .65507 m .4625 .69212 L .43504 .68773 L p .707 .577 .707 r
F P
0 g
s
.43504 .68773 m .43504 .65068 L .4625 .65507 L p .707 .577 .707 r
F P
0 g
s
.43504 .59544 m .43504 .61397 L .40387 .61207 L p .707 .577 .707 r
F P
0 g
s
.40387 .61207 m .40387 .59354 L .43504 .59544 L p .707 .577 .707 r
F P
0 g
s
.37203 .61285 m .37203 .59432 L .40387 .59354 L p .707 .577 .707 r
F P
0 g
s
.40387 .59354 m .40387 .61207 L .37203 .61285 L p .707 .577 .707 r
F P
0 g
s
.34265 .68999 m .34265 .65293 L .37203 .64955 L p .707 .577 .707 r
F P
0 g
s
.43504 .65068 m .43504 .68773 L .40387 .68583 L p .707 .577 .707 r
F P
0 g
s
.40387 .68583 m .40387 .64878 L .43504 .65068 L p .707 .577 .707 r
F P
0 g
s
.37203 .64955 m .37203 .68661 L .34265 .68999 L p .707 .577 .707 r
F P
0 g
s
.37203 .68661 m .37203 .64955 L .40387 .64878 L p .707 .577 .707 r
F P
0 g
s
.40387 .64878 m .40387 .68583 L .37203 .68661 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP06001gOol007Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`T000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001G
Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00003goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00IJEPP0
00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03
001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol00`00
FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
009JEPL000QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2
000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000]Ool0035oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;goo0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF0002FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUH0000B0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF2@0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF3P0015YF
00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000FUH005YF0P000eYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF6`00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH4000015YF0000000015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00=JEP800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07
FUH00`00FUH0000300000eYF000000040004FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEQP003ioo`00
;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP<0
00AJEP<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00<003Yoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP04001JEP000003FUH00`00FUH000020003FUH30002FUH01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP02FUH50000
15YF000000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF100000=JEP00FUH00UYF00<0
05YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH01000<Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
<Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF5`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP03FUH30004FUH00`00FUH000050003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH800000eYF001JEP05FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF200047oo20000eYF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH00004FUH000000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020002FUH01000FUIJEUYF
0P0067oo1@0015YF00D005YFFUIJEP0002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000M
Ool300000eYF001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@0
05YFFUIJEP8000Qoo`<001Moo`800003FUH0000002eoo`00<goo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUH0
05YF00<000AJEP04001JEUYFFUH20007Ool5000FOol5000]Ool003Ioo`D000AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P0015YF0`00
00=JEP00FUH00UYF0P001goo1@0057oo0P000UYF0`00;Goo000kOol80004FUH00`00FUIJEP07FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP00008000=JEP<000=JEP80
00Moo`D0011oo`@000AJEP03001JEP0002eoo`00@goo4@0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEPD00004FUH00000FUH20008Ool3000:Ool70003FUH00`00FUIJ
EP02FUH2000^Ool004Moo`T000=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000oOol8
0004FUH00`00FUIJEP02FUH400000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF2@0015YF00<005YFFUH0
0UYF2@001UYF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEPH0
00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD0009JEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000=JEPP000Aoo`04001JEUYF0005FUH40006FUH00`00FUIJEP09FUH4
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000`00<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P0015YF1P000Woo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF009JEPL000=JEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000^Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000
FUH000EJEP04001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH00`00FUIJ
EP0200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
0UYF5P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEPH001Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF000015YF00<005YF00000`006Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH3000NOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00FUH2000ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00
000HOol3000:Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P00
0UYF0`0057oo1@002goo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPH000Uoo`D000Aoo`P0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEP000080015oo`D0
00ioo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP000080011oo`<000eoo`D000AJEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF009JEPD000aoo`D000moo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEPP0021oo`H00003FUH005YF009JEP8002eoo`00;Goo
00D005YFFUIJEP0000EJEP04001JEUYFFUH80005Ool3000;Ool50005FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YFFUIJEPT0
019oo`D000EJEP<000=JEP8002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEQL000=JEP03
001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002moo`<000EJEP03
001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0039o
o`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02
FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000=o
o`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUIJEUYF
0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF100015YF00<005YF00002`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF0000
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP05001JEUYFFUH00003FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUH000080004FUH0
0`00FUIJEP02FUH9000oOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT0
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP040006FUH01000FUIJEUYF0P001Goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJ
EUYF200027oo1@0037oo1P0015YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH2000015YF001JEUYF1@000UYF00@005YF000005Qoo`00;7oo00<005YF000015YF10004Goo0`00
4goo0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000<005Yoo`00;7oo00<005YF00000UYF0P000eYF1@0087oo100000AJEP000000009J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP02FUH2001I
Ool002aoo`03001JEP0000<000EJEP04001JEUYFFUH8000:Ool>0005FUH01@00FUIJEP00FUH00P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP<005Moo`00
;7oo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000IJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=oo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF
FUIJEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30003Ool80003FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000=Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3000>Ool50004FUH01000FUIJ
EUYF0P00E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH00003000COol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH0
0003000COol600000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPD001ioo``000IJEP03001JEUYF00YJEP03001JEUYF00=JEPL0019oo`D0
00EJEP<000=JEP8005Aoo`00?Goo6@00;goo<P000eYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo002>Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001DOol008ioo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<005Aoo`00SWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002?Ool0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002B
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Moo`D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00W7oo2@0015YF00<005YFFUH00UYF
3P00HGoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .71715 m .59613 .66157 L .56496 .65967 L p .707 .577 .707 r
F P
0 g
s
.59613 .66157 m .59613 .71715 L .62796 .71638 L p .707 .577 .707 r
F P
0 g
s
.62796 .71638 m .62796 .66079 L .59613 .66157 L p .707 .577 .707 r
F P
0 g
s
.62796 .66079 m .62796 .71638 L .65734 .713 L p .707 .577 .707 r
F P
0 g
s
.65734 .713 m .65734 .65742 L .62796 .66079 L p .707 .577 .707 r
F P
0 g
s
.56496 .71525 m .56496 .65967 L .5375 .65528 L p .707 .577 .707 r
F P
0 g
s
.56496 .65967 m .56496 .71525 L .59613 .71715 L p .707 .577 .707 r
F P
0 g
s
.65734 .65742 m .65734 .713 L .6814 .70735 L p .707 .577 .707 r
F P
0 g
s
.6814 .70735 m .6814 .65177 L .65734 .65742 L p .707 .577 .707 r
F P
0 g
s
.5375 .65528 m .5375 .71086 L .56496 .71525 L p .707 .577 .707 r
F P
0 g
s
.5375 .71086 m .5375 .65528 L .51644 .64883 L p .707 .577 .707 r
F P
0 g
s
.59613 .79564 m .59613 .77711 L .56496 .77521 L p .707 .577 .707 r
F P
0 g
s
.59613 .77711 m .59613 .79564 L .62796 .79486 L p .707 .577 .707 r
F P
0 g
s
.62796 .79486 m .62796 .77633 L .59613 .77711 L p .707 .577 .707 r
F P
0 g
s
.62796 .77633 m .62796 .79486 L .65735 .79148 L p .707 .577 .707 r
F P
0 g
s
.65735 .79148 m .65735 .77295 L .62796 .77633 L p .707 .577 .707 r
F P
0 g
s
.6814 .65177 m .6814 .70735 L .69777 .69998 L p .707 .577 .707 r
F P
0 g
s
.69777 .69998 m .69777 .6444 L .6814 .65177 L p .707 .577 .707 r
F P
0 g
s
.56496 .77521 m .56496 .79373 L .59613 .79564 L p .707 .577 .707 r
F P
0 g
s
.51644 .64883 m .51644 .70441 L .5375 .71086 L p .707 .577 .707 r
F P
0 g
s
.56496 .79373 m .56496 .77521 L .5375 .77082 L p .707 .577 .707 r
F P
0 g
s
.5375 .77082 m .5375 .78934 L .56496 .79373 L p .707 .577 .707 r
F P
0 g
s
.51644 .70441 m .51644 .64883 L .50385 .64094 L p .707 .577 .707 r
F P
0 g
s
.65735 .77295 m .65735 .79148 L .6814 .78583 L p .707 .577 .707 r
F P
0 g
s
.6814 .78583 m .6814 .7673 L .65735 .77295 L p .707 .577 .707 r
F P
0 g
s
.59613 .8694 m .59613 .83234 L .56496 .83044 L p .707 .577 .707 r
F P
0 g
s
.59613 .83234 m .59613 .8694 L .62796 .86862 L p .707 .577 .707 r
F P
0 g
s
.62796 .86862 m .62796 .83156 L .59613 .83234 L p .707 .577 .707 r
F P
0 g
s
.62796 .83156 m .62796 .86862 L .65735 .86524 L p .707 .577 .707 r
F P
0 g
s
.65735 .86524 m .65735 .82819 L .62796 .83156 L p .707 .577 .707 r
F P
0 g
s
.56496 .8675 m .56496 .83044 L .5375 .82605 L p .707 .577 .707 r
F P
0 g
s
.56496 .83044 m .56496 .8675 L .59613 .8694 L p .707 .577 .707 r
F P
0 g
s
.5375 .78934 m .5375 .77082 L .51644 .76436 L p .707 .577 .707 r
F P
0 g
s
.51644 .76436 m .51644 .78289 L .5375 .78934 L p .707 .577 .707 r
F P
0 g
s
.50385 .64094 m .50385 .69652 L .51644 .70441 L p .707 .577 .707 r
F P
0 g
s
.69777 .6444 m .69777 .69998 L .70485 .69162 L p .707 .577 .707 r
F P
0 g
s
.70485 .69162 m .70485 .63603 L .69777 .6444 L p .707 .577 .707 r
F P
0 g
s
.65735 .82819 m .65735 .86524 L .6814 .85959 L p .707 .577 .707 r
F P
0 g
s
.6814 .85959 m .6814 .82254 L .65735 .82819 L p .707 .577 .707 r
F P
0 g
s
.5375 .82605 m .5375 .8631 L .56496 .8675 L p .707 .577 .707 r
F P
0 g
s
.6814 .7673 m .6814 .78583 L .69777 .77846 L p .707 .577 .707 r
F P
0 g
s
.69777 .77846 m .69777 .75993 L .6814 .7673 L p .707 .577 .707 r
F P
0 g
s
.5375 .8631 m .5375 .82605 L .51644 .81959 L p .707 .577 .707 r
F P
0 g
s
.50385 .69652 m .50385 .64094 L .50095 .6324 L p .707 .577 .707 r
F P
0 g
s
.51644 .78289 m .51644 .76436 L .50385 .75648 L p .707 .577 .707 r
F P
0 g
s
.51644 .81959 m .51644 .85665 L .5375 .8631 L p .707 .577 .707 r
F P
0 g
s
.6814 .82254 m .6814 .85959 L .69777 .85222 L p .707 .577 .707 r
F P
0 g
s
.69777 .85222 m .69777 .81517 L .6814 .82254 L p .707 .577 .707 r
F P
0 g
s
.50385 .75648 m .50385 .775 L .51644 .78289 L p .707 .577 .707 r
F P
0 g
s
.50095 .6324 m .50095 .68798 L .50385 .69652 L p .707 .577 .707 r
F P
0 g
s
.70485 .63603 m .70485 .69162 L .70195 .68307 L p .707 .577 .707 r
F P
0 g
s
.70195 .68307 m .70195 .62749 L .70485 .63603 L p .707 .577 .707 r
F P
0 g
s
.51644 .85665 m .51644 .81959 L .50385 .81171 L p .707 .577 .707 r
F P
0 g
s
.69777 .75993 m .69777 .77846 L .70485 .7701 L p .707 .577 .707 r
F P
0 g
s
.70485 .7701 m .70485 .75157 L .69777 .75993 L p .707 .577 .707 r
F P
0 g
s
.50385 .81171 m .50385 .84877 L .51644 .85665 L p .707 .577 .707 r
F P
0 g
s
.50095 .68798 m .50095 .6324 L .50804 .62403 L p .707 .577 .707 r
F P
0 g
s
.50385 .775 m .50385 .75648 L .50095 .74794 L p .707 .577 .707 r
F P
0 g
s
.69777 .81517 m .69777 .85222 L .70485 .84386 L p .707 .577 .707 r
F P
0 g
s
.70485 .84386 m .70485 .8068 L .69777 .81517 L p .707 .577 .707 r
F P
0 g
s
.50095 .74794 m .50095 .76646 L .50385 .775 L p .707 .577 .707 r
F P
0 g
s
.49044 .83252 m .49044 .33063 L .44643 .32795 L p .707 .577 .707 r
F P
0 g
s
.50804 .62403 m .50804 .67962 L .50095 .68798 L p .707 .577 .707 r
F P
0 g
s
.50385 .84877 m .50385 .81171 L .50095 .80317 L p .707 .577 .707 r
F P
0 g
s
.50095 .80317 m .50095 .84022 L .50385 .84877 L p .707 .577 .707 r
F P
0 g
s
.50804 .67962 m .50804 .62403 L .5244 .61667 L p .707 .577 .707 r
F P
0 g
s
.50095 .76646 m .50095 .74794 L .50804 .73957 L p .707 .577 .707 r
F P
0 g
s
.50804 .73957 m .50804 .7581 L .50095 .76646 L p .707 .577 .707 r
F P
0 g
s
.5244 .61667 m .5244 .67225 L .50804 .67962 L p .707 .577 .707 r
F P
0 g
s
.50095 .84022 m .50095 .80317 L .50804 .7948 L p .707 .577 .707 r
F P
0 g
s
.50804 .7948 m .50804 .83186 L .50095 .84022 L p .707 .577 .707 r
F P
0 g
s
.50804 .7581 m .50804 .73957 L .5244 .7322 L p .707 .577 .707 r
F P
0 g
s
.5244 .7322 m .5244 .75073 L .50804 .7581 L p .707 .577 .707 r
F P
0 g
s
.50804 .83186 m .50804 .7948 L .5244 .78744 L p .707 .577 .707 r
F P
0 g
s
.5244 .78744 m .5244 .82449 L .50804 .83186 L p .707 .577 .707 r
F P
0 g
s
.5244 .75073 m .5244 .7322 L .54846 .72655 L p .707 .577 .707 r
F P
0 g
s
.54846 .72655 m .54846 .74508 L .5244 .75073 L p .707 .577 .707 r
F P
0 g
s
.5244 .82449 m .5244 .78744 L .54846 .78179 L p .707 .577 .707 r
F P
0 g
s
.54846 .78179 m .54846 .81884 L .5244 .82449 L p .707 .577 .707 r
F P
0 g
s
.49044 .33063 m .49044 .83252 L .53538 .83142 L p .707 .577 .707 r
F P
0 g
s
.5244 .67225 m .5244 .61667 L .54846 .61102 L p .707 .577 .707 r
F P
0 g
s
.54846 .61102 m .54846 .6666 L .5244 .67225 L p .707 .577 .707 r
F P
0 g
s
.53538 .83142 m .53538 .32954 L .49044 .33063 L p .707 .577 .707 r
F P
0 g
s
.54846 .6666 m .54846 .61102 L .57784 .60764 L p .707 .577 .707 r
F P
0 g
s
.57784 .60764 m .57784 .66322 L .54846 .6666 L p .707 .577 .707 r
F P
0 g
s
.54846 .74508 m .54846 .72655 L .57784 .72317 L p .707 .577 .707 r
F P
0 g
s
.57784 .72317 m .57784 .7417 L .54846 .74508 L p .707 .577 .707 r
F P
0 g
s
.54846 .81884 m .54846 .78179 L .57784 .77841 L p .707 .577 .707 r
F P
0 g
s
.57784 .77841 m .57784 .81546 L .54846 .81884 L p .707 .577 .707 r
F P
0 g
s
.53538 .32954 m .53538 .83142 L .57686 .82665 L p .707 .577 .707 r
F P
0 g
s
.57686 .82665 m .57686 .32476 L .53538 .32954 L p .707 .577 .707 r
F P
0 g
s
.70195 .62749 m .70195 .68307 L .68936 .67519 L p .707 .577 .707 r
F P
0 g
s
.68936 .67519 m .68936 .61961 L .70195 .62749 L p .707 .577 .707 r
F P
0 g
s
.44643 .82984 m .44643 .32795 L .40766 .32175 L p .707 .577 .707 r
F P
0 g
s
.44643 .32795 m .44643 .82984 L .49044 .83252 L p .707 .577 .707 r
F P
0 g
s
.70485 .75157 m .70485 .7701 L .70195 .76156 L p .707 .577 .707 r
F P
0 g
s
.70195 .76156 m .70195 .74303 L .70485 .75157 L p .707 .577 .707 r
F P
0 g
s
.25312 .68034 m .25312 .62476 L .22195 .62286 L p .707 .577 .707 r
F P
0 g
s
.25312 .62476 m .25312 .68034 L .28495 .67956 L p .707 .577 .707 r
F P
0 g
s
.28495 .67956 m .28495 .62398 L .25312 .62476 L p .707 .577 .707 r
F P
0 g
s
.57784 .66322 m .57784 .60764 L .60968 .60686 L p .707 .577 .707 r
F P
0 g
s
.60968 .60686 m .60968 .66244 L .57784 .66322 L p .707 .577 .707 r
F P
0 g
s
.57784 .7417 m .57784 .72317 L .60968 .7224 L p .707 .577 .707 r
F P
0 g
s
.60968 .7224 m .60968 .74092 L .57784 .7417 L p .707 .577 .707 r
F P
0 g
s
.64085 .77953 m .64085 .81659 L .60968 .81469 L p .707 .577 .707 r
F P
0 g
s
.60968 .81469 m .60968 .77763 L .64085 .77953 L p .707 .577 .707 r
F P
0 g
s
.57784 .81546 m .57784 .77841 L .60968 .77763 L p .707 .577 .707 r
F P
0 g
s
.60968 .77763 m .60968 .81469 L .57784 .81546 L p .707 .577 .707 r
F P
0 g
s
.57686 .32476 m .57686 .82665 L .61082 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .60876 m .64085 .66434 L .60968 .66244 L p .707 .577 .707 r
F P
0 g
s
.60968 .66244 m .60968 .60686 L .64085 .60876 L p .707 .577 .707 r
F P
0 g
s
.64085 .7243 m .64085 .74283 L .60968 .74092 L p .707 .577 .707 r
F P
0 g
s
.60968 .74092 m .60968 .7224 L .64085 .7243 L p .707 .577 .707 r
F P
0 g
s
.61082 .81868 m .61082 .31679 L .57686 .32476 L p .707 .577 .707 r
F P
0 g
s
.28495 .62398 m .28495 .67956 L .31434 .67618 L p .707 .577 .707 r
F P
0 g
s
.31434 .67618 m .31434 .6206 L .28495 .62398 L p .707 .577 .707 r
F P
0 g
s
.22195 .67844 m .22195 .62286 L .19449 .61846 L p .707 .577 .707 r
F P
0 g
s
.22195 .62286 m .22195 .67844 L .25312 .68034 L p .707 .577 .707 r
F P
0 g
s
.70485 .8068 m .70485 .84386 L .70195 .83532 L p .707 .577 .707 r
F P
0 g
s
.70195 .83532 m .70195 .79826 L .70485 .8068 L p .707 .577 .707 r
F P
0 g
s
.40766 .82364 m .40766 .32175 L .37794 .31264 L p .707 .577 .707 r
F P
0 g
s
.40766 .32175 m .40766 .82364 L .44643 .82984 L p .707 .577 .707 r
F P
0 g
s
.31434 .6206 m .31434 .67618 L .33839 .67053 L p .707 .577 .707 r
F P
0 g
s
.33839 .67053 m .33839 .61495 L .31434 .6206 L p .707 .577 .707 r
F P
0 g
s
.68936 .61961 m .68936 .67519 L .66831 .66874 L p .707 .577 .707 r
F P
0 g
s
.66831 .66874 m .66831 .61315 L .68936 .61961 L p .707 .577 .707 r
F P
0 g
s
.19449 .61846 m .19449 .67405 L .22195 .67844 L p .707 .577 .707 r
F P
0 g
s
.70195 .74303 m .70195 .76156 L .68936 .75367 L p .707 .577 .707 r
F P
0 g
s
.68936 .75367 m .68936 .73514 L .70195 .74303 L p .707 .577 .707 r
F P
0 g
s
.19449 .67405 m .19449 .61846 L .17343 .61201 L p .707 .577 .707 r
F P
0 g
s
.61082 .31679 m .61082 .81868 L .63393 .80828 L p .707 .577 .707 r
F P
0 g
s
.63393 .80828 m .63393 .30639 L .61082 .31679 L p .707 .577 .707 r
F P
0 g
s
.25312 .75882 m .25312 .74029 L .22195 .73839 L p .707 .577 .707 r
F P
0 g
s
.25312 .74029 m .25312 .75882 L .28495 .75804 L p .707 .577 .707 r
F P
0 g
s
.28495 .75804 m .28495 .73952 L .25312 .74029 L p .707 .577 .707 r
F P
0 g
s
.28495 .73952 m .28495 .75804 L .31434 .75466 L p .707 .577 .707 r
F P
0 g
s
.31434 .75466 m .31434 .73614 L .28495 .73952 L p .707 .577 .707 r
F P
0 g
s
.33839 .61495 m .33839 .67053 L .35476 .66317 L p .707 .577 .707 r
F P
0 g
s
.35476 .66317 m .35476 .60758 L .33839 .61495 L p .707 .577 .707 r
F P
0 g
s
.22195 .73839 m .22195 .75692 L .25312 .75882 L p .707 .577 .707 r
F P
0 g
s
.70195 .79826 m .70195 .83532 L .68936 .82743 L p .707 .577 .707 r
F P
0 g
s
.68936 .82743 m .68936 .79038 L .70195 .79826 L p .707 .577 .707 r
F P
0 g
s
.17343 .61201 m .17343 .66759 L .19449 .67405 L p .707 .577 .707 r
F P
0 g
s
.22195 .75692 m .22195 .73839 L .19449 .734 L p .707 .577 .707 r
F P
0 g
s
.66831 .61315 m .66831 .66874 L .64085 .66434 L p .707 .577 .707 r
F P
0 g
s
.64085 .66434 m .64085 .60876 L .66831 .61315 L p .707 .577 .707 r
F P
0 g
s
.19449 .734 m .19449 .75253 L .22195 .75692 L p .707 .577 .707 r
F P
0 g
s
.17343 .66759 m .17343 .61201 L .16084 .60413 L p .707 .577 .707 r
F P
0 g
s
.37794 .81452 m .37794 .31264 L .36016 .30151 L p .707 .577 .707 r
F P
0 g
s
.37794 .31264 m .37794 .81452 L .40766 .82364 L p .707 .577 .707 r
F P
0 g
s
.31434 .73614 m .31434 .75466 L .33839 .74901 L p .707 .577 .707 r
F P
0 g
s
.33839 .74901 m .33839 .73049 L .31434 .73614 L p .707 .577 .707 r
F P
0 g
s
.25312 .83258 m .25312 .79553 L .22195 .79363 L p .707 .577 .707 r
F P
0 g
s
.25312 .79553 m .25312 .83258 L .28495 .8318 L p .707 .577 .707 r
F P
0 g
s
.28495 .8318 m .28495 .79475 L .25312 .79553 L p .707 .577 .707 r
F P
0 g
s
.28495 .79475 m .28495 .8318 L .31434 .82843 L p .707 .577 .707 r
F P
0 g
s
.31434 .82843 m .31434 .79137 L .28495 .79475 L p .707 .577 .707 r
F P
0 g
s
.68936 .73514 m .68936 .75367 L .66831 .74722 L p .707 .577 .707 r
F P
0 g
s
.66831 .74722 m .66831 .72869 L .68936 .73514 L p .707 .577 .707 r
F P
0 g
s
.22195 .83068 m .22195 .79363 L .19449 .78923 L p .707 .577 .707 r
F P
0 g
s
.22195 .79363 m .22195 .83068 L .25312 .83258 L p .707 .577 .707 r
F P
0 g
s
.19449 .75253 m .19449 .734 L .17343 .72755 L p .707 .577 .707 r
F P
0 g
s
.17343 .72755 m .17343 .74607 L .19449 .75253 L p .707 .577 .707 r
F P
0 g
s
.16084 .60413 m .16084 .65971 L .17343 .66759 L p .707 .577 .707 r
F P
0 g
s
.35476 .60758 m .35476 .66317 L .36184 .6548 L p .707 .577 .707 r
F P
0 g
s
.36184 .6548 m .36184 .59922 L .35476 .60758 L p .707 .577 .707 r
F P
0 g
s
.31434 .79137 m .31434 .82843 L .33839 .82278 L p .707 .577 .707 r
F P
0 g
s
.33839 .82278 m .33839 .78572 L .31434 .79137 L p .707 .577 .707 r
F P
0 g
s
.19449 .78923 m .19449 .82629 L .22195 .83068 L p .707 .577 .707 r
F P
0 g
s
.68936 .79038 m .68936 .82743 L .66831 .82098 L p .707 .577 .707 r
F P
0 g
s
.66831 .82098 m .66831 .78392 L .68936 .79038 L p .707 .577 .707 r
F P
0 g
s
.33839 .73049 m .33839 .74901 L .35476 .74165 L p .707 .577 .707 r
F P
0 g
s
.35476 .74165 m .35476 .72312 L .33839 .73049 L p .707 .577 .707 r
F P
0 g
s
.66831 .72869 m .66831 .74722 L .64085 .74283 L p .707 .577 .707 r
F P
0 g
s
.64085 .74283 m .64085 .7243 L .66831 .72869 L p .707 .577 .707 r
F P
0 g
s
.64085 .81659 m .64085 .77953 L .66831 .78392 L p .707 .577 .707 r
F P
0 g
s
.63393 .30639 m .63393 .80828 L .64393 .79647 L p .707 .577 .707 r
F P
0 g
s
.64393 .79647 m .64393 .29458 L .63393 .30639 L p .707 .577 .707 r
F P
0 g
s
.19449 .82629 m .19449 .78923 L .17343 .78278 L p .707 .577 .707 r
F P
0 g
s
.16084 .65971 m .16084 .60413 L .15794 .59558 L p .707 .577 .707 r
F P
0 g
s
.17343 .74607 m .17343 .72755 L .16084 .71966 L p .707 .577 .707 r
F P
0 g
s
.17343 .78278 m .17343 .81983 L .19449 .82629 L p .707 .577 .707 r
F P
0 g
s
.33839 .78572 m .33839 .82278 L .35476 .81541 L p .707 .577 .707 r
F P
0 g
s
.35476 .81541 m .35476 .77835 L .33839 .78572 L p .707 .577 .707 r
F P
0 g
s
.16084 .71966 m .16084 .73819 L .17343 .74607 L p .707 .577 .707 r
F P
0 g
s
.36184 .59922 m .36184 .6548 L .35894 .64626 L p .707 .577 .707 r
F P
0 g
s
.35894 .64626 m .35894 .59068 L .36184 .59922 L p .707 .577 .707 r
F P
0 g
s
.35476 .72312 m .35476 .74165 L .36184 .73328 L p .707 .577 .707 r
F P
0 g
s
.36184 .73328 m .36184 .71476 L .35476 .72312 L p .707 .577 .707 r
F P
0 g
s
.35476 .77835 m .35476 .81541 L .36184 .80704 L p .707 .577 .707 r
F P
0 g
s
.36184 .80704 m .36184 .76999 L .35476 .77835 L p .707 .577 .707 r
F P
0 g
s
.35894 .59068 m .35894 .64626 L .34635 .63837 L p .707 .577 .707 r
F P
0 g
s
.34635 .63837 m .34635 .58279 L .35894 .59068 L p .707 .577 .707 r
F P
0 g
s
.36184 .71476 m .36184 .73328 L .35894 .72474 L p .707 .577 .707 r
F P
0 g
s
.35894 .72474 m .35894 .70621 L .36184 .71476 L p .707 .577 .707 r
F P
0 g
s
.36184 .76999 m .36184 .80704 L .35894 .7985 L p .707 .577 .707 r
F P
0 g
s
.35894 .7985 m .35894 .76145 L .36184 .76999 L p .707 .577 .707 r
F P
0 g
s
.36016 .80339 m .36016 .30151 L .35607 .28945 L p .707 .577 .707 r
F P
0 g
s
.36016 .30151 m .36016 .80339 L .37794 .81452 L p .707 .577 .707 r
F P
0 g
s
.66831 .78392 m .66831 .82098 L .64085 .81659 L p .707 .577 .707 r
F P
0 g
s
.15794 .59558 m .15794 .65117 L .16084 .65971 L p .707 .577 .707 r
F P
0 g
s
.17343 .81983 m .17343 .78278 L .16084 .7749 L p .707 .577 .707 r
F P
0 g
s
.16084 .7749 m .16084 .81195 L .17343 .81983 L p .707 .577 .707 r
F P
0 g
s
.15794 .65117 m .15794 .59558 L .16503 .58722 L p .707 .577 .707 r
F P
0 g
s
.16084 .73819 m .16084 .71966 L .15794 .71112 L p .707 .577 .707 r
F P
0 g
s
.64393 .29458 m .64393 .79647 L .63984 .78441 L p .707 .577 .707 r
F P
0 g
s
.63984 .78441 m .63984 .28252 L .64393 .29458 L p .707 .577 .707 r
F P
0 g
s
.15794 .71112 m .15794 .72965 L .16084 .73819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .58722 m .16503 .6428 L .15794 .65117 L p .707 .577 .707 r
F P
0 g
s
.16084 .81195 m .16084 .7749 L .15794 .76635 L p .707 .577 .707 r
F P
0 g
s
.35894 .70621 m .35894 .72474 L .34635 .71686 L p .707 .577 .707 r
F P
0 g
s
.34635 .71686 m .34635 .69833 L .35894 .70621 L p .707 .577 .707 r
F P
0 g
s
.35894 .76145 m .35894 .7985 L .34635 .79062 L p .707 .577 .707 r
F P
0 g
s
.34635 .79062 m .34635 .75356 L .35894 .76145 L p .707 .577 .707 r
F P
0 g
s
.35607 .28945 m .35607 .79133 L .36016 .80339 L p .707 .577 .707 r
F P
0 g
s
.35607 .79133 m .35607 .28945 L .36607 .27764 L p .707 .577 .707 r
F P
0 g
s
.15794 .76635 m .15794 .80341 L .16084 .81195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .6428 m .16503 .58722 L .1814 .57985 L p .707 .577 .707 r
F P
0 g
s
.15794 .72965 m .15794 .71112 L .16503 .70276 L p .707 .577 .707 r
F P
0 g
s
.16503 .70276 m .16503 .72128 L .15794 .72965 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .57985 m .1814 .63543 L .16503 .6428 L p .707 .577 .707 r
F P
0 g
s
.34635 .58279 m .34635 .63837 L .3253 .63192 L p .707 .577 .707 r
F P
0 g
s
.3253 .63192 m .3253 .57634 L .34635 .58279 L p .707 .577 .707 r
F P
0 g
s
.15794 .80341 m .15794 .76635 L .16503 .75799 L p .707 .577 .707 r
F P
0 g
s
.63984 .28252 m .63984 .78441 L .62206 .77328 L p .707 .577 .707 r
F P
0 g
s
.62206 .77328 m .62206 .27139 L .63984 .28252 L p .707 .577 .707 r
F P
0 g
s
.1814 .63543 m .1814 .57985 L .20545 .5742 L p .707 .577 .707 r
F P
0 g
s
.16503 .75799 m .16503 .79504 L .15794 .80341 L p .707 .577 .707 r
F P
0 g
s
.16503 .72128 m .16503 .70276 L .1814 .69539 L p .707 .577 .707 r
F P
0 g
s
.36607 .77953 m .36607 .27764 L .38918 .26724 L p .707 .577 .707 r
F P
0 g
s
.36607 .27764 m .36607 .77953 L .35607 .79133 L p .707 .577 .707 r
F P
0 g
s
.1814 .69539 m .1814 .71392 L .16503 .72128 L p .707 .577 .707 r
F P
0 g
s
.3253 .57634 m .3253 .63192 L .29784 .62753 L p .707 .577 .707 r
F P
0 g
s
.29784 .62753 m .29784 .57195 L .3253 .57634 L p .707 .577 .707 r
F P
0 g
s
.20545 .5742 m .20545 .62978 L .1814 .63543 L p .707 .577 .707 r
F P
0 g
s
.20545 .62978 m .20545 .5742 L .23483 .57082 L p .707 .577 .707 r
F P
0 g
s
.16503 .79504 m .16503 .75799 L .1814 .75062 L p .707 .577 .707 r
F P
0 g
s
.34635 .69833 m .34635 .71686 L .3253 .7104 L p .707 .577 .707 r
F P
0 g
s
.3253 .7104 m .3253 .69187 L .34635 .69833 L p .707 .577 .707 r
F P
0 g
s
.29784 .57195 m .29784 .62753 L .26667 .62563 L p .707 .577 .707 r
F P
0 g
s
.26667 .62563 m .26667 .57005 L .29784 .57195 L p .707 .577 .707 r
F P
0 g
s
.1814 .75062 m .1814 .78768 L .16503 .79504 L p .707 .577 .707 r
F P
0 g
s
.1814 .71392 m .1814 .69539 L .20545 .68974 L p .707 .577 .707 r
F P
0 g
s
.23483 .6264 m .23483 .57082 L .26667 .57005 L p .707 .577 .707 r
F P
0 g
s
.23483 .57082 m .23483 .6264 L .20545 .62978 L p .707 .577 .707 r
F P
0 g
s
.62206 .27139 m .62206 .77328 L .59233 .76417 L p .707 .577 .707 r
F P
0 g
s
.59233 .76417 m .59233 .26228 L .62206 .27139 L p .707 .577 .707 r
F P
0 g
s
.26667 .57005 m .26667 .62563 L .23483 .6264 L p .707 .577 .707 r
F P
0 g
s
.34635 .75356 m .34635 .79062 L .3253 .78416 L p .707 .577 .707 r
F P
0 g
s
.3253 .78416 m .3253 .74711 L .34635 .75356 L p .707 .577 .707 r
F P
0 g
s
.73333 .62512 m .73333 .56953 L .70216 .56763 L p .707 .577 .707 r
F P
0 g
s
.73333 .56953 m .73333 .62512 L .76517 .62434 L p .707 .577 .707 r
F P
0 g
s
.76517 .62434 m .76517 .56876 L .73333 .56953 L p .707 .577 .707 r
F P
0 g
s
.20545 .68974 m .20545 .70827 L .1814 .71392 L p .707 .577 .707 r
F P
0 g
s
.76517 .56876 m .76517 .62434 L .79455 .62096 L p .707 .577 .707 r
F P
0 g
s
.79455 .62096 m .79455 .56538 L .76517 .56876 L p .707 .577 .707 r
F P
0 g
s
.70216 .62322 m .70216 .56763 L .6747 .56324 L p .707 .577 .707 r
F P
0 g
s
.70216 .56763 m .70216 .62322 L .73333 .62512 L p .707 .577 .707 r
F P
0 g
s
.3253 .69187 m .3253 .7104 L .29784 .70601 L p .707 .577 .707 r
F P
0 g
s
.29784 .70601 m .29784 .68748 L .3253 .69187 L p .707 .577 .707 r
F P
0 g
s
.1814 .78768 m .1814 .75062 L .20545 .74497 L p .707 .577 .707 r
F P
0 g
s
.38918 .26724 m .38918 .76912 L .36607 .77953 L p .707 .577 .707 r
F P
0 g
s
.38918 .76912 m .38918 .26724 L .42314 .25926 L p .707 .577 .707 r
F P
0 g
s
.79455 .56538 m .79455 .62096 L .8186 .61531 L p .707 .577 .707 r
F P
0 g
s
.8186 .61531 m .8186 .55973 L .79455 .56538 L p .707 .577 .707 r
F P
0 g
s
.20545 .70827 m .20545 .68974 L .23483 .68636 L p .707 .577 .707 r
F P
0 g
s
.23483 .68636 m .23483 .70489 L .20545 .70827 L p .707 .577 .707 r
F P
0 g
s
.20545 .74497 m .20545 .78203 L .1814 .78768 L p .707 .577 .707 r
F P
0 g
s
.6747 .56324 m .6747 .61882 L .70216 .62322 L p .707 .577 .707 r
F P
0 g
s
.6747 .61882 m .6747 .56324 L .65365 .55679 L p .707 .577 .707 r
F P
0 g
s
.3253 .74711 m .3253 .78416 L .29784 .77977 L p .707 .577 .707 r
F P
0 g
s
.29784 .77977 m .29784 .74272 L .3253 .74711 L p .707 .577 .707 r
F P
0 g
s
.29784 .68748 m .29784 .70601 L .26667 .70411 L p .707 .577 .707 r
F P
0 g
s
.26667 .70411 m .26667 .68558 L .29784 .68748 L p .707 .577 .707 r
F P
0 g
s
.23483 .70489 m .23483 .68636 L .26667 .68558 L p .707 .577 .707 r
F P
0 g
s
.59233 .26228 m .59233 .76417 L .55357 .75796 L p .707 .577 .707 r
F P
0 g
s
.55357 .75796 m .55357 .25608 L .59233 .26228 L p .707 .577 .707 r
F P
0 g
s
.26667 .68558 m .26667 .70411 L .23483 .70489 L p .707 .577 .707 r
F P
0 g
s
.20545 .78203 m .20545 .74497 L .23483 .74159 L p .707 .577 .707 r
F P
0 g
s
.73333 .7036 m .73333 .68507 L .70216 .68317 L p .707 .577 .707 r
F P
0 g
s
.73333 .68507 m .73333 .7036 L .76517 .70282 L p .707 .577 .707 r
F P
0 g
s
.76517 .70282 m .76517 .68429 L .73333 .68507 L p .707 .577 .707 r
F P
0 g
s
.76517 .68429 m .76517 .70282 L .79455 .69944 L p .707 .577 .707 r
F P
0 g
s
.79455 .69944 m .79455 .68091 L .76517 .68429 L p .707 .577 .707 r
F P
0 g
s
.8186 .55973 m .8186 .61531 L .83497 .60794 L p .707 .577 .707 r
F P
0 g
s
.83497 .60794 m .83497 .55236 L .8186 .55973 L p .707 .577 .707 r
F P
0 g
s
.70216 .68317 m .70216 .7017 L .73333 .7036 L p .707 .577 .707 r
F P
0 g
s
.65365 .55679 m .65365 .61237 L .6747 .61882 L p .707 .577 .707 r
F P
0 g
s
.29784 .74272 m .29784 .77977 L .26667 .77787 L p .707 .577 .707 r
F P
0 g
s
.26667 .77787 m .26667 .74082 L .29784 .74272 L p .707 .577 .707 r
F P
0 g
s
.70216 .7017 m .70216 .68317 L .6747 .67878 L p .707 .577 .707 r
F P
0 g
s
.42314 .76115 m .42314 .25926 L .46462 .25449 L p .707 .577 .707 r
F P
0 g
s
.42314 .25926 m .42314 .76115 L .38918 .76912 L p .707 .577 .707 r
F P
0 g
s
.23483 .74159 m .23483 .77865 L .20545 .78203 L p .707 .577 .707 r
F P
0 g
s
.23483 .77865 m .23483 .74159 L .26667 .74082 L p .707 .577 .707 r
F P
0 g
s
.6747 .67878 m .6747 .6973 L .70216 .7017 L p .707 .577 .707 r
F P
0 g
s
.26667 .74082 m .26667 .77787 L .23483 .77865 L p .707 .577 .707 r
F P
0 g
s
.65365 .61237 m .65365 .55679 L .64105 .5489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68091 m .79455 .69944 L .8186 .69379 L p .707 .577 .707 r
F P
0 g
s
.8186 .69379 m .8186 .67526 L .79455 .68091 L p .707 .577 .707 r
F P
0 g
s
.73333 .77736 m .73333 .7403 L .70216 .7384 L p .707 .577 .707 r
F P
0 g
s
.73333 .7403 m .73333 .77736 L .76517 .77658 L p .707 .577 .707 r
F P
0 g
s
.76517 .77658 m .76517 .73953 L .73333 .7403 L p .707 .577 .707 r
F P
0 g
s
.76517 .73953 m .76517 .77658 L .79455 .7732 L p .707 .577 .707 r
F P
0 g
s
.79455 .7732 m .79455 .73615 L .76517 .73953 L p .707 .577 .707 r
F P
0 g
s
.55357 .25608 m .55357 .75796 L .50956 .75528 L p .707 .577 .707 r
F P
0 g
s
.50956 .75528 m .50956 .25339 L .55357 .25608 L p .707 .577 .707 r
F P
0 g
s
.70216 .77546 m .70216 .7384 L .6747 .73401 L p .707 .577 .707 r
F P
0 g
s
.70216 .7384 m .70216 .77546 L .73333 .77736 L p .707 .577 .707 r
F P
0 g
s
.6747 .6973 m .6747 .67878 L .65365 .67232 L p .707 .577 .707 r
F P
0 g
s
.46462 .75638 m .46462 .25449 L .50956 .25339 L p .707 .577 .707 r
F P
0 g
s
.46462 .25449 m .46462 .75638 L .42314 .76115 L p .707 .577 .707 r
F P
0 g
s
.65365 .67232 m .65365 .69085 L .6747 .6973 L p .707 .577 .707 r
F P
0 g
s
.50956 .25339 m .50956 .75528 L .46462 .75638 L p .707 .577 .707 r
F P
0 g
s
.64105 .5489 m .64105 .60448 L .65365 .61237 L p .707 .577 .707 r
F P
0 g
s
.83497 .55236 m .83497 .60794 L .84205 .59958 L p .707 .577 .707 r
F P
0 g
s
.84205 .59958 m .84205 .544 L .83497 .55236 L p .707 .577 .707 r
F P
0 g
s
.79455 .73615 m .79455 .7732 L .8186 .76755 L p .707 .577 .707 r
F P
0 g
s
.8186 .76755 m .8186 .7305 L .79455 .73615 L p .707 .577 .707 r
F P
0 g
s
.6747 .73401 m .6747 .77107 L .70216 .77546 L p .707 .577 .707 r
F P
0 g
s
.8186 .67526 m .8186 .69379 L .83497 .68642 L p .707 .577 .707 r
F P
0 g
s
.83497 .68642 m .83497 .6679 L .8186 .67526 L p .707 .577 .707 r
F P
0 g
s
.6747 .77107 m .6747 .73401 L .65365 .72756 L p .707 .577 .707 r
F P
0 g
s
.64105 .60448 m .64105 .5489 L .63816 .54036 L p .707 .577 .707 r
F P
0 g
s
.65365 .69085 m .65365 .67232 L .64105 .66444 L p .707 .577 .707 r
F P
0 g
s
.65365 .72756 m .65365 .76461 L .6747 .77107 L p .707 .577 .707 r
F P
0 g
s
.8186 .7305 m .8186 .76755 L .83497 .76019 L p .707 .577 .707 r
F P
0 g
s
.83497 .76019 m .83497 .72313 L .8186 .7305 L p .707 .577 .707 r
F P
0 g
s
.64105 .66444 m .64105 .68297 L .65365 .69085 L p .707 .577 .707 r
F P
0 g
s
.63816 .54036 m .63816 .59594 L .64105 .60448 L p .707 .577 .707 r
F P
0 g
s
.84205 .544 m .84205 .59958 L .83916 .59104 L p .707 .577 .707 r
F P
0 g
s
.83916 .59104 m .83916 .53545 L .84205 .544 L p .707 .577 .707 r
F P
0 g
s
.65365 .76461 m .65365 .72756 L .64105 .71967 L p .707 .577 .707 r
F P
0 g
s
.83497 .6679 m .83497 .68642 L .84206 .67806 L p .707 .577 .707 r
F P
0 g
s
.84206 .67806 m .84205 .65953 L .83497 .6679 L p .707 .577 .707 r
F P
0 g
s
.64105 .71967 m .64105 .75673 L .65365 .76461 L p .707 .577 .707 r
F P
0 g
s
.63816 .59594 m .63816 .54036 L .64524 .532 L p .707 .577 .707 r
F P
0 g
s
.64105 .68297 m .64105 .66444 L .63816 .6559 L p .707 .577 .707 r
F P
0 g
s
.83497 .72313 m .83497 .76019 L .84206 .75182 L p .707 .577 .707 r
F P
0 g
s
.84206 .75182 m .84206 .71477 L .83497 .72313 L p .707 .577 .707 r
F P
0 g
s
.63816 .6559 m .63816 .67442 L .64105 .68297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .532 m .64524 .58758 L .63816 .59594 L p .707 .577 .707 r
F P
0 g
s
.64105 .75673 m .64105 .71967 L .63816 .71113 L p .707 .577 .707 r
F P
0 g
s
.83916 .53545 m .83916 .59104 L .82657 .58315 L p .707 .577 .707 r
F P
0 g
s
.82657 .58315 m .82657 .52757 L .83916 .53545 L p .707 .577 .707 r
F P
0 g
s
.84205 .65953 m .84206 .67806 L .83916 .66952 L p .707 .577 .707 r
F P
0 g
s
.83916 .66952 m .83916 .65099 L .84205 .65953 L p .707 .577 .707 r
F P
0 g
s
.63816 .71113 m .63816 .74819 L .64105 .75673 L p .707 .577 .707 r
F P
0 g
s
.39032 .5883 m .39032 .53272 L .35915 .53082 L p .707 .577 .707 r
F P
0 g
s
.39032 .53272 m .39032 .5883 L .42216 .58752 L p .707 .577 .707 r
F P
0 g
s
.42216 .58752 m .42216 .53194 L .39032 .53272 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58758 m .64524 .532 L .66161 .52463 L p .707 .577 .707 r
F P
0 g
s
.42216 .53194 m .42216 .58752 L .45154 .58414 L p .707 .577 .707 r
F P
0 g
s
.45154 .58414 m .45154 .52856 L .42216 .53194 L p .707 .577 .707 r
F P
0 g
s
.63816 .67442 m .63816 .6559 L .64524 .64753 L p .707 .577 .707 r
F P
0 g
s
.35915 .5864 m .35915 .53082 L .33169 .52643 L p .707 .577 .707 r
F P
0 g
s
.35915 .53082 m .35915 .5864 L .39032 .5883 L p .707 .577 .707 r
F P
0 g
s
.84206 .71477 m .84206 .75182 L .83916 .74328 L p .707 .577 .707 r
F P
0 g
s
.83916 .74328 m .83916 .70622 L .84206 .71477 L p .707 .577 .707 r
F P
0 g
s
.64524 .64753 m .64524 .66606 L .63816 .67442 L p .707 .577 .707 r
F P
0 g
s
.45154 .52856 m .45154 .58414 L .47559 .57849 L p .707 .577 .707 r
F P
0 g
s
.47559 .57849 m .47559 .52291 L .45154 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52463 m .66161 .58021 L .64524 .58758 L p .707 .577 .707 r
F P
0 g
s
.82657 .52757 m .82657 .58315 L .80551 .5767 L p .707 .577 .707 r
F P
0 g
s
.80551 .5767 m .80551 .52111 L .82657 .52757 L p .707 .577 .707 r
F P
0 g
s
.63816 .74819 m .63816 .71113 L .64524 .70277 L p .707 .577 .707 r
F P
0 g
s
.33169 .52643 m .33169 .58201 L .35915 .5864 L p .707 .577 .707 r
F P
0 g
s
.83916 .65099 m .83916 .66952 L .82657 .66163 L p .707 .577 .707 r
F P
0 g
s
.82657 .66163 m .82657 .64311 L .83916 .65099 L p .707 .577 .707 r
F P
0 g
s
.33169 .58201 m .33169 .52643 L .31064 .51997 L p .707 .577 .707 r
F P
0 g
s
.66161 .58021 m .66161 .52463 L .68566 .51898 L p .707 .577 .707 r
F P
0 g
s
.64524 .70277 m .64524 .73982 L .63816 .74819 L p .707 .577 .707 r
F P
0 g
s
.39032 .66678 m .39032 .64825 L .35915 .64635 L p .707 .577 .707 r
F P
0 g
s
.39032 .64825 m .39032 .66678 L .42216 .666 L p .707 .577 .707 r
F P
0 g
s
.42216 .666 m .42216 .64748 L .39032 .64825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66606 m .64524 .64753 L .66161 .64016 L p .707 .577 .707 r
F P
0 g
s
.42216 .64748 m .42216 .666 L .45154 .66263 L p .707 .577 .707 r
F P
0 g
s
.45154 .66263 m .45154 .6441 L .42216 .64748 L p .707 .577 .707 r
F P
0 g
s
.47559 .52291 m .47559 .57849 L .49196 .57113 L p .707 .577 .707 r
F P
0 g
s
.49196 .57113 m .49196 .51554 L .47559 .52291 L p .707 .577 .707 r
F P
0 g
s
.35915 .64635 m .35915 .66488 L .39032 .66678 L p .707 .577 .707 r
F P
0 g
s
.83916 .70622 m .83916 .74328 L .82657 .73539 L p .707 .577 .707 r
F P
0 g
s
.82657 .73539 m .82657 .69834 L .83916 .70622 L p .707 .577 .707 r
F P
0 g
s
.31064 .51997 m .31064 .57555 L .33169 .58201 L p .707 .577 .707 r
F P
0 g
s
.35915 .66488 m .35915 .64635 L .33169 .64196 L p .707 .577 .707 r
F P
0 g
s
.66161 .64016 m .66161 .65869 L .64524 .66606 L p .707 .577 .707 r
F P
0 g
s
.80551 .52111 m .80551 .5767 L .77805 .5723 L p .707 .577 .707 r
F P
0 g
s
.77805 .5723 m .77805 .51672 L .80551 .52111 L p .707 .577 .707 r
F P
0 g
s
.33169 .64196 m .33169 .66049 L .35915 .66488 L p .707 .577 .707 r
F P
0 g
s
.68566 .51898 m .68566 .57456 L .66161 .58021 L p .707 .577 .707 r
F P
0 g
s
.31064 .57555 m .31064 .51997 L .29804 .51209 L p .707 .577 .707 r
F P
0 g
s
.45154 .6441 m .45154 .66263 L .47559 .65698 L p .707 .577 .707 r
F P
0 g
s
.47559 .65698 m .47559 .63845 L .45154 .6441 L p .707 .577 .707 r
F P
0 g
s
.39032 .74054 m .39032 .70349 L .35915 .70159 L p .707 .577 .707 r
F P
0 g
s
.39032 .70349 m .39032 .74054 L .42216 .73977 L p .707 .577 .707 r
F P
0 g
s
.42216 .73977 m .42216 .70271 L .39032 .70349 L p .707 .577 .707 r
F P
0 g
s
.68566 .57456 m .68566 .51898 L .71504 .5156 L p .707 .577 .707 r
F P
0 g
s
.64524 .73982 m .64524 .70277 L .66161 .6954 L p .707 .577 .707 r
F P
0 g
s
.42216 .70271 m .42216 .73977 L .45154 .73639 L p .707 .577 .707 r
F P
0 g
s
.45154 .73639 m .45154 .69933 L .42216 .70271 L p .707 .577 .707 r
F P
0 g
s
.82657 .64311 m .82657 .66163 L .80551 .65518 L p .707 .577 .707 r
F P
0 g
s
.80551 .65518 m .80551 .63665 L .82657 .64311 L p .707 .577 .707 r
F P
0 g
s
.35915 .73864 m .35915 .70159 L .33169 .6972 L p .707 .577 .707 r
F P
0 g
s
.35915 .70159 m .35915 .73864 L .39032 .74054 L p .707 .577 .707 r
F P
0 g
s
.33169 .66049 m .33169 .64196 L .31064 .63551 L p .707 .577 .707 r
F P
0 g
s
.77805 .51672 m .77805 .5723 L .74688 .5704 L p .707 .577 .707 r
F P
0 g
s
.74688 .5704 m .74688 .51482 L .77805 .51672 L p .707 .577 .707 r
F P
0 g
s
.31064 .63551 m .31064 .65404 L .33169 .66049 L p .707 .577 .707 r
F P
0 g
s
.66161 .6954 m .66161 .73245 L .64524 .73982 L p .707 .577 .707 r
F P
0 g
s
.66161 .65869 m .66161 .64016 L .68566 .63451 L p .707 .577 .707 r
F P
0 g
s
.29804 .51209 m .29804 .56767 L .31064 .57555 L p .707 .577 .707 r
F P
0 g
s
.71504 .57118 m .71504 .5156 L .74688 .51482 L p .707 .577 .707 r
F P
0 g
s
.71504 .5156 m .71504 .57118 L .68566 .57456 L p .707 .577 .707 r
F P
0 g
s
.49196 .51554 m .49196 .57113 L .49904 .56276 L p .707 .577 .707 r
F P
0 g
s
.49904 .56276 m .49904 .50718 L .49196 .51554 L p .707 .577 .707 r
F P
0 g
s
.45154 .69933 m .45154 .73639 L .47559 .73074 L p .707 .577 .707 r
F P
0 g
s
.47559 .73074 m .47559 .69368 L .45154 .69933 L p .707 .577 .707 r
F P
0 g
s
.74688 .51482 m .74688 .5704 L .71504 .57118 L p .707 .577 .707 r
F P
0 g
s
.33169 .6972 m .33169 .73425 L .35915 .73864 L p .707 .577 .707 r
F P
0 g
s
.82657 .69834 m .82657 .73539 L .80551 .72894 L p .707 .577 .707 r
F P
0 g
s
.80551 .72894 m .80551 .69189 L .82657 .69834 L p .707 .577 .707 r
F P
0 g
s
.68566 .63451 m .68566 .65304 L .66161 .65869 L p .707 .577 .707 r
F P
0 g
s
.47559 .63845 m .47559 .65698 L .49196 .64961 L p .707 .577 .707 r
F P
0 g
s
.49196 .64961 m .49196 .63108 L .47559 .63845 L p .707 .577 .707 r
F P
0 g
s
.33169 .73425 m .33169 .6972 L .31064 .69074 L p .707 .577 .707 r
F P
0 g
s
.80551 .63665 m .80551 .65518 L .77805 .65079 L p .707 .577 .707 r
F P
0 g
s
.77805 .65079 m .77805 .63226 L .80551 .63665 L p .707 .577 .707 r
F P
0 g
s
.29804 .56767 m .29804 .51209 L .29515 .50354 L p .707 .577 .707 r
F P
0 g
s
.66161 .73245 m .66161 .6954 L .68566 .68975 L p .707 .577 .707 r
F P
0 g
s
.31064 .65404 m .31064 .63551 L .29804 .62762 L p .707 .577 .707 r
F P
0 g
s
.31064 .69074 m .31064 .7278 L .33169 .73425 L p .707 .577 .707 r
F P
0 g
s
.68566 .65304 m .68566 .63451 L .71504 .63114 L p .707 .577 .707 r
F P
0 g
s
.47559 .69368 m .47559 .73074 L .49196 .72337 L p .707 .577 .707 r
F P
0 g
s
.49196 .72337 m .49196 .68631 L .47559 .69368 L p .707 .577 .707 r
F P
0 g
s
.29804 .62762 m .29804 .64615 L .31064 .65404 L p .707 .577 .707 r
F P
0 g
s
.71504 .63114 m .71504 .64966 L .68566 .65304 L p .707 .577 .707 r
F P
0 g
s
.68566 .68975 m .68566 .7268 L .66161 .73245 L p .707 .577 .707 r
F P
0 g
s
.80551 .69189 m .80551 .72894 L .77805 .72455 L p .707 .577 .707 r
F P
0 g
s
.77805 .72455 m .77805 .68749 L .80551 .69189 L p .707 .577 .707 r
F P
0 g
s
.29515 .50354 m .29515 .55913 L .29804 .56767 L p .707 .577 .707 r
F P
0 g
s
.77805 .63226 m .77805 .65079 L .74688 .64889 L p .707 .577 .707 r
F P
0 g
s
.74688 .64889 m .74688 .63036 L .77805 .63226 L p .707 .577 .707 r
F P
0 g
s
.49904 .50718 m .49904 .56276 L .49615 .55422 L p .707 .577 .707 r
F P
0 g
s
.49615 .55422 m .49615 .49864 L .49904 .50718 L p .707 .577 .707 r
F P
0 g
s
.31064 .7278 m .31064 .69074 L .29804 .68286 L p .707 .577 .707 r
F P
0 g
s
.71504 .64966 m .71504 .63114 L .74688 .63036 L p .707 .577 .707 r
F P
0 g
s
.49196 .63108 m .49196 .64961 L .49904 .64124 L p .707 .577 .707 r
F P
0 g
s
.49904 .64124 m .49904 .62272 L .49196 .63108 L p .707 .577 .707 r
F P
0 g
s
.74688 .63036 m .74688 .64889 L .71504 .64966 L p .707 .577 .707 r
F P
0 g
s
.68566 .7268 m .68566 .68975 L .71504 .68637 L p .707 .577 .707 r
F P
0 g
s
.29804 .68286 m .29804 .71991 L .31064 .7278 L p .707 .577 .707 r
F P
0 g
s
.29515 .55913 m .29515 .50354 L .30223 .49518 L p .707 .577 .707 r
F P
0 g
s
.77805 .68749 m .77805 .72455 L .74688 .72265 L p .707 .577 .707 r
F P
0 g
s
.74688 .72265 m .74688 .68559 L .77805 .68749 L p .707 .577 .707 r
F P
0 g
s
.29804 .64615 m .29804 .62762 L .29515 .61908 L p .707 .577 .707 r
F P
0 g
s
.71504 .68637 m .71504 .72342 L .68566 .7268 L p .707 .577 .707 r
F P
0 g
s
.71504 .72342 m .71504 .68637 L .74688 .68559 L p .707 .577 .707 r
F P
0 g
s
.49196 .68631 m .49196 .72337 L .49904 .71501 L p .707 .577 .707 r
F P
0 g
s
.49904 .71501 m .49904 .67795 L .49196 .68631 L p .707 .577 .707 r
F P
0 g
s
.29515 .61908 m .29515 .63761 L .29804 .64615 L p .707 .577 .707 r
F P
0 g
s
.74688 .68559 m .74688 .72265 L .71504 .72342 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .49518 m .30223 .55076 L .29515 .55913 L p .707 .577 .707 r
F P
0 g
s
.29804 .71991 m .29804 .68286 L .29515 .67432 L p .707 .577 .707 r
F P
0 g
s
.49615 .49864 m .49615 .55422 L .48356 .54634 L p .707 .577 .707 r
F P
0 g
s
.48356 .54634 m .48356 .49075 L .49615 .49864 L p .707 .577 .707 r
F P
0 g
s
.49904 .62272 m .49904 .64124 L .49615 .6327 L p .707 .577 .707 r
F P
0 g
s
.49615 .6327 m .49615 .61417 L .49904 .62272 L p .707 .577 .707 r
F P
0 g
s
.29515 .67432 m .29515 .71137 L .29804 .71991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55076 m .30223 .49518 L .3186 .48781 L p .707 .577 .707 r
F P
0 g
s
.29515 .63761 m .29515 .61908 L .30223 .61072 L p .707 .577 .707 r
F P
0 g
s
.49904 .67795 m .49904 .71501 L .49615 .70646 L p .707 .577 .707 r
F P
0 g
s
.49615 .70646 m .49615 .66941 L .49904 .67795 L p .707 .577 .707 r
F P
0 g
s
.30223 .61072 m .30223 .62924 L .29515 .63761 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .48781 m .3186 .54339 L .30223 .55076 L p .707 .577 .707 r
F P
0 g
s
.48356 .49075 m .48356 .54634 L .4625 .53988 L p .707 .577 .707 r
F P
0 g
s
.4625 .53988 m .4625 .4843 L .48356 .49075 L p .707 .577 .707 r
F P
0 g
s
.29515 .71137 m .29515 .67432 L .30223 .66595 L p .707 .577 .707 r
F P
0 g
s
.49615 .61417 m .49615 .6327 L .48356 .62482 L p .707 .577 .707 r
F P
0 g
s
.48356 .62482 m .48356 .60629 L .49615 .61417 L p .707 .577 .707 r
F P
0 g
s
.3186 .54339 m .3186 .48781 L .34265 .48216 L p .707 .577 .707 r
F P
0 g
s
.30223 .66595 m .30223 .70301 L .29515 .71137 L p .707 .577 .707 r
F P
0 g
s
.30223 .62924 m .30223 .61072 L .3186 .60335 L p .707 .577 .707 r
F P
0 g
s
.49615 .66941 m .49615 .70646 L .48356 .69858 L p .707 .577 .707 r
F P
0 g
s
.48356 .69858 m .48356 .66152 L .49615 .66941 L p .707 .577 .707 r
F P
0 g
s
.3186 .60335 m .3186 .62188 L .30223 .62924 L p .707 .577 .707 r
F P
0 g
s
.4625 .4843 m .4625 .53988 L .43504 .53549 L p .707 .577 .707 r
F P
0 g
s
.43504 .53549 m .43504 .47991 L .4625 .4843 L p .707 .577 .707 r
F P
0 g
s
.34265 .48216 m .34265 .53774 L .3186 .54339 L p .707 .577 .707 r
F P
0 g
s
.34265 .53774 m .34265 .48216 L .37203 .47878 L p .707 .577 .707 r
F P
0 g
s
.30223 .70301 m .30223 .66595 L .3186 .65858 L p .707 .577 .707 r
F P
0 g
s
.48356 .60629 m .48356 .62482 L .4625 .61836 L p .707 .577 .707 r
F P
0 g
s
.4625 .61836 m .4625 .59984 L .48356 .60629 L p .707 .577 .707 r
F P
0 g
s
.43504 .47991 m .43504 .53549 L .40387 .53359 L p .707 .577 .707 r
F P
0 g
s
.40387 .53359 m .40387 .47801 L .43504 .47991 L p .707 .577 .707 r
F P
0 g
s
.3186 .65858 m .3186 .69564 L .30223 .70301 L p .707 .577 .707 r
F P
0 g
s
.3186 .62188 m .3186 .60335 L .34265 .5977 L p .707 .577 .707 r
F P
0 g
s
.37203 .53437 m .37203 .47878 L .40387 .47801 L p .707 .577 .707 r
F P
0 g
s
.37203 .47878 m .37203 .53437 L .34265 .53774 L p .707 .577 .707 r
F P
0 g
s
.40387 .47801 m .40387 .53359 L .37203 .53437 L p .707 .577 .707 r
F P
0 g
s
.48356 .66152 m .48356 .69858 L .4625 .69212 L p .707 .577 .707 r
F P
0 g
s
.4625 .69212 m .4625 .65507 L .48356 .66152 L p .707 .577 .707 r
F P
0 g
s
.34265 .5977 m .34265 .61623 L .3186 .62188 L p .707 .577 .707 r
F P
0 g
s
.4625 .59984 m .4625 .61836 L .43504 .61397 L p .707 .577 .707 r
F P
0 g
s
.43504 .61397 m .43504 .59544 L .4625 .59984 L p .707 .577 .707 r
F P
0 g
s
.3186 .69564 m .3186 .65858 L .34265 .65293 L p .707 .577 .707 r
F P
0 g
s
.34265 .61623 m .34265 .5977 L .37203 .59432 L p .707 .577 .707 r
F P
0 g
s
.37203 .59432 m .37203 .61285 L .34265 .61623 L p .707 .577 .707 r
F P
0 g
s
.34265 .65293 m .34265 .68999 L .3186 .69564 L p .707 .577 .707 r
F P
0 g
s
.4625 .65507 m .4625 .69212 L .43504 .68773 L p .707 .577 .707 r
F P
0 g
s
.43504 .68773 m .43504 .65068 L .4625 .65507 L p .707 .577 .707 r
F P
0 g
s
.43504 .59544 m .43504 .61397 L .40387 .61207 L p .707 .577 .707 r
F P
0 g
s
.40387 .61207 m .40387 .59354 L .43504 .59544 L p .707 .577 .707 r
F P
0 g
s
.37203 .61285 m .37203 .59432 L .40387 .59354 L p .707 .577 .707 r
F P
0 g
s
.40387 .59354 m .40387 .61207 L .37203 .61285 L p .707 .577 .707 r
F P
0 g
s
.34265 .68999 m .34265 .65293 L .37203 .64955 L p .707 .577 .707 r
F P
0 g
s
.43504 .65068 m .43504 .68773 L .40387 .68583 L p .707 .577 .707 r
F P
0 g
s
.40387 .68583 m .40387 .64878 L .43504 .65068 L p .707 .577 .707 r
F P
0 g
s
.37203 .64955 m .37203 .68661 L .34265 .68999 L p .707 .577 .707 r
F P
0 g
s
.37203 .68661 m .37203 .64955 L .40387 .64878 L p .707 .577 .707 r
F P
0 g
s
.40387 .64878 m .40387 .68583 L .37203 .68661 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP06001gOol007Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`T000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001G
Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00003goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00IJEPP0
00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03
001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol00`00
FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
009JEPL000QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2
000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000]Ool0035oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;goo0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF0002FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUH0000B0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF2@0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF3P0015YF
00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000FUH005YF0P000eYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF6`00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH4000015YF0000000015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00=JEP800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07
FUH00`00FUH0000300000eYF000000040004FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEQP003ioo`00
;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP<0
00AJEP<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00<003Yoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP04001JEP000003FUH00`00FUH000020003FUH30002FUH01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP02FUH50000
15YF000000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF100000=JEP00FUH00UYF00<0
05YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH01000<Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
<Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF5`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP03FUH30004FUH00`00FUH000050003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH800000eYF001JEP05FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF200047oo20000eYF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH00004FUH000000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020002FUH01000FUIJEUYF
0P0067oo1@0015YF00D005YFFUIJEP0002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000M
Ool300000eYF001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@0
05YFFUIJEP8000Qoo`<001Moo`800003FUH0000002eoo`00<goo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUH0
05YF00<000AJEP04001JEUYFFUH20007Ool5000FOol5000]Ool003Ioo`D000AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P0015YF0`00
00=JEP00FUH00UYF0P001goo1@0057oo0P000UYF0`00;Goo000kOol80004FUH00`00FUIJEP07FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP00008000=JEP<000=JEP80
00Moo`D0011oo`@000AJEP03001JEP0002eoo`00@goo4@0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEPD00004FUH00000FUH20008Ool3000:Ool70003FUH00`00FUIJ
EP02FUH2000^Ool004Moo`T000=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000oOol8
0004FUH00`00FUIJEP02FUH400000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF2@0015YF00<005YFFUH0
0UYF2@001UYF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEPH0
00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD0009JEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000=JEPP000Aoo`04001JEUYF0005FUH40006FUH00`00FUIJEP09FUH4
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000`00<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P0015YF1P000Woo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF009JEPL000=JEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000^Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000
FUH000EJEP04001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH00`00FUIJ
EP0200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
0UYF5P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEPH001Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF000015YF00<005YF00000`006Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH3000NOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00FUH2000ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00
000HOol3000:Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P00
0UYF0`0057oo1@002goo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPH000Uoo`D000Aoo`P0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEP000080015oo`D0
00ioo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP000080011oo`<000eoo`D000AJEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF009JEPD000aoo`D000moo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEPP0021oo`H00003FUH005YF009JEP8002eoo`00;Goo
00D005YFFUIJEP0000EJEP04001JEUYFFUH80005Ool3000;Ool50005FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YFFUIJEPT0
019oo`D000EJEP<000=JEP8002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEQL000=JEP03
001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002moo`<000EJEP03
001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0039o
o`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02
FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000=o
o`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUIJEUYF
0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF100015YF00<005YF00002`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF0000
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP05001JEUYFFUH00003FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUH000080004FUH0
0`00FUIJEP02FUH9000oOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT0
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP040006FUH01000FUIJEUYF0P001Goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJ
EUYF200027oo1@0037oo1P0015YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH2000015YF001JEUYF1@000UYF00@005YF000005Qoo`00;7oo00<005YF000015YF10004Goo0`00
4goo0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000<005Yoo`00;7oo00<005YF00000UYF0P000eYF1@0087oo100000AJEP000000009J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP02FUH2001I
Ool002aoo`03001JEP0000<000EJEP04001JEUYFFUH8000:Ool>0005FUH01@00FUIJEP00FUH00P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP<005Moo`00
;7oo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000IJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=oo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF
FUIJEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30003Ool80003FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000=Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3000>Ool50004FUH01000FUIJ
EUYF0P00E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH00003000COol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH0
0003000COol600000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPD001ioo``000IJEP03001JEUYF00YJEP03001JEUYF00=JEPL0019oo`D0
00EJEP<000=JEP8005Aoo`00?Goo6@00;goo<P000eYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo002>Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001DOol008ioo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<005Aoo`00SWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002?Ool0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002B
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Moo`D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00W7oo2@0015YF00<005YFFUH00UYF
3P00HGoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72951 m .59613 .67393 L .56496 .67202 L p .707 .577 .707 r
F P
0 g
s
.59613 .67393 m .59613 .72951 L .62796 .72873 L p .707 .577 .707 r
F P
0 g
s
.62796 .72873 m .62796 .67315 L .59613 .67393 L p .707 .577 .707 r
F P
0 g
s
.62796 .67315 m .62796 .72873 L .65734 .72535 L p .707 .577 .707 r
F P
0 g
s
.65734 .72535 m .65734 .66977 L .62796 .67315 L p .707 .577 .707 r
F P
0 g
s
.56496 .72761 m .56496 .67202 L .5375 .66763 L p .707 .577 .707 r
F P
0 g
s
.56496 .67202 m .56496 .72761 L .59613 .72951 L p .707 .577 .707 r
F P
0 g
s
.65734 .66977 m .65734 .72535 L .6814 .7197 L p .707 .577 .707 r
F P
0 g
s
.6814 .7197 m .6814 .66412 L .65734 .66977 L p .707 .577 .707 r
F P
0 g
s
.5375 .66763 m .5375 .72321 L .56496 .72761 L p .707 .577 .707 r
F P
0 g
s
.5375 .72321 m .5375 .66763 L .51644 .66118 L p .707 .577 .707 r
F P
0 g
s
.59613 .81705 m .59613 .79852 L .56496 .79662 L p .707 .577 .707 r
F P
0 g
s
.59613 .79852 m .59613 .81705 L .62796 .81627 L p .707 .577 .707 r
F P
0 g
s
.62796 .81627 m .62796 .79774 L .59613 .79852 L p .707 .577 .707 r
F P
0 g
s
.6814 .66412 m .6814 .7197 L .69777 .71233 L p .707 .577 .707 r
F P
0 g
s
.69777 .71233 m .69777 .65675 L .6814 .66412 L p .707 .577 .707 r
F P
0 g
s
.62796 .79774 m .62796 .81627 L .65735 .81289 L p .707 .577 .707 r
F P
0 g
s
.65735 .81289 m .65735 .79436 L .62796 .79774 L p .707 .577 .707 r
F P
0 g
s
.59613 .84665 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84665 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.51644 .66118 m .51644 .71676 L .5375 .72321 L p .707 .577 .707 r
F P
0 g
s
.56496 .79662 m .56496 .81515 L .59613 .81705 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80544 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .81515 m .56496 .79662 L .5375 .79223 L p .707 .577 .707 r
F P
0 g
s
.56496 .84475 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84475 L .59613 .84665 L p .707 .577 .707 r
F P
0 g
s
.51644 .71676 m .51644 .66118 L .50385 .65329 L p .707 .577 .707 r
F P
0 g
s
.5375 .79223 m .5375 .81075 L .56496 .81515 L p .707 .577 .707 r
F P
0 g
s
.65735 .79436 m .65735 .81289 L .6814 .80724 L p .707 .577 .707 r
F P
0 g
s
.6814 .80724 m .6814 .78871 L .65735 .79436 L p .707 .577 .707 r
F P
0 g
s
.65735 .80544 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .79979 L .65735 .80544 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84475 L p .707 .577 .707 r
F P
0 g
s
.5375 .81075 m .5375 .79223 L .51644 .78577 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79685 L p .707 .577 .707 r
F P
0 g
s
.50385 .65329 m .50385 .70888 L .51644 .71676 L p .707 .577 .707 r
F P
0 g
s
.69777 .65675 m .69777 .71233 L .70485 .70397 L p .707 .577 .707 r
F P
0 g
s
.70485 .70397 m .70485 .64839 L .69777 .65675 L p .707 .577 .707 r
F P
0 g
s
.51644 .78577 m .51644 .8043 L .5375 .81075 L p .707 .577 .707 r
F P
0 g
s
.6814 .78871 m .6814 .80724 L .69777 .79987 L p .707 .577 .707 r
F P
0 g
s
.69777 .79987 m .69777 .78135 L .6814 .78871 L p .707 .577 .707 r
F P
0 g
s
.51644 .79685 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.6814 .79979 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .79979 L p .707 .577 .707 r
F P
0 g
s
.50385 .70888 m .50385 .65329 L .50095 .64475 L p .707 .577 .707 r
F P
0 g
s
.51644 .8043 m .51644 .78577 L .50385 .77789 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79685 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .77789 m .50385 .79642 L .51644 .8043 L p .707 .577 .707 r
F P
0 g
s
.50095 .64475 m .50095 .70033 L .50385 .70888 L p .707 .577 .707 r
F P
0 g
s
.70485 .64839 m .70485 .70397 L .70195 .69543 L p .707 .577 .707 r
F P
0 g
s
.70195 .69543 m .70195 .63985 L .70485 .64839 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82602 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.69777 .78135 m .69777 .79987 L .70485 .79151 L p .707 .577 .707 r
F P
0 g
s
.70485 .79151 m .70485 .77298 L .69777 .78135 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70033 m .50095 .64475 L .50804 .63639 L p .707 .577 .707 r
F P
0 g
s
.50385 .79642 m .50385 .77789 L .50095 .76935 L p .707 .577 .707 r
F P
0 g
s
.49044 .82844 m .49044 .32655 L .44643 .32387 L p .707 .577 .707 r
F P
0 g
s
.50385 .82602 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50095 .76935 m .50095 .78787 L .50385 .79642 L p .707 .577 .707 r
F P
0 g
s
.50804 .63639 m .50804 .69197 L .50095 .70033 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82602 L p .707 .577 .707 r
F P
0 g
s
.50804 .69197 m .50804 .63639 L .5244 .62902 L p .707 .577 .707 r
F P
0 g
s
.50095 .78787 m .50095 .76935 L .50804 .76098 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .76098 m .50804 .77951 L .50095 .78787 L p .707 .577 .707 r
F P
0 g
s
.5244 .62902 m .5244 .6846 L .50804 .69197 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.50804 .77951 m .50804 .76098 L .5244 .75361 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .76469 L p .707 .577 .707 r
F P
0 g
s
.5244 .75361 m .5244 .77214 L .50804 .77951 L p .707 .577 .707 r
F P
0 g
s
.5244 .76469 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.5244 .77214 m .5244 .75361 L .54846 .74797 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .76469 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.54846 .74797 m .54846 .76649 L .5244 .77214 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.49044 .32655 m .49044 .82844 L .53538 .82734 L p .707 .577 .707 r
F P
0 g
s
.5244 .6846 m .5244 .62902 L .54846 .62337 L p .707 .577 .707 r
F P
0 g
s
.54846 .62337 m .54846 .67895 L .5244 .6846 L p .707 .577 .707 r
F P
0 g
s
.53538 .82734 m .53538 .32545 L .49044 .32655 L p .707 .577 .707 r
F P
0 g
s
.54846 .67895 m .54846 .62337 L .57784 .61999 L p .707 .577 .707 r
F P
0 g
s
.57784 .61999 m .57784 .67557 L .54846 .67895 L p .707 .577 .707 r
F P
0 g
s
.54846 .76649 m .54846 .74797 L .57784 .74459 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .74459 m .57784 .76311 L .54846 .76649 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.53538 .32545 m .53538 .82734 L .57686 .82257 L p .707 .577 .707 r
F P
0 g
s
.57686 .82257 m .57686 .32068 L .53538 .32545 L p .707 .577 .707 r
F P
0 g
s
.44643 .82576 m .44643 .32387 L .40766 .31767 L p .707 .577 .707 r
F P
0 g
s
.44643 .32387 m .44643 .82576 L .49044 .82844 L p .707 .577 .707 r
F P
0 g
s
.70195 .63985 m .70195 .69543 L .68936 .68754 L p .707 .577 .707 r
F P
0 g
s
.68936 .68754 m .68936 .63196 L .70195 .63985 L p .707 .577 .707 r
F P
0 g
s
.70485 .77298 m .70485 .79151 L .70195 .78297 L p .707 .577 .707 r
F P
0 g
s
.70195 .78297 m .70195 .76444 L .70485 .77298 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81257 L p .707 .577 .707 r
F P
0 g
s
.70195 .81257 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.57784 .67557 m .57784 .61999 L .60968 .61921 L p .707 .577 .707 r
F P
0 g
s
.60968 .61921 m .60968 .6748 L .57784 .67557 L p .707 .577 .707 r
F P
0 g
s
.57784 .76311 m .57784 .74459 L .60968 .74381 L p .707 .577 .707 r
F P
0 g
s
.60968 .74381 m .60968 .76234 L .57784 .76311 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79194 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57686 .32068 m .57686 .82257 L .61082 .8146 L p .707 .577 .707 r
F P
0 g
s
.64085 .62111 m .64085 .6767 L .60968 .6748 L p .707 .577 .707 r
F P
0 g
s
.60968 .6748 m .60968 .61921 L .64085 .62111 L p .707 .577 .707 r
F P
0 g
s
.64085 .74571 m .64085 .76424 L .60968 .76234 L p .707 .577 .707 r
F P
0 g
s
.60968 .76234 m .60968 .74381 L .64085 .74571 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79384 L .60968 .79194 L p .707 .577 .707 r
F P
0 g
s
.60968 .79194 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.61082 .8146 m .61082 .31271 L .57686 .32068 L p .707 .577 .707 r
F P
0 g
s
.25312 .69269 m .25312 .63711 L .22195 .63521 L p .707 .577 .707 r
F P
0 g
s
.25312 .63711 m .25312 .69269 L .28495 .69192 L p .707 .577 .707 r
F P
0 g
s
.28495 .69192 m .28495 .63633 L .25312 .63711 L p .707 .577 .707 r
F P
0 g
s
.28495 .63633 m .28495 .69192 L .31434 .68854 L p .707 .577 .707 r
F P
0 g
s
.31434 .68854 m .31434 .63295 L .28495 .63633 L p .707 .577 .707 r
F P
0 g
s
.22195 .69079 m .22195 .63521 L .19449 .63082 L p .707 .577 .707 r
F P
0 g
s
.22195 .63521 m .22195 .69079 L .25312 .69269 L p .707 .577 .707 r
F P
0 g
s
.40766 .81956 m .40766 .31767 L .37794 .30856 L p .707 .577 .707 r
F P
0 g
s
.40766 .31767 m .40766 .81956 L .44643 .82576 L p .707 .577 .707 r
F P
0 g
s
.31434 .63295 m .31434 .68854 L .33839 .68289 L p .707 .577 .707 r
F P
0 g
s
.33839 .68289 m .33839 .6273 L .31434 .63295 L p .707 .577 .707 r
F P
0 g
s
.68936 .63196 m .68936 .68754 L .66831 .68109 L p .707 .577 .707 r
F P
0 g
s
.66831 .68109 m .66831 .62551 L .68936 .63196 L p .707 .577 .707 r
F P
0 g
s
.19449 .63082 m .19449 .6864 L .22195 .69079 L p .707 .577 .707 r
F P
0 g
s
.19449 .6864 m .19449 .63082 L .17343 .62436 L p .707 .577 .707 r
F P
0 g
s
.70195 .76444 m .70195 .78297 L .68936 .77508 L p .707 .577 .707 r
F P
0 g
s
.68936 .77508 m .68936 .75656 L .70195 .76444 L p .707 .577 .707 r
F P
0 g
s
.61082 .31271 m .61082 .8146 L .63393 .8042 L p .707 .577 .707 r
F P
0 g
s
.63393 .8042 m .63393 .30231 L .61082 .31271 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81257 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.25312 .78023 m .25312 .7617 L .22195 .7598 L p .707 .577 .707 r
F P
0 g
s
.25312 .7617 m .25312 .78023 L .28495 .77946 L p .707 .577 .707 r
F P
0 g
s
.28495 .77946 m .28495 .76093 L .25312 .7617 L p .707 .577 .707 r
F P
0 g
s
.33839 .6273 m .33839 .68289 L .35476 .67552 L p .707 .577 .707 r
F P
0 g
s
.35476 .67552 m .35476 .61994 L .33839 .6273 L p .707 .577 .707 r
F P
0 g
s
.28495 .76093 m .28495 .77946 L .31434 .77608 L p .707 .577 .707 r
F P
0 g
s
.31434 .77608 m .31434 .75755 L .28495 .76093 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77278 L .22195 .77088 L p .707 .577 .707 r
F P
0 g
s
.25312 .77278 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77278 L p .707 .577 .707 r
F P
0 g
s
.17343 .62436 m .17343 .67995 L .19449 .6864 L p .707 .577 .707 r
F P
0 g
s
.22195 .7598 m .22195 .77833 L .25312 .78023 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80568 L p .707 .577 .707 r
F P
0 g
s
.31434 .80568 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.37794 .81044 m .37794 .30856 L .36016 .29743 L p .707 .577 .707 r
F P
0 g
s
.37794 .30856 m .37794 .81044 L .40766 .81956 L p .707 .577 .707 r
F P
0 g
s
.22195 .77833 m .22195 .7598 L .19449 .75541 L p .707 .577 .707 r
F P
0 g
s
.66831 .62551 m .66831 .68109 L .64085 .6767 L p .707 .577 .707 r
F P
0 g
s
.64085 .6767 m .64085 .62111 L .66831 .62551 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77088 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77088 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.17343 .67995 m .17343 .62436 L .16084 .61648 L p .707 .577 .707 r
F P
0 g
s
.19449 .75541 m .19449 .77394 L .22195 .77833 L p .707 .577 .707 r
F P
0 g
s
.31434 .75755 m .31434 .77608 L .33839 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .77043 m .33839 .7519 L .31434 .75755 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80568 L .33839 .80003 L p .707 .577 .707 r
F P
0 g
s
.33839 .80003 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.68936 .75656 m .68936 .77508 L .66831 .76863 L p .707 .577 .707 r
F P
0 g
s
.66831 .76863 m .66831 .7501 L .68936 .75656 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .77394 m .19449 .75541 L .17343 .74896 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.16084 .61648 m .16084 .67206 L .17343 .67995 L p .707 .577 .707 r
F P
0 g
s
.35476 .61994 m .35476 .67552 L .36184 .66715 L p .707 .577 .707 r
F P
0 g
s
.36184 .66715 m .36184 .61157 L .35476 .61994 L p .707 .577 .707 r
F P
0 g
s
.17343 .74896 m .17343 .76749 L .19449 .77394 L p .707 .577 .707 r
F P
0 g
s
.66831 .7501 m .66831 .76863 L .64085 .76424 L p .707 .577 .707 r
F P
0 g
s
.64085 .76424 m .64085 .74571 L .66831 .7501 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79384 L p .707 .577 .707 r
F P
0 g
s
.64085 .79384 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.63393 .30231 m .63393 .8042 L .64393 .79239 L p .707 .577 .707 r
F P
0 g
s
.64393 .79239 m .64393 .2905 L .63393 .30231 L p .707 .577 .707 r
F P
0 g
s
.33839 .7519 m .33839 .77043 L .35476 .76306 L p .707 .577 .707 r
F P
0 g
s
.35476 .76306 m .35476 .74453 L .33839 .7519 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80003 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.16084 .67206 m .16084 .61648 L .15794 .60794 L p .707 .577 .707 r
F P
0 g
s
.17343 .76749 m .17343 .74896 L .16084 .74107 L p .707 .577 .707 r
F P
0 g
s
.36184 .61157 m .36184 .66715 L .35894 .65861 L p .707 .577 .707 r
F P
0 g
s
.35894 .65861 m .35894 .60303 L .36184 .61157 L p .707 .577 .707 r
F P
0 g
s
.35476 .74453 m .35476 .76306 L .36184 .75469 L p .707 .577 .707 r
F P
0 g
s
.36184 .75469 m .36184 .73617 L .35476 .74453 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.35894 .60303 m .35894 .65861 L .34635 .65073 L p .707 .577 .707 r
F P
0 g
s
.34635 .65073 m .34635 .59515 L .35894 .60303 L p .707 .577 .707 r
F P
0 g
s
.36184 .73617 m .36184 .75469 L .35894 .74615 L p .707 .577 .707 r
F P
0 g
s
.35894 .74615 m .35894 .72762 L .36184 .73617 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .7387 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.36016 .79931 m .36016 .29743 L .35607 .28537 L p .707 .577 .707 r
F P
0 g
s
.36016 .29743 m .36016 .79931 L .37794 .81044 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75215 L p .707 .577 .707 r
F P
0 g
s
.16084 .74107 m .16084 .7596 L .17343 .76749 L p .707 .577 .707 r
F P
0 g
s
.15794 .60794 m .15794 .66352 L .16084 .67206 L p .707 .577 .707 r
F P
0 g
s
.16084 .75215 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.15794 .66352 m .15794 .60794 L .16503 .59957 L p .707 .577 .707 r
F P
0 g
s
.64393 .2905 m .64393 .79239 L .63984 .78033 L p .707 .577 .707 r
F P
0 g
s
.63984 .78033 m .63984 .27844 L .64393 .2905 L p .707 .577 .707 r
F P
0 g
s
.16084 .7596 m .16084 .74107 L .15794 .73253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16084 .78921 m .16084 .75215 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.15794 .73253 m .15794 .75106 L .16084 .7596 L p .707 .577 .707 r
F P
0 g
s
.16503 .59957 m .16503 .65515 L .15794 .66352 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.35894 .72762 m .35894 .74615 L .34635 .73827 L p .707 .577 .707 r
F P
0 g
s
.34635 .73827 m .34635 .71974 L .35894 .72762 L p .707 .577 .707 r
F P
0 g
s
.35894 .7387 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .7387 L p .707 .577 .707 r
F P
0 g
s
.35607 .28537 m .35607 .78725 L .36016 .79931 L p .707 .577 .707 r
F P
0 g
s
.35607 .78725 m .35607 .28537 L .36607 .27356 L p .707 .577 .707 r
F P
0 g
s
.16503 .65515 m .16503 .59957 L .1814 .5922 L p .707 .577 .707 r
F P
0 g
s
.15794 .75106 m .15794 .73253 L .16503 .72417 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .72417 m .16503 .74269 L .15794 .75106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27844 m .63984 .78033 L .62206 .7692 L p .707 .577 .707 r
F P
0 g
s
.62206 .7692 m .62206 .26731 L .63984 .27844 L p .707 .577 .707 r
F P
0 g
s
.1814 .5922 m .1814 .64779 L .16503 .65515 L p .707 .577 .707 r
F P
0 g
s
.34635 .59515 m .34635 .65073 L .3253 .64427 L p .707 .577 .707 r
F P
0 g
s
.3253 .64427 m .3253 .58869 L .34635 .59515 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .64779 m .1814 .5922 L .20545 .58655 L p .707 .577 .707 r
F P
0 g
s
.36607 .77545 m .36607 .27356 L .38918 .26316 L p .707 .577 .707 r
F P
0 g
s
.36607 .27356 m .36607 .77545 L .35607 .78725 L p .707 .577 .707 r
F P
0 g
s
.16503 .74269 m .16503 .72417 L .1814 .7168 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.3253 .58869 m .3253 .64427 L .29784 .63988 L p .707 .577 .707 r
F P
0 g
s
.29784 .63988 m .29784 .5843 L .3253 .58869 L p .707 .577 .707 r
F P
0 g
s
.1814 .7168 m .1814 .73533 L .16503 .74269 L p .707 .577 .707 r
F P
0 g
s
.20545 .58655 m .20545 .64214 L .1814 .64779 L p .707 .577 .707 r
F P
0 g
s
.20545 .64214 m .20545 .58655 L .23483 .58318 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76493 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.34635 .71974 m .34635 .73827 L .3253 .73181 L p .707 .577 .707 r
F P
0 g
s
.3253 .73181 m .3253 .71329 L .34635 .71974 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.62206 .26731 m .62206 .7692 L .59233 .76008 L p .707 .577 .707 r
F P
0 g
s
.59233 .76008 m .59233 .2582 L .62206 .26731 L p .707 .577 .707 r
F P
0 g
s
.29784 .5843 m .29784 .63988 L .26667 .63798 L p .707 .577 .707 r
F P
0 g
s
.26667 .63798 m .26667 .5824 L .29784 .5843 L p .707 .577 .707 r
F P
0 g
s
.23483 .63876 m .23483 .58318 L .26667 .5824 L p .707 .577 .707 r
F P
0 g
s
.23483 .58318 m .23483 .63876 L .20545 .64214 L p .707 .577 .707 r
F P
0 g
s
.1814 .73533 m .1814 .7168 L .20545 .71115 L p .707 .577 .707 r
F P
0 g
s
.26667 .5824 m .26667 .63798 L .23483 .63876 L p .707 .577 .707 r
F P
0 g
s
.73333 .63747 m .73333 .58189 L .70216 .57999 L p .707 .577 .707 r
F P
0 g
s
.73333 .58189 m .73333 .63747 L .76517 .63669 L p .707 .577 .707 r
F P
0 g
s
.76517 .63669 m .76517 .58111 L .73333 .58189 L p .707 .577 .707 r
F P
0 g
s
.1814 .76493 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.76517 .58111 m .76517 .63669 L .79455 .63331 L p .707 .577 .707 r
F P
0 g
s
.79455 .63331 m .79455 .57773 L .76517 .58111 L p .707 .577 .707 r
F P
0 g
s
.20545 .71115 m .20545 .72968 L .1814 .73533 L p .707 .577 .707 r
F P
0 g
s
.38918 .26316 m .38918 .76504 L .36607 .77545 L p .707 .577 .707 r
F P
0 g
s
.38918 .76504 m .38918 .26316 L .42314 .25518 L p .707 .577 .707 r
F P
0 g
s
.70216 .63557 m .70216 .57999 L .6747 .57559 L p .707 .577 .707 r
F P
0 g
s
.70216 .57999 m .70216 .63557 L .73333 .63747 L p .707 .577 .707 r
F P
0 g
s
.3253 .71329 m .3253 .73181 L .29784 .72742 L p .707 .577 .707 r
F P
0 g
s
.29784 .72742 m .29784 .70889 L .3253 .71329 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75928 L .1814 .76493 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71997 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.79455 .57773 m .79455 .63331 L .8186 .62766 L p .707 .577 .707 r
F P
0 g
s
.8186 .62766 m .8186 .57208 L .79455 .57773 L p .707 .577 .707 r
F P
0 g
s
.20545 .72968 m .20545 .71115 L .23483 .70777 L p .707 .577 .707 r
F P
0 g
s
.20545 .75928 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.6747 .57559 m .6747 .63118 L .70216 .63557 L p .707 .577 .707 r
F P
0 g
s
.6747 .63118 m .6747 .57559 L .65365 .56914 L p .707 .577 .707 r
F P
0 g
s
.23483 .70777 m .23483 .7263 L .20545 .72968 L p .707 .577 .707 r
F P
0 g
s
.59233 .2582 m .59233 .76008 L .55357 .75388 L p .707 .577 .707 r
F P
0 g
s
.55357 .75388 m .55357 .25199 L .59233 .2582 L p .707 .577 .707 r
F P
0 g
s
.29784 .70889 m .29784 .72742 L .26667 .72552 L p .707 .577 .707 r
F P
0 g
s
.26667 .72552 m .26667 .70699 L .29784 .70889 L p .707 .577 .707 r
F P
0 g
s
.29784 .71997 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71807 L .29784 .71997 L p .707 .577 .707 r
F P
0 g
s
.23483 .7263 m .23483 .70777 L .26667 .70699 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75928 L p .707 .577 .707 r
F P
0 g
s
.26667 .70699 m .26667 .72552 L .23483 .7263 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71807 L p .707 .577 .707 r
F P
0 g
s
.73333 .72501 m .73333 .70648 L .70216 .70458 L p .707 .577 .707 r
F P
0 g
s
.73333 .70648 m .73333 .72501 L .76517 .72423 L p .707 .577 .707 r
F P
0 g
s
.76517 .72423 m .76517 .7057 L .73333 .70648 L p .707 .577 .707 r
F P
0 g
s
.42314 .75707 m .42314 .25518 L .46462 .25041 L p .707 .577 .707 r
F P
0 g
s
.42314 .25518 m .42314 .75707 L .38918 .76504 L p .707 .577 .707 r
F P
0 g
s
.8186 .57208 m .8186 .62766 L .83497 .6203 L p .707 .577 .707 r
F P
0 g
s
.83497 .6203 m .83497 .56471 L .8186 .57208 L p .707 .577 .707 r
F P
0 g
s
.26667 .71807 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.76517 .7057 m .76517 .72423 L .79455 .72085 L p .707 .577 .707 r
F P
0 g
s
.79455 .72085 m .79455 .70233 L .76517 .7057 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71678 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.65365 .56914 m .65365 .62472 L .6747 .63118 L p .707 .577 .707 r
F P
0 g
s
.70216 .70458 m .70216 .72311 L .73333 .72501 L p .707 .577 .707 r
F P
0 g
s
.76517 .71678 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71678 L p .707 .577 .707 r
F P
0 g
s
.70216 .72311 m .70216 .70458 L .6747 .70019 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.65365 .62472 m .65365 .56914 L .64105 .56126 L p .707 .577 .707 r
F P
0 g
s
.55357 .25199 m .55357 .75388 L .50956 .7512 L p .707 .577 .707 r
F P
0 g
s
.50956 .7512 m .50956 .24931 L .55357 .25199 L p .707 .577 .707 r
F P
0 g
s
.6747 .70019 m .6747 .71872 L .70216 .72311 L p .707 .577 .707 r
F P
0 g
s
.79455 .70233 m .79455 .72085 L .8186 .7152 L p .707 .577 .707 r
F P
0 g
s
.8186 .7152 m .8186 .69668 L .79455 .70233 L p .707 .577 .707 r
F P
0 g
s
.46462 .7523 m .46462 .25041 L .50956 .24931 L p .707 .577 .707 r
F P
0 g
s
.46462 .25041 m .46462 .7523 L .42314 .75707 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74832 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.50956 .24931 m .50956 .7512 L .46462 .7523 L p .707 .577 .707 r
F P
0 g
s
.6747 .71872 m .6747 .70019 L .65365 .69374 L p .707 .577 .707 r
F P
0 g
s
.6747 .74832 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.64105 .56126 m .64105 .61684 L .65365 .62472 L p .707 .577 .707 r
F P
0 g
s
.83497 .56471 m .83497 .6203 L .84205 .61193 L p .707 .577 .707 r
F P
0 g
s
.84205 .61193 m .84205 .55635 L .83497 .56471 L p .707 .577 .707 r
F P
0 g
s
.65365 .69374 m .65365 .71226 L .6747 .71872 L p .707 .577 .707 r
F P
0 g
s
.8186 .69668 m .8186 .7152 L .83497 .70784 L p .707 .577 .707 r
F P
0 g
s
.83497 .70784 m .83497 .68931 L .8186 .69668 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74832 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73744 L p .707 .577 .707 r
F P
0 g
s
.83497 .73744 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.64105 .61684 m .64105 .56126 L .63816 .55271 L p .707 .577 .707 r
F P
0 g
s
.65365 .71226 m .65365 .69374 L .64105 .68585 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .68585 m .64105 .70438 L .65365 .71226 L p .707 .577 .707 r
F P
0 g
s
.63816 .55271 m .63816 .6083 L .64105 .61684 L p .707 .577 .707 r
F P
0 g
s
.84205 .55635 m .84205 .61193 L .83916 .60339 L p .707 .577 .707 r
F P
0 g
s
.83916 .60339 m .83916 .54781 L .84205 .55635 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.83497 .68931 m .83497 .70784 L .84206 .69947 L p .707 .577 .707 r
F P
0 g
s
.84206 .69947 m .84206 .68094 L .83497 .68931 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73744 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69202 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .6083 m .63816 .55271 L .64524 .54435 L p .707 .577 .707 r
F P
0 g
s
.64105 .70438 m .64105 .68585 L .63816 .67731 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.63816 .67731 m .63816 .69584 L .64105 .70438 L p .707 .577 .707 r
F P
0 g
s
.64524 .54435 m .64524 .59993 L .63816 .6083 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72544 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83916 .54781 m .83916 .60339 L .82657 .5955 L p .707 .577 .707 r
F P
0 g
s
.82657 .5955 m .82657 .53992 L .83916 .54781 L p .707 .577 .707 r
F P
0 g
s
.84206 .68094 m .84206 .69947 L .83916 .69093 L p .707 .577 .707 r
F P
0 g
s
.83916 .69093 m .83916 .6724 L .84206 .68094 L p .707 .577 .707 r
F P
0 g
s
.84206 .69202 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69202 L p .707 .577 .707 r
F P
0 g
s
.39032 .60065 m .39032 .54507 L .35915 .54317 L p .707 .577 .707 r
F P
0 g
s
.39032 .54507 m .39032 .60065 L .42216 .59988 L p .707 .577 .707 r
F P
0 g
s
.42216 .59988 m .42216 .54429 L .39032 .54507 L p .707 .577 .707 r
F P
0 g
s
.64524 .59993 m .64524 .54435 L .66161 .53698 L p .707 .577 .707 r
F P
0 g
s
.42216 .54429 m .42216 .59988 L .45154 .5965 L p .707 .577 .707 r
F P
0 g
s
.45154 .5965 m .45154 .54092 L .42216 .54429 L p .707 .577 .707 r
F P
0 g
s
.35915 .59875 m .35915 .54317 L .33169 .53878 L p .707 .577 .707 r
F P
0 g
s
.35915 .54317 m .35915 .59875 L .39032 .60065 L p .707 .577 .707 r
F P
0 g
s
.63816 .69584 m .63816 .67731 L .64524 .66894 L p .707 .577 .707 r
F P
0 g
s
.63816 .72544 m .63816 .68839 L .64524 .68002 L p .707 .577 .707 r
F P
0 g
s
.64524 .66894 m .64524 .68747 L .63816 .69584 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54092 m .45154 .5965 L .47559 .59085 L p .707 .577 .707 r
F P
0 g
s
.47559 .59085 m .47559 .53527 L .45154 .54092 L p .707 .577 .707 r
F P
0 g
s
.66161 .53698 m .66161 .59256 L .64524 .59993 L p .707 .577 .707 r
F P
0 g
s
.82657 .53992 m .82657 .5955 L .80551 .58905 L p .707 .577 .707 r
F P
0 g
s
.80551 .58905 m .80551 .53347 L .82657 .53992 L p .707 .577 .707 r
F P
0 g
s
.64524 .68002 m .64524 .71708 L .63816 .72544 L p .707 .577 .707 r
F P
0 g
s
.33169 .53878 m .33169 .59436 L .35915 .59875 L p .707 .577 .707 r
F P
0 g
s
.33169 .59436 m .33169 .53878 L .31064 .53232 L p .707 .577 .707 r
F P
0 g
s
.83916 .6724 m .83916 .69093 L .82657 .68305 L p .707 .577 .707 r
F P
0 g
s
.82657 .68305 m .82657 .66452 L .83916 .6724 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59256 m .66161 .53698 L .68566 .53133 L p .707 .577 .707 r
F P
0 g
s
.39032 .68819 m .39032 .66967 L .35915 .66777 L p .707 .577 .707 r
F P
0 g
s
.39032 .66967 m .39032 .68819 L .42216 .68742 L p .707 .577 .707 r
F P
0 g
s
.42216 .68742 m .42216 .66889 L .39032 .66967 L p .707 .577 .707 r
F P
0 g
s
.47559 .53527 m .47559 .59085 L .49196 .58348 L p .707 .577 .707 r
F P
0 g
s
.49196 .58348 m .49196 .5279 L .47559 .53527 L p .707 .577 .707 r
F P
0 g
s
.64524 .68747 m .64524 .66894 L .66161 .66158 L p .707 .577 .707 r
F P
0 g
s
.42216 .66889 m .42216 .68742 L .45154 .68404 L p .707 .577 .707 r
F P
0 g
s
.45154 .68404 m .45154 .66551 L .42216 .66889 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71702 L p .707 .577 .707 r
F P
0 g
s
.42216 .71702 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.31064 .53232 m .31064 .58791 L .33169 .59436 L p .707 .577 .707 r
F P
0 g
s
.35915 .66777 m .35915 .68629 L .39032 .68819 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68002 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71702 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .68629 m .35915 .66777 L .33169 .66337 L p .707 .577 .707 r
F P
0 g
s
.80551 .53347 m .80551 .58905 L .77805 .58466 L p .707 .577 .707 r
F P
0 g
s
.77805 .58466 m .77805 .52908 L .80551 .53347 L p .707 .577 .707 r
F P
0 g
s
.66161 .66158 m .66161 .6801 L .64524 .68747 L p .707 .577 .707 r
F P
0 g
s
.68566 .53133 m .68566 .58691 L .66161 .59256 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67445 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.31064 .58791 m .31064 .53232 L .29804 .52444 L p .707 .577 .707 r
F P
0 g
s
.33169 .66337 m .33169 .6819 L .35915 .68629 L p .707 .577 .707 r
F P
0 g
s
.68566 .58691 m .68566 .53133 L .71504 .52795 L p .707 .577 .707 r
F P
0 g
s
.45154 .66551 m .45154 .68404 L .47559 .67839 L p .707 .577 .707 r
F P
0 g
s
.47559 .67839 m .47559 .65986 L .45154 .66551 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.82657 .66452 m .82657 .68305 L .80551 .67659 L p .707 .577 .707 r
F P
0 g
s
.80551 .67659 m .80551 .65806 L .82657 .66452 L p .707 .577 .707 r
F P
0 g
s
.33169 .67445 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66914 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.33169 .6819 m .33169 .66337 L .31064 .65692 L p .707 .577 .707 r
F P
0 g
s
.77805 .52908 m .77805 .58466 L .74688 .58276 L p .707 .577 .707 r
F P
0 g
s
.74688 .58276 m .74688 .52718 L .77805 .52908 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67445 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.29804 .52444 m .29804 .58002 L .31064 .58791 L p .707 .577 .707 r
F P
0 g
s
.71504 .58354 m .71504 .52795 L .74688 .52718 L p .707 .577 .707 r
F P
0 g
s
.71504 .52795 m .71504 .58354 L .68566 .58691 L p .707 .577 .707 r
F P
0 g
s
.49196 .5279 m .49196 .58348 L .49904 .57512 L p .707 .577 .707 r
F P
0 g
s
.49904 .57512 m .49904 .51953 L .49196 .5279 L p .707 .577 .707 r
F P
0 g
s
.31064 .65692 m .31064 .67545 L .33169 .6819 L p .707 .577 .707 r
F P
0 g
s
.66161 .6801 m .66161 .66158 L .68566 .65593 L p .707 .577 .707 r
F P
0 g
s
.74688 .52718 m .74688 .58276 L .71504 .58354 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.68566 .65593 m .68566 .67445 L .66161 .6801 L p .707 .577 .707 r
F P
0 g
s
.47559 .65986 m .47559 .67839 L .49196 .67102 L p .707 .577 .707 r
F P
0 g
s
.49196 .67102 m .49196 .65249 L .47559 .65986 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70505 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66357 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.29804 .58002 m .29804 .52444 L .29515 .5159 L p .707 .577 .707 r
F P
0 g
s
.80551 .65806 m .80551 .67659 L .77805 .6722 L p .707 .577 .707 r
F P
0 g
s
.77805 .6722 m .77805 .65367 L .80551 .65806 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66914 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66914 L p .707 .577 .707 r
F P
0 g
s
.31064 .67545 m .31064 .65692 L .29804 .64904 L p .707 .577 .707 r
F P
0 g
s
.31064 .70505 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.68566 .67445 m .68566 .65593 L .71504 .65255 L p .707 .577 .707 r
F P
0 g
s
.29804 .64904 m .29804 .66756 L .31064 .67545 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.71504 .65255 m .71504 .67108 L .68566 .67445 L p .707 .577 .707 r
F P
0 g
s
.29515 .5159 m .29515 .57148 L .29804 .58002 L p .707 .577 .707 r
F P
0 g
s
.49904 .51953 m .49904 .57512 L .49615 .56657 L p .707 .577 .707 r
F P
0 g
s
.49615 .56657 m .49615 .51099 L .49904 .51953 L p .707 .577 .707 r
F P
0 g
s
.77805 .65367 m .77805 .6722 L .74688 .6703 L p .707 .577 .707 r
F P
0 g
s
.74688 .6703 m .74688 .65177 L .77805 .65367 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70505 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.71504 .67108 m .71504 .65255 L .74688 .65177 L p .707 .577 .707 r
F P
0 g
s
.49196 .65249 m .49196 .67102 L .49904 .66266 L p .707 .577 .707 r
F P
0 g
s
.49904 .66266 m .49904 .64413 L .49196 .65249 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.74688 .65177 m .74688 .6703 L .71504 .67108 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66357 m .49196 .70063 L .49904 .69226 L p .707 .577 .707 r
F P
0 g
s
.49904 .69226 m .49904 .65521 L .49196 .66357 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.29515 .57148 m .29515 .5159 L .30223 .50753 L p .707 .577 .707 r
F P
0 g
s
.29804 .66756 m .29804 .64904 L .29515 .64049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29804 .69717 m .29804 .66012 L .29515 .65157 L p .707 .577 .707 r
F P
0 g
s
.29515 .64049 m .29515 .65902 L .29804 .66756 L p .707 .577 .707 r
F P
0 g
s
.30223 .50753 m .30223 .56312 L .29515 .57148 L p .707 .577 .707 r
F P
0 g
s
.29515 .65157 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.49615 .51099 m .49615 .56657 L .48356 .55869 L p .707 .577 .707 r
F P
0 g
s
.48356 .55869 m .48356 .50311 L .49615 .51099 L p .707 .577 .707 r
F P
0 g
s
.49904 .64413 m .49904 .66266 L .49615 .65411 L p .707 .577 .707 r
F P
0 g
s
.49615 .65411 m .49615 .63559 L .49904 .64413 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69226 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .56312 m .30223 .50753 L .3186 .50017 L p .707 .577 .707 r
F P
0 g
s
.29515 .65902 m .29515 .64049 L .30223 .63213 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65157 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .63213 m .30223 .65066 L .29515 .65902 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .50017 m .3186 .55575 L .30223 .56312 L p .707 .577 .707 r
F P
0 g
s
.48356 .50311 m .48356 .55869 L .4625 .55224 L p .707 .577 .707 r
F P
0 g
s
.4625 .55224 m .4625 .49665 L .48356 .50311 L p .707 .577 .707 r
F P
0 g
s
.30223 .64321 m .30223 .68026 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49615 .63559 m .49615 .65411 L .48356 .64623 L p .707 .577 .707 r
F P
0 g
s
.48356 .64623 m .48356 .6277 L .49615 .63559 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55575 m .3186 .50017 L .34265 .49452 L p .707 .577 .707 r
F P
0 g
s
.30223 .65066 m .30223 .63213 L .3186 .62476 L p .707 .577 .707 r
F P
0 g
s
.30223 .68026 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.4625 .49665 m .4625 .55224 L .43504 .54784 L p .707 .577 .707 r
F P
0 g
s
.43504 .54784 m .43504 .49226 L .4625 .49665 L p .707 .577 .707 r
F P
0 g
s
.3186 .62476 m .3186 .64329 L .30223 .65066 L p .707 .577 .707 r
F P
0 g
s
.34265 .49452 m .34265 .5501 L .3186 .55575 L p .707 .577 .707 r
F P
0 g
s
.34265 .5501 m .34265 .49452 L .37203 .49114 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68026 L p .707 .577 .707 r
F P
0 g
s
.48356 .6277 m .48356 .64623 L .4625 .63978 L p .707 .577 .707 r
F P
0 g
s
.4625 .63978 m .4625 .62125 L .48356 .6277 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66938 L p .707 .577 .707 r
F P
0 g
s
.4625 .66938 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.43504 .49226 m .43504 .54784 L .40387 .54594 L p .707 .577 .707 r
F P
0 g
s
.40387 .54594 m .40387 .49036 L .43504 .49226 L p .707 .577 .707 r
F P
0 g
s
.37203 .54672 m .37203 .49114 L .40387 .49036 L p .707 .577 .707 r
F P
0 g
s
.37203 .49114 m .37203 .54672 L .34265 .5501 L p .707 .577 .707 r
F P
0 g
s
.3186 .64329 m .3186 .62476 L .34265 .61911 L p .707 .577 .707 r
F P
0 g
s
.40387 .49036 m .40387 .54594 L .37203 .54672 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.34265 .61911 m .34265 .63764 L .3186 .64329 L p .707 .577 .707 r
F P
0 g
s
.4625 .62125 m .4625 .63978 L .43504 .63538 L p .707 .577 .707 r
F P
0 g
s
.43504 .63538 m .43504 .61686 L .4625 .62125 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66938 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.34265 .63764 m .34265 .61911 L .37203 .61573 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.37203 .61573 m .37203 .63426 L .34265 .63764 L p .707 .577 .707 r
F P
0 g
s
.43504 .61686 m .43504 .63538 L .40387 .63348 L p .707 .577 .707 r
F P
0 g
s
.40387 .63348 m .40387 .61496 L .43504 .61686 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.37203 .63426 m .37203 .61573 L .40387 .61496 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.40387 .61496 m .40387 .63348 L .37203 .63426 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo002;Ool<0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<0
00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001^Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo2@00A7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<005YFFUH00UYF2000?7oo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool003mooa4000Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH5
0004FUH01000FUIJEUYF0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF100025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH8000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUHK0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH900000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00T000AJEP03
001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUHF0004FUH00`00FUIJ
EP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60004FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP<000AJEP03001JEUYF009J
EP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800004FUH005YF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL00005FUH005YFFUH00003FUH20000
0eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo4P00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH01000FUH005YF0P000eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00002FUH00`00FUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH00003FUH30002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`04001JEP00FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH01@00FUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol002aoo`06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF00000P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00003000jOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP<000AJEP03001JEUYF00IJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@0039o
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF0P00<Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEP0000<000IJEP04001JEUYFFUHC
0002FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEP0000=JEP03001JEUYF009JEP<00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUH00000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EP<00003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH20004FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP02FUH00`00Oomoo`0/Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP06001JEP00FUH005YF0P0000=JEP00FUH00UYF
00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=J
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF
00000UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<007ooOol0;7oo000`Ool30004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P0000AJEP00FUIJEP@000EJEP<000EJEQ40
00=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YF00000`000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool003Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30000
0eYF000000090005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000kOolJ0003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Egoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHN0003FUH50004FUH01000FUIJEUYF
0P00;Goo000oOolI0002Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP8002eoo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPX000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003
FUH30003FUH2000]Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003Ool0000000H000AJEP03001JEUYF00=JEPT000MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000800006FUH00000001JEP001EYF0`0025YF100000=JEP0000001`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUHF
0004FUH00`00FUIJEP02FUH20002Ool01@00FUIJEP00FUH02P0015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P0000=JEP00000015YF00<005YFFUH00eYF200015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000^Ool20003FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD00004FUH000000004
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJ
EP<000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000800005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`04001JEP000003FUH00`00FUH0000300000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00@005YF001J
EP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00@005YF000000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000cOol002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004Ool30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50002Ool40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF
2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P000goo6@00
?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH6000AOol80004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF1P000UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000eYF
00<005YFFUH00UYF0P00FGoo000/Ool00`00FUH00004FUH00`00FUH000030004FUHI0002FUH60004
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF1@00
15YF0`00Egoo000/Ool00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH0000500001EYF001JEUYF00000UYF00<005YFFUH00eYF0`000UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P0000AJEP00FUIJEP8005Eoo`00;7oo00@0
05YF001JEP<000AJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50005FUH30002FUH01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00001EYF00<005YFFUH0
0UYF0P000eYF00<007ooOol0Dgoo000/Ool01`00FUH00000FUH005YF00<00003FUH005YF00AJEP<0
00AJEQ8000=JEP03001JEUYF00AJEP03001JEUYF00<0009JEP04001JEP000007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF00<005YF00001EYF00<005YFFUH00eYF0`0000=JEP000000E7oo000/Ool20003FUH00`00
FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH0
15YF00<005YFFUH00eYF00<005YFFUH00`00E7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF1@0000=JEP0000002@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF0000009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP0000=JEPD000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Aoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Ao
o`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00
27oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001EYF00<005YF00000`0000AJEP000000
00=JEP8005Aoo`00>goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@003Woo0`001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUIJEP/000EJEP04001JEUYF0002FUH2001DOol004=ooa<001Eoo`8000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001J
EP001eYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00E7oo001_Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol0079oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Aoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH01P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo0025OolF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002AOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000F7oo002BOol30003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Eoo`D000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00VWoo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002NOolI001VOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76948 m .59613 .7139 L .56496 .712 L p .707 .577 .707 r
F P
0 g
s
.59613 .7139 m .59613 .76948 L .62796 .76871 L p .707 .577 .707 r
F P
0 g
s
.62796 .76871 m .62796 .71312 L .59613 .7139 L p .707 .577 .707 r
F P
0 g
s
.62796 .71312 m .62796 .76871 L .65735 .76533 L p .707 .577 .707 r
F P
0 g
s
.65735 .76533 m .65734 .70975 L .62796 .71312 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .73601 L .56496 .73411 L p .707 .577 .707 r
F P
0 g
s
.59613 .73601 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .73601 L p .707 .577 .707 r
F P
0 g
s
.56496 .76758 m .56496 .712 L .5375 .70761 L p .707 .577 .707 r
F P
0 g
s
.56496 .712 m .56496 .76758 L .59613 .76948 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .73411 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .73411 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.65734 .70975 m .65735 .76533 L .6814 .75968 L p .707 .577 .707 r
F P
0 g
s
.6814 .75968 m .6814 .7041 L .65734 .70975 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76326 L p .707 .577 .707 r
F P
0 g
s
.6814 .76326 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.5375 .70761 m .5375 .76319 L .56496 .76758 L p .707 .577 .707 r
F P
0 g
s
.5375 .76319 m .5375 .70761 L .51644 .70116 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.6814 .7041 m .6814 .75968 L .69777 .75231 L p .707 .577 .707 r
F P
0 g
s
.69777 .75231 m .69777 .69673 L .6814 .7041 L p .707 .577 .707 r
F P
0 g
s
.51644 .70116 m .51644 .75674 L .5375 .76319 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76326 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.59613 .88634 m .59613 .86781 L .56496 .86591 L p .707 .577 .707 r
F P
0 g
s
.59613 .86781 m .59613 .88634 L .62796 .88556 L p .707 .577 .707 r
F P
0 g
s
.62796 .88556 m .62796 .86703 L .59613 .86781 L p .707 .577 .707 r
F P
0 g
s
.62796 .86703 m .62796 .88556 L .65735 .88218 L p .707 .577 .707 r
F P
0 g
s
.65735 .88218 m .65735 .86365 L .62796 .86703 L p .707 .577 .707 r
F P
0 g
s
.51644 .75674 m .51644 .70116 L .50385 .69327 L p .707 .577 .707 r
F P
0 g
s
.56496 .86591 m .56496 .88444 L .59613 .88634 L p .707 .577 .707 r
F P
0 g
s
.56496 .88444 m .56496 .86591 L .5375 .86152 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71538 L p .707 .577 .707 r
F P
0 g
s
.5375 .86152 m .5375 .88005 L .56496 .88444 L p .707 .577 .707 r
F P
0 g
s
.65735 .86365 m .65735 .88218 L .6814 .87653 L p .707 .577 .707 r
F P
0 g
s
.6814 .87653 m .6814 .858 L .65735 .86365 L p .707 .577 .707 r
F P
0 g
s
.50385 .69327 m .50385 .74885 L .51644 .75674 L p .707 .577 .707 r
F P
0 g
s
.69777 .69673 m .69777 .75231 L .70485 .74395 L p .707 .577 .707 r
F P
0 g
s
.70485 .74395 m .70485 .68836 L .69777 .69673 L p .707 .577 .707 r
F P
0 g
s
.50385 .71538 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.5375 .88005 m .5375 .86152 L .51644 .85506 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.51644 .85506 m .51644 .87359 L .5375 .88005 L p .707 .577 .707 r
F P
0 g
s
.50385 .74885 m .50385 .69327 L .50095 .68473 L p .707 .577 .707 r
F P
0 g
s
.6814 .858 m .6814 .87653 L .69777 .86916 L p .707 .577 .707 r
F P
0 g
s
.69777 .86916 m .69777 .85064 L .6814 .858 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71538 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.51644 .87359 m .51644 .85506 L .50385 .84718 L p .707 .577 .707 r
F P
0 g
s
.50095 .68473 m .50095 .74031 L .50385 .74885 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.70485 .68836 m .70485 .74395 L .70195 .7354 L p .707 .577 .707 r
F P
0 g
s
.70195 .7354 m .70195 .67982 L .70485 .68836 L p .707 .577 .707 r
F P
0 g
s
.50385 .84718 m .50385 .86571 L .51644 .87359 L p .707 .577 .707 r
F P
0 g
s
.49044 .81524 m .49044 .31335 L .44643 .31066 L p .707 .577 .707 r
F P
0 g
s
.50095 .74031 m .50095 .68473 L .50804 .67636 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .67636 m .50804 .73195 L .50095 .74031 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .73195 m .50804 .67636 L .5244 .669 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.5244 .669 m .5244 .72458 L .50804 .73195 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72816 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .72458 m .5244 .669 L .54846 .66335 L p .707 .577 .707 r
F P
0 g
s
.5244 .72816 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.54846 .66335 m .54846 .71893 L .5244 .72458 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .72251 L .5244 .72816 L p .707 .577 .707 r
F P
0 g
s
.49044 .31335 m .49044 .81524 L .53538 .81414 L p .707 .577 .707 r
F P
0 g
s
.53538 .81414 m .53538 .31225 L .49044 .31335 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70193 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.54846 .71893 m .54846 .66335 L .57784 .65997 L p .707 .577 .707 r
F P
0 g
s
.54846 .72251 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.57784 .65997 m .57784 .71555 L .54846 .71893 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .72251 L p .707 .577 .707 r
F P
0 g
s
.53538 .31225 m .53538 .81414 L .57686 .80937 L p .707 .577 .707 r
F P
0 g
s
.57686 .80937 m .57686 .30748 L .53538 .31225 L p .707 .577 .707 r
F P
0 g
s
.44643 .81255 m .44643 .31066 L .40766 .30446 L p .707 .577 .707 r
F P
0 g
s
.44643 .31066 m .44643 .81255 L .49044 .81524 L p .707 .577 .707 r
F P
0 g
s
.69777 .85064 m .69777 .86916 L .70485 .8608 L p .707 .577 .707 r
F P
0 g
s
.70485 .8608 m .70485 .84227 L .69777 .85064 L p .707 .577 .707 r
F P
0 g
s
.57784 .71555 m .57784 .65997 L .60968 .65919 L p .707 .577 .707 r
F P
0 g
s
.60968 .65919 m .60968 .71477 L .57784 .71555 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .6813 L p .707 .577 .707 r
F P
0 g
s
.60968 .6813 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.57686 .30748 m .57686 .80937 L .61082 .80139 L p .707 .577 .707 r
F P
0 g
s
.64085 .66109 m .64085 .71667 L .60968 .71477 L p .707 .577 .707 r
F P
0 g
s
.60968 .71477 m .60968 .65919 L .64085 .66109 L p .707 .577 .707 r
F P
0 g
s
.64085 .6832 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .6813 L .64085 .6832 L p .707 .577 .707 r
F P
0 g
s
.61082 .80139 m .61082 .2995 L .57686 .30748 L p .707 .577 .707 r
F P
0 g
s
.50385 .86571 m .50385 .84718 L .50095 .83864 L p .707 .577 .707 r
F P
0 g
s
.50095 .83864 m .50095 .85716 L .50385 .86571 L p .707 .577 .707 r
F P
0 g
s
.70195 .67982 m .70195 .7354 L .68936 .72752 L p .707 .577 .707 r
F P
0 g
s
.68936 .72752 m .68936 .67194 L .70195 .67982 L p .707 .577 .707 r
F P
0 g
s
.40766 .80635 m .40766 .30446 L .37794 .29535 L p .707 .577 .707 r
F P
0 g
s
.40766 .30446 m .40766 .80635 L .44643 .81255 L p .707 .577 .707 r
F P
0 g
s
.70195 .70193 m .70195 .73898 L .68936 .7311 L p .707 .577 .707 r
F P
0 g
s
.68936 .7311 m .68936 .69404 L .70195 .70193 L p .707 .577 .707 r
F P
0 g
s
.25312 .73267 m .25312 .67709 L .22195 .67519 L p .707 .577 .707 r
F P
0 g
s
.25312 .67709 m .25312 .73267 L .28495 .73189 L p .707 .577 .707 r
F P
0 g
s
.28495 .73189 m .28495 .67631 L .25312 .67709 L p .707 .577 .707 r
F P
0 g
s
.70485 .84227 m .70485 .8608 L .70195 .85226 L p .707 .577 .707 r
F P
0 g
s
.70195 .85226 m .70195 .83373 L .70485 .84227 L p .707 .577 .707 r
F P
0 g
s
.28495 .67631 m .28495 .73189 L .31434 .72851 L p .707 .577 .707 r
F P
0 g
s
.31434 .72851 m .31434 .67293 L .28495 .67631 L p .707 .577 .707 r
F P
0 g
s
.25312 .73625 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73625 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.22195 .73077 m .22195 .67519 L .19449 .67079 L p .707 .577 .707 r
F P
0 g
s
.22195 .67519 m .22195 .73077 L .25312 .73267 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69504 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.61082 .2995 m .61082 .80139 L .63393 .79099 L p .707 .577 .707 r
F P
0 g
s
.63393 .79099 m .63393 .2891 L .61082 .2995 L p .707 .577 .707 r
F P
0 g
s
.22195 .73435 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73435 L .25312 .73625 L p .707 .577 .707 r
F P
0 g
s
.31434 .67293 m .31434 .72851 L .33839 .72286 L p .707 .577 .707 r
F P
0 g
s
.33839 .72286 m .33839 .66728 L .31434 .67293 L p .707 .577 .707 r
F P
0 g
s
.50095 .85716 m .50095 .83864 L .50804 .83027 L p .707 .577 .707 r
F P
0 g
s
.68936 .67194 m .68936 .72752 L .66831 .72107 L p .707 .577 .707 r
F P
0 g
s
.66831 .72107 m .66831 .66548 L .68936 .67194 L p .707 .577 .707 r
F P
0 g
s
.50804 .83027 m .50804 .8488 L .50095 .85716 L p .707 .577 .707 r
F P
0 g
s
.31434 .69504 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68939 L .31434 .69504 L p .707 .577 .707 r
F P
0 g
s
.19449 .67079 m .19449 .72638 L .22195 .73077 L p .707 .577 .707 r
F P
0 g
s
.19449 .72638 m .19449 .67079 L .17343 .66434 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73435 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .7311 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.37794 .79724 m .37794 .29535 L .36016 .28422 L p .707 .577 .707 r
F P
0 g
s
.37794 .29535 m .37794 .79724 L .40766 .80635 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.70195 .83373 m .70195 .85226 L .68936 .84437 L p .707 .577 .707 r
F P
0 g
s
.68936 .84437 m .68936 .82585 L .70195 .83373 L p .707 .577 .707 r
F P
0 g
s
.33839 .66728 m .33839 .72286 L .35476 .7155 L p .707 .577 .707 r
F P
0 g
s
.35476 .7155 m .35476 .65991 L .33839 .66728 L p .707 .577 .707 r
F P
0 g
s
.17343 .66434 m .17343 .71992 L .19449 .72638 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68939 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68939 L p .707 .577 .707 r
F P
0 g
s
.66831 .66548 m .66831 .72107 L .64085 .71667 L p .707 .577 .707 r
F P
0 g
s
.64085 .71667 m .64085 .66109 L .66831 .66548 L p .707 .577 .707 r
F P
0 g
s
.25312 .84952 m .25312 .831 L .22195 .82909 L p .707 .577 .707 r
F P
0 g
s
.25312 .831 m .25312 .84952 L .28495 .84875 L p .707 .577 .707 r
F P
0 g
s
.28495 .84875 m .28495 .83022 L .25312 .831 L p .707 .577 .707 r
F P
0 g
s
.50804 .8488 m .50804 .83027 L .5244 .82291 L p .707 .577 .707 r
F P
0 g
s
.28495 .83022 m .28495 .84875 L .31434 .84537 L p .707 .577 .707 r
F P
0 g
s
.31434 .84537 m .31434 .82684 L .28495 .83022 L p .707 .577 .707 r
F P
0 g
s
.17343 .71992 m .17343 .66434 L .16084 .65646 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .6832 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.22195 .82909 m .22195 .84762 L .25312 .84952 L p .707 .577 .707 r
F P
0 g
s
.63393 .2891 m .63393 .79099 L .64393 .77918 L p .707 .577 .707 r
F P
0 g
s
.64393 .77918 m .64393 .27729 L .63393 .2891 L p .707 .577 .707 r
F P
0 g
s
.22195 .84762 m .22195 .82909 L .19449 .8247 L p .707 .577 .707 r
F P
0 g
s
.5244 .82291 m .5244 .84143 L .50804 .8488 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.19449 .8247 m .19449 .84323 L .22195 .84762 L p .707 .577 .707 r
F P
0 g
s
.31434 .82684 m .31434 .84537 L .33839 .83972 L p .707 .577 .707 r
F P
0 g
s
.33839 .83972 m .33839 .82119 L .31434 .82684 L p .707 .577 .707 r
F P
0 g
s
.16084 .65646 m .16084 .71204 L .17343 .71992 L p .707 .577 .707 r
F P
0 g
s
.68936 .82585 m .68936 .84437 L .66831 .83792 L p .707 .577 .707 r
F P
0 g
s
.66831 .83792 m .66831 .81939 L .68936 .82585 L p .707 .577 .707 r
F P
0 g
s
.35476 .65991 m .35476 .7155 L .36184 .70713 L p .707 .577 .707 r
F P
0 g
s
.36184 .70713 m .36184 .65155 L .35476 .65991 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.19449 .84323 m .19449 .8247 L .17343 .81825 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .65155 m .36184 .70713 L .35894 .69859 L p .707 .577 .707 r
F P
0 g
s
.35894 .69859 m .35894 .64301 L .36184 .65155 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70217 L p .707 .577 .707 r
F P
0 g
s
.35894 .70217 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .78611 m .36016 .28422 L .35607 .27216 L p .707 .577 .707 r
F P
0 g
s
.36016 .28422 m .36016 .78611 L .37794 .79724 L p .707 .577 .707 r
F P
0 g
s
.17343 .81825 m .17343 .83678 L .19449 .84323 L p .707 .577 .707 r
F P
0 g
s
.5244 .84143 m .5244 .82291 L .54846 .81726 L p .707 .577 .707 r
F P
0 g
s
.16084 .71204 m .16084 .65646 L .15794 .64791 L p .707 .577 .707 r
F P
0 g
s
.54846 .81726 m .54846 .83578 L .5244 .84143 L p .707 .577 .707 r
F P
0 g
s
.33839 .82119 m .33839 .83972 L .35476 .83235 L p .707 .577 .707 r
F P
0 g
s
.35476 .83235 m .35476 .81382 L .33839 .82119 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.66831 .81939 m .66831 .83792 L .64085 .83353 L p .707 .577 .707 r
F P
0 g
s
.64085 .83353 m .64085 .815 L .66831 .81939 L p .707 .577 .707 r
F P
0 g
s
.17343 .83678 m .17343 .81825 L .16084 .81036 L p .707 .577 .707 r
F P
0 g
s
.15794 .64791 m .15794 .7035 L .16084 .71204 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.64393 .27729 m .64393 .77918 L .63984 .76712 L p .707 .577 .707 r
F P
0 g
s
.63984 .76712 m .63984 .26523 L .64393 .27729 L p .707 .577 .707 r
F P
0 g
s
.54846 .83578 m .54846 .81726 L .57784 .81388 L p .707 .577 .707 r
F P
0 g
s
.16084 .81036 m .16084 .82889 L .17343 .83678 L p .707 .577 .707 r
F P
0 g
s
.57784 .81388 m .57784 .8324 L .54846 .83578 L p .707 .577 .707 r
F P
0 g
s
.64085 .815 m .64085 .83353 L .60968 .83163 L p .707 .577 .707 r
F P
0 g
s
.60968 .83163 m .60968 .8131 L .64085 .815 L p .707 .577 .707 r
F P
0 g
s
.57784 .8324 m .57784 .81388 L .60968 .8131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81382 m .35476 .83235 L .36184 .82399 L p .707 .577 .707 r
F P
0 g
s
.36184 .82399 m .36184 .80546 L .35476 .81382 L p .707 .577 .707 r
F P
0 g
s
.15794 .7035 m .15794 .64791 L .16503 .63955 L p .707 .577 .707 r
F P
0 g
s
.60968 .8131 m .60968 .83163 L .57784 .8324 L p .707 .577 .707 r
F P
0 g
s
.35894 .64301 m .35894 .69859 L .34635 .6907 L p .707 .577 .707 r
F P
0 g
s
.34635 .6907 m .34635 .63512 L .35894 .64301 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70217 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65723 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .27216 m .35607 .77405 L .36016 .78611 L p .707 .577 .707 r
F P
0 g
s
.35607 .77405 m .35607 .27216 L .36607 .26035 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.16084 .82889 m .16084 .81036 L .15794 .80182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .63955 m .16503 .69513 L .15794 .7035 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.15794 .80182 m .15794 .82035 L .16084 .82889 L p .707 .577 .707 r
F P
0 g
s
.36184 .80546 m .36184 .82399 L .35894 .81544 L p .707 .577 .707 r
F P
0 g
s
.35894 .81544 m .35894 .79692 L .36184 .80546 L p .707 .577 .707 r
F P
0 g
s
.63984 .26523 m .63984 .76712 L .62206 .75599 L p .707 .577 .707 r
F P
0 g
s
.62206 .75599 m .62206 .2541 L .63984 .26523 L p .707 .577 .707 r
F P
0 g
s
.16503 .69513 m .16503 .63955 L .1814 .63218 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65429 L p .707 .577 .707 r
F P
0 g
s
.15794 .82035 m .15794 .80182 L .16503 .79346 L p .707 .577 .707 r
F P
0 g
s
.1814 .63218 m .1814 .68776 L .16503 .69513 L p .707 .577 .707 r
F P
0 g
s
.34635 .63512 m .34635 .6907 L .3253 .68425 L p .707 .577 .707 r
F P
0 g
s
.3253 .68425 m .3253 .62867 L .34635 .63512 L p .707 .577 .707 r
F P
0 g
s
.1814 .65429 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.36607 .76224 m .36607 .26035 L .38918 .24995 L p .707 .577 .707 r
F P
0 g
s
.36607 .26035 m .36607 .76224 L .35607 .77405 L p .707 .577 .707 r
F P
0 g
s
.16503 .79346 m .16503 .81199 L .15794 .82035 L p .707 .577 .707 r
F P
0 g
s
.34635 .65723 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65723 L p .707 .577 .707 r
F P
0 g
s
.1814 .68776 m .1814 .63218 L .20545 .62653 L p .707 .577 .707 r
F P
0 g
s
.35894 .79692 m .35894 .81544 L .34635 .80756 L p .707 .577 .707 r
F P
0 g
s
.34635 .80756 m .34635 .78903 L .35894 .79692 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65429 L .20545 .64864 L p .707 .577 .707 r
F P
0 g
s
.3253 .62867 m .3253 .68425 L .29784 .67986 L p .707 .577 .707 r
F P
0 g
s
.29784 .67986 m .29784 .62428 L .3253 .62867 L p .707 .577 .707 r
F P
0 g
s
.62206 .2541 m .62206 .75599 L .59233 .74688 L p .707 .577 .707 r
F P
0 g
s
.59233 .74688 m .59233 .24499 L .62206 .2541 L p .707 .577 .707 r
F P
0 g
s
.20545 .62653 m .20545 .68211 L .1814 .68776 L p .707 .577 .707 r
F P
0 g
s
.16503 .81199 m .16503 .79346 L .1814 .78609 L p .707 .577 .707 r
F P
0 g
s
.20545 .64864 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68344 L p .707 .577 .707 r
F P
0 g
s
.29784 .68344 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68211 m .20545 .62653 L .23483 .62315 L p .707 .577 .707 r
F P
0 g
s
.1814 .78609 m .1814 .80462 L .16503 .81199 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64864 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.38918 .24995 m .38918 .75184 L .36607 .76224 L p .707 .577 .707 r
F P
0 g
s
.38918 .75184 m .38918 .24995 L .42314 .24197 L p .707 .577 .707 r
F P
0 g
s
.29784 .62428 m .29784 .67986 L .26667 .67796 L p .707 .577 .707 r
F P
0 g
s
.26667 .67796 m .26667 .62238 L .29784 .62428 L p .707 .577 .707 r
F P
0 g
s
.34635 .78903 m .34635 .80756 L .3253 .8011 L p .707 .577 .707 r
F P
0 g
s
.3253 .8011 m .3253 .78258 L .34635 .78903 L p .707 .577 .707 r
F P
0 g
s
.23483 .67873 m .23483 .62315 L .26667 .62238 L p .707 .577 .707 r
F P
0 g
s
.23483 .62315 m .23483 .67873 L .20545 .68211 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68344 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.26667 .62238 m .26667 .67796 L .23483 .67873 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.73333 .67745 m .73333 .62186 L .70216 .61996 L p .707 .577 .707 r
F P
0 g
s
.73333 .62186 m .73333 .67745 L .76517 .67667 L p .707 .577 .707 r
F P
0 g
s
.76517 .67667 m .76517 .62109 L .73333 .62186 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.76517 .62109 m .76517 .67667 L .79455 .67329 L p .707 .577 .707 r
F P
0 g
s
.79455 .67329 m .79455 .61771 L .76517 .62109 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.1814 .80462 m .1814 .78609 L .20545 .78044 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68025 L p .707 .577 .707 r
F P
0 g
s
.76517 .68025 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.70216 .67555 m .70216 .61996 L .6747 .61557 L p .707 .577 .707 r
F P
0 g
s
.70216 .61996 m .70216 .67555 L .73333 .67745 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68025 L .79455 .67687 L p .707 .577 .707 r
F P
0 g
s
.79455 .67687 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.59233 .24499 m .59233 .74688 L .55357 .74068 L p .707 .577 .707 r
F P
0 g
s
.55357 .74068 m .55357 .23879 L .59233 .24499 L p .707 .577 .707 r
F P
0 g
s
.20545 .78044 m .20545 .79897 L .1814 .80462 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63768 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.79455 .61771 m .79455 .67329 L .8186 .66764 L p .707 .577 .707 r
F P
0 g
s
.8186 .66764 m .8186 .61206 L .79455 .61771 L p .707 .577 .707 r
F P
0 g
s
.3253 .78258 m .3253 .8011 L .29784 .79671 L p .707 .577 .707 r
F P
0 g
s
.29784 .79671 m .29784 .77819 L .3253 .78258 L p .707 .577 .707 r
F P
0 g
s
.42314 .74386 m .42314 .24197 L .46462 .2372 L p .707 .577 .707 r
F P
0 g
s
.42314 .24197 m .42314 .74386 L .38918 .75184 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67687 L .8186 .67122 L p .707 .577 .707 r
F P
0 g
s
.8186 .67122 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.6747 .61557 m .6747 .67115 L .70216 .67555 L p .707 .577 .707 r
F P
0 g
s
.6747 .67115 m .6747 .61557 L .65365 .60912 L p .707 .577 .707 r
F P
0 g
s
.6747 .63768 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.20545 .79897 m .20545 .78044 L .23483 .77706 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63768 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.23483 .77706 m .23483 .79559 L .20545 .79897 L p .707 .577 .707 r
F P
0 g
s
.55357 .23879 m .55357 .74068 L .50956 .738 L p .707 .577 .707 r
F P
0 g
s
.50956 .738 m .50956 .23611 L .55357 .23879 L p .707 .577 .707 r
F P
0 g
s
.29784 .77819 m .29784 .79671 L .26667 .79481 L p .707 .577 .707 r
F P
0 g
s
.26667 .79481 m .26667 .77628 L .29784 .77819 L p .707 .577 .707 r
F P
0 g
s
.8186 .61206 m .8186 .66764 L .83497 .66027 L p .707 .577 .707 r
F P
0 g
s
.83497 .66027 m .83497 .60469 L .8186 .61206 L p .707 .577 .707 r
F P
0 g
s
.46462 .73909 m .46462 .2372 L .50956 .23611 L p .707 .577 .707 r
F P
0 g
s
.46462 .2372 m .46462 .73909 L .42314 .74386 L p .707 .577 .707 r
F P
0 g
s
.65365 .60912 m .65365 .6647 L .6747 .67115 L p .707 .577 .707 r
F P
0 g
s
.23483 .79559 m .23483 .77706 L .26667 .77628 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66828 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.50956 .23611 m .50956 .738 L .46462 .73909 L p .707 .577 .707 r
F P
0 g
s
.26667 .77628 m .26667 .79481 L .23483 .79559 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67122 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.73333 .7943 m .73333 .77577 L .70216 .77387 L p .707 .577 .707 r
F P
0 g
s
.73333 .77577 m .73333 .7943 L .76517 .79352 L p .707 .577 .707 r
F P
0 g
s
.76517 .79352 m .76517 .775 L .73333 .77577 L p .707 .577 .707 r
F P
0 g
s
.76517 .775 m .76517 .79352 L .79455 .79014 L p .707 .577 .707 r
F P
0 g
s
.79455 .79014 m .79455 .77162 L .76517 .775 L p .707 .577 .707 r
F P
0 g
s
.65365 .6647 m .65365 .60912 L .64105 .60123 L p .707 .577 .707 r
F P
0 g
s
.70216 .77387 m .70216 .7924 L .73333 .7943 L p .707 .577 .707 r
F P
0 g
s
.70216 .7924 m .70216 .77387 L .6747 .76948 L p .707 .577 .707 r
F P
0 g
s
.65365 .66828 m .65365 .63122 L .64105 .62334 L p .707 .577 .707 r
F P
0 g
s
.6747 .76948 m .6747 .78801 L .70216 .7924 L p .707 .577 .707 r
F P
0 g
s
.79455 .77162 m .79455 .79014 L .8186 .78449 L p .707 .577 .707 r
F P
0 g
s
.8186 .78449 m .8186 .76597 L .79455 .77162 L p .707 .577 .707 r
F P
0 g
s
.64105 .60123 m .64105 .65681 L .65365 .6647 L p .707 .577 .707 r
F P
0 g
s
.83497 .60469 m .83497 .66027 L .84205 .65191 L p .707 .577 .707 r
F P
0 g
s
.84205 .65191 m .84205 .59633 L .83497 .60469 L p .707 .577 .707 r
F P
0 g
s
.64105 .62334 m .64105 .66039 L .65365 .66828 L p .707 .577 .707 r
F P
0 g
s
.6747 .78801 m .6747 .76948 L .65365 .76303 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.65365 .76303 m .65365 .78155 L .6747 .78801 L p .707 .577 .707 r
F P
0 g
s
.64105 .65681 m .64105 .60123 L .63816 .59269 L p .707 .577 .707 r
F P
0 g
s
.8186 .76597 m .8186 .78449 L .83497 .77713 L p .707 .577 .707 r
F P
0 g
s
.83497 .77713 m .83497 .7586 L .8186 .76597 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62334 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.65365 .78155 m .65365 .76303 L .64105 .75514 L p .707 .577 .707 r
F P
0 g
s
.63816 .59269 m .63816 .64827 L .64105 .65681 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.84205 .59633 m .84205 .65191 L .83916 .64337 L p .707 .577 .707 r
F P
0 g
s
.83916 .64337 m .83916 .58778 L .84205 .59633 L p .707 .577 .707 r
F P
0 g
s
.64105 .75514 m .64105 .77367 L .65365 .78155 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.83497 .7586 m .83497 .77713 L .84206 .76876 L p .707 .577 .707 r
F P
0 g
s
.84206 .76876 m .84206 .75023 L .83497 .7586 L p .707 .577 .707 r
F P
0 g
s
.63816 .64827 m .63816 .59269 L .64524 .58433 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.64105 .77367 m .64105 .75514 L .63816 .7466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58433 m .64524 .63991 L .63816 .64827 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64349 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.63816 .7466 m .63816 .76513 L .64105 .77367 L p .707 .577 .707 r
F P
0 g
s
.83916 .58778 m .83916 .64337 L .82657 .63548 L p .707 .577 .707 r
F P
0 g
s
.82657 .63548 m .82657 .5799 L .83916 .58778 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.39032 .64063 m .39032 .58505 L .35915 .58315 L p .707 .577 .707 r
F P
0 g
s
.39032 .58505 m .39032 .64063 L .42216 .63985 L p .707 .577 .707 r
F P
0 g
s
.42216 .63985 m .42216 .58427 L .39032 .58505 L p .707 .577 .707 r
F P
0 g
s
.84206 .75023 m .84206 .76876 L .83916 .76022 L p .707 .577 .707 r
F P
0 g
s
.83916 .76022 m .83916 .74169 L .84206 .75023 L p .707 .577 .707 r
F P
0 g
s
.64524 .63991 m .64524 .58433 L .66161 .57696 L p .707 .577 .707 r
F P
0 g
s
.42216 .58427 m .42216 .63985 L .45154 .63647 L p .707 .577 .707 r
F P
0 g
s
.45154 .63647 m .45154 .58089 L .42216 .58427 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60638 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.35915 .63873 m .35915 .58315 L .33169 .57876 L p .707 .577 .707 r
F P
0 g
s
.35915 .58315 m .35915 .63873 L .39032 .64063 L p .707 .577 .707 r
F P
0 g
s
.64524 .64349 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60638 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .603 L .42216 .60638 L p .707 .577 .707 r
F P
0 g
s
.35915 .64231 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .64231 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.45154 .58089 m .45154 .63647 L .47559 .63082 L p .707 .577 .707 r
F P
0 g
s
.47559 .63082 m .47559 .57524 L .45154 .58089 L p .707 .577 .707 r
F P
0 g
s
.63816 .76513 m .63816 .7466 L .64524 .73824 L p .707 .577 .707 r
F P
0 g
s
.66161 .57696 m .66161 .63254 L .64524 .63991 L p .707 .577 .707 r
F P
0 g
s
.82657 .5799 m .82657 .63548 L .80551 .62903 L p .707 .577 .707 r
F P
0 g
s
.80551 .62903 m .80551 .57344 L .82657 .5799 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64349 L p .707 .577 .707 r
F P
0 g
s
.64524 .73824 m .64524 .75676 L .63816 .76513 L p .707 .577 .707 r
F P
0 g
s
.45154 .603 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59735 L .45154 .603 L p .707 .577 .707 r
F P
0 g
s
.33169 .57876 m .33169 .63434 L .35915 .63873 L p .707 .577 .707 r
F P
0 g
s
.33169 .63434 m .33169 .57876 L .31064 .5723 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .64231 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .59441 L p .707 .577 .707 r
F P
0 g
s
.66161 .63254 m .66161 .57696 L .68566 .57131 L p .707 .577 .707 r
F P
0 g
s
.83916 .74169 m .83916 .76022 L .82657 .75234 L p .707 .577 .707 r
F P
0 g
s
.82657 .75234 m .82657 .73381 L .83916 .74169 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.47559 .57524 m .47559 .63082 L .49196 .62346 L p .707 .577 .707 r
F P
0 g
s
.49196 .62346 m .49196 .56787 L .47559 .57524 L p .707 .577 .707 r
F P
0 g
s
.31064 .5723 m .31064 .62788 L .33169 .63434 L p .707 .577 .707 r
F P
0 g
s
.31064 .59441 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.47559 .59735 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59735 L p .707 .577 .707 r
F P
0 g
s
.80551 .57344 m .80551 .62903 L .77805 .62463 L p .707 .577 .707 r
F P
0 g
s
.77805 .62463 m .77805 .56905 L .80551 .57344 L p .707 .577 .707 r
F P
0 g
s
.39032 .75748 m .39032 .73896 L .35915 .73706 L p .707 .577 .707 r
F P
0 g
s
.39032 .73896 m .39032 .75748 L .42216 .75671 L p .707 .577 .707 r
F P
0 g
s
.42216 .75671 m .42216 .73818 L .39032 .73896 L p .707 .577 .707 r
F P
0 g
s
.68566 .57131 m .68566 .62689 L .66161 .63254 L p .707 .577 .707 r
F P
0 g
s
.64524 .75676 m .64524 .73824 L .66161 .73087 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.42216 .73818 m .42216 .75671 L .45154 .75333 L p .707 .577 .707 r
F P
0 g
s
.45154 .75333 m .45154 .7348 L .42216 .73818 L p .707 .577 .707 r
F P
0 g
s
.31064 .62788 m .31064 .5723 L .29804 .56442 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.35915 .73706 m .35915 .75558 L .39032 .75748 L p .707 .577 .707 r
F P
0 g
s
.68566 .62689 m .68566 .57131 L .71504 .56793 L p .707 .577 .707 r
F P
0 g
s
.35915 .75558 m .35915 .73706 L .33169 .73266 L p .707 .577 .707 r
F P
0 g
s
.66161 .73087 m .66161 .74939 L .64524 .75676 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .59441 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.33169 .73266 m .33169 .75119 L .35915 .75558 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.77805 .56905 m .77805 .62463 L .74688 .62273 L p .707 .577 .707 r
F P
0 g
s
.74688 .62273 m .74688 .56715 L .77805 .56905 L p .707 .577 .707 r
F P
0 g
s
.45154 .7348 m .45154 .75333 L .47559 .74768 L p .707 .577 .707 r
F P
0 g
s
.47559 .74768 m .47559 .72915 L .45154 .7348 L p .707 .577 .707 r
F P
0 g
s
.29804 .56442 m .29804 .62 L .31064 .62788 L p .707 .577 .707 r
F P
0 g
s
.82657 .73381 m .82657 .75234 L .80551 .74588 L p .707 .577 .707 r
F P
0 g
s
.80551 .74588 m .80551 .72735 L .82657 .73381 L p .707 .577 .707 r
F P
0 g
s
.71504 .62351 m .71504 .56793 L .74688 .56715 L p .707 .577 .707 r
F P
0 g
s
.71504 .56793 m .71504 .62351 L .68566 .62689 L p .707 .577 .707 r
F P
0 g
s
.49196 .56787 m .49196 .62346 L .49904 .61509 L p .707 .577 .707 r
F P
0 g
s
.49904 .61509 m .49904 .55951 L .49196 .56787 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62358 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58926 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.74688 .56715 m .74688 .62273 L .71504 .62351 L p .707 .577 .707 r
F P
0 g
s
.33169 .75119 m .33169 .73266 L .31064 .72621 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58926 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.74688 .58926 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.31064 .72621 m .31064 .74474 L .33169 .75119 L p .707 .577 .707 r
F P
0 g
s
.66161 .74939 m .66161 .73087 L .68566 .72522 L p .707 .577 .707 r
F P
0 g
s
.29804 .62 m .29804 .56442 L .29515 .55587 L p .707 .577 .707 r
F P
0 g
s
.68566 .72522 m .68566 .74375 L .66161 .74939 L p .707 .577 .707 r
F P
0 g
s
.47559 .72915 m .47559 .74768 L .49196 .74031 L p .707 .577 .707 r
F P
0 g
s
.49196 .74031 m .49196 .72178 L .47559 .72915 L p .707 .577 .707 r
F P
0 g
s
.29804 .62358 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.80551 .72735 m .80551 .74588 L .77805 .74149 L p .707 .577 .707 r
F P
0 g
s
.77805 .74149 m .77805 .72296 L .80551 .72735 L p .707 .577 .707 r
F P
0 g
s
.31064 .74474 m .31064 .72621 L .29804 .71833 L p .707 .577 .707 r
F P
0 g
s
.29515 .55587 m .29515 .61146 L .29804 .62 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62358 L p .707 .577 .707 r
F P
0 g
s
.49904 .55951 m .49904 .61509 L .49615 .60655 L p .707 .577 .707 r
F P
0 g
s
.49615 .60655 m .49615 .55097 L .49904 .55951 L p .707 .577 .707 r
F P
0 g
s
.68566 .74375 m .68566 .72522 L .71504 .72184 L p .707 .577 .707 r
F P
0 g
s
.29804 .71833 m .29804 .73685 L .31064 .74474 L p .707 .577 .707 r
F P
0 g
s
.71504 .72184 m .71504 .74037 L .68566 .74375 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61013 L p .707 .577 .707 r
F P
0 g
s
.49615 .61013 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.77805 .72296 m .77805 .74149 L .74688 .73959 L p .707 .577 .707 r
F P
0 g
s
.74688 .73959 m .74688 .72106 L .77805 .72296 L p .707 .577 .707 r
F P
0 g
s
.71504 .74037 m .71504 .72184 L .74688 .72106 L p .707 .577 .707 r
F P
0 g
s
.49196 .72178 m .49196 .74031 L .49904 .73195 L p .707 .577 .707 r
F P
0 g
s
.49904 .73195 m .49904 .71342 L .49196 .72178 L p .707 .577 .707 r
F P
0 g
s
.29515 .61146 m .29515 .55587 L .30223 .54751 L p .707 .577 .707 r
F P
0 g
s
.74688 .72106 m .74688 .73959 L .71504 .74037 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.29804 .73685 m .29804 .71833 L .29515 .70978 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .54751 m .30223 .60309 L .29515 .61146 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.29515 .70978 m .29515 .72831 L .29804 .73685 L p .707 .577 .707 r
F P
0 g
s
.49615 .55097 m .49615 .60655 L .48356 .59867 L p .707 .577 .707 r
F P
0 g
s
.48356 .59867 m .48356 .54308 L .49615 .55097 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61013 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.49904 .71342 m .49904 .73195 L .49615 .7234 L p .707 .577 .707 r
F P
0 g
s
.49615 .7234 m .49615 .70488 L .49904 .71342 L p .707 .577 .707 r
F P
0 g
s
.30223 .60309 m .30223 .54751 L .3186 .54014 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56225 L p .707 .577 .707 r
F P
0 g
s
.29515 .72831 m .29515 .70978 L .30223 .70142 L p .707 .577 .707 r
F P
0 g
s
.3186 .54014 m .3186 .59572 L .30223 .60309 L p .707 .577 .707 r
F P
0 g
s
.48356 .54308 m .48356 .59867 L .4625 .59221 L p .707 .577 .707 r
F P
0 g
s
.4625 .59221 m .4625 .53663 L .48356 .54308 L p .707 .577 .707 r
F P
0 g
s
.3186 .56225 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.30223 .70142 m .30223 .71995 L .29515 .72831 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.3186 .59572 m .3186 .54014 L .34265 .53449 L p .707 .577 .707 r
F P
0 g
s
.49615 .70488 m .49615 .7234 L .48356 .71552 L p .707 .577 .707 r
F P
0 g
s
.48356 .71552 m .48356 .69699 L .49615 .70488 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56225 L .34265 .5566 L p .707 .577 .707 r
F P
0 g
s
.4625 .53663 m .4625 .59221 L .43504 .58782 L p .707 .577 .707 r
F P
0 g
s
.43504 .58782 m .43504 .53224 L .4625 .53663 L p .707 .577 .707 r
F P
0 g
s
.34265 .53449 m .34265 .59007 L .3186 .59572 L p .707 .577 .707 r
F P
0 g
s
.30223 .71995 m .30223 .70142 L .3186 .69405 L p .707 .577 .707 r
F P
0 g
s
.34265 .5566 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .5914 L p .707 .577 .707 r
F P
0 g
s
.43504 .5914 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .59007 m .34265 .53449 L .37203 .53111 L p .707 .577 .707 r
F P
0 g
s
.3186 .69405 m .3186 .71258 L .30223 .71995 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .5566 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.43504 .53224 m .43504 .58782 L .40387 .58592 L p .707 .577 .707 r
F P
0 g
s
.40387 .58592 m .40387 .53034 L .43504 .53224 L p .707 .577 .707 r
F P
0 g
s
.48356 .69699 m .48356 .71552 L .4625 .70907 L p .707 .577 .707 r
F P
0 g
s
.4625 .70907 m .4625 .69054 L .48356 .69699 L p .707 .577 .707 r
F P
0 g
s
.37203 .5867 m .37203 .53111 L .40387 .53034 L p .707 .577 .707 r
F P
0 g
s
.37203 .53111 m .37203 .5867 L .34265 .59007 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .5914 L .40387 .5895 L p .707 .577 .707 r
F P
0 g
s
.40387 .5895 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.40387 .53034 m .40387 .58592 L .37203 .5867 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .5895 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.3186 .71258 m .3186 .69405 L .34265 .6884 L p .707 .577 .707 r
F P
0 g
s
.34265 .6884 m .34265 .70693 L .3186 .71258 L p .707 .577 .707 r
F P
0 g
s
.4625 .69054 m .4625 .70907 L .43504 .70467 L p .707 .577 .707 r
F P
0 g
s
.43504 .70467 m .43504 .68615 L .4625 .69054 L p .707 .577 .707 r
F P
0 g
s
.34265 .70693 m .34265 .6884 L .37203 .68502 L p .707 .577 .707 r
F P
0 g
s
.37203 .68502 m .37203 .70355 L .34265 .70693 L p .707 .577 .707 r
F P
0 g
s
.43504 .68615 m .43504 .70467 L .40387 .70277 L p .707 .577 .707 r
F P
0 g
s
.40387 .70277 m .40387 .68425 L .43504 .68615 L p .707 .577 .707 r
F P
0 g
s
.37203 .70355 m .37203 .68502 L .40387 .68425 L p .707 .577 .707 r
F P
0 g
s
.40387 .68425 m .40387 .70277 L .37203 .70355 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^
Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000
FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo2@0015YF00<005YFFUH00UYF20001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEQH000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF00000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF0000
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH01000<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEPh000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJ
EP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YF0000009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000500000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo001COol01000FUH005YF0P00
1EYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo001COol01P00FUH00000FUH000EJEP03
001JEUYF00=JEP<000=JEQ<000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQX000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF
00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
1000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eo
o`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH005YF009JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF0`000eYF0P00;Goo000]Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH80004FUH40002FUH>0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF1@000eYF00<0
05YFFUH00UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHD0006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00D005YF001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD0
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH5000jOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUH0000H000o
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPl000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP05001JEUYFFUH0001E
Ool002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEPH0009JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEPD000AJEP04001JEUYFFUH2001DOol002aoo`03001JEP0000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002aoo`04001JEP00FUH20004FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003FUH2001DOol002aoo`06001JEP00001J
EP001EYF00@005YFFUIJEPD0009JEQ@00005FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH3
00000eYF0000001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJ
EP03001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPP000AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00
FUH00004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH50002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF100000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000
FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002ioo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEP0000<0009JEP03001JEUYF00AJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
100000=JEP00FUH015YF00@005YFFUIJEQX003aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEP<000EJEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF00002P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD003Moo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF00@005YF
000000=JEP03001JEP0000@000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH5
0002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol003]oo`P000AJEPD000EJEP04001JEP000003FUH00`00
FUIJEP02FUH50003Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00L0
05YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol004=ooa8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH01000FUIJEUYF30001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00EGoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH00`00FUIJ
EP02000^Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001J
EUYFFUH0000^Ool005Yoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEP0001Yoo`@000=J
EP04001JEUYFFUH2000]Ool005eoo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP03001JEP0000=JEP<000=JEP03001JEUYF009JEP8001moo`@000=JEP8002eo
o`00HWoo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF100015YF00@005YF001JEP8000IJEP03001JEUYF009JEP03001oogoo
029oo`03001JEUYF008002eoo`00IGoo00D005YFFUH005YF01<00003FUH005YF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP05001JEUYFFUH00003FUH01P00FUH00000FUH000IJ
EP03001JEUYF008002Ioo`@002eoo`00IGoo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000000UYF0P001UYF0`009Woo0P0000AJEP00000002eoo`00IGoo00<005YF0000
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YF00001P009Goo0`000eYF0`00;Goo
001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP02FUH3000ROol4
00000eYF001JEP03FUH00`00FUH0000]Ool006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<001Uoo`D000EJEP03001JEUYF009JEP80
02ioo`00?goo4@005Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uo
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00=Goo100000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0P001Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P002Goo1@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004Ool3
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P0047oo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000K7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP0000Ioo`8000AJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006io
o`00;7oo00<005YF00000eYF1@009goo0`0000=JEP00FUH00UYF00<007ooOol01Woo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00LGoo
000/Ool01000FUH005YF0P00;goo0P000eYF00<007ooOol02Goo100025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00M7oo000/Ool01000FUH00000<goo0P0000=J
EP00Ool03Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`00N7oo000/
Ool4000dOol3000EOolR0002OolJ001SOol002aoo`80009JEP<002moo`<00003FUH007oo035oo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5001NOol002aoo`8000=JEP03001J
EP00008002Uoo`<0009JEP03001JEP0002ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008005]oo`00;7oo0P000eYF00<005YFFUH00UYF
1@0087oo100000=JEP00FUH00UYF00<005YF0000;7oo0`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00FGoo000]Ool01@00FUIJEUYF
00001EYF00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000[Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH2001HOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000:goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF
4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000005Ioo`00<7oo0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000002]oo`8000AJEP03001JEUYF009JEPH0019oo`P000=JEP03001JEUYF00=JEP05001JEUYFFUH0
001EOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<002aoo`03001JEP0000AJEP03001JEP000080021oo`D000AJEP05001JEUYF
FUH0001EOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000<002moo`03001JEP0000=JEP<002Qoo`<00003FUH005YF009JEP8005Aoo`00>Goo10000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP8002ioo`80
00=JEP8005Aoo`00?Goo6@00>7oo00@005YF0000039oo`800003FUH0000005Aoo`00SWoo0P0000=J
EP00Ool0<7oo0P0000AJEP00000005Aoo`00SWoo0P000UYF0`00:goo0`000eYF0`00E7oo002>Ool2
0002FUH00`00FUIJEP05000ROol400000eYF001JEP03FUH00`00FUH0001DOol008moo`04001JEUYF
0005FUH00`00FUH00003000IOol50005FUH00`00FUIJEP02FUH2001EOol008moo`04001JEUYF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<0
05YFFUH00UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75032 m .59613 .71326 L .56496 .71136 L p .707 .577 .707 r
F P
0 g
s
.59613 .71326 m .59613 .75032 L .62796 .74954 L p .707 .577 .707 r
F P
0 g
s
.62796 .74954 m .62796 .71249 L .59613 .71326 L p .707 .577 .707 r
F P
0 g
s
.62796 .71249 m .62796 .74954 L .65735 .74616 L p .707 .577 .707 r
F P
0 g
s
.65735 .74616 m .65734 .70911 L .62796 .71249 L p .707 .577 .707 r
F P
0 g
s
.59613 .78184 m .59613 .72626 L .56496 .72435 L p .707 .577 .707 r
F P
0 g
s
.59613 .72626 m .59613 .78184 L .62796 .78106 L p .707 .577 .707 r
F P
0 g
s
.62796 .78106 m .62796 .72548 L .59613 .72626 L p .707 .577 .707 r
F P
0 g
s
.62796 .72548 m .62796 .78106 L .65735 .77768 L p .707 .577 .707 r
F P
0 g
s
.65735 .77768 m .65734 .7221 L .62796 .72548 L p .707 .577 .707 r
F P
0 g
s
.56496 .74842 m .56496 .71136 L .5375 .70697 L p .707 .577 .707 r
F P
0 g
s
.56496 .71136 m .56496 .74842 L .59613 .75032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77994 m .56496 .72435 L .5375 .71996 L p .707 .577 .707 r
F P
0 g
s
.56496 .72435 m .56496 .77994 L .59613 .78184 L p .707 .577 .707 r
F P
0 g
s
.65734 .70911 m .65735 .74616 L .6814 .74051 L p .707 .577 .707 r
F P
0 g
s
.6814 .74051 m .6814 .70346 L .65734 .70911 L p .707 .577 .707 r
F P
0 g
s
.5375 .70697 m .5375 .74403 L .56496 .74842 L p .707 .577 .707 r
F P
0 g
s
.65734 .7221 m .65735 .77768 L .6814 .77203 L p .707 .577 .707 r
F P
0 g
s
.6814 .77203 m .6814 .71645 L .65734 .7221 L p .707 .577 .707 r
F P
0 g
s
.5375 .74403 m .5375 .70697 L .51644 .70052 L p .707 .577 .707 r
F P
0 g
s
.5375 .71996 m .5375 .77554 L .56496 .77994 L p .707 .577 .707 r
F P
0 g
s
.5375 .77554 m .5375 .71996 L .51644 .71351 L p .707 .577 .707 r
F P
0 g
s
.51644 .70052 m .51644 .73757 L .5375 .74403 L p .707 .577 .707 r
F P
0 g
s
.6814 .70346 m .6814 .74051 L .69777 .73315 L p .707 .577 .707 r
F P
0 g
s
.69777 .73315 m .69777 .69609 L .6814 .70346 L p .707 .577 .707 r
F P
0 g
s
.6814 .71645 m .6814 .77203 L .69777 .76466 L p .707 .577 .707 r
F P
0 g
s
.69777 .76466 m .69777 .70908 L .6814 .71645 L p .707 .577 .707 r
F P
0 g
s
.51644 .71351 m .51644 .76909 L .5375 .77554 L p .707 .577 .707 r
F P
0 g
s
.51644 .73757 m .51644 .70052 L .50385 .69263 L p .707 .577 .707 r
F P
0 g
s
.59613 .90775 m .59613 .88922 L .56496 .88732 L p .707 .577 .707 r
F P
0 g
s
.59613 .88922 m .59613 .90775 L .62796 .90697 L p .707 .577 .707 r
F P
0 g
s
.62796 .90697 m .62796 .88845 L .59613 .88922 L p .707 .577 .707 r
F P
0 g
s
.51644 .76909 m .51644 .71351 L .50385 .70562 L p .707 .577 .707 r
F P
0 g
s
.62796 .88845 m .62796 .90697 L .65735 .90359 L p .707 .577 .707 r
F P
0 g
s
.65735 .90359 m .65735 .88507 L .62796 .88845 L p .707 .577 .707 r
F P
0 g
s
.56496 .88732 m .56496 .90585 L .59613 .90775 L p .707 .577 .707 r
F P
0 g
s
.56496 .90585 m .56496 .88732 L .5375 .88293 L p .707 .577 .707 r
F P
0 g
s
.50385 .69263 m .50385 .72969 L .51644 .73757 L p .707 .577 .707 r
F P
0 g
s
.5375 .88293 m .5375 .90146 L .56496 .90585 L p .707 .577 .707 r
F P
0 g
s
.69777 .69609 m .69777 .73315 L .70485 .72478 L p .707 .577 .707 r
F P
0 g
s
.70485 .72478 m .70485 .68773 L .69777 .69609 L p .707 .577 .707 r
F P
0 g
s
.65735 .88507 m .65735 .90359 L .6814 .89794 L p .707 .577 .707 r
F P
0 g
s
.6814 .89794 m .6814 .87942 L .65735 .88507 L p .707 .577 .707 r
F P
0 g
s
.50385 .70562 m .50385 .76121 L .51644 .76909 L p .707 .577 .707 r
F P
0 g
s
.69777 .70908 m .69777 .76466 L .70485 .7563 L p .707 .577 .707 r
F P
0 g
s
.70485 .7563 m .70485 .70072 L .69777 .70908 L p .707 .577 .707 r
F P
0 g
s
.5375 .90146 m .5375 .88293 L .51644 .87648 L p .707 .577 .707 r
F P
0 g
s
.50385 .72969 m .50385 .69263 L .50095 .68409 L p .707 .577 .707 r
F P
0 g
s
.51644 .87648 m .51644 .895 L .5375 .90146 L p .707 .577 .707 r
F P
0 g
s
.50385 .76121 m .50385 .70562 L .50095 .69708 L p .707 .577 .707 r
F P
0 g
s
.6814 .87942 m .6814 .89794 L .69777 .89058 L p .707 .577 .707 r
F P
0 g
s
.69777 .89058 m .69777 .87205 L .6814 .87942 L p .707 .577 .707 r
F P
0 g
s
.50095 .68409 m .50095 .72115 L .50385 .72969 L p .707 .577 .707 r
F P
0 g
s
.70485 .68773 m .70485 .72478 L .70195 .71624 L p .707 .577 .707 r
F P
0 g
s
.70195 .71624 m .70195 .67918 L .70485 .68773 L p .707 .577 .707 r
F P
0 g
s
.49044 .81115 m .49044 .30927 L .44643 .30658 L p .707 .577 .707 r
F P
0 g
s
.50095 .69708 m .50095 .75266 L .50385 .76121 L p .707 .577 .707 r
F P
0 g
s
.50095 .72115 m .50095 .68409 L .50804 .67573 L p .707 .577 .707 r
F P
0 g
s
.50095 .75266 m .50095 .69708 L .50804 .68872 L p .707 .577 .707 r
F P
0 g
s
.50804 .67573 m .50804 .71278 L .50095 .72115 L p .707 .577 .707 r
F P
0 g
s
.50804 .68872 m .50804 .7443 L .50095 .75266 L p .707 .577 .707 r
F P
0 g
s
.50804 .71278 m .50804 .67573 L .5244 .66836 L p .707 .577 .707 r
F P
0 g
s
.50804 .7443 m .50804 .68872 L .5244 .68135 L p .707 .577 .707 r
F P
0 g
s
.5244 .66836 m .5244 .70541 L .50804 .71278 L p .707 .577 .707 r
F P
0 g
s
.5244 .68135 m .5244 .73693 L .50804 .7443 L p .707 .577 .707 r
F P
0 g
s
.5244 .70541 m .5244 .66836 L .54846 .66271 L p .707 .577 .707 r
F P
0 g
s
.5244 .73693 m .5244 .68135 L .54846 .6757 L p .707 .577 .707 r
F P
0 g
s
.54846 .66271 m .54846 .69976 L .5244 .70541 L p .707 .577 .707 r
F P
0 g
s
.54846 .6757 m .54846 .73128 L .5244 .73693 L p .707 .577 .707 r
F P
0 g
s
.49044 .30927 m .49044 .81115 L .53538 .81006 L p .707 .577 .707 r
F P
0 g
s
.53538 .81006 m .53538 .30817 L .49044 .30927 L p .707 .577 .707 r
F P
0 g
s
.51644 .895 m .51644 .87648 L .50385 .86859 L p .707 .577 .707 r
F P
0 g
s
.70485 .70072 m .70485 .7563 L .70195 .74776 L p .707 .577 .707 r
F P
0 g
s
.70195 .74776 m .70195 .69218 L .70485 .70072 L p .707 .577 .707 r
F P
0 g
s
.54846 .69976 m .54846 .66271 L .57784 .65933 L p .707 .577 .707 r
F P
0 g
s
.54846 .73128 m .54846 .6757 L .57784 .67232 L p .707 .577 .707 r
F P
0 g
s
.57784 .65933 m .57784 .69639 L .54846 .69976 L p .707 .577 .707 r
F P
0 g
s
.57784 .67232 m .57784 .7279 L .54846 .73128 L p .707 .577 .707 r
F P
0 g
s
.53538 .30817 m .53538 .81006 L .57686 .80529 L p .707 .577 .707 r
F P
0 g
s
.57686 .80529 m .57686 .3034 L .53538 .30817 L p .707 .577 .707 r
F P
0 g
s
.50385 .86859 m .50385 .88712 L .51644 .895 L p .707 .577 .707 r
F P
0 g
s
.44643 .80847 m .44643 .30658 L .40766 .30038 L p .707 .577 .707 r
F P
0 g
s
.44643 .30658 m .44643 .80847 L .49044 .81115 L p .707 .577 .707 r
F P
0 g
s
.69777 .87205 m .69777 .89058 L .70485 .88221 L p .707 .577 .707 r
F P
0 g
s
.70485 .88221 m .70485 .86368 L .69777 .87205 L p .707 .577 .707 r
F P
0 g
s
.57784 .69639 m .57784 .65933 L .60968 .65855 L p .707 .577 .707 r
F P
0 g
s
.60968 .65855 m .60968 .69561 L .57784 .69639 L p .707 .577 .707 r
F P
0 g
s
.57784 .7279 m .57784 .67232 L .60968 .67154 L p .707 .577 .707 r
F P
0 g
s
.60968 .67154 m .60968 .72713 L .57784 .7279 L p .707 .577 .707 r
F P
0 g
s
.57686 .3034 m .57686 .80529 L .61082 .79731 L p .707 .577 .707 r
F P
0 g
s
.64085 .66045 m .64085 .69751 L .60968 .69561 L p .707 .577 .707 r
F P
0 g
s
.60968 .69561 m .60968 .65855 L .64085 .66045 L p .707 .577 .707 r
F P
0 g
s
.64085 .67344 m .64085 .72903 L .60968 .72713 L p .707 .577 .707 r
F P
0 g
s
.60968 .72713 m .60968 .67154 L .64085 .67344 L p .707 .577 .707 r
F P
0 g
s
.61082 .79731 m .61082 .29542 L .57686 .3034 L p .707 .577 .707 r
F P
0 g
s
.70195 .67918 m .70195 .71624 L .68936 .70836 L p .707 .577 .707 r
F P
0 g
s
.68936 .70836 m .68936 .6713 L .70195 .67918 L p .707 .577 .707 r
F P
0 g
s
.50385 .88712 m .50385 .86859 L .50095 .86005 L p .707 .577 .707 r
F P
0 g
s
.40766 .80227 m .40766 .30038 L .37794 .29127 L p .707 .577 .707 r
F P
0 g
s
.40766 .30038 m .40766 .80227 L .44643 .80847 L p .707 .577 .707 r
F P
0 g
s
.70195 .69218 m .70195 .74776 L .68936 .73987 L p .707 .577 .707 r
F P
0 g
s
.68936 .73987 m .68936 .68429 L .70195 .69218 L p .707 .577 .707 r
F P
0 g
s
.50095 .86005 m .50095 .87858 L .50385 .88712 L p .707 .577 .707 r
F P
0 g
s
.25312 .7135 m .25312 .67645 L .22195 .67455 L p .707 .577 .707 r
F P
0 g
s
.25312 .67645 m .25312 .7135 L .28495 .71273 L p .707 .577 .707 r
F P
0 g
s
.28495 .71273 m .28495 .67567 L .25312 .67645 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28495 .67567 m .28495 .71273 L .31434 .70935 L p .707 .577 .707 r
F P
0 g
s
.31434 .70935 m .31434 .67229 L .28495 .67567 L p .707 .577 .707 r
F P
0 g
s
.25312 .74502 m .25312 .68944 L .22195 .68754 L p .707 .577 .707 r
F P
0 g
s
.25312 .68944 m .25312 .74502 L .28495 .74424 L p .707 .577 .707 r
F P
0 g
s
.28495 .74424 m .28495 .68866 L .25312 .68944 L p .707 .577 .707 r
F P
0 g
s
.28495 .68866 m .28495 .74424 L .31434 .74087 L p .707 .577 .707 r
F P
0 g
s
.31434 .74087 m .31434 .68528 L .28495 .68866 L p .707 .577 .707 r
F P
0 g
s
.22195 .7116 m .22195 .67455 L .19449 .67016 L p .707 .577 .707 r
F P
0 g
s
.22195 .67455 m .22195 .7116 L .25312 .7135 L p .707 .577 .707 r
F P
0 g
s
.70485 .86368 m .70485 .88221 L .70195 .87367 L p .707 .577 .707 r
F P
0 g
s
.70195 .87367 m .70195 .85514 L .70485 .86368 L p .707 .577 .707 r
F P
0 g
s
.22195 .74312 m .22195 .68754 L .19449 .68315 L p .707 .577 .707 r
F P
0 g
s
.22195 .68754 m .22195 .74312 L .25312 .74502 L p .707 .577 .707 r
F P
0 g
s
.61082 .29542 m .61082 .79731 L .63393 .78691 L p .707 .577 .707 r
F P
0 g
s
.63393 .78691 m .63393 .28502 L .61082 .29542 L p .707 .577 .707 r
F P
0 g
s
.31434 .67229 m .31434 .70935 L .33839 .7037 L p .707 .577 .707 r
F P
0 g
s
.33839 .7037 m .33839 .66664 L .31434 .67229 L p .707 .577 .707 r
F P
0 g
s
.19449 .67016 m .19449 .70721 L .22195 .7116 L p .707 .577 .707 r
F P
0 g
s
.68936 .6713 m .68936 .70836 L .66831 .7019 L p .707 .577 .707 r
F P
0 g
s
.66831 .7019 m .66831 .66485 L .68936 .6713 L p .707 .577 .707 r
F P
0 g
s
.31434 .68528 m .31434 .74087 L .33839 .73522 L p .707 .577 .707 r
F P
0 g
s
.33839 .73522 m .33839 .67963 L .31434 .68528 L p .707 .577 .707 r
F P
0 g
s
.50095 .87858 m .50095 .86005 L .50804 .85169 L p .707 .577 .707 r
F P
0 g
s
.68936 .68429 m .68936 .73987 L .66831 .73342 L p .707 .577 .707 r
F P
0 g
s
.66831 .73342 m .66831 .67784 L .68936 .68429 L p .707 .577 .707 r
F P
0 g
s
.19449 .70721 m .19449 .67016 L .17343 .6637 L p .707 .577 .707 r
F P
0 g
s
.37794 .79316 m .37794 .29127 L .36016 .28014 L p .707 .577 .707 r
F P
0 g
s
.37794 .29127 m .37794 .79316 L .40766 .80227 L p .707 .577 .707 r
F P
0 g
s
.19449 .68315 m .19449 .73873 L .22195 .74312 L p .707 .577 .707 r
F P
0 g
s
.19449 .73873 m .19449 .68315 L .17343 .67669 L p .707 .577 .707 r
F P
0 g
s
.50804 .85169 m .50804 .87021 L .50095 .87858 L p .707 .577 .707 r
F P
0 g
s
.17343 .6637 m .17343 .70076 L .19449 .70721 L p .707 .577 .707 r
F P
0 g
s
.33839 .66664 m .33839 .7037 L .35476 .69633 L p .707 .577 .707 r
F P
0 g
s
.35476 .69633 m .35476 .65928 L .33839 .66664 L p .707 .577 .707 r
F P
0 g
s
.33839 .67963 m .33839 .73522 L .35476 .72785 L p .707 .577 .707 r
F P
0 g
s
.35476 .72785 m .35476 .67227 L .33839 .67963 L p .707 .577 .707 r
F P
0 g
s
.70195 .85514 m .70195 .87367 L .68936 .86579 L p .707 .577 .707 r
F P
0 g
s
.68936 .86579 m .68936 .84726 L .70195 .85514 L p .707 .577 .707 r
F P
0 g
s
.66831 .66485 m .66831 .7019 L .64085 .69751 L p .707 .577 .707 r
F P
0 g
s
.64085 .69751 m .64085 .66045 L .66831 .66485 L p .707 .577 .707 r
F P
0 g
s
.17343 .67669 m .17343 .73228 L .19449 .73873 L p .707 .577 .707 r
F P
0 g
s
.66831 .67784 m .66831 .73342 L .64085 .72903 L p .707 .577 .707 r
F P
0 g
s
.64085 .72903 m .64085 .67344 L .66831 .67784 L p .707 .577 .707 r
F P
0 g
s
.17343 .70076 m .17343 .6637 L .16084 .65582 L p .707 .577 .707 r
F P
0 g
s
.63393 .28502 m .63393 .78691 L .64393 .7751 L p .707 .577 .707 r
F P
0 g
s
.64393 .7751 m .64393 .27321 L .63393 .28502 L p .707 .577 .707 r
F P
0 g
s
.25312 .87093 m .25312 .85241 L .22195 .85051 L p .707 .577 .707 r
F P
0 g
s
.25312 .85241 m .25312 .87093 L .28495 .87016 L p .707 .577 .707 r
F P
0 g
s
.28495 .87016 m .28495 .85163 L .25312 .85241 L p .707 .577 .707 r
F P
0 g
s
.17343 .73228 m .17343 .67669 L .16084 .66881 L p .707 .577 .707 r
F P
0 g
s
.50804 .87021 m .50804 .85169 L .5244 .84432 L p .707 .577 .707 r
F P
0 g
s
.28495 .85163 m .28495 .87016 L .31434 .86678 L p .707 .577 .707 r
F P
0 g
s
.31434 .86678 m .31434 .84825 L .28495 .85163 L p .707 .577 .707 r
F P
0 g
s
.22195 .85051 m .22195 .86903 L .25312 .87093 L p .707 .577 .707 r
F P
0 g
s
.22195 .86903 m .22195 .85051 L .19449 .84611 L p .707 .577 .707 r
F P
0 g
s
.16084 .65582 m .16084 .69287 L .17343 .70076 L p .707 .577 .707 r
F P
0 g
s
.5244 .84432 m .5244 .86284 L .50804 .87021 L p .707 .577 .707 r
F P
0 g
s
.19449 .84611 m .19449 .86464 L .22195 .86903 L p .707 .577 .707 r
F P
0 g
s
.35476 .65928 m .35476 .69633 L .36184 .68797 L p .707 .577 .707 r
F P
0 g
s
.36184 .68797 m .36184 .65091 L .35476 .65928 L p .707 .577 .707 r
F P
0 g
s
.31434 .84825 m .31434 .86678 L .33839 .86113 L p .707 .577 .707 r
F P
0 g
s
.33839 .86113 m .33839 .8426 L .31434 .84825 L p .707 .577 .707 r
F P
0 g
s
.16084 .66881 m .16084 .72439 L .17343 .73228 L p .707 .577 .707 r
F P
0 g
s
.35476 .67227 m .35476 .72785 L .36184 .71948 L p .707 .577 .707 r
F P
0 g
s
.36184 .71948 m .36184 .6639 L .35476 .67227 L p .707 .577 .707 r
F P
0 g
s
.36184 .65091 m .36184 .68797 L .35894 .67942 L p .707 .577 .707 r
F P
0 g
s
.35894 .67942 m .35894 .64237 L .36184 .65091 L p .707 .577 .707 r
F P
0 g
s
.36184 .6639 m .36184 .71948 L .35894 .71094 L p .707 .577 .707 r
F P
0 g
s
.35894 .71094 m .35894 .65536 L .36184 .6639 L p .707 .577 .707 r
F P
0 g
s
.36016 .78203 m .36016 .28014 L .35607 .26808 L p .707 .577 .707 r
F P
0 g
s
.36016 .28014 m .36016 .78203 L .37794 .79316 L p .707 .577 .707 r
F P
0 g
s
.68936 .84726 m .68936 .86579 L .66831 .85933 L p .707 .577 .707 r
F P
0 g
s
.66831 .85933 m .66831 .8408 L .68936 .84726 L p .707 .577 .707 r
F P
0 g
s
.19449 .86464 m .19449 .84611 L .17343 .83966 L p .707 .577 .707 r
F P
0 g
s
.16084 .69287 m .16084 .65582 L .15794 .64728 L p .707 .577 .707 r
F P
0 g
s
.17343 .83966 m .17343 .85819 L .19449 .86464 L p .707 .577 .707 r
F P
0 g
s
.16084 .72439 m .16084 .66881 L .15794 .66027 L p .707 .577 .707 r
F P
0 g
s
.5244 .86284 m .5244 .84432 L .54846 .83867 L p .707 .577 .707 r
F P
0 g
s
.54846 .83867 m .54846 .8572 L .5244 .86284 L p .707 .577 .707 r
F P
0 g
s
.33839 .8426 m .33839 .86113 L .35476 .85376 L p .707 .577 .707 r
F P
0 g
s
.35476 .85376 m .35476 .83523 L .33839 .8426 L p .707 .577 .707 r
F P
0 g
s
.15794 .64728 m .15794 .68433 L .16084 .69287 L p .707 .577 .707 r
F P
0 g
s
.64393 .27321 m .64393 .7751 L .63984 .76304 L p .707 .577 .707 r
F P
0 g
s
.63984 .76304 m .63984 .26115 L .64393 .27321 L p .707 .577 .707 r
F P
0 g
s
.66831 .8408 m .66831 .85933 L .64085 .85494 L p .707 .577 .707 r
F P
0 g
s
.64085 .85494 m .64085 .83641 L .66831 .8408 L p .707 .577 .707 r
F P
0 g
s
.15794 .66027 m .15794 .71585 L .16084 .72439 L p .707 .577 .707 r
F P
0 g
s
.17343 .85819 m .17343 .83966 L .16084 .83178 L p .707 .577 .707 r
F P
0 g
s
.54846 .8572 m .54846 .83867 L .57784 .83529 L p .707 .577 .707 r
F P
0 g
s
.16084 .83178 m .16084 .8503 L .17343 .85819 L p .707 .577 .707 r
F P
0 g
s
.57784 .83529 m .57784 .85382 L .54846 .8572 L p .707 .577 .707 r
F P
0 g
s
.15794 .68433 m .15794 .64728 L .16503 .63891 L p .707 .577 .707 r
F P
0 g
s
.64085 .83641 m .64085 .85494 L .60968 .85304 L p .707 .577 .707 r
F P
0 g
s
.60968 .85304 m .60968 .83451 L .64085 .83641 L p .707 .577 .707 r
F P
0 g
s
.15794 .71585 m .15794 .66027 L .16503 .6519 L p .707 .577 .707 r
F P
0 g
s
.35894 .64237 m .35894 .67942 L .34635 .67154 L p .707 .577 .707 r
F P
0 g
s
.34635 .67154 m .34635 .63449 L .35894 .64237 L p .707 .577 .707 r
F P
0 g
s
.35894 .65536 m .35894 .71094 L .34635 .70306 L p .707 .577 .707 r
F P
0 g
s
.34635 .70306 m .34635 .64748 L .35894 .65536 L p .707 .577 .707 r
F P
0 g
s
.35607 .26808 m .35607 .76997 L .36016 .78203 L p .707 .577 .707 r
F P
0 g
s
.35607 .76997 m .35607 .26808 L .36607 .25627 L p .707 .577 .707 r
F P
0 g
s
.57784 .85382 m .57784 .83529 L .60968 .83451 L p .707 .577 .707 r
F P
0 g
s
.35476 .83523 m .35476 .85376 L .36184 .8454 L p .707 .577 .707 r
F P
0 g
s
.36184 .8454 m .36184 .82687 L .35476 .83523 L p .707 .577 .707 r
F P
0 g
s
.60968 .83451 m .60968 .85304 L .57784 .85382 L p .707 .577 .707 r
F P
0 g
s
.16503 .63891 m .16503 .67597 L .15794 .68433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .8503 m .16084 .83178 L .15794 .82323 L p .707 .577 .707 r
F P
0 g
s
.16503 .6519 m .16503 .70748 L .15794 .71585 L p .707 .577 .707 r
F P
0 g
s
.15794 .82323 m .15794 .84176 L .16084 .8503 L p .707 .577 .707 r
F P
0 g
s
.63984 .26115 m .63984 .76304 L .62206 .75191 L p .707 .577 .707 r
F P
0 g
s
.62206 .75191 m .62206 .25002 L .63984 .26115 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .67597 m .16503 .63891 L .1814 .63154 L p .707 .577 .707 r
F P
0 g
s
.16503 .70748 m .16503 .6519 L .1814 .64453 L p .707 .577 .707 r
F P
0 g
s
.36184 .82687 m .36184 .8454 L .35894 .83685 L p .707 .577 .707 r
F P
0 g
s
.35894 .83685 m .35894 .81833 L .36184 .82687 L p .707 .577 .707 r
F P
0 g
s
.1814 .63154 m .1814 .6686 L .16503 .67597 L p .707 .577 .707 r
F P
0 g
s
.34635 .63449 m .34635 .67154 L .3253 .66509 L p .707 .577 .707 r
F P
0 g
s
.3253 .66509 m .3253 .62803 L .34635 .63449 L p .707 .577 .707 r
F P
0 g
s
.36607 .75816 m .36607 .25627 L .38918 .24587 L p .707 .577 .707 r
F P
0 g
s
.36607 .25627 m .36607 .75816 L .35607 .76997 L p .707 .577 .707 r
F P
0 g
s
.15794 .84176 m .15794 .82323 L .16503 .81487 L p .707 .577 .707 r
F P
0 g
s
.1814 .64453 m .1814 .70012 L .16503 .70748 L p .707 .577 .707 r
F P
0 g
s
.34635 .64748 m .34635 .70306 L .3253 .6966 L p .707 .577 .707 r
F P
0 g
s
.3253 .6966 m .3253 .64102 L .34635 .64748 L p .707 .577 .707 r
F P
0 g
s
.16503 .81487 m .16503 .8334 L .15794 .84176 L p .707 .577 .707 r
F P
0 g
s
.1814 .6686 m .1814 .63154 L .20545 .62589 L p .707 .577 .707 r
F P
0 g
s
.1814 .70012 m .1814 .64453 L .20545 .63888 L p .707 .577 .707 r
F P
0 g
s
.35894 .81833 m .35894 .83685 L .34635 .82897 L p .707 .577 .707 r
F P
0 g
s
.34635 .82897 m .34635 .81044 L .35894 .81833 L p .707 .577 .707 r
F P
0 g
s
.20545 .62589 m .20545 .66295 L .1814 .6686 L p .707 .577 .707 r
F P
0 g
s
.62206 .25002 m .62206 .75191 L .59233 .7428 L p .707 .577 .707 r
F P
0 g
s
.59233 .7428 m .59233 .24091 L .62206 .25002 L p .707 .577 .707 r
F P
0 g
s
.3253 .62803 m .3253 .66509 L .29784 .66069 L p .707 .577 .707 r
F P
0 g
s
.29784 .66069 m .29784 .62364 L .3253 .62803 L p .707 .577 .707 r
F P
0 g
s
.3253 .64102 m .3253 .6966 L .29784 .69221 L p .707 .577 .707 r
F P
0 g
s
.29784 .69221 m .29784 .63663 L .3253 .64102 L p .707 .577 .707 r
F P
0 g
s
.20545 .63888 m .20545 .69447 L .1814 .70012 L p .707 .577 .707 r
F P
0 g
s
.20545 .66295 m .20545 .62589 L .23483 .62252 L p .707 .577 .707 r
F P
0 g
s
.16503 .8334 m .16503 .81487 L .1814 .8075 L p .707 .577 .707 r
F P
0 g
s
.20545 .69447 m .20545 .63888 L .23483 .63551 L p .707 .577 .707 r
F P
0 g
s
.38918 .24587 m .38918 .74776 L .36607 .75816 L p .707 .577 .707 r
F P
0 g
s
.38918 .74776 m .38918 .24587 L .42314 .23789 L p .707 .577 .707 r
F P
0 g
s
.1814 .8075 m .1814 .82603 L .16503 .8334 L p .707 .577 .707 r
F P
0 g
s
.29784 .62364 m .29784 .66069 L .26667 .65879 L p .707 .577 .707 r
F P
0 g
s
.26667 .65879 m .26667 .62174 L .29784 .62364 L p .707 .577 .707 r
F P
0 g
s
.23483 .62252 m .23483 .65957 L .20545 .66295 L p .707 .577 .707 r
F P
0 g
s
.29784 .63663 m .29784 .69221 L .26667 .69031 L p .707 .577 .707 r
F P
0 g
s
.26667 .69031 m .26667 .63473 L .29784 .63663 L p .707 .577 .707 r
F P
0 g
s
.23483 .65957 m .23483 .62252 L .26667 .62174 L p .707 .577 .707 r
F P
0 g
s
.26667 .62174 m .26667 .65879 L .23483 .65957 L p .707 .577 .707 r
F P
0 g
s
.23483 .69109 m .23483 .63551 L .26667 .63473 L p .707 .577 .707 r
F P
0 g
s
.23483 .63551 m .23483 .69109 L .20545 .69447 L p .707 .577 .707 r
F P
0 g
s
.73333 .65828 m .73333 .62123 L .70216 .61933 L p .707 .577 .707 r
F P
0 g
s
.73333 .62123 m .73333 .65828 L .76517 .6575 L p .707 .577 .707 r
F P
0 g
s
.76517 .6575 m .76517 .62045 L .73333 .62123 L p .707 .577 .707 r
F P
0 g
s
.34635 .81044 m .34635 .82897 L .3253 .82252 L p .707 .577 .707 r
F P
0 g
s
.3253 .82252 m .3253 .80399 L .34635 .81044 L p .707 .577 .707 r
F P
0 g
s
.26667 .63473 m .26667 .69031 L .23483 .69109 L p .707 .577 .707 r
F P
0 g
s
.76517 .62045 m .76517 .6575 L .79455 .65413 L p .707 .577 .707 r
F P
0 g
s
.79455 .65413 m .79455 .61707 L .76517 .62045 L p .707 .577 .707 r
F P
0 g
s
.73333 .6898 m .73333 .63422 L .70216 .63232 L p .707 .577 .707 r
F P
0 g
s
.73333 .63422 m .73333 .6898 L .76517 .68902 L p .707 .577 .707 r
F P
0 g
s
.76517 .68902 m .76517 .63344 L .73333 .63422 L p .707 .577 .707 r
F P
0 g
s
.76517 .63344 m .76517 .68902 L .79455 .68564 L p .707 .577 .707 r
F P
0 g
s
.79455 .68564 m .79455 .63006 L .76517 .63344 L p .707 .577 .707 r
F P
0 g
s
.70216 .65638 m .70216 .61933 L .6747 .61493 L p .707 .577 .707 r
F P
0 g
s
.70216 .61933 m .70216 .65638 L .73333 .65828 L p .707 .577 .707 r
F P
0 g
s
.59233 .24091 m .59233 .7428 L .55357 .7366 L p .707 .577 .707 r
F P
0 g
s
.55357 .7366 m .55357 .23471 L .59233 .24091 L p .707 .577 .707 r
F P
0 g
s
.70216 .6879 m .70216 .63232 L .6747 .62792 L p .707 .577 .707 r
F P
0 g
s
.70216 .63232 m .70216 .6879 L .73333 .6898 L p .707 .577 .707 r
F P
0 g
s
.1814 .82603 m .1814 .8075 L .20545 .80185 L p .707 .577 .707 r
F P
0 g
s
.79455 .61707 m .79455 .65413 L .8186 .64848 L p .707 .577 .707 r
F P
0 g
s
.8186 .64848 m .8186 .61142 L .79455 .61707 L p .707 .577 .707 r
F P
0 g
s
.20545 .80185 m .20545 .82038 L .1814 .82603 L p .707 .577 .707 r
F P
0 g
s
.6747 .61493 m .6747 .65199 L .70216 .65638 L p .707 .577 .707 r
F P
0 g
s
.79455 .63006 m .79455 .68564 L .8186 .67999 L p .707 .577 .707 r
F P
0 g
s
.8186 .67999 m .8186 .62441 L .79455 .63006 L p .707 .577 .707 r
F P
0 g
s
.42314 .73978 m .42314 .23789 L .46462 .23312 L p .707 .577 .707 r
F P
0 g
s
.42314 .23789 m .42314 .73978 L .38918 .74776 L p .707 .577 .707 r
F P
0 g
s
.6747 .65199 m .6747 .61493 L .65365 .60848 L p .707 .577 .707 r
F P
0 g
s
.3253 .80399 m .3253 .82252 L .29784 .81812 L p .707 .577 .707 r
F P
0 g
s
.29784 .81812 m .29784 .7996 L .3253 .80399 L p .707 .577 .707 r
F P
0 g
s
.6747 .62792 m .6747 .68351 L .70216 .6879 L p .707 .577 .707 r
F P
0 g
s
.6747 .68351 m .6747 .62792 L .65365 .62147 L p .707 .577 .707 r
F P
0 g
s
.55357 .23471 m .55357 .7366 L .50956 .73392 L p .707 .577 .707 r
F P
0 g
s
.50956 .73392 m .50956 .23203 L .55357 .23471 L p .707 .577 .707 r
F P
0 g
s
.20545 .82038 m .20545 .80185 L .23483 .79847 L p .707 .577 .707 r
F P
0 g
s
.65365 .60848 m .65365 .64553 L .6747 .65199 L p .707 .577 .707 r
F P
0 g
s
.8186 .61142 m .8186 .64848 L .83497 .64111 L p .707 .577 .707 r
F P
0 g
s
.83497 .64111 m .83497 .60405 L .8186 .61142 L p .707 .577 .707 r
F P
0 g
s
.46462 .73501 m .46462 .23312 L .50956 .23203 L p .707 .577 .707 r
F P
0 g
s
.46462 .23312 m .46462 .73501 L .42314 .73978 L p .707 .577 .707 r
F P
0 g
s
.23483 .79847 m .23483 .817 L .20545 .82038 L p .707 .577 .707 r
F P
0 g
s
.8186 .62441 m .8186 .67999 L .83497 .67263 L p .707 .577 .707 r
F P
0 g
s
.83497 .67263 m .83497 .61704 L .8186 .62441 L p .707 .577 .707 r
F P
0 g
s
.50956 .23203 m .50956 .73392 L .46462 .73501 L p .707 .577 .707 r
F P
0 g
s
.29784 .7996 m .29784 .81812 L .26667 .81622 L p .707 .577 .707 r
F P
0 g
s
.26667 .81622 m .26667 .7977 L .29784 .7996 L p .707 .577 .707 r
F P
0 g
s
.65365 .62147 m .65365 .67705 L .6747 .68351 L p .707 .577 .707 r
F P
0 g
s
.23483 .817 m .23483 .79847 L .26667 .7977 L p .707 .577 .707 r
F P
0 g
s
.65365 .64553 m .65365 .60848 L .64105 .6006 L p .707 .577 .707 r
F P
0 g
s
.26667 .7977 m .26667 .81622 L .23483 .817 L p .707 .577 .707 r
F P
0 g
s
.73333 .81571 m .73333 .79718 L .70216 .79528 L p .707 .577 .707 r
F P
0 g
s
.73333 .79718 m .73333 .81571 L .76517 .81493 L p .707 .577 .707 r
F P
0 g
s
.76517 .81493 m .76517 .79641 L .73333 .79718 L p .707 .577 .707 r
F P
0 g
s
.65365 .67705 m .65365 .62147 L .64105 .61359 L p .707 .577 .707 r
F P
0 g
s
.76517 .79641 m .76517 .81493 L .79455 .81156 L p .707 .577 .707 r
F P
0 g
s
.79455 .81156 m .79455 .79303 L .76517 .79641 L p .707 .577 .707 r
F P
0 g
s
.70216 .79528 m .70216 .81381 L .73333 .81571 L p .707 .577 .707 r
F P
0 g
s
.70216 .81381 m .70216 .79528 L .6747 .79089 L p .707 .577 .707 r
F P
0 g
s
.64105 .6006 m .64105 .63765 L .65365 .64553 L p .707 .577 .707 r
F P
0 g
s
.6747 .79089 m .6747 .80942 L .70216 .81381 L p .707 .577 .707 r
F P
0 g
s
.83497 .60405 m .83497 .64111 L .84205 .63274 L p .707 .577 .707 r
F P
0 g
s
.84205 .63274 m .84205 .59569 L .83497 .60405 L p .707 .577 .707 r
F P
0 g
s
.79455 .79303 m .79455 .81156 L .8186 .80591 L p .707 .577 .707 r
F P
0 g
s
.8186 .80591 m .8186 .78738 L .79455 .79303 L p .707 .577 .707 r
F P
0 g
s
.64105 .61359 m .64105 .66917 L .65365 .67705 L p .707 .577 .707 r
F P
0 g
s
.83497 .61704 m .83497 .67263 L .84205 .66426 L p .707 .577 .707 r
F P
0 g
s
.84205 .66426 m .84205 .60868 L .83497 .61704 L p .707 .577 .707 r
F P
0 g
s
.6747 .80942 m .6747 .79089 L .65365 .78444 L p .707 .577 .707 r
F P
0 g
s
.64105 .63765 m .64105 .6006 L .63816 .59205 L p .707 .577 .707 r
F P
0 g
s
.65365 .78444 m .65365 .80297 L .6747 .80942 L p .707 .577 .707 r
F P
0 g
s
.64105 .66917 m .64105 .61359 L .63816 .60504 L p .707 .577 .707 r
F P
0 g
s
.8186 .78738 m .8186 .80591 L .83497 .79854 L p .707 .577 .707 r
F P
0 g
s
.83497 .79854 m .83497 .78001 L .8186 .78738 L p .707 .577 .707 r
F P
0 g
s
.63816 .59205 m .63816 .62911 L .64105 .63765 L p .707 .577 .707 r
F P
0 g
s
.84205 .59569 m .84205 .63274 L .83916 .6242 L p .707 .577 .707 r
F P
0 g
s
.83916 .6242 m .83916 .58715 L .84205 .59569 L p .707 .577 .707 r
F P
0 g
s
.63816 .60504 m .63816 .66063 L .64105 .66917 L p .707 .577 .707 r
F P
0 g
s
.65365 .80297 m .65365 .78444 L .64105 .77655 L p .707 .577 .707 r
F P
0 g
s
.84205 .60868 m .84205 .66426 L .83916 .65572 L p .707 .577 .707 r
F P
0 g
s
.83916 .65572 m .83916 .60014 L .84205 .60868 L p .707 .577 .707 r
F P
0 g
s
.64105 .77655 m .64105 .79508 L .65365 .80297 L p .707 .577 .707 r
F P
0 g
s
.63816 .62911 m .63816 .59205 L .64524 .58369 L p .707 .577 .707 r
F P
0 g
s
.63816 .66063 m .63816 .60504 L .64524 .59668 L p .707 .577 .707 r
F P
0 g
s
.83497 .78001 m .83497 .79854 L .84206 .79017 L p .707 .577 .707 r
F P
0 g
s
.84206 .79017 m .84206 .77165 L .83497 .78001 L p .707 .577 .707 r
F P
0 g
s
.64524 .58369 m .64524 .62074 L .63816 .62911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83916 .58715 m .83916 .6242 L .82657 .61632 L p .707 .577 .707 r
F P
0 g
s
.82657 .61632 m .82657 .57926 L .83916 .58715 L p .707 .577 .707 r
F P
0 g
s
.64105 .79508 m .64105 .77655 L .63816 .76801 L p .707 .577 .707 r
F P
0 g
s
.64524 .59668 m .64524 .65226 L .63816 .66063 L p .707 .577 .707 r
F P
0 g
s
.83916 .60014 m .83916 .65572 L .82657 .64783 L p .707 .577 .707 r
F P
0 g
s
.82657 .64783 m .82657 .59225 L .83916 .60014 L p .707 .577 .707 r
F P
0 g
s
.63816 .76801 m .63816 .78654 L .64105 .79508 L p .707 .577 .707 r
F P
0 g
s
.39032 .62147 m .39032 .58441 L .35915 .58251 L p .707 .577 .707 r
F P
0 g
s
.39032 .58441 m .39032 .62147 L .42216 .62069 L p .707 .577 .707 r
F P
0 g
s
.42216 .62069 m .42216 .58363 L .39032 .58441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .62074 m .64524 .58369 L .66161 .57632 L p .707 .577 .707 r
F P
0 g
s
.42216 .58363 m .42216 .62069 L .45154 .61731 L p .707 .577 .707 r
F P
0 g
s
.45154 .61731 m .45154 .58025 L .42216 .58363 L p .707 .577 .707 r
F P
0 g
s
.39032 .65298 m .39032 .5974 L .35915 .5955 L p .707 .577 .707 r
F P
0 g
s
.39032 .5974 m .39032 .65298 L .42216 .65221 L p .707 .577 .707 r
F P
0 g
s
.42216 .65221 m .42216 .59662 L .39032 .5974 L p .707 .577 .707 r
F P
0 g
s
.64524 .65226 m .64524 .59668 L .66161 .58931 L p .707 .577 .707 r
F P
0 g
s
.42216 .59662 m .42216 .65221 L .45154 .64883 L p .707 .577 .707 r
F P
0 g
s
.45154 .64883 m .45154 .59325 L .42216 .59662 L p .707 .577 .707 r
F P
0 g
s
.35915 .61957 m .35915 .58251 L .33169 .57812 L p .707 .577 .707 r
F P
0 g
s
.35915 .58251 m .35915 .61957 L .39032 .62147 L p .707 .577 .707 r
F P
0 g
s
.84206 .77165 m .84206 .79017 L .83916 .78163 L p .707 .577 .707 r
F P
0 g
s
.83916 .78163 m .83916 .7631 L .84206 .77165 L p .707 .577 .707 r
F P
0 g
s
.35915 .65108 m .35915 .5955 L .33169 .59111 L p .707 .577 .707 r
F P
0 g
s
.35915 .5955 m .35915 .65108 L .39032 .65298 L p .707 .577 .707 r
F P
0 g
s
.66161 .57632 m .66161 .61338 L .64524 .62074 L p .707 .577 .707 r
F P
0 g
s
.45154 .58025 m .45154 .61731 L .47559 .61166 L p .707 .577 .707 r
F P
0 g
s
.47559 .61166 m .47559 .5746 L .45154 .58025 L p .707 .577 .707 r
F P
0 g
s
.33169 .57812 m .33169 .61517 L .35915 .61957 L p .707 .577 .707 r
F P
0 g
s
.82657 .57926 m .82657 .61632 L .80551 .60986 L p .707 .577 .707 r
F P
0 g
s
.80551 .60986 m .80551 .57281 L .82657 .57926 L p .707 .577 .707 r
F P
0 g
s
.45154 .59325 m .45154 .64883 L .47559 .64318 L p .707 .577 .707 r
F P
0 g
s
.47559 .64318 m .47559 .5876 L .45154 .59325 L p .707 .577 .707 r
F P
0 g
s
.63816 .78654 m .63816 .76801 L .64524 .75965 L p .707 .577 .707 r
F P
0 g
s
.66161 .58931 m .66161 .64489 L .64524 .65226 L p .707 .577 .707 r
F P
0 g
s
.82657 .59225 m .82657 .64783 L .80551 .64138 L p .707 .577 .707 r
F P
0 g
s
.80551 .64138 m .80551 .5858 L .82657 .59225 L p .707 .577 .707 r
F P
0 g
s
.33169 .61517 m .33169 .57812 L .31064 .57166 L p .707 .577 .707 r
F P
0 g
s
.33169 .59111 m .33169 .64669 L .35915 .65108 L p .707 .577 .707 r
F P
0 g
s
.33169 .64669 m .33169 .59111 L .31064 .58465 L p .707 .577 .707 r
F P
0 g
s
.64524 .75965 m .64524 .77817 L .63816 .78654 L p .707 .577 .707 r
F P
0 g
s
.66161 .61338 m .66161 .57632 L .68566 .57067 L p .707 .577 .707 r
F P
0 g
s
.66161 .64489 m .66161 .58931 L .68566 .58366 L p .707 .577 .707 r
F P
0 g
s
.31064 .57166 m .31064 .60872 L .33169 .61517 L p .707 .577 .707 r
F P
0 g
s
.47559 .5746 m .47559 .61166 L .49196 .60429 L p .707 .577 .707 r
F P
0 g
s
.49196 .60429 m .49196 .56724 L .47559 .5746 L p .707 .577 .707 r
F P
0 g
s
.47559 .5876 m .47559 .64318 L .49196 .63581 L p .707 .577 .707 r
F P
0 g
s
.49196 .63581 m .49196 .58023 L .47559 .5876 L p .707 .577 .707 r
F P
0 g
s
.83916 .7631 m .83916 .78163 L .82657 .77375 L p .707 .577 .707 r
F P
0 g
s
.82657 .77375 m .82657 .75522 L .83916 .7631 L p .707 .577 .707 r
F P
0 g
s
.68566 .57067 m .68566 .60773 L .66161 .61338 L p .707 .577 .707 r
F P
0 g
s
.80551 .57281 m .80551 .60986 L .77805 .60547 L p .707 .577 .707 r
F P
0 g
s
.77805 .60547 m .77805 .56842 L .80551 .57281 L p .707 .577 .707 r
F P
0 g
s
.31064 .58465 m .31064 .64024 L .33169 .64669 L p .707 .577 .707 r
F P
0 g
s
.80551 .5858 m .80551 .64138 L .77805 .63699 L p .707 .577 .707 r
F P
0 g
s
.77805 .63699 m .77805 .58141 L .80551 .5858 L p .707 .577 .707 r
F P
0 g
s
.31064 .60872 m .31064 .57166 L .29804 .56378 L p .707 .577 .707 r
F P
0 g
s
.68566 .58366 m .68566 .63924 L .66161 .64489 L p .707 .577 .707 r
F P
0 g
s
.39032 .7789 m .39032 .76037 L .35915 .75847 L p .707 .577 .707 r
F P
0 g
s
.39032 .76037 m .39032 .7789 L .42216 .77812 L p .707 .577 .707 r
F P
0 g
s
.42216 .77812 m .42216 .75959 L .39032 .76037 L p .707 .577 .707 r
F P
0 g
s
.68566 .60773 m .68566 .57067 L .71504 .56729 L p .707 .577 .707 r
F P
0 g
s
.31064 .64024 m .31064 .58465 L .29804 .57677 L p .707 .577 .707 r
F P
0 g
s
.64524 .77817 m .64524 .75965 L .66161 .75228 L p .707 .577 .707 r
F P
0 g
s
.42216 .75959 m .42216 .77812 L .45154 .77474 L p .707 .577 .707 r
F P
0 g
s
.45154 .77474 m .45154 .75621 L .42216 .75959 L p .707 .577 .707 r
F P
0 g
s
.68566 .63924 m .68566 .58366 L .71504 .58028 L p .707 .577 .707 r
F P
0 g
s
.35915 .75847 m .35915 .777 L .39032 .7789 L p .707 .577 .707 r
F P
0 g
s
.35915 .777 m .35915 .75847 L .33169 .75408 L p .707 .577 .707 r
F P
0 g
s
.29804 .56378 m .29804 .60083 L .31064 .60872 L p .707 .577 .707 r
F P
0 g
s
.66161 .75228 m .66161 .77081 L .64524 .77817 L p .707 .577 .707 r
F P
0 g
s
.77805 .56842 m .77805 .60547 L .74688 .60357 L p .707 .577 .707 r
F P
0 g
s
.74688 .60357 m .74688 .56651 L .77805 .56842 L p .707 .577 .707 r
F P
0 g
s
.71504 .56729 m .71504 .60435 L .68566 .60773 L p .707 .577 .707 r
F P
0 g
s
.33169 .75408 m .33169 .7726 L .35915 .777 L p .707 .577 .707 r
F P
0 g
s
.77805 .58141 m .77805 .63699 L .74688 .63509 L p .707 .577 .707 r
F P
0 g
s
.74688 .63509 m .74688 .57951 L .77805 .58141 L p .707 .577 .707 r
F P
0 g
s
.71504 .60435 m .71504 .56729 L .74688 .56651 L p .707 .577 .707 r
F P
0 g
s
.49196 .56724 m .49196 .60429 L .49904 .59593 L p .707 .577 .707 r
F P
0 g
s
.49904 .59593 m .49904 .55887 L .49196 .56724 L p .707 .577 .707 r
F P
0 g
s
.45154 .75621 m .45154 .77474 L .47559 .76909 L p .707 .577 .707 r
F P
0 g
s
.47559 .76909 m .47559 .75056 L .45154 .75621 L p .707 .577 .707 r
F P
0 g
s
.74688 .56651 m .74688 .60357 L .71504 .60435 L p .707 .577 .707 r
F P
0 g
s
.29804 .57677 m .29804 .63235 L .31064 .64024 L p .707 .577 .707 r
F P
0 g
s
.71504 .63587 m .71504 .58028 L .74688 .57951 L p .707 .577 .707 r
F P
0 g
s
.71504 .58028 m .71504 .63587 L .68566 .63924 L p .707 .577 .707 r
F P
0 g
s
.49196 .58023 m .49196 .63581 L .49904 .62745 L p .707 .577 .707 r
F P
0 g
s
.49904 .62745 m .49904 .57186 L .49196 .58023 L p .707 .577 .707 r
F P
0 g
s
.82657 .75522 m .82657 .77375 L .80551 .76729 L p .707 .577 .707 r
F P
0 g
s
.80551 .76729 m .80551 .74877 L .82657 .75522 L p .707 .577 .707 r
F P
0 g
s
.74688 .57951 m .74688 .63509 L .71504 .63587 L p .707 .577 .707 r
F P
0 g
s
.33169 .7726 m .33169 .75408 L .31064 .74762 L p .707 .577 .707 r
F P
0 g
s
.29804 .60083 m .29804 .56378 L .29515 .55524 L p .707 .577 .707 r
F P
0 g
s
.31064 .74762 m .31064 .76615 L .33169 .7726 L p .707 .577 .707 r
F P
0 g
s
.29804 .63235 m .29804 .57677 L .29515 .56823 L p .707 .577 .707 r
F P
0 g
s
.66161 .77081 m .66161 .75228 L .68566 .74663 L p .707 .577 .707 r
F P
0 g
s
.68566 .74663 m .68566 .76516 L .66161 .77081 L p .707 .577 .707 r
F P
0 g
s
.47559 .75056 m .47559 .76909 L .49196 .76172 L p .707 .577 .707 r
F P
0 g
s
.49196 .76172 m .49196 .7432 L .47559 .75056 L p .707 .577 .707 r
F P
0 g
s
.29515 .55524 m .29515 .59229 L .29804 .60083 L p .707 .577 .707 r
F P
0 g
s
.80551 .74877 m .80551 .76729 L .77805 .7629 L p .707 .577 .707 r
F P
0 g
s
.77805 .7629 m .77805 .74437 L .80551 .74877 L p .707 .577 .707 r
F P
0 g
s
.49904 .55887 m .49904 .59593 L .49615 .58739 L p .707 .577 .707 r
F P
0 g
s
.49615 .58739 m .49615 .55033 L .49904 .55887 L p .707 .577 .707 r
F P
0 g
s
.29515 .56823 m .29515 .62381 L .29804 .63235 L p .707 .577 .707 r
F P
0 g
s
.31064 .76615 m .31064 .74762 L .29804 .73974 L p .707 .577 .707 r
F P
0 g
s
.49904 .57186 m .49904 .62745 L .49615 .6189 L p .707 .577 .707 r
F P
0 g
s
.49615 .6189 m .49615 .56332 L .49904 .57186 L p .707 .577 .707 r
F P
0 g
s
.68566 .76516 m .68566 .74663 L .71504 .74325 L p .707 .577 .707 r
F P
0 g
s
.29804 .73974 m .29804 .75827 L .31064 .76615 L p .707 .577 .707 r
F P
0 g
s
.71504 .74325 m .71504 .76178 L .68566 .76516 L p .707 .577 .707 r
F P
0 g
s
.29515 .59229 m .29515 .55524 L .30223 .54687 L p .707 .577 .707 r
F P
0 g
s
.77805 .74437 m .77805 .7629 L .74688 .761 L p .707 .577 .707 r
F P
0 g
s
.74688 .761 m .74688 .74247 L .77805 .74437 L p .707 .577 .707 r
F P
0 g
s
.29515 .62381 m .29515 .56823 L .30223 .55986 L p .707 .577 .707 r
F P
0 g
s
.71504 .76178 m .71504 .74325 L .74688 .74247 L p .707 .577 .707 r
F P
0 g
s
.49196 .7432 m .49196 .76172 L .49904 .75336 L p .707 .577 .707 r
F P
0 g
s
.49904 .75336 m .49904 .73483 L .49196 .7432 L p .707 .577 .707 r
F P
0 g
s
.74688 .74247 m .74688 .761 L .71504 .76178 L p .707 .577 .707 r
F P
0 g
s
.30223 .54687 m .30223 .58393 L .29515 .59229 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49615 .55033 m .49615 .58739 L .48356 .5795 L p .707 .577 .707 r
F P
0 g
s
.48356 .5795 m .48356 .54245 L .49615 .55033 L p .707 .577 .707 r
F P
0 g
s
.29804 .75827 m .29804 .73974 L .29515 .7312 L p .707 .577 .707 r
F P
0 g
s
.30223 .55986 m .30223 .61545 L .29515 .62381 L p .707 .577 .707 r
F P
0 g
s
.49615 .56332 m .49615 .6189 L .48356 .61102 L p .707 .577 .707 r
F P
0 g
s
.48356 .61102 m .48356 .55544 L .49615 .56332 L p .707 .577 .707 r
F P
0 g
s
.29515 .7312 m .29515 .74972 L .29804 .75827 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .58393 m .30223 .54687 L .3186 .53951 L p .707 .577 .707 r
F P
0 g
s
.30223 .61545 m .30223 .55986 L .3186 .5525 L p .707 .577 .707 r
F P
0 g
s
.49904 .73483 m .49904 .75336 L .49615 .74482 L p .707 .577 .707 r
F P
0 g
s
.49615 .74482 m .49615 .72629 L .49904 .73483 L p .707 .577 .707 r
F P
0 g
s
.3186 .53951 m .3186 .57656 L .30223 .58393 L p .707 .577 .707 r
F P
0 g
s
.48356 .54245 m .48356 .5795 L .4625 .57305 L p .707 .577 .707 r
F P
0 g
s
.4625 .57305 m .4625 .53599 L .48356 .54245 L p .707 .577 .707 r
F P
0 g
s
.29515 .74972 m .29515 .7312 L .30223 .72283 L p .707 .577 .707 r
F P
0 g
s
.3186 .5525 m .3186 .60808 L .30223 .61545 L p .707 .577 .707 r
F P
0 g
s
.48356 .55544 m .48356 .61102 L .4625 .60457 L p .707 .577 .707 r
F P
0 g
s
.4625 .60457 m .4625 .54898 L .48356 .55544 L p .707 .577 .707 r
F P
0 g
s
.30223 .72283 m .30223 .74136 L .29515 .74972 L p .707 .577 .707 r
F P
0 g
s
.3186 .57656 m .3186 .53951 L .34265 .53386 L p .707 .577 .707 r
F P
0 g
s
.3186 .60808 m .3186 .5525 L .34265 .54685 L p .707 .577 .707 r
F P
0 g
s
.49615 .72629 m .49615 .74482 L .48356 .73693 L p .707 .577 .707 r
F P
0 g
s
.48356 .73693 m .48356 .71841 L .49615 .72629 L p .707 .577 .707 r
F P
0 g
s
.34265 .53386 m .34265 .57091 L .3186 .57656 L p .707 .577 .707 r
F P
0 g
s
.4625 .53599 m .4625 .57305 L .43504 .56865 L p .707 .577 .707 r
F P
0 g
s
.43504 .56865 m .43504 .5316 L .4625 .53599 L p .707 .577 .707 r
F P
0 g
s
.4625 .54898 m .4625 .60457 L .43504 .60017 L p .707 .577 .707 r
F P
0 g
s
.43504 .60017 m .43504 .54459 L .4625 .54898 L p .707 .577 .707 r
F P
0 g
s
.34265 .54685 m .34265 .60243 L .3186 .60808 L p .707 .577 .707 r
F P
0 g
s
.34265 .57091 m .34265 .53386 L .37203 .53048 L p .707 .577 .707 r
F P
0 g
s
.30223 .74136 m .30223 .72283 L .3186 .71546 L p .707 .577 .707 r
F P
0 g
s
.34265 .60243 m .34265 .54685 L .37203 .54347 L p .707 .577 .707 r
F P
0 g
s
.3186 .71546 m .3186 .73399 L .30223 .74136 L p .707 .577 .707 r
F P
0 g
s
.43504 .5316 m .43504 .56865 L .40387 .56675 L p .707 .577 .707 r
F P
0 g
s
.40387 .56675 m .40387 .5297 L .43504 .5316 L p .707 .577 .707 r
F P
0 g
s
.37203 .53048 m .37203 .56753 L .34265 .57091 L p .707 .577 .707 r
F P
0 g
s
.43504 .54459 m .43504 .60017 L .40387 .59827 L p .707 .577 .707 r
F P
0 g
s
.40387 .59827 m .40387 .54269 L .43504 .54459 L p .707 .577 .707 r
F P
0 g
s
.37203 .56753 m .37203 .53048 L .40387 .5297 L p .707 .577 .707 r
F P
0 g
s
.40387 .5297 m .40387 .56675 L .37203 .56753 L p .707 .577 .707 r
F P
0 g
s
.37203 .59905 m .37203 .54347 L .40387 .54269 L p .707 .577 .707 r
F P
0 g
s
.37203 .54347 m .37203 .59905 L .34265 .60243 L p .707 .577 .707 r
F P
0 g
s
.48356 .71841 m .48356 .73693 L .4625 .73048 L p .707 .577 .707 r
F P
0 g
s
.4625 .73048 m .4625 .71195 L .48356 .71841 L p .707 .577 .707 r
F P
0 g
s
.40387 .54269 m .40387 .59827 L .37203 .59905 L p .707 .577 .707 r
F P
0 g
s
.3186 .73399 m .3186 .71546 L .34265 .70981 L p .707 .577 .707 r
F P
0 g
s
.34265 .70981 m .34265 .72834 L .3186 .73399 L p .707 .577 .707 r
F P
0 g
s
.4625 .71195 m .4625 .73048 L .43504 .72609 L p .707 .577 .707 r
F P
0 g
s
.43504 .72609 m .43504 .70756 L .4625 .71195 L p .707 .577 .707 r
F P
0 g
s
.34265 .72834 m .34265 .70981 L .37203 .70644 L p .707 .577 .707 r
F P
0 g
s
.37203 .70644 m .37203 .72496 L .34265 .72834 L p .707 .577 .707 r
F P
0 g
s
.43504 .70756 m .43504 .72609 L .40387 .72419 L p .707 .577 .707 r
F P
0 g
s
.40387 .72419 m .40387 .70566 L .43504 .70756 L p .707 .577 .707 r
F P
0 g
s
.37203 .72496 m .37203 .70644 L .40387 .70566 L p .707 .577 .707 r
F P
0 g
s
.40387 .70566 m .40387 .72419 L .37203 .72496 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001fOol90005FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJ
EP<006ioo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00IWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eooa80
0003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF
20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF
009JEP03001JEUYF01@000IJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001DOol20004FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH000000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001C
Ool00`00FUH00004FUH01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH00002000dOol005=oo`03001JEP00009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool3
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000bOol005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00
FUIJEP03FUH60003FUH50004FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH3000`Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF008002io
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP03001oogoo
02aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20003FUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP000000;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00
;Goo001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH00008FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0004FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH00eYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH000030002FUH40007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004Moo`T000=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h0
00AJEP03001JEUYF009JEPD000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0031oo`800003FUH005YF00EJ
EP03001JEUYF009JEP03001JEUYF00h000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00UYF1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF009JEP8002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000EJEP00001JEP0000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP8002eoo`00
;7oo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEQ/000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
000002eoo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH50003FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP04
001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool0
02aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH3
00000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF2@0015YF00<005YF
FUH00UYF2@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH00eYF00<005YFFUH00`000goo2@00B7oo000/Ool00`00FUH00004FUH00`00
FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001D
Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01000FUH0
05YF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUH005YF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002aoo`06001JEP00001JEP0015YF0P001eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF1P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0027oo0`00BGoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P001goo1@00B7oo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF
FUH20007Ool50018Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005
FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008FUH80004FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P001goo1@00B7oo000_Ool3
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF00@005YFFUIJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`00BGoo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF00000eYF1@000UYF0`000Woo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEPX000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH2001DOol0
03=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP@000IJEP06001JEP00FUH005YF0`000eYF1000
17oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP/000=JEP03001JEUYF00MJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP<00003FUH0
05YF009JEP8005Aoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001JEPP0
00Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH9000;FUH200000eYF001JEP09FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH30003
FUH2001DOol003]ooa`000ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH3
000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000H000lOol005=oo`80009JEP<000]oo`04001JEUYF
0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH300000eYF001JEP09FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH70004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol20003FUH00`00FUH0
00020008Ool01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YF00002UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00000UYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo001COol20003FUH00`00FUIJEP02FUH50003Ool01@00FUIJEP00FUH00P001eYF00<0
05YFFUH025YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005Aoo`05001J
EUYFFUH00005FUH01000FUIJEUYF200000=JEP00FUH01UYF3`001EYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00004FUH000000002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH3000`Ool005Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF60001EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001GOol30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP02FUH6000HOol400000eYF001J
EP04FUH01@00FUIJEUYF0000;Woo001JOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUH0000300000eYF0000000N
Ool30004FUH01000FUIJEUYF0P00;Goo0018Ool3000BOol50004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH30002FUH3000SOol300000eYF001JEP02
FUH2000]Ool004Moo`D001Ioo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00800003
FUH00000008002Uoo`8000=JEP8002eoo`00Agoo1@006Woo00@005YFFUIJEQ<00003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<002moo`800003FUH0000002eoo`00Agoo1@006Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0000=JEP00Ool0<7oo0P0000AJEP00000002eoo`00B7oo0`0077oo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF10000UYF0`00:goo0`000eYF0`00;Goo001YOol30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000
FUIJEUYF0P000Woo0P000UYF00<005YFFUH01@008Woo100000=JEP00FUH00eYF00<005YF0000;Goo
001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH000001Goo00@005YFFUH000EJEP03001JEP0000<001Uoo`D000EJEP03
001JEUYF009JEP8002ioo`00Agoo2@007Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001goo00@005YFFUH000EJEP03001JEUYF
00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00?goo200015YF00<005YFFUH0
0UYF20005goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01@0037oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPH001Aoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00IJEPD001=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008001Qoo``000IJEP03001J
EUYF00YJEP03001JEUYF00H001Yoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80029ooaH000mo
o`<0015oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`00A7oo1@005Goo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020012Ool5001_Ool002eoo`8000AJ
EP04001JEUYFFUH8000IOol60004FUH01@00FUIJEUYF0000@Woo1@00Kgoo000/Ool00`00FUH00003
FUH5000WOol300000eYF001JEP02FUH00`00Oomoo`11Ool3001`Ool002aoo`04001JEP00FUH2000_
Ool20003FUH00`00Oomoo`2dOol002aoo`04001JEP00000cOol200000eYF001oo`2eOol002aoo`@0
03Aoo`<003UooaP006Eoo`00;7oo0P000UYF0`00;goo0`0000=JEP00Ool0<Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`00HGoo000/Ool20003FUH00`00FUH00002000YOol3
0002FUH00`00FUH0000`Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4001MOol002aoo`8000=JEP03001JEUYF009JEPD0021oo`@00003FUH005YF009JEP03
001JEP0002eoo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000COol50005
FUH01000FUIJEUYF0P00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00F7oo000^Ool01000FUIJEP001EYF00<0
05YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH0
0000EWoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;7oo00<005YF000015YF00<0
05YF00000P0087oo1@0015YF00D005YFFUIJEP0005Eoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`00:7oo0`0000=J
EP00FUH00UYF0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH5000cOol01000FUH005YF0P00;Woo0P000eYF0P00E7oo000mOolI000hOol01000FUH00000<Woo
0P0000=JEP000000E7oo002>Ool200000eYF001oo`0aOol5001DOol008ioo`80009JEP8002ioo`80
009JEP<005Aoo`00SWoo0P000UYF00<005YF00000P009goo100015YF00<005YF0000E7oo002?Ool0
1000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF
00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD005Yoo`00Ugoo1@0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002LOol90004FUH00`00FUIJ
EP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75032 m .59613 .71326 L .56496 .71136 L p .707 .577 .707 r
F P
0 g
s
.59613 .71326 m .59613 .75032 L .62796 .74954 L p .707 .577 .707 r
F P
0 g
s
.62796 .74954 m .62796 .71249 L .59613 .71326 L p .707 .577 .707 r
F P
0 g
s
.62796 .71249 m .62796 .74954 L .65735 .74616 L p .707 .577 .707 r
F P
0 g
s
.65735 .74616 m .65734 .70911 L .62796 .71249 L p .707 .577 .707 r
F P
0 g
s
.59613 .78184 m .59613 .72626 L .56496 .72435 L p .707 .577 .707 r
F P
0 g
s
.59613 .72626 m .59613 .78184 L .62796 .78106 L p .707 .577 .707 r
F P
0 g
s
.62796 .78106 m .62796 .72548 L .59613 .72626 L p .707 .577 .707 r
F P
0 g
s
.62796 .72548 m .62796 .78106 L .65735 .77768 L p .707 .577 .707 r
F P
0 g
s
.65735 .77768 m .65734 .7221 L .62796 .72548 L p .707 .577 .707 r
F P
0 g
s
.56496 .74842 m .56496 .71136 L .5375 .70697 L p .707 .577 .707 r
F P
0 g
s
.56496 .71136 m .56496 .74842 L .59613 .75032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77994 m .56496 .72435 L .5375 .71996 L p .707 .577 .707 r
F P
0 g
s
.56496 .72435 m .56496 .77994 L .59613 .78184 L p .707 .577 .707 r
F P
0 g
s
.65734 .70911 m .65735 .74616 L .6814 .74051 L p .707 .577 .707 r
F P
0 g
s
.6814 .74051 m .6814 .70346 L .65734 .70911 L p .707 .577 .707 r
F P
0 g
s
.5375 .70697 m .5375 .74403 L .56496 .74842 L p .707 .577 .707 r
F P
0 g
s
.65734 .7221 m .65735 .77768 L .6814 .77203 L p .707 .577 .707 r
F P
0 g
s
.6814 .77203 m .6814 .71645 L .65734 .7221 L p .707 .577 .707 r
F P
0 g
s
.5375 .74403 m .5375 .70697 L .51644 .70052 L p .707 .577 .707 r
F P
0 g
s
.5375 .71996 m .5375 .77554 L .56496 .77994 L p .707 .577 .707 r
F P
0 g
s
.5375 .77554 m .5375 .71996 L .51644 .71351 L p .707 .577 .707 r
F P
0 g
s
.51644 .70052 m .51644 .73757 L .5375 .74403 L p .707 .577 .707 r
F P
0 g
s
.6814 .70346 m .6814 .74051 L .69777 .73315 L p .707 .577 .707 r
F P
0 g
s
.69777 .73315 m .69777 .69609 L .6814 .70346 L p .707 .577 .707 r
F P
0 g
s
.6814 .71645 m .6814 .77203 L .69777 .76466 L p .707 .577 .707 r
F P
0 g
s
.69777 .76466 m .69777 .70908 L .6814 .71645 L p .707 .577 .707 r
F P
0 g
s
.51644 .71351 m .51644 .76909 L .5375 .77554 L p .707 .577 .707 r
F P
0 g
s
.51644 .73757 m .51644 .70052 L .50385 .69263 L p .707 .577 .707 r
F P
0 g
s
.59613 .90775 m .59613 .88922 L .56496 .88732 L p .707 .577 .707 r
F P
0 g
s
.59613 .88922 m .59613 .90775 L .62796 .90697 L p .707 .577 .707 r
F P
0 g
s
.62796 .90697 m .62796 .88845 L .59613 .88922 L p .707 .577 .707 r
F P
0 g
s
.51644 .76909 m .51644 .71351 L .50385 .70562 L p .707 .577 .707 r
F P
0 g
s
.62796 .88845 m .62796 .90697 L .65735 .90359 L p .707 .577 .707 r
F P
0 g
s
.65735 .90359 m .65735 .88507 L .62796 .88845 L p .707 .577 .707 r
F P
0 g
s
.56496 .88732 m .56496 .90585 L .59613 .90775 L p .707 .577 .707 r
F P
0 g
s
.56496 .90585 m .56496 .88732 L .5375 .88293 L p .707 .577 .707 r
F P
0 g
s
.50385 .69263 m .50385 .72969 L .51644 .73757 L p .707 .577 .707 r
F P
0 g
s
.5375 .88293 m .5375 .90146 L .56496 .90585 L p .707 .577 .707 r
F P
0 g
s
.69777 .69609 m .69777 .73315 L .70485 .72478 L p .707 .577 .707 r
F P
0 g
s
.70485 .72478 m .70485 .68773 L .69777 .69609 L p .707 .577 .707 r
F P
0 g
s
.65735 .88507 m .65735 .90359 L .6814 .89794 L p .707 .577 .707 r
F P
0 g
s
.6814 .89794 m .6814 .87942 L .65735 .88507 L p .707 .577 .707 r
F P
0 g
s
.50385 .70562 m .50385 .76121 L .51644 .76909 L p .707 .577 .707 r
F P
0 g
s
.69777 .70908 m .69777 .76466 L .70485 .7563 L p .707 .577 .707 r
F P
0 g
s
.70485 .7563 m .70485 .70072 L .69777 .70908 L p .707 .577 .707 r
F P
0 g
s
.5375 .90146 m .5375 .88293 L .51644 .87648 L p .707 .577 .707 r
F P
0 g
s
.50385 .72969 m .50385 .69263 L .50095 .68409 L p .707 .577 .707 r
F P
0 g
s
.51644 .87648 m .51644 .895 L .5375 .90146 L p .707 .577 .707 r
F P
0 g
s
.50385 .76121 m .50385 .70562 L .50095 .69708 L p .707 .577 .707 r
F P
0 g
s
.6814 .87942 m .6814 .89794 L .69777 .89058 L p .707 .577 .707 r
F P
0 g
s
.69777 .89058 m .69777 .87205 L .6814 .87942 L p .707 .577 .707 r
F P
0 g
s
.50095 .68409 m .50095 .72115 L .50385 .72969 L p .707 .577 .707 r
F P
0 g
s
.70485 .68773 m .70485 .72478 L .70195 .71624 L p .707 .577 .707 r
F P
0 g
s
.70195 .71624 m .70195 .67918 L .70485 .68773 L p .707 .577 .707 r
F P
0 g
s
.49044 .81115 m .49044 .30927 L .44643 .30658 L p .707 .577 .707 r
F P
0 g
s
.50095 .69708 m .50095 .75266 L .50385 .76121 L p .707 .577 .707 r
F P
0 g
s
.50095 .72115 m .50095 .68409 L .50804 .67573 L p .707 .577 .707 r
F P
0 g
s
.50095 .75266 m .50095 .69708 L .50804 .68872 L p .707 .577 .707 r
F P
0 g
s
.50804 .67573 m .50804 .71278 L .50095 .72115 L p .707 .577 .707 r
F P
0 g
s
.50804 .68872 m .50804 .7443 L .50095 .75266 L p .707 .577 .707 r
F P
0 g
s
.50804 .71278 m .50804 .67573 L .5244 .66836 L p .707 .577 .707 r
F P
0 g
s
.50804 .7443 m .50804 .68872 L .5244 .68135 L p .707 .577 .707 r
F P
0 g
s
.5244 .66836 m .5244 .70541 L .50804 .71278 L p .707 .577 .707 r
F P
0 g
s
.5244 .68135 m .5244 .73693 L .50804 .7443 L p .707 .577 .707 r
F P
0 g
s
.5244 .70541 m .5244 .66836 L .54846 .66271 L p .707 .577 .707 r
F P
0 g
s
.5244 .73693 m .5244 .68135 L .54846 .6757 L p .707 .577 .707 r
F P
0 g
s
.54846 .66271 m .54846 .69976 L .5244 .70541 L p .707 .577 .707 r
F P
0 g
s
.54846 .6757 m .54846 .73128 L .5244 .73693 L p .707 .577 .707 r
F P
0 g
s
.49044 .30927 m .49044 .81115 L .53538 .81006 L p .707 .577 .707 r
F P
0 g
s
.53538 .81006 m .53538 .30817 L .49044 .30927 L p .707 .577 .707 r
F P
0 g
s
.51644 .895 m .51644 .87648 L .50385 .86859 L p .707 .577 .707 r
F P
0 g
s
.70485 .70072 m .70485 .7563 L .70195 .74776 L p .707 .577 .707 r
F P
0 g
s
.70195 .74776 m .70195 .69218 L .70485 .70072 L p .707 .577 .707 r
F P
0 g
s
.54846 .69976 m .54846 .66271 L .57784 .65933 L p .707 .577 .707 r
F P
0 g
s
.54846 .73128 m .54846 .6757 L .57784 .67232 L p .707 .577 .707 r
F P
0 g
s
.57784 .65933 m .57784 .69639 L .54846 .69976 L p .707 .577 .707 r
F P
0 g
s
.57784 .67232 m .57784 .7279 L .54846 .73128 L p .707 .577 .707 r
F P
0 g
s
.53538 .30817 m .53538 .81006 L .57686 .80529 L p .707 .577 .707 r
F P
0 g
s
.57686 .80529 m .57686 .3034 L .53538 .30817 L p .707 .577 .707 r
F P
0 g
s
.50385 .86859 m .50385 .88712 L .51644 .895 L p .707 .577 .707 r
F P
0 g
s
.44643 .80847 m .44643 .30658 L .40766 .30038 L p .707 .577 .707 r
F P
0 g
s
.44643 .30658 m .44643 .80847 L .49044 .81115 L p .707 .577 .707 r
F P
0 g
s
.69777 .87205 m .69777 .89058 L .70485 .88221 L p .707 .577 .707 r
F P
0 g
s
.70485 .88221 m .70485 .86368 L .69777 .87205 L p .707 .577 .707 r
F P
0 g
s
.57784 .69639 m .57784 .65933 L .60968 .65855 L p .707 .577 .707 r
F P
0 g
s
.60968 .65855 m .60968 .69561 L .57784 .69639 L p .707 .577 .707 r
F P
0 g
s
.57784 .7279 m .57784 .67232 L .60968 .67154 L p .707 .577 .707 r
F P
0 g
s
.60968 .67154 m .60968 .72713 L .57784 .7279 L p .707 .577 .707 r
F P
0 g
s
.57686 .3034 m .57686 .80529 L .61082 .79731 L p .707 .577 .707 r
F P
0 g
s
.64085 .66045 m .64085 .69751 L .60968 .69561 L p .707 .577 .707 r
F P
0 g
s
.60968 .69561 m .60968 .65855 L .64085 .66045 L p .707 .577 .707 r
F P
0 g
s
.64085 .67344 m .64085 .72903 L .60968 .72713 L p .707 .577 .707 r
F P
0 g
s
.60968 .72713 m .60968 .67154 L .64085 .67344 L p .707 .577 .707 r
F P
0 g
s
.61082 .79731 m .61082 .29542 L .57686 .3034 L p .707 .577 .707 r
F P
0 g
s
.70195 .67918 m .70195 .71624 L .68936 .70836 L p .707 .577 .707 r
F P
0 g
s
.68936 .70836 m .68936 .6713 L .70195 .67918 L p .707 .577 .707 r
F P
0 g
s
.50385 .88712 m .50385 .86859 L .50095 .86005 L p .707 .577 .707 r
F P
0 g
s
.40766 .80227 m .40766 .30038 L .37794 .29127 L p .707 .577 .707 r
F P
0 g
s
.40766 .30038 m .40766 .80227 L .44643 .80847 L p .707 .577 .707 r
F P
0 g
s
.70195 .69218 m .70195 .74776 L .68936 .73987 L p .707 .577 .707 r
F P
0 g
s
.68936 .73987 m .68936 .68429 L .70195 .69218 L p .707 .577 .707 r
F P
0 g
s
.50095 .86005 m .50095 .87858 L .50385 .88712 L p .707 .577 .707 r
F P
0 g
s
.25312 .7135 m .25312 .67645 L .22195 .67455 L p .707 .577 .707 r
F P
0 g
s
.25312 .67645 m .25312 .7135 L .28495 .71273 L p .707 .577 .707 r
F P
0 g
s
.28495 .71273 m .28495 .67567 L .25312 .67645 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28495 .67567 m .28495 .71273 L .31434 .70935 L p .707 .577 .707 r
F P
0 g
s
.31434 .70935 m .31434 .67229 L .28495 .67567 L p .707 .577 .707 r
F P
0 g
s
.25312 .74502 m .25312 .68944 L .22195 .68754 L p .707 .577 .707 r
F P
0 g
s
.25312 .68944 m .25312 .74502 L .28495 .74424 L p .707 .577 .707 r
F P
0 g
s
.28495 .74424 m .28495 .68866 L .25312 .68944 L p .707 .577 .707 r
F P
0 g
s
.28495 .68866 m .28495 .74424 L .31434 .74087 L p .707 .577 .707 r
F P
0 g
s
.31434 .74087 m .31434 .68528 L .28495 .68866 L p .707 .577 .707 r
F P
0 g
s
.22195 .7116 m .22195 .67455 L .19449 .67016 L p .707 .577 .707 r
F P
0 g
s
.22195 .67455 m .22195 .7116 L .25312 .7135 L p .707 .577 .707 r
F P
0 g
s
.70485 .86368 m .70485 .88221 L .70195 .87367 L p .707 .577 .707 r
F P
0 g
s
.70195 .87367 m .70195 .85514 L .70485 .86368 L p .707 .577 .707 r
F P
0 g
s
.22195 .74312 m .22195 .68754 L .19449 .68315 L p .707 .577 .707 r
F P
0 g
s
.22195 .68754 m .22195 .74312 L .25312 .74502 L p .707 .577 .707 r
F P
0 g
s
.61082 .29542 m .61082 .79731 L .63393 .78691 L p .707 .577 .707 r
F P
0 g
s
.63393 .78691 m .63393 .28502 L .61082 .29542 L p .707 .577 .707 r
F P
0 g
s
.31434 .67229 m .31434 .70935 L .33839 .7037 L p .707 .577 .707 r
F P
0 g
s
.33839 .7037 m .33839 .66664 L .31434 .67229 L p .707 .577 .707 r
F P
0 g
s
.19449 .67016 m .19449 .70721 L .22195 .7116 L p .707 .577 .707 r
F P
0 g
s
.68936 .6713 m .68936 .70836 L .66831 .7019 L p .707 .577 .707 r
F P
0 g
s
.66831 .7019 m .66831 .66485 L .68936 .6713 L p .707 .577 .707 r
F P
0 g
s
.31434 .68528 m .31434 .74087 L .33839 .73522 L p .707 .577 .707 r
F P
0 g
s
.33839 .73522 m .33839 .67963 L .31434 .68528 L p .707 .577 .707 r
F P
0 g
s
.50095 .87858 m .50095 .86005 L .50804 .85169 L p .707 .577 .707 r
F P
0 g
s
.68936 .68429 m .68936 .73987 L .66831 .73342 L p .707 .577 .707 r
F P
0 g
s
.66831 .73342 m .66831 .67784 L .68936 .68429 L p .707 .577 .707 r
F P
0 g
s
.19449 .70721 m .19449 .67016 L .17343 .6637 L p .707 .577 .707 r
F P
0 g
s
.37794 .79316 m .37794 .29127 L .36016 .28014 L p .707 .577 .707 r
F P
0 g
s
.37794 .29127 m .37794 .79316 L .40766 .80227 L p .707 .577 .707 r
F P
0 g
s
.19449 .68315 m .19449 .73873 L .22195 .74312 L p .707 .577 .707 r
F P
0 g
s
.19449 .73873 m .19449 .68315 L .17343 .67669 L p .707 .577 .707 r
F P
0 g
s
.50804 .85169 m .50804 .87021 L .50095 .87858 L p .707 .577 .707 r
F P
0 g
s
.17343 .6637 m .17343 .70076 L .19449 .70721 L p .707 .577 .707 r
F P
0 g
s
.33839 .66664 m .33839 .7037 L .35476 .69633 L p .707 .577 .707 r
F P
0 g
s
.35476 .69633 m .35476 .65928 L .33839 .66664 L p .707 .577 .707 r
F P
0 g
s
.33839 .67963 m .33839 .73522 L .35476 .72785 L p .707 .577 .707 r
F P
0 g
s
.35476 .72785 m .35476 .67227 L .33839 .67963 L p .707 .577 .707 r
F P
0 g
s
.70195 .85514 m .70195 .87367 L .68936 .86579 L p .707 .577 .707 r
F P
0 g
s
.68936 .86579 m .68936 .84726 L .70195 .85514 L p .707 .577 .707 r
F P
0 g
s
.66831 .66485 m .66831 .7019 L .64085 .69751 L p .707 .577 .707 r
F P
0 g
s
.64085 .69751 m .64085 .66045 L .66831 .66485 L p .707 .577 .707 r
F P
0 g
s
.17343 .67669 m .17343 .73228 L .19449 .73873 L p .707 .577 .707 r
F P
0 g
s
.66831 .67784 m .66831 .73342 L .64085 .72903 L p .707 .577 .707 r
F P
0 g
s
.64085 .72903 m .64085 .67344 L .66831 .67784 L p .707 .577 .707 r
F P
0 g
s
.17343 .70076 m .17343 .6637 L .16084 .65582 L p .707 .577 .707 r
F P
0 g
s
.63393 .28502 m .63393 .78691 L .64393 .7751 L p .707 .577 .707 r
F P
0 g
s
.64393 .7751 m .64393 .27321 L .63393 .28502 L p .707 .577 .707 r
F P
0 g
s
.25312 .87093 m .25312 .85241 L .22195 .85051 L p .707 .577 .707 r
F P
0 g
s
.25312 .85241 m .25312 .87093 L .28495 .87016 L p .707 .577 .707 r
F P
0 g
s
.28495 .87016 m .28495 .85163 L .25312 .85241 L p .707 .577 .707 r
F P
0 g
s
.17343 .73228 m .17343 .67669 L .16084 .66881 L p .707 .577 .707 r
F P
0 g
s
.50804 .87021 m .50804 .85169 L .5244 .84432 L p .707 .577 .707 r
F P
0 g
s
.28495 .85163 m .28495 .87016 L .31434 .86678 L p .707 .577 .707 r
F P
0 g
s
.31434 .86678 m .31434 .84825 L .28495 .85163 L p .707 .577 .707 r
F P
0 g
s
.22195 .85051 m .22195 .86903 L .25312 .87093 L p .707 .577 .707 r
F P
0 g
s
.22195 .86903 m .22195 .85051 L .19449 .84611 L p .707 .577 .707 r
F P
0 g
s
.16084 .65582 m .16084 .69287 L .17343 .70076 L p .707 .577 .707 r
F P
0 g
s
.5244 .84432 m .5244 .86284 L .50804 .87021 L p .707 .577 .707 r
F P
0 g
s
.19449 .84611 m .19449 .86464 L .22195 .86903 L p .707 .577 .707 r
F P
0 g
s
.35476 .65928 m .35476 .69633 L .36184 .68797 L p .707 .577 .707 r
F P
0 g
s
.36184 .68797 m .36184 .65091 L .35476 .65928 L p .707 .577 .707 r
F P
0 g
s
.31434 .84825 m .31434 .86678 L .33839 .86113 L p .707 .577 .707 r
F P
0 g
s
.33839 .86113 m .33839 .8426 L .31434 .84825 L p .707 .577 .707 r
F P
0 g
s
.16084 .66881 m .16084 .72439 L .17343 .73228 L p .707 .577 .707 r
F P
0 g
s
.35476 .67227 m .35476 .72785 L .36184 .71948 L p .707 .577 .707 r
F P
0 g
s
.36184 .71948 m .36184 .6639 L .35476 .67227 L p .707 .577 .707 r
F P
0 g
s
.36184 .65091 m .36184 .68797 L .35894 .67942 L p .707 .577 .707 r
F P
0 g
s
.35894 .67942 m .35894 .64237 L .36184 .65091 L p .707 .577 .707 r
F P
0 g
s
.36184 .6639 m .36184 .71948 L .35894 .71094 L p .707 .577 .707 r
F P
0 g
s
.35894 .71094 m .35894 .65536 L .36184 .6639 L p .707 .577 .707 r
F P
0 g
s
.36016 .78203 m .36016 .28014 L .35607 .26808 L p .707 .577 .707 r
F P
0 g
s
.36016 .28014 m .36016 .78203 L .37794 .79316 L p .707 .577 .707 r
F P
0 g
s
.68936 .84726 m .68936 .86579 L .66831 .85933 L p .707 .577 .707 r
F P
0 g
s
.66831 .85933 m .66831 .8408 L .68936 .84726 L p .707 .577 .707 r
F P
0 g
s
.19449 .86464 m .19449 .84611 L .17343 .83966 L p .707 .577 .707 r
F P
0 g
s
.16084 .69287 m .16084 .65582 L .15794 .64728 L p .707 .577 .707 r
F P
0 g
s
.17343 .83966 m .17343 .85819 L .19449 .86464 L p .707 .577 .707 r
F P
0 g
s
.16084 .72439 m .16084 .66881 L .15794 .66027 L p .707 .577 .707 r
F P
0 g
s
.5244 .86284 m .5244 .84432 L .54846 .83867 L p .707 .577 .707 r
F P
0 g
s
.54846 .83867 m .54846 .8572 L .5244 .86284 L p .707 .577 .707 r
F P
0 g
s
.33839 .8426 m .33839 .86113 L .35476 .85376 L p .707 .577 .707 r
F P
0 g
s
.35476 .85376 m .35476 .83523 L .33839 .8426 L p .707 .577 .707 r
F P
0 g
s
.15794 .64728 m .15794 .68433 L .16084 .69287 L p .707 .577 .707 r
F P
0 g
s
.64393 .27321 m .64393 .7751 L .63984 .76304 L p .707 .577 .707 r
F P
0 g
s
.63984 .76304 m .63984 .26115 L .64393 .27321 L p .707 .577 .707 r
F P
0 g
s
.66831 .8408 m .66831 .85933 L .64085 .85494 L p .707 .577 .707 r
F P
0 g
s
.64085 .85494 m .64085 .83641 L .66831 .8408 L p .707 .577 .707 r
F P
0 g
s
.15794 .66027 m .15794 .71585 L .16084 .72439 L p .707 .577 .707 r
F P
0 g
s
.17343 .85819 m .17343 .83966 L .16084 .83178 L p .707 .577 .707 r
F P
0 g
s
.54846 .8572 m .54846 .83867 L .57784 .83529 L p .707 .577 .707 r
F P
0 g
s
.16084 .83178 m .16084 .8503 L .17343 .85819 L p .707 .577 .707 r
F P
0 g
s
.57784 .83529 m .57784 .85382 L .54846 .8572 L p .707 .577 .707 r
F P
0 g
s
.15794 .68433 m .15794 .64728 L .16503 .63891 L p .707 .577 .707 r
F P
0 g
s
.64085 .83641 m .64085 .85494 L .60968 .85304 L p .707 .577 .707 r
F P
0 g
s
.60968 .85304 m .60968 .83451 L .64085 .83641 L p .707 .577 .707 r
F P
0 g
s
.15794 .71585 m .15794 .66027 L .16503 .6519 L p .707 .577 .707 r
F P
0 g
s
.35894 .64237 m .35894 .67942 L .34635 .67154 L p .707 .577 .707 r
F P
0 g
s
.34635 .67154 m .34635 .63449 L .35894 .64237 L p .707 .577 .707 r
F P
0 g
s
.35894 .65536 m .35894 .71094 L .34635 .70306 L p .707 .577 .707 r
F P
0 g
s
.34635 .70306 m .34635 .64748 L .35894 .65536 L p .707 .577 .707 r
F P
0 g
s
.35607 .26808 m .35607 .76997 L .36016 .78203 L p .707 .577 .707 r
F P
0 g
s
.35607 .76997 m .35607 .26808 L .36607 .25627 L p .707 .577 .707 r
F P
0 g
s
.57784 .85382 m .57784 .83529 L .60968 .83451 L p .707 .577 .707 r
F P
0 g
s
.35476 .83523 m .35476 .85376 L .36184 .8454 L p .707 .577 .707 r
F P
0 g
s
.36184 .8454 m .36184 .82687 L .35476 .83523 L p .707 .577 .707 r
F P
0 g
s
.60968 .83451 m .60968 .85304 L .57784 .85382 L p .707 .577 .707 r
F P
0 g
s
.16503 .63891 m .16503 .67597 L .15794 .68433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .8503 m .16084 .83178 L .15794 .82323 L p .707 .577 .707 r
F P
0 g
s
.16503 .6519 m .16503 .70748 L .15794 .71585 L p .707 .577 .707 r
F P
0 g
s
.15794 .82323 m .15794 .84176 L .16084 .8503 L p .707 .577 .707 r
F P
0 g
s
.63984 .26115 m .63984 .76304 L .62206 .75191 L p .707 .577 .707 r
F P
0 g
s
.62206 .75191 m .62206 .25002 L .63984 .26115 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .67597 m .16503 .63891 L .1814 .63154 L p .707 .577 .707 r
F P
0 g
s
.16503 .70748 m .16503 .6519 L .1814 .64453 L p .707 .577 .707 r
F P
0 g
s
.36184 .82687 m .36184 .8454 L .35894 .83685 L p .707 .577 .707 r
F P
0 g
s
.35894 .83685 m .35894 .81833 L .36184 .82687 L p .707 .577 .707 r
F P
0 g
s
.1814 .63154 m .1814 .6686 L .16503 .67597 L p .707 .577 .707 r
F P
0 g
s
.34635 .63449 m .34635 .67154 L .3253 .66509 L p .707 .577 .707 r
F P
0 g
s
.3253 .66509 m .3253 .62803 L .34635 .63449 L p .707 .577 .707 r
F P
0 g
s
.36607 .75816 m .36607 .25627 L .38918 .24587 L p .707 .577 .707 r
F P
0 g
s
.36607 .25627 m .36607 .75816 L .35607 .76997 L p .707 .577 .707 r
F P
0 g
s
.15794 .84176 m .15794 .82323 L .16503 .81487 L p .707 .577 .707 r
F P
0 g
s
.1814 .64453 m .1814 .70012 L .16503 .70748 L p .707 .577 .707 r
F P
0 g
s
.34635 .64748 m .34635 .70306 L .3253 .6966 L p .707 .577 .707 r
F P
0 g
s
.3253 .6966 m .3253 .64102 L .34635 .64748 L p .707 .577 .707 r
F P
0 g
s
.16503 .81487 m .16503 .8334 L .15794 .84176 L p .707 .577 .707 r
F P
0 g
s
.1814 .6686 m .1814 .63154 L .20545 .62589 L p .707 .577 .707 r
F P
0 g
s
.1814 .70012 m .1814 .64453 L .20545 .63888 L p .707 .577 .707 r
F P
0 g
s
.35894 .81833 m .35894 .83685 L .34635 .82897 L p .707 .577 .707 r
F P
0 g
s
.34635 .82897 m .34635 .81044 L .35894 .81833 L p .707 .577 .707 r
F P
0 g
s
.20545 .62589 m .20545 .66295 L .1814 .6686 L p .707 .577 .707 r
F P
0 g
s
.62206 .25002 m .62206 .75191 L .59233 .7428 L p .707 .577 .707 r
F P
0 g
s
.59233 .7428 m .59233 .24091 L .62206 .25002 L p .707 .577 .707 r
F P
0 g
s
.3253 .62803 m .3253 .66509 L .29784 .66069 L p .707 .577 .707 r
F P
0 g
s
.29784 .66069 m .29784 .62364 L .3253 .62803 L p .707 .577 .707 r
F P
0 g
s
.3253 .64102 m .3253 .6966 L .29784 .69221 L p .707 .577 .707 r
F P
0 g
s
.29784 .69221 m .29784 .63663 L .3253 .64102 L p .707 .577 .707 r
F P
0 g
s
.20545 .63888 m .20545 .69447 L .1814 .70012 L p .707 .577 .707 r
F P
0 g
s
.20545 .66295 m .20545 .62589 L .23483 .62252 L p .707 .577 .707 r
F P
0 g
s
.16503 .8334 m .16503 .81487 L .1814 .8075 L p .707 .577 .707 r
F P
0 g
s
.20545 .69447 m .20545 .63888 L .23483 .63551 L p .707 .577 .707 r
F P
0 g
s
.38918 .24587 m .38918 .74776 L .36607 .75816 L p .707 .577 .707 r
F P
0 g
s
.38918 .74776 m .38918 .24587 L .42314 .23789 L p .707 .577 .707 r
F P
0 g
s
.1814 .8075 m .1814 .82603 L .16503 .8334 L p .707 .577 .707 r
F P
0 g
s
.29784 .62364 m .29784 .66069 L .26667 .65879 L p .707 .577 .707 r
F P
0 g
s
.26667 .65879 m .26667 .62174 L .29784 .62364 L p .707 .577 .707 r
F P
0 g
s
.23483 .62252 m .23483 .65957 L .20545 .66295 L p .707 .577 .707 r
F P
0 g
s
.29784 .63663 m .29784 .69221 L .26667 .69031 L p .707 .577 .707 r
F P
0 g
s
.26667 .69031 m .26667 .63473 L .29784 .63663 L p .707 .577 .707 r
F P
0 g
s
.23483 .65957 m .23483 .62252 L .26667 .62174 L p .707 .577 .707 r
F P
0 g
s
.26667 .62174 m .26667 .65879 L .23483 .65957 L p .707 .577 .707 r
F P
0 g
s
.23483 .69109 m .23483 .63551 L .26667 .63473 L p .707 .577 .707 r
F P
0 g
s
.23483 .63551 m .23483 .69109 L .20545 .69447 L p .707 .577 .707 r
F P
0 g
s
.73333 .65828 m .73333 .62123 L .70216 .61933 L p .707 .577 .707 r
F P
0 g
s
.73333 .62123 m .73333 .65828 L .76517 .6575 L p .707 .577 .707 r
F P
0 g
s
.76517 .6575 m .76517 .62045 L .73333 .62123 L p .707 .577 .707 r
F P
0 g
s
.34635 .81044 m .34635 .82897 L .3253 .82252 L p .707 .577 .707 r
F P
0 g
s
.3253 .82252 m .3253 .80399 L .34635 .81044 L p .707 .577 .707 r
F P
0 g
s
.26667 .63473 m .26667 .69031 L .23483 .69109 L p .707 .577 .707 r
F P
0 g
s
.76517 .62045 m .76517 .6575 L .79455 .65413 L p .707 .577 .707 r
F P
0 g
s
.79455 .65413 m .79455 .61707 L .76517 .62045 L p .707 .577 .707 r
F P
0 g
s
.73333 .6898 m .73333 .63422 L .70216 .63232 L p .707 .577 .707 r
F P
0 g
s
.73333 .63422 m .73333 .6898 L .76517 .68902 L p .707 .577 .707 r
F P
0 g
s
.76517 .68902 m .76517 .63344 L .73333 .63422 L p .707 .577 .707 r
F P
0 g
s
.76517 .63344 m .76517 .68902 L .79455 .68564 L p .707 .577 .707 r
F P
0 g
s
.79455 .68564 m .79455 .63006 L .76517 .63344 L p .707 .577 .707 r
F P
0 g
s
.70216 .65638 m .70216 .61933 L .6747 .61493 L p .707 .577 .707 r
F P
0 g
s
.70216 .61933 m .70216 .65638 L .73333 .65828 L p .707 .577 .707 r
F P
0 g
s
.59233 .24091 m .59233 .7428 L .55357 .7366 L p .707 .577 .707 r
F P
0 g
s
.55357 .7366 m .55357 .23471 L .59233 .24091 L p .707 .577 .707 r
F P
0 g
s
.70216 .6879 m .70216 .63232 L .6747 .62792 L p .707 .577 .707 r
F P
0 g
s
.70216 .63232 m .70216 .6879 L .73333 .6898 L p .707 .577 .707 r
F P
0 g
s
.1814 .82603 m .1814 .8075 L .20545 .80185 L p .707 .577 .707 r
F P
0 g
s
.79455 .61707 m .79455 .65413 L .8186 .64848 L p .707 .577 .707 r
F P
0 g
s
.8186 .64848 m .8186 .61142 L .79455 .61707 L p .707 .577 .707 r
F P
0 g
s
.20545 .80185 m .20545 .82038 L .1814 .82603 L p .707 .577 .707 r
F P
0 g
s
.6747 .61493 m .6747 .65199 L .70216 .65638 L p .707 .577 .707 r
F P
0 g
s
.79455 .63006 m .79455 .68564 L .8186 .67999 L p .707 .577 .707 r
F P
0 g
s
.8186 .67999 m .8186 .62441 L .79455 .63006 L p .707 .577 .707 r
F P
0 g
s
.42314 .73978 m .42314 .23789 L .46462 .23312 L p .707 .577 .707 r
F P
0 g
s
.42314 .23789 m .42314 .73978 L .38918 .74776 L p .707 .577 .707 r
F P
0 g
s
.6747 .65199 m .6747 .61493 L .65365 .60848 L p .707 .577 .707 r
F P
0 g
s
.3253 .80399 m .3253 .82252 L .29784 .81812 L p .707 .577 .707 r
F P
0 g
s
.29784 .81812 m .29784 .7996 L .3253 .80399 L p .707 .577 .707 r
F P
0 g
s
.6747 .62792 m .6747 .68351 L .70216 .6879 L p .707 .577 .707 r
F P
0 g
s
.6747 .68351 m .6747 .62792 L .65365 .62147 L p .707 .577 .707 r
F P
0 g
s
.55357 .23471 m .55357 .7366 L .50956 .73392 L p .707 .577 .707 r
F P
0 g
s
.50956 .73392 m .50956 .23203 L .55357 .23471 L p .707 .577 .707 r
F P
0 g
s
.20545 .82038 m .20545 .80185 L .23483 .79847 L p .707 .577 .707 r
F P
0 g
s
.65365 .60848 m .65365 .64553 L .6747 .65199 L p .707 .577 .707 r
F P
0 g
s
.8186 .61142 m .8186 .64848 L .83497 .64111 L p .707 .577 .707 r
F P
0 g
s
.83497 .64111 m .83497 .60405 L .8186 .61142 L p .707 .577 .707 r
F P
0 g
s
.46462 .73501 m .46462 .23312 L .50956 .23203 L p .707 .577 .707 r
F P
0 g
s
.46462 .23312 m .46462 .73501 L .42314 .73978 L p .707 .577 .707 r
F P
0 g
s
.23483 .79847 m .23483 .817 L .20545 .82038 L p .707 .577 .707 r
F P
0 g
s
.8186 .62441 m .8186 .67999 L .83497 .67263 L p .707 .577 .707 r
F P
0 g
s
.83497 .67263 m .83497 .61704 L .8186 .62441 L p .707 .577 .707 r
F P
0 g
s
.50956 .23203 m .50956 .73392 L .46462 .73501 L p .707 .577 .707 r
F P
0 g
s
.29784 .7996 m .29784 .81812 L .26667 .81622 L p .707 .577 .707 r
F P
0 g
s
.26667 .81622 m .26667 .7977 L .29784 .7996 L p .707 .577 .707 r
F P
0 g
s
.65365 .62147 m .65365 .67705 L .6747 .68351 L p .707 .577 .707 r
F P
0 g
s
.23483 .817 m .23483 .79847 L .26667 .7977 L p .707 .577 .707 r
F P
0 g
s
.65365 .64553 m .65365 .60848 L .64105 .6006 L p .707 .577 .707 r
F P
0 g
s
.26667 .7977 m .26667 .81622 L .23483 .817 L p .707 .577 .707 r
F P
0 g
s
.73333 .81571 m .73333 .79718 L .70216 .79528 L p .707 .577 .707 r
F P
0 g
s
.73333 .79718 m .73333 .81571 L .76517 .81493 L p .707 .577 .707 r
F P
0 g
s
.76517 .81493 m .76517 .79641 L .73333 .79718 L p .707 .577 .707 r
F P
0 g
s
.65365 .67705 m .65365 .62147 L .64105 .61359 L p .707 .577 .707 r
F P
0 g
s
.76517 .79641 m .76517 .81493 L .79455 .81156 L p .707 .577 .707 r
F P
0 g
s
.79455 .81156 m .79455 .79303 L .76517 .79641 L p .707 .577 .707 r
F P
0 g
s
.70216 .79528 m .70216 .81381 L .73333 .81571 L p .707 .577 .707 r
F P
0 g
s
.70216 .81381 m .70216 .79528 L .6747 .79089 L p .707 .577 .707 r
F P
0 g
s
.64105 .6006 m .64105 .63765 L .65365 .64553 L p .707 .577 .707 r
F P
0 g
s
.6747 .79089 m .6747 .80942 L .70216 .81381 L p .707 .577 .707 r
F P
0 g
s
.83497 .60405 m .83497 .64111 L .84205 .63274 L p .707 .577 .707 r
F P
0 g
s
.84205 .63274 m .84205 .59569 L .83497 .60405 L p .707 .577 .707 r
F P
0 g
s
.79455 .79303 m .79455 .81156 L .8186 .80591 L p .707 .577 .707 r
F P
0 g
s
.8186 .80591 m .8186 .78738 L .79455 .79303 L p .707 .577 .707 r
F P
0 g
s
.64105 .61359 m .64105 .66917 L .65365 .67705 L p .707 .577 .707 r
F P
0 g
s
.83497 .61704 m .83497 .67263 L .84205 .66426 L p .707 .577 .707 r
F P
0 g
s
.84205 .66426 m .84205 .60868 L .83497 .61704 L p .707 .577 .707 r
F P
0 g
s
.6747 .80942 m .6747 .79089 L .65365 .78444 L p .707 .577 .707 r
F P
0 g
s
.64105 .63765 m .64105 .6006 L .63816 .59205 L p .707 .577 .707 r
F P
0 g
s
.65365 .78444 m .65365 .80297 L .6747 .80942 L p .707 .577 .707 r
F P
0 g
s
.64105 .66917 m .64105 .61359 L .63816 .60504 L p .707 .577 .707 r
F P
0 g
s
.8186 .78738 m .8186 .80591 L .83497 .79854 L p .707 .577 .707 r
F P
0 g
s
.83497 .79854 m .83497 .78001 L .8186 .78738 L p .707 .577 .707 r
F P
0 g
s
.63816 .59205 m .63816 .62911 L .64105 .63765 L p .707 .577 .707 r
F P
0 g
s
.84205 .59569 m .84205 .63274 L .83916 .6242 L p .707 .577 .707 r
F P
0 g
s
.83916 .6242 m .83916 .58715 L .84205 .59569 L p .707 .577 .707 r
F P
0 g
s
.63816 .60504 m .63816 .66063 L .64105 .66917 L p .707 .577 .707 r
F P
0 g
s
.65365 .80297 m .65365 .78444 L .64105 .77655 L p .707 .577 .707 r
F P
0 g
s
.84205 .60868 m .84205 .66426 L .83916 .65572 L p .707 .577 .707 r
F P
0 g
s
.83916 .65572 m .83916 .60014 L .84205 .60868 L p .707 .577 .707 r
F P
0 g
s
.64105 .77655 m .64105 .79508 L .65365 .80297 L p .707 .577 .707 r
F P
0 g
s
.63816 .62911 m .63816 .59205 L .64524 .58369 L p .707 .577 .707 r
F P
0 g
s
.63816 .66063 m .63816 .60504 L .64524 .59668 L p .707 .577 .707 r
F P
0 g
s
.83497 .78001 m .83497 .79854 L .84206 .79017 L p .707 .577 .707 r
F P
0 g
s
.84206 .79017 m .84206 .77165 L .83497 .78001 L p .707 .577 .707 r
F P
0 g
s
.64524 .58369 m .64524 .62074 L .63816 .62911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83916 .58715 m .83916 .6242 L .82657 .61632 L p .707 .577 .707 r
F P
0 g
s
.82657 .61632 m .82657 .57926 L .83916 .58715 L p .707 .577 .707 r
F P
0 g
s
.64105 .79508 m .64105 .77655 L .63816 .76801 L p .707 .577 .707 r
F P
0 g
s
.64524 .59668 m .64524 .65226 L .63816 .66063 L p .707 .577 .707 r
F P
0 g
s
.83916 .60014 m .83916 .65572 L .82657 .64783 L p .707 .577 .707 r
F P
0 g
s
.82657 .64783 m .82657 .59225 L .83916 .60014 L p .707 .577 .707 r
F P
0 g
s
.63816 .76801 m .63816 .78654 L .64105 .79508 L p .707 .577 .707 r
F P
0 g
s
.39032 .62147 m .39032 .58441 L .35915 .58251 L p .707 .577 .707 r
F P
0 g
s
.39032 .58441 m .39032 .62147 L .42216 .62069 L p .707 .577 .707 r
F P
0 g
s
.42216 .62069 m .42216 .58363 L .39032 .58441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .62074 m .64524 .58369 L .66161 .57632 L p .707 .577 .707 r
F P
0 g
s
.42216 .58363 m .42216 .62069 L .45154 .61731 L p .707 .577 .707 r
F P
0 g
s
.45154 .61731 m .45154 .58025 L .42216 .58363 L p .707 .577 .707 r
F P
0 g
s
.39032 .65298 m .39032 .5974 L .35915 .5955 L p .707 .577 .707 r
F P
0 g
s
.39032 .5974 m .39032 .65298 L .42216 .65221 L p .707 .577 .707 r
F P
0 g
s
.42216 .65221 m .42216 .59662 L .39032 .5974 L p .707 .577 .707 r
F P
0 g
s
.64524 .65226 m .64524 .59668 L .66161 .58931 L p .707 .577 .707 r
F P
0 g
s
.42216 .59662 m .42216 .65221 L .45154 .64883 L p .707 .577 .707 r
F P
0 g
s
.45154 .64883 m .45154 .59325 L .42216 .59662 L p .707 .577 .707 r
F P
0 g
s
.35915 .61957 m .35915 .58251 L .33169 .57812 L p .707 .577 .707 r
F P
0 g
s
.35915 .58251 m .35915 .61957 L .39032 .62147 L p .707 .577 .707 r
F P
0 g
s
.84206 .77165 m .84206 .79017 L .83916 .78163 L p .707 .577 .707 r
F P
0 g
s
.83916 .78163 m .83916 .7631 L .84206 .77165 L p .707 .577 .707 r
F P
0 g
s
.35915 .65108 m .35915 .5955 L .33169 .59111 L p .707 .577 .707 r
F P
0 g
s
.35915 .5955 m .35915 .65108 L .39032 .65298 L p .707 .577 .707 r
F P
0 g
s
.66161 .57632 m .66161 .61338 L .64524 .62074 L p .707 .577 .707 r
F P
0 g
s
.45154 .58025 m .45154 .61731 L .47559 .61166 L p .707 .577 .707 r
F P
0 g
s
.47559 .61166 m .47559 .5746 L .45154 .58025 L p .707 .577 .707 r
F P
0 g
s
.33169 .57812 m .33169 .61517 L .35915 .61957 L p .707 .577 .707 r
F P
0 g
s
.82657 .57926 m .82657 .61632 L .80551 .60986 L p .707 .577 .707 r
F P
0 g
s
.80551 .60986 m .80551 .57281 L .82657 .57926 L p .707 .577 .707 r
F P
0 g
s
.45154 .59325 m .45154 .64883 L .47559 .64318 L p .707 .577 .707 r
F P
0 g
s
.47559 .64318 m .47559 .5876 L .45154 .59325 L p .707 .577 .707 r
F P
0 g
s
.63816 .78654 m .63816 .76801 L .64524 .75965 L p .707 .577 .707 r
F P
0 g
s
.66161 .58931 m .66161 .64489 L .64524 .65226 L p .707 .577 .707 r
F P
0 g
s
.82657 .59225 m .82657 .64783 L .80551 .64138 L p .707 .577 .707 r
F P
0 g
s
.80551 .64138 m .80551 .5858 L .82657 .59225 L p .707 .577 .707 r
F P
0 g
s
.33169 .61517 m .33169 .57812 L .31064 .57166 L p .707 .577 .707 r
F P
0 g
s
.33169 .59111 m .33169 .64669 L .35915 .65108 L p .707 .577 .707 r
F P
0 g
s
.33169 .64669 m .33169 .59111 L .31064 .58465 L p .707 .577 .707 r
F P
0 g
s
.64524 .75965 m .64524 .77817 L .63816 .78654 L p .707 .577 .707 r
F P
0 g
s
.66161 .61338 m .66161 .57632 L .68566 .57067 L p .707 .577 .707 r
F P
0 g
s
.66161 .64489 m .66161 .58931 L .68566 .58366 L p .707 .577 .707 r
F P
0 g
s
.31064 .57166 m .31064 .60872 L .33169 .61517 L p .707 .577 .707 r
F P
0 g
s
.47559 .5746 m .47559 .61166 L .49196 .60429 L p .707 .577 .707 r
F P
0 g
s
.49196 .60429 m .49196 .56724 L .47559 .5746 L p .707 .577 .707 r
F P
0 g
s
.47559 .5876 m .47559 .64318 L .49196 .63581 L p .707 .577 .707 r
F P
0 g
s
.49196 .63581 m .49196 .58023 L .47559 .5876 L p .707 .577 .707 r
F P
0 g
s
.83916 .7631 m .83916 .78163 L .82657 .77375 L p .707 .577 .707 r
F P
0 g
s
.82657 .77375 m .82657 .75522 L .83916 .7631 L p .707 .577 .707 r
F P
0 g
s
.68566 .57067 m .68566 .60773 L .66161 .61338 L p .707 .577 .707 r
F P
0 g
s
.80551 .57281 m .80551 .60986 L .77805 .60547 L p .707 .577 .707 r
F P
0 g
s
.77805 .60547 m .77805 .56842 L .80551 .57281 L p .707 .577 .707 r
F P
0 g
s
.31064 .58465 m .31064 .64024 L .33169 .64669 L p .707 .577 .707 r
F P
0 g
s
.80551 .5858 m .80551 .64138 L .77805 .63699 L p .707 .577 .707 r
F P
0 g
s
.77805 .63699 m .77805 .58141 L .80551 .5858 L p .707 .577 .707 r
F P
0 g
s
.31064 .60872 m .31064 .57166 L .29804 .56378 L p .707 .577 .707 r
F P
0 g
s
.68566 .58366 m .68566 .63924 L .66161 .64489 L p .707 .577 .707 r
F P
0 g
s
.39032 .7789 m .39032 .76037 L .35915 .75847 L p .707 .577 .707 r
F P
0 g
s
.39032 .76037 m .39032 .7789 L .42216 .77812 L p .707 .577 .707 r
F P
0 g
s
.42216 .77812 m .42216 .75959 L .39032 .76037 L p .707 .577 .707 r
F P
0 g
s
.68566 .60773 m .68566 .57067 L .71504 .56729 L p .707 .577 .707 r
F P
0 g
s
.31064 .64024 m .31064 .58465 L .29804 .57677 L p .707 .577 .707 r
F P
0 g
s
.64524 .77817 m .64524 .75965 L .66161 .75228 L p .707 .577 .707 r
F P
0 g
s
.42216 .75959 m .42216 .77812 L .45154 .77474 L p .707 .577 .707 r
F P
0 g
s
.45154 .77474 m .45154 .75621 L .42216 .75959 L p .707 .577 .707 r
F P
0 g
s
.68566 .63924 m .68566 .58366 L .71504 .58028 L p .707 .577 .707 r
F P
0 g
s
.35915 .75847 m .35915 .777 L .39032 .7789 L p .707 .577 .707 r
F P
0 g
s
.35915 .777 m .35915 .75847 L .33169 .75408 L p .707 .577 .707 r
F P
0 g
s
.29804 .56378 m .29804 .60083 L .31064 .60872 L p .707 .577 .707 r
F P
0 g
s
.66161 .75228 m .66161 .77081 L .64524 .77817 L p .707 .577 .707 r
F P
0 g
s
.77805 .56842 m .77805 .60547 L .74688 .60357 L p .707 .577 .707 r
F P
0 g
s
.74688 .60357 m .74688 .56651 L .77805 .56842 L p .707 .577 .707 r
F P
0 g
s
.71504 .56729 m .71504 .60435 L .68566 .60773 L p .707 .577 .707 r
F P
0 g
s
.33169 .75408 m .33169 .7726 L .35915 .777 L p .707 .577 .707 r
F P
0 g
s
.77805 .58141 m .77805 .63699 L .74688 .63509 L p .707 .577 .707 r
F P
0 g
s
.74688 .63509 m .74688 .57951 L .77805 .58141 L p .707 .577 .707 r
F P
0 g
s
.71504 .60435 m .71504 .56729 L .74688 .56651 L p .707 .577 .707 r
F P
0 g
s
.49196 .56724 m .49196 .60429 L .49904 .59593 L p .707 .577 .707 r
F P
0 g
s
.49904 .59593 m .49904 .55887 L .49196 .56724 L p .707 .577 .707 r
F P
0 g
s
.45154 .75621 m .45154 .77474 L .47559 .76909 L p .707 .577 .707 r
F P
0 g
s
.47559 .76909 m .47559 .75056 L .45154 .75621 L p .707 .577 .707 r
F P
0 g
s
.74688 .56651 m .74688 .60357 L .71504 .60435 L p .707 .577 .707 r
F P
0 g
s
.29804 .57677 m .29804 .63235 L .31064 .64024 L p .707 .577 .707 r
F P
0 g
s
.71504 .63587 m .71504 .58028 L .74688 .57951 L p .707 .577 .707 r
F P
0 g
s
.71504 .58028 m .71504 .63587 L .68566 .63924 L p .707 .577 .707 r
F P
0 g
s
.49196 .58023 m .49196 .63581 L .49904 .62745 L p .707 .577 .707 r
F P
0 g
s
.49904 .62745 m .49904 .57186 L .49196 .58023 L p .707 .577 .707 r
F P
0 g
s
.82657 .75522 m .82657 .77375 L .80551 .76729 L p .707 .577 .707 r
F P
0 g
s
.80551 .76729 m .80551 .74877 L .82657 .75522 L p .707 .577 .707 r
F P
0 g
s
.74688 .57951 m .74688 .63509 L .71504 .63587 L p .707 .577 .707 r
F P
0 g
s
.33169 .7726 m .33169 .75408 L .31064 .74762 L p .707 .577 .707 r
F P
0 g
s
.29804 .60083 m .29804 .56378 L .29515 .55524 L p .707 .577 .707 r
F P
0 g
s
.31064 .74762 m .31064 .76615 L .33169 .7726 L p .707 .577 .707 r
F P
0 g
s
.29804 .63235 m .29804 .57677 L .29515 .56823 L p .707 .577 .707 r
F P
0 g
s
.66161 .77081 m .66161 .75228 L .68566 .74663 L p .707 .577 .707 r
F P
0 g
s
.68566 .74663 m .68566 .76516 L .66161 .77081 L p .707 .577 .707 r
F P
0 g
s
.47559 .75056 m .47559 .76909 L .49196 .76172 L p .707 .577 .707 r
F P
0 g
s
.49196 .76172 m .49196 .7432 L .47559 .75056 L p .707 .577 .707 r
F P
0 g
s
.29515 .55524 m .29515 .59229 L .29804 .60083 L p .707 .577 .707 r
F P
0 g
s
.80551 .74877 m .80551 .76729 L .77805 .7629 L p .707 .577 .707 r
F P
0 g
s
.77805 .7629 m .77805 .74437 L .80551 .74877 L p .707 .577 .707 r
F P
0 g
s
.49904 .55887 m .49904 .59593 L .49615 .58739 L p .707 .577 .707 r
F P
0 g
s
.49615 .58739 m .49615 .55033 L .49904 .55887 L p .707 .577 .707 r
F P
0 g
s
.29515 .56823 m .29515 .62381 L .29804 .63235 L p .707 .577 .707 r
F P
0 g
s
.31064 .76615 m .31064 .74762 L .29804 .73974 L p .707 .577 .707 r
F P
0 g
s
.49904 .57186 m .49904 .62745 L .49615 .6189 L p .707 .577 .707 r
F P
0 g
s
.49615 .6189 m .49615 .56332 L .49904 .57186 L p .707 .577 .707 r
F P
0 g
s
.68566 .76516 m .68566 .74663 L .71504 .74325 L p .707 .577 .707 r
F P
0 g
s
.29804 .73974 m .29804 .75827 L .31064 .76615 L p .707 .577 .707 r
F P
0 g
s
.71504 .74325 m .71504 .76178 L .68566 .76516 L p .707 .577 .707 r
F P
0 g
s
.29515 .59229 m .29515 .55524 L .30223 .54687 L p .707 .577 .707 r
F P
0 g
s
.77805 .74437 m .77805 .7629 L .74688 .761 L p .707 .577 .707 r
F P
0 g
s
.74688 .761 m .74688 .74247 L .77805 .74437 L p .707 .577 .707 r
F P
0 g
s
.29515 .62381 m .29515 .56823 L .30223 .55986 L p .707 .577 .707 r
F P
0 g
s
.71504 .76178 m .71504 .74325 L .74688 .74247 L p .707 .577 .707 r
F P
0 g
s
.49196 .7432 m .49196 .76172 L .49904 .75336 L p .707 .577 .707 r
F P
0 g
s
.49904 .75336 m .49904 .73483 L .49196 .7432 L p .707 .577 .707 r
F P
0 g
s
.74688 .74247 m .74688 .761 L .71504 .76178 L p .707 .577 .707 r
F P
0 g
s
.30223 .54687 m .30223 .58393 L .29515 .59229 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49615 .55033 m .49615 .58739 L .48356 .5795 L p .707 .577 .707 r
F P
0 g
s
.48356 .5795 m .48356 .54245 L .49615 .55033 L p .707 .577 .707 r
F P
0 g
s
.29804 .75827 m .29804 .73974 L .29515 .7312 L p .707 .577 .707 r
F P
0 g
s
.30223 .55986 m .30223 .61545 L .29515 .62381 L p .707 .577 .707 r
F P
0 g
s
.49615 .56332 m .49615 .6189 L .48356 .61102 L p .707 .577 .707 r
F P
0 g
s
.48356 .61102 m .48356 .55544 L .49615 .56332 L p .707 .577 .707 r
F P
0 g
s
.29515 .7312 m .29515 .74972 L .29804 .75827 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .58393 m .30223 .54687 L .3186 .53951 L p .707 .577 .707 r
F P
0 g
s
.30223 .61545 m .30223 .55986 L .3186 .5525 L p .707 .577 .707 r
F P
0 g
s
.49904 .73483 m .49904 .75336 L .49615 .74482 L p .707 .577 .707 r
F P
0 g
s
.49615 .74482 m .49615 .72629 L .49904 .73483 L p .707 .577 .707 r
F P
0 g
s
.3186 .53951 m .3186 .57656 L .30223 .58393 L p .707 .577 .707 r
F P
0 g
s
.48356 .54245 m .48356 .5795 L .4625 .57305 L p .707 .577 .707 r
F P
0 g
s
.4625 .57305 m .4625 .53599 L .48356 .54245 L p .707 .577 .707 r
F P
0 g
s
.29515 .74972 m .29515 .7312 L .30223 .72283 L p .707 .577 .707 r
F P
0 g
s
.3186 .5525 m .3186 .60808 L .30223 .61545 L p .707 .577 .707 r
F P
0 g
s
.48356 .55544 m .48356 .61102 L .4625 .60457 L p .707 .577 .707 r
F P
0 g
s
.4625 .60457 m .4625 .54898 L .48356 .55544 L p .707 .577 .707 r
F P
0 g
s
.30223 .72283 m .30223 .74136 L .29515 .74972 L p .707 .577 .707 r
F P
0 g
s
.3186 .57656 m .3186 .53951 L .34265 .53386 L p .707 .577 .707 r
F P
0 g
s
.3186 .60808 m .3186 .5525 L .34265 .54685 L p .707 .577 .707 r
F P
0 g
s
.49615 .72629 m .49615 .74482 L .48356 .73693 L p .707 .577 .707 r
F P
0 g
s
.48356 .73693 m .48356 .71841 L .49615 .72629 L p .707 .577 .707 r
F P
0 g
s
.34265 .53386 m .34265 .57091 L .3186 .57656 L p .707 .577 .707 r
F P
0 g
s
.4625 .53599 m .4625 .57305 L .43504 .56865 L p .707 .577 .707 r
F P
0 g
s
.43504 .56865 m .43504 .5316 L .4625 .53599 L p .707 .577 .707 r
F P
0 g
s
.4625 .54898 m .4625 .60457 L .43504 .60017 L p .707 .577 .707 r
F P
0 g
s
.43504 .60017 m .43504 .54459 L .4625 .54898 L p .707 .577 .707 r
F P
0 g
s
.34265 .54685 m .34265 .60243 L .3186 .60808 L p .707 .577 .707 r
F P
0 g
s
.34265 .57091 m .34265 .53386 L .37203 .53048 L p .707 .577 .707 r
F P
0 g
s
.30223 .74136 m .30223 .72283 L .3186 .71546 L p .707 .577 .707 r
F P
0 g
s
.34265 .60243 m .34265 .54685 L .37203 .54347 L p .707 .577 .707 r
F P
0 g
s
.3186 .71546 m .3186 .73399 L .30223 .74136 L p .707 .577 .707 r
F P
0 g
s
.43504 .5316 m .43504 .56865 L .40387 .56675 L p .707 .577 .707 r
F P
0 g
s
.40387 .56675 m .40387 .5297 L .43504 .5316 L p .707 .577 .707 r
F P
0 g
s
.37203 .53048 m .37203 .56753 L .34265 .57091 L p .707 .577 .707 r
F P
0 g
s
.43504 .54459 m .43504 .60017 L .40387 .59827 L p .707 .577 .707 r
F P
0 g
s
.40387 .59827 m .40387 .54269 L .43504 .54459 L p .707 .577 .707 r
F P
0 g
s
.37203 .56753 m .37203 .53048 L .40387 .5297 L p .707 .577 .707 r
F P
0 g
s
.40387 .5297 m .40387 .56675 L .37203 .56753 L p .707 .577 .707 r
F P
0 g
s
.37203 .59905 m .37203 .54347 L .40387 .54269 L p .707 .577 .707 r
F P
0 g
s
.37203 .54347 m .37203 .59905 L .34265 .60243 L p .707 .577 .707 r
F P
0 g
s
.48356 .71841 m .48356 .73693 L .4625 .73048 L p .707 .577 .707 r
F P
0 g
s
.4625 .73048 m .4625 .71195 L .48356 .71841 L p .707 .577 .707 r
F P
0 g
s
.40387 .54269 m .40387 .59827 L .37203 .59905 L p .707 .577 .707 r
F P
0 g
s
.3186 .73399 m .3186 .71546 L .34265 .70981 L p .707 .577 .707 r
F P
0 g
s
.34265 .70981 m .34265 .72834 L .3186 .73399 L p .707 .577 .707 r
F P
0 g
s
.4625 .71195 m .4625 .73048 L .43504 .72609 L p .707 .577 .707 r
F P
0 g
s
.43504 .72609 m .43504 .70756 L .4625 .71195 L p .707 .577 .707 r
F P
0 g
s
.34265 .72834 m .34265 .70981 L .37203 .70644 L p .707 .577 .707 r
F P
0 g
s
.37203 .70644 m .37203 .72496 L .34265 .72834 L p .707 .577 .707 r
F P
0 g
s
.43504 .70756 m .43504 .72609 L .40387 .72419 L p .707 .577 .707 r
F P
0 g
s
.40387 .72419 m .40387 .70566 L .43504 .70756 L p .707 .577 .707 r
F P
0 g
s
.37203 .72496 m .37203 .70644 L .40387 .70566 L p .707 .577 .707 r
F P
0 g
s
.40387 .70566 m .40387 .72419 L .37203 .72496 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001fOol90005FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJ
EP<006ioo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00IWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eooa80
0003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF
20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF
009JEP03001JEUYF01@000IJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001DOol20004FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH000000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001C
Ool00`00FUH00004FUH01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH00002000dOol005=oo`03001JEP00009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool3
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000bOol005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00
FUIJEP03FUH60003FUH50004FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH3000`Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF008002io
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP03001oogoo
02aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20003FUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP000000;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00
;Goo001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH00008FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0004FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH00eYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH000030002FUH40007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004Moo`T000=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h0
00AJEP03001JEUYF009JEPD000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0031oo`800003FUH005YF00EJ
EP03001JEUYF009JEP03001JEUYF00h000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00UYF1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF009JEP8002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000EJEP00001JEP0000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP8002eoo`00
;7oo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEQ/000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
000002eoo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH50003FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP04
001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool0
02aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH3
00000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF2@0015YF00<005YF
FUH00UYF2@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH00eYF00<005YFFUH00`000goo2@00B7oo000/Ool00`00FUH00004FUH00`00
FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001D
Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01000FUH0
05YF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUH005YF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002aoo`06001JEP00001JEP0015YF0P001eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF1P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0027oo0`00BGoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P001goo1@00B7oo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF
FUH20007Ool50018Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005
FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008FUH80004FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P001goo1@00B7oo000_Ool3
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF00@005YFFUIJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`00BGoo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF00000eYF1@000UYF0`000Woo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEPX000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH2001DOol0
03=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP@000IJEP06001JEP00FUH005YF0`000eYF1000
17oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP/000=JEP03001JEUYF00MJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP<00003FUH0
05YF009JEP8005Aoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001JEPP0
00Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH9000;FUH200000eYF001JEP09FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH30003
FUH2001DOol003]ooa`000ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH3
000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000H000lOol005=oo`80009JEP<000]oo`04001JEUYF
0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH300000eYF001JEP09FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH70004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol20003FUH00`00FUH0
00020008Ool01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YF00002UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00000UYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo001COol20003FUH00`00FUIJEP02FUH50003Ool01@00FUIJEP00FUH00P001eYF00<0
05YFFUH025YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005Aoo`05001J
EUYFFUH00005FUH01000FUIJEUYF200000=JEP00FUH01UYF3`001EYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00004FUH000000002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH3000`Ool005Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF60001EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001GOol30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP02FUH6000HOol400000eYF001J
EP04FUH01@00FUIJEUYF0000;Woo001JOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUH0000300000eYF0000000N
Ool30004FUH01000FUIJEUYF0P00;Goo0018Ool3000BOol50004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH30002FUH3000SOol300000eYF001JEP02
FUH2000]Ool004Moo`D001Ioo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00800003
FUH00000008002Uoo`8000=JEP8002eoo`00Agoo1@006Woo00@005YFFUIJEQ<00003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<002moo`800003FUH0000002eoo`00Agoo1@006Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0000=JEP00Ool0<7oo0P0000AJEP00000002eoo`00B7oo0`0077oo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF10000UYF0`00:goo0`000eYF0`00;Goo001YOol30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000
FUIJEUYF0P000Woo0P000UYF00<005YFFUH01@008Woo100000=JEP00FUH00eYF00<005YF0000;Goo
001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH000001Goo00@005YFFUH000EJEP03001JEP0000<001Uoo`D000EJEP03
001JEUYF009JEP8002ioo`00Agoo2@007Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001goo00@005YFFUH000EJEP03001JEUYF
00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00?goo200015YF00<005YFFUH0
0UYF20005goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01@0037oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPH001Aoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00IJEPD001=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008001Qoo``000IJEP03001J
EUYF00YJEP03001JEUYF00H001Yoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80029ooaH000mo
o`<0015oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`00A7oo1@005Goo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020012Ool5001_Ool002eoo`8000AJ
EP04001JEUYFFUH8000IOol60004FUH01@00FUIJEUYF0000@Woo1@00Kgoo000/Ool00`00FUH00003
FUH5000WOol300000eYF001JEP02FUH00`00Oomoo`11Ool3001`Ool002aoo`04001JEP00FUH2000_
Ool20003FUH00`00Oomoo`2dOol002aoo`04001JEP00000cOol200000eYF001oo`2eOol002aoo`@0
03Aoo`<003UooaP006Eoo`00;7oo0P000UYF0`00;goo0`0000=JEP00Ool0<Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`00HGoo000/Ool20003FUH00`00FUH00002000YOol3
0002FUH00`00FUH0000`Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4001MOol002aoo`8000=JEP03001JEUYF009JEPD0021oo`@00003FUH005YF009JEP03
001JEP0002eoo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000COol50005
FUH01000FUIJEUYF0P00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00F7oo000^Ool01000FUIJEP001EYF00<0
05YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH0
0000EWoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;7oo00<005YF000015YF00<0
05YF00000P0087oo1@0015YF00D005YFFUIJEP0005Eoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`00:7oo0`0000=J
EP00FUH00UYF0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH5000cOol01000FUH005YF0P00;Woo0P000eYF0P00E7oo000mOolI000hOol01000FUH00000<Woo
0P0000=JEP000000E7oo002>Ool200000eYF001oo`0aOol5001DOol008ioo`80009JEP8002ioo`80
009JEP<005Aoo`00SWoo0P000UYF00<005YF00000P009goo100015YF00<005YF0000E7oo002?Ool0
1000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF
00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD005Yoo`00Ugoo1@0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002LOol90004FUH00`00FUIJ
EP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76948 m .59613 .7139 L .56496 .712 L p .707 .577 .707 r
F P
0 g
s
.59613 .7139 m .59613 .76948 L .62796 .76871 L p .707 .577 .707 r
F P
0 g
s
.62796 .76871 m .62796 .71312 L .59613 .7139 L p .707 .577 .707 r
F P
0 g
s
.62796 .71312 m .62796 .76871 L .65735 .76533 L p .707 .577 .707 r
F P
0 g
s
.65735 .76533 m .65734 .70975 L .62796 .71312 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .73601 L .56496 .73411 L p .707 .577 .707 r
F P
0 g
s
.59613 .73601 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .73601 L p .707 .577 .707 r
F P
0 g
s
.56496 .76758 m .56496 .712 L .5375 .70761 L p .707 .577 .707 r
F P
0 g
s
.56496 .712 m .56496 .76758 L .59613 .76948 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .73411 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .73411 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.65734 .70975 m .65735 .76533 L .6814 .75968 L p .707 .577 .707 r
F P
0 g
s
.6814 .75968 m .6814 .7041 L .65734 .70975 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76326 L p .707 .577 .707 r
F P
0 g
s
.6814 .76326 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.5375 .70761 m .5375 .76319 L .56496 .76758 L p .707 .577 .707 r
F P
0 g
s
.5375 .76319 m .5375 .70761 L .51644 .70116 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.6814 .7041 m .6814 .75968 L .69777 .75231 L p .707 .577 .707 r
F P
0 g
s
.69777 .75231 m .69777 .69673 L .6814 .7041 L p .707 .577 .707 r
F P
0 g
s
.51644 .70116 m .51644 .75674 L .5375 .76319 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76326 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.59613 .88634 m .59613 .86781 L .56496 .86591 L p .707 .577 .707 r
F P
0 g
s
.59613 .86781 m .59613 .88634 L .62796 .88556 L p .707 .577 .707 r
F P
0 g
s
.62796 .88556 m .62796 .86703 L .59613 .86781 L p .707 .577 .707 r
F P
0 g
s
.62796 .86703 m .62796 .88556 L .65735 .88218 L p .707 .577 .707 r
F P
0 g
s
.65735 .88218 m .65735 .86365 L .62796 .86703 L p .707 .577 .707 r
F P
0 g
s
.51644 .75674 m .51644 .70116 L .50385 .69327 L p .707 .577 .707 r
F P
0 g
s
.56496 .86591 m .56496 .88444 L .59613 .88634 L p .707 .577 .707 r
F P
0 g
s
.56496 .88444 m .56496 .86591 L .5375 .86152 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71538 L p .707 .577 .707 r
F P
0 g
s
.5375 .86152 m .5375 .88005 L .56496 .88444 L p .707 .577 .707 r
F P
0 g
s
.65735 .86365 m .65735 .88218 L .6814 .87653 L p .707 .577 .707 r
F P
0 g
s
.6814 .87653 m .6814 .858 L .65735 .86365 L p .707 .577 .707 r
F P
0 g
s
.50385 .69327 m .50385 .74885 L .51644 .75674 L p .707 .577 .707 r
F P
0 g
s
.69777 .69673 m .69777 .75231 L .70485 .74395 L p .707 .577 .707 r
F P
0 g
s
.70485 .74395 m .70485 .68836 L .69777 .69673 L p .707 .577 .707 r
F P
0 g
s
.50385 .71538 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.5375 .88005 m .5375 .86152 L .51644 .85506 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.51644 .85506 m .51644 .87359 L .5375 .88005 L p .707 .577 .707 r
F P
0 g
s
.50385 .74885 m .50385 .69327 L .50095 .68473 L p .707 .577 .707 r
F P
0 g
s
.6814 .858 m .6814 .87653 L .69777 .86916 L p .707 .577 .707 r
F P
0 g
s
.69777 .86916 m .69777 .85064 L .6814 .858 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71538 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.51644 .87359 m .51644 .85506 L .50385 .84718 L p .707 .577 .707 r
F P
0 g
s
.50095 .68473 m .50095 .74031 L .50385 .74885 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.70485 .68836 m .70485 .74395 L .70195 .7354 L p .707 .577 .707 r
F P
0 g
s
.70195 .7354 m .70195 .67982 L .70485 .68836 L p .707 .577 .707 r
F P
0 g
s
.50385 .84718 m .50385 .86571 L .51644 .87359 L p .707 .577 .707 r
F P
0 g
s
.49044 .81524 m .49044 .31335 L .44643 .31066 L p .707 .577 .707 r
F P
0 g
s
.50095 .74031 m .50095 .68473 L .50804 .67636 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .67636 m .50804 .73195 L .50095 .74031 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .73195 m .50804 .67636 L .5244 .669 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.5244 .669 m .5244 .72458 L .50804 .73195 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72816 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .72458 m .5244 .669 L .54846 .66335 L p .707 .577 .707 r
F P
0 g
s
.5244 .72816 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.54846 .66335 m .54846 .71893 L .5244 .72458 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .72251 L .5244 .72816 L p .707 .577 .707 r
F P
0 g
s
.49044 .31335 m .49044 .81524 L .53538 .81414 L p .707 .577 .707 r
F P
0 g
s
.53538 .81414 m .53538 .31225 L .49044 .31335 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70193 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.54846 .71893 m .54846 .66335 L .57784 .65997 L p .707 .577 .707 r
F P
0 g
s
.54846 .72251 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.57784 .65997 m .57784 .71555 L .54846 .71893 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .72251 L p .707 .577 .707 r
F P
0 g
s
.53538 .31225 m .53538 .81414 L .57686 .80937 L p .707 .577 .707 r
F P
0 g
s
.57686 .80937 m .57686 .30748 L .53538 .31225 L p .707 .577 .707 r
F P
0 g
s
.44643 .81255 m .44643 .31066 L .40766 .30446 L p .707 .577 .707 r
F P
0 g
s
.44643 .31066 m .44643 .81255 L .49044 .81524 L p .707 .577 .707 r
F P
0 g
s
.69777 .85064 m .69777 .86916 L .70485 .8608 L p .707 .577 .707 r
F P
0 g
s
.70485 .8608 m .70485 .84227 L .69777 .85064 L p .707 .577 .707 r
F P
0 g
s
.57784 .71555 m .57784 .65997 L .60968 .65919 L p .707 .577 .707 r
F P
0 g
s
.60968 .65919 m .60968 .71477 L .57784 .71555 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .6813 L p .707 .577 .707 r
F P
0 g
s
.60968 .6813 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.57686 .30748 m .57686 .80937 L .61082 .80139 L p .707 .577 .707 r
F P
0 g
s
.64085 .66109 m .64085 .71667 L .60968 .71477 L p .707 .577 .707 r
F P
0 g
s
.60968 .71477 m .60968 .65919 L .64085 .66109 L p .707 .577 .707 r
F P
0 g
s
.64085 .6832 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .6813 L .64085 .6832 L p .707 .577 .707 r
F P
0 g
s
.61082 .80139 m .61082 .2995 L .57686 .30748 L p .707 .577 .707 r
F P
0 g
s
.50385 .86571 m .50385 .84718 L .50095 .83864 L p .707 .577 .707 r
F P
0 g
s
.50095 .83864 m .50095 .85716 L .50385 .86571 L p .707 .577 .707 r
F P
0 g
s
.70195 .67982 m .70195 .7354 L .68936 .72752 L p .707 .577 .707 r
F P
0 g
s
.68936 .72752 m .68936 .67194 L .70195 .67982 L p .707 .577 .707 r
F P
0 g
s
.40766 .80635 m .40766 .30446 L .37794 .29535 L p .707 .577 .707 r
F P
0 g
s
.40766 .30446 m .40766 .80635 L .44643 .81255 L p .707 .577 .707 r
F P
0 g
s
.70195 .70193 m .70195 .73898 L .68936 .7311 L p .707 .577 .707 r
F P
0 g
s
.68936 .7311 m .68936 .69404 L .70195 .70193 L p .707 .577 .707 r
F P
0 g
s
.25312 .73267 m .25312 .67709 L .22195 .67519 L p .707 .577 .707 r
F P
0 g
s
.25312 .67709 m .25312 .73267 L .28495 .73189 L p .707 .577 .707 r
F P
0 g
s
.28495 .73189 m .28495 .67631 L .25312 .67709 L p .707 .577 .707 r
F P
0 g
s
.70485 .84227 m .70485 .8608 L .70195 .85226 L p .707 .577 .707 r
F P
0 g
s
.70195 .85226 m .70195 .83373 L .70485 .84227 L p .707 .577 .707 r
F P
0 g
s
.28495 .67631 m .28495 .73189 L .31434 .72851 L p .707 .577 .707 r
F P
0 g
s
.31434 .72851 m .31434 .67293 L .28495 .67631 L p .707 .577 .707 r
F P
0 g
s
.25312 .73625 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73625 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.22195 .73077 m .22195 .67519 L .19449 .67079 L p .707 .577 .707 r
F P
0 g
s
.22195 .67519 m .22195 .73077 L .25312 .73267 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69504 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.61082 .2995 m .61082 .80139 L .63393 .79099 L p .707 .577 .707 r
F P
0 g
s
.63393 .79099 m .63393 .2891 L .61082 .2995 L p .707 .577 .707 r
F P
0 g
s
.22195 .73435 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73435 L .25312 .73625 L p .707 .577 .707 r
F P
0 g
s
.31434 .67293 m .31434 .72851 L .33839 .72286 L p .707 .577 .707 r
F P
0 g
s
.33839 .72286 m .33839 .66728 L .31434 .67293 L p .707 .577 .707 r
F P
0 g
s
.50095 .85716 m .50095 .83864 L .50804 .83027 L p .707 .577 .707 r
F P
0 g
s
.68936 .67194 m .68936 .72752 L .66831 .72107 L p .707 .577 .707 r
F P
0 g
s
.66831 .72107 m .66831 .66548 L .68936 .67194 L p .707 .577 .707 r
F P
0 g
s
.50804 .83027 m .50804 .8488 L .50095 .85716 L p .707 .577 .707 r
F P
0 g
s
.31434 .69504 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68939 L .31434 .69504 L p .707 .577 .707 r
F P
0 g
s
.19449 .67079 m .19449 .72638 L .22195 .73077 L p .707 .577 .707 r
F P
0 g
s
.19449 .72638 m .19449 .67079 L .17343 .66434 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73435 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .7311 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.37794 .79724 m .37794 .29535 L .36016 .28422 L p .707 .577 .707 r
F P
0 g
s
.37794 .29535 m .37794 .79724 L .40766 .80635 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.70195 .83373 m .70195 .85226 L .68936 .84437 L p .707 .577 .707 r
F P
0 g
s
.68936 .84437 m .68936 .82585 L .70195 .83373 L p .707 .577 .707 r
F P
0 g
s
.33839 .66728 m .33839 .72286 L .35476 .7155 L p .707 .577 .707 r
F P
0 g
s
.35476 .7155 m .35476 .65991 L .33839 .66728 L p .707 .577 .707 r
F P
0 g
s
.17343 .66434 m .17343 .71992 L .19449 .72638 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68939 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68939 L p .707 .577 .707 r
F P
0 g
s
.66831 .66548 m .66831 .72107 L .64085 .71667 L p .707 .577 .707 r
F P
0 g
s
.64085 .71667 m .64085 .66109 L .66831 .66548 L p .707 .577 .707 r
F P
0 g
s
.25312 .84952 m .25312 .831 L .22195 .82909 L p .707 .577 .707 r
F P
0 g
s
.25312 .831 m .25312 .84952 L .28495 .84875 L p .707 .577 .707 r
F P
0 g
s
.28495 .84875 m .28495 .83022 L .25312 .831 L p .707 .577 .707 r
F P
0 g
s
.50804 .8488 m .50804 .83027 L .5244 .82291 L p .707 .577 .707 r
F P
0 g
s
.28495 .83022 m .28495 .84875 L .31434 .84537 L p .707 .577 .707 r
F P
0 g
s
.31434 .84537 m .31434 .82684 L .28495 .83022 L p .707 .577 .707 r
F P
0 g
s
.17343 .71992 m .17343 .66434 L .16084 .65646 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .6832 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.22195 .82909 m .22195 .84762 L .25312 .84952 L p .707 .577 .707 r
F P
0 g
s
.63393 .2891 m .63393 .79099 L .64393 .77918 L p .707 .577 .707 r
F P
0 g
s
.64393 .77918 m .64393 .27729 L .63393 .2891 L p .707 .577 .707 r
F P
0 g
s
.22195 .84762 m .22195 .82909 L .19449 .8247 L p .707 .577 .707 r
F P
0 g
s
.5244 .82291 m .5244 .84143 L .50804 .8488 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.19449 .8247 m .19449 .84323 L .22195 .84762 L p .707 .577 .707 r
F P
0 g
s
.31434 .82684 m .31434 .84537 L .33839 .83972 L p .707 .577 .707 r
F P
0 g
s
.33839 .83972 m .33839 .82119 L .31434 .82684 L p .707 .577 .707 r
F P
0 g
s
.16084 .65646 m .16084 .71204 L .17343 .71992 L p .707 .577 .707 r
F P
0 g
s
.68936 .82585 m .68936 .84437 L .66831 .83792 L p .707 .577 .707 r
F P
0 g
s
.66831 .83792 m .66831 .81939 L .68936 .82585 L p .707 .577 .707 r
F P
0 g
s
.35476 .65991 m .35476 .7155 L .36184 .70713 L p .707 .577 .707 r
F P
0 g
s
.36184 .70713 m .36184 .65155 L .35476 .65991 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.19449 .84323 m .19449 .8247 L .17343 .81825 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .65155 m .36184 .70713 L .35894 .69859 L p .707 .577 .707 r
F P
0 g
s
.35894 .69859 m .35894 .64301 L .36184 .65155 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70217 L p .707 .577 .707 r
F P
0 g
s
.35894 .70217 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .78611 m .36016 .28422 L .35607 .27216 L p .707 .577 .707 r
F P
0 g
s
.36016 .28422 m .36016 .78611 L .37794 .79724 L p .707 .577 .707 r
F P
0 g
s
.17343 .81825 m .17343 .83678 L .19449 .84323 L p .707 .577 .707 r
F P
0 g
s
.5244 .84143 m .5244 .82291 L .54846 .81726 L p .707 .577 .707 r
F P
0 g
s
.16084 .71204 m .16084 .65646 L .15794 .64791 L p .707 .577 .707 r
F P
0 g
s
.54846 .81726 m .54846 .83578 L .5244 .84143 L p .707 .577 .707 r
F P
0 g
s
.33839 .82119 m .33839 .83972 L .35476 .83235 L p .707 .577 .707 r
F P
0 g
s
.35476 .83235 m .35476 .81382 L .33839 .82119 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.66831 .81939 m .66831 .83792 L .64085 .83353 L p .707 .577 .707 r
F P
0 g
s
.64085 .83353 m .64085 .815 L .66831 .81939 L p .707 .577 .707 r
F P
0 g
s
.17343 .83678 m .17343 .81825 L .16084 .81036 L p .707 .577 .707 r
F P
0 g
s
.15794 .64791 m .15794 .7035 L .16084 .71204 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.64393 .27729 m .64393 .77918 L .63984 .76712 L p .707 .577 .707 r
F P
0 g
s
.63984 .76712 m .63984 .26523 L .64393 .27729 L p .707 .577 .707 r
F P
0 g
s
.54846 .83578 m .54846 .81726 L .57784 .81388 L p .707 .577 .707 r
F P
0 g
s
.16084 .81036 m .16084 .82889 L .17343 .83678 L p .707 .577 .707 r
F P
0 g
s
.57784 .81388 m .57784 .8324 L .54846 .83578 L p .707 .577 .707 r
F P
0 g
s
.64085 .815 m .64085 .83353 L .60968 .83163 L p .707 .577 .707 r
F P
0 g
s
.60968 .83163 m .60968 .8131 L .64085 .815 L p .707 .577 .707 r
F P
0 g
s
.57784 .8324 m .57784 .81388 L .60968 .8131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81382 m .35476 .83235 L .36184 .82399 L p .707 .577 .707 r
F P
0 g
s
.36184 .82399 m .36184 .80546 L .35476 .81382 L p .707 .577 .707 r
F P
0 g
s
.15794 .7035 m .15794 .64791 L .16503 .63955 L p .707 .577 .707 r
F P
0 g
s
.60968 .8131 m .60968 .83163 L .57784 .8324 L p .707 .577 .707 r
F P
0 g
s
.35894 .64301 m .35894 .69859 L .34635 .6907 L p .707 .577 .707 r
F P
0 g
s
.34635 .6907 m .34635 .63512 L .35894 .64301 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70217 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65723 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .27216 m .35607 .77405 L .36016 .78611 L p .707 .577 .707 r
F P
0 g
s
.35607 .77405 m .35607 .27216 L .36607 .26035 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.16084 .82889 m .16084 .81036 L .15794 .80182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .63955 m .16503 .69513 L .15794 .7035 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.15794 .80182 m .15794 .82035 L .16084 .82889 L p .707 .577 .707 r
F P
0 g
s
.36184 .80546 m .36184 .82399 L .35894 .81544 L p .707 .577 .707 r
F P
0 g
s
.35894 .81544 m .35894 .79692 L .36184 .80546 L p .707 .577 .707 r
F P
0 g
s
.63984 .26523 m .63984 .76712 L .62206 .75599 L p .707 .577 .707 r
F P
0 g
s
.62206 .75599 m .62206 .2541 L .63984 .26523 L p .707 .577 .707 r
F P
0 g
s
.16503 .69513 m .16503 .63955 L .1814 .63218 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65429 L p .707 .577 .707 r
F P
0 g
s
.15794 .82035 m .15794 .80182 L .16503 .79346 L p .707 .577 .707 r
F P
0 g
s
.1814 .63218 m .1814 .68776 L .16503 .69513 L p .707 .577 .707 r
F P
0 g
s
.34635 .63512 m .34635 .6907 L .3253 .68425 L p .707 .577 .707 r
F P
0 g
s
.3253 .68425 m .3253 .62867 L .34635 .63512 L p .707 .577 .707 r
F P
0 g
s
.1814 .65429 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.36607 .76224 m .36607 .26035 L .38918 .24995 L p .707 .577 .707 r
F P
0 g
s
.36607 .26035 m .36607 .76224 L .35607 .77405 L p .707 .577 .707 r
F P
0 g
s
.16503 .79346 m .16503 .81199 L .15794 .82035 L p .707 .577 .707 r
F P
0 g
s
.34635 .65723 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65723 L p .707 .577 .707 r
F P
0 g
s
.1814 .68776 m .1814 .63218 L .20545 .62653 L p .707 .577 .707 r
F P
0 g
s
.35894 .79692 m .35894 .81544 L .34635 .80756 L p .707 .577 .707 r
F P
0 g
s
.34635 .80756 m .34635 .78903 L .35894 .79692 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65429 L .20545 .64864 L p .707 .577 .707 r
F P
0 g
s
.3253 .62867 m .3253 .68425 L .29784 .67986 L p .707 .577 .707 r
F P
0 g
s
.29784 .67986 m .29784 .62428 L .3253 .62867 L p .707 .577 .707 r
F P
0 g
s
.62206 .2541 m .62206 .75599 L .59233 .74688 L p .707 .577 .707 r
F P
0 g
s
.59233 .74688 m .59233 .24499 L .62206 .2541 L p .707 .577 .707 r
F P
0 g
s
.20545 .62653 m .20545 .68211 L .1814 .68776 L p .707 .577 .707 r
F P
0 g
s
.16503 .81199 m .16503 .79346 L .1814 .78609 L p .707 .577 .707 r
F P
0 g
s
.20545 .64864 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68344 L p .707 .577 .707 r
F P
0 g
s
.29784 .68344 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68211 m .20545 .62653 L .23483 .62315 L p .707 .577 .707 r
F P
0 g
s
.1814 .78609 m .1814 .80462 L .16503 .81199 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64864 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.38918 .24995 m .38918 .75184 L .36607 .76224 L p .707 .577 .707 r
F P
0 g
s
.38918 .75184 m .38918 .24995 L .42314 .24197 L p .707 .577 .707 r
F P
0 g
s
.29784 .62428 m .29784 .67986 L .26667 .67796 L p .707 .577 .707 r
F P
0 g
s
.26667 .67796 m .26667 .62238 L .29784 .62428 L p .707 .577 .707 r
F P
0 g
s
.34635 .78903 m .34635 .80756 L .3253 .8011 L p .707 .577 .707 r
F P
0 g
s
.3253 .8011 m .3253 .78258 L .34635 .78903 L p .707 .577 .707 r
F P
0 g
s
.23483 .67873 m .23483 .62315 L .26667 .62238 L p .707 .577 .707 r
F P
0 g
s
.23483 .62315 m .23483 .67873 L .20545 .68211 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68344 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.26667 .62238 m .26667 .67796 L .23483 .67873 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.73333 .67745 m .73333 .62186 L .70216 .61996 L p .707 .577 .707 r
F P
0 g
s
.73333 .62186 m .73333 .67745 L .76517 .67667 L p .707 .577 .707 r
F P
0 g
s
.76517 .67667 m .76517 .62109 L .73333 .62186 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.76517 .62109 m .76517 .67667 L .79455 .67329 L p .707 .577 .707 r
F P
0 g
s
.79455 .67329 m .79455 .61771 L .76517 .62109 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.1814 .80462 m .1814 .78609 L .20545 .78044 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68025 L p .707 .577 .707 r
F P
0 g
s
.76517 .68025 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.70216 .67555 m .70216 .61996 L .6747 .61557 L p .707 .577 .707 r
F P
0 g
s
.70216 .61996 m .70216 .67555 L .73333 .67745 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68025 L .79455 .67687 L p .707 .577 .707 r
F P
0 g
s
.79455 .67687 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.59233 .24499 m .59233 .74688 L .55357 .74068 L p .707 .577 .707 r
F P
0 g
s
.55357 .74068 m .55357 .23879 L .59233 .24499 L p .707 .577 .707 r
F P
0 g
s
.20545 .78044 m .20545 .79897 L .1814 .80462 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63768 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.79455 .61771 m .79455 .67329 L .8186 .66764 L p .707 .577 .707 r
F P
0 g
s
.8186 .66764 m .8186 .61206 L .79455 .61771 L p .707 .577 .707 r
F P
0 g
s
.3253 .78258 m .3253 .8011 L .29784 .79671 L p .707 .577 .707 r
F P
0 g
s
.29784 .79671 m .29784 .77819 L .3253 .78258 L p .707 .577 .707 r
F P
0 g
s
.42314 .74386 m .42314 .24197 L .46462 .2372 L p .707 .577 .707 r
F P
0 g
s
.42314 .24197 m .42314 .74386 L .38918 .75184 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67687 L .8186 .67122 L p .707 .577 .707 r
F P
0 g
s
.8186 .67122 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.6747 .61557 m .6747 .67115 L .70216 .67555 L p .707 .577 .707 r
F P
0 g
s
.6747 .67115 m .6747 .61557 L .65365 .60912 L p .707 .577 .707 r
F P
0 g
s
.6747 .63768 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.20545 .79897 m .20545 .78044 L .23483 .77706 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63768 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.23483 .77706 m .23483 .79559 L .20545 .79897 L p .707 .577 .707 r
F P
0 g
s
.55357 .23879 m .55357 .74068 L .50956 .738 L p .707 .577 .707 r
F P
0 g
s
.50956 .738 m .50956 .23611 L .55357 .23879 L p .707 .577 .707 r
F P
0 g
s
.29784 .77819 m .29784 .79671 L .26667 .79481 L p .707 .577 .707 r
F P
0 g
s
.26667 .79481 m .26667 .77628 L .29784 .77819 L p .707 .577 .707 r
F P
0 g
s
.8186 .61206 m .8186 .66764 L .83497 .66027 L p .707 .577 .707 r
F P
0 g
s
.83497 .66027 m .83497 .60469 L .8186 .61206 L p .707 .577 .707 r
F P
0 g
s
.46462 .73909 m .46462 .2372 L .50956 .23611 L p .707 .577 .707 r
F P
0 g
s
.46462 .2372 m .46462 .73909 L .42314 .74386 L p .707 .577 .707 r
F P
0 g
s
.65365 .60912 m .65365 .6647 L .6747 .67115 L p .707 .577 .707 r
F P
0 g
s
.23483 .79559 m .23483 .77706 L .26667 .77628 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66828 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.50956 .23611 m .50956 .738 L .46462 .73909 L p .707 .577 .707 r
F P
0 g
s
.26667 .77628 m .26667 .79481 L .23483 .79559 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67122 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.73333 .7943 m .73333 .77577 L .70216 .77387 L p .707 .577 .707 r
F P
0 g
s
.73333 .77577 m .73333 .7943 L .76517 .79352 L p .707 .577 .707 r
F P
0 g
s
.76517 .79352 m .76517 .775 L .73333 .77577 L p .707 .577 .707 r
F P
0 g
s
.76517 .775 m .76517 .79352 L .79455 .79014 L p .707 .577 .707 r
F P
0 g
s
.79455 .79014 m .79455 .77162 L .76517 .775 L p .707 .577 .707 r
F P
0 g
s
.65365 .6647 m .65365 .60912 L .64105 .60123 L p .707 .577 .707 r
F P
0 g
s
.70216 .77387 m .70216 .7924 L .73333 .7943 L p .707 .577 .707 r
F P
0 g
s
.70216 .7924 m .70216 .77387 L .6747 .76948 L p .707 .577 .707 r
F P
0 g
s
.65365 .66828 m .65365 .63122 L .64105 .62334 L p .707 .577 .707 r
F P
0 g
s
.6747 .76948 m .6747 .78801 L .70216 .7924 L p .707 .577 .707 r
F P
0 g
s
.79455 .77162 m .79455 .79014 L .8186 .78449 L p .707 .577 .707 r
F P
0 g
s
.8186 .78449 m .8186 .76597 L .79455 .77162 L p .707 .577 .707 r
F P
0 g
s
.64105 .60123 m .64105 .65681 L .65365 .6647 L p .707 .577 .707 r
F P
0 g
s
.83497 .60469 m .83497 .66027 L .84205 .65191 L p .707 .577 .707 r
F P
0 g
s
.84205 .65191 m .84205 .59633 L .83497 .60469 L p .707 .577 .707 r
F P
0 g
s
.64105 .62334 m .64105 .66039 L .65365 .66828 L p .707 .577 .707 r
F P
0 g
s
.6747 .78801 m .6747 .76948 L .65365 .76303 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.65365 .76303 m .65365 .78155 L .6747 .78801 L p .707 .577 .707 r
F P
0 g
s
.64105 .65681 m .64105 .60123 L .63816 .59269 L p .707 .577 .707 r
F P
0 g
s
.8186 .76597 m .8186 .78449 L .83497 .77713 L p .707 .577 .707 r
F P
0 g
s
.83497 .77713 m .83497 .7586 L .8186 .76597 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62334 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.65365 .78155 m .65365 .76303 L .64105 .75514 L p .707 .577 .707 r
F P
0 g
s
.63816 .59269 m .63816 .64827 L .64105 .65681 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.84205 .59633 m .84205 .65191 L .83916 .64337 L p .707 .577 .707 r
F P
0 g
s
.83916 .64337 m .83916 .58778 L .84205 .59633 L p .707 .577 .707 r
F P
0 g
s
.64105 .75514 m .64105 .77367 L .65365 .78155 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.83497 .7586 m .83497 .77713 L .84206 .76876 L p .707 .577 .707 r
F P
0 g
s
.84206 .76876 m .84206 .75023 L .83497 .7586 L p .707 .577 .707 r
F P
0 g
s
.63816 .64827 m .63816 .59269 L .64524 .58433 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.64105 .77367 m .64105 .75514 L .63816 .7466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58433 m .64524 .63991 L .63816 .64827 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64349 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.63816 .7466 m .63816 .76513 L .64105 .77367 L p .707 .577 .707 r
F P
0 g
s
.83916 .58778 m .83916 .64337 L .82657 .63548 L p .707 .577 .707 r
F P
0 g
s
.82657 .63548 m .82657 .5799 L .83916 .58778 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.39032 .64063 m .39032 .58505 L .35915 .58315 L p .707 .577 .707 r
F P
0 g
s
.39032 .58505 m .39032 .64063 L .42216 .63985 L p .707 .577 .707 r
F P
0 g
s
.42216 .63985 m .42216 .58427 L .39032 .58505 L p .707 .577 .707 r
F P
0 g
s
.84206 .75023 m .84206 .76876 L .83916 .76022 L p .707 .577 .707 r
F P
0 g
s
.83916 .76022 m .83916 .74169 L .84206 .75023 L p .707 .577 .707 r
F P
0 g
s
.64524 .63991 m .64524 .58433 L .66161 .57696 L p .707 .577 .707 r
F P
0 g
s
.42216 .58427 m .42216 .63985 L .45154 .63647 L p .707 .577 .707 r
F P
0 g
s
.45154 .63647 m .45154 .58089 L .42216 .58427 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60638 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.35915 .63873 m .35915 .58315 L .33169 .57876 L p .707 .577 .707 r
F P
0 g
s
.35915 .58315 m .35915 .63873 L .39032 .64063 L p .707 .577 .707 r
F P
0 g
s
.64524 .64349 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60638 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .603 L .42216 .60638 L p .707 .577 .707 r
F P
0 g
s
.35915 .64231 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .64231 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.45154 .58089 m .45154 .63647 L .47559 .63082 L p .707 .577 .707 r
F P
0 g
s
.47559 .63082 m .47559 .57524 L .45154 .58089 L p .707 .577 .707 r
F P
0 g
s
.63816 .76513 m .63816 .7466 L .64524 .73824 L p .707 .577 .707 r
F P
0 g
s
.66161 .57696 m .66161 .63254 L .64524 .63991 L p .707 .577 .707 r
F P
0 g
s
.82657 .5799 m .82657 .63548 L .80551 .62903 L p .707 .577 .707 r
F P
0 g
s
.80551 .62903 m .80551 .57344 L .82657 .5799 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64349 L p .707 .577 .707 r
F P
0 g
s
.64524 .73824 m .64524 .75676 L .63816 .76513 L p .707 .577 .707 r
F P
0 g
s
.45154 .603 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59735 L .45154 .603 L p .707 .577 .707 r
F P
0 g
s
.33169 .57876 m .33169 .63434 L .35915 .63873 L p .707 .577 .707 r
F P
0 g
s
.33169 .63434 m .33169 .57876 L .31064 .5723 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .64231 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .59441 L p .707 .577 .707 r
F P
0 g
s
.66161 .63254 m .66161 .57696 L .68566 .57131 L p .707 .577 .707 r
F P
0 g
s
.83916 .74169 m .83916 .76022 L .82657 .75234 L p .707 .577 .707 r
F P
0 g
s
.82657 .75234 m .82657 .73381 L .83916 .74169 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.47559 .57524 m .47559 .63082 L .49196 .62346 L p .707 .577 .707 r
F P
0 g
s
.49196 .62346 m .49196 .56787 L .47559 .57524 L p .707 .577 .707 r
F P
0 g
s
.31064 .5723 m .31064 .62788 L .33169 .63434 L p .707 .577 .707 r
F P
0 g
s
.31064 .59441 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.47559 .59735 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59735 L p .707 .577 .707 r
F P
0 g
s
.80551 .57344 m .80551 .62903 L .77805 .62463 L p .707 .577 .707 r
F P
0 g
s
.77805 .62463 m .77805 .56905 L .80551 .57344 L p .707 .577 .707 r
F P
0 g
s
.39032 .75748 m .39032 .73896 L .35915 .73706 L p .707 .577 .707 r
F P
0 g
s
.39032 .73896 m .39032 .75748 L .42216 .75671 L p .707 .577 .707 r
F P
0 g
s
.42216 .75671 m .42216 .73818 L .39032 .73896 L p .707 .577 .707 r
F P
0 g
s
.68566 .57131 m .68566 .62689 L .66161 .63254 L p .707 .577 .707 r
F P
0 g
s
.64524 .75676 m .64524 .73824 L .66161 .73087 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.42216 .73818 m .42216 .75671 L .45154 .75333 L p .707 .577 .707 r
F P
0 g
s
.45154 .75333 m .45154 .7348 L .42216 .73818 L p .707 .577 .707 r
F P
0 g
s
.31064 .62788 m .31064 .5723 L .29804 .56442 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.35915 .73706 m .35915 .75558 L .39032 .75748 L p .707 .577 .707 r
F P
0 g
s
.68566 .62689 m .68566 .57131 L .71504 .56793 L p .707 .577 .707 r
F P
0 g
s
.35915 .75558 m .35915 .73706 L .33169 .73266 L p .707 .577 .707 r
F P
0 g
s
.66161 .73087 m .66161 .74939 L .64524 .75676 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .59441 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.33169 .73266 m .33169 .75119 L .35915 .75558 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.77805 .56905 m .77805 .62463 L .74688 .62273 L p .707 .577 .707 r
F P
0 g
s
.74688 .62273 m .74688 .56715 L .77805 .56905 L p .707 .577 .707 r
F P
0 g
s
.45154 .7348 m .45154 .75333 L .47559 .74768 L p .707 .577 .707 r
F P
0 g
s
.47559 .74768 m .47559 .72915 L .45154 .7348 L p .707 .577 .707 r
F P
0 g
s
.29804 .56442 m .29804 .62 L .31064 .62788 L p .707 .577 .707 r
F P
0 g
s
.82657 .73381 m .82657 .75234 L .80551 .74588 L p .707 .577 .707 r
F P
0 g
s
.80551 .74588 m .80551 .72735 L .82657 .73381 L p .707 .577 .707 r
F P
0 g
s
.71504 .62351 m .71504 .56793 L .74688 .56715 L p .707 .577 .707 r
F P
0 g
s
.71504 .56793 m .71504 .62351 L .68566 .62689 L p .707 .577 .707 r
F P
0 g
s
.49196 .56787 m .49196 .62346 L .49904 .61509 L p .707 .577 .707 r
F P
0 g
s
.49904 .61509 m .49904 .55951 L .49196 .56787 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62358 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58926 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.74688 .56715 m .74688 .62273 L .71504 .62351 L p .707 .577 .707 r
F P
0 g
s
.33169 .75119 m .33169 .73266 L .31064 .72621 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58926 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.74688 .58926 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.31064 .72621 m .31064 .74474 L .33169 .75119 L p .707 .577 .707 r
F P
0 g
s
.66161 .74939 m .66161 .73087 L .68566 .72522 L p .707 .577 .707 r
F P
0 g
s
.29804 .62 m .29804 .56442 L .29515 .55587 L p .707 .577 .707 r
F P
0 g
s
.68566 .72522 m .68566 .74375 L .66161 .74939 L p .707 .577 .707 r
F P
0 g
s
.47559 .72915 m .47559 .74768 L .49196 .74031 L p .707 .577 .707 r
F P
0 g
s
.49196 .74031 m .49196 .72178 L .47559 .72915 L p .707 .577 .707 r
F P
0 g
s
.29804 .62358 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.80551 .72735 m .80551 .74588 L .77805 .74149 L p .707 .577 .707 r
F P
0 g
s
.77805 .74149 m .77805 .72296 L .80551 .72735 L p .707 .577 .707 r
F P
0 g
s
.31064 .74474 m .31064 .72621 L .29804 .71833 L p .707 .577 .707 r
F P
0 g
s
.29515 .55587 m .29515 .61146 L .29804 .62 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62358 L p .707 .577 .707 r
F P
0 g
s
.49904 .55951 m .49904 .61509 L .49615 .60655 L p .707 .577 .707 r
F P
0 g
s
.49615 .60655 m .49615 .55097 L .49904 .55951 L p .707 .577 .707 r
F P
0 g
s
.68566 .74375 m .68566 .72522 L .71504 .72184 L p .707 .577 .707 r
F P
0 g
s
.29804 .71833 m .29804 .73685 L .31064 .74474 L p .707 .577 .707 r
F P
0 g
s
.71504 .72184 m .71504 .74037 L .68566 .74375 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61013 L p .707 .577 .707 r
F P
0 g
s
.49615 .61013 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.77805 .72296 m .77805 .74149 L .74688 .73959 L p .707 .577 .707 r
F P
0 g
s
.74688 .73959 m .74688 .72106 L .77805 .72296 L p .707 .577 .707 r
F P
0 g
s
.71504 .74037 m .71504 .72184 L .74688 .72106 L p .707 .577 .707 r
F P
0 g
s
.49196 .72178 m .49196 .74031 L .49904 .73195 L p .707 .577 .707 r
F P
0 g
s
.49904 .73195 m .49904 .71342 L .49196 .72178 L p .707 .577 .707 r
F P
0 g
s
.29515 .61146 m .29515 .55587 L .30223 .54751 L p .707 .577 .707 r
F P
0 g
s
.74688 .72106 m .74688 .73959 L .71504 .74037 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.29804 .73685 m .29804 .71833 L .29515 .70978 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .54751 m .30223 .60309 L .29515 .61146 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.29515 .70978 m .29515 .72831 L .29804 .73685 L p .707 .577 .707 r
F P
0 g
s
.49615 .55097 m .49615 .60655 L .48356 .59867 L p .707 .577 .707 r
F P
0 g
s
.48356 .59867 m .48356 .54308 L .49615 .55097 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61013 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.49904 .71342 m .49904 .73195 L .49615 .7234 L p .707 .577 .707 r
F P
0 g
s
.49615 .7234 m .49615 .70488 L .49904 .71342 L p .707 .577 .707 r
F P
0 g
s
.30223 .60309 m .30223 .54751 L .3186 .54014 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56225 L p .707 .577 .707 r
F P
0 g
s
.29515 .72831 m .29515 .70978 L .30223 .70142 L p .707 .577 .707 r
F P
0 g
s
.3186 .54014 m .3186 .59572 L .30223 .60309 L p .707 .577 .707 r
F P
0 g
s
.48356 .54308 m .48356 .59867 L .4625 .59221 L p .707 .577 .707 r
F P
0 g
s
.4625 .59221 m .4625 .53663 L .48356 .54308 L p .707 .577 .707 r
F P
0 g
s
.3186 .56225 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.30223 .70142 m .30223 .71995 L .29515 .72831 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.3186 .59572 m .3186 .54014 L .34265 .53449 L p .707 .577 .707 r
F P
0 g
s
.49615 .70488 m .49615 .7234 L .48356 .71552 L p .707 .577 .707 r
F P
0 g
s
.48356 .71552 m .48356 .69699 L .49615 .70488 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56225 L .34265 .5566 L p .707 .577 .707 r
F P
0 g
s
.4625 .53663 m .4625 .59221 L .43504 .58782 L p .707 .577 .707 r
F P
0 g
s
.43504 .58782 m .43504 .53224 L .4625 .53663 L p .707 .577 .707 r
F P
0 g
s
.34265 .53449 m .34265 .59007 L .3186 .59572 L p .707 .577 .707 r
F P
0 g
s
.30223 .71995 m .30223 .70142 L .3186 .69405 L p .707 .577 .707 r
F P
0 g
s
.34265 .5566 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .5914 L p .707 .577 .707 r
F P
0 g
s
.43504 .5914 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .59007 m .34265 .53449 L .37203 .53111 L p .707 .577 .707 r
F P
0 g
s
.3186 .69405 m .3186 .71258 L .30223 .71995 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .5566 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.43504 .53224 m .43504 .58782 L .40387 .58592 L p .707 .577 .707 r
F P
0 g
s
.40387 .58592 m .40387 .53034 L .43504 .53224 L p .707 .577 .707 r
F P
0 g
s
.48356 .69699 m .48356 .71552 L .4625 .70907 L p .707 .577 .707 r
F P
0 g
s
.4625 .70907 m .4625 .69054 L .48356 .69699 L p .707 .577 .707 r
F P
0 g
s
.37203 .5867 m .37203 .53111 L .40387 .53034 L p .707 .577 .707 r
F P
0 g
s
.37203 .53111 m .37203 .5867 L .34265 .59007 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .5914 L .40387 .5895 L p .707 .577 .707 r
F P
0 g
s
.40387 .5895 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.40387 .53034 m .40387 .58592 L .37203 .5867 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .5895 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.3186 .71258 m .3186 .69405 L .34265 .6884 L p .707 .577 .707 r
F P
0 g
s
.34265 .6884 m .34265 .70693 L .3186 .71258 L p .707 .577 .707 r
F P
0 g
s
.4625 .69054 m .4625 .70907 L .43504 .70467 L p .707 .577 .707 r
F P
0 g
s
.43504 .70467 m .43504 .68615 L .4625 .69054 L p .707 .577 .707 r
F P
0 g
s
.34265 .70693 m .34265 .6884 L .37203 .68502 L p .707 .577 .707 r
F P
0 g
s
.37203 .68502 m .37203 .70355 L .34265 .70693 L p .707 .577 .707 r
F P
0 g
s
.43504 .68615 m .43504 .70467 L .40387 .70277 L p .707 .577 .707 r
F P
0 g
s
.40387 .70277 m .40387 .68425 L .43504 .68615 L p .707 .577 .707 r
F P
0 g
s
.37203 .70355 m .37203 .68502 L .40387 .68425 L p .707 .577 .707 r
F P
0 g
s
.40387 .68425 m .40387 .70277 L .37203 .70355 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^
Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000
FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo2@0015YF00<005YFFUH00UYF20001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEQH000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF00000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF0000
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH01000<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEPh000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJ
EP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YF0000009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000500000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo001COol01000FUH005YF0P00
1EYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo001COol01P00FUH00000FUH000EJEP03
001JEUYF00=JEP<000=JEQ<000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQX000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF
00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
1000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eo
o`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH005YF009JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF0`000eYF0P00;Goo000]Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH80004FUH40002FUH>0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF1@000eYF00<0
05YFFUH00UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHD0006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00D005YF001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD0
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH5000jOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUH0000H000o
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPl000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP05001JEUYFFUH0001E
Ool002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEPH0009JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEPD000AJEP04001JEUYFFUH2001DOol002aoo`03001JEP0000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002aoo`04001JEP00FUH20004FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003FUH2001DOol002aoo`06001JEP00001J
EP001EYF00@005YFFUIJEPD0009JEQ@00005FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH3
00000eYF0000001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJ
EP03001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPP000AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00
FUH00004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH50002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF100000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000
FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002ioo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEP0000<0009JEP03001JEUYF00AJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
100000=JEP00FUH015YF00@005YFFUIJEQX003aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEP<000EJEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF00002P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD003Moo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF00@005YF
000000=JEP03001JEP0000@000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH5
0002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol003]oo`P000AJEPD000EJEP04001JEP000003FUH00`00
FUIJEP02FUH50003Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00L0
05YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol004=ooa8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH01000FUIJEUYF30001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00EGoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH00`00FUIJ
EP02000^Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001J
EUYFFUH0000^Ool005Yoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEP0001Yoo`@000=J
EP04001JEUYFFUH2000]Ool005eoo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP03001JEP0000=JEP<000=JEP03001JEUYF009JEP8001moo`@000=JEP8002eo
o`00HWoo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF100015YF00@005YF001JEP8000IJEP03001JEUYF009JEP03001oogoo
029oo`03001JEUYF008002eoo`00IGoo00D005YFFUH005YF01<00003FUH005YF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP05001JEUYFFUH00003FUH01P00FUH00000FUH000IJ
EP03001JEUYF008002Ioo`@002eoo`00IGoo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000000UYF0P001UYF0`009Woo0P0000AJEP00000002eoo`00IGoo00<005YF0000
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YF00001P009Goo0`000eYF0`00;Goo
001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP02FUH3000ROol4
00000eYF001JEP03FUH00`00FUH0000]Ool006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<001Uoo`D000EJEP03001JEUYF009JEP80
02ioo`00?goo4@005Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uo
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00=Goo100000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0P001Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P002Goo1@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004Ool3
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P0047oo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000K7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP0000Ioo`8000AJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006io
o`00;7oo00<005YF00000eYF1@009goo0`0000=JEP00FUH00UYF00<007ooOol01Woo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00LGoo
000/Ool01000FUH005YF0P00;goo0P000eYF00<007ooOol02Goo100025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00M7oo000/Ool01000FUH00000<goo0P0000=J
EP00Ool03Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`00N7oo000/
Ool4000dOol3000EOolR0002OolJ001SOol002aoo`80009JEP<002moo`<00003FUH007oo035oo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5001NOol002aoo`8000=JEP03001J
EP00008002Uoo`<0009JEP03001JEP0002ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008005]oo`00;7oo0P000eYF00<005YFFUH00UYF
1@0087oo100000=JEP00FUH00UYF00<005YF0000;7oo0`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00FGoo000]Ool01@00FUIJEUYF
00001EYF00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000[Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH2001HOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000:goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF
4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000005Ioo`00<7oo0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000002]oo`8000AJEP03001JEUYF009JEPH0019oo`P000=JEP03001JEUYF00=JEP05001JEUYFFUH0
001EOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<002aoo`03001JEP0000AJEP03001JEP000080021oo`D000AJEP05001JEUYF
FUH0001EOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000<002moo`03001JEP0000=JEP<002Qoo`<00003FUH005YF009JEP8005Aoo`00>Goo10000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP8002ioo`80
00=JEP8005Aoo`00?Goo6@00>7oo00@005YF0000039oo`800003FUH0000005Aoo`00SWoo0P0000=J
EP00Ool0<7oo0P0000AJEP00000005Aoo`00SWoo0P000UYF0`00:goo0`000eYF0`00E7oo002>Ool2
0002FUH00`00FUIJEP05000ROol400000eYF001JEP03FUH00`00FUH0001DOol008moo`04001JEUYF
0005FUH00`00FUH00003000IOol50005FUH00`00FUIJEP02FUH2001EOol008moo`04001JEUYF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<0
05YFFUH00UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72951 m .59613 .67393 L .56496 .67202 L p .707 .577 .707 r
F P
0 g
s
.59613 .67393 m .59613 .72951 L .62796 .72873 L p .707 .577 .707 r
F P
0 g
s
.62796 .72873 m .62796 .67315 L .59613 .67393 L p .707 .577 .707 r
F P
0 g
s
.62796 .67315 m .62796 .72873 L .65734 .72535 L p .707 .577 .707 r
F P
0 g
s
.65734 .72535 m .65734 .66977 L .62796 .67315 L p .707 .577 .707 r
F P
0 g
s
.56496 .72761 m .56496 .67202 L .5375 .66763 L p .707 .577 .707 r
F P
0 g
s
.56496 .67202 m .56496 .72761 L .59613 .72951 L p .707 .577 .707 r
F P
0 g
s
.65734 .66977 m .65734 .72535 L .6814 .7197 L p .707 .577 .707 r
F P
0 g
s
.6814 .7197 m .6814 .66412 L .65734 .66977 L p .707 .577 .707 r
F P
0 g
s
.5375 .66763 m .5375 .72321 L .56496 .72761 L p .707 .577 .707 r
F P
0 g
s
.5375 .72321 m .5375 .66763 L .51644 .66118 L p .707 .577 .707 r
F P
0 g
s
.59613 .81705 m .59613 .79852 L .56496 .79662 L p .707 .577 .707 r
F P
0 g
s
.59613 .79852 m .59613 .81705 L .62796 .81627 L p .707 .577 .707 r
F P
0 g
s
.62796 .81627 m .62796 .79774 L .59613 .79852 L p .707 .577 .707 r
F P
0 g
s
.6814 .66412 m .6814 .7197 L .69777 .71233 L p .707 .577 .707 r
F P
0 g
s
.69777 .71233 m .69777 .65675 L .6814 .66412 L p .707 .577 .707 r
F P
0 g
s
.62796 .79774 m .62796 .81627 L .65735 .81289 L p .707 .577 .707 r
F P
0 g
s
.65735 .81289 m .65735 .79436 L .62796 .79774 L p .707 .577 .707 r
F P
0 g
s
.59613 .84665 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84665 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.51644 .66118 m .51644 .71676 L .5375 .72321 L p .707 .577 .707 r
F P
0 g
s
.56496 .79662 m .56496 .81515 L .59613 .81705 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80544 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .81515 m .56496 .79662 L .5375 .79223 L p .707 .577 .707 r
F P
0 g
s
.56496 .84475 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84475 L .59613 .84665 L p .707 .577 .707 r
F P
0 g
s
.51644 .71676 m .51644 .66118 L .50385 .65329 L p .707 .577 .707 r
F P
0 g
s
.5375 .79223 m .5375 .81075 L .56496 .81515 L p .707 .577 .707 r
F P
0 g
s
.65735 .79436 m .65735 .81289 L .6814 .80724 L p .707 .577 .707 r
F P
0 g
s
.6814 .80724 m .6814 .78871 L .65735 .79436 L p .707 .577 .707 r
F P
0 g
s
.65735 .80544 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .79979 L .65735 .80544 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84475 L p .707 .577 .707 r
F P
0 g
s
.5375 .81075 m .5375 .79223 L .51644 .78577 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79685 L p .707 .577 .707 r
F P
0 g
s
.50385 .65329 m .50385 .70888 L .51644 .71676 L p .707 .577 .707 r
F P
0 g
s
.69777 .65675 m .69777 .71233 L .70485 .70397 L p .707 .577 .707 r
F P
0 g
s
.70485 .70397 m .70485 .64839 L .69777 .65675 L p .707 .577 .707 r
F P
0 g
s
.51644 .78577 m .51644 .8043 L .5375 .81075 L p .707 .577 .707 r
F P
0 g
s
.6814 .78871 m .6814 .80724 L .69777 .79987 L p .707 .577 .707 r
F P
0 g
s
.69777 .79987 m .69777 .78135 L .6814 .78871 L p .707 .577 .707 r
F P
0 g
s
.51644 .79685 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.6814 .79979 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .79979 L p .707 .577 .707 r
F P
0 g
s
.50385 .70888 m .50385 .65329 L .50095 .64475 L p .707 .577 .707 r
F P
0 g
s
.51644 .8043 m .51644 .78577 L .50385 .77789 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79685 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .77789 m .50385 .79642 L .51644 .8043 L p .707 .577 .707 r
F P
0 g
s
.50095 .64475 m .50095 .70033 L .50385 .70888 L p .707 .577 .707 r
F P
0 g
s
.70485 .64839 m .70485 .70397 L .70195 .69543 L p .707 .577 .707 r
F P
0 g
s
.70195 .69543 m .70195 .63985 L .70485 .64839 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82602 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.69777 .78135 m .69777 .79987 L .70485 .79151 L p .707 .577 .707 r
F P
0 g
s
.70485 .79151 m .70485 .77298 L .69777 .78135 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70033 m .50095 .64475 L .50804 .63639 L p .707 .577 .707 r
F P
0 g
s
.50385 .79642 m .50385 .77789 L .50095 .76935 L p .707 .577 .707 r
F P
0 g
s
.49044 .82844 m .49044 .32655 L .44643 .32387 L p .707 .577 .707 r
F P
0 g
s
.50385 .82602 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50095 .76935 m .50095 .78787 L .50385 .79642 L p .707 .577 .707 r
F P
0 g
s
.50804 .63639 m .50804 .69197 L .50095 .70033 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82602 L p .707 .577 .707 r
F P
0 g
s
.50804 .69197 m .50804 .63639 L .5244 .62902 L p .707 .577 .707 r
F P
0 g
s
.50095 .78787 m .50095 .76935 L .50804 .76098 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .76098 m .50804 .77951 L .50095 .78787 L p .707 .577 .707 r
F P
0 g
s
.5244 .62902 m .5244 .6846 L .50804 .69197 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.50804 .77951 m .50804 .76098 L .5244 .75361 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .76469 L p .707 .577 .707 r
F P
0 g
s
.5244 .75361 m .5244 .77214 L .50804 .77951 L p .707 .577 .707 r
F P
0 g
s
.5244 .76469 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.5244 .77214 m .5244 .75361 L .54846 .74797 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .76469 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.54846 .74797 m .54846 .76649 L .5244 .77214 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.49044 .32655 m .49044 .82844 L .53538 .82734 L p .707 .577 .707 r
F P
0 g
s
.5244 .6846 m .5244 .62902 L .54846 .62337 L p .707 .577 .707 r
F P
0 g
s
.54846 .62337 m .54846 .67895 L .5244 .6846 L p .707 .577 .707 r
F P
0 g
s
.53538 .82734 m .53538 .32545 L .49044 .32655 L p .707 .577 .707 r
F P
0 g
s
.54846 .67895 m .54846 .62337 L .57784 .61999 L p .707 .577 .707 r
F P
0 g
s
.57784 .61999 m .57784 .67557 L .54846 .67895 L p .707 .577 .707 r
F P
0 g
s
.54846 .76649 m .54846 .74797 L .57784 .74459 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .74459 m .57784 .76311 L .54846 .76649 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.53538 .32545 m .53538 .82734 L .57686 .82257 L p .707 .577 .707 r
F P
0 g
s
.57686 .82257 m .57686 .32068 L .53538 .32545 L p .707 .577 .707 r
F P
0 g
s
.44643 .82576 m .44643 .32387 L .40766 .31767 L p .707 .577 .707 r
F P
0 g
s
.44643 .32387 m .44643 .82576 L .49044 .82844 L p .707 .577 .707 r
F P
0 g
s
.70195 .63985 m .70195 .69543 L .68936 .68754 L p .707 .577 .707 r
F P
0 g
s
.68936 .68754 m .68936 .63196 L .70195 .63985 L p .707 .577 .707 r
F P
0 g
s
.70485 .77298 m .70485 .79151 L .70195 .78297 L p .707 .577 .707 r
F P
0 g
s
.70195 .78297 m .70195 .76444 L .70485 .77298 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81257 L p .707 .577 .707 r
F P
0 g
s
.70195 .81257 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.57784 .67557 m .57784 .61999 L .60968 .61921 L p .707 .577 .707 r
F P
0 g
s
.60968 .61921 m .60968 .6748 L .57784 .67557 L p .707 .577 .707 r
F P
0 g
s
.57784 .76311 m .57784 .74459 L .60968 .74381 L p .707 .577 .707 r
F P
0 g
s
.60968 .74381 m .60968 .76234 L .57784 .76311 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79194 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57686 .32068 m .57686 .82257 L .61082 .8146 L p .707 .577 .707 r
F P
0 g
s
.64085 .62111 m .64085 .6767 L .60968 .6748 L p .707 .577 .707 r
F P
0 g
s
.60968 .6748 m .60968 .61921 L .64085 .62111 L p .707 .577 .707 r
F P
0 g
s
.64085 .74571 m .64085 .76424 L .60968 .76234 L p .707 .577 .707 r
F P
0 g
s
.60968 .76234 m .60968 .74381 L .64085 .74571 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79384 L .60968 .79194 L p .707 .577 .707 r
F P
0 g
s
.60968 .79194 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.61082 .8146 m .61082 .31271 L .57686 .32068 L p .707 .577 .707 r
F P
0 g
s
.25312 .69269 m .25312 .63711 L .22195 .63521 L p .707 .577 .707 r
F P
0 g
s
.25312 .63711 m .25312 .69269 L .28495 .69192 L p .707 .577 .707 r
F P
0 g
s
.28495 .69192 m .28495 .63633 L .25312 .63711 L p .707 .577 .707 r
F P
0 g
s
.28495 .63633 m .28495 .69192 L .31434 .68854 L p .707 .577 .707 r
F P
0 g
s
.31434 .68854 m .31434 .63295 L .28495 .63633 L p .707 .577 .707 r
F P
0 g
s
.22195 .69079 m .22195 .63521 L .19449 .63082 L p .707 .577 .707 r
F P
0 g
s
.22195 .63521 m .22195 .69079 L .25312 .69269 L p .707 .577 .707 r
F P
0 g
s
.40766 .81956 m .40766 .31767 L .37794 .30856 L p .707 .577 .707 r
F P
0 g
s
.40766 .31767 m .40766 .81956 L .44643 .82576 L p .707 .577 .707 r
F P
0 g
s
.31434 .63295 m .31434 .68854 L .33839 .68289 L p .707 .577 .707 r
F P
0 g
s
.33839 .68289 m .33839 .6273 L .31434 .63295 L p .707 .577 .707 r
F P
0 g
s
.68936 .63196 m .68936 .68754 L .66831 .68109 L p .707 .577 .707 r
F P
0 g
s
.66831 .68109 m .66831 .62551 L .68936 .63196 L p .707 .577 .707 r
F P
0 g
s
.19449 .63082 m .19449 .6864 L .22195 .69079 L p .707 .577 .707 r
F P
0 g
s
.19449 .6864 m .19449 .63082 L .17343 .62436 L p .707 .577 .707 r
F P
0 g
s
.70195 .76444 m .70195 .78297 L .68936 .77508 L p .707 .577 .707 r
F P
0 g
s
.68936 .77508 m .68936 .75656 L .70195 .76444 L p .707 .577 .707 r
F P
0 g
s
.61082 .31271 m .61082 .8146 L .63393 .8042 L p .707 .577 .707 r
F P
0 g
s
.63393 .8042 m .63393 .30231 L .61082 .31271 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81257 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.25312 .78023 m .25312 .7617 L .22195 .7598 L p .707 .577 .707 r
F P
0 g
s
.25312 .7617 m .25312 .78023 L .28495 .77946 L p .707 .577 .707 r
F P
0 g
s
.28495 .77946 m .28495 .76093 L .25312 .7617 L p .707 .577 .707 r
F P
0 g
s
.33839 .6273 m .33839 .68289 L .35476 .67552 L p .707 .577 .707 r
F P
0 g
s
.35476 .67552 m .35476 .61994 L .33839 .6273 L p .707 .577 .707 r
F P
0 g
s
.28495 .76093 m .28495 .77946 L .31434 .77608 L p .707 .577 .707 r
F P
0 g
s
.31434 .77608 m .31434 .75755 L .28495 .76093 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77278 L .22195 .77088 L p .707 .577 .707 r
F P
0 g
s
.25312 .77278 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77278 L p .707 .577 .707 r
F P
0 g
s
.17343 .62436 m .17343 .67995 L .19449 .6864 L p .707 .577 .707 r
F P
0 g
s
.22195 .7598 m .22195 .77833 L .25312 .78023 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80568 L p .707 .577 .707 r
F P
0 g
s
.31434 .80568 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.37794 .81044 m .37794 .30856 L .36016 .29743 L p .707 .577 .707 r
F P
0 g
s
.37794 .30856 m .37794 .81044 L .40766 .81956 L p .707 .577 .707 r
F P
0 g
s
.22195 .77833 m .22195 .7598 L .19449 .75541 L p .707 .577 .707 r
F P
0 g
s
.66831 .62551 m .66831 .68109 L .64085 .6767 L p .707 .577 .707 r
F P
0 g
s
.64085 .6767 m .64085 .62111 L .66831 .62551 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77088 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77088 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.17343 .67995 m .17343 .62436 L .16084 .61648 L p .707 .577 .707 r
F P
0 g
s
.19449 .75541 m .19449 .77394 L .22195 .77833 L p .707 .577 .707 r
F P
0 g
s
.31434 .75755 m .31434 .77608 L .33839 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .77043 m .33839 .7519 L .31434 .75755 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80568 L .33839 .80003 L p .707 .577 .707 r
F P
0 g
s
.33839 .80003 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.68936 .75656 m .68936 .77508 L .66831 .76863 L p .707 .577 .707 r
F P
0 g
s
.66831 .76863 m .66831 .7501 L .68936 .75656 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .77394 m .19449 .75541 L .17343 .74896 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.16084 .61648 m .16084 .67206 L .17343 .67995 L p .707 .577 .707 r
F P
0 g
s
.35476 .61994 m .35476 .67552 L .36184 .66715 L p .707 .577 .707 r
F P
0 g
s
.36184 .66715 m .36184 .61157 L .35476 .61994 L p .707 .577 .707 r
F P
0 g
s
.17343 .74896 m .17343 .76749 L .19449 .77394 L p .707 .577 .707 r
F P
0 g
s
.66831 .7501 m .66831 .76863 L .64085 .76424 L p .707 .577 .707 r
F P
0 g
s
.64085 .76424 m .64085 .74571 L .66831 .7501 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79384 L p .707 .577 .707 r
F P
0 g
s
.64085 .79384 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.63393 .30231 m .63393 .8042 L .64393 .79239 L p .707 .577 .707 r
F P
0 g
s
.64393 .79239 m .64393 .2905 L .63393 .30231 L p .707 .577 .707 r
F P
0 g
s
.33839 .7519 m .33839 .77043 L .35476 .76306 L p .707 .577 .707 r
F P
0 g
s
.35476 .76306 m .35476 .74453 L .33839 .7519 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80003 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.16084 .67206 m .16084 .61648 L .15794 .60794 L p .707 .577 .707 r
F P
0 g
s
.17343 .76749 m .17343 .74896 L .16084 .74107 L p .707 .577 .707 r
F P
0 g
s
.36184 .61157 m .36184 .66715 L .35894 .65861 L p .707 .577 .707 r
F P
0 g
s
.35894 .65861 m .35894 .60303 L .36184 .61157 L p .707 .577 .707 r
F P
0 g
s
.35476 .74453 m .35476 .76306 L .36184 .75469 L p .707 .577 .707 r
F P
0 g
s
.36184 .75469 m .36184 .73617 L .35476 .74453 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.35894 .60303 m .35894 .65861 L .34635 .65073 L p .707 .577 .707 r
F P
0 g
s
.34635 .65073 m .34635 .59515 L .35894 .60303 L p .707 .577 .707 r
F P
0 g
s
.36184 .73617 m .36184 .75469 L .35894 .74615 L p .707 .577 .707 r
F P
0 g
s
.35894 .74615 m .35894 .72762 L .36184 .73617 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .7387 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.36016 .79931 m .36016 .29743 L .35607 .28537 L p .707 .577 .707 r
F P
0 g
s
.36016 .29743 m .36016 .79931 L .37794 .81044 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75215 L p .707 .577 .707 r
F P
0 g
s
.16084 .74107 m .16084 .7596 L .17343 .76749 L p .707 .577 .707 r
F P
0 g
s
.15794 .60794 m .15794 .66352 L .16084 .67206 L p .707 .577 .707 r
F P
0 g
s
.16084 .75215 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.15794 .66352 m .15794 .60794 L .16503 .59957 L p .707 .577 .707 r
F P
0 g
s
.64393 .2905 m .64393 .79239 L .63984 .78033 L p .707 .577 .707 r
F P
0 g
s
.63984 .78033 m .63984 .27844 L .64393 .2905 L p .707 .577 .707 r
F P
0 g
s
.16084 .7596 m .16084 .74107 L .15794 .73253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16084 .78921 m .16084 .75215 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.15794 .73253 m .15794 .75106 L .16084 .7596 L p .707 .577 .707 r
F P
0 g
s
.16503 .59957 m .16503 .65515 L .15794 .66352 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.35894 .72762 m .35894 .74615 L .34635 .73827 L p .707 .577 .707 r
F P
0 g
s
.34635 .73827 m .34635 .71974 L .35894 .72762 L p .707 .577 .707 r
F P
0 g
s
.35894 .7387 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .7387 L p .707 .577 .707 r
F P
0 g
s
.35607 .28537 m .35607 .78725 L .36016 .79931 L p .707 .577 .707 r
F P
0 g
s
.35607 .78725 m .35607 .28537 L .36607 .27356 L p .707 .577 .707 r
F P
0 g
s
.16503 .65515 m .16503 .59957 L .1814 .5922 L p .707 .577 .707 r
F P
0 g
s
.15794 .75106 m .15794 .73253 L .16503 .72417 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .72417 m .16503 .74269 L .15794 .75106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27844 m .63984 .78033 L .62206 .7692 L p .707 .577 .707 r
F P
0 g
s
.62206 .7692 m .62206 .26731 L .63984 .27844 L p .707 .577 .707 r
F P
0 g
s
.1814 .5922 m .1814 .64779 L .16503 .65515 L p .707 .577 .707 r
F P
0 g
s
.34635 .59515 m .34635 .65073 L .3253 .64427 L p .707 .577 .707 r
F P
0 g
s
.3253 .64427 m .3253 .58869 L .34635 .59515 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .64779 m .1814 .5922 L .20545 .58655 L p .707 .577 .707 r
F P
0 g
s
.36607 .77545 m .36607 .27356 L .38918 .26316 L p .707 .577 .707 r
F P
0 g
s
.36607 .27356 m .36607 .77545 L .35607 .78725 L p .707 .577 .707 r
F P
0 g
s
.16503 .74269 m .16503 .72417 L .1814 .7168 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.3253 .58869 m .3253 .64427 L .29784 .63988 L p .707 .577 .707 r
F P
0 g
s
.29784 .63988 m .29784 .5843 L .3253 .58869 L p .707 .577 .707 r
F P
0 g
s
.1814 .7168 m .1814 .73533 L .16503 .74269 L p .707 .577 .707 r
F P
0 g
s
.20545 .58655 m .20545 .64214 L .1814 .64779 L p .707 .577 .707 r
F P
0 g
s
.20545 .64214 m .20545 .58655 L .23483 .58318 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76493 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.34635 .71974 m .34635 .73827 L .3253 .73181 L p .707 .577 .707 r
F P
0 g
s
.3253 .73181 m .3253 .71329 L .34635 .71974 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.62206 .26731 m .62206 .7692 L .59233 .76008 L p .707 .577 .707 r
F P
0 g
s
.59233 .76008 m .59233 .2582 L .62206 .26731 L p .707 .577 .707 r
F P
0 g
s
.29784 .5843 m .29784 .63988 L .26667 .63798 L p .707 .577 .707 r
F P
0 g
s
.26667 .63798 m .26667 .5824 L .29784 .5843 L p .707 .577 .707 r
F P
0 g
s
.23483 .63876 m .23483 .58318 L .26667 .5824 L p .707 .577 .707 r
F P
0 g
s
.23483 .58318 m .23483 .63876 L .20545 .64214 L p .707 .577 .707 r
F P
0 g
s
.1814 .73533 m .1814 .7168 L .20545 .71115 L p .707 .577 .707 r
F P
0 g
s
.26667 .5824 m .26667 .63798 L .23483 .63876 L p .707 .577 .707 r
F P
0 g
s
.73333 .63747 m .73333 .58189 L .70216 .57999 L p .707 .577 .707 r
F P
0 g
s
.73333 .58189 m .73333 .63747 L .76517 .63669 L p .707 .577 .707 r
F P
0 g
s
.76517 .63669 m .76517 .58111 L .73333 .58189 L p .707 .577 .707 r
F P
0 g
s
.1814 .76493 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.76517 .58111 m .76517 .63669 L .79455 .63331 L p .707 .577 .707 r
F P
0 g
s
.79455 .63331 m .79455 .57773 L .76517 .58111 L p .707 .577 .707 r
F P
0 g
s
.20545 .71115 m .20545 .72968 L .1814 .73533 L p .707 .577 .707 r
F P
0 g
s
.38918 .26316 m .38918 .76504 L .36607 .77545 L p .707 .577 .707 r
F P
0 g
s
.38918 .76504 m .38918 .26316 L .42314 .25518 L p .707 .577 .707 r
F P
0 g
s
.70216 .63557 m .70216 .57999 L .6747 .57559 L p .707 .577 .707 r
F P
0 g
s
.70216 .57999 m .70216 .63557 L .73333 .63747 L p .707 .577 .707 r
F P
0 g
s
.3253 .71329 m .3253 .73181 L .29784 .72742 L p .707 .577 .707 r
F P
0 g
s
.29784 .72742 m .29784 .70889 L .3253 .71329 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75928 L .1814 .76493 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71997 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.79455 .57773 m .79455 .63331 L .8186 .62766 L p .707 .577 .707 r
F P
0 g
s
.8186 .62766 m .8186 .57208 L .79455 .57773 L p .707 .577 .707 r
F P
0 g
s
.20545 .72968 m .20545 .71115 L .23483 .70777 L p .707 .577 .707 r
F P
0 g
s
.20545 .75928 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.6747 .57559 m .6747 .63118 L .70216 .63557 L p .707 .577 .707 r
F P
0 g
s
.6747 .63118 m .6747 .57559 L .65365 .56914 L p .707 .577 .707 r
F P
0 g
s
.23483 .70777 m .23483 .7263 L .20545 .72968 L p .707 .577 .707 r
F P
0 g
s
.59233 .2582 m .59233 .76008 L .55357 .75388 L p .707 .577 .707 r
F P
0 g
s
.55357 .75388 m .55357 .25199 L .59233 .2582 L p .707 .577 .707 r
F P
0 g
s
.29784 .70889 m .29784 .72742 L .26667 .72552 L p .707 .577 .707 r
F P
0 g
s
.26667 .72552 m .26667 .70699 L .29784 .70889 L p .707 .577 .707 r
F P
0 g
s
.29784 .71997 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71807 L .29784 .71997 L p .707 .577 .707 r
F P
0 g
s
.23483 .7263 m .23483 .70777 L .26667 .70699 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75928 L p .707 .577 .707 r
F P
0 g
s
.26667 .70699 m .26667 .72552 L .23483 .7263 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71807 L p .707 .577 .707 r
F P
0 g
s
.73333 .72501 m .73333 .70648 L .70216 .70458 L p .707 .577 .707 r
F P
0 g
s
.73333 .70648 m .73333 .72501 L .76517 .72423 L p .707 .577 .707 r
F P
0 g
s
.76517 .72423 m .76517 .7057 L .73333 .70648 L p .707 .577 .707 r
F P
0 g
s
.42314 .75707 m .42314 .25518 L .46462 .25041 L p .707 .577 .707 r
F P
0 g
s
.42314 .25518 m .42314 .75707 L .38918 .76504 L p .707 .577 .707 r
F P
0 g
s
.8186 .57208 m .8186 .62766 L .83497 .6203 L p .707 .577 .707 r
F P
0 g
s
.83497 .6203 m .83497 .56471 L .8186 .57208 L p .707 .577 .707 r
F P
0 g
s
.26667 .71807 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.76517 .7057 m .76517 .72423 L .79455 .72085 L p .707 .577 .707 r
F P
0 g
s
.79455 .72085 m .79455 .70233 L .76517 .7057 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71678 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.65365 .56914 m .65365 .62472 L .6747 .63118 L p .707 .577 .707 r
F P
0 g
s
.70216 .70458 m .70216 .72311 L .73333 .72501 L p .707 .577 .707 r
F P
0 g
s
.76517 .71678 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71678 L p .707 .577 .707 r
F P
0 g
s
.70216 .72311 m .70216 .70458 L .6747 .70019 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.65365 .62472 m .65365 .56914 L .64105 .56126 L p .707 .577 .707 r
F P
0 g
s
.55357 .25199 m .55357 .75388 L .50956 .7512 L p .707 .577 .707 r
F P
0 g
s
.50956 .7512 m .50956 .24931 L .55357 .25199 L p .707 .577 .707 r
F P
0 g
s
.6747 .70019 m .6747 .71872 L .70216 .72311 L p .707 .577 .707 r
F P
0 g
s
.79455 .70233 m .79455 .72085 L .8186 .7152 L p .707 .577 .707 r
F P
0 g
s
.8186 .7152 m .8186 .69668 L .79455 .70233 L p .707 .577 .707 r
F P
0 g
s
.46462 .7523 m .46462 .25041 L .50956 .24931 L p .707 .577 .707 r
F P
0 g
s
.46462 .25041 m .46462 .7523 L .42314 .75707 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74832 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.50956 .24931 m .50956 .7512 L .46462 .7523 L p .707 .577 .707 r
F P
0 g
s
.6747 .71872 m .6747 .70019 L .65365 .69374 L p .707 .577 .707 r
F P
0 g
s
.6747 .74832 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.64105 .56126 m .64105 .61684 L .65365 .62472 L p .707 .577 .707 r
F P
0 g
s
.83497 .56471 m .83497 .6203 L .84205 .61193 L p .707 .577 .707 r
F P
0 g
s
.84205 .61193 m .84205 .55635 L .83497 .56471 L p .707 .577 .707 r
F P
0 g
s
.65365 .69374 m .65365 .71226 L .6747 .71872 L p .707 .577 .707 r
F P
0 g
s
.8186 .69668 m .8186 .7152 L .83497 .70784 L p .707 .577 .707 r
F P
0 g
s
.83497 .70784 m .83497 .68931 L .8186 .69668 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74832 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73744 L p .707 .577 .707 r
F P
0 g
s
.83497 .73744 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.64105 .61684 m .64105 .56126 L .63816 .55271 L p .707 .577 .707 r
F P
0 g
s
.65365 .71226 m .65365 .69374 L .64105 .68585 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .68585 m .64105 .70438 L .65365 .71226 L p .707 .577 .707 r
F P
0 g
s
.63816 .55271 m .63816 .6083 L .64105 .61684 L p .707 .577 .707 r
F P
0 g
s
.84205 .55635 m .84205 .61193 L .83916 .60339 L p .707 .577 .707 r
F P
0 g
s
.83916 .60339 m .83916 .54781 L .84205 .55635 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.83497 .68931 m .83497 .70784 L .84206 .69947 L p .707 .577 .707 r
F P
0 g
s
.84206 .69947 m .84206 .68094 L .83497 .68931 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73744 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69202 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .6083 m .63816 .55271 L .64524 .54435 L p .707 .577 .707 r
F P
0 g
s
.64105 .70438 m .64105 .68585 L .63816 .67731 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.63816 .67731 m .63816 .69584 L .64105 .70438 L p .707 .577 .707 r
F P
0 g
s
.64524 .54435 m .64524 .59993 L .63816 .6083 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72544 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83916 .54781 m .83916 .60339 L .82657 .5955 L p .707 .577 .707 r
F P
0 g
s
.82657 .5955 m .82657 .53992 L .83916 .54781 L p .707 .577 .707 r
F P
0 g
s
.84206 .68094 m .84206 .69947 L .83916 .69093 L p .707 .577 .707 r
F P
0 g
s
.83916 .69093 m .83916 .6724 L .84206 .68094 L p .707 .577 .707 r
F P
0 g
s
.84206 .69202 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69202 L p .707 .577 .707 r
F P
0 g
s
.39032 .60065 m .39032 .54507 L .35915 .54317 L p .707 .577 .707 r
F P
0 g
s
.39032 .54507 m .39032 .60065 L .42216 .59988 L p .707 .577 .707 r
F P
0 g
s
.42216 .59988 m .42216 .54429 L .39032 .54507 L p .707 .577 .707 r
F P
0 g
s
.64524 .59993 m .64524 .54435 L .66161 .53698 L p .707 .577 .707 r
F P
0 g
s
.42216 .54429 m .42216 .59988 L .45154 .5965 L p .707 .577 .707 r
F P
0 g
s
.45154 .5965 m .45154 .54092 L .42216 .54429 L p .707 .577 .707 r
F P
0 g
s
.35915 .59875 m .35915 .54317 L .33169 .53878 L p .707 .577 .707 r
F P
0 g
s
.35915 .54317 m .35915 .59875 L .39032 .60065 L p .707 .577 .707 r
F P
0 g
s
.63816 .69584 m .63816 .67731 L .64524 .66894 L p .707 .577 .707 r
F P
0 g
s
.63816 .72544 m .63816 .68839 L .64524 .68002 L p .707 .577 .707 r
F P
0 g
s
.64524 .66894 m .64524 .68747 L .63816 .69584 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54092 m .45154 .5965 L .47559 .59085 L p .707 .577 .707 r
F P
0 g
s
.47559 .59085 m .47559 .53527 L .45154 .54092 L p .707 .577 .707 r
F P
0 g
s
.66161 .53698 m .66161 .59256 L .64524 .59993 L p .707 .577 .707 r
F P
0 g
s
.82657 .53992 m .82657 .5955 L .80551 .58905 L p .707 .577 .707 r
F P
0 g
s
.80551 .58905 m .80551 .53347 L .82657 .53992 L p .707 .577 .707 r
F P
0 g
s
.64524 .68002 m .64524 .71708 L .63816 .72544 L p .707 .577 .707 r
F P
0 g
s
.33169 .53878 m .33169 .59436 L .35915 .59875 L p .707 .577 .707 r
F P
0 g
s
.33169 .59436 m .33169 .53878 L .31064 .53232 L p .707 .577 .707 r
F P
0 g
s
.83916 .6724 m .83916 .69093 L .82657 .68305 L p .707 .577 .707 r
F P
0 g
s
.82657 .68305 m .82657 .66452 L .83916 .6724 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59256 m .66161 .53698 L .68566 .53133 L p .707 .577 .707 r
F P
0 g
s
.39032 .68819 m .39032 .66967 L .35915 .66777 L p .707 .577 .707 r
F P
0 g
s
.39032 .66967 m .39032 .68819 L .42216 .68742 L p .707 .577 .707 r
F P
0 g
s
.42216 .68742 m .42216 .66889 L .39032 .66967 L p .707 .577 .707 r
F P
0 g
s
.47559 .53527 m .47559 .59085 L .49196 .58348 L p .707 .577 .707 r
F P
0 g
s
.49196 .58348 m .49196 .5279 L .47559 .53527 L p .707 .577 .707 r
F P
0 g
s
.64524 .68747 m .64524 .66894 L .66161 .66158 L p .707 .577 .707 r
F P
0 g
s
.42216 .66889 m .42216 .68742 L .45154 .68404 L p .707 .577 .707 r
F P
0 g
s
.45154 .68404 m .45154 .66551 L .42216 .66889 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71702 L p .707 .577 .707 r
F P
0 g
s
.42216 .71702 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.31064 .53232 m .31064 .58791 L .33169 .59436 L p .707 .577 .707 r
F P
0 g
s
.35915 .66777 m .35915 .68629 L .39032 .68819 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68002 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71702 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .68629 m .35915 .66777 L .33169 .66337 L p .707 .577 .707 r
F P
0 g
s
.80551 .53347 m .80551 .58905 L .77805 .58466 L p .707 .577 .707 r
F P
0 g
s
.77805 .58466 m .77805 .52908 L .80551 .53347 L p .707 .577 .707 r
F P
0 g
s
.66161 .66158 m .66161 .6801 L .64524 .68747 L p .707 .577 .707 r
F P
0 g
s
.68566 .53133 m .68566 .58691 L .66161 .59256 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67445 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.31064 .58791 m .31064 .53232 L .29804 .52444 L p .707 .577 .707 r
F P
0 g
s
.33169 .66337 m .33169 .6819 L .35915 .68629 L p .707 .577 .707 r
F P
0 g
s
.68566 .58691 m .68566 .53133 L .71504 .52795 L p .707 .577 .707 r
F P
0 g
s
.45154 .66551 m .45154 .68404 L .47559 .67839 L p .707 .577 .707 r
F P
0 g
s
.47559 .67839 m .47559 .65986 L .45154 .66551 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.82657 .66452 m .82657 .68305 L .80551 .67659 L p .707 .577 .707 r
F P
0 g
s
.80551 .67659 m .80551 .65806 L .82657 .66452 L p .707 .577 .707 r
F P
0 g
s
.33169 .67445 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66914 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.33169 .6819 m .33169 .66337 L .31064 .65692 L p .707 .577 .707 r
F P
0 g
s
.77805 .52908 m .77805 .58466 L .74688 .58276 L p .707 .577 .707 r
F P
0 g
s
.74688 .58276 m .74688 .52718 L .77805 .52908 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67445 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.29804 .52444 m .29804 .58002 L .31064 .58791 L p .707 .577 .707 r
F P
0 g
s
.71504 .58354 m .71504 .52795 L .74688 .52718 L p .707 .577 .707 r
F P
0 g
s
.71504 .52795 m .71504 .58354 L .68566 .58691 L p .707 .577 .707 r
F P
0 g
s
.49196 .5279 m .49196 .58348 L .49904 .57512 L p .707 .577 .707 r
F P
0 g
s
.49904 .57512 m .49904 .51953 L .49196 .5279 L p .707 .577 .707 r
F P
0 g
s
.31064 .65692 m .31064 .67545 L .33169 .6819 L p .707 .577 .707 r
F P
0 g
s
.66161 .6801 m .66161 .66158 L .68566 .65593 L p .707 .577 .707 r
F P
0 g
s
.74688 .52718 m .74688 .58276 L .71504 .58354 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.68566 .65593 m .68566 .67445 L .66161 .6801 L p .707 .577 .707 r
F P
0 g
s
.47559 .65986 m .47559 .67839 L .49196 .67102 L p .707 .577 .707 r
F P
0 g
s
.49196 .67102 m .49196 .65249 L .47559 .65986 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70505 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66357 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.29804 .58002 m .29804 .52444 L .29515 .5159 L p .707 .577 .707 r
F P
0 g
s
.80551 .65806 m .80551 .67659 L .77805 .6722 L p .707 .577 .707 r
F P
0 g
s
.77805 .6722 m .77805 .65367 L .80551 .65806 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66914 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66914 L p .707 .577 .707 r
F P
0 g
s
.31064 .67545 m .31064 .65692 L .29804 .64904 L p .707 .577 .707 r
F P
0 g
s
.31064 .70505 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.68566 .67445 m .68566 .65593 L .71504 .65255 L p .707 .577 .707 r
F P
0 g
s
.29804 .64904 m .29804 .66756 L .31064 .67545 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.71504 .65255 m .71504 .67108 L .68566 .67445 L p .707 .577 .707 r
F P
0 g
s
.29515 .5159 m .29515 .57148 L .29804 .58002 L p .707 .577 .707 r
F P
0 g
s
.49904 .51953 m .49904 .57512 L .49615 .56657 L p .707 .577 .707 r
F P
0 g
s
.49615 .56657 m .49615 .51099 L .49904 .51953 L p .707 .577 .707 r
F P
0 g
s
.77805 .65367 m .77805 .6722 L .74688 .6703 L p .707 .577 .707 r
F P
0 g
s
.74688 .6703 m .74688 .65177 L .77805 .65367 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70505 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.71504 .67108 m .71504 .65255 L .74688 .65177 L p .707 .577 .707 r
F P
0 g
s
.49196 .65249 m .49196 .67102 L .49904 .66266 L p .707 .577 .707 r
F P
0 g
s
.49904 .66266 m .49904 .64413 L .49196 .65249 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.74688 .65177 m .74688 .6703 L .71504 .67108 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66357 m .49196 .70063 L .49904 .69226 L p .707 .577 .707 r
F P
0 g
s
.49904 .69226 m .49904 .65521 L .49196 .66357 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.29515 .57148 m .29515 .5159 L .30223 .50753 L p .707 .577 .707 r
F P
0 g
s
.29804 .66756 m .29804 .64904 L .29515 .64049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29804 .69717 m .29804 .66012 L .29515 .65157 L p .707 .577 .707 r
F P
0 g
s
.29515 .64049 m .29515 .65902 L .29804 .66756 L p .707 .577 .707 r
F P
0 g
s
.30223 .50753 m .30223 .56312 L .29515 .57148 L p .707 .577 .707 r
F P
0 g
s
.29515 .65157 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.49615 .51099 m .49615 .56657 L .48356 .55869 L p .707 .577 .707 r
F P
0 g
s
.48356 .55869 m .48356 .50311 L .49615 .51099 L p .707 .577 .707 r
F P
0 g
s
.49904 .64413 m .49904 .66266 L .49615 .65411 L p .707 .577 .707 r
F P
0 g
s
.49615 .65411 m .49615 .63559 L .49904 .64413 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69226 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .56312 m .30223 .50753 L .3186 .50017 L p .707 .577 .707 r
F P
0 g
s
.29515 .65902 m .29515 .64049 L .30223 .63213 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65157 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .63213 m .30223 .65066 L .29515 .65902 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .50017 m .3186 .55575 L .30223 .56312 L p .707 .577 .707 r
F P
0 g
s
.48356 .50311 m .48356 .55869 L .4625 .55224 L p .707 .577 .707 r
F P
0 g
s
.4625 .55224 m .4625 .49665 L .48356 .50311 L p .707 .577 .707 r
F P
0 g
s
.30223 .64321 m .30223 .68026 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49615 .63559 m .49615 .65411 L .48356 .64623 L p .707 .577 .707 r
F P
0 g
s
.48356 .64623 m .48356 .6277 L .49615 .63559 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55575 m .3186 .50017 L .34265 .49452 L p .707 .577 .707 r
F P
0 g
s
.30223 .65066 m .30223 .63213 L .3186 .62476 L p .707 .577 .707 r
F P
0 g
s
.30223 .68026 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.4625 .49665 m .4625 .55224 L .43504 .54784 L p .707 .577 .707 r
F P
0 g
s
.43504 .54784 m .43504 .49226 L .4625 .49665 L p .707 .577 .707 r
F P
0 g
s
.3186 .62476 m .3186 .64329 L .30223 .65066 L p .707 .577 .707 r
F P
0 g
s
.34265 .49452 m .34265 .5501 L .3186 .55575 L p .707 .577 .707 r
F P
0 g
s
.34265 .5501 m .34265 .49452 L .37203 .49114 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68026 L p .707 .577 .707 r
F P
0 g
s
.48356 .6277 m .48356 .64623 L .4625 .63978 L p .707 .577 .707 r
F P
0 g
s
.4625 .63978 m .4625 .62125 L .48356 .6277 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66938 L p .707 .577 .707 r
F P
0 g
s
.4625 .66938 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.43504 .49226 m .43504 .54784 L .40387 .54594 L p .707 .577 .707 r
F P
0 g
s
.40387 .54594 m .40387 .49036 L .43504 .49226 L p .707 .577 .707 r
F P
0 g
s
.37203 .54672 m .37203 .49114 L .40387 .49036 L p .707 .577 .707 r
F P
0 g
s
.37203 .49114 m .37203 .54672 L .34265 .5501 L p .707 .577 .707 r
F P
0 g
s
.3186 .64329 m .3186 .62476 L .34265 .61911 L p .707 .577 .707 r
F P
0 g
s
.40387 .49036 m .40387 .54594 L .37203 .54672 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.34265 .61911 m .34265 .63764 L .3186 .64329 L p .707 .577 .707 r
F P
0 g
s
.4625 .62125 m .4625 .63978 L .43504 .63538 L p .707 .577 .707 r
F P
0 g
s
.43504 .63538 m .43504 .61686 L .4625 .62125 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66938 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.34265 .63764 m .34265 .61911 L .37203 .61573 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.37203 .61573 m .37203 .63426 L .34265 .63764 L p .707 .577 .707 r
F P
0 g
s
.43504 .61686 m .43504 .63538 L .40387 .63348 L p .707 .577 .707 r
F P
0 g
s
.40387 .63348 m .40387 .61496 L .43504 .61686 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.37203 .63426 m .37203 .61573 L .40387 .61496 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.40387 .61496 m .40387 .63348 L .37203 .63426 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo002;Ool<0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<0
00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001^Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo2@00A7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<005YFFUH00UYF2000?7oo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool003mooa4000Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH5
0004FUH01000FUIJEUYF0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF100025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH8000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUHK0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH900000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00T000AJEP03
001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUHF0004FUH00`00FUIJ
EP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60004FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP<000AJEP03001JEUYF009J
EP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800004FUH005YF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL00005FUH005YFFUH00003FUH20000
0eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo4P00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH01000FUH005YF0P000eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00002FUH00`00FUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH00003FUH30002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`04001JEP00FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH01@00FUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol002aoo`06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF00000P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00003000jOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP<000AJEP03001JEUYF00IJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@0039o
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF0P00<Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEP0000<000IJEP04001JEUYFFUHC
0002FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEP0000=JEP03001JEUYF009JEP<00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUH00000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EP<00003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH20004FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP02FUH00`00Oomoo`0/Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP06001JEP00FUH005YF0P0000=JEP00FUH00UYF
00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=J
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF
00000UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<007ooOol0;7oo000`Ool30004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P0000AJEP00FUIJEP@000EJEP<000EJEQ40
00=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YF00000`000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool003Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30000
0eYF000000090005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000kOolJ0003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Egoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHN0003FUH50004FUH01000FUIJEUYF
0P00;Goo000oOolI0002Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP8002eoo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPX000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003
FUH30003FUH2000]Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003Ool0000000H000AJEP03001JEUYF00=JEPT000MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000800006FUH00000001JEP001EYF0`0025YF100000=JEP0000001`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUHF
0004FUH00`00FUIJEP02FUH20002Ool01@00FUIJEP00FUH02P0015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P0000=JEP00000015YF00<005YFFUH00eYF200015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000^Ool20003FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD00004FUH000000004
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJ
EP<000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000800005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`04001JEP000003FUH00`00FUH0000300000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00@005YF001J
EP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00@005YF000000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000cOol002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004Ool30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50002Ool40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF
2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P000goo6@00
?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH6000AOol80004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF1P000UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000eYF
00<005YFFUH00UYF0P00FGoo000/Ool00`00FUH00004FUH00`00FUH000030004FUHI0002FUH60004
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF1@00
15YF0`00Egoo000/Ool00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH0000500001EYF001JEUYF00000UYF00<005YFFUH00eYF0`000UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P0000AJEP00FUIJEP8005Eoo`00;7oo00@0
05YF001JEP<000AJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50005FUH30002FUH01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00001EYF00<005YFFUH0
0UYF0P000eYF00<007ooOol0Dgoo000/Ool01`00FUH00000FUH005YF00<00003FUH005YF00AJEP<0
00AJEQ8000=JEP03001JEUYF00AJEP03001JEUYF00<0009JEP04001JEP000007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF00<005YF00001EYF00<005YFFUH00eYF0`0000=JEP000000E7oo000/Ool20003FUH00`00
FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH0
15YF00<005YFFUH00eYF00<005YFFUH00`00E7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF1@0000=JEP0000002@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF0000009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP0000=JEPD000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Aoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Ao
o`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00
27oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001EYF00<005YF00000`0000AJEP000000
00=JEP8005Aoo`00>goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@003Woo0`001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUIJEP/000EJEP04001JEUYF0002FUH2001DOol004=ooa<001Eoo`8000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001J
EP001eYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00E7oo001_Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol0079oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Aoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH01P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo0025OolF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002AOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000F7oo002BOol30003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Eoo`D000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00VWoo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002NOolI001VOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .71715 m .59613 .66157 L .56496 .65967 L p .707 .577 .707 r
F P
0 g
s
.59613 .66157 m .59613 .71715 L .62796 .71638 L p .707 .577 .707 r
F P
0 g
s
.62796 .71638 m .62796 .66079 L .59613 .66157 L p .707 .577 .707 r
F P
0 g
s
.62796 .66079 m .62796 .71638 L .65734 .713 L p .707 .577 .707 r
F P
0 g
s
.65734 .713 m .65734 .65742 L .62796 .66079 L p .707 .577 .707 r
F P
0 g
s
.56496 .71525 m .56496 .65967 L .5375 .65528 L p .707 .577 .707 r
F P
0 g
s
.56496 .65967 m .56496 .71525 L .59613 .71715 L p .707 .577 .707 r
F P
0 g
s
.65734 .65742 m .65734 .713 L .6814 .70735 L p .707 .577 .707 r
F P
0 g
s
.6814 .70735 m .6814 .65177 L .65734 .65742 L p .707 .577 .707 r
F P
0 g
s
.5375 .65528 m .5375 .71086 L .56496 .71525 L p .707 .577 .707 r
F P
0 g
s
.5375 .71086 m .5375 .65528 L .51644 .64883 L p .707 .577 .707 r
F P
0 g
s
.59613 .79564 m .59613 .77711 L .56496 .77521 L p .707 .577 .707 r
F P
0 g
s
.59613 .77711 m .59613 .79564 L .62796 .79486 L p .707 .577 .707 r
F P
0 g
s
.62796 .79486 m .62796 .77633 L .59613 .77711 L p .707 .577 .707 r
F P
0 g
s
.62796 .77633 m .62796 .79486 L .65735 .79148 L p .707 .577 .707 r
F P
0 g
s
.65735 .79148 m .65735 .77295 L .62796 .77633 L p .707 .577 .707 r
F P
0 g
s
.6814 .65177 m .6814 .70735 L .69777 .69998 L p .707 .577 .707 r
F P
0 g
s
.69777 .69998 m .69777 .6444 L .6814 .65177 L p .707 .577 .707 r
F P
0 g
s
.56496 .77521 m .56496 .79373 L .59613 .79564 L p .707 .577 .707 r
F P
0 g
s
.51644 .64883 m .51644 .70441 L .5375 .71086 L p .707 .577 .707 r
F P
0 g
s
.56496 .79373 m .56496 .77521 L .5375 .77082 L p .707 .577 .707 r
F P
0 g
s
.5375 .77082 m .5375 .78934 L .56496 .79373 L p .707 .577 .707 r
F P
0 g
s
.51644 .70441 m .51644 .64883 L .50385 .64094 L p .707 .577 .707 r
F P
0 g
s
.65735 .77295 m .65735 .79148 L .6814 .78583 L p .707 .577 .707 r
F P
0 g
s
.6814 .78583 m .6814 .7673 L .65735 .77295 L p .707 .577 .707 r
F P
0 g
s
.59613 .8694 m .59613 .83234 L .56496 .83044 L p .707 .577 .707 r
F P
0 g
s
.59613 .83234 m .59613 .8694 L .62796 .86862 L p .707 .577 .707 r
F P
0 g
s
.62796 .86862 m .62796 .83156 L .59613 .83234 L p .707 .577 .707 r
F P
0 g
s
.62796 .83156 m .62796 .86862 L .65735 .86524 L p .707 .577 .707 r
F P
0 g
s
.65735 .86524 m .65735 .82819 L .62796 .83156 L p .707 .577 .707 r
F P
0 g
s
.56496 .8675 m .56496 .83044 L .5375 .82605 L p .707 .577 .707 r
F P
0 g
s
.56496 .83044 m .56496 .8675 L .59613 .8694 L p .707 .577 .707 r
F P
0 g
s
.5375 .78934 m .5375 .77082 L .51644 .76436 L p .707 .577 .707 r
F P
0 g
s
.51644 .76436 m .51644 .78289 L .5375 .78934 L p .707 .577 .707 r
F P
0 g
s
.50385 .64094 m .50385 .69652 L .51644 .70441 L p .707 .577 .707 r
F P
0 g
s
.69777 .6444 m .69777 .69998 L .70485 .69162 L p .707 .577 .707 r
F P
0 g
s
.70485 .69162 m .70485 .63603 L .69777 .6444 L p .707 .577 .707 r
F P
0 g
s
.65735 .82819 m .65735 .86524 L .6814 .85959 L p .707 .577 .707 r
F P
0 g
s
.6814 .85959 m .6814 .82254 L .65735 .82819 L p .707 .577 .707 r
F P
0 g
s
.5375 .82605 m .5375 .8631 L .56496 .8675 L p .707 .577 .707 r
F P
0 g
s
.6814 .7673 m .6814 .78583 L .69777 .77846 L p .707 .577 .707 r
F P
0 g
s
.69777 .77846 m .69777 .75993 L .6814 .7673 L p .707 .577 .707 r
F P
0 g
s
.5375 .8631 m .5375 .82605 L .51644 .81959 L p .707 .577 .707 r
F P
0 g
s
.50385 .69652 m .50385 .64094 L .50095 .6324 L p .707 .577 .707 r
F P
0 g
s
.51644 .78289 m .51644 .76436 L .50385 .75648 L p .707 .577 .707 r
F P
0 g
s
.51644 .81959 m .51644 .85665 L .5375 .8631 L p .707 .577 .707 r
F P
0 g
s
.6814 .82254 m .6814 .85959 L .69777 .85222 L p .707 .577 .707 r
F P
0 g
s
.69777 .85222 m .69777 .81517 L .6814 .82254 L p .707 .577 .707 r
F P
0 g
s
.50385 .75648 m .50385 .775 L .51644 .78289 L p .707 .577 .707 r
F P
0 g
s
.50095 .6324 m .50095 .68798 L .50385 .69652 L p .707 .577 .707 r
F P
0 g
s
.70485 .63603 m .70485 .69162 L .70195 .68307 L p .707 .577 .707 r
F P
0 g
s
.70195 .68307 m .70195 .62749 L .70485 .63603 L p .707 .577 .707 r
F P
0 g
s
.51644 .85665 m .51644 .81959 L .50385 .81171 L p .707 .577 .707 r
F P
0 g
s
.69777 .75993 m .69777 .77846 L .70485 .7701 L p .707 .577 .707 r
F P
0 g
s
.70485 .7701 m .70485 .75157 L .69777 .75993 L p .707 .577 .707 r
F P
0 g
s
.50385 .81171 m .50385 .84877 L .51644 .85665 L p .707 .577 .707 r
F P
0 g
s
.50095 .68798 m .50095 .6324 L .50804 .62403 L p .707 .577 .707 r
F P
0 g
s
.50385 .775 m .50385 .75648 L .50095 .74794 L p .707 .577 .707 r
F P
0 g
s
.69777 .81517 m .69777 .85222 L .70485 .84386 L p .707 .577 .707 r
F P
0 g
s
.70485 .84386 m .70485 .8068 L .69777 .81517 L p .707 .577 .707 r
F P
0 g
s
.50095 .74794 m .50095 .76646 L .50385 .775 L p .707 .577 .707 r
F P
0 g
s
.49044 .83252 m .49044 .33063 L .44643 .32795 L p .707 .577 .707 r
F P
0 g
s
.50804 .62403 m .50804 .67962 L .50095 .68798 L p .707 .577 .707 r
F P
0 g
s
.50385 .84877 m .50385 .81171 L .50095 .80317 L p .707 .577 .707 r
F P
0 g
s
.50095 .80317 m .50095 .84022 L .50385 .84877 L p .707 .577 .707 r
F P
0 g
s
.50804 .67962 m .50804 .62403 L .5244 .61667 L p .707 .577 .707 r
F P
0 g
s
.50095 .76646 m .50095 .74794 L .50804 .73957 L p .707 .577 .707 r
F P
0 g
s
.50804 .73957 m .50804 .7581 L .50095 .76646 L p .707 .577 .707 r
F P
0 g
s
.5244 .61667 m .5244 .67225 L .50804 .67962 L p .707 .577 .707 r
F P
0 g
s
.50095 .84022 m .50095 .80317 L .50804 .7948 L p .707 .577 .707 r
F P
0 g
s
.50804 .7948 m .50804 .83186 L .50095 .84022 L p .707 .577 .707 r
F P
0 g
s
.50804 .7581 m .50804 .73957 L .5244 .7322 L p .707 .577 .707 r
F P
0 g
s
.5244 .7322 m .5244 .75073 L .50804 .7581 L p .707 .577 .707 r
F P
0 g
s
.50804 .83186 m .50804 .7948 L .5244 .78744 L p .707 .577 .707 r
F P
0 g
s
.5244 .78744 m .5244 .82449 L .50804 .83186 L p .707 .577 .707 r
F P
0 g
s
.5244 .75073 m .5244 .7322 L .54846 .72655 L p .707 .577 .707 r
F P
0 g
s
.54846 .72655 m .54846 .74508 L .5244 .75073 L p .707 .577 .707 r
F P
0 g
s
.5244 .82449 m .5244 .78744 L .54846 .78179 L p .707 .577 .707 r
F P
0 g
s
.54846 .78179 m .54846 .81884 L .5244 .82449 L p .707 .577 .707 r
F P
0 g
s
.49044 .33063 m .49044 .83252 L .53538 .83142 L p .707 .577 .707 r
F P
0 g
s
.5244 .67225 m .5244 .61667 L .54846 .61102 L p .707 .577 .707 r
F P
0 g
s
.54846 .61102 m .54846 .6666 L .5244 .67225 L p .707 .577 .707 r
F P
0 g
s
.53538 .83142 m .53538 .32954 L .49044 .33063 L p .707 .577 .707 r
F P
0 g
s
.54846 .6666 m .54846 .61102 L .57784 .60764 L p .707 .577 .707 r
F P
0 g
s
.57784 .60764 m .57784 .66322 L .54846 .6666 L p .707 .577 .707 r
F P
0 g
s
.54846 .74508 m .54846 .72655 L .57784 .72317 L p .707 .577 .707 r
F P
0 g
s
.57784 .72317 m .57784 .7417 L .54846 .74508 L p .707 .577 .707 r
F P
0 g
s
.54846 .81884 m .54846 .78179 L .57784 .77841 L p .707 .577 .707 r
F P
0 g
s
.57784 .77841 m .57784 .81546 L .54846 .81884 L p .707 .577 .707 r
F P
0 g
s
.53538 .32954 m .53538 .83142 L .57686 .82665 L p .707 .577 .707 r
F P
0 g
s
.57686 .82665 m .57686 .32476 L .53538 .32954 L p .707 .577 .707 r
F P
0 g
s
.70195 .62749 m .70195 .68307 L .68936 .67519 L p .707 .577 .707 r
F P
0 g
s
.68936 .67519 m .68936 .61961 L .70195 .62749 L p .707 .577 .707 r
F P
0 g
s
.44643 .82984 m .44643 .32795 L .40766 .32175 L p .707 .577 .707 r
F P
0 g
s
.44643 .32795 m .44643 .82984 L .49044 .83252 L p .707 .577 .707 r
F P
0 g
s
.70485 .75157 m .70485 .7701 L .70195 .76156 L p .707 .577 .707 r
F P
0 g
s
.70195 .76156 m .70195 .74303 L .70485 .75157 L p .707 .577 .707 r
F P
0 g
s
.25312 .68034 m .25312 .62476 L .22195 .62286 L p .707 .577 .707 r
F P
0 g
s
.25312 .62476 m .25312 .68034 L .28495 .67956 L p .707 .577 .707 r
F P
0 g
s
.28495 .67956 m .28495 .62398 L .25312 .62476 L p .707 .577 .707 r
F P
0 g
s
.57784 .66322 m .57784 .60764 L .60968 .60686 L p .707 .577 .707 r
F P
0 g
s
.60968 .60686 m .60968 .66244 L .57784 .66322 L p .707 .577 .707 r
F P
0 g
s
.57784 .7417 m .57784 .72317 L .60968 .7224 L p .707 .577 .707 r
F P
0 g
s
.60968 .7224 m .60968 .74092 L .57784 .7417 L p .707 .577 .707 r
F P
0 g
s
.64085 .77953 m .64085 .81659 L .60968 .81469 L p .707 .577 .707 r
F P
0 g
s
.60968 .81469 m .60968 .77763 L .64085 .77953 L p .707 .577 .707 r
F P
0 g
s
.57784 .81546 m .57784 .77841 L .60968 .77763 L p .707 .577 .707 r
F P
0 g
s
.60968 .77763 m .60968 .81469 L .57784 .81546 L p .707 .577 .707 r
F P
0 g
s
.57686 .32476 m .57686 .82665 L .61082 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .60876 m .64085 .66434 L .60968 .66244 L p .707 .577 .707 r
F P
0 g
s
.60968 .66244 m .60968 .60686 L .64085 .60876 L p .707 .577 .707 r
F P
0 g
s
.64085 .7243 m .64085 .74283 L .60968 .74092 L p .707 .577 .707 r
F P
0 g
s
.60968 .74092 m .60968 .7224 L .64085 .7243 L p .707 .577 .707 r
F P
0 g
s
.61082 .81868 m .61082 .31679 L .57686 .32476 L p .707 .577 .707 r
F P
0 g
s
.28495 .62398 m .28495 .67956 L .31434 .67618 L p .707 .577 .707 r
F P
0 g
s
.31434 .67618 m .31434 .6206 L .28495 .62398 L p .707 .577 .707 r
F P
0 g
s
.22195 .67844 m .22195 .62286 L .19449 .61846 L p .707 .577 .707 r
F P
0 g
s
.22195 .62286 m .22195 .67844 L .25312 .68034 L p .707 .577 .707 r
F P
0 g
s
.70485 .8068 m .70485 .84386 L .70195 .83532 L p .707 .577 .707 r
F P
0 g
s
.70195 .83532 m .70195 .79826 L .70485 .8068 L p .707 .577 .707 r
F P
0 g
s
.40766 .82364 m .40766 .32175 L .37794 .31264 L p .707 .577 .707 r
F P
0 g
s
.40766 .32175 m .40766 .82364 L .44643 .82984 L p .707 .577 .707 r
F P
0 g
s
.31434 .6206 m .31434 .67618 L .33839 .67053 L p .707 .577 .707 r
F P
0 g
s
.33839 .67053 m .33839 .61495 L .31434 .6206 L p .707 .577 .707 r
F P
0 g
s
.68936 .61961 m .68936 .67519 L .66831 .66874 L p .707 .577 .707 r
F P
0 g
s
.66831 .66874 m .66831 .61315 L .68936 .61961 L p .707 .577 .707 r
F P
0 g
s
.19449 .61846 m .19449 .67405 L .22195 .67844 L p .707 .577 .707 r
F P
0 g
s
.70195 .74303 m .70195 .76156 L .68936 .75367 L p .707 .577 .707 r
F P
0 g
s
.68936 .75367 m .68936 .73514 L .70195 .74303 L p .707 .577 .707 r
F P
0 g
s
.19449 .67405 m .19449 .61846 L .17343 .61201 L p .707 .577 .707 r
F P
0 g
s
.61082 .31679 m .61082 .81868 L .63393 .80828 L p .707 .577 .707 r
F P
0 g
s
.63393 .80828 m .63393 .30639 L .61082 .31679 L p .707 .577 .707 r
F P
0 g
s
.25312 .75882 m .25312 .74029 L .22195 .73839 L p .707 .577 .707 r
F P
0 g
s
.25312 .74029 m .25312 .75882 L .28495 .75804 L p .707 .577 .707 r
F P
0 g
s
.28495 .75804 m .28495 .73952 L .25312 .74029 L p .707 .577 .707 r
F P
0 g
s
.28495 .73952 m .28495 .75804 L .31434 .75466 L p .707 .577 .707 r
F P
0 g
s
.31434 .75466 m .31434 .73614 L .28495 .73952 L p .707 .577 .707 r
F P
0 g
s
.33839 .61495 m .33839 .67053 L .35476 .66317 L p .707 .577 .707 r
F P
0 g
s
.35476 .66317 m .35476 .60758 L .33839 .61495 L p .707 .577 .707 r
F P
0 g
s
.22195 .73839 m .22195 .75692 L .25312 .75882 L p .707 .577 .707 r
F P
0 g
s
.70195 .79826 m .70195 .83532 L .68936 .82743 L p .707 .577 .707 r
F P
0 g
s
.68936 .82743 m .68936 .79038 L .70195 .79826 L p .707 .577 .707 r
F P
0 g
s
.17343 .61201 m .17343 .66759 L .19449 .67405 L p .707 .577 .707 r
F P
0 g
s
.22195 .75692 m .22195 .73839 L .19449 .734 L p .707 .577 .707 r
F P
0 g
s
.66831 .61315 m .66831 .66874 L .64085 .66434 L p .707 .577 .707 r
F P
0 g
s
.64085 .66434 m .64085 .60876 L .66831 .61315 L p .707 .577 .707 r
F P
0 g
s
.19449 .734 m .19449 .75253 L .22195 .75692 L p .707 .577 .707 r
F P
0 g
s
.17343 .66759 m .17343 .61201 L .16084 .60413 L p .707 .577 .707 r
F P
0 g
s
.37794 .81452 m .37794 .31264 L .36016 .30151 L p .707 .577 .707 r
F P
0 g
s
.37794 .31264 m .37794 .81452 L .40766 .82364 L p .707 .577 .707 r
F P
0 g
s
.31434 .73614 m .31434 .75466 L .33839 .74901 L p .707 .577 .707 r
F P
0 g
s
.33839 .74901 m .33839 .73049 L .31434 .73614 L p .707 .577 .707 r
F P
0 g
s
.25312 .83258 m .25312 .79553 L .22195 .79363 L p .707 .577 .707 r
F P
0 g
s
.25312 .79553 m .25312 .83258 L .28495 .8318 L p .707 .577 .707 r
F P
0 g
s
.28495 .8318 m .28495 .79475 L .25312 .79553 L p .707 .577 .707 r
F P
0 g
s
.28495 .79475 m .28495 .8318 L .31434 .82843 L p .707 .577 .707 r
F P
0 g
s
.31434 .82843 m .31434 .79137 L .28495 .79475 L p .707 .577 .707 r
F P
0 g
s
.68936 .73514 m .68936 .75367 L .66831 .74722 L p .707 .577 .707 r
F P
0 g
s
.66831 .74722 m .66831 .72869 L .68936 .73514 L p .707 .577 .707 r
F P
0 g
s
.22195 .83068 m .22195 .79363 L .19449 .78923 L p .707 .577 .707 r
F P
0 g
s
.22195 .79363 m .22195 .83068 L .25312 .83258 L p .707 .577 .707 r
F P
0 g
s
.19449 .75253 m .19449 .734 L .17343 .72755 L p .707 .577 .707 r
F P
0 g
s
.17343 .72755 m .17343 .74607 L .19449 .75253 L p .707 .577 .707 r
F P
0 g
s
.16084 .60413 m .16084 .65971 L .17343 .66759 L p .707 .577 .707 r
F P
0 g
s
.35476 .60758 m .35476 .66317 L .36184 .6548 L p .707 .577 .707 r
F P
0 g
s
.36184 .6548 m .36184 .59922 L .35476 .60758 L p .707 .577 .707 r
F P
0 g
s
.31434 .79137 m .31434 .82843 L .33839 .82278 L p .707 .577 .707 r
F P
0 g
s
.33839 .82278 m .33839 .78572 L .31434 .79137 L p .707 .577 .707 r
F P
0 g
s
.19449 .78923 m .19449 .82629 L .22195 .83068 L p .707 .577 .707 r
F P
0 g
s
.68936 .79038 m .68936 .82743 L .66831 .82098 L p .707 .577 .707 r
F P
0 g
s
.66831 .82098 m .66831 .78392 L .68936 .79038 L p .707 .577 .707 r
F P
0 g
s
.33839 .73049 m .33839 .74901 L .35476 .74165 L p .707 .577 .707 r
F P
0 g
s
.35476 .74165 m .35476 .72312 L .33839 .73049 L p .707 .577 .707 r
F P
0 g
s
.66831 .72869 m .66831 .74722 L .64085 .74283 L p .707 .577 .707 r
F P
0 g
s
.64085 .74283 m .64085 .7243 L .66831 .72869 L p .707 .577 .707 r
F P
0 g
s
.64085 .81659 m .64085 .77953 L .66831 .78392 L p .707 .577 .707 r
F P
0 g
s
.63393 .30639 m .63393 .80828 L .64393 .79647 L p .707 .577 .707 r
F P
0 g
s
.64393 .79647 m .64393 .29458 L .63393 .30639 L p .707 .577 .707 r
F P
0 g
s
.19449 .82629 m .19449 .78923 L .17343 .78278 L p .707 .577 .707 r
F P
0 g
s
.16084 .65971 m .16084 .60413 L .15794 .59558 L p .707 .577 .707 r
F P
0 g
s
.17343 .74607 m .17343 .72755 L .16084 .71966 L p .707 .577 .707 r
F P
0 g
s
.17343 .78278 m .17343 .81983 L .19449 .82629 L p .707 .577 .707 r
F P
0 g
s
.33839 .78572 m .33839 .82278 L .35476 .81541 L p .707 .577 .707 r
F P
0 g
s
.35476 .81541 m .35476 .77835 L .33839 .78572 L p .707 .577 .707 r
F P
0 g
s
.16084 .71966 m .16084 .73819 L .17343 .74607 L p .707 .577 .707 r
F P
0 g
s
.36184 .59922 m .36184 .6548 L .35894 .64626 L p .707 .577 .707 r
F P
0 g
s
.35894 .64626 m .35894 .59068 L .36184 .59922 L p .707 .577 .707 r
F P
0 g
s
.35476 .72312 m .35476 .74165 L .36184 .73328 L p .707 .577 .707 r
F P
0 g
s
.36184 .73328 m .36184 .71476 L .35476 .72312 L p .707 .577 .707 r
F P
0 g
s
.35476 .77835 m .35476 .81541 L .36184 .80704 L p .707 .577 .707 r
F P
0 g
s
.36184 .80704 m .36184 .76999 L .35476 .77835 L p .707 .577 .707 r
F P
0 g
s
.35894 .59068 m .35894 .64626 L .34635 .63837 L p .707 .577 .707 r
F P
0 g
s
.34635 .63837 m .34635 .58279 L .35894 .59068 L p .707 .577 .707 r
F P
0 g
s
.36184 .71476 m .36184 .73328 L .35894 .72474 L p .707 .577 .707 r
F P
0 g
s
.35894 .72474 m .35894 .70621 L .36184 .71476 L p .707 .577 .707 r
F P
0 g
s
.36184 .76999 m .36184 .80704 L .35894 .7985 L p .707 .577 .707 r
F P
0 g
s
.35894 .7985 m .35894 .76145 L .36184 .76999 L p .707 .577 .707 r
F P
0 g
s
.36016 .80339 m .36016 .30151 L .35607 .28945 L p .707 .577 .707 r
F P
0 g
s
.36016 .30151 m .36016 .80339 L .37794 .81452 L p .707 .577 .707 r
F P
0 g
s
.66831 .78392 m .66831 .82098 L .64085 .81659 L p .707 .577 .707 r
F P
0 g
s
.15794 .59558 m .15794 .65117 L .16084 .65971 L p .707 .577 .707 r
F P
0 g
s
.17343 .81983 m .17343 .78278 L .16084 .7749 L p .707 .577 .707 r
F P
0 g
s
.16084 .7749 m .16084 .81195 L .17343 .81983 L p .707 .577 .707 r
F P
0 g
s
.15794 .65117 m .15794 .59558 L .16503 .58722 L p .707 .577 .707 r
F P
0 g
s
.16084 .73819 m .16084 .71966 L .15794 .71112 L p .707 .577 .707 r
F P
0 g
s
.64393 .29458 m .64393 .79647 L .63984 .78441 L p .707 .577 .707 r
F P
0 g
s
.63984 .78441 m .63984 .28252 L .64393 .29458 L p .707 .577 .707 r
F P
0 g
s
.15794 .71112 m .15794 .72965 L .16084 .73819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .58722 m .16503 .6428 L .15794 .65117 L p .707 .577 .707 r
F P
0 g
s
.16084 .81195 m .16084 .7749 L .15794 .76635 L p .707 .577 .707 r
F P
0 g
s
.35894 .70621 m .35894 .72474 L .34635 .71686 L p .707 .577 .707 r
F P
0 g
s
.34635 .71686 m .34635 .69833 L .35894 .70621 L p .707 .577 .707 r
F P
0 g
s
.35894 .76145 m .35894 .7985 L .34635 .79062 L p .707 .577 .707 r
F P
0 g
s
.34635 .79062 m .34635 .75356 L .35894 .76145 L p .707 .577 .707 r
F P
0 g
s
.35607 .28945 m .35607 .79133 L .36016 .80339 L p .707 .577 .707 r
F P
0 g
s
.35607 .79133 m .35607 .28945 L .36607 .27764 L p .707 .577 .707 r
F P
0 g
s
.15794 .76635 m .15794 .80341 L .16084 .81195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .6428 m .16503 .58722 L .1814 .57985 L p .707 .577 .707 r
F P
0 g
s
.15794 .72965 m .15794 .71112 L .16503 .70276 L p .707 .577 .707 r
F P
0 g
s
.16503 .70276 m .16503 .72128 L .15794 .72965 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .57985 m .1814 .63543 L .16503 .6428 L p .707 .577 .707 r
F P
0 g
s
.34635 .58279 m .34635 .63837 L .3253 .63192 L p .707 .577 .707 r
F P
0 g
s
.3253 .63192 m .3253 .57634 L .34635 .58279 L p .707 .577 .707 r
F P
0 g
s
.15794 .80341 m .15794 .76635 L .16503 .75799 L p .707 .577 .707 r
F P
0 g
s
.63984 .28252 m .63984 .78441 L .62206 .77328 L p .707 .577 .707 r
F P
0 g
s
.62206 .77328 m .62206 .27139 L .63984 .28252 L p .707 .577 .707 r
F P
0 g
s
.1814 .63543 m .1814 .57985 L .20545 .5742 L p .707 .577 .707 r
F P
0 g
s
.16503 .75799 m .16503 .79504 L .15794 .80341 L p .707 .577 .707 r
F P
0 g
s
.16503 .72128 m .16503 .70276 L .1814 .69539 L p .707 .577 .707 r
F P
0 g
s
.36607 .77953 m .36607 .27764 L .38918 .26724 L p .707 .577 .707 r
F P
0 g
s
.36607 .27764 m .36607 .77953 L .35607 .79133 L p .707 .577 .707 r
F P
0 g
s
.1814 .69539 m .1814 .71392 L .16503 .72128 L p .707 .577 .707 r
F P
0 g
s
.3253 .57634 m .3253 .63192 L .29784 .62753 L p .707 .577 .707 r
F P
0 g
s
.29784 .62753 m .29784 .57195 L .3253 .57634 L p .707 .577 .707 r
F P
0 g
s
.20545 .5742 m .20545 .62978 L .1814 .63543 L p .707 .577 .707 r
F P
0 g
s
.20545 .62978 m .20545 .5742 L .23483 .57082 L p .707 .577 .707 r
F P
0 g
s
.16503 .79504 m .16503 .75799 L .1814 .75062 L p .707 .577 .707 r
F P
0 g
s
.34635 .69833 m .34635 .71686 L .3253 .7104 L p .707 .577 .707 r
F P
0 g
s
.3253 .7104 m .3253 .69187 L .34635 .69833 L p .707 .577 .707 r
F P
0 g
s
.29784 .57195 m .29784 .62753 L .26667 .62563 L p .707 .577 .707 r
F P
0 g
s
.26667 .62563 m .26667 .57005 L .29784 .57195 L p .707 .577 .707 r
F P
0 g
s
.1814 .75062 m .1814 .78768 L .16503 .79504 L p .707 .577 .707 r
F P
0 g
s
.1814 .71392 m .1814 .69539 L .20545 .68974 L p .707 .577 .707 r
F P
0 g
s
.23483 .6264 m .23483 .57082 L .26667 .57005 L p .707 .577 .707 r
F P
0 g
s
.23483 .57082 m .23483 .6264 L .20545 .62978 L p .707 .577 .707 r
F P
0 g
s
.62206 .27139 m .62206 .77328 L .59233 .76417 L p .707 .577 .707 r
F P
0 g
s
.59233 .76417 m .59233 .26228 L .62206 .27139 L p .707 .577 .707 r
F P
0 g
s
.26667 .57005 m .26667 .62563 L .23483 .6264 L p .707 .577 .707 r
F P
0 g
s
.34635 .75356 m .34635 .79062 L .3253 .78416 L p .707 .577 .707 r
F P
0 g
s
.3253 .78416 m .3253 .74711 L .34635 .75356 L p .707 .577 .707 r
F P
0 g
s
.73333 .62512 m .73333 .56953 L .70216 .56763 L p .707 .577 .707 r
F P
0 g
s
.73333 .56953 m .73333 .62512 L .76517 .62434 L p .707 .577 .707 r
F P
0 g
s
.76517 .62434 m .76517 .56876 L .73333 .56953 L p .707 .577 .707 r
F P
0 g
s
.20545 .68974 m .20545 .70827 L .1814 .71392 L p .707 .577 .707 r
F P
0 g
s
.76517 .56876 m .76517 .62434 L .79455 .62096 L p .707 .577 .707 r
F P
0 g
s
.79455 .62096 m .79455 .56538 L .76517 .56876 L p .707 .577 .707 r
F P
0 g
s
.70216 .62322 m .70216 .56763 L .6747 .56324 L p .707 .577 .707 r
F P
0 g
s
.70216 .56763 m .70216 .62322 L .73333 .62512 L p .707 .577 .707 r
F P
0 g
s
.3253 .69187 m .3253 .7104 L .29784 .70601 L p .707 .577 .707 r
F P
0 g
s
.29784 .70601 m .29784 .68748 L .3253 .69187 L p .707 .577 .707 r
F P
0 g
s
.1814 .78768 m .1814 .75062 L .20545 .74497 L p .707 .577 .707 r
F P
0 g
s
.38918 .26724 m .38918 .76912 L .36607 .77953 L p .707 .577 .707 r
F P
0 g
s
.38918 .76912 m .38918 .26724 L .42314 .25926 L p .707 .577 .707 r
F P
0 g
s
.79455 .56538 m .79455 .62096 L .8186 .61531 L p .707 .577 .707 r
F P
0 g
s
.8186 .61531 m .8186 .55973 L .79455 .56538 L p .707 .577 .707 r
F P
0 g
s
.20545 .70827 m .20545 .68974 L .23483 .68636 L p .707 .577 .707 r
F P
0 g
s
.23483 .68636 m .23483 .70489 L .20545 .70827 L p .707 .577 .707 r
F P
0 g
s
.20545 .74497 m .20545 .78203 L .1814 .78768 L p .707 .577 .707 r
F P
0 g
s
.6747 .56324 m .6747 .61882 L .70216 .62322 L p .707 .577 .707 r
F P
0 g
s
.6747 .61882 m .6747 .56324 L .65365 .55679 L p .707 .577 .707 r
F P
0 g
s
.3253 .74711 m .3253 .78416 L .29784 .77977 L p .707 .577 .707 r
F P
0 g
s
.29784 .77977 m .29784 .74272 L .3253 .74711 L p .707 .577 .707 r
F P
0 g
s
.29784 .68748 m .29784 .70601 L .26667 .70411 L p .707 .577 .707 r
F P
0 g
s
.26667 .70411 m .26667 .68558 L .29784 .68748 L p .707 .577 .707 r
F P
0 g
s
.23483 .70489 m .23483 .68636 L .26667 .68558 L p .707 .577 .707 r
F P
0 g
s
.59233 .26228 m .59233 .76417 L .55357 .75796 L p .707 .577 .707 r
F P
0 g
s
.55357 .75796 m .55357 .25608 L .59233 .26228 L p .707 .577 .707 r
F P
0 g
s
.26667 .68558 m .26667 .70411 L .23483 .70489 L p .707 .577 .707 r
F P
0 g
s
.20545 .78203 m .20545 .74497 L .23483 .74159 L p .707 .577 .707 r
F P
0 g
s
.73333 .7036 m .73333 .68507 L .70216 .68317 L p .707 .577 .707 r
F P
0 g
s
.73333 .68507 m .73333 .7036 L .76517 .70282 L p .707 .577 .707 r
F P
0 g
s
.76517 .70282 m .76517 .68429 L .73333 .68507 L p .707 .577 .707 r
F P
0 g
s
.76517 .68429 m .76517 .70282 L .79455 .69944 L p .707 .577 .707 r
F P
0 g
s
.79455 .69944 m .79455 .68091 L .76517 .68429 L p .707 .577 .707 r
F P
0 g
s
.8186 .55973 m .8186 .61531 L .83497 .60794 L p .707 .577 .707 r
F P
0 g
s
.83497 .60794 m .83497 .55236 L .8186 .55973 L p .707 .577 .707 r
F P
0 g
s
.70216 .68317 m .70216 .7017 L .73333 .7036 L p .707 .577 .707 r
F P
0 g
s
.65365 .55679 m .65365 .61237 L .6747 .61882 L p .707 .577 .707 r
F P
0 g
s
.29784 .74272 m .29784 .77977 L .26667 .77787 L p .707 .577 .707 r
F P
0 g
s
.26667 .77787 m .26667 .74082 L .29784 .74272 L p .707 .577 .707 r
F P
0 g
s
.70216 .7017 m .70216 .68317 L .6747 .67878 L p .707 .577 .707 r
F P
0 g
s
.42314 .76115 m .42314 .25926 L .46462 .25449 L p .707 .577 .707 r
F P
0 g
s
.42314 .25926 m .42314 .76115 L .38918 .76912 L p .707 .577 .707 r
F P
0 g
s
.23483 .74159 m .23483 .77865 L .20545 .78203 L p .707 .577 .707 r
F P
0 g
s
.23483 .77865 m .23483 .74159 L .26667 .74082 L p .707 .577 .707 r
F P
0 g
s
.6747 .67878 m .6747 .6973 L .70216 .7017 L p .707 .577 .707 r
F P
0 g
s
.26667 .74082 m .26667 .77787 L .23483 .77865 L p .707 .577 .707 r
F P
0 g
s
.65365 .61237 m .65365 .55679 L .64105 .5489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68091 m .79455 .69944 L .8186 .69379 L p .707 .577 .707 r
F P
0 g
s
.8186 .69379 m .8186 .67526 L .79455 .68091 L p .707 .577 .707 r
F P
0 g
s
.73333 .77736 m .73333 .7403 L .70216 .7384 L p .707 .577 .707 r
F P
0 g
s
.73333 .7403 m .73333 .77736 L .76517 .77658 L p .707 .577 .707 r
F P
0 g
s
.76517 .77658 m .76517 .73953 L .73333 .7403 L p .707 .577 .707 r
F P
0 g
s
.76517 .73953 m .76517 .77658 L .79455 .7732 L p .707 .577 .707 r
F P
0 g
s
.79455 .7732 m .79455 .73615 L .76517 .73953 L p .707 .577 .707 r
F P
0 g
s
.55357 .25608 m .55357 .75796 L .50956 .75528 L p .707 .577 .707 r
F P
0 g
s
.50956 .75528 m .50956 .25339 L .55357 .25608 L p .707 .577 .707 r
F P
0 g
s
.70216 .77546 m .70216 .7384 L .6747 .73401 L p .707 .577 .707 r
F P
0 g
s
.70216 .7384 m .70216 .77546 L .73333 .77736 L p .707 .577 .707 r
F P
0 g
s
.6747 .6973 m .6747 .67878 L .65365 .67232 L p .707 .577 .707 r
F P
0 g
s
.46462 .75638 m .46462 .25449 L .50956 .25339 L p .707 .577 .707 r
F P
0 g
s
.46462 .25449 m .46462 .75638 L .42314 .76115 L p .707 .577 .707 r
F P
0 g
s
.65365 .67232 m .65365 .69085 L .6747 .6973 L p .707 .577 .707 r
F P
0 g
s
.50956 .25339 m .50956 .75528 L .46462 .75638 L p .707 .577 .707 r
F P
0 g
s
.64105 .5489 m .64105 .60448 L .65365 .61237 L p .707 .577 .707 r
F P
0 g
s
.83497 .55236 m .83497 .60794 L .84205 .59958 L p .707 .577 .707 r
F P
0 g
s
.84205 .59958 m .84205 .544 L .83497 .55236 L p .707 .577 .707 r
F P
0 g
s
.79455 .73615 m .79455 .7732 L .8186 .76755 L p .707 .577 .707 r
F P
0 g
s
.8186 .76755 m .8186 .7305 L .79455 .73615 L p .707 .577 .707 r
F P
0 g
s
.6747 .73401 m .6747 .77107 L .70216 .77546 L p .707 .577 .707 r
F P
0 g
s
.8186 .67526 m .8186 .69379 L .83497 .68642 L p .707 .577 .707 r
F P
0 g
s
.83497 .68642 m .83497 .6679 L .8186 .67526 L p .707 .577 .707 r
F P
0 g
s
.6747 .77107 m .6747 .73401 L .65365 .72756 L p .707 .577 .707 r
F P
0 g
s
.64105 .60448 m .64105 .5489 L .63816 .54036 L p .707 .577 .707 r
F P
0 g
s
.65365 .69085 m .65365 .67232 L .64105 .66444 L p .707 .577 .707 r
F P
0 g
s
.65365 .72756 m .65365 .76461 L .6747 .77107 L p .707 .577 .707 r
F P
0 g
s
.8186 .7305 m .8186 .76755 L .83497 .76019 L p .707 .577 .707 r
F P
0 g
s
.83497 .76019 m .83497 .72313 L .8186 .7305 L p .707 .577 .707 r
F P
0 g
s
.64105 .66444 m .64105 .68297 L .65365 .69085 L p .707 .577 .707 r
F P
0 g
s
.63816 .54036 m .63816 .59594 L .64105 .60448 L p .707 .577 .707 r
F P
0 g
s
.84205 .544 m .84205 .59958 L .83916 .59104 L p .707 .577 .707 r
F P
0 g
s
.83916 .59104 m .83916 .53545 L .84205 .544 L p .707 .577 .707 r
F P
0 g
s
.65365 .76461 m .65365 .72756 L .64105 .71967 L p .707 .577 .707 r
F P
0 g
s
.83497 .6679 m .83497 .68642 L .84206 .67806 L p .707 .577 .707 r
F P
0 g
s
.84206 .67806 m .84205 .65953 L .83497 .6679 L p .707 .577 .707 r
F P
0 g
s
.64105 .71967 m .64105 .75673 L .65365 .76461 L p .707 .577 .707 r
F P
0 g
s
.63816 .59594 m .63816 .54036 L .64524 .532 L p .707 .577 .707 r
F P
0 g
s
.64105 .68297 m .64105 .66444 L .63816 .6559 L p .707 .577 .707 r
F P
0 g
s
.83497 .72313 m .83497 .76019 L .84206 .75182 L p .707 .577 .707 r
F P
0 g
s
.84206 .75182 m .84206 .71477 L .83497 .72313 L p .707 .577 .707 r
F P
0 g
s
.63816 .6559 m .63816 .67442 L .64105 .68297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .532 m .64524 .58758 L .63816 .59594 L p .707 .577 .707 r
F P
0 g
s
.64105 .75673 m .64105 .71967 L .63816 .71113 L p .707 .577 .707 r
F P
0 g
s
.83916 .53545 m .83916 .59104 L .82657 .58315 L p .707 .577 .707 r
F P
0 g
s
.82657 .58315 m .82657 .52757 L .83916 .53545 L p .707 .577 .707 r
F P
0 g
s
.84205 .65953 m .84206 .67806 L .83916 .66952 L p .707 .577 .707 r
F P
0 g
s
.83916 .66952 m .83916 .65099 L .84205 .65953 L p .707 .577 .707 r
F P
0 g
s
.63816 .71113 m .63816 .74819 L .64105 .75673 L p .707 .577 .707 r
F P
0 g
s
.39032 .5883 m .39032 .53272 L .35915 .53082 L p .707 .577 .707 r
F P
0 g
s
.39032 .53272 m .39032 .5883 L .42216 .58752 L p .707 .577 .707 r
F P
0 g
s
.42216 .58752 m .42216 .53194 L .39032 .53272 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58758 m .64524 .532 L .66161 .52463 L p .707 .577 .707 r
F P
0 g
s
.42216 .53194 m .42216 .58752 L .45154 .58414 L p .707 .577 .707 r
F P
0 g
s
.45154 .58414 m .45154 .52856 L .42216 .53194 L p .707 .577 .707 r
F P
0 g
s
.63816 .67442 m .63816 .6559 L .64524 .64753 L p .707 .577 .707 r
F P
0 g
s
.35915 .5864 m .35915 .53082 L .33169 .52643 L p .707 .577 .707 r
F P
0 g
s
.35915 .53082 m .35915 .5864 L .39032 .5883 L p .707 .577 .707 r
F P
0 g
s
.84206 .71477 m .84206 .75182 L .83916 .74328 L p .707 .577 .707 r
F P
0 g
s
.83916 .74328 m .83916 .70622 L .84206 .71477 L p .707 .577 .707 r
F P
0 g
s
.64524 .64753 m .64524 .66606 L .63816 .67442 L p .707 .577 .707 r
F P
0 g
s
.45154 .52856 m .45154 .58414 L .47559 .57849 L p .707 .577 .707 r
F P
0 g
s
.47559 .57849 m .47559 .52291 L .45154 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52463 m .66161 .58021 L .64524 .58758 L p .707 .577 .707 r
F P
0 g
s
.82657 .52757 m .82657 .58315 L .80551 .5767 L p .707 .577 .707 r
F P
0 g
s
.80551 .5767 m .80551 .52111 L .82657 .52757 L p .707 .577 .707 r
F P
0 g
s
.63816 .74819 m .63816 .71113 L .64524 .70277 L p .707 .577 .707 r
F P
0 g
s
.33169 .52643 m .33169 .58201 L .35915 .5864 L p .707 .577 .707 r
F P
0 g
s
.83916 .65099 m .83916 .66952 L .82657 .66163 L p .707 .577 .707 r
F P
0 g
s
.82657 .66163 m .82657 .64311 L .83916 .65099 L p .707 .577 .707 r
F P
0 g
s
.33169 .58201 m .33169 .52643 L .31064 .51997 L p .707 .577 .707 r
F P
0 g
s
.66161 .58021 m .66161 .52463 L .68566 .51898 L p .707 .577 .707 r
F P
0 g
s
.64524 .70277 m .64524 .73982 L .63816 .74819 L p .707 .577 .707 r
F P
0 g
s
.39032 .66678 m .39032 .64825 L .35915 .64635 L p .707 .577 .707 r
F P
0 g
s
.39032 .64825 m .39032 .66678 L .42216 .666 L p .707 .577 .707 r
F P
0 g
s
.42216 .666 m .42216 .64748 L .39032 .64825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66606 m .64524 .64753 L .66161 .64016 L p .707 .577 .707 r
F P
0 g
s
.42216 .64748 m .42216 .666 L .45154 .66263 L p .707 .577 .707 r
F P
0 g
s
.45154 .66263 m .45154 .6441 L .42216 .64748 L p .707 .577 .707 r
F P
0 g
s
.47559 .52291 m .47559 .57849 L .49196 .57113 L p .707 .577 .707 r
F P
0 g
s
.49196 .57113 m .49196 .51554 L .47559 .52291 L p .707 .577 .707 r
F P
0 g
s
.35915 .64635 m .35915 .66488 L .39032 .66678 L p .707 .577 .707 r
F P
0 g
s
.83916 .70622 m .83916 .74328 L .82657 .73539 L p .707 .577 .707 r
F P
0 g
s
.82657 .73539 m .82657 .69834 L .83916 .70622 L p .707 .577 .707 r
F P
0 g
s
.31064 .51997 m .31064 .57555 L .33169 .58201 L p .707 .577 .707 r
F P
0 g
s
.35915 .66488 m .35915 .64635 L .33169 .64196 L p .707 .577 .707 r
F P
0 g
s
.66161 .64016 m .66161 .65869 L .64524 .66606 L p .707 .577 .707 r
F P
0 g
s
.80551 .52111 m .80551 .5767 L .77805 .5723 L p .707 .577 .707 r
F P
0 g
s
.77805 .5723 m .77805 .51672 L .80551 .52111 L p .707 .577 .707 r
F P
0 g
s
.33169 .64196 m .33169 .66049 L .35915 .66488 L p .707 .577 .707 r
F P
0 g
s
.68566 .51898 m .68566 .57456 L .66161 .58021 L p .707 .577 .707 r
F P
0 g
s
.31064 .57555 m .31064 .51997 L .29804 .51209 L p .707 .577 .707 r
F P
0 g
s
.45154 .6441 m .45154 .66263 L .47559 .65698 L p .707 .577 .707 r
F P
0 g
s
.47559 .65698 m .47559 .63845 L .45154 .6441 L p .707 .577 .707 r
F P
0 g
s
.39032 .74054 m .39032 .70349 L .35915 .70159 L p .707 .577 .707 r
F P
0 g
s
.39032 .70349 m .39032 .74054 L .42216 .73977 L p .707 .577 .707 r
F P
0 g
s
.42216 .73977 m .42216 .70271 L .39032 .70349 L p .707 .577 .707 r
F P
0 g
s
.68566 .57456 m .68566 .51898 L .71504 .5156 L p .707 .577 .707 r
F P
0 g
s
.64524 .73982 m .64524 .70277 L .66161 .6954 L p .707 .577 .707 r
F P
0 g
s
.42216 .70271 m .42216 .73977 L .45154 .73639 L p .707 .577 .707 r
F P
0 g
s
.45154 .73639 m .45154 .69933 L .42216 .70271 L p .707 .577 .707 r
F P
0 g
s
.82657 .64311 m .82657 .66163 L .80551 .65518 L p .707 .577 .707 r
F P
0 g
s
.80551 .65518 m .80551 .63665 L .82657 .64311 L p .707 .577 .707 r
F P
0 g
s
.35915 .73864 m .35915 .70159 L .33169 .6972 L p .707 .577 .707 r
F P
0 g
s
.35915 .70159 m .35915 .73864 L .39032 .74054 L p .707 .577 .707 r
F P
0 g
s
.33169 .66049 m .33169 .64196 L .31064 .63551 L p .707 .577 .707 r
F P
0 g
s
.77805 .51672 m .77805 .5723 L .74688 .5704 L p .707 .577 .707 r
F P
0 g
s
.74688 .5704 m .74688 .51482 L .77805 .51672 L p .707 .577 .707 r
F P
0 g
s
.31064 .63551 m .31064 .65404 L .33169 .66049 L p .707 .577 .707 r
F P
0 g
s
.66161 .6954 m .66161 .73245 L .64524 .73982 L p .707 .577 .707 r
F P
0 g
s
.66161 .65869 m .66161 .64016 L .68566 .63451 L p .707 .577 .707 r
F P
0 g
s
.29804 .51209 m .29804 .56767 L .31064 .57555 L p .707 .577 .707 r
F P
0 g
s
.71504 .57118 m .71504 .5156 L .74688 .51482 L p .707 .577 .707 r
F P
0 g
s
.71504 .5156 m .71504 .57118 L .68566 .57456 L p .707 .577 .707 r
F P
0 g
s
.49196 .51554 m .49196 .57113 L .49904 .56276 L p .707 .577 .707 r
F P
0 g
s
.49904 .56276 m .49904 .50718 L .49196 .51554 L p .707 .577 .707 r
F P
0 g
s
.45154 .69933 m .45154 .73639 L .47559 .73074 L p .707 .577 .707 r
F P
0 g
s
.47559 .73074 m .47559 .69368 L .45154 .69933 L p .707 .577 .707 r
F P
0 g
s
.74688 .51482 m .74688 .5704 L .71504 .57118 L p .707 .577 .707 r
F P
0 g
s
.33169 .6972 m .33169 .73425 L .35915 .73864 L p .707 .577 .707 r
F P
0 g
s
.82657 .69834 m .82657 .73539 L .80551 .72894 L p .707 .577 .707 r
F P
0 g
s
.80551 .72894 m .80551 .69189 L .82657 .69834 L p .707 .577 .707 r
F P
0 g
s
.68566 .63451 m .68566 .65304 L .66161 .65869 L p .707 .577 .707 r
F P
0 g
s
.47559 .63845 m .47559 .65698 L .49196 .64961 L p .707 .577 .707 r
F P
0 g
s
.49196 .64961 m .49196 .63108 L .47559 .63845 L p .707 .577 .707 r
F P
0 g
s
.33169 .73425 m .33169 .6972 L .31064 .69074 L p .707 .577 .707 r
F P
0 g
s
.80551 .63665 m .80551 .65518 L .77805 .65079 L p .707 .577 .707 r
F P
0 g
s
.77805 .65079 m .77805 .63226 L .80551 .63665 L p .707 .577 .707 r
F P
0 g
s
.29804 .56767 m .29804 .51209 L .29515 .50354 L p .707 .577 .707 r
F P
0 g
s
.66161 .73245 m .66161 .6954 L .68566 .68975 L p .707 .577 .707 r
F P
0 g
s
.31064 .65404 m .31064 .63551 L .29804 .62762 L p .707 .577 .707 r
F P
0 g
s
.31064 .69074 m .31064 .7278 L .33169 .73425 L p .707 .577 .707 r
F P
0 g
s
.68566 .65304 m .68566 .63451 L .71504 .63114 L p .707 .577 .707 r
F P
0 g
s
.47559 .69368 m .47559 .73074 L .49196 .72337 L p .707 .577 .707 r
F P
0 g
s
.49196 .72337 m .49196 .68631 L .47559 .69368 L p .707 .577 .707 r
F P
0 g
s
.29804 .62762 m .29804 .64615 L .31064 .65404 L p .707 .577 .707 r
F P
0 g
s
.71504 .63114 m .71504 .64966 L .68566 .65304 L p .707 .577 .707 r
F P
0 g
s
.68566 .68975 m .68566 .7268 L .66161 .73245 L p .707 .577 .707 r
F P
0 g
s
.80551 .69189 m .80551 .72894 L .77805 .72455 L p .707 .577 .707 r
F P
0 g
s
.77805 .72455 m .77805 .68749 L .80551 .69189 L p .707 .577 .707 r
F P
0 g
s
.29515 .50354 m .29515 .55913 L .29804 .56767 L p .707 .577 .707 r
F P
0 g
s
.77805 .63226 m .77805 .65079 L .74688 .64889 L p .707 .577 .707 r
F P
0 g
s
.74688 .64889 m .74688 .63036 L .77805 .63226 L p .707 .577 .707 r
F P
0 g
s
.49904 .50718 m .49904 .56276 L .49615 .55422 L p .707 .577 .707 r
F P
0 g
s
.49615 .55422 m .49615 .49864 L .49904 .50718 L p .707 .577 .707 r
F P
0 g
s
.31064 .7278 m .31064 .69074 L .29804 .68286 L p .707 .577 .707 r
F P
0 g
s
.71504 .64966 m .71504 .63114 L .74688 .63036 L p .707 .577 .707 r
F P
0 g
s
.49196 .63108 m .49196 .64961 L .49904 .64124 L p .707 .577 .707 r
F P
0 g
s
.49904 .64124 m .49904 .62272 L .49196 .63108 L p .707 .577 .707 r
F P
0 g
s
.74688 .63036 m .74688 .64889 L .71504 .64966 L p .707 .577 .707 r
F P
0 g
s
.68566 .7268 m .68566 .68975 L .71504 .68637 L p .707 .577 .707 r
F P
0 g
s
.29804 .68286 m .29804 .71991 L .31064 .7278 L p .707 .577 .707 r
F P
0 g
s
.29515 .55913 m .29515 .50354 L .30223 .49518 L p .707 .577 .707 r
F P
0 g
s
.77805 .68749 m .77805 .72455 L .74688 .72265 L p .707 .577 .707 r
F P
0 g
s
.74688 .72265 m .74688 .68559 L .77805 .68749 L p .707 .577 .707 r
F P
0 g
s
.29804 .64615 m .29804 .62762 L .29515 .61908 L p .707 .577 .707 r
F P
0 g
s
.71504 .68637 m .71504 .72342 L .68566 .7268 L p .707 .577 .707 r
F P
0 g
s
.71504 .72342 m .71504 .68637 L .74688 .68559 L p .707 .577 .707 r
F P
0 g
s
.49196 .68631 m .49196 .72337 L .49904 .71501 L p .707 .577 .707 r
F P
0 g
s
.49904 .71501 m .49904 .67795 L .49196 .68631 L p .707 .577 .707 r
F P
0 g
s
.29515 .61908 m .29515 .63761 L .29804 .64615 L p .707 .577 .707 r
F P
0 g
s
.74688 .68559 m .74688 .72265 L .71504 .72342 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .49518 m .30223 .55076 L .29515 .55913 L p .707 .577 .707 r
F P
0 g
s
.29804 .71991 m .29804 .68286 L .29515 .67432 L p .707 .577 .707 r
F P
0 g
s
.49615 .49864 m .49615 .55422 L .48356 .54634 L p .707 .577 .707 r
F P
0 g
s
.48356 .54634 m .48356 .49075 L .49615 .49864 L p .707 .577 .707 r
F P
0 g
s
.49904 .62272 m .49904 .64124 L .49615 .6327 L p .707 .577 .707 r
F P
0 g
s
.49615 .6327 m .49615 .61417 L .49904 .62272 L p .707 .577 .707 r
F P
0 g
s
.29515 .67432 m .29515 .71137 L .29804 .71991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55076 m .30223 .49518 L .3186 .48781 L p .707 .577 .707 r
F P
0 g
s
.29515 .63761 m .29515 .61908 L .30223 .61072 L p .707 .577 .707 r
F P
0 g
s
.49904 .67795 m .49904 .71501 L .49615 .70646 L p .707 .577 .707 r
F P
0 g
s
.49615 .70646 m .49615 .66941 L .49904 .67795 L p .707 .577 .707 r
F P
0 g
s
.30223 .61072 m .30223 .62924 L .29515 .63761 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .48781 m .3186 .54339 L .30223 .55076 L p .707 .577 .707 r
F P
0 g
s
.48356 .49075 m .48356 .54634 L .4625 .53988 L p .707 .577 .707 r
F P
0 g
s
.4625 .53988 m .4625 .4843 L .48356 .49075 L p .707 .577 .707 r
F P
0 g
s
.29515 .71137 m .29515 .67432 L .30223 .66595 L p .707 .577 .707 r
F P
0 g
s
.49615 .61417 m .49615 .6327 L .48356 .62482 L p .707 .577 .707 r
F P
0 g
s
.48356 .62482 m .48356 .60629 L .49615 .61417 L p .707 .577 .707 r
F P
0 g
s
.3186 .54339 m .3186 .48781 L .34265 .48216 L p .707 .577 .707 r
F P
0 g
s
.30223 .66595 m .30223 .70301 L .29515 .71137 L p .707 .577 .707 r
F P
0 g
s
.30223 .62924 m .30223 .61072 L .3186 .60335 L p .707 .577 .707 r
F P
0 g
s
.49615 .66941 m .49615 .70646 L .48356 .69858 L p .707 .577 .707 r
F P
0 g
s
.48356 .69858 m .48356 .66152 L .49615 .66941 L p .707 .577 .707 r
F P
0 g
s
.3186 .60335 m .3186 .62188 L .30223 .62924 L p .707 .577 .707 r
F P
0 g
s
.4625 .4843 m .4625 .53988 L .43504 .53549 L p .707 .577 .707 r
F P
0 g
s
.43504 .53549 m .43504 .47991 L .4625 .4843 L p .707 .577 .707 r
F P
0 g
s
.34265 .48216 m .34265 .53774 L .3186 .54339 L p .707 .577 .707 r
F P
0 g
s
.34265 .53774 m .34265 .48216 L .37203 .47878 L p .707 .577 .707 r
F P
0 g
s
.30223 .70301 m .30223 .66595 L .3186 .65858 L p .707 .577 .707 r
F P
0 g
s
.48356 .60629 m .48356 .62482 L .4625 .61836 L p .707 .577 .707 r
F P
0 g
s
.4625 .61836 m .4625 .59984 L .48356 .60629 L p .707 .577 .707 r
F P
0 g
s
.43504 .47991 m .43504 .53549 L .40387 .53359 L p .707 .577 .707 r
F P
0 g
s
.40387 .53359 m .40387 .47801 L .43504 .47991 L p .707 .577 .707 r
F P
0 g
s
.3186 .65858 m .3186 .69564 L .30223 .70301 L p .707 .577 .707 r
F P
0 g
s
.3186 .62188 m .3186 .60335 L .34265 .5977 L p .707 .577 .707 r
F P
0 g
s
.37203 .53437 m .37203 .47878 L .40387 .47801 L p .707 .577 .707 r
F P
0 g
s
.37203 .47878 m .37203 .53437 L .34265 .53774 L p .707 .577 .707 r
F P
0 g
s
.40387 .47801 m .40387 .53359 L .37203 .53437 L p .707 .577 .707 r
F P
0 g
s
.48356 .66152 m .48356 .69858 L .4625 .69212 L p .707 .577 .707 r
F P
0 g
s
.4625 .69212 m .4625 .65507 L .48356 .66152 L p .707 .577 .707 r
F P
0 g
s
.34265 .5977 m .34265 .61623 L .3186 .62188 L p .707 .577 .707 r
F P
0 g
s
.4625 .59984 m .4625 .61836 L .43504 .61397 L p .707 .577 .707 r
F P
0 g
s
.43504 .61397 m .43504 .59544 L .4625 .59984 L p .707 .577 .707 r
F P
0 g
s
.3186 .69564 m .3186 .65858 L .34265 .65293 L p .707 .577 .707 r
F P
0 g
s
.34265 .61623 m .34265 .5977 L .37203 .59432 L p .707 .577 .707 r
F P
0 g
s
.37203 .59432 m .37203 .61285 L .34265 .61623 L p .707 .577 .707 r
F P
0 g
s
.34265 .65293 m .34265 .68999 L .3186 .69564 L p .707 .577 .707 r
F P
0 g
s
.4625 .65507 m .4625 .69212 L .43504 .68773 L p .707 .577 .707 r
F P
0 g
s
.43504 .68773 m .43504 .65068 L .4625 .65507 L p .707 .577 .707 r
F P
0 g
s
.43504 .59544 m .43504 .61397 L .40387 .61207 L p .707 .577 .707 r
F P
0 g
s
.40387 .61207 m .40387 .59354 L .43504 .59544 L p .707 .577 .707 r
F P
0 g
s
.37203 .61285 m .37203 .59432 L .40387 .59354 L p .707 .577 .707 r
F P
0 g
s
.40387 .59354 m .40387 .61207 L .37203 .61285 L p .707 .577 .707 r
F P
0 g
s
.34265 .68999 m .34265 .65293 L .37203 .64955 L p .707 .577 .707 r
F P
0 g
s
.43504 .65068 m .43504 .68773 L .40387 .68583 L p .707 .577 .707 r
F P
0 g
s
.40387 .68583 m .40387 .64878 L .43504 .65068 L p .707 .577 .707 r
F P
0 g
s
.37203 .64955 m .37203 .68661 L .34265 .68999 L p .707 .577 .707 r
F P
0 g
s
.37203 .68661 m .37203 .64955 L .40387 .64878 L p .707 .577 .707 r
F P
0 g
s
.40387 .64878 m .40387 .68583 L .37203 .68661 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP06001gOol007Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`T000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001G
Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00003goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00IJEPP0
00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03
001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol00`00
FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
009JEPL000QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2
000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000]Ool0035oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;goo0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF0002FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUH0000B0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF2@0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF3P0015YF
00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000FUH005YF0P000eYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF6`00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH4000015YF0000000015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00=JEP800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07
FUH00`00FUH0000300000eYF000000040004FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEQP003ioo`00
;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP<0
00AJEP<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00<003Yoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP04001JEP000003FUH00`00FUH000020003FUH30002FUH01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP02FUH50000
15YF000000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF100000=JEP00FUH00UYF00<0
05YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH01000<Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
<Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF5`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP03FUH30004FUH00`00FUH000050003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH800000eYF001JEP05FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF200047oo20000eYF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH00004FUH000000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020002FUH01000FUIJEUYF
0P0067oo1@0015YF00D005YFFUIJEP0002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000M
Ool300000eYF001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@0
05YFFUIJEP8000Qoo`<001Moo`800003FUH0000002eoo`00<goo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUH0
05YF00<000AJEP04001JEUYFFUH20007Ool5000FOol5000]Ool003Ioo`D000AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P0015YF0`00
00=JEP00FUH00UYF0P001goo1@0057oo0P000UYF0`00;Goo000kOol80004FUH00`00FUIJEP07FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP00008000=JEP<000=JEP80
00Moo`D0011oo`@000AJEP03001JEP0002eoo`00@goo4@0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEPD00004FUH00000FUH20008Ool3000:Ool70003FUH00`00FUIJ
EP02FUH2000^Ool004Moo`T000=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000oOol8
0004FUH00`00FUIJEP02FUH400000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF2@0015YF00<005YFFUH0
0UYF2@001UYF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEPH0
00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD0009JEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000=JEPP000Aoo`04001JEUYF0005FUH40006FUH00`00FUIJEP09FUH4
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000`00<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P0015YF1P000Woo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF009JEPL000=JEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000^Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000
FUH000EJEP04001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH00`00FUIJ
EP0200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
0UYF5P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEPH001Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF000015YF00<005YF00000`006Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH3000NOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00FUH2000ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00
000HOol3000:Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P00
0UYF0`0057oo1@002goo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPH000Uoo`D000Aoo`P0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEP000080015oo`D0
00ioo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP000080011oo`<000eoo`D000AJEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF009JEPD000aoo`D000moo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEPP0021oo`H00003FUH005YF009JEP8002eoo`00;Goo
00D005YFFUIJEP0000EJEP04001JEUYFFUH80005Ool3000;Ool50005FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YFFUIJEPT0
019oo`D000EJEP<000=JEP8002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEQL000=JEP03
001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002moo`<000EJEP03
001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0039o
o`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02
FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000=o
o`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUIJEUYF
0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF100015YF00<005YF00002`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF0000
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP05001JEUYFFUH00003FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUH000080004FUH0
0`00FUIJEP02FUH9000oOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT0
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP040006FUH01000FUIJEUYF0P001Goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJ
EUYF200027oo1@0037oo1P0015YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH2000015YF001JEUYF1@000UYF00@005YF000005Qoo`00;7oo00<005YF000015YF10004Goo0`00
4goo0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000<005Yoo`00;7oo00<005YF00000UYF0P000eYF1@0087oo100000AJEP000000009J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP02FUH2001I
Ool002aoo`03001JEP0000<000EJEP04001JEUYFFUH8000:Ool>0005FUH01@00FUIJEP00FUH00P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP<005Moo`00
;7oo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000IJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=oo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF
FUIJEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30003Ool80003FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000=Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3000>Ool50004FUH01000FUIJ
EUYF0P00E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH00003000COol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH0
0003000COol600000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPD001ioo``000IJEP03001JEUYF00YJEP03001JEUYF00=JEPL0019oo`D0
00EJEP<000=JEP8005Aoo`00?Goo6@00;goo<P000eYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo002>Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001DOol008ioo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<005Aoo`00SWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002?Ool0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002B
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Moo`D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00W7oo2@0015YF00<005YFFUH00UYF
3P00HGoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .71715 m .59613 .66157 L .56496 .65967 L p .707 .577 .707 r
F P
0 g
s
.59613 .66157 m .59613 .71715 L .62796 .71638 L p .707 .577 .707 r
F P
0 g
s
.62796 .71638 m .62796 .66079 L .59613 .66157 L p .707 .577 .707 r
F P
0 g
s
.62796 .66079 m .62796 .71638 L .65734 .713 L p .707 .577 .707 r
F P
0 g
s
.65734 .713 m .65734 .65742 L .62796 .66079 L p .707 .577 .707 r
F P
0 g
s
.56496 .71525 m .56496 .65967 L .5375 .65528 L p .707 .577 .707 r
F P
0 g
s
.56496 .65967 m .56496 .71525 L .59613 .71715 L p .707 .577 .707 r
F P
0 g
s
.65734 .65742 m .65734 .713 L .6814 .70735 L p .707 .577 .707 r
F P
0 g
s
.6814 .70735 m .6814 .65177 L .65734 .65742 L p .707 .577 .707 r
F P
0 g
s
.5375 .65528 m .5375 .71086 L .56496 .71525 L p .707 .577 .707 r
F P
0 g
s
.5375 .71086 m .5375 .65528 L .51644 .64883 L p .707 .577 .707 r
F P
0 g
s
.59613 .79564 m .59613 .77711 L .56496 .77521 L p .707 .577 .707 r
F P
0 g
s
.59613 .77711 m .59613 .79564 L .62796 .79486 L p .707 .577 .707 r
F P
0 g
s
.62796 .79486 m .62796 .77633 L .59613 .77711 L p .707 .577 .707 r
F P
0 g
s
.62796 .77633 m .62796 .79486 L .65735 .79148 L p .707 .577 .707 r
F P
0 g
s
.65735 .79148 m .65735 .77295 L .62796 .77633 L p .707 .577 .707 r
F P
0 g
s
.6814 .65177 m .6814 .70735 L .69777 .69998 L p .707 .577 .707 r
F P
0 g
s
.69777 .69998 m .69777 .6444 L .6814 .65177 L p .707 .577 .707 r
F P
0 g
s
.56496 .77521 m .56496 .79373 L .59613 .79564 L p .707 .577 .707 r
F P
0 g
s
.51644 .64883 m .51644 .70441 L .5375 .71086 L p .707 .577 .707 r
F P
0 g
s
.56496 .79373 m .56496 .77521 L .5375 .77082 L p .707 .577 .707 r
F P
0 g
s
.5375 .77082 m .5375 .78934 L .56496 .79373 L p .707 .577 .707 r
F P
0 g
s
.51644 .70441 m .51644 .64883 L .50385 .64094 L p .707 .577 .707 r
F P
0 g
s
.65735 .77295 m .65735 .79148 L .6814 .78583 L p .707 .577 .707 r
F P
0 g
s
.6814 .78583 m .6814 .7673 L .65735 .77295 L p .707 .577 .707 r
F P
0 g
s
.59613 .8694 m .59613 .83234 L .56496 .83044 L p .707 .577 .707 r
F P
0 g
s
.59613 .83234 m .59613 .8694 L .62796 .86862 L p .707 .577 .707 r
F P
0 g
s
.62796 .86862 m .62796 .83156 L .59613 .83234 L p .707 .577 .707 r
F P
0 g
s
.62796 .83156 m .62796 .86862 L .65735 .86524 L p .707 .577 .707 r
F P
0 g
s
.65735 .86524 m .65735 .82819 L .62796 .83156 L p .707 .577 .707 r
F P
0 g
s
.56496 .8675 m .56496 .83044 L .5375 .82605 L p .707 .577 .707 r
F P
0 g
s
.56496 .83044 m .56496 .8675 L .59613 .8694 L p .707 .577 .707 r
F P
0 g
s
.5375 .78934 m .5375 .77082 L .51644 .76436 L p .707 .577 .707 r
F P
0 g
s
.51644 .76436 m .51644 .78289 L .5375 .78934 L p .707 .577 .707 r
F P
0 g
s
.50385 .64094 m .50385 .69652 L .51644 .70441 L p .707 .577 .707 r
F P
0 g
s
.69777 .6444 m .69777 .69998 L .70485 .69162 L p .707 .577 .707 r
F P
0 g
s
.70485 .69162 m .70485 .63603 L .69777 .6444 L p .707 .577 .707 r
F P
0 g
s
.65735 .82819 m .65735 .86524 L .6814 .85959 L p .707 .577 .707 r
F P
0 g
s
.6814 .85959 m .6814 .82254 L .65735 .82819 L p .707 .577 .707 r
F P
0 g
s
.5375 .82605 m .5375 .8631 L .56496 .8675 L p .707 .577 .707 r
F P
0 g
s
.6814 .7673 m .6814 .78583 L .69777 .77846 L p .707 .577 .707 r
F P
0 g
s
.69777 .77846 m .69777 .75993 L .6814 .7673 L p .707 .577 .707 r
F P
0 g
s
.5375 .8631 m .5375 .82605 L .51644 .81959 L p .707 .577 .707 r
F P
0 g
s
.50385 .69652 m .50385 .64094 L .50095 .6324 L p .707 .577 .707 r
F P
0 g
s
.51644 .78289 m .51644 .76436 L .50385 .75648 L p .707 .577 .707 r
F P
0 g
s
.51644 .81959 m .51644 .85665 L .5375 .8631 L p .707 .577 .707 r
F P
0 g
s
.6814 .82254 m .6814 .85959 L .69777 .85222 L p .707 .577 .707 r
F P
0 g
s
.69777 .85222 m .69777 .81517 L .6814 .82254 L p .707 .577 .707 r
F P
0 g
s
.50385 .75648 m .50385 .775 L .51644 .78289 L p .707 .577 .707 r
F P
0 g
s
.50095 .6324 m .50095 .68798 L .50385 .69652 L p .707 .577 .707 r
F P
0 g
s
.70485 .63603 m .70485 .69162 L .70195 .68307 L p .707 .577 .707 r
F P
0 g
s
.70195 .68307 m .70195 .62749 L .70485 .63603 L p .707 .577 .707 r
F P
0 g
s
.51644 .85665 m .51644 .81959 L .50385 .81171 L p .707 .577 .707 r
F P
0 g
s
.69777 .75993 m .69777 .77846 L .70485 .7701 L p .707 .577 .707 r
F P
0 g
s
.70485 .7701 m .70485 .75157 L .69777 .75993 L p .707 .577 .707 r
F P
0 g
s
.50385 .81171 m .50385 .84877 L .51644 .85665 L p .707 .577 .707 r
F P
0 g
s
.50095 .68798 m .50095 .6324 L .50804 .62403 L p .707 .577 .707 r
F P
0 g
s
.50385 .775 m .50385 .75648 L .50095 .74794 L p .707 .577 .707 r
F P
0 g
s
.69777 .81517 m .69777 .85222 L .70485 .84386 L p .707 .577 .707 r
F P
0 g
s
.70485 .84386 m .70485 .8068 L .69777 .81517 L p .707 .577 .707 r
F P
0 g
s
.50095 .74794 m .50095 .76646 L .50385 .775 L p .707 .577 .707 r
F P
0 g
s
.49044 .83252 m .49044 .33063 L .44643 .32795 L p .707 .577 .707 r
F P
0 g
s
.50804 .62403 m .50804 .67962 L .50095 .68798 L p .707 .577 .707 r
F P
0 g
s
.50385 .84877 m .50385 .81171 L .50095 .80317 L p .707 .577 .707 r
F P
0 g
s
.50095 .80317 m .50095 .84022 L .50385 .84877 L p .707 .577 .707 r
F P
0 g
s
.50804 .67962 m .50804 .62403 L .5244 .61667 L p .707 .577 .707 r
F P
0 g
s
.50095 .76646 m .50095 .74794 L .50804 .73957 L p .707 .577 .707 r
F P
0 g
s
.50804 .73957 m .50804 .7581 L .50095 .76646 L p .707 .577 .707 r
F P
0 g
s
.5244 .61667 m .5244 .67225 L .50804 .67962 L p .707 .577 .707 r
F P
0 g
s
.50095 .84022 m .50095 .80317 L .50804 .7948 L p .707 .577 .707 r
F P
0 g
s
.50804 .7948 m .50804 .83186 L .50095 .84022 L p .707 .577 .707 r
F P
0 g
s
.50804 .7581 m .50804 .73957 L .5244 .7322 L p .707 .577 .707 r
F P
0 g
s
.5244 .7322 m .5244 .75073 L .50804 .7581 L p .707 .577 .707 r
F P
0 g
s
.50804 .83186 m .50804 .7948 L .5244 .78744 L p .707 .577 .707 r
F P
0 g
s
.5244 .78744 m .5244 .82449 L .50804 .83186 L p .707 .577 .707 r
F P
0 g
s
.5244 .75073 m .5244 .7322 L .54846 .72655 L p .707 .577 .707 r
F P
0 g
s
.54846 .72655 m .54846 .74508 L .5244 .75073 L p .707 .577 .707 r
F P
0 g
s
.5244 .82449 m .5244 .78744 L .54846 .78179 L p .707 .577 .707 r
F P
0 g
s
.54846 .78179 m .54846 .81884 L .5244 .82449 L p .707 .577 .707 r
F P
0 g
s
.49044 .33063 m .49044 .83252 L .53538 .83142 L p .707 .577 .707 r
F P
0 g
s
.5244 .67225 m .5244 .61667 L .54846 .61102 L p .707 .577 .707 r
F P
0 g
s
.54846 .61102 m .54846 .6666 L .5244 .67225 L p .707 .577 .707 r
F P
0 g
s
.53538 .83142 m .53538 .32954 L .49044 .33063 L p .707 .577 .707 r
F P
0 g
s
.54846 .6666 m .54846 .61102 L .57784 .60764 L p .707 .577 .707 r
F P
0 g
s
.57784 .60764 m .57784 .66322 L .54846 .6666 L p .707 .577 .707 r
F P
0 g
s
.54846 .74508 m .54846 .72655 L .57784 .72317 L p .707 .577 .707 r
F P
0 g
s
.57784 .72317 m .57784 .7417 L .54846 .74508 L p .707 .577 .707 r
F P
0 g
s
.54846 .81884 m .54846 .78179 L .57784 .77841 L p .707 .577 .707 r
F P
0 g
s
.57784 .77841 m .57784 .81546 L .54846 .81884 L p .707 .577 .707 r
F P
0 g
s
.53538 .32954 m .53538 .83142 L .57686 .82665 L p .707 .577 .707 r
F P
0 g
s
.57686 .82665 m .57686 .32476 L .53538 .32954 L p .707 .577 .707 r
F P
0 g
s
.70195 .62749 m .70195 .68307 L .68936 .67519 L p .707 .577 .707 r
F P
0 g
s
.68936 .67519 m .68936 .61961 L .70195 .62749 L p .707 .577 .707 r
F P
0 g
s
.44643 .82984 m .44643 .32795 L .40766 .32175 L p .707 .577 .707 r
F P
0 g
s
.44643 .32795 m .44643 .82984 L .49044 .83252 L p .707 .577 .707 r
F P
0 g
s
.70485 .75157 m .70485 .7701 L .70195 .76156 L p .707 .577 .707 r
F P
0 g
s
.70195 .76156 m .70195 .74303 L .70485 .75157 L p .707 .577 .707 r
F P
0 g
s
.25312 .68034 m .25312 .62476 L .22195 .62286 L p .707 .577 .707 r
F P
0 g
s
.25312 .62476 m .25312 .68034 L .28495 .67956 L p .707 .577 .707 r
F P
0 g
s
.28495 .67956 m .28495 .62398 L .25312 .62476 L p .707 .577 .707 r
F P
0 g
s
.57784 .66322 m .57784 .60764 L .60968 .60686 L p .707 .577 .707 r
F P
0 g
s
.60968 .60686 m .60968 .66244 L .57784 .66322 L p .707 .577 .707 r
F P
0 g
s
.57784 .7417 m .57784 .72317 L .60968 .7224 L p .707 .577 .707 r
F P
0 g
s
.60968 .7224 m .60968 .74092 L .57784 .7417 L p .707 .577 .707 r
F P
0 g
s
.64085 .77953 m .64085 .81659 L .60968 .81469 L p .707 .577 .707 r
F P
0 g
s
.60968 .81469 m .60968 .77763 L .64085 .77953 L p .707 .577 .707 r
F P
0 g
s
.57784 .81546 m .57784 .77841 L .60968 .77763 L p .707 .577 .707 r
F P
0 g
s
.60968 .77763 m .60968 .81469 L .57784 .81546 L p .707 .577 .707 r
F P
0 g
s
.57686 .32476 m .57686 .82665 L .61082 .81868 L p .707 .577 .707 r
F P
0 g
s
.64085 .60876 m .64085 .66434 L .60968 .66244 L p .707 .577 .707 r
F P
0 g
s
.60968 .66244 m .60968 .60686 L .64085 .60876 L p .707 .577 .707 r
F P
0 g
s
.64085 .7243 m .64085 .74283 L .60968 .74092 L p .707 .577 .707 r
F P
0 g
s
.60968 .74092 m .60968 .7224 L .64085 .7243 L p .707 .577 .707 r
F P
0 g
s
.61082 .81868 m .61082 .31679 L .57686 .32476 L p .707 .577 .707 r
F P
0 g
s
.28495 .62398 m .28495 .67956 L .31434 .67618 L p .707 .577 .707 r
F P
0 g
s
.31434 .67618 m .31434 .6206 L .28495 .62398 L p .707 .577 .707 r
F P
0 g
s
.22195 .67844 m .22195 .62286 L .19449 .61846 L p .707 .577 .707 r
F P
0 g
s
.22195 .62286 m .22195 .67844 L .25312 .68034 L p .707 .577 .707 r
F P
0 g
s
.70485 .8068 m .70485 .84386 L .70195 .83532 L p .707 .577 .707 r
F P
0 g
s
.70195 .83532 m .70195 .79826 L .70485 .8068 L p .707 .577 .707 r
F P
0 g
s
.40766 .82364 m .40766 .32175 L .37794 .31264 L p .707 .577 .707 r
F P
0 g
s
.40766 .32175 m .40766 .82364 L .44643 .82984 L p .707 .577 .707 r
F P
0 g
s
.31434 .6206 m .31434 .67618 L .33839 .67053 L p .707 .577 .707 r
F P
0 g
s
.33839 .67053 m .33839 .61495 L .31434 .6206 L p .707 .577 .707 r
F P
0 g
s
.68936 .61961 m .68936 .67519 L .66831 .66874 L p .707 .577 .707 r
F P
0 g
s
.66831 .66874 m .66831 .61315 L .68936 .61961 L p .707 .577 .707 r
F P
0 g
s
.19449 .61846 m .19449 .67405 L .22195 .67844 L p .707 .577 .707 r
F P
0 g
s
.70195 .74303 m .70195 .76156 L .68936 .75367 L p .707 .577 .707 r
F P
0 g
s
.68936 .75367 m .68936 .73514 L .70195 .74303 L p .707 .577 .707 r
F P
0 g
s
.19449 .67405 m .19449 .61846 L .17343 .61201 L p .707 .577 .707 r
F P
0 g
s
.61082 .31679 m .61082 .81868 L .63393 .80828 L p .707 .577 .707 r
F P
0 g
s
.63393 .80828 m .63393 .30639 L .61082 .31679 L p .707 .577 .707 r
F P
0 g
s
.25312 .75882 m .25312 .74029 L .22195 .73839 L p .707 .577 .707 r
F P
0 g
s
.25312 .74029 m .25312 .75882 L .28495 .75804 L p .707 .577 .707 r
F P
0 g
s
.28495 .75804 m .28495 .73952 L .25312 .74029 L p .707 .577 .707 r
F P
0 g
s
.28495 .73952 m .28495 .75804 L .31434 .75466 L p .707 .577 .707 r
F P
0 g
s
.31434 .75466 m .31434 .73614 L .28495 .73952 L p .707 .577 .707 r
F P
0 g
s
.33839 .61495 m .33839 .67053 L .35476 .66317 L p .707 .577 .707 r
F P
0 g
s
.35476 .66317 m .35476 .60758 L .33839 .61495 L p .707 .577 .707 r
F P
0 g
s
.22195 .73839 m .22195 .75692 L .25312 .75882 L p .707 .577 .707 r
F P
0 g
s
.70195 .79826 m .70195 .83532 L .68936 .82743 L p .707 .577 .707 r
F P
0 g
s
.68936 .82743 m .68936 .79038 L .70195 .79826 L p .707 .577 .707 r
F P
0 g
s
.17343 .61201 m .17343 .66759 L .19449 .67405 L p .707 .577 .707 r
F P
0 g
s
.22195 .75692 m .22195 .73839 L .19449 .734 L p .707 .577 .707 r
F P
0 g
s
.66831 .61315 m .66831 .66874 L .64085 .66434 L p .707 .577 .707 r
F P
0 g
s
.64085 .66434 m .64085 .60876 L .66831 .61315 L p .707 .577 .707 r
F P
0 g
s
.19449 .734 m .19449 .75253 L .22195 .75692 L p .707 .577 .707 r
F P
0 g
s
.17343 .66759 m .17343 .61201 L .16084 .60413 L p .707 .577 .707 r
F P
0 g
s
.37794 .81452 m .37794 .31264 L .36016 .30151 L p .707 .577 .707 r
F P
0 g
s
.37794 .31264 m .37794 .81452 L .40766 .82364 L p .707 .577 .707 r
F P
0 g
s
.31434 .73614 m .31434 .75466 L .33839 .74901 L p .707 .577 .707 r
F P
0 g
s
.33839 .74901 m .33839 .73049 L .31434 .73614 L p .707 .577 .707 r
F P
0 g
s
.25312 .83258 m .25312 .79553 L .22195 .79363 L p .707 .577 .707 r
F P
0 g
s
.25312 .79553 m .25312 .83258 L .28495 .8318 L p .707 .577 .707 r
F P
0 g
s
.28495 .8318 m .28495 .79475 L .25312 .79553 L p .707 .577 .707 r
F P
0 g
s
.28495 .79475 m .28495 .8318 L .31434 .82843 L p .707 .577 .707 r
F P
0 g
s
.31434 .82843 m .31434 .79137 L .28495 .79475 L p .707 .577 .707 r
F P
0 g
s
.68936 .73514 m .68936 .75367 L .66831 .74722 L p .707 .577 .707 r
F P
0 g
s
.66831 .74722 m .66831 .72869 L .68936 .73514 L p .707 .577 .707 r
F P
0 g
s
.22195 .83068 m .22195 .79363 L .19449 .78923 L p .707 .577 .707 r
F P
0 g
s
.22195 .79363 m .22195 .83068 L .25312 .83258 L p .707 .577 .707 r
F P
0 g
s
.19449 .75253 m .19449 .734 L .17343 .72755 L p .707 .577 .707 r
F P
0 g
s
.17343 .72755 m .17343 .74607 L .19449 .75253 L p .707 .577 .707 r
F P
0 g
s
.16084 .60413 m .16084 .65971 L .17343 .66759 L p .707 .577 .707 r
F P
0 g
s
.35476 .60758 m .35476 .66317 L .36184 .6548 L p .707 .577 .707 r
F P
0 g
s
.36184 .6548 m .36184 .59922 L .35476 .60758 L p .707 .577 .707 r
F P
0 g
s
.31434 .79137 m .31434 .82843 L .33839 .82278 L p .707 .577 .707 r
F P
0 g
s
.33839 .82278 m .33839 .78572 L .31434 .79137 L p .707 .577 .707 r
F P
0 g
s
.19449 .78923 m .19449 .82629 L .22195 .83068 L p .707 .577 .707 r
F P
0 g
s
.68936 .79038 m .68936 .82743 L .66831 .82098 L p .707 .577 .707 r
F P
0 g
s
.66831 .82098 m .66831 .78392 L .68936 .79038 L p .707 .577 .707 r
F P
0 g
s
.33839 .73049 m .33839 .74901 L .35476 .74165 L p .707 .577 .707 r
F P
0 g
s
.35476 .74165 m .35476 .72312 L .33839 .73049 L p .707 .577 .707 r
F P
0 g
s
.66831 .72869 m .66831 .74722 L .64085 .74283 L p .707 .577 .707 r
F P
0 g
s
.64085 .74283 m .64085 .7243 L .66831 .72869 L p .707 .577 .707 r
F P
0 g
s
.64085 .81659 m .64085 .77953 L .66831 .78392 L p .707 .577 .707 r
F P
0 g
s
.63393 .30639 m .63393 .80828 L .64393 .79647 L p .707 .577 .707 r
F P
0 g
s
.64393 .79647 m .64393 .29458 L .63393 .30639 L p .707 .577 .707 r
F P
0 g
s
.19449 .82629 m .19449 .78923 L .17343 .78278 L p .707 .577 .707 r
F P
0 g
s
.16084 .65971 m .16084 .60413 L .15794 .59558 L p .707 .577 .707 r
F P
0 g
s
.17343 .74607 m .17343 .72755 L .16084 .71966 L p .707 .577 .707 r
F P
0 g
s
.17343 .78278 m .17343 .81983 L .19449 .82629 L p .707 .577 .707 r
F P
0 g
s
.33839 .78572 m .33839 .82278 L .35476 .81541 L p .707 .577 .707 r
F P
0 g
s
.35476 .81541 m .35476 .77835 L .33839 .78572 L p .707 .577 .707 r
F P
0 g
s
.16084 .71966 m .16084 .73819 L .17343 .74607 L p .707 .577 .707 r
F P
0 g
s
.36184 .59922 m .36184 .6548 L .35894 .64626 L p .707 .577 .707 r
F P
0 g
s
.35894 .64626 m .35894 .59068 L .36184 .59922 L p .707 .577 .707 r
F P
0 g
s
.35476 .72312 m .35476 .74165 L .36184 .73328 L p .707 .577 .707 r
F P
0 g
s
.36184 .73328 m .36184 .71476 L .35476 .72312 L p .707 .577 .707 r
F P
0 g
s
.35476 .77835 m .35476 .81541 L .36184 .80704 L p .707 .577 .707 r
F P
0 g
s
.36184 .80704 m .36184 .76999 L .35476 .77835 L p .707 .577 .707 r
F P
0 g
s
.35894 .59068 m .35894 .64626 L .34635 .63837 L p .707 .577 .707 r
F P
0 g
s
.34635 .63837 m .34635 .58279 L .35894 .59068 L p .707 .577 .707 r
F P
0 g
s
.36184 .71476 m .36184 .73328 L .35894 .72474 L p .707 .577 .707 r
F P
0 g
s
.35894 .72474 m .35894 .70621 L .36184 .71476 L p .707 .577 .707 r
F P
0 g
s
.36184 .76999 m .36184 .80704 L .35894 .7985 L p .707 .577 .707 r
F P
0 g
s
.35894 .7985 m .35894 .76145 L .36184 .76999 L p .707 .577 .707 r
F P
0 g
s
.36016 .80339 m .36016 .30151 L .35607 .28945 L p .707 .577 .707 r
F P
0 g
s
.36016 .30151 m .36016 .80339 L .37794 .81452 L p .707 .577 .707 r
F P
0 g
s
.66831 .78392 m .66831 .82098 L .64085 .81659 L p .707 .577 .707 r
F P
0 g
s
.15794 .59558 m .15794 .65117 L .16084 .65971 L p .707 .577 .707 r
F P
0 g
s
.17343 .81983 m .17343 .78278 L .16084 .7749 L p .707 .577 .707 r
F P
0 g
s
.16084 .7749 m .16084 .81195 L .17343 .81983 L p .707 .577 .707 r
F P
0 g
s
.15794 .65117 m .15794 .59558 L .16503 .58722 L p .707 .577 .707 r
F P
0 g
s
.16084 .73819 m .16084 .71966 L .15794 .71112 L p .707 .577 .707 r
F P
0 g
s
.64393 .29458 m .64393 .79647 L .63984 .78441 L p .707 .577 .707 r
F P
0 g
s
.63984 .78441 m .63984 .28252 L .64393 .29458 L p .707 .577 .707 r
F P
0 g
s
.15794 .71112 m .15794 .72965 L .16084 .73819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .58722 m .16503 .6428 L .15794 .65117 L p .707 .577 .707 r
F P
0 g
s
.16084 .81195 m .16084 .7749 L .15794 .76635 L p .707 .577 .707 r
F P
0 g
s
.35894 .70621 m .35894 .72474 L .34635 .71686 L p .707 .577 .707 r
F P
0 g
s
.34635 .71686 m .34635 .69833 L .35894 .70621 L p .707 .577 .707 r
F P
0 g
s
.35894 .76145 m .35894 .7985 L .34635 .79062 L p .707 .577 .707 r
F P
0 g
s
.34635 .79062 m .34635 .75356 L .35894 .76145 L p .707 .577 .707 r
F P
0 g
s
.35607 .28945 m .35607 .79133 L .36016 .80339 L p .707 .577 .707 r
F P
0 g
s
.35607 .79133 m .35607 .28945 L .36607 .27764 L p .707 .577 .707 r
F P
0 g
s
.15794 .76635 m .15794 .80341 L .16084 .81195 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .6428 m .16503 .58722 L .1814 .57985 L p .707 .577 .707 r
F P
0 g
s
.15794 .72965 m .15794 .71112 L .16503 .70276 L p .707 .577 .707 r
F P
0 g
s
.16503 .70276 m .16503 .72128 L .15794 .72965 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1814 .57985 m .1814 .63543 L .16503 .6428 L p .707 .577 .707 r
F P
0 g
s
.34635 .58279 m .34635 .63837 L .3253 .63192 L p .707 .577 .707 r
F P
0 g
s
.3253 .63192 m .3253 .57634 L .34635 .58279 L p .707 .577 .707 r
F P
0 g
s
.15794 .80341 m .15794 .76635 L .16503 .75799 L p .707 .577 .707 r
F P
0 g
s
.63984 .28252 m .63984 .78441 L .62206 .77328 L p .707 .577 .707 r
F P
0 g
s
.62206 .77328 m .62206 .27139 L .63984 .28252 L p .707 .577 .707 r
F P
0 g
s
.1814 .63543 m .1814 .57985 L .20545 .5742 L p .707 .577 .707 r
F P
0 g
s
.16503 .75799 m .16503 .79504 L .15794 .80341 L p .707 .577 .707 r
F P
0 g
s
.16503 .72128 m .16503 .70276 L .1814 .69539 L p .707 .577 .707 r
F P
0 g
s
.36607 .77953 m .36607 .27764 L .38918 .26724 L p .707 .577 .707 r
F P
0 g
s
.36607 .27764 m .36607 .77953 L .35607 .79133 L p .707 .577 .707 r
F P
0 g
s
.1814 .69539 m .1814 .71392 L .16503 .72128 L p .707 .577 .707 r
F P
0 g
s
.3253 .57634 m .3253 .63192 L .29784 .62753 L p .707 .577 .707 r
F P
0 g
s
.29784 .62753 m .29784 .57195 L .3253 .57634 L p .707 .577 .707 r
F P
0 g
s
.20545 .5742 m .20545 .62978 L .1814 .63543 L p .707 .577 .707 r
F P
0 g
s
.20545 .62978 m .20545 .5742 L .23483 .57082 L p .707 .577 .707 r
F P
0 g
s
.16503 .79504 m .16503 .75799 L .1814 .75062 L p .707 .577 .707 r
F P
0 g
s
.34635 .69833 m .34635 .71686 L .3253 .7104 L p .707 .577 .707 r
F P
0 g
s
.3253 .7104 m .3253 .69187 L .34635 .69833 L p .707 .577 .707 r
F P
0 g
s
.29784 .57195 m .29784 .62753 L .26667 .62563 L p .707 .577 .707 r
F P
0 g
s
.26667 .62563 m .26667 .57005 L .29784 .57195 L p .707 .577 .707 r
F P
0 g
s
.1814 .75062 m .1814 .78768 L .16503 .79504 L p .707 .577 .707 r
F P
0 g
s
.1814 .71392 m .1814 .69539 L .20545 .68974 L p .707 .577 .707 r
F P
0 g
s
.23483 .6264 m .23483 .57082 L .26667 .57005 L p .707 .577 .707 r
F P
0 g
s
.23483 .57082 m .23483 .6264 L .20545 .62978 L p .707 .577 .707 r
F P
0 g
s
.62206 .27139 m .62206 .77328 L .59233 .76417 L p .707 .577 .707 r
F P
0 g
s
.59233 .76417 m .59233 .26228 L .62206 .27139 L p .707 .577 .707 r
F P
0 g
s
.26667 .57005 m .26667 .62563 L .23483 .6264 L p .707 .577 .707 r
F P
0 g
s
.34635 .75356 m .34635 .79062 L .3253 .78416 L p .707 .577 .707 r
F P
0 g
s
.3253 .78416 m .3253 .74711 L .34635 .75356 L p .707 .577 .707 r
F P
0 g
s
.73333 .62512 m .73333 .56953 L .70216 .56763 L p .707 .577 .707 r
F P
0 g
s
.73333 .56953 m .73333 .62512 L .76517 .62434 L p .707 .577 .707 r
F P
0 g
s
.76517 .62434 m .76517 .56876 L .73333 .56953 L p .707 .577 .707 r
F P
0 g
s
.20545 .68974 m .20545 .70827 L .1814 .71392 L p .707 .577 .707 r
F P
0 g
s
.76517 .56876 m .76517 .62434 L .79455 .62096 L p .707 .577 .707 r
F P
0 g
s
.79455 .62096 m .79455 .56538 L .76517 .56876 L p .707 .577 .707 r
F P
0 g
s
.70216 .62322 m .70216 .56763 L .6747 .56324 L p .707 .577 .707 r
F P
0 g
s
.70216 .56763 m .70216 .62322 L .73333 .62512 L p .707 .577 .707 r
F P
0 g
s
.3253 .69187 m .3253 .7104 L .29784 .70601 L p .707 .577 .707 r
F P
0 g
s
.29784 .70601 m .29784 .68748 L .3253 .69187 L p .707 .577 .707 r
F P
0 g
s
.1814 .78768 m .1814 .75062 L .20545 .74497 L p .707 .577 .707 r
F P
0 g
s
.38918 .26724 m .38918 .76912 L .36607 .77953 L p .707 .577 .707 r
F P
0 g
s
.38918 .76912 m .38918 .26724 L .42314 .25926 L p .707 .577 .707 r
F P
0 g
s
.79455 .56538 m .79455 .62096 L .8186 .61531 L p .707 .577 .707 r
F P
0 g
s
.8186 .61531 m .8186 .55973 L .79455 .56538 L p .707 .577 .707 r
F P
0 g
s
.20545 .70827 m .20545 .68974 L .23483 .68636 L p .707 .577 .707 r
F P
0 g
s
.23483 .68636 m .23483 .70489 L .20545 .70827 L p .707 .577 .707 r
F P
0 g
s
.20545 .74497 m .20545 .78203 L .1814 .78768 L p .707 .577 .707 r
F P
0 g
s
.6747 .56324 m .6747 .61882 L .70216 .62322 L p .707 .577 .707 r
F P
0 g
s
.6747 .61882 m .6747 .56324 L .65365 .55679 L p .707 .577 .707 r
F P
0 g
s
.3253 .74711 m .3253 .78416 L .29784 .77977 L p .707 .577 .707 r
F P
0 g
s
.29784 .77977 m .29784 .74272 L .3253 .74711 L p .707 .577 .707 r
F P
0 g
s
.29784 .68748 m .29784 .70601 L .26667 .70411 L p .707 .577 .707 r
F P
0 g
s
.26667 .70411 m .26667 .68558 L .29784 .68748 L p .707 .577 .707 r
F P
0 g
s
.23483 .70489 m .23483 .68636 L .26667 .68558 L p .707 .577 .707 r
F P
0 g
s
.59233 .26228 m .59233 .76417 L .55357 .75796 L p .707 .577 .707 r
F P
0 g
s
.55357 .75796 m .55357 .25608 L .59233 .26228 L p .707 .577 .707 r
F P
0 g
s
.26667 .68558 m .26667 .70411 L .23483 .70489 L p .707 .577 .707 r
F P
0 g
s
.20545 .78203 m .20545 .74497 L .23483 .74159 L p .707 .577 .707 r
F P
0 g
s
.73333 .7036 m .73333 .68507 L .70216 .68317 L p .707 .577 .707 r
F P
0 g
s
.73333 .68507 m .73333 .7036 L .76517 .70282 L p .707 .577 .707 r
F P
0 g
s
.76517 .70282 m .76517 .68429 L .73333 .68507 L p .707 .577 .707 r
F P
0 g
s
.76517 .68429 m .76517 .70282 L .79455 .69944 L p .707 .577 .707 r
F P
0 g
s
.79455 .69944 m .79455 .68091 L .76517 .68429 L p .707 .577 .707 r
F P
0 g
s
.8186 .55973 m .8186 .61531 L .83497 .60794 L p .707 .577 .707 r
F P
0 g
s
.83497 .60794 m .83497 .55236 L .8186 .55973 L p .707 .577 .707 r
F P
0 g
s
.70216 .68317 m .70216 .7017 L .73333 .7036 L p .707 .577 .707 r
F P
0 g
s
.65365 .55679 m .65365 .61237 L .6747 .61882 L p .707 .577 .707 r
F P
0 g
s
.29784 .74272 m .29784 .77977 L .26667 .77787 L p .707 .577 .707 r
F P
0 g
s
.26667 .77787 m .26667 .74082 L .29784 .74272 L p .707 .577 .707 r
F P
0 g
s
.70216 .7017 m .70216 .68317 L .6747 .67878 L p .707 .577 .707 r
F P
0 g
s
.42314 .76115 m .42314 .25926 L .46462 .25449 L p .707 .577 .707 r
F P
0 g
s
.42314 .25926 m .42314 .76115 L .38918 .76912 L p .707 .577 .707 r
F P
0 g
s
.23483 .74159 m .23483 .77865 L .20545 .78203 L p .707 .577 .707 r
F P
0 g
s
.23483 .77865 m .23483 .74159 L .26667 .74082 L p .707 .577 .707 r
F P
0 g
s
.6747 .67878 m .6747 .6973 L .70216 .7017 L p .707 .577 .707 r
F P
0 g
s
.26667 .74082 m .26667 .77787 L .23483 .77865 L p .707 .577 .707 r
F P
0 g
s
.65365 .61237 m .65365 .55679 L .64105 .5489 L p .707 .577 .707 r
F P
0 g
s
.79455 .68091 m .79455 .69944 L .8186 .69379 L p .707 .577 .707 r
F P
0 g
s
.8186 .69379 m .8186 .67526 L .79455 .68091 L p .707 .577 .707 r
F P
0 g
s
.73333 .77736 m .73333 .7403 L .70216 .7384 L p .707 .577 .707 r
F P
0 g
s
.73333 .7403 m .73333 .77736 L .76517 .77658 L p .707 .577 .707 r
F P
0 g
s
.76517 .77658 m .76517 .73953 L .73333 .7403 L p .707 .577 .707 r
F P
0 g
s
.76517 .73953 m .76517 .77658 L .79455 .7732 L p .707 .577 .707 r
F P
0 g
s
.79455 .7732 m .79455 .73615 L .76517 .73953 L p .707 .577 .707 r
F P
0 g
s
.55357 .25608 m .55357 .75796 L .50956 .75528 L p .707 .577 .707 r
F P
0 g
s
.50956 .75528 m .50956 .25339 L .55357 .25608 L p .707 .577 .707 r
F P
0 g
s
.70216 .77546 m .70216 .7384 L .6747 .73401 L p .707 .577 .707 r
F P
0 g
s
.70216 .7384 m .70216 .77546 L .73333 .77736 L p .707 .577 .707 r
F P
0 g
s
.6747 .6973 m .6747 .67878 L .65365 .67232 L p .707 .577 .707 r
F P
0 g
s
.46462 .75638 m .46462 .25449 L .50956 .25339 L p .707 .577 .707 r
F P
0 g
s
.46462 .25449 m .46462 .75638 L .42314 .76115 L p .707 .577 .707 r
F P
0 g
s
.65365 .67232 m .65365 .69085 L .6747 .6973 L p .707 .577 .707 r
F P
0 g
s
.50956 .25339 m .50956 .75528 L .46462 .75638 L p .707 .577 .707 r
F P
0 g
s
.64105 .5489 m .64105 .60448 L .65365 .61237 L p .707 .577 .707 r
F P
0 g
s
.83497 .55236 m .83497 .60794 L .84205 .59958 L p .707 .577 .707 r
F P
0 g
s
.84205 .59958 m .84205 .544 L .83497 .55236 L p .707 .577 .707 r
F P
0 g
s
.79455 .73615 m .79455 .7732 L .8186 .76755 L p .707 .577 .707 r
F P
0 g
s
.8186 .76755 m .8186 .7305 L .79455 .73615 L p .707 .577 .707 r
F P
0 g
s
.6747 .73401 m .6747 .77107 L .70216 .77546 L p .707 .577 .707 r
F P
0 g
s
.8186 .67526 m .8186 .69379 L .83497 .68642 L p .707 .577 .707 r
F P
0 g
s
.83497 .68642 m .83497 .6679 L .8186 .67526 L p .707 .577 .707 r
F P
0 g
s
.6747 .77107 m .6747 .73401 L .65365 .72756 L p .707 .577 .707 r
F P
0 g
s
.64105 .60448 m .64105 .5489 L .63816 .54036 L p .707 .577 .707 r
F P
0 g
s
.65365 .69085 m .65365 .67232 L .64105 .66444 L p .707 .577 .707 r
F P
0 g
s
.65365 .72756 m .65365 .76461 L .6747 .77107 L p .707 .577 .707 r
F P
0 g
s
.8186 .7305 m .8186 .76755 L .83497 .76019 L p .707 .577 .707 r
F P
0 g
s
.83497 .76019 m .83497 .72313 L .8186 .7305 L p .707 .577 .707 r
F P
0 g
s
.64105 .66444 m .64105 .68297 L .65365 .69085 L p .707 .577 .707 r
F P
0 g
s
.63816 .54036 m .63816 .59594 L .64105 .60448 L p .707 .577 .707 r
F P
0 g
s
.84205 .544 m .84205 .59958 L .83916 .59104 L p .707 .577 .707 r
F P
0 g
s
.83916 .59104 m .83916 .53545 L .84205 .544 L p .707 .577 .707 r
F P
0 g
s
.65365 .76461 m .65365 .72756 L .64105 .71967 L p .707 .577 .707 r
F P
0 g
s
.83497 .6679 m .83497 .68642 L .84206 .67806 L p .707 .577 .707 r
F P
0 g
s
.84206 .67806 m .84205 .65953 L .83497 .6679 L p .707 .577 .707 r
F P
0 g
s
.64105 .71967 m .64105 .75673 L .65365 .76461 L p .707 .577 .707 r
F P
0 g
s
.63816 .59594 m .63816 .54036 L .64524 .532 L p .707 .577 .707 r
F P
0 g
s
.64105 .68297 m .64105 .66444 L .63816 .6559 L p .707 .577 .707 r
F P
0 g
s
.83497 .72313 m .83497 .76019 L .84206 .75182 L p .707 .577 .707 r
F P
0 g
s
.84206 .75182 m .84206 .71477 L .83497 .72313 L p .707 .577 .707 r
F P
0 g
s
.63816 .6559 m .63816 .67442 L .64105 .68297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .532 m .64524 .58758 L .63816 .59594 L p .707 .577 .707 r
F P
0 g
s
.64105 .75673 m .64105 .71967 L .63816 .71113 L p .707 .577 .707 r
F P
0 g
s
.83916 .53545 m .83916 .59104 L .82657 .58315 L p .707 .577 .707 r
F P
0 g
s
.82657 .58315 m .82657 .52757 L .83916 .53545 L p .707 .577 .707 r
F P
0 g
s
.84205 .65953 m .84206 .67806 L .83916 .66952 L p .707 .577 .707 r
F P
0 g
s
.83916 .66952 m .83916 .65099 L .84205 .65953 L p .707 .577 .707 r
F P
0 g
s
.63816 .71113 m .63816 .74819 L .64105 .75673 L p .707 .577 .707 r
F P
0 g
s
.39032 .5883 m .39032 .53272 L .35915 .53082 L p .707 .577 .707 r
F P
0 g
s
.39032 .53272 m .39032 .5883 L .42216 .58752 L p .707 .577 .707 r
F P
0 g
s
.42216 .58752 m .42216 .53194 L .39032 .53272 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58758 m .64524 .532 L .66161 .52463 L p .707 .577 .707 r
F P
0 g
s
.42216 .53194 m .42216 .58752 L .45154 .58414 L p .707 .577 .707 r
F P
0 g
s
.45154 .58414 m .45154 .52856 L .42216 .53194 L p .707 .577 .707 r
F P
0 g
s
.63816 .67442 m .63816 .6559 L .64524 .64753 L p .707 .577 .707 r
F P
0 g
s
.35915 .5864 m .35915 .53082 L .33169 .52643 L p .707 .577 .707 r
F P
0 g
s
.35915 .53082 m .35915 .5864 L .39032 .5883 L p .707 .577 .707 r
F P
0 g
s
.84206 .71477 m .84206 .75182 L .83916 .74328 L p .707 .577 .707 r
F P
0 g
s
.83916 .74328 m .83916 .70622 L .84206 .71477 L p .707 .577 .707 r
F P
0 g
s
.64524 .64753 m .64524 .66606 L .63816 .67442 L p .707 .577 .707 r
F P
0 g
s
.45154 .52856 m .45154 .58414 L .47559 .57849 L p .707 .577 .707 r
F P
0 g
s
.47559 .57849 m .47559 .52291 L .45154 .52856 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66161 .52463 m .66161 .58021 L .64524 .58758 L p .707 .577 .707 r
F P
0 g
s
.82657 .52757 m .82657 .58315 L .80551 .5767 L p .707 .577 .707 r
F P
0 g
s
.80551 .5767 m .80551 .52111 L .82657 .52757 L p .707 .577 .707 r
F P
0 g
s
.63816 .74819 m .63816 .71113 L .64524 .70277 L p .707 .577 .707 r
F P
0 g
s
.33169 .52643 m .33169 .58201 L .35915 .5864 L p .707 .577 .707 r
F P
0 g
s
.83916 .65099 m .83916 .66952 L .82657 .66163 L p .707 .577 .707 r
F P
0 g
s
.82657 .66163 m .82657 .64311 L .83916 .65099 L p .707 .577 .707 r
F P
0 g
s
.33169 .58201 m .33169 .52643 L .31064 .51997 L p .707 .577 .707 r
F P
0 g
s
.66161 .58021 m .66161 .52463 L .68566 .51898 L p .707 .577 .707 r
F P
0 g
s
.64524 .70277 m .64524 .73982 L .63816 .74819 L p .707 .577 .707 r
F P
0 g
s
.39032 .66678 m .39032 .64825 L .35915 .64635 L p .707 .577 .707 r
F P
0 g
s
.39032 .64825 m .39032 .66678 L .42216 .666 L p .707 .577 .707 r
F P
0 g
s
.42216 .666 m .42216 .64748 L .39032 .64825 L p .707 .577 .707 r
F P
0 g
s
.64524 .66606 m .64524 .64753 L .66161 .64016 L p .707 .577 .707 r
F P
0 g
s
.42216 .64748 m .42216 .666 L .45154 .66263 L p .707 .577 .707 r
F P
0 g
s
.45154 .66263 m .45154 .6441 L .42216 .64748 L p .707 .577 .707 r
F P
0 g
s
.47559 .52291 m .47559 .57849 L .49196 .57113 L p .707 .577 .707 r
F P
0 g
s
.49196 .57113 m .49196 .51554 L .47559 .52291 L p .707 .577 .707 r
F P
0 g
s
.35915 .64635 m .35915 .66488 L .39032 .66678 L p .707 .577 .707 r
F P
0 g
s
.83916 .70622 m .83916 .74328 L .82657 .73539 L p .707 .577 .707 r
F P
0 g
s
.82657 .73539 m .82657 .69834 L .83916 .70622 L p .707 .577 .707 r
F P
0 g
s
.31064 .51997 m .31064 .57555 L .33169 .58201 L p .707 .577 .707 r
F P
0 g
s
.35915 .66488 m .35915 .64635 L .33169 .64196 L p .707 .577 .707 r
F P
0 g
s
.66161 .64016 m .66161 .65869 L .64524 .66606 L p .707 .577 .707 r
F P
0 g
s
.80551 .52111 m .80551 .5767 L .77805 .5723 L p .707 .577 .707 r
F P
0 g
s
.77805 .5723 m .77805 .51672 L .80551 .52111 L p .707 .577 .707 r
F P
0 g
s
.33169 .64196 m .33169 .66049 L .35915 .66488 L p .707 .577 .707 r
F P
0 g
s
.68566 .51898 m .68566 .57456 L .66161 .58021 L p .707 .577 .707 r
F P
0 g
s
.31064 .57555 m .31064 .51997 L .29804 .51209 L p .707 .577 .707 r
F P
0 g
s
.45154 .6441 m .45154 .66263 L .47559 .65698 L p .707 .577 .707 r
F P
0 g
s
.47559 .65698 m .47559 .63845 L .45154 .6441 L p .707 .577 .707 r
F P
0 g
s
.39032 .74054 m .39032 .70349 L .35915 .70159 L p .707 .577 .707 r
F P
0 g
s
.39032 .70349 m .39032 .74054 L .42216 .73977 L p .707 .577 .707 r
F P
0 g
s
.42216 .73977 m .42216 .70271 L .39032 .70349 L p .707 .577 .707 r
F P
0 g
s
.68566 .57456 m .68566 .51898 L .71504 .5156 L p .707 .577 .707 r
F P
0 g
s
.64524 .73982 m .64524 .70277 L .66161 .6954 L p .707 .577 .707 r
F P
0 g
s
.42216 .70271 m .42216 .73977 L .45154 .73639 L p .707 .577 .707 r
F P
0 g
s
.45154 .73639 m .45154 .69933 L .42216 .70271 L p .707 .577 .707 r
F P
0 g
s
.82657 .64311 m .82657 .66163 L .80551 .65518 L p .707 .577 .707 r
F P
0 g
s
.80551 .65518 m .80551 .63665 L .82657 .64311 L p .707 .577 .707 r
F P
0 g
s
.35915 .73864 m .35915 .70159 L .33169 .6972 L p .707 .577 .707 r
F P
0 g
s
.35915 .70159 m .35915 .73864 L .39032 .74054 L p .707 .577 .707 r
F P
0 g
s
.33169 .66049 m .33169 .64196 L .31064 .63551 L p .707 .577 .707 r
F P
0 g
s
.77805 .51672 m .77805 .5723 L .74688 .5704 L p .707 .577 .707 r
F P
0 g
s
.74688 .5704 m .74688 .51482 L .77805 .51672 L p .707 .577 .707 r
F P
0 g
s
.31064 .63551 m .31064 .65404 L .33169 .66049 L p .707 .577 .707 r
F P
0 g
s
.66161 .6954 m .66161 .73245 L .64524 .73982 L p .707 .577 .707 r
F P
0 g
s
.66161 .65869 m .66161 .64016 L .68566 .63451 L p .707 .577 .707 r
F P
0 g
s
.29804 .51209 m .29804 .56767 L .31064 .57555 L p .707 .577 .707 r
F P
0 g
s
.71504 .57118 m .71504 .5156 L .74688 .51482 L p .707 .577 .707 r
F P
0 g
s
.71504 .5156 m .71504 .57118 L .68566 .57456 L p .707 .577 .707 r
F P
0 g
s
.49196 .51554 m .49196 .57113 L .49904 .56276 L p .707 .577 .707 r
F P
0 g
s
.49904 .56276 m .49904 .50718 L .49196 .51554 L p .707 .577 .707 r
F P
0 g
s
.45154 .69933 m .45154 .73639 L .47559 .73074 L p .707 .577 .707 r
F P
0 g
s
.47559 .73074 m .47559 .69368 L .45154 .69933 L p .707 .577 .707 r
F P
0 g
s
.74688 .51482 m .74688 .5704 L .71504 .57118 L p .707 .577 .707 r
F P
0 g
s
.33169 .6972 m .33169 .73425 L .35915 .73864 L p .707 .577 .707 r
F P
0 g
s
.82657 .69834 m .82657 .73539 L .80551 .72894 L p .707 .577 .707 r
F P
0 g
s
.80551 .72894 m .80551 .69189 L .82657 .69834 L p .707 .577 .707 r
F P
0 g
s
.68566 .63451 m .68566 .65304 L .66161 .65869 L p .707 .577 .707 r
F P
0 g
s
.47559 .63845 m .47559 .65698 L .49196 .64961 L p .707 .577 .707 r
F P
0 g
s
.49196 .64961 m .49196 .63108 L .47559 .63845 L p .707 .577 .707 r
F P
0 g
s
.33169 .73425 m .33169 .6972 L .31064 .69074 L p .707 .577 .707 r
F P
0 g
s
.80551 .63665 m .80551 .65518 L .77805 .65079 L p .707 .577 .707 r
F P
0 g
s
.77805 .65079 m .77805 .63226 L .80551 .63665 L p .707 .577 .707 r
F P
0 g
s
.29804 .56767 m .29804 .51209 L .29515 .50354 L p .707 .577 .707 r
F P
0 g
s
.66161 .73245 m .66161 .6954 L .68566 .68975 L p .707 .577 .707 r
F P
0 g
s
.31064 .65404 m .31064 .63551 L .29804 .62762 L p .707 .577 .707 r
F P
0 g
s
.31064 .69074 m .31064 .7278 L .33169 .73425 L p .707 .577 .707 r
F P
0 g
s
.68566 .65304 m .68566 .63451 L .71504 .63114 L p .707 .577 .707 r
F P
0 g
s
.47559 .69368 m .47559 .73074 L .49196 .72337 L p .707 .577 .707 r
F P
0 g
s
.49196 .72337 m .49196 .68631 L .47559 .69368 L p .707 .577 .707 r
F P
0 g
s
.29804 .62762 m .29804 .64615 L .31064 .65404 L p .707 .577 .707 r
F P
0 g
s
.71504 .63114 m .71504 .64966 L .68566 .65304 L p .707 .577 .707 r
F P
0 g
s
.68566 .68975 m .68566 .7268 L .66161 .73245 L p .707 .577 .707 r
F P
0 g
s
.80551 .69189 m .80551 .72894 L .77805 .72455 L p .707 .577 .707 r
F P
0 g
s
.77805 .72455 m .77805 .68749 L .80551 .69189 L p .707 .577 .707 r
F P
0 g
s
.29515 .50354 m .29515 .55913 L .29804 .56767 L p .707 .577 .707 r
F P
0 g
s
.77805 .63226 m .77805 .65079 L .74688 .64889 L p .707 .577 .707 r
F P
0 g
s
.74688 .64889 m .74688 .63036 L .77805 .63226 L p .707 .577 .707 r
F P
0 g
s
.49904 .50718 m .49904 .56276 L .49615 .55422 L p .707 .577 .707 r
F P
0 g
s
.49615 .55422 m .49615 .49864 L .49904 .50718 L p .707 .577 .707 r
F P
0 g
s
.31064 .7278 m .31064 .69074 L .29804 .68286 L p .707 .577 .707 r
F P
0 g
s
.71504 .64966 m .71504 .63114 L .74688 .63036 L p .707 .577 .707 r
F P
0 g
s
.49196 .63108 m .49196 .64961 L .49904 .64124 L p .707 .577 .707 r
F P
0 g
s
.49904 .64124 m .49904 .62272 L .49196 .63108 L p .707 .577 .707 r
F P
0 g
s
.74688 .63036 m .74688 .64889 L .71504 .64966 L p .707 .577 .707 r
F P
0 g
s
.68566 .7268 m .68566 .68975 L .71504 .68637 L p .707 .577 .707 r
F P
0 g
s
.29804 .68286 m .29804 .71991 L .31064 .7278 L p .707 .577 .707 r
F P
0 g
s
.29515 .55913 m .29515 .50354 L .30223 .49518 L p .707 .577 .707 r
F P
0 g
s
.77805 .68749 m .77805 .72455 L .74688 .72265 L p .707 .577 .707 r
F P
0 g
s
.74688 .72265 m .74688 .68559 L .77805 .68749 L p .707 .577 .707 r
F P
0 g
s
.29804 .64615 m .29804 .62762 L .29515 .61908 L p .707 .577 .707 r
F P
0 g
s
.71504 .68637 m .71504 .72342 L .68566 .7268 L p .707 .577 .707 r
F P
0 g
s
.71504 .72342 m .71504 .68637 L .74688 .68559 L p .707 .577 .707 r
F P
0 g
s
.49196 .68631 m .49196 .72337 L .49904 .71501 L p .707 .577 .707 r
F P
0 g
s
.49904 .71501 m .49904 .67795 L .49196 .68631 L p .707 .577 .707 r
F P
0 g
s
.29515 .61908 m .29515 .63761 L .29804 .64615 L p .707 .577 .707 r
F P
0 g
s
.74688 .68559 m .74688 .72265 L .71504 .72342 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .49518 m .30223 .55076 L .29515 .55913 L p .707 .577 .707 r
F P
0 g
s
.29804 .71991 m .29804 .68286 L .29515 .67432 L p .707 .577 .707 r
F P
0 g
s
.49615 .49864 m .49615 .55422 L .48356 .54634 L p .707 .577 .707 r
F P
0 g
s
.48356 .54634 m .48356 .49075 L .49615 .49864 L p .707 .577 .707 r
F P
0 g
s
.49904 .62272 m .49904 .64124 L .49615 .6327 L p .707 .577 .707 r
F P
0 g
s
.49615 .6327 m .49615 .61417 L .49904 .62272 L p .707 .577 .707 r
F P
0 g
s
.29515 .67432 m .29515 .71137 L .29804 .71991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .55076 m .30223 .49518 L .3186 .48781 L p .707 .577 .707 r
F P
0 g
s
.29515 .63761 m .29515 .61908 L .30223 .61072 L p .707 .577 .707 r
F P
0 g
s
.49904 .67795 m .49904 .71501 L .49615 .70646 L p .707 .577 .707 r
F P
0 g
s
.49615 .70646 m .49615 .66941 L .49904 .67795 L p .707 .577 .707 r
F P
0 g
s
.30223 .61072 m .30223 .62924 L .29515 .63761 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .48781 m .3186 .54339 L .30223 .55076 L p .707 .577 .707 r
F P
0 g
s
.48356 .49075 m .48356 .54634 L .4625 .53988 L p .707 .577 .707 r
F P
0 g
s
.4625 .53988 m .4625 .4843 L .48356 .49075 L p .707 .577 .707 r
F P
0 g
s
.29515 .71137 m .29515 .67432 L .30223 .66595 L p .707 .577 .707 r
F P
0 g
s
.49615 .61417 m .49615 .6327 L .48356 .62482 L p .707 .577 .707 r
F P
0 g
s
.48356 .62482 m .48356 .60629 L .49615 .61417 L p .707 .577 .707 r
F P
0 g
s
.3186 .54339 m .3186 .48781 L .34265 .48216 L p .707 .577 .707 r
F P
0 g
s
.30223 .66595 m .30223 .70301 L .29515 .71137 L p .707 .577 .707 r
F P
0 g
s
.30223 .62924 m .30223 .61072 L .3186 .60335 L p .707 .577 .707 r
F P
0 g
s
.49615 .66941 m .49615 .70646 L .48356 .69858 L p .707 .577 .707 r
F P
0 g
s
.48356 .69858 m .48356 .66152 L .49615 .66941 L p .707 .577 .707 r
F P
0 g
s
.3186 .60335 m .3186 .62188 L .30223 .62924 L p .707 .577 .707 r
F P
0 g
s
.4625 .4843 m .4625 .53988 L .43504 .53549 L p .707 .577 .707 r
F P
0 g
s
.43504 .53549 m .43504 .47991 L .4625 .4843 L p .707 .577 .707 r
F P
0 g
s
.34265 .48216 m .34265 .53774 L .3186 .54339 L p .707 .577 .707 r
F P
0 g
s
.34265 .53774 m .34265 .48216 L .37203 .47878 L p .707 .577 .707 r
F P
0 g
s
.30223 .70301 m .30223 .66595 L .3186 .65858 L p .707 .577 .707 r
F P
0 g
s
.48356 .60629 m .48356 .62482 L .4625 .61836 L p .707 .577 .707 r
F P
0 g
s
.4625 .61836 m .4625 .59984 L .48356 .60629 L p .707 .577 .707 r
F P
0 g
s
.43504 .47991 m .43504 .53549 L .40387 .53359 L p .707 .577 .707 r
F P
0 g
s
.40387 .53359 m .40387 .47801 L .43504 .47991 L p .707 .577 .707 r
F P
0 g
s
.3186 .65858 m .3186 .69564 L .30223 .70301 L p .707 .577 .707 r
F P
0 g
s
.3186 .62188 m .3186 .60335 L .34265 .5977 L p .707 .577 .707 r
F P
0 g
s
.37203 .53437 m .37203 .47878 L .40387 .47801 L p .707 .577 .707 r
F P
0 g
s
.37203 .47878 m .37203 .53437 L .34265 .53774 L p .707 .577 .707 r
F P
0 g
s
.40387 .47801 m .40387 .53359 L .37203 .53437 L p .707 .577 .707 r
F P
0 g
s
.48356 .66152 m .48356 .69858 L .4625 .69212 L p .707 .577 .707 r
F P
0 g
s
.4625 .69212 m .4625 .65507 L .48356 .66152 L p .707 .577 .707 r
F P
0 g
s
.34265 .5977 m .34265 .61623 L .3186 .62188 L p .707 .577 .707 r
F P
0 g
s
.4625 .59984 m .4625 .61836 L .43504 .61397 L p .707 .577 .707 r
F P
0 g
s
.43504 .61397 m .43504 .59544 L .4625 .59984 L p .707 .577 .707 r
F P
0 g
s
.3186 .69564 m .3186 .65858 L .34265 .65293 L p .707 .577 .707 r
F P
0 g
s
.34265 .61623 m .34265 .5977 L .37203 .59432 L p .707 .577 .707 r
F P
0 g
s
.37203 .59432 m .37203 .61285 L .34265 .61623 L p .707 .577 .707 r
F P
0 g
s
.34265 .65293 m .34265 .68999 L .3186 .69564 L p .707 .577 .707 r
F P
0 g
s
.4625 .65507 m .4625 .69212 L .43504 .68773 L p .707 .577 .707 r
F P
0 g
s
.43504 .68773 m .43504 .65068 L .4625 .65507 L p .707 .577 .707 r
F P
0 g
s
.43504 .59544 m .43504 .61397 L .40387 .61207 L p .707 .577 .707 r
F P
0 g
s
.40387 .61207 m .40387 .59354 L .43504 .59544 L p .707 .577 .707 r
F P
0 g
s
.37203 .61285 m .37203 .59432 L .40387 .59354 L p .707 .577 .707 r
F P
0 g
s
.40387 .59354 m .40387 .61207 L .37203 .61285 L p .707 .577 .707 r
F P
0 g
s
.34265 .68999 m .34265 .65293 L .37203 .64955 L p .707 .577 .707 r
F P
0 g
s
.43504 .65068 m .43504 .68773 L .40387 .68583 L p .707 .577 .707 r
F P
0 g
s
.40387 .68583 m .40387 .64878 L .43504 .65068 L p .707 .577 .707 r
F P
0 g
s
.37203 .64955 m .37203 .68661 L .34265 .68999 L p .707 .577 .707 r
F P
0 g
s
.37203 .68661 m .37203 .64955 L .40387 .64878 L p .707 .577 .707 r
F P
0 g
s
.40387 .64878 m .40387 .68583 L .37203 .68661 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP06001gOol007Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP@007=oo`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`T000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001G
Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00003goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo
1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`00=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00IJEPP0
00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03
001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol00`00
FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolH00000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
009JEPL000QJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH005YF00AJEP04001JEUYFFUH2
000]Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<000=JEP04001JEUYFFUH2000]Ool0035oo`<000IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000=JEP8002eoo`00;goo0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYF0002FUH2000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUH0000B0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000]Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF2@0000=JEP00FUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF3P0015YF
00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH01000FUIJEUYF10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90003FUH01000FUH005YF0P000eYF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04
001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00001EYF00<005YFFUH00eYF6`00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH90008FUH4000015YF0000000015YF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00=JEP800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP02001EOol002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07
FUH00`00FUH0000300000eYF000000040004FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEQP003ioo`00
;7oo00<005YF00000eYF1P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP<0
00AJEP<00005FUH005YFFUH00002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00<003Yoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP04001JEP000003FUH00`00FUH000020003FUH30002FUH01000FUIJEP001EYF1@001EYF00<0
05YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP02FUH50000
15YF000000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF100000=JEP00FUH00UYF00<0
05YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH01000<Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
<Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF5`000eYF00<005YFFUH015YF00D0
05YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUH00000;goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP03FUH30004FUH00`00FUH000050003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH800000eYF001JEP05FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF200047oo20000eYF00<0
05YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF1`0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH00004FUH000000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH000020002FUH01000FUIJEUYF
0P0067oo1@0015YF00D005YFFUIJEP0002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000EJEP04001JEUYFFUH2000M
Ool300000eYF001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@0
05YFFUIJEP8000Qoo`<001Moo`800003FUH0000002eoo`00<goo0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUH0
05YF00<000AJEP04001JEUYFFUH20007Ool5000FOol5000]Ool003Ioo`D000AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P0015YF0`00
00=JEP00FUH00UYF0P001goo1@0057oo0P000UYF0`00;Goo000kOol80004FUH00`00FUIJEP07FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEP00008000=JEP<000=JEP80
00Moo`D0011oo`@000AJEP03001JEP0002eoo`00@goo4@0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF009JEPD00004FUH00000FUH20008Ool3000:Ool70003FUH00`00FUIJ
EP02FUH2000^Ool004Moo`T000=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH01000FUIJEUYF6`000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000oOol8
0004FUH00`00FUIJEP02FUH400000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF2@0015YF00<005YFFUH0
0UYF2@001UYF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEPH0
00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P0015YF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD0009JEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000=JEPP000Aoo`04001JEUYF0005FUH40006FUH00`00FUIJEP09FUH4
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000`00<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P0015YF1P000Woo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF009JEPL000=JEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000^Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000
FUH000EJEP04001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH00`00FUIJ
EP0200001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
0UYF5P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`8000AJ
EP03001JEUYF00=JEPH001Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF000015YF00<005YF00000`006Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00003FUH3000NOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00FUH2000ROol01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`04001JEP00
000HOol3000:Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P00
0UYF0`0057oo1@002goo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPH000Uoo`D000Aoo`P0
00=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP03001JEP000080015oo`D0
00ioo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEP000080011oo`<000eoo`D000AJEP04001JEUYFFUH2000]Ool002ao
o`8000=JEP03001JEUYF009JEPD000aoo`D000moo`D000IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEPP0021oo`H00003FUH005YF009JEP8002eoo`00;Goo
00D005YFFUIJEP0000EJEP04001JEUYFFUH80005Ool3000;Ool50005FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YFFUIJEPT0
019oo`D000EJEP<000=JEP8002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEQL000=JEP03
001JEUYF00AJEP04001JEUYFFUHI0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUHB0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002moo`<000EJEP03
001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000AJEP00000000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0039o
o`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00AJEPd000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02
FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP03001JEP0000=o
o`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH5000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUIJEUYF
0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF100015YF00<005YF00002`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF0000
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP05001JEUYFFUH00003FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUH000080004FUH0
0`00FUIJEP02FUH9000oOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQT0
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP040006FUH01000FUIJEUYF0P001Goo2@00B7oo000/Ool00`00FUH00004FUH01000FUIJ
EUYF200027oo1@0037oo1P0015YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH2000015YF001JEUYF1@000UYF00@005YF000005Qoo`00;7oo00<005YF000015YF10004Goo0`00
4goo0`0000AJEP00FUIJEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJ
EP03001JEP0000<005Yoo`00;7oo00<005YF00000UYF0P000eYF1@0087oo100000AJEP000000009J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP02FUH2001I
Ool002aoo`03001JEP0000<000EJEP04001JEUYFFUH8000:Ool>0005FUH01@00FUIJEP00FUH00P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00=JEP<005Moo`00
;7oo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000/Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000IJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YFFUH00eYF00@005YFFUIJ
EP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=oo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF
FUIJEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30003Ool80003FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000aOol30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000=Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3000>Ool50004FUH01000FUIJ
EUYF0P00E7oo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUH00003000COol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH0
0003000COol600000eYF001JEP02FUH2001DOol003Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF009JEPD001ioo``000IJEP03001JEUYF00YJEP03001JEUYF00=JEPL0019oo`D0
00EJEP<000=JEP8005Aoo`00?Goo6@00;goo<P000eYF00<005YFFUH015YF00<005YFFUH00P0000=J
EP000000E7oo002>Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3001DOol008ioo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<005Aoo`00SWoo0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002?Ool0
1000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002B
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUH00000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Moo`D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00W7oo2@0015YF00<005YFFUH00UYF
3P00HGoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .72951 m .59613 .67393 L .56496 .67202 L p .707 .577 .707 r
F P
0 g
s
.59613 .67393 m .59613 .72951 L .62796 .72873 L p .707 .577 .707 r
F P
0 g
s
.62796 .72873 m .62796 .67315 L .59613 .67393 L p .707 .577 .707 r
F P
0 g
s
.62796 .67315 m .62796 .72873 L .65734 .72535 L p .707 .577 .707 r
F P
0 g
s
.65734 .72535 m .65734 .66977 L .62796 .67315 L p .707 .577 .707 r
F P
0 g
s
.56496 .72761 m .56496 .67202 L .5375 .66763 L p .707 .577 .707 r
F P
0 g
s
.56496 .67202 m .56496 .72761 L .59613 .72951 L p .707 .577 .707 r
F P
0 g
s
.65734 .66977 m .65734 .72535 L .6814 .7197 L p .707 .577 .707 r
F P
0 g
s
.6814 .7197 m .6814 .66412 L .65734 .66977 L p .707 .577 .707 r
F P
0 g
s
.5375 .66763 m .5375 .72321 L .56496 .72761 L p .707 .577 .707 r
F P
0 g
s
.5375 .72321 m .5375 .66763 L .51644 .66118 L p .707 .577 .707 r
F P
0 g
s
.59613 .81705 m .59613 .79852 L .56496 .79662 L p .707 .577 .707 r
F P
0 g
s
.59613 .79852 m .59613 .81705 L .62796 .81627 L p .707 .577 .707 r
F P
0 g
s
.62796 .81627 m .62796 .79774 L .59613 .79852 L p .707 .577 .707 r
F P
0 g
s
.6814 .66412 m .6814 .7197 L .69777 .71233 L p .707 .577 .707 r
F P
0 g
s
.69777 .71233 m .69777 .65675 L .6814 .66412 L p .707 .577 .707 r
F P
0 g
s
.62796 .79774 m .62796 .81627 L .65735 .81289 L p .707 .577 .707 r
F P
0 g
s
.65735 .81289 m .65735 .79436 L .62796 .79774 L p .707 .577 .707 r
F P
0 g
s
.59613 .84665 m .59613 .8096 L .56496 .8077 L p .707 .577 .707 r
F P
0 g
s
.59613 .8096 m .59613 .84665 L .62796 .84588 L p .707 .577 .707 r
F P
0 g
s
.62796 .84588 m .62796 .80882 L .59613 .8096 L p .707 .577 .707 r
F P
0 g
s
.51644 .66118 m .51644 .71676 L .5375 .72321 L p .707 .577 .707 r
F P
0 g
s
.56496 .79662 m .56496 .81515 L .59613 .81705 L p .707 .577 .707 r
F P
0 g
s
.62796 .80882 m .62796 .84588 L .65735 .8425 L p .707 .577 .707 r
F P
0 g
s
.65735 .8425 m .65735 .80544 L .62796 .80882 L p .707 .577 .707 r
F P
0 g
s
.56496 .81515 m .56496 .79662 L .5375 .79223 L p .707 .577 .707 r
F P
0 g
s
.56496 .84475 m .56496 .8077 L .5375 .80331 L p .707 .577 .707 r
F P
0 g
s
.56496 .8077 m .56496 .84475 L .59613 .84665 L p .707 .577 .707 r
F P
0 g
s
.51644 .71676 m .51644 .66118 L .50385 .65329 L p .707 .577 .707 r
F P
0 g
s
.5375 .79223 m .5375 .81075 L .56496 .81515 L p .707 .577 .707 r
F P
0 g
s
.65735 .79436 m .65735 .81289 L .6814 .80724 L p .707 .577 .707 r
F P
0 g
s
.6814 .80724 m .6814 .78871 L .65735 .79436 L p .707 .577 .707 r
F P
0 g
s
.65735 .80544 m .65735 .8425 L .6814 .83685 L p .707 .577 .707 r
F P
0 g
s
.6814 .83685 m .6814 .79979 L .65735 .80544 L p .707 .577 .707 r
F P
0 g
s
.5375 .80331 m .5375 .84036 L .56496 .84475 L p .707 .577 .707 r
F P
0 g
s
.5375 .81075 m .5375 .79223 L .51644 .78577 L p .707 .577 .707 r
F P
0 g
s
.5375 .84036 m .5375 .80331 L .51644 .79685 L p .707 .577 .707 r
F P
0 g
s
.50385 .65329 m .50385 .70888 L .51644 .71676 L p .707 .577 .707 r
F P
0 g
s
.69777 .65675 m .69777 .71233 L .70485 .70397 L p .707 .577 .707 r
F P
0 g
s
.70485 .70397 m .70485 .64839 L .69777 .65675 L p .707 .577 .707 r
F P
0 g
s
.51644 .78577 m .51644 .8043 L .5375 .81075 L p .707 .577 .707 r
F P
0 g
s
.6814 .78871 m .6814 .80724 L .69777 .79987 L p .707 .577 .707 r
F P
0 g
s
.69777 .79987 m .69777 .78135 L .6814 .78871 L p .707 .577 .707 r
F P
0 g
s
.51644 .79685 m .51644 .83391 L .5375 .84036 L p .707 .577 .707 r
F P
0 g
s
.6814 .79979 m .6814 .83685 L .69777 .82948 L p .707 .577 .707 r
F P
0 g
s
.69777 .82948 m .69777 .79243 L .6814 .79979 L p .707 .577 .707 r
F P
0 g
s
.50385 .70888 m .50385 .65329 L .50095 .64475 L p .707 .577 .707 r
F P
0 g
s
.51644 .8043 m .51644 .78577 L .50385 .77789 L p .707 .577 .707 r
F P
0 g
s
.51644 .83391 m .51644 .79685 L .50385 .78897 L p .707 .577 .707 r
F P
0 g
s
.50385 .77789 m .50385 .79642 L .51644 .8043 L p .707 .577 .707 r
F P
0 g
s
.50095 .64475 m .50095 .70033 L .50385 .70888 L p .707 .577 .707 r
F P
0 g
s
.70485 .64839 m .70485 .70397 L .70195 .69543 L p .707 .577 .707 r
F P
0 g
s
.70195 .69543 m .70195 .63985 L .70485 .64839 L p .707 .577 .707 r
F P
0 g
s
.50385 .78897 m .50385 .82602 L .51644 .83391 L p .707 .577 .707 r
F P
0 g
s
.69777 .78135 m .69777 .79987 L .70485 .79151 L p .707 .577 .707 r
F P
0 g
s
.70485 .79151 m .70485 .77298 L .69777 .78135 L p .707 .577 .707 r
F P
0 g
s
.69777 .79243 m .69777 .82948 L .70485 .82112 L p .707 .577 .707 r
F P
0 g
s
.70485 .82112 m .70485 .78406 L .69777 .79243 L p .707 .577 .707 r
F P
0 g
s
.50095 .70033 m .50095 .64475 L .50804 .63639 L p .707 .577 .707 r
F P
0 g
s
.50385 .79642 m .50385 .77789 L .50095 .76935 L p .707 .577 .707 r
F P
0 g
s
.49044 .82844 m .49044 .32655 L .44643 .32387 L p .707 .577 .707 r
F P
0 g
s
.50385 .82602 m .50385 .78897 L .50095 .78043 L p .707 .577 .707 r
F P
0 g
s
.50095 .76935 m .50095 .78787 L .50385 .79642 L p .707 .577 .707 r
F P
0 g
s
.50804 .63639 m .50804 .69197 L .50095 .70033 L p .707 .577 .707 r
F P
0 g
s
.50095 .78043 m .50095 .81748 L .50385 .82602 L p .707 .577 .707 r
F P
0 g
s
.50804 .69197 m .50804 .63639 L .5244 .62902 L p .707 .577 .707 r
F P
0 g
s
.50095 .78787 m .50095 .76935 L .50804 .76098 L p .707 .577 .707 r
F P
0 g
s
.50095 .81748 m .50095 .78043 L .50804 .77206 L p .707 .577 .707 r
F P
0 g
s
.50804 .76098 m .50804 .77951 L .50095 .78787 L p .707 .577 .707 r
F P
0 g
s
.5244 .62902 m .5244 .6846 L .50804 .69197 L p .707 .577 .707 r
F P
0 g
s
.50804 .77206 m .50804 .80912 L .50095 .81748 L p .707 .577 .707 r
F P
0 g
s
.50804 .77951 m .50804 .76098 L .5244 .75361 L p .707 .577 .707 r
F P
0 g
s
.50804 .80912 m .50804 .77206 L .5244 .76469 L p .707 .577 .707 r
F P
0 g
s
.5244 .75361 m .5244 .77214 L .50804 .77951 L p .707 .577 .707 r
F P
0 g
s
.5244 .76469 m .5244 .80175 L .50804 .80912 L p .707 .577 .707 r
F P
0 g
s
.5244 .77214 m .5244 .75361 L .54846 .74797 L p .707 .577 .707 r
F P
0 g
s
.5244 .80175 m .5244 .76469 L .54846 .75905 L p .707 .577 .707 r
F P
0 g
s
.54846 .74797 m .54846 .76649 L .5244 .77214 L p .707 .577 .707 r
F P
0 g
s
.54846 .75905 m .54846 .7961 L .5244 .80175 L p .707 .577 .707 r
F P
0 g
s
.49044 .32655 m .49044 .82844 L .53538 .82734 L p .707 .577 .707 r
F P
0 g
s
.5244 .6846 m .5244 .62902 L .54846 .62337 L p .707 .577 .707 r
F P
0 g
s
.54846 .62337 m .54846 .67895 L .5244 .6846 L p .707 .577 .707 r
F P
0 g
s
.53538 .82734 m .53538 .32545 L .49044 .32655 L p .707 .577 .707 r
F P
0 g
s
.54846 .67895 m .54846 .62337 L .57784 .61999 L p .707 .577 .707 r
F P
0 g
s
.57784 .61999 m .57784 .67557 L .54846 .67895 L p .707 .577 .707 r
F P
0 g
s
.54846 .76649 m .54846 .74797 L .57784 .74459 L p .707 .577 .707 r
F P
0 g
s
.54846 .7961 m .54846 .75905 L .57784 .75567 L p .707 .577 .707 r
F P
0 g
s
.57784 .74459 m .57784 .76311 L .54846 .76649 L p .707 .577 .707 r
F P
0 g
s
.57784 .75567 m .57784 .79272 L .54846 .7961 L p .707 .577 .707 r
F P
0 g
s
.53538 .32545 m .53538 .82734 L .57686 .82257 L p .707 .577 .707 r
F P
0 g
s
.57686 .82257 m .57686 .32068 L .53538 .32545 L p .707 .577 .707 r
F P
0 g
s
.44643 .82576 m .44643 .32387 L .40766 .31767 L p .707 .577 .707 r
F P
0 g
s
.44643 .32387 m .44643 .82576 L .49044 .82844 L p .707 .577 .707 r
F P
0 g
s
.70195 .63985 m .70195 .69543 L .68936 .68754 L p .707 .577 .707 r
F P
0 g
s
.68936 .68754 m .68936 .63196 L .70195 .63985 L p .707 .577 .707 r
F P
0 g
s
.70485 .77298 m .70485 .79151 L .70195 .78297 L p .707 .577 .707 r
F P
0 g
s
.70195 .78297 m .70195 .76444 L .70485 .77298 L p .707 .577 .707 r
F P
0 g
s
.70485 .78406 m .70485 .82112 L .70195 .81257 L p .707 .577 .707 r
F P
0 g
s
.70195 .81257 m .70195 .77552 L .70485 .78406 L p .707 .577 .707 r
F P
0 g
s
.57784 .67557 m .57784 .61999 L .60968 .61921 L p .707 .577 .707 r
F P
0 g
s
.60968 .61921 m .60968 .6748 L .57784 .67557 L p .707 .577 .707 r
F P
0 g
s
.57784 .76311 m .57784 .74459 L .60968 .74381 L p .707 .577 .707 r
F P
0 g
s
.60968 .74381 m .60968 .76234 L .57784 .76311 L p .707 .577 .707 r
F P
0 g
s
.57784 .79272 m .57784 .75567 L .60968 .75489 L p .707 .577 .707 r
F P
0 g
s
.60968 .75489 m .60968 .79194 L .57784 .79272 L p .707 .577 .707 r
F P
0 g
s
.57686 .32068 m .57686 .82257 L .61082 .8146 L p .707 .577 .707 r
F P
0 g
s
.64085 .62111 m .64085 .6767 L .60968 .6748 L p .707 .577 .707 r
F P
0 g
s
.60968 .6748 m .60968 .61921 L .64085 .62111 L p .707 .577 .707 r
F P
0 g
s
.64085 .74571 m .64085 .76424 L .60968 .76234 L p .707 .577 .707 r
F P
0 g
s
.60968 .76234 m .60968 .74381 L .64085 .74571 L p .707 .577 .707 r
F P
0 g
s
.64085 .75679 m .64085 .79384 L .60968 .79194 L p .707 .577 .707 r
F P
0 g
s
.60968 .79194 m .60968 .75489 L .64085 .75679 L p .707 .577 .707 r
F P
0 g
s
.61082 .8146 m .61082 .31271 L .57686 .32068 L p .707 .577 .707 r
F P
0 g
s
.25312 .69269 m .25312 .63711 L .22195 .63521 L p .707 .577 .707 r
F P
0 g
s
.25312 .63711 m .25312 .69269 L .28495 .69192 L p .707 .577 .707 r
F P
0 g
s
.28495 .69192 m .28495 .63633 L .25312 .63711 L p .707 .577 .707 r
F P
0 g
s
.28495 .63633 m .28495 .69192 L .31434 .68854 L p .707 .577 .707 r
F P
0 g
s
.31434 .68854 m .31434 .63295 L .28495 .63633 L p .707 .577 .707 r
F P
0 g
s
.22195 .69079 m .22195 .63521 L .19449 .63082 L p .707 .577 .707 r
F P
0 g
s
.22195 .63521 m .22195 .69079 L .25312 .69269 L p .707 .577 .707 r
F P
0 g
s
.40766 .81956 m .40766 .31767 L .37794 .30856 L p .707 .577 .707 r
F P
0 g
s
.40766 .31767 m .40766 .81956 L .44643 .82576 L p .707 .577 .707 r
F P
0 g
s
.31434 .63295 m .31434 .68854 L .33839 .68289 L p .707 .577 .707 r
F P
0 g
s
.33839 .68289 m .33839 .6273 L .31434 .63295 L p .707 .577 .707 r
F P
0 g
s
.68936 .63196 m .68936 .68754 L .66831 .68109 L p .707 .577 .707 r
F P
0 g
s
.66831 .68109 m .66831 .62551 L .68936 .63196 L p .707 .577 .707 r
F P
0 g
s
.19449 .63082 m .19449 .6864 L .22195 .69079 L p .707 .577 .707 r
F P
0 g
s
.19449 .6864 m .19449 .63082 L .17343 .62436 L p .707 .577 .707 r
F P
0 g
s
.70195 .76444 m .70195 .78297 L .68936 .77508 L p .707 .577 .707 r
F P
0 g
s
.68936 .77508 m .68936 .75656 L .70195 .76444 L p .707 .577 .707 r
F P
0 g
s
.61082 .31271 m .61082 .8146 L .63393 .8042 L p .707 .577 .707 r
F P
0 g
s
.63393 .8042 m .63393 .30231 L .61082 .31271 L p .707 .577 .707 r
F P
0 g
s
.70195 .77552 m .70195 .81257 L .68936 .80469 L p .707 .577 .707 r
F P
0 g
s
.68936 .80469 m .68936 .76764 L .70195 .77552 L p .707 .577 .707 r
F P
0 g
s
.25312 .78023 m .25312 .7617 L .22195 .7598 L p .707 .577 .707 r
F P
0 g
s
.25312 .7617 m .25312 .78023 L .28495 .77946 L p .707 .577 .707 r
F P
0 g
s
.28495 .77946 m .28495 .76093 L .25312 .7617 L p .707 .577 .707 r
F P
0 g
s
.33839 .6273 m .33839 .68289 L .35476 .67552 L p .707 .577 .707 r
F P
0 g
s
.35476 .67552 m .35476 .61994 L .33839 .6273 L p .707 .577 .707 r
F P
0 g
s
.28495 .76093 m .28495 .77946 L .31434 .77608 L p .707 .577 .707 r
F P
0 g
s
.31434 .77608 m .31434 .75755 L .28495 .76093 L p .707 .577 .707 r
F P
0 g
s
.25312 .80984 m .25312 .77278 L .22195 .77088 L p .707 .577 .707 r
F P
0 g
s
.25312 .77278 m .25312 .80984 L .28495 .80906 L p .707 .577 .707 r
F P
0 g
s
.28495 .80906 m .28495 .77201 L .25312 .77278 L p .707 .577 .707 r
F P
0 g
s
.17343 .62436 m .17343 .67995 L .19449 .6864 L p .707 .577 .707 r
F P
0 g
s
.22195 .7598 m .22195 .77833 L .25312 .78023 L p .707 .577 .707 r
F P
0 g
s
.28495 .77201 m .28495 .80906 L .31434 .80568 L p .707 .577 .707 r
F P
0 g
s
.31434 .80568 m .31434 .76863 L .28495 .77201 L p .707 .577 .707 r
F P
0 g
s
.37794 .81044 m .37794 .30856 L .36016 .29743 L p .707 .577 .707 r
F P
0 g
s
.37794 .30856 m .37794 .81044 L .40766 .81956 L p .707 .577 .707 r
F P
0 g
s
.22195 .77833 m .22195 .7598 L .19449 .75541 L p .707 .577 .707 r
F P
0 g
s
.66831 .62551 m .66831 .68109 L .64085 .6767 L p .707 .577 .707 r
F P
0 g
s
.64085 .6767 m .64085 .62111 L .66831 .62551 L p .707 .577 .707 r
F P
0 g
s
.22195 .80794 m .22195 .77088 L .19449 .76649 L p .707 .577 .707 r
F P
0 g
s
.22195 .77088 m .22195 .80794 L .25312 .80984 L p .707 .577 .707 r
F P
0 g
s
.17343 .67995 m .17343 .62436 L .16084 .61648 L p .707 .577 .707 r
F P
0 g
s
.19449 .75541 m .19449 .77394 L .22195 .77833 L p .707 .577 .707 r
F P
0 g
s
.31434 .75755 m .31434 .77608 L .33839 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .77043 m .33839 .7519 L .31434 .75755 L p .707 .577 .707 r
F P
0 g
s
.31434 .76863 m .31434 .80568 L .33839 .80003 L p .707 .577 .707 r
F P
0 g
s
.33839 .80003 m .33839 .76298 L .31434 .76863 L p .707 .577 .707 r
F P
0 g
s
.68936 .75656 m .68936 .77508 L .66831 .76863 L p .707 .577 .707 r
F P
0 g
s
.66831 .76863 m .66831 .7501 L .68936 .75656 L p .707 .577 .707 r
F P
0 g
s
.19449 .76649 m .19449 .80355 L .22195 .80794 L p .707 .577 .707 r
F P
0 g
s
.68936 .76764 m .68936 .80469 L .66831 .79824 L p .707 .577 .707 r
F P
0 g
s
.66831 .79824 m .66831 .76118 L .68936 .76764 L p .707 .577 .707 r
F P
0 g
s
.19449 .77394 m .19449 .75541 L .17343 .74896 L p .707 .577 .707 r
F P
0 g
s
.19449 .80355 m .19449 .76649 L .17343 .76004 L p .707 .577 .707 r
F P
0 g
s
.16084 .61648 m .16084 .67206 L .17343 .67995 L p .707 .577 .707 r
F P
0 g
s
.35476 .61994 m .35476 .67552 L .36184 .66715 L p .707 .577 .707 r
F P
0 g
s
.36184 .66715 m .36184 .61157 L .35476 .61994 L p .707 .577 .707 r
F P
0 g
s
.17343 .74896 m .17343 .76749 L .19449 .77394 L p .707 .577 .707 r
F P
0 g
s
.66831 .7501 m .66831 .76863 L .64085 .76424 L p .707 .577 .707 r
F P
0 g
s
.64085 .76424 m .64085 .74571 L .66831 .7501 L p .707 .577 .707 r
F P
0 g
s
.66831 .76118 m .66831 .79824 L .64085 .79384 L p .707 .577 .707 r
F P
0 g
s
.64085 .79384 m .64085 .75679 L .66831 .76118 L p .707 .577 .707 r
F P
0 g
s
.63393 .30231 m .63393 .8042 L .64393 .79239 L p .707 .577 .707 r
F P
0 g
s
.64393 .79239 m .64393 .2905 L .63393 .30231 L p .707 .577 .707 r
F P
0 g
s
.33839 .7519 m .33839 .77043 L .35476 .76306 L p .707 .577 .707 r
F P
0 g
s
.35476 .76306 m .35476 .74453 L .33839 .7519 L p .707 .577 .707 r
F P
0 g
s
.17343 .76004 m .17343 .79709 L .19449 .80355 L p .707 .577 .707 r
F P
0 g
s
.33839 .76298 m .33839 .80003 L .35476 .79267 L p .707 .577 .707 r
F P
0 g
s
.35476 .79267 m .35476 .75561 L .33839 .76298 L p .707 .577 .707 r
F P
0 g
s
.16084 .67206 m .16084 .61648 L .15794 .60794 L p .707 .577 .707 r
F P
0 g
s
.17343 .76749 m .17343 .74896 L .16084 .74107 L p .707 .577 .707 r
F P
0 g
s
.36184 .61157 m .36184 .66715 L .35894 .65861 L p .707 .577 .707 r
F P
0 g
s
.35894 .65861 m .35894 .60303 L .36184 .61157 L p .707 .577 .707 r
F P
0 g
s
.35476 .74453 m .35476 .76306 L .36184 .75469 L p .707 .577 .707 r
F P
0 g
s
.36184 .75469 m .36184 .73617 L .35476 .74453 L p .707 .577 .707 r
F P
0 g
s
.35476 .75561 m .35476 .79267 L .36184 .7843 L p .707 .577 .707 r
F P
0 g
s
.36184 .7843 m .36184 .74725 L .35476 .75561 L p .707 .577 .707 r
F P
0 g
s
.35894 .60303 m .35894 .65861 L .34635 .65073 L p .707 .577 .707 r
F P
0 g
s
.34635 .65073 m .34635 .59515 L .35894 .60303 L p .707 .577 .707 r
F P
0 g
s
.36184 .73617 m .36184 .75469 L .35894 .74615 L p .707 .577 .707 r
F P
0 g
s
.35894 .74615 m .35894 .72762 L .36184 .73617 L p .707 .577 .707 r
F P
0 g
s
.36184 .74725 m .36184 .7843 L .35894 .77576 L p .707 .577 .707 r
F P
0 g
s
.35894 .77576 m .35894 .7387 L .36184 .74725 L p .707 .577 .707 r
F P
0 g
s
.36016 .79931 m .36016 .29743 L .35607 .28537 L p .707 .577 .707 r
F P
0 g
s
.36016 .29743 m .36016 .79931 L .37794 .81044 L p .707 .577 .707 r
F P
0 g
s
.17343 .79709 m .17343 .76004 L .16084 .75215 L p .707 .577 .707 r
F P
0 g
s
.16084 .74107 m .16084 .7596 L .17343 .76749 L p .707 .577 .707 r
F P
0 g
s
.15794 .60794 m .15794 .66352 L .16084 .67206 L p .707 .577 .707 r
F P
0 g
s
.16084 .75215 m .16084 .78921 L .17343 .79709 L p .707 .577 .707 r
F P
0 g
s
.15794 .66352 m .15794 .60794 L .16503 .59957 L p .707 .577 .707 r
F P
0 g
s
.64393 .2905 m .64393 .79239 L .63984 .78033 L p .707 .577 .707 r
F P
0 g
s
.63984 .78033 m .63984 .27844 L .64393 .2905 L p .707 .577 .707 r
F P
0 g
s
.16084 .7596 m .16084 .74107 L .15794 .73253 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16084 .78921 m .16084 .75215 L .15794 .74361 L p .707 .577 .707 r
F P
0 g
s
.15794 .73253 m .15794 .75106 L .16084 .7596 L p .707 .577 .707 r
F P
0 g
s
.16503 .59957 m .16503 .65515 L .15794 .66352 L p .707 .577 .707 r
F P
0 g
s
.15794 .74361 m .15794 .78067 L .16084 .78921 L p .707 .577 .707 r
F P
0 g
s
.35894 .72762 m .35894 .74615 L .34635 .73827 L p .707 .577 .707 r
F P
0 g
s
.34635 .73827 m .34635 .71974 L .35894 .72762 L p .707 .577 .707 r
F P
0 g
s
.35894 .7387 m .35894 .77576 L .34635 .76788 L p .707 .577 .707 r
F P
0 g
s
.34635 .76788 m .34635 .73082 L .35894 .7387 L p .707 .577 .707 r
F P
0 g
s
.35607 .28537 m .35607 .78725 L .36016 .79931 L p .707 .577 .707 r
F P
0 g
s
.35607 .78725 m .35607 .28537 L .36607 .27356 L p .707 .577 .707 r
F P
0 g
s
.16503 .65515 m .16503 .59957 L .1814 .5922 L p .707 .577 .707 r
F P
0 g
s
.15794 .75106 m .15794 .73253 L .16503 .72417 L p .707 .577 .707 r
F P
0 g
s
.15794 .78067 m .15794 .74361 L .16503 .73525 L p .707 .577 .707 r
F P
0 g
s
.16503 .72417 m .16503 .74269 L .15794 .75106 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27844 m .63984 .78033 L .62206 .7692 L p .707 .577 .707 r
F P
0 g
s
.62206 .7692 m .62206 .26731 L .63984 .27844 L p .707 .577 .707 r
F P
0 g
s
.1814 .5922 m .1814 .64779 L .16503 .65515 L p .707 .577 .707 r
F P
0 g
s
.34635 .59515 m .34635 .65073 L .3253 .64427 L p .707 .577 .707 r
F P
0 g
s
.3253 .64427 m .3253 .58869 L .34635 .59515 L p .707 .577 .707 r
F P
0 g
s
.16503 .73525 m .16503 .7723 L .15794 .78067 L p .707 .577 .707 r
F P
0 g
s
.1814 .64779 m .1814 .5922 L .20545 .58655 L p .707 .577 .707 r
F P
0 g
s
.36607 .77545 m .36607 .27356 L .38918 .26316 L p .707 .577 .707 r
F P
0 g
s
.36607 .27356 m .36607 .77545 L .35607 .78725 L p .707 .577 .707 r
F P
0 g
s
.16503 .74269 m .16503 .72417 L .1814 .7168 L p .707 .577 .707 r
F P
0 g
s
.16503 .7723 m .16503 .73525 L .1814 .72788 L p .707 .577 .707 r
F P
0 g
s
.3253 .58869 m .3253 .64427 L .29784 .63988 L p .707 .577 .707 r
F P
0 g
s
.29784 .63988 m .29784 .5843 L .3253 .58869 L p .707 .577 .707 r
F P
0 g
s
.1814 .7168 m .1814 .73533 L .16503 .74269 L p .707 .577 .707 r
F P
0 g
s
.20545 .58655 m .20545 .64214 L .1814 .64779 L p .707 .577 .707 r
F P
0 g
s
.20545 .64214 m .20545 .58655 L .23483 .58318 L p .707 .577 .707 r
F P
0 g
s
.1814 .72788 m .1814 .76493 L .16503 .7723 L p .707 .577 .707 r
F P
0 g
s
.34635 .71974 m .34635 .73827 L .3253 .73181 L p .707 .577 .707 r
F P
0 g
s
.3253 .73181 m .3253 .71329 L .34635 .71974 L p .707 .577 .707 r
F P
0 g
s
.34635 .73082 m .34635 .76788 L .3253 .76142 L p .707 .577 .707 r
F P
0 g
s
.3253 .76142 m .3253 .72437 L .34635 .73082 L p .707 .577 .707 r
F P
0 g
s
.62206 .26731 m .62206 .7692 L .59233 .76008 L p .707 .577 .707 r
F P
0 g
s
.59233 .76008 m .59233 .2582 L .62206 .26731 L p .707 .577 .707 r
F P
0 g
s
.29784 .5843 m .29784 .63988 L .26667 .63798 L p .707 .577 .707 r
F P
0 g
s
.26667 .63798 m .26667 .5824 L .29784 .5843 L p .707 .577 .707 r
F P
0 g
s
.23483 .63876 m .23483 .58318 L .26667 .5824 L p .707 .577 .707 r
F P
0 g
s
.23483 .58318 m .23483 .63876 L .20545 .64214 L p .707 .577 .707 r
F P
0 g
s
.1814 .73533 m .1814 .7168 L .20545 .71115 L p .707 .577 .707 r
F P
0 g
s
.26667 .5824 m .26667 .63798 L .23483 .63876 L p .707 .577 .707 r
F P
0 g
s
.73333 .63747 m .73333 .58189 L .70216 .57999 L p .707 .577 .707 r
F P
0 g
s
.73333 .58189 m .73333 .63747 L .76517 .63669 L p .707 .577 .707 r
F P
0 g
s
.76517 .63669 m .76517 .58111 L .73333 .58189 L p .707 .577 .707 r
F P
0 g
s
.1814 .76493 m .1814 .72788 L .20545 .72223 L p .707 .577 .707 r
F P
0 g
s
.76517 .58111 m .76517 .63669 L .79455 .63331 L p .707 .577 .707 r
F P
0 g
s
.79455 .63331 m .79455 .57773 L .76517 .58111 L p .707 .577 .707 r
F P
0 g
s
.20545 .71115 m .20545 .72968 L .1814 .73533 L p .707 .577 .707 r
F P
0 g
s
.38918 .26316 m .38918 .76504 L .36607 .77545 L p .707 .577 .707 r
F P
0 g
s
.38918 .76504 m .38918 .26316 L .42314 .25518 L p .707 .577 .707 r
F P
0 g
s
.70216 .63557 m .70216 .57999 L .6747 .57559 L p .707 .577 .707 r
F P
0 g
s
.70216 .57999 m .70216 .63557 L .73333 .63747 L p .707 .577 .707 r
F P
0 g
s
.3253 .71329 m .3253 .73181 L .29784 .72742 L p .707 .577 .707 r
F P
0 g
s
.29784 .72742 m .29784 .70889 L .3253 .71329 L p .707 .577 .707 r
F P
0 g
s
.20545 .72223 m .20545 .75928 L .1814 .76493 L p .707 .577 .707 r
F P
0 g
s
.3253 .72437 m .3253 .76142 L .29784 .75703 L p .707 .577 .707 r
F P
0 g
s
.29784 .75703 m .29784 .71997 L .3253 .72437 L p .707 .577 .707 r
F P
0 g
s
.79455 .57773 m .79455 .63331 L .8186 .62766 L p .707 .577 .707 r
F P
0 g
s
.8186 .62766 m .8186 .57208 L .79455 .57773 L p .707 .577 .707 r
F P
0 g
s
.20545 .72968 m .20545 .71115 L .23483 .70777 L p .707 .577 .707 r
F P
0 g
s
.20545 .75928 m .20545 .72223 L .23483 .71885 L p .707 .577 .707 r
F P
0 g
s
.6747 .57559 m .6747 .63118 L .70216 .63557 L p .707 .577 .707 r
F P
0 g
s
.6747 .63118 m .6747 .57559 L .65365 .56914 L p .707 .577 .707 r
F P
0 g
s
.23483 .70777 m .23483 .7263 L .20545 .72968 L p .707 .577 .707 r
F P
0 g
s
.59233 .2582 m .59233 .76008 L .55357 .75388 L p .707 .577 .707 r
F P
0 g
s
.55357 .75388 m .55357 .25199 L .59233 .2582 L p .707 .577 .707 r
F P
0 g
s
.29784 .70889 m .29784 .72742 L .26667 .72552 L p .707 .577 .707 r
F P
0 g
s
.26667 .72552 m .26667 .70699 L .29784 .70889 L p .707 .577 .707 r
F P
0 g
s
.29784 .71997 m .29784 .75703 L .26667 .75513 L p .707 .577 .707 r
F P
0 g
s
.26667 .75513 m .26667 .71807 L .29784 .71997 L p .707 .577 .707 r
F P
0 g
s
.23483 .7263 m .23483 .70777 L .26667 .70699 L p .707 .577 .707 r
F P
0 g
s
.23483 .71885 m .23483 .75591 L .20545 .75928 L p .707 .577 .707 r
F P
0 g
s
.26667 .70699 m .26667 .72552 L .23483 .7263 L p .707 .577 .707 r
F P
0 g
s
.23483 .75591 m .23483 .71885 L .26667 .71807 L p .707 .577 .707 r
F P
0 g
s
.73333 .72501 m .73333 .70648 L .70216 .70458 L p .707 .577 .707 r
F P
0 g
s
.73333 .70648 m .73333 .72501 L .76517 .72423 L p .707 .577 .707 r
F P
0 g
s
.76517 .72423 m .76517 .7057 L .73333 .70648 L p .707 .577 .707 r
F P
0 g
s
.42314 .75707 m .42314 .25518 L .46462 .25041 L p .707 .577 .707 r
F P
0 g
s
.42314 .25518 m .42314 .75707 L .38918 .76504 L p .707 .577 .707 r
F P
0 g
s
.8186 .57208 m .8186 .62766 L .83497 .6203 L p .707 .577 .707 r
F P
0 g
s
.83497 .6203 m .83497 .56471 L .8186 .57208 L p .707 .577 .707 r
F P
0 g
s
.26667 .71807 m .26667 .75513 L .23483 .75591 L p .707 .577 .707 r
F P
0 g
s
.76517 .7057 m .76517 .72423 L .79455 .72085 L p .707 .577 .707 r
F P
0 g
s
.79455 .72085 m .79455 .70233 L .76517 .7057 L p .707 .577 .707 r
F P
0 g
s
.73333 .75462 m .73333 .71756 L .70216 .71566 L p .707 .577 .707 r
F P
0 g
s
.73333 .71756 m .73333 .75462 L .76517 .75384 L p .707 .577 .707 r
F P
0 g
s
.76517 .75384 m .76517 .71678 L .73333 .71756 L p .707 .577 .707 r
F P
0 g
s
.65365 .56914 m .65365 .62472 L .6747 .63118 L p .707 .577 .707 r
F P
0 g
s
.70216 .70458 m .70216 .72311 L .73333 .72501 L p .707 .577 .707 r
F P
0 g
s
.76517 .71678 m .76517 .75384 L .79455 .75046 L p .707 .577 .707 r
F P
0 g
s
.79455 .75046 m .79455 .71341 L .76517 .71678 L p .707 .577 .707 r
F P
0 g
s
.70216 .72311 m .70216 .70458 L .6747 .70019 L p .707 .577 .707 r
F P
0 g
s
.70216 .75272 m .70216 .71566 L .6747 .71127 L p .707 .577 .707 r
F P
0 g
s
.70216 .71566 m .70216 .75272 L .73333 .75462 L p .707 .577 .707 r
F P
0 g
s
.65365 .62472 m .65365 .56914 L .64105 .56126 L p .707 .577 .707 r
F P
0 g
s
.55357 .25199 m .55357 .75388 L .50956 .7512 L p .707 .577 .707 r
F P
0 g
s
.50956 .7512 m .50956 .24931 L .55357 .25199 L p .707 .577 .707 r
F P
0 g
s
.6747 .70019 m .6747 .71872 L .70216 .72311 L p .707 .577 .707 r
F P
0 g
s
.79455 .70233 m .79455 .72085 L .8186 .7152 L p .707 .577 .707 r
F P
0 g
s
.8186 .7152 m .8186 .69668 L .79455 .70233 L p .707 .577 .707 r
F P
0 g
s
.46462 .7523 m .46462 .25041 L .50956 .24931 L p .707 .577 .707 r
F P
0 g
s
.46462 .25041 m .46462 .7523 L .42314 .75707 L p .707 .577 .707 r
F P
0 g
s
.79455 .71341 m .79455 .75046 L .8186 .74481 L p .707 .577 .707 r
F P
0 g
s
.8186 .74481 m .8186 .70776 L .79455 .71341 L p .707 .577 .707 r
F P
0 g
s
.6747 .71127 m .6747 .74832 L .70216 .75272 L p .707 .577 .707 r
F P
0 g
s
.50956 .24931 m .50956 .7512 L .46462 .7523 L p .707 .577 .707 r
F P
0 g
s
.6747 .71872 m .6747 .70019 L .65365 .69374 L p .707 .577 .707 r
F P
0 g
s
.6747 .74832 m .6747 .71127 L .65365 .70482 L p .707 .577 .707 r
F P
0 g
s
.64105 .56126 m .64105 .61684 L .65365 .62472 L p .707 .577 .707 r
F P
0 g
s
.83497 .56471 m .83497 .6203 L .84205 .61193 L p .707 .577 .707 r
F P
0 g
s
.84205 .61193 m .84205 .55635 L .83497 .56471 L p .707 .577 .707 r
F P
0 g
s
.65365 .69374 m .65365 .71226 L .6747 .71872 L p .707 .577 .707 r
F P
0 g
s
.8186 .69668 m .8186 .7152 L .83497 .70784 L p .707 .577 .707 r
F P
0 g
s
.83497 .70784 m .83497 .68931 L .8186 .69668 L p .707 .577 .707 r
F P
0 g
s
.65365 .70482 m .65365 .74187 L .6747 .74832 L p .707 .577 .707 r
F P
0 g
s
.8186 .70776 m .8186 .74481 L .83497 .73744 L p .707 .577 .707 r
F P
0 g
s
.83497 .73744 m .83497 .70039 L .8186 .70776 L p .707 .577 .707 r
F P
0 g
s
.64105 .61684 m .64105 .56126 L .63816 .55271 L p .707 .577 .707 r
F P
0 g
s
.65365 .71226 m .65365 .69374 L .64105 .68585 L p .707 .577 .707 r
F P
0 g
s
.65365 .74187 m .65365 .70482 L .64105 .69693 L p .707 .577 .707 r
F P
0 g
s
.64105 .68585 m .64105 .70438 L .65365 .71226 L p .707 .577 .707 r
F P
0 g
s
.63816 .55271 m .63816 .6083 L .64105 .61684 L p .707 .577 .707 r
F P
0 g
s
.84205 .55635 m .84205 .61193 L .83916 .60339 L p .707 .577 .707 r
F P
0 g
s
.83916 .60339 m .83916 .54781 L .84205 .55635 L p .707 .577 .707 r
F P
0 g
s
.64105 .69693 m .64105 .73399 L .65365 .74187 L p .707 .577 .707 r
F P
0 g
s
.83497 .68931 m .83497 .70784 L .84206 .69947 L p .707 .577 .707 r
F P
0 g
s
.84206 .69947 m .84206 .68094 L .83497 .68931 L p .707 .577 .707 r
F P
0 g
s
.83497 .70039 m .83497 .73744 L .84206 .72908 L p .707 .577 .707 r
F P
0 g
s
.84206 .72908 m .84206 .69202 L .83497 .70039 L p .707 .577 .707 r
F P
0 g
s
.63816 .6083 m .63816 .55271 L .64524 .54435 L p .707 .577 .707 r
F P
0 g
s
.64105 .70438 m .64105 .68585 L .63816 .67731 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64105 .73399 m .64105 .69693 L .63816 .68839 L p .707 .577 .707 r
F P
0 g
s
.63816 .67731 m .63816 .69584 L .64105 .70438 L p .707 .577 .707 r
F P
0 g
s
.64524 .54435 m .64524 .59993 L .63816 .6083 L p .707 .577 .707 r
F P
0 g
s
.63816 .68839 m .63816 .72544 L .64105 .73399 L p .707 .577 .707 r
F P
0 g
s
.83916 .54781 m .83916 .60339 L .82657 .5955 L p .707 .577 .707 r
F P
0 g
s
.82657 .5955 m .82657 .53992 L .83916 .54781 L p .707 .577 .707 r
F P
0 g
s
.84206 .68094 m .84206 .69947 L .83916 .69093 L p .707 .577 .707 r
F P
0 g
s
.83916 .69093 m .83916 .6724 L .84206 .68094 L p .707 .577 .707 r
F P
0 g
s
.84206 .69202 m .84206 .72908 L .83916 .72054 L p .707 .577 .707 r
F P
0 g
s
.83916 .72054 m .83916 .68348 L .84206 .69202 L p .707 .577 .707 r
F P
0 g
s
.39032 .60065 m .39032 .54507 L .35915 .54317 L p .707 .577 .707 r
F P
0 g
s
.39032 .54507 m .39032 .60065 L .42216 .59988 L p .707 .577 .707 r
F P
0 g
s
.42216 .59988 m .42216 .54429 L .39032 .54507 L p .707 .577 .707 r
F P
0 g
s
.64524 .59993 m .64524 .54435 L .66161 .53698 L p .707 .577 .707 r
F P
0 g
s
.42216 .54429 m .42216 .59988 L .45154 .5965 L p .707 .577 .707 r
F P
0 g
s
.45154 .5965 m .45154 .54092 L .42216 .54429 L p .707 .577 .707 r
F P
0 g
s
.35915 .59875 m .35915 .54317 L .33169 .53878 L p .707 .577 .707 r
F P
0 g
s
.35915 .54317 m .35915 .59875 L .39032 .60065 L p .707 .577 .707 r
F P
0 g
s
.63816 .69584 m .63816 .67731 L .64524 .66894 L p .707 .577 .707 r
F P
0 g
s
.63816 .72544 m .63816 .68839 L .64524 .68002 L p .707 .577 .707 r
F P
0 g
s
.64524 .66894 m .64524 .68747 L .63816 .69584 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45154 .54092 m .45154 .5965 L .47559 .59085 L p .707 .577 .707 r
F P
0 g
s
.47559 .59085 m .47559 .53527 L .45154 .54092 L p .707 .577 .707 r
F P
0 g
s
.66161 .53698 m .66161 .59256 L .64524 .59993 L p .707 .577 .707 r
F P
0 g
s
.82657 .53992 m .82657 .5955 L .80551 .58905 L p .707 .577 .707 r
F P
0 g
s
.80551 .58905 m .80551 .53347 L .82657 .53992 L p .707 .577 .707 r
F P
0 g
s
.64524 .68002 m .64524 .71708 L .63816 .72544 L p .707 .577 .707 r
F P
0 g
s
.33169 .53878 m .33169 .59436 L .35915 .59875 L p .707 .577 .707 r
F P
0 g
s
.33169 .59436 m .33169 .53878 L .31064 .53232 L p .707 .577 .707 r
F P
0 g
s
.83916 .6724 m .83916 .69093 L .82657 .68305 L p .707 .577 .707 r
F P
0 g
s
.82657 .68305 m .82657 .66452 L .83916 .6724 L p .707 .577 .707 r
F P
0 g
s
.83916 .68348 m .83916 .72054 L .82657 .71265 L p .707 .577 .707 r
F P
0 g
s
.82657 .71265 m .82657 .6756 L .83916 .68348 L p .707 .577 .707 r
F P
0 g
s
.66161 .59256 m .66161 .53698 L .68566 .53133 L p .707 .577 .707 r
F P
0 g
s
.39032 .68819 m .39032 .66967 L .35915 .66777 L p .707 .577 .707 r
F P
0 g
s
.39032 .66967 m .39032 .68819 L .42216 .68742 L p .707 .577 .707 r
F P
0 g
s
.42216 .68742 m .42216 .66889 L .39032 .66967 L p .707 .577 .707 r
F P
0 g
s
.47559 .53527 m .47559 .59085 L .49196 .58348 L p .707 .577 .707 r
F P
0 g
s
.49196 .58348 m .49196 .5279 L .47559 .53527 L p .707 .577 .707 r
F P
0 g
s
.64524 .68747 m .64524 .66894 L .66161 .66158 L p .707 .577 .707 r
F P
0 g
s
.42216 .66889 m .42216 .68742 L .45154 .68404 L p .707 .577 .707 r
F P
0 g
s
.45154 .68404 m .45154 .66551 L .42216 .66889 L p .707 .577 .707 r
F P
0 g
s
.39032 .7178 m .39032 .68075 L .35915 .67885 L p .707 .577 .707 r
F P
0 g
s
.39032 .68075 m .39032 .7178 L .42216 .71702 L p .707 .577 .707 r
F P
0 g
s
.42216 .71702 m .42216 .67997 L .39032 .68075 L p .707 .577 .707 r
F P
0 g
s
.31064 .53232 m .31064 .58791 L .33169 .59436 L p .707 .577 .707 r
F P
0 g
s
.35915 .66777 m .35915 .68629 L .39032 .68819 L p .707 .577 .707 r
F P
0 g
s
.64524 .71708 m .64524 .68002 L .66161 .67266 L p .707 .577 .707 r
F P
0 g
s
.42216 .67997 m .42216 .71702 L .45154 .71365 L p .707 .577 .707 r
F P
0 g
s
.45154 .71365 m .45154 .67659 L .42216 .67997 L p .707 .577 .707 r
F P
0 g
s
.35915 .68629 m .35915 .66777 L .33169 .66337 L p .707 .577 .707 r
F P
0 g
s
.80551 .53347 m .80551 .58905 L .77805 .58466 L p .707 .577 .707 r
F P
0 g
s
.77805 .58466 m .77805 .52908 L .80551 .53347 L p .707 .577 .707 r
F P
0 g
s
.66161 .66158 m .66161 .6801 L .64524 .68747 L p .707 .577 .707 r
F P
0 g
s
.68566 .53133 m .68566 .58691 L .66161 .59256 L p .707 .577 .707 r
F P
0 g
s
.35915 .7159 m .35915 .67885 L .33169 .67445 L p .707 .577 .707 r
F P
0 g
s
.35915 .67885 m .35915 .7159 L .39032 .7178 L p .707 .577 .707 r
F P
0 g
s
.31064 .58791 m .31064 .53232 L .29804 .52444 L p .707 .577 .707 r
F P
0 g
s
.33169 .66337 m .33169 .6819 L .35915 .68629 L p .707 .577 .707 r
F P
0 g
s
.68566 .58691 m .68566 .53133 L .71504 .52795 L p .707 .577 .707 r
F P
0 g
s
.45154 .66551 m .45154 .68404 L .47559 .67839 L p .707 .577 .707 r
F P
0 g
s
.47559 .67839 m .47559 .65986 L .45154 .66551 L p .707 .577 .707 r
F P
0 g
s
.66161 .67266 m .66161 .70971 L .64524 .71708 L p .707 .577 .707 r
F P
0 g
s
.45154 .67659 m .45154 .71365 L .47559 .708 L p .707 .577 .707 r
F P
0 g
s
.47559 .708 m .47559 .67094 L .45154 .67659 L p .707 .577 .707 r
F P
0 g
s
.82657 .66452 m .82657 .68305 L .80551 .67659 L p .707 .577 .707 r
F P
0 g
s
.80551 .67659 m .80551 .65806 L .82657 .66452 L p .707 .577 .707 r
F P
0 g
s
.33169 .67445 m .33169 .71151 L .35915 .7159 L p .707 .577 .707 r
F P
0 g
s
.82657 .6756 m .82657 .71265 L .80551 .7062 L p .707 .577 .707 r
F P
0 g
s
.80551 .7062 m .80551 .66914 L .82657 .6756 L p .707 .577 .707 r
F P
0 g
s
.33169 .6819 m .33169 .66337 L .31064 .65692 L p .707 .577 .707 r
F P
0 g
s
.77805 .52908 m .77805 .58466 L .74688 .58276 L p .707 .577 .707 r
F P
0 g
s
.74688 .58276 m .74688 .52718 L .77805 .52908 L p .707 .577 .707 r
F P
0 g
s
.33169 .71151 m .33169 .67445 L .31064 .668 L p .707 .577 .707 r
F P
0 g
s
.29804 .52444 m .29804 .58002 L .31064 .58791 L p .707 .577 .707 r
F P
0 g
s
.71504 .58354 m .71504 .52795 L .74688 .52718 L p .707 .577 .707 r
F P
0 g
s
.71504 .52795 m .71504 .58354 L .68566 .58691 L p .707 .577 .707 r
F P
0 g
s
.49196 .5279 m .49196 .58348 L .49904 .57512 L p .707 .577 .707 r
F P
0 g
s
.49904 .57512 m .49904 .51953 L .49196 .5279 L p .707 .577 .707 r
F P
0 g
s
.31064 .65692 m .31064 .67545 L .33169 .6819 L p .707 .577 .707 r
F P
0 g
s
.66161 .6801 m .66161 .66158 L .68566 .65593 L p .707 .577 .707 r
F P
0 g
s
.74688 .52718 m .74688 .58276 L .71504 .58354 L p .707 .577 .707 r
F P
0 g
s
.66161 .70971 m .66161 .67266 L .68566 .66701 L p .707 .577 .707 r
F P
0 g
s
.68566 .65593 m .68566 .67445 L .66161 .6801 L p .707 .577 .707 r
F P
0 g
s
.47559 .65986 m .47559 .67839 L .49196 .67102 L p .707 .577 .707 r
F P
0 g
s
.49196 .67102 m .49196 .65249 L .47559 .65986 L p .707 .577 .707 r
F P
0 g
s
.31064 .668 m .31064 .70505 L .33169 .71151 L p .707 .577 .707 r
F P
0 g
s
.47559 .67094 m .47559 .708 L .49196 .70063 L p .707 .577 .707 r
F P
0 g
s
.49196 .70063 m .49196 .66357 L .47559 .67094 L p .707 .577 .707 r
F P
0 g
s
.29804 .58002 m .29804 .52444 L .29515 .5159 L p .707 .577 .707 r
F P
0 g
s
.80551 .65806 m .80551 .67659 L .77805 .6722 L p .707 .577 .707 r
F P
0 g
s
.77805 .6722 m .77805 .65367 L .80551 .65806 L p .707 .577 .707 r
F P
0 g
s
.68566 .66701 m .68566 .70406 L .66161 .70971 L p .707 .577 .707 r
F P
0 g
s
.80551 .66914 m .80551 .7062 L .77805 .70181 L p .707 .577 .707 r
F P
0 g
s
.77805 .70181 m .77805 .66475 L .80551 .66914 L p .707 .577 .707 r
F P
0 g
s
.31064 .67545 m .31064 .65692 L .29804 .64904 L p .707 .577 .707 r
F P
0 g
s
.31064 .70505 m .31064 .668 L .29804 .66012 L p .707 .577 .707 r
F P
0 g
s
.68566 .67445 m .68566 .65593 L .71504 .65255 L p .707 .577 .707 r
F P
0 g
s
.29804 .64904 m .29804 .66756 L .31064 .67545 L p .707 .577 .707 r
F P
0 g
s
.68566 .70406 m .68566 .66701 L .71504 .66363 L p .707 .577 .707 r
F P
0 g
s
.71504 .65255 m .71504 .67108 L .68566 .67445 L p .707 .577 .707 r
F P
0 g
s
.29515 .5159 m .29515 .57148 L .29804 .58002 L p .707 .577 .707 r
F P
0 g
s
.49904 .51953 m .49904 .57512 L .49615 .56657 L p .707 .577 .707 r
F P
0 g
s
.49615 .56657 m .49615 .51099 L .49904 .51953 L p .707 .577 .707 r
F P
0 g
s
.77805 .65367 m .77805 .6722 L .74688 .6703 L p .707 .577 .707 r
F P
0 g
s
.74688 .6703 m .74688 .65177 L .77805 .65367 L p .707 .577 .707 r
F P
0 g
s
.29804 .66012 m .29804 .69717 L .31064 .70505 L p .707 .577 .707 r
F P
0 g
s
.77805 .66475 m .77805 .70181 L .74688 .69991 L p .707 .577 .707 r
F P
0 g
s
.74688 .69991 m .74688 .66285 L .77805 .66475 L p .707 .577 .707 r
F P
0 g
s
.71504 .67108 m .71504 .65255 L .74688 .65177 L p .707 .577 .707 r
F P
0 g
s
.49196 .65249 m .49196 .67102 L .49904 .66266 L p .707 .577 .707 r
F P
0 g
s
.49904 .66266 m .49904 .64413 L .49196 .65249 L p .707 .577 .707 r
F P
0 g
s
.71504 .66363 m .71504 .70068 L .68566 .70406 L p .707 .577 .707 r
F P
0 g
s
.74688 .65177 m .74688 .6703 L .71504 .67108 L p .707 .577 .707 r
F P
0 g
s
.71504 .70068 m .71504 .66363 L .74688 .66285 L p .707 .577 .707 r
F P
0 g
s
.49196 .66357 m .49196 .70063 L .49904 .69226 L p .707 .577 .707 r
F P
0 g
s
.49904 .69226 m .49904 .65521 L .49196 .66357 L p .707 .577 .707 r
F P
0 g
s
.74688 .66285 m .74688 .69991 L .71504 .70068 L p .707 .577 .707 r
F P
0 g
s
.29515 .57148 m .29515 .5159 L .30223 .50753 L p .707 .577 .707 r
F P
0 g
s
.29804 .66756 m .29804 .64904 L .29515 .64049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29804 .69717 m .29804 .66012 L .29515 .65157 L p .707 .577 .707 r
F P
0 g
s
.29515 .64049 m .29515 .65902 L .29804 .66756 L p .707 .577 .707 r
F P
0 g
s
.30223 .50753 m .30223 .56312 L .29515 .57148 L p .707 .577 .707 r
F P
0 g
s
.29515 .65157 m .29515 .68863 L .29804 .69717 L p .707 .577 .707 r
F P
0 g
s
.49615 .51099 m .49615 .56657 L .48356 .55869 L p .707 .577 .707 r
F P
0 g
s
.48356 .55869 m .48356 .50311 L .49615 .51099 L p .707 .577 .707 r
F P
0 g
s
.49904 .64413 m .49904 .66266 L .49615 .65411 L p .707 .577 .707 r
F P
0 g
s
.49615 .65411 m .49615 .63559 L .49904 .64413 L p .707 .577 .707 r
F P
0 g
s
.49904 .65521 m .49904 .69226 L .49615 .68372 L p .707 .577 .707 r
F P
0 g
s
.49615 .68372 m .49615 .64667 L .49904 .65521 L p .707 .577 .707 r
F P
0 g
s
.30223 .56312 m .30223 .50753 L .3186 .50017 L p .707 .577 .707 r
F P
0 g
s
.29515 .65902 m .29515 .64049 L .30223 .63213 L p .707 .577 .707 r
F P
0 g
s
.29515 .68863 m .29515 .65157 L .30223 .64321 L p .707 .577 .707 r
F P
0 g
s
.30223 .63213 m .30223 .65066 L .29515 .65902 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3186 .50017 m .3186 .55575 L .30223 .56312 L p .707 .577 .707 r
F P
0 g
s
.48356 .50311 m .48356 .55869 L .4625 .55224 L p .707 .577 .707 r
F P
0 g
s
.4625 .55224 m .4625 .49665 L .48356 .50311 L p .707 .577 .707 r
F P
0 g
s
.30223 .64321 m .30223 .68026 L .29515 .68863 L p .707 .577 .707 r
F P
0 g
s
.49615 .63559 m .49615 .65411 L .48356 .64623 L p .707 .577 .707 r
F P
0 g
s
.48356 .64623 m .48356 .6277 L .49615 .63559 L p .707 .577 .707 r
F P
0 g
s
.49615 .64667 m .49615 .68372 L .48356 .67584 L p .707 .577 .707 r
F P
0 g
s
.48356 .67584 m .48356 .63878 L .49615 .64667 L p .707 .577 .707 r
F P
0 g
s
.3186 .55575 m .3186 .50017 L .34265 .49452 L p .707 .577 .707 r
F P
0 g
s
.30223 .65066 m .30223 .63213 L .3186 .62476 L p .707 .577 .707 r
F P
0 g
s
.30223 .68026 m .30223 .64321 L .3186 .63584 L p .707 .577 .707 r
F P
0 g
s
.4625 .49665 m .4625 .55224 L .43504 .54784 L p .707 .577 .707 r
F P
0 g
s
.43504 .54784 m .43504 .49226 L .4625 .49665 L p .707 .577 .707 r
F P
0 g
s
.3186 .62476 m .3186 .64329 L .30223 .65066 L p .707 .577 .707 r
F P
0 g
s
.34265 .49452 m .34265 .5501 L .3186 .55575 L p .707 .577 .707 r
F P
0 g
s
.34265 .5501 m .34265 .49452 L .37203 .49114 L p .707 .577 .707 r
F P
0 g
s
.3186 .63584 m .3186 .6729 L .30223 .68026 L p .707 .577 .707 r
F P
0 g
s
.48356 .6277 m .48356 .64623 L .4625 .63978 L p .707 .577 .707 r
F P
0 g
s
.4625 .63978 m .4625 .62125 L .48356 .6277 L p .707 .577 .707 r
F P
0 g
s
.48356 .63878 m .48356 .67584 L .4625 .66938 L p .707 .577 .707 r
F P
0 g
s
.4625 .66938 m .4625 .63233 L .48356 .63878 L p .707 .577 .707 r
F P
0 g
s
.43504 .49226 m .43504 .54784 L .40387 .54594 L p .707 .577 .707 r
F P
0 g
s
.40387 .54594 m .40387 .49036 L .43504 .49226 L p .707 .577 .707 r
F P
0 g
s
.37203 .54672 m .37203 .49114 L .40387 .49036 L p .707 .577 .707 r
F P
0 g
s
.37203 .49114 m .37203 .54672 L .34265 .5501 L p .707 .577 .707 r
F P
0 g
s
.3186 .64329 m .3186 .62476 L .34265 .61911 L p .707 .577 .707 r
F P
0 g
s
.40387 .49036 m .40387 .54594 L .37203 .54672 L p .707 .577 .707 r
F P
0 g
s
.3186 .6729 m .3186 .63584 L .34265 .63019 L p .707 .577 .707 r
F P
0 g
s
.34265 .61911 m .34265 .63764 L .3186 .64329 L p .707 .577 .707 r
F P
0 g
s
.4625 .62125 m .4625 .63978 L .43504 .63538 L p .707 .577 .707 r
F P
0 g
s
.43504 .63538 m .43504 .61686 L .4625 .62125 L p .707 .577 .707 r
F P
0 g
s
.34265 .63019 m .34265 .66725 L .3186 .6729 L p .707 .577 .707 r
F P
0 g
s
.4625 .63233 m .4625 .66938 L .43504 .66499 L p .707 .577 .707 r
F P
0 g
s
.43504 .66499 m .43504 .62794 L .4625 .63233 L p .707 .577 .707 r
F P
0 g
s
.34265 .63764 m .34265 .61911 L .37203 .61573 L p .707 .577 .707 r
F P
0 g
s
.34265 .66725 m .34265 .63019 L .37203 .62681 L p .707 .577 .707 r
F P
0 g
s
.37203 .61573 m .37203 .63426 L .34265 .63764 L p .707 .577 .707 r
F P
0 g
s
.43504 .61686 m .43504 .63538 L .40387 .63348 L p .707 .577 .707 r
F P
0 g
s
.40387 .63348 m .40387 .61496 L .43504 .61686 L p .707 .577 .707 r
F P
0 g
s
.43504 .62794 m .43504 .66499 L .40387 .66309 L p .707 .577 .707 r
F P
0 g
s
.40387 .66309 m .40387 .62604 L .43504 .62794 L p .707 .577 .707 r
F P
0 g
s
.37203 .63426 m .37203 .61573 L .40387 .61496 L p .707 .577 .707 r
F P
0 g
s
.37203 .62681 m .37203 .66387 L .34265 .66725 L p .707 .577 .707 r
F P
0 g
s
.40387 .61496 m .40387 .63348 L .37203 .63426 L p .707 .577 .707 r
F P
0 g
s
.37203 .66387 m .37203 .62681 L .40387 .62604 L p .707 .577 .707 r
F P
0 g
s
.40387 .62604 m .40387 .66309 L .37203 .66387 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo002;Ool<0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006aoo`<0
00UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYF
FUH3001^Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006aoo`00J7oo0P0015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0`00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOolB00000eYF001JEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool0061oo`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo
0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000067oo2@00A7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo2@0015YF00<005YFFUH00UYF2000?7oo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=oo`D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002io
o`00Dgoo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF1P000eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
1P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool003mooa4000Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00>Goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF009JEPL000QJEP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH5
0004FUH01000FUIJEUYF0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF100025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000`Ool20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH6
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH8000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUHK0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH900000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00T000AJEP03
001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05FUHF0004FUH00`00FUIJ
EP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH60004FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP<000AJEP03001JEUYF009J
EP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800004FUH005YF
FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL00005FUH005YFFUH00003FUH20000
0eYF000000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF00<005YFFUH00P0017oo4P00?goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH01000FUH005YF0P000eYF10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000EJEP00
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP05001JEUYFFUH0001EOol002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00002FUH00`00FUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH00003FUH30002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`04001JEP00FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH01@00FUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUHH000nOol002aoo`06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YF00000P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00003000jOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF
00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP<000AJEP03001JEUYF00IJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@0039o
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00D005YF
001JEP0000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH005YF0P0000=JEP00FUH015YF0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF0P00<Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP03001JEP0000<000IJEP04001JEUYFFUHC
0002FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEP0000=JEP03001JEUYF009JEP<00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUH00000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000=J
EP<00003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00
00D00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH20004FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH0000200000eYF001JEP02FUH00`00Oomoo`0/Ool002ioo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP06001JEP00FUH005YF0P0000=JEP00FUH00UYF
00<005YFFUH00UYF00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJEP<000=J
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF
00000UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P000eYF00<007ooOol0;7oo000`Ool30004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH005YF0P0000AJEP00FUIJEP@000EJEP<000EJEQ40
00=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF0`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP000000;Goo000cOol3
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YF00000`000UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03000]Ool003Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30000
0eYF000000090005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000kOolJ0003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Egoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUHN0003FUH50004FUH01000FUIJEUYF
0P00;Goo000oOolI0002Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP@00003FUH005YF009JEP8002eoo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPX000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20003FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003
FUH30003FUH2000]Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000800003Ool0000000H000AJEP03001JEUYF00=JEPT000MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000800006FUH00000001JEP001EYF0`0025YF100000=JEP0000001`000eYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP000000;Goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUHF
0004FUH00`00FUIJEP02FUH20002Ool01@00FUIJEP00FUH02P0015YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00UYF0P0000=JEP00000015YF00<005YFFUH00eYF200015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000^Ool20003FUH00`00FUIJEP04FUH30005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF10000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEPD00004FUH000000004
FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`8000AJ
EP<000AJEP03001JEUYF009JEP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000800005FUH005YFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000]Ool002aoo`04001JEP000003FUH00`00FUH0000300000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00@005YF001J
EP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUH007oo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00@005YF000000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003Ool300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000cOol002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020004Ool30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50002Ool40002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF
2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P000goo6@00
?goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH6000AOol80004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01EYF1P000UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000eYF
00<005YFFUH00UYF0P00FGoo000/Ool00`00FUH00004FUH00`00FUH000030004FUHI0002FUH60004
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF00000UYF1@00
15YF0`00Egoo000/Ool00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH0000500001EYF001JEUYF00000UYF00<005YFFUH00eYF0`000UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF10000UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YF00000P0000AJEP00FUIJEP8005Eoo`00;7oo00@0
05YF001JEP<000AJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50005FUH30002FUH01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00001EYF00<005YFFUH0
0UYF0P000eYF00<007ooOol0Dgoo000/Ool01`00FUH00000FUH005YF00<00003FUH005YF00AJEP<0
00AJEQ8000=JEP03001JEUYF00AJEP03001JEUYF00<0009JEP04001JEP000007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000UYF00<005YF00001EYF00<005YFFUH00eYF0`0000=JEP000000E7oo000/Ool20003FUH00`00
FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH0
15YF00<005YFFUH00eYF00<005YFFUH00`00E7oo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJ
EUYF1@0000=JEP0000002@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]
Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00
0005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]Ool01@00FUIJEUYF00001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00
<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF0000009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP0000=JEPD000AJEP04001JEUYFFUH2001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Aoo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP<00003FUH005YF009JEP8005Ao
o`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00
27oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001EYF00<005YF00000`0000AJEP000000
00=JEP8005Aoo`00>goo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@003Woo0`001eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUIJEP/000EJEP04001JEUYF0002FUH2001DOol004=ooa<001Eoo`8000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001J
EP001eYF00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00KGoo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00E7oo001_Ool300000eYF001JEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050007FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol0079oo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0005Aoo`00NGoo30001UYF00<005YFFUH02UYF00<005YFFUH01P0025YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00EGoo0025OolF0005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00EWoo002AOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000F7oo002BOol30003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001JOol009Eoo`D000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<005eoo`00VWoo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00HGoo002NOolI001VOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76948 m .59613 .7139 L .56496 .712 L p .707 .577 .707 r
F P
0 g
s
.59613 .7139 m .59613 .76948 L .62796 .76871 L p .707 .577 .707 r
F P
0 g
s
.62796 .76871 m .62796 .71312 L .59613 .7139 L p .707 .577 .707 r
F P
0 g
s
.62796 .71312 m .62796 .76871 L .65735 .76533 L p .707 .577 .707 r
F P
0 g
s
.65735 .76533 m .65734 .70975 L .62796 .71312 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .73601 L .56496 .73411 L p .707 .577 .707 r
F P
0 g
s
.59613 .73601 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .73601 L p .707 .577 .707 r
F P
0 g
s
.56496 .76758 m .56496 .712 L .5375 .70761 L p .707 .577 .707 r
F P
0 g
s
.56496 .712 m .56496 .76758 L .59613 .76948 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .73411 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .73411 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.65734 .70975 m .65735 .76533 L .6814 .75968 L p .707 .577 .707 r
F P
0 g
s
.6814 .75968 m .6814 .7041 L .65734 .70975 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76326 L p .707 .577 .707 r
F P
0 g
s
.6814 .76326 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.5375 .70761 m .5375 .76319 L .56496 .76758 L p .707 .577 .707 r
F P
0 g
s
.5375 .76319 m .5375 .70761 L .51644 .70116 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.6814 .7041 m .6814 .75968 L .69777 .75231 L p .707 .577 .707 r
F P
0 g
s
.69777 .75231 m .69777 .69673 L .6814 .7041 L p .707 .577 .707 r
F P
0 g
s
.51644 .70116 m .51644 .75674 L .5375 .76319 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76326 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.59613 .88634 m .59613 .86781 L .56496 .86591 L p .707 .577 .707 r
F P
0 g
s
.59613 .86781 m .59613 .88634 L .62796 .88556 L p .707 .577 .707 r
F P
0 g
s
.62796 .88556 m .62796 .86703 L .59613 .86781 L p .707 .577 .707 r
F P
0 g
s
.62796 .86703 m .62796 .88556 L .65735 .88218 L p .707 .577 .707 r
F P
0 g
s
.65735 .88218 m .65735 .86365 L .62796 .86703 L p .707 .577 .707 r
F P
0 g
s
.51644 .75674 m .51644 .70116 L .50385 .69327 L p .707 .577 .707 r
F P
0 g
s
.56496 .86591 m .56496 .88444 L .59613 .88634 L p .707 .577 .707 r
F P
0 g
s
.56496 .88444 m .56496 .86591 L .5375 .86152 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71538 L p .707 .577 .707 r
F P
0 g
s
.5375 .86152 m .5375 .88005 L .56496 .88444 L p .707 .577 .707 r
F P
0 g
s
.65735 .86365 m .65735 .88218 L .6814 .87653 L p .707 .577 .707 r
F P
0 g
s
.6814 .87653 m .6814 .858 L .65735 .86365 L p .707 .577 .707 r
F P
0 g
s
.50385 .69327 m .50385 .74885 L .51644 .75674 L p .707 .577 .707 r
F P
0 g
s
.69777 .69673 m .69777 .75231 L .70485 .74395 L p .707 .577 .707 r
F P
0 g
s
.70485 .74395 m .70485 .68836 L .69777 .69673 L p .707 .577 .707 r
F P
0 g
s
.50385 .71538 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.5375 .88005 m .5375 .86152 L .51644 .85506 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.51644 .85506 m .51644 .87359 L .5375 .88005 L p .707 .577 .707 r
F P
0 g
s
.50385 .74885 m .50385 .69327 L .50095 .68473 L p .707 .577 .707 r
F P
0 g
s
.6814 .858 m .6814 .87653 L .69777 .86916 L p .707 .577 .707 r
F P
0 g
s
.69777 .86916 m .69777 .85064 L .6814 .858 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71538 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.51644 .87359 m .51644 .85506 L .50385 .84718 L p .707 .577 .707 r
F P
0 g
s
.50095 .68473 m .50095 .74031 L .50385 .74885 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.70485 .68836 m .70485 .74395 L .70195 .7354 L p .707 .577 .707 r
F P
0 g
s
.70195 .7354 m .70195 .67982 L .70485 .68836 L p .707 .577 .707 r
F P
0 g
s
.50385 .84718 m .50385 .86571 L .51644 .87359 L p .707 .577 .707 r
F P
0 g
s
.49044 .81524 m .49044 .31335 L .44643 .31066 L p .707 .577 .707 r
F P
0 g
s
.50095 .74031 m .50095 .68473 L .50804 .67636 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .67636 m .50804 .73195 L .50095 .74031 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .73195 m .50804 .67636 L .5244 .669 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.5244 .669 m .5244 .72458 L .50804 .73195 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72816 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .72458 m .5244 .669 L .54846 .66335 L p .707 .577 .707 r
F P
0 g
s
.5244 .72816 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.54846 .66335 m .54846 .71893 L .5244 .72458 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .72251 L .5244 .72816 L p .707 .577 .707 r
F P
0 g
s
.49044 .31335 m .49044 .81524 L .53538 .81414 L p .707 .577 .707 r
F P
0 g
s
.53538 .81414 m .53538 .31225 L .49044 .31335 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70193 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.54846 .71893 m .54846 .66335 L .57784 .65997 L p .707 .577 .707 r
F P
0 g
s
.54846 .72251 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.57784 .65997 m .57784 .71555 L .54846 .71893 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .72251 L p .707 .577 .707 r
F P
0 g
s
.53538 .31225 m .53538 .81414 L .57686 .80937 L p .707 .577 .707 r
F P
0 g
s
.57686 .80937 m .57686 .30748 L .53538 .31225 L p .707 .577 .707 r
F P
0 g
s
.44643 .81255 m .44643 .31066 L .40766 .30446 L p .707 .577 .707 r
F P
0 g
s
.44643 .31066 m .44643 .81255 L .49044 .81524 L p .707 .577 .707 r
F P
0 g
s
.69777 .85064 m .69777 .86916 L .70485 .8608 L p .707 .577 .707 r
F P
0 g
s
.70485 .8608 m .70485 .84227 L .69777 .85064 L p .707 .577 .707 r
F P
0 g
s
.57784 .71555 m .57784 .65997 L .60968 .65919 L p .707 .577 .707 r
F P
0 g
s
.60968 .65919 m .60968 .71477 L .57784 .71555 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .6813 L p .707 .577 .707 r
F P
0 g
s
.60968 .6813 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.57686 .30748 m .57686 .80937 L .61082 .80139 L p .707 .577 .707 r
F P
0 g
s
.64085 .66109 m .64085 .71667 L .60968 .71477 L p .707 .577 .707 r
F P
0 g
s
.60968 .71477 m .60968 .65919 L .64085 .66109 L p .707 .577 .707 r
F P
0 g
s
.64085 .6832 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .6813 L .64085 .6832 L p .707 .577 .707 r
F P
0 g
s
.61082 .80139 m .61082 .2995 L .57686 .30748 L p .707 .577 .707 r
F P
0 g
s
.50385 .86571 m .50385 .84718 L .50095 .83864 L p .707 .577 .707 r
F P
0 g
s
.50095 .83864 m .50095 .85716 L .50385 .86571 L p .707 .577 .707 r
F P
0 g
s
.70195 .67982 m .70195 .7354 L .68936 .72752 L p .707 .577 .707 r
F P
0 g
s
.68936 .72752 m .68936 .67194 L .70195 .67982 L p .707 .577 .707 r
F P
0 g
s
.40766 .80635 m .40766 .30446 L .37794 .29535 L p .707 .577 .707 r
F P
0 g
s
.40766 .30446 m .40766 .80635 L .44643 .81255 L p .707 .577 .707 r
F P
0 g
s
.70195 .70193 m .70195 .73898 L .68936 .7311 L p .707 .577 .707 r
F P
0 g
s
.68936 .7311 m .68936 .69404 L .70195 .70193 L p .707 .577 .707 r
F P
0 g
s
.25312 .73267 m .25312 .67709 L .22195 .67519 L p .707 .577 .707 r
F P
0 g
s
.25312 .67709 m .25312 .73267 L .28495 .73189 L p .707 .577 .707 r
F P
0 g
s
.28495 .73189 m .28495 .67631 L .25312 .67709 L p .707 .577 .707 r
F P
0 g
s
.70485 .84227 m .70485 .8608 L .70195 .85226 L p .707 .577 .707 r
F P
0 g
s
.70195 .85226 m .70195 .83373 L .70485 .84227 L p .707 .577 .707 r
F P
0 g
s
.28495 .67631 m .28495 .73189 L .31434 .72851 L p .707 .577 .707 r
F P
0 g
s
.31434 .72851 m .31434 .67293 L .28495 .67631 L p .707 .577 .707 r
F P
0 g
s
.25312 .73625 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73625 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.22195 .73077 m .22195 .67519 L .19449 .67079 L p .707 .577 .707 r
F P
0 g
s
.22195 .67519 m .22195 .73077 L .25312 .73267 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69504 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.61082 .2995 m .61082 .80139 L .63393 .79099 L p .707 .577 .707 r
F P
0 g
s
.63393 .79099 m .63393 .2891 L .61082 .2995 L p .707 .577 .707 r
F P
0 g
s
.22195 .73435 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73435 L .25312 .73625 L p .707 .577 .707 r
F P
0 g
s
.31434 .67293 m .31434 .72851 L .33839 .72286 L p .707 .577 .707 r
F P
0 g
s
.33839 .72286 m .33839 .66728 L .31434 .67293 L p .707 .577 .707 r
F P
0 g
s
.50095 .85716 m .50095 .83864 L .50804 .83027 L p .707 .577 .707 r
F P
0 g
s
.68936 .67194 m .68936 .72752 L .66831 .72107 L p .707 .577 .707 r
F P
0 g
s
.66831 .72107 m .66831 .66548 L .68936 .67194 L p .707 .577 .707 r
F P
0 g
s
.50804 .83027 m .50804 .8488 L .50095 .85716 L p .707 .577 .707 r
F P
0 g
s
.31434 .69504 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68939 L .31434 .69504 L p .707 .577 .707 r
F P
0 g
s
.19449 .67079 m .19449 .72638 L .22195 .73077 L p .707 .577 .707 r
F P
0 g
s
.19449 .72638 m .19449 .67079 L .17343 .66434 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73435 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .7311 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.37794 .79724 m .37794 .29535 L .36016 .28422 L p .707 .577 .707 r
F P
0 g
s
.37794 .29535 m .37794 .79724 L .40766 .80635 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.70195 .83373 m .70195 .85226 L .68936 .84437 L p .707 .577 .707 r
F P
0 g
s
.68936 .84437 m .68936 .82585 L .70195 .83373 L p .707 .577 .707 r
F P
0 g
s
.33839 .66728 m .33839 .72286 L .35476 .7155 L p .707 .577 .707 r
F P
0 g
s
.35476 .7155 m .35476 .65991 L .33839 .66728 L p .707 .577 .707 r
F P
0 g
s
.17343 .66434 m .17343 .71992 L .19449 .72638 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68939 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68939 L p .707 .577 .707 r
F P
0 g
s
.66831 .66548 m .66831 .72107 L .64085 .71667 L p .707 .577 .707 r
F P
0 g
s
.64085 .71667 m .64085 .66109 L .66831 .66548 L p .707 .577 .707 r
F P
0 g
s
.25312 .84952 m .25312 .831 L .22195 .82909 L p .707 .577 .707 r
F P
0 g
s
.25312 .831 m .25312 .84952 L .28495 .84875 L p .707 .577 .707 r
F P
0 g
s
.28495 .84875 m .28495 .83022 L .25312 .831 L p .707 .577 .707 r
F P
0 g
s
.50804 .8488 m .50804 .83027 L .5244 .82291 L p .707 .577 .707 r
F P
0 g
s
.28495 .83022 m .28495 .84875 L .31434 .84537 L p .707 .577 .707 r
F P
0 g
s
.31434 .84537 m .31434 .82684 L .28495 .83022 L p .707 .577 .707 r
F P
0 g
s
.17343 .71992 m .17343 .66434 L .16084 .65646 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .6832 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.22195 .82909 m .22195 .84762 L .25312 .84952 L p .707 .577 .707 r
F P
0 g
s
.63393 .2891 m .63393 .79099 L .64393 .77918 L p .707 .577 .707 r
F P
0 g
s
.64393 .77918 m .64393 .27729 L .63393 .2891 L p .707 .577 .707 r
F P
0 g
s
.22195 .84762 m .22195 .82909 L .19449 .8247 L p .707 .577 .707 r
F P
0 g
s
.5244 .82291 m .5244 .84143 L .50804 .8488 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.19449 .8247 m .19449 .84323 L .22195 .84762 L p .707 .577 .707 r
F P
0 g
s
.31434 .82684 m .31434 .84537 L .33839 .83972 L p .707 .577 .707 r
F P
0 g
s
.33839 .83972 m .33839 .82119 L .31434 .82684 L p .707 .577 .707 r
F P
0 g
s
.16084 .65646 m .16084 .71204 L .17343 .71992 L p .707 .577 .707 r
F P
0 g
s
.68936 .82585 m .68936 .84437 L .66831 .83792 L p .707 .577 .707 r
F P
0 g
s
.66831 .83792 m .66831 .81939 L .68936 .82585 L p .707 .577 .707 r
F P
0 g
s
.35476 .65991 m .35476 .7155 L .36184 .70713 L p .707 .577 .707 r
F P
0 g
s
.36184 .70713 m .36184 .65155 L .35476 .65991 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.19449 .84323 m .19449 .8247 L .17343 .81825 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .65155 m .36184 .70713 L .35894 .69859 L p .707 .577 .707 r
F P
0 g
s
.35894 .69859 m .35894 .64301 L .36184 .65155 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70217 L p .707 .577 .707 r
F P
0 g
s
.35894 .70217 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .78611 m .36016 .28422 L .35607 .27216 L p .707 .577 .707 r
F P
0 g
s
.36016 .28422 m .36016 .78611 L .37794 .79724 L p .707 .577 .707 r
F P
0 g
s
.17343 .81825 m .17343 .83678 L .19449 .84323 L p .707 .577 .707 r
F P
0 g
s
.5244 .84143 m .5244 .82291 L .54846 .81726 L p .707 .577 .707 r
F P
0 g
s
.16084 .71204 m .16084 .65646 L .15794 .64791 L p .707 .577 .707 r
F P
0 g
s
.54846 .81726 m .54846 .83578 L .5244 .84143 L p .707 .577 .707 r
F P
0 g
s
.33839 .82119 m .33839 .83972 L .35476 .83235 L p .707 .577 .707 r
F P
0 g
s
.35476 .83235 m .35476 .81382 L .33839 .82119 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.66831 .81939 m .66831 .83792 L .64085 .83353 L p .707 .577 .707 r
F P
0 g
s
.64085 .83353 m .64085 .815 L .66831 .81939 L p .707 .577 .707 r
F P
0 g
s
.17343 .83678 m .17343 .81825 L .16084 .81036 L p .707 .577 .707 r
F P
0 g
s
.15794 .64791 m .15794 .7035 L .16084 .71204 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.64393 .27729 m .64393 .77918 L .63984 .76712 L p .707 .577 .707 r
F P
0 g
s
.63984 .76712 m .63984 .26523 L .64393 .27729 L p .707 .577 .707 r
F P
0 g
s
.54846 .83578 m .54846 .81726 L .57784 .81388 L p .707 .577 .707 r
F P
0 g
s
.16084 .81036 m .16084 .82889 L .17343 .83678 L p .707 .577 .707 r
F P
0 g
s
.57784 .81388 m .57784 .8324 L .54846 .83578 L p .707 .577 .707 r
F P
0 g
s
.64085 .815 m .64085 .83353 L .60968 .83163 L p .707 .577 .707 r
F P
0 g
s
.60968 .83163 m .60968 .8131 L .64085 .815 L p .707 .577 .707 r
F P
0 g
s
.57784 .8324 m .57784 .81388 L .60968 .8131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81382 m .35476 .83235 L .36184 .82399 L p .707 .577 .707 r
F P
0 g
s
.36184 .82399 m .36184 .80546 L .35476 .81382 L p .707 .577 .707 r
F P
0 g
s
.15794 .7035 m .15794 .64791 L .16503 .63955 L p .707 .577 .707 r
F P
0 g
s
.60968 .8131 m .60968 .83163 L .57784 .8324 L p .707 .577 .707 r
F P
0 g
s
.35894 .64301 m .35894 .69859 L .34635 .6907 L p .707 .577 .707 r
F P
0 g
s
.34635 .6907 m .34635 .63512 L .35894 .64301 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70217 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65723 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .27216 m .35607 .77405 L .36016 .78611 L p .707 .577 .707 r
F P
0 g
s
.35607 .77405 m .35607 .27216 L .36607 .26035 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.16084 .82889 m .16084 .81036 L .15794 .80182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .63955 m .16503 .69513 L .15794 .7035 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.15794 .80182 m .15794 .82035 L .16084 .82889 L p .707 .577 .707 r
F P
0 g
s
.36184 .80546 m .36184 .82399 L .35894 .81544 L p .707 .577 .707 r
F P
0 g
s
.35894 .81544 m .35894 .79692 L .36184 .80546 L p .707 .577 .707 r
F P
0 g
s
.63984 .26523 m .63984 .76712 L .62206 .75599 L p .707 .577 .707 r
F P
0 g
s
.62206 .75599 m .62206 .2541 L .63984 .26523 L p .707 .577 .707 r
F P
0 g
s
.16503 .69513 m .16503 .63955 L .1814 .63218 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65429 L p .707 .577 .707 r
F P
0 g
s
.15794 .82035 m .15794 .80182 L .16503 .79346 L p .707 .577 .707 r
F P
0 g
s
.1814 .63218 m .1814 .68776 L .16503 .69513 L p .707 .577 .707 r
F P
0 g
s
.34635 .63512 m .34635 .6907 L .3253 .68425 L p .707 .577 .707 r
F P
0 g
s
.3253 .68425 m .3253 .62867 L .34635 .63512 L p .707 .577 .707 r
F P
0 g
s
.1814 .65429 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.36607 .76224 m .36607 .26035 L .38918 .24995 L p .707 .577 .707 r
F P
0 g
s
.36607 .26035 m .36607 .76224 L .35607 .77405 L p .707 .577 .707 r
F P
0 g
s
.16503 .79346 m .16503 .81199 L .15794 .82035 L p .707 .577 .707 r
F P
0 g
s
.34635 .65723 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65723 L p .707 .577 .707 r
F P
0 g
s
.1814 .68776 m .1814 .63218 L .20545 .62653 L p .707 .577 .707 r
F P
0 g
s
.35894 .79692 m .35894 .81544 L .34635 .80756 L p .707 .577 .707 r
F P
0 g
s
.34635 .80756 m .34635 .78903 L .35894 .79692 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65429 L .20545 .64864 L p .707 .577 .707 r
F P
0 g
s
.3253 .62867 m .3253 .68425 L .29784 .67986 L p .707 .577 .707 r
F P
0 g
s
.29784 .67986 m .29784 .62428 L .3253 .62867 L p .707 .577 .707 r
F P
0 g
s
.62206 .2541 m .62206 .75599 L .59233 .74688 L p .707 .577 .707 r
F P
0 g
s
.59233 .74688 m .59233 .24499 L .62206 .2541 L p .707 .577 .707 r
F P
0 g
s
.20545 .62653 m .20545 .68211 L .1814 .68776 L p .707 .577 .707 r
F P
0 g
s
.16503 .81199 m .16503 .79346 L .1814 .78609 L p .707 .577 .707 r
F P
0 g
s
.20545 .64864 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68344 L p .707 .577 .707 r
F P
0 g
s
.29784 .68344 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68211 m .20545 .62653 L .23483 .62315 L p .707 .577 .707 r
F P
0 g
s
.1814 .78609 m .1814 .80462 L .16503 .81199 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64864 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.38918 .24995 m .38918 .75184 L .36607 .76224 L p .707 .577 .707 r
F P
0 g
s
.38918 .75184 m .38918 .24995 L .42314 .24197 L p .707 .577 .707 r
F P
0 g
s
.29784 .62428 m .29784 .67986 L .26667 .67796 L p .707 .577 .707 r
F P
0 g
s
.26667 .67796 m .26667 .62238 L .29784 .62428 L p .707 .577 .707 r
F P
0 g
s
.34635 .78903 m .34635 .80756 L .3253 .8011 L p .707 .577 .707 r
F P
0 g
s
.3253 .8011 m .3253 .78258 L .34635 .78903 L p .707 .577 .707 r
F P
0 g
s
.23483 .67873 m .23483 .62315 L .26667 .62238 L p .707 .577 .707 r
F P
0 g
s
.23483 .62315 m .23483 .67873 L .20545 .68211 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68344 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.26667 .62238 m .26667 .67796 L .23483 .67873 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.73333 .67745 m .73333 .62186 L .70216 .61996 L p .707 .577 .707 r
F P
0 g
s
.73333 .62186 m .73333 .67745 L .76517 .67667 L p .707 .577 .707 r
F P
0 g
s
.76517 .67667 m .76517 .62109 L .73333 .62186 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.76517 .62109 m .76517 .67667 L .79455 .67329 L p .707 .577 .707 r
F P
0 g
s
.79455 .67329 m .79455 .61771 L .76517 .62109 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.1814 .80462 m .1814 .78609 L .20545 .78044 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68025 L p .707 .577 .707 r
F P
0 g
s
.76517 .68025 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.70216 .67555 m .70216 .61996 L .6747 .61557 L p .707 .577 .707 r
F P
0 g
s
.70216 .61996 m .70216 .67555 L .73333 .67745 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68025 L .79455 .67687 L p .707 .577 .707 r
F P
0 g
s
.79455 .67687 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.59233 .24499 m .59233 .74688 L .55357 .74068 L p .707 .577 .707 r
F P
0 g
s
.55357 .74068 m .55357 .23879 L .59233 .24499 L p .707 .577 .707 r
F P
0 g
s
.20545 .78044 m .20545 .79897 L .1814 .80462 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63768 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.79455 .61771 m .79455 .67329 L .8186 .66764 L p .707 .577 .707 r
F P
0 g
s
.8186 .66764 m .8186 .61206 L .79455 .61771 L p .707 .577 .707 r
F P
0 g
s
.3253 .78258 m .3253 .8011 L .29784 .79671 L p .707 .577 .707 r
F P
0 g
s
.29784 .79671 m .29784 .77819 L .3253 .78258 L p .707 .577 .707 r
F P
0 g
s
.42314 .74386 m .42314 .24197 L .46462 .2372 L p .707 .577 .707 r
F P
0 g
s
.42314 .24197 m .42314 .74386 L .38918 .75184 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67687 L .8186 .67122 L p .707 .577 .707 r
F P
0 g
s
.8186 .67122 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.6747 .61557 m .6747 .67115 L .70216 .67555 L p .707 .577 .707 r
F P
0 g
s
.6747 .67115 m .6747 .61557 L .65365 .60912 L p .707 .577 .707 r
F P
0 g
s
.6747 .63768 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.20545 .79897 m .20545 .78044 L .23483 .77706 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63768 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.23483 .77706 m .23483 .79559 L .20545 .79897 L p .707 .577 .707 r
F P
0 g
s
.55357 .23879 m .55357 .74068 L .50956 .738 L p .707 .577 .707 r
F P
0 g
s
.50956 .738 m .50956 .23611 L .55357 .23879 L p .707 .577 .707 r
F P
0 g
s
.29784 .77819 m .29784 .79671 L .26667 .79481 L p .707 .577 .707 r
F P
0 g
s
.26667 .79481 m .26667 .77628 L .29784 .77819 L p .707 .577 .707 r
F P
0 g
s
.8186 .61206 m .8186 .66764 L .83497 .66027 L p .707 .577 .707 r
F P
0 g
s
.83497 .66027 m .83497 .60469 L .8186 .61206 L p .707 .577 .707 r
F P
0 g
s
.46462 .73909 m .46462 .2372 L .50956 .23611 L p .707 .577 .707 r
F P
0 g
s
.46462 .2372 m .46462 .73909 L .42314 .74386 L p .707 .577 .707 r
F P
0 g
s
.65365 .60912 m .65365 .6647 L .6747 .67115 L p .707 .577 .707 r
F P
0 g
s
.23483 .79559 m .23483 .77706 L .26667 .77628 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66828 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.50956 .23611 m .50956 .738 L .46462 .73909 L p .707 .577 .707 r
F P
0 g
s
.26667 .77628 m .26667 .79481 L .23483 .79559 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67122 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.73333 .7943 m .73333 .77577 L .70216 .77387 L p .707 .577 .707 r
F P
0 g
s
.73333 .77577 m .73333 .7943 L .76517 .79352 L p .707 .577 .707 r
F P
0 g
s
.76517 .79352 m .76517 .775 L .73333 .77577 L p .707 .577 .707 r
F P
0 g
s
.76517 .775 m .76517 .79352 L .79455 .79014 L p .707 .577 .707 r
F P
0 g
s
.79455 .79014 m .79455 .77162 L .76517 .775 L p .707 .577 .707 r
F P
0 g
s
.65365 .6647 m .65365 .60912 L .64105 .60123 L p .707 .577 .707 r
F P
0 g
s
.70216 .77387 m .70216 .7924 L .73333 .7943 L p .707 .577 .707 r
F P
0 g
s
.70216 .7924 m .70216 .77387 L .6747 .76948 L p .707 .577 .707 r
F P
0 g
s
.65365 .66828 m .65365 .63122 L .64105 .62334 L p .707 .577 .707 r
F P
0 g
s
.6747 .76948 m .6747 .78801 L .70216 .7924 L p .707 .577 .707 r
F P
0 g
s
.79455 .77162 m .79455 .79014 L .8186 .78449 L p .707 .577 .707 r
F P
0 g
s
.8186 .78449 m .8186 .76597 L .79455 .77162 L p .707 .577 .707 r
F P
0 g
s
.64105 .60123 m .64105 .65681 L .65365 .6647 L p .707 .577 .707 r
F P
0 g
s
.83497 .60469 m .83497 .66027 L .84205 .65191 L p .707 .577 .707 r
F P
0 g
s
.84205 .65191 m .84205 .59633 L .83497 .60469 L p .707 .577 .707 r
F P
0 g
s
.64105 .62334 m .64105 .66039 L .65365 .66828 L p .707 .577 .707 r
F P
0 g
s
.6747 .78801 m .6747 .76948 L .65365 .76303 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.65365 .76303 m .65365 .78155 L .6747 .78801 L p .707 .577 .707 r
F P
0 g
s
.64105 .65681 m .64105 .60123 L .63816 .59269 L p .707 .577 .707 r
F P
0 g
s
.8186 .76597 m .8186 .78449 L .83497 .77713 L p .707 .577 .707 r
F P
0 g
s
.83497 .77713 m .83497 .7586 L .8186 .76597 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62334 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.65365 .78155 m .65365 .76303 L .64105 .75514 L p .707 .577 .707 r
F P
0 g
s
.63816 .59269 m .63816 .64827 L .64105 .65681 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.84205 .59633 m .84205 .65191 L .83916 .64337 L p .707 .577 .707 r
F P
0 g
s
.83916 .64337 m .83916 .58778 L .84205 .59633 L p .707 .577 .707 r
F P
0 g
s
.64105 .75514 m .64105 .77367 L .65365 .78155 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.83497 .7586 m .83497 .77713 L .84206 .76876 L p .707 .577 .707 r
F P
0 g
s
.84206 .76876 m .84206 .75023 L .83497 .7586 L p .707 .577 .707 r
F P
0 g
s
.63816 .64827 m .63816 .59269 L .64524 .58433 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.64105 .77367 m .64105 .75514 L .63816 .7466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58433 m .64524 .63991 L .63816 .64827 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64349 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.63816 .7466 m .63816 .76513 L .64105 .77367 L p .707 .577 .707 r
F P
0 g
s
.83916 .58778 m .83916 .64337 L .82657 .63548 L p .707 .577 .707 r
F P
0 g
s
.82657 .63548 m .82657 .5799 L .83916 .58778 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.39032 .64063 m .39032 .58505 L .35915 .58315 L p .707 .577 .707 r
F P
0 g
s
.39032 .58505 m .39032 .64063 L .42216 .63985 L p .707 .577 .707 r
F P
0 g
s
.42216 .63985 m .42216 .58427 L .39032 .58505 L p .707 .577 .707 r
F P
0 g
s
.84206 .75023 m .84206 .76876 L .83916 .76022 L p .707 .577 .707 r
F P
0 g
s
.83916 .76022 m .83916 .74169 L .84206 .75023 L p .707 .577 .707 r
F P
0 g
s
.64524 .63991 m .64524 .58433 L .66161 .57696 L p .707 .577 .707 r
F P
0 g
s
.42216 .58427 m .42216 .63985 L .45154 .63647 L p .707 .577 .707 r
F P
0 g
s
.45154 .63647 m .45154 .58089 L .42216 .58427 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60638 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.35915 .63873 m .35915 .58315 L .33169 .57876 L p .707 .577 .707 r
F P
0 g
s
.35915 .58315 m .35915 .63873 L .39032 .64063 L p .707 .577 .707 r
F P
0 g
s
.64524 .64349 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60638 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .603 L .42216 .60638 L p .707 .577 .707 r
F P
0 g
s
.35915 .64231 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .64231 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.45154 .58089 m .45154 .63647 L .47559 .63082 L p .707 .577 .707 r
F P
0 g
s
.47559 .63082 m .47559 .57524 L .45154 .58089 L p .707 .577 .707 r
F P
0 g
s
.63816 .76513 m .63816 .7466 L .64524 .73824 L p .707 .577 .707 r
F P
0 g
s
.66161 .57696 m .66161 .63254 L .64524 .63991 L p .707 .577 .707 r
F P
0 g
s
.82657 .5799 m .82657 .63548 L .80551 .62903 L p .707 .577 .707 r
F P
0 g
s
.80551 .62903 m .80551 .57344 L .82657 .5799 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64349 L p .707 .577 .707 r
F P
0 g
s
.64524 .73824 m .64524 .75676 L .63816 .76513 L p .707 .577 .707 r
F P
0 g
s
.45154 .603 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59735 L .45154 .603 L p .707 .577 .707 r
F P
0 g
s
.33169 .57876 m .33169 .63434 L .35915 .63873 L p .707 .577 .707 r
F P
0 g
s
.33169 .63434 m .33169 .57876 L .31064 .5723 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .64231 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .59441 L p .707 .577 .707 r
F P
0 g
s
.66161 .63254 m .66161 .57696 L .68566 .57131 L p .707 .577 .707 r
F P
0 g
s
.83916 .74169 m .83916 .76022 L .82657 .75234 L p .707 .577 .707 r
F P
0 g
s
.82657 .75234 m .82657 .73381 L .83916 .74169 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.47559 .57524 m .47559 .63082 L .49196 .62346 L p .707 .577 .707 r
F P
0 g
s
.49196 .62346 m .49196 .56787 L .47559 .57524 L p .707 .577 .707 r
F P
0 g
s
.31064 .5723 m .31064 .62788 L .33169 .63434 L p .707 .577 .707 r
F P
0 g
s
.31064 .59441 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.47559 .59735 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59735 L p .707 .577 .707 r
F P
0 g
s
.80551 .57344 m .80551 .62903 L .77805 .62463 L p .707 .577 .707 r
F P
0 g
s
.77805 .62463 m .77805 .56905 L .80551 .57344 L p .707 .577 .707 r
F P
0 g
s
.39032 .75748 m .39032 .73896 L .35915 .73706 L p .707 .577 .707 r
F P
0 g
s
.39032 .73896 m .39032 .75748 L .42216 .75671 L p .707 .577 .707 r
F P
0 g
s
.42216 .75671 m .42216 .73818 L .39032 .73896 L p .707 .577 .707 r
F P
0 g
s
.68566 .57131 m .68566 .62689 L .66161 .63254 L p .707 .577 .707 r
F P
0 g
s
.64524 .75676 m .64524 .73824 L .66161 .73087 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.42216 .73818 m .42216 .75671 L .45154 .75333 L p .707 .577 .707 r
F P
0 g
s
.45154 .75333 m .45154 .7348 L .42216 .73818 L p .707 .577 .707 r
F P
0 g
s
.31064 .62788 m .31064 .5723 L .29804 .56442 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.35915 .73706 m .35915 .75558 L .39032 .75748 L p .707 .577 .707 r
F P
0 g
s
.68566 .62689 m .68566 .57131 L .71504 .56793 L p .707 .577 .707 r
F P
0 g
s
.35915 .75558 m .35915 .73706 L .33169 .73266 L p .707 .577 .707 r
F P
0 g
s
.66161 .73087 m .66161 .74939 L .64524 .75676 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .59441 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.33169 .73266 m .33169 .75119 L .35915 .75558 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.77805 .56905 m .77805 .62463 L .74688 .62273 L p .707 .577 .707 r
F P
0 g
s
.74688 .62273 m .74688 .56715 L .77805 .56905 L p .707 .577 .707 r
F P
0 g
s
.45154 .7348 m .45154 .75333 L .47559 .74768 L p .707 .577 .707 r
F P
0 g
s
.47559 .74768 m .47559 .72915 L .45154 .7348 L p .707 .577 .707 r
F P
0 g
s
.29804 .56442 m .29804 .62 L .31064 .62788 L p .707 .577 .707 r
F P
0 g
s
.82657 .73381 m .82657 .75234 L .80551 .74588 L p .707 .577 .707 r
F P
0 g
s
.80551 .74588 m .80551 .72735 L .82657 .73381 L p .707 .577 .707 r
F P
0 g
s
.71504 .62351 m .71504 .56793 L .74688 .56715 L p .707 .577 .707 r
F P
0 g
s
.71504 .56793 m .71504 .62351 L .68566 .62689 L p .707 .577 .707 r
F P
0 g
s
.49196 .56787 m .49196 .62346 L .49904 .61509 L p .707 .577 .707 r
F P
0 g
s
.49904 .61509 m .49904 .55951 L .49196 .56787 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62358 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58926 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.74688 .56715 m .74688 .62273 L .71504 .62351 L p .707 .577 .707 r
F P
0 g
s
.33169 .75119 m .33169 .73266 L .31064 .72621 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58926 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.74688 .58926 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.31064 .72621 m .31064 .74474 L .33169 .75119 L p .707 .577 .707 r
F P
0 g
s
.66161 .74939 m .66161 .73087 L .68566 .72522 L p .707 .577 .707 r
F P
0 g
s
.29804 .62 m .29804 .56442 L .29515 .55587 L p .707 .577 .707 r
F P
0 g
s
.68566 .72522 m .68566 .74375 L .66161 .74939 L p .707 .577 .707 r
F P
0 g
s
.47559 .72915 m .47559 .74768 L .49196 .74031 L p .707 .577 .707 r
F P
0 g
s
.49196 .74031 m .49196 .72178 L .47559 .72915 L p .707 .577 .707 r
F P
0 g
s
.29804 .62358 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.80551 .72735 m .80551 .74588 L .77805 .74149 L p .707 .577 .707 r
F P
0 g
s
.77805 .74149 m .77805 .72296 L .80551 .72735 L p .707 .577 .707 r
F P
0 g
s
.31064 .74474 m .31064 .72621 L .29804 .71833 L p .707 .577 .707 r
F P
0 g
s
.29515 .55587 m .29515 .61146 L .29804 .62 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62358 L p .707 .577 .707 r
F P
0 g
s
.49904 .55951 m .49904 .61509 L .49615 .60655 L p .707 .577 .707 r
F P
0 g
s
.49615 .60655 m .49615 .55097 L .49904 .55951 L p .707 .577 .707 r
F P
0 g
s
.68566 .74375 m .68566 .72522 L .71504 .72184 L p .707 .577 .707 r
F P
0 g
s
.29804 .71833 m .29804 .73685 L .31064 .74474 L p .707 .577 .707 r
F P
0 g
s
.71504 .72184 m .71504 .74037 L .68566 .74375 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61013 L p .707 .577 .707 r
F P
0 g
s
.49615 .61013 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.77805 .72296 m .77805 .74149 L .74688 .73959 L p .707 .577 .707 r
F P
0 g
s
.74688 .73959 m .74688 .72106 L .77805 .72296 L p .707 .577 .707 r
F P
0 g
s
.71504 .74037 m .71504 .72184 L .74688 .72106 L p .707 .577 .707 r
F P
0 g
s
.49196 .72178 m .49196 .74031 L .49904 .73195 L p .707 .577 .707 r
F P
0 g
s
.49904 .73195 m .49904 .71342 L .49196 .72178 L p .707 .577 .707 r
F P
0 g
s
.29515 .61146 m .29515 .55587 L .30223 .54751 L p .707 .577 .707 r
F P
0 g
s
.74688 .72106 m .74688 .73959 L .71504 .74037 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.29804 .73685 m .29804 .71833 L .29515 .70978 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .54751 m .30223 .60309 L .29515 .61146 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.29515 .70978 m .29515 .72831 L .29804 .73685 L p .707 .577 .707 r
F P
0 g
s
.49615 .55097 m .49615 .60655 L .48356 .59867 L p .707 .577 .707 r
F P
0 g
s
.48356 .59867 m .48356 .54308 L .49615 .55097 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61013 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.49904 .71342 m .49904 .73195 L .49615 .7234 L p .707 .577 .707 r
F P
0 g
s
.49615 .7234 m .49615 .70488 L .49904 .71342 L p .707 .577 .707 r
F P
0 g
s
.30223 .60309 m .30223 .54751 L .3186 .54014 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56225 L p .707 .577 .707 r
F P
0 g
s
.29515 .72831 m .29515 .70978 L .30223 .70142 L p .707 .577 .707 r
F P
0 g
s
.3186 .54014 m .3186 .59572 L .30223 .60309 L p .707 .577 .707 r
F P
0 g
s
.48356 .54308 m .48356 .59867 L .4625 .59221 L p .707 .577 .707 r
F P
0 g
s
.4625 .59221 m .4625 .53663 L .48356 .54308 L p .707 .577 .707 r
F P
0 g
s
.3186 .56225 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.30223 .70142 m .30223 .71995 L .29515 .72831 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.3186 .59572 m .3186 .54014 L .34265 .53449 L p .707 .577 .707 r
F P
0 g
s
.49615 .70488 m .49615 .7234 L .48356 .71552 L p .707 .577 .707 r
F P
0 g
s
.48356 .71552 m .48356 .69699 L .49615 .70488 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56225 L .34265 .5566 L p .707 .577 .707 r
F P
0 g
s
.4625 .53663 m .4625 .59221 L .43504 .58782 L p .707 .577 .707 r
F P
0 g
s
.43504 .58782 m .43504 .53224 L .4625 .53663 L p .707 .577 .707 r
F P
0 g
s
.34265 .53449 m .34265 .59007 L .3186 .59572 L p .707 .577 .707 r
F P
0 g
s
.30223 .71995 m .30223 .70142 L .3186 .69405 L p .707 .577 .707 r
F P
0 g
s
.34265 .5566 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .5914 L p .707 .577 .707 r
F P
0 g
s
.43504 .5914 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .59007 m .34265 .53449 L .37203 .53111 L p .707 .577 .707 r
F P
0 g
s
.3186 .69405 m .3186 .71258 L .30223 .71995 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .5566 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.43504 .53224 m .43504 .58782 L .40387 .58592 L p .707 .577 .707 r
F P
0 g
s
.40387 .58592 m .40387 .53034 L .43504 .53224 L p .707 .577 .707 r
F P
0 g
s
.48356 .69699 m .48356 .71552 L .4625 .70907 L p .707 .577 .707 r
F P
0 g
s
.4625 .70907 m .4625 .69054 L .48356 .69699 L p .707 .577 .707 r
F P
0 g
s
.37203 .5867 m .37203 .53111 L .40387 .53034 L p .707 .577 .707 r
F P
0 g
s
.37203 .53111 m .37203 .5867 L .34265 .59007 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .5914 L .40387 .5895 L p .707 .577 .707 r
F P
0 g
s
.40387 .5895 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.40387 .53034 m .40387 .58592 L .37203 .5867 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .5895 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.3186 .71258 m .3186 .69405 L .34265 .6884 L p .707 .577 .707 r
F P
0 g
s
.34265 .6884 m .34265 .70693 L .3186 .71258 L p .707 .577 .707 r
F P
0 g
s
.4625 .69054 m .4625 .70907 L .43504 .70467 L p .707 .577 .707 r
F P
0 g
s
.43504 .70467 m .43504 .68615 L .4625 .69054 L p .707 .577 .707 r
F P
0 g
s
.34265 .70693 m .34265 .6884 L .37203 .68502 L p .707 .577 .707 r
F P
0 g
s
.37203 .68502 m .37203 .70355 L .34265 .70693 L p .707 .577 .707 r
F P
0 g
s
.43504 .68615 m .43504 .70467 L .40387 .70277 L p .707 .577 .707 r
F P
0 g
s
.40387 .70277 m .40387 .68425 L .43504 .68615 L p .707 .577 .707 r
F P
0 g
s
.37203 .70355 m .37203 .68502 L .40387 .68425 L p .707 .577 .707 r
F P
0 g
s
.40387 .68425 m .40387 .70277 L .37203 .70355 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^
Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000
FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo2@0015YF00<005YFFUH00UYF20001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEQH000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF00000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF0000
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH01000<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEPh000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJ
EP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YF0000009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000500000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo001COol01000FUH005YF0P00
1EYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo001COol01P00FUH00000FUH000EJEP03
001JEUYF00=JEP<000=JEQ<000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQX000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF
00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
1000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eo
o`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH005YF009JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF0`000eYF0P00;Goo000]Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH80004FUH40002FUH>0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF1@000eYF00<0
05YFFUH00UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHD0006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00D005YF001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD0
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH5000jOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUH0000H000o
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPl000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP05001JEUYFFUH0001E
Ool002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEPH0009JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEPD000AJEP04001JEUYFFUH2001DOol002aoo`03001JEP0000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002aoo`04001JEP00FUH20004FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003FUH2001DOol002aoo`06001JEP00001J
EP001EYF00@005YFFUIJEPD0009JEQ@00005FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH3
00000eYF0000001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJ
EP03001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPP000AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00
FUH00004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH50002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF100000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000
FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002ioo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEP0000<0009JEP03001JEUYF00AJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
100000=JEP00FUH015YF00@005YFFUIJEQX003aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEP<000EJEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF00002P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD003Moo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF00@005YF
000000=JEP03001JEP0000@000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH5
0002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol003]oo`P000AJEPD000EJEP04001JEP000003FUH00`00
FUIJEP02FUH50003Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00L0
05YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol004=ooa8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH01000FUIJEUYF30001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00EGoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH00`00FUIJ
EP02000^Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001J
EUYFFUH0000^Ool005Yoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEP0001Yoo`@000=J
EP04001JEUYFFUH2000]Ool005eoo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP03001JEP0000=JEP<000=JEP03001JEUYF009JEP8001moo`@000=JEP8002eo
o`00HWoo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF100015YF00@005YF001JEP8000IJEP03001JEUYF009JEP03001oogoo
029oo`03001JEUYF008002eoo`00IGoo00D005YFFUH005YF01<00003FUH005YF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP05001JEUYFFUH00003FUH01P00FUH00000FUH000IJ
EP03001JEUYF008002Ioo`@002eoo`00IGoo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000000UYF0P001UYF0`009Woo0P0000AJEP00000002eoo`00IGoo00<005YF0000
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YF00001P009Goo0`000eYF0`00;Goo
001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP02FUH3000ROol4
00000eYF001JEP03FUH00`00FUH0000]Ool006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<001Uoo`D000EJEP03001JEUYF009JEP80
02ioo`00?goo4@005Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uo
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00=Goo100000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0P001Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P002Goo1@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004Ool3
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P0047oo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000K7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP0000Ioo`8000AJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006io
o`00;7oo00<005YF00000eYF1@009goo0`0000=JEP00FUH00UYF00<007ooOol01Woo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00LGoo
000/Ool01000FUH005YF0P00;goo0P000eYF00<007ooOol02Goo100025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00M7oo000/Ool01000FUH00000<goo0P0000=J
EP00Ool03Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`00N7oo000/
Ool4000dOol3000EOolR0002OolJ001SOol002aoo`80009JEP<002moo`<00003FUH007oo035oo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5001NOol002aoo`8000=JEP03001J
EP00008002Uoo`<0009JEP03001JEP0002ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008005]oo`00;7oo0P000eYF00<005YFFUH00UYF
1@0087oo100000=JEP00FUH00UYF00<005YF0000;7oo0`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00FGoo000]Ool01@00FUIJEUYF
00001EYF00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000[Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH2001HOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000:goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF
4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000005Ioo`00<7oo0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000002]oo`8000AJEP03001JEUYF009JEPH0019oo`P000=JEP03001JEUYF00=JEP05001JEUYFFUH0
001EOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<002aoo`03001JEP0000AJEP03001JEP000080021oo`D000AJEP05001JEUYF
FUH0001EOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000<002moo`03001JEP0000=JEP<002Qoo`<00003FUH005YF009JEP8005Aoo`00>Goo10000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP8002ioo`80
00=JEP8005Aoo`00?Goo6@00>7oo00@005YF0000039oo`800003FUH0000005Aoo`00SWoo0P0000=J
EP00Ool0<7oo0P0000AJEP00000005Aoo`00SWoo0P000UYF0`00:goo0`000eYF0`00E7oo002>Ool2
0002FUH00`00FUIJEP05000ROol400000eYF001JEP03FUH00`00FUH0001DOol008moo`04001JEUYF
0005FUH00`00FUH00003000IOol50005FUH00`00FUIJEP02FUH2001EOol008moo`04001JEUYF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<0
05YFFUH00UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75032 m .59613 .71326 L .56496 .71136 L p .707 .577 .707 r
F P
0 g
s
.59613 .71326 m .59613 .75032 L .62796 .74954 L p .707 .577 .707 r
F P
0 g
s
.62796 .74954 m .62796 .71249 L .59613 .71326 L p .707 .577 .707 r
F P
0 g
s
.62796 .71249 m .62796 .74954 L .65735 .74616 L p .707 .577 .707 r
F P
0 g
s
.65735 .74616 m .65734 .70911 L .62796 .71249 L p .707 .577 .707 r
F P
0 g
s
.59613 .78184 m .59613 .72626 L .56496 .72435 L p .707 .577 .707 r
F P
0 g
s
.59613 .72626 m .59613 .78184 L .62796 .78106 L p .707 .577 .707 r
F P
0 g
s
.62796 .78106 m .62796 .72548 L .59613 .72626 L p .707 .577 .707 r
F P
0 g
s
.62796 .72548 m .62796 .78106 L .65735 .77768 L p .707 .577 .707 r
F P
0 g
s
.65735 .77768 m .65734 .7221 L .62796 .72548 L p .707 .577 .707 r
F P
0 g
s
.56496 .74842 m .56496 .71136 L .5375 .70697 L p .707 .577 .707 r
F P
0 g
s
.56496 .71136 m .56496 .74842 L .59613 .75032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77994 m .56496 .72435 L .5375 .71996 L p .707 .577 .707 r
F P
0 g
s
.56496 .72435 m .56496 .77994 L .59613 .78184 L p .707 .577 .707 r
F P
0 g
s
.65734 .70911 m .65735 .74616 L .6814 .74051 L p .707 .577 .707 r
F P
0 g
s
.6814 .74051 m .6814 .70346 L .65734 .70911 L p .707 .577 .707 r
F P
0 g
s
.5375 .70697 m .5375 .74403 L .56496 .74842 L p .707 .577 .707 r
F P
0 g
s
.65734 .7221 m .65735 .77768 L .6814 .77203 L p .707 .577 .707 r
F P
0 g
s
.6814 .77203 m .6814 .71645 L .65734 .7221 L p .707 .577 .707 r
F P
0 g
s
.5375 .74403 m .5375 .70697 L .51644 .70052 L p .707 .577 .707 r
F P
0 g
s
.5375 .71996 m .5375 .77554 L .56496 .77994 L p .707 .577 .707 r
F P
0 g
s
.5375 .77554 m .5375 .71996 L .51644 .71351 L p .707 .577 .707 r
F P
0 g
s
.51644 .70052 m .51644 .73757 L .5375 .74403 L p .707 .577 .707 r
F P
0 g
s
.6814 .70346 m .6814 .74051 L .69777 .73315 L p .707 .577 .707 r
F P
0 g
s
.69777 .73315 m .69777 .69609 L .6814 .70346 L p .707 .577 .707 r
F P
0 g
s
.6814 .71645 m .6814 .77203 L .69777 .76466 L p .707 .577 .707 r
F P
0 g
s
.69777 .76466 m .69777 .70908 L .6814 .71645 L p .707 .577 .707 r
F P
0 g
s
.51644 .71351 m .51644 .76909 L .5375 .77554 L p .707 .577 .707 r
F P
0 g
s
.51644 .73757 m .51644 .70052 L .50385 .69263 L p .707 .577 .707 r
F P
0 g
s
.59613 .90775 m .59613 .88922 L .56496 .88732 L p .707 .577 .707 r
F P
0 g
s
.59613 .88922 m .59613 .90775 L .62796 .90697 L p .707 .577 .707 r
F P
0 g
s
.62796 .90697 m .62796 .88845 L .59613 .88922 L p .707 .577 .707 r
F P
0 g
s
.51644 .76909 m .51644 .71351 L .50385 .70562 L p .707 .577 .707 r
F P
0 g
s
.62796 .88845 m .62796 .90697 L .65735 .90359 L p .707 .577 .707 r
F P
0 g
s
.65735 .90359 m .65735 .88507 L .62796 .88845 L p .707 .577 .707 r
F P
0 g
s
.56496 .88732 m .56496 .90585 L .59613 .90775 L p .707 .577 .707 r
F P
0 g
s
.56496 .90585 m .56496 .88732 L .5375 .88293 L p .707 .577 .707 r
F P
0 g
s
.50385 .69263 m .50385 .72969 L .51644 .73757 L p .707 .577 .707 r
F P
0 g
s
.5375 .88293 m .5375 .90146 L .56496 .90585 L p .707 .577 .707 r
F P
0 g
s
.69777 .69609 m .69777 .73315 L .70485 .72478 L p .707 .577 .707 r
F P
0 g
s
.70485 .72478 m .70485 .68773 L .69777 .69609 L p .707 .577 .707 r
F P
0 g
s
.65735 .88507 m .65735 .90359 L .6814 .89794 L p .707 .577 .707 r
F P
0 g
s
.6814 .89794 m .6814 .87942 L .65735 .88507 L p .707 .577 .707 r
F P
0 g
s
.50385 .70562 m .50385 .76121 L .51644 .76909 L p .707 .577 .707 r
F P
0 g
s
.69777 .70908 m .69777 .76466 L .70485 .7563 L p .707 .577 .707 r
F P
0 g
s
.70485 .7563 m .70485 .70072 L .69777 .70908 L p .707 .577 .707 r
F P
0 g
s
.5375 .90146 m .5375 .88293 L .51644 .87648 L p .707 .577 .707 r
F P
0 g
s
.50385 .72969 m .50385 .69263 L .50095 .68409 L p .707 .577 .707 r
F P
0 g
s
.51644 .87648 m .51644 .895 L .5375 .90146 L p .707 .577 .707 r
F P
0 g
s
.50385 .76121 m .50385 .70562 L .50095 .69708 L p .707 .577 .707 r
F P
0 g
s
.6814 .87942 m .6814 .89794 L .69777 .89058 L p .707 .577 .707 r
F P
0 g
s
.69777 .89058 m .69777 .87205 L .6814 .87942 L p .707 .577 .707 r
F P
0 g
s
.50095 .68409 m .50095 .72115 L .50385 .72969 L p .707 .577 .707 r
F P
0 g
s
.70485 .68773 m .70485 .72478 L .70195 .71624 L p .707 .577 .707 r
F P
0 g
s
.70195 .71624 m .70195 .67918 L .70485 .68773 L p .707 .577 .707 r
F P
0 g
s
.49044 .81115 m .49044 .30927 L .44643 .30658 L p .707 .577 .707 r
F P
0 g
s
.50095 .69708 m .50095 .75266 L .50385 .76121 L p .707 .577 .707 r
F P
0 g
s
.50095 .72115 m .50095 .68409 L .50804 .67573 L p .707 .577 .707 r
F P
0 g
s
.50095 .75266 m .50095 .69708 L .50804 .68872 L p .707 .577 .707 r
F P
0 g
s
.50804 .67573 m .50804 .71278 L .50095 .72115 L p .707 .577 .707 r
F P
0 g
s
.50804 .68872 m .50804 .7443 L .50095 .75266 L p .707 .577 .707 r
F P
0 g
s
.50804 .71278 m .50804 .67573 L .5244 .66836 L p .707 .577 .707 r
F P
0 g
s
.50804 .7443 m .50804 .68872 L .5244 .68135 L p .707 .577 .707 r
F P
0 g
s
.5244 .66836 m .5244 .70541 L .50804 .71278 L p .707 .577 .707 r
F P
0 g
s
.5244 .68135 m .5244 .73693 L .50804 .7443 L p .707 .577 .707 r
F P
0 g
s
.5244 .70541 m .5244 .66836 L .54846 .66271 L p .707 .577 .707 r
F P
0 g
s
.5244 .73693 m .5244 .68135 L .54846 .6757 L p .707 .577 .707 r
F P
0 g
s
.54846 .66271 m .54846 .69976 L .5244 .70541 L p .707 .577 .707 r
F P
0 g
s
.54846 .6757 m .54846 .73128 L .5244 .73693 L p .707 .577 .707 r
F P
0 g
s
.49044 .30927 m .49044 .81115 L .53538 .81006 L p .707 .577 .707 r
F P
0 g
s
.53538 .81006 m .53538 .30817 L .49044 .30927 L p .707 .577 .707 r
F P
0 g
s
.51644 .895 m .51644 .87648 L .50385 .86859 L p .707 .577 .707 r
F P
0 g
s
.70485 .70072 m .70485 .7563 L .70195 .74776 L p .707 .577 .707 r
F P
0 g
s
.70195 .74776 m .70195 .69218 L .70485 .70072 L p .707 .577 .707 r
F P
0 g
s
.54846 .69976 m .54846 .66271 L .57784 .65933 L p .707 .577 .707 r
F P
0 g
s
.54846 .73128 m .54846 .6757 L .57784 .67232 L p .707 .577 .707 r
F P
0 g
s
.57784 .65933 m .57784 .69639 L .54846 .69976 L p .707 .577 .707 r
F P
0 g
s
.57784 .67232 m .57784 .7279 L .54846 .73128 L p .707 .577 .707 r
F P
0 g
s
.53538 .30817 m .53538 .81006 L .57686 .80529 L p .707 .577 .707 r
F P
0 g
s
.57686 .80529 m .57686 .3034 L .53538 .30817 L p .707 .577 .707 r
F P
0 g
s
.50385 .86859 m .50385 .88712 L .51644 .895 L p .707 .577 .707 r
F P
0 g
s
.44643 .80847 m .44643 .30658 L .40766 .30038 L p .707 .577 .707 r
F P
0 g
s
.44643 .30658 m .44643 .80847 L .49044 .81115 L p .707 .577 .707 r
F P
0 g
s
.69777 .87205 m .69777 .89058 L .70485 .88221 L p .707 .577 .707 r
F P
0 g
s
.70485 .88221 m .70485 .86368 L .69777 .87205 L p .707 .577 .707 r
F P
0 g
s
.57784 .69639 m .57784 .65933 L .60968 .65855 L p .707 .577 .707 r
F P
0 g
s
.60968 .65855 m .60968 .69561 L .57784 .69639 L p .707 .577 .707 r
F P
0 g
s
.57784 .7279 m .57784 .67232 L .60968 .67154 L p .707 .577 .707 r
F P
0 g
s
.60968 .67154 m .60968 .72713 L .57784 .7279 L p .707 .577 .707 r
F P
0 g
s
.57686 .3034 m .57686 .80529 L .61082 .79731 L p .707 .577 .707 r
F P
0 g
s
.64085 .66045 m .64085 .69751 L .60968 .69561 L p .707 .577 .707 r
F P
0 g
s
.60968 .69561 m .60968 .65855 L .64085 .66045 L p .707 .577 .707 r
F P
0 g
s
.64085 .67344 m .64085 .72903 L .60968 .72713 L p .707 .577 .707 r
F P
0 g
s
.60968 .72713 m .60968 .67154 L .64085 .67344 L p .707 .577 .707 r
F P
0 g
s
.61082 .79731 m .61082 .29542 L .57686 .3034 L p .707 .577 .707 r
F P
0 g
s
.70195 .67918 m .70195 .71624 L .68936 .70836 L p .707 .577 .707 r
F P
0 g
s
.68936 .70836 m .68936 .6713 L .70195 .67918 L p .707 .577 .707 r
F P
0 g
s
.50385 .88712 m .50385 .86859 L .50095 .86005 L p .707 .577 .707 r
F P
0 g
s
.40766 .80227 m .40766 .30038 L .37794 .29127 L p .707 .577 .707 r
F P
0 g
s
.40766 .30038 m .40766 .80227 L .44643 .80847 L p .707 .577 .707 r
F P
0 g
s
.70195 .69218 m .70195 .74776 L .68936 .73987 L p .707 .577 .707 r
F P
0 g
s
.68936 .73987 m .68936 .68429 L .70195 .69218 L p .707 .577 .707 r
F P
0 g
s
.50095 .86005 m .50095 .87858 L .50385 .88712 L p .707 .577 .707 r
F P
0 g
s
.25312 .7135 m .25312 .67645 L .22195 .67455 L p .707 .577 .707 r
F P
0 g
s
.25312 .67645 m .25312 .7135 L .28495 .71273 L p .707 .577 .707 r
F P
0 g
s
.28495 .71273 m .28495 .67567 L .25312 .67645 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28495 .67567 m .28495 .71273 L .31434 .70935 L p .707 .577 .707 r
F P
0 g
s
.31434 .70935 m .31434 .67229 L .28495 .67567 L p .707 .577 .707 r
F P
0 g
s
.25312 .74502 m .25312 .68944 L .22195 .68754 L p .707 .577 .707 r
F P
0 g
s
.25312 .68944 m .25312 .74502 L .28495 .74424 L p .707 .577 .707 r
F P
0 g
s
.28495 .74424 m .28495 .68866 L .25312 .68944 L p .707 .577 .707 r
F P
0 g
s
.28495 .68866 m .28495 .74424 L .31434 .74087 L p .707 .577 .707 r
F P
0 g
s
.31434 .74087 m .31434 .68528 L .28495 .68866 L p .707 .577 .707 r
F P
0 g
s
.22195 .7116 m .22195 .67455 L .19449 .67016 L p .707 .577 .707 r
F P
0 g
s
.22195 .67455 m .22195 .7116 L .25312 .7135 L p .707 .577 .707 r
F P
0 g
s
.70485 .86368 m .70485 .88221 L .70195 .87367 L p .707 .577 .707 r
F P
0 g
s
.70195 .87367 m .70195 .85514 L .70485 .86368 L p .707 .577 .707 r
F P
0 g
s
.22195 .74312 m .22195 .68754 L .19449 .68315 L p .707 .577 .707 r
F P
0 g
s
.22195 .68754 m .22195 .74312 L .25312 .74502 L p .707 .577 .707 r
F P
0 g
s
.61082 .29542 m .61082 .79731 L .63393 .78691 L p .707 .577 .707 r
F P
0 g
s
.63393 .78691 m .63393 .28502 L .61082 .29542 L p .707 .577 .707 r
F P
0 g
s
.31434 .67229 m .31434 .70935 L .33839 .7037 L p .707 .577 .707 r
F P
0 g
s
.33839 .7037 m .33839 .66664 L .31434 .67229 L p .707 .577 .707 r
F P
0 g
s
.19449 .67016 m .19449 .70721 L .22195 .7116 L p .707 .577 .707 r
F P
0 g
s
.68936 .6713 m .68936 .70836 L .66831 .7019 L p .707 .577 .707 r
F P
0 g
s
.66831 .7019 m .66831 .66485 L .68936 .6713 L p .707 .577 .707 r
F P
0 g
s
.31434 .68528 m .31434 .74087 L .33839 .73522 L p .707 .577 .707 r
F P
0 g
s
.33839 .73522 m .33839 .67963 L .31434 .68528 L p .707 .577 .707 r
F P
0 g
s
.50095 .87858 m .50095 .86005 L .50804 .85169 L p .707 .577 .707 r
F P
0 g
s
.68936 .68429 m .68936 .73987 L .66831 .73342 L p .707 .577 .707 r
F P
0 g
s
.66831 .73342 m .66831 .67784 L .68936 .68429 L p .707 .577 .707 r
F P
0 g
s
.19449 .70721 m .19449 .67016 L .17343 .6637 L p .707 .577 .707 r
F P
0 g
s
.37794 .79316 m .37794 .29127 L .36016 .28014 L p .707 .577 .707 r
F P
0 g
s
.37794 .29127 m .37794 .79316 L .40766 .80227 L p .707 .577 .707 r
F P
0 g
s
.19449 .68315 m .19449 .73873 L .22195 .74312 L p .707 .577 .707 r
F P
0 g
s
.19449 .73873 m .19449 .68315 L .17343 .67669 L p .707 .577 .707 r
F P
0 g
s
.50804 .85169 m .50804 .87021 L .50095 .87858 L p .707 .577 .707 r
F P
0 g
s
.17343 .6637 m .17343 .70076 L .19449 .70721 L p .707 .577 .707 r
F P
0 g
s
.33839 .66664 m .33839 .7037 L .35476 .69633 L p .707 .577 .707 r
F P
0 g
s
.35476 .69633 m .35476 .65928 L .33839 .66664 L p .707 .577 .707 r
F P
0 g
s
.33839 .67963 m .33839 .73522 L .35476 .72785 L p .707 .577 .707 r
F P
0 g
s
.35476 .72785 m .35476 .67227 L .33839 .67963 L p .707 .577 .707 r
F P
0 g
s
.70195 .85514 m .70195 .87367 L .68936 .86579 L p .707 .577 .707 r
F P
0 g
s
.68936 .86579 m .68936 .84726 L .70195 .85514 L p .707 .577 .707 r
F P
0 g
s
.66831 .66485 m .66831 .7019 L .64085 .69751 L p .707 .577 .707 r
F P
0 g
s
.64085 .69751 m .64085 .66045 L .66831 .66485 L p .707 .577 .707 r
F P
0 g
s
.17343 .67669 m .17343 .73228 L .19449 .73873 L p .707 .577 .707 r
F P
0 g
s
.66831 .67784 m .66831 .73342 L .64085 .72903 L p .707 .577 .707 r
F P
0 g
s
.64085 .72903 m .64085 .67344 L .66831 .67784 L p .707 .577 .707 r
F P
0 g
s
.17343 .70076 m .17343 .6637 L .16084 .65582 L p .707 .577 .707 r
F P
0 g
s
.63393 .28502 m .63393 .78691 L .64393 .7751 L p .707 .577 .707 r
F P
0 g
s
.64393 .7751 m .64393 .27321 L .63393 .28502 L p .707 .577 .707 r
F P
0 g
s
.25312 .87093 m .25312 .85241 L .22195 .85051 L p .707 .577 .707 r
F P
0 g
s
.25312 .85241 m .25312 .87093 L .28495 .87016 L p .707 .577 .707 r
F P
0 g
s
.28495 .87016 m .28495 .85163 L .25312 .85241 L p .707 .577 .707 r
F P
0 g
s
.17343 .73228 m .17343 .67669 L .16084 .66881 L p .707 .577 .707 r
F P
0 g
s
.50804 .87021 m .50804 .85169 L .5244 .84432 L p .707 .577 .707 r
F P
0 g
s
.28495 .85163 m .28495 .87016 L .31434 .86678 L p .707 .577 .707 r
F P
0 g
s
.31434 .86678 m .31434 .84825 L .28495 .85163 L p .707 .577 .707 r
F P
0 g
s
.22195 .85051 m .22195 .86903 L .25312 .87093 L p .707 .577 .707 r
F P
0 g
s
.22195 .86903 m .22195 .85051 L .19449 .84611 L p .707 .577 .707 r
F P
0 g
s
.16084 .65582 m .16084 .69287 L .17343 .70076 L p .707 .577 .707 r
F P
0 g
s
.5244 .84432 m .5244 .86284 L .50804 .87021 L p .707 .577 .707 r
F P
0 g
s
.19449 .84611 m .19449 .86464 L .22195 .86903 L p .707 .577 .707 r
F P
0 g
s
.35476 .65928 m .35476 .69633 L .36184 .68797 L p .707 .577 .707 r
F P
0 g
s
.36184 .68797 m .36184 .65091 L .35476 .65928 L p .707 .577 .707 r
F P
0 g
s
.31434 .84825 m .31434 .86678 L .33839 .86113 L p .707 .577 .707 r
F P
0 g
s
.33839 .86113 m .33839 .8426 L .31434 .84825 L p .707 .577 .707 r
F P
0 g
s
.16084 .66881 m .16084 .72439 L .17343 .73228 L p .707 .577 .707 r
F P
0 g
s
.35476 .67227 m .35476 .72785 L .36184 .71948 L p .707 .577 .707 r
F P
0 g
s
.36184 .71948 m .36184 .6639 L .35476 .67227 L p .707 .577 .707 r
F P
0 g
s
.36184 .65091 m .36184 .68797 L .35894 .67942 L p .707 .577 .707 r
F P
0 g
s
.35894 .67942 m .35894 .64237 L .36184 .65091 L p .707 .577 .707 r
F P
0 g
s
.36184 .6639 m .36184 .71948 L .35894 .71094 L p .707 .577 .707 r
F P
0 g
s
.35894 .71094 m .35894 .65536 L .36184 .6639 L p .707 .577 .707 r
F P
0 g
s
.36016 .78203 m .36016 .28014 L .35607 .26808 L p .707 .577 .707 r
F P
0 g
s
.36016 .28014 m .36016 .78203 L .37794 .79316 L p .707 .577 .707 r
F P
0 g
s
.68936 .84726 m .68936 .86579 L .66831 .85933 L p .707 .577 .707 r
F P
0 g
s
.66831 .85933 m .66831 .8408 L .68936 .84726 L p .707 .577 .707 r
F P
0 g
s
.19449 .86464 m .19449 .84611 L .17343 .83966 L p .707 .577 .707 r
F P
0 g
s
.16084 .69287 m .16084 .65582 L .15794 .64728 L p .707 .577 .707 r
F P
0 g
s
.17343 .83966 m .17343 .85819 L .19449 .86464 L p .707 .577 .707 r
F P
0 g
s
.16084 .72439 m .16084 .66881 L .15794 .66027 L p .707 .577 .707 r
F P
0 g
s
.5244 .86284 m .5244 .84432 L .54846 .83867 L p .707 .577 .707 r
F P
0 g
s
.54846 .83867 m .54846 .8572 L .5244 .86284 L p .707 .577 .707 r
F P
0 g
s
.33839 .8426 m .33839 .86113 L .35476 .85376 L p .707 .577 .707 r
F P
0 g
s
.35476 .85376 m .35476 .83523 L .33839 .8426 L p .707 .577 .707 r
F P
0 g
s
.15794 .64728 m .15794 .68433 L .16084 .69287 L p .707 .577 .707 r
F P
0 g
s
.64393 .27321 m .64393 .7751 L .63984 .76304 L p .707 .577 .707 r
F P
0 g
s
.63984 .76304 m .63984 .26115 L .64393 .27321 L p .707 .577 .707 r
F P
0 g
s
.66831 .8408 m .66831 .85933 L .64085 .85494 L p .707 .577 .707 r
F P
0 g
s
.64085 .85494 m .64085 .83641 L .66831 .8408 L p .707 .577 .707 r
F P
0 g
s
.15794 .66027 m .15794 .71585 L .16084 .72439 L p .707 .577 .707 r
F P
0 g
s
.17343 .85819 m .17343 .83966 L .16084 .83178 L p .707 .577 .707 r
F P
0 g
s
.54846 .8572 m .54846 .83867 L .57784 .83529 L p .707 .577 .707 r
F P
0 g
s
.16084 .83178 m .16084 .8503 L .17343 .85819 L p .707 .577 .707 r
F P
0 g
s
.57784 .83529 m .57784 .85382 L .54846 .8572 L p .707 .577 .707 r
F P
0 g
s
.15794 .68433 m .15794 .64728 L .16503 .63891 L p .707 .577 .707 r
F P
0 g
s
.64085 .83641 m .64085 .85494 L .60968 .85304 L p .707 .577 .707 r
F P
0 g
s
.60968 .85304 m .60968 .83451 L .64085 .83641 L p .707 .577 .707 r
F P
0 g
s
.15794 .71585 m .15794 .66027 L .16503 .6519 L p .707 .577 .707 r
F P
0 g
s
.35894 .64237 m .35894 .67942 L .34635 .67154 L p .707 .577 .707 r
F P
0 g
s
.34635 .67154 m .34635 .63449 L .35894 .64237 L p .707 .577 .707 r
F P
0 g
s
.35894 .65536 m .35894 .71094 L .34635 .70306 L p .707 .577 .707 r
F P
0 g
s
.34635 .70306 m .34635 .64748 L .35894 .65536 L p .707 .577 .707 r
F P
0 g
s
.35607 .26808 m .35607 .76997 L .36016 .78203 L p .707 .577 .707 r
F P
0 g
s
.35607 .76997 m .35607 .26808 L .36607 .25627 L p .707 .577 .707 r
F P
0 g
s
.57784 .85382 m .57784 .83529 L .60968 .83451 L p .707 .577 .707 r
F P
0 g
s
.35476 .83523 m .35476 .85376 L .36184 .8454 L p .707 .577 .707 r
F P
0 g
s
.36184 .8454 m .36184 .82687 L .35476 .83523 L p .707 .577 .707 r
F P
0 g
s
.60968 .83451 m .60968 .85304 L .57784 .85382 L p .707 .577 .707 r
F P
0 g
s
.16503 .63891 m .16503 .67597 L .15794 .68433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .8503 m .16084 .83178 L .15794 .82323 L p .707 .577 .707 r
F P
0 g
s
.16503 .6519 m .16503 .70748 L .15794 .71585 L p .707 .577 .707 r
F P
0 g
s
.15794 .82323 m .15794 .84176 L .16084 .8503 L p .707 .577 .707 r
F P
0 g
s
.63984 .26115 m .63984 .76304 L .62206 .75191 L p .707 .577 .707 r
F P
0 g
s
.62206 .75191 m .62206 .25002 L .63984 .26115 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .67597 m .16503 .63891 L .1814 .63154 L p .707 .577 .707 r
F P
0 g
s
.16503 .70748 m .16503 .6519 L .1814 .64453 L p .707 .577 .707 r
F P
0 g
s
.36184 .82687 m .36184 .8454 L .35894 .83685 L p .707 .577 .707 r
F P
0 g
s
.35894 .83685 m .35894 .81833 L .36184 .82687 L p .707 .577 .707 r
F P
0 g
s
.1814 .63154 m .1814 .6686 L .16503 .67597 L p .707 .577 .707 r
F P
0 g
s
.34635 .63449 m .34635 .67154 L .3253 .66509 L p .707 .577 .707 r
F P
0 g
s
.3253 .66509 m .3253 .62803 L .34635 .63449 L p .707 .577 .707 r
F P
0 g
s
.36607 .75816 m .36607 .25627 L .38918 .24587 L p .707 .577 .707 r
F P
0 g
s
.36607 .25627 m .36607 .75816 L .35607 .76997 L p .707 .577 .707 r
F P
0 g
s
.15794 .84176 m .15794 .82323 L .16503 .81487 L p .707 .577 .707 r
F P
0 g
s
.1814 .64453 m .1814 .70012 L .16503 .70748 L p .707 .577 .707 r
F P
0 g
s
.34635 .64748 m .34635 .70306 L .3253 .6966 L p .707 .577 .707 r
F P
0 g
s
.3253 .6966 m .3253 .64102 L .34635 .64748 L p .707 .577 .707 r
F P
0 g
s
.16503 .81487 m .16503 .8334 L .15794 .84176 L p .707 .577 .707 r
F P
0 g
s
.1814 .6686 m .1814 .63154 L .20545 .62589 L p .707 .577 .707 r
F P
0 g
s
.1814 .70012 m .1814 .64453 L .20545 .63888 L p .707 .577 .707 r
F P
0 g
s
.35894 .81833 m .35894 .83685 L .34635 .82897 L p .707 .577 .707 r
F P
0 g
s
.34635 .82897 m .34635 .81044 L .35894 .81833 L p .707 .577 .707 r
F P
0 g
s
.20545 .62589 m .20545 .66295 L .1814 .6686 L p .707 .577 .707 r
F P
0 g
s
.62206 .25002 m .62206 .75191 L .59233 .7428 L p .707 .577 .707 r
F P
0 g
s
.59233 .7428 m .59233 .24091 L .62206 .25002 L p .707 .577 .707 r
F P
0 g
s
.3253 .62803 m .3253 .66509 L .29784 .66069 L p .707 .577 .707 r
F P
0 g
s
.29784 .66069 m .29784 .62364 L .3253 .62803 L p .707 .577 .707 r
F P
0 g
s
.3253 .64102 m .3253 .6966 L .29784 .69221 L p .707 .577 .707 r
F P
0 g
s
.29784 .69221 m .29784 .63663 L .3253 .64102 L p .707 .577 .707 r
F P
0 g
s
.20545 .63888 m .20545 .69447 L .1814 .70012 L p .707 .577 .707 r
F P
0 g
s
.20545 .66295 m .20545 .62589 L .23483 .62252 L p .707 .577 .707 r
F P
0 g
s
.16503 .8334 m .16503 .81487 L .1814 .8075 L p .707 .577 .707 r
F P
0 g
s
.20545 .69447 m .20545 .63888 L .23483 .63551 L p .707 .577 .707 r
F P
0 g
s
.38918 .24587 m .38918 .74776 L .36607 .75816 L p .707 .577 .707 r
F P
0 g
s
.38918 .74776 m .38918 .24587 L .42314 .23789 L p .707 .577 .707 r
F P
0 g
s
.1814 .8075 m .1814 .82603 L .16503 .8334 L p .707 .577 .707 r
F P
0 g
s
.29784 .62364 m .29784 .66069 L .26667 .65879 L p .707 .577 .707 r
F P
0 g
s
.26667 .65879 m .26667 .62174 L .29784 .62364 L p .707 .577 .707 r
F P
0 g
s
.23483 .62252 m .23483 .65957 L .20545 .66295 L p .707 .577 .707 r
F P
0 g
s
.29784 .63663 m .29784 .69221 L .26667 .69031 L p .707 .577 .707 r
F P
0 g
s
.26667 .69031 m .26667 .63473 L .29784 .63663 L p .707 .577 .707 r
F P
0 g
s
.23483 .65957 m .23483 .62252 L .26667 .62174 L p .707 .577 .707 r
F P
0 g
s
.26667 .62174 m .26667 .65879 L .23483 .65957 L p .707 .577 .707 r
F P
0 g
s
.23483 .69109 m .23483 .63551 L .26667 .63473 L p .707 .577 .707 r
F P
0 g
s
.23483 .63551 m .23483 .69109 L .20545 .69447 L p .707 .577 .707 r
F P
0 g
s
.73333 .65828 m .73333 .62123 L .70216 .61933 L p .707 .577 .707 r
F P
0 g
s
.73333 .62123 m .73333 .65828 L .76517 .6575 L p .707 .577 .707 r
F P
0 g
s
.76517 .6575 m .76517 .62045 L .73333 .62123 L p .707 .577 .707 r
F P
0 g
s
.34635 .81044 m .34635 .82897 L .3253 .82252 L p .707 .577 .707 r
F P
0 g
s
.3253 .82252 m .3253 .80399 L .34635 .81044 L p .707 .577 .707 r
F P
0 g
s
.26667 .63473 m .26667 .69031 L .23483 .69109 L p .707 .577 .707 r
F P
0 g
s
.76517 .62045 m .76517 .6575 L .79455 .65413 L p .707 .577 .707 r
F P
0 g
s
.79455 .65413 m .79455 .61707 L .76517 .62045 L p .707 .577 .707 r
F P
0 g
s
.73333 .6898 m .73333 .63422 L .70216 .63232 L p .707 .577 .707 r
F P
0 g
s
.73333 .63422 m .73333 .6898 L .76517 .68902 L p .707 .577 .707 r
F P
0 g
s
.76517 .68902 m .76517 .63344 L .73333 .63422 L p .707 .577 .707 r
F P
0 g
s
.76517 .63344 m .76517 .68902 L .79455 .68564 L p .707 .577 .707 r
F P
0 g
s
.79455 .68564 m .79455 .63006 L .76517 .63344 L p .707 .577 .707 r
F P
0 g
s
.70216 .65638 m .70216 .61933 L .6747 .61493 L p .707 .577 .707 r
F P
0 g
s
.70216 .61933 m .70216 .65638 L .73333 .65828 L p .707 .577 .707 r
F P
0 g
s
.59233 .24091 m .59233 .7428 L .55357 .7366 L p .707 .577 .707 r
F P
0 g
s
.55357 .7366 m .55357 .23471 L .59233 .24091 L p .707 .577 .707 r
F P
0 g
s
.70216 .6879 m .70216 .63232 L .6747 .62792 L p .707 .577 .707 r
F P
0 g
s
.70216 .63232 m .70216 .6879 L .73333 .6898 L p .707 .577 .707 r
F P
0 g
s
.1814 .82603 m .1814 .8075 L .20545 .80185 L p .707 .577 .707 r
F P
0 g
s
.79455 .61707 m .79455 .65413 L .8186 .64848 L p .707 .577 .707 r
F P
0 g
s
.8186 .64848 m .8186 .61142 L .79455 .61707 L p .707 .577 .707 r
F P
0 g
s
.20545 .80185 m .20545 .82038 L .1814 .82603 L p .707 .577 .707 r
F P
0 g
s
.6747 .61493 m .6747 .65199 L .70216 .65638 L p .707 .577 .707 r
F P
0 g
s
.79455 .63006 m .79455 .68564 L .8186 .67999 L p .707 .577 .707 r
F P
0 g
s
.8186 .67999 m .8186 .62441 L .79455 .63006 L p .707 .577 .707 r
F P
0 g
s
.42314 .73978 m .42314 .23789 L .46462 .23312 L p .707 .577 .707 r
F P
0 g
s
.42314 .23789 m .42314 .73978 L .38918 .74776 L p .707 .577 .707 r
F P
0 g
s
.6747 .65199 m .6747 .61493 L .65365 .60848 L p .707 .577 .707 r
F P
0 g
s
.3253 .80399 m .3253 .82252 L .29784 .81812 L p .707 .577 .707 r
F P
0 g
s
.29784 .81812 m .29784 .7996 L .3253 .80399 L p .707 .577 .707 r
F P
0 g
s
.6747 .62792 m .6747 .68351 L .70216 .6879 L p .707 .577 .707 r
F P
0 g
s
.6747 .68351 m .6747 .62792 L .65365 .62147 L p .707 .577 .707 r
F P
0 g
s
.55357 .23471 m .55357 .7366 L .50956 .73392 L p .707 .577 .707 r
F P
0 g
s
.50956 .73392 m .50956 .23203 L .55357 .23471 L p .707 .577 .707 r
F P
0 g
s
.20545 .82038 m .20545 .80185 L .23483 .79847 L p .707 .577 .707 r
F P
0 g
s
.65365 .60848 m .65365 .64553 L .6747 .65199 L p .707 .577 .707 r
F P
0 g
s
.8186 .61142 m .8186 .64848 L .83497 .64111 L p .707 .577 .707 r
F P
0 g
s
.83497 .64111 m .83497 .60405 L .8186 .61142 L p .707 .577 .707 r
F P
0 g
s
.46462 .73501 m .46462 .23312 L .50956 .23203 L p .707 .577 .707 r
F P
0 g
s
.46462 .23312 m .46462 .73501 L .42314 .73978 L p .707 .577 .707 r
F P
0 g
s
.23483 .79847 m .23483 .817 L .20545 .82038 L p .707 .577 .707 r
F P
0 g
s
.8186 .62441 m .8186 .67999 L .83497 .67263 L p .707 .577 .707 r
F P
0 g
s
.83497 .67263 m .83497 .61704 L .8186 .62441 L p .707 .577 .707 r
F P
0 g
s
.50956 .23203 m .50956 .73392 L .46462 .73501 L p .707 .577 .707 r
F P
0 g
s
.29784 .7996 m .29784 .81812 L .26667 .81622 L p .707 .577 .707 r
F P
0 g
s
.26667 .81622 m .26667 .7977 L .29784 .7996 L p .707 .577 .707 r
F P
0 g
s
.65365 .62147 m .65365 .67705 L .6747 .68351 L p .707 .577 .707 r
F P
0 g
s
.23483 .817 m .23483 .79847 L .26667 .7977 L p .707 .577 .707 r
F P
0 g
s
.65365 .64553 m .65365 .60848 L .64105 .6006 L p .707 .577 .707 r
F P
0 g
s
.26667 .7977 m .26667 .81622 L .23483 .817 L p .707 .577 .707 r
F P
0 g
s
.73333 .81571 m .73333 .79718 L .70216 .79528 L p .707 .577 .707 r
F P
0 g
s
.73333 .79718 m .73333 .81571 L .76517 .81493 L p .707 .577 .707 r
F P
0 g
s
.76517 .81493 m .76517 .79641 L .73333 .79718 L p .707 .577 .707 r
F P
0 g
s
.65365 .67705 m .65365 .62147 L .64105 .61359 L p .707 .577 .707 r
F P
0 g
s
.76517 .79641 m .76517 .81493 L .79455 .81156 L p .707 .577 .707 r
F P
0 g
s
.79455 .81156 m .79455 .79303 L .76517 .79641 L p .707 .577 .707 r
F P
0 g
s
.70216 .79528 m .70216 .81381 L .73333 .81571 L p .707 .577 .707 r
F P
0 g
s
.70216 .81381 m .70216 .79528 L .6747 .79089 L p .707 .577 .707 r
F P
0 g
s
.64105 .6006 m .64105 .63765 L .65365 .64553 L p .707 .577 .707 r
F P
0 g
s
.6747 .79089 m .6747 .80942 L .70216 .81381 L p .707 .577 .707 r
F P
0 g
s
.83497 .60405 m .83497 .64111 L .84205 .63274 L p .707 .577 .707 r
F P
0 g
s
.84205 .63274 m .84205 .59569 L .83497 .60405 L p .707 .577 .707 r
F P
0 g
s
.79455 .79303 m .79455 .81156 L .8186 .80591 L p .707 .577 .707 r
F P
0 g
s
.8186 .80591 m .8186 .78738 L .79455 .79303 L p .707 .577 .707 r
F P
0 g
s
.64105 .61359 m .64105 .66917 L .65365 .67705 L p .707 .577 .707 r
F P
0 g
s
.83497 .61704 m .83497 .67263 L .84205 .66426 L p .707 .577 .707 r
F P
0 g
s
.84205 .66426 m .84205 .60868 L .83497 .61704 L p .707 .577 .707 r
F P
0 g
s
.6747 .80942 m .6747 .79089 L .65365 .78444 L p .707 .577 .707 r
F P
0 g
s
.64105 .63765 m .64105 .6006 L .63816 .59205 L p .707 .577 .707 r
F P
0 g
s
.65365 .78444 m .65365 .80297 L .6747 .80942 L p .707 .577 .707 r
F P
0 g
s
.64105 .66917 m .64105 .61359 L .63816 .60504 L p .707 .577 .707 r
F P
0 g
s
.8186 .78738 m .8186 .80591 L .83497 .79854 L p .707 .577 .707 r
F P
0 g
s
.83497 .79854 m .83497 .78001 L .8186 .78738 L p .707 .577 .707 r
F P
0 g
s
.63816 .59205 m .63816 .62911 L .64105 .63765 L p .707 .577 .707 r
F P
0 g
s
.84205 .59569 m .84205 .63274 L .83916 .6242 L p .707 .577 .707 r
F P
0 g
s
.83916 .6242 m .83916 .58715 L .84205 .59569 L p .707 .577 .707 r
F P
0 g
s
.63816 .60504 m .63816 .66063 L .64105 .66917 L p .707 .577 .707 r
F P
0 g
s
.65365 .80297 m .65365 .78444 L .64105 .77655 L p .707 .577 .707 r
F P
0 g
s
.84205 .60868 m .84205 .66426 L .83916 .65572 L p .707 .577 .707 r
F P
0 g
s
.83916 .65572 m .83916 .60014 L .84205 .60868 L p .707 .577 .707 r
F P
0 g
s
.64105 .77655 m .64105 .79508 L .65365 .80297 L p .707 .577 .707 r
F P
0 g
s
.63816 .62911 m .63816 .59205 L .64524 .58369 L p .707 .577 .707 r
F P
0 g
s
.63816 .66063 m .63816 .60504 L .64524 .59668 L p .707 .577 .707 r
F P
0 g
s
.83497 .78001 m .83497 .79854 L .84206 .79017 L p .707 .577 .707 r
F P
0 g
s
.84206 .79017 m .84206 .77165 L .83497 .78001 L p .707 .577 .707 r
F P
0 g
s
.64524 .58369 m .64524 .62074 L .63816 .62911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83916 .58715 m .83916 .6242 L .82657 .61632 L p .707 .577 .707 r
F P
0 g
s
.82657 .61632 m .82657 .57926 L .83916 .58715 L p .707 .577 .707 r
F P
0 g
s
.64105 .79508 m .64105 .77655 L .63816 .76801 L p .707 .577 .707 r
F P
0 g
s
.64524 .59668 m .64524 .65226 L .63816 .66063 L p .707 .577 .707 r
F P
0 g
s
.83916 .60014 m .83916 .65572 L .82657 .64783 L p .707 .577 .707 r
F P
0 g
s
.82657 .64783 m .82657 .59225 L .83916 .60014 L p .707 .577 .707 r
F P
0 g
s
.63816 .76801 m .63816 .78654 L .64105 .79508 L p .707 .577 .707 r
F P
0 g
s
.39032 .62147 m .39032 .58441 L .35915 .58251 L p .707 .577 .707 r
F P
0 g
s
.39032 .58441 m .39032 .62147 L .42216 .62069 L p .707 .577 .707 r
F P
0 g
s
.42216 .62069 m .42216 .58363 L .39032 .58441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .62074 m .64524 .58369 L .66161 .57632 L p .707 .577 .707 r
F P
0 g
s
.42216 .58363 m .42216 .62069 L .45154 .61731 L p .707 .577 .707 r
F P
0 g
s
.45154 .61731 m .45154 .58025 L .42216 .58363 L p .707 .577 .707 r
F P
0 g
s
.39032 .65298 m .39032 .5974 L .35915 .5955 L p .707 .577 .707 r
F P
0 g
s
.39032 .5974 m .39032 .65298 L .42216 .65221 L p .707 .577 .707 r
F P
0 g
s
.42216 .65221 m .42216 .59662 L .39032 .5974 L p .707 .577 .707 r
F P
0 g
s
.64524 .65226 m .64524 .59668 L .66161 .58931 L p .707 .577 .707 r
F P
0 g
s
.42216 .59662 m .42216 .65221 L .45154 .64883 L p .707 .577 .707 r
F P
0 g
s
.45154 .64883 m .45154 .59325 L .42216 .59662 L p .707 .577 .707 r
F P
0 g
s
.35915 .61957 m .35915 .58251 L .33169 .57812 L p .707 .577 .707 r
F P
0 g
s
.35915 .58251 m .35915 .61957 L .39032 .62147 L p .707 .577 .707 r
F P
0 g
s
.84206 .77165 m .84206 .79017 L .83916 .78163 L p .707 .577 .707 r
F P
0 g
s
.83916 .78163 m .83916 .7631 L .84206 .77165 L p .707 .577 .707 r
F P
0 g
s
.35915 .65108 m .35915 .5955 L .33169 .59111 L p .707 .577 .707 r
F P
0 g
s
.35915 .5955 m .35915 .65108 L .39032 .65298 L p .707 .577 .707 r
F P
0 g
s
.66161 .57632 m .66161 .61338 L .64524 .62074 L p .707 .577 .707 r
F P
0 g
s
.45154 .58025 m .45154 .61731 L .47559 .61166 L p .707 .577 .707 r
F P
0 g
s
.47559 .61166 m .47559 .5746 L .45154 .58025 L p .707 .577 .707 r
F P
0 g
s
.33169 .57812 m .33169 .61517 L .35915 .61957 L p .707 .577 .707 r
F P
0 g
s
.82657 .57926 m .82657 .61632 L .80551 .60986 L p .707 .577 .707 r
F P
0 g
s
.80551 .60986 m .80551 .57281 L .82657 .57926 L p .707 .577 .707 r
F P
0 g
s
.45154 .59325 m .45154 .64883 L .47559 .64318 L p .707 .577 .707 r
F P
0 g
s
.47559 .64318 m .47559 .5876 L .45154 .59325 L p .707 .577 .707 r
F P
0 g
s
.63816 .78654 m .63816 .76801 L .64524 .75965 L p .707 .577 .707 r
F P
0 g
s
.66161 .58931 m .66161 .64489 L .64524 .65226 L p .707 .577 .707 r
F P
0 g
s
.82657 .59225 m .82657 .64783 L .80551 .64138 L p .707 .577 .707 r
F P
0 g
s
.80551 .64138 m .80551 .5858 L .82657 .59225 L p .707 .577 .707 r
F P
0 g
s
.33169 .61517 m .33169 .57812 L .31064 .57166 L p .707 .577 .707 r
F P
0 g
s
.33169 .59111 m .33169 .64669 L .35915 .65108 L p .707 .577 .707 r
F P
0 g
s
.33169 .64669 m .33169 .59111 L .31064 .58465 L p .707 .577 .707 r
F P
0 g
s
.64524 .75965 m .64524 .77817 L .63816 .78654 L p .707 .577 .707 r
F P
0 g
s
.66161 .61338 m .66161 .57632 L .68566 .57067 L p .707 .577 .707 r
F P
0 g
s
.66161 .64489 m .66161 .58931 L .68566 .58366 L p .707 .577 .707 r
F P
0 g
s
.31064 .57166 m .31064 .60872 L .33169 .61517 L p .707 .577 .707 r
F P
0 g
s
.47559 .5746 m .47559 .61166 L .49196 .60429 L p .707 .577 .707 r
F P
0 g
s
.49196 .60429 m .49196 .56724 L .47559 .5746 L p .707 .577 .707 r
F P
0 g
s
.47559 .5876 m .47559 .64318 L .49196 .63581 L p .707 .577 .707 r
F P
0 g
s
.49196 .63581 m .49196 .58023 L .47559 .5876 L p .707 .577 .707 r
F P
0 g
s
.83916 .7631 m .83916 .78163 L .82657 .77375 L p .707 .577 .707 r
F P
0 g
s
.82657 .77375 m .82657 .75522 L .83916 .7631 L p .707 .577 .707 r
F P
0 g
s
.68566 .57067 m .68566 .60773 L .66161 .61338 L p .707 .577 .707 r
F P
0 g
s
.80551 .57281 m .80551 .60986 L .77805 .60547 L p .707 .577 .707 r
F P
0 g
s
.77805 .60547 m .77805 .56842 L .80551 .57281 L p .707 .577 .707 r
F P
0 g
s
.31064 .58465 m .31064 .64024 L .33169 .64669 L p .707 .577 .707 r
F P
0 g
s
.80551 .5858 m .80551 .64138 L .77805 .63699 L p .707 .577 .707 r
F P
0 g
s
.77805 .63699 m .77805 .58141 L .80551 .5858 L p .707 .577 .707 r
F P
0 g
s
.31064 .60872 m .31064 .57166 L .29804 .56378 L p .707 .577 .707 r
F P
0 g
s
.68566 .58366 m .68566 .63924 L .66161 .64489 L p .707 .577 .707 r
F P
0 g
s
.39032 .7789 m .39032 .76037 L .35915 .75847 L p .707 .577 .707 r
F P
0 g
s
.39032 .76037 m .39032 .7789 L .42216 .77812 L p .707 .577 .707 r
F P
0 g
s
.42216 .77812 m .42216 .75959 L .39032 .76037 L p .707 .577 .707 r
F P
0 g
s
.68566 .60773 m .68566 .57067 L .71504 .56729 L p .707 .577 .707 r
F P
0 g
s
.31064 .64024 m .31064 .58465 L .29804 .57677 L p .707 .577 .707 r
F P
0 g
s
.64524 .77817 m .64524 .75965 L .66161 .75228 L p .707 .577 .707 r
F P
0 g
s
.42216 .75959 m .42216 .77812 L .45154 .77474 L p .707 .577 .707 r
F P
0 g
s
.45154 .77474 m .45154 .75621 L .42216 .75959 L p .707 .577 .707 r
F P
0 g
s
.68566 .63924 m .68566 .58366 L .71504 .58028 L p .707 .577 .707 r
F P
0 g
s
.35915 .75847 m .35915 .777 L .39032 .7789 L p .707 .577 .707 r
F P
0 g
s
.35915 .777 m .35915 .75847 L .33169 .75408 L p .707 .577 .707 r
F P
0 g
s
.29804 .56378 m .29804 .60083 L .31064 .60872 L p .707 .577 .707 r
F P
0 g
s
.66161 .75228 m .66161 .77081 L .64524 .77817 L p .707 .577 .707 r
F P
0 g
s
.77805 .56842 m .77805 .60547 L .74688 .60357 L p .707 .577 .707 r
F P
0 g
s
.74688 .60357 m .74688 .56651 L .77805 .56842 L p .707 .577 .707 r
F P
0 g
s
.71504 .56729 m .71504 .60435 L .68566 .60773 L p .707 .577 .707 r
F P
0 g
s
.33169 .75408 m .33169 .7726 L .35915 .777 L p .707 .577 .707 r
F P
0 g
s
.77805 .58141 m .77805 .63699 L .74688 .63509 L p .707 .577 .707 r
F P
0 g
s
.74688 .63509 m .74688 .57951 L .77805 .58141 L p .707 .577 .707 r
F P
0 g
s
.71504 .60435 m .71504 .56729 L .74688 .56651 L p .707 .577 .707 r
F P
0 g
s
.49196 .56724 m .49196 .60429 L .49904 .59593 L p .707 .577 .707 r
F P
0 g
s
.49904 .59593 m .49904 .55887 L .49196 .56724 L p .707 .577 .707 r
F P
0 g
s
.45154 .75621 m .45154 .77474 L .47559 .76909 L p .707 .577 .707 r
F P
0 g
s
.47559 .76909 m .47559 .75056 L .45154 .75621 L p .707 .577 .707 r
F P
0 g
s
.74688 .56651 m .74688 .60357 L .71504 .60435 L p .707 .577 .707 r
F P
0 g
s
.29804 .57677 m .29804 .63235 L .31064 .64024 L p .707 .577 .707 r
F P
0 g
s
.71504 .63587 m .71504 .58028 L .74688 .57951 L p .707 .577 .707 r
F P
0 g
s
.71504 .58028 m .71504 .63587 L .68566 .63924 L p .707 .577 .707 r
F P
0 g
s
.49196 .58023 m .49196 .63581 L .49904 .62745 L p .707 .577 .707 r
F P
0 g
s
.49904 .62745 m .49904 .57186 L .49196 .58023 L p .707 .577 .707 r
F P
0 g
s
.82657 .75522 m .82657 .77375 L .80551 .76729 L p .707 .577 .707 r
F P
0 g
s
.80551 .76729 m .80551 .74877 L .82657 .75522 L p .707 .577 .707 r
F P
0 g
s
.74688 .57951 m .74688 .63509 L .71504 .63587 L p .707 .577 .707 r
F P
0 g
s
.33169 .7726 m .33169 .75408 L .31064 .74762 L p .707 .577 .707 r
F P
0 g
s
.29804 .60083 m .29804 .56378 L .29515 .55524 L p .707 .577 .707 r
F P
0 g
s
.31064 .74762 m .31064 .76615 L .33169 .7726 L p .707 .577 .707 r
F P
0 g
s
.29804 .63235 m .29804 .57677 L .29515 .56823 L p .707 .577 .707 r
F P
0 g
s
.66161 .77081 m .66161 .75228 L .68566 .74663 L p .707 .577 .707 r
F P
0 g
s
.68566 .74663 m .68566 .76516 L .66161 .77081 L p .707 .577 .707 r
F P
0 g
s
.47559 .75056 m .47559 .76909 L .49196 .76172 L p .707 .577 .707 r
F P
0 g
s
.49196 .76172 m .49196 .7432 L .47559 .75056 L p .707 .577 .707 r
F P
0 g
s
.29515 .55524 m .29515 .59229 L .29804 .60083 L p .707 .577 .707 r
F P
0 g
s
.80551 .74877 m .80551 .76729 L .77805 .7629 L p .707 .577 .707 r
F P
0 g
s
.77805 .7629 m .77805 .74437 L .80551 .74877 L p .707 .577 .707 r
F P
0 g
s
.49904 .55887 m .49904 .59593 L .49615 .58739 L p .707 .577 .707 r
F P
0 g
s
.49615 .58739 m .49615 .55033 L .49904 .55887 L p .707 .577 .707 r
F P
0 g
s
.29515 .56823 m .29515 .62381 L .29804 .63235 L p .707 .577 .707 r
F P
0 g
s
.31064 .76615 m .31064 .74762 L .29804 .73974 L p .707 .577 .707 r
F P
0 g
s
.49904 .57186 m .49904 .62745 L .49615 .6189 L p .707 .577 .707 r
F P
0 g
s
.49615 .6189 m .49615 .56332 L .49904 .57186 L p .707 .577 .707 r
F P
0 g
s
.68566 .76516 m .68566 .74663 L .71504 .74325 L p .707 .577 .707 r
F P
0 g
s
.29804 .73974 m .29804 .75827 L .31064 .76615 L p .707 .577 .707 r
F P
0 g
s
.71504 .74325 m .71504 .76178 L .68566 .76516 L p .707 .577 .707 r
F P
0 g
s
.29515 .59229 m .29515 .55524 L .30223 .54687 L p .707 .577 .707 r
F P
0 g
s
.77805 .74437 m .77805 .7629 L .74688 .761 L p .707 .577 .707 r
F P
0 g
s
.74688 .761 m .74688 .74247 L .77805 .74437 L p .707 .577 .707 r
F P
0 g
s
.29515 .62381 m .29515 .56823 L .30223 .55986 L p .707 .577 .707 r
F P
0 g
s
.71504 .76178 m .71504 .74325 L .74688 .74247 L p .707 .577 .707 r
F P
0 g
s
.49196 .7432 m .49196 .76172 L .49904 .75336 L p .707 .577 .707 r
F P
0 g
s
.49904 .75336 m .49904 .73483 L .49196 .7432 L p .707 .577 .707 r
F P
0 g
s
.74688 .74247 m .74688 .761 L .71504 .76178 L p .707 .577 .707 r
F P
0 g
s
.30223 .54687 m .30223 .58393 L .29515 .59229 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49615 .55033 m .49615 .58739 L .48356 .5795 L p .707 .577 .707 r
F P
0 g
s
.48356 .5795 m .48356 .54245 L .49615 .55033 L p .707 .577 .707 r
F P
0 g
s
.29804 .75827 m .29804 .73974 L .29515 .7312 L p .707 .577 .707 r
F P
0 g
s
.30223 .55986 m .30223 .61545 L .29515 .62381 L p .707 .577 .707 r
F P
0 g
s
.49615 .56332 m .49615 .6189 L .48356 .61102 L p .707 .577 .707 r
F P
0 g
s
.48356 .61102 m .48356 .55544 L .49615 .56332 L p .707 .577 .707 r
F P
0 g
s
.29515 .7312 m .29515 .74972 L .29804 .75827 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .58393 m .30223 .54687 L .3186 .53951 L p .707 .577 .707 r
F P
0 g
s
.30223 .61545 m .30223 .55986 L .3186 .5525 L p .707 .577 .707 r
F P
0 g
s
.49904 .73483 m .49904 .75336 L .49615 .74482 L p .707 .577 .707 r
F P
0 g
s
.49615 .74482 m .49615 .72629 L .49904 .73483 L p .707 .577 .707 r
F P
0 g
s
.3186 .53951 m .3186 .57656 L .30223 .58393 L p .707 .577 .707 r
F P
0 g
s
.48356 .54245 m .48356 .5795 L .4625 .57305 L p .707 .577 .707 r
F P
0 g
s
.4625 .57305 m .4625 .53599 L .48356 .54245 L p .707 .577 .707 r
F P
0 g
s
.29515 .74972 m .29515 .7312 L .30223 .72283 L p .707 .577 .707 r
F P
0 g
s
.3186 .5525 m .3186 .60808 L .30223 .61545 L p .707 .577 .707 r
F P
0 g
s
.48356 .55544 m .48356 .61102 L .4625 .60457 L p .707 .577 .707 r
F P
0 g
s
.4625 .60457 m .4625 .54898 L .48356 .55544 L p .707 .577 .707 r
F P
0 g
s
.30223 .72283 m .30223 .74136 L .29515 .74972 L p .707 .577 .707 r
F P
0 g
s
.3186 .57656 m .3186 .53951 L .34265 .53386 L p .707 .577 .707 r
F P
0 g
s
.3186 .60808 m .3186 .5525 L .34265 .54685 L p .707 .577 .707 r
F P
0 g
s
.49615 .72629 m .49615 .74482 L .48356 .73693 L p .707 .577 .707 r
F P
0 g
s
.48356 .73693 m .48356 .71841 L .49615 .72629 L p .707 .577 .707 r
F P
0 g
s
.34265 .53386 m .34265 .57091 L .3186 .57656 L p .707 .577 .707 r
F P
0 g
s
.4625 .53599 m .4625 .57305 L .43504 .56865 L p .707 .577 .707 r
F P
0 g
s
.43504 .56865 m .43504 .5316 L .4625 .53599 L p .707 .577 .707 r
F P
0 g
s
.4625 .54898 m .4625 .60457 L .43504 .60017 L p .707 .577 .707 r
F P
0 g
s
.43504 .60017 m .43504 .54459 L .4625 .54898 L p .707 .577 .707 r
F P
0 g
s
.34265 .54685 m .34265 .60243 L .3186 .60808 L p .707 .577 .707 r
F P
0 g
s
.34265 .57091 m .34265 .53386 L .37203 .53048 L p .707 .577 .707 r
F P
0 g
s
.30223 .74136 m .30223 .72283 L .3186 .71546 L p .707 .577 .707 r
F P
0 g
s
.34265 .60243 m .34265 .54685 L .37203 .54347 L p .707 .577 .707 r
F P
0 g
s
.3186 .71546 m .3186 .73399 L .30223 .74136 L p .707 .577 .707 r
F P
0 g
s
.43504 .5316 m .43504 .56865 L .40387 .56675 L p .707 .577 .707 r
F P
0 g
s
.40387 .56675 m .40387 .5297 L .43504 .5316 L p .707 .577 .707 r
F P
0 g
s
.37203 .53048 m .37203 .56753 L .34265 .57091 L p .707 .577 .707 r
F P
0 g
s
.43504 .54459 m .43504 .60017 L .40387 .59827 L p .707 .577 .707 r
F P
0 g
s
.40387 .59827 m .40387 .54269 L .43504 .54459 L p .707 .577 .707 r
F P
0 g
s
.37203 .56753 m .37203 .53048 L .40387 .5297 L p .707 .577 .707 r
F P
0 g
s
.40387 .5297 m .40387 .56675 L .37203 .56753 L p .707 .577 .707 r
F P
0 g
s
.37203 .59905 m .37203 .54347 L .40387 .54269 L p .707 .577 .707 r
F P
0 g
s
.37203 .54347 m .37203 .59905 L .34265 .60243 L p .707 .577 .707 r
F P
0 g
s
.48356 .71841 m .48356 .73693 L .4625 .73048 L p .707 .577 .707 r
F P
0 g
s
.4625 .73048 m .4625 .71195 L .48356 .71841 L p .707 .577 .707 r
F P
0 g
s
.40387 .54269 m .40387 .59827 L .37203 .59905 L p .707 .577 .707 r
F P
0 g
s
.3186 .73399 m .3186 .71546 L .34265 .70981 L p .707 .577 .707 r
F P
0 g
s
.34265 .70981 m .34265 .72834 L .3186 .73399 L p .707 .577 .707 r
F P
0 g
s
.4625 .71195 m .4625 .73048 L .43504 .72609 L p .707 .577 .707 r
F P
0 g
s
.43504 .72609 m .43504 .70756 L .4625 .71195 L p .707 .577 .707 r
F P
0 g
s
.34265 .72834 m .34265 .70981 L .37203 .70644 L p .707 .577 .707 r
F P
0 g
s
.37203 .70644 m .37203 .72496 L .34265 .72834 L p .707 .577 .707 r
F P
0 g
s
.43504 .70756 m .43504 .72609 L .40387 .72419 L p .707 .577 .707 r
F P
0 g
s
.40387 .72419 m .40387 .70566 L .43504 .70756 L p .707 .577 .707 r
F P
0 g
s
.37203 .72496 m .37203 .70644 L .40387 .70566 L p .707 .577 .707 r
F P
0 g
s
.40387 .70566 m .40387 .72419 L .37203 .72496 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001fOol90005FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJ
EP<006ioo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00IWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eooa80
0003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF
20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF
009JEP03001JEUYF01@000IJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001DOol20004FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH000000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001C
Ool00`00FUH00004FUH01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH00002000dOol005=oo`03001JEP00009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool3
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000bOol005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00
FUIJEP03FUH60003FUH50004FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH3000`Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF008002io
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP03001oogoo
02aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20003FUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP000000;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00
;Goo001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH00008FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0004FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH00eYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH000030002FUH40007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004Moo`T000=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h0
00AJEP03001JEUYF009JEPD000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0031oo`800003FUH005YF00EJ
EP03001JEUYF009JEP03001JEUYF00h000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00UYF1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF009JEP8002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000EJEP00001JEP0000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP8002eoo`00
;7oo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEQ/000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
000002eoo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH50003FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP04
001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool0
02aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH3
00000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF2@0015YF00<005YF
FUH00UYF2@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH00eYF00<005YFFUH00`000goo2@00B7oo000/Ool00`00FUH00004FUH00`00
FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001D
Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01000FUH0
05YF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUH005YF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002aoo`06001JEP00001JEP0015YF0P001eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF1P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0027oo0`00BGoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P001goo1@00B7oo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF
FUH20007Ool50018Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005
FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008FUH80004FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P001goo1@00B7oo000_Ool3
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF00@005YFFUIJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`00BGoo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF00000eYF1@000UYF0`000Woo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEPX000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH2001DOol0
03=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP@000IJEP06001JEP00FUH005YF0`000eYF1000
17oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP/000=JEP03001JEUYF00MJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP<00003FUH0
05YF009JEP8005Aoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001JEPP0
00Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH9000;FUH200000eYF001JEP09FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH30003
FUH2001DOol003]ooa`000ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH3
000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000H000lOol005=oo`80009JEP<000]oo`04001JEUYF
0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH300000eYF001JEP09FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH70004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol20003FUH00`00FUH0
00020008Ool01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YF00002UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00000UYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo001COol20003FUH00`00FUIJEP02FUH50003Ool01@00FUIJEP00FUH00P001eYF00<0
05YFFUH025YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005Aoo`05001J
EUYFFUH00005FUH01000FUIJEUYF200000=JEP00FUH01UYF3`001EYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00004FUH000000002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH3000`Ool005Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF60001EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001GOol30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP02FUH6000HOol400000eYF001J
EP04FUH01@00FUIJEUYF0000;Woo001JOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUH0000300000eYF0000000N
Ool30004FUH01000FUIJEUYF0P00;Goo0018Ool3000BOol50004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH30002FUH3000SOol300000eYF001JEP02
FUH2000]Ool004Moo`D001Ioo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00800003
FUH00000008002Uoo`8000=JEP8002eoo`00Agoo1@006Woo00@005YFFUIJEQ<00003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<002moo`800003FUH0000002eoo`00Agoo1@006Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0000=JEP00Ool0<7oo0P0000AJEP00000002eoo`00B7oo0`0077oo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF10000UYF0`00:goo0`000eYF0`00;Goo001YOol30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000
FUIJEUYF0P000Woo0P000UYF00<005YFFUH01@008Woo100000=JEP00FUH00eYF00<005YF0000;Goo
001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH000001Goo00@005YFFUH000EJEP03001JEP0000<001Uoo`D000EJEP03
001JEUYF009JEP8002ioo`00Agoo2@007Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001goo00@005YFFUH000EJEP03001JEUYF
00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00?goo200015YF00<005YFFUH0
0UYF20005goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01@0037oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPH001Aoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00IJEPD001=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008001Qoo``000IJEP03001J
EUYF00YJEP03001JEUYF00H001Yoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80029ooaH000mo
o`<0015oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`00A7oo1@005Goo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020012Ool5001_Ool002eoo`8000AJ
EP04001JEUYFFUH8000IOol60004FUH01@00FUIJEUYF0000@Woo1@00Kgoo000/Ool00`00FUH00003
FUH5000WOol300000eYF001JEP02FUH00`00Oomoo`11Ool3001`Ool002aoo`04001JEP00FUH2000_
Ool20003FUH00`00Oomoo`2dOol002aoo`04001JEP00000cOol200000eYF001oo`2eOol002aoo`@0
03Aoo`<003UooaP006Eoo`00;7oo0P000UYF0`00;goo0`0000=JEP00Ool0<Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`00HGoo000/Ool20003FUH00`00FUH00002000YOol3
0002FUH00`00FUH0000`Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4001MOol002aoo`8000=JEP03001JEUYF009JEPD0021oo`@00003FUH005YF009JEP03
001JEP0002eoo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000COol50005
FUH01000FUIJEUYF0P00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00F7oo000^Ool01000FUIJEP001EYF00<0
05YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH0
0000EWoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;7oo00<005YF000015YF00<0
05YF00000P0087oo1@0015YF00D005YFFUIJEP0005Eoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`00:7oo0`0000=J
EP00FUH00UYF0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH5000cOol01000FUH005YF0P00;Woo0P000eYF0P00E7oo000mOolI000hOol01000FUH00000<Woo
0P0000=JEP000000E7oo002>Ool200000eYF001oo`0aOol5001DOol008ioo`80009JEP8002ioo`80
009JEP<005Aoo`00SWoo0P000UYF00<005YF00000P009goo100015YF00<005YF0000E7oo002?Ool0
1000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF
00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD005Yoo`00Ugoo1@0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002LOol90004FUH00`00FUIJ
EP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .75032 m .59613 .71326 L .56496 .71136 L p .707 .577 .707 r
F P
0 g
s
.59613 .71326 m .59613 .75032 L .62796 .74954 L p .707 .577 .707 r
F P
0 g
s
.62796 .74954 m .62796 .71249 L .59613 .71326 L p .707 .577 .707 r
F P
0 g
s
.62796 .71249 m .62796 .74954 L .65735 .74616 L p .707 .577 .707 r
F P
0 g
s
.65735 .74616 m .65734 .70911 L .62796 .71249 L p .707 .577 .707 r
F P
0 g
s
.59613 .78184 m .59613 .72626 L .56496 .72435 L p .707 .577 .707 r
F P
0 g
s
.59613 .72626 m .59613 .78184 L .62796 .78106 L p .707 .577 .707 r
F P
0 g
s
.62796 .78106 m .62796 .72548 L .59613 .72626 L p .707 .577 .707 r
F P
0 g
s
.62796 .72548 m .62796 .78106 L .65735 .77768 L p .707 .577 .707 r
F P
0 g
s
.65735 .77768 m .65734 .7221 L .62796 .72548 L p .707 .577 .707 r
F P
0 g
s
.56496 .74842 m .56496 .71136 L .5375 .70697 L p .707 .577 .707 r
F P
0 g
s
.56496 .71136 m .56496 .74842 L .59613 .75032 L p .707 .577 .707 r
F P
0 g
s
.56496 .77994 m .56496 .72435 L .5375 .71996 L p .707 .577 .707 r
F P
0 g
s
.56496 .72435 m .56496 .77994 L .59613 .78184 L p .707 .577 .707 r
F P
0 g
s
.65734 .70911 m .65735 .74616 L .6814 .74051 L p .707 .577 .707 r
F P
0 g
s
.6814 .74051 m .6814 .70346 L .65734 .70911 L p .707 .577 .707 r
F P
0 g
s
.5375 .70697 m .5375 .74403 L .56496 .74842 L p .707 .577 .707 r
F P
0 g
s
.65734 .7221 m .65735 .77768 L .6814 .77203 L p .707 .577 .707 r
F P
0 g
s
.6814 .77203 m .6814 .71645 L .65734 .7221 L p .707 .577 .707 r
F P
0 g
s
.5375 .74403 m .5375 .70697 L .51644 .70052 L p .707 .577 .707 r
F P
0 g
s
.5375 .71996 m .5375 .77554 L .56496 .77994 L p .707 .577 .707 r
F P
0 g
s
.5375 .77554 m .5375 .71996 L .51644 .71351 L p .707 .577 .707 r
F P
0 g
s
.51644 .70052 m .51644 .73757 L .5375 .74403 L p .707 .577 .707 r
F P
0 g
s
.6814 .70346 m .6814 .74051 L .69777 .73315 L p .707 .577 .707 r
F P
0 g
s
.69777 .73315 m .69777 .69609 L .6814 .70346 L p .707 .577 .707 r
F P
0 g
s
.6814 .71645 m .6814 .77203 L .69777 .76466 L p .707 .577 .707 r
F P
0 g
s
.69777 .76466 m .69777 .70908 L .6814 .71645 L p .707 .577 .707 r
F P
0 g
s
.51644 .71351 m .51644 .76909 L .5375 .77554 L p .707 .577 .707 r
F P
0 g
s
.51644 .73757 m .51644 .70052 L .50385 .69263 L p .707 .577 .707 r
F P
0 g
s
.59613 .90775 m .59613 .88922 L .56496 .88732 L p .707 .577 .707 r
F P
0 g
s
.59613 .88922 m .59613 .90775 L .62796 .90697 L p .707 .577 .707 r
F P
0 g
s
.62796 .90697 m .62796 .88845 L .59613 .88922 L p .707 .577 .707 r
F P
0 g
s
.51644 .76909 m .51644 .71351 L .50385 .70562 L p .707 .577 .707 r
F P
0 g
s
.62796 .88845 m .62796 .90697 L .65735 .90359 L p .707 .577 .707 r
F P
0 g
s
.65735 .90359 m .65735 .88507 L .62796 .88845 L p .707 .577 .707 r
F P
0 g
s
.56496 .88732 m .56496 .90585 L .59613 .90775 L p .707 .577 .707 r
F P
0 g
s
.56496 .90585 m .56496 .88732 L .5375 .88293 L p .707 .577 .707 r
F P
0 g
s
.50385 .69263 m .50385 .72969 L .51644 .73757 L p .707 .577 .707 r
F P
0 g
s
.5375 .88293 m .5375 .90146 L .56496 .90585 L p .707 .577 .707 r
F P
0 g
s
.69777 .69609 m .69777 .73315 L .70485 .72478 L p .707 .577 .707 r
F P
0 g
s
.70485 .72478 m .70485 .68773 L .69777 .69609 L p .707 .577 .707 r
F P
0 g
s
.65735 .88507 m .65735 .90359 L .6814 .89794 L p .707 .577 .707 r
F P
0 g
s
.6814 .89794 m .6814 .87942 L .65735 .88507 L p .707 .577 .707 r
F P
0 g
s
.50385 .70562 m .50385 .76121 L .51644 .76909 L p .707 .577 .707 r
F P
0 g
s
.69777 .70908 m .69777 .76466 L .70485 .7563 L p .707 .577 .707 r
F P
0 g
s
.70485 .7563 m .70485 .70072 L .69777 .70908 L p .707 .577 .707 r
F P
0 g
s
.5375 .90146 m .5375 .88293 L .51644 .87648 L p .707 .577 .707 r
F P
0 g
s
.50385 .72969 m .50385 .69263 L .50095 .68409 L p .707 .577 .707 r
F P
0 g
s
.51644 .87648 m .51644 .895 L .5375 .90146 L p .707 .577 .707 r
F P
0 g
s
.50385 .76121 m .50385 .70562 L .50095 .69708 L p .707 .577 .707 r
F P
0 g
s
.6814 .87942 m .6814 .89794 L .69777 .89058 L p .707 .577 .707 r
F P
0 g
s
.69777 .89058 m .69777 .87205 L .6814 .87942 L p .707 .577 .707 r
F P
0 g
s
.50095 .68409 m .50095 .72115 L .50385 .72969 L p .707 .577 .707 r
F P
0 g
s
.70485 .68773 m .70485 .72478 L .70195 .71624 L p .707 .577 .707 r
F P
0 g
s
.70195 .71624 m .70195 .67918 L .70485 .68773 L p .707 .577 .707 r
F P
0 g
s
.49044 .81115 m .49044 .30927 L .44643 .30658 L p .707 .577 .707 r
F P
0 g
s
.50095 .69708 m .50095 .75266 L .50385 .76121 L p .707 .577 .707 r
F P
0 g
s
.50095 .72115 m .50095 .68409 L .50804 .67573 L p .707 .577 .707 r
F P
0 g
s
.50095 .75266 m .50095 .69708 L .50804 .68872 L p .707 .577 .707 r
F P
0 g
s
.50804 .67573 m .50804 .71278 L .50095 .72115 L p .707 .577 .707 r
F P
0 g
s
.50804 .68872 m .50804 .7443 L .50095 .75266 L p .707 .577 .707 r
F P
0 g
s
.50804 .71278 m .50804 .67573 L .5244 .66836 L p .707 .577 .707 r
F P
0 g
s
.50804 .7443 m .50804 .68872 L .5244 .68135 L p .707 .577 .707 r
F P
0 g
s
.5244 .66836 m .5244 .70541 L .50804 .71278 L p .707 .577 .707 r
F P
0 g
s
.5244 .68135 m .5244 .73693 L .50804 .7443 L p .707 .577 .707 r
F P
0 g
s
.5244 .70541 m .5244 .66836 L .54846 .66271 L p .707 .577 .707 r
F P
0 g
s
.5244 .73693 m .5244 .68135 L .54846 .6757 L p .707 .577 .707 r
F P
0 g
s
.54846 .66271 m .54846 .69976 L .5244 .70541 L p .707 .577 .707 r
F P
0 g
s
.54846 .6757 m .54846 .73128 L .5244 .73693 L p .707 .577 .707 r
F P
0 g
s
.49044 .30927 m .49044 .81115 L .53538 .81006 L p .707 .577 .707 r
F P
0 g
s
.53538 .81006 m .53538 .30817 L .49044 .30927 L p .707 .577 .707 r
F P
0 g
s
.51644 .895 m .51644 .87648 L .50385 .86859 L p .707 .577 .707 r
F P
0 g
s
.70485 .70072 m .70485 .7563 L .70195 .74776 L p .707 .577 .707 r
F P
0 g
s
.70195 .74776 m .70195 .69218 L .70485 .70072 L p .707 .577 .707 r
F P
0 g
s
.54846 .69976 m .54846 .66271 L .57784 .65933 L p .707 .577 .707 r
F P
0 g
s
.54846 .73128 m .54846 .6757 L .57784 .67232 L p .707 .577 .707 r
F P
0 g
s
.57784 .65933 m .57784 .69639 L .54846 .69976 L p .707 .577 .707 r
F P
0 g
s
.57784 .67232 m .57784 .7279 L .54846 .73128 L p .707 .577 .707 r
F P
0 g
s
.53538 .30817 m .53538 .81006 L .57686 .80529 L p .707 .577 .707 r
F P
0 g
s
.57686 .80529 m .57686 .3034 L .53538 .30817 L p .707 .577 .707 r
F P
0 g
s
.50385 .86859 m .50385 .88712 L .51644 .895 L p .707 .577 .707 r
F P
0 g
s
.44643 .80847 m .44643 .30658 L .40766 .30038 L p .707 .577 .707 r
F P
0 g
s
.44643 .30658 m .44643 .80847 L .49044 .81115 L p .707 .577 .707 r
F P
0 g
s
.69777 .87205 m .69777 .89058 L .70485 .88221 L p .707 .577 .707 r
F P
0 g
s
.70485 .88221 m .70485 .86368 L .69777 .87205 L p .707 .577 .707 r
F P
0 g
s
.57784 .69639 m .57784 .65933 L .60968 .65855 L p .707 .577 .707 r
F P
0 g
s
.60968 .65855 m .60968 .69561 L .57784 .69639 L p .707 .577 .707 r
F P
0 g
s
.57784 .7279 m .57784 .67232 L .60968 .67154 L p .707 .577 .707 r
F P
0 g
s
.60968 .67154 m .60968 .72713 L .57784 .7279 L p .707 .577 .707 r
F P
0 g
s
.57686 .3034 m .57686 .80529 L .61082 .79731 L p .707 .577 .707 r
F P
0 g
s
.64085 .66045 m .64085 .69751 L .60968 .69561 L p .707 .577 .707 r
F P
0 g
s
.60968 .69561 m .60968 .65855 L .64085 .66045 L p .707 .577 .707 r
F P
0 g
s
.64085 .67344 m .64085 .72903 L .60968 .72713 L p .707 .577 .707 r
F P
0 g
s
.60968 .72713 m .60968 .67154 L .64085 .67344 L p .707 .577 .707 r
F P
0 g
s
.61082 .79731 m .61082 .29542 L .57686 .3034 L p .707 .577 .707 r
F P
0 g
s
.70195 .67918 m .70195 .71624 L .68936 .70836 L p .707 .577 .707 r
F P
0 g
s
.68936 .70836 m .68936 .6713 L .70195 .67918 L p .707 .577 .707 r
F P
0 g
s
.50385 .88712 m .50385 .86859 L .50095 .86005 L p .707 .577 .707 r
F P
0 g
s
.40766 .80227 m .40766 .30038 L .37794 .29127 L p .707 .577 .707 r
F P
0 g
s
.40766 .30038 m .40766 .80227 L .44643 .80847 L p .707 .577 .707 r
F P
0 g
s
.70195 .69218 m .70195 .74776 L .68936 .73987 L p .707 .577 .707 r
F P
0 g
s
.68936 .73987 m .68936 .68429 L .70195 .69218 L p .707 .577 .707 r
F P
0 g
s
.50095 .86005 m .50095 .87858 L .50385 .88712 L p .707 .577 .707 r
F P
0 g
s
.25312 .7135 m .25312 .67645 L .22195 .67455 L p .707 .577 .707 r
F P
0 g
s
.25312 .67645 m .25312 .7135 L .28495 .71273 L p .707 .577 .707 r
F P
0 g
s
.28495 .71273 m .28495 .67567 L .25312 .67645 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28495 .67567 m .28495 .71273 L .31434 .70935 L p .707 .577 .707 r
F P
0 g
s
.31434 .70935 m .31434 .67229 L .28495 .67567 L p .707 .577 .707 r
F P
0 g
s
.25312 .74502 m .25312 .68944 L .22195 .68754 L p .707 .577 .707 r
F P
0 g
s
.25312 .68944 m .25312 .74502 L .28495 .74424 L p .707 .577 .707 r
F P
0 g
s
.28495 .74424 m .28495 .68866 L .25312 .68944 L p .707 .577 .707 r
F P
0 g
s
.28495 .68866 m .28495 .74424 L .31434 .74087 L p .707 .577 .707 r
F P
0 g
s
.31434 .74087 m .31434 .68528 L .28495 .68866 L p .707 .577 .707 r
F P
0 g
s
.22195 .7116 m .22195 .67455 L .19449 .67016 L p .707 .577 .707 r
F P
0 g
s
.22195 .67455 m .22195 .7116 L .25312 .7135 L p .707 .577 .707 r
F P
0 g
s
.70485 .86368 m .70485 .88221 L .70195 .87367 L p .707 .577 .707 r
F P
0 g
s
.70195 .87367 m .70195 .85514 L .70485 .86368 L p .707 .577 .707 r
F P
0 g
s
.22195 .74312 m .22195 .68754 L .19449 .68315 L p .707 .577 .707 r
F P
0 g
s
.22195 .68754 m .22195 .74312 L .25312 .74502 L p .707 .577 .707 r
F P
0 g
s
.61082 .29542 m .61082 .79731 L .63393 .78691 L p .707 .577 .707 r
F P
0 g
s
.63393 .78691 m .63393 .28502 L .61082 .29542 L p .707 .577 .707 r
F P
0 g
s
.31434 .67229 m .31434 .70935 L .33839 .7037 L p .707 .577 .707 r
F P
0 g
s
.33839 .7037 m .33839 .66664 L .31434 .67229 L p .707 .577 .707 r
F P
0 g
s
.19449 .67016 m .19449 .70721 L .22195 .7116 L p .707 .577 .707 r
F P
0 g
s
.68936 .6713 m .68936 .70836 L .66831 .7019 L p .707 .577 .707 r
F P
0 g
s
.66831 .7019 m .66831 .66485 L .68936 .6713 L p .707 .577 .707 r
F P
0 g
s
.31434 .68528 m .31434 .74087 L .33839 .73522 L p .707 .577 .707 r
F P
0 g
s
.33839 .73522 m .33839 .67963 L .31434 .68528 L p .707 .577 .707 r
F P
0 g
s
.50095 .87858 m .50095 .86005 L .50804 .85169 L p .707 .577 .707 r
F P
0 g
s
.68936 .68429 m .68936 .73987 L .66831 .73342 L p .707 .577 .707 r
F P
0 g
s
.66831 .73342 m .66831 .67784 L .68936 .68429 L p .707 .577 .707 r
F P
0 g
s
.19449 .70721 m .19449 .67016 L .17343 .6637 L p .707 .577 .707 r
F P
0 g
s
.37794 .79316 m .37794 .29127 L .36016 .28014 L p .707 .577 .707 r
F P
0 g
s
.37794 .29127 m .37794 .79316 L .40766 .80227 L p .707 .577 .707 r
F P
0 g
s
.19449 .68315 m .19449 .73873 L .22195 .74312 L p .707 .577 .707 r
F P
0 g
s
.19449 .73873 m .19449 .68315 L .17343 .67669 L p .707 .577 .707 r
F P
0 g
s
.50804 .85169 m .50804 .87021 L .50095 .87858 L p .707 .577 .707 r
F P
0 g
s
.17343 .6637 m .17343 .70076 L .19449 .70721 L p .707 .577 .707 r
F P
0 g
s
.33839 .66664 m .33839 .7037 L .35476 .69633 L p .707 .577 .707 r
F P
0 g
s
.35476 .69633 m .35476 .65928 L .33839 .66664 L p .707 .577 .707 r
F P
0 g
s
.33839 .67963 m .33839 .73522 L .35476 .72785 L p .707 .577 .707 r
F P
0 g
s
.35476 .72785 m .35476 .67227 L .33839 .67963 L p .707 .577 .707 r
F P
0 g
s
.70195 .85514 m .70195 .87367 L .68936 .86579 L p .707 .577 .707 r
F P
0 g
s
.68936 .86579 m .68936 .84726 L .70195 .85514 L p .707 .577 .707 r
F P
0 g
s
.66831 .66485 m .66831 .7019 L .64085 .69751 L p .707 .577 .707 r
F P
0 g
s
.64085 .69751 m .64085 .66045 L .66831 .66485 L p .707 .577 .707 r
F P
0 g
s
.17343 .67669 m .17343 .73228 L .19449 .73873 L p .707 .577 .707 r
F P
0 g
s
.66831 .67784 m .66831 .73342 L .64085 .72903 L p .707 .577 .707 r
F P
0 g
s
.64085 .72903 m .64085 .67344 L .66831 .67784 L p .707 .577 .707 r
F P
0 g
s
.17343 .70076 m .17343 .6637 L .16084 .65582 L p .707 .577 .707 r
F P
0 g
s
.63393 .28502 m .63393 .78691 L .64393 .7751 L p .707 .577 .707 r
F P
0 g
s
.64393 .7751 m .64393 .27321 L .63393 .28502 L p .707 .577 .707 r
F P
0 g
s
.25312 .87093 m .25312 .85241 L .22195 .85051 L p .707 .577 .707 r
F P
0 g
s
.25312 .85241 m .25312 .87093 L .28495 .87016 L p .707 .577 .707 r
F P
0 g
s
.28495 .87016 m .28495 .85163 L .25312 .85241 L p .707 .577 .707 r
F P
0 g
s
.17343 .73228 m .17343 .67669 L .16084 .66881 L p .707 .577 .707 r
F P
0 g
s
.50804 .87021 m .50804 .85169 L .5244 .84432 L p .707 .577 .707 r
F P
0 g
s
.28495 .85163 m .28495 .87016 L .31434 .86678 L p .707 .577 .707 r
F P
0 g
s
.31434 .86678 m .31434 .84825 L .28495 .85163 L p .707 .577 .707 r
F P
0 g
s
.22195 .85051 m .22195 .86903 L .25312 .87093 L p .707 .577 .707 r
F P
0 g
s
.22195 .86903 m .22195 .85051 L .19449 .84611 L p .707 .577 .707 r
F P
0 g
s
.16084 .65582 m .16084 .69287 L .17343 .70076 L p .707 .577 .707 r
F P
0 g
s
.5244 .84432 m .5244 .86284 L .50804 .87021 L p .707 .577 .707 r
F P
0 g
s
.19449 .84611 m .19449 .86464 L .22195 .86903 L p .707 .577 .707 r
F P
0 g
s
.35476 .65928 m .35476 .69633 L .36184 .68797 L p .707 .577 .707 r
F P
0 g
s
.36184 .68797 m .36184 .65091 L .35476 .65928 L p .707 .577 .707 r
F P
0 g
s
.31434 .84825 m .31434 .86678 L .33839 .86113 L p .707 .577 .707 r
F P
0 g
s
.33839 .86113 m .33839 .8426 L .31434 .84825 L p .707 .577 .707 r
F P
0 g
s
.16084 .66881 m .16084 .72439 L .17343 .73228 L p .707 .577 .707 r
F P
0 g
s
.35476 .67227 m .35476 .72785 L .36184 .71948 L p .707 .577 .707 r
F P
0 g
s
.36184 .71948 m .36184 .6639 L .35476 .67227 L p .707 .577 .707 r
F P
0 g
s
.36184 .65091 m .36184 .68797 L .35894 .67942 L p .707 .577 .707 r
F P
0 g
s
.35894 .67942 m .35894 .64237 L .36184 .65091 L p .707 .577 .707 r
F P
0 g
s
.36184 .6639 m .36184 .71948 L .35894 .71094 L p .707 .577 .707 r
F P
0 g
s
.35894 .71094 m .35894 .65536 L .36184 .6639 L p .707 .577 .707 r
F P
0 g
s
.36016 .78203 m .36016 .28014 L .35607 .26808 L p .707 .577 .707 r
F P
0 g
s
.36016 .28014 m .36016 .78203 L .37794 .79316 L p .707 .577 .707 r
F P
0 g
s
.68936 .84726 m .68936 .86579 L .66831 .85933 L p .707 .577 .707 r
F P
0 g
s
.66831 .85933 m .66831 .8408 L .68936 .84726 L p .707 .577 .707 r
F P
0 g
s
.19449 .86464 m .19449 .84611 L .17343 .83966 L p .707 .577 .707 r
F P
0 g
s
.16084 .69287 m .16084 .65582 L .15794 .64728 L p .707 .577 .707 r
F P
0 g
s
.17343 .83966 m .17343 .85819 L .19449 .86464 L p .707 .577 .707 r
F P
0 g
s
.16084 .72439 m .16084 .66881 L .15794 .66027 L p .707 .577 .707 r
F P
0 g
s
.5244 .86284 m .5244 .84432 L .54846 .83867 L p .707 .577 .707 r
F P
0 g
s
.54846 .83867 m .54846 .8572 L .5244 .86284 L p .707 .577 .707 r
F P
0 g
s
.33839 .8426 m .33839 .86113 L .35476 .85376 L p .707 .577 .707 r
F P
0 g
s
.35476 .85376 m .35476 .83523 L .33839 .8426 L p .707 .577 .707 r
F P
0 g
s
.15794 .64728 m .15794 .68433 L .16084 .69287 L p .707 .577 .707 r
F P
0 g
s
.64393 .27321 m .64393 .7751 L .63984 .76304 L p .707 .577 .707 r
F P
0 g
s
.63984 .76304 m .63984 .26115 L .64393 .27321 L p .707 .577 .707 r
F P
0 g
s
.66831 .8408 m .66831 .85933 L .64085 .85494 L p .707 .577 .707 r
F P
0 g
s
.64085 .85494 m .64085 .83641 L .66831 .8408 L p .707 .577 .707 r
F P
0 g
s
.15794 .66027 m .15794 .71585 L .16084 .72439 L p .707 .577 .707 r
F P
0 g
s
.17343 .85819 m .17343 .83966 L .16084 .83178 L p .707 .577 .707 r
F P
0 g
s
.54846 .8572 m .54846 .83867 L .57784 .83529 L p .707 .577 .707 r
F P
0 g
s
.16084 .83178 m .16084 .8503 L .17343 .85819 L p .707 .577 .707 r
F P
0 g
s
.57784 .83529 m .57784 .85382 L .54846 .8572 L p .707 .577 .707 r
F P
0 g
s
.15794 .68433 m .15794 .64728 L .16503 .63891 L p .707 .577 .707 r
F P
0 g
s
.64085 .83641 m .64085 .85494 L .60968 .85304 L p .707 .577 .707 r
F P
0 g
s
.60968 .85304 m .60968 .83451 L .64085 .83641 L p .707 .577 .707 r
F P
0 g
s
.15794 .71585 m .15794 .66027 L .16503 .6519 L p .707 .577 .707 r
F P
0 g
s
.35894 .64237 m .35894 .67942 L .34635 .67154 L p .707 .577 .707 r
F P
0 g
s
.34635 .67154 m .34635 .63449 L .35894 .64237 L p .707 .577 .707 r
F P
0 g
s
.35894 .65536 m .35894 .71094 L .34635 .70306 L p .707 .577 .707 r
F P
0 g
s
.34635 .70306 m .34635 .64748 L .35894 .65536 L p .707 .577 .707 r
F P
0 g
s
.35607 .26808 m .35607 .76997 L .36016 .78203 L p .707 .577 .707 r
F P
0 g
s
.35607 .76997 m .35607 .26808 L .36607 .25627 L p .707 .577 .707 r
F P
0 g
s
.57784 .85382 m .57784 .83529 L .60968 .83451 L p .707 .577 .707 r
F P
0 g
s
.35476 .83523 m .35476 .85376 L .36184 .8454 L p .707 .577 .707 r
F P
0 g
s
.36184 .8454 m .36184 .82687 L .35476 .83523 L p .707 .577 .707 r
F P
0 g
s
.60968 .83451 m .60968 .85304 L .57784 .85382 L p .707 .577 .707 r
F P
0 g
s
.16503 .63891 m .16503 .67597 L .15794 .68433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .8503 m .16084 .83178 L .15794 .82323 L p .707 .577 .707 r
F P
0 g
s
.16503 .6519 m .16503 .70748 L .15794 .71585 L p .707 .577 .707 r
F P
0 g
s
.15794 .82323 m .15794 .84176 L .16084 .8503 L p .707 .577 .707 r
F P
0 g
s
.63984 .26115 m .63984 .76304 L .62206 .75191 L p .707 .577 .707 r
F P
0 g
s
.62206 .75191 m .62206 .25002 L .63984 .26115 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .67597 m .16503 .63891 L .1814 .63154 L p .707 .577 .707 r
F P
0 g
s
.16503 .70748 m .16503 .6519 L .1814 .64453 L p .707 .577 .707 r
F P
0 g
s
.36184 .82687 m .36184 .8454 L .35894 .83685 L p .707 .577 .707 r
F P
0 g
s
.35894 .83685 m .35894 .81833 L .36184 .82687 L p .707 .577 .707 r
F P
0 g
s
.1814 .63154 m .1814 .6686 L .16503 .67597 L p .707 .577 .707 r
F P
0 g
s
.34635 .63449 m .34635 .67154 L .3253 .66509 L p .707 .577 .707 r
F P
0 g
s
.3253 .66509 m .3253 .62803 L .34635 .63449 L p .707 .577 .707 r
F P
0 g
s
.36607 .75816 m .36607 .25627 L .38918 .24587 L p .707 .577 .707 r
F P
0 g
s
.36607 .25627 m .36607 .75816 L .35607 .76997 L p .707 .577 .707 r
F P
0 g
s
.15794 .84176 m .15794 .82323 L .16503 .81487 L p .707 .577 .707 r
F P
0 g
s
.1814 .64453 m .1814 .70012 L .16503 .70748 L p .707 .577 .707 r
F P
0 g
s
.34635 .64748 m .34635 .70306 L .3253 .6966 L p .707 .577 .707 r
F P
0 g
s
.3253 .6966 m .3253 .64102 L .34635 .64748 L p .707 .577 .707 r
F P
0 g
s
.16503 .81487 m .16503 .8334 L .15794 .84176 L p .707 .577 .707 r
F P
0 g
s
.1814 .6686 m .1814 .63154 L .20545 .62589 L p .707 .577 .707 r
F P
0 g
s
.1814 .70012 m .1814 .64453 L .20545 .63888 L p .707 .577 .707 r
F P
0 g
s
.35894 .81833 m .35894 .83685 L .34635 .82897 L p .707 .577 .707 r
F P
0 g
s
.34635 .82897 m .34635 .81044 L .35894 .81833 L p .707 .577 .707 r
F P
0 g
s
.20545 .62589 m .20545 .66295 L .1814 .6686 L p .707 .577 .707 r
F P
0 g
s
.62206 .25002 m .62206 .75191 L .59233 .7428 L p .707 .577 .707 r
F P
0 g
s
.59233 .7428 m .59233 .24091 L .62206 .25002 L p .707 .577 .707 r
F P
0 g
s
.3253 .62803 m .3253 .66509 L .29784 .66069 L p .707 .577 .707 r
F P
0 g
s
.29784 .66069 m .29784 .62364 L .3253 .62803 L p .707 .577 .707 r
F P
0 g
s
.3253 .64102 m .3253 .6966 L .29784 .69221 L p .707 .577 .707 r
F P
0 g
s
.29784 .69221 m .29784 .63663 L .3253 .64102 L p .707 .577 .707 r
F P
0 g
s
.20545 .63888 m .20545 .69447 L .1814 .70012 L p .707 .577 .707 r
F P
0 g
s
.20545 .66295 m .20545 .62589 L .23483 .62252 L p .707 .577 .707 r
F P
0 g
s
.16503 .8334 m .16503 .81487 L .1814 .8075 L p .707 .577 .707 r
F P
0 g
s
.20545 .69447 m .20545 .63888 L .23483 .63551 L p .707 .577 .707 r
F P
0 g
s
.38918 .24587 m .38918 .74776 L .36607 .75816 L p .707 .577 .707 r
F P
0 g
s
.38918 .74776 m .38918 .24587 L .42314 .23789 L p .707 .577 .707 r
F P
0 g
s
.1814 .8075 m .1814 .82603 L .16503 .8334 L p .707 .577 .707 r
F P
0 g
s
.29784 .62364 m .29784 .66069 L .26667 .65879 L p .707 .577 .707 r
F P
0 g
s
.26667 .65879 m .26667 .62174 L .29784 .62364 L p .707 .577 .707 r
F P
0 g
s
.23483 .62252 m .23483 .65957 L .20545 .66295 L p .707 .577 .707 r
F P
0 g
s
.29784 .63663 m .29784 .69221 L .26667 .69031 L p .707 .577 .707 r
F P
0 g
s
.26667 .69031 m .26667 .63473 L .29784 .63663 L p .707 .577 .707 r
F P
0 g
s
.23483 .65957 m .23483 .62252 L .26667 .62174 L p .707 .577 .707 r
F P
0 g
s
.26667 .62174 m .26667 .65879 L .23483 .65957 L p .707 .577 .707 r
F P
0 g
s
.23483 .69109 m .23483 .63551 L .26667 .63473 L p .707 .577 .707 r
F P
0 g
s
.23483 .63551 m .23483 .69109 L .20545 .69447 L p .707 .577 .707 r
F P
0 g
s
.73333 .65828 m .73333 .62123 L .70216 .61933 L p .707 .577 .707 r
F P
0 g
s
.73333 .62123 m .73333 .65828 L .76517 .6575 L p .707 .577 .707 r
F P
0 g
s
.76517 .6575 m .76517 .62045 L .73333 .62123 L p .707 .577 .707 r
F P
0 g
s
.34635 .81044 m .34635 .82897 L .3253 .82252 L p .707 .577 .707 r
F P
0 g
s
.3253 .82252 m .3253 .80399 L .34635 .81044 L p .707 .577 .707 r
F P
0 g
s
.26667 .63473 m .26667 .69031 L .23483 .69109 L p .707 .577 .707 r
F P
0 g
s
.76517 .62045 m .76517 .6575 L .79455 .65413 L p .707 .577 .707 r
F P
0 g
s
.79455 .65413 m .79455 .61707 L .76517 .62045 L p .707 .577 .707 r
F P
0 g
s
.73333 .6898 m .73333 .63422 L .70216 .63232 L p .707 .577 .707 r
F P
0 g
s
.73333 .63422 m .73333 .6898 L .76517 .68902 L p .707 .577 .707 r
F P
0 g
s
.76517 .68902 m .76517 .63344 L .73333 .63422 L p .707 .577 .707 r
F P
0 g
s
.76517 .63344 m .76517 .68902 L .79455 .68564 L p .707 .577 .707 r
F P
0 g
s
.79455 .68564 m .79455 .63006 L .76517 .63344 L p .707 .577 .707 r
F P
0 g
s
.70216 .65638 m .70216 .61933 L .6747 .61493 L p .707 .577 .707 r
F P
0 g
s
.70216 .61933 m .70216 .65638 L .73333 .65828 L p .707 .577 .707 r
F P
0 g
s
.59233 .24091 m .59233 .7428 L .55357 .7366 L p .707 .577 .707 r
F P
0 g
s
.55357 .7366 m .55357 .23471 L .59233 .24091 L p .707 .577 .707 r
F P
0 g
s
.70216 .6879 m .70216 .63232 L .6747 .62792 L p .707 .577 .707 r
F P
0 g
s
.70216 .63232 m .70216 .6879 L .73333 .6898 L p .707 .577 .707 r
F P
0 g
s
.1814 .82603 m .1814 .8075 L .20545 .80185 L p .707 .577 .707 r
F P
0 g
s
.79455 .61707 m .79455 .65413 L .8186 .64848 L p .707 .577 .707 r
F P
0 g
s
.8186 .64848 m .8186 .61142 L .79455 .61707 L p .707 .577 .707 r
F P
0 g
s
.20545 .80185 m .20545 .82038 L .1814 .82603 L p .707 .577 .707 r
F P
0 g
s
.6747 .61493 m .6747 .65199 L .70216 .65638 L p .707 .577 .707 r
F P
0 g
s
.79455 .63006 m .79455 .68564 L .8186 .67999 L p .707 .577 .707 r
F P
0 g
s
.8186 .67999 m .8186 .62441 L .79455 .63006 L p .707 .577 .707 r
F P
0 g
s
.42314 .73978 m .42314 .23789 L .46462 .23312 L p .707 .577 .707 r
F P
0 g
s
.42314 .23789 m .42314 .73978 L .38918 .74776 L p .707 .577 .707 r
F P
0 g
s
.6747 .65199 m .6747 .61493 L .65365 .60848 L p .707 .577 .707 r
F P
0 g
s
.3253 .80399 m .3253 .82252 L .29784 .81812 L p .707 .577 .707 r
F P
0 g
s
.29784 .81812 m .29784 .7996 L .3253 .80399 L p .707 .577 .707 r
F P
0 g
s
.6747 .62792 m .6747 .68351 L .70216 .6879 L p .707 .577 .707 r
F P
0 g
s
.6747 .68351 m .6747 .62792 L .65365 .62147 L p .707 .577 .707 r
F P
0 g
s
.55357 .23471 m .55357 .7366 L .50956 .73392 L p .707 .577 .707 r
F P
0 g
s
.50956 .73392 m .50956 .23203 L .55357 .23471 L p .707 .577 .707 r
F P
0 g
s
.20545 .82038 m .20545 .80185 L .23483 .79847 L p .707 .577 .707 r
F P
0 g
s
.65365 .60848 m .65365 .64553 L .6747 .65199 L p .707 .577 .707 r
F P
0 g
s
.8186 .61142 m .8186 .64848 L .83497 .64111 L p .707 .577 .707 r
F P
0 g
s
.83497 .64111 m .83497 .60405 L .8186 .61142 L p .707 .577 .707 r
F P
0 g
s
.46462 .73501 m .46462 .23312 L .50956 .23203 L p .707 .577 .707 r
F P
0 g
s
.46462 .23312 m .46462 .73501 L .42314 .73978 L p .707 .577 .707 r
F P
0 g
s
.23483 .79847 m .23483 .817 L .20545 .82038 L p .707 .577 .707 r
F P
0 g
s
.8186 .62441 m .8186 .67999 L .83497 .67263 L p .707 .577 .707 r
F P
0 g
s
.83497 .67263 m .83497 .61704 L .8186 .62441 L p .707 .577 .707 r
F P
0 g
s
.50956 .23203 m .50956 .73392 L .46462 .73501 L p .707 .577 .707 r
F P
0 g
s
.29784 .7996 m .29784 .81812 L .26667 .81622 L p .707 .577 .707 r
F P
0 g
s
.26667 .81622 m .26667 .7977 L .29784 .7996 L p .707 .577 .707 r
F P
0 g
s
.65365 .62147 m .65365 .67705 L .6747 .68351 L p .707 .577 .707 r
F P
0 g
s
.23483 .817 m .23483 .79847 L .26667 .7977 L p .707 .577 .707 r
F P
0 g
s
.65365 .64553 m .65365 .60848 L .64105 .6006 L p .707 .577 .707 r
F P
0 g
s
.26667 .7977 m .26667 .81622 L .23483 .817 L p .707 .577 .707 r
F P
0 g
s
.73333 .81571 m .73333 .79718 L .70216 .79528 L p .707 .577 .707 r
F P
0 g
s
.73333 .79718 m .73333 .81571 L .76517 .81493 L p .707 .577 .707 r
F P
0 g
s
.76517 .81493 m .76517 .79641 L .73333 .79718 L p .707 .577 .707 r
F P
0 g
s
.65365 .67705 m .65365 .62147 L .64105 .61359 L p .707 .577 .707 r
F P
0 g
s
.76517 .79641 m .76517 .81493 L .79455 .81156 L p .707 .577 .707 r
F P
0 g
s
.79455 .81156 m .79455 .79303 L .76517 .79641 L p .707 .577 .707 r
F P
0 g
s
.70216 .79528 m .70216 .81381 L .73333 .81571 L p .707 .577 .707 r
F P
0 g
s
.70216 .81381 m .70216 .79528 L .6747 .79089 L p .707 .577 .707 r
F P
0 g
s
.64105 .6006 m .64105 .63765 L .65365 .64553 L p .707 .577 .707 r
F P
0 g
s
.6747 .79089 m .6747 .80942 L .70216 .81381 L p .707 .577 .707 r
F P
0 g
s
.83497 .60405 m .83497 .64111 L .84205 .63274 L p .707 .577 .707 r
F P
0 g
s
.84205 .63274 m .84205 .59569 L .83497 .60405 L p .707 .577 .707 r
F P
0 g
s
.79455 .79303 m .79455 .81156 L .8186 .80591 L p .707 .577 .707 r
F P
0 g
s
.8186 .80591 m .8186 .78738 L .79455 .79303 L p .707 .577 .707 r
F P
0 g
s
.64105 .61359 m .64105 .66917 L .65365 .67705 L p .707 .577 .707 r
F P
0 g
s
.83497 .61704 m .83497 .67263 L .84205 .66426 L p .707 .577 .707 r
F P
0 g
s
.84205 .66426 m .84205 .60868 L .83497 .61704 L p .707 .577 .707 r
F P
0 g
s
.6747 .80942 m .6747 .79089 L .65365 .78444 L p .707 .577 .707 r
F P
0 g
s
.64105 .63765 m .64105 .6006 L .63816 .59205 L p .707 .577 .707 r
F P
0 g
s
.65365 .78444 m .65365 .80297 L .6747 .80942 L p .707 .577 .707 r
F P
0 g
s
.64105 .66917 m .64105 .61359 L .63816 .60504 L p .707 .577 .707 r
F P
0 g
s
.8186 .78738 m .8186 .80591 L .83497 .79854 L p .707 .577 .707 r
F P
0 g
s
.83497 .79854 m .83497 .78001 L .8186 .78738 L p .707 .577 .707 r
F P
0 g
s
.63816 .59205 m .63816 .62911 L .64105 .63765 L p .707 .577 .707 r
F P
0 g
s
.84205 .59569 m .84205 .63274 L .83916 .6242 L p .707 .577 .707 r
F P
0 g
s
.83916 .6242 m .83916 .58715 L .84205 .59569 L p .707 .577 .707 r
F P
0 g
s
.63816 .60504 m .63816 .66063 L .64105 .66917 L p .707 .577 .707 r
F P
0 g
s
.65365 .80297 m .65365 .78444 L .64105 .77655 L p .707 .577 .707 r
F P
0 g
s
.84205 .60868 m .84205 .66426 L .83916 .65572 L p .707 .577 .707 r
F P
0 g
s
.83916 .65572 m .83916 .60014 L .84205 .60868 L p .707 .577 .707 r
F P
0 g
s
.64105 .77655 m .64105 .79508 L .65365 .80297 L p .707 .577 .707 r
F P
0 g
s
.63816 .62911 m .63816 .59205 L .64524 .58369 L p .707 .577 .707 r
F P
0 g
s
.63816 .66063 m .63816 .60504 L .64524 .59668 L p .707 .577 .707 r
F P
0 g
s
.83497 .78001 m .83497 .79854 L .84206 .79017 L p .707 .577 .707 r
F P
0 g
s
.84206 .79017 m .84206 .77165 L .83497 .78001 L p .707 .577 .707 r
F P
0 g
s
.64524 .58369 m .64524 .62074 L .63816 .62911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83916 .58715 m .83916 .6242 L .82657 .61632 L p .707 .577 .707 r
F P
0 g
s
.82657 .61632 m .82657 .57926 L .83916 .58715 L p .707 .577 .707 r
F P
0 g
s
.64105 .79508 m .64105 .77655 L .63816 .76801 L p .707 .577 .707 r
F P
0 g
s
.64524 .59668 m .64524 .65226 L .63816 .66063 L p .707 .577 .707 r
F P
0 g
s
.83916 .60014 m .83916 .65572 L .82657 .64783 L p .707 .577 .707 r
F P
0 g
s
.82657 .64783 m .82657 .59225 L .83916 .60014 L p .707 .577 .707 r
F P
0 g
s
.63816 .76801 m .63816 .78654 L .64105 .79508 L p .707 .577 .707 r
F P
0 g
s
.39032 .62147 m .39032 .58441 L .35915 .58251 L p .707 .577 .707 r
F P
0 g
s
.39032 .58441 m .39032 .62147 L .42216 .62069 L p .707 .577 .707 r
F P
0 g
s
.42216 .62069 m .42216 .58363 L .39032 .58441 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .62074 m .64524 .58369 L .66161 .57632 L p .707 .577 .707 r
F P
0 g
s
.42216 .58363 m .42216 .62069 L .45154 .61731 L p .707 .577 .707 r
F P
0 g
s
.45154 .61731 m .45154 .58025 L .42216 .58363 L p .707 .577 .707 r
F P
0 g
s
.39032 .65298 m .39032 .5974 L .35915 .5955 L p .707 .577 .707 r
F P
0 g
s
.39032 .5974 m .39032 .65298 L .42216 .65221 L p .707 .577 .707 r
F P
0 g
s
.42216 .65221 m .42216 .59662 L .39032 .5974 L p .707 .577 .707 r
F P
0 g
s
.64524 .65226 m .64524 .59668 L .66161 .58931 L p .707 .577 .707 r
F P
0 g
s
.42216 .59662 m .42216 .65221 L .45154 .64883 L p .707 .577 .707 r
F P
0 g
s
.45154 .64883 m .45154 .59325 L .42216 .59662 L p .707 .577 .707 r
F P
0 g
s
.35915 .61957 m .35915 .58251 L .33169 .57812 L p .707 .577 .707 r
F P
0 g
s
.35915 .58251 m .35915 .61957 L .39032 .62147 L p .707 .577 .707 r
F P
0 g
s
.84206 .77165 m .84206 .79017 L .83916 .78163 L p .707 .577 .707 r
F P
0 g
s
.83916 .78163 m .83916 .7631 L .84206 .77165 L p .707 .577 .707 r
F P
0 g
s
.35915 .65108 m .35915 .5955 L .33169 .59111 L p .707 .577 .707 r
F P
0 g
s
.35915 .5955 m .35915 .65108 L .39032 .65298 L p .707 .577 .707 r
F P
0 g
s
.66161 .57632 m .66161 .61338 L .64524 .62074 L p .707 .577 .707 r
F P
0 g
s
.45154 .58025 m .45154 .61731 L .47559 .61166 L p .707 .577 .707 r
F P
0 g
s
.47559 .61166 m .47559 .5746 L .45154 .58025 L p .707 .577 .707 r
F P
0 g
s
.33169 .57812 m .33169 .61517 L .35915 .61957 L p .707 .577 .707 r
F P
0 g
s
.82657 .57926 m .82657 .61632 L .80551 .60986 L p .707 .577 .707 r
F P
0 g
s
.80551 .60986 m .80551 .57281 L .82657 .57926 L p .707 .577 .707 r
F P
0 g
s
.45154 .59325 m .45154 .64883 L .47559 .64318 L p .707 .577 .707 r
F P
0 g
s
.47559 .64318 m .47559 .5876 L .45154 .59325 L p .707 .577 .707 r
F P
0 g
s
.63816 .78654 m .63816 .76801 L .64524 .75965 L p .707 .577 .707 r
F P
0 g
s
.66161 .58931 m .66161 .64489 L .64524 .65226 L p .707 .577 .707 r
F P
0 g
s
.82657 .59225 m .82657 .64783 L .80551 .64138 L p .707 .577 .707 r
F P
0 g
s
.80551 .64138 m .80551 .5858 L .82657 .59225 L p .707 .577 .707 r
F P
0 g
s
.33169 .61517 m .33169 .57812 L .31064 .57166 L p .707 .577 .707 r
F P
0 g
s
.33169 .59111 m .33169 .64669 L .35915 .65108 L p .707 .577 .707 r
F P
0 g
s
.33169 .64669 m .33169 .59111 L .31064 .58465 L p .707 .577 .707 r
F P
0 g
s
.64524 .75965 m .64524 .77817 L .63816 .78654 L p .707 .577 .707 r
F P
0 g
s
.66161 .61338 m .66161 .57632 L .68566 .57067 L p .707 .577 .707 r
F P
0 g
s
.66161 .64489 m .66161 .58931 L .68566 .58366 L p .707 .577 .707 r
F P
0 g
s
.31064 .57166 m .31064 .60872 L .33169 .61517 L p .707 .577 .707 r
F P
0 g
s
.47559 .5746 m .47559 .61166 L .49196 .60429 L p .707 .577 .707 r
F P
0 g
s
.49196 .60429 m .49196 .56724 L .47559 .5746 L p .707 .577 .707 r
F P
0 g
s
.47559 .5876 m .47559 .64318 L .49196 .63581 L p .707 .577 .707 r
F P
0 g
s
.49196 .63581 m .49196 .58023 L .47559 .5876 L p .707 .577 .707 r
F P
0 g
s
.83916 .7631 m .83916 .78163 L .82657 .77375 L p .707 .577 .707 r
F P
0 g
s
.82657 .77375 m .82657 .75522 L .83916 .7631 L p .707 .577 .707 r
F P
0 g
s
.68566 .57067 m .68566 .60773 L .66161 .61338 L p .707 .577 .707 r
F P
0 g
s
.80551 .57281 m .80551 .60986 L .77805 .60547 L p .707 .577 .707 r
F P
0 g
s
.77805 .60547 m .77805 .56842 L .80551 .57281 L p .707 .577 .707 r
F P
0 g
s
.31064 .58465 m .31064 .64024 L .33169 .64669 L p .707 .577 .707 r
F P
0 g
s
.80551 .5858 m .80551 .64138 L .77805 .63699 L p .707 .577 .707 r
F P
0 g
s
.77805 .63699 m .77805 .58141 L .80551 .5858 L p .707 .577 .707 r
F P
0 g
s
.31064 .60872 m .31064 .57166 L .29804 .56378 L p .707 .577 .707 r
F P
0 g
s
.68566 .58366 m .68566 .63924 L .66161 .64489 L p .707 .577 .707 r
F P
0 g
s
.39032 .7789 m .39032 .76037 L .35915 .75847 L p .707 .577 .707 r
F P
0 g
s
.39032 .76037 m .39032 .7789 L .42216 .77812 L p .707 .577 .707 r
F P
0 g
s
.42216 .77812 m .42216 .75959 L .39032 .76037 L p .707 .577 .707 r
F P
0 g
s
.68566 .60773 m .68566 .57067 L .71504 .56729 L p .707 .577 .707 r
F P
0 g
s
.31064 .64024 m .31064 .58465 L .29804 .57677 L p .707 .577 .707 r
F P
0 g
s
.64524 .77817 m .64524 .75965 L .66161 .75228 L p .707 .577 .707 r
F P
0 g
s
.42216 .75959 m .42216 .77812 L .45154 .77474 L p .707 .577 .707 r
F P
0 g
s
.45154 .77474 m .45154 .75621 L .42216 .75959 L p .707 .577 .707 r
F P
0 g
s
.68566 .63924 m .68566 .58366 L .71504 .58028 L p .707 .577 .707 r
F P
0 g
s
.35915 .75847 m .35915 .777 L .39032 .7789 L p .707 .577 .707 r
F P
0 g
s
.35915 .777 m .35915 .75847 L .33169 .75408 L p .707 .577 .707 r
F P
0 g
s
.29804 .56378 m .29804 .60083 L .31064 .60872 L p .707 .577 .707 r
F P
0 g
s
.66161 .75228 m .66161 .77081 L .64524 .77817 L p .707 .577 .707 r
F P
0 g
s
.77805 .56842 m .77805 .60547 L .74688 .60357 L p .707 .577 .707 r
F P
0 g
s
.74688 .60357 m .74688 .56651 L .77805 .56842 L p .707 .577 .707 r
F P
0 g
s
.71504 .56729 m .71504 .60435 L .68566 .60773 L p .707 .577 .707 r
F P
0 g
s
.33169 .75408 m .33169 .7726 L .35915 .777 L p .707 .577 .707 r
F P
0 g
s
.77805 .58141 m .77805 .63699 L .74688 .63509 L p .707 .577 .707 r
F P
0 g
s
.74688 .63509 m .74688 .57951 L .77805 .58141 L p .707 .577 .707 r
F P
0 g
s
.71504 .60435 m .71504 .56729 L .74688 .56651 L p .707 .577 .707 r
F P
0 g
s
.49196 .56724 m .49196 .60429 L .49904 .59593 L p .707 .577 .707 r
F P
0 g
s
.49904 .59593 m .49904 .55887 L .49196 .56724 L p .707 .577 .707 r
F P
0 g
s
.45154 .75621 m .45154 .77474 L .47559 .76909 L p .707 .577 .707 r
F P
0 g
s
.47559 .76909 m .47559 .75056 L .45154 .75621 L p .707 .577 .707 r
F P
0 g
s
.74688 .56651 m .74688 .60357 L .71504 .60435 L p .707 .577 .707 r
F P
0 g
s
.29804 .57677 m .29804 .63235 L .31064 .64024 L p .707 .577 .707 r
F P
0 g
s
.71504 .63587 m .71504 .58028 L .74688 .57951 L p .707 .577 .707 r
F P
0 g
s
.71504 .58028 m .71504 .63587 L .68566 .63924 L p .707 .577 .707 r
F P
0 g
s
.49196 .58023 m .49196 .63581 L .49904 .62745 L p .707 .577 .707 r
F P
0 g
s
.49904 .62745 m .49904 .57186 L .49196 .58023 L p .707 .577 .707 r
F P
0 g
s
.82657 .75522 m .82657 .77375 L .80551 .76729 L p .707 .577 .707 r
F P
0 g
s
.80551 .76729 m .80551 .74877 L .82657 .75522 L p .707 .577 .707 r
F P
0 g
s
.74688 .57951 m .74688 .63509 L .71504 .63587 L p .707 .577 .707 r
F P
0 g
s
.33169 .7726 m .33169 .75408 L .31064 .74762 L p .707 .577 .707 r
F P
0 g
s
.29804 .60083 m .29804 .56378 L .29515 .55524 L p .707 .577 .707 r
F P
0 g
s
.31064 .74762 m .31064 .76615 L .33169 .7726 L p .707 .577 .707 r
F P
0 g
s
.29804 .63235 m .29804 .57677 L .29515 .56823 L p .707 .577 .707 r
F P
0 g
s
.66161 .77081 m .66161 .75228 L .68566 .74663 L p .707 .577 .707 r
F P
0 g
s
.68566 .74663 m .68566 .76516 L .66161 .77081 L p .707 .577 .707 r
F P
0 g
s
.47559 .75056 m .47559 .76909 L .49196 .76172 L p .707 .577 .707 r
F P
0 g
s
.49196 .76172 m .49196 .7432 L .47559 .75056 L p .707 .577 .707 r
F P
0 g
s
.29515 .55524 m .29515 .59229 L .29804 .60083 L p .707 .577 .707 r
F P
0 g
s
.80551 .74877 m .80551 .76729 L .77805 .7629 L p .707 .577 .707 r
F P
0 g
s
.77805 .7629 m .77805 .74437 L .80551 .74877 L p .707 .577 .707 r
F P
0 g
s
.49904 .55887 m .49904 .59593 L .49615 .58739 L p .707 .577 .707 r
F P
0 g
s
.49615 .58739 m .49615 .55033 L .49904 .55887 L p .707 .577 .707 r
F P
0 g
s
.29515 .56823 m .29515 .62381 L .29804 .63235 L p .707 .577 .707 r
F P
0 g
s
.31064 .76615 m .31064 .74762 L .29804 .73974 L p .707 .577 .707 r
F P
0 g
s
.49904 .57186 m .49904 .62745 L .49615 .6189 L p .707 .577 .707 r
F P
0 g
s
.49615 .6189 m .49615 .56332 L .49904 .57186 L p .707 .577 .707 r
F P
0 g
s
.68566 .76516 m .68566 .74663 L .71504 .74325 L p .707 .577 .707 r
F P
0 g
s
.29804 .73974 m .29804 .75827 L .31064 .76615 L p .707 .577 .707 r
F P
0 g
s
.71504 .74325 m .71504 .76178 L .68566 .76516 L p .707 .577 .707 r
F P
0 g
s
.29515 .59229 m .29515 .55524 L .30223 .54687 L p .707 .577 .707 r
F P
0 g
s
.77805 .74437 m .77805 .7629 L .74688 .761 L p .707 .577 .707 r
F P
0 g
s
.74688 .761 m .74688 .74247 L .77805 .74437 L p .707 .577 .707 r
F P
0 g
s
.29515 .62381 m .29515 .56823 L .30223 .55986 L p .707 .577 .707 r
F P
0 g
s
.71504 .76178 m .71504 .74325 L .74688 .74247 L p .707 .577 .707 r
F P
0 g
s
.49196 .7432 m .49196 .76172 L .49904 .75336 L p .707 .577 .707 r
F P
0 g
s
.49904 .75336 m .49904 .73483 L .49196 .7432 L p .707 .577 .707 r
F P
0 g
s
.74688 .74247 m .74688 .761 L .71504 .76178 L p .707 .577 .707 r
F P
0 g
s
.30223 .54687 m .30223 .58393 L .29515 .59229 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49615 .55033 m .49615 .58739 L .48356 .5795 L p .707 .577 .707 r
F P
0 g
s
.48356 .5795 m .48356 .54245 L .49615 .55033 L p .707 .577 .707 r
F P
0 g
s
.29804 .75827 m .29804 .73974 L .29515 .7312 L p .707 .577 .707 r
F P
0 g
s
.30223 .55986 m .30223 .61545 L .29515 .62381 L p .707 .577 .707 r
F P
0 g
s
.49615 .56332 m .49615 .6189 L .48356 .61102 L p .707 .577 .707 r
F P
0 g
s
.48356 .61102 m .48356 .55544 L .49615 .56332 L p .707 .577 .707 r
F P
0 g
s
.29515 .7312 m .29515 .74972 L .29804 .75827 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .58393 m .30223 .54687 L .3186 .53951 L p .707 .577 .707 r
F P
0 g
s
.30223 .61545 m .30223 .55986 L .3186 .5525 L p .707 .577 .707 r
F P
0 g
s
.49904 .73483 m .49904 .75336 L .49615 .74482 L p .707 .577 .707 r
F P
0 g
s
.49615 .74482 m .49615 .72629 L .49904 .73483 L p .707 .577 .707 r
F P
0 g
s
.3186 .53951 m .3186 .57656 L .30223 .58393 L p .707 .577 .707 r
F P
0 g
s
.48356 .54245 m .48356 .5795 L .4625 .57305 L p .707 .577 .707 r
F P
0 g
s
.4625 .57305 m .4625 .53599 L .48356 .54245 L p .707 .577 .707 r
F P
0 g
s
.29515 .74972 m .29515 .7312 L .30223 .72283 L p .707 .577 .707 r
F P
0 g
s
.3186 .5525 m .3186 .60808 L .30223 .61545 L p .707 .577 .707 r
F P
0 g
s
.48356 .55544 m .48356 .61102 L .4625 .60457 L p .707 .577 .707 r
F P
0 g
s
.4625 .60457 m .4625 .54898 L .48356 .55544 L p .707 .577 .707 r
F P
0 g
s
.30223 .72283 m .30223 .74136 L .29515 .74972 L p .707 .577 .707 r
F P
0 g
s
.3186 .57656 m .3186 .53951 L .34265 .53386 L p .707 .577 .707 r
F P
0 g
s
.3186 .60808 m .3186 .5525 L .34265 .54685 L p .707 .577 .707 r
F P
0 g
s
.49615 .72629 m .49615 .74482 L .48356 .73693 L p .707 .577 .707 r
F P
0 g
s
.48356 .73693 m .48356 .71841 L .49615 .72629 L p .707 .577 .707 r
F P
0 g
s
.34265 .53386 m .34265 .57091 L .3186 .57656 L p .707 .577 .707 r
F P
0 g
s
.4625 .53599 m .4625 .57305 L .43504 .56865 L p .707 .577 .707 r
F P
0 g
s
.43504 .56865 m .43504 .5316 L .4625 .53599 L p .707 .577 .707 r
F P
0 g
s
.4625 .54898 m .4625 .60457 L .43504 .60017 L p .707 .577 .707 r
F P
0 g
s
.43504 .60017 m .43504 .54459 L .4625 .54898 L p .707 .577 .707 r
F P
0 g
s
.34265 .54685 m .34265 .60243 L .3186 .60808 L p .707 .577 .707 r
F P
0 g
s
.34265 .57091 m .34265 .53386 L .37203 .53048 L p .707 .577 .707 r
F P
0 g
s
.30223 .74136 m .30223 .72283 L .3186 .71546 L p .707 .577 .707 r
F P
0 g
s
.34265 .60243 m .34265 .54685 L .37203 .54347 L p .707 .577 .707 r
F P
0 g
s
.3186 .71546 m .3186 .73399 L .30223 .74136 L p .707 .577 .707 r
F P
0 g
s
.43504 .5316 m .43504 .56865 L .40387 .56675 L p .707 .577 .707 r
F P
0 g
s
.40387 .56675 m .40387 .5297 L .43504 .5316 L p .707 .577 .707 r
F P
0 g
s
.37203 .53048 m .37203 .56753 L .34265 .57091 L p .707 .577 .707 r
F P
0 g
s
.43504 .54459 m .43504 .60017 L .40387 .59827 L p .707 .577 .707 r
F P
0 g
s
.40387 .59827 m .40387 .54269 L .43504 .54459 L p .707 .577 .707 r
F P
0 g
s
.37203 .56753 m .37203 .53048 L .40387 .5297 L p .707 .577 .707 r
F P
0 g
s
.40387 .5297 m .40387 .56675 L .37203 .56753 L p .707 .577 .707 r
F P
0 g
s
.37203 .59905 m .37203 .54347 L .40387 .54269 L p .707 .577 .707 r
F P
0 g
s
.37203 .54347 m .37203 .59905 L .34265 .60243 L p .707 .577 .707 r
F P
0 g
s
.48356 .71841 m .48356 .73693 L .4625 .73048 L p .707 .577 .707 r
F P
0 g
s
.4625 .73048 m .4625 .71195 L .48356 .71841 L p .707 .577 .707 r
F P
0 g
s
.40387 .54269 m .40387 .59827 L .37203 .59905 L p .707 .577 .707 r
F P
0 g
s
.3186 .73399 m .3186 .71546 L .34265 .70981 L p .707 .577 .707 r
F P
0 g
s
.34265 .70981 m .34265 .72834 L .3186 .73399 L p .707 .577 .707 r
F P
0 g
s
.4625 .71195 m .4625 .73048 L .43504 .72609 L p .707 .577 .707 r
F P
0 g
s
.43504 .72609 m .43504 .70756 L .4625 .71195 L p .707 .577 .707 r
F P
0 g
s
.34265 .72834 m .34265 .70981 L .37203 .70644 L p .707 .577 .707 r
F P
0 g
s
.37203 .70644 m .37203 .72496 L .34265 .72834 L p .707 .577 .707 r
F P
0 g
s
.43504 .70756 m .43504 .72609 L .40387 .72419 L p .707 .577 .707 r
F P
0 g
s
.40387 .72419 m .40387 .70566 L .43504 .70756 L p .707 .577 .707 r
F P
0 g
s
.37203 .72496 m .37203 .70644 L .40387 .70566 L p .707 .577 .707 r
F P
0 g
s
.40387 .70566 m .40387 .72419 L .37203 .72496 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00Ogoo8@00OGoo001fOol90005FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000075oo`00K7oo0`00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJ
EP<006ioo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3
001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qoo`00IWoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eooa80
0003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF
20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF
009JEP03001JEUYF01@000IJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF
1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001DOol20004FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0
00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol005=oo`04001JEP00FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUIJEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH000000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo6P00?7oo001C
Ool00`00FUH00004FUH01@00FUIJEUYF00000UYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP@000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH00002000dOol005=oo`03001JEP00009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool3
0005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000bOol005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00
FUIJEP03FUH60003FUH50004FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH3000`Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001JEUYF008002io
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP03001oogoo
02aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20003FUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP000000;Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00`00
;Goo001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH00008FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0004FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH00eYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF00000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH000030002FUH40007
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
0UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP00009JEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YF001JEP00009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004Moo`T000=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEP<000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Uoo`h0
00AJEP03001JEUYF009JEPD000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0031oo`800003FUH005YF00EJ
EP03001JEUYF009JEP03001JEUYF00h000AJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00UYF1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;Goo0P0015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP00008000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYFFUH2000]Ool002eoo`8000AJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF009JEP8002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000EJEP00001JEP0000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=JEP8002eoo`00
;7oo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEQ/000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0
000002eoo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH50003FUH00`00FUIJ
EP02FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP04
001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF10001EYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000/Ool01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool0
02aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`<000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH3
00000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUIJEUYF1@00<goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF1`00>7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF2@0015YF00<005YF
FUH00UYF2@00?goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1@001EYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH00eYF00<005YFFUH00`000goo2@00B7oo000/Ool00`00FUH00004FUH00`00
FUIJEP03FUH70007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF1P000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001D
Ool002aoo`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool01000FUH0
05YF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUH005YF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002aoo`06001JEP00001JEP0015YF0P001eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF1P000eYF00<005YFFUH01UYF00<005YF
FUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P00
0eYF00<005YFFUH00eYF00@005YFFUIJEPD000=JEPD000UJEP03001JEUYF00EJEP03001JEUYF00@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0027oo0`00BGoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P001goo1@00B7oo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF
FUH20007Ool50018Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005
FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008FUH80004FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P001goo1@00B7oo000_Ool3
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF000015YF00@005YFFUIJ
EPP0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
00020003FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`00BGoo000aOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH50005FUH01@00FUH005YF00000eYF1@000UYF0`000Woo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEPX000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEPD000AJEP04001JEUYFFUH2001DOol0
03=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP@000IJEP06001JEP00FUH005YF0`000eYF1000
17oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP/000=JEP03001JEUYF00MJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP<00003FUH0
05YF009JEP8005Aoo`00=Woo1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001JEPP0
00Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH9000;FUH200000eYF001JEP09FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH30003
FUH2001DOol003]ooa`000ioo`04001JEUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH3
000:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH00`00FUIJEP0200000eYF0000000H000lOol005=oo`80009JEP<000]oo`04001JEUYF
0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH300000eYF001JEP09FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH70004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001COol20003FUH00`00FUH0
00020008Ool01000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<0
05YF00002UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00000UYF00<005YF0000
0`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo001COol20003FUH00`00FUIJEP02FUH50003Ool01@00FUIJEP00FUH00P001eYF00<0
05YFFUH025YF00@005YFFUIJEP@00003FUH005YF009JEP03001JEP0000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005Aoo`05001J
EUYFFUH00005FUH01000FUIJEUYF200000=JEP00FUH01UYF3`001EYF00@005YFFUIJEP8000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00004FUH000000002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH3000`Ool005Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF60001EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001GOol30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP02FUH6000HOol400000eYF001J
EP04FUH01@00FUIJEUYF0000;Woo001JOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUH0000300000eYF0000000N
Ool30004FUH01000FUIJEUYF0P00;Goo0018Ool3000BOol50004FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP02FUH30002FUH3000SOol300000eYF001JEP02
FUH2000]Ool004Moo`D001Ioo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00800003
FUH00000008002Uoo`8000=JEP8002eoo`00Agoo1@006Woo00@005YFFUIJEQ<00003FUH005YF00]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH00000
00<002moo`800003FUH0000002eoo`00Agoo1@006Woo00<005YFFUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0`0000=JEP00Ool0<7oo0P0000AJEP00000002eoo`00B7oo0`0077oo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF10000UYF0`00:goo0`000eYF0`00;Goo001YOol30007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000
FUIJEUYF0P000Woo0P000UYF00<005YFFUH01@008Woo100000=JEP00FUH00eYF00<005YF0000;Goo
001[Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUH000001Goo00@005YFFUH000EJEP03001JEP0000<001Uoo`D000EJEP03
001JEUYF009JEP8002ioo`00Agoo2@007Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10001goo00@005YFFUH000EJEP03001JEUYF
00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00?goo200015YF00<005YFFUH0
0UYF20005goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01@0037oo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00=goo20000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPH001Aoo`L000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00IJEPD001=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D000=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008001Qoo``000IJEP03001J
EUYF00YJEP03001JEUYF00H001Yoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH5000cOol0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80029ooaH000mo
o`<0015oo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`00A7oo1@005Goo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020012Ool5001_Ool002eoo`8000AJ
EP04001JEUYFFUH8000IOol60004FUH01@00FUIJEUYF0000@Woo1@00Kgoo000/Ool00`00FUH00003
FUH5000WOol300000eYF001JEP02FUH00`00Oomoo`11Ool3001`Ool002aoo`04001JEP00FUH2000_
Ool20003FUH00`00Oomoo`2dOol002aoo`04001JEP00000cOol200000eYF001oo`2eOol002aoo`@0
03Aoo`<003UooaP006Eoo`00;7oo0P000UYF0`00;goo0`0000=JEP00Ool0<Woo1P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000`00HGoo000/Ool20003FUH00`00FUH00002000YOol3
0002FUH00`00FUH0000`Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH4001MOol002aoo`8000=JEP03001JEUYF009JEPD0021oo`@00003FUH005YF009JEP03
001JEP0002eoo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00@005Uoo`00;Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH8000COol50005
FUH01000FUIJEUYF0P00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00F7oo000^Ool01000FUIJEP001EYF00<0
05YFFUH01EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH0
0000EWoo000_Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH00000:goo0P0015YF00<005YFFUH00UYF1P004Woo20000eYF
00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;7oo00<005YF000015YF00<0
05YF00000P0087oo1@0015YF00D005YFFUIJEP0005Eoo`00=7oo1@001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00;goo00<005YF00000eYF0`00:7oo0`0000=J
EP00FUH00UYF0P00E7oo000iOol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH5000cOol01000FUH005YF0P00;Woo0P000eYF0P00E7oo000mOolI000hOol01000FUH00000<Woo
0P0000=JEP000000E7oo002>Ool200000eYF001oo`0aOol5001DOol008ioo`80009JEP8002ioo`80
009JEP<005Aoo`00SWoo0P000UYF00<005YF00000P009goo100015YF00<005YF0000E7oo002?Ool0
1000FUIJEP0015YF1@006goo1`000eYF00<005YFFUH00UYF0P00EGoo002?Ool01000FUIJEP001EYF
00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8005Ioo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD005Yoo`00Ugoo1@0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Ggoo002LOol90004FUH00`00FUIJ
EP02FUH9001VOol00:Eoo`T006moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76948 m .59613 .7139 L .56496 .712 L p .707 .577 .707 r
F P
0 g
s
.59613 .7139 m .59613 .76948 L .62796 .76871 L p .707 .577 .707 r
F P
0 g
s
.62796 .76871 m .62796 .71312 L .59613 .7139 L p .707 .577 .707 r
F P
0 g
s
.62796 .71312 m .62796 .76871 L .65735 .76533 L p .707 .577 .707 r
F P
0 g
s
.65735 .76533 m .65734 .70975 L .62796 .71312 L p .707 .577 .707 r
F P
0 g
s
.59613 .77306 m .59613 .73601 L .56496 .73411 L p .707 .577 .707 r
F P
0 g
s
.59613 .73601 m .59613 .77306 L .62796 .77228 L p .707 .577 .707 r
F P
0 g
s
.62796 .77228 m .62796 .73523 L .59613 .73601 L p .707 .577 .707 r
F P
0 g
s
.56496 .76758 m .56496 .712 L .5375 .70761 L p .707 .577 .707 r
F P
0 g
s
.56496 .712 m .56496 .76758 L .59613 .76948 L p .707 .577 .707 r
F P
0 g
s
.62796 .73523 m .62796 .77228 L .65735 .7689 L p .707 .577 .707 r
F P
0 g
s
.65735 .7689 m .65734 .73185 L .62796 .73523 L p .707 .577 .707 r
F P
0 g
s
.56496 .77116 m .56496 .73411 L .5375 .72971 L p .707 .577 .707 r
F P
0 g
s
.56496 .73411 m .56496 .77116 L .59613 .77306 L p .707 .577 .707 r
F P
0 g
s
.65734 .70975 m .65735 .76533 L .6814 .75968 L p .707 .577 .707 r
F P
0 g
s
.6814 .75968 m .6814 .7041 L .65734 .70975 L p .707 .577 .707 r
F P
0 g
s
.65734 .73185 m .65735 .7689 L .6814 .76326 L p .707 .577 .707 r
F P
0 g
s
.6814 .76326 m .6814 .7262 L .65734 .73185 L p .707 .577 .707 r
F P
0 g
s
.5375 .70761 m .5375 .76319 L .56496 .76758 L p .707 .577 .707 r
F P
0 g
s
.5375 .76319 m .5375 .70761 L .51644 .70116 L p .707 .577 .707 r
F P
0 g
s
.5375 .72971 m .5375 .76677 L .56496 .77116 L p .707 .577 .707 r
F P
0 g
s
.5375 .76677 m .5375 .72971 L .51644 .72326 L p .707 .577 .707 r
F P
0 g
s
.6814 .7041 m .6814 .75968 L .69777 .75231 L p .707 .577 .707 r
F P
0 g
s
.69777 .75231 m .69777 .69673 L .6814 .7041 L p .707 .577 .707 r
F P
0 g
s
.51644 .70116 m .51644 .75674 L .5375 .76319 L p .707 .577 .707 r
F P
0 g
s
.51644 .72326 m .51644 .76031 L .5375 .76677 L p .707 .577 .707 r
F P
0 g
s
.6814 .7262 m .6814 .76326 L .69777 .75589 L p .707 .577 .707 r
F P
0 g
s
.69777 .75589 m .69777 .71883 L .6814 .7262 L p .707 .577 .707 r
F P
0 g
s
.59613 .88634 m .59613 .86781 L .56496 .86591 L p .707 .577 .707 r
F P
0 g
s
.59613 .86781 m .59613 .88634 L .62796 .88556 L p .707 .577 .707 r
F P
0 g
s
.62796 .88556 m .62796 .86703 L .59613 .86781 L p .707 .577 .707 r
F P
0 g
s
.62796 .86703 m .62796 .88556 L .65735 .88218 L p .707 .577 .707 r
F P
0 g
s
.65735 .88218 m .65735 .86365 L .62796 .86703 L p .707 .577 .707 r
F P
0 g
s
.51644 .75674 m .51644 .70116 L .50385 .69327 L p .707 .577 .707 r
F P
0 g
s
.56496 .86591 m .56496 .88444 L .59613 .88634 L p .707 .577 .707 r
F P
0 g
s
.56496 .88444 m .56496 .86591 L .5375 .86152 L p .707 .577 .707 r
F P
0 g
s
.51644 .76031 m .51644 .72326 L .50385 .71538 L p .707 .577 .707 r
F P
0 g
s
.5375 .86152 m .5375 .88005 L .56496 .88444 L p .707 .577 .707 r
F P
0 g
s
.65735 .86365 m .65735 .88218 L .6814 .87653 L p .707 .577 .707 r
F P
0 g
s
.6814 .87653 m .6814 .858 L .65735 .86365 L p .707 .577 .707 r
F P
0 g
s
.50385 .69327 m .50385 .74885 L .51644 .75674 L p .707 .577 .707 r
F P
0 g
s
.69777 .69673 m .69777 .75231 L .70485 .74395 L p .707 .577 .707 r
F P
0 g
s
.70485 .74395 m .70485 .68836 L .69777 .69673 L p .707 .577 .707 r
F P
0 g
s
.50385 .71538 m .50385 .75243 L .51644 .76031 L p .707 .577 .707 r
F P
0 g
s
.5375 .88005 m .5375 .86152 L .51644 .85506 L p .707 .577 .707 r
F P
0 g
s
.69777 .71883 m .69777 .75589 L .70485 .74752 L p .707 .577 .707 r
F P
0 g
s
.70485 .74752 m .70485 .71047 L .69777 .71883 L p .707 .577 .707 r
F P
0 g
s
.51644 .85506 m .51644 .87359 L .5375 .88005 L p .707 .577 .707 r
F P
0 g
s
.50385 .74885 m .50385 .69327 L .50095 .68473 L p .707 .577 .707 r
F P
0 g
s
.6814 .858 m .6814 .87653 L .69777 .86916 L p .707 .577 .707 r
F P
0 g
s
.69777 .86916 m .69777 .85064 L .6814 .858 L p .707 .577 .707 r
F P
0 g
s
.50385 .75243 m .50385 .71538 L .50095 .70683 L p .707 .577 .707 r
F P
0 g
s
.51644 .87359 m .51644 .85506 L .50385 .84718 L p .707 .577 .707 r
F P
0 g
s
.50095 .68473 m .50095 .74031 L .50385 .74885 L p .707 .577 .707 r
F P
0 g
s
.50095 .70683 m .50095 .74389 L .50385 .75243 L p .707 .577 .707 r
F P
0 g
s
.70485 .68836 m .70485 .74395 L .70195 .7354 L p .707 .577 .707 r
F P
0 g
s
.70195 .7354 m .70195 .67982 L .70485 .68836 L p .707 .577 .707 r
F P
0 g
s
.50385 .84718 m .50385 .86571 L .51644 .87359 L p .707 .577 .707 r
F P
0 g
s
.49044 .81524 m .49044 .31335 L .44643 .31066 L p .707 .577 .707 r
F P
0 g
s
.50095 .74031 m .50095 .68473 L .50804 .67636 L p .707 .577 .707 r
F P
0 g
s
.50095 .74389 m .50095 .70683 L .50804 .69847 L p .707 .577 .707 r
F P
0 g
s
.50804 .67636 m .50804 .73195 L .50095 .74031 L p .707 .577 .707 r
F P
0 g
s
.50804 .69847 m .50804 .73552 L .50095 .74389 L p .707 .577 .707 r
F P
0 g
s
.50804 .73195 m .50804 .67636 L .5244 .669 L p .707 .577 .707 r
F P
0 g
s
.50804 .73552 m .50804 .69847 L .5244 .6911 L p .707 .577 .707 r
F P
0 g
s
.5244 .669 m .5244 .72458 L .50804 .73195 L p .707 .577 .707 r
F P
0 g
s
.5244 .6911 m .5244 .72816 L .50804 .73552 L p .707 .577 .707 r
F P
0 g
s
.5244 .72458 m .5244 .669 L .54846 .66335 L p .707 .577 .707 r
F P
0 g
s
.5244 .72816 m .5244 .6911 L .54846 .68545 L p .707 .577 .707 r
F P
0 g
s
.54846 .66335 m .54846 .71893 L .5244 .72458 L p .707 .577 .707 r
F P
0 g
s
.54846 .68545 m .54846 .72251 L .5244 .72816 L p .707 .577 .707 r
F P
0 g
s
.49044 .31335 m .49044 .81524 L .53538 .81414 L p .707 .577 .707 r
F P
0 g
s
.53538 .81414 m .53538 .31225 L .49044 .31335 L p .707 .577 .707 r
F P
0 g
s
.70485 .71047 m .70485 .74752 L .70195 .73898 L p .707 .577 .707 r
F P
0 g
s
.70195 .73898 m .70195 .70193 L .70485 .71047 L p .707 .577 .707 r
F P
0 g
s
.54846 .71893 m .54846 .66335 L .57784 .65997 L p .707 .577 .707 r
F P
0 g
s
.54846 .72251 m .54846 .68545 L .57784 .68207 L p .707 .577 .707 r
F P
0 g
s
.57784 .65997 m .57784 .71555 L .54846 .71893 L p .707 .577 .707 r
F P
0 g
s
.57784 .68207 m .57784 .71913 L .54846 .72251 L p .707 .577 .707 r
F P
0 g
s
.53538 .31225 m .53538 .81414 L .57686 .80937 L p .707 .577 .707 r
F P
0 g
s
.57686 .80937 m .57686 .30748 L .53538 .31225 L p .707 .577 .707 r
F P
0 g
s
.44643 .81255 m .44643 .31066 L .40766 .30446 L p .707 .577 .707 r
F P
0 g
s
.44643 .31066 m .44643 .81255 L .49044 .81524 L p .707 .577 .707 r
F P
0 g
s
.69777 .85064 m .69777 .86916 L .70485 .8608 L p .707 .577 .707 r
F P
0 g
s
.70485 .8608 m .70485 .84227 L .69777 .85064 L p .707 .577 .707 r
F P
0 g
s
.57784 .71555 m .57784 .65997 L .60968 .65919 L p .707 .577 .707 r
F P
0 g
s
.60968 .65919 m .60968 .71477 L .57784 .71555 L p .707 .577 .707 r
F P
0 g
s
.57784 .71913 m .57784 .68207 L .60968 .6813 L p .707 .577 .707 r
F P
0 g
s
.60968 .6813 m .60968 .71835 L .57784 .71913 L p .707 .577 .707 r
F P
0 g
s
.57686 .30748 m .57686 .80937 L .61082 .80139 L p .707 .577 .707 r
F P
0 g
s
.64085 .66109 m .64085 .71667 L .60968 .71477 L p .707 .577 .707 r
F P
0 g
s
.60968 .71477 m .60968 .65919 L .64085 .66109 L p .707 .577 .707 r
F P
0 g
s
.64085 .6832 m .64085 .72025 L .60968 .71835 L p .707 .577 .707 r
F P
0 g
s
.60968 .71835 m .60968 .6813 L .64085 .6832 L p .707 .577 .707 r
F P
0 g
s
.61082 .80139 m .61082 .2995 L .57686 .30748 L p .707 .577 .707 r
F P
0 g
s
.50385 .86571 m .50385 .84718 L .50095 .83864 L p .707 .577 .707 r
F P
0 g
s
.50095 .83864 m .50095 .85716 L .50385 .86571 L p .707 .577 .707 r
F P
0 g
s
.70195 .67982 m .70195 .7354 L .68936 .72752 L p .707 .577 .707 r
F P
0 g
s
.68936 .72752 m .68936 .67194 L .70195 .67982 L p .707 .577 .707 r
F P
0 g
s
.40766 .80635 m .40766 .30446 L .37794 .29535 L p .707 .577 .707 r
F P
0 g
s
.40766 .30446 m .40766 .80635 L .44643 .81255 L p .707 .577 .707 r
F P
0 g
s
.70195 .70193 m .70195 .73898 L .68936 .7311 L p .707 .577 .707 r
F P
0 g
s
.68936 .7311 m .68936 .69404 L .70195 .70193 L p .707 .577 .707 r
F P
0 g
s
.25312 .73267 m .25312 .67709 L .22195 .67519 L p .707 .577 .707 r
F P
0 g
s
.25312 .67709 m .25312 .73267 L .28495 .73189 L p .707 .577 .707 r
F P
0 g
s
.28495 .73189 m .28495 .67631 L .25312 .67709 L p .707 .577 .707 r
F P
0 g
s
.70485 .84227 m .70485 .8608 L .70195 .85226 L p .707 .577 .707 r
F P
0 g
s
.70195 .85226 m .70195 .83373 L .70485 .84227 L p .707 .577 .707 r
F P
0 g
s
.28495 .67631 m .28495 .73189 L .31434 .72851 L p .707 .577 .707 r
F P
0 g
s
.31434 .72851 m .31434 .67293 L .28495 .67631 L p .707 .577 .707 r
F P
0 g
s
.25312 .73625 m .25312 .69919 L .22195 .69729 L p .707 .577 .707 r
F P
0 g
s
.25312 .69919 m .25312 .73625 L .28495 .73547 L p .707 .577 .707 r
F P
0 g
s
.28495 .73547 m .28495 .69841 L .25312 .69919 L p .707 .577 .707 r
F P
0 g
s
.22195 .73077 m .22195 .67519 L .19449 .67079 L p .707 .577 .707 r
F P
0 g
s
.22195 .67519 m .22195 .73077 L .25312 .73267 L p .707 .577 .707 r
F P
0 g
s
.28495 .69841 m .28495 .73547 L .31434 .73209 L p .707 .577 .707 r
F P
0 g
s
.31434 .73209 m .31434 .69504 L .28495 .69841 L p .707 .577 .707 r
F P
0 g
s
.61082 .2995 m .61082 .80139 L .63393 .79099 L p .707 .577 .707 r
F P
0 g
s
.63393 .79099 m .63393 .2891 L .61082 .2995 L p .707 .577 .707 r
F P
0 g
s
.22195 .73435 m .22195 .69729 L .19449 .6929 L p .707 .577 .707 r
F P
0 g
s
.22195 .69729 m .22195 .73435 L .25312 .73625 L p .707 .577 .707 r
F P
0 g
s
.31434 .67293 m .31434 .72851 L .33839 .72286 L p .707 .577 .707 r
F P
0 g
s
.33839 .72286 m .33839 .66728 L .31434 .67293 L p .707 .577 .707 r
F P
0 g
s
.50095 .85716 m .50095 .83864 L .50804 .83027 L p .707 .577 .707 r
F P
0 g
s
.68936 .67194 m .68936 .72752 L .66831 .72107 L p .707 .577 .707 r
F P
0 g
s
.66831 .72107 m .66831 .66548 L .68936 .67194 L p .707 .577 .707 r
F P
0 g
s
.50804 .83027 m .50804 .8488 L .50095 .85716 L p .707 .577 .707 r
F P
0 g
s
.31434 .69504 m .31434 .73209 L .33839 .72644 L p .707 .577 .707 r
F P
0 g
s
.33839 .72644 m .33839 .68939 L .31434 .69504 L p .707 .577 .707 r
F P
0 g
s
.19449 .67079 m .19449 .72638 L .22195 .73077 L p .707 .577 .707 r
F P
0 g
s
.19449 .72638 m .19449 .67079 L .17343 .66434 L p .707 .577 .707 r
F P
0 g
s
.19449 .6929 m .19449 .72995 L .22195 .73435 L p .707 .577 .707 r
F P
0 g
s
.68936 .69404 m .68936 .7311 L .66831 .72464 L p .707 .577 .707 r
F P
0 g
s
.66831 .72464 m .66831 .68759 L .68936 .69404 L p .707 .577 .707 r
F P
0 g
s
.37794 .79724 m .37794 .29535 L .36016 .28422 L p .707 .577 .707 r
F P
0 g
s
.37794 .29535 m .37794 .79724 L .40766 .80635 L p .707 .577 .707 r
F P
0 g
s
.19449 .72995 m .19449 .6929 L .17343 .68644 L p .707 .577 .707 r
F P
0 g
s
.70195 .83373 m .70195 .85226 L .68936 .84437 L p .707 .577 .707 r
F P
0 g
s
.68936 .84437 m .68936 .82585 L .70195 .83373 L p .707 .577 .707 r
F P
0 g
s
.33839 .66728 m .33839 .72286 L .35476 .7155 L p .707 .577 .707 r
F P
0 g
s
.35476 .7155 m .35476 .65991 L .33839 .66728 L p .707 .577 .707 r
F P
0 g
s
.17343 .66434 m .17343 .71992 L .19449 .72638 L p .707 .577 .707 r
F P
0 g
s
.17343 .68644 m .17343 .7235 L .19449 .72995 L p .707 .577 .707 r
F P
0 g
s
.33839 .68939 m .33839 .72644 L .35476 .71907 L p .707 .577 .707 r
F P
0 g
s
.35476 .71907 m .35476 .68202 L .33839 .68939 L p .707 .577 .707 r
F P
0 g
s
.66831 .66548 m .66831 .72107 L .64085 .71667 L p .707 .577 .707 r
F P
0 g
s
.64085 .71667 m .64085 .66109 L .66831 .66548 L p .707 .577 .707 r
F P
0 g
s
.25312 .84952 m .25312 .831 L .22195 .82909 L p .707 .577 .707 r
F P
0 g
s
.25312 .831 m .25312 .84952 L .28495 .84875 L p .707 .577 .707 r
F P
0 g
s
.28495 .84875 m .28495 .83022 L .25312 .831 L p .707 .577 .707 r
F P
0 g
s
.50804 .8488 m .50804 .83027 L .5244 .82291 L p .707 .577 .707 r
F P
0 g
s
.28495 .83022 m .28495 .84875 L .31434 .84537 L p .707 .577 .707 r
F P
0 g
s
.31434 .84537 m .31434 .82684 L .28495 .83022 L p .707 .577 .707 r
F P
0 g
s
.17343 .71992 m .17343 .66434 L .16084 .65646 L p .707 .577 .707 r
F P
0 g
s
.66831 .68759 m .66831 .72464 L .64085 .72025 L p .707 .577 .707 r
F P
0 g
s
.64085 .72025 m .64085 .6832 L .66831 .68759 L p .707 .577 .707 r
F P
0 g
s
.22195 .82909 m .22195 .84762 L .25312 .84952 L p .707 .577 .707 r
F P
0 g
s
.63393 .2891 m .63393 .79099 L .64393 .77918 L p .707 .577 .707 r
F P
0 g
s
.64393 .77918 m .64393 .27729 L .63393 .2891 L p .707 .577 .707 r
F P
0 g
s
.22195 .84762 m .22195 .82909 L .19449 .8247 L p .707 .577 .707 r
F P
0 g
s
.5244 .82291 m .5244 .84143 L .50804 .8488 L p .707 .577 .707 r
F P
0 g
s
.17343 .7235 m .17343 .68644 L .16084 .67856 L p .707 .577 .707 r
F P
0 g
s
.19449 .8247 m .19449 .84323 L .22195 .84762 L p .707 .577 .707 r
F P
0 g
s
.31434 .82684 m .31434 .84537 L .33839 .83972 L p .707 .577 .707 r
F P
0 g
s
.33839 .83972 m .33839 .82119 L .31434 .82684 L p .707 .577 .707 r
F P
0 g
s
.16084 .65646 m .16084 .71204 L .17343 .71992 L p .707 .577 .707 r
F P
0 g
s
.68936 .82585 m .68936 .84437 L .66831 .83792 L p .707 .577 .707 r
F P
0 g
s
.66831 .83792 m .66831 .81939 L .68936 .82585 L p .707 .577 .707 r
F P
0 g
s
.35476 .65991 m .35476 .7155 L .36184 .70713 L p .707 .577 .707 r
F P
0 g
s
.36184 .70713 m .36184 .65155 L .35476 .65991 L p .707 .577 .707 r
F P
0 g
s
.16084 .67856 m .16084 .71561 L .17343 .7235 L p .707 .577 .707 r
F P
0 g
s
.19449 .84323 m .19449 .8247 L .17343 .81825 L p .707 .577 .707 r
F P
0 g
s
.35476 .68202 m .35476 .71907 L .36184 .71071 L p .707 .577 .707 r
F P
0 g
s
.36184 .71071 m .36184 .67365 L .35476 .68202 L p .707 .577 .707 r
F P
0 g
s
.36184 .65155 m .36184 .70713 L .35894 .69859 L p .707 .577 .707 r
F P
0 g
s
.35894 .69859 m .35894 .64301 L .36184 .65155 L p .707 .577 .707 r
F P
0 g
s
.36184 .67365 m .36184 .71071 L .35894 .70217 L p .707 .577 .707 r
F P
0 g
s
.35894 .70217 m .35894 .66511 L .36184 .67365 L p .707 .577 .707 r
F P
0 g
s
.36016 .78611 m .36016 .28422 L .35607 .27216 L p .707 .577 .707 r
F P
0 g
s
.36016 .28422 m .36016 .78611 L .37794 .79724 L p .707 .577 .707 r
F P
0 g
s
.17343 .81825 m .17343 .83678 L .19449 .84323 L p .707 .577 .707 r
F P
0 g
s
.5244 .84143 m .5244 .82291 L .54846 .81726 L p .707 .577 .707 r
F P
0 g
s
.16084 .71204 m .16084 .65646 L .15794 .64791 L p .707 .577 .707 r
F P
0 g
s
.54846 .81726 m .54846 .83578 L .5244 .84143 L p .707 .577 .707 r
F P
0 g
s
.33839 .82119 m .33839 .83972 L .35476 .83235 L p .707 .577 .707 r
F P
0 g
s
.35476 .83235 m .35476 .81382 L .33839 .82119 L p .707 .577 .707 r
F P
0 g
s
.16084 .71561 m .16084 .67856 L .15794 .67002 L p .707 .577 .707 r
F P
0 g
s
.66831 .81939 m .66831 .83792 L .64085 .83353 L p .707 .577 .707 r
F P
0 g
s
.64085 .83353 m .64085 .815 L .66831 .81939 L p .707 .577 .707 r
F P
0 g
s
.17343 .83678 m .17343 .81825 L .16084 .81036 L p .707 .577 .707 r
F P
0 g
s
.15794 .64791 m .15794 .7035 L .16084 .71204 L p .707 .577 .707 r
F P
0 g
s
.15794 .67002 m .15794 .70707 L .16084 .71561 L p .707 .577 .707 r
F P
0 g
s
.64393 .27729 m .64393 .77918 L .63984 .76712 L p .707 .577 .707 r
F P
0 g
s
.63984 .76712 m .63984 .26523 L .64393 .27729 L p .707 .577 .707 r
F P
0 g
s
.54846 .83578 m .54846 .81726 L .57784 .81388 L p .707 .577 .707 r
F P
0 g
s
.16084 .81036 m .16084 .82889 L .17343 .83678 L p .707 .577 .707 r
F P
0 g
s
.57784 .81388 m .57784 .8324 L .54846 .83578 L p .707 .577 .707 r
F P
0 g
s
.64085 .815 m .64085 .83353 L .60968 .83163 L p .707 .577 .707 r
F P
0 g
s
.60968 .83163 m .60968 .8131 L .64085 .815 L p .707 .577 .707 r
F P
0 g
s
.57784 .8324 m .57784 .81388 L .60968 .8131 L p .707 .577 .707 r
F P
0 g
s
.35476 .81382 m .35476 .83235 L .36184 .82399 L p .707 .577 .707 r
F P
0 g
s
.36184 .82399 m .36184 .80546 L .35476 .81382 L p .707 .577 .707 r
F P
0 g
s
.15794 .7035 m .15794 .64791 L .16503 .63955 L p .707 .577 .707 r
F P
0 g
s
.60968 .8131 m .60968 .83163 L .57784 .8324 L p .707 .577 .707 r
F P
0 g
s
.35894 .64301 m .35894 .69859 L .34635 .6907 L p .707 .577 .707 r
F P
0 g
s
.34635 .6907 m .34635 .63512 L .35894 .64301 L p .707 .577 .707 r
F P
0 g
s
.35894 .66511 m .35894 .70217 L .34635 .69428 L p .707 .577 .707 r
F P
0 g
s
.34635 .69428 m .34635 .65723 L .35894 .66511 L p .707 .577 .707 r
F P
0 g
s
.35607 .27216 m .35607 .77405 L .36016 .78611 L p .707 .577 .707 r
F P
0 g
s
.35607 .77405 m .35607 .27216 L .36607 .26035 L p .707 .577 .707 r
F P
0 g
s
.15794 .70707 m .15794 .67002 L .16503 .66165 L p .707 .577 .707 r
F P
0 g
s
.16084 .82889 m .16084 .81036 L .15794 .80182 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .63955 m .16503 .69513 L .15794 .7035 L p .707 .577 .707 r
F P
0 g
s
.16503 .66165 m .16503 .69871 L .15794 .70707 L p .707 .577 .707 r
F P
0 g
s
.15794 .80182 m .15794 .82035 L .16084 .82889 L p .707 .577 .707 r
F P
0 g
s
.36184 .80546 m .36184 .82399 L .35894 .81544 L p .707 .577 .707 r
F P
0 g
s
.35894 .81544 m .35894 .79692 L .36184 .80546 L p .707 .577 .707 r
F P
0 g
s
.63984 .26523 m .63984 .76712 L .62206 .75599 L p .707 .577 .707 r
F P
0 g
s
.62206 .75599 m .62206 .2541 L .63984 .26523 L p .707 .577 .707 r
F P
0 g
s
.16503 .69513 m .16503 .63955 L .1814 .63218 L p .707 .577 .707 r
F P
0 g
s
.16503 .69871 m .16503 .66165 L .1814 .65429 L p .707 .577 .707 r
F P
0 g
s
.15794 .82035 m .15794 .80182 L .16503 .79346 L p .707 .577 .707 r
F P
0 g
s
.1814 .63218 m .1814 .68776 L .16503 .69513 L p .707 .577 .707 r
F P
0 g
s
.34635 .63512 m .34635 .6907 L .3253 .68425 L p .707 .577 .707 r
F P
0 g
s
.3253 .68425 m .3253 .62867 L .34635 .63512 L p .707 .577 .707 r
F P
0 g
s
.1814 .65429 m .1814 .69134 L .16503 .69871 L p .707 .577 .707 r
F P
0 g
s
.36607 .76224 m .36607 .26035 L .38918 .24995 L p .707 .577 .707 r
F P
0 g
s
.36607 .26035 m .36607 .76224 L .35607 .77405 L p .707 .577 .707 r
F P
0 g
s
.16503 .79346 m .16503 .81199 L .15794 .82035 L p .707 .577 .707 r
F P
0 g
s
.34635 .65723 m .34635 .69428 L .3253 .68783 L p .707 .577 .707 r
F P
0 g
s
.3253 .68783 m .3253 .65077 L .34635 .65723 L p .707 .577 .707 r
F P
0 g
s
.1814 .68776 m .1814 .63218 L .20545 .62653 L p .707 .577 .707 r
F P
0 g
s
.35894 .79692 m .35894 .81544 L .34635 .80756 L p .707 .577 .707 r
F P
0 g
s
.34635 .80756 m .34635 .78903 L .35894 .79692 L p .707 .577 .707 r
F P
0 g
s
.1814 .69134 m .1814 .65429 L .20545 .64864 L p .707 .577 .707 r
F P
0 g
s
.3253 .62867 m .3253 .68425 L .29784 .67986 L p .707 .577 .707 r
F P
0 g
s
.29784 .67986 m .29784 .62428 L .3253 .62867 L p .707 .577 .707 r
F P
0 g
s
.62206 .2541 m .62206 .75599 L .59233 .74688 L p .707 .577 .707 r
F P
0 g
s
.59233 .74688 m .59233 .24499 L .62206 .2541 L p .707 .577 .707 r
F P
0 g
s
.20545 .62653 m .20545 .68211 L .1814 .68776 L p .707 .577 .707 r
F P
0 g
s
.16503 .81199 m .16503 .79346 L .1814 .78609 L p .707 .577 .707 r
F P
0 g
s
.20545 .64864 m .20545 .68569 L .1814 .69134 L p .707 .577 .707 r
F P
0 g
s
.3253 .65077 m .3253 .68783 L .29784 .68344 L p .707 .577 .707 r
F P
0 g
s
.29784 .68344 m .29784 .64638 L .3253 .65077 L p .707 .577 .707 r
F P
0 g
s
.20545 .68211 m .20545 .62653 L .23483 .62315 L p .707 .577 .707 r
F P
0 g
s
.1814 .78609 m .1814 .80462 L .16503 .81199 L p .707 .577 .707 r
F P
0 g
s
.20545 .68569 m .20545 .64864 L .23483 .64526 L p .707 .577 .707 r
F P
0 g
s
.38918 .24995 m .38918 .75184 L .36607 .76224 L p .707 .577 .707 r
F P
0 g
s
.38918 .75184 m .38918 .24995 L .42314 .24197 L p .707 .577 .707 r
F P
0 g
s
.29784 .62428 m .29784 .67986 L .26667 .67796 L p .707 .577 .707 r
F P
0 g
s
.26667 .67796 m .26667 .62238 L .29784 .62428 L p .707 .577 .707 r
F P
0 g
s
.34635 .78903 m .34635 .80756 L .3253 .8011 L p .707 .577 .707 r
F P
0 g
s
.3253 .8011 m .3253 .78258 L .34635 .78903 L p .707 .577 .707 r
F P
0 g
s
.23483 .67873 m .23483 .62315 L .26667 .62238 L p .707 .577 .707 r
F P
0 g
s
.23483 .62315 m .23483 .67873 L .20545 .68211 L p .707 .577 .707 r
F P
0 g
s
.29784 .64638 m .29784 .68344 L .26667 .68153 L p .707 .577 .707 r
F P
0 g
s
.26667 .68153 m .26667 .64448 L .29784 .64638 L p .707 .577 .707 r
F P
0 g
s
.26667 .62238 m .26667 .67796 L .23483 .67873 L p .707 .577 .707 r
F P
0 g
s
.23483 .64526 m .23483 .68231 L .20545 .68569 L p .707 .577 .707 r
F P
0 g
s
.73333 .67745 m .73333 .62186 L .70216 .61996 L p .707 .577 .707 r
F P
0 g
s
.73333 .62186 m .73333 .67745 L .76517 .67667 L p .707 .577 .707 r
F P
0 g
s
.76517 .67667 m .76517 .62109 L .73333 .62186 L p .707 .577 .707 r
F P
0 g
s
.23483 .68231 m .23483 .64526 L .26667 .64448 L p .707 .577 .707 r
F P
0 g
s
.76517 .62109 m .76517 .67667 L .79455 .67329 L p .707 .577 .707 r
F P
0 g
s
.79455 .67329 m .79455 .61771 L .76517 .62109 L p .707 .577 .707 r
F P
0 g
s
.26667 .64448 m .26667 .68153 L .23483 .68231 L p .707 .577 .707 r
F P
0 g
s
.1814 .80462 m .1814 .78609 L .20545 .78044 L p .707 .577 .707 r
F P
0 g
s
.73333 .68102 m .73333 .64397 L .70216 .64207 L p .707 .577 .707 r
F P
0 g
s
.73333 .64397 m .73333 .68102 L .76517 .68025 L p .707 .577 .707 r
F P
0 g
s
.76517 .68025 m .76517 .64319 L .73333 .64397 L p .707 .577 .707 r
F P
0 g
s
.70216 .67555 m .70216 .61996 L .6747 .61557 L p .707 .577 .707 r
F P
0 g
s
.70216 .61996 m .70216 .67555 L .73333 .67745 L p .707 .577 .707 r
F P
0 g
s
.76517 .64319 m .76517 .68025 L .79455 .67687 L p .707 .577 .707 r
F P
0 g
s
.79455 .67687 m .79455 .63981 L .76517 .64319 L p .707 .577 .707 r
F P
0 g
s
.59233 .24499 m .59233 .74688 L .55357 .74068 L p .707 .577 .707 r
F P
0 g
s
.55357 .74068 m .55357 .23879 L .59233 .24499 L p .707 .577 .707 r
F P
0 g
s
.20545 .78044 m .20545 .79897 L .1814 .80462 L p .707 .577 .707 r
F P
0 g
s
.70216 .67912 m .70216 .64207 L .6747 .63768 L p .707 .577 .707 r
F P
0 g
s
.70216 .64207 m .70216 .67912 L .73333 .68102 L p .707 .577 .707 r
F P
0 g
s
.79455 .61771 m .79455 .67329 L .8186 .66764 L p .707 .577 .707 r
F P
0 g
s
.8186 .66764 m .8186 .61206 L .79455 .61771 L p .707 .577 .707 r
F P
0 g
s
.3253 .78258 m .3253 .8011 L .29784 .79671 L p .707 .577 .707 r
F P
0 g
s
.29784 .79671 m .29784 .77819 L .3253 .78258 L p .707 .577 .707 r
F P
0 g
s
.42314 .74386 m .42314 .24197 L .46462 .2372 L p .707 .577 .707 r
F P
0 g
s
.42314 .24197 m .42314 .74386 L .38918 .75184 L p .707 .577 .707 r
F P
0 g
s
.79455 .63981 m .79455 .67687 L .8186 .67122 L p .707 .577 .707 r
F P
0 g
s
.8186 .67122 m .8186 .63416 L .79455 .63981 L p .707 .577 .707 r
F P
0 g
s
.6747 .61557 m .6747 .67115 L .70216 .67555 L p .707 .577 .707 r
F P
0 g
s
.6747 .67115 m .6747 .61557 L .65365 .60912 L p .707 .577 .707 r
F P
0 g
s
.6747 .63768 m .6747 .67473 L .70216 .67912 L p .707 .577 .707 r
F P
0 g
s
.20545 .79897 m .20545 .78044 L .23483 .77706 L p .707 .577 .707 r
F P
0 g
s
.6747 .67473 m .6747 .63768 L .65365 .63122 L p .707 .577 .707 r
F P
0 g
s
.23483 .77706 m .23483 .79559 L .20545 .79897 L p .707 .577 .707 r
F P
0 g
s
.55357 .23879 m .55357 .74068 L .50956 .738 L p .707 .577 .707 r
F P
0 g
s
.50956 .738 m .50956 .23611 L .55357 .23879 L p .707 .577 .707 r
F P
0 g
s
.29784 .77819 m .29784 .79671 L .26667 .79481 L p .707 .577 .707 r
F P
0 g
s
.26667 .79481 m .26667 .77628 L .29784 .77819 L p .707 .577 .707 r
F P
0 g
s
.8186 .61206 m .8186 .66764 L .83497 .66027 L p .707 .577 .707 r
F P
0 g
s
.83497 .66027 m .83497 .60469 L .8186 .61206 L p .707 .577 .707 r
F P
0 g
s
.46462 .73909 m .46462 .2372 L .50956 .23611 L p .707 .577 .707 r
F P
0 g
s
.46462 .2372 m .46462 .73909 L .42314 .74386 L p .707 .577 .707 r
F P
0 g
s
.65365 .60912 m .65365 .6647 L .6747 .67115 L p .707 .577 .707 r
F P
0 g
s
.23483 .79559 m .23483 .77706 L .26667 .77628 L p .707 .577 .707 r
F P
0 g
s
.65365 .63122 m .65365 .66828 L .6747 .67473 L p .707 .577 .707 r
F P
0 g
s
.50956 .23611 m .50956 .738 L .46462 .73909 L p .707 .577 .707 r
F P
0 g
s
.26667 .77628 m .26667 .79481 L .23483 .79559 L p .707 .577 .707 r
F P
0 g
s
.8186 .63416 m .8186 .67122 L .83497 .66385 L p .707 .577 .707 r
F P
0 g
s
.83497 .66385 m .83497 .62679 L .8186 .63416 L p .707 .577 .707 r
F P
0 g
s
.73333 .7943 m .73333 .77577 L .70216 .77387 L p .707 .577 .707 r
F P
0 g
s
.73333 .77577 m .73333 .7943 L .76517 .79352 L p .707 .577 .707 r
F P
0 g
s
.76517 .79352 m .76517 .775 L .73333 .77577 L p .707 .577 .707 r
F P
0 g
s
.76517 .775 m .76517 .79352 L .79455 .79014 L p .707 .577 .707 r
F P
0 g
s
.79455 .79014 m .79455 .77162 L .76517 .775 L p .707 .577 .707 r
F P
0 g
s
.65365 .6647 m .65365 .60912 L .64105 .60123 L p .707 .577 .707 r
F P
0 g
s
.70216 .77387 m .70216 .7924 L .73333 .7943 L p .707 .577 .707 r
F P
0 g
s
.70216 .7924 m .70216 .77387 L .6747 .76948 L p .707 .577 .707 r
F P
0 g
s
.65365 .66828 m .65365 .63122 L .64105 .62334 L p .707 .577 .707 r
F P
0 g
s
.6747 .76948 m .6747 .78801 L .70216 .7924 L p .707 .577 .707 r
F P
0 g
s
.79455 .77162 m .79455 .79014 L .8186 .78449 L p .707 .577 .707 r
F P
0 g
s
.8186 .78449 m .8186 .76597 L .79455 .77162 L p .707 .577 .707 r
F P
0 g
s
.64105 .60123 m .64105 .65681 L .65365 .6647 L p .707 .577 .707 r
F P
0 g
s
.83497 .60469 m .83497 .66027 L .84205 .65191 L p .707 .577 .707 r
F P
0 g
s
.84205 .65191 m .84205 .59633 L .83497 .60469 L p .707 .577 .707 r
F P
0 g
s
.64105 .62334 m .64105 .66039 L .65365 .66828 L p .707 .577 .707 r
F P
0 g
s
.6747 .78801 m .6747 .76948 L .65365 .76303 L p .707 .577 .707 r
F P
0 g
s
.83497 .62679 m .83497 .66385 L .84205 .65548 L p .707 .577 .707 r
F P
0 g
s
.84205 .65548 m .84205 .61843 L .83497 .62679 L p .707 .577 .707 r
F P
0 g
s
.65365 .76303 m .65365 .78155 L .6747 .78801 L p .707 .577 .707 r
F P
0 g
s
.64105 .65681 m .64105 .60123 L .63816 .59269 L p .707 .577 .707 r
F P
0 g
s
.8186 .76597 m .8186 .78449 L .83497 .77713 L p .707 .577 .707 r
F P
0 g
s
.83497 .77713 m .83497 .7586 L .8186 .76597 L p .707 .577 .707 r
F P
0 g
s
.64105 .66039 m .64105 .62334 L .63816 .61479 L p .707 .577 .707 r
F P
0 g
s
.65365 .78155 m .65365 .76303 L .64105 .75514 L p .707 .577 .707 r
F P
0 g
s
.63816 .59269 m .63816 .64827 L .64105 .65681 L p .707 .577 .707 r
F P
0 g
s
.63816 .61479 m .63816 .65185 L .64105 .66039 L p .707 .577 .707 r
F P
0 g
s
.84205 .59633 m .84205 .65191 L .83916 .64337 L p .707 .577 .707 r
F P
0 g
s
.83916 .64337 m .83916 .58778 L .84205 .59633 L p .707 .577 .707 r
F P
0 g
s
.64105 .75514 m .64105 .77367 L .65365 .78155 L p .707 .577 .707 r
F P
0 g
s
.84205 .61843 m .84205 .65548 L .83916 .64694 L p .707 .577 .707 r
F P
0 g
s
.83916 .64694 m .83916 .60989 L .84205 .61843 L p .707 .577 .707 r
F P
0 g
s
.83497 .7586 m .83497 .77713 L .84206 .76876 L p .707 .577 .707 r
F P
0 g
s
.84206 .76876 m .84206 .75023 L .83497 .7586 L p .707 .577 .707 r
F P
0 g
s
.63816 .64827 m .63816 .59269 L .64524 .58433 L p .707 .577 .707 r
F P
0 g
s
.63816 .65185 m .63816 .61479 L .64524 .60643 L p .707 .577 .707 r
F P
0 g
s
.64105 .77367 m .64105 .75514 L .63816 .7466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .58433 m .64524 .63991 L .63816 .64827 L p .707 .577 .707 r
F P
0 g
s
.64524 .60643 m .64524 .64349 L .63816 .65185 L p .707 .577 .707 r
F P
0 g
s
.63816 .7466 m .63816 .76513 L .64105 .77367 L p .707 .577 .707 r
F P
0 g
s
.83916 .58778 m .83916 .64337 L .82657 .63548 L p .707 .577 .707 r
F P
0 g
s
.82657 .63548 m .82657 .5799 L .83916 .58778 L p .707 .577 .707 r
F P
0 g
s
.83916 .60989 m .83916 .64694 L .82657 .63906 L p .707 .577 .707 r
F P
0 g
s
.82657 .63906 m .82657 .602 L .83916 .60989 L p .707 .577 .707 r
F P
0 g
s
.39032 .64063 m .39032 .58505 L .35915 .58315 L p .707 .577 .707 r
F P
0 g
s
.39032 .58505 m .39032 .64063 L .42216 .63985 L p .707 .577 .707 r
F P
0 g
s
.42216 .63985 m .42216 .58427 L .39032 .58505 L p .707 .577 .707 r
F P
0 g
s
.84206 .75023 m .84206 .76876 L .83916 .76022 L p .707 .577 .707 r
F P
0 g
s
.83916 .76022 m .83916 .74169 L .84206 .75023 L p .707 .577 .707 r
F P
0 g
s
.64524 .63991 m .64524 .58433 L .66161 .57696 L p .707 .577 .707 r
F P
0 g
s
.42216 .58427 m .42216 .63985 L .45154 .63647 L p .707 .577 .707 r
F P
0 g
s
.45154 .63647 m .45154 .58089 L .42216 .58427 L p .707 .577 .707 r
F P
0 g
s
.39032 .64421 m .39032 .60715 L .35915 .60525 L p .707 .577 .707 r
F P
0 g
s
.39032 .60715 m .39032 .64421 L .42216 .64343 L p .707 .577 .707 r
F P
0 g
s
.42216 .64343 m .42216 .60638 L .39032 .60715 L p .707 .577 .707 r
F P
0 g
s
.35915 .63873 m .35915 .58315 L .33169 .57876 L p .707 .577 .707 r
F P
0 g
s
.35915 .58315 m .35915 .63873 L .39032 .64063 L p .707 .577 .707 r
F P
0 g
s
.64524 .64349 m .64524 .60643 L .66161 .59906 L p .707 .577 .707 r
F P
0 g
s
.42216 .60638 m .42216 .64343 L .45154 .64005 L p .707 .577 .707 r
F P
0 g
s
.45154 .64005 m .45154 .603 L .42216 .60638 L p .707 .577 .707 r
F P
0 g
s
.35915 .64231 m .35915 .60525 L .33169 .60086 L p .707 .577 .707 r
F P
0 g
s
.35915 .60525 m .35915 .64231 L .39032 .64421 L p .707 .577 .707 r
F P
0 g
s
.45154 .58089 m .45154 .63647 L .47559 .63082 L p .707 .577 .707 r
F P
0 g
s
.47559 .63082 m .47559 .57524 L .45154 .58089 L p .707 .577 .707 r
F P
0 g
s
.63816 .76513 m .63816 .7466 L .64524 .73824 L p .707 .577 .707 r
F P
0 g
s
.66161 .57696 m .66161 .63254 L .64524 .63991 L p .707 .577 .707 r
F P
0 g
s
.82657 .5799 m .82657 .63548 L .80551 .62903 L p .707 .577 .707 r
F P
0 g
s
.80551 .62903 m .80551 .57344 L .82657 .5799 L p .707 .577 .707 r
F P
0 g
s
.66161 .59906 m .66161 .63612 L .64524 .64349 L p .707 .577 .707 r
F P
0 g
s
.64524 .73824 m .64524 .75676 L .63816 .76513 L p .707 .577 .707 r
F P
0 g
s
.45154 .603 m .45154 .64005 L .47559 .6344 L p .707 .577 .707 r
F P
0 g
s
.47559 .6344 m .47559 .59735 L .45154 .603 L p .707 .577 .707 r
F P
0 g
s
.33169 .57876 m .33169 .63434 L .35915 .63873 L p .707 .577 .707 r
F P
0 g
s
.33169 .63434 m .33169 .57876 L .31064 .5723 L p .707 .577 .707 r
F P
0 g
s
.33169 .60086 m .33169 .63791 L .35915 .64231 L p .707 .577 .707 r
F P
0 g
s
.82657 .602 m .82657 .63906 L .80551 .6326 L p .707 .577 .707 r
F P
0 g
s
.80551 .6326 m .80551 .59555 L .82657 .602 L p .707 .577 .707 r
F P
0 g
s
.33169 .63791 m .33169 .60086 L .31064 .59441 L p .707 .577 .707 r
F P
0 g
s
.66161 .63254 m .66161 .57696 L .68566 .57131 L p .707 .577 .707 r
F P
0 g
s
.83916 .74169 m .83916 .76022 L .82657 .75234 L p .707 .577 .707 r
F P
0 g
s
.82657 .75234 m .82657 .73381 L .83916 .74169 L p .707 .577 .707 r
F P
0 g
s
.66161 .63612 m .66161 .59906 L .68566 .59341 L p .707 .577 .707 r
F P
0 g
s
.47559 .57524 m .47559 .63082 L .49196 .62346 L p .707 .577 .707 r
F P
0 g
s
.49196 .62346 m .49196 .56787 L .47559 .57524 L p .707 .577 .707 r
F P
0 g
s
.31064 .5723 m .31064 .62788 L .33169 .63434 L p .707 .577 .707 r
F P
0 g
s
.31064 .59441 m .31064 .63146 L .33169 .63791 L p .707 .577 .707 r
F P
0 g
s
.47559 .59735 m .47559 .6344 L .49196 .62703 L p .707 .577 .707 r
F P
0 g
s
.49196 .62703 m .49196 .58998 L .47559 .59735 L p .707 .577 .707 r
F P
0 g
s
.80551 .57344 m .80551 .62903 L .77805 .62463 L p .707 .577 .707 r
F P
0 g
s
.77805 .62463 m .77805 .56905 L .80551 .57344 L p .707 .577 .707 r
F P
0 g
s
.39032 .75748 m .39032 .73896 L .35915 .73706 L p .707 .577 .707 r
F P
0 g
s
.39032 .73896 m .39032 .75748 L .42216 .75671 L p .707 .577 .707 r
F P
0 g
s
.42216 .75671 m .42216 .73818 L .39032 .73896 L p .707 .577 .707 r
F P
0 g
s
.68566 .57131 m .68566 .62689 L .66161 .63254 L p .707 .577 .707 r
F P
0 g
s
.64524 .75676 m .64524 .73824 L .66161 .73087 L p .707 .577 .707 r
F P
0 g
s
.68566 .59341 m .68566 .63047 L .66161 .63612 L p .707 .577 .707 r
F P
0 g
s
.42216 .73818 m .42216 .75671 L .45154 .75333 L p .707 .577 .707 r
F P
0 g
s
.45154 .75333 m .45154 .7348 L .42216 .73818 L p .707 .577 .707 r
F P
0 g
s
.31064 .62788 m .31064 .5723 L .29804 .56442 L p .707 .577 .707 r
F P
0 g
s
.80551 .59555 m .80551 .6326 L .77805 .62821 L p .707 .577 .707 r
F P
0 g
s
.77805 .62821 m .77805 .59116 L .80551 .59555 L p .707 .577 .707 r
F P
0 g
s
.35915 .73706 m .35915 .75558 L .39032 .75748 L p .707 .577 .707 r
F P
0 g
s
.68566 .62689 m .68566 .57131 L .71504 .56793 L p .707 .577 .707 r
F P
0 g
s
.35915 .75558 m .35915 .73706 L .33169 .73266 L p .707 .577 .707 r
F P
0 g
s
.66161 .73087 m .66161 .74939 L .64524 .75676 L p .707 .577 .707 r
F P
0 g
s
.31064 .63146 m .31064 .59441 L .29804 .58652 L p .707 .577 .707 r
F P
0 g
s
.33169 .73266 m .33169 .75119 L .35915 .75558 L p .707 .577 .707 r
F P
0 g
s
.68566 .63047 m .68566 .59341 L .71504 .59003 L p .707 .577 .707 r
F P
0 g
s
.77805 .56905 m .77805 .62463 L .74688 .62273 L p .707 .577 .707 r
F P
0 g
s
.74688 .62273 m .74688 .56715 L .77805 .56905 L p .707 .577 .707 r
F P
0 g
s
.45154 .7348 m .45154 .75333 L .47559 .74768 L p .707 .577 .707 r
F P
0 g
s
.47559 .74768 m .47559 .72915 L .45154 .7348 L p .707 .577 .707 r
F P
0 g
s
.29804 .56442 m .29804 .62 L .31064 .62788 L p .707 .577 .707 r
F P
0 g
s
.82657 .73381 m .82657 .75234 L .80551 .74588 L p .707 .577 .707 r
F P
0 g
s
.80551 .74588 m .80551 .72735 L .82657 .73381 L p .707 .577 .707 r
F P
0 g
s
.71504 .62351 m .71504 .56793 L .74688 .56715 L p .707 .577 .707 r
F P
0 g
s
.71504 .56793 m .71504 .62351 L .68566 .62689 L p .707 .577 .707 r
F P
0 g
s
.49196 .56787 m .49196 .62346 L .49904 .61509 L p .707 .577 .707 r
F P
0 g
s
.49904 .61509 m .49904 .55951 L .49196 .56787 L p .707 .577 .707 r
F P
0 g
s
.29804 .58652 m .29804 .62358 L .31064 .63146 L p .707 .577 .707 r
F P
0 g
s
.77805 .59116 m .77805 .62821 L .74688 .62631 L p .707 .577 .707 r
F P
0 g
s
.74688 .62631 m .74688 .58926 L .77805 .59116 L p .707 .577 .707 r
F P
0 g
s
.74688 .56715 m .74688 .62273 L .71504 .62351 L p .707 .577 .707 r
F P
0 g
s
.33169 .75119 m .33169 .73266 L .31064 .72621 L p .707 .577 .707 r
F P
0 g
s
.71504 .59003 m .71504 .62709 L .68566 .63047 L p .707 .577 .707 r
F P
0 g
s
.71504 .62709 m .71504 .59003 L .74688 .58926 L p .707 .577 .707 r
F P
0 g
s
.49196 .58998 m .49196 .62703 L .49904 .61867 L p .707 .577 .707 r
F P
0 g
s
.49904 .61867 m .49904 .58161 L .49196 .58998 L p .707 .577 .707 r
F P
0 g
s
.74688 .58926 m .74688 .62631 L .71504 .62709 L p .707 .577 .707 r
F P
0 g
s
.31064 .72621 m .31064 .74474 L .33169 .75119 L p .707 .577 .707 r
F P
0 g
s
.66161 .74939 m .66161 .73087 L .68566 .72522 L p .707 .577 .707 r
F P
0 g
s
.29804 .62 m .29804 .56442 L .29515 .55587 L p .707 .577 .707 r
F P
0 g
s
.68566 .72522 m .68566 .74375 L .66161 .74939 L p .707 .577 .707 r
F P
0 g
s
.47559 .72915 m .47559 .74768 L .49196 .74031 L p .707 .577 .707 r
F P
0 g
s
.49196 .74031 m .49196 .72178 L .47559 .72915 L p .707 .577 .707 r
F P
0 g
s
.29804 .62358 m .29804 .58652 L .29515 .57798 L p .707 .577 .707 r
F P
0 g
s
.80551 .72735 m .80551 .74588 L .77805 .74149 L p .707 .577 .707 r
F P
0 g
s
.77805 .74149 m .77805 .72296 L .80551 .72735 L p .707 .577 .707 r
F P
0 g
s
.31064 .74474 m .31064 .72621 L .29804 .71833 L p .707 .577 .707 r
F P
0 g
s
.29515 .55587 m .29515 .61146 L .29804 .62 L p .707 .577 .707 r
F P
0 g
s
.29515 .57798 m .29515 .61503 L .29804 .62358 L p .707 .577 .707 r
F P
0 g
s
.49904 .55951 m .49904 .61509 L .49615 .60655 L p .707 .577 .707 r
F P
0 g
s
.49615 .60655 m .49615 .55097 L .49904 .55951 L p .707 .577 .707 r
F P
0 g
s
.68566 .74375 m .68566 .72522 L .71504 .72184 L p .707 .577 .707 r
F P
0 g
s
.29804 .71833 m .29804 .73685 L .31064 .74474 L p .707 .577 .707 r
F P
0 g
s
.71504 .72184 m .71504 .74037 L .68566 .74375 L p .707 .577 .707 r
F P
0 g
s
.49904 .58161 m .49904 .61867 L .49615 .61013 L p .707 .577 .707 r
F P
0 g
s
.49615 .61013 m .49615 .57307 L .49904 .58161 L p .707 .577 .707 r
F P
0 g
s
.77805 .72296 m .77805 .74149 L .74688 .73959 L p .707 .577 .707 r
F P
0 g
s
.74688 .73959 m .74688 .72106 L .77805 .72296 L p .707 .577 .707 r
F P
0 g
s
.71504 .74037 m .71504 .72184 L .74688 .72106 L p .707 .577 .707 r
F P
0 g
s
.49196 .72178 m .49196 .74031 L .49904 .73195 L p .707 .577 .707 r
F P
0 g
s
.49904 .73195 m .49904 .71342 L .49196 .72178 L p .707 .577 .707 r
F P
0 g
s
.29515 .61146 m .29515 .55587 L .30223 .54751 L p .707 .577 .707 r
F P
0 g
s
.74688 .72106 m .74688 .73959 L .71504 .74037 L p .707 .577 .707 r
F P
0 g
s
.29515 .61503 m .29515 .57798 L .30223 .56961 L p .707 .577 .707 r
F P
0 g
s
.29804 .73685 m .29804 .71833 L .29515 .70978 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .54751 m .30223 .60309 L .29515 .61146 L p .707 .577 .707 r
F P
0 g
s
.30223 .56961 m .30223 .60667 L .29515 .61503 L p .707 .577 .707 r
F P
0 g
s
.29515 .70978 m .29515 .72831 L .29804 .73685 L p .707 .577 .707 r
F P
0 g
s
.49615 .55097 m .49615 .60655 L .48356 .59867 L p .707 .577 .707 r
F P
0 g
s
.48356 .59867 m .48356 .54308 L .49615 .55097 L p .707 .577 .707 r
F P
0 g
s
.49615 .57307 m .49615 .61013 L .48356 .60224 L p .707 .577 .707 r
F P
0 g
s
.48356 .60224 m .48356 .56519 L .49615 .57307 L p .707 .577 .707 r
F P
0 g
s
.49904 .71342 m .49904 .73195 L .49615 .7234 L p .707 .577 .707 r
F P
0 g
s
.49615 .7234 m .49615 .70488 L .49904 .71342 L p .707 .577 .707 r
F P
0 g
s
.30223 .60309 m .30223 .54751 L .3186 .54014 L p .707 .577 .707 r
F P
0 g
s
.30223 .60667 m .30223 .56961 L .3186 .56225 L p .707 .577 .707 r
F P
0 g
s
.29515 .72831 m .29515 .70978 L .30223 .70142 L p .707 .577 .707 r
F P
0 g
s
.3186 .54014 m .3186 .59572 L .30223 .60309 L p .707 .577 .707 r
F P
0 g
s
.48356 .54308 m .48356 .59867 L .4625 .59221 L p .707 .577 .707 r
F P
0 g
s
.4625 .59221 m .4625 .53663 L .48356 .54308 L p .707 .577 .707 r
F P
0 g
s
.3186 .56225 m .3186 .5993 L .30223 .60667 L p .707 .577 .707 r
F P
0 g
s
.30223 .70142 m .30223 .71995 L .29515 .72831 L p .707 .577 .707 r
F P
0 g
s
.48356 .56519 m .48356 .60224 L .4625 .59579 L p .707 .577 .707 r
F P
0 g
s
.4625 .59579 m .4625 .55873 L .48356 .56519 L p .707 .577 .707 r
F P
0 g
s
.3186 .59572 m .3186 .54014 L .34265 .53449 L p .707 .577 .707 r
F P
0 g
s
.49615 .70488 m .49615 .7234 L .48356 .71552 L p .707 .577 .707 r
F P
0 g
s
.48356 .71552 m .48356 .69699 L .49615 .70488 L p .707 .577 .707 r
F P
0 g
s
.3186 .5993 m .3186 .56225 L .34265 .5566 L p .707 .577 .707 r
F P
0 g
s
.4625 .53663 m .4625 .59221 L .43504 .58782 L p .707 .577 .707 r
F P
0 g
s
.43504 .58782 m .43504 .53224 L .4625 .53663 L p .707 .577 .707 r
F P
0 g
s
.34265 .53449 m .34265 .59007 L .3186 .59572 L p .707 .577 .707 r
F P
0 g
s
.30223 .71995 m .30223 .70142 L .3186 .69405 L p .707 .577 .707 r
F P
0 g
s
.34265 .5566 m .34265 .59365 L .3186 .5993 L p .707 .577 .707 r
F P
0 g
s
.4625 .55873 m .4625 .59579 L .43504 .5914 L p .707 .577 .707 r
F P
0 g
s
.43504 .5914 m .43504 .55434 L .4625 .55873 L p .707 .577 .707 r
F P
0 g
s
.34265 .59007 m .34265 .53449 L .37203 .53111 L p .707 .577 .707 r
F P
0 g
s
.3186 .69405 m .3186 .71258 L .30223 .71995 L p .707 .577 .707 r
F P
0 g
s
.34265 .59365 m .34265 .5566 L .37203 .55322 L p .707 .577 .707 r
F P
0 g
s
.43504 .53224 m .43504 .58782 L .40387 .58592 L p .707 .577 .707 r
F P
0 g
s
.40387 .58592 m .40387 .53034 L .43504 .53224 L p .707 .577 .707 r
F P
0 g
s
.48356 .69699 m .48356 .71552 L .4625 .70907 L p .707 .577 .707 r
F P
0 g
s
.4625 .70907 m .4625 .69054 L .48356 .69699 L p .707 .577 .707 r
F P
0 g
s
.37203 .5867 m .37203 .53111 L .40387 .53034 L p .707 .577 .707 r
F P
0 g
s
.37203 .53111 m .37203 .5867 L .34265 .59007 L p .707 .577 .707 r
F P
0 g
s
.43504 .55434 m .43504 .5914 L .40387 .5895 L p .707 .577 .707 r
F P
0 g
s
.40387 .5895 m .40387 .55244 L .43504 .55434 L p .707 .577 .707 r
F P
0 g
s
.40387 .53034 m .40387 .58592 L .37203 .5867 L p .707 .577 .707 r
F P
0 g
s
.37203 .55322 m .37203 .59027 L .34265 .59365 L p .707 .577 .707 r
F P
0 g
s
.37203 .59027 m .37203 .55322 L .40387 .55244 L p .707 .577 .707 r
F P
0 g
s
.40387 .55244 m .40387 .5895 L .37203 .59027 L p .707 .577 .707 r
F P
0 g
s
.3186 .71258 m .3186 .69405 L .34265 .6884 L p .707 .577 .707 r
F P
0 g
s
.34265 .6884 m .34265 .70693 L .3186 .71258 L p .707 .577 .707 r
F P
0 g
s
.4625 .69054 m .4625 .70907 L .43504 .70467 L p .707 .577 .707 r
F P
0 g
s
.43504 .70467 m .43504 .68615 L .4625 .69054 L p .707 .577 .707 r
F P
0 g
s
.34265 .70693 m .34265 .6884 L .37203 .68502 L p .707 .577 .707 r
F P
0 g
s
.37203 .68502 m .37203 .70355 L .34265 .70693 L p .707 .577 .707 r
F P
0 g
s
.43504 .68615 m .43504 .70467 L .40387 .70277 L p .707 .577 .707 r
F P
0 g
s
.40387 .70277 m .40387 .68425 L .43504 .68615 L p .707 .577 .707 r
F P
0 g
s
.37203 .70355 m .37203 .68502 L .40387 .68425 L p .707 .577 .707 r
F P
0 g
s
.40387 .68425 m .40387 .70277 L .37203 .70355 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolQ001mOol007Moo`P0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00M7oo0`0000=JEP00FUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001`Ool40004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^
Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000
FUIJEUYF0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00
J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo2@0015YF00<005YFFUH00UYF20001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001NOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001IOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEQH000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP05001JEUYFFUH00002FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF10000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF00000UYF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF0000
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000mooaP003ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo
001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH01000<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF001oo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0`0015YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEPh000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJ
EP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH5
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001COol00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00@005YF0000009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
000500000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo001COol01000FUH005YF0P00
1EYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD000EJ
EP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00;Goo001COol01P00FUH00000FUH000EJEP03
001JEUYF00=JEP<000=JEQ<000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`0000=JEP000000;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00`00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYF
FUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOolF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=goo2000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQX000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0039oo`D000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF
00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
1000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eo
o`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@00003FUH005YF009JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P0015YF00<005YFFUH01EYF1@001EYF
00<005YFFUH01EYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000UYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF0`000eYF0P00;Goo000]Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH80004FUH40002FUH>0002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000FUIJEUYF1@000eYF00<0
05YFFUH00UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000
;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUHD0006FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YF00000`000UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo
00<005YF000015YF00<005YF00000P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@000eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<0
05YF000015YF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00D005YF001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP800005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD0
00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH5000jOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUH0000H000o
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEPl000QJEPP000AJEP03001JEUYF00=JEP03001J
EUYF01800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF00=JEP05001JEUYFFUH0001E
Ool002aoo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEPH0009JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEPD000AJEP04001JEUYFFUH2001DOol002aoo`03001JEP0000=JEP@00003FUH005YF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000200000eYF001JEP02
FUH2001DOol002aoo`04001JEP00FUH20004FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003FUH2001DOol002aoo`06001JEP00001J
EP001EYF00@005YFFUIJEPD0009JEQ@00005FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH3
00000eYF0000001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJ
EP03001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPP000AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00
FUH00004FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF
1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH0
0003FUH50002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF100000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002eoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01P00FUH005YF001JEP<0
00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000
FUIJEUYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002ioo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00FUH20002FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEP0000<0009JEP03001JEUYF00AJEP06001JEP00
001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0`00
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
100000=JEP00FUH015YF00@005YFFUIJEQX003aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH0
1EYF1@001EYF00@005YF0000009JEP<000EJEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF00002P0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPD003Moo`00=Woo1@0015YF00<005YFFUH01EYF1@001EYF00@005YF
000000=JEP03001JEP0000@000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH5
0002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol003]oo`P000AJEPD000EJEP04001JEP000003FUH00`00
FUIJEP02FUH50003Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH00UYF1`000eYF00L0
05YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0000300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol004=ooa8000=JEP03001JEUYF00=JEP04
001JEUYFFUH80004FUH00`00FUIJEP03FUH90003FUH00`00FUIJEP04FUH01000FUIJEUYF30001UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<0031oo`00EGoo0P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH00`00FUIJ
EP02000^Ool005Moo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEP00008000aJEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEPP001Ioo`@00003FUH005YF00AJEP05001J
EUYFFUH0000^Ool005Yoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000<000AJEP03001JEP0001Yoo`@000=J
EP04001JEUYFFUH2000]Ool005eoo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP03001JEP0000=JEP<000=JEP03001JEUYF009JEP8001moo`@000=JEP8002eo
o`00HWoo200015YF00<005YFFUH01eYF00<005YFFUH00UYF1@002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF100015YF00@005YF001JEP8000IJEP03001JEUYF009JEP03001oogoo
029oo`03001JEUYF008002eoo`00IGoo00D005YFFUH005YF01<00003FUH005YF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP05001JEUYFFUH00003FUH01P00FUH00000FUH000IJ
EP03001JEUYF008002Ioo`@002eoo`00IGoo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000000UYF0P001UYF0`009Woo0P0000AJEP00000002eoo`00IGoo00<005YF0000
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0`000UYF00<005YF00001P009Goo0`000eYF0`00;Goo
001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP02FUH3000ROol4
00000eYF001JEP03FUH00`00FUH0000]Ool006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000<001Uoo`D000EJEP03001JEUYF009JEP80
02ioo`00?goo4@005Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00H005YF000005YF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003Uo
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000eoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080031oo`00=Goo100000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000Qoo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00009oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0039oo`00<Woo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P001Goo00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0P001Goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@003Aoo`00<7oo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P002Goo1@0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004Ool3
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P0047oo6`00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020004Ool20006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH00000K7oo000/Ool0
0`00FUH00004FUH01000FUIJEUYF20006Goo1P0015YF00D005YFFUIJEP0000Ioo`8000AJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006io
o`00;7oo00<005YF00000eYF1@009goo0`0000=JEP00FUH00UYF00<007ooOol01Woo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00LGoo
000/Ool01000FUH005YF0P00;goo0P000eYF00<007ooOol02Goo100025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00M7oo000/Ool01000FUH00000<goo0P0000=J
EP00Ool03Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF1`00N7oo000/
Ool4000dOol3000EOolR0002OolJ001SOol002aoo`80009JEP<002moo`<00003FUH007oo035oo`L0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5001NOol002aoo`8000=JEP03001J
EP00008002Uoo`<0009JEP03001JEP0002ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008005]oo`00;7oo0P000eYF00<005YFFUH00UYF
1@0087oo100000=JEP00FUH00UYF00<005YF0000;7oo0`001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00FGoo000]Ool01@00FUIJEUYF
00001EYF00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH2000[Ool20002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH2001HOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUHC0003FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000:goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF
4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000005Ioo`00<7oo0`0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000002]oo`8000AJEP03001JEUYF009JEPH0019oo`P000=JEP03001JEUYF00=JEP05001JEUYFFUH0
001EOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<002aoo`03001JEP0000AJEP03001JEP000080021oo`D000AJEP05001JEUYF
FUH0001EOol003Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000<002moo`03001JEP0000=JEP<002Qoo`<00003FUH005YF009JEP8005Aoo`00>Goo10000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@00<goo00@005YF001JEP8002ioo`80
00=JEP8005Aoo`00?Goo6@00>7oo00@005YF0000039oo`800003FUH0000005Aoo`00SWoo0P0000=J
EP00Ool0<7oo0P0000AJEP00000005Aoo`00SWoo0P000UYF0`00:goo0`000eYF0`00E7oo002>Ool2
0002FUH00`00FUIJEP05000ROol400000eYF001JEP03FUH00`00FUH0001DOol008moo`04001JEUYF
0005FUH00`00FUH00003000IOol50005FUH00`00FUIJEP02FUH2001EOol008moo`04001JEUYF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<0
05YFFUH00UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]55\[InvisibleSpace]"     "\
\[InvisibleSpace]12.948298795553866`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 55, "     ", 12.948298795553866, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60019 .76901 m .59458 .71913 L .56347 .71845 L p .707 .577 .707 r
F P
0 g
s
.59458 .71913 m .60019 .76901 L .63184 .7647 L p .707 .577 .707 r
F P
0 g
s
.63184 .7647 m .62622 .71482 L .59458 .71913 L p .707 .577 .707 r
F P
0 g
s
.62622 .71482 m .63184 .7647 L .66092 .75581 L p .707 .577 .707 r
F P
0 g
s
.66092 .75581 m .65531 .70593 L .62622 .71482 L p .707 .577 .707 r
F P
0 g
s
.56908 .76833 m .56347 .71845 L .53595 .71284 L p .707 .577 .707 r
F P
0 g
s
.56347 .71845 m .56908 .76833 L .60019 .76901 L p .707 .577 .707 r
F P
0 g
s
.65531 .70593 m .66092 .75581 L .68461 .74323 L p .707 .577 .707 r
F P
0 g
s
.68461 .74323 m .679 .69335 L .65531 .70593 L p .707 .577 .707 r
F P
0 g
s
.59633 .8109 m .59659 .77368 L .56541 .77169 L p .707 .577 .707 r
F P
0 g
s
.59659 .77368 m .59633 .8109 L .62816 .81037 L p .707 .577 .707 r
F P
0 g
s
.62816 .81037 m .62842 .77315 L .59659 .77368 L p .707 .577 .707 r
F P
0 g
s
.54156 .76272 m .53595 .71284 L .5147 .70285 L p .707 .577 .707 r
F P
0 g
s
.53595 .71284 m .54156 .76272 L .56908 .76833 L p .707 .577 .707 r
F P
0 g
s
.59177 .84066 m .5925 .82174 L .56133 .81934 L p .707 .577 .707 r
F P
0 g
s
.5925 .82174 m .59177 .84066 L .62357 .84133 L p .707 .577 .707 r
F P
0 g
s
.62357 .84133 m .6243 .82241 L .5925 .82174 L p .707 .577 .707 r
F P
0 g
s
.62842 .77315 m .62816 .81037 L .65754 .80739 L p .707 .577 .707 r
F P
0 g
s
.65754 .80739 m .6578 .77017 L .62842 .77315 L p .707 .577 .707 r
F P
0 g
s
.6243 .82241 m .62357 .84133 L .65291 .84021 L p .707 .577 .707 r
F P
0 g
s
.65291 .84021 m .65364 .82129 L .6243 .82241 L p .707 .577 .707 r
F P
0 g
s
.56133 .81934 m .5606 .83826 L .59177 .84066 L p .707 .577 .707 r
F P
0 g
s
.56516 .80891 m .56541 .77169 L .53796 .76738 L p .707 .577 .707 r
F P
0 g
s
.56541 .77169 m .56516 .80891 L .59633 .8109 L p .707 .577 .707 r
F P
0 g
s
.679 .69335 m .68461 .74323 L .70057 .72817 L p .707 .577 .707 r
F P
0 g
s
.70057 .72817 m .69496 .67829 L .679 .69335 L p .707 .577 .707 r
F P
0 g
s
.5606 .83826 m .56133 .81934 L .53387 .81545 L p .707 .577 .707 r
F P
0 g
s
.53387 .81545 m .53314 .83437 L .5606 .83826 L p .707 .577 .707 r
F P
0 g
s
.6578 .77017 m .65754 .80739 L .6816 .80223 L p .707 .577 .707 r
F P
0 g
s
.6816 .80223 m .68185 .76501 L .6578 .77017 L p .707 .577 .707 r
F P
0 g
s
.53796 .76738 m .5377 .80461 L .56516 .80891 L p .707 .577 .707 r
F P
0 g
s
.65364 .82129 m .65291 .84021 L .67691 .8374 L p .707 .577 .707 r
F P
0 g
s
.67691 .8374 m .67764 .81848 L .65364 .82129 L p .707 .577 .707 r
F P
0 g
s
.5377 .80461 m .53796 .76738 L .5169 .76118 L p .707 .577 .707 r
F P
0 g
s
.52031 .75273 m .5147 .70285 L .50182 .68946 L p .707 .577 .707 r
F P
0 g
s
.5147 .70285 m .52031 .75273 L .54156 .76272 L p .707 .577 .707 r
F P
0 g
s
.53314 .83437 m .53387 .81545 L .51278 .81044 L p .707 .577 .707 r
F P
0 g
s
.51278 .81044 m .51205 .82936 L .53314 .83437 L p .707 .577 .707 r
F P
0 g
s
.69496 .67829 m .70057 .72817 L .70724 .71212 L p .707 .577 .707 r
F P
0 g
s
.70724 .71212 m .70163 .66224 L .69496 .67829 L p .707 .577 .707 r
F P
0 g
s
.5169 .76118 m .51664 .7984 L .5377 .80461 L p .707 .577 .707 r
F P
0 g
s
.68185 .76501 m .6816 .80223 L .69796 .79541 L p .707 .577 .707 r
F P
0 g
s
.69796 .79541 m .69822 .75819 L .68185 .76501 L p .707 .577 .707 r
F P
0 g
s
.67764 .81848 m .67691 .8374 L .69322 .83318 L p .707 .577 .707 r
F P
0 g
s
.69322 .83318 m .69395 .81426 L .67764 .81848 L p .707 .577 .707 r
F P
0 g
s
.51664 .7984 m .5169 .76118 L .50431 .75369 L p .707 .577 .707 r
F P
0 g
s
.51205 .82936 m .51278 .81044 L .50015 .80482 L p .707 .577 .707 r
F P
0 g
s
.50743 .73934 m .50182 .68946 L .49855 .67398 L p .707 .577 .707 r
F P
0 g
s
.50182 .68946 m .50743 .73934 L .52031 .75273 L p .707 .577 .707 r
F P
0 g
s
.50015 .80482 m .49942 .82374 L .51205 .82936 L p .707 .577 .707 r
F P
0 g
s
.50431 .75369 m .50405 .79091 L .51664 .7984 L p .707 .577 .707 r
F P
0 g
s
.70163 .66224 m .70724 .71212 L .70398 .69664 L p .707 .577 .707 r
F P
0 g
s
.70398 .69664 m .69837 .64676 L .70163 .66224 L p .707 .577 .707 r
F P
0 g
s
.69822 .75819 m .69796 .79541 L .70504 .7876 L p .707 .577 .707 r
F P
0 g
s
.70504 .7876 m .7053 .75038 L .69822 .75819 L p .707 .577 .707 r
F P
0 g
s
.69395 .81426 m .69322 .83318 L .70024 .82797 L p .707 .577 .707 r
F P
0 g
s
.70024 .82797 m .70097 .80905 L .69395 .81426 L p .707 .577 .707 r
F P
0 g
s
.49942 .82374 m .50015 .80482 L .49719 .79911 L p .707 .577 .707 r
F P
0 g
s
.49719 .79911 m .49646 .81803 L .49942 .82374 L p .707 .577 .707 r
F P
0 g
s
.49646 .81803 m .49719 .79911 L .50422 .7939 L p .707 .577 .707 r
F P
0 g
s
.50422 .7939 m .50349 .81282 L .49646 .81803 L p .707 .577 .707 r
F P
0 g
s
.49788 .82403 m .48674 .33045 L .44274 .32816 L p .707 .577 .707 r
F P
0 g
s
.50405 .79091 m .50431 .75369 L .50141 .74564 L p .707 .577 .707 r
F P
0 g
s
.50416 .72386 m .50743 .73934 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.49855 .67398 m .50171 .70204 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50171 .70204 m .50416 .72386 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50141 .74564 m .50115 .78286 L .50405 .79091 L p .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50141 .74564 L .50575 .74085 L p .707 .577 .707 r
F P
0 g
s
.50575 .74085 m .50849 .73783 L p .50663 .74925 L .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50575 .74085 L .50663 .74925 L .707 .577 .707 r
F
.50416 .72386 m .49855 .67398 L .50523 .65793 L p F P
0 g
s
.51084 .70781 m .50523 .65793 L .52119 .64287 L p .707 .577 .707 r
F P
0 g
s
.50523 .65793 m .51084 .70781 L .50416 .72386 L p .707 .577 .707 r
F P
0 g
s
.50849 .73783 m .50823 .77505 L .50115 .78286 L p .707 .577 .707 r
F P
0 g
s
.52119 .64287 m .5268 .69275 L .51084 .70781 L p .707 .577 .707 r
F P
0 g
s
.5268 .69275 m .52119 .64287 L .54487 .63028 L p .707 .577 .707 r
F P
0 g
s
.50823 .77505 m .50849 .73783 L .52486 .73101 L p .707 .577 .707 r
F P
0 g
s
.50349 .81282 m .50422 .7939 L .52052 .78968 L p .707 .577 .707 r
F P
0 g
s
.52052 .78968 m .51979 .8086 L .50349 .81282 L p .707 .577 .707 r
F P
0 g
s
.52486 .73101 m .5246 .76823 L .50823 .77505 L p .707 .577 .707 r
F P
0 g
s
.54487 .63028 m .55048 .68016 L .5268 .69275 L p .707 .577 .707 r
F P
0 g
s
.5246 .76823 m .52486 .73101 L .54891 .72585 L p .707 .577 .707 r
F P
0 g
s
.51979 .8086 m .52052 .78968 L .54452 .78688 L p .707 .577 .707 r
F P
0 g
s
.54452 .78688 m .54379 .8058 L .51979 .8086 L p .707 .577 .707 r
F P
0 g
s
.54891 .72585 m .54865 .76308 L .5246 .76823 L p .707 .577 .707 r
F P
0 g
s
.48674 .33045 m .49788 .82403 L .54281 .82181 L p .707 .577 .707 r
F P
0 g
s
.54281 .82181 m .53167 .32823 L .48674 .33045 L p .707 .577 .707 r
F P
0 g
s
.55048 .68016 m .54487 .63028 L .57396 .6214 L p .707 .577 .707 r
F P
0 g
s
.57396 .6214 m .57957 .67128 L .55048 .68016 L p .707 .577 .707 r
F P
0 g
s
.54865 .76308 m .54891 .72585 L .57829 .72287 L p .707 .577 .707 r
F P
0 g
s
.54379 .8058 m .54452 .78688 L .57386 .78575 L p .707 .577 .707 r
F P
0 g
s
.57386 .78575 m .57313 .80467 L .54379 .8058 L p .707 .577 .707 r
F P
0 g
s
.57829 .72287 m .57803 .76009 L .54865 .76308 L p .707 .577 .707 r
F P
0 g
s
.57803 .76009 m .57829 .72287 L .61012 .72234 L p .707 .577 .707 r
F P
0 g
s
.61012 .72234 m .60987 .75956 L .57803 .76009 L p .707 .577 .707 r
F P
0 g
s
.57313 .80467 m .57386 .78575 L .60567 .78642 L p .707 .577 .707 r
F P
0 g
s
.60567 .78642 m .60494 .80534 L .57313 .80467 L p .707 .577 .707 r
F P
0 g
s
.53167 .32823 m .54281 .82181 L .58427 .81528 L p .707 .577 .707 r
F P
0 g
s
.57957 .67128 m .57396 .6214 L .60561 .61709 L p .707 .577 .707 r
F P
0 g
s
.60561 .61709 m .61122 .66697 L .57957 .67128 L p .707 .577 .707 r
F P
0 g
s
.58427 .81528 m .57314 .3217 L .53167 .32823 L p .707 .577 .707 r
F P
0 g
s
.45388 .82174 m .44274 .32816 L .40397 .32157 L p .707 .577 .707 r
F P
0 g
s
.44274 .32816 m .45388 .82174 L .49788 .82403 L p .707 .577 .707 r
F P
0 g
s
.69837 .64676 m .70398 .69664 L .69109 .68325 L p .707 .577 .707 r
F P
0 g
s
.69109 .68325 m .68548 .63337 L .69837 .64676 L p .707 .577 .707 r
F P
0 g
s
.64129 .72433 m .64104 .76155 L .60987 .75956 L p .707 .577 .707 r
F P
0 g
s
.60987 .75956 m .61012 .72234 L .64129 .72433 L p .707 .577 .707 r
F P
0 g
s
.63683 .78882 m .6361 .80774 L .60494 .80534 L p .707 .577 .707 r
F P
0 g
s
.60494 .80534 m .60567 .78642 L .63683 .78882 L p .707 .577 .707 r
F P
0 g
s
.57314 .3217 m .58427 .81528 L .61821 .80509 L p .707 .577 .707 r
F P
0 g
s
.63671 .61777 m .64233 .66765 L .61122 .66697 L p .707 .577 .707 r
F P
0 g
s
.61122 .66697 m .60561 .61709 L .63671 .61777 L p .707 .577 .707 r
F P
0 g
s
.61821 .80509 m .60707 .31151 L .57314 .3217 L p .707 .577 .707 r
F P
0 g
s
.7053 .75038 m .70504 .7876 L .70215 .77955 L p .707 .577 .707 r
F P
0 g
s
.70215 .77955 m .7024 .74233 L .7053 .75038 L p .707 .577 .707 r
F P
0 g
s
.70097 .80905 m .70024 .82797 L .69729 .82227 L p .707 .577 .707 r
F P
0 g
s
.69729 .82227 m .69802 .80335 L .70097 .80905 L p .707 .577 .707 r
F P
0 g
s
.41511 .81515 m .40397 .32157 L .37423 .31133 L p .707 .577 .707 r
F P
0 g
s
.40397 .32157 m .41511 .81515 L .45388 .82174 L p .707 .577 .707 r
F P
0 g
s
.25718 .73219 m .25157 .68231 L .22046 .68163 L p .707 .577 .707 r
F P
0 g
s
.25157 .68231 m .25718 .73219 L .28883 .72788 L p .707 .577 .707 r
F P
0 g
s
.28883 .72788 m .28322 .678 L .25157 .68231 L p .707 .577 .707 r
F P
0 g
s
.68548 .63337 m .69109 .68325 L .66985 .67326 L p .707 .577 .707 r
F P
0 g
s
.66985 .67326 m .66424 .62338 L .68548 .63337 L p .707 .577 .707 r
F P
0 g
s
.28322 .678 m .28883 .72788 L .31792 .719 L p .707 .577 .707 r
F P
0 g
s
.31792 .719 m .3123 .66912 L .28322 .678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22607 .73151 m .22046 .68163 L .19294 .67602 L p .707 .577 .707 r
F P
0 g
s
.22046 .68163 m .22607 .73151 L .25718 .73219 L p .707 .577 .707 r
F P
0 g
s
.6361 .80774 m .63683 .78882 L .6643 .79272 L p .707 .577 .707 r
F P
0 g
s
.60707 .31151 m .61821 .80509 L .64129 .79224 L p .707 .577 .707 r
F P
0 g
s
.64233 .66765 m .63671 .61777 L .66424 .62338 L p .707 .577 .707 r
F P
0 g
s
.64129 .79224 m .63015 .29865 L .60707 .31151 L p .707 .577 .707 r
F P
0 g
s
.3123 .66912 m .31792 .719 L .3416 .70641 L p .707 .577 .707 r
F P
0 g
s
.3416 .70641 m .33599 .65653 L .3123 .66912 L p .707 .577 .707 r
F P
0 g
s
.7024 .74233 m .70215 .77955 L .68955 .77206 L p .707 .577 .707 r
F P
0 g
s
.68955 .77206 m .68981 .73484 L .7024 .74233 L p .707 .577 .707 r
F P
0 g
s
.69802 .80335 m .69729 .82227 L .68465 .81664 L p .707 .577 .707 r
F P
0 g
s
.68465 .81664 m .68538 .79772 L .69802 .80335 L p .707 .577 .707 r
F P
0 g
s
.25332 .77408 m .25358 .73686 L .22241 .73487 L p .707 .577 .707 r
F P
0 g
s
.25358 .73686 m .25332 .77408 L .28515 .77356 L p .707 .577 .707 r
F P
0 g
s
.28515 .77356 m .28541 .73634 L .25358 .73686 L p .707 .577 .707 r
F P
0 g
s
.66424 .62338 m .66985 .67326 L .64233 .66765 L p .707 .577 .707 r
F P
0 g
s
.19855 .7259 m .19294 .67602 L .17169 .66603 L p .707 .577 .707 r
F P
0 g
s
.19294 .67602 m .19855 .7259 L .22607 .73151 L p .707 .577 .707 r
F P
0 g
s
.24876 .80385 m .24949 .78493 L .21832 .78253 L p .707 .577 .707 r
F P
0 g
s
.24949 .78493 m .24876 .80385 L .28056 .80452 L p .707 .577 .707 r
F P
0 g
s
.28056 .80452 m .28129 .7856 L .24949 .78493 L p .707 .577 .707 r
F P
0 g
s
.28541 .73634 m .28515 .77356 L .31454 .77057 L p .707 .577 .707 r
F P
0 g
s
.31454 .77057 m .31479 .73335 L .28541 .73634 L p .707 .577 .707 r
F P
0 g
s
.38537 .80491 m .37423 .31133 L .35644 .29844 L p .707 .577 .707 r
F P
0 g
s
.37423 .31133 m .38537 .80491 L .41511 .81515 L p .707 .577 .707 r
F P
0 g
s
.28129 .7856 m .28056 .80452 L .3099 .80339 L p .707 .577 .707 r
F P
0 g
s
.3099 .80339 m .31063 .78447 L .28129 .7856 L p .707 .577 .707 r
F P
0 g
s
.21832 .78253 m .21759 .80145 L .24876 .80385 L p .707 .577 .707 r
F P
0 g
s
.22215 .7721 m .22241 .73487 L .19495 .73057 L p .707 .577 .707 r
F P
0 g
s
.22241 .73487 m .22215 .7721 L .25332 .77408 L p .707 .577 .707 r
F P
0 g
s
.33599 .65653 m .3416 .70641 L .35756 .69135 L p .707 .577 .707 r
F P
0 g
s
.35756 .69135 m .35195 .64147 L .33599 .65653 L p .707 .577 .707 r
F P
0 g
s
.21759 .80145 m .21832 .78253 L .19086 .77863 L p .707 .577 .707 r
F P
0 g
s
.19086 .77863 m .19013 .79755 L .21759 .80145 L p .707 .577 .707 r
F P
0 g
s
.31479 .73335 m .31454 .77057 L .33859 .76542 L p .707 .577 .707 r
F P
0 g
s
.33859 .76542 m .33884 .7282 L .31479 .73335 L p .707 .577 .707 r
F P
0 g
s
.19495 .73057 m .19469 .76779 L .22215 .7721 L p .707 .577 .707 r
F P
0 g
s
.31063 .78447 m .3099 .80339 L .3339 .80059 L p .707 .577 .707 r
F P
0 g
s
.3339 .80059 m .33463 .78167 L .31063 .78447 L p .707 .577 .707 r
F P
0 g
s
.68981 .73484 m .68955 .77206 L .6685 .76586 L p .707 .577 .707 r
F P
0 g
s
.6685 .76586 m .66875 .72864 L .68981 .73484 L p .707 .577 .707 r
F P
0 g
s
.19469 .76779 m .19495 .73057 L .17389 .72437 L p .707 .577 .707 r
F P
0 g
s
.1773 .71591 m .17169 .66603 L .15881 .65264 L p .707 .577 .707 r
F P
0 g
s
.17169 .66603 m .1773 .71591 L .19855 .7259 L p .707 .577 .707 r
F P
0 g
s
.66875 .72864 m .6685 .76586 L .64104 .76155 L p .707 .577 .707 r
F P
0 g
s
.64104 .76155 m .64129 .72433 L .66875 .72864 L p .707 .577 .707 r
F P
0 g
s
.63015 .29865 m .64129 .79224 L .65126 .77798 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64012 .28439 L .63015 .29865 L p .707 .577 .707 r
F P
0 g
s
.68538 .79772 m .68465 .81664 L .66357 .81164 L p .707 .577 .707 r
F P
0 g
s
.66357 .81164 m .6643 .79272 L .68538 .79772 L p .707 .577 .707 r
F P
0 g
s
.19013 .79755 m .19086 .77863 L .16977 .77363 L p .707 .577 .707 r
F P
0 g
s
.16977 .77363 m .16904 .79255 L .19013 .79755 L p .707 .577 .707 r
F P
0 g
s
.35195 .64147 m .35756 .69135 L .36423 .6753 L p .707 .577 .707 r
F P
0 g
s
.36423 .6753 m .35862 .62542 L .35195 .64147 L p .707 .577 .707 r
F P
0 g
s
.17389 .72437 m .17363 .76159 L .19469 .76779 L p .707 .577 .707 r
F P
0 g
s
.33884 .7282 m .33859 .76542 L .35495 .7586 L p .707 .577 .707 r
F P
0 g
s
.35495 .7586 m .35521 .72138 L .33884 .7282 L p .707 .577 .707 r
F P
0 g
s
.33463 .78167 m .3339 .80059 L .35021 .79637 L p .707 .577 .707 r
F P
0 g
s
.35021 .79637 m .35094 .77745 L .33463 .78167 L p .707 .577 .707 r
F P
0 g
s
.35862 .62542 m .36423 .6753 L .36097 .65982 L p .707 .577 .707 r
F P
0 g
s
.36757 .79202 m .35644 .29844 L .35232 .28417 L p .707 .577 .707 r
F P
0 g
s
.35644 .29844 m .36757 .79202 L .38537 .80491 L p .707 .577 .707 r
F P
0 g
s
.17363 .76159 m .17389 .72437 L .1613 .71688 L p .707 .577 .707 r
F P
0 g
s
.6643 .79272 m .66357 .81164 L .6361 .80774 L p .707 .577 .707 r
F P
0 g
s
.16904 .79255 m .16977 .77363 L .15714 .768 L p .707 .577 .707 r
F P
0 g
s
.16442 .70252 m .15881 .65264 L .15554 .63716 L p .707 .577 .707 r
F P
0 g
s
.15881 .65264 m .16442 .70252 L .1773 .71591 L p .707 .577 .707 r
F P
0 g
s
.15714 .768 m .15641 .78692 L .16904 .79255 L p .707 .577 .707 r
F P
0 g
s
.1613 .71688 m .16104 .7541 L .17363 .76159 L p .707 .577 .707 r
F P
0 g
s
.36097 .65982 m .35536 .60994 L .35862 .62542 L p .707 .577 .707 r
F P
0 g
s
.35521 .72138 m .35495 .7586 L .36203 .75078 L p .707 .577 .707 r
F P
0 g
s
.36203 .75078 m .36229 .71356 L .35521 .72138 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64897 .77004 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64666 .7256 m .63735 .72145 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64656 .7237 m .64376 .53234 L .64897 .77004 L .707 .577 .707 r
F
.63735 .72145 m .63662 .74037 L .64769 .7453 L p F P
0 g
s
.64769 .7453 m .64926 .746 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64754 .74246 m .63735 .72145 L .64769 .7453 L .707 .577 .707 r
F
.64656 .7237 m .64283 .56343 L .64376 .53234 L F
.646 .71297 m .64418 .63221 L p .64656 .7237 L F P
0 g
s
.64418 .63221 m .63601 .27012 L p .64446 .63343 L .707 .577 .707 r
F P
0 g
s
.64418 .63221 m .64446 .63343 L .64656 .7237 L .707 .577 .707 r
F
.63601 .27012 m .64411 .62916 L p .62935 .75082 L F P
0 g
s
.63662 .74037 m .63735 .72145 L .63688 .72055 L p .707 .577 .707 r
F P
0 g
s
.63662 .74037 m .63688 .72055 L .63592 .73267 L .707 .577 .707 r
F
.63421 .75434 m .62935 .75082 L p .64411 .62916 L F P
0 g
s
.6344 .71575 m .63367 .73467 L .63662 .74037 L p .707 .577 .707 r
F P
0 g
s
.64411 .62916 m .64715 .7637 L .63421 .75434 L p .707 .577 .707 r
F P
0 g
s
.63688 .72055 m .6344 .71575 L p .63592 .73267 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .63576 .58455 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .64118 .61918 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .63902 .60003 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64487 .49481 m .65126 .77798 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .65752 .6633 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .64118 .61918 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .64463 .64991 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63601 .27012 m .64012 .28439 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64283 .56343 m .63601 .27012 L .64376 .53234 L .707 .577 .707 r
F
.64715 .7637 m .646 .71297 L p .64656 .7237 L F P
0 g
s
.64897 .77004 m .64715 .7637 L p .64656 .7237 L .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64999 .72708 L .64666 .7256 L p .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64666 .7256 L .64754 .74246 L .707 .577 .707 r
F
.65752 .6633 m .65191 .61342 L .64166 .60277 L p F P
0 g
s
.64166 .60277 m .63902 .60003 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.65752 .6633 m .64166 .60277 L .64149 .60849 L .707 .577 .707 r
F
.64012 .28439 m .64487 .49481 L p .64376 .53234 L F P
0 g
s
.35094 .77745 m .35021 .79637 L .35723 .79116 L p .707 .577 .707 r
F P
0 g
s
.35723 .79116 m .35796 .77224 L .35094 .77745 L p .707 .577 .707 r
F P
0 g
s
.16104 .7541 m .1613 .71688 L .1584 .70883 L p .707 .577 .707 r
F P
0 g
s
.16115 .68704 m .16442 .70252 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.15554 .63716 m .1587 .66522 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1587 .66522 m .16115 .68704 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1584 .70883 m .15814 .74605 L .16104 .7541 L p .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .1584 .70883 L .16274 .70403 L p .707 .577 .707 r
F P
0 g
s
.16274 .70403 m .16548 .70101 L p .16362 .71244 L .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .16274 .70403 L .16362 .71244 L .707 .577 .707 r
F
.16115 .68704 m .15554 .63716 L .16222 .62111 L p F P
0 g
s
.15641 .78692 m .15714 .768 L .15418 .7623 L p .707 .577 .707 r
F P
0 g
s
.15418 .7623 m .15345 .78122 L .15641 .78692 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35536 .60994 m .36097 .65982 L .34808 .64643 L p .707 .577 .707 r
F P
0 g
s
.36229 .71356 m .36203 .75078 L .35914 .74273 L p .707 .577 .707 r
F P
0 g
s
.35914 .74273 m .35939 .70551 L .36229 .71356 L p .707 .577 .707 r
F P
0 g
s
.35232 .28417 m .36346 .77775 L .36757 .79202 L p .707 .577 .707 r
F P
0 g
s
.36346 .77775 m .35232 .28417 L .36229 .2699 L p .707 .577 .707 r
F P
0 g
s
.34808 .64643 m .34247 .59655 L .35536 .60994 L p .707 .577 .707 r
F P
0 g
s
.35796 .77224 m .35723 .79116 L .35428 .78546 L p .707 .577 .707 r
F P
0 g
s
.35428 .78546 m .35501 .76653 L .35796 .77224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16783 .67099 m .16222 .62111 L .17818 .60605 L p .707 .577 .707 r
F P
0 g
s
.16222 .62111 m .16783 .67099 L .16115 .68704 L p .707 .577 .707 r
F P
0 g
s
.62935 .75082 m .61821 .25723 L .63601 .27012 L p .707 .577 .707 r
F P
0 g
s
.15345 .78122 m .15418 .7623 L .16121 .75709 L p .707 .577 .707 r
F P
0 g
s
.34247 .59655 m .34808 .64643 L .32684 .63644 L p .707 .577 .707 r
F P
0 g
s
.32684 .63644 m .32123 .58656 L .34247 .59655 L p .707 .577 .707 r
F P
0 g
s
.16121 .75709 m .16048 .77601 L .15345 .78122 L p .707 .577 .707 r
F P
0 g
s
.16548 .70101 m .16522 .73823 L .15814 .74605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35939 .70551 m .35914 .74273 L .34654 .73524 L p .707 .577 .707 r
F P
0 g
s
.34654 .73524 m .3468 .69802 L .35939 .70551 L p .707 .577 .707 r
F P
0 g
s
.37343 .76349 m .36229 .2699 L .38538 .25705 L p .707 .577 .707 r
F P
0 g
s
.36229 .2699 m .37343 .76349 L .36346 .77775 L p .707 .577 .707 r
F P
0 g
s
.17818 .60605 m .18379 .65593 L .16783 .67099 L p .707 .577 .707 r
F P
0 g
s
.18379 .65593 m .17818 .60605 L .20186 .59347 L p .707 .577 .707 r
F P
0 g
s
.35501 .76653 m .35428 .78546 L .34164 .77983 L p .707 .577 .707 r
F P
0 g
s
.34164 .77983 m .34237 .76091 L .35501 .76653 L p .707 .577 .707 r
F P
0 g
s
.32123 .58656 m .32684 .63644 L .29932 .63083 L p .707 .577 .707 r
F P
0 g
s
.29932 .63083 m .29371 .58095 L .32123 .58656 L p .707 .577 .707 r
F P
0 g
s
.16522 .73823 m .16548 .70101 L .18185 .69419 L p .707 .577 .707 r
F P
0 g
s
.16048 .77601 m .16121 .75709 L .17751 .75287 L p .707 .577 .707 r
F P
0 g
s
.17751 .75287 m .17678 .77179 L .16048 .77601 L p .707 .577 .707 r
F P
0 g
s
.18185 .69419 m .18159 .73141 L .16522 .73823 L p .707 .577 .707 r
F P
0 g
s
.20747 .64335 m .20186 .59347 L .23095 .58458 L p .707 .577 .707 r
F P
0 g
s
.20186 .59347 m .20747 .64335 L .18379 .65593 L p .707 .577 .707 r
F P
0 g
s
.61821 .25723 m .62935 .75082 L .59961 .74058 L p .707 .577 .707 r
F P
0 g
s
.59961 .74058 m .58847 .24699 L .61821 .25723 L p .707 .577 .707 r
F P
0 g
s
.29371 .58095 m .29932 .63083 L .26821 .63015 L p .707 .577 .707 r
F P
0 g
s
.26821 .63015 m .2626 .58027 L .29371 .58095 L p .707 .577 .707 r
F P
0 g
s
.3468 .69802 m .34654 .73524 L .32549 .72904 L p .707 .577 .707 r
F P
0 g
s
.32549 .72904 m .32574 .69182 L .3468 .69802 L p .707 .577 .707 r
F P
0 g
s
.23656 .63446 m .23095 .58458 L .2626 .58027 L p .707 .577 .707 r
F P
0 g
s
.23095 .58458 m .23656 .63446 L .20747 .64335 L p .707 .577 .707 r
F P
0 g
s
.2626 .58027 m .26821 .63015 L .23656 .63446 L p .707 .577 .707 r
F P
0 g
s
.34237 .76091 m .34164 .77983 L .32056 .77482 L p .707 .577 .707 r
F P
0 g
s
.32056 .77482 m .32129 .7559 L .34237 .76091 L p .707 .577 .707 r
F P
0 g
s
.18159 .73141 m .18185 .69419 L .2059 .68904 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .37343 .76349 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.38949 .4392 m .39651 .75063 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .38538 .25705 L .41931 .24686 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .40763 .50485 L .42658 .70051 L .707 .577 .707 r
F
.41538 .74497 m .39651 .75063 L p .42658 .70051 L F P
0 g
s
.4185 .70224 m .41777 .72116 L .42141 .72102 L p .707 .577 .707 r
F P
0 g
s
.42141 .72102 m .44711 .72003 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.42511 .70635 m .4185 .70224 L .42141 .72102 L .707 .577 .707 r
F
.44711 .72003 m .44784 .70111 L .42622 .70194 L p F P
0 g
s
.42622 .70194 m .4185 .70224 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.44711 .72003 m .42622 .70194 L .42511 .70635 L .707 .577 .707 r
F
.42601 .54409 m .4293 .68971 L p .40763 .50485 L F P
0 g
s
.4293 .68971 m .43045 .74044 L p .42658 .70051 L .707 .577 .707 r
F P
0 g
s
.40763 .50485 m .4293 .68971 L .42658 .70051 L .707 .577 .707 r
F
.43045 .74044 m .41538 .74497 L p .42658 .70051 L F P
0 g
s
.41931 .24686 m .42601 .54409 L p .40763 .50485 L .707 .577 .707 r
F P
0 g
s
.43045 .74044 m .41931 .24686 L .46077 .24033 L p .707 .577 .707 r
F P
0 g
s
.46077 .24033 m .47191 .73392 L .46058 .7357 L p .707 .577 .707 r
F P
0 g
s
.44784 .70111 m .44711 .72003 L .4563 .71896 L p .707 .577 .707 r
F P
0 g
s
.45258 .7044 m .44784 .70111 L .4563 .71896 L .707 .577 .707 r
F
.43646 .6413 m .46077 .24033 L .46058 .7357 L F
.47191 .73392 m .46077 .24033 L .5057 .23811 L p F P
0 g
s
.4711 .71723 m .47183 .69831 L .44784 .70111 L p .707 .577 .707 r
F P
0 g
s
.46058 .7357 m .43045 .74044 L p .43646 .6413 L .707 .577 .707 r
F P
0 g
s
.4563 .71896 m .4711 .71723 L p .45258 .7044 L .707 .577 .707 r
F P
0 g
s
.45512 .62957 m .45166 .59884 L p .42042 .58857 L .707 .577 .707 r
F P
0 g
s
.45166 .59884 m .44951 .57969 L .44354 .58151 L p .707 .577 .707 r
F P
0 g
s
.44354 .58151 m .42042 .58857 L p .45166 .59884 L .707 .577 .707 r
F P
0 g
s
.42236 .67579 m .42257 .64453 L p .39078 .6391 L .707 .577 .707 r
F P
0 g
s
.42257 .64453 m .42262 .63857 L .41681 .63867 L p .707 .577 .707 r
F P
0 g
s
.41681 .63867 m .39078 .6391 L p .42257 .64453 L .707 .577 .707 r
F P
0 g
s
.39438 .64276 m .39096 .61239 L p .35766 .5922 L .707 .577 .707 r
F P
0 g
s
.39096 .61239 m .38877 .59288 L .37141 .5925 L p .707 .577 .707 r
F P
0 g
s
.37141 .5925 m .35766 .5922 L p .39096 .61239 L .707 .577 .707 r
F P
0 g
s
.38877 .59288 m .39438 .64276 L .42126 .6391 L p .707 .577 .707 r
F P
0 g
s
.42262 .63857 m .42236 .67579 L .45174 .67281 L p .707 .577 .707 r
F P
0 g
s
.45174 .67281 m .45195 .64219 L p .42262 .63857 L .707 .577 .707 r
F P
0 g
s
.45195 .64219 m .452 .63559 L .4465 .63614 L p .707 .577 .707 r
F P
0 g
s
.4465 .63614 m .42262 .63857 L p .45195 .64219 L .707 .577 .707 r
F P
0 g
s
.42603 .63845 m .42281 .60986 L p .38877 .59288 L .707 .577 .707 r
F P
0 g
s
.42281 .60986 m .42042 .58857 L .40546 .59061 L p .707 .577 .707 r
F P
0 g
s
.40546 .59061 m .38877 .59288 L p .42281 .60986 L .707 .577 .707 r
F P
0 g
s
.42126 .6391 m .42603 .63845 L p .41999 .63106 L .707 .577 .707 r
F P
0 g
s
.41999 .63106 m .38877 .59288 L .42126 .6391 L .707 .577 .707 r
F
.38538 .25705 m .38949 .4392 L p .38217 .39315 L F P
0 g
s
.17678 .77179 m .17751 .75287 L .20151 .75006 L p .707 .577 .707 r
F P
0 g
s
.20151 .75006 m .20078 .76898 L .17678 .77179 L p .707 .577 .707 r
F P
0 g
s
.2059 .68904 m .20564 .72626 L .18159 .73141 L p .707 .577 .707 r
F P
0 g
s
.32574 .69182 m .32549 .72904 L .29803 .72474 L p .707 .577 .707 r
F P
0 g
s
.29803 .72474 m .29829 .68751 L .32574 .69182 L p .707 .577 .707 r
F P
0 g
s
.76537 .71261 m .76558 .68134 L p .73379 .67591 L .707 .577 .707 r
F P
0 g
s
.76558 .68134 m .76562 .67539 L .75982 .67548 L p .707 .577 .707 r
F P
0 g
s
.75982 .67548 m .73379 .67591 L p .76558 .68134 L .707 .577 .707 r
F P
0 g
s
.73739 .67958 m .73397 .6492 L p .70067 .62902 L .707 .577 .707 r
F P
0 g
s
.73397 .6492 m .73178 .6297 L .71442 .62932 L p .707 .577 .707 r
F P
0 g
s
.71442 .62932 m .70067 .62902 L p .73397 .6492 L .707 .577 .707 r
F P
0 g
s
.76562 .67539 m .76537 .71261 L .79475 .70962 L p .707 .577 .707 r
F P
0 g
s
.79475 .70962 m .79496 .679 L p .76562 .67539 L .707 .577 .707 r
F P
0 g
s
.79496 .679 m .79501 .6724 L .78951 .67296 L p .707 .577 .707 r
F P
0 g
s
.78951 .67296 m .76562 .67539 L p .79496 .679 L .707 .577 .707 r
F P
0 g
s
.76904 .67527 m .76582 .64668 L p .73178 .6297 L .707 .577 .707 r
F P
0 g
s
.76582 .64668 m .76343 .62539 L .74847 .62743 L p .707 .577 .707 r
F P
0 g
s
.74847 .62743 m .73178 .6297 L p .76582 .64668 L .707 .577 .707 r
F P
0 g
s
.73178 .6297 m .73739 .67958 L .76904 .67527 L p .707 .577 .707 r
F P
0 g
s
.76343 .62539 m .76904 .67527 L .79813 .66638 L p .707 .577 .707 r
F P
0 g
s
.79813 .66638 m .79252 .6165 L .76343 .62539 L p .707 .577 .707 r
F P
0 g
s
.58847 .24699 m .59961 .74058 L .56084 .73399 L p .707 .577 .707 r
F P
0 g
s
.56084 .73399 m .5497 .2404 L .58847 .24699 L p .707 .577 .707 r
F P
0 g
s
.32129 .7559 m .32056 .77482 L .29309 .77093 L p .707 .577 .707 r
F P
0 g
s
.29309 .77093 m .29382 .75201 L .32129 .7559 L p .707 .577 .707 r
F P
0 g
s
.20564 .72626 m .2059 .68904 L .23528 .68605 L p .707 .577 .707 r
F P
0 g
s
.73353 .71313 m .73374 .68387 L p .70262 .67393 L .707 .577 .707 r
F P
0 g
s
.73374 .68387 m .73379 .67591 L .72649 .67545 L p .707 .577 .707 r
F P
0 g
s
.72649 .67545 m .70262 .67393 L p .73374 .68387 L .707 .577 .707 r
F P
0 g
s
.70262 .67393 m .70236 .71115 L .73353 .71313 L p .707 .577 .707 r
F P
0 g
s
.70628 .6789 m .7028 .6479 L p .67315 .62341 L .707 .577 .707 r
F P
0 g
s
.7028 .6479 m .70067 .62902 L .68355 .62553 L p .707 .577 .707 r
F P
0 g
s
.68355 .62553 m .67315 .62341 L p .7028 .6479 L .707 .577 .707 r
F P
0 g
s
.73379 .67591 m .73353 .71313 L .76537 .71261 L p .707 .577 .707 r
F P
0 g
s
.70067 .62902 m .70628 .6789 L .73739 .67958 L p .707 .577 .707 r
F P
0 g
s
.20078 .76898 m .20151 .75006 L .23085 .74894 L p .707 .577 .707 r
F P
0 g
s
.79252 .6165 m .79813 .66638 L .82181 .6538 L p .707 .577 .707 r
F P
0 g
s
.82181 .6538 m .8162 .60392 L .79252 .6165 L p .707 .577 .707 r
F P
0 g
s
.29829 .68751 m .29803 .72474 L .26686 .72275 L p .707 .577 .707 r
F P
0 g
s
.26686 .72275 m .26711 .68553 L .29829 .68751 L p .707 .577 .707 r
F P
0 g
s
.23085 .74894 m .23012 .76786 L .20078 .76898 L p .707 .577 .707 r
F P
0 g
s
.23528 .68605 m .23502 .72327 L .20564 .72626 L p .707 .577 .707 r
F P
0 g
s
.23502 .72327 m .23528 .68605 L .26711 .68553 L p .707 .577 .707 r
F P
0 g
s
.29382 .75201 m .29309 .77093 L .26193 .76853 L p .707 .577 .707 r
F P
0 g
s
.26193 .76853 m .26266 .74961 L .29382 .75201 L p .707 .577 .707 r
F P
0 g
s
.26711 .68553 m .26686 .72275 L .23502 .72327 L p .707 .577 .707 r
F P
0 g
s
.23012 .76786 m .23085 .74894 L .26266 .74961 L p .707 .577 .707 r
F P
0 g
s
.70236 .71115 m .70253 .68633 L p .67516 .66962 L .707 .577 .707 r
F P
0 g
s
.70253 .68633 m .70262 .67393 L .69391 .67256 L p .707 .577 .707 r
F P
0 g
s
.69391 .67256 m .67516 .66962 L p .70253 .68633 L .707 .577 .707 r
F P
0 g
s
.67876 .67329 m .67534 .64291 L p .65191 .61342 L .707 .577 .707 r
F P
0 g
s
.67534 .64291 m .67315 .62341 L .65896 .61673 L p .707 .577 .707 r
F P
0 g
s
.65896 .61673 m .65191 .61342 L p .67534 .64291 L .707 .577 .707 r
F P
0 g
s
.67315 .62341 m .67876 .67329 L .70628 .6789 L p .707 .577 .707 r
F P
0 g
s
.5497 .2404 m .56084 .73399 L .51684 .73169 L p .707 .577 .707 r
F P
0 g
s
.51684 .73169 m .5057 .23811 L .5497 .2404 L p .707 .577 .707 r
F P
0 g
s
.72897 .7573 m .7297 .73838 L .69854 .73598 L p .707 .577 .707 r
F P
0 g
s
.7297 .73838 m .72897 .7573 L .76078 .75797 L p .707 .577 .707 r
F P
0 g
s
.76078 .75797 m .76151 .73905 L .7297 .73838 L p .707 .577 .707 r
F P
0 g
s
.26266 .74961 m .26193 .76853 L .23012 .76786 L p .707 .577 .707 r
F P
0 g
s
.76151 .73905 m .76078 .75797 L .79012 .75685 L p .707 .577 .707 r
F P
0 g
s
.79012 .75685 m .79085 .73793 L .76151 .73905 L p .707 .577 .707 r
F P
0 g
s
.69854 .73598 m .69781 .7549 L .72897 .7573 L p .707 .577 .707 r
F P
0 g
s
.8162 .60392 m .82181 .6538 L .83777 .63874 L p .707 .577 .707 r
F P
0 g
s
.83777 .63874 m .83216 .58886 L .8162 .60392 L p .707 .577 .707 r
F P
0 g
s
.69781 .7549 m .69854 .73598 L .67107 .73209 L p .707 .577 .707 r
F P
0 g
s
.79501 .6724 m .79475 .70962 L .8188 .70447 L p .707 .577 .707 r
F P
0 g
s
.8188 .70447 m .81906 .66725 L .79501 .6724 L p .707 .577 .707 r
F P
0 g
s
.5057 .23811 m .51684 .73169 L .47191 .73392 L p .707 .577 .707 r
F P
0 g
s
.67516 .66962 m .6749 .70684 L .70236 .71115 L p .707 .577 .707 r
F P
0 g
s
.67107 .73209 m .67034 .75101 L .69781 .7549 L p .707 .577 .707 r
F P
0 g
s
.79085 .73793 m .79012 .75685 L .81411 .75404 L p .707 .577 .707 r
F P
0 g
s
.81411 .75404 m .81484 .73512 L .79085 .73793 L p .707 .577 .707 r
F P
0 g
s
.6749 .70684 m .67516 .66962 L .6541 .66342 L p .707 .577 .707 r
F P
0 g
s
.65191 .61342 m .65752 .6633 L .67876 .67329 L p .707 .577 .707 r
F P
0 g
s
.67034 .75101 m .67107 .73209 L .64999 .72708 L p .707 .577 .707 r
F P
0 g
s
.6541 .66342 m .65385 .70064 L .6749 .70684 L p .707 .577 .707 r
F P
0 g
s
.64999 .72708 m .64926 .746 L .67034 .75101 L p .707 .577 .707 r
F P
0 g
s
.83216 .58886 m .83777 .63874 L .84445 .62269 L p .707 .577 .707 r
F P
0 g
s
.84445 .62269 m .83884 .57281 L .83216 .58886 L p .707 .577 .707 r
F P
0 g
s
.81906 .66725 m .8188 .70447 L .83517 .69765 L p .707 .577 .707 r
F P
0 g
s
.83517 .69765 m .83542 .66043 L .81906 .66725 L p .707 .577 .707 r
F P
0 g
s
.81484 .73512 m .81411 .75404 L .83042 .74982 L p .707 .577 .707 r
F P
0 g
s
.83042 .74982 m .83115 .7309 L .81484 .73512 L p .707 .577 .707 r
F P
0 g
s
.65385 .70064 m .6541 .66342 L .64151 .65593 L p .707 .577 .707 r
F P
0 g
s
.64151 .65593 m .64125 .69315 L .65385 .70064 L p .707 .577 .707 r
F P
0 g
s
.83884 .57281 m .84445 .62269 L .84118 .60721 L p .707 .577 .707 r
F P
0 g
s
.84118 .60721 m .83557 .55733 L .83884 .57281 L p .707 .577 .707 r
F P
0 g
s
.83542 .66043 m .83517 .69765 L .84225 .68983 L p .707 .577 .707 r
F P
0 g
s
.84225 .68983 m .84251 .65261 L .83542 .66043 L p .707 .577 .707 r
F P
0 g
s
.83115 .7309 m .83042 .74982 L .83744 .74461 L p .707 .577 .707 r
F P
0 g
s
.83744 .74461 m .83817 .72569 L .83115 .7309 L p .707 .577 .707 r
F P
0 g
s
.64125 .69315 m .64151 .65593 L .63861 .64788 L p .707 .577 .707 r
F P
0 g
s
.64137 .63443 m .64463 .64991 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63576 .58455 m .63886 .61213 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63886 .61213 m .64137 .63443 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63861 .64788 m .63835 .6851 L .64125 .69315 L p .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .63861 .64788 L .64217 .64395 L p .707 .577 .707 r
F P
0 g
s
.64217 .64395 m .64569 .64006 L p .6433 .65475 L .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .64217 .64395 L .6433 .65475 L .707 .577 .707 r
F
.64137 .63443 m .63576 .58455 L .64243 .5685 L p F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83557 .55733 m .84118 .60721 L .8283 .59382 L p .707 .577 .707 r
F P
0 g
s
.8283 .59382 m .82269 .54394 L .83557 .55733 L p .707 .577 .707 r
F P
0 g
s
.84251 .65261 m .84225 .68983 L .83935 .68179 L p .707 .577 .707 r
F P
0 g
s
.83935 .68179 m .83961 .64456 L .84251 .65261 L p .707 .577 .707 r
F P
0 g
s
.83817 .72569 m .83744 .74461 L .83449 .73891 L p .707 .577 .707 r
F P
0 g
s
.83449 .73891 m .83522 .71999 L .83817 .72569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64804 .61838 m .64243 .5685 L .65839 .55344 L p .707 .577 .707 r
F P
0 g
s
.64243 .5685 m .64804 .61838 L .64137 .63443 L p .707 .577 .707 r
F P
0 g
s
.63367 .73467 m .6344 .71575 L .64142 .71054 L p .707 .577 .707 r
F P
0 g
s
.82269 .54394 m .8283 .59382 L .80705 .58383 L p .707 .577 .707 r
F P
0 g
s
.80705 .58383 m .80144 .53395 L .82269 .54394 L p .707 .577 .707 r
F P
0 g
s
.64569 .64006 m .64544 .67728 L .63835 .6851 L p .707 .577 .707 r
F P
0 g
s
.42042 .58857 m .42603 .63845 L .45512 .62957 L p .707 .577 .707 r
F P
0 g
s
.64142 .71054 m .64069 .72946 L .63367 .73467 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39052 .67632 m .39073 .64705 L p .35961 .63711 L .707 .577 .707 r
F P
0 g
s
.39073 .64705 m .39078 .6391 L .38348 .63863 L p .707 .577 .707 r
F P
0 g
s
.38348 .63863 m .35961 .63711 L p .39073 .64705 L .707 .577 .707 r
F P
0 g
s
.35961 .63711 m .35935 .67433 L .39052 .67632 L p .707 .577 .707 r
F P
0 g
s
.36327 .64208 m .35979 .61109 L p .33014 .58659 L .707 .577 .707 r
F P
0 g
s
.35979 .61109 m .35766 .5922 L .34054 .58871 L p .707 .577 .707 r
F P
0 g
s
.34054 .58871 m .33014 .58659 L p .35979 .61109 L .707 .577 .707 r
F P
0 g
s
.39078 .6391 m .39052 .67632 L .42236 .67579 L p .707 .577 .707 r
F P
0 g
s
.35766 .5922 m .36327 .64208 L .39438 .64276 L p .707 .577 .707 r
F P
0 g
s
.83961 .64456 m .83935 .68179 L .82676 .67429 L p .707 .577 .707 r
F P
0 g
s
.82676 .67429 m .82701 .63707 L .83961 .64456 L p .707 .577 .707 r
F P
0 g
s
.44951 .57969 m .45512 .62957 L .4788 .61698 L p .707 .577 .707 r
F P
0 g
s
.4788 .61698 m .47319 .5671 L .44951 .57969 L p .707 .577 .707 r
F P
0 g
s
.65839 .55344 m .664 .60332 L .64804 .61838 L p .707 .577 .707 r
F P
0 g
s
.664 .60332 m .65839 .55344 L .68207 .54085 L p .707 .577 .707 r
F P
0 g
s
.83522 .71999 m .83449 .73891 L .82185 .73328 L p .707 .577 .707 r
F P
0 g
s
.82185 .73328 m .82259 .71436 L .83522 .71999 L p .707 .577 .707 r
F P
0 g
s
.64544 .67728 m .64569 .64006 L .66206 .63324 L p .707 .577 .707 r
F P
0 g
s
.80144 .53395 m .80705 .58383 L .77953 .57822 L p .707 .577 .707 r
F P
0 g
s
.77953 .57822 m .77392 .52834 L .80144 .53395 L p .707 .577 .707 r
F P
0 g
s
.35935 .67433 m .35952 .64952 L p .33215 .6328 L .707 .577 .707 r
F P
0 g
s
.35952 .64952 m .35961 .63711 L .3509 .63574 L p .707 .577 .707 r
F P
0 g
s
.3509 .63574 m .33215 .6328 L p .35952 .64952 L .707 .577 .707 r
F P
0 g
s
.33575 .63647 m .33233 .60609 L p .3089 .5766 L .707 .577 .707 r
F P
0 g
s
.33233 .60609 m .33014 .58659 L .31595 .57992 L p .707 .577 .707 r
F P
0 g
s
.31595 .57992 m .3089 .5766 L p .33233 .60609 L .707 .577 .707 r
F P
0 g
s
.33014 .58659 m .33575 .63647 L .36327 .64208 L p .707 .577 .707 r
F P
0 g
s
.38596 .72049 m .38669 .70157 L .35553 .69917 L p .707 .577 .707 r
F P
0 g
s
.38669 .70157 m .38596 .72049 L .41777 .72116 L p .707 .577 .707 r
F P
0 g
s
.41777 .72116 m .4185 .70224 L .38669 .70157 L p .707 .577 .707 r
F P
0 g
s
.35553 .69917 m .3548 .71809 L .38596 .72049 L p .707 .577 .707 r
F P
0 g
s
.47319 .5671 m .4788 .61698 L .49476 .60192 L p .707 .577 .707 r
F P
0 g
s
.49476 .60192 m .48915 .55204 L .47319 .5671 L p .707 .577 .707 r
F P
0 g
s
.64069 .72946 m .64142 .71054 L .65773 .70632 L p .707 .577 .707 r
F P
0 g
s
.66206 .63324 m .6618 .67047 L .64544 .67728 L p .707 .577 .707 r
F P
0 g
s
.3548 .71809 m .35553 .69917 L .32806 .69527 L p .707 .577 .707 r
F P
0 g
s
.65773 .70632 m .657 .72524 L .64069 .72946 L p .707 .577 .707 r
F P
0 g
s
.452 .63559 m .45174 .67281 L .47579 .66765 L p .707 .577 .707 r
F P
0 g
s
.47579 .66765 m .47605 .63043 L .452 .63559 L p .707 .577 .707 r
F P
0 g
s
.68769 .59073 m .68207 .54085 L .71116 .53197 L p .707 .577 .707 r
F P
0 g
s
.68207 .54085 m .68769 .59073 L .664 .60332 L p .707 .577 .707 r
F P
0 g
s
.33215 .6328 m .33189 .67003 L .35935 .67433 L p .707 .577 .707 r
F P
0 g
s
.32806 .69527 m .32733 .71419 L .3548 .71809 L p .707 .577 .707 r
F P
0 g
s
.77392 .52834 m .77953 .57822 L .74842 .57754 L p .707 .577 .707 r
F P
0 g
s
.74842 .57754 m .74281 .52766 L .77392 .52834 L p .707 .577 .707 r
F P
0 g
s
.82701 .63707 m .82676 .67429 L .8057 .66809 L p .707 .577 .707 r
F P
0 g
s
.8057 .66809 m .80596 .63087 L .82701 .63707 L p .707 .577 .707 r
F P
0 g
s
.33189 .67003 m .33215 .6328 L .31109 .6266 L p .707 .577 .707 r
F P
0 g
s
.71677 .58185 m .71116 .53197 L .74281 .52766 L p .707 .577 .707 r
F P
0 g
s
.71116 .53197 m .71677 .58185 L .68769 .59073 L p .707 .577 .707 r
F P
0 g
s
.31451 .62648 m .3089 .5766 L .29601 .56321 L p .707 .577 .707 r
F P
0 g
s
.3089 .5766 m .31451 .62648 L .33575 .63647 L p .707 .577 .707 r
F P
0 g
s
.74281 .52766 m .74842 .57754 L .71677 .58185 L p .707 .577 .707 r
F P
0 g
s
.82259 .71436 m .82185 .73328 L .80077 .72827 L p .707 .577 .707 r
F P
0 g
s
.80077 .72827 m .8015 .70935 L .82259 .71436 L p .707 .577 .707 r
F P
0 g
s
.32733 .71419 m .32806 .69527 L .30698 .69027 L p .707 .577 .707 r
F P
0 g
s
.6618 .67047 m .66206 .63324 L .68611 .62809 L p .707 .577 .707 r
F P
0 g
s
.31109 .6266 m .31084 .66382 L .33189 .67003 L p .707 .577 .707 r
F P
0 g
s
.30698 .69027 m .30625 .70919 L .32733 .71419 L p .707 .577 .707 r
F P
0 g
s
.48915 .55204 m .49476 .60192 L .50144 .58587 L p .707 .577 .707 r
F P
0 g
s
.50144 .58587 m .49583 .53599 L .48915 .55204 L p .707 .577 .707 r
F P
0 g
s
.47605 .63043 m .47579 .66765 L .49216 .66083 L p .707 .577 .707 r
F P
0 g
s
.49216 .66083 m .49241 .62361 L .47605 .63043 L p .707 .577 .707 r
F P
0 g
s
.657 .72524 m .65773 .70632 L .68172 .70351 L p .707 .577 .707 r
F P
0 g
s
.68611 .62809 m .68585 .66531 L .6618 .67047 L p .707 .577 .707 r
F P
0 g
s
.68172 .70351 m .68099 .72243 L .657 .72524 L p .707 .577 .707 r
F P
0 g
s
.80596 .63087 m .8057 .66809 L .77824 .66379 L p .707 .577 .707 r
F P
0 g
s
.77824 .66379 m .7785 .62657 L .80596 .63087 L p .707 .577 .707 r
F P
0 g
s
.47183 .69831 m .4711 .71723 L .48741 .71301 L p .707 .577 .707 r
F P
0 g
s
.48741 .71301 m .48814 .69409 L .47183 .69831 L p .707 .577 .707 r
F P
0 g
s
.31084 .66382 m .31109 .6266 L .2985 .61911 L p .707 .577 .707 r
F P
0 g
s
.68585 .66531 m .68611 .62809 L .71549 .6251 L p .707 .577 .707 r
F P
0 g
s
.30162 .61309 m .29601 .56321 L .29275 .54773 L p .707 .577 .707 r
F P
0 g
s
.29601 .56321 m .30162 .61309 L .31451 .62648 L p .707 .577 .707 r
F P
0 g
s
.8015 .70935 m .80077 .72827 L .7733 .72438 L p .707 .577 .707 r
F P
0 g
s
.7733 .72438 m .77403 .70546 L .8015 .70935 L p .707 .577 .707 r
F P
0 g
s
.30625 .70919 m .30698 .69027 L .29434 .68464 L p .707 .577 .707 r
F P
0 g
s
.2985 .61911 m .29824 .65633 L .31084 .66382 L p .707 .577 .707 r
F P
0 g
s
.29434 .68464 m .29361 .70356 L .30625 .70919 L p .707 .577 .707 r
F P
0 g
s
.7785 .62657 m .77824 .66379 L .74707 .6618 L p .707 .577 .707 r
F P
0 g
s
.74707 .6618 m .74733 .62458 L .7785 .62657 L p .707 .577 .707 r
F P
0 g
s
.68099 .72243 m .68172 .70351 L .71106 .70239 L p .707 .577 .707 r
F P
0 g
s
.71549 .6251 m .71524 .66232 L .68585 .66531 L p .707 .577 .707 r
F P
0 g
s
.49583 .53599 m .50144 .58587 L .49817 .57039 L p .707 .577 .707 r
F P
0 g
s
.49817 .57039 m .49256 .52051 L .49583 .53599 L p .707 .577 .707 r
F P
0 g
s
.49241 .62361 m .49216 .66083 L .49924 .65302 L p .707 .577 .707 r
F P
0 g
s
.49924 .65302 m .4995 .6158 L .49241 .62361 L p .707 .577 .707 r
F P
0 g
s
.71524 .66232 m .71549 .6251 L .74733 .62458 L p .707 .577 .707 r
F P
0 g
s
.71106 .70239 m .71033 .72131 L .68099 .72243 L p .707 .577 .707 r
F P
0 g
s
.74733 .62458 m .74707 .6618 L .71524 .66232 L p .707 .577 .707 r
F P
0 g
s
.77403 .70546 m .7733 .72438 L .74214 .72198 L p .707 .577 .707 r
F P
0 g
s
.74214 .72198 m .74287 .70306 L .77403 .70546 L p .707 .577 .707 r
F P
0 g
s
.48814 .69409 m .48741 .71301 L .49443 .70779 L p .707 .577 .707 r
F P
0 g
s
.49443 .70779 m .49516 .68887 L .48814 .69409 L p .707 .577 .707 r
F P
0 g
s
.71033 .72131 m .71106 .70239 L .74287 .70306 L p .707 .577 .707 r
F P
0 g
s
.29824 .65633 m .2985 .61911 L .2956 .61106 L p .707 .577 .707 r
F P
0 g
s
.74287 .70306 m .74214 .72198 L .71033 .72131 L p .707 .577 .707 r
F P
0 g
s
.29836 .59761 m .30162 .61309 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29275 .54773 m .29585 .57531 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29585 .57531 m .29836 .59761 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.2956 .61106 m .29534 .64829 L .29824 .65633 L p .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .2956 .61106 L .29916 .60713 L p .707 .577 .707 r
F P
0 g
s
.29916 .60713 m .30268 .60325 L p .30029 .61794 L .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .29916 .60713 L .30029 .61794 L .707 .577 .707 r
F
.29836 .59761 m .29275 .54773 L .29942 .53168 L p F P
0 g
s
.29361 .70356 m .29434 .68464 L .29139 .67894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29139 .67894 m .29066 .69786 L .29361 .70356 L p .707 .577 .707 r
F P
0 g
s
.49256 .52051 m .49817 .57039 L .48529 .557 L p .707 .577 .707 r
F P
0 g
s
.48529 .557 m .47968 .50712 L .49256 .52051 L p .707 .577 .707 r
F P
0 g
s
.4995 .6158 m .49924 .65302 L .49634 .64497 L p .707 .577 .707 r
F P
0 g
s
.49634 .64497 m .4966 .60775 L .4995 .6158 L p .707 .577 .707 r
F P
0 g
s
.49516 .68887 m .49443 .70779 L .49148 .70209 L p .707 .577 .707 r
F P
0 g
s
.49148 .70209 m .49221 .68317 L .49516 .68887 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30503 .58156 m .29942 .53168 L .31538 .51662 L p .707 .577 .707 r
F P
0 g
s
.29942 .53168 m .30503 .58156 L .29836 .59761 L p .707 .577 .707 r
F P
0 g
s
.29066 .69786 m .29139 .67894 L .29841 .67372 L p .707 .577 .707 r
F P
0 g
s
.47968 .50712 m .48529 .557 L .46404 .54701 L p .707 .577 .707 r
F P
0 g
s
.46404 .54701 m .45843 .49713 L .47968 .50712 L p .707 .577 .707 r
F P
0 g
s
.30268 .60325 m .30242 .64047 L .29534 .64829 L p .707 .577 .707 r
F P
0 g
s
.29841 .67372 m .29768 .69264 L .29066 .69786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4966 .60775 m .49634 .64497 L .48375 .63748 L p .707 .577 .707 r
F P
0 g
s
.48375 .63748 m .484 .60026 L .4966 .60775 L p .707 .577 .707 r
F P
0 g
s
.31538 .51662 m .32099 .5665 L .30503 .58156 L p .707 .577 .707 r
F P
0 g
s
.32099 .5665 m .31538 .51662 L .33906 .50404 L p .707 .577 .707 r
F P
0 g
s
.49221 .68317 m .49148 .70209 L .47884 .69647 L p .707 .577 .707 r
F P
0 g
s
.47884 .69647 m .47957 .67755 L .49221 .68317 L p .707 .577 .707 r
F P
0 g
s
.30242 .64047 m .30268 .60325 L .31905 .59643 L p .707 .577 .707 r
F P
0 g
s
.45843 .49713 m .46404 .54701 L .43652 .5414 L p .707 .577 .707 r
F P
0 g
s
.43652 .5414 m .43091 .49152 L .45843 .49713 L p .707 .577 .707 r
F P
0 g
s
.29768 .69264 m .29841 .67372 L .31472 .66951 L p .707 .577 .707 r
F P
0 g
s
.31905 .59643 m .31879 .63365 L .30242 .64047 L p .707 .577 .707 r
F P
0 g
s
.31472 .66951 m .31399 .68843 L .29768 .69264 L p .707 .577 .707 r
F P
0 g
s
.34467 .55392 m .33906 .50404 L .36815 .49515 L p .707 .577 .707 r
F P
0 g
s
.33906 .50404 m .34467 .55392 L .32099 .5665 L p .707 .577 .707 r
F P
0 g
s
.43091 .49152 m .43652 .5414 L .40541 .54072 L p .707 .577 .707 r
F P
0 g
s
.40541 .54072 m .3998 .49084 L .43091 .49152 L p .707 .577 .707 r
F P
0 g
s
.484 .60026 m .48375 .63748 L .46269 .63128 L p .707 .577 .707 r
F P
0 g
s
.46269 .63128 m .46295 .59406 L .484 .60026 L p .707 .577 .707 r
F P
0 g
s
.37376 .54503 m .36815 .49515 L .3998 .49084 L p .707 .577 .707 r
F P
0 g
s
.36815 .49515 m .37376 .54503 L .34467 .55392 L p .707 .577 .707 r
F P
0 g
s
.3998 .49084 m .40541 .54072 L .37376 .54503 L p .707 .577 .707 r
F P
0 g
s
.47957 .67755 m .47884 .69647 L .45776 .69146 L p .707 .577 .707 r
F P
0 g
s
.45776 .69146 m .45849 .67254 L .47957 .67755 L p .707 .577 .707 r
F P
0 g
s
.31879 .63365 m .31905 .59643 L .3431 .59127 L p .707 .577 .707 r
F P
0 g
s
.31399 .68843 m .31472 .66951 L .33871 .6667 L p .707 .577 .707 r
F P
0 g
s
.3431 .59127 m .34284 .6285 L .31879 .63365 L p .707 .577 .707 r
F P
0 g
s
.33871 .6667 m .33798 .68562 L .31399 .68843 L p .707 .577 .707 r
F P
0 g
s
.46295 .59406 m .46269 .63128 L .43523 .62697 L p .707 .577 .707 r
F P
0 g
s
.43523 .62697 m .43549 .58975 L .46295 .59406 L p .707 .577 .707 r
F P
0 g
s
.34284 .6285 m .3431 .59127 L .37248 .58829 L p .707 .577 .707 r
F P
0 g
s
.45849 .67254 m .45776 .69146 L .43029 .68757 L p .707 .577 .707 r
F P
0 g
s
.43029 .68757 m .43102 .66865 L .45849 .67254 L p .707 .577 .707 r
F P
0 g
s
.43549 .58975 m .43523 .62697 L .40406 .62498 L p .707 .577 .707 r
F P
0 g
s
.40406 .62498 m .40432 .58776 L .43549 .58975 L p .707 .577 .707 r
F P
0 g
s
.33798 .68562 m .33871 .6667 L .36805 .66558 L p .707 .577 .707 r
F P
0 g
s
.37248 .58829 m .37222 .62551 L .34284 .6285 L p .707 .577 .707 r
F P
0 g
s
.37222 .62551 m .37248 .58829 L .40432 .58776 L p .707 .577 .707 r
F P
0 g
s
.36805 .66558 m .36732 .6845 L .33798 .68562 L p .707 .577 .707 r
F P
0 g
s
.40432 .58776 m .40406 .62498 L .37222 .62551 L p .707 .577 .707 r
F P
0 g
s
.43102 .66865 m .43029 .68757 L .39913 .68517 L p .707 .577 .707 r
F P
0 g
s
.39913 .68517 m .39986 .66625 L .43102 .66865 L p .707 .577 .707 r
F P
0 g
s
.36732 .6845 m .36805 .66558 L .39986 .66625 L p .707 .577 .707 r
F P
0 g
s
.39986 .66625 m .39913 .68517 L .36732 .6845 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool=0027Ool0081oo`T0
00IJEP03001JEUYF00AJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001dOol007=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEP00001bOol006moo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP04001JEUYFFUH3001_Ool006aoo`<000QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006eoo`00JWoo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0`00Jgoo001XOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001YOol006Ioo`8000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0IWoo001UOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=o
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000AJEPl0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00<005YF00001@0015YF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0Hgoo001UOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1SOol0069oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00AJEP03001oogoo06=oo`00Ggoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH015YF00<007ooOol0Hgoo001MOol200000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1S
Ool005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06=oo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001HOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0Hgoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001GOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<007ooOol0Hgoo001FOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo01Eooa0003ioo`00EGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00ioo`L000AJEP03001JEUYF00EJEP04
001JEUYFFUH5000iOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3000gOol005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPd000EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02000eOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF009JEP@00003FUH005YF
00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20007Ool30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000cOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPD0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP8000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006Ool01000FUIJEP0025YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20003FUH01@00
FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000<Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH30002Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH300000eYF001JEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF008000=JEP05001JEUYFFUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
1000FUIJEP0015YF00@005YFFUH000Moo`03001JEP0000IJEP<000MJEP03001JEUYF00UJEP03001J
EUYF00<0009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH400000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0`0027oo00<005YF
00001EYF1@001UYF00<005YFFUH02EYF00<005YF00000eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH002moo`00Dgoo00@005YFFUH000AJEP03001oogoo00Qoo`03001JEP0000EJEPD000IJEP03001J
EUYF00UJEP8000AJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH0
00=JEP03001oogoo00Uoo`03001JEP0000EJEPD000IJEP03001JEUYF00MJEP800003FUH005YF00=J
EP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH2000<
Ool00`00FUH00006FUH30007FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000<000aoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00AWoo3`00
00=JEP0000000UYF0P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH30007FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF1P003goo10000UYF
00<005YFFUH00eYF00@005YFFUH002ioo`00@7oo1P0015YF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0`001goo00@005YFFUH000EJEP03001JEUYF00MJEP@0009JEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000IOol40004FUH00`00FUIJ
EP02000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03
001JEP0000<000=ooaX000MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH00002000OOol3000015YF001JEUYF0P00;Goo000iOol30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH30002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P000UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00=JEP<002Eoo`80009JEP8002eoo`00
=goo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF00000`000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF
009JEP04001JEUYFFUH2000?Ool3000EOol200001EYF001JEUYF0000;Goo000eOol20002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03
FUH01000FUH0000047oo1@004goo00@005YFFUIJEP800003FUH007oo02aoo`00<goo0P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH2000BOol5
000BOol00`00FUIJEP03FUH3000]Ool0039oo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP0057oo1@0047oo
0`001EYF00<005YF0000;Goo000aOol20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP0001Ioo`<0011oo`04001J
EUYF0005FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P00:7oo0P000eYF00<0
05YFFUH00eYF00@005YF000002aoo`00;goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF10008goo0`001UYF
00<005YFFUH00UYF00@005YFFUH002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH20002FUH2000MOol40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000^
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00T005YF
FUIJEP00FUH005YF000015YF1`000goo4`001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002aoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF0`001EYF200015YF00<005YFFUH00eYF
00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000EJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP03001JEUYF00=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF300000=JEP00FUH00eYF00<005YF00000`001eYF00<005YFFUH015YF1@001UYF00<005YF
FUH00eYF1P0015YF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH7000;Ool00`00FUH00003FUH500000eYF001JEP06FUH00`00FUIJ
EP04FUH50006FUH00`00FUIJEP0800001UYF00000000FUH000=JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00`001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00<007oo
Ool0;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04000BOol01000FUH005YF
0P001EYF1@0015YF00<005YFFUH015YF1@0000=JEP0000001P0015YF00<005YFFUH015YF0`000eYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH0
0000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP<0
01Ioo`06001JEP00001JEP001EYF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo000/Ool00`00FUH00005FUH01000
FUIJEUYF0P006Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000^Ool002aoo`04001JEUYF0004FUH01000FUIJEP006goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002aoo`04001JEUYF0004FUH3000AOol3
0008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000/Ool01000FUIJEP0015YF00<007ooOol047oo1@0027oo00D005YFFUIJEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001oogoo
015oo`D000Uoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00;7oo00D005YFFUH005YF008001Aoo`D000]oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`04001JEP00000G
Ool3000>OolM0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH700000eYF001J
EP06FUH40006FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
000TOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUH0
0003000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=J
EPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEP80009oo`H00003FUH005YF009JEP80
02eoo`00;Goo00@005YF0000009JEP8001ioo`@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJEP<000EJEP8000MJEPD0
00EJEP03001JEP0000H000EJEP<000=JEP8002eoo`00;Goo0P0000=JEP00FUH00eYF1@0057oo1`00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00<000EJEP03001JEUYF00@0009JEP03001JEUYF00EJEPD00003FUH0000000D000AJEP03
001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P000UYF00<005YFFUH00UYF00@0
05YFFUIJEPT000Moo`@0009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPh00004FUH005YF0004FUH0
1000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;Goo0P000UYF00<005YFFUH00UYF00<005YFFUH03P0015YF00<005YFFUH0
0UYF0`0000AJEP00FUIJEPH000=JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000=JEPP0
00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Goo0P000UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000T0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH6
0004FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool20002FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF
FUH020000UYF00<007oo00000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01eYF0`0000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF00<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH90006
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH700000eYF00000005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool30002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF400000=JEP00FUH015YF0`000eYF00@005YFFUIJ
EP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJ
EP03001JEUYF00AJEQ800003FUH005YF00IJEP03001JEUYF00AJEP04001JEP00000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;
FUH01000FUIJEUYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF3`0015YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH00UYF1@00<goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00002UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Qoo`00;Goo00<007oo00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP0000YJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00002000eOol002eoo`03001oo`0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00009FUH4000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000b
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP05001JEUYFFUH00006FUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YF00001@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YF001JEP0000=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000]Ool00eYF001JEP03FUH01000FUIJEUYF200000=JEP00FUH01EYF1@0015YF
200015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00002FUH50003FUH00`00FUIJEP03FUH00`00Oomoo`06Ool50008Ool40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool30003FUH<0002FUH00`00FUIJEP04FUH90008Ool6
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<00003
FUH0000000H000EJEP03001oogoo00Moo`<000eoo`D000=JEP04001JEUYFFUH2000^Ool002aoo`04
001JEP00FUH20005FUH01000FUIJEUYF4@002Woo1`0000IJEP00000005YF0003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF7@0025YF00<005YFFUH01EYF00@005YF0000009J
EP03001JEUYF009JEPP00003FUH007oo01ioo`@000=JEP8002ioo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YFFUH01UYF
1P000UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEQ8000Uoo``0
0004FUH00000FUH2000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF
009JEP03001JEUYF00=JEP03001JEUYF00IJEPH00003FUH005YF00YJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00=JEP03001JEUYF009J
EP@000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH015YF20000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP04FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000_Ool002aoo`8000=JEP03001JEUYF009JEPP000=JEP03001JEUYF009J
EQ40009JEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000000IJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<0031oo`00;Goo00<005YFFUH01P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH200001GooFUIJ
EUYF00000eYF0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP04001JEUYFFUH90004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00<goo000]Ool30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
0003FUH00`00Oomoo`03FUH01000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03
001JEUYF009JEP04001JEUYFFUH20002OolI000iOol002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000=o
o`=JEP@000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0eYF00@005YFFUH000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH0000000D000=JEP04001JEUYFFUH2001DOol002]oo`03001JEP00
00AJEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000Woo0UYF
00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002Ool600000eYF001JEP02FUH2001D
Ool002]oo`03001JEP00009JEPH000Eoo`T000AJEP<0009JEPX000AJEP03001JEUYF00=JEP03001J
EUYF00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000<000EJEP<0
00=JEP8005Aoo`00:goo00<005YF00000`0000AJEP00000000moo`T000Yoo`L000=JEP03001JEUYF
00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001J
EUYF00800003FUH0000005Aoo`00:goo0P000eYF00<005YFFUH00UYF1@003Goo1@004Woo10000UYF
0P0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YF
FUH00UYF0`00E7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF20001Goo1@0047oo2P00
00=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF001JEP0000IJEP03001JEUYF
009JEP<005Aoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUHJ0003FUH0
1000FUIJEUYF0`0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP00009oo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00EJ
EP03001JEUYF009JEP8005Eoo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P000goo00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1P000UYF00<005YFFUH00UYF0P00EGoo000cOol7
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP030005Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH010000UYF0P00
EWoo000jOol80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@002Woo0`0025YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00H005YF000005YF0007FUH00`00FUIJEP03FUH3001HOol0049ooaX0015oo`8000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00Kgoo0`0015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`000UYF200015YF
00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00LWoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00003P0000=oo`000000100015YF00@005YFFUIJ
EP8005Eoo`00MGoo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF100000=o
o`0000000`0047oo0`0000=JEP00FUH00UYF0P00EGoo001iOol60002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH01000FUIJEUYF1P001Goo1@003goo1`000UYF0P00EGoo001oOol80006FUH00`00FUIJ
EP04FUH:00000eYF001JEP03FUHI0003FUH01000FUIJEUYF1000EGoo0027Ool=0003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3001EOol008moo`@000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Eoo`00Tgoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<005Ioo`00UWoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF000005Uoo`00Vgoo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF
3000Fgoo002TOolB001WOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63519 .77235 m .62628 .72777 L .59493 .73403 L p .707 .577 .707 r
F P
0 g
s
.62628 .72777 m .63519 .77235 L .66381 .76043 L p .707 .577 .707 r
F P
0 g
s
.66381 .76043 m .6549 .71585 L .62628 .72777 L p .707 .577 .707 r
F P
0 g
s
.62829 .81117 m .62871 .77385 L .59688 .77422 L p .707 .577 .707 r
F P
0 g
s
.60384 .77861 m .59493 .73403 L .56393 .73402 L p .707 .577 .707 r
F P
0 g
s
.59493 .73403 m .60384 .77861 L .63519 .77235 L p .707 .577 .707 r
F P
0 g
s
.6549 .71585 m .66381 .76043 L .68691 .74401 L p .707 .577 .707 r
F P
0 g
s
.68691 .74401 m .678 .69943 L .6549 .71585 L p .707 .577 .707 r
F P
0 g
s
.59646 .81153 m .59688 .77422 L .5657 .77217 L p .707 .577 .707 r
F P
0 g
s
.57284 .7786 m .56393 .73402 L .5363 .72774 L p .707 .577 .707 r
F P
0 g
s
.59688 .77422 m .59646 .81153 L .62829 .81117 L p .707 .577 .707 r
F P
0 g
s
.56393 .73402 m .57284 .7786 L .60384 .77861 L p .707 .577 .707 r
F P
0 g
s
.58926 .83371 m .59044 .81465 L .55929 .81194 L p .707 .577 .707 r
F P
0 g
s
.59044 .81465 m .58926 .83371 L .62102 .83529 L p .707 .577 .707 r
F P
0 g
s
.62102 .83529 m .6222 .81623 L .59044 .81465 L p .707 .577 .707 r
F P
0 g
s
.55929 .81194 m .55811 .831 L .58926 .83371 L p .707 .577 .707 r
F P
0 g
s
.6222 .81623 m .62102 .83529 L .65029 .83558 L p .707 .577 .707 r
F P
0 g
s
.65029 .83558 m .65147 .81652 L .6222 .81623 L p .707 .577 .707 r
F P
0 g
s
.55811 .831 m .55929 .81194 L .53181 .80836 L p .707 .577 .707 r
F P
0 g
s
.62871 .77385 m .62829 .81117 L .65767 .80842 L p .707 .577 .707 r
F P
0 g
s
.65767 .80842 m .65809 .77111 L .62871 .77385 L p .707 .577 .707 r
F P
0 g
s
.53181 .80836 m .53063 .82742 L .55811 .831 L p .707 .577 .707 r
F P
0 g
s
.678 .69943 m .68691 .74401 L .70221 .72471 L p .707 .577 .707 r
F P
0 g
s
.70221 .72471 m .69331 .68014 L .678 .69943 L p .707 .577 .707 r
F P
0 g
s
.56529 .80949 m .5657 .77217 L .53825 .76792 L p .707 .577 .707 r
F P
0 g
s
.54521 .77231 m .5363 .72774 L .51476 .7158 L p .707 .577 .707 r
F P
0 g
s
.5657 .77217 m .56529 .80949 L .59646 .81153 L p .707 .577 .707 r
F P
0 g
s
.5363 .72774 m .54521 .77231 L .57284 .7786 L p .707 .577 .707 r
F P
0 g
s
.65147 .81652 m .65029 .83558 L .6742 .83455 L p .707 .577 .707 r
F P
0 g
s
.6742 .83455 m .67538 .81549 L .65147 .81652 L p .707 .577 .707 r
F P
0 g
s
.65809 .77111 m .65767 .80842 L .68172 .80358 L p .707 .577 .707 r
F P
0 g
s
.68172 .80358 m .68214 .76626 L .65809 .77111 L p .707 .577 .707 r
F P
0 g
s
.53825 .76792 m .53783 .80524 L .56529 .80949 L p .707 .577 .707 r
F P
0 g
s
.53063 .82742 m .53181 .80836 L .51068 .80426 L p .707 .577 .707 r
F P
0 g
s
.51068 .80426 m .5095 .82332 L .53063 .82742 L p .707 .577 .707 r
F P
0 g
s
.53783 .80524 m .53825 .76792 L .51719 .76188 L p .707 .577 .707 r
F P
0 g
s
.69331 .68014 m .70221 .72471 L .70824 .70442 L p .707 .577 .707 r
F P
0 g
s
.70824 .70442 m .69933 .65984 L .69331 .68014 L p .707 .577 .707 r
F P
0 g
s
.52367 .76038 m .51476 .7158 L .50141 .69937 L p .707 .577 .707 r
F P
0 g
s
.51476 .7158 m .52367 .76038 L .54521 .77231 L p .707 .577 .707 r
F P
0 g
s
.67538 .81549 m .6742 .83455 L .69041 .83231 L p .707 .577 .707 r
F P
0 g
s
.69041 .83231 m .69158 .81325 L .67538 .81549 L p .707 .577 .707 r
F P
0 g
s
.51719 .76188 m .51677 .7992 L .53783 .80524 L p .707 .577 .707 r
F P
0 g
s
.68214 .76626 m .68172 .80358 L .69808 .7971 L p .707 .577 .707 r
F P
0 g
s
.69808 .7971 m .6985 .75978 L .68214 .76626 L p .707 .577 .707 r
F P
0 g
s
.5095 .82332 m .51068 .80426 L .49797 .80004 L p .707 .577 .707 r
F P
0 g
s
.49797 .80004 m .49679 .81911 L .5095 .82332 L p .707 .577 .707 r
F P
0 g
s
.51677 .7992 m .51719 .76188 L .50459 .75463 L p .707 .577 .707 r
F P
0 g
s
.69933 .65984 m .70824 .70442 L .70438 .68511 L p .636 .53 .717 r
F P
0 g
s
.70438 .68511 m .69548 .64054 L .69933 .65984 L p .636 .53 .717 r
F P
0 g
s
.50141 .69937 m .51031 .74395 L .52367 .76038 L p .707 .577 .707 r
F P
0 g
s
.51031 .74395 m .50141 .69937 L .49755 .68007 L p .634 .529 .717 r
F P
0 g
s
.50459 .75463 m .50418 .79195 L .51677 .7992 L p .707 .577 .707 r
F P
0 g
s
.69158 .81325 m .69041 .83231 L .69733 .82907 L p .707 .577 .707 r
F P
0 g
s
.69733 .82907 m .69851 .81001 L .69158 .81325 L p .707 .577 .707 r
F P
0 g
s
.6985 .75978 m .69808 .7971 L .70516 .78962 L p .707 .577 .707 r
F P
0 g
s
.70516 .78962 m .70558 .7523 L .6985 .75978 L p .707 .577 .707 r
F P
0 g
s
.49679 .81911 m .49797 .80004 L .49493 .79612 L p .707 .577 .707 r
F P
0 g
s
.49493 .79612 m .49375 .81519 L .49679 .81911 L p .707 .577 .707 r
F P
0 g
s
.49375 .81519 m .49493 .79612 L .50185 .79288 L p .707 .577 .707 r
F P
0 g
s
.50185 .79288 m .50067 .81195 L .49375 .81519 L p .707 .577 .707 r
F P
0 g
s
.50067 .81195 m .50185 .79288 L .51806 .79064 L p .707 .577 .707 r
F P
0 g
s
.51806 .79064 m .51688 .8097 L .50067 .81195 L p .707 .577 .707 r
F P
0 g
s
.50256 .82491 m .48455 .33728 L .44056 .33523 L p .707 .577 .707 r
F P
0 g
s
.50418 .79195 m .50459 .75463 L .50169 .74689 L p .707 .577 .707 r
F P
0 g
s
.50646 .72465 m .49755 .68007 L .50358 .65977 L p .707 .577 .707 r
F P
0 g
s
.49755 .68007 m .50646 .72465 L .51031 .74395 L p .634 .529 .717 r
F P
0 g
s
.50169 .74689 m .50127 .78421 L .50418 .79195 L p .707 .577 .707 r
F P
0 g
s
.51248 .70435 m .50358 .65977 L .51888 .64047 L p .707 .577 .707 r
F P
0 g
s
.50358 .65977 m .51248 .70435 L .50646 .72465 L p .707 .577 .707 r
F P
0 g
s
.50127 .78421 m .50169 .74689 L .50877 .73941 L p .707 .577 .707 r
F P
0 g
s
.50877 .73941 m .50835 .77673 L .50127 .78421 L p .707 .577 .707 r
F P
0 g
s
.51888 .64047 m .52779 .68505 L .51248 .70435 L p .707 .577 .707 r
F P
0 g
s
.52779 .68505 m .51888 .64047 L .54198 .62406 L p .707 .577 .707 r
F P
0 g
s
.54198 .62406 m .55089 .66864 L .52779 .68505 L p .707 .577 .707 r
F P
0 g
s
.50835 .77673 m .50877 .73941 L .52513 .73294 L p .707 .577 .707 r
F P
0 g
s
.52513 .73294 m .52472 .77025 L .50835 .77673 L p .707 .577 .707 r
F P
0 g
s
.51688 .8097 m .51806 .79064 L .54197 .78961 L p .707 .577 .707 r
F P
0 g
s
.54197 .78961 m .54079 .80868 L .51688 .8097 L p .707 .577 .707 r
F P
0 g
s
.52472 .77025 m .52513 .73294 L .54918 .72809 L p .707 .577 .707 r
F P
0 g
s
.54918 .72809 m .54876 .76541 L .52472 .77025 L p .707 .577 .707 r
F P
0 g
s
.54079 .80868 m .54197 .78961 L .57124 .7899 L p .707 .577 .707 r
F P
0 g
s
.57124 .7899 m .57006 .80897 L .54079 .80868 L p .707 .577 .707 r
F P
0 g
s
.48455 .33728 m .50256 .82491 L .54747 .822 L p .707 .577 .707 r
F P
0 g
s
.54747 .822 m .52946 .33437 L .48455 .33728 L p .707 .577 .707 r
F P
0 g
s
.55089 .66864 m .54198 .62406 L .5706 .61214 L p .707 .577 .707 r
F P
0 g
s
.5706 .61214 m .57951 .65672 L .55089 .66864 L p .707 .577 .707 r
F P
0 g
s
.54876 .76541 m .54918 .72809 L .57856 .72535 L p .707 .577 .707 r
F P
0 g
s
.57856 .72535 m .57814 .76266 L .54876 .76541 L p .707 .577 .707 r
F P
0 g
s
.57006 .80897 m .57124 .7899 L .603 .79148 L p .707 .577 .707 r
F P
0 g
s
.57814 .76266 m .57856 .72535 L .61039 .72498 L p .707 .577 .707 r
F P
0 g
s
.603 .79148 m .60182 .81054 L .57006 .80897 L p .707 .577 .707 r
F P
0 g
s
.61039 .72498 m .60998 .76229 L .57814 .76266 L p .707 .577 .707 r
F P
0 g
s
.52946 .33437 m .54747 .822 L .5889 .81441 L p .707 .577 .707 r
F P
0 g
s
.60195 .60588 m .61086 .65046 L .57951 .65672 L p .707 .577 .707 r
F P
0 g
s
.57951 .65672 m .5706 .61214 L .60195 .60588 L p .707 .577 .707 r
F P
0 g
s
.5889 .81441 m .57089 .32677 L .52946 .33437 L p .707 .577 .707 r
F P
0 g
s
.69548 .64054 m .70438 .68511 L .69103 .66869 L p .707 .577 .707 r
F P
0 g
s
.69103 .66869 m .68212 .62411 L .69548 .64054 L p .707 .577 .707 r
F P
0 g
s
.45856 .82286 m .44056 .33523 L .40178 .3284 L p .707 .577 .707 r
F P
0 g
s
.44056 .33523 m .45856 .82286 L .50256 .82491 L p .707 .577 .707 r
F P
0 g
s
.63414 .79419 m .63297 .81326 L .60182 .81054 L p .707 .577 .707 r
F P
0 g
s
.60182 .81054 m .603 .79148 L .63414 .79419 L p .707 .577 .707 r
F P
0 g
s
.64156 .72702 m .64115 .76434 L .60998 .76229 L p .707 .577 .707 r
F P
0 g
s
.60998 .76229 m .61039 .72498 L .64156 .72702 L p .707 .577 .707 r
F P
0 g
s
.57089 .32677 m .5889 .81441 L .62279 .80287 L p .707 .577 .707 r
F P
0 g
s
.63295 .60589 m .64186 .65047 L .61086 .65046 L p .707 .577 .707 r
F P
0 g
s
.61086 .65046 m .60195 .60588 L .63295 .60589 L p .707 .577 .707 r
F P
0 g
s
.62279 .80287 m .60479 .31524 L .57089 .32677 L p .707 .577 .707 r
F P
0 g
s
.69851 .81001 m .69733 .82907 L .69429 .82515 L p .707 .577 .707 r
F P
0 g
s
.69429 .82515 m .69546 .80609 L .69851 .81001 L p .707 .577 .707 r
F P
0 g
s
.70558 .7523 m .70516 .78962 L .70226 .78188 L p .707 .577 .707 r
F P
0 g
s
.70226 .78188 m .70268 .74456 L .70558 .7523 L p .707 .577 .707 r
F P
0 g
s
.41979 .81603 m .40178 .3284 L .37202 .31747 L p .707 .577 .707 r
F P
0 g
s
.40178 .3284 m .41979 .81603 L .45856 .82286 L p .707 .577 .707 r
F P
0 g
s
.68212 .62411 m .69103 .66869 L .66949 .65675 L p .707 .577 .707 r
F P
0 g
s
.66949 .65675 m .66058 .61217 L .68212 .62411 L p .707 .577 .707 r
F P
0 g
s
.63297 .81326 m .63414 .79419 L .66163 .79777 L p .707 .577 .707 r
F P
0 g
s
.66902 .73127 m .66861 .76859 L .64115 .76434 L p .707 .577 .707 r
F P
0 g
s
.64115 .76434 m .64156 .72702 L .66902 .73127 L p .707 .577 .707 r
F P
0 g
s
.60479 .31524 m .62279 .80287 L .64583 .78852 L p .707 .577 .707 r
F P
0 g
s
.64186 .65047 m .63295 .60589 L .66058 .61217 L p .707 .577 .707 r
F P
0 g
s
.64583 .78852 m .62782 .30089 L .60479 .31524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29218 .73553 m .28327 .69095 L .25192 .69721 L p .707 .577 .707 r
F P
0 g
s
.28327 .69095 m .29218 .73553 L .3208 .72361 L p .707 .577 .707 r
F P
0 g
s
.3208 .72361 m .31189 .67903 L .28327 .69095 L p .707 .577 .707 r
F P
0 g
s
.28528 .77435 m .2857 .73703 L .25387 .7374 L p .707 .577 .707 r
F P
0 g
s
.26083 .74179 m .25192 .69721 L .22092 .6972 L p .707 .577 .707 r
F P
0 g
s
.25192 .69721 m .26083 .74179 L .29218 .73553 L p .707 .577 .707 r
F P
0 g
s
.66058 .61217 m .66949 .65675 L .64186 .65047 L p .707 .577 .707 r
F P
0 g
s
.69546 .80609 m .69429 .82515 L .68158 .82093 L p .707 .577 .707 r
F P
0 g
s
.68158 .82093 m .68276 .80187 L .69546 .80609 L p .707 .577 .707 r
F P
0 g
s
.70268 .74456 m .70226 .78188 L .68967 .77463 L p .707 .577 .707 r
F P
0 g
s
.68967 .77463 m .69008 .73731 L .70268 .74456 L p .707 .577 .707 r
F P
0 g
s
.31189 .67903 m .3208 .72361 L .3439 .7072 L p .707 .577 .707 r
F P
0 g
s
.3439 .7072 m .33499 .66262 L .31189 .67903 L p .707 .577 .707 r
F P
0 g
s
.25345 .77472 m .25387 .7374 L .22269 .73536 L p .707 .577 .707 r
F P
0 g
s
.22983 .74178 m .22092 .6972 L .19329 .69092 L p .707 .577 .707 r
F P
0 g
s
.25387 .7374 m .25345 .77472 L .28528 .77435 L p .707 .577 .707 r
F P
0 g
s
.22092 .6972 m .22983 .74178 L .26083 .74179 L p .707 .577 .707 r
F P
0 g
s
.24625 .7969 m .24743 .77783 L .21628 .77512 L p .707 .577 .707 r
F P
0 g
s
.24743 .77783 m .24625 .7969 L .27801 .79848 L p .707 .577 .707 r
F P
0 g
s
.27801 .79848 m .27919 .77941 L .24743 .77783 L p .707 .577 .707 r
F P
0 g
s
.21628 .77512 m .2151 .79419 L .24625 .7969 L p .707 .577 .707 r
F P
0 g
s
.27919 .77941 m .27801 .79848 L .30728 .79877 L p .707 .577 .707 r
F P
0 g
s
.30728 .79877 m .30846 .7797 L .27919 .77941 L p .707 .577 .707 r
F P
0 g
s
.39003 .8051 m .37202 .31747 L .35419 .30352 L p .707 .577 .707 r
F P
0 g
s
.37202 .31747 m .39003 .8051 L .41979 .81603 L p .707 .577 .707 r
F P
0 g
s
.2151 .79419 m .21628 .77512 L .1888 .77154 L p .707 .577 .707 r
F P
0 g
s
.2857 .73703 m .28528 .77435 L .31466 .77161 L p .707 .577 .707 r
F P
0 g
s
.31466 .77161 m .31508 .73429 L .2857 .73703 L p .707 .577 .707 r
F P
0 g
s
.1888 .77154 m .18762 .79061 L .2151 .79419 L p .707 .577 .707 r
F P
0 g
s
.33499 .66262 m .3439 .7072 L .3592 .6879 L p .707 .577 .707 r
F P
0 g
s
.3592 .6879 m .3503 .64332 L .33499 .66262 L p .707 .577 .707 r
F P
0 g
s
.22228 .77268 m .22269 .73536 L .19524 .73111 L p .707 .577 .707 r
F P
0 g
s
.2022 .7355 m .19329 .69092 L .17175 .67898 L p .707 .577 .707 r
F P
0 g
s
.22269 .73536 m .22228 .77268 L .25345 .77472 L p .707 .577 .707 r
F P
0 g
s
.19329 .69092 m .2022 .7355 L .22983 .74178 L p .707 .577 .707 r
F P
0 g
s
.30846 .7797 m .30728 .79877 L .33119 .79774 L p .707 .577 .707 r
F P
0 g
s
.33119 .79774 m .33237 .77867 L .30846 .7797 L p .707 .577 .707 r
F P
0 g
s
.31508 .73429 m .31466 .77161 L .33871 .76676 L p .707 .577 .707 r
F P
0 g
s
.33871 .76676 m .33913 .72944 L .31508 .73429 L p .707 .577 .707 r
F P
0 g
s
.19524 .73111 m .19482 .76843 L .22228 .77268 L p .707 .577 .707 r
F P
0 g
s
.18762 .79061 m .1888 .77154 L .16767 .76744 L p .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .66901 .73036 L .65615 .72786 L p .707 .577 .707 r
F P
0 g
s
.62782 .30089 m .64583 .78852 L .65482 .77425 L p .707 .577 .707 r
F P
0 g
s
.65516 .76258 m .62782 .30089 L .65482 .77425 L .707 .577 .707 r
F
.63775 .28513 m .62782 .30089 L p .65516 .76258 L F P
0 g
s
.65576 .77276 m .65525 .75913 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .63775 .28513 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.64788 .72626 m .6467 .74532 L .65443 .74682 L p .707 .577 .707 r
F P
0 g
s
.65419 .74326 m .64788 .72626 L .65443 .74682 L .707 .577 .707 r
F
.64885 .66332 m .64721 .60747 L .65525 .75913 L F
.63775 .28513 m .64879 .5842 L p .64721 .60747 L F P
0 g
s
.64879 .5842 m .65525 .75913 L p .64721 .60747 L .707 .577 .707 r
F P
0 g
s
.65593 .7356 m .65349 .73277 L .6556 .74705 L .707 .577 .707 r
F
.65349 .73277 m .64788 .72626 L .65419 .74326 L F
.65349 .73277 m .65419 .74326 L .6556 .74705 L F
.6336 .26951 m .63775 .28513 L p .64885 .66332 L F P
0 g
s
.65615 .72786 m .64788 .72626 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64726 .63956 L .64885 .66332 L .707 .577 .707 r
F
.64949 .69983 m .64726 .63956 L p .65036 .71465 L F P
0 g
s
.64726 .63956 m .6336 .26951 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.65482 .77425 m .65576 .77276 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65576 .77276 m .6532 .76315 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.6532 .76315 m .6516 .75714 L p .65036 .71465 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64885 .66332 L .6532 .76315 L .707 .577 .707 r
F
.6467 .74532 m .64788 .72626 L .63518 .72204 L p F P
0 g
s
.63518 .72204 m .634 .74111 L .6467 .74532 L p .707 .577 .707 r
F P
0 g
s
.634 .74111 m .63518 .72204 L .63213 .71812 L p .707 .577 .707 r
F P
0 g
s
.63213 .71812 m .63096 .73719 L .634 .74111 L p .707 .577 .707 r
F P
0 g
s
.6336 .26951 m .6516 .75714 L .63393 .7433 L p .707 .577 .707 r
F P
0 g
s
.63096 .73719 m .6337 .71739 L .63381 .72934 L .707 .577 .707 r
F
.63377 .72496 m .6336 .26951 L .63393 .7433 L F
.63906 .71488 m .63788 .73395 L .63386 .73583 L p F P
0 g
s
.63386 .73583 m .63096 .73719 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.63381 .72934 m .63906 .71488 L .63386 .73583 L .707 .577 .707 r
F
.63096 .73719 m .63213 .71812 L .6337 .71739 L p F P
0 g
s
.63378 .74318 m .61577 .25555 L .62985 .26658 L p .707 .577 .707 r
F P
0 g
s
.62985 .26658 m .6336 .26951 L p .63377 .72496 L .707 .577 .707 r
F P
0 g
s
.63378 .74318 m .62985 .26658 L .63377 .72496 L .707 .577 .707 r
F
.63393 .7433 m .63378 .74318 L p .63377 .72496 L F P
0 g
s
.6337 .71739 m .63906 .71488 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.6418 .65333 m .64138 .69065 L .64921 .69515 L p .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .65576 .77276 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.64921 .69515 m .65398 .69789 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.64812 .67646 m .6418 .65333 L .64921 .69515 L .707 .577 .707 r
F
.65398 .69789 m .65439 .66058 L .64693 .65628 L p F P
0 g
s
.64693 .65628 m .6418 .65333 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.65398 .69789 m .64693 .65628 L .64812 .67646 L .707 .577 .707 r
F
.6516 .75714 m .64949 .69983 L p .65036 .71465 L F P
0 g
s
.67503 .70394 m .67529 .68121 L p .65439 .66058 L .707 .577 .707 r
F P
0 g
s
.67529 .68121 m .67545 .66662 L .6664 .66402 L p .707 .577 .707 r
F P
0 g
s
.6664 .66402 m .65439 .66058 L p .67529 .68121 L .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .64629 .621 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .65461 .64121 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.65461 .64121 m .65196 .62798 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.64629 .621 m .63861 .61155 L p .64563 .63078 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .64629 .621 L .64563 .63078 L .707 .577 .707 r
F
.65443 .74682 m .6556 .74705 L p .65419 .74326 L F P
0 g
s
.6556 .74705 m .66783 .74942 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .65615 .72786 L .65593 .7356 L .707 .577 .707 r
F
.68276 .80187 m .68158 .82093 L .66045 .81684 L p F P
0 g
s
.66045 .81684 m .66163 .79777 L .68276 .80187 L p .707 .577 .707 r
F P
0 g
s
.16767 .76744 m .16649 .78651 L .18762 .79061 L p .707 .577 .707 r
F P
0 g
s
.69008 .73731 m .68967 .77463 L .66861 .76859 L p .707 .577 .707 r
F P
0 g
s
.66861 .76859 m .66902 .73127 L .69008 .73731 L p .707 .577 .707 r
F P
0 g
s
.19482 .76843 m .19524 .73111 L .17418 .72506 L p .707 .577 .707 r
F P
0 g
s
.3503 .64332 m .3592 .6879 L .36523 .6676 L p .707 .577 .707 r
F P
0 g
s
.36523 .6676 m .35632 .62303 L .3503 .64332 L p .707 .577 .707 r
F P
0 g
s
.18066 .72356 m .17175 .67898 L .1584 .66256 L p .707 .577 .707 r
F P
0 g
s
.17175 .67898 m .18066 .72356 L .2022 .7355 L p .707 .577 .707 r
F P
0 g
s
.33237 .77867 m .33119 .79774 L .3474 .7955 L p .707 .577 .707 r
F P
0 g
s
.3474 .7955 m .34857 .77643 L .33237 .77867 L p .707 .577 .707 r
F P
0 g
s
.17418 .72506 m .17376 .76238 L .19482 .76843 L p .707 .577 .707 r
F P
0 g
s
.33913 .72944 m .33871 .76676 L .35507 .76028 L p .707 .577 .707 r
F P
0 g
s
.35507 .76028 m .35549 .72296 L .33913 .72944 L p .707 .577 .707 r
F P
0 g
s
.3722 .79115 m .35419 .30352 L .35004 .28789 L p .707 .577 .707 r
F P
0 g
s
.35419 .30352 m .3722 .79115 L .39003 .8051 L p .707 .577 .707 r
F P
0 g
s
.16649 .78651 m .16767 .76744 L .15496 .76323 L p .707 .577 .707 r
F P
0 g
s
.66163 .79777 m .66045 .81684 L .63297 .81326 L p .707 .577 .707 r
F P
0 g
s
.15496 .76323 m .15378 .78229 L .16649 .78651 L p .707 .577 .707 r
F P
0 g
s
.17376 .76238 m .17418 .72506 L .16158 .71782 L p .707 .577 .707 r
F P
0 g
s
.35632 .62303 m .36523 .6676 L .36137 .6483 L p .632 .528 .718 r
F P
0 g
s
.36137 .6483 m .35247 .60372 L .35632 .62303 L p .632 .528 .718 r
F P
0 g
s
.1584 .66256 m .1673 .70714 L .18066 .72356 L p .707 .577 .707 r
F P
0 g
s
.1673 .70714 m .1584 .66256 L .15454 .64325 L p .63 .526 .718 r
F P
0 g
s
.16158 .71782 m .16117 .75513 L .17376 .76238 L p .707 .577 .707 r
F P
0 g
s
.34857 .77643 m .3474 .7955 L .35432 .79225 L p .707 .577 .707 r
F P
0 g
s
.35432 .79225 m .3555 .77319 L .34857 .77643 L p .707 .577 .707 r
F P
0 g
s
.35549 .72296 m .35507 .76028 L .36215 .75281 L p .707 .577 .707 r
F P
0 g
s
.36215 .75281 m .36257 .71549 L .35549 .72296 L p .707 .577 .707 r
F P
0 g
s
.15378 .78229 m .15496 .76323 L .15192 .75931 L p .707 .577 .707 r
F P
0 g
s
.15192 .75931 m .15074 .77837 L .15378 .78229 L p .707 .577 .707 r
F P
0 g
s
.16117 .75513 m .16158 .71782 L .15868 .71007 L p .707 .577 .707 r
F P
0 g
s
.35247 .60372 m .36137 .6483 L .34802 .63187 L p .707 .577 .707 r
F P
0 g
s
.34802 .63187 m .33911 .5873 L .35247 .60372 L p .707 .577 .707 r
F P
0 g
s
.16345 .68783 m .15454 .64325 L .16057 .62296 L p .707 .577 .707 r
F P
0 g
s
.15454 .64325 m .16345 .68783 L .1673 .70714 L p .63 .526 .718 r
F P
0 g
s
.35004 .28789 m .36805 .77553 L .3722 .79115 L p .707 .577 .707 r
F P
0 g
s
.36805 .77553 m .35004 .28789 L .35997 .27214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15868 .71007 m .15826 .74739 L .16117 .75513 L p .707 .577 .707 r
F P
0 g
s
.3555 .77319 m .35432 .79225 L .35128 .78834 L p .707 .577 .707 r
F P
0 g
s
.35128 .78834 m .35246 .76927 L .3555 .77319 L p .707 .577 .707 r
F P
0 g
s
.36257 .71549 m .36215 .75281 L .35925 .74507 L p .707 .577 .707 r
F P
0 g
s
.35925 .74507 m .35967 .70775 L .36257 .71549 L p .707 .577 .707 r
F P
0 g
s
.33911 .5873 m .34802 .63187 L .32648 .61994 L p .707 .577 .707 r
F P
0 g
s
.32648 .61994 m .31757 .57536 L .33911 .5873 L p .707 .577 .707 r
F P
0 g
s
.16947 .66754 m .16057 .62296 L .17587 .60366 L p .707 .577 .707 r
F P
0 g
s
.16057 .62296 m .16947 .66754 L .16345 .68783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15074 .77837 m .15192 .75931 L .15884 .75607 L p .707 .577 .707 r
F P
0 g
s
.15884 .75607 m .15766 .77513 L .15074 .77837 L p .707 .577 .707 r
F P
0 g
s
.15826 .74739 m .15868 .71007 L .16576 .7026 L p .707 .577 .707 r
F P
0 g
s
.16576 .7026 m .16534 .73992 L .15826 .74739 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.31757 .57536 m .32648 .61994 L .29885 .61365 L p .707 .577 .707 r
F P
0 g
s
.29885 .61365 m .28995 .56908 L .31757 .57536 L p .707 .577 .707 r
F P
0 g
s
.17587 .60366 m .18478 .64824 L .16947 .66754 L p .707 .577 .707 r
F P
0 g
s
.18478 .64824 m .17587 .60366 L .19897 .58725 L p .707 .577 .707 r
F P
0 g
s
.37797 .75977 m .35997 .27214 L .383 .25779 L p .707 .577 .707 r
F P
0 g
s
.35997 .27214 m .37797 .75977 L .36805 .77553 L p .707 .577 .707 r
F P
0 g
s
.35246 .76927 m .35128 .78834 L .33857 .78412 L p .707 .577 .707 r
F P
0 g
s
.33857 .78412 m .33975 .76506 L .35246 .76927 L p .707 .577 .707 r
F P
0 g
s
.35967 .70775 m .35925 .74507 L .34666 .73782 L p .707 .577 .707 r
F P
0 g
s
.34666 .73782 m .34707 .7005 L .35967 .70775 L p .707 .577 .707 r
F P
0 g
s
.15766 .77513 m .15884 .75607 L .17505 .75382 L p .707 .577 .707 r
F P
0 g
s
.17505 .75382 m .17387 .77289 L .15766 .77513 L p .707 .577 .707 r
F P
0 g
s
.28995 .56908 m .29885 .61365 L .26785 .61364 L p .707 .577 .707 r
F P
0 g
s
.26785 .61364 m .25894 .56906 L .28995 .56908 L p .707 .577 .707 r
F P
0 g
s
.20788 .63182 m .19897 .58725 L .22759 .57533 L p .707 .577 .707 r
F P
0 g
s
.19897 .58725 m .20788 .63182 L .18478 .64824 L p .707 .577 .707 r
F P
0 g
s
.16534 .73992 m .16576 .7026 L .18212 .69612 L p .707 .577 .707 r
F P
0 g
s
.61577 .25555 m .63378 .74318 L .60402 .73226 L p .707 .577 .707 r
F P
0 g
s
.60402 .73226 m .58601 .24463 L .61577 .25555 L p .707 .577 .707 r
F P
0 g
s
.25894 .56906 m .26785 .61364 L .2365 .6199 L p .707 .577 .707 r
F P
0 g
s
.2365 .6199 m .22759 .57533 L .25894 .56906 L p .707 .577 .707 r
F P
0 g
s
.22759 .57533 m .2365 .6199 L .20788 .63182 L p .707 .577 .707 r
F P
0 g
s
.18212 .69612 m .18171 .73344 L .16534 .73992 L p .707 .577 .707 r
F P
0 g
s
.33975 .76506 m .33857 .78412 L .31744 .78002 L p .707 .577 .707 r
F P
0 g
s
.31744 .78002 m .31862 .76096 L .33975 .76506 L p .707 .577 .707 r
F P
0 g
s
.34707 .7005 m .34666 .73782 L .3256 .73177 L p .707 .577 .707 r
F P
0 g
s
.3256 .73177 m .32601 .69445 L .34707 .7005 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .40659 .57025 L .42095 .65324 L .707 .577 .707 r
F
.37797 .75977 m .38063 .49454 L .40016 .73492 L F
.40101 .74542 m .39884 .74678 L p .40016 .73492 L F P
0 g
s
.39884 .74678 m .37797 .75977 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.3934 .53939 m .40051 .73179 L p .38063 .49454 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .40101 .74542 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.38063 .49454 m .40051 .73179 L .40016 .73492 L .707 .577 .707 r
F
.40521 .71372 m .40271 .71204 L .4036 .7199 L F
.383 .25779 m .4169 .24625 L p .40158 .72768 L F P
0 g
s
.40101 .74542 m .40051 .73179 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .383 .25779 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .41639 .70141 L .40851 .70102 L p .707 .577 .707 r
F P
0 g
s
.40851 .70102 m .38463 .69984 L p .40521 .71372 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .40851 .70102 L .40521 .71372 L .707 .577 .707 r
F
.40271 .71204 m .38463 .69984 L .40202 .71823 L F
.40271 .71204 m .40202 .71823 L .4036 .7199 L F
.38463 .69984 m .38345 .7189 L .40184 .71981 L p F P
0 g
s
.40184 .71981 m .4036 .7199 L p .40202 .71823 L .707 .577 .707 r
F P
0 g
s
.40202 .71823 m .38463 .69984 L .40184 .71981 L .707 .577 .707 r
F
.4036 .7199 m .41522 .72048 L p .40521 .71372 L F P
0 g
s
.4349 .73388 m .40101 .74542 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41639 .70141 m .41522 .72048 L .44448 .72077 L p .707 .577 .707 r
F P
0 g
s
.44448 .72077 m .44566 .7017 L .41639 .70141 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .42095 .65324 L .42884 .69887 L .707 .577 .707 r
F
.42978 .59502 m .43279 .67657 L p .40659 .57025 L F P
0 g
s
.43279 .67657 m .4349 .73388 L p .42884 .69887 L .707 .577 .707 r
F P
0 g
s
.40659 .57025 m .43279 .67657 L .42884 .69887 L .707 .577 .707 r
F
.44566 .7017 m .44448 .72077 L .46839 .71974 L p F P
0 g
s
.46839 .71974 m .46957 .70068 L .44566 .7017 L p .707 .577 .707 r
F P
0 g
s
.45833 .23865 m .47633 .72629 L .47598 .72635 L p .707 .577 .707 r
F P
0 g
s
.46957 .70068 m .46839 .71974 L .47519 .7188 L p .707 .577 .707 r
F P
0 g
s
.47379 .7054 m .46957 .70068 L .47519 .7188 L .707 .577 .707 r
F
.44794 .45826 m .45833 .23865 L .47598 .72635 L F
.45833 .23865 m .50324 .23574 L p .49249 .4316 L F P
0 g
s
.47633 .72629 m .46927 .5351 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.46927 .5351 m .45833 .23865 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.50324 .23574 m .52124 .72337 L .47633 .72629 L p .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .48578 .69843 L .47325 .70017 L p .707 .577 .707 r
F P
0 g
s
.47325 .70017 m .46957 .70068 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .47325 .70017 L .47379 .7054 L .707 .577 .707 r
F
.47598 .72635 m .4349 .73388 L p .44794 .45826 L F P
0 g
s
.47591 .66546 m .47633 .62814 L .45228 .63299 L p .707 .577 .707 r
F P
0 g
s
.458 .63579 m .4811 .61938 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.4491 .59121 m .45267 .60909 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.45267 .60909 m .458 .63579 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.47519 .7188 m .4846 .7175 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .45228 .63299 L .4403 .63411 L p .707 .577 .707 r
F P
0 g
s
.4349 .73388 m .4169 .24625 L .45833 .23865 L p .707 .577 .707 r
F P
0 g
s
.4403 .63411 m .4229 .63573 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .4403 .63411 L .43703 .65259 L .707 .577 .707 r
F
.4229 .63573 m .42249 .67305 L .43359 .67201 L p F P
0 g
s
.43359 .67201 m .45187 .67031 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.43703 .65259 m .4229 .63573 L .43359 .67201 L .707 .577 .707 r
F
.42304 .73168 m .42884 .69887 L .4349 .73388 L F
.40158 .72768 m .42884 .69887 L .42304 .73168 L F
.4169 .24625 m .42978 .59502 L p .40659 .57025 L F P
0 g
s
.458 .63579 m .45531 .62229 L p .42047 .60313 L .707 .577 .707 r
F P
0 g
s
.45531 .62229 m .4491 .59121 L .43263 .59807 L p .707 .577 .707 r
F P
0 g
s
.43263 .59807 m .42047 .60313 L p .45531 .62229 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .42047 .60313 L .41204 .60482 L p .707 .577 .707 r
F P
0 g
s
.42249 .67305 m .42287 .63832 L p .39107 .6361 L .707 .577 .707 r
F P
0 g
s
.42287 .63832 m .4229 .63573 L .41848 .63578 L p .707 .577 .707 r
F P
0 g
s
.41848 .63578 m .39107 .6361 L p .42287 .63832 L .707 .577 .707 r
F P
0 g
s
.39065 .67342 m .391 .64197 L p .3599 .63406 L .707 .577 .707 r
F P
0 g
s
.391 .64197 m .39107 .6361 L .38228 .63552 L p .707 .577 .707 r
F P
0 g
s
.38228 .63552 m .3599 .63406 L p .391 .64197 L .707 .577 .707 r
F P
0 g
s
.35948 .67137 m .35979 .64344 L p .33244 .62981 L .707 .577 .707 r
F P
0 g
s
.35979 .64344 m .3599 .63406 L .34978 .63249 L p .707 .577 .707 r
F P
0 g
s
.34978 .63249 m .33244 .62981 L p .35979 .64344 L .707 .577 .707 r
F P
0 g
s
.33244 .62981 m .33202 .66712 L .35948 .67137 L p .707 .577 .707 r
F P
0 g
s
.33202 .66712 m .33228 .64439 L p .31138 .62376 L .707 .577 .707 r
F P
0 g
s
.33228 .64439 m .33244 .62981 L .32339 .62721 L p .707 .577 .707 r
F P
0 g
s
.32339 .62721 m .31138 .62376 L p .33228 .64439 L .707 .577 .707 r
F P
0 g
s
.31786 .63574 m .3116 .6044 L p .2956 .57474 L .707 .577 .707 r
F P
0 g
s
.3116 .6044 m .30895 .59116 L .29741 .57697 L p .707 .577 .707 r
F P
0 g
s
.29741 .57697 m .2956 .57474 L p .3116 .6044 L .707 .577 .707 r
F P
0 g
s
.3394 .64768 m .33262 .61372 L p .30895 .59116 L .707 .577 .707 r
F P
0 g
s
.33262 .61372 m .3305 .6031 L .31511 .59458 L p .707 .577 .707 r
F P
0 g
s
.31511 .59458 m .30895 .59116 L p .33262 .61372 L .707 .577 .707 r
F P
0 g
s
.3599 .63406 m .35948 .67137 L .39065 .67342 L p .707 .577 .707 r
F P
0 g
s
.36703 .65396 m .36006 .61911 L p .3305 .6031 L .707 .577 .707 r
F P
0 g
s
.36006 .61911 m .35812 .60938 L .34193 .6057 L p .707 .577 .707 r
F P
0 g
s
.34193 .6057 m .3305 .6031 L p .36006 .61911 L .707 .577 .707 r
F P
0 g
s
.39107 .6361 m .39065 .67342 L .42249 .67305 L p .707 .577 .707 r
F P
0 g
s
.39803 .65397 m .39125 .62002 L p .35812 .60938 L .707 .577 .707 r
F P
0 g
s
.39125 .62002 m .38913 .6094 L .37289 .60939 L p .707 .577 .707 r
F P
0 g
s
.37289 .60939 m .35812 .60938 L p .39125 .62002 L .707 .577 .707 r
F P
0 g
s
.41204 .60482 m .38913 .6094 L p .42234 .64101 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .41204 .60482 L .42234 .64101 L .707 .577 .707 r
F
.383 .25779 m .3934 .53939 L p .38063 .49454 L F P
0 g
s
.17387 .77289 m .17505 .75382 L .19896 .7528 L p .707 .577 .707 r
F P
0 g
s
.19896 .7528 m .19778 .77186 L .17387 .77289 L p .707 .577 .707 r
F P
0 g
s
.18171 .73344 m .18212 .69612 L .20617 .69127 L p .707 .577 .707 r
F P
0 g
s
.20617 .69127 m .20576 .72859 L .18171 .73344 L p .707 .577 .707 r
F P
0 g
s
.58601 .24463 m .60402 .73226 L .56524 .72543 L p .707 .577 .707 r
F P
0 g
s
.56524 .72543 m .54723 .2378 L .58601 .24463 L p .707 .577 .707 r
F P
0 g
s
.31862 .76096 m .31744 .78002 L .28996 .77644 L p .707 .577 .707 r
F P
0 g
s
.28996 .77644 m .29114 .75738 L .31862 .76096 L p .707 .577 .707 r
F P
0 g
s
.32601 .69445 m .3256 .73177 L .29814 .72752 L p .707 .577 .707 r
F P
0 g
s
.29814 .72752 m .29855 .6902 L .32601 .69445 L p .707 .577 .707 r
F P
0 g
s
.19778 .77186 m .19896 .7528 L .22823 .75309 L p .707 .577 .707 r
F P
0 g
s
.20576 .72859 m .20617 .69127 L .23555 .68853 L p .707 .577 .707 r
F P
0 g
s
.7655 .70986 m .76588 .67514 L p .73408 .67291 L .707 .577 .707 r
F P
0 g
s
.76588 .67514 m .76591 .67254 L .76149 .6726 L p .707 .577 .707 r
F P
0 g
s
.76149 .6726 m .73408 .67291 L p .76588 .67514 L .707 .577 .707 r
F P
0 g
s
.73366 .71023 m .73401 .67879 L p .70291 .67087 L .707 .577 .707 r
F P
0 g
s
.73401 .67879 m .73408 .67291 L .72529 .67234 L p .707 .577 .707 r
F P
0 g
s
.72529 .67234 m .70291 .67087 L p .73401 .67879 L .707 .577 .707 r
F P
0 g
s
.70249 .70819 m .7028 .68026 L p .67545 .66662 L .707 .577 .707 r
F P
0 g
s
.7028 .68026 m .70291 .67087 L .69279 .66931 L p .707 .577 .707 r
F P
0 g
s
.69279 .66931 m .67545 .66662 L p .7028 .68026 L .707 .577 .707 r
F P
0 g
s
.67545 .66662 m .67503 .70394 L .70249 .70819 L p .707 .577 .707 r
F P
0 g
s
.68241 .6845 m .67563 .65054 L p .65196 .62798 L .707 .577 .707 r
F P
0 g
s
.67563 .65054 m .67351 .63992 L .65812 .63139 L p .707 .577 .707 r
F P
0 g
s
.65812 .63139 m .65196 .62798 L p .67563 .65054 L .707 .577 .707 r
F P
0 g
s
.70291 .67087 m .70249 .70819 L .73366 .71023 L p .707 .577 .707 r
F P
0 g
s
.71004 .69078 m .70307 .65592 L p .67351 .63992 L .707 .577 .707 r
F P
0 g
s
.70307 .65592 m .70113 .6462 L .68494 .64252 L p .707 .577 .707 r
F P
0 g
s
.68494 .64252 m .67351 .63992 L p .70307 .65592 L .707 .577 .707 r
F P
0 g
s
.73408 .67291 m .73366 .71023 L .7655 .70986 L p .707 .577 .707 r
F P
0 g
s
.74104 .69079 m .73426 .65683 L p .70113 .6462 L .707 .577 .707 r
F P
0 g
s
.73426 .65683 m .73214 .64621 L .7159 .64621 L p .707 .577 .707 r
F P
0 g
s
.7159 .64621 m .70113 .6462 L p .73426 .65683 L .707 .577 .707 r
F P
0 g
s
.76591 .67254 m .7655 .70986 L .79488 .70712 L p .707 .577 .707 r
F P
0 g
s
.79488 .70712 m .79529 .6698 L .76591 .67254 L p .707 .577 .707 r
F P
0 g
s
.77239 .68453 m .76348 .63995 L .73214 .64621 L p .707 .577 .707 r
F P
0 g
s
.79529 .6698 m .79488 .70712 L .81892 .70227 L p .707 .577 .707 r
F P
0 g
s
.81892 .70227 m .81934 .66495 L .79529 .6698 L p .707 .577 .707 r
F P
0 g
s
.76348 .63995 m .77239 .68453 L .80101 .67261 L p .707 .577 .707 r
F P
0 g
s
.80101 .67261 m .79211 .62803 L .76348 .63995 L p .707 .577 .707 r
F P
0 g
s
.73214 .64621 m .74104 .69079 L .77239 .68453 L p .707 .577 .707 r
F P
0 g
s
.22823 .75309 m .22705 .77215 L .19778 .77186 L p .707 .577 .707 r
F P
0 g
s
.29114 .75738 m .28996 .77644 L .25881 .77373 L p .707 .577 .707 r
F P
0 g
s
.25881 .77373 m .25999 .75466 L .29114 .75738 L p .707 .577 .707 r
F P
0 g
s
.79211 .62803 m .80101 .67261 L .82411 .6562 L p .707 .577 .707 r
F P
0 g
s
.82411 .6562 m .8152 .61162 L .79211 .62803 L p .707 .577 .707 r
F P
0 g
s
.70113 .6462 m .71004 .69078 L .74104 .69079 L p .707 .577 .707 r
F P
0 g
s
.29855 .6902 m .29814 .72752 L .26697 .72548 L p .707 .577 .707 r
F P
0 g
s
.26697 .72548 m .26738 .68816 L .29855 .6902 L p .707 .577 .707 r
F P
0 g
s
.23555 .68853 m .23513 .72585 L .20576 .72859 L p .707 .577 .707 r
F P
0 g
s
.22705 .77215 m .22823 .75309 L .25999 .75466 L p .707 .577 .707 r
F P
0 g
s
.54723 .2378 m .56524 .72543 L .52124 .72337 L p .707 .577 .707 r
F P
0 g
s
.52124 .72337 m .50324 .23574 L .54723 .2378 L p .707 .577 .707 r
F P
0 g
s
.23513 .72585 m .23555 .68853 L .26738 .68816 L p .707 .577 .707 r
F P
0 g
s
.25999 .75466 m .25881 .77373 L .22705 .77215 L p .707 .577 .707 r
F P
0 g
s
.72646 .75572 m .72764 .73665 L .6965 .73394 L p .707 .577 .707 r
F P
0 g
s
.72764 .73665 m .72646 .75572 L .75823 .75729 L p .707 .577 .707 r
F P
0 g
s
.75823 .75729 m .7594 .73823 L .72764 .73665 L p .707 .577 .707 r
F P
0 g
s
.26738 .68816 m .26697 .72548 L .23513 .72585 L p .707 .577 .707 r
F P
0 g
s
.6965 .73394 m .69532 .753 L .72646 .75572 L p .707 .577 .707 r
F P
0 g
s
.7594 .73823 m .75823 .75729 L .78749 .75758 L p .707 .577 .707 r
F P
0 g
s
.78749 .75758 m .78867 .73852 L .7594 .73823 L p .707 .577 .707 r
F P
0 g
s
.69532 .753 m .6965 .73394 L .66901 .73036 L p .707 .577 .707 r
F P
0 g
s
.66901 .73036 m .66783 .74942 L .69532 .753 L p .707 .577 .707 r
F P
0 g
s
.8152 .61162 m .82411 .6562 L .83942 .6369 L p .707 .577 .707 r
F P
0 g
s
.83942 .6369 m .83051 .59232 L .8152 .61162 L p .707 .577 .707 r
F P
0 g
s
.67351 .63992 m .68241 .6845 L .71004 .69078 L p .707 .577 .707 r
F P
0 g
s
.78867 .73852 m .78749 .75758 L .8114 .75656 L p .707 .577 .707 r
F P
0 g
s
.8114 .75656 m .81258 .73749 L .78867 .73852 L p .707 .577 .707 r
F P
0 g
s
.83051 .59232 m .83942 .6369 L .84544 .6166 L p .707 .577 .707 r
F P
0 g
s
.84544 .6166 m .83653 .57202 L .83051 .59232 L p .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .66087 .67256 L .68241 .6845 L p .707 .577 .707 r
F P
0 g
s
.65439 .66058 m .65398 .69789 L .67503 .70394 L p .707 .577 .707 r
F P
0 g
s
.81934 .66495 m .81892 .70227 L .83529 .69579 L p .707 .577 .707 r
F P
0 g
s
.83529 .69579 m .8357 .65848 L .81934 .66495 L p .707 .577 .707 r
F P
0 g
s
.81258 .73749 m .8114 .75656 L .82761 .75431 L p .707 .577 .707 r
F P
0 g
s
.82761 .75431 m .82879 .73525 L .81258 .73749 L p .707 .577 .707 r
F P
0 g
s
.83653 .57202 m .84544 .6166 L .84159 .5973 L p .637 .531 .717 r
F P
0 g
s
.84159 .5973 m .83268 .55272 L .83653 .57202 L p .637 .531 .717 r
F P
0 g
s
.63861 .61155 m .64752 .65613 L .66087 .67256 L p .707 .577 .707 r
F P
0 g
s
.64752 .65613 m .63861 .61155 L .63476 .59225 L p .635 .53 .717 r
F P
0 g
s
.8357 .65848 m .83529 .69579 L .84237 .68832 L p .707 .577 .707 r
F P
0 g
s
.84237 .68832 m .84278 .651 L .8357 .65848 L p .707 .577 .707 r
F P
0 g
s
.82879 .73525 m .82761 .75431 L .83453 .75107 L p .707 .577 .707 r
F P
0 g
s
.83453 .75107 m .83571 .73201 L .82879 .73525 L p .707 .577 .707 r
F P
0 g
s
.64138 .69065 m .6418 .65333 L .63889 .64559 L p .707 .577 .707 r
F P
0 g
s
.83268 .55272 m .84159 .5973 L .82824 .58087 L p .707 .577 .707 r
F P
0 g
s
.82824 .58087 m .81933 .53629 L .83268 .55272 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .63476 .59225 L .64078 .57195 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .64752 .65613 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63889 .64559 m .63848 .68291 L .64138 .69065 L p .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .63889 .64559 L .64428 .6399 L p .707 .577 .707 r
F P
0 g
s
.64428 .6399 m .64597 .63811 L p .64504 .6437 L .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .64428 .6399 L .64504 .6437 L .707 .577 .707 r
F
.63476 .59225 m .63924 .61468 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63924 .61468 m .64366 .63683 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84278 .651 m .84237 .68832 L .83947 .68058 L p .707 .577 .707 r
F P
0 g
s
.83947 .68058 m .83988 .64326 L .84278 .651 L p .707 .577 .707 r
F P
0 g
s
.83571 .73201 m .83453 .75107 L .83149 .74715 L p .707 .577 .707 r
F P
0 g
s
.83149 .74715 m .83267 .72809 L .83571 .73201 L p .707 .577 .707 r
F P
0 g
s
.81933 .53629 m .82824 .58087 L .80669 .56893 L p .707 .577 .707 r
F P
0 g
s
.80669 .56893 m .79778 .52435 L .81933 .53629 L p .707 .577 .707 r
F P
0 g
s
.64969 .61653 m .64078 .57195 L .65609 .55266 L p .707 .577 .707 r
F P
0 g
s
.64078 .57195 m .64969 .61653 L .64366 .63683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64597 .63811 m .64556 .67543 L .63848 .68291 L p .707 .577 .707 r
F P
0 g
s
.45228 .63299 m .45187 .67031 L .47591 .66546 L p .707 .577 .707 r
F P
0 g
s
.42047 .60313 m .42938 .64771 L .458 .63579 L p .707 .577 .707 r
F P
0 g
s
.38913 .6094 m .39803 .65397 L .42938 .64771 L p .707 .577 .707 r
F P
0 g
s
.83988 .64326 m .83947 .68058 L .82687 .67333 L p .707 .577 .707 r
F P
0 g
s
.82687 .67333 m .82729 .63601 L .83988 .64326 L p .707 .577 .707 r
F P
0 g
s
.79778 .52435 m .80669 .56893 L .77907 .56265 L p .707 .577 .707 r
F P
0 g
s
.77907 .56265 m .77016 .51807 L .79778 .52435 L p .707 .577 .707 r
F P
0 g
s
.65609 .55266 m .66499 .59723 L .64969 .61653 L p .707 .577 .707 r
F P
0 g
s
.66499 .59723 m .65609 .55266 L .67918 .53624 L p .707 .577 .707 r
F P
0 g
s
.4811 .61938 m .47219 .5748 L .4491 .59121 L p .707 .577 .707 r
F P
0 g
s
.35812 .60938 m .36703 .65396 L .39803 .65397 L p .707 .577 .707 r
F P
0 g
s
.83267 .72809 m .83149 .74715 L .81878 .74294 L p .707 .577 .707 r
F P
0 g
s
.81878 .74294 m .81996 .72387 L .83267 .72809 L p .707 .577 .707 r
F P
0 g
s
.38345 .7189 m .38463 .69984 L .35349 .69712 L p .707 .577 .707 r
F P
0 g
s
.35349 .69712 m .35231 .71619 L .38345 .7189 L p .707 .577 .707 r
F P
0 g
s
.64556 .67543 m .64597 .63811 L .66234 .63163 L p .707 .577 .707 r
F P
0 g
s
.77016 .51807 m .77907 .56265 L .74806 .56264 L p .707 .577 .707 r
F P
0 g
s
.74806 .56264 m .73915 .51806 L .77016 .51807 L p .707 .577 .707 r
F P
0 g
s
.68809 .58082 m .67918 .53624 L .70781 .52432 L p .707 .577 .707 r
F P
0 g
s
.67918 .53624 m .68809 .58082 L .66499 .59723 L p .707 .577 .707 r
F P
0 g
s
.63788 .73395 m .63906 .71488 L .65527 .71264 L p .707 .577 .707 r
F P
0 g
s
.35231 .71619 m .35349 .69712 L .326 .69354 L p .707 .577 .707 r
F P
0 g
s
.65527 .71264 m .65409 .7317 L .63788 .73395 L p .707 .577 .707 r
F P
0 g
s
.326 .69354 m .32482 .71261 L .35231 .71619 L p .707 .577 .707 r
F P
0 g
s
.47219 .5748 m .4811 .61938 L .49641 .60008 L p .707 .577 .707 r
F P
0 g
s
.49641 .60008 m .4875 .5555 L .47219 .5748 L p .707 .577 .707 r
F P
0 g
s
.3305 .6031 m .3394 .64768 L .36703 .65396 L p .707 .577 .707 r
F P
0 g
s
.66234 .63163 m .66192 .66895 L .64556 .67543 L p .707 .577 .707 r
F P
0 g
s
.73915 .51806 m .74806 .56264 L .71671 .5689 L p .707 .577 .707 r
F P
0 g
s
.71671 .5689 m .70781 .52432 L .73915 .51806 L p .707 .577 .707 r
F P
0 g
s
.70781 .52432 m .71671 .5689 L .68809 .58082 L p .707 .577 .707 r
F P
0 g
s
.82729 .63601 m .82687 .67333 L .80581 .66728 L p .707 .577 .707 r
F P
0 g
s
.80581 .66728 m .80623 .62997 L .82729 .63601 L p .707 .577 .707 r
F P
0 g
s
.32482 .71261 m .326 .69354 L .30487 .68945 L p .707 .577 .707 r
F P
0 g
s
.81996 .72387 m .81878 .74294 L .79765 .73884 L p .707 .577 .707 r
F P
0 g
s
.79765 .73884 m .79883 .71977 L .81996 .72387 L p .707 .577 .707 r
F P
0 g
s
.30487 .68945 m .30369 .70851 L .32482 .71261 L p .707 .577 .707 r
F P
0 g
s
.66192 .66895 m .66234 .63163 L .68639 .62678 L p .707 .577 .707 r
F P
0 g
s
.4875 .5555 m .49641 .60008 L .50243 .57979 L p .707 .577 .707 r
F P
0 g
s
.50243 .57979 m .49352 .53521 L .4875 .5555 L p .707 .577 .707 r
F P
0 g
s
.30895 .59116 m .31786 .63574 L .3394 .64768 L p .707 .577 .707 r
F P
0 g
s
.31138 .62376 m .31097 .66108 L .33202 .66712 L p .707 .577 .707 r
F P
0 g
s
.65409 .7317 m .65527 .71264 L .67917 .71161 L p .707 .577 .707 r
F P
0 g
s
.47633 .62814 m .47591 .66546 L .49228 .65898 L p .707 .577 .707 r
F P
0 g
s
.49228 .65898 m .49269 .62166 L .47633 .62814 L p .707 .577 .707 r
F P
0 g
s
.67917 .71161 m .678 .73068 L .65409 .7317 L p .707 .577 .707 r
F P
0 g
s
.68639 .62678 m .68597 .6641 L .66192 .66895 L p .707 .577 .707 r
F P
0 g
s
.80623 .62997 m .80581 .66728 L .77835 .66303 L p .707 .577 .707 r
F P
0 g
s
.77835 .66303 m .77877 .62571 L .80623 .62997 L p .707 .577 .707 r
F P
0 g
s
.31097 .66108 m .31138 .62376 L .29878 .61651 L p .707 .577 .707 r
F P
0 g
s
.30369 .70851 m .30487 .68945 L .29216 .68523 L p .707 .577 .707 r
F P
0 g
s
.79883 .71977 m .79765 .73884 L .77017 .73526 L p .707 .577 .707 r
F P
0 g
s
.77017 .73526 m .77135 .71619 L .79883 .71977 L p .707 .577 .707 r
F P
0 g
s
.29216 .68523 m .29099 .70429 L .30369 .70851 L p .707 .577 .707 r
F P
0 g
s
.68597 .6641 m .68639 .62678 L .71576 .62404 L p .707 .577 .707 r
F P
0 g
s
.49352 .53521 m .50243 .57979 L .49858 .56048 L p .634 .529 .717 r
F P
0 g
s
.49858 .56048 m .48967 .5159 L .49352 .53521 L p .634 .529 .717 r
F P
0 g
s
.2956 .57474 m .30451 .61932 L .31786 .63574 L p .707 .577 .707 r
F P
0 g
s
.30451 .61932 m .2956 .57474 L .29175 .55543 L p .632 .527 .718 r
F P
0 g
s
.29878 .61651 m .29837 .65383 L .31097 .66108 L p .707 .577 .707 r
F P
0 g
s
.678 .73068 m .67917 .71161 L .70844 .7119 L p .707 .577 .707 r
F P
0 g
s
.70844 .7119 m .70726 .73097 L .678 .73068 L p .707 .577 .707 r
F P
0 g
s
.77877 .62571 m .77835 .66303 L .74718 .66099 L p .707 .577 .707 r
F P
0 g
s
.74718 .66099 m .7476 .62367 L .77877 .62571 L p .707 .577 .707 r
F P
0 g
s
.71576 .62404 m .71535 .66136 L .68597 .6641 L p .707 .577 .707 r
F P
0 g
s
.49269 .62166 m .49228 .65898 L .49936 .6515 L p .707 .577 .707 r
F P
0 g
s
.49936 .6515 m .49977 .61418 L .49269 .62166 L p .707 .577 .707 r
F P
0 g
s
.71535 .66136 m .71576 .62404 L .7476 .62367 L p .707 .577 .707 r
F P
0 g
s
.77135 .71619 m .77017 .73526 L .73902 .73255 L p .707 .577 .707 r
F P
0 g
s
.73902 .73255 m .7402 .71348 L .77135 .71619 L p .707 .577 .707 r
F P
0 g
s
.7476 .62367 m .74718 .66099 L .71535 .66136 L p .707 .577 .707 r
F P
0 g
s
.48578 .69843 m .4846 .7175 L .49152 .71426 L p .707 .577 .707 r
F P
0 g
s
.49152 .71426 m .4927 .69519 L .48578 .69843 L p .707 .577 .707 r
F P
0 g
s
.70726 .73097 m .70844 .7119 L .7402 .71348 L p .707 .577 .707 r
F P
0 g
s
.7402 .71348 m .73902 .73255 L .70726 .73097 L p .707 .577 .707 r
F P
0 g
s
.29837 .65383 m .29878 .61651 L .29588 .60877 L p .707 .577 .707 r
F P
0 g
s
.29099 .70429 m .29216 .68523 L .28912 .68131 L p .707 .577 .707 r
F P
0 g
s
.28912 .68131 m .28795 .70037 L .29099 .70429 L p .707 .577 .707 r
F P
0 g
s
.48967 .5159 m .49858 .56048 L .48523 .54406 L p .707 .577 .707 r
F P
0 g
s
.48523 .54406 m .47632 .49948 L .48967 .5159 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .29175 .55543 L .29777 .53514 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .30451 .61932 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29588 .60877 m .29547 .64609 L .29837 .65383 L p .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .29588 .60877 L .30127 .60308 L p .707 .577 .707 r
F P
0 g
s
.30127 .60308 m .30296 .6013 L p .30203 .60688 L .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .30127 .60308 L .30203 .60688 L .707 .577 .707 r
F
.29175 .55543 m .29623 .57786 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29623 .57786 m .30065 .60001 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49977 .61418 m .49936 .6515 L .49646 .64376 L p .707 .577 .707 r
F P
0 g
s
.49646 .64376 m .49687 .60644 L .49977 .61418 L p .707 .577 .707 r
F P
0 g
s
.4927 .69519 m .49152 .71426 L .48848 .71034 L p .707 .577 .707 r
F P
0 g
s
.48848 .71034 m .48966 .69127 L .4927 .69519 L p .707 .577 .707 r
F P
0 g
s
.47632 .49948 m .48523 .54406 L .46368 .53212 L p .707 .577 .707 r
F P
0 g
s
.46368 .53212 m .45477 .48754 L .47632 .49948 L p .707 .577 .707 r
F P
0 g
s
.30668 .57972 m .29777 .53514 L .31308 .51584 L p .707 .577 .707 r
F P
0 g
s
.29777 .53514 m .30668 .57972 L .30065 .60001 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28795 .70037 m .28912 .68131 L .29605 .67807 L p .707 .577 .707 r
F P
0 g
s
.29605 .67807 m .29487 .69713 L .28795 .70037 L p .707 .577 .707 r
F P
0 g
s
.30296 .6013 m .30255 .63861 L .29547 .64609 L p .707 .577 .707 r
F P
0 g
s
.49687 .60644 m .49646 .64376 L .48386 .63651 L p .707 .577 .707 r
F P
0 g
s
.48386 .63651 m .48428 .5992 L .49687 .60644 L p .707 .577 .707 r
F P
0 g
s
.45477 .48754 m .46368 .53212 L .43606 .52584 L p .707 .577 .707 r
F P
0 g
s
.43606 .52584 m .42715 .48126 L .45477 .48754 L p .707 .577 .707 r
F P
0 g
s
.31308 .51584 m .32198 .56042 L .30668 .57972 L p .707 .577 .707 r
F P
0 g
s
.32198 .56042 m .31308 .51584 L .33617 .49943 L p .707 .577 .707 r
F P
0 g
s
.48966 .69127 m .48848 .71034 L .47577 .70612 L p .707 .577 .707 r
F P
0 g
s
.47577 .70612 m .47695 .68706 L .48966 .69127 L p .707 .577 .707 r
F P
0 g
s
.30255 .63861 m .30296 .6013 L .31933 .59482 L p .707 .577 .707 r
F P
0 g
s
.42715 .48126 m .43606 .52584 L .40505 .52582 L p .707 .577 .707 r
F P
0 g
s
.40505 .52582 m .39614 .48125 L .42715 .48126 L p .707 .577 .707 r
F P
0 g
s
.34508 .54401 m .33617 .49943 L .3648 .48751 L p .707 .577 .707 r
F P
0 g
s
.33617 .49943 m .34508 .54401 L .32198 .56042 L p .707 .577 .707 r
F P
0 g
s
.29487 .69713 m .29605 .67807 L .31225 .67583 L p .707 .577 .707 r
F P
0 g
s
.31225 .67583 m .31108 .69489 L .29487 .69713 L p .707 .577 .707 r
F P
0 g
s
.31933 .59482 m .31891 .63214 L .30255 .63861 L p .707 .577 .707 r
F P
0 g
s
.39614 .48125 m .40505 .52582 L .3737 .53209 L p .707 .577 .707 r
F P
0 g
s
.3737 .53209 m .3648 .48751 L .39614 .48125 L p .707 .577 .707 r
F P
0 g
s
.3648 .48751 m .3737 .53209 L .34508 .54401 L p .707 .577 .707 r
F P
0 g
s
.48428 .5992 m .48386 .63651 L .4628 .63047 L p .707 .577 .707 r
F P
0 g
s
.4628 .63047 m .46322 .59315 L .48428 .5992 L p .707 .577 .707 r
F P
0 g
s
.47695 .68706 m .47577 .70612 L .45464 .70202 L p .707 .577 .707 r
F P
0 g
s
.45464 .70202 m .45582 .68296 L .47695 .68706 L p .707 .577 .707 r
F P
0 g
s
.31891 .63214 m .31933 .59482 L .34337 .58997 L p .707 .577 .707 r
F P
0 g
s
.31108 .69489 m .31225 .67583 L .33616 .6748 L p .707 .577 .707 r
F P
0 g
s
.33616 .6748 m .33498 .69386 L .31108 .69489 L p .707 .577 .707 r
F P
0 g
s
.34337 .58997 m .34296 .62729 L .31891 .63214 L p .707 .577 .707 r
F P
0 g
s
.46322 .59315 m .4628 .63047 L .43534 .62622 L p .707 .577 .707 r
F P
0 g
s
.43534 .62622 m .43576 .5889 L .46322 .59315 L p .707 .577 .707 r
F P
0 g
s
.45582 .68296 m .45464 .70202 L .42716 .69844 L p .707 .577 .707 r
F P
0 g
s
.42716 .69844 m .42834 .67938 L .45582 .68296 L p .707 .577 .707 r
F P
0 g
s
.34296 .62729 m .34337 .58997 L .37275 .58723 L p .707 .577 .707 r
F P
0 g
s
.33498 .69386 m .33616 .6748 L .36543 .67509 L p .707 .577 .707 r
F P
0 g
s
.36543 .67509 m .36425 .69415 L .33498 .69386 L p .707 .577 .707 r
F P
0 g
s
.43576 .5889 m .43534 .62622 L .40417 .62418 L p .707 .577 .707 r
F P
0 g
s
.40417 .62418 m .40459 .58686 L .43576 .5889 L p .707 .577 .707 r
F P
0 g
s
.37275 .58723 m .37234 .62454 L .34296 .62729 L p .707 .577 .707 r
F P
0 g
s
.37234 .62454 m .37275 .58723 L .40459 .58686 L p .707 .577 .707 r
F P
0 g
s
.42834 .67938 m .42716 .69844 L .39601 .69573 L p .707 .577 .707 r
F P
0 g
s
.39601 .69573 m .39719 .67667 L .42834 .67938 L p .707 .577 .707 r
F P
0 g
s
.40459 .58686 m .40417 .62418 L .37234 .62454 L p .707 .577 .707 r
F P
0 g
s
.36425 .69415 m .36543 .67509 L .39719 .67667 L p .707 .577 .707 r
F P
0 g
s
.39719 .67667 m .39601 .69573 L .36425 .69415 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolM001oOol007eoo`@0
0003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00H007Uoo`00NGoo10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1000MGoo001eOol40009FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001bOol0079oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006moo`00KWoo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P00KGoo001/Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH2001/Ool006Yoo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00001ZOol006Uoo`04001JEUYF
0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF0000JGoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVQoo`00IGoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYFJ7oo001TOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEVMoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Eoo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEPd000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00D005YFFUH005YF00@0
009JEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00<005YF00000P001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol30009FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006=oo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00HGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00Ggoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Eoo`00GGoo0`0025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8006Eoo`00G7oo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Yoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001IOol00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001HOol20006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol05Woo3000@Goo001GOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool04Woo10000UYF00<005YFFUH01EYF00<005YF00000`00?Goo001FOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000moo`@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<003Yoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00@000QJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Goo0P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30004FUH01@00FUIJEUYF
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo
0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00=Woo001D
Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH20003FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0027oo0P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YFFUIJEP8003Aoo`00E7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0`0000EJEP00FUIJEP0000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<000QJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00Dgoo0P00
1EYF00<005YFFUH01EYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000bOol005=oo`03001JEP0000AJEP03001JEUYF00=J
EP8000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool01@00FUIJEUYF000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00<Woo001BOol01000FUIJEP001EYF00D005YFFUIJEP0000Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000a
Ool0059oo`04001JEUYF0005FUH01000FUIJEP001goo00@005YFFUH000EJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003Ool005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000`Ool0059oo`04
001JEUYF0005FUH30008Ool01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00@005YF
FUIJEP800003FUH0000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF000`Ool0059oo`80009JEP03001JEUYF009JEP03001oogoo00Qo
o`04001JEUYF0005FUH30008FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF0000<7oo001COol01000FUIJEP000eYF00<007ooOol02Goo00@005YFFUH000AJEPD0
00MJEP03001JEUYF00QJEP04001JEUYF0002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000FUIJEP00;goo0017Ool=0002FUH01000FUIJ
EP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001JEP0000=JEP03001JEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH5000AOol50004FUH01000FUIJEP00;goo0013Ool40002FUH00`00FUIJ
EP06FUH20002FUH01000FUIJEP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001J
EP0000=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00eYF0P006goo0P000UYF00@005YFFUH002mo
o`00@7oo0`001UYF00<005YFFUH01UYF0`000UYF10002goo00@005YFFUH000EJEP<000QJEP03001J
EUYF00QJEP8000AJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00@005YFFUIJEP8001moo`06001JEUYF001JEP00
;goo000nOol30009FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP030009Ool01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH01eYF0`001EYF00<005YF000015YF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00@005YF0000
029oo`<0009JEP03001oogoo02aoo`00?7oo0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
0UYF00@005YFFUH0009JEP03001oogoo00Ioo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP001EYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF0P009Woo00@005YFFUH002ioo`00>Woo0P00
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000Ioo`04
001JEUYF0005FUH80003FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF00<005YF000015YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP02
FUH2000YOol00`00FUH0000^Ool003Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF009JEPl000AJEP04001JEUYFFUH800000eYF00000005FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000:goo0`00;Woo000fOol30008FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEUYF1P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00eYF0`00;7oo00@005YF000002eo
o`00=Goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP00FUH50005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020005
FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00Oomoo`0AOol3000GOol20002FUH00`00Oomoo`0[Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH40006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJ
EP02FUH00`00Oomoo`0AOol5000EOol00`00FUH00002FUH00`00Oomoo`0[Ool0039oo`03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH0000D
Ool5000DOol01000FUIJEP000UYF00<007ooOol0:goo000aOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000EOol5000COol0
0`00FUIJEP02FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000FOol3000COol00`00
FUIJEP03FUH01000FUIJEP00;7oo000_Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
15YF3@000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP00009JEP@002Yoo`8000EJEP04001JEUYF000/Ool002moo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool00`00Ool00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000UYF0P0000AJEP00000002Moo`03001JEP0000EJEP04001JEUYF000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP@000ioo`<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH20000
15YF001JEUYF0P008goo0P000eYF00<005YFFUH00UYF00@005YFFUH002aoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00eYF0P004Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00FUH30002FUH01000FUIJEUYF0P00
1Woo5`000goo00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUH00002000DOol00`00FUH00003FUH01000FUIJEUYF2@0025YF0`00
1EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF00@005YFFUIJEPP000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEP8002eoo`00;7oo0P001EYF00<0
05YFFUH01EYF0P005goo00<005YF00000eYF100000=JEP00FUH01EYF00<005YFFUH01EYF1@001UYF
00<005YFFUH00eYF1P0015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YF1`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1P001EYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH2
000IOol01000FUH005YF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH0
1UYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001oogoo02aoo`00
:goo00@005YFFUH000EJEP05001JEUYFFUH0000KOol00`00FUH000020002FUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH20005FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000^Ool002]oo`04001JEUYF0005FUH01000FUIJEP0077oo0P000UYF00<005YFFUH00UYF00@0
05YFFUH000IJEP03001JEUYF00EJEP<000QJEP04001JEUYFFUH30006FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool01000FUIJEP001EYF0`007Goo00D005YFFUIJEP00
00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`05001JEUYFFUH00004FUH00`00Oomo
o`0MOol01@00FUIJEUYF00001EYF00<005YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/
Ool01000FUIJEP000eYF00<007ooOol04Woo0`002Goo00D005YFFUIJEP0000EJEP03001JEUYF00=J
EQ80009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo019oo`D000Uoo`04001JEUYF0005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo
019oo`D000Yoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEUYF
0P005Goo1@0037oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP02FUHA0007FUH80004FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`04001JEUYF000GOol3000@Ool70004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEP00008000MJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00AJEPH000AJEP03001JEUYF008002eoo`00;Goo00@005YFFUH002]oo`04001JEUYF
0002FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`0000IJEP00000005YF0002FUH2000]Ool0
02eoo`03001JEP0002]oob<000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEP00FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF
00<005YFFUH015YF0P0015YF00@005YF0000009JEP8002eoo`00;Goo00<005YF000097oo20000eYF
00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP800003FUH005YF008000=JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF009JEP<000EJEP04001JEUYFFUH4000]
Ool002ioo`03FUH00000025oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH20007FUH30007FUH0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEP000080
01moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH70003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01UYF00<005YFFUH0
15YF10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000^Ool00`00FUH00002FUH2000:
OolA0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03
001JEUYF00D000QJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@005YF
FUH000=JEPX000=JEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Woo000^Ool01@00FUIJEP00FUH010000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF7`0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool2000015YF000000001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000`001EYF00@005YFFUIJEPT00003FUH005YF00EJ
EP04001JEUYFFUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP/000MJEP03001JEP0000H000=JEP06001JEUYF
001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800006
Ool00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00<goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0;
FUH00`00FUIJEP06FUH500000eYF00000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0017oo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000Woo0P000eYF00<005YF00007`00>Woo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF7`00AWoo000]Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
2@0015YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YF000025YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2000?Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
00=JEP000000200025YF00<005YFFUH02EYF10002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPL003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03
001JEUYF00QJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003=oo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEPT000aJEPT000QJEP03001JEUYF00IJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0035oo`00;Goo00<005YF00000eYF00@005YFFUIJEPP00003FUH005YF
00EJEPD000MJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P00
0UYF00<005YFFUH01UYF0P000eYF00@005YFFUIJEQ4000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYF000`Ool002eoo`03001JEP0000=JEPL000IJEP03001JEUYF00AJ
EPD000MJEP03001JEP0000T000=JEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH9
00000eYF001JEP02FUH80004Ool80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000]Ool01000FUH005YF0P0015YF00<005YF00000`0015YF00<005YFFUH015YF0`0015YF
1`000eYF00<005YFFUH00eYF10000eYF00<007ooFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF500015YF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00;Goo00<005YF00000P001EYF00<005YFFUH00eYF4P000UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool00eYF00<005YFFUH00eYF
00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF0`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000=JEP04001JEUYFFUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH300001GooFUIJEUYF00001EYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00D005YFFUIJEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002mo
o`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYFFUH005YF001oo`=JEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF1000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH00000FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000_Ool002eoob4000=JEP03001JEUYF00EJEP03001JEUYF
00AJEP08001JEUYFFUH005YF001oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP0B0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000`Ool002]oo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001J
EUYF00AJEP04001JEUYFFUH20002Ool3FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00P002Woo5P00=7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00D005YFFUIJ
EP0000=oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH00P00E7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP070004Ool2FUH01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF008005Aoo`00:Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000goo00=JEP00FUH00eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001P0015YF00<005YFFUH00P00E7oo000ZOol00`00FUH00002FUHF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0000AJEP00FUIJ
EP8005Aoo`00:Woo00<005YF00000`001EYF00@005YFFUIJEPT0009ooa8000AJEP03001JEUYF00=J
EP04001JEUYFFUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020005
FUH01000FUH000000UYF0P00E7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK0003FUH01P00FUIJEP00FUH0009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP05001JEP00FUH00005FUH01000FUIJEUYF1000E7oo000[Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH20003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH3001DOol002eoo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000Aoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00<Woo1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
00Aoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH00`00FUH0001DOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001Goo00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001EOol0049oo`T000AJEP03001JEUYF00EJEP04001JEUYFFUH9
0007Ool200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEP000eYF1P000eYF00@005YFFUIJEP8005Ioo`00Bgoo
40004Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF10001eYF00<005YF00000`0000=JEP000000F7oo001^Ool20007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF
001JEP07FUH00`00FUIJEP02FUH3001IOol0071oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001GOol0079oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000D000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008005Ioo`00M7oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2@0000=oo`0000001P0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00MWoo
1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEPH0009JEP03001JEP0001@000=J
EP04001JEUYFFUH2001FOol007eoo`/000IJEP03001JEUYF00AJEPX000QJEP03001JEP0000@0009J
EP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8005Ioo`00R7oo3@0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
05Ioo`00Tgoo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000EWoo002JOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP04001GOol00:=ooal005]oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63519 .77235 m .62628 .72777 L .59493 .73403 L p .707 .577 .707 r
F P
0 g
s
.62628 .72777 m .63519 .77235 L .66381 .76043 L p .707 .577 .707 r
F P
0 g
s
.66381 .76043 m .6549 .71585 L .62628 .72777 L p .707 .577 .707 r
F P
0 g
s
.62829 .81117 m .62871 .77385 L .59688 .77422 L p .707 .577 .707 r
F P
0 g
s
.60384 .77861 m .59493 .73403 L .56393 .73402 L p .707 .577 .707 r
F P
0 g
s
.59493 .73403 m .60384 .77861 L .63519 .77235 L p .707 .577 .707 r
F P
0 g
s
.6549 .71585 m .66381 .76043 L .68691 .74401 L p .707 .577 .707 r
F P
0 g
s
.68691 .74401 m .678 .69943 L .6549 .71585 L p .707 .577 .707 r
F P
0 g
s
.59646 .81153 m .59688 .77422 L .5657 .77217 L p .707 .577 .707 r
F P
0 g
s
.57284 .7786 m .56393 .73402 L .5363 .72774 L p .707 .577 .707 r
F P
0 g
s
.59688 .77422 m .59646 .81153 L .62829 .81117 L p .707 .577 .707 r
F P
0 g
s
.56393 .73402 m .57284 .7786 L .60384 .77861 L p .707 .577 .707 r
F P
0 g
s
.58926 .83371 m .59044 .81465 L .55929 .81194 L p .707 .577 .707 r
F P
0 g
s
.59044 .81465 m .58926 .83371 L .62102 .83529 L p .707 .577 .707 r
F P
0 g
s
.62102 .83529 m .6222 .81623 L .59044 .81465 L p .707 .577 .707 r
F P
0 g
s
.55929 .81194 m .55811 .831 L .58926 .83371 L p .707 .577 .707 r
F P
0 g
s
.6222 .81623 m .62102 .83529 L .65029 .83558 L p .707 .577 .707 r
F P
0 g
s
.65029 .83558 m .65147 .81652 L .6222 .81623 L p .707 .577 .707 r
F P
0 g
s
.55811 .831 m .55929 .81194 L .53181 .80836 L p .707 .577 .707 r
F P
0 g
s
.62871 .77385 m .62829 .81117 L .65767 .80842 L p .707 .577 .707 r
F P
0 g
s
.65767 .80842 m .65809 .77111 L .62871 .77385 L p .707 .577 .707 r
F P
0 g
s
.53181 .80836 m .53063 .82742 L .55811 .831 L p .707 .577 .707 r
F P
0 g
s
.678 .69943 m .68691 .74401 L .70221 .72471 L p .707 .577 .707 r
F P
0 g
s
.70221 .72471 m .69331 .68014 L .678 .69943 L p .707 .577 .707 r
F P
0 g
s
.56529 .80949 m .5657 .77217 L .53825 .76792 L p .707 .577 .707 r
F P
0 g
s
.54521 .77231 m .5363 .72774 L .51476 .7158 L p .707 .577 .707 r
F P
0 g
s
.5657 .77217 m .56529 .80949 L .59646 .81153 L p .707 .577 .707 r
F P
0 g
s
.5363 .72774 m .54521 .77231 L .57284 .7786 L p .707 .577 .707 r
F P
0 g
s
.65147 .81652 m .65029 .83558 L .6742 .83455 L p .707 .577 .707 r
F P
0 g
s
.6742 .83455 m .67538 .81549 L .65147 .81652 L p .707 .577 .707 r
F P
0 g
s
.65809 .77111 m .65767 .80842 L .68172 .80358 L p .707 .577 .707 r
F P
0 g
s
.68172 .80358 m .68214 .76626 L .65809 .77111 L p .707 .577 .707 r
F P
0 g
s
.53825 .76792 m .53783 .80524 L .56529 .80949 L p .707 .577 .707 r
F P
0 g
s
.53063 .82742 m .53181 .80836 L .51068 .80426 L p .707 .577 .707 r
F P
0 g
s
.51068 .80426 m .5095 .82332 L .53063 .82742 L p .707 .577 .707 r
F P
0 g
s
.53783 .80524 m .53825 .76792 L .51719 .76188 L p .707 .577 .707 r
F P
0 g
s
.69331 .68014 m .70221 .72471 L .70824 .70442 L p .707 .577 .707 r
F P
0 g
s
.70824 .70442 m .69933 .65984 L .69331 .68014 L p .707 .577 .707 r
F P
0 g
s
.52367 .76038 m .51476 .7158 L .50141 .69937 L p .707 .577 .707 r
F P
0 g
s
.51476 .7158 m .52367 .76038 L .54521 .77231 L p .707 .577 .707 r
F P
0 g
s
.67538 .81549 m .6742 .83455 L .69041 .83231 L p .707 .577 .707 r
F P
0 g
s
.69041 .83231 m .69158 .81325 L .67538 .81549 L p .707 .577 .707 r
F P
0 g
s
.51719 .76188 m .51677 .7992 L .53783 .80524 L p .707 .577 .707 r
F P
0 g
s
.68214 .76626 m .68172 .80358 L .69808 .7971 L p .707 .577 .707 r
F P
0 g
s
.69808 .7971 m .6985 .75978 L .68214 .76626 L p .707 .577 .707 r
F P
0 g
s
.5095 .82332 m .51068 .80426 L .49797 .80004 L p .707 .577 .707 r
F P
0 g
s
.49797 .80004 m .49679 .81911 L .5095 .82332 L p .707 .577 .707 r
F P
0 g
s
.51677 .7992 m .51719 .76188 L .50459 .75463 L p .707 .577 .707 r
F P
0 g
s
.69933 .65984 m .70824 .70442 L .70438 .68511 L p .636 .53 .717 r
F P
0 g
s
.70438 .68511 m .69548 .64054 L .69933 .65984 L p .636 .53 .717 r
F P
0 g
s
.50141 .69937 m .51031 .74395 L .52367 .76038 L p .707 .577 .707 r
F P
0 g
s
.51031 .74395 m .50141 .69937 L .49755 .68007 L p .634 .529 .717 r
F P
0 g
s
.50459 .75463 m .50418 .79195 L .51677 .7992 L p .707 .577 .707 r
F P
0 g
s
.69158 .81325 m .69041 .83231 L .69733 .82907 L p .707 .577 .707 r
F P
0 g
s
.69733 .82907 m .69851 .81001 L .69158 .81325 L p .707 .577 .707 r
F P
0 g
s
.6985 .75978 m .69808 .7971 L .70516 .78962 L p .707 .577 .707 r
F P
0 g
s
.70516 .78962 m .70558 .7523 L .6985 .75978 L p .707 .577 .707 r
F P
0 g
s
.49679 .81911 m .49797 .80004 L .49493 .79612 L p .707 .577 .707 r
F P
0 g
s
.49493 .79612 m .49375 .81519 L .49679 .81911 L p .707 .577 .707 r
F P
0 g
s
.49375 .81519 m .49493 .79612 L .50185 .79288 L p .707 .577 .707 r
F P
0 g
s
.50185 .79288 m .50067 .81195 L .49375 .81519 L p .707 .577 .707 r
F P
0 g
s
.50067 .81195 m .50185 .79288 L .51806 .79064 L p .707 .577 .707 r
F P
0 g
s
.51806 .79064 m .51688 .8097 L .50067 .81195 L p .707 .577 .707 r
F P
0 g
s
.50256 .82491 m .48455 .33728 L .44056 .33523 L p .707 .577 .707 r
F P
0 g
s
.50418 .79195 m .50459 .75463 L .50169 .74689 L p .707 .577 .707 r
F P
0 g
s
.50646 .72465 m .49755 .68007 L .50358 .65977 L p .707 .577 .707 r
F P
0 g
s
.49755 .68007 m .50646 .72465 L .51031 .74395 L p .634 .529 .717 r
F P
0 g
s
.50169 .74689 m .50127 .78421 L .50418 .79195 L p .707 .577 .707 r
F P
0 g
s
.51248 .70435 m .50358 .65977 L .51888 .64047 L p .707 .577 .707 r
F P
0 g
s
.50358 .65977 m .51248 .70435 L .50646 .72465 L p .707 .577 .707 r
F P
0 g
s
.50127 .78421 m .50169 .74689 L .50877 .73941 L p .707 .577 .707 r
F P
0 g
s
.50877 .73941 m .50835 .77673 L .50127 .78421 L p .707 .577 .707 r
F P
0 g
s
.51888 .64047 m .52779 .68505 L .51248 .70435 L p .707 .577 .707 r
F P
0 g
s
.52779 .68505 m .51888 .64047 L .54198 .62406 L p .707 .577 .707 r
F P
0 g
s
.54198 .62406 m .55089 .66864 L .52779 .68505 L p .707 .577 .707 r
F P
0 g
s
.50835 .77673 m .50877 .73941 L .52513 .73294 L p .707 .577 .707 r
F P
0 g
s
.52513 .73294 m .52472 .77025 L .50835 .77673 L p .707 .577 .707 r
F P
0 g
s
.51688 .8097 m .51806 .79064 L .54197 .78961 L p .707 .577 .707 r
F P
0 g
s
.54197 .78961 m .54079 .80868 L .51688 .8097 L p .707 .577 .707 r
F P
0 g
s
.52472 .77025 m .52513 .73294 L .54918 .72809 L p .707 .577 .707 r
F P
0 g
s
.54918 .72809 m .54876 .76541 L .52472 .77025 L p .707 .577 .707 r
F P
0 g
s
.54079 .80868 m .54197 .78961 L .57124 .7899 L p .707 .577 .707 r
F P
0 g
s
.57124 .7899 m .57006 .80897 L .54079 .80868 L p .707 .577 .707 r
F P
0 g
s
.48455 .33728 m .50256 .82491 L .54747 .822 L p .707 .577 .707 r
F P
0 g
s
.54747 .822 m .52946 .33437 L .48455 .33728 L p .707 .577 .707 r
F P
0 g
s
.55089 .66864 m .54198 .62406 L .5706 .61214 L p .707 .577 .707 r
F P
0 g
s
.5706 .61214 m .57951 .65672 L .55089 .66864 L p .707 .577 .707 r
F P
0 g
s
.54876 .76541 m .54918 .72809 L .57856 .72535 L p .707 .577 .707 r
F P
0 g
s
.57856 .72535 m .57814 .76266 L .54876 .76541 L p .707 .577 .707 r
F P
0 g
s
.57006 .80897 m .57124 .7899 L .603 .79148 L p .707 .577 .707 r
F P
0 g
s
.57814 .76266 m .57856 .72535 L .61039 .72498 L p .707 .577 .707 r
F P
0 g
s
.603 .79148 m .60182 .81054 L .57006 .80897 L p .707 .577 .707 r
F P
0 g
s
.61039 .72498 m .60998 .76229 L .57814 .76266 L p .707 .577 .707 r
F P
0 g
s
.52946 .33437 m .54747 .822 L .5889 .81441 L p .707 .577 .707 r
F P
0 g
s
.60195 .60588 m .61086 .65046 L .57951 .65672 L p .707 .577 .707 r
F P
0 g
s
.57951 .65672 m .5706 .61214 L .60195 .60588 L p .707 .577 .707 r
F P
0 g
s
.5889 .81441 m .57089 .32677 L .52946 .33437 L p .707 .577 .707 r
F P
0 g
s
.69548 .64054 m .70438 .68511 L .69103 .66869 L p .707 .577 .707 r
F P
0 g
s
.69103 .66869 m .68212 .62411 L .69548 .64054 L p .707 .577 .707 r
F P
0 g
s
.45856 .82286 m .44056 .33523 L .40178 .3284 L p .707 .577 .707 r
F P
0 g
s
.44056 .33523 m .45856 .82286 L .50256 .82491 L p .707 .577 .707 r
F P
0 g
s
.63414 .79419 m .63297 .81326 L .60182 .81054 L p .707 .577 .707 r
F P
0 g
s
.60182 .81054 m .603 .79148 L .63414 .79419 L p .707 .577 .707 r
F P
0 g
s
.64156 .72702 m .64115 .76434 L .60998 .76229 L p .707 .577 .707 r
F P
0 g
s
.60998 .76229 m .61039 .72498 L .64156 .72702 L p .707 .577 .707 r
F P
0 g
s
.57089 .32677 m .5889 .81441 L .62279 .80287 L p .707 .577 .707 r
F P
0 g
s
.63295 .60589 m .64186 .65047 L .61086 .65046 L p .707 .577 .707 r
F P
0 g
s
.61086 .65046 m .60195 .60588 L .63295 .60589 L p .707 .577 .707 r
F P
0 g
s
.62279 .80287 m .60479 .31524 L .57089 .32677 L p .707 .577 .707 r
F P
0 g
s
.69851 .81001 m .69733 .82907 L .69429 .82515 L p .707 .577 .707 r
F P
0 g
s
.69429 .82515 m .69546 .80609 L .69851 .81001 L p .707 .577 .707 r
F P
0 g
s
.70558 .7523 m .70516 .78962 L .70226 .78188 L p .707 .577 .707 r
F P
0 g
s
.70226 .78188 m .70268 .74456 L .70558 .7523 L p .707 .577 .707 r
F P
0 g
s
.41979 .81603 m .40178 .3284 L .37202 .31747 L p .707 .577 .707 r
F P
0 g
s
.40178 .3284 m .41979 .81603 L .45856 .82286 L p .707 .577 .707 r
F P
0 g
s
.68212 .62411 m .69103 .66869 L .66949 .65675 L p .707 .577 .707 r
F P
0 g
s
.66949 .65675 m .66058 .61217 L .68212 .62411 L p .707 .577 .707 r
F P
0 g
s
.63297 .81326 m .63414 .79419 L .66163 .79777 L p .707 .577 .707 r
F P
0 g
s
.66902 .73127 m .66861 .76859 L .64115 .76434 L p .707 .577 .707 r
F P
0 g
s
.64115 .76434 m .64156 .72702 L .66902 .73127 L p .707 .577 .707 r
F P
0 g
s
.60479 .31524 m .62279 .80287 L .64583 .78852 L p .707 .577 .707 r
F P
0 g
s
.64186 .65047 m .63295 .60589 L .66058 .61217 L p .707 .577 .707 r
F P
0 g
s
.64583 .78852 m .62782 .30089 L .60479 .31524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29218 .73553 m .28327 .69095 L .25192 .69721 L p .707 .577 .707 r
F P
0 g
s
.28327 .69095 m .29218 .73553 L .3208 .72361 L p .707 .577 .707 r
F P
0 g
s
.3208 .72361 m .31189 .67903 L .28327 .69095 L p .707 .577 .707 r
F P
0 g
s
.28528 .77435 m .2857 .73703 L .25387 .7374 L p .707 .577 .707 r
F P
0 g
s
.26083 .74179 m .25192 .69721 L .22092 .6972 L p .707 .577 .707 r
F P
0 g
s
.25192 .69721 m .26083 .74179 L .29218 .73553 L p .707 .577 .707 r
F P
0 g
s
.66058 .61217 m .66949 .65675 L .64186 .65047 L p .707 .577 .707 r
F P
0 g
s
.69546 .80609 m .69429 .82515 L .68158 .82093 L p .707 .577 .707 r
F P
0 g
s
.68158 .82093 m .68276 .80187 L .69546 .80609 L p .707 .577 .707 r
F P
0 g
s
.70268 .74456 m .70226 .78188 L .68967 .77463 L p .707 .577 .707 r
F P
0 g
s
.68967 .77463 m .69008 .73731 L .70268 .74456 L p .707 .577 .707 r
F P
0 g
s
.31189 .67903 m .3208 .72361 L .3439 .7072 L p .707 .577 .707 r
F P
0 g
s
.3439 .7072 m .33499 .66262 L .31189 .67903 L p .707 .577 .707 r
F P
0 g
s
.25345 .77472 m .25387 .7374 L .22269 .73536 L p .707 .577 .707 r
F P
0 g
s
.22983 .74178 m .22092 .6972 L .19329 .69092 L p .707 .577 .707 r
F P
0 g
s
.25387 .7374 m .25345 .77472 L .28528 .77435 L p .707 .577 .707 r
F P
0 g
s
.22092 .6972 m .22983 .74178 L .26083 .74179 L p .707 .577 .707 r
F P
0 g
s
.24625 .7969 m .24743 .77783 L .21628 .77512 L p .707 .577 .707 r
F P
0 g
s
.24743 .77783 m .24625 .7969 L .27801 .79848 L p .707 .577 .707 r
F P
0 g
s
.27801 .79848 m .27919 .77941 L .24743 .77783 L p .707 .577 .707 r
F P
0 g
s
.21628 .77512 m .2151 .79419 L .24625 .7969 L p .707 .577 .707 r
F P
0 g
s
.27919 .77941 m .27801 .79848 L .30728 .79877 L p .707 .577 .707 r
F P
0 g
s
.30728 .79877 m .30846 .7797 L .27919 .77941 L p .707 .577 .707 r
F P
0 g
s
.39003 .8051 m .37202 .31747 L .35419 .30352 L p .707 .577 .707 r
F P
0 g
s
.37202 .31747 m .39003 .8051 L .41979 .81603 L p .707 .577 .707 r
F P
0 g
s
.2151 .79419 m .21628 .77512 L .1888 .77154 L p .707 .577 .707 r
F P
0 g
s
.2857 .73703 m .28528 .77435 L .31466 .77161 L p .707 .577 .707 r
F P
0 g
s
.31466 .77161 m .31508 .73429 L .2857 .73703 L p .707 .577 .707 r
F P
0 g
s
.1888 .77154 m .18762 .79061 L .2151 .79419 L p .707 .577 .707 r
F P
0 g
s
.33499 .66262 m .3439 .7072 L .3592 .6879 L p .707 .577 .707 r
F P
0 g
s
.3592 .6879 m .3503 .64332 L .33499 .66262 L p .707 .577 .707 r
F P
0 g
s
.22228 .77268 m .22269 .73536 L .19524 .73111 L p .707 .577 .707 r
F P
0 g
s
.2022 .7355 m .19329 .69092 L .17175 .67898 L p .707 .577 .707 r
F P
0 g
s
.22269 .73536 m .22228 .77268 L .25345 .77472 L p .707 .577 .707 r
F P
0 g
s
.19329 .69092 m .2022 .7355 L .22983 .74178 L p .707 .577 .707 r
F P
0 g
s
.30846 .7797 m .30728 .79877 L .33119 .79774 L p .707 .577 .707 r
F P
0 g
s
.33119 .79774 m .33237 .77867 L .30846 .7797 L p .707 .577 .707 r
F P
0 g
s
.31508 .73429 m .31466 .77161 L .33871 .76676 L p .707 .577 .707 r
F P
0 g
s
.33871 .76676 m .33913 .72944 L .31508 .73429 L p .707 .577 .707 r
F P
0 g
s
.19524 .73111 m .19482 .76843 L .22228 .77268 L p .707 .577 .707 r
F P
0 g
s
.18762 .79061 m .1888 .77154 L .16767 .76744 L p .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .66901 .73036 L .65615 .72786 L p .707 .577 .707 r
F P
0 g
s
.62782 .30089 m .64583 .78852 L .65482 .77425 L p .707 .577 .707 r
F P
0 g
s
.65516 .76258 m .62782 .30089 L .65482 .77425 L .707 .577 .707 r
F
.63775 .28513 m .62782 .30089 L p .65516 .76258 L F P
0 g
s
.65576 .77276 m .65525 .75913 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .63775 .28513 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.64788 .72626 m .6467 .74532 L .65443 .74682 L p .707 .577 .707 r
F P
0 g
s
.65419 .74326 m .64788 .72626 L .65443 .74682 L .707 .577 .707 r
F
.64885 .66332 m .64721 .60747 L .65525 .75913 L F
.63775 .28513 m .64879 .5842 L p .64721 .60747 L F P
0 g
s
.64879 .5842 m .65525 .75913 L p .64721 .60747 L .707 .577 .707 r
F P
0 g
s
.65593 .7356 m .65349 .73277 L .6556 .74705 L .707 .577 .707 r
F
.65349 .73277 m .64788 .72626 L .65419 .74326 L F
.65349 .73277 m .65419 .74326 L .6556 .74705 L F
.6336 .26951 m .63775 .28513 L p .64885 .66332 L F P
0 g
s
.65615 .72786 m .64788 .72626 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64726 .63956 L .64885 .66332 L .707 .577 .707 r
F
.64949 .69983 m .64726 .63956 L p .65036 .71465 L F P
0 g
s
.64726 .63956 m .6336 .26951 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.65482 .77425 m .65576 .77276 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65576 .77276 m .6532 .76315 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.6532 .76315 m .6516 .75714 L p .65036 .71465 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64885 .66332 L .6532 .76315 L .707 .577 .707 r
F
.6467 .74532 m .64788 .72626 L .63518 .72204 L p F P
0 g
s
.63518 .72204 m .634 .74111 L .6467 .74532 L p .707 .577 .707 r
F P
0 g
s
.634 .74111 m .63518 .72204 L .63213 .71812 L p .707 .577 .707 r
F P
0 g
s
.63213 .71812 m .63096 .73719 L .634 .74111 L p .707 .577 .707 r
F P
0 g
s
.6336 .26951 m .6516 .75714 L .63393 .7433 L p .707 .577 .707 r
F P
0 g
s
.63096 .73719 m .6337 .71739 L .63381 .72934 L .707 .577 .707 r
F
.63377 .72496 m .6336 .26951 L .63393 .7433 L F
.63906 .71488 m .63788 .73395 L .63386 .73583 L p F P
0 g
s
.63386 .73583 m .63096 .73719 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.63381 .72934 m .63906 .71488 L .63386 .73583 L .707 .577 .707 r
F
.63096 .73719 m .63213 .71812 L .6337 .71739 L p F P
0 g
s
.63378 .74318 m .61577 .25555 L .62985 .26658 L p .707 .577 .707 r
F P
0 g
s
.62985 .26658 m .6336 .26951 L p .63377 .72496 L .707 .577 .707 r
F P
0 g
s
.63378 .74318 m .62985 .26658 L .63377 .72496 L .707 .577 .707 r
F
.63393 .7433 m .63378 .74318 L p .63377 .72496 L F P
0 g
s
.6337 .71739 m .63906 .71488 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.6418 .65333 m .64138 .69065 L .64921 .69515 L p .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .65576 .77276 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.64921 .69515 m .65398 .69789 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.64812 .67646 m .6418 .65333 L .64921 .69515 L .707 .577 .707 r
F
.65398 .69789 m .65439 .66058 L .64693 .65628 L p F P
0 g
s
.64693 .65628 m .6418 .65333 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.65398 .69789 m .64693 .65628 L .64812 .67646 L .707 .577 .707 r
F
.6516 .75714 m .64949 .69983 L p .65036 .71465 L F P
0 g
s
.67503 .70394 m .67529 .68121 L p .65439 .66058 L .707 .577 .707 r
F P
0 g
s
.67529 .68121 m .67545 .66662 L .6664 .66402 L p .707 .577 .707 r
F P
0 g
s
.6664 .66402 m .65439 .66058 L p .67529 .68121 L .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .64629 .621 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .65461 .64121 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.65461 .64121 m .65196 .62798 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.64629 .621 m .63861 .61155 L p .64563 .63078 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .64629 .621 L .64563 .63078 L .707 .577 .707 r
F
.65443 .74682 m .6556 .74705 L p .65419 .74326 L F P
0 g
s
.6556 .74705 m .66783 .74942 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .65615 .72786 L .65593 .7356 L .707 .577 .707 r
F
.68276 .80187 m .68158 .82093 L .66045 .81684 L p F P
0 g
s
.66045 .81684 m .66163 .79777 L .68276 .80187 L p .707 .577 .707 r
F P
0 g
s
.16767 .76744 m .16649 .78651 L .18762 .79061 L p .707 .577 .707 r
F P
0 g
s
.69008 .73731 m .68967 .77463 L .66861 .76859 L p .707 .577 .707 r
F P
0 g
s
.66861 .76859 m .66902 .73127 L .69008 .73731 L p .707 .577 .707 r
F P
0 g
s
.19482 .76843 m .19524 .73111 L .17418 .72506 L p .707 .577 .707 r
F P
0 g
s
.3503 .64332 m .3592 .6879 L .36523 .6676 L p .707 .577 .707 r
F P
0 g
s
.36523 .6676 m .35632 .62303 L .3503 .64332 L p .707 .577 .707 r
F P
0 g
s
.18066 .72356 m .17175 .67898 L .1584 .66256 L p .707 .577 .707 r
F P
0 g
s
.17175 .67898 m .18066 .72356 L .2022 .7355 L p .707 .577 .707 r
F P
0 g
s
.33237 .77867 m .33119 .79774 L .3474 .7955 L p .707 .577 .707 r
F P
0 g
s
.3474 .7955 m .34857 .77643 L .33237 .77867 L p .707 .577 .707 r
F P
0 g
s
.17418 .72506 m .17376 .76238 L .19482 .76843 L p .707 .577 .707 r
F P
0 g
s
.33913 .72944 m .33871 .76676 L .35507 .76028 L p .707 .577 .707 r
F P
0 g
s
.35507 .76028 m .35549 .72296 L .33913 .72944 L p .707 .577 .707 r
F P
0 g
s
.3722 .79115 m .35419 .30352 L .35004 .28789 L p .707 .577 .707 r
F P
0 g
s
.35419 .30352 m .3722 .79115 L .39003 .8051 L p .707 .577 .707 r
F P
0 g
s
.16649 .78651 m .16767 .76744 L .15496 .76323 L p .707 .577 .707 r
F P
0 g
s
.66163 .79777 m .66045 .81684 L .63297 .81326 L p .707 .577 .707 r
F P
0 g
s
.15496 .76323 m .15378 .78229 L .16649 .78651 L p .707 .577 .707 r
F P
0 g
s
.17376 .76238 m .17418 .72506 L .16158 .71782 L p .707 .577 .707 r
F P
0 g
s
.35632 .62303 m .36523 .6676 L .36137 .6483 L p .632 .528 .718 r
F P
0 g
s
.36137 .6483 m .35247 .60372 L .35632 .62303 L p .632 .528 .718 r
F P
0 g
s
.1584 .66256 m .1673 .70714 L .18066 .72356 L p .707 .577 .707 r
F P
0 g
s
.1673 .70714 m .1584 .66256 L .15454 .64325 L p .63 .526 .718 r
F P
0 g
s
.16158 .71782 m .16117 .75513 L .17376 .76238 L p .707 .577 .707 r
F P
0 g
s
.34857 .77643 m .3474 .7955 L .35432 .79225 L p .707 .577 .707 r
F P
0 g
s
.35432 .79225 m .3555 .77319 L .34857 .77643 L p .707 .577 .707 r
F P
0 g
s
.35549 .72296 m .35507 .76028 L .36215 .75281 L p .707 .577 .707 r
F P
0 g
s
.36215 .75281 m .36257 .71549 L .35549 .72296 L p .707 .577 .707 r
F P
0 g
s
.15378 .78229 m .15496 .76323 L .15192 .75931 L p .707 .577 .707 r
F P
0 g
s
.15192 .75931 m .15074 .77837 L .15378 .78229 L p .707 .577 .707 r
F P
0 g
s
.16117 .75513 m .16158 .71782 L .15868 .71007 L p .707 .577 .707 r
F P
0 g
s
.35247 .60372 m .36137 .6483 L .34802 .63187 L p .707 .577 .707 r
F P
0 g
s
.34802 .63187 m .33911 .5873 L .35247 .60372 L p .707 .577 .707 r
F P
0 g
s
.16345 .68783 m .15454 .64325 L .16057 .62296 L p .707 .577 .707 r
F P
0 g
s
.15454 .64325 m .16345 .68783 L .1673 .70714 L p .63 .526 .718 r
F P
0 g
s
.35004 .28789 m .36805 .77553 L .3722 .79115 L p .707 .577 .707 r
F P
0 g
s
.36805 .77553 m .35004 .28789 L .35997 .27214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15868 .71007 m .15826 .74739 L .16117 .75513 L p .707 .577 .707 r
F P
0 g
s
.3555 .77319 m .35432 .79225 L .35128 .78834 L p .707 .577 .707 r
F P
0 g
s
.35128 .78834 m .35246 .76927 L .3555 .77319 L p .707 .577 .707 r
F P
0 g
s
.36257 .71549 m .36215 .75281 L .35925 .74507 L p .707 .577 .707 r
F P
0 g
s
.35925 .74507 m .35967 .70775 L .36257 .71549 L p .707 .577 .707 r
F P
0 g
s
.33911 .5873 m .34802 .63187 L .32648 .61994 L p .707 .577 .707 r
F P
0 g
s
.32648 .61994 m .31757 .57536 L .33911 .5873 L p .707 .577 .707 r
F P
0 g
s
.16947 .66754 m .16057 .62296 L .17587 .60366 L p .707 .577 .707 r
F P
0 g
s
.16057 .62296 m .16947 .66754 L .16345 .68783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15074 .77837 m .15192 .75931 L .15884 .75607 L p .707 .577 .707 r
F P
0 g
s
.15884 .75607 m .15766 .77513 L .15074 .77837 L p .707 .577 .707 r
F P
0 g
s
.15826 .74739 m .15868 .71007 L .16576 .7026 L p .707 .577 .707 r
F P
0 g
s
.16576 .7026 m .16534 .73992 L .15826 .74739 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.31757 .57536 m .32648 .61994 L .29885 .61365 L p .707 .577 .707 r
F P
0 g
s
.29885 .61365 m .28995 .56908 L .31757 .57536 L p .707 .577 .707 r
F P
0 g
s
.17587 .60366 m .18478 .64824 L .16947 .66754 L p .707 .577 .707 r
F P
0 g
s
.18478 .64824 m .17587 .60366 L .19897 .58725 L p .707 .577 .707 r
F P
0 g
s
.37797 .75977 m .35997 .27214 L .383 .25779 L p .707 .577 .707 r
F P
0 g
s
.35997 .27214 m .37797 .75977 L .36805 .77553 L p .707 .577 .707 r
F P
0 g
s
.35246 .76927 m .35128 .78834 L .33857 .78412 L p .707 .577 .707 r
F P
0 g
s
.33857 .78412 m .33975 .76506 L .35246 .76927 L p .707 .577 .707 r
F P
0 g
s
.35967 .70775 m .35925 .74507 L .34666 .73782 L p .707 .577 .707 r
F P
0 g
s
.34666 .73782 m .34707 .7005 L .35967 .70775 L p .707 .577 .707 r
F P
0 g
s
.15766 .77513 m .15884 .75607 L .17505 .75382 L p .707 .577 .707 r
F P
0 g
s
.17505 .75382 m .17387 .77289 L .15766 .77513 L p .707 .577 .707 r
F P
0 g
s
.28995 .56908 m .29885 .61365 L .26785 .61364 L p .707 .577 .707 r
F P
0 g
s
.26785 .61364 m .25894 .56906 L .28995 .56908 L p .707 .577 .707 r
F P
0 g
s
.20788 .63182 m .19897 .58725 L .22759 .57533 L p .707 .577 .707 r
F P
0 g
s
.19897 .58725 m .20788 .63182 L .18478 .64824 L p .707 .577 .707 r
F P
0 g
s
.16534 .73992 m .16576 .7026 L .18212 .69612 L p .707 .577 .707 r
F P
0 g
s
.61577 .25555 m .63378 .74318 L .60402 .73226 L p .707 .577 .707 r
F P
0 g
s
.60402 .73226 m .58601 .24463 L .61577 .25555 L p .707 .577 .707 r
F P
0 g
s
.25894 .56906 m .26785 .61364 L .2365 .6199 L p .707 .577 .707 r
F P
0 g
s
.2365 .6199 m .22759 .57533 L .25894 .56906 L p .707 .577 .707 r
F P
0 g
s
.22759 .57533 m .2365 .6199 L .20788 .63182 L p .707 .577 .707 r
F P
0 g
s
.18212 .69612 m .18171 .73344 L .16534 .73992 L p .707 .577 .707 r
F P
0 g
s
.33975 .76506 m .33857 .78412 L .31744 .78002 L p .707 .577 .707 r
F P
0 g
s
.31744 .78002 m .31862 .76096 L .33975 .76506 L p .707 .577 .707 r
F P
0 g
s
.34707 .7005 m .34666 .73782 L .3256 .73177 L p .707 .577 .707 r
F P
0 g
s
.3256 .73177 m .32601 .69445 L .34707 .7005 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .40659 .57025 L .42095 .65324 L .707 .577 .707 r
F
.37797 .75977 m .38063 .49454 L .40016 .73492 L F
.40101 .74542 m .39884 .74678 L p .40016 .73492 L F P
0 g
s
.39884 .74678 m .37797 .75977 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.3934 .53939 m .40051 .73179 L p .38063 .49454 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .40101 .74542 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.38063 .49454 m .40051 .73179 L .40016 .73492 L .707 .577 .707 r
F
.40521 .71372 m .40271 .71204 L .4036 .7199 L F
.383 .25779 m .4169 .24625 L p .40158 .72768 L F P
0 g
s
.40101 .74542 m .40051 .73179 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .383 .25779 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .41639 .70141 L .40851 .70102 L p .707 .577 .707 r
F P
0 g
s
.40851 .70102 m .38463 .69984 L p .40521 .71372 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .40851 .70102 L .40521 .71372 L .707 .577 .707 r
F
.40271 .71204 m .38463 .69984 L .40202 .71823 L F
.40271 .71204 m .40202 .71823 L .4036 .7199 L F
.38463 .69984 m .38345 .7189 L .40184 .71981 L p F P
0 g
s
.40184 .71981 m .4036 .7199 L p .40202 .71823 L .707 .577 .707 r
F P
0 g
s
.40202 .71823 m .38463 .69984 L .40184 .71981 L .707 .577 .707 r
F
.4036 .7199 m .41522 .72048 L p .40521 .71372 L F P
0 g
s
.4349 .73388 m .40101 .74542 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41639 .70141 m .41522 .72048 L .44448 .72077 L p .707 .577 .707 r
F P
0 g
s
.44448 .72077 m .44566 .7017 L .41639 .70141 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .42095 .65324 L .42884 .69887 L .707 .577 .707 r
F
.42978 .59502 m .43279 .67657 L p .40659 .57025 L F P
0 g
s
.43279 .67657 m .4349 .73388 L p .42884 .69887 L .707 .577 .707 r
F P
0 g
s
.40659 .57025 m .43279 .67657 L .42884 .69887 L .707 .577 .707 r
F
.44566 .7017 m .44448 .72077 L .46839 .71974 L p F P
0 g
s
.46839 .71974 m .46957 .70068 L .44566 .7017 L p .707 .577 .707 r
F P
0 g
s
.45833 .23865 m .47633 .72629 L .47598 .72635 L p .707 .577 .707 r
F P
0 g
s
.46957 .70068 m .46839 .71974 L .47519 .7188 L p .707 .577 .707 r
F P
0 g
s
.47379 .7054 m .46957 .70068 L .47519 .7188 L .707 .577 .707 r
F
.44794 .45826 m .45833 .23865 L .47598 .72635 L F
.45833 .23865 m .50324 .23574 L p .49249 .4316 L F P
0 g
s
.47633 .72629 m .46927 .5351 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.46927 .5351 m .45833 .23865 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.50324 .23574 m .52124 .72337 L .47633 .72629 L p .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .48578 .69843 L .47325 .70017 L p .707 .577 .707 r
F P
0 g
s
.47325 .70017 m .46957 .70068 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .47325 .70017 L .47379 .7054 L .707 .577 .707 r
F
.47598 .72635 m .4349 .73388 L p .44794 .45826 L F P
0 g
s
.47591 .66546 m .47633 .62814 L .45228 .63299 L p .707 .577 .707 r
F P
0 g
s
.458 .63579 m .4811 .61938 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.4491 .59121 m .45267 .60909 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.45267 .60909 m .458 .63579 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.47519 .7188 m .4846 .7175 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .45228 .63299 L .4403 .63411 L p .707 .577 .707 r
F P
0 g
s
.4349 .73388 m .4169 .24625 L .45833 .23865 L p .707 .577 .707 r
F P
0 g
s
.4403 .63411 m .4229 .63573 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .4403 .63411 L .43703 .65259 L .707 .577 .707 r
F
.4229 .63573 m .42249 .67305 L .43359 .67201 L p F P
0 g
s
.43359 .67201 m .45187 .67031 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.43703 .65259 m .4229 .63573 L .43359 .67201 L .707 .577 .707 r
F
.42304 .73168 m .42884 .69887 L .4349 .73388 L F
.40158 .72768 m .42884 .69887 L .42304 .73168 L F
.4169 .24625 m .42978 .59502 L p .40659 .57025 L F P
0 g
s
.458 .63579 m .45531 .62229 L p .42047 .60313 L .707 .577 .707 r
F P
0 g
s
.45531 .62229 m .4491 .59121 L .43263 .59807 L p .707 .577 .707 r
F P
0 g
s
.43263 .59807 m .42047 .60313 L p .45531 .62229 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .42047 .60313 L .41204 .60482 L p .707 .577 .707 r
F P
0 g
s
.42249 .67305 m .42287 .63832 L p .39107 .6361 L .707 .577 .707 r
F P
0 g
s
.42287 .63832 m .4229 .63573 L .41848 .63578 L p .707 .577 .707 r
F P
0 g
s
.41848 .63578 m .39107 .6361 L p .42287 .63832 L .707 .577 .707 r
F P
0 g
s
.39065 .67342 m .391 .64197 L p .3599 .63406 L .707 .577 .707 r
F P
0 g
s
.391 .64197 m .39107 .6361 L .38228 .63552 L p .707 .577 .707 r
F P
0 g
s
.38228 .63552 m .3599 .63406 L p .391 .64197 L .707 .577 .707 r
F P
0 g
s
.35948 .67137 m .35979 .64344 L p .33244 .62981 L .707 .577 .707 r
F P
0 g
s
.35979 .64344 m .3599 .63406 L .34978 .63249 L p .707 .577 .707 r
F P
0 g
s
.34978 .63249 m .33244 .62981 L p .35979 .64344 L .707 .577 .707 r
F P
0 g
s
.33244 .62981 m .33202 .66712 L .35948 .67137 L p .707 .577 .707 r
F P
0 g
s
.33202 .66712 m .33228 .64439 L p .31138 .62376 L .707 .577 .707 r
F P
0 g
s
.33228 .64439 m .33244 .62981 L .32339 .62721 L p .707 .577 .707 r
F P
0 g
s
.32339 .62721 m .31138 .62376 L p .33228 .64439 L .707 .577 .707 r
F P
0 g
s
.31786 .63574 m .3116 .6044 L p .2956 .57474 L .707 .577 .707 r
F P
0 g
s
.3116 .6044 m .30895 .59116 L .29741 .57697 L p .707 .577 .707 r
F P
0 g
s
.29741 .57697 m .2956 .57474 L p .3116 .6044 L .707 .577 .707 r
F P
0 g
s
.3394 .64768 m .33262 .61372 L p .30895 .59116 L .707 .577 .707 r
F P
0 g
s
.33262 .61372 m .3305 .6031 L .31511 .59458 L p .707 .577 .707 r
F P
0 g
s
.31511 .59458 m .30895 .59116 L p .33262 .61372 L .707 .577 .707 r
F P
0 g
s
.3599 .63406 m .35948 .67137 L .39065 .67342 L p .707 .577 .707 r
F P
0 g
s
.36703 .65396 m .36006 .61911 L p .3305 .6031 L .707 .577 .707 r
F P
0 g
s
.36006 .61911 m .35812 .60938 L .34193 .6057 L p .707 .577 .707 r
F P
0 g
s
.34193 .6057 m .3305 .6031 L p .36006 .61911 L .707 .577 .707 r
F P
0 g
s
.39107 .6361 m .39065 .67342 L .42249 .67305 L p .707 .577 .707 r
F P
0 g
s
.39803 .65397 m .39125 .62002 L p .35812 .60938 L .707 .577 .707 r
F P
0 g
s
.39125 .62002 m .38913 .6094 L .37289 .60939 L p .707 .577 .707 r
F P
0 g
s
.37289 .60939 m .35812 .60938 L p .39125 .62002 L .707 .577 .707 r
F P
0 g
s
.41204 .60482 m .38913 .6094 L p .42234 .64101 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .41204 .60482 L .42234 .64101 L .707 .577 .707 r
F
.383 .25779 m .3934 .53939 L p .38063 .49454 L F P
0 g
s
.17387 .77289 m .17505 .75382 L .19896 .7528 L p .707 .577 .707 r
F P
0 g
s
.19896 .7528 m .19778 .77186 L .17387 .77289 L p .707 .577 .707 r
F P
0 g
s
.18171 .73344 m .18212 .69612 L .20617 .69127 L p .707 .577 .707 r
F P
0 g
s
.20617 .69127 m .20576 .72859 L .18171 .73344 L p .707 .577 .707 r
F P
0 g
s
.58601 .24463 m .60402 .73226 L .56524 .72543 L p .707 .577 .707 r
F P
0 g
s
.56524 .72543 m .54723 .2378 L .58601 .24463 L p .707 .577 .707 r
F P
0 g
s
.31862 .76096 m .31744 .78002 L .28996 .77644 L p .707 .577 .707 r
F P
0 g
s
.28996 .77644 m .29114 .75738 L .31862 .76096 L p .707 .577 .707 r
F P
0 g
s
.32601 .69445 m .3256 .73177 L .29814 .72752 L p .707 .577 .707 r
F P
0 g
s
.29814 .72752 m .29855 .6902 L .32601 .69445 L p .707 .577 .707 r
F P
0 g
s
.19778 .77186 m .19896 .7528 L .22823 .75309 L p .707 .577 .707 r
F P
0 g
s
.20576 .72859 m .20617 .69127 L .23555 .68853 L p .707 .577 .707 r
F P
0 g
s
.7655 .70986 m .76588 .67514 L p .73408 .67291 L .707 .577 .707 r
F P
0 g
s
.76588 .67514 m .76591 .67254 L .76149 .6726 L p .707 .577 .707 r
F P
0 g
s
.76149 .6726 m .73408 .67291 L p .76588 .67514 L .707 .577 .707 r
F P
0 g
s
.73366 .71023 m .73401 .67879 L p .70291 .67087 L .707 .577 .707 r
F P
0 g
s
.73401 .67879 m .73408 .67291 L .72529 .67234 L p .707 .577 .707 r
F P
0 g
s
.72529 .67234 m .70291 .67087 L p .73401 .67879 L .707 .577 .707 r
F P
0 g
s
.70249 .70819 m .7028 .68026 L p .67545 .66662 L .707 .577 .707 r
F P
0 g
s
.7028 .68026 m .70291 .67087 L .69279 .66931 L p .707 .577 .707 r
F P
0 g
s
.69279 .66931 m .67545 .66662 L p .7028 .68026 L .707 .577 .707 r
F P
0 g
s
.67545 .66662 m .67503 .70394 L .70249 .70819 L p .707 .577 .707 r
F P
0 g
s
.68241 .6845 m .67563 .65054 L p .65196 .62798 L .707 .577 .707 r
F P
0 g
s
.67563 .65054 m .67351 .63992 L .65812 .63139 L p .707 .577 .707 r
F P
0 g
s
.65812 .63139 m .65196 .62798 L p .67563 .65054 L .707 .577 .707 r
F P
0 g
s
.70291 .67087 m .70249 .70819 L .73366 .71023 L p .707 .577 .707 r
F P
0 g
s
.71004 .69078 m .70307 .65592 L p .67351 .63992 L .707 .577 .707 r
F P
0 g
s
.70307 .65592 m .70113 .6462 L .68494 .64252 L p .707 .577 .707 r
F P
0 g
s
.68494 .64252 m .67351 .63992 L p .70307 .65592 L .707 .577 .707 r
F P
0 g
s
.73408 .67291 m .73366 .71023 L .7655 .70986 L p .707 .577 .707 r
F P
0 g
s
.74104 .69079 m .73426 .65683 L p .70113 .6462 L .707 .577 .707 r
F P
0 g
s
.73426 .65683 m .73214 .64621 L .7159 .64621 L p .707 .577 .707 r
F P
0 g
s
.7159 .64621 m .70113 .6462 L p .73426 .65683 L .707 .577 .707 r
F P
0 g
s
.76591 .67254 m .7655 .70986 L .79488 .70712 L p .707 .577 .707 r
F P
0 g
s
.79488 .70712 m .79529 .6698 L .76591 .67254 L p .707 .577 .707 r
F P
0 g
s
.77239 .68453 m .76348 .63995 L .73214 .64621 L p .707 .577 .707 r
F P
0 g
s
.79529 .6698 m .79488 .70712 L .81892 .70227 L p .707 .577 .707 r
F P
0 g
s
.81892 .70227 m .81934 .66495 L .79529 .6698 L p .707 .577 .707 r
F P
0 g
s
.76348 .63995 m .77239 .68453 L .80101 .67261 L p .707 .577 .707 r
F P
0 g
s
.80101 .67261 m .79211 .62803 L .76348 .63995 L p .707 .577 .707 r
F P
0 g
s
.73214 .64621 m .74104 .69079 L .77239 .68453 L p .707 .577 .707 r
F P
0 g
s
.22823 .75309 m .22705 .77215 L .19778 .77186 L p .707 .577 .707 r
F P
0 g
s
.29114 .75738 m .28996 .77644 L .25881 .77373 L p .707 .577 .707 r
F P
0 g
s
.25881 .77373 m .25999 .75466 L .29114 .75738 L p .707 .577 .707 r
F P
0 g
s
.79211 .62803 m .80101 .67261 L .82411 .6562 L p .707 .577 .707 r
F P
0 g
s
.82411 .6562 m .8152 .61162 L .79211 .62803 L p .707 .577 .707 r
F P
0 g
s
.70113 .6462 m .71004 .69078 L .74104 .69079 L p .707 .577 .707 r
F P
0 g
s
.29855 .6902 m .29814 .72752 L .26697 .72548 L p .707 .577 .707 r
F P
0 g
s
.26697 .72548 m .26738 .68816 L .29855 .6902 L p .707 .577 .707 r
F P
0 g
s
.23555 .68853 m .23513 .72585 L .20576 .72859 L p .707 .577 .707 r
F P
0 g
s
.22705 .77215 m .22823 .75309 L .25999 .75466 L p .707 .577 .707 r
F P
0 g
s
.54723 .2378 m .56524 .72543 L .52124 .72337 L p .707 .577 .707 r
F P
0 g
s
.52124 .72337 m .50324 .23574 L .54723 .2378 L p .707 .577 .707 r
F P
0 g
s
.23513 .72585 m .23555 .68853 L .26738 .68816 L p .707 .577 .707 r
F P
0 g
s
.25999 .75466 m .25881 .77373 L .22705 .77215 L p .707 .577 .707 r
F P
0 g
s
.72646 .75572 m .72764 .73665 L .6965 .73394 L p .707 .577 .707 r
F P
0 g
s
.72764 .73665 m .72646 .75572 L .75823 .75729 L p .707 .577 .707 r
F P
0 g
s
.75823 .75729 m .7594 .73823 L .72764 .73665 L p .707 .577 .707 r
F P
0 g
s
.26738 .68816 m .26697 .72548 L .23513 .72585 L p .707 .577 .707 r
F P
0 g
s
.6965 .73394 m .69532 .753 L .72646 .75572 L p .707 .577 .707 r
F P
0 g
s
.7594 .73823 m .75823 .75729 L .78749 .75758 L p .707 .577 .707 r
F P
0 g
s
.78749 .75758 m .78867 .73852 L .7594 .73823 L p .707 .577 .707 r
F P
0 g
s
.69532 .753 m .6965 .73394 L .66901 .73036 L p .707 .577 .707 r
F P
0 g
s
.66901 .73036 m .66783 .74942 L .69532 .753 L p .707 .577 .707 r
F P
0 g
s
.8152 .61162 m .82411 .6562 L .83942 .6369 L p .707 .577 .707 r
F P
0 g
s
.83942 .6369 m .83051 .59232 L .8152 .61162 L p .707 .577 .707 r
F P
0 g
s
.67351 .63992 m .68241 .6845 L .71004 .69078 L p .707 .577 .707 r
F P
0 g
s
.78867 .73852 m .78749 .75758 L .8114 .75656 L p .707 .577 .707 r
F P
0 g
s
.8114 .75656 m .81258 .73749 L .78867 .73852 L p .707 .577 .707 r
F P
0 g
s
.83051 .59232 m .83942 .6369 L .84544 .6166 L p .707 .577 .707 r
F P
0 g
s
.84544 .6166 m .83653 .57202 L .83051 .59232 L p .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .66087 .67256 L .68241 .6845 L p .707 .577 .707 r
F P
0 g
s
.65439 .66058 m .65398 .69789 L .67503 .70394 L p .707 .577 .707 r
F P
0 g
s
.81934 .66495 m .81892 .70227 L .83529 .69579 L p .707 .577 .707 r
F P
0 g
s
.83529 .69579 m .8357 .65848 L .81934 .66495 L p .707 .577 .707 r
F P
0 g
s
.81258 .73749 m .8114 .75656 L .82761 .75431 L p .707 .577 .707 r
F P
0 g
s
.82761 .75431 m .82879 .73525 L .81258 .73749 L p .707 .577 .707 r
F P
0 g
s
.83653 .57202 m .84544 .6166 L .84159 .5973 L p .637 .531 .717 r
F P
0 g
s
.84159 .5973 m .83268 .55272 L .83653 .57202 L p .637 .531 .717 r
F P
0 g
s
.63861 .61155 m .64752 .65613 L .66087 .67256 L p .707 .577 .707 r
F P
0 g
s
.64752 .65613 m .63861 .61155 L .63476 .59225 L p .635 .53 .717 r
F P
0 g
s
.8357 .65848 m .83529 .69579 L .84237 .68832 L p .707 .577 .707 r
F P
0 g
s
.84237 .68832 m .84278 .651 L .8357 .65848 L p .707 .577 .707 r
F P
0 g
s
.82879 .73525 m .82761 .75431 L .83453 .75107 L p .707 .577 .707 r
F P
0 g
s
.83453 .75107 m .83571 .73201 L .82879 .73525 L p .707 .577 .707 r
F P
0 g
s
.64138 .69065 m .6418 .65333 L .63889 .64559 L p .707 .577 .707 r
F P
0 g
s
.83268 .55272 m .84159 .5973 L .82824 .58087 L p .707 .577 .707 r
F P
0 g
s
.82824 .58087 m .81933 .53629 L .83268 .55272 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .63476 .59225 L .64078 .57195 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .64752 .65613 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63889 .64559 m .63848 .68291 L .64138 .69065 L p .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .63889 .64559 L .64428 .6399 L p .707 .577 .707 r
F P
0 g
s
.64428 .6399 m .64597 .63811 L p .64504 .6437 L .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .64428 .6399 L .64504 .6437 L .707 .577 .707 r
F
.63476 .59225 m .63924 .61468 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63924 .61468 m .64366 .63683 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84278 .651 m .84237 .68832 L .83947 .68058 L p .707 .577 .707 r
F P
0 g
s
.83947 .68058 m .83988 .64326 L .84278 .651 L p .707 .577 .707 r
F P
0 g
s
.83571 .73201 m .83453 .75107 L .83149 .74715 L p .707 .577 .707 r
F P
0 g
s
.83149 .74715 m .83267 .72809 L .83571 .73201 L p .707 .577 .707 r
F P
0 g
s
.81933 .53629 m .82824 .58087 L .80669 .56893 L p .707 .577 .707 r
F P
0 g
s
.80669 .56893 m .79778 .52435 L .81933 .53629 L p .707 .577 .707 r
F P
0 g
s
.64969 .61653 m .64078 .57195 L .65609 .55266 L p .707 .577 .707 r
F P
0 g
s
.64078 .57195 m .64969 .61653 L .64366 .63683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64597 .63811 m .64556 .67543 L .63848 .68291 L p .707 .577 .707 r
F P
0 g
s
.45228 .63299 m .45187 .67031 L .47591 .66546 L p .707 .577 .707 r
F P
0 g
s
.42047 .60313 m .42938 .64771 L .458 .63579 L p .707 .577 .707 r
F P
0 g
s
.38913 .6094 m .39803 .65397 L .42938 .64771 L p .707 .577 .707 r
F P
0 g
s
.83988 .64326 m .83947 .68058 L .82687 .67333 L p .707 .577 .707 r
F P
0 g
s
.82687 .67333 m .82729 .63601 L .83988 .64326 L p .707 .577 .707 r
F P
0 g
s
.79778 .52435 m .80669 .56893 L .77907 .56265 L p .707 .577 .707 r
F P
0 g
s
.77907 .56265 m .77016 .51807 L .79778 .52435 L p .707 .577 .707 r
F P
0 g
s
.65609 .55266 m .66499 .59723 L .64969 .61653 L p .707 .577 .707 r
F P
0 g
s
.66499 .59723 m .65609 .55266 L .67918 .53624 L p .707 .577 .707 r
F P
0 g
s
.4811 .61938 m .47219 .5748 L .4491 .59121 L p .707 .577 .707 r
F P
0 g
s
.35812 .60938 m .36703 .65396 L .39803 .65397 L p .707 .577 .707 r
F P
0 g
s
.83267 .72809 m .83149 .74715 L .81878 .74294 L p .707 .577 .707 r
F P
0 g
s
.81878 .74294 m .81996 .72387 L .83267 .72809 L p .707 .577 .707 r
F P
0 g
s
.38345 .7189 m .38463 .69984 L .35349 .69712 L p .707 .577 .707 r
F P
0 g
s
.35349 .69712 m .35231 .71619 L .38345 .7189 L p .707 .577 .707 r
F P
0 g
s
.64556 .67543 m .64597 .63811 L .66234 .63163 L p .707 .577 .707 r
F P
0 g
s
.77016 .51807 m .77907 .56265 L .74806 .56264 L p .707 .577 .707 r
F P
0 g
s
.74806 .56264 m .73915 .51806 L .77016 .51807 L p .707 .577 .707 r
F P
0 g
s
.68809 .58082 m .67918 .53624 L .70781 .52432 L p .707 .577 .707 r
F P
0 g
s
.67918 .53624 m .68809 .58082 L .66499 .59723 L p .707 .577 .707 r
F P
0 g
s
.63788 .73395 m .63906 .71488 L .65527 .71264 L p .707 .577 .707 r
F P
0 g
s
.35231 .71619 m .35349 .69712 L .326 .69354 L p .707 .577 .707 r
F P
0 g
s
.65527 .71264 m .65409 .7317 L .63788 .73395 L p .707 .577 .707 r
F P
0 g
s
.326 .69354 m .32482 .71261 L .35231 .71619 L p .707 .577 .707 r
F P
0 g
s
.47219 .5748 m .4811 .61938 L .49641 .60008 L p .707 .577 .707 r
F P
0 g
s
.49641 .60008 m .4875 .5555 L .47219 .5748 L p .707 .577 .707 r
F P
0 g
s
.3305 .6031 m .3394 .64768 L .36703 .65396 L p .707 .577 .707 r
F P
0 g
s
.66234 .63163 m .66192 .66895 L .64556 .67543 L p .707 .577 .707 r
F P
0 g
s
.73915 .51806 m .74806 .56264 L .71671 .5689 L p .707 .577 .707 r
F P
0 g
s
.71671 .5689 m .70781 .52432 L .73915 .51806 L p .707 .577 .707 r
F P
0 g
s
.70781 .52432 m .71671 .5689 L .68809 .58082 L p .707 .577 .707 r
F P
0 g
s
.82729 .63601 m .82687 .67333 L .80581 .66728 L p .707 .577 .707 r
F P
0 g
s
.80581 .66728 m .80623 .62997 L .82729 .63601 L p .707 .577 .707 r
F P
0 g
s
.32482 .71261 m .326 .69354 L .30487 .68945 L p .707 .577 .707 r
F P
0 g
s
.81996 .72387 m .81878 .74294 L .79765 .73884 L p .707 .577 .707 r
F P
0 g
s
.79765 .73884 m .79883 .71977 L .81996 .72387 L p .707 .577 .707 r
F P
0 g
s
.30487 .68945 m .30369 .70851 L .32482 .71261 L p .707 .577 .707 r
F P
0 g
s
.66192 .66895 m .66234 .63163 L .68639 .62678 L p .707 .577 .707 r
F P
0 g
s
.4875 .5555 m .49641 .60008 L .50243 .57979 L p .707 .577 .707 r
F P
0 g
s
.50243 .57979 m .49352 .53521 L .4875 .5555 L p .707 .577 .707 r
F P
0 g
s
.30895 .59116 m .31786 .63574 L .3394 .64768 L p .707 .577 .707 r
F P
0 g
s
.31138 .62376 m .31097 .66108 L .33202 .66712 L p .707 .577 .707 r
F P
0 g
s
.65409 .7317 m .65527 .71264 L .67917 .71161 L p .707 .577 .707 r
F P
0 g
s
.47633 .62814 m .47591 .66546 L .49228 .65898 L p .707 .577 .707 r
F P
0 g
s
.49228 .65898 m .49269 .62166 L .47633 .62814 L p .707 .577 .707 r
F P
0 g
s
.67917 .71161 m .678 .73068 L .65409 .7317 L p .707 .577 .707 r
F P
0 g
s
.68639 .62678 m .68597 .6641 L .66192 .66895 L p .707 .577 .707 r
F P
0 g
s
.80623 .62997 m .80581 .66728 L .77835 .66303 L p .707 .577 .707 r
F P
0 g
s
.77835 .66303 m .77877 .62571 L .80623 .62997 L p .707 .577 .707 r
F P
0 g
s
.31097 .66108 m .31138 .62376 L .29878 .61651 L p .707 .577 .707 r
F P
0 g
s
.30369 .70851 m .30487 .68945 L .29216 .68523 L p .707 .577 .707 r
F P
0 g
s
.79883 .71977 m .79765 .73884 L .77017 .73526 L p .707 .577 .707 r
F P
0 g
s
.77017 .73526 m .77135 .71619 L .79883 .71977 L p .707 .577 .707 r
F P
0 g
s
.29216 .68523 m .29099 .70429 L .30369 .70851 L p .707 .577 .707 r
F P
0 g
s
.68597 .6641 m .68639 .62678 L .71576 .62404 L p .707 .577 .707 r
F P
0 g
s
.49352 .53521 m .50243 .57979 L .49858 .56048 L p .634 .529 .717 r
F P
0 g
s
.49858 .56048 m .48967 .5159 L .49352 .53521 L p .634 .529 .717 r
F P
0 g
s
.2956 .57474 m .30451 .61932 L .31786 .63574 L p .707 .577 .707 r
F P
0 g
s
.30451 .61932 m .2956 .57474 L .29175 .55543 L p .632 .527 .718 r
F P
0 g
s
.29878 .61651 m .29837 .65383 L .31097 .66108 L p .707 .577 .707 r
F P
0 g
s
.678 .73068 m .67917 .71161 L .70844 .7119 L p .707 .577 .707 r
F P
0 g
s
.70844 .7119 m .70726 .73097 L .678 .73068 L p .707 .577 .707 r
F P
0 g
s
.77877 .62571 m .77835 .66303 L .74718 .66099 L p .707 .577 .707 r
F P
0 g
s
.74718 .66099 m .7476 .62367 L .77877 .62571 L p .707 .577 .707 r
F P
0 g
s
.71576 .62404 m .71535 .66136 L .68597 .6641 L p .707 .577 .707 r
F P
0 g
s
.49269 .62166 m .49228 .65898 L .49936 .6515 L p .707 .577 .707 r
F P
0 g
s
.49936 .6515 m .49977 .61418 L .49269 .62166 L p .707 .577 .707 r
F P
0 g
s
.71535 .66136 m .71576 .62404 L .7476 .62367 L p .707 .577 .707 r
F P
0 g
s
.77135 .71619 m .77017 .73526 L .73902 .73255 L p .707 .577 .707 r
F P
0 g
s
.73902 .73255 m .7402 .71348 L .77135 .71619 L p .707 .577 .707 r
F P
0 g
s
.7476 .62367 m .74718 .66099 L .71535 .66136 L p .707 .577 .707 r
F P
0 g
s
.48578 .69843 m .4846 .7175 L .49152 .71426 L p .707 .577 .707 r
F P
0 g
s
.49152 .71426 m .4927 .69519 L .48578 .69843 L p .707 .577 .707 r
F P
0 g
s
.70726 .73097 m .70844 .7119 L .7402 .71348 L p .707 .577 .707 r
F P
0 g
s
.7402 .71348 m .73902 .73255 L .70726 .73097 L p .707 .577 .707 r
F P
0 g
s
.29837 .65383 m .29878 .61651 L .29588 .60877 L p .707 .577 .707 r
F P
0 g
s
.29099 .70429 m .29216 .68523 L .28912 .68131 L p .707 .577 .707 r
F P
0 g
s
.28912 .68131 m .28795 .70037 L .29099 .70429 L p .707 .577 .707 r
F P
0 g
s
.48967 .5159 m .49858 .56048 L .48523 .54406 L p .707 .577 .707 r
F P
0 g
s
.48523 .54406 m .47632 .49948 L .48967 .5159 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .29175 .55543 L .29777 .53514 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .30451 .61932 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29588 .60877 m .29547 .64609 L .29837 .65383 L p .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .29588 .60877 L .30127 .60308 L p .707 .577 .707 r
F P
0 g
s
.30127 .60308 m .30296 .6013 L p .30203 .60688 L .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .30127 .60308 L .30203 .60688 L .707 .577 .707 r
F
.29175 .55543 m .29623 .57786 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29623 .57786 m .30065 .60001 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49977 .61418 m .49936 .6515 L .49646 .64376 L p .707 .577 .707 r
F P
0 g
s
.49646 .64376 m .49687 .60644 L .49977 .61418 L p .707 .577 .707 r
F P
0 g
s
.4927 .69519 m .49152 .71426 L .48848 .71034 L p .707 .577 .707 r
F P
0 g
s
.48848 .71034 m .48966 .69127 L .4927 .69519 L p .707 .577 .707 r
F P
0 g
s
.47632 .49948 m .48523 .54406 L .46368 .53212 L p .707 .577 .707 r
F P
0 g
s
.46368 .53212 m .45477 .48754 L .47632 .49948 L p .707 .577 .707 r
F P
0 g
s
.30668 .57972 m .29777 .53514 L .31308 .51584 L p .707 .577 .707 r
F P
0 g
s
.29777 .53514 m .30668 .57972 L .30065 .60001 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28795 .70037 m .28912 .68131 L .29605 .67807 L p .707 .577 .707 r
F P
0 g
s
.29605 .67807 m .29487 .69713 L .28795 .70037 L p .707 .577 .707 r
F P
0 g
s
.30296 .6013 m .30255 .63861 L .29547 .64609 L p .707 .577 .707 r
F P
0 g
s
.49687 .60644 m .49646 .64376 L .48386 .63651 L p .707 .577 .707 r
F P
0 g
s
.48386 .63651 m .48428 .5992 L .49687 .60644 L p .707 .577 .707 r
F P
0 g
s
.45477 .48754 m .46368 .53212 L .43606 .52584 L p .707 .577 .707 r
F P
0 g
s
.43606 .52584 m .42715 .48126 L .45477 .48754 L p .707 .577 .707 r
F P
0 g
s
.31308 .51584 m .32198 .56042 L .30668 .57972 L p .707 .577 .707 r
F P
0 g
s
.32198 .56042 m .31308 .51584 L .33617 .49943 L p .707 .577 .707 r
F P
0 g
s
.48966 .69127 m .48848 .71034 L .47577 .70612 L p .707 .577 .707 r
F P
0 g
s
.47577 .70612 m .47695 .68706 L .48966 .69127 L p .707 .577 .707 r
F P
0 g
s
.30255 .63861 m .30296 .6013 L .31933 .59482 L p .707 .577 .707 r
F P
0 g
s
.42715 .48126 m .43606 .52584 L .40505 .52582 L p .707 .577 .707 r
F P
0 g
s
.40505 .52582 m .39614 .48125 L .42715 .48126 L p .707 .577 .707 r
F P
0 g
s
.34508 .54401 m .33617 .49943 L .3648 .48751 L p .707 .577 .707 r
F P
0 g
s
.33617 .49943 m .34508 .54401 L .32198 .56042 L p .707 .577 .707 r
F P
0 g
s
.29487 .69713 m .29605 .67807 L .31225 .67583 L p .707 .577 .707 r
F P
0 g
s
.31225 .67583 m .31108 .69489 L .29487 .69713 L p .707 .577 .707 r
F P
0 g
s
.31933 .59482 m .31891 .63214 L .30255 .63861 L p .707 .577 .707 r
F P
0 g
s
.39614 .48125 m .40505 .52582 L .3737 .53209 L p .707 .577 .707 r
F P
0 g
s
.3737 .53209 m .3648 .48751 L .39614 .48125 L p .707 .577 .707 r
F P
0 g
s
.3648 .48751 m .3737 .53209 L .34508 .54401 L p .707 .577 .707 r
F P
0 g
s
.48428 .5992 m .48386 .63651 L .4628 .63047 L p .707 .577 .707 r
F P
0 g
s
.4628 .63047 m .46322 .59315 L .48428 .5992 L p .707 .577 .707 r
F P
0 g
s
.47695 .68706 m .47577 .70612 L .45464 .70202 L p .707 .577 .707 r
F P
0 g
s
.45464 .70202 m .45582 .68296 L .47695 .68706 L p .707 .577 .707 r
F P
0 g
s
.31891 .63214 m .31933 .59482 L .34337 .58997 L p .707 .577 .707 r
F P
0 g
s
.31108 .69489 m .31225 .67583 L .33616 .6748 L p .707 .577 .707 r
F P
0 g
s
.33616 .6748 m .33498 .69386 L .31108 .69489 L p .707 .577 .707 r
F P
0 g
s
.34337 .58997 m .34296 .62729 L .31891 .63214 L p .707 .577 .707 r
F P
0 g
s
.46322 .59315 m .4628 .63047 L .43534 .62622 L p .707 .577 .707 r
F P
0 g
s
.43534 .62622 m .43576 .5889 L .46322 .59315 L p .707 .577 .707 r
F P
0 g
s
.45582 .68296 m .45464 .70202 L .42716 .69844 L p .707 .577 .707 r
F P
0 g
s
.42716 .69844 m .42834 .67938 L .45582 .68296 L p .707 .577 .707 r
F P
0 g
s
.34296 .62729 m .34337 .58997 L .37275 .58723 L p .707 .577 .707 r
F P
0 g
s
.33498 .69386 m .33616 .6748 L .36543 .67509 L p .707 .577 .707 r
F P
0 g
s
.36543 .67509 m .36425 .69415 L .33498 .69386 L p .707 .577 .707 r
F P
0 g
s
.43576 .5889 m .43534 .62622 L .40417 .62418 L p .707 .577 .707 r
F P
0 g
s
.40417 .62418 m .40459 .58686 L .43576 .5889 L p .707 .577 .707 r
F P
0 g
s
.37275 .58723 m .37234 .62454 L .34296 .62729 L p .707 .577 .707 r
F P
0 g
s
.37234 .62454 m .37275 .58723 L .40459 .58686 L p .707 .577 .707 r
F P
0 g
s
.42834 .67938 m .42716 .69844 L .39601 .69573 L p .707 .577 .707 r
F P
0 g
s
.39601 .69573 m .39719 .67667 L .42834 .67938 L p .707 .577 .707 r
F P
0 g
s
.40459 .58686 m .40417 .62418 L .37234 .62454 L p .707 .577 .707 r
F P
0 g
s
.36425 .69415 m .36543 .67509 L .39719 .67667 L p .707 .577 .707 r
F P
0 g
s
.39719 .67667 m .39601 .69573 L .36425 .69415 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolM001oOol007eoo`@0
0003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00H007Uoo`00NGoo10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1000MGoo001eOol40009FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001bOol0079oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006moo`00KWoo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P00KGoo001/Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH2001/Ool006Yoo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00001ZOol006Uoo`04001JEUYF
0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF0000JGoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVQoo`00IGoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYFJ7oo001TOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEVMoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Eoo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEPd000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00D005YFFUH005YF00@0
009JEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00<005YF00000P001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol30009FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006=oo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00HGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00Ggoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Eoo`00GGoo0`0025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8006Eoo`00G7oo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Yoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001IOol00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001HOol20006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol05Woo3000@Goo001GOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool04Woo10000UYF00<005YFFUH01EYF00<005YF00000`00?Goo001FOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000moo`@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<003Yoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00@000QJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Goo0P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30004FUH01@00FUIJEUYF
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo
0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00=Woo001D
Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH20003FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0027oo0P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YFFUIJEP8003Aoo`00E7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0`0000EJEP00FUIJEP0000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<000QJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00Dgoo0P00
1EYF00<005YFFUH01EYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000bOol005=oo`03001JEP0000AJEP03001JEUYF00=J
EP8000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool01@00FUIJEUYF000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00<Woo001BOol01000FUIJEP001EYF00D005YFFUIJEP0000Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000a
Ool0059oo`04001JEUYF0005FUH01000FUIJEP001goo00@005YFFUH000EJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003Ool005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000`Ool0059oo`04
001JEUYF0005FUH30008Ool01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00@005YF
FUIJEP800003FUH0000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF000`Ool0059oo`80009JEP03001JEUYF009JEP03001oogoo00Qo
o`04001JEUYF0005FUH30008FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF0000<7oo001COol01000FUIJEP000eYF00<007ooOol02Goo00@005YFFUH000AJEPD0
00MJEP03001JEUYF00QJEP04001JEUYF0002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000FUIJEP00;goo0017Ool=0002FUH01000FUIJ
EP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001JEP0000=JEP03001JEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH5000AOol50004FUH01000FUIJEP00;goo0013Ool40002FUH00`00FUIJ
EP06FUH20002FUH01000FUIJEP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001J
EP0000=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00eYF0P006goo0P000UYF00@005YFFUH002mo
o`00@7oo0`001UYF00<005YFFUH01UYF0`000UYF10002goo00@005YFFUH000EJEP<000QJEP03001J
EUYF00QJEP8000AJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00@005YFFUIJEP8001moo`06001JEUYF001JEP00
;goo000nOol30009FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP030009Ool01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH01eYF0`001EYF00<005YF000015YF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00@005YF0000
029oo`<0009JEP03001oogoo02aoo`00?7oo0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
0UYF00@005YFFUH0009JEP03001oogoo00Ioo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP001EYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF0P009Woo00@005YFFUH002ioo`00>Woo0P00
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000Ioo`04
001JEUYF0005FUH80003FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF00<005YF000015YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP02
FUH2000YOol00`00FUH0000^Ool003Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF009JEPl000AJEP04001JEUYFFUH800000eYF00000005FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000:goo0`00;Woo000fOol30008FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEUYF1P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00eYF0`00;7oo00@005YF000002eo
o`00=Goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP00FUH50005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020005
FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00Oomoo`0AOol3000GOol20002FUH00`00Oomoo`0[Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH40006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJ
EP02FUH00`00Oomoo`0AOol5000EOol00`00FUH00002FUH00`00Oomoo`0[Ool0039oo`03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH0000D
Ool5000DOol01000FUIJEP000UYF00<007ooOol0:goo000aOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000EOol5000COol0
0`00FUIJEP02FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000FOol3000COol00`00
FUIJEP03FUH01000FUIJEP00;7oo000_Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
15YF3@000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP00009JEP@002Yoo`8000EJEP04001JEUYF000/Ool002moo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool00`00Ool00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000UYF0P0000AJEP00000002Moo`03001JEP0000EJEP04001JEUYF000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP@000ioo`<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH20000
15YF001JEUYF0P008goo0P000eYF00<005YFFUH00UYF00@005YFFUH002aoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00eYF0P004Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00FUH30002FUH01000FUIJEUYF0P00
1Woo5`000goo00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUH00002000DOol00`00FUH00003FUH01000FUIJEUYF2@0025YF0`00
1EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF00@005YFFUIJEPP000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEP8002eoo`00;7oo0P001EYF00<0
05YFFUH01EYF0P005goo00<005YF00000eYF100000=JEP00FUH01EYF00<005YFFUH01EYF1@001UYF
00<005YFFUH00eYF1P0015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YF1`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1P001EYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH2
000IOol01000FUH005YF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH0
1UYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001oogoo02aoo`00
:goo00@005YFFUH000EJEP05001JEUYFFUH0000KOol00`00FUH000020002FUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH20005FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000^Ool002]oo`04001JEUYF0005FUH01000FUIJEP0077oo0P000UYF00<005YFFUH00UYF00@0
05YFFUH000IJEP03001JEUYF00EJEP<000QJEP04001JEUYFFUH30006FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool01000FUIJEP001EYF0`007Goo00D005YFFUIJEP00
00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`05001JEUYFFUH00004FUH00`00Oomo
o`0MOol01@00FUIJEUYF00001EYF00<005YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/
Ool01000FUIJEP000eYF00<007ooOol04Woo0`002Goo00D005YFFUIJEP0000EJEP03001JEUYF00=J
EQ80009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo019oo`D000Uoo`04001JEUYF0005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo
019oo`D000Yoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEUYF
0P005Goo1@0037oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP02FUHA0007FUH80004FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`04001JEUYF000GOol3000@Ool70004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEP00008000MJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00AJEPH000AJEP03001JEUYF008002eoo`00;Goo00@005YFFUH002]oo`04001JEUYF
0002FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`0000IJEP00000005YF0002FUH2000]Ool0
02eoo`03001JEP0002]oob<000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEP00FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF
00<005YFFUH015YF0P0015YF00@005YF0000009JEP8002eoo`00;Goo00<005YF000097oo20000eYF
00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP800003FUH005YF008000=JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF009JEP<000EJEP04001JEUYFFUH4000]
Ool002ioo`03FUH00000025oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH20007FUH30007FUH0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEP000080
01moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH70003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01UYF00<005YFFUH0
15YF10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000^Ool00`00FUH00002FUH2000:
OolA0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03
001JEUYF00D000QJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@005YF
FUH000=JEPX000=JEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Woo000^Ool01@00FUIJEP00FUH010000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF7`0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool2000015YF000000001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000`001EYF00@005YFFUIJEPT00003FUH005YF00EJ
EP04001JEUYFFUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP/000MJEP03001JEP0000H000=JEP06001JEUYF
001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800006
Ool00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00<goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0;
FUH00`00FUIJEP06FUH500000eYF00000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0017oo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000Woo0P000eYF00<005YF00007`00>Woo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF7`00AWoo000]Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
2@0015YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YF000025YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2000?Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
00=JEP000000200025YF00<005YFFUH02EYF10002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPL003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03
001JEUYF00QJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003=oo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEPT000aJEPT000QJEP03001JEUYF00IJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0035oo`00;Goo00<005YF00000eYF00@005YFFUIJEPP00003FUH005YF
00EJEPD000MJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P00
0UYF00<005YFFUH01UYF0P000eYF00@005YFFUIJEQ4000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYF000`Ool002eoo`03001JEP0000=JEPL000IJEP03001JEUYF00AJ
EPD000MJEP03001JEP0000T000=JEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH9
00000eYF001JEP02FUH80004Ool80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000]Ool01000FUH005YF0P0015YF00<005YF00000`0015YF00<005YFFUH015YF0`0015YF
1`000eYF00<005YFFUH00eYF10000eYF00<007ooFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF500015YF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00;Goo00<005YF00000P001EYF00<005YFFUH00eYF4P000UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool00eYF00<005YFFUH00eYF
00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF0`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000=JEP04001JEUYFFUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH300001GooFUIJEUYF00001EYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00D005YFFUIJEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002mo
o`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYFFUH005YF001oo`=JEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF1000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH00000FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000_Ool002eoob4000=JEP03001JEUYF00EJEP03001JEUYF
00AJEP08001JEUYFFUH005YF001oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP0B0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000`Ool002]oo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001J
EUYF00AJEP04001JEUYFFUH20002Ool3FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00P002Woo5P00=7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00D005YFFUIJ
EP0000=oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH00P00E7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP070004Ool2FUH01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF008005Aoo`00:Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000goo00=JEP00FUH00eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001P0015YF00<005YFFUH00P00E7oo000ZOol00`00FUH00002FUHF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0000AJEP00FUIJ
EP8005Aoo`00:Woo00<005YF00000`001EYF00@005YFFUIJEPT0009ooa8000AJEP03001JEUYF00=J
EP04001JEUYFFUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020005
FUH01000FUH000000UYF0P00E7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK0003FUH01P00FUIJEP00FUH0009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP05001JEP00FUH00005FUH01000FUIJEUYF1000E7oo000[Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH20003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH3001DOol002eoo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000Aoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00<Woo1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
00Aoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH00`00FUH0001DOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001Goo00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001EOol0049oo`T000AJEP03001JEUYF00EJEP04001JEUYFFUH9
0007Ool200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEP000eYF1P000eYF00@005YFFUIJEP8005Ioo`00Bgoo
40004Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF10001eYF00<005YF00000`0000=JEP000000F7oo001^Ool20007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF
001JEP07FUH00`00FUIJEP02FUH3001IOol0071oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001GOol0079oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000D000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008005Ioo`00M7oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2@0000=oo`0000001P0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00MWoo
1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEPH0009JEP03001JEP0001@000=J
EP04001JEUYFFUH2001FOol007eoo`/000IJEP03001JEUYF00AJEPX000QJEP03001JEP0000@0009J
EP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8005Ioo`00R7oo3@0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
05Ioo`00Tgoo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000EWoo002JOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP04001GOol00:=ooal005]oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60019 .76901 m .59458 .71913 L .56347 .71845 L p .707 .577 .707 r
F P
0 g
s
.59458 .71913 m .60019 .76901 L .63184 .7647 L p .707 .577 .707 r
F P
0 g
s
.63184 .7647 m .62622 .71482 L .59458 .71913 L p .707 .577 .707 r
F P
0 g
s
.62622 .71482 m .63184 .7647 L .66092 .75581 L p .707 .577 .707 r
F P
0 g
s
.66092 .75581 m .65531 .70593 L .62622 .71482 L p .707 .577 .707 r
F P
0 g
s
.56908 .76833 m .56347 .71845 L .53595 .71284 L p .707 .577 .707 r
F P
0 g
s
.56347 .71845 m .56908 .76833 L .60019 .76901 L p .707 .577 .707 r
F P
0 g
s
.65531 .70593 m .66092 .75581 L .68461 .74323 L p .707 .577 .707 r
F P
0 g
s
.68461 .74323 m .679 .69335 L .65531 .70593 L p .707 .577 .707 r
F P
0 g
s
.59633 .8109 m .59659 .77368 L .56541 .77169 L p .707 .577 .707 r
F P
0 g
s
.59659 .77368 m .59633 .8109 L .62816 .81037 L p .707 .577 .707 r
F P
0 g
s
.62816 .81037 m .62842 .77315 L .59659 .77368 L p .707 .577 .707 r
F P
0 g
s
.54156 .76272 m .53595 .71284 L .5147 .70285 L p .707 .577 .707 r
F P
0 g
s
.53595 .71284 m .54156 .76272 L .56908 .76833 L p .707 .577 .707 r
F P
0 g
s
.59177 .84066 m .5925 .82174 L .56133 .81934 L p .707 .577 .707 r
F P
0 g
s
.5925 .82174 m .59177 .84066 L .62357 .84133 L p .707 .577 .707 r
F P
0 g
s
.62357 .84133 m .6243 .82241 L .5925 .82174 L p .707 .577 .707 r
F P
0 g
s
.62842 .77315 m .62816 .81037 L .65754 .80739 L p .707 .577 .707 r
F P
0 g
s
.65754 .80739 m .6578 .77017 L .62842 .77315 L p .707 .577 .707 r
F P
0 g
s
.6243 .82241 m .62357 .84133 L .65291 .84021 L p .707 .577 .707 r
F P
0 g
s
.65291 .84021 m .65364 .82129 L .6243 .82241 L p .707 .577 .707 r
F P
0 g
s
.56133 .81934 m .5606 .83826 L .59177 .84066 L p .707 .577 .707 r
F P
0 g
s
.56516 .80891 m .56541 .77169 L .53796 .76738 L p .707 .577 .707 r
F P
0 g
s
.56541 .77169 m .56516 .80891 L .59633 .8109 L p .707 .577 .707 r
F P
0 g
s
.679 .69335 m .68461 .74323 L .70057 .72817 L p .707 .577 .707 r
F P
0 g
s
.70057 .72817 m .69496 .67829 L .679 .69335 L p .707 .577 .707 r
F P
0 g
s
.5606 .83826 m .56133 .81934 L .53387 .81545 L p .707 .577 .707 r
F P
0 g
s
.53387 .81545 m .53314 .83437 L .5606 .83826 L p .707 .577 .707 r
F P
0 g
s
.6578 .77017 m .65754 .80739 L .6816 .80223 L p .707 .577 .707 r
F P
0 g
s
.6816 .80223 m .68185 .76501 L .6578 .77017 L p .707 .577 .707 r
F P
0 g
s
.53796 .76738 m .5377 .80461 L .56516 .80891 L p .707 .577 .707 r
F P
0 g
s
.65364 .82129 m .65291 .84021 L .67691 .8374 L p .707 .577 .707 r
F P
0 g
s
.67691 .8374 m .67764 .81848 L .65364 .82129 L p .707 .577 .707 r
F P
0 g
s
.5377 .80461 m .53796 .76738 L .5169 .76118 L p .707 .577 .707 r
F P
0 g
s
.52031 .75273 m .5147 .70285 L .50182 .68946 L p .707 .577 .707 r
F P
0 g
s
.5147 .70285 m .52031 .75273 L .54156 .76272 L p .707 .577 .707 r
F P
0 g
s
.53314 .83437 m .53387 .81545 L .51278 .81044 L p .707 .577 .707 r
F P
0 g
s
.51278 .81044 m .51205 .82936 L .53314 .83437 L p .707 .577 .707 r
F P
0 g
s
.69496 .67829 m .70057 .72817 L .70724 .71212 L p .707 .577 .707 r
F P
0 g
s
.70724 .71212 m .70163 .66224 L .69496 .67829 L p .707 .577 .707 r
F P
0 g
s
.5169 .76118 m .51664 .7984 L .5377 .80461 L p .707 .577 .707 r
F P
0 g
s
.68185 .76501 m .6816 .80223 L .69796 .79541 L p .707 .577 .707 r
F P
0 g
s
.69796 .79541 m .69822 .75819 L .68185 .76501 L p .707 .577 .707 r
F P
0 g
s
.67764 .81848 m .67691 .8374 L .69322 .83318 L p .707 .577 .707 r
F P
0 g
s
.69322 .83318 m .69395 .81426 L .67764 .81848 L p .707 .577 .707 r
F P
0 g
s
.51664 .7984 m .5169 .76118 L .50431 .75369 L p .707 .577 .707 r
F P
0 g
s
.51205 .82936 m .51278 .81044 L .50015 .80482 L p .707 .577 .707 r
F P
0 g
s
.50743 .73934 m .50182 .68946 L .49855 .67398 L p .707 .577 .707 r
F P
0 g
s
.50182 .68946 m .50743 .73934 L .52031 .75273 L p .707 .577 .707 r
F P
0 g
s
.50015 .80482 m .49942 .82374 L .51205 .82936 L p .707 .577 .707 r
F P
0 g
s
.50431 .75369 m .50405 .79091 L .51664 .7984 L p .707 .577 .707 r
F P
0 g
s
.70163 .66224 m .70724 .71212 L .70398 .69664 L p .707 .577 .707 r
F P
0 g
s
.70398 .69664 m .69837 .64676 L .70163 .66224 L p .707 .577 .707 r
F P
0 g
s
.69822 .75819 m .69796 .79541 L .70504 .7876 L p .707 .577 .707 r
F P
0 g
s
.70504 .7876 m .7053 .75038 L .69822 .75819 L p .707 .577 .707 r
F P
0 g
s
.69395 .81426 m .69322 .83318 L .70024 .82797 L p .707 .577 .707 r
F P
0 g
s
.70024 .82797 m .70097 .80905 L .69395 .81426 L p .707 .577 .707 r
F P
0 g
s
.49942 .82374 m .50015 .80482 L .49719 .79911 L p .707 .577 .707 r
F P
0 g
s
.49719 .79911 m .49646 .81803 L .49942 .82374 L p .707 .577 .707 r
F P
0 g
s
.49646 .81803 m .49719 .79911 L .50422 .7939 L p .707 .577 .707 r
F P
0 g
s
.50422 .7939 m .50349 .81282 L .49646 .81803 L p .707 .577 .707 r
F P
0 g
s
.49788 .82403 m .48674 .33045 L .44274 .32816 L p .707 .577 .707 r
F P
0 g
s
.50405 .79091 m .50431 .75369 L .50141 .74564 L p .707 .577 .707 r
F P
0 g
s
.50416 .72386 m .50743 .73934 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.49855 .67398 m .50171 .70204 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50171 .70204 m .50416 .72386 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50141 .74564 m .50115 .78286 L .50405 .79091 L p .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50141 .74564 L .50575 .74085 L p .707 .577 .707 r
F P
0 g
s
.50575 .74085 m .50849 .73783 L p .50663 .74925 L .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50575 .74085 L .50663 .74925 L .707 .577 .707 r
F
.50416 .72386 m .49855 .67398 L .50523 .65793 L p F P
0 g
s
.51084 .70781 m .50523 .65793 L .52119 .64287 L p .707 .577 .707 r
F P
0 g
s
.50523 .65793 m .51084 .70781 L .50416 .72386 L p .707 .577 .707 r
F P
0 g
s
.50849 .73783 m .50823 .77505 L .50115 .78286 L p .707 .577 .707 r
F P
0 g
s
.52119 .64287 m .5268 .69275 L .51084 .70781 L p .707 .577 .707 r
F P
0 g
s
.5268 .69275 m .52119 .64287 L .54487 .63028 L p .707 .577 .707 r
F P
0 g
s
.50823 .77505 m .50849 .73783 L .52486 .73101 L p .707 .577 .707 r
F P
0 g
s
.50349 .81282 m .50422 .7939 L .52052 .78968 L p .707 .577 .707 r
F P
0 g
s
.52052 .78968 m .51979 .8086 L .50349 .81282 L p .707 .577 .707 r
F P
0 g
s
.52486 .73101 m .5246 .76823 L .50823 .77505 L p .707 .577 .707 r
F P
0 g
s
.54487 .63028 m .55048 .68016 L .5268 .69275 L p .707 .577 .707 r
F P
0 g
s
.5246 .76823 m .52486 .73101 L .54891 .72585 L p .707 .577 .707 r
F P
0 g
s
.51979 .8086 m .52052 .78968 L .54452 .78688 L p .707 .577 .707 r
F P
0 g
s
.54452 .78688 m .54379 .8058 L .51979 .8086 L p .707 .577 .707 r
F P
0 g
s
.54891 .72585 m .54865 .76308 L .5246 .76823 L p .707 .577 .707 r
F P
0 g
s
.48674 .33045 m .49788 .82403 L .54281 .82181 L p .707 .577 .707 r
F P
0 g
s
.54281 .82181 m .53167 .32823 L .48674 .33045 L p .707 .577 .707 r
F P
0 g
s
.55048 .68016 m .54487 .63028 L .57396 .6214 L p .707 .577 .707 r
F P
0 g
s
.57396 .6214 m .57957 .67128 L .55048 .68016 L p .707 .577 .707 r
F P
0 g
s
.54865 .76308 m .54891 .72585 L .57829 .72287 L p .707 .577 .707 r
F P
0 g
s
.54379 .8058 m .54452 .78688 L .57386 .78575 L p .707 .577 .707 r
F P
0 g
s
.57386 .78575 m .57313 .80467 L .54379 .8058 L p .707 .577 .707 r
F P
0 g
s
.57829 .72287 m .57803 .76009 L .54865 .76308 L p .707 .577 .707 r
F P
0 g
s
.57803 .76009 m .57829 .72287 L .61012 .72234 L p .707 .577 .707 r
F P
0 g
s
.61012 .72234 m .60987 .75956 L .57803 .76009 L p .707 .577 .707 r
F P
0 g
s
.57313 .80467 m .57386 .78575 L .60567 .78642 L p .707 .577 .707 r
F P
0 g
s
.60567 .78642 m .60494 .80534 L .57313 .80467 L p .707 .577 .707 r
F P
0 g
s
.53167 .32823 m .54281 .82181 L .58427 .81528 L p .707 .577 .707 r
F P
0 g
s
.57957 .67128 m .57396 .6214 L .60561 .61709 L p .707 .577 .707 r
F P
0 g
s
.60561 .61709 m .61122 .66697 L .57957 .67128 L p .707 .577 .707 r
F P
0 g
s
.58427 .81528 m .57314 .3217 L .53167 .32823 L p .707 .577 .707 r
F P
0 g
s
.45388 .82174 m .44274 .32816 L .40397 .32157 L p .707 .577 .707 r
F P
0 g
s
.44274 .32816 m .45388 .82174 L .49788 .82403 L p .707 .577 .707 r
F P
0 g
s
.69837 .64676 m .70398 .69664 L .69109 .68325 L p .707 .577 .707 r
F P
0 g
s
.69109 .68325 m .68548 .63337 L .69837 .64676 L p .707 .577 .707 r
F P
0 g
s
.64129 .72433 m .64104 .76155 L .60987 .75956 L p .707 .577 .707 r
F P
0 g
s
.60987 .75956 m .61012 .72234 L .64129 .72433 L p .707 .577 .707 r
F P
0 g
s
.63683 .78882 m .6361 .80774 L .60494 .80534 L p .707 .577 .707 r
F P
0 g
s
.60494 .80534 m .60567 .78642 L .63683 .78882 L p .707 .577 .707 r
F P
0 g
s
.57314 .3217 m .58427 .81528 L .61821 .80509 L p .707 .577 .707 r
F P
0 g
s
.63671 .61777 m .64233 .66765 L .61122 .66697 L p .707 .577 .707 r
F P
0 g
s
.61122 .66697 m .60561 .61709 L .63671 .61777 L p .707 .577 .707 r
F P
0 g
s
.61821 .80509 m .60707 .31151 L .57314 .3217 L p .707 .577 .707 r
F P
0 g
s
.7053 .75038 m .70504 .7876 L .70215 .77955 L p .707 .577 .707 r
F P
0 g
s
.70215 .77955 m .7024 .74233 L .7053 .75038 L p .707 .577 .707 r
F P
0 g
s
.70097 .80905 m .70024 .82797 L .69729 .82227 L p .707 .577 .707 r
F P
0 g
s
.69729 .82227 m .69802 .80335 L .70097 .80905 L p .707 .577 .707 r
F P
0 g
s
.41511 .81515 m .40397 .32157 L .37423 .31133 L p .707 .577 .707 r
F P
0 g
s
.40397 .32157 m .41511 .81515 L .45388 .82174 L p .707 .577 .707 r
F P
0 g
s
.25718 .73219 m .25157 .68231 L .22046 .68163 L p .707 .577 .707 r
F P
0 g
s
.25157 .68231 m .25718 .73219 L .28883 .72788 L p .707 .577 .707 r
F P
0 g
s
.28883 .72788 m .28322 .678 L .25157 .68231 L p .707 .577 .707 r
F P
0 g
s
.68548 .63337 m .69109 .68325 L .66985 .67326 L p .707 .577 .707 r
F P
0 g
s
.66985 .67326 m .66424 .62338 L .68548 .63337 L p .707 .577 .707 r
F P
0 g
s
.28322 .678 m .28883 .72788 L .31792 .719 L p .707 .577 .707 r
F P
0 g
s
.31792 .719 m .3123 .66912 L .28322 .678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22607 .73151 m .22046 .68163 L .19294 .67602 L p .707 .577 .707 r
F P
0 g
s
.22046 .68163 m .22607 .73151 L .25718 .73219 L p .707 .577 .707 r
F P
0 g
s
.6361 .80774 m .63683 .78882 L .6643 .79272 L p .707 .577 .707 r
F P
0 g
s
.60707 .31151 m .61821 .80509 L .64129 .79224 L p .707 .577 .707 r
F P
0 g
s
.64233 .66765 m .63671 .61777 L .66424 .62338 L p .707 .577 .707 r
F P
0 g
s
.64129 .79224 m .63015 .29865 L .60707 .31151 L p .707 .577 .707 r
F P
0 g
s
.3123 .66912 m .31792 .719 L .3416 .70641 L p .707 .577 .707 r
F P
0 g
s
.3416 .70641 m .33599 .65653 L .3123 .66912 L p .707 .577 .707 r
F P
0 g
s
.7024 .74233 m .70215 .77955 L .68955 .77206 L p .707 .577 .707 r
F P
0 g
s
.68955 .77206 m .68981 .73484 L .7024 .74233 L p .707 .577 .707 r
F P
0 g
s
.69802 .80335 m .69729 .82227 L .68465 .81664 L p .707 .577 .707 r
F P
0 g
s
.68465 .81664 m .68538 .79772 L .69802 .80335 L p .707 .577 .707 r
F P
0 g
s
.25332 .77408 m .25358 .73686 L .22241 .73487 L p .707 .577 .707 r
F P
0 g
s
.25358 .73686 m .25332 .77408 L .28515 .77356 L p .707 .577 .707 r
F P
0 g
s
.28515 .77356 m .28541 .73634 L .25358 .73686 L p .707 .577 .707 r
F P
0 g
s
.66424 .62338 m .66985 .67326 L .64233 .66765 L p .707 .577 .707 r
F P
0 g
s
.19855 .7259 m .19294 .67602 L .17169 .66603 L p .707 .577 .707 r
F P
0 g
s
.19294 .67602 m .19855 .7259 L .22607 .73151 L p .707 .577 .707 r
F P
0 g
s
.24876 .80385 m .24949 .78493 L .21832 .78253 L p .707 .577 .707 r
F P
0 g
s
.24949 .78493 m .24876 .80385 L .28056 .80452 L p .707 .577 .707 r
F P
0 g
s
.28056 .80452 m .28129 .7856 L .24949 .78493 L p .707 .577 .707 r
F P
0 g
s
.28541 .73634 m .28515 .77356 L .31454 .77057 L p .707 .577 .707 r
F P
0 g
s
.31454 .77057 m .31479 .73335 L .28541 .73634 L p .707 .577 .707 r
F P
0 g
s
.38537 .80491 m .37423 .31133 L .35644 .29844 L p .707 .577 .707 r
F P
0 g
s
.37423 .31133 m .38537 .80491 L .41511 .81515 L p .707 .577 .707 r
F P
0 g
s
.28129 .7856 m .28056 .80452 L .3099 .80339 L p .707 .577 .707 r
F P
0 g
s
.3099 .80339 m .31063 .78447 L .28129 .7856 L p .707 .577 .707 r
F P
0 g
s
.21832 .78253 m .21759 .80145 L .24876 .80385 L p .707 .577 .707 r
F P
0 g
s
.22215 .7721 m .22241 .73487 L .19495 .73057 L p .707 .577 .707 r
F P
0 g
s
.22241 .73487 m .22215 .7721 L .25332 .77408 L p .707 .577 .707 r
F P
0 g
s
.33599 .65653 m .3416 .70641 L .35756 .69135 L p .707 .577 .707 r
F P
0 g
s
.35756 .69135 m .35195 .64147 L .33599 .65653 L p .707 .577 .707 r
F P
0 g
s
.21759 .80145 m .21832 .78253 L .19086 .77863 L p .707 .577 .707 r
F P
0 g
s
.19086 .77863 m .19013 .79755 L .21759 .80145 L p .707 .577 .707 r
F P
0 g
s
.31479 .73335 m .31454 .77057 L .33859 .76542 L p .707 .577 .707 r
F P
0 g
s
.33859 .76542 m .33884 .7282 L .31479 .73335 L p .707 .577 .707 r
F P
0 g
s
.19495 .73057 m .19469 .76779 L .22215 .7721 L p .707 .577 .707 r
F P
0 g
s
.31063 .78447 m .3099 .80339 L .3339 .80059 L p .707 .577 .707 r
F P
0 g
s
.3339 .80059 m .33463 .78167 L .31063 .78447 L p .707 .577 .707 r
F P
0 g
s
.68981 .73484 m .68955 .77206 L .6685 .76586 L p .707 .577 .707 r
F P
0 g
s
.6685 .76586 m .66875 .72864 L .68981 .73484 L p .707 .577 .707 r
F P
0 g
s
.19469 .76779 m .19495 .73057 L .17389 .72437 L p .707 .577 .707 r
F P
0 g
s
.1773 .71591 m .17169 .66603 L .15881 .65264 L p .707 .577 .707 r
F P
0 g
s
.17169 .66603 m .1773 .71591 L .19855 .7259 L p .707 .577 .707 r
F P
0 g
s
.66875 .72864 m .6685 .76586 L .64104 .76155 L p .707 .577 .707 r
F P
0 g
s
.64104 .76155 m .64129 .72433 L .66875 .72864 L p .707 .577 .707 r
F P
0 g
s
.63015 .29865 m .64129 .79224 L .65126 .77798 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64012 .28439 L .63015 .29865 L p .707 .577 .707 r
F P
0 g
s
.68538 .79772 m .68465 .81664 L .66357 .81164 L p .707 .577 .707 r
F P
0 g
s
.66357 .81164 m .6643 .79272 L .68538 .79772 L p .707 .577 .707 r
F P
0 g
s
.19013 .79755 m .19086 .77863 L .16977 .77363 L p .707 .577 .707 r
F P
0 g
s
.16977 .77363 m .16904 .79255 L .19013 .79755 L p .707 .577 .707 r
F P
0 g
s
.35195 .64147 m .35756 .69135 L .36423 .6753 L p .707 .577 .707 r
F P
0 g
s
.36423 .6753 m .35862 .62542 L .35195 .64147 L p .707 .577 .707 r
F P
0 g
s
.17389 .72437 m .17363 .76159 L .19469 .76779 L p .707 .577 .707 r
F P
0 g
s
.33884 .7282 m .33859 .76542 L .35495 .7586 L p .707 .577 .707 r
F P
0 g
s
.35495 .7586 m .35521 .72138 L .33884 .7282 L p .707 .577 .707 r
F P
0 g
s
.33463 .78167 m .3339 .80059 L .35021 .79637 L p .707 .577 .707 r
F P
0 g
s
.35021 .79637 m .35094 .77745 L .33463 .78167 L p .707 .577 .707 r
F P
0 g
s
.35862 .62542 m .36423 .6753 L .36097 .65982 L p .707 .577 .707 r
F P
0 g
s
.36757 .79202 m .35644 .29844 L .35232 .28417 L p .707 .577 .707 r
F P
0 g
s
.35644 .29844 m .36757 .79202 L .38537 .80491 L p .707 .577 .707 r
F P
0 g
s
.17363 .76159 m .17389 .72437 L .1613 .71688 L p .707 .577 .707 r
F P
0 g
s
.6643 .79272 m .66357 .81164 L .6361 .80774 L p .707 .577 .707 r
F P
0 g
s
.16904 .79255 m .16977 .77363 L .15714 .768 L p .707 .577 .707 r
F P
0 g
s
.16442 .70252 m .15881 .65264 L .15554 .63716 L p .707 .577 .707 r
F P
0 g
s
.15881 .65264 m .16442 .70252 L .1773 .71591 L p .707 .577 .707 r
F P
0 g
s
.15714 .768 m .15641 .78692 L .16904 .79255 L p .707 .577 .707 r
F P
0 g
s
.1613 .71688 m .16104 .7541 L .17363 .76159 L p .707 .577 .707 r
F P
0 g
s
.36097 .65982 m .35536 .60994 L .35862 .62542 L p .707 .577 .707 r
F P
0 g
s
.35521 .72138 m .35495 .7586 L .36203 .75078 L p .707 .577 .707 r
F P
0 g
s
.36203 .75078 m .36229 .71356 L .35521 .72138 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64897 .77004 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64666 .7256 m .63735 .72145 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64656 .7237 m .64376 .53234 L .64897 .77004 L .707 .577 .707 r
F
.63735 .72145 m .63662 .74037 L .64769 .7453 L p F P
0 g
s
.64769 .7453 m .64926 .746 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64754 .74246 m .63735 .72145 L .64769 .7453 L .707 .577 .707 r
F
.64656 .7237 m .64283 .56343 L .64376 .53234 L F
.646 .71297 m .64418 .63221 L p .64656 .7237 L F P
0 g
s
.64418 .63221 m .63601 .27012 L p .64446 .63343 L .707 .577 .707 r
F P
0 g
s
.64418 .63221 m .64446 .63343 L .64656 .7237 L .707 .577 .707 r
F
.63601 .27012 m .64411 .62916 L p .62935 .75082 L F P
0 g
s
.63662 .74037 m .63735 .72145 L .63688 .72055 L p .707 .577 .707 r
F P
0 g
s
.63662 .74037 m .63688 .72055 L .63592 .73267 L .707 .577 .707 r
F
.63421 .75434 m .62935 .75082 L p .64411 .62916 L F P
0 g
s
.6344 .71575 m .63367 .73467 L .63662 .74037 L p .707 .577 .707 r
F P
0 g
s
.64411 .62916 m .64715 .7637 L .63421 .75434 L p .707 .577 .707 r
F P
0 g
s
.63688 .72055 m .6344 .71575 L p .63592 .73267 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .63576 .58455 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .64118 .61918 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .63902 .60003 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64487 .49481 m .65126 .77798 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .65752 .6633 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .64118 .61918 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .64463 .64991 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63601 .27012 m .64012 .28439 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64283 .56343 m .63601 .27012 L .64376 .53234 L .707 .577 .707 r
F
.64715 .7637 m .646 .71297 L p .64656 .7237 L F P
0 g
s
.64897 .77004 m .64715 .7637 L p .64656 .7237 L .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64999 .72708 L .64666 .7256 L p .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64666 .7256 L .64754 .74246 L .707 .577 .707 r
F
.65752 .6633 m .65191 .61342 L .64166 .60277 L p F P
0 g
s
.64166 .60277 m .63902 .60003 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.65752 .6633 m .64166 .60277 L .64149 .60849 L .707 .577 .707 r
F
.64012 .28439 m .64487 .49481 L p .64376 .53234 L F P
0 g
s
.35094 .77745 m .35021 .79637 L .35723 .79116 L p .707 .577 .707 r
F P
0 g
s
.35723 .79116 m .35796 .77224 L .35094 .77745 L p .707 .577 .707 r
F P
0 g
s
.16104 .7541 m .1613 .71688 L .1584 .70883 L p .707 .577 .707 r
F P
0 g
s
.16115 .68704 m .16442 .70252 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.15554 .63716 m .1587 .66522 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1587 .66522 m .16115 .68704 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1584 .70883 m .15814 .74605 L .16104 .7541 L p .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .1584 .70883 L .16274 .70403 L p .707 .577 .707 r
F P
0 g
s
.16274 .70403 m .16548 .70101 L p .16362 .71244 L .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .16274 .70403 L .16362 .71244 L .707 .577 .707 r
F
.16115 .68704 m .15554 .63716 L .16222 .62111 L p F P
0 g
s
.15641 .78692 m .15714 .768 L .15418 .7623 L p .707 .577 .707 r
F P
0 g
s
.15418 .7623 m .15345 .78122 L .15641 .78692 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35536 .60994 m .36097 .65982 L .34808 .64643 L p .707 .577 .707 r
F P
0 g
s
.36229 .71356 m .36203 .75078 L .35914 .74273 L p .707 .577 .707 r
F P
0 g
s
.35914 .74273 m .35939 .70551 L .36229 .71356 L p .707 .577 .707 r
F P
0 g
s
.35232 .28417 m .36346 .77775 L .36757 .79202 L p .707 .577 .707 r
F P
0 g
s
.36346 .77775 m .35232 .28417 L .36229 .2699 L p .707 .577 .707 r
F P
0 g
s
.34808 .64643 m .34247 .59655 L .35536 .60994 L p .707 .577 .707 r
F P
0 g
s
.35796 .77224 m .35723 .79116 L .35428 .78546 L p .707 .577 .707 r
F P
0 g
s
.35428 .78546 m .35501 .76653 L .35796 .77224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16783 .67099 m .16222 .62111 L .17818 .60605 L p .707 .577 .707 r
F P
0 g
s
.16222 .62111 m .16783 .67099 L .16115 .68704 L p .707 .577 .707 r
F P
0 g
s
.62935 .75082 m .61821 .25723 L .63601 .27012 L p .707 .577 .707 r
F P
0 g
s
.15345 .78122 m .15418 .7623 L .16121 .75709 L p .707 .577 .707 r
F P
0 g
s
.34247 .59655 m .34808 .64643 L .32684 .63644 L p .707 .577 .707 r
F P
0 g
s
.32684 .63644 m .32123 .58656 L .34247 .59655 L p .707 .577 .707 r
F P
0 g
s
.16121 .75709 m .16048 .77601 L .15345 .78122 L p .707 .577 .707 r
F P
0 g
s
.16548 .70101 m .16522 .73823 L .15814 .74605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35939 .70551 m .35914 .74273 L .34654 .73524 L p .707 .577 .707 r
F P
0 g
s
.34654 .73524 m .3468 .69802 L .35939 .70551 L p .707 .577 .707 r
F P
0 g
s
.37343 .76349 m .36229 .2699 L .38538 .25705 L p .707 .577 .707 r
F P
0 g
s
.36229 .2699 m .37343 .76349 L .36346 .77775 L p .707 .577 .707 r
F P
0 g
s
.17818 .60605 m .18379 .65593 L .16783 .67099 L p .707 .577 .707 r
F P
0 g
s
.18379 .65593 m .17818 .60605 L .20186 .59347 L p .707 .577 .707 r
F P
0 g
s
.35501 .76653 m .35428 .78546 L .34164 .77983 L p .707 .577 .707 r
F P
0 g
s
.34164 .77983 m .34237 .76091 L .35501 .76653 L p .707 .577 .707 r
F P
0 g
s
.32123 .58656 m .32684 .63644 L .29932 .63083 L p .707 .577 .707 r
F P
0 g
s
.29932 .63083 m .29371 .58095 L .32123 .58656 L p .707 .577 .707 r
F P
0 g
s
.16522 .73823 m .16548 .70101 L .18185 .69419 L p .707 .577 .707 r
F P
0 g
s
.16048 .77601 m .16121 .75709 L .17751 .75287 L p .707 .577 .707 r
F P
0 g
s
.17751 .75287 m .17678 .77179 L .16048 .77601 L p .707 .577 .707 r
F P
0 g
s
.18185 .69419 m .18159 .73141 L .16522 .73823 L p .707 .577 .707 r
F P
0 g
s
.20747 .64335 m .20186 .59347 L .23095 .58458 L p .707 .577 .707 r
F P
0 g
s
.20186 .59347 m .20747 .64335 L .18379 .65593 L p .707 .577 .707 r
F P
0 g
s
.61821 .25723 m .62935 .75082 L .59961 .74058 L p .707 .577 .707 r
F P
0 g
s
.59961 .74058 m .58847 .24699 L .61821 .25723 L p .707 .577 .707 r
F P
0 g
s
.29371 .58095 m .29932 .63083 L .26821 .63015 L p .707 .577 .707 r
F P
0 g
s
.26821 .63015 m .2626 .58027 L .29371 .58095 L p .707 .577 .707 r
F P
0 g
s
.3468 .69802 m .34654 .73524 L .32549 .72904 L p .707 .577 .707 r
F P
0 g
s
.32549 .72904 m .32574 .69182 L .3468 .69802 L p .707 .577 .707 r
F P
0 g
s
.23656 .63446 m .23095 .58458 L .2626 .58027 L p .707 .577 .707 r
F P
0 g
s
.23095 .58458 m .23656 .63446 L .20747 .64335 L p .707 .577 .707 r
F P
0 g
s
.2626 .58027 m .26821 .63015 L .23656 .63446 L p .707 .577 .707 r
F P
0 g
s
.34237 .76091 m .34164 .77983 L .32056 .77482 L p .707 .577 .707 r
F P
0 g
s
.32056 .77482 m .32129 .7559 L .34237 .76091 L p .707 .577 .707 r
F P
0 g
s
.18159 .73141 m .18185 .69419 L .2059 .68904 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .37343 .76349 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.38949 .4392 m .39651 .75063 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .38538 .25705 L .41931 .24686 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .40763 .50485 L .42658 .70051 L .707 .577 .707 r
F
.41538 .74497 m .39651 .75063 L p .42658 .70051 L F P
0 g
s
.4185 .70224 m .41777 .72116 L .42141 .72102 L p .707 .577 .707 r
F P
0 g
s
.42141 .72102 m .44711 .72003 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.42511 .70635 m .4185 .70224 L .42141 .72102 L .707 .577 .707 r
F
.44711 .72003 m .44784 .70111 L .42622 .70194 L p F P
0 g
s
.42622 .70194 m .4185 .70224 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.44711 .72003 m .42622 .70194 L .42511 .70635 L .707 .577 .707 r
F
.42601 .54409 m .4293 .68971 L p .40763 .50485 L F P
0 g
s
.4293 .68971 m .43045 .74044 L p .42658 .70051 L .707 .577 .707 r
F P
0 g
s
.40763 .50485 m .4293 .68971 L .42658 .70051 L .707 .577 .707 r
F
.43045 .74044 m .41538 .74497 L p .42658 .70051 L F P
0 g
s
.41931 .24686 m .42601 .54409 L p .40763 .50485 L .707 .577 .707 r
F P
0 g
s
.43045 .74044 m .41931 .24686 L .46077 .24033 L p .707 .577 .707 r
F P
0 g
s
.46077 .24033 m .47191 .73392 L .46058 .7357 L p .707 .577 .707 r
F P
0 g
s
.44784 .70111 m .44711 .72003 L .4563 .71896 L p .707 .577 .707 r
F P
0 g
s
.45258 .7044 m .44784 .70111 L .4563 .71896 L .707 .577 .707 r
F
.43646 .6413 m .46077 .24033 L .46058 .7357 L F
.47191 .73392 m .46077 .24033 L .5057 .23811 L p F P
0 g
s
.4711 .71723 m .47183 .69831 L .44784 .70111 L p .707 .577 .707 r
F P
0 g
s
.46058 .7357 m .43045 .74044 L p .43646 .6413 L .707 .577 .707 r
F P
0 g
s
.4563 .71896 m .4711 .71723 L p .45258 .7044 L .707 .577 .707 r
F P
0 g
s
.45512 .62957 m .45166 .59884 L p .42042 .58857 L .707 .577 .707 r
F P
0 g
s
.45166 .59884 m .44951 .57969 L .44354 .58151 L p .707 .577 .707 r
F P
0 g
s
.44354 .58151 m .42042 .58857 L p .45166 .59884 L .707 .577 .707 r
F P
0 g
s
.42236 .67579 m .42257 .64453 L p .39078 .6391 L .707 .577 .707 r
F P
0 g
s
.42257 .64453 m .42262 .63857 L .41681 .63867 L p .707 .577 .707 r
F P
0 g
s
.41681 .63867 m .39078 .6391 L p .42257 .64453 L .707 .577 .707 r
F P
0 g
s
.39438 .64276 m .39096 .61239 L p .35766 .5922 L .707 .577 .707 r
F P
0 g
s
.39096 .61239 m .38877 .59288 L .37141 .5925 L p .707 .577 .707 r
F P
0 g
s
.37141 .5925 m .35766 .5922 L p .39096 .61239 L .707 .577 .707 r
F P
0 g
s
.38877 .59288 m .39438 .64276 L .42126 .6391 L p .707 .577 .707 r
F P
0 g
s
.42262 .63857 m .42236 .67579 L .45174 .67281 L p .707 .577 .707 r
F P
0 g
s
.45174 .67281 m .45195 .64219 L p .42262 .63857 L .707 .577 .707 r
F P
0 g
s
.45195 .64219 m .452 .63559 L .4465 .63614 L p .707 .577 .707 r
F P
0 g
s
.4465 .63614 m .42262 .63857 L p .45195 .64219 L .707 .577 .707 r
F P
0 g
s
.42603 .63845 m .42281 .60986 L p .38877 .59288 L .707 .577 .707 r
F P
0 g
s
.42281 .60986 m .42042 .58857 L .40546 .59061 L p .707 .577 .707 r
F P
0 g
s
.40546 .59061 m .38877 .59288 L p .42281 .60986 L .707 .577 .707 r
F P
0 g
s
.42126 .6391 m .42603 .63845 L p .41999 .63106 L .707 .577 .707 r
F P
0 g
s
.41999 .63106 m .38877 .59288 L .42126 .6391 L .707 .577 .707 r
F
.38538 .25705 m .38949 .4392 L p .38217 .39315 L F P
0 g
s
.17678 .77179 m .17751 .75287 L .20151 .75006 L p .707 .577 .707 r
F P
0 g
s
.20151 .75006 m .20078 .76898 L .17678 .77179 L p .707 .577 .707 r
F P
0 g
s
.2059 .68904 m .20564 .72626 L .18159 .73141 L p .707 .577 .707 r
F P
0 g
s
.32574 .69182 m .32549 .72904 L .29803 .72474 L p .707 .577 .707 r
F P
0 g
s
.29803 .72474 m .29829 .68751 L .32574 .69182 L p .707 .577 .707 r
F P
0 g
s
.76537 .71261 m .76558 .68134 L p .73379 .67591 L .707 .577 .707 r
F P
0 g
s
.76558 .68134 m .76562 .67539 L .75982 .67548 L p .707 .577 .707 r
F P
0 g
s
.75982 .67548 m .73379 .67591 L p .76558 .68134 L .707 .577 .707 r
F P
0 g
s
.73739 .67958 m .73397 .6492 L p .70067 .62902 L .707 .577 .707 r
F P
0 g
s
.73397 .6492 m .73178 .6297 L .71442 .62932 L p .707 .577 .707 r
F P
0 g
s
.71442 .62932 m .70067 .62902 L p .73397 .6492 L .707 .577 .707 r
F P
0 g
s
.76562 .67539 m .76537 .71261 L .79475 .70962 L p .707 .577 .707 r
F P
0 g
s
.79475 .70962 m .79496 .679 L p .76562 .67539 L .707 .577 .707 r
F P
0 g
s
.79496 .679 m .79501 .6724 L .78951 .67296 L p .707 .577 .707 r
F P
0 g
s
.78951 .67296 m .76562 .67539 L p .79496 .679 L .707 .577 .707 r
F P
0 g
s
.76904 .67527 m .76582 .64668 L p .73178 .6297 L .707 .577 .707 r
F P
0 g
s
.76582 .64668 m .76343 .62539 L .74847 .62743 L p .707 .577 .707 r
F P
0 g
s
.74847 .62743 m .73178 .6297 L p .76582 .64668 L .707 .577 .707 r
F P
0 g
s
.73178 .6297 m .73739 .67958 L .76904 .67527 L p .707 .577 .707 r
F P
0 g
s
.76343 .62539 m .76904 .67527 L .79813 .66638 L p .707 .577 .707 r
F P
0 g
s
.79813 .66638 m .79252 .6165 L .76343 .62539 L p .707 .577 .707 r
F P
0 g
s
.58847 .24699 m .59961 .74058 L .56084 .73399 L p .707 .577 .707 r
F P
0 g
s
.56084 .73399 m .5497 .2404 L .58847 .24699 L p .707 .577 .707 r
F P
0 g
s
.32129 .7559 m .32056 .77482 L .29309 .77093 L p .707 .577 .707 r
F P
0 g
s
.29309 .77093 m .29382 .75201 L .32129 .7559 L p .707 .577 .707 r
F P
0 g
s
.20564 .72626 m .2059 .68904 L .23528 .68605 L p .707 .577 .707 r
F P
0 g
s
.73353 .71313 m .73374 .68387 L p .70262 .67393 L .707 .577 .707 r
F P
0 g
s
.73374 .68387 m .73379 .67591 L .72649 .67545 L p .707 .577 .707 r
F P
0 g
s
.72649 .67545 m .70262 .67393 L p .73374 .68387 L .707 .577 .707 r
F P
0 g
s
.70262 .67393 m .70236 .71115 L .73353 .71313 L p .707 .577 .707 r
F P
0 g
s
.70628 .6789 m .7028 .6479 L p .67315 .62341 L .707 .577 .707 r
F P
0 g
s
.7028 .6479 m .70067 .62902 L .68355 .62553 L p .707 .577 .707 r
F P
0 g
s
.68355 .62553 m .67315 .62341 L p .7028 .6479 L .707 .577 .707 r
F P
0 g
s
.73379 .67591 m .73353 .71313 L .76537 .71261 L p .707 .577 .707 r
F P
0 g
s
.70067 .62902 m .70628 .6789 L .73739 .67958 L p .707 .577 .707 r
F P
0 g
s
.20078 .76898 m .20151 .75006 L .23085 .74894 L p .707 .577 .707 r
F P
0 g
s
.79252 .6165 m .79813 .66638 L .82181 .6538 L p .707 .577 .707 r
F P
0 g
s
.82181 .6538 m .8162 .60392 L .79252 .6165 L p .707 .577 .707 r
F P
0 g
s
.29829 .68751 m .29803 .72474 L .26686 .72275 L p .707 .577 .707 r
F P
0 g
s
.26686 .72275 m .26711 .68553 L .29829 .68751 L p .707 .577 .707 r
F P
0 g
s
.23085 .74894 m .23012 .76786 L .20078 .76898 L p .707 .577 .707 r
F P
0 g
s
.23528 .68605 m .23502 .72327 L .20564 .72626 L p .707 .577 .707 r
F P
0 g
s
.23502 .72327 m .23528 .68605 L .26711 .68553 L p .707 .577 .707 r
F P
0 g
s
.29382 .75201 m .29309 .77093 L .26193 .76853 L p .707 .577 .707 r
F P
0 g
s
.26193 .76853 m .26266 .74961 L .29382 .75201 L p .707 .577 .707 r
F P
0 g
s
.26711 .68553 m .26686 .72275 L .23502 .72327 L p .707 .577 .707 r
F P
0 g
s
.23012 .76786 m .23085 .74894 L .26266 .74961 L p .707 .577 .707 r
F P
0 g
s
.70236 .71115 m .70253 .68633 L p .67516 .66962 L .707 .577 .707 r
F P
0 g
s
.70253 .68633 m .70262 .67393 L .69391 .67256 L p .707 .577 .707 r
F P
0 g
s
.69391 .67256 m .67516 .66962 L p .70253 .68633 L .707 .577 .707 r
F P
0 g
s
.67876 .67329 m .67534 .64291 L p .65191 .61342 L .707 .577 .707 r
F P
0 g
s
.67534 .64291 m .67315 .62341 L .65896 .61673 L p .707 .577 .707 r
F P
0 g
s
.65896 .61673 m .65191 .61342 L p .67534 .64291 L .707 .577 .707 r
F P
0 g
s
.67315 .62341 m .67876 .67329 L .70628 .6789 L p .707 .577 .707 r
F P
0 g
s
.5497 .2404 m .56084 .73399 L .51684 .73169 L p .707 .577 .707 r
F P
0 g
s
.51684 .73169 m .5057 .23811 L .5497 .2404 L p .707 .577 .707 r
F P
0 g
s
.72897 .7573 m .7297 .73838 L .69854 .73598 L p .707 .577 .707 r
F P
0 g
s
.7297 .73838 m .72897 .7573 L .76078 .75797 L p .707 .577 .707 r
F P
0 g
s
.76078 .75797 m .76151 .73905 L .7297 .73838 L p .707 .577 .707 r
F P
0 g
s
.26266 .74961 m .26193 .76853 L .23012 .76786 L p .707 .577 .707 r
F P
0 g
s
.76151 .73905 m .76078 .75797 L .79012 .75685 L p .707 .577 .707 r
F P
0 g
s
.79012 .75685 m .79085 .73793 L .76151 .73905 L p .707 .577 .707 r
F P
0 g
s
.69854 .73598 m .69781 .7549 L .72897 .7573 L p .707 .577 .707 r
F P
0 g
s
.8162 .60392 m .82181 .6538 L .83777 .63874 L p .707 .577 .707 r
F P
0 g
s
.83777 .63874 m .83216 .58886 L .8162 .60392 L p .707 .577 .707 r
F P
0 g
s
.69781 .7549 m .69854 .73598 L .67107 .73209 L p .707 .577 .707 r
F P
0 g
s
.79501 .6724 m .79475 .70962 L .8188 .70447 L p .707 .577 .707 r
F P
0 g
s
.8188 .70447 m .81906 .66725 L .79501 .6724 L p .707 .577 .707 r
F P
0 g
s
.5057 .23811 m .51684 .73169 L .47191 .73392 L p .707 .577 .707 r
F P
0 g
s
.67516 .66962 m .6749 .70684 L .70236 .71115 L p .707 .577 .707 r
F P
0 g
s
.67107 .73209 m .67034 .75101 L .69781 .7549 L p .707 .577 .707 r
F P
0 g
s
.79085 .73793 m .79012 .75685 L .81411 .75404 L p .707 .577 .707 r
F P
0 g
s
.81411 .75404 m .81484 .73512 L .79085 .73793 L p .707 .577 .707 r
F P
0 g
s
.6749 .70684 m .67516 .66962 L .6541 .66342 L p .707 .577 .707 r
F P
0 g
s
.65191 .61342 m .65752 .6633 L .67876 .67329 L p .707 .577 .707 r
F P
0 g
s
.67034 .75101 m .67107 .73209 L .64999 .72708 L p .707 .577 .707 r
F P
0 g
s
.6541 .66342 m .65385 .70064 L .6749 .70684 L p .707 .577 .707 r
F P
0 g
s
.64999 .72708 m .64926 .746 L .67034 .75101 L p .707 .577 .707 r
F P
0 g
s
.83216 .58886 m .83777 .63874 L .84445 .62269 L p .707 .577 .707 r
F P
0 g
s
.84445 .62269 m .83884 .57281 L .83216 .58886 L p .707 .577 .707 r
F P
0 g
s
.81906 .66725 m .8188 .70447 L .83517 .69765 L p .707 .577 .707 r
F P
0 g
s
.83517 .69765 m .83542 .66043 L .81906 .66725 L p .707 .577 .707 r
F P
0 g
s
.81484 .73512 m .81411 .75404 L .83042 .74982 L p .707 .577 .707 r
F P
0 g
s
.83042 .74982 m .83115 .7309 L .81484 .73512 L p .707 .577 .707 r
F P
0 g
s
.65385 .70064 m .6541 .66342 L .64151 .65593 L p .707 .577 .707 r
F P
0 g
s
.64151 .65593 m .64125 .69315 L .65385 .70064 L p .707 .577 .707 r
F P
0 g
s
.83884 .57281 m .84445 .62269 L .84118 .60721 L p .707 .577 .707 r
F P
0 g
s
.84118 .60721 m .83557 .55733 L .83884 .57281 L p .707 .577 .707 r
F P
0 g
s
.83542 .66043 m .83517 .69765 L .84225 .68983 L p .707 .577 .707 r
F P
0 g
s
.84225 .68983 m .84251 .65261 L .83542 .66043 L p .707 .577 .707 r
F P
0 g
s
.83115 .7309 m .83042 .74982 L .83744 .74461 L p .707 .577 .707 r
F P
0 g
s
.83744 .74461 m .83817 .72569 L .83115 .7309 L p .707 .577 .707 r
F P
0 g
s
.64125 .69315 m .64151 .65593 L .63861 .64788 L p .707 .577 .707 r
F P
0 g
s
.64137 .63443 m .64463 .64991 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63576 .58455 m .63886 .61213 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63886 .61213 m .64137 .63443 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63861 .64788 m .63835 .6851 L .64125 .69315 L p .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .63861 .64788 L .64217 .64395 L p .707 .577 .707 r
F P
0 g
s
.64217 .64395 m .64569 .64006 L p .6433 .65475 L .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .64217 .64395 L .6433 .65475 L .707 .577 .707 r
F
.64137 .63443 m .63576 .58455 L .64243 .5685 L p F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83557 .55733 m .84118 .60721 L .8283 .59382 L p .707 .577 .707 r
F P
0 g
s
.8283 .59382 m .82269 .54394 L .83557 .55733 L p .707 .577 .707 r
F P
0 g
s
.84251 .65261 m .84225 .68983 L .83935 .68179 L p .707 .577 .707 r
F P
0 g
s
.83935 .68179 m .83961 .64456 L .84251 .65261 L p .707 .577 .707 r
F P
0 g
s
.83817 .72569 m .83744 .74461 L .83449 .73891 L p .707 .577 .707 r
F P
0 g
s
.83449 .73891 m .83522 .71999 L .83817 .72569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64804 .61838 m .64243 .5685 L .65839 .55344 L p .707 .577 .707 r
F P
0 g
s
.64243 .5685 m .64804 .61838 L .64137 .63443 L p .707 .577 .707 r
F P
0 g
s
.63367 .73467 m .6344 .71575 L .64142 .71054 L p .707 .577 .707 r
F P
0 g
s
.82269 .54394 m .8283 .59382 L .80705 .58383 L p .707 .577 .707 r
F P
0 g
s
.80705 .58383 m .80144 .53395 L .82269 .54394 L p .707 .577 .707 r
F P
0 g
s
.64569 .64006 m .64544 .67728 L .63835 .6851 L p .707 .577 .707 r
F P
0 g
s
.42042 .58857 m .42603 .63845 L .45512 .62957 L p .707 .577 .707 r
F P
0 g
s
.64142 .71054 m .64069 .72946 L .63367 .73467 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39052 .67632 m .39073 .64705 L p .35961 .63711 L .707 .577 .707 r
F P
0 g
s
.39073 .64705 m .39078 .6391 L .38348 .63863 L p .707 .577 .707 r
F P
0 g
s
.38348 .63863 m .35961 .63711 L p .39073 .64705 L .707 .577 .707 r
F P
0 g
s
.35961 .63711 m .35935 .67433 L .39052 .67632 L p .707 .577 .707 r
F P
0 g
s
.36327 .64208 m .35979 .61109 L p .33014 .58659 L .707 .577 .707 r
F P
0 g
s
.35979 .61109 m .35766 .5922 L .34054 .58871 L p .707 .577 .707 r
F P
0 g
s
.34054 .58871 m .33014 .58659 L p .35979 .61109 L .707 .577 .707 r
F P
0 g
s
.39078 .6391 m .39052 .67632 L .42236 .67579 L p .707 .577 .707 r
F P
0 g
s
.35766 .5922 m .36327 .64208 L .39438 .64276 L p .707 .577 .707 r
F P
0 g
s
.83961 .64456 m .83935 .68179 L .82676 .67429 L p .707 .577 .707 r
F P
0 g
s
.82676 .67429 m .82701 .63707 L .83961 .64456 L p .707 .577 .707 r
F P
0 g
s
.44951 .57969 m .45512 .62957 L .4788 .61698 L p .707 .577 .707 r
F P
0 g
s
.4788 .61698 m .47319 .5671 L .44951 .57969 L p .707 .577 .707 r
F P
0 g
s
.65839 .55344 m .664 .60332 L .64804 .61838 L p .707 .577 .707 r
F P
0 g
s
.664 .60332 m .65839 .55344 L .68207 .54085 L p .707 .577 .707 r
F P
0 g
s
.83522 .71999 m .83449 .73891 L .82185 .73328 L p .707 .577 .707 r
F P
0 g
s
.82185 .73328 m .82259 .71436 L .83522 .71999 L p .707 .577 .707 r
F P
0 g
s
.64544 .67728 m .64569 .64006 L .66206 .63324 L p .707 .577 .707 r
F P
0 g
s
.80144 .53395 m .80705 .58383 L .77953 .57822 L p .707 .577 .707 r
F P
0 g
s
.77953 .57822 m .77392 .52834 L .80144 .53395 L p .707 .577 .707 r
F P
0 g
s
.35935 .67433 m .35952 .64952 L p .33215 .6328 L .707 .577 .707 r
F P
0 g
s
.35952 .64952 m .35961 .63711 L .3509 .63574 L p .707 .577 .707 r
F P
0 g
s
.3509 .63574 m .33215 .6328 L p .35952 .64952 L .707 .577 .707 r
F P
0 g
s
.33575 .63647 m .33233 .60609 L p .3089 .5766 L .707 .577 .707 r
F P
0 g
s
.33233 .60609 m .33014 .58659 L .31595 .57992 L p .707 .577 .707 r
F P
0 g
s
.31595 .57992 m .3089 .5766 L p .33233 .60609 L .707 .577 .707 r
F P
0 g
s
.33014 .58659 m .33575 .63647 L .36327 .64208 L p .707 .577 .707 r
F P
0 g
s
.38596 .72049 m .38669 .70157 L .35553 .69917 L p .707 .577 .707 r
F P
0 g
s
.38669 .70157 m .38596 .72049 L .41777 .72116 L p .707 .577 .707 r
F P
0 g
s
.41777 .72116 m .4185 .70224 L .38669 .70157 L p .707 .577 .707 r
F P
0 g
s
.35553 .69917 m .3548 .71809 L .38596 .72049 L p .707 .577 .707 r
F P
0 g
s
.47319 .5671 m .4788 .61698 L .49476 .60192 L p .707 .577 .707 r
F P
0 g
s
.49476 .60192 m .48915 .55204 L .47319 .5671 L p .707 .577 .707 r
F P
0 g
s
.64069 .72946 m .64142 .71054 L .65773 .70632 L p .707 .577 .707 r
F P
0 g
s
.66206 .63324 m .6618 .67047 L .64544 .67728 L p .707 .577 .707 r
F P
0 g
s
.3548 .71809 m .35553 .69917 L .32806 .69527 L p .707 .577 .707 r
F P
0 g
s
.65773 .70632 m .657 .72524 L .64069 .72946 L p .707 .577 .707 r
F P
0 g
s
.452 .63559 m .45174 .67281 L .47579 .66765 L p .707 .577 .707 r
F P
0 g
s
.47579 .66765 m .47605 .63043 L .452 .63559 L p .707 .577 .707 r
F P
0 g
s
.68769 .59073 m .68207 .54085 L .71116 .53197 L p .707 .577 .707 r
F P
0 g
s
.68207 .54085 m .68769 .59073 L .664 .60332 L p .707 .577 .707 r
F P
0 g
s
.33215 .6328 m .33189 .67003 L .35935 .67433 L p .707 .577 .707 r
F P
0 g
s
.32806 .69527 m .32733 .71419 L .3548 .71809 L p .707 .577 .707 r
F P
0 g
s
.77392 .52834 m .77953 .57822 L .74842 .57754 L p .707 .577 .707 r
F P
0 g
s
.74842 .57754 m .74281 .52766 L .77392 .52834 L p .707 .577 .707 r
F P
0 g
s
.82701 .63707 m .82676 .67429 L .8057 .66809 L p .707 .577 .707 r
F P
0 g
s
.8057 .66809 m .80596 .63087 L .82701 .63707 L p .707 .577 .707 r
F P
0 g
s
.33189 .67003 m .33215 .6328 L .31109 .6266 L p .707 .577 .707 r
F P
0 g
s
.71677 .58185 m .71116 .53197 L .74281 .52766 L p .707 .577 .707 r
F P
0 g
s
.71116 .53197 m .71677 .58185 L .68769 .59073 L p .707 .577 .707 r
F P
0 g
s
.31451 .62648 m .3089 .5766 L .29601 .56321 L p .707 .577 .707 r
F P
0 g
s
.3089 .5766 m .31451 .62648 L .33575 .63647 L p .707 .577 .707 r
F P
0 g
s
.74281 .52766 m .74842 .57754 L .71677 .58185 L p .707 .577 .707 r
F P
0 g
s
.82259 .71436 m .82185 .73328 L .80077 .72827 L p .707 .577 .707 r
F P
0 g
s
.80077 .72827 m .8015 .70935 L .82259 .71436 L p .707 .577 .707 r
F P
0 g
s
.32733 .71419 m .32806 .69527 L .30698 .69027 L p .707 .577 .707 r
F P
0 g
s
.6618 .67047 m .66206 .63324 L .68611 .62809 L p .707 .577 .707 r
F P
0 g
s
.31109 .6266 m .31084 .66382 L .33189 .67003 L p .707 .577 .707 r
F P
0 g
s
.30698 .69027 m .30625 .70919 L .32733 .71419 L p .707 .577 .707 r
F P
0 g
s
.48915 .55204 m .49476 .60192 L .50144 .58587 L p .707 .577 .707 r
F P
0 g
s
.50144 .58587 m .49583 .53599 L .48915 .55204 L p .707 .577 .707 r
F P
0 g
s
.47605 .63043 m .47579 .66765 L .49216 .66083 L p .707 .577 .707 r
F P
0 g
s
.49216 .66083 m .49241 .62361 L .47605 .63043 L p .707 .577 .707 r
F P
0 g
s
.657 .72524 m .65773 .70632 L .68172 .70351 L p .707 .577 .707 r
F P
0 g
s
.68611 .62809 m .68585 .66531 L .6618 .67047 L p .707 .577 .707 r
F P
0 g
s
.68172 .70351 m .68099 .72243 L .657 .72524 L p .707 .577 .707 r
F P
0 g
s
.80596 .63087 m .8057 .66809 L .77824 .66379 L p .707 .577 .707 r
F P
0 g
s
.77824 .66379 m .7785 .62657 L .80596 .63087 L p .707 .577 .707 r
F P
0 g
s
.47183 .69831 m .4711 .71723 L .48741 .71301 L p .707 .577 .707 r
F P
0 g
s
.48741 .71301 m .48814 .69409 L .47183 .69831 L p .707 .577 .707 r
F P
0 g
s
.31084 .66382 m .31109 .6266 L .2985 .61911 L p .707 .577 .707 r
F P
0 g
s
.68585 .66531 m .68611 .62809 L .71549 .6251 L p .707 .577 .707 r
F P
0 g
s
.30162 .61309 m .29601 .56321 L .29275 .54773 L p .707 .577 .707 r
F P
0 g
s
.29601 .56321 m .30162 .61309 L .31451 .62648 L p .707 .577 .707 r
F P
0 g
s
.8015 .70935 m .80077 .72827 L .7733 .72438 L p .707 .577 .707 r
F P
0 g
s
.7733 .72438 m .77403 .70546 L .8015 .70935 L p .707 .577 .707 r
F P
0 g
s
.30625 .70919 m .30698 .69027 L .29434 .68464 L p .707 .577 .707 r
F P
0 g
s
.2985 .61911 m .29824 .65633 L .31084 .66382 L p .707 .577 .707 r
F P
0 g
s
.29434 .68464 m .29361 .70356 L .30625 .70919 L p .707 .577 .707 r
F P
0 g
s
.7785 .62657 m .77824 .66379 L .74707 .6618 L p .707 .577 .707 r
F P
0 g
s
.74707 .6618 m .74733 .62458 L .7785 .62657 L p .707 .577 .707 r
F P
0 g
s
.68099 .72243 m .68172 .70351 L .71106 .70239 L p .707 .577 .707 r
F P
0 g
s
.71549 .6251 m .71524 .66232 L .68585 .66531 L p .707 .577 .707 r
F P
0 g
s
.49583 .53599 m .50144 .58587 L .49817 .57039 L p .707 .577 .707 r
F P
0 g
s
.49817 .57039 m .49256 .52051 L .49583 .53599 L p .707 .577 .707 r
F P
0 g
s
.49241 .62361 m .49216 .66083 L .49924 .65302 L p .707 .577 .707 r
F P
0 g
s
.49924 .65302 m .4995 .6158 L .49241 .62361 L p .707 .577 .707 r
F P
0 g
s
.71524 .66232 m .71549 .6251 L .74733 .62458 L p .707 .577 .707 r
F P
0 g
s
.71106 .70239 m .71033 .72131 L .68099 .72243 L p .707 .577 .707 r
F P
0 g
s
.74733 .62458 m .74707 .6618 L .71524 .66232 L p .707 .577 .707 r
F P
0 g
s
.77403 .70546 m .7733 .72438 L .74214 .72198 L p .707 .577 .707 r
F P
0 g
s
.74214 .72198 m .74287 .70306 L .77403 .70546 L p .707 .577 .707 r
F P
0 g
s
.48814 .69409 m .48741 .71301 L .49443 .70779 L p .707 .577 .707 r
F P
0 g
s
.49443 .70779 m .49516 .68887 L .48814 .69409 L p .707 .577 .707 r
F P
0 g
s
.71033 .72131 m .71106 .70239 L .74287 .70306 L p .707 .577 .707 r
F P
0 g
s
.29824 .65633 m .2985 .61911 L .2956 .61106 L p .707 .577 .707 r
F P
0 g
s
.74287 .70306 m .74214 .72198 L .71033 .72131 L p .707 .577 .707 r
F P
0 g
s
.29836 .59761 m .30162 .61309 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29275 .54773 m .29585 .57531 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29585 .57531 m .29836 .59761 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.2956 .61106 m .29534 .64829 L .29824 .65633 L p .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .2956 .61106 L .29916 .60713 L p .707 .577 .707 r
F P
0 g
s
.29916 .60713 m .30268 .60325 L p .30029 .61794 L .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .29916 .60713 L .30029 .61794 L .707 .577 .707 r
F
.29836 .59761 m .29275 .54773 L .29942 .53168 L p F P
0 g
s
.29361 .70356 m .29434 .68464 L .29139 .67894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29139 .67894 m .29066 .69786 L .29361 .70356 L p .707 .577 .707 r
F P
0 g
s
.49256 .52051 m .49817 .57039 L .48529 .557 L p .707 .577 .707 r
F P
0 g
s
.48529 .557 m .47968 .50712 L .49256 .52051 L p .707 .577 .707 r
F P
0 g
s
.4995 .6158 m .49924 .65302 L .49634 .64497 L p .707 .577 .707 r
F P
0 g
s
.49634 .64497 m .4966 .60775 L .4995 .6158 L p .707 .577 .707 r
F P
0 g
s
.49516 .68887 m .49443 .70779 L .49148 .70209 L p .707 .577 .707 r
F P
0 g
s
.49148 .70209 m .49221 .68317 L .49516 .68887 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30503 .58156 m .29942 .53168 L .31538 .51662 L p .707 .577 .707 r
F P
0 g
s
.29942 .53168 m .30503 .58156 L .29836 .59761 L p .707 .577 .707 r
F P
0 g
s
.29066 .69786 m .29139 .67894 L .29841 .67372 L p .707 .577 .707 r
F P
0 g
s
.47968 .50712 m .48529 .557 L .46404 .54701 L p .707 .577 .707 r
F P
0 g
s
.46404 .54701 m .45843 .49713 L .47968 .50712 L p .707 .577 .707 r
F P
0 g
s
.30268 .60325 m .30242 .64047 L .29534 .64829 L p .707 .577 .707 r
F P
0 g
s
.29841 .67372 m .29768 .69264 L .29066 .69786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4966 .60775 m .49634 .64497 L .48375 .63748 L p .707 .577 .707 r
F P
0 g
s
.48375 .63748 m .484 .60026 L .4966 .60775 L p .707 .577 .707 r
F P
0 g
s
.31538 .51662 m .32099 .5665 L .30503 .58156 L p .707 .577 .707 r
F P
0 g
s
.32099 .5665 m .31538 .51662 L .33906 .50404 L p .707 .577 .707 r
F P
0 g
s
.49221 .68317 m .49148 .70209 L .47884 .69647 L p .707 .577 .707 r
F P
0 g
s
.47884 .69647 m .47957 .67755 L .49221 .68317 L p .707 .577 .707 r
F P
0 g
s
.30242 .64047 m .30268 .60325 L .31905 .59643 L p .707 .577 .707 r
F P
0 g
s
.45843 .49713 m .46404 .54701 L .43652 .5414 L p .707 .577 .707 r
F P
0 g
s
.43652 .5414 m .43091 .49152 L .45843 .49713 L p .707 .577 .707 r
F P
0 g
s
.29768 .69264 m .29841 .67372 L .31472 .66951 L p .707 .577 .707 r
F P
0 g
s
.31905 .59643 m .31879 .63365 L .30242 .64047 L p .707 .577 .707 r
F P
0 g
s
.31472 .66951 m .31399 .68843 L .29768 .69264 L p .707 .577 .707 r
F P
0 g
s
.34467 .55392 m .33906 .50404 L .36815 .49515 L p .707 .577 .707 r
F P
0 g
s
.33906 .50404 m .34467 .55392 L .32099 .5665 L p .707 .577 .707 r
F P
0 g
s
.43091 .49152 m .43652 .5414 L .40541 .54072 L p .707 .577 .707 r
F P
0 g
s
.40541 .54072 m .3998 .49084 L .43091 .49152 L p .707 .577 .707 r
F P
0 g
s
.484 .60026 m .48375 .63748 L .46269 .63128 L p .707 .577 .707 r
F P
0 g
s
.46269 .63128 m .46295 .59406 L .484 .60026 L p .707 .577 .707 r
F P
0 g
s
.37376 .54503 m .36815 .49515 L .3998 .49084 L p .707 .577 .707 r
F P
0 g
s
.36815 .49515 m .37376 .54503 L .34467 .55392 L p .707 .577 .707 r
F P
0 g
s
.3998 .49084 m .40541 .54072 L .37376 .54503 L p .707 .577 .707 r
F P
0 g
s
.47957 .67755 m .47884 .69647 L .45776 .69146 L p .707 .577 .707 r
F P
0 g
s
.45776 .69146 m .45849 .67254 L .47957 .67755 L p .707 .577 .707 r
F P
0 g
s
.31879 .63365 m .31905 .59643 L .3431 .59127 L p .707 .577 .707 r
F P
0 g
s
.31399 .68843 m .31472 .66951 L .33871 .6667 L p .707 .577 .707 r
F P
0 g
s
.3431 .59127 m .34284 .6285 L .31879 .63365 L p .707 .577 .707 r
F P
0 g
s
.33871 .6667 m .33798 .68562 L .31399 .68843 L p .707 .577 .707 r
F P
0 g
s
.46295 .59406 m .46269 .63128 L .43523 .62697 L p .707 .577 .707 r
F P
0 g
s
.43523 .62697 m .43549 .58975 L .46295 .59406 L p .707 .577 .707 r
F P
0 g
s
.34284 .6285 m .3431 .59127 L .37248 .58829 L p .707 .577 .707 r
F P
0 g
s
.45849 .67254 m .45776 .69146 L .43029 .68757 L p .707 .577 .707 r
F P
0 g
s
.43029 .68757 m .43102 .66865 L .45849 .67254 L p .707 .577 .707 r
F P
0 g
s
.43549 .58975 m .43523 .62697 L .40406 .62498 L p .707 .577 .707 r
F P
0 g
s
.40406 .62498 m .40432 .58776 L .43549 .58975 L p .707 .577 .707 r
F P
0 g
s
.33798 .68562 m .33871 .6667 L .36805 .66558 L p .707 .577 .707 r
F P
0 g
s
.37248 .58829 m .37222 .62551 L .34284 .6285 L p .707 .577 .707 r
F P
0 g
s
.37222 .62551 m .37248 .58829 L .40432 .58776 L p .707 .577 .707 r
F P
0 g
s
.36805 .66558 m .36732 .6845 L .33798 .68562 L p .707 .577 .707 r
F P
0 g
s
.40432 .58776 m .40406 .62498 L .37222 .62551 L p .707 .577 .707 r
F P
0 g
s
.43102 .66865 m .43029 .68757 L .39913 .68517 L p .707 .577 .707 r
F P
0 g
s
.39913 .68517 m .39986 .66625 L .43102 .66865 L p .707 .577 .707 r
F P
0 g
s
.36732 .6845 m .36805 .66558 L .39986 .66625 L p .707 .577 .707 r
F P
0 g
s
.39986 .66625 m .39913 .68517 L .36732 .6845 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool=0027Ool0081oo`T0
00IJEP03001JEUYF00AJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001dOol007=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEP00001bOol006moo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP04001JEUYFFUH3001_Ool006aoo`<000QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006eoo`00JWoo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0`00Jgoo001XOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001YOol006Ioo`8000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0IWoo001UOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=o
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000AJEPl0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00<005YF00001@0015YF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0Hgoo001UOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1SOol0069oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00AJEP03001oogoo06=oo`00Ggoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH015YF00<007ooOol0Hgoo001MOol200000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1S
Ool005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06=oo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001HOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0Hgoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001GOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<007ooOol0Hgoo001FOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo01Eooa0003ioo`00EGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00ioo`L000AJEP03001JEUYF00EJEP04
001JEUYFFUH5000iOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3000gOol005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPd000EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02000eOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF009JEP@00003FUH005YF
00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20007Ool30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000cOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPD0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP8000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006Ool01000FUIJEP0025YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20003FUH01@00
FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000<Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH30002Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH300000eYF001JEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF008000=JEP05001JEUYFFUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
1000FUIJEP0015YF00@005YFFUH000Moo`03001JEP0000IJEP<000MJEP03001JEUYF00UJEP03001J
EUYF00<0009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH400000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0`0027oo00<005YF
00001EYF1@001UYF00<005YFFUH02EYF00<005YF00000eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH002moo`00Dgoo00@005YFFUH000AJEP03001oogoo00Qoo`03001JEP0000EJEPD000IJEP03001J
EUYF00UJEP8000AJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH0
00=JEP03001oogoo00Uoo`03001JEP0000EJEPD000IJEP03001JEUYF00MJEP800003FUH005YF00=J
EP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH2000<
Ool00`00FUH00006FUH30007FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000<000aoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00AWoo3`00
00=JEP0000000UYF0P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH30007FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF1P003goo10000UYF
00<005YFFUH00eYF00@005YFFUH002ioo`00@7oo1P0015YF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0`001goo00@005YFFUH000EJEP03001JEUYF00MJEP@0009JEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000IOol40004FUH00`00FUIJ
EP02000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03
001JEP0000<000=ooaX000MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH00002000OOol3000015YF001JEUYF0P00;Goo000iOol30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH30002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P000UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00=JEP<002Eoo`80009JEP8002eoo`00
=goo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF00000`000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF
009JEP04001JEUYFFUH2000?Ool3000EOol200001EYF001JEUYF0000;Goo000eOol20002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03
FUH01000FUH0000047oo1@004goo00@005YFFUIJEP800003FUH007oo02aoo`00<goo0P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH2000BOol5
000BOol00`00FUIJEP03FUH3000]Ool0039oo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP0057oo1@0047oo
0`001EYF00<005YF0000;Goo000aOol20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP0001Ioo`<0011oo`04001J
EUYF0005FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P00:7oo0P000eYF00<0
05YFFUH00eYF00@005YF000002aoo`00;goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF10008goo0`001UYF
00<005YFFUH00UYF00@005YFFUH002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH20002FUH2000MOol40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000^
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00T005YF
FUIJEP00FUH005YF000015YF1`000goo4`001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002aoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF0`001EYF200015YF00<005YFFUH00eYF
00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000EJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP03001JEUYF00=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF300000=JEP00FUH00eYF00<005YF00000`001eYF00<005YFFUH015YF1@001UYF00<005YF
FUH00eYF1P0015YF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH7000;Ool00`00FUH00003FUH500000eYF001JEP06FUH00`00FUIJ
EP04FUH50006FUH00`00FUIJEP0800001UYF00000000FUH000=JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00`001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00<007oo
Ool0;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04000BOol01000FUH005YF
0P001EYF1@0015YF00<005YFFUH015YF1@0000=JEP0000001P0015YF00<005YFFUH015YF0`000eYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH0
0000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP<0
01Ioo`06001JEP00001JEP001EYF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo000/Ool00`00FUH00005FUH01000
FUIJEUYF0P006Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000^Ool002aoo`04001JEUYF0004FUH01000FUIJEP006goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002aoo`04001JEUYF0004FUH3000AOol3
0008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000/Ool01000FUIJEP0015YF00<007ooOol047oo1@0027oo00D005YFFUIJEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001oogoo
015oo`D000Uoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00;7oo00D005YFFUH005YF008001Aoo`D000]oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`04001JEP00000G
Ool3000>OolM0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH700000eYF001J
EP06FUH40006FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
000TOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUH0
0003000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=J
EPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEP80009oo`H00003FUH005YF009JEP80
02eoo`00;Goo00@005YF0000009JEP8001ioo`@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJEP<000EJEP8000MJEPD0
00EJEP03001JEP0000H000EJEP<000=JEP8002eoo`00;Goo0P0000=JEP00FUH00eYF1@0057oo1`00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00<000EJEP03001JEUYF00@0009JEP03001JEUYF00EJEPD00003FUH0000000D000AJEP03
001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P000UYF00<005YFFUH00UYF00@0
05YFFUIJEPT000Moo`@0009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPh00004FUH005YF0004FUH0
1000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;Goo0P000UYF00<005YFFUH00UYF00<005YFFUH03P0015YF00<005YFFUH0
0UYF0`0000AJEP00FUIJEPH000=JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000=JEPP0
00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Goo0P000UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000T0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH6
0004FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool20002FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF
FUH020000UYF00<007oo00000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01eYF0`0000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF00<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH90006
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH700000eYF00000005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool30002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF400000=JEP00FUH015YF0`000eYF00@005YFFUIJ
EP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJ
EP03001JEUYF00AJEQ800003FUH005YF00IJEP03001JEUYF00AJEP04001JEP00000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;
FUH01000FUIJEUYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF3`0015YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH00UYF1@00<goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00002UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Qoo`00;Goo00<007oo00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP0000YJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00002000eOol002eoo`03001oo`0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00009FUH4000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000b
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP05001JEUYFFUH00006FUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YF00001@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YF001JEP0000=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000]Ool00eYF001JEP03FUH01000FUIJEUYF200000=JEP00FUH01EYF1@0015YF
200015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00002FUH50003FUH00`00FUIJEP03FUH00`00Oomoo`06Ool50008Ool40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool30003FUH<0002FUH00`00FUIJEP04FUH90008Ool6
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<00003
FUH0000000H000EJEP03001oogoo00Moo`<000eoo`D000=JEP04001JEUYFFUH2000^Ool002aoo`04
001JEP00FUH20005FUH01000FUIJEUYF4@002Woo1`0000IJEP00000005YF0003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF7@0025YF00<005YFFUH01EYF00@005YF0000009J
EP03001JEUYF009JEPP00003FUH007oo01ioo`@000=JEP8002ioo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YFFUH01UYF
1P000UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEQ8000Uoo``0
0004FUH00000FUH2000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF
009JEP03001JEUYF00=JEP03001JEUYF00IJEPH00003FUH005YF00YJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00=JEP03001JEUYF009J
EP@000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH015YF20000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP04FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000_Ool002aoo`8000=JEP03001JEUYF009JEPP000=JEP03001JEUYF009J
EQ40009JEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000000IJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<0031oo`00;Goo00<005YFFUH01P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH200001GooFUIJ
EUYF00000eYF0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP04001JEUYFFUH90004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00<goo000]Ool30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
0003FUH00`00Oomoo`03FUH01000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03
001JEUYF009JEP04001JEUYFFUH20002OolI000iOol002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000=o
o`=JEP@000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0eYF00@005YFFUH000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH0000000D000=JEP04001JEUYFFUH2001DOol002]oo`03001JEP00
00AJEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000Woo0UYF
00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002Ool600000eYF001JEP02FUH2001D
Ool002]oo`03001JEP00009JEPH000Eoo`T000AJEP<0009JEPX000AJEP03001JEUYF00=JEP03001J
EUYF00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000<000EJEP<0
00=JEP8005Aoo`00:goo00<005YF00000`0000AJEP00000000moo`T000Yoo`L000=JEP03001JEUYF
00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001J
EUYF00800003FUH0000005Aoo`00:goo0P000eYF00<005YFFUH00UYF1@003Goo1@004Woo10000UYF
0P0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YF
FUH00UYF0`00E7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF20001Goo1@0047oo2P00
00=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF001JEP0000IJEP03001JEUYF
009JEP<005Aoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUHJ0003FUH0
1000FUIJEUYF0`0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP00009oo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00EJ
EP03001JEUYF009JEP8005Eoo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P000goo00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1P000UYF00<005YFFUH00UYF0P00EGoo000cOol7
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP030005Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH010000UYF0P00
EWoo000jOol80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@002Woo0`0025YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00H005YF000005YF0007FUH00`00FUIJEP03FUH3001HOol0049ooaX0015oo`8000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00Kgoo0`0015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`000UYF200015YF
00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00LWoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00003P0000=oo`000000100015YF00@005YFFUIJ
EP8005Eoo`00MGoo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF100000=o
o`0000000`0047oo0`0000=JEP00FUH00UYF0P00EGoo001iOol60002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH01000FUIJEUYF1P001Goo1@003goo1`000UYF0P00EGoo001oOol80006FUH00`00FUIJ
EP04FUH:00000eYF001JEP03FUHI0003FUH01000FUIJEUYF1000EGoo0027Ool=0003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3001EOol008moo`@000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Eoo`00Tgoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<005Ioo`00UWoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF000005Uoo`00Vgoo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF
3000Fgoo002TOolB001WOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59459 .72635 m .6002 .66895 L .56909 .66574 L p .707 .577 .707 r
F P
0 g
s
.6002 .66895 m .59459 .72635 L .62623 .72936 L p .707 .577 .707 r
F P
0 g
s
.62623 .72936 m .63184 .67196 L .6002 .66895 L p .707 .577 .707 r
F P
0 g
s
.56909 .66574 m .56348 .72315 L .59459 .72635 L p .707 .577 .707 r
F P
0 g
s
.63184 .67196 m .62623 .72936 L .65532 .73188 L p .707 .577 .707 r
F P
0 g
s
.65532 .73188 m .66093 .67448 L .63184 .67196 L p .707 .577 .707 r
F P
0 g
s
.56348 .72315 m .56909 .66574 L .54157 .66265 L p .707 .577 .707 r
F P
0 g
s
.54157 .66265 m .53596 .72006 L .56348 .72315 L p .707 .577 .707 r
F P
0 g
s
.66093 .67448 m .65532 .73188 L .67901 .73367 L p .707 .577 .707 r
F P
0 g
s
.67901 .73367 m .68462 .67626 L .66093 .67448 L p .707 .577 .707 r
F P
0 g
s
.59594 .8088 m .59568 .77193 L .56451 .77011 L p .707 .577 .707 r
F P
0 g
s
.59568 .77193 m .59594 .8088 L .62777 .80778 L p .707 .577 .707 r
F P
0 g
s
.62777 .80778 m .62751 .7709 L .59568 .77193 L p .707 .577 .707 r
F P
0 g
s
.62751 .7709 m .62777 .80778 L .65715 .80401 L p .707 .577 .707 r
F P
0 g
s
.65715 .80401 m .6569 .76713 L .62751 .7709 L p .707 .577 .707 r
F P
0 g
s
.53596 .72006 m .54157 .66265 L .52032 .65999 L p .707 .577 .707 r
F P
0 g
s
.56477 .80699 m .56451 .77011 L .53705 .76563 L p .707 .577 .707 r
F P
0 g
s
.56451 .77011 m .56477 .80699 L .59594 .8088 L p .707 .577 .707 r
F P
0 g
s
.52032 .65999 m .51471 .71739 L .53596 .72006 L p .707 .577 .707 r
F P
0 g
s
.6569 .76713 m .65715 .80401 L .6812 .79786 L p .707 .577 .707 r
F P
0 g
s
.6812 .79786 m .68095 .76099 L .6569 .76713 L p .707 .577 .707 r
F P
0 g
s
.53705 .76563 m .53731 .80251 L .56477 .80699 L p .707 .577 .707 r
F P
0 g
s
.68462 .67626 m .67901 .73367 L .69497 .73454 L p .707 .577 .707 r
F P
0 g
s
.69497 .73454 m .70058 .67713 L .68462 .67626 L p .707 .577 .707 r
F P
0 g
s
.53731 .80251 m .53705 .76563 L .51599 .75893 L p .707 .577 .707 r
F P
0 g
s
.51471 .71739 m .52032 .65999 L .50744 .658 L p .707 .577 .707 r
F P
0 g
s
.50744 .658 m .50183 .71541 L .51471 .71739 L p .707 .577 .707 r
F P
0 g
s
.60087 .86237 m .60014 .84443 L .56897 .84302 L p .707 .577 .707 r
F P
0 g
s
.60014 .84443 m .60087 .86237 L .63267 .86018 L p .707 .577 .707 r
F P
0 g
s
.63267 .86018 m .63194 .84224 L .60014 .84443 L p .707 .577 .707 r
F P
0 g
s
.51599 .75893 m .51625 .79581 L .53731 .80251 L p .707 .577 .707 r
F P
0 g
s
.63194 .84224 m .63267 .86018 L .66201 .85461 L p .707 .577 .707 r
F P
0 g
s
.66201 .85461 m .66128 .83667 L .63194 .84224 L p .707 .577 .707 r
F P
0 g
s
.68095 .76099 m .6812 .79786 L .69757 .78995 L p .707 .577 .707 r
F P
0 g
s
.69757 .78995 m .69731 .75307 L .68095 .76099 L p .707 .577 .707 r
F P
0 g
s
.56897 .84302 m .5697 .86096 L .60087 .86237 L p .707 .577 .707 r
F P
0 g
s
.5697 .86096 m .56897 .84302 L .54151 .83814 L p .707 .577 .707 r
F P
0 g
s
.66128 .83667 m .66201 .85461 L .68601 .84619 L p .707 .577 .707 r
F P
0 g
s
.68601 .84619 m .68528 .82825 L .66128 .83667 L p .707 .577 .707 r
F P
0 g
s
.54151 .83814 m .54224 .85608 L .5697 .86096 L p .707 .577 .707 r
F P
0 g
s
.51625 .79581 m .51599 .75893 L .5034 .75065 L p .707 .577 .707 r
F P
0 g
s
.70058 .67713 m .69497 .73454 L .70164 .73441 L p .707 .577 .707 r
F P
0 g
s
.70164 .73441 m .70725 .677 L .70058 .67713 L p .707 .577 .707 r
F P
0 g
s
.54224 .85608 m .54151 .83814 L .52042 .83027 L p .707 .577 .707 r
F P
0 g
s
.5034 .75065 m .50366 .78753 L .51625 .79581 L p .707 .577 .707 r
F P
0 g
s
.50183 .71541 m .50744 .658 L .50417 .65689 L p .707 .577 .707 r
F P
0 g
s
.50417 .65689 m .49856 .7143 L .50183 .71541 L p .707 .577 .707 r
F P
0 g
s
.69731 .75307 m .69757 .78995 L .70465 .78104 L p .707 .577 .707 r
F P
0 g
s
.70465 .78104 m .7044 .74416 L .69731 .75307 L p .707 .577 .707 r
F P
0 g
s
.52042 .83027 m .52115 .84822 L .54224 .85608 L p .707 .577 .707 r
F P
0 g
s
.68528 .82825 m .68601 .84619 L .70232 .83576 L p .707 .577 .707 r
F P
0 g
s
.70232 .83576 m .70159 .81782 L .68528 .82825 L p .707 .577 .707 r
F P
0 g
s
.50366 .78753 m .5034 .75065 L .5005 .74162 L p .707 .577 .707 r
F P
0 g
s
.52115 .84822 m .52042 .83027 L .50779 .82019 L p .707 .577 .707 r
F P
0 g
s
.70725 .677 m .70164 .73441 L .69837 .7333 L p .707 .577 .707 r
F P
0 g
s
.69837 .7333 m .70399 .67589 L .70725 .677 L p .707 .577 .707 r
F P
0 g
s
.50779 .82019 m .50852 .83813 L .52115 .84822 L p .707 .577 .707 r
F P
0 g
s
.5005 .74162 m .50076 .7785 L .50366 .78753 L p .707 .577 .707 r
F P
0 g
s
.48316 .8187 m .4943 .31017 L .45029 .30709 L p .707 .577 .707 r
F P
0 g
s
.49856 .7143 m .50417 .65689 L .51085 .65677 L p .707 .577 .707 r
F P
0 g
s
.51085 .65677 m .50523 .71417 L .49856 .7143 L p .707 .577 .707 r
F P
0 g
s
.50076 .7785 m .5005 .74162 L .50758 .73271 L p .707 .577 .707 r
F P
0 g
s
.50852 .83813 m .50779 .82019 L .50483 .80888 L p .707 .577 .707 r
F P
0 g
s
.50483 .80888 m .50556 .82682 L .50852 .83813 L p .707 .577 .707 r
F P
0 g
s
.50758 .73271 m .50784 .76959 L .50076 .7785 L p .707 .577 .707 r
F P
0 g
s
.50523 .71417 m .51085 .65677 L .52681 .65764 L p .707 .577 .707 r
F P
0 g
s
.52681 .65764 m .52119 .71504 L .50523 .71417 L p .707 .577 .707 r
F P
0 g
s
.50784 .76959 m .50758 .73271 L .52395 .7248 L p .707 .577 .707 r
F P
0 g
s
.50556 .82682 m .50483 .80888 L .51186 .79745 L p .707 .577 .707 r
F P
0 g
s
.51186 .79745 m .51259 .81539 L .50556 .82682 L p .707 .577 .707 r
F P
0 g
s
.52395 .7248 m .52421 .76167 L .50784 .76959 L p .707 .577 .707 r
F P
0 g
s
.52119 .71504 m .52681 .65764 L .55049 .65942 L p .707 .577 .707 r
F P
0 g
s
.55049 .65942 m .54488 .71683 L .52119 .71504 L p .707 .577 .707 r
F P
0 g
s
.52421 .76167 m .52395 .7248 L .548 .71865 L p .707 .577 .707 r
F P
0 g
s
.51259 .81539 m .51186 .79745 L .52816 .78702 L p .707 .577 .707 r
F P
0 g
s
.52816 .78702 m .52889 .80496 L .51259 .81539 L p .707 .577 .707 r
F P
0 g
s
.548 .71865 m .54826 .75553 L .52421 .76167 L p .707 .577 .707 r
F P
0 g
s
.4943 .31017 m .48316 .8187 L .52809 .81874 L p .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .52816 .78702 L .54837 .77993 L p .707 .577 .707 r
F P
0 g
s
.57958 .66194 m .57397 .71934 L .54488 .71683 L p .707 .577 .707 r
F P
0 g
s
.57397 .71934 m .57718 .68644 L p .58392 .68219 L .707 .577 .707 r
F P
0 g
s
.58001 .71052 m .58392 .68219 L .61123 .66495 L .707 .577 .707 r
F
.57397 .71934 m .58392 .68219 L .58001 .71052 L F
.59453 .66336 m .61123 .66495 L p .57718 .68644 L F P
0 g
s
.64233 .66815 m .63672 .72556 L .60993 .7228 L p .707 .577 .707 r
F P
0 g
s
.60993 .7228 m .60562 .72235 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.61043 .71525 m .64233 .66815 L .60993 .7228 L .707 .577 .707 r
F
.60562 .72235 m .61123 .66495 L .61373 .66521 L p F P
0 g
s
.61373 .66521 m .64233 .66815 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.60562 .72235 m .61373 .66521 L .61043 .71525 L .707 .577 .707 r
F
.66986 .67124 m .66425 .72865 L .63672 .72556 L p F P
0 g
s
.63672 .72556 m .64233 .66815 L .66986 .67124 L p .707 .577 .707 r
F P
0 g
s
.64039 .71567 m .64065 .75255 L .60947 .75073 L p .707 .577 .707 r
F P
0 g
s
.60947 .75073 m .60922 .71386 L .64039 .71567 L p .707 .577 .707 r
F P
0 g
s
.64447 .77225 m .6452 .79019 L .61404 .78878 L p .707 .577 .707 r
F P
0 g
s
.61404 .78878 m .61331 .77084 L .64447 .77225 L p .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .64768 .28427 L .6383 .29303 L p .707 .577 .707 r
F P
0 g
s
.6383 .29303 m .6377 .29359 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .6383 .29303 L .63768 .30239 L .707 .577 .707 r
F
.62657 .80211 m .63654 .7928 L p .63768 .30239 L F P
0 g
s
.6377 .29359 m .63743 .30629 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63743 .30629 m .62657 .80211 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.61123 .66495 m .60562 .72235 L .57397 .71934 L p .707 .577 .707 r
F P
0 g
s
.57764 .75176 m .57738 .71488 L .60922 .71386 L p .707 .577 .707 r
F P
0 g
s
.60922 .71386 m .60947 .75073 L .57764 .75176 L p .707 .577 .707 r
F P
0 g
s
.58223 .79096 m .5815 .77302 L .61331 .77084 L p .707 .577 .707 r
F P
0 g
s
.61331 .77084 m .61404 .78878 L .58223 .79096 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .62657 .80211 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61462 .3015 m .61051 .48916 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61051 .48916 m .60348 .81003 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.54826 .75553 m .54805 .72519 L p .57738 .71488 L .707 .577 .707 r
F P
0 g
s
.54805 .72519 m .548 .71865 L .55349 .71795 L p .707 .577 .707 r
F P
0 g
s
.55349 .71795 m .57738 .71488 L p .54805 .72519 L .707 .577 .707 r
F P
0 g
s
.57718 .68644 m .57958 .66194 L .59453 .66336 L p .707 .577 .707 r
F P
0 g
s
.57738 .71488 m .57764 .75176 L .54826 .75553 L p .707 .577 .707 r
F P
0 g
s
.53941 .81793 m .56955 .81576 L p .56354 .71554 L .707 .577 .707 r
F P
0 g
s
.54837 .77993 m .55216 .7786 L p .54741 .78398 L .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .54837 .77993 L .54741 .78398 L .707 .577 .707 r
F
.55216 .7786 m .55289 .79654 L .52889 .80496 L p F P
0 g
s
.53923 .31021 m .52809 .81874 L .53941 .81793 L p .707 .577 .707 r
F P
0 g
s
.54488 .71683 m .54833 .68146 L p .57958 .66194 L .707 .577 .707 r
F P
0 g
s
.54833 .68146 m .55049 .65942 L .55645 .65993 L p .707 .577 .707 r
F P
0 g
s
.55645 .65993 m .57958 .66194 L p .54833 .68146 L .707 .577 .707 r
F P
0 g
s
.56955 .81576 m .58462 .81321 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.57398 .61346 m .5707 .76349 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.5707 .76349 m .56955 .81576 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.59236 .56472 m .5707 .76349 L .57342 .77321 L .707 .577 .707 r
F
.5815 .77302 m .58223 .79096 L .57858 .79166 L p F P
0 g
s
.56955 .81576 m .58069 .30723 L .53923 .31021 L p .707 .577 .707 r
F P
0 g
s
.57858 .79166 m .55289 .79654 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.57489 .77846 m .5815 .77302 L .57858 .79166 L .707 .577 .707 r
F
.55289 .79654 m .55216 .7786 L .57378 .77449 L p F P
0 g
s
.57378 .77449 m .5815 .77302 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.55289 .79654 m .57378 .77449 L .57489 .77846 L .707 .577 .707 r
F
.60348 .81003 m .59236 .56472 L .57342 .77321 L F
.58462 .81321 m .60348 .81003 L p .57342 .77321 L F P
0 g
s
.58069 .30723 m .57398 .61346 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.56354 .71554 m .53923 .31021 L .53941 .81793 L .707 .577 .707 r
F
.52809 .81874 m .53923 .31021 L .4943 .31017 L p F P
0 g
s
.70159 .81782 m .70232 .83576 L .70934 .82432 L p .707 .577 .707 r
F P
0 g
s
.70934 .82432 m .70861 .80638 L .70159 .81782 L p .707 .577 .707 r
F P
0 g
s
.7044 .74416 m .70465 .78104 L .70175 .772 L p .707 .577 .707 r
F P
0 g
s
.70175 .772 m .7015 .73513 L .7044 .74416 L p .707 .577 .707 r
F P
0 g
s
.43915 .81562 m .45029 .30709 L .41153 .30128 L p .707 .577 .707 r
F P
0 g
s
.45029 .30709 m .43915 .81562 L .48316 .8187 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .61462 .3015 L .58069 .30723 L p .707 .577 .707 r
F P
0 g
s
.70399 .67589 m .69837 .7333 L .68549 .73131 L p .707 .577 .707 r
F P
0 g
s
.68549 .73131 m .6911 .67391 L .70399 .67589 L p .707 .577 .707 r
F P
0 g
s
.25158 .68954 m .25719 .63213 L .22608 .62893 L p .707 .577 .707 r
F P
0 g
s
.25719 .63213 m .25158 .68954 L .28322 .69255 L p .707 .577 .707 r
F P
0 g
s
.28322 .69255 m .28883 .63514 L .25719 .63213 L p .707 .577 .707 r
F P
0 g
s
.22608 .62893 m .22047 .68633 L .25158 .68954 L p .707 .577 .707 r
F P
0 g
s
.28883 .63514 m .28322 .69255 L .31231 .69507 L p .707 .577 .707 r
F P
0 g
s
.31231 .69507 m .31792 .63766 L .28883 .63514 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70861 .80638 m .70934 .82432 L .70639 .81301 L p .707 .577 .707 r
F P
0 g
s
.70639 .81301 m .70566 .79507 L .70861 .80638 L p .707 .577 .707 r
F P
0 g
s
.40039 .80981 m .41153 .30128 L .38179 .29332 L p .707 .577 .707 r
F P
0 g
s
.41153 .30128 m .40039 .80981 L .43915 .81562 L p .707 .577 .707 r
F P
0 g
s
.7015 .73513 m .70175 .772 L .68916 .76373 L p .707 .577 .707 r
F P
0 g
s
.68916 .76373 m .6889 .72685 L .7015 .73513 L p .707 .577 .707 r
F P
0 g
s
.22047 .68633 m .22608 .62893 L .19856 .62584 L p .707 .577 .707 r
F P
0 g
s
.19856 .62584 m .19295 .68325 L .22047 .68633 L p .707 .577 .707 r
F P
0 g
s
.31792 .63766 m .31231 .69507 L .336 .69685 L p .707 .577 .707 r
F P
0 g
s
.336 .69685 m .34161 .63944 L .31792 .63766 L p .707 .577 .707 r
F P
0 g
s
.25293 .77199 m .25267 .73511 L .2215 .7333 L p .707 .577 .707 r
F P
0 g
s
.25267 .73511 m .25293 .77199 L .28476 .77096 L p .707 .577 .707 r
F P
0 g
s
.28476 .77096 m .28451 .73408 L .25267 .73511 L p .707 .577 .707 r
F P
0 g
s
.28451 .73408 m .28476 .77096 L .31414 .76719 L p .707 .577 .707 r
F P
0 g
s
.31414 .76719 m .31389 .73031 L .28451 .73408 L p .707 .577 .707 r
F P
0 g
s
.19295 .68325 m .19856 .62584 L .17731 .62317 L p .707 .577 .707 r
F P
0 g
s
.22176 .77017 m .2215 .7333 L .19404 .72882 L p .707 .577 .707 r
F P
0 g
s
.2215 .7333 m .22176 .77017 L .25293 .77199 L p .707 .577 .707 r
F P
0 g
s
.62657 .80211 m .6377 .29359 L .61462 .3015 L p .707 .577 .707 r
F P
0 g
s
.17731 .62317 m .1717 .68058 L .19295 .68325 L p .707 .577 .707 r
F P
0 g
s
.6911 .67391 m .68549 .73131 L .66425 .72865 L p .707 .577 .707 r
F P
0 g
s
.66425 .72865 m .66986 .67124 L .6911 .67391 L p .707 .577 .707 r
F P
0 g
s
.31389 .73031 m .31414 .76719 L .3382 .76105 L p .707 .577 .707 r
F P
0 g
s
.3382 .76105 m .33794 .72417 L .31389 .73031 L p .707 .577 .707 r
F P
0 g
s
.70566 .79507 m .70639 .81301 L .69375 .80293 L p .707 .577 .707 r
F P
0 g
s
.69375 .80293 m .69302 .78499 L .70566 .79507 L p .707 .577 .707 r
F P
0 g
s
.6889 .72685 m .68916 .76373 L .6681 .75702 L p .707 .577 .707 r
F P
0 g
s
.6681 .75702 m .66785 .72015 L .6889 .72685 L p .707 .577 .707 r
F P
0 g
s
.19404 .72882 m .1943 .7657 L .22176 .77017 L p .707 .577 .707 r
F P
0 g
s
.34161 .63944 m .336 .69685 L .35196 .69772 L p .707 .577 .707 r
F P
0 g
s
.35196 .69772 m .35757 .64031 L .34161 .63944 L p .707 .577 .707 r
F P
0 g
s
.37065 .80184 m .38179 .29332 L .36399 .28397 L p .707 .577 .707 r
F P
0 g
s
.38179 .29332 m .37065 .80184 L .40039 .80981 L p .707 .577 .707 r
F P
0 g
s
.1943 .7657 m .19404 .72882 L .17298 .72211 L p .707 .577 .707 r
F P
0 g
s
.1717 .68058 m .17731 .62317 L .16443 .62119 L p .707 .577 .707 r
F P
0 g
s
.16443 .62119 m .15882 .67859 L .1717 .68058 L p .707 .577 .707 r
F P
0 g
s
.25786 .82556 m .25713 .80762 L .22597 .8062 L p .707 .577 .707 r
F P
0 g
s
.25713 .80762 m .25786 .82556 L .28967 .82337 L p .707 .577 .707 r
F P
0 g
s
.28967 .82337 m .28894 .80543 L .25713 .80762 L p .707 .577 .707 r
F P
0 g
s
.17298 .72211 m .17324 .75899 L .1943 .7657 L p .707 .577 .707 r
F P
0 g
s
.28894 .80543 m .28967 .82337 L .319 .81779 L p .707 .577 .707 r
F P
0 g
s
.319 .81779 m .31827 .79985 L .28894 .80543 L p .707 .577 .707 r
F P
0 g
s
.33794 .72417 m .3382 .76105 L .35456 .75313 L p .707 .577 .707 r
F P
0 g
s
.35456 .75313 m .35431 .71626 L .33794 .72417 L p .707 .577 .707 r
F P
0 g
s
.22597 .8062 m .2267 .82414 L .25786 .82556 L p .707 .577 .707 r
F P
0 g
s
.2267 .82414 m .22597 .8062 L .1985 .80132 L p .707 .577 .707 r
F P
0 g
s
.66785 .72015 m .6681 .75702 L .64065 .75255 L p .707 .577 .707 r
F P
0 g
s
.64065 .75255 m .64039 .71567 L .66785 .72015 L p .707 .577 .707 r
F P
0 g
s
.69302 .78499 m .69375 .80293 L .67267 .79507 L p .707 .577 .707 r
F P
0 g
s
.67267 .79507 m .67194 .77713 L .69302 .78499 L p .707 .577 .707 r
F P
0 g
s
.31827 .79985 m .319 .81779 L .343 .80938 L p .707 .577 .707 r
F P
0 g
s
.343 .80938 m .34227 .79144 L .31827 .79985 L p .707 .577 .707 r
F P
0 g
s
.1985 .80132 m .19923 .81926 L .2267 .82414 L p .707 .577 .707 r
F P
0 g
s
.17324 .75899 m .17298 .72211 L .16039 .71384 L p .707 .577 .707 r
F P
0 g
s
.35757 .64031 m .35196 .69772 L .35863 .69759 L p .707 .577 .707 r
F P
0 g
s
.35863 .69759 m .36424 .64019 L .35757 .64031 L p .707 .577 .707 r
F P
0 g
s
.19923 .81926 m .1985 .80132 L .17741 .79346 L p .707 .577 .707 r
F P
0 g
s
.16039 .71384 m .16065 .75072 L .17324 .75899 L p .707 .577 .707 r
F P
0 g
s
.15882 .67859 m .16443 .62119 L .16116 .62008 L p .707 .577 .707 r
F P
0 g
s
.16116 .62008 m .15555 .67748 L .15882 .67859 L p .707 .577 .707 r
F P
0 g
s
.35431 .71626 m .35456 .75313 L .36164 .74422 L p .707 .577 .707 r
F P
0 g
s
.36164 .74422 m .36139 .70735 L .35431 .71626 L p .707 .577 .707 r
F P
0 g
s
.17741 .79346 m .17814 .8114 L .19923 .81926 L p .707 .577 .707 r
F P
0 g
s
.35931 .79894 m .35858 .781 L .34227 .79144 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .34248 .6945 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36098 .63908 m .35882 .66112 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.35882 .66112 m .35537 .69648 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35988 .27416 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .34809 .63709 L .35833 .63867 L p .707 .577 .707 r
F P
0 g
s
.35833 .63867 m .36098 .63908 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .35833 .63867 L .3585 .64648 L .707 .577 .707 r
F
.35849 .69831 m .35875 .73519 L .34615 .72691 L p F P
0 g
s
.36424 .64019 m .35863 .69759 L .35537 .69648 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .36098 .63908 L .36424 .64019 L p .707 .577 .707 r
F P
0 g
s
.34615 .72691 m .34589 .69004 L .35849 .69831 L p .707 .577 .707 r
F P
0 g
s
.35102 .78814 m .35285 .7925 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35728 .5902 L .35624 .54229 L .707 .577 .707 r
F
.35285 .7925 m .354 .74023 L p .35344 .74923 L F P
0 g
s
.354 .74023 m .35728 .5902 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35001 .74818 L .35334 .75083 L p .707 .577 .707 r
F P
0 g
s
.35858 .781 m .35931 .79894 L .36633 .78751 L p .707 .577 .707 r
F P
0 g
s
.36633 .78751 m .3656 .76957 L .35858 .781 L p .707 .577 .707 r
F P
0 g
s
.36139 .70735 m .36164 .74422 L .35875 .73519 L p .707 .577 .707 r
F P
0 g
s
.35875 .73519 m .35849 .69831 L .36139 .70735 L p .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35589 .65388 L p .37065 .80184 L .707 .577 .707 r
F P
0 g
s
.35589 .65388 m .35285 .7925 L .36579 .79929 L p .707 .577 .707 r
F P
0 g
s
.3656 .76957 m .36633 .78751 L .36451 .78053 L p .707 .577 .707 r
F P
0 g
s
.36407 .77413 m .3656 .76957 L .36451 .78053 L .707 .577 .707 r
F
.36338 .7762 m .36265 .75826 L .3656 .76957 L p F P
0 g
s
.36579 .79929 m .37065 .80184 L p .35589 .65388 L .707 .577 .707 r
F P
0 g
s
.36451 .78053 m .36338 .7762 L p .36407 .77413 L .707 .577 .707 r
F P
0 g
s
.35334 .75083 m .36265 .75826 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35334 .75083 L .35246 .76499 L .707 .577 .707 r
F
.36265 .75826 m .36338 .7762 L .35231 .76737 L p F P
0 g
s
.35231 .76737 m .35074 .76612 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35246 .76499 m .36265 .75826 L .35231 .76737 L .707 .577 .707 r
F
.35001 .74818 m .35074 .76612 L .32966 .75826 L p F P
0 g
s
.32966 .75826 m .32893 .74031 L .35001 .74818 L p .707 .577 .707 r
F P
0 g
s
.34874 .78268 m .35102 .78814 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35624 .54229 L .35102 .78814 L .707 .577 .707 r
F
.35988 .27416 m .35513 .49095 L p .35624 .54229 L F P
0 g
s
.35513 .49095 m .34874 .78268 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35728 .5902 m .36399 .28397 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34227 .79144 m .343 .80938 L .35931 .79894 L p .707 .577 .707 r
F P
0 g
s
.67194 .77713 m .67267 .79507 L .6452 .79019 L p .707 .577 .707 r
F P
0 g
s
.6452 .79019 m .64447 .77225 L .67194 .77713 L p .707 .577 .707 r
F P
0 g
s
.16065 .75072 m .16039 .71384 L .15749 .7048 L p .707 .577 .707 r
F P
0 g
s
.17814 .8114 m .17741 .79346 L .16478 .78338 L p .707 .577 .707 r
F P
0 g
s
.16478 .78338 m .16551 .80132 L .17814 .8114 L p .707 .577 .707 r
F P
0 g
s
.15749 .7048 m .15775 .74168 L .16065 .75072 L p .707 .577 .707 r
F P
0 g
s
.64768 .28427 m .63654 .7928 L .63242 .78298 L p .707 .577 .707 r
F P
0 g
s
.63242 .78298 m .64356 .27445 L .64768 .28427 L p .707 .577 .707 r
F P
0 g
s
.15555 .67748 m .16116 .62008 L .16784 .61995 L p .707 .577 .707 r
F P
0 g
s
.16784 .61995 m .16223 .67736 L .15555 .67748 L p .707 .577 .707 r
F P
0 g
s
.15775 .74168 m .15749 .7048 L .16457 .69589 L p .707 .577 .707 r
F P
0 g
s
.16551 .80132 m .16478 .78338 L .16183 .77207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34874 .78268 m .35988 .27416 L .36985 .26484 L p .707 .577 .707 r
F P
0 g
s
.16183 .77207 m .16256 .79001 L .16551 .80132 L p .707 .577 .707 r
F P
0 g
s
.16457 .69589 m .16483 .73277 L .15775 .74168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16223 .67736 m .16784 .61995 L .1838 .62082 L p .707 .577 .707 r
F P
0 g
s
.1838 .62082 m .17818 .67823 L .16223 .67736 L p .707 .577 .707 r
F P
0 g
s
.64356 .27445 m .63242 .78298 L .61463 .77364 L p .707 .577 .707 r
F P
0 g
s
.61463 .77364 m .62577 .26511 L .64356 .27445 L p .707 .577 .707 r
F P
0 g
s
.16483 .73277 m .16457 .69589 L .18094 .68798 L p .707 .577 .707 r
F P
0 g
s
.16256 .79001 m .16183 .77207 L .16885 .76064 L p .707 .577 .707 r
F P
0 g
s
.34809 .63709 m .34248 .6945 L .32124 .69183 L p .707 .577 .707 r
F P
0 g
s
.32124 .69183 m .32685 .63442 L .34809 .63709 L p .707 .577 .707 r
F P
0 g
s
.16885 .76064 m .16958 .77858 L .16256 .79001 L p .707 .577 .707 r
F P
0 g
s
.18094 .68798 m .1812 .72486 L .16483 .73277 L p .707 .577 .707 r
F P
0 g
s
.35871 .77337 m .36985 .26484 L .39293 .25693 L p .707 .577 .707 r
F P
0 g
s
.36985 .26484 m .35871 .77337 L .34874 .78268 L p .707 .577 .707 r
F P
0 g
s
.17818 .67823 m .1838 .62082 L .20748 .6226 L p .707 .577 .707 r
F P
0 g
s
.34589 .69004 m .34615 .72691 L .32509 .72021 L p .707 .577 .707 r
F P
0 g
s
.32509 .72021 m .32484 .68333 L .34589 .69004 L p .707 .577 .707 r
F P
0 g
s
.20748 .6226 m .20187 .68001 L .17818 .67823 L p .707 .577 .707 r
F P
0 g
s
.1812 .72486 m .18094 .68798 L .20499 .68184 L p .707 .577 .707 r
F P
0 g
s
.16958 .77858 m .16885 .76064 L .18515 .7502 L p .707 .577 .707 r
F P
0 g
s
.32685 .63442 m .32124 .69183 L .29371 .68874 L p .707 .577 .707 r
F P
0 g
s
.29371 .68874 m .29932 .63134 L .32685 .63442 L p .707 .577 .707 r
F P
0 g
s
.18515 .7502 m .18588 .76814 L .16958 .77858 L p .707 .577 .707 r
F P
0 g
s
.20187 .68001 m .20748 .6226 L .23657 .62512 L p .707 .577 .707 r
F P
0 g
s
.20499 .68184 m .20525 .71871 L .1812 .72486 L p .707 .577 .707 r
F P
0 g
s
.23657 .62512 m .23096 .68253 L .20187 .68001 L p .707 .577 .707 r
F P
0 g
s
.62577 .26511 m .61463 .77364 L .58489 .76567 L p .707 .577 .707 r
F P
0 g
s
.58489 .76567 m .59603 .25714 L .62577 .26511 L p .707 .577 .707 r
F P
0 g
s
.32484 .68333 m .32509 .72021 L .29764 .71573 L p .707 .577 .707 r
F P
0 g
s
.29764 .71573 m .29738 .67885 L .32484 .68333 L p .707 .577 .707 r
F P
0 g
s
.29932 .63134 m .29371 .68874 L .26261 .68554 L p .707 .577 .707 r
F P
0 g
s
.26261 .68554 m .26822 .62813 L .29932 .63134 L p .707 .577 .707 r
F P
0 g
s
.73179 .63171 m .7374 .5743 L .70629 .57109 L p .707 .577 .707 r
F P
0 g
s
.7374 .5743 m .73179 .63171 L .76344 .63472 L p .707 .577 .707 r
F P
0 g
s
.76344 .63472 m .76905 .57731 L .7374 .5743 L p .707 .577 .707 r
F P
0 g
s
.23096 .68253 m .23417 .64962 L p .26822 .62813 L .707 .577 .707 r
F P
0 g
s
.23417 .64962 m .23657 .62512 L .25152 .62654 L p .707 .577 .707 r
F P
0 g
s
.25152 .62654 m .26822 .62813 L p .23417 .64962 L .707 .577 .707 r
F P
0 g
s
.26822 .62813 m .26261 .68554 L .23096 .68253 L p .707 .577 .707 r
F P
0 g
s
.20525 .71871 m .20504 .68838 L p .23437 .67807 L .707 .577 .707 r
F P
0 g
s
.20504 .68838 m .20499 .68184 L .21048 .68113 L p .707 .577 .707 r
F P
0 g
s
.21048 .68113 m .23437 .67807 L p .20504 .68838 L .707 .577 .707 r
F P
0 g
s
.70629 .57109 m .70068 .6285 L .73179 .63171 L p .707 .577 .707 r
F P
0 g
s
.76905 .57731 m .76344 .63472 L .79253 .63724 L p .707 .577 .707 r
F P
0 g
s
.79253 .63724 m .79814 .57983 L .76905 .57731 L p .707 .577 .707 r
F P
0 g
s
.39293 .25693 m .38179 .76545 L .35871 .77337 L p .707 .577 .707 r
F P
0 g
s
.38179 .76545 m .39293 .25693 L .42686 .2512 L p .707 .577 .707 r
F P
0 g
s
.70068 .6285 m .70629 .57109 L .67877 .56801 L p .707 .577 .707 r
F P
0 g
s
.29738 .67885 m .29764 .71573 L .26646 .71392 L p .707 .577 .707 r
F P
0 g
s
.26646 .71392 m .26621 .67704 L .29738 .67885 L p .707 .577 .707 r
F P
0 g
s
.67877 .56801 m .67316 .62541 L .70068 .6285 L p .707 .577 .707 r
F P
0 g
s
.18588 .76814 m .18515 .7502 L .20915 .74178 L p .707 .577 .707 r
F P
0 g
s
.23437 .67807 m .23463 .71494 L .20525 .71871 L p .707 .577 .707 r
F P
0 g
s
.23463 .71494 m .23437 .67807 L .26621 .67704 L p .707 .577 .707 r
F P
0 g
s
.26621 .67704 m .26646 .71392 L .23463 .71494 L p .707 .577 .707 r
F P
0 g
s
.20915 .74178 m .20988 .75972 L .18588 .76814 L p .707 .577 .707 r
F P
0 g
s
.79814 .57983 m .79253 .63724 L .81621 .63902 L p .707 .577 .707 r
F P
0 g
s
.81621 .63902 m .82182 .58161 L .79814 .57983 L p .707 .577 .707 r
F P
0 g
s
.32893 .74031 m .32966 .75826 L .30219 .75338 L p .707 .577 .707 r
F P
0 g
s
.30219 .75338 m .30146 .73544 L .32893 .74031 L p .707 .577 .707 r
F P
0 g
s
.73314 .72249 m .73288 .68562 L .70171 .6838 L p .707 .577 .707 r
F P
0 g
s
.73288 .68562 m .73314 .72249 L .76498 .72146 L p .707 .577 .707 r
F P
0 g
s
.76498 .72146 m .76472 .68459 L .73288 .68562 L p .707 .577 .707 r
F P
0 g
s
.76472 .68459 m .76498 .72146 L .79436 .71769 L p .707 .577 .707 r
F P
0 g
s
.79436 .71769 m .7941 .68082 L .76472 .68459 L p .707 .577 .707 r
F P
0 g
s
.67316 .62541 m .67877 .56801 L .65753 .56534 L p .707 .577 .707 r
F P
0 g
s
.65753 .56534 m .65192 .62275 L .67316 .62541 L p .707 .577 .707 r
F P
0 g
s
.59603 .25714 m .58489 .76567 L .54612 .75986 L p .707 .577 .707 r
F P
0 g
s
.54612 .75986 m .55726 .25133 L .59603 .25714 L p .707 .577 .707 r
F P
0 g
s
.70197 .72068 m .70171 .6838 L .67425 .67932 L p .707 .577 .707 r
F P
0 g
s
.70171 .6838 m .70197 .72068 L .73314 .72249 L p .707 .577 .707 r
F P
0 g
s
.20988 .75972 m .20915 .74178 L .23849 .73621 L p .707 .577 .707 r
F P
0 g
s
.7941 .68082 m .79436 .71769 L .81841 .71155 L p .707 .577 .707 r
F P
0 g
s
.81841 .71155 m .81815 .67467 L .7941 .68082 L p .707 .577 .707 r
F P
0 g
s
.30146 .73544 m .30219 .75338 L .27103 .75196 L p .707 .577 .707 r
F P
0 g
s
.27103 .75196 m .2703 .73402 L .30146 .73544 L p .707 .577 .707 r
F P
0 g
s
.23849 .73621 m .23922 .75415 L .20988 .75972 L p .707 .577 .707 r
F P
0 g
s
.41572 .75972 m .42686 .2512 L .46832 .24821 L p .707 .577 .707 r
F P
0 g
s
.42686 .2512 m .41572 .75972 L .38179 .76545 L p .707 .577 .707 r
F P
0 g
s
.67425 .67932 m .67451 .7162 L .70197 .72068 L p .707 .577 .707 r
F P
0 g
s
.82182 .58161 m .81621 .63902 L .83217 .63989 L p .707 .577 .707 r
F P
0 g
s
.83217 .63989 m .83778 .58248 L .82182 .58161 L p .707 .577 .707 r
F P
0 g
s
.23922 .75415 m .23849 .73621 L .2703 .73402 L p .707 .577 .707 r
F P
0 g
s
.2703 .73402 m .27103 .75196 L .23922 .75415 L p .707 .577 .707 r
F P
0 g
s
.67451 .7162 m .67425 .67932 L .6532 .67262 L p .707 .577 .707 r
F P
0 g
s
.65192 .62275 m .65753 .56534 L .64464 .56335 L p .707 .577 .707 r
F P
0 g
s
.73807 .76166 m .73734 .74372 L .70618 .7423 L p .707 .577 .707 r
F P
0 g
s
.73734 .74372 m .73807 .76166 L .76988 .75947 L p .707 .577 .707 r
F P
0 g
s
.76988 .75947 m .76915 .74153 L .73734 .74372 L p .707 .577 .707 r
F P
0 g
s
.55726 .25133 m .54612 .75986 L .50212 .75678 L p .707 .577 .707 r
F P
0 g
s
.50212 .75678 m .51325 .24826 L .55726 .25133 L p .707 .577 .707 r
F P
0 g
s
.64464 .56335 m .63903 .62076 L .65192 .62275 L p .707 .577 .707 r
F P
0 g
s
.76915 .74153 m .76988 .75947 L .79922 .75389 L p .707 .577 .707 r
F P
0 g
s
.79922 .75389 m .79849 .73595 L .76915 .74153 L p .707 .577 .707 r
F P
0 g
s
.45718 .75674 m .46832 .24821 L .51325 .24826 L p .707 .577 .707 r
F P
0 g
s
.46832 .24821 m .45718 .75674 L .41572 .75972 L p .707 .577 .707 r
F P
0 g
s
.6532 .67262 m .65345 .70949 L .67451 .7162 L p .707 .577 .707 r
F P
0 g
s
.70618 .7423 m .70691 .76024 L .73807 .76166 L p .707 .577 .707 r
F P
0 g
s
.70691 .76024 m .70618 .7423 L .67871 .73742 L p .707 .577 .707 r
F P
0 g
s
.81815 .67467 m .81841 .71155 L .83478 .70364 L p .707 .577 .707 r
F P
0 g
s
.83478 .70364 m .83452 .66676 L .81815 .67467 L p .707 .577 .707 r
F P
0 g
s
.51325 .24826 m .50212 .75678 L .45718 .75674 L p .707 .577 .707 r
F P
0 g
s
.79849 .73595 m .79922 .75389 L .82321 .74548 L p .707 .577 .707 r
F P
0 g
s
.82321 .74548 m .82248 .72754 L .79849 .73595 L p .707 .577 .707 r
F P
0 g
s
.67871 .73742 m .67944 .75536 L .70691 .76024 L p .707 .577 .707 r
F P
0 g
s
.65345 .70949 m .6532 .67262 L .6406 .66434 L p .707 .577 .707 r
F P
0 g
s
.83778 .58248 m .83217 .63989 L .83884 .63976 L p .707 .577 .707 r
F P
0 g
s
.83884 .63976 m .84446 .58236 L .83778 .58248 L p .707 .577 .707 r
F P
0 g
s
.67944 .75536 m .67871 .73742 L .65763 .72956 L p .707 .577 .707 r
F P
0 g
s
.63903 .62076 m .64464 .56335 L .64138 .56224 L p .707 .577 .707 r
F P
0 g
s
.6406 .66434 m .64086 .70122 L .65345 .70949 L p .707 .577 .707 r
F P
0 g
s
.65763 .72956 m .65836 .7475 L .67944 .75536 L p .707 .577 .707 r
F P
0 g
s
.64138 .56224 m .63576 .61965 L .63903 .62076 L p .707 .577 .707 r
F P
0 g
s
.82248 .72754 m .82321 .74548 L .83952 .73504 L p .707 .577 .707 r
F P
0 g
s
.83952 .73504 m .83879 .7171 L .82248 .72754 L p .707 .577 .707 r
F P
0 g
s
.83452 .66676 m .83478 .70364 L .84186 .69473 L p .707 .577 .707 r
F P
0 g
s
.84186 .69473 m .8416 .65785 L .83452 .66676 L p .707 .577 .707 r
F P
0 g
s
.65836 .7475 m .65763 .72956 L .64499 .71948 L p .707 .577 .707 r
F P
0 g
s
.64086 .70122 m .6406 .66434 L .63771 .65531 L p .707 .577 .707 r
F P
0 g
s
.84446 .58236 m .83884 .63976 L .83558 .63865 L p .707 .577 .707 r
F P
0 g
s
.83558 .63865 m .84119 .58125 L .84446 .58236 L p .707 .577 .707 r
F P
0 g
s
.64499 .71948 m .64572 .73742 L .65836 .7475 L p .707 .577 .707 r
F P
0 g
s
.63771 .65531 m .63796 .69218 L .64086 .70122 L p .707 .577 .707 r
F P
0 g
s
.83879 .7171 m .83952 .73504 L .84654 .72361 L p .707 .577 .707 r
F P
0 g
s
.84654 .72361 m .84581 .70567 L .83879 .7171 L p .707 .577 .707 r
F P
0 g
s
.63576 .61965 m .64138 .56224 L .64805 .56212 L p .707 .577 .707 r
F P
0 g
s
.64805 .56212 m .64244 .61952 L .63576 .61965 L p .707 .577 .707 r
F P
0 g
s
.8416 .65785 m .84186 .69473 L .83896 .68569 L p .707 .577 .707 r
F P
0 g
s
.83896 .68569 m .8387 .64882 L .8416 .65785 L p .707 .577 .707 r
F P
0 g
s
.64572 .73742 m .64499 .71948 L .64204 .70817 L p .707 .577 .707 r
F P
0 g
s
.63796 .69218 m .63771 .65531 L .64479 .6464 L p .707 .577 .707 r
F P
0 g
s
.64204 .70817 m .64277 .72611 L .64572 .73742 L p .707 .577 .707 r
F P
0 g
s
.84119 .58125 m .83558 .63865 L .82269 .63667 L p .707 .577 .707 r
F P
0 g
s
.82269 .63667 m .8283 .57926 L .84119 .58125 L p .707 .577 .707 r
F P
0 g
s
.38878 .59489 m .39439 .53748 L .36328 .53428 L p .707 .577 .707 r
F P
0 g
s
.39439 .53748 m .38878 .59489 L .42043 .5979 L p .707 .577 .707 r
F P
0 g
s
.42043 .5979 m .42604 .54049 L .39439 .53748 L p .707 .577 .707 r
F P
0 g
s
.36328 .53428 m .35767 .59169 L .38878 .59489 L p .707 .577 .707 r
F P
0 g
s
.84581 .70567 m .84654 .72361 L .84359 .7123 L p .707 .577 .707 r
F P
0 g
s
.84359 .7123 m .84286 .69436 L .84581 .70567 L p .707 .577 .707 r
F P
0 g
s
.64479 .6464 m .64504 .68327 L .63796 .69218 L p .707 .577 .707 r
F P
0 g
s
.42604 .54049 m .42043 .5979 L .44952 .60042 L p .707 .577 .707 r
F P
0 g
s
.44952 .60042 m .45513 .54301 L .42604 .54049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64244 .61952 m .64805 .56212 L .66401 .56299 L p .707 .577 .707 r
F P
0 g
s
.35767 .59169 m .36328 .53428 L .33576 .53119 L p .707 .577 .707 r
F P
0 g
s
.66401 .56299 m .6584 .6204 L .64244 .61952 L p .707 .577 .707 r
F P
0 g
s
.33576 .53119 m .33015 .5886 L .35767 .59169 L p .707 .577 .707 r
F P
0 g
s
.8387 .64882 m .83896 .68569 L .82637 .67742 L p .707 .577 .707 r
F P
0 g
s
.82637 .67742 m .82611 .64054 L .8387 .64882 L p .707 .577 .707 r
F P
0 g
s
.45513 .54301 m .44952 .60042 L .4732 .6022 L p .707 .577 .707 r
F P
0 g
s
.4732 .6022 m .47881 .5448 L .45513 .54301 L p .707 .577 .707 r
F P
0 g
s
.64277 .72611 m .64204 .70817 L .64906 .69674 L p .707 .577 .707 r
F P
0 g
s
.39013 .68568 m .38987 .6488 L .3587 .64699 L p .707 .577 .707 r
F P
0 g
s
.38987 .6488 m .39013 .68568 L .42197 .68465 L p .707 .577 .707 r
F P
0 g
s
.42197 .68465 m .42171 .64777 L .38987 .6488 L p .707 .577 .707 r
F P
0 g
s
.64504 .68327 m .64479 .6464 L .66115 .63848 L p .707 .577 .707 r
F P
0 g
s
.42171 .64777 m .42197 .68465 L .45135 .68088 L p .707 .577 .707 r
F P
0 g
s
.45135 .68088 m .45109 .644 L .42171 .64777 L p .707 .577 .707 r
F P
0 g
s
.33015 .5886 m .33576 .53119 L .31452 .52852 L p .707 .577 .707 r
F P
0 g
s
.31452 .52852 m .30891 .58593 L .33015 .5886 L p .707 .577 .707 r
F P
0 g
s
.64906 .69674 m .64979 .71468 L .64277 .72611 L p .707 .577 .707 r
F P
0 g
s
.8283 .57926 m .82269 .63667 L .80145 .634 L p .707 .577 .707 r
F P
0 g
s
.80145 .634 m .80706 .57659 L .8283 .57926 L p .707 .577 .707 r
F P
0 g
s
.35896 .68386 m .3587 .64699 L .33124 .64251 L p .707 .577 .707 r
F P
0 g
s
.3587 .64699 m .35896 .68386 L .39013 .68568 L p .707 .577 .707 r
F P
0 g
s
.84286 .69436 m .84359 .7123 L .83096 .70222 L p .707 .577 .707 r
F P
0 g
s
.83096 .70222 m .83023 .68428 L .84286 .69436 L p .707 .577 .707 r
F P
0 g
s
.66115 .63848 m .66141 .67536 L .64504 .68327 L p .707 .577 .707 r
F P
0 g
s
.45109 .644 m .45135 .68088 L .4754 .67474 L p .707 .577 .707 r
F P
0 g
s
.4754 .67474 m .47514 .63786 L .45109 .644 L p .707 .577 .707 r
F P
0 g
s
.6584 .6204 m .66401 .56299 L .68769 .56477 L p .707 .577 .707 r
F P
0 g
s
.68769 .56477 m .68208 .62218 L .6584 .6204 L p .707 .577 .707 r
F P
0 g
s
.82611 .64054 m .82637 .67742 L .80531 .67071 L p .707 .577 .707 r
F P
0 g
s
.80531 .67071 m .80505 .63384 L .82611 .64054 L p .707 .577 .707 r
F P
0 g
s
.33124 .64251 m .3315 .67938 L .35896 .68386 L p .707 .577 .707 r
F P
0 g
s
.47881 .5448 m .4732 .6022 L .48916 .60307 L p .707 .577 .707 r
F P
0 g
s
.48916 .60307 m .49477 .54567 L .47881 .5448 L p .707 .577 .707 r
F P
0 g
s
.3315 .67938 m .33124 .64251 L .31019 .6358 L p .707 .577 .707 r
F P
0 g
s
.30891 .58593 m .31452 .52852 L .30163 .52654 L p .707 .577 .707 r
F P
0 g
s
.64979 .71468 m .64906 .69674 L .66537 .6863 L p .707 .577 .707 r
F P
0 g
s
.39506 .72484 m .39433 .7069 L .36317 .70549 L p .707 .577 .707 r
F P
0 g
s
.39433 .7069 m .39506 .72484 L .42687 .72265 L p .707 .577 .707 r
F P
0 g
s
.42687 .72265 m .42614 .70471 L .39433 .7069 L p .707 .577 .707 r
F P
0 g
s
.66141 .67536 m .66115 .63848 L .68521 .63234 L p .707 .577 .707 r
F P
0 g
s
.30163 .52654 m .29602 .58395 L .30891 .58593 L p .707 .577 .707 r
F P
0 g
s
.80706 .57659 m .80145 .634 L .77393 .63091 L p .707 .577 .707 r
F P
0 g
s
.77393 .63091 m .77954 .57351 L .80706 .57659 L p .707 .577 .707 r
F P
0 g
s
.42614 .70471 m .42687 .72265 L .45621 .71708 L p .707 .577 .707 r
F P
0 g
s
.45621 .71708 m .45548 .69914 L .42614 .70471 L p .707 .577 .707 r
F P
0 g
s
.31019 .6358 m .31044 .67268 L .3315 .67938 L p .707 .577 .707 r
F P
0 g
s
.66537 .6863 m .6661 .70424 L .64979 .71468 L p .707 .577 .707 r
F P
0 g
s
.36317 .70549 m .3639 .72343 L .39506 .72484 L p .707 .577 .707 r
F P
0 g
s
.3639 .72343 m .36317 .70549 L .3357 .70061 L p .707 .577 .707 r
F P
0 g
s
.47514 .63786 m .4754 .67474 L .49177 .66682 L p .707 .577 .707 r
F P
0 g
s
.49177 .66682 m .49151 .62995 L .47514 .63786 L p .707 .577 .707 r
F P
0 g
s
.68208 .62218 m .68769 .56477 L .71678 .56729 L p .707 .577 .707 r
F P
0 g
s
.71678 .56729 m .71117 .6247 L .68208 .62218 L p .707 .577 .707 r
F P
0 g
s
.68521 .63234 m .68546 .66922 L .66141 .67536 L p .707 .577 .707 r
F P
0 g
s
.83023 .68428 m .83096 .70222 L .80987 .69435 L p .707 .577 .707 r
F P
0 g
s
.80987 .69435 m .80914 .67641 L .83023 .68428 L p .707 .577 .707 r
F P
0 g
s
.80505 .63384 m .80531 .67071 L .77785 .66623 L p .707 .577 .707 r
F P
0 g
s
.77785 .66623 m .77759 .62936 L .80505 .63384 L p .707 .577 .707 r
F P
0 g
s
.45548 .69914 m .45621 .71708 L .4802 .70866 L p .707 .577 .707 r
F P
0 g
s
.4802 .70866 m .47947 .69072 L .45548 .69914 L p .707 .577 .707 r
F P
0 g
s
.3357 .70061 m .33643 .71855 L .3639 .72343 L p .707 .577 .707 r
F P
0 g
s
.31044 .67268 m .31019 .6358 L .29759 .62753 L p .707 .577 .707 r
F P
0 g
s
.77954 .57351 m .77393 .63091 L .74282 .62771 L p .707 .577 .707 r
F P
0 g
s
.74282 .62771 m .74843 .5703 L .77954 .57351 L p .707 .577 .707 r
F P
0 g
s
.49477 .54567 m .48916 .60307 L .49583 .60295 L p .707 .577 .707 r
F P
0 g
s
.49583 .60295 m .50145 .54554 L .49477 .54567 L p .707 .577 .707 r
F P
0 g
s
.68546 .66922 m .68521 .63234 L .71459 .62857 L p .707 .577 .707 r
F P
0 g
s
.71117 .6247 m .71678 .56729 L .74843 .5703 L p .707 .577 .707 r
F P
0 g
s
.33643 .71855 m .3357 .70061 L .31462 .69274 L p .707 .577 .707 r
F P
0 g
s
.74843 .5703 m .74282 .62771 L .71117 .6247 L p .707 .577 .707 r
F P
0 g
s
.6661 .70424 m .66537 .6863 L .68937 .67788 L p .707 .577 .707 r
F P
0 g
s
.29602 .58395 m .30163 .52654 L .29837 .52543 L p .707 .577 .707 r
F P
0 g
s
.77759 .62936 m .77785 .66623 L .74668 .66442 L p .707 .577 .707 r
F P
0 g
s
.74668 .66442 m .74642 .62754 L .77759 .62936 L p .707 .577 .707 r
F P
0 g
s
.29759 .62753 m .29785 .6644 L .31044 .67268 L p .707 .577 .707 r
F P
0 g
s
.31462 .69274 m .31535 .71068 L .33643 .71855 L p .707 .577 .707 r
F P
0 g
s
.29837 .52543 m .29275 .58284 L .29602 .58395 L p .707 .577 .707 r
F P
0 g
s
.71459 .62857 m .71484 .66545 L .68546 .66922 L p .707 .577 .707 r
F P
0 g
s
.68937 .67788 m .6901 .69582 L .6661 .70424 L p .707 .577 .707 r
F P
0 g
s
.71484 .66545 m .71459 .62857 L .74642 .62754 L p .707 .577 .707 r
F P
0 g
s
.47947 .69072 m .4802 .70866 L .49651 .69823 L p .707 .577 .707 r
F P
0 g
s
.49651 .69823 m .49578 .68029 L .47947 .69072 L p .707 .577 .707 r
F P
0 g
s
.49151 .62995 m .49177 .66682 L .49885 .65791 L p .707 .577 .707 r
F P
0 g
s
.49885 .65791 m .49859 .62104 L .49151 .62995 L p .707 .577 .707 r
F P
0 g
s
.80914 .67641 m .80987 .69435 L .7824 .68948 L p .707 .577 .707 r
F P
0 g
s
.7824 .68948 m .78167 .67154 L .80914 .67641 L p .707 .577 .707 r
F P
0 g
s
.74642 .62754 m .74668 .66442 L .71484 .66545 L p .707 .577 .707 r
F P
0 g
s
.6901 .69582 m .68937 .67788 L .7187 .67231 L p .707 .577 .707 r
F P
0 g
s
.31535 .71068 m .31462 .69274 L .30198 .68266 L p .707 .577 .707 r
F P
0 g
s
.29785 .6644 m .29759 .62753 L .2947 .61849 L p .707 .577 .707 r
F P
0 g
s
.50145 .54554 m .49583 .60295 L .49257 .60184 L p .707 .577 .707 r
F P
0 g
s
.49257 .60184 m .49818 .54443 L .50145 .54554 L p .707 .577 .707 r
F P
0 g
s
.78167 .67154 m .7824 .68948 L .75124 .68806 L p .707 .577 .707 r
F P
0 g
s
.75124 .68806 m .75051 .67012 L .78167 .67154 L p .707 .577 .707 r
F P
0 g
s
.7187 .67231 m .71943 .69025 L .6901 .69582 L p .707 .577 .707 r
F P
0 g
s
.30198 .68266 m .30271 .7006 L .31535 .71068 L p .707 .577 .707 r
F P
0 g
s
.71943 .69025 m .7187 .67231 L .75051 .67012 L p .707 .577 .707 r
F P
0 g
s
.2947 .61849 m .29495 .65537 L .29785 .6644 L p .707 .577 .707 r
F P
0 g
s
.75051 .67012 m .75124 .68806 L .71943 .69025 L p .707 .577 .707 r
F P
0 g
s
.49578 .68029 m .49651 .69823 L .50353 .68679 L p .707 .577 .707 r
F P
0 g
s
.50353 .68679 m .5028 .66885 L .49578 .68029 L p .707 .577 .707 r
F P
0 g
s
.29275 .58284 m .29837 .52543 L .30504 .5253 L p .707 .577 .707 r
F P
0 g
s
.30504 .5253 m .29943 .58271 L .29275 .58284 L p .707 .577 .707 r
F P
0 g
s
.49859 .62104 m .49885 .65791 L .49595 .64888 L p .707 .577 .707 r
F P
0 g
s
.49595 .64888 m .49569 .612 L .49859 .62104 L p .707 .577 .707 r
F P
0 g
s
.30271 .7006 m .30198 .68266 L .29903 .67135 L p .707 .577 .707 r
F P
0 g
s
.29495 .65537 m .2947 .61849 L .30178 .60958 L p .707 .577 .707 r
F P
0 g
s
.29903 .67135 m .29976 .68929 L .30271 .7006 L p .707 .577 .707 r
F P
0 g
s
.49818 .54443 m .49257 .60184 L .47968 .59985 L p .707 .577 .707 r
F P
0 g
s
.47968 .59985 m .48529 .54244 L .49818 .54443 L p .707 .577 .707 r
F P
0 g
s
.5028 .66885 m .50353 .68679 L .50058 .67548 L p .707 .577 .707 r
F P
0 g
s
.50058 .67548 m .49985 .65754 L .5028 .66885 L p .707 .577 .707 r
F P
0 g
s
.30178 .60958 m .30203 .64646 L .29495 .65537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29943 .58271 m .30504 .5253 L .321 .52617 L p .707 .577 .707 r
F P
0 g
s
.321 .52617 m .31539 .58358 L .29943 .58271 L p .707 .577 .707 r
F P
0 g
s
.49569 .612 m .49595 .64888 L .48336 .6406 L p .707 .577 .707 r
F P
0 g
s
.48336 .6406 m .4831 .60373 L .49569 .612 L p .707 .577 .707 r
F P
0 g
s
.29976 .68929 m .29903 .67135 L .30605 .65992 L p .707 .577 .707 r
F P
0 g
s
.30203 .64646 m .30178 .60958 L .31814 .60167 L p .707 .577 .707 r
F P
0 g
s
.30605 .65992 m .30678 .67786 L .29976 .68929 L p .707 .577 .707 r
F P
0 g
s
.48529 .54244 m .47968 .59985 L .45844 .59718 L p .707 .577 .707 r
F P
0 g
s
.45844 .59718 m .46405 .53978 L .48529 .54244 L p .707 .577 .707 r
F P
0 g
s
.49985 .65754 m .50058 .67548 L .48795 .6654 L p .707 .577 .707 r
F P
0 g
s
.48795 .6654 m .48722 .64746 L .49985 .65754 L p .707 .577 .707 r
F P
0 g
s
.31814 .60167 m .3184 .63854 L .30203 .64646 L p .707 .577 .707 r
F P
0 g
s
.31539 .58358 m .321 .52617 L .34468 .52796 L p .707 .577 .707 r
F P
0 g
s
.34468 .52796 m .33907 .58536 L .31539 .58358 L p .707 .577 .707 r
F P
0 g
s
.4831 .60373 m .48336 .6406 L .4623 .6339 L p .707 .577 .707 r
F P
0 g
s
.4623 .6339 m .46204 .59702 L .4831 .60373 L p .707 .577 .707 r
F P
0 g
s
.30678 .67786 m .30605 .65992 L .32236 .64949 L p .707 .577 .707 r
F P
0 g
s
.3184 .63854 m .31814 .60167 L .3422 .59553 L p .707 .577 .707 r
F P
0 g
s
.46405 .53978 m .45844 .59718 L .43092 .5941 L p .707 .577 .707 r
F P
0 g
s
.43092 .5941 m .43653 .53669 L .46405 .53978 L p .707 .577 .707 r
F P
0 g
s
.32236 .64949 m .32309 .66743 L .30678 .67786 L p .707 .577 .707 r
F P
0 g
s
.33907 .58536 m .34468 .52796 L .37377 .53047 L p .707 .577 .707 r
F P
0 g
s
.37377 .53047 m .36816 .58788 L .33907 .58536 L p .707 .577 .707 r
F P
0 g
s
.3422 .59553 m .34245 .6324 L .3184 .63854 L p .707 .577 .707 r
F P
0 g
s
.48722 .64746 m .48795 .6654 L .46686 .65754 L p .707 .577 .707 r
F P
0 g
s
.46686 .65754 m .46613 .6396 L .48722 .64746 L p .707 .577 .707 r
F P
0 g
s
.46204 .59702 m .4623 .6339 L .43484 .62942 L p .707 .577 .707 r
F P
0 g
s
.43484 .62942 m .43458 .59254 L .46204 .59702 L p .707 .577 .707 r
F P
0 g
s
.43653 .53669 m .43092 .5941 L .39981 .59089 L p .707 .577 .707 r
F P
0 g
s
.39981 .59089 m .40542 .53348 L .43653 .53669 L p .707 .577 .707 r
F P
0 g
s
.34245 .6324 m .3422 .59553 L .37158 .59176 L p .707 .577 .707 r
F P
0 g
s
.36816 .58788 m .37377 .53047 L .40542 .53348 L p .707 .577 .707 r
F P
0 g
s
.40542 .53348 m .39981 .59089 L .36816 .58788 L p .707 .577 .707 r
F P
0 g
s
.32309 .66743 m .32236 .64949 L .34636 .64107 L p .707 .577 .707 r
F P
0 g
s
.43458 .59254 m .43484 .62942 L .40367 .6276 L p .707 .577 .707 r
F P
0 g
s
.40367 .6276 m .40341 .59073 L .43458 .59254 L p .707 .577 .707 r
F P
0 g
s
.37158 .59176 m .37183 .62863 L .34245 .6324 L p .707 .577 .707 r
F P
0 g
s
.34636 .64107 m .34709 .65901 L .32309 .66743 L p .707 .577 .707 r
F P
0 g
s
.37183 .62863 m .37158 .59176 L .40341 .59073 L p .707 .577 .707 r
F P
0 g
s
.46613 .6396 m .46686 .65754 L .43939 .65266 L p .707 .577 .707 r
F P
0 g
s
.43939 .65266 m .43866 .63472 L .46613 .6396 L p .707 .577 .707 r
F P
0 g
s
.40341 .59073 m .40367 .6276 L .37183 .62863 L p .707 .577 .707 r
F P
0 g
s
.34709 .65901 m .34636 .64107 L .37569 .63549 L p .707 .577 .707 r
F P
0 g
s
.43866 .63472 m .43939 .65266 L .40823 .65125 L p .707 .577 .707 r
F P
0 g
s
.40823 .65125 m .4075 .63331 L .43866 .63472 L p .707 .577 .707 r
F P
0 g
s
.37569 .63549 m .37642 .65343 L .34709 .65901 L p .707 .577 .707 r
F P
0 g
s
.37642 .65343 m .37569 .63549 L .4075 .63331 L p .707 .577 .707 r
F P
0 g
s
.4075 .63331 m .40823 .65125 L .37642 .65343 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001bOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEP0000<006ioo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Jgoo001X
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF008006Moo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol0
06Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo06Aoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001DOol:0006Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool005Aoo`03001JEP0000AJEP03001JEUYF014000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00
E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00P00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003001SOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF001JEP00FUH=001FOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYF
FUH9001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@00<7oo001COol:0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000`00;7oo001DOol60003FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
FWoo1`000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool0065ooah000=JEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo001POol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYFFUH005YF;Goo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEP0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUIJEP00FUH]Ool005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;Goo2P0077oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF4P0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF000015YF00<005YFFUH03P003Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00
00002P000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00002`00
0Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P003Goo700015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF1`001UYF00<005YFFUH01eYF200015YF00<005YFFUH00eYF00<0
05YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
2goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00@005YFFUIJEP80
02ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YF00000`0017oo00<005YF00000UYF700015YF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF10000UYF2P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPP00004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00008000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004FUH80005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EP00001JEP0015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0000=JEP0000000P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH500000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP04001JEP000006
FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH400000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH200000eYF001JEP05FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50005FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJ
EUYF00001EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@0
05YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH00003
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF
001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH40003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH00UYF2@002Goo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0P0000EJEP00FUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP000080009JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEPH000Yoo`l00003Ool00000
00<000AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH3000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUH000080002
Ool90004FUH00`00FUIJEP06FUH00`00FUH000030002Ool300000eYF001JEP02FUH2000]Ool002ao
o`X000=JEP03001JEUYF00=JEQ4000=JEP05001JEP00FUH00002FUH300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH2000<FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH40004FUH50004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000015YF000000000eYF0P00;Goo000_Ool4
0003FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUH000040004FUH00`00
FUIJEP05FUH40005FUH00`00FUIJEP02FUH70009FUH01000FUH000002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P000eYF1P0025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000AJEP00001JEP8002eoo`00<goo1P0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00000010000eYF6`001UYF00<0
05YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00000000EJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP800004FUH00000000]Ool0039oo`<000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEP0000<00005FUH00000FUH00005
FUH00`00FUH000040003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200001EYF001JEUYF00002eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP8000EJEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEPD002eoo`00
<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
0P000UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YF000010000eYF00<005YFFUH02EYF
00<005YFFUH00UYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0`000UYF00<005YF00000P001UYF00<005YFFUH00UYF200025YF2@0015YF00<005YFFUH00UYF00<0
05YF00000P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH30002FUH40005FUH300000eYF001JEP04FUH00`00FUIJEP030004FUH00`00FUIJ
EP08FUH00`00FUH0000300000eYF001JEP03FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH20002FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH70004FUH01000FUIJEP00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP02FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEP04001JEUYFFUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300001EYF
001JEUYF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
0UYF0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP04001JEUYFFUH:0008FUH70005FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH0000002aoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000UYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF0000009oo`<002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF00H00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eo
o`8002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@000eYF0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF0080009JEP03
001JEP0000@000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<000Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1P006Goo2`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF1@000eYF2P0015YF1@0015YF00<005YF
FUH00UYF1@002Goo0`0000=JEP00Ool0:goo000/Ool00`00FUH00004FUH00`00FUH00003000?Ool3
000COol300000eYF000000080004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00
FUH000030003FUH20004OolB000<Ool20002FUH00`00FUH0000/Ool002aoo`03001JEP0000=JEP@0
015oo`D000moo`@00003FUH0000000800003FUH005YF00EJEPT00003FUH005YF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF009JEP03001JEUYF009JEP80009JEP8000Qoo`D001=oo`8000AJEP8002eoo`00
;7oo00@005YF001JEP8000AJEPD000aoo`D000Uoo`H000EJEP06001JEUYF001JEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP0000000UYF0P0000=JEP00FUH015YF0P0000=JEP000000
2Goo0`004Woo0P0000=JEP00FUH00eYF0P00;Goo000/Ool01P00FUH00000FUH000EJEP04001JEUYF
FUH80004Ool>0004FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH00000009JEP03001JEP00008000AJEP03001JEP00008001aoo`8000=JEP03
001JEUYF009JEP03001oogoo02aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<0
05YF00001`0015YF00<005YFFUH00UYF2@001UYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomo
o`0EOol50005FUH01000FUIJEUYF0P00;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000MJEP00FUIJEP00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH00UYF00<005YF
00000`0000=JEP00Ool03Goo2@000eYF00<005YFFUH015YF00@005YF0000031oo`00;7oo0P000eYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P0000AJEP00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH0
05YFFUH30004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol0
02eoo`05001JEUYFFUH00004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=7oo000]Ool01@00FUIJEUYF00000UYF0P001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Ioo`00;Woo0P0000=JEP00FUH00P001UYF
00<005YFFUH015YF1`001eYF2@0015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000goo100000AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPH003Qoo`00<7oo0`0000=JEP00FUH01EYF00<005YFFUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF1P0015YF00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF
6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`0015YF100000=J
EP00FUH01eYF00<005YFFUH00UYF2@00?Woo000`Ool01@00FUIJEUYF00001EYF100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000AJEP00FUH000IJEP03001J
EUYF00=JEP/000aJEP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yo
o`<00003FUH005YF009JEPl004Moo`00;goo0P000eYF00<005YF00000`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000goo0P0000=JEP00FUH015YF1`002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF0P001goo
100000AJEP00000000=JEP8005Aoo`00;goo0P000eYF0P000goo10000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P0027oo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009J
EP80009oo`D000EJEP03001JEUYF00800003FUH0000005Aoo`00;Woo00<005YF00000UYF00<007oo
Ool01goo60003Woo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF20001UYF00<005YFFUH00UYF
0`00E7oo000^Ool00`00FUH00002000DOol5000GOol20002FUH00`00FUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH30008FUH01000FUIJEUYF0P000UYF
0P000UYF00@005YFFUIJEP@0009JEP03001JEUYF009JEP<005Aoo`00;Woo00<005YF00005Woo1@00
5goo0P000UYF00<005YF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH00eYF10002eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF100015YF00<005YF0000
E7oo000^Ool2000GOol5000GOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH00`00FUIJEP0<FUH00`00FUIJEP04FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0001DOol002ioo`8001Qoo`<001Qoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP03
001JEUYF00aJEP03001JEUYF00AJEP<0009JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
000005Eoo`00;Woo00@005YF0000031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00]JEP03001JEUYF00AJEP03001J
EP0000@000IJEP03001JEUYF009JEP<005Ioo`00;Woo0P000UYF0P00;7oo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF00@005YFFUIJEP<000MJEP03001JEUYF00AJEP03001JEP0000AJEP@0009JEP03001JEUYF009J
EP04001JEP00001EOol002moo`05001JEUYF001JEP03000UOol400000eYF001JEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH6
0009FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP040004FUH01000FUIJEP00E7oo000_Ool01000
FUIJEP0015YF0`007goo0`001EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH015YF0P001UYF00<005YF00000`0000Ioo`00000005YF0002FUH00`00Oomoo`1BOol0
031oo`03001JEP0000EJEP03001JEP0000<001Moo`@00003FUH005YF00EJEP03001JEUYF0080009o
o`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000AJEPD000Qoo`80009JEP8005=oo`00<Goo0P001EYF00<005YF
FUH00eYF5`001EYF00<005YFFUH015YF0`001goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00002@003goo00@005YF0000
05=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P003Goo20001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF10006Woo0`00Dgoo000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000GOol<0006FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH@000JOol2001COol003Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<002Mooa/000]oo`D001Uoo`<005=oo`00>Woo10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000=Woo0P0067oo1@005goo0`0000=JEP00Ool0DWoo000nOolG000jOol3
000HOol3000FOol20002FUH00`00FUH0001COol008moo`800003FUH007oo02eoo`8000AJEP8005Ao
o`00Sgoo0P000UYF0P00:7oo100000=JEP00FUH00eYF0P00E7oo002@Ool01@00FUIJEP00FUH00`00
8Woo0`001EYF00<005YFFUH00UYF00<007ooOol0Dgoo002@Ool01000FUIJEP0015YF1@006Goo1000
00=JEP00FUH01EYF00<005YFFUH00P00EWoo002AOol01000FUIJEP0015YF00@005YFFUIJEPT000Uo
o`L000EJEP03001JEUYF00AJEP<005Qoo`00TWoo0`0015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0F7oo002DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Fgoo002F
Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0
0000GGoo002IOol50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6001OOol0
09ioo`P000AJEP03001JEUYF009JEPT006Eoo`00YWoo2@00KWoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57285 .65043 m .56394 .70696 L .59495 .71098 L p .707 .577 .707 r
F P
0 g
s
.59495 .71098 m .60385 .65445 L .57285 .65043 L p .707 .577 .707 r
F P
0 g
s
.60385 .65445 m .59495 .71098 L .62629 .71634 L p .707 .577 .707 r
F P
0 g
s
.62629 .71634 m .6352 .65981 L .60385 .65445 L p .707 .577 .707 r
F P
0 g
s
.6352 .65981 m .62629 .71634 L .65492 .72252 L p .707 .577 .707 r
F P
0 g
s
.54522 .64815 m .53632 .70468 L .56394 .70696 L p .707 .577 .707 r
F P
0 g
s
.56394 .70696 m .57285 .65043 L .54522 .64815 L p .707 .577 .707 r
F P
0 g
s
.65492 .72252 m .66382 .66599 L .6352 .65981 L p .707 .577 .707 r
F P
0 g
s
.66382 .66599 m .65492 .72252 L .67801 .72891 L p .707 .577 .707 r
F P
0 g
s
.59583 .80815 m .59541 .77139 L .56424 .76962 L p .707 .577 .707 r
F P
0 g
s
.59541 .77139 m .59583 .80815 L .62766 .80696 L p .707 .577 .707 r
F P
0 g
s
.62766 .80696 m .62724 .7702 L .59541 .77139 L p .707 .577 .707 r
F P
0 g
s
.62724 .7702 m .62766 .80696 L .65704 .80295 L p .707 .577 .707 r
F P
0 g
s
.65704 .80295 m .65662 .76619 L .62724 .7702 L p .707 .577 .707 r
F P
0 g
s
.52368 .64784 m .51477 .70437 L .53632 .70468 L p .707 .577 .707 r
F P
0 g
s
.53632 .70468 m .54522 .64815 L .52368 .64784 L p .707 .577 .707 r
F P
0 g
s
.67801 .72891 m .68692 .67239 L .66382 .66599 L p .707 .577 .707 r
F P
0 g
s
.56465 .80638 m .56424 .76962 L .53678 .76509 L p .707 .577 .707 r
F P
0 g
s
.56424 .76962 m .56465 .80638 L .59583 .80815 L p .707 .577 .707 r
F P
0 g
s
.65662 .76619 m .65704 .80295 L .68109 .79651 L p .707 .577 .707 r
F P
0 g
s
.68109 .79651 m .68067 .75975 L .65662 .76619 L p .707 .577 .707 r
F P
0 g
s
.53678 .76509 m .5372 .80185 L .56465 .80638 L p .707 .577 .707 r
F P
0 g
s
.68692 .67239 m .67801 .72891 L .69332 .7349 L p .707 .577 .707 r
F P
0 g
s
.5372 .80185 m .53678 .76509 L .51572 .75823 L p .707 .577 .707 r
F P
0 g
s
.69332 .7349 m .70223 .67837 L .68692 .67239 L p .707 .577 .707 r
F P
0 g
s
.51033 .64951 m .50142 .70604 L .51477 .70437 L p .707 .577 .707 r
F P
0 g
s
.51477 .70437 m .52368 .64784 L .51033 .64951 L p .707 .577 .707 r
F P
0 g
s
.51572 .75823 m .51614 .79499 L .5372 .80185 L p .707 .577 .707 r
F P
0 g
s
.68067 .75975 m .68109 .79651 L .69745 .78826 L p .707 .577 .707 r
F P
0 g
s
.69745 .78826 m .69703 .7515 L .68067 .75975 L p .707 .577 .707 r
F P
0 g
s
.60398 .86875 m .60281 .85127 L .57166 .85015 L p .707 .577 .707 r
F P
0 g
s
.60281 .85127 m .60398 .86875 L .63574 .86572 L p .707 .577 .707 r
F P
0 g
s
.63574 .86572 m .63457 .84824 L .60281 .85127 L p .707 .577 .707 r
F P
0 g
s
.63457 .84824 m .63574 .86572 L .66501 .85883 L p .707 .577 .707 r
F P
0 g
s
.66501 .85883 m .66383 .84134 L .63457 .84824 L p .707 .577 .707 r
F P
0 g
s
.51614 .79499 m .51572 .75823 L .50313 .74972 L p .707 .577 .707 r
F P
0 g
s
.70223 .67837 m .69332 .7349 L .69934 .73989 L p .707 .577 .707 r
F P
0 g
s
.57284 .86763 m .57166 .85015 L .54417 .84498 L p .707 .577 .707 r
F P
0 g
s
.57166 .85015 m .57284 .86763 L .60398 .86875 L p .707 .577 .707 r
F P
0 g
s
.69934 .73989 m .70825 .68336 L .70223 .67837 L p .707 .577 .707 r
F P
0 g
s
.66383 .84134 m .66501 .85883 L .68892 .84875 L p .707 .577 .707 r
F P
0 g
s
.68892 .84875 m .68774 .83127 L .66383 .84134 L p .707 .577 .707 r
F P
0 g
s
.54417 .84498 m .54535 .86246 L .57284 .86763 L p .707 .577 .707 r
F P
0 g
s
.50313 .74972 m .50354 .78648 L .51614 .79499 L p .707 .577 .707 r
F P
0 g
s
.50647 .65302 m .49757 .70955 L .50142 .70604 L p .707 .577 .707 r
F P
0 g
s
.50142 .70604 m .51033 .64951 L .50647 .65302 L p .707 .577 .707 r
F P
0 g
s
.69703 .7515 m .69745 .78826 L .70453 .77901 L p .707 .577 .707 r
F P
0 g
s
.70453 .77901 m .70411 .74225 L .69703 .7515 L p .707 .577 .707 r
F P
0 g
s
.54535 .86246 m .54417 .84498 L .52305 .83627 L p .707 .577 .707 r
F P
0 g
s
.52305 .83627 m .52422 .85375 L .54535 .86246 L p .707 .577 .707 r
F P
0 g
s
.68774 .83127 m .68892 .84875 L .70513 .83647 L p .707 .577 .707 r
F P
0 g
s
.70513 .83647 m .70395 .81899 L .68774 .83127 L p .707 .577 .707 r
F P
0 g
s
.50354 .78648 m .50313 .74972 L .50023 .74038 L p .707 .577 .707 r
F P
0 g
s
.70825 .68336 m .69934 .73989 L .69549 .7434 L p .707 .577 .707 r
F P
0 g
s
.69549 .7434 m .7044 .68687 L .70825 .68336 L p .707 .577 .707 r
F P
0 g
s
.50023 .74038 m .50064 .77714 L .50354 .78648 L p .707 .577 .707 r
F P
0 g
s
.52422 .85375 m .52305 .83627 L .51034 .82487 L p .707 .577 .707 r
F P
0 g
s
.5125 .65801 m .50359 .71454 L .49757 .70955 L p .707 .577 .707 r
F P
0 g
s
.49757 .70955 m .50647 .65302 L .5125 .65801 L p .707 .577 .707 r
F P
0 g
s
.70411 .74225 m .70453 .77901 L .70163 .76967 L p .707 .577 .707 r
F P
0 g
s
.70163 .76967 m .70121 .73291 L .70411 .74225 L p .707 .577 .707 r
F P
0 g
s
.47875 .81629 m .49676 .3045 L .45276 .30117 L p .707 .577 .707 r
F P
0 g
s
.50064 .77714 m .50023 .74038 L .5073 .73113 L p .707 .577 .707 r
F P
0 g
s
.51152 .84235 m .51034 .82487 L .5073 .8119 L p .707 .577 .707 r
F P
0 g
s
.5073 .73113 m .50772 .76789 L .50064 .77714 L p .707 .577 .707 r
F P
0 g
s
.5278 .664 m .5189 .72052 L .50359 .71454 L p .707 .577 .707 r
F P
0 g
s
.50359 .71454 m .5125 .65801 L .5278 .664 L p .707 .577 .707 r
F P
0 g
s
.5073 .8119 m .50847 .82938 L .51152 .84235 L p .707 .577 .707 r
F P
0 g
s
.50772 .76789 m .5073 .73113 L .52367 .72288 L p .707 .577 .707 r
F P
0 g
s
.50847 .82938 m .5073 .8119 L .51422 .79863 L p .707 .577 .707 r
F P
0 g
s
.52367 .72288 m .52408 .75964 L .50772 .76789 L p .707 .577 .707 r
F P
0 g
s
.51034 .82487 m .51152 .84235 L .52422 .85375 L p .707 .577 .707 r
F P
0 g
s
.51422 .79863 m .5154 .81611 L .50847 .82938 L p .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .51422 .79863 L .52675 .78913 L p .707 .577 .707 r
F P
0 g
s
.54199 .72692 m .5189 .72052 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.5509 .67039 m .54733 .69306 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54733 .69306 m .54199 .72692 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .49676 .3045 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .52675 .78913 L .5262 .79471 L .707 .577 .707 r
F
.5189 .72052 m .5278 .664 L .5509 .67039 L p F P
0 g
s
.54199 .72692 m .54469 .70979 L p .57952 .67657 L .707 .577 .707 r
F P
0 g
s
.54469 .70979 m .5509 .67039 L .56736 .67395 L p .707 .577 .707 r
F P
0 g
s
.56736 .67395 m .57952 .67657 L p .54469 .70979 L .707 .577 .707 r
F P
0 g
s
.61087 .68194 m .60196 .73846 L .57547 .73393 L p .707 .577 .707 r
F P
0 g
s
.57547 .73393 m .57062 .7331 L p .57765 .72416 L .707 .577 .707 r
F P
0 g
s
.57765 .72416 m .61087 .68194 L .57547 .73393 L .707 .577 .707 r
F
.64187 .68595 m .63297 .74248 L .60623 .73902 L p F P
0 g
s
.60623 .73902 m .60196 .73846 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60698 .73186 m .64187 .68595 L .60623 .73902 L .707 .577 .707 r
F
.60196 .73846 m .61087 .68194 L .61225 .68211 L p F P
0 g
s
.61225 .68211 m .64187 .68595 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60196 .73846 m .61225 .68211 L .60698 .73186 L .707 .577 .707 r
F
.64996 .28493 m .64003 .2927 L p .63763 .44218 L F P
0 g
s
.6695 .68823 m .66059 .74476 L .63297 .74248 L p .707 .577 .707 r
F P
0 g
s
.63297 .74248 m .64187 .68595 L .6695 .68823 L p .707 .577 .707 r
F P
0 g
s
.6401 .713 m .64052 .74977 L .60934 .748 L p .707 .577 .707 r
F P
0 g
s
.60934 .748 m .60893 .71124 L .6401 .713 L p .707 .577 .707 r
F P
0 g
s
.64651 .76747 m .64769 .78495 L .61654 .78383 L p .707 .577 .707 r
F P
0 g
s
.61654 .78383 m .61536 .76635 L .64651 .76747 L p .707 .577 .707 r
F P
0 g
s
.63195 .79672 m .64781 .34602 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64781 .34602 m .64996 .28493 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .63195 .79672 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64003 .2927 m .63335 .48271 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.63335 .48271 m .62202 .80449 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.57062 .7331 m .57952 .67657 L .61087 .68194 L p .707 .577 .707 r
F P
0 g
s
.57751 .74919 m .57709 .71243 L .60893 .71124 L p .707 .577 .707 r
F P
0 g
s
.60893 .71124 m .60934 .748 L .57751 .74919 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .59899 .81085 L p .59842 .79281 L .707 .577 .707 r
F P
0 g
s
.59148 .76863 m .59603 .76819 L p .59287 .77345 L .707 .577 .707 r
F P
0 g
s
.59603 .76819 m .61536 .76635 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.57709 .71243 m .57751 .74919 L .5664 .7507 L p .707 .577 .707 r
F P
0 g
s
.5664 .7507 m .54813 .7532 L p .56297 .73231 L .707 .577 .707 r
F P
0 g
s
.57952 .67657 m .57062 .7331 L .54199 .72692 L p .707 .577 .707 r
F P
0 g
s
.56297 .73231 m .57709 .71243 L .5664 .7507 L .707 .577 .707 r
F
.54813 .7532 m .54772 .71644 L .57709 .71243 L p F P
0 g
s
.57022 .66943 m .56721 .75502 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.56721 .75502 m .56509 .81517 L p .57115 .77614 L .707 .577 .707 r
F P
0 g
s
.59341 .63276 m .56721 .75502 L .57115 .77614 L .707 .577 .707 r
F
.59842 .79281 m .57905 .72528 L .56509 .81517 L F
.58478 .78686 m .59603 .76819 L .59729 .77847 L F
.61536 .76635 m .61654 .78383 L .59815 .78559 L p F P
0 g
s
.59815 .78559 m .58478 .78686 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.59729 .77847 m .61536 .76635 L .59815 .78559 L .707 .577 .707 r
F
.60659 .59461 m .59949 .79654 L p .61937 .53744 L F P
0 g
s
.59949 .79654 m .59899 .81085 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61937 .53744 m .59949 .79654 L .59984 .7994 L .707 .577 .707 r
F
.59842 .79281 m .59341 .63276 L .57905 .72528 L F
.58478 .78686 m .5836 .76938 L .59148 .76863 L p F P
0 g
s
.58478 .78686 m .59148 .76863 L .59287 .77345 L .707 .577 .707 r
F
.62202 .80449 m .61937 .53744 L .59984 .7994 L F
.59899 .81085 m .60116 .81025 L p .59984 .7994 L F P
0 g
s
.60116 .81025 m .62202 .80449 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61699 .29906 m .60659 .59461 L p .61937 .53744 L .707 .577 .707 r
F P
0 g
s
.5831 .30338 m .57022 .66943 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.52408 .75964 m .52367 .72288 L .54772 .71644 L p .707 .577 .707 r
F P
0 g
s
.54772 .71644 m .54813 .7532 L .52408 .75964 L p .707 .577 .707 r
F P
0 g
s
.52401 .81703 m .56509 .81517 L p .55206 .53137 L .707 .577 .707 r
F P
0 g
s
.53043 .78635 m .53161 .80383 L .5248 .80899 L p .707 .577 .707 r
F P
0 g
s
.5248 .80899 m .5154 .81611 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.5262 .79471 m .53043 .78635 L .5248 .80899 L .707 .577 .707 r
F
.52366 .81705 m .53072 .61639 L p .5075 .50915 L F P
0 g
s
.53072 .61639 m .54167 .30526 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.52675 .78913 m .53043 .78635 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .52366 .81705 L .52401 .81703 L p .707 .577 .707 r
F P
0 g
s
.55206 .53137 m .54167 .30526 L .52401 .81703 L .707 .577 .707 r
F
.49676 .3045 m .47875 .81629 L .52366 .81705 L p F P
0 g
s
.70395 .81899 m .70513 .83647 L .71205 .8232 L p .707 .577 .707 r
F P
0 g
s
.71205 .8232 m .71087 .80572 L .70395 .81899 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .5831 .30338 L .54167 .30526 L p .707 .577 .707 r
F P
0 g
s
.43476 .81296 m .45276 .30117 L .41399 .29561 L p .707 .577 .707 r
F P
0 g
s
.45276 .30117 m .43476 .81296 L .47875 .81629 L p .707 .577 .707 r
F P
0 g
s
.7044 .68687 m .69549 .7434 L .68214 .74507 L p .707 .577 .707 r
F P
0 g
s
.22984 .61362 m .22093 .67014 L .25194 .67416 L p .707 .577 .707 r
F P
0 g
s
.25194 .67416 m .26084 .61763 L .22984 .61362 L p .707 .577 .707 r
F P
0 g
s
.26084 .61763 m .25194 .67416 L .28329 .67952 L p .707 .577 .707 r
F P
0 g
s
.59899 .81085 m .61699 .29906 L .5831 .30338 L p .707 .577 .707 r
F P
0 g
s
.68214 .74507 m .69104 .68854 L .7044 .68687 L p .707 .577 .707 r
F P
0 g
s
.28329 .67952 m .29219 .62299 L .26084 .61763 L p .707 .577 .707 r
F P
0 g
s
.29219 .62299 m .28329 .67952 L .31191 .6857 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.20221 .61134 m .19331 .66787 L .22093 .67014 L p .707 .577 .707 r
F P
0 g
s
.22093 .67014 m .22984 .61362 L .20221 .61134 L p .707 .577 .707 r
F P
0 g
s
.70121 .73291 m .70163 .76967 L .68903 .76116 L p .707 .577 .707 r
F P
0 g
s
.68903 .76116 m .68862 .7244 L .70121 .73291 L p .707 .577 .707 r
F P
0 g
s
.31191 .6857 m .32081 .62917 L .29219 .62299 L p .707 .577 .707 r
F P
0 g
s
.39598 .8074 m .41399 .29561 L .38423 .28836 L p .707 .577 .707 r
F P
0 g
s
.41399 .29561 m .39598 .8074 L .43476 .81296 L p .707 .577 .707 r
F P
0 g
s
.71087 .80572 m .71205 .8232 L .70901 .81023 L p .707 .577 .707 r
F P
0 g
s
.70901 .81023 m .70783 .79275 L .71087 .80572 L p .707 .577 .707 r
F P
0 g
s
.32081 .62917 m .31191 .6857 L .335 .6921 L p .707 .577 .707 r
F P
0 g
s
.25282 .77133 m .2524 .73457 L .22123 .73281 L p .707 .577 .707 r
F P
0 g
s
.2524 .73457 m .25282 .77133 L .28465 .77015 L p .707 .577 .707 r
F P
0 g
s
.28465 .77015 m .28423 .73339 L .2524 .73457 L p .707 .577 .707 r
F P
0 g
s
.28423 .73339 m .28465 .77015 L .31403 .76614 L p .707 .577 .707 r
F P
0 g
s
.31403 .76614 m .31361 .72938 L .28423 .73339 L p .707 .577 .707 r
F P
0 g
s
.18067 .61102 m .17176 .66755 L .19331 .66787 L p .707 .577 .707 r
F P
0 g
s
.19331 .66787 m .20221 .61134 L .18067 .61102 L p .707 .577 .707 r
F P
0 g
s
.335 .6921 m .34391 .63557 L .32081 .62917 L p .707 .577 .707 r
F P
0 g
s
.69104 .68854 m .68214 .74507 L .66059 .74476 L p .707 .577 .707 r
F P
0 g
s
.22165 .76957 m .22123 .73281 L .19377 .72828 L p .707 .577 .707 r
F P
0 g
s
.22123 .73281 m .22165 .76957 L .25282 .77133 L p .707 .577 .707 r
F P
0 g
s
.66059 .74476 m .6695 .68823 L .69104 .68854 L p .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .64003 .2927 L .61699 .29906 L p .707 .577 .707 r
F P
0 g
s
.31361 .72938 m .31403 .76614 L .33808 .75969 L p .707 .577 .707 r
F P
0 g
s
.33808 .75969 m .33766 .72293 L .31361 .72938 L p .707 .577 .707 r
F P
0 g
s
.68862 .7244 m .68903 .76116 L .66797 .7543 L p .707 .577 .707 r
F P
0 g
s
.66797 .7543 m .66756 .71754 L .68862 .7244 L p .707 .577 .707 r
F P
0 g
s
.19377 .72828 m .19419 .76504 L .22165 .76957 L p .707 .577 .707 r
F P
0 g
s
.34391 .63557 m .335 .6921 L .35031 .69809 L p .707 .577 .707 r
F P
0 g
s
.19419 .76504 m .19377 .72828 L .17271 .72142 L p .707 .577 .707 r
F P
0 g
s
.70783 .79275 m .70901 .81023 L .6963 .79883 L p .707 .577 .707 r
F P
0 g
s
.6963 .79883 m .69512 .78135 L .70783 .79275 L p .707 .577 .707 r
F P
0 g
s
.35031 .69809 m .35922 .64156 L .34391 .63557 L p .707 .577 .707 r
F P
0 g
s
.36094 .78218 m .36212 .79966 L .36614 .79196 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .38423 .28836 L .37014 .28185 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .37014 .28185 L .36623 .78014 L .707 .577 .707 r
F
.38423 .28836 m .36622 .80015 L .39598 .8074 L p F P
0 g
s
.36619 .7849 m .36094 .78218 L .36614 .79196 L .707 .577 .707 r
F
.33766 .72293 m .33808 .75969 L .35444 .75144 L p F P
0 g
s
.35444 .75144 m .35403 .71468 L .33766 .72293 L p .707 .577 .707 r
F P
0 g
s
.35922 .64156 m .35031 .69809 L .35633 .70308 L p .707 .577 .707 r
F P
0 g
s
.35633 .70308 m .36524 .64655 L .35922 .64156 L p .707 .577 .707 r
F P
0 g
s
.35403 .71468 m .35444 .75144 L .36152 .74219 L p .707 .577 .707 r
F P
0 g
s
.36152 .74219 m .3611 .70543 L .35403 .71468 L p .707 .577 .707 r
F P
0 g
s
.36212 .79966 m .36094 .78218 L .34473 .79445 L p .707 .577 .707 r
F P
0 g
s
.36524 .64655 m .35633 .70308 L .35248 .70658 L p .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .36139 .65005 L .36524 .64655 L p .707 .577 .707 r
F P
0 g
s
.3611 .70543 m .36152 .74219 L .35862 .73286 L p .707 .577 .707 r
F P
0 g
s
.35862 .73286 m .3582 .6961 L .3611 .70543 L p .707 .577 .707 r
F P
0 g
s
.36629 .77191 m .36094 .78218 L p .36619 .7849 L .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .33913 .70826 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.36139 .65005 m .35518 .68945 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.35518 .68945 m .35248 .70658 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.3664 .28013 m .36225 .27171 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .34803 .65173 L .35371 .65102 L p .707 .577 .707 r
F P
0 g
s
.35371 .65102 m .36139 .65005 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .35371 .65102 L .35437 .66839 L .707 .577 .707 r
F
.3582 .6961 m .35862 .73286 L .35078 .72756 L p F P
0 g
s
.35078 .72756 m .34602 .72434 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.35188 .71076 m .3582 .6961 L .35078 .72756 L .707 .577 .707 r
F
.34602 .72434 m .34561 .68758 L .35306 .69262 L p F P
0 g
s
.35306 .69262 m .3582 .6961 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.34602 .72434 m .35306 .69262 L .35188 .71076 L .707 .577 .707 r
F
.34964 .74508 m .35352 .64617 L .35279 .62696 L F
.34839 .79191 m .35051 .73176 L p .34964 .74508 L F P
0 g
s
.35051 .73176 m .35352 .64617 L p .34964 .74508 L .707 .577 .707 r
F P
0 g
s
.34424 .7835 m .3468 .78868 L p .34995 .70366 L .707 .577 .707 r
F P
0 g
s
.34995 .70366 m .34563 .75799 L .34424 .7835 L .707 .577 .707 r
F
.3468 .78868 m .34839 .79191 L p .34964 .74508 L F P
0 g
s
.34964 .74508 m .35279 .62696 L .3468 .78868 L .707 .577 .707 r
F
.34557 .75883 m .3444 .75835 L p .3465 .747 L F P
0 g
s
.3444 .75835 m .33216 .75331 L p .34407 .74807 L .707 .577 .707 r
F P
0 g
s
.34407 .74807 m .3465 .747 L .3444 .75835 L .707 .577 .707 r
F
.3664 .28013 m .34839 .79191 L .36607 .80008 L p F P
0 g
s
.34687 .74237 m .35212 .74453 L p .3465 .747 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .34424 .7835 L p .34563 .75799 L .707 .577 .707 r
F P
0 g
s
.35212 .74453 m .35329 .76202 L .34557 .75883 L p .707 .577 .707 r
F P
0 g
s
.3465 .747 m .35212 .74453 L .34557 .75883 L .707 .577 .707 r
F
.34385 .74113 m .34687 .74237 L p .34396 .74454 L F P
0 g
s
.33216 .75331 m .34687 .74237 L .3465 .747 L .707 .577 .707 r
F
.34995 .70366 m .35279 .62696 L .34563 .75799 L F
.35352 .64617 m .3664 .28013 L p .35279 .62696 L F P
0 g
s
.36623 .78014 m .3664 .28013 L .36607 .80008 L .707 .577 .707 r
F
.37014 .28185 m .3664 .28013 L p .36623 .78014 L F P
0 g
s
.36482 .75593 m .366 .77342 L .35329 .76202 L p .707 .577 .707 r
F P
0 g
s
.35329 .76202 m .35212 .74453 L .36482 .75593 L p .707 .577 .707 r
F P
0 g
s
.37217 .26395 m .35417 .77574 L .34518 .78277 L p .707 .577 .707 r
F P
0 g
s
.34518 .78277 m .34424 .7835 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.3512 .5856 m .34474 .76919 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.35279 .62696 m .34474 .76919 L .34563 .75799 L .707 .577 .707 r
F
.36225 .27171 m .3512 .5856 L p .35279 .62696 L F P
0 g
s
.34484 .7723 m .37217 .26395 L .34518 .78277 L .707 .577 .707 r
F
.33216 .75331 m .33099 .73582 L .34385 .74113 L p F P
0 g
s
.33216 .75331 m .34385 .74113 L .34396 .74454 L .707 .577 .707 r
F
.34484 .7723 m .35127 .58738 L .35273 .62555 L F
.35127 .58738 m .36225 .27171 L .35273 .62555 L F
.36225 .27171 m .37217 .26395 L p .35273 .62555 L F P
0 g
s
.34424 .7835 m .34474 .76919 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .36225 .27171 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.36607 .80008 m .36622 .80015 L p .36623 .78014 L .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36786 .7689 L .36629 .77191 L p .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36629 .77191 L .36619 .7849 L .707 .577 .707 r
F
.36614 .79196 m .36904 .78639 L p .36619 .7849 L F P
0 g
s
.16732 .6127 m .15841 .66923 L .17176 .66755 L p .707 .577 .707 r
F P
0 g
s
.17176 .66755 m .18067 .61102 L .16732 .6127 L p .707 .577 .707 r
F P
0 g
s
.17271 .72142 m .17313 .75818 L .19419 .76504 L p .707 .577 .707 r
F P
0 g
s
.66756 .71754 m .66797 .7543 L .64052 .74977 L p .707 .577 .707 r
F P
0 g
s
.64052 .74977 m .6401 .713 L .66756 .71754 L p .707 .577 .707 r
F P
0 g
s
.26097 .83194 m .2598 .81446 L .22865 .81333 L p .707 .577 .707 r
F P
0 g
s
.2598 .81446 m .26097 .83194 L .29274 .82891 L p .707 .577 .707 r
F P
0 g
s
.29274 .82891 m .29156 .81142 L .2598 .81446 L p .707 .577 .707 r
F P
0 g
s
.29156 .81142 m .29274 .82891 L .322 .82201 L p .707 .577 .707 r
F P
0 g
s
.322 .82201 m .32083 .80453 L .29156 .81142 L p .707 .577 .707 r
F P
0 g
s
.17313 .75818 m .17271 .72142 L .16012 .7129 L p .707 .577 .707 r
F P
0 g
s
.22983 .83082 m .22865 .81333 L .20117 .80816 L p .707 .577 .707 r
F P
0 g
s
.22865 .81333 m .22983 .83082 L .26097 .83194 L p .707 .577 .707 r
F P
0 g
s
.69512 .78135 m .6963 .79883 L .67517 .79012 L p .707 .577 .707 r
F P
0 g
s
.67517 .79012 m .674 .77264 L .69512 .78135 L p .707 .577 .707 r
F P
0 g
s
.32083 .80453 m .322 .82201 L .34591 .81194 L p .707 .577 .707 r
F P
0 g
s
.34591 .81194 m .34473 .79445 L .32083 .80453 L p .707 .577 .707 r
F P
0 g
s
.20117 .80816 m .20234 .82565 L .22983 .83082 L p .707 .577 .707 r
F P
0 g
s
.16012 .7129 m .16053 .74966 L .17313 .75818 L p .707 .577 .707 r
F P
0 g
s
.16346 .6162 m .15456 .67273 L .15841 .66923 L p .707 .577 .707 r
F P
0 g
s
.15841 .66923 m .16732 .6127 L .16346 .6162 L p .707 .577 .707 r
F P
0 g
s
.53161 .80383 m .53043 .78635 L .55434 .77627 L p .707 .577 .707 r
F P
0 g
s
.20234 .82565 m .20117 .80816 L .18004 .79945 L p .707 .577 .707 r
F P
0 g
s
.55434 .77627 m .55551 .79376 L .53161 .80383 L p .707 .577 .707 r
F P
0 g
s
.18004 .79945 m .18121 .81694 L .20234 .82565 L p .707 .577 .707 r
F P
0 g
s
.674 .77264 m .67517 .79012 L .64769 .78495 L p .707 .577 .707 r
F P
0 g
s
.64769 .78495 m .64651 .76747 L .674 .77264 L p .707 .577 .707 r
F P
0 g
s
.34473 .79445 m .34591 .81194 L .36212 .79966 L p .707 .577 .707 r
F P
0 g
s
.16053 .74966 m .16012 .7129 L .15722 .70356 L p .707 .577 .707 r
F P
0 g
s
.55551 .79376 m .55434 .77627 L .5836 .76938 L p .707 .577 .707 r
F P
0 g
s
.15722 .70356 m .15763 .74032 L .16053 .74966 L p .707 .577 .707 r
F P
0 g
s
.18121 .81694 m .18004 .79945 L .16733 .78806 L p .707 .577 .707 r
F P
0 g
s
.16949 .62119 m .16058 .67772 L .15456 .67273 L p .707 .577 .707 r
F P
0 g
s
.15456 .67273 m .16346 .6162 L .16949 .62119 L p .707 .577 .707 r
F P
0 g
s
.5836 .76938 m .58478 .78686 L .55551 .79376 L p .707 .577 .707 r
F P
0 g
s
.16733 .78806 m .16851 .80554 L .18121 .81694 L p .707 .577 .707 r
F P
0 g
s
.64996 .28493 m .63195 .79672 L .6278 .78831 L p .707 .577 .707 r
F P
0 g
s
.6278 .78831 m .6458 .27652 L .64996 .28493 L p .707 .577 .707 r
F P
0 g
s
.15763 .74032 m .15722 .70356 L .16429 .69432 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16851 .80554 m .16733 .78806 L .16429 .77508 L p .707 .577 .707 r
F P
0 g
s
.16429 .69432 m .16471 .73108 L .15763 .74032 L p .707 .577 .707 r
F P
0 g
s
.18479 .62718 m .17589 .68371 L .16058 .67772 L p .707 .577 .707 r
F P
0 g
s
.16058 .67772 m .16949 .62119 L .18479 .62718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16429 .77508 m .16547 .79257 L .16851 .80554 L p .707 .577 .707 r
F P
0 g
s
.36786 .7689 m .36904 .78639 L .366 .77342 L p .707 .577 .707 r
F P
0 g
s
.366 .77342 m .36482 .75593 L .36786 .7689 L p .707 .577 .707 r
F P
0 g
s
.16471 .73108 m .16429 .69432 L .18066 .68607 L p .707 .577 .707 r
F P
0 g
s
.34803 .65173 m .33913 .70826 L .31758 .70794 L p .707 .577 .707 r
F P
0 g
s
.6458 .27652 m .6278 .78831 L .60997 .78008 L p .707 .577 .707 r
F P
0 g
s
.60997 .78008 m .62798 .26829 L .6458 .27652 L p .707 .577 .707 r
F P
0 g
s
.16547 .79257 m .16429 .77508 L .17121 .76181 L p .707 .577 .707 r
F P
0 g
s
.18066 .68607 m .18107 .72283 L .16471 .73108 L p .707 .577 .707 r
F P
0 g
s
.31758 .70794 m .32649 .65141 L .34803 .65173 L p .707 .577 .707 r
F P
0 g
s
.20789 .63358 m .19898 .69011 L .17589 .68371 L p .707 .577 .707 r
F P
0 g
s
.17589 .68371 m .18479 .62718 L .20789 .63358 L p .707 .577 .707 r
F P
0 g
s
.34561 .68758 m .34602 .72434 L .32496 .71748 L p .707 .577 .707 r
F P
0 g
s
.32496 .71748 m .32455 .68072 L .34561 .68758 L p .707 .577 .707 r
F P
0 g
s
.17121 .76181 m .17239 .7793 L .16547 .79257 L p .707 .577 .707 r
F P
0 g
s
.35417 .77574 m .37217 .26395 L .39521 .25759 L p .707 .577 .707 r
F P
0 g
s
.19898 .69011 m .20789 .63358 L .23651 .63976 L p .707 .577 .707 r
F P
0 g
s
.18107 .72283 m .18066 .68607 L .20471 .67962 L p .707 .577 .707 r
F P
0 g
s
.32649 .65141 m .31758 .70794 L .28996 .70566 L p .707 .577 .707 r
F P
0 g
s
.23651 .63976 m .22761 .69629 L .19898 .69011 L p .707 .577 .707 r
F P
0 g
s
.28996 .70566 m .29887 .64914 L .32649 .65141 L p .707 .577 .707 r
F P
0 g
s
.17239 .7793 m .17121 .76181 L .18742 .74954 L p .707 .577 .707 r
F P
0 g
s
.20471 .67962 m .20512 .71638 L .18107 .72283 L p .707 .577 .707 r
F P
0 g
s
.32455 .68072 m .32496 .71748 L .29751 .71295 L p .707 .577 .707 r
F P
0 g
s
.29751 .71295 m .29709 .67619 L .32455 .68072 L p .707 .577 .707 r
F P
0 g
s
.29887 .64914 m .28996 .70566 L .25895 .70165 L p .707 .577 .707 r
F P
0 g
s
.18742 .74954 m .1886 .76702 L .17239 .7793 L p .707 .577 .707 r
F P
0 g
s
.71005 .55417 m .70115 .6107 L .73215 .61472 L p .707 .577 .707 r
F P
0 g
s
.73215 .61472 m .74106 .55819 L .71005 .55417 L p .707 .577 .707 r
F P
0 g
s
.74106 .55819 m .73215 .61472 L .7635 .62008 L p .707 .577 .707 r
F P
0 g
s
.62798 .26829 m .60997 .78008 L .58021 .77283 L p .707 .577 .707 r
F P
0 g
s
.58021 .77283 m .59822 .26103 L .62798 .26829 L p .707 .577 .707 r
F P
0 g
s
.22761 .69629 m .23651 .63976 L .26786 .64512 L p .707 .577 .707 r
F P
0 g
s
.20512 .71638 m .20471 .67962 L .23408 .67561 L p .707 .577 .707 r
F P
0 g
s
.26786 .64512 m .25895 .70165 L .22761 .69629 L p .707 .577 .707 r
F P
0 g
s
.7635 .62008 m .7724 .56355 L .74106 .55819 L p .707 .577 .707 r
F P
0 g
s
.7724 .56355 m .7635 .62008 L .79212 .62626 L p .707 .577 .707 r
F P
0 g
s
.25895 .70165 m .26786 .64512 L .29887 .64914 L p .707 .577 .707 r
F P
0 g
s
.68243 .55189 m .67352 .60842 L .70115 .6107 L p .707 .577 .707 r
F P
0 g
s
.70115 .6107 m .71005 .55417 L .68243 .55189 L p .707 .577 .707 r
F P
0 g
s
.29709 .67619 m .29751 .71295 L .26633 .71119 L p .707 .577 .707 r
F P
0 g
s
.26633 .71119 m .26592 .67443 L .29709 .67619 L p .707 .577 .707 r
F P
0 g
s
.79212 .62626 m .80103 .56973 L .7724 .56355 L p .707 .577 .707 r
F P
0 g
s
.23408 .67561 m .2345 .71237 L .20512 .71638 L p .707 .577 .707 r
F P
0 g
s
.2345 .71237 m .23408 .67561 L .26592 .67443 L p .707 .577 .707 r
F P
0 g
s
.39521 .25759 m .3772 .76938 L .35417 .77574 L p .707 .577 .707 r
F P
0 g
s
.3772 .76938 m .39521 .25759 L .4291 .25326 L p .707 .577 .707 r
F P
0 g
s
.26592 .67443 m .26633 .71119 L .2345 .71237 L p .707 .577 .707 r
F P
0 g
s
.80103 .56973 m .79212 .62626 L .81522 .63266 L p .707 .577 .707 r
F P
0 g
s
.1886 .76702 m .18742 .74954 L .21133 .73946 L p .707 .577 .707 r
F P
0 g
s
.73303 .72537 m .73261 .68861 L .70144 .68685 L p .707 .577 .707 r
F P
0 g
s
.73261 .68861 m .73303 .72537 L .76486 .72419 L p .707 .577 .707 r
F P
0 g
s
.76486 .72419 m .76445 .68743 L .73261 .68861 L p .707 .577 .707 r
F P
0 g
s
.66088 .55158 m .65198 .60811 L .67352 .60842 L p .707 .577 .707 r
F P
0 g
s
.67352 .60842 m .68243 .55189 L .66088 .55158 L p .707 .577 .707 r
F P
0 g
s
.81522 .63266 m .82412 .57613 L .80103 .56973 L p .707 .577 .707 r
F P
0 g
s
.21133 .73946 m .2125 .75694 L .1886 .76702 L p .707 .577 .707 r
F P
0 g
s
.76445 .68743 m .76486 .72419 L .79424 .72018 L p .707 .577 .707 r
F P
0 g
s
.79424 .72018 m .79383 .68342 L .76445 .68743 L p .707 .577 .707 r
F P
0 g
s
.33099 .73582 m .33216 .75331 L .30468 .74814 L p .707 .577 .707 r
F P
0 g
s
.30468 .74814 m .3035 .73065 L .33099 .73582 L p .707 .577 .707 r
F P
0 g
s
.70186 .72361 m .70144 .68685 L .67398 .68232 L p .707 .577 .707 r
F P
0 g
s
.70144 .68685 m .70186 .72361 L .73303 .72537 L p .707 .577 .707 r
F P
0 g
s
.59822 .26103 m .58021 .77283 L .54143 .76726 L p .707 .577 .707 r
F P
0 g
s
.54143 .76726 m .55944 .25547 L .59822 .26103 L p .707 .577 .707 r
F P
0 g
s
.2125 .75694 m .21133 .73946 L .24059 .73256 L p .707 .577 .707 r
F P
0 g
s
.79383 .68342 m .79424 .72018 L .81829 .71373 L p .707 .577 .707 r
F P
0 g
s
.81829 .71373 m .81788 .67697 L .79383 .68342 L p .707 .577 .707 r
F P
0 g
s
.82412 .57613 m .81522 .63266 L .83053 .63864 L p .707 .577 .707 r
F P
0 g
s
.67398 .68232 m .6744 .71908 L .70186 .72361 L p .707 .577 .707 r
F P
0 g
s
.3035 .73065 m .30468 .74814 L .27353 .74701 L p .707 .577 .707 r
F P
0 g
s
.27353 .74701 m .27236 .72953 L .3035 .73065 L p .707 .577 .707 r
F P
0 g
s
.24059 .73256 m .24177 .75005 L .2125 .75694 L p .707 .577 .707 r
F P
0 g
s
.4111 .76505 m .4291 .25326 L .47053 .25139 L p .707 .577 .707 r
F P
0 g
s
.4291 .25326 m .4111 .76505 L .3772 .76938 L p .707 .577 .707 r
F P
0 g
s
.6744 .71908 m .67398 .68232 L .65293 .67546 L p .707 .577 .707 r
F P
0 g
s
.83053 .63864 m .83943 .58211 L .82412 .57613 L p .707 .577 .707 r
F P
0 g
s
.24177 .75005 m .24059 .73256 L .27236 .72953 L p .707 .577 .707 r
F P
0 g
s
.64753 .55326 m .63862 .60978 L .65198 .60811 L p .707 .577 .707 r
F P
0 g
s
.65198 .60811 m .66088 .55158 L .64753 .55326 L p .707 .577 .707 r
F P
0 g
s
.27236 .72953 m .27353 .74701 L .24177 .75005 L p .707 .577 .707 r
F P
0 g
s
.65293 .67546 m .65334 .71222 L .6744 .71908 L p .707 .577 .707 r
F P
0 g
s
.55944 .25547 m .54143 .76726 L .49744 .76394 L p .707 .577 .707 r
F P
0 g
s
.49744 .76394 m .51544 .25215 L .55944 .25547 L p .707 .577 .707 r
F P
0 g
s
.81788 .67697 m .81829 .71373 L .83466 .70548 L p .707 .577 .707 r
F P
0 g
s
.83466 .70548 m .83424 .66872 L .81788 .67697 L p .707 .577 .707 r
F P
0 g
s
.74119 .76268 m .74001 .74519 L .70886 .74407 L p .707 .577 .707 r
F P
0 g
s
.74001 .74519 m .74119 .76268 L .77295 .75964 L p .707 .577 .707 r
F P
0 g
s
.77295 .75964 m .77177 .74216 L .74001 .74519 L p .707 .577 .707 r
F P
0 g
s
.77177 .74216 m .77295 .75964 L .80222 .75275 L p .707 .577 .707 r
F P
0 g
s
.80222 .75275 m .80104 .73527 L .77177 .74216 L p .707 .577 .707 r
F P
0 g
s
.45253 .76318 m .47053 .25139 L .51544 .25215 L p .707 .577 .707 r
F P
0 g
s
.47053 .25139 m .45253 .76318 L .4111 .76505 L p .707 .577 .707 r
F P
0 g
s
.71004 .76155 m .70886 .74407 L .68138 .7389 L p .707 .577 .707 r
F P
0 g
s
.70886 .74407 m .71004 .76155 L .74119 .76268 L p .707 .577 .707 r
F P
0 g
s
.83943 .58211 m .83053 .63864 L .83655 .64363 L p .707 .577 .707 r
F P
0 g
s
.51544 .25215 m .49744 .76394 L .45253 .76318 L p .707 .577 .707 r
F P
0 g
s
.65334 .71222 m .65293 .67546 L .64033 .66694 L p .707 .577 .707 r
F P
0 g
s
.80104 .73527 m .80222 .75275 L .82612 .74267 L p .707 .577 .707 r
F P
0 g
s
.82612 .74267 m .82495 .72519 L .80104 .73527 L p .707 .577 .707 r
F P
0 g
s
.68138 .7389 m .68256 .75638 L .71004 .76155 L p .707 .577 .707 r
F P
0 g
s
.83655 .64363 m .84545 .5871 L .83943 .58211 L p .707 .577 .707 r
F P
0 g
s
.64368 .55676 m .63477 .61329 L .63862 .60978 L p .707 .577 .707 r
F P
0 g
s
.63862 .60978 m .64753 .55326 L .64368 .55676 L p .707 .577 .707 r
F P
0 g
s
.64033 .66694 m .64075 .7037 L .65334 .71222 L p .707 .577 .707 r
F P
0 g
s
.68256 .75638 m .68138 .7389 L .66025 .73019 L p .707 .577 .707 r
F P
0 g
s
.83424 .66872 m .83466 .70548 L .84173 .69624 L p .707 .577 .707 r
F P
0 g
s
.84173 .69624 m .84132 .65948 L .83424 .66872 L p .707 .577 .707 r
F P
0 g
s
.66025 .73019 m .66143 .74767 L .68256 .75638 L p .707 .577 .707 r
F P
0 g
s
.82495 .72519 m .82612 .74267 L .84233 .7304 L p .707 .577 .707 r
F P
0 g
s
.84233 .7304 m .84116 .71291 L .82495 .72519 L p .707 .577 .707 r
F P
0 g
s
.64075 .7037 m .64033 .66694 L .63743 .65761 L p .707 .577 .707 r
F P
0 g
s
.84545 .5871 m .83655 .64363 L .83269 .64714 L p .707 .577 .707 r
F P
0 g
s
.66143 .74767 m .66025 .73019 L .64754 .71879 L p .707 .577 .707 r
F P
0 g
s
.83269 .64714 m .8416 .59061 L .84545 .5871 L p .707 .577 .707 r
F P
0 g
s
.6497 .56175 m .64079 .61828 L .63477 .61329 L p .707 .577 .707 r
F P
0 g
s
.63477 .61329 m .64368 .55676 L .6497 .56175 L p .707 .577 .707 r
F P
0 g
s
.63743 .65761 m .63785 .69437 L .64075 .7037 L p .707 .577 .707 r
F P
0 g
s
.64754 .71879 m .64872 .73628 L .66143 .74767 L p .707 .577 .707 r
F P
0 g
s
.84132 .65948 m .84173 .69624 L .83883 .6869 L p .707 .577 .707 r
F P
0 g
s
.83883 .6869 m .83842 .65014 L .84132 .65948 L p .707 .577 .707 r
F P
0 g
s
.84116 .71291 m .84233 .7304 L .84926 .71712 L p .707 .577 .707 r
F P
0 g
s
.84926 .71712 m .84808 .69964 L .84116 .71291 L p .707 .577 .707 r
F P
0 g
s
.63785 .69437 m .63743 .65761 L .64451 .64836 L p .707 .577 .707 r
F P
0 g
s
.8416 .59061 m .83269 .64714 L .81934 .64881 L p .707 .577 .707 r
F P
0 g
s
.64872 .73628 m .64754 .71879 L .6445 .70582 L p .707 .577 .707 r
F P
0 g
s
.36704 .51736 m .35814 .57388 L .38914 .5779 L p .707 .577 .707 r
F P
0 g
s
.38914 .5779 m .39805 .52137 L .36704 .51736 L p .707 .577 .707 r
F P
0 g
s
.39805 .52137 m .38914 .5779 L .42049 .58326 L p .707 .577 .707 r
F P
0 g
s
.81934 .64881 m .82825 .59228 L .8416 .59061 L p .707 .577 .707 r
F P
0 g
s
.42049 .58326 m .4294 .52673 L .39805 .52137 L p .707 .577 .707 r
F P
0 g
s
.4294 .52673 m .42049 .58326 L .44911 .58944 L p .707 .577 .707 r
F P
0 g
s
.6445 .70582 m .64568 .72331 L .64872 .73628 L p .707 .577 .707 r
F P
0 g
s
.64451 .64836 m .64492 .68512 L .63785 .69437 L p .707 .577 .707 r
F P
0 g
s
.66501 .56774 m .6561 .62426 L .64079 .61828 L p .707 .577 .707 r
F P
0 g
s
.64079 .61828 m .6497 .56175 L .66501 .56774 L p .707 .577 .707 r
F P
0 g
s
.33942 .51508 m .33051 .57161 L .35814 .57388 L p .707 .577 .707 r
F P
0 g
s
.35814 .57388 m .36704 .51736 L .33942 .51508 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84808 .69964 m .84926 .71712 L .84621 .70415 L p .707 .577 .707 r
F P
0 g
s
.84621 .70415 m .84504 .68667 L .84808 .69964 L p .707 .577 .707 r
F P
0 g
s
.44911 .58944 m .45802 .53291 L .4294 .52673 L p .707 .577 .707 r
F P
0 g
s
.83842 .65014 m .83883 .6869 L .82624 .67838 L p .707 .577 .707 r
F P
0 g
s
.82624 .67838 m .82582 .64162 L .83842 .65014 L p .707 .577 .707 r
F P
0 g
s
.45802 .53291 m .44911 .58944 L .47221 .59584 L p .707 .577 .707 r
F P
0 g
s
.39002 .68856 m .3896 .6518 L .35843 .65004 L p .707 .577 .707 r
F P
0 g
s
.3896 .6518 m .39002 .68856 L .42185 .68737 L p .707 .577 .707 r
F P
0 g
s
.42185 .68737 m .42144 .65061 L .3896 .6518 L p .707 .577 .707 r
F P
0 g
s
.31787 .51476 m .30897 .57129 L .33051 .57161 L p .707 .577 .707 r
F P
0 g
s
.33051 .57161 m .33942 .51508 L .31787 .51476 L p .707 .577 .707 r
F P
0 g
s
.47221 .59584 m .48111 .53931 L .45802 .53291 L p .707 .577 .707 r
F P
0 g
s
.64492 .68512 m .64451 .64836 L .66087 .64011 L p .707 .577 .707 r
F P
0 g
s
.82825 .59228 m .81934 .64881 L .7978 .6485 L p .707 .577 .707 r
F P
0 g
s
.42144 .65061 m .42185 .68737 L .45123 .68336 L p .707 .577 .707 r
F P
0 g
s
.45123 .68336 m .45082 .6466 L .42144 .65061 L p .707 .577 .707 r
F P
0 g
s
.64568 .72331 m .6445 .70582 L .65142 .69255 L p .707 .577 .707 r
F P
0 g
s
.35885 .6868 m .35843 .65004 L .33097 .6455 L p .707 .577 .707 r
F P
0 g
s
.35843 .65004 m .35885 .6868 L .39002 .68856 L p .707 .577 .707 r
F P
0 g
s
.7978 .6485 m .80671 .59197 L .82825 .59228 L p .707 .577 .707 r
F P
0 g
s
.6881 .57413 m .6792 .63066 L .6561 .62426 L p .707 .577 .707 r
F P
0 g
s
.6561 .62426 m .66501 .56774 L .6881 .57413 L p .707 .577 .707 r
F P
0 g
s
.65142 .69255 m .6526 .71003 L .64568 .72331 L p .707 .577 .707 r
F P
0 g
s
.66087 .64011 m .66129 .67687 L .64492 .68512 L p .707 .577 .707 r
F P
0 g
s
.45082 .6466 m .45123 .68336 L .47528 .67692 L p .707 .577 .707 r
F P
0 g
s
.47528 .67692 m .47487 .64016 L .45082 .6466 L p .707 .577 .707 r
F P
0 g
s
.48111 .53931 m .47221 .59584 L .48752 .60183 L p .707 .577 .707 r
F P
0 g
s
.84504 .68667 m .84621 .70415 L .83351 .69275 L p .707 .577 .707 r
F P
0 g
s
.83351 .69275 m .83233 .67527 L .84504 .68667 L p .707 .577 .707 r
F P
0 g
s
.82582 .64162 m .82624 .67838 L .80518 .67152 L p .707 .577 .707 r
F P
0 g
s
.80518 .67152 m .80476 .63476 L .82582 .64162 L p .707 .577 .707 r
F P
0 g
s
.33097 .6455 m .33139 .68226 L .35885 .6868 L p .707 .577 .707 r
F P
0 g
s
.33139 .68226 m .33097 .6455 L .30992 .63864 L p .707 .577 .707 r
F P
0 g
s
.48752 .60183 m .49642 .5453 L .48111 .53931 L p .707 .577 .707 r
F P
0 g
s
.30452 .51644 m .29561 .57297 L .30897 .57129 L p .707 .577 .707 r
F P
0 g
s
.30897 .57129 m .31787 .51476 L .30452 .51644 L p .707 .577 .707 r
F P
0 g
s
.80671 .59197 m .7978 .6485 L .77017 .64622 L p .707 .577 .707 r
F P
0 g
s
.66129 .67687 m .66087 .64011 L .68492 .63366 L p .707 .577 .707 r
F P
0 g
s
.6526 .71003 m .65142 .69255 L .66763 .68027 L p .707 .577 .707 r
F P
0 g
s
.71673 .58031 m .70782 .63684 L .6792 .63066 L p .707 .577 .707 r
F P
0 g
s
.6792 .63066 m .6881 .57413 L .71673 .58031 L p .707 .577 .707 r
F P
0 g
s
.77017 .64622 m .77908 .58969 L .80671 .59197 L p .707 .577 .707 r
F P
0 g
s
.30992 .63864 m .31033 .6754 L .33139 .68226 L p .707 .577 .707 r
F P
0 g
s
.47487 .64016 m .47528 .67692 L .49165 .66867 L p .707 .577 .707 r
F P
0 g
s
.49165 .66867 m .49123 .63191 L .47487 .64016 L p .707 .577 .707 r
F P
0 g
s
.39818 .72586 m .397 .70838 L .36585 .70725 L p .707 .577 .707 r
F P
0 g
s
.397 .70838 m .39818 .72586 L .42994 .72283 L p .707 .577 .707 r
F P
0 g
s
.42994 .72283 m .42876 .70534 L .397 .70838 L p .707 .577 .707 r
F P
0 g
s
.42876 .70534 m .42994 .72283 L .45921 .71593 L p .707 .577 .707 r
F P
0 g
s
.45921 .71593 m .45803 .69845 L .42876 .70534 L p .707 .577 .707 r
F P
0 g
s
.68492 .63366 m .68534 .67042 L .66129 .67687 L p .707 .577 .707 r
F P
0 g
s
.66763 .68027 m .66881 .69776 L .6526 .71003 L p .707 .577 .707 r
F P
0 g
s
.80476 .63476 m .80518 .67152 L .77772 .66699 L p .707 .577 .707 r
F P
0 g
s
.77772 .66699 m .7773 .63023 L .80476 .63476 L p .707 .577 .707 r
F P
0 g
s
.77908 .58969 m .77017 .64622 L .73917 .6422 L p .707 .577 .707 r
F P
0 g
s
.36703 .72474 m .36585 .70725 L .33837 .70209 L p .707 .577 .707 r
F P
0 g
s
.36585 .70725 m .36703 .72474 L .39818 .72586 L p .707 .577 .707 r
F P
0 g
s
.49642 .5453 m .48752 .60183 L .49354 .60682 L p .707 .577 .707 r
F P
0 g
s
.83233 .67527 m .83351 .69275 L .81238 .68404 L p .707 .577 .707 r
F P
0 g
s
.81238 .68404 m .8112 .66656 L .83233 .67527 L p .707 .577 .707 r
F P
0 g
s
.74808 .58568 m .73917 .6422 L .70782 .63684 L p .707 .577 .707 r
F P
0 g
s
.70782 .63684 m .71673 .58031 L .74808 .58568 L p .707 .577 .707 r
F P
0 g
s
.31033 .6754 m .30992 .63864 L .29732 .63013 L p .707 .577 .707 r
F P
0 g
s
.45803 .69845 m .45921 .71593 L .48311 .70586 L p .707 .577 .707 r
F P
0 g
s
.48311 .70586 m .48194 .68837 L .45803 .69845 L p .707 .577 .707 r
F P
0 g
s
.68534 .67042 m .68492 .63366 L .7143 .62965 L p .707 .577 .707 r
F P
0 g
s
.73917 .6422 m .74808 .58568 L .77908 .58969 L p .707 .577 .707 r
F P
0 g
s
.33837 .70209 m .33955 .71957 L .36703 .72474 L p .707 .577 .707 r
F P
0 g
s
.49354 .60682 m .50244 .55029 L .49642 .5453 L p .707 .577 .707 r
F P
0 g
s
.30067 .51994 m .29176 .57647 L .29561 .57297 L p .707 .577 .707 r
F P
0 g
s
.29561 .57297 m .30452 .51644 L .30067 .51994 L p .707 .577 .707 r
F P
0 g
s
.7773 .63023 m .77772 .66699 L .74655 .66523 L p .707 .577 .707 r
F P
0 g
s
.74655 .66523 m .74613 .62847 L .7773 .63023 L p .707 .577 .707 r
F P
0 g
s
.66881 .69776 m .66763 .68027 L .69154 .67019 L p .707 .577 .707 r
F P
0 g
s
.29732 .63013 m .29774 .66689 L .31033 .6754 L p .707 .577 .707 r
F P
0 g
s
.33955 .71957 m .33837 .70209 L .31724 .69337 L p .707 .577 .707 r
F P
0 g
s
.7143 .62965 m .71471 .66641 L .68534 .67042 L p .707 .577 .707 r
F P
0 g
s
.71471 .66641 m .7143 .62965 L .74613 .62847 L p .707 .577 .707 r
F P
0 g
s
.49123 .63191 m .49165 .66867 L .49872 .65942 L p .707 .577 .707 r
F P
0 g
s
.49872 .65942 m .49831 .62266 L .49123 .63191 L p .707 .577 .707 r
F P
0 g
s
.74613 .62847 m .74655 .66523 L .71471 .66641 L p .707 .577 .707 r
F P
0 g
s
.69154 .67019 m .69272 .68768 L .66881 .69776 L p .707 .577 .707 r
F P
0 g
s
.31724 .69337 m .31842 .71086 L .33955 .71957 L p .707 .577 .707 r
F P
0 g
s
.8112 .66656 m .81238 .68404 L .78489 .67887 L p .707 .577 .707 r
F P
0 g
s
.78489 .67887 m .78372 .66139 L .8112 .66656 L p .707 .577 .707 r
F P
0 g
s
.48194 .68837 m .48311 .70586 L .49932 .69358 L p .707 .577 .707 r
F P
0 g
s
.49932 .69358 m .49815 .6761 L .48194 .68837 L p .707 .577 .707 r
F P
0 g
s
.29774 .66689 m .29732 .63013 L .29442 .62079 L p .707 .577 .707 r
F P
0 g
s
.50244 .55029 m .49354 .60682 L .48968 .61032 L p .707 .577 .707 r
F P
0 g
s
.69272 .68768 m .69154 .67019 L .72081 .6633 L p .707 .577 .707 r
F P
0 g
s
.31842 .71086 m .31724 .69337 L .30453 .68198 L p .707 .577 .707 r
F P
0 g
s
.78372 .66139 m .78489 .67887 L .75375 .67775 L p .707 .577 .707 r
F P
0 g
s
.75375 .67775 m .75257 .66027 L .78372 .66139 L p .707 .577 .707 r
F P
0 g
s
.48968 .61032 m .49859 .55379 L .50244 .55029 L p .707 .577 .707 r
F P
0 g
s
.72081 .6633 m .72199 .68078 L .69272 .68768 L p .707 .577 .707 r
F P
0 g
s
.30669 .52493 m .29778 .58146 L .29176 .57647 L p .707 .577 .707 r
F P
0 g
s
.29176 .57647 m .30067 .51994 L .30669 .52493 L p .707 .577 .707 r
F P
0 g
s
.29442 .62079 m .29483 .65755 L .29774 .66689 L p .707 .577 .707 r
F P
0 g
s
.72199 .68078 m .72081 .6633 L .75257 .66027 L p .707 .577 .707 r
F P
0 g
s
.30453 .68198 m .30571 .69946 L .31842 .71086 L p .707 .577 .707 r
F P
0 g
s
.75257 .66027 m .75375 .67775 L .72199 .68078 L p .707 .577 .707 r
F P
0 g
s
.49831 .62266 m .49872 .65942 L .49582 .65008 L p .707 .577 .707 r
F P
0 g
s
.49582 .65008 m .49541 .61332 L .49831 .62266 L p .707 .577 .707 r
F P
0 g
s
.49815 .6761 m .49932 .69358 L .50625 .68031 L p .707 .577 .707 r
F P
0 g
s
.50625 .68031 m .50507 .66282 L .49815 .6761 L p .707 .577 .707 r
F P
0 g
s
.29483 .65755 m .29442 .62079 L .3015 .61154 L p .707 .577 .707 r
F P
0 g
s
.49859 .55379 m .48968 .61032 L .47633 .612 L p .707 .577 .707 r
F P
0 g
s
.30571 .69946 m .30453 .68198 L .30149 .66901 L p .707 .577 .707 r
F P
0 g
s
.47633 .612 m .48524 .55547 L .49859 .55379 L p .707 .577 .707 r
F P
0 g
s
.30149 .66901 m .30267 .68649 L .30571 .69946 L p .707 .577 .707 r
F P
0 g
s
.3015 .61154 m .30191 .6483 L .29483 .65755 L p .707 .577 .707 r
F P
0 g
s
.322 .53092 m .31309 .58745 L .29778 .58146 L p .707 .577 .707 r
F P
0 g
s
.29778 .58146 m .30669 .52493 L .322 .53092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50507 .66282 m .50625 .68031 L .5032 .66734 L p .707 .577 .707 r
F P
0 g
s
.5032 .66734 m .50203 .64985 L .50507 .66282 L p .707 .577 .707 r
F P
0 g
s
.49541 .61332 m .49582 .65008 L .48323 .64157 L p .707 .577 .707 r
F P
0 g
s
.48323 .64157 m .48281 .60481 L .49541 .61332 L p .707 .577 .707 r
F P
0 g
s
.30191 .6483 m .3015 .61154 L .31786 .60329 L p .707 .577 .707 r
F P
0 g
s
.48524 .55547 m .47633 .612 L .45479 .61168 L p .707 .577 .707 r
F P
0 g
s
.30267 .68649 m .30149 .66901 L .30841 .65573 L p .707 .577 .707 r
F P
0 g
s
.45479 .61168 m .4637 .55515 L .48524 .55547 L p .707 .577 .707 r
F P
0 g
s
.34509 .53732 m .33619 .59385 L .31309 .58745 L p .707 .577 .707 r
F P
0 g
s
.31309 .58745 m .322 .53092 L .34509 .53732 L p .707 .577 .707 r
F P
0 g
s
.30841 .65573 m .30959 .67322 L .30267 .68649 L p .707 .577 .707 r
F P
0 g
s
.31786 .60329 m .31828 .64005 L .30191 .6483 L p .707 .577 .707 r
F P
0 g
s
.50203 .64985 m .5032 .66734 L .4905 .65594 L p .707 .577 .707 r
F P
0 g
s
.4905 .65594 m .48932 .63846 L .50203 .64985 L p .707 .577 .707 r
F P
0 g
s
.48281 .60481 m .48323 .64157 L .46217 .63471 L p .707 .577 .707 r
F P
0 g
s
.46217 .63471 m .46175 .59795 L .48281 .60481 L p .707 .577 .707 r
F P
0 g
s
.4637 .55515 m .45479 .61168 L .42716 .6094 L p .707 .577 .707 r
F P
0 g
s
.31828 .64005 m .31786 .60329 L .34191 .59685 L p .707 .577 .707 r
F P
0 g
s
.30959 .67322 m .30841 .65573 L .32462 .64346 L p .707 .577 .707 r
F P
0 g
s
.37372 .5435 m .36481 .60003 L .33619 .59385 L p .707 .577 .707 r
F P
0 g
s
.33619 .59385 m .34509 .53732 L .37372 .5435 L p .707 .577 .707 r
F P
0 g
s
.42716 .6094 m .43607 .55288 L .4637 .55515 L p .707 .577 .707 r
F P
0 g
s
.34191 .59685 m .34233 .63361 L .31828 .64005 L p .707 .577 .707 r
F P
0 g
s
.32462 .64346 m .3258 .66094 L .30959 .67322 L p .707 .577 .707 r
F P
0 g
s
.46175 .59795 m .46217 .63471 L .43471 .63018 L p .707 .577 .707 r
F P
0 g
s
.43471 .63018 m .43429 .59342 L .46175 .59795 L p .707 .577 .707 r
F P
0 g
s
.43607 .55288 m .42716 .6094 L .39616 .60539 L p .707 .577 .707 r
F P
0 g
s
.48932 .63846 m .4905 .65594 L .46937 .64723 L p .707 .577 .707 r
F P
0 g
s
.46937 .64723 m .46819 .62975 L .48932 .63846 L p .707 .577 .707 r
F P
0 g
s
.40506 .54886 m .39616 .60539 L .36481 .60003 L p .707 .577 .707 r
F P
0 g
s
.36481 .60003 m .37372 .5435 L .40506 .54886 L p .707 .577 .707 r
F P
0 g
s
.34233 .63361 m .34191 .59685 L .37129 .59284 L p .707 .577 .707 r
F P
0 g
s
.39616 .60539 m .40506 .54886 L .43607 .55288 L p .707 .577 .707 r
F P
0 g
s
.43429 .59342 m .43471 .63018 L .40354 .62841 L p .707 .577 .707 r
F P
0 g
s
.40354 .62841 m .40312 .59165 L .43429 .59342 L p .707 .577 .707 r
F P
0 g
s
.3258 .66094 m .32462 .64346 L .34853 .63338 L p .707 .577 .707 r
F P
0 g
s
.37129 .59284 m .3717 .6296 L .34233 .63361 L p .707 .577 .707 r
F P
0 g
s
.3717 .6296 m .37129 .59284 L .40312 .59165 L p .707 .577 .707 r
F P
0 g
s
.40312 .59165 m .40354 .62841 L .3717 .6296 L p .707 .577 .707 r
F P
0 g
s
.34853 .63338 m .34971 .65086 L .3258 .66094 L p .707 .577 .707 r
F P
0 g
s
.46819 .62975 m .46937 .64723 L .44188 .64206 L p .707 .577 .707 r
F P
0 g
s
.44188 .64206 m .44071 .62458 L .46819 .62975 L p .707 .577 .707 r
F P
0 g
s
.34971 .65086 m .34853 .63338 L .3778 .62649 L p .707 .577 .707 r
F P
0 g
s
.44071 .62458 m .44188 .64206 L .41074 .64094 L p .707 .577 .707 r
F P
0 g
s
.41074 .64094 m .40956 .62345 L .44071 .62458 L p .707 .577 .707 r
F P
0 g
s
.3778 .62649 m .37897 .64397 L .34971 .65086 L p .707 .577 .707 r
F P
0 g
s
.37897 .64397 m .3778 .62649 L .40956 .62345 L p .707 .577 .707 r
F P
0 g
s
.40956 .62345 m .41074 .64094 L .37897 .64397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol0081ooaT008Aoo`00MGoo2`001EYF00<005YFFUH02UYF00<005YFFUH015YF
2@00Ngoo001_Ool60004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06001eOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@0075oo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00KGoo001WOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH4001YOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000Igoo
001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Eoo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo
001UOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001FOol?0002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP04001J
EUYFFUH:0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPX000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo00D005YF001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00E7oo00<005YFFUH00`001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001DOol0
1000FUIJEP000UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001DOol00`00FUH00004FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
00030008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001VOol005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP040008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IWoo001COol01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1P000UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000goo2`00F7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF6@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0000Eoo`00001JEP0000EJEP04001JEUYFFUH9001?Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70018Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH600000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040014
Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF1000@7oo001BOol01000FUIJEP0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00
00<003aoo`00DWoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00
FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000fOol0059oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP02FUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<Woo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF00000`0025YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00<7oo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P00;Woo001FOol200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;7oo001HOol40003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01EYF
00<005YFFUH00UYF0`00;7oo001LOol50005FUHG0005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd00003FUH0000002aoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
000010001UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Goo001IOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000bOol;000HOol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000_Ool300000eYF001JEP04FUH01000
FUIJEUYF2@003Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70007Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ioo`<00003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005
Ool00000FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH?0004FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool0
1000FUIJEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00001000
1EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo
100000=JEP00FUH01UYF00<005YFFUH015YF20000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P002Woo0`0015YF2@0015YF00@005YFFUIJEPP000=JEP03001J
EUYF00=JEP04001JEUYFFUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEPD00003FUH0
05YF00MJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00=JEPH000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH60003FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH01000FUIJEUYF1`000eYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF00001@0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000eYF00<0
07ooOol0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04
0008FUH200000eYF001JEP02FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP03FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF0000000_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60002FUH200000eYF001JEP020002FUH20006FUH00`00FUIJEP04FUH6
0005FUH00`00FUIJEP06FUH50002FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF100000AJEP00001JEP<0
0003FUH005YF00EJEP03001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03
001JEUYF00@000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000goo00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP05001J
EUYFFUH00005FUH40004FUH@0006FUH00`00FUIJEP03FUH400001EYF001JEUYF00002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF00<005YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP800003FUH0000000AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00=JEPT000=JEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP800003FUH0000000=JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@002UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH00UYF20000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00:goo00@005YF
FUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009J
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00@005YFFUIJEP8002eoo`00:goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP<00003FUH005YF009JEP8002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF2@000eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YF0000009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002eoo`00;7oo0`000eYF00<005YF
FUH015YF00<005YFFUH00eYF200015YF00<005YFFUH00UYF1P0000AJEP00000000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009J
EP80009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH0000002eoo`00;goo0P0000=JEP00FUH01EYF1P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001P0000=JEP00FUH01UYF00<005YFFUH01EYF10001EYF00<005YF
FUH01UYF00<005YF00000`001EYF0`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0000=JEP00FUH01P001EYF00<005YFFUH015YF1`002Goo20000eYF00<005YF
FUH00eYF1000;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH0000015YF1P0015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF1P00
1eYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000AJEP00
0000009JEP8000IJEP03001JEUYF00@001=oo`T000EJEP04001JEP00000]Ool0039oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP02
FUHK0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH300000eYF001JEP05FUHJ0003FUH00`00FUIJEP03FUH20003FUH0
1@00FUIJEUYF0000;7oo000`Ool200000eYF001JEP03FUH00`00FUH00007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP001EYF0P0000=JEP00FUH01EYF00<005YF0000
10000UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF0P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH005YF009JEP03001o
ogoo02Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`001EYF0P0000=JEP00FUH01EYF00<005YFFUH00`000eYF00<005YF
FUH02EYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF100000=JEP00000015YF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002]oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0eYF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH025YF1000
1EYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40000
0eYF00000004FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP02000[Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH50000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04FUH30002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF1@00:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000<000IJ
EP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH000000003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000Woo0P00
:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000
FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP000003Ool3000[Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQL000AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30005Ool00`00FUH0000[Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEPH001Moo`@0009JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH0000000D00003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00EJEP03001JEP0000<000Moo`800003FUH007oo02Yoo`00;7oo00<005YF000015YF00<005YF0000
0`008Goo20001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000UYF200015YF
00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1@002Goo0P0000=JEP000000;7oo000/Ool00`00
FUH00003FUH3000COol3000COol80002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30000
15YF000000000eYF00<005YFFUH0300015YF3P003Goo00@005YFFUIJEP8002aoo`00;7oo00@005YF
001JEP800004FUH00000000AOol5000?Ool3000025YF001JEUYF001JEP00FUH@000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF
000005YF00000UYF00<005YFFUH00eYF0P0000=JEP00000017oo2@0057oo0P0015YF00<007ooOol0
:goo000/Ool01P00FUH00000FUH000AJEPD000aooa@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP0000000UYF00<005YF00001EYF00<005YF00000P002Goo
0`004goo0P0000=JEP00FUH00eYF00<007ooOol0:goo000/Ool20003FUH00`00FUIJEP03FUH01000
FUIJEUYF3P0015YF00<005YFFUH01UYF00<005YF00000`000eYF00H005YFFUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2000015YF001JEP000UYF0`001EYF00D005YFFUIJEP0001eoo`80
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPD00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP800004FUH005YF0002FUH00`00FUIJEP020003FUH01@00FUIJEUYF0000
6Woo0`001EYF00@005YF000002moo`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00002FUH01000FUIJEP000eYF1@000UYF
0P005Goo100000=JEP00FUH01EYF0P00<Goo000/Ool20003FUH00`00FUIJEP03FUH01P00FUH00000
FUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP04001JEUYFFUHI
0005FUH00`00FUIJEP04FUH00`00Oomoo`0`Ool002eoo`05001JEUYFFUH00005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH?0006FUH01`00FUH005YF001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002eoo`05001JEUYFFUH00003
FUH20005FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000eOol002ioo`800003FUH005YF00<0
00IJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`L00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Moo`00<7oo0`000UYF00<005YFFUH00eYF
1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01000>goo000`Ool00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@00004Ool005YF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000:Ool60002FUHH000oOol002moo`8000AJEP03001JEP0000<000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000Eoo`03001JEP0000IJEP03001JEUYF009J
ER<000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`D000=JEP03001J
EUYF00800003FUH0000005Aoo`00;goo0P0015YF0P0017oo200015YF00<005YFFUH00UYF2@003Goo
00<005YF00001EYF1`002UYF00<005YFFUH02UYF00<005YFFUH025YF30001EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001UYF00<005YFFUH00UYF0`00E7oo000^Ool01000FUIJEP000UYF00<007oo
Ool037oo2@005Woo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEPP000IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH500000eYF001J
EP03FUH3001DOol002ioo`03001JEUYF00<001=oo`D001Eoo`03001JEUYF0080009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@000EJEP03
001JEP0000<0009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP<000AJEP03001JEP0005Ao
o`00;Woo00@005YFFUH001Eoo`D001Eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP800003FUH005YF00MJEP04001JEUYF
FUH40004FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUH0001DOol002ioo`03
001JEP0001Ioo`D001Eoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0P000UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1000EGoo000_Ool2000GOol3000FOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH0
00001EYF00<005YFFUH015YF1`001EYF30000eYF00<005YFFUH00eYF0`00EGoo000_Ool00`00Oomo
o`0`Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH3
0006FUH00`00FUIJEP040006FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YF00000`001EYF
00@005YF000005Aoo`00;goo0P00<7oo00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000IJEP@000UJEP03001JEUYF00=JEP04001J
EP000006FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000Dgoo000_Ool01000FUH00000;7oo
0`000eYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUH000=J
EP8000=JEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH40000
0eYF001JEP02FUH00`00Oomoo`1AOol002moo`04001JEUYFFUH2000XOol20002FUH00`00FUIJEP02
FUH40006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01@00FUIJEP00FUH00P00
1EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001eYF00<005YF00000`0017oo0P000eYF00<007oo
Ool0DGoo000_Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP04001JEUYF0004Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP020007FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH5000:Ool00`00FUIJEP02001BOol002moo`05001JEUYF
FUH00004FUH3000JOol40002FUH00`00FUIJEP04FUH30009Ool50008FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUH00009FUH00`00FUIJEP07FUH00`00FUH0000:000@Ool4001BOol0031oo`04
001JEUYF0005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000@Ool60002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP03FUH7000LOol2001BOol0035oo`<000EJ
EP03001JEUYF00=JEPl000AJEP03001JEUYF00IJEP04001JEUYFFUH2000HOol90006FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH;0003Ool5000KOol2001BOol003=oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000SOolI000>Ool5000JOol3
001BOol003Eoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<003=oo`8001Moo`D001Uoo`800003FUH007oo055oo`00>7oo0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01000=Woo0P0067oo0`0067oo0P0000AJEP00FUH0059oo`00>goo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00<Goo00@005YFFUIJEP8005=oo`00?goo
4000@Goo0P0000=JEP00Ool0;Goo0P0015YF0P00Dgoo002@Ool20002FUH00`00Oomoo`0YOol20000
0eYF001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF00<002Moo`8000=JEP05001JEUYFFUH0
001EOol0095oo`04001JEUYF0002FUH2000ROol30005FUH01000FUH00000EWoo002BOol01000FUIJ
EP000eYF1@006Goo100000=JEP00FUH01EYF0P00F7oo002COol30004FUH01000FUIJEUYF2@002Goo
1`001EYF00<005YFFUH015YF00<007ooOol0Egoo002EOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00FWoo002FOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000G7oo002H
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4001NOol0
09Yoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0069oo`00Wgoo200015YF
00<005YFFUH00UYF1`00IWoo002WOol9001]Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57285 .65043 m .56394 .70696 L .59495 .71098 L p .707 .577 .707 r
F P
0 g
s
.59495 .71098 m .60385 .65445 L .57285 .65043 L p .707 .577 .707 r
F P
0 g
s
.60385 .65445 m .59495 .71098 L .62629 .71634 L p .707 .577 .707 r
F P
0 g
s
.62629 .71634 m .6352 .65981 L .60385 .65445 L p .707 .577 .707 r
F P
0 g
s
.6352 .65981 m .62629 .71634 L .65492 .72252 L p .707 .577 .707 r
F P
0 g
s
.54522 .64815 m .53632 .70468 L .56394 .70696 L p .707 .577 .707 r
F P
0 g
s
.56394 .70696 m .57285 .65043 L .54522 .64815 L p .707 .577 .707 r
F P
0 g
s
.65492 .72252 m .66382 .66599 L .6352 .65981 L p .707 .577 .707 r
F P
0 g
s
.66382 .66599 m .65492 .72252 L .67801 .72891 L p .707 .577 .707 r
F P
0 g
s
.59583 .80815 m .59541 .77139 L .56424 .76962 L p .707 .577 .707 r
F P
0 g
s
.59541 .77139 m .59583 .80815 L .62766 .80696 L p .707 .577 .707 r
F P
0 g
s
.62766 .80696 m .62724 .7702 L .59541 .77139 L p .707 .577 .707 r
F P
0 g
s
.62724 .7702 m .62766 .80696 L .65704 .80295 L p .707 .577 .707 r
F P
0 g
s
.65704 .80295 m .65662 .76619 L .62724 .7702 L p .707 .577 .707 r
F P
0 g
s
.52368 .64784 m .51477 .70437 L .53632 .70468 L p .707 .577 .707 r
F P
0 g
s
.53632 .70468 m .54522 .64815 L .52368 .64784 L p .707 .577 .707 r
F P
0 g
s
.67801 .72891 m .68692 .67239 L .66382 .66599 L p .707 .577 .707 r
F P
0 g
s
.56465 .80638 m .56424 .76962 L .53678 .76509 L p .707 .577 .707 r
F P
0 g
s
.56424 .76962 m .56465 .80638 L .59583 .80815 L p .707 .577 .707 r
F P
0 g
s
.65662 .76619 m .65704 .80295 L .68109 .79651 L p .707 .577 .707 r
F P
0 g
s
.68109 .79651 m .68067 .75975 L .65662 .76619 L p .707 .577 .707 r
F P
0 g
s
.53678 .76509 m .5372 .80185 L .56465 .80638 L p .707 .577 .707 r
F P
0 g
s
.68692 .67239 m .67801 .72891 L .69332 .7349 L p .707 .577 .707 r
F P
0 g
s
.5372 .80185 m .53678 .76509 L .51572 .75823 L p .707 .577 .707 r
F P
0 g
s
.69332 .7349 m .70223 .67837 L .68692 .67239 L p .707 .577 .707 r
F P
0 g
s
.51033 .64951 m .50142 .70604 L .51477 .70437 L p .707 .577 .707 r
F P
0 g
s
.51477 .70437 m .52368 .64784 L .51033 .64951 L p .707 .577 .707 r
F P
0 g
s
.51572 .75823 m .51614 .79499 L .5372 .80185 L p .707 .577 .707 r
F P
0 g
s
.68067 .75975 m .68109 .79651 L .69745 .78826 L p .707 .577 .707 r
F P
0 g
s
.69745 .78826 m .69703 .7515 L .68067 .75975 L p .707 .577 .707 r
F P
0 g
s
.60398 .86875 m .60281 .85127 L .57166 .85015 L p .707 .577 .707 r
F P
0 g
s
.60281 .85127 m .60398 .86875 L .63574 .86572 L p .707 .577 .707 r
F P
0 g
s
.63574 .86572 m .63457 .84824 L .60281 .85127 L p .707 .577 .707 r
F P
0 g
s
.63457 .84824 m .63574 .86572 L .66501 .85883 L p .707 .577 .707 r
F P
0 g
s
.66501 .85883 m .66383 .84134 L .63457 .84824 L p .707 .577 .707 r
F P
0 g
s
.51614 .79499 m .51572 .75823 L .50313 .74972 L p .707 .577 .707 r
F P
0 g
s
.70223 .67837 m .69332 .7349 L .69934 .73989 L p .707 .577 .707 r
F P
0 g
s
.57284 .86763 m .57166 .85015 L .54417 .84498 L p .707 .577 .707 r
F P
0 g
s
.57166 .85015 m .57284 .86763 L .60398 .86875 L p .707 .577 .707 r
F P
0 g
s
.69934 .73989 m .70825 .68336 L .70223 .67837 L p .707 .577 .707 r
F P
0 g
s
.66383 .84134 m .66501 .85883 L .68892 .84875 L p .707 .577 .707 r
F P
0 g
s
.68892 .84875 m .68774 .83127 L .66383 .84134 L p .707 .577 .707 r
F P
0 g
s
.54417 .84498 m .54535 .86246 L .57284 .86763 L p .707 .577 .707 r
F P
0 g
s
.50313 .74972 m .50354 .78648 L .51614 .79499 L p .707 .577 .707 r
F P
0 g
s
.50647 .65302 m .49757 .70955 L .50142 .70604 L p .707 .577 .707 r
F P
0 g
s
.50142 .70604 m .51033 .64951 L .50647 .65302 L p .707 .577 .707 r
F P
0 g
s
.69703 .7515 m .69745 .78826 L .70453 .77901 L p .707 .577 .707 r
F P
0 g
s
.70453 .77901 m .70411 .74225 L .69703 .7515 L p .707 .577 .707 r
F P
0 g
s
.54535 .86246 m .54417 .84498 L .52305 .83627 L p .707 .577 .707 r
F P
0 g
s
.52305 .83627 m .52422 .85375 L .54535 .86246 L p .707 .577 .707 r
F P
0 g
s
.68774 .83127 m .68892 .84875 L .70513 .83647 L p .707 .577 .707 r
F P
0 g
s
.70513 .83647 m .70395 .81899 L .68774 .83127 L p .707 .577 .707 r
F P
0 g
s
.50354 .78648 m .50313 .74972 L .50023 .74038 L p .707 .577 .707 r
F P
0 g
s
.70825 .68336 m .69934 .73989 L .69549 .7434 L p .707 .577 .707 r
F P
0 g
s
.69549 .7434 m .7044 .68687 L .70825 .68336 L p .707 .577 .707 r
F P
0 g
s
.50023 .74038 m .50064 .77714 L .50354 .78648 L p .707 .577 .707 r
F P
0 g
s
.52422 .85375 m .52305 .83627 L .51034 .82487 L p .707 .577 .707 r
F P
0 g
s
.5125 .65801 m .50359 .71454 L .49757 .70955 L p .707 .577 .707 r
F P
0 g
s
.49757 .70955 m .50647 .65302 L .5125 .65801 L p .707 .577 .707 r
F P
0 g
s
.70411 .74225 m .70453 .77901 L .70163 .76967 L p .707 .577 .707 r
F P
0 g
s
.70163 .76967 m .70121 .73291 L .70411 .74225 L p .707 .577 .707 r
F P
0 g
s
.47875 .81629 m .49676 .3045 L .45276 .30117 L p .707 .577 .707 r
F P
0 g
s
.50064 .77714 m .50023 .74038 L .5073 .73113 L p .707 .577 .707 r
F P
0 g
s
.51152 .84235 m .51034 .82487 L .5073 .8119 L p .707 .577 .707 r
F P
0 g
s
.5073 .73113 m .50772 .76789 L .50064 .77714 L p .707 .577 .707 r
F P
0 g
s
.5278 .664 m .5189 .72052 L .50359 .71454 L p .707 .577 .707 r
F P
0 g
s
.50359 .71454 m .5125 .65801 L .5278 .664 L p .707 .577 .707 r
F P
0 g
s
.5073 .8119 m .50847 .82938 L .51152 .84235 L p .707 .577 .707 r
F P
0 g
s
.50772 .76789 m .5073 .73113 L .52367 .72288 L p .707 .577 .707 r
F P
0 g
s
.50847 .82938 m .5073 .8119 L .51422 .79863 L p .707 .577 .707 r
F P
0 g
s
.52367 .72288 m .52408 .75964 L .50772 .76789 L p .707 .577 .707 r
F P
0 g
s
.51034 .82487 m .51152 .84235 L .52422 .85375 L p .707 .577 .707 r
F P
0 g
s
.51422 .79863 m .5154 .81611 L .50847 .82938 L p .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .51422 .79863 L .52675 .78913 L p .707 .577 .707 r
F P
0 g
s
.54199 .72692 m .5189 .72052 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.5509 .67039 m .54733 .69306 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54733 .69306 m .54199 .72692 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .49676 .3045 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .52675 .78913 L .5262 .79471 L .707 .577 .707 r
F
.5189 .72052 m .5278 .664 L .5509 .67039 L p F P
0 g
s
.54199 .72692 m .54469 .70979 L p .57952 .67657 L .707 .577 .707 r
F P
0 g
s
.54469 .70979 m .5509 .67039 L .56736 .67395 L p .707 .577 .707 r
F P
0 g
s
.56736 .67395 m .57952 .67657 L p .54469 .70979 L .707 .577 .707 r
F P
0 g
s
.61087 .68194 m .60196 .73846 L .57547 .73393 L p .707 .577 .707 r
F P
0 g
s
.57547 .73393 m .57062 .7331 L p .57765 .72416 L .707 .577 .707 r
F P
0 g
s
.57765 .72416 m .61087 .68194 L .57547 .73393 L .707 .577 .707 r
F
.64187 .68595 m .63297 .74248 L .60623 .73902 L p F P
0 g
s
.60623 .73902 m .60196 .73846 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60698 .73186 m .64187 .68595 L .60623 .73902 L .707 .577 .707 r
F
.60196 .73846 m .61087 .68194 L .61225 .68211 L p F P
0 g
s
.61225 .68211 m .64187 .68595 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60196 .73846 m .61225 .68211 L .60698 .73186 L .707 .577 .707 r
F
.64996 .28493 m .64003 .2927 L p .63763 .44218 L F P
0 g
s
.6695 .68823 m .66059 .74476 L .63297 .74248 L p .707 .577 .707 r
F P
0 g
s
.63297 .74248 m .64187 .68595 L .6695 .68823 L p .707 .577 .707 r
F P
0 g
s
.6401 .713 m .64052 .74977 L .60934 .748 L p .707 .577 .707 r
F P
0 g
s
.60934 .748 m .60893 .71124 L .6401 .713 L p .707 .577 .707 r
F P
0 g
s
.64651 .76747 m .64769 .78495 L .61654 .78383 L p .707 .577 .707 r
F P
0 g
s
.61654 .78383 m .61536 .76635 L .64651 .76747 L p .707 .577 .707 r
F P
0 g
s
.63195 .79672 m .64781 .34602 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64781 .34602 m .64996 .28493 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .63195 .79672 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64003 .2927 m .63335 .48271 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.63335 .48271 m .62202 .80449 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.57062 .7331 m .57952 .67657 L .61087 .68194 L p .707 .577 .707 r
F P
0 g
s
.57751 .74919 m .57709 .71243 L .60893 .71124 L p .707 .577 .707 r
F P
0 g
s
.60893 .71124 m .60934 .748 L .57751 .74919 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .59899 .81085 L p .59842 .79281 L .707 .577 .707 r
F P
0 g
s
.59148 .76863 m .59603 .76819 L p .59287 .77345 L .707 .577 .707 r
F P
0 g
s
.59603 .76819 m .61536 .76635 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.57709 .71243 m .57751 .74919 L .5664 .7507 L p .707 .577 .707 r
F P
0 g
s
.5664 .7507 m .54813 .7532 L p .56297 .73231 L .707 .577 .707 r
F P
0 g
s
.57952 .67657 m .57062 .7331 L .54199 .72692 L p .707 .577 .707 r
F P
0 g
s
.56297 .73231 m .57709 .71243 L .5664 .7507 L .707 .577 .707 r
F
.54813 .7532 m .54772 .71644 L .57709 .71243 L p F P
0 g
s
.57022 .66943 m .56721 .75502 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.56721 .75502 m .56509 .81517 L p .57115 .77614 L .707 .577 .707 r
F P
0 g
s
.59341 .63276 m .56721 .75502 L .57115 .77614 L .707 .577 .707 r
F
.59842 .79281 m .57905 .72528 L .56509 .81517 L F
.58478 .78686 m .59603 .76819 L .59729 .77847 L F
.61536 .76635 m .61654 .78383 L .59815 .78559 L p F P
0 g
s
.59815 .78559 m .58478 .78686 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.59729 .77847 m .61536 .76635 L .59815 .78559 L .707 .577 .707 r
F
.60659 .59461 m .59949 .79654 L p .61937 .53744 L F P
0 g
s
.59949 .79654 m .59899 .81085 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61937 .53744 m .59949 .79654 L .59984 .7994 L .707 .577 .707 r
F
.59842 .79281 m .59341 .63276 L .57905 .72528 L F
.58478 .78686 m .5836 .76938 L .59148 .76863 L p F P
0 g
s
.58478 .78686 m .59148 .76863 L .59287 .77345 L .707 .577 .707 r
F
.62202 .80449 m .61937 .53744 L .59984 .7994 L F
.59899 .81085 m .60116 .81025 L p .59984 .7994 L F P
0 g
s
.60116 .81025 m .62202 .80449 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61699 .29906 m .60659 .59461 L p .61937 .53744 L .707 .577 .707 r
F P
0 g
s
.5831 .30338 m .57022 .66943 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.52408 .75964 m .52367 .72288 L .54772 .71644 L p .707 .577 .707 r
F P
0 g
s
.54772 .71644 m .54813 .7532 L .52408 .75964 L p .707 .577 .707 r
F P
0 g
s
.52401 .81703 m .56509 .81517 L p .55206 .53137 L .707 .577 .707 r
F P
0 g
s
.53043 .78635 m .53161 .80383 L .5248 .80899 L p .707 .577 .707 r
F P
0 g
s
.5248 .80899 m .5154 .81611 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.5262 .79471 m .53043 .78635 L .5248 .80899 L .707 .577 .707 r
F
.52366 .81705 m .53072 .61639 L p .5075 .50915 L F P
0 g
s
.53072 .61639 m .54167 .30526 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.52675 .78913 m .53043 .78635 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .52366 .81705 L .52401 .81703 L p .707 .577 .707 r
F P
0 g
s
.55206 .53137 m .54167 .30526 L .52401 .81703 L .707 .577 .707 r
F
.49676 .3045 m .47875 .81629 L .52366 .81705 L p F P
0 g
s
.70395 .81899 m .70513 .83647 L .71205 .8232 L p .707 .577 .707 r
F P
0 g
s
.71205 .8232 m .71087 .80572 L .70395 .81899 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .5831 .30338 L .54167 .30526 L p .707 .577 .707 r
F P
0 g
s
.43476 .81296 m .45276 .30117 L .41399 .29561 L p .707 .577 .707 r
F P
0 g
s
.45276 .30117 m .43476 .81296 L .47875 .81629 L p .707 .577 .707 r
F P
0 g
s
.7044 .68687 m .69549 .7434 L .68214 .74507 L p .707 .577 .707 r
F P
0 g
s
.22984 .61362 m .22093 .67014 L .25194 .67416 L p .707 .577 .707 r
F P
0 g
s
.25194 .67416 m .26084 .61763 L .22984 .61362 L p .707 .577 .707 r
F P
0 g
s
.26084 .61763 m .25194 .67416 L .28329 .67952 L p .707 .577 .707 r
F P
0 g
s
.59899 .81085 m .61699 .29906 L .5831 .30338 L p .707 .577 .707 r
F P
0 g
s
.68214 .74507 m .69104 .68854 L .7044 .68687 L p .707 .577 .707 r
F P
0 g
s
.28329 .67952 m .29219 .62299 L .26084 .61763 L p .707 .577 .707 r
F P
0 g
s
.29219 .62299 m .28329 .67952 L .31191 .6857 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.20221 .61134 m .19331 .66787 L .22093 .67014 L p .707 .577 .707 r
F P
0 g
s
.22093 .67014 m .22984 .61362 L .20221 .61134 L p .707 .577 .707 r
F P
0 g
s
.70121 .73291 m .70163 .76967 L .68903 .76116 L p .707 .577 .707 r
F P
0 g
s
.68903 .76116 m .68862 .7244 L .70121 .73291 L p .707 .577 .707 r
F P
0 g
s
.31191 .6857 m .32081 .62917 L .29219 .62299 L p .707 .577 .707 r
F P
0 g
s
.39598 .8074 m .41399 .29561 L .38423 .28836 L p .707 .577 .707 r
F P
0 g
s
.41399 .29561 m .39598 .8074 L .43476 .81296 L p .707 .577 .707 r
F P
0 g
s
.71087 .80572 m .71205 .8232 L .70901 .81023 L p .707 .577 .707 r
F P
0 g
s
.70901 .81023 m .70783 .79275 L .71087 .80572 L p .707 .577 .707 r
F P
0 g
s
.32081 .62917 m .31191 .6857 L .335 .6921 L p .707 .577 .707 r
F P
0 g
s
.25282 .77133 m .2524 .73457 L .22123 .73281 L p .707 .577 .707 r
F P
0 g
s
.2524 .73457 m .25282 .77133 L .28465 .77015 L p .707 .577 .707 r
F P
0 g
s
.28465 .77015 m .28423 .73339 L .2524 .73457 L p .707 .577 .707 r
F P
0 g
s
.28423 .73339 m .28465 .77015 L .31403 .76614 L p .707 .577 .707 r
F P
0 g
s
.31403 .76614 m .31361 .72938 L .28423 .73339 L p .707 .577 .707 r
F P
0 g
s
.18067 .61102 m .17176 .66755 L .19331 .66787 L p .707 .577 .707 r
F P
0 g
s
.19331 .66787 m .20221 .61134 L .18067 .61102 L p .707 .577 .707 r
F P
0 g
s
.335 .6921 m .34391 .63557 L .32081 .62917 L p .707 .577 .707 r
F P
0 g
s
.69104 .68854 m .68214 .74507 L .66059 .74476 L p .707 .577 .707 r
F P
0 g
s
.22165 .76957 m .22123 .73281 L .19377 .72828 L p .707 .577 .707 r
F P
0 g
s
.22123 .73281 m .22165 .76957 L .25282 .77133 L p .707 .577 .707 r
F P
0 g
s
.66059 .74476 m .6695 .68823 L .69104 .68854 L p .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .64003 .2927 L .61699 .29906 L p .707 .577 .707 r
F P
0 g
s
.31361 .72938 m .31403 .76614 L .33808 .75969 L p .707 .577 .707 r
F P
0 g
s
.33808 .75969 m .33766 .72293 L .31361 .72938 L p .707 .577 .707 r
F P
0 g
s
.68862 .7244 m .68903 .76116 L .66797 .7543 L p .707 .577 .707 r
F P
0 g
s
.66797 .7543 m .66756 .71754 L .68862 .7244 L p .707 .577 .707 r
F P
0 g
s
.19377 .72828 m .19419 .76504 L .22165 .76957 L p .707 .577 .707 r
F P
0 g
s
.34391 .63557 m .335 .6921 L .35031 .69809 L p .707 .577 .707 r
F P
0 g
s
.19419 .76504 m .19377 .72828 L .17271 .72142 L p .707 .577 .707 r
F P
0 g
s
.70783 .79275 m .70901 .81023 L .6963 .79883 L p .707 .577 .707 r
F P
0 g
s
.6963 .79883 m .69512 .78135 L .70783 .79275 L p .707 .577 .707 r
F P
0 g
s
.35031 .69809 m .35922 .64156 L .34391 .63557 L p .707 .577 .707 r
F P
0 g
s
.36094 .78218 m .36212 .79966 L .36614 .79196 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .38423 .28836 L .37014 .28185 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .37014 .28185 L .36623 .78014 L .707 .577 .707 r
F
.38423 .28836 m .36622 .80015 L .39598 .8074 L p F P
0 g
s
.36619 .7849 m .36094 .78218 L .36614 .79196 L .707 .577 .707 r
F
.33766 .72293 m .33808 .75969 L .35444 .75144 L p F P
0 g
s
.35444 .75144 m .35403 .71468 L .33766 .72293 L p .707 .577 .707 r
F P
0 g
s
.35922 .64156 m .35031 .69809 L .35633 .70308 L p .707 .577 .707 r
F P
0 g
s
.35633 .70308 m .36524 .64655 L .35922 .64156 L p .707 .577 .707 r
F P
0 g
s
.35403 .71468 m .35444 .75144 L .36152 .74219 L p .707 .577 .707 r
F P
0 g
s
.36152 .74219 m .3611 .70543 L .35403 .71468 L p .707 .577 .707 r
F P
0 g
s
.36212 .79966 m .36094 .78218 L .34473 .79445 L p .707 .577 .707 r
F P
0 g
s
.36524 .64655 m .35633 .70308 L .35248 .70658 L p .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .36139 .65005 L .36524 .64655 L p .707 .577 .707 r
F P
0 g
s
.3611 .70543 m .36152 .74219 L .35862 .73286 L p .707 .577 .707 r
F P
0 g
s
.35862 .73286 m .3582 .6961 L .3611 .70543 L p .707 .577 .707 r
F P
0 g
s
.36629 .77191 m .36094 .78218 L p .36619 .7849 L .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .33913 .70826 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.36139 .65005 m .35518 .68945 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.35518 .68945 m .35248 .70658 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.3664 .28013 m .36225 .27171 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .34803 .65173 L .35371 .65102 L p .707 .577 .707 r
F P
0 g
s
.35371 .65102 m .36139 .65005 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .35371 .65102 L .35437 .66839 L .707 .577 .707 r
F
.3582 .6961 m .35862 .73286 L .35078 .72756 L p F P
0 g
s
.35078 .72756 m .34602 .72434 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.35188 .71076 m .3582 .6961 L .35078 .72756 L .707 .577 .707 r
F
.34602 .72434 m .34561 .68758 L .35306 .69262 L p F P
0 g
s
.35306 .69262 m .3582 .6961 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.34602 .72434 m .35306 .69262 L .35188 .71076 L .707 .577 .707 r
F
.34964 .74508 m .35352 .64617 L .35279 .62696 L F
.34839 .79191 m .35051 .73176 L p .34964 .74508 L F P
0 g
s
.35051 .73176 m .35352 .64617 L p .34964 .74508 L .707 .577 .707 r
F P
0 g
s
.34424 .7835 m .3468 .78868 L p .34995 .70366 L .707 .577 .707 r
F P
0 g
s
.34995 .70366 m .34563 .75799 L .34424 .7835 L .707 .577 .707 r
F
.3468 .78868 m .34839 .79191 L p .34964 .74508 L F P
0 g
s
.34964 .74508 m .35279 .62696 L .3468 .78868 L .707 .577 .707 r
F
.34557 .75883 m .3444 .75835 L p .3465 .747 L F P
0 g
s
.3444 .75835 m .33216 .75331 L p .34407 .74807 L .707 .577 .707 r
F P
0 g
s
.34407 .74807 m .3465 .747 L .3444 .75835 L .707 .577 .707 r
F
.3664 .28013 m .34839 .79191 L .36607 .80008 L p F P
0 g
s
.34687 .74237 m .35212 .74453 L p .3465 .747 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .34424 .7835 L p .34563 .75799 L .707 .577 .707 r
F P
0 g
s
.35212 .74453 m .35329 .76202 L .34557 .75883 L p .707 .577 .707 r
F P
0 g
s
.3465 .747 m .35212 .74453 L .34557 .75883 L .707 .577 .707 r
F
.34385 .74113 m .34687 .74237 L p .34396 .74454 L F P
0 g
s
.33216 .75331 m .34687 .74237 L .3465 .747 L .707 .577 .707 r
F
.34995 .70366 m .35279 .62696 L .34563 .75799 L F
.35352 .64617 m .3664 .28013 L p .35279 .62696 L F P
0 g
s
.36623 .78014 m .3664 .28013 L .36607 .80008 L .707 .577 .707 r
F
.37014 .28185 m .3664 .28013 L p .36623 .78014 L F P
0 g
s
.36482 .75593 m .366 .77342 L .35329 .76202 L p .707 .577 .707 r
F P
0 g
s
.35329 .76202 m .35212 .74453 L .36482 .75593 L p .707 .577 .707 r
F P
0 g
s
.37217 .26395 m .35417 .77574 L .34518 .78277 L p .707 .577 .707 r
F P
0 g
s
.34518 .78277 m .34424 .7835 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.3512 .5856 m .34474 .76919 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.35279 .62696 m .34474 .76919 L .34563 .75799 L .707 .577 .707 r
F
.36225 .27171 m .3512 .5856 L p .35279 .62696 L F P
0 g
s
.34484 .7723 m .37217 .26395 L .34518 .78277 L .707 .577 .707 r
F
.33216 .75331 m .33099 .73582 L .34385 .74113 L p F P
0 g
s
.33216 .75331 m .34385 .74113 L .34396 .74454 L .707 .577 .707 r
F
.34484 .7723 m .35127 .58738 L .35273 .62555 L F
.35127 .58738 m .36225 .27171 L .35273 .62555 L F
.36225 .27171 m .37217 .26395 L p .35273 .62555 L F P
0 g
s
.34424 .7835 m .34474 .76919 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .36225 .27171 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.36607 .80008 m .36622 .80015 L p .36623 .78014 L .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36786 .7689 L .36629 .77191 L p .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36629 .77191 L .36619 .7849 L .707 .577 .707 r
F
.36614 .79196 m .36904 .78639 L p .36619 .7849 L F P
0 g
s
.16732 .6127 m .15841 .66923 L .17176 .66755 L p .707 .577 .707 r
F P
0 g
s
.17176 .66755 m .18067 .61102 L .16732 .6127 L p .707 .577 .707 r
F P
0 g
s
.17271 .72142 m .17313 .75818 L .19419 .76504 L p .707 .577 .707 r
F P
0 g
s
.66756 .71754 m .66797 .7543 L .64052 .74977 L p .707 .577 .707 r
F P
0 g
s
.64052 .74977 m .6401 .713 L .66756 .71754 L p .707 .577 .707 r
F P
0 g
s
.26097 .83194 m .2598 .81446 L .22865 .81333 L p .707 .577 .707 r
F P
0 g
s
.2598 .81446 m .26097 .83194 L .29274 .82891 L p .707 .577 .707 r
F P
0 g
s
.29274 .82891 m .29156 .81142 L .2598 .81446 L p .707 .577 .707 r
F P
0 g
s
.29156 .81142 m .29274 .82891 L .322 .82201 L p .707 .577 .707 r
F P
0 g
s
.322 .82201 m .32083 .80453 L .29156 .81142 L p .707 .577 .707 r
F P
0 g
s
.17313 .75818 m .17271 .72142 L .16012 .7129 L p .707 .577 .707 r
F P
0 g
s
.22983 .83082 m .22865 .81333 L .20117 .80816 L p .707 .577 .707 r
F P
0 g
s
.22865 .81333 m .22983 .83082 L .26097 .83194 L p .707 .577 .707 r
F P
0 g
s
.69512 .78135 m .6963 .79883 L .67517 .79012 L p .707 .577 .707 r
F P
0 g
s
.67517 .79012 m .674 .77264 L .69512 .78135 L p .707 .577 .707 r
F P
0 g
s
.32083 .80453 m .322 .82201 L .34591 .81194 L p .707 .577 .707 r
F P
0 g
s
.34591 .81194 m .34473 .79445 L .32083 .80453 L p .707 .577 .707 r
F P
0 g
s
.20117 .80816 m .20234 .82565 L .22983 .83082 L p .707 .577 .707 r
F P
0 g
s
.16012 .7129 m .16053 .74966 L .17313 .75818 L p .707 .577 .707 r
F P
0 g
s
.16346 .6162 m .15456 .67273 L .15841 .66923 L p .707 .577 .707 r
F P
0 g
s
.15841 .66923 m .16732 .6127 L .16346 .6162 L p .707 .577 .707 r
F P
0 g
s
.53161 .80383 m .53043 .78635 L .55434 .77627 L p .707 .577 .707 r
F P
0 g
s
.20234 .82565 m .20117 .80816 L .18004 .79945 L p .707 .577 .707 r
F P
0 g
s
.55434 .77627 m .55551 .79376 L .53161 .80383 L p .707 .577 .707 r
F P
0 g
s
.18004 .79945 m .18121 .81694 L .20234 .82565 L p .707 .577 .707 r
F P
0 g
s
.674 .77264 m .67517 .79012 L .64769 .78495 L p .707 .577 .707 r
F P
0 g
s
.64769 .78495 m .64651 .76747 L .674 .77264 L p .707 .577 .707 r
F P
0 g
s
.34473 .79445 m .34591 .81194 L .36212 .79966 L p .707 .577 .707 r
F P
0 g
s
.16053 .74966 m .16012 .7129 L .15722 .70356 L p .707 .577 .707 r
F P
0 g
s
.55551 .79376 m .55434 .77627 L .5836 .76938 L p .707 .577 .707 r
F P
0 g
s
.15722 .70356 m .15763 .74032 L .16053 .74966 L p .707 .577 .707 r
F P
0 g
s
.18121 .81694 m .18004 .79945 L .16733 .78806 L p .707 .577 .707 r
F P
0 g
s
.16949 .62119 m .16058 .67772 L .15456 .67273 L p .707 .577 .707 r
F P
0 g
s
.15456 .67273 m .16346 .6162 L .16949 .62119 L p .707 .577 .707 r
F P
0 g
s
.5836 .76938 m .58478 .78686 L .55551 .79376 L p .707 .577 .707 r
F P
0 g
s
.16733 .78806 m .16851 .80554 L .18121 .81694 L p .707 .577 .707 r
F P
0 g
s
.64996 .28493 m .63195 .79672 L .6278 .78831 L p .707 .577 .707 r
F P
0 g
s
.6278 .78831 m .6458 .27652 L .64996 .28493 L p .707 .577 .707 r
F P
0 g
s
.15763 .74032 m .15722 .70356 L .16429 .69432 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16851 .80554 m .16733 .78806 L .16429 .77508 L p .707 .577 .707 r
F P
0 g
s
.16429 .69432 m .16471 .73108 L .15763 .74032 L p .707 .577 .707 r
F P
0 g
s
.18479 .62718 m .17589 .68371 L .16058 .67772 L p .707 .577 .707 r
F P
0 g
s
.16058 .67772 m .16949 .62119 L .18479 .62718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16429 .77508 m .16547 .79257 L .16851 .80554 L p .707 .577 .707 r
F P
0 g
s
.36786 .7689 m .36904 .78639 L .366 .77342 L p .707 .577 .707 r
F P
0 g
s
.366 .77342 m .36482 .75593 L .36786 .7689 L p .707 .577 .707 r
F P
0 g
s
.16471 .73108 m .16429 .69432 L .18066 .68607 L p .707 .577 .707 r
F P
0 g
s
.34803 .65173 m .33913 .70826 L .31758 .70794 L p .707 .577 .707 r
F P
0 g
s
.6458 .27652 m .6278 .78831 L .60997 .78008 L p .707 .577 .707 r
F P
0 g
s
.60997 .78008 m .62798 .26829 L .6458 .27652 L p .707 .577 .707 r
F P
0 g
s
.16547 .79257 m .16429 .77508 L .17121 .76181 L p .707 .577 .707 r
F P
0 g
s
.18066 .68607 m .18107 .72283 L .16471 .73108 L p .707 .577 .707 r
F P
0 g
s
.31758 .70794 m .32649 .65141 L .34803 .65173 L p .707 .577 .707 r
F P
0 g
s
.20789 .63358 m .19898 .69011 L .17589 .68371 L p .707 .577 .707 r
F P
0 g
s
.17589 .68371 m .18479 .62718 L .20789 .63358 L p .707 .577 .707 r
F P
0 g
s
.34561 .68758 m .34602 .72434 L .32496 .71748 L p .707 .577 .707 r
F P
0 g
s
.32496 .71748 m .32455 .68072 L .34561 .68758 L p .707 .577 .707 r
F P
0 g
s
.17121 .76181 m .17239 .7793 L .16547 .79257 L p .707 .577 .707 r
F P
0 g
s
.35417 .77574 m .37217 .26395 L .39521 .25759 L p .707 .577 .707 r
F P
0 g
s
.19898 .69011 m .20789 .63358 L .23651 .63976 L p .707 .577 .707 r
F P
0 g
s
.18107 .72283 m .18066 .68607 L .20471 .67962 L p .707 .577 .707 r
F P
0 g
s
.32649 .65141 m .31758 .70794 L .28996 .70566 L p .707 .577 .707 r
F P
0 g
s
.23651 .63976 m .22761 .69629 L .19898 .69011 L p .707 .577 .707 r
F P
0 g
s
.28996 .70566 m .29887 .64914 L .32649 .65141 L p .707 .577 .707 r
F P
0 g
s
.17239 .7793 m .17121 .76181 L .18742 .74954 L p .707 .577 .707 r
F P
0 g
s
.20471 .67962 m .20512 .71638 L .18107 .72283 L p .707 .577 .707 r
F P
0 g
s
.32455 .68072 m .32496 .71748 L .29751 .71295 L p .707 .577 .707 r
F P
0 g
s
.29751 .71295 m .29709 .67619 L .32455 .68072 L p .707 .577 .707 r
F P
0 g
s
.29887 .64914 m .28996 .70566 L .25895 .70165 L p .707 .577 .707 r
F P
0 g
s
.18742 .74954 m .1886 .76702 L .17239 .7793 L p .707 .577 .707 r
F P
0 g
s
.71005 .55417 m .70115 .6107 L .73215 .61472 L p .707 .577 .707 r
F P
0 g
s
.73215 .61472 m .74106 .55819 L .71005 .55417 L p .707 .577 .707 r
F P
0 g
s
.74106 .55819 m .73215 .61472 L .7635 .62008 L p .707 .577 .707 r
F P
0 g
s
.62798 .26829 m .60997 .78008 L .58021 .77283 L p .707 .577 .707 r
F P
0 g
s
.58021 .77283 m .59822 .26103 L .62798 .26829 L p .707 .577 .707 r
F P
0 g
s
.22761 .69629 m .23651 .63976 L .26786 .64512 L p .707 .577 .707 r
F P
0 g
s
.20512 .71638 m .20471 .67962 L .23408 .67561 L p .707 .577 .707 r
F P
0 g
s
.26786 .64512 m .25895 .70165 L .22761 .69629 L p .707 .577 .707 r
F P
0 g
s
.7635 .62008 m .7724 .56355 L .74106 .55819 L p .707 .577 .707 r
F P
0 g
s
.7724 .56355 m .7635 .62008 L .79212 .62626 L p .707 .577 .707 r
F P
0 g
s
.25895 .70165 m .26786 .64512 L .29887 .64914 L p .707 .577 .707 r
F P
0 g
s
.68243 .55189 m .67352 .60842 L .70115 .6107 L p .707 .577 .707 r
F P
0 g
s
.70115 .6107 m .71005 .55417 L .68243 .55189 L p .707 .577 .707 r
F P
0 g
s
.29709 .67619 m .29751 .71295 L .26633 .71119 L p .707 .577 .707 r
F P
0 g
s
.26633 .71119 m .26592 .67443 L .29709 .67619 L p .707 .577 .707 r
F P
0 g
s
.79212 .62626 m .80103 .56973 L .7724 .56355 L p .707 .577 .707 r
F P
0 g
s
.23408 .67561 m .2345 .71237 L .20512 .71638 L p .707 .577 .707 r
F P
0 g
s
.2345 .71237 m .23408 .67561 L .26592 .67443 L p .707 .577 .707 r
F P
0 g
s
.39521 .25759 m .3772 .76938 L .35417 .77574 L p .707 .577 .707 r
F P
0 g
s
.3772 .76938 m .39521 .25759 L .4291 .25326 L p .707 .577 .707 r
F P
0 g
s
.26592 .67443 m .26633 .71119 L .2345 .71237 L p .707 .577 .707 r
F P
0 g
s
.80103 .56973 m .79212 .62626 L .81522 .63266 L p .707 .577 .707 r
F P
0 g
s
.1886 .76702 m .18742 .74954 L .21133 .73946 L p .707 .577 .707 r
F P
0 g
s
.73303 .72537 m .73261 .68861 L .70144 .68685 L p .707 .577 .707 r
F P
0 g
s
.73261 .68861 m .73303 .72537 L .76486 .72419 L p .707 .577 .707 r
F P
0 g
s
.76486 .72419 m .76445 .68743 L .73261 .68861 L p .707 .577 .707 r
F P
0 g
s
.66088 .55158 m .65198 .60811 L .67352 .60842 L p .707 .577 .707 r
F P
0 g
s
.67352 .60842 m .68243 .55189 L .66088 .55158 L p .707 .577 .707 r
F P
0 g
s
.81522 .63266 m .82412 .57613 L .80103 .56973 L p .707 .577 .707 r
F P
0 g
s
.21133 .73946 m .2125 .75694 L .1886 .76702 L p .707 .577 .707 r
F P
0 g
s
.76445 .68743 m .76486 .72419 L .79424 .72018 L p .707 .577 .707 r
F P
0 g
s
.79424 .72018 m .79383 .68342 L .76445 .68743 L p .707 .577 .707 r
F P
0 g
s
.33099 .73582 m .33216 .75331 L .30468 .74814 L p .707 .577 .707 r
F P
0 g
s
.30468 .74814 m .3035 .73065 L .33099 .73582 L p .707 .577 .707 r
F P
0 g
s
.70186 .72361 m .70144 .68685 L .67398 .68232 L p .707 .577 .707 r
F P
0 g
s
.70144 .68685 m .70186 .72361 L .73303 .72537 L p .707 .577 .707 r
F P
0 g
s
.59822 .26103 m .58021 .77283 L .54143 .76726 L p .707 .577 .707 r
F P
0 g
s
.54143 .76726 m .55944 .25547 L .59822 .26103 L p .707 .577 .707 r
F P
0 g
s
.2125 .75694 m .21133 .73946 L .24059 .73256 L p .707 .577 .707 r
F P
0 g
s
.79383 .68342 m .79424 .72018 L .81829 .71373 L p .707 .577 .707 r
F P
0 g
s
.81829 .71373 m .81788 .67697 L .79383 .68342 L p .707 .577 .707 r
F P
0 g
s
.82412 .57613 m .81522 .63266 L .83053 .63864 L p .707 .577 .707 r
F P
0 g
s
.67398 .68232 m .6744 .71908 L .70186 .72361 L p .707 .577 .707 r
F P
0 g
s
.3035 .73065 m .30468 .74814 L .27353 .74701 L p .707 .577 .707 r
F P
0 g
s
.27353 .74701 m .27236 .72953 L .3035 .73065 L p .707 .577 .707 r
F P
0 g
s
.24059 .73256 m .24177 .75005 L .2125 .75694 L p .707 .577 .707 r
F P
0 g
s
.4111 .76505 m .4291 .25326 L .47053 .25139 L p .707 .577 .707 r
F P
0 g
s
.4291 .25326 m .4111 .76505 L .3772 .76938 L p .707 .577 .707 r
F P
0 g
s
.6744 .71908 m .67398 .68232 L .65293 .67546 L p .707 .577 .707 r
F P
0 g
s
.83053 .63864 m .83943 .58211 L .82412 .57613 L p .707 .577 .707 r
F P
0 g
s
.24177 .75005 m .24059 .73256 L .27236 .72953 L p .707 .577 .707 r
F P
0 g
s
.64753 .55326 m .63862 .60978 L .65198 .60811 L p .707 .577 .707 r
F P
0 g
s
.65198 .60811 m .66088 .55158 L .64753 .55326 L p .707 .577 .707 r
F P
0 g
s
.27236 .72953 m .27353 .74701 L .24177 .75005 L p .707 .577 .707 r
F P
0 g
s
.65293 .67546 m .65334 .71222 L .6744 .71908 L p .707 .577 .707 r
F P
0 g
s
.55944 .25547 m .54143 .76726 L .49744 .76394 L p .707 .577 .707 r
F P
0 g
s
.49744 .76394 m .51544 .25215 L .55944 .25547 L p .707 .577 .707 r
F P
0 g
s
.81788 .67697 m .81829 .71373 L .83466 .70548 L p .707 .577 .707 r
F P
0 g
s
.83466 .70548 m .83424 .66872 L .81788 .67697 L p .707 .577 .707 r
F P
0 g
s
.74119 .76268 m .74001 .74519 L .70886 .74407 L p .707 .577 .707 r
F P
0 g
s
.74001 .74519 m .74119 .76268 L .77295 .75964 L p .707 .577 .707 r
F P
0 g
s
.77295 .75964 m .77177 .74216 L .74001 .74519 L p .707 .577 .707 r
F P
0 g
s
.77177 .74216 m .77295 .75964 L .80222 .75275 L p .707 .577 .707 r
F P
0 g
s
.80222 .75275 m .80104 .73527 L .77177 .74216 L p .707 .577 .707 r
F P
0 g
s
.45253 .76318 m .47053 .25139 L .51544 .25215 L p .707 .577 .707 r
F P
0 g
s
.47053 .25139 m .45253 .76318 L .4111 .76505 L p .707 .577 .707 r
F P
0 g
s
.71004 .76155 m .70886 .74407 L .68138 .7389 L p .707 .577 .707 r
F P
0 g
s
.70886 .74407 m .71004 .76155 L .74119 .76268 L p .707 .577 .707 r
F P
0 g
s
.83943 .58211 m .83053 .63864 L .83655 .64363 L p .707 .577 .707 r
F P
0 g
s
.51544 .25215 m .49744 .76394 L .45253 .76318 L p .707 .577 .707 r
F P
0 g
s
.65334 .71222 m .65293 .67546 L .64033 .66694 L p .707 .577 .707 r
F P
0 g
s
.80104 .73527 m .80222 .75275 L .82612 .74267 L p .707 .577 .707 r
F P
0 g
s
.82612 .74267 m .82495 .72519 L .80104 .73527 L p .707 .577 .707 r
F P
0 g
s
.68138 .7389 m .68256 .75638 L .71004 .76155 L p .707 .577 .707 r
F P
0 g
s
.83655 .64363 m .84545 .5871 L .83943 .58211 L p .707 .577 .707 r
F P
0 g
s
.64368 .55676 m .63477 .61329 L .63862 .60978 L p .707 .577 .707 r
F P
0 g
s
.63862 .60978 m .64753 .55326 L .64368 .55676 L p .707 .577 .707 r
F P
0 g
s
.64033 .66694 m .64075 .7037 L .65334 .71222 L p .707 .577 .707 r
F P
0 g
s
.68256 .75638 m .68138 .7389 L .66025 .73019 L p .707 .577 .707 r
F P
0 g
s
.83424 .66872 m .83466 .70548 L .84173 .69624 L p .707 .577 .707 r
F P
0 g
s
.84173 .69624 m .84132 .65948 L .83424 .66872 L p .707 .577 .707 r
F P
0 g
s
.66025 .73019 m .66143 .74767 L .68256 .75638 L p .707 .577 .707 r
F P
0 g
s
.82495 .72519 m .82612 .74267 L .84233 .7304 L p .707 .577 .707 r
F P
0 g
s
.84233 .7304 m .84116 .71291 L .82495 .72519 L p .707 .577 .707 r
F P
0 g
s
.64075 .7037 m .64033 .66694 L .63743 .65761 L p .707 .577 .707 r
F P
0 g
s
.84545 .5871 m .83655 .64363 L .83269 .64714 L p .707 .577 .707 r
F P
0 g
s
.66143 .74767 m .66025 .73019 L .64754 .71879 L p .707 .577 .707 r
F P
0 g
s
.83269 .64714 m .8416 .59061 L .84545 .5871 L p .707 .577 .707 r
F P
0 g
s
.6497 .56175 m .64079 .61828 L .63477 .61329 L p .707 .577 .707 r
F P
0 g
s
.63477 .61329 m .64368 .55676 L .6497 .56175 L p .707 .577 .707 r
F P
0 g
s
.63743 .65761 m .63785 .69437 L .64075 .7037 L p .707 .577 .707 r
F P
0 g
s
.64754 .71879 m .64872 .73628 L .66143 .74767 L p .707 .577 .707 r
F P
0 g
s
.84132 .65948 m .84173 .69624 L .83883 .6869 L p .707 .577 .707 r
F P
0 g
s
.83883 .6869 m .83842 .65014 L .84132 .65948 L p .707 .577 .707 r
F P
0 g
s
.84116 .71291 m .84233 .7304 L .84926 .71712 L p .707 .577 .707 r
F P
0 g
s
.84926 .71712 m .84808 .69964 L .84116 .71291 L p .707 .577 .707 r
F P
0 g
s
.63785 .69437 m .63743 .65761 L .64451 .64836 L p .707 .577 .707 r
F P
0 g
s
.8416 .59061 m .83269 .64714 L .81934 .64881 L p .707 .577 .707 r
F P
0 g
s
.64872 .73628 m .64754 .71879 L .6445 .70582 L p .707 .577 .707 r
F P
0 g
s
.36704 .51736 m .35814 .57388 L .38914 .5779 L p .707 .577 .707 r
F P
0 g
s
.38914 .5779 m .39805 .52137 L .36704 .51736 L p .707 .577 .707 r
F P
0 g
s
.39805 .52137 m .38914 .5779 L .42049 .58326 L p .707 .577 .707 r
F P
0 g
s
.81934 .64881 m .82825 .59228 L .8416 .59061 L p .707 .577 .707 r
F P
0 g
s
.42049 .58326 m .4294 .52673 L .39805 .52137 L p .707 .577 .707 r
F P
0 g
s
.4294 .52673 m .42049 .58326 L .44911 .58944 L p .707 .577 .707 r
F P
0 g
s
.6445 .70582 m .64568 .72331 L .64872 .73628 L p .707 .577 .707 r
F P
0 g
s
.64451 .64836 m .64492 .68512 L .63785 .69437 L p .707 .577 .707 r
F P
0 g
s
.66501 .56774 m .6561 .62426 L .64079 .61828 L p .707 .577 .707 r
F P
0 g
s
.64079 .61828 m .6497 .56175 L .66501 .56774 L p .707 .577 .707 r
F P
0 g
s
.33942 .51508 m .33051 .57161 L .35814 .57388 L p .707 .577 .707 r
F P
0 g
s
.35814 .57388 m .36704 .51736 L .33942 .51508 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84808 .69964 m .84926 .71712 L .84621 .70415 L p .707 .577 .707 r
F P
0 g
s
.84621 .70415 m .84504 .68667 L .84808 .69964 L p .707 .577 .707 r
F P
0 g
s
.44911 .58944 m .45802 .53291 L .4294 .52673 L p .707 .577 .707 r
F P
0 g
s
.83842 .65014 m .83883 .6869 L .82624 .67838 L p .707 .577 .707 r
F P
0 g
s
.82624 .67838 m .82582 .64162 L .83842 .65014 L p .707 .577 .707 r
F P
0 g
s
.45802 .53291 m .44911 .58944 L .47221 .59584 L p .707 .577 .707 r
F P
0 g
s
.39002 .68856 m .3896 .6518 L .35843 .65004 L p .707 .577 .707 r
F P
0 g
s
.3896 .6518 m .39002 .68856 L .42185 .68737 L p .707 .577 .707 r
F P
0 g
s
.42185 .68737 m .42144 .65061 L .3896 .6518 L p .707 .577 .707 r
F P
0 g
s
.31787 .51476 m .30897 .57129 L .33051 .57161 L p .707 .577 .707 r
F P
0 g
s
.33051 .57161 m .33942 .51508 L .31787 .51476 L p .707 .577 .707 r
F P
0 g
s
.47221 .59584 m .48111 .53931 L .45802 .53291 L p .707 .577 .707 r
F P
0 g
s
.64492 .68512 m .64451 .64836 L .66087 .64011 L p .707 .577 .707 r
F P
0 g
s
.82825 .59228 m .81934 .64881 L .7978 .6485 L p .707 .577 .707 r
F P
0 g
s
.42144 .65061 m .42185 .68737 L .45123 .68336 L p .707 .577 .707 r
F P
0 g
s
.45123 .68336 m .45082 .6466 L .42144 .65061 L p .707 .577 .707 r
F P
0 g
s
.64568 .72331 m .6445 .70582 L .65142 .69255 L p .707 .577 .707 r
F P
0 g
s
.35885 .6868 m .35843 .65004 L .33097 .6455 L p .707 .577 .707 r
F P
0 g
s
.35843 .65004 m .35885 .6868 L .39002 .68856 L p .707 .577 .707 r
F P
0 g
s
.7978 .6485 m .80671 .59197 L .82825 .59228 L p .707 .577 .707 r
F P
0 g
s
.6881 .57413 m .6792 .63066 L .6561 .62426 L p .707 .577 .707 r
F P
0 g
s
.6561 .62426 m .66501 .56774 L .6881 .57413 L p .707 .577 .707 r
F P
0 g
s
.65142 .69255 m .6526 .71003 L .64568 .72331 L p .707 .577 .707 r
F P
0 g
s
.66087 .64011 m .66129 .67687 L .64492 .68512 L p .707 .577 .707 r
F P
0 g
s
.45082 .6466 m .45123 .68336 L .47528 .67692 L p .707 .577 .707 r
F P
0 g
s
.47528 .67692 m .47487 .64016 L .45082 .6466 L p .707 .577 .707 r
F P
0 g
s
.48111 .53931 m .47221 .59584 L .48752 .60183 L p .707 .577 .707 r
F P
0 g
s
.84504 .68667 m .84621 .70415 L .83351 .69275 L p .707 .577 .707 r
F P
0 g
s
.83351 .69275 m .83233 .67527 L .84504 .68667 L p .707 .577 .707 r
F P
0 g
s
.82582 .64162 m .82624 .67838 L .80518 .67152 L p .707 .577 .707 r
F P
0 g
s
.80518 .67152 m .80476 .63476 L .82582 .64162 L p .707 .577 .707 r
F P
0 g
s
.33097 .6455 m .33139 .68226 L .35885 .6868 L p .707 .577 .707 r
F P
0 g
s
.33139 .68226 m .33097 .6455 L .30992 .63864 L p .707 .577 .707 r
F P
0 g
s
.48752 .60183 m .49642 .5453 L .48111 .53931 L p .707 .577 .707 r
F P
0 g
s
.30452 .51644 m .29561 .57297 L .30897 .57129 L p .707 .577 .707 r
F P
0 g
s
.30897 .57129 m .31787 .51476 L .30452 .51644 L p .707 .577 .707 r
F P
0 g
s
.80671 .59197 m .7978 .6485 L .77017 .64622 L p .707 .577 .707 r
F P
0 g
s
.66129 .67687 m .66087 .64011 L .68492 .63366 L p .707 .577 .707 r
F P
0 g
s
.6526 .71003 m .65142 .69255 L .66763 .68027 L p .707 .577 .707 r
F P
0 g
s
.71673 .58031 m .70782 .63684 L .6792 .63066 L p .707 .577 .707 r
F P
0 g
s
.6792 .63066 m .6881 .57413 L .71673 .58031 L p .707 .577 .707 r
F P
0 g
s
.77017 .64622 m .77908 .58969 L .80671 .59197 L p .707 .577 .707 r
F P
0 g
s
.30992 .63864 m .31033 .6754 L .33139 .68226 L p .707 .577 .707 r
F P
0 g
s
.47487 .64016 m .47528 .67692 L .49165 .66867 L p .707 .577 .707 r
F P
0 g
s
.49165 .66867 m .49123 .63191 L .47487 .64016 L p .707 .577 .707 r
F P
0 g
s
.39818 .72586 m .397 .70838 L .36585 .70725 L p .707 .577 .707 r
F P
0 g
s
.397 .70838 m .39818 .72586 L .42994 .72283 L p .707 .577 .707 r
F P
0 g
s
.42994 .72283 m .42876 .70534 L .397 .70838 L p .707 .577 .707 r
F P
0 g
s
.42876 .70534 m .42994 .72283 L .45921 .71593 L p .707 .577 .707 r
F P
0 g
s
.45921 .71593 m .45803 .69845 L .42876 .70534 L p .707 .577 .707 r
F P
0 g
s
.68492 .63366 m .68534 .67042 L .66129 .67687 L p .707 .577 .707 r
F P
0 g
s
.66763 .68027 m .66881 .69776 L .6526 .71003 L p .707 .577 .707 r
F P
0 g
s
.80476 .63476 m .80518 .67152 L .77772 .66699 L p .707 .577 .707 r
F P
0 g
s
.77772 .66699 m .7773 .63023 L .80476 .63476 L p .707 .577 .707 r
F P
0 g
s
.77908 .58969 m .77017 .64622 L .73917 .6422 L p .707 .577 .707 r
F P
0 g
s
.36703 .72474 m .36585 .70725 L .33837 .70209 L p .707 .577 .707 r
F P
0 g
s
.36585 .70725 m .36703 .72474 L .39818 .72586 L p .707 .577 .707 r
F P
0 g
s
.49642 .5453 m .48752 .60183 L .49354 .60682 L p .707 .577 .707 r
F P
0 g
s
.83233 .67527 m .83351 .69275 L .81238 .68404 L p .707 .577 .707 r
F P
0 g
s
.81238 .68404 m .8112 .66656 L .83233 .67527 L p .707 .577 .707 r
F P
0 g
s
.74808 .58568 m .73917 .6422 L .70782 .63684 L p .707 .577 .707 r
F P
0 g
s
.70782 .63684 m .71673 .58031 L .74808 .58568 L p .707 .577 .707 r
F P
0 g
s
.31033 .6754 m .30992 .63864 L .29732 .63013 L p .707 .577 .707 r
F P
0 g
s
.45803 .69845 m .45921 .71593 L .48311 .70586 L p .707 .577 .707 r
F P
0 g
s
.48311 .70586 m .48194 .68837 L .45803 .69845 L p .707 .577 .707 r
F P
0 g
s
.68534 .67042 m .68492 .63366 L .7143 .62965 L p .707 .577 .707 r
F P
0 g
s
.73917 .6422 m .74808 .58568 L .77908 .58969 L p .707 .577 .707 r
F P
0 g
s
.33837 .70209 m .33955 .71957 L .36703 .72474 L p .707 .577 .707 r
F P
0 g
s
.49354 .60682 m .50244 .55029 L .49642 .5453 L p .707 .577 .707 r
F P
0 g
s
.30067 .51994 m .29176 .57647 L .29561 .57297 L p .707 .577 .707 r
F P
0 g
s
.29561 .57297 m .30452 .51644 L .30067 .51994 L p .707 .577 .707 r
F P
0 g
s
.7773 .63023 m .77772 .66699 L .74655 .66523 L p .707 .577 .707 r
F P
0 g
s
.74655 .66523 m .74613 .62847 L .7773 .63023 L p .707 .577 .707 r
F P
0 g
s
.66881 .69776 m .66763 .68027 L .69154 .67019 L p .707 .577 .707 r
F P
0 g
s
.29732 .63013 m .29774 .66689 L .31033 .6754 L p .707 .577 .707 r
F P
0 g
s
.33955 .71957 m .33837 .70209 L .31724 .69337 L p .707 .577 .707 r
F P
0 g
s
.7143 .62965 m .71471 .66641 L .68534 .67042 L p .707 .577 .707 r
F P
0 g
s
.71471 .66641 m .7143 .62965 L .74613 .62847 L p .707 .577 .707 r
F P
0 g
s
.49123 .63191 m .49165 .66867 L .49872 .65942 L p .707 .577 .707 r
F P
0 g
s
.49872 .65942 m .49831 .62266 L .49123 .63191 L p .707 .577 .707 r
F P
0 g
s
.74613 .62847 m .74655 .66523 L .71471 .66641 L p .707 .577 .707 r
F P
0 g
s
.69154 .67019 m .69272 .68768 L .66881 .69776 L p .707 .577 .707 r
F P
0 g
s
.31724 .69337 m .31842 .71086 L .33955 .71957 L p .707 .577 .707 r
F P
0 g
s
.8112 .66656 m .81238 .68404 L .78489 .67887 L p .707 .577 .707 r
F P
0 g
s
.78489 .67887 m .78372 .66139 L .8112 .66656 L p .707 .577 .707 r
F P
0 g
s
.48194 .68837 m .48311 .70586 L .49932 .69358 L p .707 .577 .707 r
F P
0 g
s
.49932 .69358 m .49815 .6761 L .48194 .68837 L p .707 .577 .707 r
F P
0 g
s
.29774 .66689 m .29732 .63013 L .29442 .62079 L p .707 .577 .707 r
F P
0 g
s
.50244 .55029 m .49354 .60682 L .48968 .61032 L p .707 .577 .707 r
F P
0 g
s
.69272 .68768 m .69154 .67019 L .72081 .6633 L p .707 .577 .707 r
F P
0 g
s
.31842 .71086 m .31724 .69337 L .30453 .68198 L p .707 .577 .707 r
F P
0 g
s
.78372 .66139 m .78489 .67887 L .75375 .67775 L p .707 .577 .707 r
F P
0 g
s
.75375 .67775 m .75257 .66027 L .78372 .66139 L p .707 .577 .707 r
F P
0 g
s
.48968 .61032 m .49859 .55379 L .50244 .55029 L p .707 .577 .707 r
F P
0 g
s
.72081 .6633 m .72199 .68078 L .69272 .68768 L p .707 .577 .707 r
F P
0 g
s
.30669 .52493 m .29778 .58146 L .29176 .57647 L p .707 .577 .707 r
F P
0 g
s
.29176 .57647 m .30067 .51994 L .30669 .52493 L p .707 .577 .707 r
F P
0 g
s
.29442 .62079 m .29483 .65755 L .29774 .66689 L p .707 .577 .707 r
F P
0 g
s
.72199 .68078 m .72081 .6633 L .75257 .66027 L p .707 .577 .707 r
F P
0 g
s
.30453 .68198 m .30571 .69946 L .31842 .71086 L p .707 .577 .707 r
F P
0 g
s
.75257 .66027 m .75375 .67775 L .72199 .68078 L p .707 .577 .707 r
F P
0 g
s
.49831 .62266 m .49872 .65942 L .49582 .65008 L p .707 .577 .707 r
F P
0 g
s
.49582 .65008 m .49541 .61332 L .49831 .62266 L p .707 .577 .707 r
F P
0 g
s
.49815 .6761 m .49932 .69358 L .50625 .68031 L p .707 .577 .707 r
F P
0 g
s
.50625 .68031 m .50507 .66282 L .49815 .6761 L p .707 .577 .707 r
F P
0 g
s
.29483 .65755 m .29442 .62079 L .3015 .61154 L p .707 .577 .707 r
F P
0 g
s
.49859 .55379 m .48968 .61032 L .47633 .612 L p .707 .577 .707 r
F P
0 g
s
.30571 .69946 m .30453 .68198 L .30149 .66901 L p .707 .577 .707 r
F P
0 g
s
.47633 .612 m .48524 .55547 L .49859 .55379 L p .707 .577 .707 r
F P
0 g
s
.30149 .66901 m .30267 .68649 L .30571 .69946 L p .707 .577 .707 r
F P
0 g
s
.3015 .61154 m .30191 .6483 L .29483 .65755 L p .707 .577 .707 r
F P
0 g
s
.322 .53092 m .31309 .58745 L .29778 .58146 L p .707 .577 .707 r
F P
0 g
s
.29778 .58146 m .30669 .52493 L .322 .53092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50507 .66282 m .50625 .68031 L .5032 .66734 L p .707 .577 .707 r
F P
0 g
s
.5032 .66734 m .50203 .64985 L .50507 .66282 L p .707 .577 .707 r
F P
0 g
s
.49541 .61332 m .49582 .65008 L .48323 .64157 L p .707 .577 .707 r
F P
0 g
s
.48323 .64157 m .48281 .60481 L .49541 .61332 L p .707 .577 .707 r
F P
0 g
s
.30191 .6483 m .3015 .61154 L .31786 .60329 L p .707 .577 .707 r
F P
0 g
s
.48524 .55547 m .47633 .612 L .45479 .61168 L p .707 .577 .707 r
F P
0 g
s
.30267 .68649 m .30149 .66901 L .30841 .65573 L p .707 .577 .707 r
F P
0 g
s
.45479 .61168 m .4637 .55515 L .48524 .55547 L p .707 .577 .707 r
F P
0 g
s
.34509 .53732 m .33619 .59385 L .31309 .58745 L p .707 .577 .707 r
F P
0 g
s
.31309 .58745 m .322 .53092 L .34509 .53732 L p .707 .577 .707 r
F P
0 g
s
.30841 .65573 m .30959 .67322 L .30267 .68649 L p .707 .577 .707 r
F P
0 g
s
.31786 .60329 m .31828 .64005 L .30191 .6483 L p .707 .577 .707 r
F P
0 g
s
.50203 .64985 m .5032 .66734 L .4905 .65594 L p .707 .577 .707 r
F P
0 g
s
.4905 .65594 m .48932 .63846 L .50203 .64985 L p .707 .577 .707 r
F P
0 g
s
.48281 .60481 m .48323 .64157 L .46217 .63471 L p .707 .577 .707 r
F P
0 g
s
.46217 .63471 m .46175 .59795 L .48281 .60481 L p .707 .577 .707 r
F P
0 g
s
.4637 .55515 m .45479 .61168 L .42716 .6094 L p .707 .577 .707 r
F P
0 g
s
.31828 .64005 m .31786 .60329 L .34191 .59685 L p .707 .577 .707 r
F P
0 g
s
.30959 .67322 m .30841 .65573 L .32462 .64346 L p .707 .577 .707 r
F P
0 g
s
.37372 .5435 m .36481 .60003 L .33619 .59385 L p .707 .577 .707 r
F P
0 g
s
.33619 .59385 m .34509 .53732 L .37372 .5435 L p .707 .577 .707 r
F P
0 g
s
.42716 .6094 m .43607 .55288 L .4637 .55515 L p .707 .577 .707 r
F P
0 g
s
.34191 .59685 m .34233 .63361 L .31828 .64005 L p .707 .577 .707 r
F P
0 g
s
.32462 .64346 m .3258 .66094 L .30959 .67322 L p .707 .577 .707 r
F P
0 g
s
.46175 .59795 m .46217 .63471 L .43471 .63018 L p .707 .577 .707 r
F P
0 g
s
.43471 .63018 m .43429 .59342 L .46175 .59795 L p .707 .577 .707 r
F P
0 g
s
.43607 .55288 m .42716 .6094 L .39616 .60539 L p .707 .577 .707 r
F P
0 g
s
.48932 .63846 m .4905 .65594 L .46937 .64723 L p .707 .577 .707 r
F P
0 g
s
.46937 .64723 m .46819 .62975 L .48932 .63846 L p .707 .577 .707 r
F P
0 g
s
.40506 .54886 m .39616 .60539 L .36481 .60003 L p .707 .577 .707 r
F P
0 g
s
.36481 .60003 m .37372 .5435 L .40506 .54886 L p .707 .577 .707 r
F P
0 g
s
.34233 .63361 m .34191 .59685 L .37129 .59284 L p .707 .577 .707 r
F P
0 g
s
.39616 .60539 m .40506 .54886 L .43607 .55288 L p .707 .577 .707 r
F P
0 g
s
.43429 .59342 m .43471 .63018 L .40354 .62841 L p .707 .577 .707 r
F P
0 g
s
.40354 .62841 m .40312 .59165 L .43429 .59342 L p .707 .577 .707 r
F P
0 g
s
.3258 .66094 m .32462 .64346 L .34853 .63338 L p .707 .577 .707 r
F P
0 g
s
.37129 .59284 m .3717 .6296 L .34233 .63361 L p .707 .577 .707 r
F P
0 g
s
.3717 .6296 m .37129 .59284 L .40312 .59165 L p .707 .577 .707 r
F P
0 g
s
.40312 .59165 m .40354 .62841 L .3717 .6296 L p .707 .577 .707 r
F P
0 g
s
.34853 .63338 m .34971 .65086 L .3258 .66094 L p .707 .577 .707 r
F P
0 g
s
.46819 .62975 m .46937 .64723 L .44188 .64206 L p .707 .577 .707 r
F P
0 g
s
.44188 .64206 m .44071 .62458 L .46819 .62975 L p .707 .577 .707 r
F P
0 g
s
.34971 .65086 m .34853 .63338 L .3778 .62649 L p .707 .577 .707 r
F P
0 g
s
.44071 .62458 m .44188 .64206 L .41074 .64094 L p .707 .577 .707 r
F P
0 g
s
.41074 .64094 m .40956 .62345 L .44071 .62458 L p .707 .577 .707 r
F P
0 g
s
.3778 .62649 m .37897 .64397 L .34971 .65086 L p .707 .577 .707 r
F P
0 g
s
.37897 .64397 m .3778 .62649 L .40956 .62345 L p .707 .577 .707 r
F P
0 g
s
.40956 .62345 m .41074 .64094 L .37897 .64397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol0081ooaT008Aoo`00MGoo2`001EYF00<005YFFUH02UYF00<005YFFUH015YF
2@00Ngoo001_Ool60004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06001eOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@0075oo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00KGoo001WOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH4001YOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000Igoo
001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Eoo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo
001UOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001FOol?0002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP04001J
EUYFFUH:0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPX000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo00D005YF001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00E7oo00<005YFFUH00`001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001DOol0
1000FUIJEP000UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001DOol00`00FUH00004FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
00030008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001VOol005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP040008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IWoo001COol01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1P000UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000goo2`00F7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF6@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0000Eoo`00001JEP0000EJEP04001JEUYFFUH9001?Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70018Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH600000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040014
Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF1000@7oo001BOol01000FUIJEP0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00
00<003aoo`00DWoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00
FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000fOol0059oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP02FUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<Woo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF00000`0025YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00<7oo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P00;Woo001FOol200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;7oo001HOol40003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01EYF
00<005YFFUH00UYF0`00;7oo001LOol50005FUHG0005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd00003FUH0000002aoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
000010001UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Goo001IOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000bOol;000HOol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000_Ool300000eYF001JEP04FUH01000
FUIJEUYF2@003Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70007Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ioo`<00003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005
Ool00000FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH?0004FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool0
1000FUIJEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00001000
1EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo
100000=JEP00FUH01UYF00<005YFFUH015YF20000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P002Woo0`0015YF2@0015YF00@005YFFUIJEPP000=JEP03001J
EUYF00=JEP04001JEUYFFUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEPD00003FUH0
05YF00MJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00=JEPH000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH60003FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH01000FUIJEUYF1`000eYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF00001@0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000eYF00<0
07ooOol0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04
0008FUH200000eYF001JEP02FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP03FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF0000000_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60002FUH200000eYF001JEP020002FUH20006FUH00`00FUIJEP04FUH6
0005FUH00`00FUIJEP06FUH50002FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF100000AJEP00001JEP<0
0003FUH005YF00EJEP03001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03
001JEUYF00@000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000goo00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP05001J
EUYFFUH00005FUH40004FUH@0006FUH00`00FUIJEP03FUH400001EYF001JEUYF00002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF00<005YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP800003FUH0000000AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00=JEPT000=JEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP800003FUH0000000=JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@002UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH00UYF20000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00:goo00@005YF
FUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009J
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00@005YFFUIJEP8002eoo`00:goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP<00003FUH005YF009JEP8002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF2@000eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YF0000009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002eoo`00;7oo0`000eYF00<005YF
FUH015YF00<005YFFUH00eYF200015YF00<005YFFUH00UYF1P0000AJEP00000000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009J
EP80009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH0000002eoo`00;goo0P0000=JEP00FUH01EYF1P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001P0000=JEP00FUH01UYF00<005YFFUH01EYF10001EYF00<005YF
FUH01UYF00<005YF00000`001EYF0`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0000=JEP00FUH01P001EYF00<005YFFUH015YF1`002Goo20000eYF00<005YF
FUH00eYF1000;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH0000015YF1P0015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF1P00
1eYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000AJEP00
0000009JEP8000IJEP03001JEUYF00@001=oo`T000EJEP04001JEP00000]Ool0039oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP02
FUHK0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH300000eYF001JEP05FUHJ0003FUH00`00FUIJEP03FUH20003FUH0
1@00FUIJEUYF0000;7oo000`Ool200000eYF001JEP03FUH00`00FUH00007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP001EYF0P0000=JEP00FUH01EYF00<005YF0000
10000UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF0P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH005YF009JEP03001o
ogoo02Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`001EYF0P0000=JEP00FUH01EYF00<005YFFUH00`000eYF00<005YF
FUH02EYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF100000=JEP00000015YF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002]oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0eYF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH025YF1000
1EYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40000
0eYF00000004FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP02000[Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH50000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04FUH30002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF1@00:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000<000IJ
EP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH000000003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000Woo0P00
:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000
FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP000003Ool3000[Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQL000AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30005Ool00`00FUH0000[Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEPH001Moo`@0009JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH0000000D00003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00EJEP03001JEP0000<000Moo`800003FUH007oo02Yoo`00;7oo00<005YF000015YF00<005YF0000
0`008Goo20001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000UYF200015YF
00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1@002Goo0P0000=JEP000000;7oo000/Ool00`00
FUH00003FUH3000COol3000COol80002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30000
15YF000000000eYF00<005YFFUH0300015YF3P003Goo00@005YFFUIJEP8002aoo`00;7oo00@005YF
001JEP800004FUH00000000AOol5000?Ool3000025YF001JEUYF001JEP00FUH@000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF
000005YF00000UYF00<005YFFUH00eYF0P0000=JEP00000017oo2@0057oo0P0015YF00<007ooOol0
:goo000/Ool01P00FUH00000FUH000AJEPD000aooa@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP0000000UYF00<005YF00001EYF00<005YF00000P002Goo
0`004goo0P0000=JEP00FUH00eYF00<007ooOol0:goo000/Ool20003FUH00`00FUIJEP03FUH01000
FUIJEUYF3P0015YF00<005YFFUH01UYF00<005YF00000`000eYF00H005YFFUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2000015YF001JEP000UYF0`001EYF00D005YFFUIJEP0001eoo`80
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPD00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP800004FUH005YF0002FUH00`00FUIJEP020003FUH01@00FUIJEUYF0000
6Woo0`001EYF00@005YF000002moo`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00002FUH01000FUIJEP000eYF1@000UYF
0P005Goo100000=JEP00FUH01EYF0P00<Goo000/Ool20003FUH00`00FUIJEP03FUH01P00FUH00000
FUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP04001JEUYFFUHI
0005FUH00`00FUIJEP04FUH00`00Oomoo`0`Ool002eoo`05001JEUYFFUH00005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH?0006FUH01`00FUH005YF001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002eoo`05001JEUYFFUH00003
FUH20005FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000eOol002ioo`800003FUH005YF00<0
00IJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`L00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Moo`00<7oo0`000UYF00<005YFFUH00eYF
1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01000>goo000`Ool00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@00004Ool005YF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000:Ool60002FUHH000oOol002moo`8000AJEP03001JEP0000<000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000Eoo`03001JEP0000IJEP03001JEUYF009J
ER<000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`D000=JEP03001J
EUYF00800003FUH0000005Aoo`00;goo0P0015YF0P0017oo200015YF00<005YFFUH00UYF2@003Goo
00<005YF00001EYF1`002UYF00<005YFFUH02UYF00<005YFFUH025YF30001EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001UYF00<005YFFUH00UYF0`00E7oo000^Ool01000FUIJEP000UYF00<007oo
Ool037oo2@005Woo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEPP000IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH500000eYF001J
EP03FUH3001DOol002ioo`03001JEUYF00<001=oo`D001Eoo`03001JEUYF0080009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@000EJEP03
001JEP0000<0009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP<000AJEP03001JEP0005Ao
o`00;Woo00@005YFFUH001Eoo`D001Eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP800003FUH005YF00MJEP04001JEUYF
FUH40004FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUH0001DOol002ioo`03
001JEP0001Ioo`D001Eoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0P000UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1000EGoo000_Ool2000GOol3000FOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH0
00001EYF00<005YFFUH015YF1`001EYF30000eYF00<005YFFUH00eYF0`00EGoo000_Ool00`00Oomo
o`0`Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH3
0006FUH00`00FUIJEP040006FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YF00000`001EYF
00@005YF000005Aoo`00;goo0P00<7oo00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000IJEP@000UJEP03001JEUYF00=JEP04001J
EP000006FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000Dgoo000_Ool01000FUH00000;7oo
0`000eYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUH000=J
EP8000=JEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH40000
0eYF001JEP02FUH00`00Oomoo`1AOol002moo`04001JEUYFFUH2000XOol20002FUH00`00FUIJEP02
FUH40006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01@00FUIJEP00FUH00P00
1EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001eYF00<005YF00000`0017oo0P000eYF00<007oo
Ool0DGoo000_Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP04001JEUYF0004Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP020007FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH5000:Ool00`00FUIJEP02001BOol002moo`05001JEUYF
FUH00004FUH3000JOol40002FUH00`00FUIJEP04FUH30009Ool50008FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUH00009FUH00`00FUIJEP07FUH00`00FUH0000:000@Ool4001BOol0031oo`04
001JEUYF0005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000@Ool60002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP03FUH7000LOol2001BOol0035oo`<000EJ
EP03001JEUYF00=JEPl000AJEP03001JEUYF00IJEP04001JEUYFFUH2000HOol90006FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH;0003Ool5000KOol2001BOol003=oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000SOolI000>Ool5000JOol3
001BOol003Eoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<003=oo`8001Moo`D001Uoo`800003FUH007oo055oo`00>7oo0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01000=Woo0P0067oo0`0067oo0P0000AJEP00FUH0059oo`00>goo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00<Goo00@005YFFUIJEP8005=oo`00?goo
4000@Goo0P0000=JEP00Ool0;Goo0P0015YF0P00Dgoo002@Ool20002FUH00`00Oomoo`0YOol20000
0eYF001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF00<002Moo`8000=JEP05001JEUYFFUH0
001EOol0095oo`04001JEUYF0002FUH2000ROol30005FUH01000FUH00000EWoo002BOol01000FUIJ
EP000eYF1@006Goo100000=JEP00FUH01EYF0P00F7oo002COol30004FUH01000FUIJEUYF2@002Goo
1`001EYF00<005YFFUH015YF00<007ooOol0Egoo002EOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00FWoo002FOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000G7oo002H
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4001NOol0
09Yoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0069oo`00Wgoo200015YF
00<005YFFUH00UYF1`00IWoo002WOol9001]Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59459 .72635 m .6002 .66895 L .56909 .66574 L p .707 .577 .707 r
F P
0 g
s
.6002 .66895 m .59459 .72635 L .62623 .72936 L p .707 .577 .707 r
F P
0 g
s
.62623 .72936 m .63184 .67196 L .6002 .66895 L p .707 .577 .707 r
F P
0 g
s
.56909 .66574 m .56348 .72315 L .59459 .72635 L p .707 .577 .707 r
F P
0 g
s
.63184 .67196 m .62623 .72936 L .65532 .73188 L p .707 .577 .707 r
F P
0 g
s
.65532 .73188 m .66093 .67448 L .63184 .67196 L p .707 .577 .707 r
F P
0 g
s
.56348 .72315 m .56909 .66574 L .54157 .66265 L p .707 .577 .707 r
F P
0 g
s
.54157 .66265 m .53596 .72006 L .56348 .72315 L p .707 .577 .707 r
F P
0 g
s
.66093 .67448 m .65532 .73188 L .67901 .73367 L p .707 .577 .707 r
F P
0 g
s
.67901 .73367 m .68462 .67626 L .66093 .67448 L p .707 .577 .707 r
F P
0 g
s
.59594 .8088 m .59568 .77193 L .56451 .77011 L p .707 .577 .707 r
F P
0 g
s
.59568 .77193 m .59594 .8088 L .62777 .80778 L p .707 .577 .707 r
F P
0 g
s
.62777 .80778 m .62751 .7709 L .59568 .77193 L p .707 .577 .707 r
F P
0 g
s
.62751 .7709 m .62777 .80778 L .65715 .80401 L p .707 .577 .707 r
F P
0 g
s
.65715 .80401 m .6569 .76713 L .62751 .7709 L p .707 .577 .707 r
F P
0 g
s
.53596 .72006 m .54157 .66265 L .52032 .65999 L p .707 .577 .707 r
F P
0 g
s
.56477 .80699 m .56451 .77011 L .53705 .76563 L p .707 .577 .707 r
F P
0 g
s
.56451 .77011 m .56477 .80699 L .59594 .8088 L p .707 .577 .707 r
F P
0 g
s
.52032 .65999 m .51471 .71739 L .53596 .72006 L p .707 .577 .707 r
F P
0 g
s
.6569 .76713 m .65715 .80401 L .6812 .79786 L p .707 .577 .707 r
F P
0 g
s
.6812 .79786 m .68095 .76099 L .6569 .76713 L p .707 .577 .707 r
F P
0 g
s
.53705 .76563 m .53731 .80251 L .56477 .80699 L p .707 .577 .707 r
F P
0 g
s
.68462 .67626 m .67901 .73367 L .69497 .73454 L p .707 .577 .707 r
F P
0 g
s
.69497 .73454 m .70058 .67713 L .68462 .67626 L p .707 .577 .707 r
F P
0 g
s
.53731 .80251 m .53705 .76563 L .51599 .75893 L p .707 .577 .707 r
F P
0 g
s
.51471 .71739 m .52032 .65999 L .50744 .658 L p .707 .577 .707 r
F P
0 g
s
.50744 .658 m .50183 .71541 L .51471 .71739 L p .707 .577 .707 r
F P
0 g
s
.60087 .86237 m .60014 .84443 L .56897 .84302 L p .707 .577 .707 r
F P
0 g
s
.60014 .84443 m .60087 .86237 L .63267 .86018 L p .707 .577 .707 r
F P
0 g
s
.63267 .86018 m .63194 .84224 L .60014 .84443 L p .707 .577 .707 r
F P
0 g
s
.51599 .75893 m .51625 .79581 L .53731 .80251 L p .707 .577 .707 r
F P
0 g
s
.63194 .84224 m .63267 .86018 L .66201 .85461 L p .707 .577 .707 r
F P
0 g
s
.66201 .85461 m .66128 .83667 L .63194 .84224 L p .707 .577 .707 r
F P
0 g
s
.68095 .76099 m .6812 .79786 L .69757 .78995 L p .707 .577 .707 r
F P
0 g
s
.69757 .78995 m .69731 .75307 L .68095 .76099 L p .707 .577 .707 r
F P
0 g
s
.56897 .84302 m .5697 .86096 L .60087 .86237 L p .707 .577 .707 r
F P
0 g
s
.5697 .86096 m .56897 .84302 L .54151 .83814 L p .707 .577 .707 r
F P
0 g
s
.66128 .83667 m .66201 .85461 L .68601 .84619 L p .707 .577 .707 r
F P
0 g
s
.68601 .84619 m .68528 .82825 L .66128 .83667 L p .707 .577 .707 r
F P
0 g
s
.54151 .83814 m .54224 .85608 L .5697 .86096 L p .707 .577 .707 r
F P
0 g
s
.51625 .79581 m .51599 .75893 L .5034 .75065 L p .707 .577 .707 r
F P
0 g
s
.70058 .67713 m .69497 .73454 L .70164 .73441 L p .707 .577 .707 r
F P
0 g
s
.70164 .73441 m .70725 .677 L .70058 .67713 L p .707 .577 .707 r
F P
0 g
s
.54224 .85608 m .54151 .83814 L .52042 .83027 L p .707 .577 .707 r
F P
0 g
s
.5034 .75065 m .50366 .78753 L .51625 .79581 L p .707 .577 .707 r
F P
0 g
s
.50183 .71541 m .50744 .658 L .50417 .65689 L p .707 .577 .707 r
F P
0 g
s
.50417 .65689 m .49856 .7143 L .50183 .71541 L p .707 .577 .707 r
F P
0 g
s
.69731 .75307 m .69757 .78995 L .70465 .78104 L p .707 .577 .707 r
F P
0 g
s
.70465 .78104 m .7044 .74416 L .69731 .75307 L p .707 .577 .707 r
F P
0 g
s
.52042 .83027 m .52115 .84822 L .54224 .85608 L p .707 .577 .707 r
F P
0 g
s
.68528 .82825 m .68601 .84619 L .70232 .83576 L p .707 .577 .707 r
F P
0 g
s
.70232 .83576 m .70159 .81782 L .68528 .82825 L p .707 .577 .707 r
F P
0 g
s
.50366 .78753 m .5034 .75065 L .5005 .74162 L p .707 .577 .707 r
F P
0 g
s
.52115 .84822 m .52042 .83027 L .50779 .82019 L p .707 .577 .707 r
F P
0 g
s
.70725 .677 m .70164 .73441 L .69837 .7333 L p .707 .577 .707 r
F P
0 g
s
.69837 .7333 m .70399 .67589 L .70725 .677 L p .707 .577 .707 r
F P
0 g
s
.50779 .82019 m .50852 .83813 L .52115 .84822 L p .707 .577 .707 r
F P
0 g
s
.5005 .74162 m .50076 .7785 L .50366 .78753 L p .707 .577 .707 r
F P
0 g
s
.48316 .8187 m .4943 .31017 L .45029 .30709 L p .707 .577 .707 r
F P
0 g
s
.49856 .7143 m .50417 .65689 L .51085 .65677 L p .707 .577 .707 r
F P
0 g
s
.51085 .65677 m .50523 .71417 L .49856 .7143 L p .707 .577 .707 r
F P
0 g
s
.50076 .7785 m .5005 .74162 L .50758 .73271 L p .707 .577 .707 r
F P
0 g
s
.50852 .83813 m .50779 .82019 L .50483 .80888 L p .707 .577 .707 r
F P
0 g
s
.50483 .80888 m .50556 .82682 L .50852 .83813 L p .707 .577 .707 r
F P
0 g
s
.50758 .73271 m .50784 .76959 L .50076 .7785 L p .707 .577 .707 r
F P
0 g
s
.50523 .71417 m .51085 .65677 L .52681 .65764 L p .707 .577 .707 r
F P
0 g
s
.52681 .65764 m .52119 .71504 L .50523 .71417 L p .707 .577 .707 r
F P
0 g
s
.50784 .76959 m .50758 .73271 L .52395 .7248 L p .707 .577 .707 r
F P
0 g
s
.50556 .82682 m .50483 .80888 L .51186 .79745 L p .707 .577 .707 r
F P
0 g
s
.51186 .79745 m .51259 .81539 L .50556 .82682 L p .707 .577 .707 r
F P
0 g
s
.52395 .7248 m .52421 .76167 L .50784 .76959 L p .707 .577 .707 r
F P
0 g
s
.52119 .71504 m .52681 .65764 L .55049 .65942 L p .707 .577 .707 r
F P
0 g
s
.55049 .65942 m .54488 .71683 L .52119 .71504 L p .707 .577 .707 r
F P
0 g
s
.52421 .76167 m .52395 .7248 L .548 .71865 L p .707 .577 .707 r
F P
0 g
s
.51259 .81539 m .51186 .79745 L .52816 .78702 L p .707 .577 .707 r
F P
0 g
s
.52816 .78702 m .52889 .80496 L .51259 .81539 L p .707 .577 .707 r
F P
0 g
s
.548 .71865 m .54826 .75553 L .52421 .76167 L p .707 .577 .707 r
F P
0 g
s
.4943 .31017 m .48316 .8187 L .52809 .81874 L p .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .52816 .78702 L .54837 .77993 L p .707 .577 .707 r
F P
0 g
s
.57958 .66194 m .57397 .71934 L .54488 .71683 L p .707 .577 .707 r
F P
0 g
s
.57397 .71934 m .57718 .68644 L p .58392 .68219 L .707 .577 .707 r
F P
0 g
s
.58001 .71052 m .58392 .68219 L .61123 .66495 L .707 .577 .707 r
F
.57397 .71934 m .58392 .68219 L .58001 .71052 L F
.59453 .66336 m .61123 .66495 L p .57718 .68644 L F P
0 g
s
.64233 .66815 m .63672 .72556 L .60993 .7228 L p .707 .577 .707 r
F P
0 g
s
.60993 .7228 m .60562 .72235 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.61043 .71525 m .64233 .66815 L .60993 .7228 L .707 .577 .707 r
F
.60562 .72235 m .61123 .66495 L .61373 .66521 L p F P
0 g
s
.61373 .66521 m .64233 .66815 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.60562 .72235 m .61373 .66521 L .61043 .71525 L .707 .577 .707 r
F
.66986 .67124 m .66425 .72865 L .63672 .72556 L p F P
0 g
s
.63672 .72556 m .64233 .66815 L .66986 .67124 L p .707 .577 .707 r
F P
0 g
s
.64039 .71567 m .64065 .75255 L .60947 .75073 L p .707 .577 .707 r
F P
0 g
s
.60947 .75073 m .60922 .71386 L .64039 .71567 L p .707 .577 .707 r
F P
0 g
s
.64447 .77225 m .6452 .79019 L .61404 .78878 L p .707 .577 .707 r
F P
0 g
s
.61404 .78878 m .61331 .77084 L .64447 .77225 L p .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .64768 .28427 L .6383 .29303 L p .707 .577 .707 r
F P
0 g
s
.6383 .29303 m .6377 .29359 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .6383 .29303 L .63768 .30239 L .707 .577 .707 r
F
.62657 .80211 m .63654 .7928 L p .63768 .30239 L F P
0 g
s
.6377 .29359 m .63743 .30629 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63743 .30629 m .62657 .80211 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.61123 .66495 m .60562 .72235 L .57397 .71934 L p .707 .577 .707 r
F P
0 g
s
.57764 .75176 m .57738 .71488 L .60922 .71386 L p .707 .577 .707 r
F P
0 g
s
.60922 .71386 m .60947 .75073 L .57764 .75176 L p .707 .577 .707 r
F P
0 g
s
.58223 .79096 m .5815 .77302 L .61331 .77084 L p .707 .577 .707 r
F P
0 g
s
.61331 .77084 m .61404 .78878 L .58223 .79096 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .62657 .80211 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61462 .3015 m .61051 .48916 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61051 .48916 m .60348 .81003 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.54826 .75553 m .54805 .72519 L p .57738 .71488 L .707 .577 .707 r
F P
0 g
s
.54805 .72519 m .548 .71865 L .55349 .71795 L p .707 .577 .707 r
F P
0 g
s
.55349 .71795 m .57738 .71488 L p .54805 .72519 L .707 .577 .707 r
F P
0 g
s
.57718 .68644 m .57958 .66194 L .59453 .66336 L p .707 .577 .707 r
F P
0 g
s
.57738 .71488 m .57764 .75176 L .54826 .75553 L p .707 .577 .707 r
F P
0 g
s
.53941 .81793 m .56955 .81576 L p .56354 .71554 L .707 .577 .707 r
F P
0 g
s
.54837 .77993 m .55216 .7786 L p .54741 .78398 L .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .54837 .77993 L .54741 .78398 L .707 .577 .707 r
F
.55216 .7786 m .55289 .79654 L .52889 .80496 L p F P
0 g
s
.53923 .31021 m .52809 .81874 L .53941 .81793 L p .707 .577 .707 r
F P
0 g
s
.54488 .71683 m .54833 .68146 L p .57958 .66194 L .707 .577 .707 r
F P
0 g
s
.54833 .68146 m .55049 .65942 L .55645 .65993 L p .707 .577 .707 r
F P
0 g
s
.55645 .65993 m .57958 .66194 L p .54833 .68146 L .707 .577 .707 r
F P
0 g
s
.56955 .81576 m .58462 .81321 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.57398 .61346 m .5707 .76349 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.5707 .76349 m .56955 .81576 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.59236 .56472 m .5707 .76349 L .57342 .77321 L .707 .577 .707 r
F
.5815 .77302 m .58223 .79096 L .57858 .79166 L p F P
0 g
s
.56955 .81576 m .58069 .30723 L .53923 .31021 L p .707 .577 .707 r
F P
0 g
s
.57858 .79166 m .55289 .79654 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.57489 .77846 m .5815 .77302 L .57858 .79166 L .707 .577 .707 r
F
.55289 .79654 m .55216 .7786 L .57378 .77449 L p F P
0 g
s
.57378 .77449 m .5815 .77302 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.55289 .79654 m .57378 .77449 L .57489 .77846 L .707 .577 .707 r
F
.60348 .81003 m .59236 .56472 L .57342 .77321 L F
.58462 .81321 m .60348 .81003 L p .57342 .77321 L F P
0 g
s
.58069 .30723 m .57398 .61346 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.56354 .71554 m .53923 .31021 L .53941 .81793 L .707 .577 .707 r
F
.52809 .81874 m .53923 .31021 L .4943 .31017 L p F P
0 g
s
.70159 .81782 m .70232 .83576 L .70934 .82432 L p .707 .577 .707 r
F P
0 g
s
.70934 .82432 m .70861 .80638 L .70159 .81782 L p .707 .577 .707 r
F P
0 g
s
.7044 .74416 m .70465 .78104 L .70175 .772 L p .707 .577 .707 r
F P
0 g
s
.70175 .772 m .7015 .73513 L .7044 .74416 L p .707 .577 .707 r
F P
0 g
s
.43915 .81562 m .45029 .30709 L .41153 .30128 L p .707 .577 .707 r
F P
0 g
s
.45029 .30709 m .43915 .81562 L .48316 .8187 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .61462 .3015 L .58069 .30723 L p .707 .577 .707 r
F P
0 g
s
.70399 .67589 m .69837 .7333 L .68549 .73131 L p .707 .577 .707 r
F P
0 g
s
.68549 .73131 m .6911 .67391 L .70399 .67589 L p .707 .577 .707 r
F P
0 g
s
.25158 .68954 m .25719 .63213 L .22608 .62893 L p .707 .577 .707 r
F P
0 g
s
.25719 .63213 m .25158 .68954 L .28322 .69255 L p .707 .577 .707 r
F P
0 g
s
.28322 .69255 m .28883 .63514 L .25719 .63213 L p .707 .577 .707 r
F P
0 g
s
.22608 .62893 m .22047 .68633 L .25158 .68954 L p .707 .577 .707 r
F P
0 g
s
.28883 .63514 m .28322 .69255 L .31231 .69507 L p .707 .577 .707 r
F P
0 g
s
.31231 .69507 m .31792 .63766 L .28883 .63514 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70861 .80638 m .70934 .82432 L .70639 .81301 L p .707 .577 .707 r
F P
0 g
s
.70639 .81301 m .70566 .79507 L .70861 .80638 L p .707 .577 .707 r
F P
0 g
s
.40039 .80981 m .41153 .30128 L .38179 .29332 L p .707 .577 .707 r
F P
0 g
s
.41153 .30128 m .40039 .80981 L .43915 .81562 L p .707 .577 .707 r
F P
0 g
s
.7015 .73513 m .70175 .772 L .68916 .76373 L p .707 .577 .707 r
F P
0 g
s
.68916 .76373 m .6889 .72685 L .7015 .73513 L p .707 .577 .707 r
F P
0 g
s
.22047 .68633 m .22608 .62893 L .19856 .62584 L p .707 .577 .707 r
F P
0 g
s
.19856 .62584 m .19295 .68325 L .22047 .68633 L p .707 .577 .707 r
F P
0 g
s
.31792 .63766 m .31231 .69507 L .336 .69685 L p .707 .577 .707 r
F P
0 g
s
.336 .69685 m .34161 .63944 L .31792 .63766 L p .707 .577 .707 r
F P
0 g
s
.25293 .77199 m .25267 .73511 L .2215 .7333 L p .707 .577 .707 r
F P
0 g
s
.25267 .73511 m .25293 .77199 L .28476 .77096 L p .707 .577 .707 r
F P
0 g
s
.28476 .77096 m .28451 .73408 L .25267 .73511 L p .707 .577 .707 r
F P
0 g
s
.28451 .73408 m .28476 .77096 L .31414 .76719 L p .707 .577 .707 r
F P
0 g
s
.31414 .76719 m .31389 .73031 L .28451 .73408 L p .707 .577 .707 r
F P
0 g
s
.19295 .68325 m .19856 .62584 L .17731 .62317 L p .707 .577 .707 r
F P
0 g
s
.22176 .77017 m .2215 .7333 L .19404 .72882 L p .707 .577 .707 r
F P
0 g
s
.2215 .7333 m .22176 .77017 L .25293 .77199 L p .707 .577 .707 r
F P
0 g
s
.62657 .80211 m .6377 .29359 L .61462 .3015 L p .707 .577 .707 r
F P
0 g
s
.17731 .62317 m .1717 .68058 L .19295 .68325 L p .707 .577 .707 r
F P
0 g
s
.6911 .67391 m .68549 .73131 L .66425 .72865 L p .707 .577 .707 r
F P
0 g
s
.66425 .72865 m .66986 .67124 L .6911 .67391 L p .707 .577 .707 r
F P
0 g
s
.31389 .73031 m .31414 .76719 L .3382 .76105 L p .707 .577 .707 r
F P
0 g
s
.3382 .76105 m .33794 .72417 L .31389 .73031 L p .707 .577 .707 r
F P
0 g
s
.70566 .79507 m .70639 .81301 L .69375 .80293 L p .707 .577 .707 r
F P
0 g
s
.69375 .80293 m .69302 .78499 L .70566 .79507 L p .707 .577 .707 r
F P
0 g
s
.6889 .72685 m .68916 .76373 L .6681 .75702 L p .707 .577 .707 r
F P
0 g
s
.6681 .75702 m .66785 .72015 L .6889 .72685 L p .707 .577 .707 r
F P
0 g
s
.19404 .72882 m .1943 .7657 L .22176 .77017 L p .707 .577 .707 r
F P
0 g
s
.34161 .63944 m .336 .69685 L .35196 .69772 L p .707 .577 .707 r
F P
0 g
s
.35196 .69772 m .35757 .64031 L .34161 .63944 L p .707 .577 .707 r
F P
0 g
s
.37065 .80184 m .38179 .29332 L .36399 .28397 L p .707 .577 .707 r
F P
0 g
s
.38179 .29332 m .37065 .80184 L .40039 .80981 L p .707 .577 .707 r
F P
0 g
s
.1943 .7657 m .19404 .72882 L .17298 .72211 L p .707 .577 .707 r
F P
0 g
s
.1717 .68058 m .17731 .62317 L .16443 .62119 L p .707 .577 .707 r
F P
0 g
s
.16443 .62119 m .15882 .67859 L .1717 .68058 L p .707 .577 .707 r
F P
0 g
s
.25786 .82556 m .25713 .80762 L .22597 .8062 L p .707 .577 .707 r
F P
0 g
s
.25713 .80762 m .25786 .82556 L .28967 .82337 L p .707 .577 .707 r
F P
0 g
s
.28967 .82337 m .28894 .80543 L .25713 .80762 L p .707 .577 .707 r
F P
0 g
s
.17298 .72211 m .17324 .75899 L .1943 .7657 L p .707 .577 .707 r
F P
0 g
s
.28894 .80543 m .28967 .82337 L .319 .81779 L p .707 .577 .707 r
F P
0 g
s
.319 .81779 m .31827 .79985 L .28894 .80543 L p .707 .577 .707 r
F P
0 g
s
.33794 .72417 m .3382 .76105 L .35456 .75313 L p .707 .577 .707 r
F P
0 g
s
.35456 .75313 m .35431 .71626 L .33794 .72417 L p .707 .577 .707 r
F P
0 g
s
.22597 .8062 m .2267 .82414 L .25786 .82556 L p .707 .577 .707 r
F P
0 g
s
.2267 .82414 m .22597 .8062 L .1985 .80132 L p .707 .577 .707 r
F P
0 g
s
.66785 .72015 m .6681 .75702 L .64065 .75255 L p .707 .577 .707 r
F P
0 g
s
.64065 .75255 m .64039 .71567 L .66785 .72015 L p .707 .577 .707 r
F P
0 g
s
.69302 .78499 m .69375 .80293 L .67267 .79507 L p .707 .577 .707 r
F P
0 g
s
.67267 .79507 m .67194 .77713 L .69302 .78499 L p .707 .577 .707 r
F P
0 g
s
.31827 .79985 m .319 .81779 L .343 .80938 L p .707 .577 .707 r
F P
0 g
s
.343 .80938 m .34227 .79144 L .31827 .79985 L p .707 .577 .707 r
F P
0 g
s
.1985 .80132 m .19923 .81926 L .2267 .82414 L p .707 .577 .707 r
F P
0 g
s
.17324 .75899 m .17298 .72211 L .16039 .71384 L p .707 .577 .707 r
F P
0 g
s
.35757 .64031 m .35196 .69772 L .35863 .69759 L p .707 .577 .707 r
F P
0 g
s
.35863 .69759 m .36424 .64019 L .35757 .64031 L p .707 .577 .707 r
F P
0 g
s
.19923 .81926 m .1985 .80132 L .17741 .79346 L p .707 .577 .707 r
F P
0 g
s
.16039 .71384 m .16065 .75072 L .17324 .75899 L p .707 .577 .707 r
F P
0 g
s
.15882 .67859 m .16443 .62119 L .16116 .62008 L p .707 .577 .707 r
F P
0 g
s
.16116 .62008 m .15555 .67748 L .15882 .67859 L p .707 .577 .707 r
F P
0 g
s
.35431 .71626 m .35456 .75313 L .36164 .74422 L p .707 .577 .707 r
F P
0 g
s
.36164 .74422 m .36139 .70735 L .35431 .71626 L p .707 .577 .707 r
F P
0 g
s
.17741 .79346 m .17814 .8114 L .19923 .81926 L p .707 .577 .707 r
F P
0 g
s
.35931 .79894 m .35858 .781 L .34227 .79144 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .34248 .6945 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36098 .63908 m .35882 .66112 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.35882 .66112 m .35537 .69648 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35988 .27416 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .34809 .63709 L .35833 .63867 L p .707 .577 .707 r
F P
0 g
s
.35833 .63867 m .36098 .63908 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .35833 .63867 L .3585 .64648 L .707 .577 .707 r
F
.35849 .69831 m .35875 .73519 L .34615 .72691 L p F P
0 g
s
.36424 .64019 m .35863 .69759 L .35537 .69648 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .36098 .63908 L .36424 .64019 L p .707 .577 .707 r
F P
0 g
s
.34615 .72691 m .34589 .69004 L .35849 .69831 L p .707 .577 .707 r
F P
0 g
s
.35102 .78814 m .35285 .7925 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35728 .5902 L .35624 .54229 L .707 .577 .707 r
F
.35285 .7925 m .354 .74023 L p .35344 .74923 L F P
0 g
s
.354 .74023 m .35728 .5902 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35001 .74818 L .35334 .75083 L p .707 .577 .707 r
F P
0 g
s
.35858 .781 m .35931 .79894 L .36633 .78751 L p .707 .577 .707 r
F P
0 g
s
.36633 .78751 m .3656 .76957 L .35858 .781 L p .707 .577 .707 r
F P
0 g
s
.36139 .70735 m .36164 .74422 L .35875 .73519 L p .707 .577 .707 r
F P
0 g
s
.35875 .73519 m .35849 .69831 L .36139 .70735 L p .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35589 .65388 L p .37065 .80184 L .707 .577 .707 r
F P
0 g
s
.35589 .65388 m .35285 .7925 L .36579 .79929 L p .707 .577 .707 r
F P
0 g
s
.3656 .76957 m .36633 .78751 L .36451 .78053 L p .707 .577 .707 r
F P
0 g
s
.36407 .77413 m .3656 .76957 L .36451 .78053 L .707 .577 .707 r
F
.36338 .7762 m .36265 .75826 L .3656 .76957 L p F P
0 g
s
.36579 .79929 m .37065 .80184 L p .35589 .65388 L .707 .577 .707 r
F P
0 g
s
.36451 .78053 m .36338 .7762 L p .36407 .77413 L .707 .577 .707 r
F P
0 g
s
.35334 .75083 m .36265 .75826 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35334 .75083 L .35246 .76499 L .707 .577 .707 r
F
.36265 .75826 m .36338 .7762 L .35231 .76737 L p F P
0 g
s
.35231 .76737 m .35074 .76612 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35246 .76499 m .36265 .75826 L .35231 .76737 L .707 .577 .707 r
F
.35001 .74818 m .35074 .76612 L .32966 .75826 L p F P
0 g
s
.32966 .75826 m .32893 .74031 L .35001 .74818 L p .707 .577 .707 r
F P
0 g
s
.34874 .78268 m .35102 .78814 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35624 .54229 L .35102 .78814 L .707 .577 .707 r
F
.35988 .27416 m .35513 .49095 L p .35624 .54229 L F P
0 g
s
.35513 .49095 m .34874 .78268 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35728 .5902 m .36399 .28397 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34227 .79144 m .343 .80938 L .35931 .79894 L p .707 .577 .707 r
F P
0 g
s
.67194 .77713 m .67267 .79507 L .6452 .79019 L p .707 .577 .707 r
F P
0 g
s
.6452 .79019 m .64447 .77225 L .67194 .77713 L p .707 .577 .707 r
F P
0 g
s
.16065 .75072 m .16039 .71384 L .15749 .7048 L p .707 .577 .707 r
F P
0 g
s
.17814 .8114 m .17741 .79346 L .16478 .78338 L p .707 .577 .707 r
F P
0 g
s
.16478 .78338 m .16551 .80132 L .17814 .8114 L p .707 .577 .707 r
F P
0 g
s
.15749 .7048 m .15775 .74168 L .16065 .75072 L p .707 .577 .707 r
F P
0 g
s
.64768 .28427 m .63654 .7928 L .63242 .78298 L p .707 .577 .707 r
F P
0 g
s
.63242 .78298 m .64356 .27445 L .64768 .28427 L p .707 .577 .707 r
F P
0 g
s
.15555 .67748 m .16116 .62008 L .16784 .61995 L p .707 .577 .707 r
F P
0 g
s
.16784 .61995 m .16223 .67736 L .15555 .67748 L p .707 .577 .707 r
F P
0 g
s
.15775 .74168 m .15749 .7048 L .16457 .69589 L p .707 .577 .707 r
F P
0 g
s
.16551 .80132 m .16478 .78338 L .16183 .77207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34874 .78268 m .35988 .27416 L .36985 .26484 L p .707 .577 .707 r
F P
0 g
s
.16183 .77207 m .16256 .79001 L .16551 .80132 L p .707 .577 .707 r
F P
0 g
s
.16457 .69589 m .16483 .73277 L .15775 .74168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16223 .67736 m .16784 .61995 L .1838 .62082 L p .707 .577 .707 r
F P
0 g
s
.1838 .62082 m .17818 .67823 L .16223 .67736 L p .707 .577 .707 r
F P
0 g
s
.64356 .27445 m .63242 .78298 L .61463 .77364 L p .707 .577 .707 r
F P
0 g
s
.61463 .77364 m .62577 .26511 L .64356 .27445 L p .707 .577 .707 r
F P
0 g
s
.16483 .73277 m .16457 .69589 L .18094 .68798 L p .707 .577 .707 r
F P
0 g
s
.16256 .79001 m .16183 .77207 L .16885 .76064 L p .707 .577 .707 r
F P
0 g
s
.34809 .63709 m .34248 .6945 L .32124 .69183 L p .707 .577 .707 r
F P
0 g
s
.32124 .69183 m .32685 .63442 L .34809 .63709 L p .707 .577 .707 r
F P
0 g
s
.16885 .76064 m .16958 .77858 L .16256 .79001 L p .707 .577 .707 r
F P
0 g
s
.18094 .68798 m .1812 .72486 L .16483 .73277 L p .707 .577 .707 r
F P
0 g
s
.35871 .77337 m .36985 .26484 L .39293 .25693 L p .707 .577 .707 r
F P
0 g
s
.36985 .26484 m .35871 .77337 L .34874 .78268 L p .707 .577 .707 r
F P
0 g
s
.17818 .67823 m .1838 .62082 L .20748 .6226 L p .707 .577 .707 r
F P
0 g
s
.34589 .69004 m .34615 .72691 L .32509 .72021 L p .707 .577 .707 r
F P
0 g
s
.32509 .72021 m .32484 .68333 L .34589 .69004 L p .707 .577 .707 r
F P
0 g
s
.20748 .6226 m .20187 .68001 L .17818 .67823 L p .707 .577 .707 r
F P
0 g
s
.1812 .72486 m .18094 .68798 L .20499 .68184 L p .707 .577 .707 r
F P
0 g
s
.16958 .77858 m .16885 .76064 L .18515 .7502 L p .707 .577 .707 r
F P
0 g
s
.32685 .63442 m .32124 .69183 L .29371 .68874 L p .707 .577 .707 r
F P
0 g
s
.29371 .68874 m .29932 .63134 L .32685 .63442 L p .707 .577 .707 r
F P
0 g
s
.18515 .7502 m .18588 .76814 L .16958 .77858 L p .707 .577 .707 r
F P
0 g
s
.20187 .68001 m .20748 .6226 L .23657 .62512 L p .707 .577 .707 r
F P
0 g
s
.20499 .68184 m .20525 .71871 L .1812 .72486 L p .707 .577 .707 r
F P
0 g
s
.23657 .62512 m .23096 .68253 L .20187 .68001 L p .707 .577 .707 r
F P
0 g
s
.62577 .26511 m .61463 .77364 L .58489 .76567 L p .707 .577 .707 r
F P
0 g
s
.58489 .76567 m .59603 .25714 L .62577 .26511 L p .707 .577 .707 r
F P
0 g
s
.32484 .68333 m .32509 .72021 L .29764 .71573 L p .707 .577 .707 r
F P
0 g
s
.29764 .71573 m .29738 .67885 L .32484 .68333 L p .707 .577 .707 r
F P
0 g
s
.29932 .63134 m .29371 .68874 L .26261 .68554 L p .707 .577 .707 r
F P
0 g
s
.26261 .68554 m .26822 .62813 L .29932 .63134 L p .707 .577 .707 r
F P
0 g
s
.73179 .63171 m .7374 .5743 L .70629 .57109 L p .707 .577 .707 r
F P
0 g
s
.7374 .5743 m .73179 .63171 L .76344 .63472 L p .707 .577 .707 r
F P
0 g
s
.76344 .63472 m .76905 .57731 L .7374 .5743 L p .707 .577 .707 r
F P
0 g
s
.23096 .68253 m .23417 .64962 L p .26822 .62813 L .707 .577 .707 r
F P
0 g
s
.23417 .64962 m .23657 .62512 L .25152 .62654 L p .707 .577 .707 r
F P
0 g
s
.25152 .62654 m .26822 .62813 L p .23417 .64962 L .707 .577 .707 r
F P
0 g
s
.26822 .62813 m .26261 .68554 L .23096 .68253 L p .707 .577 .707 r
F P
0 g
s
.20525 .71871 m .20504 .68838 L p .23437 .67807 L .707 .577 .707 r
F P
0 g
s
.20504 .68838 m .20499 .68184 L .21048 .68113 L p .707 .577 .707 r
F P
0 g
s
.21048 .68113 m .23437 .67807 L p .20504 .68838 L .707 .577 .707 r
F P
0 g
s
.70629 .57109 m .70068 .6285 L .73179 .63171 L p .707 .577 .707 r
F P
0 g
s
.76905 .57731 m .76344 .63472 L .79253 .63724 L p .707 .577 .707 r
F P
0 g
s
.79253 .63724 m .79814 .57983 L .76905 .57731 L p .707 .577 .707 r
F P
0 g
s
.39293 .25693 m .38179 .76545 L .35871 .77337 L p .707 .577 .707 r
F P
0 g
s
.38179 .76545 m .39293 .25693 L .42686 .2512 L p .707 .577 .707 r
F P
0 g
s
.70068 .6285 m .70629 .57109 L .67877 .56801 L p .707 .577 .707 r
F P
0 g
s
.29738 .67885 m .29764 .71573 L .26646 .71392 L p .707 .577 .707 r
F P
0 g
s
.26646 .71392 m .26621 .67704 L .29738 .67885 L p .707 .577 .707 r
F P
0 g
s
.67877 .56801 m .67316 .62541 L .70068 .6285 L p .707 .577 .707 r
F P
0 g
s
.18588 .76814 m .18515 .7502 L .20915 .74178 L p .707 .577 .707 r
F P
0 g
s
.23437 .67807 m .23463 .71494 L .20525 .71871 L p .707 .577 .707 r
F P
0 g
s
.23463 .71494 m .23437 .67807 L .26621 .67704 L p .707 .577 .707 r
F P
0 g
s
.26621 .67704 m .26646 .71392 L .23463 .71494 L p .707 .577 .707 r
F P
0 g
s
.20915 .74178 m .20988 .75972 L .18588 .76814 L p .707 .577 .707 r
F P
0 g
s
.79814 .57983 m .79253 .63724 L .81621 .63902 L p .707 .577 .707 r
F P
0 g
s
.81621 .63902 m .82182 .58161 L .79814 .57983 L p .707 .577 .707 r
F P
0 g
s
.32893 .74031 m .32966 .75826 L .30219 .75338 L p .707 .577 .707 r
F P
0 g
s
.30219 .75338 m .30146 .73544 L .32893 .74031 L p .707 .577 .707 r
F P
0 g
s
.73314 .72249 m .73288 .68562 L .70171 .6838 L p .707 .577 .707 r
F P
0 g
s
.73288 .68562 m .73314 .72249 L .76498 .72146 L p .707 .577 .707 r
F P
0 g
s
.76498 .72146 m .76472 .68459 L .73288 .68562 L p .707 .577 .707 r
F P
0 g
s
.76472 .68459 m .76498 .72146 L .79436 .71769 L p .707 .577 .707 r
F P
0 g
s
.79436 .71769 m .7941 .68082 L .76472 .68459 L p .707 .577 .707 r
F P
0 g
s
.67316 .62541 m .67877 .56801 L .65753 .56534 L p .707 .577 .707 r
F P
0 g
s
.65753 .56534 m .65192 .62275 L .67316 .62541 L p .707 .577 .707 r
F P
0 g
s
.59603 .25714 m .58489 .76567 L .54612 .75986 L p .707 .577 .707 r
F P
0 g
s
.54612 .75986 m .55726 .25133 L .59603 .25714 L p .707 .577 .707 r
F P
0 g
s
.70197 .72068 m .70171 .6838 L .67425 .67932 L p .707 .577 .707 r
F P
0 g
s
.70171 .6838 m .70197 .72068 L .73314 .72249 L p .707 .577 .707 r
F P
0 g
s
.20988 .75972 m .20915 .74178 L .23849 .73621 L p .707 .577 .707 r
F P
0 g
s
.7941 .68082 m .79436 .71769 L .81841 .71155 L p .707 .577 .707 r
F P
0 g
s
.81841 .71155 m .81815 .67467 L .7941 .68082 L p .707 .577 .707 r
F P
0 g
s
.30146 .73544 m .30219 .75338 L .27103 .75196 L p .707 .577 .707 r
F P
0 g
s
.27103 .75196 m .2703 .73402 L .30146 .73544 L p .707 .577 .707 r
F P
0 g
s
.23849 .73621 m .23922 .75415 L .20988 .75972 L p .707 .577 .707 r
F P
0 g
s
.41572 .75972 m .42686 .2512 L .46832 .24821 L p .707 .577 .707 r
F P
0 g
s
.42686 .2512 m .41572 .75972 L .38179 .76545 L p .707 .577 .707 r
F P
0 g
s
.67425 .67932 m .67451 .7162 L .70197 .72068 L p .707 .577 .707 r
F P
0 g
s
.82182 .58161 m .81621 .63902 L .83217 .63989 L p .707 .577 .707 r
F P
0 g
s
.83217 .63989 m .83778 .58248 L .82182 .58161 L p .707 .577 .707 r
F P
0 g
s
.23922 .75415 m .23849 .73621 L .2703 .73402 L p .707 .577 .707 r
F P
0 g
s
.2703 .73402 m .27103 .75196 L .23922 .75415 L p .707 .577 .707 r
F P
0 g
s
.67451 .7162 m .67425 .67932 L .6532 .67262 L p .707 .577 .707 r
F P
0 g
s
.65192 .62275 m .65753 .56534 L .64464 .56335 L p .707 .577 .707 r
F P
0 g
s
.73807 .76166 m .73734 .74372 L .70618 .7423 L p .707 .577 .707 r
F P
0 g
s
.73734 .74372 m .73807 .76166 L .76988 .75947 L p .707 .577 .707 r
F P
0 g
s
.76988 .75947 m .76915 .74153 L .73734 .74372 L p .707 .577 .707 r
F P
0 g
s
.55726 .25133 m .54612 .75986 L .50212 .75678 L p .707 .577 .707 r
F P
0 g
s
.50212 .75678 m .51325 .24826 L .55726 .25133 L p .707 .577 .707 r
F P
0 g
s
.64464 .56335 m .63903 .62076 L .65192 .62275 L p .707 .577 .707 r
F P
0 g
s
.76915 .74153 m .76988 .75947 L .79922 .75389 L p .707 .577 .707 r
F P
0 g
s
.79922 .75389 m .79849 .73595 L .76915 .74153 L p .707 .577 .707 r
F P
0 g
s
.45718 .75674 m .46832 .24821 L .51325 .24826 L p .707 .577 .707 r
F P
0 g
s
.46832 .24821 m .45718 .75674 L .41572 .75972 L p .707 .577 .707 r
F P
0 g
s
.6532 .67262 m .65345 .70949 L .67451 .7162 L p .707 .577 .707 r
F P
0 g
s
.70618 .7423 m .70691 .76024 L .73807 .76166 L p .707 .577 .707 r
F P
0 g
s
.70691 .76024 m .70618 .7423 L .67871 .73742 L p .707 .577 .707 r
F P
0 g
s
.81815 .67467 m .81841 .71155 L .83478 .70364 L p .707 .577 .707 r
F P
0 g
s
.83478 .70364 m .83452 .66676 L .81815 .67467 L p .707 .577 .707 r
F P
0 g
s
.51325 .24826 m .50212 .75678 L .45718 .75674 L p .707 .577 .707 r
F P
0 g
s
.79849 .73595 m .79922 .75389 L .82321 .74548 L p .707 .577 .707 r
F P
0 g
s
.82321 .74548 m .82248 .72754 L .79849 .73595 L p .707 .577 .707 r
F P
0 g
s
.67871 .73742 m .67944 .75536 L .70691 .76024 L p .707 .577 .707 r
F P
0 g
s
.65345 .70949 m .6532 .67262 L .6406 .66434 L p .707 .577 .707 r
F P
0 g
s
.83778 .58248 m .83217 .63989 L .83884 .63976 L p .707 .577 .707 r
F P
0 g
s
.83884 .63976 m .84446 .58236 L .83778 .58248 L p .707 .577 .707 r
F P
0 g
s
.67944 .75536 m .67871 .73742 L .65763 .72956 L p .707 .577 .707 r
F P
0 g
s
.63903 .62076 m .64464 .56335 L .64138 .56224 L p .707 .577 .707 r
F P
0 g
s
.6406 .66434 m .64086 .70122 L .65345 .70949 L p .707 .577 .707 r
F P
0 g
s
.65763 .72956 m .65836 .7475 L .67944 .75536 L p .707 .577 .707 r
F P
0 g
s
.64138 .56224 m .63576 .61965 L .63903 .62076 L p .707 .577 .707 r
F P
0 g
s
.82248 .72754 m .82321 .74548 L .83952 .73504 L p .707 .577 .707 r
F P
0 g
s
.83952 .73504 m .83879 .7171 L .82248 .72754 L p .707 .577 .707 r
F P
0 g
s
.83452 .66676 m .83478 .70364 L .84186 .69473 L p .707 .577 .707 r
F P
0 g
s
.84186 .69473 m .8416 .65785 L .83452 .66676 L p .707 .577 .707 r
F P
0 g
s
.65836 .7475 m .65763 .72956 L .64499 .71948 L p .707 .577 .707 r
F P
0 g
s
.64086 .70122 m .6406 .66434 L .63771 .65531 L p .707 .577 .707 r
F P
0 g
s
.84446 .58236 m .83884 .63976 L .83558 .63865 L p .707 .577 .707 r
F P
0 g
s
.83558 .63865 m .84119 .58125 L .84446 .58236 L p .707 .577 .707 r
F P
0 g
s
.64499 .71948 m .64572 .73742 L .65836 .7475 L p .707 .577 .707 r
F P
0 g
s
.63771 .65531 m .63796 .69218 L .64086 .70122 L p .707 .577 .707 r
F P
0 g
s
.83879 .7171 m .83952 .73504 L .84654 .72361 L p .707 .577 .707 r
F P
0 g
s
.84654 .72361 m .84581 .70567 L .83879 .7171 L p .707 .577 .707 r
F P
0 g
s
.63576 .61965 m .64138 .56224 L .64805 .56212 L p .707 .577 .707 r
F P
0 g
s
.64805 .56212 m .64244 .61952 L .63576 .61965 L p .707 .577 .707 r
F P
0 g
s
.8416 .65785 m .84186 .69473 L .83896 .68569 L p .707 .577 .707 r
F P
0 g
s
.83896 .68569 m .8387 .64882 L .8416 .65785 L p .707 .577 .707 r
F P
0 g
s
.64572 .73742 m .64499 .71948 L .64204 .70817 L p .707 .577 .707 r
F P
0 g
s
.63796 .69218 m .63771 .65531 L .64479 .6464 L p .707 .577 .707 r
F P
0 g
s
.64204 .70817 m .64277 .72611 L .64572 .73742 L p .707 .577 .707 r
F P
0 g
s
.84119 .58125 m .83558 .63865 L .82269 .63667 L p .707 .577 .707 r
F P
0 g
s
.82269 .63667 m .8283 .57926 L .84119 .58125 L p .707 .577 .707 r
F P
0 g
s
.38878 .59489 m .39439 .53748 L .36328 .53428 L p .707 .577 .707 r
F P
0 g
s
.39439 .53748 m .38878 .59489 L .42043 .5979 L p .707 .577 .707 r
F P
0 g
s
.42043 .5979 m .42604 .54049 L .39439 .53748 L p .707 .577 .707 r
F P
0 g
s
.36328 .53428 m .35767 .59169 L .38878 .59489 L p .707 .577 .707 r
F P
0 g
s
.84581 .70567 m .84654 .72361 L .84359 .7123 L p .707 .577 .707 r
F P
0 g
s
.84359 .7123 m .84286 .69436 L .84581 .70567 L p .707 .577 .707 r
F P
0 g
s
.64479 .6464 m .64504 .68327 L .63796 .69218 L p .707 .577 .707 r
F P
0 g
s
.42604 .54049 m .42043 .5979 L .44952 .60042 L p .707 .577 .707 r
F P
0 g
s
.44952 .60042 m .45513 .54301 L .42604 .54049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64244 .61952 m .64805 .56212 L .66401 .56299 L p .707 .577 .707 r
F P
0 g
s
.35767 .59169 m .36328 .53428 L .33576 .53119 L p .707 .577 .707 r
F P
0 g
s
.66401 .56299 m .6584 .6204 L .64244 .61952 L p .707 .577 .707 r
F P
0 g
s
.33576 .53119 m .33015 .5886 L .35767 .59169 L p .707 .577 .707 r
F P
0 g
s
.8387 .64882 m .83896 .68569 L .82637 .67742 L p .707 .577 .707 r
F P
0 g
s
.82637 .67742 m .82611 .64054 L .8387 .64882 L p .707 .577 .707 r
F P
0 g
s
.45513 .54301 m .44952 .60042 L .4732 .6022 L p .707 .577 .707 r
F P
0 g
s
.4732 .6022 m .47881 .5448 L .45513 .54301 L p .707 .577 .707 r
F P
0 g
s
.64277 .72611 m .64204 .70817 L .64906 .69674 L p .707 .577 .707 r
F P
0 g
s
.39013 .68568 m .38987 .6488 L .3587 .64699 L p .707 .577 .707 r
F P
0 g
s
.38987 .6488 m .39013 .68568 L .42197 .68465 L p .707 .577 .707 r
F P
0 g
s
.42197 .68465 m .42171 .64777 L .38987 .6488 L p .707 .577 .707 r
F P
0 g
s
.64504 .68327 m .64479 .6464 L .66115 .63848 L p .707 .577 .707 r
F P
0 g
s
.42171 .64777 m .42197 .68465 L .45135 .68088 L p .707 .577 .707 r
F P
0 g
s
.45135 .68088 m .45109 .644 L .42171 .64777 L p .707 .577 .707 r
F P
0 g
s
.33015 .5886 m .33576 .53119 L .31452 .52852 L p .707 .577 .707 r
F P
0 g
s
.31452 .52852 m .30891 .58593 L .33015 .5886 L p .707 .577 .707 r
F P
0 g
s
.64906 .69674 m .64979 .71468 L .64277 .72611 L p .707 .577 .707 r
F P
0 g
s
.8283 .57926 m .82269 .63667 L .80145 .634 L p .707 .577 .707 r
F P
0 g
s
.80145 .634 m .80706 .57659 L .8283 .57926 L p .707 .577 .707 r
F P
0 g
s
.35896 .68386 m .3587 .64699 L .33124 .64251 L p .707 .577 .707 r
F P
0 g
s
.3587 .64699 m .35896 .68386 L .39013 .68568 L p .707 .577 .707 r
F P
0 g
s
.84286 .69436 m .84359 .7123 L .83096 .70222 L p .707 .577 .707 r
F P
0 g
s
.83096 .70222 m .83023 .68428 L .84286 .69436 L p .707 .577 .707 r
F P
0 g
s
.66115 .63848 m .66141 .67536 L .64504 .68327 L p .707 .577 .707 r
F P
0 g
s
.45109 .644 m .45135 .68088 L .4754 .67474 L p .707 .577 .707 r
F P
0 g
s
.4754 .67474 m .47514 .63786 L .45109 .644 L p .707 .577 .707 r
F P
0 g
s
.6584 .6204 m .66401 .56299 L .68769 .56477 L p .707 .577 .707 r
F P
0 g
s
.68769 .56477 m .68208 .62218 L .6584 .6204 L p .707 .577 .707 r
F P
0 g
s
.82611 .64054 m .82637 .67742 L .80531 .67071 L p .707 .577 .707 r
F P
0 g
s
.80531 .67071 m .80505 .63384 L .82611 .64054 L p .707 .577 .707 r
F P
0 g
s
.33124 .64251 m .3315 .67938 L .35896 .68386 L p .707 .577 .707 r
F P
0 g
s
.47881 .5448 m .4732 .6022 L .48916 .60307 L p .707 .577 .707 r
F P
0 g
s
.48916 .60307 m .49477 .54567 L .47881 .5448 L p .707 .577 .707 r
F P
0 g
s
.3315 .67938 m .33124 .64251 L .31019 .6358 L p .707 .577 .707 r
F P
0 g
s
.30891 .58593 m .31452 .52852 L .30163 .52654 L p .707 .577 .707 r
F P
0 g
s
.64979 .71468 m .64906 .69674 L .66537 .6863 L p .707 .577 .707 r
F P
0 g
s
.39506 .72484 m .39433 .7069 L .36317 .70549 L p .707 .577 .707 r
F P
0 g
s
.39433 .7069 m .39506 .72484 L .42687 .72265 L p .707 .577 .707 r
F P
0 g
s
.42687 .72265 m .42614 .70471 L .39433 .7069 L p .707 .577 .707 r
F P
0 g
s
.66141 .67536 m .66115 .63848 L .68521 .63234 L p .707 .577 .707 r
F P
0 g
s
.30163 .52654 m .29602 .58395 L .30891 .58593 L p .707 .577 .707 r
F P
0 g
s
.80706 .57659 m .80145 .634 L .77393 .63091 L p .707 .577 .707 r
F P
0 g
s
.77393 .63091 m .77954 .57351 L .80706 .57659 L p .707 .577 .707 r
F P
0 g
s
.42614 .70471 m .42687 .72265 L .45621 .71708 L p .707 .577 .707 r
F P
0 g
s
.45621 .71708 m .45548 .69914 L .42614 .70471 L p .707 .577 .707 r
F P
0 g
s
.31019 .6358 m .31044 .67268 L .3315 .67938 L p .707 .577 .707 r
F P
0 g
s
.66537 .6863 m .6661 .70424 L .64979 .71468 L p .707 .577 .707 r
F P
0 g
s
.36317 .70549 m .3639 .72343 L .39506 .72484 L p .707 .577 .707 r
F P
0 g
s
.3639 .72343 m .36317 .70549 L .3357 .70061 L p .707 .577 .707 r
F P
0 g
s
.47514 .63786 m .4754 .67474 L .49177 .66682 L p .707 .577 .707 r
F P
0 g
s
.49177 .66682 m .49151 .62995 L .47514 .63786 L p .707 .577 .707 r
F P
0 g
s
.68208 .62218 m .68769 .56477 L .71678 .56729 L p .707 .577 .707 r
F P
0 g
s
.71678 .56729 m .71117 .6247 L .68208 .62218 L p .707 .577 .707 r
F P
0 g
s
.68521 .63234 m .68546 .66922 L .66141 .67536 L p .707 .577 .707 r
F P
0 g
s
.83023 .68428 m .83096 .70222 L .80987 .69435 L p .707 .577 .707 r
F P
0 g
s
.80987 .69435 m .80914 .67641 L .83023 .68428 L p .707 .577 .707 r
F P
0 g
s
.80505 .63384 m .80531 .67071 L .77785 .66623 L p .707 .577 .707 r
F P
0 g
s
.77785 .66623 m .77759 .62936 L .80505 .63384 L p .707 .577 .707 r
F P
0 g
s
.45548 .69914 m .45621 .71708 L .4802 .70866 L p .707 .577 .707 r
F P
0 g
s
.4802 .70866 m .47947 .69072 L .45548 .69914 L p .707 .577 .707 r
F P
0 g
s
.3357 .70061 m .33643 .71855 L .3639 .72343 L p .707 .577 .707 r
F P
0 g
s
.31044 .67268 m .31019 .6358 L .29759 .62753 L p .707 .577 .707 r
F P
0 g
s
.77954 .57351 m .77393 .63091 L .74282 .62771 L p .707 .577 .707 r
F P
0 g
s
.74282 .62771 m .74843 .5703 L .77954 .57351 L p .707 .577 .707 r
F P
0 g
s
.49477 .54567 m .48916 .60307 L .49583 .60295 L p .707 .577 .707 r
F P
0 g
s
.49583 .60295 m .50145 .54554 L .49477 .54567 L p .707 .577 .707 r
F P
0 g
s
.68546 .66922 m .68521 .63234 L .71459 .62857 L p .707 .577 .707 r
F P
0 g
s
.71117 .6247 m .71678 .56729 L .74843 .5703 L p .707 .577 .707 r
F P
0 g
s
.33643 .71855 m .3357 .70061 L .31462 .69274 L p .707 .577 .707 r
F P
0 g
s
.74843 .5703 m .74282 .62771 L .71117 .6247 L p .707 .577 .707 r
F P
0 g
s
.6661 .70424 m .66537 .6863 L .68937 .67788 L p .707 .577 .707 r
F P
0 g
s
.29602 .58395 m .30163 .52654 L .29837 .52543 L p .707 .577 .707 r
F P
0 g
s
.77759 .62936 m .77785 .66623 L .74668 .66442 L p .707 .577 .707 r
F P
0 g
s
.74668 .66442 m .74642 .62754 L .77759 .62936 L p .707 .577 .707 r
F P
0 g
s
.29759 .62753 m .29785 .6644 L .31044 .67268 L p .707 .577 .707 r
F P
0 g
s
.31462 .69274 m .31535 .71068 L .33643 .71855 L p .707 .577 .707 r
F P
0 g
s
.29837 .52543 m .29275 .58284 L .29602 .58395 L p .707 .577 .707 r
F P
0 g
s
.71459 .62857 m .71484 .66545 L .68546 .66922 L p .707 .577 .707 r
F P
0 g
s
.68937 .67788 m .6901 .69582 L .6661 .70424 L p .707 .577 .707 r
F P
0 g
s
.71484 .66545 m .71459 .62857 L .74642 .62754 L p .707 .577 .707 r
F P
0 g
s
.47947 .69072 m .4802 .70866 L .49651 .69823 L p .707 .577 .707 r
F P
0 g
s
.49651 .69823 m .49578 .68029 L .47947 .69072 L p .707 .577 .707 r
F P
0 g
s
.49151 .62995 m .49177 .66682 L .49885 .65791 L p .707 .577 .707 r
F P
0 g
s
.49885 .65791 m .49859 .62104 L .49151 .62995 L p .707 .577 .707 r
F P
0 g
s
.80914 .67641 m .80987 .69435 L .7824 .68948 L p .707 .577 .707 r
F P
0 g
s
.7824 .68948 m .78167 .67154 L .80914 .67641 L p .707 .577 .707 r
F P
0 g
s
.74642 .62754 m .74668 .66442 L .71484 .66545 L p .707 .577 .707 r
F P
0 g
s
.6901 .69582 m .68937 .67788 L .7187 .67231 L p .707 .577 .707 r
F P
0 g
s
.31535 .71068 m .31462 .69274 L .30198 .68266 L p .707 .577 .707 r
F P
0 g
s
.29785 .6644 m .29759 .62753 L .2947 .61849 L p .707 .577 .707 r
F P
0 g
s
.50145 .54554 m .49583 .60295 L .49257 .60184 L p .707 .577 .707 r
F P
0 g
s
.49257 .60184 m .49818 .54443 L .50145 .54554 L p .707 .577 .707 r
F P
0 g
s
.78167 .67154 m .7824 .68948 L .75124 .68806 L p .707 .577 .707 r
F P
0 g
s
.75124 .68806 m .75051 .67012 L .78167 .67154 L p .707 .577 .707 r
F P
0 g
s
.7187 .67231 m .71943 .69025 L .6901 .69582 L p .707 .577 .707 r
F P
0 g
s
.30198 .68266 m .30271 .7006 L .31535 .71068 L p .707 .577 .707 r
F P
0 g
s
.71943 .69025 m .7187 .67231 L .75051 .67012 L p .707 .577 .707 r
F P
0 g
s
.2947 .61849 m .29495 .65537 L .29785 .6644 L p .707 .577 .707 r
F P
0 g
s
.75051 .67012 m .75124 .68806 L .71943 .69025 L p .707 .577 .707 r
F P
0 g
s
.49578 .68029 m .49651 .69823 L .50353 .68679 L p .707 .577 .707 r
F P
0 g
s
.50353 .68679 m .5028 .66885 L .49578 .68029 L p .707 .577 .707 r
F P
0 g
s
.29275 .58284 m .29837 .52543 L .30504 .5253 L p .707 .577 .707 r
F P
0 g
s
.30504 .5253 m .29943 .58271 L .29275 .58284 L p .707 .577 .707 r
F P
0 g
s
.49859 .62104 m .49885 .65791 L .49595 .64888 L p .707 .577 .707 r
F P
0 g
s
.49595 .64888 m .49569 .612 L .49859 .62104 L p .707 .577 .707 r
F P
0 g
s
.30271 .7006 m .30198 .68266 L .29903 .67135 L p .707 .577 .707 r
F P
0 g
s
.29495 .65537 m .2947 .61849 L .30178 .60958 L p .707 .577 .707 r
F P
0 g
s
.29903 .67135 m .29976 .68929 L .30271 .7006 L p .707 .577 .707 r
F P
0 g
s
.49818 .54443 m .49257 .60184 L .47968 .59985 L p .707 .577 .707 r
F P
0 g
s
.47968 .59985 m .48529 .54244 L .49818 .54443 L p .707 .577 .707 r
F P
0 g
s
.5028 .66885 m .50353 .68679 L .50058 .67548 L p .707 .577 .707 r
F P
0 g
s
.50058 .67548 m .49985 .65754 L .5028 .66885 L p .707 .577 .707 r
F P
0 g
s
.30178 .60958 m .30203 .64646 L .29495 .65537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29943 .58271 m .30504 .5253 L .321 .52617 L p .707 .577 .707 r
F P
0 g
s
.321 .52617 m .31539 .58358 L .29943 .58271 L p .707 .577 .707 r
F P
0 g
s
.49569 .612 m .49595 .64888 L .48336 .6406 L p .707 .577 .707 r
F P
0 g
s
.48336 .6406 m .4831 .60373 L .49569 .612 L p .707 .577 .707 r
F P
0 g
s
.29976 .68929 m .29903 .67135 L .30605 .65992 L p .707 .577 .707 r
F P
0 g
s
.30203 .64646 m .30178 .60958 L .31814 .60167 L p .707 .577 .707 r
F P
0 g
s
.30605 .65992 m .30678 .67786 L .29976 .68929 L p .707 .577 .707 r
F P
0 g
s
.48529 .54244 m .47968 .59985 L .45844 .59718 L p .707 .577 .707 r
F P
0 g
s
.45844 .59718 m .46405 .53978 L .48529 .54244 L p .707 .577 .707 r
F P
0 g
s
.49985 .65754 m .50058 .67548 L .48795 .6654 L p .707 .577 .707 r
F P
0 g
s
.48795 .6654 m .48722 .64746 L .49985 .65754 L p .707 .577 .707 r
F P
0 g
s
.31814 .60167 m .3184 .63854 L .30203 .64646 L p .707 .577 .707 r
F P
0 g
s
.31539 .58358 m .321 .52617 L .34468 .52796 L p .707 .577 .707 r
F P
0 g
s
.34468 .52796 m .33907 .58536 L .31539 .58358 L p .707 .577 .707 r
F P
0 g
s
.4831 .60373 m .48336 .6406 L .4623 .6339 L p .707 .577 .707 r
F P
0 g
s
.4623 .6339 m .46204 .59702 L .4831 .60373 L p .707 .577 .707 r
F P
0 g
s
.30678 .67786 m .30605 .65992 L .32236 .64949 L p .707 .577 .707 r
F P
0 g
s
.3184 .63854 m .31814 .60167 L .3422 .59553 L p .707 .577 .707 r
F P
0 g
s
.46405 .53978 m .45844 .59718 L .43092 .5941 L p .707 .577 .707 r
F P
0 g
s
.43092 .5941 m .43653 .53669 L .46405 .53978 L p .707 .577 .707 r
F P
0 g
s
.32236 .64949 m .32309 .66743 L .30678 .67786 L p .707 .577 .707 r
F P
0 g
s
.33907 .58536 m .34468 .52796 L .37377 .53047 L p .707 .577 .707 r
F P
0 g
s
.37377 .53047 m .36816 .58788 L .33907 .58536 L p .707 .577 .707 r
F P
0 g
s
.3422 .59553 m .34245 .6324 L .3184 .63854 L p .707 .577 .707 r
F P
0 g
s
.48722 .64746 m .48795 .6654 L .46686 .65754 L p .707 .577 .707 r
F P
0 g
s
.46686 .65754 m .46613 .6396 L .48722 .64746 L p .707 .577 .707 r
F P
0 g
s
.46204 .59702 m .4623 .6339 L .43484 .62942 L p .707 .577 .707 r
F P
0 g
s
.43484 .62942 m .43458 .59254 L .46204 .59702 L p .707 .577 .707 r
F P
0 g
s
.43653 .53669 m .43092 .5941 L .39981 .59089 L p .707 .577 .707 r
F P
0 g
s
.39981 .59089 m .40542 .53348 L .43653 .53669 L p .707 .577 .707 r
F P
0 g
s
.34245 .6324 m .3422 .59553 L .37158 .59176 L p .707 .577 .707 r
F P
0 g
s
.36816 .58788 m .37377 .53047 L .40542 .53348 L p .707 .577 .707 r
F P
0 g
s
.40542 .53348 m .39981 .59089 L .36816 .58788 L p .707 .577 .707 r
F P
0 g
s
.32309 .66743 m .32236 .64949 L .34636 .64107 L p .707 .577 .707 r
F P
0 g
s
.43458 .59254 m .43484 .62942 L .40367 .6276 L p .707 .577 .707 r
F P
0 g
s
.40367 .6276 m .40341 .59073 L .43458 .59254 L p .707 .577 .707 r
F P
0 g
s
.37158 .59176 m .37183 .62863 L .34245 .6324 L p .707 .577 .707 r
F P
0 g
s
.34636 .64107 m .34709 .65901 L .32309 .66743 L p .707 .577 .707 r
F P
0 g
s
.37183 .62863 m .37158 .59176 L .40341 .59073 L p .707 .577 .707 r
F P
0 g
s
.46613 .6396 m .46686 .65754 L .43939 .65266 L p .707 .577 .707 r
F P
0 g
s
.43939 .65266 m .43866 .63472 L .46613 .6396 L p .707 .577 .707 r
F P
0 g
s
.40341 .59073 m .40367 .6276 L .37183 .62863 L p .707 .577 .707 r
F P
0 g
s
.34709 .65901 m .34636 .64107 L .37569 .63549 L p .707 .577 .707 r
F P
0 g
s
.43866 .63472 m .43939 .65266 L .40823 .65125 L p .707 .577 .707 r
F P
0 g
s
.40823 .65125 m .4075 .63331 L .43866 .63472 L p .707 .577 .707 r
F P
0 g
s
.37569 .63549 m .37642 .65343 L .34709 .65901 L p .707 .577 .707 r
F P
0 g
s
.37642 .65343 m .37569 .63549 L .4075 .63331 L p .707 .577 .707 r
F P
0 g
s
.4075 .63331 m .40823 .65125 L .37642 .65343 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001bOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEP0000<006ioo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Jgoo001X
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF008006Moo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol0
06Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo06Aoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001DOol:0006Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool005Aoo`03001JEP0000AJEP03001JEUYF014000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00
E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00P00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003001SOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF001JEP00FUH=001FOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYF
FUH9001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@00<7oo001COol:0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000`00;7oo001DOol60003FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
FWoo1`000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool0065ooah000=JEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo001POol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYFFUH005YF;Goo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEP0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUIJEP00FUH]Ool005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;Goo2P0077oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF4P0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF000015YF00<005YFFUH03P003Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00
00002P000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00002`00
0Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P003Goo700015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF1`001UYF00<005YFFUH01eYF200015YF00<005YFFUH00eYF00<0
05YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
2goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00@005YFFUIJEP80
02ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YF00000`0017oo00<005YF00000UYF700015YF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF10000UYF2P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPP00004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00008000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004FUH80005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EP00001JEP0015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0000=JEP0000000P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH500000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP04001JEP000006
FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH400000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH200000eYF001JEP05FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50005FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJ
EUYF00001EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@0
05YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH00003
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF
001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH40003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH00UYF2@002Goo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0P0000EJEP00FUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP000080009JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEPH000Yoo`l00003Ool00000
00<000AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH3000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUH000080002
Ool90004FUH00`00FUIJEP06FUH00`00FUH000030002Ool300000eYF001JEP02FUH2000]Ool002ao
o`X000=JEP03001JEUYF00=JEQ4000=JEP05001JEP00FUH00002FUH300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH2000<FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH40004FUH50004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000015YF000000000eYF0P00;Goo000_Ool4
0003FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUH000040004FUH00`00
FUIJEP05FUH40005FUH00`00FUIJEP02FUH70009FUH01000FUH000002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P000eYF1P0025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000AJEP00001JEP8002eoo`00<goo1P0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00000010000eYF6`001UYF00<0
05YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00000000EJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP800004FUH00000000]Ool0039oo`<000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEP0000<00005FUH00000FUH00005
FUH00`00FUH000040003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200001EYF001JEUYF00002eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP8000EJEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEPD002eoo`00
<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
0P000UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YF000010000eYF00<005YFFUH02EYF
00<005YFFUH00UYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0`000UYF00<005YF00000P001UYF00<005YFFUH00UYF200025YF2@0015YF00<005YFFUH00UYF00<0
05YF00000P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH30002FUH40005FUH300000eYF001JEP04FUH00`00FUIJEP030004FUH00`00FUIJ
EP08FUH00`00FUH0000300000eYF001JEP03FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH20002FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH70004FUH01000FUIJEP00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP02FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEP04001JEUYFFUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300001EYF
001JEUYF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
0UYF0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP04001JEUYFFUH:0008FUH70005FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH0000002aoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000UYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF0000009oo`<002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF00H00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eo
o`8002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@000eYF0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF0080009JEP03
001JEP0000@000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<000Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1P006Goo2`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF1@000eYF2P0015YF1@0015YF00<005YF
FUH00UYF1@002Goo0`0000=JEP00Ool0:goo000/Ool00`00FUH00004FUH00`00FUH00003000?Ool3
000COol300000eYF000000080004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00
FUH000030003FUH20004OolB000<Ool20002FUH00`00FUH0000/Ool002aoo`03001JEP0000=JEP@0
015oo`D000moo`@00003FUH0000000800003FUH005YF00EJEPT00003FUH005YF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF009JEP03001JEUYF009JEP80009JEP8000Qoo`D001=oo`8000AJEP8002eoo`00
;7oo00@005YF001JEP8000AJEPD000aoo`D000Uoo`H000EJEP06001JEUYF001JEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP0000000UYF0P0000=JEP00FUH015YF0P0000=JEP000000
2Goo0`004Woo0P0000=JEP00FUH00eYF0P00;Goo000/Ool01P00FUH00000FUH000EJEP04001JEUYF
FUH80004Ool>0004FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH00000009JEP03001JEP00008000AJEP03001JEP00008001aoo`8000=JEP03
001JEUYF009JEP03001oogoo02aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<0
05YF00001`0015YF00<005YFFUH00UYF2@001UYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomo
o`0EOol50005FUH01000FUIJEUYF0P00;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000MJEP00FUIJEP00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH00UYF00<005YF
00000`0000=JEP00Ool03Goo2@000eYF00<005YFFUH015YF00@005YF0000031oo`00;7oo0P000eYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P0000AJEP00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH0
05YFFUH30004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol0
02eoo`05001JEUYFFUH00004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=7oo000]Ool01@00FUIJEUYF00000UYF0P001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Ioo`00;Woo0P0000=JEP00FUH00P001UYF
00<005YFFUH015YF1`001eYF2@0015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000goo100000AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPH003Qoo`00<7oo0`0000=JEP00FUH01EYF00<005YFFUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF1P0015YF00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF
6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`0015YF100000=J
EP00FUH01eYF00<005YFFUH00UYF2@00?Woo000`Ool01@00FUIJEUYF00001EYF100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000AJEP00FUH000IJEP03001J
EUYF00=JEP/000aJEP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yo
o`<00003FUH005YF009JEPl004Moo`00;goo0P000eYF00<005YF00000`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000goo0P0000=JEP00FUH015YF1`002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF0P001goo
100000AJEP00000000=JEP8005Aoo`00;goo0P000eYF0P000goo10000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P0027oo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009J
EP80009oo`D000EJEP03001JEUYF00800003FUH0000005Aoo`00;Woo00<005YF00000UYF00<007oo
Ool01goo60003Woo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF20001UYF00<005YFFUH00UYF
0`00E7oo000^Ool00`00FUH00002000DOol5000GOol20002FUH00`00FUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH30008FUH01000FUIJEUYF0P000UYF
0P000UYF00@005YFFUIJEP@0009JEP03001JEUYF009JEP<005Aoo`00;Woo00<005YF00005Woo1@00
5goo0P000UYF00<005YF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH00eYF10002eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF100015YF00<005YF0000
E7oo000^Ool2000GOol5000GOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH00`00FUIJEP0<FUH00`00FUIJEP04FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0001DOol002ioo`8001Qoo`<001Qoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP03
001JEUYF00aJEP03001JEUYF00AJEP<0009JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
000005Eoo`00;Woo00@005YF0000031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00]JEP03001JEUYF00AJEP03001J
EP0000@000IJEP03001JEUYF009JEP<005Ioo`00;Woo0P000UYF0P00;7oo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF00@005YFFUIJEP<000MJEP03001JEUYF00AJEP03001JEP0000AJEP@0009JEP03001JEUYF009J
EP04001JEP00001EOol002moo`05001JEUYF001JEP03000UOol400000eYF001JEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH6
0009FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP040004FUH01000FUIJEP00E7oo000_Ool01000
FUIJEP0015YF0`007goo0`001EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH015YF0P001UYF00<005YF00000`0000Ioo`00000005YF0002FUH00`00Oomoo`1BOol0
031oo`03001JEP0000EJEP03001JEP0000<001Moo`@00003FUH005YF00EJEP03001JEUYF0080009o
o`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000AJEPD000Qoo`80009JEP8005=oo`00<Goo0P001EYF00<005YF
FUH00eYF5`001EYF00<005YFFUH015YF0`001goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00002@003goo00@005YF0000
05=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P003Goo20001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF10006Woo0`00Dgoo000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000GOol<0006FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH@000JOol2001COol003Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<002Mooa/000]oo`D001Uoo`<005=oo`00>Woo10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000=Woo0P0067oo1@005goo0`0000=JEP00Ool0DWoo000nOolG000jOol3
000HOol3000FOol20002FUH00`00FUH0001COol008moo`800003FUH007oo02eoo`8000AJEP8005Ao
o`00Sgoo0P000UYF0P00:7oo100000=JEP00FUH00eYF0P00E7oo002@Ool01@00FUIJEP00FUH00`00
8Woo0`001EYF00<005YFFUH00UYF00<007ooOol0Dgoo002@Ool01000FUIJEP0015YF1@006Goo1000
00=JEP00FUH01EYF00<005YFFUH00P00EWoo002AOol01000FUIJEP0015YF00@005YFFUIJEPT000Uo
o`L000EJEP03001JEUYF00AJEP<005Qoo`00TWoo0`0015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0F7oo002DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Fgoo002F
Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0
0000GGoo002IOol50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6001OOol0
09ioo`P000AJEP03001JEUYF009JEPT006Eoo`00YWoo2@00KWoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60019 .76901 m .59458 .71913 L .56347 .71845 L p .707 .577 .707 r
F P
0 g
s
.59458 .71913 m .60019 .76901 L .63184 .7647 L p .707 .577 .707 r
F P
0 g
s
.63184 .7647 m .62622 .71482 L .59458 .71913 L p .707 .577 .707 r
F P
0 g
s
.62622 .71482 m .63184 .7647 L .66092 .75581 L p .707 .577 .707 r
F P
0 g
s
.66092 .75581 m .65531 .70593 L .62622 .71482 L p .707 .577 .707 r
F P
0 g
s
.56908 .76833 m .56347 .71845 L .53595 .71284 L p .707 .577 .707 r
F P
0 g
s
.56347 .71845 m .56908 .76833 L .60019 .76901 L p .707 .577 .707 r
F P
0 g
s
.65531 .70593 m .66092 .75581 L .68461 .74323 L p .707 .577 .707 r
F P
0 g
s
.68461 .74323 m .679 .69335 L .65531 .70593 L p .707 .577 .707 r
F P
0 g
s
.59633 .8109 m .59659 .77368 L .56541 .77169 L p .707 .577 .707 r
F P
0 g
s
.59659 .77368 m .59633 .8109 L .62816 .81037 L p .707 .577 .707 r
F P
0 g
s
.62816 .81037 m .62842 .77315 L .59659 .77368 L p .707 .577 .707 r
F P
0 g
s
.54156 .76272 m .53595 .71284 L .5147 .70285 L p .707 .577 .707 r
F P
0 g
s
.53595 .71284 m .54156 .76272 L .56908 .76833 L p .707 .577 .707 r
F P
0 g
s
.59177 .84066 m .5925 .82174 L .56133 .81934 L p .707 .577 .707 r
F P
0 g
s
.5925 .82174 m .59177 .84066 L .62357 .84133 L p .707 .577 .707 r
F P
0 g
s
.62357 .84133 m .6243 .82241 L .5925 .82174 L p .707 .577 .707 r
F P
0 g
s
.62842 .77315 m .62816 .81037 L .65754 .80739 L p .707 .577 .707 r
F P
0 g
s
.65754 .80739 m .6578 .77017 L .62842 .77315 L p .707 .577 .707 r
F P
0 g
s
.6243 .82241 m .62357 .84133 L .65291 .84021 L p .707 .577 .707 r
F P
0 g
s
.65291 .84021 m .65364 .82129 L .6243 .82241 L p .707 .577 .707 r
F P
0 g
s
.56133 .81934 m .5606 .83826 L .59177 .84066 L p .707 .577 .707 r
F P
0 g
s
.56516 .80891 m .56541 .77169 L .53796 .76738 L p .707 .577 .707 r
F P
0 g
s
.56541 .77169 m .56516 .80891 L .59633 .8109 L p .707 .577 .707 r
F P
0 g
s
.679 .69335 m .68461 .74323 L .70057 .72817 L p .707 .577 .707 r
F P
0 g
s
.70057 .72817 m .69496 .67829 L .679 .69335 L p .707 .577 .707 r
F P
0 g
s
.5606 .83826 m .56133 .81934 L .53387 .81545 L p .707 .577 .707 r
F P
0 g
s
.53387 .81545 m .53314 .83437 L .5606 .83826 L p .707 .577 .707 r
F P
0 g
s
.6578 .77017 m .65754 .80739 L .6816 .80223 L p .707 .577 .707 r
F P
0 g
s
.6816 .80223 m .68185 .76501 L .6578 .77017 L p .707 .577 .707 r
F P
0 g
s
.53796 .76738 m .5377 .80461 L .56516 .80891 L p .707 .577 .707 r
F P
0 g
s
.65364 .82129 m .65291 .84021 L .67691 .8374 L p .707 .577 .707 r
F P
0 g
s
.67691 .8374 m .67764 .81848 L .65364 .82129 L p .707 .577 .707 r
F P
0 g
s
.5377 .80461 m .53796 .76738 L .5169 .76118 L p .707 .577 .707 r
F P
0 g
s
.52031 .75273 m .5147 .70285 L .50182 .68946 L p .707 .577 .707 r
F P
0 g
s
.5147 .70285 m .52031 .75273 L .54156 .76272 L p .707 .577 .707 r
F P
0 g
s
.53314 .83437 m .53387 .81545 L .51278 .81044 L p .707 .577 .707 r
F P
0 g
s
.51278 .81044 m .51205 .82936 L .53314 .83437 L p .707 .577 .707 r
F P
0 g
s
.69496 .67829 m .70057 .72817 L .70724 .71212 L p .707 .577 .707 r
F P
0 g
s
.70724 .71212 m .70163 .66224 L .69496 .67829 L p .707 .577 .707 r
F P
0 g
s
.5169 .76118 m .51664 .7984 L .5377 .80461 L p .707 .577 .707 r
F P
0 g
s
.68185 .76501 m .6816 .80223 L .69796 .79541 L p .707 .577 .707 r
F P
0 g
s
.69796 .79541 m .69822 .75819 L .68185 .76501 L p .707 .577 .707 r
F P
0 g
s
.67764 .81848 m .67691 .8374 L .69322 .83318 L p .707 .577 .707 r
F P
0 g
s
.69322 .83318 m .69395 .81426 L .67764 .81848 L p .707 .577 .707 r
F P
0 g
s
.51664 .7984 m .5169 .76118 L .50431 .75369 L p .707 .577 .707 r
F P
0 g
s
.51205 .82936 m .51278 .81044 L .50015 .80482 L p .707 .577 .707 r
F P
0 g
s
.50743 .73934 m .50182 .68946 L .49855 .67398 L p .707 .577 .707 r
F P
0 g
s
.50182 .68946 m .50743 .73934 L .52031 .75273 L p .707 .577 .707 r
F P
0 g
s
.50015 .80482 m .49942 .82374 L .51205 .82936 L p .707 .577 .707 r
F P
0 g
s
.50431 .75369 m .50405 .79091 L .51664 .7984 L p .707 .577 .707 r
F P
0 g
s
.70163 .66224 m .70724 .71212 L .70398 .69664 L p .707 .577 .707 r
F P
0 g
s
.70398 .69664 m .69837 .64676 L .70163 .66224 L p .707 .577 .707 r
F P
0 g
s
.69822 .75819 m .69796 .79541 L .70504 .7876 L p .707 .577 .707 r
F P
0 g
s
.70504 .7876 m .7053 .75038 L .69822 .75819 L p .707 .577 .707 r
F P
0 g
s
.69395 .81426 m .69322 .83318 L .70024 .82797 L p .707 .577 .707 r
F P
0 g
s
.70024 .82797 m .70097 .80905 L .69395 .81426 L p .707 .577 .707 r
F P
0 g
s
.49942 .82374 m .50015 .80482 L .49719 .79911 L p .707 .577 .707 r
F P
0 g
s
.49719 .79911 m .49646 .81803 L .49942 .82374 L p .707 .577 .707 r
F P
0 g
s
.49646 .81803 m .49719 .79911 L .50422 .7939 L p .707 .577 .707 r
F P
0 g
s
.50422 .7939 m .50349 .81282 L .49646 .81803 L p .707 .577 .707 r
F P
0 g
s
.49788 .82403 m .48674 .33045 L .44274 .32816 L p .707 .577 .707 r
F P
0 g
s
.50405 .79091 m .50431 .75369 L .50141 .74564 L p .707 .577 .707 r
F P
0 g
s
.50416 .72386 m .50743 .73934 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.49855 .67398 m .50171 .70204 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50171 .70204 m .50416 .72386 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50141 .74564 m .50115 .78286 L .50405 .79091 L p .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50141 .74564 L .50575 .74085 L p .707 .577 .707 r
F P
0 g
s
.50575 .74085 m .50849 .73783 L p .50663 .74925 L .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50575 .74085 L .50663 .74925 L .707 .577 .707 r
F
.50416 .72386 m .49855 .67398 L .50523 .65793 L p F P
0 g
s
.51084 .70781 m .50523 .65793 L .52119 .64287 L p .707 .577 .707 r
F P
0 g
s
.50523 .65793 m .51084 .70781 L .50416 .72386 L p .707 .577 .707 r
F P
0 g
s
.50849 .73783 m .50823 .77505 L .50115 .78286 L p .707 .577 .707 r
F P
0 g
s
.52119 .64287 m .5268 .69275 L .51084 .70781 L p .707 .577 .707 r
F P
0 g
s
.5268 .69275 m .52119 .64287 L .54487 .63028 L p .707 .577 .707 r
F P
0 g
s
.50823 .77505 m .50849 .73783 L .52486 .73101 L p .707 .577 .707 r
F P
0 g
s
.50349 .81282 m .50422 .7939 L .52052 .78968 L p .707 .577 .707 r
F P
0 g
s
.52052 .78968 m .51979 .8086 L .50349 .81282 L p .707 .577 .707 r
F P
0 g
s
.52486 .73101 m .5246 .76823 L .50823 .77505 L p .707 .577 .707 r
F P
0 g
s
.54487 .63028 m .55048 .68016 L .5268 .69275 L p .707 .577 .707 r
F P
0 g
s
.5246 .76823 m .52486 .73101 L .54891 .72585 L p .707 .577 .707 r
F P
0 g
s
.51979 .8086 m .52052 .78968 L .54452 .78688 L p .707 .577 .707 r
F P
0 g
s
.54452 .78688 m .54379 .8058 L .51979 .8086 L p .707 .577 .707 r
F P
0 g
s
.54891 .72585 m .54865 .76308 L .5246 .76823 L p .707 .577 .707 r
F P
0 g
s
.48674 .33045 m .49788 .82403 L .54281 .82181 L p .707 .577 .707 r
F P
0 g
s
.54281 .82181 m .53167 .32823 L .48674 .33045 L p .707 .577 .707 r
F P
0 g
s
.55048 .68016 m .54487 .63028 L .57396 .6214 L p .707 .577 .707 r
F P
0 g
s
.57396 .6214 m .57957 .67128 L .55048 .68016 L p .707 .577 .707 r
F P
0 g
s
.54865 .76308 m .54891 .72585 L .57829 .72287 L p .707 .577 .707 r
F P
0 g
s
.54379 .8058 m .54452 .78688 L .57386 .78575 L p .707 .577 .707 r
F P
0 g
s
.57386 .78575 m .57313 .80467 L .54379 .8058 L p .707 .577 .707 r
F P
0 g
s
.57829 .72287 m .57803 .76009 L .54865 .76308 L p .707 .577 .707 r
F P
0 g
s
.57803 .76009 m .57829 .72287 L .61012 .72234 L p .707 .577 .707 r
F P
0 g
s
.61012 .72234 m .60987 .75956 L .57803 .76009 L p .707 .577 .707 r
F P
0 g
s
.57313 .80467 m .57386 .78575 L .60567 .78642 L p .707 .577 .707 r
F P
0 g
s
.60567 .78642 m .60494 .80534 L .57313 .80467 L p .707 .577 .707 r
F P
0 g
s
.53167 .32823 m .54281 .82181 L .58427 .81528 L p .707 .577 .707 r
F P
0 g
s
.57957 .67128 m .57396 .6214 L .60561 .61709 L p .707 .577 .707 r
F P
0 g
s
.60561 .61709 m .61122 .66697 L .57957 .67128 L p .707 .577 .707 r
F P
0 g
s
.58427 .81528 m .57314 .3217 L .53167 .32823 L p .707 .577 .707 r
F P
0 g
s
.45388 .82174 m .44274 .32816 L .40397 .32157 L p .707 .577 .707 r
F P
0 g
s
.44274 .32816 m .45388 .82174 L .49788 .82403 L p .707 .577 .707 r
F P
0 g
s
.69837 .64676 m .70398 .69664 L .69109 .68325 L p .707 .577 .707 r
F P
0 g
s
.69109 .68325 m .68548 .63337 L .69837 .64676 L p .707 .577 .707 r
F P
0 g
s
.64129 .72433 m .64104 .76155 L .60987 .75956 L p .707 .577 .707 r
F P
0 g
s
.60987 .75956 m .61012 .72234 L .64129 .72433 L p .707 .577 .707 r
F P
0 g
s
.63683 .78882 m .6361 .80774 L .60494 .80534 L p .707 .577 .707 r
F P
0 g
s
.60494 .80534 m .60567 .78642 L .63683 .78882 L p .707 .577 .707 r
F P
0 g
s
.57314 .3217 m .58427 .81528 L .61821 .80509 L p .707 .577 .707 r
F P
0 g
s
.63671 .61777 m .64233 .66765 L .61122 .66697 L p .707 .577 .707 r
F P
0 g
s
.61122 .66697 m .60561 .61709 L .63671 .61777 L p .707 .577 .707 r
F P
0 g
s
.61821 .80509 m .60707 .31151 L .57314 .3217 L p .707 .577 .707 r
F P
0 g
s
.7053 .75038 m .70504 .7876 L .70215 .77955 L p .707 .577 .707 r
F P
0 g
s
.70215 .77955 m .7024 .74233 L .7053 .75038 L p .707 .577 .707 r
F P
0 g
s
.70097 .80905 m .70024 .82797 L .69729 .82227 L p .707 .577 .707 r
F P
0 g
s
.69729 .82227 m .69802 .80335 L .70097 .80905 L p .707 .577 .707 r
F P
0 g
s
.41511 .81515 m .40397 .32157 L .37423 .31133 L p .707 .577 .707 r
F P
0 g
s
.40397 .32157 m .41511 .81515 L .45388 .82174 L p .707 .577 .707 r
F P
0 g
s
.25718 .73219 m .25157 .68231 L .22046 .68163 L p .707 .577 .707 r
F P
0 g
s
.25157 .68231 m .25718 .73219 L .28883 .72788 L p .707 .577 .707 r
F P
0 g
s
.28883 .72788 m .28322 .678 L .25157 .68231 L p .707 .577 .707 r
F P
0 g
s
.68548 .63337 m .69109 .68325 L .66985 .67326 L p .707 .577 .707 r
F P
0 g
s
.66985 .67326 m .66424 .62338 L .68548 .63337 L p .707 .577 .707 r
F P
0 g
s
.28322 .678 m .28883 .72788 L .31792 .719 L p .707 .577 .707 r
F P
0 g
s
.31792 .719 m .3123 .66912 L .28322 .678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22607 .73151 m .22046 .68163 L .19294 .67602 L p .707 .577 .707 r
F P
0 g
s
.22046 .68163 m .22607 .73151 L .25718 .73219 L p .707 .577 .707 r
F P
0 g
s
.6361 .80774 m .63683 .78882 L .6643 .79272 L p .707 .577 .707 r
F P
0 g
s
.60707 .31151 m .61821 .80509 L .64129 .79224 L p .707 .577 .707 r
F P
0 g
s
.64233 .66765 m .63671 .61777 L .66424 .62338 L p .707 .577 .707 r
F P
0 g
s
.64129 .79224 m .63015 .29865 L .60707 .31151 L p .707 .577 .707 r
F P
0 g
s
.3123 .66912 m .31792 .719 L .3416 .70641 L p .707 .577 .707 r
F P
0 g
s
.3416 .70641 m .33599 .65653 L .3123 .66912 L p .707 .577 .707 r
F P
0 g
s
.7024 .74233 m .70215 .77955 L .68955 .77206 L p .707 .577 .707 r
F P
0 g
s
.68955 .77206 m .68981 .73484 L .7024 .74233 L p .707 .577 .707 r
F P
0 g
s
.69802 .80335 m .69729 .82227 L .68465 .81664 L p .707 .577 .707 r
F P
0 g
s
.68465 .81664 m .68538 .79772 L .69802 .80335 L p .707 .577 .707 r
F P
0 g
s
.25332 .77408 m .25358 .73686 L .22241 .73487 L p .707 .577 .707 r
F P
0 g
s
.25358 .73686 m .25332 .77408 L .28515 .77356 L p .707 .577 .707 r
F P
0 g
s
.28515 .77356 m .28541 .73634 L .25358 .73686 L p .707 .577 .707 r
F P
0 g
s
.66424 .62338 m .66985 .67326 L .64233 .66765 L p .707 .577 .707 r
F P
0 g
s
.19855 .7259 m .19294 .67602 L .17169 .66603 L p .707 .577 .707 r
F P
0 g
s
.19294 .67602 m .19855 .7259 L .22607 .73151 L p .707 .577 .707 r
F P
0 g
s
.24876 .80385 m .24949 .78493 L .21832 .78253 L p .707 .577 .707 r
F P
0 g
s
.24949 .78493 m .24876 .80385 L .28056 .80452 L p .707 .577 .707 r
F P
0 g
s
.28056 .80452 m .28129 .7856 L .24949 .78493 L p .707 .577 .707 r
F P
0 g
s
.28541 .73634 m .28515 .77356 L .31454 .77057 L p .707 .577 .707 r
F P
0 g
s
.31454 .77057 m .31479 .73335 L .28541 .73634 L p .707 .577 .707 r
F P
0 g
s
.38537 .80491 m .37423 .31133 L .35644 .29844 L p .707 .577 .707 r
F P
0 g
s
.37423 .31133 m .38537 .80491 L .41511 .81515 L p .707 .577 .707 r
F P
0 g
s
.28129 .7856 m .28056 .80452 L .3099 .80339 L p .707 .577 .707 r
F P
0 g
s
.3099 .80339 m .31063 .78447 L .28129 .7856 L p .707 .577 .707 r
F P
0 g
s
.21832 .78253 m .21759 .80145 L .24876 .80385 L p .707 .577 .707 r
F P
0 g
s
.22215 .7721 m .22241 .73487 L .19495 .73057 L p .707 .577 .707 r
F P
0 g
s
.22241 .73487 m .22215 .7721 L .25332 .77408 L p .707 .577 .707 r
F P
0 g
s
.33599 .65653 m .3416 .70641 L .35756 .69135 L p .707 .577 .707 r
F P
0 g
s
.35756 .69135 m .35195 .64147 L .33599 .65653 L p .707 .577 .707 r
F P
0 g
s
.21759 .80145 m .21832 .78253 L .19086 .77863 L p .707 .577 .707 r
F P
0 g
s
.19086 .77863 m .19013 .79755 L .21759 .80145 L p .707 .577 .707 r
F P
0 g
s
.31479 .73335 m .31454 .77057 L .33859 .76542 L p .707 .577 .707 r
F P
0 g
s
.33859 .76542 m .33884 .7282 L .31479 .73335 L p .707 .577 .707 r
F P
0 g
s
.19495 .73057 m .19469 .76779 L .22215 .7721 L p .707 .577 .707 r
F P
0 g
s
.31063 .78447 m .3099 .80339 L .3339 .80059 L p .707 .577 .707 r
F P
0 g
s
.3339 .80059 m .33463 .78167 L .31063 .78447 L p .707 .577 .707 r
F P
0 g
s
.68981 .73484 m .68955 .77206 L .6685 .76586 L p .707 .577 .707 r
F P
0 g
s
.6685 .76586 m .66875 .72864 L .68981 .73484 L p .707 .577 .707 r
F P
0 g
s
.19469 .76779 m .19495 .73057 L .17389 .72437 L p .707 .577 .707 r
F P
0 g
s
.1773 .71591 m .17169 .66603 L .15881 .65264 L p .707 .577 .707 r
F P
0 g
s
.17169 .66603 m .1773 .71591 L .19855 .7259 L p .707 .577 .707 r
F P
0 g
s
.66875 .72864 m .6685 .76586 L .64104 .76155 L p .707 .577 .707 r
F P
0 g
s
.64104 .76155 m .64129 .72433 L .66875 .72864 L p .707 .577 .707 r
F P
0 g
s
.63015 .29865 m .64129 .79224 L .65126 .77798 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64012 .28439 L .63015 .29865 L p .707 .577 .707 r
F P
0 g
s
.68538 .79772 m .68465 .81664 L .66357 .81164 L p .707 .577 .707 r
F P
0 g
s
.66357 .81164 m .6643 .79272 L .68538 .79772 L p .707 .577 .707 r
F P
0 g
s
.19013 .79755 m .19086 .77863 L .16977 .77363 L p .707 .577 .707 r
F P
0 g
s
.16977 .77363 m .16904 .79255 L .19013 .79755 L p .707 .577 .707 r
F P
0 g
s
.35195 .64147 m .35756 .69135 L .36423 .6753 L p .707 .577 .707 r
F P
0 g
s
.36423 .6753 m .35862 .62542 L .35195 .64147 L p .707 .577 .707 r
F P
0 g
s
.17389 .72437 m .17363 .76159 L .19469 .76779 L p .707 .577 .707 r
F P
0 g
s
.33884 .7282 m .33859 .76542 L .35495 .7586 L p .707 .577 .707 r
F P
0 g
s
.35495 .7586 m .35521 .72138 L .33884 .7282 L p .707 .577 .707 r
F P
0 g
s
.33463 .78167 m .3339 .80059 L .35021 .79637 L p .707 .577 .707 r
F P
0 g
s
.35021 .79637 m .35094 .77745 L .33463 .78167 L p .707 .577 .707 r
F P
0 g
s
.35862 .62542 m .36423 .6753 L .36097 .65982 L p .707 .577 .707 r
F P
0 g
s
.36757 .79202 m .35644 .29844 L .35232 .28417 L p .707 .577 .707 r
F P
0 g
s
.35644 .29844 m .36757 .79202 L .38537 .80491 L p .707 .577 .707 r
F P
0 g
s
.17363 .76159 m .17389 .72437 L .1613 .71688 L p .707 .577 .707 r
F P
0 g
s
.6643 .79272 m .66357 .81164 L .6361 .80774 L p .707 .577 .707 r
F P
0 g
s
.16904 .79255 m .16977 .77363 L .15714 .768 L p .707 .577 .707 r
F P
0 g
s
.16442 .70252 m .15881 .65264 L .15554 .63716 L p .707 .577 .707 r
F P
0 g
s
.15881 .65264 m .16442 .70252 L .1773 .71591 L p .707 .577 .707 r
F P
0 g
s
.15714 .768 m .15641 .78692 L .16904 .79255 L p .707 .577 .707 r
F P
0 g
s
.1613 .71688 m .16104 .7541 L .17363 .76159 L p .707 .577 .707 r
F P
0 g
s
.36097 .65982 m .35536 .60994 L .35862 .62542 L p .707 .577 .707 r
F P
0 g
s
.35521 .72138 m .35495 .7586 L .36203 .75078 L p .707 .577 .707 r
F P
0 g
s
.36203 .75078 m .36229 .71356 L .35521 .72138 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64897 .77004 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64666 .7256 m .63735 .72145 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64656 .7237 m .64376 .53234 L .64897 .77004 L .707 .577 .707 r
F
.63735 .72145 m .63662 .74037 L .64769 .7453 L p F P
0 g
s
.64769 .7453 m .64926 .746 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64754 .74246 m .63735 .72145 L .64769 .7453 L .707 .577 .707 r
F
.64656 .7237 m .64283 .56343 L .64376 .53234 L F
.646 .71297 m .64418 .63221 L p .64656 .7237 L F P
0 g
s
.64418 .63221 m .63601 .27012 L p .64446 .63343 L .707 .577 .707 r
F P
0 g
s
.64418 .63221 m .64446 .63343 L .64656 .7237 L .707 .577 .707 r
F
.63601 .27012 m .64411 .62916 L p .62935 .75082 L F P
0 g
s
.63662 .74037 m .63735 .72145 L .63688 .72055 L p .707 .577 .707 r
F P
0 g
s
.63662 .74037 m .63688 .72055 L .63592 .73267 L .707 .577 .707 r
F
.63421 .75434 m .62935 .75082 L p .64411 .62916 L F P
0 g
s
.6344 .71575 m .63367 .73467 L .63662 .74037 L p .707 .577 .707 r
F P
0 g
s
.64411 .62916 m .64715 .7637 L .63421 .75434 L p .707 .577 .707 r
F P
0 g
s
.63688 .72055 m .6344 .71575 L p .63592 .73267 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .63576 .58455 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .64118 .61918 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .63902 .60003 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64487 .49481 m .65126 .77798 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .65752 .6633 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .64118 .61918 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .64463 .64991 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63601 .27012 m .64012 .28439 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64283 .56343 m .63601 .27012 L .64376 .53234 L .707 .577 .707 r
F
.64715 .7637 m .646 .71297 L p .64656 .7237 L F P
0 g
s
.64897 .77004 m .64715 .7637 L p .64656 .7237 L .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64999 .72708 L .64666 .7256 L p .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64666 .7256 L .64754 .74246 L .707 .577 .707 r
F
.65752 .6633 m .65191 .61342 L .64166 .60277 L p F P
0 g
s
.64166 .60277 m .63902 .60003 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.65752 .6633 m .64166 .60277 L .64149 .60849 L .707 .577 .707 r
F
.64012 .28439 m .64487 .49481 L p .64376 .53234 L F P
0 g
s
.35094 .77745 m .35021 .79637 L .35723 .79116 L p .707 .577 .707 r
F P
0 g
s
.35723 .79116 m .35796 .77224 L .35094 .77745 L p .707 .577 .707 r
F P
0 g
s
.16104 .7541 m .1613 .71688 L .1584 .70883 L p .707 .577 .707 r
F P
0 g
s
.16115 .68704 m .16442 .70252 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.15554 .63716 m .1587 .66522 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1587 .66522 m .16115 .68704 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1584 .70883 m .15814 .74605 L .16104 .7541 L p .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .1584 .70883 L .16274 .70403 L p .707 .577 .707 r
F P
0 g
s
.16274 .70403 m .16548 .70101 L p .16362 .71244 L .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .16274 .70403 L .16362 .71244 L .707 .577 .707 r
F
.16115 .68704 m .15554 .63716 L .16222 .62111 L p F P
0 g
s
.15641 .78692 m .15714 .768 L .15418 .7623 L p .707 .577 .707 r
F P
0 g
s
.15418 .7623 m .15345 .78122 L .15641 .78692 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35536 .60994 m .36097 .65982 L .34808 .64643 L p .707 .577 .707 r
F P
0 g
s
.36229 .71356 m .36203 .75078 L .35914 .74273 L p .707 .577 .707 r
F P
0 g
s
.35914 .74273 m .35939 .70551 L .36229 .71356 L p .707 .577 .707 r
F P
0 g
s
.35232 .28417 m .36346 .77775 L .36757 .79202 L p .707 .577 .707 r
F P
0 g
s
.36346 .77775 m .35232 .28417 L .36229 .2699 L p .707 .577 .707 r
F P
0 g
s
.34808 .64643 m .34247 .59655 L .35536 .60994 L p .707 .577 .707 r
F P
0 g
s
.35796 .77224 m .35723 .79116 L .35428 .78546 L p .707 .577 .707 r
F P
0 g
s
.35428 .78546 m .35501 .76653 L .35796 .77224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16783 .67099 m .16222 .62111 L .17818 .60605 L p .707 .577 .707 r
F P
0 g
s
.16222 .62111 m .16783 .67099 L .16115 .68704 L p .707 .577 .707 r
F P
0 g
s
.62935 .75082 m .61821 .25723 L .63601 .27012 L p .707 .577 .707 r
F P
0 g
s
.15345 .78122 m .15418 .7623 L .16121 .75709 L p .707 .577 .707 r
F P
0 g
s
.34247 .59655 m .34808 .64643 L .32684 .63644 L p .707 .577 .707 r
F P
0 g
s
.32684 .63644 m .32123 .58656 L .34247 .59655 L p .707 .577 .707 r
F P
0 g
s
.16121 .75709 m .16048 .77601 L .15345 .78122 L p .707 .577 .707 r
F P
0 g
s
.16548 .70101 m .16522 .73823 L .15814 .74605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35939 .70551 m .35914 .74273 L .34654 .73524 L p .707 .577 .707 r
F P
0 g
s
.34654 .73524 m .3468 .69802 L .35939 .70551 L p .707 .577 .707 r
F P
0 g
s
.37343 .76349 m .36229 .2699 L .38538 .25705 L p .707 .577 .707 r
F P
0 g
s
.36229 .2699 m .37343 .76349 L .36346 .77775 L p .707 .577 .707 r
F P
0 g
s
.17818 .60605 m .18379 .65593 L .16783 .67099 L p .707 .577 .707 r
F P
0 g
s
.18379 .65593 m .17818 .60605 L .20186 .59347 L p .707 .577 .707 r
F P
0 g
s
.35501 .76653 m .35428 .78546 L .34164 .77983 L p .707 .577 .707 r
F P
0 g
s
.34164 .77983 m .34237 .76091 L .35501 .76653 L p .707 .577 .707 r
F P
0 g
s
.32123 .58656 m .32684 .63644 L .29932 .63083 L p .707 .577 .707 r
F P
0 g
s
.29932 .63083 m .29371 .58095 L .32123 .58656 L p .707 .577 .707 r
F P
0 g
s
.16522 .73823 m .16548 .70101 L .18185 .69419 L p .707 .577 .707 r
F P
0 g
s
.16048 .77601 m .16121 .75709 L .17751 .75287 L p .707 .577 .707 r
F P
0 g
s
.17751 .75287 m .17678 .77179 L .16048 .77601 L p .707 .577 .707 r
F P
0 g
s
.18185 .69419 m .18159 .73141 L .16522 .73823 L p .707 .577 .707 r
F P
0 g
s
.20747 .64335 m .20186 .59347 L .23095 .58458 L p .707 .577 .707 r
F P
0 g
s
.20186 .59347 m .20747 .64335 L .18379 .65593 L p .707 .577 .707 r
F P
0 g
s
.61821 .25723 m .62935 .75082 L .59961 .74058 L p .707 .577 .707 r
F P
0 g
s
.59961 .74058 m .58847 .24699 L .61821 .25723 L p .707 .577 .707 r
F P
0 g
s
.29371 .58095 m .29932 .63083 L .26821 .63015 L p .707 .577 .707 r
F P
0 g
s
.26821 .63015 m .2626 .58027 L .29371 .58095 L p .707 .577 .707 r
F P
0 g
s
.3468 .69802 m .34654 .73524 L .32549 .72904 L p .707 .577 .707 r
F P
0 g
s
.32549 .72904 m .32574 .69182 L .3468 .69802 L p .707 .577 .707 r
F P
0 g
s
.23656 .63446 m .23095 .58458 L .2626 .58027 L p .707 .577 .707 r
F P
0 g
s
.23095 .58458 m .23656 .63446 L .20747 .64335 L p .707 .577 .707 r
F P
0 g
s
.2626 .58027 m .26821 .63015 L .23656 .63446 L p .707 .577 .707 r
F P
0 g
s
.34237 .76091 m .34164 .77983 L .32056 .77482 L p .707 .577 .707 r
F P
0 g
s
.32056 .77482 m .32129 .7559 L .34237 .76091 L p .707 .577 .707 r
F P
0 g
s
.18159 .73141 m .18185 .69419 L .2059 .68904 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .37343 .76349 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.38949 .4392 m .39651 .75063 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .38538 .25705 L .41931 .24686 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .40763 .50485 L .42658 .70051 L .707 .577 .707 r
F
.41538 .74497 m .39651 .75063 L p .42658 .70051 L F P
0 g
s
.4185 .70224 m .41777 .72116 L .42141 .72102 L p .707 .577 .707 r
F P
0 g
s
.42141 .72102 m .44711 .72003 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.42511 .70635 m .4185 .70224 L .42141 .72102 L .707 .577 .707 r
F
.44711 .72003 m .44784 .70111 L .42622 .70194 L p F P
0 g
s
.42622 .70194 m .4185 .70224 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.44711 .72003 m .42622 .70194 L .42511 .70635 L .707 .577 .707 r
F
.42601 .54409 m .4293 .68971 L p .40763 .50485 L F P
0 g
s
.4293 .68971 m .43045 .74044 L p .42658 .70051 L .707 .577 .707 r
F P
0 g
s
.40763 .50485 m .4293 .68971 L .42658 .70051 L .707 .577 .707 r
F
.43045 .74044 m .41538 .74497 L p .42658 .70051 L F P
0 g
s
.41931 .24686 m .42601 .54409 L p .40763 .50485 L .707 .577 .707 r
F P
0 g
s
.43045 .74044 m .41931 .24686 L .46077 .24033 L p .707 .577 .707 r
F P
0 g
s
.46077 .24033 m .47191 .73392 L .46058 .7357 L p .707 .577 .707 r
F P
0 g
s
.44784 .70111 m .44711 .72003 L .4563 .71896 L p .707 .577 .707 r
F P
0 g
s
.45258 .7044 m .44784 .70111 L .4563 .71896 L .707 .577 .707 r
F
.43646 .6413 m .46077 .24033 L .46058 .7357 L F
.47191 .73392 m .46077 .24033 L .5057 .23811 L p F P
0 g
s
.4711 .71723 m .47183 .69831 L .44784 .70111 L p .707 .577 .707 r
F P
0 g
s
.46058 .7357 m .43045 .74044 L p .43646 .6413 L .707 .577 .707 r
F P
0 g
s
.4563 .71896 m .4711 .71723 L p .45258 .7044 L .707 .577 .707 r
F P
0 g
s
.45512 .62957 m .45166 .59884 L p .42042 .58857 L .707 .577 .707 r
F P
0 g
s
.45166 .59884 m .44951 .57969 L .44354 .58151 L p .707 .577 .707 r
F P
0 g
s
.44354 .58151 m .42042 .58857 L p .45166 .59884 L .707 .577 .707 r
F P
0 g
s
.42236 .67579 m .42257 .64453 L p .39078 .6391 L .707 .577 .707 r
F P
0 g
s
.42257 .64453 m .42262 .63857 L .41681 .63867 L p .707 .577 .707 r
F P
0 g
s
.41681 .63867 m .39078 .6391 L p .42257 .64453 L .707 .577 .707 r
F P
0 g
s
.39438 .64276 m .39096 .61239 L p .35766 .5922 L .707 .577 .707 r
F P
0 g
s
.39096 .61239 m .38877 .59288 L .37141 .5925 L p .707 .577 .707 r
F P
0 g
s
.37141 .5925 m .35766 .5922 L p .39096 .61239 L .707 .577 .707 r
F P
0 g
s
.38877 .59288 m .39438 .64276 L .42126 .6391 L p .707 .577 .707 r
F P
0 g
s
.42262 .63857 m .42236 .67579 L .45174 .67281 L p .707 .577 .707 r
F P
0 g
s
.45174 .67281 m .45195 .64219 L p .42262 .63857 L .707 .577 .707 r
F P
0 g
s
.45195 .64219 m .452 .63559 L .4465 .63614 L p .707 .577 .707 r
F P
0 g
s
.4465 .63614 m .42262 .63857 L p .45195 .64219 L .707 .577 .707 r
F P
0 g
s
.42603 .63845 m .42281 .60986 L p .38877 .59288 L .707 .577 .707 r
F P
0 g
s
.42281 .60986 m .42042 .58857 L .40546 .59061 L p .707 .577 .707 r
F P
0 g
s
.40546 .59061 m .38877 .59288 L p .42281 .60986 L .707 .577 .707 r
F P
0 g
s
.42126 .6391 m .42603 .63845 L p .41999 .63106 L .707 .577 .707 r
F P
0 g
s
.41999 .63106 m .38877 .59288 L .42126 .6391 L .707 .577 .707 r
F
.38538 .25705 m .38949 .4392 L p .38217 .39315 L F P
0 g
s
.17678 .77179 m .17751 .75287 L .20151 .75006 L p .707 .577 .707 r
F P
0 g
s
.20151 .75006 m .20078 .76898 L .17678 .77179 L p .707 .577 .707 r
F P
0 g
s
.2059 .68904 m .20564 .72626 L .18159 .73141 L p .707 .577 .707 r
F P
0 g
s
.32574 .69182 m .32549 .72904 L .29803 .72474 L p .707 .577 .707 r
F P
0 g
s
.29803 .72474 m .29829 .68751 L .32574 .69182 L p .707 .577 .707 r
F P
0 g
s
.76537 .71261 m .76558 .68134 L p .73379 .67591 L .707 .577 .707 r
F P
0 g
s
.76558 .68134 m .76562 .67539 L .75982 .67548 L p .707 .577 .707 r
F P
0 g
s
.75982 .67548 m .73379 .67591 L p .76558 .68134 L .707 .577 .707 r
F P
0 g
s
.73739 .67958 m .73397 .6492 L p .70067 .62902 L .707 .577 .707 r
F P
0 g
s
.73397 .6492 m .73178 .6297 L .71442 .62932 L p .707 .577 .707 r
F P
0 g
s
.71442 .62932 m .70067 .62902 L p .73397 .6492 L .707 .577 .707 r
F P
0 g
s
.76562 .67539 m .76537 .71261 L .79475 .70962 L p .707 .577 .707 r
F P
0 g
s
.79475 .70962 m .79496 .679 L p .76562 .67539 L .707 .577 .707 r
F P
0 g
s
.79496 .679 m .79501 .6724 L .78951 .67296 L p .707 .577 .707 r
F P
0 g
s
.78951 .67296 m .76562 .67539 L p .79496 .679 L .707 .577 .707 r
F P
0 g
s
.76904 .67527 m .76582 .64668 L p .73178 .6297 L .707 .577 .707 r
F P
0 g
s
.76582 .64668 m .76343 .62539 L .74847 .62743 L p .707 .577 .707 r
F P
0 g
s
.74847 .62743 m .73178 .6297 L p .76582 .64668 L .707 .577 .707 r
F P
0 g
s
.73178 .6297 m .73739 .67958 L .76904 .67527 L p .707 .577 .707 r
F P
0 g
s
.76343 .62539 m .76904 .67527 L .79813 .66638 L p .707 .577 .707 r
F P
0 g
s
.79813 .66638 m .79252 .6165 L .76343 .62539 L p .707 .577 .707 r
F P
0 g
s
.58847 .24699 m .59961 .74058 L .56084 .73399 L p .707 .577 .707 r
F P
0 g
s
.56084 .73399 m .5497 .2404 L .58847 .24699 L p .707 .577 .707 r
F P
0 g
s
.32129 .7559 m .32056 .77482 L .29309 .77093 L p .707 .577 .707 r
F P
0 g
s
.29309 .77093 m .29382 .75201 L .32129 .7559 L p .707 .577 .707 r
F P
0 g
s
.20564 .72626 m .2059 .68904 L .23528 .68605 L p .707 .577 .707 r
F P
0 g
s
.73353 .71313 m .73374 .68387 L p .70262 .67393 L .707 .577 .707 r
F P
0 g
s
.73374 .68387 m .73379 .67591 L .72649 .67545 L p .707 .577 .707 r
F P
0 g
s
.72649 .67545 m .70262 .67393 L p .73374 .68387 L .707 .577 .707 r
F P
0 g
s
.70262 .67393 m .70236 .71115 L .73353 .71313 L p .707 .577 .707 r
F P
0 g
s
.70628 .6789 m .7028 .6479 L p .67315 .62341 L .707 .577 .707 r
F P
0 g
s
.7028 .6479 m .70067 .62902 L .68355 .62553 L p .707 .577 .707 r
F P
0 g
s
.68355 .62553 m .67315 .62341 L p .7028 .6479 L .707 .577 .707 r
F P
0 g
s
.73379 .67591 m .73353 .71313 L .76537 .71261 L p .707 .577 .707 r
F P
0 g
s
.70067 .62902 m .70628 .6789 L .73739 .67958 L p .707 .577 .707 r
F P
0 g
s
.20078 .76898 m .20151 .75006 L .23085 .74894 L p .707 .577 .707 r
F P
0 g
s
.79252 .6165 m .79813 .66638 L .82181 .6538 L p .707 .577 .707 r
F P
0 g
s
.82181 .6538 m .8162 .60392 L .79252 .6165 L p .707 .577 .707 r
F P
0 g
s
.29829 .68751 m .29803 .72474 L .26686 .72275 L p .707 .577 .707 r
F P
0 g
s
.26686 .72275 m .26711 .68553 L .29829 .68751 L p .707 .577 .707 r
F P
0 g
s
.23085 .74894 m .23012 .76786 L .20078 .76898 L p .707 .577 .707 r
F P
0 g
s
.23528 .68605 m .23502 .72327 L .20564 .72626 L p .707 .577 .707 r
F P
0 g
s
.23502 .72327 m .23528 .68605 L .26711 .68553 L p .707 .577 .707 r
F P
0 g
s
.29382 .75201 m .29309 .77093 L .26193 .76853 L p .707 .577 .707 r
F P
0 g
s
.26193 .76853 m .26266 .74961 L .29382 .75201 L p .707 .577 .707 r
F P
0 g
s
.26711 .68553 m .26686 .72275 L .23502 .72327 L p .707 .577 .707 r
F P
0 g
s
.23012 .76786 m .23085 .74894 L .26266 .74961 L p .707 .577 .707 r
F P
0 g
s
.70236 .71115 m .70253 .68633 L p .67516 .66962 L .707 .577 .707 r
F P
0 g
s
.70253 .68633 m .70262 .67393 L .69391 .67256 L p .707 .577 .707 r
F P
0 g
s
.69391 .67256 m .67516 .66962 L p .70253 .68633 L .707 .577 .707 r
F P
0 g
s
.67876 .67329 m .67534 .64291 L p .65191 .61342 L .707 .577 .707 r
F P
0 g
s
.67534 .64291 m .67315 .62341 L .65896 .61673 L p .707 .577 .707 r
F P
0 g
s
.65896 .61673 m .65191 .61342 L p .67534 .64291 L .707 .577 .707 r
F P
0 g
s
.67315 .62341 m .67876 .67329 L .70628 .6789 L p .707 .577 .707 r
F P
0 g
s
.5497 .2404 m .56084 .73399 L .51684 .73169 L p .707 .577 .707 r
F P
0 g
s
.51684 .73169 m .5057 .23811 L .5497 .2404 L p .707 .577 .707 r
F P
0 g
s
.72897 .7573 m .7297 .73838 L .69854 .73598 L p .707 .577 .707 r
F P
0 g
s
.7297 .73838 m .72897 .7573 L .76078 .75797 L p .707 .577 .707 r
F P
0 g
s
.76078 .75797 m .76151 .73905 L .7297 .73838 L p .707 .577 .707 r
F P
0 g
s
.26266 .74961 m .26193 .76853 L .23012 .76786 L p .707 .577 .707 r
F P
0 g
s
.76151 .73905 m .76078 .75797 L .79012 .75685 L p .707 .577 .707 r
F P
0 g
s
.79012 .75685 m .79085 .73793 L .76151 .73905 L p .707 .577 .707 r
F P
0 g
s
.69854 .73598 m .69781 .7549 L .72897 .7573 L p .707 .577 .707 r
F P
0 g
s
.8162 .60392 m .82181 .6538 L .83777 .63874 L p .707 .577 .707 r
F P
0 g
s
.83777 .63874 m .83216 .58886 L .8162 .60392 L p .707 .577 .707 r
F P
0 g
s
.69781 .7549 m .69854 .73598 L .67107 .73209 L p .707 .577 .707 r
F P
0 g
s
.79501 .6724 m .79475 .70962 L .8188 .70447 L p .707 .577 .707 r
F P
0 g
s
.8188 .70447 m .81906 .66725 L .79501 .6724 L p .707 .577 .707 r
F P
0 g
s
.5057 .23811 m .51684 .73169 L .47191 .73392 L p .707 .577 .707 r
F P
0 g
s
.67516 .66962 m .6749 .70684 L .70236 .71115 L p .707 .577 .707 r
F P
0 g
s
.67107 .73209 m .67034 .75101 L .69781 .7549 L p .707 .577 .707 r
F P
0 g
s
.79085 .73793 m .79012 .75685 L .81411 .75404 L p .707 .577 .707 r
F P
0 g
s
.81411 .75404 m .81484 .73512 L .79085 .73793 L p .707 .577 .707 r
F P
0 g
s
.6749 .70684 m .67516 .66962 L .6541 .66342 L p .707 .577 .707 r
F P
0 g
s
.65191 .61342 m .65752 .6633 L .67876 .67329 L p .707 .577 .707 r
F P
0 g
s
.67034 .75101 m .67107 .73209 L .64999 .72708 L p .707 .577 .707 r
F P
0 g
s
.6541 .66342 m .65385 .70064 L .6749 .70684 L p .707 .577 .707 r
F P
0 g
s
.64999 .72708 m .64926 .746 L .67034 .75101 L p .707 .577 .707 r
F P
0 g
s
.83216 .58886 m .83777 .63874 L .84445 .62269 L p .707 .577 .707 r
F P
0 g
s
.84445 .62269 m .83884 .57281 L .83216 .58886 L p .707 .577 .707 r
F P
0 g
s
.81906 .66725 m .8188 .70447 L .83517 .69765 L p .707 .577 .707 r
F P
0 g
s
.83517 .69765 m .83542 .66043 L .81906 .66725 L p .707 .577 .707 r
F P
0 g
s
.81484 .73512 m .81411 .75404 L .83042 .74982 L p .707 .577 .707 r
F P
0 g
s
.83042 .74982 m .83115 .7309 L .81484 .73512 L p .707 .577 .707 r
F P
0 g
s
.65385 .70064 m .6541 .66342 L .64151 .65593 L p .707 .577 .707 r
F P
0 g
s
.64151 .65593 m .64125 .69315 L .65385 .70064 L p .707 .577 .707 r
F P
0 g
s
.83884 .57281 m .84445 .62269 L .84118 .60721 L p .707 .577 .707 r
F P
0 g
s
.84118 .60721 m .83557 .55733 L .83884 .57281 L p .707 .577 .707 r
F P
0 g
s
.83542 .66043 m .83517 .69765 L .84225 .68983 L p .707 .577 .707 r
F P
0 g
s
.84225 .68983 m .84251 .65261 L .83542 .66043 L p .707 .577 .707 r
F P
0 g
s
.83115 .7309 m .83042 .74982 L .83744 .74461 L p .707 .577 .707 r
F P
0 g
s
.83744 .74461 m .83817 .72569 L .83115 .7309 L p .707 .577 .707 r
F P
0 g
s
.64125 .69315 m .64151 .65593 L .63861 .64788 L p .707 .577 .707 r
F P
0 g
s
.64137 .63443 m .64463 .64991 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63576 .58455 m .63886 .61213 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63886 .61213 m .64137 .63443 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63861 .64788 m .63835 .6851 L .64125 .69315 L p .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .63861 .64788 L .64217 .64395 L p .707 .577 .707 r
F P
0 g
s
.64217 .64395 m .64569 .64006 L p .6433 .65475 L .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .64217 .64395 L .6433 .65475 L .707 .577 .707 r
F
.64137 .63443 m .63576 .58455 L .64243 .5685 L p F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83557 .55733 m .84118 .60721 L .8283 .59382 L p .707 .577 .707 r
F P
0 g
s
.8283 .59382 m .82269 .54394 L .83557 .55733 L p .707 .577 .707 r
F P
0 g
s
.84251 .65261 m .84225 .68983 L .83935 .68179 L p .707 .577 .707 r
F P
0 g
s
.83935 .68179 m .83961 .64456 L .84251 .65261 L p .707 .577 .707 r
F P
0 g
s
.83817 .72569 m .83744 .74461 L .83449 .73891 L p .707 .577 .707 r
F P
0 g
s
.83449 .73891 m .83522 .71999 L .83817 .72569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64804 .61838 m .64243 .5685 L .65839 .55344 L p .707 .577 .707 r
F P
0 g
s
.64243 .5685 m .64804 .61838 L .64137 .63443 L p .707 .577 .707 r
F P
0 g
s
.63367 .73467 m .6344 .71575 L .64142 .71054 L p .707 .577 .707 r
F P
0 g
s
.82269 .54394 m .8283 .59382 L .80705 .58383 L p .707 .577 .707 r
F P
0 g
s
.80705 .58383 m .80144 .53395 L .82269 .54394 L p .707 .577 .707 r
F P
0 g
s
.64569 .64006 m .64544 .67728 L .63835 .6851 L p .707 .577 .707 r
F P
0 g
s
.42042 .58857 m .42603 .63845 L .45512 .62957 L p .707 .577 .707 r
F P
0 g
s
.64142 .71054 m .64069 .72946 L .63367 .73467 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39052 .67632 m .39073 .64705 L p .35961 .63711 L .707 .577 .707 r
F P
0 g
s
.39073 .64705 m .39078 .6391 L .38348 .63863 L p .707 .577 .707 r
F P
0 g
s
.38348 .63863 m .35961 .63711 L p .39073 .64705 L .707 .577 .707 r
F P
0 g
s
.35961 .63711 m .35935 .67433 L .39052 .67632 L p .707 .577 .707 r
F P
0 g
s
.36327 .64208 m .35979 .61109 L p .33014 .58659 L .707 .577 .707 r
F P
0 g
s
.35979 .61109 m .35766 .5922 L .34054 .58871 L p .707 .577 .707 r
F P
0 g
s
.34054 .58871 m .33014 .58659 L p .35979 .61109 L .707 .577 .707 r
F P
0 g
s
.39078 .6391 m .39052 .67632 L .42236 .67579 L p .707 .577 .707 r
F P
0 g
s
.35766 .5922 m .36327 .64208 L .39438 .64276 L p .707 .577 .707 r
F P
0 g
s
.83961 .64456 m .83935 .68179 L .82676 .67429 L p .707 .577 .707 r
F P
0 g
s
.82676 .67429 m .82701 .63707 L .83961 .64456 L p .707 .577 .707 r
F P
0 g
s
.44951 .57969 m .45512 .62957 L .4788 .61698 L p .707 .577 .707 r
F P
0 g
s
.4788 .61698 m .47319 .5671 L .44951 .57969 L p .707 .577 .707 r
F P
0 g
s
.65839 .55344 m .664 .60332 L .64804 .61838 L p .707 .577 .707 r
F P
0 g
s
.664 .60332 m .65839 .55344 L .68207 .54085 L p .707 .577 .707 r
F P
0 g
s
.83522 .71999 m .83449 .73891 L .82185 .73328 L p .707 .577 .707 r
F P
0 g
s
.82185 .73328 m .82259 .71436 L .83522 .71999 L p .707 .577 .707 r
F P
0 g
s
.64544 .67728 m .64569 .64006 L .66206 .63324 L p .707 .577 .707 r
F P
0 g
s
.80144 .53395 m .80705 .58383 L .77953 .57822 L p .707 .577 .707 r
F P
0 g
s
.77953 .57822 m .77392 .52834 L .80144 .53395 L p .707 .577 .707 r
F P
0 g
s
.35935 .67433 m .35952 .64952 L p .33215 .6328 L .707 .577 .707 r
F P
0 g
s
.35952 .64952 m .35961 .63711 L .3509 .63574 L p .707 .577 .707 r
F P
0 g
s
.3509 .63574 m .33215 .6328 L p .35952 .64952 L .707 .577 .707 r
F P
0 g
s
.33575 .63647 m .33233 .60609 L p .3089 .5766 L .707 .577 .707 r
F P
0 g
s
.33233 .60609 m .33014 .58659 L .31595 .57992 L p .707 .577 .707 r
F P
0 g
s
.31595 .57992 m .3089 .5766 L p .33233 .60609 L .707 .577 .707 r
F P
0 g
s
.33014 .58659 m .33575 .63647 L .36327 .64208 L p .707 .577 .707 r
F P
0 g
s
.38596 .72049 m .38669 .70157 L .35553 .69917 L p .707 .577 .707 r
F P
0 g
s
.38669 .70157 m .38596 .72049 L .41777 .72116 L p .707 .577 .707 r
F P
0 g
s
.41777 .72116 m .4185 .70224 L .38669 .70157 L p .707 .577 .707 r
F P
0 g
s
.35553 .69917 m .3548 .71809 L .38596 .72049 L p .707 .577 .707 r
F P
0 g
s
.47319 .5671 m .4788 .61698 L .49476 .60192 L p .707 .577 .707 r
F P
0 g
s
.49476 .60192 m .48915 .55204 L .47319 .5671 L p .707 .577 .707 r
F P
0 g
s
.64069 .72946 m .64142 .71054 L .65773 .70632 L p .707 .577 .707 r
F P
0 g
s
.66206 .63324 m .6618 .67047 L .64544 .67728 L p .707 .577 .707 r
F P
0 g
s
.3548 .71809 m .35553 .69917 L .32806 .69527 L p .707 .577 .707 r
F P
0 g
s
.65773 .70632 m .657 .72524 L .64069 .72946 L p .707 .577 .707 r
F P
0 g
s
.452 .63559 m .45174 .67281 L .47579 .66765 L p .707 .577 .707 r
F P
0 g
s
.47579 .66765 m .47605 .63043 L .452 .63559 L p .707 .577 .707 r
F P
0 g
s
.68769 .59073 m .68207 .54085 L .71116 .53197 L p .707 .577 .707 r
F P
0 g
s
.68207 .54085 m .68769 .59073 L .664 .60332 L p .707 .577 .707 r
F P
0 g
s
.33215 .6328 m .33189 .67003 L .35935 .67433 L p .707 .577 .707 r
F P
0 g
s
.32806 .69527 m .32733 .71419 L .3548 .71809 L p .707 .577 .707 r
F P
0 g
s
.77392 .52834 m .77953 .57822 L .74842 .57754 L p .707 .577 .707 r
F P
0 g
s
.74842 .57754 m .74281 .52766 L .77392 .52834 L p .707 .577 .707 r
F P
0 g
s
.82701 .63707 m .82676 .67429 L .8057 .66809 L p .707 .577 .707 r
F P
0 g
s
.8057 .66809 m .80596 .63087 L .82701 .63707 L p .707 .577 .707 r
F P
0 g
s
.33189 .67003 m .33215 .6328 L .31109 .6266 L p .707 .577 .707 r
F P
0 g
s
.71677 .58185 m .71116 .53197 L .74281 .52766 L p .707 .577 .707 r
F P
0 g
s
.71116 .53197 m .71677 .58185 L .68769 .59073 L p .707 .577 .707 r
F P
0 g
s
.31451 .62648 m .3089 .5766 L .29601 .56321 L p .707 .577 .707 r
F P
0 g
s
.3089 .5766 m .31451 .62648 L .33575 .63647 L p .707 .577 .707 r
F P
0 g
s
.74281 .52766 m .74842 .57754 L .71677 .58185 L p .707 .577 .707 r
F P
0 g
s
.82259 .71436 m .82185 .73328 L .80077 .72827 L p .707 .577 .707 r
F P
0 g
s
.80077 .72827 m .8015 .70935 L .82259 .71436 L p .707 .577 .707 r
F P
0 g
s
.32733 .71419 m .32806 .69527 L .30698 .69027 L p .707 .577 .707 r
F P
0 g
s
.6618 .67047 m .66206 .63324 L .68611 .62809 L p .707 .577 .707 r
F P
0 g
s
.31109 .6266 m .31084 .66382 L .33189 .67003 L p .707 .577 .707 r
F P
0 g
s
.30698 .69027 m .30625 .70919 L .32733 .71419 L p .707 .577 .707 r
F P
0 g
s
.48915 .55204 m .49476 .60192 L .50144 .58587 L p .707 .577 .707 r
F P
0 g
s
.50144 .58587 m .49583 .53599 L .48915 .55204 L p .707 .577 .707 r
F P
0 g
s
.47605 .63043 m .47579 .66765 L .49216 .66083 L p .707 .577 .707 r
F P
0 g
s
.49216 .66083 m .49241 .62361 L .47605 .63043 L p .707 .577 .707 r
F P
0 g
s
.657 .72524 m .65773 .70632 L .68172 .70351 L p .707 .577 .707 r
F P
0 g
s
.68611 .62809 m .68585 .66531 L .6618 .67047 L p .707 .577 .707 r
F P
0 g
s
.68172 .70351 m .68099 .72243 L .657 .72524 L p .707 .577 .707 r
F P
0 g
s
.80596 .63087 m .8057 .66809 L .77824 .66379 L p .707 .577 .707 r
F P
0 g
s
.77824 .66379 m .7785 .62657 L .80596 .63087 L p .707 .577 .707 r
F P
0 g
s
.47183 .69831 m .4711 .71723 L .48741 .71301 L p .707 .577 .707 r
F P
0 g
s
.48741 .71301 m .48814 .69409 L .47183 .69831 L p .707 .577 .707 r
F P
0 g
s
.31084 .66382 m .31109 .6266 L .2985 .61911 L p .707 .577 .707 r
F P
0 g
s
.68585 .66531 m .68611 .62809 L .71549 .6251 L p .707 .577 .707 r
F P
0 g
s
.30162 .61309 m .29601 .56321 L .29275 .54773 L p .707 .577 .707 r
F P
0 g
s
.29601 .56321 m .30162 .61309 L .31451 .62648 L p .707 .577 .707 r
F P
0 g
s
.8015 .70935 m .80077 .72827 L .7733 .72438 L p .707 .577 .707 r
F P
0 g
s
.7733 .72438 m .77403 .70546 L .8015 .70935 L p .707 .577 .707 r
F P
0 g
s
.30625 .70919 m .30698 .69027 L .29434 .68464 L p .707 .577 .707 r
F P
0 g
s
.2985 .61911 m .29824 .65633 L .31084 .66382 L p .707 .577 .707 r
F P
0 g
s
.29434 .68464 m .29361 .70356 L .30625 .70919 L p .707 .577 .707 r
F P
0 g
s
.7785 .62657 m .77824 .66379 L .74707 .6618 L p .707 .577 .707 r
F P
0 g
s
.74707 .6618 m .74733 .62458 L .7785 .62657 L p .707 .577 .707 r
F P
0 g
s
.68099 .72243 m .68172 .70351 L .71106 .70239 L p .707 .577 .707 r
F P
0 g
s
.71549 .6251 m .71524 .66232 L .68585 .66531 L p .707 .577 .707 r
F P
0 g
s
.49583 .53599 m .50144 .58587 L .49817 .57039 L p .707 .577 .707 r
F P
0 g
s
.49817 .57039 m .49256 .52051 L .49583 .53599 L p .707 .577 .707 r
F P
0 g
s
.49241 .62361 m .49216 .66083 L .49924 .65302 L p .707 .577 .707 r
F P
0 g
s
.49924 .65302 m .4995 .6158 L .49241 .62361 L p .707 .577 .707 r
F P
0 g
s
.71524 .66232 m .71549 .6251 L .74733 .62458 L p .707 .577 .707 r
F P
0 g
s
.71106 .70239 m .71033 .72131 L .68099 .72243 L p .707 .577 .707 r
F P
0 g
s
.74733 .62458 m .74707 .6618 L .71524 .66232 L p .707 .577 .707 r
F P
0 g
s
.77403 .70546 m .7733 .72438 L .74214 .72198 L p .707 .577 .707 r
F P
0 g
s
.74214 .72198 m .74287 .70306 L .77403 .70546 L p .707 .577 .707 r
F P
0 g
s
.48814 .69409 m .48741 .71301 L .49443 .70779 L p .707 .577 .707 r
F P
0 g
s
.49443 .70779 m .49516 .68887 L .48814 .69409 L p .707 .577 .707 r
F P
0 g
s
.71033 .72131 m .71106 .70239 L .74287 .70306 L p .707 .577 .707 r
F P
0 g
s
.29824 .65633 m .2985 .61911 L .2956 .61106 L p .707 .577 .707 r
F P
0 g
s
.74287 .70306 m .74214 .72198 L .71033 .72131 L p .707 .577 .707 r
F P
0 g
s
.29836 .59761 m .30162 .61309 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29275 .54773 m .29585 .57531 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29585 .57531 m .29836 .59761 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.2956 .61106 m .29534 .64829 L .29824 .65633 L p .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .2956 .61106 L .29916 .60713 L p .707 .577 .707 r
F P
0 g
s
.29916 .60713 m .30268 .60325 L p .30029 .61794 L .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .29916 .60713 L .30029 .61794 L .707 .577 .707 r
F
.29836 .59761 m .29275 .54773 L .29942 .53168 L p F P
0 g
s
.29361 .70356 m .29434 .68464 L .29139 .67894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29139 .67894 m .29066 .69786 L .29361 .70356 L p .707 .577 .707 r
F P
0 g
s
.49256 .52051 m .49817 .57039 L .48529 .557 L p .707 .577 .707 r
F P
0 g
s
.48529 .557 m .47968 .50712 L .49256 .52051 L p .707 .577 .707 r
F P
0 g
s
.4995 .6158 m .49924 .65302 L .49634 .64497 L p .707 .577 .707 r
F P
0 g
s
.49634 .64497 m .4966 .60775 L .4995 .6158 L p .707 .577 .707 r
F P
0 g
s
.49516 .68887 m .49443 .70779 L .49148 .70209 L p .707 .577 .707 r
F P
0 g
s
.49148 .70209 m .49221 .68317 L .49516 .68887 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30503 .58156 m .29942 .53168 L .31538 .51662 L p .707 .577 .707 r
F P
0 g
s
.29942 .53168 m .30503 .58156 L .29836 .59761 L p .707 .577 .707 r
F P
0 g
s
.29066 .69786 m .29139 .67894 L .29841 .67372 L p .707 .577 .707 r
F P
0 g
s
.47968 .50712 m .48529 .557 L .46404 .54701 L p .707 .577 .707 r
F P
0 g
s
.46404 .54701 m .45843 .49713 L .47968 .50712 L p .707 .577 .707 r
F P
0 g
s
.30268 .60325 m .30242 .64047 L .29534 .64829 L p .707 .577 .707 r
F P
0 g
s
.29841 .67372 m .29768 .69264 L .29066 .69786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4966 .60775 m .49634 .64497 L .48375 .63748 L p .707 .577 .707 r
F P
0 g
s
.48375 .63748 m .484 .60026 L .4966 .60775 L p .707 .577 .707 r
F P
0 g
s
.31538 .51662 m .32099 .5665 L .30503 .58156 L p .707 .577 .707 r
F P
0 g
s
.32099 .5665 m .31538 .51662 L .33906 .50404 L p .707 .577 .707 r
F P
0 g
s
.49221 .68317 m .49148 .70209 L .47884 .69647 L p .707 .577 .707 r
F P
0 g
s
.47884 .69647 m .47957 .67755 L .49221 .68317 L p .707 .577 .707 r
F P
0 g
s
.30242 .64047 m .30268 .60325 L .31905 .59643 L p .707 .577 .707 r
F P
0 g
s
.45843 .49713 m .46404 .54701 L .43652 .5414 L p .707 .577 .707 r
F P
0 g
s
.43652 .5414 m .43091 .49152 L .45843 .49713 L p .707 .577 .707 r
F P
0 g
s
.29768 .69264 m .29841 .67372 L .31472 .66951 L p .707 .577 .707 r
F P
0 g
s
.31905 .59643 m .31879 .63365 L .30242 .64047 L p .707 .577 .707 r
F P
0 g
s
.31472 .66951 m .31399 .68843 L .29768 .69264 L p .707 .577 .707 r
F P
0 g
s
.34467 .55392 m .33906 .50404 L .36815 .49515 L p .707 .577 .707 r
F P
0 g
s
.33906 .50404 m .34467 .55392 L .32099 .5665 L p .707 .577 .707 r
F P
0 g
s
.43091 .49152 m .43652 .5414 L .40541 .54072 L p .707 .577 .707 r
F P
0 g
s
.40541 .54072 m .3998 .49084 L .43091 .49152 L p .707 .577 .707 r
F P
0 g
s
.484 .60026 m .48375 .63748 L .46269 .63128 L p .707 .577 .707 r
F P
0 g
s
.46269 .63128 m .46295 .59406 L .484 .60026 L p .707 .577 .707 r
F P
0 g
s
.37376 .54503 m .36815 .49515 L .3998 .49084 L p .707 .577 .707 r
F P
0 g
s
.36815 .49515 m .37376 .54503 L .34467 .55392 L p .707 .577 .707 r
F P
0 g
s
.3998 .49084 m .40541 .54072 L .37376 .54503 L p .707 .577 .707 r
F P
0 g
s
.47957 .67755 m .47884 .69647 L .45776 .69146 L p .707 .577 .707 r
F P
0 g
s
.45776 .69146 m .45849 .67254 L .47957 .67755 L p .707 .577 .707 r
F P
0 g
s
.31879 .63365 m .31905 .59643 L .3431 .59127 L p .707 .577 .707 r
F P
0 g
s
.31399 .68843 m .31472 .66951 L .33871 .6667 L p .707 .577 .707 r
F P
0 g
s
.3431 .59127 m .34284 .6285 L .31879 .63365 L p .707 .577 .707 r
F P
0 g
s
.33871 .6667 m .33798 .68562 L .31399 .68843 L p .707 .577 .707 r
F P
0 g
s
.46295 .59406 m .46269 .63128 L .43523 .62697 L p .707 .577 .707 r
F P
0 g
s
.43523 .62697 m .43549 .58975 L .46295 .59406 L p .707 .577 .707 r
F P
0 g
s
.34284 .6285 m .3431 .59127 L .37248 .58829 L p .707 .577 .707 r
F P
0 g
s
.45849 .67254 m .45776 .69146 L .43029 .68757 L p .707 .577 .707 r
F P
0 g
s
.43029 .68757 m .43102 .66865 L .45849 .67254 L p .707 .577 .707 r
F P
0 g
s
.43549 .58975 m .43523 .62697 L .40406 .62498 L p .707 .577 .707 r
F P
0 g
s
.40406 .62498 m .40432 .58776 L .43549 .58975 L p .707 .577 .707 r
F P
0 g
s
.33798 .68562 m .33871 .6667 L .36805 .66558 L p .707 .577 .707 r
F P
0 g
s
.37248 .58829 m .37222 .62551 L .34284 .6285 L p .707 .577 .707 r
F P
0 g
s
.37222 .62551 m .37248 .58829 L .40432 .58776 L p .707 .577 .707 r
F P
0 g
s
.36805 .66558 m .36732 .6845 L .33798 .68562 L p .707 .577 .707 r
F P
0 g
s
.40432 .58776 m .40406 .62498 L .37222 .62551 L p .707 .577 .707 r
F P
0 g
s
.43102 .66865 m .43029 .68757 L .39913 .68517 L p .707 .577 .707 r
F P
0 g
s
.39913 .68517 m .39986 .66625 L .43102 .66865 L p .707 .577 .707 r
F P
0 g
s
.36732 .6845 m .36805 .66558 L .39986 .66625 L p .707 .577 .707 r
F P
0 g
s
.39986 .66625 m .39913 .68517 L .36732 .6845 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool=0027Ool0081oo`T0
00IJEP03001JEUYF00AJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001dOol007=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEP00001bOol006moo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP04001JEUYFFUH3001_Ool006aoo`<000QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006eoo`00JWoo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0`00Jgoo001XOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001YOol006Ioo`8000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0IWoo001UOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=o
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000AJEPl0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00<005YF00001@0015YF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0Hgoo001UOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1SOol0069oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00AJEP03001oogoo06=oo`00Ggoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH015YF00<007ooOol0Hgoo001MOol200000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1S
Ool005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06=oo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001HOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0Hgoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001GOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<007ooOol0Hgoo001FOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo01Eooa0003ioo`00EGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00ioo`L000AJEP03001JEUYF00EJEP04
001JEUYFFUH5000iOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3000gOol005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPd000EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02000eOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF009JEP@00003FUH005YF
00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20007Ool30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000cOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPD0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP8000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006Ool01000FUIJEP0025YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20003FUH01@00
FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000<Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH30002Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH300000eYF001JEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF008000=JEP05001JEUYFFUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
1000FUIJEP0015YF00@005YFFUH000Moo`03001JEP0000IJEP<000MJEP03001JEUYF00UJEP03001J
EUYF00<0009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH400000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0`0027oo00<005YF
00001EYF1@001UYF00<005YFFUH02EYF00<005YF00000eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH002moo`00Dgoo00@005YFFUH000AJEP03001oogoo00Qoo`03001JEP0000EJEPD000IJEP03001J
EUYF00UJEP8000AJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH0
00=JEP03001oogoo00Uoo`03001JEP0000EJEPD000IJEP03001JEUYF00MJEP800003FUH005YF00=J
EP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH2000<
Ool00`00FUH00006FUH30007FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000<000aoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00AWoo3`00
00=JEP0000000UYF0P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH30007FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF1P003goo10000UYF
00<005YFFUH00eYF00@005YFFUH002ioo`00@7oo1P0015YF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0`001goo00@005YFFUH000EJEP03001JEUYF00MJEP@0009JEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000IOol40004FUH00`00FUIJ
EP02000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03
001JEP0000<000=ooaX000MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH00002000OOol3000015YF001JEUYF0P00;Goo000iOol30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH30002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P000UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00=JEP<002Eoo`80009JEP8002eoo`00
=goo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF00000`000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF
009JEP04001JEUYFFUH2000?Ool3000EOol200001EYF001JEUYF0000;Goo000eOol20002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03
FUH01000FUH0000047oo1@004goo00@005YFFUIJEP800003FUH007oo02aoo`00<goo0P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH2000BOol5
000BOol00`00FUIJEP03FUH3000]Ool0039oo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP0057oo1@0047oo
0`001EYF00<005YF0000;Goo000aOol20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP0001Ioo`<0011oo`04001J
EUYF0005FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P00:7oo0P000eYF00<0
05YFFUH00eYF00@005YF000002aoo`00;goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF10008goo0`001UYF
00<005YFFUH00UYF00@005YFFUH002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH20002FUH2000MOol40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000^
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00T005YF
FUIJEP00FUH005YF000015YF1`000goo4`001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002aoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF0`001EYF200015YF00<005YFFUH00eYF
00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000EJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP03001JEUYF00=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF300000=JEP00FUH00eYF00<005YF00000`001eYF00<005YFFUH015YF1@001UYF00<005YF
FUH00eYF1P0015YF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH7000;Ool00`00FUH00003FUH500000eYF001JEP06FUH00`00FUIJ
EP04FUH50006FUH00`00FUIJEP0800001UYF00000000FUH000=JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00`001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00<007oo
Ool0;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04000BOol01000FUH005YF
0P001EYF1@0015YF00<005YFFUH015YF1@0000=JEP0000001P0015YF00<005YFFUH015YF0`000eYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH0
0000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP<0
01Ioo`06001JEP00001JEP001EYF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo000/Ool00`00FUH00005FUH01000
FUIJEUYF0P006Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000^Ool002aoo`04001JEUYF0004FUH01000FUIJEP006goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002aoo`04001JEUYF0004FUH3000AOol3
0008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000/Ool01000FUIJEP0015YF00<007ooOol047oo1@0027oo00D005YFFUIJEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001oogoo
015oo`D000Uoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00;7oo00D005YFFUH005YF008001Aoo`D000]oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`04001JEP00000G
Ool3000>OolM0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH700000eYF001J
EP06FUH40006FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
000TOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUH0
0003000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=J
EPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEP80009oo`H00003FUH005YF009JEP80
02eoo`00;Goo00@005YF0000009JEP8001ioo`@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJEP<000EJEP8000MJEPD0
00EJEP03001JEP0000H000EJEP<000=JEP8002eoo`00;Goo0P0000=JEP00FUH00eYF1@0057oo1`00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00<000EJEP03001JEUYF00@0009JEP03001JEUYF00EJEPD00003FUH0000000D000AJEP03
001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P000UYF00<005YFFUH00UYF00@0
05YFFUIJEPT000Moo`@0009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPh00004FUH005YF0004FUH0
1000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;Goo0P000UYF00<005YFFUH00UYF00<005YFFUH03P0015YF00<005YFFUH0
0UYF0`0000AJEP00FUIJEPH000=JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000=JEPP0
00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Goo0P000UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000T0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH6
0004FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool20002FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF
FUH020000UYF00<007oo00000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01eYF0`0000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF00<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH90006
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH700000eYF00000005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool30002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF400000=JEP00FUH015YF0`000eYF00@005YFFUIJ
EP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJ
EP03001JEUYF00AJEQ800003FUH005YF00IJEP03001JEUYF00AJEP04001JEP00000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;
FUH01000FUIJEUYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF3`0015YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH00UYF1@00<goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00002UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Qoo`00;Goo00<007oo00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP0000YJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00002000eOol002eoo`03001oo`0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00009FUH4000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000b
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP05001JEUYFFUH00006FUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YF00001@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YF001JEP0000=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000]Ool00eYF001JEP03FUH01000FUIJEUYF200000=JEP00FUH01EYF1@0015YF
200015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00002FUH50003FUH00`00FUIJEP03FUH00`00Oomoo`06Ool50008Ool40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool30003FUH<0002FUH00`00FUIJEP04FUH90008Ool6
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<00003
FUH0000000H000EJEP03001oogoo00Moo`<000eoo`D000=JEP04001JEUYFFUH2000^Ool002aoo`04
001JEP00FUH20005FUH01000FUIJEUYF4@002Woo1`0000IJEP00000005YF0003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF7@0025YF00<005YFFUH01EYF00@005YF0000009J
EP03001JEUYF009JEPP00003FUH007oo01ioo`@000=JEP8002ioo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YFFUH01UYF
1P000UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEQ8000Uoo``0
0004FUH00000FUH2000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF
009JEP03001JEUYF00=JEP03001JEUYF00IJEPH00003FUH005YF00YJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00=JEP03001JEUYF009J
EP@000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH015YF20000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP04FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000_Ool002aoo`8000=JEP03001JEUYF009JEPP000=JEP03001JEUYF009J
EQ40009JEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000000IJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<0031oo`00;Goo00<005YFFUH01P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH200001GooFUIJ
EUYF00000eYF0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP04001JEUYFFUH90004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00<goo000]Ool30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
0003FUH00`00Oomoo`03FUH01000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03
001JEUYF009JEP04001JEUYFFUH20002OolI000iOol002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000=o
o`=JEP@000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0eYF00@005YFFUH000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH0000000D000=JEP04001JEUYFFUH2001DOol002]oo`03001JEP00
00AJEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000Woo0UYF
00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002Ool600000eYF001JEP02FUH2001D
Ool002]oo`03001JEP00009JEPH000Eoo`T000AJEP<0009JEPX000AJEP03001JEUYF00=JEP03001J
EUYF00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000<000EJEP<0
00=JEP8005Aoo`00:goo00<005YF00000`0000AJEP00000000moo`T000Yoo`L000=JEP03001JEUYF
00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001J
EUYF00800003FUH0000005Aoo`00:goo0P000eYF00<005YFFUH00UYF1@003Goo1@004Woo10000UYF
0P0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YF
FUH00UYF0`00E7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF20001Goo1@0047oo2P00
00=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF001JEP0000IJEP03001JEUYF
009JEP<005Aoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUHJ0003FUH0
1000FUIJEUYF0`0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP00009oo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00EJ
EP03001JEUYF009JEP8005Eoo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P000goo00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1P000UYF00<005YFFUH00UYF0P00EGoo000cOol7
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP030005Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH010000UYF0P00
EWoo000jOol80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@002Woo0`0025YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00H005YF000005YF0007FUH00`00FUIJEP03FUH3001HOol0049ooaX0015oo`8000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00Kgoo0`0015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`000UYF200015YF
00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00LWoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00003P0000=oo`000000100015YF00@005YFFUIJ
EP8005Eoo`00MGoo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF100000=o
o`0000000`0047oo0`0000=JEP00FUH00UYF0P00EGoo001iOol60002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH01000FUIJEUYF1P001Goo1@003goo1`000UYF0P00EGoo001oOol80006FUH00`00FUIJ
EP04FUH:00000eYF001JEP03FUHI0003FUH01000FUIJEUYF1000EGoo0027Ool=0003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3001EOol008moo`@000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Eoo`00Tgoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<005Ioo`00UWoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF000005Uoo`00Vgoo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF
3000Fgoo002TOolB001WOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63519 .77235 m .62628 .72777 L .59493 .73403 L p .707 .577 .707 r
F P
0 g
s
.62628 .72777 m .63519 .77235 L .66381 .76043 L p .707 .577 .707 r
F P
0 g
s
.66381 .76043 m .6549 .71585 L .62628 .72777 L p .707 .577 .707 r
F P
0 g
s
.62829 .81117 m .62871 .77385 L .59688 .77422 L p .707 .577 .707 r
F P
0 g
s
.60384 .77861 m .59493 .73403 L .56393 .73402 L p .707 .577 .707 r
F P
0 g
s
.59493 .73403 m .60384 .77861 L .63519 .77235 L p .707 .577 .707 r
F P
0 g
s
.6549 .71585 m .66381 .76043 L .68691 .74401 L p .707 .577 .707 r
F P
0 g
s
.68691 .74401 m .678 .69943 L .6549 .71585 L p .707 .577 .707 r
F P
0 g
s
.59646 .81153 m .59688 .77422 L .5657 .77217 L p .707 .577 .707 r
F P
0 g
s
.57284 .7786 m .56393 .73402 L .5363 .72774 L p .707 .577 .707 r
F P
0 g
s
.59688 .77422 m .59646 .81153 L .62829 .81117 L p .707 .577 .707 r
F P
0 g
s
.56393 .73402 m .57284 .7786 L .60384 .77861 L p .707 .577 .707 r
F P
0 g
s
.58926 .83371 m .59044 .81465 L .55929 .81194 L p .707 .577 .707 r
F P
0 g
s
.59044 .81465 m .58926 .83371 L .62102 .83529 L p .707 .577 .707 r
F P
0 g
s
.62102 .83529 m .6222 .81623 L .59044 .81465 L p .707 .577 .707 r
F P
0 g
s
.55929 .81194 m .55811 .831 L .58926 .83371 L p .707 .577 .707 r
F P
0 g
s
.6222 .81623 m .62102 .83529 L .65029 .83558 L p .707 .577 .707 r
F P
0 g
s
.65029 .83558 m .65147 .81652 L .6222 .81623 L p .707 .577 .707 r
F P
0 g
s
.55811 .831 m .55929 .81194 L .53181 .80836 L p .707 .577 .707 r
F P
0 g
s
.62871 .77385 m .62829 .81117 L .65767 .80842 L p .707 .577 .707 r
F P
0 g
s
.65767 .80842 m .65809 .77111 L .62871 .77385 L p .707 .577 .707 r
F P
0 g
s
.53181 .80836 m .53063 .82742 L .55811 .831 L p .707 .577 .707 r
F P
0 g
s
.678 .69943 m .68691 .74401 L .70221 .72471 L p .707 .577 .707 r
F P
0 g
s
.70221 .72471 m .69331 .68014 L .678 .69943 L p .707 .577 .707 r
F P
0 g
s
.56529 .80949 m .5657 .77217 L .53825 .76792 L p .707 .577 .707 r
F P
0 g
s
.54521 .77231 m .5363 .72774 L .51476 .7158 L p .707 .577 .707 r
F P
0 g
s
.5657 .77217 m .56529 .80949 L .59646 .81153 L p .707 .577 .707 r
F P
0 g
s
.5363 .72774 m .54521 .77231 L .57284 .7786 L p .707 .577 .707 r
F P
0 g
s
.65147 .81652 m .65029 .83558 L .6742 .83455 L p .707 .577 .707 r
F P
0 g
s
.6742 .83455 m .67538 .81549 L .65147 .81652 L p .707 .577 .707 r
F P
0 g
s
.65809 .77111 m .65767 .80842 L .68172 .80358 L p .707 .577 .707 r
F P
0 g
s
.68172 .80358 m .68214 .76626 L .65809 .77111 L p .707 .577 .707 r
F P
0 g
s
.53825 .76792 m .53783 .80524 L .56529 .80949 L p .707 .577 .707 r
F P
0 g
s
.53063 .82742 m .53181 .80836 L .51068 .80426 L p .707 .577 .707 r
F P
0 g
s
.51068 .80426 m .5095 .82332 L .53063 .82742 L p .707 .577 .707 r
F P
0 g
s
.53783 .80524 m .53825 .76792 L .51719 .76188 L p .707 .577 .707 r
F P
0 g
s
.69331 .68014 m .70221 .72471 L .70824 .70442 L p .707 .577 .707 r
F P
0 g
s
.70824 .70442 m .69933 .65984 L .69331 .68014 L p .707 .577 .707 r
F P
0 g
s
.52367 .76038 m .51476 .7158 L .50141 .69937 L p .707 .577 .707 r
F P
0 g
s
.51476 .7158 m .52367 .76038 L .54521 .77231 L p .707 .577 .707 r
F P
0 g
s
.67538 .81549 m .6742 .83455 L .69041 .83231 L p .707 .577 .707 r
F P
0 g
s
.69041 .83231 m .69158 .81325 L .67538 .81549 L p .707 .577 .707 r
F P
0 g
s
.51719 .76188 m .51677 .7992 L .53783 .80524 L p .707 .577 .707 r
F P
0 g
s
.68214 .76626 m .68172 .80358 L .69808 .7971 L p .707 .577 .707 r
F P
0 g
s
.69808 .7971 m .6985 .75978 L .68214 .76626 L p .707 .577 .707 r
F P
0 g
s
.5095 .82332 m .51068 .80426 L .49797 .80004 L p .707 .577 .707 r
F P
0 g
s
.49797 .80004 m .49679 .81911 L .5095 .82332 L p .707 .577 .707 r
F P
0 g
s
.51677 .7992 m .51719 .76188 L .50459 .75463 L p .707 .577 .707 r
F P
0 g
s
.69933 .65984 m .70824 .70442 L .70438 .68511 L p .636 .53 .717 r
F P
0 g
s
.70438 .68511 m .69548 .64054 L .69933 .65984 L p .636 .53 .717 r
F P
0 g
s
.50141 .69937 m .51031 .74395 L .52367 .76038 L p .707 .577 .707 r
F P
0 g
s
.51031 .74395 m .50141 .69937 L .49755 .68007 L p .634 .529 .717 r
F P
0 g
s
.50459 .75463 m .50418 .79195 L .51677 .7992 L p .707 .577 .707 r
F P
0 g
s
.69158 .81325 m .69041 .83231 L .69733 .82907 L p .707 .577 .707 r
F P
0 g
s
.69733 .82907 m .69851 .81001 L .69158 .81325 L p .707 .577 .707 r
F P
0 g
s
.6985 .75978 m .69808 .7971 L .70516 .78962 L p .707 .577 .707 r
F P
0 g
s
.70516 .78962 m .70558 .7523 L .6985 .75978 L p .707 .577 .707 r
F P
0 g
s
.49679 .81911 m .49797 .80004 L .49493 .79612 L p .707 .577 .707 r
F P
0 g
s
.49493 .79612 m .49375 .81519 L .49679 .81911 L p .707 .577 .707 r
F P
0 g
s
.49375 .81519 m .49493 .79612 L .50185 .79288 L p .707 .577 .707 r
F P
0 g
s
.50185 .79288 m .50067 .81195 L .49375 .81519 L p .707 .577 .707 r
F P
0 g
s
.50067 .81195 m .50185 .79288 L .51806 .79064 L p .707 .577 .707 r
F P
0 g
s
.51806 .79064 m .51688 .8097 L .50067 .81195 L p .707 .577 .707 r
F P
0 g
s
.50256 .82491 m .48455 .33728 L .44056 .33523 L p .707 .577 .707 r
F P
0 g
s
.50418 .79195 m .50459 .75463 L .50169 .74689 L p .707 .577 .707 r
F P
0 g
s
.50646 .72465 m .49755 .68007 L .50358 .65977 L p .707 .577 .707 r
F P
0 g
s
.49755 .68007 m .50646 .72465 L .51031 .74395 L p .634 .529 .717 r
F P
0 g
s
.50169 .74689 m .50127 .78421 L .50418 .79195 L p .707 .577 .707 r
F P
0 g
s
.51248 .70435 m .50358 .65977 L .51888 .64047 L p .707 .577 .707 r
F P
0 g
s
.50358 .65977 m .51248 .70435 L .50646 .72465 L p .707 .577 .707 r
F P
0 g
s
.50127 .78421 m .50169 .74689 L .50877 .73941 L p .707 .577 .707 r
F P
0 g
s
.50877 .73941 m .50835 .77673 L .50127 .78421 L p .707 .577 .707 r
F P
0 g
s
.51888 .64047 m .52779 .68505 L .51248 .70435 L p .707 .577 .707 r
F P
0 g
s
.52779 .68505 m .51888 .64047 L .54198 .62406 L p .707 .577 .707 r
F P
0 g
s
.54198 .62406 m .55089 .66864 L .52779 .68505 L p .707 .577 .707 r
F P
0 g
s
.50835 .77673 m .50877 .73941 L .52513 .73294 L p .707 .577 .707 r
F P
0 g
s
.52513 .73294 m .52472 .77025 L .50835 .77673 L p .707 .577 .707 r
F P
0 g
s
.51688 .8097 m .51806 .79064 L .54197 .78961 L p .707 .577 .707 r
F P
0 g
s
.54197 .78961 m .54079 .80868 L .51688 .8097 L p .707 .577 .707 r
F P
0 g
s
.52472 .77025 m .52513 .73294 L .54918 .72809 L p .707 .577 .707 r
F P
0 g
s
.54918 .72809 m .54876 .76541 L .52472 .77025 L p .707 .577 .707 r
F P
0 g
s
.54079 .80868 m .54197 .78961 L .57124 .7899 L p .707 .577 .707 r
F P
0 g
s
.57124 .7899 m .57006 .80897 L .54079 .80868 L p .707 .577 .707 r
F P
0 g
s
.48455 .33728 m .50256 .82491 L .54747 .822 L p .707 .577 .707 r
F P
0 g
s
.54747 .822 m .52946 .33437 L .48455 .33728 L p .707 .577 .707 r
F P
0 g
s
.55089 .66864 m .54198 .62406 L .5706 .61214 L p .707 .577 .707 r
F P
0 g
s
.5706 .61214 m .57951 .65672 L .55089 .66864 L p .707 .577 .707 r
F P
0 g
s
.54876 .76541 m .54918 .72809 L .57856 .72535 L p .707 .577 .707 r
F P
0 g
s
.57856 .72535 m .57814 .76266 L .54876 .76541 L p .707 .577 .707 r
F P
0 g
s
.57006 .80897 m .57124 .7899 L .603 .79148 L p .707 .577 .707 r
F P
0 g
s
.57814 .76266 m .57856 .72535 L .61039 .72498 L p .707 .577 .707 r
F P
0 g
s
.603 .79148 m .60182 .81054 L .57006 .80897 L p .707 .577 .707 r
F P
0 g
s
.61039 .72498 m .60998 .76229 L .57814 .76266 L p .707 .577 .707 r
F P
0 g
s
.52946 .33437 m .54747 .822 L .5889 .81441 L p .707 .577 .707 r
F P
0 g
s
.60195 .60588 m .61086 .65046 L .57951 .65672 L p .707 .577 .707 r
F P
0 g
s
.57951 .65672 m .5706 .61214 L .60195 .60588 L p .707 .577 .707 r
F P
0 g
s
.5889 .81441 m .57089 .32677 L .52946 .33437 L p .707 .577 .707 r
F P
0 g
s
.69548 .64054 m .70438 .68511 L .69103 .66869 L p .707 .577 .707 r
F P
0 g
s
.69103 .66869 m .68212 .62411 L .69548 .64054 L p .707 .577 .707 r
F P
0 g
s
.45856 .82286 m .44056 .33523 L .40178 .3284 L p .707 .577 .707 r
F P
0 g
s
.44056 .33523 m .45856 .82286 L .50256 .82491 L p .707 .577 .707 r
F P
0 g
s
.63414 .79419 m .63297 .81326 L .60182 .81054 L p .707 .577 .707 r
F P
0 g
s
.60182 .81054 m .603 .79148 L .63414 .79419 L p .707 .577 .707 r
F P
0 g
s
.64156 .72702 m .64115 .76434 L .60998 .76229 L p .707 .577 .707 r
F P
0 g
s
.60998 .76229 m .61039 .72498 L .64156 .72702 L p .707 .577 .707 r
F P
0 g
s
.57089 .32677 m .5889 .81441 L .62279 .80287 L p .707 .577 .707 r
F P
0 g
s
.63295 .60589 m .64186 .65047 L .61086 .65046 L p .707 .577 .707 r
F P
0 g
s
.61086 .65046 m .60195 .60588 L .63295 .60589 L p .707 .577 .707 r
F P
0 g
s
.62279 .80287 m .60479 .31524 L .57089 .32677 L p .707 .577 .707 r
F P
0 g
s
.69851 .81001 m .69733 .82907 L .69429 .82515 L p .707 .577 .707 r
F P
0 g
s
.69429 .82515 m .69546 .80609 L .69851 .81001 L p .707 .577 .707 r
F P
0 g
s
.70558 .7523 m .70516 .78962 L .70226 .78188 L p .707 .577 .707 r
F P
0 g
s
.70226 .78188 m .70268 .74456 L .70558 .7523 L p .707 .577 .707 r
F P
0 g
s
.41979 .81603 m .40178 .3284 L .37202 .31747 L p .707 .577 .707 r
F P
0 g
s
.40178 .3284 m .41979 .81603 L .45856 .82286 L p .707 .577 .707 r
F P
0 g
s
.68212 .62411 m .69103 .66869 L .66949 .65675 L p .707 .577 .707 r
F P
0 g
s
.66949 .65675 m .66058 .61217 L .68212 .62411 L p .707 .577 .707 r
F P
0 g
s
.63297 .81326 m .63414 .79419 L .66163 .79777 L p .707 .577 .707 r
F P
0 g
s
.66902 .73127 m .66861 .76859 L .64115 .76434 L p .707 .577 .707 r
F P
0 g
s
.64115 .76434 m .64156 .72702 L .66902 .73127 L p .707 .577 .707 r
F P
0 g
s
.60479 .31524 m .62279 .80287 L .64583 .78852 L p .707 .577 .707 r
F P
0 g
s
.64186 .65047 m .63295 .60589 L .66058 .61217 L p .707 .577 .707 r
F P
0 g
s
.64583 .78852 m .62782 .30089 L .60479 .31524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29218 .73553 m .28327 .69095 L .25192 .69721 L p .707 .577 .707 r
F P
0 g
s
.28327 .69095 m .29218 .73553 L .3208 .72361 L p .707 .577 .707 r
F P
0 g
s
.3208 .72361 m .31189 .67903 L .28327 .69095 L p .707 .577 .707 r
F P
0 g
s
.28528 .77435 m .2857 .73703 L .25387 .7374 L p .707 .577 .707 r
F P
0 g
s
.26083 .74179 m .25192 .69721 L .22092 .6972 L p .707 .577 .707 r
F P
0 g
s
.25192 .69721 m .26083 .74179 L .29218 .73553 L p .707 .577 .707 r
F P
0 g
s
.66058 .61217 m .66949 .65675 L .64186 .65047 L p .707 .577 .707 r
F P
0 g
s
.69546 .80609 m .69429 .82515 L .68158 .82093 L p .707 .577 .707 r
F P
0 g
s
.68158 .82093 m .68276 .80187 L .69546 .80609 L p .707 .577 .707 r
F P
0 g
s
.70268 .74456 m .70226 .78188 L .68967 .77463 L p .707 .577 .707 r
F P
0 g
s
.68967 .77463 m .69008 .73731 L .70268 .74456 L p .707 .577 .707 r
F P
0 g
s
.31189 .67903 m .3208 .72361 L .3439 .7072 L p .707 .577 .707 r
F P
0 g
s
.3439 .7072 m .33499 .66262 L .31189 .67903 L p .707 .577 .707 r
F P
0 g
s
.25345 .77472 m .25387 .7374 L .22269 .73536 L p .707 .577 .707 r
F P
0 g
s
.22983 .74178 m .22092 .6972 L .19329 .69092 L p .707 .577 .707 r
F P
0 g
s
.25387 .7374 m .25345 .77472 L .28528 .77435 L p .707 .577 .707 r
F P
0 g
s
.22092 .6972 m .22983 .74178 L .26083 .74179 L p .707 .577 .707 r
F P
0 g
s
.24625 .7969 m .24743 .77783 L .21628 .77512 L p .707 .577 .707 r
F P
0 g
s
.24743 .77783 m .24625 .7969 L .27801 .79848 L p .707 .577 .707 r
F P
0 g
s
.27801 .79848 m .27919 .77941 L .24743 .77783 L p .707 .577 .707 r
F P
0 g
s
.21628 .77512 m .2151 .79419 L .24625 .7969 L p .707 .577 .707 r
F P
0 g
s
.27919 .77941 m .27801 .79848 L .30728 .79877 L p .707 .577 .707 r
F P
0 g
s
.30728 .79877 m .30846 .7797 L .27919 .77941 L p .707 .577 .707 r
F P
0 g
s
.39003 .8051 m .37202 .31747 L .35419 .30352 L p .707 .577 .707 r
F P
0 g
s
.37202 .31747 m .39003 .8051 L .41979 .81603 L p .707 .577 .707 r
F P
0 g
s
.2151 .79419 m .21628 .77512 L .1888 .77154 L p .707 .577 .707 r
F P
0 g
s
.2857 .73703 m .28528 .77435 L .31466 .77161 L p .707 .577 .707 r
F P
0 g
s
.31466 .77161 m .31508 .73429 L .2857 .73703 L p .707 .577 .707 r
F P
0 g
s
.1888 .77154 m .18762 .79061 L .2151 .79419 L p .707 .577 .707 r
F P
0 g
s
.33499 .66262 m .3439 .7072 L .3592 .6879 L p .707 .577 .707 r
F P
0 g
s
.3592 .6879 m .3503 .64332 L .33499 .66262 L p .707 .577 .707 r
F P
0 g
s
.22228 .77268 m .22269 .73536 L .19524 .73111 L p .707 .577 .707 r
F P
0 g
s
.2022 .7355 m .19329 .69092 L .17175 .67898 L p .707 .577 .707 r
F P
0 g
s
.22269 .73536 m .22228 .77268 L .25345 .77472 L p .707 .577 .707 r
F P
0 g
s
.19329 .69092 m .2022 .7355 L .22983 .74178 L p .707 .577 .707 r
F P
0 g
s
.30846 .7797 m .30728 .79877 L .33119 .79774 L p .707 .577 .707 r
F P
0 g
s
.33119 .79774 m .33237 .77867 L .30846 .7797 L p .707 .577 .707 r
F P
0 g
s
.31508 .73429 m .31466 .77161 L .33871 .76676 L p .707 .577 .707 r
F P
0 g
s
.33871 .76676 m .33913 .72944 L .31508 .73429 L p .707 .577 .707 r
F P
0 g
s
.19524 .73111 m .19482 .76843 L .22228 .77268 L p .707 .577 .707 r
F P
0 g
s
.18762 .79061 m .1888 .77154 L .16767 .76744 L p .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .66901 .73036 L .65615 .72786 L p .707 .577 .707 r
F P
0 g
s
.62782 .30089 m .64583 .78852 L .65482 .77425 L p .707 .577 .707 r
F P
0 g
s
.65516 .76258 m .62782 .30089 L .65482 .77425 L .707 .577 .707 r
F
.63775 .28513 m .62782 .30089 L p .65516 .76258 L F P
0 g
s
.65576 .77276 m .65525 .75913 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .63775 .28513 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.64788 .72626 m .6467 .74532 L .65443 .74682 L p .707 .577 .707 r
F P
0 g
s
.65419 .74326 m .64788 .72626 L .65443 .74682 L .707 .577 .707 r
F
.64885 .66332 m .64721 .60747 L .65525 .75913 L F
.63775 .28513 m .64879 .5842 L p .64721 .60747 L F P
0 g
s
.64879 .5842 m .65525 .75913 L p .64721 .60747 L .707 .577 .707 r
F P
0 g
s
.65593 .7356 m .65349 .73277 L .6556 .74705 L .707 .577 .707 r
F
.65349 .73277 m .64788 .72626 L .65419 .74326 L F
.65349 .73277 m .65419 .74326 L .6556 .74705 L F
.6336 .26951 m .63775 .28513 L p .64885 .66332 L F P
0 g
s
.65615 .72786 m .64788 .72626 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64726 .63956 L .64885 .66332 L .707 .577 .707 r
F
.64949 .69983 m .64726 .63956 L p .65036 .71465 L F P
0 g
s
.64726 .63956 m .6336 .26951 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.65482 .77425 m .65576 .77276 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65576 .77276 m .6532 .76315 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.6532 .76315 m .6516 .75714 L p .65036 .71465 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64885 .66332 L .6532 .76315 L .707 .577 .707 r
F
.6467 .74532 m .64788 .72626 L .63518 .72204 L p F P
0 g
s
.63518 .72204 m .634 .74111 L .6467 .74532 L p .707 .577 .707 r
F P
0 g
s
.634 .74111 m .63518 .72204 L .63213 .71812 L p .707 .577 .707 r
F P
0 g
s
.63213 .71812 m .63096 .73719 L .634 .74111 L p .707 .577 .707 r
F P
0 g
s
.6336 .26951 m .6516 .75714 L .63393 .7433 L p .707 .577 .707 r
F P
0 g
s
.63096 .73719 m .6337 .71739 L .63381 .72934 L .707 .577 .707 r
F
.63377 .72496 m .6336 .26951 L .63393 .7433 L F
.63906 .71488 m .63788 .73395 L .63386 .73583 L p F P
0 g
s
.63386 .73583 m .63096 .73719 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.63381 .72934 m .63906 .71488 L .63386 .73583 L .707 .577 .707 r
F
.63096 .73719 m .63213 .71812 L .6337 .71739 L p F P
0 g
s
.63378 .74318 m .61577 .25555 L .62985 .26658 L p .707 .577 .707 r
F P
0 g
s
.62985 .26658 m .6336 .26951 L p .63377 .72496 L .707 .577 .707 r
F P
0 g
s
.63378 .74318 m .62985 .26658 L .63377 .72496 L .707 .577 .707 r
F
.63393 .7433 m .63378 .74318 L p .63377 .72496 L F P
0 g
s
.6337 .71739 m .63906 .71488 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.6418 .65333 m .64138 .69065 L .64921 .69515 L p .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .65576 .77276 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.64921 .69515 m .65398 .69789 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.64812 .67646 m .6418 .65333 L .64921 .69515 L .707 .577 .707 r
F
.65398 .69789 m .65439 .66058 L .64693 .65628 L p F P
0 g
s
.64693 .65628 m .6418 .65333 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.65398 .69789 m .64693 .65628 L .64812 .67646 L .707 .577 .707 r
F
.6516 .75714 m .64949 .69983 L p .65036 .71465 L F P
0 g
s
.67503 .70394 m .67529 .68121 L p .65439 .66058 L .707 .577 .707 r
F P
0 g
s
.67529 .68121 m .67545 .66662 L .6664 .66402 L p .707 .577 .707 r
F P
0 g
s
.6664 .66402 m .65439 .66058 L p .67529 .68121 L .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .64629 .621 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .65461 .64121 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.65461 .64121 m .65196 .62798 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.64629 .621 m .63861 .61155 L p .64563 .63078 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .64629 .621 L .64563 .63078 L .707 .577 .707 r
F
.65443 .74682 m .6556 .74705 L p .65419 .74326 L F P
0 g
s
.6556 .74705 m .66783 .74942 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .65615 .72786 L .65593 .7356 L .707 .577 .707 r
F
.68276 .80187 m .68158 .82093 L .66045 .81684 L p F P
0 g
s
.66045 .81684 m .66163 .79777 L .68276 .80187 L p .707 .577 .707 r
F P
0 g
s
.16767 .76744 m .16649 .78651 L .18762 .79061 L p .707 .577 .707 r
F P
0 g
s
.69008 .73731 m .68967 .77463 L .66861 .76859 L p .707 .577 .707 r
F P
0 g
s
.66861 .76859 m .66902 .73127 L .69008 .73731 L p .707 .577 .707 r
F P
0 g
s
.19482 .76843 m .19524 .73111 L .17418 .72506 L p .707 .577 .707 r
F P
0 g
s
.3503 .64332 m .3592 .6879 L .36523 .6676 L p .707 .577 .707 r
F P
0 g
s
.36523 .6676 m .35632 .62303 L .3503 .64332 L p .707 .577 .707 r
F P
0 g
s
.18066 .72356 m .17175 .67898 L .1584 .66256 L p .707 .577 .707 r
F P
0 g
s
.17175 .67898 m .18066 .72356 L .2022 .7355 L p .707 .577 .707 r
F P
0 g
s
.33237 .77867 m .33119 .79774 L .3474 .7955 L p .707 .577 .707 r
F P
0 g
s
.3474 .7955 m .34857 .77643 L .33237 .77867 L p .707 .577 .707 r
F P
0 g
s
.17418 .72506 m .17376 .76238 L .19482 .76843 L p .707 .577 .707 r
F P
0 g
s
.33913 .72944 m .33871 .76676 L .35507 .76028 L p .707 .577 .707 r
F P
0 g
s
.35507 .76028 m .35549 .72296 L .33913 .72944 L p .707 .577 .707 r
F P
0 g
s
.3722 .79115 m .35419 .30352 L .35004 .28789 L p .707 .577 .707 r
F P
0 g
s
.35419 .30352 m .3722 .79115 L .39003 .8051 L p .707 .577 .707 r
F P
0 g
s
.16649 .78651 m .16767 .76744 L .15496 .76323 L p .707 .577 .707 r
F P
0 g
s
.66163 .79777 m .66045 .81684 L .63297 .81326 L p .707 .577 .707 r
F P
0 g
s
.15496 .76323 m .15378 .78229 L .16649 .78651 L p .707 .577 .707 r
F P
0 g
s
.17376 .76238 m .17418 .72506 L .16158 .71782 L p .707 .577 .707 r
F P
0 g
s
.35632 .62303 m .36523 .6676 L .36137 .6483 L p .632 .528 .718 r
F P
0 g
s
.36137 .6483 m .35247 .60372 L .35632 .62303 L p .632 .528 .718 r
F P
0 g
s
.1584 .66256 m .1673 .70714 L .18066 .72356 L p .707 .577 .707 r
F P
0 g
s
.1673 .70714 m .1584 .66256 L .15454 .64325 L p .63 .526 .718 r
F P
0 g
s
.16158 .71782 m .16117 .75513 L .17376 .76238 L p .707 .577 .707 r
F P
0 g
s
.34857 .77643 m .3474 .7955 L .35432 .79225 L p .707 .577 .707 r
F P
0 g
s
.35432 .79225 m .3555 .77319 L .34857 .77643 L p .707 .577 .707 r
F P
0 g
s
.35549 .72296 m .35507 .76028 L .36215 .75281 L p .707 .577 .707 r
F P
0 g
s
.36215 .75281 m .36257 .71549 L .35549 .72296 L p .707 .577 .707 r
F P
0 g
s
.15378 .78229 m .15496 .76323 L .15192 .75931 L p .707 .577 .707 r
F P
0 g
s
.15192 .75931 m .15074 .77837 L .15378 .78229 L p .707 .577 .707 r
F P
0 g
s
.16117 .75513 m .16158 .71782 L .15868 .71007 L p .707 .577 .707 r
F P
0 g
s
.35247 .60372 m .36137 .6483 L .34802 .63187 L p .707 .577 .707 r
F P
0 g
s
.34802 .63187 m .33911 .5873 L .35247 .60372 L p .707 .577 .707 r
F P
0 g
s
.16345 .68783 m .15454 .64325 L .16057 .62296 L p .707 .577 .707 r
F P
0 g
s
.15454 .64325 m .16345 .68783 L .1673 .70714 L p .63 .526 .718 r
F P
0 g
s
.35004 .28789 m .36805 .77553 L .3722 .79115 L p .707 .577 .707 r
F P
0 g
s
.36805 .77553 m .35004 .28789 L .35997 .27214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15868 .71007 m .15826 .74739 L .16117 .75513 L p .707 .577 .707 r
F P
0 g
s
.3555 .77319 m .35432 .79225 L .35128 .78834 L p .707 .577 .707 r
F P
0 g
s
.35128 .78834 m .35246 .76927 L .3555 .77319 L p .707 .577 .707 r
F P
0 g
s
.36257 .71549 m .36215 .75281 L .35925 .74507 L p .707 .577 .707 r
F P
0 g
s
.35925 .74507 m .35967 .70775 L .36257 .71549 L p .707 .577 .707 r
F P
0 g
s
.33911 .5873 m .34802 .63187 L .32648 .61994 L p .707 .577 .707 r
F P
0 g
s
.32648 .61994 m .31757 .57536 L .33911 .5873 L p .707 .577 .707 r
F P
0 g
s
.16947 .66754 m .16057 .62296 L .17587 .60366 L p .707 .577 .707 r
F P
0 g
s
.16057 .62296 m .16947 .66754 L .16345 .68783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15074 .77837 m .15192 .75931 L .15884 .75607 L p .707 .577 .707 r
F P
0 g
s
.15884 .75607 m .15766 .77513 L .15074 .77837 L p .707 .577 .707 r
F P
0 g
s
.15826 .74739 m .15868 .71007 L .16576 .7026 L p .707 .577 .707 r
F P
0 g
s
.16576 .7026 m .16534 .73992 L .15826 .74739 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.31757 .57536 m .32648 .61994 L .29885 .61365 L p .707 .577 .707 r
F P
0 g
s
.29885 .61365 m .28995 .56908 L .31757 .57536 L p .707 .577 .707 r
F P
0 g
s
.17587 .60366 m .18478 .64824 L .16947 .66754 L p .707 .577 .707 r
F P
0 g
s
.18478 .64824 m .17587 .60366 L .19897 .58725 L p .707 .577 .707 r
F P
0 g
s
.37797 .75977 m .35997 .27214 L .383 .25779 L p .707 .577 .707 r
F P
0 g
s
.35997 .27214 m .37797 .75977 L .36805 .77553 L p .707 .577 .707 r
F P
0 g
s
.35246 .76927 m .35128 .78834 L .33857 .78412 L p .707 .577 .707 r
F P
0 g
s
.33857 .78412 m .33975 .76506 L .35246 .76927 L p .707 .577 .707 r
F P
0 g
s
.35967 .70775 m .35925 .74507 L .34666 .73782 L p .707 .577 .707 r
F P
0 g
s
.34666 .73782 m .34707 .7005 L .35967 .70775 L p .707 .577 .707 r
F P
0 g
s
.15766 .77513 m .15884 .75607 L .17505 .75382 L p .707 .577 .707 r
F P
0 g
s
.17505 .75382 m .17387 .77289 L .15766 .77513 L p .707 .577 .707 r
F P
0 g
s
.28995 .56908 m .29885 .61365 L .26785 .61364 L p .707 .577 .707 r
F P
0 g
s
.26785 .61364 m .25894 .56906 L .28995 .56908 L p .707 .577 .707 r
F P
0 g
s
.20788 .63182 m .19897 .58725 L .22759 .57533 L p .707 .577 .707 r
F P
0 g
s
.19897 .58725 m .20788 .63182 L .18478 .64824 L p .707 .577 .707 r
F P
0 g
s
.16534 .73992 m .16576 .7026 L .18212 .69612 L p .707 .577 .707 r
F P
0 g
s
.61577 .25555 m .63378 .74318 L .60402 .73226 L p .707 .577 .707 r
F P
0 g
s
.60402 .73226 m .58601 .24463 L .61577 .25555 L p .707 .577 .707 r
F P
0 g
s
.25894 .56906 m .26785 .61364 L .2365 .6199 L p .707 .577 .707 r
F P
0 g
s
.2365 .6199 m .22759 .57533 L .25894 .56906 L p .707 .577 .707 r
F P
0 g
s
.22759 .57533 m .2365 .6199 L .20788 .63182 L p .707 .577 .707 r
F P
0 g
s
.18212 .69612 m .18171 .73344 L .16534 .73992 L p .707 .577 .707 r
F P
0 g
s
.33975 .76506 m .33857 .78412 L .31744 .78002 L p .707 .577 .707 r
F P
0 g
s
.31744 .78002 m .31862 .76096 L .33975 .76506 L p .707 .577 .707 r
F P
0 g
s
.34707 .7005 m .34666 .73782 L .3256 .73177 L p .707 .577 .707 r
F P
0 g
s
.3256 .73177 m .32601 .69445 L .34707 .7005 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .40659 .57025 L .42095 .65324 L .707 .577 .707 r
F
.37797 .75977 m .38063 .49454 L .40016 .73492 L F
.40101 .74542 m .39884 .74678 L p .40016 .73492 L F P
0 g
s
.39884 .74678 m .37797 .75977 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.3934 .53939 m .40051 .73179 L p .38063 .49454 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .40101 .74542 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.38063 .49454 m .40051 .73179 L .40016 .73492 L .707 .577 .707 r
F
.40521 .71372 m .40271 .71204 L .4036 .7199 L F
.383 .25779 m .4169 .24625 L p .40158 .72768 L F P
0 g
s
.40101 .74542 m .40051 .73179 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .383 .25779 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .41639 .70141 L .40851 .70102 L p .707 .577 .707 r
F P
0 g
s
.40851 .70102 m .38463 .69984 L p .40521 .71372 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .40851 .70102 L .40521 .71372 L .707 .577 .707 r
F
.40271 .71204 m .38463 .69984 L .40202 .71823 L F
.40271 .71204 m .40202 .71823 L .4036 .7199 L F
.38463 .69984 m .38345 .7189 L .40184 .71981 L p F P
0 g
s
.40184 .71981 m .4036 .7199 L p .40202 .71823 L .707 .577 .707 r
F P
0 g
s
.40202 .71823 m .38463 .69984 L .40184 .71981 L .707 .577 .707 r
F
.4036 .7199 m .41522 .72048 L p .40521 .71372 L F P
0 g
s
.4349 .73388 m .40101 .74542 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41639 .70141 m .41522 .72048 L .44448 .72077 L p .707 .577 .707 r
F P
0 g
s
.44448 .72077 m .44566 .7017 L .41639 .70141 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .42095 .65324 L .42884 .69887 L .707 .577 .707 r
F
.42978 .59502 m .43279 .67657 L p .40659 .57025 L F P
0 g
s
.43279 .67657 m .4349 .73388 L p .42884 .69887 L .707 .577 .707 r
F P
0 g
s
.40659 .57025 m .43279 .67657 L .42884 .69887 L .707 .577 .707 r
F
.44566 .7017 m .44448 .72077 L .46839 .71974 L p F P
0 g
s
.46839 .71974 m .46957 .70068 L .44566 .7017 L p .707 .577 .707 r
F P
0 g
s
.45833 .23865 m .47633 .72629 L .47598 .72635 L p .707 .577 .707 r
F P
0 g
s
.46957 .70068 m .46839 .71974 L .47519 .7188 L p .707 .577 .707 r
F P
0 g
s
.47379 .7054 m .46957 .70068 L .47519 .7188 L .707 .577 .707 r
F
.44794 .45826 m .45833 .23865 L .47598 .72635 L F
.45833 .23865 m .50324 .23574 L p .49249 .4316 L F P
0 g
s
.47633 .72629 m .46927 .5351 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.46927 .5351 m .45833 .23865 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.50324 .23574 m .52124 .72337 L .47633 .72629 L p .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .48578 .69843 L .47325 .70017 L p .707 .577 .707 r
F P
0 g
s
.47325 .70017 m .46957 .70068 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .47325 .70017 L .47379 .7054 L .707 .577 .707 r
F
.47598 .72635 m .4349 .73388 L p .44794 .45826 L F P
0 g
s
.47591 .66546 m .47633 .62814 L .45228 .63299 L p .707 .577 .707 r
F P
0 g
s
.458 .63579 m .4811 .61938 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.4491 .59121 m .45267 .60909 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.45267 .60909 m .458 .63579 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.47519 .7188 m .4846 .7175 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .45228 .63299 L .4403 .63411 L p .707 .577 .707 r
F P
0 g
s
.4349 .73388 m .4169 .24625 L .45833 .23865 L p .707 .577 .707 r
F P
0 g
s
.4403 .63411 m .4229 .63573 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .4403 .63411 L .43703 .65259 L .707 .577 .707 r
F
.4229 .63573 m .42249 .67305 L .43359 .67201 L p F P
0 g
s
.43359 .67201 m .45187 .67031 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.43703 .65259 m .4229 .63573 L .43359 .67201 L .707 .577 .707 r
F
.42304 .73168 m .42884 .69887 L .4349 .73388 L F
.40158 .72768 m .42884 .69887 L .42304 .73168 L F
.4169 .24625 m .42978 .59502 L p .40659 .57025 L F P
0 g
s
.458 .63579 m .45531 .62229 L p .42047 .60313 L .707 .577 .707 r
F P
0 g
s
.45531 .62229 m .4491 .59121 L .43263 .59807 L p .707 .577 .707 r
F P
0 g
s
.43263 .59807 m .42047 .60313 L p .45531 .62229 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .42047 .60313 L .41204 .60482 L p .707 .577 .707 r
F P
0 g
s
.42249 .67305 m .42287 .63832 L p .39107 .6361 L .707 .577 .707 r
F P
0 g
s
.42287 .63832 m .4229 .63573 L .41848 .63578 L p .707 .577 .707 r
F P
0 g
s
.41848 .63578 m .39107 .6361 L p .42287 .63832 L .707 .577 .707 r
F P
0 g
s
.39065 .67342 m .391 .64197 L p .3599 .63406 L .707 .577 .707 r
F P
0 g
s
.391 .64197 m .39107 .6361 L .38228 .63552 L p .707 .577 .707 r
F P
0 g
s
.38228 .63552 m .3599 .63406 L p .391 .64197 L .707 .577 .707 r
F P
0 g
s
.35948 .67137 m .35979 .64344 L p .33244 .62981 L .707 .577 .707 r
F P
0 g
s
.35979 .64344 m .3599 .63406 L .34978 .63249 L p .707 .577 .707 r
F P
0 g
s
.34978 .63249 m .33244 .62981 L p .35979 .64344 L .707 .577 .707 r
F P
0 g
s
.33244 .62981 m .33202 .66712 L .35948 .67137 L p .707 .577 .707 r
F P
0 g
s
.33202 .66712 m .33228 .64439 L p .31138 .62376 L .707 .577 .707 r
F P
0 g
s
.33228 .64439 m .33244 .62981 L .32339 .62721 L p .707 .577 .707 r
F P
0 g
s
.32339 .62721 m .31138 .62376 L p .33228 .64439 L .707 .577 .707 r
F P
0 g
s
.31786 .63574 m .3116 .6044 L p .2956 .57474 L .707 .577 .707 r
F P
0 g
s
.3116 .6044 m .30895 .59116 L .29741 .57697 L p .707 .577 .707 r
F P
0 g
s
.29741 .57697 m .2956 .57474 L p .3116 .6044 L .707 .577 .707 r
F P
0 g
s
.3394 .64768 m .33262 .61372 L p .30895 .59116 L .707 .577 .707 r
F P
0 g
s
.33262 .61372 m .3305 .6031 L .31511 .59458 L p .707 .577 .707 r
F P
0 g
s
.31511 .59458 m .30895 .59116 L p .33262 .61372 L .707 .577 .707 r
F P
0 g
s
.3599 .63406 m .35948 .67137 L .39065 .67342 L p .707 .577 .707 r
F P
0 g
s
.36703 .65396 m .36006 .61911 L p .3305 .6031 L .707 .577 .707 r
F P
0 g
s
.36006 .61911 m .35812 .60938 L .34193 .6057 L p .707 .577 .707 r
F P
0 g
s
.34193 .6057 m .3305 .6031 L p .36006 .61911 L .707 .577 .707 r
F P
0 g
s
.39107 .6361 m .39065 .67342 L .42249 .67305 L p .707 .577 .707 r
F P
0 g
s
.39803 .65397 m .39125 .62002 L p .35812 .60938 L .707 .577 .707 r
F P
0 g
s
.39125 .62002 m .38913 .6094 L .37289 .60939 L p .707 .577 .707 r
F P
0 g
s
.37289 .60939 m .35812 .60938 L p .39125 .62002 L .707 .577 .707 r
F P
0 g
s
.41204 .60482 m .38913 .6094 L p .42234 .64101 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .41204 .60482 L .42234 .64101 L .707 .577 .707 r
F
.383 .25779 m .3934 .53939 L p .38063 .49454 L F P
0 g
s
.17387 .77289 m .17505 .75382 L .19896 .7528 L p .707 .577 .707 r
F P
0 g
s
.19896 .7528 m .19778 .77186 L .17387 .77289 L p .707 .577 .707 r
F P
0 g
s
.18171 .73344 m .18212 .69612 L .20617 .69127 L p .707 .577 .707 r
F P
0 g
s
.20617 .69127 m .20576 .72859 L .18171 .73344 L p .707 .577 .707 r
F P
0 g
s
.58601 .24463 m .60402 .73226 L .56524 .72543 L p .707 .577 .707 r
F P
0 g
s
.56524 .72543 m .54723 .2378 L .58601 .24463 L p .707 .577 .707 r
F P
0 g
s
.31862 .76096 m .31744 .78002 L .28996 .77644 L p .707 .577 .707 r
F P
0 g
s
.28996 .77644 m .29114 .75738 L .31862 .76096 L p .707 .577 .707 r
F P
0 g
s
.32601 .69445 m .3256 .73177 L .29814 .72752 L p .707 .577 .707 r
F P
0 g
s
.29814 .72752 m .29855 .6902 L .32601 .69445 L p .707 .577 .707 r
F P
0 g
s
.19778 .77186 m .19896 .7528 L .22823 .75309 L p .707 .577 .707 r
F P
0 g
s
.20576 .72859 m .20617 .69127 L .23555 .68853 L p .707 .577 .707 r
F P
0 g
s
.7655 .70986 m .76588 .67514 L p .73408 .67291 L .707 .577 .707 r
F P
0 g
s
.76588 .67514 m .76591 .67254 L .76149 .6726 L p .707 .577 .707 r
F P
0 g
s
.76149 .6726 m .73408 .67291 L p .76588 .67514 L .707 .577 .707 r
F P
0 g
s
.73366 .71023 m .73401 .67879 L p .70291 .67087 L .707 .577 .707 r
F P
0 g
s
.73401 .67879 m .73408 .67291 L .72529 .67234 L p .707 .577 .707 r
F P
0 g
s
.72529 .67234 m .70291 .67087 L p .73401 .67879 L .707 .577 .707 r
F P
0 g
s
.70249 .70819 m .7028 .68026 L p .67545 .66662 L .707 .577 .707 r
F P
0 g
s
.7028 .68026 m .70291 .67087 L .69279 .66931 L p .707 .577 .707 r
F P
0 g
s
.69279 .66931 m .67545 .66662 L p .7028 .68026 L .707 .577 .707 r
F P
0 g
s
.67545 .66662 m .67503 .70394 L .70249 .70819 L p .707 .577 .707 r
F P
0 g
s
.68241 .6845 m .67563 .65054 L p .65196 .62798 L .707 .577 .707 r
F P
0 g
s
.67563 .65054 m .67351 .63992 L .65812 .63139 L p .707 .577 .707 r
F P
0 g
s
.65812 .63139 m .65196 .62798 L p .67563 .65054 L .707 .577 .707 r
F P
0 g
s
.70291 .67087 m .70249 .70819 L .73366 .71023 L p .707 .577 .707 r
F P
0 g
s
.71004 .69078 m .70307 .65592 L p .67351 .63992 L .707 .577 .707 r
F P
0 g
s
.70307 .65592 m .70113 .6462 L .68494 .64252 L p .707 .577 .707 r
F P
0 g
s
.68494 .64252 m .67351 .63992 L p .70307 .65592 L .707 .577 .707 r
F P
0 g
s
.73408 .67291 m .73366 .71023 L .7655 .70986 L p .707 .577 .707 r
F P
0 g
s
.74104 .69079 m .73426 .65683 L p .70113 .6462 L .707 .577 .707 r
F P
0 g
s
.73426 .65683 m .73214 .64621 L .7159 .64621 L p .707 .577 .707 r
F P
0 g
s
.7159 .64621 m .70113 .6462 L p .73426 .65683 L .707 .577 .707 r
F P
0 g
s
.76591 .67254 m .7655 .70986 L .79488 .70712 L p .707 .577 .707 r
F P
0 g
s
.79488 .70712 m .79529 .6698 L .76591 .67254 L p .707 .577 .707 r
F P
0 g
s
.77239 .68453 m .76348 .63995 L .73214 .64621 L p .707 .577 .707 r
F P
0 g
s
.79529 .6698 m .79488 .70712 L .81892 .70227 L p .707 .577 .707 r
F P
0 g
s
.81892 .70227 m .81934 .66495 L .79529 .6698 L p .707 .577 .707 r
F P
0 g
s
.76348 .63995 m .77239 .68453 L .80101 .67261 L p .707 .577 .707 r
F P
0 g
s
.80101 .67261 m .79211 .62803 L .76348 .63995 L p .707 .577 .707 r
F P
0 g
s
.73214 .64621 m .74104 .69079 L .77239 .68453 L p .707 .577 .707 r
F P
0 g
s
.22823 .75309 m .22705 .77215 L .19778 .77186 L p .707 .577 .707 r
F P
0 g
s
.29114 .75738 m .28996 .77644 L .25881 .77373 L p .707 .577 .707 r
F P
0 g
s
.25881 .77373 m .25999 .75466 L .29114 .75738 L p .707 .577 .707 r
F P
0 g
s
.79211 .62803 m .80101 .67261 L .82411 .6562 L p .707 .577 .707 r
F P
0 g
s
.82411 .6562 m .8152 .61162 L .79211 .62803 L p .707 .577 .707 r
F P
0 g
s
.70113 .6462 m .71004 .69078 L .74104 .69079 L p .707 .577 .707 r
F P
0 g
s
.29855 .6902 m .29814 .72752 L .26697 .72548 L p .707 .577 .707 r
F P
0 g
s
.26697 .72548 m .26738 .68816 L .29855 .6902 L p .707 .577 .707 r
F P
0 g
s
.23555 .68853 m .23513 .72585 L .20576 .72859 L p .707 .577 .707 r
F P
0 g
s
.22705 .77215 m .22823 .75309 L .25999 .75466 L p .707 .577 .707 r
F P
0 g
s
.54723 .2378 m .56524 .72543 L .52124 .72337 L p .707 .577 .707 r
F P
0 g
s
.52124 .72337 m .50324 .23574 L .54723 .2378 L p .707 .577 .707 r
F P
0 g
s
.23513 .72585 m .23555 .68853 L .26738 .68816 L p .707 .577 .707 r
F P
0 g
s
.25999 .75466 m .25881 .77373 L .22705 .77215 L p .707 .577 .707 r
F P
0 g
s
.72646 .75572 m .72764 .73665 L .6965 .73394 L p .707 .577 .707 r
F P
0 g
s
.72764 .73665 m .72646 .75572 L .75823 .75729 L p .707 .577 .707 r
F P
0 g
s
.75823 .75729 m .7594 .73823 L .72764 .73665 L p .707 .577 .707 r
F P
0 g
s
.26738 .68816 m .26697 .72548 L .23513 .72585 L p .707 .577 .707 r
F P
0 g
s
.6965 .73394 m .69532 .753 L .72646 .75572 L p .707 .577 .707 r
F P
0 g
s
.7594 .73823 m .75823 .75729 L .78749 .75758 L p .707 .577 .707 r
F P
0 g
s
.78749 .75758 m .78867 .73852 L .7594 .73823 L p .707 .577 .707 r
F P
0 g
s
.69532 .753 m .6965 .73394 L .66901 .73036 L p .707 .577 .707 r
F P
0 g
s
.66901 .73036 m .66783 .74942 L .69532 .753 L p .707 .577 .707 r
F P
0 g
s
.8152 .61162 m .82411 .6562 L .83942 .6369 L p .707 .577 .707 r
F P
0 g
s
.83942 .6369 m .83051 .59232 L .8152 .61162 L p .707 .577 .707 r
F P
0 g
s
.67351 .63992 m .68241 .6845 L .71004 .69078 L p .707 .577 .707 r
F P
0 g
s
.78867 .73852 m .78749 .75758 L .8114 .75656 L p .707 .577 .707 r
F P
0 g
s
.8114 .75656 m .81258 .73749 L .78867 .73852 L p .707 .577 .707 r
F P
0 g
s
.83051 .59232 m .83942 .6369 L .84544 .6166 L p .707 .577 .707 r
F P
0 g
s
.84544 .6166 m .83653 .57202 L .83051 .59232 L p .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .66087 .67256 L .68241 .6845 L p .707 .577 .707 r
F P
0 g
s
.65439 .66058 m .65398 .69789 L .67503 .70394 L p .707 .577 .707 r
F P
0 g
s
.81934 .66495 m .81892 .70227 L .83529 .69579 L p .707 .577 .707 r
F P
0 g
s
.83529 .69579 m .8357 .65848 L .81934 .66495 L p .707 .577 .707 r
F P
0 g
s
.81258 .73749 m .8114 .75656 L .82761 .75431 L p .707 .577 .707 r
F P
0 g
s
.82761 .75431 m .82879 .73525 L .81258 .73749 L p .707 .577 .707 r
F P
0 g
s
.83653 .57202 m .84544 .6166 L .84159 .5973 L p .637 .531 .717 r
F P
0 g
s
.84159 .5973 m .83268 .55272 L .83653 .57202 L p .637 .531 .717 r
F P
0 g
s
.63861 .61155 m .64752 .65613 L .66087 .67256 L p .707 .577 .707 r
F P
0 g
s
.64752 .65613 m .63861 .61155 L .63476 .59225 L p .635 .53 .717 r
F P
0 g
s
.8357 .65848 m .83529 .69579 L .84237 .68832 L p .707 .577 .707 r
F P
0 g
s
.84237 .68832 m .84278 .651 L .8357 .65848 L p .707 .577 .707 r
F P
0 g
s
.82879 .73525 m .82761 .75431 L .83453 .75107 L p .707 .577 .707 r
F P
0 g
s
.83453 .75107 m .83571 .73201 L .82879 .73525 L p .707 .577 .707 r
F P
0 g
s
.64138 .69065 m .6418 .65333 L .63889 .64559 L p .707 .577 .707 r
F P
0 g
s
.83268 .55272 m .84159 .5973 L .82824 .58087 L p .707 .577 .707 r
F P
0 g
s
.82824 .58087 m .81933 .53629 L .83268 .55272 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .63476 .59225 L .64078 .57195 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .64752 .65613 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63889 .64559 m .63848 .68291 L .64138 .69065 L p .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .63889 .64559 L .64428 .6399 L p .707 .577 .707 r
F P
0 g
s
.64428 .6399 m .64597 .63811 L p .64504 .6437 L .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .64428 .6399 L .64504 .6437 L .707 .577 .707 r
F
.63476 .59225 m .63924 .61468 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63924 .61468 m .64366 .63683 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84278 .651 m .84237 .68832 L .83947 .68058 L p .707 .577 .707 r
F P
0 g
s
.83947 .68058 m .83988 .64326 L .84278 .651 L p .707 .577 .707 r
F P
0 g
s
.83571 .73201 m .83453 .75107 L .83149 .74715 L p .707 .577 .707 r
F P
0 g
s
.83149 .74715 m .83267 .72809 L .83571 .73201 L p .707 .577 .707 r
F P
0 g
s
.81933 .53629 m .82824 .58087 L .80669 .56893 L p .707 .577 .707 r
F P
0 g
s
.80669 .56893 m .79778 .52435 L .81933 .53629 L p .707 .577 .707 r
F P
0 g
s
.64969 .61653 m .64078 .57195 L .65609 .55266 L p .707 .577 .707 r
F P
0 g
s
.64078 .57195 m .64969 .61653 L .64366 .63683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64597 .63811 m .64556 .67543 L .63848 .68291 L p .707 .577 .707 r
F P
0 g
s
.45228 .63299 m .45187 .67031 L .47591 .66546 L p .707 .577 .707 r
F P
0 g
s
.42047 .60313 m .42938 .64771 L .458 .63579 L p .707 .577 .707 r
F P
0 g
s
.38913 .6094 m .39803 .65397 L .42938 .64771 L p .707 .577 .707 r
F P
0 g
s
.83988 .64326 m .83947 .68058 L .82687 .67333 L p .707 .577 .707 r
F P
0 g
s
.82687 .67333 m .82729 .63601 L .83988 .64326 L p .707 .577 .707 r
F P
0 g
s
.79778 .52435 m .80669 .56893 L .77907 .56265 L p .707 .577 .707 r
F P
0 g
s
.77907 .56265 m .77016 .51807 L .79778 .52435 L p .707 .577 .707 r
F P
0 g
s
.65609 .55266 m .66499 .59723 L .64969 .61653 L p .707 .577 .707 r
F P
0 g
s
.66499 .59723 m .65609 .55266 L .67918 .53624 L p .707 .577 .707 r
F P
0 g
s
.4811 .61938 m .47219 .5748 L .4491 .59121 L p .707 .577 .707 r
F P
0 g
s
.35812 .60938 m .36703 .65396 L .39803 .65397 L p .707 .577 .707 r
F P
0 g
s
.83267 .72809 m .83149 .74715 L .81878 .74294 L p .707 .577 .707 r
F P
0 g
s
.81878 .74294 m .81996 .72387 L .83267 .72809 L p .707 .577 .707 r
F P
0 g
s
.38345 .7189 m .38463 .69984 L .35349 .69712 L p .707 .577 .707 r
F P
0 g
s
.35349 .69712 m .35231 .71619 L .38345 .7189 L p .707 .577 .707 r
F P
0 g
s
.64556 .67543 m .64597 .63811 L .66234 .63163 L p .707 .577 .707 r
F P
0 g
s
.77016 .51807 m .77907 .56265 L .74806 .56264 L p .707 .577 .707 r
F P
0 g
s
.74806 .56264 m .73915 .51806 L .77016 .51807 L p .707 .577 .707 r
F P
0 g
s
.68809 .58082 m .67918 .53624 L .70781 .52432 L p .707 .577 .707 r
F P
0 g
s
.67918 .53624 m .68809 .58082 L .66499 .59723 L p .707 .577 .707 r
F P
0 g
s
.63788 .73395 m .63906 .71488 L .65527 .71264 L p .707 .577 .707 r
F P
0 g
s
.35231 .71619 m .35349 .69712 L .326 .69354 L p .707 .577 .707 r
F P
0 g
s
.65527 .71264 m .65409 .7317 L .63788 .73395 L p .707 .577 .707 r
F P
0 g
s
.326 .69354 m .32482 .71261 L .35231 .71619 L p .707 .577 .707 r
F P
0 g
s
.47219 .5748 m .4811 .61938 L .49641 .60008 L p .707 .577 .707 r
F P
0 g
s
.49641 .60008 m .4875 .5555 L .47219 .5748 L p .707 .577 .707 r
F P
0 g
s
.3305 .6031 m .3394 .64768 L .36703 .65396 L p .707 .577 .707 r
F P
0 g
s
.66234 .63163 m .66192 .66895 L .64556 .67543 L p .707 .577 .707 r
F P
0 g
s
.73915 .51806 m .74806 .56264 L .71671 .5689 L p .707 .577 .707 r
F P
0 g
s
.71671 .5689 m .70781 .52432 L .73915 .51806 L p .707 .577 .707 r
F P
0 g
s
.70781 .52432 m .71671 .5689 L .68809 .58082 L p .707 .577 .707 r
F P
0 g
s
.82729 .63601 m .82687 .67333 L .80581 .66728 L p .707 .577 .707 r
F P
0 g
s
.80581 .66728 m .80623 .62997 L .82729 .63601 L p .707 .577 .707 r
F P
0 g
s
.32482 .71261 m .326 .69354 L .30487 .68945 L p .707 .577 .707 r
F P
0 g
s
.81996 .72387 m .81878 .74294 L .79765 .73884 L p .707 .577 .707 r
F P
0 g
s
.79765 .73884 m .79883 .71977 L .81996 .72387 L p .707 .577 .707 r
F P
0 g
s
.30487 .68945 m .30369 .70851 L .32482 .71261 L p .707 .577 .707 r
F P
0 g
s
.66192 .66895 m .66234 .63163 L .68639 .62678 L p .707 .577 .707 r
F P
0 g
s
.4875 .5555 m .49641 .60008 L .50243 .57979 L p .707 .577 .707 r
F P
0 g
s
.50243 .57979 m .49352 .53521 L .4875 .5555 L p .707 .577 .707 r
F P
0 g
s
.30895 .59116 m .31786 .63574 L .3394 .64768 L p .707 .577 .707 r
F P
0 g
s
.31138 .62376 m .31097 .66108 L .33202 .66712 L p .707 .577 .707 r
F P
0 g
s
.65409 .7317 m .65527 .71264 L .67917 .71161 L p .707 .577 .707 r
F P
0 g
s
.47633 .62814 m .47591 .66546 L .49228 .65898 L p .707 .577 .707 r
F P
0 g
s
.49228 .65898 m .49269 .62166 L .47633 .62814 L p .707 .577 .707 r
F P
0 g
s
.67917 .71161 m .678 .73068 L .65409 .7317 L p .707 .577 .707 r
F P
0 g
s
.68639 .62678 m .68597 .6641 L .66192 .66895 L p .707 .577 .707 r
F P
0 g
s
.80623 .62997 m .80581 .66728 L .77835 .66303 L p .707 .577 .707 r
F P
0 g
s
.77835 .66303 m .77877 .62571 L .80623 .62997 L p .707 .577 .707 r
F P
0 g
s
.31097 .66108 m .31138 .62376 L .29878 .61651 L p .707 .577 .707 r
F P
0 g
s
.30369 .70851 m .30487 .68945 L .29216 .68523 L p .707 .577 .707 r
F P
0 g
s
.79883 .71977 m .79765 .73884 L .77017 .73526 L p .707 .577 .707 r
F P
0 g
s
.77017 .73526 m .77135 .71619 L .79883 .71977 L p .707 .577 .707 r
F P
0 g
s
.29216 .68523 m .29099 .70429 L .30369 .70851 L p .707 .577 .707 r
F P
0 g
s
.68597 .6641 m .68639 .62678 L .71576 .62404 L p .707 .577 .707 r
F P
0 g
s
.49352 .53521 m .50243 .57979 L .49858 .56048 L p .634 .529 .717 r
F P
0 g
s
.49858 .56048 m .48967 .5159 L .49352 .53521 L p .634 .529 .717 r
F P
0 g
s
.2956 .57474 m .30451 .61932 L .31786 .63574 L p .707 .577 .707 r
F P
0 g
s
.30451 .61932 m .2956 .57474 L .29175 .55543 L p .632 .527 .718 r
F P
0 g
s
.29878 .61651 m .29837 .65383 L .31097 .66108 L p .707 .577 .707 r
F P
0 g
s
.678 .73068 m .67917 .71161 L .70844 .7119 L p .707 .577 .707 r
F P
0 g
s
.70844 .7119 m .70726 .73097 L .678 .73068 L p .707 .577 .707 r
F P
0 g
s
.77877 .62571 m .77835 .66303 L .74718 .66099 L p .707 .577 .707 r
F P
0 g
s
.74718 .66099 m .7476 .62367 L .77877 .62571 L p .707 .577 .707 r
F P
0 g
s
.71576 .62404 m .71535 .66136 L .68597 .6641 L p .707 .577 .707 r
F P
0 g
s
.49269 .62166 m .49228 .65898 L .49936 .6515 L p .707 .577 .707 r
F P
0 g
s
.49936 .6515 m .49977 .61418 L .49269 .62166 L p .707 .577 .707 r
F P
0 g
s
.71535 .66136 m .71576 .62404 L .7476 .62367 L p .707 .577 .707 r
F P
0 g
s
.77135 .71619 m .77017 .73526 L .73902 .73255 L p .707 .577 .707 r
F P
0 g
s
.73902 .73255 m .7402 .71348 L .77135 .71619 L p .707 .577 .707 r
F P
0 g
s
.7476 .62367 m .74718 .66099 L .71535 .66136 L p .707 .577 .707 r
F P
0 g
s
.48578 .69843 m .4846 .7175 L .49152 .71426 L p .707 .577 .707 r
F P
0 g
s
.49152 .71426 m .4927 .69519 L .48578 .69843 L p .707 .577 .707 r
F P
0 g
s
.70726 .73097 m .70844 .7119 L .7402 .71348 L p .707 .577 .707 r
F P
0 g
s
.7402 .71348 m .73902 .73255 L .70726 .73097 L p .707 .577 .707 r
F P
0 g
s
.29837 .65383 m .29878 .61651 L .29588 .60877 L p .707 .577 .707 r
F P
0 g
s
.29099 .70429 m .29216 .68523 L .28912 .68131 L p .707 .577 .707 r
F P
0 g
s
.28912 .68131 m .28795 .70037 L .29099 .70429 L p .707 .577 .707 r
F P
0 g
s
.48967 .5159 m .49858 .56048 L .48523 .54406 L p .707 .577 .707 r
F P
0 g
s
.48523 .54406 m .47632 .49948 L .48967 .5159 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .29175 .55543 L .29777 .53514 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .30451 .61932 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29588 .60877 m .29547 .64609 L .29837 .65383 L p .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .29588 .60877 L .30127 .60308 L p .707 .577 .707 r
F P
0 g
s
.30127 .60308 m .30296 .6013 L p .30203 .60688 L .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .30127 .60308 L .30203 .60688 L .707 .577 .707 r
F
.29175 .55543 m .29623 .57786 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29623 .57786 m .30065 .60001 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49977 .61418 m .49936 .6515 L .49646 .64376 L p .707 .577 .707 r
F P
0 g
s
.49646 .64376 m .49687 .60644 L .49977 .61418 L p .707 .577 .707 r
F P
0 g
s
.4927 .69519 m .49152 .71426 L .48848 .71034 L p .707 .577 .707 r
F P
0 g
s
.48848 .71034 m .48966 .69127 L .4927 .69519 L p .707 .577 .707 r
F P
0 g
s
.47632 .49948 m .48523 .54406 L .46368 .53212 L p .707 .577 .707 r
F P
0 g
s
.46368 .53212 m .45477 .48754 L .47632 .49948 L p .707 .577 .707 r
F P
0 g
s
.30668 .57972 m .29777 .53514 L .31308 .51584 L p .707 .577 .707 r
F P
0 g
s
.29777 .53514 m .30668 .57972 L .30065 .60001 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28795 .70037 m .28912 .68131 L .29605 .67807 L p .707 .577 .707 r
F P
0 g
s
.29605 .67807 m .29487 .69713 L .28795 .70037 L p .707 .577 .707 r
F P
0 g
s
.30296 .6013 m .30255 .63861 L .29547 .64609 L p .707 .577 .707 r
F P
0 g
s
.49687 .60644 m .49646 .64376 L .48386 .63651 L p .707 .577 .707 r
F P
0 g
s
.48386 .63651 m .48428 .5992 L .49687 .60644 L p .707 .577 .707 r
F P
0 g
s
.45477 .48754 m .46368 .53212 L .43606 .52584 L p .707 .577 .707 r
F P
0 g
s
.43606 .52584 m .42715 .48126 L .45477 .48754 L p .707 .577 .707 r
F P
0 g
s
.31308 .51584 m .32198 .56042 L .30668 .57972 L p .707 .577 .707 r
F P
0 g
s
.32198 .56042 m .31308 .51584 L .33617 .49943 L p .707 .577 .707 r
F P
0 g
s
.48966 .69127 m .48848 .71034 L .47577 .70612 L p .707 .577 .707 r
F P
0 g
s
.47577 .70612 m .47695 .68706 L .48966 .69127 L p .707 .577 .707 r
F P
0 g
s
.30255 .63861 m .30296 .6013 L .31933 .59482 L p .707 .577 .707 r
F P
0 g
s
.42715 .48126 m .43606 .52584 L .40505 .52582 L p .707 .577 .707 r
F P
0 g
s
.40505 .52582 m .39614 .48125 L .42715 .48126 L p .707 .577 .707 r
F P
0 g
s
.34508 .54401 m .33617 .49943 L .3648 .48751 L p .707 .577 .707 r
F P
0 g
s
.33617 .49943 m .34508 .54401 L .32198 .56042 L p .707 .577 .707 r
F P
0 g
s
.29487 .69713 m .29605 .67807 L .31225 .67583 L p .707 .577 .707 r
F P
0 g
s
.31225 .67583 m .31108 .69489 L .29487 .69713 L p .707 .577 .707 r
F P
0 g
s
.31933 .59482 m .31891 .63214 L .30255 .63861 L p .707 .577 .707 r
F P
0 g
s
.39614 .48125 m .40505 .52582 L .3737 .53209 L p .707 .577 .707 r
F P
0 g
s
.3737 .53209 m .3648 .48751 L .39614 .48125 L p .707 .577 .707 r
F P
0 g
s
.3648 .48751 m .3737 .53209 L .34508 .54401 L p .707 .577 .707 r
F P
0 g
s
.48428 .5992 m .48386 .63651 L .4628 .63047 L p .707 .577 .707 r
F P
0 g
s
.4628 .63047 m .46322 .59315 L .48428 .5992 L p .707 .577 .707 r
F P
0 g
s
.47695 .68706 m .47577 .70612 L .45464 .70202 L p .707 .577 .707 r
F P
0 g
s
.45464 .70202 m .45582 .68296 L .47695 .68706 L p .707 .577 .707 r
F P
0 g
s
.31891 .63214 m .31933 .59482 L .34337 .58997 L p .707 .577 .707 r
F P
0 g
s
.31108 .69489 m .31225 .67583 L .33616 .6748 L p .707 .577 .707 r
F P
0 g
s
.33616 .6748 m .33498 .69386 L .31108 .69489 L p .707 .577 .707 r
F P
0 g
s
.34337 .58997 m .34296 .62729 L .31891 .63214 L p .707 .577 .707 r
F P
0 g
s
.46322 .59315 m .4628 .63047 L .43534 .62622 L p .707 .577 .707 r
F P
0 g
s
.43534 .62622 m .43576 .5889 L .46322 .59315 L p .707 .577 .707 r
F P
0 g
s
.45582 .68296 m .45464 .70202 L .42716 .69844 L p .707 .577 .707 r
F P
0 g
s
.42716 .69844 m .42834 .67938 L .45582 .68296 L p .707 .577 .707 r
F P
0 g
s
.34296 .62729 m .34337 .58997 L .37275 .58723 L p .707 .577 .707 r
F P
0 g
s
.33498 .69386 m .33616 .6748 L .36543 .67509 L p .707 .577 .707 r
F P
0 g
s
.36543 .67509 m .36425 .69415 L .33498 .69386 L p .707 .577 .707 r
F P
0 g
s
.43576 .5889 m .43534 .62622 L .40417 .62418 L p .707 .577 .707 r
F P
0 g
s
.40417 .62418 m .40459 .58686 L .43576 .5889 L p .707 .577 .707 r
F P
0 g
s
.37275 .58723 m .37234 .62454 L .34296 .62729 L p .707 .577 .707 r
F P
0 g
s
.37234 .62454 m .37275 .58723 L .40459 .58686 L p .707 .577 .707 r
F P
0 g
s
.42834 .67938 m .42716 .69844 L .39601 .69573 L p .707 .577 .707 r
F P
0 g
s
.39601 .69573 m .39719 .67667 L .42834 .67938 L p .707 .577 .707 r
F P
0 g
s
.40459 .58686 m .40417 .62418 L .37234 .62454 L p .707 .577 .707 r
F P
0 g
s
.36425 .69415 m .36543 .67509 L .39719 .67667 L p .707 .577 .707 r
F P
0 g
s
.39719 .67667 m .39601 .69573 L .36425 .69415 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolM001oOol007eoo`@0
0003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00H007Uoo`00NGoo10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1000MGoo001eOol40009FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001bOol0079oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006moo`00KWoo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P00KGoo001/Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH2001/Ool006Yoo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00001ZOol006Uoo`04001JEUYF
0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF0000JGoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVQoo`00IGoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYFJ7oo001TOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEVMoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Eoo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEPd000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00D005YFFUH005YF00@0
009JEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00<005YF00000P001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol30009FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006=oo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00HGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00Ggoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Eoo`00GGoo0`0025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8006Eoo`00G7oo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Yoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001IOol00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001HOol20006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol05Woo3000@Goo001GOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool04Woo10000UYF00<005YFFUH01EYF00<005YF00000`00?Goo001FOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000moo`@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<003Yoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00@000QJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Goo0P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30004FUH01@00FUIJEUYF
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo
0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00=Woo001D
Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH20003FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0027oo0P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YFFUIJEP8003Aoo`00E7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0`0000EJEP00FUIJEP0000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<000QJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00Dgoo0P00
1EYF00<005YFFUH01EYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000bOol005=oo`03001JEP0000AJEP03001JEUYF00=J
EP8000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool01@00FUIJEUYF000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00<Woo001BOol01000FUIJEP001EYF00D005YFFUIJEP0000Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000a
Ool0059oo`04001JEUYF0005FUH01000FUIJEP001goo00@005YFFUH000EJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003Ool005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000`Ool0059oo`04
001JEUYF0005FUH30008Ool01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00@005YF
FUIJEP800003FUH0000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF000`Ool0059oo`80009JEP03001JEUYF009JEP03001oogoo00Qo
o`04001JEUYF0005FUH30008FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF0000<7oo001COol01000FUIJEP000eYF00<007ooOol02Goo00@005YFFUH000AJEPD0
00MJEP03001JEUYF00QJEP04001JEUYF0002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000FUIJEP00;goo0017Ool=0002FUH01000FUIJ
EP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001JEP0000=JEP03001JEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH5000AOol50004FUH01000FUIJEP00;goo0013Ool40002FUH00`00FUIJ
EP06FUH20002FUH01000FUIJEP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001J
EP0000=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00eYF0P006goo0P000UYF00@005YFFUH002mo
o`00@7oo0`001UYF00<005YFFUH01UYF0`000UYF10002goo00@005YFFUH000EJEP<000QJEP03001J
EUYF00QJEP8000AJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00@005YFFUIJEP8001moo`06001JEUYF001JEP00
;goo000nOol30009FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP030009Ool01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH01eYF0`001EYF00<005YF000015YF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00@005YF0000
029oo`<0009JEP03001oogoo02aoo`00?7oo0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
0UYF00@005YFFUH0009JEP03001oogoo00Ioo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP001EYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF0P009Woo00@005YFFUH002ioo`00>Woo0P00
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000Ioo`04
001JEUYF0005FUH80003FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF00<005YF000015YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP02
FUH2000YOol00`00FUH0000^Ool003Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF009JEPl000AJEP04001JEUYFFUH800000eYF00000005FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000:goo0`00;Woo000fOol30008FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEUYF1P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00eYF0`00;7oo00@005YF000002eo
o`00=Goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP00FUH50005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020005
FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00Oomoo`0AOol3000GOol20002FUH00`00Oomoo`0[Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH40006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJ
EP02FUH00`00Oomoo`0AOol5000EOol00`00FUH00002FUH00`00Oomoo`0[Ool0039oo`03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH0000D
Ool5000DOol01000FUIJEP000UYF00<007ooOol0:goo000aOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000EOol5000COol0
0`00FUIJEP02FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000FOol3000COol00`00
FUIJEP03FUH01000FUIJEP00;7oo000_Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
15YF3@000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP00009JEP@002Yoo`8000EJEP04001JEUYF000/Ool002moo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool00`00Ool00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000UYF0P0000AJEP00000002Moo`03001JEP0000EJEP04001JEUYF000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP@000ioo`<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH20000
15YF001JEUYF0P008goo0P000eYF00<005YFFUH00UYF00@005YFFUH002aoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00eYF0P004Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00FUH30002FUH01000FUIJEUYF0P00
1Woo5`000goo00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUH00002000DOol00`00FUH00003FUH01000FUIJEUYF2@0025YF0`00
1EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF00@005YFFUIJEPP000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEP8002eoo`00;7oo0P001EYF00<0
05YFFUH01EYF0P005goo00<005YF00000eYF100000=JEP00FUH01EYF00<005YFFUH01EYF1@001UYF
00<005YFFUH00eYF1P0015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YF1`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1P001EYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH2
000IOol01000FUH005YF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH0
1UYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001oogoo02aoo`00
:goo00@005YFFUH000EJEP05001JEUYFFUH0000KOol00`00FUH000020002FUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH20005FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000^Ool002]oo`04001JEUYF0005FUH01000FUIJEP0077oo0P000UYF00<005YFFUH00UYF00@0
05YFFUH000IJEP03001JEUYF00EJEP<000QJEP04001JEUYFFUH30006FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool01000FUIJEP001EYF0`007Goo00D005YFFUIJEP00
00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`05001JEUYFFUH00004FUH00`00Oomo
o`0MOol01@00FUIJEUYF00001EYF00<005YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/
Ool01000FUIJEP000eYF00<007ooOol04Woo0`002Goo00D005YFFUIJEP0000EJEP03001JEUYF00=J
EQ80009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo019oo`D000Uoo`04001JEUYF0005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo
019oo`D000Yoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEUYF
0P005Goo1@0037oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP02FUHA0007FUH80004FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`04001JEUYF000GOol3000@Ool70004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEP00008000MJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00AJEPH000AJEP03001JEUYF008002eoo`00;Goo00@005YFFUH002]oo`04001JEUYF
0002FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`0000IJEP00000005YF0002FUH2000]Ool0
02eoo`03001JEP0002]oob<000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEP00FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF
00<005YFFUH015YF0P0015YF00@005YF0000009JEP8002eoo`00;Goo00<005YF000097oo20000eYF
00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP800003FUH005YF008000=JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF009JEP<000EJEP04001JEUYFFUH4000]
Ool002ioo`03FUH00000025oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH20007FUH30007FUH0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEP000080
01moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH70003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01UYF00<005YFFUH0
15YF10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000^Ool00`00FUH00002FUH2000:
OolA0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03
001JEUYF00D000QJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@005YF
FUH000=JEPX000=JEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Woo000^Ool01@00FUIJEP00FUH010000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF7`0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool2000015YF000000001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000`001EYF00@005YFFUIJEPT00003FUH005YF00EJ
EP04001JEUYFFUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP/000MJEP03001JEP0000H000=JEP06001JEUYF
001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800006
Ool00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00<goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0;
FUH00`00FUIJEP06FUH500000eYF00000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0017oo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000Woo0P000eYF00<005YF00007`00>Woo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF7`00AWoo000]Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
2@0015YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YF000025YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2000?Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
00=JEP000000200025YF00<005YFFUH02EYF10002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPL003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03
001JEUYF00QJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003=oo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEPT000aJEPT000QJEP03001JEUYF00IJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0035oo`00;Goo00<005YF00000eYF00@005YFFUIJEPP00003FUH005YF
00EJEPD000MJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P00
0UYF00<005YFFUH01UYF0P000eYF00@005YFFUIJEQ4000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYF000`Ool002eoo`03001JEP0000=JEPL000IJEP03001JEUYF00AJ
EPD000MJEP03001JEP0000T000=JEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH9
00000eYF001JEP02FUH80004Ool80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000]Ool01000FUH005YF0P0015YF00<005YF00000`0015YF00<005YFFUH015YF0`0015YF
1`000eYF00<005YFFUH00eYF10000eYF00<007ooFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF500015YF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00;Goo00<005YF00000P001EYF00<005YFFUH00eYF4P000UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool00eYF00<005YFFUH00eYF
00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF0`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000=JEP04001JEUYFFUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH300001GooFUIJEUYF00001EYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00D005YFFUIJEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002mo
o`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYFFUH005YF001oo`=JEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF1000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH00000FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000_Ool002eoob4000=JEP03001JEUYF00EJEP03001JEUYF
00AJEP08001JEUYFFUH005YF001oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP0B0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000`Ool002]oo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001J
EUYF00AJEP04001JEUYFFUH20002Ool3FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00P002Woo5P00=7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00D005YFFUIJ
EP0000=oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH00P00E7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP070004Ool2FUH01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF008005Aoo`00:Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000goo00=JEP00FUH00eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001P0015YF00<005YFFUH00P00E7oo000ZOol00`00FUH00002FUHF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0000AJEP00FUIJ
EP8005Aoo`00:Woo00<005YF00000`001EYF00@005YFFUIJEPT0009ooa8000AJEP03001JEUYF00=J
EP04001JEUYFFUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020005
FUH01000FUH000000UYF0P00E7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK0003FUH01P00FUIJEP00FUH0009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP05001JEP00FUH00005FUH01000FUIJEUYF1000E7oo000[Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH20003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH3001DOol002eoo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000Aoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00<Woo1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
00Aoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH00`00FUH0001DOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001Goo00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001EOol0049oo`T000AJEP03001JEUYF00EJEP04001JEUYFFUH9
0007Ool200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEP000eYF1P000eYF00@005YFFUIJEP8005Ioo`00Bgoo
40004Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF10001eYF00<005YF00000`0000=JEP000000F7oo001^Ool20007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF
001JEP07FUH00`00FUIJEP02FUH3001IOol0071oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001GOol0079oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000D000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008005Ioo`00M7oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2@0000=oo`0000001P0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00MWoo
1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEPH0009JEP03001JEP0001@000=J
EP04001JEUYFFUH2001FOol007eoo`/000IJEP03001JEUYF00AJEPX000QJEP03001JEP0000@0009J
EP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8005Ioo`00R7oo3@0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
05Ioo`00Tgoo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000EWoo002JOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP04001GOol00:=ooal005]oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63519 .77235 m .62628 .72777 L .59493 .73403 L p .707 .577 .707 r
F P
0 g
s
.62628 .72777 m .63519 .77235 L .66381 .76043 L p .707 .577 .707 r
F P
0 g
s
.66381 .76043 m .6549 .71585 L .62628 .72777 L p .707 .577 .707 r
F P
0 g
s
.62829 .81117 m .62871 .77385 L .59688 .77422 L p .707 .577 .707 r
F P
0 g
s
.60384 .77861 m .59493 .73403 L .56393 .73402 L p .707 .577 .707 r
F P
0 g
s
.59493 .73403 m .60384 .77861 L .63519 .77235 L p .707 .577 .707 r
F P
0 g
s
.6549 .71585 m .66381 .76043 L .68691 .74401 L p .707 .577 .707 r
F P
0 g
s
.68691 .74401 m .678 .69943 L .6549 .71585 L p .707 .577 .707 r
F P
0 g
s
.59646 .81153 m .59688 .77422 L .5657 .77217 L p .707 .577 .707 r
F P
0 g
s
.57284 .7786 m .56393 .73402 L .5363 .72774 L p .707 .577 .707 r
F P
0 g
s
.59688 .77422 m .59646 .81153 L .62829 .81117 L p .707 .577 .707 r
F P
0 g
s
.56393 .73402 m .57284 .7786 L .60384 .77861 L p .707 .577 .707 r
F P
0 g
s
.58926 .83371 m .59044 .81465 L .55929 .81194 L p .707 .577 .707 r
F P
0 g
s
.59044 .81465 m .58926 .83371 L .62102 .83529 L p .707 .577 .707 r
F P
0 g
s
.62102 .83529 m .6222 .81623 L .59044 .81465 L p .707 .577 .707 r
F P
0 g
s
.55929 .81194 m .55811 .831 L .58926 .83371 L p .707 .577 .707 r
F P
0 g
s
.6222 .81623 m .62102 .83529 L .65029 .83558 L p .707 .577 .707 r
F P
0 g
s
.65029 .83558 m .65147 .81652 L .6222 .81623 L p .707 .577 .707 r
F P
0 g
s
.55811 .831 m .55929 .81194 L .53181 .80836 L p .707 .577 .707 r
F P
0 g
s
.62871 .77385 m .62829 .81117 L .65767 .80842 L p .707 .577 .707 r
F P
0 g
s
.65767 .80842 m .65809 .77111 L .62871 .77385 L p .707 .577 .707 r
F P
0 g
s
.53181 .80836 m .53063 .82742 L .55811 .831 L p .707 .577 .707 r
F P
0 g
s
.678 .69943 m .68691 .74401 L .70221 .72471 L p .707 .577 .707 r
F P
0 g
s
.70221 .72471 m .69331 .68014 L .678 .69943 L p .707 .577 .707 r
F P
0 g
s
.56529 .80949 m .5657 .77217 L .53825 .76792 L p .707 .577 .707 r
F P
0 g
s
.54521 .77231 m .5363 .72774 L .51476 .7158 L p .707 .577 .707 r
F P
0 g
s
.5657 .77217 m .56529 .80949 L .59646 .81153 L p .707 .577 .707 r
F P
0 g
s
.5363 .72774 m .54521 .77231 L .57284 .7786 L p .707 .577 .707 r
F P
0 g
s
.65147 .81652 m .65029 .83558 L .6742 .83455 L p .707 .577 .707 r
F P
0 g
s
.6742 .83455 m .67538 .81549 L .65147 .81652 L p .707 .577 .707 r
F P
0 g
s
.65809 .77111 m .65767 .80842 L .68172 .80358 L p .707 .577 .707 r
F P
0 g
s
.68172 .80358 m .68214 .76626 L .65809 .77111 L p .707 .577 .707 r
F P
0 g
s
.53825 .76792 m .53783 .80524 L .56529 .80949 L p .707 .577 .707 r
F P
0 g
s
.53063 .82742 m .53181 .80836 L .51068 .80426 L p .707 .577 .707 r
F P
0 g
s
.51068 .80426 m .5095 .82332 L .53063 .82742 L p .707 .577 .707 r
F P
0 g
s
.53783 .80524 m .53825 .76792 L .51719 .76188 L p .707 .577 .707 r
F P
0 g
s
.69331 .68014 m .70221 .72471 L .70824 .70442 L p .707 .577 .707 r
F P
0 g
s
.70824 .70442 m .69933 .65984 L .69331 .68014 L p .707 .577 .707 r
F P
0 g
s
.52367 .76038 m .51476 .7158 L .50141 .69937 L p .707 .577 .707 r
F P
0 g
s
.51476 .7158 m .52367 .76038 L .54521 .77231 L p .707 .577 .707 r
F P
0 g
s
.67538 .81549 m .6742 .83455 L .69041 .83231 L p .707 .577 .707 r
F P
0 g
s
.69041 .83231 m .69158 .81325 L .67538 .81549 L p .707 .577 .707 r
F P
0 g
s
.51719 .76188 m .51677 .7992 L .53783 .80524 L p .707 .577 .707 r
F P
0 g
s
.68214 .76626 m .68172 .80358 L .69808 .7971 L p .707 .577 .707 r
F P
0 g
s
.69808 .7971 m .6985 .75978 L .68214 .76626 L p .707 .577 .707 r
F P
0 g
s
.5095 .82332 m .51068 .80426 L .49797 .80004 L p .707 .577 .707 r
F P
0 g
s
.49797 .80004 m .49679 .81911 L .5095 .82332 L p .707 .577 .707 r
F P
0 g
s
.51677 .7992 m .51719 .76188 L .50459 .75463 L p .707 .577 .707 r
F P
0 g
s
.69933 .65984 m .70824 .70442 L .70438 .68511 L p .636 .53 .717 r
F P
0 g
s
.70438 .68511 m .69548 .64054 L .69933 .65984 L p .636 .53 .717 r
F P
0 g
s
.50141 .69937 m .51031 .74395 L .52367 .76038 L p .707 .577 .707 r
F P
0 g
s
.51031 .74395 m .50141 .69937 L .49755 .68007 L p .634 .529 .717 r
F P
0 g
s
.50459 .75463 m .50418 .79195 L .51677 .7992 L p .707 .577 .707 r
F P
0 g
s
.69158 .81325 m .69041 .83231 L .69733 .82907 L p .707 .577 .707 r
F P
0 g
s
.69733 .82907 m .69851 .81001 L .69158 .81325 L p .707 .577 .707 r
F P
0 g
s
.6985 .75978 m .69808 .7971 L .70516 .78962 L p .707 .577 .707 r
F P
0 g
s
.70516 .78962 m .70558 .7523 L .6985 .75978 L p .707 .577 .707 r
F P
0 g
s
.49679 .81911 m .49797 .80004 L .49493 .79612 L p .707 .577 .707 r
F P
0 g
s
.49493 .79612 m .49375 .81519 L .49679 .81911 L p .707 .577 .707 r
F P
0 g
s
.49375 .81519 m .49493 .79612 L .50185 .79288 L p .707 .577 .707 r
F P
0 g
s
.50185 .79288 m .50067 .81195 L .49375 .81519 L p .707 .577 .707 r
F P
0 g
s
.50067 .81195 m .50185 .79288 L .51806 .79064 L p .707 .577 .707 r
F P
0 g
s
.51806 .79064 m .51688 .8097 L .50067 .81195 L p .707 .577 .707 r
F P
0 g
s
.50256 .82491 m .48455 .33728 L .44056 .33523 L p .707 .577 .707 r
F P
0 g
s
.50418 .79195 m .50459 .75463 L .50169 .74689 L p .707 .577 .707 r
F P
0 g
s
.50646 .72465 m .49755 .68007 L .50358 .65977 L p .707 .577 .707 r
F P
0 g
s
.49755 .68007 m .50646 .72465 L .51031 .74395 L p .634 .529 .717 r
F P
0 g
s
.50169 .74689 m .50127 .78421 L .50418 .79195 L p .707 .577 .707 r
F P
0 g
s
.51248 .70435 m .50358 .65977 L .51888 .64047 L p .707 .577 .707 r
F P
0 g
s
.50358 .65977 m .51248 .70435 L .50646 .72465 L p .707 .577 .707 r
F P
0 g
s
.50127 .78421 m .50169 .74689 L .50877 .73941 L p .707 .577 .707 r
F P
0 g
s
.50877 .73941 m .50835 .77673 L .50127 .78421 L p .707 .577 .707 r
F P
0 g
s
.51888 .64047 m .52779 .68505 L .51248 .70435 L p .707 .577 .707 r
F P
0 g
s
.52779 .68505 m .51888 .64047 L .54198 .62406 L p .707 .577 .707 r
F P
0 g
s
.54198 .62406 m .55089 .66864 L .52779 .68505 L p .707 .577 .707 r
F P
0 g
s
.50835 .77673 m .50877 .73941 L .52513 .73294 L p .707 .577 .707 r
F P
0 g
s
.52513 .73294 m .52472 .77025 L .50835 .77673 L p .707 .577 .707 r
F P
0 g
s
.51688 .8097 m .51806 .79064 L .54197 .78961 L p .707 .577 .707 r
F P
0 g
s
.54197 .78961 m .54079 .80868 L .51688 .8097 L p .707 .577 .707 r
F P
0 g
s
.52472 .77025 m .52513 .73294 L .54918 .72809 L p .707 .577 .707 r
F P
0 g
s
.54918 .72809 m .54876 .76541 L .52472 .77025 L p .707 .577 .707 r
F P
0 g
s
.54079 .80868 m .54197 .78961 L .57124 .7899 L p .707 .577 .707 r
F P
0 g
s
.57124 .7899 m .57006 .80897 L .54079 .80868 L p .707 .577 .707 r
F P
0 g
s
.48455 .33728 m .50256 .82491 L .54747 .822 L p .707 .577 .707 r
F P
0 g
s
.54747 .822 m .52946 .33437 L .48455 .33728 L p .707 .577 .707 r
F P
0 g
s
.55089 .66864 m .54198 .62406 L .5706 .61214 L p .707 .577 .707 r
F P
0 g
s
.5706 .61214 m .57951 .65672 L .55089 .66864 L p .707 .577 .707 r
F P
0 g
s
.54876 .76541 m .54918 .72809 L .57856 .72535 L p .707 .577 .707 r
F P
0 g
s
.57856 .72535 m .57814 .76266 L .54876 .76541 L p .707 .577 .707 r
F P
0 g
s
.57006 .80897 m .57124 .7899 L .603 .79148 L p .707 .577 .707 r
F P
0 g
s
.57814 .76266 m .57856 .72535 L .61039 .72498 L p .707 .577 .707 r
F P
0 g
s
.603 .79148 m .60182 .81054 L .57006 .80897 L p .707 .577 .707 r
F P
0 g
s
.61039 .72498 m .60998 .76229 L .57814 .76266 L p .707 .577 .707 r
F P
0 g
s
.52946 .33437 m .54747 .822 L .5889 .81441 L p .707 .577 .707 r
F P
0 g
s
.60195 .60588 m .61086 .65046 L .57951 .65672 L p .707 .577 .707 r
F P
0 g
s
.57951 .65672 m .5706 .61214 L .60195 .60588 L p .707 .577 .707 r
F P
0 g
s
.5889 .81441 m .57089 .32677 L .52946 .33437 L p .707 .577 .707 r
F P
0 g
s
.69548 .64054 m .70438 .68511 L .69103 .66869 L p .707 .577 .707 r
F P
0 g
s
.69103 .66869 m .68212 .62411 L .69548 .64054 L p .707 .577 .707 r
F P
0 g
s
.45856 .82286 m .44056 .33523 L .40178 .3284 L p .707 .577 .707 r
F P
0 g
s
.44056 .33523 m .45856 .82286 L .50256 .82491 L p .707 .577 .707 r
F P
0 g
s
.63414 .79419 m .63297 .81326 L .60182 .81054 L p .707 .577 .707 r
F P
0 g
s
.60182 .81054 m .603 .79148 L .63414 .79419 L p .707 .577 .707 r
F P
0 g
s
.64156 .72702 m .64115 .76434 L .60998 .76229 L p .707 .577 .707 r
F P
0 g
s
.60998 .76229 m .61039 .72498 L .64156 .72702 L p .707 .577 .707 r
F P
0 g
s
.57089 .32677 m .5889 .81441 L .62279 .80287 L p .707 .577 .707 r
F P
0 g
s
.63295 .60589 m .64186 .65047 L .61086 .65046 L p .707 .577 .707 r
F P
0 g
s
.61086 .65046 m .60195 .60588 L .63295 .60589 L p .707 .577 .707 r
F P
0 g
s
.62279 .80287 m .60479 .31524 L .57089 .32677 L p .707 .577 .707 r
F P
0 g
s
.69851 .81001 m .69733 .82907 L .69429 .82515 L p .707 .577 .707 r
F P
0 g
s
.69429 .82515 m .69546 .80609 L .69851 .81001 L p .707 .577 .707 r
F P
0 g
s
.70558 .7523 m .70516 .78962 L .70226 .78188 L p .707 .577 .707 r
F P
0 g
s
.70226 .78188 m .70268 .74456 L .70558 .7523 L p .707 .577 .707 r
F P
0 g
s
.41979 .81603 m .40178 .3284 L .37202 .31747 L p .707 .577 .707 r
F P
0 g
s
.40178 .3284 m .41979 .81603 L .45856 .82286 L p .707 .577 .707 r
F P
0 g
s
.68212 .62411 m .69103 .66869 L .66949 .65675 L p .707 .577 .707 r
F P
0 g
s
.66949 .65675 m .66058 .61217 L .68212 .62411 L p .707 .577 .707 r
F P
0 g
s
.63297 .81326 m .63414 .79419 L .66163 .79777 L p .707 .577 .707 r
F P
0 g
s
.66902 .73127 m .66861 .76859 L .64115 .76434 L p .707 .577 .707 r
F P
0 g
s
.64115 .76434 m .64156 .72702 L .66902 .73127 L p .707 .577 .707 r
F P
0 g
s
.60479 .31524 m .62279 .80287 L .64583 .78852 L p .707 .577 .707 r
F P
0 g
s
.64186 .65047 m .63295 .60589 L .66058 .61217 L p .707 .577 .707 r
F P
0 g
s
.64583 .78852 m .62782 .30089 L .60479 .31524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29218 .73553 m .28327 .69095 L .25192 .69721 L p .707 .577 .707 r
F P
0 g
s
.28327 .69095 m .29218 .73553 L .3208 .72361 L p .707 .577 .707 r
F P
0 g
s
.3208 .72361 m .31189 .67903 L .28327 .69095 L p .707 .577 .707 r
F P
0 g
s
.28528 .77435 m .2857 .73703 L .25387 .7374 L p .707 .577 .707 r
F P
0 g
s
.26083 .74179 m .25192 .69721 L .22092 .6972 L p .707 .577 .707 r
F P
0 g
s
.25192 .69721 m .26083 .74179 L .29218 .73553 L p .707 .577 .707 r
F P
0 g
s
.66058 .61217 m .66949 .65675 L .64186 .65047 L p .707 .577 .707 r
F P
0 g
s
.69546 .80609 m .69429 .82515 L .68158 .82093 L p .707 .577 .707 r
F P
0 g
s
.68158 .82093 m .68276 .80187 L .69546 .80609 L p .707 .577 .707 r
F P
0 g
s
.70268 .74456 m .70226 .78188 L .68967 .77463 L p .707 .577 .707 r
F P
0 g
s
.68967 .77463 m .69008 .73731 L .70268 .74456 L p .707 .577 .707 r
F P
0 g
s
.31189 .67903 m .3208 .72361 L .3439 .7072 L p .707 .577 .707 r
F P
0 g
s
.3439 .7072 m .33499 .66262 L .31189 .67903 L p .707 .577 .707 r
F P
0 g
s
.25345 .77472 m .25387 .7374 L .22269 .73536 L p .707 .577 .707 r
F P
0 g
s
.22983 .74178 m .22092 .6972 L .19329 .69092 L p .707 .577 .707 r
F P
0 g
s
.25387 .7374 m .25345 .77472 L .28528 .77435 L p .707 .577 .707 r
F P
0 g
s
.22092 .6972 m .22983 .74178 L .26083 .74179 L p .707 .577 .707 r
F P
0 g
s
.24625 .7969 m .24743 .77783 L .21628 .77512 L p .707 .577 .707 r
F P
0 g
s
.24743 .77783 m .24625 .7969 L .27801 .79848 L p .707 .577 .707 r
F P
0 g
s
.27801 .79848 m .27919 .77941 L .24743 .77783 L p .707 .577 .707 r
F P
0 g
s
.21628 .77512 m .2151 .79419 L .24625 .7969 L p .707 .577 .707 r
F P
0 g
s
.27919 .77941 m .27801 .79848 L .30728 .79877 L p .707 .577 .707 r
F P
0 g
s
.30728 .79877 m .30846 .7797 L .27919 .77941 L p .707 .577 .707 r
F P
0 g
s
.39003 .8051 m .37202 .31747 L .35419 .30352 L p .707 .577 .707 r
F P
0 g
s
.37202 .31747 m .39003 .8051 L .41979 .81603 L p .707 .577 .707 r
F P
0 g
s
.2151 .79419 m .21628 .77512 L .1888 .77154 L p .707 .577 .707 r
F P
0 g
s
.2857 .73703 m .28528 .77435 L .31466 .77161 L p .707 .577 .707 r
F P
0 g
s
.31466 .77161 m .31508 .73429 L .2857 .73703 L p .707 .577 .707 r
F P
0 g
s
.1888 .77154 m .18762 .79061 L .2151 .79419 L p .707 .577 .707 r
F P
0 g
s
.33499 .66262 m .3439 .7072 L .3592 .6879 L p .707 .577 .707 r
F P
0 g
s
.3592 .6879 m .3503 .64332 L .33499 .66262 L p .707 .577 .707 r
F P
0 g
s
.22228 .77268 m .22269 .73536 L .19524 .73111 L p .707 .577 .707 r
F P
0 g
s
.2022 .7355 m .19329 .69092 L .17175 .67898 L p .707 .577 .707 r
F P
0 g
s
.22269 .73536 m .22228 .77268 L .25345 .77472 L p .707 .577 .707 r
F P
0 g
s
.19329 .69092 m .2022 .7355 L .22983 .74178 L p .707 .577 .707 r
F P
0 g
s
.30846 .7797 m .30728 .79877 L .33119 .79774 L p .707 .577 .707 r
F P
0 g
s
.33119 .79774 m .33237 .77867 L .30846 .7797 L p .707 .577 .707 r
F P
0 g
s
.31508 .73429 m .31466 .77161 L .33871 .76676 L p .707 .577 .707 r
F P
0 g
s
.33871 .76676 m .33913 .72944 L .31508 .73429 L p .707 .577 .707 r
F P
0 g
s
.19524 .73111 m .19482 .76843 L .22228 .77268 L p .707 .577 .707 r
F P
0 g
s
.18762 .79061 m .1888 .77154 L .16767 .76744 L p .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .66901 .73036 L .65615 .72786 L p .707 .577 .707 r
F P
0 g
s
.62782 .30089 m .64583 .78852 L .65482 .77425 L p .707 .577 .707 r
F P
0 g
s
.65516 .76258 m .62782 .30089 L .65482 .77425 L .707 .577 .707 r
F
.63775 .28513 m .62782 .30089 L p .65516 .76258 L F P
0 g
s
.65576 .77276 m .65525 .75913 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .63775 .28513 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.64788 .72626 m .6467 .74532 L .65443 .74682 L p .707 .577 .707 r
F P
0 g
s
.65419 .74326 m .64788 .72626 L .65443 .74682 L .707 .577 .707 r
F
.64885 .66332 m .64721 .60747 L .65525 .75913 L F
.63775 .28513 m .64879 .5842 L p .64721 .60747 L F P
0 g
s
.64879 .5842 m .65525 .75913 L p .64721 .60747 L .707 .577 .707 r
F P
0 g
s
.65593 .7356 m .65349 .73277 L .6556 .74705 L .707 .577 .707 r
F
.65349 .73277 m .64788 .72626 L .65419 .74326 L F
.65349 .73277 m .65419 .74326 L .6556 .74705 L F
.6336 .26951 m .63775 .28513 L p .64885 .66332 L F P
0 g
s
.65615 .72786 m .64788 .72626 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64726 .63956 L .64885 .66332 L .707 .577 .707 r
F
.64949 .69983 m .64726 .63956 L p .65036 .71465 L F P
0 g
s
.64726 .63956 m .6336 .26951 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.65482 .77425 m .65576 .77276 L p .65516 .76258 L .707 .577 .707 r
F P
0 g
s
.65576 .77276 m .6532 .76315 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.6532 .76315 m .6516 .75714 L p .65036 .71465 L .707 .577 .707 r
F P
0 g
s
.65036 .71465 m .64885 .66332 L .6532 .76315 L .707 .577 .707 r
F
.6467 .74532 m .64788 .72626 L .63518 .72204 L p F P
0 g
s
.63518 .72204 m .634 .74111 L .6467 .74532 L p .707 .577 .707 r
F P
0 g
s
.634 .74111 m .63518 .72204 L .63213 .71812 L p .707 .577 .707 r
F P
0 g
s
.63213 .71812 m .63096 .73719 L .634 .74111 L p .707 .577 .707 r
F P
0 g
s
.6336 .26951 m .6516 .75714 L .63393 .7433 L p .707 .577 .707 r
F P
0 g
s
.63096 .73719 m .6337 .71739 L .63381 .72934 L .707 .577 .707 r
F
.63377 .72496 m .6336 .26951 L .63393 .7433 L F
.63906 .71488 m .63788 .73395 L .63386 .73583 L p F P
0 g
s
.63386 .73583 m .63096 .73719 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.63381 .72934 m .63906 .71488 L .63386 .73583 L .707 .577 .707 r
F
.63096 .73719 m .63213 .71812 L .6337 .71739 L p F P
0 g
s
.63378 .74318 m .61577 .25555 L .62985 .26658 L p .707 .577 .707 r
F P
0 g
s
.62985 .26658 m .6336 .26951 L p .63377 .72496 L .707 .577 .707 r
F P
0 g
s
.63378 .74318 m .62985 .26658 L .63377 .72496 L .707 .577 .707 r
F
.63393 .7433 m .63378 .74318 L p .63377 .72496 L F P
0 g
s
.6337 .71739 m .63906 .71488 L p .63381 .72934 L .707 .577 .707 r
F P
0 g
s
.6418 .65333 m .64138 .69065 L .64921 .69515 L p .707 .577 .707 r
F P
0 g
s
.65525 .75913 m .65576 .77276 L p .64885 .66332 L .707 .577 .707 r
F P
0 g
s
.64921 .69515 m .65398 .69789 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.64812 .67646 m .6418 .65333 L .64921 .69515 L .707 .577 .707 r
F
.65398 .69789 m .65439 .66058 L .64693 .65628 L p F P
0 g
s
.64693 .65628 m .6418 .65333 L p .64812 .67646 L .707 .577 .707 r
F P
0 g
s
.65398 .69789 m .64693 .65628 L .64812 .67646 L .707 .577 .707 r
F
.6516 .75714 m .64949 .69983 L p .65036 .71465 L F P
0 g
s
.67503 .70394 m .67529 .68121 L p .65439 .66058 L .707 .577 .707 r
F P
0 g
s
.67529 .68121 m .67545 .66662 L .6664 .66402 L p .707 .577 .707 r
F P
0 g
s
.6664 .66402 m .65439 .66058 L p .67529 .68121 L .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .64629 .621 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .65461 .64121 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.65461 .64121 m .65196 .62798 L p .64887 .63011 L .707 .577 .707 r
F P
0 g
s
.64629 .621 m .63861 .61155 L p .64563 .63078 L .707 .577 .707 r
F P
0 g
s
.66087 .67256 m .64629 .621 L .64563 .63078 L .707 .577 .707 r
F
.65443 .74682 m .6556 .74705 L p .65419 .74326 L F P
0 g
s
.6556 .74705 m .66783 .74942 L p .65593 .7356 L .707 .577 .707 r
F P
0 g
s
.66783 .74942 m .65615 .72786 L .65593 .7356 L .707 .577 .707 r
F
.68276 .80187 m .68158 .82093 L .66045 .81684 L p F P
0 g
s
.66045 .81684 m .66163 .79777 L .68276 .80187 L p .707 .577 .707 r
F P
0 g
s
.16767 .76744 m .16649 .78651 L .18762 .79061 L p .707 .577 .707 r
F P
0 g
s
.69008 .73731 m .68967 .77463 L .66861 .76859 L p .707 .577 .707 r
F P
0 g
s
.66861 .76859 m .66902 .73127 L .69008 .73731 L p .707 .577 .707 r
F P
0 g
s
.19482 .76843 m .19524 .73111 L .17418 .72506 L p .707 .577 .707 r
F P
0 g
s
.3503 .64332 m .3592 .6879 L .36523 .6676 L p .707 .577 .707 r
F P
0 g
s
.36523 .6676 m .35632 .62303 L .3503 .64332 L p .707 .577 .707 r
F P
0 g
s
.18066 .72356 m .17175 .67898 L .1584 .66256 L p .707 .577 .707 r
F P
0 g
s
.17175 .67898 m .18066 .72356 L .2022 .7355 L p .707 .577 .707 r
F P
0 g
s
.33237 .77867 m .33119 .79774 L .3474 .7955 L p .707 .577 .707 r
F P
0 g
s
.3474 .7955 m .34857 .77643 L .33237 .77867 L p .707 .577 .707 r
F P
0 g
s
.17418 .72506 m .17376 .76238 L .19482 .76843 L p .707 .577 .707 r
F P
0 g
s
.33913 .72944 m .33871 .76676 L .35507 .76028 L p .707 .577 .707 r
F P
0 g
s
.35507 .76028 m .35549 .72296 L .33913 .72944 L p .707 .577 .707 r
F P
0 g
s
.3722 .79115 m .35419 .30352 L .35004 .28789 L p .707 .577 .707 r
F P
0 g
s
.35419 .30352 m .3722 .79115 L .39003 .8051 L p .707 .577 .707 r
F P
0 g
s
.16649 .78651 m .16767 .76744 L .15496 .76323 L p .707 .577 .707 r
F P
0 g
s
.66163 .79777 m .66045 .81684 L .63297 .81326 L p .707 .577 .707 r
F P
0 g
s
.15496 .76323 m .15378 .78229 L .16649 .78651 L p .707 .577 .707 r
F P
0 g
s
.17376 .76238 m .17418 .72506 L .16158 .71782 L p .707 .577 .707 r
F P
0 g
s
.35632 .62303 m .36523 .6676 L .36137 .6483 L p .632 .528 .718 r
F P
0 g
s
.36137 .6483 m .35247 .60372 L .35632 .62303 L p .632 .528 .718 r
F P
0 g
s
.1584 .66256 m .1673 .70714 L .18066 .72356 L p .707 .577 .707 r
F P
0 g
s
.1673 .70714 m .1584 .66256 L .15454 .64325 L p .63 .526 .718 r
F P
0 g
s
.16158 .71782 m .16117 .75513 L .17376 .76238 L p .707 .577 .707 r
F P
0 g
s
.34857 .77643 m .3474 .7955 L .35432 .79225 L p .707 .577 .707 r
F P
0 g
s
.35432 .79225 m .3555 .77319 L .34857 .77643 L p .707 .577 .707 r
F P
0 g
s
.35549 .72296 m .35507 .76028 L .36215 .75281 L p .707 .577 .707 r
F P
0 g
s
.36215 .75281 m .36257 .71549 L .35549 .72296 L p .707 .577 .707 r
F P
0 g
s
.15378 .78229 m .15496 .76323 L .15192 .75931 L p .707 .577 .707 r
F P
0 g
s
.15192 .75931 m .15074 .77837 L .15378 .78229 L p .707 .577 .707 r
F P
0 g
s
.16117 .75513 m .16158 .71782 L .15868 .71007 L p .707 .577 .707 r
F P
0 g
s
.35247 .60372 m .36137 .6483 L .34802 .63187 L p .707 .577 .707 r
F P
0 g
s
.34802 .63187 m .33911 .5873 L .35247 .60372 L p .707 .577 .707 r
F P
0 g
s
.16345 .68783 m .15454 .64325 L .16057 .62296 L p .707 .577 .707 r
F P
0 g
s
.15454 .64325 m .16345 .68783 L .1673 .70714 L p .63 .526 .718 r
F P
0 g
s
.35004 .28789 m .36805 .77553 L .3722 .79115 L p .707 .577 .707 r
F P
0 g
s
.36805 .77553 m .35004 .28789 L .35997 .27214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15868 .71007 m .15826 .74739 L .16117 .75513 L p .707 .577 .707 r
F P
0 g
s
.3555 .77319 m .35432 .79225 L .35128 .78834 L p .707 .577 .707 r
F P
0 g
s
.35128 .78834 m .35246 .76927 L .3555 .77319 L p .707 .577 .707 r
F P
0 g
s
.36257 .71549 m .36215 .75281 L .35925 .74507 L p .707 .577 .707 r
F P
0 g
s
.35925 .74507 m .35967 .70775 L .36257 .71549 L p .707 .577 .707 r
F P
0 g
s
.33911 .5873 m .34802 .63187 L .32648 .61994 L p .707 .577 .707 r
F P
0 g
s
.32648 .61994 m .31757 .57536 L .33911 .5873 L p .707 .577 .707 r
F P
0 g
s
.16947 .66754 m .16057 .62296 L .17587 .60366 L p .707 .577 .707 r
F P
0 g
s
.16057 .62296 m .16947 .66754 L .16345 .68783 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15074 .77837 m .15192 .75931 L .15884 .75607 L p .707 .577 .707 r
F P
0 g
s
.15884 .75607 m .15766 .77513 L .15074 .77837 L p .707 .577 .707 r
F P
0 g
s
.15826 .74739 m .15868 .71007 L .16576 .7026 L p .707 .577 .707 r
F P
0 g
s
.16576 .7026 m .16534 .73992 L .15826 .74739 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.31757 .57536 m .32648 .61994 L .29885 .61365 L p .707 .577 .707 r
F P
0 g
s
.29885 .61365 m .28995 .56908 L .31757 .57536 L p .707 .577 .707 r
F P
0 g
s
.17587 .60366 m .18478 .64824 L .16947 .66754 L p .707 .577 .707 r
F P
0 g
s
.18478 .64824 m .17587 .60366 L .19897 .58725 L p .707 .577 .707 r
F P
0 g
s
.37797 .75977 m .35997 .27214 L .383 .25779 L p .707 .577 .707 r
F P
0 g
s
.35997 .27214 m .37797 .75977 L .36805 .77553 L p .707 .577 .707 r
F P
0 g
s
.35246 .76927 m .35128 .78834 L .33857 .78412 L p .707 .577 .707 r
F P
0 g
s
.33857 .78412 m .33975 .76506 L .35246 .76927 L p .707 .577 .707 r
F P
0 g
s
.35967 .70775 m .35925 .74507 L .34666 .73782 L p .707 .577 .707 r
F P
0 g
s
.34666 .73782 m .34707 .7005 L .35967 .70775 L p .707 .577 .707 r
F P
0 g
s
.15766 .77513 m .15884 .75607 L .17505 .75382 L p .707 .577 .707 r
F P
0 g
s
.17505 .75382 m .17387 .77289 L .15766 .77513 L p .707 .577 .707 r
F P
0 g
s
.28995 .56908 m .29885 .61365 L .26785 .61364 L p .707 .577 .707 r
F P
0 g
s
.26785 .61364 m .25894 .56906 L .28995 .56908 L p .707 .577 .707 r
F P
0 g
s
.20788 .63182 m .19897 .58725 L .22759 .57533 L p .707 .577 .707 r
F P
0 g
s
.19897 .58725 m .20788 .63182 L .18478 .64824 L p .707 .577 .707 r
F P
0 g
s
.16534 .73992 m .16576 .7026 L .18212 .69612 L p .707 .577 .707 r
F P
0 g
s
.61577 .25555 m .63378 .74318 L .60402 .73226 L p .707 .577 .707 r
F P
0 g
s
.60402 .73226 m .58601 .24463 L .61577 .25555 L p .707 .577 .707 r
F P
0 g
s
.25894 .56906 m .26785 .61364 L .2365 .6199 L p .707 .577 .707 r
F P
0 g
s
.2365 .6199 m .22759 .57533 L .25894 .56906 L p .707 .577 .707 r
F P
0 g
s
.22759 .57533 m .2365 .6199 L .20788 .63182 L p .707 .577 .707 r
F P
0 g
s
.18212 .69612 m .18171 .73344 L .16534 .73992 L p .707 .577 .707 r
F P
0 g
s
.33975 .76506 m .33857 .78412 L .31744 .78002 L p .707 .577 .707 r
F P
0 g
s
.31744 .78002 m .31862 .76096 L .33975 .76506 L p .707 .577 .707 r
F P
0 g
s
.34707 .7005 m .34666 .73782 L .3256 .73177 L p .707 .577 .707 r
F P
0 g
s
.3256 .73177 m .32601 .69445 L .34707 .7005 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .40659 .57025 L .42095 .65324 L .707 .577 .707 r
F
.37797 .75977 m .38063 .49454 L .40016 .73492 L F
.40101 .74542 m .39884 .74678 L p .40016 .73492 L F P
0 g
s
.39884 .74678 m .37797 .75977 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.3934 .53939 m .40051 .73179 L p .38063 .49454 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .40101 .74542 L p .40016 .73492 L .707 .577 .707 r
F P
0 g
s
.38063 .49454 m .40051 .73179 L .40016 .73492 L .707 .577 .707 r
F
.40521 .71372 m .40271 .71204 L .4036 .7199 L F
.383 .25779 m .4169 .24625 L p .40158 .72768 L F P
0 g
s
.40101 .74542 m .40051 .73179 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.40051 .73179 m .383 .25779 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .41639 .70141 L .40851 .70102 L p .707 .577 .707 r
F P
0 g
s
.40851 .70102 m .38463 .69984 L p .40521 .71372 L .707 .577 .707 r
F P
0 g
s
.41522 .72048 m .40851 .70102 L .40521 .71372 L .707 .577 .707 r
F
.40271 .71204 m .38463 .69984 L .40202 .71823 L F
.40271 .71204 m .40202 .71823 L .4036 .7199 L F
.38463 .69984 m .38345 .7189 L .40184 .71981 L p F P
0 g
s
.40184 .71981 m .4036 .7199 L p .40202 .71823 L .707 .577 .707 r
F P
0 g
s
.40202 .71823 m .38463 .69984 L .40184 .71981 L .707 .577 .707 r
F
.4036 .7199 m .41522 .72048 L p .40521 .71372 L F P
0 g
s
.4349 .73388 m .40101 .74542 L p .40158 .72768 L .707 .577 .707 r
F P
0 g
s
.41639 .70141 m .41522 .72048 L .44448 .72077 L p .707 .577 .707 r
F P
0 g
s
.44448 .72077 m .44566 .7017 L .41639 .70141 L p .707 .577 .707 r
F P
0 g
s
.40158 .72768 m .42095 .65324 L .42884 .69887 L .707 .577 .707 r
F
.42978 .59502 m .43279 .67657 L p .40659 .57025 L F P
0 g
s
.43279 .67657 m .4349 .73388 L p .42884 .69887 L .707 .577 .707 r
F P
0 g
s
.40659 .57025 m .43279 .67657 L .42884 .69887 L .707 .577 .707 r
F
.44566 .7017 m .44448 .72077 L .46839 .71974 L p F P
0 g
s
.46839 .71974 m .46957 .70068 L .44566 .7017 L p .707 .577 .707 r
F P
0 g
s
.45833 .23865 m .47633 .72629 L .47598 .72635 L p .707 .577 .707 r
F P
0 g
s
.46957 .70068 m .46839 .71974 L .47519 .7188 L p .707 .577 .707 r
F P
0 g
s
.47379 .7054 m .46957 .70068 L .47519 .7188 L .707 .577 .707 r
F
.44794 .45826 m .45833 .23865 L .47598 .72635 L F
.45833 .23865 m .50324 .23574 L p .49249 .4316 L F P
0 g
s
.47633 .72629 m .46927 .5351 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.46927 .5351 m .45833 .23865 L p .49249 .4316 L .707 .577 .707 r
F P
0 g
s
.50324 .23574 m .52124 .72337 L .47633 .72629 L p .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .48578 .69843 L .47325 .70017 L p .707 .577 .707 r
F P
0 g
s
.47325 .70017 m .46957 .70068 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.4846 .7175 m .47325 .70017 L .47379 .7054 L .707 .577 .707 r
F
.47598 .72635 m .4349 .73388 L p .44794 .45826 L F P
0 g
s
.47591 .66546 m .47633 .62814 L .45228 .63299 L p .707 .577 .707 r
F P
0 g
s
.458 .63579 m .4811 .61938 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.4491 .59121 m .45267 .60909 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.45267 .60909 m .458 .63579 L p .45543 .59679 L .707 .577 .707 r
F P
0 g
s
.47519 .7188 m .4846 .7175 L p .47379 .7054 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .45228 .63299 L .4403 .63411 L p .707 .577 .707 r
F P
0 g
s
.4349 .73388 m .4169 .24625 L .45833 .23865 L p .707 .577 .707 r
F P
0 g
s
.4403 .63411 m .4229 .63573 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.45187 .67031 m .4403 .63411 L .43703 .65259 L .707 .577 .707 r
F
.4229 .63573 m .42249 .67305 L .43359 .67201 L p F P
0 g
s
.43359 .67201 m .45187 .67031 L p .43703 .65259 L .707 .577 .707 r
F P
0 g
s
.43703 .65259 m .4229 .63573 L .43359 .67201 L .707 .577 .707 r
F
.42304 .73168 m .42884 .69887 L .4349 .73388 L F
.40158 .72768 m .42884 .69887 L .42304 .73168 L F
.4169 .24625 m .42978 .59502 L p .40659 .57025 L F P
0 g
s
.458 .63579 m .45531 .62229 L p .42047 .60313 L .707 .577 .707 r
F P
0 g
s
.45531 .62229 m .4491 .59121 L .43263 .59807 L p .707 .577 .707 r
F P
0 g
s
.43263 .59807 m .42047 .60313 L p .45531 .62229 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .42047 .60313 L .41204 .60482 L p .707 .577 .707 r
F P
0 g
s
.42249 .67305 m .42287 .63832 L p .39107 .6361 L .707 .577 .707 r
F P
0 g
s
.42287 .63832 m .4229 .63573 L .41848 .63578 L p .707 .577 .707 r
F P
0 g
s
.41848 .63578 m .39107 .6361 L p .42287 .63832 L .707 .577 .707 r
F P
0 g
s
.39065 .67342 m .391 .64197 L p .3599 .63406 L .707 .577 .707 r
F P
0 g
s
.391 .64197 m .39107 .6361 L .38228 .63552 L p .707 .577 .707 r
F P
0 g
s
.38228 .63552 m .3599 .63406 L p .391 .64197 L .707 .577 .707 r
F P
0 g
s
.35948 .67137 m .35979 .64344 L p .33244 .62981 L .707 .577 .707 r
F P
0 g
s
.35979 .64344 m .3599 .63406 L .34978 .63249 L p .707 .577 .707 r
F P
0 g
s
.34978 .63249 m .33244 .62981 L p .35979 .64344 L .707 .577 .707 r
F P
0 g
s
.33244 .62981 m .33202 .66712 L .35948 .67137 L p .707 .577 .707 r
F P
0 g
s
.33202 .66712 m .33228 .64439 L p .31138 .62376 L .707 .577 .707 r
F P
0 g
s
.33228 .64439 m .33244 .62981 L .32339 .62721 L p .707 .577 .707 r
F P
0 g
s
.32339 .62721 m .31138 .62376 L p .33228 .64439 L .707 .577 .707 r
F P
0 g
s
.31786 .63574 m .3116 .6044 L p .2956 .57474 L .707 .577 .707 r
F P
0 g
s
.3116 .6044 m .30895 .59116 L .29741 .57697 L p .707 .577 .707 r
F P
0 g
s
.29741 .57697 m .2956 .57474 L p .3116 .6044 L .707 .577 .707 r
F P
0 g
s
.3394 .64768 m .33262 .61372 L p .30895 .59116 L .707 .577 .707 r
F P
0 g
s
.33262 .61372 m .3305 .6031 L .31511 .59458 L p .707 .577 .707 r
F P
0 g
s
.31511 .59458 m .30895 .59116 L p .33262 .61372 L .707 .577 .707 r
F P
0 g
s
.3599 .63406 m .35948 .67137 L .39065 .67342 L p .707 .577 .707 r
F P
0 g
s
.36703 .65396 m .36006 .61911 L p .3305 .6031 L .707 .577 .707 r
F P
0 g
s
.36006 .61911 m .35812 .60938 L .34193 .6057 L p .707 .577 .707 r
F P
0 g
s
.34193 .6057 m .3305 .6031 L p .36006 .61911 L .707 .577 .707 r
F P
0 g
s
.39107 .6361 m .39065 .67342 L .42249 .67305 L p .707 .577 .707 r
F P
0 g
s
.39803 .65397 m .39125 .62002 L p .35812 .60938 L .707 .577 .707 r
F P
0 g
s
.39125 .62002 m .38913 .6094 L .37289 .60939 L p .707 .577 .707 r
F P
0 g
s
.37289 .60939 m .35812 .60938 L p .39125 .62002 L .707 .577 .707 r
F P
0 g
s
.41204 .60482 m .38913 .6094 L p .42234 .64101 L .707 .577 .707 r
F P
0 g
s
.42938 .64771 m .41204 .60482 L .42234 .64101 L .707 .577 .707 r
F
.383 .25779 m .3934 .53939 L p .38063 .49454 L F P
0 g
s
.17387 .77289 m .17505 .75382 L .19896 .7528 L p .707 .577 .707 r
F P
0 g
s
.19896 .7528 m .19778 .77186 L .17387 .77289 L p .707 .577 .707 r
F P
0 g
s
.18171 .73344 m .18212 .69612 L .20617 .69127 L p .707 .577 .707 r
F P
0 g
s
.20617 .69127 m .20576 .72859 L .18171 .73344 L p .707 .577 .707 r
F P
0 g
s
.58601 .24463 m .60402 .73226 L .56524 .72543 L p .707 .577 .707 r
F P
0 g
s
.56524 .72543 m .54723 .2378 L .58601 .24463 L p .707 .577 .707 r
F P
0 g
s
.31862 .76096 m .31744 .78002 L .28996 .77644 L p .707 .577 .707 r
F P
0 g
s
.28996 .77644 m .29114 .75738 L .31862 .76096 L p .707 .577 .707 r
F P
0 g
s
.32601 .69445 m .3256 .73177 L .29814 .72752 L p .707 .577 .707 r
F P
0 g
s
.29814 .72752 m .29855 .6902 L .32601 .69445 L p .707 .577 .707 r
F P
0 g
s
.19778 .77186 m .19896 .7528 L .22823 .75309 L p .707 .577 .707 r
F P
0 g
s
.20576 .72859 m .20617 .69127 L .23555 .68853 L p .707 .577 .707 r
F P
0 g
s
.7655 .70986 m .76588 .67514 L p .73408 .67291 L .707 .577 .707 r
F P
0 g
s
.76588 .67514 m .76591 .67254 L .76149 .6726 L p .707 .577 .707 r
F P
0 g
s
.76149 .6726 m .73408 .67291 L p .76588 .67514 L .707 .577 .707 r
F P
0 g
s
.73366 .71023 m .73401 .67879 L p .70291 .67087 L .707 .577 .707 r
F P
0 g
s
.73401 .67879 m .73408 .67291 L .72529 .67234 L p .707 .577 .707 r
F P
0 g
s
.72529 .67234 m .70291 .67087 L p .73401 .67879 L .707 .577 .707 r
F P
0 g
s
.70249 .70819 m .7028 .68026 L p .67545 .66662 L .707 .577 .707 r
F P
0 g
s
.7028 .68026 m .70291 .67087 L .69279 .66931 L p .707 .577 .707 r
F P
0 g
s
.69279 .66931 m .67545 .66662 L p .7028 .68026 L .707 .577 .707 r
F P
0 g
s
.67545 .66662 m .67503 .70394 L .70249 .70819 L p .707 .577 .707 r
F P
0 g
s
.68241 .6845 m .67563 .65054 L p .65196 .62798 L .707 .577 .707 r
F P
0 g
s
.67563 .65054 m .67351 .63992 L .65812 .63139 L p .707 .577 .707 r
F P
0 g
s
.65812 .63139 m .65196 .62798 L p .67563 .65054 L .707 .577 .707 r
F P
0 g
s
.70291 .67087 m .70249 .70819 L .73366 .71023 L p .707 .577 .707 r
F P
0 g
s
.71004 .69078 m .70307 .65592 L p .67351 .63992 L .707 .577 .707 r
F P
0 g
s
.70307 .65592 m .70113 .6462 L .68494 .64252 L p .707 .577 .707 r
F P
0 g
s
.68494 .64252 m .67351 .63992 L p .70307 .65592 L .707 .577 .707 r
F P
0 g
s
.73408 .67291 m .73366 .71023 L .7655 .70986 L p .707 .577 .707 r
F P
0 g
s
.74104 .69079 m .73426 .65683 L p .70113 .6462 L .707 .577 .707 r
F P
0 g
s
.73426 .65683 m .73214 .64621 L .7159 .64621 L p .707 .577 .707 r
F P
0 g
s
.7159 .64621 m .70113 .6462 L p .73426 .65683 L .707 .577 .707 r
F P
0 g
s
.76591 .67254 m .7655 .70986 L .79488 .70712 L p .707 .577 .707 r
F P
0 g
s
.79488 .70712 m .79529 .6698 L .76591 .67254 L p .707 .577 .707 r
F P
0 g
s
.77239 .68453 m .76348 .63995 L .73214 .64621 L p .707 .577 .707 r
F P
0 g
s
.79529 .6698 m .79488 .70712 L .81892 .70227 L p .707 .577 .707 r
F P
0 g
s
.81892 .70227 m .81934 .66495 L .79529 .6698 L p .707 .577 .707 r
F P
0 g
s
.76348 .63995 m .77239 .68453 L .80101 .67261 L p .707 .577 .707 r
F P
0 g
s
.80101 .67261 m .79211 .62803 L .76348 .63995 L p .707 .577 .707 r
F P
0 g
s
.73214 .64621 m .74104 .69079 L .77239 .68453 L p .707 .577 .707 r
F P
0 g
s
.22823 .75309 m .22705 .77215 L .19778 .77186 L p .707 .577 .707 r
F P
0 g
s
.29114 .75738 m .28996 .77644 L .25881 .77373 L p .707 .577 .707 r
F P
0 g
s
.25881 .77373 m .25999 .75466 L .29114 .75738 L p .707 .577 .707 r
F P
0 g
s
.79211 .62803 m .80101 .67261 L .82411 .6562 L p .707 .577 .707 r
F P
0 g
s
.82411 .6562 m .8152 .61162 L .79211 .62803 L p .707 .577 .707 r
F P
0 g
s
.70113 .6462 m .71004 .69078 L .74104 .69079 L p .707 .577 .707 r
F P
0 g
s
.29855 .6902 m .29814 .72752 L .26697 .72548 L p .707 .577 .707 r
F P
0 g
s
.26697 .72548 m .26738 .68816 L .29855 .6902 L p .707 .577 .707 r
F P
0 g
s
.23555 .68853 m .23513 .72585 L .20576 .72859 L p .707 .577 .707 r
F P
0 g
s
.22705 .77215 m .22823 .75309 L .25999 .75466 L p .707 .577 .707 r
F P
0 g
s
.54723 .2378 m .56524 .72543 L .52124 .72337 L p .707 .577 .707 r
F P
0 g
s
.52124 .72337 m .50324 .23574 L .54723 .2378 L p .707 .577 .707 r
F P
0 g
s
.23513 .72585 m .23555 .68853 L .26738 .68816 L p .707 .577 .707 r
F P
0 g
s
.25999 .75466 m .25881 .77373 L .22705 .77215 L p .707 .577 .707 r
F P
0 g
s
.72646 .75572 m .72764 .73665 L .6965 .73394 L p .707 .577 .707 r
F P
0 g
s
.72764 .73665 m .72646 .75572 L .75823 .75729 L p .707 .577 .707 r
F P
0 g
s
.75823 .75729 m .7594 .73823 L .72764 .73665 L p .707 .577 .707 r
F P
0 g
s
.26738 .68816 m .26697 .72548 L .23513 .72585 L p .707 .577 .707 r
F P
0 g
s
.6965 .73394 m .69532 .753 L .72646 .75572 L p .707 .577 .707 r
F P
0 g
s
.7594 .73823 m .75823 .75729 L .78749 .75758 L p .707 .577 .707 r
F P
0 g
s
.78749 .75758 m .78867 .73852 L .7594 .73823 L p .707 .577 .707 r
F P
0 g
s
.69532 .753 m .6965 .73394 L .66901 .73036 L p .707 .577 .707 r
F P
0 g
s
.66901 .73036 m .66783 .74942 L .69532 .753 L p .707 .577 .707 r
F P
0 g
s
.8152 .61162 m .82411 .6562 L .83942 .6369 L p .707 .577 .707 r
F P
0 g
s
.83942 .6369 m .83051 .59232 L .8152 .61162 L p .707 .577 .707 r
F P
0 g
s
.67351 .63992 m .68241 .6845 L .71004 .69078 L p .707 .577 .707 r
F P
0 g
s
.78867 .73852 m .78749 .75758 L .8114 .75656 L p .707 .577 .707 r
F P
0 g
s
.8114 .75656 m .81258 .73749 L .78867 .73852 L p .707 .577 .707 r
F P
0 g
s
.83051 .59232 m .83942 .6369 L .84544 .6166 L p .707 .577 .707 r
F P
0 g
s
.84544 .6166 m .83653 .57202 L .83051 .59232 L p .707 .577 .707 r
F P
0 g
s
.65196 .62798 m .66087 .67256 L .68241 .6845 L p .707 .577 .707 r
F P
0 g
s
.65439 .66058 m .65398 .69789 L .67503 .70394 L p .707 .577 .707 r
F P
0 g
s
.81934 .66495 m .81892 .70227 L .83529 .69579 L p .707 .577 .707 r
F P
0 g
s
.83529 .69579 m .8357 .65848 L .81934 .66495 L p .707 .577 .707 r
F P
0 g
s
.81258 .73749 m .8114 .75656 L .82761 .75431 L p .707 .577 .707 r
F P
0 g
s
.82761 .75431 m .82879 .73525 L .81258 .73749 L p .707 .577 .707 r
F P
0 g
s
.83653 .57202 m .84544 .6166 L .84159 .5973 L p .637 .531 .717 r
F P
0 g
s
.84159 .5973 m .83268 .55272 L .83653 .57202 L p .637 .531 .717 r
F P
0 g
s
.63861 .61155 m .64752 .65613 L .66087 .67256 L p .707 .577 .707 r
F P
0 g
s
.64752 .65613 m .63861 .61155 L .63476 .59225 L p .635 .53 .717 r
F P
0 g
s
.8357 .65848 m .83529 .69579 L .84237 .68832 L p .707 .577 .707 r
F P
0 g
s
.84237 .68832 m .84278 .651 L .8357 .65848 L p .707 .577 .707 r
F P
0 g
s
.82879 .73525 m .82761 .75431 L .83453 .75107 L p .707 .577 .707 r
F P
0 g
s
.83453 .75107 m .83571 .73201 L .82879 .73525 L p .707 .577 .707 r
F P
0 g
s
.64138 .69065 m .6418 .65333 L .63889 .64559 L p .707 .577 .707 r
F P
0 g
s
.83268 .55272 m .84159 .5973 L .82824 .58087 L p .707 .577 .707 r
F P
0 g
s
.82824 .58087 m .81933 .53629 L .83268 .55272 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .63476 .59225 L .64078 .57195 L p .707 .577 .707 r
F P
0 g
s
.64366 .63683 m .64752 .65613 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63889 .64559 m .63848 .68291 L .64138 .69065 L p .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .63889 .64559 L .64428 .6399 L p .707 .577 .707 r
F P
0 g
s
.64428 .6399 m .64597 .63811 L p .64504 .6437 L .707 .577 .707 r
F P
0 g
s
.63848 .68291 m .64428 .6399 L .64504 .6437 L .707 .577 .707 r
F
.63476 .59225 m .63924 .61468 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.63924 .61468 m .64366 .63683 L p .63655 .6012 L .635 .53 .717 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84278 .651 m .84237 .68832 L .83947 .68058 L p .707 .577 .707 r
F P
0 g
s
.83947 .68058 m .83988 .64326 L .84278 .651 L p .707 .577 .707 r
F P
0 g
s
.83571 .73201 m .83453 .75107 L .83149 .74715 L p .707 .577 .707 r
F P
0 g
s
.83149 .74715 m .83267 .72809 L .83571 .73201 L p .707 .577 .707 r
F P
0 g
s
.81933 .53629 m .82824 .58087 L .80669 .56893 L p .707 .577 .707 r
F P
0 g
s
.80669 .56893 m .79778 .52435 L .81933 .53629 L p .707 .577 .707 r
F P
0 g
s
.64969 .61653 m .64078 .57195 L .65609 .55266 L p .707 .577 .707 r
F P
0 g
s
.64078 .57195 m .64969 .61653 L .64366 .63683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64597 .63811 m .64556 .67543 L .63848 .68291 L p .707 .577 .707 r
F P
0 g
s
.45228 .63299 m .45187 .67031 L .47591 .66546 L p .707 .577 .707 r
F P
0 g
s
.42047 .60313 m .42938 .64771 L .458 .63579 L p .707 .577 .707 r
F P
0 g
s
.38913 .6094 m .39803 .65397 L .42938 .64771 L p .707 .577 .707 r
F P
0 g
s
.83988 .64326 m .83947 .68058 L .82687 .67333 L p .707 .577 .707 r
F P
0 g
s
.82687 .67333 m .82729 .63601 L .83988 .64326 L p .707 .577 .707 r
F P
0 g
s
.79778 .52435 m .80669 .56893 L .77907 .56265 L p .707 .577 .707 r
F P
0 g
s
.77907 .56265 m .77016 .51807 L .79778 .52435 L p .707 .577 .707 r
F P
0 g
s
.65609 .55266 m .66499 .59723 L .64969 .61653 L p .707 .577 .707 r
F P
0 g
s
.66499 .59723 m .65609 .55266 L .67918 .53624 L p .707 .577 .707 r
F P
0 g
s
.4811 .61938 m .47219 .5748 L .4491 .59121 L p .707 .577 .707 r
F P
0 g
s
.35812 .60938 m .36703 .65396 L .39803 .65397 L p .707 .577 .707 r
F P
0 g
s
.83267 .72809 m .83149 .74715 L .81878 .74294 L p .707 .577 .707 r
F P
0 g
s
.81878 .74294 m .81996 .72387 L .83267 .72809 L p .707 .577 .707 r
F P
0 g
s
.38345 .7189 m .38463 .69984 L .35349 .69712 L p .707 .577 .707 r
F P
0 g
s
.35349 .69712 m .35231 .71619 L .38345 .7189 L p .707 .577 .707 r
F P
0 g
s
.64556 .67543 m .64597 .63811 L .66234 .63163 L p .707 .577 .707 r
F P
0 g
s
.77016 .51807 m .77907 .56265 L .74806 .56264 L p .707 .577 .707 r
F P
0 g
s
.74806 .56264 m .73915 .51806 L .77016 .51807 L p .707 .577 .707 r
F P
0 g
s
.68809 .58082 m .67918 .53624 L .70781 .52432 L p .707 .577 .707 r
F P
0 g
s
.67918 .53624 m .68809 .58082 L .66499 .59723 L p .707 .577 .707 r
F P
0 g
s
.63788 .73395 m .63906 .71488 L .65527 .71264 L p .707 .577 .707 r
F P
0 g
s
.35231 .71619 m .35349 .69712 L .326 .69354 L p .707 .577 .707 r
F P
0 g
s
.65527 .71264 m .65409 .7317 L .63788 .73395 L p .707 .577 .707 r
F P
0 g
s
.326 .69354 m .32482 .71261 L .35231 .71619 L p .707 .577 .707 r
F P
0 g
s
.47219 .5748 m .4811 .61938 L .49641 .60008 L p .707 .577 .707 r
F P
0 g
s
.49641 .60008 m .4875 .5555 L .47219 .5748 L p .707 .577 .707 r
F P
0 g
s
.3305 .6031 m .3394 .64768 L .36703 .65396 L p .707 .577 .707 r
F P
0 g
s
.66234 .63163 m .66192 .66895 L .64556 .67543 L p .707 .577 .707 r
F P
0 g
s
.73915 .51806 m .74806 .56264 L .71671 .5689 L p .707 .577 .707 r
F P
0 g
s
.71671 .5689 m .70781 .52432 L .73915 .51806 L p .707 .577 .707 r
F P
0 g
s
.70781 .52432 m .71671 .5689 L .68809 .58082 L p .707 .577 .707 r
F P
0 g
s
.82729 .63601 m .82687 .67333 L .80581 .66728 L p .707 .577 .707 r
F P
0 g
s
.80581 .66728 m .80623 .62997 L .82729 .63601 L p .707 .577 .707 r
F P
0 g
s
.32482 .71261 m .326 .69354 L .30487 .68945 L p .707 .577 .707 r
F P
0 g
s
.81996 .72387 m .81878 .74294 L .79765 .73884 L p .707 .577 .707 r
F P
0 g
s
.79765 .73884 m .79883 .71977 L .81996 .72387 L p .707 .577 .707 r
F P
0 g
s
.30487 .68945 m .30369 .70851 L .32482 .71261 L p .707 .577 .707 r
F P
0 g
s
.66192 .66895 m .66234 .63163 L .68639 .62678 L p .707 .577 .707 r
F P
0 g
s
.4875 .5555 m .49641 .60008 L .50243 .57979 L p .707 .577 .707 r
F P
0 g
s
.50243 .57979 m .49352 .53521 L .4875 .5555 L p .707 .577 .707 r
F P
0 g
s
.30895 .59116 m .31786 .63574 L .3394 .64768 L p .707 .577 .707 r
F P
0 g
s
.31138 .62376 m .31097 .66108 L .33202 .66712 L p .707 .577 .707 r
F P
0 g
s
.65409 .7317 m .65527 .71264 L .67917 .71161 L p .707 .577 .707 r
F P
0 g
s
.47633 .62814 m .47591 .66546 L .49228 .65898 L p .707 .577 .707 r
F P
0 g
s
.49228 .65898 m .49269 .62166 L .47633 .62814 L p .707 .577 .707 r
F P
0 g
s
.67917 .71161 m .678 .73068 L .65409 .7317 L p .707 .577 .707 r
F P
0 g
s
.68639 .62678 m .68597 .6641 L .66192 .66895 L p .707 .577 .707 r
F P
0 g
s
.80623 .62997 m .80581 .66728 L .77835 .66303 L p .707 .577 .707 r
F P
0 g
s
.77835 .66303 m .77877 .62571 L .80623 .62997 L p .707 .577 .707 r
F P
0 g
s
.31097 .66108 m .31138 .62376 L .29878 .61651 L p .707 .577 .707 r
F P
0 g
s
.30369 .70851 m .30487 .68945 L .29216 .68523 L p .707 .577 .707 r
F P
0 g
s
.79883 .71977 m .79765 .73884 L .77017 .73526 L p .707 .577 .707 r
F P
0 g
s
.77017 .73526 m .77135 .71619 L .79883 .71977 L p .707 .577 .707 r
F P
0 g
s
.29216 .68523 m .29099 .70429 L .30369 .70851 L p .707 .577 .707 r
F P
0 g
s
.68597 .6641 m .68639 .62678 L .71576 .62404 L p .707 .577 .707 r
F P
0 g
s
.49352 .53521 m .50243 .57979 L .49858 .56048 L p .634 .529 .717 r
F P
0 g
s
.49858 .56048 m .48967 .5159 L .49352 .53521 L p .634 .529 .717 r
F P
0 g
s
.2956 .57474 m .30451 .61932 L .31786 .63574 L p .707 .577 .707 r
F P
0 g
s
.30451 .61932 m .2956 .57474 L .29175 .55543 L p .632 .527 .718 r
F P
0 g
s
.29878 .61651 m .29837 .65383 L .31097 .66108 L p .707 .577 .707 r
F P
0 g
s
.678 .73068 m .67917 .71161 L .70844 .7119 L p .707 .577 .707 r
F P
0 g
s
.70844 .7119 m .70726 .73097 L .678 .73068 L p .707 .577 .707 r
F P
0 g
s
.77877 .62571 m .77835 .66303 L .74718 .66099 L p .707 .577 .707 r
F P
0 g
s
.74718 .66099 m .7476 .62367 L .77877 .62571 L p .707 .577 .707 r
F P
0 g
s
.71576 .62404 m .71535 .66136 L .68597 .6641 L p .707 .577 .707 r
F P
0 g
s
.49269 .62166 m .49228 .65898 L .49936 .6515 L p .707 .577 .707 r
F P
0 g
s
.49936 .6515 m .49977 .61418 L .49269 .62166 L p .707 .577 .707 r
F P
0 g
s
.71535 .66136 m .71576 .62404 L .7476 .62367 L p .707 .577 .707 r
F P
0 g
s
.77135 .71619 m .77017 .73526 L .73902 .73255 L p .707 .577 .707 r
F P
0 g
s
.73902 .73255 m .7402 .71348 L .77135 .71619 L p .707 .577 .707 r
F P
0 g
s
.7476 .62367 m .74718 .66099 L .71535 .66136 L p .707 .577 .707 r
F P
0 g
s
.48578 .69843 m .4846 .7175 L .49152 .71426 L p .707 .577 .707 r
F P
0 g
s
.49152 .71426 m .4927 .69519 L .48578 .69843 L p .707 .577 .707 r
F P
0 g
s
.70726 .73097 m .70844 .7119 L .7402 .71348 L p .707 .577 .707 r
F P
0 g
s
.7402 .71348 m .73902 .73255 L .70726 .73097 L p .707 .577 .707 r
F P
0 g
s
.29837 .65383 m .29878 .61651 L .29588 .60877 L p .707 .577 .707 r
F P
0 g
s
.29099 .70429 m .29216 .68523 L .28912 .68131 L p .707 .577 .707 r
F P
0 g
s
.28912 .68131 m .28795 .70037 L .29099 .70429 L p .707 .577 .707 r
F P
0 g
s
.48967 .5159 m .49858 .56048 L .48523 .54406 L p .707 .577 .707 r
F P
0 g
s
.48523 .54406 m .47632 .49948 L .48967 .5159 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .29175 .55543 L .29777 .53514 L p .707 .577 .707 r
F P
0 g
s
.30065 .60001 m .30451 .61932 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29588 .60877 m .29547 .64609 L .29837 .65383 L p .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .29588 .60877 L .30127 .60308 L p .707 .577 .707 r
F P
0 g
s
.30127 .60308 m .30296 .6013 L p .30203 .60688 L .707 .577 .707 r
F P
0 g
s
.29547 .64609 m .30127 .60308 L .30203 .60688 L .707 .577 .707 r
F
.29175 .55543 m .29623 .57786 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.29623 .57786 m .30065 .60001 L p .29353 .56438 L .632 .527 .718 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49977 .61418 m .49936 .6515 L .49646 .64376 L p .707 .577 .707 r
F P
0 g
s
.49646 .64376 m .49687 .60644 L .49977 .61418 L p .707 .577 .707 r
F P
0 g
s
.4927 .69519 m .49152 .71426 L .48848 .71034 L p .707 .577 .707 r
F P
0 g
s
.48848 .71034 m .48966 .69127 L .4927 .69519 L p .707 .577 .707 r
F P
0 g
s
.47632 .49948 m .48523 .54406 L .46368 .53212 L p .707 .577 .707 r
F P
0 g
s
.46368 .53212 m .45477 .48754 L .47632 .49948 L p .707 .577 .707 r
F P
0 g
s
.30668 .57972 m .29777 .53514 L .31308 .51584 L p .707 .577 .707 r
F P
0 g
s
.29777 .53514 m .30668 .57972 L .30065 .60001 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28795 .70037 m .28912 .68131 L .29605 .67807 L p .707 .577 .707 r
F P
0 g
s
.29605 .67807 m .29487 .69713 L .28795 .70037 L p .707 .577 .707 r
F P
0 g
s
.30296 .6013 m .30255 .63861 L .29547 .64609 L p .707 .577 .707 r
F P
0 g
s
.49687 .60644 m .49646 .64376 L .48386 .63651 L p .707 .577 .707 r
F P
0 g
s
.48386 .63651 m .48428 .5992 L .49687 .60644 L p .707 .577 .707 r
F P
0 g
s
.45477 .48754 m .46368 .53212 L .43606 .52584 L p .707 .577 .707 r
F P
0 g
s
.43606 .52584 m .42715 .48126 L .45477 .48754 L p .707 .577 .707 r
F P
0 g
s
.31308 .51584 m .32198 .56042 L .30668 .57972 L p .707 .577 .707 r
F P
0 g
s
.32198 .56042 m .31308 .51584 L .33617 .49943 L p .707 .577 .707 r
F P
0 g
s
.48966 .69127 m .48848 .71034 L .47577 .70612 L p .707 .577 .707 r
F P
0 g
s
.47577 .70612 m .47695 .68706 L .48966 .69127 L p .707 .577 .707 r
F P
0 g
s
.30255 .63861 m .30296 .6013 L .31933 .59482 L p .707 .577 .707 r
F P
0 g
s
.42715 .48126 m .43606 .52584 L .40505 .52582 L p .707 .577 .707 r
F P
0 g
s
.40505 .52582 m .39614 .48125 L .42715 .48126 L p .707 .577 .707 r
F P
0 g
s
.34508 .54401 m .33617 .49943 L .3648 .48751 L p .707 .577 .707 r
F P
0 g
s
.33617 .49943 m .34508 .54401 L .32198 .56042 L p .707 .577 .707 r
F P
0 g
s
.29487 .69713 m .29605 .67807 L .31225 .67583 L p .707 .577 .707 r
F P
0 g
s
.31225 .67583 m .31108 .69489 L .29487 .69713 L p .707 .577 .707 r
F P
0 g
s
.31933 .59482 m .31891 .63214 L .30255 .63861 L p .707 .577 .707 r
F P
0 g
s
.39614 .48125 m .40505 .52582 L .3737 .53209 L p .707 .577 .707 r
F P
0 g
s
.3737 .53209 m .3648 .48751 L .39614 .48125 L p .707 .577 .707 r
F P
0 g
s
.3648 .48751 m .3737 .53209 L .34508 .54401 L p .707 .577 .707 r
F P
0 g
s
.48428 .5992 m .48386 .63651 L .4628 .63047 L p .707 .577 .707 r
F P
0 g
s
.4628 .63047 m .46322 .59315 L .48428 .5992 L p .707 .577 .707 r
F P
0 g
s
.47695 .68706 m .47577 .70612 L .45464 .70202 L p .707 .577 .707 r
F P
0 g
s
.45464 .70202 m .45582 .68296 L .47695 .68706 L p .707 .577 .707 r
F P
0 g
s
.31891 .63214 m .31933 .59482 L .34337 .58997 L p .707 .577 .707 r
F P
0 g
s
.31108 .69489 m .31225 .67583 L .33616 .6748 L p .707 .577 .707 r
F P
0 g
s
.33616 .6748 m .33498 .69386 L .31108 .69489 L p .707 .577 .707 r
F P
0 g
s
.34337 .58997 m .34296 .62729 L .31891 .63214 L p .707 .577 .707 r
F P
0 g
s
.46322 .59315 m .4628 .63047 L .43534 .62622 L p .707 .577 .707 r
F P
0 g
s
.43534 .62622 m .43576 .5889 L .46322 .59315 L p .707 .577 .707 r
F P
0 g
s
.45582 .68296 m .45464 .70202 L .42716 .69844 L p .707 .577 .707 r
F P
0 g
s
.42716 .69844 m .42834 .67938 L .45582 .68296 L p .707 .577 .707 r
F P
0 g
s
.34296 .62729 m .34337 .58997 L .37275 .58723 L p .707 .577 .707 r
F P
0 g
s
.33498 .69386 m .33616 .6748 L .36543 .67509 L p .707 .577 .707 r
F P
0 g
s
.36543 .67509 m .36425 .69415 L .33498 .69386 L p .707 .577 .707 r
F P
0 g
s
.43576 .5889 m .43534 .62622 L .40417 .62418 L p .707 .577 .707 r
F P
0 g
s
.40417 .62418 m .40459 .58686 L .43576 .5889 L p .707 .577 .707 r
F P
0 g
s
.37275 .58723 m .37234 .62454 L .34296 .62729 L p .707 .577 .707 r
F P
0 g
s
.37234 .62454 m .37275 .58723 L .40459 .58686 L p .707 .577 .707 r
F P
0 g
s
.42834 .67938 m .42716 .69844 L .39601 .69573 L p .707 .577 .707 r
F P
0 g
s
.39601 .69573 m .39719 .67667 L .42834 .67938 L p .707 .577 .707 r
F P
0 g
s
.40459 .58686 m .40417 .62418 L .37234 .62454 L p .707 .577 .707 r
F P
0 g
s
.36425 .69415 m .36543 .67509 L .39719 .67667 L p .707 .577 .707 r
F P
0 g
s
.39719 .67667 m .39601 .69573 L .36425 .69415 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolM001oOol007eoo`@0
0003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00H007Uoo`00NGoo10001EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1000MGoo001eOol40009FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001bOol0079oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006moo`00KWoo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P00KGoo001/Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH2001/Ool006Yoo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00001ZOol006Uoo`04001JEUYF
0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF0000JGoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVQoo`00IGoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYFJ7oo001TOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo06Eoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03OomJEP0000]JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEVMoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEVMoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Eoo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00
Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00Hgoo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJ
EUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000EJEPd000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00D005YFFUH005YF00@0
009JEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00<005YF00000P001UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol30009FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006=oo`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF008000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Eoo`00HGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00Ggoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Eoo`00GGoo0`0025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8006Eoo`00G7oo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol005Yoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IGoo001IOol00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001HOol20006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol05Woo3000@Goo001GOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJ
EP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool04Woo10000UYF00<005YFFUH01EYF00<005YF00000`00?Goo001FOol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000moo`@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<003Yoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00@000QJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Goo0P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF0`00>7oo001EOol00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30004FUH01@00FUIJEUYF
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002Woo
0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00=Woo001D
Ool00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH20003FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0027oo0P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00@005YFFUIJEP8003Aoo`00E7oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF00000P00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0`0000EJEP00FUIJEP0000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<000QJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8003=oo`00Dgoo0P00
1EYF00<005YFFUH01EYF0P000Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`04001JEUYF0008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000bOol005=oo`03001JEP0000AJEP03001JEUYF00=J
EP8000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
Ool01@00FUIJEUYF000025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00<Woo001BOol01000FUIJEP001EYF00D005YFFUIJEP0000Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000a
Ool0059oo`04001JEUYF0005FUH01000FUIJEP001goo00@005YFFUH000EJEP03001JEUYF00QJEP03
001JEUYF00QJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP800003Ool005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF000`Ool0059oo`04
001JEUYF0005FUH30008Ool01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00@005YF
FUIJEP800003FUH0000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP@000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF000`Ool0059oo`80009JEP03001JEUYF009JEP03001oogoo00Qo
o`04001JEUYF0005FUH30008FUH00`00FUIJEP08FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF0000<7oo001COol01000FUIJEP000eYF00<007ooOol02Goo00@005YFFUH000AJEPD0
00MJEP03001JEUYF00QJEP04001JEUYF0002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHA0004FUH00`00FUIJEP02FUH01000FUIJEP00;goo0017Ool=0002FUH01000FUIJ
EP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001JEP0000=JEP03001JEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH5000AOol50004FUH01000FUIJEP00;goo0013Ool40002FUH00`00FUIJ
EP06FUH20002FUH01000FUIJEP0037oo00@005YFFUH000AJEPD000MJEP03001JEUYF00QJEP03001J
EP0000=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00eYF0P006goo0P000UYF00@005YFFUH002mo
o`00@7oo0`001UYF00<005YFFUH01UYF0`000UYF10002goo00@005YFFUH000EJEP<000QJEP03001J
EUYF00QJEP8000AJEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00@005YFFUIJEP8001moo`06001JEUYF001JEP00
;goo000nOol30009FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP030009Ool01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH01eYF0`001EYF00<005YF000015YF00<005YFFUH025YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF00@005YF0000
029oo`<0009JEP03001oogoo02aoo`00?7oo0P000UYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
0UYF00@005YFFUH0009JEP03001oogoo00Ioo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP001EYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH015YF0P009Woo00@005YFFUH002ioo`00>Woo0P00
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF00@005YFFUIJEP8000Ioo`04
001JEUYF0005FUH80003FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF00<005YF000015YF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP02
FUH2000YOol00`00FUH0000^Ool003Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF009JEPl000AJEP04001JEUYFFUH800000eYF00000005FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH0
0`00FUIJEP02FUH01@00FUIJEUYF0000:goo0`00;Woo000fOol30008FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEUYF1P000UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00eYF0`00;7oo00@005YF000002eo
o`00=Goo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP00FUH50005FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020005
FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00Oomoo`0AOol3000GOol20002FUH00`00Oomoo`0[Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH40006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJ
EP02FUH00`00Oomoo`0AOol5000EOol00`00FUH00002FUH00`00Oomoo`0[Ool0039oo`03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009JEP05001JEUYFFUH0000D
Ool5000DOol01000FUIJEP000UYF00<007ooOol0:goo000aOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000EOol5000COol0
0`00FUIJEP02FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUH0000FOol3000COol00`00
FUIJEP03FUH01000FUIJEP00;7oo000_Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
15YF3@000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEP00009JEP@002Yoo`8000EJEP04001JEUYF000/Ool002moo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP04000:Ool00`00Ool00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
00000UYF0P0000AJEP00000002Moo`03001JEP0000EJEP04001JEUYF000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP@000ioo`<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH20000
15YF001JEUYF0P008goo0P000eYF00<005YFFUH00UYF00@005YFFUH002aoo`00;Goo00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00eYF0P004Woo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00FUH30002FUH01000FUIJEUYF0P00
1Woo5`000goo00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000;Goo000]Ool00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUH00002000DOol00`00FUH00003FUH01000FUIJEUYF2@0025YF0`00
1EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF00@005YFFUIJEPP000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEP8002eoo`00;7oo0P001EYF00<0
05YFFUH01EYF0P005goo00<005YF00000eYF100000=JEP00FUH01EYF00<005YFFUH01EYF1@001UYF
00<005YFFUH00eYF1P0015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYFFUH005YF1`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF1P001EYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH2
000IOol01000FUH005YF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@001UYF00<005YFFUH0
1UYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001oogoo02aoo`00
:goo00@005YFFUH000EJEP05001JEUYFFUH0000KOol00`00FUH000020002FUH20002FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP04FUH20005FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000^Ool002]oo`04001JEUYF0005FUH01000FUIJEP0077oo0P000UYF00<005YFFUH00UYF00@0
05YFFUH000IJEP03001JEUYF00EJEP<000QJEP04001JEUYFFUH30006FUH00`00FUIJEP0200000eYF
001JEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool01000FUIJEP001EYF0`007Goo00D005YFFUIJEP00
00EJEP<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002]oo`05001JEUYFFUH00004FUH00`00Oomo
o`0MOol01@00FUIJEUYF00001EYF00<005YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00UYF
1P0015YF00<005YFFUH015YF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/
Ool01000FUIJEP000eYF00<007ooOol04Woo0`002Goo00D005YFFUIJEP0000EJEP03001JEUYF00=J
EQ80009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo019oo`D000Uoo`04001JEUYF0005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00@005YFFUH0009JEP03001oogoo
019oo`D000Yoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000/Ool01000FUIJEUYF
0P005Goo1@0037oo0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP02FUHA0007FUH80004FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`04001JEUYF000GOol3000@Ool70004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEP00008000MJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00AJEPH000AJEP03001JEUYF008002eoo`00;Goo00@005YFFUH002]oo`04001JEUYF
0002FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF0`000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`0000IJEP00000005YF0002FUH2000]Ool0
02eoo`03001JEP0002]oob<000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEP00FUH005YF0`001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF
00<005YFFUH015YF0P0015YF00@005YF0000009JEP8002eoo`00;Goo00<005YF000097oo20000eYF
00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP800003FUH005YF008000=JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF009JEP<000EJEP04001JEUYFFUH4000]
Ool002ioo`03FUH00000025oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPP000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00IJEP04001JEP000002FUH00`00FUIJEP02FUH200000eYF001JEP05FUH20007FUH30007FUH0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEP000080
01moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH70003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000UYF00<005YFFUH00eYF10001UYF00<005YFFUH01UYF00<005YFFUH0
15YF10001EYF00<005YFFUH00eYF00<005YFFUH00UYF0`00;Goo000^Ool00`00FUH00002FUH2000:
OolA0002Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUH000000UYF00<005YFFUH00eYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03
001JEUYF00D000QJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00@005YF
FUH000=JEPX000=JEP03001JEUYF00MJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH000020008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00eYF00<005YFFUH01EYF3P0015YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Woo000^Ool01@00FUIJEP00FUH010000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF00<005YF00000UYF7`0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool2000015YF000000001UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00UYF00<005YF00000`001EYF00@005YFFUIJEPT00003FUH005YF00EJ
EP04001JEUYFFUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP/000MJEP03001JEP0000H000=JEP06001JEUYF
001JEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800006
Ool00000001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00<goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0;
FUH00`00FUIJEP06FUH500000eYF00000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0017oo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000`00=Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000Woo0P000eYF00<005YF00007`00>Woo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70004FUH0
0`00FUIJEP06FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH30008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF7`00AWoo000]Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF
2@0015YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YF000025YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2000?Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
00=JEP000000200025YF00<005YFFUH02EYF10002EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPL003Moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
00=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03
001JEUYF00QJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@003=oo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00MJEPT000aJEPT000QJEP03001JEUYF00IJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0035oo`00;Goo00<005YF00000eYF00@005YFFUIJEPP00003FUH005YF
00EJEPD000MJEP03001JEUYF00@0009JEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P00
0UYF00<005YFFUH01UYF0P000eYF00@005YFFUIJEQ4000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYF000`Ool002eoo`03001JEP0000=JEPL000IJEP03001JEUYF00AJ
EPD000MJEP03001JEP0000T000=JEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH40002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH9
00000eYF001JEP02FUH80004Ool80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000]Ool01000FUH005YF0P0015YF00<005YF00000`0015YF00<005YFFUH015YF0`0015YF
1`000eYF00<005YFFUH00eYF10000eYF00<007ooFUH00UYF00<005YFFUH00eYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF0`0015YF
00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF500015YF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00;Goo00<005YF00000P001EYF00<005YFFUH00eYF4P000UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool00eYF00<005YFFUH00eYF
00<005YF00000`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF0`0000=JEP00FUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPT000=JEP04001JEUYFFUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH300001GooFUIJEUYF00001EYF0P000eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00P0015YF00D005YFFUIJEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002mo
o`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYFFUH005YF001oo`=JEP03001JEUYF00=JEP03001J
EUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF009JEP04001JEUYFFUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF1000;goo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00P005YFFUIJEP00FUH007oo0eYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
0004FUH00000FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000_Ool002eoob4000=JEP03001JEUYF00EJEP03001JEUYF
00AJEP08001JEUYFFUH005YF001oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP0B0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000`Ool002]oo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001J
EUYF00AJEP04001JEUYFFUH20002Ool3FUH40007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH00P002Woo5P00=7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00D005YFFUIJ
EP0000=oo`=JEP04001JEUYF0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH00P00E7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP070004Ool2FUH01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF008005Aoo`00:Woo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P000goo00=JEP00FUH00eYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00001P0015YF00<005YFFUH00P00E7oo000ZOol00`00FUH00002FUHF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo00=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0000AJEP00FUIJ
EP8005Aoo`00:Woo00<005YF00000`001EYF00@005YFFUIJEPT0009ooa8000AJEP03001JEUYF00=J
EP04001JEUYFFUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020005
FUH01000FUH000000UYF0P00E7oo000ZOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHK0003FUH01P00FUIJEP00FUH0009oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP05001JEP00FUH00005FUH01000FUIJEUYF1000E7oo000[Ool20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH20003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH3001DOol002eoo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000Aoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00<Woo1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0
00Aoo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJ
EP02FUH00`00FUH0001DOol003Uoo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP07001JEUYFFUH005YF00001Goo00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001EOol0049oo`T000AJEP03001JEUYF00EJEP04001JEUYFFUH9
0007Ool200000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEP000eYF1P000eYF00@005YFFUIJEP8005Ioo`00Bgoo
40004Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF10001eYF00<005YF00000`0000=JEP000000F7oo001^Ool20007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH200000eYF
001JEP07FUH00`00FUIJEP02FUH3001IOol0071oo`8000EJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP00001GOol0079oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000D000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008005Ioo`00M7oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF2@0000=oo`0000001P0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00MWoo
1`001EYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEPH0009JEP03001JEP0001@000=J
EP04001JEUYFFUH2001FOol007eoo`/000IJEP03001JEUYF00AJEPX000QJEP03001JEP0000@0009J
EP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8005Ioo`00R7oo3@0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@0
05Ioo`00Tgoo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF0000EWoo002JOol90004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP04001GOol00:=ooal005]oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60019 .76901 m .59458 .71913 L .56347 .71845 L p .707 .577 .707 r
F P
0 g
s
.59458 .71913 m .60019 .76901 L .63184 .7647 L p .707 .577 .707 r
F P
0 g
s
.63184 .7647 m .62622 .71482 L .59458 .71913 L p .707 .577 .707 r
F P
0 g
s
.62622 .71482 m .63184 .7647 L .66092 .75581 L p .707 .577 .707 r
F P
0 g
s
.66092 .75581 m .65531 .70593 L .62622 .71482 L p .707 .577 .707 r
F P
0 g
s
.56908 .76833 m .56347 .71845 L .53595 .71284 L p .707 .577 .707 r
F P
0 g
s
.56347 .71845 m .56908 .76833 L .60019 .76901 L p .707 .577 .707 r
F P
0 g
s
.65531 .70593 m .66092 .75581 L .68461 .74323 L p .707 .577 .707 r
F P
0 g
s
.68461 .74323 m .679 .69335 L .65531 .70593 L p .707 .577 .707 r
F P
0 g
s
.59633 .8109 m .59659 .77368 L .56541 .77169 L p .707 .577 .707 r
F P
0 g
s
.59659 .77368 m .59633 .8109 L .62816 .81037 L p .707 .577 .707 r
F P
0 g
s
.62816 .81037 m .62842 .77315 L .59659 .77368 L p .707 .577 .707 r
F P
0 g
s
.54156 .76272 m .53595 .71284 L .5147 .70285 L p .707 .577 .707 r
F P
0 g
s
.53595 .71284 m .54156 .76272 L .56908 .76833 L p .707 .577 .707 r
F P
0 g
s
.59177 .84066 m .5925 .82174 L .56133 .81934 L p .707 .577 .707 r
F P
0 g
s
.5925 .82174 m .59177 .84066 L .62357 .84133 L p .707 .577 .707 r
F P
0 g
s
.62357 .84133 m .6243 .82241 L .5925 .82174 L p .707 .577 .707 r
F P
0 g
s
.62842 .77315 m .62816 .81037 L .65754 .80739 L p .707 .577 .707 r
F P
0 g
s
.65754 .80739 m .6578 .77017 L .62842 .77315 L p .707 .577 .707 r
F P
0 g
s
.6243 .82241 m .62357 .84133 L .65291 .84021 L p .707 .577 .707 r
F P
0 g
s
.65291 .84021 m .65364 .82129 L .6243 .82241 L p .707 .577 .707 r
F P
0 g
s
.56133 .81934 m .5606 .83826 L .59177 .84066 L p .707 .577 .707 r
F P
0 g
s
.56516 .80891 m .56541 .77169 L .53796 .76738 L p .707 .577 .707 r
F P
0 g
s
.56541 .77169 m .56516 .80891 L .59633 .8109 L p .707 .577 .707 r
F P
0 g
s
.679 .69335 m .68461 .74323 L .70057 .72817 L p .707 .577 .707 r
F P
0 g
s
.70057 .72817 m .69496 .67829 L .679 .69335 L p .707 .577 .707 r
F P
0 g
s
.5606 .83826 m .56133 .81934 L .53387 .81545 L p .707 .577 .707 r
F P
0 g
s
.53387 .81545 m .53314 .83437 L .5606 .83826 L p .707 .577 .707 r
F P
0 g
s
.6578 .77017 m .65754 .80739 L .6816 .80223 L p .707 .577 .707 r
F P
0 g
s
.6816 .80223 m .68185 .76501 L .6578 .77017 L p .707 .577 .707 r
F P
0 g
s
.53796 .76738 m .5377 .80461 L .56516 .80891 L p .707 .577 .707 r
F P
0 g
s
.65364 .82129 m .65291 .84021 L .67691 .8374 L p .707 .577 .707 r
F P
0 g
s
.67691 .8374 m .67764 .81848 L .65364 .82129 L p .707 .577 .707 r
F P
0 g
s
.5377 .80461 m .53796 .76738 L .5169 .76118 L p .707 .577 .707 r
F P
0 g
s
.52031 .75273 m .5147 .70285 L .50182 .68946 L p .707 .577 .707 r
F P
0 g
s
.5147 .70285 m .52031 .75273 L .54156 .76272 L p .707 .577 .707 r
F P
0 g
s
.53314 .83437 m .53387 .81545 L .51278 .81044 L p .707 .577 .707 r
F P
0 g
s
.51278 .81044 m .51205 .82936 L .53314 .83437 L p .707 .577 .707 r
F P
0 g
s
.69496 .67829 m .70057 .72817 L .70724 .71212 L p .707 .577 .707 r
F P
0 g
s
.70724 .71212 m .70163 .66224 L .69496 .67829 L p .707 .577 .707 r
F P
0 g
s
.5169 .76118 m .51664 .7984 L .5377 .80461 L p .707 .577 .707 r
F P
0 g
s
.68185 .76501 m .6816 .80223 L .69796 .79541 L p .707 .577 .707 r
F P
0 g
s
.69796 .79541 m .69822 .75819 L .68185 .76501 L p .707 .577 .707 r
F P
0 g
s
.67764 .81848 m .67691 .8374 L .69322 .83318 L p .707 .577 .707 r
F P
0 g
s
.69322 .83318 m .69395 .81426 L .67764 .81848 L p .707 .577 .707 r
F P
0 g
s
.51664 .7984 m .5169 .76118 L .50431 .75369 L p .707 .577 .707 r
F P
0 g
s
.51205 .82936 m .51278 .81044 L .50015 .80482 L p .707 .577 .707 r
F P
0 g
s
.50743 .73934 m .50182 .68946 L .49855 .67398 L p .707 .577 .707 r
F P
0 g
s
.50182 .68946 m .50743 .73934 L .52031 .75273 L p .707 .577 .707 r
F P
0 g
s
.50015 .80482 m .49942 .82374 L .51205 .82936 L p .707 .577 .707 r
F P
0 g
s
.50431 .75369 m .50405 .79091 L .51664 .7984 L p .707 .577 .707 r
F P
0 g
s
.70163 .66224 m .70724 .71212 L .70398 .69664 L p .707 .577 .707 r
F P
0 g
s
.70398 .69664 m .69837 .64676 L .70163 .66224 L p .707 .577 .707 r
F P
0 g
s
.69822 .75819 m .69796 .79541 L .70504 .7876 L p .707 .577 .707 r
F P
0 g
s
.70504 .7876 m .7053 .75038 L .69822 .75819 L p .707 .577 .707 r
F P
0 g
s
.69395 .81426 m .69322 .83318 L .70024 .82797 L p .707 .577 .707 r
F P
0 g
s
.70024 .82797 m .70097 .80905 L .69395 .81426 L p .707 .577 .707 r
F P
0 g
s
.49942 .82374 m .50015 .80482 L .49719 .79911 L p .707 .577 .707 r
F P
0 g
s
.49719 .79911 m .49646 .81803 L .49942 .82374 L p .707 .577 .707 r
F P
0 g
s
.49646 .81803 m .49719 .79911 L .50422 .7939 L p .707 .577 .707 r
F P
0 g
s
.50422 .7939 m .50349 .81282 L .49646 .81803 L p .707 .577 .707 r
F P
0 g
s
.49788 .82403 m .48674 .33045 L .44274 .32816 L p .707 .577 .707 r
F P
0 g
s
.50405 .79091 m .50431 .75369 L .50141 .74564 L p .707 .577 .707 r
F P
0 g
s
.50416 .72386 m .50743 .73934 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.49855 .67398 m .50171 .70204 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50171 .70204 m .50416 .72386 L p .49955 .68135 L .707 .577 .707 r
F P
0 g
s
.50141 .74564 m .50115 .78286 L .50405 .79091 L p .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50141 .74564 L .50575 .74085 L p .707 .577 .707 r
F P
0 g
s
.50575 .74085 m .50849 .73783 L p .50663 .74925 L .707 .577 .707 r
F P
0 g
s
.50115 .78286 m .50575 .74085 L .50663 .74925 L .707 .577 .707 r
F
.50416 .72386 m .49855 .67398 L .50523 .65793 L p F P
0 g
s
.51084 .70781 m .50523 .65793 L .52119 .64287 L p .707 .577 .707 r
F P
0 g
s
.50523 .65793 m .51084 .70781 L .50416 .72386 L p .707 .577 .707 r
F P
0 g
s
.50849 .73783 m .50823 .77505 L .50115 .78286 L p .707 .577 .707 r
F P
0 g
s
.52119 .64287 m .5268 .69275 L .51084 .70781 L p .707 .577 .707 r
F P
0 g
s
.5268 .69275 m .52119 .64287 L .54487 .63028 L p .707 .577 .707 r
F P
0 g
s
.50823 .77505 m .50849 .73783 L .52486 .73101 L p .707 .577 .707 r
F P
0 g
s
.50349 .81282 m .50422 .7939 L .52052 .78968 L p .707 .577 .707 r
F P
0 g
s
.52052 .78968 m .51979 .8086 L .50349 .81282 L p .707 .577 .707 r
F P
0 g
s
.52486 .73101 m .5246 .76823 L .50823 .77505 L p .707 .577 .707 r
F P
0 g
s
.54487 .63028 m .55048 .68016 L .5268 .69275 L p .707 .577 .707 r
F P
0 g
s
.5246 .76823 m .52486 .73101 L .54891 .72585 L p .707 .577 .707 r
F P
0 g
s
.51979 .8086 m .52052 .78968 L .54452 .78688 L p .707 .577 .707 r
F P
0 g
s
.54452 .78688 m .54379 .8058 L .51979 .8086 L p .707 .577 .707 r
F P
0 g
s
.54891 .72585 m .54865 .76308 L .5246 .76823 L p .707 .577 .707 r
F P
0 g
s
.48674 .33045 m .49788 .82403 L .54281 .82181 L p .707 .577 .707 r
F P
0 g
s
.54281 .82181 m .53167 .32823 L .48674 .33045 L p .707 .577 .707 r
F P
0 g
s
.55048 .68016 m .54487 .63028 L .57396 .6214 L p .707 .577 .707 r
F P
0 g
s
.57396 .6214 m .57957 .67128 L .55048 .68016 L p .707 .577 .707 r
F P
0 g
s
.54865 .76308 m .54891 .72585 L .57829 .72287 L p .707 .577 .707 r
F P
0 g
s
.54379 .8058 m .54452 .78688 L .57386 .78575 L p .707 .577 .707 r
F P
0 g
s
.57386 .78575 m .57313 .80467 L .54379 .8058 L p .707 .577 .707 r
F P
0 g
s
.57829 .72287 m .57803 .76009 L .54865 .76308 L p .707 .577 .707 r
F P
0 g
s
.57803 .76009 m .57829 .72287 L .61012 .72234 L p .707 .577 .707 r
F P
0 g
s
.61012 .72234 m .60987 .75956 L .57803 .76009 L p .707 .577 .707 r
F P
0 g
s
.57313 .80467 m .57386 .78575 L .60567 .78642 L p .707 .577 .707 r
F P
0 g
s
.60567 .78642 m .60494 .80534 L .57313 .80467 L p .707 .577 .707 r
F P
0 g
s
.53167 .32823 m .54281 .82181 L .58427 .81528 L p .707 .577 .707 r
F P
0 g
s
.57957 .67128 m .57396 .6214 L .60561 .61709 L p .707 .577 .707 r
F P
0 g
s
.60561 .61709 m .61122 .66697 L .57957 .67128 L p .707 .577 .707 r
F P
0 g
s
.58427 .81528 m .57314 .3217 L .53167 .32823 L p .707 .577 .707 r
F P
0 g
s
.45388 .82174 m .44274 .32816 L .40397 .32157 L p .707 .577 .707 r
F P
0 g
s
.44274 .32816 m .45388 .82174 L .49788 .82403 L p .707 .577 .707 r
F P
0 g
s
.69837 .64676 m .70398 .69664 L .69109 .68325 L p .707 .577 .707 r
F P
0 g
s
.69109 .68325 m .68548 .63337 L .69837 .64676 L p .707 .577 .707 r
F P
0 g
s
.64129 .72433 m .64104 .76155 L .60987 .75956 L p .707 .577 .707 r
F P
0 g
s
.60987 .75956 m .61012 .72234 L .64129 .72433 L p .707 .577 .707 r
F P
0 g
s
.63683 .78882 m .6361 .80774 L .60494 .80534 L p .707 .577 .707 r
F P
0 g
s
.60494 .80534 m .60567 .78642 L .63683 .78882 L p .707 .577 .707 r
F P
0 g
s
.57314 .3217 m .58427 .81528 L .61821 .80509 L p .707 .577 .707 r
F P
0 g
s
.63671 .61777 m .64233 .66765 L .61122 .66697 L p .707 .577 .707 r
F P
0 g
s
.61122 .66697 m .60561 .61709 L .63671 .61777 L p .707 .577 .707 r
F P
0 g
s
.61821 .80509 m .60707 .31151 L .57314 .3217 L p .707 .577 .707 r
F P
0 g
s
.7053 .75038 m .70504 .7876 L .70215 .77955 L p .707 .577 .707 r
F P
0 g
s
.70215 .77955 m .7024 .74233 L .7053 .75038 L p .707 .577 .707 r
F P
0 g
s
.70097 .80905 m .70024 .82797 L .69729 .82227 L p .707 .577 .707 r
F P
0 g
s
.69729 .82227 m .69802 .80335 L .70097 .80905 L p .707 .577 .707 r
F P
0 g
s
.41511 .81515 m .40397 .32157 L .37423 .31133 L p .707 .577 .707 r
F P
0 g
s
.40397 .32157 m .41511 .81515 L .45388 .82174 L p .707 .577 .707 r
F P
0 g
s
.25718 .73219 m .25157 .68231 L .22046 .68163 L p .707 .577 .707 r
F P
0 g
s
.25157 .68231 m .25718 .73219 L .28883 .72788 L p .707 .577 .707 r
F P
0 g
s
.28883 .72788 m .28322 .678 L .25157 .68231 L p .707 .577 .707 r
F P
0 g
s
.68548 .63337 m .69109 .68325 L .66985 .67326 L p .707 .577 .707 r
F P
0 g
s
.66985 .67326 m .66424 .62338 L .68548 .63337 L p .707 .577 .707 r
F P
0 g
s
.28322 .678 m .28883 .72788 L .31792 .719 L p .707 .577 .707 r
F P
0 g
s
.31792 .719 m .3123 .66912 L .28322 .678 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22607 .73151 m .22046 .68163 L .19294 .67602 L p .707 .577 .707 r
F P
0 g
s
.22046 .68163 m .22607 .73151 L .25718 .73219 L p .707 .577 .707 r
F P
0 g
s
.6361 .80774 m .63683 .78882 L .6643 .79272 L p .707 .577 .707 r
F P
0 g
s
.60707 .31151 m .61821 .80509 L .64129 .79224 L p .707 .577 .707 r
F P
0 g
s
.64233 .66765 m .63671 .61777 L .66424 .62338 L p .707 .577 .707 r
F P
0 g
s
.64129 .79224 m .63015 .29865 L .60707 .31151 L p .707 .577 .707 r
F P
0 g
s
.3123 .66912 m .31792 .719 L .3416 .70641 L p .707 .577 .707 r
F P
0 g
s
.3416 .70641 m .33599 .65653 L .3123 .66912 L p .707 .577 .707 r
F P
0 g
s
.7024 .74233 m .70215 .77955 L .68955 .77206 L p .707 .577 .707 r
F P
0 g
s
.68955 .77206 m .68981 .73484 L .7024 .74233 L p .707 .577 .707 r
F P
0 g
s
.69802 .80335 m .69729 .82227 L .68465 .81664 L p .707 .577 .707 r
F P
0 g
s
.68465 .81664 m .68538 .79772 L .69802 .80335 L p .707 .577 .707 r
F P
0 g
s
.25332 .77408 m .25358 .73686 L .22241 .73487 L p .707 .577 .707 r
F P
0 g
s
.25358 .73686 m .25332 .77408 L .28515 .77356 L p .707 .577 .707 r
F P
0 g
s
.28515 .77356 m .28541 .73634 L .25358 .73686 L p .707 .577 .707 r
F P
0 g
s
.66424 .62338 m .66985 .67326 L .64233 .66765 L p .707 .577 .707 r
F P
0 g
s
.19855 .7259 m .19294 .67602 L .17169 .66603 L p .707 .577 .707 r
F P
0 g
s
.19294 .67602 m .19855 .7259 L .22607 .73151 L p .707 .577 .707 r
F P
0 g
s
.24876 .80385 m .24949 .78493 L .21832 .78253 L p .707 .577 .707 r
F P
0 g
s
.24949 .78493 m .24876 .80385 L .28056 .80452 L p .707 .577 .707 r
F P
0 g
s
.28056 .80452 m .28129 .7856 L .24949 .78493 L p .707 .577 .707 r
F P
0 g
s
.28541 .73634 m .28515 .77356 L .31454 .77057 L p .707 .577 .707 r
F P
0 g
s
.31454 .77057 m .31479 .73335 L .28541 .73634 L p .707 .577 .707 r
F P
0 g
s
.38537 .80491 m .37423 .31133 L .35644 .29844 L p .707 .577 .707 r
F P
0 g
s
.37423 .31133 m .38537 .80491 L .41511 .81515 L p .707 .577 .707 r
F P
0 g
s
.28129 .7856 m .28056 .80452 L .3099 .80339 L p .707 .577 .707 r
F P
0 g
s
.3099 .80339 m .31063 .78447 L .28129 .7856 L p .707 .577 .707 r
F P
0 g
s
.21832 .78253 m .21759 .80145 L .24876 .80385 L p .707 .577 .707 r
F P
0 g
s
.22215 .7721 m .22241 .73487 L .19495 .73057 L p .707 .577 .707 r
F P
0 g
s
.22241 .73487 m .22215 .7721 L .25332 .77408 L p .707 .577 .707 r
F P
0 g
s
.33599 .65653 m .3416 .70641 L .35756 .69135 L p .707 .577 .707 r
F P
0 g
s
.35756 .69135 m .35195 .64147 L .33599 .65653 L p .707 .577 .707 r
F P
0 g
s
.21759 .80145 m .21832 .78253 L .19086 .77863 L p .707 .577 .707 r
F P
0 g
s
.19086 .77863 m .19013 .79755 L .21759 .80145 L p .707 .577 .707 r
F P
0 g
s
.31479 .73335 m .31454 .77057 L .33859 .76542 L p .707 .577 .707 r
F P
0 g
s
.33859 .76542 m .33884 .7282 L .31479 .73335 L p .707 .577 .707 r
F P
0 g
s
.19495 .73057 m .19469 .76779 L .22215 .7721 L p .707 .577 .707 r
F P
0 g
s
.31063 .78447 m .3099 .80339 L .3339 .80059 L p .707 .577 .707 r
F P
0 g
s
.3339 .80059 m .33463 .78167 L .31063 .78447 L p .707 .577 .707 r
F P
0 g
s
.68981 .73484 m .68955 .77206 L .6685 .76586 L p .707 .577 .707 r
F P
0 g
s
.6685 .76586 m .66875 .72864 L .68981 .73484 L p .707 .577 .707 r
F P
0 g
s
.19469 .76779 m .19495 .73057 L .17389 .72437 L p .707 .577 .707 r
F P
0 g
s
.1773 .71591 m .17169 .66603 L .15881 .65264 L p .707 .577 .707 r
F P
0 g
s
.17169 .66603 m .1773 .71591 L .19855 .7259 L p .707 .577 .707 r
F P
0 g
s
.66875 .72864 m .6685 .76586 L .64104 .76155 L p .707 .577 .707 r
F P
0 g
s
.64104 .76155 m .64129 .72433 L .66875 .72864 L p .707 .577 .707 r
F P
0 g
s
.63015 .29865 m .64129 .79224 L .65126 .77798 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64012 .28439 L .63015 .29865 L p .707 .577 .707 r
F P
0 g
s
.68538 .79772 m .68465 .81664 L .66357 .81164 L p .707 .577 .707 r
F P
0 g
s
.66357 .81164 m .6643 .79272 L .68538 .79772 L p .707 .577 .707 r
F P
0 g
s
.19013 .79755 m .19086 .77863 L .16977 .77363 L p .707 .577 .707 r
F P
0 g
s
.16977 .77363 m .16904 .79255 L .19013 .79755 L p .707 .577 .707 r
F P
0 g
s
.35195 .64147 m .35756 .69135 L .36423 .6753 L p .707 .577 .707 r
F P
0 g
s
.36423 .6753 m .35862 .62542 L .35195 .64147 L p .707 .577 .707 r
F P
0 g
s
.17389 .72437 m .17363 .76159 L .19469 .76779 L p .707 .577 .707 r
F P
0 g
s
.33884 .7282 m .33859 .76542 L .35495 .7586 L p .707 .577 .707 r
F P
0 g
s
.35495 .7586 m .35521 .72138 L .33884 .7282 L p .707 .577 .707 r
F P
0 g
s
.33463 .78167 m .3339 .80059 L .35021 .79637 L p .707 .577 .707 r
F P
0 g
s
.35021 .79637 m .35094 .77745 L .33463 .78167 L p .707 .577 .707 r
F P
0 g
s
.35862 .62542 m .36423 .6753 L .36097 .65982 L p .707 .577 .707 r
F P
0 g
s
.36757 .79202 m .35644 .29844 L .35232 .28417 L p .707 .577 .707 r
F P
0 g
s
.35644 .29844 m .36757 .79202 L .38537 .80491 L p .707 .577 .707 r
F P
0 g
s
.17363 .76159 m .17389 .72437 L .1613 .71688 L p .707 .577 .707 r
F P
0 g
s
.6643 .79272 m .66357 .81164 L .6361 .80774 L p .707 .577 .707 r
F P
0 g
s
.16904 .79255 m .16977 .77363 L .15714 .768 L p .707 .577 .707 r
F P
0 g
s
.16442 .70252 m .15881 .65264 L .15554 .63716 L p .707 .577 .707 r
F P
0 g
s
.15881 .65264 m .16442 .70252 L .1773 .71591 L p .707 .577 .707 r
F P
0 g
s
.15714 .768 m .15641 .78692 L .16904 .79255 L p .707 .577 .707 r
F P
0 g
s
.1613 .71688 m .16104 .7541 L .17363 .76159 L p .707 .577 .707 r
F P
0 g
s
.36097 .65982 m .35536 .60994 L .35862 .62542 L p .707 .577 .707 r
F P
0 g
s
.35521 .72138 m .35495 .7586 L .36203 .75078 L p .707 .577 .707 r
F P
0 g
s
.36203 .75078 m .36229 .71356 L .35521 .72138 L p .707 .577 .707 r
F P
0 g
s
.65126 .77798 m .64897 .77004 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64666 .7256 m .63735 .72145 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64656 .7237 m .64376 .53234 L .64897 .77004 L .707 .577 .707 r
F
.63735 .72145 m .63662 .74037 L .64769 .7453 L p F P
0 g
s
.64769 .7453 m .64926 .746 L p .64754 .74246 L .707 .577 .707 r
F P
0 g
s
.64754 .74246 m .63735 .72145 L .64769 .7453 L .707 .577 .707 r
F
.64656 .7237 m .64283 .56343 L .64376 .53234 L F
.646 .71297 m .64418 .63221 L p .64656 .7237 L F P
0 g
s
.64418 .63221 m .63601 .27012 L p .64446 .63343 L .707 .577 .707 r
F P
0 g
s
.64418 .63221 m .64446 .63343 L .64656 .7237 L .707 .577 .707 r
F
.63601 .27012 m .64411 .62916 L p .62935 .75082 L F P
0 g
s
.63662 .74037 m .63735 .72145 L .63688 .72055 L p .707 .577 .707 r
F P
0 g
s
.63662 .74037 m .63688 .72055 L .63592 .73267 L .707 .577 .707 r
F
.63421 .75434 m .62935 .75082 L p .64411 .62916 L F P
0 g
s
.6344 .71575 m .63367 .73467 L .63662 .74037 L p .707 .577 .707 r
F P
0 g
s
.64411 .62916 m .64715 .7637 L .63421 .75434 L p .707 .577 .707 r
F P
0 g
s
.63688 .72055 m .6344 .71575 L p .63592 .73267 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .63576 .58455 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .64118 .61918 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .63902 .60003 L p .63943 .61161 L .707 .577 .707 r
F P
0 g
s
.64487 .49481 m .65126 .77798 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64463 .64991 m .65752 .6633 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63902 .60003 m .64118 .61918 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.64118 .61918 m .64463 .64991 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.63601 .27012 m .64012 .28439 L p .64376 .53234 L .707 .577 .707 r
F P
0 g
s
.64283 .56343 m .63601 .27012 L .64376 .53234 L .707 .577 .707 r
F
.64715 .7637 m .646 .71297 L p .64656 .7237 L F P
0 g
s
.64897 .77004 m .64715 .7637 L p .64656 .7237 L .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64999 .72708 L .64666 .7256 L p .707 .577 .707 r
F P
0 g
s
.64926 .746 m .64666 .7256 L .64754 .74246 L .707 .577 .707 r
F
.65752 .6633 m .65191 .61342 L .64166 .60277 L p F P
0 g
s
.64166 .60277 m .63902 .60003 L p .64149 .60849 L .707 .577 .707 r
F P
0 g
s
.65752 .6633 m .64166 .60277 L .64149 .60849 L .707 .577 .707 r
F
.64012 .28439 m .64487 .49481 L p .64376 .53234 L F P
0 g
s
.35094 .77745 m .35021 .79637 L .35723 .79116 L p .707 .577 .707 r
F P
0 g
s
.35723 .79116 m .35796 .77224 L .35094 .77745 L p .707 .577 .707 r
F P
0 g
s
.16104 .7541 m .1613 .71688 L .1584 .70883 L p .707 .577 .707 r
F P
0 g
s
.16115 .68704 m .16442 .70252 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.15554 .63716 m .1587 .66522 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1587 .66522 m .16115 .68704 L p .15654 .64453 L .707 .577 .707 r
F P
0 g
s
.1584 .70883 m .15814 .74605 L .16104 .7541 L p .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .1584 .70883 L .16274 .70403 L p .707 .577 .707 r
F P
0 g
s
.16274 .70403 m .16548 .70101 L p .16362 .71244 L .707 .577 .707 r
F P
0 g
s
.15814 .74605 m .16274 .70403 L .16362 .71244 L .707 .577 .707 r
F
.16115 .68704 m .15554 .63716 L .16222 .62111 L p F P
0 g
s
.15641 .78692 m .15714 .768 L .15418 .7623 L p .707 .577 .707 r
F P
0 g
s
.15418 .7623 m .15345 .78122 L .15641 .78692 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35536 .60994 m .36097 .65982 L .34808 .64643 L p .707 .577 .707 r
F P
0 g
s
.36229 .71356 m .36203 .75078 L .35914 .74273 L p .707 .577 .707 r
F P
0 g
s
.35914 .74273 m .35939 .70551 L .36229 .71356 L p .707 .577 .707 r
F P
0 g
s
.35232 .28417 m .36346 .77775 L .36757 .79202 L p .707 .577 .707 r
F P
0 g
s
.36346 .77775 m .35232 .28417 L .36229 .2699 L p .707 .577 .707 r
F P
0 g
s
.34808 .64643 m .34247 .59655 L .35536 .60994 L p .707 .577 .707 r
F P
0 g
s
.35796 .77224 m .35723 .79116 L .35428 .78546 L p .707 .577 .707 r
F P
0 g
s
.35428 .78546 m .35501 .76653 L .35796 .77224 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16783 .67099 m .16222 .62111 L .17818 .60605 L p .707 .577 .707 r
F P
0 g
s
.16222 .62111 m .16783 .67099 L .16115 .68704 L p .707 .577 .707 r
F P
0 g
s
.62935 .75082 m .61821 .25723 L .63601 .27012 L p .707 .577 .707 r
F P
0 g
s
.15345 .78122 m .15418 .7623 L .16121 .75709 L p .707 .577 .707 r
F P
0 g
s
.34247 .59655 m .34808 .64643 L .32684 .63644 L p .707 .577 .707 r
F P
0 g
s
.32684 .63644 m .32123 .58656 L .34247 .59655 L p .707 .577 .707 r
F P
0 g
s
.16121 .75709 m .16048 .77601 L .15345 .78122 L p .707 .577 .707 r
F P
0 g
s
.16548 .70101 m .16522 .73823 L .15814 .74605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35939 .70551 m .35914 .74273 L .34654 .73524 L p .707 .577 .707 r
F P
0 g
s
.34654 .73524 m .3468 .69802 L .35939 .70551 L p .707 .577 .707 r
F P
0 g
s
.37343 .76349 m .36229 .2699 L .38538 .25705 L p .707 .577 .707 r
F P
0 g
s
.36229 .2699 m .37343 .76349 L .36346 .77775 L p .707 .577 .707 r
F P
0 g
s
.17818 .60605 m .18379 .65593 L .16783 .67099 L p .707 .577 .707 r
F P
0 g
s
.18379 .65593 m .17818 .60605 L .20186 .59347 L p .707 .577 .707 r
F P
0 g
s
.35501 .76653 m .35428 .78546 L .34164 .77983 L p .707 .577 .707 r
F P
0 g
s
.34164 .77983 m .34237 .76091 L .35501 .76653 L p .707 .577 .707 r
F P
0 g
s
.32123 .58656 m .32684 .63644 L .29932 .63083 L p .707 .577 .707 r
F P
0 g
s
.29932 .63083 m .29371 .58095 L .32123 .58656 L p .707 .577 .707 r
F P
0 g
s
.16522 .73823 m .16548 .70101 L .18185 .69419 L p .707 .577 .707 r
F P
0 g
s
.16048 .77601 m .16121 .75709 L .17751 .75287 L p .707 .577 .707 r
F P
0 g
s
.17751 .75287 m .17678 .77179 L .16048 .77601 L p .707 .577 .707 r
F P
0 g
s
.18185 .69419 m .18159 .73141 L .16522 .73823 L p .707 .577 .707 r
F P
0 g
s
.20747 .64335 m .20186 .59347 L .23095 .58458 L p .707 .577 .707 r
F P
0 g
s
.20186 .59347 m .20747 .64335 L .18379 .65593 L p .707 .577 .707 r
F P
0 g
s
.61821 .25723 m .62935 .75082 L .59961 .74058 L p .707 .577 .707 r
F P
0 g
s
.59961 .74058 m .58847 .24699 L .61821 .25723 L p .707 .577 .707 r
F P
0 g
s
.29371 .58095 m .29932 .63083 L .26821 .63015 L p .707 .577 .707 r
F P
0 g
s
.26821 .63015 m .2626 .58027 L .29371 .58095 L p .707 .577 .707 r
F P
0 g
s
.3468 .69802 m .34654 .73524 L .32549 .72904 L p .707 .577 .707 r
F P
0 g
s
.32549 .72904 m .32574 .69182 L .3468 .69802 L p .707 .577 .707 r
F P
0 g
s
.23656 .63446 m .23095 .58458 L .2626 .58027 L p .707 .577 .707 r
F P
0 g
s
.23095 .58458 m .23656 .63446 L .20747 .64335 L p .707 .577 .707 r
F P
0 g
s
.2626 .58027 m .26821 .63015 L .23656 .63446 L p .707 .577 .707 r
F P
0 g
s
.34237 .76091 m .34164 .77983 L .32056 .77482 L p .707 .577 .707 r
F P
0 g
s
.32056 .77482 m .32129 .7559 L .34237 .76091 L p .707 .577 .707 r
F P
0 g
s
.18159 .73141 m .18185 .69419 L .2059 .68904 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .37343 .76349 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.38949 .4392 m .39651 .75063 L p .38217 .39315 L .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .38538 .25705 L .41931 .24686 L p .707 .577 .707 r
F P
0 g
s
.39651 .75063 m .40763 .50485 L .42658 .70051 L .707 .577 .707 r
F
.41538 .74497 m .39651 .75063 L p .42658 .70051 L F P
0 g
s
.4185 .70224 m .41777 .72116 L .42141 .72102 L p .707 .577 .707 r
F P
0 g
s
.42141 .72102 m .44711 .72003 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.42511 .70635 m .4185 .70224 L .42141 .72102 L .707 .577 .707 r
F
.44711 .72003 m .44784 .70111 L .42622 .70194 L p F P
0 g
s
.42622 .70194 m .4185 .70224 L p .42511 .70635 L .707 .577 .707 r
F P
0 g
s
.44711 .72003 m .42622 .70194 L .42511 .70635 L .707 .577 .707 r
F
.42601 .54409 m .4293 .68971 L p .40763 .50485 L F P
0 g
s
.4293 .68971 m .43045 .74044 L p .42658 .70051 L .707 .577 .707 r
F P
0 g
s
.40763 .50485 m .4293 .68971 L .42658 .70051 L .707 .577 .707 r
F
.43045 .74044 m .41538 .74497 L p .42658 .70051 L F P
0 g
s
.41931 .24686 m .42601 .54409 L p .40763 .50485 L .707 .577 .707 r
F P
0 g
s
.43045 .74044 m .41931 .24686 L .46077 .24033 L p .707 .577 .707 r
F P
0 g
s
.46077 .24033 m .47191 .73392 L .46058 .7357 L p .707 .577 .707 r
F P
0 g
s
.44784 .70111 m .44711 .72003 L .4563 .71896 L p .707 .577 .707 r
F P
0 g
s
.45258 .7044 m .44784 .70111 L .4563 .71896 L .707 .577 .707 r
F
.43646 .6413 m .46077 .24033 L .46058 .7357 L F
.47191 .73392 m .46077 .24033 L .5057 .23811 L p F P
0 g
s
.4711 .71723 m .47183 .69831 L .44784 .70111 L p .707 .577 .707 r
F P
0 g
s
.46058 .7357 m .43045 .74044 L p .43646 .6413 L .707 .577 .707 r
F P
0 g
s
.4563 .71896 m .4711 .71723 L p .45258 .7044 L .707 .577 .707 r
F P
0 g
s
.45512 .62957 m .45166 .59884 L p .42042 .58857 L .707 .577 .707 r
F P
0 g
s
.45166 .59884 m .44951 .57969 L .44354 .58151 L p .707 .577 .707 r
F P
0 g
s
.44354 .58151 m .42042 .58857 L p .45166 .59884 L .707 .577 .707 r
F P
0 g
s
.42236 .67579 m .42257 .64453 L p .39078 .6391 L .707 .577 .707 r
F P
0 g
s
.42257 .64453 m .42262 .63857 L .41681 .63867 L p .707 .577 .707 r
F P
0 g
s
.41681 .63867 m .39078 .6391 L p .42257 .64453 L .707 .577 .707 r
F P
0 g
s
.39438 .64276 m .39096 .61239 L p .35766 .5922 L .707 .577 .707 r
F P
0 g
s
.39096 .61239 m .38877 .59288 L .37141 .5925 L p .707 .577 .707 r
F P
0 g
s
.37141 .5925 m .35766 .5922 L p .39096 .61239 L .707 .577 .707 r
F P
0 g
s
.38877 .59288 m .39438 .64276 L .42126 .6391 L p .707 .577 .707 r
F P
0 g
s
.42262 .63857 m .42236 .67579 L .45174 .67281 L p .707 .577 .707 r
F P
0 g
s
.45174 .67281 m .45195 .64219 L p .42262 .63857 L .707 .577 .707 r
F P
0 g
s
.45195 .64219 m .452 .63559 L .4465 .63614 L p .707 .577 .707 r
F P
0 g
s
.4465 .63614 m .42262 .63857 L p .45195 .64219 L .707 .577 .707 r
F P
0 g
s
.42603 .63845 m .42281 .60986 L p .38877 .59288 L .707 .577 .707 r
F P
0 g
s
.42281 .60986 m .42042 .58857 L .40546 .59061 L p .707 .577 .707 r
F P
0 g
s
.40546 .59061 m .38877 .59288 L p .42281 .60986 L .707 .577 .707 r
F P
0 g
s
.42126 .6391 m .42603 .63845 L p .41999 .63106 L .707 .577 .707 r
F P
0 g
s
.41999 .63106 m .38877 .59288 L .42126 .6391 L .707 .577 .707 r
F
.38538 .25705 m .38949 .4392 L p .38217 .39315 L F P
0 g
s
.17678 .77179 m .17751 .75287 L .20151 .75006 L p .707 .577 .707 r
F P
0 g
s
.20151 .75006 m .20078 .76898 L .17678 .77179 L p .707 .577 .707 r
F P
0 g
s
.2059 .68904 m .20564 .72626 L .18159 .73141 L p .707 .577 .707 r
F P
0 g
s
.32574 .69182 m .32549 .72904 L .29803 .72474 L p .707 .577 .707 r
F P
0 g
s
.29803 .72474 m .29829 .68751 L .32574 .69182 L p .707 .577 .707 r
F P
0 g
s
.76537 .71261 m .76558 .68134 L p .73379 .67591 L .707 .577 .707 r
F P
0 g
s
.76558 .68134 m .76562 .67539 L .75982 .67548 L p .707 .577 .707 r
F P
0 g
s
.75982 .67548 m .73379 .67591 L p .76558 .68134 L .707 .577 .707 r
F P
0 g
s
.73739 .67958 m .73397 .6492 L p .70067 .62902 L .707 .577 .707 r
F P
0 g
s
.73397 .6492 m .73178 .6297 L .71442 .62932 L p .707 .577 .707 r
F P
0 g
s
.71442 .62932 m .70067 .62902 L p .73397 .6492 L .707 .577 .707 r
F P
0 g
s
.76562 .67539 m .76537 .71261 L .79475 .70962 L p .707 .577 .707 r
F P
0 g
s
.79475 .70962 m .79496 .679 L p .76562 .67539 L .707 .577 .707 r
F P
0 g
s
.79496 .679 m .79501 .6724 L .78951 .67296 L p .707 .577 .707 r
F P
0 g
s
.78951 .67296 m .76562 .67539 L p .79496 .679 L .707 .577 .707 r
F P
0 g
s
.76904 .67527 m .76582 .64668 L p .73178 .6297 L .707 .577 .707 r
F P
0 g
s
.76582 .64668 m .76343 .62539 L .74847 .62743 L p .707 .577 .707 r
F P
0 g
s
.74847 .62743 m .73178 .6297 L p .76582 .64668 L .707 .577 .707 r
F P
0 g
s
.73178 .6297 m .73739 .67958 L .76904 .67527 L p .707 .577 .707 r
F P
0 g
s
.76343 .62539 m .76904 .67527 L .79813 .66638 L p .707 .577 .707 r
F P
0 g
s
.79813 .66638 m .79252 .6165 L .76343 .62539 L p .707 .577 .707 r
F P
0 g
s
.58847 .24699 m .59961 .74058 L .56084 .73399 L p .707 .577 .707 r
F P
0 g
s
.56084 .73399 m .5497 .2404 L .58847 .24699 L p .707 .577 .707 r
F P
0 g
s
.32129 .7559 m .32056 .77482 L .29309 .77093 L p .707 .577 .707 r
F P
0 g
s
.29309 .77093 m .29382 .75201 L .32129 .7559 L p .707 .577 .707 r
F P
0 g
s
.20564 .72626 m .2059 .68904 L .23528 .68605 L p .707 .577 .707 r
F P
0 g
s
.73353 .71313 m .73374 .68387 L p .70262 .67393 L .707 .577 .707 r
F P
0 g
s
.73374 .68387 m .73379 .67591 L .72649 .67545 L p .707 .577 .707 r
F P
0 g
s
.72649 .67545 m .70262 .67393 L p .73374 .68387 L .707 .577 .707 r
F P
0 g
s
.70262 .67393 m .70236 .71115 L .73353 .71313 L p .707 .577 .707 r
F P
0 g
s
.70628 .6789 m .7028 .6479 L p .67315 .62341 L .707 .577 .707 r
F P
0 g
s
.7028 .6479 m .70067 .62902 L .68355 .62553 L p .707 .577 .707 r
F P
0 g
s
.68355 .62553 m .67315 .62341 L p .7028 .6479 L .707 .577 .707 r
F P
0 g
s
.73379 .67591 m .73353 .71313 L .76537 .71261 L p .707 .577 .707 r
F P
0 g
s
.70067 .62902 m .70628 .6789 L .73739 .67958 L p .707 .577 .707 r
F P
0 g
s
.20078 .76898 m .20151 .75006 L .23085 .74894 L p .707 .577 .707 r
F P
0 g
s
.79252 .6165 m .79813 .66638 L .82181 .6538 L p .707 .577 .707 r
F P
0 g
s
.82181 .6538 m .8162 .60392 L .79252 .6165 L p .707 .577 .707 r
F P
0 g
s
.29829 .68751 m .29803 .72474 L .26686 .72275 L p .707 .577 .707 r
F P
0 g
s
.26686 .72275 m .26711 .68553 L .29829 .68751 L p .707 .577 .707 r
F P
0 g
s
.23085 .74894 m .23012 .76786 L .20078 .76898 L p .707 .577 .707 r
F P
0 g
s
.23528 .68605 m .23502 .72327 L .20564 .72626 L p .707 .577 .707 r
F P
0 g
s
.23502 .72327 m .23528 .68605 L .26711 .68553 L p .707 .577 .707 r
F P
0 g
s
.29382 .75201 m .29309 .77093 L .26193 .76853 L p .707 .577 .707 r
F P
0 g
s
.26193 .76853 m .26266 .74961 L .29382 .75201 L p .707 .577 .707 r
F P
0 g
s
.26711 .68553 m .26686 .72275 L .23502 .72327 L p .707 .577 .707 r
F P
0 g
s
.23012 .76786 m .23085 .74894 L .26266 .74961 L p .707 .577 .707 r
F P
0 g
s
.70236 .71115 m .70253 .68633 L p .67516 .66962 L .707 .577 .707 r
F P
0 g
s
.70253 .68633 m .70262 .67393 L .69391 .67256 L p .707 .577 .707 r
F P
0 g
s
.69391 .67256 m .67516 .66962 L p .70253 .68633 L .707 .577 .707 r
F P
0 g
s
.67876 .67329 m .67534 .64291 L p .65191 .61342 L .707 .577 .707 r
F P
0 g
s
.67534 .64291 m .67315 .62341 L .65896 .61673 L p .707 .577 .707 r
F P
0 g
s
.65896 .61673 m .65191 .61342 L p .67534 .64291 L .707 .577 .707 r
F P
0 g
s
.67315 .62341 m .67876 .67329 L .70628 .6789 L p .707 .577 .707 r
F P
0 g
s
.5497 .2404 m .56084 .73399 L .51684 .73169 L p .707 .577 .707 r
F P
0 g
s
.51684 .73169 m .5057 .23811 L .5497 .2404 L p .707 .577 .707 r
F P
0 g
s
.72897 .7573 m .7297 .73838 L .69854 .73598 L p .707 .577 .707 r
F P
0 g
s
.7297 .73838 m .72897 .7573 L .76078 .75797 L p .707 .577 .707 r
F P
0 g
s
.76078 .75797 m .76151 .73905 L .7297 .73838 L p .707 .577 .707 r
F P
0 g
s
.26266 .74961 m .26193 .76853 L .23012 .76786 L p .707 .577 .707 r
F P
0 g
s
.76151 .73905 m .76078 .75797 L .79012 .75685 L p .707 .577 .707 r
F P
0 g
s
.79012 .75685 m .79085 .73793 L .76151 .73905 L p .707 .577 .707 r
F P
0 g
s
.69854 .73598 m .69781 .7549 L .72897 .7573 L p .707 .577 .707 r
F P
0 g
s
.8162 .60392 m .82181 .6538 L .83777 .63874 L p .707 .577 .707 r
F P
0 g
s
.83777 .63874 m .83216 .58886 L .8162 .60392 L p .707 .577 .707 r
F P
0 g
s
.69781 .7549 m .69854 .73598 L .67107 .73209 L p .707 .577 .707 r
F P
0 g
s
.79501 .6724 m .79475 .70962 L .8188 .70447 L p .707 .577 .707 r
F P
0 g
s
.8188 .70447 m .81906 .66725 L .79501 .6724 L p .707 .577 .707 r
F P
0 g
s
.5057 .23811 m .51684 .73169 L .47191 .73392 L p .707 .577 .707 r
F P
0 g
s
.67516 .66962 m .6749 .70684 L .70236 .71115 L p .707 .577 .707 r
F P
0 g
s
.67107 .73209 m .67034 .75101 L .69781 .7549 L p .707 .577 .707 r
F P
0 g
s
.79085 .73793 m .79012 .75685 L .81411 .75404 L p .707 .577 .707 r
F P
0 g
s
.81411 .75404 m .81484 .73512 L .79085 .73793 L p .707 .577 .707 r
F P
0 g
s
.6749 .70684 m .67516 .66962 L .6541 .66342 L p .707 .577 .707 r
F P
0 g
s
.65191 .61342 m .65752 .6633 L .67876 .67329 L p .707 .577 .707 r
F P
0 g
s
.67034 .75101 m .67107 .73209 L .64999 .72708 L p .707 .577 .707 r
F P
0 g
s
.6541 .66342 m .65385 .70064 L .6749 .70684 L p .707 .577 .707 r
F P
0 g
s
.64999 .72708 m .64926 .746 L .67034 .75101 L p .707 .577 .707 r
F P
0 g
s
.83216 .58886 m .83777 .63874 L .84445 .62269 L p .707 .577 .707 r
F P
0 g
s
.84445 .62269 m .83884 .57281 L .83216 .58886 L p .707 .577 .707 r
F P
0 g
s
.81906 .66725 m .8188 .70447 L .83517 .69765 L p .707 .577 .707 r
F P
0 g
s
.83517 .69765 m .83542 .66043 L .81906 .66725 L p .707 .577 .707 r
F P
0 g
s
.81484 .73512 m .81411 .75404 L .83042 .74982 L p .707 .577 .707 r
F P
0 g
s
.83042 .74982 m .83115 .7309 L .81484 .73512 L p .707 .577 .707 r
F P
0 g
s
.65385 .70064 m .6541 .66342 L .64151 .65593 L p .707 .577 .707 r
F P
0 g
s
.64151 .65593 m .64125 .69315 L .65385 .70064 L p .707 .577 .707 r
F P
0 g
s
.83884 .57281 m .84445 .62269 L .84118 .60721 L p .707 .577 .707 r
F P
0 g
s
.84118 .60721 m .83557 .55733 L .83884 .57281 L p .707 .577 .707 r
F P
0 g
s
.83542 .66043 m .83517 .69765 L .84225 .68983 L p .707 .577 .707 r
F P
0 g
s
.84225 .68983 m .84251 .65261 L .83542 .66043 L p .707 .577 .707 r
F P
0 g
s
.83115 .7309 m .83042 .74982 L .83744 .74461 L p .707 .577 .707 r
F P
0 g
s
.83744 .74461 m .83817 .72569 L .83115 .7309 L p .707 .577 .707 r
F P
0 g
s
.64125 .69315 m .64151 .65593 L .63861 .64788 L p .707 .577 .707 r
F P
0 g
s
.64137 .63443 m .64463 .64991 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63576 .58455 m .63886 .61213 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63886 .61213 m .64137 .63443 L p .63674 .59179 L .707 .577 .707 r
F P
0 g
s
.63861 .64788 m .63835 .6851 L .64125 .69315 L p .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .63861 .64788 L .64217 .64395 L p .707 .577 .707 r
F P
0 g
s
.64217 .64395 m .64569 .64006 L p .6433 .65475 L .707 .577 .707 r
F P
0 g
s
.63835 .6851 m .64217 .64395 L .6433 .65475 L .707 .577 .707 r
F
.64137 .63443 m .63576 .58455 L .64243 .5685 L p F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83557 .55733 m .84118 .60721 L .8283 .59382 L p .707 .577 .707 r
F P
0 g
s
.8283 .59382 m .82269 .54394 L .83557 .55733 L p .707 .577 .707 r
F P
0 g
s
.84251 .65261 m .84225 .68983 L .83935 .68179 L p .707 .577 .707 r
F P
0 g
s
.83935 .68179 m .83961 .64456 L .84251 .65261 L p .707 .577 .707 r
F P
0 g
s
.83817 .72569 m .83744 .74461 L .83449 .73891 L p .707 .577 .707 r
F P
0 g
s
.83449 .73891 m .83522 .71999 L .83817 .72569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64804 .61838 m .64243 .5685 L .65839 .55344 L p .707 .577 .707 r
F P
0 g
s
.64243 .5685 m .64804 .61838 L .64137 .63443 L p .707 .577 .707 r
F P
0 g
s
.63367 .73467 m .6344 .71575 L .64142 .71054 L p .707 .577 .707 r
F P
0 g
s
.82269 .54394 m .8283 .59382 L .80705 .58383 L p .707 .577 .707 r
F P
0 g
s
.80705 .58383 m .80144 .53395 L .82269 .54394 L p .707 .577 .707 r
F P
0 g
s
.64569 .64006 m .64544 .67728 L .63835 .6851 L p .707 .577 .707 r
F P
0 g
s
.42042 .58857 m .42603 .63845 L .45512 .62957 L p .707 .577 .707 r
F P
0 g
s
.64142 .71054 m .64069 .72946 L .63367 .73467 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39052 .67632 m .39073 .64705 L p .35961 .63711 L .707 .577 .707 r
F P
0 g
s
.39073 .64705 m .39078 .6391 L .38348 .63863 L p .707 .577 .707 r
F P
0 g
s
.38348 .63863 m .35961 .63711 L p .39073 .64705 L .707 .577 .707 r
F P
0 g
s
.35961 .63711 m .35935 .67433 L .39052 .67632 L p .707 .577 .707 r
F P
0 g
s
.36327 .64208 m .35979 .61109 L p .33014 .58659 L .707 .577 .707 r
F P
0 g
s
.35979 .61109 m .35766 .5922 L .34054 .58871 L p .707 .577 .707 r
F P
0 g
s
.34054 .58871 m .33014 .58659 L p .35979 .61109 L .707 .577 .707 r
F P
0 g
s
.39078 .6391 m .39052 .67632 L .42236 .67579 L p .707 .577 .707 r
F P
0 g
s
.35766 .5922 m .36327 .64208 L .39438 .64276 L p .707 .577 .707 r
F P
0 g
s
.83961 .64456 m .83935 .68179 L .82676 .67429 L p .707 .577 .707 r
F P
0 g
s
.82676 .67429 m .82701 .63707 L .83961 .64456 L p .707 .577 .707 r
F P
0 g
s
.44951 .57969 m .45512 .62957 L .4788 .61698 L p .707 .577 .707 r
F P
0 g
s
.4788 .61698 m .47319 .5671 L .44951 .57969 L p .707 .577 .707 r
F P
0 g
s
.65839 .55344 m .664 .60332 L .64804 .61838 L p .707 .577 .707 r
F P
0 g
s
.664 .60332 m .65839 .55344 L .68207 .54085 L p .707 .577 .707 r
F P
0 g
s
.83522 .71999 m .83449 .73891 L .82185 .73328 L p .707 .577 .707 r
F P
0 g
s
.82185 .73328 m .82259 .71436 L .83522 .71999 L p .707 .577 .707 r
F P
0 g
s
.64544 .67728 m .64569 .64006 L .66206 .63324 L p .707 .577 .707 r
F P
0 g
s
.80144 .53395 m .80705 .58383 L .77953 .57822 L p .707 .577 .707 r
F P
0 g
s
.77953 .57822 m .77392 .52834 L .80144 .53395 L p .707 .577 .707 r
F P
0 g
s
.35935 .67433 m .35952 .64952 L p .33215 .6328 L .707 .577 .707 r
F P
0 g
s
.35952 .64952 m .35961 .63711 L .3509 .63574 L p .707 .577 .707 r
F P
0 g
s
.3509 .63574 m .33215 .6328 L p .35952 .64952 L .707 .577 .707 r
F P
0 g
s
.33575 .63647 m .33233 .60609 L p .3089 .5766 L .707 .577 .707 r
F P
0 g
s
.33233 .60609 m .33014 .58659 L .31595 .57992 L p .707 .577 .707 r
F P
0 g
s
.31595 .57992 m .3089 .5766 L p .33233 .60609 L .707 .577 .707 r
F P
0 g
s
.33014 .58659 m .33575 .63647 L .36327 .64208 L p .707 .577 .707 r
F P
0 g
s
.38596 .72049 m .38669 .70157 L .35553 .69917 L p .707 .577 .707 r
F P
0 g
s
.38669 .70157 m .38596 .72049 L .41777 .72116 L p .707 .577 .707 r
F P
0 g
s
.41777 .72116 m .4185 .70224 L .38669 .70157 L p .707 .577 .707 r
F P
0 g
s
.35553 .69917 m .3548 .71809 L .38596 .72049 L p .707 .577 .707 r
F P
0 g
s
.47319 .5671 m .4788 .61698 L .49476 .60192 L p .707 .577 .707 r
F P
0 g
s
.49476 .60192 m .48915 .55204 L .47319 .5671 L p .707 .577 .707 r
F P
0 g
s
.64069 .72946 m .64142 .71054 L .65773 .70632 L p .707 .577 .707 r
F P
0 g
s
.66206 .63324 m .6618 .67047 L .64544 .67728 L p .707 .577 .707 r
F P
0 g
s
.3548 .71809 m .35553 .69917 L .32806 .69527 L p .707 .577 .707 r
F P
0 g
s
.65773 .70632 m .657 .72524 L .64069 .72946 L p .707 .577 .707 r
F P
0 g
s
.452 .63559 m .45174 .67281 L .47579 .66765 L p .707 .577 .707 r
F P
0 g
s
.47579 .66765 m .47605 .63043 L .452 .63559 L p .707 .577 .707 r
F P
0 g
s
.68769 .59073 m .68207 .54085 L .71116 .53197 L p .707 .577 .707 r
F P
0 g
s
.68207 .54085 m .68769 .59073 L .664 .60332 L p .707 .577 .707 r
F P
0 g
s
.33215 .6328 m .33189 .67003 L .35935 .67433 L p .707 .577 .707 r
F P
0 g
s
.32806 .69527 m .32733 .71419 L .3548 .71809 L p .707 .577 .707 r
F P
0 g
s
.77392 .52834 m .77953 .57822 L .74842 .57754 L p .707 .577 .707 r
F P
0 g
s
.74842 .57754 m .74281 .52766 L .77392 .52834 L p .707 .577 .707 r
F P
0 g
s
.82701 .63707 m .82676 .67429 L .8057 .66809 L p .707 .577 .707 r
F P
0 g
s
.8057 .66809 m .80596 .63087 L .82701 .63707 L p .707 .577 .707 r
F P
0 g
s
.33189 .67003 m .33215 .6328 L .31109 .6266 L p .707 .577 .707 r
F P
0 g
s
.71677 .58185 m .71116 .53197 L .74281 .52766 L p .707 .577 .707 r
F P
0 g
s
.71116 .53197 m .71677 .58185 L .68769 .59073 L p .707 .577 .707 r
F P
0 g
s
.31451 .62648 m .3089 .5766 L .29601 .56321 L p .707 .577 .707 r
F P
0 g
s
.3089 .5766 m .31451 .62648 L .33575 .63647 L p .707 .577 .707 r
F P
0 g
s
.74281 .52766 m .74842 .57754 L .71677 .58185 L p .707 .577 .707 r
F P
0 g
s
.82259 .71436 m .82185 .73328 L .80077 .72827 L p .707 .577 .707 r
F P
0 g
s
.80077 .72827 m .8015 .70935 L .82259 .71436 L p .707 .577 .707 r
F P
0 g
s
.32733 .71419 m .32806 .69527 L .30698 .69027 L p .707 .577 .707 r
F P
0 g
s
.6618 .67047 m .66206 .63324 L .68611 .62809 L p .707 .577 .707 r
F P
0 g
s
.31109 .6266 m .31084 .66382 L .33189 .67003 L p .707 .577 .707 r
F P
0 g
s
.30698 .69027 m .30625 .70919 L .32733 .71419 L p .707 .577 .707 r
F P
0 g
s
.48915 .55204 m .49476 .60192 L .50144 .58587 L p .707 .577 .707 r
F P
0 g
s
.50144 .58587 m .49583 .53599 L .48915 .55204 L p .707 .577 .707 r
F P
0 g
s
.47605 .63043 m .47579 .66765 L .49216 .66083 L p .707 .577 .707 r
F P
0 g
s
.49216 .66083 m .49241 .62361 L .47605 .63043 L p .707 .577 .707 r
F P
0 g
s
.657 .72524 m .65773 .70632 L .68172 .70351 L p .707 .577 .707 r
F P
0 g
s
.68611 .62809 m .68585 .66531 L .6618 .67047 L p .707 .577 .707 r
F P
0 g
s
.68172 .70351 m .68099 .72243 L .657 .72524 L p .707 .577 .707 r
F P
0 g
s
.80596 .63087 m .8057 .66809 L .77824 .66379 L p .707 .577 .707 r
F P
0 g
s
.77824 .66379 m .7785 .62657 L .80596 .63087 L p .707 .577 .707 r
F P
0 g
s
.47183 .69831 m .4711 .71723 L .48741 .71301 L p .707 .577 .707 r
F P
0 g
s
.48741 .71301 m .48814 .69409 L .47183 .69831 L p .707 .577 .707 r
F P
0 g
s
.31084 .66382 m .31109 .6266 L .2985 .61911 L p .707 .577 .707 r
F P
0 g
s
.68585 .66531 m .68611 .62809 L .71549 .6251 L p .707 .577 .707 r
F P
0 g
s
.30162 .61309 m .29601 .56321 L .29275 .54773 L p .707 .577 .707 r
F P
0 g
s
.29601 .56321 m .30162 .61309 L .31451 .62648 L p .707 .577 .707 r
F P
0 g
s
.8015 .70935 m .80077 .72827 L .7733 .72438 L p .707 .577 .707 r
F P
0 g
s
.7733 .72438 m .77403 .70546 L .8015 .70935 L p .707 .577 .707 r
F P
0 g
s
.30625 .70919 m .30698 .69027 L .29434 .68464 L p .707 .577 .707 r
F P
0 g
s
.2985 .61911 m .29824 .65633 L .31084 .66382 L p .707 .577 .707 r
F P
0 g
s
.29434 .68464 m .29361 .70356 L .30625 .70919 L p .707 .577 .707 r
F P
0 g
s
.7785 .62657 m .77824 .66379 L .74707 .6618 L p .707 .577 .707 r
F P
0 g
s
.74707 .6618 m .74733 .62458 L .7785 .62657 L p .707 .577 .707 r
F P
0 g
s
.68099 .72243 m .68172 .70351 L .71106 .70239 L p .707 .577 .707 r
F P
0 g
s
.71549 .6251 m .71524 .66232 L .68585 .66531 L p .707 .577 .707 r
F P
0 g
s
.49583 .53599 m .50144 .58587 L .49817 .57039 L p .707 .577 .707 r
F P
0 g
s
.49817 .57039 m .49256 .52051 L .49583 .53599 L p .707 .577 .707 r
F P
0 g
s
.49241 .62361 m .49216 .66083 L .49924 .65302 L p .707 .577 .707 r
F P
0 g
s
.49924 .65302 m .4995 .6158 L .49241 .62361 L p .707 .577 .707 r
F P
0 g
s
.71524 .66232 m .71549 .6251 L .74733 .62458 L p .707 .577 .707 r
F P
0 g
s
.71106 .70239 m .71033 .72131 L .68099 .72243 L p .707 .577 .707 r
F P
0 g
s
.74733 .62458 m .74707 .6618 L .71524 .66232 L p .707 .577 .707 r
F P
0 g
s
.77403 .70546 m .7733 .72438 L .74214 .72198 L p .707 .577 .707 r
F P
0 g
s
.74214 .72198 m .74287 .70306 L .77403 .70546 L p .707 .577 .707 r
F P
0 g
s
.48814 .69409 m .48741 .71301 L .49443 .70779 L p .707 .577 .707 r
F P
0 g
s
.49443 .70779 m .49516 .68887 L .48814 .69409 L p .707 .577 .707 r
F P
0 g
s
.71033 .72131 m .71106 .70239 L .74287 .70306 L p .707 .577 .707 r
F P
0 g
s
.29824 .65633 m .2985 .61911 L .2956 .61106 L p .707 .577 .707 r
F P
0 g
s
.74287 .70306 m .74214 .72198 L .71033 .72131 L p .707 .577 .707 r
F P
0 g
s
.29836 .59761 m .30162 .61309 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29275 .54773 m .29585 .57531 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.29585 .57531 m .29836 .59761 L p .29373 .55497 L .707 .577 .707 r
F P
0 g
s
.2956 .61106 m .29534 .64829 L .29824 .65633 L p .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .2956 .61106 L .29916 .60713 L p .707 .577 .707 r
F P
0 g
s
.29916 .60713 m .30268 .60325 L p .30029 .61794 L .707 .577 .707 r
F P
0 g
s
.29534 .64829 m .29916 .60713 L .30029 .61794 L .707 .577 .707 r
F
.29836 .59761 m .29275 .54773 L .29942 .53168 L p F P
0 g
s
.29361 .70356 m .29434 .68464 L .29139 .67894 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29139 .67894 m .29066 .69786 L .29361 .70356 L p .707 .577 .707 r
F P
0 g
s
.49256 .52051 m .49817 .57039 L .48529 .557 L p .707 .577 .707 r
F P
0 g
s
.48529 .557 m .47968 .50712 L .49256 .52051 L p .707 .577 .707 r
F P
0 g
s
.4995 .6158 m .49924 .65302 L .49634 .64497 L p .707 .577 .707 r
F P
0 g
s
.49634 .64497 m .4966 .60775 L .4995 .6158 L p .707 .577 .707 r
F P
0 g
s
.49516 .68887 m .49443 .70779 L .49148 .70209 L p .707 .577 .707 r
F P
0 g
s
.49148 .70209 m .49221 .68317 L .49516 .68887 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30503 .58156 m .29942 .53168 L .31538 .51662 L p .707 .577 .707 r
F P
0 g
s
.29942 .53168 m .30503 .58156 L .29836 .59761 L p .707 .577 .707 r
F P
0 g
s
.29066 .69786 m .29139 .67894 L .29841 .67372 L p .707 .577 .707 r
F P
0 g
s
.47968 .50712 m .48529 .557 L .46404 .54701 L p .707 .577 .707 r
F P
0 g
s
.46404 .54701 m .45843 .49713 L .47968 .50712 L p .707 .577 .707 r
F P
0 g
s
.30268 .60325 m .30242 .64047 L .29534 .64829 L p .707 .577 .707 r
F P
0 g
s
.29841 .67372 m .29768 .69264 L .29066 .69786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4966 .60775 m .49634 .64497 L .48375 .63748 L p .707 .577 .707 r
F P
0 g
s
.48375 .63748 m .484 .60026 L .4966 .60775 L p .707 .577 .707 r
F P
0 g
s
.31538 .51662 m .32099 .5665 L .30503 .58156 L p .707 .577 .707 r
F P
0 g
s
.32099 .5665 m .31538 .51662 L .33906 .50404 L p .707 .577 .707 r
F P
0 g
s
.49221 .68317 m .49148 .70209 L .47884 .69647 L p .707 .577 .707 r
F P
0 g
s
.47884 .69647 m .47957 .67755 L .49221 .68317 L p .707 .577 .707 r
F P
0 g
s
.30242 .64047 m .30268 .60325 L .31905 .59643 L p .707 .577 .707 r
F P
0 g
s
.45843 .49713 m .46404 .54701 L .43652 .5414 L p .707 .577 .707 r
F P
0 g
s
.43652 .5414 m .43091 .49152 L .45843 .49713 L p .707 .577 .707 r
F P
0 g
s
.29768 .69264 m .29841 .67372 L .31472 .66951 L p .707 .577 .707 r
F P
0 g
s
.31905 .59643 m .31879 .63365 L .30242 .64047 L p .707 .577 .707 r
F P
0 g
s
.31472 .66951 m .31399 .68843 L .29768 .69264 L p .707 .577 .707 r
F P
0 g
s
.34467 .55392 m .33906 .50404 L .36815 .49515 L p .707 .577 .707 r
F P
0 g
s
.33906 .50404 m .34467 .55392 L .32099 .5665 L p .707 .577 .707 r
F P
0 g
s
.43091 .49152 m .43652 .5414 L .40541 .54072 L p .707 .577 .707 r
F P
0 g
s
.40541 .54072 m .3998 .49084 L .43091 .49152 L p .707 .577 .707 r
F P
0 g
s
.484 .60026 m .48375 .63748 L .46269 .63128 L p .707 .577 .707 r
F P
0 g
s
.46269 .63128 m .46295 .59406 L .484 .60026 L p .707 .577 .707 r
F P
0 g
s
.37376 .54503 m .36815 .49515 L .3998 .49084 L p .707 .577 .707 r
F P
0 g
s
.36815 .49515 m .37376 .54503 L .34467 .55392 L p .707 .577 .707 r
F P
0 g
s
.3998 .49084 m .40541 .54072 L .37376 .54503 L p .707 .577 .707 r
F P
0 g
s
.47957 .67755 m .47884 .69647 L .45776 .69146 L p .707 .577 .707 r
F P
0 g
s
.45776 .69146 m .45849 .67254 L .47957 .67755 L p .707 .577 .707 r
F P
0 g
s
.31879 .63365 m .31905 .59643 L .3431 .59127 L p .707 .577 .707 r
F P
0 g
s
.31399 .68843 m .31472 .66951 L .33871 .6667 L p .707 .577 .707 r
F P
0 g
s
.3431 .59127 m .34284 .6285 L .31879 .63365 L p .707 .577 .707 r
F P
0 g
s
.33871 .6667 m .33798 .68562 L .31399 .68843 L p .707 .577 .707 r
F P
0 g
s
.46295 .59406 m .46269 .63128 L .43523 .62697 L p .707 .577 .707 r
F P
0 g
s
.43523 .62697 m .43549 .58975 L .46295 .59406 L p .707 .577 .707 r
F P
0 g
s
.34284 .6285 m .3431 .59127 L .37248 .58829 L p .707 .577 .707 r
F P
0 g
s
.45849 .67254 m .45776 .69146 L .43029 .68757 L p .707 .577 .707 r
F P
0 g
s
.43029 .68757 m .43102 .66865 L .45849 .67254 L p .707 .577 .707 r
F P
0 g
s
.43549 .58975 m .43523 .62697 L .40406 .62498 L p .707 .577 .707 r
F P
0 g
s
.40406 .62498 m .40432 .58776 L .43549 .58975 L p .707 .577 .707 r
F P
0 g
s
.33798 .68562 m .33871 .6667 L .36805 .66558 L p .707 .577 .707 r
F P
0 g
s
.37248 .58829 m .37222 .62551 L .34284 .6285 L p .707 .577 .707 r
F P
0 g
s
.37222 .62551 m .37248 .58829 L .40432 .58776 L p .707 .577 .707 r
F P
0 g
s
.36805 .66558 m .36732 .6845 L .33798 .68562 L p .707 .577 .707 r
F P
0 g
s
.40432 .58776 m .40406 .62498 L .37222 .62551 L p .707 .577 .707 r
F P
0 g
s
.43102 .66865 m .43029 .68757 L .39913 .68517 L p .707 .577 .707 r
F P
0 g
s
.39913 .68517 m .39986 .66625 L .43102 .66865 L p .707 .577 .707 r
F P
0 g
s
.36732 .6845 m .36805 .66558 L .39986 .66625 L p .707 .577 .707 r
F P
0 g
s
.39986 .66625 m .39913 .68517 L .36732 .6845 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029Ool=0027Ool0081oo`T0
00IJEP03001JEUYF00AJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01P00N7oo001fOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001dOol007=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEP00001bOol006moo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP04001JEUYFFUH3001_Ool006aoo`<000QJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8006eoo`00JWoo0P0000=JEP00
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF0`00Jgoo001XOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001YOol006Ioo`8000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0IWoo001UOol20006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001J
EUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0005FUH20009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1T
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<007ooOol0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00Oomoo`1TOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001oogoo06Aoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0I7oo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=o
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo06=oo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo06=oo`00IGoo00@005YFFUH000AJEPl0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo06=oo`00IGoo
00<005YF00001@0015YF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0Hgoo001UOol2
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`1SOol0069oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000aJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00AJEP03001oogoo06=oo`00Ggoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH015YF00<007ooOol0Hgoo001MOol200000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1S
Ool005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06=oo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001HOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0Hgoo001GOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001GOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<007ooOol0Hgoo001FOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo01Eooa0003ioo`00EGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00ioo`L000AJEP03001JEUYF00EJEP04
001JEUYFFUH5000iOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000<Ool40002FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3000gOol005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPd000EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool30006FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02000eOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF009JEP@00003FUH005YF
00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20007Ool30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH2000cOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPD0009JEP03
001JEUYF00MJEP03001JEUYF00IJEP8000EJEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006Ool01000FUIJEP0025YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP050006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20003FUH01@00
FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000<Goo001COol00`00FUH00004FUH00`00FUIJEP04FUH30002Ool0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH300000eYF001JEP02FUH01@00FUIJEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000goo00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH0031oo`00Dgoo00<005YF00001EYF00@005YFFUIJEP8000Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF008000=JEP05001JEUYFFUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool20006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol0
1000FUIJEP0015YF00@005YFFUH000Moo`03001JEP0000IJEP<000MJEP03001JEUYF00UJEP03001J
EUYF00<0009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH400000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol01000FUIJEP0015YF0`0027oo00<005YF
00001EYF1@001UYF00<005YFFUH02EYF00<005YF00000eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH002moo`00Dgoo00@005YFFUH000AJEP03001oogoo00Qoo`03001JEP0000EJEPD000IJEP03001J
EUYF00UJEP8000AJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH0
00=JEP03001oogoo00Uoo`03001JEP0000EJEPD000IJEP03001JEUYF00MJEP800003FUH005YF00=J
EP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH2000<
Ool00`00FUH00006FUH30007FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000<000aoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00AWoo3`00
00=JEP0000000UYF0P002Woo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH30007FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH015YF1P003goo10000UYF
00<005YFFUH00eYF00@005YFFUH002ioo`00@7oo1P0015YF00<005YFFUH01UYF0`0000=JEP00FUH0
0eYF0`001goo00@005YFFUH000EJEP03001JEUYF00MJEP@0009JEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000IOol40004FUH00`00FUIJ
EP02000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<0009JEP03001JEUYF009JEP03
001JEP0000<000=ooaX000MJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUH00002000OOol3000015YF001JEUYF0P00;Goo000iOol30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH30002FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P000UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00=JEP<002Eoo`80009JEP8002eoo`00
=goo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF00000`000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF0P00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF
009JEP04001JEUYFFUH2000?Ool3000EOol200001EYF001JEUYF0000;Goo000eOol20002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH30006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03
FUH01000FUH0000047oo1@004goo00@005YFFUIJEP800003FUH007oo02aoo`00<goo0P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00004FUH2000BOol5
000BOol00`00FUIJEP03FUH3000]Ool0039oo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP0057oo1@0047oo
0`001EYF00<005YF0000;Goo000aOol20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP0001Ioo`<0011oo`04001J
EUYF0005FUH00`00FUH0000]Ool0031oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P00:7oo0P000eYF00<0
05YFFUH00eYF00@005YF000002aoo`00;goo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF10008goo0`001UYF
00<005YFFUH00UYF00@005YFFUH002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH20002FUH2000MOol40002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000^
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00T005YF
FUIJEP00FUH005YF000015YF1`000goo4`001UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002aoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF1`0025YF0`001EYF200015YF00<005YFFUH00eYF
00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000EJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000IJ
EP03001JEUYF00=JEP8002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF300000=JEP00FUH00eYF00<005YF00000`001eYF00<005YFFUH015YF1@001UYF00<005YF
FUH00eYF1P0015YF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEUYF0004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0000=JEP00FUH015YF0P00;Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH7000;Ool00`00FUH00003FUH500000eYF001JEP06FUH00`00FUIJ
EP04FUH50006FUH00`00FUIJEP0800001UYF00000000FUH000=JEP05001JEUYFFUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00`001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0015YF00<007oo
Ool0;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04000BOol01000FUH005YF
0P001EYF1@0015YF00<005YFFUH015YF1@0000=JEP0000001P0015YF00<005YFFUH015YF0`000eYF
00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH0
0000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00Oomoo`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP<0
01Ioo`06001JEP00001JEP001EYF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;goo000/Ool00`00FUH00005FUH01000
FUIJEUYF0P006Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000^Ool002aoo`04001JEUYF0004FUH01000FUIJEP006goo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002aoo`04001JEUYF0004FUH3000AOol3
0008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000/Ool01000FUIJEP0015YF00<007ooOol047oo1@0027oo00D005YFFUIJEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF
0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001oogoo
015oo`D000Uoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eo
o`00;7oo00D005YFFUH005YF008001Aoo`D000]oo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEQX000AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002eoo`04001JEP00000G
Ool3000>OolM0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUH700000eYF001J
EP06FUH40006FUH00`00FUIJEP04FUH60003FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
000TOol60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUH0
0003000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=J
EPH000MJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEP80009oo`H00003FUH005YF009JEP80
02eoo`00;Goo00@005YF0000009JEP8001ioo`@0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF008000AJEP<000EJEP8000MJEPD0
00EJEP03001JEP0000H000EJEP<000=JEP8002eoo`00;Goo0P0000=JEP00FUH00eYF1@0057oo1`00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF00<000EJEP03001JEUYF00@0009JEP03001JEUYF00EJEPD00003FUH0000000D000AJEP03
001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00;Goo0P000UYF00<005YFFUH00UYF00@0
05YFFUIJEPT000Moo`@0009JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPh00004FUH005YF0004FUH0
1000FUIJEUYF6@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002eoo`00;Goo0P000UYF00<005YFFUH00UYF00<005YFFUH03P0015YF00<005YFFUH0
0UYF0`0000AJEP00FUIJEPH000=JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000=JEPP0
00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;Goo0P000UYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000T0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH6
0004FUH00`00FUIJEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000]Ool20002FUH0
1000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YF
FUH020000UYF00<007oo00000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01eYF0`0000AJEP00
FUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`03001JEUYF00<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH90006
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH700000eYF00000005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000^Ool30002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF400000=JEP00FUH015YF0`000eYF00@005YFFUIJ
EP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJ
EP03001JEUYF00AJEQ800003FUH005YF00IJEP03001JEUYF00AJEP04001JEP00000aOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000;
FUH01000FUIJEUYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF3`0015YF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH00UYF1@00<goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00002UYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD003Qoo`00;Goo00<007oo00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP0000YJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00002000eOol002eoo`03001oo`0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EPD000=JEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00009FUH4000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000b
Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP05001JEUYFFUH00006FUH30002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000P00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<0
05YF00001@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YF001JEP0000=JEP04001JEUYFFUHO0006FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;goo000]Ool00eYF001JEP03FUH01000FUIJEUYF200000=JEP00FUH01EYF1@0015YF
200015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00002FUH50003FUH00`00FUIJEP03FUH00`00Oomoo`06Ool50008Ool40002FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool30003FUH<0002FUH00`00FUIJEP04FUH90008Ool6
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<00003
FUH0000000H000EJEP03001oogoo00Moo`<000eoo`D000=JEP04001JEUYFFUH2000^Ool002aoo`04
001JEP00FUH20005FUH01000FUIJEUYF4@002Woo1`0000IJEP00000005YF0003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF7@0025YF00<005YFFUH01EYF00@005YF0000009J
EP03001JEUYF009JEPP00003FUH007oo01ioo`@000=JEP8002ioo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHB0003FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH00UYF1P001eYF00<005YFFUH02UYF00<005YFFUH01UYF
1P000UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEQ8000Uoo``0
0004FUH00000FUH2000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF
009JEP03001JEUYF00=JEP03001JEUYF00IJEPH00003FUH005YF00YJEP03001JEUYF00]JEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP03001JEUYF009JEP<002ioo`00
;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000=JEP03001JEUYF00=JEP03001JEUYF009J
EP@000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH015YF20000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP04FUH30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000_Ool002aoo`8000=JEP03001JEUYF009JEPP000=JEP03001JEUYF009J
EQ40009JEP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YF000000IJEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<0031oo`00;Goo00<005YFFUH01P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH200001GooFUIJ
EUYF00000eYF0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP04001JEUYFFUH90004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P00<goo000]Ool30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003
0003FUH00`00Oomoo`03FUH01000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJEP03
001JEUYF009JEP04001JEUYFFUH20002OolI000iOol002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000=o
o`=JEP@000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
E7oo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000Woo0eYF00@005YFFUH000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP800003FUH0000000D000=JEP04001JEUYFFUH2001DOol002]oo`03001JEP00
00AJEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000Woo0UYF
00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002Ool600000eYF001JEP02FUH2001D
Ool002]oo`03001JEP00009JEPH000Eoo`T000AJEP<0009JEPX000AJEP03001JEUYF00=JEP03001J
EUYF00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000<000EJEP<0
00=JEP8005Aoo`00:goo00<005YF00000`0000AJEP00000000moo`T000Yoo`L000=JEP03001JEUYF
00800003OomJEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001J
EUYF00800003FUH0000005Aoo`00:goo0P000eYF00<005YFFUH00UYF1@003Goo1@004Woo10000UYF
0P0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001UYF00<005YF
FUH00UYF0`00E7oo000[Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF20001Goo1@0047oo2P00
00=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF001JEP0000IJEP03001JEUYF
009JEP<005Aoo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP04001JEUYFFUHJ0003FUH0
1000FUIJEUYF0`0000=oo`00000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF0000E7oo000]Ool200000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP00009oo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00EJ
EP03001JEUYF009JEP8005Eoo`00;goo10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P000goo00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF1P000UYF00<005YFFUH00UYF0P00EGoo000cOol7
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP030005Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH010000UYF0P00
EWoo000jOol80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@002Woo0`0025YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00H005YF000005YF0007FUH00`00FUIJEP03FUH3001HOol0049ooaX0015oo`8000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008005Ioo`00Kgoo0`0015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`000UYF200015YF
00<005YFFUH00eYF00D005YFFUIJEP0005Ioo`00LWoo0`0000=JEP00FUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00003P0000=oo`000000100015YF00@005YFFUIJ
EP8005Eoo`00MGoo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF100000=o
o`0000000`0047oo0`0000=JEP00FUH00UYF0P00EGoo001iOol60002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH01000FUIJEUYF1P001Goo1@003goo1`000UYF0P00EGoo001oOol80006FUH00`00FUIJ
EP04FUH:00000eYF001JEP03FUHI0003FUH01000FUIJEUYF1000EGoo0027Ool=0003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3001EOol008moo`@000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Eoo`00Tgoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP<005Ioo`00UWoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF000005Uoo`00Vgoo2@0015YF00<005YFFUH01UYF00<005YFFUH00UYF
3000Fgoo002TOolB001WOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59459 .72635 m .6002 .66895 L .56909 .66574 L p .707 .577 .707 r
F P
0 g
s
.6002 .66895 m .59459 .72635 L .62623 .72936 L p .707 .577 .707 r
F P
0 g
s
.62623 .72936 m .63184 .67196 L .6002 .66895 L p .707 .577 .707 r
F P
0 g
s
.56909 .66574 m .56348 .72315 L .59459 .72635 L p .707 .577 .707 r
F P
0 g
s
.63184 .67196 m .62623 .72936 L .65532 .73188 L p .707 .577 .707 r
F P
0 g
s
.65532 .73188 m .66093 .67448 L .63184 .67196 L p .707 .577 .707 r
F P
0 g
s
.56348 .72315 m .56909 .66574 L .54157 .66265 L p .707 .577 .707 r
F P
0 g
s
.54157 .66265 m .53596 .72006 L .56348 .72315 L p .707 .577 .707 r
F P
0 g
s
.66093 .67448 m .65532 .73188 L .67901 .73367 L p .707 .577 .707 r
F P
0 g
s
.67901 .73367 m .68462 .67626 L .66093 .67448 L p .707 .577 .707 r
F P
0 g
s
.59594 .8088 m .59568 .77193 L .56451 .77011 L p .707 .577 .707 r
F P
0 g
s
.59568 .77193 m .59594 .8088 L .62777 .80778 L p .707 .577 .707 r
F P
0 g
s
.62777 .80778 m .62751 .7709 L .59568 .77193 L p .707 .577 .707 r
F P
0 g
s
.62751 .7709 m .62777 .80778 L .65715 .80401 L p .707 .577 .707 r
F P
0 g
s
.65715 .80401 m .6569 .76713 L .62751 .7709 L p .707 .577 .707 r
F P
0 g
s
.53596 .72006 m .54157 .66265 L .52032 .65999 L p .707 .577 .707 r
F P
0 g
s
.56477 .80699 m .56451 .77011 L .53705 .76563 L p .707 .577 .707 r
F P
0 g
s
.56451 .77011 m .56477 .80699 L .59594 .8088 L p .707 .577 .707 r
F P
0 g
s
.52032 .65999 m .51471 .71739 L .53596 .72006 L p .707 .577 .707 r
F P
0 g
s
.6569 .76713 m .65715 .80401 L .6812 .79786 L p .707 .577 .707 r
F P
0 g
s
.6812 .79786 m .68095 .76099 L .6569 .76713 L p .707 .577 .707 r
F P
0 g
s
.53705 .76563 m .53731 .80251 L .56477 .80699 L p .707 .577 .707 r
F P
0 g
s
.68462 .67626 m .67901 .73367 L .69497 .73454 L p .707 .577 .707 r
F P
0 g
s
.69497 .73454 m .70058 .67713 L .68462 .67626 L p .707 .577 .707 r
F P
0 g
s
.53731 .80251 m .53705 .76563 L .51599 .75893 L p .707 .577 .707 r
F P
0 g
s
.51471 .71739 m .52032 .65999 L .50744 .658 L p .707 .577 .707 r
F P
0 g
s
.50744 .658 m .50183 .71541 L .51471 .71739 L p .707 .577 .707 r
F P
0 g
s
.60087 .86237 m .60014 .84443 L .56897 .84302 L p .707 .577 .707 r
F P
0 g
s
.60014 .84443 m .60087 .86237 L .63267 .86018 L p .707 .577 .707 r
F P
0 g
s
.63267 .86018 m .63194 .84224 L .60014 .84443 L p .707 .577 .707 r
F P
0 g
s
.51599 .75893 m .51625 .79581 L .53731 .80251 L p .707 .577 .707 r
F P
0 g
s
.63194 .84224 m .63267 .86018 L .66201 .85461 L p .707 .577 .707 r
F P
0 g
s
.66201 .85461 m .66128 .83667 L .63194 .84224 L p .707 .577 .707 r
F P
0 g
s
.68095 .76099 m .6812 .79786 L .69757 .78995 L p .707 .577 .707 r
F P
0 g
s
.69757 .78995 m .69731 .75307 L .68095 .76099 L p .707 .577 .707 r
F P
0 g
s
.56897 .84302 m .5697 .86096 L .60087 .86237 L p .707 .577 .707 r
F P
0 g
s
.5697 .86096 m .56897 .84302 L .54151 .83814 L p .707 .577 .707 r
F P
0 g
s
.66128 .83667 m .66201 .85461 L .68601 .84619 L p .707 .577 .707 r
F P
0 g
s
.68601 .84619 m .68528 .82825 L .66128 .83667 L p .707 .577 .707 r
F P
0 g
s
.54151 .83814 m .54224 .85608 L .5697 .86096 L p .707 .577 .707 r
F P
0 g
s
.51625 .79581 m .51599 .75893 L .5034 .75065 L p .707 .577 .707 r
F P
0 g
s
.70058 .67713 m .69497 .73454 L .70164 .73441 L p .707 .577 .707 r
F P
0 g
s
.70164 .73441 m .70725 .677 L .70058 .67713 L p .707 .577 .707 r
F P
0 g
s
.54224 .85608 m .54151 .83814 L .52042 .83027 L p .707 .577 .707 r
F P
0 g
s
.5034 .75065 m .50366 .78753 L .51625 .79581 L p .707 .577 .707 r
F P
0 g
s
.50183 .71541 m .50744 .658 L .50417 .65689 L p .707 .577 .707 r
F P
0 g
s
.50417 .65689 m .49856 .7143 L .50183 .71541 L p .707 .577 .707 r
F P
0 g
s
.69731 .75307 m .69757 .78995 L .70465 .78104 L p .707 .577 .707 r
F P
0 g
s
.70465 .78104 m .7044 .74416 L .69731 .75307 L p .707 .577 .707 r
F P
0 g
s
.52042 .83027 m .52115 .84822 L .54224 .85608 L p .707 .577 .707 r
F P
0 g
s
.68528 .82825 m .68601 .84619 L .70232 .83576 L p .707 .577 .707 r
F P
0 g
s
.70232 .83576 m .70159 .81782 L .68528 .82825 L p .707 .577 .707 r
F P
0 g
s
.50366 .78753 m .5034 .75065 L .5005 .74162 L p .707 .577 .707 r
F P
0 g
s
.52115 .84822 m .52042 .83027 L .50779 .82019 L p .707 .577 .707 r
F P
0 g
s
.70725 .677 m .70164 .73441 L .69837 .7333 L p .707 .577 .707 r
F P
0 g
s
.69837 .7333 m .70399 .67589 L .70725 .677 L p .707 .577 .707 r
F P
0 g
s
.50779 .82019 m .50852 .83813 L .52115 .84822 L p .707 .577 .707 r
F P
0 g
s
.5005 .74162 m .50076 .7785 L .50366 .78753 L p .707 .577 .707 r
F P
0 g
s
.48316 .8187 m .4943 .31017 L .45029 .30709 L p .707 .577 .707 r
F P
0 g
s
.49856 .7143 m .50417 .65689 L .51085 .65677 L p .707 .577 .707 r
F P
0 g
s
.51085 .65677 m .50523 .71417 L .49856 .7143 L p .707 .577 .707 r
F P
0 g
s
.50076 .7785 m .5005 .74162 L .50758 .73271 L p .707 .577 .707 r
F P
0 g
s
.50852 .83813 m .50779 .82019 L .50483 .80888 L p .707 .577 .707 r
F P
0 g
s
.50483 .80888 m .50556 .82682 L .50852 .83813 L p .707 .577 .707 r
F P
0 g
s
.50758 .73271 m .50784 .76959 L .50076 .7785 L p .707 .577 .707 r
F P
0 g
s
.50523 .71417 m .51085 .65677 L .52681 .65764 L p .707 .577 .707 r
F P
0 g
s
.52681 .65764 m .52119 .71504 L .50523 .71417 L p .707 .577 .707 r
F P
0 g
s
.50784 .76959 m .50758 .73271 L .52395 .7248 L p .707 .577 .707 r
F P
0 g
s
.50556 .82682 m .50483 .80888 L .51186 .79745 L p .707 .577 .707 r
F P
0 g
s
.51186 .79745 m .51259 .81539 L .50556 .82682 L p .707 .577 .707 r
F P
0 g
s
.52395 .7248 m .52421 .76167 L .50784 .76959 L p .707 .577 .707 r
F P
0 g
s
.52119 .71504 m .52681 .65764 L .55049 .65942 L p .707 .577 .707 r
F P
0 g
s
.55049 .65942 m .54488 .71683 L .52119 .71504 L p .707 .577 .707 r
F P
0 g
s
.52421 .76167 m .52395 .7248 L .548 .71865 L p .707 .577 .707 r
F P
0 g
s
.51259 .81539 m .51186 .79745 L .52816 .78702 L p .707 .577 .707 r
F P
0 g
s
.52816 .78702 m .52889 .80496 L .51259 .81539 L p .707 .577 .707 r
F P
0 g
s
.548 .71865 m .54826 .75553 L .52421 .76167 L p .707 .577 .707 r
F P
0 g
s
.4943 .31017 m .48316 .8187 L .52809 .81874 L p .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .52816 .78702 L .54837 .77993 L p .707 .577 .707 r
F P
0 g
s
.57958 .66194 m .57397 .71934 L .54488 .71683 L p .707 .577 .707 r
F P
0 g
s
.57397 .71934 m .57718 .68644 L p .58392 .68219 L .707 .577 .707 r
F P
0 g
s
.58001 .71052 m .58392 .68219 L .61123 .66495 L .707 .577 .707 r
F
.57397 .71934 m .58392 .68219 L .58001 .71052 L F
.59453 .66336 m .61123 .66495 L p .57718 .68644 L F P
0 g
s
.64233 .66815 m .63672 .72556 L .60993 .7228 L p .707 .577 .707 r
F P
0 g
s
.60993 .7228 m .60562 .72235 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.61043 .71525 m .64233 .66815 L .60993 .7228 L .707 .577 .707 r
F
.60562 .72235 m .61123 .66495 L .61373 .66521 L p F P
0 g
s
.61373 .66521 m .64233 .66815 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.60562 .72235 m .61373 .66521 L .61043 .71525 L .707 .577 .707 r
F
.66986 .67124 m .66425 .72865 L .63672 .72556 L p F P
0 g
s
.63672 .72556 m .64233 .66815 L .66986 .67124 L p .707 .577 .707 r
F P
0 g
s
.64039 .71567 m .64065 .75255 L .60947 .75073 L p .707 .577 .707 r
F P
0 g
s
.60947 .75073 m .60922 .71386 L .64039 .71567 L p .707 .577 .707 r
F P
0 g
s
.64447 .77225 m .6452 .79019 L .61404 .78878 L p .707 .577 .707 r
F P
0 g
s
.61404 .78878 m .61331 .77084 L .64447 .77225 L p .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .64768 .28427 L .6383 .29303 L p .707 .577 .707 r
F P
0 g
s
.6383 .29303 m .6377 .29359 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .6383 .29303 L .63768 .30239 L .707 .577 .707 r
F
.62657 .80211 m .63654 .7928 L p .63768 .30239 L F P
0 g
s
.6377 .29359 m .63743 .30629 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63743 .30629 m .62657 .80211 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.61123 .66495 m .60562 .72235 L .57397 .71934 L p .707 .577 .707 r
F P
0 g
s
.57764 .75176 m .57738 .71488 L .60922 .71386 L p .707 .577 .707 r
F P
0 g
s
.60922 .71386 m .60947 .75073 L .57764 .75176 L p .707 .577 .707 r
F P
0 g
s
.58223 .79096 m .5815 .77302 L .61331 .77084 L p .707 .577 .707 r
F P
0 g
s
.61331 .77084 m .61404 .78878 L .58223 .79096 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .62657 .80211 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61462 .3015 m .61051 .48916 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61051 .48916 m .60348 .81003 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.54826 .75553 m .54805 .72519 L p .57738 .71488 L .707 .577 .707 r
F P
0 g
s
.54805 .72519 m .548 .71865 L .55349 .71795 L p .707 .577 .707 r
F P
0 g
s
.55349 .71795 m .57738 .71488 L p .54805 .72519 L .707 .577 .707 r
F P
0 g
s
.57718 .68644 m .57958 .66194 L .59453 .66336 L p .707 .577 .707 r
F P
0 g
s
.57738 .71488 m .57764 .75176 L .54826 .75553 L p .707 .577 .707 r
F P
0 g
s
.53941 .81793 m .56955 .81576 L p .56354 .71554 L .707 .577 .707 r
F P
0 g
s
.54837 .77993 m .55216 .7786 L p .54741 .78398 L .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .54837 .77993 L .54741 .78398 L .707 .577 .707 r
F
.55216 .7786 m .55289 .79654 L .52889 .80496 L p F P
0 g
s
.53923 .31021 m .52809 .81874 L .53941 .81793 L p .707 .577 .707 r
F P
0 g
s
.54488 .71683 m .54833 .68146 L p .57958 .66194 L .707 .577 .707 r
F P
0 g
s
.54833 .68146 m .55049 .65942 L .55645 .65993 L p .707 .577 .707 r
F P
0 g
s
.55645 .65993 m .57958 .66194 L p .54833 .68146 L .707 .577 .707 r
F P
0 g
s
.56955 .81576 m .58462 .81321 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.57398 .61346 m .5707 .76349 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.5707 .76349 m .56955 .81576 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.59236 .56472 m .5707 .76349 L .57342 .77321 L .707 .577 .707 r
F
.5815 .77302 m .58223 .79096 L .57858 .79166 L p F P
0 g
s
.56955 .81576 m .58069 .30723 L .53923 .31021 L p .707 .577 .707 r
F P
0 g
s
.57858 .79166 m .55289 .79654 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.57489 .77846 m .5815 .77302 L .57858 .79166 L .707 .577 .707 r
F
.55289 .79654 m .55216 .7786 L .57378 .77449 L p F P
0 g
s
.57378 .77449 m .5815 .77302 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.55289 .79654 m .57378 .77449 L .57489 .77846 L .707 .577 .707 r
F
.60348 .81003 m .59236 .56472 L .57342 .77321 L F
.58462 .81321 m .60348 .81003 L p .57342 .77321 L F P
0 g
s
.58069 .30723 m .57398 .61346 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.56354 .71554 m .53923 .31021 L .53941 .81793 L .707 .577 .707 r
F
.52809 .81874 m .53923 .31021 L .4943 .31017 L p F P
0 g
s
.70159 .81782 m .70232 .83576 L .70934 .82432 L p .707 .577 .707 r
F P
0 g
s
.70934 .82432 m .70861 .80638 L .70159 .81782 L p .707 .577 .707 r
F P
0 g
s
.7044 .74416 m .70465 .78104 L .70175 .772 L p .707 .577 .707 r
F P
0 g
s
.70175 .772 m .7015 .73513 L .7044 .74416 L p .707 .577 .707 r
F P
0 g
s
.43915 .81562 m .45029 .30709 L .41153 .30128 L p .707 .577 .707 r
F P
0 g
s
.45029 .30709 m .43915 .81562 L .48316 .8187 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .61462 .3015 L .58069 .30723 L p .707 .577 .707 r
F P
0 g
s
.70399 .67589 m .69837 .7333 L .68549 .73131 L p .707 .577 .707 r
F P
0 g
s
.68549 .73131 m .6911 .67391 L .70399 .67589 L p .707 .577 .707 r
F P
0 g
s
.25158 .68954 m .25719 .63213 L .22608 .62893 L p .707 .577 .707 r
F P
0 g
s
.25719 .63213 m .25158 .68954 L .28322 .69255 L p .707 .577 .707 r
F P
0 g
s
.28322 .69255 m .28883 .63514 L .25719 .63213 L p .707 .577 .707 r
F P
0 g
s
.22608 .62893 m .22047 .68633 L .25158 .68954 L p .707 .577 .707 r
F P
0 g
s
.28883 .63514 m .28322 .69255 L .31231 .69507 L p .707 .577 .707 r
F P
0 g
s
.31231 .69507 m .31792 .63766 L .28883 .63514 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70861 .80638 m .70934 .82432 L .70639 .81301 L p .707 .577 .707 r
F P
0 g
s
.70639 .81301 m .70566 .79507 L .70861 .80638 L p .707 .577 .707 r
F P
0 g
s
.40039 .80981 m .41153 .30128 L .38179 .29332 L p .707 .577 .707 r
F P
0 g
s
.41153 .30128 m .40039 .80981 L .43915 .81562 L p .707 .577 .707 r
F P
0 g
s
.7015 .73513 m .70175 .772 L .68916 .76373 L p .707 .577 .707 r
F P
0 g
s
.68916 .76373 m .6889 .72685 L .7015 .73513 L p .707 .577 .707 r
F P
0 g
s
.22047 .68633 m .22608 .62893 L .19856 .62584 L p .707 .577 .707 r
F P
0 g
s
.19856 .62584 m .19295 .68325 L .22047 .68633 L p .707 .577 .707 r
F P
0 g
s
.31792 .63766 m .31231 .69507 L .336 .69685 L p .707 .577 .707 r
F P
0 g
s
.336 .69685 m .34161 .63944 L .31792 .63766 L p .707 .577 .707 r
F P
0 g
s
.25293 .77199 m .25267 .73511 L .2215 .7333 L p .707 .577 .707 r
F P
0 g
s
.25267 .73511 m .25293 .77199 L .28476 .77096 L p .707 .577 .707 r
F P
0 g
s
.28476 .77096 m .28451 .73408 L .25267 .73511 L p .707 .577 .707 r
F P
0 g
s
.28451 .73408 m .28476 .77096 L .31414 .76719 L p .707 .577 .707 r
F P
0 g
s
.31414 .76719 m .31389 .73031 L .28451 .73408 L p .707 .577 .707 r
F P
0 g
s
.19295 .68325 m .19856 .62584 L .17731 .62317 L p .707 .577 .707 r
F P
0 g
s
.22176 .77017 m .2215 .7333 L .19404 .72882 L p .707 .577 .707 r
F P
0 g
s
.2215 .7333 m .22176 .77017 L .25293 .77199 L p .707 .577 .707 r
F P
0 g
s
.62657 .80211 m .6377 .29359 L .61462 .3015 L p .707 .577 .707 r
F P
0 g
s
.17731 .62317 m .1717 .68058 L .19295 .68325 L p .707 .577 .707 r
F P
0 g
s
.6911 .67391 m .68549 .73131 L .66425 .72865 L p .707 .577 .707 r
F P
0 g
s
.66425 .72865 m .66986 .67124 L .6911 .67391 L p .707 .577 .707 r
F P
0 g
s
.31389 .73031 m .31414 .76719 L .3382 .76105 L p .707 .577 .707 r
F P
0 g
s
.3382 .76105 m .33794 .72417 L .31389 .73031 L p .707 .577 .707 r
F P
0 g
s
.70566 .79507 m .70639 .81301 L .69375 .80293 L p .707 .577 .707 r
F P
0 g
s
.69375 .80293 m .69302 .78499 L .70566 .79507 L p .707 .577 .707 r
F P
0 g
s
.6889 .72685 m .68916 .76373 L .6681 .75702 L p .707 .577 .707 r
F P
0 g
s
.6681 .75702 m .66785 .72015 L .6889 .72685 L p .707 .577 .707 r
F P
0 g
s
.19404 .72882 m .1943 .7657 L .22176 .77017 L p .707 .577 .707 r
F P
0 g
s
.34161 .63944 m .336 .69685 L .35196 .69772 L p .707 .577 .707 r
F P
0 g
s
.35196 .69772 m .35757 .64031 L .34161 .63944 L p .707 .577 .707 r
F P
0 g
s
.37065 .80184 m .38179 .29332 L .36399 .28397 L p .707 .577 .707 r
F P
0 g
s
.38179 .29332 m .37065 .80184 L .40039 .80981 L p .707 .577 .707 r
F P
0 g
s
.1943 .7657 m .19404 .72882 L .17298 .72211 L p .707 .577 .707 r
F P
0 g
s
.1717 .68058 m .17731 .62317 L .16443 .62119 L p .707 .577 .707 r
F P
0 g
s
.16443 .62119 m .15882 .67859 L .1717 .68058 L p .707 .577 .707 r
F P
0 g
s
.25786 .82556 m .25713 .80762 L .22597 .8062 L p .707 .577 .707 r
F P
0 g
s
.25713 .80762 m .25786 .82556 L .28967 .82337 L p .707 .577 .707 r
F P
0 g
s
.28967 .82337 m .28894 .80543 L .25713 .80762 L p .707 .577 .707 r
F P
0 g
s
.17298 .72211 m .17324 .75899 L .1943 .7657 L p .707 .577 .707 r
F P
0 g
s
.28894 .80543 m .28967 .82337 L .319 .81779 L p .707 .577 .707 r
F P
0 g
s
.319 .81779 m .31827 .79985 L .28894 .80543 L p .707 .577 .707 r
F P
0 g
s
.33794 .72417 m .3382 .76105 L .35456 .75313 L p .707 .577 .707 r
F P
0 g
s
.35456 .75313 m .35431 .71626 L .33794 .72417 L p .707 .577 .707 r
F P
0 g
s
.22597 .8062 m .2267 .82414 L .25786 .82556 L p .707 .577 .707 r
F P
0 g
s
.2267 .82414 m .22597 .8062 L .1985 .80132 L p .707 .577 .707 r
F P
0 g
s
.66785 .72015 m .6681 .75702 L .64065 .75255 L p .707 .577 .707 r
F P
0 g
s
.64065 .75255 m .64039 .71567 L .66785 .72015 L p .707 .577 .707 r
F P
0 g
s
.69302 .78499 m .69375 .80293 L .67267 .79507 L p .707 .577 .707 r
F P
0 g
s
.67267 .79507 m .67194 .77713 L .69302 .78499 L p .707 .577 .707 r
F P
0 g
s
.31827 .79985 m .319 .81779 L .343 .80938 L p .707 .577 .707 r
F P
0 g
s
.343 .80938 m .34227 .79144 L .31827 .79985 L p .707 .577 .707 r
F P
0 g
s
.1985 .80132 m .19923 .81926 L .2267 .82414 L p .707 .577 .707 r
F P
0 g
s
.17324 .75899 m .17298 .72211 L .16039 .71384 L p .707 .577 .707 r
F P
0 g
s
.35757 .64031 m .35196 .69772 L .35863 .69759 L p .707 .577 .707 r
F P
0 g
s
.35863 .69759 m .36424 .64019 L .35757 .64031 L p .707 .577 .707 r
F P
0 g
s
.19923 .81926 m .1985 .80132 L .17741 .79346 L p .707 .577 .707 r
F P
0 g
s
.16039 .71384 m .16065 .75072 L .17324 .75899 L p .707 .577 .707 r
F P
0 g
s
.15882 .67859 m .16443 .62119 L .16116 .62008 L p .707 .577 .707 r
F P
0 g
s
.16116 .62008 m .15555 .67748 L .15882 .67859 L p .707 .577 .707 r
F P
0 g
s
.35431 .71626 m .35456 .75313 L .36164 .74422 L p .707 .577 .707 r
F P
0 g
s
.36164 .74422 m .36139 .70735 L .35431 .71626 L p .707 .577 .707 r
F P
0 g
s
.17741 .79346 m .17814 .8114 L .19923 .81926 L p .707 .577 .707 r
F P
0 g
s
.35931 .79894 m .35858 .781 L .34227 .79144 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .34248 .6945 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36098 .63908 m .35882 .66112 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.35882 .66112 m .35537 .69648 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35988 .27416 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .34809 .63709 L .35833 .63867 L p .707 .577 .707 r
F P
0 g
s
.35833 .63867 m .36098 .63908 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .35833 .63867 L .3585 .64648 L .707 .577 .707 r
F
.35849 .69831 m .35875 .73519 L .34615 .72691 L p F P
0 g
s
.36424 .64019 m .35863 .69759 L .35537 .69648 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .36098 .63908 L .36424 .64019 L p .707 .577 .707 r
F P
0 g
s
.34615 .72691 m .34589 .69004 L .35849 .69831 L p .707 .577 .707 r
F P
0 g
s
.35102 .78814 m .35285 .7925 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35728 .5902 L .35624 .54229 L .707 .577 .707 r
F
.35285 .7925 m .354 .74023 L p .35344 .74923 L F P
0 g
s
.354 .74023 m .35728 .5902 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35001 .74818 L .35334 .75083 L p .707 .577 .707 r
F P
0 g
s
.35858 .781 m .35931 .79894 L .36633 .78751 L p .707 .577 .707 r
F P
0 g
s
.36633 .78751 m .3656 .76957 L .35858 .781 L p .707 .577 .707 r
F P
0 g
s
.36139 .70735 m .36164 .74422 L .35875 .73519 L p .707 .577 .707 r
F P
0 g
s
.35875 .73519 m .35849 .69831 L .36139 .70735 L p .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35589 .65388 L p .37065 .80184 L .707 .577 .707 r
F P
0 g
s
.35589 .65388 m .35285 .7925 L .36579 .79929 L p .707 .577 .707 r
F P
0 g
s
.3656 .76957 m .36633 .78751 L .36451 .78053 L p .707 .577 .707 r
F P
0 g
s
.36407 .77413 m .3656 .76957 L .36451 .78053 L .707 .577 .707 r
F
.36338 .7762 m .36265 .75826 L .3656 .76957 L p F P
0 g
s
.36579 .79929 m .37065 .80184 L p .35589 .65388 L .707 .577 .707 r
F P
0 g
s
.36451 .78053 m .36338 .7762 L p .36407 .77413 L .707 .577 .707 r
F P
0 g
s
.35334 .75083 m .36265 .75826 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35334 .75083 L .35246 .76499 L .707 .577 .707 r
F
.36265 .75826 m .36338 .7762 L .35231 .76737 L p F P
0 g
s
.35231 .76737 m .35074 .76612 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35246 .76499 m .36265 .75826 L .35231 .76737 L .707 .577 .707 r
F
.35001 .74818 m .35074 .76612 L .32966 .75826 L p F P
0 g
s
.32966 .75826 m .32893 .74031 L .35001 .74818 L p .707 .577 .707 r
F P
0 g
s
.34874 .78268 m .35102 .78814 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35624 .54229 L .35102 .78814 L .707 .577 .707 r
F
.35988 .27416 m .35513 .49095 L p .35624 .54229 L F P
0 g
s
.35513 .49095 m .34874 .78268 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35728 .5902 m .36399 .28397 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34227 .79144 m .343 .80938 L .35931 .79894 L p .707 .577 .707 r
F P
0 g
s
.67194 .77713 m .67267 .79507 L .6452 .79019 L p .707 .577 .707 r
F P
0 g
s
.6452 .79019 m .64447 .77225 L .67194 .77713 L p .707 .577 .707 r
F P
0 g
s
.16065 .75072 m .16039 .71384 L .15749 .7048 L p .707 .577 .707 r
F P
0 g
s
.17814 .8114 m .17741 .79346 L .16478 .78338 L p .707 .577 .707 r
F P
0 g
s
.16478 .78338 m .16551 .80132 L .17814 .8114 L p .707 .577 .707 r
F P
0 g
s
.15749 .7048 m .15775 .74168 L .16065 .75072 L p .707 .577 .707 r
F P
0 g
s
.64768 .28427 m .63654 .7928 L .63242 .78298 L p .707 .577 .707 r
F P
0 g
s
.63242 .78298 m .64356 .27445 L .64768 .28427 L p .707 .577 .707 r
F P
0 g
s
.15555 .67748 m .16116 .62008 L .16784 .61995 L p .707 .577 .707 r
F P
0 g
s
.16784 .61995 m .16223 .67736 L .15555 .67748 L p .707 .577 .707 r
F P
0 g
s
.15775 .74168 m .15749 .7048 L .16457 .69589 L p .707 .577 .707 r
F P
0 g
s
.16551 .80132 m .16478 .78338 L .16183 .77207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34874 .78268 m .35988 .27416 L .36985 .26484 L p .707 .577 .707 r
F P
0 g
s
.16183 .77207 m .16256 .79001 L .16551 .80132 L p .707 .577 .707 r
F P
0 g
s
.16457 .69589 m .16483 .73277 L .15775 .74168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16223 .67736 m .16784 .61995 L .1838 .62082 L p .707 .577 .707 r
F P
0 g
s
.1838 .62082 m .17818 .67823 L .16223 .67736 L p .707 .577 .707 r
F P
0 g
s
.64356 .27445 m .63242 .78298 L .61463 .77364 L p .707 .577 .707 r
F P
0 g
s
.61463 .77364 m .62577 .26511 L .64356 .27445 L p .707 .577 .707 r
F P
0 g
s
.16483 .73277 m .16457 .69589 L .18094 .68798 L p .707 .577 .707 r
F P
0 g
s
.16256 .79001 m .16183 .77207 L .16885 .76064 L p .707 .577 .707 r
F P
0 g
s
.34809 .63709 m .34248 .6945 L .32124 .69183 L p .707 .577 .707 r
F P
0 g
s
.32124 .69183 m .32685 .63442 L .34809 .63709 L p .707 .577 .707 r
F P
0 g
s
.16885 .76064 m .16958 .77858 L .16256 .79001 L p .707 .577 .707 r
F P
0 g
s
.18094 .68798 m .1812 .72486 L .16483 .73277 L p .707 .577 .707 r
F P
0 g
s
.35871 .77337 m .36985 .26484 L .39293 .25693 L p .707 .577 .707 r
F P
0 g
s
.36985 .26484 m .35871 .77337 L .34874 .78268 L p .707 .577 .707 r
F P
0 g
s
.17818 .67823 m .1838 .62082 L .20748 .6226 L p .707 .577 .707 r
F P
0 g
s
.34589 .69004 m .34615 .72691 L .32509 .72021 L p .707 .577 .707 r
F P
0 g
s
.32509 .72021 m .32484 .68333 L .34589 .69004 L p .707 .577 .707 r
F P
0 g
s
.20748 .6226 m .20187 .68001 L .17818 .67823 L p .707 .577 .707 r
F P
0 g
s
.1812 .72486 m .18094 .68798 L .20499 .68184 L p .707 .577 .707 r
F P
0 g
s
.16958 .77858 m .16885 .76064 L .18515 .7502 L p .707 .577 .707 r
F P
0 g
s
.32685 .63442 m .32124 .69183 L .29371 .68874 L p .707 .577 .707 r
F P
0 g
s
.29371 .68874 m .29932 .63134 L .32685 .63442 L p .707 .577 .707 r
F P
0 g
s
.18515 .7502 m .18588 .76814 L .16958 .77858 L p .707 .577 .707 r
F P
0 g
s
.20187 .68001 m .20748 .6226 L .23657 .62512 L p .707 .577 .707 r
F P
0 g
s
.20499 .68184 m .20525 .71871 L .1812 .72486 L p .707 .577 .707 r
F P
0 g
s
.23657 .62512 m .23096 .68253 L .20187 .68001 L p .707 .577 .707 r
F P
0 g
s
.62577 .26511 m .61463 .77364 L .58489 .76567 L p .707 .577 .707 r
F P
0 g
s
.58489 .76567 m .59603 .25714 L .62577 .26511 L p .707 .577 .707 r
F P
0 g
s
.32484 .68333 m .32509 .72021 L .29764 .71573 L p .707 .577 .707 r
F P
0 g
s
.29764 .71573 m .29738 .67885 L .32484 .68333 L p .707 .577 .707 r
F P
0 g
s
.29932 .63134 m .29371 .68874 L .26261 .68554 L p .707 .577 .707 r
F P
0 g
s
.26261 .68554 m .26822 .62813 L .29932 .63134 L p .707 .577 .707 r
F P
0 g
s
.73179 .63171 m .7374 .5743 L .70629 .57109 L p .707 .577 .707 r
F P
0 g
s
.7374 .5743 m .73179 .63171 L .76344 .63472 L p .707 .577 .707 r
F P
0 g
s
.76344 .63472 m .76905 .57731 L .7374 .5743 L p .707 .577 .707 r
F P
0 g
s
.23096 .68253 m .23417 .64962 L p .26822 .62813 L .707 .577 .707 r
F P
0 g
s
.23417 .64962 m .23657 .62512 L .25152 .62654 L p .707 .577 .707 r
F P
0 g
s
.25152 .62654 m .26822 .62813 L p .23417 .64962 L .707 .577 .707 r
F P
0 g
s
.26822 .62813 m .26261 .68554 L .23096 .68253 L p .707 .577 .707 r
F P
0 g
s
.20525 .71871 m .20504 .68838 L p .23437 .67807 L .707 .577 .707 r
F P
0 g
s
.20504 .68838 m .20499 .68184 L .21048 .68113 L p .707 .577 .707 r
F P
0 g
s
.21048 .68113 m .23437 .67807 L p .20504 .68838 L .707 .577 .707 r
F P
0 g
s
.70629 .57109 m .70068 .6285 L .73179 .63171 L p .707 .577 .707 r
F P
0 g
s
.76905 .57731 m .76344 .63472 L .79253 .63724 L p .707 .577 .707 r
F P
0 g
s
.79253 .63724 m .79814 .57983 L .76905 .57731 L p .707 .577 .707 r
F P
0 g
s
.39293 .25693 m .38179 .76545 L .35871 .77337 L p .707 .577 .707 r
F P
0 g
s
.38179 .76545 m .39293 .25693 L .42686 .2512 L p .707 .577 .707 r
F P
0 g
s
.70068 .6285 m .70629 .57109 L .67877 .56801 L p .707 .577 .707 r
F P
0 g
s
.29738 .67885 m .29764 .71573 L .26646 .71392 L p .707 .577 .707 r
F P
0 g
s
.26646 .71392 m .26621 .67704 L .29738 .67885 L p .707 .577 .707 r
F P
0 g
s
.67877 .56801 m .67316 .62541 L .70068 .6285 L p .707 .577 .707 r
F P
0 g
s
.18588 .76814 m .18515 .7502 L .20915 .74178 L p .707 .577 .707 r
F P
0 g
s
.23437 .67807 m .23463 .71494 L .20525 .71871 L p .707 .577 .707 r
F P
0 g
s
.23463 .71494 m .23437 .67807 L .26621 .67704 L p .707 .577 .707 r
F P
0 g
s
.26621 .67704 m .26646 .71392 L .23463 .71494 L p .707 .577 .707 r
F P
0 g
s
.20915 .74178 m .20988 .75972 L .18588 .76814 L p .707 .577 .707 r
F P
0 g
s
.79814 .57983 m .79253 .63724 L .81621 .63902 L p .707 .577 .707 r
F P
0 g
s
.81621 .63902 m .82182 .58161 L .79814 .57983 L p .707 .577 .707 r
F P
0 g
s
.32893 .74031 m .32966 .75826 L .30219 .75338 L p .707 .577 .707 r
F P
0 g
s
.30219 .75338 m .30146 .73544 L .32893 .74031 L p .707 .577 .707 r
F P
0 g
s
.73314 .72249 m .73288 .68562 L .70171 .6838 L p .707 .577 .707 r
F P
0 g
s
.73288 .68562 m .73314 .72249 L .76498 .72146 L p .707 .577 .707 r
F P
0 g
s
.76498 .72146 m .76472 .68459 L .73288 .68562 L p .707 .577 .707 r
F P
0 g
s
.76472 .68459 m .76498 .72146 L .79436 .71769 L p .707 .577 .707 r
F P
0 g
s
.79436 .71769 m .7941 .68082 L .76472 .68459 L p .707 .577 .707 r
F P
0 g
s
.67316 .62541 m .67877 .56801 L .65753 .56534 L p .707 .577 .707 r
F P
0 g
s
.65753 .56534 m .65192 .62275 L .67316 .62541 L p .707 .577 .707 r
F P
0 g
s
.59603 .25714 m .58489 .76567 L .54612 .75986 L p .707 .577 .707 r
F P
0 g
s
.54612 .75986 m .55726 .25133 L .59603 .25714 L p .707 .577 .707 r
F P
0 g
s
.70197 .72068 m .70171 .6838 L .67425 .67932 L p .707 .577 .707 r
F P
0 g
s
.70171 .6838 m .70197 .72068 L .73314 .72249 L p .707 .577 .707 r
F P
0 g
s
.20988 .75972 m .20915 .74178 L .23849 .73621 L p .707 .577 .707 r
F P
0 g
s
.7941 .68082 m .79436 .71769 L .81841 .71155 L p .707 .577 .707 r
F P
0 g
s
.81841 .71155 m .81815 .67467 L .7941 .68082 L p .707 .577 .707 r
F P
0 g
s
.30146 .73544 m .30219 .75338 L .27103 .75196 L p .707 .577 .707 r
F P
0 g
s
.27103 .75196 m .2703 .73402 L .30146 .73544 L p .707 .577 .707 r
F P
0 g
s
.23849 .73621 m .23922 .75415 L .20988 .75972 L p .707 .577 .707 r
F P
0 g
s
.41572 .75972 m .42686 .2512 L .46832 .24821 L p .707 .577 .707 r
F P
0 g
s
.42686 .2512 m .41572 .75972 L .38179 .76545 L p .707 .577 .707 r
F P
0 g
s
.67425 .67932 m .67451 .7162 L .70197 .72068 L p .707 .577 .707 r
F P
0 g
s
.82182 .58161 m .81621 .63902 L .83217 .63989 L p .707 .577 .707 r
F P
0 g
s
.83217 .63989 m .83778 .58248 L .82182 .58161 L p .707 .577 .707 r
F P
0 g
s
.23922 .75415 m .23849 .73621 L .2703 .73402 L p .707 .577 .707 r
F P
0 g
s
.2703 .73402 m .27103 .75196 L .23922 .75415 L p .707 .577 .707 r
F P
0 g
s
.67451 .7162 m .67425 .67932 L .6532 .67262 L p .707 .577 .707 r
F P
0 g
s
.65192 .62275 m .65753 .56534 L .64464 .56335 L p .707 .577 .707 r
F P
0 g
s
.73807 .76166 m .73734 .74372 L .70618 .7423 L p .707 .577 .707 r
F P
0 g
s
.73734 .74372 m .73807 .76166 L .76988 .75947 L p .707 .577 .707 r
F P
0 g
s
.76988 .75947 m .76915 .74153 L .73734 .74372 L p .707 .577 .707 r
F P
0 g
s
.55726 .25133 m .54612 .75986 L .50212 .75678 L p .707 .577 .707 r
F P
0 g
s
.50212 .75678 m .51325 .24826 L .55726 .25133 L p .707 .577 .707 r
F P
0 g
s
.64464 .56335 m .63903 .62076 L .65192 .62275 L p .707 .577 .707 r
F P
0 g
s
.76915 .74153 m .76988 .75947 L .79922 .75389 L p .707 .577 .707 r
F P
0 g
s
.79922 .75389 m .79849 .73595 L .76915 .74153 L p .707 .577 .707 r
F P
0 g
s
.45718 .75674 m .46832 .24821 L .51325 .24826 L p .707 .577 .707 r
F P
0 g
s
.46832 .24821 m .45718 .75674 L .41572 .75972 L p .707 .577 .707 r
F P
0 g
s
.6532 .67262 m .65345 .70949 L .67451 .7162 L p .707 .577 .707 r
F P
0 g
s
.70618 .7423 m .70691 .76024 L .73807 .76166 L p .707 .577 .707 r
F P
0 g
s
.70691 .76024 m .70618 .7423 L .67871 .73742 L p .707 .577 .707 r
F P
0 g
s
.81815 .67467 m .81841 .71155 L .83478 .70364 L p .707 .577 .707 r
F P
0 g
s
.83478 .70364 m .83452 .66676 L .81815 .67467 L p .707 .577 .707 r
F P
0 g
s
.51325 .24826 m .50212 .75678 L .45718 .75674 L p .707 .577 .707 r
F P
0 g
s
.79849 .73595 m .79922 .75389 L .82321 .74548 L p .707 .577 .707 r
F P
0 g
s
.82321 .74548 m .82248 .72754 L .79849 .73595 L p .707 .577 .707 r
F P
0 g
s
.67871 .73742 m .67944 .75536 L .70691 .76024 L p .707 .577 .707 r
F P
0 g
s
.65345 .70949 m .6532 .67262 L .6406 .66434 L p .707 .577 .707 r
F P
0 g
s
.83778 .58248 m .83217 .63989 L .83884 .63976 L p .707 .577 .707 r
F P
0 g
s
.83884 .63976 m .84446 .58236 L .83778 .58248 L p .707 .577 .707 r
F P
0 g
s
.67944 .75536 m .67871 .73742 L .65763 .72956 L p .707 .577 .707 r
F P
0 g
s
.63903 .62076 m .64464 .56335 L .64138 .56224 L p .707 .577 .707 r
F P
0 g
s
.6406 .66434 m .64086 .70122 L .65345 .70949 L p .707 .577 .707 r
F P
0 g
s
.65763 .72956 m .65836 .7475 L .67944 .75536 L p .707 .577 .707 r
F P
0 g
s
.64138 .56224 m .63576 .61965 L .63903 .62076 L p .707 .577 .707 r
F P
0 g
s
.82248 .72754 m .82321 .74548 L .83952 .73504 L p .707 .577 .707 r
F P
0 g
s
.83952 .73504 m .83879 .7171 L .82248 .72754 L p .707 .577 .707 r
F P
0 g
s
.83452 .66676 m .83478 .70364 L .84186 .69473 L p .707 .577 .707 r
F P
0 g
s
.84186 .69473 m .8416 .65785 L .83452 .66676 L p .707 .577 .707 r
F P
0 g
s
.65836 .7475 m .65763 .72956 L .64499 .71948 L p .707 .577 .707 r
F P
0 g
s
.64086 .70122 m .6406 .66434 L .63771 .65531 L p .707 .577 .707 r
F P
0 g
s
.84446 .58236 m .83884 .63976 L .83558 .63865 L p .707 .577 .707 r
F P
0 g
s
.83558 .63865 m .84119 .58125 L .84446 .58236 L p .707 .577 .707 r
F P
0 g
s
.64499 .71948 m .64572 .73742 L .65836 .7475 L p .707 .577 .707 r
F P
0 g
s
.63771 .65531 m .63796 .69218 L .64086 .70122 L p .707 .577 .707 r
F P
0 g
s
.83879 .7171 m .83952 .73504 L .84654 .72361 L p .707 .577 .707 r
F P
0 g
s
.84654 .72361 m .84581 .70567 L .83879 .7171 L p .707 .577 .707 r
F P
0 g
s
.63576 .61965 m .64138 .56224 L .64805 .56212 L p .707 .577 .707 r
F P
0 g
s
.64805 .56212 m .64244 .61952 L .63576 .61965 L p .707 .577 .707 r
F P
0 g
s
.8416 .65785 m .84186 .69473 L .83896 .68569 L p .707 .577 .707 r
F P
0 g
s
.83896 .68569 m .8387 .64882 L .8416 .65785 L p .707 .577 .707 r
F P
0 g
s
.64572 .73742 m .64499 .71948 L .64204 .70817 L p .707 .577 .707 r
F P
0 g
s
.63796 .69218 m .63771 .65531 L .64479 .6464 L p .707 .577 .707 r
F P
0 g
s
.64204 .70817 m .64277 .72611 L .64572 .73742 L p .707 .577 .707 r
F P
0 g
s
.84119 .58125 m .83558 .63865 L .82269 .63667 L p .707 .577 .707 r
F P
0 g
s
.82269 .63667 m .8283 .57926 L .84119 .58125 L p .707 .577 .707 r
F P
0 g
s
.38878 .59489 m .39439 .53748 L .36328 .53428 L p .707 .577 .707 r
F P
0 g
s
.39439 .53748 m .38878 .59489 L .42043 .5979 L p .707 .577 .707 r
F P
0 g
s
.42043 .5979 m .42604 .54049 L .39439 .53748 L p .707 .577 .707 r
F P
0 g
s
.36328 .53428 m .35767 .59169 L .38878 .59489 L p .707 .577 .707 r
F P
0 g
s
.84581 .70567 m .84654 .72361 L .84359 .7123 L p .707 .577 .707 r
F P
0 g
s
.84359 .7123 m .84286 .69436 L .84581 .70567 L p .707 .577 .707 r
F P
0 g
s
.64479 .6464 m .64504 .68327 L .63796 .69218 L p .707 .577 .707 r
F P
0 g
s
.42604 .54049 m .42043 .5979 L .44952 .60042 L p .707 .577 .707 r
F P
0 g
s
.44952 .60042 m .45513 .54301 L .42604 .54049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64244 .61952 m .64805 .56212 L .66401 .56299 L p .707 .577 .707 r
F P
0 g
s
.35767 .59169 m .36328 .53428 L .33576 .53119 L p .707 .577 .707 r
F P
0 g
s
.66401 .56299 m .6584 .6204 L .64244 .61952 L p .707 .577 .707 r
F P
0 g
s
.33576 .53119 m .33015 .5886 L .35767 .59169 L p .707 .577 .707 r
F P
0 g
s
.8387 .64882 m .83896 .68569 L .82637 .67742 L p .707 .577 .707 r
F P
0 g
s
.82637 .67742 m .82611 .64054 L .8387 .64882 L p .707 .577 .707 r
F P
0 g
s
.45513 .54301 m .44952 .60042 L .4732 .6022 L p .707 .577 .707 r
F P
0 g
s
.4732 .6022 m .47881 .5448 L .45513 .54301 L p .707 .577 .707 r
F P
0 g
s
.64277 .72611 m .64204 .70817 L .64906 .69674 L p .707 .577 .707 r
F P
0 g
s
.39013 .68568 m .38987 .6488 L .3587 .64699 L p .707 .577 .707 r
F P
0 g
s
.38987 .6488 m .39013 .68568 L .42197 .68465 L p .707 .577 .707 r
F P
0 g
s
.42197 .68465 m .42171 .64777 L .38987 .6488 L p .707 .577 .707 r
F P
0 g
s
.64504 .68327 m .64479 .6464 L .66115 .63848 L p .707 .577 .707 r
F P
0 g
s
.42171 .64777 m .42197 .68465 L .45135 .68088 L p .707 .577 .707 r
F P
0 g
s
.45135 .68088 m .45109 .644 L .42171 .64777 L p .707 .577 .707 r
F P
0 g
s
.33015 .5886 m .33576 .53119 L .31452 .52852 L p .707 .577 .707 r
F P
0 g
s
.31452 .52852 m .30891 .58593 L .33015 .5886 L p .707 .577 .707 r
F P
0 g
s
.64906 .69674 m .64979 .71468 L .64277 .72611 L p .707 .577 .707 r
F P
0 g
s
.8283 .57926 m .82269 .63667 L .80145 .634 L p .707 .577 .707 r
F P
0 g
s
.80145 .634 m .80706 .57659 L .8283 .57926 L p .707 .577 .707 r
F P
0 g
s
.35896 .68386 m .3587 .64699 L .33124 .64251 L p .707 .577 .707 r
F P
0 g
s
.3587 .64699 m .35896 .68386 L .39013 .68568 L p .707 .577 .707 r
F P
0 g
s
.84286 .69436 m .84359 .7123 L .83096 .70222 L p .707 .577 .707 r
F P
0 g
s
.83096 .70222 m .83023 .68428 L .84286 .69436 L p .707 .577 .707 r
F P
0 g
s
.66115 .63848 m .66141 .67536 L .64504 .68327 L p .707 .577 .707 r
F P
0 g
s
.45109 .644 m .45135 .68088 L .4754 .67474 L p .707 .577 .707 r
F P
0 g
s
.4754 .67474 m .47514 .63786 L .45109 .644 L p .707 .577 .707 r
F P
0 g
s
.6584 .6204 m .66401 .56299 L .68769 .56477 L p .707 .577 .707 r
F P
0 g
s
.68769 .56477 m .68208 .62218 L .6584 .6204 L p .707 .577 .707 r
F P
0 g
s
.82611 .64054 m .82637 .67742 L .80531 .67071 L p .707 .577 .707 r
F P
0 g
s
.80531 .67071 m .80505 .63384 L .82611 .64054 L p .707 .577 .707 r
F P
0 g
s
.33124 .64251 m .3315 .67938 L .35896 .68386 L p .707 .577 .707 r
F P
0 g
s
.47881 .5448 m .4732 .6022 L .48916 .60307 L p .707 .577 .707 r
F P
0 g
s
.48916 .60307 m .49477 .54567 L .47881 .5448 L p .707 .577 .707 r
F P
0 g
s
.3315 .67938 m .33124 .64251 L .31019 .6358 L p .707 .577 .707 r
F P
0 g
s
.30891 .58593 m .31452 .52852 L .30163 .52654 L p .707 .577 .707 r
F P
0 g
s
.64979 .71468 m .64906 .69674 L .66537 .6863 L p .707 .577 .707 r
F P
0 g
s
.39506 .72484 m .39433 .7069 L .36317 .70549 L p .707 .577 .707 r
F P
0 g
s
.39433 .7069 m .39506 .72484 L .42687 .72265 L p .707 .577 .707 r
F P
0 g
s
.42687 .72265 m .42614 .70471 L .39433 .7069 L p .707 .577 .707 r
F P
0 g
s
.66141 .67536 m .66115 .63848 L .68521 .63234 L p .707 .577 .707 r
F P
0 g
s
.30163 .52654 m .29602 .58395 L .30891 .58593 L p .707 .577 .707 r
F P
0 g
s
.80706 .57659 m .80145 .634 L .77393 .63091 L p .707 .577 .707 r
F P
0 g
s
.77393 .63091 m .77954 .57351 L .80706 .57659 L p .707 .577 .707 r
F P
0 g
s
.42614 .70471 m .42687 .72265 L .45621 .71708 L p .707 .577 .707 r
F P
0 g
s
.45621 .71708 m .45548 .69914 L .42614 .70471 L p .707 .577 .707 r
F P
0 g
s
.31019 .6358 m .31044 .67268 L .3315 .67938 L p .707 .577 .707 r
F P
0 g
s
.66537 .6863 m .6661 .70424 L .64979 .71468 L p .707 .577 .707 r
F P
0 g
s
.36317 .70549 m .3639 .72343 L .39506 .72484 L p .707 .577 .707 r
F P
0 g
s
.3639 .72343 m .36317 .70549 L .3357 .70061 L p .707 .577 .707 r
F P
0 g
s
.47514 .63786 m .4754 .67474 L .49177 .66682 L p .707 .577 .707 r
F P
0 g
s
.49177 .66682 m .49151 .62995 L .47514 .63786 L p .707 .577 .707 r
F P
0 g
s
.68208 .62218 m .68769 .56477 L .71678 .56729 L p .707 .577 .707 r
F P
0 g
s
.71678 .56729 m .71117 .6247 L .68208 .62218 L p .707 .577 .707 r
F P
0 g
s
.68521 .63234 m .68546 .66922 L .66141 .67536 L p .707 .577 .707 r
F P
0 g
s
.83023 .68428 m .83096 .70222 L .80987 .69435 L p .707 .577 .707 r
F P
0 g
s
.80987 .69435 m .80914 .67641 L .83023 .68428 L p .707 .577 .707 r
F P
0 g
s
.80505 .63384 m .80531 .67071 L .77785 .66623 L p .707 .577 .707 r
F P
0 g
s
.77785 .66623 m .77759 .62936 L .80505 .63384 L p .707 .577 .707 r
F P
0 g
s
.45548 .69914 m .45621 .71708 L .4802 .70866 L p .707 .577 .707 r
F P
0 g
s
.4802 .70866 m .47947 .69072 L .45548 .69914 L p .707 .577 .707 r
F P
0 g
s
.3357 .70061 m .33643 .71855 L .3639 .72343 L p .707 .577 .707 r
F P
0 g
s
.31044 .67268 m .31019 .6358 L .29759 .62753 L p .707 .577 .707 r
F P
0 g
s
.77954 .57351 m .77393 .63091 L .74282 .62771 L p .707 .577 .707 r
F P
0 g
s
.74282 .62771 m .74843 .5703 L .77954 .57351 L p .707 .577 .707 r
F P
0 g
s
.49477 .54567 m .48916 .60307 L .49583 .60295 L p .707 .577 .707 r
F P
0 g
s
.49583 .60295 m .50145 .54554 L .49477 .54567 L p .707 .577 .707 r
F P
0 g
s
.68546 .66922 m .68521 .63234 L .71459 .62857 L p .707 .577 .707 r
F P
0 g
s
.71117 .6247 m .71678 .56729 L .74843 .5703 L p .707 .577 .707 r
F P
0 g
s
.33643 .71855 m .3357 .70061 L .31462 .69274 L p .707 .577 .707 r
F P
0 g
s
.74843 .5703 m .74282 .62771 L .71117 .6247 L p .707 .577 .707 r
F P
0 g
s
.6661 .70424 m .66537 .6863 L .68937 .67788 L p .707 .577 .707 r
F P
0 g
s
.29602 .58395 m .30163 .52654 L .29837 .52543 L p .707 .577 .707 r
F P
0 g
s
.77759 .62936 m .77785 .66623 L .74668 .66442 L p .707 .577 .707 r
F P
0 g
s
.74668 .66442 m .74642 .62754 L .77759 .62936 L p .707 .577 .707 r
F P
0 g
s
.29759 .62753 m .29785 .6644 L .31044 .67268 L p .707 .577 .707 r
F P
0 g
s
.31462 .69274 m .31535 .71068 L .33643 .71855 L p .707 .577 .707 r
F P
0 g
s
.29837 .52543 m .29275 .58284 L .29602 .58395 L p .707 .577 .707 r
F P
0 g
s
.71459 .62857 m .71484 .66545 L .68546 .66922 L p .707 .577 .707 r
F P
0 g
s
.68937 .67788 m .6901 .69582 L .6661 .70424 L p .707 .577 .707 r
F P
0 g
s
.71484 .66545 m .71459 .62857 L .74642 .62754 L p .707 .577 .707 r
F P
0 g
s
.47947 .69072 m .4802 .70866 L .49651 .69823 L p .707 .577 .707 r
F P
0 g
s
.49651 .69823 m .49578 .68029 L .47947 .69072 L p .707 .577 .707 r
F P
0 g
s
.49151 .62995 m .49177 .66682 L .49885 .65791 L p .707 .577 .707 r
F P
0 g
s
.49885 .65791 m .49859 .62104 L .49151 .62995 L p .707 .577 .707 r
F P
0 g
s
.80914 .67641 m .80987 .69435 L .7824 .68948 L p .707 .577 .707 r
F P
0 g
s
.7824 .68948 m .78167 .67154 L .80914 .67641 L p .707 .577 .707 r
F P
0 g
s
.74642 .62754 m .74668 .66442 L .71484 .66545 L p .707 .577 .707 r
F P
0 g
s
.6901 .69582 m .68937 .67788 L .7187 .67231 L p .707 .577 .707 r
F P
0 g
s
.31535 .71068 m .31462 .69274 L .30198 .68266 L p .707 .577 .707 r
F P
0 g
s
.29785 .6644 m .29759 .62753 L .2947 .61849 L p .707 .577 .707 r
F P
0 g
s
.50145 .54554 m .49583 .60295 L .49257 .60184 L p .707 .577 .707 r
F P
0 g
s
.49257 .60184 m .49818 .54443 L .50145 .54554 L p .707 .577 .707 r
F P
0 g
s
.78167 .67154 m .7824 .68948 L .75124 .68806 L p .707 .577 .707 r
F P
0 g
s
.75124 .68806 m .75051 .67012 L .78167 .67154 L p .707 .577 .707 r
F P
0 g
s
.7187 .67231 m .71943 .69025 L .6901 .69582 L p .707 .577 .707 r
F P
0 g
s
.30198 .68266 m .30271 .7006 L .31535 .71068 L p .707 .577 .707 r
F P
0 g
s
.71943 .69025 m .7187 .67231 L .75051 .67012 L p .707 .577 .707 r
F P
0 g
s
.2947 .61849 m .29495 .65537 L .29785 .6644 L p .707 .577 .707 r
F P
0 g
s
.75051 .67012 m .75124 .68806 L .71943 .69025 L p .707 .577 .707 r
F P
0 g
s
.49578 .68029 m .49651 .69823 L .50353 .68679 L p .707 .577 .707 r
F P
0 g
s
.50353 .68679 m .5028 .66885 L .49578 .68029 L p .707 .577 .707 r
F P
0 g
s
.29275 .58284 m .29837 .52543 L .30504 .5253 L p .707 .577 .707 r
F P
0 g
s
.30504 .5253 m .29943 .58271 L .29275 .58284 L p .707 .577 .707 r
F P
0 g
s
.49859 .62104 m .49885 .65791 L .49595 .64888 L p .707 .577 .707 r
F P
0 g
s
.49595 .64888 m .49569 .612 L .49859 .62104 L p .707 .577 .707 r
F P
0 g
s
.30271 .7006 m .30198 .68266 L .29903 .67135 L p .707 .577 .707 r
F P
0 g
s
.29495 .65537 m .2947 .61849 L .30178 .60958 L p .707 .577 .707 r
F P
0 g
s
.29903 .67135 m .29976 .68929 L .30271 .7006 L p .707 .577 .707 r
F P
0 g
s
.49818 .54443 m .49257 .60184 L .47968 .59985 L p .707 .577 .707 r
F P
0 g
s
.47968 .59985 m .48529 .54244 L .49818 .54443 L p .707 .577 .707 r
F P
0 g
s
.5028 .66885 m .50353 .68679 L .50058 .67548 L p .707 .577 .707 r
F P
0 g
s
.50058 .67548 m .49985 .65754 L .5028 .66885 L p .707 .577 .707 r
F P
0 g
s
.30178 .60958 m .30203 .64646 L .29495 .65537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29943 .58271 m .30504 .5253 L .321 .52617 L p .707 .577 .707 r
F P
0 g
s
.321 .52617 m .31539 .58358 L .29943 .58271 L p .707 .577 .707 r
F P
0 g
s
.49569 .612 m .49595 .64888 L .48336 .6406 L p .707 .577 .707 r
F P
0 g
s
.48336 .6406 m .4831 .60373 L .49569 .612 L p .707 .577 .707 r
F P
0 g
s
.29976 .68929 m .29903 .67135 L .30605 .65992 L p .707 .577 .707 r
F P
0 g
s
.30203 .64646 m .30178 .60958 L .31814 .60167 L p .707 .577 .707 r
F P
0 g
s
.30605 .65992 m .30678 .67786 L .29976 .68929 L p .707 .577 .707 r
F P
0 g
s
.48529 .54244 m .47968 .59985 L .45844 .59718 L p .707 .577 .707 r
F P
0 g
s
.45844 .59718 m .46405 .53978 L .48529 .54244 L p .707 .577 .707 r
F P
0 g
s
.49985 .65754 m .50058 .67548 L .48795 .6654 L p .707 .577 .707 r
F P
0 g
s
.48795 .6654 m .48722 .64746 L .49985 .65754 L p .707 .577 .707 r
F P
0 g
s
.31814 .60167 m .3184 .63854 L .30203 .64646 L p .707 .577 .707 r
F P
0 g
s
.31539 .58358 m .321 .52617 L .34468 .52796 L p .707 .577 .707 r
F P
0 g
s
.34468 .52796 m .33907 .58536 L .31539 .58358 L p .707 .577 .707 r
F P
0 g
s
.4831 .60373 m .48336 .6406 L .4623 .6339 L p .707 .577 .707 r
F P
0 g
s
.4623 .6339 m .46204 .59702 L .4831 .60373 L p .707 .577 .707 r
F P
0 g
s
.30678 .67786 m .30605 .65992 L .32236 .64949 L p .707 .577 .707 r
F P
0 g
s
.3184 .63854 m .31814 .60167 L .3422 .59553 L p .707 .577 .707 r
F P
0 g
s
.46405 .53978 m .45844 .59718 L .43092 .5941 L p .707 .577 .707 r
F P
0 g
s
.43092 .5941 m .43653 .53669 L .46405 .53978 L p .707 .577 .707 r
F P
0 g
s
.32236 .64949 m .32309 .66743 L .30678 .67786 L p .707 .577 .707 r
F P
0 g
s
.33907 .58536 m .34468 .52796 L .37377 .53047 L p .707 .577 .707 r
F P
0 g
s
.37377 .53047 m .36816 .58788 L .33907 .58536 L p .707 .577 .707 r
F P
0 g
s
.3422 .59553 m .34245 .6324 L .3184 .63854 L p .707 .577 .707 r
F P
0 g
s
.48722 .64746 m .48795 .6654 L .46686 .65754 L p .707 .577 .707 r
F P
0 g
s
.46686 .65754 m .46613 .6396 L .48722 .64746 L p .707 .577 .707 r
F P
0 g
s
.46204 .59702 m .4623 .6339 L .43484 .62942 L p .707 .577 .707 r
F P
0 g
s
.43484 .62942 m .43458 .59254 L .46204 .59702 L p .707 .577 .707 r
F P
0 g
s
.43653 .53669 m .43092 .5941 L .39981 .59089 L p .707 .577 .707 r
F P
0 g
s
.39981 .59089 m .40542 .53348 L .43653 .53669 L p .707 .577 .707 r
F P
0 g
s
.34245 .6324 m .3422 .59553 L .37158 .59176 L p .707 .577 .707 r
F P
0 g
s
.36816 .58788 m .37377 .53047 L .40542 .53348 L p .707 .577 .707 r
F P
0 g
s
.40542 .53348 m .39981 .59089 L .36816 .58788 L p .707 .577 .707 r
F P
0 g
s
.32309 .66743 m .32236 .64949 L .34636 .64107 L p .707 .577 .707 r
F P
0 g
s
.43458 .59254 m .43484 .62942 L .40367 .6276 L p .707 .577 .707 r
F P
0 g
s
.40367 .6276 m .40341 .59073 L .43458 .59254 L p .707 .577 .707 r
F P
0 g
s
.37158 .59176 m .37183 .62863 L .34245 .6324 L p .707 .577 .707 r
F P
0 g
s
.34636 .64107 m .34709 .65901 L .32309 .66743 L p .707 .577 .707 r
F P
0 g
s
.37183 .62863 m .37158 .59176 L .40341 .59073 L p .707 .577 .707 r
F P
0 g
s
.46613 .6396 m .46686 .65754 L .43939 .65266 L p .707 .577 .707 r
F P
0 g
s
.43939 .65266 m .43866 .63472 L .46613 .6396 L p .707 .577 .707 r
F P
0 g
s
.40341 .59073 m .40367 .6276 L .37183 .62863 L p .707 .577 .707 r
F P
0 g
s
.34709 .65901 m .34636 .64107 L .37569 .63549 L p .707 .577 .707 r
F P
0 g
s
.43866 .63472 m .43939 .65266 L .40823 .65125 L p .707 .577 .707 r
F P
0 g
s
.40823 .65125 m .4075 .63331 L .43866 .63472 L p .707 .577 .707 r
F P
0 g
s
.37569 .63549 m .37642 .65343 L .34709 .65901 L p .707 .577 .707 r
F P
0 g
s
.37642 .65343 m .37569 .63549 L .4075 .63331 L p .707 .577 .707 r
F P
0 g
s
.4075 .63331 m .40823 .65125 L .37642 .65343 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001bOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEP0000<006ioo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Jgoo001X
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF008006Moo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol0
06Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo06Aoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001DOol:0006Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool005Aoo`03001JEP0000AJEP03001JEUYF014000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00
E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00P00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003001SOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF001JEP00FUH=001FOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYF
FUH9001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@00<7oo001COol:0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000`00;7oo001DOol60003FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
FWoo1`000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool0065ooah000=JEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo001POol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYFFUH005YF;Goo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEP0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUIJEP00FUH]Ool005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;Goo2P0077oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF4P0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF000015YF00<005YFFUH03P003Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00
00002P000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00002`00
0Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P003Goo700015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF1`001UYF00<005YFFUH01eYF200015YF00<005YFFUH00eYF00<0
05YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
2goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00@005YFFUIJEP80
02ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YF00000`0017oo00<005YF00000UYF700015YF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF10000UYF2P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPP00004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00008000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004FUH80005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EP00001JEP0015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0000=JEP0000000P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH500000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP04001JEP000006
FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH400000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH200000eYF001JEP05FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50005FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJ
EUYF00001EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@0
05YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH00003
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF
001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH40003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH00UYF2@002Goo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0P0000EJEP00FUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP000080009JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEPH000Yoo`l00003Ool00000
00<000AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH3000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUH000080002
Ool90004FUH00`00FUIJEP06FUH00`00FUH000030002Ool300000eYF001JEP02FUH2000]Ool002ao
o`X000=JEP03001JEUYF00=JEQ4000=JEP05001JEP00FUH00002FUH300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH2000<FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH40004FUH50004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000015YF000000000eYF0P00;Goo000_Ool4
0003FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUH000040004FUH00`00
FUIJEP05FUH40005FUH00`00FUIJEP02FUH70009FUH01000FUH000002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P000eYF1P0025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000AJEP00001JEP8002eoo`00<goo1P0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00000010000eYF6`001UYF00<0
05YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00000000EJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP800004FUH00000000]Ool0039oo`<000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEP0000<00005FUH00000FUH00005
FUH00`00FUH000040003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200001EYF001JEUYF00002eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP8000EJEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEPD002eoo`00
<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
0P000UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YF000010000eYF00<005YFFUH02EYF
00<005YFFUH00UYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0`000UYF00<005YF00000P001UYF00<005YFFUH00UYF200025YF2@0015YF00<005YFFUH00UYF00<0
05YF00000P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH30002FUH40005FUH300000eYF001JEP04FUH00`00FUIJEP030004FUH00`00FUIJ
EP08FUH00`00FUH0000300000eYF001JEP03FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH20002FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH70004FUH01000FUIJEP00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP02FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEP04001JEUYFFUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300001EYF
001JEUYF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
0UYF0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP04001JEUYFFUH:0008FUH70005FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH0000002aoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000UYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF0000009oo`<002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF00H00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eo
o`8002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@000eYF0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF0080009JEP03
001JEP0000@000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<000Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1P006Goo2`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF1@000eYF2P0015YF1@0015YF00<005YF
FUH00UYF1@002Goo0`0000=JEP00Ool0:goo000/Ool00`00FUH00004FUH00`00FUH00003000?Ool3
000COol300000eYF000000080004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00
FUH000030003FUH20004OolB000<Ool20002FUH00`00FUH0000/Ool002aoo`03001JEP0000=JEP@0
015oo`D000moo`@00003FUH0000000800003FUH005YF00EJEPT00003FUH005YF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF009JEP03001JEUYF009JEP80009JEP8000Qoo`D001=oo`8000AJEP8002eoo`00
;7oo00@005YF001JEP8000AJEPD000aoo`D000Uoo`H000EJEP06001JEUYF001JEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP0000000UYF0P0000=JEP00FUH015YF0P0000=JEP000000
2Goo0`004Woo0P0000=JEP00FUH00eYF0P00;Goo000/Ool01P00FUH00000FUH000EJEP04001JEUYF
FUH80004Ool>0004FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH00000009JEP03001JEP00008000AJEP03001JEP00008001aoo`8000=JEP03
001JEUYF009JEP03001oogoo02aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<0
05YF00001`0015YF00<005YFFUH00UYF2@001UYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomo
o`0EOol50005FUH01000FUIJEUYF0P00;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000MJEP00FUIJEP00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH00UYF00<005YF
00000`0000=JEP00Ool03Goo2@000eYF00<005YFFUH015YF00@005YF0000031oo`00;7oo0P000eYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P0000AJEP00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH0
05YFFUH30004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol0
02eoo`05001JEUYFFUH00004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=7oo000]Ool01@00FUIJEUYF00000UYF0P001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Ioo`00;Woo0P0000=JEP00FUH00P001UYF
00<005YFFUH015YF1`001eYF2@0015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000goo100000AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPH003Qoo`00<7oo0`0000=JEP00FUH01EYF00<005YFFUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF1P0015YF00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF
6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`0015YF100000=J
EP00FUH01eYF00<005YFFUH00UYF2@00?Woo000`Ool01@00FUIJEUYF00001EYF100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000AJEP00FUH000IJEP03001J
EUYF00=JEP/000aJEP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yo
o`<00003FUH005YF009JEPl004Moo`00;goo0P000eYF00<005YF00000`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000goo0P0000=JEP00FUH015YF1`002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF0P001goo
100000AJEP00000000=JEP8005Aoo`00;goo0P000eYF0P000goo10000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P0027oo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009J
EP80009oo`D000EJEP03001JEUYF00800003FUH0000005Aoo`00;Woo00<005YF00000UYF00<007oo
Ool01goo60003Woo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF20001UYF00<005YFFUH00UYF
0`00E7oo000^Ool00`00FUH00002000DOol5000GOol20002FUH00`00FUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH30008FUH01000FUIJEUYF0P000UYF
0P000UYF00@005YFFUIJEP@0009JEP03001JEUYF009JEP<005Aoo`00;Woo00<005YF00005Woo1@00
5goo0P000UYF00<005YF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH00eYF10002eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF100015YF00<005YF0000
E7oo000^Ool2000GOol5000GOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH00`00FUIJEP0<FUH00`00FUIJEP04FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0001DOol002ioo`8001Qoo`<001Qoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP03
001JEUYF00aJEP03001JEUYF00AJEP<0009JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
000005Eoo`00;Woo00@005YF0000031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00]JEP03001JEUYF00AJEP03001J
EP0000@000IJEP03001JEUYF009JEP<005Ioo`00;Woo0P000UYF0P00;7oo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF00@005YFFUIJEP<000MJEP03001JEUYF00AJEP03001JEP0000AJEP@0009JEP03001JEUYF009J
EP04001JEP00001EOol002moo`05001JEUYF001JEP03000UOol400000eYF001JEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH6
0009FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP040004FUH01000FUIJEP00E7oo000_Ool01000
FUIJEP0015YF0`007goo0`001EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH015YF0P001UYF00<005YF00000`0000Ioo`00000005YF0002FUH00`00Oomoo`1BOol0
031oo`03001JEP0000EJEP03001JEP0000<001Moo`@00003FUH005YF00EJEP03001JEUYF0080009o
o`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000AJEPD000Qoo`80009JEP8005=oo`00<Goo0P001EYF00<005YF
FUH00eYF5`001EYF00<005YFFUH015YF0`001goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00002@003goo00@005YF0000
05=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P003Goo20001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF10006Woo0`00Dgoo000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000GOol<0006FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH@000JOol2001COol003Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<002Mooa/000]oo`D001Uoo`<005=oo`00>Woo10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000=Woo0P0067oo1@005goo0`0000=JEP00Ool0DWoo000nOolG000jOol3
000HOol3000FOol20002FUH00`00FUH0001COol008moo`800003FUH007oo02eoo`8000AJEP8005Ao
o`00Sgoo0P000UYF0P00:7oo100000=JEP00FUH00eYF0P00E7oo002@Ool01@00FUIJEP00FUH00`00
8Woo0`001EYF00<005YFFUH00UYF00<007ooOol0Dgoo002@Ool01000FUIJEP0015YF1@006Goo1000
00=JEP00FUH01EYF00<005YFFUH00P00EWoo002AOol01000FUIJEP0015YF00@005YFFUIJEPT000Uo
o`L000EJEP03001JEUYF00AJEP<005Qoo`00TWoo0`0015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0F7oo002DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Fgoo002F
Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0
0000GGoo002IOol50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6001OOol0
09ioo`P000AJEP03001JEUYF009JEPT006Eoo`00YWoo2@00KWoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57285 .65043 m .56394 .70696 L .59495 .71098 L p .707 .577 .707 r
F P
0 g
s
.59495 .71098 m .60385 .65445 L .57285 .65043 L p .707 .577 .707 r
F P
0 g
s
.60385 .65445 m .59495 .71098 L .62629 .71634 L p .707 .577 .707 r
F P
0 g
s
.62629 .71634 m .6352 .65981 L .60385 .65445 L p .707 .577 .707 r
F P
0 g
s
.6352 .65981 m .62629 .71634 L .65492 .72252 L p .707 .577 .707 r
F P
0 g
s
.54522 .64815 m .53632 .70468 L .56394 .70696 L p .707 .577 .707 r
F P
0 g
s
.56394 .70696 m .57285 .65043 L .54522 .64815 L p .707 .577 .707 r
F P
0 g
s
.65492 .72252 m .66382 .66599 L .6352 .65981 L p .707 .577 .707 r
F P
0 g
s
.66382 .66599 m .65492 .72252 L .67801 .72891 L p .707 .577 .707 r
F P
0 g
s
.59583 .80815 m .59541 .77139 L .56424 .76962 L p .707 .577 .707 r
F P
0 g
s
.59541 .77139 m .59583 .80815 L .62766 .80696 L p .707 .577 .707 r
F P
0 g
s
.62766 .80696 m .62724 .7702 L .59541 .77139 L p .707 .577 .707 r
F P
0 g
s
.62724 .7702 m .62766 .80696 L .65704 .80295 L p .707 .577 .707 r
F P
0 g
s
.65704 .80295 m .65662 .76619 L .62724 .7702 L p .707 .577 .707 r
F P
0 g
s
.52368 .64784 m .51477 .70437 L .53632 .70468 L p .707 .577 .707 r
F P
0 g
s
.53632 .70468 m .54522 .64815 L .52368 .64784 L p .707 .577 .707 r
F P
0 g
s
.67801 .72891 m .68692 .67239 L .66382 .66599 L p .707 .577 .707 r
F P
0 g
s
.56465 .80638 m .56424 .76962 L .53678 .76509 L p .707 .577 .707 r
F P
0 g
s
.56424 .76962 m .56465 .80638 L .59583 .80815 L p .707 .577 .707 r
F P
0 g
s
.65662 .76619 m .65704 .80295 L .68109 .79651 L p .707 .577 .707 r
F P
0 g
s
.68109 .79651 m .68067 .75975 L .65662 .76619 L p .707 .577 .707 r
F P
0 g
s
.53678 .76509 m .5372 .80185 L .56465 .80638 L p .707 .577 .707 r
F P
0 g
s
.68692 .67239 m .67801 .72891 L .69332 .7349 L p .707 .577 .707 r
F P
0 g
s
.5372 .80185 m .53678 .76509 L .51572 .75823 L p .707 .577 .707 r
F P
0 g
s
.69332 .7349 m .70223 .67837 L .68692 .67239 L p .707 .577 .707 r
F P
0 g
s
.51033 .64951 m .50142 .70604 L .51477 .70437 L p .707 .577 .707 r
F P
0 g
s
.51477 .70437 m .52368 .64784 L .51033 .64951 L p .707 .577 .707 r
F P
0 g
s
.51572 .75823 m .51614 .79499 L .5372 .80185 L p .707 .577 .707 r
F P
0 g
s
.68067 .75975 m .68109 .79651 L .69745 .78826 L p .707 .577 .707 r
F P
0 g
s
.69745 .78826 m .69703 .7515 L .68067 .75975 L p .707 .577 .707 r
F P
0 g
s
.60398 .86875 m .60281 .85127 L .57166 .85015 L p .707 .577 .707 r
F P
0 g
s
.60281 .85127 m .60398 .86875 L .63574 .86572 L p .707 .577 .707 r
F P
0 g
s
.63574 .86572 m .63457 .84824 L .60281 .85127 L p .707 .577 .707 r
F P
0 g
s
.63457 .84824 m .63574 .86572 L .66501 .85883 L p .707 .577 .707 r
F P
0 g
s
.66501 .85883 m .66383 .84134 L .63457 .84824 L p .707 .577 .707 r
F P
0 g
s
.51614 .79499 m .51572 .75823 L .50313 .74972 L p .707 .577 .707 r
F P
0 g
s
.70223 .67837 m .69332 .7349 L .69934 .73989 L p .707 .577 .707 r
F P
0 g
s
.57284 .86763 m .57166 .85015 L .54417 .84498 L p .707 .577 .707 r
F P
0 g
s
.57166 .85015 m .57284 .86763 L .60398 .86875 L p .707 .577 .707 r
F P
0 g
s
.69934 .73989 m .70825 .68336 L .70223 .67837 L p .707 .577 .707 r
F P
0 g
s
.66383 .84134 m .66501 .85883 L .68892 .84875 L p .707 .577 .707 r
F P
0 g
s
.68892 .84875 m .68774 .83127 L .66383 .84134 L p .707 .577 .707 r
F P
0 g
s
.54417 .84498 m .54535 .86246 L .57284 .86763 L p .707 .577 .707 r
F P
0 g
s
.50313 .74972 m .50354 .78648 L .51614 .79499 L p .707 .577 .707 r
F P
0 g
s
.50647 .65302 m .49757 .70955 L .50142 .70604 L p .707 .577 .707 r
F P
0 g
s
.50142 .70604 m .51033 .64951 L .50647 .65302 L p .707 .577 .707 r
F P
0 g
s
.69703 .7515 m .69745 .78826 L .70453 .77901 L p .707 .577 .707 r
F P
0 g
s
.70453 .77901 m .70411 .74225 L .69703 .7515 L p .707 .577 .707 r
F P
0 g
s
.54535 .86246 m .54417 .84498 L .52305 .83627 L p .707 .577 .707 r
F P
0 g
s
.52305 .83627 m .52422 .85375 L .54535 .86246 L p .707 .577 .707 r
F P
0 g
s
.68774 .83127 m .68892 .84875 L .70513 .83647 L p .707 .577 .707 r
F P
0 g
s
.70513 .83647 m .70395 .81899 L .68774 .83127 L p .707 .577 .707 r
F P
0 g
s
.50354 .78648 m .50313 .74972 L .50023 .74038 L p .707 .577 .707 r
F P
0 g
s
.70825 .68336 m .69934 .73989 L .69549 .7434 L p .707 .577 .707 r
F P
0 g
s
.69549 .7434 m .7044 .68687 L .70825 .68336 L p .707 .577 .707 r
F P
0 g
s
.50023 .74038 m .50064 .77714 L .50354 .78648 L p .707 .577 .707 r
F P
0 g
s
.52422 .85375 m .52305 .83627 L .51034 .82487 L p .707 .577 .707 r
F P
0 g
s
.5125 .65801 m .50359 .71454 L .49757 .70955 L p .707 .577 .707 r
F P
0 g
s
.49757 .70955 m .50647 .65302 L .5125 .65801 L p .707 .577 .707 r
F P
0 g
s
.70411 .74225 m .70453 .77901 L .70163 .76967 L p .707 .577 .707 r
F P
0 g
s
.70163 .76967 m .70121 .73291 L .70411 .74225 L p .707 .577 .707 r
F P
0 g
s
.47875 .81629 m .49676 .3045 L .45276 .30117 L p .707 .577 .707 r
F P
0 g
s
.50064 .77714 m .50023 .74038 L .5073 .73113 L p .707 .577 .707 r
F P
0 g
s
.51152 .84235 m .51034 .82487 L .5073 .8119 L p .707 .577 .707 r
F P
0 g
s
.5073 .73113 m .50772 .76789 L .50064 .77714 L p .707 .577 .707 r
F P
0 g
s
.5278 .664 m .5189 .72052 L .50359 .71454 L p .707 .577 .707 r
F P
0 g
s
.50359 .71454 m .5125 .65801 L .5278 .664 L p .707 .577 .707 r
F P
0 g
s
.5073 .8119 m .50847 .82938 L .51152 .84235 L p .707 .577 .707 r
F P
0 g
s
.50772 .76789 m .5073 .73113 L .52367 .72288 L p .707 .577 .707 r
F P
0 g
s
.50847 .82938 m .5073 .8119 L .51422 .79863 L p .707 .577 .707 r
F P
0 g
s
.52367 .72288 m .52408 .75964 L .50772 .76789 L p .707 .577 .707 r
F P
0 g
s
.51034 .82487 m .51152 .84235 L .52422 .85375 L p .707 .577 .707 r
F P
0 g
s
.51422 .79863 m .5154 .81611 L .50847 .82938 L p .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .51422 .79863 L .52675 .78913 L p .707 .577 .707 r
F P
0 g
s
.54199 .72692 m .5189 .72052 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.5509 .67039 m .54733 .69306 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54733 .69306 m .54199 .72692 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .49676 .3045 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .52675 .78913 L .5262 .79471 L .707 .577 .707 r
F
.5189 .72052 m .5278 .664 L .5509 .67039 L p F P
0 g
s
.54199 .72692 m .54469 .70979 L p .57952 .67657 L .707 .577 .707 r
F P
0 g
s
.54469 .70979 m .5509 .67039 L .56736 .67395 L p .707 .577 .707 r
F P
0 g
s
.56736 .67395 m .57952 .67657 L p .54469 .70979 L .707 .577 .707 r
F P
0 g
s
.61087 .68194 m .60196 .73846 L .57547 .73393 L p .707 .577 .707 r
F P
0 g
s
.57547 .73393 m .57062 .7331 L p .57765 .72416 L .707 .577 .707 r
F P
0 g
s
.57765 .72416 m .61087 .68194 L .57547 .73393 L .707 .577 .707 r
F
.64187 .68595 m .63297 .74248 L .60623 .73902 L p F P
0 g
s
.60623 .73902 m .60196 .73846 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60698 .73186 m .64187 .68595 L .60623 .73902 L .707 .577 .707 r
F
.60196 .73846 m .61087 .68194 L .61225 .68211 L p F P
0 g
s
.61225 .68211 m .64187 .68595 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60196 .73846 m .61225 .68211 L .60698 .73186 L .707 .577 .707 r
F
.64996 .28493 m .64003 .2927 L p .63763 .44218 L F P
0 g
s
.6695 .68823 m .66059 .74476 L .63297 .74248 L p .707 .577 .707 r
F P
0 g
s
.63297 .74248 m .64187 .68595 L .6695 .68823 L p .707 .577 .707 r
F P
0 g
s
.6401 .713 m .64052 .74977 L .60934 .748 L p .707 .577 .707 r
F P
0 g
s
.60934 .748 m .60893 .71124 L .6401 .713 L p .707 .577 .707 r
F P
0 g
s
.64651 .76747 m .64769 .78495 L .61654 .78383 L p .707 .577 .707 r
F P
0 g
s
.61654 .78383 m .61536 .76635 L .64651 .76747 L p .707 .577 .707 r
F P
0 g
s
.63195 .79672 m .64781 .34602 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64781 .34602 m .64996 .28493 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .63195 .79672 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64003 .2927 m .63335 .48271 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.63335 .48271 m .62202 .80449 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.57062 .7331 m .57952 .67657 L .61087 .68194 L p .707 .577 .707 r
F P
0 g
s
.57751 .74919 m .57709 .71243 L .60893 .71124 L p .707 .577 .707 r
F P
0 g
s
.60893 .71124 m .60934 .748 L .57751 .74919 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .59899 .81085 L p .59842 .79281 L .707 .577 .707 r
F P
0 g
s
.59148 .76863 m .59603 .76819 L p .59287 .77345 L .707 .577 .707 r
F P
0 g
s
.59603 .76819 m .61536 .76635 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.57709 .71243 m .57751 .74919 L .5664 .7507 L p .707 .577 .707 r
F P
0 g
s
.5664 .7507 m .54813 .7532 L p .56297 .73231 L .707 .577 .707 r
F P
0 g
s
.57952 .67657 m .57062 .7331 L .54199 .72692 L p .707 .577 .707 r
F P
0 g
s
.56297 .73231 m .57709 .71243 L .5664 .7507 L .707 .577 .707 r
F
.54813 .7532 m .54772 .71644 L .57709 .71243 L p F P
0 g
s
.57022 .66943 m .56721 .75502 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.56721 .75502 m .56509 .81517 L p .57115 .77614 L .707 .577 .707 r
F P
0 g
s
.59341 .63276 m .56721 .75502 L .57115 .77614 L .707 .577 .707 r
F
.59842 .79281 m .57905 .72528 L .56509 .81517 L F
.58478 .78686 m .59603 .76819 L .59729 .77847 L F
.61536 .76635 m .61654 .78383 L .59815 .78559 L p F P
0 g
s
.59815 .78559 m .58478 .78686 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.59729 .77847 m .61536 .76635 L .59815 .78559 L .707 .577 .707 r
F
.60659 .59461 m .59949 .79654 L p .61937 .53744 L F P
0 g
s
.59949 .79654 m .59899 .81085 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61937 .53744 m .59949 .79654 L .59984 .7994 L .707 .577 .707 r
F
.59842 .79281 m .59341 .63276 L .57905 .72528 L F
.58478 .78686 m .5836 .76938 L .59148 .76863 L p F P
0 g
s
.58478 .78686 m .59148 .76863 L .59287 .77345 L .707 .577 .707 r
F
.62202 .80449 m .61937 .53744 L .59984 .7994 L F
.59899 .81085 m .60116 .81025 L p .59984 .7994 L F P
0 g
s
.60116 .81025 m .62202 .80449 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61699 .29906 m .60659 .59461 L p .61937 .53744 L .707 .577 .707 r
F P
0 g
s
.5831 .30338 m .57022 .66943 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.52408 .75964 m .52367 .72288 L .54772 .71644 L p .707 .577 .707 r
F P
0 g
s
.54772 .71644 m .54813 .7532 L .52408 .75964 L p .707 .577 .707 r
F P
0 g
s
.52401 .81703 m .56509 .81517 L p .55206 .53137 L .707 .577 .707 r
F P
0 g
s
.53043 .78635 m .53161 .80383 L .5248 .80899 L p .707 .577 .707 r
F P
0 g
s
.5248 .80899 m .5154 .81611 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.5262 .79471 m .53043 .78635 L .5248 .80899 L .707 .577 .707 r
F
.52366 .81705 m .53072 .61639 L p .5075 .50915 L F P
0 g
s
.53072 .61639 m .54167 .30526 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.52675 .78913 m .53043 .78635 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .52366 .81705 L .52401 .81703 L p .707 .577 .707 r
F P
0 g
s
.55206 .53137 m .54167 .30526 L .52401 .81703 L .707 .577 .707 r
F
.49676 .3045 m .47875 .81629 L .52366 .81705 L p F P
0 g
s
.70395 .81899 m .70513 .83647 L .71205 .8232 L p .707 .577 .707 r
F P
0 g
s
.71205 .8232 m .71087 .80572 L .70395 .81899 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .5831 .30338 L .54167 .30526 L p .707 .577 .707 r
F P
0 g
s
.43476 .81296 m .45276 .30117 L .41399 .29561 L p .707 .577 .707 r
F P
0 g
s
.45276 .30117 m .43476 .81296 L .47875 .81629 L p .707 .577 .707 r
F P
0 g
s
.7044 .68687 m .69549 .7434 L .68214 .74507 L p .707 .577 .707 r
F P
0 g
s
.22984 .61362 m .22093 .67014 L .25194 .67416 L p .707 .577 .707 r
F P
0 g
s
.25194 .67416 m .26084 .61763 L .22984 .61362 L p .707 .577 .707 r
F P
0 g
s
.26084 .61763 m .25194 .67416 L .28329 .67952 L p .707 .577 .707 r
F P
0 g
s
.59899 .81085 m .61699 .29906 L .5831 .30338 L p .707 .577 .707 r
F P
0 g
s
.68214 .74507 m .69104 .68854 L .7044 .68687 L p .707 .577 .707 r
F P
0 g
s
.28329 .67952 m .29219 .62299 L .26084 .61763 L p .707 .577 .707 r
F P
0 g
s
.29219 .62299 m .28329 .67952 L .31191 .6857 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.20221 .61134 m .19331 .66787 L .22093 .67014 L p .707 .577 .707 r
F P
0 g
s
.22093 .67014 m .22984 .61362 L .20221 .61134 L p .707 .577 .707 r
F P
0 g
s
.70121 .73291 m .70163 .76967 L .68903 .76116 L p .707 .577 .707 r
F P
0 g
s
.68903 .76116 m .68862 .7244 L .70121 .73291 L p .707 .577 .707 r
F P
0 g
s
.31191 .6857 m .32081 .62917 L .29219 .62299 L p .707 .577 .707 r
F P
0 g
s
.39598 .8074 m .41399 .29561 L .38423 .28836 L p .707 .577 .707 r
F P
0 g
s
.41399 .29561 m .39598 .8074 L .43476 .81296 L p .707 .577 .707 r
F P
0 g
s
.71087 .80572 m .71205 .8232 L .70901 .81023 L p .707 .577 .707 r
F P
0 g
s
.70901 .81023 m .70783 .79275 L .71087 .80572 L p .707 .577 .707 r
F P
0 g
s
.32081 .62917 m .31191 .6857 L .335 .6921 L p .707 .577 .707 r
F P
0 g
s
.25282 .77133 m .2524 .73457 L .22123 .73281 L p .707 .577 .707 r
F P
0 g
s
.2524 .73457 m .25282 .77133 L .28465 .77015 L p .707 .577 .707 r
F P
0 g
s
.28465 .77015 m .28423 .73339 L .2524 .73457 L p .707 .577 .707 r
F P
0 g
s
.28423 .73339 m .28465 .77015 L .31403 .76614 L p .707 .577 .707 r
F P
0 g
s
.31403 .76614 m .31361 .72938 L .28423 .73339 L p .707 .577 .707 r
F P
0 g
s
.18067 .61102 m .17176 .66755 L .19331 .66787 L p .707 .577 .707 r
F P
0 g
s
.19331 .66787 m .20221 .61134 L .18067 .61102 L p .707 .577 .707 r
F P
0 g
s
.335 .6921 m .34391 .63557 L .32081 .62917 L p .707 .577 .707 r
F P
0 g
s
.69104 .68854 m .68214 .74507 L .66059 .74476 L p .707 .577 .707 r
F P
0 g
s
.22165 .76957 m .22123 .73281 L .19377 .72828 L p .707 .577 .707 r
F P
0 g
s
.22123 .73281 m .22165 .76957 L .25282 .77133 L p .707 .577 .707 r
F P
0 g
s
.66059 .74476 m .6695 .68823 L .69104 .68854 L p .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .64003 .2927 L .61699 .29906 L p .707 .577 .707 r
F P
0 g
s
.31361 .72938 m .31403 .76614 L .33808 .75969 L p .707 .577 .707 r
F P
0 g
s
.33808 .75969 m .33766 .72293 L .31361 .72938 L p .707 .577 .707 r
F P
0 g
s
.68862 .7244 m .68903 .76116 L .66797 .7543 L p .707 .577 .707 r
F P
0 g
s
.66797 .7543 m .66756 .71754 L .68862 .7244 L p .707 .577 .707 r
F P
0 g
s
.19377 .72828 m .19419 .76504 L .22165 .76957 L p .707 .577 .707 r
F P
0 g
s
.34391 .63557 m .335 .6921 L .35031 .69809 L p .707 .577 .707 r
F P
0 g
s
.19419 .76504 m .19377 .72828 L .17271 .72142 L p .707 .577 .707 r
F P
0 g
s
.70783 .79275 m .70901 .81023 L .6963 .79883 L p .707 .577 .707 r
F P
0 g
s
.6963 .79883 m .69512 .78135 L .70783 .79275 L p .707 .577 .707 r
F P
0 g
s
.35031 .69809 m .35922 .64156 L .34391 .63557 L p .707 .577 .707 r
F P
0 g
s
.36094 .78218 m .36212 .79966 L .36614 .79196 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .38423 .28836 L .37014 .28185 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .37014 .28185 L .36623 .78014 L .707 .577 .707 r
F
.38423 .28836 m .36622 .80015 L .39598 .8074 L p F P
0 g
s
.36619 .7849 m .36094 .78218 L .36614 .79196 L .707 .577 .707 r
F
.33766 .72293 m .33808 .75969 L .35444 .75144 L p F P
0 g
s
.35444 .75144 m .35403 .71468 L .33766 .72293 L p .707 .577 .707 r
F P
0 g
s
.35922 .64156 m .35031 .69809 L .35633 .70308 L p .707 .577 .707 r
F P
0 g
s
.35633 .70308 m .36524 .64655 L .35922 .64156 L p .707 .577 .707 r
F P
0 g
s
.35403 .71468 m .35444 .75144 L .36152 .74219 L p .707 .577 .707 r
F P
0 g
s
.36152 .74219 m .3611 .70543 L .35403 .71468 L p .707 .577 .707 r
F P
0 g
s
.36212 .79966 m .36094 .78218 L .34473 .79445 L p .707 .577 .707 r
F P
0 g
s
.36524 .64655 m .35633 .70308 L .35248 .70658 L p .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .36139 .65005 L .36524 .64655 L p .707 .577 .707 r
F P
0 g
s
.3611 .70543 m .36152 .74219 L .35862 .73286 L p .707 .577 .707 r
F P
0 g
s
.35862 .73286 m .3582 .6961 L .3611 .70543 L p .707 .577 .707 r
F P
0 g
s
.36629 .77191 m .36094 .78218 L p .36619 .7849 L .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .33913 .70826 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.36139 .65005 m .35518 .68945 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.35518 .68945 m .35248 .70658 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.3664 .28013 m .36225 .27171 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .34803 .65173 L .35371 .65102 L p .707 .577 .707 r
F P
0 g
s
.35371 .65102 m .36139 .65005 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .35371 .65102 L .35437 .66839 L .707 .577 .707 r
F
.3582 .6961 m .35862 .73286 L .35078 .72756 L p F P
0 g
s
.35078 .72756 m .34602 .72434 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.35188 .71076 m .3582 .6961 L .35078 .72756 L .707 .577 .707 r
F
.34602 .72434 m .34561 .68758 L .35306 .69262 L p F P
0 g
s
.35306 .69262 m .3582 .6961 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.34602 .72434 m .35306 .69262 L .35188 .71076 L .707 .577 .707 r
F
.34964 .74508 m .35352 .64617 L .35279 .62696 L F
.34839 .79191 m .35051 .73176 L p .34964 .74508 L F P
0 g
s
.35051 .73176 m .35352 .64617 L p .34964 .74508 L .707 .577 .707 r
F P
0 g
s
.34424 .7835 m .3468 .78868 L p .34995 .70366 L .707 .577 .707 r
F P
0 g
s
.34995 .70366 m .34563 .75799 L .34424 .7835 L .707 .577 .707 r
F
.3468 .78868 m .34839 .79191 L p .34964 .74508 L F P
0 g
s
.34964 .74508 m .35279 .62696 L .3468 .78868 L .707 .577 .707 r
F
.34557 .75883 m .3444 .75835 L p .3465 .747 L F P
0 g
s
.3444 .75835 m .33216 .75331 L p .34407 .74807 L .707 .577 .707 r
F P
0 g
s
.34407 .74807 m .3465 .747 L .3444 .75835 L .707 .577 .707 r
F
.3664 .28013 m .34839 .79191 L .36607 .80008 L p F P
0 g
s
.34687 .74237 m .35212 .74453 L p .3465 .747 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .34424 .7835 L p .34563 .75799 L .707 .577 .707 r
F P
0 g
s
.35212 .74453 m .35329 .76202 L .34557 .75883 L p .707 .577 .707 r
F P
0 g
s
.3465 .747 m .35212 .74453 L .34557 .75883 L .707 .577 .707 r
F
.34385 .74113 m .34687 .74237 L p .34396 .74454 L F P
0 g
s
.33216 .75331 m .34687 .74237 L .3465 .747 L .707 .577 .707 r
F
.34995 .70366 m .35279 .62696 L .34563 .75799 L F
.35352 .64617 m .3664 .28013 L p .35279 .62696 L F P
0 g
s
.36623 .78014 m .3664 .28013 L .36607 .80008 L .707 .577 .707 r
F
.37014 .28185 m .3664 .28013 L p .36623 .78014 L F P
0 g
s
.36482 .75593 m .366 .77342 L .35329 .76202 L p .707 .577 .707 r
F P
0 g
s
.35329 .76202 m .35212 .74453 L .36482 .75593 L p .707 .577 .707 r
F P
0 g
s
.37217 .26395 m .35417 .77574 L .34518 .78277 L p .707 .577 .707 r
F P
0 g
s
.34518 .78277 m .34424 .7835 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.3512 .5856 m .34474 .76919 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.35279 .62696 m .34474 .76919 L .34563 .75799 L .707 .577 .707 r
F
.36225 .27171 m .3512 .5856 L p .35279 .62696 L F P
0 g
s
.34484 .7723 m .37217 .26395 L .34518 .78277 L .707 .577 .707 r
F
.33216 .75331 m .33099 .73582 L .34385 .74113 L p F P
0 g
s
.33216 .75331 m .34385 .74113 L .34396 .74454 L .707 .577 .707 r
F
.34484 .7723 m .35127 .58738 L .35273 .62555 L F
.35127 .58738 m .36225 .27171 L .35273 .62555 L F
.36225 .27171 m .37217 .26395 L p .35273 .62555 L F P
0 g
s
.34424 .7835 m .34474 .76919 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .36225 .27171 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.36607 .80008 m .36622 .80015 L p .36623 .78014 L .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36786 .7689 L .36629 .77191 L p .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36629 .77191 L .36619 .7849 L .707 .577 .707 r
F
.36614 .79196 m .36904 .78639 L p .36619 .7849 L F P
0 g
s
.16732 .6127 m .15841 .66923 L .17176 .66755 L p .707 .577 .707 r
F P
0 g
s
.17176 .66755 m .18067 .61102 L .16732 .6127 L p .707 .577 .707 r
F P
0 g
s
.17271 .72142 m .17313 .75818 L .19419 .76504 L p .707 .577 .707 r
F P
0 g
s
.66756 .71754 m .66797 .7543 L .64052 .74977 L p .707 .577 .707 r
F P
0 g
s
.64052 .74977 m .6401 .713 L .66756 .71754 L p .707 .577 .707 r
F P
0 g
s
.26097 .83194 m .2598 .81446 L .22865 .81333 L p .707 .577 .707 r
F P
0 g
s
.2598 .81446 m .26097 .83194 L .29274 .82891 L p .707 .577 .707 r
F P
0 g
s
.29274 .82891 m .29156 .81142 L .2598 .81446 L p .707 .577 .707 r
F P
0 g
s
.29156 .81142 m .29274 .82891 L .322 .82201 L p .707 .577 .707 r
F P
0 g
s
.322 .82201 m .32083 .80453 L .29156 .81142 L p .707 .577 .707 r
F P
0 g
s
.17313 .75818 m .17271 .72142 L .16012 .7129 L p .707 .577 .707 r
F P
0 g
s
.22983 .83082 m .22865 .81333 L .20117 .80816 L p .707 .577 .707 r
F P
0 g
s
.22865 .81333 m .22983 .83082 L .26097 .83194 L p .707 .577 .707 r
F P
0 g
s
.69512 .78135 m .6963 .79883 L .67517 .79012 L p .707 .577 .707 r
F P
0 g
s
.67517 .79012 m .674 .77264 L .69512 .78135 L p .707 .577 .707 r
F P
0 g
s
.32083 .80453 m .322 .82201 L .34591 .81194 L p .707 .577 .707 r
F P
0 g
s
.34591 .81194 m .34473 .79445 L .32083 .80453 L p .707 .577 .707 r
F P
0 g
s
.20117 .80816 m .20234 .82565 L .22983 .83082 L p .707 .577 .707 r
F P
0 g
s
.16012 .7129 m .16053 .74966 L .17313 .75818 L p .707 .577 .707 r
F P
0 g
s
.16346 .6162 m .15456 .67273 L .15841 .66923 L p .707 .577 .707 r
F P
0 g
s
.15841 .66923 m .16732 .6127 L .16346 .6162 L p .707 .577 .707 r
F P
0 g
s
.53161 .80383 m .53043 .78635 L .55434 .77627 L p .707 .577 .707 r
F P
0 g
s
.20234 .82565 m .20117 .80816 L .18004 .79945 L p .707 .577 .707 r
F P
0 g
s
.55434 .77627 m .55551 .79376 L .53161 .80383 L p .707 .577 .707 r
F P
0 g
s
.18004 .79945 m .18121 .81694 L .20234 .82565 L p .707 .577 .707 r
F P
0 g
s
.674 .77264 m .67517 .79012 L .64769 .78495 L p .707 .577 .707 r
F P
0 g
s
.64769 .78495 m .64651 .76747 L .674 .77264 L p .707 .577 .707 r
F P
0 g
s
.34473 .79445 m .34591 .81194 L .36212 .79966 L p .707 .577 .707 r
F P
0 g
s
.16053 .74966 m .16012 .7129 L .15722 .70356 L p .707 .577 .707 r
F P
0 g
s
.55551 .79376 m .55434 .77627 L .5836 .76938 L p .707 .577 .707 r
F P
0 g
s
.15722 .70356 m .15763 .74032 L .16053 .74966 L p .707 .577 .707 r
F P
0 g
s
.18121 .81694 m .18004 .79945 L .16733 .78806 L p .707 .577 .707 r
F P
0 g
s
.16949 .62119 m .16058 .67772 L .15456 .67273 L p .707 .577 .707 r
F P
0 g
s
.15456 .67273 m .16346 .6162 L .16949 .62119 L p .707 .577 .707 r
F P
0 g
s
.5836 .76938 m .58478 .78686 L .55551 .79376 L p .707 .577 .707 r
F P
0 g
s
.16733 .78806 m .16851 .80554 L .18121 .81694 L p .707 .577 .707 r
F P
0 g
s
.64996 .28493 m .63195 .79672 L .6278 .78831 L p .707 .577 .707 r
F P
0 g
s
.6278 .78831 m .6458 .27652 L .64996 .28493 L p .707 .577 .707 r
F P
0 g
s
.15763 .74032 m .15722 .70356 L .16429 .69432 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16851 .80554 m .16733 .78806 L .16429 .77508 L p .707 .577 .707 r
F P
0 g
s
.16429 .69432 m .16471 .73108 L .15763 .74032 L p .707 .577 .707 r
F P
0 g
s
.18479 .62718 m .17589 .68371 L .16058 .67772 L p .707 .577 .707 r
F P
0 g
s
.16058 .67772 m .16949 .62119 L .18479 .62718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16429 .77508 m .16547 .79257 L .16851 .80554 L p .707 .577 .707 r
F P
0 g
s
.36786 .7689 m .36904 .78639 L .366 .77342 L p .707 .577 .707 r
F P
0 g
s
.366 .77342 m .36482 .75593 L .36786 .7689 L p .707 .577 .707 r
F P
0 g
s
.16471 .73108 m .16429 .69432 L .18066 .68607 L p .707 .577 .707 r
F P
0 g
s
.34803 .65173 m .33913 .70826 L .31758 .70794 L p .707 .577 .707 r
F P
0 g
s
.6458 .27652 m .6278 .78831 L .60997 .78008 L p .707 .577 .707 r
F P
0 g
s
.60997 .78008 m .62798 .26829 L .6458 .27652 L p .707 .577 .707 r
F P
0 g
s
.16547 .79257 m .16429 .77508 L .17121 .76181 L p .707 .577 .707 r
F P
0 g
s
.18066 .68607 m .18107 .72283 L .16471 .73108 L p .707 .577 .707 r
F P
0 g
s
.31758 .70794 m .32649 .65141 L .34803 .65173 L p .707 .577 .707 r
F P
0 g
s
.20789 .63358 m .19898 .69011 L .17589 .68371 L p .707 .577 .707 r
F P
0 g
s
.17589 .68371 m .18479 .62718 L .20789 .63358 L p .707 .577 .707 r
F P
0 g
s
.34561 .68758 m .34602 .72434 L .32496 .71748 L p .707 .577 .707 r
F P
0 g
s
.32496 .71748 m .32455 .68072 L .34561 .68758 L p .707 .577 .707 r
F P
0 g
s
.17121 .76181 m .17239 .7793 L .16547 .79257 L p .707 .577 .707 r
F P
0 g
s
.35417 .77574 m .37217 .26395 L .39521 .25759 L p .707 .577 .707 r
F P
0 g
s
.19898 .69011 m .20789 .63358 L .23651 .63976 L p .707 .577 .707 r
F P
0 g
s
.18107 .72283 m .18066 .68607 L .20471 .67962 L p .707 .577 .707 r
F P
0 g
s
.32649 .65141 m .31758 .70794 L .28996 .70566 L p .707 .577 .707 r
F P
0 g
s
.23651 .63976 m .22761 .69629 L .19898 .69011 L p .707 .577 .707 r
F P
0 g
s
.28996 .70566 m .29887 .64914 L .32649 .65141 L p .707 .577 .707 r
F P
0 g
s
.17239 .7793 m .17121 .76181 L .18742 .74954 L p .707 .577 .707 r
F P
0 g
s
.20471 .67962 m .20512 .71638 L .18107 .72283 L p .707 .577 .707 r
F P
0 g
s
.32455 .68072 m .32496 .71748 L .29751 .71295 L p .707 .577 .707 r
F P
0 g
s
.29751 .71295 m .29709 .67619 L .32455 .68072 L p .707 .577 .707 r
F P
0 g
s
.29887 .64914 m .28996 .70566 L .25895 .70165 L p .707 .577 .707 r
F P
0 g
s
.18742 .74954 m .1886 .76702 L .17239 .7793 L p .707 .577 .707 r
F P
0 g
s
.71005 .55417 m .70115 .6107 L .73215 .61472 L p .707 .577 .707 r
F P
0 g
s
.73215 .61472 m .74106 .55819 L .71005 .55417 L p .707 .577 .707 r
F P
0 g
s
.74106 .55819 m .73215 .61472 L .7635 .62008 L p .707 .577 .707 r
F P
0 g
s
.62798 .26829 m .60997 .78008 L .58021 .77283 L p .707 .577 .707 r
F P
0 g
s
.58021 .77283 m .59822 .26103 L .62798 .26829 L p .707 .577 .707 r
F P
0 g
s
.22761 .69629 m .23651 .63976 L .26786 .64512 L p .707 .577 .707 r
F P
0 g
s
.20512 .71638 m .20471 .67962 L .23408 .67561 L p .707 .577 .707 r
F P
0 g
s
.26786 .64512 m .25895 .70165 L .22761 .69629 L p .707 .577 .707 r
F P
0 g
s
.7635 .62008 m .7724 .56355 L .74106 .55819 L p .707 .577 .707 r
F P
0 g
s
.7724 .56355 m .7635 .62008 L .79212 .62626 L p .707 .577 .707 r
F P
0 g
s
.25895 .70165 m .26786 .64512 L .29887 .64914 L p .707 .577 .707 r
F P
0 g
s
.68243 .55189 m .67352 .60842 L .70115 .6107 L p .707 .577 .707 r
F P
0 g
s
.70115 .6107 m .71005 .55417 L .68243 .55189 L p .707 .577 .707 r
F P
0 g
s
.29709 .67619 m .29751 .71295 L .26633 .71119 L p .707 .577 .707 r
F P
0 g
s
.26633 .71119 m .26592 .67443 L .29709 .67619 L p .707 .577 .707 r
F P
0 g
s
.79212 .62626 m .80103 .56973 L .7724 .56355 L p .707 .577 .707 r
F P
0 g
s
.23408 .67561 m .2345 .71237 L .20512 .71638 L p .707 .577 .707 r
F P
0 g
s
.2345 .71237 m .23408 .67561 L .26592 .67443 L p .707 .577 .707 r
F P
0 g
s
.39521 .25759 m .3772 .76938 L .35417 .77574 L p .707 .577 .707 r
F P
0 g
s
.3772 .76938 m .39521 .25759 L .4291 .25326 L p .707 .577 .707 r
F P
0 g
s
.26592 .67443 m .26633 .71119 L .2345 .71237 L p .707 .577 .707 r
F P
0 g
s
.80103 .56973 m .79212 .62626 L .81522 .63266 L p .707 .577 .707 r
F P
0 g
s
.1886 .76702 m .18742 .74954 L .21133 .73946 L p .707 .577 .707 r
F P
0 g
s
.73303 .72537 m .73261 .68861 L .70144 .68685 L p .707 .577 .707 r
F P
0 g
s
.73261 .68861 m .73303 .72537 L .76486 .72419 L p .707 .577 .707 r
F P
0 g
s
.76486 .72419 m .76445 .68743 L .73261 .68861 L p .707 .577 .707 r
F P
0 g
s
.66088 .55158 m .65198 .60811 L .67352 .60842 L p .707 .577 .707 r
F P
0 g
s
.67352 .60842 m .68243 .55189 L .66088 .55158 L p .707 .577 .707 r
F P
0 g
s
.81522 .63266 m .82412 .57613 L .80103 .56973 L p .707 .577 .707 r
F P
0 g
s
.21133 .73946 m .2125 .75694 L .1886 .76702 L p .707 .577 .707 r
F P
0 g
s
.76445 .68743 m .76486 .72419 L .79424 .72018 L p .707 .577 .707 r
F P
0 g
s
.79424 .72018 m .79383 .68342 L .76445 .68743 L p .707 .577 .707 r
F P
0 g
s
.33099 .73582 m .33216 .75331 L .30468 .74814 L p .707 .577 .707 r
F P
0 g
s
.30468 .74814 m .3035 .73065 L .33099 .73582 L p .707 .577 .707 r
F P
0 g
s
.70186 .72361 m .70144 .68685 L .67398 .68232 L p .707 .577 .707 r
F P
0 g
s
.70144 .68685 m .70186 .72361 L .73303 .72537 L p .707 .577 .707 r
F P
0 g
s
.59822 .26103 m .58021 .77283 L .54143 .76726 L p .707 .577 .707 r
F P
0 g
s
.54143 .76726 m .55944 .25547 L .59822 .26103 L p .707 .577 .707 r
F P
0 g
s
.2125 .75694 m .21133 .73946 L .24059 .73256 L p .707 .577 .707 r
F P
0 g
s
.79383 .68342 m .79424 .72018 L .81829 .71373 L p .707 .577 .707 r
F P
0 g
s
.81829 .71373 m .81788 .67697 L .79383 .68342 L p .707 .577 .707 r
F P
0 g
s
.82412 .57613 m .81522 .63266 L .83053 .63864 L p .707 .577 .707 r
F P
0 g
s
.67398 .68232 m .6744 .71908 L .70186 .72361 L p .707 .577 .707 r
F P
0 g
s
.3035 .73065 m .30468 .74814 L .27353 .74701 L p .707 .577 .707 r
F P
0 g
s
.27353 .74701 m .27236 .72953 L .3035 .73065 L p .707 .577 .707 r
F P
0 g
s
.24059 .73256 m .24177 .75005 L .2125 .75694 L p .707 .577 .707 r
F P
0 g
s
.4111 .76505 m .4291 .25326 L .47053 .25139 L p .707 .577 .707 r
F P
0 g
s
.4291 .25326 m .4111 .76505 L .3772 .76938 L p .707 .577 .707 r
F P
0 g
s
.6744 .71908 m .67398 .68232 L .65293 .67546 L p .707 .577 .707 r
F P
0 g
s
.83053 .63864 m .83943 .58211 L .82412 .57613 L p .707 .577 .707 r
F P
0 g
s
.24177 .75005 m .24059 .73256 L .27236 .72953 L p .707 .577 .707 r
F P
0 g
s
.64753 .55326 m .63862 .60978 L .65198 .60811 L p .707 .577 .707 r
F P
0 g
s
.65198 .60811 m .66088 .55158 L .64753 .55326 L p .707 .577 .707 r
F P
0 g
s
.27236 .72953 m .27353 .74701 L .24177 .75005 L p .707 .577 .707 r
F P
0 g
s
.65293 .67546 m .65334 .71222 L .6744 .71908 L p .707 .577 .707 r
F P
0 g
s
.55944 .25547 m .54143 .76726 L .49744 .76394 L p .707 .577 .707 r
F P
0 g
s
.49744 .76394 m .51544 .25215 L .55944 .25547 L p .707 .577 .707 r
F P
0 g
s
.81788 .67697 m .81829 .71373 L .83466 .70548 L p .707 .577 .707 r
F P
0 g
s
.83466 .70548 m .83424 .66872 L .81788 .67697 L p .707 .577 .707 r
F P
0 g
s
.74119 .76268 m .74001 .74519 L .70886 .74407 L p .707 .577 .707 r
F P
0 g
s
.74001 .74519 m .74119 .76268 L .77295 .75964 L p .707 .577 .707 r
F P
0 g
s
.77295 .75964 m .77177 .74216 L .74001 .74519 L p .707 .577 .707 r
F P
0 g
s
.77177 .74216 m .77295 .75964 L .80222 .75275 L p .707 .577 .707 r
F P
0 g
s
.80222 .75275 m .80104 .73527 L .77177 .74216 L p .707 .577 .707 r
F P
0 g
s
.45253 .76318 m .47053 .25139 L .51544 .25215 L p .707 .577 .707 r
F P
0 g
s
.47053 .25139 m .45253 .76318 L .4111 .76505 L p .707 .577 .707 r
F P
0 g
s
.71004 .76155 m .70886 .74407 L .68138 .7389 L p .707 .577 .707 r
F P
0 g
s
.70886 .74407 m .71004 .76155 L .74119 .76268 L p .707 .577 .707 r
F P
0 g
s
.83943 .58211 m .83053 .63864 L .83655 .64363 L p .707 .577 .707 r
F P
0 g
s
.51544 .25215 m .49744 .76394 L .45253 .76318 L p .707 .577 .707 r
F P
0 g
s
.65334 .71222 m .65293 .67546 L .64033 .66694 L p .707 .577 .707 r
F P
0 g
s
.80104 .73527 m .80222 .75275 L .82612 .74267 L p .707 .577 .707 r
F P
0 g
s
.82612 .74267 m .82495 .72519 L .80104 .73527 L p .707 .577 .707 r
F P
0 g
s
.68138 .7389 m .68256 .75638 L .71004 .76155 L p .707 .577 .707 r
F P
0 g
s
.83655 .64363 m .84545 .5871 L .83943 .58211 L p .707 .577 .707 r
F P
0 g
s
.64368 .55676 m .63477 .61329 L .63862 .60978 L p .707 .577 .707 r
F P
0 g
s
.63862 .60978 m .64753 .55326 L .64368 .55676 L p .707 .577 .707 r
F P
0 g
s
.64033 .66694 m .64075 .7037 L .65334 .71222 L p .707 .577 .707 r
F P
0 g
s
.68256 .75638 m .68138 .7389 L .66025 .73019 L p .707 .577 .707 r
F P
0 g
s
.83424 .66872 m .83466 .70548 L .84173 .69624 L p .707 .577 .707 r
F P
0 g
s
.84173 .69624 m .84132 .65948 L .83424 .66872 L p .707 .577 .707 r
F P
0 g
s
.66025 .73019 m .66143 .74767 L .68256 .75638 L p .707 .577 .707 r
F P
0 g
s
.82495 .72519 m .82612 .74267 L .84233 .7304 L p .707 .577 .707 r
F P
0 g
s
.84233 .7304 m .84116 .71291 L .82495 .72519 L p .707 .577 .707 r
F P
0 g
s
.64075 .7037 m .64033 .66694 L .63743 .65761 L p .707 .577 .707 r
F P
0 g
s
.84545 .5871 m .83655 .64363 L .83269 .64714 L p .707 .577 .707 r
F P
0 g
s
.66143 .74767 m .66025 .73019 L .64754 .71879 L p .707 .577 .707 r
F P
0 g
s
.83269 .64714 m .8416 .59061 L .84545 .5871 L p .707 .577 .707 r
F P
0 g
s
.6497 .56175 m .64079 .61828 L .63477 .61329 L p .707 .577 .707 r
F P
0 g
s
.63477 .61329 m .64368 .55676 L .6497 .56175 L p .707 .577 .707 r
F P
0 g
s
.63743 .65761 m .63785 .69437 L .64075 .7037 L p .707 .577 .707 r
F P
0 g
s
.64754 .71879 m .64872 .73628 L .66143 .74767 L p .707 .577 .707 r
F P
0 g
s
.84132 .65948 m .84173 .69624 L .83883 .6869 L p .707 .577 .707 r
F P
0 g
s
.83883 .6869 m .83842 .65014 L .84132 .65948 L p .707 .577 .707 r
F P
0 g
s
.84116 .71291 m .84233 .7304 L .84926 .71712 L p .707 .577 .707 r
F P
0 g
s
.84926 .71712 m .84808 .69964 L .84116 .71291 L p .707 .577 .707 r
F P
0 g
s
.63785 .69437 m .63743 .65761 L .64451 .64836 L p .707 .577 .707 r
F P
0 g
s
.8416 .59061 m .83269 .64714 L .81934 .64881 L p .707 .577 .707 r
F P
0 g
s
.64872 .73628 m .64754 .71879 L .6445 .70582 L p .707 .577 .707 r
F P
0 g
s
.36704 .51736 m .35814 .57388 L .38914 .5779 L p .707 .577 .707 r
F P
0 g
s
.38914 .5779 m .39805 .52137 L .36704 .51736 L p .707 .577 .707 r
F P
0 g
s
.39805 .52137 m .38914 .5779 L .42049 .58326 L p .707 .577 .707 r
F P
0 g
s
.81934 .64881 m .82825 .59228 L .8416 .59061 L p .707 .577 .707 r
F P
0 g
s
.42049 .58326 m .4294 .52673 L .39805 .52137 L p .707 .577 .707 r
F P
0 g
s
.4294 .52673 m .42049 .58326 L .44911 .58944 L p .707 .577 .707 r
F P
0 g
s
.6445 .70582 m .64568 .72331 L .64872 .73628 L p .707 .577 .707 r
F P
0 g
s
.64451 .64836 m .64492 .68512 L .63785 .69437 L p .707 .577 .707 r
F P
0 g
s
.66501 .56774 m .6561 .62426 L .64079 .61828 L p .707 .577 .707 r
F P
0 g
s
.64079 .61828 m .6497 .56175 L .66501 .56774 L p .707 .577 .707 r
F P
0 g
s
.33942 .51508 m .33051 .57161 L .35814 .57388 L p .707 .577 .707 r
F P
0 g
s
.35814 .57388 m .36704 .51736 L .33942 .51508 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84808 .69964 m .84926 .71712 L .84621 .70415 L p .707 .577 .707 r
F P
0 g
s
.84621 .70415 m .84504 .68667 L .84808 .69964 L p .707 .577 .707 r
F P
0 g
s
.44911 .58944 m .45802 .53291 L .4294 .52673 L p .707 .577 .707 r
F P
0 g
s
.83842 .65014 m .83883 .6869 L .82624 .67838 L p .707 .577 .707 r
F P
0 g
s
.82624 .67838 m .82582 .64162 L .83842 .65014 L p .707 .577 .707 r
F P
0 g
s
.45802 .53291 m .44911 .58944 L .47221 .59584 L p .707 .577 .707 r
F P
0 g
s
.39002 .68856 m .3896 .6518 L .35843 .65004 L p .707 .577 .707 r
F P
0 g
s
.3896 .6518 m .39002 .68856 L .42185 .68737 L p .707 .577 .707 r
F P
0 g
s
.42185 .68737 m .42144 .65061 L .3896 .6518 L p .707 .577 .707 r
F P
0 g
s
.31787 .51476 m .30897 .57129 L .33051 .57161 L p .707 .577 .707 r
F P
0 g
s
.33051 .57161 m .33942 .51508 L .31787 .51476 L p .707 .577 .707 r
F P
0 g
s
.47221 .59584 m .48111 .53931 L .45802 .53291 L p .707 .577 .707 r
F P
0 g
s
.64492 .68512 m .64451 .64836 L .66087 .64011 L p .707 .577 .707 r
F P
0 g
s
.82825 .59228 m .81934 .64881 L .7978 .6485 L p .707 .577 .707 r
F P
0 g
s
.42144 .65061 m .42185 .68737 L .45123 .68336 L p .707 .577 .707 r
F P
0 g
s
.45123 .68336 m .45082 .6466 L .42144 .65061 L p .707 .577 .707 r
F P
0 g
s
.64568 .72331 m .6445 .70582 L .65142 .69255 L p .707 .577 .707 r
F P
0 g
s
.35885 .6868 m .35843 .65004 L .33097 .6455 L p .707 .577 .707 r
F P
0 g
s
.35843 .65004 m .35885 .6868 L .39002 .68856 L p .707 .577 .707 r
F P
0 g
s
.7978 .6485 m .80671 .59197 L .82825 .59228 L p .707 .577 .707 r
F P
0 g
s
.6881 .57413 m .6792 .63066 L .6561 .62426 L p .707 .577 .707 r
F P
0 g
s
.6561 .62426 m .66501 .56774 L .6881 .57413 L p .707 .577 .707 r
F P
0 g
s
.65142 .69255 m .6526 .71003 L .64568 .72331 L p .707 .577 .707 r
F P
0 g
s
.66087 .64011 m .66129 .67687 L .64492 .68512 L p .707 .577 .707 r
F P
0 g
s
.45082 .6466 m .45123 .68336 L .47528 .67692 L p .707 .577 .707 r
F P
0 g
s
.47528 .67692 m .47487 .64016 L .45082 .6466 L p .707 .577 .707 r
F P
0 g
s
.48111 .53931 m .47221 .59584 L .48752 .60183 L p .707 .577 .707 r
F P
0 g
s
.84504 .68667 m .84621 .70415 L .83351 .69275 L p .707 .577 .707 r
F P
0 g
s
.83351 .69275 m .83233 .67527 L .84504 .68667 L p .707 .577 .707 r
F P
0 g
s
.82582 .64162 m .82624 .67838 L .80518 .67152 L p .707 .577 .707 r
F P
0 g
s
.80518 .67152 m .80476 .63476 L .82582 .64162 L p .707 .577 .707 r
F P
0 g
s
.33097 .6455 m .33139 .68226 L .35885 .6868 L p .707 .577 .707 r
F P
0 g
s
.33139 .68226 m .33097 .6455 L .30992 .63864 L p .707 .577 .707 r
F P
0 g
s
.48752 .60183 m .49642 .5453 L .48111 .53931 L p .707 .577 .707 r
F P
0 g
s
.30452 .51644 m .29561 .57297 L .30897 .57129 L p .707 .577 .707 r
F P
0 g
s
.30897 .57129 m .31787 .51476 L .30452 .51644 L p .707 .577 .707 r
F P
0 g
s
.80671 .59197 m .7978 .6485 L .77017 .64622 L p .707 .577 .707 r
F P
0 g
s
.66129 .67687 m .66087 .64011 L .68492 .63366 L p .707 .577 .707 r
F P
0 g
s
.6526 .71003 m .65142 .69255 L .66763 .68027 L p .707 .577 .707 r
F P
0 g
s
.71673 .58031 m .70782 .63684 L .6792 .63066 L p .707 .577 .707 r
F P
0 g
s
.6792 .63066 m .6881 .57413 L .71673 .58031 L p .707 .577 .707 r
F P
0 g
s
.77017 .64622 m .77908 .58969 L .80671 .59197 L p .707 .577 .707 r
F P
0 g
s
.30992 .63864 m .31033 .6754 L .33139 .68226 L p .707 .577 .707 r
F P
0 g
s
.47487 .64016 m .47528 .67692 L .49165 .66867 L p .707 .577 .707 r
F P
0 g
s
.49165 .66867 m .49123 .63191 L .47487 .64016 L p .707 .577 .707 r
F P
0 g
s
.39818 .72586 m .397 .70838 L .36585 .70725 L p .707 .577 .707 r
F P
0 g
s
.397 .70838 m .39818 .72586 L .42994 .72283 L p .707 .577 .707 r
F P
0 g
s
.42994 .72283 m .42876 .70534 L .397 .70838 L p .707 .577 .707 r
F P
0 g
s
.42876 .70534 m .42994 .72283 L .45921 .71593 L p .707 .577 .707 r
F P
0 g
s
.45921 .71593 m .45803 .69845 L .42876 .70534 L p .707 .577 .707 r
F P
0 g
s
.68492 .63366 m .68534 .67042 L .66129 .67687 L p .707 .577 .707 r
F P
0 g
s
.66763 .68027 m .66881 .69776 L .6526 .71003 L p .707 .577 .707 r
F P
0 g
s
.80476 .63476 m .80518 .67152 L .77772 .66699 L p .707 .577 .707 r
F P
0 g
s
.77772 .66699 m .7773 .63023 L .80476 .63476 L p .707 .577 .707 r
F P
0 g
s
.77908 .58969 m .77017 .64622 L .73917 .6422 L p .707 .577 .707 r
F P
0 g
s
.36703 .72474 m .36585 .70725 L .33837 .70209 L p .707 .577 .707 r
F P
0 g
s
.36585 .70725 m .36703 .72474 L .39818 .72586 L p .707 .577 .707 r
F P
0 g
s
.49642 .5453 m .48752 .60183 L .49354 .60682 L p .707 .577 .707 r
F P
0 g
s
.83233 .67527 m .83351 .69275 L .81238 .68404 L p .707 .577 .707 r
F P
0 g
s
.81238 .68404 m .8112 .66656 L .83233 .67527 L p .707 .577 .707 r
F P
0 g
s
.74808 .58568 m .73917 .6422 L .70782 .63684 L p .707 .577 .707 r
F P
0 g
s
.70782 .63684 m .71673 .58031 L .74808 .58568 L p .707 .577 .707 r
F P
0 g
s
.31033 .6754 m .30992 .63864 L .29732 .63013 L p .707 .577 .707 r
F P
0 g
s
.45803 .69845 m .45921 .71593 L .48311 .70586 L p .707 .577 .707 r
F P
0 g
s
.48311 .70586 m .48194 .68837 L .45803 .69845 L p .707 .577 .707 r
F P
0 g
s
.68534 .67042 m .68492 .63366 L .7143 .62965 L p .707 .577 .707 r
F P
0 g
s
.73917 .6422 m .74808 .58568 L .77908 .58969 L p .707 .577 .707 r
F P
0 g
s
.33837 .70209 m .33955 .71957 L .36703 .72474 L p .707 .577 .707 r
F P
0 g
s
.49354 .60682 m .50244 .55029 L .49642 .5453 L p .707 .577 .707 r
F P
0 g
s
.30067 .51994 m .29176 .57647 L .29561 .57297 L p .707 .577 .707 r
F P
0 g
s
.29561 .57297 m .30452 .51644 L .30067 .51994 L p .707 .577 .707 r
F P
0 g
s
.7773 .63023 m .77772 .66699 L .74655 .66523 L p .707 .577 .707 r
F P
0 g
s
.74655 .66523 m .74613 .62847 L .7773 .63023 L p .707 .577 .707 r
F P
0 g
s
.66881 .69776 m .66763 .68027 L .69154 .67019 L p .707 .577 .707 r
F P
0 g
s
.29732 .63013 m .29774 .66689 L .31033 .6754 L p .707 .577 .707 r
F P
0 g
s
.33955 .71957 m .33837 .70209 L .31724 .69337 L p .707 .577 .707 r
F P
0 g
s
.7143 .62965 m .71471 .66641 L .68534 .67042 L p .707 .577 .707 r
F P
0 g
s
.71471 .66641 m .7143 .62965 L .74613 .62847 L p .707 .577 .707 r
F P
0 g
s
.49123 .63191 m .49165 .66867 L .49872 .65942 L p .707 .577 .707 r
F P
0 g
s
.49872 .65942 m .49831 .62266 L .49123 .63191 L p .707 .577 .707 r
F P
0 g
s
.74613 .62847 m .74655 .66523 L .71471 .66641 L p .707 .577 .707 r
F P
0 g
s
.69154 .67019 m .69272 .68768 L .66881 .69776 L p .707 .577 .707 r
F P
0 g
s
.31724 .69337 m .31842 .71086 L .33955 .71957 L p .707 .577 .707 r
F P
0 g
s
.8112 .66656 m .81238 .68404 L .78489 .67887 L p .707 .577 .707 r
F P
0 g
s
.78489 .67887 m .78372 .66139 L .8112 .66656 L p .707 .577 .707 r
F P
0 g
s
.48194 .68837 m .48311 .70586 L .49932 .69358 L p .707 .577 .707 r
F P
0 g
s
.49932 .69358 m .49815 .6761 L .48194 .68837 L p .707 .577 .707 r
F P
0 g
s
.29774 .66689 m .29732 .63013 L .29442 .62079 L p .707 .577 .707 r
F P
0 g
s
.50244 .55029 m .49354 .60682 L .48968 .61032 L p .707 .577 .707 r
F P
0 g
s
.69272 .68768 m .69154 .67019 L .72081 .6633 L p .707 .577 .707 r
F P
0 g
s
.31842 .71086 m .31724 .69337 L .30453 .68198 L p .707 .577 .707 r
F P
0 g
s
.78372 .66139 m .78489 .67887 L .75375 .67775 L p .707 .577 .707 r
F P
0 g
s
.75375 .67775 m .75257 .66027 L .78372 .66139 L p .707 .577 .707 r
F P
0 g
s
.48968 .61032 m .49859 .55379 L .50244 .55029 L p .707 .577 .707 r
F P
0 g
s
.72081 .6633 m .72199 .68078 L .69272 .68768 L p .707 .577 .707 r
F P
0 g
s
.30669 .52493 m .29778 .58146 L .29176 .57647 L p .707 .577 .707 r
F P
0 g
s
.29176 .57647 m .30067 .51994 L .30669 .52493 L p .707 .577 .707 r
F P
0 g
s
.29442 .62079 m .29483 .65755 L .29774 .66689 L p .707 .577 .707 r
F P
0 g
s
.72199 .68078 m .72081 .6633 L .75257 .66027 L p .707 .577 .707 r
F P
0 g
s
.30453 .68198 m .30571 .69946 L .31842 .71086 L p .707 .577 .707 r
F P
0 g
s
.75257 .66027 m .75375 .67775 L .72199 .68078 L p .707 .577 .707 r
F P
0 g
s
.49831 .62266 m .49872 .65942 L .49582 .65008 L p .707 .577 .707 r
F P
0 g
s
.49582 .65008 m .49541 .61332 L .49831 .62266 L p .707 .577 .707 r
F P
0 g
s
.49815 .6761 m .49932 .69358 L .50625 .68031 L p .707 .577 .707 r
F P
0 g
s
.50625 .68031 m .50507 .66282 L .49815 .6761 L p .707 .577 .707 r
F P
0 g
s
.29483 .65755 m .29442 .62079 L .3015 .61154 L p .707 .577 .707 r
F P
0 g
s
.49859 .55379 m .48968 .61032 L .47633 .612 L p .707 .577 .707 r
F P
0 g
s
.30571 .69946 m .30453 .68198 L .30149 .66901 L p .707 .577 .707 r
F P
0 g
s
.47633 .612 m .48524 .55547 L .49859 .55379 L p .707 .577 .707 r
F P
0 g
s
.30149 .66901 m .30267 .68649 L .30571 .69946 L p .707 .577 .707 r
F P
0 g
s
.3015 .61154 m .30191 .6483 L .29483 .65755 L p .707 .577 .707 r
F P
0 g
s
.322 .53092 m .31309 .58745 L .29778 .58146 L p .707 .577 .707 r
F P
0 g
s
.29778 .58146 m .30669 .52493 L .322 .53092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50507 .66282 m .50625 .68031 L .5032 .66734 L p .707 .577 .707 r
F P
0 g
s
.5032 .66734 m .50203 .64985 L .50507 .66282 L p .707 .577 .707 r
F P
0 g
s
.49541 .61332 m .49582 .65008 L .48323 .64157 L p .707 .577 .707 r
F P
0 g
s
.48323 .64157 m .48281 .60481 L .49541 .61332 L p .707 .577 .707 r
F P
0 g
s
.30191 .6483 m .3015 .61154 L .31786 .60329 L p .707 .577 .707 r
F P
0 g
s
.48524 .55547 m .47633 .612 L .45479 .61168 L p .707 .577 .707 r
F P
0 g
s
.30267 .68649 m .30149 .66901 L .30841 .65573 L p .707 .577 .707 r
F P
0 g
s
.45479 .61168 m .4637 .55515 L .48524 .55547 L p .707 .577 .707 r
F P
0 g
s
.34509 .53732 m .33619 .59385 L .31309 .58745 L p .707 .577 .707 r
F P
0 g
s
.31309 .58745 m .322 .53092 L .34509 .53732 L p .707 .577 .707 r
F P
0 g
s
.30841 .65573 m .30959 .67322 L .30267 .68649 L p .707 .577 .707 r
F P
0 g
s
.31786 .60329 m .31828 .64005 L .30191 .6483 L p .707 .577 .707 r
F P
0 g
s
.50203 .64985 m .5032 .66734 L .4905 .65594 L p .707 .577 .707 r
F P
0 g
s
.4905 .65594 m .48932 .63846 L .50203 .64985 L p .707 .577 .707 r
F P
0 g
s
.48281 .60481 m .48323 .64157 L .46217 .63471 L p .707 .577 .707 r
F P
0 g
s
.46217 .63471 m .46175 .59795 L .48281 .60481 L p .707 .577 .707 r
F P
0 g
s
.4637 .55515 m .45479 .61168 L .42716 .6094 L p .707 .577 .707 r
F P
0 g
s
.31828 .64005 m .31786 .60329 L .34191 .59685 L p .707 .577 .707 r
F P
0 g
s
.30959 .67322 m .30841 .65573 L .32462 .64346 L p .707 .577 .707 r
F P
0 g
s
.37372 .5435 m .36481 .60003 L .33619 .59385 L p .707 .577 .707 r
F P
0 g
s
.33619 .59385 m .34509 .53732 L .37372 .5435 L p .707 .577 .707 r
F P
0 g
s
.42716 .6094 m .43607 .55288 L .4637 .55515 L p .707 .577 .707 r
F P
0 g
s
.34191 .59685 m .34233 .63361 L .31828 .64005 L p .707 .577 .707 r
F P
0 g
s
.32462 .64346 m .3258 .66094 L .30959 .67322 L p .707 .577 .707 r
F P
0 g
s
.46175 .59795 m .46217 .63471 L .43471 .63018 L p .707 .577 .707 r
F P
0 g
s
.43471 .63018 m .43429 .59342 L .46175 .59795 L p .707 .577 .707 r
F P
0 g
s
.43607 .55288 m .42716 .6094 L .39616 .60539 L p .707 .577 .707 r
F P
0 g
s
.48932 .63846 m .4905 .65594 L .46937 .64723 L p .707 .577 .707 r
F P
0 g
s
.46937 .64723 m .46819 .62975 L .48932 .63846 L p .707 .577 .707 r
F P
0 g
s
.40506 .54886 m .39616 .60539 L .36481 .60003 L p .707 .577 .707 r
F P
0 g
s
.36481 .60003 m .37372 .5435 L .40506 .54886 L p .707 .577 .707 r
F P
0 g
s
.34233 .63361 m .34191 .59685 L .37129 .59284 L p .707 .577 .707 r
F P
0 g
s
.39616 .60539 m .40506 .54886 L .43607 .55288 L p .707 .577 .707 r
F P
0 g
s
.43429 .59342 m .43471 .63018 L .40354 .62841 L p .707 .577 .707 r
F P
0 g
s
.40354 .62841 m .40312 .59165 L .43429 .59342 L p .707 .577 .707 r
F P
0 g
s
.3258 .66094 m .32462 .64346 L .34853 .63338 L p .707 .577 .707 r
F P
0 g
s
.37129 .59284 m .3717 .6296 L .34233 .63361 L p .707 .577 .707 r
F P
0 g
s
.3717 .6296 m .37129 .59284 L .40312 .59165 L p .707 .577 .707 r
F P
0 g
s
.40312 .59165 m .40354 .62841 L .3717 .6296 L p .707 .577 .707 r
F P
0 g
s
.34853 .63338 m .34971 .65086 L .3258 .66094 L p .707 .577 .707 r
F P
0 g
s
.46819 .62975 m .46937 .64723 L .44188 .64206 L p .707 .577 .707 r
F P
0 g
s
.44188 .64206 m .44071 .62458 L .46819 .62975 L p .707 .577 .707 r
F P
0 g
s
.34971 .65086 m .34853 .63338 L .3778 .62649 L p .707 .577 .707 r
F P
0 g
s
.44071 .62458 m .44188 .64206 L .41074 .64094 L p .707 .577 .707 r
F P
0 g
s
.41074 .64094 m .40956 .62345 L .44071 .62458 L p .707 .577 .707 r
F P
0 g
s
.3778 .62649 m .37897 .64397 L .34971 .65086 L p .707 .577 .707 r
F P
0 g
s
.37897 .64397 m .3778 .62649 L .40956 .62345 L p .707 .577 .707 r
F P
0 g
s
.40956 .62345 m .41074 .64094 L .37897 .64397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol0081ooaT008Aoo`00MGoo2`001EYF00<005YFFUH02UYF00<005YFFUH015YF
2@00Ngoo001_Ool60004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06001eOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@0075oo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00KGoo001WOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH4001YOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000Igoo
001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Eoo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo
001UOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001FOol?0002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP04001J
EUYFFUH:0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPX000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo00D005YF001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00E7oo00<005YFFUH00`001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001DOol0
1000FUIJEP000UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001DOol00`00FUH00004FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
00030008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001VOol005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP040008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IWoo001COol01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1P000UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000goo2`00F7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF6@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0000Eoo`00001JEP0000EJEP04001JEUYFFUH9001?Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70018Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH600000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040014
Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF1000@7oo001BOol01000FUIJEP0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00
00<003aoo`00DWoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00
FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000fOol0059oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP02FUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<Woo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF00000`0025YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00<7oo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P00;Woo001FOol200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;7oo001HOol40003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01EYF
00<005YFFUH00UYF0`00;7oo001LOol50005FUHG0005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd00003FUH0000002aoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
000010001UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Goo001IOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000bOol;000HOol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000_Ool300000eYF001JEP04FUH01000
FUIJEUYF2@003Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70007Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ioo`<00003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005
Ool00000FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH?0004FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool0
1000FUIJEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00001000
1EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo
100000=JEP00FUH01UYF00<005YFFUH015YF20000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P002Woo0`0015YF2@0015YF00@005YFFUIJEPP000=JEP03001J
EUYF00=JEP04001JEUYFFUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEPD00003FUH0
05YF00MJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00=JEPH000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH60003FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH01000FUIJEUYF1`000eYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF00001@0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000eYF00<0
07ooOol0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04
0008FUH200000eYF001JEP02FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP03FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF0000000_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60002FUH200000eYF001JEP020002FUH20006FUH00`00FUIJEP04FUH6
0005FUH00`00FUIJEP06FUH50002FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF100000AJEP00001JEP<0
0003FUH005YF00EJEP03001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03
001JEUYF00@000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000goo00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP05001J
EUYFFUH00005FUH40004FUH@0006FUH00`00FUIJEP03FUH400001EYF001JEUYF00002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF00<005YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP800003FUH0000000AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00=JEPT000=JEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP800003FUH0000000=JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@002UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH00UYF20000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00:goo00@005YF
FUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009J
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00@005YFFUIJEP8002eoo`00:goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP<00003FUH005YF009JEP8002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF2@000eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YF0000009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002eoo`00;7oo0`000eYF00<005YF
FUH015YF00<005YFFUH00eYF200015YF00<005YFFUH00UYF1P0000AJEP00000000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009J
EP80009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH0000002eoo`00;goo0P0000=JEP00FUH01EYF1P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001P0000=JEP00FUH01UYF00<005YFFUH01EYF10001EYF00<005YF
FUH01UYF00<005YF00000`001EYF0`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0000=JEP00FUH01P001EYF00<005YFFUH015YF1`002Goo20000eYF00<005YF
FUH00eYF1000;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH0000015YF1P0015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF1P00
1eYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000AJEP00
0000009JEP8000IJEP03001JEUYF00@001=oo`T000EJEP04001JEP00000]Ool0039oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP02
FUHK0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH300000eYF001JEP05FUHJ0003FUH00`00FUIJEP03FUH20003FUH0
1@00FUIJEUYF0000;7oo000`Ool200000eYF001JEP03FUH00`00FUH00007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP001EYF0P0000=JEP00FUH01EYF00<005YF0000
10000UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF0P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH005YF009JEP03001o
ogoo02Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`001EYF0P0000=JEP00FUH01EYF00<005YFFUH00`000eYF00<005YF
FUH02EYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF100000=JEP00000015YF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002]oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0eYF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH025YF1000
1EYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40000
0eYF00000004FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP02000[Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH50000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04FUH30002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF1@00:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000<000IJ
EP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH000000003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000Woo0P00
:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000
FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP000003Ool3000[Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQL000AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30005Ool00`00FUH0000[Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEPH001Moo`@0009JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH0000000D00003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00EJEP03001JEP0000<000Moo`800003FUH007oo02Yoo`00;7oo00<005YF000015YF00<005YF0000
0`008Goo20001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000UYF200015YF
00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1@002Goo0P0000=JEP000000;7oo000/Ool00`00
FUH00003FUH3000COol3000COol80002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30000
15YF000000000eYF00<005YFFUH0300015YF3P003Goo00@005YFFUIJEP8002aoo`00;7oo00@005YF
001JEP800004FUH00000000AOol5000?Ool3000025YF001JEUYF001JEP00FUH@000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF
000005YF00000UYF00<005YFFUH00eYF0P0000=JEP00000017oo2@0057oo0P0015YF00<007ooOol0
:goo000/Ool01P00FUH00000FUH000AJEPD000aooa@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP0000000UYF00<005YF00001EYF00<005YF00000P002Goo
0`004goo0P0000=JEP00FUH00eYF00<007ooOol0:goo000/Ool20003FUH00`00FUIJEP03FUH01000
FUIJEUYF3P0015YF00<005YFFUH01UYF00<005YF00000`000eYF00H005YFFUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2000015YF001JEP000UYF0`001EYF00D005YFFUIJEP0001eoo`80
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPD00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP800004FUH005YF0002FUH00`00FUIJEP020003FUH01@00FUIJEUYF0000
6Woo0`001EYF00@005YF000002moo`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00002FUH01000FUIJEP000eYF1@000UYF
0P005Goo100000=JEP00FUH01EYF0P00<Goo000/Ool20003FUH00`00FUIJEP03FUH01P00FUH00000
FUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP04001JEUYFFUHI
0005FUH00`00FUIJEP04FUH00`00Oomoo`0`Ool002eoo`05001JEUYFFUH00005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH?0006FUH01`00FUH005YF001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002eoo`05001JEUYFFUH00003
FUH20005FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000eOol002ioo`800003FUH005YF00<0
00IJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`L00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Moo`00<7oo0`000UYF00<005YFFUH00eYF
1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01000>goo000`Ool00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@00004Ool005YF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000:Ool60002FUHH000oOol002moo`8000AJEP03001JEP0000<000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000Eoo`03001JEP0000IJEP03001JEUYF009J
ER<000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`D000=JEP03001J
EUYF00800003FUH0000005Aoo`00;goo0P0015YF0P0017oo200015YF00<005YFFUH00UYF2@003Goo
00<005YF00001EYF1`002UYF00<005YFFUH02UYF00<005YFFUH025YF30001EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001UYF00<005YFFUH00UYF0`00E7oo000^Ool01000FUIJEP000UYF00<007oo
Ool037oo2@005Woo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEPP000IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH500000eYF001J
EP03FUH3001DOol002ioo`03001JEUYF00<001=oo`D001Eoo`03001JEUYF0080009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@000EJEP03
001JEP0000<0009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP<000AJEP03001JEP0005Ao
o`00;Woo00@005YFFUH001Eoo`D001Eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP800003FUH005YF00MJEP04001JEUYF
FUH40004FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUH0001DOol002ioo`03
001JEP0001Ioo`D001Eoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0P000UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1000EGoo000_Ool2000GOol3000FOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH0
00001EYF00<005YFFUH015YF1`001EYF30000eYF00<005YFFUH00eYF0`00EGoo000_Ool00`00Oomo
o`0`Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH3
0006FUH00`00FUIJEP040006FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YF00000`001EYF
00@005YF000005Aoo`00;goo0P00<7oo00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000IJEP@000UJEP03001JEUYF00=JEP04001J
EP000006FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000Dgoo000_Ool01000FUH00000;7oo
0`000eYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUH000=J
EP8000=JEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH40000
0eYF001JEP02FUH00`00Oomoo`1AOol002moo`04001JEUYFFUH2000XOol20002FUH00`00FUIJEP02
FUH40006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01@00FUIJEP00FUH00P00
1EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001eYF00<005YF00000`0017oo0P000eYF00<007oo
Ool0DGoo000_Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP04001JEUYF0004Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP020007FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH5000:Ool00`00FUIJEP02001BOol002moo`05001JEUYF
FUH00004FUH3000JOol40002FUH00`00FUIJEP04FUH30009Ool50008FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUH00009FUH00`00FUIJEP07FUH00`00FUH0000:000@Ool4001BOol0031oo`04
001JEUYF0005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000@Ool60002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP03FUH7000LOol2001BOol0035oo`<000EJ
EP03001JEUYF00=JEPl000AJEP03001JEUYF00IJEP04001JEUYFFUH2000HOol90006FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH;0003Ool5000KOol2001BOol003=oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000SOolI000>Ool5000JOol3
001BOol003Eoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<003=oo`8001Moo`D001Uoo`800003FUH007oo055oo`00>7oo0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01000=Woo0P0067oo0`0067oo0P0000AJEP00FUH0059oo`00>goo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00<Goo00@005YFFUIJEP8005=oo`00?goo
4000@Goo0P0000=JEP00Ool0;Goo0P0015YF0P00Dgoo002@Ool20002FUH00`00Oomoo`0YOol20000
0eYF001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF00<002Moo`8000=JEP05001JEUYFFUH0
001EOol0095oo`04001JEUYF0002FUH2000ROol30005FUH01000FUH00000EWoo002BOol01000FUIJ
EP000eYF1@006Goo100000=JEP00FUH01EYF0P00F7oo002COol30004FUH01000FUIJEUYF2@002Goo
1`001EYF00<005YFFUH015YF00<007ooOol0Egoo002EOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00FWoo002FOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000G7oo002H
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4001NOol0
09Yoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0069oo`00Wgoo200015YF
00<005YFFUH00UYF1`00IWoo002WOol9001]Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57285 .65043 m .56394 .70696 L .59495 .71098 L p .707 .577 .707 r
F P
0 g
s
.59495 .71098 m .60385 .65445 L .57285 .65043 L p .707 .577 .707 r
F P
0 g
s
.60385 .65445 m .59495 .71098 L .62629 .71634 L p .707 .577 .707 r
F P
0 g
s
.62629 .71634 m .6352 .65981 L .60385 .65445 L p .707 .577 .707 r
F P
0 g
s
.6352 .65981 m .62629 .71634 L .65492 .72252 L p .707 .577 .707 r
F P
0 g
s
.54522 .64815 m .53632 .70468 L .56394 .70696 L p .707 .577 .707 r
F P
0 g
s
.56394 .70696 m .57285 .65043 L .54522 .64815 L p .707 .577 .707 r
F P
0 g
s
.65492 .72252 m .66382 .66599 L .6352 .65981 L p .707 .577 .707 r
F P
0 g
s
.66382 .66599 m .65492 .72252 L .67801 .72891 L p .707 .577 .707 r
F P
0 g
s
.59583 .80815 m .59541 .77139 L .56424 .76962 L p .707 .577 .707 r
F P
0 g
s
.59541 .77139 m .59583 .80815 L .62766 .80696 L p .707 .577 .707 r
F P
0 g
s
.62766 .80696 m .62724 .7702 L .59541 .77139 L p .707 .577 .707 r
F P
0 g
s
.62724 .7702 m .62766 .80696 L .65704 .80295 L p .707 .577 .707 r
F P
0 g
s
.65704 .80295 m .65662 .76619 L .62724 .7702 L p .707 .577 .707 r
F P
0 g
s
.52368 .64784 m .51477 .70437 L .53632 .70468 L p .707 .577 .707 r
F P
0 g
s
.53632 .70468 m .54522 .64815 L .52368 .64784 L p .707 .577 .707 r
F P
0 g
s
.67801 .72891 m .68692 .67239 L .66382 .66599 L p .707 .577 .707 r
F P
0 g
s
.56465 .80638 m .56424 .76962 L .53678 .76509 L p .707 .577 .707 r
F P
0 g
s
.56424 .76962 m .56465 .80638 L .59583 .80815 L p .707 .577 .707 r
F P
0 g
s
.65662 .76619 m .65704 .80295 L .68109 .79651 L p .707 .577 .707 r
F P
0 g
s
.68109 .79651 m .68067 .75975 L .65662 .76619 L p .707 .577 .707 r
F P
0 g
s
.53678 .76509 m .5372 .80185 L .56465 .80638 L p .707 .577 .707 r
F P
0 g
s
.68692 .67239 m .67801 .72891 L .69332 .7349 L p .707 .577 .707 r
F P
0 g
s
.5372 .80185 m .53678 .76509 L .51572 .75823 L p .707 .577 .707 r
F P
0 g
s
.69332 .7349 m .70223 .67837 L .68692 .67239 L p .707 .577 .707 r
F P
0 g
s
.51033 .64951 m .50142 .70604 L .51477 .70437 L p .707 .577 .707 r
F P
0 g
s
.51477 .70437 m .52368 .64784 L .51033 .64951 L p .707 .577 .707 r
F P
0 g
s
.51572 .75823 m .51614 .79499 L .5372 .80185 L p .707 .577 .707 r
F P
0 g
s
.68067 .75975 m .68109 .79651 L .69745 .78826 L p .707 .577 .707 r
F P
0 g
s
.69745 .78826 m .69703 .7515 L .68067 .75975 L p .707 .577 .707 r
F P
0 g
s
.60398 .86875 m .60281 .85127 L .57166 .85015 L p .707 .577 .707 r
F P
0 g
s
.60281 .85127 m .60398 .86875 L .63574 .86572 L p .707 .577 .707 r
F P
0 g
s
.63574 .86572 m .63457 .84824 L .60281 .85127 L p .707 .577 .707 r
F P
0 g
s
.63457 .84824 m .63574 .86572 L .66501 .85883 L p .707 .577 .707 r
F P
0 g
s
.66501 .85883 m .66383 .84134 L .63457 .84824 L p .707 .577 .707 r
F P
0 g
s
.51614 .79499 m .51572 .75823 L .50313 .74972 L p .707 .577 .707 r
F P
0 g
s
.70223 .67837 m .69332 .7349 L .69934 .73989 L p .707 .577 .707 r
F P
0 g
s
.57284 .86763 m .57166 .85015 L .54417 .84498 L p .707 .577 .707 r
F P
0 g
s
.57166 .85015 m .57284 .86763 L .60398 .86875 L p .707 .577 .707 r
F P
0 g
s
.69934 .73989 m .70825 .68336 L .70223 .67837 L p .707 .577 .707 r
F P
0 g
s
.66383 .84134 m .66501 .85883 L .68892 .84875 L p .707 .577 .707 r
F P
0 g
s
.68892 .84875 m .68774 .83127 L .66383 .84134 L p .707 .577 .707 r
F P
0 g
s
.54417 .84498 m .54535 .86246 L .57284 .86763 L p .707 .577 .707 r
F P
0 g
s
.50313 .74972 m .50354 .78648 L .51614 .79499 L p .707 .577 .707 r
F P
0 g
s
.50647 .65302 m .49757 .70955 L .50142 .70604 L p .707 .577 .707 r
F P
0 g
s
.50142 .70604 m .51033 .64951 L .50647 .65302 L p .707 .577 .707 r
F P
0 g
s
.69703 .7515 m .69745 .78826 L .70453 .77901 L p .707 .577 .707 r
F P
0 g
s
.70453 .77901 m .70411 .74225 L .69703 .7515 L p .707 .577 .707 r
F P
0 g
s
.54535 .86246 m .54417 .84498 L .52305 .83627 L p .707 .577 .707 r
F P
0 g
s
.52305 .83627 m .52422 .85375 L .54535 .86246 L p .707 .577 .707 r
F P
0 g
s
.68774 .83127 m .68892 .84875 L .70513 .83647 L p .707 .577 .707 r
F P
0 g
s
.70513 .83647 m .70395 .81899 L .68774 .83127 L p .707 .577 .707 r
F P
0 g
s
.50354 .78648 m .50313 .74972 L .50023 .74038 L p .707 .577 .707 r
F P
0 g
s
.70825 .68336 m .69934 .73989 L .69549 .7434 L p .707 .577 .707 r
F P
0 g
s
.69549 .7434 m .7044 .68687 L .70825 .68336 L p .707 .577 .707 r
F P
0 g
s
.50023 .74038 m .50064 .77714 L .50354 .78648 L p .707 .577 .707 r
F P
0 g
s
.52422 .85375 m .52305 .83627 L .51034 .82487 L p .707 .577 .707 r
F P
0 g
s
.5125 .65801 m .50359 .71454 L .49757 .70955 L p .707 .577 .707 r
F P
0 g
s
.49757 .70955 m .50647 .65302 L .5125 .65801 L p .707 .577 .707 r
F P
0 g
s
.70411 .74225 m .70453 .77901 L .70163 .76967 L p .707 .577 .707 r
F P
0 g
s
.70163 .76967 m .70121 .73291 L .70411 .74225 L p .707 .577 .707 r
F P
0 g
s
.47875 .81629 m .49676 .3045 L .45276 .30117 L p .707 .577 .707 r
F P
0 g
s
.50064 .77714 m .50023 .74038 L .5073 .73113 L p .707 .577 .707 r
F P
0 g
s
.51152 .84235 m .51034 .82487 L .5073 .8119 L p .707 .577 .707 r
F P
0 g
s
.5073 .73113 m .50772 .76789 L .50064 .77714 L p .707 .577 .707 r
F P
0 g
s
.5278 .664 m .5189 .72052 L .50359 .71454 L p .707 .577 .707 r
F P
0 g
s
.50359 .71454 m .5125 .65801 L .5278 .664 L p .707 .577 .707 r
F P
0 g
s
.5073 .8119 m .50847 .82938 L .51152 .84235 L p .707 .577 .707 r
F P
0 g
s
.50772 .76789 m .5073 .73113 L .52367 .72288 L p .707 .577 .707 r
F P
0 g
s
.50847 .82938 m .5073 .8119 L .51422 .79863 L p .707 .577 .707 r
F P
0 g
s
.52367 .72288 m .52408 .75964 L .50772 .76789 L p .707 .577 .707 r
F P
0 g
s
.51034 .82487 m .51152 .84235 L .52422 .85375 L p .707 .577 .707 r
F P
0 g
s
.51422 .79863 m .5154 .81611 L .50847 .82938 L p .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .51422 .79863 L .52675 .78913 L p .707 .577 .707 r
F P
0 g
s
.54199 .72692 m .5189 .72052 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.5509 .67039 m .54733 .69306 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54733 .69306 m .54199 .72692 L p .54457 .68031 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .49676 .3045 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.5154 .81611 m .52675 .78913 L .5262 .79471 L .707 .577 .707 r
F
.5189 .72052 m .5278 .664 L .5509 .67039 L p F P
0 g
s
.54199 .72692 m .54469 .70979 L p .57952 .67657 L .707 .577 .707 r
F P
0 g
s
.54469 .70979 m .5509 .67039 L .56736 .67395 L p .707 .577 .707 r
F P
0 g
s
.56736 .67395 m .57952 .67657 L p .54469 .70979 L .707 .577 .707 r
F P
0 g
s
.61087 .68194 m .60196 .73846 L .57547 .73393 L p .707 .577 .707 r
F P
0 g
s
.57547 .73393 m .57062 .7331 L p .57765 .72416 L .707 .577 .707 r
F P
0 g
s
.57765 .72416 m .61087 .68194 L .57547 .73393 L .707 .577 .707 r
F
.64187 .68595 m .63297 .74248 L .60623 .73902 L p F P
0 g
s
.60623 .73902 m .60196 .73846 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60698 .73186 m .64187 .68595 L .60623 .73902 L .707 .577 .707 r
F
.60196 .73846 m .61087 .68194 L .61225 .68211 L p F P
0 g
s
.61225 .68211 m .64187 .68595 L p .60698 .73186 L .707 .577 .707 r
F P
0 g
s
.60196 .73846 m .61225 .68211 L .60698 .73186 L .707 .577 .707 r
F
.64996 .28493 m .64003 .2927 L p .63763 .44218 L F P
0 g
s
.6695 .68823 m .66059 .74476 L .63297 .74248 L p .707 .577 .707 r
F P
0 g
s
.63297 .74248 m .64187 .68595 L .6695 .68823 L p .707 .577 .707 r
F P
0 g
s
.6401 .713 m .64052 .74977 L .60934 .748 L p .707 .577 .707 r
F P
0 g
s
.60934 .748 m .60893 .71124 L .6401 .713 L p .707 .577 .707 r
F P
0 g
s
.64651 .76747 m .64769 .78495 L .61654 .78383 L p .707 .577 .707 r
F P
0 g
s
.61654 .78383 m .61536 .76635 L .64651 .76747 L p .707 .577 .707 r
F P
0 g
s
.63195 .79672 m .64781 .34602 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64781 .34602 m .64996 .28493 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .63195 .79672 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.64003 .2927 m .63335 .48271 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.63335 .48271 m .62202 .80449 L p .63763 .44218 L .707 .577 .707 r
F P
0 g
s
.57062 .7331 m .57952 .67657 L .61087 .68194 L p .707 .577 .707 r
F P
0 g
s
.57751 .74919 m .57709 .71243 L .60893 .71124 L p .707 .577 .707 r
F P
0 g
s
.60893 .71124 m .60934 .748 L .57751 .74919 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .59899 .81085 L p .59842 .79281 L .707 .577 .707 r
F P
0 g
s
.59148 .76863 m .59603 .76819 L p .59287 .77345 L .707 .577 .707 r
F P
0 g
s
.59603 .76819 m .61536 .76635 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.57709 .71243 m .57751 .74919 L .5664 .7507 L p .707 .577 .707 r
F P
0 g
s
.5664 .7507 m .54813 .7532 L p .56297 .73231 L .707 .577 .707 r
F P
0 g
s
.57952 .67657 m .57062 .7331 L .54199 .72692 L p .707 .577 .707 r
F P
0 g
s
.56297 .73231 m .57709 .71243 L .5664 .7507 L .707 .577 .707 r
F
.54813 .7532 m .54772 .71644 L .57709 .71243 L p F P
0 g
s
.57022 .66943 m .56721 .75502 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.56721 .75502 m .56509 .81517 L p .57115 .77614 L .707 .577 .707 r
F P
0 g
s
.59341 .63276 m .56721 .75502 L .57115 .77614 L .707 .577 .707 r
F
.59842 .79281 m .57905 .72528 L .56509 .81517 L F
.58478 .78686 m .59603 .76819 L .59729 .77847 L F
.61536 .76635 m .61654 .78383 L .59815 .78559 L p F P
0 g
s
.59815 .78559 m .58478 .78686 L p .59729 .77847 L .707 .577 .707 r
F P
0 g
s
.59729 .77847 m .61536 .76635 L .59815 .78559 L .707 .577 .707 r
F
.60659 .59461 m .59949 .79654 L p .61937 .53744 L F P
0 g
s
.59949 .79654 m .59899 .81085 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61937 .53744 m .59949 .79654 L .59984 .7994 L .707 .577 .707 r
F
.59842 .79281 m .59341 .63276 L .57905 .72528 L F
.58478 .78686 m .5836 .76938 L .59148 .76863 L p F P
0 g
s
.58478 .78686 m .59148 .76863 L .59287 .77345 L .707 .577 .707 r
F
.62202 .80449 m .61937 .53744 L .59984 .7994 L F
.59899 .81085 m .60116 .81025 L p .59984 .7994 L F P
0 g
s
.60116 .81025 m .62202 .80449 L p .59984 .7994 L .707 .577 .707 r
F P
0 g
s
.61699 .29906 m .60659 .59461 L p .61937 .53744 L .707 .577 .707 r
F P
0 g
s
.5831 .30338 m .57022 .66943 L p .59341 .63276 L .707 .577 .707 r
F P
0 g
s
.52408 .75964 m .52367 .72288 L .54772 .71644 L p .707 .577 .707 r
F P
0 g
s
.54772 .71644 m .54813 .7532 L .52408 .75964 L p .707 .577 .707 r
F P
0 g
s
.52401 .81703 m .56509 .81517 L p .55206 .53137 L .707 .577 .707 r
F P
0 g
s
.53043 .78635 m .53161 .80383 L .5248 .80899 L p .707 .577 .707 r
F P
0 g
s
.5248 .80899 m .5154 .81611 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.5262 .79471 m .53043 .78635 L .5248 .80899 L .707 .577 .707 r
F
.52366 .81705 m .53072 .61639 L p .5075 .50915 L F P
0 g
s
.53072 .61639 m .54167 .30526 L p .5075 .50915 L .707 .577 .707 r
F P
0 g
s
.52675 .78913 m .53043 .78635 L p .5262 .79471 L .707 .577 .707 r
F P
0 g
s
.54167 .30526 m .52366 .81705 L .52401 .81703 L p .707 .577 .707 r
F P
0 g
s
.55206 .53137 m .54167 .30526 L .52401 .81703 L .707 .577 .707 r
F
.49676 .3045 m .47875 .81629 L .52366 .81705 L p F P
0 g
s
.70395 .81899 m .70513 .83647 L .71205 .8232 L p .707 .577 .707 r
F P
0 g
s
.71205 .8232 m .71087 .80572 L .70395 .81899 L p .707 .577 .707 r
F P
0 g
s
.56509 .81517 m .5831 .30338 L .54167 .30526 L p .707 .577 .707 r
F P
0 g
s
.43476 .81296 m .45276 .30117 L .41399 .29561 L p .707 .577 .707 r
F P
0 g
s
.45276 .30117 m .43476 .81296 L .47875 .81629 L p .707 .577 .707 r
F P
0 g
s
.7044 .68687 m .69549 .7434 L .68214 .74507 L p .707 .577 .707 r
F P
0 g
s
.22984 .61362 m .22093 .67014 L .25194 .67416 L p .707 .577 .707 r
F P
0 g
s
.25194 .67416 m .26084 .61763 L .22984 .61362 L p .707 .577 .707 r
F P
0 g
s
.26084 .61763 m .25194 .67416 L .28329 .67952 L p .707 .577 .707 r
F P
0 g
s
.59899 .81085 m .61699 .29906 L .5831 .30338 L p .707 .577 .707 r
F P
0 g
s
.68214 .74507 m .69104 .68854 L .7044 .68687 L p .707 .577 .707 r
F P
0 g
s
.28329 .67952 m .29219 .62299 L .26084 .61763 L p .707 .577 .707 r
F P
0 g
s
.29219 .62299 m .28329 .67952 L .31191 .6857 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.20221 .61134 m .19331 .66787 L .22093 .67014 L p .707 .577 .707 r
F P
0 g
s
.22093 .67014 m .22984 .61362 L .20221 .61134 L p .707 .577 .707 r
F P
0 g
s
.70121 .73291 m .70163 .76967 L .68903 .76116 L p .707 .577 .707 r
F P
0 g
s
.68903 .76116 m .68862 .7244 L .70121 .73291 L p .707 .577 .707 r
F P
0 g
s
.31191 .6857 m .32081 .62917 L .29219 .62299 L p .707 .577 .707 r
F P
0 g
s
.39598 .8074 m .41399 .29561 L .38423 .28836 L p .707 .577 .707 r
F P
0 g
s
.41399 .29561 m .39598 .8074 L .43476 .81296 L p .707 .577 .707 r
F P
0 g
s
.71087 .80572 m .71205 .8232 L .70901 .81023 L p .707 .577 .707 r
F P
0 g
s
.70901 .81023 m .70783 .79275 L .71087 .80572 L p .707 .577 .707 r
F P
0 g
s
.32081 .62917 m .31191 .6857 L .335 .6921 L p .707 .577 .707 r
F P
0 g
s
.25282 .77133 m .2524 .73457 L .22123 .73281 L p .707 .577 .707 r
F P
0 g
s
.2524 .73457 m .25282 .77133 L .28465 .77015 L p .707 .577 .707 r
F P
0 g
s
.28465 .77015 m .28423 .73339 L .2524 .73457 L p .707 .577 .707 r
F P
0 g
s
.28423 .73339 m .28465 .77015 L .31403 .76614 L p .707 .577 .707 r
F P
0 g
s
.31403 .76614 m .31361 .72938 L .28423 .73339 L p .707 .577 .707 r
F P
0 g
s
.18067 .61102 m .17176 .66755 L .19331 .66787 L p .707 .577 .707 r
F P
0 g
s
.19331 .66787 m .20221 .61134 L .18067 .61102 L p .707 .577 .707 r
F P
0 g
s
.335 .6921 m .34391 .63557 L .32081 .62917 L p .707 .577 .707 r
F P
0 g
s
.69104 .68854 m .68214 .74507 L .66059 .74476 L p .707 .577 .707 r
F P
0 g
s
.22165 .76957 m .22123 .73281 L .19377 .72828 L p .707 .577 .707 r
F P
0 g
s
.22123 .73281 m .22165 .76957 L .25282 .77133 L p .707 .577 .707 r
F P
0 g
s
.66059 .74476 m .6695 .68823 L .69104 .68854 L p .707 .577 .707 r
F P
0 g
s
.62202 .80449 m .64003 .2927 L .61699 .29906 L p .707 .577 .707 r
F P
0 g
s
.31361 .72938 m .31403 .76614 L .33808 .75969 L p .707 .577 .707 r
F P
0 g
s
.33808 .75969 m .33766 .72293 L .31361 .72938 L p .707 .577 .707 r
F P
0 g
s
.68862 .7244 m .68903 .76116 L .66797 .7543 L p .707 .577 .707 r
F P
0 g
s
.66797 .7543 m .66756 .71754 L .68862 .7244 L p .707 .577 .707 r
F P
0 g
s
.19377 .72828 m .19419 .76504 L .22165 .76957 L p .707 .577 .707 r
F P
0 g
s
.34391 .63557 m .335 .6921 L .35031 .69809 L p .707 .577 .707 r
F P
0 g
s
.19419 .76504 m .19377 .72828 L .17271 .72142 L p .707 .577 .707 r
F P
0 g
s
.70783 .79275 m .70901 .81023 L .6963 .79883 L p .707 .577 .707 r
F P
0 g
s
.6963 .79883 m .69512 .78135 L .70783 .79275 L p .707 .577 .707 r
F P
0 g
s
.35031 .69809 m .35922 .64156 L .34391 .63557 L p .707 .577 .707 r
F P
0 g
s
.36094 .78218 m .36212 .79966 L .36614 .79196 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .38423 .28836 L .37014 .28185 L p .707 .577 .707 r
F P
0 g
s
.36622 .80015 m .37014 .28185 L .36623 .78014 L .707 .577 .707 r
F
.38423 .28836 m .36622 .80015 L .39598 .8074 L p F P
0 g
s
.36619 .7849 m .36094 .78218 L .36614 .79196 L .707 .577 .707 r
F
.33766 .72293 m .33808 .75969 L .35444 .75144 L p F P
0 g
s
.35444 .75144 m .35403 .71468 L .33766 .72293 L p .707 .577 .707 r
F P
0 g
s
.35922 .64156 m .35031 .69809 L .35633 .70308 L p .707 .577 .707 r
F P
0 g
s
.35633 .70308 m .36524 .64655 L .35922 .64156 L p .707 .577 .707 r
F P
0 g
s
.35403 .71468 m .35444 .75144 L .36152 .74219 L p .707 .577 .707 r
F P
0 g
s
.36152 .74219 m .3611 .70543 L .35403 .71468 L p .707 .577 .707 r
F P
0 g
s
.36212 .79966 m .36094 .78218 L .34473 .79445 L p .707 .577 .707 r
F P
0 g
s
.36524 .64655 m .35633 .70308 L .35248 .70658 L p .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .36139 .65005 L .36524 .64655 L p .707 .577 .707 r
F P
0 g
s
.3611 .70543 m .36152 .74219 L .35862 .73286 L p .707 .577 .707 r
F P
0 g
s
.35862 .73286 m .3582 .6961 L .3611 .70543 L p .707 .577 .707 r
F P
0 g
s
.36629 .77191 m .36094 .78218 L p .36619 .7849 L .707 .577 .707 r
F P
0 g
s
.35248 .70658 m .33913 .70826 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.36139 .65005 m .35518 .68945 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.35518 .68945 m .35248 .70658 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.3664 .28013 m .36225 .27171 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .34803 .65173 L .35371 .65102 L p .707 .577 .707 r
F P
0 g
s
.35371 .65102 m .36139 .65005 L p .35437 .66839 L .707 .577 .707 r
F P
0 g
s
.33913 .70826 m .35371 .65102 L .35437 .66839 L .707 .577 .707 r
F
.3582 .6961 m .35862 .73286 L .35078 .72756 L p F P
0 g
s
.35078 .72756 m .34602 .72434 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.35188 .71076 m .3582 .6961 L .35078 .72756 L .707 .577 .707 r
F
.34602 .72434 m .34561 .68758 L .35306 .69262 L p F P
0 g
s
.35306 .69262 m .3582 .6961 L p .35188 .71076 L .707 .577 .707 r
F P
0 g
s
.34602 .72434 m .35306 .69262 L .35188 .71076 L .707 .577 .707 r
F
.34964 .74508 m .35352 .64617 L .35279 .62696 L F
.34839 .79191 m .35051 .73176 L p .34964 .74508 L F P
0 g
s
.35051 .73176 m .35352 .64617 L p .34964 .74508 L .707 .577 .707 r
F P
0 g
s
.34424 .7835 m .3468 .78868 L p .34995 .70366 L .707 .577 .707 r
F P
0 g
s
.34995 .70366 m .34563 .75799 L .34424 .7835 L .707 .577 .707 r
F
.3468 .78868 m .34839 .79191 L p .34964 .74508 L F P
0 g
s
.34964 .74508 m .35279 .62696 L .3468 .78868 L .707 .577 .707 r
F
.34557 .75883 m .3444 .75835 L p .3465 .747 L F P
0 g
s
.3444 .75835 m .33216 .75331 L p .34407 .74807 L .707 .577 .707 r
F P
0 g
s
.34407 .74807 m .3465 .747 L .3444 .75835 L .707 .577 .707 r
F
.3664 .28013 m .34839 .79191 L .36607 .80008 L p F P
0 g
s
.34687 .74237 m .35212 .74453 L p .3465 .747 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .34424 .7835 L p .34563 .75799 L .707 .577 .707 r
F P
0 g
s
.35212 .74453 m .35329 .76202 L .34557 .75883 L p .707 .577 .707 r
F P
0 g
s
.3465 .747 m .35212 .74453 L .34557 .75883 L .707 .577 .707 r
F
.34385 .74113 m .34687 .74237 L p .34396 .74454 L F P
0 g
s
.33216 .75331 m .34687 .74237 L .3465 .747 L .707 .577 .707 r
F
.34995 .70366 m .35279 .62696 L .34563 .75799 L F
.35352 .64617 m .3664 .28013 L p .35279 .62696 L F P
0 g
s
.36623 .78014 m .3664 .28013 L .36607 .80008 L .707 .577 .707 r
F
.37014 .28185 m .3664 .28013 L p .36623 .78014 L F P
0 g
s
.36482 .75593 m .366 .77342 L .35329 .76202 L p .707 .577 .707 r
F P
0 g
s
.35329 .76202 m .35212 .74453 L .36482 .75593 L p .707 .577 .707 r
F P
0 g
s
.37217 .26395 m .35417 .77574 L .34518 .78277 L p .707 .577 .707 r
F P
0 g
s
.34518 .78277 m .34424 .7835 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.3512 .5856 m .34474 .76919 L p .35279 .62696 L .707 .577 .707 r
F P
0 g
s
.35279 .62696 m .34474 .76919 L .34563 .75799 L .707 .577 .707 r
F
.36225 .27171 m .3512 .5856 L p .35279 .62696 L F P
0 g
s
.34484 .7723 m .37217 .26395 L .34518 .78277 L .707 .577 .707 r
F
.33216 .75331 m .33099 .73582 L .34385 .74113 L p F P
0 g
s
.33216 .75331 m .34385 .74113 L .34396 .74454 L .707 .577 .707 r
F
.34484 .7723 m .35127 .58738 L .35273 .62555 L F
.35127 .58738 m .36225 .27171 L .35273 .62555 L F
.36225 .27171 m .37217 .26395 L p .35273 .62555 L F P
0 g
s
.34424 .7835 m .34474 .76919 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.34474 .76919 m .36225 .27171 L p .34484 .7723 L .707 .577 .707 r
F P
0 g
s
.36607 .80008 m .36622 .80015 L p .36623 .78014 L .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36786 .7689 L .36629 .77191 L p .707 .577 .707 r
F P
0 g
s
.36904 .78639 m .36629 .77191 L .36619 .7849 L .707 .577 .707 r
F
.36614 .79196 m .36904 .78639 L p .36619 .7849 L F P
0 g
s
.16732 .6127 m .15841 .66923 L .17176 .66755 L p .707 .577 .707 r
F P
0 g
s
.17176 .66755 m .18067 .61102 L .16732 .6127 L p .707 .577 .707 r
F P
0 g
s
.17271 .72142 m .17313 .75818 L .19419 .76504 L p .707 .577 .707 r
F P
0 g
s
.66756 .71754 m .66797 .7543 L .64052 .74977 L p .707 .577 .707 r
F P
0 g
s
.64052 .74977 m .6401 .713 L .66756 .71754 L p .707 .577 .707 r
F P
0 g
s
.26097 .83194 m .2598 .81446 L .22865 .81333 L p .707 .577 .707 r
F P
0 g
s
.2598 .81446 m .26097 .83194 L .29274 .82891 L p .707 .577 .707 r
F P
0 g
s
.29274 .82891 m .29156 .81142 L .2598 .81446 L p .707 .577 .707 r
F P
0 g
s
.29156 .81142 m .29274 .82891 L .322 .82201 L p .707 .577 .707 r
F P
0 g
s
.322 .82201 m .32083 .80453 L .29156 .81142 L p .707 .577 .707 r
F P
0 g
s
.17313 .75818 m .17271 .72142 L .16012 .7129 L p .707 .577 .707 r
F P
0 g
s
.22983 .83082 m .22865 .81333 L .20117 .80816 L p .707 .577 .707 r
F P
0 g
s
.22865 .81333 m .22983 .83082 L .26097 .83194 L p .707 .577 .707 r
F P
0 g
s
.69512 .78135 m .6963 .79883 L .67517 .79012 L p .707 .577 .707 r
F P
0 g
s
.67517 .79012 m .674 .77264 L .69512 .78135 L p .707 .577 .707 r
F P
0 g
s
.32083 .80453 m .322 .82201 L .34591 .81194 L p .707 .577 .707 r
F P
0 g
s
.34591 .81194 m .34473 .79445 L .32083 .80453 L p .707 .577 .707 r
F P
0 g
s
.20117 .80816 m .20234 .82565 L .22983 .83082 L p .707 .577 .707 r
F P
0 g
s
.16012 .7129 m .16053 .74966 L .17313 .75818 L p .707 .577 .707 r
F P
0 g
s
.16346 .6162 m .15456 .67273 L .15841 .66923 L p .707 .577 .707 r
F P
0 g
s
.15841 .66923 m .16732 .6127 L .16346 .6162 L p .707 .577 .707 r
F P
0 g
s
.53161 .80383 m .53043 .78635 L .55434 .77627 L p .707 .577 .707 r
F P
0 g
s
.20234 .82565 m .20117 .80816 L .18004 .79945 L p .707 .577 .707 r
F P
0 g
s
.55434 .77627 m .55551 .79376 L .53161 .80383 L p .707 .577 .707 r
F P
0 g
s
.18004 .79945 m .18121 .81694 L .20234 .82565 L p .707 .577 .707 r
F P
0 g
s
.674 .77264 m .67517 .79012 L .64769 .78495 L p .707 .577 .707 r
F P
0 g
s
.64769 .78495 m .64651 .76747 L .674 .77264 L p .707 .577 .707 r
F P
0 g
s
.34473 .79445 m .34591 .81194 L .36212 .79966 L p .707 .577 .707 r
F P
0 g
s
.16053 .74966 m .16012 .7129 L .15722 .70356 L p .707 .577 .707 r
F P
0 g
s
.55551 .79376 m .55434 .77627 L .5836 .76938 L p .707 .577 .707 r
F P
0 g
s
.15722 .70356 m .15763 .74032 L .16053 .74966 L p .707 .577 .707 r
F P
0 g
s
.18121 .81694 m .18004 .79945 L .16733 .78806 L p .707 .577 .707 r
F P
0 g
s
.16949 .62119 m .16058 .67772 L .15456 .67273 L p .707 .577 .707 r
F P
0 g
s
.15456 .67273 m .16346 .6162 L .16949 .62119 L p .707 .577 .707 r
F P
0 g
s
.5836 .76938 m .58478 .78686 L .55551 .79376 L p .707 .577 .707 r
F P
0 g
s
.16733 .78806 m .16851 .80554 L .18121 .81694 L p .707 .577 .707 r
F P
0 g
s
.64996 .28493 m .63195 .79672 L .6278 .78831 L p .707 .577 .707 r
F P
0 g
s
.6278 .78831 m .6458 .27652 L .64996 .28493 L p .707 .577 .707 r
F P
0 g
s
.15763 .74032 m .15722 .70356 L .16429 .69432 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16851 .80554 m .16733 .78806 L .16429 .77508 L p .707 .577 .707 r
F P
0 g
s
.16429 .69432 m .16471 .73108 L .15763 .74032 L p .707 .577 .707 r
F P
0 g
s
.18479 .62718 m .17589 .68371 L .16058 .67772 L p .707 .577 .707 r
F P
0 g
s
.16058 .67772 m .16949 .62119 L .18479 .62718 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16429 .77508 m .16547 .79257 L .16851 .80554 L p .707 .577 .707 r
F P
0 g
s
.36786 .7689 m .36904 .78639 L .366 .77342 L p .707 .577 .707 r
F P
0 g
s
.366 .77342 m .36482 .75593 L .36786 .7689 L p .707 .577 .707 r
F P
0 g
s
.16471 .73108 m .16429 .69432 L .18066 .68607 L p .707 .577 .707 r
F P
0 g
s
.34803 .65173 m .33913 .70826 L .31758 .70794 L p .707 .577 .707 r
F P
0 g
s
.6458 .27652 m .6278 .78831 L .60997 .78008 L p .707 .577 .707 r
F P
0 g
s
.60997 .78008 m .62798 .26829 L .6458 .27652 L p .707 .577 .707 r
F P
0 g
s
.16547 .79257 m .16429 .77508 L .17121 .76181 L p .707 .577 .707 r
F P
0 g
s
.18066 .68607 m .18107 .72283 L .16471 .73108 L p .707 .577 .707 r
F P
0 g
s
.31758 .70794 m .32649 .65141 L .34803 .65173 L p .707 .577 .707 r
F P
0 g
s
.20789 .63358 m .19898 .69011 L .17589 .68371 L p .707 .577 .707 r
F P
0 g
s
.17589 .68371 m .18479 .62718 L .20789 .63358 L p .707 .577 .707 r
F P
0 g
s
.34561 .68758 m .34602 .72434 L .32496 .71748 L p .707 .577 .707 r
F P
0 g
s
.32496 .71748 m .32455 .68072 L .34561 .68758 L p .707 .577 .707 r
F P
0 g
s
.17121 .76181 m .17239 .7793 L .16547 .79257 L p .707 .577 .707 r
F P
0 g
s
.35417 .77574 m .37217 .26395 L .39521 .25759 L p .707 .577 .707 r
F P
0 g
s
.19898 .69011 m .20789 .63358 L .23651 .63976 L p .707 .577 .707 r
F P
0 g
s
.18107 .72283 m .18066 .68607 L .20471 .67962 L p .707 .577 .707 r
F P
0 g
s
.32649 .65141 m .31758 .70794 L .28996 .70566 L p .707 .577 .707 r
F P
0 g
s
.23651 .63976 m .22761 .69629 L .19898 .69011 L p .707 .577 .707 r
F P
0 g
s
.28996 .70566 m .29887 .64914 L .32649 .65141 L p .707 .577 .707 r
F P
0 g
s
.17239 .7793 m .17121 .76181 L .18742 .74954 L p .707 .577 .707 r
F P
0 g
s
.20471 .67962 m .20512 .71638 L .18107 .72283 L p .707 .577 .707 r
F P
0 g
s
.32455 .68072 m .32496 .71748 L .29751 .71295 L p .707 .577 .707 r
F P
0 g
s
.29751 .71295 m .29709 .67619 L .32455 .68072 L p .707 .577 .707 r
F P
0 g
s
.29887 .64914 m .28996 .70566 L .25895 .70165 L p .707 .577 .707 r
F P
0 g
s
.18742 .74954 m .1886 .76702 L .17239 .7793 L p .707 .577 .707 r
F P
0 g
s
.71005 .55417 m .70115 .6107 L .73215 .61472 L p .707 .577 .707 r
F P
0 g
s
.73215 .61472 m .74106 .55819 L .71005 .55417 L p .707 .577 .707 r
F P
0 g
s
.74106 .55819 m .73215 .61472 L .7635 .62008 L p .707 .577 .707 r
F P
0 g
s
.62798 .26829 m .60997 .78008 L .58021 .77283 L p .707 .577 .707 r
F P
0 g
s
.58021 .77283 m .59822 .26103 L .62798 .26829 L p .707 .577 .707 r
F P
0 g
s
.22761 .69629 m .23651 .63976 L .26786 .64512 L p .707 .577 .707 r
F P
0 g
s
.20512 .71638 m .20471 .67962 L .23408 .67561 L p .707 .577 .707 r
F P
0 g
s
.26786 .64512 m .25895 .70165 L .22761 .69629 L p .707 .577 .707 r
F P
0 g
s
.7635 .62008 m .7724 .56355 L .74106 .55819 L p .707 .577 .707 r
F P
0 g
s
.7724 .56355 m .7635 .62008 L .79212 .62626 L p .707 .577 .707 r
F P
0 g
s
.25895 .70165 m .26786 .64512 L .29887 .64914 L p .707 .577 .707 r
F P
0 g
s
.68243 .55189 m .67352 .60842 L .70115 .6107 L p .707 .577 .707 r
F P
0 g
s
.70115 .6107 m .71005 .55417 L .68243 .55189 L p .707 .577 .707 r
F P
0 g
s
.29709 .67619 m .29751 .71295 L .26633 .71119 L p .707 .577 .707 r
F P
0 g
s
.26633 .71119 m .26592 .67443 L .29709 .67619 L p .707 .577 .707 r
F P
0 g
s
.79212 .62626 m .80103 .56973 L .7724 .56355 L p .707 .577 .707 r
F P
0 g
s
.23408 .67561 m .2345 .71237 L .20512 .71638 L p .707 .577 .707 r
F P
0 g
s
.2345 .71237 m .23408 .67561 L .26592 .67443 L p .707 .577 .707 r
F P
0 g
s
.39521 .25759 m .3772 .76938 L .35417 .77574 L p .707 .577 .707 r
F P
0 g
s
.3772 .76938 m .39521 .25759 L .4291 .25326 L p .707 .577 .707 r
F P
0 g
s
.26592 .67443 m .26633 .71119 L .2345 .71237 L p .707 .577 .707 r
F P
0 g
s
.80103 .56973 m .79212 .62626 L .81522 .63266 L p .707 .577 .707 r
F P
0 g
s
.1886 .76702 m .18742 .74954 L .21133 .73946 L p .707 .577 .707 r
F P
0 g
s
.73303 .72537 m .73261 .68861 L .70144 .68685 L p .707 .577 .707 r
F P
0 g
s
.73261 .68861 m .73303 .72537 L .76486 .72419 L p .707 .577 .707 r
F P
0 g
s
.76486 .72419 m .76445 .68743 L .73261 .68861 L p .707 .577 .707 r
F P
0 g
s
.66088 .55158 m .65198 .60811 L .67352 .60842 L p .707 .577 .707 r
F P
0 g
s
.67352 .60842 m .68243 .55189 L .66088 .55158 L p .707 .577 .707 r
F P
0 g
s
.81522 .63266 m .82412 .57613 L .80103 .56973 L p .707 .577 .707 r
F P
0 g
s
.21133 .73946 m .2125 .75694 L .1886 .76702 L p .707 .577 .707 r
F P
0 g
s
.76445 .68743 m .76486 .72419 L .79424 .72018 L p .707 .577 .707 r
F P
0 g
s
.79424 .72018 m .79383 .68342 L .76445 .68743 L p .707 .577 .707 r
F P
0 g
s
.33099 .73582 m .33216 .75331 L .30468 .74814 L p .707 .577 .707 r
F P
0 g
s
.30468 .74814 m .3035 .73065 L .33099 .73582 L p .707 .577 .707 r
F P
0 g
s
.70186 .72361 m .70144 .68685 L .67398 .68232 L p .707 .577 .707 r
F P
0 g
s
.70144 .68685 m .70186 .72361 L .73303 .72537 L p .707 .577 .707 r
F P
0 g
s
.59822 .26103 m .58021 .77283 L .54143 .76726 L p .707 .577 .707 r
F P
0 g
s
.54143 .76726 m .55944 .25547 L .59822 .26103 L p .707 .577 .707 r
F P
0 g
s
.2125 .75694 m .21133 .73946 L .24059 .73256 L p .707 .577 .707 r
F P
0 g
s
.79383 .68342 m .79424 .72018 L .81829 .71373 L p .707 .577 .707 r
F P
0 g
s
.81829 .71373 m .81788 .67697 L .79383 .68342 L p .707 .577 .707 r
F P
0 g
s
.82412 .57613 m .81522 .63266 L .83053 .63864 L p .707 .577 .707 r
F P
0 g
s
.67398 .68232 m .6744 .71908 L .70186 .72361 L p .707 .577 .707 r
F P
0 g
s
.3035 .73065 m .30468 .74814 L .27353 .74701 L p .707 .577 .707 r
F P
0 g
s
.27353 .74701 m .27236 .72953 L .3035 .73065 L p .707 .577 .707 r
F P
0 g
s
.24059 .73256 m .24177 .75005 L .2125 .75694 L p .707 .577 .707 r
F P
0 g
s
.4111 .76505 m .4291 .25326 L .47053 .25139 L p .707 .577 .707 r
F P
0 g
s
.4291 .25326 m .4111 .76505 L .3772 .76938 L p .707 .577 .707 r
F P
0 g
s
.6744 .71908 m .67398 .68232 L .65293 .67546 L p .707 .577 .707 r
F P
0 g
s
.83053 .63864 m .83943 .58211 L .82412 .57613 L p .707 .577 .707 r
F P
0 g
s
.24177 .75005 m .24059 .73256 L .27236 .72953 L p .707 .577 .707 r
F P
0 g
s
.64753 .55326 m .63862 .60978 L .65198 .60811 L p .707 .577 .707 r
F P
0 g
s
.65198 .60811 m .66088 .55158 L .64753 .55326 L p .707 .577 .707 r
F P
0 g
s
.27236 .72953 m .27353 .74701 L .24177 .75005 L p .707 .577 .707 r
F P
0 g
s
.65293 .67546 m .65334 .71222 L .6744 .71908 L p .707 .577 .707 r
F P
0 g
s
.55944 .25547 m .54143 .76726 L .49744 .76394 L p .707 .577 .707 r
F P
0 g
s
.49744 .76394 m .51544 .25215 L .55944 .25547 L p .707 .577 .707 r
F P
0 g
s
.81788 .67697 m .81829 .71373 L .83466 .70548 L p .707 .577 .707 r
F P
0 g
s
.83466 .70548 m .83424 .66872 L .81788 .67697 L p .707 .577 .707 r
F P
0 g
s
.74119 .76268 m .74001 .74519 L .70886 .74407 L p .707 .577 .707 r
F P
0 g
s
.74001 .74519 m .74119 .76268 L .77295 .75964 L p .707 .577 .707 r
F P
0 g
s
.77295 .75964 m .77177 .74216 L .74001 .74519 L p .707 .577 .707 r
F P
0 g
s
.77177 .74216 m .77295 .75964 L .80222 .75275 L p .707 .577 .707 r
F P
0 g
s
.80222 .75275 m .80104 .73527 L .77177 .74216 L p .707 .577 .707 r
F P
0 g
s
.45253 .76318 m .47053 .25139 L .51544 .25215 L p .707 .577 .707 r
F P
0 g
s
.47053 .25139 m .45253 .76318 L .4111 .76505 L p .707 .577 .707 r
F P
0 g
s
.71004 .76155 m .70886 .74407 L .68138 .7389 L p .707 .577 .707 r
F P
0 g
s
.70886 .74407 m .71004 .76155 L .74119 .76268 L p .707 .577 .707 r
F P
0 g
s
.83943 .58211 m .83053 .63864 L .83655 .64363 L p .707 .577 .707 r
F P
0 g
s
.51544 .25215 m .49744 .76394 L .45253 .76318 L p .707 .577 .707 r
F P
0 g
s
.65334 .71222 m .65293 .67546 L .64033 .66694 L p .707 .577 .707 r
F P
0 g
s
.80104 .73527 m .80222 .75275 L .82612 .74267 L p .707 .577 .707 r
F P
0 g
s
.82612 .74267 m .82495 .72519 L .80104 .73527 L p .707 .577 .707 r
F P
0 g
s
.68138 .7389 m .68256 .75638 L .71004 .76155 L p .707 .577 .707 r
F P
0 g
s
.83655 .64363 m .84545 .5871 L .83943 .58211 L p .707 .577 .707 r
F P
0 g
s
.64368 .55676 m .63477 .61329 L .63862 .60978 L p .707 .577 .707 r
F P
0 g
s
.63862 .60978 m .64753 .55326 L .64368 .55676 L p .707 .577 .707 r
F P
0 g
s
.64033 .66694 m .64075 .7037 L .65334 .71222 L p .707 .577 .707 r
F P
0 g
s
.68256 .75638 m .68138 .7389 L .66025 .73019 L p .707 .577 .707 r
F P
0 g
s
.83424 .66872 m .83466 .70548 L .84173 .69624 L p .707 .577 .707 r
F P
0 g
s
.84173 .69624 m .84132 .65948 L .83424 .66872 L p .707 .577 .707 r
F P
0 g
s
.66025 .73019 m .66143 .74767 L .68256 .75638 L p .707 .577 .707 r
F P
0 g
s
.82495 .72519 m .82612 .74267 L .84233 .7304 L p .707 .577 .707 r
F P
0 g
s
.84233 .7304 m .84116 .71291 L .82495 .72519 L p .707 .577 .707 r
F P
0 g
s
.64075 .7037 m .64033 .66694 L .63743 .65761 L p .707 .577 .707 r
F P
0 g
s
.84545 .5871 m .83655 .64363 L .83269 .64714 L p .707 .577 .707 r
F P
0 g
s
.66143 .74767 m .66025 .73019 L .64754 .71879 L p .707 .577 .707 r
F P
0 g
s
.83269 .64714 m .8416 .59061 L .84545 .5871 L p .707 .577 .707 r
F P
0 g
s
.6497 .56175 m .64079 .61828 L .63477 .61329 L p .707 .577 .707 r
F P
0 g
s
.63477 .61329 m .64368 .55676 L .6497 .56175 L p .707 .577 .707 r
F P
0 g
s
.63743 .65761 m .63785 .69437 L .64075 .7037 L p .707 .577 .707 r
F P
0 g
s
.64754 .71879 m .64872 .73628 L .66143 .74767 L p .707 .577 .707 r
F P
0 g
s
.84132 .65948 m .84173 .69624 L .83883 .6869 L p .707 .577 .707 r
F P
0 g
s
.83883 .6869 m .83842 .65014 L .84132 .65948 L p .707 .577 .707 r
F P
0 g
s
.84116 .71291 m .84233 .7304 L .84926 .71712 L p .707 .577 .707 r
F P
0 g
s
.84926 .71712 m .84808 .69964 L .84116 .71291 L p .707 .577 .707 r
F P
0 g
s
.63785 .69437 m .63743 .65761 L .64451 .64836 L p .707 .577 .707 r
F P
0 g
s
.8416 .59061 m .83269 .64714 L .81934 .64881 L p .707 .577 .707 r
F P
0 g
s
.64872 .73628 m .64754 .71879 L .6445 .70582 L p .707 .577 .707 r
F P
0 g
s
.36704 .51736 m .35814 .57388 L .38914 .5779 L p .707 .577 .707 r
F P
0 g
s
.38914 .5779 m .39805 .52137 L .36704 .51736 L p .707 .577 .707 r
F P
0 g
s
.39805 .52137 m .38914 .5779 L .42049 .58326 L p .707 .577 .707 r
F P
0 g
s
.81934 .64881 m .82825 .59228 L .8416 .59061 L p .707 .577 .707 r
F P
0 g
s
.42049 .58326 m .4294 .52673 L .39805 .52137 L p .707 .577 .707 r
F P
0 g
s
.4294 .52673 m .42049 .58326 L .44911 .58944 L p .707 .577 .707 r
F P
0 g
s
.6445 .70582 m .64568 .72331 L .64872 .73628 L p .707 .577 .707 r
F P
0 g
s
.64451 .64836 m .64492 .68512 L .63785 .69437 L p .707 .577 .707 r
F P
0 g
s
.66501 .56774 m .6561 .62426 L .64079 .61828 L p .707 .577 .707 r
F P
0 g
s
.64079 .61828 m .6497 .56175 L .66501 .56774 L p .707 .577 .707 r
F P
0 g
s
.33942 .51508 m .33051 .57161 L .35814 .57388 L p .707 .577 .707 r
F P
0 g
s
.35814 .57388 m .36704 .51736 L .33942 .51508 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84808 .69964 m .84926 .71712 L .84621 .70415 L p .707 .577 .707 r
F P
0 g
s
.84621 .70415 m .84504 .68667 L .84808 .69964 L p .707 .577 .707 r
F P
0 g
s
.44911 .58944 m .45802 .53291 L .4294 .52673 L p .707 .577 .707 r
F P
0 g
s
.83842 .65014 m .83883 .6869 L .82624 .67838 L p .707 .577 .707 r
F P
0 g
s
.82624 .67838 m .82582 .64162 L .83842 .65014 L p .707 .577 .707 r
F P
0 g
s
.45802 .53291 m .44911 .58944 L .47221 .59584 L p .707 .577 .707 r
F P
0 g
s
.39002 .68856 m .3896 .6518 L .35843 .65004 L p .707 .577 .707 r
F P
0 g
s
.3896 .6518 m .39002 .68856 L .42185 .68737 L p .707 .577 .707 r
F P
0 g
s
.42185 .68737 m .42144 .65061 L .3896 .6518 L p .707 .577 .707 r
F P
0 g
s
.31787 .51476 m .30897 .57129 L .33051 .57161 L p .707 .577 .707 r
F P
0 g
s
.33051 .57161 m .33942 .51508 L .31787 .51476 L p .707 .577 .707 r
F P
0 g
s
.47221 .59584 m .48111 .53931 L .45802 .53291 L p .707 .577 .707 r
F P
0 g
s
.64492 .68512 m .64451 .64836 L .66087 .64011 L p .707 .577 .707 r
F P
0 g
s
.82825 .59228 m .81934 .64881 L .7978 .6485 L p .707 .577 .707 r
F P
0 g
s
.42144 .65061 m .42185 .68737 L .45123 .68336 L p .707 .577 .707 r
F P
0 g
s
.45123 .68336 m .45082 .6466 L .42144 .65061 L p .707 .577 .707 r
F P
0 g
s
.64568 .72331 m .6445 .70582 L .65142 .69255 L p .707 .577 .707 r
F P
0 g
s
.35885 .6868 m .35843 .65004 L .33097 .6455 L p .707 .577 .707 r
F P
0 g
s
.35843 .65004 m .35885 .6868 L .39002 .68856 L p .707 .577 .707 r
F P
0 g
s
.7978 .6485 m .80671 .59197 L .82825 .59228 L p .707 .577 .707 r
F P
0 g
s
.6881 .57413 m .6792 .63066 L .6561 .62426 L p .707 .577 .707 r
F P
0 g
s
.6561 .62426 m .66501 .56774 L .6881 .57413 L p .707 .577 .707 r
F P
0 g
s
.65142 .69255 m .6526 .71003 L .64568 .72331 L p .707 .577 .707 r
F P
0 g
s
.66087 .64011 m .66129 .67687 L .64492 .68512 L p .707 .577 .707 r
F P
0 g
s
.45082 .6466 m .45123 .68336 L .47528 .67692 L p .707 .577 .707 r
F P
0 g
s
.47528 .67692 m .47487 .64016 L .45082 .6466 L p .707 .577 .707 r
F P
0 g
s
.48111 .53931 m .47221 .59584 L .48752 .60183 L p .707 .577 .707 r
F P
0 g
s
.84504 .68667 m .84621 .70415 L .83351 .69275 L p .707 .577 .707 r
F P
0 g
s
.83351 .69275 m .83233 .67527 L .84504 .68667 L p .707 .577 .707 r
F P
0 g
s
.82582 .64162 m .82624 .67838 L .80518 .67152 L p .707 .577 .707 r
F P
0 g
s
.80518 .67152 m .80476 .63476 L .82582 .64162 L p .707 .577 .707 r
F P
0 g
s
.33097 .6455 m .33139 .68226 L .35885 .6868 L p .707 .577 .707 r
F P
0 g
s
.33139 .68226 m .33097 .6455 L .30992 .63864 L p .707 .577 .707 r
F P
0 g
s
.48752 .60183 m .49642 .5453 L .48111 .53931 L p .707 .577 .707 r
F P
0 g
s
.30452 .51644 m .29561 .57297 L .30897 .57129 L p .707 .577 .707 r
F P
0 g
s
.30897 .57129 m .31787 .51476 L .30452 .51644 L p .707 .577 .707 r
F P
0 g
s
.80671 .59197 m .7978 .6485 L .77017 .64622 L p .707 .577 .707 r
F P
0 g
s
.66129 .67687 m .66087 .64011 L .68492 .63366 L p .707 .577 .707 r
F P
0 g
s
.6526 .71003 m .65142 .69255 L .66763 .68027 L p .707 .577 .707 r
F P
0 g
s
.71673 .58031 m .70782 .63684 L .6792 .63066 L p .707 .577 .707 r
F P
0 g
s
.6792 .63066 m .6881 .57413 L .71673 .58031 L p .707 .577 .707 r
F P
0 g
s
.77017 .64622 m .77908 .58969 L .80671 .59197 L p .707 .577 .707 r
F P
0 g
s
.30992 .63864 m .31033 .6754 L .33139 .68226 L p .707 .577 .707 r
F P
0 g
s
.47487 .64016 m .47528 .67692 L .49165 .66867 L p .707 .577 .707 r
F P
0 g
s
.49165 .66867 m .49123 .63191 L .47487 .64016 L p .707 .577 .707 r
F P
0 g
s
.39818 .72586 m .397 .70838 L .36585 .70725 L p .707 .577 .707 r
F P
0 g
s
.397 .70838 m .39818 .72586 L .42994 .72283 L p .707 .577 .707 r
F P
0 g
s
.42994 .72283 m .42876 .70534 L .397 .70838 L p .707 .577 .707 r
F P
0 g
s
.42876 .70534 m .42994 .72283 L .45921 .71593 L p .707 .577 .707 r
F P
0 g
s
.45921 .71593 m .45803 .69845 L .42876 .70534 L p .707 .577 .707 r
F P
0 g
s
.68492 .63366 m .68534 .67042 L .66129 .67687 L p .707 .577 .707 r
F P
0 g
s
.66763 .68027 m .66881 .69776 L .6526 .71003 L p .707 .577 .707 r
F P
0 g
s
.80476 .63476 m .80518 .67152 L .77772 .66699 L p .707 .577 .707 r
F P
0 g
s
.77772 .66699 m .7773 .63023 L .80476 .63476 L p .707 .577 .707 r
F P
0 g
s
.77908 .58969 m .77017 .64622 L .73917 .6422 L p .707 .577 .707 r
F P
0 g
s
.36703 .72474 m .36585 .70725 L .33837 .70209 L p .707 .577 .707 r
F P
0 g
s
.36585 .70725 m .36703 .72474 L .39818 .72586 L p .707 .577 .707 r
F P
0 g
s
.49642 .5453 m .48752 .60183 L .49354 .60682 L p .707 .577 .707 r
F P
0 g
s
.83233 .67527 m .83351 .69275 L .81238 .68404 L p .707 .577 .707 r
F P
0 g
s
.81238 .68404 m .8112 .66656 L .83233 .67527 L p .707 .577 .707 r
F P
0 g
s
.74808 .58568 m .73917 .6422 L .70782 .63684 L p .707 .577 .707 r
F P
0 g
s
.70782 .63684 m .71673 .58031 L .74808 .58568 L p .707 .577 .707 r
F P
0 g
s
.31033 .6754 m .30992 .63864 L .29732 .63013 L p .707 .577 .707 r
F P
0 g
s
.45803 .69845 m .45921 .71593 L .48311 .70586 L p .707 .577 .707 r
F P
0 g
s
.48311 .70586 m .48194 .68837 L .45803 .69845 L p .707 .577 .707 r
F P
0 g
s
.68534 .67042 m .68492 .63366 L .7143 .62965 L p .707 .577 .707 r
F P
0 g
s
.73917 .6422 m .74808 .58568 L .77908 .58969 L p .707 .577 .707 r
F P
0 g
s
.33837 .70209 m .33955 .71957 L .36703 .72474 L p .707 .577 .707 r
F P
0 g
s
.49354 .60682 m .50244 .55029 L .49642 .5453 L p .707 .577 .707 r
F P
0 g
s
.30067 .51994 m .29176 .57647 L .29561 .57297 L p .707 .577 .707 r
F P
0 g
s
.29561 .57297 m .30452 .51644 L .30067 .51994 L p .707 .577 .707 r
F P
0 g
s
.7773 .63023 m .77772 .66699 L .74655 .66523 L p .707 .577 .707 r
F P
0 g
s
.74655 .66523 m .74613 .62847 L .7773 .63023 L p .707 .577 .707 r
F P
0 g
s
.66881 .69776 m .66763 .68027 L .69154 .67019 L p .707 .577 .707 r
F P
0 g
s
.29732 .63013 m .29774 .66689 L .31033 .6754 L p .707 .577 .707 r
F P
0 g
s
.33955 .71957 m .33837 .70209 L .31724 .69337 L p .707 .577 .707 r
F P
0 g
s
.7143 .62965 m .71471 .66641 L .68534 .67042 L p .707 .577 .707 r
F P
0 g
s
.71471 .66641 m .7143 .62965 L .74613 .62847 L p .707 .577 .707 r
F P
0 g
s
.49123 .63191 m .49165 .66867 L .49872 .65942 L p .707 .577 .707 r
F P
0 g
s
.49872 .65942 m .49831 .62266 L .49123 .63191 L p .707 .577 .707 r
F P
0 g
s
.74613 .62847 m .74655 .66523 L .71471 .66641 L p .707 .577 .707 r
F P
0 g
s
.69154 .67019 m .69272 .68768 L .66881 .69776 L p .707 .577 .707 r
F P
0 g
s
.31724 .69337 m .31842 .71086 L .33955 .71957 L p .707 .577 .707 r
F P
0 g
s
.8112 .66656 m .81238 .68404 L .78489 .67887 L p .707 .577 .707 r
F P
0 g
s
.78489 .67887 m .78372 .66139 L .8112 .66656 L p .707 .577 .707 r
F P
0 g
s
.48194 .68837 m .48311 .70586 L .49932 .69358 L p .707 .577 .707 r
F P
0 g
s
.49932 .69358 m .49815 .6761 L .48194 .68837 L p .707 .577 .707 r
F P
0 g
s
.29774 .66689 m .29732 .63013 L .29442 .62079 L p .707 .577 .707 r
F P
0 g
s
.50244 .55029 m .49354 .60682 L .48968 .61032 L p .707 .577 .707 r
F P
0 g
s
.69272 .68768 m .69154 .67019 L .72081 .6633 L p .707 .577 .707 r
F P
0 g
s
.31842 .71086 m .31724 .69337 L .30453 .68198 L p .707 .577 .707 r
F P
0 g
s
.78372 .66139 m .78489 .67887 L .75375 .67775 L p .707 .577 .707 r
F P
0 g
s
.75375 .67775 m .75257 .66027 L .78372 .66139 L p .707 .577 .707 r
F P
0 g
s
.48968 .61032 m .49859 .55379 L .50244 .55029 L p .707 .577 .707 r
F P
0 g
s
.72081 .6633 m .72199 .68078 L .69272 .68768 L p .707 .577 .707 r
F P
0 g
s
.30669 .52493 m .29778 .58146 L .29176 .57647 L p .707 .577 .707 r
F P
0 g
s
.29176 .57647 m .30067 .51994 L .30669 .52493 L p .707 .577 .707 r
F P
0 g
s
.29442 .62079 m .29483 .65755 L .29774 .66689 L p .707 .577 .707 r
F P
0 g
s
.72199 .68078 m .72081 .6633 L .75257 .66027 L p .707 .577 .707 r
F P
0 g
s
.30453 .68198 m .30571 .69946 L .31842 .71086 L p .707 .577 .707 r
F P
0 g
s
.75257 .66027 m .75375 .67775 L .72199 .68078 L p .707 .577 .707 r
F P
0 g
s
.49831 .62266 m .49872 .65942 L .49582 .65008 L p .707 .577 .707 r
F P
0 g
s
.49582 .65008 m .49541 .61332 L .49831 .62266 L p .707 .577 .707 r
F P
0 g
s
.49815 .6761 m .49932 .69358 L .50625 .68031 L p .707 .577 .707 r
F P
0 g
s
.50625 .68031 m .50507 .66282 L .49815 .6761 L p .707 .577 .707 r
F P
0 g
s
.29483 .65755 m .29442 .62079 L .3015 .61154 L p .707 .577 .707 r
F P
0 g
s
.49859 .55379 m .48968 .61032 L .47633 .612 L p .707 .577 .707 r
F P
0 g
s
.30571 .69946 m .30453 .68198 L .30149 .66901 L p .707 .577 .707 r
F P
0 g
s
.47633 .612 m .48524 .55547 L .49859 .55379 L p .707 .577 .707 r
F P
0 g
s
.30149 .66901 m .30267 .68649 L .30571 .69946 L p .707 .577 .707 r
F P
0 g
s
.3015 .61154 m .30191 .6483 L .29483 .65755 L p .707 .577 .707 r
F P
0 g
s
.322 .53092 m .31309 .58745 L .29778 .58146 L p .707 .577 .707 r
F P
0 g
s
.29778 .58146 m .30669 .52493 L .322 .53092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50507 .66282 m .50625 .68031 L .5032 .66734 L p .707 .577 .707 r
F P
0 g
s
.5032 .66734 m .50203 .64985 L .50507 .66282 L p .707 .577 .707 r
F P
0 g
s
.49541 .61332 m .49582 .65008 L .48323 .64157 L p .707 .577 .707 r
F P
0 g
s
.48323 .64157 m .48281 .60481 L .49541 .61332 L p .707 .577 .707 r
F P
0 g
s
.30191 .6483 m .3015 .61154 L .31786 .60329 L p .707 .577 .707 r
F P
0 g
s
.48524 .55547 m .47633 .612 L .45479 .61168 L p .707 .577 .707 r
F P
0 g
s
.30267 .68649 m .30149 .66901 L .30841 .65573 L p .707 .577 .707 r
F P
0 g
s
.45479 .61168 m .4637 .55515 L .48524 .55547 L p .707 .577 .707 r
F P
0 g
s
.34509 .53732 m .33619 .59385 L .31309 .58745 L p .707 .577 .707 r
F P
0 g
s
.31309 .58745 m .322 .53092 L .34509 .53732 L p .707 .577 .707 r
F P
0 g
s
.30841 .65573 m .30959 .67322 L .30267 .68649 L p .707 .577 .707 r
F P
0 g
s
.31786 .60329 m .31828 .64005 L .30191 .6483 L p .707 .577 .707 r
F P
0 g
s
.50203 .64985 m .5032 .66734 L .4905 .65594 L p .707 .577 .707 r
F P
0 g
s
.4905 .65594 m .48932 .63846 L .50203 .64985 L p .707 .577 .707 r
F P
0 g
s
.48281 .60481 m .48323 .64157 L .46217 .63471 L p .707 .577 .707 r
F P
0 g
s
.46217 .63471 m .46175 .59795 L .48281 .60481 L p .707 .577 .707 r
F P
0 g
s
.4637 .55515 m .45479 .61168 L .42716 .6094 L p .707 .577 .707 r
F P
0 g
s
.31828 .64005 m .31786 .60329 L .34191 .59685 L p .707 .577 .707 r
F P
0 g
s
.30959 .67322 m .30841 .65573 L .32462 .64346 L p .707 .577 .707 r
F P
0 g
s
.37372 .5435 m .36481 .60003 L .33619 .59385 L p .707 .577 .707 r
F P
0 g
s
.33619 .59385 m .34509 .53732 L .37372 .5435 L p .707 .577 .707 r
F P
0 g
s
.42716 .6094 m .43607 .55288 L .4637 .55515 L p .707 .577 .707 r
F P
0 g
s
.34191 .59685 m .34233 .63361 L .31828 .64005 L p .707 .577 .707 r
F P
0 g
s
.32462 .64346 m .3258 .66094 L .30959 .67322 L p .707 .577 .707 r
F P
0 g
s
.46175 .59795 m .46217 .63471 L .43471 .63018 L p .707 .577 .707 r
F P
0 g
s
.43471 .63018 m .43429 .59342 L .46175 .59795 L p .707 .577 .707 r
F P
0 g
s
.43607 .55288 m .42716 .6094 L .39616 .60539 L p .707 .577 .707 r
F P
0 g
s
.48932 .63846 m .4905 .65594 L .46937 .64723 L p .707 .577 .707 r
F P
0 g
s
.46937 .64723 m .46819 .62975 L .48932 .63846 L p .707 .577 .707 r
F P
0 g
s
.40506 .54886 m .39616 .60539 L .36481 .60003 L p .707 .577 .707 r
F P
0 g
s
.36481 .60003 m .37372 .5435 L .40506 .54886 L p .707 .577 .707 r
F P
0 g
s
.34233 .63361 m .34191 .59685 L .37129 .59284 L p .707 .577 .707 r
F P
0 g
s
.39616 .60539 m .40506 .54886 L .43607 .55288 L p .707 .577 .707 r
F P
0 g
s
.43429 .59342 m .43471 .63018 L .40354 .62841 L p .707 .577 .707 r
F P
0 g
s
.40354 .62841 m .40312 .59165 L .43429 .59342 L p .707 .577 .707 r
F P
0 g
s
.3258 .66094 m .32462 .64346 L .34853 .63338 L p .707 .577 .707 r
F P
0 g
s
.37129 .59284 m .3717 .6296 L .34233 .63361 L p .707 .577 .707 r
F P
0 g
s
.3717 .6296 m .37129 .59284 L .40312 .59165 L p .707 .577 .707 r
F P
0 g
s
.40312 .59165 m .40354 .62841 L .3717 .6296 L p .707 .577 .707 r
F P
0 g
s
.34853 .63338 m .34971 .65086 L .3258 .66094 L p .707 .577 .707 r
F P
0 g
s
.46819 .62975 m .46937 .64723 L .44188 .64206 L p .707 .577 .707 r
F P
0 g
s
.44188 .64206 m .44071 .62458 L .46819 .62975 L p .707 .577 .707 r
F P
0 g
s
.34971 .65086 m .34853 .63338 L .3778 .62649 L p .707 .577 .707 r
F P
0 g
s
.44071 .62458 m .44188 .64206 L .41074 .64094 L p .707 .577 .707 r
F P
0 g
s
.41074 .64094 m .40956 .62345 L .44071 .62458 L p .707 .577 .707 r
F P
0 g
s
.3778 .62649 m .37897 .64397 L .34971 .65086 L p .707 .577 .707 r
F P
0 g
s
.37897 .64397 m .3778 .62649 L .40956 .62345 L p .707 .577 .707 r
F P
0 g
s
.40956 .62345 m .41074 .64094 L .37897 .64397 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol0081ooaT008Aoo`00MGoo2`001EYF00<005YFFUH02UYF00<005YFFUH015YF
2@00Ngoo001_Ool60004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06001eOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@0075oo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00KGoo001WOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH4001YOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000Igoo
001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Eoo`00IWoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=oo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo
001UOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH3001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001FOol?0002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP04001J
EUYFFUH:0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPX000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo00D005YF001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00E7oo00<005YFFUH00`001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001DOol0
1000FUIJEP000UYF1P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF10002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001DOol00`00FUH00004FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
00030008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH3001VOol005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP040008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IWoo001COol01000FUIJ
EP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1P000UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000goo2`00F7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH01000FUIJEUYF6@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`0000Eoo`00001JEP0000EJEP04001JEUYFFUH9001?Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70018Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH600000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040014
Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH015YF1000@7oo001BOol01000FUIJEP0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00
00<003aoo`00DWoo00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00
FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH6000fOol0059oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04FUH00`00FUIJEP02FUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1000<Woo001COol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF00000`0025YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00<7oo001DOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P00;Woo001FOol200000eYF001JEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0P00;7oo001HOol40003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01EYF
00<005YFFUH00UYF0`00;7oo001LOol50005FUHG0005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPd00003FUH0000002aoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
000010001UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00G7oo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Goo001IOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOol200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000bOol;000HOol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH30003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000_Ool300000eYF001JEP04FUH01000
FUIJEUYF2@003Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70007Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002ioo`<00003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005
Ool00000FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH000020005FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH?0004FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool0
1000FUIJEP000UYF0`000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00001000
1EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P001Woo
100000=JEP00FUH01UYF00<005YFFUH015YF20000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P002Woo0`0015YF2@0015YF00@005YFFUIJEPP000=JEP03001J
EUYF00=JEP04001JEUYFFUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEPD00003FUH0
05YF00MJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEUYF00=JEPH000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000]oo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH60003FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04
FUH01000FUIJEUYF1`000eYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YF00001@0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000eYF00<0
07ooOol0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04
0008FUH200000eYF001JEP02FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0006FUH00`00
FUIJEP03FUH4000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF0000000_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH60002FUH200000eYF001JEP020002FUH20006FUH00`00FUIJEP04FUH6
0005FUH00`00FUIJEP06FUH50002FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF100000AJEP00001JEP<0
0003FUH005YF00EJEP03001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03
001JEUYF00@000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000goo00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP05001J
EUYFFUH00005FUH40004FUH@0006FUH00`00FUIJEP03FUH400001EYF001JEUYF00002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF00<005YFFUH00UYF00<005YF00000`000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP800003FUH0000000AJEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00=JEPT000=JEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP800003FUH0000000=JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@002UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF1P00
15YF00<005YFFUH00UYF20000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00:goo00@005YF
FUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<0009J
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH200000eYF0000000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@000eYF00@005YFFUIJEP8002eoo`00:goo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP<00003FUH005YF009JEP8002eoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF2@000eYF00<005YF00000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YF0000009JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEP0000D00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002eoo`00;7oo0`000eYF00<005YF
FUH015YF00<005YFFUH00eYF200015YF00<005YFFUH00UYF1P0000AJEP00000000AJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009J
EP80009JEP8000=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03001J
EUYF009JEP800003FUH0000002eoo`00;goo0P0000=JEP00FUH01EYF1P000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00001P0000=JEP00FUH01UYF00<005YFFUH01EYF10001EYF00<005YF
FUH01UYF00<005YF00000`001EYF0`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0000=JEP00FUH01P001EYF00<005YFFUH015YF1`002Goo20000eYF00<005YF
FUH00eYF1000;Goo000aOol300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH0000015YF1P0015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF1P00
1eYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000AJEP00
0000009JEP8000IJEP03001JEUYF00@001=oo`T000EJEP04001JEP00000]Ool0039oo`<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP02
FUHK0005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH300000eYF001JEP05FUHJ0003FUH00`00FUIJEP03FUH20003FUH0
1@00FUIJEUYF0000;7oo000`Ool200000eYF001JEP03FUH00`00FUH00007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH01000FUIJEP001EYF0P0000=JEP00FUH01EYF00<005YF0000
10000UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF0P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00003FUH005YF009JEP03001o
ogoo02Yoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000eYF0`001EYF0P0000=JEP00FUH01EYF00<005YFFUH00`000eYF00<005YF
FUH02EYF00<005YFFUH00P000UYF00<005YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF100000=JEP00000015YF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000=JEP8002]oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0eYF00<005YF00000P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH025YF1000
1EYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40000
0eYF00000004FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP02000[Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH50000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04FUH30002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000015YF001JEUYF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF1@00:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000EJEP03001JEP0000<000IJ
EP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEPD00004FUH000000003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000Woo0P00
:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000
FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP000003Ool3000[Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQL000AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30005Ool00`00FUH0000[Ool002aoo`03001JEP0000AJEP03
001JEUYF00=JEPH001Moo`@0009JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH0000000D00003FUH005YF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF
00EJEP03001JEP0000<000Moo`800003FUH007oo02Yoo`00;7oo00<005YF000015YF00<005YF0000
0`008Goo20001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100035YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000UYF200015YF
00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1@002Goo0P0000=JEP000000;7oo000/Ool00`00
FUH00003FUH3000COol3000COol80002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70003FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30000
15YF000000000eYF00<005YFFUH0300015YF3P003Goo00@005YFFUIJEP8002aoo`00;7oo00@005YF
001JEP800004FUH00000000AOol5000?Ool3000025YF001JEUYF001JEP00FUH@000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300001EYF
000005YF00000UYF00<005YFFUH00eYF0P0000=JEP00000017oo2@0057oo0P0015YF00<007ooOol0
:goo000/Ool01P00FUH00000FUH000AJEPD000aooa@000AJEP06001JEUYF001JEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0`0000=JEP0000000UYF00<005YF00001EYF00<005YF00000P002Goo
0`004goo0P0000=JEP00FUH00eYF00<007ooOol0:goo000/Ool20003FUH00`00FUIJEP03FUH01000
FUIJEUYF3P0015YF00<005YFFUH01UYF00<005YF00000`000eYF00H005YFFUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2000015YF001JEP000UYF0`001EYF00D005YFFUIJEP0001eoo`80
00=JEP05001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPD00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP800004FUH005YF0002FUH00`00FUIJEP020003FUH01@00FUIJEUYF0000
6Woo0`001EYF00@005YF000002moo`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF00EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00002FUH01000FUIJEP000eYF1@000UYF
0P005Goo100000=JEP00FUH01EYF0P00<Goo000/Ool20003FUH00`00FUIJEP03FUH01P00FUH00000
FUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP04001JEUYFFUHI
0005FUH00`00FUIJEP04FUH00`00Oomoo`0`Ool002eoo`05001JEUYFFUH00005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH?0006FUH01`00FUH005YF001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002eoo`05001JEUYFFUH00003
FUH20005FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05FUH40002FUH01`00FUIJEUYF001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000eOol002ioo`800003FUH005YF00<0
00IJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`L00003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Moo`00<7oo0`000UYF00<005YFFUH00eYF
1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P002goo1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01000>goo000`Ool00`00FUIJEP02FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@00004Ool005YF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000:Ool60002FUHH000oOol002moo`8000AJEP03001JEP0000<000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000Eoo`03001JEP0000IJEP03001JEUYF009J
ER<000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`D000=JEP03001J
EUYF00800003FUH0000005Aoo`00;goo0P0015YF0P0017oo200015YF00<005YFFUH00UYF2@003Goo
00<005YF00001EYF1`002UYF00<005YFFUH02UYF00<005YFFUH025YF30001EYF00<005YFFUH01UYF
00<005YFFUH00UYF2@001UYF00<005YFFUH00UYF0`00E7oo000^Ool01000FUIJEP000UYF00<007oo
Ool037oo2@005Woo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEPP000IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH500000eYF001J
EP03FUH3001DOol002ioo`03001JEUYF00<001=oo`D001Eoo`03001JEUYF0080009JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@000EJEP03
001JEP0000<0009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP<000AJEP03001JEP0005Ao
o`00;Woo00@005YFFUH001Eoo`D001Eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP800003FUH005YF00MJEP04001JEUYF
FUH40004FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUH0001DOol002ioo`03
001JEP0001Ioo`D001Eoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP04001JEUYFFUH20003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0P000UYF
0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1000EGoo000_Ool2000GOol3000FOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUH0
00001EYF00<005YFFUH015YF1`001EYF30000eYF00<005YFFUH00eYF0`00EGoo000_Ool00`00Oomo
o`0`Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH3
0006FUH00`00FUIJEP040006FUH00`00FUIJEP03FUH01000FUH000001UYF00<005YF00000`001EYF
00@005YF000005Aoo`00;goo0P00<7oo00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000IJEP@000UJEP03001JEUYF00=JEP04001J
EP000006FUH00`00FUIJEP03FUH20003FUH01@00FUIJEUYF0000Dgoo000_Ool01000FUH00000;7oo
0`000eYF0P002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUH000=J
EP8000=JEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00FUIJEP03FUH40000
0eYF001JEP02FUH00`00Oomoo`1AOol002moo`04001JEUYFFUH2000XOol20002FUH00`00FUIJEP02
FUH40006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01@00FUIJEP00FUH00P00
1EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001eYF00<005YF00000`0017oo0P000eYF00<007oo
Ool0DGoo000_Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP04001JEUYF0004Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP020007FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH5000:Ool00`00FUIJEP02001BOol002moo`05001JEUYF
FUH00004FUH3000JOol40002FUH00`00FUIJEP04FUH30009Ool50008FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUH00009FUH00`00FUIJEP07FUH00`00FUH0000:000@Ool4001BOol0031oo`04
001JEUYF0005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000@Ool60002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP03FUH7000LOol2001BOol0035oo`<000EJ
EP03001JEUYF00=JEPl000AJEP03001JEUYF00IJEP04001JEUYFFUH2000HOol90006FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH;0003Ool5000KOol2001BOol003=oo`8000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000SOolI000>Ool5000JOol3
001BOol003Eoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP<003=oo`8001Moo`D001Uoo`800003FUH007oo055oo`00>7oo0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01000=Woo0P0067oo0`0067oo0P0000AJEP00FUH0059oo`00>goo1000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00<Goo00@005YFFUIJEP8005=oo`00?goo
4000@Goo0P0000=JEP00Ool0;Goo0P0015YF0P00Dgoo002@Ool20002FUH00`00Oomoo`0YOol20000
0eYF001JEP03FUH00`00Oomoo`1BOol0095oo`03001JEUYF00<002Moo`8000=JEP05001JEUYFFUH0
001EOol0095oo`04001JEUYF0002FUH2000ROol30005FUH01000FUH00000EWoo002BOol01000FUIJ
EP000eYF1@006Goo100000=JEP00FUH01EYF0P00F7oo002COol30004FUH01000FUIJEUYF2@002Goo
1`001EYF00<005YFFUH015YF00<007ooOol0Egoo002EOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00FWoo002FOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000G7oo002H
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4001NOol0
09Yoo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0069oo`00Wgoo200015YF
00<005YFFUH00UYF1`00IWoo002WOol9001]Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59459 .72635 m .6002 .66895 L .56909 .66574 L p .707 .577 .707 r
F P
0 g
s
.6002 .66895 m .59459 .72635 L .62623 .72936 L p .707 .577 .707 r
F P
0 g
s
.62623 .72936 m .63184 .67196 L .6002 .66895 L p .707 .577 .707 r
F P
0 g
s
.56909 .66574 m .56348 .72315 L .59459 .72635 L p .707 .577 .707 r
F P
0 g
s
.63184 .67196 m .62623 .72936 L .65532 .73188 L p .707 .577 .707 r
F P
0 g
s
.65532 .73188 m .66093 .67448 L .63184 .67196 L p .707 .577 .707 r
F P
0 g
s
.56348 .72315 m .56909 .66574 L .54157 .66265 L p .707 .577 .707 r
F P
0 g
s
.54157 .66265 m .53596 .72006 L .56348 .72315 L p .707 .577 .707 r
F P
0 g
s
.66093 .67448 m .65532 .73188 L .67901 .73367 L p .707 .577 .707 r
F P
0 g
s
.67901 .73367 m .68462 .67626 L .66093 .67448 L p .707 .577 .707 r
F P
0 g
s
.59594 .8088 m .59568 .77193 L .56451 .77011 L p .707 .577 .707 r
F P
0 g
s
.59568 .77193 m .59594 .8088 L .62777 .80778 L p .707 .577 .707 r
F P
0 g
s
.62777 .80778 m .62751 .7709 L .59568 .77193 L p .707 .577 .707 r
F P
0 g
s
.62751 .7709 m .62777 .80778 L .65715 .80401 L p .707 .577 .707 r
F P
0 g
s
.65715 .80401 m .6569 .76713 L .62751 .7709 L p .707 .577 .707 r
F P
0 g
s
.53596 .72006 m .54157 .66265 L .52032 .65999 L p .707 .577 .707 r
F P
0 g
s
.56477 .80699 m .56451 .77011 L .53705 .76563 L p .707 .577 .707 r
F P
0 g
s
.56451 .77011 m .56477 .80699 L .59594 .8088 L p .707 .577 .707 r
F P
0 g
s
.52032 .65999 m .51471 .71739 L .53596 .72006 L p .707 .577 .707 r
F P
0 g
s
.6569 .76713 m .65715 .80401 L .6812 .79786 L p .707 .577 .707 r
F P
0 g
s
.6812 .79786 m .68095 .76099 L .6569 .76713 L p .707 .577 .707 r
F P
0 g
s
.53705 .76563 m .53731 .80251 L .56477 .80699 L p .707 .577 .707 r
F P
0 g
s
.68462 .67626 m .67901 .73367 L .69497 .73454 L p .707 .577 .707 r
F P
0 g
s
.69497 .73454 m .70058 .67713 L .68462 .67626 L p .707 .577 .707 r
F P
0 g
s
.53731 .80251 m .53705 .76563 L .51599 .75893 L p .707 .577 .707 r
F P
0 g
s
.51471 .71739 m .52032 .65999 L .50744 .658 L p .707 .577 .707 r
F P
0 g
s
.50744 .658 m .50183 .71541 L .51471 .71739 L p .707 .577 .707 r
F P
0 g
s
.60087 .86237 m .60014 .84443 L .56897 .84302 L p .707 .577 .707 r
F P
0 g
s
.60014 .84443 m .60087 .86237 L .63267 .86018 L p .707 .577 .707 r
F P
0 g
s
.63267 .86018 m .63194 .84224 L .60014 .84443 L p .707 .577 .707 r
F P
0 g
s
.51599 .75893 m .51625 .79581 L .53731 .80251 L p .707 .577 .707 r
F P
0 g
s
.63194 .84224 m .63267 .86018 L .66201 .85461 L p .707 .577 .707 r
F P
0 g
s
.66201 .85461 m .66128 .83667 L .63194 .84224 L p .707 .577 .707 r
F P
0 g
s
.68095 .76099 m .6812 .79786 L .69757 .78995 L p .707 .577 .707 r
F P
0 g
s
.69757 .78995 m .69731 .75307 L .68095 .76099 L p .707 .577 .707 r
F P
0 g
s
.56897 .84302 m .5697 .86096 L .60087 .86237 L p .707 .577 .707 r
F P
0 g
s
.5697 .86096 m .56897 .84302 L .54151 .83814 L p .707 .577 .707 r
F P
0 g
s
.66128 .83667 m .66201 .85461 L .68601 .84619 L p .707 .577 .707 r
F P
0 g
s
.68601 .84619 m .68528 .82825 L .66128 .83667 L p .707 .577 .707 r
F P
0 g
s
.54151 .83814 m .54224 .85608 L .5697 .86096 L p .707 .577 .707 r
F P
0 g
s
.51625 .79581 m .51599 .75893 L .5034 .75065 L p .707 .577 .707 r
F P
0 g
s
.70058 .67713 m .69497 .73454 L .70164 .73441 L p .707 .577 .707 r
F P
0 g
s
.70164 .73441 m .70725 .677 L .70058 .67713 L p .707 .577 .707 r
F P
0 g
s
.54224 .85608 m .54151 .83814 L .52042 .83027 L p .707 .577 .707 r
F P
0 g
s
.5034 .75065 m .50366 .78753 L .51625 .79581 L p .707 .577 .707 r
F P
0 g
s
.50183 .71541 m .50744 .658 L .50417 .65689 L p .707 .577 .707 r
F P
0 g
s
.50417 .65689 m .49856 .7143 L .50183 .71541 L p .707 .577 .707 r
F P
0 g
s
.69731 .75307 m .69757 .78995 L .70465 .78104 L p .707 .577 .707 r
F P
0 g
s
.70465 .78104 m .7044 .74416 L .69731 .75307 L p .707 .577 .707 r
F P
0 g
s
.52042 .83027 m .52115 .84822 L .54224 .85608 L p .707 .577 .707 r
F P
0 g
s
.68528 .82825 m .68601 .84619 L .70232 .83576 L p .707 .577 .707 r
F P
0 g
s
.70232 .83576 m .70159 .81782 L .68528 .82825 L p .707 .577 .707 r
F P
0 g
s
.50366 .78753 m .5034 .75065 L .5005 .74162 L p .707 .577 .707 r
F P
0 g
s
.52115 .84822 m .52042 .83027 L .50779 .82019 L p .707 .577 .707 r
F P
0 g
s
.70725 .677 m .70164 .73441 L .69837 .7333 L p .707 .577 .707 r
F P
0 g
s
.69837 .7333 m .70399 .67589 L .70725 .677 L p .707 .577 .707 r
F P
0 g
s
.50779 .82019 m .50852 .83813 L .52115 .84822 L p .707 .577 .707 r
F P
0 g
s
.5005 .74162 m .50076 .7785 L .50366 .78753 L p .707 .577 .707 r
F P
0 g
s
.48316 .8187 m .4943 .31017 L .45029 .30709 L p .707 .577 .707 r
F P
0 g
s
.49856 .7143 m .50417 .65689 L .51085 .65677 L p .707 .577 .707 r
F P
0 g
s
.51085 .65677 m .50523 .71417 L .49856 .7143 L p .707 .577 .707 r
F P
0 g
s
.50076 .7785 m .5005 .74162 L .50758 .73271 L p .707 .577 .707 r
F P
0 g
s
.50852 .83813 m .50779 .82019 L .50483 .80888 L p .707 .577 .707 r
F P
0 g
s
.50483 .80888 m .50556 .82682 L .50852 .83813 L p .707 .577 .707 r
F P
0 g
s
.50758 .73271 m .50784 .76959 L .50076 .7785 L p .707 .577 .707 r
F P
0 g
s
.50523 .71417 m .51085 .65677 L .52681 .65764 L p .707 .577 .707 r
F P
0 g
s
.52681 .65764 m .52119 .71504 L .50523 .71417 L p .707 .577 .707 r
F P
0 g
s
.50784 .76959 m .50758 .73271 L .52395 .7248 L p .707 .577 .707 r
F P
0 g
s
.50556 .82682 m .50483 .80888 L .51186 .79745 L p .707 .577 .707 r
F P
0 g
s
.51186 .79745 m .51259 .81539 L .50556 .82682 L p .707 .577 .707 r
F P
0 g
s
.52395 .7248 m .52421 .76167 L .50784 .76959 L p .707 .577 .707 r
F P
0 g
s
.52119 .71504 m .52681 .65764 L .55049 .65942 L p .707 .577 .707 r
F P
0 g
s
.55049 .65942 m .54488 .71683 L .52119 .71504 L p .707 .577 .707 r
F P
0 g
s
.52421 .76167 m .52395 .7248 L .548 .71865 L p .707 .577 .707 r
F P
0 g
s
.51259 .81539 m .51186 .79745 L .52816 .78702 L p .707 .577 .707 r
F P
0 g
s
.52816 .78702 m .52889 .80496 L .51259 .81539 L p .707 .577 .707 r
F P
0 g
s
.548 .71865 m .54826 .75553 L .52421 .76167 L p .707 .577 .707 r
F P
0 g
s
.4943 .31017 m .48316 .8187 L .52809 .81874 L p .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .52816 .78702 L .54837 .77993 L p .707 .577 .707 r
F P
0 g
s
.57958 .66194 m .57397 .71934 L .54488 .71683 L p .707 .577 .707 r
F P
0 g
s
.57397 .71934 m .57718 .68644 L p .58392 .68219 L .707 .577 .707 r
F P
0 g
s
.58001 .71052 m .58392 .68219 L .61123 .66495 L .707 .577 .707 r
F
.57397 .71934 m .58392 .68219 L .58001 .71052 L F
.59453 .66336 m .61123 .66495 L p .57718 .68644 L F P
0 g
s
.64233 .66815 m .63672 .72556 L .60993 .7228 L p .707 .577 .707 r
F P
0 g
s
.60993 .7228 m .60562 .72235 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.61043 .71525 m .64233 .66815 L .60993 .7228 L .707 .577 .707 r
F
.60562 .72235 m .61123 .66495 L .61373 .66521 L p F P
0 g
s
.61373 .66521 m .64233 .66815 L p .61043 .71525 L .707 .577 .707 r
F P
0 g
s
.60562 .72235 m .61373 .66521 L .61043 .71525 L .707 .577 .707 r
F
.66986 .67124 m .66425 .72865 L .63672 .72556 L p F P
0 g
s
.63672 .72556 m .64233 .66815 L .66986 .67124 L p .707 .577 .707 r
F P
0 g
s
.64039 .71567 m .64065 .75255 L .60947 .75073 L p .707 .577 .707 r
F P
0 g
s
.60947 .75073 m .60922 .71386 L .64039 .71567 L p .707 .577 .707 r
F P
0 g
s
.64447 .77225 m .6452 .79019 L .61404 .78878 L p .707 .577 .707 r
F P
0 g
s
.61404 .78878 m .61331 .77084 L .64447 .77225 L p .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .64768 .28427 L .6383 .29303 L p .707 .577 .707 r
F P
0 g
s
.6383 .29303 m .6377 .29359 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63654 .7928 m .6383 .29303 L .63768 .30239 L .707 .577 .707 r
F
.62657 .80211 m .63654 .7928 L p .63768 .30239 L F P
0 g
s
.6377 .29359 m .63743 .30629 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.63743 .30629 m .62657 .80211 L p .63768 .30239 L .707 .577 .707 r
F P
0 g
s
.61123 .66495 m .60562 .72235 L .57397 .71934 L p .707 .577 .707 r
F P
0 g
s
.57764 .75176 m .57738 .71488 L .60922 .71386 L p .707 .577 .707 r
F P
0 g
s
.60922 .71386 m .60947 .75073 L .57764 .75176 L p .707 .577 .707 r
F P
0 g
s
.58223 .79096 m .5815 .77302 L .61331 .77084 L p .707 .577 .707 r
F P
0 g
s
.61331 .77084 m .61404 .78878 L .58223 .79096 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .62657 .80211 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61462 .3015 m .61051 .48916 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.61051 .48916 m .60348 .81003 L p .61783 .43603 L .707 .577 .707 r
F P
0 g
s
.54826 .75553 m .54805 .72519 L p .57738 .71488 L .707 .577 .707 r
F P
0 g
s
.54805 .72519 m .548 .71865 L .55349 .71795 L p .707 .577 .707 r
F P
0 g
s
.55349 .71795 m .57738 .71488 L p .54805 .72519 L .707 .577 .707 r
F P
0 g
s
.57718 .68644 m .57958 .66194 L .59453 .66336 L p .707 .577 .707 r
F P
0 g
s
.57738 .71488 m .57764 .75176 L .54826 .75553 L p .707 .577 .707 r
F P
0 g
s
.53941 .81793 m .56955 .81576 L p .56354 .71554 L .707 .577 .707 r
F P
0 g
s
.54837 .77993 m .55216 .7786 L p .54741 .78398 L .707 .577 .707 r
F P
0 g
s
.52889 .80496 m .54837 .77993 L .54741 .78398 L .707 .577 .707 r
F
.55216 .7786 m .55289 .79654 L .52889 .80496 L p F P
0 g
s
.53923 .31021 m .52809 .81874 L .53941 .81793 L p .707 .577 .707 r
F P
0 g
s
.54488 .71683 m .54833 .68146 L p .57958 .66194 L .707 .577 .707 r
F P
0 g
s
.54833 .68146 m .55049 .65942 L .55645 .65993 L p .707 .577 .707 r
F P
0 g
s
.55645 .65993 m .57958 .66194 L p .54833 .68146 L .707 .577 .707 r
F P
0 g
s
.56955 .81576 m .58462 .81321 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.57398 .61346 m .5707 .76349 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.5707 .76349 m .56955 .81576 L p .57342 .77321 L .707 .577 .707 r
F P
0 g
s
.59236 .56472 m .5707 .76349 L .57342 .77321 L .707 .577 .707 r
F
.5815 .77302 m .58223 .79096 L .57858 .79166 L p F P
0 g
s
.56955 .81576 m .58069 .30723 L .53923 .31021 L p .707 .577 .707 r
F P
0 g
s
.57858 .79166 m .55289 .79654 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.57489 .77846 m .5815 .77302 L .57858 .79166 L .707 .577 .707 r
F
.55289 .79654 m .55216 .7786 L .57378 .77449 L p F P
0 g
s
.57378 .77449 m .5815 .77302 L p .57489 .77846 L .707 .577 .707 r
F P
0 g
s
.55289 .79654 m .57378 .77449 L .57489 .77846 L .707 .577 .707 r
F
.60348 .81003 m .59236 .56472 L .57342 .77321 L F
.58462 .81321 m .60348 .81003 L p .57342 .77321 L F P
0 g
s
.58069 .30723 m .57398 .61346 L p .59236 .56472 L .707 .577 .707 r
F P
0 g
s
.56354 .71554 m .53923 .31021 L .53941 .81793 L .707 .577 .707 r
F
.52809 .81874 m .53923 .31021 L .4943 .31017 L p F P
0 g
s
.70159 .81782 m .70232 .83576 L .70934 .82432 L p .707 .577 .707 r
F P
0 g
s
.70934 .82432 m .70861 .80638 L .70159 .81782 L p .707 .577 .707 r
F P
0 g
s
.7044 .74416 m .70465 .78104 L .70175 .772 L p .707 .577 .707 r
F P
0 g
s
.70175 .772 m .7015 .73513 L .7044 .74416 L p .707 .577 .707 r
F P
0 g
s
.43915 .81562 m .45029 .30709 L .41153 .30128 L p .707 .577 .707 r
F P
0 g
s
.45029 .30709 m .43915 .81562 L .48316 .8187 L p .707 .577 .707 r
F P
0 g
s
.60348 .81003 m .61462 .3015 L .58069 .30723 L p .707 .577 .707 r
F P
0 g
s
.70399 .67589 m .69837 .7333 L .68549 .73131 L p .707 .577 .707 r
F P
0 g
s
.68549 .73131 m .6911 .67391 L .70399 .67589 L p .707 .577 .707 r
F P
0 g
s
.25158 .68954 m .25719 .63213 L .22608 .62893 L p .707 .577 .707 r
F P
0 g
s
.25719 .63213 m .25158 .68954 L .28322 .69255 L p .707 .577 .707 r
F P
0 g
s
.28322 .69255 m .28883 .63514 L .25719 .63213 L p .707 .577 .707 r
F P
0 g
s
.22608 .62893 m .22047 .68633 L .25158 .68954 L p .707 .577 .707 r
F P
0 g
s
.28883 .63514 m .28322 .69255 L .31231 .69507 L p .707 .577 .707 r
F P
0 g
s
.31231 .69507 m .31792 .63766 L .28883 .63514 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70861 .80638 m .70934 .82432 L .70639 .81301 L p .707 .577 .707 r
F P
0 g
s
.70639 .81301 m .70566 .79507 L .70861 .80638 L p .707 .577 .707 r
F P
0 g
s
.40039 .80981 m .41153 .30128 L .38179 .29332 L p .707 .577 .707 r
F P
0 g
s
.41153 .30128 m .40039 .80981 L .43915 .81562 L p .707 .577 .707 r
F P
0 g
s
.7015 .73513 m .70175 .772 L .68916 .76373 L p .707 .577 .707 r
F P
0 g
s
.68916 .76373 m .6889 .72685 L .7015 .73513 L p .707 .577 .707 r
F P
0 g
s
.22047 .68633 m .22608 .62893 L .19856 .62584 L p .707 .577 .707 r
F P
0 g
s
.19856 .62584 m .19295 .68325 L .22047 .68633 L p .707 .577 .707 r
F P
0 g
s
.31792 .63766 m .31231 .69507 L .336 .69685 L p .707 .577 .707 r
F P
0 g
s
.336 .69685 m .34161 .63944 L .31792 .63766 L p .707 .577 .707 r
F P
0 g
s
.25293 .77199 m .25267 .73511 L .2215 .7333 L p .707 .577 .707 r
F P
0 g
s
.25267 .73511 m .25293 .77199 L .28476 .77096 L p .707 .577 .707 r
F P
0 g
s
.28476 .77096 m .28451 .73408 L .25267 .73511 L p .707 .577 .707 r
F P
0 g
s
.28451 .73408 m .28476 .77096 L .31414 .76719 L p .707 .577 .707 r
F P
0 g
s
.31414 .76719 m .31389 .73031 L .28451 .73408 L p .707 .577 .707 r
F P
0 g
s
.19295 .68325 m .19856 .62584 L .17731 .62317 L p .707 .577 .707 r
F P
0 g
s
.22176 .77017 m .2215 .7333 L .19404 .72882 L p .707 .577 .707 r
F P
0 g
s
.2215 .7333 m .22176 .77017 L .25293 .77199 L p .707 .577 .707 r
F P
0 g
s
.62657 .80211 m .6377 .29359 L .61462 .3015 L p .707 .577 .707 r
F P
0 g
s
.17731 .62317 m .1717 .68058 L .19295 .68325 L p .707 .577 .707 r
F P
0 g
s
.6911 .67391 m .68549 .73131 L .66425 .72865 L p .707 .577 .707 r
F P
0 g
s
.66425 .72865 m .66986 .67124 L .6911 .67391 L p .707 .577 .707 r
F P
0 g
s
.31389 .73031 m .31414 .76719 L .3382 .76105 L p .707 .577 .707 r
F P
0 g
s
.3382 .76105 m .33794 .72417 L .31389 .73031 L p .707 .577 .707 r
F P
0 g
s
.70566 .79507 m .70639 .81301 L .69375 .80293 L p .707 .577 .707 r
F P
0 g
s
.69375 .80293 m .69302 .78499 L .70566 .79507 L p .707 .577 .707 r
F P
0 g
s
.6889 .72685 m .68916 .76373 L .6681 .75702 L p .707 .577 .707 r
F P
0 g
s
.6681 .75702 m .66785 .72015 L .6889 .72685 L p .707 .577 .707 r
F P
0 g
s
.19404 .72882 m .1943 .7657 L .22176 .77017 L p .707 .577 .707 r
F P
0 g
s
.34161 .63944 m .336 .69685 L .35196 .69772 L p .707 .577 .707 r
F P
0 g
s
.35196 .69772 m .35757 .64031 L .34161 .63944 L p .707 .577 .707 r
F P
0 g
s
.37065 .80184 m .38179 .29332 L .36399 .28397 L p .707 .577 .707 r
F P
0 g
s
.38179 .29332 m .37065 .80184 L .40039 .80981 L p .707 .577 .707 r
F P
0 g
s
.1943 .7657 m .19404 .72882 L .17298 .72211 L p .707 .577 .707 r
F P
0 g
s
.1717 .68058 m .17731 .62317 L .16443 .62119 L p .707 .577 .707 r
F P
0 g
s
.16443 .62119 m .15882 .67859 L .1717 .68058 L p .707 .577 .707 r
F P
0 g
s
.25786 .82556 m .25713 .80762 L .22597 .8062 L p .707 .577 .707 r
F P
0 g
s
.25713 .80762 m .25786 .82556 L .28967 .82337 L p .707 .577 .707 r
F P
0 g
s
.28967 .82337 m .28894 .80543 L .25713 .80762 L p .707 .577 .707 r
F P
0 g
s
.17298 .72211 m .17324 .75899 L .1943 .7657 L p .707 .577 .707 r
F P
0 g
s
.28894 .80543 m .28967 .82337 L .319 .81779 L p .707 .577 .707 r
F P
0 g
s
.319 .81779 m .31827 .79985 L .28894 .80543 L p .707 .577 .707 r
F P
0 g
s
.33794 .72417 m .3382 .76105 L .35456 .75313 L p .707 .577 .707 r
F P
0 g
s
.35456 .75313 m .35431 .71626 L .33794 .72417 L p .707 .577 .707 r
F P
0 g
s
.22597 .8062 m .2267 .82414 L .25786 .82556 L p .707 .577 .707 r
F P
0 g
s
.2267 .82414 m .22597 .8062 L .1985 .80132 L p .707 .577 .707 r
F P
0 g
s
.66785 .72015 m .6681 .75702 L .64065 .75255 L p .707 .577 .707 r
F P
0 g
s
.64065 .75255 m .64039 .71567 L .66785 .72015 L p .707 .577 .707 r
F P
0 g
s
.69302 .78499 m .69375 .80293 L .67267 .79507 L p .707 .577 .707 r
F P
0 g
s
.67267 .79507 m .67194 .77713 L .69302 .78499 L p .707 .577 .707 r
F P
0 g
s
.31827 .79985 m .319 .81779 L .343 .80938 L p .707 .577 .707 r
F P
0 g
s
.343 .80938 m .34227 .79144 L .31827 .79985 L p .707 .577 .707 r
F P
0 g
s
.1985 .80132 m .19923 .81926 L .2267 .82414 L p .707 .577 .707 r
F P
0 g
s
.17324 .75899 m .17298 .72211 L .16039 .71384 L p .707 .577 .707 r
F P
0 g
s
.35757 .64031 m .35196 .69772 L .35863 .69759 L p .707 .577 .707 r
F P
0 g
s
.35863 .69759 m .36424 .64019 L .35757 .64031 L p .707 .577 .707 r
F P
0 g
s
.19923 .81926 m .1985 .80132 L .17741 .79346 L p .707 .577 .707 r
F P
0 g
s
.16039 .71384 m .16065 .75072 L .17324 .75899 L p .707 .577 .707 r
F P
0 g
s
.15882 .67859 m .16443 .62119 L .16116 .62008 L p .707 .577 .707 r
F P
0 g
s
.16116 .62008 m .15555 .67748 L .15882 .67859 L p .707 .577 .707 r
F P
0 g
s
.35431 .71626 m .35456 .75313 L .36164 .74422 L p .707 .577 .707 r
F P
0 g
s
.36164 .74422 m .36139 .70735 L .35431 .71626 L p .707 .577 .707 r
F P
0 g
s
.17741 .79346 m .17814 .8114 L .19923 .81926 L p .707 .577 .707 r
F P
0 g
s
.35931 .79894 m .35858 .781 L .34227 .79144 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .34248 .6945 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36098 .63908 m .35882 .66112 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.35882 .66112 m .35537 .69648 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35988 .27416 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .34809 .63709 L .35833 .63867 L p .707 .577 .707 r
F P
0 g
s
.35833 .63867 m .36098 .63908 L p .3585 .64648 L .707 .577 .707 r
F P
0 g
s
.34248 .6945 m .35833 .63867 L .3585 .64648 L .707 .577 .707 r
F
.35849 .69831 m .35875 .73519 L .34615 .72691 L p F P
0 g
s
.36424 .64019 m .35863 .69759 L .35537 .69648 L p .707 .577 .707 r
F P
0 g
s
.35537 .69648 m .36098 .63908 L .36424 .64019 L p .707 .577 .707 r
F P
0 g
s
.34615 .72691 m .34589 .69004 L .35849 .69831 L p .707 .577 .707 r
F P
0 g
s
.35102 .78814 m .35285 .7925 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35728 .5902 L .35624 .54229 L .707 .577 .707 r
F
.35285 .7925 m .354 .74023 L p .35344 .74923 L F P
0 g
s
.354 .74023 m .35728 .5902 L p .35344 .74923 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35001 .74818 L .35334 .75083 L p .707 .577 .707 r
F P
0 g
s
.35858 .781 m .35931 .79894 L .36633 .78751 L p .707 .577 .707 r
F P
0 g
s
.36633 .78751 m .3656 .76957 L .35858 .781 L p .707 .577 .707 r
F P
0 g
s
.36139 .70735 m .36164 .74422 L .35875 .73519 L p .707 .577 .707 r
F P
0 g
s
.35875 .73519 m .35849 .69831 L .36139 .70735 L p .707 .577 .707 r
F P
0 g
s
.36399 .28397 m .35589 .65388 L p .37065 .80184 L .707 .577 .707 r
F P
0 g
s
.35589 .65388 m .35285 .7925 L .36579 .79929 L p .707 .577 .707 r
F P
0 g
s
.3656 .76957 m .36633 .78751 L .36451 .78053 L p .707 .577 .707 r
F P
0 g
s
.36407 .77413 m .3656 .76957 L .36451 .78053 L .707 .577 .707 r
F
.36338 .7762 m .36265 .75826 L .3656 .76957 L p F P
0 g
s
.36579 .79929 m .37065 .80184 L p .35589 .65388 L .707 .577 .707 r
F P
0 g
s
.36451 .78053 m .36338 .7762 L p .36407 .77413 L .707 .577 .707 r
F P
0 g
s
.35334 .75083 m .36265 .75826 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35074 .76612 m .35334 .75083 L .35246 .76499 L .707 .577 .707 r
F
.36265 .75826 m .36338 .7762 L .35231 .76737 L p F P
0 g
s
.35231 .76737 m .35074 .76612 L p .35246 .76499 L .707 .577 .707 r
F P
0 g
s
.35246 .76499 m .36265 .75826 L .35231 .76737 L .707 .577 .707 r
F
.35001 .74818 m .35074 .76612 L .32966 .75826 L p F P
0 g
s
.32966 .75826 m .32893 .74031 L .35001 .74818 L p .707 .577 .707 r
F P
0 g
s
.34874 .78268 m .35102 .78814 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35344 .74923 m .35624 .54229 L .35102 .78814 L .707 .577 .707 r
F
.35988 .27416 m .35513 .49095 L p .35624 .54229 L F P
0 g
s
.35513 .49095 m .34874 .78268 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.35728 .5902 m .36399 .28397 L p .35624 .54229 L .707 .577 .707 r
F P
0 g
s
.34227 .79144 m .343 .80938 L .35931 .79894 L p .707 .577 .707 r
F P
0 g
s
.67194 .77713 m .67267 .79507 L .6452 .79019 L p .707 .577 .707 r
F P
0 g
s
.6452 .79019 m .64447 .77225 L .67194 .77713 L p .707 .577 .707 r
F P
0 g
s
.16065 .75072 m .16039 .71384 L .15749 .7048 L p .707 .577 .707 r
F P
0 g
s
.17814 .8114 m .17741 .79346 L .16478 .78338 L p .707 .577 .707 r
F P
0 g
s
.16478 .78338 m .16551 .80132 L .17814 .8114 L p .707 .577 .707 r
F P
0 g
s
.15749 .7048 m .15775 .74168 L .16065 .75072 L p .707 .577 .707 r
F P
0 g
s
.64768 .28427 m .63654 .7928 L .63242 .78298 L p .707 .577 .707 r
F P
0 g
s
.63242 .78298 m .64356 .27445 L .64768 .28427 L p .707 .577 .707 r
F P
0 g
s
.15555 .67748 m .16116 .62008 L .16784 .61995 L p .707 .577 .707 r
F P
0 g
s
.16784 .61995 m .16223 .67736 L .15555 .67748 L p .707 .577 .707 r
F P
0 g
s
.15775 .74168 m .15749 .7048 L .16457 .69589 L p .707 .577 .707 r
F P
0 g
s
.16551 .80132 m .16478 .78338 L .16183 .77207 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34874 .78268 m .35988 .27416 L .36985 .26484 L p .707 .577 .707 r
F P
0 g
s
.16183 .77207 m .16256 .79001 L .16551 .80132 L p .707 .577 .707 r
F P
0 g
s
.16457 .69589 m .16483 .73277 L .15775 .74168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16223 .67736 m .16784 .61995 L .1838 .62082 L p .707 .577 .707 r
F P
0 g
s
.1838 .62082 m .17818 .67823 L .16223 .67736 L p .707 .577 .707 r
F P
0 g
s
.64356 .27445 m .63242 .78298 L .61463 .77364 L p .707 .577 .707 r
F P
0 g
s
.61463 .77364 m .62577 .26511 L .64356 .27445 L p .707 .577 .707 r
F P
0 g
s
.16483 .73277 m .16457 .69589 L .18094 .68798 L p .707 .577 .707 r
F P
0 g
s
.16256 .79001 m .16183 .77207 L .16885 .76064 L p .707 .577 .707 r
F P
0 g
s
.34809 .63709 m .34248 .6945 L .32124 .69183 L p .707 .577 .707 r
F P
0 g
s
.32124 .69183 m .32685 .63442 L .34809 .63709 L p .707 .577 .707 r
F P
0 g
s
.16885 .76064 m .16958 .77858 L .16256 .79001 L p .707 .577 .707 r
F P
0 g
s
.18094 .68798 m .1812 .72486 L .16483 .73277 L p .707 .577 .707 r
F P
0 g
s
.35871 .77337 m .36985 .26484 L .39293 .25693 L p .707 .577 .707 r
F P
0 g
s
.36985 .26484 m .35871 .77337 L .34874 .78268 L p .707 .577 .707 r
F P
0 g
s
.17818 .67823 m .1838 .62082 L .20748 .6226 L p .707 .577 .707 r
F P
0 g
s
.34589 .69004 m .34615 .72691 L .32509 .72021 L p .707 .577 .707 r
F P
0 g
s
.32509 .72021 m .32484 .68333 L .34589 .69004 L p .707 .577 .707 r
F P
0 g
s
.20748 .6226 m .20187 .68001 L .17818 .67823 L p .707 .577 .707 r
F P
0 g
s
.1812 .72486 m .18094 .68798 L .20499 .68184 L p .707 .577 .707 r
F P
0 g
s
.16958 .77858 m .16885 .76064 L .18515 .7502 L p .707 .577 .707 r
F P
0 g
s
.32685 .63442 m .32124 .69183 L .29371 .68874 L p .707 .577 .707 r
F P
0 g
s
.29371 .68874 m .29932 .63134 L .32685 .63442 L p .707 .577 .707 r
F P
0 g
s
.18515 .7502 m .18588 .76814 L .16958 .77858 L p .707 .577 .707 r
F P
0 g
s
.20187 .68001 m .20748 .6226 L .23657 .62512 L p .707 .577 .707 r
F P
0 g
s
.20499 .68184 m .20525 .71871 L .1812 .72486 L p .707 .577 .707 r
F P
0 g
s
.23657 .62512 m .23096 .68253 L .20187 .68001 L p .707 .577 .707 r
F P
0 g
s
.62577 .26511 m .61463 .77364 L .58489 .76567 L p .707 .577 .707 r
F P
0 g
s
.58489 .76567 m .59603 .25714 L .62577 .26511 L p .707 .577 .707 r
F P
0 g
s
.32484 .68333 m .32509 .72021 L .29764 .71573 L p .707 .577 .707 r
F P
0 g
s
.29764 .71573 m .29738 .67885 L .32484 .68333 L p .707 .577 .707 r
F P
0 g
s
.29932 .63134 m .29371 .68874 L .26261 .68554 L p .707 .577 .707 r
F P
0 g
s
.26261 .68554 m .26822 .62813 L .29932 .63134 L p .707 .577 .707 r
F P
0 g
s
.73179 .63171 m .7374 .5743 L .70629 .57109 L p .707 .577 .707 r
F P
0 g
s
.7374 .5743 m .73179 .63171 L .76344 .63472 L p .707 .577 .707 r
F P
0 g
s
.76344 .63472 m .76905 .57731 L .7374 .5743 L p .707 .577 .707 r
F P
0 g
s
.23096 .68253 m .23417 .64962 L p .26822 .62813 L .707 .577 .707 r
F P
0 g
s
.23417 .64962 m .23657 .62512 L .25152 .62654 L p .707 .577 .707 r
F P
0 g
s
.25152 .62654 m .26822 .62813 L p .23417 .64962 L .707 .577 .707 r
F P
0 g
s
.26822 .62813 m .26261 .68554 L .23096 .68253 L p .707 .577 .707 r
F P
0 g
s
.20525 .71871 m .20504 .68838 L p .23437 .67807 L .707 .577 .707 r
F P
0 g
s
.20504 .68838 m .20499 .68184 L .21048 .68113 L p .707 .577 .707 r
F P
0 g
s
.21048 .68113 m .23437 .67807 L p .20504 .68838 L .707 .577 .707 r
F P
0 g
s
.70629 .57109 m .70068 .6285 L .73179 .63171 L p .707 .577 .707 r
F P
0 g
s
.76905 .57731 m .76344 .63472 L .79253 .63724 L p .707 .577 .707 r
F P
0 g
s
.79253 .63724 m .79814 .57983 L .76905 .57731 L p .707 .577 .707 r
F P
0 g
s
.39293 .25693 m .38179 .76545 L .35871 .77337 L p .707 .577 .707 r
F P
0 g
s
.38179 .76545 m .39293 .25693 L .42686 .2512 L p .707 .577 .707 r
F P
0 g
s
.70068 .6285 m .70629 .57109 L .67877 .56801 L p .707 .577 .707 r
F P
0 g
s
.29738 .67885 m .29764 .71573 L .26646 .71392 L p .707 .577 .707 r
F P
0 g
s
.26646 .71392 m .26621 .67704 L .29738 .67885 L p .707 .577 .707 r
F P
0 g
s
.67877 .56801 m .67316 .62541 L .70068 .6285 L p .707 .577 .707 r
F P
0 g
s
.18588 .76814 m .18515 .7502 L .20915 .74178 L p .707 .577 .707 r
F P
0 g
s
.23437 .67807 m .23463 .71494 L .20525 .71871 L p .707 .577 .707 r
F P
0 g
s
.23463 .71494 m .23437 .67807 L .26621 .67704 L p .707 .577 .707 r
F P
0 g
s
.26621 .67704 m .26646 .71392 L .23463 .71494 L p .707 .577 .707 r
F P
0 g
s
.20915 .74178 m .20988 .75972 L .18588 .76814 L p .707 .577 .707 r
F P
0 g
s
.79814 .57983 m .79253 .63724 L .81621 .63902 L p .707 .577 .707 r
F P
0 g
s
.81621 .63902 m .82182 .58161 L .79814 .57983 L p .707 .577 .707 r
F P
0 g
s
.32893 .74031 m .32966 .75826 L .30219 .75338 L p .707 .577 .707 r
F P
0 g
s
.30219 .75338 m .30146 .73544 L .32893 .74031 L p .707 .577 .707 r
F P
0 g
s
.73314 .72249 m .73288 .68562 L .70171 .6838 L p .707 .577 .707 r
F P
0 g
s
.73288 .68562 m .73314 .72249 L .76498 .72146 L p .707 .577 .707 r
F P
0 g
s
.76498 .72146 m .76472 .68459 L .73288 .68562 L p .707 .577 .707 r
F P
0 g
s
.76472 .68459 m .76498 .72146 L .79436 .71769 L p .707 .577 .707 r
F P
0 g
s
.79436 .71769 m .7941 .68082 L .76472 .68459 L p .707 .577 .707 r
F P
0 g
s
.67316 .62541 m .67877 .56801 L .65753 .56534 L p .707 .577 .707 r
F P
0 g
s
.65753 .56534 m .65192 .62275 L .67316 .62541 L p .707 .577 .707 r
F P
0 g
s
.59603 .25714 m .58489 .76567 L .54612 .75986 L p .707 .577 .707 r
F P
0 g
s
.54612 .75986 m .55726 .25133 L .59603 .25714 L p .707 .577 .707 r
F P
0 g
s
.70197 .72068 m .70171 .6838 L .67425 .67932 L p .707 .577 .707 r
F P
0 g
s
.70171 .6838 m .70197 .72068 L .73314 .72249 L p .707 .577 .707 r
F P
0 g
s
.20988 .75972 m .20915 .74178 L .23849 .73621 L p .707 .577 .707 r
F P
0 g
s
.7941 .68082 m .79436 .71769 L .81841 .71155 L p .707 .577 .707 r
F P
0 g
s
.81841 .71155 m .81815 .67467 L .7941 .68082 L p .707 .577 .707 r
F P
0 g
s
.30146 .73544 m .30219 .75338 L .27103 .75196 L p .707 .577 .707 r
F P
0 g
s
.27103 .75196 m .2703 .73402 L .30146 .73544 L p .707 .577 .707 r
F P
0 g
s
.23849 .73621 m .23922 .75415 L .20988 .75972 L p .707 .577 .707 r
F P
0 g
s
.41572 .75972 m .42686 .2512 L .46832 .24821 L p .707 .577 .707 r
F P
0 g
s
.42686 .2512 m .41572 .75972 L .38179 .76545 L p .707 .577 .707 r
F P
0 g
s
.67425 .67932 m .67451 .7162 L .70197 .72068 L p .707 .577 .707 r
F P
0 g
s
.82182 .58161 m .81621 .63902 L .83217 .63989 L p .707 .577 .707 r
F P
0 g
s
.83217 .63989 m .83778 .58248 L .82182 .58161 L p .707 .577 .707 r
F P
0 g
s
.23922 .75415 m .23849 .73621 L .2703 .73402 L p .707 .577 .707 r
F P
0 g
s
.2703 .73402 m .27103 .75196 L .23922 .75415 L p .707 .577 .707 r
F P
0 g
s
.67451 .7162 m .67425 .67932 L .6532 .67262 L p .707 .577 .707 r
F P
0 g
s
.65192 .62275 m .65753 .56534 L .64464 .56335 L p .707 .577 .707 r
F P
0 g
s
.73807 .76166 m .73734 .74372 L .70618 .7423 L p .707 .577 .707 r
F P
0 g
s
.73734 .74372 m .73807 .76166 L .76988 .75947 L p .707 .577 .707 r
F P
0 g
s
.76988 .75947 m .76915 .74153 L .73734 .74372 L p .707 .577 .707 r
F P
0 g
s
.55726 .25133 m .54612 .75986 L .50212 .75678 L p .707 .577 .707 r
F P
0 g
s
.50212 .75678 m .51325 .24826 L .55726 .25133 L p .707 .577 .707 r
F P
0 g
s
.64464 .56335 m .63903 .62076 L .65192 .62275 L p .707 .577 .707 r
F P
0 g
s
.76915 .74153 m .76988 .75947 L .79922 .75389 L p .707 .577 .707 r
F P
0 g
s
.79922 .75389 m .79849 .73595 L .76915 .74153 L p .707 .577 .707 r
F P
0 g
s
.45718 .75674 m .46832 .24821 L .51325 .24826 L p .707 .577 .707 r
F P
0 g
s
.46832 .24821 m .45718 .75674 L .41572 .75972 L p .707 .577 .707 r
F P
0 g
s
.6532 .67262 m .65345 .70949 L .67451 .7162 L p .707 .577 .707 r
F P
0 g
s
.70618 .7423 m .70691 .76024 L .73807 .76166 L p .707 .577 .707 r
F P
0 g
s
.70691 .76024 m .70618 .7423 L .67871 .73742 L p .707 .577 .707 r
F P
0 g
s
.81815 .67467 m .81841 .71155 L .83478 .70364 L p .707 .577 .707 r
F P
0 g
s
.83478 .70364 m .83452 .66676 L .81815 .67467 L p .707 .577 .707 r
F P
0 g
s
.51325 .24826 m .50212 .75678 L .45718 .75674 L p .707 .577 .707 r
F P
0 g
s
.79849 .73595 m .79922 .75389 L .82321 .74548 L p .707 .577 .707 r
F P
0 g
s
.82321 .74548 m .82248 .72754 L .79849 .73595 L p .707 .577 .707 r
F P
0 g
s
.67871 .73742 m .67944 .75536 L .70691 .76024 L p .707 .577 .707 r
F P
0 g
s
.65345 .70949 m .6532 .67262 L .6406 .66434 L p .707 .577 .707 r
F P
0 g
s
.83778 .58248 m .83217 .63989 L .83884 .63976 L p .707 .577 .707 r
F P
0 g
s
.83884 .63976 m .84446 .58236 L .83778 .58248 L p .707 .577 .707 r
F P
0 g
s
.67944 .75536 m .67871 .73742 L .65763 .72956 L p .707 .577 .707 r
F P
0 g
s
.63903 .62076 m .64464 .56335 L .64138 .56224 L p .707 .577 .707 r
F P
0 g
s
.6406 .66434 m .64086 .70122 L .65345 .70949 L p .707 .577 .707 r
F P
0 g
s
.65763 .72956 m .65836 .7475 L .67944 .75536 L p .707 .577 .707 r
F P
0 g
s
.64138 .56224 m .63576 .61965 L .63903 .62076 L p .707 .577 .707 r
F P
0 g
s
.82248 .72754 m .82321 .74548 L .83952 .73504 L p .707 .577 .707 r
F P
0 g
s
.83952 .73504 m .83879 .7171 L .82248 .72754 L p .707 .577 .707 r
F P
0 g
s
.83452 .66676 m .83478 .70364 L .84186 .69473 L p .707 .577 .707 r
F P
0 g
s
.84186 .69473 m .8416 .65785 L .83452 .66676 L p .707 .577 .707 r
F P
0 g
s
.65836 .7475 m .65763 .72956 L .64499 .71948 L p .707 .577 .707 r
F P
0 g
s
.64086 .70122 m .6406 .66434 L .63771 .65531 L p .707 .577 .707 r
F P
0 g
s
.84446 .58236 m .83884 .63976 L .83558 .63865 L p .707 .577 .707 r
F P
0 g
s
.83558 .63865 m .84119 .58125 L .84446 .58236 L p .707 .577 .707 r
F P
0 g
s
.64499 .71948 m .64572 .73742 L .65836 .7475 L p .707 .577 .707 r
F P
0 g
s
.63771 .65531 m .63796 .69218 L .64086 .70122 L p .707 .577 .707 r
F P
0 g
s
.83879 .7171 m .83952 .73504 L .84654 .72361 L p .707 .577 .707 r
F P
0 g
s
.84654 .72361 m .84581 .70567 L .83879 .7171 L p .707 .577 .707 r
F P
0 g
s
.63576 .61965 m .64138 .56224 L .64805 .56212 L p .707 .577 .707 r
F P
0 g
s
.64805 .56212 m .64244 .61952 L .63576 .61965 L p .707 .577 .707 r
F P
0 g
s
.8416 .65785 m .84186 .69473 L .83896 .68569 L p .707 .577 .707 r
F P
0 g
s
.83896 .68569 m .8387 .64882 L .8416 .65785 L p .707 .577 .707 r
F P
0 g
s
.64572 .73742 m .64499 .71948 L .64204 .70817 L p .707 .577 .707 r
F P
0 g
s
.63796 .69218 m .63771 .65531 L .64479 .6464 L p .707 .577 .707 r
F P
0 g
s
.64204 .70817 m .64277 .72611 L .64572 .73742 L p .707 .577 .707 r
F P
0 g
s
.84119 .58125 m .83558 .63865 L .82269 .63667 L p .707 .577 .707 r
F P
0 g
s
.82269 .63667 m .8283 .57926 L .84119 .58125 L p .707 .577 .707 r
F P
0 g
s
.38878 .59489 m .39439 .53748 L .36328 .53428 L p .707 .577 .707 r
F P
0 g
s
.39439 .53748 m .38878 .59489 L .42043 .5979 L p .707 .577 .707 r
F P
0 g
s
.42043 .5979 m .42604 .54049 L .39439 .53748 L p .707 .577 .707 r
F P
0 g
s
.36328 .53428 m .35767 .59169 L .38878 .59489 L p .707 .577 .707 r
F P
0 g
s
.84581 .70567 m .84654 .72361 L .84359 .7123 L p .707 .577 .707 r
F P
0 g
s
.84359 .7123 m .84286 .69436 L .84581 .70567 L p .707 .577 .707 r
F P
0 g
s
.64479 .6464 m .64504 .68327 L .63796 .69218 L p .707 .577 .707 r
F P
0 g
s
.42604 .54049 m .42043 .5979 L .44952 .60042 L p .707 .577 .707 r
F P
0 g
s
.44952 .60042 m .45513 .54301 L .42604 .54049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64244 .61952 m .64805 .56212 L .66401 .56299 L p .707 .577 .707 r
F P
0 g
s
.35767 .59169 m .36328 .53428 L .33576 .53119 L p .707 .577 .707 r
F P
0 g
s
.66401 .56299 m .6584 .6204 L .64244 .61952 L p .707 .577 .707 r
F P
0 g
s
.33576 .53119 m .33015 .5886 L .35767 .59169 L p .707 .577 .707 r
F P
0 g
s
.8387 .64882 m .83896 .68569 L .82637 .67742 L p .707 .577 .707 r
F P
0 g
s
.82637 .67742 m .82611 .64054 L .8387 .64882 L p .707 .577 .707 r
F P
0 g
s
.45513 .54301 m .44952 .60042 L .4732 .6022 L p .707 .577 .707 r
F P
0 g
s
.4732 .6022 m .47881 .5448 L .45513 .54301 L p .707 .577 .707 r
F P
0 g
s
.64277 .72611 m .64204 .70817 L .64906 .69674 L p .707 .577 .707 r
F P
0 g
s
.39013 .68568 m .38987 .6488 L .3587 .64699 L p .707 .577 .707 r
F P
0 g
s
.38987 .6488 m .39013 .68568 L .42197 .68465 L p .707 .577 .707 r
F P
0 g
s
.42197 .68465 m .42171 .64777 L .38987 .6488 L p .707 .577 .707 r
F P
0 g
s
.64504 .68327 m .64479 .6464 L .66115 .63848 L p .707 .577 .707 r
F P
0 g
s
.42171 .64777 m .42197 .68465 L .45135 .68088 L p .707 .577 .707 r
F P
0 g
s
.45135 .68088 m .45109 .644 L .42171 .64777 L p .707 .577 .707 r
F P
0 g
s
.33015 .5886 m .33576 .53119 L .31452 .52852 L p .707 .577 .707 r
F P
0 g
s
.31452 .52852 m .30891 .58593 L .33015 .5886 L p .707 .577 .707 r
F P
0 g
s
.64906 .69674 m .64979 .71468 L .64277 .72611 L p .707 .577 .707 r
F P
0 g
s
.8283 .57926 m .82269 .63667 L .80145 .634 L p .707 .577 .707 r
F P
0 g
s
.80145 .634 m .80706 .57659 L .8283 .57926 L p .707 .577 .707 r
F P
0 g
s
.35896 .68386 m .3587 .64699 L .33124 .64251 L p .707 .577 .707 r
F P
0 g
s
.3587 .64699 m .35896 .68386 L .39013 .68568 L p .707 .577 .707 r
F P
0 g
s
.84286 .69436 m .84359 .7123 L .83096 .70222 L p .707 .577 .707 r
F P
0 g
s
.83096 .70222 m .83023 .68428 L .84286 .69436 L p .707 .577 .707 r
F P
0 g
s
.66115 .63848 m .66141 .67536 L .64504 .68327 L p .707 .577 .707 r
F P
0 g
s
.45109 .644 m .45135 .68088 L .4754 .67474 L p .707 .577 .707 r
F P
0 g
s
.4754 .67474 m .47514 .63786 L .45109 .644 L p .707 .577 .707 r
F P
0 g
s
.6584 .6204 m .66401 .56299 L .68769 .56477 L p .707 .577 .707 r
F P
0 g
s
.68769 .56477 m .68208 .62218 L .6584 .6204 L p .707 .577 .707 r
F P
0 g
s
.82611 .64054 m .82637 .67742 L .80531 .67071 L p .707 .577 .707 r
F P
0 g
s
.80531 .67071 m .80505 .63384 L .82611 .64054 L p .707 .577 .707 r
F P
0 g
s
.33124 .64251 m .3315 .67938 L .35896 .68386 L p .707 .577 .707 r
F P
0 g
s
.47881 .5448 m .4732 .6022 L .48916 .60307 L p .707 .577 .707 r
F P
0 g
s
.48916 .60307 m .49477 .54567 L .47881 .5448 L p .707 .577 .707 r
F P
0 g
s
.3315 .67938 m .33124 .64251 L .31019 .6358 L p .707 .577 .707 r
F P
0 g
s
.30891 .58593 m .31452 .52852 L .30163 .52654 L p .707 .577 .707 r
F P
0 g
s
.64979 .71468 m .64906 .69674 L .66537 .6863 L p .707 .577 .707 r
F P
0 g
s
.39506 .72484 m .39433 .7069 L .36317 .70549 L p .707 .577 .707 r
F P
0 g
s
.39433 .7069 m .39506 .72484 L .42687 .72265 L p .707 .577 .707 r
F P
0 g
s
.42687 .72265 m .42614 .70471 L .39433 .7069 L p .707 .577 .707 r
F P
0 g
s
.66141 .67536 m .66115 .63848 L .68521 .63234 L p .707 .577 .707 r
F P
0 g
s
.30163 .52654 m .29602 .58395 L .30891 .58593 L p .707 .577 .707 r
F P
0 g
s
.80706 .57659 m .80145 .634 L .77393 .63091 L p .707 .577 .707 r
F P
0 g
s
.77393 .63091 m .77954 .57351 L .80706 .57659 L p .707 .577 .707 r
F P
0 g
s
.42614 .70471 m .42687 .72265 L .45621 .71708 L p .707 .577 .707 r
F P
0 g
s
.45621 .71708 m .45548 .69914 L .42614 .70471 L p .707 .577 .707 r
F P
0 g
s
.31019 .6358 m .31044 .67268 L .3315 .67938 L p .707 .577 .707 r
F P
0 g
s
.66537 .6863 m .6661 .70424 L .64979 .71468 L p .707 .577 .707 r
F P
0 g
s
.36317 .70549 m .3639 .72343 L .39506 .72484 L p .707 .577 .707 r
F P
0 g
s
.3639 .72343 m .36317 .70549 L .3357 .70061 L p .707 .577 .707 r
F P
0 g
s
.47514 .63786 m .4754 .67474 L .49177 .66682 L p .707 .577 .707 r
F P
0 g
s
.49177 .66682 m .49151 .62995 L .47514 .63786 L p .707 .577 .707 r
F P
0 g
s
.68208 .62218 m .68769 .56477 L .71678 .56729 L p .707 .577 .707 r
F P
0 g
s
.71678 .56729 m .71117 .6247 L .68208 .62218 L p .707 .577 .707 r
F P
0 g
s
.68521 .63234 m .68546 .66922 L .66141 .67536 L p .707 .577 .707 r
F P
0 g
s
.83023 .68428 m .83096 .70222 L .80987 .69435 L p .707 .577 .707 r
F P
0 g
s
.80987 .69435 m .80914 .67641 L .83023 .68428 L p .707 .577 .707 r
F P
0 g
s
.80505 .63384 m .80531 .67071 L .77785 .66623 L p .707 .577 .707 r
F P
0 g
s
.77785 .66623 m .77759 .62936 L .80505 .63384 L p .707 .577 .707 r
F P
0 g
s
.45548 .69914 m .45621 .71708 L .4802 .70866 L p .707 .577 .707 r
F P
0 g
s
.4802 .70866 m .47947 .69072 L .45548 .69914 L p .707 .577 .707 r
F P
0 g
s
.3357 .70061 m .33643 .71855 L .3639 .72343 L p .707 .577 .707 r
F P
0 g
s
.31044 .67268 m .31019 .6358 L .29759 .62753 L p .707 .577 .707 r
F P
0 g
s
.77954 .57351 m .77393 .63091 L .74282 .62771 L p .707 .577 .707 r
F P
0 g
s
.74282 .62771 m .74843 .5703 L .77954 .57351 L p .707 .577 .707 r
F P
0 g
s
.49477 .54567 m .48916 .60307 L .49583 .60295 L p .707 .577 .707 r
F P
0 g
s
.49583 .60295 m .50145 .54554 L .49477 .54567 L p .707 .577 .707 r
F P
0 g
s
.68546 .66922 m .68521 .63234 L .71459 .62857 L p .707 .577 .707 r
F P
0 g
s
.71117 .6247 m .71678 .56729 L .74843 .5703 L p .707 .577 .707 r
F P
0 g
s
.33643 .71855 m .3357 .70061 L .31462 .69274 L p .707 .577 .707 r
F P
0 g
s
.74843 .5703 m .74282 .62771 L .71117 .6247 L p .707 .577 .707 r
F P
0 g
s
.6661 .70424 m .66537 .6863 L .68937 .67788 L p .707 .577 .707 r
F P
0 g
s
.29602 .58395 m .30163 .52654 L .29837 .52543 L p .707 .577 .707 r
F P
0 g
s
.77759 .62936 m .77785 .66623 L .74668 .66442 L p .707 .577 .707 r
F P
0 g
s
.74668 .66442 m .74642 .62754 L .77759 .62936 L p .707 .577 .707 r
F P
0 g
s
.29759 .62753 m .29785 .6644 L .31044 .67268 L p .707 .577 .707 r
F P
0 g
s
.31462 .69274 m .31535 .71068 L .33643 .71855 L p .707 .577 .707 r
F P
0 g
s
.29837 .52543 m .29275 .58284 L .29602 .58395 L p .707 .577 .707 r
F P
0 g
s
.71459 .62857 m .71484 .66545 L .68546 .66922 L p .707 .577 .707 r
F P
0 g
s
.68937 .67788 m .6901 .69582 L .6661 .70424 L p .707 .577 .707 r
F P
0 g
s
.71484 .66545 m .71459 .62857 L .74642 .62754 L p .707 .577 .707 r
F P
0 g
s
.47947 .69072 m .4802 .70866 L .49651 .69823 L p .707 .577 .707 r
F P
0 g
s
.49651 .69823 m .49578 .68029 L .47947 .69072 L p .707 .577 .707 r
F P
0 g
s
.49151 .62995 m .49177 .66682 L .49885 .65791 L p .707 .577 .707 r
F P
0 g
s
.49885 .65791 m .49859 .62104 L .49151 .62995 L p .707 .577 .707 r
F P
0 g
s
.80914 .67641 m .80987 .69435 L .7824 .68948 L p .707 .577 .707 r
F P
0 g
s
.7824 .68948 m .78167 .67154 L .80914 .67641 L p .707 .577 .707 r
F P
0 g
s
.74642 .62754 m .74668 .66442 L .71484 .66545 L p .707 .577 .707 r
F P
0 g
s
.6901 .69582 m .68937 .67788 L .7187 .67231 L p .707 .577 .707 r
F P
0 g
s
.31535 .71068 m .31462 .69274 L .30198 .68266 L p .707 .577 .707 r
F P
0 g
s
.29785 .6644 m .29759 .62753 L .2947 .61849 L p .707 .577 .707 r
F P
0 g
s
.50145 .54554 m .49583 .60295 L .49257 .60184 L p .707 .577 .707 r
F P
0 g
s
.49257 .60184 m .49818 .54443 L .50145 .54554 L p .707 .577 .707 r
F P
0 g
s
.78167 .67154 m .7824 .68948 L .75124 .68806 L p .707 .577 .707 r
F P
0 g
s
.75124 .68806 m .75051 .67012 L .78167 .67154 L p .707 .577 .707 r
F P
0 g
s
.7187 .67231 m .71943 .69025 L .6901 .69582 L p .707 .577 .707 r
F P
0 g
s
.30198 .68266 m .30271 .7006 L .31535 .71068 L p .707 .577 .707 r
F P
0 g
s
.71943 .69025 m .7187 .67231 L .75051 .67012 L p .707 .577 .707 r
F P
0 g
s
.2947 .61849 m .29495 .65537 L .29785 .6644 L p .707 .577 .707 r
F P
0 g
s
.75051 .67012 m .75124 .68806 L .71943 .69025 L p .707 .577 .707 r
F P
0 g
s
.49578 .68029 m .49651 .69823 L .50353 .68679 L p .707 .577 .707 r
F P
0 g
s
.50353 .68679 m .5028 .66885 L .49578 .68029 L p .707 .577 .707 r
F P
0 g
s
.29275 .58284 m .29837 .52543 L .30504 .5253 L p .707 .577 .707 r
F P
0 g
s
.30504 .5253 m .29943 .58271 L .29275 .58284 L p .707 .577 .707 r
F P
0 g
s
.49859 .62104 m .49885 .65791 L .49595 .64888 L p .707 .577 .707 r
F P
0 g
s
.49595 .64888 m .49569 .612 L .49859 .62104 L p .707 .577 .707 r
F P
0 g
s
.30271 .7006 m .30198 .68266 L .29903 .67135 L p .707 .577 .707 r
F P
0 g
s
.29495 .65537 m .2947 .61849 L .30178 .60958 L p .707 .577 .707 r
F P
0 g
s
.29903 .67135 m .29976 .68929 L .30271 .7006 L p .707 .577 .707 r
F P
0 g
s
.49818 .54443 m .49257 .60184 L .47968 .59985 L p .707 .577 .707 r
F P
0 g
s
.47968 .59985 m .48529 .54244 L .49818 .54443 L p .707 .577 .707 r
F P
0 g
s
.5028 .66885 m .50353 .68679 L .50058 .67548 L p .707 .577 .707 r
F P
0 g
s
.50058 .67548 m .49985 .65754 L .5028 .66885 L p .707 .577 .707 r
F P
0 g
s
.30178 .60958 m .30203 .64646 L .29495 .65537 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29943 .58271 m .30504 .5253 L .321 .52617 L p .707 .577 .707 r
F P
0 g
s
.321 .52617 m .31539 .58358 L .29943 .58271 L p .707 .577 .707 r
F P
0 g
s
.49569 .612 m .49595 .64888 L .48336 .6406 L p .707 .577 .707 r
F P
0 g
s
.48336 .6406 m .4831 .60373 L .49569 .612 L p .707 .577 .707 r
F P
0 g
s
.29976 .68929 m .29903 .67135 L .30605 .65992 L p .707 .577 .707 r
F P
0 g
s
.30203 .64646 m .30178 .60958 L .31814 .60167 L p .707 .577 .707 r
F P
0 g
s
.30605 .65992 m .30678 .67786 L .29976 .68929 L p .707 .577 .707 r
F P
0 g
s
.48529 .54244 m .47968 .59985 L .45844 .59718 L p .707 .577 .707 r
F P
0 g
s
.45844 .59718 m .46405 .53978 L .48529 .54244 L p .707 .577 .707 r
F P
0 g
s
.49985 .65754 m .50058 .67548 L .48795 .6654 L p .707 .577 .707 r
F P
0 g
s
.48795 .6654 m .48722 .64746 L .49985 .65754 L p .707 .577 .707 r
F P
0 g
s
.31814 .60167 m .3184 .63854 L .30203 .64646 L p .707 .577 .707 r
F P
0 g
s
.31539 .58358 m .321 .52617 L .34468 .52796 L p .707 .577 .707 r
F P
0 g
s
.34468 .52796 m .33907 .58536 L .31539 .58358 L p .707 .577 .707 r
F P
0 g
s
.4831 .60373 m .48336 .6406 L .4623 .6339 L p .707 .577 .707 r
F P
0 g
s
.4623 .6339 m .46204 .59702 L .4831 .60373 L p .707 .577 .707 r
F P
0 g
s
.30678 .67786 m .30605 .65992 L .32236 .64949 L p .707 .577 .707 r
F P
0 g
s
.3184 .63854 m .31814 .60167 L .3422 .59553 L p .707 .577 .707 r
F P
0 g
s
.46405 .53978 m .45844 .59718 L .43092 .5941 L p .707 .577 .707 r
F P
0 g
s
.43092 .5941 m .43653 .53669 L .46405 .53978 L p .707 .577 .707 r
F P
0 g
s
.32236 .64949 m .32309 .66743 L .30678 .67786 L p .707 .577 .707 r
F P
0 g
s
.33907 .58536 m .34468 .52796 L .37377 .53047 L p .707 .577 .707 r
F P
0 g
s
.37377 .53047 m .36816 .58788 L .33907 .58536 L p .707 .577 .707 r
F P
0 g
s
.3422 .59553 m .34245 .6324 L .3184 .63854 L p .707 .577 .707 r
F P
0 g
s
.48722 .64746 m .48795 .6654 L .46686 .65754 L p .707 .577 .707 r
F P
0 g
s
.46686 .65754 m .46613 .6396 L .48722 .64746 L p .707 .577 .707 r
F P
0 g
s
.46204 .59702 m .4623 .6339 L .43484 .62942 L p .707 .577 .707 r
F P
0 g
s
.43484 .62942 m .43458 .59254 L .46204 .59702 L p .707 .577 .707 r
F P
0 g
s
.43653 .53669 m .43092 .5941 L .39981 .59089 L p .707 .577 .707 r
F P
0 g
s
.39981 .59089 m .40542 .53348 L .43653 .53669 L p .707 .577 .707 r
F P
0 g
s
.34245 .6324 m .3422 .59553 L .37158 .59176 L p .707 .577 .707 r
F P
0 g
s
.36816 .58788 m .37377 .53047 L .40542 .53348 L p .707 .577 .707 r
F P
0 g
s
.40542 .53348 m .39981 .59089 L .36816 .58788 L p .707 .577 .707 r
F P
0 g
s
.32309 .66743 m .32236 .64949 L .34636 .64107 L p .707 .577 .707 r
F P
0 g
s
.43458 .59254 m .43484 .62942 L .40367 .6276 L p .707 .577 .707 r
F P
0 g
s
.40367 .6276 m .40341 .59073 L .43458 .59254 L p .707 .577 .707 r
F P
0 g
s
.37158 .59176 m .37183 .62863 L .34245 .6324 L p .707 .577 .707 r
F P
0 g
s
.34636 .64107 m .34709 .65901 L .32309 .66743 L p .707 .577 .707 r
F P
0 g
s
.37183 .62863 m .37158 .59176 L .40341 .59073 L p .707 .577 .707 r
F P
0 g
s
.46613 .6396 m .46686 .65754 L .43939 .65266 L p .707 .577 .707 r
F P
0 g
s
.43939 .65266 m .43866 .63472 L .46613 .6396 L p .707 .577 .707 r
F P
0 g
s
.40341 .59073 m .40367 .6276 L .37183 .62863 L p .707 .577 .707 r
F P
0 g
s
.34709 .65901 m .34636 .64107 L .37569 .63549 L p .707 .577 .707 r
F P
0 g
s
.43866 .63472 m .43939 .65266 L .40823 .65125 L p .707 .577 .707 r
F P
0 g
s
.40823 .65125 m .4075 .63331 L .43866 .63472 L p .707 .577 .707 r
F P
0 g
s
.37569 .63549 m .37642 .65343 L .34709 .65901 L p .707 .577 .707 r
F P
0 g
s
.37642 .65343 m .37569 .63549 L .4075 .63331 L p .707 .577 .707 r
F P
0 g
s
.4075 .63331 m .40823 .65125 L .37642 .65343 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00UJEP03001JEUYF00AJEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4
001bOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEP0000<006ioo`00JGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Jgoo001X
Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF008006Moo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Aoo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000I7oo001UOol200000eYF001JEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Eoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Aoo`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Aoo`00IGoo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1TOol0
06Eoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo06Aoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Ao
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001DOol:0006Ool200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool005Aoo`03001JEP0000AJEP03001JEUYF014000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00
E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@002eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IWoo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60009FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00P00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Io
o`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003001SOol005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF001JEP00FUH=001FOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYF
FUH9001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90014Ool005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF3`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01@00<7oo001COol:0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000`00;7oo001DOol60003FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
FWoo1`000eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool0065ooah000=JEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo001POol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYFFUH005YF;Goo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000040002FUH01000FUIJEP0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUIJEP00FUH]Ool005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
05Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ao
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00;Goo2P0077oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF4P0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo
00<005YF000015YF00<005YFFUH03P003Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00
00002P000eYF2@0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002ioo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00002`00
0Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P003Goo700015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=J
EP00FUH00eYF00<005YFFUH00eYF1`001UYF00<005YFFUH01eYF200015YF00<005YFFUH00eYF00<0
05YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
2goo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001EYF00@005YFFUIJEP80
02ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF000015YF00<005YF00000`0017oo00<005YF00000UYF700015YF00<005YF
FUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00@0
05YFFUIJEP8002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000eYF10000UYF2P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YFFUIJEPP00004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00008000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004FUH80005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP06001J
EP00001JEP0015YF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00P0000=JEP0000000P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=oo`0000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH500000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP04001JEP000006
FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH400000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH200000eYF001JEP05FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH50005FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH01@00FUIJ
EUYF00001EYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00@0
05YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUH00003
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF
001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH40003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF0P0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH00UYF2@002Goo20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0P0000EJEP00FUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP000080009JEP8000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEPH000Yoo`l00003Ool00000
00<000AJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00FUH30004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH3000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUH000080002
Ool90004FUH00`00FUIJEP06FUH00`00FUH000030002Ool300000eYF001JEP02FUH2000]Ool002ao
o`X000=JEP03001JEUYF00=JEQ4000=JEP05001JEP00FUH00002FUH300000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030007FUH2000<FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH40004FUH50004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000015YF000000000eYF0P00;Goo000_Ool4
0003FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUH000040004FUH00`00
FUIJEP05FUH40005FUH00`00FUIJEP02FUH70009FUH01000FUH000002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P000eYF1P0025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000AJEP00001JEP8002eoo`00<goo1P0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00000010000eYF6`001UYF00<0
05YFFUH01UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0000AJEP00000000EJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP800004FUH00000000]Ool0039oo`<000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000AJEP03001JEP0000<00005FUH00000FUH00005
FUH00`00FUH000040003FUH00`00FUIJEP09FUH00`00FUIJEP04FUH200001EYF001JEUYF00002eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00@005YFFUIJEP8000EJEP03
001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEPD002eoo`00
<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF
0P000UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YF000010000eYF00<005YFFUH02EYF
00<005YFFUH00UYF0P0015YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0`000UYF00<005YF00000P001UYF00<005YFFUH00UYF200025YF2@0015YF00<005YFFUH00UYF00<0
05YF00000P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH30002FUH40005FUH300000eYF001JEP04FUH00`00FUIJEP030004FUH00`00FUIJ
EP08FUH00`00FUH0000300000eYF001JEP03FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30002FUH20002FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH70004FUH01000FUIJEP00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP020004FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH30005FUH00`00FUIJEP02FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEP04001JEUYFFUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300001EYF
001JEUYF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
0UYF0P00;7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP04001JEUYFFUH:0008FUH70005FUH00`00FUIJ
EP04FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH005YF0P0015YF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH0000002aoo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000UYF
0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF0000009oo`<002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF00H00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000Eo
o`8002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@000eYF0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF000005YF0080009JEP03
001JEP0000@000AJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<000Moo`<0
02aoo`00;7oo00<005YF000015YF00<005YFFUH00eYF1P006Goo2`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF1@000eYF2P0015YF1@0015YF00<005YF
FUH00UYF1@002Goo0`0000=JEP00Ool0:goo000/Ool00`00FUH00004FUH00`00FUH00003000?Ool3
000COol300000eYF000000080004FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00
FUH000030003FUH20004OolB000<Ool20002FUH00`00FUH0000/Ool002aoo`03001JEP0000=JEP@0
015oo`D000moo`@00003FUH0000000800003FUH005YF00EJEPT00003FUH005YF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00800003FUH005YF009JEP03001JEUYF009JEP80009JEP8000Qoo`D001=oo`8000AJEP8002eoo`00
;7oo00@005YF001JEP8000AJEPD000aoo`D000Uoo`H000EJEP06001JEUYF001JEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP0000000UYF0P0000=JEP00FUH015YF0P0000=JEP000000
2Goo0`004Woo0P0000=JEP00FUH00eYF0P00;Goo000/Ool01P00FUH00000FUH000EJEP04001JEUYF
FUH80004Ool>0004FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH00000009JEP03001JEP00008000AJEP03001JEP00008001aoo`8000=JEP03
001JEUYF009JEP03001oogoo02aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<0
05YF00001`0015YF00<005YFFUH00UYF2@001UYF00H005YFFUH005YF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF00000002FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00Oomo
o`0EOol50005FUH01000FUIJEUYF0P00;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0000MJEP00FUIJEP00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YFFUH00UYF00<005YF
00000`0000=JEP00Ool03Goo2@000eYF00<005YFFUH015YF00@005YF0000031oo`00;7oo0P000eYF
00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YF00000P0000AJEP00FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800004FUH0
05YFFUH30004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000bOol0
02eoo`05001JEUYFFUH00004FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=7oo000]Ool01@00FUIJEUYF00000UYF0P001EYF00<0
05YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Ioo`00;Woo0P0000=JEP00FUH00P001UYF
00<005YFFUH015YF1`001eYF2@0015YF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000goo100000AJEP00FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPH003Qoo`00<7oo0`0000=JEP00FUH01EYF00<005YFFUH010001EYF00<005YF
FUH01UYF00<005YFFUH01UYF1P0015YF00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH00eYF
6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001goo0`0015YF100000=J
EP00FUH01eYF00<005YFFUH00UYF2@00?Woo000`Ool01@00FUIJEUYF00001EYF100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000AJEP00FUH000IJEP03001J
EUYF00=JEP/000aJEP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000Yo
o`<00003FUH005YF009JEPl004Moo`00;goo0P000eYF00<005YF00000`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000goo0P0000=JEP00FUH015YF1`002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF0P001goo
100000AJEP00000000=JEP8005Aoo`00;goo0P000eYF0P000goo10000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P0027oo00@005YF001JEP@000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009J
EP80009oo`D000EJEP03001JEUYF00800003FUH0000005Aoo`00;Woo00<005YF00000UYF00<007oo
Ool01goo60003Woo00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF100015YF20001UYF00<005YFFUH00UYF
0`00E7oo000^Ool00`00FUH00002000DOol5000GOol20002FUH00`00FUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH30008FUH01000FUIJEUYF0P000UYF
0P000UYF00@005YFFUIJEP@0009JEP03001JEUYF009JEP<005Aoo`00;Woo00<005YF00005Woo1@00
5goo0P000UYF00<005YF00001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH00eYF10002eYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF100015YF00<005YF0000
E7oo000^Ool2000GOol5000GOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH00`00FUIJEP0<FUH00`00FUIJEP04FUH30002FUH00`00
FUIJEP04FUH00`00FUIJEP020003FUH00`00FUH0001DOol002ioo`8001Qoo`<001Qoo`8000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00=JEP03
001JEUYF00aJEP03001JEUYF00AJEP<0009JEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
000005Eoo`00;Woo00@005YF0000031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00]JEP03001JEUYF00AJEP03001J
EP0000@000IJEP03001JEUYF009JEP<005Ioo`00;Woo0P000UYF0P00;7oo0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF00@005YFFUIJEP<000MJEP03001JEUYF00AJEP03001JEP0000AJEP@0009JEP03001JEUYF009J
EP04001JEP00001EOol002moo`05001JEUYF001JEP03000UOol400000eYF001JEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH6
0009FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP040004FUH01000FUIJEP00E7oo000_Ool01000
FUIJEP0015YF0`007goo0`001EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH015YF0P001UYF00<005YF00000`0000Ioo`00000005YF0002FUH00`00Oomoo`1BOol0
031oo`03001JEP0000EJEP03001JEP0000<001Moo`@00003FUH005YF00EJEP03001JEUYF0080009o
o`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000AJEPD000Qoo`80009JEP8005=oo`00<Goo0P001EYF00<005YF
FUH00eYF5`001EYF00<005YFFUH015YF0`001goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF00002@003goo00@005YF0000
05=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P003Goo20001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF10006Woo0`00Dgoo000dOol300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000GOol<0006FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH@000JOol2001COol003Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<002Mooa/000]oo`D001Uoo`<005=oo`00>Woo10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000=Woo0P0067oo1@005goo0`0000=JEP00Ool0DWoo000nOolG000jOol3
000HOol3000FOol20002FUH00`00FUH0001COol008moo`800003FUH007oo02eoo`8000AJEP8005Ao
o`00Sgoo0P000UYF0P00:7oo100000=JEP00FUH00eYF0P00E7oo002@Ool01@00FUIJEP00FUH00`00
8Woo0`001EYF00<005YFFUH00UYF00<007ooOol0Dgoo002@Ool01000FUIJEP0015YF1@006Goo1000
00=JEP00FUH01EYF00<005YFFUH00P00EWoo002AOol01000FUIJEP0015YF00@005YFFUIJEPT000Uo
o`L000EJEP03001JEUYF00AJEP<005Qoo`00TWoo0`0015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0F7oo002DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Fgoo002F
Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0
0000GGoo002IOol50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6001OOol0
09ioo`P000AJEP03001JEUYF009JEPT006Eoo`00YWoo2@00KWoo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]56\[InvisibleSpace]"     "\
\[InvisibleSpace]13.54821250631116`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 56, "     ", 13.54821250631116, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59026 .73945 m .60152 .68388 L .57109 .67648 L p .707 .577 .707 r
F P
0 g
s
.60152 .68388 m .59026 .73945 L .62154 .74514 L p .707 .577 .707 r
F P
0 g
s
.62154 .74514 m .6328 .68956 L .60152 .68388 L p .707 .577 .707 r
F P
0 g
s
.6328 .68956 m .62154 .74514 L .65059 .74855 L p .707 .577 .707 r
F P
0 g
s
.65059 .74855 m .66185 .69297 L .6328 .68956 L p .707 .577 .707 r
F P
0 g
s
.55983 .73206 m .57109 .67648 L .54448 .6681 L p .707 .577 .707 r
F P
0 g
s
.57109 .67648 m .55983 .73206 L .59026 .73945 L p .707 .577 .707 r
F P
0 g
s
.66185 .69297 m .65059 .74855 L .67458 .74936 L p .707 .577 .707 r
F P
0 g
s
.67458 .74936 m .68584 .69378 L .66185 .69297 L p .707 .577 .707 r
F P
0 g
s
.54448 .6681 m .53322 .72367 L .55983 .73206 L p .707 .577 .707 r
F P
0 g
s
.59252 .80535 m .59625 .76808 L .56525 .76349 L p .707 .577 .707 r
F P
0 g
s
.59625 .76808 m .59252 .80535 L .62421 .80773 L p .707 .577 .707 r
F P
0 g
s
.62421 .80773 m .62795 .77045 L .59625 .76808 L p .707 .577 .707 r
F P
0 g
s
.53322 .72367 m .54448 .6681 L .52429 .65954 L p .707 .577 .707 r
F P
0 g
s
.62795 .77045 m .62421 .80773 L .6535 .80766 L p .707 .577 .707 r
F P
0 g
s
.6535 .80766 m .65723 .77039 L .62795 .77045 L p .707 .577 .707 r
F P
0 g
s
.56152 .80076 m .56525 .76349 L .53798 .75714 L p .707 .577 .707 r
F P
0 g
s
.56525 .76349 m .56152 .80076 L .59252 .80535 L p .707 .577 .707 r
F P
0 g
s
.52429 .65954 m .51303 .71512 L .53322 .72367 L p .707 .577 .707 r
F P
0 g
s
.53798 .75714 m .53424 .79442 L .56152 .80076 L p .707 .577 .707 r
F P
0 g
s
.65723 .77039 m .6535 .80766 L .67751 .80516 L p .707 .577 .707 r
F P
0 g
s
.67751 .80516 m .68125 .76789 L .65723 .77039 L p .707 .577 .707 r
F P
0 g
s
.68584 .69378 m .67458 .74936 L .69115 .74749 L p .707 .577 .707 r
F P
0 g
s
.69115 .74749 m .70241 .69191 L .68584 .69378 L p .707 .577 .707 r
F P
0 g
s
.53424 .79442 m .53798 .75714 L .51711 .74965 L p .707 .577 .707 r
F P
0 g
s
.6089 .85725 m .60614 .83928 L .57512 .84145 L p .707 .577 .707 r
F P
0 g
s
.60614 .83928 m .6089 .85725 L .64033 .85172 L p .707 .577 .707 r
F P
0 g
s
.64033 .85172 m .63756 .83375 L .60614 .83928 L p .707 .577 .707 r
F P
0 g
s
.63756 .83375 m .64033 .85172 L .66908 .84339 L p .707 .577 .707 r
F P
0 g
s
.66908 .84339 m .66632 .82542 L .63756 .83375 L p .707 .577 .707 r
F P
0 g
s
.51303 .71512 m .52429 .65954 L .51251 .65166 L p .707 .577 .707 r
F P
0 g
s
.57512 .84145 m .57789 .85943 L .6089 .85725 L p .707 .577 .707 r
F P
0 g
s
.57789 .85943 m .57512 .84145 L .54755 .84007 L p .707 .577 .707 r
F P
0 g
s
.51711 .74965 m .51337 .78693 L .53424 .79442 L p .707 .577 .707 r
F P
0 g
s
.51251 .65166 m .50125 .70724 L .51303 .71512 L p .707 .577 .707 r
F P
0 g
s
.66632 .82542 m .66908 .84339 L .69235 .83307 L p .707 .577 .707 r
F P
0 g
s
.69235 .83307 m .68959 .8151 L .66632 .82542 L p .707 .577 .707 r
F P
0 g
s
.54755 .84007 m .55031 .85804 L .57789 .85943 L p .707 .577 .707 r
F P
0 g
s
.68125 .76789 m .67751 .80516 L .69389 .80047 L p .707 .577 .707 r
F P
0 g
s
.69389 .80047 m .69763 .76319 L .68125 .76789 L p .707 .577 .707 r
F P
0 g
s
.70241 .69191 m .69115 .74749 L .69869 .74312 L p .707 .577 .707 r
F P
0 g
s
.69869 .74312 m .70995 .68754 L .70241 .69191 L p .707 .577 .707 r
F P
0 g
s
.51337 .78693 m .51711 .74965 L .50467 .74176 L p .707 .577 .707 r
F P
0 g
s
.55031 .85804 m .54755 .84007 L .52612 .83526 L p .707 .577 .707 r
F P
0 g
s
.52612 .83526 m .52888 .85323 L .55031 .85804 L p .707 .577 .707 r
F P
0 g
s
.50467 .74176 m .50094 .77904 L .51337 .78693 L p .707 .577 .707 r
F P
0 g
s
.50125 .70724 m .51251 .65166 L .51027 .64522 L p .707 .577 .707 r
F P
0 g
s
.68959 .8151 m .69235 .83307 L .70786 .82177 L p .707 .577 .707 r
F P
0 g
s
.70786 .82177 m .7051 .80379 L .68959 .8151 L p .707 .577 .707 r
F P
0 g
s
.69763 .76319 m .69389 .80047 L .70105 .79404 L p .707 .577 .707 r
F P
0 g
s
.70105 .79404 m .70479 .75677 L .69763 .76319 L p .707 .577 .707 r
F P
0 g
s
.51027 .64522 m .49901 .70079 L .50125 .70724 L p .707 .577 .707 r
F P
0 g
s
.52888 .85323 m .52612 .83526 L .51293 .8275 L p .707 .577 .707 r
F P
0 g
s
.50094 .77904 m .50467 .74176 L .5019 .73423 L p .707 .577 .707 r
F P
0 g
s
.70995 .68754 m .69869 .74312 L .69646 .73667 L p .707 .577 .707 r
F P
0 g
s
.69646 .73667 m .70772 .6811 L .70995 .68754 L p .707 .577 .707 r
F P
0 g
s
.51293 .8275 m .51569 .84547 L .52888 .85323 L p .707 .577 .707 r
F P
0 g
s
.7051 .80379 m .70786 .82177 L .71409 .81059 L p .707 .577 .707 r
F P
0 g
s
.71409 .81059 m .71132 .79262 L .7051 .80379 L p .707 .577 .707 r
F P
0 g
s
.48073 .82158 m .48073 .31969 L .4375 .31621 L p .707 .577 .707 r
F P
0 g
s
.5019 .73423 m .49816 .77151 L .50094 .77904 L p .707 .577 .707 r
F P
0 g
s
.49901 .70079 m .51027 .64522 L .51781 .64085 L p .707 .577 .707 r
F P
0 g
s
.51781 .64085 m .50655 .69642 L .49901 .70079 L p .707 .577 .707 r
F P
0 g
s
.51569 .84547 m .51293 .8275 L .50927 .81754 L p .707 .577 .707 r
F P
0 g
s
.50927 .81754 m .51203 .83551 L .51569 .84547 L p .707 .577 .707 r
F P
0 g
s
.49816 .77151 m .5019 .73423 L .50906 .72781 L p .707 .577 .707 r
F P
0 g
s
.50906 .72781 m .50532 .76508 L .49816 .77151 L p .707 .577 .707 r
F P
0 g
s
.50655 .69642 m .51781 .64085 L .53439 .63897 L p .707 .577 .707 r
F P
0 g
s
.53439 .63897 m .52313 .69455 L .50655 .69642 L p .707 .577 .707 r
F P
0 g
s
.51203 .83551 m .50927 .81754 L .5155 .80636 L p .707 .577 .707 r
F P
0 g
s
.5155 .80636 m .51826 .82433 L .51203 .83551 L p .707 .577 .707 r
F P
0 g
s
.50532 .76508 m .50906 .72781 L .52544 .72312 L p .707 .577 .707 r
F P
0 g
s
.52544 .72312 m .5217 .76039 L .50532 .76508 L p .707 .577 .707 r
F P
0 g
s
.51826 .82433 m .5155 .80636 L .531 .79506 L p .707 .577 .707 r
F P
0 g
s
.531 .79506 m .53377 .81303 L .51826 .82433 L p .707 .577 .707 r
F P
0 g
s
.48073 .31969 m .48073 .82158 L .52585 .8213 L p .707 .577 .707 r
F P
0 g
s
.52313 .69455 m .53439 .63897 L .55838 .63979 L p .707 .577 .707 r
F P
0 g
s
.55838 .63979 m .54712 .69536 L .52313 .69455 L p .707 .577 .707 r
F P
0 g
s
.5217 .76039 m .52544 .72312 L .54945 .72062 L p .707 .577 .707 r
F P
0 g
s
.54945 .72062 m .54571 .75789 L .5217 .76039 L p .707 .577 .707 r
F P
0 g
s
.52585 .8213 m .52585 .31941 L .48073 .31969 L p .707 .577 .707 r
F P
0 g
s
.54712 .69536 m .55838 .63979 L .58743 .6432 L p .707 .577 .707 r
F P
0 g
s
.58743 .6432 m .57617 .69877 L .54712 .69536 L p .707 .577 .707 r
F P
0 g
s
.54571 .75789 m .54945 .72062 L .57874 .72055 L p .707 .577 .707 r
F P
0 g
s
.53377 .81303 m .531 .79506 L .55427 .78474 L p .707 .577 .707 r
F P
0 g
s
.55427 .78474 m .55704 .80271 L .53377 .81303 L p .707 .577 .707 r
F P
0 g
s
.57874 .72055 m .575 .75783 L .54571 .75789 L p .707 .577 .707 r
F P
0 g
s
.55704 .80271 m .55427 .78474 L .58303 .77641 L p .707 .577 .707 r
F P
0 g
s
.58303 .77641 m .58579 .79438 L .55704 .80271 L p .707 .577 .707 r
F P
0 g
s
.52585 .31941 m .52585 .8213 L .56844 .81729 L p .707 .577 .707 r
F P
0 g
s
.56844 .81729 m .56844 .3154 L .52585 .31941 L p .707 .577 .707 r
F P
0 g
s
.4375 .8181 m .4375 .31621 L .40039 .30932 L p .707 .577 .707 r
F P
0 g
s
.4375 .31621 m .4375 .8181 L .48073 .82158 L p .707 .577 .707 r
F P
0 g
s
.70479 .75677 m .70105 .79404 L .69827 .78652 L p .707 .577 .707 r
F P
0 g
s
.69827 .78652 m .70201 .74924 L .70479 .75677 L p .707 .577 .707 r
F P
0 g
s
.57617 .69877 m .58743 .6432 L .6187 .64888 L p .707 .577 .707 r
F P
0 g
s
.6187 .64888 m .60744 .70446 L .57617 .69877 L p .707 .577 .707 r
F P
0 g
s
.575 .75783 m .57874 .72055 L .61043 .72293 L p .707 .577 .707 r
F P
0 g
s
.61043 .72293 m .60669 .7602 L .575 .75783 L p .707 .577 .707 r
F P
0 g
s
.58579 .79438 m .58303 .77641 L .61445 .77088 L p .707 .577 .707 r
F P
0 g
s
.61445 .77088 m .61721 .78885 L .58579 .79438 L p .707 .577 .707 r
F P
0 g
s
.56844 .3154 m .56844 .81729 L .60432 .80995 L p .707 .577 .707 r
F P
0 g
s
.60432 .80995 m .60432 .30806 L .56844 .3154 L p .707 .577 .707 r
F P
0 g
s
.70772 .6811 m .69646 .73667 L .68467 .72879 L p .707 .577 .707 r
F P
0 g
s
.68467 .72879 m .69593 .67321 L .70772 .6811 L p .707 .577 .707 r
F P
0 g
s
.71132 .79262 m .71409 .81059 L .71043 .80063 L p .707 .577 .707 r
F P
0 g
s
.71043 .80063 m .70766 .78266 L .71132 .79262 L p .707 .577 .707 r
F P
0 g
s
.25009 .72919 m .25494 .67795 L .22397 .67223 L p .707 .577 .707 r
F P
0 g
s
.25494 .67795 m .25009 .72919 L .28185 .73045 L p .707 .577 .707 r
F P
0 g
s
.28185 .73045 m .2867 .67921 L .25494 .67795 L p .707 .577 .707 r
F P
0 g
s
.2867 .67921 m .28185 .73045 L .31129 .72712 L p .707 .577 .707 r
F P
0 g
s
.31129 .72712 m .31614 .67588 L .2867 .67921 L p .707 .577 .707 r
F P
0 g
s
.21913 .72347 m .22397 .67223 L .19683 .6626 L p .707 .577 .707 r
F P
0 g
s
.22397 .67223 m .21913 .72347 L .25009 .72919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.40039 .81121 m .40039 .30932 L .37302 .29969 L p .707 .577 .707 r
F P
0 g
s
.40039 .30932 m .40039 .81121 L .4375 .8181 L p .707 .577 .707 r
F P
0 g
s
.64913 .65628 m .63787 .71185 L .60744 .70446 L p .707 .577 .707 r
F P
0 g
s
.60744 .70446 m .6187 .64888 L .64913 .65628 L p .707 .577 .707 r
F P
0 g
s
.64143 .72752 m .63769 .76479 L .60669 .7602 L p .707 .577 .707 r
F P
0 g
s
.60669 .7602 m .61043 .72293 L .64143 .72752 L p .707 .577 .707 r
F P
0 g
s
.64547 .7687 m .64823 .78667 L .61721 .78885 L p .707 .577 .707 r
F P
0 g
s
.61721 .78885 m .61445 .77088 L .64547 .7687 L p .707 .577 .707 r
F P
0 g
s
.60432 .30806 m .60432 .80995 L .63 .79999 L p .707 .577 .707 r
F P
0 g
s
.63 .79999 m .63 .2981 L .60432 .30806 L p .707 .577 .707 r
F P
0 g
s
.70201 .74924 m .69827 .78652 L .68584 .77862 L p .707 .577 .707 r
F P
0 g
s
.68584 .77862 m .68958 .74135 L .70201 .74924 L p .707 .577 .707 r
F P
0 g
s
.31614 .67588 m .31129 .72712 L .33552 .71952 L p .707 .577 .707 r
F P
0 g
s
.33552 .71952 m .34037 .66829 L .31614 .67588 L p .707 .577 .707 r
F P
0 g
s
.19198 .71384 m .19683 .6626 L .17615 .65001 L p .707 .577 .707 r
F P
0 g
s
.19683 .6626 m .19198 .71384 L .21913 .72347 L p .707 .577 .707 r
F P
0 g
s
.69593 .67321 m .68467 .72879 L .66449 .72024 L p .707 .577 .707 r
F P
0 g
s
.66449 .72024 m .67575 .66466 L .69593 .67321 L p .707 .577 .707 r
F P
0 g
s
.25152 .78121 m .25313 .74537 L .22199 .74158 L p .707 .577 .707 r
F P
0 g
s
.25313 .74537 m .25152 .78121 L .28334 .78143 L p .707 .577 .707 r
F P
0 g
s
.28334 .78143 m .28494 .74559 L .25313 .74537 L p .707 .577 .707 r
F P
0 g
s
.28494 .74559 m .28334 .78143 L .31271 .77805 L p .707 .577 .707 r
F P
0 g
s
.31271 .77805 m .31432 .74221 L .28494 .74559 L p .707 .577 .707 r
F P
0 g
s
.26038 .80375 m .25918 .78472 L .22788 .78585 L p .707 .577 .707 r
F P
0 g
s
.25918 .78472 m .26038 .80375 L .29206 .80128 L p .707 .577 .707 r
F P
0 g
s
.29206 .80128 m .29086 .78225 L .25918 .78472 L p .707 .577 .707 r
F P
0 g
s
.70766 .78266 m .71043 .80063 L .69723 .79287 L p .707 .577 .707 r
F P
0 g
s
.69723 .79287 m .69447 .7749 L .70766 .78266 L p .707 .577 .707 r
F P
0 g
s
.22039 .77742 m .22199 .74158 L .19459 .73459 L p .707 .577 .707 r
F P
0 g
s
.22199 .74158 m .22039 .77742 L .25152 .78121 L p .707 .577 .707 r
F P
0 g
s
.22788 .78585 m .22908 .80488 L .26038 .80375 L p .707 .577 .707 r
F P
0 g
s
.29086 .78225 m .29206 .80128 L .32102 .79773 L p .707 .577 .707 r
F P
0 g
s
.32102 .79773 m .31981 .7787 L .29086 .78225 L p .707 .577 .707 r
F P
0 g
s
.22908 .80488 m .22788 .78585 L .20002 .78554 L p .707 .577 .707 r
F P
0 g
s
.34037 .66829 m .33552 .71952 L .35218 .70841 L p .707 .577 .707 r
F P
0 g
s
.35218 .70841 m .35703 .65718 L .34037 .66829 L p .707 .577 .707 r
F P
0 g
s
.20002 .78554 m .20123 .80457 L .22908 .80488 L p .707 .577 .707 r
F P
0 g
s
.31432 .74221 m .31271 .77805 L .33679 .7714 L p .707 .577 .707 r
F P
0 g
s
.33679 .7714 m .33839 .73556 L .31432 .74221 L p .707 .577 .707 r
F P
0 g
s
.1713 .70125 m .17615 .65001 L .16398 .63569 L p .707 .577 .707 r
F P
0 g
s
.17615 .65001 m .1713 .70125 L .19198 .71384 L p .707 .577 .707 r
F P
0 g
s
.37302 .80158 m .37302 .29969 L .35809 .28827 L p .707 .577 .707 r
F P
0 g
s
.37302 .29969 m .37302 .80158 L .40039 .81121 L p .707 .577 .707 r
F P
0 g
s
.68958 .74135 m .68584 .77862 L .66497 .77114 L p .707 .577 .707 r
F P
0 g
s
.66497 .77114 m .6687 .73386 L .68958 .74135 L p .707 .577 .707 r
F P
0 g
s
.19459 .73459 m .19299 .77043 L .22039 .77742 L p .707 .577 .707 r
F P
0 g
s
.31981 .7787 m .32102 .79773 L .34442 .79343 L p .707 .577 .707 r
F P
0 g
s
.34442 .79343 m .34322 .7744 L .31981 .7787 L p .707 .577 .707 r
F P
0 g
s
.19299 .77043 m .19459 .73459 L .1736 .72508 L p .707 .577 .707 r
F P
0 g
s
.67575 .66466 m .66449 .72024 L .63787 .71185 L p .707 .577 .707 r
F P
0 g
s
.63787 .71185 m .64913 .65628 L .67575 .66466 L p .707 .577 .707 r
F P
0 g
s
.6687 .73386 m .66497 .77114 L .63769 .76479 L p .707 .577 .707 r
F P
0 g
s
.63769 .76479 m .64143 .72752 L .6687 .73386 L p .707 .577 .707 r
F P
0 g
s
.63 .2981 m .63 .79999 L .64295 .78839 L p .707 .577 .707 r
F P
0 g
s
.64295 .78839 m .64295 .2865 L .63 .2981 L p .707 .577 .707 r
F P
0 g
s
.20123 .80457 m .20002 .78554 L .17834 .78381 L p .707 .577 .707 r
F P
0 g
s
.17834 .78381 m .17954 .80284 L .20123 .80457 L p .707 .577 .707 r
F P
0 g
s
.69447 .7749 m .69723 .79287 L .6758 .78806 L p .707 .577 .707 r
F P
0 g
s
.6758 .78806 m .67304 .77009 L .69447 .7749 L p .707 .577 .707 r
F P
0 g
s
.1736 .72508 m .17199 .76092 L .19299 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .73556 m .33679 .7714 L .35319 .76214 L p .707 .577 .707 r
F P
0 g
s
.35319 .76214 m .3548 .7263 L .33839 .73556 L p .707 .577 .707 r
F P
0 g
s
.35703 .65718 m .35218 .70841 L .35964 .69487 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .36449 .64364 L .35703 .65718 L p .707 .577 .707 r
F P
0 g
s
.15913 .68693 m .16398 .63569 L .1615 .62105 L p .707 .577 .707 r
F P
0 g
s
.16398 .63569 m .15913 .68693 L .1713 .70125 L p .707 .577 .707 r
F P
0 g
s
.34322 .7744 m .34442 .79343 L .35997 .7888 L p .707 .577 .707 r
F P
0 g
s
.35997 .7888 m .35877 .76977 L .34322 .7744 L p .707 .577 .707 r
F P
0 g
s
.17199 .76092 m .1736 .72508 L .16107 .71398 L p .707 .577 .707 r
F P
0 g
s
.17954 .80284 m .17834 .78381 L .16494 .78084 L p .707 .577 .707 r
F P
0 g
s
.16494 .78084 m .16614 .79987 L .17954 .80284 L p .707 .577 .707 r
F P
0 g
s
.67304 .77009 m .6758 .78806 L .64823 .78667 L p .707 .577 .707 r
F P
0 g
s
.64823 .78667 m .64547 .7687 L .67304 .77009 L p .707 .577 .707 r
F P
0 g
s
.16107 .71398 m .15947 .74982 L .17199 .76092 L p .707 .577 .707 r
F P
0 g
s
.3548 .7263 m .35319 .76214 L .36033 .75118 L p .707 .577 .707 r
F P
0 g
s
.36033 .75118 m .36193 .71533 L .3548 .7263 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .35716 .68022 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36449 .64364 m .35993 .69175 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35993 .69175 m .35964 .69487 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35705 .27616 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36201 .62899 m .36449 .64364 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35716 .68022 m .35931 .65746 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35931 .65746 m .36201 .62899 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36193 .71533 m .36033 .75118 L .35749 .73958 L p .707 .577 .707 r
F P
0 g
s
.35749 .73958 m .3591 .70373 L .36193 .71533 L p .707 .577 .707 r
F P
0 g
s
.36201 .62899 m .35716 .68022 L .34499 .6659 L p .707 .577 .707 r
F P
0 g
s
.34499 .6659 m .34984 .61467 L .36201 .62899 L p .707 .577 .707 r
F P
0 g
s
.3591 .70373 m .35749 .73958 L .34496 .72848 L p .707 .577 .707 r
F P
0 g
s
.34496 .72848 m .34657 .69263 L .3591 .70373 L p .707 .577 .707 r
F P
0 g
s
.35877 .76977 m .35997 .7888 L .36615 .78431 L p .707 .577 .707 r
F P
0 g
s
.36615 .78431 m .36495 .76528 L .35877 .76977 L p .707 .577 .707 r
F P
0 g
s
.36116 .76136 m .36236 .78039 L .34897 .77741 L p .707 .577 .707 r
F P
0 g
s
.34897 .77741 m .34777 .75839 L .36116 .76136 L p .707 .577 .707 r
F P
0 g
s
.35705 .77805 m .35809 .79015 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .27616 m .35705 .53203 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .53203 m .35705 .77805 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .79015 m .35809 .58969 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .58969 m .35809 .28827 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36495 .76528 m .36615 .78431 L .36236 .78039 L p .707 .577 .707 r
F P
0 g
s
.36236 .78039 m .36116 .76136 L .36495 .76528 L p .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35809 .79015 L .37302 .80158 L p .707 .577 .707 r
F P
0 g
s
.64295 .2865 m .64295 .78839 L .64191 .77628 L p .707 .578 .707 r
F P
0 g
s
.64191 .77628 m .64191 .27439 L .64295 .2865 L p .707 .578 .707 r
F P
0 g
s
.1615 .62105 m .15665 .67228 L .15913 .68693 L p .707 .577 .707 r
F P
0 g
s
.15665 .67228 m .1615 .62105 L .16896 .6075 L p .707 .577 .707 r
F P
0 g
s
.15947 .74982 m .16107 .71398 L .15824 .70238 L p .707 .577 .707 r
F P
0 g
s
.16614 .79987 m .16494 .78084 L .16115 .77692 L p .707 .577 .707 r
F P
0 g
s
.16115 .77692 m .16235 .79595 L .16614 .79987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15824 .70238 m .15663 .73822 L .15947 .74982 L p .707 .577 .707 r
F P
0 g
s
.16896 .6075 m .16411 .65874 L .15665 .67228 L p .707 .577 .707 r
F P
0 g
s
.16411 .65874 m .16896 .6075 L .18562 .59639 L p .707 .577 .707 r
F P
0 g
s
.15663 .73822 m .15824 .70238 L .16537 .69141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35705 .77805 m .35705 .27616 L .37 .26456 L p .707 .577 .707 r
F P
0 g
s
.64191 .27439 m .64191 .77628 L .62698 .76485 L p .707 .577 .707 r
F P
0 g
s
.62698 .76485 m .62698 .26297 L .64191 .27439 L p .707 .577 .707 r
F P
0 g
s
.16235 .79595 m .16115 .77692 L .16734 .77242 L p .707 .577 .707 r
F P
0 g
s
.16734 .77242 m .16854 .79145 L .16235 .79595 L p .707 .577 .707 r
F P
0 g
s
.16537 .69141 m .16376 .72725 L .15663 .73822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34984 .61467 m .34499 .6659 L .32432 .65331 L p .707 .577 .707 r
F P
0 g
s
.32432 .65331 m .32917 .60208 L .34984 .61467 L p .707 .577 .707 r
F P
0 g
s
.18562 .59639 m .18077 .64763 L .16411 .65874 L p .707 .577 .707 r
F P
0 g
s
.18077 .64763 m .18562 .59639 L .20985 .5888 L p .707 .577 .707 r
F P
0 g
s
.16376 .72725 m .16537 .69141 L .18177 .68215 L p .707 .577 .707 r
F P
0 g
s
.32917 .60208 m .32432 .65331 L .29717 .64369 L p .707 .577 .707 r
F P
0 g
s
.29717 .64369 m .30202 .59245 L .32917 .60208 L p .707 .577 .707 r
F P
0 g
s
.16854 .79145 m .16734 .77242 L .18289 .7678 L p .707 .577 .707 r
F P
0 g
s
.205 .64003 m .20985 .5888 L .23929 .58547 L p .707 .577 .707 r
F P
0 g
s
.20985 .5888 m .205 .64003 L .18077 .64763 L p .707 .577 .707 r
F P
0 g
s
.18177 .68215 m .18017 .71799 L .16376 .72725 L p .707 .577 .707 r
F P
0 g
s
.18289 .7678 m .18409 .78683 L .16854 .79145 L p .707 .577 .707 r
F P
0 g
s
.37 .76645 m .37 .26456 L .39567 .2546 L p .707 .577 .707 r
F P
0 g
s
.37 .26456 m .37 .76645 L .35705 .77805 L p .707 .577 .707 r
F P
0 g
s
.34657 .69263 m .34496 .72848 L .32397 .71896 L p .707 .577 .707 r
F P
0 g
s
.32397 .71896 m .32557 .68312 L .34657 .69263 L p .707 .577 .707 r
F P
0 g
s
.62698 .26297 m .62698 .76485 L .59961 .75522 L p .707 .577 .707 r
F P
0 g
s
.59961 .75522 m .59961 .25334 L .62698 .26297 L p .707 .577 .707 r
F P
0 g
s
.30202 .59245 m .29717 .64369 L .2662 .63796 L p .707 .577 .707 r
F P
0 g
s
.2662 .63796 m .27105 .58673 L .30202 .59245 L p .707 .577 .707 r
F P
0 g
s
.23444 .6367 m .23929 .58547 L .27105 .58673 L p .707 .577 .707 r
F P
0 g
s
.23929 .58547 m .23444 .6367 L .205 .64003 L p .707 .577 .707 r
F P
0 g
s
.18017 .71799 m .18177 .68215 L .20585 .67551 L p .707 .577 .707 r
F P
0 g
s
.27105 .58673 m .2662 .63796 L .23444 .6367 L p .707 .577 .707 r
F P
0 g
s
.34777 .75839 m .34897 .77741 L .32728 .77569 L p .707 .577 .707 r
F P
0 g
s
.32728 .77569 m .32608 .75666 L .34777 .75839 L p .707 .577 .707 r
F P
0 g
s
.18409 .78683 m .18289 .7678 L .20629 .7635 L p .707 .577 .707 r
F P
0 g
s
.20585 .67551 m .20424 .71135 L .18017 .71799 L p .707 .577 .707 r
F P
0 g
s
.32557 .68312 m .32397 .71896 L .29657 .71197 L p .707 .577 .707 r
F P
0 g
s
.29657 .71197 m .29817 .67613 L .32557 .68312 L p .707 .577 .707 r
F P
0 g
s
.20629 .7635 m .20749 .78253 L .18409 .78683 L p .707 .577 .707 r
F P
0 g
s
.20424 .71135 m .20585 .67551 L .23523 .67213 L p .707 .577 .707 r
F P
0 g
s
.7338 .6386 m .72895 .58125 L .69798 .58332 L p .707 .577 .707 r
F P
0 g
s
.72895 .58125 m .7338 .6386 L .76556 .63574 L p .707 .577 .707 r
F P
0 g
s
.76556 .63574 m .76071 .5784 L .72895 .58125 L p .707 .577 .707 r
F P
0 g
s
.39567 .2546 m .39567 .75649 L .37 .76645 L p .707 .577 .707 r
F P
0 g
s
.39567 .75649 m .39567 .2546 L .43156 .24726 L p .707 .577 .707 r
F P
0 g
s
.76071 .5784 m .76556 .63574 L .79499 .63238 L p .707 .577 .707 r
F P
0 g
s
.79499 .63238 m .79015 .57504 L .76071 .5784 L p .707 .577 .707 r
F P
0 g
s
.69798 .58332 m .70283 .64066 L .7338 .6386 L p .707 .577 .707 r
F P
0 g
s
.59961 .25334 m .59961 .75522 L .5625 .74834 L p .707 .577 .707 r
F P
0 g
s
.5625 .74834 m .5625 .24645 L .59961 .25334 L p .707 .577 .707 r
F P
0 g
s
.29817 .67613 m .29657 .71197 L .26543 .70818 L p .707 .577 .707 r
F P
0 g
s
.26543 .70818 m .26704 .67234 L .29817 .67613 L p .707 .577 .707 r
F P
0 g
s
.32608 .75666 m .32728 .77569 L .29943 .77538 L p .707 .577 .707 r
F P
0 g
s
.29943 .77538 m .29822 .75635 L .32608 .75666 L p .707 .577 .707 r
F P
0 g
s
.70283 .64066 m .69798 .58332 L .67083 .58439 L p .707 .577 .707 r
F P
0 g
s
.23362 .70797 m .23523 .67213 L .26704 .67234 L p .707 .577 .707 r
F P
0 g
s
.23523 .67213 m .23362 .70797 L .20424 .71135 L p .707 .577 .707 r
F P
0 g
s
.67083 .58439 m .67568 .64174 L .70283 .64066 L p .707 .577 .707 r
F P
0 g
s
.20749 .78253 m .20629 .7635 L .23525 .75994 L p .707 .577 .707 r
F P
0 g
s
.26704 .67234 m .26543 .70818 L .23362 .70797 L p .707 .577 .707 r
F P
0 g
s
.79015 .57504 m .79499 .63238 L .81923 .62885 L p .707 .577 .707 r
F P
0 g
s
.81923 .62885 m .81438 .5715 L .79015 .57504 L p .707 .577 .707 r
F P
0 g
s
.23525 .75994 m .23645 .77897 L .20749 .78253 L p .707 .577 .707 r
F P
0 g
s
.73456 .70919 m .73296 .67134 L .70183 .67138 L p .707 .577 .707 r
F P
0 g
s
.73296 .67134 m .73456 .70919 L .76638 .70739 L p .707 .577 .707 r
F P
0 g
s
.76638 .70739 m .76477 .66954 L .73296 .67134 L p .707 .577 .707 r
F P
0 g
s
.76477 .66954 m .76638 .70739 L .79576 .70401 L p .707 .577 .707 r
F P
0 g
s
.79576 .70401 m .79415 .66616 L .76477 .66954 L p .707 .577 .707 r
F P
0 g
s
.29822 .75635 m .29943 .77538 L .26813 .77651 L p .707 .577 .707 r
F P
0 g
s
.26813 .77651 m .26692 .75748 L .29822 .75635 L p .707 .577 .707 r
F P
0 g
s
.70183 .67138 m .70343 .70923 L .73456 .70919 L p .707 .577 .707 r
F P
0 g
s
.70343 .70923 m .70183 .67138 L .67442 .66966 L p .707 .577 .707 r
F P
0 g
s
.67568 .64174 m .67083 .58439 L .65016 .58437 L p .707 .577 .707 r
F P
0 g
s
.23645 .77897 m .23525 .75994 L .26692 .75748 L p .707 .577 .707 r
F P
0 g
s
.26692 .75748 m .26813 .77651 L .23645 .77897 L p .707 .577 .707 r
F P
0 g
s
.43156 .74915 m .43156 .24726 L .47415 .24325 L p .707 .577 .707 r
F P
0 g
s
.43156 .24726 m .43156 .74915 L .39567 .75649 L p .707 .577 .707 r
F P
0 g
s
.65016 .58437 m .65501 .64172 L .67568 .64174 L p .707 .577 .707 r
F P
0 g
s
.67442 .66966 m .67603 .70752 L .70343 .70923 L p .707 .577 .707 r
F P
0 g
s
.5625 .24645 m .5625 .74834 L .51927 .74486 L p .707 .577 .707 r
F P
0 g
s
.51927 .74486 m .51927 .24297 L .5625 .24645 L p .707 .577 .707 r
F P
0 g
s
.79415 .66616 m .79576 .70401 L .81983 .69938 L p .707 .577 .707 r
F P
0 g
s
.81983 .69938 m .81822 .66153 L .79415 .66616 L p .707 .577 .707 r
F P
0 g
s
.81438 .5715 m .81923 .62885 L .83589 .62548 L p .707 .577 .707 r
F P
0 g
s
.83589 .62548 m .83104 .56813 L .81438 .5715 L p .707 .577 .707 r
F P
0 g
s
.67603 .70752 m .67442 .66966 L .65343 .66635 L p .707 .577 .707 r
F P
0 g
s
.47415 .74514 m .47415 .24325 L .51927 .24297 L p .707 .577 .707 r
F P
0 g
s
.47415 .24325 m .47415 .74514 L .43156 .74915 L p .707 .577 .707 r
F P
0 g
s
.51927 .24297 m .51927 .74486 L .47415 .74514 L p .707 .577 .707 r
F P
0 g
s
.73187 .77013 m .73307 .75254 L .70177 .74826 L p .707 .577 .707 r
F P
0 g
s
.73307 .75254 m .73187 .77013 L .76355 .77043 L p .707 .577 .707 r
F P
0 g
s
.76355 .77043 m .76475 .75284 L .73307 .75254 L p .707 .577 .707 r
F P
0 g
s
.65343 .66635 m .65503 .70421 L .67603 .70752 L p .707 .577 .707 r
F P
0 g
s
.65501 .64172 m .65016 .58437 L .63799 .58326 L p .707 .577 .707 r
F P
0 g
s
.76475 .75284 m .76355 .77043 L .79251 .76672 L p .707 .577 .707 r
F P
0 g
s
.79251 .76672 m .79371 .74913 L .76475 .75284 L p .707 .577 .707 r
F P
0 g
s
.70057 .76585 m .70177 .74826 L .67392 .74042 L p .707 .577 .707 r
F P
0 g
s
.70177 .74826 m .70057 .76585 L .73187 .77013 L p .707 .577 .707 r
F P
0 g
s
.81822 .66153 m .81983 .69938 L .83623 .69395 L p .707 .577 .707 r
F P
0 g
s
.83623 .69395 m .83463 .6561 L .81822 .66153 L p .707 .577 .707 r
F P
0 g
s
.63799 .58326 m .64284 .64061 L .65501 .64172 L p .707 .577 .707 r
F P
0 g
s
.67392 .74042 m .67272 .75801 L .70057 .76585 L p .707 .577 .707 r
F P
0 g
s
.83104 .56813 m .83589 .62548 L .84335 .6226 L p .707 .577 .707 r
F P
0 g
s
.84335 .6226 m .8385 .56526 L .83104 .56813 L p .707 .577 .707 r
F P
0 g
s
.65503 .70421 m .65343 .66635 L .6409 .66178 L p .707 .577 .707 r
F P
0 g
s
.79371 .74913 m .79251 .76672 L .81591 .75936 L p .707 .577 .707 r
F P
0 g
s
.81591 .75936 m .81711 .74177 L .79371 .74913 L p .707 .577 .707 r
F P
0 g
s
.67272 .75801 m .67392 .74042 L .65223 .72979 L p .707 .577 .707 r
F P
0 g
s
.6409 .66178 m .64251 .69963 L .65503 .70421 L p .707 .577 .707 r
F P
0 g
s
.65223 .72979 m .65103 .74738 L .67272 .75801 L p .707 .577 .707 r
F P
0 g
s
.64284 .64061 m .63799 .58326 L .63551 .58117 L p .707 .577 .707 r
F P
0 g
s
.83463 .6561 m .83623 .69395 L .84337 .68826 L p .707 .577 .707 r
F P
0 g
s
.84337 .68826 m .84176 .65041 L .83463 .6561 L p .707 .577 .707 r
F P
0 g
s
.63551 .58117 m .64036 .63851 L .64284 .64061 L p .707 .577 .707 r
F P
0 g
s
.81711 .74177 m .81591 .75936 L .83146 .74908 L p .707 .577 .707 r
F P
0 g
s
.83146 .74908 m .83266 .73149 L .81711 .74177 L p .707 .577 .707 r
F P
0 g
s
.65103 .74738 m .65223 .72979 L .63884 .71741 L p .707 .577 .707 r
F P
0 g
s
.8385 .56526 m .84335 .6226 L .84087 .62051 L p .707 .577 .707 r
F P
0 g
s
.84087 .62051 m .83602 .56317 L .8385 .56526 L p .707 .577 .707 r
F P
0 g
s
.64251 .69963 m .6409 .66178 L .63807 .65638 L p .707 .577 .707 r
F P
0 g
s
.63884 .71741 m .63763 .735 L .65103 .74738 L p .707 .577 .707 r
F P
0 g
s
.63807 .65638 m .63967 .69423 L .64251 .69963 L p .707 .577 .707 r
F P
0 g
s
.84176 .65041 m .84337 .68826 L .84053 .68286 L p .707 .577 .707 r
F P
0 g
s
.84053 .68286 m .83893 .64501 L .84176 .65041 L p .707 .577 .707 r
F P
0 g
s
.64036 .63851 m .63551 .58117 L .64297 .5783 L p .707 .577 .707 r
F P
0 g
s
.83266 .73149 m .83146 .74908 L .83764 .73688 L p .707 .577 .707 r
F P
0 g
s
.83764 .73688 m .83885 .71929 L .83266 .73149 L p .707 .577 .707 r
F P
0 g
s
.63763 .735 m .63884 .71741 L .63505 .70448 L p .707 .577 .707 r
F P
0 g
s
.64297 .5783 m .64781 .63564 L .64036 .63851 L p .707 .577 .707 r
F P
0 g
s
.63505 .70448 m .63384 .72207 L .63763 .735 L p .707 .577 .707 r
F P
0 g
s
.63967 .69423 m .63807 .65638 L .6452 .65069 L p .707 .577 .707 r
F P
0 g
s
.83602 .56317 m .84087 .62051 L .8287 .6194 L p .707 .577 .707 r
F P
0 g
s
.8287 .6194 m .82385 .56205 L .83602 .56317 L p .707 .577 .707 r
F P
0 g
s
.42383 .62247 m .41257 .56938 L .38129 .57601 L p .707 .577 .707 r
F P
0 g
s
.41257 .56938 m .42383 .62247 L .45288 .61288 L p .707 .577 .707 r
F P
0 g
s
.45288 .61288 m .44162 .55979 L .41257 .56938 L p .707 .577 .707 r
F P
0 g
s
.39256 .62909 m .38129 .57601 L .35086 .57903 L p .707 .577 .707 r
F P
0 g
s
.38129 .57601 m .39256 .62909 L .42383 .62247 L p .707 .577 .707 r
F P
0 g
s
.6452 .65069 m .64681 .68854 L .63967 .69423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44162 .55979 m .45288 .61288 L .47687 .60127 L p .707 .577 .707 r
F P
0 g
s
.47687 .60127 m .46561 .54819 L .44162 .55979 L p .707 .577 .707 r
F P
0 g
s
.36212 .63211 m .35086 .57903 L .32425 .57814 L p .707 .577 .707 r
F P
0 g
s
.35086 .57903 m .36212 .63211 L .39256 .62909 L p .707 .577 .707 r
F P
0 g
s
.83885 .71929 m .83764 .73688 L .83385 .72395 L p .707 .577 .707 r
F P
0 g
s
.83385 .72395 m .83506 .70636 L .83885 .71929 L p .707 .577 .707 r
F P
0 g
s
.83893 .64501 m .84053 .68286 L .82801 .67829 L p .707 .577 .707 r
F P
0 g
s
.82801 .67829 m .8264 .64043 L .83893 .64501 L p .707 .577 .707 r
F P
0 g
s
.64781 .63564 m .64297 .5783 L .65963 .57493 L p .707 .577 .707 r
F P
0 g
s
.63384 .72207 m .63505 .70448 L .64123 .69228 L p .707 .577 .707 r
F P
0 g
s
.65963 .57493 m .66448 .63227 L .64781 .63564 L p .707 .577 .707 r
F P
0 g
s
.64123 .69228 m .64003 .70987 L .63384 .72207 L p .707 .577 .707 r
F P
0 g
s
.3933 .68523 m .38957 .64881 L .35857 .64947 L p .707 .577 .707 r
F P
0 g
s
.38957 .64881 m .3933 .68523 L .425 .68143 L p .707 .577 .707 r
F P
0 g
s
.425 .68143 m .42126 .64501 L .38957 .64881 L p .707 .577 .707 r
F P
0 g
s
.42126 .64501 m .425 .68143 L .45429 .67486 L p .707 .577 .707 r
F P
0 g
s
.45429 .67486 m .45055 .63844 L .42126 .64501 L p .707 .577 .707 r
F P
0 g
s
.82385 .56205 m .8287 .6194 L .80802 .61938 L p .707 .577 .707 r
F P
0 g
s
.80802 .61938 m .80317 .56204 L .82385 .56205 L p .707 .577 .707 r
F P
0 g
s
.64681 .68854 m .6452 .65069 L .66161 .64526 L p .707 .577 .707 r
F P
0 g
s
.46561 .54819 m .47687 .60127 L .49344 .58877 L p .707 .577 .707 r
F P
0 g
s
.49344 .58877 m .48218 .53569 L .46561 .54819 L p .707 .577 .707 r
F P
0 g
s
.33551 .63122 m .32425 .57814 L .30406 .57343 L p .707 .577 .707 r
F P
0 g
s
.32425 .57814 m .33551 .63122 L .36212 .63211 L p .707 .577 .707 r
F P
0 g
s
.3623 .68589 m .35857 .64947 L .33129 .64693 L p .707 .577 .707 r
F P
0 g
s
.35857 .64947 m .3623 .68589 L .3933 .68523 L p .707 .577 .707 r
F P
0 g
s
.66161 .64526 m .66321 .68311 L .64681 .68854 L p .707 .577 .707 r
F P
0 g
s
.38278 .717 m .38555 .69837 L .35453 .69267 L p .707 .577 .707 r
F P
0 g
s
.38555 .69837 m .38278 .717 L .41421 .7207 L p .707 .577 .707 r
F P
0 g
s
.41421 .7207 m .41697 .70207 L .38555 .69837 L p .707 .577 .707 r
F P
0 g
s
.45055 .63844 m .45429 .67486 L .4783 .66617 L p .707 .577 .707 r
F P
0 g
s
.4783 .66617 m .47456 .62974 L .45055 .63844 L p .707 .577 .707 r
F P
0 g
s
.35453 .69267 m .35177 .71129 L .38278 .717 L p .707 .577 .707 r
F P
0 g
s
.41697 .70207 m .41421 .7207 L .44296 .72203 L p .707 .577 .707 r
F P
0 g
s
.44296 .72203 m .44572 .70341 L .41697 .70207 L p .707 .577 .707 r
F P
0 g
s
.35177 .71129 m .35453 .69267 L .32696 .68552 L p .707 .577 .707 r
F P
0 g
s
.66448 .63227 m .65963 .57493 L .68386 .57139 L p .707 .577 .707 r
F P
0 g
s
.83506 .70636 m .83385 .72395 L .82046 .71157 L p .707 .577 .707 r
F P
0 g
s
.82046 .71157 m .82166 .69398 L .83506 .70636 L p .707 .577 .707 r
F P
0 g
s
.8264 .64043 m .82801 .67829 L .80701 .67498 L p .707 .577 .707 r
F P
0 g
s
.80701 .67498 m .80541 .63712 L .8264 .64043 L p .707 .577 .707 r
F P
0 g
s
.64003 .70987 m .64123 .69228 L .65678 .682 L p .707 .577 .707 r
F P
0 g
s
.33129 .64693 m .33503 .68336 L .3623 .68589 L p .707 .577 .707 r
F P
0 g
s
.32696 .68552 m .32419 .70415 L .35177 .71129 L p .707 .577 .707 r
F P
0 g
s
.68386 .57139 m .68871 .62873 L .66448 .63227 L p .707 .577 .707 r
F P
0 g
s
.30406 .57343 m .31532 .62652 L .33551 .63122 L p .707 .577 .707 r
F P
0 g
s
.33503 .68336 m .33129 .64693 L .31042 .64144 L p .707 .577 .707 r
F P
0 g
s
.65678 .682 m .65558 .69959 L .64003 .70987 L p .707 .577 .707 r
F P
0 g
s
.80317 .56204 m .80802 .61938 L .78087 .62046 L p .707 .577 .707 r
F P
0 g
s
.78087 .62046 m .77602 .56311 L .80317 .56204 L p .707 .577 .707 r
F P
0 g
s
.48218 .53569 m .49344 .58877 L .50098 .57662 L p .707 .577 .707 r
F P
0 g
s
.50098 .57662 m .48972 .52353 L .48218 .53569 L p .707 .577 .707 r
F P
0 g
s
.31532 .62652 m .30406 .57343 L .29228 .56537 L p .707 .577 .707 r
F P
0 g
s
.44572 .70341 m .44296 .72203 L .46623 .72087 L p .707 .577 .707 r
F P
0 g
s
.46623 .72087 m .46899 .70225 L .44572 .70341 L p .707 .577 .707 r
F P
0 g
s
.66321 .68311 m .66161 .64526 L .68568 .64063 L p .707 .577 .707 r
F P
0 g
s
.32419 .70415 m .32696 .68552 L .30552 .67763 L p .707 .577 .707 r
F P
0 g
s
.47456 .62974 m .4783 .66617 L .49468 .6562 L p .707 .577 .707 r
F P
0 g
s
.49468 .6562 m .49094 .61978 L .47456 .62974 L p .707 .577 .707 r
F P
0 g
s
.30552 .67763 m .30276 .69625 L .32419 .70415 L p .707 .577 .707 r
F P
0 g
s
.31042 .64144 m .31416 .67786 L .33503 .68336 L p .707 .577 .707 r
F P
0 g
s
.68568 .64063 m .68728 .67848 L .66321 .68311 L p .707 .577 .707 r
F P
0 g
s
.68871 .62873 m .68386 .57139 L .7133 .56803 L p .707 .577 .707 r
F P
0 g
s
.7133 .56803 m .71815 .62537 L .68871 .62873 L p .707 .577 .707 r
F P
0 g
s
.80541 .63712 m .80701 .67498 L .77961 .67326 L p .707 .577 .707 r
F P
0 g
s
.77961 .67326 m .778 .63541 L .80541 .63712 L p .707 .577 .707 r
F P
0 g
s
.82166 .69398 m .82046 .71157 L .79877 .70094 L p .707 .577 .707 r
F P
0 g
s
.79877 .70094 m .79997 .68335 L .82166 .69398 L p .707 .577 .707 r
F P
0 g
s
.77602 .56311 m .78087 .62046 L .7499 .62252 L p .707 .577 .707 r
F P
0 g
s
.7499 .62252 m .74506 .56518 L .77602 .56311 L p .707 .577 .707 r
F P
0 g
s
.65558 .69959 m .65678 .682 L .68018 .67465 L p .707 .577 .707 r
F P
0 g
s
.31416 .67786 m .31042 .64144 L .29799 .63353 L p .707 .577 .707 r
F P
0 g
s
.29228 .56537 m .30354 .61845 L .31532 .62652 L p .707 .577 .707 r
F P
0 g
s
.71815 .62537 m .7133 .56803 L .74506 .56518 L p .707 .577 .707 r
F P
0 g
s
.68728 .67848 m .68568 .64063 L .71506 .63725 L p .707 .577 .707 r
F P
0 g
s
.46899 .70225 m .46623 .72087 L .48174 .71733 L p .707 .577 .707 r
F P
0 g
s
.48174 .71733 m .4845 .69871 L .46899 .70225 L p .707 .577 .707 r
F P
0 g
s
.74506 .56518 m .7499 .62252 L .71815 .62537 L p .707 .577 .707 r
F P
0 g
s
.68018 .67465 m .67898 .69224 L .65558 .69959 L p .707 .577 .707 r
F P
0 g
s
.30276 .69625 m .30552 .67763 L .29233 .66977 L p .707 .577 .707 r
F P
0 g
s
.29233 .66977 m .28957 .68839 L .30276 .69625 L p .707 .577 .707 r
F P
0 g
s
.48972 .52353 m .50098 .57662 L .49875 .56599 L p .698 .571 .709 r
F P
0 g
s
.49875 .56599 m .48749 .5129 L .48972 .52353 L p .698 .571 .709 r
F P
0 g
s
.30354 .61845 m .29228 .56537 L .29004 .55474 L p .698 .571 .709 r
F P
0 g
s
.71506 .63725 m .71666 .6751 L .68728 .67848 L p .707 .577 .707 r
F P
0 g
s
.49094 .61978 m .49468 .6562 L .50184 .64594 L p .707 .577 .707 r
F P
0 g
s
.50184 .64594 m .4981 .60952 L .49094 .61978 L p .707 .577 .707 r
F P
0 g
s
.778 .63541 m .77961 .67326 L .74848 .6733 L p .707 .577 .707 r
F P
0 g
s
.74848 .6733 m .74687 .63545 L .778 .63541 L p .707 .577 .707 r
F P
0 g
s
.29799 .63353 m .30172 .66995 L .31416 .67786 L p .707 .577 .707 r
F P
0 g
s
.71666 .6751 m .71506 .63725 L .74687 .63545 L p .707 .577 .707 r
F P
0 g
s
.79997 .68335 m .79877 .70094 L .77092 .6931 L p .707 .577 .707 r
F P
0 g
s
.77092 .6931 m .77212 .67551 L .79997 .68335 L p .707 .577 .707 r
F P
0 g
s
.67898 .69224 m .68018 .67465 L .70914 .67094 L p .707 .577 .707 r
F P
0 g
s
.74687 .63545 m .74848 .6733 L .71666 .6751 L p .707 .577 .707 r
F P
0 g
s
.70914 .67094 m .70794 .68852 L .67898 .69224 L p .707 .577 .707 r
F P
0 g
s
.30172 .66995 m .29799 .63353 L .29521 .62398 L p .707 .577 .707 r
F P
0 g
s
.29004 .55474 m .3013 .60782 L .30354 .61845 L p .698 .571 .709 r
F P
0 g
s
.77212 .67551 m .77092 .6931 L .73962 .68882 L p .707 .577 .707 r
F P
0 g
s
.73962 .68882 m .74082 .67123 L .77212 .67551 L p .707 .577 .707 r
F P
0 g
s
.70794 .68852 m .70914 .67094 L .74082 .67123 L p .707 .577 .707 r
F P
0 g
s
.4845 .69871 m .48174 .71733 L .48797 .71176 L p .707 .577 .707 r
F P
0 g
s
.48797 .71176 m .49073 .69313 L .4845 .69871 L p .707 .577 .707 r
F P
0 g
s
.28957 .68839 m .29233 .66977 L .28867 .6627 L p .707 .577 .707 r
F P
0 g
s
.74082 .67123 m .73962 .68882 L .70794 .68852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28867 .6627 m .28591 .68133 L .28957 .68839 L p .707 .577 .707 r
F P
0 g
s
.4981 .60952 m .50184 .64594 L .49906 .63639 L p .707 .577 .707 r
F P
0 g
s
.49906 .63639 m .49532 .59996 L .4981 .60952 L p .707 .577 .707 r
F P
0 g
s
.48749 .5129 m .49875 .56599 L .48697 .55792 L p .707 .577 .707 r
F P
0 g
s
.48697 .55792 m .4757 .50484 L .48749 .5129 L p .707 .577 .707 r
F P
0 g
s
.3013 .60782 m .29004 .55474 L .29758 .54258 L p .707 .577 .707 r
F P
0 g
s
.29521 .62398 m .29895 .6604 L .30172 .66995 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29895 .6604 m .29521 .62398 L .30237 .61371 L p .707 .577 .707 r
F P
0 g
s
.29758 .54258 m .30884 .59566 L .3013 .60782 L p .707 .577 .707 r
F P
0 g
s
.49073 .69313 m .48797 .71176 L .48431 .70469 L p .707 .577 .707 r
F P
0 g
s
.48431 .70469 m .48707 .68607 L .49073 .69313 L p .707 .577 .707 r
F P
0 g
s
.28591 .68133 m .28867 .6627 L .2949 .65713 L p .707 .577 .707 r
F P
0 g
s
.2949 .65713 m .29214 .67575 L .28591 .68133 L p .707 .577 .707 r
F P
0 g
s
.4757 .50484 m .48697 .55792 L .46678 .55322 L p .707 .577 .707 r
F P
0 g
s
.46678 .55322 m .45552 .50013 L .4757 .50484 L p .707 .577 .707 r
F P
0 g
s
.30884 .59566 m .29758 .54258 L .31416 .53008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49532 .59996 m .49906 .63639 L .48663 .62847 L p .707 .577 .707 r
F P
0 g
s
.48663 .62847 m .48289 .59205 L .49532 .59996 L p .707 .577 .707 r
F P
0 g
s
.30237 .61371 m .3061 .65013 L .29895 .6604 L p .707 .577 .707 r
F P
0 g
s
.31416 .53008 m .32542 .58317 L .30884 .59566 L p .707 .577 .707 r
F P
0 g
s
.3061 .65013 m .30237 .61371 L .31875 .60375 L p .707 .577 .707 r
F P
0 g
s
.45552 .50013 m .46678 .55322 L .44016 .55233 L p .707 .577 .707 r
F P
0 g
s
.44016 .55233 m .4289 .49925 L .45552 .50013 L p .707 .577 .707 r
F P
0 g
s
.32542 .58317 m .31416 .53008 L .33815 .51848 L p .707 .577 .707 r
F P
0 g
s
.48707 .68607 m .48431 .70469 L .47112 .69683 L p .707 .577 .707 r
F P
0 g
s
.47112 .69683 m .47388 .6782 L .48707 .68607 L p .707 .577 .707 r
F P
0 g
s
.29214 .67575 m .2949 .65713 L .31041 .65359 L p .707 .577 .707 r
F P
0 g
s
.48289 .59205 m .48663 .62847 L .46575 .62298 L p .707 .577 .707 r
F P
0 g
s
.46575 .62298 m .46202 .58656 L .48289 .59205 L p .707 .577 .707 r
F P
0 g
s
.31041 .65359 m .30765 .67221 L .29214 .67575 L p .707 .577 .707 r
F P
0 g
s
.31875 .60375 m .32249 .64017 L .3061 .65013 L p .707 .577 .707 r
F P
0 g
s
.4289 .49925 m .44016 .55233 L .40973 .55535 L p .707 .577 .707 r
F P
0 g
s
.40973 .55535 m .39847 .50226 L .4289 .49925 L p .707 .577 .707 r
F P
0 g
s
.34941 .57156 m .33815 .51848 L .3672 .50889 L p .707 .577 .707 r
F P
0 g
s
.33815 .51848 m .34941 .57156 L .32542 .58317 L p .707 .577 .707 r
F P
0 g
s
.32249 .64017 m .31875 .60375 L .34276 .59506 L p .707 .577 .707 r
F P
0 g
s
.39847 .50226 m .40973 .55535 L .37846 .56197 L p .707 .577 .707 r
F P
0 g
s
.37846 .56197 m .3672 .50889 L .39847 .50226 L p .707 .577 .707 r
F P
0 g
s
.3672 .50889 m .37846 .56197 L .34941 .57156 L p .707 .577 .707 r
F P
0 g
s
.47388 .6782 m .47112 .69683 L .44968 .68894 L p .707 .577 .707 r
F P
0 g
s
.44968 .68894 m .45245 .67031 L .47388 .6782 L p .707 .577 .707 r
F P
0 g
s
.46202 .58656 m .46575 .62298 L .43848 .62044 L p .707 .577 .707 r
F P
0 g
s
.43848 .62044 m .43474 .58402 L .46202 .58656 L p .707 .577 .707 r
F P
0 g
s
.30765 .67221 m .31041 .65359 L .33368 .65243 L p .707 .577 .707 r
F P
0 g
s
.34276 .59506 m .3465 .63148 L .32249 .64017 L p .707 .577 .707 r
F P
0 g
s
.33368 .65243 m .33092 .67105 L .30765 .67221 L p .707 .577 .707 r
F P
0 g
s
.3465 .63148 m .34276 .59506 L .37205 .58849 L p .707 .577 .707 r
F P
0 g
s
.43474 .58402 m .43848 .62044 L .40748 .62111 L p .707 .577 .707 r
F P
0 g
s
.40748 .62111 m .40374 .58468 L .43474 .58402 L p .707 .577 .707 r
F P
0 g
s
.45245 .67031 m .44968 .68894 L .42211 .68179 L p .707 .577 .707 r
F P
0 g
s
.42211 .68179 m .42487 .66317 L .45245 .67031 L p .707 .577 .707 r
F P
0 g
s
.37579 .62491 m .37205 .58849 L .40374 .58468 L p .707 .577 .707 r
F P
0 g
s
.37205 .58849 m .37579 .62491 L .3465 .63148 L p .707 .577 .707 r
F P
0 g
s
.33092 .67105 m .33368 .65243 L .36243 .65376 L p .707 .577 .707 r
F P
0 g
s
.40374 .58468 m .40748 .62111 L .37579 .62491 L p .707 .577 .707 r
F P
0 g
s
.36243 .65376 m .35967 .67239 L .33092 .67105 L p .707 .577 .707 r
F P
0 g
s
.42487 .66317 m .42211 .68179 L .39109 .67609 L p .707 .577 .707 r
F P
0 g
s
.39109 .67609 m .39386 .65746 L .42487 .66317 L p .707 .577 .707 r
F P
0 g
s
.35967 .67239 m .36243 .65376 L .39386 .65746 L p .707 .577 .707 r
F P
0 g
s
.39386 .65746 m .39109 .67609 L .35967 .67239 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001EYF5@000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00H005YFFUIJEP00FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP04000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00HWoo0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00Ggoo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001KOol20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00FGoo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol005Qoo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001FOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005Aoo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001C
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0059oo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUH0
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
DWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP04001J
EUYFFUH20005FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01EYF100000AJEP00000000QJEP04001JEP000007FUH00`00FUIJEP02FUH40005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000:Woo2`00<Goo001C
Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH50005FUH400000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF000067oo4P000eYF00<005YFFUH00eYF00<005YF00000P00;Woo001COol0
0`00FUH00005FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH:0005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00011oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP02FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000Qoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001J
EP0^Ool005=oo`04001JEUYF0005FUH01000FUIJEUYF0P000goo00<005YFFUH02P000eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001C
Ool01000FUIJEP001EYF00<005YF00002@0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001JEP0^Ool005Aoo`03001J
EP0000EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0041oo`l000Eoo`03001JEP0000AJ
EP8000IJEP03001JEUYF00MJEQP00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo000jOol60004FUH00`00FUIJEP06FUH00`00FUH0000300001Woo001JEUYF001JEP80009J
EP03001JEUYF00AJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
00020004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH015YF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF000^Ool003Aoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000cOol20006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0031oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF000]Ool002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH70004FUH70005FUH70003FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUHB0007FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP040002FUH90006FUH00`00FUIJEP09FUH50002FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000eYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0039oo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00=JEPX000=JEPD000MJEP03001JEUYF00QJEP8000AJEP@000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00H000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJ
EP04001JEUYFFUH20002FUH00`00FUH00003FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP05FUH3
00000eYF001JEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF4@00?7oo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0005FUH01000FUIJEP0015YF00@005YF0000
00AJEP03001JEP0000=JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH40004FUH00`00FUIJEP02
FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH6
000fOol002eoo`03001JEP0000=JEP03001JEUYF00=JEPH000moo`@00003FUH005YF009JEP04001J
EUYFFUH20005FUH01000FUIJEP000eYF00<005YFFUH00eYF0`0025YF10000UYF00<005YFFUH00eYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEQ4000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00D0035oo`00;Goo00<005YF00000eYF00<005YF00000`006Goo0`000UYF00<005YF00002@000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00L000IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00004Ool5
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool002aoo`03001JEP0000AJEP8001moo`03001JEUYF008000EJEP04
001JEUYFFUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF0`0057oo0`002Goo00<005YF00005000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool002aoo`03001JEP0000800003FUH005YF0080015oo`D000Moo`<0009J
EP03001JEUYF00=JEP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH0
0003FUH01@00FUIJEUYF000047oo1@001Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH0100000=JEP00FUH025YF00<005YFFUH00eYF00<005YFFUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH2000>Ool50006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH00`00
FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0P000eYF00<005YFFUH00eYF00@0
05YF000000eoo`<000Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF0`0057oo00=JEP00FUH00UYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH000000080
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH03`0025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUHB000017oo001JEP000UYF1@0015YF
00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH01000
FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH04`000eYF00<005YFFUH00P00;Goo000/Ool2
0003FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000006
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009J
EP8002eoo`00;7oo0P000eYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YF00001@0000=JEP00FUH01EYF00<005YFFUH01UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00H005YFFUH005YF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000040006FUH01000FUIJEUYF1000;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF00<005YF
FUH00UYF2@001EYF10000UYF00<005YFFUH015YF00@005YF000000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001EYF00@005YFFUIJEP<002eoo`00;Goo00<0
05YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH0000000H000=JEPD000MJEP03001JEUYF00<000EJ
EP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP02FUH@0006FUH00`00FUIJEP05FUH3
0003FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH00eYF1@000UYF00<0
05YFFUH00UYF1@001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH30008FUH00`00
FUIJEP05FUH200000eYF001JEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH40006FUH00`00FUIJEP02FUH20002FUH2000_Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00MJEP8000=JEP03001JEP0000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH3000aOol0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJ
EPH00004FUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0
00000UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00@005YF0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPP000=JEP03001JEUYF00<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP05001JEUYFFUH0000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000IJER4000Qoo`80
0003FUH005YF009JEP03001oogoo02eoo`00;Goo0P0015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01UYF1P001UYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH000020006FUH00`00FUIJEP03FUH01000FUIJEUYF0P007goo0P000eYF00<007ooOol0
;Goo000]Ool20004FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01000FUIJEP000UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00001P0000=JEP00FUH01EYF00<005YFFUH00P002Goo0`005Woo00<005YFFUH00P00;Woo000/
Ool00`00FUH00003FUH30005Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH01000FUIJEP000eYF00<005YFFUH015YF2@0015YF00@005YFFUIJEPH000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP<000IJEP03
001JEUYF008000Qoo`D001Ioo`@002ioo`00;7oo00@005YF001JEP8000]oo`@000IJEP@000EJEP03
001JEUYF00EJEP03001JEP0000@000=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH000020003FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0027oo1@0067oo0P00;Woo000/Ool0
1@00FUH00000FUH00P003Woo10000UYF1@0015YF00<005YFFUH00UYF1@001Goo0P0000EJEP00FUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001JEP0200000eYF001JEP03FUH2
00000eYF001JEP02FUH20008Ool5000HOol2000^Ool002aoo`8000=JEP03001JEP00008000mooa00
00aoo`80009JEP05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF0`0015YF0`00
0UYF00<005YF00002Goo0`0067oo0`00;Woo000/Ool20003FUH00`00FUIJEP02FUH3000>Ool5000E
Ool300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF20000UYF
0`0000=JEP00Ool08goo00<005YF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003
000;Ool3000DOol20003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF
00<005YFFUH00`0000AJEP000000009JEP8002=oo`<00003FUH007oo02eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF1P0067oo100000=JEP00FUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP<0009JEP@0021oo`<0009JEP80
02moo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000Yoo`D000EJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10001EYF00<005YF00001@007Woo0P0000=J
EP00FUH00UYF0P00;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2P000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF00MJEP04001JEUYFFUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEPL001Moo`8000=JEP05001J
EUYFFUH0000`Ool002eoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF1P002UYF00<005YFFUH02UYF00<005YFFUH02EYF1`000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000Uoo`D000AJEP04001J
EUYFFUH2000`Ool002ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@000IJEP05001JEUYFFUH00005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90003FUH00`00FUIJEP03FUH01000FUH00000<Woo000_Ool20005FUH00`00FUIJEP06FUH00`00
FUIJEP05FUHO0003FUH00`00FUIJEP03FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH30004FUH01@00FUIJEUYF00001UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00=7oo000`Ool00`00FUIJEP03FUH0
0`00FUIJEP05FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000eYF00<005YF00000`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH015YF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH2
000fOol0035oo`8000=JEP03001JEP0000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH00000>7oo000bOol60002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH02`000UYF00H005YFFUH005YF0003Ool90004FUH00`00FUIJEP02FUH5000jOol002mo
o`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5
0007FUH00`00FUH000020002FUH00`00FUH0000<Ool9000oOol002eoo`<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF009JEQP000=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH4001EOol002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF009JEPd000AJEP03001JEUYF009JEPT0009JEPH000AJEP03001JEUYF
00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP06001JEUYF001JEP001UYF00<005YFFUH00eYF0`00EGoo000]Ool00`00
FUH00004FUH01000FUIJEUYF1`0017oo50000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP001eYF00<005YFFUH00UYF00<005YFFUH0
0P00Dgoo000]Ool00`00FUH00003FUHK0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF000015YF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH00eYF
00@005YFFUH005=oo`00;Woo0P0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF00L000=JEP03001JEUYF0080059oo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEPD0009oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00@0009JEP80059oo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Goo0`001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1P00DWoo000_Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000BOol20005FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP030003Ool2001BOol0035ooah001eoo`80
00=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000MJEP04001JEUYFFUH60005Ool3001BOol006ioo`800003FUH005YF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00
00l000Yoo`800003FUH007oo055oo`00L7oo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF100067oo0P0000AJEP00FUH0059oo`00M7oo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02P005Goo0P0015YF0P00DWoo001j
Ool80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH80005Ool5000COol200000eYF001JEP03FUH0
0`00Oomoo`1AOol0089ooaX000eoo`D0015oo`8000=JEP03001JEUYF009JEP03001oogoo055oo`00
T7oo00@005YFFUH001Ioo`<000moo`<000EJEP03001JEUYF008005Aoo`00TGoo0P009goo0P0000=J
EP00FUH01EYF0`00EWoo002AOol3000SOol30003FUH00`00FUIJEP04FUH00`00Oomoo`1FOol0095o
o`03001JEUYF00@001Uoo`H000MJEP04001JEUYFFUH2001IOol0095oo`80009JEP03001JEUYF00L0
00Uoo`T000AJEP03001JEUYF00IJEP04001JEP00001KOol0099oo`04001JEUYF0005FUH01000FUIJ
EUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF0`00GGoo002BOol01@00FUIJEUYF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00H7oo002COol2
00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002
001ROol009Eoo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH006Eoo`00
VGoo1`0015YF00<005YFFUH00UYF2@00Jgoo002POol9001dOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5866 .73235 m .60456 .67807 L .57519 .66739 L p .707 .577 .707 r
F P
0 g
s
.60456 .67807 m .5866 .73235 L .61693 .74193 L p .707 .577 .707 r
F P
0 g
s
.61693 .74193 m .63489 .68765 L .60456 .67807 L p .707 .577 .707 r
F P
0 g
s
.63489 .68765 m .61693 .74193 L .64526 .74949 L p .707 .577 .707 r
F P
0 g
s
.64526 .74949 m .66322 .69521 L .63489 .68765 L p .707 .577 .707 r
F P
0 g
s
.55724 .72167 m .57519 .66739 L .54967 .65666 L p .707 .577 .707 r
F P
0 g
s
.57519 .66739 m .55724 .72167 L .5866 .73235 L p .707 .577 .707 r
F P
0 g
s
.54967 .65666 m .53171 .71095 L .55724 .72167 L p .707 .577 .707 r
F P
0 g
s
.66322 .69521 m .64526 .74949 L .66882 .75428 L p .707 .577 .707 r
F P
0 g
s
.66882 .75428 m .68678 .7 L .66322 .69521 L p .707 .577 .707 r
F P
0 g
s
.59025 .80241 m .59628 .76522 L .56554 .75896 L p .707 .577 .707 r
F P
0 g
s
.59628 .76522 m .59025 .80241 L .62171 .80675 L p .707 .577 .707 r
F P
0 g
s
.62171 .80675 m .62774 .76956 L .59628 .76522 L p .707 .577 .707 r
F P
0 g
s
.62774 .76956 m .62171 .80675 L .65081 .80875 L p .707 .577 .707 r
F P
0 g
s
.65081 .80875 m .65683 .77156 L .62774 .76956 L p .707 .577 .707 r
F P
0 g
s
.53171 .71095 m .54967 .65666 L .53049 .64694 L p .707 .577 .707 r
F P
0 g
s
.55951 .79616 m .56554 .75896 L .53852 .7514 L p .707 .577 .707 r
F P
0 g
s
.56554 .75896 m .55951 .79616 L .59025 .80241 L p .707 .577 .707 r
F P
0 g
s
.53049 .64694 m .51253 .70122 L .53171 .71095 L p .707 .577 .707 r
F P
0 g
s
.53852 .7514 m .53249 .7886 L .55951 .79616 L p .707 .577 .707 r
F P
0 g
s
.65683 .77156 m .65081 .80875 L .67469 .80822 L p .707 .577 .707 r
F P
0 g
s
.67469 .80822 m .68072 .77102 L .65683 .77156 L p .707 .577 .707 r
F P
0 g
s
.68678 .7 m .66882 .75428 L .68529 .75583 L p .707 .577 .707 r
F P
0 g
s
.68529 .75583 m .70325 .70154 L .68678 .7 L p .707 .577 .707 r
F P
0 g
s
.53249 .7886 m .53852 .7514 L .51788 .74328 L p .707 .577 .707 r
F P
0 g
s
.61669 .86041 m .61223 .84302 L .58165 .84764 L p .707 .577 .707 r
F P
0 g
s
.61223 .84302 m .61669 .86041 L .64752 .85204 L p .707 .577 .707 r
F P
0 g
s
.64752 .85204 m .64306 .83465 L .61223 .84302 L p .707 .577 .707 r
F P
0 g
s
.51253 .70122 m .53049 .64694 L .51952 .63918 L p .707 .577 .707 r
F P
0 g
s
.64306 .83465 m .64752 .85204 L .67559 .84074 L p .707 .577 .707 r
F P
0 g
s
.67559 .84074 m .67113 .82336 L .64306 .83465 L p .707 .577 .707 r
F P
0 g
s
.51788 .74328 m .51185 .78047 L .53249 .7886 L p .707 .577 .707 r
F P
0 g
s
.58165 .84764 m .58612 .86503 L .61669 .86041 L p .707 .577 .707 r
F P
0 g
s
.58612 .86503 m .58165 .84764 L .55433 .84807 L p .707 .577 .707 r
F P
0 g
s
.51952 .63918 m .50156 .69346 L .51253 .70122 L p .707 .577 .707 r
F P
0 g
s
.68072 .77102 m .67469 .80822 L .69103 .80519 L p .707 .577 .707 r
F P
0 g
s
.69103 .80519 m .69706 .768 L .68072 .77102 L p .707 .577 .707 r
F P
0 g
s
.67113 .82336 m .67559 .84074 L .69815 .82763 L p .707 .577 .707 r
F P
0 g
s
.69815 .82763 m .69369 .81024 L .67113 .82336 L p .707 .577 .707 r
F P
0 g
s
.55433 .84807 m .55879 .86545 L .58612 .86503 L p .707 .577 .707 r
F P
0 g
s
.51185 .78047 m .51788 .74328 L .50562 .73539 L p .707 .577 .707 r
F P
0 g
s
.70325 .70154 m .68529 .75583 L .69308 .75398 L p .707 .577 .707 r
F P
0 g
s
.69308 .75398 m .71103 .6997 L .70325 .70154 L p .707 .577 .707 r
F P
0 g
s
.55879 .86545 m .55433 .84807 L .53294 .84425 L p .707 .577 .707 r
F P
0 g
s
.50562 .73539 m .49959 .77258 L .51185 .78047 L p .707 .577 .707 r
F P
0 g
s
.69369 .81024 m .69815 .82763 L .713 .81397 L p .707 .577 .707 r
F P
0 g
s
.713 .81397 m .70854 .79658 L .69369 .81024 L p .707 .577 .707 r
F P
0 g
s
.50156 .69346 m .51952 .63918 L .51785 .63412 L p .707 .577 .707 r
F P
0 g
s
.53294 .84425 m .5374 .86164 L .55879 .86545 L p .707 .577 .707 r
F P
0 g
s
.51785 .63412 m .49989 .68841 L .50156 .69346 L p .707 .577 .707 r
F P
0 g
s
.69706 .768 m .69103 .80519 L .69822 .79998 L p .707 .577 .707 r
F P
0 g
s
.69822 .79998 m .70425 .76279 L .69706 .768 L p .707 .577 .707 r
F P
0 g
s
.49959 .77258 m .50562 .73539 L .50296 .7285 L p .707 .577 .707 r
F P
0 g
s
.5374 .86164 m .53294 .84425 L .51956 .83656 L p .707 .577 .707 r
F P
0 g
s
.71103 .6997 m .69308 .75398 L .6914 .74893 L p .707 .577 .707 r
F P
0 g
s
.6914 .74893 m .70936 .69465 L .71103 .6997 L p .707 .577 .707 r
F P
0 g
s
.50296 .7285 m .49693 .76569 L .49959 .77258 L p .707 .577 .707 r
F P
0 g
s
.70854 .79658 m .713 .81397 L .71868 .80112 L p .707 .577 .707 r
F P
0 g
s
.71868 .80112 m .71422 .78373 L .70854 .79658 L p .707 .577 .707 r
F P
0 g
s
.51956 .83656 m .52403 .85395 L .5374 .86164 L p .707 .577 .707 r
F P
0 g
s
.49989 .68841 m .51785 .63412 L .52563 .63228 L p .707 .577 .707 r
F P
0 g
s
.52563 .63228 m .50767 .68657 L .49989 .68841 L p .707 .577 .707 r
F P
0 g
s
.50767 .68657 m .52563 .63228 L .5421 .63383 L p .707 .577 .707 r
F P
0 g
s
.5421 .63383 m .52414 .68811 L .50767 .68657 L p .707 .577 .707 r
F P
0 g
s
.52403 .85395 m .51956 .83656 L .51552 .82576 L p .707 .577 .707 r
F P
0 g
s
.51552 .82576 m .51998 .84315 L .52403 .85395 L p .707 .577 .707 r
F P
0 g
s
.51998 .84315 m .51552 .82576 L .5212 .81291 L p .707 .577 .707 r
F P
0 g
s
.50412 .76048 m .51015 .72329 L .52649 .72027 L p .707 .577 .707 r
F P
0 g
s
.52649 .72027 m .52046 .75746 L .50412 .76048 L p .707 .577 .707 r
F P
0 g
s
.5199 .82155 m .5199 .31966 L .47477 .31944 L p .707 .577 .707 r
F P
0 g
s
.5212 .81291 m .52566 .8303 L .51998 .84315 L p .707 .577 .707 r
F P
0 g
s
.52414 .68811 m .5421 .63383 L .56566 .63862 L p .707 .577 .707 r
F P
0 g
s
.56566 .63862 m .5477 .6929 L .52414 .68811 L p .707 .577 .707 r
F P
0 g
s
.52566 .8303 m .5212 .81291 L .53605 .79925 L p .707 .577 .707 r
F P
0 g
s
.52046 .75746 m .52649 .72027 L .55038 .71973 L p .707 .577 .707 r
F P
0 g
s
.5477 .6929 m .56566 .63862 L .59399 .64617 L p .707 .577 .707 r
F P
0 g
s
.53605 .79925 m .54051 .81664 L .52566 .8303 L p .707 .577 .707 r
F P
0 g
s
.55038 .71973 m .54435 .75693 L .52046 .75746 L p .707 .577 .707 r
F P
0 g
s
.59399 .64617 m .57603 .70046 L .5477 .6929 L p .707 .577 .707 r
F P
0 g
s
.54435 .75693 m .55038 .71973 L .57947 .72173 L p .707 .577 .707 r
F P
0 g
s
.54051 .81664 m .53605 .79925 L .55861 .78614 L p .707 .577 .707 r
F P
0 g
s
.57947 .72173 m .57345 .75892 L .54435 .75693 L p .707 .577 .707 r
F P
0 g
s
.55861 .78614 m .56307 .80352 L .54051 .81664 L p .707 .577 .707 r
F P
0 g
s
.56307 .80352 m .55861 .78614 L .58668 .77484 L p .707 .577 .707 r
F P
0 g
s
.5199 .31966 m .5199 .82155 L .56307 .81803 L p .707 .577 .707 r
F P
0 g
s
.56307 .81803 m .56307 .31614 L .5199 .31966 L p .707 .577 .707 r
F P
0 g
s
.47477 .82133 m .47477 .31944 L .43212 .31548 L p .707 .577 .707 r
F P
0 g
s
.49693 .76569 m .50296 .7285 L .51015 .72329 L p .707 .577 .707 r
F P
0 g
s
.51015 .72329 m .50412 .76048 L .49693 .76569 L p .707 .577 .707 r
F P
0 g
s
.47477 .31944 m .47477 .82133 L .5199 .82155 L p .707 .577 .707 r
F P
0 g
s
.57603 .70046 m .59399 .64617 L .62432 .65576 L p .707 .577 .707 r
F P
0 g
s
.62432 .65576 m .60636 .71004 L .57603 .70046 L p .707 .577 .707 r
F P
0 g
s
.57345 .75892 m .57947 .72173 L .61093 .72607 L p .707 .577 .707 r
F P
0 g
s
.61093 .72607 m .6049 .76326 L .57345 .75892 L p .707 .577 .707 r
F P
0 g
s
.58668 .77484 m .59114 .79223 L .56307 .80352 L p .707 .577 .707 r
F P
0 g
s
.59114 .79223 m .58668 .77484 L .61751 .76647 L p .707 .577 .707 r
F P
0 g
s
.61751 .76647 m .62198 .78386 L .59114 .79223 L p .707 .577 .707 r
F P
0 g
s
.56307 .31614 m .56307 .81803 L .60007 .81109 L p .707 .577 .707 r
F P
0 g
s
.60007 .81109 m .60007 .30921 L .56307 .31614 L p .707 .577 .707 r
F P
0 g
s
.70425 .76279 m .69822 .79998 L .69556 .7931 L p .707 .577 .707 r
F P
0 g
s
.69556 .7931 m .70159 .7559 L .70425 .76279 L p .707 .577 .707 r
F P
0 g
s
.43212 .81737 m .43212 .31548 L .39611 .30818 L p .707 .577 .707 r
F P
0 g
s
.43212 .31548 m .43212 .81737 L .47477 .82133 L p .707 .577 .707 r
F P
0 g
s
.70936 .69465 m .6914 .74893 L .68044 .74117 L p .707 .577 .707 r
F P
0 g
s
.68044 .74117 m .69839 .68689 L .70936 .69465 L p .707 .577 .707 r
F P
0 g
s
.71422 .78373 m .71868 .80112 L .71464 .79032 L p .707 .577 .707 r
F P
0 g
s
.71464 .79032 m .71018 .77293 L .71422 .78373 L p .707 .577 .707 r
F P
0 g
s
.24858 .73802 m .25642 .69069 L .22566 .68292 L p .707 .577 .707 r
F P
0 g
s
.25642 .69069 m .24858 .73802 L .28016 .7403 L p .707 .577 .707 r
F P
0 g
s
.28016 .7403 m .288 .69297 L .25642 .69069 L p .707 .577 .707 r
F P
0 g
s
.21782 .73025 m .22566 .68292 L .19875 .67041 L p .707 .577 .707 r
F P
0 g
s
.22566 .68292 m .21782 .73025 L .24858 .73802 L p .707 .577 .707 r
F P
0 g
s
.288 .69297 m .28016 .7403 L .30949 .73686 L p .707 .577 .707 r
F P
0 g
s
.30949 .73686 m .31733 .68953 L .288 .69297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.65369 .66644 m .63573 .72072 L .60636 .71004 L p .707 .577 .707 r
F P
0 g
s
.60636 .71004 m .62432 .65576 L .65369 .66644 L p .707 .577 .707 r
F P
0 g
s
.64168 .73232 m .63565 .76952 L .6049 .76326 L p .707 .577 .707 r
F P
0 g
s
.6049 .76326 m .61093 .72607 L .64168 .73232 L p .707 .577 .707 r
F P
0 g
s
.66869 .73988 m .66266 .77708 L .63565 .76952 L p .707 .577 .707 r
F P
0 g
s
.64809 .76185 m .65255 .77924 L .62198 .78386 L p .707 .577 .707 r
F P
0 g
s
.63565 .76952 m .64168 .73232 L .66869 .73988 L p .707 .577 .707 r
F P
0 g
s
.62198 .78386 m .61751 .76647 L .64809 .76185 L p .707 .577 .707 r
F P
0 g
s
.60007 .30921 m .60007 .81109 L .62728 .80143 L p .707 .577 .707 r
F P
0 g
s
.62728 .80143 m .62728 .29954 L .60007 .30921 L p .707 .577 .707 r
F P
0 g
s
.39611 .81007 m .39611 .30818 L .37027 .29825 L p .707 .577 .707 r
F P
0 g
s
.39611 .30818 m .39611 .81007 L .43212 .81737 L p .707 .577 .707 r
F P
0 g
s
.70159 .7559 m .69556 .7931 L .68331 .7852 L p .707 .577 .707 r
F P
0 g
s
.68331 .7852 m .68934 .74801 L .70159 .7559 L p .707 .577 .707 r
F P
0 g
s
.19091 .71774 m .19875 .67041 L .17832 .65439 L p .707 .577 .707 r
F P
0 g
s
.19875 .67041 m .19091 .71774 L .21782 .73025 L p .707 .577 .707 r
F P
0 g
s
.31733 .68953 m .30949 .73686 L .33368 .72804 L p .707 .577 .707 r
F P
0 g
s
.33368 .72804 m .34152 .68071 L .31733 .68953 L p .707 .577 .707 r
F P
0 g
s
.26506 .79671 m .26309 .7776 L .23178 .78055 L p .707 .577 .707 r
F P
0 g
s
.26309 .7776 m .26506 .79671 L .29655 .79326 L p .707 .577 .707 r
F P
0 g
s
.29655 .79326 m .29458 .77415 L .26309 .7776 L p .707 .577 .707 r
F P
0 g
s
.23178 .78055 m .23375 .79966 L .26506 .79671 L p .707 .577 .707 r
F P
0 g
s
.69839 .68689 m .68044 .74117 L .66125 .73145 L p .707 .577 .707 r
F P
0 g
s
.66125 .73145 m .67921 .67716 L .69839 .68689 L p .707 .577 .707 r
F P
0 g
s
.25062 .78601 m .25322 .75112 L .22213 .74623 L p .707 .577 .707 r
F P
0 g
s
.25322 .75112 m .25062 .78601 L .28239 .78679 L p .707 .577 .707 r
F P
0 g
s
.28239 .78679 m .28499 .75189 L .25322 .75112 L p .707 .577 .707 r
F P
0 g
s
.29458 .77415 m .29655 .79326 L .32515 .78965 L p .707 .577 .707 r
F P
0 g
s
.32515 .78965 m .32318 .77054 L .29458 .77415 L p .707 .577 .707 r
F P
0 g
s
.71018 .77293 m .71464 .79032 L .70126 .78263 L p .707 .577 .707 r
F P
0 g
s
.70126 .78263 m .6968 .76525 L .71018 .77293 L p .707 .577 .707 r
F P
0 g
s
.23375 .79966 m .23178 .78055 L .20372 .78272 L p .707 .577 .707 r
F P
0 g
s
.20372 .78272 m .20569 .80183 L .23375 .79966 L p .707 .577 .707 r
F P
0 g
s
.28499 .75189 m .28239 .78679 L .31173 .78337 L p .707 .577 .707 r
F P
0 g
s
.31173 .78337 m .31433 .74848 L .28499 .75189 L p .707 .577 .707 r
F P
0 g
s
.21953 .78112 m .22213 .74623 L .19477 .7377 L p .707 .577 .707 r
F P
0 g
s
.22213 .74623 m .21953 .78112 L .25062 .78601 L p .707 .577 .707 r
F P
0 g
s
.17047 .70172 m .17832 .65439 L .16636 .63643 L p .707 .577 .707 r
F P
0 g
s
.17832 .65439 m .17047 .70172 L .19091 .71774 L p .707 .577 .707 r
F P
0 g
s
.34152 .68071 m .33368 .72804 L .35037 .7147 L p .707 .577 .707 r
F P
0 g
s
.35037 .7147 m .35822 .66737 L .34152 .68071 L p .707 .577 .707 r
F P
0 g
s
.32318 .77054 m .32515 .78965 L .34805 .78623 L p .707 .577 .707 r
F P
0 g
s
.34805 .78623 m .34608 .76712 L .32318 .77054 L p .707 .577 .707 r
F P
0 g
s
.31433 .74848 m .31173 .78337 L .33578 .77611 L p .707 .577 .707 r
F P
0 g
s
.33578 .77611 m .33837 .74122 L .31433 .74848 L p .707 .577 .707 r
F P
0 g
s
.67921 .67716 m .66125 .73145 L .63573 .72072 L p .707 .577 .707 r
F P
0 g
s
.63573 .72072 m .65369 .66644 L .67921 .67716 L p .707 .577 .707 r
F P
0 g
s
.62728 .29954 m .62728 .80143 L .64202 .78999 L p .707 .577 .707 r
F P
0 g
s
.64202 .78999 m .64202 .2881 L .62728 .29954 L p .707 .577 .707 r
F P
0 g
s
.68934 .74801 m .68331 .7852 L .66266 .77708 L p .707 .577 .707 r
F P
0 g
s
.66266 .77708 m .66869 .73988 L .68934 .74801 L p .707 .577 .707 r
F P
0 g
s
.20569 .80183 m .20372 .78272 L .18166 .78388 L p .707 .577 .707 r
F P
0 g
s
.18166 .78388 m .18363 .80299 L .20569 .80183 L p .707 .577 .707 r
F P
0 g
s
.19218 .77259 m .19477 .7377 L .17382 .72637 L p .707 .577 .707 r
F P
0 g
s
.19477 .7377 m .19218 .77259 L .21953 .78112 L p .707 .577 .707 r
F P
0 g
s
.37027 .80014 m .37027 .29825 L .35713 .28667 L p .707 .577 .707 r
F P
0 g
s
.37027 .29825 m .37027 .80014 L .39611 .81007 L p .707 .577 .707 r
F P
0 g
s
.6968 .76525 m .70126 .78263 L .67987 .77882 L p .707 .577 .707 r
F P
0 g
s
.67987 .77882 m .67541 .76143 L .6968 .76525 L p .707 .577 .707 r
F P
0 g
s
.15851 .68376 m .16636 .63643 L .16404 .61829 L p .707 .577 .707 r
F P
0 g
s
.16636 .63643 m .15851 .68376 L .17047 .70172 L p .707 .577 .707 r
F P
0 g
s
.35822 .66737 m .35488 .68751 L p .35794 .69815 L .707 .577 .707 r
F P
0 g
s
.35545 .70359 m .35794 .69815 L p .35488 .68751 L .707 .577 .707 r
F P
0 g
s
.35477 .7308 m .35217 .7657 L .3593 .75316 L p .707 .577 .707 r
F P
0 g
s
.3593 .75316 m .3619 .71827 L .35477 .7308 L p .707 .577 .707 r
F P
0 g
s
.35794 .69815 m .36578 .65082 L .35822 .66737 L p .707 .577 .707 r
F P
0 g
s
.36578 .65082 m .35794 .69815 L .35608 .68362 L p .707 .577 .707 r
F P
0 g
s
.35608 .68362 m .35562 .68001 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35615 .67849 m .36578 .65082 L .35608 .68362 L .707 .577 .707 r
F
.34608 .76712 m .34805 .78623 L .36302 .78334 L p F P
0 g
s
.36302 .78334 m .36105 .76423 L .34608 .76712 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .36578 .65082 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35562 .68001 m .35617 .67669 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35617 .67669 m .36347 .63268 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.36105 .76423 m .36302 .78334 L .36858 .78126 L p .707 .577 .707 r
F P
0 g
s
.36858 .78126 m .36661 .76216 L .36105 .76423 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .35562 .68001 L .34366 .66205 L p .707 .577 .707 r
F P
0 g
s
.34366 .66205 m .35151 .61472 L .36347 .63268 L p .707 .577 .707 r
F P
0 g
s
.3619 .71827 m .3593 .75316 L .35649 .73972 L p .707 .577 .707 r
F P
0 g
s
.35649 .73972 m .35908 .70483 L .3619 .71827 L p .707 .577 .707 r
F P
0 g
s
.36661 .76216 m .36858 .78126 L .3642 .7802 L p .707 .577 .707 r
F P
0 g
s
.3642 .7802 m .36223 .76109 L .36661 .76216 L p .707 .577 .707 r
F P
0 g
s
.35217 .7657 m .35477 .7308 L .33837 .74122 L p .707 .577 .707 r
F P
0 g
s
.35908 .70483 m .35649 .73972 L .34399 .72671 L p .707 .577 .707 r
F P
0 g
s
.35488 .68751 m .35037 .7147 L .35545 .70359 L p .707 .577 .707 r
F P
0 g
s
.34399 .72671 m .34658 .69182 L .35908 .70483 L p .707 .577 .707 r
F P
0 g
s
.36223 .76109 m .3642 .7802 L .35029 .78025 L p .707 .577 .707 r
F P
0 g
s
.33837 .74122 m .33578 .77611 L .35217 .7657 L p .707 .577 .707 r
F P
0 g
s
.35029 .78025 m .34832 .76114 L .36223 .76109 L p .707 .577 .707 r
F P
0 g
s
.35713 .28667 m .35713 .78856 L .37027 .80014 L p .707 .577 .707 r
F P
0 g
s
.35713 .75115 m .35713 .60146 L .35719 .75281 L .707 .577 .707 r
F
.35713 .60146 m .35713 .28667 L p .35717 .59839 L F P
0 g
s
.35713 .60146 m .35717 .59839 L .35719 .75281 L .707 .577 .707 r
F
.35713 .28667 m .35798 .27456 L p .35748 .57385 L F P
0 g
s
.35719 .75281 m .35717 .59839 L .35748 .57385 L .707 .577 .707 r
F
.35717 .59839 m .35713 .28667 L .35748 .57385 L F
.35713 .78856 m .35713 .75115 L p .35719 .75281 L F P
0 g
s
.17382 .72637 m .17122 .76126 L .19218 .77259 L p .707 .577 .707 r
F P
0 g
s
.18363 .80299 m .18166 .78388 L .16776 .78394 L p .707 .577 .707 r
F P
0 g
s
.17122 .76126 m .17382 .72637 L .16132 .71336 L p .707 .577 .707 r
F P
0 g
s
.16776 .78394 m .16973 .80305 L .18363 .80299 L p .707 .577 .707 r
F P
0 g
s
.67541 .76143 m .67987 .77882 L .65255 .77924 L p .707 .577 .707 r
F P
0 g
s
.65255 .77924 m .64809 .76185 L .67541 .76143 L p .707 .577 .707 r
F P
0 g
s
.64202 .2881 m .64202 .78999 L .64287 .77788 L p .707 .577 .707 r
F P
0 g
s
.64287 .77788 m .64287 .27599 L .64202 .2881 L p .707 .577 .707 r
F P
0 g
s
.16132 .71336 m .15872 .74825 L .17122 .76126 L p .707 .577 .707 r
F P
0 g
s
.16404 .61829 m .1562 .66562 L .15851 .68376 L p .707 .577 .707 r
F P
0 g
s
.1562 .66562 m .16404 .61829 L .1716 .60174 L p .707 .577 .707 r
F P
0 g
s
.15872 .74825 m .16132 .71336 L .1585 .69992 L p .707 .577 .707 r
F P
0 g
s
.16973 .80305 m .16776 .78394 L .16337 .78287 L p .707 .577 .707 r
F P
0 g
s
.16337 .78287 m .16534 .80198 L .16973 .80305 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1585 .69992 m .1559 .73481 L .15872 .74825 L p .707 .577 .707 r
F P
0 g
s
.16376 .64907 m .1716 .60174 L .1883 .5884 L p .707 .577 .707 r
F P
0 g
s
.1716 .60174 m .16376 .64907 L .1562 .66562 L p .707 .577 .707 r
F P
0 g
s
.1559 .73481 m .1585 .69992 L .16564 .68738 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.64287 .27599 m .64287 .77788 L .62972 .76629 L p .707 .577 .707 r
F P
0 g
s
.62972 .76629 m .62972 .26441 L .64287 .27599 L p .707 .577 .707 r
F P
0 g
s
.16534 .80198 m .16337 .78287 L .16894 .78079 L p .707 .577 .707 r
F P
0 g
s
.16894 .78079 m .17091 .7999 L .16534 .80198 L p .707 .577 .707 r
F P
0 g
s
.35798 .77645 m .35798 .27456 L .37272 .26312 L p .707 .577 .707 r
F P
0 g
s
.35798 .27456 m .35798 .77645 L .35713 .78856 L p .707 .577 .707 r
F P
0 g
s
.1883 .5884 m .18045 .63573 L .16376 .64907 L p .707 .577 .707 r
F P
0 g
s
.18045 .63573 m .1883 .5884 L .21249 .57958 L p .707 .577 .707 r
F P
0 g
s
.35151 .61472 m .34366 .66205 L .32323 .64603 L p .707 .577 .707 r
F P
0 g
s
.32323 .64603 m .33107 .5987 L .35151 .61472 L p .707 .577 .707 r
F P
0 g
s
.16564 .68738 m .16304 .72228 L .1559 .73481 L p .707 .577 .707 r
F P
0 g
s
.16304 .72228 m .16564 .68738 L .18203 .67697 L p .707 .577 .707 r
F P
0 g
s
.20465 .62691 m .21249 .57958 L .24182 .57614 L p .707 .577 .707 r
F P
0 g
s
.21249 .57958 m .20465 .62691 L .18045 .63573 L p .707 .577 .707 r
F P
0 g
s
.33107 .5987 m .32323 .64603 L .29631 .63352 L p .707 .577 .707 r
F P
0 g
s
.29631 .63352 m .30416 .5862 L .33107 .5987 L p .707 .577 .707 r
F P
0 g
s
.17091 .7999 m .16894 .78079 L .1839 .7779 L p .707 .577 .707 r
F P
0 g
s
.1839 .7779 m .18587 .79701 L .17091 .7999 L p .707 .577 .707 r
F P
0 g
s
.18203 .67697 m .17943 .71186 L .16304 .72228 L p .707 .577 .707 r
F P
0 g
s
.23397 .62347 m .24182 .57614 L .2734 .57842 L p .707 .577 .707 r
F P
0 g
s
.24182 .57614 m .23397 .62347 L .20465 .62691 L p .707 .577 .707 r
F P
0 g
s
.30416 .5862 m .29631 .63352 L .26556 .62575 L p .707 .577 .707 r
F P
0 g
s
.26556 .62575 m .2734 .57842 L .30416 .5862 L p .707 .577 .707 r
F P
0 g
s
.62972 .26441 m .62972 .76629 L .60388 .75637 L p .707 .577 .707 r
F P
0 g
s
.60388 .75637 m .60388 .25448 L .62972 .26441 L p .707 .577 .707 r
F P
0 g
s
.34658 .69182 m .34399 .72671 L .32303 .71538 L p .707 .577 .707 r
F P
0 g
s
.32303 .71538 m .32563 .68049 L .34658 .69182 L p .707 .577 .707 r
F P
0 g
s
.2734 .57842 m .26556 .62575 L .23397 .62347 L p .707 .577 .707 r
F P
0 g
s
.37272 .76501 m .37272 .26312 L .39993 .25345 L p .707 .577 .707 r
F P
0 g
s
.37272 .26312 m .37272 .76501 L .35798 .77645 L p .707 .577 .707 r
F P
0 g
s
.17943 .71186 m .18203 .67697 L .20607 .66971 L p .707 .577 .707 r
F P
0 g
s
.34832 .76114 m .35029 .78025 L .32824 .78142 L p .707 .577 .707 r
F P
0 g
s
.32824 .78142 m .32627 .76231 L .34832 .76114 L p .707 .577 .707 r
F P
0 g
s
.18587 .79701 m .1839 .7779 L .20681 .77449 L p .707 .577 .707 r
F P
0 g
s
.20681 .77449 m .20878 .79359 L .18587 .79701 L p .707 .577 .707 r
F P
0 g
s
.32563 .68049 m .32303 .71538 L .29567 .70685 L p .707 .577 .707 r
F P
0 g
s
.29567 .70685 m .29827 .67196 L .32563 .68049 L p .707 .577 .707 r
F P
0 g
s
.20607 .66971 m .20348 .7046 L .17943 .71186 L p .707 .577 .707 r
F P
0 g
s
.20348 .7046 m .20607 .66971 L .23542 .66629 L p .707 .577 .707 r
F P
0 g
s
.69584 .57356 m .70368 .63064 L .73444 .62603 L p .707 .577 .707 r
F P
0 g
s
.73444 .62603 m .72659 .56894 L .69584 .57356 L p .707 .577 .707 r
F P
0 g
s
.72659 .56894 m .73444 .62603 L .76602 .62182 L p .707 .577 .707 r
F P
0 g
s
.60388 .25448 m .60388 .75637 L .56788 .74907 L p .707 .577 .707 r
F P
0 g
s
.56788 .74907 m .56788 .24718 L .60388 .25448 L p .707 .577 .707 r
F P
0 g
s
.76602 .62182 m .75818 .56474 L .72659 .56894 L p .707 .577 .707 r
F P
0 g
s
.75818 .56474 m .76602 .62182 L .79535 .61843 L p .707 .577 .707 r
F P
0 g
s
.32627 .76231 m .32824 .78142 L .30018 .78358 L p .707 .577 .707 r
F P
0 g
s
.30018 .78358 m .29821 .76447 L .32627 .76231 L p .707 .577 .707 r
F P
0 g
s
.29827 .67196 m .29567 .70685 L .26459 .70196 L p .707 .577 .707 r
F P
0 g
s
.26459 .70196 m .26719 .66707 L .29827 .67196 L p .707 .577 .707 r
F P
0 g
s
.39993 .25345 m .39993 .75534 L .37272 .76501 L p .707 .577 .707 r
F P
0 g
s
.39993 .75534 m .39993 .25345 L .43693 .24652 L p .707 .577 .707 r
F P
0 g
s
.23282 .70119 m .23542 .66629 L .26719 .66707 L p .707 .577 .707 r
F P
0 g
s
.23542 .66629 m .23282 .70119 L .20348 .7046 L p .707 .577 .707 r
F P
0 g
s
.79535 .61843 m .78751 .56135 L .75818 .56474 L p .707 .577 .707 r
F P
0 g
s
.20878 .79359 m .20681 .77449 L .2354 .77087 L p .707 .577 .707 r
F P
0 g
s
.2354 .77087 m .23737 .78998 L .20878 .79359 L p .707 .577 .707 r
F P
0 g
s
.66893 .57812 m .67677 .63521 L .70368 .63064 L p .707 .577 .707 r
F P
0 g
s
.70368 .63064 m .69584 .57356 L .66893 .57812 L p .707 .577 .707 r
F P
0 g
s
.26719 .66707 m .26459 .70196 L .23282 .70119 L p .707 .577 .707 r
F P
0 g
s
.73541 .70366 m .73281 .66553 L .70173 .66681 L p .707 .577 .707 r
F P
0 g
s
.73281 .66553 m .73541 .70366 L .76718 .7012 L p .707 .577 .707 r
F P
0 g
s
.76718 .7012 m .76458 .66307 L .73281 .66553 L p .707 .577 .707 r
F P
0 g
s
.78751 .56135 m .79535 .61843 L .81954 .61619 L p .707 .577 .707 r
F P
0 g
s
.76458 .66307 m .76718 .7012 L .79652 .69781 L p .707 .577 .707 r
F P
0 g
s
.79652 .69781 m .79392 .65968 L .76458 .66307 L p .707 .577 .707 r
F P
0 g
s
.81954 .61619 m .8117 .55911 L .78751 .56135 L p .707 .577 .707 r
F P
0 g
s
.29821 .76447 m .30018 .78358 L .26887 .78653 L p .707 .577 .707 r
F P
0 g
s
.26887 .78653 m .2669 .76742 L .29821 .76447 L p .707 .577 .707 r
F P
0 g
s
.70173 .66681 m .70432 .70494 L .73541 .70366 L p .707 .577 .707 r
F P
0 g
s
.23737 .78998 m .2354 .77087 L .2669 .76742 L p .707 .577 .707 r
F P
0 g
s
.2669 .76742 m .26887 .78653 L .23737 .78998 L p .707 .577 .707 r
F P
0 g
s
.70432 .70494 m .70173 .66681 L .67437 .66679 L p .707 .577 .707 r
F P
0 g
s
.64849 .58219 m .65633 .63928 L .67677 .63521 L p .707 .577 .707 r
F P
0 g
s
.67677 .63521 m .66893 .57812 L .64849 .58219 L p .707 .577 .707 r
F P
0 g
s
.67437 .66679 m .67697 .70491 L .70432 .70494 L p .707 .577 .707 r
F P
0 g
s
.56788 .24718 m .56788 .74907 L .52522 .74511 L p .707 .577 .707 r
F P
0 g
s
.52522 .74511 m .52522 .24322 L .56788 .24718 L p .707 .577 .707 r
F P
0 g
s
.79392 .65968 m .79652 .69781 L .82057 .69381 L p .707 .577 .707 r
F P
0 g
s
.82057 .69381 m .81797 .65568 L .79392 .65968 L p .707 .577 .707 r
F P
0 g
s
.43693 .74841 m .43693 .24652 L .4801 .24299 L p .707 .577 .707 r
F P
0 g
s
.43693 .24652 m .43693 .74841 L .39993 .75534 L p .707 .577 .707 r
F P
0 g
s
.8117 .55911 m .81954 .61619 L .83624 .61532 L p .707 .577 .707 r
F P
0 g
s
.67697 .70491 m .67437 .66679 L .65341 .66546 L p .707 .577 .707 r
F P
0 g
s
.83624 .61532 m .82839 .55823 L .8117 .55911 L p .707 .577 .707 r
F P
0 g
s
.52522 .24322 m .52522 .74511 L .4801 .74488 L p .707 .577 .707 r
F P
0 g
s
.4801 .74488 m .4801 .24299 L .52522 .24322 L p .707 .577 .707 r
F P
0 g
s
.4801 .24299 m .4801 .74488 L .43693 .74841 L p .707 .577 .707 r
F P
0 g
s
.65341 .66546 m .65601 .70359 L .67697 .70491 L p .707 .577 .707 r
F P
0 g
s
.63653 .58537 m .64437 .64246 L .65633 .63928 L p .707 .577 .707 r
F P
0 g
s
.65633 .63928 m .64849 .58219 L .63653 .58537 L p .707 .577 .707 r
F P
0 g
s
.81797 .65568 m .82057 .69381 L .83696 .68959 L p .707 .577 .707 r
F P
0 g
s
.83696 .68959 m .83436 .65146 L .81797 .65568 L p .707 .577 .707 r
F P
0 g
s
.73113 .77603 m .7331 .7592 L .70179 .75371 L p .707 .577 .707 r
F P
0 g
s
.7331 .7592 m .73113 .77603 L .76262 .77679 L p .707 .577 .707 r
F P
0 g
s
.76262 .77679 m .76459 .75996 L .7331 .7592 L p .707 .577 .707 r
F P
0 g
s
.69982 .77054 m .70179 .75371 L .67373 .74401 L p .707 .577 .707 r
F P
0 g
s
.70179 .75371 m .69982 .77054 L .73113 .77603 L p .707 .577 .707 r
F P
0 g
s
.76459 .75996 m .76262 .77679 L .79122 .77274 L p .707 .577 .707 r
F P
0 g
s
.79122 .77274 m .79319 .7559 L .76459 .75996 L p .707 .577 .707 r
F P
0 g
s
.65601 .70359 m .65341 .66546 L .64092 .66296 L p .707 .577 .707 r
F P
0 g
s
.82839 .55823 m .83624 .61532 L .8438 .6159 L p .707 .577 .707 r
F P
0 g
s
.8438 .6159 m .83596 .55881 L .82839 .55823 L p .707 .577 .707 r
F P
0 g
s
.67373 .74401 m .67176 .76084 L .69982 .77054 L p .707 .577 .707 r
F P
0 g
s
.64092 .66296 m .64351 .70109 L .65601 .70359 L p .707 .577 .707 r
F P
0 g
s
.67176 .76084 m .67373 .74401 L .65167 .73107 L p .707 .577 .707 r
F P
0 g
s
.79319 .7559 m .79122 .77274 L .81413 .76427 L p .707 .577 .707 r
F P
0 g
s
.81413 .76427 m .8161 .74744 L .79319 .7559 L p .707 .577 .707 r
F P
0 g
s
.83436 .65146 m .83696 .68959 L .8441 .68558 L p .707 .577 .707 r
F P
0 g
s
.8441 .68558 m .8415 .64745 L .83436 .65146 L p .707 .577 .707 r
F P
0 g
s
.63422 .58735 m .64206 .64443 L .64437 .64246 L p .707 .577 .707 r
F P
0 g
s
.64437 .64246 m .63653 .58537 L .63422 .58735 L p .707 .577 .707 r
F P
0 g
s
.65167 .73107 m .6497 .7479 L .67176 .76084 L p .707 .577 .707 r
F P
0 g
s
.6497 .7479 m .65167 .73107 L .63777 .71614 L p .707 .577 .707 r
F P
0 g
s
.64351 .70109 m .64092 .66296 L .6381 .65954 L p .707 .577 .707 r
F P
0 g
s
.8161 .74744 m .81413 .76427 L .82909 .75222 L p .707 .577 .707 r
F P
0 g
s
.82909 .75222 m .83106 .73538 L .8161 .74744 L p .707 .577 .707 r
F P
0 g
s
.83596 .55881 m .8438 .6159 L .84149 .61788 L p .707 .577 .707 r
F P
0 g
s
.6381 .65954 m .64069 .69767 L .64351 .70109 L p .707 .577 .707 r
F P
0 g
s
.84149 .61788 m .83364 .56079 L .83596 .55881 L p .707 .577 .707 r
F P
0 g
s
.63777 .71614 m .6358 .73297 L .6497 .7479 L p .707 .577 .707 r
F P
0 g
s
.8415 .64745 m .8441 .68558 L .84128 .68215 L p .707 .577 .707 r
F P
0 g
s
.84128 .68215 m .83868 .64402 L .8415 .64745 L p .707 .577 .707 r
F P
0 g
s
.64178 .58793 m .64962 .64501 L .64206 .64443 L p .707 .577 .707 r
F P
0 g
s
.64206 .64443 m .63422 .58735 L .64178 .58793 L p .707 .577 .707 r
F P
0 g
s
.6358 .73297 m .63777 .71614 L .63339 .70069 L p .707 .577 .707 r
F P
0 g
s
.83106 .73538 m .82909 .75222 L .83465 .73776 L p .707 .577 .707 r
F P
0 g
s
.83465 .73776 m .83662 .72093 L .83106 .73538 L p .707 .577 .707 r
F P
0 g
s
.63339 .70069 m .63142 .71753 L .6358 .73297 L p .707 .577 .707 r
F P
0 g
s
.64069 .69767 m .6381 .65954 L .64523 .65552 L p .707 .577 .707 r
F P
0 g
s
.83364 .56079 m .84149 .61788 L .82953 .62106 L p .707 .577 .707 r
F P
0 g
s
.42397 .6239 m .40601 .57343 L .37568 .58326 L p .707 .577 .707 r
F P
0 g
s
.40601 .57343 m .42397 .6239 L .4523 .61085 L p .707 .577 .707 r
F P
0 g
s
.4523 .61085 m .43434 .56038 L .40601 .57343 L p .707 .577 .707 r
F P
0 g
s
.64523 .65552 m .64783 .69365 L .64069 .69767 L p .707 .577 .707 r
F P
0 g
s
.82953 .62106 m .82168 .56397 L .83364 .56079 L p .707 .577 .707 r
F P
0 g
s
.39363 .63373 m .37568 .58326 L .34631 .58892 L p .707 .577 .707 r
F P
0 g
s
.37568 .58326 m .39363 .63373 L .42397 .6239 L p .707 .577 .707 r
F P
0 g
s
.43434 .56038 m .4523 .61085 L .47585 .59586 L p .707 .577 .707 r
F P
0 g
s
.47585 .59586 m .45789 .54539 L .43434 .56038 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83868 .64402 m .84128 .68215 L .82878 .67965 L p .707 .577 .707 r
F P
0 g
s
.82878 .67965 m .82618 .64152 L .83868 .64402 L p .707 .577 .707 r
F P
0 g
s
.36427 .63939 m .34631 .58892 L .32079 .58984 L p .707 .577 .707 r
F P
0 g
s
.34631 .58892 m .36427 .63939 L .39363 .63373 L p .707 .577 .707 r
F P
0 g
s
.63142 .71753 m .63339 .70069 L .63895 .68624 L p .707 .577 .707 r
F P
0 g
s
.65847 .58706 m .66632 .64414 L .64962 .64501 L p .707 .577 .707 r
F P
0 g
s
.64962 .64501 m .64178 .58793 L .65847 .58706 L p .707 .577 .707 r
F P
0 g
s
.83662 .72093 m .83465 .73776 L .83027 .72231 L p .707 .577 .707 r
F P
0 g
s
.83027 .72231 m .83224 .70548 L .83662 .72093 L p .707 .577 .707 r
F P
0 g
s
.45789 .54539 m .47585 .59586 L .49233 .58039 L p .707 .577 .707 r
F P
0 g
s
.49233 .58039 m .47437 .52992 L .45789 .54539 L p .707 .577 .707 r
F P
0 g
s
.63895 .68624 m .63698 .70307 L .63142 .71753 L p .707 .577 .707 r
F P
0 g
s
.39509 .68772 m .38906 .65189 L .35832 .65407 L p .707 .577 .707 r
F P
0 g
s
.38906 .65189 m .39509 .68772 L .42655 .68212 L p .707 .577 .707 r
F P
0 g
s
.42655 .68212 m .42052 .64628 L .38906 .65189 L p .707 .577 .707 r
F P
0 g
s
.42052 .64628 m .42655 .68212 L .45565 .67364 L p .707 .577 .707 r
F P
0 g
s
.45565 .67364 m .44962 .63781 L .42052 .64628 L p .707 .577 .707 r
F P
0 g
s
.64783 .69365 m .64523 .65552 L .66162 .6513 L p .707 .577 .707 r
F P
0 g
s
.82168 .56397 m .82953 .62106 L .80909 .62513 L p .707 .577 .707 r
F P
0 g
s
.80909 .62513 m .80125 .56804 L .82168 .56397 L p .707 .577 .707 r
F P
0 g
s
.37802 .71327 m .38248 .69482 L .35191 .68667 L p .707 .577 .707 r
F P
0 g
s
.38248 .69482 m .37802 .71327 L .40885 .71984 L p .707 .577 .707 r
F P
0 g
s
.40885 .71984 m .41331 .70139 L .38248 .69482 L p .707 .577 .707 r
F P
0 g
s
.66162 .6513 m .66422 .68943 L .64783 .69365 L p .707 .577 .707 r
F P
0 g
s
.33874 .64031 m .32079 .58984 L .3016 .58593 L p .707 .577 .707 r
F P
0 g
s
.32079 .58984 m .33874 .64031 L .36427 .63939 L p .707 .577 .707 r
F P
0 g
s
.36435 .6899 m .35832 .65407 L .33131 .65262 L p .707 .577 .707 r
F P
0 g
s
.35832 .65407 m .36435 .6899 L .39509 .68772 L p .707 .577 .707 r
F P
0 g
s
.35191 .68667 m .34745 .70512 L .37802 .71327 L p .707 .577 .707 r
F P
0 g
s
.44962 .63781 m .45565 .67364 L .47954 .66312 L p .707 .577 .707 r
F P
0 g
s
.47954 .66312 m .47351 .62729 L .44962 .63781 L p .707 .577 .707 r
F P
0 g
s
.34745 .70512 m .35191 .68667 L .32459 .67773 L p .707 .577 .707 r
F P
0 g
s
.41331 .70139 m .40885 .71984 L .43692 .72418 L p .707 .577 .707 r
F P
0 g
s
.43692 .72418 m .44139 .70573 L .41331 .70139 L p .707 .577 .707 r
F P
0 g
s
.32459 .67773 m .32013 .69618 L .34745 .70512 L p .707 .577 .707 r
F P
0 g
s
.68267 .58481 m .69051 .6419 L .66632 .64414 L p .707 .577 .707 r
F P
0 g
s
.66632 .64414 m .65847 .58706 L .68267 .58481 L p .707 .577 .707 r
F P
0 g
s
.63698 .70307 m .63895 .68624 L .65392 .67418 L p .707 .577 .707 r
F P
0 g
s
.82618 .64152 m .82878 .67965 L .80782 .67833 L p .707 .577 .707 r
F P
0 g
s
.80782 .67833 m .80523 .6402 L .82618 .64152 L p .707 .577 .707 r
F P
0 g
s
.47437 .52992 m .49233 .58039 L .50011 .56597 L p .707 .577 .707 r
F P
0 g
s
.50011 .56597 m .48215 .5155 L .47437 .52992 L p .707 .577 .707 r
F P
0 g
s
.33131 .65262 m .33733 .68845 L .36435 .6899 L p .707 .577 .707 r
F P
0 g
s
.83224 .70548 m .83027 .72231 L .81637 .70738 L p .707 .577 .707 r
F P
0 g
s
.81637 .70738 m .81834 .69055 L .83224 .70548 L p .707 .577 .707 r
F P
0 g
s
.33733 .68845 m .33131 .65262 L .31066 .64767 L p .707 .577 .707 r
F P
0 g
s
.32013 .69618 m .32459 .67773 L .3032 .66888 L p .707 .577 .707 r
F P
0 g
s
.65392 .67418 m .65195 .69101 L .63698 .70307 L p .707 .577 .707 r
F P
0 g
s
.44139 .70573 m .43692 .72418 L .45949 .72587 L p .707 .577 .707 r
F P
0 g
s
.45949 .72587 m .46395 .70741 L .44139 .70573 L p .707 .577 .707 r
F P
0 g
s
.80125 .56804 m .80909 .62513 L .78218 .62969 L p .707 .577 .707 r
F P
0 g
s
.3032 .66888 m .29873 .68733 L .32013 .69618 L p .707 .577 .707 r
F P
0 g
s
.47351 .62729 m .47954 .66312 L .49587 .65159 L p .707 .577 .707 r
F P
0 g
s
.49587 .65159 m .48985 .61576 L .47351 .62729 L p .707 .577 .707 r
F P
0 g
s
.3016 .58593 m .31956 .6364 L .33874 .64031 L p .707 .577 .707 r
F P
0 g
s
.66422 .68943 m .66162 .6513 L .68567 .6473 L p .707 .577 .707 r
F P
0 g
s
.78218 .62969 m .77433 .57261 L .80125 .56804 L p .707 .577 .707 r
F P
0 g
s
.31956 .6364 m .3016 .58593 L .29064 .57758 L p .707 .577 .707 r
F P
0 g
s
.68567 .6473 m .68827 .68543 L .66422 .68943 L p .707 .577 .707 r
F P
0 g
s
.71199 .58143 m .71984 .63851 L .69051 .6419 L p .707 .577 .707 r
F P
0 g
s
.69051 .6419 m .68267 .58481 L .71199 .58143 L p .707 .577 .707 r
F P
0 g
s
.31066 .64767 m .31669 .68351 L .33733 .68845 L p .707 .577 .707 r
F P
0 g
s
.80523 .6402 m .80782 .67833 L .78046 .6783 L p .707 .577 .707 r
F P
0 g
s
.78046 .6783 m .77787 .64017 L .80523 .6402 L p .707 .577 .707 r
F P
0 g
s
.65195 .69101 m .65392 .67418 L .67682 .66571 L p .707 .577 .707 r
F P
0 g
s
.77433 .57261 m .78218 .62969 L .75142 .6343 L p .707 .577 .707 r
F P
0 g
s
.29873 .68733 m .3032 .66888 L .28982 .66098 L p .707 .577 .707 r
F P
0 g
s
.75142 .6343 m .74358 .57722 L .77433 .57261 L p .707 .577 .707 r
F P
0 g
s
.81834 .69055 m .81637 .70738 L .79431 .69444 L p .707 .577 .707 r
F P
0 g
s
.79431 .69444 m .79628 .67761 L .81834 .69055 L p .707 .577 .707 r
F P
0 g
s
.48215 .5155 m .50011 .56597 L .49844 .554 L p .707 .577 .707 r
F P
0 g
s
.49844 .554 m .48048 .50353 L .48215 .5155 L p .707 .577 .707 r
F P
0 g
s
.31669 .68351 m .31066 .64767 L .29841 .63972 L p .707 .577 .707 r
F P
0 g
s
.46395 .70741 m .45949 .72587 L .47434 .72473 L p .707 .577 .707 r
F P
0 g
s
.47434 .72473 m .4788 .70628 L .46395 .70741 L p .707 .577 .707 r
F P
0 g
s
.74358 .57722 m .75142 .6343 L .71984 .63851 L p .707 .577 .707 r
F P
0 g
s
.71984 .63851 m .71199 .58143 L .74358 .57722 L p .707 .577 .707 r
F P
0 g
s
.28982 .66098 m .28536 .67943 L .29873 .68733 L p .707 .577 .707 r
F P
0 g
s
.68827 .68543 m .68567 .6473 L .71501 .64391 L p .707 .577 .707 r
F P
0 g
s
.67682 .66571 m .67485 .68255 L .65195 .69101 L p .707 .577 .707 r
F P
0 g
s
.48985 .61576 m .49587 .65159 L .50306 .64017 L p .707 .577 .707 r
F P
0 g
s
.50306 .64017 m .49704 .60434 L .48985 .61576 L p .707 .577 .707 r
F P
0 g
s
.29064 .57758 m .3086 .62805 L .31956 .6364 L p .707 .577 .707 r
F P
0 g
s
.71501 .64391 m .71761 .68204 L .68827 .68543 L p .707 .577 .707 r
F P
0 g
s
.77787 .64017 m .78046 .6783 L .74938 .67958 L p .707 .577 .707 r
F P
0 g
s
.74938 .67958 m .74678 .64145 L .77787 .64017 L p .707 .577 .707 r
F P
0 g
s
.29841 .63972 m .30444 .67555 L .31669 .68351 L p .707 .577 .707 r
F P
0 g
s
.3086 .62805 m .29064 .57758 L .28896 .56561 L p .707 .577 .707 r
F P
0 g
s
.67485 .68255 m .67682 .66571 L .70542 .66166 L p .707 .577 .707 r
F P
0 g
s
.71761 .68204 m .71501 .64391 L .74678 .64145 L p .707 .577 .707 r
F P
0 g
s
.74678 .64145 m .74938 .67958 L .71761 .68204 L p .707 .577 .707 r
F P
0 g
s
.79628 .67761 m .79431 .69444 L .76625 .68475 L p .707 .577 .707 r
F P
0 g
s
.76625 .68475 m .76822 .66791 L .79628 .67761 L p .707 .577 .707 r
F P
0 g
s
.70542 .66166 m .70345 .67849 L .67485 .68255 L p .707 .577 .707 r
F P
0 g
s
.28536 .67943 m .28982 .66098 L .28578 .65481 L p .707 .577 .707 r
F P
0 g
s
.70345 .67849 m .70542 .66166 L .73691 .66242 L p .707 .577 .707 r
F P
0 g
s
.48048 .50353 m .49844 .554 L .48747 .54565 L p .707 .577 .707 r
F P
0 g
s
.48747 .54565 m .46951 .49518 L .48048 .50353 L p .707 .577 .707 r
F P
0 g
s
.30444 .67555 m .29841 .63972 L .29575 .62954 L p .707 .578 .707 r
F P
0 g
s
.4788 .70628 m .47434 .72473 L .48002 .7209 L p .707 .577 .707 r
F P
0 g
s
.48002 .7209 m .48448 .70244 L .4788 .70628 L p .707 .577 .707 r
F P
0 g
s
.28578 .65481 m .28131 .67326 L .28536 .67943 L p .707 .577 .707 r
F P
0 g
s
.76822 .66791 m .76625 .68475 L .73494 .67925 L p .707 .577 .707 r
F P
0 g
s
.73494 .67925 m .73691 .66242 L .76822 .66791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73691 .66242 m .73494 .67925 L .70345 .67849 L p .707 .577 .707 r
F P
0 g
s
.49704 .60434 m .50306 .64017 L .5004 .62999 L p .707 .578 .707 r
F P
0 g
s
.5004 .62999 m .49438 .59416 L .49704 .60434 L p .707 .578 .707 r
F P
0 g
s
.28896 .56561 m .30692 .61608 L .3086 .62805 L p .707 .577 .707 r
F P
0 g
s
.29575 .62954 m .30177 .66537 L .30444 .67555 L p .707 .578 .707 r
F P
0 g
s
.30692 .61608 m .28896 .56561 L .29674 .55119 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.46951 .49518 m .48747 .54565 L .46829 .54174 L p .707 .577 .707 r
F P
0 g
s
.46829 .54174 m .45033 .49127 L .46951 .49518 L p .707 .577 .707 r
F P
0 g
s
.28131 .67326 m .28578 .65481 L .29145 .65097 L p .707 .577 .707 r
F P
0 g
s
.30177 .66537 m .29575 .62954 L .30294 .61812 L p .707 .577 .707 r
F P
0 g
s
.48448 .70244 m .48002 .7209 L .47597 .71473 L p .707 .577 .707 r
F P
0 g
s
.47597 .71473 m .48043 .69627 L .48448 .70244 L p .707 .577 .707 r
F P
0 g
s
.29145 .65097 m .28699 .66942 L .28131 .67326 L p .707 .577 .707 r
F P
0 g
s
.29674 .55119 m .3147 .60166 L .30692 .61608 L p .707 .577 .707 r
F P
0 g
s
.49438 .59416 m .5004 .62999 L .48815 .62204 L p .707 .577 .707 r
F P
0 g
s
.48815 .62204 m .48212 .5862 L .49438 .59416 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3147 .60166 m .29674 .55119 L .31322 .53572 L p .707 .577 .707 r
F P
0 g
s
.30294 .61812 m .30896 .65395 L .30177 .66537 L p .707 .577 .707 r
F P
0 g
s
.45033 .49127 m .46829 .54174 L .44276 .54266 L p .707 .577 .707 r
F P
0 g
s
.44276 .54266 m .4248 .49219 L .45033 .49127 L p .707 .577 .707 r
F P
0 g
s
.30896 .65395 m .30294 .61812 L .31927 .60659 L p .707 .577 .707 r
F P
0 g
s
.28699 .66942 m .29145 .65097 L .3063 .64984 L p .707 .577 .707 r
F P
0 g
s
.48043 .69627 m .47597 .71473 L .4626 .70683 L p .707 .577 .707 r
F P
0 g
s
.4626 .70683 m .46706 .68838 L .48043 .69627 L p .707 .577 .707 r
F P
0 g
s
.31322 .53572 m .33118 .58619 L .3147 .60166 L p .707 .577 .707 r
F P
0 g
s
.3063 .64984 m .30184 .66829 L .28699 .66942 L p .707 .577 .707 r
F P
0 g
s
.33118 .58619 m .31322 .53572 L .33677 .52073 L p .707 .577 .707 r
F P
0 g
s
.48212 .5862 m .48815 .62204 L .46751 .61709 L p .707 .577 .707 r
F P
0 g
s
.46751 .61709 m .46148 .58126 L .48212 .5862 L p .707 .577 .707 r
F P
0 g
s
.31927 .60659 m .3253 .64242 L .30896 .65395 L p .707 .577 .707 r
F P
0 g
s
.4248 .49219 m .44276 .54266 L .4134 .54831 L p .707 .577 .707 r
F P
0 g
s
.4134 .54831 m .39544 .49784 L .4248 .49219 L p .707 .577 .707 r
F P
0 g
s
.35473 .5712 m .33677 .52073 L .3651 .50768 L p .707 .577 .707 r
F P
0 g
s
.33677 .52073 m .35473 .5712 L .33118 .58619 L p .707 .577 .707 r
F P
0 g
s
.3253 .64242 m .31927 .60659 L .34316 .59607 L p .707 .577 .707 r
F P
0 g
s
.39544 .49784 m .4134 .54831 L .38306 .55815 L p .707 .577 .707 r
F P
0 g
s
.38306 .55815 m .3651 .50768 L .39544 .49784 L p .707 .577 .707 r
F P
0 g
s
.3651 .50768 m .38306 .55815 L .35473 .5712 L p .707 .577 .707 r
F P
0 g
s
.46148 .58126 m .46751 .61709 L .44049 .61564 L p .707 .577 .707 r
F P
0 g
s
.44049 .61564 m .43446 .57981 L .46148 .58126 L p .707 .577 .707 r
F P
0 g
s
.30184 .66829 m .3063 .64984 L .32887 .65153 L p .707 .577 .707 r
F P
0 g
s
.46706 .68838 m .4626 .70683 L .4412 .69798 L p .707 .577 .707 r
F P
0 g
s
.4412 .69798 m .44566 .67953 L .46706 .68838 L p .707 .577 .707 r
F P
0 g
s
.32887 .65153 m .32441 .66998 L .30184 .66829 L p .707 .577 .707 r
F P
0 g
s
.34316 .59607 m .34919 .6319 L .3253 .64242 L p .707 .577 .707 r
F P
0 g
s
.34919 .6319 m .34316 .59607 L .37226 .58759 L p .707 .577 .707 r
F P
0 g
s
.43446 .57981 m .44049 .61564 L .40975 .61782 L p .707 .577 .707 r
F P
0 g
s
.40975 .61782 m .40372 .58199 L .43446 .57981 L p .707 .577 .707 r
F P
0 g
s
.32441 .66998 m .32887 .65153 L .35694 .65587 L p .707 .577 .707 r
F P
0 g
s
.44566 .67953 m .4412 .69798 L .41388 .68904 L p .707 .577 .707 r
F P
0 g
s
.41388 .68904 m .41834 .67059 L .44566 .67953 L p .707 .577 .707 r
F P
0 g
s
.37829 .62343 m .37226 .58759 L .40372 .58199 L p .707 .577 .707 r
F P
0 g
s
.37226 .58759 m .37829 .62343 L .34919 .6319 L p .707 .577 .707 r
F P
0 g
s
.40372 .58199 m .40975 .61782 L .37829 .62343 L p .707 .577 .707 r
F P
0 g
s
.35694 .65587 m .35248 .67432 L .32441 .66998 L p .707 .577 .707 r
F P
0 g
s
.35248 .67432 m .35694 .65587 L .38777 .66243 L p .707 .577 .707 r
F P
0 g
s
.41834 .67059 m .41388 .68904 L .38331 .68089 L p .707 .577 .707 r
F P
0 g
s
.38331 .68089 m .38777 .66243 L .41834 .67059 L p .707 .577 .707 r
F P
0 g
s
.38777 .66243 m .38331 .68089 L .35248 .67432 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF1`001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP04001JEUYFFUH80003FUH00`00FUIJEP030002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001EYF1P000eYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1000FUIJEUYF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00@005YF000000QJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000>FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol30009FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001SOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001QOol20005FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005moo`8000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005eoo`<000UJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005aoo`05001JEUYFFUH0
0008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Yoo`80
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol005Uoo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0002FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001E
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH60002FUH00`00
FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH30008FUH01000FUIJEUYF0`001EYF00<005YFFUH00`001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00Dgoo0P001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YF00000`002UYF00@005YF000000=JEP03001JEUYF
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol005=oo`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP8000=JEP03001JEUYF00QJEP8000EJEP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000<Woo1@00;goo001BOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0`002EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0002Eoo`d0009JEP800003FUIoogoo02eoo`00DWoo00@005YFFUH0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEPD000IJEP<000QJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0000LOol90003FUH00`00FUIJEP04FUH500000eYF001JEP0_Ool0059oo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEPD000AJEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00005Goo1`0015YF00<005YFFUH01EYF20000UYF00D005YFFUH005YF02moo`00
DWoo0P000UYF00<005YFFUH015YF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF1@000UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0000AOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06
0003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo0011Ool80009Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P001UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00>goo1P000eYF00<005YFFUH00UYF1`000Woo0P000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=oo`05001JEUYFFUH00003FUH40002FUH01000FUIJEUYF20001UYF
00<005YFFUH00eYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Eoo`H000=JEP03001JEUYF00IJEPP000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool003Uoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<00005
FUH005YFFUH00006FUH30004Ool01000FUIJEUYF10000eYF1`0015YF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH60002
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP02000^Ool003Moo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP80009JEP03001JEUYF00AJEP03001oogoo00Aoo`@00003FUH005YF00@0009JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000800003FUH0000000d000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0P001EYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF10001UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00P00
0eYF10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000aOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00@005YF001JEP800003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo000`Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP020006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH2000015YF000000001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUIJEP001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEP00008000YJEP@0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPD002moo`00;Woo0P000eYF00<005YF
FUH015YF00<005YFFUH00UYF3P001eYF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF
0`000UYF00<005YFFUH025YF0P000UYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1@00=7oo000^Ool20003FUH00`00FUIJEP03FUH6
000>Ool30004FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH40002FUH30005
FUH00`00FUIJEP06FUH20004FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<003Uoo`00;Goo00<005YF00000eYF00<005YF00000`005goo0`0000AJ
EP00FUH000AJEP03001JEUYF00AJEPD000MJEPH000QJEP03001JEUYF00AJEP800003FUH005YF00=J
EP04001JEUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH003eo
o`00;Goo00<005YF00000eYF0P007Woo0P0000=JEP00FUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF009JEPL000UJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004=oo`00;Goo0P000eYF00<007ooOol07goo00@0
05YFFUH000AJEP03001JEP00008000=JEPP0009JEPD000UJEP03001JEP00008000IJEP03001JEUYF
009JEP03001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000C7oo000]Ool200000eYF0000000R
Ool01000FUIJEP0015YF0P0000=JEP0000000`0000=JEP00FUH00UYF00<005YFFUH00eYF0`0025YF
100000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF20001goo7000<Goo000]
Ool4000SOol01000FUIJEP000UYF0P001UYF00@005YFFUH000=JEP03001JEUYF00EJEP04001JEUYF
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF2`001Woo2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool20002FUH00`00Oomoo`0POol700000goo001J
EP04FUH01000FUIJEP000eYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Uoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`05FUH005YFFUH0000FOol30007Ool30002FUH00`00FUIJ
EP080003FUH01000FUIJEUYF20001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
00=oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP03001oogoo019oo`D000Eoo`8000=J
EP03001JEUYF00AJEP04001JEUYFFUH90004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP<0019oo`D000Eo
o`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP0000=JEP04001JEUYF000AOol50004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
014000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
0eYF00@005YFFUIJEP8000Moo`l0009oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP00009JEP03001JEUYF00AJEPL000=JEP03001J
EUYF00IJEP03001JEUYF00800003FUH0000000d000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00QJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP@00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEP000007FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUIJEP02FUH0
1000FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF
0005FUH70007FUH00`00FUIJEP06FUH01000FUH000001UYF0`001EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUH005YF001JEP020005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002eoo`00;Goo00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH40002FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH0009JEP8000EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0000]Ool002eoo`04001JEUYFFUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP800003FUH005YF00=J
EP03001JEUYF00AJEP04001JEUYFFUH50006FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH015YF
00<005YFFUH010000UYF3@0015YF00<005YFFUH01UYF0`000eYF2000;Goo000]Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUH000020005FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00UYF2P0025YF00<005YFFUH00UYF1P001eYF00@005YFFUH000=JEP07001JEUYF
FUH005YF0000;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUH000050004FUH00`00FUIJEP02FUH;0007FUH00`00FUIJEP02
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<005YF00001P001UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP06FUH90002FUH50004
FUH20004FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEP000eYF1@000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0000=JEP00FUH01EYF0P000UYF0P00;goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006
FUH00`00FUIJEP04FUH80007FUH300000eYF001JEP05FUH00`00FUH00002000<FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1000<Goo000]Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH0000015YF00<005YFFUH01UYF00<005YFFUH010002EYF0P001EYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0015YF00<005YF0000<Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH@0006FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<005YFFUH015YF1P00
0eYF00@005YF000000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000Eoo`80009JEP04001JEUYF000aOol002eoo`8000AJEP03001JEUYF009J
EPH00003FUH005YF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00MJEP04001JEUYFFUH900000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000L000@Ool30003FUH00`00
Oomoo`0^Ool002eoo`8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<000EJEP03001JEUYF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP040003FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUH005YF00001UYF00<005YFFUH015YF00@005YFFUIJEP8001ioo`05001JEUYF
FUH0000`Ool002eoo`8000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH50006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP04FUH01@00FUIJEP00FUH087oo00@005YFFUH0031oo`00;Goo0P000UYF
0P000Woo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP05001JEUYFFUH00003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP03000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF0000
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`005Goo00D005YF001JEP0002moo`00;7oo
00<005YF00000P001Goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0P001goo1@005Goo0P0000=JEP00Ool0;Woo000/
Ool01@00FUH005YF00001goo0P000eYF00<005YFFUH01eYF10001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPL000=JEP07001J
EUYFFUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF008000Qoo`D001Ioo`03001JEP0002moo`00;7oo0P00
0eYF00<007ooOol01Woo0P0000=JEP00FUH01eYF1P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
10000eYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00X000aJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP800003FUH005YF00EJEP04001JEUYFFUH20008
Ool5000FOol00`00FUH0000_Ool002aoo`8000=JEP<000Qoo`@000IJEPH000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00004FUH30006FUH01000FUIJEUYF0P002Goo0`0067oo0P00;goo000/Ool20003FUH00`00FUIJ
EP02000:Ool40002FUH60003FUH00`00FUIJEP05FUH00`00FUH000030006Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH50004FUH00`00FUIJEP02000UOol2000_
Ool002aoo`8000=JEP03001JEUYF009JEP<000]oo`L000AJEP03001JEUYF009JEPD000Qoo`800003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH01@00FUIJEP00FUH0
0P0000=JEP00FUH00UYF0P009Goo0P00;goo000/Ool20003FUH00`00FUIJEP03FUH01000FUH00000
47oo2@002goo0P000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0004FUH50003FUH00`00Oomoo`0ROol3000`Ool002eoo`04001JEUYF0006FUH01000FUIJEUYF0`00
7Goo100000=JEP00FUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH015YF
5@002EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<000IJEPL0029oo`800003FUH0
0000031oo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEPD001=oo`D000EJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEP0000@0
021oo`8000=JEP03001oogoo02moo`00;Woo00<005YF00001UYF00<005YFFUH01EYF00@005YFFUIJ
EQ<000=JEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF
0P0015YF00@005YFFUIJEP<001eoo`<00003FUH005YF009JEP03001oogoo02moo`00;Woo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP@000IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP04001JEUYFFUH50002FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF
00@005YFFUH000MJEPH001Aoo`<000AJEP04001JEUYF000bOol002moo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8000=JEP03001JEUYF009JEP<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEP@000EJEP05001JEUYFFUH00005FUH30008FUH00`00FUIJEP02FUH90007Ool4
00000eYF001JEP04FUH00`00FUH0000cOol0031oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEPd000=JEP03001JEP000080009JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00@00003FUH005YF009JEPX000MJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF
00=JEP8003Aoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF2@00
0eYF00<005YFFUH015YF00<005YF00000eYF0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00<005YF0000
1UYF0`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
=Goo000cOol200000eYF001JEP06FUH00`00FUIJEP06FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH00002FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUH00007FUH00`00FUH0
000200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000gOol003Eo
o`<000IJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP000080
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000kOol003Qoo`L000=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0001<0041oo`00<goo1@000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH>
0003FUH01000FUIJEP00DWoo000^Ool500000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH@00001EYF001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP03001JEUYF00=JEP800003FUH005YF00@0009JEP80055oo`00;Woo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00@005YFFUIJEPH0
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH30002
FUH00`00FUH0000200000eYF001oo`1@Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000=JEP03001JEUYF00IJEP03001JEUYF009JEPL000Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH00`0000AJEP00Oomo
o`80055oo`00;Woo00<005YF00000eYF00@005YFFUIJEPP0009JEP03001JEUYF00IJEP03001JEUYF
009JEPT000eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000Woo00@005YF0000051oo`00;goo0P000UYF1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF2@005goo0`001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00@005YF
FUIJEP<0009oo`04001JEUYF001@Ool002moo`@00003FUH005YF00AJEP03001JEUYF009JEPP0029o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00Ool2
0002FUH00`00Oomoo`1>Ool002mooa0002aoo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF
00AJEP03001JEUYF00@00006Ool005YF001JEP00DGoo001]Ool200000eYF001JEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUH0000E0004Ool01000
FUIJEUYF0P00DGoo001_Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH5000HOol00`00FUIJEP02FUH00`00Oomoo`1@Ool007=oo`D0009JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00D00003Ool0000000<001Eoo`<000AJ
EP03001oogoo051oo`00N7oo20001UYF00<005YFFUH02UYF00<005YFFUH015YF2@001Woo1@004goo
0P000UYF00D005YFFUIJEP0005=oo`00P7oo6P003goo1@004Goo0P001EYF00<005YF0000E7oo002B
Ool01P00FUIJEP00FUH0019oo`<0011oo`8000MJEP8005Eoo`00TWoo00<005YFFUH00P0097oo0P00
00=JEP00FUH01UYF00<007ooOol0E7oo002BOol01000FUIJEP008Woo0`0015YF00<005YFFUH00UYF
0P00Egoo002COol2000POol30007FUH01@00FUIJEUYF0000FGoo002COol2000LOol400000eYF001J
EP08FUH3001JOol009=oo`04001JEP00000EOol50006FUH00`00FUIJEP05FUH2001LOol009=oo`80
009JEP<000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8005ioo`00U7oo00@005YFFUH0
009JEPh000IJEP03001JEUYF00MJEP03001JEP000080061oo`00U7oo00@005YFFUH000EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@006=oo`00UGoo0P0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000Igoo002GOol30004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001[Ool009Yoo`<00003FUH005YF00=JEPP0079oo`00WGoo1P00NWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5866 .73235 m .60456 .67807 L .57519 .66739 L p .707 .577 .707 r
F P
0 g
s
.60456 .67807 m .5866 .73235 L .61693 .74193 L p .707 .577 .707 r
F P
0 g
s
.61693 .74193 m .63489 .68765 L .60456 .67807 L p .707 .577 .707 r
F P
0 g
s
.63489 .68765 m .61693 .74193 L .64526 .74949 L p .707 .577 .707 r
F P
0 g
s
.64526 .74949 m .66322 .69521 L .63489 .68765 L p .707 .577 .707 r
F P
0 g
s
.55724 .72167 m .57519 .66739 L .54967 .65666 L p .707 .577 .707 r
F P
0 g
s
.57519 .66739 m .55724 .72167 L .5866 .73235 L p .707 .577 .707 r
F P
0 g
s
.54967 .65666 m .53171 .71095 L .55724 .72167 L p .707 .577 .707 r
F P
0 g
s
.66322 .69521 m .64526 .74949 L .66882 .75428 L p .707 .577 .707 r
F P
0 g
s
.66882 .75428 m .68678 .7 L .66322 .69521 L p .707 .577 .707 r
F P
0 g
s
.59025 .80241 m .59628 .76522 L .56554 .75896 L p .707 .577 .707 r
F P
0 g
s
.59628 .76522 m .59025 .80241 L .62171 .80675 L p .707 .577 .707 r
F P
0 g
s
.62171 .80675 m .62774 .76956 L .59628 .76522 L p .707 .577 .707 r
F P
0 g
s
.62774 .76956 m .62171 .80675 L .65081 .80875 L p .707 .577 .707 r
F P
0 g
s
.65081 .80875 m .65683 .77156 L .62774 .76956 L p .707 .577 .707 r
F P
0 g
s
.53171 .71095 m .54967 .65666 L .53049 .64694 L p .707 .577 .707 r
F P
0 g
s
.55951 .79616 m .56554 .75896 L .53852 .7514 L p .707 .577 .707 r
F P
0 g
s
.56554 .75896 m .55951 .79616 L .59025 .80241 L p .707 .577 .707 r
F P
0 g
s
.53049 .64694 m .51253 .70122 L .53171 .71095 L p .707 .577 .707 r
F P
0 g
s
.53852 .7514 m .53249 .7886 L .55951 .79616 L p .707 .577 .707 r
F P
0 g
s
.65683 .77156 m .65081 .80875 L .67469 .80822 L p .707 .577 .707 r
F P
0 g
s
.67469 .80822 m .68072 .77102 L .65683 .77156 L p .707 .577 .707 r
F P
0 g
s
.68678 .7 m .66882 .75428 L .68529 .75583 L p .707 .577 .707 r
F P
0 g
s
.68529 .75583 m .70325 .70154 L .68678 .7 L p .707 .577 .707 r
F P
0 g
s
.53249 .7886 m .53852 .7514 L .51788 .74328 L p .707 .577 .707 r
F P
0 g
s
.61669 .86041 m .61223 .84302 L .58165 .84764 L p .707 .577 .707 r
F P
0 g
s
.61223 .84302 m .61669 .86041 L .64752 .85204 L p .707 .577 .707 r
F P
0 g
s
.64752 .85204 m .64306 .83465 L .61223 .84302 L p .707 .577 .707 r
F P
0 g
s
.51253 .70122 m .53049 .64694 L .51952 .63918 L p .707 .577 .707 r
F P
0 g
s
.64306 .83465 m .64752 .85204 L .67559 .84074 L p .707 .577 .707 r
F P
0 g
s
.67559 .84074 m .67113 .82336 L .64306 .83465 L p .707 .577 .707 r
F P
0 g
s
.51788 .74328 m .51185 .78047 L .53249 .7886 L p .707 .577 .707 r
F P
0 g
s
.58165 .84764 m .58612 .86503 L .61669 .86041 L p .707 .577 .707 r
F P
0 g
s
.58612 .86503 m .58165 .84764 L .55433 .84807 L p .707 .577 .707 r
F P
0 g
s
.51952 .63918 m .50156 .69346 L .51253 .70122 L p .707 .577 .707 r
F P
0 g
s
.68072 .77102 m .67469 .80822 L .69103 .80519 L p .707 .577 .707 r
F P
0 g
s
.69103 .80519 m .69706 .768 L .68072 .77102 L p .707 .577 .707 r
F P
0 g
s
.67113 .82336 m .67559 .84074 L .69815 .82763 L p .707 .577 .707 r
F P
0 g
s
.69815 .82763 m .69369 .81024 L .67113 .82336 L p .707 .577 .707 r
F P
0 g
s
.55433 .84807 m .55879 .86545 L .58612 .86503 L p .707 .577 .707 r
F P
0 g
s
.51185 .78047 m .51788 .74328 L .50562 .73539 L p .707 .577 .707 r
F P
0 g
s
.70325 .70154 m .68529 .75583 L .69308 .75398 L p .707 .577 .707 r
F P
0 g
s
.69308 .75398 m .71103 .6997 L .70325 .70154 L p .707 .577 .707 r
F P
0 g
s
.55879 .86545 m .55433 .84807 L .53294 .84425 L p .707 .577 .707 r
F P
0 g
s
.50562 .73539 m .49959 .77258 L .51185 .78047 L p .707 .577 .707 r
F P
0 g
s
.69369 .81024 m .69815 .82763 L .713 .81397 L p .707 .577 .707 r
F P
0 g
s
.713 .81397 m .70854 .79658 L .69369 .81024 L p .707 .577 .707 r
F P
0 g
s
.50156 .69346 m .51952 .63918 L .51785 .63412 L p .707 .577 .707 r
F P
0 g
s
.53294 .84425 m .5374 .86164 L .55879 .86545 L p .707 .577 .707 r
F P
0 g
s
.51785 .63412 m .49989 .68841 L .50156 .69346 L p .707 .577 .707 r
F P
0 g
s
.69706 .768 m .69103 .80519 L .69822 .79998 L p .707 .577 .707 r
F P
0 g
s
.69822 .79998 m .70425 .76279 L .69706 .768 L p .707 .577 .707 r
F P
0 g
s
.49959 .77258 m .50562 .73539 L .50296 .7285 L p .707 .577 .707 r
F P
0 g
s
.5374 .86164 m .53294 .84425 L .51956 .83656 L p .707 .577 .707 r
F P
0 g
s
.71103 .6997 m .69308 .75398 L .6914 .74893 L p .707 .577 .707 r
F P
0 g
s
.6914 .74893 m .70936 .69465 L .71103 .6997 L p .707 .577 .707 r
F P
0 g
s
.50296 .7285 m .49693 .76569 L .49959 .77258 L p .707 .577 .707 r
F P
0 g
s
.70854 .79658 m .713 .81397 L .71868 .80112 L p .707 .577 .707 r
F P
0 g
s
.71868 .80112 m .71422 .78373 L .70854 .79658 L p .707 .577 .707 r
F P
0 g
s
.51956 .83656 m .52403 .85395 L .5374 .86164 L p .707 .577 .707 r
F P
0 g
s
.49989 .68841 m .51785 .63412 L .52563 .63228 L p .707 .577 .707 r
F P
0 g
s
.52563 .63228 m .50767 .68657 L .49989 .68841 L p .707 .577 .707 r
F P
0 g
s
.50767 .68657 m .52563 .63228 L .5421 .63383 L p .707 .577 .707 r
F P
0 g
s
.5421 .63383 m .52414 .68811 L .50767 .68657 L p .707 .577 .707 r
F P
0 g
s
.52403 .85395 m .51956 .83656 L .51552 .82576 L p .707 .577 .707 r
F P
0 g
s
.51552 .82576 m .51998 .84315 L .52403 .85395 L p .707 .577 .707 r
F P
0 g
s
.51998 .84315 m .51552 .82576 L .5212 .81291 L p .707 .577 .707 r
F P
0 g
s
.50412 .76048 m .51015 .72329 L .52649 .72027 L p .707 .577 .707 r
F P
0 g
s
.52649 .72027 m .52046 .75746 L .50412 .76048 L p .707 .577 .707 r
F P
0 g
s
.5199 .82155 m .5199 .31966 L .47477 .31944 L p .707 .577 .707 r
F P
0 g
s
.5212 .81291 m .52566 .8303 L .51998 .84315 L p .707 .577 .707 r
F P
0 g
s
.52414 .68811 m .5421 .63383 L .56566 .63862 L p .707 .577 .707 r
F P
0 g
s
.56566 .63862 m .5477 .6929 L .52414 .68811 L p .707 .577 .707 r
F P
0 g
s
.52566 .8303 m .5212 .81291 L .53605 .79925 L p .707 .577 .707 r
F P
0 g
s
.52046 .75746 m .52649 .72027 L .55038 .71973 L p .707 .577 .707 r
F P
0 g
s
.5477 .6929 m .56566 .63862 L .59399 .64617 L p .707 .577 .707 r
F P
0 g
s
.53605 .79925 m .54051 .81664 L .52566 .8303 L p .707 .577 .707 r
F P
0 g
s
.55038 .71973 m .54435 .75693 L .52046 .75746 L p .707 .577 .707 r
F P
0 g
s
.59399 .64617 m .57603 .70046 L .5477 .6929 L p .707 .577 .707 r
F P
0 g
s
.54435 .75693 m .55038 .71973 L .57947 .72173 L p .707 .577 .707 r
F P
0 g
s
.54051 .81664 m .53605 .79925 L .55861 .78614 L p .707 .577 .707 r
F P
0 g
s
.57947 .72173 m .57345 .75892 L .54435 .75693 L p .707 .577 .707 r
F P
0 g
s
.55861 .78614 m .56307 .80352 L .54051 .81664 L p .707 .577 .707 r
F P
0 g
s
.56307 .80352 m .55861 .78614 L .58668 .77484 L p .707 .577 .707 r
F P
0 g
s
.5199 .31966 m .5199 .82155 L .56307 .81803 L p .707 .577 .707 r
F P
0 g
s
.56307 .81803 m .56307 .31614 L .5199 .31966 L p .707 .577 .707 r
F P
0 g
s
.47477 .82133 m .47477 .31944 L .43212 .31548 L p .707 .577 .707 r
F P
0 g
s
.49693 .76569 m .50296 .7285 L .51015 .72329 L p .707 .577 .707 r
F P
0 g
s
.51015 .72329 m .50412 .76048 L .49693 .76569 L p .707 .577 .707 r
F P
0 g
s
.47477 .31944 m .47477 .82133 L .5199 .82155 L p .707 .577 .707 r
F P
0 g
s
.57603 .70046 m .59399 .64617 L .62432 .65576 L p .707 .577 .707 r
F P
0 g
s
.62432 .65576 m .60636 .71004 L .57603 .70046 L p .707 .577 .707 r
F P
0 g
s
.57345 .75892 m .57947 .72173 L .61093 .72607 L p .707 .577 .707 r
F P
0 g
s
.61093 .72607 m .6049 .76326 L .57345 .75892 L p .707 .577 .707 r
F P
0 g
s
.58668 .77484 m .59114 .79223 L .56307 .80352 L p .707 .577 .707 r
F P
0 g
s
.59114 .79223 m .58668 .77484 L .61751 .76647 L p .707 .577 .707 r
F P
0 g
s
.61751 .76647 m .62198 .78386 L .59114 .79223 L p .707 .577 .707 r
F P
0 g
s
.56307 .31614 m .56307 .81803 L .60007 .81109 L p .707 .577 .707 r
F P
0 g
s
.60007 .81109 m .60007 .30921 L .56307 .31614 L p .707 .577 .707 r
F P
0 g
s
.70425 .76279 m .69822 .79998 L .69556 .7931 L p .707 .577 .707 r
F P
0 g
s
.69556 .7931 m .70159 .7559 L .70425 .76279 L p .707 .577 .707 r
F P
0 g
s
.43212 .81737 m .43212 .31548 L .39611 .30818 L p .707 .577 .707 r
F P
0 g
s
.43212 .31548 m .43212 .81737 L .47477 .82133 L p .707 .577 .707 r
F P
0 g
s
.70936 .69465 m .6914 .74893 L .68044 .74117 L p .707 .577 .707 r
F P
0 g
s
.68044 .74117 m .69839 .68689 L .70936 .69465 L p .707 .577 .707 r
F P
0 g
s
.71422 .78373 m .71868 .80112 L .71464 .79032 L p .707 .577 .707 r
F P
0 g
s
.71464 .79032 m .71018 .77293 L .71422 .78373 L p .707 .577 .707 r
F P
0 g
s
.24858 .73802 m .25642 .69069 L .22566 .68292 L p .707 .577 .707 r
F P
0 g
s
.25642 .69069 m .24858 .73802 L .28016 .7403 L p .707 .577 .707 r
F P
0 g
s
.28016 .7403 m .288 .69297 L .25642 .69069 L p .707 .577 .707 r
F P
0 g
s
.21782 .73025 m .22566 .68292 L .19875 .67041 L p .707 .577 .707 r
F P
0 g
s
.22566 .68292 m .21782 .73025 L .24858 .73802 L p .707 .577 .707 r
F P
0 g
s
.288 .69297 m .28016 .7403 L .30949 .73686 L p .707 .577 .707 r
F P
0 g
s
.30949 .73686 m .31733 .68953 L .288 .69297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.65369 .66644 m .63573 .72072 L .60636 .71004 L p .707 .577 .707 r
F P
0 g
s
.60636 .71004 m .62432 .65576 L .65369 .66644 L p .707 .577 .707 r
F P
0 g
s
.64168 .73232 m .63565 .76952 L .6049 .76326 L p .707 .577 .707 r
F P
0 g
s
.6049 .76326 m .61093 .72607 L .64168 .73232 L p .707 .577 .707 r
F P
0 g
s
.66869 .73988 m .66266 .77708 L .63565 .76952 L p .707 .577 .707 r
F P
0 g
s
.64809 .76185 m .65255 .77924 L .62198 .78386 L p .707 .577 .707 r
F P
0 g
s
.63565 .76952 m .64168 .73232 L .66869 .73988 L p .707 .577 .707 r
F P
0 g
s
.62198 .78386 m .61751 .76647 L .64809 .76185 L p .707 .577 .707 r
F P
0 g
s
.60007 .30921 m .60007 .81109 L .62728 .80143 L p .707 .577 .707 r
F P
0 g
s
.62728 .80143 m .62728 .29954 L .60007 .30921 L p .707 .577 .707 r
F P
0 g
s
.39611 .81007 m .39611 .30818 L .37027 .29825 L p .707 .577 .707 r
F P
0 g
s
.39611 .30818 m .39611 .81007 L .43212 .81737 L p .707 .577 .707 r
F P
0 g
s
.70159 .7559 m .69556 .7931 L .68331 .7852 L p .707 .577 .707 r
F P
0 g
s
.68331 .7852 m .68934 .74801 L .70159 .7559 L p .707 .577 .707 r
F P
0 g
s
.19091 .71774 m .19875 .67041 L .17832 .65439 L p .707 .577 .707 r
F P
0 g
s
.19875 .67041 m .19091 .71774 L .21782 .73025 L p .707 .577 .707 r
F P
0 g
s
.31733 .68953 m .30949 .73686 L .33368 .72804 L p .707 .577 .707 r
F P
0 g
s
.33368 .72804 m .34152 .68071 L .31733 .68953 L p .707 .577 .707 r
F P
0 g
s
.26506 .79671 m .26309 .7776 L .23178 .78055 L p .707 .577 .707 r
F P
0 g
s
.26309 .7776 m .26506 .79671 L .29655 .79326 L p .707 .577 .707 r
F P
0 g
s
.29655 .79326 m .29458 .77415 L .26309 .7776 L p .707 .577 .707 r
F P
0 g
s
.23178 .78055 m .23375 .79966 L .26506 .79671 L p .707 .577 .707 r
F P
0 g
s
.69839 .68689 m .68044 .74117 L .66125 .73145 L p .707 .577 .707 r
F P
0 g
s
.66125 .73145 m .67921 .67716 L .69839 .68689 L p .707 .577 .707 r
F P
0 g
s
.25062 .78601 m .25322 .75112 L .22213 .74623 L p .707 .577 .707 r
F P
0 g
s
.25322 .75112 m .25062 .78601 L .28239 .78679 L p .707 .577 .707 r
F P
0 g
s
.28239 .78679 m .28499 .75189 L .25322 .75112 L p .707 .577 .707 r
F P
0 g
s
.29458 .77415 m .29655 .79326 L .32515 .78965 L p .707 .577 .707 r
F P
0 g
s
.32515 .78965 m .32318 .77054 L .29458 .77415 L p .707 .577 .707 r
F P
0 g
s
.71018 .77293 m .71464 .79032 L .70126 .78263 L p .707 .577 .707 r
F P
0 g
s
.70126 .78263 m .6968 .76525 L .71018 .77293 L p .707 .577 .707 r
F P
0 g
s
.23375 .79966 m .23178 .78055 L .20372 .78272 L p .707 .577 .707 r
F P
0 g
s
.20372 .78272 m .20569 .80183 L .23375 .79966 L p .707 .577 .707 r
F P
0 g
s
.28499 .75189 m .28239 .78679 L .31173 .78337 L p .707 .577 .707 r
F P
0 g
s
.31173 .78337 m .31433 .74848 L .28499 .75189 L p .707 .577 .707 r
F P
0 g
s
.21953 .78112 m .22213 .74623 L .19477 .7377 L p .707 .577 .707 r
F P
0 g
s
.22213 .74623 m .21953 .78112 L .25062 .78601 L p .707 .577 .707 r
F P
0 g
s
.17047 .70172 m .17832 .65439 L .16636 .63643 L p .707 .577 .707 r
F P
0 g
s
.17832 .65439 m .17047 .70172 L .19091 .71774 L p .707 .577 .707 r
F P
0 g
s
.34152 .68071 m .33368 .72804 L .35037 .7147 L p .707 .577 .707 r
F P
0 g
s
.35037 .7147 m .35822 .66737 L .34152 .68071 L p .707 .577 .707 r
F P
0 g
s
.32318 .77054 m .32515 .78965 L .34805 .78623 L p .707 .577 .707 r
F P
0 g
s
.34805 .78623 m .34608 .76712 L .32318 .77054 L p .707 .577 .707 r
F P
0 g
s
.31433 .74848 m .31173 .78337 L .33578 .77611 L p .707 .577 .707 r
F P
0 g
s
.33578 .77611 m .33837 .74122 L .31433 .74848 L p .707 .577 .707 r
F P
0 g
s
.67921 .67716 m .66125 .73145 L .63573 .72072 L p .707 .577 .707 r
F P
0 g
s
.63573 .72072 m .65369 .66644 L .67921 .67716 L p .707 .577 .707 r
F P
0 g
s
.62728 .29954 m .62728 .80143 L .64202 .78999 L p .707 .577 .707 r
F P
0 g
s
.64202 .78999 m .64202 .2881 L .62728 .29954 L p .707 .577 .707 r
F P
0 g
s
.68934 .74801 m .68331 .7852 L .66266 .77708 L p .707 .577 .707 r
F P
0 g
s
.66266 .77708 m .66869 .73988 L .68934 .74801 L p .707 .577 .707 r
F P
0 g
s
.20569 .80183 m .20372 .78272 L .18166 .78388 L p .707 .577 .707 r
F P
0 g
s
.18166 .78388 m .18363 .80299 L .20569 .80183 L p .707 .577 .707 r
F P
0 g
s
.19218 .77259 m .19477 .7377 L .17382 .72637 L p .707 .577 .707 r
F P
0 g
s
.19477 .7377 m .19218 .77259 L .21953 .78112 L p .707 .577 .707 r
F P
0 g
s
.37027 .80014 m .37027 .29825 L .35713 .28667 L p .707 .577 .707 r
F P
0 g
s
.37027 .29825 m .37027 .80014 L .39611 .81007 L p .707 .577 .707 r
F P
0 g
s
.6968 .76525 m .70126 .78263 L .67987 .77882 L p .707 .577 .707 r
F P
0 g
s
.67987 .77882 m .67541 .76143 L .6968 .76525 L p .707 .577 .707 r
F P
0 g
s
.15851 .68376 m .16636 .63643 L .16404 .61829 L p .707 .577 .707 r
F P
0 g
s
.16636 .63643 m .15851 .68376 L .17047 .70172 L p .707 .577 .707 r
F P
0 g
s
.35822 .66737 m .35488 .68751 L p .35794 .69815 L .707 .577 .707 r
F P
0 g
s
.35545 .70359 m .35794 .69815 L p .35488 .68751 L .707 .577 .707 r
F P
0 g
s
.35477 .7308 m .35217 .7657 L .3593 .75316 L p .707 .577 .707 r
F P
0 g
s
.3593 .75316 m .3619 .71827 L .35477 .7308 L p .707 .577 .707 r
F P
0 g
s
.35794 .69815 m .36578 .65082 L .35822 .66737 L p .707 .577 .707 r
F P
0 g
s
.36578 .65082 m .35794 .69815 L .35608 .68362 L p .707 .577 .707 r
F P
0 g
s
.35608 .68362 m .35562 .68001 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35615 .67849 m .36578 .65082 L .35608 .68362 L .707 .577 .707 r
F
.34608 .76712 m .34805 .78623 L .36302 .78334 L p F P
0 g
s
.36302 .78334 m .36105 .76423 L .34608 .76712 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .36578 .65082 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35562 .68001 m .35617 .67669 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35617 .67669 m .36347 .63268 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.36105 .76423 m .36302 .78334 L .36858 .78126 L p .707 .577 .707 r
F P
0 g
s
.36858 .78126 m .36661 .76216 L .36105 .76423 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .35562 .68001 L .34366 .66205 L p .707 .577 .707 r
F P
0 g
s
.34366 .66205 m .35151 .61472 L .36347 .63268 L p .707 .577 .707 r
F P
0 g
s
.3619 .71827 m .3593 .75316 L .35649 .73972 L p .707 .577 .707 r
F P
0 g
s
.35649 .73972 m .35908 .70483 L .3619 .71827 L p .707 .577 .707 r
F P
0 g
s
.36661 .76216 m .36858 .78126 L .3642 .7802 L p .707 .577 .707 r
F P
0 g
s
.3642 .7802 m .36223 .76109 L .36661 .76216 L p .707 .577 .707 r
F P
0 g
s
.35217 .7657 m .35477 .7308 L .33837 .74122 L p .707 .577 .707 r
F P
0 g
s
.35908 .70483 m .35649 .73972 L .34399 .72671 L p .707 .577 .707 r
F P
0 g
s
.35488 .68751 m .35037 .7147 L .35545 .70359 L p .707 .577 .707 r
F P
0 g
s
.34399 .72671 m .34658 .69182 L .35908 .70483 L p .707 .577 .707 r
F P
0 g
s
.36223 .76109 m .3642 .7802 L .35029 .78025 L p .707 .577 .707 r
F P
0 g
s
.33837 .74122 m .33578 .77611 L .35217 .7657 L p .707 .577 .707 r
F P
0 g
s
.35029 .78025 m .34832 .76114 L .36223 .76109 L p .707 .577 .707 r
F P
0 g
s
.35713 .28667 m .35713 .78856 L .37027 .80014 L p .707 .577 .707 r
F P
0 g
s
.35713 .75115 m .35713 .60146 L .35719 .75281 L .707 .577 .707 r
F
.35713 .60146 m .35713 .28667 L p .35717 .59839 L F P
0 g
s
.35713 .60146 m .35717 .59839 L .35719 .75281 L .707 .577 .707 r
F
.35713 .28667 m .35798 .27456 L p .35748 .57385 L F P
0 g
s
.35719 .75281 m .35717 .59839 L .35748 .57385 L .707 .577 .707 r
F
.35717 .59839 m .35713 .28667 L .35748 .57385 L F
.35713 .78856 m .35713 .75115 L p .35719 .75281 L F P
0 g
s
.17382 .72637 m .17122 .76126 L .19218 .77259 L p .707 .577 .707 r
F P
0 g
s
.18363 .80299 m .18166 .78388 L .16776 .78394 L p .707 .577 .707 r
F P
0 g
s
.17122 .76126 m .17382 .72637 L .16132 .71336 L p .707 .577 .707 r
F P
0 g
s
.16776 .78394 m .16973 .80305 L .18363 .80299 L p .707 .577 .707 r
F P
0 g
s
.67541 .76143 m .67987 .77882 L .65255 .77924 L p .707 .577 .707 r
F P
0 g
s
.65255 .77924 m .64809 .76185 L .67541 .76143 L p .707 .577 .707 r
F P
0 g
s
.64202 .2881 m .64202 .78999 L .64287 .77788 L p .707 .577 .707 r
F P
0 g
s
.64287 .77788 m .64287 .27599 L .64202 .2881 L p .707 .577 .707 r
F P
0 g
s
.16132 .71336 m .15872 .74825 L .17122 .76126 L p .707 .577 .707 r
F P
0 g
s
.16404 .61829 m .1562 .66562 L .15851 .68376 L p .707 .577 .707 r
F P
0 g
s
.1562 .66562 m .16404 .61829 L .1716 .60174 L p .707 .577 .707 r
F P
0 g
s
.15872 .74825 m .16132 .71336 L .1585 .69992 L p .707 .577 .707 r
F P
0 g
s
.16973 .80305 m .16776 .78394 L .16337 .78287 L p .707 .577 .707 r
F P
0 g
s
.16337 .78287 m .16534 .80198 L .16973 .80305 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1585 .69992 m .1559 .73481 L .15872 .74825 L p .707 .577 .707 r
F P
0 g
s
.16376 .64907 m .1716 .60174 L .1883 .5884 L p .707 .577 .707 r
F P
0 g
s
.1716 .60174 m .16376 .64907 L .1562 .66562 L p .707 .577 .707 r
F P
0 g
s
.1559 .73481 m .1585 .69992 L .16564 .68738 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.64287 .27599 m .64287 .77788 L .62972 .76629 L p .707 .577 .707 r
F P
0 g
s
.62972 .76629 m .62972 .26441 L .64287 .27599 L p .707 .577 .707 r
F P
0 g
s
.16534 .80198 m .16337 .78287 L .16894 .78079 L p .707 .577 .707 r
F P
0 g
s
.16894 .78079 m .17091 .7999 L .16534 .80198 L p .707 .577 .707 r
F P
0 g
s
.35798 .77645 m .35798 .27456 L .37272 .26312 L p .707 .577 .707 r
F P
0 g
s
.35798 .27456 m .35798 .77645 L .35713 .78856 L p .707 .577 .707 r
F P
0 g
s
.1883 .5884 m .18045 .63573 L .16376 .64907 L p .707 .577 .707 r
F P
0 g
s
.18045 .63573 m .1883 .5884 L .21249 .57958 L p .707 .577 .707 r
F P
0 g
s
.35151 .61472 m .34366 .66205 L .32323 .64603 L p .707 .577 .707 r
F P
0 g
s
.32323 .64603 m .33107 .5987 L .35151 .61472 L p .707 .577 .707 r
F P
0 g
s
.16564 .68738 m .16304 .72228 L .1559 .73481 L p .707 .577 .707 r
F P
0 g
s
.16304 .72228 m .16564 .68738 L .18203 .67697 L p .707 .577 .707 r
F P
0 g
s
.20465 .62691 m .21249 .57958 L .24182 .57614 L p .707 .577 .707 r
F P
0 g
s
.21249 .57958 m .20465 .62691 L .18045 .63573 L p .707 .577 .707 r
F P
0 g
s
.33107 .5987 m .32323 .64603 L .29631 .63352 L p .707 .577 .707 r
F P
0 g
s
.29631 .63352 m .30416 .5862 L .33107 .5987 L p .707 .577 .707 r
F P
0 g
s
.17091 .7999 m .16894 .78079 L .1839 .7779 L p .707 .577 .707 r
F P
0 g
s
.1839 .7779 m .18587 .79701 L .17091 .7999 L p .707 .577 .707 r
F P
0 g
s
.18203 .67697 m .17943 .71186 L .16304 .72228 L p .707 .577 .707 r
F P
0 g
s
.23397 .62347 m .24182 .57614 L .2734 .57842 L p .707 .577 .707 r
F P
0 g
s
.24182 .57614 m .23397 .62347 L .20465 .62691 L p .707 .577 .707 r
F P
0 g
s
.30416 .5862 m .29631 .63352 L .26556 .62575 L p .707 .577 .707 r
F P
0 g
s
.26556 .62575 m .2734 .57842 L .30416 .5862 L p .707 .577 .707 r
F P
0 g
s
.62972 .26441 m .62972 .76629 L .60388 .75637 L p .707 .577 .707 r
F P
0 g
s
.60388 .75637 m .60388 .25448 L .62972 .26441 L p .707 .577 .707 r
F P
0 g
s
.34658 .69182 m .34399 .72671 L .32303 .71538 L p .707 .577 .707 r
F P
0 g
s
.32303 .71538 m .32563 .68049 L .34658 .69182 L p .707 .577 .707 r
F P
0 g
s
.2734 .57842 m .26556 .62575 L .23397 .62347 L p .707 .577 .707 r
F P
0 g
s
.37272 .76501 m .37272 .26312 L .39993 .25345 L p .707 .577 .707 r
F P
0 g
s
.37272 .26312 m .37272 .76501 L .35798 .77645 L p .707 .577 .707 r
F P
0 g
s
.17943 .71186 m .18203 .67697 L .20607 .66971 L p .707 .577 .707 r
F P
0 g
s
.34832 .76114 m .35029 .78025 L .32824 .78142 L p .707 .577 .707 r
F P
0 g
s
.32824 .78142 m .32627 .76231 L .34832 .76114 L p .707 .577 .707 r
F P
0 g
s
.18587 .79701 m .1839 .7779 L .20681 .77449 L p .707 .577 .707 r
F P
0 g
s
.20681 .77449 m .20878 .79359 L .18587 .79701 L p .707 .577 .707 r
F P
0 g
s
.32563 .68049 m .32303 .71538 L .29567 .70685 L p .707 .577 .707 r
F P
0 g
s
.29567 .70685 m .29827 .67196 L .32563 .68049 L p .707 .577 .707 r
F P
0 g
s
.20607 .66971 m .20348 .7046 L .17943 .71186 L p .707 .577 .707 r
F P
0 g
s
.20348 .7046 m .20607 .66971 L .23542 .66629 L p .707 .577 .707 r
F P
0 g
s
.69584 .57356 m .70368 .63064 L .73444 .62603 L p .707 .577 .707 r
F P
0 g
s
.73444 .62603 m .72659 .56894 L .69584 .57356 L p .707 .577 .707 r
F P
0 g
s
.72659 .56894 m .73444 .62603 L .76602 .62182 L p .707 .577 .707 r
F P
0 g
s
.60388 .25448 m .60388 .75637 L .56788 .74907 L p .707 .577 .707 r
F P
0 g
s
.56788 .74907 m .56788 .24718 L .60388 .25448 L p .707 .577 .707 r
F P
0 g
s
.76602 .62182 m .75818 .56474 L .72659 .56894 L p .707 .577 .707 r
F P
0 g
s
.75818 .56474 m .76602 .62182 L .79535 .61843 L p .707 .577 .707 r
F P
0 g
s
.32627 .76231 m .32824 .78142 L .30018 .78358 L p .707 .577 .707 r
F P
0 g
s
.30018 .78358 m .29821 .76447 L .32627 .76231 L p .707 .577 .707 r
F P
0 g
s
.29827 .67196 m .29567 .70685 L .26459 .70196 L p .707 .577 .707 r
F P
0 g
s
.26459 .70196 m .26719 .66707 L .29827 .67196 L p .707 .577 .707 r
F P
0 g
s
.39993 .25345 m .39993 .75534 L .37272 .76501 L p .707 .577 .707 r
F P
0 g
s
.39993 .75534 m .39993 .25345 L .43693 .24652 L p .707 .577 .707 r
F P
0 g
s
.23282 .70119 m .23542 .66629 L .26719 .66707 L p .707 .577 .707 r
F P
0 g
s
.23542 .66629 m .23282 .70119 L .20348 .7046 L p .707 .577 .707 r
F P
0 g
s
.79535 .61843 m .78751 .56135 L .75818 .56474 L p .707 .577 .707 r
F P
0 g
s
.20878 .79359 m .20681 .77449 L .2354 .77087 L p .707 .577 .707 r
F P
0 g
s
.2354 .77087 m .23737 .78998 L .20878 .79359 L p .707 .577 .707 r
F P
0 g
s
.66893 .57812 m .67677 .63521 L .70368 .63064 L p .707 .577 .707 r
F P
0 g
s
.70368 .63064 m .69584 .57356 L .66893 .57812 L p .707 .577 .707 r
F P
0 g
s
.26719 .66707 m .26459 .70196 L .23282 .70119 L p .707 .577 .707 r
F P
0 g
s
.73541 .70366 m .73281 .66553 L .70173 .66681 L p .707 .577 .707 r
F P
0 g
s
.73281 .66553 m .73541 .70366 L .76718 .7012 L p .707 .577 .707 r
F P
0 g
s
.76718 .7012 m .76458 .66307 L .73281 .66553 L p .707 .577 .707 r
F P
0 g
s
.78751 .56135 m .79535 .61843 L .81954 .61619 L p .707 .577 .707 r
F P
0 g
s
.76458 .66307 m .76718 .7012 L .79652 .69781 L p .707 .577 .707 r
F P
0 g
s
.79652 .69781 m .79392 .65968 L .76458 .66307 L p .707 .577 .707 r
F P
0 g
s
.81954 .61619 m .8117 .55911 L .78751 .56135 L p .707 .577 .707 r
F P
0 g
s
.29821 .76447 m .30018 .78358 L .26887 .78653 L p .707 .577 .707 r
F P
0 g
s
.26887 .78653 m .2669 .76742 L .29821 .76447 L p .707 .577 .707 r
F P
0 g
s
.70173 .66681 m .70432 .70494 L .73541 .70366 L p .707 .577 .707 r
F P
0 g
s
.23737 .78998 m .2354 .77087 L .2669 .76742 L p .707 .577 .707 r
F P
0 g
s
.2669 .76742 m .26887 .78653 L .23737 .78998 L p .707 .577 .707 r
F P
0 g
s
.70432 .70494 m .70173 .66681 L .67437 .66679 L p .707 .577 .707 r
F P
0 g
s
.64849 .58219 m .65633 .63928 L .67677 .63521 L p .707 .577 .707 r
F P
0 g
s
.67677 .63521 m .66893 .57812 L .64849 .58219 L p .707 .577 .707 r
F P
0 g
s
.67437 .66679 m .67697 .70491 L .70432 .70494 L p .707 .577 .707 r
F P
0 g
s
.56788 .24718 m .56788 .74907 L .52522 .74511 L p .707 .577 .707 r
F P
0 g
s
.52522 .74511 m .52522 .24322 L .56788 .24718 L p .707 .577 .707 r
F P
0 g
s
.79392 .65968 m .79652 .69781 L .82057 .69381 L p .707 .577 .707 r
F P
0 g
s
.82057 .69381 m .81797 .65568 L .79392 .65968 L p .707 .577 .707 r
F P
0 g
s
.43693 .74841 m .43693 .24652 L .4801 .24299 L p .707 .577 .707 r
F P
0 g
s
.43693 .24652 m .43693 .74841 L .39993 .75534 L p .707 .577 .707 r
F P
0 g
s
.8117 .55911 m .81954 .61619 L .83624 .61532 L p .707 .577 .707 r
F P
0 g
s
.67697 .70491 m .67437 .66679 L .65341 .66546 L p .707 .577 .707 r
F P
0 g
s
.83624 .61532 m .82839 .55823 L .8117 .55911 L p .707 .577 .707 r
F P
0 g
s
.52522 .24322 m .52522 .74511 L .4801 .74488 L p .707 .577 .707 r
F P
0 g
s
.4801 .74488 m .4801 .24299 L .52522 .24322 L p .707 .577 .707 r
F P
0 g
s
.4801 .24299 m .4801 .74488 L .43693 .74841 L p .707 .577 .707 r
F P
0 g
s
.65341 .66546 m .65601 .70359 L .67697 .70491 L p .707 .577 .707 r
F P
0 g
s
.63653 .58537 m .64437 .64246 L .65633 .63928 L p .707 .577 .707 r
F P
0 g
s
.65633 .63928 m .64849 .58219 L .63653 .58537 L p .707 .577 .707 r
F P
0 g
s
.81797 .65568 m .82057 .69381 L .83696 .68959 L p .707 .577 .707 r
F P
0 g
s
.83696 .68959 m .83436 .65146 L .81797 .65568 L p .707 .577 .707 r
F P
0 g
s
.73113 .77603 m .7331 .7592 L .70179 .75371 L p .707 .577 .707 r
F P
0 g
s
.7331 .7592 m .73113 .77603 L .76262 .77679 L p .707 .577 .707 r
F P
0 g
s
.76262 .77679 m .76459 .75996 L .7331 .7592 L p .707 .577 .707 r
F P
0 g
s
.69982 .77054 m .70179 .75371 L .67373 .74401 L p .707 .577 .707 r
F P
0 g
s
.70179 .75371 m .69982 .77054 L .73113 .77603 L p .707 .577 .707 r
F P
0 g
s
.76459 .75996 m .76262 .77679 L .79122 .77274 L p .707 .577 .707 r
F P
0 g
s
.79122 .77274 m .79319 .7559 L .76459 .75996 L p .707 .577 .707 r
F P
0 g
s
.65601 .70359 m .65341 .66546 L .64092 .66296 L p .707 .577 .707 r
F P
0 g
s
.82839 .55823 m .83624 .61532 L .8438 .6159 L p .707 .577 .707 r
F P
0 g
s
.8438 .6159 m .83596 .55881 L .82839 .55823 L p .707 .577 .707 r
F P
0 g
s
.67373 .74401 m .67176 .76084 L .69982 .77054 L p .707 .577 .707 r
F P
0 g
s
.64092 .66296 m .64351 .70109 L .65601 .70359 L p .707 .577 .707 r
F P
0 g
s
.67176 .76084 m .67373 .74401 L .65167 .73107 L p .707 .577 .707 r
F P
0 g
s
.79319 .7559 m .79122 .77274 L .81413 .76427 L p .707 .577 .707 r
F P
0 g
s
.81413 .76427 m .8161 .74744 L .79319 .7559 L p .707 .577 .707 r
F P
0 g
s
.83436 .65146 m .83696 .68959 L .8441 .68558 L p .707 .577 .707 r
F P
0 g
s
.8441 .68558 m .8415 .64745 L .83436 .65146 L p .707 .577 .707 r
F P
0 g
s
.63422 .58735 m .64206 .64443 L .64437 .64246 L p .707 .577 .707 r
F P
0 g
s
.64437 .64246 m .63653 .58537 L .63422 .58735 L p .707 .577 .707 r
F P
0 g
s
.65167 .73107 m .6497 .7479 L .67176 .76084 L p .707 .577 .707 r
F P
0 g
s
.6497 .7479 m .65167 .73107 L .63777 .71614 L p .707 .577 .707 r
F P
0 g
s
.64351 .70109 m .64092 .66296 L .6381 .65954 L p .707 .577 .707 r
F P
0 g
s
.8161 .74744 m .81413 .76427 L .82909 .75222 L p .707 .577 .707 r
F P
0 g
s
.82909 .75222 m .83106 .73538 L .8161 .74744 L p .707 .577 .707 r
F P
0 g
s
.83596 .55881 m .8438 .6159 L .84149 .61788 L p .707 .577 .707 r
F P
0 g
s
.6381 .65954 m .64069 .69767 L .64351 .70109 L p .707 .577 .707 r
F P
0 g
s
.84149 .61788 m .83364 .56079 L .83596 .55881 L p .707 .577 .707 r
F P
0 g
s
.63777 .71614 m .6358 .73297 L .6497 .7479 L p .707 .577 .707 r
F P
0 g
s
.8415 .64745 m .8441 .68558 L .84128 .68215 L p .707 .577 .707 r
F P
0 g
s
.84128 .68215 m .83868 .64402 L .8415 .64745 L p .707 .577 .707 r
F P
0 g
s
.64178 .58793 m .64962 .64501 L .64206 .64443 L p .707 .577 .707 r
F P
0 g
s
.64206 .64443 m .63422 .58735 L .64178 .58793 L p .707 .577 .707 r
F P
0 g
s
.6358 .73297 m .63777 .71614 L .63339 .70069 L p .707 .577 .707 r
F P
0 g
s
.83106 .73538 m .82909 .75222 L .83465 .73776 L p .707 .577 .707 r
F P
0 g
s
.83465 .73776 m .83662 .72093 L .83106 .73538 L p .707 .577 .707 r
F P
0 g
s
.63339 .70069 m .63142 .71753 L .6358 .73297 L p .707 .577 .707 r
F P
0 g
s
.64069 .69767 m .6381 .65954 L .64523 .65552 L p .707 .577 .707 r
F P
0 g
s
.83364 .56079 m .84149 .61788 L .82953 .62106 L p .707 .577 .707 r
F P
0 g
s
.42397 .6239 m .40601 .57343 L .37568 .58326 L p .707 .577 .707 r
F P
0 g
s
.40601 .57343 m .42397 .6239 L .4523 .61085 L p .707 .577 .707 r
F P
0 g
s
.4523 .61085 m .43434 .56038 L .40601 .57343 L p .707 .577 .707 r
F P
0 g
s
.64523 .65552 m .64783 .69365 L .64069 .69767 L p .707 .577 .707 r
F P
0 g
s
.82953 .62106 m .82168 .56397 L .83364 .56079 L p .707 .577 .707 r
F P
0 g
s
.39363 .63373 m .37568 .58326 L .34631 .58892 L p .707 .577 .707 r
F P
0 g
s
.37568 .58326 m .39363 .63373 L .42397 .6239 L p .707 .577 .707 r
F P
0 g
s
.43434 .56038 m .4523 .61085 L .47585 .59586 L p .707 .577 .707 r
F P
0 g
s
.47585 .59586 m .45789 .54539 L .43434 .56038 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83868 .64402 m .84128 .68215 L .82878 .67965 L p .707 .577 .707 r
F P
0 g
s
.82878 .67965 m .82618 .64152 L .83868 .64402 L p .707 .577 .707 r
F P
0 g
s
.36427 .63939 m .34631 .58892 L .32079 .58984 L p .707 .577 .707 r
F P
0 g
s
.34631 .58892 m .36427 .63939 L .39363 .63373 L p .707 .577 .707 r
F P
0 g
s
.63142 .71753 m .63339 .70069 L .63895 .68624 L p .707 .577 .707 r
F P
0 g
s
.65847 .58706 m .66632 .64414 L .64962 .64501 L p .707 .577 .707 r
F P
0 g
s
.64962 .64501 m .64178 .58793 L .65847 .58706 L p .707 .577 .707 r
F P
0 g
s
.83662 .72093 m .83465 .73776 L .83027 .72231 L p .707 .577 .707 r
F P
0 g
s
.83027 .72231 m .83224 .70548 L .83662 .72093 L p .707 .577 .707 r
F P
0 g
s
.45789 .54539 m .47585 .59586 L .49233 .58039 L p .707 .577 .707 r
F P
0 g
s
.49233 .58039 m .47437 .52992 L .45789 .54539 L p .707 .577 .707 r
F P
0 g
s
.63895 .68624 m .63698 .70307 L .63142 .71753 L p .707 .577 .707 r
F P
0 g
s
.39509 .68772 m .38906 .65189 L .35832 .65407 L p .707 .577 .707 r
F P
0 g
s
.38906 .65189 m .39509 .68772 L .42655 .68212 L p .707 .577 .707 r
F P
0 g
s
.42655 .68212 m .42052 .64628 L .38906 .65189 L p .707 .577 .707 r
F P
0 g
s
.42052 .64628 m .42655 .68212 L .45565 .67364 L p .707 .577 .707 r
F P
0 g
s
.45565 .67364 m .44962 .63781 L .42052 .64628 L p .707 .577 .707 r
F P
0 g
s
.64783 .69365 m .64523 .65552 L .66162 .6513 L p .707 .577 .707 r
F P
0 g
s
.82168 .56397 m .82953 .62106 L .80909 .62513 L p .707 .577 .707 r
F P
0 g
s
.80909 .62513 m .80125 .56804 L .82168 .56397 L p .707 .577 .707 r
F P
0 g
s
.37802 .71327 m .38248 .69482 L .35191 .68667 L p .707 .577 .707 r
F P
0 g
s
.38248 .69482 m .37802 .71327 L .40885 .71984 L p .707 .577 .707 r
F P
0 g
s
.40885 .71984 m .41331 .70139 L .38248 .69482 L p .707 .577 .707 r
F P
0 g
s
.66162 .6513 m .66422 .68943 L .64783 .69365 L p .707 .577 .707 r
F P
0 g
s
.33874 .64031 m .32079 .58984 L .3016 .58593 L p .707 .577 .707 r
F P
0 g
s
.32079 .58984 m .33874 .64031 L .36427 .63939 L p .707 .577 .707 r
F P
0 g
s
.36435 .6899 m .35832 .65407 L .33131 .65262 L p .707 .577 .707 r
F P
0 g
s
.35832 .65407 m .36435 .6899 L .39509 .68772 L p .707 .577 .707 r
F P
0 g
s
.35191 .68667 m .34745 .70512 L .37802 .71327 L p .707 .577 .707 r
F P
0 g
s
.44962 .63781 m .45565 .67364 L .47954 .66312 L p .707 .577 .707 r
F P
0 g
s
.47954 .66312 m .47351 .62729 L .44962 .63781 L p .707 .577 .707 r
F P
0 g
s
.34745 .70512 m .35191 .68667 L .32459 .67773 L p .707 .577 .707 r
F P
0 g
s
.41331 .70139 m .40885 .71984 L .43692 .72418 L p .707 .577 .707 r
F P
0 g
s
.43692 .72418 m .44139 .70573 L .41331 .70139 L p .707 .577 .707 r
F P
0 g
s
.32459 .67773 m .32013 .69618 L .34745 .70512 L p .707 .577 .707 r
F P
0 g
s
.68267 .58481 m .69051 .6419 L .66632 .64414 L p .707 .577 .707 r
F P
0 g
s
.66632 .64414 m .65847 .58706 L .68267 .58481 L p .707 .577 .707 r
F P
0 g
s
.63698 .70307 m .63895 .68624 L .65392 .67418 L p .707 .577 .707 r
F P
0 g
s
.82618 .64152 m .82878 .67965 L .80782 .67833 L p .707 .577 .707 r
F P
0 g
s
.80782 .67833 m .80523 .6402 L .82618 .64152 L p .707 .577 .707 r
F P
0 g
s
.47437 .52992 m .49233 .58039 L .50011 .56597 L p .707 .577 .707 r
F P
0 g
s
.50011 .56597 m .48215 .5155 L .47437 .52992 L p .707 .577 .707 r
F P
0 g
s
.33131 .65262 m .33733 .68845 L .36435 .6899 L p .707 .577 .707 r
F P
0 g
s
.83224 .70548 m .83027 .72231 L .81637 .70738 L p .707 .577 .707 r
F P
0 g
s
.81637 .70738 m .81834 .69055 L .83224 .70548 L p .707 .577 .707 r
F P
0 g
s
.33733 .68845 m .33131 .65262 L .31066 .64767 L p .707 .577 .707 r
F P
0 g
s
.32013 .69618 m .32459 .67773 L .3032 .66888 L p .707 .577 .707 r
F P
0 g
s
.65392 .67418 m .65195 .69101 L .63698 .70307 L p .707 .577 .707 r
F P
0 g
s
.44139 .70573 m .43692 .72418 L .45949 .72587 L p .707 .577 .707 r
F P
0 g
s
.45949 .72587 m .46395 .70741 L .44139 .70573 L p .707 .577 .707 r
F P
0 g
s
.80125 .56804 m .80909 .62513 L .78218 .62969 L p .707 .577 .707 r
F P
0 g
s
.3032 .66888 m .29873 .68733 L .32013 .69618 L p .707 .577 .707 r
F P
0 g
s
.47351 .62729 m .47954 .66312 L .49587 .65159 L p .707 .577 .707 r
F P
0 g
s
.49587 .65159 m .48985 .61576 L .47351 .62729 L p .707 .577 .707 r
F P
0 g
s
.3016 .58593 m .31956 .6364 L .33874 .64031 L p .707 .577 .707 r
F P
0 g
s
.66422 .68943 m .66162 .6513 L .68567 .6473 L p .707 .577 .707 r
F P
0 g
s
.78218 .62969 m .77433 .57261 L .80125 .56804 L p .707 .577 .707 r
F P
0 g
s
.31956 .6364 m .3016 .58593 L .29064 .57758 L p .707 .577 .707 r
F P
0 g
s
.68567 .6473 m .68827 .68543 L .66422 .68943 L p .707 .577 .707 r
F P
0 g
s
.71199 .58143 m .71984 .63851 L .69051 .6419 L p .707 .577 .707 r
F P
0 g
s
.69051 .6419 m .68267 .58481 L .71199 .58143 L p .707 .577 .707 r
F P
0 g
s
.31066 .64767 m .31669 .68351 L .33733 .68845 L p .707 .577 .707 r
F P
0 g
s
.80523 .6402 m .80782 .67833 L .78046 .6783 L p .707 .577 .707 r
F P
0 g
s
.78046 .6783 m .77787 .64017 L .80523 .6402 L p .707 .577 .707 r
F P
0 g
s
.65195 .69101 m .65392 .67418 L .67682 .66571 L p .707 .577 .707 r
F P
0 g
s
.77433 .57261 m .78218 .62969 L .75142 .6343 L p .707 .577 .707 r
F P
0 g
s
.29873 .68733 m .3032 .66888 L .28982 .66098 L p .707 .577 .707 r
F P
0 g
s
.75142 .6343 m .74358 .57722 L .77433 .57261 L p .707 .577 .707 r
F P
0 g
s
.81834 .69055 m .81637 .70738 L .79431 .69444 L p .707 .577 .707 r
F P
0 g
s
.79431 .69444 m .79628 .67761 L .81834 .69055 L p .707 .577 .707 r
F P
0 g
s
.48215 .5155 m .50011 .56597 L .49844 .554 L p .707 .577 .707 r
F P
0 g
s
.49844 .554 m .48048 .50353 L .48215 .5155 L p .707 .577 .707 r
F P
0 g
s
.31669 .68351 m .31066 .64767 L .29841 .63972 L p .707 .577 .707 r
F P
0 g
s
.46395 .70741 m .45949 .72587 L .47434 .72473 L p .707 .577 .707 r
F P
0 g
s
.47434 .72473 m .4788 .70628 L .46395 .70741 L p .707 .577 .707 r
F P
0 g
s
.74358 .57722 m .75142 .6343 L .71984 .63851 L p .707 .577 .707 r
F P
0 g
s
.71984 .63851 m .71199 .58143 L .74358 .57722 L p .707 .577 .707 r
F P
0 g
s
.28982 .66098 m .28536 .67943 L .29873 .68733 L p .707 .577 .707 r
F P
0 g
s
.68827 .68543 m .68567 .6473 L .71501 .64391 L p .707 .577 .707 r
F P
0 g
s
.67682 .66571 m .67485 .68255 L .65195 .69101 L p .707 .577 .707 r
F P
0 g
s
.48985 .61576 m .49587 .65159 L .50306 .64017 L p .707 .577 .707 r
F P
0 g
s
.50306 .64017 m .49704 .60434 L .48985 .61576 L p .707 .577 .707 r
F P
0 g
s
.29064 .57758 m .3086 .62805 L .31956 .6364 L p .707 .577 .707 r
F P
0 g
s
.71501 .64391 m .71761 .68204 L .68827 .68543 L p .707 .577 .707 r
F P
0 g
s
.77787 .64017 m .78046 .6783 L .74938 .67958 L p .707 .577 .707 r
F P
0 g
s
.74938 .67958 m .74678 .64145 L .77787 .64017 L p .707 .577 .707 r
F P
0 g
s
.29841 .63972 m .30444 .67555 L .31669 .68351 L p .707 .577 .707 r
F P
0 g
s
.3086 .62805 m .29064 .57758 L .28896 .56561 L p .707 .577 .707 r
F P
0 g
s
.67485 .68255 m .67682 .66571 L .70542 .66166 L p .707 .577 .707 r
F P
0 g
s
.71761 .68204 m .71501 .64391 L .74678 .64145 L p .707 .577 .707 r
F P
0 g
s
.74678 .64145 m .74938 .67958 L .71761 .68204 L p .707 .577 .707 r
F P
0 g
s
.79628 .67761 m .79431 .69444 L .76625 .68475 L p .707 .577 .707 r
F P
0 g
s
.76625 .68475 m .76822 .66791 L .79628 .67761 L p .707 .577 .707 r
F P
0 g
s
.70542 .66166 m .70345 .67849 L .67485 .68255 L p .707 .577 .707 r
F P
0 g
s
.28536 .67943 m .28982 .66098 L .28578 .65481 L p .707 .577 .707 r
F P
0 g
s
.70345 .67849 m .70542 .66166 L .73691 .66242 L p .707 .577 .707 r
F P
0 g
s
.48048 .50353 m .49844 .554 L .48747 .54565 L p .707 .577 .707 r
F P
0 g
s
.48747 .54565 m .46951 .49518 L .48048 .50353 L p .707 .577 .707 r
F P
0 g
s
.30444 .67555 m .29841 .63972 L .29575 .62954 L p .707 .578 .707 r
F P
0 g
s
.4788 .70628 m .47434 .72473 L .48002 .7209 L p .707 .577 .707 r
F P
0 g
s
.48002 .7209 m .48448 .70244 L .4788 .70628 L p .707 .577 .707 r
F P
0 g
s
.28578 .65481 m .28131 .67326 L .28536 .67943 L p .707 .577 .707 r
F P
0 g
s
.76822 .66791 m .76625 .68475 L .73494 .67925 L p .707 .577 .707 r
F P
0 g
s
.73494 .67925 m .73691 .66242 L .76822 .66791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73691 .66242 m .73494 .67925 L .70345 .67849 L p .707 .577 .707 r
F P
0 g
s
.49704 .60434 m .50306 .64017 L .5004 .62999 L p .707 .578 .707 r
F P
0 g
s
.5004 .62999 m .49438 .59416 L .49704 .60434 L p .707 .578 .707 r
F P
0 g
s
.28896 .56561 m .30692 .61608 L .3086 .62805 L p .707 .577 .707 r
F P
0 g
s
.29575 .62954 m .30177 .66537 L .30444 .67555 L p .707 .578 .707 r
F P
0 g
s
.30692 .61608 m .28896 .56561 L .29674 .55119 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.46951 .49518 m .48747 .54565 L .46829 .54174 L p .707 .577 .707 r
F P
0 g
s
.46829 .54174 m .45033 .49127 L .46951 .49518 L p .707 .577 .707 r
F P
0 g
s
.28131 .67326 m .28578 .65481 L .29145 .65097 L p .707 .577 .707 r
F P
0 g
s
.30177 .66537 m .29575 .62954 L .30294 .61812 L p .707 .577 .707 r
F P
0 g
s
.48448 .70244 m .48002 .7209 L .47597 .71473 L p .707 .577 .707 r
F P
0 g
s
.47597 .71473 m .48043 .69627 L .48448 .70244 L p .707 .577 .707 r
F P
0 g
s
.29145 .65097 m .28699 .66942 L .28131 .67326 L p .707 .577 .707 r
F P
0 g
s
.29674 .55119 m .3147 .60166 L .30692 .61608 L p .707 .577 .707 r
F P
0 g
s
.49438 .59416 m .5004 .62999 L .48815 .62204 L p .707 .577 .707 r
F P
0 g
s
.48815 .62204 m .48212 .5862 L .49438 .59416 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3147 .60166 m .29674 .55119 L .31322 .53572 L p .707 .577 .707 r
F P
0 g
s
.30294 .61812 m .30896 .65395 L .30177 .66537 L p .707 .577 .707 r
F P
0 g
s
.45033 .49127 m .46829 .54174 L .44276 .54266 L p .707 .577 .707 r
F P
0 g
s
.44276 .54266 m .4248 .49219 L .45033 .49127 L p .707 .577 .707 r
F P
0 g
s
.30896 .65395 m .30294 .61812 L .31927 .60659 L p .707 .577 .707 r
F P
0 g
s
.28699 .66942 m .29145 .65097 L .3063 .64984 L p .707 .577 .707 r
F P
0 g
s
.48043 .69627 m .47597 .71473 L .4626 .70683 L p .707 .577 .707 r
F P
0 g
s
.4626 .70683 m .46706 .68838 L .48043 .69627 L p .707 .577 .707 r
F P
0 g
s
.31322 .53572 m .33118 .58619 L .3147 .60166 L p .707 .577 .707 r
F P
0 g
s
.3063 .64984 m .30184 .66829 L .28699 .66942 L p .707 .577 .707 r
F P
0 g
s
.33118 .58619 m .31322 .53572 L .33677 .52073 L p .707 .577 .707 r
F P
0 g
s
.48212 .5862 m .48815 .62204 L .46751 .61709 L p .707 .577 .707 r
F P
0 g
s
.46751 .61709 m .46148 .58126 L .48212 .5862 L p .707 .577 .707 r
F P
0 g
s
.31927 .60659 m .3253 .64242 L .30896 .65395 L p .707 .577 .707 r
F P
0 g
s
.4248 .49219 m .44276 .54266 L .4134 .54831 L p .707 .577 .707 r
F P
0 g
s
.4134 .54831 m .39544 .49784 L .4248 .49219 L p .707 .577 .707 r
F P
0 g
s
.35473 .5712 m .33677 .52073 L .3651 .50768 L p .707 .577 .707 r
F P
0 g
s
.33677 .52073 m .35473 .5712 L .33118 .58619 L p .707 .577 .707 r
F P
0 g
s
.3253 .64242 m .31927 .60659 L .34316 .59607 L p .707 .577 .707 r
F P
0 g
s
.39544 .49784 m .4134 .54831 L .38306 .55815 L p .707 .577 .707 r
F P
0 g
s
.38306 .55815 m .3651 .50768 L .39544 .49784 L p .707 .577 .707 r
F P
0 g
s
.3651 .50768 m .38306 .55815 L .35473 .5712 L p .707 .577 .707 r
F P
0 g
s
.46148 .58126 m .46751 .61709 L .44049 .61564 L p .707 .577 .707 r
F P
0 g
s
.44049 .61564 m .43446 .57981 L .46148 .58126 L p .707 .577 .707 r
F P
0 g
s
.30184 .66829 m .3063 .64984 L .32887 .65153 L p .707 .577 .707 r
F P
0 g
s
.46706 .68838 m .4626 .70683 L .4412 .69798 L p .707 .577 .707 r
F P
0 g
s
.4412 .69798 m .44566 .67953 L .46706 .68838 L p .707 .577 .707 r
F P
0 g
s
.32887 .65153 m .32441 .66998 L .30184 .66829 L p .707 .577 .707 r
F P
0 g
s
.34316 .59607 m .34919 .6319 L .3253 .64242 L p .707 .577 .707 r
F P
0 g
s
.34919 .6319 m .34316 .59607 L .37226 .58759 L p .707 .577 .707 r
F P
0 g
s
.43446 .57981 m .44049 .61564 L .40975 .61782 L p .707 .577 .707 r
F P
0 g
s
.40975 .61782 m .40372 .58199 L .43446 .57981 L p .707 .577 .707 r
F P
0 g
s
.32441 .66998 m .32887 .65153 L .35694 .65587 L p .707 .577 .707 r
F P
0 g
s
.44566 .67953 m .4412 .69798 L .41388 .68904 L p .707 .577 .707 r
F P
0 g
s
.41388 .68904 m .41834 .67059 L .44566 .67953 L p .707 .577 .707 r
F P
0 g
s
.37829 .62343 m .37226 .58759 L .40372 .58199 L p .707 .577 .707 r
F P
0 g
s
.37226 .58759 m .37829 .62343 L .34919 .6319 L p .707 .577 .707 r
F P
0 g
s
.40372 .58199 m .40975 .61782 L .37829 .62343 L p .707 .577 .707 r
F P
0 g
s
.35694 .65587 m .35248 .67432 L .32441 .66998 L p .707 .577 .707 r
F P
0 g
s
.35248 .67432 m .35694 .65587 L .38777 .66243 L p .707 .577 .707 r
F P
0 g
s
.41834 .67059 m .41388 .68904 L .38331 .68089 L p .707 .577 .707 r
F P
0 g
s
.38331 .68089 m .38777 .66243 L .41834 .67059 L p .707 .577 .707 r
F P
0 g
s
.38777 .66243 m .38331 .68089 L .35248 .67432 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF1`001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP04001JEUYFFUH80003FUH00`00FUIJEP030002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001EYF1P000eYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1000FUIJEUYF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00@005YF000000QJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000>FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol30009FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001SOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001QOol20005FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005moo`8000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005eoo`<000UJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005aoo`05001JEUYFFUH0
0008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Yoo`80
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol005Uoo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0002FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001E
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH60002FUH00`00
FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH30008FUH01000FUIJEUYF0`001EYF00<005YFFUH00`001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00Dgoo0P001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YF00000`002UYF00@005YF000000=JEP03001JEUYF
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol005=oo`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP8000=JEP03001JEUYF00QJEP8000EJEP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000<Woo1@00;goo001BOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0`002EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0002Eoo`d0009JEP800003FUIoogoo02eoo`00DWoo00@005YFFUH0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEPD000IJEP<000QJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0000LOol90003FUH00`00FUIJEP04FUH500000eYF001JEP0_Ool0059oo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEPD000AJEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00005Goo1`0015YF00<005YFFUH01EYF20000UYF00D005YFFUH005YF02moo`00
DWoo0P000UYF00<005YFFUH015YF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF1@000UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0000AOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06
0003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo0011Ool80009Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P001UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00>goo1P000eYF00<005YFFUH00UYF1`000Woo0P000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=oo`05001JEUYFFUH00003FUH40002FUH01000FUIJEUYF20001UYF
00<005YFFUH00eYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Eoo`H000=JEP03001JEUYF00IJEPP000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool003Uoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<00005
FUH005YFFUH00006FUH30004Ool01000FUIJEUYF10000eYF1`0015YF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH60002
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP02000^Ool003Moo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP80009JEP03001JEUYF00AJEP03001oogoo00Aoo`@00003FUH005YF00@0009JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000800003FUH0000000d000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0P001EYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF10001UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00P00
0eYF10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000aOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00@005YF001JEP800003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo000`Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP020006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH2000015YF000000001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUIJEP001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEP00008000YJEP@0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPD002moo`00;Woo0P000eYF00<005YF
FUH015YF00<005YFFUH00UYF3P001eYF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF
0`000UYF00<005YFFUH025YF0P000UYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1@00=7oo000^Ool20003FUH00`00FUIJEP03FUH6
000>Ool30004FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH40002FUH30005
FUH00`00FUIJEP06FUH20004FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<003Uoo`00;Goo00<005YF00000eYF00<005YF00000`005goo0`0000AJ
EP00FUH000AJEP03001JEUYF00AJEPD000MJEPH000QJEP03001JEUYF00AJEP800003FUH005YF00=J
EP04001JEUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH003eo
o`00;Goo00<005YF00000eYF0P007Woo0P0000=JEP00FUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF009JEPL000UJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004=oo`00;Goo0P000eYF00<007ooOol07goo00@0
05YFFUH000AJEP03001JEP00008000=JEPP0009JEPD000UJEP03001JEP00008000IJEP03001JEUYF
009JEP03001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000C7oo000]Ool200000eYF0000000R
Ool01000FUIJEP0015YF0P0000=JEP0000000`0000=JEP00FUH00UYF00<005YFFUH00eYF0`0025YF
100000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF20001goo7000<Goo000]
Ool4000SOol01000FUIJEP000UYF0P001UYF00@005YFFUH000=JEP03001JEUYF00EJEP04001JEUYF
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF2`001Woo2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool20002FUH00`00Oomoo`0POol700000goo001J
EP04FUH01000FUIJEP000eYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Uoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`05FUH005YFFUH0000FOol30007Ool30002FUH00`00FUIJ
EP080003FUH01000FUIJEUYF20001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
00=oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP03001oogoo019oo`D000Eoo`8000=J
EP03001JEUYF00AJEP04001JEUYFFUH90004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP<0019oo`D000Eo
o`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP0000=JEP04001JEUYF000AOol50004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
014000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
0eYF00@005YFFUIJEP8000Moo`l0009oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP00009JEP03001JEUYF00AJEPL000=JEP03001J
EUYF00IJEP03001JEUYF00800003FUH0000000d000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00QJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP@00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEP000007FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUIJEP02FUH0
1000FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF
0005FUH70007FUH00`00FUIJEP06FUH01000FUH000001UYF0`001EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUH005YF001JEP020005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002eoo`00;Goo00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH40002FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH0009JEP8000EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0000]Ool002eoo`04001JEUYFFUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP800003FUH005YF00=J
EP03001JEUYF00AJEP04001JEUYFFUH50006FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH015YF
00<005YFFUH010000UYF3@0015YF00<005YFFUH01UYF0`000eYF2000;Goo000]Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUH000020005FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00UYF2P0025YF00<005YFFUH00UYF1P001eYF00@005YFFUH000=JEP07001JEUYF
FUH005YF0000;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUH000050004FUH00`00FUIJEP02FUH;0007FUH00`00FUIJEP02
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<005YF00001P001UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP06FUH90002FUH50004
FUH20004FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEP000eYF1@000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0000=JEP00FUH01EYF0P000UYF0P00;goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006
FUH00`00FUIJEP04FUH80007FUH300000eYF001JEP05FUH00`00FUH00002000<FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1000<Goo000]Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH0000015YF00<005YFFUH01UYF00<005YFFUH010002EYF0P001EYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0015YF00<005YF0000<Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH@0006FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<005YFFUH015YF1P00
0eYF00@005YF000000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000Eoo`80009JEP04001JEUYF000aOol002eoo`8000AJEP03001JEUYF009J
EPH00003FUH005YF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00MJEP04001JEUYFFUH900000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000L000@Ool30003FUH00`00
Oomoo`0^Ool002eoo`8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<000EJEP03001JEUYF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP040003FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUH005YF00001UYF00<005YFFUH015YF00@005YFFUIJEP8001ioo`05001JEUYF
FUH0000`Ool002eoo`8000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH50006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP04FUH01@00FUIJEP00FUH087oo00@005YFFUH0031oo`00;Goo0P000UYF
0P000Woo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP05001JEUYFFUH00003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP03000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF0000
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`005Goo00D005YF001JEP0002moo`00;7oo
00<005YF00000P001Goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0P001goo1@005Goo0P0000=JEP00Ool0;Woo000/
Ool01@00FUH005YF00001goo0P000eYF00<005YFFUH01eYF10001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPL000=JEP07001J
EUYFFUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF008000Qoo`D001Ioo`03001JEP0002moo`00;7oo0P00
0eYF00<007ooOol01Woo0P0000=JEP00FUH01eYF1P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
10000eYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00X000aJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP800003FUH005YF00EJEP04001JEUYFFUH20008
Ool5000FOol00`00FUH0000_Ool002aoo`8000=JEP<000Qoo`@000IJEPH000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00004FUH30006FUH01000FUIJEUYF0P002Goo0`0067oo0P00;goo000/Ool20003FUH00`00FUIJ
EP02000:Ool40002FUH60003FUH00`00FUIJEP05FUH00`00FUH000030006Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH50004FUH00`00FUIJEP02000UOol2000_
Ool002aoo`8000=JEP03001JEUYF009JEP<000]oo`L000AJEP03001JEUYF009JEPD000Qoo`800003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH01@00FUIJEP00FUH0
0P0000=JEP00FUH00UYF0P009Goo0P00;goo000/Ool20003FUH00`00FUIJEP03FUH01000FUH00000
47oo2@002goo0P000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0004FUH50003FUH00`00Oomoo`0ROol3000`Ool002eoo`04001JEUYF0006FUH01000FUIJEUYF0`00
7Goo100000=JEP00FUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH015YF
5@002EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<000IJEPL0029oo`800003FUH0
0000031oo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEPD001=oo`D000EJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEP0000@0
021oo`8000=JEP03001oogoo02moo`00;Woo00<005YF00001UYF00<005YFFUH01EYF00@005YFFUIJ
EQ<000=JEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF
0P0015YF00@005YFFUIJEP<001eoo`<00003FUH005YF009JEP03001oogoo02moo`00;Woo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP@000IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP04001JEUYFFUH50002FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF
00@005YFFUH000MJEPH001Aoo`<000AJEP04001JEUYF000bOol002moo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8000=JEP03001JEUYF009JEP<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEP@000EJEP05001JEUYFFUH00005FUH30008FUH00`00FUIJEP02FUH90007Ool4
00000eYF001JEP04FUH00`00FUH0000cOol0031oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEPd000=JEP03001JEP000080009JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00@00003FUH005YF009JEPX000MJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF
00=JEP8003Aoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF2@00
0eYF00<005YFFUH015YF00<005YF00000eYF0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00<005YF0000
1UYF0`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
=Goo000cOol200000eYF001JEP06FUH00`00FUIJEP06FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH00002FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUH00007FUH00`00FUH0
000200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000gOol003Eo
o`<000IJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP000080
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000kOol003Qoo`L000=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0001<0041oo`00<goo1@000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH>
0003FUH01000FUIJEP00DWoo000^Ool500000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH@00001EYF001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP03001JEUYF00=JEP800003FUH005YF00@0009JEP80055oo`00;Woo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00@005YFFUIJEPH0
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH30002
FUH00`00FUH0000200000eYF001oo`1@Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000=JEP03001JEUYF00IJEP03001JEUYF009JEPL000Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH00`0000AJEP00Oomo
o`80055oo`00;Woo00<005YF00000eYF00@005YFFUIJEPP0009JEP03001JEUYF00IJEP03001JEUYF
009JEPT000eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000Woo00@005YF0000051oo`00;goo0P000UYF1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF2@005goo0`001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00@005YF
FUIJEP<0009oo`04001JEUYF001@Ool002moo`@00003FUH005YF00AJEP03001JEUYF009JEPP0029o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00Ool2
0002FUH00`00Oomoo`1>Ool002mooa0002aoo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF
00AJEP03001JEUYF00@00006Ool005YF001JEP00DGoo001]Ool200000eYF001JEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUH0000E0004Ool01000
FUIJEUYF0P00DGoo001_Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH5000HOol00`00FUIJEP02FUH00`00Oomoo`1@Ool007=oo`D0009JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00D00003Ool0000000<001Eoo`<000AJ
EP03001oogoo051oo`00N7oo20001UYF00<005YFFUH02UYF00<005YFFUH015YF2@001Woo1@004goo
0P000UYF00D005YFFUIJEP0005=oo`00P7oo6P003goo1@004Goo0P001EYF00<005YF0000E7oo002B
Ool01P00FUIJEP00FUH0019oo`<0011oo`8000MJEP8005Eoo`00TWoo00<005YFFUH00P0097oo0P00
00=JEP00FUH01UYF00<007ooOol0E7oo002BOol01000FUIJEP008Woo0`0015YF00<005YFFUH00UYF
0P00Egoo002COol2000POol30007FUH01@00FUIJEUYF0000FGoo002COol2000LOol400000eYF001J
EP08FUH3001JOol009=oo`04001JEP00000EOol50006FUH00`00FUIJEP05FUH2001LOol009=oo`80
009JEP<000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8005ioo`00U7oo00@005YFFUH0
009JEPh000IJEP03001JEUYF00MJEP03001JEP000080061oo`00U7oo00@005YFFUH000EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@006=oo`00UGoo0P0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000Igoo002GOol30004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001[Ool009Yoo`<00003FUH005YF00=JEPP0079oo`00WGoo1P00NWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59026 .73945 m .60152 .68388 L .57109 .67648 L p .707 .577 .707 r
F P
0 g
s
.60152 .68388 m .59026 .73945 L .62154 .74514 L p .707 .577 .707 r
F P
0 g
s
.62154 .74514 m .6328 .68956 L .60152 .68388 L p .707 .577 .707 r
F P
0 g
s
.6328 .68956 m .62154 .74514 L .65059 .74855 L p .707 .577 .707 r
F P
0 g
s
.65059 .74855 m .66185 .69297 L .6328 .68956 L p .707 .577 .707 r
F P
0 g
s
.55983 .73206 m .57109 .67648 L .54448 .6681 L p .707 .577 .707 r
F P
0 g
s
.57109 .67648 m .55983 .73206 L .59026 .73945 L p .707 .577 .707 r
F P
0 g
s
.66185 .69297 m .65059 .74855 L .67458 .74936 L p .707 .577 .707 r
F P
0 g
s
.67458 .74936 m .68584 .69378 L .66185 .69297 L p .707 .577 .707 r
F P
0 g
s
.54448 .6681 m .53322 .72367 L .55983 .73206 L p .707 .577 .707 r
F P
0 g
s
.59252 .80535 m .59625 .76808 L .56525 .76349 L p .707 .577 .707 r
F P
0 g
s
.59625 .76808 m .59252 .80535 L .62421 .80773 L p .707 .577 .707 r
F P
0 g
s
.62421 .80773 m .62795 .77045 L .59625 .76808 L p .707 .577 .707 r
F P
0 g
s
.53322 .72367 m .54448 .6681 L .52429 .65954 L p .707 .577 .707 r
F P
0 g
s
.62795 .77045 m .62421 .80773 L .6535 .80766 L p .707 .577 .707 r
F P
0 g
s
.6535 .80766 m .65723 .77039 L .62795 .77045 L p .707 .577 .707 r
F P
0 g
s
.56152 .80076 m .56525 .76349 L .53798 .75714 L p .707 .577 .707 r
F P
0 g
s
.56525 .76349 m .56152 .80076 L .59252 .80535 L p .707 .577 .707 r
F P
0 g
s
.52429 .65954 m .51303 .71512 L .53322 .72367 L p .707 .577 .707 r
F P
0 g
s
.53798 .75714 m .53424 .79442 L .56152 .80076 L p .707 .577 .707 r
F P
0 g
s
.65723 .77039 m .6535 .80766 L .67751 .80516 L p .707 .577 .707 r
F P
0 g
s
.67751 .80516 m .68125 .76789 L .65723 .77039 L p .707 .577 .707 r
F P
0 g
s
.68584 .69378 m .67458 .74936 L .69115 .74749 L p .707 .577 .707 r
F P
0 g
s
.69115 .74749 m .70241 .69191 L .68584 .69378 L p .707 .577 .707 r
F P
0 g
s
.53424 .79442 m .53798 .75714 L .51711 .74965 L p .707 .577 .707 r
F P
0 g
s
.6089 .85725 m .60614 .83928 L .57512 .84145 L p .707 .577 .707 r
F P
0 g
s
.60614 .83928 m .6089 .85725 L .64033 .85172 L p .707 .577 .707 r
F P
0 g
s
.64033 .85172 m .63756 .83375 L .60614 .83928 L p .707 .577 .707 r
F P
0 g
s
.63756 .83375 m .64033 .85172 L .66908 .84339 L p .707 .577 .707 r
F P
0 g
s
.66908 .84339 m .66632 .82542 L .63756 .83375 L p .707 .577 .707 r
F P
0 g
s
.51303 .71512 m .52429 .65954 L .51251 .65166 L p .707 .577 .707 r
F P
0 g
s
.57512 .84145 m .57789 .85943 L .6089 .85725 L p .707 .577 .707 r
F P
0 g
s
.57789 .85943 m .57512 .84145 L .54755 .84007 L p .707 .577 .707 r
F P
0 g
s
.51711 .74965 m .51337 .78693 L .53424 .79442 L p .707 .577 .707 r
F P
0 g
s
.51251 .65166 m .50125 .70724 L .51303 .71512 L p .707 .577 .707 r
F P
0 g
s
.66632 .82542 m .66908 .84339 L .69235 .83307 L p .707 .577 .707 r
F P
0 g
s
.69235 .83307 m .68959 .8151 L .66632 .82542 L p .707 .577 .707 r
F P
0 g
s
.54755 .84007 m .55031 .85804 L .57789 .85943 L p .707 .577 .707 r
F P
0 g
s
.68125 .76789 m .67751 .80516 L .69389 .80047 L p .707 .577 .707 r
F P
0 g
s
.69389 .80047 m .69763 .76319 L .68125 .76789 L p .707 .577 .707 r
F P
0 g
s
.70241 .69191 m .69115 .74749 L .69869 .74312 L p .707 .577 .707 r
F P
0 g
s
.69869 .74312 m .70995 .68754 L .70241 .69191 L p .707 .577 .707 r
F P
0 g
s
.51337 .78693 m .51711 .74965 L .50467 .74176 L p .707 .577 .707 r
F P
0 g
s
.55031 .85804 m .54755 .84007 L .52612 .83526 L p .707 .577 .707 r
F P
0 g
s
.52612 .83526 m .52888 .85323 L .55031 .85804 L p .707 .577 .707 r
F P
0 g
s
.50467 .74176 m .50094 .77904 L .51337 .78693 L p .707 .577 .707 r
F P
0 g
s
.50125 .70724 m .51251 .65166 L .51027 .64522 L p .707 .577 .707 r
F P
0 g
s
.68959 .8151 m .69235 .83307 L .70786 .82177 L p .707 .577 .707 r
F P
0 g
s
.70786 .82177 m .7051 .80379 L .68959 .8151 L p .707 .577 .707 r
F P
0 g
s
.69763 .76319 m .69389 .80047 L .70105 .79404 L p .707 .577 .707 r
F P
0 g
s
.70105 .79404 m .70479 .75677 L .69763 .76319 L p .707 .577 .707 r
F P
0 g
s
.51027 .64522 m .49901 .70079 L .50125 .70724 L p .707 .577 .707 r
F P
0 g
s
.52888 .85323 m .52612 .83526 L .51293 .8275 L p .707 .577 .707 r
F P
0 g
s
.50094 .77904 m .50467 .74176 L .5019 .73423 L p .707 .577 .707 r
F P
0 g
s
.70995 .68754 m .69869 .74312 L .69646 .73667 L p .707 .577 .707 r
F P
0 g
s
.69646 .73667 m .70772 .6811 L .70995 .68754 L p .707 .577 .707 r
F P
0 g
s
.51293 .8275 m .51569 .84547 L .52888 .85323 L p .707 .577 .707 r
F P
0 g
s
.7051 .80379 m .70786 .82177 L .71409 .81059 L p .707 .577 .707 r
F P
0 g
s
.71409 .81059 m .71132 .79262 L .7051 .80379 L p .707 .577 .707 r
F P
0 g
s
.48073 .82158 m .48073 .31969 L .4375 .31621 L p .707 .577 .707 r
F P
0 g
s
.5019 .73423 m .49816 .77151 L .50094 .77904 L p .707 .577 .707 r
F P
0 g
s
.49901 .70079 m .51027 .64522 L .51781 .64085 L p .707 .577 .707 r
F P
0 g
s
.51781 .64085 m .50655 .69642 L .49901 .70079 L p .707 .577 .707 r
F P
0 g
s
.51569 .84547 m .51293 .8275 L .50927 .81754 L p .707 .577 .707 r
F P
0 g
s
.50927 .81754 m .51203 .83551 L .51569 .84547 L p .707 .577 .707 r
F P
0 g
s
.49816 .77151 m .5019 .73423 L .50906 .72781 L p .707 .577 .707 r
F P
0 g
s
.50906 .72781 m .50532 .76508 L .49816 .77151 L p .707 .577 .707 r
F P
0 g
s
.50655 .69642 m .51781 .64085 L .53439 .63897 L p .707 .577 .707 r
F P
0 g
s
.53439 .63897 m .52313 .69455 L .50655 .69642 L p .707 .577 .707 r
F P
0 g
s
.51203 .83551 m .50927 .81754 L .5155 .80636 L p .707 .577 .707 r
F P
0 g
s
.5155 .80636 m .51826 .82433 L .51203 .83551 L p .707 .577 .707 r
F P
0 g
s
.50532 .76508 m .50906 .72781 L .52544 .72312 L p .707 .577 .707 r
F P
0 g
s
.52544 .72312 m .5217 .76039 L .50532 .76508 L p .707 .577 .707 r
F P
0 g
s
.51826 .82433 m .5155 .80636 L .531 .79506 L p .707 .577 .707 r
F P
0 g
s
.531 .79506 m .53377 .81303 L .51826 .82433 L p .707 .577 .707 r
F P
0 g
s
.48073 .31969 m .48073 .82158 L .52585 .8213 L p .707 .577 .707 r
F P
0 g
s
.52313 .69455 m .53439 .63897 L .55838 .63979 L p .707 .577 .707 r
F P
0 g
s
.55838 .63979 m .54712 .69536 L .52313 .69455 L p .707 .577 .707 r
F P
0 g
s
.5217 .76039 m .52544 .72312 L .54945 .72062 L p .707 .577 .707 r
F P
0 g
s
.54945 .72062 m .54571 .75789 L .5217 .76039 L p .707 .577 .707 r
F P
0 g
s
.52585 .8213 m .52585 .31941 L .48073 .31969 L p .707 .577 .707 r
F P
0 g
s
.54712 .69536 m .55838 .63979 L .58743 .6432 L p .707 .577 .707 r
F P
0 g
s
.58743 .6432 m .57617 .69877 L .54712 .69536 L p .707 .577 .707 r
F P
0 g
s
.54571 .75789 m .54945 .72062 L .57874 .72055 L p .707 .577 .707 r
F P
0 g
s
.53377 .81303 m .531 .79506 L .55427 .78474 L p .707 .577 .707 r
F P
0 g
s
.55427 .78474 m .55704 .80271 L .53377 .81303 L p .707 .577 .707 r
F P
0 g
s
.57874 .72055 m .575 .75783 L .54571 .75789 L p .707 .577 .707 r
F P
0 g
s
.55704 .80271 m .55427 .78474 L .58303 .77641 L p .707 .577 .707 r
F P
0 g
s
.58303 .77641 m .58579 .79438 L .55704 .80271 L p .707 .577 .707 r
F P
0 g
s
.52585 .31941 m .52585 .8213 L .56844 .81729 L p .707 .577 .707 r
F P
0 g
s
.56844 .81729 m .56844 .3154 L .52585 .31941 L p .707 .577 .707 r
F P
0 g
s
.4375 .8181 m .4375 .31621 L .40039 .30932 L p .707 .577 .707 r
F P
0 g
s
.4375 .31621 m .4375 .8181 L .48073 .82158 L p .707 .577 .707 r
F P
0 g
s
.70479 .75677 m .70105 .79404 L .69827 .78652 L p .707 .577 .707 r
F P
0 g
s
.69827 .78652 m .70201 .74924 L .70479 .75677 L p .707 .577 .707 r
F P
0 g
s
.57617 .69877 m .58743 .6432 L .6187 .64888 L p .707 .577 .707 r
F P
0 g
s
.6187 .64888 m .60744 .70446 L .57617 .69877 L p .707 .577 .707 r
F P
0 g
s
.575 .75783 m .57874 .72055 L .61043 .72293 L p .707 .577 .707 r
F P
0 g
s
.61043 .72293 m .60669 .7602 L .575 .75783 L p .707 .577 .707 r
F P
0 g
s
.58579 .79438 m .58303 .77641 L .61445 .77088 L p .707 .577 .707 r
F P
0 g
s
.61445 .77088 m .61721 .78885 L .58579 .79438 L p .707 .577 .707 r
F P
0 g
s
.56844 .3154 m .56844 .81729 L .60432 .80995 L p .707 .577 .707 r
F P
0 g
s
.60432 .80995 m .60432 .30806 L .56844 .3154 L p .707 .577 .707 r
F P
0 g
s
.70772 .6811 m .69646 .73667 L .68467 .72879 L p .707 .577 .707 r
F P
0 g
s
.68467 .72879 m .69593 .67321 L .70772 .6811 L p .707 .577 .707 r
F P
0 g
s
.71132 .79262 m .71409 .81059 L .71043 .80063 L p .707 .577 .707 r
F P
0 g
s
.71043 .80063 m .70766 .78266 L .71132 .79262 L p .707 .577 .707 r
F P
0 g
s
.25009 .72919 m .25494 .67795 L .22397 .67223 L p .707 .577 .707 r
F P
0 g
s
.25494 .67795 m .25009 .72919 L .28185 .73045 L p .707 .577 .707 r
F P
0 g
s
.28185 .73045 m .2867 .67921 L .25494 .67795 L p .707 .577 .707 r
F P
0 g
s
.2867 .67921 m .28185 .73045 L .31129 .72712 L p .707 .577 .707 r
F P
0 g
s
.31129 .72712 m .31614 .67588 L .2867 .67921 L p .707 .577 .707 r
F P
0 g
s
.21913 .72347 m .22397 .67223 L .19683 .6626 L p .707 .577 .707 r
F P
0 g
s
.22397 .67223 m .21913 .72347 L .25009 .72919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.40039 .81121 m .40039 .30932 L .37302 .29969 L p .707 .577 .707 r
F P
0 g
s
.40039 .30932 m .40039 .81121 L .4375 .8181 L p .707 .577 .707 r
F P
0 g
s
.64913 .65628 m .63787 .71185 L .60744 .70446 L p .707 .577 .707 r
F P
0 g
s
.60744 .70446 m .6187 .64888 L .64913 .65628 L p .707 .577 .707 r
F P
0 g
s
.64143 .72752 m .63769 .76479 L .60669 .7602 L p .707 .577 .707 r
F P
0 g
s
.60669 .7602 m .61043 .72293 L .64143 .72752 L p .707 .577 .707 r
F P
0 g
s
.64547 .7687 m .64823 .78667 L .61721 .78885 L p .707 .577 .707 r
F P
0 g
s
.61721 .78885 m .61445 .77088 L .64547 .7687 L p .707 .577 .707 r
F P
0 g
s
.60432 .30806 m .60432 .80995 L .63 .79999 L p .707 .577 .707 r
F P
0 g
s
.63 .79999 m .63 .2981 L .60432 .30806 L p .707 .577 .707 r
F P
0 g
s
.70201 .74924 m .69827 .78652 L .68584 .77862 L p .707 .577 .707 r
F P
0 g
s
.68584 .77862 m .68958 .74135 L .70201 .74924 L p .707 .577 .707 r
F P
0 g
s
.31614 .67588 m .31129 .72712 L .33552 .71952 L p .707 .577 .707 r
F P
0 g
s
.33552 .71952 m .34037 .66829 L .31614 .67588 L p .707 .577 .707 r
F P
0 g
s
.19198 .71384 m .19683 .6626 L .17615 .65001 L p .707 .577 .707 r
F P
0 g
s
.19683 .6626 m .19198 .71384 L .21913 .72347 L p .707 .577 .707 r
F P
0 g
s
.69593 .67321 m .68467 .72879 L .66449 .72024 L p .707 .577 .707 r
F P
0 g
s
.66449 .72024 m .67575 .66466 L .69593 .67321 L p .707 .577 .707 r
F P
0 g
s
.25152 .78121 m .25313 .74537 L .22199 .74158 L p .707 .577 .707 r
F P
0 g
s
.25313 .74537 m .25152 .78121 L .28334 .78143 L p .707 .577 .707 r
F P
0 g
s
.28334 .78143 m .28494 .74559 L .25313 .74537 L p .707 .577 .707 r
F P
0 g
s
.28494 .74559 m .28334 .78143 L .31271 .77805 L p .707 .577 .707 r
F P
0 g
s
.31271 .77805 m .31432 .74221 L .28494 .74559 L p .707 .577 .707 r
F P
0 g
s
.26038 .80375 m .25918 .78472 L .22788 .78585 L p .707 .577 .707 r
F P
0 g
s
.25918 .78472 m .26038 .80375 L .29206 .80128 L p .707 .577 .707 r
F P
0 g
s
.29206 .80128 m .29086 .78225 L .25918 .78472 L p .707 .577 .707 r
F P
0 g
s
.70766 .78266 m .71043 .80063 L .69723 .79287 L p .707 .577 .707 r
F P
0 g
s
.69723 .79287 m .69447 .7749 L .70766 .78266 L p .707 .577 .707 r
F P
0 g
s
.22039 .77742 m .22199 .74158 L .19459 .73459 L p .707 .577 .707 r
F P
0 g
s
.22199 .74158 m .22039 .77742 L .25152 .78121 L p .707 .577 .707 r
F P
0 g
s
.22788 .78585 m .22908 .80488 L .26038 .80375 L p .707 .577 .707 r
F P
0 g
s
.29086 .78225 m .29206 .80128 L .32102 .79773 L p .707 .577 .707 r
F P
0 g
s
.32102 .79773 m .31981 .7787 L .29086 .78225 L p .707 .577 .707 r
F P
0 g
s
.22908 .80488 m .22788 .78585 L .20002 .78554 L p .707 .577 .707 r
F P
0 g
s
.34037 .66829 m .33552 .71952 L .35218 .70841 L p .707 .577 .707 r
F P
0 g
s
.35218 .70841 m .35703 .65718 L .34037 .66829 L p .707 .577 .707 r
F P
0 g
s
.20002 .78554 m .20123 .80457 L .22908 .80488 L p .707 .577 .707 r
F P
0 g
s
.31432 .74221 m .31271 .77805 L .33679 .7714 L p .707 .577 .707 r
F P
0 g
s
.33679 .7714 m .33839 .73556 L .31432 .74221 L p .707 .577 .707 r
F P
0 g
s
.1713 .70125 m .17615 .65001 L .16398 .63569 L p .707 .577 .707 r
F P
0 g
s
.17615 .65001 m .1713 .70125 L .19198 .71384 L p .707 .577 .707 r
F P
0 g
s
.37302 .80158 m .37302 .29969 L .35809 .28827 L p .707 .577 .707 r
F P
0 g
s
.37302 .29969 m .37302 .80158 L .40039 .81121 L p .707 .577 .707 r
F P
0 g
s
.68958 .74135 m .68584 .77862 L .66497 .77114 L p .707 .577 .707 r
F P
0 g
s
.66497 .77114 m .6687 .73386 L .68958 .74135 L p .707 .577 .707 r
F P
0 g
s
.19459 .73459 m .19299 .77043 L .22039 .77742 L p .707 .577 .707 r
F P
0 g
s
.31981 .7787 m .32102 .79773 L .34442 .79343 L p .707 .577 .707 r
F P
0 g
s
.34442 .79343 m .34322 .7744 L .31981 .7787 L p .707 .577 .707 r
F P
0 g
s
.19299 .77043 m .19459 .73459 L .1736 .72508 L p .707 .577 .707 r
F P
0 g
s
.67575 .66466 m .66449 .72024 L .63787 .71185 L p .707 .577 .707 r
F P
0 g
s
.63787 .71185 m .64913 .65628 L .67575 .66466 L p .707 .577 .707 r
F P
0 g
s
.6687 .73386 m .66497 .77114 L .63769 .76479 L p .707 .577 .707 r
F P
0 g
s
.63769 .76479 m .64143 .72752 L .6687 .73386 L p .707 .577 .707 r
F P
0 g
s
.63 .2981 m .63 .79999 L .64295 .78839 L p .707 .577 .707 r
F P
0 g
s
.64295 .78839 m .64295 .2865 L .63 .2981 L p .707 .577 .707 r
F P
0 g
s
.20123 .80457 m .20002 .78554 L .17834 .78381 L p .707 .577 .707 r
F P
0 g
s
.17834 .78381 m .17954 .80284 L .20123 .80457 L p .707 .577 .707 r
F P
0 g
s
.69447 .7749 m .69723 .79287 L .6758 .78806 L p .707 .577 .707 r
F P
0 g
s
.6758 .78806 m .67304 .77009 L .69447 .7749 L p .707 .577 .707 r
F P
0 g
s
.1736 .72508 m .17199 .76092 L .19299 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .73556 m .33679 .7714 L .35319 .76214 L p .707 .577 .707 r
F P
0 g
s
.35319 .76214 m .3548 .7263 L .33839 .73556 L p .707 .577 .707 r
F P
0 g
s
.35703 .65718 m .35218 .70841 L .35964 .69487 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .36449 .64364 L .35703 .65718 L p .707 .577 .707 r
F P
0 g
s
.15913 .68693 m .16398 .63569 L .1615 .62105 L p .707 .577 .707 r
F P
0 g
s
.16398 .63569 m .15913 .68693 L .1713 .70125 L p .707 .577 .707 r
F P
0 g
s
.34322 .7744 m .34442 .79343 L .35997 .7888 L p .707 .577 .707 r
F P
0 g
s
.35997 .7888 m .35877 .76977 L .34322 .7744 L p .707 .577 .707 r
F P
0 g
s
.17199 .76092 m .1736 .72508 L .16107 .71398 L p .707 .577 .707 r
F P
0 g
s
.17954 .80284 m .17834 .78381 L .16494 .78084 L p .707 .577 .707 r
F P
0 g
s
.16494 .78084 m .16614 .79987 L .17954 .80284 L p .707 .577 .707 r
F P
0 g
s
.67304 .77009 m .6758 .78806 L .64823 .78667 L p .707 .577 .707 r
F P
0 g
s
.64823 .78667 m .64547 .7687 L .67304 .77009 L p .707 .577 .707 r
F P
0 g
s
.16107 .71398 m .15947 .74982 L .17199 .76092 L p .707 .577 .707 r
F P
0 g
s
.3548 .7263 m .35319 .76214 L .36033 .75118 L p .707 .577 .707 r
F P
0 g
s
.36033 .75118 m .36193 .71533 L .3548 .7263 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .35716 .68022 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36449 .64364 m .35993 .69175 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35993 .69175 m .35964 .69487 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35705 .27616 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36201 .62899 m .36449 .64364 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35716 .68022 m .35931 .65746 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35931 .65746 m .36201 .62899 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36193 .71533 m .36033 .75118 L .35749 .73958 L p .707 .577 .707 r
F P
0 g
s
.35749 .73958 m .3591 .70373 L .36193 .71533 L p .707 .577 .707 r
F P
0 g
s
.36201 .62899 m .35716 .68022 L .34499 .6659 L p .707 .577 .707 r
F P
0 g
s
.34499 .6659 m .34984 .61467 L .36201 .62899 L p .707 .577 .707 r
F P
0 g
s
.3591 .70373 m .35749 .73958 L .34496 .72848 L p .707 .577 .707 r
F P
0 g
s
.34496 .72848 m .34657 .69263 L .3591 .70373 L p .707 .577 .707 r
F P
0 g
s
.35877 .76977 m .35997 .7888 L .36615 .78431 L p .707 .577 .707 r
F P
0 g
s
.36615 .78431 m .36495 .76528 L .35877 .76977 L p .707 .577 .707 r
F P
0 g
s
.36116 .76136 m .36236 .78039 L .34897 .77741 L p .707 .577 .707 r
F P
0 g
s
.34897 .77741 m .34777 .75839 L .36116 .76136 L p .707 .577 .707 r
F P
0 g
s
.35705 .77805 m .35809 .79015 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .27616 m .35705 .53203 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .53203 m .35705 .77805 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .79015 m .35809 .58969 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .58969 m .35809 .28827 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36495 .76528 m .36615 .78431 L .36236 .78039 L p .707 .577 .707 r
F P
0 g
s
.36236 .78039 m .36116 .76136 L .36495 .76528 L p .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35809 .79015 L .37302 .80158 L p .707 .577 .707 r
F P
0 g
s
.64295 .2865 m .64295 .78839 L .64191 .77628 L p .707 .578 .707 r
F P
0 g
s
.64191 .77628 m .64191 .27439 L .64295 .2865 L p .707 .578 .707 r
F P
0 g
s
.1615 .62105 m .15665 .67228 L .15913 .68693 L p .707 .577 .707 r
F P
0 g
s
.15665 .67228 m .1615 .62105 L .16896 .6075 L p .707 .577 .707 r
F P
0 g
s
.15947 .74982 m .16107 .71398 L .15824 .70238 L p .707 .577 .707 r
F P
0 g
s
.16614 .79987 m .16494 .78084 L .16115 .77692 L p .707 .577 .707 r
F P
0 g
s
.16115 .77692 m .16235 .79595 L .16614 .79987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15824 .70238 m .15663 .73822 L .15947 .74982 L p .707 .577 .707 r
F P
0 g
s
.16896 .6075 m .16411 .65874 L .15665 .67228 L p .707 .577 .707 r
F P
0 g
s
.16411 .65874 m .16896 .6075 L .18562 .59639 L p .707 .577 .707 r
F P
0 g
s
.15663 .73822 m .15824 .70238 L .16537 .69141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35705 .77805 m .35705 .27616 L .37 .26456 L p .707 .577 .707 r
F P
0 g
s
.64191 .27439 m .64191 .77628 L .62698 .76485 L p .707 .577 .707 r
F P
0 g
s
.62698 .76485 m .62698 .26297 L .64191 .27439 L p .707 .577 .707 r
F P
0 g
s
.16235 .79595 m .16115 .77692 L .16734 .77242 L p .707 .577 .707 r
F P
0 g
s
.16734 .77242 m .16854 .79145 L .16235 .79595 L p .707 .577 .707 r
F P
0 g
s
.16537 .69141 m .16376 .72725 L .15663 .73822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34984 .61467 m .34499 .6659 L .32432 .65331 L p .707 .577 .707 r
F P
0 g
s
.32432 .65331 m .32917 .60208 L .34984 .61467 L p .707 .577 .707 r
F P
0 g
s
.18562 .59639 m .18077 .64763 L .16411 .65874 L p .707 .577 .707 r
F P
0 g
s
.18077 .64763 m .18562 .59639 L .20985 .5888 L p .707 .577 .707 r
F P
0 g
s
.16376 .72725 m .16537 .69141 L .18177 .68215 L p .707 .577 .707 r
F P
0 g
s
.32917 .60208 m .32432 .65331 L .29717 .64369 L p .707 .577 .707 r
F P
0 g
s
.29717 .64369 m .30202 .59245 L .32917 .60208 L p .707 .577 .707 r
F P
0 g
s
.16854 .79145 m .16734 .77242 L .18289 .7678 L p .707 .577 .707 r
F P
0 g
s
.205 .64003 m .20985 .5888 L .23929 .58547 L p .707 .577 .707 r
F P
0 g
s
.20985 .5888 m .205 .64003 L .18077 .64763 L p .707 .577 .707 r
F P
0 g
s
.18177 .68215 m .18017 .71799 L .16376 .72725 L p .707 .577 .707 r
F P
0 g
s
.18289 .7678 m .18409 .78683 L .16854 .79145 L p .707 .577 .707 r
F P
0 g
s
.37 .76645 m .37 .26456 L .39567 .2546 L p .707 .577 .707 r
F P
0 g
s
.37 .26456 m .37 .76645 L .35705 .77805 L p .707 .577 .707 r
F P
0 g
s
.34657 .69263 m .34496 .72848 L .32397 .71896 L p .707 .577 .707 r
F P
0 g
s
.32397 .71896 m .32557 .68312 L .34657 .69263 L p .707 .577 .707 r
F P
0 g
s
.62698 .26297 m .62698 .76485 L .59961 .75522 L p .707 .577 .707 r
F P
0 g
s
.59961 .75522 m .59961 .25334 L .62698 .26297 L p .707 .577 .707 r
F P
0 g
s
.30202 .59245 m .29717 .64369 L .2662 .63796 L p .707 .577 .707 r
F P
0 g
s
.2662 .63796 m .27105 .58673 L .30202 .59245 L p .707 .577 .707 r
F P
0 g
s
.23444 .6367 m .23929 .58547 L .27105 .58673 L p .707 .577 .707 r
F P
0 g
s
.23929 .58547 m .23444 .6367 L .205 .64003 L p .707 .577 .707 r
F P
0 g
s
.18017 .71799 m .18177 .68215 L .20585 .67551 L p .707 .577 .707 r
F P
0 g
s
.27105 .58673 m .2662 .63796 L .23444 .6367 L p .707 .577 .707 r
F P
0 g
s
.34777 .75839 m .34897 .77741 L .32728 .77569 L p .707 .577 .707 r
F P
0 g
s
.32728 .77569 m .32608 .75666 L .34777 .75839 L p .707 .577 .707 r
F P
0 g
s
.18409 .78683 m .18289 .7678 L .20629 .7635 L p .707 .577 .707 r
F P
0 g
s
.20585 .67551 m .20424 .71135 L .18017 .71799 L p .707 .577 .707 r
F P
0 g
s
.32557 .68312 m .32397 .71896 L .29657 .71197 L p .707 .577 .707 r
F P
0 g
s
.29657 .71197 m .29817 .67613 L .32557 .68312 L p .707 .577 .707 r
F P
0 g
s
.20629 .7635 m .20749 .78253 L .18409 .78683 L p .707 .577 .707 r
F P
0 g
s
.20424 .71135 m .20585 .67551 L .23523 .67213 L p .707 .577 .707 r
F P
0 g
s
.7338 .6386 m .72895 .58125 L .69798 .58332 L p .707 .577 .707 r
F P
0 g
s
.72895 .58125 m .7338 .6386 L .76556 .63574 L p .707 .577 .707 r
F P
0 g
s
.76556 .63574 m .76071 .5784 L .72895 .58125 L p .707 .577 .707 r
F P
0 g
s
.39567 .2546 m .39567 .75649 L .37 .76645 L p .707 .577 .707 r
F P
0 g
s
.39567 .75649 m .39567 .2546 L .43156 .24726 L p .707 .577 .707 r
F P
0 g
s
.76071 .5784 m .76556 .63574 L .79499 .63238 L p .707 .577 .707 r
F P
0 g
s
.79499 .63238 m .79015 .57504 L .76071 .5784 L p .707 .577 .707 r
F P
0 g
s
.69798 .58332 m .70283 .64066 L .7338 .6386 L p .707 .577 .707 r
F P
0 g
s
.59961 .25334 m .59961 .75522 L .5625 .74834 L p .707 .577 .707 r
F P
0 g
s
.5625 .74834 m .5625 .24645 L .59961 .25334 L p .707 .577 .707 r
F P
0 g
s
.29817 .67613 m .29657 .71197 L .26543 .70818 L p .707 .577 .707 r
F P
0 g
s
.26543 .70818 m .26704 .67234 L .29817 .67613 L p .707 .577 .707 r
F P
0 g
s
.32608 .75666 m .32728 .77569 L .29943 .77538 L p .707 .577 .707 r
F P
0 g
s
.29943 .77538 m .29822 .75635 L .32608 .75666 L p .707 .577 .707 r
F P
0 g
s
.70283 .64066 m .69798 .58332 L .67083 .58439 L p .707 .577 .707 r
F P
0 g
s
.23362 .70797 m .23523 .67213 L .26704 .67234 L p .707 .577 .707 r
F P
0 g
s
.23523 .67213 m .23362 .70797 L .20424 .71135 L p .707 .577 .707 r
F P
0 g
s
.67083 .58439 m .67568 .64174 L .70283 .64066 L p .707 .577 .707 r
F P
0 g
s
.20749 .78253 m .20629 .7635 L .23525 .75994 L p .707 .577 .707 r
F P
0 g
s
.26704 .67234 m .26543 .70818 L .23362 .70797 L p .707 .577 .707 r
F P
0 g
s
.79015 .57504 m .79499 .63238 L .81923 .62885 L p .707 .577 .707 r
F P
0 g
s
.81923 .62885 m .81438 .5715 L .79015 .57504 L p .707 .577 .707 r
F P
0 g
s
.23525 .75994 m .23645 .77897 L .20749 .78253 L p .707 .577 .707 r
F P
0 g
s
.73456 .70919 m .73296 .67134 L .70183 .67138 L p .707 .577 .707 r
F P
0 g
s
.73296 .67134 m .73456 .70919 L .76638 .70739 L p .707 .577 .707 r
F P
0 g
s
.76638 .70739 m .76477 .66954 L .73296 .67134 L p .707 .577 .707 r
F P
0 g
s
.76477 .66954 m .76638 .70739 L .79576 .70401 L p .707 .577 .707 r
F P
0 g
s
.79576 .70401 m .79415 .66616 L .76477 .66954 L p .707 .577 .707 r
F P
0 g
s
.29822 .75635 m .29943 .77538 L .26813 .77651 L p .707 .577 .707 r
F P
0 g
s
.26813 .77651 m .26692 .75748 L .29822 .75635 L p .707 .577 .707 r
F P
0 g
s
.70183 .67138 m .70343 .70923 L .73456 .70919 L p .707 .577 .707 r
F P
0 g
s
.70343 .70923 m .70183 .67138 L .67442 .66966 L p .707 .577 .707 r
F P
0 g
s
.67568 .64174 m .67083 .58439 L .65016 .58437 L p .707 .577 .707 r
F P
0 g
s
.23645 .77897 m .23525 .75994 L .26692 .75748 L p .707 .577 .707 r
F P
0 g
s
.26692 .75748 m .26813 .77651 L .23645 .77897 L p .707 .577 .707 r
F P
0 g
s
.43156 .74915 m .43156 .24726 L .47415 .24325 L p .707 .577 .707 r
F P
0 g
s
.43156 .24726 m .43156 .74915 L .39567 .75649 L p .707 .577 .707 r
F P
0 g
s
.65016 .58437 m .65501 .64172 L .67568 .64174 L p .707 .577 .707 r
F P
0 g
s
.67442 .66966 m .67603 .70752 L .70343 .70923 L p .707 .577 .707 r
F P
0 g
s
.5625 .24645 m .5625 .74834 L .51927 .74486 L p .707 .577 .707 r
F P
0 g
s
.51927 .74486 m .51927 .24297 L .5625 .24645 L p .707 .577 .707 r
F P
0 g
s
.79415 .66616 m .79576 .70401 L .81983 .69938 L p .707 .577 .707 r
F P
0 g
s
.81983 .69938 m .81822 .66153 L .79415 .66616 L p .707 .577 .707 r
F P
0 g
s
.81438 .5715 m .81923 .62885 L .83589 .62548 L p .707 .577 .707 r
F P
0 g
s
.83589 .62548 m .83104 .56813 L .81438 .5715 L p .707 .577 .707 r
F P
0 g
s
.67603 .70752 m .67442 .66966 L .65343 .66635 L p .707 .577 .707 r
F P
0 g
s
.47415 .74514 m .47415 .24325 L .51927 .24297 L p .707 .577 .707 r
F P
0 g
s
.47415 .24325 m .47415 .74514 L .43156 .74915 L p .707 .577 .707 r
F P
0 g
s
.51927 .24297 m .51927 .74486 L .47415 .74514 L p .707 .577 .707 r
F P
0 g
s
.73187 .77013 m .73307 .75254 L .70177 .74826 L p .707 .577 .707 r
F P
0 g
s
.73307 .75254 m .73187 .77013 L .76355 .77043 L p .707 .577 .707 r
F P
0 g
s
.76355 .77043 m .76475 .75284 L .73307 .75254 L p .707 .577 .707 r
F P
0 g
s
.65343 .66635 m .65503 .70421 L .67603 .70752 L p .707 .577 .707 r
F P
0 g
s
.65501 .64172 m .65016 .58437 L .63799 .58326 L p .707 .577 .707 r
F P
0 g
s
.76475 .75284 m .76355 .77043 L .79251 .76672 L p .707 .577 .707 r
F P
0 g
s
.79251 .76672 m .79371 .74913 L .76475 .75284 L p .707 .577 .707 r
F P
0 g
s
.70057 .76585 m .70177 .74826 L .67392 .74042 L p .707 .577 .707 r
F P
0 g
s
.70177 .74826 m .70057 .76585 L .73187 .77013 L p .707 .577 .707 r
F P
0 g
s
.81822 .66153 m .81983 .69938 L .83623 .69395 L p .707 .577 .707 r
F P
0 g
s
.83623 .69395 m .83463 .6561 L .81822 .66153 L p .707 .577 .707 r
F P
0 g
s
.63799 .58326 m .64284 .64061 L .65501 .64172 L p .707 .577 .707 r
F P
0 g
s
.67392 .74042 m .67272 .75801 L .70057 .76585 L p .707 .577 .707 r
F P
0 g
s
.83104 .56813 m .83589 .62548 L .84335 .6226 L p .707 .577 .707 r
F P
0 g
s
.84335 .6226 m .8385 .56526 L .83104 .56813 L p .707 .577 .707 r
F P
0 g
s
.65503 .70421 m .65343 .66635 L .6409 .66178 L p .707 .577 .707 r
F P
0 g
s
.79371 .74913 m .79251 .76672 L .81591 .75936 L p .707 .577 .707 r
F P
0 g
s
.81591 .75936 m .81711 .74177 L .79371 .74913 L p .707 .577 .707 r
F P
0 g
s
.67272 .75801 m .67392 .74042 L .65223 .72979 L p .707 .577 .707 r
F P
0 g
s
.6409 .66178 m .64251 .69963 L .65503 .70421 L p .707 .577 .707 r
F P
0 g
s
.65223 .72979 m .65103 .74738 L .67272 .75801 L p .707 .577 .707 r
F P
0 g
s
.64284 .64061 m .63799 .58326 L .63551 .58117 L p .707 .577 .707 r
F P
0 g
s
.83463 .6561 m .83623 .69395 L .84337 .68826 L p .707 .577 .707 r
F P
0 g
s
.84337 .68826 m .84176 .65041 L .83463 .6561 L p .707 .577 .707 r
F P
0 g
s
.63551 .58117 m .64036 .63851 L .64284 .64061 L p .707 .577 .707 r
F P
0 g
s
.81711 .74177 m .81591 .75936 L .83146 .74908 L p .707 .577 .707 r
F P
0 g
s
.83146 .74908 m .83266 .73149 L .81711 .74177 L p .707 .577 .707 r
F P
0 g
s
.65103 .74738 m .65223 .72979 L .63884 .71741 L p .707 .577 .707 r
F P
0 g
s
.8385 .56526 m .84335 .6226 L .84087 .62051 L p .707 .577 .707 r
F P
0 g
s
.84087 .62051 m .83602 .56317 L .8385 .56526 L p .707 .577 .707 r
F P
0 g
s
.64251 .69963 m .6409 .66178 L .63807 .65638 L p .707 .577 .707 r
F P
0 g
s
.63884 .71741 m .63763 .735 L .65103 .74738 L p .707 .577 .707 r
F P
0 g
s
.63807 .65638 m .63967 .69423 L .64251 .69963 L p .707 .577 .707 r
F P
0 g
s
.84176 .65041 m .84337 .68826 L .84053 .68286 L p .707 .577 .707 r
F P
0 g
s
.84053 .68286 m .83893 .64501 L .84176 .65041 L p .707 .577 .707 r
F P
0 g
s
.64036 .63851 m .63551 .58117 L .64297 .5783 L p .707 .577 .707 r
F P
0 g
s
.83266 .73149 m .83146 .74908 L .83764 .73688 L p .707 .577 .707 r
F P
0 g
s
.83764 .73688 m .83885 .71929 L .83266 .73149 L p .707 .577 .707 r
F P
0 g
s
.63763 .735 m .63884 .71741 L .63505 .70448 L p .707 .577 .707 r
F P
0 g
s
.64297 .5783 m .64781 .63564 L .64036 .63851 L p .707 .577 .707 r
F P
0 g
s
.63505 .70448 m .63384 .72207 L .63763 .735 L p .707 .577 .707 r
F P
0 g
s
.63967 .69423 m .63807 .65638 L .6452 .65069 L p .707 .577 .707 r
F P
0 g
s
.83602 .56317 m .84087 .62051 L .8287 .6194 L p .707 .577 .707 r
F P
0 g
s
.8287 .6194 m .82385 .56205 L .83602 .56317 L p .707 .577 .707 r
F P
0 g
s
.42383 .62247 m .41257 .56938 L .38129 .57601 L p .707 .577 .707 r
F P
0 g
s
.41257 .56938 m .42383 .62247 L .45288 .61288 L p .707 .577 .707 r
F P
0 g
s
.45288 .61288 m .44162 .55979 L .41257 .56938 L p .707 .577 .707 r
F P
0 g
s
.39256 .62909 m .38129 .57601 L .35086 .57903 L p .707 .577 .707 r
F P
0 g
s
.38129 .57601 m .39256 .62909 L .42383 .62247 L p .707 .577 .707 r
F P
0 g
s
.6452 .65069 m .64681 .68854 L .63967 .69423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44162 .55979 m .45288 .61288 L .47687 .60127 L p .707 .577 .707 r
F P
0 g
s
.47687 .60127 m .46561 .54819 L .44162 .55979 L p .707 .577 .707 r
F P
0 g
s
.36212 .63211 m .35086 .57903 L .32425 .57814 L p .707 .577 .707 r
F P
0 g
s
.35086 .57903 m .36212 .63211 L .39256 .62909 L p .707 .577 .707 r
F P
0 g
s
.83885 .71929 m .83764 .73688 L .83385 .72395 L p .707 .577 .707 r
F P
0 g
s
.83385 .72395 m .83506 .70636 L .83885 .71929 L p .707 .577 .707 r
F P
0 g
s
.83893 .64501 m .84053 .68286 L .82801 .67829 L p .707 .577 .707 r
F P
0 g
s
.82801 .67829 m .8264 .64043 L .83893 .64501 L p .707 .577 .707 r
F P
0 g
s
.64781 .63564 m .64297 .5783 L .65963 .57493 L p .707 .577 .707 r
F P
0 g
s
.63384 .72207 m .63505 .70448 L .64123 .69228 L p .707 .577 .707 r
F P
0 g
s
.65963 .57493 m .66448 .63227 L .64781 .63564 L p .707 .577 .707 r
F P
0 g
s
.64123 .69228 m .64003 .70987 L .63384 .72207 L p .707 .577 .707 r
F P
0 g
s
.3933 .68523 m .38957 .64881 L .35857 .64947 L p .707 .577 .707 r
F P
0 g
s
.38957 .64881 m .3933 .68523 L .425 .68143 L p .707 .577 .707 r
F P
0 g
s
.425 .68143 m .42126 .64501 L .38957 .64881 L p .707 .577 .707 r
F P
0 g
s
.42126 .64501 m .425 .68143 L .45429 .67486 L p .707 .577 .707 r
F P
0 g
s
.45429 .67486 m .45055 .63844 L .42126 .64501 L p .707 .577 .707 r
F P
0 g
s
.82385 .56205 m .8287 .6194 L .80802 .61938 L p .707 .577 .707 r
F P
0 g
s
.80802 .61938 m .80317 .56204 L .82385 .56205 L p .707 .577 .707 r
F P
0 g
s
.64681 .68854 m .6452 .65069 L .66161 .64526 L p .707 .577 .707 r
F P
0 g
s
.46561 .54819 m .47687 .60127 L .49344 .58877 L p .707 .577 .707 r
F P
0 g
s
.49344 .58877 m .48218 .53569 L .46561 .54819 L p .707 .577 .707 r
F P
0 g
s
.33551 .63122 m .32425 .57814 L .30406 .57343 L p .707 .577 .707 r
F P
0 g
s
.32425 .57814 m .33551 .63122 L .36212 .63211 L p .707 .577 .707 r
F P
0 g
s
.3623 .68589 m .35857 .64947 L .33129 .64693 L p .707 .577 .707 r
F P
0 g
s
.35857 .64947 m .3623 .68589 L .3933 .68523 L p .707 .577 .707 r
F P
0 g
s
.66161 .64526 m .66321 .68311 L .64681 .68854 L p .707 .577 .707 r
F P
0 g
s
.38278 .717 m .38555 .69837 L .35453 .69267 L p .707 .577 .707 r
F P
0 g
s
.38555 .69837 m .38278 .717 L .41421 .7207 L p .707 .577 .707 r
F P
0 g
s
.41421 .7207 m .41697 .70207 L .38555 .69837 L p .707 .577 .707 r
F P
0 g
s
.45055 .63844 m .45429 .67486 L .4783 .66617 L p .707 .577 .707 r
F P
0 g
s
.4783 .66617 m .47456 .62974 L .45055 .63844 L p .707 .577 .707 r
F P
0 g
s
.35453 .69267 m .35177 .71129 L .38278 .717 L p .707 .577 .707 r
F P
0 g
s
.41697 .70207 m .41421 .7207 L .44296 .72203 L p .707 .577 .707 r
F P
0 g
s
.44296 .72203 m .44572 .70341 L .41697 .70207 L p .707 .577 .707 r
F P
0 g
s
.35177 .71129 m .35453 .69267 L .32696 .68552 L p .707 .577 .707 r
F P
0 g
s
.66448 .63227 m .65963 .57493 L .68386 .57139 L p .707 .577 .707 r
F P
0 g
s
.83506 .70636 m .83385 .72395 L .82046 .71157 L p .707 .577 .707 r
F P
0 g
s
.82046 .71157 m .82166 .69398 L .83506 .70636 L p .707 .577 .707 r
F P
0 g
s
.8264 .64043 m .82801 .67829 L .80701 .67498 L p .707 .577 .707 r
F P
0 g
s
.80701 .67498 m .80541 .63712 L .8264 .64043 L p .707 .577 .707 r
F P
0 g
s
.64003 .70987 m .64123 .69228 L .65678 .682 L p .707 .577 .707 r
F P
0 g
s
.33129 .64693 m .33503 .68336 L .3623 .68589 L p .707 .577 .707 r
F P
0 g
s
.32696 .68552 m .32419 .70415 L .35177 .71129 L p .707 .577 .707 r
F P
0 g
s
.68386 .57139 m .68871 .62873 L .66448 .63227 L p .707 .577 .707 r
F P
0 g
s
.30406 .57343 m .31532 .62652 L .33551 .63122 L p .707 .577 .707 r
F P
0 g
s
.33503 .68336 m .33129 .64693 L .31042 .64144 L p .707 .577 .707 r
F P
0 g
s
.65678 .682 m .65558 .69959 L .64003 .70987 L p .707 .577 .707 r
F P
0 g
s
.80317 .56204 m .80802 .61938 L .78087 .62046 L p .707 .577 .707 r
F P
0 g
s
.78087 .62046 m .77602 .56311 L .80317 .56204 L p .707 .577 .707 r
F P
0 g
s
.48218 .53569 m .49344 .58877 L .50098 .57662 L p .707 .577 .707 r
F P
0 g
s
.50098 .57662 m .48972 .52353 L .48218 .53569 L p .707 .577 .707 r
F P
0 g
s
.31532 .62652 m .30406 .57343 L .29228 .56537 L p .707 .577 .707 r
F P
0 g
s
.44572 .70341 m .44296 .72203 L .46623 .72087 L p .707 .577 .707 r
F P
0 g
s
.46623 .72087 m .46899 .70225 L .44572 .70341 L p .707 .577 .707 r
F P
0 g
s
.66321 .68311 m .66161 .64526 L .68568 .64063 L p .707 .577 .707 r
F P
0 g
s
.32419 .70415 m .32696 .68552 L .30552 .67763 L p .707 .577 .707 r
F P
0 g
s
.47456 .62974 m .4783 .66617 L .49468 .6562 L p .707 .577 .707 r
F P
0 g
s
.49468 .6562 m .49094 .61978 L .47456 .62974 L p .707 .577 .707 r
F P
0 g
s
.30552 .67763 m .30276 .69625 L .32419 .70415 L p .707 .577 .707 r
F P
0 g
s
.31042 .64144 m .31416 .67786 L .33503 .68336 L p .707 .577 .707 r
F P
0 g
s
.68568 .64063 m .68728 .67848 L .66321 .68311 L p .707 .577 .707 r
F P
0 g
s
.68871 .62873 m .68386 .57139 L .7133 .56803 L p .707 .577 .707 r
F P
0 g
s
.7133 .56803 m .71815 .62537 L .68871 .62873 L p .707 .577 .707 r
F P
0 g
s
.80541 .63712 m .80701 .67498 L .77961 .67326 L p .707 .577 .707 r
F P
0 g
s
.77961 .67326 m .778 .63541 L .80541 .63712 L p .707 .577 .707 r
F P
0 g
s
.82166 .69398 m .82046 .71157 L .79877 .70094 L p .707 .577 .707 r
F P
0 g
s
.79877 .70094 m .79997 .68335 L .82166 .69398 L p .707 .577 .707 r
F P
0 g
s
.77602 .56311 m .78087 .62046 L .7499 .62252 L p .707 .577 .707 r
F P
0 g
s
.7499 .62252 m .74506 .56518 L .77602 .56311 L p .707 .577 .707 r
F P
0 g
s
.65558 .69959 m .65678 .682 L .68018 .67465 L p .707 .577 .707 r
F P
0 g
s
.31416 .67786 m .31042 .64144 L .29799 .63353 L p .707 .577 .707 r
F P
0 g
s
.29228 .56537 m .30354 .61845 L .31532 .62652 L p .707 .577 .707 r
F P
0 g
s
.71815 .62537 m .7133 .56803 L .74506 .56518 L p .707 .577 .707 r
F P
0 g
s
.68728 .67848 m .68568 .64063 L .71506 .63725 L p .707 .577 .707 r
F P
0 g
s
.46899 .70225 m .46623 .72087 L .48174 .71733 L p .707 .577 .707 r
F P
0 g
s
.48174 .71733 m .4845 .69871 L .46899 .70225 L p .707 .577 .707 r
F P
0 g
s
.74506 .56518 m .7499 .62252 L .71815 .62537 L p .707 .577 .707 r
F P
0 g
s
.68018 .67465 m .67898 .69224 L .65558 .69959 L p .707 .577 .707 r
F P
0 g
s
.30276 .69625 m .30552 .67763 L .29233 .66977 L p .707 .577 .707 r
F P
0 g
s
.29233 .66977 m .28957 .68839 L .30276 .69625 L p .707 .577 .707 r
F P
0 g
s
.48972 .52353 m .50098 .57662 L .49875 .56599 L p .698 .571 .709 r
F P
0 g
s
.49875 .56599 m .48749 .5129 L .48972 .52353 L p .698 .571 .709 r
F P
0 g
s
.30354 .61845 m .29228 .56537 L .29004 .55474 L p .698 .571 .709 r
F P
0 g
s
.71506 .63725 m .71666 .6751 L .68728 .67848 L p .707 .577 .707 r
F P
0 g
s
.49094 .61978 m .49468 .6562 L .50184 .64594 L p .707 .577 .707 r
F P
0 g
s
.50184 .64594 m .4981 .60952 L .49094 .61978 L p .707 .577 .707 r
F P
0 g
s
.778 .63541 m .77961 .67326 L .74848 .6733 L p .707 .577 .707 r
F P
0 g
s
.74848 .6733 m .74687 .63545 L .778 .63541 L p .707 .577 .707 r
F P
0 g
s
.29799 .63353 m .30172 .66995 L .31416 .67786 L p .707 .577 .707 r
F P
0 g
s
.71666 .6751 m .71506 .63725 L .74687 .63545 L p .707 .577 .707 r
F P
0 g
s
.79997 .68335 m .79877 .70094 L .77092 .6931 L p .707 .577 .707 r
F P
0 g
s
.77092 .6931 m .77212 .67551 L .79997 .68335 L p .707 .577 .707 r
F P
0 g
s
.67898 .69224 m .68018 .67465 L .70914 .67094 L p .707 .577 .707 r
F P
0 g
s
.74687 .63545 m .74848 .6733 L .71666 .6751 L p .707 .577 .707 r
F P
0 g
s
.70914 .67094 m .70794 .68852 L .67898 .69224 L p .707 .577 .707 r
F P
0 g
s
.30172 .66995 m .29799 .63353 L .29521 .62398 L p .707 .577 .707 r
F P
0 g
s
.29004 .55474 m .3013 .60782 L .30354 .61845 L p .698 .571 .709 r
F P
0 g
s
.77212 .67551 m .77092 .6931 L .73962 .68882 L p .707 .577 .707 r
F P
0 g
s
.73962 .68882 m .74082 .67123 L .77212 .67551 L p .707 .577 .707 r
F P
0 g
s
.70794 .68852 m .70914 .67094 L .74082 .67123 L p .707 .577 .707 r
F P
0 g
s
.4845 .69871 m .48174 .71733 L .48797 .71176 L p .707 .577 .707 r
F P
0 g
s
.48797 .71176 m .49073 .69313 L .4845 .69871 L p .707 .577 .707 r
F P
0 g
s
.28957 .68839 m .29233 .66977 L .28867 .6627 L p .707 .577 .707 r
F P
0 g
s
.74082 .67123 m .73962 .68882 L .70794 .68852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28867 .6627 m .28591 .68133 L .28957 .68839 L p .707 .577 .707 r
F P
0 g
s
.4981 .60952 m .50184 .64594 L .49906 .63639 L p .707 .577 .707 r
F P
0 g
s
.49906 .63639 m .49532 .59996 L .4981 .60952 L p .707 .577 .707 r
F P
0 g
s
.48749 .5129 m .49875 .56599 L .48697 .55792 L p .707 .577 .707 r
F P
0 g
s
.48697 .55792 m .4757 .50484 L .48749 .5129 L p .707 .577 .707 r
F P
0 g
s
.3013 .60782 m .29004 .55474 L .29758 .54258 L p .707 .577 .707 r
F P
0 g
s
.29521 .62398 m .29895 .6604 L .30172 .66995 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29895 .6604 m .29521 .62398 L .30237 .61371 L p .707 .577 .707 r
F P
0 g
s
.29758 .54258 m .30884 .59566 L .3013 .60782 L p .707 .577 .707 r
F P
0 g
s
.49073 .69313 m .48797 .71176 L .48431 .70469 L p .707 .577 .707 r
F P
0 g
s
.48431 .70469 m .48707 .68607 L .49073 .69313 L p .707 .577 .707 r
F P
0 g
s
.28591 .68133 m .28867 .6627 L .2949 .65713 L p .707 .577 .707 r
F P
0 g
s
.2949 .65713 m .29214 .67575 L .28591 .68133 L p .707 .577 .707 r
F P
0 g
s
.4757 .50484 m .48697 .55792 L .46678 .55322 L p .707 .577 .707 r
F P
0 g
s
.46678 .55322 m .45552 .50013 L .4757 .50484 L p .707 .577 .707 r
F P
0 g
s
.30884 .59566 m .29758 .54258 L .31416 .53008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49532 .59996 m .49906 .63639 L .48663 .62847 L p .707 .577 .707 r
F P
0 g
s
.48663 .62847 m .48289 .59205 L .49532 .59996 L p .707 .577 .707 r
F P
0 g
s
.30237 .61371 m .3061 .65013 L .29895 .6604 L p .707 .577 .707 r
F P
0 g
s
.31416 .53008 m .32542 .58317 L .30884 .59566 L p .707 .577 .707 r
F P
0 g
s
.3061 .65013 m .30237 .61371 L .31875 .60375 L p .707 .577 .707 r
F P
0 g
s
.45552 .50013 m .46678 .55322 L .44016 .55233 L p .707 .577 .707 r
F P
0 g
s
.44016 .55233 m .4289 .49925 L .45552 .50013 L p .707 .577 .707 r
F P
0 g
s
.32542 .58317 m .31416 .53008 L .33815 .51848 L p .707 .577 .707 r
F P
0 g
s
.48707 .68607 m .48431 .70469 L .47112 .69683 L p .707 .577 .707 r
F P
0 g
s
.47112 .69683 m .47388 .6782 L .48707 .68607 L p .707 .577 .707 r
F P
0 g
s
.29214 .67575 m .2949 .65713 L .31041 .65359 L p .707 .577 .707 r
F P
0 g
s
.48289 .59205 m .48663 .62847 L .46575 .62298 L p .707 .577 .707 r
F P
0 g
s
.46575 .62298 m .46202 .58656 L .48289 .59205 L p .707 .577 .707 r
F P
0 g
s
.31041 .65359 m .30765 .67221 L .29214 .67575 L p .707 .577 .707 r
F P
0 g
s
.31875 .60375 m .32249 .64017 L .3061 .65013 L p .707 .577 .707 r
F P
0 g
s
.4289 .49925 m .44016 .55233 L .40973 .55535 L p .707 .577 .707 r
F P
0 g
s
.40973 .55535 m .39847 .50226 L .4289 .49925 L p .707 .577 .707 r
F P
0 g
s
.34941 .57156 m .33815 .51848 L .3672 .50889 L p .707 .577 .707 r
F P
0 g
s
.33815 .51848 m .34941 .57156 L .32542 .58317 L p .707 .577 .707 r
F P
0 g
s
.32249 .64017 m .31875 .60375 L .34276 .59506 L p .707 .577 .707 r
F P
0 g
s
.39847 .50226 m .40973 .55535 L .37846 .56197 L p .707 .577 .707 r
F P
0 g
s
.37846 .56197 m .3672 .50889 L .39847 .50226 L p .707 .577 .707 r
F P
0 g
s
.3672 .50889 m .37846 .56197 L .34941 .57156 L p .707 .577 .707 r
F P
0 g
s
.47388 .6782 m .47112 .69683 L .44968 .68894 L p .707 .577 .707 r
F P
0 g
s
.44968 .68894 m .45245 .67031 L .47388 .6782 L p .707 .577 .707 r
F P
0 g
s
.46202 .58656 m .46575 .62298 L .43848 .62044 L p .707 .577 .707 r
F P
0 g
s
.43848 .62044 m .43474 .58402 L .46202 .58656 L p .707 .577 .707 r
F P
0 g
s
.30765 .67221 m .31041 .65359 L .33368 .65243 L p .707 .577 .707 r
F P
0 g
s
.34276 .59506 m .3465 .63148 L .32249 .64017 L p .707 .577 .707 r
F P
0 g
s
.33368 .65243 m .33092 .67105 L .30765 .67221 L p .707 .577 .707 r
F P
0 g
s
.3465 .63148 m .34276 .59506 L .37205 .58849 L p .707 .577 .707 r
F P
0 g
s
.43474 .58402 m .43848 .62044 L .40748 .62111 L p .707 .577 .707 r
F P
0 g
s
.40748 .62111 m .40374 .58468 L .43474 .58402 L p .707 .577 .707 r
F P
0 g
s
.45245 .67031 m .44968 .68894 L .42211 .68179 L p .707 .577 .707 r
F P
0 g
s
.42211 .68179 m .42487 .66317 L .45245 .67031 L p .707 .577 .707 r
F P
0 g
s
.37579 .62491 m .37205 .58849 L .40374 .58468 L p .707 .577 .707 r
F P
0 g
s
.37205 .58849 m .37579 .62491 L .3465 .63148 L p .707 .577 .707 r
F P
0 g
s
.33092 .67105 m .33368 .65243 L .36243 .65376 L p .707 .577 .707 r
F P
0 g
s
.40374 .58468 m .40748 .62111 L .37579 .62491 L p .707 .577 .707 r
F P
0 g
s
.36243 .65376 m .35967 .67239 L .33092 .67105 L p .707 .577 .707 r
F P
0 g
s
.42487 .66317 m .42211 .68179 L .39109 .67609 L p .707 .577 .707 r
F P
0 g
s
.39109 .67609 m .39386 .65746 L .42487 .66317 L p .707 .577 .707 r
F P
0 g
s
.35967 .67239 m .36243 .65376 L .39386 .65746 L p .707 .577 .707 r
F P
0 g
s
.39386 .65746 m .39109 .67609 L .35967 .67239 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001EYF5@000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00H005YFFUIJEP00FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP04000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00HWoo0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00Ggoo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001KOol20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00FGoo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol005Qoo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001FOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005Aoo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001C
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0059oo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUH0
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
DWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP04001J
EUYFFUH20005FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01EYF100000AJEP00000000QJEP04001JEP000007FUH00`00FUIJEP02FUH40005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000:Woo2`00<Goo001C
Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH50005FUH400000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF000067oo4P000eYF00<005YFFUH00eYF00<005YF00000P00;Woo001COol0
0`00FUH00005FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH:0005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00011oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP02FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000Qoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001J
EP0^Ool005=oo`04001JEUYF0005FUH01000FUIJEUYF0P000goo00<005YFFUH02P000eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001C
Ool01000FUIJEP001EYF00<005YF00002@0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001JEP0^Ool005Aoo`03001J
EP0000EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0041oo`l000Eoo`03001JEP0000AJ
EP8000IJEP03001JEUYF00MJEQP00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo000jOol60004FUH00`00FUIJEP06FUH00`00FUH0000300001Woo001JEUYF001JEP80009J
EP03001JEUYF00AJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
00020004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH015YF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF000^Ool003Aoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000cOol20006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0031oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF000]Ool002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH70004FUH70005FUH70003FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUHB0007FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP040002FUH90006FUH00`00FUIJEP09FUH50002FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000eYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0039oo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00=JEPX000=JEPD000MJEP03001JEUYF00QJEP8000AJEP@000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00H000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJ
EP04001JEUYFFUH20002FUH00`00FUH00003FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP05FUH3
00000eYF001JEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF4@00?7oo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0005FUH01000FUIJEP0015YF00@005YF0000
00AJEP03001JEP0000=JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH40004FUH00`00FUIJEP02
FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH6
000fOol002eoo`03001JEP0000=JEP03001JEUYF00=JEPH000moo`@00003FUH005YF009JEP04001J
EUYFFUH20005FUH01000FUIJEP000eYF00<005YFFUH00eYF0`0025YF10000UYF00<005YFFUH00eYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEQ4000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00D0035oo`00;Goo00<005YF00000eYF00<005YF00000`006Goo0`000UYF00<005YF00002@000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00L000IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00004Ool5
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool002aoo`03001JEP0000AJEP8001moo`03001JEUYF008000EJEP04
001JEUYFFUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF0`0057oo0`002Goo00<005YF00005000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool002aoo`03001JEP0000800003FUH005YF0080015oo`D000Moo`<0009J
EP03001JEUYF00=JEP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH0
0003FUH01@00FUIJEUYF000047oo1@001Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH0100000=JEP00FUH025YF00<005YFFUH00eYF00<005YFFUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH2000>Ool50006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH00`00
FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0P000eYF00<005YFFUH00eYF00@0
05YF000000eoo`<000Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF0`0057oo00=JEP00FUH00UYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH000000080
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH03`0025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUHB000017oo001JEP000UYF1@0015YF
00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH01000
FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH04`000eYF00<005YFFUH00P00;Goo000/Ool2
0003FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000006
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009J
EP8002eoo`00;7oo0P000eYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YF00001@0000=JEP00FUH01EYF00<005YFFUH01UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00H005YFFUH005YF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000040006FUH01000FUIJEUYF1000;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF00<005YF
FUH00UYF2@001EYF10000UYF00<005YFFUH015YF00@005YF000000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001EYF00@005YFFUIJEP<002eoo`00;Goo00<0
05YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH0000000H000=JEPD000MJEP03001JEUYF00<000EJ
EP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP02FUH@0006FUH00`00FUIJEP05FUH3
0003FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH00eYF1@000UYF00<0
05YFFUH00UYF1@001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH30008FUH00`00
FUIJEP05FUH200000eYF001JEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH40006FUH00`00FUIJEP02FUH20002FUH2000_Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00MJEP8000=JEP03001JEP0000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH3000aOol0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJ
EPH00004FUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0
00000UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00@005YF0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPP000=JEP03001JEUYF00<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP05001JEUYFFUH0000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000IJER4000Qoo`80
0003FUH005YF009JEP03001oogoo02eoo`00;Goo0P0015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01UYF1P001UYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH000020006FUH00`00FUIJEP03FUH01000FUIJEUYF0P007goo0P000eYF00<007ooOol0
;Goo000]Ool20004FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01000FUIJEP000UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00001P0000=JEP00FUH01EYF00<005YFFUH00P002Goo0`005Woo00<005YFFUH00P00;Woo000/
Ool00`00FUH00003FUH30005Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH01000FUIJEP000eYF00<005YFFUH015YF2@0015YF00@005YFFUIJEPH000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP<000IJEP03
001JEUYF008000Qoo`D001Ioo`@002ioo`00;7oo00@005YF001JEP8000]oo`@000IJEP@000EJEP03
001JEUYF00EJEP03001JEP0000@000=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH000020003FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0027oo1@0067oo0P00;Woo000/Ool0
1@00FUH00000FUH00P003Woo10000UYF1@0015YF00<005YFFUH00UYF1@001Goo0P0000EJEP00FUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001JEP0200000eYF001JEP03FUH2
00000eYF001JEP02FUH20008Ool5000HOol2000^Ool002aoo`8000=JEP03001JEP00008000mooa00
00aoo`80009JEP05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF0`0015YF0`00
0UYF00<005YF00002Goo0`0067oo0`00;Woo000/Ool20003FUH00`00FUIJEP02FUH3000>Ool5000E
Ool300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF20000UYF
0`0000=JEP00Ool08goo00<005YF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003
000;Ool3000DOol20003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF
00<005YFFUH00`0000AJEP000000009JEP8002=oo`<00003FUH007oo02eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF1P0067oo100000=JEP00FUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP<0009JEP@0021oo`<0009JEP80
02moo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000Yoo`D000EJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10001EYF00<005YF00001@007Woo0P0000=J
EP00FUH00UYF0P00;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2P000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF00MJEP04001JEUYFFUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEPL001Moo`8000=JEP05001J
EUYFFUH0000`Ool002eoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF1P002UYF00<005YFFUH02UYF00<005YFFUH02EYF1`000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000Uoo`D000AJEP04001J
EUYFFUH2000`Ool002ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@000IJEP05001JEUYFFUH00005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90003FUH00`00FUIJEP03FUH01000FUH00000<Woo000_Ool20005FUH00`00FUIJEP06FUH00`00
FUIJEP05FUHO0003FUH00`00FUIJEP03FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH30004FUH01@00FUIJEUYF00001UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00=7oo000`Ool00`00FUIJEP03FUH0
0`00FUIJEP05FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000eYF00<005YF00000`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH015YF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH2
000fOol0035oo`8000=JEP03001JEP0000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH00000>7oo000bOol60002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH02`000UYF00H005YFFUH005YF0003Ool90004FUH00`00FUIJEP02FUH5000jOol002mo
o`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5
0007FUH00`00FUH000020002FUH00`00FUH0000<Ool9000oOol002eoo`<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF009JEQP000=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH4001EOol002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF009JEPd000AJEP03001JEUYF009JEPT0009JEPH000AJEP03001JEUYF
00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP06001JEUYF001JEP001UYF00<005YFFUH00eYF0`00EGoo000]Ool00`00
FUH00004FUH01000FUIJEUYF1`0017oo50000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP001eYF00<005YFFUH00UYF00<005YFFUH0
0P00Dgoo000]Ool00`00FUH00003FUHK0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF000015YF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH00eYF
00@005YFFUH005=oo`00;Woo0P0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF00L000=JEP03001JEUYF0080059oo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEPD0009oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00@0009JEP80059oo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Goo0`001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1P00DWoo000_Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000BOol20005FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP030003Ool2001BOol0035ooah001eoo`80
00=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000MJEP04001JEUYFFUH60005Ool3001BOol006ioo`800003FUH005YF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00
00l000Yoo`800003FUH007oo055oo`00L7oo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF100067oo0P0000AJEP00FUH0059oo`00M7oo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02P005Goo0P0015YF0P00DWoo001j
Ool80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH80005Ool5000COol200000eYF001JEP03FUH0
0`00Oomoo`1AOol0089ooaX000eoo`D0015oo`8000=JEP03001JEUYF009JEP03001oogoo055oo`00
T7oo00@005YFFUH001Ioo`<000moo`<000EJEP03001JEUYF008005Aoo`00TGoo0P009goo0P0000=J
EP00FUH01EYF0`00EWoo002AOol3000SOol30003FUH00`00FUIJEP04FUH00`00Oomoo`1FOol0095o
o`03001JEUYF00@001Uoo`H000MJEP04001JEUYFFUH2001IOol0095oo`80009JEP03001JEUYF00L0
00Uoo`T000AJEP03001JEUYF00IJEP04001JEP00001KOol0099oo`04001JEUYF0005FUH01000FUIJ
EUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF0`00GGoo002BOol01@00FUIJEUYF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00H7oo002COol2
00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002
001ROol009Eoo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH006Eoo`00
VGoo1`0015YF00<005YFFUH00UYF2@00Jgoo002POol9001dOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60166 .75781 m .5903 .70484 L .55965 .70826 L p .707 .577 .707 r
F P
0 g
s
.5903 .70484 m .60166 .75781 L .63283 .75078 L p .707 .577 .707 r
F P
0 g
s
.63283 .75078 m .62147 .69781 L .5903 .70484 L p .707 .577 .707 r
F P
0 g
s
.62147 .69781 m .63283 .75078 L .66148 .74084 L p .707 .577 .707 r
F P
0 g
s
.66148 .74084 m .65011 .68787 L .62147 .69781 L p .707 .577 .707 r
F P
0 g
s
.57101 .76123 m .55965 .70826 L .53252 .70775 L p .707 .577 .707 r
F P
0 g
s
.55965 .70826 m .57101 .76123 L .60166 .75781 L p .707 .577 .707 r
F P
0 g
s
.65011 .68787 m .66148 .74084 L .68479 .72897 L p .707 .577 .707 r
F P
0 g
s
.68479 .72897 m .67343 .67599 L .65011 .68787 L p .707 .577 .707 r
F P
0 g
s
.59965 .81408 m .5959 .77766 L .56487 .77838 L p .707 .577 .707 r
F P
0 g
s
.5959 .77766 m .59965 .81408 L .63133 .81022 L p .707 .577 .707 r
F P
0 g
s
.63133 .81022 m .62758 .7738 L .5959 .77766 L p .707 .577 .707 r
F P
0 g
s
.62758 .7738 m .63133 .81022 L .66055 .8036 L p .707 .577 .707 r
F P
0 g
s
.66055 .8036 m .6568 .76719 L .62758 .7738 L p .707 .577 .707 r
F P
0 g
s
.54389 .76072 m .53252 .70775 L .51157 .70335 L p .707 .577 .707 r
F P
0 g
s
.53252 .70775 m .54389 .76072 L .57101 .76123 L p .707 .577 .707 r
F P
0 g
s
.67343 .67599 m .68479 .72897 L .70049 .71631 L p .707 .577 .707 r
F P
0 g
s
.70049 .71631 m .68912 .66333 L .67343 .67599 L p .707 .577 .707 r
F P
0 g
s
.56861 .8148 m .56487 .77838 L .53751 .77589 L p .707 .577 .707 r
F P
0 g
s
.56487 .77838 m .56861 .8148 L .59965 .81408 L p .707 .577 .707 r
F P
0 g
s
.58318 .84556 m .5859 .82695 L .55525 .82099 L p .707 .577 .707 r
F P
0 g
s
.5859 .82695 m .58318 .84556 L .61476 .84955 L p .707 .577 .707 r
F P
0 g
s
.61476 .84955 m .61748 .83094 L .5859 .82695 L p .707 .577 .707 r
F P
0 g
s
.6568 .76719 m .66055 .8036 L .68445 .79487 L p .707 .577 .707 r
F P
0 g
s
.68445 .79487 m .6807 .75845 L .6568 .76719 L p .707 .577 .707 r
F P
0 g
s
.61748 .83094 m .61476 .84955 L .64419 .85118 L p .707 .577 .707 r
F P
0 g
s
.64419 .85118 m .64691 .83257 L .61748 .83094 L p .707 .577 .707 r
F P
0 g
s
.55525 .82099 m .55253 .83959 L .58318 .84556 L p .707 .577 .707 r
F P
0 g
s
.55253 .83959 m .55525 .82099 L .52854 .81363 L p .707 .577 .707 r
F P
0 g
s
.53751 .77589 m .54125 .81231 L .56861 .8148 L p .707 .577 .707 r
F P
0 g
s
.52854 .81363 m .52582 .83224 L .55253 .83959 L p .707 .577 .707 r
F P
0 g
s
.51157 .70335 m .52294 .75632 L .54389 .76072 L p .707 .577 .707 r
F P
0 g
s
.54125 .81231 m .53751 .77589 L .51651 .77044 L p .707 .577 .707 r
F P
0 g
s
.52294 .75632 m .51157 .70335 L .49885 .69549 L p .707 .577 .707 r
F P
0 g
s
.64691 .83257 m .64419 .85118 L .66859 .85028 L p .707 .577 .707 r
F P
0 g
s
.66859 .85028 m .67131 .83167 L .64691 .83257 L p .707 .577 .707 r
F P
0 g
s
.68912 .66333 m .70049 .71631 L .70703 .70411 L p .707 .577 .707 r
F P
0 g
s
.70703 .70411 m .69567 .65114 L .68912 .66333 L p .707 .577 .707 r
F P
0 g
s
.6807 .75845 m .68445 .79487 L .70069 .78488 L p .707 .577 .707 r
F P
0 g
s
.70069 .78488 m .69694 .74846 L .6807 .75845 L p .707 .577 .707 r
F P
0 g
s
.52582 .83224 m .52854 .81363 L .50839 .8056 L p .707 .577 .707 r
F P
0 g
s
.51651 .77044 m .52025 .80686 L .54125 .81231 L p .707 .577 .707 r
F P
0 g
s
.50839 .8056 m .50567 .82421 L .52582 .83224 L p .707 .577 .707 r
F P
0 g
s
.49885 .69549 m .51022 .74847 L .52294 .75632 L p .707 .577 .707 r
F P
0 g
s
.67131 .83167 m .66859 .85028 L .68556 .84695 L p .707 .577 .707 r
F P
0 g
s
.68556 .84695 m .68829 .82834 L .67131 .83167 L p .707 .577 .707 r
F P
0 g
s
.52025 .80686 m .51651 .77044 L .50392 .76256 L p .707 .577 .707 r
F P
0 g
s
.51022 .74847 m .49885 .69549 L .49561 .68495 L p .707 .577 .707 r
F P
0 g
s
.50567 .82421 m .50839 .8056 L .49676 .79769 L p .707 .577 .707 r
F P
0 g
s
.69694 .74846 m .70069 .78488 L .70768 .77461 L p .707 .577 .707 r
F P
0 g
s
.70768 .77461 m .70393 .73819 L .69694 .74846 L p .707 .577 .707 r
F P
0 g
s
.50392 .76256 m .50767 .79897 L .52025 .80686 L p .707 .577 .707 r
F P
0 g
s
.69567 .65114 m .70703 .70411 L .70379 .69357 L p .707 .577 .707 r
F P
0 g
s
.70379 .69357 m .69242 .6406 L .69567 .65114 L p .707 .577 .707 r
F P
0 g
s
.49676 .79769 m .49404 .8163 L .50567 .82421 L p .707 .577 .707 r
F P
0 g
s
.68829 .82834 m .68556 .84695 L .69346 .8415 L p .707 .577 .707 r
F P
0 g
s
.69346 .8415 m .69618 .82289 L .68829 .82834 L p .707 .577 .707 r
F P
0 g
s
.49561 .68495 m .50697 .73793 L .51022 .74847 L p .707 .577 .707 r
F P
0 g
s
.50767 .79897 m .50392 .76256 L .50098 .75301 L p .707 .577 .707 r
F P
0 g
s
.50697 .73793 m .49561 .68495 L .50215 .67275 L p .707 .577 .707 r
F P
0 g
s
.49404 .8163 m .49676 .79769 L .4948 .79067 L p .707 .577 .707 r
F P
0 g
s
.4948 .79067 m .49208 .80927 L .49404 .8163 L p .707 .577 .707 r
F P
0 g
s
.49208 .80927 m .4948 .79067 L .50269 .78522 L p .707 .577 .707 r
F P
0 g
s
.50269 .78522 m .49997 .80383 L .49208 .80927 L p .707 .577 .707 r
F P
0 g
s
.50098 .75301 m .50472 .78943 L .50767 .79897 L p .707 .577 .707 r
F P
0 g
s
.50472 .78943 m .50098 .75301 L .50797 .74274 L p .707 .577 .707 r
F P
0 g
s
.50797 .74274 m .51172 .77916 L .50472 .78943 L p .707 .577 .707 r
F P
0 g
s
.49997 .80383 m .50269 .78522 L .51966 .78188 L p .707 .577 .707 r
F P
0 g
s
.51966 .78188 m .51694 .80049 L .49997 .80383 L p .707 .577 .707 r
F P
0 g
s
.50018 .82192 m .50018 .32003 L .4556 .31816 L p .707 .577 .707 r
F P
0 g
s
.50215 .67275 m .51352 .72573 L .50697 .73793 L p .707 .577 .707 r
F P
0 g
s
.51352 .72573 m .50215 .67275 L .51785 .6601 L p .707 .577 .707 r
F P
0 g
s
.51785 .6601 m .52921 .71307 L .51352 .72573 L p .707 .577 .707 r
F P
0 g
s
.51172 .77916 m .50797 .74274 L .52421 .73275 L p .707 .577 .707 r
F P
0 g
s
.52921 .71307 m .51785 .6601 L .54116 .64822 L p .707 .577 .707 r
F P
0 g
s
.52421 .73275 m .52796 .76917 L .51172 .77916 L p .707 .577 .707 r
F P
0 g
s
.54116 .64822 m .55252 .70119 L .52921 .71307 L p .707 .577 .707 r
F P
0 g
s
.52796 .76917 m .52421 .73275 L .54811 .72402 L p .707 .577 .707 r
F P
0 g
s
.54811 .72402 m .55186 .76044 L .52796 .76917 L p .707 .577 .707 r
F P
0 g
s
.51694 .80049 m .51966 .78188 L .54406 .78099 L p .707 .577 .707 r
F P
0 g
s
.54406 .78099 m .54134 .79959 L .51694 .80049 L p .707 .577 .707 r
F P
0 g
s
.54134 .79959 m .54406 .78099 L .57349 .78261 L p .707 .577 .707 r
F P
0 g
s
.57349 .78261 m .57077 .80122 L .54134 .79959 L p .707 .577 .707 r
F P
0 g
s
.50018 .32003 m .50018 .82192 L .54475 .82001 L p .707 .577 .707 r
F P
0 g
s
.55252 .70119 m .54116 .64822 L .5698 .63828 L p .707 .577 .707 r
F P
0 g
s
.54475 .82001 m .54475 .31813 L .50018 .32003 L p .707 .577 .707 r
F P
0 g
s
.4556 .82004 m .4556 .31816 L .41536 .31267 L p .707 .577 .707 r
F P
0 g
s
.4556 .31816 m .4556 .82004 L .50018 .82192 L p .707 .577 .707 r
F P
0 g
s
.58117 .69125 m .5698 .63828 L .60098 .63125 L p .707 .577 .707 r
F P
0 g
s
.5698 .63828 m .58117 .69125 L .55252 .70119 L p .707 .577 .707 r
F P
0 g
s
.55186 .76044 m .54811 .72402 L .57733 .7174 L p .707 .577 .707 r
F P
0 g
s
.57733 .7174 m .58108 .75382 L .55186 .76044 L p .707 .577 .707 r
F P
0 g
s
.57077 .80122 m .57349 .78261 L .60508 .7866 L p .707 .577 .707 r
F P
0 g
s
.60508 .7866 m .60235 .80521 L .57077 .80122 L p .707 .577 .707 r
F P
0 g
s
.54475 .31813 m .54475 .82001 L .58493 .8145 L p .707 .577 .707 r
F P
0 g
s
.60098 .63125 m .61234 .68423 L .58117 .69125 L p .707 .577 .707 r
F P
0 g
s
.58108 .75382 m .57733 .7174 L .60901 .71354 L p .707 .577 .707 r
F P
0 g
s
.60901 .71354 m .61275 .74996 L .58108 .75382 L p .707 .577 .707 r
F P
0 g
s
.58493 .8145 m .58493 .31261 L .54475 .31813 L p .707 .577 .707 r
F P
0 g
s
.70393 .73819 m .70768 .77461 L .70474 .76507 L p .707 .577 .707 r
F P
0 g
s
.70474 .76507 m .70099 .72865 L .70393 .73819 L p .707 .577 .707 r
F P
0 g
s
.69242 .6406 m .70379 .69357 L .69107 .68571 L p .707 .577 .707 r
F P
0 g
s
.69107 .68571 m .6797 .63274 L .69242 .6406 L p .707 .577 .707 r
F P
0 g
s
.69618 .82289 m .69346 .8415 L .69149 .83448 L p .707 .577 .707 r
F P
0 g
s
.69149 .83448 m .69421 .81587 L .69618 .82289 L p .707 .577 .707 r
F P
0 g
s
.41536 .81456 m .41536 .31267 L .38341 .30412 L p .707 .577 .707 r
F P
0 g
s
.41536 .31267 m .41536 .81456 L .4556 .82004 L p .707 .577 .707 r
F P
0 g
s
.61234 .68423 m .60098 .63125 L .63163 .62783 L p .707 .577 .707 r
F P
0 g
s
.64005 .71282 m .64379 .74924 L .61275 .74996 L p .707 .577 .707 r
F P
0 g
s
.61275 .74996 m .60901 .71354 L .64005 .71282 L p .707 .577 .707 r
F P
0 g
s
.63572 .79257 m .633 .81118 L .60235 .80521 L p .707 .577 .707 r
F P
0 g
s
.60235 .80521 m .60508 .7866 L .63572 .79257 L p .707 .577 .707 r
F P
0 g
s
.58493 .31261 m .58493 .8145 L .6168 .80593 L p .707 .577 .707 r
F P
0 g
s
.63163 .62783 m .64299 .6808 L .61234 .68423 L p .707 .577 .707 r
F P
0 g
s
.6168 .80593 m .6168 .30404 L .58493 .31261 L p .707 .577 .707 r
F P
0 g
s
.25689 .69401 m .25194 .6367 L .22075 .63888 L p .707 .577 .707 r
F P
0 g
s
.25194 .6367 m .25689 .69401 L .28855 .69103 L p .707 .577 .707 r
F P
0 g
s
.28855 .69103 m .28359 .63371 L .25194 .6367 L p .707 .577 .707 r
F P
0 g
s
.28359 .63371 m .28855 .69103 L .31757 .68752 L p .707 .577 .707 r
F P
0 g
s
.31757 .68752 m .31262 .63021 L .28359 .63371 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22075 .63888 m .2257 .69619 L .25689 .69401 L p .707 .577 .707 r
F P
0 g
s
.70099 .72865 m .70474 .76507 L .69215 .75718 L p .707 .577 .707 r
F P
0 g
s
.69215 .75718 m .68841 .72077 L .70099 .72865 L p .707 .577 .707 r
F P
0 g
s
.6797 .63274 m .69107 .68571 L .67012 .68132 L p .707 .577 .707 r
F P
0 g
s
.67012 .68132 m .65875 .62834 L .6797 .63274 L p .707 .577 .707 r
F P
0 g
s
.2257 .69619 m .22075 .63888 L .19309 .64004 L p .707 .577 .707 r
F P
0 g
s
.19309 .64004 m .19804 .69735 L .2257 .69619 L p .707 .577 .707 r
F P
0 g
s
.31262 .63021 m .31757 .68752 L .34113 .68385 L p .707 .577 .707 r
F P
0 g
s
.34113 .68385 m .33618 .62653 L .31262 .63021 L p .707 .577 .707 r
F P
0 g
s
.25489 .76443 m .25328 .72658 L .22211 .72666 L p .707 .577 .707 r
F P
0 g
s
.25328 .72658 m .25489 .76443 L .28668 .7626 L p .707 .577 .707 r
F P
0 g
s
.28668 .7626 m .28507 .72475 L .25328 .72658 L p .707 .577 .707 r
F P
0 g
s
.28507 .72475 m .28668 .7626 L .316 .75919 L p .707 .577 .707 r
F P
0 g
s
.316 .75919 m .31439 .72134 L .28507 .72475 L p .707 .577 .707 r
F P
0 g
s
.38341 .80601 m .38341 .30412 L .36287 .29334 L p .707 .577 .707 r
F P
0 g
s
.38341 .30412 m .38341 .80601 L .41536 .81456 L p .707 .577 .707 r
F P
0 g
s
.19804 .69735 m .19309 .64004 L .17165 .64007 L p .707 .577 .707 r
F P
0 g
s
.633 .81118 m .63572 .79257 L .66243 .79993 L p .707 .577 .707 r
F P
0 g
s
.6168 .30404 m .6168 .80593 L .63724 .79513 L p .707 .577 .707 r
F P
0 g
s
.64299 .6808 m .63163 .62783 L .65875 .62834 L p .707 .577 .707 r
F P
0 g
s
.63724 .79513 m .63724 .29324 L .6168 .30404 L p .707 .577 .707 r
F P
0 g
s
.69421 .81587 m .69149 .83448 L .67986 .82656 L p .707 .577 .707 r
F P
0 g
s
.67986 .82656 m .68258 .80796 L .69421 .81587 L p .707 .577 .707 r
F P
0 g
s
.22211 .72666 m .22372 .76451 L .25489 .76443 L p .707 .577 .707 r
F P
0 g
s
.22372 .76451 m .22211 .72666 L .19462 .72497 L p .707 .577 .707 r
F P
0 g
s
.17165 .64007 m .1766 .69738 L .19804 .69735 L p .707 .577 .707 r
F P
0 g
s
.65875 .62834 m .67012 .68132 L .64299 .6808 L p .707 .577 .707 r
F P
0 g
s
.19462 .72497 m .19623 .76282 L .22372 .76451 L p .707 .577 .707 r
F P
0 g
s
.31439 .72134 m .316 .75919 L .33996 .75453 L p .707 .577 .707 r
F P
0 g
s
.33996 .75453 m .33835 .71668 L .31439 .72134 L p .707 .577 .707 r
F P
0 g
s
.68841 .72077 m .69215 .75718 L .67115 .75173 L p .707 .577 .707 r
F P
0 g
s
.67115 .75173 m .66741 .71531 L .68841 .72077 L p .707 .577 .707 r
F P
0 g
s
.33618 .62653 m .34113 .68385 L .35691 .68036 L p .707 .577 .707 r
F P
0 g
s
.35691 .68036 m .35196 .62305 L .33618 .62653 L p .707 .577 .707 r
F P
0 g
s
.19623 .76282 m .19462 .72497 L .1735 .72168 L p .707 .577 .707 r
F P
0 g
s
.1766 .69738 m .17165 .64007 L .15855 .63895 L p .707 .577 .707 r
F P
0 g
s
.1735 .72168 m .17511 .75953 L .19623 .76282 L p .707 .577 .707 r
F P
0 g
s
.24625 .82541 m .24741 .80786 L .21648 .80296 L p .707 .577 .707 r
F P
0 g
s
.24741 .80786 m .24625 .82541 L .27809 .82632 L p .707 .577 .707 r
F P
0 g
s
.27809 .82632 m .27925 .80877 L .24741 .80786 L p .707 .577 .707 r
F P
0 g
s
.27925 .80877 m .27809 .82632 L .30772 .82315 L p .707 .577 .707 r
F P
0 g
s
.30772 .82315 m .30888 .8056 L .27925 .80877 L p .707 .577 .707 r
F P
0 g
s
.15855 .63895 m .1635 .69627 L .1766 .69738 L p .707 .577 .707 r
F P
0 g
s
.68258 .80796 m .67986 .82656 L .65971 .81854 L p .707 .577 .707 r
F P
0 g
s
.65971 .81854 m .66243 .79993 L .68258 .80796 L p .707 .577 .707 r
F P
0 g
s
.33835 .71668 m .33996 .75453 L .35622 .74908 L p .707 .577 .707 r
F P
0 g
s
.35622 .74908 m .35461 .71123 L .33835 .71668 L p .707 .577 .707 r
F P
0 g
s
.21532 .82051 m .21648 .80296 L .18949 .79456 L p .707 .577 .707 r
F P
0 g
s
.21648 .80296 m .21532 .82051 L .24625 .82541 L p .707 .577 .707 r
F P
0 g
s
.66741 .71531 m .67115 .75173 L .64379 .74924 L p .707 .577 .707 r
F P
0 g
s
.64379 .74924 m .64005 .71282 L .66741 .71531 L p .707 .577 .707 r
F P
0 g
s
.35196 .62305 m .35691 .68036 L .36337 .6774 L p .707 .577 .707 r
F P
0 g
s
.36337 .6774 m .35842 .62009 L .35196 .62305 L p .707 .577 .707 r
F P
0 g
s
.35461 .71123 m .35622 .74908 L .36319 .74338 L p .707 .577 .707 r
F P
0 g
s
.36319 .74338 m .36158 .70553 L .35461 .71123 L p .707 .577 .707 r
F P
0 g
s
.35842 .62009 m .36337 .6774 L .35988 .67526 L p .707 .577 .707 r
F P
0 g
s
.36158 .70553 m .36319 .74338 L .36019 .73798 L p .707 .577 .707 r
F P
0 g
s
.36287 .79523 m .36287 .29334 L .35575 .28138 L p .707 .577 .707 r
F P
0 g
s
.36287 .29334 m .36287 .79523 L .38341 .80601 L p .707 .577 .707 r
F P
0 g
s
.18949 .79456 m .18833 .81211 L .21532 .82051 L p .707 .577 .707 r
F P
0 g
s
.30888 .8056 m .30772 .82315 L .33225 .81622 L p .707 .577 .707 r
F P
0 g
s
.33225 .81622 m .33341 .79867 L .30888 .8056 L p .707 .577 .707 r
F P
0 g
s
.63724 .29324 m .63724 .79513 L .64424 .78317 L p .707 .577 .707 r
F P
0 g
s
.64424 .78317 m .64424 .28128 L .63724 .29324 L p .707 .577 .707 r
F P
0 g
s
.17511 .75953 m .1735 .72168 L .16082 .71711 L p .707 .577 .707 r
F P
0 g
s
.18833 .81211 m .18949 .79456 L .16908 .78347 L p .707 .577 .707 r
F P
0 g
s
.16082 .71711 m .16243 .75496 L .17511 .75953 L p .707 .577 .707 r
F P
0 g
s
.66243 .79993 m .65971 .81854 L .633 .81118 L p .707 .577 .707 r
F P
0 g
s
.1635 .69627 m .15855 .63895 L .15505 .63682 L p .707 .577 .707 r
F P
0 g
s
.16908 .78347 m .16792 .80102 L .18833 .81211 L p .707 .577 .707 r
F P
0 g
s
.15505 .63682 m .16001 .69413 L .1635 .69627 L p .707 .577 .707 r
F P
0 g
s
.33341 .79867 m .33225 .81622 L .34927 .8062 L p .707 .577 .707 r
F P
0 g
s
.34927 .8062 m .35043 .78865 L .33341 .79867 L p .707 .577 .707 r
F P
0 g
s
.16792 .80102 m .16908 .78347 L .15724 .77078 L p .707 .577 .707 r
F P
0 g
s
.16243 .75496 m .16082 .71711 L .15782 .71171 L p .707 .577 .707 r
F P
0 g
s
.35988 .67526 m .35493 .61795 L .35842 .62009 L p .707 .577 .707 r
F P
0 g
s
.15724 .77078 m .15608 .78833 L .16792 .80102 L p .707 .577 .707 r
F P
0 g
s
.15782 .71171 m .15943 .74956 L .16243 .75496 L p .707 .577 .707 r
F P
0 g
s
.35711 .79407 m .35827 .77652 L .35043 .78865 L p .707 .577 .707 r
F P
0 g
s
.36019 .73798 m .35858 .70013 L .36158 .70553 L p .707 .577 .707 r
F P
0 g
s
.35493 .61795 m .35988 .67526 L .34678 .67415 L p .707 .577 .707 r
F P
0 g
s
.35827 .77652 m .35711 .79407 L .35502 .78103 L p .707 .577 .707 r
F P
0 g
s
.35502 .78103 m .35618 .76348 L .35827 .77652 L p .707 .577 .707 r
F P
0 g
s
.35858 .70013 m .36019 .73798 L .34751 .73341 L p .707 .577 .707 r
F P
0 g
s
.34751 .73341 m .3459 .69556 L .35858 .70013 L p .707 .577 .707 r
F P
0 g
s
.35618 .76348 m .35502 .78103 L .34319 .76834 L p .707 .577 .707 r
F P
0 g
s
.34319 .76834 m .34435 .75079 L .35618 .76348 L p .707 .577 .707 r
F P
0 g
s
.35575 .28138 m .35575 .78327 L .36287 .79523 L p .707 .577 .707 r
F P
0 g
s
.35575 .78327 m .35575 .28138 L .36276 .26942 L p .707 .577 .707 r
F P
0 g
s
.64424 .28128 m .64424 .78317 L .63713 .77121 L p .707 .577 .707 r
F P
0 g
s
.63713 .77121 m .63713 .26932 L .64424 .28128 L p .707 .577 .707 r
F P
0 g
s
.35043 .78865 m .34927 .8062 L .35711 .79407 L p .707 .577 .707 r
F P
0 g
s
.16001 .69413 m .15505 .63682 L .16152 .63386 L p .707 .577 .707 r
F P
0 g
s
.16152 .63386 m .16647 .69117 L .16001 .69413 L p .707 .577 .707 r
F P
0 g
s
.15608 .78833 m .15724 .77078 L .15515 .75774 L p .707 .577 .707 r
F P
0 g
s
.15943 .74956 m .15782 .71171 L .16479 .706 L p .707 .577 .707 r
F P
0 g
s
.15515 .75774 m .15399 .77529 L .15608 .78833 L p .707 .577 .707 r
F P
0 g
s
.34678 .67415 m .34182 .61684 L .35493 .61795 L p .707 .577 .707 r
F P
0 g
s
.16479 .706 m .1664 .74385 L .15943 .74956 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16647 .69117 m .16152 .63386 L .1773 .63037 L p .707 .577 .707 r
F P
0 g
s
.1773 .63037 m .18225 .68769 L .16647 .69117 L p .707 .577 .707 r
F P
0 g
s
.15399 .77529 m .15515 .75774 L .163 .74561 L p .707 .577 .707 r
F P
0 g
s
.36276 .7713 m .36276 .26942 L .38319 .25862 L p .707 .577 .707 r
F P
0 g
s
.36276 .26942 m .36276 .7713 L .35575 .78327 L p .707 .577 .707 r
F P
0 g
s
.63713 .26932 m .63713 .77121 L .61659 .76043 L p .707 .577 .707 r
F P
0 g
s
.61659 .76043 m .61659 .25854 L .63713 .26932 L p .707 .577 .707 r
F P
0 g
s
.163 .74561 m .16183 .76316 L .15399 .77529 L p .707 .577 .707 r
F P
0 g
s
.1664 .74385 m .16479 .706 L .18105 .70056 L p .707 .577 .707 r
F P
0 g
s
.34182 .61684 m .34678 .67415 L .32534 .67418 L p .707 .577 .707 r
F P
0 g
s
.32534 .67418 m .32039 .61686 L .34182 .61684 L p .707 .577 .707 r
F P
0 g
s
.18105 .70056 m .18266 .73841 L .1664 .74385 L p .707 .577 .707 r
F P
0 g
s
.18225 .68769 m .1773 .63037 L .20085 .6267 L p .707 .577 .707 r
F P
0 g
s
.20085 .6267 m .20581 .68401 L .18225 .68769 L p .707 .577 .707 r
F P
0 g
s
.3459 .69556 m .34751 .73341 L .32639 .73012 L p .707 .577 .707 r
F P
0 g
s
.32639 .73012 m .32478 .69227 L .3459 .69556 L p .707 .577 .707 r
F P
0 g
s
.16183 .76316 m .163 .74561 L .18002 .73559 L p .707 .577 .707 r
F P
0 g
s
.32039 .61686 m .32534 .67418 L .29768 .67534 L p .707 .577 .707 r
F P
0 g
s
.29768 .67534 m .29273 .61802 L .32039 .61686 L p .707 .577 .707 r
F P
0 g
s
.18266 .73841 m .18105 .70056 L .20501 .6959 L p .707 .577 .707 r
F P
0 g
s
.18002 .73559 m .17885 .75314 L .16183 .76316 L p .707 .577 .707 r
F P
0 g
s
.38319 .25862 m .38319 .76051 L .36276 .7713 L p .707 .577 .707 r
F P
0 g
s
.38319 .76051 m .38319 .25862 L .41506 .25005 L p .707 .577 .707 r
F P
0 g
s
.61659 .25854 m .61659 .76043 L .58463 .75188 L p .707 .577 .707 r
F P
0 g
s
.58463 .75188 m .58463 .24999 L .61659 .25854 L p .707 .577 .707 r
F P
0 g
s
.20581 .68401 m .20085 .6267 L .22988 .62319 L p .707 .577 .707 r
F P
0 g
s
.20501 .6959 m .20662 .73375 L .18266 .73841 L p .707 .577 .707 r
F P
0 g
s
.34435 .75079 m .34319 .76834 L .32278 .75725 L p .707 .577 .707 r
F P
0 g
s
.32278 .75725 m .32394 .7397 L .34435 .75079 L p .707 .577 .707 r
F P
0 g
s
.22988 .62319 m .23483 .68051 L .20581 .68401 L p .707 .577 .707 r
F P
0 g
s
.32478 .69227 m .32639 .73012 L .2989 .72843 L p .707 .577 .707 r
F P
0 g
s
.2989 .72843 m .29729 .69058 L .32478 .69227 L p .707 .577 .707 r
F P
0 g
s
.73351 .67394 m .73846 .62259 L .70727 .61728 L p .707 .577 .707 r
F P
0 g
s
.73846 .62259 m .73351 .67394 L .76516 .6748 L p .707 .577 .707 r
F P
0 g
s
.76516 .6748 m .77012 .62345 L .73846 .62259 L p .707 .577 .707 r
F P
0 g
s
.29273 .61802 m .29768 .67534 L .26649 .67752 L p .707 .577 .707 r
F P
0 g
s
.26649 .67752 m .26154 .62021 L .29273 .61802 L p .707 .577 .707 r
F P
0 g
s
.77012 .62345 m .76516 .6748 L .79419 .67111 L p .707 .577 .707 r
F P
0 g
s
.79419 .67111 m .79914 .61977 L .77012 .62345 L p .707 .577 .707 r
F P
0 g
s
.70232 .66862 m .70727 .61728 L .67961 .60803 L p .707 .577 .707 r
F P
0 g
s
.70727 .61728 m .70232 .66862 L .73351 .67394 L p .707 .577 .707 r
F P
0 g
s
.23483 .68051 m .22988 .62319 L .26154 .62021 L p .707 .577 .707 r
F P
0 g
s
.17885 .75314 m .18002 .73559 L .20454 .72866 L p .707 .577 .707 r
F P
0 g
s
.20662 .73375 m .20501 .6959 L .23432 .69249 L p .707 .577 .707 r
F P
0 g
s
.26154 .62021 m .26649 .67752 L .23483 .68051 L p .707 .577 .707 r
F P
0 g
s
.20454 .72866 m .20338 .74621 L .17885 .75314 L p .707 .577 .707 r
F P
0 g
s
.23432 .69249 m .23593 .73034 L .20662 .73375 L p .707 .577 .707 r
F P
0 g
s
.29729 .69058 m .2989 .72843 L .26773 .7285 L p .707 .577 .707 r
F P
0 g
s
.26773 .7285 m .26612 .69065 L .29729 .69058 L p .707 .577 .707 r
F P
0 g
s
.79914 .61977 m .79419 .67111 L .81775 .66325 L p .707 .577 .707 r
F P
0 g
s
.81775 .66325 m .8227 .61191 L .79914 .61977 L p .707 .577 .707 r
F P
0 g
s
.32394 .7397 m .32278 .75725 L .29579 .74885 L p .707 .577 .707 r
F P
0 g
s
.29579 .74885 m .29695 .7313 L .32394 .7397 L p .707 .577 .707 r
F P
0 g
s
.67466 .65937 m .67961 .60803 L .65817 .59574 L p .707 .577 .707 r
F P
0 g
s
.67961 .60803 m .67466 .65937 L .70232 .66862 L p .707 .577 .707 r
F P
0 g
s
.23593 .73034 m .23432 .69249 L .26612 .69065 L p .707 .577 .707 r
F P
0 g
s
.41506 .75193 m .41506 .25005 L .45525 .24453 L p .707 .577 .707 r
F P
0 g
s
.41506 .25005 m .41506 .75193 L .38319 .76051 L p .707 .577 .707 r
F P
0 g
s
.58463 .24999 m .58463 .75188 L .5444 .74639 L p .707 .577 .707 r
F P
0 g
s
.5444 .74639 m .5444 .2445 L .58463 .24999 L p .707 .577 .707 r
F P
0 g
s
.26612 .69065 m .26773 .7285 L .23593 .73034 L p .707 .577 .707 r
F P
0 g
s
.73227 .72599 m .73388 .69014 L .70271 .68641 L p .707 .577 .707 r
F P
0 g
s
.73388 .69014 m .73227 .72599 L .76406 .72615 L p .707 .577 .707 r
F P
0 g
s
.76406 .72615 m .76567 .6903 L .73388 .69014 L p .707 .577 .707 r
F P
0 g
s
.20338 .74621 m .20454 .72866 L .23418 .72549 L p .707 .577 .707 r
F P
0 g
s
.76567 .6903 m .76406 .72615 L .79338 .72272 L p .707 .577 .707 r
F P
0 g
s
.79338 .72272 m .79499 .68687 L .76567 .6903 L p .707 .577 .707 r
F P
0 g
s
.73514 .74825 m .73398 .72921 L .70305 .73008 L p .707 .577 .707 r
F P
0 g
s
.73398 .72921 m .73514 .74825 L .76698 .74608 L p .707 .577 .707 r
F P
0 g
s
.76698 .74608 m .76582 .72703 L .73398 .72921 L p .707 .577 .707 r
F P
0 g
s
.7011 .72226 m .70271 .68641 L .67522 .67947 L p .707 .577 .707 r
F P
0 g
s
.70271 .68641 m .7011 .72226 L .73227 .72599 L p .707 .577 .707 r
F P
0 g
s
.76582 .72703 m .76698 .74608 L .79662 .74281 L p .707 .577 .707 r
F P
0 g
s
.79662 .74281 m .79545 .72377 L .76582 .72703 L p .707 .577 .707 r
F P
0 g
s
.70305 .73008 m .70421 .74912 L .73514 .74825 L p .707 .577 .707 r
F P
0 g
s
.23418 .72549 m .23302 .74304 L .20338 .74621 L p .707 .577 .707 r
F P
0 g
s
.29695 .7313 m .29579 .74885 L .26486 .74395 L p .707 .577 .707 r
F P
0 g
s
.26486 .74395 m .26602 .7264 L .29695 .7313 L p .707 .577 .707 r
F P
0 g
s
.23302 .74304 m .23418 .72549 L .26602 .7264 L p .707 .577 .707 r
F P
0 g
s
.70421 .74912 m .70305 .73008 L .67606 .72955 L p .707 .577 .707 r
F P
0 g
s
.8227 .61191 m .81775 .66325 L .83353 .65198 L p .707 .577 .707 r
F P
0 g
s
.83353 .65198 m .83848 .60064 L .8227 .61191 L p .707 .577 .707 r
F P
0 g
s
.65322 .64709 m .65817 .59574 L .64507 .58163 L p .707 .577 .707 r
F P
0 g
s
.65817 .59574 m .65322 .64709 L .67466 .65937 L p .707 .577 .707 r
F P
0 g
s
.26602 .7264 m .26486 .74395 L .23302 .74304 L p .707 .577 .707 r
F P
0 g
s
.67606 .72955 m .67722 .7486 L .70421 .74912 L p .707 .577 .707 r
F P
0 g
s
.79499 .68687 m .79338 .72272 L .81734 .71604 L p .707 .577 .707 r
F P
0 g
s
.81734 .71604 m .81895 .68019 L .79499 .68687 L p .707 .577 .707 r
F P
0 g
s
.45525 .74642 m .45525 .24453 L .49981 .24262 L p .707 .577 .707 r
F P
0 g
s
.45525 .24453 m .45525 .74642 L .41506 .75193 L p .707 .577 .707 r
F P
0 g
s
.5444 .2445 m .5444 .74639 L .49981 .74451 L p .707 .577 .707 r
F P
0 g
s
.49981 .74451 m .49981 .24262 L .5444 .2445 L p .707 .577 .707 r
F P
0 g
s
.79545 .72377 m .79662 .74281 L .82114 .73877 L p .707 .577 .707 r
F P
0 g
s
.82114 .73877 m .81998 .71973 L .79545 .72377 L p .707 .577 .707 r
F P
0 g
s
.67522 .67947 m .67361 .71531 L .7011 .72226 L p .707 .577 .707 r
F P
0 g
s
.67361 .71531 m .67522 .67947 L .6541 .67 L p .707 .577 .707 r
F P
0 g
s
.49981 .24262 m .49981 .74451 L .45525 .74642 L p .707 .577 .707 r
F P
0 g
s
.67722 .7486 m .67606 .72955 L .65565 .72769 L p .707 .577 .707 r
F P
0 g
s
.65565 .72769 m .65681 .74673 L .67722 .7486 L p .707 .577 .707 r
F P
0 g
s
.6541 .67 m .65249 .70584 L .67361 .71531 L p .707 .577 .707 r
F P
0 g
s
.81895 .68019 m .81734 .71604 L .8336 .70675 L p .707 .577 .707 r
F P
0 g
s
.8336 .70675 m .83521 .6709 L .81895 .68019 L p .707 .577 .707 r
F P
0 g
s
.81998 .71973 m .82114 .73877 L .83816 .73436 L p .707 .577 .707 r
F P
0 g
s
.83816 .73436 m .837 .71531 L .81998 .71973 L p .707 .577 .707 r
F P
0 g
s
.83848 .60064 m .83353 .65198 L .83999 .6384 L p .707 .577 .707 r
F P
0 g
s
.83999 .6384 m .84494 .58705 L .83848 .60064 L p .707 .577 .707 r
F P
0 g
s
.64012 .63297 m .64507 .58163 L .64158 .56707 L p .707 .577 .707 r
F P
0 g
s
.64507 .58163 m .64012 .63297 L .65322 .64709 L p .707 .577 .707 r
F P
0 g
s
.65249 .70584 m .6541 .67 L .64142 .65892 L p .707 .577 .707 r
F P
0 g
s
.65681 .74673 m .65565 .72769 L .64382 .72467 L p .707 .577 .707 r
F P
0 g
s
.64382 .72467 m .64498 .74371 L .65681 .74673 L p .707 .577 .707 r
F P
0 g
s
.64142 .65892 m .63981 .69477 L .65249 .70584 L p .707 .577 .707 r
F P
0 g
s
.83521 .6709 m .8336 .70675 L .84057 .69578 L p .707 .577 .707 r
F P
0 g
s
.84057 .69578 m .84218 .65993 L .83521 .6709 L p .707 .577 .707 r
F P
0 g
s
.837 .71531 m .83816 .73436 L .84601 .72999 L p .707 .577 .707 r
F P
0 g
s
.84601 .72999 m .84485 .71095 L .837 .71531 L p .707 .577 .707 r
F P
0 g
s
.64158 .56707 m .63662 .61842 L .64012 .63297 L p .707 .577 .707 r
F P
0 g
s
.84494 .58705 m .83999 .6384 L .8365 .62384 L p .707 .577 .707 r
F P
0 g
s
.8365 .62384 m .84145 .5725 L .84494 .58705 L p .707 .577 .707 r
F P
0 g
s
.63662 .61842 m .64158 .56707 L .64804 .55349 L p .707 .577 .707 r
F P
0 g
s
.63981 .69477 m .64142 .65892 L .63842 .64733 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64498 .74371 m .64382 .72467 L .64172 .72079 L p .707 .577 .707 r
F P
0 g
s
.63842 .64733 m .63681 .68318 L .63981 .69477 L p .707 .577 .707 r
F P
0 g
s
.64172 .72079 m .64288 .73983 L .64498 .74371 L p .707 .577 .707 r
F P
0 g
s
.84218 .65993 m .84057 .69578 L .83757 .68418 L p .707 .577 .707 r
F P
0 g
s
.83757 .68418 m .83918 .64834 L .84218 .65993 L p .707 .577 .707 r
F P
0 g
s
.64804 .55349 m .64308 .60484 L .63662 .61842 L p .707 .577 .707 r
F P
0 g
s
.84145 .5725 m .8365 .62384 L .82339 .60973 L p .707 .577 .707 r
F P
0 g
s
.82339 .60973 m .82835 .55838 L .84145 .5725 L p .707 .577 .707 r
F P
0 g
s
.84485 .71095 m .84601 .72999 L .84391 .72611 L p .707 .577 .707 r
F P
0 g
s
.84391 .72611 m .84275 .70707 L .84485 .71095 L p .707 .577 .707 r
F P
0 g
s
.64308 .60484 m .64804 .55349 L .66382 .54222 L p .707 .577 .707 r
F P
0 g
s
.63681 .68318 m .63842 .64733 L .64539 .63636 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38766 .61082 m .39902 .55522 L .36837 .54794 L p .707 .577 .707 r
F P
0 g
s
.39902 .55522 m .38766 .61082 L .41883 .61637 L p .707 .577 .707 r
F P
0 g
s
.41883 .61637 m .43019 .56076 L .39902 .55522 L p .707 .577 .707 r
F P
0 g
s
.43019 .56076 m .41883 .61637 L .44747 .61964 L p .707 .577 .707 r
F P
0 g
s
.44747 .61964 m .45884 .56403 L .43019 .56076 L p .707 .577 .707 r
F P
0 g
s
.64539 .63636 m .64378 .6722 L .63681 .68318 L p .707 .577 .707 r
F P
0 g
s
.35701 .60354 m .36837 .54794 L .34124 .53964 L p .707 .577 .707 r
F P
0 g
s
.36837 .54794 m .35701 .60354 L .38766 .61082 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64288 .73983 m .64172 .72079 L .64957 .71642 L p .707 .577 .707 r
F P
0 g
s
.64957 .71642 m .65073 .73547 L .64288 .73983 L p .707 .577 .707 r
F P
0 g
s
.82835 .55838 m .82339 .60973 L .80196 .59744 L p .707 .577 .707 r
F P
0 g
s
.80196 .59744 m .80691 .5461 L .82835 .55838 L p .707 .577 .707 r
F P
0 g
s
.83918 .64834 m .83757 .68418 L .82489 .67311 L p .707 .577 .707 r
F P
0 g
s
.82489 .67311 m .8265 .63726 L .83918 .64834 L p .707 .577 .707 r
F P
0 g
s
.66382 .54222 m .65887 .59356 L .64308 .60484 L p .707 .577 .707 r
F P
0 g
s
.65887 .59356 m .66382 .54222 L .68738 .53436 L p .707 .577 .707 r
F P
0 g
s
.34124 .53964 m .32988 .59524 L .35701 .60354 L p .707 .577 .707 r
F P
0 g
s
.45884 .56403 m .44747 .61964 L .47078 .62031 L p .707 .577 .707 r
F P
0 g
s
.47078 .62031 m .48215 .56471 L .45884 .56403 L p .707 .577 .707 r
F P
0 g
s
.84275 .70707 m .84391 .72611 L .83208 .72309 L p .707 .577 .707 r
F P
0 g
s
.83208 .72309 m .83092 .70405 L .84275 .70707 L p .707 .577 .707 r
F P
0 g
s
.38724 .67652 m .39099 .63924 L .35995 .63469 L p .707 .577 .707 r
F P
0 g
s
.39099 .63924 m .38724 .67652 L .41892 .67886 L p .707 .577 .707 r
F P
0 g
s
.41892 .67886 m .42267 .64159 L .39099 .63924 L p .707 .577 .707 r
F P
0 g
s
.32988 .59524 m .34124 .53964 L .3203 .53113 L p .707 .577 .707 r
F P
0 g
s
.64378 .6722 m .64539 .63636 L .66165 .62707 L p .707 .577 .707 r
F P
0 g
s
.42267 .64159 m .41892 .67886 L .44814 .67877 L p .707 .577 .707 r
F P
0 g
s
.44814 .67877 m .45188 .64149 L .42267 .64159 L p .707 .577 .707 r
F P
0 g
s
.35621 .67196 m .35995 .63469 L .33259 .62837 L p .707 .577 .707 r
F P
0 g
s
.35995 .63469 m .35621 .67196 L .38724 .67652 L p .707 .577 .707 r
F P
0 g
s
.3203 .53113 m .30893 .58673 L .32988 .59524 L p .707 .577 .707 r
F P
0 g
s
.80691 .5461 m .80196 .59744 L .7743 .58819 L p .707 .577 .707 r
F P
0 g
s
.7743 .58819 m .77925 .53685 L .80691 .5461 L p .707 .577 .707 r
F P
0 g
s
.68242 .5857 m .68738 .53436 L .7164 .53067 L p .707 .577 .707 r
F P
0 g
s
.68738 .53436 m .68242 .5857 L .65887 .59356 L p .707 .577 .707 r
F P
0 g
s
.66165 .62707 m .66004 .66292 L .64378 .6722 L p .707 .577 .707 r
F P
0 g
s
.33259 .62837 m .32885 .66564 L .35621 .67196 L p .707 .577 .707 r
F P
0 g
s
.45188 .64149 m .44814 .67877 L .47204 .67624 L p .707 .577 .707 r
F P
0 g
s
.47204 .67624 m .47578 .63896 L .45188 .64149 L p .707 .577 .707 r
F P
0 g
s
.65073 .73547 m .64957 .71642 L .66659 .71201 L p .707 .577 .707 r
F P
0 g
s
.8265 .63726 m .82489 .67311 L .80377 .66364 L p .707 .577 .707 r
F P
0 g
s
.80377 .66364 m .80538 .62779 L .8265 .63726 L p .707 .577 .707 r
F P
0 g
s
.66659 .71201 m .66775 .73105 L .65073 .73547 L p .707 .577 .707 r
F P
0 g
s
.48215 .56471 m .47078 .62031 L .48648 .61832 L p .707 .577 .707 r
F P
0 g
s
.48648 .61832 m .49784 .56272 L .48215 .56471 L p .707 .577 .707 r
F P
0 g
s
.32885 .66564 m .33259 .62837 L .31159 .6209 L p .707 .577 .707 r
F P
0 g
s
.30893 .58673 m .3203 .53113 L .30757 .52325 L p .707 .577 .707 r
F P
0 g
s
.39764 .72849 m .39492 .71048 L .36428 .71204 L p .707 .577 .707 r
F P
0 g
s
.39492 .71048 m .39764 .72849 L .42923 .72358 L p .707 .577 .707 r
F P
0 g
s
.42923 .72358 m .42651 .70557 L .39492 .71048 L p .707 .577 .707 r
F P
0 g
s
.42651 .70557 m .42923 .72358 L .45866 .71579 L p .707 .577 .707 r
F P
0 g
s
.45866 .71579 m .45594 .69778 L .42651 .70557 L p .707 .577 .707 r
F P
0 g
s
.77925 .53685 m .7743 .58819 L .74311 .58288 L p .707 .577 .707 r
F P
0 g
s
.74311 .58288 m .74806 .53153 L .77925 .53685 L p .707 .577 .707 r
F P
0 g
s
.71145 .58202 m .7164 .53067 L .74806 .53153 L p .707 .577 .707 r
F P
0 g
s
.7164 .53067 m .71145 .58202 L .68242 .5857 L p .707 .577 .707 r
F P
0 g
s
.66004 .66292 m .66165 .62707 L .68561 .62039 L p .707 .577 .707 r
F P
0 g
s
.83092 .70405 m .83208 .72309 L .81167 .72123 L p .707 .577 .707 r
F P
0 g
s
.81167 .72123 m .81051 .70218 L .83092 .70405 L p .707 .577 .707 r
F P
0 g
s
.36428 .71204 m .367 .73005 L .39764 .72849 L p .707 .577 .707 r
F P
0 g
s
.74806 .53153 m .74311 .58288 L .71145 .58202 L p .707 .577 .707 r
F P
0 g
s
.31159 .6209 m .30785 .65818 L .32885 .66564 L p .707 .577 .707 r
F P
0 g
s
.367 .73005 m .36428 .71204 L .33757 .71009 L p .707 .577 .707 r
F P
0 g
s
.30757 .52325 m .29621 .57885 L .30893 .58673 L p .707 .577 .707 r
F P
0 g
s
.45594 .69778 m .45866 .71579 L .48306 .70589 L p .707 .577 .707 r
F P
0 g
s
.48306 .70589 m .48034 .68788 L .45594 .69778 L p .707 .577 .707 r
F P
0 g
s
.47578 .63896 m .47204 .67624 L .48828 .67152 L p .707 .577 .707 r
F P
0 g
s
.48828 .67152 m .49203 .63425 L .47578 .63896 L p .707 .577 .707 r
F P
0 g
s
.33757 .71009 m .34029 .7281 L .367 .73005 L p .707 .577 .707 r
F P
0 g
s
.68561 .62039 m .684 .65623 L .66004 .66292 L p .707 .577 .707 r
F P
0 g
s
.80538 .62779 m .80377 .66364 L .77628 .6567 L p .707 .577 .707 r
F P
0 g
s
.77628 .6567 m .77789 .62085 L .80538 .62779 L p .707 .577 .707 r
F P
0 g
s
.66775 .73105 m .66659 .71201 L .69112 .70797 L p .707 .577 .707 r
F P
0 g
s
.30785 .65818 m .31159 .6209 L .299 .61301 L p .707 .577 .707 r
F P
0 g
s
.684 .65623 m .68561 .62039 L .71492 .61696 L p .707 .577 .707 r
F P
0 g
s
.69112 .70797 m .69228 .72701 L .66775 .73105 L p .707 .577 .707 r
F P
0 g
s
.49784 .56272 m .48648 .61832 L .49303 .61387 L p .707 .577 .707 r
F P
0 g
s
.49303 .61387 m .50439 .55826 L .49784 .56272 L p .707 .577 .707 r
F P
0 g
s
.34029 .7281 m .33757 .71009 L .31741 .70482 L p .707 .577 .707 r
F P
0 g
s
.29621 .57885 m .30757 .52325 L .30433 .51676 L p .707 .577 .707 r
F P
0 g
s
.48034 .68788 m .48306 .70589 L .50003 .69485 L p .707 .577 .707 r
F P
0 g
s
.50003 .69485 m .49731 .67684 L .48034 .68788 L p .707 .577 .707 r
F P
0 g
s
.81051 .70218 m .81167 .72123 L .78468 .72071 L p .707 .577 .707 r
F P
0 g
s
.78468 .72071 m .78352 .70166 L .81051 .70218 L p .707 .577 .707 r
F P
0 g
s
.299 .61301 m .29526 .65029 L .30785 .65818 L p .707 .577 .707 r
F P
0 g
s
.77789 .62085 m .77628 .6567 L .74511 .65296 L p .707 .577 .707 r
F P
0 g
s
.74511 .65296 m .74672 .61712 L .77789 .62085 L p .707 .577 .707 r
F P
0 g
s
.31741 .70482 m .32014 .72283 L .34029 .7281 L p .707 .577 .707 r
F P
0 g
s
.71331 .6528 m .71492 .61696 L .74672 .61712 L p .707 .577 .707 r
F P
0 g
s
.71492 .61696 m .71331 .6528 L .684 .65623 L p .707 .577 .707 r
F P
0 g
s
.30433 .51676 m .29297 .57236 L .29621 .57885 L p .707 .577 .707 r
F P
0 g
s
.74672 .61712 m .74511 .65296 L .71331 .6528 L p .707 .577 .707 r
F P
0 g
s
.69228 .72701 m .69112 .70797 L .72075 .7047 L p .707 .577 .707 r
F P
0 g
s
.49203 .63425 m .48828 .67152 L .49527 .66509 L p .707 .577 .707 r
F P
0 g
s
.49527 .66509 m .49902 .62781 L .49203 .63425 L p .707 .577 .707 r
F P
0 g
s
.72075 .7047 m .72191 .72375 L .69228 .72701 L p .707 .577 .707 r
F P
0 g
s
.78352 .70166 m .78468 .72071 L .75375 .72157 L p .707 .577 .707 r
F P
0 g
s
.75375 .72157 m .75259 .70253 L .78352 .70166 L p .707 .577 .707 r
F P
0 g
s
.29526 .65029 m .299 .61301 L .29606 .60549 L p .707 .577 .707 r
F P
0 g
s
.32014 .72283 m .31741 .70482 L .30578 .69676 L p .707 .577 .707 r
F P
0 g
s
.72191 .72375 m .72075 .7047 L .75259 .70253 L p .707 .577 .707 r
F P
0 g
s
.49731 .67684 m .50003 .69485 L .50792 .68374 L p .707 .577 .707 r
F P
0 g
s
.50792 .68374 m .5052 .66573 L .49731 .67684 L p .707 .577 .707 r
F P
0 g
s
.75259 .70253 m .75375 .72157 L .72191 .72375 L p .707 .577 .707 r
F P
0 g
s
.50439 .55826 m .49303 .61387 L .48978 .60738 L p .707 .577 .707 r
F P
0 g
s
.48978 .60738 m .50114 .55178 L .50439 .55826 L p .707 .577 .707 r
F P
0 g
s
.30578 .69676 m .30851 .71477 L .32014 .72283 L p .707 .577 .707 r
F P
0 g
s
.29606 .60549 m .29232 .64276 L .29526 .65029 L p .707 .577 .707 r
F P
0 g
s
.29297 .57236 m .30433 .51676 L .31087 .5123 L p .707 .577 .707 r
F P
0 g
s
.31087 .5123 m .29951 .56791 L .29297 .57236 L p .707 .577 .707 r
F P
0 g
s
.49902 .62781 m .49527 .66509 L .49233 .65756 L p .707 .577 .707 r
F P
0 g
s
.49233 .65756 m .49608 .62028 L .49902 .62781 L p .707 .577 .707 r
F P
0 g
s
.30851 .71477 m .30578 .69676 L .30382 .68668 L p .708 .578 .707 r
F P
0 g
s
.29232 .64276 m .29606 .60549 L .30305 .59905 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.5052 .66573 m .50792 .68374 L .50596 .67367 L p .708 .578 .707 r
F P
0 g
s
.50596 .67367 m .50324 .65565 L .5052 .66573 L p .708 .578 .707 r
F P
0 g
s
.30382 .68668 m .30654 .70469 L .30851 .71477 L p .708 .578 .707 r
F P
0 g
s
.50114 .55178 m .48978 .60738 L .47706 .5995 L p .707 .577 .707 r
F P
0 g
s
.47706 .5995 m .48842 .54389 L .50114 .55178 L p .707 .577 .707 r
F P
0 g
s
.30305 .59905 m .29931 .63633 L .29232 .64276 L p .707 .577 .707 r
F P
0 g
s
.29951 .56791 m .31087 .5123 L .32657 .51031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32657 .51031 m .31521 .56592 L .29951 .56791 L p .707 .577 .707 r
F P
0 g
s
.49608 .62028 m .49233 .65756 L .47975 .64967 L p .707 .577 .707 r
F P
0 g
s
.47975 .64967 m .48349 .6124 L .49608 .62028 L p .707 .577 .707 r
F P
0 g
s
.30654 .70469 m .30382 .68668 L .31171 .67557 L p .707 .577 .707 r
F P
0 g
s
.29931 .63633 m .30305 .59905 L .31929 .59434 L p .707 .577 .707 r
F P
0 g
s
.50324 .65565 m .50596 .67367 L .49433 .6656 L p .707 .577 .707 r
F P
0 g
s
.49433 .6656 m .49161 .64759 L .50324 .65565 L p .707 .577 .707 r
F P
0 g
s
.48842 .54389 m .47706 .5995 L .45611 .59099 L p .707 .577 .707 r
F P
0 g
s
.45611 .59099 m .46747 .53538 L .48842 .54389 L p .707 .577 .707 r
F P
0 g
s
.31171 .67557 m .31443 .69359 L .30654 .70469 L p .707 .577 .707 r
F P
0 g
s
.31521 .56592 m .32657 .51031 L .34988 .51099 L p .707 .577 .707 r
F P
0 g
s
.31929 .59434 m .31555 .63161 L .29931 .63633 L p .707 .577 .707 r
F P
0 g
s
.34988 .51099 m .33852 .56659 L .31521 .56592 L p .707 .577 .707 r
F P
0 g
s
.48349 .6124 m .47975 .64967 L .45875 .6422 L p .707 .577 .707 r
F P
0 g
s
.45875 .6422 m .46249 .60493 L .48349 .6124 L p .707 .577 .707 r
F P
0 g
s
.46747 .53538 m .45611 .59099 L .42898 .58269 L p .707 .577 .707 r
F P
0 g
s
.42898 .58269 m .44035 .52708 L .46747 .53538 L p .707 .577 .707 r
F P
0 g
s
.31555 .63161 m .31929 .59434 L .34319 .59181 L p .707 .577 .707 r
F P
0 g
s
.31443 .69359 m .31171 .67557 L .32869 .66453 L p .707 .577 .707 r
F P
0 g
s
.33852 .56659 m .34988 .51099 L .37853 .51426 L p .707 .577 .707 r
F P
0 g
s
.49161 .64759 m .49433 .6656 L .47417 .66033 L p .707 .577 .707 r
F P
0 g
s
.47417 .66033 m .47145 .64232 L .49161 .64759 L p .707 .577 .707 r
F P
0 g
s
.32869 .66453 m .33141 .68254 L .31443 .69359 L p .707 .577 .707 r
F P
0 g
s
.34319 .59181 m .33945 .62908 L .31555 .63161 L p .707 .577 .707 r
F P
0 g
s
.37853 .51426 m .36716 .56986 L .33852 .56659 L p .707 .577 .707 r
F P
0 g
s
.44035 .52708 m .42898 .58269 L .39833 .57541 L p .707 .577 .707 r
F P
0 g
s
.39833 .57541 m .4097 .5198 L .44035 .52708 L p .707 .577 .707 r
F P
0 g
s
.36716 .56986 m .37853 .51426 L .4097 .5198 L p .707 .577 .707 r
F P
0 g
s
.46249 .60493 m .45875 .6422 L .43139 .63588 L p .707 .577 .707 r
F P
0 g
s
.43139 .63588 m .43513 .59861 L .46249 .60493 L p .707 .577 .707 r
F P
0 g
s
.4097 .5198 m .39833 .57541 L .36716 .56986 L p .707 .577 .707 r
F P
0 g
s
.33945 .62908 m .34319 .59181 L .37241 .59171 L p .707 .577 .707 r
F P
0 g
s
.33141 .68254 m .32869 .66453 L .35308 .65463 L p .707 .577 .707 r
F P
0 g
s
.47145 .64232 m .47417 .66033 L .44747 .65838 L p .707 .577 .707 r
F P
0 g
s
.44747 .65838 m .44475 .64037 L .47145 .64232 L p .707 .577 .707 r
F P
0 g
s
.37241 .59171 m .36867 .62898 L .33945 .62908 L p .707 .577 .707 r
F P
0 g
s
.43513 .59861 m .43139 .63588 L .40035 .63133 L p .707 .577 .707 r
F P
0 g
s
.40035 .63133 m .40409 .59405 L .43513 .59861 L p .707 .577 .707 r
F P
0 g
s
.35308 .65463 m .3558 .67264 L .33141 .68254 L p .707 .577 .707 r
F P
0 g
s
.36867 .62898 m .37241 .59171 L .40409 .59405 L p .707 .577 .707 r
F P
0 g
s
.40409 .59405 m .40035 .63133 L .36867 .62898 L p .707 .577 .707 r
F P
0 g
s
.3558 .67264 m .35308 .65463 L .38251 .64685 L p .707 .577 .707 r
F P
0 g
s
.44475 .64037 m .44747 .65838 L .41682 .65994 L p .707 .577 .707 r
F P
0 g
s
.41682 .65994 m .4141 .64193 L .44475 .64037 L p .707 .577 .707 r
F P
0 g
s
.38251 .64685 m .38524 .66486 L .3558 .67264 L p .707 .577 .707 r
F P
0 g
s
.38524 .66486 m .38251 .64685 L .4141 .64193 L p .707 .577 .707 r
F P
0 g
s
.4141 .64193 m .41682 .65994 L .38524 .66486 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001VOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol@0004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`<000=JEP03001JEUYF00AJEP04001J
EUYFFUH90005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00011oo`P004eoo`00EGoo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF00002Woo1P000eYF00<005YFFUH00UYF2@00A7oo001EOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00008Ool2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
000lOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Aoo`8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000iOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8003Moo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001oo`800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Eoo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=oo`00E7oo00<005YF0000
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH015YF0P00<7oo001COol00`00FUH00002FUH50003FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002moo`00Dgoo00<005YF00000`0015YF1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF000^Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005=o
o`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH00UYF40001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02aoo`00Egoo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YF000000AJEP03001JEUYF00AJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP02FUH6000@Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002aoo`00F7oo0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00@005YFFUIJEP<0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEP00
008001Yoo`@000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo001JOol200000eYF0000
000F0003FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH2000QOol400000eYF001JEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00FGoo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF00<005YFFUH00`0000=JEP00FUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF0P005Goo0`003Woo0P001UYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001J
EUYF00=JEP8000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2000015YF000005YF0`004Woo1@003goo0P0015YF00@005YFFUIJEP8002eoo`00EGoo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
1EYF00L005YF000005YF001JEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP02000@Ool5000AOol20002FUH01000FUIJEUYF0P00;Goo001DOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF001JEP02FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH3000=Ool5000COol30003FUH2000]
Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP04001JEP00000<Ool3000F
Ool01000FUIJEUYF0P00;Goo001DOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000015YF001JEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00@0
05YFFUIJEP<0021oo`800006FUH005YF001JEP00;Goo001?Ool70003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUHB000<Ool3000025YF001JEP00FUH005YF000]Ool004Io
o`T000AJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00=JEPL000AJEP03001JEUYF00IJEP03
001JEUYF009JEP`000AJEP03001JEUYF00800003FUH007oo02aoo`00?Woo200015YF00<005YFFUH0
1UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH01`00FUIJEUYF001JEP0002eoo`00=Woo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P00;Woo000`Ool6
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH500000eYF
001JEP0600000eYF001JEP03FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009J
EP04001JEUYFFUH2000^Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEPL00003FUH005YF00D0009J
EPL000IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF0P00;Woo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP05FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
6P000eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1000;goo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUH000EJEP03001JEUYF00IJEP<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF008000YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEPH00003FUH005YF00IJEP03
001JEUYF00EJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEP0000<00003FUH005YF00MJEP03001JEUYF00AJEQ@000AJEP04001JEUYF000:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000005FUH00`00FUIJEP06FUH00`00FUIJEP04
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF00002UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF0`000eYF0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001eYF00<005YFFUH015YF10001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
009JEP80009JEP03001JEUYF00=JEP<00003FUH005YF00MJEP@000EJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000015YF000000002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<0
05YFFUH00eYF00<005YFFUH01P0015YF1@0015YF00<005YFFUH00UYF1@0017oo0P0000=JEP00FUH0
0UYF0P00;Goo000]Ool00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF1P0015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP8000YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEP04001JEUYF0005OolB000;
Ool20003FUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQ8000EJEP04001JEUYFFUH4000015YF001JEUYF2@0015YF00<005YFFUH01EYF00@005YF
FUIJEPD000EJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002FUH00`00FUIJEP030005FUH01000FUIJEP0027oo1@0057oo0`000UYF00<007ooOol0;7oo000]
Ool2FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF200000=JEP00FUH025YF00<005YFFUH00UYF
0P001EYF00D005YF000005YF00<00003FUH005YF00=JEP03001JEUYF00<00003FUH0000000h000QJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH00004FUH30003FUH01000FUIJEP002Goo0`004goo0P000eYF0`00;Woo000]Ool2FUH01@00
FUIJEUYF00000eYF200000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1@00
0Woo00<005YF000015YF00<005YF000010000UYF00<005YFFUH02EYF00<005YFFUH01EYF0P000UYF
00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0005FUH00`00FUH000030002FUH00`00Oomoo`0IOol400000eYF001JEP03FUH2000^Ool002eoo`9J
EP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP020007Ool00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP09FUH0
0`00FUIJEP03FUH20005FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00001EYF00<005YFFUH00eYF1`004Woo1@001EYF00L005YFFUIJEP00FUH0000^Ool0
02eoo`9JEP@000EJEP03001JEUYF00AJEQP0009JEPH000Ioo`03001JEP0000AJEP03001JEP0000@0
009JEP03001JEUYF00UJEP04001JEUYFFUH200000eYF001JEP04FUH2000:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH0
0UYF4P000eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`8000=JEP03001JEUYF
00=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0002FUH4
0002Ool00`00FUH00004FUH00`00FUIJEP030003FUH00`00FUIJEP09FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000^Ool;00000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00FUIJEP03FUH400000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH30006FUH00`00FUIJEP03000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000aOol4
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00
FUIJEP03FUH01P00FUIJEP00FUH000AJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF
00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEQT000=JEP8002moo`00;Woo0`000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF000005YF
00@000EJEP06001JEUYF001JEP0015YF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000L000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00H0009JEP03001JEP0000AJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH20003FUH00`00FUH00007
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEQ0000IJEP03001JEUYF
00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH00000FUH01`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00D0
05YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00D000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
1@0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P000eYF400000=JEP00
0000;7oo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YF
FUH01EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUIJEPP000=ooa8000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JER@00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP800003FUH005YF009JEQT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0002aoo`00;Goo00<005YF00000eYF00<005YF00000`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0005FUH5000015YF001JEP0015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo
00<005YF00000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000EJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YF0000031oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002eoo`04
001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP05FUH300000eYF
001JEP03FUH00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL003Moo`00;Goo0P000eYF
00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01EYF1P001UYF00<005YFFUH00P0015YF
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001JEP/000AJEP03001JEUYF009JEQ8003ioo`00
;Goo0P000eYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH01EYF20001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF20001eYF00<005YFFUH00eYF00<005YF
0000200015YF2@00D7oo000]Ool20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP02FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUH000020004FUH00`00FUIJEP03FUH00`00FUH00008Ool300000eYF001JEP02FUH00`00Oomo
o`1BOol002aoo`03001JEP00009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH000EJEP07001JEP00Ool005YF000015YF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF0`00
00=JEP00FUH015YF00<005YF000027oo0P0000=JEP0000000eYF0P00Dgoo000/Ool00`00FUH00002
0003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006Ool20003FUH00`00FUIJEP020000
0eYF001JEP03FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH20005FUH00`00FUH00006Ool200000eYF001JEP02FUH200000eYF0000
001COol002aoo`03001JEP0000aooa80015oo`800003FUH005YF009JEP03001JEP00009JEP<000UJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP<000=JEP03001JEP0000Aoo`8000=JEP03001JEUYF009JEP@005=oo`00:goo00<005YF0000<Woo
0P000eYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00FUH007oo00<0
00EJEP03001JEUYF00=JEP<005=oo`00:goo0P006goo0`005goo00H005YFFUH005YF0004FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF000005YF00001UYF00<005YFFUH00eYF00<005YF0000
Dgoo000[Ool3000IOol5000FOol00`00FUH000030004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0001COol002]oo`800003FUH0000001Mo
o`D001Moo`D000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00EJEP03001J
EUYF009JEP8005Aoo`00:goo0P000eYF00<007ooOol057oo1@0067oo0P0000=JEP00FUH00eYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
E7oo000/Ool01000FUIJEUYF0`005Goo0`0067oo0`0000=JEP00FUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Dgoo000/Ool01@00
FUIJEUYF00000UYF0P00;Woo00<005YF00000P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH015YF00<005YFFUH00P00EWoo000]Ool00`00FUH00005FUH2000ZOol3000015YF
0000000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH015YF0`00
F7oo000^Ool20005FUH01000FUH000009Woo0P000UYF0P000Woo00<005YFFUH00UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@0000=JEP00FUH015YF0P00FWoo000_Ool00`00FUIJEP03FUH01000FUIJ
EUYF0`008Goo0P0015YF0P000goo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEPL005ao
o`00<7oo0P000eYF00<005YFFUH015YF1P005goo100000=JEP00FUH00eYF00<007ooOol017oo0`00
2EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YF00000P0025YF00<005YF00000P00G7oo000bOol200000eYF001JEP06FUH00`00FUIJ
EP02FUHG0005FUH00`00FUIJEP02FUH00`00Oomoo`06Ool30007FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001JOol003Aoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF008000aoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0009JEPH000IJEP03001JEUYF00AJEP<0
05Qoo`00=goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`004goo1@0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF2`001Woo1000
0UYF00<005YFFUH015YF00@005YFFUH005Moo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P006Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000Eoo`D000]oo`<000EJEP05001JEUYFFUH0001GOol003aoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000<0029oob4000Uoo`D000ioo`8000=JEP05001JEUYF
FUH0001GOol0049ooaL003Ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00@000Ioo`<0015oo`80
0004FUH005YFFUH2001GOol0095oo`<00003FUH005YF00IJEP03001JEUYF00AJEPL001Eoo`80009J
EP8005Moo`00U7oo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF5P0000=JEP0000000P00Egoo
002GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001GOol009]oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00Egoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8005Moo`00Xgoo1`0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00FGoo002ZOol90004FUH01000FUIJEUYF1P00G7oo002cOol8001ROol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63496 .75157 m .61674 .70145 L .58659 .71204 L p .707 .577 .707 r
F P
0 g
s
.61674 .70145 m .63496 .75157 L .66261 .73787 L p .707 .577 .707 r
F P
0 g
s
.66261 .73787 m .64439 .68774 L .61674 .70145 L p .707 .577 .707 r
F P
0 g
s
.60481 .76216 m .58659 .71204 L .55689 .71847 L p .707 .577 .707 r
F P
0 g
s
.58659 .71204 m .60481 .76216 L .63496 .75157 L p .707 .577 .707 r
F P
0 g
s
.64439 .68774 m .66261 .73787 L .68506 .72238 L p .707 .577 .707 r
F P
0 g
s
.68506 .72238 m .66684 .67226 L .64439 .68774 L p .707 .577 .707 r
F P
0 g
s
.57511 .76859 m .55689 .71847 L .53056 .72012 L p .707 .577 .707 r
F P
0 g
s
.55689 .71847 m .57511 .76859 L .60481 .76216 L p .707 .577 .707 r
F P
0 g
s
.60177 .81655 m .59573 .78073 L .56493 .78302 L p .707 .577 .707 r
F P
0 g
s
.59573 .78073 m .60177 .81655 L .6332 .81085 L p .707 .577 .707 r
F P
0 g
s
.6332 .81085 m .62716 .77503 L .59573 .78073 L p .707 .577 .707 r
F P
0 g
s
.66684 .67226 m .68506 .72238 L .70011 .70663 L p .707 .577 .707 r
F P
0 g
s
.70011 .70663 m .68189 .65651 L .66684 .67226 L p .707 .577 .707 r
F P
0 g
s
.62716 .77503 m .6332 .81085 L .66219 .80228 L p .707 .577 .707 r
F P
0 g
s
.66219 .80228 m .65615 .76647 L .62716 .77503 L p .707 .577 .707 r
F P
0 g
s
.54878 .77024 m .53056 .72012 L .51016 .71682 L p .707 .577 .707 r
F P
0 g
s
.53056 .72012 m .54878 .77024 L .57511 .76859 L p .707 .577 .707 r
F P
0 g
s
.57511 .84148 m .57947 .82305 L .54947 .81465 L p .707 .577 .707 r
F P
0 g
s
.57947 .82305 m .57511 .84148 L .60622 .84835 L p .707 .577 .707 r
F P
0 g
s
.60622 .84835 m .61058 .82992 L .57947 .82305 L p .707 .577 .707 r
F P
0 g
s
.57097 .81884 m .56493 .78302 L .53777 .78166 L p .707 .577 .707 r
F P
0 g
s
.56493 .78302 m .57097 .81884 L .60177 .81655 L p .707 .577 .707 r
F P
0 g
s
.61058 .82992 m .60622 .84835 L .6354 .85303 L p .707 .577 .707 r
F P
0 g
s
.6354 .85303 m .63976 .8346 L .61058 .82992 L p .707 .577 .707 r
F P
0 g
s
.54947 .81465 m .54512 .83308 L .57511 .84148 L p .707 .577 .707 r
F P
0 g
s
.65615 .76647 m .66219 .80228 L .6859 .7917 L p .707 .577 .707 r
F P
0 g
s
.6859 .7917 m .67986 .75588 L .65615 .76647 L p .707 .577 .707 r
F P
0 g
s
.54512 .83308 m .54947 .81465 L .52353 .80556 L p .707 .577 .707 r
F P
0 g
s
.52353 .80556 m .51918 .82399 L .54512 .83308 L p .707 .577 .707 r
F P
0 g
s
.53777 .78166 m .54381 .81748 L .57097 .81884 L p .707 .577 .707 r
F P
0 g
s
.63976 .8346 m .6354 .85303 L .6598 .85505 L p .707 .577 .707 r
F P
0 g
s
.6598 .85505 m .66415 .83662 L .63976 .8346 L p .707 .577 .707 r
F P
0 g
s
.68189 .65651 m .70011 .70663 L .70629 .69217 L p .707 .577 .707 r
F P
0 g
s
.70629 .69217 m .68806 .64204 L .68189 .65651 L p .707 .577 .707 r
F P
0 g
s
.54381 .81748 m .53777 .78166 L .51692 .77679 L p .707 .577 .707 r
F P
0 g
s
.51016 .71682 m .52838 .76694 L .54878 .77024 L p .707 .577 .707 r
F P
0 g
s
.52838 .76694 m .51016 .71682 L .4977 .70889 L p .707 .577 .707 r
F P
0 g
s
.67986 .75588 m .6859 .7917 L .702 .78012 L p .707 .577 .707 r
F P
0 g
s
.702 .78012 m .69596 .7443 L .67986 .75588 L p .707 .577 .707 r
F P
0 g
s
.51918 .82399 m .52353 .80556 L .50419 .79665 L p .707 .577 .707 r
F P
0 g
s
.50419 .79665 m .49983 .81508 L .51918 .82399 L p .707 .577 .707 r
F P
0 g
s
.51692 .77679 m .52297 .81261 L .54381 .81748 L p .707 .577 .707 r
F P
0 g
s
.66415 .83662 m .6598 .85505 L .67702 .85422 L p .707 .577 .707 r
F P
0 g
s
.67702 .85422 m .68138 .83579 L .66415 .83662 L p .707 .577 .707 r
F P
0 g
s
.52297 .81261 m .51692 .77679 L .50442 .76889 L p .707 .577 .707 r
F P
0 g
s
.4977 .70889 m .51592 .75902 L .52838 .76694 L p .707 .577 .707 r
F P
0 g
s
.68806 .64204 m .70629 .69217 L .70298 .68039 L p .707 .577 .707 r
F P
0 g
s
.70298 .68039 m .68476 .63027 L .68806 .64204 L p .707 .577 .707 r
F P
0 g
s
.49983 .81508 m .50419 .79665 L .49333 .7888 L p .707 .577 .707 r
F P
0 g
s
.69596 .7443 m .702 .78012 L .70893 .7687 L p .707 .577 .707 r
F P
0 g
s
.70893 .7687 m .70289 .73288 L .69596 .7443 L p .707 .577 .707 r
F P
0 g
s
.51592 .75902 m .4977 .70889 L .4944 .69712 L p .707 .577 .707 r
F P
0 g
s
.49333 .7888 m .48897 .80723 L .49983 .81508 L p .707 .577 .707 r
F P
0 g
s
.50442 .76889 m .51047 .8047 L .52297 .81261 L p .707 .577 .707 r
F P
0 g
s
.68138 .83579 m .67702 .85422 L .68539 .85063 L p .707 .577 .707 r
F P
0 g
s
.68539 .85063 m .68974 .83219 L .68138 .83579 L p .707 .577 .707 r
F P
0 g
s
.51047 .8047 m .50442 .76889 L .50149 .75872 L p .707 .577 .707 r
F P
0 g
s
.4944 .69712 m .51262 .74725 L .51592 .75902 L p .707 .577 .707 r
F P
0 g
s
.51262 .74725 m .4944 .69712 L .50057 .68265 L p .707 .577 .707 r
F P
0 g
s
.50149 .75872 m .50754 .79454 L .51047 .8047 L p .707 .577 .707 r
F P
0 g
s
.50754 .79454 m .50149 .75872 L .50842 .7473 L p .707 .577 .707 r
F P
0 g
s
.50057 .68265 m .51879 .73278 L .51262 .74725 L p .707 .577 .707 r
F P
0 g
s
.51879 .73278 m .50057 .68265 L .51562 .66691 L p .707 .577 .707 r
F P
0 g
s
.50842 .7473 m .51446 .78311 L .50754 .79454 L p .707 .577 .707 r
F P
0 g
s
.51446 .78311 m .50842 .7473 L .52452 .73572 L p .707 .577 .707 r
F P
0 g
s
.52452 .73572 m .53057 .77154 L .51446 .78311 L p .707 .577 .707 r
F P
0 g
s
.49603 .79762 m .50038 .77919 L .5176 .77836 L p .707 .577 .707 r
F P
0 g
s
.5176 .77836 m .51325 .79679 L .49603 .79762 L p .707 .577 .707 r
F P
0 g
s
.50621 .82189 m .50621 .32 L .46137 .31862 L p .707 .577 .707 r
F P
0 g
s
.51562 .66691 m .53384 .71703 L .51879 .73278 L p .707 .577 .707 r
F P
0 g
s
.53384 .71703 m .51562 .66691 L .53807 .65142 L p .707 .577 .707 r
F P
0 g
s
.53807 .65142 m .55629 .70154 L .53384 .71703 L p .707 .577 .707 r
F P
0 g
s
.53057 .77154 m .52452 .73572 L .54823 .72513 L p .707 .577 .707 r
F P
0 g
s
.51325 .79679 m .5176 .77836 L .542 .78038 L p .707 .577 .707 r
F P
0 g
s
.54823 .72513 m .55427 .76095 L .53057 .77154 L p .707 .577 .707 r
F P
0 g
s
.542 .78038 m .53765 .79882 L .51325 .79679 L p .707 .577 .707 r
F P
0 g
s
.53765 .79882 m .542 .78038 L .57118 .78506 L p .707 .577 .707 r
F P
0 g
s
.57118 .78506 m .56683 .80349 L .53765 .79882 L p .707 .577 .707 r
F P
0 g
s
.50621 .32 m .50621 .82189 L .55044 .81948 L p .707 .577 .707 r
F P
0 g
s
.55629 .70154 m .53807 .65142 L .56572 .63771 L p .707 .577 .707 r
F P
0 g
s
.55427 .76095 m .54823 .72513 L .57722 .71657 L p .707 .577 .707 r
F P
0 g
s
.55044 .81948 m .55044 .31759 L .50621 .32 L p .707 .577 .707 r
F P
0 g
s
.68476 .63027 m .70298 .68039 L .69052 .67247 L p .707 .577 .707 r
F P
0 g
s
.69052 .67247 m .6723 .62235 L .68476 .63027 L p .707 .577 .707 r
F P
0 g
s
.46137 .82051 m .46137 .31862 L .42032 .31359 L p .707 .577 .707 r
F P
0 g
s
.48897 .80723 m .49333 .7888 L .49201 .78279 L p .707 .577 .707 r
F P
0 g
s
.49201 .78279 m .48766 .80122 L .48897 .80723 L p .707 .577 .707 r
F P
0 g
s
.48766 .80122 m .49201 .78279 L .50038 .77919 L p .707 .577 .707 r
F P
0 g
s
.50038 .77919 m .49603 .79762 L .48766 .80122 L p .707 .577 .707 r
F P
0 g
s
.46137 .31862 m .46137 .82051 L .50621 .82189 L p .707 .577 .707 r
F P
0 g
s
.70289 .73288 m .70893 .7687 L .706 .75853 L p .707 .577 .707 r
F P
0 g
s
.706 .75853 m .69996 .72271 L .70289 .73288 L p .707 .577 .707 r
F P
0 g
s
.58395 .68784 m .56572 .63771 L .59588 .62713 L p .707 .577 .707 r
F P
0 g
s
.56572 .63771 m .58395 .68784 L .55629 .70154 L p .707 .577 .707 r
F P
0 g
s
.58326 .75239 m .57722 .71657 L .60865 .71087 L p .707 .577 .707 r
F P
0 g
s
.57722 .71657 m .58326 .75239 L .55427 .76095 L p .707 .577 .707 r
F P
0 g
s
.60865 .71087 m .6147 .74669 L .58326 .75239 L p .707 .577 .707 r
F P
0 g
s
.56683 .80349 m .57118 .78506 L .60229 .79193 L p .707 .577 .707 r
F P
0 g
s
.60229 .79193 m .59794 .81037 L .56683 .80349 L p .707 .577 .707 r
F P
0 g
s
.55044 .31759 m .55044 .81948 L .58973 .81352 L p .707 .577 .707 r
F P
0 g
s
.59588 .62713 m .6141 .67725 L .58395 .68784 L p .707 .577 .707 r
F P
0 g
s
.58973 .81352 m .58973 .31163 L .55044 .31759 L p .707 .577 .707 r
F P
0 g
s
.42032 .81548 m .42032 .31359 L .38706 .30541 L p .707 .577 .707 r
F P
0 g
s
.42032 .31359 m .42032 .81548 L .46137 .82051 L p .707 .577 .707 r
F P
0 g
s
.68974 .83219 m .68539 .85063 L .68408 .84461 L p .707 .577 .707 r
F P
0 g
s
.68408 .84461 m .68843 .82618 L .68974 .83219 L p .707 .577 .707 r
F P
0 g
s
.6141 .67725 m .59588 .62713 L .62557 .62069 L p .707 .577 .707 r
F P
0 g
s
.63946 .70858 m .6455 .7444 L .6147 .74669 L p .707 .577 .707 r
F P
0 g
s
.6147 .74669 m .60865 .71087 L .63946 .70858 L p .707 .577 .707 r
F P
0 g
s
.63229 .80033 m .62793 .81876 L .59794 .81037 L p .707 .577 .707 r
F P
0 g
s
.59794 .81037 m .60229 .79193 L .63229 .80033 L p .707 .577 .707 r
F P
0 g
s
.58973 .31163 m .58973 .81352 L .62024 .8046 L p .707 .577 .707 r
F P
0 g
s
.62557 .62069 m .64379 .67082 L .6141 .67725 L p .707 .577 .707 r
F P
0 g
s
.62024 .8046 m .62024 .30271 L .58973 .31163 L p .707 .577 .707 r
F P
0 g
s
.6723 .62235 m .69052 .67247 L .67013 .66917 L p .707 .577 .707 r
F P
0 g
s
.67013 .66917 m .65191 .61905 L .6723 .62235 L p .707 .577 .707 r
F P
0 g
s
.2204 .62931 m .22851 .68639 L .25959 .68174 L p .707 .577 .707 r
F P
0 g
s
.25959 .68174 m .25149 .62466 L .2204 .62931 L p .707 .577 .707 r
F P
0 g
s
.25149 .62466 m .25959 .68174 L .291 .67745 L p .707 .577 .707 r
F P
0 g
s
.69996 .72271 m .706 .75853 L .6935 .75063 L p .707 .577 .707 r
F P
0 g
s
.6935 .75063 m .68746 .71481 L .69996 .72271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.291 .67745 m .28289 .62037 L .25149 .62466 L p .707 .577 .707 r
F P
0 g
s
.28289 .62037 m .291 .67745 L .31964 .67393 L p .707 .577 .707 r
F P
0 g
s
.19268 .63386 m .20078 .69094 L .22851 .68639 L p .707 .577 .707 r
F P
0 g
s
.22851 .68639 m .2204 .62931 L .19268 .63386 L p .707 .577 .707 r
F P
0 g
s
.31964 .67393 m .31154 .61685 L .28289 .62037 L p .707 .577 .707 r
F P
0 g
s
.25607 .75893 m .25346 .7208 L .22231 .72212 L p .707 .577 .707 r
F P
0 g
s
.25346 .7208 m .25607 .75893 L .28781 .75643 L p .707 .577 .707 r
F P
0 g
s
.28781 .75643 m .2852 .7183 L .25346 .7208 L p .707 .577 .707 r
F P
0 g
s
.38706 .8073 m .38706 .30541 L .36486 .29486 L p .707 .577 .707 r
F P
0 g
s
.38706 .30541 m .38706 .8073 L .42032 .81548 L p .707 .577 .707 r
F P
0 g
s
.2852 .7183 m .28781 .75643 L .31705 .75299 L p .707 .577 .707 r
F P
0 g
s
.31705 .75299 m .31443 .71486 L .2852 .7183 L p .707 .577 .707 r
F P
0 g
s
.31154 .61685 m .31964 .67393 L .34273 .67154 L p .707 .577 .707 r
F P
0 g
s
.68843 .82618 m .68408 .84461 L .67322 .83676 L p .707 .577 .707 r
F P
0 g
s
.67322 .83676 m .67757 .81833 L .68843 .82618 L p .707 .577 .707 r
F P
0 g
s
.22231 .72212 m .22492 .76025 L .25607 .75893 L p .707 .577 .707 r
F P
0 g
s
.34273 .67154 m .33463 .61446 L .31154 .61685 L p .707 .577 .707 r
F P
0 g
s
.17103 .63787 m .17914 .69495 L .20078 .69094 L p .707 .577 .707 r
F P
0 g
s
.20078 .69094 m .19268 .63386 L .17103 .63787 L p .707 .577 .707 r
F P
0 g
s
.65191 .61905 m .67013 .66917 L .64379 .67082 L p .707 .577 .707 r
F P
0 g
s
.64379 .67082 m .62557 .62069 L .65191 .61905 L p .707 .577 .707 r
F P
0 g
s
.22492 .76025 m .22231 .72212 L .19482 .72213 L p .707 .577 .707 r
F P
0 g
s
.19482 .72213 m .19743 .76025 L .22492 .76025 L p .707 .577 .707 r
F P
0 g
s
.62024 .30271 m .62024 .8046 L .63898 .79358 L p .707 .577 .707 r
F P
0 g
s
.63898 .79358 m .63898 .29169 L .62024 .30271 L p .707 .577 .707 r
F P
0 g
s
.68746 .71481 m .6935 .75063 L .67265 .74576 L p .707 .577 .707 r
F P
0 g
s
.67265 .74576 m .66661 .70994 L .68746 .71481 L p .707 .577 .707 r
F P
0 g
s
.31443 .71486 m .31705 .75299 L .34091 .74895 L p .707 .577 .707 r
F P
0 g
s
.34091 .74895 m .3383 .71082 L .31443 .71486 L p .707 .577 .707 r
F P
0 g
s
.19743 .76025 m .19482 .72213 L .17366 .72082 L p .707 .577 .707 r
F P
0 g
s
.33463 .61446 m .34273 .67154 L .358 .6705 L p .707 .577 .707 r
F P
0 g
s
.358 .6705 m .3499 .61342 L .33463 .61446 L p .707 .577 .707 r
F P
0 g
s
.17366 .72082 m .17627 .75894 L .19743 .76025 L p .707 .577 .707 r
F P
0 g
s
.15758 .64094 m .16568 .69802 L .17914 .69495 L p .707 .577 .707 r
F P
0 g
s
.17914 .69495 m .17103 .63787 L .15758 .64094 L p .707 .577 .707 r
F P
0 g
s
.67757 .81833 m .67322 .83676 L .65387 .82786 L p .707 .577 .707 r
F P
0 g
s
.65387 .82786 m .65822 .80943 L .67757 .81833 L p .707 .577 .707 r
F P
0 g
s
.3383 .71082 m .34091 .74895 L .35707 .7447 L p .707 .577 .707 r
F P
0 g
s
.35707 .7447 m .35446 .70658 L .3383 .71082 L p .707 .577 .707 r
F P
0 g
s
.66661 .70994 m .67265 .74576 L .6455 .7444 L p .707 .577 .707 r
F P
0 g
s
.6455 .7444 m .63946 .70858 L .66661 .70994 L p .707 .577 .707 r
F P
0 g
s
.2422 .83147 m .24406 .81476 L .21333 .80811 L p .707 .577 .707 r
F P
0 g
s
.24406 .81476 m .2422 .83147 L .27397 .83336 L p .707 .577 .707 r
F P
0 g
s
.27397 .83336 m .27584 .81665 L .24406 .81476 L p .707 .577 .707 r
F P
0 g
s
.3499 .61342 m .358 .6705 L .36396 .67092 L p .707 .577 .707 r
F P
0 g
s
.36396 .67092 m .35585 .61384 L .3499 .61342 L p .707 .577 .707 r
F P
0 g
s
.35446 .70658 m .35707 .7447 L .36394 .74066 L p .707 .577 .707 r
F P
0 g
s
.36394 .74066 m .36133 .70254 L .35446 .70658 L p .707 .577 .707 r
F P
0 g
s
.35585 .61384 m .36396 .67092 L .36001 .67276 L p .707 .577 .707 r
F P
0 g
s
.36133 .70254 m .36394 .74066 L .36085 .73723 L p .707 .577 .707 r
F P
0 g
s
.36486 .79675 m .36486 .29486 L .35589 .283 L p .707 .577 .707 r
F P
0 g
s
.36486 .29486 m .36486 .79675 L .38706 .8073 L p .707 .577 .707 r
F P
0 g
s
.27584 .81665 m .27397 .83336 L .30368 .8303 L p .707 .577 .707 r
F P
0 g
s
.30368 .8303 m .30554 .81359 L .27584 .81665 L p .707 .577 .707 r
F P
0 g
s
.21147 .82482 m .21333 .80811 L .18666 .79734 L p .707 .577 .707 r
F P
0 g
s
.21333 .80811 m .21147 .82482 L .2422 .83147 L p .707 .577 .707 r
F P
0 g
s
.17627 .75894 m .17366 .72082 L .16091 .71833 L p .707 .577 .707 r
F P
0 g
s
.63898 .29169 m .63898 .79358 L .64411 .78155 L p .707 .577 .707 r
F P
0 g
s
.64411 .78155 m .64411 .27966 L .63898 .29169 L p .707 .577 .707 r
F P
0 g
s
.16091 .71833 m .16352 .75645 L .17627 .75894 L p .707 .577 .707 r
F P
0 g
s
.30554 .81359 m .30368 .8303 L .32842 .82259 L p .707 .577 .707 r
F P
0 g
s
.32842 .82259 m .33028 .80588 L .30554 .81359 L p .707 .577 .707 r
F P
0 g
s
.18666 .79734 m .18479 .81405 L .21147 .82482 L p .707 .577 .707 r
F P
0 g
s
.65822 .80943 m .65387 .82786 L .62793 .81876 L p .707 .577 .707 r
F P
0 g
s
.62793 .81876 m .63229 .80033 L .65822 .80943 L p .707 .577 .707 r
F P
0 g
s
.15363 .64277 m .16174 .69985 L .16568 .69802 L p .707 .577 .707 r
F P
0 g
s
.16568 .69802 m .15758 .64094 L .15363 .64277 L p .707 .577 .707 r
F P
0 g
s
.18479 .81405 m .18666 .79734 L .16665 .78352 L p .707 .577 .707 r
F P
0 g
s
.16665 .78352 m .16478 .80023 L .18479 .81405 L p .707 .577 .707 r
F P
0 g
s
.33028 .80588 m .32842 .82259 L .34576 .81099 L p .707 .577 .707 r
F P
0 g
s
.34576 .81099 m .34762 .79428 L .33028 .80588 L p .707 .577 .707 r
F P
0 g
s
.16352 .75645 m .16091 .71833 L .15782 .7149 L p .707 .577 .707 r
F P
0 g
s
.16478 .80023 m .16665 .78352 L .15526 .76799 L p .707 .577 .707 r
F P
0 g
s
.15782 .7149 m .16043 .75302 L .16352 .75645 L p .707 .577 .707 r
F P
0 g
s
.36001 .67276 m .35191 .61568 L .35585 .61384 L p .707 .577 .707 r
F P
0 g
s
.36085 .73723 m .35824 .69911 L .36133 .70254 L p .707 .577 .707 r
F P
0 g
s
.35191 .61568 m .36001 .67276 L .34656 .67583 L p .707 .577 .707 r
F P
0 g
s
.35824 .69911 m .36085 .73723 L .34811 .73474 L p .707 .577 .707 r
F P
0 g
s
.34811 .73474 m .34549 .69661 L .35824 .69911 L p .707 .577 .707 r
F P
0 g
s
.35589 .283 m .35589 .78489 L .36486 .79675 L p .707 .577 .707 r
F P
0 g
s
.35589 .78489 m .35589 .283 L .36102 .27097 L p .707 .577 .707 r
F P
0 g
s
.15526 .76799 m .15339 .7847 L .16478 .80023 L p .707 .577 .707 r
F P
0 g
s
.15959 .64319 m .16769 .70027 L .16174 .69985 L p .707 .577 .707 r
F P
0 g
s
.16174 .69985 m .15363 .64277 L .15959 .64319 L p .707 .577 .707 r
F P
0 g
s
.64411 .27966 m .64411 .78155 L .63514 .76968 L p .707 .577 .707 r
F P
0 g
s
.63514 .76968 m .63514 .26779 L .64411 .27966 L p .707 .577 .707 r
F P
0 g
s
.34762 .79428 m .34576 .81099 L .35401 .79662 L p .707 .577 .707 r
F P
0 g
s
.35401 .79662 m .35587 .77992 L .34762 .79428 L p .707 .577 .707 r
F P
0 g
s
.15339 .7847 m .15526 .76799 L .15361 .75227 L p .707 .577 .707 r
F P
0 g
s
.16043 .75302 m .15782 .7149 L .16469 .71086 L p .707 .577 .707 r
F P
0 g
s
.16469 .71086 m .16731 .74898 L .16043 .75302 L p .707 .577 .707 r
F P
0 g
s
.15361 .75227 m .15174 .76898 L .15339 .7847 L p .707 .577 .707 r
F P
0 g
s
.34656 .67583 m .33845 .61875 L .35191 .61568 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17486 .64215 m .18296 .69923 L .16769 .70027 L p .707 .577 .707 r
F P
0 g
s
.16769 .70027 m .15959 .64319 L .17486 .64215 L p .707 .577 .707 r
F P
0 g
s
.35587 .77992 m .35401 .79662 L .35236 .78091 L p .707 .577 .707 r
F P
0 g
s
.35236 .78091 m .35422 .7642 L .35587 .77992 L p .707 .577 .707 r
F P
0 g
s
.36102 .77285 m .36102 .27097 L .37976 .25995 L p .707 .577 .707 r
F P
0 g
s
.36102 .27097 m .36102 .77285 L .35589 .78489 L p .707 .577 .707 r
F P
0 g
s
.15174 .76898 m .15361 .75227 L .16186 .73791 L p .707 .577 .707 r
F P
0 g
s
.63514 .26779 m .63514 .76968 L .61294 .75914 L p .707 .577 .707 r
F P
0 g
s
.61294 .75914 m .61294 .25725 L .63514 .26779 L p .707 .577 .707 r
F P
0 g
s
.16731 .74898 m .16469 .71086 L .18085 .70661 L p .707 .577 .707 r
F P
0 g
s
.16186 .73791 m .15999 .75462 L .15174 .76898 L p .707 .577 .707 r
F P
0 g
s
.18085 .70661 m .18347 .74474 L .16731 .74898 L p .707 .577 .707 r
F P
0 g
s
.33845 .61875 m .34656 .67583 L .32491 .67984 L p .707 .577 .707 r
F P
0 g
s
.32491 .67984 m .31681 .62276 L .33845 .61875 L p .707 .577 .707 r
F P
0 g
s
.19795 .63976 m .20605 .69684 L .18296 .69923 L p .707 .577 .707 r
F P
0 g
s
.18296 .69923 m .17486 .64215 L .19795 .63976 L p .707 .577 .707 r
F P
0 g
s
.35422 .7642 m .35236 .78091 L .34097 .76538 L p .707 .577 .707 r
F P
0 g
s
.34097 .76538 m .34283 .74867 L .35422 .7642 L p .707 .577 .707 r
F P
0 g
s
.34549 .69661 m .34811 .73474 L .32695 .73343 L p .707 .577 .707 r
F P
0 g
s
.32695 .73343 m .32434 .69531 L .34549 .69661 L p .707 .577 .707 r
F P
0 g
s
.15999 .75462 m .16186 .73791 L .1792 .7263 L p .707 .577 .707 r
F P
0 g
s
.37976 .25995 m .37976 .76184 L .36102 .77285 L p .707 .577 .707 r
F P
0 g
s
.37976 .76184 m .37976 .25995 L .41027 .25102 L p .707 .577 .707 r
F P
0 g
s
.18347 .74474 m .18085 .70661 L .20472 .70257 L p .707 .577 .707 r
F P
0 g
s
.31681 .62276 m .32491 .67984 L .29719 .68439 L p .707 .577 .707 r
F P
0 g
s
.1792 .7263 m .17733 .74301 L .15999 .75462 L p .707 .577 .707 r
F P
0 g
s
.20472 .70257 m .20733 .74069 L .18347 .74474 L p .707 .577 .707 r
F P
0 g
s
.29719 .68439 m .28908 .62731 L .31681 .62276 L p .707 .577 .707 r
F P
0 g
s
.22659 .63625 m .2347 .69333 L .20605 .69684 L p .707 .577 .707 r
F P
0 g
s
.20605 .69684 m .19795 .63976 L .22659 .63625 L p .707 .577 .707 r
F P
0 g
s
.61294 .25725 m .61294 .75914 L .57968 .75095 L p .707 .577 .707 r
F P
0 g
s
.57968 .75095 m .57968 .24907 L .61294 .25725 L p .707 .577 .707 r
F P
0 g
s
.34283 .74867 m .34097 .76538 L .32096 .75155 L p .707 .577 .707 r
F P
0 g
s
.32096 .75155 m .32282 .73484 L .34283 .74867 L p .707 .577 .707 r
F P
0 g
s
.32434 .69531 m .32695 .73343 L .29945 .73344 L p .707 .577 .707 r
F P
0 g
s
.29945 .73344 m .29684 .69531 L .32434 .69531 L p .707 .577 .707 r
F P
0 g
s
.73389 .68272 m .742 .63504 L .71091 .62805 L p .707 .577 .707 r
F P
0 g
s
.742 .63504 m .73389 .68272 L .7653 .68424 L p .707 .577 .707 r
F P
0 g
s
.7653 .68424 m .7734 .63657 L .742 .63504 L p .707 .577 .707 r
F P
0 g
s
.70281 .67572 m .71091 .62805 L .68319 .61627 L p .707 .577 .707 r
F P
0 g
s
.71091 .62805 m .70281 .67572 L .73389 .68272 L p .707 .577 .707 r
F P
0 g
s
.28908 .62731 m .29719 .68439 L .2661 .68903 L p .707 .577 .707 r
F P
0 g
s
.17733 .74301 m .1792 .7263 L .20393 .71859 L p .707 .577 .707 r
F P
0 g
s
.258 .63196 m .2661 .68903 L .2347 .69333 L p .707 .577 .707 r
F P
0 g
s
.2347 .69333 m .22659 .63625 L .258 .63196 L p .707 .577 .707 r
F P
0 g
s
.2661 .68903 m .258 .63196 L .28908 .62731 L p .707 .577 .707 r
F P
0 g
s
.7734 .63657 m .7653 .68424 L .79395 .68015 L p .707 .577 .707 r
F P
0 g
s
.79395 .68015 m .80205 .63247 L .7734 .63657 L p .707 .577 .707 r
F P
0 g
s
.20733 .74069 m .20472 .70257 L .23395 .69913 L p .707 .577 .707 r
F P
0 g
s
.23395 .69913 m .23657 .73726 L .20733 .74069 L p .707 .577 .707 r
F P
0 g
s
.67509 .66394 m .68319 .61627 L .66154 .60086 L p .707 .577 .707 r
F P
0 g
s
.68319 .61627 m .67509 .66394 L .70281 .67572 L p .707 .577 .707 r
F P
0 g
s
.20393 .71859 m .20207 .7353 L .17733 .74301 L p .707 .577 .707 r
F P
0 g
s
.29684 .69531 m .29945 .73344 L .26831 .73475 L p .707 .577 .707 r
F P
0 g
s
.26831 .73475 m .2657 .69663 L .29684 .69531 L p .707 .577 .707 r
F P
0 g
s
.41027 .75291 m .41027 .25102 L .44956 .24507 L p .707 .577 .707 r
F P
0 g
s
.41027 .25102 m .41027 .75291 L .37976 .76184 L p .707 .577 .707 r
F P
0 g
s
.32282 .73484 m .32096 .75155 L .29428 .74079 L p .707 .577 .707 r
F P
0 g
s
.29428 .74079 m .29614 .72408 L .32282 .73484 L p .707 .577 .707 r
F P
0 g
s
.23657 .73726 m .23395 .69913 L .2657 .69663 L p .707 .577 .707 r
F P
0 g
s
.80205 .63247 m .79395 .68015 L .81704 .67083 L p .707 .577 .707 r
F P
0 g
s
.81704 .67083 m .82514 .62316 L .80205 .63247 L p .707 .577 .707 r
F P
0 g
s
.2657 .69663 m .26831 .73475 L .23657 .73726 L p .707 .577 .707 r
F P
0 g
s
.73645 .74086 m .73458 .72173 L .70385 .72444 L p .707 .577 .707 r
F P
0 g
s
.73458 .72173 m .73645 .74086 L .76822 .73772 L p .707 .577 .707 r
F P
0 g
s
.76822 .73772 m .76636 .71859 L .73458 .72173 L p .707 .577 .707 r
F P
0 g
s
.70385 .72444 m .70572 .74357 L .73645 .74086 L p .707 .577 .707 r
F P
0 g
s
.20207 .7353 m .20393 .71859 L .23364 .71553 L p .707 .577 .707 r
F P
0 g
s
.57968 .24907 m .57968 .75095 L .53862 .74593 L p .707 .577 .707 r
F P
0 g
s
.53862 .74593 m .53862 .24404 L .57968 .24907 L p .707 .577 .707 r
F P
0 g
s
.76636 .71859 m .76822 .73772 L .79793 .73445 L p .707 .577 .707 r
F P
0 g
s
.79793 .73445 m .79607 .71531 L .76636 .71859 L p .707 .577 .707 r
F P
0 g
s
.73169 .73078 m .7343 .69587 L .70316 .69108 L p .707 .577 .707 r
F P
0 g
s
.7343 .69587 m .73169 .73078 L .76343 .73146 L p .707 .577 .707 r
F P
0 g
s
.76343 .73146 m .76604 .69655 L .7343 .69587 L p .707 .577 .707 r
F P
0 g
s
.76604 .69655 m .76343 .73146 L .79267 .72796 L p .707 .577 .707 r
F P
0 g
s
.79267 .72796 m .79528 .69305 L .76604 .69655 L p .707 .577 .707 r
F P
0 g
s
.70572 .74357 m .70385 .72444 L .67718 .72645 L p .707 .577 .707 r
F P
0 g
s
.70054 .72599 m .70316 .69108 L .67566 .68265 L p .707 .577 .707 r
F P
0 g
s
.70316 .69108 m .70054 .72599 L .73169 .73078 L p .707 .577 .707 r
F P
0 g
s
.67718 .72645 m .67904 .74558 L .70572 .74357 L p .707 .577 .707 r
F P
0 g
s
.65344 .64853 m .66154 .60086 L .64809 .58332 L p .707 .577 .707 r
F P
0 g
s
.66154 .60086 m .65344 .64853 L .67509 .66394 L p .707 .577 .707 r
F P
0 g
s
.29614 .72408 m .29428 .74079 L .26355 .73413 L p .707 .577 .707 r
F P
0 g
s
.26355 .73413 m .26541 .71742 L .29614 .72408 L p .707 .577 .707 r
F P
0 g
s
.23364 .71553 m .23178 .73224 L .20207 .7353 L p .707 .577 .707 r
F P
0 g
s
.23178 .73224 m .23364 .71553 L .26541 .71742 L p .707 .577 .707 r
F P
0 g
s
.79607 .71531 m .79793 .73445 L .82266 .73137 L p .707 .577 .707 r
F P
0 g
s
.82266 .73137 m .8208 .71223 L .79607 .71531 L p .707 .577 .707 r
F P
0 g
s
.26541 .71742 m .26355 .73413 L .23178 .73224 L p .707 .577 .707 r
F P
0 g
s
.44956 .74696 m .44956 .24507 L .49379 .24266 L p .707 .577 .707 r
F P
0 g
s
.44956 .24507 m .44956 .74696 L .41027 .75291 L p .707 .577 .707 r
F P
0 g
s
.82514 .62316 m .81704 .67083 L .8323 .65721 L p .707 .577 .707 r
F P
0 g
s
.8323 .65721 m .84041 .60954 L .82514 .62316 L p .707 .577 .707 r
F P
0 g
s
.79528 .69305 m .79267 .72796 L .81653 .72062 L p .707 .577 .707 r
F P
0 g
s
.81653 .72062 m .81914 .68571 L .79528 .69305 L p .707 .577 .707 r
F P
0 g
s
.53862 .24404 m .53862 .74593 L .49379 .74455 L p .707 .577 .707 r
F P
0 g
s
.49379 .74455 m .49379 .24266 L .53862 .24404 L p .707 .577 .707 r
F P
0 g
s
.67305 .71755 m .67566 .68265 L .6545 .6714 L p .707 .577 .707 r
F P
0 g
s
.67566 .68265 m .67305 .71755 L .70054 .72599 L p .707 .577 .707 r
F P
0 g
s
.49379 .24266 m .49379 .74455 L .44956 .74696 L p .707 .577 .707 r
F P
0 g
s
.67904 .74558 m .67718 .72645 L .65717 .72756 L p .707 .577 .707 r
F P
0 g
s
.65717 .72756 m .65903 .74669 L .67904 .74558 L p .707 .577 .707 r
F P
0 g
s
.63998 .63099 m .64809 .58332 L .64415 .56538 L p .707 .577 .707 r
F P
0 g
s
.64809 .58332 m .63998 .63099 L .65344 .64853 L p .707 .577 .707 r
F P
0 g
s
.8208 .71223 m .82266 .73137 L .84 .72878 L p .707 .577 .707 r
F P
0 g
s
.84 .72878 m .83814 .70965 L .8208 .71223 L p .707 .577 .707 r
F P
0 g
s
.6545 .6714 m .65189 .7063 L .67305 .71755 L p .707 .577 .707 r
F P
0 g
s
.81914 .68571 m .81653 .72062 L .83269 .71017 L p .707 .577 .707 r
F P
0 g
s
.83269 .71017 m .8353 .67526 L .81914 .68571 L p .707 .577 .707 r
F P
0 g
s
.84041 .60954 m .8323 .65721 L .83826 .64062 L p .707 .577 .707 r
F P
0 g
s
.83826 .64062 m .84636 .59294 L .84041 .60954 L p .707 .577 .707 r
F P
0 g
s
.65189 .7063 m .6545 .6714 L .64176 .65843 L p .707 .577 .707 r
F P
0 g
s
.65903 .74669 m .65717 .72756 L .64578 .72766 L p .707 .577 .707 r
F P
0 g
s
.64578 .72766 m .64764 .7468 L .65903 .74669 L p .707 .577 .707 r
F P
0 g
s
.64415 .56538 m .63604 .61305 L .63998 .63099 L p .707 .577 .707 r
F P
0 g
s
.63604 .61305 m .64415 .56538 L .6501 .54878 L p .707 .577 .707 r
F P
0 g
s
.64176 .65843 m .63914 .69333 L .65189 .7063 L p .707 .577 .707 r
F P
0 g
s
.83814 .70965 m .84 .72878 L .84825 .72694 L p .707 .577 .707 r
F P
0 g
s
.84825 .72694 m .84639 .70781 L .83814 .70965 L p .707 .577 .707 r
F P
0 g
s
.8353 .67526 m .83269 .71017 L .83956 .69762 L p .707 .577 .707 r
F P
0 g
s
.83956 .69762 m .84218 .66271 L .8353 .67526 L p .707 .577 .707 r
F P
0 g
s
.84636 .59294 m .83826 .64062 L .83432 .62267 L p .707 .577 .707 r
F P
0 g
s
.83432 .62267 m .84242 .575 L .84636 .59294 L p .707 .577 .707 r
F P
0 g
s
.63914 .69333 m .64176 .65843 L .63867 .64502 L p .707 .577 .707 r
F P
0 g
s
.64764 .7468 m .64578 .72766 L .64413 .72675 L p .707 .577 .707 r
F P
0 g
s
.64413 .72675 m .64599 .74588 L .64764 .7468 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.642 .59646 m .6501 .54878 L .66537 .53516 L p .707 .577 .707 r
F P
0 g
s
.6501 .54878 m .642 .59646 L .63604 .61305 L p .707 .577 .707 r
F P
0 g
s
.63867 .64502 m .63606 .67992 L .63914 .69333 L p .707 .577 .707 r
F P
0 g
s
.84639 .70781 m .84825 .72694 L .8466 .72603 L p .707 .577 .707 r
F P
0 g
s
.8466 .72603 m .84474 .7069 L .84639 .70781 L p .707 .577 .707 r
F P
0 g
s
.84218 .66271 m .83956 .69762 L .83648 .6842 L p .707 .577 .707 r
F P
0 g
s
.83648 .6842 m .83909 .6493 L .84218 .66271 L p .707 .577 .707 r
F P
0 g
s
.84242 .575 m .83432 .62267 L .82086 .60514 L p .707 .577 .707 r
F P
0 g
s
.82086 .60514 m .82897 .55746 L .84242 .575 L p .707 .577 .707 r
F P
0 g
s
.63606 .67992 m .63867 .64502 L .64554 .63247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.66537 .53516 m .65727 .58284 L .642 .59646 L p .707 .577 .707 r
F P
0 g
s
.65727 .58284 m .66537 .53516 L .68846 .52585 L p .707 .577 .707 r
F P
0 g
s
.3859 .60399 m .40412 .5497 L .37443 .53906 L p .707 .577 .707 r
F P
0 g
s
.40412 .5497 m .3859 .60399 L .41605 .61349 L p .707 .577 .707 r
F P
0 g
s
.41605 .61349 m .43427 .5592 L .40412 .5497 L p .707 .577 .707 r
F P
0 g
s
.64599 .74588 m .64413 .72675 L .65238 .72491 L p .707 .577 .707 r
F P
0 g
s
.65238 .72491 m .65424 .74404 L .64599 .74588 L p .707 .577 .707 r
F P
0 g
s
.64554 .63247 m .64293 .66737 L .63606 .67992 L p .707 .577 .707 r
F P
0 g
s
.43427 .5592 m .41605 .61349 L .44371 .62092 L p .707 .577 .707 r
F P
0 g
s
.44371 .62092 m .46193 .56663 L .43427 .5592 L p .707 .577 .707 r
F P
0 g
s
.3562 .59335 m .37443 .53906 L .34809 .52832 L p .707 .577 .707 r
F P
0 g
s
.37443 .53906 m .3562 .59335 L .3859 .60399 L p .707 .577 .707 r
F P
0 g
s
.82897 .55746 m .82086 .60514 L .79921 .58972 L p .707 .577 .707 r
F P
0 g
s
.79921 .58972 m .80732 .54205 L .82897 .55746 L p .707 .577 .707 r
F P
0 g
s
.83909 .6493 m .83648 .6842 L .82373 .67124 L p .707 .577 .707 r
F P
0 g
s
.82373 .67124 m .82634 .63633 L .83909 .6493 L p .707 .577 .707 r
F P
0 g
s
.84474 .7069 m .8466 .72603 L .83522 .72613 L p .707 .577 .707 r
F P
0 g
s
.83522 .72613 m .83335 .707 L .84474 .7069 L p .707 .577 .707 r
F P
0 g
s
.34809 .52832 m .32987 .58261 L .3562 .59335 L p .707 .577 .707 r
F P
0 g
s
.64293 .66737 m .64554 .63247 L .6617 .62201 L p .707 .577 .707 r
F P
0 g
s
.3853 .67361 m .39134 .63641 L .36054 .63019 L p .707 .577 .707 r
F P
0 g
s
.39134 .63641 m .3853 .67361 L .41673 .67791 L p .707 .577 .707 r
F P
0 g
s
.41673 .67791 m .42278 .6407 L .39134 .63641 L p .707 .577 .707 r
F P
0 g
s
.46193 .56663 m .44371 .62092 L .46616 .62555 L p .707 .577 .707 r
F P
0 g
s
.46616 .62555 m .48438 .57127 L .46193 .56663 L p .707 .577 .707 r
F P
0 g
s
.68035 .57352 m .68846 .52585 L .71711 .52175 L p .707 .577 .707 r
F P
0 g
s
.68846 .52585 m .68035 .57352 L .65727 .58284 L p .707 .577 .707 r
F P
0 g
s
.32987 .58261 m .34809 .52832 L .3277 .51853 L p .707 .577 .707 r
F P
0 g
s
.42278 .6407 m .41673 .67791 L .44572 .67986 L p .707 .577 .707 r
F P
0 g
s
.44572 .67986 m .45177 .64266 L .42278 .6407 L p .707 .577 .707 r
F P
0 g
s
.3545 .66739 m .36054 .63019 L .33339 .62266 L p .707 .577 .707 r
F P
0 g
s
.36054 .63019 m .3545 .66739 L .3853 .67361 L p .707 .577 .707 r
F P
0 g
s
.80732 .54205 m .79921 .58972 L .77149 .57794 L p .707 .577 .707 r
F P
0 g
s
.77149 .57794 m .7796 .53027 L .80732 .54205 L p .707 .577 .707 r
F P
0 g
s
.3277 .51853 m .30947 .57282 L .32987 .58261 L p .707 .577 .707 r
F P
0 g
s
.33339 .62266 m .32735 .65986 L .3545 .66739 L p .707 .577 .707 r
F P
0 g
s
.6617 .62201 m .65909 .65692 L .64293 .66737 L p .707 .577 .707 r
F P
0 g
s
.709 .56943 m .71711 .52175 L .74851 .52328 L p .707 .577 .707 r
F P
0 g
s
.71711 .52175 m .709 .56943 L .68035 .57352 L p .707 .577 .707 r
F P
0 g
s
.65424 .74404 m .65238 .72491 L .66972 .72233 L p .707 .577 .707 r
F P
0 g
s
.66972 .72233 m .67158 .74146 L .65424 .74404 L p .707 .577 .707 r
F P
0 g
s
.45177 .64266 m .44572 .67986 L .46943 .67928 L p .707 .577 .707 r
F P
0 g
s
.46943 .67928 m .47547 .64208 L .45177 .64266 L p .707 .577 .707 r
F P
0 g
s
.7796 .53027 m .77149 .57794 L .74041 .57095 L p .707 .577 .707 r
F P
0 g
s
.74041 .57095 m .74851 .52328 L .7796 .53027 L p .707 .577 .707 r
F P
0 g
s
.82634 .63633 m .82373 .67124 L .80257 .65999 L p .707 .577 .707 r
F P
0 g
s
.80257 .65999 m .80518 .62508 L .82634 .63633 L p .707 .577 .707 r
F P
0 g
s
.74851 .52328 m .74041 .57095 L .709 .56943 L p .707 .577 .707 r
F P
0 g
s
.32735 .65986 m .33339 .62266 L .31254 .61456 L p .707 .577 .707 r
F P
0 g
s
.48438 .57127 m .46616 .62555 L .4812 .62694 L p .707 .577 .707 r
F P
0 g
s
.4812 .62694 m .49943 .57265 L .48438 .57127 L p .707 .577 .707 r
F P
0 g
s
.83335 .707 m .83522 .72613 L .8152 .72724 L p .707 .577 .707 r
F P
0 g
s
.8152 .72724 m .81334 .70811 L .83335 .707 L p .707 .577 .707 r
F P
0 g
s
.65909 .65692 m .6617 .62201 L .68556 .61468 L p .707 .577 .707 r
F P
0 g
s
.30947 .57282 m .3277 .51853 L .31524 .51066 L p .707 .577 .707 r
F P
0 g
s
.43317 .72466 m .42881 .70715 L .3977 .71439 L p .707 .577 .707 r
F P
0 g
s
.42881 .70715 m .43317 .72466 L .46235 .71436 L p .707 .577 .707 r
F P
0 g
s
.46235 .71436 m .458 .69685 L .42881 .70715 L p .707 .577 .707 r
F P
0 g
s
.40206 .7319 m .3977 .71439 L .36771 .71785 L p .707 .577 .707 r
F P
0 g
s
.3977 .71439 m .40206 .7319 L .43317 .72466 L p .707 .577 .707 r
F P
0 g
s
.31254 .61456 m .3065 .65176 L .32735 .65986 L p .707 .577 .707 r
F P
0 g
s
.31524 .51066 m .29702 .56495 L .30947 .57282 L p .707 .577 .707 r
F P
0 g
s
.36771 .71785 m .37207 .73536 L .40206 .7319 L p .707 .577 .707 r
F P
0 g
s
.458 .69685 m .46235 .71436 L .48675 .702 L p .707 .577 .707 r
F P
0 g
s
.48675 .702 m .48239 .68449 L .458 .69685 L p .707 .577 .707 r
F P
0 g
s
.37207 .73536 m .36771 .71785 L .34177 .7172 L p .707 .577 .707 r
F P
0 g
s
.47547 .64208 m .46943 .67928 L .48554 .67623 L p .707 .577 .707 r
F P
0 g
s
.48554 .67623 m .49158 .63903 L .47547 .64208 L p .707 .577 .707 r
F P
0 g
s
.68556 .61468 m .68295 .64958 L .65909 .65692 L p .707 .577 .707 r
F P
0 g
s
.80518 .62508 m .80257 .65999 L .77508 .65155 L p .707 .577 .707 r
F P
0 g
s
.77508 .65155 m .77769 .61665 L .80518 .62508 L p .707 .577 .707 r
F P
0 g
s
.67158 .74146 m .66972 .72233 L .69445 .71925 L p .707 .577 .707 r
F P
0 g
s
.69445 .71925 m .69632 .73838 L .67158 .74146 L p .707 .577 .707 r
F P
0 g
s
.68295 .64958 m .68556 .61468 L .7148 .61118 L p .707 .577 .707 r
F P
0 g
s
.3065 .65176 m .31254 .61456 L .30004 .60667 L p .707 .577 .707 r
F P
0 g
s
.34177 .7172 m .34613 .73471 L .37207 .73536 L p .707 .577 .707 r
F P
0 g
s
.81334 .70811 m .8152 .72724 L .78853 .72925 L p .707 .577 .707 r
F P
0 g
s
.78853 .72925 m .78667 .71012 L .81334 .70811 L p .707 .577 .707 r
F P
0 g
s
.48239 .68449 m .48675 .702 L .50397 .68879 L p .707 .577 .707 r
F P
0 g
s
.50397 .68879 m .49962 .67128 L .48239 .68449 L p .707 .577 .707 r
F P
0 g
s
.49943 .57265 m .4812 .62694 L .48738 .62494 L p .707 .577 .707 r
F P
0 g
s
.48738 .62494 m .5056 .57065 L .49943 .57265 L p .707 .577 .707 r
F P
0 g
s
.30004 .60667 m .294 .64387 L .3065 .65176 L p .707 .577 .707 r
F P
0 g
s
.29702 .56495 m .31524 .51066 L .31193 .50547 L p .707 .577 .707 r
F P
0 g
s
.77769 .61665 m .77508 .65155 L .74393 .64676 L p .707 .577 .707 r
F P
0 g
s
.74393 .64676 m .74654 .61186 L .77769 .61665 L p .707 .577 .707 r
F P
0 g
s
.71219 .64608 m .7148 .61118 L .74654 .61186 L p .707 .577 .707 r
F P
0 g
s
.7148 .61118 m .71219 .64608 L .68295 .64958 L p .707 .577 .707 r
F P
0 g
s
.34613 .73471 m .34177 .7172 L .32243 .7125 L p .707 .577 .707 r
F P
0 g
s
.31193 .50547 m .29371 .55975 L .29702 .56495 L p .707 .577 .707 r
F P
0 g
s
.74654 .61186 m .74393 .64676 L .71219 .64608 L p .707 .577 .707 r
F P
0 g
s
.69632 .73838 m .69445 .71925 L .72416 .71597 L p .707 .577 .707 r
F P
0 g
s
.72416 .71597 m .72603 .7351 L .69632 .73838 L p .707 .577 .707 r
F P
0 g
s
.32243 .7125 m .32678 .73001 L .34613 .73471 L p .707 .577 .707 r
F P
0 g
s
.78667 .71012 m .78853 .72925 L .7578 .73196 L p .707 .577 .707 r
F P
0 g
s
.7578 .73196 m .75594 .71283 L .78667 .71012 L p .707 .577 .707 r
F P
0 g
s
.49158 .63903 m .48554 .67623 L .49246 .671 L p .707 .577 .707 r
F P
0 g
s
.49246 .671 m .49851 .6338 L .49158 .63903 L p .707 .577 .707 r
F P
0 g
s
.294 .64387 m .30004 .60667 L .29711 .59977 L p .707 .577 .707 r
F P
0 g
s
.72603 .7351 m .72416 .71597 L .75594 .71283 L p .707 .577 .707 r
F P
0 g
s
.75594 .71283 m .7578 .73196 L .72603 .7351 L p .707 .577 .707 r
F P
0 g
s
.49962 .67128 m .50397 .68879 L .51234 .67603 L p .707 .577 .707 r
F P
0 g
s
.51234 .67603 m .50798 .65852 L .49962 .67128 L p .707 .577 .707 r
F P
0 g
s
.29711 .59977 m .29107 .63698 L .294 .64387 L p .707 .577 .707 r
F P
0 g
s
.32678 .73001 m .32243 .7125 L .31156 .70421 L p .707 .577 .707 r
F P
0 g
s
.5056 .57065 m .48738 .62494 L .48408 .61974 L p .707 .577 .707 r
F P
0 g
s
.48408 .61974 m .5023 .56546 L .5056 .57065 L p .707 .577 .707 r
F P
0 g
s
.29371 .55975 m .31193 .50547 L .31811 .50346 L p .707 .577 .707 r
F P
0 g
s
.31156 .70421 m .31592 .72172 L .32678 .73001 L p .707 .577 .707 r
F P
0 g
s
.31811 .50346 m .29989 .55775 L .29371 .55975 L p .707 .577 .707 r
F P
0 g
s
.49851 .6338 m .49246 .671 L .48953 .6641 L p .707 .577 .707 r
F P
0 g
s
.48953 .6641 m .49557 .6269 L .49851 .6338 L p .707 .577 .707 r
F P
0 g
s
.50798 .65852 m .51234 .67603 L .51102 .66496 L p .707 .577 .707 r
F P
0 g
s
.51102 .66496 m .50667 .64745 L .50798 .65852 L p .707 .577 .707 r
F P
0 g
s
.29107 .63698 m .29711 .59977 L .30403 .59454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31592 .72172 m .31156 .70421 L .31025 .69314 L p .707 .577 .707 r
F P
0 g
s
.30403 .59454 m .29799 .63175 L .29107 .63698 L p .707 .577 .707 r
F P
0 g
s
.5023 .56546 m .48408 .61974 L .47162 .61187 L p .707 .577 .707 r
F P
0 g
s
.47162 .61187 m .48984 .55758 L .5023 .56546 L p .707 .577 .707 r
F P
0 g
s
.29989 .55775 m .31811 .50346 L .33315 .50485 L p .707 .577 .707 r
F P
0 g
s
.31025 .69314 m .31461 .71065 L .31592 .72172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.33315 .50485 m .31493 .55913 L .29989 .55775 L p .707 .577 .707 r
F P
0 g
s
.49557 .6269 m .48953 .6641 L .47703 .65622 L p .707 .577 .707 r
F P
0 g
s
.47703 .65622 m .48307 .61901 L .49557 .6269 L p .707 .577 .707 r
F P
0 g
s
.50667 .64745 m .51102 .66496 L .50016 .65667 L p .707 .577 .707 r
F P
0 g
s
.50016 .65667 m .49581 .63916 L .50667 .64745 L p .707 .577 .707 r
F P
0 g
s
.29799 .63175 m .30403 .59454 L .32014 .59149 L p .707 .577 .707 r
F P
0 g
s
.31461 .71065 m .31025 .69314 L .31862 .68038 L p .707 .577 .707 r
F P
0 g
s
.32014 .59149 m .3141 .62869 L .29799 .63175 L p .707 .577 .707 r
F P
0 g
s
.48984 .55758 m .47162 .61187 L .45122 .60208 L p .707 .577 .707 r
F P
0 g
s
.45122 .60208 m .46944 .54779 L .48984 .55758 L p .707 .577 .707 r
F P
0 g
s
.31493 .55913 m .33315 .50485 L .35561 .50948 L p .707 .577 .707 r
F P
0 g
s
.31862 .68038 m .32297 .69789 L .31461 .71065 L p .707 .577 .707 r
F P
0 g
s
.35561 .50948 m .33738 .56377 L .31493 .55913 L p .707 .577 .707 r
F P
0 g
s
.48307 .61901 m .47703 .65622 L .45618 .64811 L p .707 .577 .707 r
F P
0 g
s
.45618 .64811 m .46223 .61091 L .48307 .61901 L p .707 .577 .707 r
F P
0 g
s
.49581 .63916 m .50016 .65667 L .48082 .65198 L p .707 .577 .707 r
F P
0 g
s
.48082 .65198 m .47646 .63447 L .49581 .63916 L p .707 .577 .707 r
F P
0 g
s
.3141 .62869 m .32014 .59149 L .34385 .59091 L p .707 .577 .707 r
F P
0 g
s
.46944 .54779 m .45122 .60208 L .42489 .59134 L p .707 .577 .707 r
F P
0 g
s
.42489 .59134 m .44311 .53706 L .46944 .54779 L p .707 .577 .707 r
F P
0 g
s
.33738 .56377 m .35561 .50948 L .38326 .51691 L p .707 .577 .707 r
F P
0 g
s
.32297 .69789 m .31862 .68038 L .33584 .66718 L p .707 .577 .707 r
F P
0 g
s
.34385 .59091 m .3378 .62811 L .3141 .62869 L p .707 .577 .707 r
F P
0 g
s
.38326 .51691 m .36504 .5712 L .33738 .56377 L p .707 .577 .707 r
F P
0 g
s
.33584 .66718 m .3402 .68469 L .32297 .69789 L p .707 .577 .707 r
F P
0 g
s
.46223 .61091 m .45618 .64811 L .42903 .64058 L p .707 .577 .707 r
F P
0 g
s
.42903 .64058 m .43507 .60338 L .46223 .61091 L p .707 .577 .707 r
F P
0 g
s
.44311 .53706 m .42489 .59134 L .39519 .5807 L p .707 .577 .707 r
F P
0 g
s
.39519 .5807 m .41341 .52641 L .44311 .53706 L p .707 .577 .707 r
F P
0 g
s
.36504 .5712 m .38326 .51691 L .41341 .52641 L p .707 .577 .707 r
F P
0 g
s
.3378 .62811 m .34385 .59091 L .37284 .59287 L p .707 .577 .707 r
F P
0 g
s
.41341 .52641 m .39519 .5807 L .36504 .5712 L p .707 .577 .707 r
F P
0 g
s
.47646 .63447 m .48082 .65198 L .45488 .65133 L p .707 .577 .707 r
F P
0 g
s
.45488 .65133 m .45052 .63382 L .47646 .63447 L p .707 .577 .707 r
F P
0 g
s
.37284 .59287 m .36679 .63007 L .3378 .62811 L p .707 .577 .707 r
F P
0 g
s
.3402 .68469 m .33584 .66718 L .36024 .65482 L p .707 .577 .707 r
F P
0 g
s
.43507 .60338 m .42903 .64058 L .39823 .63437 L p .707 .577 .707 r
F P
0 g
s
.39823 .63437 m .40427 .59716 L .43507 .60338 L p .707 .577 .707 r
F P
0 g
s
.36679 .63007 m .37284 .59287 L .40427 .59716 L p .707 .577 .707 r
F P
0 g
s
.36024 .65482 m .36459 .67233 L .3402 .68469 L p .707 .577 .707 r
F P
0 g
s
.40427 .59716 m .39823 .63437 L .36679 .63007 L p .707 .577 .707 r
F P
0 g
s
.45052 .63382 m .45488 .65133 L .42489 .65479 L p .707 .577 .707 r
F P
0 g
s
.42489 .65479 m .42053 .63728 L .45052 .63382 L p .707 .577 .707 r
F P
0 g
s
.36459 .67233 m .36024 .65482 L .38942 .64451 L p .707 .577 .707 r
F P
0 g
s
.38942 .64451 m .39378 .66203 L .36459 .67233 L p .707 .577 .707 r
F P
0 g
s
.42053 .63728 m .42489 .65479 L .39378 .66203 L p .707 .577 .707 r
F P
0 g
s
.39378 .66203 m .38942 .64451 L .42053 .63728 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP000080
07Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF1000L7oo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001^Ool006]oo`8000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006aoo`00JGoo0`00
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JWoo001WOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00IWoo00<005YFFUH0
0UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol:0003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol00`00FUH00003
FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Egoo
00<005YF00000eYF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP@000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000@Ool?0016
Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF000;Ool50003FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP002Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0`00?goo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001goo0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00?Goo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH4
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00P00
>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH000Aoo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF009JEP8003Uoo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009oo`800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Moo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00H005YFFUH007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH3000eOol005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000d
Ool005Aoo`03FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00<Woo001COol0
1000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0;goo001COol20002FUH50003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000`Ool005Aoo`05001JEUYFFUH00003FUH50007FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002mo
o`00EGoo0P001eYF00<005YFFUH010000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000_Ool005Moo`03001JEUYF00AJEP03001J
EUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00=JEP03001JEUYF00@000Ioo`L000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005Qoo`8000AJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEP@0015oo`@0009JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FWoo0P0000=JEP00FUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF
FUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH0
0`00FUH00003000IOol40006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005ao
o`<000MJEP03001JEUYF00IJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP80025o
o`8000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00Ggoo0P001EYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00Oomo
o`0SOol300000eYF001JEP05FUH00`00FUIJEP02FUH2000/Ool0065oo`<00003FUH005YF00MJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000015YF001JEP009goo0P001UYF00L005YFFUIJ
EP00FUH0000/Ool005UooaH000QJEP<000MJEP03001JEUYF00AJEP06001JEUYF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10000UYF00<007ooOol09goo00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000=JEP04001JEP000005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001oogoo01=oo`<0015oo`05
001JEUYFFUH00004FUH00`00FUH0000/Ool005Aoo`<000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00@000=JEP<00003FUH005YF00EJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<007ooOol04Goo
1@004Goo0P0000=JEP00FUH00eYF00<005YF0000;7oo001DOol00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH20006FUH01000FUIJEUYF
0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF0P00
4Woo1@004goo0P0015YF00<005YF0000;7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050004FUH01P00FUIJEP00FUH000aJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000EJEP03001JEP00015oo`D001Aoo`03
001JEUYF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEP8000Ioo`T0
0004Ool00000000FOol01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40003FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH6
0004FUH00`00FUIJEP02FUH9000BOol01@00FUH005YF0000;Goo001COol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000<
Ool01@00FUH005YF0000;Goo001<Ool800000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030008Ool300000eYF001o
o`0/Ool004=oo`T000AJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`80009JEP03001JEP0002eoo`00?Goo1P0015YF
00<005YFFUH015YF1@0000AJEP00FUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH500001eYF001JEUYF001JEP0002eoo`00>Goo100000=JEP00FUH0
1EYF2@0015YF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00800004FUH005YFFUH2000^
Ool003Aoo`D000AJEPP000AJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPP000IJEP03001JEUYF00h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000^Ool002moo`D0
0003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@000]J
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF0000000^Ool002]oo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEPH0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002ioo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEPl000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH0
0`00FUIJEP030003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003FUH00`00FUH00008FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUH000030007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH300000eYF001JEP06FUH30007FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP04FUH2
0003FUH400000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004
FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF0P0000=JEP00
FUH01eYF00<005YFFUH0100000=JEP00FUH01UYF00<005YFFUH015YF00D005YF000005YF0080009J
EP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0009JEP80009J
EP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP05FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF0`001eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YF000025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH005YF0P0015YF00@005YF000000IJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUH000001eYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUIJEP<00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30003FUH700000eYF00000003FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH40002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00EJEP<0009J
EPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000=JEP@000=JEPD0
0003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool01@00FUH005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0`0015YF00<005YFFUH015YF
200015YF00<005YFFUH015YF00<005YFFUH01@0000EJEP00FUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8000AJEP04001JEUYF0005FUH00`00FUH000040006FUH50004
FUH00`00FUIJEP05FUH01000FUH000001Woo00D005YF001JEP0002eoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P001EYF00D005YF000007oo008000AJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH>0002FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH0
1000FUIJEUYF0P000eYF00D005YFFUIJEP00009oo`@0009JEP@000EJEP03001JEUYF009JEPD000Mo
o`D002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2`001EYF0P000goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF0P0025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
0P0015YF00<005YFFUH00eYF0P000UYF00@005YFFUH000Iooa0000Yoo`8000=JEP8002ioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1`002Goo0P0015YF
00<007ooOol00goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01EYF0`001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YF00000`000UYF00<007ooOol06goo0`0015YF0P00;Woo000]Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000?Ool01@00FUIJEP00FUH00P001Woo
0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YFFUH00eYF1P0067oo0P000UYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6000;Ool90002FUH40006Ool20004FUH01000FUIJ
EUYF0`000UYF00<005YFFUH025YF00@005YFFUIJEP8000EJEP04001JEP00000;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH90009Ool60004FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<005YF00000UYF7P00
15YF00D005YFFUIJEP00009JEP80009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00QJEP04001J
EP000007FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Goo1@001Goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00T005YFFUIJEP00FUH005YF00001EYF00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01eYF0`0000=JEP00FUH01UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00<Woo1@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03
001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP80009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03001JEUYF008000AJEP03
001JEUYF00IJEP04001JEUYFFUH30008FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000E000/Ool002ioo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000000015YF
00<005YFFUH00P0015YF00<005YFFUH01UYF100000=JEP00FUH025YF0`001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP04001JEUYF0007
FUH00`00FUIJEP05FUH00`00FUIJEP090004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF0000;7oo000/Ool30004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF
00L005YFFUIJEP00FUH00002FUH90004FUH00`00FUH000060006FUH00`00FUIJEP05FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001EYF
0`001eYF00<005YFFUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002aoo`00;7oo00<005YF000015YF00<005YFFUH00UYF1P0015YF00<005YFFUH00UYF
2@001EYF00L005YFFUIJEP00FUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH000IJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;7oo00<005YF000015YF1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00@005YFFUH000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000[
Ool002aoo`03001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000002FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH01000FUIJEUYF3P00:goo000/Ool00`00FUH00002FUH20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH:000]Ool002aoo`03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00AJEP`000=JEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF
1`00=goo000]Ool20003FUH00`00FUIJEP03FUH600000eYF000000080004FUH40002FUH00`00FUIJ
EP05FUH30002FUH01000FUIJEUYF2P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH01000
FUIJEUYF4@000eYF2@00?Woo000]Ool20003FUH00`00FUH0000;0008FUH00`00FUIJEP06FUH40006
FUH01P00FUIJEP00FUH000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP000UYF1P001UYF00<005YFFUH00UYF2@00Agoo000/Ool00`00FUH00003FUH70006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP80009JEP@000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF2000D7oo000/Ool20002FUH3
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF
001JEP04FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH90009FUH01000FUIJEUYF
30001EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH03`0000=JEP000000E7oo000[Ool0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20005FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP060006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP080007FUH00`00FUIJEP03FUH01000FUIJEP00
2Woo10000UYF00<007ooOol0DWoo000[Ool01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF0P000Woo0P0015YF00<0
05YFFUH015YF1P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF1@000UYF00<0
05YFFUH00eYF00@005YFFUH000Qoo`8000AJEP<005Aoo`00:goo0P0000=oo`0000001@000eYF00<0
05YFFUH015YF00<005YFFUH00UYF4P001goo0P0000IJEP00FUIJEP00Ool20004FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP02FUH30005FUH01000FUIJEP001Woo0P0000=JEP00FUH00eYF00<005YF0000E7oo000[Ool20008
Ool?000KOol20002FUH01000Ool0000015YF100025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00@005YFFUH000Aoo`8000=JEP03
001JEUYF009JEP04001JEP00001COol002]oo`8003=oo`04001JEUYFFUH30002FUH20003FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300001UYF001JEUYF001oo`<000EJEP03001JEUYF009JEP04001JEUYF001COol002]o
o`8003Aoo`03001JEUYF00D000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP800003FUH005YF
00EJEP03001JEUYF009JEP04001JEUYF001COol002]oo`<001Yoo`<001Moo`03001JEP0000<000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00=J
EP8005Aoo`00:goo0`006Goo1@005Woo00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00E7oo000[Ool01000FUIJEP00
67oo1@005goo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH00UYF00<007ooOol0Dgoo000[Ool01@00FUIJEUYF00005goo1@0067oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00D005YF
FUIJEP0005Ioo`00:goo00@005YFFUIJEP<001Ioo`<001Qoo`<00003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP04001JEP00001GOol002aoo`04001JEUYF
0002FUH00`00Oomoo`0^Ool200000goo00000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH2001IOol002aoo`03001JEP0000AJEP8002eoo`04001JEP00Ool20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00Oomoo`1HOol0
02eoo`8000IJEP8002Yoo`800004FUH007ooOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020007
FUH01000FUIJEUYF0P00Fgoo000^Ool00`00FUIJEP04FUH01000FUH000009Woo0P0000=JEP000000
1Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF1@001eYF00@005YF000005eoo`00;goo0P0015YF00@005YFFUIJ
EP8002=oo`04001JEUYFFUH20007Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH01000FUH000000eYF1000
Ggoo000aOol01000FUIJEP001UYF10007Goo0P0015YF00<007ooOol027oo10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`0015YF00@0
05YFFUIJEP<006=oo`00<Woo0`001eYF00<005YFFUH010005Goo100000=JEP00FUH00eYF00<007oo
Ool037oo10000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`001EYF00<005YFFUH01EYF0`00H7oo000dOol20006FUH00`00FUIJEP04FUH70009
Ool50005FUH00`00FUIJEP02000COol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH;0002FUH00`00FUIJEP06FUH01000FUH00000GWoo000fOol20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH3000JOol60003FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0?0002Ool40006FUH00`00FUIJEP02FUH2001LOol003Qoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80029ooal00004FUH000000006
Ool50006Ool20004FUH00`00FUIJEP03FUH3001JOol003]oo`<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH2000gOol20006FUH00`00FUIJEP05FUH6000017oo000000002Goo0P00
00=JEP00FUH01EYF00@005YFFUH005Uoo`00?Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003]oo`@00003FUH005YF00QJEP03001JEUYF009JEPH000Uoo`<000AJEP05001JEUYF
FUH0001IOol0049ooaH0045oo`<000QJEP03001JEUYF00IJEP03001JEP0000<000Qoo`<00003FUH0
05YF009JEP8005Qoo`00W7oo0`0015YF00<005YFFUH01eYF00<005YFFUH00eYF3@000UYF00<005YF
0000F7oo002OOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP8005Uoo`00XWoo10001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00
FGoo002VOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001J
Ool00:Yoo`H000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Yoo`00/7oo20000eYF
00<005YFFUH01000Fgoo002hOol6001OOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63496 .75157 m .61674 .70145 L .58659 .71204 L p .707 .577 .707 r
F P
0 g
s
.61674 .70145 m .63496 .75157 L .66261 .73787 L p .707 .577 .707 r
F P
0 g
s
.66261 .73787 m .64439 .68774 L .61674 .70145 L p .707 .577 .707 r
F P
0 g
s
.60481 .76216 m .58659 .71204 L .55689 .71847 L p .707 .577 .707 r
F P
0 g
s
.58659 .71204 m .60481 .76216 L .63496 .75157 L p .707 .577 .707 r
F P
0 g
s
.64439 .68774 m .66261 .73787 L .68506 .72238 L p .707 .577 .707 r
F P
0 g
s
.68506 .72238 m .66684 .67226 L .64439 .68774 L p .707 .577 .707 r
F P
0 g
s
.57511 .76859 m .55689 .71847 L .53056 .72012 L p .707 .577 .707 r
F P
0 g
s
.55689 .71847 m .57511 .76859 L .60481 .76216 L p .707 .577 .707 r
F P
0 g
s
.60177 .81655 m .59573 .78073 L .56493 .78302 L p .707 .577 .707 r
F P
0 g
s
.59573 .78073 m .60177 .81655 L .6332 .81085 L p .707 .577 .707 r
F P
0 g
s
.6332 .81085 m .62716 .77503 L .59573 .78073 L p .707 .577 .707 r
F P
0 g
s
.66684 .67226 m .68506 .72238 L .70011 .70663 L p .707 .577 .707 r
F P
0 g
s
.70011 .70663 m .68189 .65651 L .66684 .67226 L p .707 .577 .707 r
F P
0 g
s
.62716 .77503 m .6332 .81085 L .66219 .80228 L p .707 .577 .707 r
F P
0 g
s
.66219 .80228 m .65615 .76647 L .62716 .77503 L p .707 .577 .707 r
F P
0 g
s
.54878 .77024 m .53056 .72012 L .51016 .71682 L p .707 .577 .707 r
F P
0 g
s
.53056 .72012 m .54878 .77024 L .57511 .76859 L p .707 .577 .707 r
F P
0 g
s
.57511 .84148 m .57947 .82305 L .54947 .81465 L p .707 .577 .707 r
F P
0 g
s
.57947 .82305 m .57511 .84148 L .60622 .84835 L p .707 .577 .707 r
F P
0 g
s
.60622 .84835 m .61058 .82992 L .57947 .82305 L p .707 .577 .707 r
F P
0 g
s
.57097 .81884 m .56493 .78302 L .53777 .78166 L p .707 .577 .707 r
F P
0 g
s
.56493 .78302 m .57097 .81884 L .60177 .81655 L p .707 .577 .707 r
F P
0 g
s
.61058 .82992 m .60622 .84835 L .6354 .85303 L p .707 .577 .707 r
F P
0 g
s
.6354 .85303 m .63976 .8346 L .61058 .82992 L p .707 .577 .707 r
F P
0 g
s
.54947 .81465 m .54512 .83308 L .57511 .84148 L p .707 .577 .707 r
F P
0 g
s
.65615 .76647 m .66219 .80228 L .6859 .7917 L p .707 .577 .707 r
F P
0 g
s
.6859 .7917 m .67986 .75588 L .65615 .76647 L p .707 .577 .707 r
F P
0 g
s
.54512 .83308 m .54947 .81465 L .52353 .80556 L p .707 .577 .707 r
F P
0 g
s
.52353 .80556 m .51918 .82399 L .54512 .83308 L p .707 .577 .707 r
F P
0 g
s
.53777 .78166 m .54381 .81748 L .57097 .81884 L p .707 .577 .707 r
F P
0 g
s
.63976 .8346 m .6354 .85303 L .6598 .85505 L p .707 .577 .707 r
F P
0 g
s
.6598 .85505 m .66415 .83662 L .63976 .8346 L p .707 .577 .707 r
F P
0 g
s
.68189 .65651 m .70011 .70663 L .70629 .69217 L p .707 .577 .707 r
F P
0 g
s
.70629 .69217 m .68806 .64204 L .68189 .65651 L p .707 .577 .707 r
F P
0 g
s
.54381 .81748 m .53777 .78166 L .51692 .77679 L p .707 .577 .707 r
F P
0 g
s
.51016 .71682 m .52838 .76694 L .54878 .77024 L p .707 .577 .707 r
F P
0 g
s
.52838 .76694 m .51016 .71682 L .4977 .70889 L p .707 .577 .707 r
F P
0 g
s
.67986 .75588 m .6859 .7917 L .702 .78012 L p .707 .577 .707 r
F P
0 g
s
.702 .78012 m .69596 .7443 L .67986 .75588 L p .707 .577 .707 r
F P
0 g
s
.51918 .82399 m .52353 .80556 L .50419 .79665 L p .707 .577 .707 r
F P
0 g
s
.50419 .79665 m .49983 .81508 L .51918 .82399 L p .707 .577 .707 r
F P
0 g
s
.51692 .77679 m .52297 .81261 L .54381 .81748 L p .707 .577 .707 r
F P
0 g
s
.66415 .83662 m .6598 .85505 L .67702 .85422 L p .707 .577 .707 r
F P
0 g
s
.67702 .85422 m .68138 .83579 L .66415 .83662 L p .707 .577 .707 r
F P
0 g
s
.52297 .81261 m .51692 .77679 L .50442 .76889 L p .707 .577 .707 r
F P
0 g
s
.4977 .70889 m .51592 .75902 L .52838 .76694 L p .707 .577 .707 r
F P
0 g
s
.68806 .64204 m .70629 .69217 L .70298 .68039 L p .707 .577 .707 r
F P
0 g
s
.70298 .68039 m .68476 .63027 L .68806 .64204 L p .707 .577 .707 r
F P
0 g
s
.49983 .81508 m .50419 .79665 L .49333 .7888 L p .707 .577 .707 r
F P
0 g
s
.69596 .7443 m .702 .78012 L .70893 .7687 L p .707 .577 .707 r
F P
0 g
s
.70893 .7687 m .70289 .73288 L .69596 .7443 L p .707 .577 .707 r
F P
0 g
s
.51592 .75902 m .4977 .70889 L .4944 .69712 L p .707 .577 .707 r
F P
0 g
s
.49333 .7888 m .48897 .80723 L .49983 .81508 L p .707 .577 .707 r
F P
0 g
s
.50442 .76889 m .51047 .8047 L .52297 .81261 L p .707 .577 .707 r
F P
0 g
s
.68138 .83579 m .67702 .85422 L .68539 .85063 L p .707 .577 .707 r
F P
0 g
s
.68539 .85063 m .68974 .83219 L .68138 .83579 L p .707 .577 .707 r
F P
0 g
s
.51047 .8047 m .50442 .76889 L .50149 .75872 L p .707 .577 .707 r
F P
0 g
s
.4944 .69712 m .51262 .74725 L .51592 .75902 L p .707 .577 .707 r
F P
0 g
s
.51262 .74725 m .4944 .69712 L .50057 .68265 L p .707 .577 .707 r
F P
0 g
s
.50149 .75872 m .50754 .79454 L .51047 .8047 L p .707 .577 .707 r
F P
0 g
s
.50754 .79454 m .50149 .75872 L .50842 .7473 L p .707 .577 .707 r
F P
0 g
s
.50057 .68265 m .51879 .73278 L .51262 .74725 L p .707 .577 .707 r
F P
0 g
s
.51879 .73278 m .50057 .68265 L .51562 .66691 L p .707 .577 .707 r
F P
0 g
s
.50842 .7473 m .51446 .78311 L .50754 .79454 L p .707 .577 .707 r
F P
0 g
s
.51446 .78311 m .50842 .7473 L .52452 .73572 L p .707 .577 .707 r
F P
0 g
s
.52452 .73572 m .53057 .77154 L .51446 .78311 L p .707 .577 .707 r
F P
0 g
s
.49603 .79762 m .50038 .77919 L .5176 .77836 L p .707 .577 .707 r
F P
0 g
s
.5176 .77836 m .51325 .79679 L .49603 .79762 L p .707 .577 .707 r
F P
0 g
s
.50621 .82189 m .50621 .32 L .46137 .31862 L p .707 .577 .707 r
F P
0 g
s
.51562 .66691 m .53384 .71703 L .51879 .73278 L p .707 .577 .707 r
F P
0 g
s
.53384 .71703 m .51562 .66691 L .53807 .65142 L p .707 .577 .707 r
F P
0 g
s
.53807 .65142 m .55629 .70154 L .53384 .71703 L p .707 .577 .707 r
F P
0 g
s
.53057 .77154 m .52452 .73572 L .54823 .72513 L p .707 .577 .707 r
F P
0 g
s
.51325 .79679 m .5176 .77836 L .542 .78038 L p .707 .577 .707 r
F P
0 g
s
.54823 .72513 m .55427 .76095 L .53057 .77154 L p .707 .577 .707 r
F P
0 g
s
.542 .78038 m .53765 .79882 L .51325 .79679 L p .707 .577 .707 r
F P
0 g
s
.53765 .79882 m .542 .78038 L .57118 .78506 L p .707 .577 .707 r
F P
0 g
s
.57118 .78506 m .56683 .80349 L .53765 .79882 L p .707 .577 .707 r
F P
0 g
s
.50621 .32 m .50621 .82189 L .55044 .81948 L p .707 .577 .707 r
F P
0 g
s
.55629 .70154 m .53807 .65142 L .56572 .63771 L p .707 .577 .707 r
F P
0 g
s
.55427 .76095 m .54823 .72513 L .57722 .71657 L p .707 .577 .707 r
F P
0 g
s
.55044 .81948 m .55044 .31759 L .50621 .32 L p .707 .577 .707 r
F P
0 g
s
.68476 .63027 m .70298 .68039 L .69052 .67247 L p .707 .577 .707 r
F P
0 g
s
.69052 .67247 m .6723 .62235 L .68476 .63027 L p .707 .577 .707 r
F P
0 g
s
.46137 .82051 m .46137 .31862 L .42032 .31359 L p .707 .577 .707 r
F P
0 g
s
.48897 .80723 m .49333 .7888 L .49201 .78279 L p .707 .577 .707 r
F P
0 g
s
.49201 .78279 m .48766 .80122 L .48897 .80723 L p .707 .577 .707 r
F P
0 g
s
.48766 .80122 m .49201 .78279 L .50038 .77919 L p .707 .577 .707 r
F P
0 g
s
.50038 .77919 m .49603 .79762 L .48766 .80122 L p .707 .577 .707 r
F P
0 g
s
.46137 .31862 m .46137 .82051 L .50621 .82189 L p .707 .577 .707 r
F P
0 g
s
.70289 .73288 m .70893 .7687 L .706 .75853 L p .707 .577 .707 r
F P
0 g
s
.706 .75853 m .69996 .72271 L .70289 .73288 L p .707 .577 .707 r
F P
0 g
s
.58395 .68784 m .56572 .63771 L .59588 .62713 L p .707 .577 .707 r
F P
0 g
s
.56572 .63771 m .58395 .68784 L .55629 .70154 L p .707 .577 .707 r
F P
0 g
s
.58326 .75239 m .57722 .71657 L .60865 .71087 L p .707 .577 .707 r
F P
0 g
s
.57722 .71657 m .58326 .75239 L .55427 .76095 L p .707 .577 .707 r
F P
0 g
s
.60865 .71087 m .6147 .74669 L .58326 .75239 L p .707 .577 .707 r
F P
0 g
s
.56683 .80349 m .57118 .78506 L .60229 .79193 L p .707 .577 .707 r
F P
0 g
s
.60229 .79193 m .59794 .81037 L .56683 .80349 L p .707 .577 .707 r
F P
0 g
s
.55044 .31759 m .55044 .81948 L .58973 .81352 L p .707 .577 .707 r
F P
0 g
s
.59588 .62713 m .6141 .67725 L .58395 .68784 L p .707 .577 .707 r
F P
0 g
s
.58973 .81352 m .58973 .31163 L .55044 .31759 L p .707 .577 .707 r
F P
0 g
s
.42032 .81548 m .42032 .31359 L .38706 .30541 L p .707 .577 .707 r
F P
0 g
s
.42032 .31359 m .42032 .81548 L .46137 .82051 L p .707 .577 .707 r
F P
0 g
s
.68974 .83219 m .68539 .85063 L .68408 .84461 L p .707 .577 .707 r
F P
0 g
s
.68408 .84461 m .68843 .82618 L .68974 .83219 L p .707 .577 .707 r
F P
0 g
s
.6141 .67725 m .59588 .62713 L .62557 .62069 L p .707 .577 .707 r
F P
0 g
s
.63946 .70858 m .6455 .7444 L .6147 .74669 L p .707 .577 .707 r
F P
0 g
s
.6147 .74669 m .60865 .71087 L .63946 .70858 L p .707 .577 .707 r
F P
0 g
s
.63229 .80033 m .62793 .81876 L .59794 .81037 L p .707 .577 .707 r
F P
0 g
s
.59794 .81037 m .60229 .79193 L .63229 .80033 L p .707 .577 .707 r
F P
0 g
s
.58973 .31163 m .58973 .81352 L .62024 .8046 L p .707 .577 .707 r
F P
0 g
s
.62557 .62069 m .64379 .67082 L .6141 .67725 L p .707 .577 .707 r
F P
0 g
s
.62024 .8046 m .62024 .30271 L .58973 .31163 L p .707 .577 .707 r
F P
0 g
s
.6723 .62235 m .69052 .67247 L .67013 .66917 L p .707 .577 .707 r
F P
0 g
s
.67013 .66917 m .65191 .61905 L .6723 .62235 L p .707 .577 .707 r
F P
0 g
s
.2204 .62931 m .22851 .68639 L .25959 .68174 L p .707 .577 .707 r
F P
0 g
s
.25959 .68174 m .25149 .62466 L .2204 .62931 L p .707 .577 .707 r
F P
0 g
s
.25149 .62466 m .25959 .68174 L .291 .67745 L p .707 .577 .707 r
F P
0 g
s
.69996 .72271 m .706 .75853 L .6935 .75063 L p .707 .577 .707 r
F P
0 g
s
.6935 .75063 m .68746 .71481 L .69996 .72271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.291 .67745 m .28289 .62037 L .25149 .62466 L p .707 .577 .707 r
F P
0 g
s
.28289 .62037 m .291 .67745 L .31964 .67393 L p .707 .577 .707 r
F P
0 g
s
.19268 .63386 m .20078 .69094 L .22851 .68639 L p .707 .577 .707 r
F P
0 g
s
.22851 .68639 m .2204 .62931 L .19268 .63386 L p .707 .577 .707 r
F P
0 g
s
.31964 .67393 m .31154 .61685 L .28289 .62037 L p .707 .577 .707 r
F P
0 g
s
.25607 .75893 m .25346 .7208 L .22231 .72212 L p .707 .577 .707 r
F P
0 g
s
.25346 .7208 m .25607 .75893 L .28781 .75643 L p .707 .577 .707 r
F P
0 g
s
.28781 .75643 m .2852 .7183 L .25346 .7208 L p .707 .577 .707 r
F P
0 g
s
.38706 .8073 m .38706 .30541 L .36486 .29486 L p .707 .577 .707 r
F P
0 g
s
.38706 .30541 m .38706 .8073 L .42032 .81548 L p .707 .577 .707 r
F P
0 g
s
.2852 .7183 m .28781 .75643 L .31705 .75299 L p .707 .577 .707 r
F P
0 g
s
.31705 .75299 m .31443 .71486 L .2852 .7183 L p .707 .577 .707 r
F P
0 g
s
.31154 .61685 m .31964 .67393 L .34273 .67154 L p .707 .577 .707 r
F P
0 g
s
.68843 .82618 m .68408 .84461 L .67322 .83676 L p .707 .577 .707 r
F P
0 g
s
.67322 .83676 m .67757 .81833 L .68843 .82618 L p .707 .577 .707 r
F P
0 g
s
.22231 .72212 m .22492 .76025 L .25607 .75893 L p .707 .577 .707 r
F P
0 g
s
.34273 .67154 m .33463 .61446 L .31154 .61685 L p .707 .577 .707 r
F P
0 g
s
.17103 .63787 m .17914 .69495 L .20078 .69094 L p .707 .577 .707 r
F P
0 g
s
.20078 .69094 m .19268 .63386 L .17103 .63787 L p .707 .577 .707 r
F P
0 g
s
.65191 .61905 m .67013 .66917 L .64379 .67082 L p .707 .577 .707 r
F P
0 g
s
.64379 .67082 m .62557 .62069 L .65191 .61905 L p .707 .577 .707 r
F P
0 g
s
.22492 .76025 m .22231 .72212 L .19482 .72213 L p .707 .577 .707 r
F P
0 g
s
.19482 .72213 m .19743 .76025 L .22492 .76025 L p .707 .577 .707 r
F P
0 g
s
.62024 .30271 m .62024 .8046 L .63898 .79358 L p .707 .577 .707 r
F P
0 g
s
.63898 .79358 m .63898 .29169 L .62024 .30271 L p .707 .577 .707 r
F P
0 g
s
.68746 .71481 m .6935 .75063 L .67265 .74576 L p .707 .577 .707 r
F P
0 g
s
.67265 .74576 m .66661 .70994 L .68746 .71481 L p .707 .577 .707 r
F P
0 g
s
.31443 .71486 m .31705 .75299 L .34091 .74895 L p .707 .577 .707 r
F P
0 g
s
.34091 .74895 m .3383 .71082 L .31443 .71486 L p .707 .577 .707 r
F P
0 g
s
.19743 .76025 m .19482 .72213 L .17366 .72082 L p .707 .577 .707 r
F P
0 g
s
.33463 .61446 m .34273 .67154 L .358 .6705 L p .707 .577 .707 r
F P
0 g
s
.358 .6705 m .3499 .61342 L .33463 .61446 L p .707 .577 .707 r
F P
0 g
s
.17366 .72082 m .17627 .75894 L .19743 .76025 L p .707 .577 .707 r
F P
0 g
s
.15758 .64094 m .16568 .69802 L .17914 .69495 L p .707 .577 .707 r
F P
0 g
s
.17914 .69495 m .17103 .63787 L .15758 .64094 L p .707 .577 .707 r
F P
0 g
s
.67757 .81833 m .67322 .83676 L .65387 .82786 L p .707 .577 .707 r
F P
0 g
s
.65387 .82786 m .65822 .80943 L .67757 .81833 L p .707 .577 .707 r
F P
0 g
s
.3383 .71082 m .34091 .74895 L .35707 .7447 L p .707 .577 .707 r
F P
0 g
s
.35707 .7447 m .35446 .70658 L .3383 .71082 L p .707 .577 .707 r
F P
0 g
s
.66661 .70994 m .67265 .74576 L .6455 .7444 L p .707 .577 .707 r
F P
0 g
s
.6455 .7444 m .63946 .70858 L .66661 .70994 L p .707 .577 .707 r
F P
0 g
s
.2422 .83147 m .24406 .81476 L .21333 .80811 L p .707 .577 .707 r
F P
0 g
s
.24406 .81476 m .2422 .83147 L .27397 .83336 L p .707 .577 .707 r
F P
0 g
s
.27397 .83336 m .27584 .81665 L .24406 .81476 L p .707 .577 .707 r
F P
0 g
s
.3499 .61342 m .358 .6705 L .36396 .67092 L p .707 .577 .707 r
F P
0 g
s
.36396 .67092 m .35585 .61384 L .3499 .61342 L p .707 .577 .707 r
F P
0 g
s
.35446 .70658 m .35707 .7447 L .36394 .74066 L p .707 .577 .707 r
F P
0 g
s
.36394 .74066 m .36133 .70254 L .35446 .70658 L p .707 .577 .707 r
F P
0 g
s
.35585 .61384 m .36396 .67092 L .36001 .67276 L p .707 .577 .707 r
F P
0 g
s
.36133 .70254 m .36394 .74066 L .36085 .73723 L p .707 .577 .707 r
F P
0 g
s
.36486 .79675 m .36486 .29486 L .35589 .283 L p .707 .577 .707 r
F P
0 g
s
.36486 .29486 m .36486 .79675 L .38706 .8073 L p .707 .577 .707 r
F P
0 g
s
.27584 .81665 m .27397 .83336 L .30368 .8303 L p .707 .577 .707 r
F P
0 g
s
.30368 .8303 m .30554 .81359 L .27584 .81665 L p .707 .577 .707 r
F P
0 g
s
.21147 .82482 m .21333 .80811 L .18666 .79734 L p .707 .577 .707 r
F P
0 g
s
.21333 .80811 m .21147 .82482 L .2422 .83147 L p .707 .577 .707 r
F P
0 g
s
.17627 .75894 m .17366 .72082 L .16091 .71833 L p .707 .577 .707 r
F P
0 g
s
.63898 .29169 m .63898 .79358 L .64411 .78155 L p .707 .577 .707 r
F P
0 g
s
.64411 .78155 m .64411 .27966 L .63898 .29169 L p .707 .577 .707 r
F P
0 g
s
.16091 .71833 m .16352 .75645 L .17627 .75894 L p .707 .577 .707 r
F P
0 g
s
.30554 .81359 m .30368 .8303 L .32842 .82259 L p .707 .577 .707 r
F P
0 g
s
.32842 .82259 m .33028 .80588 L .30554 .81359 L p .707 .577 .707 r
F P
0 g
s
.18666 .79734 m .18479 .81405 L .21147 .82482 L p .707 .577 .707 r
F P
0 g
s
.65822 .80943 m .65387 .82786 L .62793 .81876 L p .707 .577 .707 r
F P
0 g
s
.62793 .81876 m .63229 .80033 L .65822 .80943 L p .707 .577 .707 r
F P
0 g
s
.15363 .64277 m .16174 .69985 L .16568 .69802 L p .707 .577 .707 r
F P
0 g
s
.16568 .69802 m .15758 .64094 L .15363 .64277 L p .707 .577 .707 r
F P
0 g
s
.18479 .81405 m .18666 .79734 L .16665 .78352 L p .707 .577 .707 r
F P
0 g
s
.16665 .78352 m .16478 .80023 L .18479 .81405 L p .707 .577 .707 r
F P
0 g
s
.33028 .80588 m .32842 .82259 L .34576 .81099 L p .707 .577 .707 r
F P
0 g
s
.34576 .81099 m .34762 .79428 L .33028 .80588 L p .707 .577 .707 r
F P
0 g
s
.16352 .75645 m .16091 .71833 L .15782 .7149 L p .707 .577 .707 r
F P
0 g
s
.16478 .80023 m .16665 .78352 L .15526 .76799 L p .707 .577 .707 r
F P
0 g
s
.15782 .7149 m .16043 .75302 L .16352 .75645 L p .707 .577 .707 r
F P
0 g
s
.36001 .67276 m .35191 .61568 L .35585 .61384 L p .707 .577 .707 r
F P
0 g
s
.36085 .73723 m .35824 .69911 L .36133 .70254 L p .707 .577 .707 r
F P
0 g
s
.35191 .61568 m .36001 .67276 L .34656 .67583 L p .707 .577 .707 r
F P
0 g
s
.35824 .69911 m .36085 .73723 L .34811 .73474 L p .707 .577 .707 r
F P
0 g
s
.34811 .73474 m .34549 .69661 L .35824 .69911 L p .707 .577 .707 r
F P
0 g
s
.35589 .283 m .35589 .78489 L .36486 .79675 L p .707 .577 .707 r
F P
0 g
s
.35589 .78489 m .35589 .283 L .36102 .27097 L p .707 .577 .707 r
F P
0 g
s
.15526 .76799 m .15339 .7847 L .16478 .80023 L p .707 .577 .707 r
F P
0 g
s
.15959 .64319 m .16769 .70027 L .16174 .69985 L p .707 .577 .707 r
F P
0 g
s
.16174 .69985 m .15363 .64277 L .15959 .64319 L p .707 .577 .707 r
F P
0 g
s
.64411 .27966 m .64411 .78155 L .63514 .76968 L p .707 .577 .707 r
F P
0 g
s
.63514 .76968 m .63514 .26779 L .64411 .27966 L p .707 .577 .707 r
F P
0 g
s
.34762 .79428 m .34576 .81099 L .35401 .79662 L p .707 .577 .707 r
F P
0 g
s
.35401 .79662 m .35587 .77992 L .34762 .79428 L p .707 .577 .707 r
F P
0 g
s
.15339 .7847 m .15526 .76799 L .15361 .75227 L p .707 .577 .707 r
F P
0 g
s
.16043 .75302 m .15782 .7149 L .16469 .71086 L p .707 .577 .707 r
F P
0 g
s
.16469 .71086 m .16731 .74898 L .16043 .75302 L p .707 .577 .707 r
F P
0 g
s
.15361 .75227 m .15174 .76898 L .15339 .7847 L p .707 .577 .707 r
F P
0 g
s
.34656 .67583 m .33845 .61875 L .35191 .61568 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17486 .64215 m .18296 .69923 L .16769 .70027 L p .707 .577 .707 r
F P
0 g
s
.16769 .70027 m .15959 .64319 L .17486 .64215 L p .707 .577 .707 r
F P
0 g
s
.35587 .77992 m .35401 .79662 L .35236 .78091 L p .707 .577 .707 r
F P
0 g
s
.35236 .78091 m .35422 .7642 L .35587 .77992 L p .707 .577 .707 r
F P
0 g
s
.36102 .77285 m .36102 .27097 L .37976 .25995 L p .707 .577 .707 r
F P
0 g
s
.36102 .27097 m .36102 .77285 L .35589 .78489 L p .707 .577 .707 r
F P
0 g
s
.15174 .76898 m .15361 .75227 L .16186 .73791 L p .707 .577 .707 r
F P
0 g
s
.63514 .26779 m .63514 .76968 L .61294 .75914 L p .707 .577 .707 r
F P
0 g
s
.61294 .75914 m .61294 .25725 L .63514 .26779 L p .707 .577 .707 r
F P
0 g
s
.16731 .74898 m .16469 .71086 L .18085 .70661 L p .707 .577 .707 r
F P
0 g
s
.16186 .73791 m .15999 .75462 L .15174 .76898 L p .707 .577 .707 r
F P
0 g
s
.18085 .70661 m .18347 .74474 L .16731 .74898 L p .707 .577 .707 r
F P
0 g
s
.33845 .61875 m .34656 .67583 L .32491 .67984 L p .707 .577 .707 r
F P
0 g
s
.32491 .67984 m .31681 .62276 L .33845 .61875 L p .707 .577 .707 r
F P
0 g
s
.19795 .63976 m .20605 .69684 L .18296 .69923 L p .707 .577 .707 r
F P
0 g
s
.18296 .69923 m .17486 .64215 L .19795 .63976 L p .707 .577 .707 r
F P
0 g
s
.35422 .7642 m .35236 .78091 L .34097 .76538 L p .707 .577 .707 r
F P
0 g
s
.34097 .76538 m .34283 .74867 L .35422 .7642 L p .707 .577 .707 r
F P
0 g
s
.34549 .69661 m .34811 .73474 L .32695 .73343 L p .707 .577 .707 r
F P
0 g
s
.32695 .73343 m .32434 .69531 L .34549 .69661 L p .707 .577 .707 r
F P
0 g
s
.15999 .75462 m .16186 .73791 L .1792 .7263 L p .707 .577 .707 r
F P
0 g
s
.37976 .25995 m .37976 .76184 L .36102 .77285 L p .707 .577 .707 r
F P
0 g
s
.37976 .76184 m .37976 .25995 L .41027 .25102 L p .707 .577 .707 r
F P
0 g
s
.18347 .74474 m .18085 .70661 L .20472 .70257 L p .707 .577 .707 r
F P
0 g
s
.31681 .62276 m .32491 .67984 L .29719 .68439 L p .707 .577 .707 r
F P
0 g
s
.1792 .7263 m .17733 .74301 L .15999 .75462 L p .707 .577 .707 r
F P
0 g
s
.20472 .70257 m .20733 .74069 L .18347 .74474 L p .707 .577 .707 r
F P
0 g
s
.29719 .68439 m .28908 .62731 L .31681 .62276 L p .707 .577 .707 r
F P
0 g
s
.22659 .63625 m .2347 .69333 L .20605 .69684 L p .707 .577 .707 r
F P
0 g
s
.20605 .69684 m .19795 .63976 L .22659 .63625 L p .707 .577 .707 r
F P
0 g
s
.61294 .25725 m .61294 .75914 L .57968 .75095 L p .707 .577 .707 r
F P
0 g
s
.57968 .75095 m .57968 .24907 L .61294 .25725 L p .707 .577 .707 r
F P
0 g
s
.34283 .74867 m .34097 .76538 L .32096 .75155 L p .707 .577 .707 r
F P
0 g
s
.32096 .75155 m .32282 .73484 L .34283 .74867 L p .707 .577 .707 r
F P
0 g
s
.32434 .69531 m .32695 .73343 L .29945 .73344 L p .707 .577 .707 r
F P
0 g
s
.29945 .73344 m .29684 .69531 L .32434 .69531 L p .707 .577 .707 r
F P
0 g
s
.73389 .68272 m .742 .63504 L .71091 .62805 L p .707 .577 .707 r
F P
0 g
s
.742 .63504 m .73389 .68272 L .7653 .68424 L p .707 .577 .707 r
F P
0 g
s
.7653 .68424 m .7734 .63657 L .742 .63504 L p .707 .577 .707 r
F P
0 g
s
.70281 .67572 m .71091 .62805 L .68319 .61627 L p .707 .577 .707 r
F P
0 g
s
.71091 .62805 m .70281 .67572 L .73389 .68272 L p .707 .577 .707 r
F P
0 g
s
.28908 .62731 m .29719 .68439 L .2661 .68903 L p .707 .577 .707 r
F P
0 g
s
.17733 .74301 m .1792 .7263 L .20393 .71859 L p .707 .577 .707 r
F P
0 g
s
.258 .63196 m .2661 .68903 L .2347 .69333 L p .707 .577 .707 r
F P
0 g
s
.2347 .69333 m .22659 .63625 L .258 .63196 L p .707 .577 .707 r
F P
0 g
s
.2661 .68903 m .258 .63196 L .28908 .62731 L p .707 .577 .707 r
F P
0 g
s
.7734 .63657 m .7653 .68424 L .79395 .68015 L p .707 .577 .707 r
F P
0 g
s
.79395 .68015 m .80205 .63247 L .7734 .63657 L p .707 .577 .707 r
F P
0 g
s
.20733 .74069 m .20472 .70257 L .23395 .69913 L p .707 .577 .707 r
F P
0 g
s
.23395 .69913 m .23657 .73726 L .20733 .74069 L p .707 .577 .707 r
F P
0 g
s
.67509 .66394 m .68319 .61627 L .66154 .60086 L p .707 .577 .707 r
F P
0 g
s
.68319 .61627 m .67509 .66394 L .70281 .67572 L p .707 .577 .707 r
F P
0 g
s
.20393 .71859 m .20207 .7353 L .17733 .74301 L p .707 .577 .707 r
F P
0 g
s
.29684 .69531 m .29945 .73344 L .26831 .73475 L p .707 .577 .707 r
F P
0 g
s
.26831 .73475 m .2657 .69663 L .29684 .69531 L p .707 .577 .707 r
F P
0 g
s
.41027 .75291 m .41027 .25102 L .44956 .24507 L p .707 .577 .707 r
F P
0 g
s
.41027 .25102 m .41027 .75291 L .37976 .76184 L p .707 .577 .707 r
F P
0 g
s
.32282 .73484 m .32096 .75155 L .29428 .74079 L p .707 .577 .707 r
F P
0 g
s
.29428 .74079 m .29614 .72408 L .32282 .73484 L p .707 .577 .707 r
F P
0 g
s
.23657 .73726 m .23395 .69913 L .2657 .69663 L p .707 .577 .707 r
F P
0 g
s
.80205 .63247 m .79395 .68015 L .81704 .67083 L p .707 .577 .707 r
F P
0 g
s
.81704 .67083 m .82514 .62316 L .80205 .63247 L p .707 .577 .707 r
F P
0 g
s
.2657 .69663 m .26831 .73475 L .23657 .73726 L p .707 .577 .707 r
F P
0 g
s
.73645 .74086 m .73458 .72173 L .70385 .72444 L p .707 .577 .707 r
F P
0 g
s
.73458 .72173 m .73645 .74086 L .76822 .73772 L p .707 .577 .707 r
F P
0 g
s
.76822 .73772 m .76636 .71859 L .73458 .72173 L p .707 .577 .707 r
F P
0 g
s
.70385 .72444 m .70572 .74357 L .73645 .74086 L p .707 .577 .707 r
F P
0 g
s
.20207 .7353 m .20393 .71859 L .23364 .71553 L p .707 .577 .707 r
F P
0 g
s
.57968 .24907 m .57968 .75095 L .53862 .74593 L p .707 .577 .707 r
F P
0 g
s
.53862 .74593 m .53862 .24404 L .57968 .24907 L p .707 .577 .707 r
F P
0 g
s
.76636 .71859 m .76822 .73772 L .79793 .73445 L p .707 .577 .707 r
F P
0 g
s
.79793 .73445 m .79607 .71531 L .76636 .71859 L p .707 .577 .707 r
F P
0 g
s
.73169 .73078 m .7343 .69587 L .70316 .69108 L p .707 .577 .707 r
F P
0 g
s
.7343 .69587 m .73169 .73078 L .76343 .73146 L p .707 .577 .707 r
F P
0 g
s
.76343 .73146 m .76604 .69655 L .7343 .69587 L p .707 .577 .707 r
F P
0 g
s
.76604 .69655 m .76343 .73146 L .79267 .72796 L p .707 .577 .707 r
F P
0 g
s
.79267 .72796 m .79528 .69305 L .76604 .69655 L p .707 .577 .707 r
F P
0 g
s
.70572 .74357 m .70385 .72444 L .67718 .72645 L p .707 .577 .707 r
F P
0 g
s
.70054 .72599 m .70316 .69108 L .67566 .68265 L p .707 .577 .707 r
F P
0 g
s
.70316 .69108 m .70054 .72599 L .73169 .73078 L p .707 .577 .707 r
F P
0 g
s
.67718 .72645 m .67904 .74558 L .70572 .74357 L p .707 .577 .707 r
F P
0 g
s
.65344 .64853 m .66154 .60086 L .64809 .58332 L p .707 .577 .707 r
F P
0 g
s
.66154 .60086 m .65344 .64853 L .67509 .66394 L p .707 .577 .707 r
F P
0 g
s
.29614 .72408 m .29428 .74079 L .26355 .73413 L p .707 .577 .707 r
F P
0 g
s
.26355 .73413 m .26541 .71742 L .29614 .72408 L p .707 .577 .707 r
F P
0 g
s
.23364 .71553 m .23178 .73224 L .20207 .7353 L p .707 .577 .707 r
F P
0 g
s
.23178 .73224 m .23364 .71553 L .26541 .71742 L p .707 .577 .707 r
F P
0 g
s
.79607 .71531 m .79793 .73445 L .82266 .73137 L p .707 .577 .707 r
F P
0 g
s
.82266 .73137 m .8208 .71223 L .79607 .71531 L p .707 .577 .707 r
F P
0 g
s
.26541 .71742 m .26355 .73413 L .23178 .73224 L p .707 .577 .707 r
F P
0 g
s
.44956 .74696 m .44956 .24507 L .49379 .24266 L p .707 .577 .707 r
F P
0 g
s
.44956 .24507 m .44956 .74696 L .41027 .75291 L p .707 .577 .707 r
F P
0 g
s
.82514 .62316 m .81704 .67083 L .8323 .65721 L p .707 .577 .707 r
F P
0 g
s
.8323 .65721 m .84041 .60954 L .82514 .62316 L p .707 .577 .707 r
F P
0 g
s
.79528 .69305 m .79267 .72796 L .81653 .72062 L p .707 .577 .707 r
F P
0 g
s
.81653 .72062 m .81914 .68571 L .79528 .69305 L p .707 .577 .707 r
F P
0 g
s
.53862 .24404 m .53862 .74593 L .49379 .74455 L p .707 .577 .707 r
F P
0 g
s
.49379 .74455 m .49379 .24266 L .53862 .24404 L p .707 .577 .707 r
F P
0 g
s
.67305 .71755 m .67566 .68265 L .6545 .6714 L p .707 .577 .707 r
F P
0 g
s
.67566 .68265 m .67305 .71755 L .70054 .72599 L p .707 .577 .707 r
F P
0 g
s
.49379 .24266 m .49379 .74455 L .44956 .74696 L p .707 .577 .707 r
F P
0 g
s
.67904 .74558 m .67718 .72645 L .65717 .72756 L p .707 .577 .707 r
F P
0 g
s
.65717 .72756 m .65903 .74669 L .67904 .74558 L p .707 .577 .707 r
F P
0 g
s
.63998 .63099 m .64809 .58332 L .64415 .56538 L p .707 .577 .707 r
F P
0 g
s
.64809 .58332 m .63998 .63099 L .65344 .64853 L p .707 .577 .707 r
F P
0 g
s
.8208 .71223 m .82266 .73137 L .84 .72878 L p .707 .577 .707 r
F P
0 g
s
.84 .72878 m .83814 .70965 L .8208 .71223 L p .707 .577 .707 r
F P
0 g
s
.6545 .6714 m .65189 .7063 L .67305 .71755 L p .707 .577 .707 r
F P
0 g
s
.81914 .68571 m .81653 .72062 L .83269 .71017 L p .707 .577 .707 r
F P
0 g
s
.83269 .71017 m .8353 .67526 L .81914 .68571 L p .707 .577 .707 r
F P
0 g
s
.84041 .60954 m .8323 .65721 L .83826 .64062 L p .707 .577 .707 r
F P
0 g
s
.83826 .64062 m .84636 .59294 L .84041 .60954 L p .707 .577 .707 r
F P
0 g
s
.65189 .7063 m .6545 .6714 L .64176 .65843 L p .707 .577 .707 r
F P
0 g
s
.65903 .74669 m .65717 .72756 L .64578 .72766 L p .707 .577 .707 r
F P
0 g
s
.64578 .72766 m .64764 .7468 L .65903 .74669 L p .707 .577 .707 r
F P
0 g
s
.64415 .56538 m .63604 .61305 L .63998 .63099 L p .707 .577 .707 r
F P
0 g
s
.63604 .61305 m .64415 .56538 L .6501 .54878 L p .707 .577 .707 r
F P
0 g
s
.64176 .65843 m .63914 .69333 L .65189 .7063 L p .707 .577 .707 r
F P
0 g
s
.83814 .70965 m .84 .72878 L .84825 .72694 L p .707 .577 .707 r
F P
0 g
s
.84825 .72694 m .84639 .70781 L .83814 .70965 L p .707 .577 .707 r
F P
0 g
s
.8353 .67526 m .83269 .71017 L .83956 .69762 L p .707 .577 .707 r
F P
0 g
s
.83956 .69762 m .84218 .66271 L .8353 .67526 L p .707 .577 .707 r
F P
0 g
s
.84636 .59294 m .83826 .64062 L .83432 .62267 L p .707 .577 .707 r
F P
0 g
s
.83432 .62267 m .84242 .575 L .84636 .59294 L p .707 .577 .707 r
F P
0 g
s
.63914 .69333 m .64176 .65843 L .63867 .64502 L p .707 .577 .707 r
F P
0 g
s
.64764 .7468 m .64578 .72766 L .64413 .72675 L p .707 .577 .707 r
F P
0 g
s
.64413 .72675 m .64599 .74588 L .64764 .7468 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.642 .59646 m .6501 .54878 L .66537 .53516 L p .707 .577 .707 r
F P
0 g
s
.6501 .54878 m .642 .59646 L .63604 .61305 L p .707 .577 .707 r
F P
0 g
s
.63867 .64502 m .63606 .67992 L .63914 .69333 L p .707 .577 .707 r
F P
0 g
s
.84639 .70781 m .84825 .72694 L .8466 .72603 L p .707 .577 .707 r
F P
0 g
s
.8466 .72603 m .84474 .7069 L .84639 .70781 L p .707 .577 .707 r
F P
0 g
s
.84218 .66271 m .83956 .69762 L .83648 .6842 L p .707 .577 .707 r
F P
0 g
s
.83648 .6842 m .83909 .6493 L .84218 .66271 L p .707 .577 .707 r
F P
0 g
s
.84242 .575 m .83432 .62267 L .82086 .60514 L p .707 .577 .707 r
F P
0 g
s
.82086 .60514 m .82897 .55746 L .84242 .575 L p .707 .577 .707 r
F P
0 g
s
.63606 .67992 m .63867 .64502 L .64554 .63247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.66537 .53516 m .65727 .58284 L .642 .59646 L p .707 .577 .707 r
F P
0 g
s
.65727 .58284 m .66537 .53516 L .68846 .52585 L p .707 .577 .707 r
F P
0 g
s
.3859 .60399 m .40412 .5497 L .37443 .53906 L p .707 .577 .707 r
F P
0 g
s
.40412 .5497 m .3859 .60399 L .41605 .61349 L p .707 .577 .707 r
F P
0 g
s
.41605 .61349 m .43427 .5592 L .40412 .5497 L p .707 .577 .707 r
F P
0 g
s
.64599 .74588 m .64413 .72675 L .65238 .72491 L p .707 .577 .707 r
F P
0 g
s
.65238 .72491 m .65424 .74404 L .64599 .74588 L p .707 .577 .707 r
F P
0 g
s
.64554 .63247 m .64293 .66737 L .63606 .67992 L p .707 .577 .707 r
F P
0 g
s
.43427 .5592 m .41605 .61349 L .44371 .62092 L p .707 .577 .707 r
F P
0 g
s
.44371 .62092 m .46193 .56663 L .43427 .5592 L p .707 .577 .707 r
F P
0 g
s
.3562 .59335 m .37443 .53906 L .34809 .52832 L p .707 .577 .707 r
F P
0 g
s
.37443 .53906 m .3562 .59335 L .3859 .60399 L p .707 .577 .707 r
F P
0 g
s
.82897 .55746 m .82086 .60514 L .79921 .58972 L p .707 .577 .707 r
F P
0 g
s
.79921 .58972 m .80732 .54205 L .82897 .55746 L p .707 .577 .707 r
F P
0 g
s
.83909 .6493 m .83648 .6842 L .82373 .67124 L p .707 .577 .707 r
F P
0 g
s
.82373 .67124 m .82634 .63633 L .83909 .6493 L p .707 .577 .707 r
F P
0 g
s
.84474 .7069 m .8466 .72603 L .83522 .72613 L p .707 .577 .707 r
F P
0 g
s
.83522 .72613 m .83335 .707 L .84474 .7069 L p .707 .577 .707 r
F P
0 g
s
.34809 .52832 m .32987 .58261 L .3562 .59335 L p .707 .577 .707 r
F P
0 g
s
.64293 .66737 m .64554 .63247 L .6617 .62201 L p .707 .577 .707 r
F P
0 g
s
.3853 .67361 m .39134 .63641 L .36054 .63019 L p .707 .577 .707 r
F P
0 g
s
.39134 .63641 m .3853 .67361 L .41673 .67791 L p .707 .577 .707 r
F P
0 g
s
.41673 .67791 m .42278 .6407 L .39134 .63641 L p .707 .577 .707 r
F P
0 g
s
.46193 .56663 m .44371 .62092 L .46616 .62555 L p .707 .577 .707 r
F P
0 g
s
.46616 .62555 m .48438 .57127 L .46193 .56663 L p .707 .577 .707 r
F P
0 g
s
.68035 .57352 m .68846 .52585 L .71711 .52175 L p .707 .577 .707 r
F P
0 g
s
.68846 .52585 m .68035 .57352 L .65727 .58284 L p .707 .577 .707 r
F P
0 g
s
.32987 .58261 m .34809 .52832 L .3277 .51853 L p .707 .577 .707 r
F P
0 g
s
.42278 .6407 m .41673 .67791 L .44572 .67986 L p .707 .577 .707 r
F P
0 g
s
.44572 .67986 m .45177 .64266 L .42278 .6407 L p .707 .577 .707 r
F P
0 g
s
.3545 .66739 m .36054 .63019 L .33339 .62266 L p .707 .577 .707 r
F P
0 g
s
.36054 .63019 m .3545 .66739 L .3853 .67361 L p .707 .577 .707 r
F P
0 g
s
.80732 .54205 m .79921 .58972 L .77149 .57794 L p .707 .577 .707 r
F P
0 g
s
.77149 .57794 m .7796 .53027 L .80732 .54205 L p .707 .577 .707 r
F P
0 g
s
.3277 .51853 m .30947 .57282 L .32987 .58261 L p .707 .577 .707 r
F P
0 g
s
.33339 .62266 m .32735 .65986 L .3545 .66739 L p .707 .577 .707 r
F P
0 g
s
.6617 .62201 m .65909 .65692 L .64293 .66737 L p .707 .577 .707 r
F P
0 g
s
.709 .56943 m .71711 .52175 L .74851 .52328 L p .707 .577 .707 r
F P
0 g
s
.71711 .52175 m .709 .56943 L .68035 .57352 L p .707 .577 .707 r
F P
0 g
s
.65424 .74404 m .65238 .72491 L .66972 .72233 L p .707 .577 .707 r
F P
0 g
s
.66972 .72233 m .67158 .74146 L .65424 .74404 L p .707 .577 .707 r
F P
0 g
s
.45177 .64266 m .44572 .67986 L .46943 .67928 L p .707 .577 .707 r
F P
0 g
s
.46943 .67928 m .47547 .64208 L .45177 .64266 L p .707 .577 .707 r
F P
0 g
s
.7796 .53027 m .77149 .57794 L .74041 .57095 L p .707 .577 .707 r
F P
0 g
s
.74041 .57095 m .74851 .52328 L .7796 .53027 L p .707 .577 .707 r
F P
0 g
s
.82634 .63633 m .82373 .67124 L .80257 .65999 L p .707 .577 .707 r
F P
0 g
s
.80257 .65999 m .80518 .62508 L .82634 .63633 L p .707 .577 .707 r
F P
0 g
s
.74851 .52328 m .74041 .57095 L .709 .56943 L p .707 .577 .707 r
F P
0 g
s
.32735 .65986 m .33339 .62266 L .31254 .61456 L p .707 .577 .707 r
F P
0 g
s
.48438 .57127 m .46616 .62555 L .4812 .62694 L p .707 .577 .707 r
F P
0 g
s
.4812 .62694 m .49943 .57265 L .48438 .57127 L p .707 .577 .707 r
F P
0 g
s
.83335 .707 m .83522 .72613 L .8152 .72724 L p .707 .577 .707 r
F P
0 g
s
.8152 .72724 m .81334 .70811 L .83335 .707 L p .707 .577 .707 r
F P
0 g
s
.65909 .65692 m .6617 .62201 L .68556 .61468 L p .707 .577 .707 r
F P
0 g
s
.30947 .57282 m .3277 .51853 L .31524 .51066 L p .707 .577 .707 r
F P
0 g
s
.43317 .72466 m .42881 .70715 L .3977 .71439 L p .707 .577 .707 r
F P
0 g
s
.42881 .70715 m .43317 .72466 L .46235 .71436 L p .707 .577 .707 r
F P
0 g
s
.46235 .71436 m .458 .69685 L .42881 .70715 L p .707 .577 .707 r
F P
0 g
s
.40206 .7319 m .3977 .71439 L .36771 .71785 L p .707 .577 .707 r
F P
0 g
s
.3977 .71439 m .40206 .7319 L .43317 .72466 L p .707 .577 .707 r
F P
0 g
s
.31254 .61456 m .3065 .65176 L .32735 .65986 L p .707 .577 .707 r
F P
0 g
s
.31524 .51066 m .29702 .56495 L .30947 .57282 L p .707 .577 .707 r
F P
0 g
s
.36771 .71785 m .37207 .73536 L .40206 .7319 L p .707 .577 .707 r
F P
0 g
s
.458 .69685 m .46235 .71436 L .48675 .702 L p .707 .577 .707 r
F P
0 g
s
.48675 .702 m .48239 .68449 L .458 .69685 L p .707 .577 .707 r
F P
0 g
s
.37207 .73536 m .36771 .71785 L .34177 .7172 L p .707 .577 .707 r
F P
0 g
s
.47547 .64208 m .46943 .67928 L .48554 .67623 L p .707 .577 .707 r
F P
0 g
s
.48554 .67623 m .49158 .63903 L .47547 .64208 L p .707 .577 .707 r
F P
0 g
s
.68556 .61468 m .68295 .64958 L .65909 .65692 L p .707 .577 .707 r
F P
0 g
s
.80518 .62508 m .80257 .65999 L .77508 .65155 L p .707 .577 .707 r
F P
0 g
s
.77508 .65155 m .77769 .61665 L .80518 .62508 L p .707 .577 .707 r
F P
0 g
s
.67158 .74146 m .66972 .72233 L .69445 .71925 L p .707 .577 .707 r
F P
0 g
s
.69445 .71925 m .69632 .73838 L .67158 .74146 L p .707 .577 .707 r
F P
0 g
s
.68295 .64958 m .68556 .61468 L .7148 .61118 L p .707 .577 .707 r
F P
0 g
s
.3065 .65176 m .31254 .61456 L .30004 .60667 L p .707 .577 .707 r
F P
0 g
s
.34177 .7172 m .34613 .73471 L .37207 .73536 L p .707 .577 .707 r
F P
0 g
s
.81334 .70811 m .8152 .72724 L .78853 .72925 L p .707 .577 .707 r
F P
0 g
s
.78853 .72925 m .78667 .71012 L .81334 .70811 L p .707 .577 .707 r
F P
0 g
s
.48239 .68449 m .48675 .702 L .50397 .68879 L p .707 .577 .707 r
F P
0 g
s
.50397 .68879 m .49962 .67128 L .48239 .68449 L p .707 .577 .707 r
F P
0 g
s
.49943 .57265 m .4812 .62694 L .48738 .62494 L p .707 .577 .707 r
F P
0 g
s
.48738 .62494 m .5056 .57065 L .49943 .57265 L p .707 .577 .707 r
F P
0 g
s
.30004 .60667 m .294 .64387 L .3065 .65176 L p .707 .577 .707 r
F P
0 g
s
.29702 .56495 m .31524 .51066 L .31193 .50547 L p .707 .577 .707 r
F P
0 g
s
.77769 .61665 m .77508 .65155 L .74393 .64676 L p .707 .577 .707 r
F P
0 g
s
.74393 .64676 m .74654 .61186 L .77769 .61665 L p .707 .577 .707 r
F P
0 g
s
.71219 .64608 m .7148 .61118 L .74654 .61186 L p .707 .577 .707 r
F P
0 g
s
.7148 .61118 m .71219 .64608 L .68295 .64958 L p .707 .577 .707 r
F P
0 g
s
.34613 .73471 m .34177 .7172 L .32243 .7125 L p .707 .577 .707 r
F P
0 g
s
.31193 .50547 m .29371 .55975 L .29702 .56495 L p .707 .577 .707 r
F P
0 g
s
.74654 .61186 m .74393 .64676 L .71219 .64608 L p .707 .577 .707 r
F P
0 g
s
.69632 .73838 m .69445 .71925 L .72416 .71597 L p .707 .577 .707 r
F P
0 g
s
.72416 .71597 m .72603 .7351 L .69632 .73838 L p .707 .577 .707 r
F P
0 g
s
.32243 .7125 m .32678 .73001 L .34613 .73471 L p .707 .577 .707 r
F P
0 g
s
.78667 .71012 m .78853 .72925 L .7578 .73196 L p .707 .577 .707 r
F P
0 g
s
.7578 .73196 m .75594 .71283 L .78667 .71012 L p .707 .577 .707 r
F P
0 g
s
.49158 .63903 m .48554 .67623 L .49246 .671 L p .707 .577 .707 r
F P
0 g
s
.49246 .671 m .49851 .6338 L .49158 .63903 L p .707 .577 .707 r
F P
0 g
s
.294 .64387 m .30004 .60667 L .29711 .59977 L p .707 .577 .707 r
F P
0 g
s
.72603 .7351 m .72416 .71597 L .75594 .71283 L p .707 .577 .707 r
F P
0 g
s
.75594 .71283 m .7578 .73196 L .72603 .7351 L p .707 .577 .707 r
F P
0 g
s
.49962 .67128 m .50397 .68879 L .51234 .67603 L p .707 .577 .707 r
F P
0 g
s
.51234 .67603 m .50798 .65852 L .49962 .67128 L p .707 .577 .707 r
F P
0 g
s
.29711 .59977 m .29107 .63698 L .294 .64387 L p .707 .577 .707 r
F P
0 g
s
.32678 .73001 m .32243 .7125 L .31156 .70421 L p .707 .577 .707 r
F P
0 g
s
.5056 .57065 m .48738 .62494 L .48408 .61974 L p .707 .577 .707 r
F P
0 g
s
.48408 .61974 m .5023 .56546 L .5056 .57065 L p .707 .577 .707 r
F P
0 g
s
.29371 .55975 m .31193 .50547 L .31811 .50346 L p .707 .577 .707 r
F P
0 g
s
.31156 .70421 m .31592 .72172 L .32678 .73001 L p .707 .577 .707 r
F P
0 g
s
.31811 .50346 m .29989 .55775 L .29371 .55975 L p .707 .577 .707 r
F P
0 g
s
.49851 .6338 m .49246 .671 L .48953 .6641 L p .707 .577 .707 r
F P
0 g
s
.48953 .6641 m .49557 .6269 L .49851 .6338 L p .707 .577 .707 r
F P
0 g
s
.50798 .65852 m .51234 .67603 L .51102 .66496 L p .707 .577 .707 r
F P
0 g
s
.51102 .66496 m .50667 .64745 L .50798 .65852 L p .707 .577 .707 r
F P
0 g
s
.29107 .63698 m .29711 .59977 L .30403 .59454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31592 .72172 m .31156 .70421 L .31025 .69314 L p .707 .577 .707 r
F P
0 g
s
.30403 .59454 m .29799 .63175 L .29107 .63698 L p .707 .577 .707 r
F P
0 g
s
.5023 .56546 m .48408 .61974 L .47162 .61187 L p .707 .577 .707 r
F P
0 g
s
.47162 .61187 m .48984 .55758 L .5023 .56546 L p .707 .577 .707 r
F P
0 g
s
.29989 .55775 m .31811 .50346 L .33315 .50485 L p .707 .577 .707 r
F P
0 g
s
.31025 .69314 m .31461 .71065 L .31592 .72172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.33315 .50485 m .31493 .55913 L .29989 .55775 L p .707 .577 .707 r
F P
0 g
s
.49557 .6269 m .48953 .6641 L .47703 .65622 L p .707 .577 .707 r
F P
0 g
s
.47703 .65622 m .48307 .61901 L .49557 .6269 L p .707 .577 .707 r
F P
0 g
s
.50667 .64745 m .51102 .66496 L .50016 .65667 L p .707 .577 .707 r
F P
0 g
s
.50016 .65667 m .49581 .63916 L .50667 .64745 L p .707 .577 .707 r
F P
0 g
s
.29799 .63175 m .30403 .59454 L .32014 .59149 L p .707 .577 .707 r
F P
0 g
s
.31461 .71065 m .31025 .69314 L .31862 .68038 L p .707 .577 .707 r
F P
0 g
s
.32014 .59149 m .3141 .62869 L .29799 .63175 L p .707 .577 .707 r
F P
0 g
s
.48984 .55758 m .47162 .61187 L .45122 .60208 L p .707 .577 .707 r
F P
0 g
s
.45122 .60208 m .46944 .54779 L .48984 .55758 L p .707 .577 .707 r
F P
0 g
s
.31493 .55913 m .33315 .50485 L .35561 .50948 L p .707 .577 .707 r
F P
0 g
s
.31862 .68038 m .32297 .69789 L .31461 .71065 L p .707 .577 .707 r
F P
0 g
s
.35561 .50948 m .33738 .56377 L .31493 .55913 L p .707 .577 .707 r
F P
0 g
s
.48307 .61901 m .47703 .65622 L .45618 .64811 L p .707 .577 .707 r
F P
0 g
s
.45618 .64811 m .46223 .61091 L .48307 .61901 L p .707 .577 .707 r
F P
0 g
s
.49581 .63916 m .50016 .65667 L .48082 .65198 L p .707 .577 .707 r
F P
0 g
s
.48082 .65198 m .47646 .63447 L .49581 .63916 L p .707 .577 .707 r
F P
0 g
s
.3141 .62869 m .32014 .59149 L .34385 .59091 L p .707 .577 .707 r
F P
0 g
s
.46944 .54779 m .45122 .60208 L .42489 .59134 L p .707 .577 .707 r
F P
0 g
s
.42489 .59134 m .44311 .53706 L .46944 .54779 L p .707 .577 .707 r
F P
0 g
s
.33738 .56377 m .35561 .50948 L .38326 .51691 L p .707 .577 .707 r
F P
0 g
s
.32297 .69789 m .31862 .68038 L .33584 .66718 L p .707 .577 .707 r
F P
0 g
s
.34385 .59091 m .3378 .62811 L .3141 .62869 L p .707 .577 .707 r
F P
0 g
s
.38326 .51691 m .36504 .5712 L .33738 .56377 L p .707 .577 .707 r
F P
0 g
s
.33584 .66718 m .3402 .68469 L .32297 .69789 L p .707 .577 .707 r
F P
0 g
s
.46223 .61091 m .45618 .64811 L .42903 .64058 L p .707 .577 .707 r
F P
0 g
s
.42903 .64058 m .43507 .60338 L .46223 .61091 L p .707 .577 .707 r
F P
0 g
s
.44311 .53706 m .42489 .59134 L .39519 .5807 L p .707 .577 .707 r
F P
0 g
s
.39519 .5807 m .41341 .52641 L .44311 .53706 L p .707 .577 .707 r
F P
0 g
s
.36504 .5712 m .38326 .51691 L .41341 .52641 L p .707 .577 .707 r
F P
0 g
s
.3378 .62811 m .34385 .59091 L .37284 .59287 L p .707 .577 .707 r
F P
0 g
s
.41341 .52641 m .39519 .5807 L .36504 .5712 L p .707 .577 .707 r
F P
0 g
s
.47646 .63447 m .48082 .65198 L .45488 .65133 L p .707 .577 .707 r
F P
0 g
s
.45488 .65133 m .45052 .63382 L .47646 .63447 L p .707 .577 .707 r
F P
0 g
s
.37284 .59287 m .36679 .63007 L .3378 .62811 L p .707 .577 .707 r
F P
0 g
s
.3402 .68469 m .33584 .66718 L .36024 .65482 L p .707 .577 .707 r
F P
0 g
s
.43507 .60338 m .42903 .64058 L .39823 .63437 L p .707 .577 .707 r
F P
0 g
s
.39823 .63437 m .40427 .59716 L .43507 .60338 L p .707 .577 .707 r
F P
0 g
s
.36679 .63007 m .37284 .59287 L .40427 .59716 L p .707 .577 .707 r
F P
0 g
s
.36024 .65482 m .36459 .67233 L .3402 .68469 L p .707 .577 .707 r
F P
0 g
s
.40427 .59716 m .39823 .63437 L .36679 .63007 L p .707 .577 .707 r
F P
0 g
s
.45052 .63382 m .45488 .65133 L .42489 .65479 L p .707 .577 .707 r
F P
0 g
s
.42489 .65479 m .42053 .63728 L .45052 .63382 L p .707 .577 .707 r
F P
0 g
s
.36459 .67233 m .36024 .65482 L .38942 .64451 L p .707 .577 .707 r
F P
0 g
s
.38942 .64451 m .39378 .66203 L .36459 .67233 L p .707 .577 .707 r
F P
0 g
s
.42053 .63728 m .42489 .65479 L .39378 .66203 L p .707 .577 .707 r
F P
0 g
s
.39378 .66203 m .38942 .64451 L .42053 .63728 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP000080
07Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF1000L7oo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001^Ool006]oo`8000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006aoo`00JGoo0`00
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JWoo001WOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00IWoo00<005YFFUH0
0UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol:0003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol00`00FUH00003
FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Egoo
00<005YF00000eYF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP@000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000@Ool?0016
Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF000;Ool50003FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP002Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0`00?goo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001goo0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00?Goo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH4
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00P00
>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH000Aoo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF009JEP8003Uoo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009oo`800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Moo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00H005YFFUH007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH3000eOol005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000d
Ool005Aoo`03FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00<Woo001COol0
1000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0;goo001COol20002FUH50003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000`Ool005Aoo`05001JEUYFFUH00003FUH50007FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002mo
o`00EGoo0P001eYF00<005YFFUH010000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000_Ool005Moo`03001JEUYF00AJEP03001J
EUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00=JEP03001JEUYF00@000Ioo`L000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005Qoo`8000AJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEP@0015oo`@0009JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FWoo0P0000=JEP00FUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF
FUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH0
0`00FUH00003000IOol40006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005ao
o`<000MJEP03001JEUYF00IJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP80025o
o`8000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00Ggoo0P001EYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00Oomo
o`0SOol300000eYF001JEP05FUH00`00FUIJEP02FUH2000/Ool0065oo`<00003FUH005YF00MJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000015YF001JEP009goo0P001UYF00L005YFFUIJ
EP00FUH0000/Ool005UooaH000QJEP<000MJEP03001JEUYF00AJEP06001JEUYF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10000UYF00<007ooOol09goo00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000=JEP04001JEP000005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001oogoo01=oo`<0015oo`05
001JEUYFFUH00004FUH00`00FUH0000/Ool005Aoo`<000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00@000=JEP<00003FUH005YF00EJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<007ooOol04Goo
1@004Goo0P0000=JEP00FUH00eYF00<005YF0000;7oo001DOol00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH20006FUH01000FUIJEUYF
0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF0P00
4Woo1@004goo0P0015YF00<005YF0000;7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050004FUH01P00FUIJEP00FUH000aJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000EJEP03001JEP00015oo`D001Aoo`03
001JEUYF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEP8000Ioo`T0
0004Ool00000000FOol01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40003FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH6
0004FUH00`00FUIJEP02FUH9000BOol01@00FUH005YF0000;Goo001COol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000<
Ool01@00FUH005YF0000;Goo001<Ool800000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030008Ool300000eYF001o
o`0/Ool004=oo`T000AJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`80009JEP03001JEP0002eoo`00?Goo1P0015YF
00<005YFFUH015YF1@0000AJEP00FUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH500001eYF001JEUYF001JEP0002eoo`00>Goo100000=JEP00FUH0
1EYF2@0015YF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00800004FUH005YFFUH2000^
Ool003Aoo`D000AJEPP000AJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPP000IJEP03001JEUYF00h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000^Ool002moo`D0
0003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@000]J
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF0000000^Ool002]oo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEPH0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002ioo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEPl000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH0
0`00FUIJEP030003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003FUH00`00FUH00008FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUH000030007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH300000eYF001JEP06FUH30007FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP04FUH2
0003FUH400000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004
FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF0P0000=JEP00
FUH01eYF00<005YFFUH0100000=JEP00FUH01UYF00<005YFFUH015YF00D005YF000005YF0080009J
EP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0009JEP80009J
EP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP05FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF0`001eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YF000025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH005YF0P0015YF00@005YF000000IJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUH000001eYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUIJEP<00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30003FUH700000eYF00000003FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH40002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00EJEP<0009J
EPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000=JEP@000=JEPD0
0003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool01@00FUH005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0`0015YF00<005YFFUH015YF
200015YF00<005YFFUH015YF00<005YFFUH01@0000EJEP00FUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8000AJEP04001JEUYF0005FUH00`00FUH000040006FUH50004
FUH00`00FUIJEP05FUH01000FUH000001Woo00D005YF001JEP0002eoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P001EYF00D005YF000007oo008000AJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH>0002FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH0
1000FUIJEUYF0P000eYF00D005YFFUIJEP00009oo`@0009JEP@000EJEP03001JEUYF009JEPD000Mo
o`D002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2`001EYF0P000goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF0P0025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
0P0015YF00<005YFFUH00eYF0P000UYF00@005YFFUH000Iooa0000Yoo`8000=JEP8002ioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1`002Goo0P0015YF
00<007ooOol00goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01EYF0`001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YF00000`000UYF00<007ooOol06goo0`0015YF0P00;Woo000]Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000?Ool01@00FUIJEP00FUH00P001Woo
0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YFFUH00eYF1P0067oo0P000UYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6000;Ool90002FUH40006Ool20004FUH01000FUIJ
EUYF0`000UYF00<005YFFUH025YF00@005YFFUIJEP8000EJEP04001JEP00000;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH90009Ool60004FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<005YF00000UYF7P00
15YF00D005YFFUIJEP00009JEP80009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00QJEP04001J
EP000007FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Goo1@001Goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00T005YFFUIJEP00FUH005YF00001EYF00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01eYF0`0000=JEP00FUH01UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00<Woo1@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03
001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP80009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03001JEUYF008000AJEP03
001JEUYF00IJEP04001JEUYFFUH30008FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000E000/Ool002ioo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000000015YF
00<005YFFUH00P0015YF00<005YFFUH01UYF100000=JEP00FUH025YF0`001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP04001JEUYF0007
FUH00`00FUIJEP05FUH00`00FUIJEP090004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF0000;7oo000/Ool30004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF
00L005YFFUIJEP00FUH00002FUH90004FUH00`00FUH000060006FUH00`00FUIJEP05FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001EYF
0`001eYF00<005YFFUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002aoo`00;7oo00<005YF000015YF00<005YFFUH00UYF1P0015YF00<005YFFUH00UYF
2@001EYF00L005YFFUIJEP00FUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH000IJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;7oo00<005YF000015YF1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00@005YFFUH000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000[
Ool002aoo`03001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000002FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH01000FUIJEUYF3P00:goo000/Ool00`00FUH00002FUH20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH:000]Ool002aoo`03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00AJEP`000=JEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF
1`00=goo000]Ool20003FUH00`00FUIJEP03FUH600000eYF000000080004FUH40002FUH00`00FUIJ
EP05FUH30002FUH01000FUIJEUYF2P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH01000
FUIJEUYF4@000eYF2@00?Woo000]Ool20003FUH00`00FUH0000;0008FUH00`00FUIJEP06FUH40006
FUH01P00FUIJEP00FUH000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP000UYF1P001UYF00<005YFFUH00UYF2@00Agoo000/Ool00`00FUH00003FUH70006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP80009JEP@000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF2000D7oo000/Ool20002FUH3
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF
001JEP04FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH90009FUH01000FUIJEUYF
30001EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH03`0000=JEP000000E7oo000[Ool0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20005FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP060006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP080007FUH00`00FUIJEP03FUH01000FUIJEP00
2Woo10000UYF00<007ooOol0DWoo000[Ool01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF0P000Woo0P0015YF00<0
05YFFUH015YF1P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF1@000UYF00<0
05YFFUH00eYF00@005YFFUH000Qoo`8000AJEP<005Aoo`00:goo0P0000=oo`0000001@000eYF00<0
05YFFUH015YF00<005YFFUH00UYF4P001goo0P0000IJEP00FUIJEP00Ool20004FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP02FUH30005FUH01000FUIJEP001Woo0P0000=JEP00FUH00eYF00<005YF0000E7oo000[Ool20008
Ool?000KOol20002FUH01000Ool0000015YF100025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00@005YFFUH000Aoo`8000=JEP03
001JEUYF009JEP04001JEP00001COol002]oo`8003=oo`04001JEUYFFUH30002FUH20003FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300001UYF001JEUYF001oo`<000EJEP03001JEUYF009JEP04001JEUYF001COol002]o
o`8003Aoo`03001JEUYF00D000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP800003FUH005YF
00EJEP03001JEUYF009JEP04001JEUYF001COol002]oo`<001Yoo`<001Moo`03001JEP0000<000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00=J
EP8005Aoo`00:goo0`006Goo1@005Woo00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00E7oo000[Ool01000FUIJEP00
67oo1@005goo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH00UYF00<007ooOol0Dgoo000[Ool01@00FUIJEUYF00005goo1@0067oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00D005YF
FUIJEP0005Ioo`00:goo00@005YFFUIJEP<001Ioo`<001Qoo`<00003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP04001JEP00001GOol002aoo`04001JEUYF
0002FUH00`00Oomoo`0^Ool200000goo00000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH2001IOol002aoo`03001JEP0000AJEP8002eoo`04001JEP00Ool20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00Oomoo`1HOol0
02eoo`8000IJEP8002Yoo`800004FUH007ooOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020007
FUH01000FUIJEUYF0P00Fgoo000^Ool00`00FUIJEP04FUH01000FUH000009Woo0P0000=JEP000000
1Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF1@001eYF00@005YF000005eoo`00;goo0P0015YF00@005YFFUIJ
EP8002=oo`04001JEUYFFUH20007Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH01000FUH000000eYF1000
Ggoo000aOol01000FUIJEP001UYF10007Goo0P0015YF00<007ooOol027oo10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`0015YF00@0
05YFFUIJEP<006=oo`00<Woo0`001eYF00<005YFFUH010005Goo100000=JEP00FUH00eYF00<007oo
Ool037oo10000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`001EYF00<005YFFUH01EYF0`00H7oo000dOol20006FUH00`00FUIJEP04FUH70009
Ool50005FUH00`00FUIJEP02000COol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH;0002FUH00`00FUIJEP06FUH01000FUH00000GWoo000fOol20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH3000JOol60003FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0?0002Ool40006FUH00`00FUIJEP02FUH2001LOol003Qoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80029ooal00004FUH000000006
Ool50006Ool20004FUH00`00FUIJEP03FUH3001JOol003]oo`<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH2000gOol20006FUH00`00FUIJEP05FUH6000017oo000000002Goo0P00
00=JEP00FUH01EYF00@005YFFUH005Uoo`00?Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003]oo`@00003FUH005YF00QJEP03001JEUYF009JEPH000Uoo`<000AJEP05001JEUYF
FUH0001IOol0049ooaH0045oo`<000QJEP03001JEUYF00IJEP03001JEP0000<000Qoo`<00003FUH0
05YF009JEP8005Qoo`00W7oo0`0015YF00<005YFFUH01eYF00<005YFFUH00eYF3@000UYF00<005YF
0000F7oo002OOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP8005Uoo`00XWoo10001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00
FGoo002VOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001J
Ool00:Yoo`H000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Yoo`00/7oo20000eYF
00<005YFFUH01000Fgoo002hOol6001OOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60166 .75781 m .5903 .70484 L .55965 .70826 L p .707 .577 .707 r
F P
0 g
s
.5903 .70484 m .60166 .75781 L .63283 .75078 L p .707 .577 .707 r
F P
0 g
s
.63283 .75078 m .62147 .69781 L .5903 .70484 L p .707 .577 .707 r
F P
0 g
s
.62147 .69781 m .63283 .75078 L .66148 .74084 L p .707 .577 .707 r
F P
0 g
s
.66148 .74084 m .65011 .68787 L .62147 .69781 L p .707 .577 .707 r
F P
0 g
s
.57101 .76123 m .55965 .70826 L .53252 .70775 L p .707 .577 .707 r
F P
0 g
s
.55965 .70826 m .57101 .76123 L .60166 .75781 L p .707 .577 .707 r
F P
0 g
s
.65011 .68787 m .66148 .74084 L .68479 .72897 L p .707 .577 .707 r
F P
0 g
s
.68479 .72897 m .67343 .67599 L .65011 .68787 L p .707 .577 .707 r
F P
0 g
s
.59965 .81408 m .5959 .77766 L .56487 .77838 L p .707 .577 .707 r
F P
0 g
s
.5959 .77766 m .59965 .81408 L .63133 .81022 L p .707 .577 .707 r
F P
0 g
s
.63133 .81022 m .62758 .7738 L .5959 .77766 L p .707 .577 .707 r
F P
0 g
s
.62758 .7738 m .63133 .81022 L .66055 .8036 L p .707 .577 .707 r
F P
0 g
s
.66055 .8036 m .6568 .76719 L .62758 .7738 L p .707 .577 .707 r
F P
0 g
s
.54389 .76072 m .53252 .70775 L .51157 .70335 L p .707 .577 .707 r
F P
0 g
s
.53252 .70775 m .54389 .76072 L .57101 .76123 L p .707 .577 .707 r
F P
0 g
s
.67343 .67599 m .68479 .72897 L .70049 .71631 L p .707 .577 .707 r
F P
0 g
s
.70049 .71631 m .68912 .66333 L .67343 .67599 L p .707 .577 .707 r
F P
0 g
s
.56861 .8148 m .56487 .77838 L .53751 .77589 L p .707 .577 .707 r
F P
0 g
s
.56487 .77838 m .56861 .8148 L .59965 .81408 L p .707 .577 .707 r
F P
0 g
s
.58318 .84556 m .5859 .82695 L .55525 .82099 L p .707 .577 .707 r
F P
0 g
s
.5859 .82695 m .58318 .84556 L .61476 .84955 L p .707 .577 .707 r
F P
0 g
s
.61476 .84955 m .61748 .83094 L .5859 .82695 L p .707 .577 .707 r
F P
0 g
s
.6568 .76719 m .66055 .8036 L .68445 .79487 L p .707 .577 .707 r
F P
0 g
s
.68445 .79487 m .6807 .75845 L .6568 .76719 L p .707 .577 .707 r
F P
0 g
s
.61748 .83094 m .61476 .84955 L .64419 .85118 L p .707 .577 .707 r
F P
0 g
s
.64419 .85118 m .64691 .83257 L .61748 .83094 L p .707 .577 .707 r
F P
0 g
s
.55525 .82099 m .55253 .83959 L .58318 .84556 L p .707 .577 .707 r
F P
0 g
s
.55253 .83959 m .55525 .82099 L .52854 .81363 L p .707 .577 .707 r
F P
0 g
s
.53751 .77589 m .54125 .81231 L .56861 .8148 L p .707 .577 .707 r
F P
0 g
s
.52854 .81363 m .52582 .83224 L .55253 .83959 L p .707 .577 .707 r
F P
0 g
s
.51157 .70335 m .52294 .75632 L .54389 .76072 L p .707 .577 .707 r
F P
0 g
s
.54125 .81231 m .53751 .77589 L .51651 .77044 L p .707 .577 .707 r
F P
0 g
s
.52294 .75632 m .51157 .70335 L .49885 .69549 L p .707 .577 .707 r
F P
0 g
s
.64691 .83257 m .64419 .85118 L .66859 .85028 L p .707 .577 .707 r
F P
0 g
s
.66859 .85028 m .67131 .83167 L .64691 .83257 L p .707 .577 .707 r
F P
0 g
s
.68912 .66333 m .70049 .71631 L .70703 .70411 L p .707 .577 .707 r
F P
0 g
s
.70703 .70411 m .69567 .65114 L .68912 .66333 L p .707 .577 .707 r
F P
0 g
s
.6807 .75845 m .68445 .79487 L .70069 .78488 L p .707 .577 .707 r
F P
0 g
s
.70069 .78488 m .69694 .74846 L .6807 .75845 L p .707 .577 .707 r
F P
0 g
s
.52582 .83224 m .52854 .81363 L .50839 .8056 L p .707 .577 .707 r
F P
0 g
s
.51651 .77044 m .52025 .80686 L .54125 .81231 L p .707 .577 .707 r
F P
0 g
s
.50839 .8056 m .50567 .82421 L .52582 .83224 L p .707 .577 .707 r
F P
0 g
s
.49885 .69549 m .51022 .74847 L .52294 .75632 L p .707 .577 .707 r
F P
0 g
s
.67131 .83167 m .66859 .85028 L .68556 .84695 L p .707 .577 .707 r
F P
0 g
s
.68556 .84695 m .68829 .82834 L .67131 .83167 L p .707 .577 .707 r
F P
0 g
s
.52025 .80686 m .51651 .77044 L .50392 .76256 L p .707 .577 .707 r
F P
0 g
s
.51022 .74847 m .49885 .69549 L .49561 .68495 L p .707 .577 .707 r
F P
0 g
s
.50567 .82421 m .50839 .8056 L .49676 .79769 L p .707 .577 .707 r
F P
0 g
s
.69694 .74846 m .70069 .78488 L .70768 .77461 L p .707 .577 .707 r
F P
0 g
s
.70768 .77461 m .70393 .73819 L .69694 .74846 L p .707 .577 .707 r
F P
0 g
s
.50392 .76256 m .50767 .79897 L .52025 .80686 L p .707 .577 .707 r
F P
0 g
s
.69567 .65114 m .70703 .70411 L .70379 .69357 L p .707 .577 .707 r
F P
0 g
s
.70379 .69357 m .69242 .6406 L .69567 .65114 L p .707 .577 .707 r
F P
0 g
s
.49676 .79769 m .49404 .8163 L .50567 .82421 L p .707 .577 .707 r
F P
0 g
s
.68829 .82834 m .68556 .84695 L .69346 .8415 L p .707 .577 .707 r
F P
0 g
s
.69346 .8415 m .69618 .82289 L .68829 .82834 L p .707 .577 .707 r
F P
0 g
s
.49561 .68495 m .50697 .73793 L .51022 .74847 L p .707 .577 .707 r
F P
0 g
s
.50767 .79897 m .50392 .76256 L .50098 .75301 L p .707 .577 .707 r
F P
0 g
s
.50697 .73793 m .49561 .68495 L .50215 .67275 L p .707 .577 .707 r
F P
0 g
s
.49404 .8163 m .49676 .79769 L .4948 .79067 L p .707 .577 .707 r
F P
0 g
s
.4948 .79067 m .49208 .80927 L .49404 .8163 L p .707 .577 .707 r
F P
0 g
s
.49208 .80927 m .4948 .79067 L .50269 .78522 L p .707 .577 .707 r
F P
0 g
s
.50269 .78522 m .49997 .80383 L .49208 .80927 L p .707 .577 .707 r
F P
0 g
s
.50098 .75301 m .50472 .78943 L .50767 .79897 L p .707 .577 .707 r
F P
0 g
s
.50472 .78943 m .50098 .75301 L .50797 .74274 L p .707 .577 .707 r
F P
0 g
s
.50797 .74274 m .51172 .77916 L .50472 .78943 L p .707 .577 .707 r
F P
0 g
s
.49997 .80383 m .50269 .78522 L .51966 .78188 L p .707 .577 .707 r
F P
0 g
s
.51966 .78188 m .51694 .80049 L .49997 .80383 L p .707 .577 .707 r
F P
0 g
s
.50018 .82192 m .50018 .32003 L .4556 .31816 L p .707 .577 .707 r
F P
0 g
s
.50215 .67275 m .51352 .72573 L .50697 .73793 L p .707 .577 .707 r
F P
0 g
s
.51352 .72573 m .50215 .67275 L .51785 .6601 L p .707 .577 .707 r
F P
0 g
s
.51785 .6601 m .52921 .71307 L .51352 .72573 L p .707 .577 .707 r
F P
0 g
s
.51172 .77916 m .50797 .74274 L .52421 .73275 L p .707 .577 .707 r
F P
0 g
s
.52921 .71307 m .51785 .6601 L .54116 .64822 L p .707 .577 .707 r
F P
0 g
s
.52421 .73275 m .52796 .76917 L .51172 .77916 L p .707 .577 .707 r
F P
0 g
s
.54116 .64822 m .55252 .70119 L .52921 .71307 L p .707 .577 .707 r
F P
0 g
s
.52796 .76917 m .52421 .73275 L .54811 .72402 L p .707 .577 .707 r
F P
0 g
s
.54811 .72402 m .55186 .76044 L .52796 .76917 L p .707 .577 .707 r
F P
0 g
s
.51694 .80049 m .51966 .78188 L .54406 .78099 L p .707 .577 .707 r
F P
0 g
s
.54406 .78099 m .54134 .79959 L .51694 .80049 L p .707 .577 .707 r
F P
0 g
s
.54134 .79959 m .54406 .78099 L .57349 .78261 L p .707 .577 .707 r
F P
0 g
s
.57349 .78261 m .57077 .80122 L .54134 .79959 L p .707 .577 .707 r
F P
0 g
s
.50018 .32003 m .50018 .82192 L .54475 .82001 L p .707 .577 .707 r
F P
0 g
s
.55252 .70119 m .54116 .64822 L .5698 .63828 L p .707 .577 .707 r
F P
0 g
s
.54475 .82001 m .54475 .31813 L .50018 .32003 L p .707 .577 .707 r
F P
0 g
s
.4556 .82004 m .4556 .31816 L .41536 .31267 L p .707 .577 .707 r
F P
0 g
s
.4556 .31816 m .4556 .82004 L .50018 .82192 L p .707 .577 .707 r
F P
0 g
s
.58117 .69125 m .5698 .63828 L .60098 .63125 L p .707 .577 .707 r
F P
0 g
s
.5698 .63828 m .58117 .69125 L .55252 .70119 L p .707 .577 .707 r
F P
0 g
s
.55186 .76044 m .54811 .72402 L .57733 .7174 L p .707 .577 .707 r
F P
0 g
s
.57733 .7174 m .58108 .75382 L .55186 .76044 L p .707 .577 .707 r
F P
0 g
s
.57077 .80122 m .57349 .78261 L .60508 .7866 L p .707 .577 .707 r
F P
0 g
s
.60508 .7866 m .60235 .80521 L .57077 .80122 L p .707 .577 .707 r
F P
0 g
s
.54475 .31813 m .54475 .82001 L .58493 .8145 L p .707 .577 .707 r
F P
0 g
s
.60098 .63125 m .61234 .68423 L .58117 .69125 L p .707 .577 .707 r
F P
0 g
s
.58108 .75382 m .57733 .7174 L .60901 .71354 L p .707 .577 .707 r
F P
0 g
s
.60901 .71354 m .61275 .74996 L .58108 .75382 L p .707 .577 .707 r
F P
0 g
s
.58493 .8145 m .58493 .31261 L .54475 .31813 L p .707 .577 .707 r
F P
0 g
s
.70393 .73819 m .70768 .77461 L .70474 .76507 L p .707 .577 .707 r
F P
0 g
s
.70474 .76507 m .70099 .72865 L .70393 .73819 L p .707 .577 .707 r
F P
0 g
s
.69242 .6406 m .70379 .69357 L .69107 .68571 L p .707 .577 .707 r
F P
0 g
s
.69107 .68571 m .6797 .63274 L .69242 .6406 L p .707 .577 .707 r
F P
0 g
s
.69618 .82289 m .69346 .8415 L .69149 .83448 L p .707 .577 .707 r
F P
0 g
s
.69149 .83448 m .69421 .81587 L .69618 .82289 L p .707 .577 .707 r
F P
0 g
s
.41536 .81456 m .41536 .31267 L .38341 .30412 L p .707 .577 .707 r
F P
0 g
s
.41536 .31267 m .41536 .81456 L .4556 .82004 L p .707 .577 .707 r
F P
0 g
s
.61234 .68423 m .60098 .63125 L .63163 .62783 L p .707 .577 .707 r
F P
0 g
s
.64005 .71282 m .64379 .74924 L .61275 .74996 L p .707 .577 .707 r
F P
0 g
s
.61275 .74996 m .60901 .71354 L .64005 .71282 L p .707 .577 .707 r
F P
0 g
s
.63572 .79257 m .633 .81118 L .60235 .80521 L p .707 .577 .707 r
F P
0 g
s
.60235 .80521 m .60508 .7866 L .63572 .79257 L p .707 .577 .707 r
F P
0 g
s
.58493 .31261 m .58493 .8145 L .6168 .80593 L p .707 .577 .707 r
F P
0 g
s
.63163 .62783 m .64299 .6808 L .61234 .68423 L p .707 .577 .707 r
F P
0 g
s
.6168 .80593 m .6168 .30404 L .58493 .31261 L p .707 .577 .707 r
F P
0 g
s
.25689 .69401 m .25194 .6367 L .22075 .63888 L p .707 .577 .707 r
F P
0 g
s
.25194 .6367 m .25689 .69401 L .28855 .69103 L p .707 .577 .707 r
F P
0 g
s
.28855 .69103 m .28359 .63371 L .25194 .6367 L p .707 .577 .707 r
F P
0 g
s
.28359 .63371 m .28855 .69103 L .31757 .68752 L p .707 .577 .707 r
F P
0 g
s
.31757 .68752 m .31262 .63021 L .28359 .63371 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22075 .63888 m .2257 .69619 L .25689 .69401 L p .707 .577 .707 r
F P
0 g
s
.70099 .72865 m .70474 .76507 L .69215 .75718 L p .707 .577 .707 r
F P
0 g
s
.69215 .75718 m .68841 .72077 L .70099 .72865 L p .707 .577 .707 r
F P
0 g
s
.6797 .63274 m .69107 .68571 L .67012 .68132 L p .707 .577 .707 r
F P
0 g
s
.67012 .68132 m .65875 .62834 L .6797 .63274 L p .707 .577 .707 r
F P
0 g
s
.2257 .69619 m .22075 .63888 L .19309 .64004 L p .707 .577 .707 r
F P
0 g
s
.19309 .64004 m .19804 .69735 L .2257 .69619 L p .707 .577 .707 r
F P
0 g
s
.31262 .63021 m .31757 .68752 L .34113 .68385 L p .707 .577 .707 r
F P
0 g
s
.34113 .68385 m .33618 .62653 L .31262 .63021 L p .707 .577 .707 r
F P
0 g
s
.25489 .76443 m .25328 .72658 L .22211 .72666 L p .707 .577 .707 r
F P
0 g
s
.25328 .72658 m .25489 .76443 L .28668 .7626 L p .707 .577 .707 r
F P
0 g
s
.28668 .7626 m .28507 .72475 L .25328 .72658 L p .707 .577 .707 r
F P
0 g
s
.28507 .72475 m .28668 .7626 L .316 .75919 L p .707 .577 .707 r
F P
0 g
s
.316 .75919 m .31439 .72134 L .28507 .72475 L p .707 .577 .707 r
F P
0 g
s
.38341 .80601 m .38341 .30412 L .36287 .29334 L p .707 .577 .707 r
F P
0 g
s
.38341 .30412 m .38341 .80601 L .41536 .81456 L p .707 .577 .707 r
F P
0 g
s
.19804 .69735 m .19309 .64004 L .17165 .64007 L p .707 .577 .707 r
F P
0 g
s
.633 .81118 m .63572 .79257 L .66243 .79993 L p .707 .577 .707 r
F P
0 g
s
.6168 .30404 m .6168 .80593 L .63724 .79513 L p .707 .577 .707 r
F P
0 g
s
.64299 .6808 m .63163 .62783 L .65875 .62834 L p .707 .577 .707 r
F P
0 g
s
.63724 .79513 m .63724 .29324 L .6168 .30404 L p .707 .577 .707 r
F P
0 g
s
.69421 .81587 m .69149 .83448 L .67986 .82656 L p .707 .577 .707 r
F P
0 g
s
.67986 .82656 m .68258 .80796 L .69421 .81587 L p .707 .577 .707 r
F P
0 g
s
.22211 .72666 m .22372 .76451 L .25489 .76443 L p .707 .577 .707 r
F P
0 g
s
.22372 .76451 m .22211 .72666 L .19462 .72497 L p .707 .577 .707 r
F P
0 g
s
.17165 .64007 m .1766 .69738 L .19804 .69735 L p .707 .577 .707 r
F P
0 g
s
.65875 .62834 m .67012 .68132 L .64299 .6808 L p .707 .577 .707 r
F P
0 g
s
.19462 .72497 m .19623 .76282 L .22372 .76451 L p .707 .577 .707 r
F P
0 g
s
.31439 .72134 m .316 .75919 L .33996 .75453 L p .707 .577 .707 r
F P
0 g
s
.33996 .75453 m .33835 .71668 L .31439 .72134 L p .707 .577 .707 r
F P
0 g
s
.68841 .72077 m .69215 .75718 L .67115 .75173 L p .707 .577 .707 r
F P
0 g
s
.67115 .75173 m .66741 .71531 L .68841 .72077 L p .707 .577 .707 r
F P
0 g
s
.33618 .62653 m .34113 .68385 L .35691 .68036 L p .707 .577 .707 r
F P
0 g
s
.35691 .68036 m .35196 .62305 L .33618 .62653 L p .707 .577 .707 r
F P
0 g
s
.19623 .76282 m .19462 .72497 L .1735 .72168 L p .707 .577 .707 r
F P
0 g
s
.1766 .69738 m .17165 .64007 L .15855 .63895 L p .707 .577 .707 r
F P
0 g
s
.1735 .72168 m .17511 .75953 L .19623 .76282 L p .707 .577 .707 r
F P
0 g
s
.24625 .82541 m .24741 .80786 L .21648 .80296 L p .707 .577 .707 r
F P
0 g
s
.24741 .80786 m .24625 .82541 L .27809 .82632 L p .707 .577 .707 r
F P
0 g
s
.27809 .82632 m .27925 .80877 L .24741 .80786 L p .707 .577 .707 r
F P
0 g
s
.27925 .80877 m .27809 .82632 L .30772 .82315 L p .707 .577 .707 r
F P
0 g
s
.30772 .82315 m .30888 .8056 L .27925 .80877 L p .707 .577 .707 r
F P
0 g
s
.15855 .63895 m .1635 .69627 L .1766 .69738 L p .707 .577 .707 r
F P
0 g
s
.68258 .80796 m .67986 .82656 L .65971 .81854 L p .707 .577 .707 r
F P
0 g
s
.65971 .81854 m .66243 .79993 L .68258 .80796 L p .707 .577 .707 r
F P
0 g
s
.33835 .71668 m .33996 .75453 L .35622 .74908 L p .707 .577 .707 r
F P
0 g
s
.35622 .74908 m .35461 .71123 L .33835 .71668 L p .707 .577 .707 r
F P
0 g
s
.21532 .82051 m .21648 .80296 L .18949 .79456 L p .707 .577 .707 r
F P
0 g
s
.21648 .80296 m .21532 .82051 L .24625 .82541 L p .707 .577 .707 r
F P
0 g
s
.66741 .71531 m .67115 .75173 L .64379 .74924 L p .707 .577 .707 r
F P
0 g
s
.64379 .74924 m .64005 .71282 L .66741 .71531 L p .707 .577 .707 r
F P
0 g
s
.35196 .62305 m .35691 .68036 L .36337 .6774 L p .707 .577 .707 r
F P
0 g
s
.36337 .6774 m .35842 .62009 L .35196 .62305 L p .707 .577 .707 r
F P
0 g
s
.35461 .71123 m .35622 .74908 L .36319 .74338 L p .707 .577 .707 r
F P
0 g
s
.36319 .74338 m .36158 .70553 L .35461 .71123 L p .707 .577 .707 r
F P
0 g
s
.35842 .62009 m .36337 .6774 L .35988 .67526 L p .707 .577 .707 r
F P
0 g
s
.36158 .70553 m .36319 .74338 L .36019 .73798 L p .707 .577 .707 r
F P
0 g
s
.36287 .79523 m .36287 .29334 L .35575 .28138 L p .707 .577 .707 r
F P
0 g
s
.36287 .29334 m .36287 .79523 L .38341 .80601 L p .707 .577 .707 r
F P
0 g
s
.18949 .79456 m .18833 .81211 L .21532 .82051 L p .707 .577 .707 r
F P
0 g
s
.30888 .8056 m .30772 .82315 L .33225 .81622 L p .707 .577 .707 r
F P
0 g
s
.33225 .81622 m .33341 .79867 L .30888 .8056 L p .707 .577 .707 r
F P
0 g
s
.63724 .29324 m .63724 .79513 L .64424 .78317 L p .707 .577 .707 r
F P
0 g
s
.64424 .78317 m .64424 .28128 L .63724 .29324 L p .707 .577 .707 r
F P
0 g
s
.17511 .75953 m .1735 .72168 L .16082 .71711 L p .707 .577 .707 r
F P
0 g
s
.18833 .81211 m .18949 .79456 L .16908 .78347 L p .707 .577 .707 r
F P
0 g
s
.16082 .71711 m .16243 .75496 L .17511 .75953 L p .707 .577 .707 r
F P
0 g
s
.66243 .79993 m .65971 .81854 L .633 .81118 L p .707 .577 .707 r
F P
0 g
s
.1635 .69627 m .15855 .63895 L .15505 .63682 L p .707 .577 .707 r
F P
0 g
s
.16908 .78347 m .16792 .80102 L .18833 .81211 L p .707 .577 .707 r
F P
0 g
s
.15505 .63682 m .16001 .69413 L .1635 .69627 L p .707 .577 .707 r
F P
0 g
s
.33341 .79867 m .33225 .81622 L .34927 .8062 L p .707 .577 .707 r
F P
0 g
s
.34927 .8062 m .35043 .78865 L .33341 .79867 L p .707 .577 .707 r
F P
0 g
s
.16792 .80102 m .16908 .78347 L .15724 .77078 L p .707 .577 .707 r
F P
0 g
s
.16243 .75496 m .16082 .71711 L .15782 .71171 L p .707 .577 .707 r
F P
0 g
s
.35988 .67526 m .35493 .61795 L .35842 .62009 L p .707 .577 .707 r
F P
0 g
s
.15724 .77078 m .15608 .78833 L .16792 .80102 L p .707 .577 .707 r
F P
0 g
s
.15782 .71171 m .15943 .74956 L .16243 .75496 L p .707 .577 .707 r
F P
0 g
s
.35711 .79407 m .35827 .77652 L .35043 .78865 L p .707 .577 .707 r
F P
0 g
s
.36019 .73798 m .35858 .70013 L .36158 .70553 L p .707 .577 .707 r
F P
0 g
s
.35493 .61795 m .35988 .67526 L .34678 .67415 L p .707 .577 .707 r
F P
0 g
s
.35827 .77652 m .35711 .79407 L .35502 .78103 L p .707 .577 .707 r
F P
0 g
s
.35502 .78103 m .35618 .76348 L .35827 .77652 L p .707 .577 .707 r
F P
0 g
s
.35858 .70013 m .36019 .73798 L .34751 .73341 L p .707 .577 .707 r
F P
0 g
s
.34751 .73341 m .3459 .69556 L .35858 .70013 L p .707 .577 .707 r
F P
0 g
s
.35618 .76348 m .35502 .78103 L .34319 .76834 L p .707 .577 .707 r
F P
0 g
s
.34319 .76834 m .34435 .75079 L .35618 .76348 L p .707 .577 .707 r
F P
0 g
s
.35575 .28138 m .35575 .78327 L .36287 .79523 L p .707 .577 .707 r
F P
0 g
s
.35575 .78327 m .35575 .28138 L .36276 .26942 L p .707 .577 .707 r
F P
0 g
s
.64424 .28128 m .64424 .78317 L .63713 .77121 L p .707 .577 .707 r
F P
0 g
s
.63713 .77121 m .63713 .26932 L .64424 .28128 L p .707 .577 .707 r
F P
0 g
s
.35043 .78865 m .34927 .8062 L .35711 .79407 L p .707 .577 .707 r
F P
0 g
s
.16001 .69413 m .15505 .63682 L .16152 .63386 L p .707 .577 .707 r
F P
0 g
s
.16152 .63386 m .16647 .69117 L .16001 .69413 L p .707 .577 .707 r
F P
0 g
s
.15608 .78833 m .15724 .77078 L .15515 .75774 L p .707 .577 .707 r
F P
0 g
s
.15943 .74956 m .15782 .71171 L .16479 .706 L p .707 .577 .707 r
F P
0 g
s
.15515 .75774 m .15399 .77529 L .15608 .78833 L p .707 .577 .707 r
F P
0 g
s
.34678 .67415 m .34182 .61684 L .35493 .61795 L p .707 .577 .707 r
F P
0 g
s
.16479 .706 m .1664 .74385 L .15943 .74956 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16647 .69117 m .16152 .63386 L .1773 .63037 L p .707 .577 .707 r
F P
0 g
s
.1773 .63037 m .18225 .68769 L .16647 .69117 L p .707 .577 .707 r
F P
0 g
s
.15399 .77529 m .15515 .75774 L .163 .74561 L p .707 .577 .707 r
F P
0 g
s
.36276 .7713 m .36276 .26942 L .38319 .25862 L p .707 .577 .707 r
F P
0 g
s
.36276 .26942 m .36276 .7713 L .35575 .78327 L p .707 .577 .707 r
F P
0 g
s
.63713 .26932 m .63713 .77121 L .61659 .76043 L p .707 .577 .707 r
F P
0 g
s
.61659 .76043 m .61659 .25854 L .63713 .26932 L p .707 .577 .707 r
F P
0 g
s
.163 .74561 m .16183 .76316 L .15399 .77529 L p .707 .577 .707 r
F P
0 g
s
.1664 .74385 m .16479 .706 L .18105 .70056 L p .707 .577 .707 r
F P
0 g
s
.34182 .61684 m .34678 .67415 L .32534 .67418 L p .707 .577 .707 r
F P
0 g
s
.32534 .67418 m .32039 .61686 L .34182 .61684 L p .707 .577 .707 r
F P
0 g
s
.18105 .70056 m .18266 .73841 L .1664 .74385 L p .707 .577 .707 r
F P
0 g
s
.18225 .68769 m .1773 .63037 L .20085 .6267 L p .707 .577 .707 r
F P
0 g
s
.20085 .6267 m .20581 .68401 L .18225 .68769 L p .707 .577 .707 r
F P
0 g
s
.3459 .69556 m .34751 .73341 L .32639 .73012 L p .707 .577 .707 r
F P
0 g
s
.32639 .73012 m .32478 .69227 L .3459 .69556 L p .707 .577 .707 r
F P
0 g
s
.16183 .76316 m .163 .74561 L .18002 .73559 L p .707 .577 .707 r
F P
0 g
s
.32039 .61686 m .32534 .67418 L .29768 .67534 L p .707 .577 .707 r
F P
0 g
s
.29768 .67534 m .29273 .61802 L .32039 .61686 L p .707 .577 .707 r
F P
0 g
s
.18266 .73841 m .18105 .70056 L .20501 .6959 L p .707 .577 .707 r
F P
0 g
s
.18002 .73559 m .17885 .75314 L .16183 .76316 L p .707 .577 .707 r
F P
0 g
s
.38319 .25862 m .38319 .76051 L .36276 .7713 L p .707 .577 .707 r
F P
0 g
s
.38319 .76051 m .38319 .25862 L .41506 .25005 L p .707 .577 .707 r
F P
0 g
s
.61659 .25854 m .61659 .76043 L .58463 .75188 L p .707 .577 .707 r
F P
0 g
s
.58463 .75188 m .58463 .24999 L .61659 .25854 L p .707 .577 .707 r
F P
0 g
s
.20581 .68401 m .20085 .6267 L .22988 .62319 L p .707 .577 .707 r
F P
0 g
s
.20501 .6959 m .20662 .73375 L .18266 .73841 L p .707 .577 .707 r
F P
0 g
s
.34435 .75079 m .34319 .76834 L .32278 .75725 L p .707 .577 .707 r
F P
0 g
s
.32278 .75725 m .32394 .7397 L .34435 .75079 L p .707 .577 .707 r
F P
0 g
s
.22988 .62319 m .23483 .68051 L .20581 .68401 L p .707 .577 .707 r
F P
0 g
s
.32478 .69227 m .32639 .73012 L .2989 .72843 L p .707 .577 .707 r
F P
0 g
s
.2989 .72843 m .29729 .69058 L .32478 .69227 L p .707 .577 .707 r
F P
0 g
s
.73351 .67394 m .73846 .62259 L .70727 .61728 L p .707 .577 .707 r
F P
0 g
s
.73846 .62259 m .73351 .67394 L .76516 .6748 L p .707 .577 .707 r
F P
0 g
s
.76516 .6748 m .77012 .62345 L .73846 .62259 L p .707 .577 .707 r
F P
0 g
s
.29273 .61802 m .29768 .67534 L .26649 .67752 L p .707 .577 .707 r
F P
0 g
s
.26649 .67752 m .26154 .62021 L .29273 .61802 L p .707 .577 .707 r
F P
0 g
s
.77012 .62345 m .76516 .6748 L .79419 .67111 L p .707 .577 .707 r
F P
0 g
s
.79419 .67111 m .79914 .61977 L .77012 .62345 L p .707 .577 .707 r
F P
0 g
s
.70232 .66862 m .70727 .61728 L .67961 .60803 L p .707 .577 .707 r
F P
0 g
s
.70727 .61728 m .70232 .66862 L .73351 .67394 L p .707 .577 .707 r
F P
0 g
s
.23483 .68051 m .22988 .62319 L .26154 .62021 L p .707 .577 .707 r
F P
0 g
s
.17885 .75314 m .18002 .73559 L .20454 .72866 L p .707 .577 .707 r
F P
0 g
s
.20662 .73375 m .20501 .6959 L .23432 .69249 L p .707 .577 .707 r
F P
0 g
s
.26154 .62021 m .26649 .67752 L .23483 .68051 L p .707 .577 .707 r
F P
0 g
s
.20454 .72866 m .20338 .74621 L .17885 .75314 L p .707 .577 .707 r
F P
0 g
s
.23432 .69249 m .23593 .73034 L .20662 .73375 L p .707 .577 .707 r
F P
0 g
s
.29729 .69058 m .2989 .72843 L .26773 .7285 L p .707 .577 .707 r
F P
0 g
s
.26773 .7285 m .26612 .69065 L .29729 .69058 L p .707 .577 .707 r
F P
0 g
s
.79914 .61977 m .79419 .67111 L .81775 .66325 L p .707 .577 .707 r
F P
0 g
s
.81775 .66325 m .8227 .61191 L .79914 .61977 L p .707 .577 .707 r
F P
0 g
s
.32394 .7397 m .32278 .75725 L .29579 .74885 L p .707 .577 .707 r
F P
0 g
s
.29579 .74885 m .29695 .7313 L .32394 .7397 L p .707 .577 .707 r
F P
0 g
s
.67466 .65937 m .67961 .60803 L .65817 .59574 L p .707 .577 .707 r
F P
0 g
s
.67961 .60803 m .67466 .65937 L .70232 .66862 L p .707 .577 .707 r
F P
0 g
s
.23593 .73034 m .23432 .69249 L .26612 .69065 L p .707 .577 .707 r
F P
0 g
s
.41506 .75193 m .41506 .25005 L .45525 .24453 L p .707 .577 .707 r
F P
0 g
s
.41506 .25005 m .41506 .75193 L .38319 .76051 L p .707 .577 .707 r
F P
0 g
s
.58463 .24999 m .58463 .75188 L .5444 .74639 L p .707 .577 .707 r
F P
0 g
s
.5444 .74639 m .5444 .2445 L .58463 .24999 L p .707 .577 .707 r
F P
0 g
s
.26612 .69065 m .26773 .7285 L .23593 .73034 L p .707 .577 .707 r
F P
0 g
s
.73227 .72599 m .73388 .69014 L .70271 .68641 L p .707 .577 .707 r
F P
0 g
s
.73388 .69014 m .73227 .72599 L .76406 .72615 L p .707 .577 .707 r
F P
0 g
s
.76406 .72615 m .76567 .6903 L .73388 .69014 L p .707 .577 .707 r
F P
0 g
s
.20338 .74621 m .20454 .72866 L .23418 .72549 L p .707 .577 .707 r
F P
0 g
s
.76567 .6903 m .76406 .72615 L .79338 .72272 L p .707 .577 .707 r
F P
0 g
s
.79338 .72272 m .79499 .68687 L .76567 .6903 L p .707 .577 .707 r
F P
0 g
s
.73514 .74825 m .73398 .72921 L .70305 .73008 L p .707 .577 .707 r
F P
0 g
s
.73398 .72921 m .73514 .74825 L .76698 .74608 L p .707 .577 .707 r
F P
0 g
s
.76698 .74608 m .76582 .72703 L .73398 .72921 L p .707 .577 .707 r
F P
0 g
s
.7011 .72226 m .70271 .68641 L .67522 .67947 L p .707 .577 .707 r
F P
0 g
s
.70271 .68641 m .7011 .72226 L .73227 .72599 L p .707 .577 .707 r
F P
0 g
s
.76582 .72703 m .76698 .74608 L .79662 .74281 L p .707 .577 .707 r
F P
0 g
s
.79662 .74281 m .79545 .72377 L .76582 .72703 L p .707 .577 .707 r
F P
0 g
s
.70305 .73008 m .70421 .74912 L .73514 .74825 L p .707 .577 .707 r
F P
0 g
s
.23418 .72549 m .23302 .74304 L .20338 .74621 L p .707 .577 .707 r
F P
0 g
s
.29695 .7313 m .29579 .74885 L .26486 .74395 L p .707 .577 .707 r
F P
0 g
s
.26486 .74395 m .26602 .7264 L .29695 .7313 L p .707 .577 .707 r
F P
0 g
s
.23302 .74304 m .23418 .72549 L .26602 .7264 L p .707 .577 .707 r
F P
0 g
s
.70421 .74912 m .70305 .73008 L .67606 .72955 L p .707 .577 .707 r
F P
0 g
s
.8227 .61191 m .81775 .66325 L .83353 .65198 L p .707 .577 .707 r
F P
0 g
s
.83353 .65198 m .83848 .60064 L .8227 .61191 L p .707 .577 .707 r
F P
0 g
s
.65322 .64709 m .65817 .59574 L .64507 .58163 L p .707 .577 .707 r
F P
0 g
s
.65817 .59574 m .65322 .64709 L .67466 .65937 L p .707 .577 .707 r
F P
0 g
s
.26602 .7264 m .26486 .74395 L .23302 .74304 L p .707 .577 .707 r
F P
0 g
s
.67606 .72955 m .67722 .7486 L .70421 .74912 L p .707 .577 .707 r
F P
0 g
s
.79499 .68687 m .79338 .72272 L .81734 .71604 L p .707 .577 .707 r
F P
0 g
s
.81734 .71604 m .81895 .68019 L .79499 .68687 L p .707 .577 .707 r
F P
0 g
s
.45525 .74642 m .45525 .24453 L .49981 .24262 L p .707 .577 .707 r
F P
0 g
s
.45525 .24453 m .45525 .74642 L .41506 .75193 L p .707 .577 .707 r
F P
0 g
s
.5444 .2445 m .5444 .74639 L .49981 .74451 L p .707 .577 .707 r
F P
0 g
s
.49981 .74451 m .49981 .24262 L .5444 .2445 L p .707 .577 .707 r
F P
0 g
s
.79545 .72377 m .79662 .74281 L .82114 .73877 L p .707 .577 .707 r
F P
0 g
s
.82114 .73877 m .81998 .71973 L .79545 .72377 L p .707 .577 .707 r
F P
0 g
s
.67522 .67947 m .67361 .71531 L .7011 .72226 L p .707 .577 .707 r
F P
0 g
s
.67361 .71531 m .67522 .67947 L .6541 .67 L p .707 .577 .707 r
F P
0 g
s
.49981 .24262 m .49981 .74451 L .45525 .74642 L p .707 .577 .707 r
F P
0 g
s
.67722 .7486 m .67606 .72955 L .65565 .72769 L p .707 .577 .707 r
F P
0 g
s
.65565 .72769 m .65681 .74673 L .67722 .7486 L p .707 .577 .707 r
F P
0 g
s
.6541 .67 m .65249 .70584 L .67361 .71531 L p .707 .577 .707 r
F P
0 g
s
.81895 .68019 m .81734 .71604 L .8336 .70675 L p .707 .577 .707 r
F P
0 g
s
.8336 .70675 m .83521 .6709 L .81895 .68019 L p .707 .577 .707 r
F P
0 g
s
.81998 .71973 m .82114 .73877 L .83816 .73436 L p .707 .577 .707 r
F P
0 g
s
.83816 .73436 m .837 .71531 L .81998 .71973 L p .707 .577 .707 r
F P
0 g
s
.83848 .60064 m .83353 .65198 L .83999 .6384 L p .707 .577 .707 r
F P
0 g
s
.83999 .6384 m .84494 .58705 L .83848 .60064 L p .707 .577 .707 r
F P
0 g
s
.64012 .63297 m .64507 .58163 L .64158 .56707 L p .707 .577 .707 r
F P
0 g
s
.64507 .58163 m .64012 .63297 L .65322 .64709 L p .707 .577 .707 r
F P
0 g
s
.65249 .70584 m .6541 .67 L .64142 .65892 L p .707 .577 .707 r
F P
0 g
s
.65681 .74673 m .65565 .72769 L .64382 .72467 L p .707 .577 .707 r
F P
0 g
s
.64382 .72467 m .64498 .74371 L .65681 .74673 L p .707 .577 .707 r
F P
0 g
s
.64142 .65892 m .63981 .69477 L .65249 .70584 L p .707 .577 .707 r
F P
0 g
s
.83521 .6709 m .8336 .70675 L .84057 .69578 L p .707 .577 .707 r
F P
0 g
s
.84057 .69578 m .84218 .65993 L .83521 .6709 L p .707 .577 .707 r
F P
0 g
s
.837 .71531 m .83816 .73436 L .84601 .72999 L p .707 .577 .707 r
F P
0 g
s
.84601 .72999 m .84485 .71095 L .837 .71531 L p .707 .577 .707 r
F P
0 g
s
.64158 .56707 m .63662 .61842 L .64012 .63297 L p .707 .577 .707 r
F P
0 g
s
.84494 .58705 m .83999 .6384 L .8365 .62384 L p .707 .577 .707 r
F P
0 g
s
.8365 .62384 m .84145 .5725 L .84494 .58705 L p .707 .577 .707 r
F P
0 g
s
.63662 .61842 m .64158 .56707 L .64804 .55349 L p .707 .577 .707 r
F P
0 g
s
.63981 .69477 m .64142 .65892 L .63842 .64733 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64498 .74371 m .64382 .72467 L .64172 .72079 L p .707 .577 .707 r
F P
0 g
s
.63842 .64733 m .63681 .68318 L .63981 .69477 L p .707 .577 .707 r
F P
0 g
s
.64172 .72079 m .64288 .73983 L .64498 .74371 L p .707 .577 .707 r
F P
0 g
s
.84218 .65993 m .84057 .69578 L .83757 .68418 L p .707 .577 .707 r
F P
0 g
s
.83757 .68418 m .83918 .64834 L .84218 .65993 L p .707 .577 .707 r
F P
0 g
s
.64804 .55349 m .64308 .60484 L .63662 .61842 L p .707 .577 .707 r
F P
0 g
s
.84145 .5725 m .8365 .62384 L .82339 .60973 L p .707 .577 .707 r
F P
0 g
s
.82339 .60973 m .82835 .55838 L .84145 .5725 L p .707 .577 .707 r
F P
0 g
s
.84485 .71095 m .84601 .72999 L .84391 .72611 L p .707 .577 .707 r
F P
0 g
s
.84391 .72611 m .84275 .70707 L .84485 .71095 L p .707 .577 .707 r
F P
0 g
s
.64308 .60484 m .64804 .55349 L .66382 .54222 L p .707 .577 .707 r
F P
0 g
s
.63681 .68318 m .63842 .64733 L .64539 .63636 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38766 .61082 m .39902 .55522 L .36837 .54794 L p .707 .577 .707 r
F P
0 g
s
.39902 .55522 m .38766 .61082 L .41883 .61637 L p .707 .577 .707 r
F P
0 g
s
.41883 .61637 m .43019 .56076 L .39902 .55522 L p .707 .577 .707 r
F P
0 g
s
.43019 .56076 m .41883 .61637 L .44747 .61964 L p .707 .577 .707 r
F P
0 g
s
.44747 .61964 m .45884 .56403 L .43019 .56076 L p .707 .577 .707 r
F P
0 g
s
.64539 .63636 m .64378 .6722 L .63681 .68318 L p .707 .577 .707 r
F P
0 g
s
.35701 .60354 m .36837 .54794 L .34124 .53964 L p .707 .577 .707 r
F P
0 g
s
.36837 .54794 m .35701 .60354 L .38766 .61082 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64288 .73983 m .64172 .72079 L .64957 .71642 L p .707 .577 .707 r
F P
0 g
s
.64957 .71642 m .65073 .73547 L .64288 .73983 L p .707 .577 .707 r
F P
0 g
s
.82835 .55838 m .82339 .60973 L .80196 .59744 L p .707 .577 .707 r
F P
0 g
s
.80196 .59744 m .80691 .5461 L .82835 .55838 L p .707 .577 .707 r
F P
0 g
s
.83918 .64834 m .83757 .68418 L .82489 .67311 L p .707 .577 .707 r
F P
0 g
s
.82489 .67311 m .8265 .63726 L .83918 .64834 L p .707 .577 .707 r
F P
0 g
s
.66382 .54222 m .65887 .59356 L .64308 .60484 L p .707 .577 .707 r
F P
0 g
s
.65887 .59356 m .66382 .54222 L .68738 .53436 L p .707 .577 .707 r
F P
0 g
s
.34124 .53964 m .32988 .59524 L .35701 .60354 L p .707 .577 .707 r
F P
0 g
s
.45884 .56403 m .44747 .61964 L .47078 .62031 L p .707 .577 .707 r
F P
0 g
s
.47078 .62031 m .48215 .56471 L .45884 .56403 L p .707 .577 .707 r
F P
0 g
s
.84275 .70707 m .84391 .72611 L .83208 .72309 L p .707 .577 .707 r
F P
0 g
s
.83208 .72309 m .83092 .70405 L .84275 .70707 L p .707 .577 .707 r
F P
0 g
s
.38724 .67652 m .39099 .63924 L .35995 .63469 L p .707 .577 .707 r
F P
0 g
s
.39099 .63924 m .38724 .67652 L .41892 .67886 L p .707 .577 .707 r
F P
0 g
s
.41892 .67886 m .42267 .64159 L .39099 .63924 L p .707 .577 .707 r
F P
0 g
s
.32988 .59524 m .34124 .53964 L .3203 .53113 L p .707 .577 .707 r
F P
0 g
s
.64378 .6722 m .64539 .63636 L .66165 .62707 L p .707 .577 .707 r
F P
0 g
s
.42267 .64159 m .41892 .67886 L .44814 .67877 L p .707 .577 .707 r
F P
0 g
s
.44814 .67877 m .45188 .64149 L .42267 .64159 L p .707 .577 .707 r
F P
0 g
s
.35621 .67196 m .35995 .63469 L .33259 .62837 L p .707 .577 .707 r
F P
0 g
s
.35995 .63469 m .35621 .67196 L .38724 .67652 L p .707 .577 .707 r
F P
0 g
s
.3203 .53113 m .30893 .58673 L .32988 .59524 L p .707 .577 .707 r
F P
0 g
s
.80691 .5461 m .80196 .59744 L .7743 .58819 L p .707 .577 .707 r
F P
0 g
s
.7743 .58819 m .77925 .53685 L .80691 .5461 L p .707 .577 .707 r
F P
0 g
s
.68242 .5857 m .68738 .53436 L .7164 .53067 L p .707 .577 .707 r
F P
0 g
s
.68738 .53436 m .68242 .5857 L .65887 .59356 L p .707 .577 .707 r
F P
0 g
s
.66165 .62707 m .66004 .66292 L .64378 .6722 L p .707 .577 .707 r
F P
0 g
s
.33259 .62837 m .32885 .66564 L .35621 .67196 L p .707 .577 .707 r
F P
0 g
s
.45188 .64149 m .44814 .67877 L .47204 .67624 L p .707 .577 .707 r
F P
0 g
s
.47204 .67624 m .47578 .63896 L .45188 .64149 L p .707 .577 .707 r
F P
0 g
s
.65073 .73547 m .64957 .71642 L .66659 .71201 L p .707 .577 .707 r
F P
0 g
s
.8265 .63726 m .82489 .67311 L .80377 .66364 L p .707 .577 .707 r
F P
0 g
s
.80377 .66364 m .80538 .62779 L .8265 .63726 L p .707 .577 .707 r
F P
0 g
s
.66659 .71201 m .66775 .73105 L .65073 .73547 L p .707 .577 .707 r
F P
0 g
s
.48215 .56471 m .47078 .62031 L .48648 .61832 L p .707 .577 .707 r
F P
0 g
s
.48648 .61832 m .49784 .56272 L .48215 .56471 L p .707 .577 .707 r
F P
0 g
s
.32885 .66564 m .33259 .62837 L .31159 .6209 L p .707 .577 .707 r
F P
0 g
s
.30893 .58673 m .3203 .53113 L .30757 .52325 L p .707 .577 .707 r
F P
0 g
s
.39764 .72849 m .39492 .71048 L .36428 .71204 L p .707 .577 .707 r
F P
0 g
s
.39492 .71048 m .39764 .72849 L .42923 .72358 L p .707 .577 .707 r
F P
0 g
s
.42923 .72358 m .42651 .70557 L .39492 .71048 L p .707 .577 .707 r
F P
0 g
s
.42651 .70557 m .42923 .72358 L .45866 .71579 L p .707 .577 .707 r
F P
0 g
s
.45866 .71579 m .45594 .69778 L .42651 .70557 L p .707 .577 .707 r
F P
0 g
s
.77925 .53685 m .7743 .58819 L .74311 .58288 L p .707 .577 .707 r
F P
0 g
s
.74311 .58288 m .74806 .53153 L .77925 .53685 L p .707 .577 .707 r
F P
0 g
s
.71145 .58202 m .7164 .53067 L .74806 .53153 L p .707 .577 .707 r
F P
0 g
s
.7164 .53067 m .71145 .58202 L .68242 .5857 L p .707 .577 .707 r
F P
0 g
s
.66004 .66292 m .66165 .62707 L .68561 .62039 L p .707 .577 .707 r
F P
0 g
s
.83092 .70405 m .83208 .72309 L .81167 .72123 L p .707 .577 .707 r
F P
0 g
s
.81167 .72123 m .81051 .70218 L .83092 .70405 L p .707 .577 .707 r
F P
0 g
s
.36428 .71204 m .367 .73005 L .39764 .72849 L p .707 .577 .707 r
F P
0 g
s
.74806 .53153 m .74311 .58288 L .71145 .58202 L p .707 .577 .707 r
F P
0 g
s
.31159 .6209 m .30785 .65818 L .32885 .66564 L p .707 .577 .707 r
F P
0 g
s
.367 .73005 m .36428 .71204 L .33757 .71009 L p .707 .577 .707 r
F P
0 g
s
.30757 .52325 m .29621 .57885 L .30893 .58673 L p .707 .577 .707 r
F P
0 g
s
.45594 .69778 m .45866 .71579 L .48306 .70589 L p .707 .577 .707 r
F P
0 g
s
.48306 .70589 m .48034 .68788 L .45594 .69778 L p .707 .577 .707 r
F P
0 g
s
.47578 .63896 m .47204 .67624 L .48828 .67152 L p .707 .577 .707 r
F P
0 g
s
.48828 .67152 m .49203 .63425 L .47578 .63896 L p .707 .577 .707 r
F P
0 g
s
.33757 .71009 m .34029 .7281 L .367 .73005 L p .707 .577 .707 r
F P
0 g
s
.68561 .62039 m .684 .65623 L .66004 .66292 L p .707 .577 .707 r
F P
0 g
s
.80538 .62779 m .80377 .66364 L .77628 .6567 L p .707 .577 .707 r
F P
0 g
s
.77628 .6567 m .77789 .62085 L .80538 .62779 L p .707 .577 .707 r
F P
0 g
s
.66775 .73105 m .66659 .71201 L .69112 .70797 L p .707 .577 .707 r
F P
0 g
s
.30785 .65818 m .31159 .6209 L .299 .61301 L p .707 .577 .707 r
F P
0 g
s
.684 .65623 m .68561 .62039 L .71492 .61696 L p .707 .577 .707 r
F P
0 g
s
.69112 .70797 m .69228 .72701 L .66775 .73105 L p .707 .577 .707 r
F P
0 g
s
.49784 .56272 m .48648 .61832 L .49303 .61387 L p .707 .577 .707 r
F P
0 g
s
.49303 .61387 m .50439 .55826 L .49784 .56272 L p .707 .577 .707 r
F P
0 g
s
.34029 .7281 m .33757 .71009 L .31741 .70482 L p .707 .577 .707 r
F P
0 g
s
.29621 .57885 m .30757 .52325 L .30433 .51676 L p .707 .577 .707 r
F P
0 g
s
.48034 .68788 m .48306 .70589 L .50003 .69485 L p .707 .577 .707 r
F P
0 g
s
.50003 .69485 m .49731 .67684 L .48034 .68788 L p .707 .577 .707 r
F P
0 g
s
.81051 .70218 m .81167 .72123 L .78468 .72071 L p .707 .577 .707 r
F P
0 g
s
.78468 .72071 m .78352 .70166 L .81051 .70218 L p .707 .577 .707 r
F P
0 g
s
.299 .61301 m .29526 .65029 L .30785 .65818 L p .707 .577 .707 r
F P
0 g
s
.77789 .62085 m .77628 .6567 L .74511 .65296 L p .707 .577 .707 r
F P
0 g
s
.74511 .65296 m .74672 .61712 L .77789 .62085 L p .707 .577 .707 r
F P
0 g
s
.31741 .70482 m .32014 .72283 L .34029 .7281 L p .707 .577 .707 r
F P
0 g
s
.71331 .6528 m .71492 .61696 L .74672 .61712 L p .707 .577 .707 r
F P
0 g
s
.71492 .61696 m .71331 .6528 L .684 .65623 L p .707 .577 .707 r
F P
0 g
s
.30433 .51676 m .29297 .57236 L .29621 .57885 L p .707 .577 .707 r
F P
0 g
s
.74672 .61712 m .74511 .65296 L .71331 .6528 L p .707 .577 .707 r
F P
0 g
s
.69228 .72701 m .69112 .70797 L .72075 .7047 L p .707 .577 .707 r
F P
0 g
s
.49203 .63425 m .48828 .67152 L .49527 .66509 L p .707 .577 .707 r
F P
0 g
s
.49527 .66509 m .49902 .62781 L .49203 .63425 L p .707 .577 .707 r
F P
0 g
s
.72075 .7047 m .72191 .72375 L .69228 .72701 L p .707 .577 .707 r
F P
0 g
s
.78352 .70166 m .78468 .72071 L .75375 .72157 L p .707 .577 .707 r
F P
0 g
s
.75375 .72157 m .75259 .70253 L .78352 .70166 L p .707 .577 .707 r
F P
0 g
s
.29526 .65029 m .299 .61301 L .29606 .60549 L p .707 .577 .707 r
F P
0 g
s
.32014 .72283 m .31741 .70482 L .30578 .69676 L p .707 .577 .707 r
F P
0 g
s
.72191 .72375 m .72075 .7047 L .75259 .70253 L p .707 .577 .707 r
F P
0 g
s
.49731 .67684 m .50003 .69485 L .50792 .68374 L p .707 .577 .707 r
F P
0 g
s
.50792 .68374 m .5052 .66573 L .49731 .67684 L p .707 .577 .707 r
F P
0 g
s
.75259 .70253 m .75375 .72157 L .72191 .72375 L p .707 .577 .707 r
F P
0 g
s
.50439 .55826 m .49303 .61387 L .48978 .60738 L p .707 .577 .707 r
F P
0 g
s
.48978 .60738 m .50114 .55178 L .50439 .55826 L p .707 .577 .707 r
F P
0 g
s
.30578 .69676 m .30851 .71477 L .32014 .72283 L p .707 .577 .707 r
F P
0 g
s
.29606 .60549 m .29232 .64276 L .29526 .65029 L p .707 .577 .707 r
F P
0 g
s
.29297 .57236 m .30433 .51676 L .31087 .5123 L p .707 .577 .707 r
F P
0 g
s
.31087 .5123 m .29951 .56791 L .29297 .57236 L p .707 .577 .707 r
F P
0 g
s
.49902 .62781 m .49527 .66509 L .49233 .65756 L p .707 .577 .707 r
F P
0 g
s
.49233 .65756 m .49608 .62028 L .49902 .62781 L p .707 .577 .707 r
F P
0 g
s
.30851 .71477 m .30578 .69676 L .30382 .68668 L p .708 .578 .707 r
F P
0 g
s
.29232 .64276 m .29606 .60549 L .30305 .59905 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.5052 .66573 m .50792 .68374 L .50596 .67367 L p .708 .578 .707 r
F P
0 g
s
.50596 .67367 m .50324 .65565 L .5052 .66573 L p .708 .578 .707 r
F P
0 g
s
.30382 .68668 m .30654 .70469 L .30851 .71477 L p .708 .578 .707 r
F P
0 g
s
.50114 .55178 m .48978 .60738 L .47706 .5995 L p .707 .577 .707 r
F P
0 g
s
.47706 .5995 m .48842 .54389 L .50114 .55178 L p .707 .577 .707 r
F P
0 g
s
.30305 .59905 m .29931 .63633 L .29232 .64276 L p .707 .577 .707 r
F P
0 g
s
.29951 .56791 m .31087 .5123 L .32657 .51031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32657 .51031 m .31521 .56592 L .29951 .56791 L p .707 .577 .707 r
F P
0 g
s
.49608 .62028 m .49233 .65756 L .47975 .64967 L p .707 .577 .707 r
F P
0 g
s
.47975 .64967 m .48349 .6124 L .49608 .62028 L p .707 .577 .707 r
F P
0 g
s
.30654 .70469 m .30382 .68668 L .31171 .67557 L p .707 .577 .707 r
F P
0 g
s
.29931 .63633 m .30305 .59905 L .31929 .59434 L p .707 .577 .707 r
F P
0 g
s
.50324 .65565 m .50596 .67367 L .49433 .6656 L p .707 .577 .707 r
F P
0 g
s
.49433 .6656 m .49161 .64759 L .50324 .65565 L p .707 .577 .707 r
F P
0 g
s
.48842 .54389 m .47706 .5995 L .45611 .59099 L p .707 .577 .707 r
F P
0 g
s
.45611 .59099 m .46747 .53538 L .48842 .54389 L p .707 .577 .707 r
F P
0 g
s
.31171 .67557 m .31443 .69359 L .30654 .70469 L p .707 .577 .707 r
F P
0 g
s
.31521 .56592 m .32657 .51031 L .34988 .51099 L p .707 .577 .707 r
F P
0 g
s
.31929 .59434 m .31555 .63161 L .29931 .63633 L p .707 .577 .707 r
F P
0 g
s
.34988 .51099 m .33852 .56659 L .31521 .56592 L p .707 .577 .707 r
F P
0 g
s
.48349 .6124 m .47975 .64967 L .45875 .6422 L p .707 .577 .707 r
F P
0 g
s
.45875 .6422 m .46249 .60493 L .48349 .6124 L p .707 .577 .707 r
F P
0 g
s
.46747 .53538 m .45611 .59099 L .42898 .58269 L p .707 .577 .707 r
F P
0 g
s
.42898 .58269 m .44035 .52708 L .46747 .53538 L p .707 .577 .707 r
F P
0 g
s
.31555 .63161 m .31929 .59434 L .34319 .59181 L p .707 .577 .707 r
F P
0 g
s
.31443 .69359 m .31171 .67557 L .32869 .66453 L p .707 .577 .707 r
F P
0 g
s
.33852 .56659 m .34988 .51099 L .37853 .51426 L p .707 .577 .707 r
F P
0 g
s
.49161 .64759 m .49433 .6656 L .47417 .66033 L p .707 .577 .707 r
F P
0 g
s
.47417 .66033 m .47145 .64232 L .49161 .64759 L p .707 .577 .707 r
F P
0 g
s
.32869 .66453 m .33141 .68254 L .31443 .69359 L p .707 .577 .707 r
F P
0 g
s
.34319 .59181 m .33945 .62908 L .31555 .63161 L p .707 .577 .707 r
F P
0 g
s
.37853 .51426 m .36716 .56986 L .33852 .56659 L p .707 .577 .707 r
F P
0 g
s
.44035 .52708 m .42898 .58269 L .39833 .57541 L p .707 .577 .707 r
F P
0 g
s
.39833 .57541 m .4097 .5198 L .44035 .52708 L p .707 .577 .707 r
F P
0 g
s
.36716 .56986 m .37853 .51426 L .4097 .5198 L p .707 .577 .707 r
F P
0 g
s
.46249 .60493 m .45875 .6422 L .43139 .63588 L p .707 .577 .707 r
F P
0 g
s
.43139 .63588 m .43513 .59861 L .46249 .60493 L p .707 .577 .707 r
F P
0 g
s
.4097 .5198 m .39833 .57541 L .36716 .56986 L p .707 .577 .707 r
F P
0 g
s
.33945 .62908 m .34319 .59181 L .37241 .59171 L p .707 .577 .707 r
F P
0 g
s
.33141 .68254 m .32869 .66453 L .35308 .65463 L p .707 .577 .707 r
F P
0 g
s
.47145 .64232 m .47417 .66033 L .44747 .65838 L p .707 .577 .707 r
F P
0 g
s
.44747 .65838 m .44475 .64037 L .47145 .64232 L p .707 .577 .707 r
F P
0 g
s
.37241 .59171 m .36867 .62898 L .33945 .62908 L p .707 .577 .707 r
F P
0 g
s
.43513 .59861 m .43139 .63588 L .40035 .63133 L p .707 .577 .707 r
F P
0 g
s
.40035 .63133 m .40409 .59405 L .43513 .59861 L p .707 .577 .707 r
F P
0 g
s
.35308 .65463 m .3558 .67264 L .33141 .68254 L p .707 .577 .707 r
F P
0 g
s
.36867 .62898 m .37241 .59171 L .40409 .59405 L p .707 .577 .707 r
F P
0 g
s
.40409 .59405 m .40035 .63133 L .36867 .62898 L p .707 .577 .707 r
F P
0 g
s
.3558 .67264 m .35308 .65463 L .38251 .64685 L p .707 .577 .707 r
F P
0 g
s
.44475 .64037 m .44747 .65838 L .41682 .65994 L p .707 .577 .707 r
F P
0 g
s
.41682 .65994 m .4141 .64193 L .44475 .64037 L p .707 .577 .707 r
F P
0 g
s
.38251 .64685 m .38524 .66486 L .3558 .67264 L p .707 .577 .707 r
F P
0 g
s
.38524 .66486 m .38251 .64685 L .4141 .64193 L p .707 .577 .707 r
F P
0 g
s
.4141 .64193 m .41682 .65994 L .38524 .66486 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001VOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol@0004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`<000=JEP03001JEUYF00AJEP04001J
EUYFFUH90005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00011oo`P004eoo`00EGoo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF00002Woo1P000eYF00<005YFFUH00UYF2@00A7oo001EOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00008Ool2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
000lOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Aoo`8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000iOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8003Moo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001oo`800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Eoo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=oo`00E7oo00<005YF0000
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH015YF0P00<7oo001COol00`00FUH00002FUH50003FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002moo`00Dgoo00<005YF00000`0015YF1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF000^Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005=o
o`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH00UYF40001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02aoo`00Egoo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YF000000AJEP03001JEUYF00AJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP02FUH6000@Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002aoo`00F7oo0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00@005YFFUIJEP<0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEP00
008001Yoo`@000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo001JOol200000eYF0000
000F0003FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH2000QOol400000eYF001JEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00FGoo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF00<005YFFUH00`0000=JEP00FUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF0P005Goo0`003Woo0P001UYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001J
EUYF00=JEP8000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2000015YF000005YF0`004Woo1@003goo0P0015YF00@005YFFUIJEP8002eoo`00EGoo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
1EYF00L005YF000005YF001JEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP02000@Ool5000AOol20002FUH01000FUIJEUYF0P00;Goo001DOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF001JEP02FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH3000=Ool5000COol30003FUH2000]
Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP04001JEP00000<Ool3000F
Ool01000FUIJEUYF0P00;Goo001DOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000015YF001JEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00@0
05YFFUIJEP<0021oo`800006FUH005YF001JEP00;Goo001?Ool70003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUHB000<Ool3000025YF001JEP00FUH005YF000]Ool004Io
o`T000AJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00=JEPL000AJEP03001JEUYF00IJEP03
001JEUYF009JEP`000AJEP03001JEUYF00800003FUH007oo02aoo`00?Woo200015YF00<005YFFUH0
1UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH01`00FUIJEUYF001JEP0002eoo`00=Woo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P00;Woo000`Ool6
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH500000eYF
001JEP0600000eYF001JEP03FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009J
EP04001JEUYFFUH2000^Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEPL00003FUH005YF00D0009J
EPL000IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF0P00;Woo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP05FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
6P000eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1000;goo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUH000EJEP03001JEUYF00IJEP<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF008000YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEPH00003FUH005YF00IJEP03
001JEUYF00EJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEP0000<00003FUH005YF00MJEP03001JEUYF00AJEQ@000AJEP04001JEUYF000:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000005FUH00`00FUIJEP06FUH00`00FUIJEP04
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF00002UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF0`000eYF0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001eYF00<005YFFUH015YF10001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
009JEP80009JEP03001JEUYF00=JEP<00003FUH005YF00MJEP@000EJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000015YF000000002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<0
05YFFUH00eYF00<005YFFUH01P0015YF1@0015YF00<005YFFUH00UYF1@0017oo0P0000=JEP00FUH0
0UYF0P00;Goo000]Ool00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF1P0015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP8000YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEP04001JEUYF0005OolB000;
Ool20003FUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQ8000EJEP04001JEUYFFUH4000015YF001JEUYF2@0015YF00<005YFFUH01EYF00@005YF
FUIJEPD000EJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002FUH00`00FUIJEP030005FUH01000FUIJEP0027oo1@0057oo0`000UYF00<007ooOol0;7oo000]
Ool2FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF200000=JEP00FUH025YF00<005YFFUH00UYF
0P001EYF00D005YF000005YF00<00003FUH005YF00=JEP03001JEUYF00<00003FUH0000000h000QJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH00004FUH30003FUH01000FUIJEP002Goo0`004goo0P000eYF0`00;Woo000]Ool2FUH01@00
FUIJEUYF00000eYF200000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1@00
0Woo00<005YF000015YF00<005YF000010000UYF00<005YFFUH02EYF00<005YFFUH01EYF0P000UYF
00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0005FUH00`00FUH000030002FUH00`00Oomoo`0IOol400000eYF001JEP03FUH2000^Ool002eoo`9J
EP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP020007Ool00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP09FUH0
0`00FUIJEP03FUH20005FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00001EYF00<005YFFUH00eYF1`004Woo1@001EYF00L005YFFUIJEP00FUH0000^Ool0
02eoo`9JEP@000EJEP03001JEUYF00AJEQP0009JEPH000Ioo`03001JEP0000AJEP03001JEP0000@0
009JEP03001JEUYF00UJEP04001JEUYFFUH200000eYF001JEP04FUH2000:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH0
0UYF4P000eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`8000=JEP03001JEUYF
00=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0002FUH4
0002Ool00`00FUH00004FUH00`00FUIJEP030003FUH00`00FUIJEP09FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000^Ool;00000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00FUIJEP03FUH400000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH30006FUH00`00FUIJEP03000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000aOol4
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00
FUIJEP03FUH01P00FUIJEP00FUH000AJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF
00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEQT000=JEP8002moo`00;Woo0`000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF000005YF
00@000EJEP06001JEUYF001JEP0015YF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000L000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00H0009JEP03001JEP0000AJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH20003FUH00`00FUH00007
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEQ0000IJEP03001JEUYF
00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH00000FUH01`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00D0
05YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00D000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
1@0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P000eYF400000=JEP00
0000;7oo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YF
FUH01EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUIJEPP000=ooa8000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JER@00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP800003FUH005YF009JEQT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0002aoo`00;Goo00<005YF00000eYF00<005YF00000`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0005FUH5000015YF001JEP0015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo
00<005YF00000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000EJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YF0000031oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002eoo`04
001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP05FUH300000eYF
001JEP03FUH00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL003Moo`00;Goo0P000eYF
00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01EYF1P001UYF00<005YFFUH00P0015YF
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001JEP/000AJEP03001JEUYF009JEQ8003ioo`00
;Goo0P000eYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH01EYF20001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF20001eYF00<005YFFUH00eYF00<005YF
0000200015YF2@00D7oo000]Ool20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP02FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUH000020004FUH00`00FUIJEP03FUH00`00FUH00008Ool300000eYF001JEP02FUH00`00Oomo
o`1BOol002aoo`03001JEP00009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH000EJEP07001JEP00Ool005YF000015YF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF0`00
00=JEP00FUH015YF00<005YF000027oo0P0000=JEP0000000eYF0P00Dgoo000/Ool00`00FUH00002
0003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006Ool20003FUH00`00FUIJEP020000
0eYF001JEP03FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH20005FUH00`00FUH00006Ool200000eYF001JEP02FUH200000eYF0000
001COol002aoo`03001JEP0000aooa80015oo`800003FUH005YF009JEP03001JEP00009JEP<000UJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP<000=JEP03001JEP0000Aoo`8000=JEP03001JEUYF009JEP@005=oo`00:goo00<005YF0000<Woo
0P000eYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00FUH007oo00<0
00EJEP03001JEUYF00=JEP<005=oo`00:goo0P006goo0`005goo00H005YFFUH005YF0004FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF000005YF00001UYF00<005YFFUH00eYF00<005YF0000
Dgoo000[Ool3000IOol5000FOol00`00FUH000030004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0001COol002]oo`800003FUH0000001Mo
o`D001Moo`D000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00EJEP03001J
EUYF009JEP8005Aoo`00:goo0P000eYF00<007ooOol057oo1@0067oo0P0000=JEP00FUH00eYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
E7oo000/Ool01000FUIJEUYF0`005Goo0`0067oo0`0000=JEP00FUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Dgoo000/Ool01@00
FUIJEUYF00000UYF0P00;Woo00<005YF00000P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH015YF00<005YFFUH00P00EWoo000]Ool00`00FUH00005FUH2000ZOol3000015YF
0000000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH015YF0`00
F7oo000^Ool20005FUH01000FUH000009Woo0P000UYF0P000Woo00<005YFFUH00UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@0000=JEP00FUH015YF0P00FWoo000_Ool00`00FUIJEP03FUH01000FUIJ
EUYF0`008Goo0P0015YF0P000goo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEPL005ao
o`00<7oo0P000eYF00<005YFFUH015YF1P005goo100000=JEP00FUH00eYF00<007ooOol017oo0`00
2EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YF00000P0025YF00<005YF00000P00G7oo000bOol200000eYF001JEP06FUH00`00FUIJ
EP02FUHG0005FUH00`00FUIJEP02FUH00`00Oomoo`06Ool30007FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001JOol003Aoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF008000aoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0009JEPH000IJEP03001JEUYF00AJEP<0
05Qoo`00=goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`004goo1@0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF2`001Woo1000
0UYF00<005YFFUH015YF00@005YFFUH005Moo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P006Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000Eoo`D000]oo`<000EJEP05001JEUYFFUH0001GOol003aoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000<0029oob4000Uoo`D000ioo`8000=JEP05001JEUYF
FUH0001GOol0049ooaL003Ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00@000Ioo`<0015oo`80
0004FUH005YFFUH2001GOol0095oo`<00003FUH005YF00IJEP03001JEUYF00AJEPL001Eoo`80009J
EP8005Moo`00U7oo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF5P0000=JEP0000000P00Egoo
002GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001GOol009]oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00Egoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8005Moo`00Xgoo1`0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00FGoo002ZOol90004FUH01000FUIJEUYF1P00G7oo002cOol8001ROol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59026 .73945 m .60152 .68388 L .57109 .67648 L p .707 .577 .707 r
F P
0 g
s
.60152 .68388 m .59026 .73945 L .62154 .74514 L p .707 .577 .707 r
F P
0 g
s
.62154 .74514 m .6328 .68956 L .60152 .68388 L p .707 .577 .707 r
F P
0 g
s
.6328 .68956 m .62154 .74514 L .65059 .74855 L p .707 .577 .707 r
F P
0 g
s
.65059 .74855 m .66185 .69297 L .6328 .68956 L p .707 .577 .707 r
F P
0 g
s
.55983 .73206 m .57109 .67648 L .54448 .6681 L p .707 .577 .707 r
F P
0 g
s
.57109 .67648 m .55983 .73206 L .59026 .73945 L p .707 .577 .707 r
F P
0 g
s
.66185 .69297 m .65059 .74855 L .67458 .74936 L p .707 .577 .707 r
F P
0 g
s
.67458 .74936 m .68584 .69378 L .66185 .69297 L p .707 .577 .707 r
F P
0 g
s
.54448 .6681 m .53322 .72367 L .55983 .73206 L p .707 .577 .707 r
F P
0 g
s
.59252 .80535 m .59625 .76808 L .56525 .76349 L p .707 .577 .707 r
F P
0 g
s
.59625 .76808 m .59252 .80535 L .62421 .80773 L p .707 .577 .707 r
F P
0 g
s
.62421 .80773 m .62795 .77045 L .59625 .76808 L p .707 .577 .707 r
F P
0 g
s
.53322 .72367 m .54448 .6681 L .52429 .65954 L p .707 .577 .707 r
F P
0 g
s
.62795 .77045 m .62421 .80773 L .6535 .80766 L p .707 .577 .707 r
F P
0 g
s
.6535 .80766 m .65723 .77039 L .62795 .77045 L p .707 .577 .707 r
F P
0 g
s
.56152 .80076 m .56525 .76349 L .53798 .75714 L p .707 .577 .707 r
F P
0 g
s
.56525 .76349 m .56152 .80076 L .59252 .80535 L p .707 .577 .707 r
F P
0 g
s
.52429 .65954 m .51303 .71512 L .53322 .72367 L p .707 .577 .707 r
F P
0 g
s
.53798 .75714 m .53424 .79442 L .56152 .80076 L p .707 .577 .707 r
F P
0 g
s
.65723 .77039 m .6535 .80766 L .67751 .80516 L p .707 .577 .707 r
F P
0 g
s
.67751 .80516 m .68125 .76789 L .65723 .77039 L p .707 .577 .707 r
F P
0 g
s
.68584 .69378 m .67458 .74936 L .69115 .74749 L p .707 .577 .707 r
F P
0 g
s
.69115 .74749 m .70241 .69191 L .68584 .69378 L p .707 .577 .707 r
F P
0 g
s
.53424 .79442 m .53798 .75714 L .51711 .74965 L p .707 .577 .707 r
F P
0 g
s
.6089 .85725 m .60614 .83928 L .57512 .84145 L p .707 .577 .707 r
F P
0 g
s
.60614 .83928 m .6089 .85725 L .64033 .85172 L p .707 .577 .707 r
F P
0 g
s
.64033 .85172 m .63756 .83375 L .60614 .83928 L p .707 .577 .707 r
F P
0 g
s
.63756 .83375 m .64033 .85172 L .66908 .84339 L p .707 .577 .707 r
F P
0 g
s
.66908 .84339 m .66632 .82542 L .63756 .83375 L p .707 .577 .707 r
F P
0 g
s
.51303 .71512 m .52429 .65954 L .51251 .65166 L p .707 .577 .707 r
F P
0 g
s
.57512 .84145 m .57789 .85943 L .6089 .85725 L p .707 .577 .707 r
F P
0 g
s
.57789 .85943 m .57512 .84145 L .54755 .84007 L p .707 .577 .707 r
F P
0 g
s
.51711 .74965 m .51337 .78693 L .53424 .79442 L p .707 .577 .707 r
F P
0 g
s
.51251 .65166 m .50125 .70724 L .51303 .71512 L p .707 .577 .707 r
F P
0 g
s
.66632 .82542 m .66908 .84339 L .69235 .83307 L p .707 .577 .707 r
F P
0 g
s
.69235 .83307 m .68959 .8151 L .66632 .82542 L p .707 .577 .707 r
F P
0 g
s
.54755 .84007 m .55031 .85804 L .57789 .85943 L p .707 .577 .707 r
F P
0 g
s
.68125 .76789 m .67751 .80516 L .69389 .80047 L p .707 .577 .707 r
F P
0 g
s
.69389 .80047 m .69763 .76319 L .68125 .76789 L p .707 .577 .707 r
F P
0 g
s
.70241 .69191 m .69115 .74749 L .69869 .74312 L p .707 .577 .707 r
F P
0 g
s
.69869 .74312 m .70995 .68754 L .70241 .69191 L p .707 .577 .707 r
F P
0 g
s
.51337 .78693 m .51711 .74965 L .50467 .74176 L p .707 .577 .707 r
F P
0 g
s
.55031 .85804 m .54755 .84007 L .52612 .83526 L p .707 .577 .707 r
F P
0 g
s
.52612 .83526 m .52888 .85323 L .55031 .85804 L p .707 .577 .707 r
F P
0 g
s
.50467 .74176 m .50094 .77904 L .51337 .78693 L p .707 .577 .707 r
F P
0 g
s
.50125 .70724 m .51251 .65166 L .51027 .64522 L p .707 .577 .707 r
F P
0 g
s
.68959 .8151 m .69235 .83307 L .70786 .82177 L p .707 .577 .707 r
F P
0 g
s
.70786 .82177 m .7051 .80379 L .68959 .8151 L p .707 .577 .707 r
F P
0 g
s
.69763 .76319 m .69389 .80047 L .70105 .79404 L p .707 .577 .707 r
F P
0 g
s
.70105 .79404 m .70479 .75677 L .69763 .76319 L p .707 .577 .707 r
F P
0 g
s
.51027 .64522 m .49901 .70079 L .50125 .70724 L p .707 .577 .707 r
F P
0 g
s
.52888 .85323 m .52612 .83526 L .51293 .8275 L p .707 .577 .707 r
F P
0 g
s
.50094 .77904 m .50467 .74176 L .5019 .73423 L p .707 .577 .707 r
F P
0 g
s
.70995 .68754 m .69869 .74312 L .69646 .73667 L p .707 .577 .707 r
F P
0 g
s
.69646 .73667 m .70772 .6811 L .70995 .68754 L p .707 .577 .707 r
F P
0 g
s
.51293 .8275 m .51569 .84547 L .52888 .85323 L p .707 .577 .707 r
F P
0 g
s
.7051 .80379 m .70786 .82177 L .71409 .81059 L p .707 .577 .707 r
F P
0 g
s
.71409 .81059 m .71132 .79262 L .7051 .80379 L p .707 .577 .707 r
F P
0 g
s
.48073 .82158 m .48073 .31969 L .4375 .31621 L p .707 .577 .707 r
F P
0 g
s
.5019 .73423 m .49816 .77151 L .50094 .77904 L p .707 .577 .707 r
F P
0 g
s
.49901 .70079 m .51027 .64522 L .51781 .64085 L p .707 .577 .707 r
F P
0 g
s
.51781 .64085 m .50655 .69642 L .49901 .70079 L p .707 .577 .707 r
F P
0 g
s
.51569 .84547 m .51293 .8275 L .50927 .81754 L p .707 .577 .707 r
F P
0 g
s
.50927 .81754 m .51203 .83551 L .51569 .84547 L p .707 .577 .707 r
F P
0 g
s
.49816 .77151 m .5019 .73423 L .50906 .72781 L p .707 .577 .707 r
F P
0 g
s
.50906 .72781 m .50532 .76508 L .49816 .77151 L p .707 .577 .707 r
F P
0 g
s
.50655 .69642 m .51781 .64085 L .53439 .63897 L p .707 .577 .707 r
F P
0 g
s
.53439 .63897 m .52313 .69455 L .50655 .69642 L p .707 .577 .707 r
F P
0 g
s
.51203 .83551 m .50927 .81754 L .5155 .80636 L p .707 .577 .707 r
F P
0 g
s
.5155 .80636 m .51826 .82433 L .51203 .83551 L p .707 .577 .707 r
F P
0 g
s
.50532 .76508 m .50906 .72781 L .52544 .72312 L p .707 .577 .707 r
F P
0 g
s
.52544 .72312 m .5217 .76039 L .50532 .76508 L p .707 .577 .707 r
F P
0 g
s
.51826 .82433 m .5155 .80636 L .531 .79506 L p .707 .577 .707 r
F P
0 g
s
.531 .79506 m .53377 .81303 L .51826 .82433 L p .707 .577 .707 r
F P
0 g
s
.48073 .31969 m .48073 .82158 L .52585 .8213 L p .707 .577 .707 r
F P
0 g
s
.52313 .69455 m .53439 .63897 L .55838 .63979 L p .707 .577 .707 r
F P
0 g
s
.55838 .63979 m .54712 .69536 L .52313 .69455 L p .707 .577 .707 r
F P
0 g
s
.5217 .76039 m .52544 .72312 L .54945 .72062 L p .707 .577 .707 r
F P
0 g
s
.54945 .72062 m .54571 .75789 L .5217 .76039 L p .707 .577 .707 r
F P
0 g
s
.52585 .8213 m .52585 .31941 L .48073 .31969 L p .707 .577 .707 r
F P
0 g
s
.54712 .69536 m .55838 .63979 L .58743 .6432 L p .707 .577 .707 r
F P
0 g
s
.58743 .6432 m .57617 .69877 L .54712 .69536 L p .707 .577 .707 r
F P
0 g
s
.54571 .75789 m .54945 .72062 L .57874 .72055 L p .707 .577 .707 r
F P
0 g
s
.53377 .81303 m .531 .79506 L .55427 .78474 L p .707 .577 .707 r
F P
0 g
s
.55427 .78474 m .55704 .80271 L .53377 .81303 L p .707 .577 .707 r
F P
0 g
s
.57874 .72055 m .575 .75783 L .54571 .75789 L p .707 .577 .707 r
F P
0 g
s
.55704 .80271 m .55427 .78474 L .58303 .77641 L p .707 .577 .707 r
F P
0 g
s
.58303 .77641 m .58579 .79438 L .55704 .80271 L p .707 .577 .707 r
F P
0 g
s
.52585 .31941 m .52585 .8213 L .56844 .81729 L p .707 .577 .707 r
F P
0 g
s
.56844 .81729 m .56844 .3154 L .52585 .31941 L p .707 .577 .707 r
F P
0 g
s
.4375 .8181 m .4375 .31621 L .40039 .30932 L p .707 .577 .707 r
F P
0 g
s
.4375 .31621 m .4375 .8181 L .48073 .82158 L p .707 .577 .707 r
F P
0 g
s
.70479 .75677 m .70105 .79404 L .69827 .78652 L p .707 .577 .707 r
F P
0 g
s
.69827 .78652 m .70201 .74924 L .70479 .75677 L p .707 .577 .707 r
F P
0 g
s
.57617 .69877 m .58743 .6432 L .6187 .64888 L p .707 .577 .707 r
F P
0 g
s
.6187 .64888 m .60744 .70446 L .57617 .69877 L p .707 .577 .707 r
F P
0 g
s
.575 .75783 m .57874 .72055 L .61043 .72293 L p .707 .577 .707 r
F P
0 g
s
.61043 .72293 m .60669 .7602 L .575 .75783 L p .707 .577 .707 r
F P
0 g
s
.58579 .79438 m .58303 .77641 L .61445 .77088 L p .707 .577 .707 r
F P
0 g
s
.61445 .77088 m .61721 .78885 L .58579 .79438 L p .707 .577 .707 r
F P
0 g
s
.56844 .3154 m .56844 .81729 L .60432 .80995 L p .707 .577 .707 r
F P
0 g
s
.60432 .80995 m .60432 .30806 L .56844 .3154 L p .707 .577 .707 r
F P
0 g
s
.70772 .6811 m .69646 .73667 L .68467 .72879 L p .707 .577 .707 r
F P
0 g
s
.68467 .72879 m .69593 .67321 L .70772 .6811 L p .707 .577 .707 r
F P
0 g
s
.71132 .79262 m .71409 .81059 L .71043 .80063 L p .707 .577 .707 r
F P
0 g
s
.71043 .80063 m .70766 .78266 L .71132 .79262 L p .707 .577 .707 r
F P
0 g
s
.25009 .72919 m .25494 .67795 L .22397 .67223 L p .707 .577 .707 r
F P
0 g
s
.25494 .67795 m .25009 .72919 L .28185 .73045 L p .707 .577 .707 r
F P
0 g
s
.28185 .73045 m .2867 .67921 L .25494 .67795 L p .707 .577 .707 r
F P
0 g
s
.2867 .67921 m .28185 .73045 L .31129 .72712 L p .707 .577 .707 r
F P
0 g
s
.31129 .72712 m .31614 .67588 L .2867 .67921 L p .707 .577 .707 r
F P
0 g
s
.21913 .72347 m .22397 .67223 L .19683 .6626 L p .707 .577 .707 r
F P
0 g
s
.22397 .67223 m .21913 .72347 L .25009 .72919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.40039 .81121 m .40039 .30932 L .37302 .29969 L p .707 .577 .707 r
F P
0 g
s
.40039 .30932 m .40039 .81121 L .4375 .8181 L p .707 .577 .707 r
F P
0 g
s
.64913 .65628 m .63787 .71185 L .60744 .70446 L p .707 .577 .707 r
F P
0 g
s
.60744 .70446 m .6187 .64888 L .64913 .65628 L p .707 .577 .707 r
F P
0 g
s
.64143 .72752 m .63769 .76479 L .60669 .7602 L p .707 .577 .707 r
F P
0 g
s
.60669 .7602 m .61043 .72293 L .64143 .72752 L p .707 .577 .707 r
F P
0 g
s
.64547 .7687 m .64823 .78667 L .61721 .78885 L p .707 .577 .707 r
F P
0 g
s
.61721 .78885 m .61445 .77088 L .64547 .7687 L p .707 .577 .707 r
F P
0 g
s
.60432 .30806 m .60432 .80995 L .63 .79999 L p .707 .577 .707 r
F P
0 g
s
.63 .79999 m .63 .2981 L .60432 .30806 L p .707 .577 .707 r
F P
0 g
s
.70201 .74924 m .69827 .78652 L .68584 .77862 L p .707 .577 .707 r
F P
0 g
s
.68584 .77862 m .68958 .74135 L .70201 .74924 L p .707 .577 .707 r
F P
0 g
s
.31614 .67588 m .31129 .72712 L .33552 .71952 L p .707 .577 .707 r
F P
0 g
s
.33552 .71952 m .34037 .66829 L .31614 .67588 L p .707 .577 .707 r
F P
0 g
s
.19198 .71384 m .19683 .6626 L .17615 .65001 L p .707 .577 .707 r
F P
0 g
s
.19683 .6626 m .19198 .71384 L .21913 .72347 L p .707 .577 .707 r
F P
0 g
s
.69593 .67321 m .68467 .72879 L .66449 .72024 L p .707 .577 .707 r
F P
0 g
s
.66449 .72024 m .67575 .66466 L .69593 .67321 L p .707 .577 .707 r
F P
0 g
s
.25152 .78121 m .25313 .74537 L .22199 .74158 L p .707 .577 .707 r
F P
0 g
s
.25313 .74537 m .25152 .78121 L .28334 .78143 L p .707 .577 .707 r
F P
0 g
s
.28334 .78143 m .28494 .74559 L .25313 .74537 L p .707 .577 .707 r
F P
0 g
s
.28494 .74559 m .28334 .78143 L .31271 .77805 L p .707 .577 .707 r
F P
0 g
s
.31271 .77805 m .31432 .74221 L .28494 .74559 L p .707 .577 .707 r
F P
0 g
s
.26038 .80375 m .25918 .78472 L .22788 .78585 L p .707 .577 .707 r
F P
0 g
s
.25918 .78472 m .26038 .80375 L .29206 .80128 L p .707 .577 .707 r
F P
0 g
s
.29206 .80128 m .29086 .78225 L .25918 .78472 L p .707 .577 .707 r
F P
0 g
s
.70766 .78266 m .71043 .80063 L .69723 .79287 L p .707 .577 .707 r
F P
0 g
s
.69723 .79287 m .69447 .7749 L .70766 .78266 L p .707 .577 .707 r
F P
0 g
s
.22039 .77742 m .22199 .74158 L .19459 .73459 L p .707 .577 .707 r
F P
0 g
s
.22199 .74158 m .22039 .77742 L .25152 .78121 L p .707 .577 .707 r
F P
0 g
s
.22788 .78585 m .22908 .80488 L .26038 .80375 L p .707 .577 .707 r
F P
0 g
s
.29086 .78225 m .29206 .80128 L .32102 .79773 L p .707 .577 .707 r
F P
0 g
s
.32102 .79773 m .31981 .7787 L .29086 .78225 L p .707 .577 .707 r
F P
0 g
s
.22908 .80488 m .22788 .78585 L .20002 .78554 L p .707 .577 .707 r
F P
0 g
s
.34037 .66829 m .33552 .71952 L .35218 .70841 L p .707 .577 .707 r
F P
0 g
s
.35218 .70841 m .35703 .65718 L .34037 .66829 L p .707 .577 .707 r
F P
0 g
s
.20002 .78554 m .20123 .80457 L .22908 .80488 L p .707 .577 .707 r
F P
0 g
s
.31432 .74221 m .31271 .77805 L .33679 .7714 L p .707 .577 .707 r
F P
0 g
s
.33679 .7714 m .33839 .73556 L .31432 .74221 L p .707 .577 .707 r
F P
0 g
s
.1713 .70125 m .17615 .65001 L .16398 .63569 L p .707 .577 .707 r
F P
0 g
s
.17615 .65001 m .1713 .70125 L .19198 .71384 L p .707 .577 .707 r
F P
0 g
s
.37302 .80158 m .37302 .29969 L .35809 .28827 L p .707 .577 .707 r
F P
0 g
s
.37302 .29969 m .37302 .80158 L .40039 .81121 L p .707 .577 .707 r
F P
0 g
s
.68958 .74135 m .68584 .77862 L .66497 .77114 L p .707 .577 .707 r
F P
0 g
s
.66497 .77114 m .6687 .73386 L .68958 .74135 L p .707 .577 .707 r
F P
0 g
s
.19459 .73459 m .19299 .77043 L .22039 .77742 L p .707 .577 .707 r
F P
0 g
s
.31981 .7787 m .32102 .79773 L .34442 .79343 L p .707 .577 .707 r
F P
0 g
s
.34442 .79343 m .34322 .7744 L .31981 .7787 L p .707 .577 .707 r
F P
0 g
s
.19299 .77043 m .19459 .73459 L .1736 .72508 L p .707 .577 .707 r
F P
0 g
s
.67575 .66466 m .66449 .72024 L .63787 .71185 L p .707 .577 .707 r
F P
0 g
s
.63787 .71185 m .64913 .65628 L .67575 .66466 L p .707 .577 .707 r
F P
0 g
s
.6687 .73386 m .66497 .77114 L .63769 .76479 L p .707 .577 .707 r
F P
0 g
s
.63769 .76479 m .64143 .72752 L .6687 .73386 L p .707 .577 .707 r
F P
0 g
s
.63 .2981 m .63 .79999 L .64295 .78839 L p .707 .577 .707 r
F P
0 g
s
.64295 .78839 m .64295 .2865 L .63 .2981 L p .707 .577 .707 r
F P
0 g
s
.20123 .80457 m .20002 .78554 L .17834 .78381 L p .707 .577 .707 r
F P
0 g
s
.17834 .78381 m .17954 .80284 L .20123 .80457 L p .707 .577 .707 r
F P
0 g
s
.69447 .7749 m .69723 .79287 L .6758 .78806 L p .707 .577 .707 r
F P
0 g
s
.6758 .78806 m .67304 .77009 L .69447 .7749 L p .707 .577 .707 r
F P
0 g
s
.1736 .72508 m .17199 .76092 L .19299 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .73556 m .33679 .7714 L .35319 .76214 L p .707 .577 .707 r
F P
0 g
s
.35319 .76214 m .3548 .7263 L .33839 .73556 L p .707 .577 .707 r
F P
0 g
s
.35703 .65718 m .35218 .70841 L .35964 .69487 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .36449 .64364 L .35703 .65718 L p .707 .577 .707 r
F P
0 g
s
.15913 .68693 m .16398 .63569 L .1615 .62105 L p .707 .577 .707 r
F P
0 g
s
.16398 .63569 m .15913 .68693 L .1713 .70125 L p .707 .577 .707 r
F P
0 g
s
.34322 .7744 m .34442 .79343 L .35997 .7888 L p .707 .577 .707 r
F P
0 g
s
.35997 .7888 m .35877 .76977 L .34322 .7744 L p .707 .577 .707 r
F P
0 g
s
.17199 .76092 m .1736 .72508 L .16107 .71398 L p .707 .577 .707 r
F P
0 g
s
.17954 .80284 m .17834 .78381 L .16494 .78084 L p .707 .577 .707 r
F P
0 g
s
.16494 .78084 m .16614 .79987 L .17954 .80284 L p .707 .577 .707 r
F P
0 g
s
.67304 .77009 m .6758 .78806 L .64823 .78667 L p .707 .577 .707 r
F P
0 g
s
.64823 .78667 m .64547 .7687 L .67304 .77009 L p .707 .577 .707 r
F P
0 g
s
.16107 .71398 m .15947 .74982 L .17199 .76092 L p .707 .577 .707 r
F P
0 g
s
.3548 .7263 m .35319 .76214 L .36033 .75118 L p .707 .577 .707 r
F P
0 g
s
.36033 .75118 m .36193 .71533 L .3548 .7263 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .35716 .68022 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36449 .64364 m .35993 .69175 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35993 .69175 m .35964 .69487 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35705 .27616 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36201 .62899 m .36449 .64364 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35716 .68022 m .35931 .65746 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35931 .65746 m .36201 .62899 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36193 .71533 m .36033 .75118 L .35749 .73958 L p .707 .577 .707 r
F P
0 g
s
.35749 .73958 m .3591 .70373 L .36193 .71533 L p .707 .577 .707 r
F P
0 g
s
.36201 .62899 m .35716 .68022 L .34499 .6659 L p .707 .577 .707 r
F P
0 g
s
.34499 .6659 m .34984 .61467 L .36201 .62899 L p .707 .577 .707 r
F P
0 g
s
.3591 .70373 m .35749 .73958 L .34496 .72848 L p .707 .577 .707 r
F P
0 g
s
.34496 .72848 m .34657 .69263 L .3591 .70373 L p .707 .577 .707 r
F P
0 g
s
.35877 .76977 m .35997 .7888 L .36615 .78431 L p .707 .577 .707 r
F P
0 g
s
.36615 .78431 m .36495 .76528 L .35877 .76977 L p .707 .577 .707 r
F P
0 g
s
.36116 .76136 m .36236 .78039 L .34897 .77741 L p .707 .577 .707 r
F P
0 g
s
.34897 .77741 m .34777 .75839 L .36116 .76136 L p .707 .577 .707 r
F P
0 g
s
.35705 .77805 m .35809 .79015 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .27616 m .35705 .53203 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .53203 m .35705 .77805 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .79015 m .35809 .58969 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .58969 m .35809 .28827 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36495 .76528 m .36615 .78431 L .36236 .78039 L p .707 .577 .707 r
F P
0 g
s
.36236 .78039 m .36116 .76136 L .36495 .76528 L p .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35809 .79015 L .37302 .80158 L p .707 .577 .707 r
F P
0 g
s
.64295 .2865 m .64295 .78839 L .64191 .77628 L p .707 .578 .707 r
F P
0 g
s
.64191 .77628 m .64191 .27439 L .64295 .2865 L p .707 .578 .707 r
F P
0 g
s
.1615 .62105 m .15665 .67228 L .15913 .68693 L p .707 .577 .707 r
F P
0 g
s
.15665 .67228 m .1615 .62105 L .16896 .6075 L p .707 .577 .707 r
F P
0 g
s
.15947 .74982 m .16107 .71398 L .15824 .70238 L p .707 .577 .707 r
F P
0 g
s
.16614 .79987 m .16494 .78084 L .16115 .77692 L p .707 .577 .707 r
F P
0 g
s
.16115 .77692 m .16235 .79595 L .16614 .79987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15824 .70238 m .15663 .73822 L .15947 .74982 L p .707 .577 .707 r
F P
0 g
s
.16896 .6075 m .16411 .65874 L .15665 .67228 L p .707 .577 .707 r
F P
0 g
s
.16411 .65874 m .16896 .6075 L .18562 .59639 L p .707 .577 .707 r
F P
0 g
s
.15663 .73822 m .15824 .70238 L .16537 .69141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35705 .77805 m .35705 .27616 L .37 .26456 L p .707 .577 .707 r
F P
0 g
s
.64191 .27439 m .64191 .77628 L .62698 .76485 L p .707 .577 .707 r
F P
0 g
s
.62698 .76485 m .62698 .26297 L .64191 .27439 L p .707 .577 .707 r
F P
0 g
s
.16235 .79595 m .16115 .77692 L .16734 .77242 L p .707 .577 .707 r
F P
0 g
s
.16734 .77242 m .16854 .79145 L .16235 .79595 L p .707 .577 .707 r
F P
0 g
s
.16537 .69141 m .16376 .72725 L .15663 .73822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34984 .61467 m .34499 .6659 L .32432 .65331 L p .707 .577 .707 r
F P
0 g
s
.32432 .65331 m .32917 .60208 L .34984 .61467 L p .707 .577 .707 r
F P
0 g
s
.18562 .59639 m .18077 .64763 L .16411 .65874 L p .707 .577 .707 r
F P
0 g
s
.18077 .64763 m .18562 .59639 L .20985 .5888 L p .707 .577 .707 r
F P
0 g
s
.16376 .72725 m .16537 .69141 L .18177 .68215 L p .707 .577 .707 r
F P
0 g
s
.32917 .60208 m .32432 .65331 L .29717 .64369 L p .707 .577 .707 r
F P
0 g
s
.29717 .64369 m .30202 .59245 L .32917 .60208 L p .707 .577 .707 r
F P
0 g
s
.16854 .79145 m .16734 .77242 L .18289 .7678 L p .707 .577 .707 r
F P
0 g
s
.205 .64003 m .20985 .5888 L .23929 .58547 L p .707 .577 .707 r
F P
0 g
s
.20985 .5888 m .205 .64003 L .18077 .64763 L p .707 .577 .707 r
F P
0 g
s
.18177 .68215 m .18017 .71799 L .16376 .72725 L p .707 .577 .707 r
F P
0 g
s
.18289 .7678 m .18409 .78683 L .16854 .79145 L p .707 .577 .707 r
F P
0 g
s
.37 .76645 m .37 .26456 L .39567 .2546 L p .707 .577 .707 r
F P
0 g
s
.37 .26456 m .37 .76645 L .35705 .77805 L p .707 .577 .707 r
F P
0 g
s
.34657 .69263 m .34496 .72848 L .32397 .71896 L p .707 .577 .707 r
F P
0 g
s
.32397 .71896 m .32557 .68312 L .34657 .69263 L p .707 .577 .707 r
F P
0 g
s
.62698 .26297 m .62698 .76485 L .59961 .75522 L p .707 .577 .707 r
F P
0 g
s
.59961 .75522 m .59961 .25334 L .62698 .26297 L p .707 .577 .707 r
F P
0 g
s
.30202 .59245 m .29717 .64369 L .2662 .63796 L p .707 .577 .707 r
F P
0 g
s
.2662 .63796 m .27105 .58673 L .30202 .59245 L p .707 .577 .707 r
F P
0 g
s
.23444 .6367 m .23929 .58547 L .27105 .58673 L p .707 .577 .707 r
F P
0 g
s
.23929 .58547 m .23444 .6367 L .205 .64003 L p .707 .577 .707 r
F P
0 g
s
.18017 .71799 m .18177 .68215 L .20585 .67551 L p .707 .577 .707 r
F P
0 g
s
.27105 .58673 m .2662 .63796 L .23444 .6367 L p .707 .577 .707 r
F P
0 g
s
.34777 .75839 m .34897 .77741 L .32728 .77569 L p .707 .577 .707 r
F P
0 g
s
.32728 .77569 m .32608 .75666 L .34777 .75839 L p .707 .577 .707 r
F P
0 g
s
.18409 .78683 m .18289 .7678 L .20629 .7635 L p .707 .577 .707 r
F P
0 g
s
.20585 .67551 m .20424 .71135 L .18017 .71799 L p .707 .577 .707 r
F P
0 g
s
.32557 .68312 m .32397 .71896 L .29657 .71197 L p .707 .577 .707 r
F P
0 g
s
.29657 .71197 m .29817 .67613 L .32557 .68312 L p .707 .577 .707 r
F P
0 g
s
.20629 .7635 m .20749 .78253 L .18409 .78683 L p .707 .577 .707 r
F P
0 g
s
.20424 .71135 m .20585 .67551 L .23523 .67213 L p .707 .577 .707 r
F P
0 g
s
.7338 .6386 m .72895 .58125 L .69798 .58332 L p .707 .577 .707 r
F P
0 g
s
.72895 .58125 m .7338 .6386 L .76556 .63574 L p .707 .577 .707 r
F P
0 g
s
.76556 .63574 m .76071 .5784 L .72895 .58125 L p .707 .577 .707 r
F P
0 g
s
.39567 .2546 m .39567 .75649 L .37 .76645 L p .707 .577 .707 r
F P
0 g
s
.39567 .75649 m .39567 .2546 L .43156 .24726 L p .707 .577 .707 r
F P
0 g
s
.76071 .5784 m .76556 .63574 L .79499 .63238 L p .707 .577 .707 r
F P
0 g
s
.79499 .63238 m .79015 .57504 L .76071 .5784 L p .707 .577 .707 r
F P
0 g
s
.69798 .58332 m .70283 .64066 L .7338 .6386 L p .707 .577 .707 r
F P
0 g
s
.59961 .25334 m .59961 .75522 L .5625 .74834 L p .707 .577 .707 r
F P
0 g
s
.5625 .74834 m .5625 .24645 L .59961 .25334 L p .707 .577 .707 r
F P
0 g
s
.29817 .67613 m .29657 .71197 L .26543 .70818 L p .707 .577 .707 r
F P
0 g
s
.26543 .70818 m .26704 .67234 L .29817 .67613 L p .707 .577 .707 r
F P
0 g
s
.32608 .75666 m .32728 .77569 L .29943 .77538 L p .707 .577 .707 r
F P
0 g
s
.29943 .77538 m .29822 .75635 L .32608 .75666 L p .707 .577 .707 r
F P
0 g
s
.70283 .64066 m .69798 .58332 L .67083 .58439 L p .707 .577 .707 r
F P
0 g
s
.23362 .70797 m .23523 .67213 L .26704 .67234 L p .707 .577 .707 r
F P
0 g
s
.23523 .67213 m .23362 .70797 L .20424 .71135 L p .707 .577 .707 r
F P
0 g
s
.67083 .58439 m .67568 .64174 L .70283 .64066 L p .707 .577 .707 r
F P
0 g
s
.20749 .78253 m .20629 .7635 L .23525 .75994 L p .707 .577 .707 r
F P
0 g
s
.26704 .67234 m .26543 .70818 L .23362 .70797 L p .707 .577 .707 r
F P
0 g
s
.79015 .57504 m .79499 .63238 L .81923 .62885 L p .707 .577 .707 r
F P
0 g
s
.81923 .62885 m .81438 .5715 L .79015 .57504 L p .707 .577 .707 r
F P
0 g
s
.23525 .75994 m .23645 .77897 L .20749 .78253 L p .707 .577 .707 r
F P
0 g
s
.73456 .70919 m .73296 .67134 L .70183 .67138 L p .707 .577 .707 r
F P
0 g
s
.73296 .67134 m .73456 .70919 L .76638 .70739 L p .707 .577 .707 r
F P
0 g
s
.76638 .70739 m .76477 .66954 L .73296 .67134 L p .707 .577 .707 r
F P
0 g
s
.76477 .66954 m .76638 .70739 L .79576 .70401 L p .707 .577 .707 r
F P
0 g
s
.79576 .70401 m .79415 .66616 L .76477 .66954 L p .707 .577 .707 r
F P
0 g
s
.29822 .75635 m .29943 .77538 L .26813 .77651 L p .707 .577 .707 r
F P
0 g
s
.26813 .77651 m .26692 .75748 L .29822 .75635 L p .707 .577 .707 r
F P
0 g
s
.70183 .67138 m .70343 .70923 L .73456 .70919 L p .707 .577 .707 r
F P
0 g
s
.70343 .70923 m .70183 .67138 L .67442 .66966 L p .707 .577 .707 r
F P
0 g
s
.67568 .64174 m .67083 .58439 L .65016 .58437 L p .707 .577 .707 r
F P
0 g
s
.23645 .77897 m .23525 .75994 L .26692 .75748 L p .707 .577 .707 r
F P
0 g
s
.26692 .75748 m .26813 .77651 L .23645 .77897 L p .707 .577 .707 r
F P
0 g
s
.43156 .74915 m .43156 .24726 L .47415 .24325 L p .707 .577 .707 r
F P
0 g
s
.43156 .24726 m .43156 .74915 L .39567 .75649 L p .707 .577 .707 r
F P
0 g
s
.65016 .58437 m .65501 .64172 L .67568 .64174 L p .707 .577 .707 r
F P
0 g
s
.67442 .66966 m .67603 .70752 L .70343 .70923 L p .707 .577 .707 r
F P
0 g
s
.5625 .24645 m .5625 .74834 L .51927 .74486 L p .707 .577 .707 r
F P
0 g
s
.51927 .74486 m .51927 .24297 L .5625 .24645 L p .707 .577 .707 r
F P
0 g
s
.79415 .66616 m .79576 .70401 L .81983 .69938 L p .707 .577 .707 r
F P
0 g
s
.81983 .69938 m .81822 .66153 L .79415 .66616 L p .707 .577 .707 r
F P
0 g
s
.81438 .5715 m .81923 .62885 L .83589 .62548 L p .707 .577 .707 r
F P
0 g
s
.83589 .62548 m .83104 .56813 L .81438 .5715 L p .707 .577 .707 r
F P
0 g
s
.67603 .70752 m .67442 .66966 L .65343 .66635 L p .707 .577 .707 r
F P
0 g
s
.47415 .74514 m .47415 .24325 L .51927 .24297 L p .707 .577 .707 r
F P
0 g
s
.47415 .24325 m .47415 .74514 L .43156 .74915 L p .707 .577 .707 r
F P
0 g
s
.51927 .24297 m .51927 .74486 L .47415 .74514 L p .707 .577 .707 r
F P
0 g
s
.73187 .77013 m .73307 .75254 L .70177 .74826 L p .707 .577 .707 r
F P
0 g
s
.73307 .75254 m .73187 .77013 L .76355 .77043 L p .707 .577 .707 r
F P
0 g
s
.76355 .77043 m .76475 .75284 L .73307 .75254 L p .707 .577 .707 r
F P
0 g
s
.65343 .66635 m .65503 .70421 L .67603 .70752 L p .707 .577 .707 r
F P
0 g
s
.65501 .64172 m .65016 .58437 L .63799 .58326 L p .707 .577 .707 r
F P
0 g
s
.76475 .75284 m .76355 .77043 L .79251 .76672 L p .707 .577 .707 r
F P
0 g
s
.79251 .76672 m .79371 .74913 L .76475 .75284 L p .707 .577 .707 r
F P
0 g
s
.70057 .76585 m .70177 .74826 L .67392 .74042 L p .707 .577 .707 r
F P
0 g
s
.70177 .74826 m .70057 .76585 L .73187 .77013 L p .707 .577 .707 r
F P
0 g
s
.81822 .66153 m .81983 .69938 L .83623 .69395 L p .707 .577 .707 r
F P
0 g
s
.83623 .69395 m .83463 .6561 L .81822 .66153 L p .707 .577 .707 r
F P
0 g
s
.63799 .58326 m .64284 .64061 L .65501 .64172 L p .707 .577 .707 r
F P
0 g
s
.67392 .74042 m .67272 .75801 L .70057 .76585 L p .707 .577 .707 r
F P
0 g
s
.83104 .56813 m .83589 .62548 L .84335 .6226 L p .707 .577 .707 r
F P
0 g
s
.84335 .6226 m .8385 .56526 L .83104 .56813 L p .707 .577 .707 r
F P
0 g
s
.65503 .70421 m .65343 .66635 L .6409 .66178 L p .707 .577 .707 r
F P
0 g
s
.79371 .74913 m .79251 .76672 L .81591 .75936 L p .707 .577 .707 r
F P
0 g
s
.81591 .75936 m .81711 .74177 L .79371 .74913 L p .707 .577 .707 r
F P
0 g
s
.67272 .75801 m .67392 .74042 L .65223 .72979 L p .707 .577 .707 r
F P
0 g
s
.6409 .66178 m .64251 .69963 L .65503 .70421 L p .707 .577 .707 r
F P
0 g
s
.65223 .72979 m .65103 .74738 L .67272 .75801 L p .707 .577 .707 r
F P
0 g
s
.64284 .64061 m .63799 .58326 L .63551 .58117 L p .707 .577 .707 r
F P
0 g
s
.83463 .6561 m .83623 .69395 L .84337 .68826 L p .707 .577 .707 r
F P
0 g
s
.84337 .68826 m .84176 .65041 L .83463 .6561 L p .707 .577 .707 r
F P
0 g
s
.63551 .58117 m .64036 .63851 L .64284 .64061 L p .707 .577 .707 r
F P
0 g
s
.81711 .74177 m .81591 .75936 L .83146 .74908 L p .707 .577 .707 r
F P
0 g
s
.83146 .74908 m .83266 .73149 L .81711 .74177 L p .707 .577 .707 r
F P
0 g
s
.65103 .74738 m .65223 .72979 L .63884 .71741 L p .707 .577 .707 r
F P
0 g
s
.8385 .56526 m .84335 .6226 L .84087 .62051 L p .707 .577 .707 r
F P
0 g
s
.84087 .62051 m .83602 .56317 L .8385 .56526 L p .707 .577 .707 r
F P
0 g
s
.64251 .69963 m .6409 .66178 L .63807 .65638 L p .707 .577 .707 r
F P
0 g
s
.63884 .71741 m .63763 .735 L .65103 .74738 L p .707 .577 .707 r
F P
0 g
s
.63807 .65638 m .63967 .69423 L .64251 .69963 L p .707 .577 .707 r
F P
0 g
s
.84176 .65041 m .84337 .68826 L .84053 .68286 L p .707 .577 .707 r
F P
0 g
s
.84053 .68286 m .83893 .64501 L .84176 .65041 L p .707 .577 .707 r
F P
0 g
s
.64036 .63851 m .63551 .58117 L .64297 .5783 L p .707 .577 .707 r
F P
0 g
s
.83266 .73149 m .83146 .74908 L .83764 .73688 L p .707 .577 .707 r
F P
0 g
s
.83764 .73688 m .83885 .71929 L .83266 .73149 L p .707 .577 .707 r
F P
0 g
s
.63763 .735 m .63884 .71741 L .63505 .70448 L p .707 .577 .707 r
F P
0 g
s
.64297 .5783 m .64781 .63564 L .64036 .63851 L p .707 .577 .707 r
F P
0 g
s
.63505 .70448 m .63384 .72207 L .63763 .735 L p .707 .577 .707 r
F P
0 g
s
.63967 .69423 m .63807 .65638 L .6452 .65069 L p .707 .577 .707 r
F P
0 g
s
.83602 .56317 m .84087 .62051 L .8287 .6194 L p .707 .577 .707 r
F P
0 g
s
.8287 .6194 m .82385 .56205 L .83602 .56317 L p .707 .577 .707 r
F P
0 g
s
.42383 .62247 m .41257 .56938 L .38129 .57601 L p .707 .577 .707 r
F P
0 g
s
.41257 .56938 m .42383 .62247 L .45288 .61288 L p .707 .577 .707 r
F P
0 g
s
.45288 .61288 m .44162 .55979 L .41257 .56938 L p .707 .577 .707 r
F P
0 g
s
.39256 .62909 m .38129 .57601 L .35086 .57903 L p .707 .577 .707 r
F P
0 g
s
.38129 .57601 m .39256 .62909 L .42383 .62247 L p .707 .577 .707 r
F P
0 g
s
.6452 .65069 m .64681 .68854 L .63967 .69423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44162 .55979 m .45288 .61288 L .47687 .60127 L p .707 .577 .707 r
F P
0 g
s
.47687 .60127 m .46561 .54819 L .44162 .55979 L p .707 .577 .707 r
F P
0 g
s
.36212 .63211 m .35086 .57903 L .32425 .57814 L p .707 .577 .707 r
F P
0 g
s
.35086 .57903 m .36212 .63211 L .39256 .62909 L p .707 .577 .707 r
F P
0 g
s
.83885 .71929 m .83764 .73688 L .83385 .72395 L p .707 .577 .707 r
F P
0 g
s
.83385 .72395 m .83506 .70636 L .83885 .71929 L p .707 .577 .707 r
F P
0 g
s
.83893 .64501 m .84053 .68286 L .82801 .67829 L p .707 .577 .707 r
F P
0 g
s
.82801 .67829 m .8264 .64043 L .83893 .64501 L p .707 .577 .707 r
F P
0 g
s
.64781 .63564 m .64297 .5783 L .65963 .57493 L p .707 .577 .707 r
F P
0 g
s
.63384 .72207 m .63505 .70448 L .64123 .69228 L p .707 .577 .707 r
F P
0 g
s
.65963 .57493 m .66448 .63227 L .64781 .63564 L p .707 .577 .707 r
F P
0 g
s
.64123 .69228 m .64003 .70987 L .63384 .72207 L p .707 .577 .707 r
F P
0 g
s
.3933 .68523 m .38957 .64881 L .35857 .64947 L p .707 .577 .707 r
F P
0 g
s
.38957 .64881 m .3933 .68523 L .425 .68143 L p .707 .577 .707 r
F P
0 g
s
.425 .68143 m .42126 .64501 L .38957 .64881 L p .707 .577 .707 r
F P
0 g
s
.42126 .64501 m .425 .68143 L .45429 .67486 L p .707 .577 .707 r
F P
0 g
s
.45429 .67486 m .45055 .63844 L .42126 .64501 L p .707 .577 .707 r
F P
0 g
s
.82385 .56205 m .8287 .6194 L .80802 .61938 L p .707 .577 .707 r
F P
0 g
s
.80802 .61938 m .80317 .56204 L .82385 .56205 L p .707 .577 .707 r
F P
0 g
s
.64681 .68854 m .6452 .65069 L .66161 .64526 L p .707 .577 .707 r
F P
0 g
s
.46561 .54819 m .47687 .60127 L .49344 .58877 L p .707 .577 .707 r
F P
0 g
s
.49344 .58877 m .48218 .53569 L .46561 .54819 L p .707 .577 .707 r
F P
0 g
s
.33551 .63122 m .32425 .57814 L .30406 .57343 L p .707 .577 .707 r
F P
0 g
s
.32425 .57814 m .33551 .63122 L .36212 .63211 L p .707 .577 .707 r
F P
0 g
s
.3623 .68589 m .35857 .64947 L .33129 .64693 L p .707 .577 .707 r
F P
0 g
s
.35857 .64947 m .3623 .68589 L .3933 .68523 L p .707 .577 .707 r
F P
0 g
s
.66161 .64526 m .66321 .68311 L .64681 .68854 L p .707 .577 .707 r
F P
0 g
s
.38278 .717 m .38555 .69837 L .35453 .69267 L p .707 .577 .707 r
F P
0 g
s
.38555 .69837 m .38278 .717 L .41421 .7207 L p .707 .577 .707 r
F P
0 g
s
.41421 .7207 m .41697 .70207 L .38555 .69837 L p .707 .577 .707 r
F P
0 g
s
.45055 .63844 m .45429 .67486 L .4783 .66617 L p .707 .577 .707 r
F P
0 g
s
.4783 .66617 m .47456 .62974 L .45055 .63844 L p .707 .577 .707 r
F P
0 g
s
.35453 .69267 m .35177 .71129 L .38278 .717 L p .707 .577 .707 r
F P
0 g
s
.41697 .70207 m .41421 .7207 L .44296 .72203 L p .707 .577 .707 r
F P
0 g
s
.44296 .72203 m .44572 .70341 L .41697 .70207 L p .707 .577 .707 r
F P
0 g
s
.35177 .71129 m .35453 .69267 L .32696 .68552 L p .707 .577 .707 r
F P
0 g
s
.66448 .63227 m .65963 .57493 L .68386 .57139 L p .707 .577 .707 r
F P
0 g
s
.83506 .70636 m .83385 .72395 L .82046 .71157 L p .707 .577 .707 r
F P
0 g
s
.82046 .71157 m .82166 .69398 L .83506 .70636 L p .707 .577 .707 r
F P
0 g
s
.8264 .64043 m .82801 .67829 L .80701 .67498 L p .707 .577 .707 r
F P
0 g
s
.80701 .67498 m .80541 .63712 L .8264 .64043 L p .707 .577 .707 r
F P
0 g
s
.64003 .70987 m .64123 .69228 L .65678 .682 L p .707 .577 .707 r
F P
0 g
s
.33129 .64693 m .33503 .68336 L .3623 .68589 L p .707 .577 .707 r
F P
0 g
s
.32696 .68552 m .32419 .70415 L .35177 .71129 L p .707 .577 .707 r
F P
0 g
s
.68386 .57139 m .68871 .62873 L .66448 .63227 L p .707 .577 .707 r
F P
0 g
s
.30406 .57343 m .31532 .62652 L .33551 .63122 L p .707 .577 .707 r
F P
0 g
s
.33503 .68336 m .33129 .64693 L .31042 .64144 L p .707 .577 .707 r
F P
0 g
s
.65678 .682 m .65558 .69959 L .64003 .70987 L p .707 .577 .707 r
F P
0 g
s
.80317 .56204 m .80802 .61938 L .78087 .62046 L p .707 .577 .707 r
F P
0 g
s
.78087 .62046 m .77602 .56311 L .80317 .56204 L p .707 .577 .707 r
F P
0 g
s
.48218 .53569 m .49344 .58877 L .50098 .57662 L p .707 .577 .707 r
F P
0 g
s
.50098 .57662 m .48972 .52353 L .48218 .53569 L p .707 .577 .707 r
F P
0 g
s
.31532 .62652 m .30406 .57343 L .29228 .56537 L p .707 .577 .707 r
F P
0 g
s
.44572 .70341 m .44296 .72203 L .46623 .72087 L p .707 .577 .707 r
F P
0 g
s
.46623 .72087 m .46899 .70225 L .44572 .70341 L p .707 .577 .707 r
F P
0 g
s
.66321 .68311 m .66161 .64526 L .68568 .64063 L p .707 .577 .707 r
F P
0 g
s
.32419 .70415 m .32696 .68552 L .30552 .67763 L p .707 .577 .707 r
F P
0 g
s
.47456 .62974 m .4783 .66617 L .49468 .6562 L p .707 .577 .707 r
F P
0 g
s
.49468 .6562 m .49094 .61978 L .47456 .62974 L p .707 .577 .707 r
F P
0 g
s
.30552 .67763 m .30276 .69625 L .32419 .70415 L p .707 .577 .707 r
F P
0 g
s
.31042 .64144 m .31416 .67786 L .33503 .68336 L p .707 .577 .707 r
F P
0 g
s
.68568 .64063 m .68728 .67848 L .66321 .68311 L p .707 .577 .707 r
F P
0 g
s
.68871 .62873 m .68386 .57139 L .7133 .56803 L p .707 .577 .707 r
F P
0 g
s
.7133 .56803 m .71815 .62537 L .68871 .62873 L p .707 .577 .707 r
F P
0 g
s
.80541 .63712 m .80701 .67498 L .77961 .67326 L p .707 .577 .707 r
F P
0 g
s
.77961 .67326 m .778 .63541 L .80541 .63712 L p .707 .577 .707 r
F P
0 g
s
.82166 .69398 m .82046 .71157 L .79877 .70094 L p .707 .577 .707 r
F P
0 g
s
.79877 .70094 m .79997 .68335 L .82166 .69398 L p .707 .577 .707 r
F P
0 g
s
.77602 .56311 m .78087 .62046 L .7499 .62252 L p .707 .577 .707 r
F P
0 g
s
.7499 .62252 m .74506 .56518 L .77602 .56311 L p .707 .577 .707 r
F P
0 g
s
.65558 .69959 m .65678 .682 L .68018 .67465 L p .707 .577 .707 r
F P
0 g
s
.31416 .67786 m .31042 .64144 L .29799 .63353 L p .707 .577 .707 r
F P
0 g
s
.29228 .56537 m .30354 .61845 L .31532 .62652 L p .707 .577 .707 r
F P
0 g
s
.71815 .62537 m .7133 .56803 L .74506 .56518 L p .707 .577 .707 r
F P
0 g
s
.68728 .67848 m .68568 .64063 L .71506 .63725 L p .707 .577 .707 r
F P
0 g
s
.46899 .70225 m .46623 .72087 L .48174 .71733 L p .707 .577 .707 r
F P
0 g
s
.48174 .71733 m .4845 .69871 L .46899 .70225 L p .707 .577 .707 r
F P
0 g
s
.74506 .56518 m .7499 .62252 L .71815 .62537 L p .707 .577 .707 r
F P
0 g
s
.68018 .67465 m .67898 .69224 L .65558 .69959 L p .707 .577 .707 r
F P
0 g
s
.30276 .69625 m .30552 .67763 L .29233 .66977 L p .707 .577 .707 r
F P
0 g
s
.29233 .66977 m .28957 .68839 L .30276 .69625 L p .707 .577 .707 r
F P
0 g
s
.48972 .52353 m .50098 .57662 L .49875 .56599 L p .698 .571 .709 r
F P
0 g
s
.49875 .56599 m .48749 .5129 L .48972 .52353 L p .698 .571 .709 r
F P
0 g
s
.30354 .61845 m .29228 .56537 L .29004 .55474 L p .698 .571 .709 r
F P
0 g
s
.71506 .63725 m .71666 .6751 L .68728 .67848 L p .707 .577 .707 r
F P
0 g
s
.49094 .61978 m .49468 .6562 L .50184 .64594 L p .707 .577 .707 r
F P
0 g
s
.50184 .64594 m .4981 .60952 L .49094 .61978 L p .707 .577 .707 r
F P
0 g
s
.778 .63541 m .77961 .67326 L .74848 .6733 L p .707 .577 .707 r
F P
0 g
s
.74848 .6733 m .74687 .63545 L .778 .63541 L p .707 .577 .707 r
F P
0 g
s
.29799 .63353 m .30172 .66995 L .31416 .67786 L p .707 .577 .707 r
F P
0 g
s
.71666 .6751 m .71506 .63725 L .74687 .63545 L p .707 .577 .707 r
F P
0 g
s
.79997 .68335 m .79877 .70094 L .77092 .6931 L p .707 .577 .707 r
F P
0 g
s
.77092 .6931 m .77212 .67551 L .79997 .68335 L p .707 .577 .707 r
F P
0 g
s
.67898 .69224 m .68018 .67465 L .70914 .67094 L p .707 .577 .707 r
F P
0 g
s
.74687 .63545 m .74848 .6733 L .71666 .6751 L p .707 .577 .707 r
F P
0 g
s
.70914 .67094 m .70794 .68852 L .67898 .69224 L p .707 .577 .707 r
F P
0 g
s
.30172 .66995 m .29799 .63353 L .29521 .62398 L p .707 .577 .707 r
F P
0 g
s
.29004 .55474 m .3013 .60782 L .30354 .61845 L p .698 .571 .709 r
F P
0 g
s
.77212 .67551 m .77092 .6931 L .73962 .68882 L p .707 .577 .707 r
F P
0 g
s
.73962 .68882 m .74082 .67123 L .77212 .67551 L p .707 .577 .707 r
F P
0 g
s
.70794 .68852 m .70914 .67094 L .74082 .67123 L p .707 .577 .707 r
F P
0 g
s
.4845 .69871 m .48174 .71733 L .48797 .71176 L p .707 .577 .707 r
F P
0 g
s
.48797 .71176 m .49073 .69313 L .4845 .69871 L p .707 .577 .707 r
F P
0 g
s
.28957 .68839 m .29233 .66977 L .28867 .6627 L p .707 .577 .707 r
F P
0 g
s
.74082 .67123 m .73962 .68882 L .70794 .68852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28867 .6627 m .28591 .68133 L .28957 .68839 L p .707 .577 .707 r
F P
0 g
s
.4981 .60952 m .50184 .64594 L .49906 .63639 L p .707 .577 .707 r
F P
0 g
s
.49906 .63639 m .49532 .59996 L .4981 .60952 L p .707 .577 .707 r
F P
0 g
s
.48749 .5129 m .49875 .56599 L .48697 .55792 L p .707 .577 .707 r
F P
0 g
s
.48697 .55792 m .4757 .50484 L .48749 .5129 L p .707 .577 .707 r
F P
0 g
s
.3013 .60782 m .29004 .55474 L .29758 .54258 L p .707 .577 .707 r
F P
0 g
s
.29521 .62398 m .29895 .6604 L .30172 .66995 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29895 .6604 m .29521 .62398 L .30237 .61371 L p .707 .577 .707 r
F P
0 g
s
.29758 .54258 m .30884 .59566 L .3013 .60782 L p .707 .577 .707 r
F P
0 g
s
.49073 .69313 m .48797 .71176 L .48431 .70469 L p .707 .577 .707 r
F P
0 g
s
.48431 .70469 m .48707 .68607 L .49073 .69313 L p .707 .577 .707 r
F P
0 g
s
.28591 .68133 m .28867 .6627 L .2949 .65713 L p .707 .577 .707 r
F P
0 g
s
.2949 .65713 m .29214 .67575 L .28591 .68133 L p .707 .577 .707 r
F P
0 g
s
.4757 .50484 m .48697 .55792 L .46678 .55322 L p .707 .577 .707 r
F P
0 g
s
.46678 .55322 m .45552 .50013 L .4757 .50484 L p .707 .577 .707 r
F P
0 g
s
.30884 .59566 m .29758 .54258 L .31416 .53008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49532 .59996 m .49906 .63639 L .48663 .62847 L p .707 .577 .707 r
F P
0 g
s
.48663 .62847 m .48289 .59205 L .49532 .59996 L p .707 .577 .707 r
F P
0 g
s
.30237 .61371 m .3061 .65013 L .29895 .6604 L p .707 .577 .707 r
F P
0 g
s
.31416 .53008 m .32542 .58317 L .30884 .59566 L p .707 .577 .707 r
F P
0 g
s
.3061 .65013 m .30237 .61371 L .31875 .60375 L p .707 .577 .707 r
F P
0 g
s
.45552 .50013 m .46678 .55322 L .44016 .55233 L p .707 .577 .707 r
F P
0 g
s
.44016 .55233 m .4289 .49925 L .45552 .50013 L p .707 .577 .707 r
F P
0 g
s
.32542 .58317 m .31416 .53008 L .33815 .51848 L p .707 .577 .707 r
F P
0 g
s
.48707 .68607 m .48431 .70469 L .47112 .69683 L p .707 .577 .707 r
F P
0 g
s
.47112 .69683 m .47388 .6782 L .48707 .68607 L p .707 .577 .707 r
F P
0 g
s
.29214 .67575 m .2949 .65713 L .31041 .65359 L p .707 .577 .707 r
F P
0 g
s
.48289 .59205 m .48663 .62847 L .46575 .62298 L p .707 .577 .707 r
F P
0 g
s
.46575 .62298 m .46202 .58656 L .48289 .59205 L p .707 .577 .707 r
F P
0 g
s
.31041 .65359 m .30765 .67221 L .29214 .67575 L p .707 .577 .707 r
F P
0 g
s
.31875 .60375 m .32249 .64017 L .3061 .65013 L p .707 .577 .707 r
F P
0 g
s
.4289 .49925 m .44016 .55233 L .40973 .55535 L p .707 .577 .707 r
F P
0 g
s
.40973 .55535 m .39847 .50226 L .4289 .49925 L p .707 .577 .707 r
F P
0 g
s
.34941 .57156 m .33815 .51848 L .3672 .50889 L p .707 .577 .707 r
F P
0 g
s
.33815 .51848 m .34941 .57156 L .32542 .58317 L p .707 .577 .707 r
F P
0 g
s
.32249 .64017 m .31875 .60375 L .34276 .59506 L p .707 .577 .707 r
F P
0 g
s
.39847 .50226 m .40973 .55535 L .37846 .56197 L p .707 .577 .707 r
F P
0 g
s
.37846 .56197 m .3672 .50889 L .39847 .50226 L p .707 .577 .707 r
F P
0 g
s
.3672 .50889 m .37846 .56197 L .34941 .57156 L p .707 .577 .707 r
F P
0 g
s
.47388 .6782 m .47112 .69683 L .44968 .68894 L p .707 .577 .707 r
F P
0 g
s
.44968 .68894 m .45245 .67031 L .47388 .6782 L p .707 .577 .707 r
F P
0 g
s
.46202 .58656 m .46575 .62298 L .43848 .62044 L p .707 .577 .707 r
F P
0 g
s
.43848 .62044 m .43474 .58402 L .46202 .58656 L p .707 .577 .707 r
F P
0 g
s
.30765 .67221 m .31041 .65359 L .33368 .65243 L p .707 .577 .707 r
F P
0 g
s
.34276 .59506 m .3465 .63148 L .32249 .64017 L p .707 .577 .707 r
F P
0 g
s
.33368 .65243 m .33092 .67105 L .30765 .67221 L p .707 .577 .707 r
F P
0 g
s
.3465 .63148 m .34276 .59506 L .37205 .58849 L p .707 .577 .707 r
F P
0 g
s
.43474 .58402 m .43848 .62044 L .40748 .62111 L p .707 .577 .707 r
F P
0 g
s
.40748 .62111 m .40374 .58468 L .43474 .58402 L p .707 .577 .707 r
F P
0 g
s
.45245 .67031 m .44968 .68894 L .42211 .68179 L p .707 .577 .707 r
F P
0 g
s
.42211 .68179 m .42487 .66317 L .45245 .67031 L p .707 .577 .707 r
F P
0 g
s
.37579 .62491 m .37205 .58849 L .40374 .58468 L p .707 .577 .707 r
F P
0 g
s
.37205 .58849 m .37579 .62491 L .3465 .63148 L p .707 .577 .707 r
F P
0 g
s
.33092 .67105 m .33368 .65243 L .36243 .65376 L p .707 .577 .707 r
F P
0 g
s
.40374 .58468 m .40748 .62111 L .37579 .62491 L p .707 .577 .707 r
F P
0 g
s
.36243 .65376 m .35967 .67239 L .33092 .67105 L p .707 .577 .707 r
F P
0 g
s
.42487 .66317 m .42211 .68179 L .39109 .67609 L p .707 .577 .707 r
F P
0 g
s
.39109 .67609 m .39386 .65746 L .42487 .66317 L p .707 .577 .707 r
F P
0 g
s
.35967 .67239 m .36243 .65376 L .39386 .65746 L p .707 .577 .707 r
F P
0 g
s
.39386 .65746 m .39109 .67609 L .35967 .67239 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001EYF5@000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00H005YFFUIJEP00FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP04000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00HWoo0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00Ggoo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001KOol20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00FGoo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol005Qoo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001FOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005Aoo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001C
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0059oo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUH0
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
DWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP04001J
EUYFFUH20005FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01EYF100000AJEP00000000QJEP04001JEP000007FUH00`00FUIJEP02FUH40005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000:Woo2`00<Goo001C
Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH50005FUH400000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF000067oo4P000eYF00<005YFFUH00eYF00<005YF00000P00;Woo001COol0
0`00FUH00005FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH:0005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00011oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP02FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000Qoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001J
EP0^Ool005=oo`04001JEUYF0005FUH01000FUIJEUYF0P000goo00<005YFFUH02P000eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001C
Ool01000FUIJEP001EYF00<005YF00002@0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001JEP0^Ool005Aoo`03001J
EP0000EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0041oo`l000Eoo`03001JEP0000AJ
EP8000IJEP03001JEUYF00MJEQP00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo000jOol60004FUH00`00FUIJEP06FUH00`00FUH0000300001Woo001JEUYF001JEP80009J
EP03001JEUYF00AJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
00020004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH015YF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF000^Ool003Aoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000cOol20006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0031oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF000]Ool002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH70004FUH70005FUH70003FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUHB0007FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP040002FUH90006FUH00`00FUIJEP09FUH50002FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000eYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0039oo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00=JEPX000=JEPD000MJEP03001JEUYF00QJEP8000AJEP@000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00H000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJ
EP04001JEUYFFUH20002FUH00`00FUH00003FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP05FUH3
00000eYF001JEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF4@00?7oo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0005FUH01000FUIJEP0015YF00@005YF0000
00AJEP03001JEP0000=JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH40004FUH00`00FUIJEP02
FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH6
000fOol002eoo`03001JEP0000=JEP03001JEUYF00=JEPH000moo`@00003FUH005YF009JEP04001J
EUYFFUH20005FUH01000FUIJEP000eYF00<005YFFUH00eYF0`0025YF10000UYF00<005YFFUH00eYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEQ4000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00D0035oo`00;Goo00<005YF00000eYF00<005YF00000`006Goo0`000UYF00<005YF00002@000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00L000IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00004Ool5
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool002aoo`03001JEP0000AJEP8001moo`03001JEUYF008000EJEP04
001JEUYFFUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF0`0057oo0`002Goo00<005YF00005000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool002aoo`03001JEP0000800003FUH005YF0080015oo`D000Moo`<0009J
EP03001JEUYF00=JEP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH0
0003FUH01@00FUIJEUYF000047oo1@001Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH0100000=JEP00FUH025YF00<005YFFUH00eYF00<005YFFUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH2000>Ool50006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH00`00
FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0P000eYF00<005YFFUH00eYF00@0
05YF000000eoo`<000Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF0`0057oo00=JEP00FUH00UYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH000000080
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH03`0025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUHB000017oo001JEP000UYF1@0015YF
00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH01000
FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH04`000eYF00<005YFFUH00P00;Goo000/Ool2
0003FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000006
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009J
EP8002eoo`00;7oo0P000eYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YF00001@0000=JEP00FUH01EYF00<005YFFUH01UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00H005YFFUH005YF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000040006FUH01000FUIJEUYF1000;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF00<005YF
FUH00UYF2@001EYF10000UYF00<005YFFUH015YF00@005YF000000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001EYF00@005YFFUIJEP<002eoo`00;Goo00<0
05YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH0000000H000=JEPD000MJEP03001JEUYF00<000EJ
EP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP02FUH@0006FUH00`00FUIJEP05FUH3
0003FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH00eYF1@000UYF00<0
05YFFUH00UYF1@001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH30008FUH00`00
FUIJEP05FUH200000eYF001JEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH40006FUH00`00FUIJEP02FUH20002FUH2000_Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00MJEP8000=JEP03001JEP0000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH3000aOol0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJ
EPH00004FUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0
00000UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00@005YF0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPP000=JEP03001JEUYF00<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP05001JEUYFFUH0000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000IJER4000Qoo`80
0003FUH005YF009JEP03001oogoo02eoo`00;Goo0P0015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01UYF1P001UYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH000020006FUH00`00FUIJEP03FUH01000FUIJEUYF0P007goo0P000eYF00<007ooOol0
;Goo000]Ool20004FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01000FUIJEP000UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00001P0000=JEP00FUH01EYF00<005YFFUH00P002Goo0`005Woo00<005YFFUH00P00;Woo000/
Ool00`00FUH00003FUH30005Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH01000FUIJEP000eYF00<005YFFUH015YF2@0015YF00@005YFFUIJEPH000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP<000IJEP03
001JEUYF008000Qoo`D001Ioo`@002ioo`00;7oo00@005YF001JEP8000]oo`@000IJEP@000EJEP03
001JEUYF00EJEP03001JEP0000@000=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH000020003FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0027oo1@0067oo0P00;Woo000/Ool0
1@00FUH00000FUH00P003Woo10000UYF1@0015YF00<005YFFUH00UYF1@001Goo0P0000EJEP00FUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001JEP0200000eYF001JEP03FUH2
00000eYF001JEP02FUH20008Ool5000HOol2000^Ool002aoo`8000=JEP03001JEP00008000mooa00
00aoo`80009JEP05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF0`0015YF0`00
0UYF00<005YF00002Goo0`0067oo0`00;Woo000/Ool20003FUH00`00FUIJEP02FUH3000>Ool5000E
Ool300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF20000UYF
0`0000=JEP00Ool08goo00<005YF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003
000;Ool3000DOol20003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF
00<005YFFUH00`0000AJEP000000009JEP8002=oo`<00003FUH007oo02eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF1P0067oo100000=JEP00FUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP<0009JEP@0021oo`<0009JEP80
02moo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000Yoo`D000EJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10001EYF00<005YF00001@007Woo0P0000=J
EP00FUH00UYF0P00;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2P000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF00MJEP04001JEUYFFUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEPL001Moo`8000=JEP05001J
EUYFFUH0000`Ool002eoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF1P002UYF00<005YFFUH02UYF00<005YFFUH02EYF1`000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000Uoo`D000AJEP04001J
EUYFFUH2000`Ool002ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@000IJEP05001JEUYFFUH00005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90003FUH00`00FUIJEP03FUH01000FUH00000<Woo000_Ool20005FUH00`00FUIJEP06FUH00`00
FUIJEP05FUHO0003FUH00`00FUIJEP03FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH30004FUH01@00FUIJEUYF00001UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00=7oo000`Ool00`00FUIJEP03FUH0
0`00FUIJEP05FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000eYF00<005YF00000`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH015YF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH2
000fOol0035oo`8000=JEP03001JEP0000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH00000>7oo000bOol60002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH02`000UYF00H005YFFUH005YF0003Ool90004FUH00`00FUIJEP02FUH5000jOol002mo
o`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5
0007FUH00`00FUH000020002FUH00`00FUH0000<Ool9000oOol002eoo`<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF009JEQP000=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH4001EOol002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF009JEPd000AJEP03001JEUYF009JEPT0009JEPH000AJEP03001JEUYF
00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP06001JEUYF001JEP001UYF00<005YFFUH00eYF0`00EGoo000]Ool00`00
FUH00004FUH01000FUIJEUYF1`0017oo50000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP001eYF00<005YFFUH00UYF00<005YFFUH0
0P00Dgoo000]Ool00`00FUH00003FUHK0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF000015YF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH00eYF
00@005YFFUH005=oo`00;Woo0P0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF00L000=JEP03001JEUYF0080059oo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEPD0009oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00@0009JEP80059oo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Goo0`001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1P00DWoo000_Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000BOol20005FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP030003Ool2001BOol0035ooah001eoo`80
00=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000MJEP04001JEUYFFUH60005Ool3001BOol006ioo`800003FUH005YF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00
00l000Yoo`800003FUH007oo055oo`00L7oo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF100067oo0P0000AJEP00FUH0059oo`00M7oo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02P005Goo0P0015YF0P00DWoo001j
Ool80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH80005Ool5000COol200000eYF001JEP03FUH0
0`00Oomoo`1AOol0089ooaX000eoo`D0015oo`8000=JEP03001JEUYF009JEP03001oogoo055oo`00
T7oo00@005YFFUH001Ioo`<000moo`<000EJEP03001JEUYF008005Aoo`00TGoo0P009goo0P0000=J
EP00FUH01EYF0`00EWoo002AOol3000SOol30003FUH00`00FUIJEP04FUH00`00Oomoo`1FOol0095o
o`03001JEUYF00@001Uoo`H000MJEP04001JEUYFFUH2001IOol0095oo`80009JEP03001JEUYF00L0
00Uoo`T000AJEP03001JEUYF00IJEP04001JEP00001KOol0099oo`04001JEUYF0005FUH01000FUIJ
EUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF0`00GGoo002BOol01@00FUIJEUYF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00H7oo002COol2
00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002
001ROol009Eoo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH006Eoo`00
VGoo1`0015YF00<005YFFUH00UYF2@00Jgoo002POol9001dOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5866 .73235 m .60456 .67807 L .57519 .66739 L p .707 .577 .707 r
F P
0 g
s
.60456 .67807 m .5866 .73235 L .61693 .74193 L p .707 .577 .707 r
F P
0 g
s
.61693 .74193 m .63489 .68765 L .60456 .67807 L p .707 .577 .707 r
F P
0 g
s
.63489 .68765 m .61693 .74193 L .64526 .74949 L p .707 .577 .707 r
F P
0 g
s
.64526 .74949 m .66322 .69521 L .63489 .68765 L p .707 .577 .707 r
F P
0 g
s
.55724 .72167 m .57519 .66739 L .54967 .65666 L p .707 .577 .707 r
F P
0 g
s
.57519 .66739 m .55724 .72167 L .5866 .73235 L p .707 .577 .707 r
F P
0 g
s
.54967 .65666 m .53171 .71095 L .55724 .72167 L p .707 .577 .707 r
F P
0 g
s
.66322 .69521 m .64526 .74949 L .66882 .75428 L p .707 .577 .707 r
F P
0 g
s
.66882 .75428 m .68678 .7 L .66322 .69521 L p .707 .577 .707 r
F P
0 g
s
.59025 .80241 m .59628 .76522 L .56554 .75896 L p .707 .577 .707 r
F P
0 g
s
.59628 .76522 m .59025 .80241 L .62171 .80675 L p .707 .577 .707 r
F P
0 g
s
.62171 .80675 m .62774 .76956 L .59628 .76522 L p .707 .577 .707 r
F P
0 g
s
.62774 .76956 m .62171 .80675 L .65081 .80875 L p .707 .577 .707 r
F P
0 g
s
.65081 .80875 m .65683 .77156 L .62774 .76956 L p .707 .577 .707 r
F P
0 g
s
.53171 .71095 m .54967 .65666 L .53049 .64694 L p .707 .577 .707 r
F P
0 g
s
.55951 .79616 m .56554 .75896 L .53852 .7514 L p .707 .577 .707 r
F P
0 g
s
.56554 .75896 m .55951 .79616 L .59025 .80241 L p .707 .577 .707 r
F P
0 g
s
.53049 .64694 m .51253 .70122 L .53171 .71095 L p .707 .577 .707 r
F P
0 g
s
.53852 .7514 m .53249 .7886 L .55951 .79616 L p .707 .577 .707 r
F P
0 g
s
.65683 .77156 m .65081 .80875 L .67469 .80822 L p .707 .577 .707 r
F P
0 g
s
.67469 .80822 m .68072 .77102 L .65683 .77156 L p .707 .577 .707 r
F P
0 g
s
.68678 .7 m .66882 .75428 L .68529 .75583 L p .707 .577 .707 r
F P
0 g
s
.68529 .75583 m .70325 .70154 L .68678 .7 L p .707 .577 .707 r
F P
0 g
s
.53249 .7886 m .53852 .7514 L .51788 .74328 L p .707 .577 .707 r
F P
0 g
s
.61669 .86041 m .61223 .84302 L .58165 .84764 L p .707 .577 .707 r
F P
0 g
s
.61223 .84302 m .61669 .86041 L .64752 .85204 L p .707 .577 .707 r
F P
0 g
s
.64752 .85204 m .64306 .83465 L .61223 .84302 L p .707 .577 .707 r
F P
0 g
s
.51253 .70122 m .53049 .64694 L .51952 .63918 L p .707 .577 .707 r
F P
0 g
s
.64306 .83465 m .64752 .85204 L .67559 .84074 L p .707 .577 .707 r
F P
0 g
s
.67559 .84074 m .67113 .82336 L .64306 .83465 L p .707 .577 .707 r
F P
0 g
s
.51788 .74328 m .51185 .78047 L .53249 .7886 L p .707 .577 .707 r
F P
0 g
s
.58165 .84764 m .58612 .86503 L .61669 .86041 L p .707 .577 .707 r
F P
0 g
s
.58612 .86503 m .58165 .84764 L .55433 .84807 L p .707 .577 .707 r
F P
0 g
s
.51952 .63918 m .50156 .69346 L .51253 .70122 L p .707 .577 .707 r
F P
0 g
s
.68072 .77102 m .67469 .80822 L .69103 .80519 L p .707 .577 .707 r
F P
0 g
s
.69103 .80519 m .69706 .768 L .68072 .77102 L p .707 .577 .707 r
F P
0 g
s
.67113 .82336 m .67559 .84074 L .69815 .82763 L p .707 .577 .707 r
F P
0 g
s
.69815 .82763 m .69369 .81024 L .67113 .82336 L p .707 .577 .707 r
F P
0 g
s
.55433 .84807 m .55879 .86545 L .58612 .86503 L p .707 .577 .707 r
F P
0 g
s
.51185 .78047 m .51788 .74328 L .50562 .73539 L p .707 .577 .707 r
F P
0 g
s
.70325 .70154 m .68529 .75583 L .69308 .75398 L p .707 .577 .707 r
F P
0 g
s
.69308 .75398 m .71103 .6997 L .70325 .70154 L p .707 .577 .707 r
F P
0 g
s
.55879 .86545 m .55433 .84807 L .53294 .84425 L p .707 .577 .707 r
F P
0 g
s
.50562 .73539 m .49959 .77258 L .51185 .78047 L p .707 .577 .707 r
F P
0 g
s
.69369 .81024 m .69815 .82763 L .713 .81397 L p .707 .577 .707 r
F P
0 g
s
.713 .81397 m .70854 .79658 L .69369 .81024 L p .707 .577 .707 r
F P
0 g
s
.50156 .69346 m .51952 .63918 L .51785 .63412 L p .707 .577 .707 r
F P
0 g
s
.53294 .84425 m .5374 .86164 L .55879 .86545 L p .707 .577 .707 r
F P
0 g
s
.51785 .63412 m .49989 .68841 L .50156 .69346 L p .707 .577 .707 r
F P
0 g
s
.69706 .768 m .69103 .80519 L .69822 .79998 L p .707 .577 .707 r
F P
0 g
s
.69822 .79998 m .70425 .76279 L .69706 .768 L p .707 .577 .707 r
F P
0 g
s
.49959 .77258 m .50562 .73539 L .50296 .7285 L p .707 .577 .707 r
F P
0 g
s
.5374 .86164 m .53294 .84425 L .51956 .83656 L p .707 .577 .707 r
F P
0 g
s
.71103 .6997 m .69308 .75398 L .6914 .74893 L p .707 .577 .707 r
F P
0 g
s
.6914 .74893 m .70936 .69465 L .71103 .6997 L p .707 .577 .707 r
F P
0 g
s
.50296 .7285 m .49693 .76569 L .49959 .77258 L p .707 .577 .707 r
F P
0 g
s
.70854 .79658 m .713 .81397 L .71868 .80112 L p .707 .577 .707 r
F P
0 g
s
.71868 .80112 m .71422 .78373 L .70854 .79658 L p .707 .577 .707 r
F P
0 g
s
.51956 .83656 m .52403 .85395 L .5374 .86164 L p .707 .577 .707 r
F P
0 g
s
.49989 .68841 m .51785 .63412 L .52563 .63228 L p .707 .577 .707 r
F P
0 g
s
.52563 .63228 m .50767 .68657 L .49989 .68841 L p .707 .577 .707 r
F P
0 g
s
.50767 .68657 m .52563 .63228 L .5421 .63383 L p .707 .577 .707 r
F P
0 g
s
.5421 .63383 m .52414 .68811 L .50767 .68657 L p .707 .577 .707 r
F P
0 g
s
.52403 .85395 m .51956 .83656 L .51552 .82576 L p .707 .577 .707 r
F P
0 g
s
.51552 .82576 m .51998 .84315 L .52403 .85395 L p .707 .577 .707 r
F P
0 g
s
.51998 .84315 m .51552 .82576 L .5212 .81291 L p .707 .577 .707 r
F P
0 g
s
.50412 .76048 m .51015 .72329 L .52649 .72027 L p .707 .577 .707 r
F P
0 g
s
.52649 .72027 m .52046 .75746 L .50412 .76048 L p .707 .577 .707 r
F P
0 g
s
.5199 .82155 m .5199 .31966 L .47477 .31944 L p .707 .577 .707 r
F P
0 g
s
.5212 .81291 m .52566 .8303 L .51998 .84315 L p .707 .577 .707 r
F P
0 g
s
.52414 .68811 m .5421 .63383 L .56566 .63862 L p .707 .577 .707 r
F P
0 g
s
.56566 .63862 m .5477 .6929 L .52414 .68811 L p .707 .577 .707 r
F P
0 g
s
.52566 .8303 m .5212 .81291 L .53605 .79925 L p .707 .577 .707 r
F P
0 g
s
.52046 .75746 m .52649 .72027 L .55038 .71973 L p .707 .577 .707 r
F P
0 g
s
.5477 .6929 m .56566 .63862 L .59399 .64617 L p .707 .577 .707 r
F P
0 g
s
.53605 .79925 m .54051 .81664 L .52566 .8303 L p .707 .577 .707 r
F P
0 g
s
.55038 .71973 m .54435 .75693 L .52046 .75746 L p .707 .577 .707 r
F P
0 g
s
.59399 .64617 m .57603 .70046 L .5477 .6929 L p .707 .577 .707 r
F P
0 g
s
.54435 .75693 m .55038 .71973 L .57947 .72173 L p .707 .577 .707 r
F P
0 g
s
.54051 .81664 m .53605 .79925 L .55861 .78614 L p .707 .577 .707 r
F P
0 g
s
.57947 .72173 m .57345 .75892 L .54435 .75693 L p .707 .577 .707 r
F P
0 g
s
.55861 .78614 m .56307 .80352 L .54051 .81664 L p .707 .577 .707 r
F P
0 g
s
.56307 .80352 m .55861 .78614 L .58668 .77484 L p .707 .577 .707 r
F P
0 g
s
.5199 .31966 m .5199 .82155 L .56307 .81803 L p .707 .577 .707 r
F P
0 g
s
.56307 .81803 m .56307 .31614 L .5199 .31966 L p .707 .577 .707 r
F P
0 g
s
.47477 .82133 m .47477 .31944 L .43212 .31548 L p .707 .577 .707 r
F P
0 g
s
.49693 .76569 m .50296 .7285 L .51015 .72329 L p .707 .577 .707 r
F P
0 g
s
.51015 .72329 m .50412 .76048 L .49693 .76569 L p .707 .577 .707 r
F P
0 g
s
.47477 .31944 m .47477 .82133 L .5199 .82155 L p .707 .577 .707 r
F P
0 g
s
.57603 .70046 m .59399 .64617 L .62432 .65576 L p .707 .577 .707 r
F P
0 g
s
.62432 .65576 m .60636 .71004 L .57603 .70046 L p .707 .577 .707 r
F P
0 g
s
.57345 .75892 m .57947 .72173 L .61093 .72607 L p .707 .577 .707 r
F P
0 g
s
.61093 .72607 m .6049 .76326 L .57345 .75892 L p .707 .577 .707 r
F P
0 g
s
.58668 .77484 m .59114 .79223 L .56307 .80352 L p .707 .577 .707 r
F P
0 g
s
.59114 .79223 m .58668 .77484 L .61751 .76647 L p .707 .577 .707 r
F P
0 g
s
.61751 .76647 m .62198 .78386 L .59114 .79223 L p .707 .577 .707 r
F P
0 g
s
.56307 .31614 m .56307 .81803 L .60007 .81109 L p .707 .577 .707 r
F P
0 g
s
.60007 .81109 m .60007 .30921 L .56307 .31614 L p .707 .577 .707 r
F P
0 g
s
.70425 .76279 m .69822 .79998 L .69556 .7931 L p .707 .577 .707 r
F P
0 g
s
.69556 .7931 m .70159 .7559 L .70425 .76279 L p .707 .577 .707 r
F P
0 g
s
.43212 .81737 m .43212 .31548 L .39611 .30818 L p .707 .577 .707 r
F P
0 g
s
.43212 .31548 m .43212 .81737 L .47477 .82133 L p .707 .577 .707 r
F P
0 g
s
.70936 .69465 m .6914 .74893 L .68044 .74117 L p .707 .577 .707 r
F P
0 g
s
.68044 .74117 m .69839 .68689 L .70936 .69465 L p .707 .577 .707 r
F P
0 g
s
.71422 .78373 m .71868 .80112 L .71464 .79032 L p .707 .577 .707 r
F P
0 g
s
.71464 .79032 m .71018 .77293 L .71422 .78373 L p .707 .577 .707 r
F P
0 g
s
.24858 .73802 m .25642 .69069 L .22566 .68292 L p .707 .577 .707 r
F P
0 g
s
.25642 .69069 m .24858 .73802 L .28016 .7403 L p .707 .577 .707 r
F P
0 g
s
.28016 .7403 m .288 .69297 L .25642 .69069 L p .707 .577 .707 r
F P
0 g
s
.21782 .73025 m .22566 .68292 L .19875 .67041 L p .707 .577 .707 r
F P
0 g
s
.22566 .68292 m .21782 .73025 L .24858 .73802 L p .707 .577 .707 r
F P
0 g
s
.288 .69297 m .28016 .7403 L .30949 .73686 L p .707 .577 .707 r
F P
0 g
s
.30949 .73686 m .31733 .68953 L .288 .69297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.65369 .66644 m .63573 .72072 L .60636 .71004 L p .707 .577 .707 r
F P
0 g
s
.60636 .71004 m .62432 .65576 L .65369 .66644 L p .707 .577 .707 r
F P
0 g
s
.64168 .73232 m .63565 .76952 L .6049 .76326 L p .707 .577 .707 r
F P
0 g
s
.6049 .76326 m .61093 .72607 L .64168 .73232 L p .707 .577 .707 r
F P
0 g
s
.66869 .73988 m .66266 .77708 L .63565 .76952 L p .707 .577 .707 r
F P
0 g
s
.64809 .76185 m .65255 .77924 L .62198 .78386 L p .707 .577 .707 r
F P
0 g
s
.63565 .76952 m .64168 .73232 L .66869 .73988 L p .707 .577 .707 r
F P
0 g
s
.62198 .78386 m .61751 .76647 L .64809 .76185 L p .707 .577 .707 r
F P
0 g
s
.60007 .30921 m .60007 .81109 L .62728 .80143 L p .707 .577 .707 r
F P
0 g
s
.62728 .80143 m .62728 .29954 L .60007 .30921 L p .707 .577 .707 r
F P
0 g
s
.39611 .81007 m .39611 .30818 L .37027 .29825 L p .707 .577 .707 r
F P
0 g
s
.39611 .30818 m .39611 .81007 L .43212 .81737 L p .707 .577 .707 r
F P
0 g
s
.70159 .7559 m .69556 .7931 L .68331 .7852 L p .707 .577 .707 r
F P
0 g
s
.68331 .7852 m .68934 .74801 L .70159 .7559 L p .707 .577 .707 r
F P
0 g
s
.19091 .71774 m .19875 .67041 L .17832 .65439 L p .707 .577 .707 r
F P
0 g
s
.19875 .67041 m .19091 .71774 L .21782 .73025 L p .707 .577 .707 r
F P
0 g
s
.31733 .68953 m .30949 .73686 L .33368 .72804 L p .707 .577 .707 r
F P
0 g
s
.33368 .72804 m .34152 .68071 L .31733 .68953 L p .707 .577 .707 r
F P
0 g
s
.26506 .79671 m .26309 .7776 L .23178 .78055 L p .707 .577 .707 r
F P
0 g
s
.26309 .7776 m .26506 .79671 L .29655 .79326 L p .707 .577 .707 r
F P
0 g
s
.29655 .79326 m .29458 .77415 L .26309 .7776 L p .707 .577 .707 r
F P
0 g
s
.23178 .78055 m .23375 .79966 L .26506 .79671 L p .707 .577 .707 r
F P
0 g
s
.69839 .68689 m .68044 .74117 L .66125 .73145 L p .707 .577 .707 r
F P
0 g
s
.66125 .73145 m .67921 .67716 L .69839 .68689 L p .707 .577 .707 r
F P
0 g
s
.25062 .78601 m .25322 .75112 L .22213 .74623 L p .707 .577 .707 r
F P
0 g
s
.25322 .75112 m .25062 .78601 L .28239 .78679 L p .707 .577 .707 r
F P
0 g
s
.28239 .78679 m .28499 .75189 L .25322 .75112 L p .707 .577 .707 r
F P
0 g
s
.29458 .77415 m .29655 .79326 L .32515 .78965 L p .707 .577 .707 r
F P
0 g
s
.32515 .78965 m .32318 .77054 L .29458 .77415 L p .707 .577 .707 r
F P
0 g
s
.71018 .77293 m .71464 .79032 L .70126 .78263 L p .707 .577 .707 r
F P
0 g
s
.70126 .78263 m .6968 .76525 L .71018 .77293 L p .707 .577 .707 r
F P
0 g
s
.23375 .79966 m .23178 .78055 L .20372 .78272 L p .707 .577 .707 r
F P
0 g
s
.20372 .78272 m .20569 .80183 L .23375 .79966 L p .707 .577 .707 r
F P
0 g
s
.28499 .75189 m .28239 .78679 L .31173 .78337 L p .707 .577 .707 r
F P
0 g
s
.31173 .78337 m .31433 .74848 L .28499 .75189 L p .707 .577 .707 r
F P
0 g
s
.21953 .78112 m .22213 .74623 L .19477 .7377 L p .707 .577 .707 r
F P
0 g
s
.22213 .74623 m .21953 .78112 L .25062 .78601 L p .707 .577 .707 r
F P
0 g
s
.17047 .70172 m .17832 .65439 L .16636 .63643 L p .707 .577 .707 r
F P
0 g
s
.17832 .65439 m .17047 .70172 L .19091 .71774 L p .707 .577 .707 r
F P
0 g
s
.34152 .68071 m .33368 .72804 L .35037 .7147 L p .707 .577 .707 r
F P
0 g
s
.35037 .7147 m .35822 .66737 L .34152 .68071 L p .707 .577 .707 r
F P
0 g
s
.32318 .77054 m .32515 .78965 L .34805 .78623 L p .707 .577 .707 r
F P
0 g
s
.34805 .78623 m .34608 .76712 L .32318 .77054 L p .707 .577 .707 r
F P
0 g
s
.31433 .74848 m .31173 .78337 L .33578 .77611 L p .707 .577 .707 r
F P
0 g
s
.33578 .77611 m .33837 .74122 L .31433 .74848 L p .707 .577 .707 r
F P
0 g
s
.67921 .67716 m .66125 .73145 L .63573 .72072 L p .707 .577 .707 r
F P
0 g
s
.63573 .72072 m .65369 .66644 L .67921 .67716 L p .707 .577 .707 r
F P
0 g
s
.62728 .29954 m .62728 .80143 L .64202 .78999 L p .707 .577 .707 r
F P
0 g
s
.64202 .78999 m .64202 .2881 L .62728 .29954 L p .707 .577 .707 r
F P
0 g
s
.68934 .74801 m .68331 .7852 L .66266 .77708 L p .707 .577 .707 r
F P
0 g
s
.66266 .77708 m .66869 .73988 L .68934 .74801 L p .707 .577 .707 r
F P
0 g
s
.20569 .80183 m .20372 .78272 L .18166 .78388 L p .707 .577 .707 r
F P
0 g
s
.18166 .78388 m .18363 .80299 L .20569 .80183 L p .707 .577 .707 r
F P
0 g
s
.19218 .77259 m .19477 .7377 L .17382 .72637 L p .707 .577 .707 r
F P
0 g
s
.19477 .7377 m .19218 .77259 L .21953 .78112 L p .707 .577 .707 r
F P
0 g
s
.37027 .80014 m .37027 .29825 L .35713 .28667 L p .707 .577 .707 r
F P
0 g
s
.37027 .29825 m .37027 .80014 L .39611 .81007 L p .707 .577 .707 r
F P
0 g
s
.6968 .76525 m .70126 .78263 L .67987 .77882 L p .707 .577 .707 r
F P
0 g
s
.67987 .77882 m .67541 .76143 L .6968 .76525 L p .707 .577 .707 r
F P
0 g
s
.15851 .68376 m .16636 .63643 L .16404 .61829 L p .707 .577 .707 r
F P
0 g
s
.16636 .63643 m .15851 .68376 L .17047 .70172 L p .707 .577 .707 r
F P
0 g
s
.35822 .66737 m .35488 .68751 L p .35794 .69815 L .707 .577 .707 r
F P
0 g
s
.35545 .70359 m .35794 .69815 L p .35488 .68751 L .707 .577 .707 r
F P
0 g
s
.35477 .7308 m .35217 .7657 L .3593 .75316 L p .707 .577 .707 r
F P
0 g
s
.3593 .75316 m .3619 .71827 L .35477 .7308 L p .707 .577 .707 r
F P
0 g
s
.35794 .69815 m .36578 .65082 L .35822 .66737 L p .707 .577 .707 r
F P
0 g
s
.36578 .65082 m .35794 .69815 L .35608 .68362 L p .707 .577 .707 r
F P
0 g
s
.35608 .68362 m .35562 .68001 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35615 .67849 m .36578 .65082 L .35608 .68362 L .707 .577 .707 r
F
.34608 .76712 m .34805 .78623 L .36302 .78334 L p F P
0 g
s
.36302 .78334 m .36105 .76423 L .34608 .76712 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .36578 .65082 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35562 .68001 m .35617 .67669 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35617 .67669 m .36347 .63268 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.36105 .76423 m .36302 .78334 L .36858 .78126 L p .707 .577 .707 r
F P
0 g
s
.36858 .78126 m .36661 .76216 L .36105 .76423 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .35562 .68001 L .34366 .66205 L p .707 .577 .707 r
F P
0 g
s
.34366 .66205 m .35151 .61472 L .36347 .63268 L p .707 .577 .707 r
F P
0 g
s
.3619 .71827 m .3593 .75316 L .35649 .73972 L p .707 .577 .707 r
F P
0 g
s
.35649 .73972 m .35908 .70483 L .3619 .71827 L p .707 .577 .707 r
F P
0 g
s
.36661 .76216 m .36858 .78126 L .3642 .7802 L p .707 .577 .707 r
F P
0 g
s
.3642 .7802 m .36223 .76109 L .36661 .76216 L p .707 .577 .707 r
F P
0 g
s
.35217 .7657 m .35477 .7308 L .33837 .74122 L p .707 .577 .707 r
F P
0 g
s
.35908 .70483 m .35649 .73972 L .34399 .72671 L p .707 .577 .707 r
F P
0 g
s
.35488 .68751 m .35037 .7147 L .35545 .70359 L p .707 .577 .707 r
F P
0 g
s
.34399 .72671 m .34658 .69182 L .35908 .70483 L p .707 .577 .707 r
F P
0 g
s
.36223 .76109 m .3642 .7802 L .35029 .78025 L p .707 .577 .707 r
F P
0 g
s
.33837 .74122 m .33578 .77611 L .35217 .7657 L p .707 .577 .707 r
F P
0 g
s
.35029 .78025 m .34832 .76114 L .36223 .76109 L p .707 .577 .707 r
F P
0 g
s
.35713 .28667 m .35713 .78856 L .37027 .80014 L p .707 .577 .707 r
F P
0 g
s
.35713 .75115 m .35713 .60146 L .35719 .75281 L .707 .577 .707 r
F
.35713 .60146 m .35713 .28667 L p .35717 .59839 L F P
0 g
s
.35713 .60146 m .35717 .59839 L .35719 .75281 L .707 .577 .707 r
F
.35713 .28667 m .35798 .27456 L p .35748 .57385 L F P
0 g
s
.35719 .75281 m .35717 .59839 L .35748 .57385 L .707 .577 .707 r
F
.35717 .59839 m .35713 .28667 L .35748 .57385 L F
.35713 .78856 m .35713 .75115 L p .35719 .75281 L F P
0 g
s
.17382 .72637 m .17122 .76126 L .19218 .77259 L p .707 .577 .707 r
F P
0 g
s
.18363 .80299 m .18166 .78388 L .16776 .78394 L p .707 .577 .707 r
F P
0 g
s
.17122 .76126 m .17382 .72637 L .16132 .71336 L p .707 .577 .707 r
F P
0 g
s
.16776 .78394 m .16973 .80305 L .18363 .80299 L p .707 .577 .707 r
F P
0 g
s
.67541 .76143 m .67987 .77882 L .65255 .77924 L p .707 .577 .707 r
F P
0 g
s
.65255 .77924 m .64809 .76185 L .67541 .76143 L p .707 .577 .707 r
F P
0 g
s
.64202 .2881 m .64202 .78999 L .64287 .77788 L p .707 .577 .707 r
F P
0 g
s
.64287 .77788 m .64287 .27599 L .64202 .2881 L p .707 .577 .707 r
F P
0 g
s
.16132 .71336 m .15872 .74825 L .17122 .76126 L p .707 .577 .707 r
F P
0 g
s
.16404 .61829 m .1562 .66562 L .15851 .68376 L p .707 .577 .707 r
F P
0 g
s
.1562 .66562 m .16404 .61829 L .1716 .60174 L p .707 .577 .707 r
F P
0 g
s
.15872 .74825 m .16132 .71336 L .1585 .69992 L p .707 .577 .707 r
F P
0 g
s
.16973 .80305 m .16776 .78394 L .16337 .78287 L p .707 .577 .707 r
F P
0 g
s
.16337 .78287 m .16534 .80198 L .16973 .80305 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1585 .69992 m .1559 .73481 L .15872 .74825 L p .707 .577 .707 r
F P
0 g
s
.16376 .64907 m .1716 .60174 L .1883 .5884 L p .707 .577 .707 r
F P
0 g
s
.1716 .60174 m .16376 .64907 L .1562 .66562 L p .707 .577 .707 r
F P
0 g
s
.1559 .73481 m .1585 .69992 L .16564 .68738 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.64287 .27599 m .64287 .77788 L .62972 .76629 L p .707 .577 .707 r
F P
0 g
s
.62972 .76629 m .62972 .26441 L .64287 .27599 L p .707 .577 .707 r
F P
0 g
s
.16534 .80198 m .16337 .78287 L .16894 .78079 L p .707 .577 .707 r
F P
0 g
s
.16894 .78079 m .17091 .7999 L .16534 .80198 L p .707 .577 .707 r
F P
0 g
s
.35798 .77645 m .35798 .27456 L .37272 .26312 L p .707 .577 .707 r
F P
0 g
s
.35798 .27456 m .35798 .77645 L .35713 .78856 L p .707 .577 .707 r
F P
0 g
s
.1883 .5884 m .18045 .63573 L .16376 .64907 L p .707 .577 .707 r
F P
0 g
s
.18045 .63573 m .1883 .5884 L .21249 .57958 L p .707 .577 .707 r
F P
0 g
s
.35151 .61472 m .34366 .66205 L .32323 .64603 L p .707 .577 .707 r
F P
0 g
s
.32323 .64603 m .33107 .5987 L .35151 .61472 L p .707 .577 .707 r
F P
0 g
s
.16564 .68738 m .16304 .72228 L .1559 .73481 L p .707 .577 .707 r
F P
0 g
s
.16304 .72228 m .16564 .68738 L .18203 .67697 L p .707 .577 .707 r
F P
0 g
s
.20465 .62691 m .21249 .57958 L .24182 .57614 L p .707 .577 .707 r
F P
0 g
s
.21249 .57958 m .20465 .62691 L .18045 .63573 L p .707 .577 .707 r
F P
0 g
s
.33107 .5987 m .32323 .64603 L .29631 .63352 L p .707 .577 .707 r
F P
0 g
s
.29631 .63352 m .30416 .5862 L .33107 .5987 L p .707 .577 .707 r
F P
0 g
s
.17091 .7999 m .16894 .78079 L .1839 .7779 L p .707 .577 .707 r
F P
0 g
s
.1839 .7779 m .18587 .79701 L .17091 .7999 L p .707 .577 .707 r
F P
0 g
s
.18203 .67697 m .17943 .71186 L .16304 .72228 L p .707 .577 .707 r
F P
0 g
s
.23397 .62347 m .24182 .57614 L .2734 .57842 L p .707 .577 .707 r
F P
0 g
s
.24182 .57614 m .23397 .62347 L .20465 .62691 L p .707 .577 .707 r
F P
0 g
s
.30416 .5862 m .29631 .63352 L .26556 .62575 L p .707 .577 .707 r
F P
0 g
s
.26556 .62575 m .2734 .57842 L .30416 .5862 L p .707 .577 .707 r
F P
0 g
s
.62972 .26441 m .62972 .76629 L .60388 .75637 L p .707 .577 .707 r
F P
0 g
s
.60388 .75637 m .60388 .25448 L .62972 .26441 L p .707 .577 .707 r
F P
0 g
s
.34658 .69182 m .34399 .72671 L .32303 .71538 L p .707 .577 .707 r
F P
0 g
s
.32303 .71538 m .32563 .68049 L .34658 .69182 L p .707 .577 .707 r
F P
0 g
s
.2734 .57842 m .26556 .62575 L .23397 .62347 L p .707 .577 .707 r
F P
0 g
s
.37272 .76501 m .37272 .26312 L .39993 .25345 L p .707 .577 .707 r
F P
0 g
s
.37272 .26312 m .37272 .76501 L .35798 .77645 L p .707 .577 .707 r
F P
0 g
s
.17943 .71186 m .18203 .67697 L .20607 .66971 L p .707 .577 .707 r
F P
0 g
s
.34832 .76114 m .35029 .78025 L .32824 .78142 L p .707 .577 .707 r
F P
0 g
s
.32824 .78142 m .32627 .76231 L .34832 .76114 L p .707 .577 .707 r
F P
0 g
s
.18587 .79701 m .1839 .7779 L .20681 .77449 L p .707 .577 .707 r
F P
0 g
s
.20681 .77449 m .20878 .79359 L .18587 .79701 L p .707 .577 .707 r
F P
0 g
s
.32563 .68049 m .32303 .71538 L .29567 .70685 L p .707 .577 .707 r
F P
0 g
s
.29567 .70685 m .29827 .67196 L .32563 .68049 L p .707 .577 .707 r
F P
0 g
s
.20607 .66971 m .20348 .7046 L .17943 .71186 L p .707 .577 .707 r
F P
0 g
s
.20348 .7046 m .20607 .66971 L .23542 .66629 L p .707 .577 .707 r
F P
0 g
s
.69584 .57356 m .70368 .63064 L .73444 .62603 L p .707 .577 .707 r
F P
0 g
s
.73444 .62603 m .72659 .56894 L .69584 .57356 L p .707 .577 .707 r
F P
0 g
s
.72659 .56894 m .73444 .62603 L .76602 .62182 L p .707 .577 .707 r
F P
0 g
s
.60388 .25448 m .60388 .75637 L .56788 .74907 L p .707 .577 .707 r
F P
0 g
s
.56788 .74907 m .56788 .24718 L .60388 .25448 L p .707 .577 .707 r
F P
0 g
s
.76602 .62182 m .75818 .56474 L .72659 .56894 L p .707 .577 .707 r
F P
0 g
s
.75818 .56474 m .76602 .62182 L .79535 .61843 L p .707 .577 .707 r
F P
0 g
s
.32627 .76231 m .32824 .78142 L .30018 .78358 L p .707 .577 .707 r
F P
0 g
s
.30018 .78358 m .29821 .76447 L .32627 .76231 L p .707 .577 .707 r
F P
0 g
s
.29827 .67196 m .29567 .70685 L .26459 .70196 L p .707 .577 .707 r
F P
0 g
s
.26459 .70196 m .26719 .66707 L .29827 .67196 L p .707 .577 .707 r
F P
0 g
s
.39993 .25345 m .39993 .75534 L .37272 .76501 L p .707 .577 .707 r
F P
0 g
s
.39993 .75534 m .39993 .25345 L .43693 .24652 L p .707 .577 .707 r
F P
0 g
s
.23282 .70119 m .23542 .66629 L .26719 .66707 L p .707 .577 .707 r
F P
0 g
s
.23542 .66629 m .23282 .70119 L .20348 .7046 L p .707 .577 .707 r
F P
0 g
s
.79535 .61843 m .78751 .56135 L .75818 .56474 L p .707 .577 .707 r
F P
0 g
s
.20878 .79359 m .20681 .77449 L .2354 .77087 L p .707 .577 .707 r
F P
0 g
s
.2354 .77087 m .23737 .78998 L .20878 .79359 L p .707 .577 .707 r
F P
0 g
s
.66893 .57812 m .67677 .63521 L .70368 .63064 L p .707 .577 .707 r
F P
0 g
s
.70368 .63064 m .69584 .57356 L .66893 .57812 L p .707 .577 .707 r
F P
0 g
s
.26719 .66707 m .26459 .70196 L .23282 .70119 L p .707 .577 .707 r
F P
0 g
s
.73541 .70366 m .73281 .66553 L .70173 .66681 L p .707 .577 .707 r
F P
0 g
s
.73281 .66553 m .73541 .70366 L .76718 .7012 L p .707 .577 .707 r
F P
0 g
s
.76718 .7012 m .76458 .66307 L .73281 .66553 L p .707 .577 .707 r
F P
0 g
s
.78751 .56135 m .79535 .61843 L .81954 .61619 L p .707 .577 .707 r
F P
0 g
s
.76458 .66307 m .76718 .7012 L .79652 .69781 L p .707 .577 .707 r
F P
0 g
s
.79652 .69781 m .79392 .65968 L .76458 .66307 L p .707 .577 .707 r
F P
0 g
s
.81954 .61619 m .8117 .55911 L .78751 .56135 L p .707 .577 .707 r
F P
0 g
s
.29821 .76447 m .30018 .78358 L .26887 .78653 L p .707 .577 .707 r
F P
0 g
s
.26887 .78653 m .2669 .76742 L .29821 .76447 L p .707 .577 .707 r
F P
0 g
s
.70173 .66681 m .70432 .70494 L .73541 .70366 L p .707 .577 .707 r
F P
0 g
s
.23737 .78998 m .2354 .77087 L .2669 .76742 L p .707 .577 .707 r
F P
0 g
s
.2669 .76742 m .26887 .78653 L .23737 .78998 L p .707 .577 .707 r
F P
0 g
s
.70432 .70494 m .70173 .66681 L .67437 .66679 L p .707 .577 .707 r
F P
0 g
s
.64849 .58219 m .65633 .63928 L .67677 .63521 L p .707 .577 .707 r
F P
0 g
s
.67677 .63521 m .66893 .57812 L .64849 .58219 L p .707 .577 .707 r
F P
0 g
s
.67437 .66679 m .67697 .70491 L .70432 .70494 L p .707 .577 .707 r
F P
0 g
s
.56788 .24718 m .56788 .74907 L .52522 .74511 L p .707 .577 .707 r
F P
0 g
s
.52522 .74511 m .52522 .24322 L .56788 .24718 L p .707 .577 .707 r
F P
0 g
s
.79392 .65968 m .79652 .69781 L .82057 .69381 L p .707 .577 .707 r
F P
0 g
s
.82057 .69381 m .81797 .65568 L .79392 .65968 L p .707 .577 .707 r
F P
0 g
s
.43693 .74841 m .43693 .24652 L .4801 .24299 L p .707 .577 .707 r
F P
0 g
s
.43693 .24652 m .43693 .74841 L .39993 .75534 L p .707 .577 .707 r
F P
0 g
s
.8117 .55911 m .81954 .61619 L .83624 .61532 L p .707 .577 .707 r
F P
0 g
s
.67697 .70491 m .67437 .66679 L .65341 .66546 L p .707 .577 .707 r
F P
0 g
s
.83624 .61532 m .82839 .55823 L .8117 .55911 L p .707 .577 .707 r
F P
0 g
s
.52522 .24322 m .52522 .74511 L .4801 .74488 L p .707 .577 .707 r
F P
0 g
s
.4801 .74488 m .4801 .24299 L .52522 .24322 L p .707 .577 .707 r
F P
0 g
s
.4801 .24299 m .4801 .74488 L .43693 .74841 L p .707 .577 .707 r
F P
0 g
s
.65341 .66546 m .65601 .70359 L .67697 .70491 L p .707 .577 .707 r
F P
0 g
s
.63653 .58537 m .64437 .64246 L .65633 .63928 L p .707 .577 .707 r
F P
0 g
s
.65633 .63928 m .64849 .58219 L .63653 .58537 L p .707 .577 .707 r
F P
0 g
s
.81797 .65568 m .82057 .69381 L .83696 .68959 L p .707 .577 .707 r
F P
0 g
s
.83696 .68959 m .83436 .65146 L .81797 .65568 L p .707 .577 .707 r
F P
0 g
s
.73113 .77603 m .7331 .7592 L .70179 .75371 L p .707 .577 .707 r
F P
0 g
s
.7331 .7592 m .73113 .77603 L .76262 .77679 L p .707 .577 .707 r
F P
0 g
s
.76262 .77679 m .76459 .75996 L .7331 .7592 L p .707 .577 .707 r
F P
0 g
s
.69982 .77054 m .70179 .75371 L .67373 .74401 L p .707 .577 .707 r
F P
0 g
s
.70179 .75371 m .69982 .77054 L .73113 .77603 L p .707 .577 .707 r
F P
0 g
s
.76459 .75996 m .76262 .77679 L .79122 .77274 L p .707 .577 .707 r
F P
0 g
s
.79122 .77274 m .79319 .7559 L .76459 .75996 L p .707 .577 .707 r
F P
0 g
s
.65601 .70359 m .65341 .66546 L .64092 .66296 L p .707 .577 .707 r
F P
0 g
s
.82839 .55823 m .83624 .61532 L .8438 .6159 L p .707 .577 .707 r
F P
0 g
s
.8438 .6159 m .83596 .55881 L .82839 .55823 L p .707 .577 .707 r
F P
0 g
s
.67373 .74401 m .67176 .76084 L .69982 .77054 L p .707 .577 .707 r
F P
0 g
s
.64092 .66296 m .64351 .70109 L .65601 .70359 L p .707 .577 .707 r
F P
0 g
s
.67176 .76084 m .67373 .74401 L .65167 .73107 L p .707 .577 .707 r
F P
0 g
s
.79319 .7559 m .79122 .77274 L .81413 .76427 L p .707 .577 .707 r
F P
0 g
s
.81413 .76427 m .8161 .74744 L .79319 .7559 L p .707 .577 .707 r
F P
0 g
s
.83436 .65146 m .83696 .68959 L .8441 .68558 L p .707 .577 .707 r
F P
0 g
s
.8441 .68558 m .8415 .64745 L .83436 .65146 L p .707 .577 .707 r
F P
0 g
s
.63422 .58735 m .64206 .64443 L .64437 .64246 L p .707 .577 .707 r
F P
0 g
s
.64437 .64246 m .63653 .58537 L .63422 .58735 L p .707 .577 .707 r
F P
0 g
s
.65167 .73107 m .6497 .7479 L .67176 .76084 L p .707 .577 .707 r
F P
0 g
s
.6497 .7479 m .65167 .73107 L .63777 .71614 L p .707 .577 .707 r
F P
0 g
s
.64351 .70109 m .64092 .66296 L .6381 .65954 L p .707 .577 .707 r
F P
0 g
s
.8161 .74744 m .81413 .76427 L .82909 .75222 L p .707 .577 .707 r
F P
0 g
s
.82909 .75222 m .83106 .73538 L .8161 .74744 L p .707 .577 .707 r
F P
0 g
s
.83596 .55881 m .8438 .6159 L .84149 .61788 L p .707 .577 .707 r
F P
0 g
s
.6381 .65954 m .64069 .69767 L .64351 .70109 L p .707 .577 .707 r
F P
0 g
s
.84149 .61788 m .83364 .56079 L .83596 .55881 L p .707 .577 .707 r
F P
0 g
s
.63777 .71614 m .6358 .73297 L .6497 .7479 L p .707 .577 .707 r
F P
0 g
s
.8415 .64745 m .8441 .68558 L .84128 .68215 L p .707 .577 .707 r
F P
0 g
s
.84128 .68215 m .83868 .64402 L .8415 .64745 L p .707 .577 .707 r
F P
0 g
s
.64178 .58793 m .64962 .64501 L .64206 .64443 L p .707 .577 .707 r
F P
0 g
s
.64206 .64443 m .63422 .58735 L .64178 .58793 L p .707 .577 .707 r
F P
0 g
s
.6358 .73297 m .63777 .71614 L .63339 .70069 L p .707 .577 .707 r
F P
0 g
s
.83106 .73538 m .82909 .75222 L .83465 .73776 L p .707 .577 .707 r
F P
0 g
s
.83465 .73776 m .83662 .72093 L .83106 .73538 L p .707 .577 .707 r
F P
0 g
s
.63339 .70069 m .63142 .71753 L .6358 .73297 L p .707 .577 .707 r
F P
0 g
s
.64069 .69767 m .6381 .65954 L .64523 .65552 L p .707 .577 .707 r
F P
0 g
s
.83364 .56079 m .84149 .61788 L .82953 .62106 L p .707 .577 .707 r
F P
0 g
s
.42397 .6239 m .40601 .57343 L .37568 .58326 L p .707 .577 .707 r
F P
0 g
s
.40601 .57343 m .42397 .6239 L .4523 .61085 L p .707 .577 .707 r
F P
0 g
s
.4523 .61085 m .43434 .56038 L .40601 .57343 L p .707 .577 .707 r
F P
0 g
s
.64523 .65552 m .64783 .69365 L .64069 .69767 L p .707 .577 .707 r
F P
0 g
s
.82953 .62106 m .82168 .56397 L .83364 .56079 L p .707 .577 .707 r
F P
0 g
s
.39363 .63373 m .37568 .58326 L .34631 .58892 L p .707 .577 .707 r
F P
0 g
s
.37568 .58326 m .39363 .63373 L .42397 .6239 L p .707 .577 .707 r
F P
0 g
s
.43434 .56038 m .4523 .61085 L .47585 .59586 L p .707 .577 .707 r
F P
0 g
s
.47585 .59586 m .45789 .54539 L .43434 .56038 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83868 .64402 m .84128 .68215 L .82878 .67965 L p .707 .577 .707 r
F P
0 g
s
.82878 .67965 m .82618 .64152 L .83868 .64402 L p .707 .577 .707 r
F P
0 g
s
.36427 .63939 m .34631 .58892 L .32079 .58984 L p .707 .577 .707 r
F P
0 g
s
.34631 .58892 m .36427 .63939 L .39363 .63373 L p .707 .577 .707 r
F P
0 g
s
.63142 .71753 m .63339 .70069 L .63895 .68624 L p .707 .577 .707 r
F P
0 g
s
.65847 .58706 m .66632 .64414 L .64962 .64501 L p .707 .577 .707 r
F P
0 g
s
.64962 .64501 m .64178 .58793 L .65847 .58706 L p .707 .577 .707 r
F P
0 g
s
.83662 .72093 m .83465 .73776 L .83027 .72231 L p .707 .577 .707 r
F P
0 g
s
.83027 .72231 m .83224 .70548 L .83662 .72093 L p .707 .577 .707 r
F P
0 g
s
.45789 .54539 m .47585 .59586 L .49233 .58039 L p .707 .577 .707 r
F P
0 g
s
.49233 .58039 m .47437 .52992 L .45789 .54539 L p .707 .577 .707 r
F P
0 g
s
.63895 .68624 m .63698 .70307 L .63142 .71753 L p .707 .577 .707 r
F P
0 g
s
.39509 .68772 m .38906 .65189 L .35832 .65407 L p .707 .577 .707 r
F P
0 g
s
.38906 .65189 m .39509 .68772 L .42655 .68212 L p .707 .577 .707 r
F P
0 g
s
.42655 .68212 m .42052 .64628 L .38906 .65189 L p .707 .577 .707 r
F P
0 g
s
.42052 .64628 m .42655 .68212 L .45565 .67364 L p .707 .577 .707 r
F P
0 g
s
.45565 .67364 m .44962 .63781 L .42052 .64628 L p .707 .577 .707 r
F P
0 g
s
.64783 .69365 m .64523 .65552 L .66162 .6513 L p .707 .577 .707 r
F P
0 g
s
.82168 .56397 m .82953 .62106 L .80909 .62513 L p .707 .577 .707 r
F P
0 g
s
.80909 .62513 m .80125 .56804 L .82168 .56397 L p .707 .577 .707 r
F P
0 g
s
.37802 .71327 m .38248 .69482 L .35191 .68667 L p .707 .577 .707 r
F P
0 g
s
.38248 .69482 m .37802 .71327 L .40885 .71984 L p .707 .577 .707 r
F P
0 g
s
.40885 .71984 m .41331 .70139 L .38248 .69482 L p .707 .577 .707 r
F P
0 g
s
.66162 .6513 m .66422 .68943 L .64783 .69365 L p .707 .577 .707 r
F P
0 g
s
.33874 .64031 m .32079 .58984 L .3016 .58593 L p .707 .577 .707 r
F P
0 g
s
.32079 .58984 m .33874 .64031 L .36427 .63939 L p .707 .577 .707 r
F P
0 g
s
.36435 .6899 m .35832 .65407 L .33131 .65262 L p .707 .577 .707 r
F P
0 g
s
.35832 .65407 m .36435 .6899 L .39509 .68772 L p .707 .577 .707 r
F P
0 g
s
.35191 .68667 m .34745 .70512 L .37802 .71327 L p .707 .577 .707 r
F P
0 g
s
.44962 .63781 m .45565 .67364 L .47954 .66312 L p .707 .577 .707 r
F P
0 g
s
.47954 .66312 m .47351 .62729 L .44962 .63781 L p .707 .577 .707 r
F P
0 g
s
.34745 .70512 m .35191 .68667 L .32459 .67773 L p .707 .577 .707 r
F P
0 g
s
.41331 .70139 m .40885 .71984 L .43692 .72418 L p .707 .577 .707 r
F P
0 g
s
.43692 .72418 m .44139 .70573 L .41331 .70139 L p .707 .577 .707 r
F P
0 g
s
.32459 .67773 m .32013 .69618 L .34745 .70512 L p .707 .577 .707 r
F P
0 g
s
.68267 .58481 m .69051 .6419 L .66632 .64414 L p .707 .577 .707 r
F P
0 g
s
.66632 .64414 m .65847 .58706 L .68267 .58481 L p .707 .577 .707 r
F P
0 g
s
.63698 .70307 m .63895 .68624 L .65392 .67418 L p .707 .577 .707 r
F P
0 g
s
.82618 .64152 m .82878 .67965 L .80782 .67833 L p .707 .577 .707 r
F P
0 g
s
.80782 .67833 m .80523 .6402 L .82618 .64152 L p .707 .577 .707 r
F P
0 g
s
.47437 .52992 m .49233 .58039 L .50011 .56597 L p .707 .577 .707 r
F P
0 g
s
.50011 .56597 m .48215 .5155 L .47437 .52992 L p .707 .577 .707 r
F P
0 g
s
.33131 .65262 m .33733 .68845 L .36435 .6899 L p .707 .577 .707 r
F P
0 g
s
.83224 .70548 m .83027 .72231 L .81637 .70738 L p .707 .577 .707 r
F P
0 g
s
.81637 .70738 m .81834 .69055 L .83224 .70548 L p .707 .577 .707 r
F P
0 g
s
.33733 .68845 m .33131 .65262 L .31066 .64767 L p .707 .577 .707 r
F P
0 g
s
.32013 .69618 m .32459 .67773 L .3032 .66888 L p .707 .577 .707 r
F P
0 g
s
.65392 .67418 m .65195 .69101 L .63698 .70307 L p .707 .577 .707 r
F P
0 g
s
.44139 .70573 m .43692 .72418 L .45949 .72587 L p .707 .577 .707 r
F P
0 g
s
.45949 .72587 m .46395 .70741 L .44139 .70573 L p .707 .577 .707 r
F P
0 g
s
.80125 .56804 m .80909 .62513 L .78218 .62969 L p .707 .577 .707 r
F P
0 g
s
.3032 .66888 m .29873 .68733 L .32013 .69618 L p .707 .577 .707 r
F P
0 g
s
.47351 .62729 m .47954 .66312 L .49587 .65159 L p .707 .577 .707 r
F P
0 g
s
.49587 .65159 m .48985 .61576 L .47351 .62729 L p .707 .577 .707 r
F P
0 g
s
.3016 .58593 m .31956 .6364 L .33874 .64031 L p .707 .577 .707 r
F P
0 g
s
.66422 .68943 m .66162 .6513 L .68567 .6473 L p .707 .577 .707 r
F P
0 g
s
.78218 .62969 m .77433 .57261 L .80125 .56804 L p .707 .577 .707 r
F P
0 g
s
.31956 .6364 m .3016 .58593 L .29064 .57758 L p .707 .577 .707 r
F P
0 g
s
.68567 .6473 m .68827 .68543 L .66422 .68943 L p .707 .577 .707 r
F P
0 g
s
.71199 .58143 m .71984 .63851 L .69051 .6419 L p .707 .577 .707 r
F P
0 g
s
.69051 .6419 m .68267 .58481 L .71199 .58143 L p .707 .577 .707 r
F P
0 g
s
.31066 .64767 m .31669 .68351 L .33733 .68845 L p .707 .577 .707 r
F P
0 g
s
.80523 .6402 m .80782 .67833 L .78046 .6783 L p .707 .577 .707 r
F P
0 g
s
.78046 .6783 m .77787 .64017 L .80523 .6402 L p .707 .577 .707 r
F P
0 g
s
.65195 .69101 m .65392 .67418 L .67682 .66571 L p .707 .577 .707 r
F P
0 g
s
.77433 .57261 m .78218 .62969 L .75142 .6343 L p .707 .577 .707 r
F P
0 g
s
.29873 .68733 m .3032 .66888 L .28982 .66098 L p .707 .577 .707 r
F P
0 g
s
.75142 .6343 m .74358 .57722 L .77433 .57261 L p .707 .577 .707 r
F P
0 g
s
.81834 .69055 m .81637 .70738 L .79431 .69444 L p .707 .577 .707 r
F P
0 g
s
.79431 .69444 m .79628 .67761 L .81834 .69055 L p .707 .577 .707 r
F P
0 g
s
.48215 .5155 m .50011 .56597 L .49844 .554 L p .707 .577 .707 r
F P
0 g
s
.49844 .554 m .48048 .50353 L .48215 .5155 L p .707 .577 .707 r
F P
0 g
s
.31669 .68351 m .31066 .64767 L .29841 .63972 L p .707 .577 .707 r
F P
0 g
s
.46395 .70741 m .45949 .72587 L .47434 .72473 L p .707 .577 .707 r
F P
0 g
s
.47434 .72473 m .4788 .70628 L .46395 .70741 L p .707 .577 .707 r
F P
0 g
s
.74358 .57722 m .75142 .6343 L .71984 .63851 L p .707 .577 .707 r
F P
0 g
s
.71984 .63851 m .71199 .58143 L .74358 .57722 L p .707 .577 .707 r
F P
0 g
s
.28982 .66098 m .28536 .67943 L .29873 .68733 L p .707 .577 .707 r
F P
0 g
s
.68827 .68543 m .68567 .6473 L .71501 .64391 L p .707 .577 .707 r
F P
0 g
s
.67682 .66571 m .67485 .68255 L .65195 .69101 L p .707 .577 .707 r
F P
0 g
s
.48985 .61576 m .49587 .65159 L .50306 .64017 L p .707 .577 .707 r
F P
0 g
s
.50306 .64017 m .49704 .60434 L .48985 .61576 L p .707 .577 .707 r
F P
0 g
s
.29064 .57758 m .3086 .62805 L .31956 .6364 L p .707 .577 .707 r
F P
0 g
s
.71501 .64391 m .71761 .68204 L .68827 .68543 L p .707 .577 .707 r
F P
0 g
s
.77787 .64017 m .78046 .6783 L .74938 .67958 L p .707 .577 .707 r
F P
0 g
s
.74938 .67958 m .74678 .64145 L .77787 .64017 L p .707 .577 .707 r
F P
0 g
s
.29841 .63972 m .30444 .67555 L .31669 .68351 L p .707 .577 .707 r
F P
0 g
s
.3086 .62805 m .29064 .57758 L .28896 .56561 L p .707 .577 .707 r
F P
0 g
s
.67485 .68255 m .67682 .66571 L .70542 .66166 L p .707 .577 .707 r
F P
0 g
s
.71761 .68204 m .71501 .64391 L .74678 .64145 L p .707 .577 .707 r
F P
0 g
s
.74678 .64145 m .74938 .67958 L .71761 .68204 L p .707 .577 .707 r
F P
0 g
s
.79628 .67761 m .79431 .69444 L .76625 .68475 L p .707 .577 .707 r
F P
0 g
s
.76625 .68475 m .76822 .66791 L .79628 .67761 L p .707 .577 .707 r
F P
0 g
s
.70542 .66166 m .70345 .67849 L .67485 .68255 L p .707 .577 .707 r
F P
0 g
s
.28536 .67943 m .28982 .66098 L .28578 .65481 L p .707 .577 .707 r
F P
0 g
s
.70345 .67849 m .70542 .66166 L .73691 .66242 L p .707 .577 .707 r
F P
0 g
s
.48048 .50353 m .49844 .554 L .48747 .54565 L p .707 .577 .707 r
F P
0 g
s
.48747 .54565 m .46951 .49518 L .48048 .50353 L p .707 .577 .707 r
F P
0 g
s
.30444 .67555 m .29841 .63972 L .29575 .62954 L p .707 .578 .707 r
F P
0 g
s
.4788 .70628 m .47434 .72473 L .48002 .7209 L p .707 .577 .707 r
F P
0 g
s
.48002 .7209 m .48448 .70244 L .4788 .70628 L p .707 .577 .707 r
F P
0 g
s
.28578 .65481 m .28131 .67326 L .28536 .67943 L p .707 .577 .707 r
F P
0 g
s
.76822 .66791 m .76625 .68475 L .73494 .67925 L p .707 .577 .707 r
F P
0 g
s
.73494 .67925 m .73691 .66242 L .76822 .66791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73691 .66242 m .73494 .67925 L .70345 .67849 L p .707 .577 .707 r
F P
0 g
s
.49704 .60434 m .50306 .64017 L .5004 .62999 L p .707 .578 .707 r
F P
0 g
s
.5004 .62999 m .49438 .59416 L .49704 .60434 L p .707 .578 .707 r
F P
0 g
s
.28896 .56561 m .30692 .61608 L .3086 .62805 L p .707 .577 .707 r
F P
0 g
s
.29575 .62954 m .30177 .66537 L .30444 .67555 L p .707 .578 .707 r
F P
0 g
s
.30692 .61608 m .28896 .56561 L .29674 .55119 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.46951 .49518 m .48747 .54565 L .46829 .54174 L p .707 .577 .707 r
F P
0 g
s
.46829 .54174 m .45033 .49127 L .46951 .49518 L p .707 .577 .707 r
F P
0 g
s
.28131 .67326 m .28578 .65481 L .29145 .65097 L p .707 .577 .707 r
F P
0 g
s
.30177 .66537 m .29575 .62954 L .30294 .61812 L p .707 .577 .707 r
F P
0 g
s
.48448 .70244 m .48002 .7209 L .47597 .71473 L p .707 .577 .707 r
F P
0 g
s
.47597 .71473 m .48043 .69627 L .48448 .70244 L p .707 .577 .707 r
F P
0 g
s
.29145 .65097 m .28699 .66942 L .28131 .67326 L p .707 .577 .707 r
F P
0 g
s
.29674 .55119 m .3147 .60166 L .30692 .61608 L p .707 .577 .707 r
F P
0 g
s
.49438 .59416 m .5004 .62999 L .48815 .62204 L p .707 .577 .707 r
F P
0 g
s
.48815 .62204 m .48212 .5862 L .49438 .59416 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3147 .60166 m .29674 .55119 L .31322 .53572 L p .707 .577 .707 r
F P
0 g
s
.30294 .61812 m .30896 .65395 L .30177 .66537 L p .707 .577 .707 r
F P
0 g
s
.45033 .49127 m .46829 .54174 L .44276 .54266 L p .707 .577 .707 r
F P
0 g
s
.44276 .54266 m .4248 .49219 L .45033 .49127 L p .707 .577 .707 r
F P
0 g
s
.30896 .65395 m .30294 .61812 L .31927 .60659 L p .707 .577 .707 r
F P
0 g
s
.28699 .66942 m .29145 .65097 L .3063 .64984 L p .707 .577 .707 r
F P
0 g
s
.48043 .69627 m .47597 .71473 L .4626 .70683 L p .707 .577 .707 r
F P
0 g
s
.4626 .70683 m .46706 .68838 L .48043 .69627 L p .707 .577 .707 r
F P
0 g
s
.31322 .53572 m .33118 .58619 L .3147 .60166 L p .707 .577 .707 r
F P
0 g
s
.3063 .64984 m .30184 .66829 L .28699 .66942 L p .707 .577 .707 r
F P
0 g
s
.33118 .58619 m .31322 .53572 L .33677 .52073 L p .707 .577 .707 r
F P
0 g
s
.48212 .5862 m .48815 .62204 L .46751 .61709 L p .707 .577 .707 r
F P
0 g
s
.46751 .61709 m .46148 .58126 L .48212 .5862 L p .707 .577 .707 r
F P
0 g
s
.31927 .60659 m .3253 .64242 L .30896 .65395 L p .707 .577 .707 r
F P
0 g
s
.4248 .49219 m .44276 .54266 L .4134 .54831 L p .707 .577 .707 r
F P
0 g
s
.4134 .54831 m .39544 .49784 L .4248 .49219 L p .707 .577 .707 r
F P
0 g
s
.35473 .5712 m .33677 .52073 L .3651 .50768 L p .707 .577 .707 r
F P
0 g
s
.33677 .52073 m .35473 .5712 L .33118 .58619 L p .707 .577 .707 r
F P
0 g
s
.3253 .64242 m .31927 .60659 L .34316 .59607 L p .707 .577 .707 r
F P
0 g
s
.39544 .49784 m .4134 .54831 L .38306 .55815 L p .707 .577 .707 r
F P
0 g
s
.38306 .55815 m .3651 .50768 L .39544 .49784 L p .707 .577 .707 r
F P
0 g
s
.3651 .50768 m .38306 .55815 L .35473 .5712 L p .707 .577 .707 r
F P
0 g
s
.46148 .58126 m .46751 .61709 L .44049 .61564 L p .707 .577 .707 r
F P
0 g
s
.44049 .61564 m .43446 .57981 L .46148 .58126 L p .707 .577 .707 r
F P
0 g
s
.30184 .66829 m .3063 .64984 L .32887 .65153 L p .707 .577 .707 r
F P
0 g
s
.46706 .68838 m .4626 .70683 L .4412 .69798 L p .707 .577 .707 r
F P
0 g
s
.4412 .69798 m .44566 .67953 L .46706 .68838 L p .707 .577 .707 r
F P
0 g
s
.32887 .65153 m .32441 .66998 L .30184 .66829 L p .707 .577 .707 r
F P
0 g
s
.34316 .59607 m .34919 .6319 L .3253 .64242 L p .707 .577 .707 r
F P
0 g
s
.34919 .6319 m .34316 .59607 L .37226 .58759 L p .707 .577 .707 r
F P
0 g
s
.43446 .57981 m .44049 .61564 L .40975 .61782 L p .707 .577 .707 r
F P
0 g
s
.40975 .61782 m .40372 .58199 L .43446 .57981 L p .707 .577 .707 r
F P
0 g
s
.32441 .66998 m .32887 .65153 L .35694 .65587 L p .707 .577 .707 r
F P
0 g
s
.44566 .67953 m .4412 .69798 L .41388 .68904 L p .707 .577 .707 r
F P
0 g
s
.41388 .68904 m .41834 .67059 L .44566 .67953 L p .707 .577 .707 r
F P
0 g
s
.37829 .62343 m .37226 .58759 L .40372 .58199 L p .707 .577 .707 r
F P
0 g
s
.37226 .58759 m .37829 .62343 L .34919 .6319 L p .707 .577 .707 r
F P
0 g
s
.40372 .58199 m .40975 .61782 L .37829 .62343 L p .707 .577 .707 r
F P
0 g
s
.35694 .65587 m .35248 .67432 L .32441 .66998 L p .707 .577 .707 r
F P
0 g
s
.35248 .67432 m .35694 .65587 L .38777 .66243 L p .707 .577 .707 r
F P
0 g
s
.41834 .67059 m .41388 .68904 L .38331 .68089 L p .707 .577 .707 r
F P
0 g
s
.38331 .68089 m .38777 .66243 L .41834 .67059 L p .707 .577 .707 r
F P
0 g
s
.38777 .66243 m .38331 .68089 L .35248 .67432 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF1`001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP04001JEUYFFUH80003FUH00`00FUIJEP030002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001EYF1P000eYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1000FUIJEUYF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00@005YF000000QJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000>FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol30009FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001SOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001QOol20005FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005moo`8000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005eoo`<000UJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005aoo`05001JEUYFFUH0
0008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Yoo`80
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol005Uoo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0002FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001E
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH60002FUH00`00
FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH30008FUH01000FUIJEUYF0`001EYF00<005YFFUH00`001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00Dgoo0P001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YF00000`002UYF00@005YF000000=JEP03001JEUYF
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol005=oo`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP8000=JEP03001JEUYF00QJEP8000EJEP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000<Woo1@00;goo001BOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0`002EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0002Eoo`d0009JEP800003FUIoogoo02eoo`00DWoo00@005YFFUH0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEPD000IJEP<000QJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0000LOol90003FUH00`00FUIJEP04FUH500000eYF001JEP0_Ool0059oo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEPD000AJEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00005Goo1`0015YF00<005YFFUH01EYF20000UYF00D005YFFUH005YF02moo`00
DWoo0P000UYF00<005YFFUH015YF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF1@000UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0000AOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06
0003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo0011Ool80009Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P001UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00>goo1P000eYF00<005YFFUH00UYF1`000Woo0P000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=oo`05001JEUYFFUH00003FUH40002FUH01000FUIJEUYF20001UYF
00<005YFFUH00eYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Eoo`H000=JEP03001JEUYF00IJEPP000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool003Uoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<00005
FUH005YFFUH00006FUH30004Ool01000FUIJEUYF10000eYF1`0015YF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH60002
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP02000^Ool003Moo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP80009JEP03001JEUYF00AJEP03001oogoo00Aoo`@00003FUH005YF00@0009JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000800003FUH0000000d000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0P001EYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF10001UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00P00
0eYF10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000aOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00@005YF001JEP800003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo000`Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP020006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH2000015YF000000001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUIJEP001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEP00008000YJEP@0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPD002moo`00;Woo0P000eYF00<005YF
FUH015YF00<005YFFUH00UYF3P001eYF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF
0`000UYF00<005YFFUH025YF0P000UYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1@00=7oo000^Ool20003FUH00`00FUIJEP03FUH6
000>Ool30004FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH40002FUH30005
FUH00`00FUIJEP06FUH20004FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<003Uoo`00;Goo00<005YF00000eYF00<005YF00000`005goo0`0000AJ
EP00FUH000AJEP03001JEUYF00AJEPD000MJEPH000QJEP03001JEUYF00AJEP800003FUH005YF00=J
EP04001JEUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH003eo
o`00;Goo00<005YF00000eYF0P007Woo0P0000=JEP00FUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF009JEPL000UJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004=oo`00;Goo0P000eYF00<007ooOol07goo00@0
05YFFUH000AJEP03001JEP00008000=JEPP0009JEPD000UJEP03001JEP00008000IJEP03001JEUYF
009JEP03001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000C7oo000]Ool200000eYF0000000R
Ool01000FUIJEP0015YF0P0000=JEP0000000`0000=JEP00FUH00UYF00<005YFFUH00eYF0`0025YF
100000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF20001goo7000<Goo000]
Ool4000SOol01000FUIJEP000UYF0P001UYF00@005YFFUH000=JEP03001JEUYF00EJEP04001JEUYF
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF2`001Woo2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool20002FUH00`00Oomoo`0POol700000goo001J
EP04FUH01000FUIJEP000eYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Uoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`05FUH005YFFUH0000FOol30007Ool30002FUH00`00FUIJ
EP080003FUH01000FUIJEUYF20001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
00=oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP03001oogoo019oo`D000Eoo`8000=J
EP03001JEUYF00AJEP04001JEUYFFUH90004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP<0019oo`D000Eo
o`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP0000=JEP04001JEUYF000AOol50004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
014000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
0eYF00@005YFFUIJEP8000Moo`l0009oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP00009JEP03001JEUYF00AJEPL000=JEP03001J
EUYF00IJEP03001JEUYF00800003FUH0000000d000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00QJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP@00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEP000007FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUIJEP02FUH0
1000FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF
0005FUH70007FUH00`00FUIJEP06FUH01000FUH000001UYF0`001EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUH005YF001JEP020005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002eoo`00;Goo00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH40002FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH0009JEP8000EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0000]Ool002eoo`04001JEUYFFUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP800003FUH005YF00=J
EP03001JEUYF00AJEP04001JEUYFFUH50006FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH015YF
00<005YFFUH010000UYF3@0015YF00<005YFFUH01UYF0`000eYF2000;Goo000]Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUH000020005FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00UYF2P0025YF00<005YFFUH00UYF1P001eYF00@005YFFUH000=JEP07001JEUYF
FUH005YF0000;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUH000050004FUH00`00FUIJEP02FUH;0007FUH00`00FUIJEP02
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<005YF00001P001UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP06FUH90002FUH50004
FUH20004FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEP000eYF1@000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0000=JEP00FUH01EYF0P000UYF0P00;goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006
FUH00`00FUIJEP04FUH80007FUH300000eYF001JEP05FUH00`00FUH00002000<FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1000<Goo000]Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH0000015YF00<005YFFUH01UYF00<005YFFUH010002EYF0P001EYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0015YF00<005YF0000<Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH@0006FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<005YFFUH015YF1P00
0eYF00@005YF000000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000Eoo`80009JEP04001JEUYF000aOol002eoo`8000AJEP03001JEUYF009J
EPH00003FUH005YF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00MJEP04001JEUYFFUH900000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000L000@Ool30003FUH00`00
Oomoo`0^Ool002eoo`8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<000EJEP03001JEUYF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP040003FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUH005YF00001UYF00<005YFFUH015YF00@005YFFUIJEP8001ioo`05001JEUYF
FUH0000`Ool002eoo`8000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH50006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP04FUH01@00FUIJEP00FUH087oo00@005YFFUH0031oo`00;Goo0P000UYF
0P000Woo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP05001JEUYFFUH00003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP03000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF0000
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`005Goo00D005YF001JEP0002moo`00;7oo
00<005YF00000P001Goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0P001goo1@005Goo0P0000=JEP00Ool0;Woo000/
Ool01@00FUH005YF00001goo0P000eYF00<005YFFUH01eYF10001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPL000=JEP07001J
EUYFFUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF008000Qoo`D001Ioo`03001JEP0002moo`00;7oo0P00
0eYF00<007ooOol01Woo0P0000=JEP00FUH01eYF1P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
10000eYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00X000aJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP800003FUH005YF00EJEP04001JEUYFFUH20008
Ool5000FOol00`00FUH0000_Ool002aoo`8000=JEP<000Qoo`@000IJEPH000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00004FUH30006FUH01000FUIJEUYF0P002Goo0`0067oo0P00;goo000/Ool20003FUH00`00FUIJ
EP02000:Ool40002FUH60003FUH00`00FUIJEP05FUH00`00FUH000030006Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH50004FUH00`00FUIJEP02000UOol2000_
Ool002aoo`8000=JEP03001JEUYF009JEP<000]oo`L000AJEP03001JEUYF009JEPD000Qoo`800003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH01@00FUIJEP00FUH0
0P0000=JEP00FUH00UYF0P009Goo0P00;goo000/Ool20003FUH00`00FUIJEP03FUH01000FUH00000
47oo2@002goo0P000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0004FUH50003FUH00`00Oomoo`0ROol3000`Ool002eoo`04001JEUYF0006FUH01000FUIJEUYF0`00
7Goo100000=JEP00FUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH015YF
5@002EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<000IJEPL0029oo`800003FUH0
0000031oo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEPD001=oo`D000EJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEP0000@0
021oo`8000=JEP03001oogoo02moo`00;Woo00<005YF00001UYF00<005YFFUH01EYF00@005YFFUIJ
EQ<000=JEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF
0P0015YF00@005YFFUIJEP<001eoo`<00003FUH005YF009JEP03001oogoo02moo`00;Woo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP@000IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP04001JEUYFFUH50002FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF
00@005YFFUH000MJEPH001Aoo`<000AJEP04001JEUYF000bOol002moo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8000=JEP03001JEUYF009JEP<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEP@000EJEP05001JEUYFFUH00005FUH30008FUH00`00FUIJEP02FUH90007Ool4
00000eYF001JEP04FUH00`00FUH0000cOol0031oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEPd000=JEP03001JEP000080009JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00@00003FUH005YF009JEPX000MJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF
00=JEP8003Aoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF2@00
0eYF00<005YFFUH015YF00<005YF00000eYF0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00<005YF0000
1UYF0`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
=Goo000cOol200000eYF001JEP06FUH00`00FUIJEP06FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH00002FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUH00007FUH00`00FUH0
000200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000gOol003Eo
o`<000IJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP000080
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000kOol003Qoo`L000=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0001<0041oo`00<goo1@000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH>
0003FUH01000FUIJEP00DWoo000^Ool500000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH@00001EYF001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP03001JEUYF00=JEP800003FUH005YF00@0009JEP80055oo`00;Woo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00@005YFFUIJEPH0
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH30002
FUH00`00FUH0000200000eYF001oo`1@Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000=JEP03001JEUYF00IJEP03001JEUYF009JEPL000Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH00`0000AJEP00Oomo
o`80055oo`00;Woo00<005YF00000eYF00@005YFFUIJEPP0009JEP03001JEUYF00IJEP03001JEUYF
009JEPT000eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000Woo00@005YF0000051oo`00;goo0P000UYF1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF2@005goo0`001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00@005YF
FUIJEP<0009oo`04001JEUYF001@Ool002moo`@00003FUH005YF00AJEP03001JEUYF009JEPP0029o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00Ool2
0002FUH00`00Oomoo`1>Ool002mooa0002aoo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF
00AJEP03001JEUYF00@00006Ool005YF001JEP00DGoo001]Ool200000eYF001JEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUH0000E0004Ool01000
FUIJEUYF0P00DGoo001_Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH5000HOol00`00FUIJEP02FUH00`00Oomoo`1@Ool007=oo`D0009JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00D00003Ool0000000<001Eoo`<000AJ
EP03001oogoo051oo`00N7oo20001UYF00<005YFFUH02UYF00<005YFFUH015YF2@001Woo1@004goo
0P000UYF00D005YFFUIJEP0005=oo`00P7oo6P003goo1@004Goo0P001EYF00<005YF0000E7oo002B
Ool01P00FUIJEP00FUH0019oo`<0011oo`8000MJEP8005Eoo`00TWoo00<005YFFUH00P0097oo0P00
00=JEP00FUH01UYF00<007ooOol0E7oo002BOol01000FUIJEP008Woo0`0015YF00<005YFFUH00UYF
0P00Egoo002COol2000POol30007FUH01@00FUIJEUYF0000FGoo002COol2000LOol400000eYF001J
EP08FUH3001JOol009=oo`04001JEP00000EOol50006FUH00`00FUIJEP05FUH2001LOol009=oo`80
009JEP<000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8005ioo`00U7oo00@005YFFUH0
009JEPh000IJEP03001JEUYF00MJEP03001JEP000080061oo`00U7oo00@005YFFUH000EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@006=oo`00UGoo0P0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000Igoo002GOol30004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001[Ool009Yoo`<00003FUH005YF00=JEPP0079oo`00WGoo1P00NWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5866 .73235 m .60456 .67807 L .57519 .66739 L p .707 .577 .707 r
F P
0 g
s
.60456 .67807 m .5866 .73235 L .61693 .74193 L p .707 .577 .707 r
F P
0 g
s
.61693 .74193 m .63489 .68765 L .60456 .67807 L p .707 .577 .707 r
F P
0 g
s
.63489 .68765 m .61693 .74193 L .64526 .74949 L p .707 .577 .707 r
F P
0 g
s
.64526 .74949 m .66322 .69521 L .63489 .68765 L p .707 .577 .707 r
F P
0 g
s
.55724 .72167 m .57519 .66739 L .54967 .65666 L p .707 .577 .707 r
F P
0 g
s
.57519 .66739 m .55724 .72167 L .5866 .73235 L p .707 .577 .707 r
F P
0 g
s
.54967 .65666 m .53171 .71095 L .55724 .72167 L p .707 .577 .707 r
F P
0 g
s
.66322 .69521 m .64526 .74949 L .66882 .75428 L p .707 .577 .707 r
F P
0 g
s
.66882 .75428 m .68678 .7 L .66322 .69521 L p .707 .577 .707 r
F P
0 g
s
.59025 .80241 m .59628 .76522 L .56554 .75896 L p .707 .577 .707 r
F P
0 g
s
.59628 .76522 m .59025 .80241 L .62171 .80675 L p .707 .577 .707 r
F P
0 g
s
.62171 .80675 m .62774 .76956 L .59628 .76522 L p .707 .577 .707 r
F P
0 g
s
.62774 .76956 m .62171 .80675 L .65081 .80875 L p .707 .577 .707 r
F P
0 g
s
.65081 .80875 m .65683 .77156 L .62774 .76956 L p .707 .577 .707 r
F P
0 g
s
.53171 .71095 m .54967 .65666 L .53049 .64694 L p .707 .577 .707 r
F P
0 g
s
.55951 .79616 m .56554 .75896 L .53852 .7514 L p .707 .577 .707 r
F P
0 g
s
.56554 .75896 m .55951 .79616 L .59025 .80241 L p .707 .577 .707 r
F P
0 g
s
.53049 .64694 m .51253 .70122 L .53171 .71095 L p .707 .577 .707 r
F P
0 g
s
.53852 .7514 m .53249 .7886 L .55951 .79616 L p .707 .577 .707 r
F P
0 g
s
.65683 .77156 m .65081 .80875 L .67469 .80822 L p .707 .577 .707 r
F P
0 g
s
.67469 .80822 m .68072 .77102 L .65683 .77156 L p .707 .577 .707 r
F P
0 g
s
.68678 .7 m .66882 .75428 L .68529 .75583 L p .707 .577 .707 r
F P
0 g
s
.68529 .75583 m .70325 .70154 L .68678 .7 L p .707 .577 .707 r
F P
0 g
s
.53249 .7886 m .53852 .7514 L .51788 .74328 L p .707 .577 .707 r
F P
0 g
s
.61669 .86041 m .61223 .84302 L .58165 .84764 L p .707 .577 .707 r
F P
0 g
s
.61223 .84302 m .61669 .86041 L .64752 .85204 L p .707 .577 .707 r
F P
0 g
s
.64752 .85204 m .64306 .83465 L .61223 .84302 L p .707 .577 .707 r
F P
0 g
s
.51253 .70122 m .53049 .64694 L .51952 .63918 L p .707 .577 .707 r
F P
0 g
s
.64306 .83465 m .64752 .85204 L .67559 .84074 L p .707 .577 .707 r
F P
0 g
s
.67559 .84074 m .67113 .82336 L .64306 .83465 L p .707 .577 .707 r
F P
0 g
s
.51788 .74328 m .51185 .78047 L .53249 .7886 L p .707 .577 .707 r
F P
0 g
s
.58165 .84764 m .58612 .86503 L .61669 .86041 L p .707 .577 .707 r
F P
0 g
s
.58612 .86503 m .58165 .84764 L .55433 .84807 L p .707 .577 .707 r
F P
0 g
s
.51952 .63918 m .50156 .69346 L .51253 .70122 L p .707 .577 .707 r
F P
0 g
s
.68072 .77102 m .67469 .80822 L .69103 .80519 L p .707 .577 .707 r
F P
0 g
s
.69103 .80519 m .69706 .768 L .68072 .77102 L p .707 .577 .707 r
F P
0 g
s
.67113 .82336 m .67559 .84074 L .69815 .82763 L p .707 .577 .707 r
F P
0 g
s
.69815 .82763 m .69369 .81024 L .67113 .82336 L p .707 .577 .707 r
F P
0 g
s
.55433 .84807 m .55879 .86545 L .58612 .86503 L p .707 .577 .707 r
F P
0 g
s
.51185 .78047 m .51788 .74328 L .50562 .73539 L p .707 .577 .707 r
F P
0 g
s
.70325 .70154 m .68529 .75583 L .69308 .75398 L p .707 .577 .707 r
F P
0 g
s
.69308 .75398 m .71103 .6997 L .70325 .70154 L p .707 .577 .707 r
F P
0 g
s
.55879 .86545 m .55433 .84807 L .53294 .84425 L p .707 .577 .707 r
F P
0 g
s
.50562 .73539 m .49959 .77258 L .51185 .78047 L p .707 .577 .707 r
F P
0 g
s
.69369 .81024 m .69815 .82763 L .713 .81397 L p .707 .577 .707 r
F P
0 g
s
.713 .81397 m .70854 .79658 L .69369 .81024 L p .707 .577 .707 r
F P
0 g
s
.50156 .69346 m .51952 .63918 L .51785 .63412 L p .707 .577 .707 r
F P
0 g
s
.53294 .84425 m .5374 .86164 L .55879 .86545 L p .707 .577 .707 r
F P
0 g
s
.51785 .63412 m .49989 .68841 L .50156 .69346 L p .707 .577 .707 r
F P
0 g
s
.69706 .768 m .69103 .80519 L .69822 .79998 L p .707 .577 .707 r
F P
0 g
s
.69822 .79998 m .70425 .76279 L .69706 .768 L p .707 .577 .707 r
F P
0 g
s
.49959 .77258 m .50562 .73539 L .50296 .7285 L p .707 .577 .707 r
F P
0 g
s
.5374 .86164 m .53294 .84425 L .51956 .83656 L p .707 .577 .707 r
F P
0 g
s
.71103 .6997 m .69308 .75398 L .6914 .74893 L p .707 .577 .707 r
F P
0 g
s
.6914 .74893 m .70936 .69465 L .71103 .6997 L p .707 .577 .707 r
F P
0 g
s
.50296 .7285 m .49693 .76569 L .49959 .77258 L p .707 .577 .707 r
F P
0 g
s
.70854 .79658 m .713 .81397 L .71868 .80112 L p .707 .577 .707 r
F P
0 g
s
.71868 .80112 m .71422 .78373 L .70854 .79658 L p .707 .577 .707 r
F P
0 g
s
.51956 .83656 m .52403 .85395 L .5374 .86164 L p .707 .577 .707 r
F P
0 g
s
.49989 .68841 m .51785 .63412 L .52563 .63228 L p .707 .577 .707 r
F P
0 g
s
.52563 .63228 m .50767 .68657 L .49989 .68841 L p .707 .577 .707 r
F P
0 g
s
.50767 .68657 m .52563 .63228 L .5421 .63383 L p .707 .577 .707 r
F P
0 g
s
.5421 .63383 m .52414 .68811 L .50767 .68657 L p .707 .577 .707 r
F P
0 g
s
.52403 .85395 m .51956 .83656 L .51552 .82576 L p .707 .577 .707 r
F P
0 g
s
.51552 .82576 m .51998 .84315 L .52403 .85395 L p .707 .577 .707 r
F P
0 g
s
.51998 .84315 m .51552 .82576 L .5212 .81291 L p .707 .577 .707 r
F P
0 g
s
.50412 .76048 m .51015 .72329 L .52649 .72027 L p .707 .577 .707 r
F P
0 g
s
.52649 .72027 m .52046 .75746 L .50412 .76048 L p .707 .577 .707 r
F P
0 g
s
.5199 .82155 m .5199 .31966 L .47477 .31944 L p .707 .577 .707 r
F P
0 g
s
.5212 .81291 m .52566 .8303 L .51998 .84315 L p .707 .577 .707 r
F P
0 g
s
.52414 .68811 m .5421 .63383 L .56566 .63862 L p .707 .577 .707 r
F P
0 g
s
.56566 .63862 m .5477 .6929 L .52414 .68811 L p .707 .577 .707 r
F P
0 g
s
.52566 .8303 m .5212 .81291 L .53605 .79925 L p .707 .577 .707 r
F P
0 g
s
.52046 .75746 m .52649 .72027 L .55038 .71973 L p .707 .577 .707 r
F P
0 g
s
.5477 .6929 m .56566 .63862 L .59399 .64617 L p .707 .577 .707 r
F P
0 g
s
.53605 .79925 m .54051 .81664 L .52566 .8303 L p .707 .577 .707 r
F P
0 g
s
.55038 .71973 m .54435 .75693 L .52046 .75746 L p .707 .577 .707 r
F P
0 g
s
.59399 .64617 m .57603 .70046 L .5477 .6929 L p .707 .577 .707 r
F P
0 g
s
.54435 .75693 m .55038 .71973 L .57947 .72173 L p .707 .577 .707 r
F P
0 g
s
.54051 .81664 m .53605 .79925 L .55861 .78614 L p .707 .577 .707 r
F P
0 g
s
.57947 .72173 m .57345 .75892 L .54435 .75693 L p .707 .577 .707 r
F P
0 g
s
.55861 .78614 m .56307 .80352 L .54051 .81664 L p .707 .577 .707 r
F P
0 g
s
.56307 .80352 m .55861 .78614 L .58668 .77484 L p .707 .577 .707 r
F P
0 g
s
.5199 .31966 m .5199 .82155 L .56307 .81803 L p .707 .577 .707 r
F P
0 g
s
.56307 .81803 m .56307 .31614 L .5199 .31966 L p .707 .577 .707 r
F P
0 g
s
.47477 .82133 m .47477 .31944 L .43212 .31548 L p .707 .577 .707 r
F P
0 g
s
.49693 .76569 m .50296 .7285 L .51015 .72329 L p .707 .577 .707 r
F P
0 g
s
.51015 .72329 m .50412 .76048 L .49693 .76569 L p .707 .577 .707 r
F P
0 g
s
.47477 .31944 m .47477 .82133 L .5199 .82155 L p .707 .577 .707 r
F P
0 g
s
.57603 .70046 m .59399 .64617 L .62432 .65576 L p .707 .577 .707 r
F P
0 g
s
.62432 .65576 m .60636 .71004 L .57603 .70046 L p .707 .577 .707 r
F P
0 g
s
.57345 .75892 m .57947 .72173 L .61093 .72607 L p .707 .577 .707 r
F P
0 g
s
.61093 .72607 m .6049 .76326 L .57345 .75892 L p .707 .577 .707 r
F P
0 g
s
.58668 .77484 m .59114 .79223 L .56307 .80352 L p .707 .577 .707 r
F P
0 g
s
.59114 .79223 m .58668 .77484 L .61751 .76647 L p .707 .577 .707 r
F P
0 g
s
.61751 .76647 m .62198 .78386 L .59114 .79223 L p .707 .577 .707 r
F P
0 g
s
.56307 .31614 m .56307 .81803 L .60007 .81109 L p .707 .577 .707 r
F P
0 g
s
.60007 .81109 m .60007 .30921 L .56307 .31614 L p .707 .577 .707 r
F P
0 g
s
.70425 .76279 m .69822 .79998 L .69556 .7931 L p .707 .577 .707 r
F P
0 g
s
.69556 .7931 m .70159 .7559 L .70425 .76279 L p .707 .577 .707 r
F P
0 g
s
.43212 .81737 m .43212 .31548 L .39611 .30818 L p .707 .577 .707 r
F P
0 g
s
.43212 .31548 m .43212 .81737 L .47477 .82133 L p .707 .577 .707 r
F P
0 g
s
.70936 .69465 m .6914 .74893 L .68044 .74117 L p .707 .577 .707 r
F P
0 g
s
.68044 .74117 m .69839 .68689 L .70936 .69465 L p .707 .577 .707 r
F P
0 g
s
.71422 .78373 m .71868 .80112 L .71464 .79032 L p .707 .577 .707 r
F P
0 g
s
.71464 .79032 m .71018 .77293 L .71422 .78373 L p .707 .577 .707 r
F P
0 g
s
.24858 .73802 m .25642 .69069 L .22566 .68292 L p .707 .577 .707 r
F P
0 g
s
.25642 .69069 m .24858 .73802 L .28016 .7403 L p .707 .577 .707 r
F P
0 g
s
.28016 .7403 m .288 .69297 L .25642 .69069 L p .707 .577 .707 r
F P
0 g
s
.21782 .73025 m .22566 .68292 L .19875 .67041 L p .707 .577 .707 r
F P
0 g
s
.22566 .68292 m .21782 .73025 L .24858 .73802 L p .707 .577 .707 r
F P
0 g
s
.288 .69297 m .28016 .7403 L .30949 .73686 L p .707 .577 .707 r
F P
0 g
s
.30949 .73686 m .31733 .68953 L .288 .69297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.65369 .66644 m .63573 .72072 L .60636 .71004 L p .707 .577 .707 r
F P
0 g
s
.60636 .71004 m .62432 .65576 L .65369 .66644 L p .707 .577 .707 r
F P
0 g
s
.64168 .73232 m .63565 .76952 L .6049 .76326 L p .707 .577 .707 r
F P
0 g
s
.6049 .76326 m .61093 .72607 L .64168 .73232 L p .707 .577 .707 r
F P
0 g
s
.66869 .73988 m .66266 .77708 L .63565 .76952 L p .707 .577 .707 r
F P
0 g
s
.64809 .76185 m .65255 .77924 L .62198 .78386 L p .707 .577 .707 r
F P
0 g
s
.63565 .76952 m .64168 .73232 L .66869 .73988 L p .707 .577 .707 r
F P
0 g
s
.62198 .78386 m .61751 .76647 L .64809 .76185 L p .707 .577 .707 r
F P
0 g
s
.60007 .30921 m .60007 .81109 L .62728 .80143 L p .707 .577 .707 r
F P
0 g
s
.62728 .80143 m .62728 .29954 L .60007 .30921 L p .707 .577 .707 r
F P
0 g
s
.39611 .81007 m .39611 .30818 L .37027 .29825 L p .707 .577 .707 r
F P
0 g
s
.39611 .30818 m .39611 .81007 L .43212 .81737 L p .707 .577 .707 r
F P
0 g
s
.70159 .7559 m .69556 .7931 L .68331 .7852 L p .707 .577 .707 r
F P
0 g
s
.68331 .7852 m .68934 .74801 L .70159 .7559 L p .707 .577 .707 r
F P
0 g
s
.19091 .71774 m .19875 .67041 L .17832 .65439 L p .707 .577 .707 r
F P
0 g
s
.19875 .67041 m .19091 .71774 L .21782 .73025 L p .707 .577 .707 r
F P
0 g
s
.31733 .68953 m .30949 .73686 L .33368 .72804 L p .707 .577 .707 r
F P
0 g
s
.33368 .72804 m .34152 .68071 L .31733 .68953 L p .707 .577 .707 r
F P
0 g
s
.26506 .79671 m .26309 .7776 L .23178 .78055 L p .707 .577 .707 r
F P
0 g
s
.26309 .7776 m .26506 .79671 L .29655 .79326 L p .707 .577 .707 r
F P
0 g
s
.29655 .79326 m .29458 .77415 L .26309 .7776 L p .707 .577 .707 r
F P
0 g
s
.23178 .78055 m .23375 .79966 L .26506 .79671 L p .707 .577 .707 r
F P
0 g
s
.69839 .68689 m .68044 .74117 L .66125 .73145 L p .707 .577 .707 r
F P
0 g
s
.66125 .73145 m .67921 .67716 L .69839 .68689 L p .707 .577 .707 r
F P
0 g
s
.25062 .78601 m .25322 .75112 L .22213 .74623 L p .707 .577 .707 r
F P
0 g
s
.25322 .75112 m .25062 .78601 L .28239 .78679 L p .707 .577 .707 r
F P
0 g
s
.28239 .78679 m .28499 .75189 L .25322 .75112 L p .707 .577 .707 r
F P
0 g
s
.29458 .77415 m .29655 .79326 L .32515 .78965 L p .707 .577 .707 r
F P
0 g
s
.32515 .78965 m .32318 .77054 L .29458 .77415 L p .707 .577 .707 r
F P
0 g
s
.71018 .77293 m .71464 .79032 L .70126 .78263 L p .707 .577 .707 r
F P
0 g
s
.70126 .78263 m .6968 .76525 L .71018 .77293 L p .707 .577 .707 r
F P
0 g
s
.23375 .79966 m .23178 .78055 L .20372 .78272 L p .707 .577 .707 r
F P
0 g
s
.20372 .78272 m .20569 .80183 L .23375 .79966 L p .707 .577 .707 r
F P
0 g
s
.28499 .75189 m .28239 .78679 L .31173 .78337 L p .707 .577 .707 r
F P
0 g
s
.31173 .78337 m .31433 .74848 L .28499 .75189 L p .707 .577 .707 r
F P
0 g
s
.21953 .78112 m .22213 .74623 L .19477 .7377 L p .707 .577 .707 r
F P
0 g
s
.22213 .74623 m .21953 .78112 L .25062 .78601 L p .707 .577 .707 r
F P
0 g
s
.17047 .70172 m .17832 .65439 L .16636 .63643 L p .707 .577 .707 r
F P
0 g
s
.17832 .65439 m .17047 .70172 L .19091 .71774 L p .707 .577 .707 r
F P
0 g
s
.34152 .68071 m .33368 .72804 L .35037 .7147 L p .707 .577 .707 r
F P
0 g
s
.35037 .7147 m .35822 .66737 L .34152 .68071 L p .707 .577 .707 r
F P
0 g
s
.32318 .77054 m .32515 .78965 L .34805 .78623 L p .707 .577 .707 r
F P
0 g
s
.34805 .78623 m .34608 .76712 L .32318 .77054 L p .707 .577 .707 r
F P
0 g
s
.31433 .74848 m .31173 .78337 L .33578 .77611 L p .707 .577 .707 r
F P
0 g
s
.33578 .77611 m .33837 .74122 L .31433 .74848 L p .707 .577 .707 r
F P
0 g
s
.67921 .67716 m .66125 .73145 L .63573 .72072 L p .707 .577 .707 r
F P
0 g
s
.63573 .72072 m .65369 .66644 L .67921 .67716 L p .707 .577 .707 r
F P
0 g
s
.62728 .29954 m .62728 .80143 L .64202 .78999 L p .707 .577 .707 r
F P
0 g
s
.64202 .78999 m .64202 .2881 L .62728 .29954 L p .707 .577 .707 r
F P
0 g
s
.68934 .74801 m .68331 .7852 L .66266 .77708 L p .707 .577 .707 r
F P
0 g
s
.66266 .77708 m .66869 .73988 L .68934 .74801 L p .707 .577 .707 r
F P
0 g
s
.20569 .80183 m .20372 .78272 L .18166 .78388 L p .707 .577 .707 r
F P
0 g
s
.18166 .78388 m .18363 .80299 L .20569 .80183 L p .707 .577 .707 r
F P
0 g
s
.19218 .77259 m .19477 .7377 L .17382 .72637 L p .707 .577 .707 r
F P
0 g
s
.19477 .7377 m .19218 .77259 L .21953 .78112 L p .707 .577 .707 r
F P
0 g
s
.37027 .80014 m .37027 .29825 L .35713 .28667 L p .707 .577 .707 r
F P
0 g
s
.37027 .29825 m .37027 .80014 L .39611 .81007 L p .707 .577 .707 r
F P
0 g
s
.6968 .76525 m .70126 .78263 L .67987 .77882 L p .707 .577 .707 r
F P
0 g
s
.67987 .77882 m .67541 .76143 L .6968 .76525 L p .707 .577 .707 r
F P
0 g
s
.15851 .68376 m .16636 .63643 L .16404 .61829 L p .707 .577 .707 r
F P
0 g
s
.16636 .63643 m .15851 .68376 L .17047 .70172 L p .707 .577 .707 r
F P
0 g
s
.35822 .66737 m .35488 .68751 L p .35794 .69815 L .707 .577 .707 r
F P
0 g
s
.35545 .70359 m .35794 .69815 L p .35488 .68751 L .707 .577 .707 r
F P
0 g
s
.35477 .7308 m .35217 .7657 L .3593 .75316 L p .707 .577 .707 r
F P
0 g
s
.3593 .75316 m .3619 .71827 L .35477 .7308 L p .707 .577 .707 r
F P
0 g
s
.35794 .69815 m .36578 .65082 L .35822 .66737 L p .707 .577 .707 r
F P
0 g
s
.36578 .65082 m .35794 .69815 L .35608 .68362 L p .707 .577 .707 r
F P
0 g
s
.35608 .68362 m .35562 .68001 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35615 .67849 m .36578 .65082 L .35608 .68362 L .707 .577 .707 r
F
.34608 .76712 m .34805 .78623 L .36302 .78334 L p F P
0 g
s
.36302 .78334 m .36105 .76423 L .34608 .76712 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .36578 .65082 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35562 .68001 m .35617 .67669 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.35617 .67669 m .36347 .63268 L p .35615 .67849 L .707 .577 .707 r
F P
0 g
s
.36105 .76423 m .36302 .78334 L .36858 .78126 L p .707 .577 .707 r
F P
0 g
s
.36858 .78126 m .36661 .76216 L .36105 .76423 L p .707 .577 .707 r
F P
0 g
s
.36347 .63268 m .35562 .68001 L .34366 .66205 L p .707 .577 .707 r
F P
0 g
s
.34366 .66205 m .35151 .61472 L .36347 .63268 L p .707 .577 .707 r
F P
0 g
s
.3619 .71827 m .3593 .75316 L .35649 .73972 L p .707 .577 .707 r
F P
0 g
s
.35649 .73972 m .35908 .70483 L .3619 .71827 L p .707 .577 .707 r
F P
0 g
s
.36661 .76216 m .36858 .78126 L .3642 .7802 L p .707 .577 .707 r
F P
0 g
s
.3642 .7802 m .36223 .76109 L .36661 .76216 L p .707 .577 .707 r
F P
0 g
s
.35217 .7657 m .35477 .7308 L .33837 .74122 L p .707 .577 .707 r
F P
0 g
s
.35908 .70483 m .35649 .73972 L .34399 .72671 L p .707 .577 .707 r
F P
0 g
s
.35488 .68751 m .35037 .7147 L .35545 .70359 L p .707 .577 .707 r
F P
0 g
s
.34399 .72671 m .34658 .69182 L .35908 .70483 L p .707 .577 .707 r
F P
0 g
s
.36223 .76109 m .3642 .7802 L .35029 .78025 L p .707 .577 .707 r
F P
0 g
s
.33837 .74122 m .33578 .77611 L .35217 .7657 L p .707 .577 .707 r
F P
0 g
s
.35029 .78025 m .34832 .76114 L .36223 .76109 L p .707 .577 .707 r
F P
0 g
s
.35713 .28667 m .35713 .78856 L .37027 .80014 L p .707 .577 .707 r
F P
0 g
s
.35713 .75115 m .35713 .60146 L .35719 .75281 L .707 .577 .707 r
F
.35713 .60146 m .35713 .28667 L p .35717 .59839 L F P
0 g
s
.35713 .60146 m .35717 .59839 L .35719 .75281 L .707 .577 .707 r
F
.35713 .28667 m .35798 .27456 L p .35748 .57385 L F P
0 g
s
.35719 .75281 m .35717 .59839 L .35748 .57385 L .707 .577 .707 r
F
.35717 .59839 m .35713 .28667 L .35748 .57385 L F
.35713 .78856 m .35713 .75115 L p .35719 .75281 L F P
0 g
s
.17382 .72637 m .17122 .76126 L .19218 .77259 L p .707 .577 .707 r
F P
0 g
s
.18363 .80299 m .18166 .78388 L .16776 .78394 L p .707 .577 .707 r
F P
0 g
s
.17122 .76126 m .17382 .72637 L .16132 .71336 L p .707 .577 .707 r
F P
0 g
s
.16776 .78394 m .16973 .80305 L .18363 .80299 L p .707 .577 .707 r
F P
0 g
s
.67541 .76143 m .67987 .77882 L .65255 .77924 L p .707 .577 .707 r
F P
0 g
s
.65255 .77924 m .64809 .76185 L .67541 .76143 L p .707 .577 .707 r
F P
0 g
s
.64202 .2881 m .64202 .78999 L .64287 .77788 L p .707 .577 .707 r
F P
0 g
s
.64287 .77788 m .64287 .27599 L .64202 .2881 L p .707 .577 .707 r
F P
0 g
s
.16132 .71336 m .15872 .74825 L .17122 .76126 L p .707 .577 .707 r
F P
0 g
s
.16404 .61829 m .1562 .66562 L .15851 .68376 L p .707 .577 .707 r
F P
0 g
s
.1562 .66562 m .16404 .61829 L .1716 .60174 L p .707 .577 .707 r
F P
0 g
s
.15872 .74825 m .16132 .71336 L .1585 .69992 L p .707 .577 .707 r
F P
0 g
s
.16973 .80305 m .16776 .78394 L .16337 .78287 L p .707 .577 .707 r
F P
0 g
s
.16337 .78287 m .16534 .80198 L .16973 .80305 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1585 .69992 m .1559 .73481 L .15872 .74825 L p .707 .577 .707 r
F P
0 g
s
.16376 .64907 m .1716 .60174 L .1883 .5884 L p .707 .577 .707 r
F P
0 g
s
.1716 .60174 m .16376 .64907 L .1562 .66562 L p .707 .577 .707 r
F P
0 g
s
.1559 .73481 m .1585 .69992 L .16564 .68738 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.64287 .27599 m .64287 .77788 L .62972 .76629 L p .707 .577 .707 r
F P
0 g
s
.62972 .76629 m .62972 .26441 L .64287 .27599 L p .707 .577 .707 r
F P
0 g
s
.16534 .80198 m .16337 .78287 L .16894 .78079 L p .707 .577 .707 r
F P
0 g
s
.16894 .78079 m .17091 .7999 L .16534 .80198 L p .707 .577 .707 r
F P
0 g
s
.35798 .77645 m .35798 .27456 L .37272 .26312 L p .707 .577 .707 r
F P
0 g
s
.35798 .27456 m .35798 .77645 L .35713 .78856 L p .707 .577 .707 r
F P
0 g
s
.1883 .5884 m .18045 .63573 L .16376 .64907 L p .707 .577 .707 r
F P
0 g
s
.18045 .63573 m .1883 .5884 L .21249 .57958 L p .707 .577 .707 r
F P
0 g
s
.35151 .61472 m .34366 .66205 L .32323 .64603 L p .707 .577 .707 r
F P
0 g
s
.32323 .64603 m .33107 .5987 L .35151 .61472 L p .707 .577 .707 r
F P
0 g
s
.16564 .68738 m .16304 .72228 L .1559 .73481 L p .707 .577 .707 r
F P
0 g
s
.16304 .72228 m .16564 .68738 L .18203 .67697 L p .707 .577 .707 r
F P
0 g
s
.20465 .62691 m .21249 .57958 L .24182 .57614 L p .707 .577 .707 r
F P
0 g
s
.21249 .57958 m .20465 .62691 L .18045 .63573 L p .707 .577 .707 r
F P
0 g
s
.33107 .5987 m .32323 .64603 L .29631 .63352 L p .707 .577 .707 r
F P
0 g
s
.29631 .63352 m .30416 .5862 L .33107 .5987 L p .707 .577 .707 r
F P
0 g
s
.17091 .7999 m .16894 .78079 L .1839 .7779 L p .707 .577 .707 r
F P
0 g
s
.1839 .7779 m .18587 .79701 L .17091 .7999 L p .707 .577 .707 r
F P
0 g
s
.18203 .67697 m .17943 .71186 L .16304 .72228 L p .707 .577 .707 r
F P
0 g
s
.23397 .62347 m .24182 .57614 L .2734 .57842 L p .707 .577 .707 r
F P
0 g
s
.24182 .57614 m .23397 .62347 L .20465 .62691 L p .707 .577 .707 r
F P
0 g
s
.30416 .5862 m .29631 .63352 L .26556 .62575 L p .707 .577 .707 r
F P
0 g
s
.26556 .62575 m .2734 .57842 L .30416 .5862 L p .707 .577 .707 r
F P
0 g
s
.62972 .26441 m .62972 .76629 L .60388 .75637 L p .707 .577 .707 r
F P
0 g
s
.60388 .75637 m .60388 .25448 L .62972 .26441 L p .707 .577 .707 r
F P
0 g
s
.34658 .69182 m .34399 .72671 L .32303 .71538 L p .707 .577 .707 r
F P
0 g
s
.32303 .71538 m .32563 .68049 L .34658 .69182 L p .707 .577 .707 r
F P
0 g
s
.2734 .57842 m .26556 .62575 L .23397 .62347 L p .707 .577 .707 r
F P
0 g
s
.37272 .76501 m .37272 .26312 L .39993 .25345 L p .707 .577 .707 r
F P
0 g
s
.37272 .26312 m .37272 .76501 L .35798 .77645 L p .707 .577 .707 r
F P
0 g
s
.17943 .71186 m .18203 .67697 L .20607 .66971 L p .707 .577 .707 r
F P
0 g
s
.34832 .76114 m .35029 .78025 L .32824 .78142 L p .707 .577 .707 r
F P
0 g
s
.32824 .78142 m .32627 .76231 L .34832 .76114 L p .707 .577 .707 r
F P
0 g
s
.18587 .79701 m .1839 .7779 L .20681 .77449 L p .707 .577 .707 r
F P
0 g
s
.20681 .77449 m .20878 .79359 L .18587 .79701 L p .707 .577 .707 r
F P
0 g
s
.32563 .68049 m .32303 .71538 L .29567 .70685 L p .707 .577 .707 r
F P
0 g
s
.29567 .70685 m .29827 .67196 L .32563 .68049 L p .707 .577 .707 r
F P
0 g
s
.20607 .66971 m .20348 .7046 L .17943 .71186 L p .707 .577 .707 r
F P
0 g
s
.20348 .7046 m .20607 .66971 L .23542 .66629 L p .707 .577 .707 r
F P
0 g
s
.69584 .57356 m .70368 .63064 L .73444 .62603 L p .707 .577 .707 r
F P
0 g
s
.73444 .62603 m .72659 .56894 L .69584 .57356 L p .707 .577 .707 r
F P
0 g
s
.72659 .56894 m .73444 .62603 L .76602 .62182 L p .707 .577 .707 r
F P
0 g
s
.60388 .25448 m .60388 .75637 L .56788 .74907 L p .707 .577 .707 r
F P
0 g
s
.56788 .74907 m .56788 .24718 L .60388 .25448 L p .707 .577 .707 r
F P
0 g
s
.76602 .62182 m .75818 .56474 L .72659 .56894 L p .707 .577 .707 r
F P
0 g
s
.75818 .56474 m .76602 .62182 L .79535 .61843 L p .707 .577 .707 r
F P
0 g
s
.32627 .76231 m .32824 .78142 L .30018 .78358 L p .707 .577 .707 r
F P
0 g
s
.30018 .78358 m .29821 .76447 L .32627 .76231 L p .707 .577 .707 r
F P
0 g
s
.29827 .67196 m .29567 .70685 L .26459 .70196 L p .707 .577 .707 r
F P
0 g
s
.26459 .70196 m .26719 .66707 L .29827 .67196 L p .707 .577 .707 r
F P
0 g
s
.39993 .25345 m .39993 .75534 L .37272 .76501 L p .707 .577 .707 r
F P
0 g
s
.39993 .75534 m .39993 .25345 L .43693 .24652 L p .707 .577 .707 r
F P
0 g
s
.23282 .70119 m .23542 .66629 L .26719 .66707 L p .707 .577 .707 r
F P
0 g
s
.23542 .66629 m .23282 .70119 L .20348 .7046 L p .707 .577 .707 r
F P
0 g
s
.79535 .61843 m .78751 .56135 L .75818 .56474 L p .707 .577 .707 r
F P
0 g
s
.20878 .79359 m .20681 .77449 L .2354 .77087 L p .707 .577 .707 r
F P
0 g
s
.2354 .77087 m .23737 .78998 L .20878 .79359 L p .707 .577 .707 r
F P
0 g
s
.66893 .57812 m .67677 .63521 L .70368 .63064 L p .707 .577 .707 r
F P
0 g
s
.70368 .63064 m .69584 .57356 L .66893 .57812 L p .707 .577 .707 r
F P
0 g
s
.26719 .66707 m .26459 .70196 L .23282 .70119 L p .707 .577 .707 r
F P
0 g
s
.73541 .70366 m .73281 .66553 L .70173 .66681 L p .707 .577 .707 r
F P
0 g
s
.73281 .66553 m .73541 .70366 L .76718 .7012 L p .707 .577 .707 r
F P
0 g
s
.76718 .7012 m .76458 .66307 L .73281 .66553 L p .707 .577 .707 r
F P
0 g
s
.78751 .56135 m .79535 .61843 L .81954 .61619 L p .707 .577 .707 r
F P
0 g
s
.76458 .66307 m .76718 .7012 L .79652 .69781 L p .707 .577 .707 r
F P
0 g
s
.79652 .69781 m .79392 .65968 L .76458 .66307 L p .707 .577 .707 r
F P
0 g
s
.81954 .61619 m .8117 .55911 L .78751 .56135 L p .707 .577 .707 r
F P
0 g
s
.29821 .76447 m .30018 .78358 L .26887 .78653 L p .707 .577 .707 r
F P
0 g
s
.26887 .78653 m .2669 .76742 L .29821 .76447 L p .707 .577 .707 r
F P
0 g
s
.70173 .66681 m .70432 .70494 L .73541 .70366 L p .707 .577 .707 r
F P
0 g
s
.23737 .78998 m .2354 .77087 L .2669 .76742 L p .707 .577 .707 r
F P
0 g
s
.2669 .76742 m .26887 .78653 L .23737 .78998 L p .707 .577 .707 r
F P
0 g
s
.70432 .70494 m .70173 .66681 L .67437 .66679 L p .707 .577 .707 r
F P
0 g
s
.64849 .58219 m .65633 .63928 L .67677 .63521 L p .707 .577 .707 r
F P
0 g
s
.67677 .63521 m .66893 .57812 L .64849 .58219 L p .707 .577 .707 r
F P
0 g
s
.67437 .66679 m .67697 .70491 L .70432 .70494 L p .707 .577 .707 r
F P
0 g
s
.56788 .24718 m .56788 .74907 L .52522 .74511 L p .707 .577 .707 r
F P
0 g
s
.52522 .74511 m .52522 .24322 L .56788 .24718 L p .707 .577 .707 r
F P
0 g
s
.79392 .65968 m .79652 .69781 L .82057 .69381 L p .707 .577 .707 r
F P
0 g
s
.82057 .69381 m .81797 .65568 L .79392 .65968 L p .707 .577 .707 r
F P
0 g
s
.43693 .74841 m .43693 .24652 L .4801 .24299 L p .707 .577 .707 r
F P
0 g
s
.43693 .24652 m .43693 .74841 L .39993 .75534 L p .707 .577 .707 r
F P
0 g
s
.8117 .55911 m .81954 .61619 L .83624 .61532 L p .707 .577 .707 r
F P
0 g
s
.67697 .70491 m .67437 .66679 L .65341 .66546 L p .707 .577 .707 r
F P
0 g
s
.83624 .61532 m .82839 .55823 L .8117 .55911 L p .707 .577 .707 r
F P
0 g
s
.52522 .24322 m .52522 .74511 L .4801 .74488 L p .707 .577 .707 r
F P
0 g
s
.4801 .74488 m .4801 .24299 L .52522 .24322 L p .707 .577 .707 r
F P
0 g
s
.4801 .24299 m .4801 .74488 L .43693 .74841 L p .707 .577 .707 r
F P
0 g
s
.65341 .66546 m .65601 .70359 L .67697 .70491 L p .707 .577 .707 r
F P
0 g
s
.63653 .58537 m .64437 .64246 L .65633 .63928 L p .707 .577 .707 r
F P
0 g
s
.65633 .63928 m .64849 .58219 L .63653 .58537 L p .707 .577 .707 r
F P
0 g
s
.81797 .65568 m .82057 .69381 L .83696 .68959 L p .707 .577 .707 r
F P
0 g
s
.83696 .68959 m .83436 .65146 L .81797 .65568 L p .707 .577 .707 r
F P
0 g
s
.73113 .77603 m .7331 .7592 L .70179 .75371 L p .707 .577 .707 r
F P
0 g
s
.7331 .7592 m .73113 .77603 L .76262 .77679 L p .707 .577 .707 r
F P
0 g
s
.76262 .77679 m .76459 .75996 L .7331 .7592 L p .707 .577 .707 r
F P
0 g
s
.69982 .77054 m .70179 .75371 L .67373 .74401 L p .707 .577 .707 r
F P
0 g
s
.70179 .75371 m .69982 .77054 L .73113 .77603 L p .707 .577 .707 r
F P
0 g
s
.76459 .75996 m .76262 .77679 L .79122 .77274 L p .707 .577 .707 r
F P
0 g
s
.79122 .77274 m .79319 .7559 L .76459 .75996 L p .707 .577 .707 r
F P
0 g
s
.65601 .70359 m .65341 .66546 L .64092 .66296 L p .707 .577 .707 r
F P
0 g
s
.82839 .55823 m .83624 .61532 L .8438 .6159 L p .707 .577 .707 r
F P
0 g
s
.8438 .6159 m .83596 .55881 L .82839 .55823 L p .707 .577 .707 r
F P
0 g
s
.67373 .74401 m .67176 .76084 L .69982 .77054 L p .707 .577 .707 r
F P
0 g
s
.64092 .66296 m .64351 .70109 L .65601 .70359 L p .707 .577 .707 r
F P
0 g
s
.67176 .76084 m .67373 .74401 L .65167 .73107 L p .707 .577 .707 r
F P
0 g
s
.79319 .7559 m .79122 .77274 L .81413 .76427 L p .707 .577 .707 r
F P
0 g
s
.81413 .76427 m .8161 .74744 L .79319 .7559 L p .707 .577 .707 r
F P
0 g
s
.83436 .65146 m .83696 .68959 L .8441 .68558 L p .707 .577 .707 r
F P
0 g
s
.8441 .68558 m .8415 .64745 L .83436 .65146 L p .707 .577 .707 r
F P
0 g
s
.63422 .58735 m .64206 .64443 L .64437 .64246 L p .707 .577 .707 r
F P
0 g
s
.64437 .64246 m .63653 .58537 L .63422 .58735 L p .707 .577 .707 r
F P
0 g
s
.65167 .73107 m .6497 .7479 L .67176 .76084 L p .707 .577 .707 r
F P
0 g
s
.6497 .7479 m .65167 .73107 L .63777 .71614 L p .707 .577 .707 r
F P
0 g
s
.64351 .70109 m .64092 .66296 L .6381 .65954 L p .707 .577 .707 r
F P
0 g
s
.8161 .74744 m .81413 .76427 L .82909 .75222 L p .707 .577 .707 r
F P
0 g
s
.82909 .75222 m .83106 .73538 L .8161 .74744 L p .707 .577 .707 r
F P
0 g
s
.83596 .55881 m .8438 .6159 L .84149 .61788 L p .707 .577 .707 r
F P
0 g
s
.6381 .65954 m .64069 .69767 L .64351 .70109 L p .707 .577 .707 r
F P
0 g
s
.84149 .61788 m .83364 .56079 L .83596 .55881 L p .707 .577 .707 r
F P
0 g
s
.63777 .71614 m .6358 .73297 L .6497 .7479 L p .707 .577 .707 r
F P
0 g
s
.8415 .64745 m .8441 .68558 L .84128 .68215 L p .707 .577 .707 r
F P
0 g
s
.84128 .68215 m .83868 .64402 L .8415 .64745 L p .707 .577 .707 r
F P
0 g
s
.64178 .58793 m .64962 .64501 L .64206 .64443 L p .707 .577 .707 r
F P
0 g
s
.64206 .64443 m .63422 .58735 L .64178 .58793 L p .707 .577 .707 r
F P
0 g
s
.6358 .73297 m .63777 .71614 L .63339 .70069 L p .707 .577 .707 r
F P
0 g
s
.83106 .73538 m .82909 .75222 L .83465 .73776 L p .707 .577 .707 r
F P
0 g
s
.83465 .73776 m .83662 .72093 L .83106 .73538 L p .707 .577 .707 r
F P
0 g
s
.63339 .70069 m .63142 .71753 L .6358 .73297 L p .707 .577 .707 r
F P
0 g
s
.64069 .69767 m .6381 .65954 L .64523 .65552 L p .707 .577 .707 r
F P
0 g
s
.83364 .56079 m .84149 .61788 L .82953 .62106 L p .707 .577 .707 r
F P
0 g
s
.42397 .6239 m .40601 .57343 L .37568 .58326 L p .707 .577 .707 r
F P
0 g
s
.40601 .57343 m .42397 .6239 L .4523 .61085 L p .707 .577 .707 r
F P
0 g
s
.4523 .61085 m .43434 .56038 L .40601 .57343 L p .707 .577 .707 r
F P
0 g
s
.64523 .65552 m .64783 .69365 L .64069 .69767 L p .707 .577 .707 r
F P
0 g
s
.82953 .62106 m .82168 .56397 L .83364 .56079 L p .707 .577 .707 r
F P
0 g
s
.39363 .63373 m .37568 .58326 L .34631 .58892 L p .707 .577 .707 r
F P
0 g
s
.37568 .58326 m .39363 .63373 L .42397 .6239 L p .707 .577 .707 r
F P
0 g
s
.43434 .56038 m .4523 .61085 L .47585 .59586 L p .707 .577 .707 r
F P
0 g
s
.47585 .59586 m .45789 .54539 L .43434 .56038 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83868 .64402 m .84128 .68215 L .82878 .67965 L p .707 .577 .707 r
F P
0 g
s
.82878 .67965 m .82618 .64152 L .83868 .64402 L p .707 .577 .707 r
F P
0 g
s
.36427 .63939 m .34631 .58892 L .32079 .58984 L p .707 .577 .707 r
F P
0 g
s
.34631 .58892 m .36427 .63939 L .39363 .63373 L p .707 .577 .707 r
F P
0 g
s
.63142 .71753 m .63339 .70069 L .63895 .68624 L p .707 .577 .707 r
F P
0 g
s
.65847 .58706 m .66632 .64414 L .64962 .64501 L p .707 .577 .707 r
F P
0 g
s
.64962 .64501 m .64178 .58793 L .65847 .58706 L p .707 .577 .707 r
F P
0 g
s
.83662 .72093 m .83465 .73776 L .83027 .72231 L p .707 .577 .707 r
F P
0 g
s
.83027 .72231 m .83224 .70548 L .83662 .72093 L p .707 .577 .707 r
F P
0 g
s
.45789 .54539 m .47585 .59586 L .49233 .58039 L p .707 .577 .707 r
F P
0 g
s
.49233 .58039 m .47437 .52992 L .45789 .54539 L p .707 .577 .707 r
F P
0 g
s
.63895 .68624 m .63698 .70307 L .63142 .71753 L p .707 .577 .707 r
F P
0 g
s
.39509 .68772 m .38906 .65189 L .35832 .65407 L p .707 .577 .707 r
F P
0 g
s
.38906 .65189 m .39509 .68772 L .42655 .68212 L p .707 .577 .707 r
F P
0 g
s
.42655 .68212 m .42052 .64628 L .38906 .65189 L p .707 .577 .707 r
F P
0 g
s
.42052 .64628 m .42655 .68212 L .45565 .67364 L p .707 .577 .707 r
F P
0 g
s
.45565 .67364 m .44962 .63781 L .42052 .64628 L p .707 .577 .707 r
F P
0 g
s
.64783 .69365 m .64523 .65552 L .66162 .6513 L p .707 .577 .707 r
F P
0 g
s
.82168 .56397 m .82953 .62106 L .80909 .62513 L p .707 .577 .707 r
F P
0 g
s
.80909 .62513 m .80125 .56804 L .82168 .56397 L p .707 .577 .707 r
F P
0 g
s
.37802 .71327 m .38248 .69482 L .35191 .68667 L p .707 .577 .707 r
F P
0 g
s
.38248 .69482 m .37802 .71327 L .40885 .71984 L p .707 .577 .707 r
F P
0 g
s
.40885 .71984 m .41331 .70139 L .38248 .69482 L p .707 .577 .707 r
F P
0 g
s
.66162 .6513 m .66422 .68943 L .64783 .69365 L p .707 .577 .707 r
F P
0 g
s
.33874 .64031 m .32079 .58984 L .3016 .58593 L p .707 .577 .707 r
F P
0 g
s
.32079 .58984 m .33874 .64031 L .36427 .63939 L p .707 .577 .707 r
F P
0 g
s
.36435 .6899 m .35832 .65407 L .33131 .65262 L p .707 .577 .707 r
F P
0 g
s
.35832 .65407 m .36435 .6899 L .39509 .68772 L p .707 .577 .707 r
F P
0 g
s
.35191 .68667 m .34745 .70512 L .37802 .71327 L p .707 .577 .707 r
F P
0 g
s
.44962 .63781 m .45565 .67364 L .47954 .66312 L p .707 .577 .707 r
F P
0 g
s
.47954 .66312 m .47351 .62729 L .44962 .63781 L p .707 .577 .707 r
F P
0 g
s
.34745 .70512 m .35191 .68667 L .32459 .67773 L p .707 .577 .707 r
F P
0 g
s
.41331 .70139 m .40885 .71984 L .43692 .72418 L p .707 .577 .707 r
F P
0 g
s
.43692 .72418 m .44139 .70573 L .41331 .70139 L p .707 .577 .707 r
F P
0 g
s
.32459 .67773 m .32013 .69618 L .34745 .70512 L p .707 .577 .707 r
F P
0 g
s
.68267 .58481 m .69051 .6419 L .66632 .64414 L p .707 .577 .707 r
F P
0 g
s
.66632 .64414 m .65847 .58706 L .68267 .58481 L p .707 .577 .707 r
F P
0 g
s
.63698 .70307 m .63895 .68624 L .65392 .67418 L p .707 .577 .707 r
F P
0 g
s
.82618 .64152 m .82878 .67965 L .80782 .67833 L p .707 .577 .707 r
F P
0 g
s
.80782 .67833 m .80523 .6402 L .82618 .64152 L p .707 .577 .707 r
F P
0 g
s
.47437 .52992 m .49233 .58039 L .50011 .56597 L p .707 .577 .707 r
F P
0 g
s
.50011 .56597 m .48215 .5155 L .47437 .52992 L p .707 .577 .707 r
F P
0 g
s
.33131 .65262 m .33733 .68845 L .36435 .6899 L p .707 .577 .707 r
F P
0 g
s
.83224 .70548 m .83027 .72231 L .81637 .70738 L p .707 .577 .707 r
F P
0 g
s
.81637 .70738 m .81834 .69055 L .83224 .70548 L p .707 .577 .707 r
F P
0 g
s
.33733 .68845 m .33131 .65262 L .31066 .64767 L p .707 .577 .707 r
F P
0 g
s
.32013 .69618 m .32459 .67773 L .3032 .66888 L p .707 .577 .707 r
F P
0 g
s
.65392 .67418 m .65195 .69101 L .63698 .70307 L p .707 .577 .707 r
F P
0 g
s
.44139 .70573 m .43692 .72418 L .45949 .72587 L p .707 .577 .707 r
F P
0 g
s
.45949 .72587 m .46395 .70741 L .44139 .70573 L p .707 .577 .707 r
F P
0 g
s
.80125 .56804 m .80909 .62513 L .78218 .62969 L p .707 .577 .707 r
F P
0 g
s
.3032 .66888 m .29873 .68733 L .32013 .69618 L p .707 .577 .707 r
F P
0 g
s
.47351 .62729 m .47954 .66312 L .49587 .65159 L p .707 .577 .707 r
F P
0 g
s
.49587 .65159 m .48985 .61576 L .47351 .62729 L p .707 .577 .707 r
F P
0 g
s
.3016 .58593 m .31956 .6364 L .33874 .64031 L p .707 .577 .707 r
F P
0 g
s
.66422 .68943 m .66162 .6513 L .68567 .6473 L p .707 .577 .707 r
F P
0 g
s
.78218 .62969 m .77433 .57261 L .80125 .56804 L p .707 .577 .707 r
F P
0 g
s
.31956 .6364 m .3016 .58593 L .29064 .57758 L p .707 .577 .707 r
F P
0 g
s
.68567 .6473 m .68827 .68543 L .66422 .68943 L p .707 .577 .707 r
F P
0 g
s
.71199 .58143 m .71984 .63851 L .69051 .6419 L p .707 .577 .707 r
F P
0 g
s
.69051 .6419 m .68267 .58481 L .71199 .58143 L p .707 .577 .707 r
F P
0 g
s
.31066 .64767 m .31669 .68351 L .33733 .68845 L p .707 .577 .707 r
F P
0 g
s
.80523 .6402 m .80782 .67833 L .78046 .6783 L p .707 .577 .707 r
F P
0 g
s
.78046 .6783 m .77787 .64017 L .80523 .6402 L p .707 .577 .707 r
F P
0 g
s
.65195 .69101 m .65392 .67418 L .67682 .66571 L p .707 .577 .707 r
F P
0 g
s
.77433 .57261 m .78218 .62969 L .75142 .6343 L p .707 .577 .707 r
F P
0 g
s
.29873 .68733 m .3032 .66888 L .28982 .66098 L p .707 .577 .707 r
F P
0 g
s
.75142 .6343 m .74358 .57722 L .77433 .57261 L p .707 .577 .707 r
F P
0 g
s
.81834 .69055 m .81637 .70738 L .79431 .69444 L p .707 .577 .707 r
F P
0 g
s
.79431 .69444 m .79628 .67761 L .81834 .69055 L p .707 .577 .707 r
F P
0 g
s
.48215 .5155 m .50011 .56597 L .49844 .554 L p .707 .577 .707 r
F P
0 g
s
.49844 .554 m .48048 .50353 L .48215 .5155 L p .707 .577 .707 r
F P
0 g
s
.31669 .68351 m .31066 .64767 L .29841 .63972 L p .707 .577 .707 r
F P
0 g
s
.46395 .70741 m .45949 .72587 L .47434 .72473 L p .707 .577 .707 r
F P
0 g
s
.47434 .72473 m .4788 .70628 L .46395 .70741 L p .707 .577 .707 r
F P
0 g
s
.74358 .57722 m .75142 .6343 L .71984 .63851 L p .707 .577 .707 r
F P
0 g
s
.71984 .63851 m .71199 .58143 L .74358 .57722 L p .707 .577 .707 r
F P
0 g
s
.28982 .66098 m .28536 .67943 L .29873 .68733 L p .707 .577 .707 r
F P
0 g
s
.68827 .68543 m .68567 .6473 L .71501 .64391 L p .707 .577 .707 r
F P
0 g
s
.67682 .66571 m .67485 .68255 L .65195 .69101 L p .707 .577 .707 r
F P
0 g
s
.48985 .61576 m .49587 .65159 L .50306 .64017 L p .707 .577 .707 r
F P
0 g
s
.50306 .64017 m .49704 .60434 L .48985 .61576 L p .707 .577 .707 r
F P
0 g
s
.29064 .57758 m .3086 .62805 L .31956 .6364 L p .707 .577 .707 r
F P
0 g
s
.71501 .64391 m .71761 .68204 L .68827 .68543 L p .707 .577 .707 r
F P
0 g
s
.77787 .64017 m .78046 .6783 L .74938 .67958 L p .707 .577 .707 r
F P
0 g
s
.74938 .67958 m .74678 .64145 L .77787 .64017 L p .707 .577 .707 r
F P
0 g
s
.29841 .63972 m .30444 .67555 L .31669 .68351 L p .707 .577 .707 r
F P
0 g
s
.3086 .62805 m .29064 .57758 L .28896 .56561 L p .707 .577 .707 r
F P
0 g
s
.67485 .68255 m .67682 .66571 L .70542 .66166 L p .707 .577 .707 r
F P
0 g
s
.71761 .68204 m .71501 .64391 L .74678 .64145 L p .707 .577 .707 r
F P
0 g
s
.74678 .64145 m .74938 .67958 L .71761 .68204 L p .707 .577 .707 r
F P
0 g
s
.79628 .67761 m .79431 .69444 L .76625 .68475 L p .707 .577 .707 r
F P
0 g
s
.76625 .68475 m .76822 .66791 L .79628 .67761 L p .707 .577 .707 r
F P
0 g
s
.70542 .66166 m .70345 .67849 L .67485 .68255 L p .707 .577 .707 r
F P
0 g
s
.28536 .67943 m .28982 .66098 L .28578 .65481 L p .707 .577 .707 r
F P
0 g
s
.70345 .67849 m .70542 .66166 L .73691 .66242 L p .707 .577 .707 r
F P
0 g
s
.48048 .50353 m .49844 .554 L .48747 .54565 L p .707 .577 .707 r
F P
0 g
s
.48747 .54565 m .46951 .49518 L .48048 .50353 L p .707 .577 .707 r
F P
0 g
s
.30444 .67555 m .29841 .63972 L .29575 .62954 L p .707 .578 .707 r
F P
0 g
s
.4788 .70628 m .47434 .72473 L .48002 .7209 L p .707 .577 .707 r
F P
0 g
s
.48002 .7209 m .48448 .70244 L .4788 .70628 L p .707 .577 .707 r
F P
0 g
s
.28578 .65481 m .28131 .67326 L .28536 .67943 L p .707 .577 .707 r
F P
0 g
s
.76822 .66791 m .76625 .68475 L .73494 .67925 L p .707 .577 .707 r
F P
0 g
s
.73494 .67925 m .73691 .66242 L .76822 .66791 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73691 .66242 m .73494 .67925 L .70345 .67849 L p .707 .577 .707 r
F P
0 g
s
.49704 .60434 m .50306 .64017 L .5004 .62999 L p .707 .578 .707 r
F P
0 g
s
.5004 .62999 m .49438 .59416 L .49704 .60434 L p .707 .578 .707 r
F P
0 g
s
.28896 .56561 m .30692 .61608 L .3086 .62805 L p .707 .577 .707 r
F P
0 g
s
.29575 .62954 m .30177 .66537 L .30444 .67555 L p .707 .578 .707 r
F P
0 g
s
.30692 .61608 m .28896 .56561 L .29674 .55119 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.46951 .49518 m .48747 .54565 L .46829 .54174 L p .707 .577 .707 r
F P
0 g
s
.46829 .54174 m .45033 .49127 L .46951 .49518 L p .707 .577 .707 r
F P
0 g
s
.28131 .67326 m .28578 .65481 L .29145 .65097 L p .707 .577 .707 r
F P
0 g
s
.30177 .66537 m .29575 .62954 L .30294 .61812 L p .707 .577 .707 r
F P
0 g
s
.48448 .70244 m .48002 .7209 L .47597 .71473 L p .707 .577 .707 r
F P
0 g
s
.47597 .71473 m .48043 .69627 L .48448 .70244 L p .707 .577 .707 r
F P
0 g
s
.29145 .65097 m .28699 .66942 L .28131 .67326 L p .707 .577 .707 r
F P
0 g
s
.29674 .55119 m .3147 .60166 L .30692 .61608 L p .707 .577 .707 r
F P
0 g
s
.49438 .59416 m .5004 .62999 L .48815 .62204 L p .707 .577 .707 r
F P
0 g
s
.48815 .62204 m .48212 .5862 L .49438 .59416 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3147 .60166 m .29674 .55119 L .31322 .53572 L p .707 .577 .707 r
F P
0 g
s
.30294 .61812 m .30896 .65395 L .30177 .66537 L p .707 .577 .707 r
F P
0 g
s
.45033 .49127 m .46829 .54174 L .44276 .54266 L p .707 .577 .707 r
F P
0 g
s
.44276 .54266 m .4248 .49219 L .45033 .49127 L p .707 .577 .707 r
F P
0 g
s
.30896 .65395 m .30294 .61812 L .31927 .60659 L p .707 .577 .707 r
F P
0 g
s
.28699 .66942 m .29145 .65097 L .3063 .64984 L p .707 .577 .707 r
F P
0 g
s
.48043 .69627 m .47597 .71473 L .4626 .70683 L p .707 .577 .707 r
F P
0 g
s
.4626 .70683 m .46706 .68838 L .48043 .69627 L p .707 .577 .707 r
F P
0 g
s
.31322 .53572 m .33118 .58619 L .3147 .60166 L p .707 .577 .707 r
F P
0 g
s
.3063 .64984 m .30184 .66829 L .28699 .66942 L p .707 .577 .707 r
F P
0 g
s
.33118 .58619 m .31322 .53572 L .33677 .52073 L p .707 .577 .707 r
F P
0 g
s
.48212 .5862 m .48815 .62204 L .46751 .61709 L p .707 .577 .707 r
F P
0 g
s
.46751 .61709 m .46148 .58126 L .48212 .5862 L p .707 .577 .707 r
F P
0 g
s
.31927 .60659 m .3253 .64242 L .30896 .65395 L p .707 .577 .707 r
F P
0 g
s
.4248 .49219 m .44276 .54266 L .4134 .54831 L p .707 .577 .707 r
F P
0 g
s
.4134 .54831 m .39544 .49784 L .4248 .49219 L p .707 .577 .707 r
F P
0 g
s
.35473 .5712 m .33677 .52073 L .3651 .50768 L p .707 .577 .707 r
F P
0 g
s
.33677 .52073 m .35473 .5712 L .33118 .58619 L p .707 .577 .707 r
F P
0 g
s
.3253 .64242 m .31927 .60659 L .34316 .59607 L p .707 .577 .707 r
F P
0 g
s
.39544 .49784 m .4134 .54831 L .38306 .55815 L p .707 .577 .707 r
F P
0 g
s
.38306 .55815 m .3651 .50768 L .39544 .49784 L p .707 .577 .707 r
F P
0 g
s
.3651 .50768 m .38306 .55815 L .35473 .5712 L p .707 .577 .707 r
F P
0 g
s
.46148 .58126 m .46751 .61709 L .44049 .61564 L p .707 .577 .707 r
F P
0 g
s
.44049 .61564 m .43446 .57981 L .46148 .58126 L p .707 .577 .707 r
F P
0 g
s
.30184 .66829 m .3063 .64984 L .32887 .65153 L p .707 .577 .707 r
F P
0 g
s
.46706 .68838 m .4626 .70683 L .4412 .69798 L p .707 .577 .707 r
F P
0 g
s
.4412 .69798 m .44566 .67953 L .46706 .68838 L p .707 .577 .707 r
F P
0 g
s
.32887 .65153 m .32441 .66998 L .30184 .66829 L p .707 .577 .707 r
F P
0 g
s
.34316 .59607 m .34919 .6319 L .3253 .64242 L p .707 .577 .707 r
F P
0 g
s
.34919 .6319 m .34316 .59607 L .37226 .58759 L p .707 .577 .707 r
F P
0 g
s
.43446 .57981 m .44049 .61564 L .40975 .61782 L p .707 .577 .707 r
F P
0 g
s
.40975 .61782 m .40372 .58199 L .43446 .57981 L p .707 .577 .707 r
F P
0 g
s
.32441 .66998 m .32887 .65153 L .35694 .65587 L p .707 .577 .707 r
F P
0 g
s
.44566 .67953 m .4412 .69798 L .41388 .68904 L p .707 .577 .707 r
F P
0 g
s
.41388 .68904 m .41834 .67059 L .44566 .67953 L p .707 .577 .707 r
F P
0 g
s
.37829 .62343 m .37226 .58759 L .40372 .58199 L p .707 .577 .707 r
F P
0 g
s
.37226 .58759 m .37829 .62343 L .34919 .6319 L p .707 .577 .707 r
F P
0 g
s
.40372 .58199 m .40975 .61782 L .37829 .62343 L p .707 .577 .707 r
F P
0 g
s
.35694 .65587 m .35248 .67432 L .32441 .66998 L p .707 .577 .707 r
F P
0 g
s
.35248 .67432 m .35694 .65587 L .38777 .66243 L p .707 .577 .707 r
F P
0 g
s
.41834 .67059 m .41388 .68904 L .38331 .68089 L p .707 .577 .707 r
F P
0 g
s
.38331 .68089 m .38777 .66243 L .41834 .67059 L p .707 .577 .707 r
F P
0 g
s
.38777 .66243 m .38331 .68089 L .35248 .67432 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF1`001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP04001JEUYFFUH80003FUH00`00FUIJEP030002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001EYF1P000eYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1000FUIJEUYF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00@005YF000000QJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH0000>FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol30009FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001SOol20003FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001QOol20005FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005moo`8000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005eoo`<000UJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005aoo`05001JEUYFFUH0
0008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Yoo`80
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol005Uoo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol005Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001FOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0002FUH00`00FUH0
0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001E
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH60002FUH00`00
FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001DOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH30008FUH01000FUIJEUYF0`001EYF00<005YFFUH00`001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00Dgoo0P001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YF00000`002UYF00@005YF000000=JEP03001JEUYF
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol005=oo`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP8000=JEP03001JEUYF00QJEP8000EJEP03001JEUYF00=JEP05001JEUYFFUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000<Woo1@00;goo001BOol01000
FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0`002EYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0002Eoo`d0009JEP800003FUIoogoo02eoo`00DWoo00@005YFFUH0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEPD000IJEP<000QJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0000LOol90003FUH00`00FUIJEP04FUH500000eYF001JEP0_Ool0059oo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEPD000AJEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00005Goo1`0015YF00<005YFFUH01EYF20000UYF00D005YFFUH005YF02moo`00
DWoo0P000UYF00<005YFFUH015YF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF1@000UYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0000AOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06
0003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo0011Ool80009Ool20002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJEP03FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00002goo1P001UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00>goo1P000eYF00<005YFFUH00UYF1`000Woo0P000eYF00<005YF
FUH00eYF00D005YFFUIJEP0000=oo`05001JEUYFFUH00003FUH40002FUH01000FUIJEUYF20001UYF
00<005YFFUH00eYF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Eoo`H000=JEP03001JEUYF00IJEPP000IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool003Uoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00<00005
FUH005YFFUH00006FUH30004Ool01000FUIJEUYF10000eYF1`0015YF00@005YFFUIJEPP000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH60002
FUH00`00FUIJEP04FUH00`00FUH000070004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP02000^Ool003Moo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP80009JEP03001JEUYF00AJEP03001oogoo00Aoo`@00003FUH005YF00@0009JEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000800003FUH0000000d000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Goo0P001EYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF10001UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`002EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUH005YF02ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00P00
0eYF10001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000aOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00@005YF001JEP800003FUH005YF00MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo000`Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEP00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP020006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH2000015YF000000001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJEP0002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00H005YF000005YF0007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUIJEP001eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000IJ
EP03001JEP00008000YJEP@0009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEPD002moo`00;Woo0P000eYF00<005YF
FUH015YF00<005YFFUH00UYF3P001eYF0`0015YF00<005YFFUH01EYF00<005YFFUH015YF1@0025YF
0`000UYF00<005YFFUH025YF0P000UYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1@00=7oo000^Ool20003FUH00`00FUIJEP03FUH6
000>Ool30004FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH40002FUH30005
FUH00`00FUIJEP06FUH20004FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000<003Uoo`00;Goo00<005YF00000eYF00<005YF00000`005goo0`0000AJ
EP00FUH000AJEP03001JEUYF00AJEPD000MJEPH000QJEP03001JEUYF00AJEP800003FUH005YF00=J
EP04001JEUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH003eo
o`00;Goo00<005YF00000eYF0P007Woo0P0000=JEP00FUH015YF00@005YFFUIJEP8000EJEP03001J
EUYF009JEPL000UJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT004=oo`00;Goo0P000eYF00<007ooOol07goo00@0
05YFFUH000AJEP03001JEP00008000=JEPP0009JEPD000UJEP03001JEP00008000IJEP03001JEUYF
009JEP03001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2000C7oo000]Ool200000eYF0000000R
Ool01000FUIJEP0015YF0P0000=JEP0000000`0000=JEP00FUH00UYF00<005YFFUH00eYF0`0025YF
100000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF20001goo7000<Goo000]
Ool4000SOol01000FUIJEP000UYF0P001UYF00@005YFFUH000=JEP03001JEUYF00EJEP04001JEUYF
FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEUYF2`001Woo2@0015YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YF00000P00;Woo000]Ool20002FUH00`00Oomoo`0POol700000goo001J
EP04FUH01000FUIJEP000eYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0000Uoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002eoo`05FUH005YFFUH0000FOol30007Ool30002FUH00`00FUIJ
EP080003FUH01000FUIJEUYF20001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
00=oo`H0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP03001oogoo019oo`D000Eoo`8000=J
EP03001JEUYF00AJEP04001JEUYFFUH90004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
FUIJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`<000=JEP<0019oo`D000Eo
o`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@0009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP<000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03
001JEP0000=JEP04001JEUYF000AOol50004Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001JEUYF
014000MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF0000
0eYF00@005YFFUIJEP8000Moo`l0009oo`03FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00H000=JEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP00009JEP03001JEUYF00AJEPL000=JEP03001J
EUYF00IJEP03001JEUYF00800003FUH0000000d000AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00QJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01P00FUIJEP00FUH000=JEP@00003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEP000007FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUIJEP02FUH0
1000FUIJEUYF100000=JEP00FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP04001JEUYF
0005FUH70007FUH00`00FUIJEP06FUH01000FUH000001UYF0`001EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUH005YF001JEP020005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF00D0
05YFFUIJEP0002eoo`00;Goo00H005YFFUIJEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH40002FUH00`00
FUIJEP07FUH01000FUIJEUYF1P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00@005YFFUH0009JEP8000EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEPL000=JEP05001JEUYFFUH0000]Ool002eoo`04001JEUYFFUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP800003FUH005YF00=J
EP03001JEUYF00AJEP04001JEUYFFUH50006FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH015YF
00<005YFFUH010000UYF3@0015YF00<005YFFUH01UYF0`000eYF2000;Goo000]Ool00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30004FUH40002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP06FUH00`00FUH000020005FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00UYF2P0025YF00<005YFFUH00UYF1P001eYF00@005YFFUH000=JEP07001JEUYF
FUH005YF0000;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUH000050004FUH00`00FUIJEP02FUH;0007FUH00`00FUIJEP02
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUIJEP000eYF00<005YF00001P001UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP06FUH90002FUH50004
FUH20004FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUIJEP000eYF1@000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00`0000=JEP00FUH01EYF0P000UYF0P00;goo000^Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006
FUH00`00FUIJEP04FUH80007FUH300000eYF001JEP05FUH00`00FUH00002000<FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1000<Goo000]Ool00`00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH0000015YF00<005YFFUH01UYF00<005YFFUH010002EYF0P001EYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000`00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0015YF00<005YF0000<Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH@0006FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH025YF00<005YFFUH015YF1P00
0eYF00@005YF000000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPT000Eoo`80009JEP04001JEUYF000aOol002eoo`8000AJEP03001JEUYF009J
EPH00003FUH005YF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF00=JEP@0
00IJEP03001JEUYF00MJEP04001JEUYFFUH900000eYF001JEP03FUH2000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000L000@Ool30003FUH00`00
Oomoo`0^Ool002eoo`8000AJEP03001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<000EJEP03001JEUYF00=JEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP040003FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUH005YF00001UYF00<005YFFUH015YF00@005YFFUIJEP8001ioo`05001JEUYF
FUH0000`Ool002eoo`8000AJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH50006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH50006FUH00`00FUIJEP04FUH01@00FUIJEP00FUH087oo00@005YFFUH0031oo`00;Goo0P000UYF
0P000Woo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJ
EP05001JEUYFFUH00003FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP03000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF0000
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P0027oo0`005Goo00D005YF001JEP0002moo`00;7oo
00<005YF00000P001Goo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF
00000005FUH00`00FUIJEP04FUH01000FUIJEUYF0P001goo1@005Goo0P0000=JEP00Ool0;Woo000/
Ool01@00FUH005YF00001goo0P000eYF00<005YFFUH01eYF10001EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPL000=JEP07001J
EUYFFUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P0000AJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF008000Qoo`D001Ioo`03001JEP0002moo`00;7oo0P00
0eYF00<007ooOol01Woo0P0000=JEP00FUH01eYF1P0015YF00<005YFFUH01EYF00<005YFFUH00eYF
10000eYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00X000aJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP800003FUH005YF00EJEP04001JEUYFFUH20008
Ool5000FOol00`00FUH0000_Ool002aoo`8000=JEP<000Qoo`@000IJEPH000=JEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000=oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00004FUH30006FUH01000FUIJEUYF0P002Goo0`0067oo0P00;goo000/Ool20003FUH00`00FUIJ
EP02000:Ool40002FUH60003FUH00`00FUIJEP05FUH00`00FUH000030006Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00004FUH50004FUH00`00FUIJEP02000UOol2000_
Ool002aoo`8000=JEP03001JEUYF009JEP<000]oo`L000AJEP03001JEUYF009JEPD000Qoo`800003
FUH0000000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH01@00FUIJEP00FUH0
0P0000=JEP00FUH00UYF0P009Goo0P00;goo000/Ool20003FUH00`00FUIJEP03FUH01000FUH00000
47oo2@002goo0P000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0
0004FUH50003FUH00`00Oomoo`0ROol3000`Ool002eoo`04001JEUYF0006FUH01000FUIJEUYF0`00
7Goo100000=JEP00FUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH015YF
5@002EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP<000IJEPL0029oo`800003FUH0
0000031oo`00;Goo00@005YFFUH000IJEP03001JEUYF00AJEPD001=oo`D000EJEP04001JEUYFFUH2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH6
0003FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000IJEP03001JEP0000@0
021oo`8000=JEP03001oogoo02moo`00;Woo00<005YF00001UYF00<005YFFUH01EYF00@005YFFUIJ
EQ<000=JEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJEP07000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH60007FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF
0P0015YF00@005YFFUIJEP<001eoo`<00003FUH005YF009JEP03001oogoo02moo`00;Woo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP@000IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP04001JEUYFFUH50002FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF
00@005YFFUH000MJEPH001Aoo`<000AJEP04001JEUYF000bOol002moo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8000=JEP03001JEUYF009JEP<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEP@000EJEP05001JEUYFFUH00005FUH30008FUH00`00FUIJEP02FUH90007Ool4
00000eYF001JEP04FUH00`00FUH0000cOol0031oo`03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEPd000=JEP03001JEP000080009JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00@00003FUH005YF009JEPX000MJEP03001JEUYF00IJEP03001JEUYF009JEPL000EJEP03001JEUYF
00=JEP8003Aoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF2@00
0eYF00<005YFFUH015YF00<005YF00000eYF0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00<005YF0000
1UYF0`0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
=Goo000cOol200000eYF001JEP06FUH00`00FUIJEP06FUH90004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUH00002FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH00`00FUH00007FUH00`00FUH0
000200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000gOol003Eo
o`<000IJEPT000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP000080
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000kOol003Qoo`L000=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0001<0041oo`00<goo1@000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEPD000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH>
0003FUH01000FUIJEP00DWoo000^Ool500000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH@00001EYF001JEUYF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP03001JEUYF00=JEP800003FUH005YF00@0009JEP80055oo`00;Woo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00@005YFFUIJEPH0
00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH30002
FUH00`00FUH0000200000eYF001oo`1@Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000=JEP03001JEUYF00IJEP03001JEUYF009JEPL000Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH00`0000AJEP00Oomo
o`80055oo`00;Woo00<005YF00000eYF00@005YFFUIJEPP0009JEP03001JEUYF00IJEP03001JEUYF
009JEPT000eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH00UYF0P000Woo00@005YF0000051oo`00;goo0P000UYF1@000UYF00<005YFFUH01EYF
00<005YFFUH00UYF2@005goo0`001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00@005YF
FUIJEP<0009oo`04001JEUYF001@Ool002moo`@00003FUH005YF00AJEP03001JEUYF009JEPP0029o
o`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00Ool2
0002FUH00`00Oomoo`1>Ool002mooa0002aoo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF
00AJEP03001JEUYF00@00006Ool005YF001JEP00DGoo001]Ool200000eYF001JEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUH0000E0004Ool01000
FUIJEUYF0P00DGoo001_Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH5000HOol00`00FUIJEP02FUH00`00Oomoo`1@Ool007=oo`D0009JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00D00003Ool0000000<001Eoo`<000AJ
EP03001oogoo051oo`00N7oo20001UYF00<005YFFUH02UYF00<005YFFUH015YF2@001Woo1@004goo
0P000UYF00D005YFFUIJEP0005=oo`00P7oo6P003goo1@004Goo0P001EYF00<005YF0000E7oo002B
Ool01P00FUIJEP00FUH0019oo`<0011oo`8000MJEP8005Eoo`00TWoo00<005YFFUH00P0097oo0P00
00=JEP00FUH01UYF00<007ooOol0E7oo002BOol01000FUIJEP008Woo0`0015YF00<005YFFUH00UYF
0P00Egoo002COol2000POol30007FUH01@00FUIJEUYF0000FGoo002COol2000LOol400000eYF001J
EP08FUH3001JOol009=oo`04001JEP00000EOol50006FUH00`00FUIJEP05FUH2001LOol009=oo`80
009JEP<000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8005ioo`00U7oo00@005YFFUH0
009JEPh000IJEP03001JEUYF00MJEP03001JEP000080061oo`00U7oo00@005YFFUH000EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@006=oo`00UGoo0P0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000Igoo002GOol30004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001[Ool009Yoo`<00003FUH005YF00=JEPP0079oo`00WGoo1P00NWoo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59026 .73945 m .60152 .68388 L .57109 .67648 L p .707 .577 .707 r
F P
0 g
s
.60152 .68388 m .59026 .73945 L .62154 .74514 L p .707 .577 .707 r
F P
0 g
s
.62154 .74514 m .6328 .68956 L .60152 .68388 L p .707 .577 .707 r
F P
0 g
s
.6328 .68956 m .62154 .74514 L .65059 .74855 L p .707 .577 .707 r
F P
0 g
s
.65059 .74855 m .66185 .69297 L .6328 .68956 L p .707 .577 .707 r
F P
0 g
s
.55983 .73206 m .57109 .67648 L .54448 .6681 L p .707 .577 .707 r
F P
0 g
s
.57109 .67648 m .55983 .73206 L .59026 .73945 L p .707 .577 .707 r
F P
0 g
s
.66185 .69297 m .65059 .74855 L .67458 .74936 L p .707 .577 .707 r
F P
0 g
s
.67458 .74936 m .68584 .69378 L .66185 .69297 L p .707 .577 .707 r
F P
0 g
s
.54448 .6681 m .53322 .72367 L .55983 .73206 L p .707 .577 .707 r
F P
0 g
s
.59252 .80535 m .59625 .76808 L .56525 .76349 L p .707 .577 .707 r
F P
0 g
s
.59625 .76808 m .59252 .80535 L .62421 .80773 L p .707 .577 .707 r
F P
0 g
s
.62421 .80773 m .62795 .77045 L .59625 .76808 L p .707 .577 .707 r
F P
0 g
s
.53322 .72367 m .54448 .6681 L .52429 .65954 L p .707 .577 .707 r
F P
0 g
s
.62795 .77045 m .62421 .80773 L .6535 .80766 L p .707 .577 .707 r
F P
0 g
s
.6535 .80766 m .65723 .77039 L .62795 .77045 L p .707 .577 .707 r
F P
0 g
s
.56152 .80076 m .56525 .76349 L .53798 .75714 L p .707 .577 .707 r
F P
0 g
s
.56525 .76349 m .56152 .80076 L .59252 .80535 L p .707 .577 .707 r
F P
0 g
s
.52429 .65954 m .51303 .71512 L .53322 .72367 L p .707 .577 .707 r
F P
0 g
s
.53798 .75714 m .53424 .79442 L .56152 .80076 L p .707 .577 .707 r
F P
0 g
s
.65723 .77039 m .6535 .80766 L .67751 .80516 L p .707 .577 .707 r
F P
0 g
s
.67751 .80516 m .68125 .76789 L .65723 .77039 L p .707 .577 .707 r
F P
0 g
s
.68584 .69378 m .67458 .74936 L .69115 .74749 L p .707 .577 .707 r
F P
0 g
s
.69115 .74749 m .70241 .69191 L .68584 .69378 L p .707 .577 .707 r
F P
0 g
s
.53424 .79442 m .53798 .75714 L .51711 .74965 L p .707 .577 .707 r
F P
0 g
s
.6089 .85725 m .60614 .83928 L .57512 .84145 L p .707 .577 .707 r
F P
0 g
s
.60614 .83928 m .6089 .85725 L .64033 .85172 L p .707 .577 .707 r
F P
0 g
s
.64033 .85172 m .63756 .83375 L .60614 .83928 L p .707 .577 .707 r
F P
0 g
s
.63756 .83375 m .64033 .85172 L .66908 .84339 L p .707 .577 .707 r
F P
0 g
s
.66908 .84339 m .66632 .82542 L .63756 .83375 L p .707 .577 .707 r
F P
0 g
s
.51303 .71512 m .52429 .65954 L .51251 .65166 L p .707 .577 .707 r
F P
0 g
s
.57512 .84145 m .57789 .85943 L .6089 .85725 L p .707 .577 .707 r
F P
0 g
s
.57789 .85943 m .57512 .84145 L .54755 .84007 L p .707 .577 .707 r
F P
0 g
s
.51711 .74965 m .51337 .78693 L .53424 .79442 L p .707 .577 .707 r
F P
0 g
s
.51251 .65166 m .50125 .70724 L .51303 .71512 L p .707 .577 .707 r
F P
0 g
s
.66632 .82542 m .66908 .84339 L .69235 .83307 L p .707 .577 .707 r
F P
0 g
s
.69235 .83307 m .68959 .8151 L .66632 .82542 L p .707 .577 .707 r
F P
0 g
s
.54755 .84007 m .55031 .85804 L .57789 .85943 L p .707 .577 .707 r
F P
0 g
s
.68125 .76789 m .67751 .80516 L .69389 .80047 L p .707 .577 .707 r
F P
0 g
s
.69389 .80047 m .69763 .76319 L .68125 .76789 L p .707 .577 .707 r
F P
0 g
s
.70241 .69191 m .69115 .74749 L .69869 .74312 L p .707 .577 .707 r
F P
0 g
s
.69869 .74312 m .70995 .68754 L .70241 .69191 L p .707 .577 .707 r
F P
0 g
s
.51337 .78693 m .51711 .74965 L .50467 .74176 L p .707 .577 .707 r
F P
0 g
s
.55031 .85804 m .54755 .84007 L .52612 .83526 L p .707 .577 .707 r
F P
0 g
s
.52612 .83526 m .52888 .85323 L .55031 .85804 L p .707 .577 .707 r
F P
0 g
s
.50467 .74176 m .50094 .77904 L .51337 .78693 L p .707 .577 .707 r
F P
0 g
s
.50125 .70724 m .51251 .65166 L .51027 .64522 L p .707 .577 .707 r
F P
0 g
s
.68959 .8151 m .69235 .83307 L .70786 .82177 L p .707 .577 .707 r
F P
0 g
s
.70786 .82177 m .7051 .80379 L .68959 .8151 L p .707 .577 .707 r
F P
0 g
s
.69763 .76319 m .69389 .80047 L .70105 .79404 L p .707 .577 .707 r
F P
0 g
s
.70105 .79404 m .70479 .75677 L .69763 .76319 L p .707 .577 .707 r
F P
0 g
s
.51027 .64522 m .49901 .70079 L .50125 .70724 L p .707 .577 .707 r
F P
0 g
s
.52888 .85323 m .52612 .83526 L .51293 .8275 L p .707 .577 .707 r
F P
0 g
s
.50094 .77904 m .50467 .74176 L .5019 .73423 L p .707 .577 .707 r
F P
0 g
s
.70995 .68754 m .69869 .74312 L .69646 .73667 L p .707 .577 .707 r
F P
0 g
s
.69646 .73667 m .70772 .6811 L .70995 .68754 L p .707 .577 .707 r
F P
0 g
s
.51293 .8275 m .51569 .84547 L .52888 .85323 L p .707 .577 .707 r
F P
0 g
s
.7051 .80379 m .70786 .82177 L .71409 .81059 L p .707 .577 .707 r
F P
0 g
s
.71409 .81059 m .71132 .79262 L .7051 .80379 L p .707 .577 .707 r
F P
0 g
s
.48073 .82158 m .48073 .31969 L .4375 .31621 L p .707 .577 .707 r
F P
0 g
s
.5019 .73423 m .49816 .77151 L .50094 .77904 L p .707 .577 .707 r
F P
0 g
s
.49901 .70079 m .51027 .64522 L .51781 .64085 L p .707 .577 .707 r
F P
0 g
s
.51781 .64085 m .50655 .69642 L .49901 .70079 L p .707 .577 .707 r
F P
0 g
s
.51569 .84547 m .51293 .8275 L .50927 .81754 L p .707 .577 .707 r
F P
0 g
s
.50927 .81754 m .51203 .83551 L .51569 .84547 L p .707 .577 .707 r
F P
0 g
s
.49816 .77151 m .5019 .73423 L .50906 .72781 L p .707 .577 .707 r
F P
0 g
s
.50906 .72781 m .50532 .76508 L .49816 .77151 L p .707 .577 .707 r
F P
0 g
s
.50655 .69642 m .51781 .64085 L .53439 .63897 L p .707 .577 .707 r
F P
0 g
s
.53439 .63897 m .52313 .69455 L .50655 .69642 L p .707 .577 .707 r
F P
0 g
s
.51203 .83551 m .50927 .81754 L .5155 .80636 L p .707 .577 .707 r
F P
0 g
s
.5155 .80636 m .51826 .82433 L .51203 .83551 L p .707 .577 .707 r
F P
0 g
s
.50532 .76508 m .50906 .72781 L .52544 .72312 L p .707 .577 .707 r
F P
0 g
s
.52544 .72312 m .5217 .76039 L .50532 .76508 L p .707 .577 .707 r
F P
0 g
s
.51826 .82433 m .5155 .80636 L .531 .79506 L p .707 .577 .707 r
F P
0 g
s
.531 .79506 m .53377 .81303 L .51826 .82433 L p .707 .577 .707 r
F P
0 g
s
.48073 .31969 m .48073 .82158 L .52585 .8213 L p .707 .577 .707 r
F P
0 g
s
.52313 .69455 m .53439 .63897 L .55838 .63979 L p .707 .577 .707 r
F P
0 g
s
.55838 .63979 m .54712 .69536 L .52313 .69455 L p .707 .577 .707 r
F P
0 g
s
.5217 .76039 m .52544 .72312 L .54945 .72062 L p .707 .577 .707 r
F P
0 g
s
.54945 .72062 m .54571 .75789 L .5217 .76039 L p .707 .577 .707 r
F P
0 g
s
.52585 .8213 m .52585 .31941 L .48073 .31969 L p .707 .577 .707 r
F P
0 g
s
.54712 .69536 m .55838 .63979 L .58743 .6432 L p .707 .577 .707 r
F P
0 g
s
.58743 .6432 m .57617 .69877 L .54712 .69536 L p .707 .577 .707 r
F P
0 g
s
.54571 .75789 m .54945 .72062 L .57874 .72055 L p .707 .577 .707 r
F P
0 g
s
.53377 .81303 m .531 .79506 L .55427 .78474 L p .707 .577 .707 r
F P
0 g
s
.55427 .78474 m .55704 .80271 L .53377 .81303 L p .707 .577 .707 r
F P
0 g
s
.57874 .72055 m .575 .75783 L .54571 .75789 L p .707 .577 .707 r
F P
0 g
s
.55704 .80271 m .55427 .78474 L .58303 .77641 L p .707 .577 .707 r
F P
0 g
s
.58303 .77641 m .58579 .79438 L .55704 .80271 L p .707 .577 .707 r
F P
0 g
s
.52585 .31941 m .52585 .8213 L .56844 .81729 L p .707 .577 .707 r
F P
0 g
s
.56844 .81729 m .56844 .3154 L .52585 .31941 L p .707 .577 .707 r
F P
0 g
s
.4375 .8181 m .4375 .31621 L .40039 .30932 L p .707 .577 .707 r
F P
0 g
s
.4375 .31621 m .4375 .8181 L .48073 .82158 L p .707 .577 .707 r
F P
0 g
s
.70479 .75677 m .70105 .79404 L .69827 .78652 L p .707 .577 .707 r
F P
0 g
s
.69827 .78652 m .70201 .74924 L .70479 .75677 L p .707 .577 .707 r
F P
0 g
s
.57617 .69877 m .58743 .6432 L .6187 .64888 L p .707 .577 .707 r
F P
0 g
s
.6187 .64888 m .60744 .70446 L .57617 .69877 L p .707 .577 .707 r
F P
0 g
s
.575 .75783 m .57874 .72055 L .61043 .72293 L p .707 .577 .707 r
F P
0 g
s
.61043 .72293 m .60669 .7602 L .575 .75783 L p .707 .577 .707 r
F P
0 g
s
.58579 .79438 m .58303 .77641 L .61445 .77088 L p .707 .577 .707 r
F P
0 g
s
.61445 .77088 m .61721 .78885 L .58579 .79438 L p .707 .577 .707 r
F P
0 g
s
.56844 .3154 m .56844 .81729 L .60432 .80995 L p .707 .577 .707 r
F P
0 g
s
.60432 .80995 m .60432 .30806 L .56844 .3154 L p .707 .577 .707 r
F P
0 g
s
.70772 .6811 m .69646 .73667 L .68467 .72879 L p .707 .577 .707 r
F P
0 g
s
.68467 .72879 m .69593 .67321 L .70772 .6811 L p .707 .577 .707 r
F P
0 g
s
.71132 .79262 m .71409 .81059 L .71043 .80063 L p .707 .577 .707 r
F P
0 g
s
.71043 .80063 m .70766 .78266 L .71132 .79262 L p .707 .577 .707 r
F P
0 g
s
.25009 .72919 m .25494 .67795 L .22397 .67223 L p .707 .577 .707 r
F P
0 g
s
.25494 .67795 m .25009 .72919 L .28185 .73045 L p .707 .577 .707 r
F P
0 g
s
.28185 .73045 m .2867 .67921 L .25494 .67795 L p .707 .577 .707 r
F P
0 g
s
.2867 .67921 m .28185 .73045 L .31129 .72712 L p .707 .577 .707 r
F P
0 g
s
.31129 .72712 m .31614 .67588 L .2867 .67921 L p .707 .577 .707 r
F P
0 g
s
.21913 .72347 m .22397 .67223 L .19683 .6626 L p .707 .577 .707 r
F P
0 g
s
.22397 .67223 m .21913 .72347 L .25009 .72919 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.40039 .81121 m .40039 .30932 L .37302 .29969 L p .707 .577 .707 r
F P
0 g
s
.40039 .30932 m .40039 .81121 L .4375 .8181 L p .707 .577 .707 r
F P
0 g
s
.64913 .65628 m .63787 .71185 L .60744 .70446 L p .707 .577 .707 r
F P
0 g
s
.60744 .70446 m .6187 .64888 L .64913 .65628 L p .707 .577 .707 r
F P
0 g
s
.64143 .72752 m .63769 .76479 L .60669 .7602 L p .707 .577 .707 r
F P
0 g
s
.60669 .7602 m .61043 .72293 L .64143 .72752 L p .707 .577 .707 r
F P
0 g
s
.64547 .7687 m .64823 .78667 L .61721 .78885 L p .707 .577 .707 r
F P
0 g
s
.61721 .78885 m .61445 .77088 L .64547 .7687 L p .707 .577 .707 r
F P
0 g
s
.60432 .30806 m .60432 .80995 L .63 .79999 L p .707 .577 .707 r
F P
0 g
s
.63 .79999 m .63 .2981 L .60432 .30806 L p .707 .577 .707 r
F P
0 g
s
.70201 .74924 m .69827 .78652 L .68584 .77862 L p .707 .577 .707 r
F P
0 g
s
.68584 .77862 m .68958 .74135 L .70201 .74924 L p .707 .577 .707 r
F P
0 g
s
.31614 .67588 m .31129 .72712 L .33552 .71952 L p .707 .577 .707 r
F P
0 g
s
.33552 .71952 m .34037 .66829 L .31614 .67588 L p .707 .577 .707 r
F P
0 g
s
.19198 .71384 m .19683 .6626 L .17615 .65001 L p .707 .577 .707 r
F P
0 g
s
.19683 .6626 m .19198 .71384 L .21913 .72347 L p .707 .577 .707 r
F P
0 g
s
.69593 .67321 m .68467 .72879 L .66449 .72024 L p .707 .577 .707 r
F P
0 g
s
.66449 .72024 m .67575 .66466 L .69593 .67321 L p .707 .577 .707 r
F P
0 g
s
.25152 .78121 m .25313 .74537 L .22199 .74158 L p .707 .577 .707 r
F P
0 g
s
.25313 .74537 m .25152 .78121 L .28334 .78143 L p .707 .577 .707 r
F P
0 g
s
.28334 .78143 m .28494 .74559 L .25313 .74537 L p .707 .577 .707 r
F P
0 g
s
.28494 .74559 m .28334 .78143 L .31271 .77805 L p .707 .577 .707 r
F P
0 g
s
.31271 .77805 m .31432 .74221 L .28494 .74559 L p .707 .577 .707 r
F P
0 g
s
.26038 .80375 m .25918 .78472 L .22788 .78585 L p .707 .577 .707 r
F P
0 g
s
.25918 .78472 m .26038 .80375 L .29206 .80128 L p .707 .577 .707 r
F P
0 g
s
.29206 .80128 m .29086 .78225 L .25918 .78472 L p .707 .577 .707 r
F P
0 g
s
.70766 .78266 m .71043 .80063 L .69723 .79287 L p .707 .577 .707 r
F P
0 g
s
.69723 .79287 m .69447 .7749 L .70766 .78266 L p .707 .577 .707 r
F P
0 g
s
.22039 .77742 m .22199 .74158 L .19459 .73459 L p .707 .577 .707 r
F P
0 g
s
.22199 .74158 m .22039 .77742 L .25152 .78121 L p .707 .577 .707 r
F P
0 g
s
.22788 .78585 m .22908 .80488 L .26038 .80375 L p .707 .577 .707 r
F P
0 g
s
.29086 .78225 m .29206 .80128 L .32102 .79773 L p .707 .577 .707 r
F P
0 g
s
.32102 .79773 m .31981 .7787 L .29086 .78225 L p .707 .577 .707 r
F P
0 g
s
.22908 .80488 m .22788 .78585 L .20002 .78554 L p .707 .577 .707 r
F P
0 g
s
.34037 .66829 m .33552 .71952 L .35218 .70841 L p .707 .577 .707 r
F P
0 g
s
.35218 .70841 m .35703 .65718 L .34037 .66829 L p .707 .577 .707 r
F P
0 g
s
.20002 .78554 m .20123 .80457 L .22908 .80488 L p .707 .577 .707 r
F P
0 g
s
.31432 .74221 m .31271 .77805 L .33679 .7714 L p .707 .577 .707 r
F P
0 g
s
.33679 .7714 m .33839 .73556 L .31432 .74221 L p .707 .577 .707 r
F P
0 g
s
.1713 .70125 m .17615 .65001 L .16398 .63569 L p .707 .577 .707 r
F P
0 g
s
.17615 .65001 m .1713 .70125 L .19198 .71384 L p .707 .577 .707 r
F P
0 g
s
.37302 .80158 m .37302 .29969 L .35809 .28827 L p .707 .577 .707 r
F P
0 g
s
.37302 .29969 m .37302 .80158 L .40039 .81121 L p .707 .577 .707 r
F P
0 g
s
.68958 .74135 m .68584 .77862 L .66497 .77114 L p .707 .577 .707 r
F P
0 g
s
.66497 .77114 m .6687 .73386 L .68958 .74135 L p .707 .577 .707 r
F P
0 g
s
.19459 .73459 m .19299 .77043 L .22039 .77742 L p .707 .577 .707 r
F P
0 g
s
.31981 .7787 m .32102 .79773 L .34442 .79343 L p .707 .577 .707 r
F P
0 g
s
.34442 .79343 m .34322 .7744 L .31981 .7787 L p .707 .577 .707 r
F P
0 g
s
.19299 .77043 m .19459 .73459 L .1736 .72508 L p .707 .577 .707 r
F P
0 g
s
.67575 .66466 m .66449 .72024 L .63787 .71185 L p .707 .577 .707 r
F P
0 g
s
.63787 .71185 m .64913 .65628 L .67575 .66466 L p .707 .577 .707 r
F P
0 g
s
.6687 .73386 m .66497 .77114 L .63769 .76479 L p .707 .577 .707 r
F P
0 g
s
.63769 .76479 m .64143 .72752 L .6687 .73386 L p .707 .577 .707 r
F P
0 g
s
.63 .2981 m .63 .79999 L .64295 .78839 L p .707 .577 .707 r
F P
0 g
s
.64295 .78839 m .64295 .2865 L .63 .2981 L p .707 .577 .707 r
F P
0 g
s
.20123 .80457 m .20002 .78554 L .17834 .78381 L p .707 .577 .707 r
F P
0 g
s
.17834 .78381 m .17954 .80284 L .20123 .80457 L p .707 .577 .707 r
F P
0 g
s
.69447 .7749 m .69723 .79287 L .6758 .78806 L p .707 .577 .707 r
F P
0 g
s
.6758 .78806 m .67304 .77009 L .69447 .7749 L p .707 .577 .707 r
F P
0 g
s
.1736 .72508 m .17199 .76092 L .19299 .77043 L p .707 .577 .707 r
F P
0 g
s
.33839 .73556 m .33679 .7714 L .35319 .76214 L p .707 .577 .707 r
F P
0 g
s
.35319 .76214 m .3548 .7263 L .33839 .73556 L p .707 .577 .707 r
F P
0 g
s
.35703 .65718 m .35218 .70841 L .35964 .69487 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .36449 .64364 L .35703 .65718 L p .707 .577 .707 r
F P
0 g
s
.15913 .68693 m .16398 .63569 L .1615 .62105 L p .707 .577 .707 r
F P
0 g
s
.16398 .63569 m .15913 .68693 L .1713 .70125 L p .707 .577 .707 r
F P
0 g
s
.34322 .7744 m .34442 .79343 L .35997 .7888 L p .707 .577 .707 r
F P
0 g
s
.35997 .7888 m .35877 .76977 L .34322 .7744 L p .707 .577 .707 r
F P
0 g
s
.17199 .76092 m .1736 .72508 L .16107 .71398 L p .707 .577 .707 r
F P
0 g
s
.17954 .80284 m .17834 .78381 L .16494 .78084 L p .707 .577 .707 r
F P
0 g
s
.16494 .78084 m .16614 .79987 L .17954 .80284 L p .707 .577 .707 r
F P
0 g
s
.67304 .77009 m .6758 .78806 L .64823 .78667 L p .707 .577 .707 r
F P
0 g
s
.64823 .78667 m .64547 .7687 L .67304 .77009 L p .707 .577 .707 r
F P
0 g
s
.16107 .71398 m .15947 .74982 L .17199 .76092 L p .707 .577 .707 r
F P
0 g
s
.3548 .7263 m .35319 .76214 L .36033 .75118 L p .707 .577 .707 r
F P
0 g
s
.36033 .75118 m .36193 .71533 L .3548 .7263 L p .707 .577 .707 r
F P
0 g
s
.35964 .69487 m .35716 .68022 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36449 .64364 m .35993 .69175 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35993 .69175 m .35964 .69487 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35705 .27616 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36201 .62899 m .36449 .64364 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35716 .68022 m .35931 .65746 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.35931 .65746 m .36201 .62899 L p .35951 .66847 L .707 .577 .707 r
F P
0 g
s
.36193 .71533 m .36033 .75118 L .35749 .73958 L p .707 .577 .707 r
F P
0 g
s
.35749 .73958 m .3591 .70373 L .36193 .71533 L p .707 .577 .707 r
F P
0 g
s
.36201 .62899 m .35716 .68022 L .34499 .6659 L p .707 .577 .707 r
F P
0 g
s
.34499 .6659 m .34984 .61467 L .36201 .62899 L p .707 .577 .707 r
F P
0 g
s
.3591 .70373 m .35749 .73958 L .34496 .72848 L p .707 .577 .707 r
F P
0 g
s
.34496 .72848 m .34657 .69263 L .3591 .70373 L p .707 .577 .707 r
F P
0 g
s
.35877 .76977 m .35997 .7888 L .36615 .78431 L p .707 .577 .707 r
F P
0 g
s
.36615 .78431 m .36495 .76528 L .35877 .76977 L p .707 .577 .707 r
F P
0 g
s
.36116 .76136 m .36236 .78039 L .34897 .77741 L p .707 .577 .707 r
F P
0 g
s
.34897 .77741 m .34777 .75839 L .36116 .76136 L p .707 .577 .707 r
F P
0 g
s
.35705 .77805 m .35809 .79015 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .27616 m .35705 .53203 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35705 .53203 m .35705 .77805 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .79015 m .35809 .58969 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.35809 .58969 m .35809 .28827 L p .35763 .56436 L .707 .578 .707 r
F P
0 g
s
.36495 .76528 m .36615 .78431 L .36236 .78039 L p .707 .577 .707 r
F P
0 g
s
.36236 .78039 m .36116 .76136 L .36495 .76528 L p .707 .577 .707 r
F P
0 g
s
.35809 .28827 m .35809 .79015 L .37302 .80158 L p .707 .577 .707 r
F P
0 g
s
.64295 .2865 m .64295 .78839 L .64191 .77628 L p .707 .578 .707 r
F P
0 g
s
.64191 .77628 m .64191 .27439 L .64295 .2865 L p .707 .578 .707 r
F P
0 g
s
.1615 .62105 m .15665 .67228 L .15913 .68693 L p .707 .577 .707 r
F P
0 g
s
.15665 .67228 m .1615 .62105 L .16896 .6075 L p .707 .577 .707 r
F P
0 g
s
.15947 .74982 m .16107 .71398 L .15824 .70238 L p .707 .577 .707 r
F P
0 g
s
.16614 .79987 m .16494 .78084 L .16115 .77692 L p .707 .577 .707 r
F P
0 g
s
.16115 .77692 m .16235 .79595 L .16614 .79987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15824 .70238 m .15663 .73822 L .15947 .74982 L p .707 .577 .707 r
F P
0 g
s
.16896 .6075 m .16411 .65874 L .15665 .67228 L p .707 .577 .707 r
F P
0 g
s
.16411 .65874 m .16896 .6075 L .18562 .59639 L p .707 .577 .707 r
F P
0 g
s
.15663 .73822 m .15824 .70238 L .16537 .69141 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35705 .77805 m .35705 .27616 L .37 .26456 L p .707 .577 .707 r
F P
0 g
s
.64191 .27439 m .64191 .77628 L .62698 .76485 L p .707 .577 .707 r
F P
0 g
s
.62698 .76485 m .62698 .26297 L .64191 .27439 L p .707 .577 .707 r
F P
0 g
s
.16235 .79595 m .16115 .77692 L .16734 .77242 L p .707 .577 .707 r
F P
0 g
s
.16734 .77242 m .16854 .79145 L .16235 .79595 L p .707 .577 .707 r
F P
0 g
s
.16537 .69141 m .16376 .72725 L .15663 .73822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34984 .61467 m .34499 .6659 L .32432 .65331 L p .707 .577 .707 r
F P
0 g
s
.32432 .65331 m .32917 .60208 L .34984 .61467 L p .707 .577 .707 r
F P
0 g
s
.18562 .59639 m .18077 .64763 L .16411 .65874 L p .707 .577 .707 r
F P
0 g
s
.18077 .64763 m .18562 .59639 L .20985 .5888 L p .707 .577 .707 r
F P
0 g
s
.16376 .72725 m .16537 .69141 L .18177 .68215 L p .707 .577 .707 r
F P
0 g
s
.32917 .60208 m .32432 .65331 L .29717 .64369 L p .707 .577 .707 r
F P
0 g
s
.29717 .64369 m .30202 .59245 L .32917 .60208 L p .707 .577 .707 r
F P
0 g
s
.16854 .79145 m .16734 .77242 L .18289 .7678 L p .707 .577 .707 r
F P
0 g
s
.205 .64003 m .20985 .5888 L .23929 .58547 L p .707 .577 .707 r
F P
0 g
s
.20985 .5888 m .205 .64003 L .18077 .64763 L p .707 .577 .707 r
F P
0 g
s
.18177 .68215 m .18017 .71799 L .16376 .72725 L p .707 .577 .707 r
F P
0 g
s
.18289 .7678 m .18409 .78683 L .16854 .79145 L p .707 .577 .707 r
F P
0 g
s
.37 .76645 m .37 .26456 L .39567 .2546 L p .707 .577 .707 r
F P
0 g
s
.37 .26456 m .37 .76645 L .35705 .77805 L p .707 .577 .707 r
F P
0 g
s
.34657 .69263 m .34496 .72848 L .32397 .71896 L p .707 .577 .707 r
F P
0 g
s
.32397 .71896 m .32557 .68312 L .34657 .69263 L p .707 .577 .707 r
F P
0 g
s
.62698 .26297 m .62698 .76485 L .59961 .75522 L p .707 .577 .707 r
F P
0 g
s
.59961 .75522 m .59961 .25334 L .62698 .26297 L p .707 .577 .707 r
F P
0 g
s
.30202 .59245 m .29717 .64369 L .2662 .63796 L p .707 .577 .707 r
F P
0 g
s
.2662 .63796 m .27105 .58673 L .30202 .59245 L p .707 .577 .707 r
F P
0 g
s
.23444 .6367 m .23929 .58547 L .27105 .58673 L p .707 .577 .707 r
F P
0 g
s
.23929 .58547 m .23444 .6367 L .205 .64003 L p .707 .577 .707 r
F P
0 g
s
.18017 .71799 m .18177 .68215 L .20585 .67551 L p .707 .577 .707 r
F P
0 g
s
.27105 .58673 m .2662 .63796 L .23444 .6367 L p .707 .577 .707 r
F P
0 g
s
.34777 .75839 m .34897 .77741 L .32728 .77569 L p .707 .577 .707 r
F P
0 g
s
.32728 .77569 m .32608 .75666 L .34777 .75839 L p .707 .577 .707 r
F P
0 g
s
.18409 .78683 m .18289 .7678 L .20629 .7635 L p .707 .577 .707 r
F P
0 g
s
.20585 .67551 m .20424 .71135 L .18017 .71799 L p .707 .577 .707 r
F P
0 g
s
.32557 .68312 m .32397 .71896 L .29657 .71197 L p .707 .577 .707 r
F P
0 g
s
.29657 .71197 m .29817 .67613 L .32557 .68312 L p .707 .577 .707 r
F P
0 g
s
.20629 .7635 m .20749 .78253 L .18409 .78683 L p .707 .577 .707 r
F P
0 g
s
.20424 .71135 m .20585 .67551 L .23523 .67213 L p .707 .577 .707 r
F P
0 g
s
.7338 .6386 m .72895 .58125 L .69798 .58332 L p .707 .577 .707 r
F P
0 g
s
.72895 .58125 m .7338 .6386 L .76556 .63574 L p .707 .577 .707 r
F P
0 g
s
.76556 .63574 m .76071 .5784 L .72895 .58125 L p .707 .577 .707 r
F P
0 g
s
.39567 .2546 m .39567 .75649 L .37 .76645 L p .707 .577 .707 r
F P
0 g
s
.39567 .75649 m .39567 .2546 L .43156 .24726 L p .707 .577 .707 r
F P
0 g
s
.76071 .5784 m .76556 .63574 L .79499 .63238 L p .707 .577 .707 r
F P
0 g
s
.79499 .63238 m .79015 .57504 L .76071 .5784 L p .707 .577 .707 r
F P
0 g
s
.69798 .58332 m .70283 .64066 L .7338 .6386 L p .707 .577 .707 r
F P
0 g
s
.59961 .25334 m .59961 .75522 L .5625 .74834 L p .707 .577 .707 r
F P
0 g
s
.5625 .74834 m .5625 .24645 L .59961 .25334 L p .707 .577 .707 r
F P
0 g
s
.29817 .67613 m .29657 .71197 L .26543 .70818 L p .707 .577 .707 r
F P
0 g
s
.26543 .70818 m .26704 .67234 L .29817 .67613 L p .707 .577 .707 r
F P
0 g
s
.32608 .75666 m .32728 .77569 L .29943 .77538 L p .707 .577 .707 r
F P
0 g
s
.29943 .77538 m .29822 .75635 L .32608 .75666 L p .707 .577 .707 r
F P
0 g
s
.70283 .64066 m .69798 .58332 L .67083 .58439 L p .707 .577 .707 r
F P
0 g
s
.23362 .70797 m .23523 .67213 L .26704 .67234 L p .707 .577 .707 r
F P
0 g
s
.23523 .67213 m .23362 .70797 L .20424 .71135 L p .707 .577 .707 r
F P
0 g
s
.67083 .58439 m .67568 .64174 L .70283 .64066 L p .707 .577 .707 r
F P
0 g
s
.20749 .78253 m .20629 .7635 L .23525 .75994 L p .707 .577 .707 r
F P
0 g
s
.26704 .67234 m .26543 .70818 L .23362 .70797 L p .707 .577 .707 r
F P
0 g
s
.79015 .57504 m .79499 .63238 L .81923 .62885 L p .707 .577 .707 r
F P
0 g
s
.81923 .62885 m .81438 .5715 L .79015 .57504 L p .707 .577 .707 r
F P
0 g
s
.23525 .75994 m .23645 .77897 L .20749 .78253 L p .707 .577 .707 r
F P
0 g
s
.73456 .70919 m .73296 .67134 L .70183 .67138 L p .707 .577 .707 r
F P
0 g
s
.73296 .67134 m .73456 .70919 L .76638 .70739 L p .707 .577 .707 r
F P
0 g
s
.76638 .70739 m .76477 .66954 L .73296 .67134 L p .707 .577 .707 r
F P
0 g
s
.76477 .66954 m .76638 .70739 L .79576 .70401 L p .707 .577 .707 r
F P
0 g
s
.79576 .70401 m .79415 .66616 L .76477 .66954 L p .707 .577 .707 r
F P
0 g
s
.29822 .75635 m .29943 .77538 L .26813 .77651 L p .707 .577 .707 r
F P
0 g
s
.26813 .77651 m .26692 .75748 L .29822 .75635 L p .707 .577 .707 r
F P
0 g
s
.70183 .67138 m .70343 .70923 L .73456 .70919 L p .707 .577 .707 r
F P
0 g
s
.70343 .70923 m .70183 .67138 L .67442 .66966 L p .707 .577 .707 r
F P
0 g
s
.67568 .64174 m .67083 .58439 L .65016 .58437 L p .707 .577 .707 r
F P
0 g
s
.23645 .77897 m .23525 .75994 L .26692 .75748 L p .707 .577 .707 r
F P
0 g
s
.26692 .75748 m .26813 .77651 L .23645 .77897 L p .707 .577 .707 r
F P
0 g
s
.43156 .74915 m .43156 .24726 L .47415 .24325 L p .707 .577 .707 r
F P
0 g
s
.43156 .24726 m .43156 .74915 L .39567 .75649 L p .707 .577 .707 r
F P
0 g
s
.65016 .58437 m .65501 .64172 L .67568 .64174 L p .707 .577 .707 r
F P
0 g
s
.67442 .66966 m .67603 .70752 L .70343 .70923 L p .707 .577 .707 r
F P
0 g
s
.5625 .24645 m .5625 .74834 L .51927 .74486 L p .707 .577 .707 r
F P
0 g
s
.51927 .74486 m .51927 .24297 L .5625 .24645 L p .707 .577 .707 r
F P
0 g
s
.79415 .66616 m .79576 .70401 L .81983 .69938 L p .707 .577 .707 r
F P
0 g
s
.81983 .69938 m .81822 .66153 L .79415 .66616 L p .707 .577 .707 r
F P
0 g
s
.81438 .5715 m .81923 .62885 L .83589 .62548 L p .707 .577 .707 r
F P
0 g
s
.83589 .62548 m .83104 .56813 L .81438 .5715 L p .707 .577 .707 r
F P
0 g
s
.67603 .70752 m .67442 .66966 L .65343 .66635 L p .707 .577 .707 r
F P
0 g
s
.47415 .74514 m .47415 .24325 L .51927 .24297 L p .707 .577 .707 r
F P
0 g
s
.47415 .24325 m .47415 .74514 L .43156 .74915 L p .707 .577 .707 r
F P
0 g
s
.51927 .24297 m .51927 .74486 L .47415 .74514 L p .707 .577 .707 r
F P
0 g
s
.73187 .77013 m .73307 .75254 L .70177 .74826 L p .707 .577 .707 r
F P
0 g
s
.73307 .75254 m .73187 .77013 L .76355 .77043 L p .707 .577 .707 r
F P
0 g
s
.76355 .77043 m .76475 .75284 L .73307 .75254 L p .707 .577 .707 r
F P
0 g
s
.65343 .66635 m .65503 .70421 L .67603 .70752 L p .707 .577 .707 r
F P
0 g
s
.65501 .64172 m .65016 .58437 L .63799 .58326 L p .707 .577 .707 r
F P
0 g
s
.76475 .75284 m .76355 .77043 L .79251 .76672 L p .707 .577 .707 r
F P
0 g
s
.79251 .76672 m .79371 .74913 L .76475 .75284 L p .707 .577 .707 r
F P
0 g
s
.70057 .76585 m .70177 .74826 L .67392 .74042 L p .707 .577 .707 r
F P
0 g
s
.70177 .74826 m .70057 .76585 L .73187 .77013 L p .707 .577 .707 r
F P
0 g
s
.81822 .66153 m .81983 .69938 L .83623 .69395 L p .707 .577 .707 r
F P
0 g
s
.83623 .69395 m .83463 .6561 L .81822 .66153 L p .707 .577 .707 r
F P
0 g
s
.63799 .58326 m .64284 .64061 L .65501 .64172 L p .707 .577 .707 r
F P
0 g
s
.67392 .74042 m .67272 .75801 L .70057 .76585 L p .707 .577 .707 r
F P
0 g
s
.83104 .56813 m .83589 .62548 L .84335 .6226 L p .707 .577 .707 r
F P
0 g
s
.84335 .6226 m .8385 .56526 L .83104 .56813 L p .707 .577 .707 r
F P
0 g
s
.65503 .70421 m .65343 .66635 L .6409 .66178 L p .707 .577 .707 r
F P
0 g
s
.79371 .74913 m .79251 .76672 L .81591 .75936 L p .707 .577 .707 r
F P
0 g
s
.81591 .75936 m .81711 .74177 L .79371 .74913 L p .707 .577 .707 r
F P
0 g
s
.67272 .75801 m .67392 .74042 L .65223 .72979 L p .707 .577 .707 r
F P
0 g
s
.6409 .66178 m .64251 .69963 L .65503 .70421 L p .707 .577 .707 r
F P
0 g
s
.65223 .72979 m .65103 .74738 L .67272 .75801 L p .707 .577 .707 r
F P
0 g
s
.64284 .64061 m .63799 .58326 L .63551 .58117 L p .707 .577 .707 r
F P
0 g
s
.83463 .6561 m .83623 .69395 L .84337 .68826 L p .707 .577 .707 r
F P
0 g
s
.84337 .68826 m .84176 .65041 L .83463 .6561 L p .707 .577 .707 r
F P
0 g
s
.63551 .58117 m .64036 .63851 L .64284 .64061 L p .707 .577 .707 r
F P
0 g
s
.81711 .74177 m .81591 .75936 L .83146 .74908 L p .707 .577 .707 r
F P
0 g
s
.83146 .74908 m .83266 .73149 L .81711 .74177 L p .707 .577 .707 r
F P
0 g
s
.65103 .74738 m .65223 .72979 L .63884 .71741 L p .707 .577 .707 r
F P
0 g
s
.8385 .56526 m .84335 .6226 L .84087 .62051 L p .707 .577 .707 r
F P
0 g
s
.84087 .62051 m .83602 .56317 L .8385 .56526 L p .707 .577 .707 r
F P
0 g
s
.64251 .69963 m .6409 .66178 L .63807 .65638 L p .707 .577 .707 r
F P
0 g
s
.63884 .71741 m .63763 .735 L .65103 .74738 L p .707 .577 .707 r
F P
0 g
s
.63807 .65638 m .63967 .69423 L .64251 .69963 L p .707 .577 .707 r
F P
0 g
s
.84176 .65041 m .84337 .68826 L .84053 .68286 L p .707 .577 .707 r
F P
0 g
s
.84053 .68286 m .83893 .64501 L .84176 .65041 L p .707 .577 .707 r
F P
0 g
s
.64036 .63851 m .63551 .58117 L .64297 .5783 L p .707 .577 .707 r
F P
0 g
s
.83266 .73149 m .83146 .74908 L .83764 .73688 L p .707 .577 .707 r
F P
0 g
s
.83764 .73688 m .83885 .71929 L .83266 .73149 L p .707 .577 .707 r
F P
0 g
s
.63763 .735 m .63884 .71741 L .63505 .70448 L p .707 .577 .707 r
F P
0 g
s
.64297 .5783 m .64781 .63564 L .64036 .63851 L p .707 .577 .707 r
F P
0 g
s
.63505 .70448 m .63384 .72207 L .63763 .735 L p .707 .577 .707 r
F P
0 g
s
.63967 .69423 m .63807 .65638 L .6452 .65069 L p .707 .577 .707 r
F P
0 g
s
.83602 .56317 m .84087 .62051 L .8287 .6194 L p .707 .577 .707 r
F P
0 g
s
.8287 .6194 m .82385 .56205 L .83602 .56317 L p .707 .577 .707 r
F P
0 g
s
.42383 .62247 m .41257 .56938 L .38129 .57601 L p .707 .577 .707 r
F P
0 g
s
.41257 .56938 m .42383 .62247 L .45288 .61288 L p .707 .577 .707 r
F P
0 g
s
.45288 .61288 m .44162 .55979 L .41257 .56938 L p .707 .577 .707 r
F P
0 g
s
.39256 .62909 m .38129 .57601 L .35086 .57903 L p .707 .577 .707 r
F P
0 g
s
.38129 .57601 m .39256 .62909 L .42383 .62247 L p .707 .577 .707 r
F P
0 g
s
.6452 .65069 m .64681 .68854 L .63967 .69423 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44162 .55979 m .45288 .61288 L .47687 .60127 L p .707 .577 .707 r
F P
0 g
s
.47687 .60127 m .46561 .54819 L .44162 .55979 L p .707 .577 .707 r
F P
0 g
s
.36212 .63211 m .35086 .57903 L .32425 .57814 L p .707 .577 .707 r
F P
0 g
s
.35086 .57903 m .36212 .63211 L .39256 .62909 L p .707 .577 .707 r
F P
0 g
s
.83885 .71929 m .83764 .73688 L .83385 .72395 L p .707 .577 .707 r
F P
0 g
s
.83385 .72395 m .83506 .70636 L .83885 .71929 L p .707 .577 .707 r
F P
0 g
s
.83893 .64501 m .84053 .68286 L .82801 .67829 L p .707 .577 .707 r
F P
0 g
s
.82801 .67829 m .8264 .64043 L .83893 .64501 L p .707 .577 .707 r
F P
0 g
s
.64781 .63564 m .64297 .5783 L .65963 .57493 L p .707 .577 .707 r
F P
0 g
s
.63384 .72207 m .63505 .70448 L .64123 .69228 L p .707 .577 .707 r
F P
0 g
s
.65963 .57493 m .66448 .63227 L .64781 .63564 L p .707 .577 .707 r
F P
0 g
s
.64123 .69228 m .64003 .70987 L .63384 .72207 L p .707 .577 .707 r
F P
0 g
s
.3933 .68523 m .38957 .64881 L .35857 .64947 L p .707 .577 .707 r
F P
0 g
s
.38957 .64881 m .3933 .68523 L .425 .68143 L p .707 .577 .707 r
F P
0 g
s
.425 .68143 m .42126 .64501 L .38957 .64881 L p .707 .577 .707 r
F P
0 g
s
.42126 .64501 m .425 .68143 L .45429 .67486 L p .707 .577 .707 r
F P
0 g
s
.45429 .67486 m .45055 .63844 L .42126 .64501 L p .707 .577 .707 r
F P
0 g
s
.82385 .56205 m .8287 .6194 L .80802 .61938 L p .707 .577 .707 r
F P
0 g
s
.80802 .61938 m .80317 .56204 L .82385 .56205 L p .707 .577 .707 r
F P
0 g
s
.64681 .68854 m .6452 .65069 L .66161 .64526 L p .707 .577 .707 r
F P
0 g
s
.46561 .54819 m .47687 .60127 L .49344 .58877 L p .707 .577 .707 r
F P
0 g
s
.49344 .58877 m .48218 .53569 L .46561 .54819 L p .707 .577 .707 r
F P
0 g
s
.33551 .63122 m .32425 .57814 L .30406 .57343 L p .707 .577 .707 r
F P
0 g
s
.32425 .57814 m .33551 .63122 L .36212 .63211 L p .707 .577 .707 r
F P
0 g
s
.3623 .68589 m .35857 .64947 L .33129 .64693 L p .707 .577 .707 r
F P
0 g
s
.35857 .64947 m .3623 .68589 L .3933 .68523 L p .707 .577 .707 r
F P
0 g
s
.66161 .64526 m .66321 .68311 L .64681 .68854 L p .707 .577 .707 r
F P
0 g
s
.38278 .717 m .38555 .69837 L .35453 .69267 L p .707 .577 .707 r
F P
0 g
s
.38555 .69837 m .38278 .717 L .41421 .7207 L p .707 .577 .707 r
F P
0 g
s
.41421 .7207 m .41697 .70207 L .38555 .69837 L p .707 .577 .707 r
F P
0 g
s
.45055 .63844 m .45429 .67486 L .4783 .66617 L p .707 .577 .707 r
F P
0 g
s
.4783 .66617 m .47456 .62974 L .45055 .63844 L p .707 .577 .707 r
F P
0 g
s
.35453 .69267 m .35177 .71129 L .38278 .717 L p .707 .577 .707 r
F P
0 g
s
.41697 .70207 m .41421 .7207 L .44296 .72203 L p .707 .577 .707 r
F P
0 g
s
.44296 .72203 m .44572 .70341 L .41697 .70207 L p .707 .577 .707 r
F P
0 g
s
.35177 .71129 m .35453 .69267 L .32696 .68552 L p .707 .577 .707 r
F P
0 g
s
.66448 .63227 m .65963 .57493 L .68386 .57139 L p .707 .577 .707 r
F P
0 g
s
.83506 .70636 m .83385 .72395 L .82046 .71157 L p .707 .577 .707 r
F P
0 g
s
.82046 .71157 m .82166 .69398 L .83506 .70636 L p .707 .577 .707 r
F P
0 g
s
.8264 .64043 m .82801 .67829 L .80701 .67498 L p .707 .577 .707 r
F P
0 g
s
.80701 .67498 m .80541 .63712 L .8264 .64043 L p .707 .577 .707 r
F P
0 g
s
.64003 .70987 m .64123 .69228 L .65678 .682 L p .707 .577 .707 r
F P
0 g
s
.33129 .64693 m .33503 .68336 L .3623 .68589 L p .707 .577 .707 r
F P
0 g
s
.32696 .68552 m .32419 .70415 L .35177 .71129 L p .707 .577 .707 r
F P
0 g
s
.68386 .57139 m .68871 .62873 L .66448 .63227 L p .707 .577 .707 r
F P
0 g
s
.30406 .57343 m .31532 .62652 L .33551 .63122 L p .707 .577 .707 r
F P
0 g
s
.33503 .68336 m .33129 .64693 L .31042 .64144 L p .707 .577 .707 r
F P
0 g
s
.65678 .682 m .65558 .69959 L .64003 .70987 L p .707 .577 .707 r
F P
0 g
s
.80317 .56204 m .80802 .61938 L .78087 .62046 L p .707 .577 .707 r
F P
0 g
s
.78087 .62046 m .77602 .56311 L .80317 .56204 L p .707 .577 .707 r
F P
0 g
s
.48218 .53569 m .49344 .58877 L .50098 .57662 L p .707 .577 .707 r
F P
0 g
s
.50098 .57662 m .48972 .52353 L .48218 .53569 L p .707 .577 .707 r
F P
0 g
s
.31532 .62652 m .30406 .57343 L .29228 .56537 L p .707 .577 .707 r
F P
0 g
s
.44572 .70341 m .44296 .72203 L .46623 .72087 L p .707 .577 .707 r
F P
0 g
s
.46623 .72087 m .46899 .70225 L .44572 .70341 L p .707 .577 .707 r
F P
0 g
s
.66321 .68311 m .66161 .64526 L .68568 .64063 L p .707 .577 .707 r
F P
0 g
s
.32419 .70415 m .32696 .68552 L .30552 .67763 L p .707 .577 .707 r
F P
0 g
s
.47456 .62974 m .4783 .66617 L .49468 .6562 L p .707 .577 .707 r
F P
0 g
s
.49468 .6562 m .49094 .61978 L .47456 .62974 L p .707 .577 .707 r
F P
0 g
s
.30552 .67763 m .30276 .69625 L .32419 .70415 L p .707 .577 .707 r
F P
0 g
s
.31042 .64144 m .31416 .67786 L .33503 .68336 L p .707 .577 .707 r
F P
0 g
s
.68568 .64063 m .68728 .67848 L .66321 .68311 L p .707 .577 .707 r
F P
0 g
s
.68871 .62873 m .68386 .57139 L .7133 .56803 L p .707 .577 .707 r
F P
0 g
s
.7133 .56803 m .71815 .62537 L .68871 .62873 L p .707 .577 .707 r
F P
0 g
s
.80541 .63712 m .80701 .67498 L .77961 .67326 L p .707 .577 .707 r
F P
0 g
s
.77961 .67326 m .778 .63541 L .80541 .63712 L p .707 .577 .707 r
F P
0 g
s
.82166 .69398 m .82046 .71157 L .79877 .70094 L p .707 .577 .707 r
F P
0 g
s
.79877 .70094 m .79997 .68335 L .82166 .69398 L p .707 .577 .707 r
F P
0 g
s
.77602 .56311 m .78087 .62046 L .7499 .62252 L p .707 .577 .707 r
F P
0 g
s
.7499 .62252 m .74506 .56518 L .77602 .56311 L p .707 .577 .707 r
F P
0 g
s
.65558 .69959 m .65678 .682 L .68018 .67465 L p .707 .577 .707 r
F P
0 g
s
.31416 .67786 m .31042 .64144 L .29799 .63353 L p .707 .577 .707 r
F P
0 g
s
.29228 .56537 m .30354 .61845 L .31532 .62652 L p .707 .577 .707 r
F P
0 g
s
.71815 .62537 m .7133 .56803 L .74506 .56518 L p .707 .577 .707 r
F P
0 g
s
.68728 .67848 m .68568 .64063 L .71506 .63725 L p .707 .577 .707 r
F P
0 g
s
.46899 .70225 m .46623 .72087 L .48174 .71733 L p .707 .577 .707 r
F P
0 g
s
.48174 .71733 m .4845 .69871 L .46899 .70225 L p .707 .577 .707 r
F P
0 g
s
.74506 .56518 m .7499 .62252 L .71815 .62537 L p .707 .577 .707 r
F P
0 g
s
.68018 .67465 m .67898 .69224 L .65558 .69959 L p .707 .577 .707 r
F P
0 g
s
.30276 .69625 m .30552 .67763 L .29233 .66977 L p .707 .577 .707 r
F P
0 g
s
.29233 .66977 m .28957 .68839 L .30276 .69625 L p .707 .577 .707 r
F P
0 g
s
.48972 .52353 m .50098 .57662 L .49875 .56599 L p .698 .571 .709 r
F P
0 g
s
.49875 .56599 m .48749 .5129 L .48972 .52353 L p .698 .571 .709 r
F P
0 g
s
.30354 .61845 m .29228 .56537 L .29004 .55474 L p .698 .571 .709 r
F P
0 g
s
.71506 .63725 m .71666 .6751 L .68728 .67848 L p .707 .577 .707 r
F P
0 g
s
.49094 .61978 m .49468 .6562 L .50184 .64594 L p .707 .577 .707 r
F P
0 g
s
.50184 .64594 m .4981 .60952 L .49094 .61978 L p .707 .577 .707 r
F P
0 g
s
.778 .63541 m .77961 .67326 L .74848 .6733 L p .707 .577 .707 r
F P
0 g
s
.74848 .6733 m .74687 .63545 L .778 .63541 L p .707 .577 .707 r
F P
0 g
s
.29799 .63353 m .30172 .66995 L .31416 .67786 L p .707 .577 .707 r
F P
0 g
s
.71666 .6751 m .71506 .63725 L .74687 .63545 L p .707 .577 .707 r
F P
0 g
s
.79997 .68335 m .79877 .70094 L .77092 .6931 L p .707 .577 .707 r
F P
0 g
s
.77092 .6931 m .77212 .67551 L .79997 .68335 L p .707 .577 .707 r
F P
0 g
s
.67898 .69224 m .68018 .67465 L .70914 .67094 L p .707 .577 .707 r
F P
0 g
s
.74687 .63545 m .74848 .6733 L .71666 .6751 L p .707 .577 .707 r
F P
0 g
s
.70914 .67094 m .70794 .68852 L .67898 .69224 L p .707 .577 .707 r
F P
0 g
s
.30172 .66995 m .29799 .63353 L .29521 .62398 L p .707 .577 .707 r
F P
0 g
s
.29004 .55474 m .3013 .60782 L .30354 .61845 L p .698 .571 .709 r
F P
0 g
s
.77212 .67551 m .77092 .6931 L .73962 .68882 L p .707 .577 .707 r
F P
0 g
s
.73962 .68882 m .74082 .67123 L .77212 .67551 L p .707 .577 .707 r
F P
0 g
s
.70794 .68852 m .70914 .67094 L .74082 .67123 L p .707 .577 .707 r
F P
0 g
s
.4845 .69871 m .48174 .71733 L .48797 .71176 L p .707 .577 .707 r
F P
0 g
s
.48797 .71176 m .49073 .69313 L .4845 .69871 L p .707 .577 .707 r
F P
0 g
s
.28957 .68839 m .29233 .66977 L .28867 .6627 L p .707 .577 .707 r
F P
0 g
s
.74082 .67123 m .73962 .68882 L .70794 .68852 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28867 .6627 m .28591 .68133 L .28957 .68839 L p .707 .577 .707 r
F P
0 g
s
.4981 .60952 m .50184 .64594 L .49906 .63639 L p .707 .577 .707 r
F P
0 g
s
.49906 .63639 m .49532 .59996 L .4981 .60952 L p .707 .577 .707 r
F P
0 g
s
.48749 .5129 m .49875 .56599 L .48697 .55792 L p .707 .577 .707 r
F P
0 g
s
.48697 .55792 m .4757 .50484 L .48749 .5129 L p .707 .577 .707 r
F P
0 g
s
.3013 .60782 m .29004 .55474 L .29758 .54258 L p .707 .577 .707 r
F P
0 g
s
.29521 .62398 m .29895 .6604 L .30172 .66995 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29895 .6604 m .29521 .62398 L .30237 .61371 L p .707 .577 .707 r
F P
0 g
s
.29758 .54258 m .30884 .59566 L .3013 .60782 L p .707 .577 .707 r
F P
0 g
s
.49073 .69313 m .48797 .71176 L .48431 .70469 L p .707 .577 .707 r
F P
0 g
s
.48431 .70469 m .48707 .68607 L .49073 .69313 L p .707 .577 .707 r
F P
0 g
s
.28591 .68133 m .28867 .6627 L .2949 .65713 L p .707 .577 .707 r
F P
0 g
s
.2949 .65713 m .29214 .67575 L .28591 .68133 L p .707 .577 .707 r
F P
0 g
s
.4757 .50484 m .48697 .55792 L .46678 .55322 L p .707 .577 .707 r
F P
0 g
s
.46678 .55322 m .45552 .50013 L .4757 .50484 L p .707 .577 .707 r
F P
0 g
s
.30884 .59566 m .29758 .54258 L .31416 .53008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49532 .59996 m .49906 .63639 L .48663 .62847 L p .707 .577 .707 r
F P
0 g
s
.48663 .62847 m .48289 .59205 L .49532 .59996 L p .707 .577 .707 r
F P
0 g
s
.30237 .61371 m .3061 .65013 L .29895 .6604 L p .707 .577 .707 r
F P
0 g
s
.31416 .53008 m .32542 .58317 L .30884 .59566 L p .707 .577 .707 r
F P
0 g
s
.3061 .65013 m .30237 .61371 L .31875 .60375 L p .707 .577 .707 r
F P
0 g
s
.45552 .50013 m .46678 .55322 L .44016 .55233 L p .707 .577 .707 r
F P
0 g
s
.44016 .55233 m .4289 .49925 L .45552 .50013 L p .707 .577 .707 r
F P
0 g
s
.32542 .58317 m .31416 .53008 L .33815 .51848 L p .707 .577 .707 r
F P
0 g
s
.48707 .68607 m .48431 .70469 L .47112 .69683 L p .707 .577 .707 r
F P
0 g
s
.47112 .69683 m .47388 .6782 L .48707 .68607 L p .707 .577 .707 r
F P
0 g
s
.29214 .67575 m .2949 .65713 L .31041 .65359 L p .707 .577 .707 r
F P
0 g
s
.48289 .59205 m .48663 .62847 L .46575 .62298 L p .707 .577 .707 r
F P
0 g
s
.46575 .62298 m .46202 .58656 L .48289 .59205 L p .707 .577 .707 r
F P
0 g
s
.31041 .65359 m .30765 .67221 L .29214 .67575 L p .707 .577 .707 r
F P
0 g
s
.31875 .60375 m .32249 .64017 L .3061 .65013 L p .707 .577 .707 r
F P
0 g
s
.4289 .49925 m .44016 .55233 L .40973 .55535 L p .707 .577 .707 r
F P
0 g
s
.40973 .55535 m .39847 .50226 L .4289 .49925 L p .707 .577 .707 r
F P
0 g
s
.34941 .57156 m .33815 .51848 L .3672 .50889 L p .707 .577 .707 r
F P
0 g
s
.33815 .51848 m .34941 .57156 L .32542 .58317 L p .707 .577 .707 r
F P
0 g
s
.32249 .64017 m .31875 .60375 L .34276 .59506 L p .707 .577 .707 r
F P
0 g
s
.39847 .50226 m .40973 .55535 L .37846 .56197 L p .707 .577 .707 r
F P
0 g
s
.37846 .56197 m .3672 .50889 L .39847 .50226 L p .707 .577 .707 r
F P
0 g
s
.3672 .50889 m .37846 .56197 L .34941 .57156 L p .707 .577 .707 r
F P
0 g
s
.47388 .6782 m .47112 .69683 L .44968 .68894 L p .707 .577 .707 r
F P
0 g
s
.44968 .68894 m .45245 .67031 L .47388 .6782 L p .707 .577 .707 r
F P
0 g
s
.46202 .58656 m .46575 .62298 L .43848 .62044 L p .707 .577 .707 r
F P
0 g
s
.43848 .62044 m .43474 .58402 L .46202 .58656 L p .707 .577 .707 r
F P
0 g
s
.30765 .67221 m .31041 .65359 L .33368 .65243 L p .707 .577 .707 r
F P
0 g
s
.34276 .59506 m .3465 .63148 L .32249 .64017 L p .707 .577 .707 r
F P
0 g
s
.33368 .65243 m .33092 .67105 L .30765 .67221 L p .707 .577 .707 r
F P
0 g
s
.3465 .63148 m .34276 .59506 L .37205 .58849 L p .707 .577 .707 r
F P
0 g
s
.43474 .58402 m .43848 .62044 L .40748 .62111 L p .707 .577 .707 r
F P
0 g
s
.40748 .62111 m .40374 .58468 L .43474 .58402 L p .707 .577 .707 r
F P
0 g
s
.45245 .67031 m .44968 .68894 L .42211 .68179 L p .707 .577 .707 r
F P
0 g
s
.42211 .68179 m .42487 .66317 L .45245 .67031 L p .707 .577 .707 r
F P
0 g
s
.37579 .62491 m .37205 .58849 L .40374 .58468 L p .707 .577 .707 r
F P
0 g
s
.37205 .58849 m .37579 .62491 L .3465 .63148 L p .707 .577 .707 r
F P
0 g
s
.33092 .67105 m .33368 .65243 L .36243 .65376 L p .707 .577 .707 r
F P
0 g
s
.40374 .58468 m .40748 .62111 L .37579 .62491 L p .707 .577 .707 r
F P
0 g
s
.36243 .65376 m .35967 .67239 L .33092 .67105 L p .707 .577 .707 r
F P
0 g
s
.42487 .66317 m .42211 .68179 L .39109 .67609 L p .707 .577 .707 r
F P
0 g
s
.39109 .67609 m .39386 .65746 L .42487 .66317 L p .707 .577 .707 r
F P
0 g
s
.35967 .67239 m .36243 .65376 L .39386 .65746 L p .707 .577 .707 r
F P
0 g
s
.39386 .65746 m .39109 .67609 L .35967 .67239 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001kOol007=oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00Kgoo1000
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001EYF5@000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00H005YFFUIJEP00FUH40002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP04000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00HWoo0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00Ggoo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001KOol20003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00FGoo0P00
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol005Qoo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001FOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00EGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol005Aoo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001C
Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0059oo`04
001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE0003FUH01000FUH0
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
DWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP04001J
EUYFFUH20005FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001BOol01000FUIJEP001EYF00<005YFFUH015YF
00<005YFFUH01EYF100000AJEP00000000QJEP04001JEP000007FUH00`00FUIJEP02FUH40005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF0000:Woo2`00<Goo001C
Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH50005FUH400000eYF001J
EP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEUYF000067oo4P000eYF00<005YFFUH00eYF00<005YF00000P00;Woo001COol0
0`00FUH00005FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH:0005FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00D005YFFUIJEP00011oo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0^Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH40003FUH00`00
FUIJEP02FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000Qoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001J
EP0^Ool005=oo`04001JEUYF0005FUH01000FUIJEUYF0P000goo00<005YFFUH02P000eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002Ool60003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001C
Ool01000FUIJEP001EYF00<005YF00002@0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF001JEP0^Ool005Aoo`03001J
EP0000EJEP8000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0041oo`l000Eoo`03001JEP0000AJ
EP8000IJEP03001JEUYF00MJEQP00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo000jOol60004FUH00`00FUIJEP06FUH00`00FUH0000300001Woo001JEUYF001JEP80009J
EP03001JEUYF00AJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
00020004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Woo100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH015YF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF000^Ool003Aoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYF0005FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH00002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000cOol20006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0031oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH0
05YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUH000001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF000]Ool002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH70004FUH70005FUH70003FUH01000FUIJEP001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00006FUH00`00
FUIJEP02FUHB0007FUH00`00FUIJEP04FUH00`00FUIJEP05000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP040002FUH90006FUH00`00FUIJEP09FUH50002FUH00`00FUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000eYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPH0039oo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00=JEPX000=JEPD000MJEP03001JEUYF00QJEP8000AJEP@000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00H000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJ
EP04001JEUYFFUH20002FUH00`00FUH00003FUH00`00FUIJEP02FUH50007FUH00`00FUIJEP05FUH3
00000eYF001JEP03FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF4@00?7oo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0005FUH01000FUIJEP0015YF00@005YF0000
00AJEP03001JEP0000=JEP03001JEUYF009JEPD000MJEP04001JEUYFFUH40004FUH00`00FUIJEP02
FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00AJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH6
000fOol002eoo`03001JEP0000=JEP03001JEUYF00=JEPH000moo`@00003FUH005YF009JEP04001J
EUYFFUH20005FUH01000FUIJEP000eYF00<005YFFUH00eYF0`0025YF10000UYF00<005YFFUH00eYF
00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEQ4000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00D0035oo`00;Goo00<005YF00000eYF00<005YF00000`006Goo0`000UYF00<005YF00002@000UYF
00D005YFFUIJEP0000IJEP03001JEUYF00L000IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001J
EP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00004Ool5
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH00002000^Ool002aoo`03001JEP0000AJEP8001moo`03001JEUYF008000EJEP04
001JEUYFFUHA0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000Woo0P0000=JEP00FUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000UYF0`0057oo0`002Goo00<005YF00005000
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool002aoo`03001JEP0000800003FUH005YF0080015oo`D000Moo`<0009J
EP03001JEUYF00=JEP03001JEUYF00IJEP04001JEUYFFUH70005FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH0
0003FUH01@00FUIJEUYF000047oo1@001Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH0100000=JEP00FUH025YF00<005YFFUH00eYF00<005YFFUH00P001eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH2000>Ool50006Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH00`00
FUIJEP03FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0P000eYF00<005YFFUH00eYF00@0
05YF000000eoo`<000Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH01000FUIJEUYF0`0057oo00=JEP00FUH00UYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00003FUH000000080
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<0
05YFFUH015YF00<005YFFUH03`0025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUHB000017oo001JEP000UYF1@0015YF
00<005YFFUH02@0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH0
2eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH01000
FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH04`000eYF00<005YFFUH00P00;Goo000/Ool2
0003FUH00`00FUIJEP03FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF00000006
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00AJEP@0009J
EP8002eoo`00;7oo0P000eYF00<005YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YF00001@0000=JEP00FUH01EYF00<005YFFUH01UYF0`0000=JEP00
000010001UYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00H005YFFUH005YF0002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000040006FUH01000FUIJEUYF1000;Goo000]Ool01000FUIJEUYF0`001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF20000eYF00<005YF
FUH00UYF2@001EYF10000UYF00<005YFFUH015YF00@005YF000000UJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001EYF00@005YFFUIJEP<002eoo`00;Goo00<0
05YFFUH00P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00D0
05YFFUIJEP0000EJEP03001JEP0000<00003FUH0000000H000=JEPD000MJEP03001JEUYF00<000EJ
EP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYF001JEP0200000eYF001JEP04FUH00`00FUIJEP02FUH@0006FUH00`00FUIJEP05FUH3
0003FUH01`00FUIJEUYF001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00<005YFFUH00eYF1@000UYF00<0
05YFFUH00UYF1@001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF00<005YFFUH00P00
00=JEP00FUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH30008FUH00`00
FUIJEP05FUH200000eYF001JEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH40006FUH00`00FUIJEP02FUH20002FUH2000_Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF
00EJEP03001JEUYF00AJEPL000QJEP03001JEUYF00MJEP8000=JEP03001JEP0000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH3000aOol0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000MJ
EPH00004FUH005YF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0
00000UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00@005YF0000031oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPP000=JEP03001JEUYF00<000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000<00003FUH00000008000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP05001JEUYFFUH0000_Ool002eoo`8000AJ
EP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000QJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000IJER4000Qoo`80
0003FUH005YF009JEP03001oogoo02eoo`00;Goo0P0015YF00<005YFFUH00eYF1P0025YF00<005YF
FUH01UYF1P001UYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUH000020006FUH00`00FUIJEP03FUH01000FUIJEUYF0P007goo0P000eYF00<007ooOol0
;Goo000]Ool20004FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH40002FUH00`00FUIJEP03FUH01000FUIJEP000UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00001P0000=JEP00FUH01EYF00<005YFFUH00P002Goo0`005Woo00<005YFFUH00P00;Woo000/
Ool00`00FUH00003FUH30005Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH01000FUIJEP000eYF00<005YFFUH015YF2@0015YF00@005YFFUIJEPH000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP<000IJEP03
001JEUYF008000Qoo`D001Ioo`@002ioo`00;7oo00@005YF001JEP8000]oo`@000IJEP@000EJEP03
001JEUYF00EJEP03001JEP0000@000=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUH000020003FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0027oo1@0067oo0P00;Woo000/Ool0
1@00FUH00000FUH00P003Woo10000UYF1@0015YF00<005YFFUH00UYF1@001Goo0P0000EJEP00FUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00001JEP0200000eYF001JEP03FUH2
00000eYF001JEP02FUH20008Ool5000HOol2000^Ool002aoo`8000=JEP03001JEP00008000mooa00
00aoo`80009JEP05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF0`0015YF0`00
0UYF00<005YF00002Goo0`0067oo0`00;Woo000/Ool20003FUH00`00FUIJEP02FUH3000>Ool5000E
Ool300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF20000UYF
0`0000=JEP00Ool08goo00<005YF0000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003
000;Ool3000DOol20003FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000eYF
00<005YFFUH00`0000AJEP000000009JEP8002=oo`<00003FUH007oo02eoo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH00eYF1P0067oo100000=JEP00FUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF009JEP<0009JEP@0021oo`<0009JEP80
02moo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEPT000Yoo`D000EJ
EP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10001EYF00<005YF00001@007Woo0P0000=J
EP00FUH00UYF0P00;goo000]Ool01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF2P000eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF00MJEP04001JEUYFFUH60004FUH00`00FUIJEP0:FUH01000FUIJEUYF2@0025YF00<005YFFUH0
1EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEPL001Moo`8000=JEP05001J
EUYFFUH0000`Ool002eoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF1P002UYF00<005YFFUH02UYF00<005YFFUH02EYF1`000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000Uoo`D000AJEP04001J
EUYFFUH2000`Ool002ioo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03
001JEUYF00D000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@000IJEP05001JEUYFFUH00005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90003FUH00`00FUIJEP03FUH01000FUH00000<Woo000_Ool20005FUH00`00FUIJEP06FUH00`00
FUIJEP05FUHO0003FUH00`00FUIJEP03FUH40009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH30004FUH01@00FUIJEUYF00001UYF10001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00=7oo000`Ool00`00FUIJEP03FUH0
0`00FUIJEP05FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00000eYF00<005YF00000`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00`0000=JEP00FUH00UYF00<005YFFUH015YF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH2
000fOol0035oo`8000=JEP03001JEP0000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH00000>7oo000bOol60002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH02`000UYF00H005YFFUH005YF0003Ool90004FUH00`00FUIJEP02FUH5000jOol002mo
o`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH5
0007FUH00`00FUH000020002FUH00`00FUH0000<Ool9000oOol002eoo`<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF009JEQP000=JEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP020007FUH00`00FUIJEP02FUH4001EOol002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF009JEPd000AJEP03001JEUYF009JEPT0009JEPH000AJEP03001JEUYF
00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP06001JEUYF001JEP001UYF00<005YFFUH00eYF0`00EGoo000]Ool00`00
FUH00004FUH01000FUIJEUYF1`0017oo50000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP001eYF00<005YFFUH00UYF00<005YFFUH0
0P00Dgoo000]Ool00`00FUH00003FUHK0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF000015YF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01P0015YF00<005YFFUH00eYF
00@005YFFUH005=oo`00;Woo0P0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF00L000=JEP03001JEUYF0080059oo`00;Woo
0`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEPD0009oo`80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00@0009JEP80059oo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Goo0`001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1P00DWoo000_Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000BOol20005FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP030003Ool2001BOol0035ooah001eoo`80
00=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000MJEP04001JEUYFFUH60005Ool3001BOol006ioo`800003FUH005YF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00
00l000Yoo`800003FUH007oo055oo`00L7oo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF100067oo0P0000AJEP00FUH0059oo`00M7oo1P000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02P005Goo0P0015YF0P00DWoo001j
Ool80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH80005Ool5000COol200000eYF001JEP03FUH0
0`00Oomoo`1AOol0089ooaX000eoo`D0015oo`8000=JEP03001JEUYF009JEP03001oogoo055oo`00
T7oo00@005YFFUH001Ioo`<000moo`<000EJEP03001JEUYF008005Aoo`00TGoo0P009goo0P0000=J
EP00FUH01EYF0`00EWoo002AOol3000SOol30003FUH00`00FUIJEP04FUH00`00Oomoo`1FOol0095o
o`03001JEUYF00@001Uoo`H000MJEP04001JEUYFFUH2001IOol0095oo`80009JEP03001JEUYF00L0
00Uoo`T000AJEP03001JEUYF00IJEP04001JEP00001KOol0099oo`04001JEUYF0005FUH01000FUIJ
EUYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF0`00GGoo002BOol01@00FUIJEUYF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00H7oo002COol2
00000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002
001ROol009Eoo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH006Eoo`00
VGoo1`0015YF00<005YFFUH00UYF2@00Jgoo002POol9001dOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60166 .75781 m .5903 .70484 L .55965 .70826 L p .707 .577 .707 r
F P
0 g
s
.5903 .70484 m .60166 .75781 L .63283 .75078 L p .707 .577 .707 r
F P
0 g
s
.63283 .75078 m .62147 .69781 L .5903 .70484 L p .707 .577 .707 r
F P
0 g
s
.62147 .69781 m .63283 .75078 L .66148 .74084 L p .707 .577 .707 r
F P
0 g
s
.66148 .74084 m .65011 .68787 L .62147 .69781 L p .707 .577 .707 r
F P
0 g
s
.57101 .76123 m .55965 .70826 L .53252 .70775 L p .707 .577 .707 r
F P
0 g
s
.55965 .70826 m .57101 .76123 L .60166 .75781 L p .707 .577 .707 r
F P
0 g
s
.65011 .68787 m .66148 .74084 L .68479 .72897 L p .707 .577 .707 r
F P
0 g
s
.68479 .72897 m .67343 .67599 L .65011 .68787 L p .707 .577 .707 r
F P
0 g
s
.59965 .81408 m .5959 .77766 L .56487 .77838 L p .707 .577 .707 r
F P
0 g
s
.5959 .77766 m .59965 .81408 L .63133 .81022 L p .707 .577 .707 r
F P
0 g
s
.63133 .81022 m .62758 .7738 L .5959 .77766 L p .707 .577 .707 r
F P
0 g
s
.62758 .7738 m .63133 .81022 L .66055 .8036 L p .707 .577 .707 r
F P
0 g
s
.66055 .8036 m .6568 .76719 L .62758 .7738 L p .707 .577 .707 r
F P
0 g
s
.54389 .76072 m .53252 .70775 L .51157 .70335 L p .707 .577 .707 r
F P
0 g
s
.53252 .70775 m .54389 .76072 L .57101 .76123 L p .707 .577 .707 r
F P
0 g
s
.67343 .67599 m .68479 .72897 L .70049 .71631 L p .707 .577 .707 r
F P
0 g
s
.70049 .71631 m .68912 .66333 L .67343 .67599 L p .707 .577 .707 r
F P
0 g
s
.56861 .8148 m .56487 .77838 L .53751 .77589 L p .707 .577 .707 r
F P
0 g
s
.56487 .77838 m .56861 .8148 L .59965 .81408 L p .707 .577 .707 r
F P
0 g
s
.58318 .84556 m .5859 .82695 L .55525 .82099 L p .707 .577 .707 r
F P
0 g
s
.5859 .82695 m .58318 .84556 L .61476 .84955 L p .707 .577 .707 r
F P
0 g
s
.61476 .84955 m .61748 .83094 L .5859 .82695 L p .707 .577 .707 r
F P
0 g
s
.6568 .76719 m .66055 .8036 L .68445 .79487 L p .707 .577 .707 r
F P
0 g
s
.68445 .79487 m .6807 .75845 L .6568 .76719 L p .707 .577 .707 r
F P
0 g
s
.61748 .83094 m .61476 .84955 L .64419 .85118 L p .707 .577 .707 r
F P
0 g
s
.64419 .85118 m .64691 .83257 L .61748 .83094 L p .707 .577 .707 r
F P
0 g
s
.55525 .82099 m .55253 .83959 L .58318 .84556 L p .707 .577 .707 r
F P
0 g
s
.55253 .83959 m .55525 .82099 L .52854 .81363 L p .707 .577 .707 r
F P
0 g
s
.53751 .77589 m .54125 .81231 L .56861 .8148 L p .707 .577 .707 r
F P
0 g
s
.52854 .81363 m .52582 .83224 L .55253 .83959 L p .707 .577 .707 r
F P
0 g
s
.51157 .70335 m .52294 .75632 L .54389 .76072 L p .707 .577 .707 r
F P
0 g
s
.54125 .81231 m .53751 .77589 L .51651 .77044 L p .707 .577 .707 r
F P
0 g
s
.52294 .75632 m .51157 .70335 L .49885 .69549 L p .707 .577 .707 r
F P
0 g
s
.64691 .83257 m .64419 .85118 L .66859 .85028 L p .707 .577 .707 r
F P
0 g
s
.66859 .85028 m .67131 .83167 L .64691 .83257 L p .707 .577 .707 r
F P
0 g
s
.68912 .66333 m .70049 .71631 L .70703 .70411 L p .707 .577 .707 r
F P
0 g
s
.70703 .70411 m .69567 .65114 L .68912 .66333 L p .707 .577 .707 r
F P
0 g
s
.6807 .75845 m .68445 .79487 L .70069 .78488 L p .707 .577 .707 r
F P
0 g
s
.70069 .78488 m .69694 .74846 L .6807 .75845 L p .707 .577 .707 r
F P
0 g
s
.52582 .83224 m .52854 .81363 L .50839 .8056 L p .707 .577 .707 r
F P
0 g
s
.51651 .77044 m .52025 .80686 L .54125 .81231 L p .707 .577 .707 r
F P
0 g
s
.50839 .8056 m .50567 .82421 L .52582 .83224 L p .707 .577 .707 r
F P
0 g
s
.49885 .69549 m .51022 .74847 L .52294 .75632 L p .707 .577 .707 r
F P
0 g
s
.67131 .83167 m .66859 .85028 L .68556 .84695 L p .707 .577 .707 r
F P
0 g
s
.68556 .84695 m .68829 .82834 L .67131 .83167 L p .707 .577 .707 r
F P
0 g
s
.52025 .80686 m .51651 .77044 L .50392 .76256 L p .707 .577 .707 r
F P
0 g
s
.51022 .74847 m .49885 .69549 L .49561 .68495 L p .707 .577 .707 r
F P
0 g
s
.50567 .82421 m .50839 .8056 L .49676 .79769 L p .707 .577 .707 r
F P
0 g
s
.69694 .74846 m .70069 .78488 L .70768 .77461 L p .707 .577 .707 r
F P
0 g
s
.70768 .77461 m .70393 .73819 L .69694 .74846 L p .707 .577 .707 r
F P
0 g
s
.50392 .76256 m .50767 .79897 L .52025 .80686 L p .707 .577 .707 r
F P
0 g
s
.69567 .65114 m .70703 .70411 L .70379 .69357 L p .707 .577 .707 r
F P
0 g
s
.70379 .69357 m .69242 .6406 L .69567 .65114 L p .707 .577 .707 r
F P
0 g
s
.49676 .79769 m .49404 .8163 L .50567 .82421 L p .707 .577 .707 r
F P
0 g
s
.68829 .82834 m .68556 .84695 L .69346 .8415 L p .707 .577 .707 r
F P
0 g
s
.69346 .8415 m .69618 .82289 L .68829 .82834 L p .707 .577 .707 r
F P
0 g
s
.49561 .68495 m .50697 .73793 L .51022 .74847 L p .707 .577 .707 r
F P
0 g
s
.50767 .79897 m .50392 .76256 L .50098 .75301 L p .707 .577 .707 r
F P
0 g
s
.50697 .73793 m .49561 .68495 L .50215 .67275 L p .707 .577 .707 r
F P
0 g
s
.49404 .8163 m .49676 .79769 L .4948 .79067 L p .707 .577 .707 r
F P
0 g
s
.4948 .79067 m .49208 .80927 L .49404 .8163 L p .707 .577 .707 r
F P
0 g
s
.49208 .80927 m .4948 .79067 L .50269 .78522 L p .707 .577 .707 r
F P
0 g
s
.50269 .78522 m .49997 .80383 L .49208 .80927 L p .707 .577 .707 r
F P
0 g
s
.50098 .75301 m .50472 .78943 L .50767 .79897 L p .707 .577 .707 r
F P
0 g
s
.50472 .78943 m .50098 .75301 L .50797 .74274 L p .707 .577 .707 r
F P
0 g
s
.50797 .74274 m .51172 .77916 L .50472 .78943 L p .707 .577 .707 r
F P
0 g
s
.49997 .80383 m .50269 .78522 L .51966 .78188 L p .707 .577 .707 r
F P
0 g
s
.51966 .78188 m .51694 .80049 L .49997 .80383 L p .707 .577 .707 r
F P
0 g
s
.50018 .82192 m .50018 .32003 L .4556 .31816 L p .707 .577 .707 r
F P
0 g
s
.50215 .67275 m .51352 .72573 L .50697 .73793 L p .707 .577 .707 r
F P
0 g
s
.51352 .72573 m .50215 .67275 L .51785 .6601 L p .707 .577 .707 r
F P
0 g
s
.51785 .6601 m .52921 .71307 L .51352 .72573 L p .707 .577 .707 r
F P
0 g
s
.51172 .77916 m .50797 .74274 L .52421 .73275 L p .707 .577 .707 r
F P
0 g
s
.52921 .71307 m .51785 .6601 L .54116 .64822 L p .707 .577 .707 r
F P
0 g
s
.52421 .73275 m .52796 .76917 L .51172 .77916 L p .707 .577 .707 r
F P
0 g
s
.54116 .64822 m .55252 .70119 L .52921 .71307 L p .707 .577 .707 r
F P
0 g
s
.52796 .76917 m .52421 .73275 L .54811 .72402 L p .707 .577 .707 r
F P
0 g
s
.54811 .72402 m .55186 .76044 L .52796 .76917 L p .707 .577 .707 r
F P
0 g
s
.51694 .80049 m .51966 .78188 L .54406 .78099 L p .707 .577 .707 r
F P
0 g
s
.54406 .78099 m .54134 .79959 L .51694 .80049 L p .707 .577 .707 r
F P
0 g
s
.54134 .79959 m .54406 .78099 L .57349 .78261 L p .707 .577 .707 r
F P
0 g
s
.57349 .78261 m .57077 .80122 L .54134 .79959 L p .707 .577 .707 r
F P
0 g
s
.50018 .32003 m .50018 .82192 L .54475 .82001 L p .707 .577 .707 r
F P
0 g
s
.55252 .70119 m .54116 .64822 L .5698 .63828 L p .707 .577 .707 r
F P
0 g
s
.54475 .82001 m .54475 .31813 L .50018 .32003 L p .707 .577 .707 r
F P
0 g
s
.4556 .82004 m .4556 .31816 L .41536 .31267 L p .707 .577 .707 r
F P
0 g
s
.4556 .31816 m .4556 .82004 L .50018 .82192 L p .707 .577 .707 r
F P
0 g
s
.58117 .69125 m .5698 .63828 L .60098 .63125 L p .707 .577 .707 r
F P
0 g
s
.5698 .63828 m .58117 .69125 L .55252 .70119 L p .707 .577 .707 r
F P
0 g
s
.55186 .76044 m .54811 .72402 L .57733 .7174 L p .707 .577 .707 r
F P
0 g
s
.57733 .7174 m .58108 .75382 L .55186 .76044 L p .707 .577 .707 r
F P
0 g
s
.57077 .80122 m .57349 .78261 L .60508 .7866 L p .707 .577 .707 r
F P
0 g
s
.60508 .7866 m .60235 .80521 L .57077 .80122 L p .707 .577 .707 r
F P
0 g
s
.54475 .31813 m .54475 .82001 L .58493 .8145 L p .707 .577 .707 r
F P
0 g
s
.60098 .63125 m .61234 .68423 L .58117 .69125 L p .707 .577 .707 r
F P
0 g
s
.58108 .75382 m .57733 .7174 L .60901 .71354 L p .707 .577 .707 r
F P
0 g
s
.60901 .71354 m .61275 .74996 L .58108 .75382 L p .707 .577 .707 r
F P
0 g
s
.58493 .8145 m .58493 .31261 L .54475 .31813 L p .707 .577 .707 r
F P
0 g
s
.70393 .73819 m .70768 .77461 L .70474 .76507 L p .707 .577 .707 r
F P
0 g
s
.70474 .76507 m .70099 .72865 L .70393 .73819 L p .707 .577 .707 r
F P
0 g
s
.69242 .6406 m .70379 .69357 L .69107 .68571 L p .707 .577 .707 r
F P
0 g
s
.69107 .68571 m .6797 .63274 L .69242 .6406 L p .707 .577 .707 r
F P
0 g
s
.69618 .82289 m .69346 .8415 L .69149 .83448 L p .707 .577 .707 r
F P
0 g
s
.69149 .83448 m .69421 .81587 L .69618 .82289 L p .707 .577 .707 r
F P
0 g
s
.41536 .81456 m .41536 .31267 L .38341 .30412 L p .707 .577 .707 r
F P
0 g
s
.41536 .31267 m .41536 .81456 L .4556 .82004 L p .707 .577 .707 r
F P
0 g
s
.61234 .68423 m .60098 .63125 L .63163 .62783 L p .707 .577 .707 r
F P
0 g
s
.64005 .71282 m .64379 .74924 L .61275 .74996 L p .707 .577 .707 r
F P
0 g
s
.61275 .74996 m .60901 .71354 L .64005 .71282 L p .707 .577 .707 r
F P
0 g
s
.63572 .79257 m .633 .81118 L .60235 .80521 L p .707 .577 .707 r
F P
0 g
s
.60235 .80521 m .60508 .7866 L .63572 .79257 L p .707 .577 .707 r
F P
0 g
s
.58493 .31261 m .58493 .8145 L .6168 .80593 L p .707 .577 .707 r
F P
0 g
s
.63163 .62783 m .64299 .6808 L .61234 .68423 L p .707 .577 .707 r
F P
0 g
s
.6168 .80593 m .6168 .30404 L .58493 .31261 L p .707 .577 .707 r
F P
0 g
s
.25689 .69401 m .25194 .6367 L .22075 .63888 L p .707 .577 .707 r
F P
0 g
s
.25194 .6367 m .25689 .69401 L .28855 .69103 L p .707 .577 .707 r
F P
0 g
s
.28855 .69103 m .28359 .63371 L .25194 .6367 L p .707 .577 .707 r
F P
0 g
s
.28359 .63371 m .28855 .69103 L .31757 .68752 L p .707 .577 .707 r
F P
0 g
s
.31757 .68752 m .31262 .63021 L .28359 .63371 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22075 .63888 m .2257 .69619 L .25689 .69401 L p .707 .577 .707 r
F P
0 g
s
.70099 .72865 m .70474 .76507 L .69215 .75718 L p .707 .577 .707 r
F P
0 g
s
.69215 .75718 m .68841 .72077 L .70099 .72865 L p .707 .577 .707 r
F P
0 g
s
.6797 .63274 m .69107 .68571 L .67012 .68132 L p .707 .577 .707 r
F P
0 g
s
.67012 .68132 m .65875 .62834 L .6797 .63274 L p .707 .577 .707 r
F P
0 g
s
.2257 .69619 m .22075 .63888 L .19309 .64004 L p .707 .577 .707 r
F P
0 g
s
.19309 .64004 m .19804 .69735 L .2257 .69619 L p .707 .577 .707 r
F P
0 g
s
.31262 .63021 m .31757 .68752 L .34113 .68385 L p .707 .577 .707 r
F P
0 g
s
.34113 .68385 m .33618 .62653 L .31262 .63021 L p .707 .577 .707 r
F P
0 g
s
.25489 .76443 m .25328 .72658 L .22211 .72666 L p .707 .577 .707 r
F P
0 g
s
.25328 .72658 m .25489 .76443 L .28668 .7626 L p .707 .577 .707 r
F P
0 g
s
.28668 .7626 m .28507 .72475 L .25328 .72658 L p .707 .577 .707 r
F P
0 g
s
.28507 .72475 m .28668 .7626 L .316 .75919 L p .707 .577 .707 r
F P
0 g
s
.316 .75919 m .31439 .72134 L .28507 .72475 L p .707 .577 .707 r
F P
0 g
s
.38341 .80601 m .38341 .30412 L .36287 .29334 L p .707 .577 .707 r
F P
0 g
s
.38341 .30412 m .38341 .80601 L .41536 .81456 L p .707 .577 .707 r
F P
0 g
s
.19804 .69735 m .19309 .64004 L .17165 .64007 L p .707 .577 .707 r
F P
0 g
s
.633 .81118 m .63572 .79257 L .66243 .79993 L p .707 .577 .707 r
F P
0 g
s
.6168 .30404 m .6168 .80593 L .63724 .79513 L p .707 .577 .707 r
F P
0 g
s
.64299 .6808 m .63163 .62783 L .65875 .62834 L p .707 .577 .707 r
F P
0 g
s
.63724 .79513 m .63724 .29324 L .6168 .30404 L p .707 .577 .707 r
F P
0 g
s
.69421 .81587 m .69149 .83448 L .67986 .82656 L p .707 .577 .707 r
F P
0 g
s
.67986 .82656 m .68258 .80796 L .69421 .81587 L p .707 .577 .707 r
F P
0 g
s
.22211 .72666 m .22372 .76451 L .25489 .76443 L p .707 .577 .707 r
F P
0 g
s
.22372 .76451 m .22211 .72666 L .19462 .72497 L p .707 .577 .707 r
F P
0 g
s
.17165 .64007 m .1766 .69738 L .19804 .69735 L p .707 .577 .707 r
F P
0 g
s
.65875 .62834 m .67012 .68132 L .64299 .6808 L p .707 .577 .707 r
F P
0 g
s
.19462 .72497 m .19623 .76282 L .22372 .76451 L p .707 .577 .707 r
F P
0 g
s
.31439 .72134 m .316 .75919 L .33996 .75453 L p .707 .577 .707 r
F P
0 g
s
.33996 .75453 m .33835 .71668 L .31439 .72134 L p .707 .577 .707 r
F P
0 g
s
.68841 .72077 m .69215 .75718 L .67115 .75173 L p .707 .577 .707 r
F P
0 g
s
.67115 .75173 m .66741 .71531 L .68841 .72077 L p .707 .577 .707 r
F P
0 g
s
.33618 .62653 m .34113 .68385 L .35691 .68036 L p .707 .577 .707 r
F P
0 g
s
.35691 .68036 m .35196 .62305 L .33618 .62653 L p .707 .577 .707 r
F P
0 g
s
.19623 .76282 m .19462 .72497 L .1735 .72168 L p .707 .577 .707 r
F P
0 g
s
.1766 .69738 m .17165 .64007 L .15855 .63895 L p .707 .577 .707 r
F P
0 g
s
.1735 .72168 m .17511 .75953 L .19623 .76282 L p .707 .577 .707 r
F P
0 g
s
.24625 .82541 m .24741 .80786 L .21648 .80296 L p .707 .577 .707 r
F P
0 g
s
.24741 .80786 m .24625 .82541 L .27809 .82632 L p .707 .577 .707 r
F P
0 g
s
.27809 .82632 m .27925 .80877 L .24741 .80786 L p .707 .577 .707 r
F P
0 g
s
.27925 .80877 m .27809 .82632 L .30772 .82315 L p .707 .577 .707 r
F P
0 g
s
.30772 .82315 m .30888 .8056 L .27925 .80877 L p .707 .577 .707 r
F P
0 g
s
.15855 .63895 m .1635 .69627 L .1766 .69738 L p .707 .577 .707 r
F P
0 g
s
.68258 .80796 m .67986 .82656 L .65971 .81854 L p .707 .577 .707 r
F P
0 g
s
.65971 .81854 m .66243 .79993 L .68258 .80796 L p .707 .577 .707 r
F P
0 g
s
.33835 .71668 m .33996 .75453 L .35622 .74908 L p .707 .577 .707 r
F P
0 g
s
.35622 .74908 m .35461 .71123 L .33835 .71668 L p .707 .577 .707 r
F P
0 g
s
.21532 .82051 m .21648 .80296 L .18949 .79456 L p .707 .577 .707 r
F P
0 g
s
.21648 .80296 m .21532 .82051 L .24625 .82541 L p .707 .577 .707 r
F P
0 g
s
.66741 .71531 m .67115 .75173 L .64379 .74924 L p .707 .577 .707 r
F P
0 g
s
.64379 .74924 m .64005 .71282 L .66741 .71531 L p .707 .577 .707 r
F P
0 g
s
.35196 .62305 m .35691 .68036 L .36337 .6774 L p .707 .577 .707 r
F P
0 g
s
.36337 .6774 m .35842 .62009 L .35196 .62305 L p .707 .577 .707 r
F P
0 g
s
.35461 .71123 m .35622 .74908 L .36319 .74338 L p .707 .577 .707 r
F P
0 g
s
.36319 .74338 m .36158 .70553 L .35461 .71123 L p .707 .577 .707 r
F P
0 g
s
.35842 .62009 m .36337 .6774 L .35988 .67526 L p .707 .577 .707 r
F P
0 g
s
.36158 .70553 m .36319 .74338 L .36019 .73798 L p .707 .577 .707 r
F P
0 g
s
.36287 .79523 m .36287 .29334 L .35575 .28138 L p .707 .577 .707 r
F P
0 g
s
.36287 .29334 m .36287 .79523 L .38341 .80601 L p .707 .577 .707 r
F P
0 g
s
.18949 .79456 m .18833 .81211 L .21532 .82051 L p .707 .577 .707 r
F P
0 g
s
.30888 .8056 m .30772 .82315 L .33225 .81622 L p .707 .577 .707 r
F P
0 g
s
.33225 .81622 m .33341 .79867 L .30888 .8056 L p .707 .577 .707 r
F P
0 g
s
.63724 .29324 m .63724 .79513 L .64424 .78317 L p .707 .577 .707 r
F P
0 g
s
.64424 .78317 m .64424 .28128 L .63724 .29324 L p .707 .577 .707 r
F P
0 g
s
.17511 .75953 m .1735 .72168 L .16082 .71711 L p .707 .577 .707 r
F P
0 g
s
.18833 .81211 m .18949 .79456 L .16908 .78347 L p .707 .577 .707 r
F P
0 g
s
.16082 .71711 m .16243 .75496 L .17511 .75953 L p .707 .577 .707 r
F P
0 g
s
.66243 .79993 m .65971 .81854 L .633 .81118 L p .707 .577 .707 r
F P
0 g
s
.1635 .69627 m .15855 .63895 L .15505 .63682 L p .707 .577 .707 r
F P
0 g
s
.16908 .78347 m .16792 .80102 L .18833 .81211 L p .707 .577 .707 r
F P
0 g
s
.15505 .63682 m .16001 .69413 L .1635 .69627 L p .707 .577 .707 r
F P
0 g
s
.33341 .79867 m .33225 .81622 L .34927 .8062 L p .707 .577 .707 r
F P
0 g
s
.34927 .8062 m .35043 .78865 L .33341 .79867 L p .707 .577 .707 r
F P
0 g
s
.16792 .80102 m .16908 .78347 L .15724 .77078 L p .707 .577 .707 r
F P
0 g
s
.16243 .75496 m .16082 .71711 L .15782 .71171 L p .707 .577 .707 r
F P
0 g
s
.35988 .67526 m .35493 .61795 L .35842 .62009 L p .707 .577 .707 r
F P
0 g
s
.15724 .77078 m .15608 .78833 L .16792 .80102 L p .707 .577 .707 r
F P
0 g
s
.15782 .71171 m .15943 .74956 L .16243 .75496 L p .707 .577 .707 r
F P
0 g
s
.35711 .79407 m .35827 .77652 L .35043 .78865 L p .707 .577 .707 r
F P
0 g
s
.36019 .73798 m .35858 .70013 L .36158 .70553 L p .707 .577 .707 r
F P
0 g
s
.35493 .61795 m .35988 .67526 L .34678 .67415 L p .707 .577 .707 r
F P
0 g
s
.35827 .77652 m .35711 .79407 L .35502 .78103 L p .707 .577 .707 r
F P
0 g
s
.35502 .78103 m .35618 .76348 L .35827 .77652 L p .707 .577 .707 r
F P
0 g
s
.35858 .70013 m .36019 .73798 L .34751 .73341 L p .707 .577 .707 r
F P
0 g
s
.34751 .73341 m .3459 .69556 L .35858 .70013 L p .707 .577 .707 r
F P
0 g
s
.35618 .76348 m .35502 .78103 L .34319 .76834 L p .707 .577 .707 r
F P
0 g
s
.34319 .76834 m .34435 .75079 L .35618 .76348 L p .707 .577 .707 r
F P
0 g
s
.35575 .28138 m .35575 .78327 L .36287 .79523 L p .707 .577 .707 r
F P
0 g
s
.35575 .78327 m .35575 .28138 L .36276 .26942 L p .707 .577 .707 r
F P
0 g
s
.64424 .28128 m .64424 .78317 L .63713 .77121 L p .707 .577 .707 r
F P
0 g
s
.63713 .77121 m .63713 .26932 L .64424 .28128 L p .707 .577 .707 r
F P
0 g
s
.35043 .78865 m .34927 .8062 L .35711 .79407 L p .707 .577 .707 r
F P
0 g
s
.16001 .69413 m .15505 .63682 L .16152 .63386 L p .707 .577 .707 r
F P
0 g
s
.16152 .63386 m .16647 .69117 L .16001 .69413 L p .707 .577 .707 r
F P
0 g
s
.15608 .78833 m .15724 .77078 L .15515 .75774 L p .707 .577 .707 r
F P
0 g
s
.15943 .74956 m .15782 .71171 L .16479 .706 L p .707 .577 .707 r
F P
0 g
s
.15515 .75774 m .15399 .77529 L .15608 .78833 L p .707 .577 .707 r
F P
0 g
s
.34678 .67415 m .34182 .61684 L .35493 .61795 L p .707 .577 .707 r
F P
0 g
s
.16479 .706 m .1664 .74385 L .15943 .74956 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16647 .69117 m .16152 .63386 L .1773 .63037 L p .707 .577 .707 r
F P
0 g
s
.1773 .63037 m .18225 .68769 L .16647 .69117 L p .707 .577 .707 r
F P
0 g
s
.15399 .77529 m .15515 .75774 L .163 .74561 L p .707 .577 .707 r
F P
0 g
s
.36276 .7713 m .36276 .26942 L .38319 .25862 L p .707 .577 .707 r
F P
0 g
s
.36276 .26942 m .36276 .7713 L .35575 .78327 L p .707 .577 .707 r
F P
0 g
s
.63713 .26932 m .63713 .77121 L .61659 .76043 L p .707 .577 .707 r
F P
0 g
s
.61659 .76043 m .61659 .25854 L .63713 .26932 L p .707 .577 .707 r
F P
0 g
s
.163 .74561 m .16183 .76316 L .15399 .77529 L p .707 .577 .707 r
F P
0 g
s
.1664 .74385 m .16479 .706 L .18105 .70056 L p .707 .577 .707 r
F P
0 g
s
.34182 .61684 m .34678 .67415 L .32534 .67418 L p .707 .577 .707 r
F P
0 g
s
.32534 .67418 m .32039 .61686 L .34182 .61684 L p .707 .577 .707 r
F P
0 g
s
.18105 .70056 m .18266 .73841 L .1664 .74385 L p .707 .577 .707 r
F P
0 g
s
.18225 .68769 m .1773 .63037 L .20085 .6267 L p .707 .577 .707 r
F P
0 g
s
.20085 .6267 m .20581 .68401 L .18225 .68769 L p .707 .577 .707 r
F P
0 g
s
.3459 .69556 m .34751 .73341 L .32639 .73012 L p .707 .577 .707 r
F P
0 g
s
.32639 .73012 m .32478 .69227 L .3459 .69556 L p .707 .577 .707 r
F P
0 g
s
.16183 .76316 m .163 .74561 L .18002 .73559 L p .707 .577 .707 r
F P
0 g
s
.32039 .61686 m .32534 .67418 L .29768 .67534 L p .707 .577 .707 r
F P
0 g
s
.29768 .67534 m .29273 .61802 L .32039 .61686 L p .707 .577 .707 r
F P
0 g
s
.18266 .73841 m .18105 .70056 L .20501 .6959 L p .707 .577 .707 r
F P
0 g
s
.18002 .73559 m .17885 .75314 L .16183 .76316 L p .707 .577 .707 r
F P
0 g
s
.38319 .25862 m .38319 .76051 L .36276 .7713 L p .707 .577 .707 r
F P
0 g
s
.38319 .76051 m .38319 .25862 L .41506 .25005 L p .707 .577 .707 r
F P
0 g
s
.61659 .25854 m .61659 .76043 L .58463 .75188 L p .707 .577 .707 r
F P
0 g
s
.58463 .75188 m .58463 .24999 L .61659 .25854 L p .707 .577 .707 r
F P
0 g
s
.20581 .68401 m .20085 .6267 L .22988 .62319 L p .707 .577 .707 r
F P
0 g
s
.20501 .6959 m .20662 .73375 L .18266 .73841 L p .707 .577 .707 r
F P
0 g
s
.34435 .75079 m .34319 .76834 L .32278 .75725 L p .707 .577 .707 r
F P
0 g
s
.32278 .75725 m .32394 .7397 L .34435 .75079 L p .707 .577 .707 r
F P
0 g
s
.22988 .62319 m .23483 .68051 L .20581 .68401 L p .707 .577 .707 r
F P
0 g
s
.32478 .69227 m .32639 .73012 L .2989 .72843 L p .707 .577 .707 r
F P
0 g
s
.2989 .72843 m .29729 .69058 L .32478 .69227 L p .707 .577 .707 r
F P
0 g
s
.73351 .67394 m .73846 .62259 L .70727 .61728 L p .707 .577 .707 r
F P
0 g
s
.73846 .62259 m .73351 .67394 L .76516 .6748 L p .707 .577 .707 r
F P
0 g
s
.76516 .6748 m .77012 .62345 L .73846 .62259 L p .707 .577 .707 r
F P
0 g
s
.29273 .61802 m .29768 .67534 L .26649 .67752 L p .707 .577 .707 r
F P
0 g
s
.26649 .67752 m .26154 .62021 L .29273 .61802 L p .707 .577 .707 r
F P
0 g
s
.77012 .62345 m .76516 .6748 L .79419 .67111 L p .707 .577 .707 r
F P
0 g
s
.79419 .67111 m .79914 .61977 L .77012 .62345 L p .707 .577 .707 r
F P
0 g
s
.70232 .66862 m .70727 .61728 L .67961 .60803 L p .707 .577 .707 r
F P
0 g
s
.70727 .61728 m .70232 .66862 L .73351 .67394 L p .707 .577 .707 r
F P
0 g
s
.23483 .68051 m .22988 .62319 L .26154 .62021 L p .707 .577 .707 r
F P
0 g
s
.17885 .75314 m .18002 .73559 L .20454 .72866 L p .707 .577 .707 r
F P
0 g
s
.20662 .73375 m .20501 .6959 L .23432 .69249 L p .707 .577 .707 r
F P
0 g
s
.26154 .62021 m .26649 .67752 L .23483 .68051 L p .707 .577 .707 r
F P
0 g
s
.20454 .72866 m .20338 .74621 L .17885 .75314 L p .707 .577 .707 r
F P
0 g
s
.23432 .69249 m .23593 .73034 L .20662 .73375 L p .707 .577 .707 r
F P
0 g
s
.29729 .69058 m .2989 .72843 L .26773 .7285 L p .707 .577 .707 r
F P
0 g
s
.26773 .7285 m .26612 .69065 L .29729 .69058 L p .707 .577 .707 r
F P
0 g
s
.79914 .61977 m .79419 .67111 L .81775 .66325 L p .707 .577 .707 r
F P
0 g
s
.81775 .66325 m .8227 .61191 L .79914 .61977 L p .707 .577 .707 r
F P
0 g
s
.32394 .7397 m .32278 .75725 L .29579 .74885 L p .707 .577 .707 r
F P
0 g
s
.29579 .74885 m .29695 .7313 L .32394 .7397 L p .707 .577 .707 r
F P
0 g
s
.67466 .65937 m .67961 .60803 L .65817 .59574 L p .707 .577 .707 r
F P
0 g
s
.67961 .60803 m .67466 .65937 L .70232 .66862 L p .707 .577 .707 r
F P
0 g
s
.23593 .73034 m .23432 .69249 L .26612 .69065 L p .707 .577 .707 r
F P
0 g
s
.41506 .75193 m .41506 .25005 L .45525 .24453 L p .707 .577 .707 r
F P
0 g
s
.41506 .25005 m .41506 .75193 L .38319 .76051 L p .707 .577 .707 r
F P
0 g
s
.58463 .24999 m .58463 .75188 L .5444 .74639 L p .707 .577 .707 r
F P
0 g
s
.5444 .74639 m .5444 .2445 L .58463 .24999 L p .707 .577 .707 r
F P
0 g
s
.26612 .69065 m .26773 .7285 L .23593 .73034 L p .707 .577 .707 r
F P
0 g
s
.73227 .72599 m .73388 .69014 L .70271 .68641 L p .707 .577 .707 r
F P
0 g
s
.73388 .69014 m .73227 .72599 L .76406 .72615 L p .707 .577 .707 r
F P
0 g
s
.76406 .72615 m .76567 .6903 L .73388 .69014 L p .707 .577 .707 r
F P
0 g
s
.20338 .74621 m .20454 .72866 L .23418 .72549 L p .707 .577 .707 r
F P
0 g
s
.76567 .6903 m .76406 .72615 L .79338 .72272 L p .707 .577 .707 r
F P
0 g
s
.79338 .72272 m .79499 .68687 L .76567 .6903 L p .707 .577 .707 r
F P
0 g
s
.73514 .74825 m .73398 .72921 L .70305 .73008 L p .707 .577 .707 r
F P
0 g
s
.73398 .72921 m .73514 .74825 L .76698 .74608 L p .707 .577 .707 r
F P
0 g
s
.76698 .74608 m .76582 .72703 L .73398 .72921 L p .707 .577 .707 r
F P
0 g
s
.7011 .72226 m .70271 .68641 L .67522 .67947 L p .707 .577 .707 r
F P
0 g
s
.70271 .68641 m .7011 .72226 L .73227 .72599 L p .707 .577 .707 r
F P
0 g
s
.76582 .72703 m .76698 .74608 L .79662 .74281 L p .707 .577 .707 r
F P
0 g
s
.79662 .74281 m .79545 .72377 L .76582 .72703 L p .707 .577 .707 r
F P
0 g
s
.70305 .73008 m .70421 .74912 L .73514 .74825 L p .707 .577 .707 r
F P
0 g
s
.23418 .72549 m .23302 .74304 L .20338 .74621 L p .707 .577 .707 r
F P
0 g
s
.29695 .7313 m .29579 .74885 L .26486 .74395 L p .707 .577 .707 r
F P
0 g
s
.26486 .74395 m .26602 .7264 L .29695 .7313 L p .707 .577 .707 r
F P
0 g
s
.23302 .74304 m .23418 .72549 L .26602 .7264 L p .707 .577 .707 r
F P
0 g
s
.70421 .74912 m .70305 .73008 L .67606 .72955 L p .707 .577 .707 r
F P
0 g
s
.8227 .61191 m .81775 .66325 L .83353 .65198 L p .707 .577 .707 r
F P
0 g
s
.83353 .65198 m .83848 .60064 L .8227 .61191 L p .707 .577 .707 r
F P
0 g
s
.65322 .64709 m .65817 .59574 L .64507 .58163 L p .707 .577 .707 r
F P
0 g
s
.65817 .59574 m .65322 .64709 L .67466 .65937 L p .707 .577 .707 r
F P
0 g
s
.26602 .7264 m .26486 .74395 L .23302 .74304 L p .707 .577 .707 r
F P
0 g
s
.67606 .72955 m .67722 .7486 L .70421 .74912 L p .707 .577 .707 r
F P
0 g
s
.79499 .68687 m .79338 .72272 L .81734 .71604 L p .707 .577 .707 r
F P
0 g
s
.81734 .71604 m .81895 .68019 L .79499 .68687 L p .707 .577 .707 r
F P
0 g
s
.45525 .74642 m .45525 .24453 L .49981 .24262 L p .707 .577 .707 r
F P
0 g
s
.45525 .24453 m .45525 .74642 L .41506 .75193 L p .707 .577 .707 r
F P
0 g
s
.5444 .2445 m .5444 .74639 L .49981 .74451 L p .707 .577 .707 r
F P
0 g
s
.49981 .74451 m .49981 .24262 L .5444 .2445 L p .707 .577 .707 r
F P
0 g
s
.79545 .72377 m .79662 .74281 L .82114 .73877 L p .707 .577 .707 r
F P
0 g
s
.82114 .73877 m .81998 .71973 L .79545 .72377 L p .707 .577 .707 r
F P
0 g
s
.67522 .67947 m .67361 .71531 L .7011 .72226 L p .707 .577 .707 r
F P
0 g
s
.67361 .71531 m .67522 .67947 L .6541 .67 L p .707 .577 .707 r
F P
0 g
s
.49981 .24262 m .49981 .74451 L .45525 .74642 L p .707 .577 .707 r
F P
0 g
s
.67722 .7486 m .67606 .72955 L .65565 .72769 L p .707 .577 .707 r
F P
0 g
s
.65565 .72769 m .65681 .74673 L .67722 .7486 L p .707 .577 .707 r
F P
0 g
s
.6541 .67 m .65249 .70584 L .67361 .71531 L p .707 .577 .707 r
F P
0 g
s
.81895 .68019 m .81734 .71604 L .8336 .70675 L p .707 .577 .707 r
F P
0 g
s
.8336 .70675 m .83521 .6709 L .81895 .68019 L p .707 .577 .707 r
F P
0 g
s
.81998 .71973 m .82114 .73877 L .83816 .73436 L p .707 .577 .707 r
F P
0 g
s
.83816 .73436 m .837 .71531 L .81998 .71973 L p .707 .577 .707 r
F P
0 g
s
.83848 .60064 m .83353 .65198 L .83999 .6384 L p .707 .577 .707 r
F P
0 g
s
.83999 .6384 m .84494 .58705 L .83848 .60064 L p .707 .577 .707 r
F P
0 g
s
.64012 .63297 m .64507 .58163 L .64158 .56707 L p .707 .577 .707 r
F P
0 g
s
.64507 .58163 m .64012 .63297 L .65322 .64709 L p .707 .577 .707 r
F P
0 g
s
.65249 .70584 m .6541 .67 L .64142 .65892 L p .707 .577 .707 r
F P
0 g
s
.65681 .74673 m .65565 .72769 L .64382 .72467 L p .707 .577 .707 r
F P
0 g
s
.64382 .72467 m .64498 .74371 L .65681 .74673 L p .707 .577 .707 r
F P
0 g
s
.64142 .65892 m .63981 .69477 L .65249 .70584 L p .707 .577 .707 r
F P
0 g
s
.83521 .6709 m .8336 .70675 L .84057 .69578 L p .707 .577 .707 r
F P
0 g
s
.84057 .69578 m .84218 .65993 L .83521 .6709 L p .707 .577 .707 r
F P
0 g
s
.837 .71531 m .83816 .73436 L .84601 .72999 L p .707 .577 .707 r
F P
0 g
s
.84601 .72999 m .84485 .71095 L .837 .71531 L p .707 .577 .707 r
F P
0 g
s
.64158 .56707 m .63662 .61842 L .64012 .63297 L p .707 .577 .707 r
F P
0 g
s
.84494 .58705 m .83999 .6384 L .8365 .62384 L p .707 .577 .707 r
F P
0 g
s
.8365 .62384 m .84145 .5725 L .84494 .58705 L p .707 .577 .707 r
F P
0 g
s
.63662 .61842 m .64158 .56707 L .64804 .55349 L p .707 .577 .707 r
F P
0 g
s
.63981 .69477 m .64142 .65892 L .63842 .64733 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64498 .74371 m .64382 .72467 L .64172 .72079 L p .707 .577 .707 r
F P
0 g
s
.63842 .64733 m .63681 .68318 L .63981 .69477 L p .707 .577 .707 r
F P
0 g
s
.64172 .72079 m .64288 .73983 L .64498 .74371 L p .707 .577 .707 r
F P
0 g
s
.84218 .65993 m .84057 .69578 L .83757 .68418 L p .707 .577 .707 r
F P
0 g
s
.83757 .68418 m .83918 .64834 L .84218 .65993 L p .707 .577 .707 r
F P
0 g
s
.64804 .55349 m .64308 .60484 L .63662 .61842 L p .707 .577 .707 r
F P
0 g
s
.84145 .5725 m .8365 .62384 L .82339 .60973 L p .707 .577 .707 r
F P
0 g
s
.82339 .60973 m .82835 .55838 L .84145 .5725 L p .707 .577 .707 r
F P
0 g
s
.84485 .71095 m .84601 .72999 L .84391 .72611 L p .707 .577 .707 r
F P
0 g
s
.84391 .72611 m .84275 .70707 L .84485 .71095 L p .707 .577 .707 r
F P
0 g
s
.64308 .60484 m .64804 .55349 L .66382 .54222 L p .707 .577 .707 r
F P
0 g
s
.63681 .68318 m .63842 .64733 L .64539 .63636 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38766 .61082 m .39902 .55522 L .36837 .54794 L p .707 .577 .707 r
F P
0 g
s
.39902 .55522 m .38766 .61082 L .41883 .61637 L p .707 .577 .707 r
F P
0 g
s
.41883 .61637 m .43019 .56076 L .39902 .55522 L p .707 .577 .707 r
F P
0 g
s
.43019 .56076 m .41883 .61637 L .44747 .61964 L p .707 .577 .707 r
F P
0 g
s
.44747 .61964 m .45884 .56403 L .43019 .56076 L p .707 .577 .707 r
F P
0 g
s
.64539 .63636 m .64378 .6722 L .63681 .68318 L p .707 .577 .707 r
F P
0 g
s
.35701 .60354 m .36837 .54794 L .34124 .53964 L p .707 .577 .707 r
F P
0 g
s
.36837 .54794 m .35701 .60354 L .38766 .61082 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64288 .73983 m .64172 .72079 L .64957 .71642 L p .707 .577 .707 r
F P
0 g
s
.64957 .71642 m .65073 .73547 L .64288 .73983 L p .707 .577 .707 r
F P
0 g
s
.82835 .55838 m .82339 .60973 L .80196 .59744 L p .707 .577 .707 r
F P
0 g
s
.80196 .59744 m .80691 .5461 L .82835 .55838 L p .707 .577 .707 r
F P
0 g
s
.83918 .64834 m .83757 .68418 L .82489 .67311 L p .707 .577 .707 r
F P
0 g
s
.82489 .67311 m .8265 .63726 L .83918 .64834 L p .707 .577 .707 r
F P
0 g
s
.66382 .54222 m .65887 .59356 L .64308 .60484 L p .707 .577 .707 r
F P
0 g
s
.65887 .59356 m .66382 .54222 L .68738 .53436 L p .707 .577 .707 r
F P
0 g
s
.34124 .53964 m .32988 .59524 L .35701 .60354 L p .707 .577 .707 r
F P
0 g
s
.45884 .56403 m .44747 .61964 L .47078 .62031 L p .707 .577 .707 r
F P
0 g
s
.47078 .62031 m .48215 .56471 L .45884 .56403 L p .707 .577 .707 r
F P
0 g
s
.84275 .70707 m .84391 .72611 L .83208 .72309 L p .707 .577 .707 r
F P
0 g
s
.83208 .72309 m .83092 .70405 L .84275 .70707 L p .707 .577 .707 r
F P
0 g
s
.38724 .67652 m .39099 .63924 L .35995 .63469 L p .707 .577 .707 r
F P
0 g
s
.39099 .63924 m .38724 .67652 L .41892 .67886 L p .707 .577 .707 r
F P
0 g
s
.41892 .67886 m .42267 .64159 L .39099 .63924 L p .707 .577 .707 r
F P
0 g
s
.32988 .59524 m .34124 .53964 L .3203 .53113 L p .707 .577 .707 r
F P
0 g
s
.64378 .6722 m .64539 .63636 L .66165 .62707 L p .707 .577 .707 r
F P
0 g
s
.42267 .64159 m .41892 .67886 L .44814 .67877 L p .707 .577 .707 r
F P
0 g
s
.44814 .67877 m .45188 .64149 L .42267 .64159 L p .707 .577 .707 r
F P
0 g
s
.35621 .67196 m .35995 .63469 L .33259 .62837 L p .707 .577 .707 r
F P
0 g
s
.35995 .63469 m .35621 .67196 L .38724 .67652 L p .707 .577 .707 r
F P
0 g
s
.3203 .53113 m .30893 .58673 L .32988 .59524 L p .707 .577 .707 r
F P
0 g
s
.80691 .5461 m .80196 .59744 L .7743 .58819 L p .707 .577 .707 r
F P
0 g
s
.7743 .58819 m .77925 .53685 L .80691 .5461 L p .707 .577 .707 r
F P
0 g
s
.68242 .5857 m .68738 .53436 L .7164 .53067 L p .707 .577 .707 r
F P
0 g
s
.68738 .53436 m .68242 .5857 L .65887 .59356 L p .707 .577 .707 r
F P
0 g
s
.66165 .62707 m .66004 .66292 L .64378 .6722 L p .707 .577 .707 r
F P
0 g
s
.33259 .62837 m .32885 .66564 L .35621 .67196 L p .707 .577 .707 r
F P
0 g
s
.45188 .64149 m .44814 .67877 L .47204 .67624 L p .707 .577 .707 r
F P
0 g
s
.47204 .67624 m .47578 .63896 L .45188 .64149 L p .707 .577 .707 r
F P
0 g
s
.65073 .73547 m .64957 .71642 L .66659 .71201 L p .707 .577 .707 r
F P
0 g
s
.8265 .63726 m .82489 .67311 L .80377 .66364 L p .707 .577 .707 r
F P
0 g
s
.80377 .66364 m .80538 .62779 L .8265 .63726 L p .707 .577 .707 r
F P
0 g
s
.66659 .71201 m .66775 .73105 L .65073 .73547 L p .707 .577 .707 r
F P
0 g
s
.48215 .56471 m .47078 .62031 L .48648 .61832 L p .707 .577 .707 r
F P
0 g
s
.48648 .61832 m .49784 .56272 L .48215 .56471 L p .707 .577 .707 r
F P
0 g
s
.32885 .66564 m .33259 .62837 L .31159 .6209 L p .707 .577 .707 r
F P
0 g
s
.30893 .58673 m .3203 .53113 L .30757 .52325 L p .707 .577 .707 r
F P
0 g
s
.39764 .72849 m .39492 .71048 L .36428 .71204 L p .707 .577 .707 r
F P
0 g
s
.39492 .71048 m .39764 .72849 L .42923 .72358 L p .707 .577 .707 r
F P
0 g
s
.42923 .72358 m .42651 .70557 L .39492 .71048 L p .707 .577 .707 r
F P
0 g
s
.42651 .70557 m .42923 .72358 L .45866 .71579 L p .707 .577 .707 r
F P
0 g
s
.45866 .71579 m .45594 .69778 L .42651 .70557 L p .707 .577 .707 r
F P
0 g
s
.77925 .53685 m .7743 .58819 L .74311 .58288 L p .707 .577 .707 r
F P
0 g
s
.74311 .58288 m .74806 .53153 L .77925 .53685 L p .707 .577 .707 r
F P
0 g
s
.71145 .58202 m .7164 .53067 L .74806 .53153 L p .707 .577 .707 r
F P
0 g
s
.7164 .53067 m .71145 .58202 L .68242 .5857 L p .707 .577 .707 r
F P
0 g
s
.66004 .66292 m .66165 .62707 L .68561 .62039 L p .707 .577 .707 r
F P
0 g
s
.83092 .70405 m .83208 .72309 L .81167 .72123 L p .707 .577 .707 r
F P
0 g
s
.81167 .72123 m .81051 .70218 L .83092 .70405 L p .707 .577 .707 r
F P
0 g
s
.36428 .71204 m .367 .73005 L .39764 .72849 L p .707 .577 .707 r
F P
0 g
s
.74806 .53153 m .74311 .58288 L .71145 .58202 L p .707 .577 .707 r
F P
0 g
s
.31159 .6209 m .30785 .65818 L .32885 .66564 L p .707 .577 .707 r
F P
0 g
s
.367 .73005 m .36428 .71204 L .33757 .71009 L p .707 .577 .707 r
F P
0 g
s
.30757 .52325 m .29621 .57885 L .30893 .58673 L p .707 .577 .707 r
F P
0 g
s
.45594 .69778 m .45866 .71579 L .48306 .70589 L p .707 .577 .707 r
F P
0 g
s
.48306 .70589 m .48034 .68788 L .45594 .69778 L p .707 .577 .707 r
F P
0 g
s
.47578 .63896 m .47204 .67624 L .48828 .67152 L p .707 .577 .707 r
F P
0 g
s
.48828 .67152 m .49203 .63425 L .47578 .63896 L p .707 .577 .707 r
F P
0 g
s
.33757 .71009 m .34029 .7281 L .367 .73005 L p .707 .577 .707 r
F P
0 g
s
.68561 .62039 m .684 .65623 L .66004 .66292 L p .707 .577 .707 r
F P
0 g
s
.80538 .62779 m .80377 .66364 L .77628 .6567 L p .707 .577 .707 r
F P
0 g
s
.77628 .6567 m .77789 .62085 L .80538 .62779 L p .707 .577 .707 r
F P
0 g
s
.66775 .73105 m .66659 .71201 L .69112 .70797 L p .707 .577 .707 r
F P
0 g
s
.30785 .65818 m .31159 .6209 L .299 .61301 L p .707 .577 .707 r
F P
0 g
s
.684 .65623 m .68561 .62039 L .71492 .61696 L p .707 .577 .707 r
F P
0 g
s
.69112 .70797 m .69228 .72701 L .66775 .73105 L p .707 .577 .707 r
F P
0 g
s
.49784 .56272 m .48648 .61832 L .49303 .61387 L p .707 .577 .707 r
F P
0 g
s
.49303 .61387 m .50439 .55826 L .49784 .56272 L p .707 .577 .707 r
F P
0 g
s
.34029 .7281 m .33757 .71009 L .31741 .70482 L p .707 .577 .707 r
F P
0 g
s
.29621 .57885 m .30757 .52325 L .30433 .51676 L p .707 .577 .707 r
F P
0 g
s
.48034 .68788 m .48306 .70589 L .50003 .69485 L p .707 .577 .707 r
F P
0 g
s
.50003 .69485 m .49731 .67684 L .48034 .68788 L p .707 .577 .707 r
F P
0 g
s
.81051 .70218 m .81167 .72123 L .78468 .72071 L p .707 .577 .707 r
F P
0 g
s
.78468 .72071 m .78352 .70166 L .81051 .70218 L p .707 .577 .707 r
F P
0 g
s
.299 .61301 m .29526 .65029 L .30785 .65818 L p .707 .577 .707 r
F P
0 g
s
.77789 .62085 m .77628 .6567 L .74511 .65296 L p .707 .577 .707 r
F P
0 g
s
.74511 .65296 m .74672 .61712 L .77789 .62085 L p .707 .577 .707 r
F P
0 g
s
.31741 .70482 m .32014 .72283 L .34029 .7281 L p .707 .577 .707 r
F P
0 g
s
.71331 .6528 m .71492 .61696 L .74672 .61712 L p .707 .577 .707 r
F P
0 g
s
.71492 .61696 m .71331 .6528 L .684 .65623 L p .707 .577 .707 r
F P
0 g
s
.30433 .51676 m .29297 .57236 L .29621 .57885 L p .707 .577 .707 r
F P
0 g
s
.74672 .61712 m .74511 .65296 L .71331 .6528 L p .707 .577 .707 r
F P
0 g
s
.69228 .72701 m .69112 .70797 L .72075 .7047 L p .707 .577 .707 r
F P
0 g
s
.49203 .63425 m .48828 .67152 L .49527 .66509 L p .707 .577 .707 r
F P
0 g
s
.49527 .66509 m .49902 .62781 L .49203 .63425 L p .707 .577 .707 r
F P
0 g
s
.72075 .7047 m .72191 .72375 L .69228 .72701 L p .707 .577 .707 r
F P
0 g
s
.78352 .70166 m .78468 .72071 L .75375 .72157 L p .707 .577 .707 r
F P
0 g
s
.75375 .72157 m .75259 .70253 L .78352 .70166 L p .707 .577 .707 r
F P
0 g
s
.29526 .65029 m .299 .61301 L .29606 .60549 L p .707 .577 .707 r
F P
0 g
s
.32014 .72283 m .31741 .70482 L .30578 .69676 L p .707 .577 .707 r
F P
0 g
s
.72191 .72375 m .72075 .7047 L .75259 .70253 L p .707 .577 .707 r
F P
0 g
s
.49731 .67684 m .50003 .69485 L .50792 .68374 L p .707 .577 .707 r
F P
0 g
s
.50792 .68374 m .5052 .66573 L .49731 .67684 L p .707 .577 .707 r
F P
0 g
s
.75259 .70253 m .75375 .72157 L .72191 .72375 L p .707 .577 .707 r
F P
0 g
s
.50439 .55826 m .49303 .61387 L .48978 .60738 L p .707 .577 .707 r
F P
0 g
s
.48978 .60738 m .50114 .55178 L .50439 .55826 L p .707 .577 .707 r
F P
0 g
s
.30578 .69676 m .30851 .71477 L .32014 .72283 L p .707 .577 .707 r
F P
0 g
s
.29606 .60549 m .29232 .64276 L .29526 .65029 L p .707 .577 .707 r
F P
0 g
s
.29297 .57236 m .30433 .51676 L .31087 .5123 L p .707 .577 .707 r
F P
0 g
s
.31087 .5123 m .29951 .56791 L .29297 .57236 L p .707 .577 .707 r
F P
0 g
s
.49902 .62781 m .49527 .66509 L .49233 .65756 L p .707 .577 .707 r
F P
0 g
s
.49233 .65756 m .49608 .62028 L .49902 .62781 L p .707 .577 .707 r
F P
0 g
s
.30851 .71477 m .30578 .69676 L .30382 .68668 L p .708 .578 .707 r
F P
0 g
s
.29232 .64276 m .29606 .60549 L .30305 .59905 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.5052 .66573 m .50792 .68374 L .50596 .67367 L p .708 .578 .707 r
F P
0 g
s
.50596 .67367 m .50324 .65565 L .5052 .66573 L p .708 .578 .707 r
F P
0 g
s
.30382 .68668 m .30654 .70469 L .30851 .71477 L p .708 .578 .707 r
F P
0 g
s
.50114 .55178 m .48978 .60738 L .47706 .5995 L p .707 .577 .707 r
F P
0 g
s
.47706 .5995 m .48842 .54389 L .50114 .55178 L p .707 .577 .707 r
F P
0 g
s
.30305 .59905 m .29931 .63633 L .29232 .64276 L p .707 .577 .707 r
F P
0 g
s
.29951 .56791 m .31087 .5123 L .32657 .51031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32657 .51031 m .31521 .56592 L .29951 .56791 L p .707 .577 .707 r
F P
0 g
s
.49608 .62028 m .49233 .65756 L .47975 .64967 L p .707 .577 .707 r
F P
0 g
s
.47975 .64967 m .48349 .6124 L .49608 .62028 L p .707 .577 .707 r
F P
0 g
s
.30654 .70469 m .30382 .68668 L .31171 .67557 L p .707 .577 .707 r
F P
0 g
s
.29931 .63633 m .30305 .59905 L .31929 .59434 L p .707 .577 .707 r
F P
0 g
s
.50324 .65565 m .50596 .67367 L .49433 .6656 L p .707 .577 .707 r
F P
0 g
s
.49433 .6656 m .49161 .64759 L .50324 .65565 L p .707 .577 .707 r
F P
0 g
s
.48842 .54389 m .47706 .5995 L .45611 .59099 L p .707 .577 .707 r
F P
0 g
s
.45611 .59099 m .46747 .53538 L .48842 .54389 L p .707 .577 .707 r
F P
0 g
s
.31171 .67557 m .31443 .69359 L .30654 .70469 L p .707 .577 .707 r
F P
0 g
s
.31521 .56592 m .32657 .51031 L .34988 .51099 L p .707 .577 .707 r
F P
0 g
s
.31929 .59434 m .31555 .63161 L .29931 .63633 L p .707 .577 .707 r
F P
0 g
s
.34988 .51099 m .33852 .56659 L .31521 .56592 L p .707 .577 .707 r
F P
0 g
s
.48349 .6124 m .47975 .64967 L .45875 .6422 L p .707 .577 .707 r
F P
0 g
s
.45875 .6422 m .46249 .60493 L .48349 .6124 L p .707 .577 .707 r
F P
0 g
s
.46747 .53538 m .45611 .59099 L .42898 .58269 L p .707 .577 .707 r
F P
0 g
s
.42898 .58269 m .44035 .52708 L .46747 .53538 L p .707 .577 .707 r
F P
0 g
s
.31555 .63161 m .31929 .59434 L .34319 .59181 L p .707 .577 .707 r
F P
0 g
s
.31443 .69359 m .31171 .67557 L .32869 .66453 L p .707 .577 .707 r
F P
0 g
s
.33852 .56659 m .34988 .51099 L .37853 .51426 L p .707 .577 .707 r
F P
0 g
s
.49161 .64759 m .49433 .6656 L .47417 .66033 L p .707 .577 .707 r
F P
0 g
s
.47417 .66033 m .47145 .64232 L .49161 .64759 L p .707 .577 .707 r
F P
0 g
s
.32869 .66453 m .33141 .68254 L .31443 .69359 L p .707 .577 .707 r
F P
0 g
s
.34319 .59181 m .33945 .62908 L .31555 .63161 L p .707 .577 .707 r
F P
0 g
s
.37853 .51426 m .36716 .56986 L .33852 .56659 L p .707 .577 .707 r
F P
0 g
s
.44035 .52708 m .42898 .58269 L .39833 .57541 L p .707 .577 .707 r
F P
0 g
s
.39833 .57541 m .4097 .5198 L .44035 .52708 L p .707 .577 .707 r
F P
0 g
s
.36716 .56986 m .37853 .51426 L .4097 .5198 L p .707 .577 .707 r
F P
0 g
s
.46249 .60493 m .45875 .6422 L .43139 .63588 L p .707 .577 .707 r
F P
0 g
s
.43139 .63588 m .43513 .59861 L .46249 .60493 L p .707 .577 .707 r
F P
0 g
s
.4097 .5198 m .39833 .57541 L .36716 .56986 L p .707 .577 .707 r
F P
0 g
s
.33945 .62908 m .34319 .59181 L .37241 .59171 L p .707 .577 .707 r
F P
0 g
s
.33141 .68254 m .32869 .66453 L .35308 .65463 L p .707 .577 .707 r
F P
0 g
s
.47145 .64232 m .47417 .66033 L .44747 .65838 L p .707 .577 .707 r
F P
0 g
s
.44747 .65838 m .44475 .64037 L .47145 .64232 L p .707 .577 .707 r
F P
0 g
s
.37241 .59171 m .36867 .62898 L .33945 .62908 L p .707 .577 .707 r
F P
0 g
s
.43513 .59861 m .43139 .63588 L .40035 .63133 L p .707 .577 .707 r
F P
0 g
s
.40035 .63133 m .40409 .59405 L .43513 .59861 L p .707 .577 .707 r
F P
0 g
s
.35308 .65463 m .3558 .67264 L .33141 .68254 L p .707 .577 .707 r
F P
0 g
s
.36867 .62898 m .37241 .59171 L .40409 .59405 L p .707 .577 .707 r
F P
0 g
s
.40409 .59405 m .40035 .63133 L .36867 .62898 L p .707 .577 .707 r
F P
0 g
s
.3558 .67264 m .35308 .65463 L .38251 .64685 L p .707 .577 .707 r
F P
0 g
s
.44475 .64037 m .44747 .65838 L .41682 .65994 L p .707 .577 .707 r
F P
0 g
s
.41682 .65994 m .4141 .64193 L .44475 .64037 L p .707 .577 .707 r
F P
0 g
s
.38251 .64685 m .38524 .66486 L .3558 .67264 L p .707 .577 .707 r
F P
0 g
s
.38524 .66486 m .38251 .64685 L .4141 .64193 L p .707 .577 .707 r
F P
0 g
s
.4141 .64193 m .41682 .65994 L .38524 .66486 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001VOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol@0004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`<000=JEP03001JEUYF00AJEP04001J
EUYFFUH90005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00011oo`P004eoo`00EGoo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF00002Woo1P000eYF00<005YFFUH00UYF2@00A7oo001EOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00008Ool2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
000lOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Aoo`8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000iOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8003Moo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001oo`800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Eoo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=oo`00E7oo00<005YF0000
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH015YF0P00<7oo001COol00`00FUH00002FUH50003FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002moo`00Dgoo00<005YF00000`0015YF1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF000^Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005=o
o`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH00UYF40001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02aoo`00Egoo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YF000000AJEP03001JEUYF00AJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP02FUH6000@Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002aoo`00F7oo0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00@005YFFUIJEP<0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEP00
008001Yoo`@000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo001JOol200000eYF0000
000F0003FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH2000QOol400000eYF001JEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00FGoo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF00<005YFFUH00`0000=JEP00FUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF0P005Goo0`003Woo0P001UYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001J
EUYF00=JEP8000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2000015YF000005YF0`004Woo1@003goo0P0015YF00@005YFFUIJEP8002eoo`00EGoo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
1EYF00L005YF000005YF001JEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP02000@Ool5000AOol20002FUH01000FUIJEUYF0P00;Goo001DOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF001JEP02FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH3000=Ool5000COol30003FUH2000]
Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP04001JEP00000<Ool3000F
Ool01000FUIJEUYF0P00;Goo001DOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000015YF001JEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00@0
05YFFUIJEP<0021oo`800006FUH005YF001JEP00;Goo001?Ool70003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUHB000<Ool3000025YF001JEP00FUH005YF000]Ool004Io
o`T000AJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00=JEPL000AJEP03001JEUYF00IJEP03
001JEUYF009JEP`000AJEP03001JEUYF00800003FUH007oo02aoo`00?Woo200015YF00<005YFFUH0
1UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH01`00FUIJEUYF001JEP0002eoo`00=Woo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P00;Woo000`Ool6
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH500000eYF
001JEP0600000eYF001JEP03FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009J
EP04001JEUYFFUH2000^Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEPL00003FUH005YF00D0009J
EPL000IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF0P00;Woo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP05FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
6P000eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1000;goo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUH000EJEP03001JEUYF00IJEP<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF008000YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEPH00003FUH005YF00IJEP03
001JEUYF00EJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEP0000<00003FUH005YF00MJEP03001JEUYF00AJEQ@000AJEP04001JEUYF000:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000005FUH00`00FUIJEP06FUH00`00FUIJEP04
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF00002UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF0`000eYF0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001eYF00<005YFFUH015YF10001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
009JEP80009JEP03001JEUYF00=JEP<00003FUH005YF00MJEP@000EJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000015YF000000002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<0
05YFFUH00eYF00<005YFFUH01P0015YF1@0015YF00<005YFFUH00UYF1@0017oo0P0000=JEP00FUH0
0UYF0P00;Goo000]Ool00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF1P0015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP8000YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEP04001JEUYF0005OolB000;
Ool20003FUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQ8000EJEP04001JEUYFFUH4000015YF001JEUYF2@0015YF00<005YFFUH01EYF00@005YF
FUIJEPD000EJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002FUH00`00FUIJEP030005FUH01000FUIJEP0027oo1@0057oo0`000UYF00<007ooOol0;7oo000]
Ool2FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF200000=JEP00FUH025YF00<005YFFUH00UYF
0P001EYF00D005YF000005YF00<00003FUH005YF00=JEP03001JEUYF00<00003FUH0000000h000QJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH00004FUH30003FUH01000FUIJEP002Goo0`004goo0P000eYF0`00;Woo000]Ool2FUH01@00
FUIJEUYF00000eYF200000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1@00
0Woo00<005YF000015YF00<005YF000010000UYF00<005YFFUH02EYF00<005YFFUH01EYF0P000UYF
00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0005FUH00`00FUH000030002FUH00`00Oomoo`0IOol400000eYF001JEP03FUH2000^Ool002eoo`9J
EP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP020007Ool00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP09FUH0
0`00FUIJEP03FUH20005FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00001EYF00<005YFFUH00eYF1`004Woo1@001EYF00L005YFFUIJEP00FUH0000^Ool0
02eoo`9JEP@000EJEP03001JEUYF00AJEQP0009JEPH000Ioo`03001JEP0000AJEP03001JEP0000@0
009JEP03001JEUYF00UJEP04001JEUYFFUH200000eYF001JEP04FUH2000:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH0
0UYF4P000eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`8000=JEP03001JEUYF
00=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0002FUH4
0002Ool00`00FUH00004FUH00`00FUIJEP030003FUH00`00FUIJEP09FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000^Ool;00000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00FUIJEP03FUH400000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH30006FUH00`00FUIJEP03000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000aOol4
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00
FUIJEP03FUH01P00FUIJEP00FUH000AJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF
00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEQT000=JEP8002moo`00;Woo0`000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF000005YF
00@000EJEP06001JEUYF001JEP0015YF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000L000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00H0009JEP03001JEP0000AJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH20003FUH00`00FUH00007
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEQ0000IJEP03001JEUYF
00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH00000FUH01`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00D0
05YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00D000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
1@0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P000eYF400000=JEP00
0000;7oo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YF
FUH01EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUIJEPP000=ooa8000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JER@00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP800003FUH005YF009JEQT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0002aoo`00;Goo00<005YF00000eYF00<005YF00000`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0005FUH5000015YF001JEP0015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo
00<005YF00000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000EJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YF0000031oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002eoo`04
001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP05FUH300000eYF
001JEP03FUH00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL003Moo`00;Goo0P000eYF
00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01EYF1P001UYF00<005YFFUH00P0015YF
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001JEP/000AJEP03001JEUYF009JEQ8003ioo`00
;Goo0P000eYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH01EYF20001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF20001eYF00<005YFFUH00eYF00<005YF
0000200015YF2@00D7oo000]Ool20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP02FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUH000020004FUH00`00FUIJEP03FUH00`00FUH00008Ool300000eYF001JEP02FUH00`00Oomo
o`1BOol002aoo`03001JEP00009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH000EJEP07001JEP00Ool005YF000015YF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF0`00
00=JEP00FUH015YF00<005YF000027oo0P0000=JEP0000000eYF0P00Dgoo000/Ool00`00FUH00002
0003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006Ool20003FUH00`00FUIJEP020000
0eYF001JEP03FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH20005FUH00`00FUH00006Ool200000eYF001JEP02FUH200000eYF0000
001COol002aoo`03001JEP0000aooa80015oo`800003FUH005YF009JEP03001JEP00009JEP<000UJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP<000=JEP03001JEP0000Aoo`8000=JEP03001JEUYF009JEP@005=oo`00:goo00<005YF0000<Woo
0P000eYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00FUH007oo00<0
00EJEP03001JEUYF00=JEP<005=oo`00:goo0P006goo0`005goo00H005YFFUH005YF0004FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF000005YF00001UYF00<005YFFUH00eYF00<005YF0000
Dgoo000[Ool3000IOol5000FOol00`00FUH000030004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0001COol002]oo`800003FUH0000001Mo
o`D001Moo`D000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00EJEP03001J
EUYF009JEP8005Aoo`00:goo0P000eYF00<007ooOol057oo1@0067oo0P0000=JEP00FUH00eYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
E7oo000/Ool01000FUIJEUYF0`005Goo0`0067oo0`0000=JEP00FUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Dgoo000/Ool01@00
FUIJEUYF00000UYF0P00;Woo00<005YF00000P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH015YF00<005YFFUH00P00EWoo000]Ool00`00FUH00005FUH2000ZOol3000015YF
0000000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH015YF0`00
F7oo000^Ool20005FUH01000FUH000009Woo0P000UYF0P000Woo00<005YFFUH00UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@0000=JEP00FUH015YF0P00FWoo000_Ool00`00FUIJEP03FUH01000FUIJ
EUYF0`008Goo0P0015YF0P000goo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEPL005ao
o`00<7oo0P000eYF00<005YFFUH015YF1P005goo100000=JEP00FUH00eYF00<007ooOol017oo0`00
2EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YF00000P0025YF00<005YF00000P00G7oo000bOol200000eYF001JEP06FUH00`00FUIJ
EP02FUHG0005FUH00`00FUIJEP02FUH00`00Oomoo`06Ool30007FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001JOol003Aoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF008000aoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0009JEPH000IJEP03001JEUYF00AJEP<0
05Qoo`00=goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`004goo1@0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF2`001Woo1000
0UYF00<005YFFUH015YF00@005YFFUH005Moo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P006Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000Eoo`D000]oo`<000EJEP05001JEUYFFUH0001GOol003aoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000<0029oob4000Uoo`D000ioo`8000=JEP05001JEUYF
FUH0001GOol0049ooaL003Ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00@000Ioo`<0015oo`80
0004FUH005YFFUH2001GOol0095oo`<00003FUH005YF00IJEP03001JEUYF00AJEPL001Eoo`80009J
EP8005Moo`00U7oo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF5P0000=JEP0000000P00Egoo
002GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001GOol009]oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00Egoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8005Moo`00Xgoo1`0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00FGoo002ZOol90004FUH01000FUIJEUYF1P00G7oo002cOol8001ROol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63496 .75157 m .61674 .70145 L .58659 .71204 L p .707 .577 .707 r
F P
0 g
s
.61674 .70145 m .63496 .75157 L .66261 .73787 L p .707 .577 .707 r
F P
0 g
s
.66261 .73787 m .64439 .68774 L .61674 .70145 L p .707 .577 .707 r
F P
0 g
s
.60481 .76216 m .58659 .71204 L .55689 .71847 L p .707 .577 .707 r
F P
0 g
s
.58659 .71204 m .60481 .76216 L .63496 .75157 L p .707 .577 .707 r
F P
0 g
s
.64439 .68774 m .66261 .73787 L .68506 .72238 L p .707 .577 .707 r
F P
0 g
s
.68506 .72238 m .66684 .67226 L .64439 .68774 L p .707 .577 .707 r
F P
0 g
s
.57511 .76859 m .55689 .71847 L .53056 .72012 L p .707 .577 .707 r
F P
0 g
s
.55689 .71847 m .57511 .76859 L .60481 .76216 L p .707 .577 .707 r
F P
0 g
s
.60177 .81655 m .59573 .78073 L .56493 .78302 L p .707 .577 .707 r
F P
0 g
s
.59573 .78073 m .60177 .81655 L .6332 .81085 L p .707 .577 .707 r
F P
0 g
s
.6332 .81085 m .62716 .77503 L .59573 .78073 L p .707 .577 .707 r
F P
0 g
s
.66684 .67226 m .68506 .72238 L .70011 .70663 L p .707 .577 .707 r
F P
0 g
s
.70011 .70663 m .68189 .65651 L .66684 .67226 L p .707 .577 .707 r
F P
0 g
s
.62716 .77503 m .6332 .81085 L .66219 .80228 L p .707 .577 .707 r
F P
0 g
s
.66219 .80228 m .65615 .76647 L .62716 .77503 L p .707 .577 .707 r
F P
0 g
s
.54878 .77024 m .53056 .72012 L .51016 .71682 L p .707 .577 .707 r
F P
0 g
s
.53056 .72012 m .54878 .77024 L .57511 .76859 L p .707 .577 .707 r
F P
0 g
s
.57511 .84148 m .57947 .82305 L .54947 .81465 L p .707 .577 .707 r
F P
0 g
s
.57947 .82305 m .57511 .84148 L .60622 .84835 L p .707 .577 .707 r
F P
0 g
s
.60622 .84835 m .61058 .82992 L .57947 .82305 L p .707 .577 .707 r
F P
0 g
s
.57097 .81884 m .56493 .78302 L .53777 .78166 L p .707 .577 .707 r
F P
0 g
s
.56493 .78302 m .57097 .81884 L .60177 .81655 L p .707 .577 .707 r
F P
0 g
s
.61058 .82992 m .60622 .84835 L .6354 .85303 L p .707 .577 .707 r
F P
0 g
s
.6354 .85303 m .63976 .8346 L .61058 .82992 L p .707 .577 .707 r
F P
0 g
s
.54947 .81465 m .54512 .83308 L .57511 .84148 L p .707 .577 .707 r
F P
0 g
s
.65615 .76647 m .66219 .80228 L .6859 .7917 L p .707 .577 .707 r
F P
0 g
s
.6859 .7917 m .67986 .75588 L .65615 .76647 L p .707 .577 .707 r
F P
0 g
s
.54512 .83308 m .54947 .81465 L .52353 .80556 L p .707 .577 .707 r
F P
0 g
s
.52353 .80556 m .51918 .82399 L .54512 .83308 L p .707 .577 .707 r
F P
0 g
s
.53777 .78166 m .54381 .81748 L .57097 .81884 L p .707 .577 .707 r
F P
0 g
s
.63976 .8346 m .6354 .85303 L .6598 .85505 L p .707 .577 .707 r
F P
0 g
s
.6598 .85505 m .66415 .83662 L .63976 .8346 L p .707 .577 .707 r
F P
0 g
s
.68189 .65651 m .70011 .70663 L .70629 .69217 L p .707 .577 .707 r
F P
0 g
s
.70629 .69217 m .68806 .64204 L .68189 .65651 L p .707 .577 .707 r
F P
0 g
s
.54381 .81748 m .53777 .78166 L .51692 .77679 L p .707 .577 .707 r
F P
0 g
s
.51016 .71682 m .52838 .76694 L .54878 .77024 L p .707 .577 .707 r
F P
0 g
s
.52838 .76694 m .51016 .71682 L .4977 .70889 L p .707 .577 .707 r
F P
0 g
s
.67986 .75588 m .6859 .7917 L .702 .78012 L p .707 .577 .707 r
F P
0 g
s
.702 .78012 m .69596 .7443 L .67986 .75588 L p .707 .577 .707 r
F P
0 g
s
.51918 .82399 m .52353 .80556 L .50419 .79665 L p .707 .577 .707 r
F P
0 g
s
.50419 .79665 m .49983 .81508 L .51918 .82399 L p .707 .577 .707 r
F P
0 g
s
.51692 .77679 m .52297 .81261 L .54381 .81748 L p .707 .577 .707 r
F P
0 g
s
.66415 .83662 m .6598 .85505 L .67702 .85422 L p .707 .577 .707 r
F P
0 g
s
.67702 .85422 m .68138 .83579 L .66415 .83662 L p .707 .577 .707 r
F P
0 g
s
.52297 .81261 m .51692 .77679 L .50442 .76889 L p .707 .577 .707 r
F P
0 g
s
.4977 .70889 m .51592 .75902 L .52838 .76694 L p .707 .577 .707 r
F P
0 g
s
.68806 .64204 m .70629 .69217 L .70298 .68039 L p .707 .577 .707 r
F P
0 g
s
.70298 .68039 m .68476 .63027 L .68806 .64204 L p .707 .577 .707 r
F P
0 g
s
.49983 .81508 m .50419 .79665 L .49333 .7888 L p .707 .577 .707 r
F P
0 g
s
.69596 .7443 m .702 .78012 L .70893 .7687 L p .707 .577 .707 r
F P
0 g
s
.70893 .7687 m .70289 .73288 L .69596 .7443 L p .707 .577 .707 r
F P
0 g
s
.51592 .75902 m .4977 .70889 L .4944 .69712 L p .707 .577 .707 r
F P
0 g
s
.49333 .7888 m .48897 .80723 L .49983 .81508 L p .707 .577 .707 r
F P
0 g
s
.50442 .76889 m .51047 .8047 L .52297 .81261 L p .707 .577 .707 r
F P
0 g
s
.68138 .83579 m .67702 .85422 L .68539 .85063 L p .707 .577 .707 r
F P
0 g
s
.68539 .85063 m .68974 .83219 L .68138 .83579 L p .707 .577 .707 r
F P
0 g
s
.51047 .8047 m .50442 .76889 L .50149 .75872 L p .707 .577 .707 r
F P
0 g
s
.4944 .69712 m .51262 .74725 L .51592 .75902 L p .707 .577 .707 r
F P
0 g
s
.51262 .74725 m .4944 .69712 L .50057 .68265 L p .707 .577 .707 r
F P
0 g
s
.50149 .75872 m .50754 .79454 L .51047 .8047 L p .707 .577 .707 r
F P
0 g
s
.50754 .79454 m .50149 .75872 L .50842 .7473 L p .707 .577 .707 r
F P
0 g
s
.50057 .68265 m .51879 .73278 L .51262 .74725 L p .707 .577 .707 r
F P
0 g
s
.51879 .73278 m .50057 .68265 L .51562 .66691 L p .707 .577 .707 r
F P
0 g
s
.50842 .7473 m .51446 .78311 L .50754 .79454 L p .707 .577 .707 r
F P
0 g
s
.51446 .78311 m .50842 .7473 L .52452 .73572 L p .707 .577 .707 r
F P
0 g
s
.52452 .73572 m .53057 .77154 L .51446 .78311 L p .707 .577 .707 r
F P
0 g
s
.49603 .79762 m .50038 .77919 L .5176 .77836 L p .707 .577 .707 r
F P
0 g
s
.5176 .77836 m .51325 .79679 L .49603 .79762 L p .707 .577 .707 r
F P
0 g
s
.50621 .82189 m .50621 .32 L .46137 .31862 L p .707 .577 .707 r
F P
0 g
s
.51562 .66691 m .53384 .71703 L .51879 .73278 L p .707 .577 .707 r
F P
0 g
s
.53384 .71703 m .51562 .66691 L .53807 .65142 L p .707 .577 .707 r
F P
0 g
s
.53807 .65142 m .55629 .70154 L .53384 .71703 L p .707 .577 .707 r
F P
0 g
s
.53057 .77154 m .52452 .73572 L .54823 .72513 L p .707 .577 .707 r
F P
0 g
s
.51325 .79679 m .5176 .77836 L .542 .78038 L p .707 .577 .707 r
F P
0 g
s
.54823 .72513 m .55427 .76095 L .53057 .77154 L p .707 .577 .707 r
F P
0 g
s
.542 .78038 m .53765 .79882 L .51325 .79679 L p .707 .577 .707 r
F P
0 g
s
.53765 .79882 m .542 .78038 L .57118 .78506 L p .707 .577 .707 r
F P
0 g
s
.57118 .78506 m .56683 .80349 L .53765 .79882 L p .707 .577 .707 r
F P
0 g
s
.50621 .32 m .50621 .82189 L .55044 .81948 L p .707 .577 .707 r
F P
0 g
s
.55629 .70154 m .53807 .65142 L .56572 .63771 L p .707 .577 .707 r
F P
0 g
s
.55427 .76095 m .54823 .72513 L .57722 .71657 L p .707 .577 .707 r
F P
0 g
s
.55044 .81948 m .55044 .31759 L .50621 .32 L p .707 .577 .707 r
F P
0 g
s
.68476 .63027 m .70298 .68039 L .69052 .67247 L p .707 .577 .707 r
F P
0 g
s
.69052 .67247 m .6723 .62235 L .68476 .63027 L p .707 .577 .707 r
F P
0 g
s
.46137 .82051 m .46137 .31862 L .42032 .31359 L p .707 .577 .707 r
F P
0 g
s
.48897 .80723 m .49333 .7888 L .49201 .78279 L p .707 .577 .707 r
F P
0 g
s
.49201 .78279 m .48766 .80122 L .48897 .80723 L p .707 .577 .707 r
F P
0 g
s
.48766 .80122 m .49201 .78279 L .50038 .77919 L p .707 .577 .707 r
F P
0 g
s
.50038 .77919 m .49603 .79762 L .48766 .80122 L p .707 .577 .707 r
F P
0 g
s
.46137 .31862 m .46137 .82051 L .50621 .82189 L p .707 .577 .707 r
F P
0 g
s
.70289 .73288 m .70893 .7687 L .706 .75853 L p .707 .577 .707 r
F P
0 g
s
.706 .75853 m .69996 .72271 L .70289 .73288 L p .707 .577 .707 r
F P
0 g
s
.58395 .68784 m .56572 .63771 L .59588 .62713 L p .707 .577 .707 r
F P
0 g
s
.56572 .63771 m .58395 .68784 L .55629 .70154 L p .707 .577 .707 r
F P
0 g
s
.58326 .75239 m .57722 .71657 L .60865 .71087 L p .707 .577 .707 r
F P
0 g
s
.57722 .71657 m .58326 .75239 L .55427 .76095 L p .707 .577 .707 r
F P
0 g
s
.60865 .71087 m .6147 .74669 L .58326 .75239 L p .707 .577 .707 r
F P
0 g
s
.56683 .80349 m .57118 .78506 L .60229 .79193 L p .707 .577 .707 r
F P
0 g
s
.60229 .79193 m .59794 .81037 L .56683 .80349 L p .707 .577 .707 r
F P
0 g
s
.55044 .31759 m .55044 .81948 L .58973 .81352 L p .707 .577 .707 r
F P
0 g
s
.59588 .62713 m .6141 .67725 L .58395 .68784 L p .707 .577 .707 r
F P
0 g
s
.58973 .81352 m .58973 .31163 L .55044 .31759 L p .707 .577 .707 r
F P
0 g
s
.42032 .81548 m .42032 .31359 L .38706 .30541 L p .707 .577 .707 r
F P
0 g
s
.42032 .31359 m .42032 .81548 L .46137 .82051 L p .707 .577 .707 r
F P
0 g
s
.68974 .83219 m .68539 .85063 L .68408 .84461 L p .707 .577 .707 r
F P
0 g
s
.68408 .84461 m .68843 .82618 L .68974 .83219 L p .707 .577 .707 r
F P
0 g
s
.6141 .67725 m .59588 .62713 L .62557 .62069 L p .707 .577 .707 r
F P
0 g
s
.63946 .70858 m .6455 .7444 L .6147 .74669 L p .707 .577 .707 r
F P
0 g
s
.6147 .74669 m .60865 .71087 L .63946 .70858 L p .707 .577 .707 r
F P
0 g
s
.63229 .80033 m .62793 .81876 L .59794 .81037 L p .707 .577 .707 r
F P
0 g
s
.59794 .81037 m .60229 .79193 L .63229 .80033 L p .707 .577 .707 r
F P
0 g
s
.58973 .31163 m .58973 .81352 L .62024 .8046 L p .707 .577 .707 r
F P
0 g
s
.62557 .62069 m .64379 .67082 L .6141 .67725 L p .707 .577 .707 r
F P
0 g
s
.62024 .8046 m .62024 .30271 L .58973 .31163 L p .707 .577 .707 r
F P
0 g
s
.6723 .62235 m .69052 .67247 L .67013 .66917 L p .707 .577 .707 r
F P
0 g
s
.67013 .66917 m .65191 .61905 L .6723 .62235 L p .707 .577 .707 r
F P
0 g
s
.2204 .62931 m .22851 .68639 L .25959 .68174 L p .707 .577 .707 r
F P
0 g
s
.25959 .68174 m .25149 .62466 L .2204 .62931 L p .707 .577 .707 r
F P
0 g
s
.25149 .62466 m .25959 .68174 L .291 .67745 L p .707 .577 .707 r
F P
0 g
s
.69996 .72271 m .706 .75853 L .6935 .75063 L p .707 .577 .707 r
F P
0 g
s
.6935 .75063 m .68746 .71481 L .69996 .72271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.291 .67745 m .28289 .62037 L .25149 .62466 L p .707 .577 .707 r
F P
0 g
s
.28289 .62037 m .291 .67745 L .31964 .67393 L p .707 .577 .707 r
F P
0 g
s
.19268 .63386 m .20078 .69094 L .22851 .68639 L p .707 .577 .707 r
F P
0 g
s
.22851 .68639 m .2204 .62931 L .19268 .63386 L p .707 .577 .707 r
F P
0 g
s
.31964 .67393 m .31154 .61685 L .28289 .62037 L p .707 .577 .707 r
F P
0 g
s
.25607 .75893 m .25346 .7208 L .22231 .72212 L p .707 .577 .707 r
F P
0 g
s
.25346 .7208 m .25607 .75893 L .28781 .75643 L p .707 .577 .707 r
F P
0 g
s
.28781 .75643 m .2852 .7183 L .25346 .7208 L p .707 .577 .707 r
F P
0 g
s
.38706 .8073 m .38706 .30541 L .36486 .29486 L p .707 .577 .707 r
F P
0 g
s
.38706 .30541 m .38706 .8073 L .42032 .81548 L p .707 .577 .707 r
F P
0 g
s
.2852 .7183 m .28781 .75643 L .31705 .75299 L p .707 .577 .707 r
F P
0 g
s
.31705 .75299 m .31443 .71486 L .2852 .7183 L p .707 .577 .707 r
F P
0 g
s
.31154 .61685 m .31964 .67393 L .34273 .67154 L p .707 .577 .707 r
F P
0 g
s
.68843 .82618 m .68408 .84461 L .67322 .83676 L p .707 .577 .707 r
F P
0 g
s
.67322 .83676 m .67757 .81833 L .68843 .82618 L p .707 .577 .707 r
F P
0 g
s
.22231 .72212 m .22492 .76025 L .25607 .75893 L p .707 .577 .707 r
F P
0 g
s
.34273 .67154 m .33463 .61446 L .31154 .61685 L p .707 .577 .707 r
F P
0 g
s
.17103 .63787 m .17914 .69495 L .20078 .69094 L p .707 .577 .707 r
F P
0 g
s
.20078 .69094 m .19268 .63386 L .17103 .63787 L p .707 .577 .707 r
F P
0 g
s
.65191 .61905 m .67013 .66917 L .64379 .67082 L p .707 .577 .707 r
F P
0 g
s
.64379 .67082 m .62557 .62069 L .65191 .61905 L p .707 .577 .707 r
F P
0 g
s
.22492 .76025 m .22231 .72212 L .19482 .72213 L p .707 .577 .707 r
F P
0 g
s
.19482 .72213 m .19743 .76025 L .22492 .76025 L p .707 .577 .707 r
F P
0 g
s
.62024 .30271 m .62024 .8046 L .63898 .79358 L p .707 .577 .707 r
F P
0 g
s
.63898 .79358 m .63898 .29169 L .62024 .30271 L p .707 .577 .707 r
F P
0 g
s
.68746 .71481 m .6935 .75063 L .67265 .74576 L p .707 .577 .707 r
F P
0 g
s
.67265 .74576 m .66661 .70994 L .68746 .71481 L p .707 .577 .707 r
F P
0 g
s
.31443 .71486 m .31705 .75299 L .34091 .74895 L p .707 .577 .707 r
F P
0 g
s
.34091 .74895 m .3383 .71082 L .31443 .71486 L p .707 .577 .707 r
F P
0 g
s
.19743 .76025 m .19482 .72213 L .17366 .72082 L p .707 .577 .707 r
F P
0 g
s
.33463 .61446 m .34273 .67154 L .358 .6705 L p .707 .577 .707 r
F P
0 g
s
.358 .6705 m .3499 .61342 L .33463 .61446 L p .707 .577 .707 r
F P
0 g
s
.17366 .72082 m .17627 .75894 L .19743 .76025 L p .707 .577 .707 r
F P
0 g
s
.15758 .64094 m .16568 .69802 L .17914 .69495 L p .707 .577 .707 r
F P
0 g
s
.17914 .69495 m .17103 .63787 L .15758 .64094 L p .707 .577 .707 r
F P
0 g
s
.67757 .81833 m .67322 .83676 L .65387 .82786 L p .707 .577 .707 r
F P
0 g
s
.65387 .82786 m .65822 .80943 L .67757 .81833 L p .707 .577 .707 r
F P
0 g
s
.3383 .71082 m .34091 .74895 L .35707 .7447 L p .707 .577 .707 r
F P
0 g
s
.35707 .7447 m .35446 .70658 L .3383 .71082 L p .707 .577 .707 r
F P
0 g
s
.66661 .70994 m .67265 .74576 L .6455 .7444 L p .707 .577 .707 r
F P
0 g
s
.6455 .7444 m .63946 .70858 L .66661 .70994 L p .707 .577 .707 r
F P
0 g
s
.2422 .83147 m .24406 .81476 L .21333 .80811 L p .707 .577 .707 r
F P
0 g
s
.24406 .81476 m .2422 .83147 L .27397 .83336 L p .707 .577 .707 r
F P
0 g
s
.27397 .83336 m .27584 .81665 L .24406 .81476 L p .707 .577 .707 r
F P
0 g
s
.3499 .61342 m .358 .6705 L .36396 .67092 L p .707 .577 .707 r
F P
0 g
s
.36396 .67092 m .35585 .61384 L .3499 .61342 L p .707 .577 .707 r
F P
0 g
s
.35446 .70658 m .35707 .7447 L .36394 .74066 L p .707 .577 .707 r
F P
0 g
s
.36394 .74066 m .36133 .70254 L .35446 .70658 L p .707 .577 .707 r
F P
0 g
s
.35585 .61384 m .36396 .67092 L .36001 .67276 L p .707 .577 .707 r
F P
0 g
s
.36133 .70254 m .36394 .74066 L .36085 .73723 L p .707 .577 .707 r
F P
0 g
s
.36486 .79675 m .36486 .29486 L .35589 .283 L p .707 .577 .707 r
F P
0 g
s
.36486 .29486 m .36486 .79675 L .38706 .8073 L p .707 .577 .707 r
F P
0 g
s
.27584 .81665 m .27397 .83336 L .30368 .8303 L p .707 .577 .707 r
F P
0 g
s
.30368 .8303 m .30554 .81359 L .27584 .81665 L p .707 .577 .707 r
F P
0 g
s
.21147 .82482 m .21333 .80811 L .18666 .79734 L p .707 .577 .707 r
F P
0 g
s
.21333 .80811 m .21147 .82482 L .2422 .83147 L p .707 .577 .707 r
F P
0 g
s
.17627 .75894 m .17366 .72082 L .16091 .71833 L p .707 .577 .707 r
F P
0 g
s
.63898 .29169 m .63898 .79358 L .64411 .78155 L p .707 .577 .707 r
F P
0 g
s
.64411 .78155 m .64411 .27966 L .63898 .29169 L p .707 .577 .707 r
F P
0 g
s
.16091 .71833 m .16352 .75645 L .17627 .75894 L p .707 .577 .707 r
F P
0 g
s
.30554 .81359 m .30368 .8303 L .32842 .82259 L p .707 .577 .707 r
F P
0 g
s
.32842 .82259 m .33028 .80588 L .30554 .81359 L p .707 .577 .707 r
F P
0 g
s
.18666 .79734 m .18479 .81405 L .21147 .82482 L p .707 .577 .707 r
F P
0 g
s
.65822 .80943 m .65387 .82786 L .62793 .81876 L p .707 .577 .707 r
F P
0 g
s
.62793 .81876 m .63229 .80033 L .65822 .80943 L p .707 .577 .707 r
F P
0 g
s
.15363 .64277 m .16174 .69985 L .16568 .69802 L p .707 .577 .707 r
F P
0 g
s
.16568 .69802 m .15758 .64094 L .15363 .64277 L p .707 .577 .707 r
F P
0 g
s
.18479 .81405 m .18666 .79734 L .16665 .78352 L p .707 .577 .707 r
F P
0 g
s
.16665 .78352 m .16478 .80023 L .18479 .81405 L p .707 .577 .707 r
F P
0 g
s
.33028 .80588 m .32842 .82259 L .34576 .81099 L p .707 .577 .707 r
F P
0 g
s
.34576 .81099 m .34762 .79428 L .33028 .80588 L p .707 .577 .707 r
F P
0 g
s
.16352 .75645 m .16091 .71833 L .15782 .7149 L p .707 .577 .707 r
F P
0 g
s
.16478 .80023 m .16665 .78352 L .15526 .76799 L p .707 .577 .707 r
F P
0 g
s
.15782 .7149 m .16043 .75302 L .16352 .75645 L p .707 .577 .707 r
F P
0 g
s
.36001 .67276 m .35191 .61568 L .35585 .61384 L p .707 .577 .707 r
F P
0 g
s
.36085 .73723 m .35824 .69911 L .36133 .70254 L p .707 .577 .707 r
F P
0 g
s
.35191 .61568 m .36001 .67276 L .34656 .67583 L p .707 .577 .707 r
F P
0 g
s
.35824 .69911 m .36085 .73723 L .34811 .73474 L p .707 .577 .707 r
F P
0 g
s
.34811 .73474 m .34549 .69661 L .35824 .69911 L p .707 .577 .707 r
F P
0 g
s
.35589 .283 m .35589 .78489 L .36486 .79675 L p .707 .577 .707 r
F P
0 g
s
.35589 .78489 m .35589 .283 L .36102 .27097 L p .707 .577 .707 r
F P
0 g
s
.15526 .76799 m .15339 .7847 L .16478 .80023 L p .707 .577 .707 r
F P
0 g
s
.15959 .64319 m .16769 .70027 L .16174 .69985 L p .707 .577 .707 r
F P
0 g
s
.16174 .69985 m .15363 .64277 L .15959 .64319 L p .707 .577 .707 r
F P
0 g
s
.64411 .27966 m .64411 .78155 L .63514 .76968 L p .707 .577 .707 r
F P
0 g
s
.63514 .76968 m .63514 .26779 L .64411 .27966 L p .707 .577 .707 r
F P
0 g
s
.34762 .79428 m .34576 .81099 L .35401 .79662 L p .707 .577 .707 r
F P
0 g
s
.35401 .79662 m .35587 .77992 L .34762 .79428 L p .707 .577 .707 r
F P
0 g
s
.15339 .7847 m .15526 .76799 L .15361 .75227 L p .707 .577 .707 r
F P
0 g
s
.16043 .75302 m .15782 .7149 L .16469 .71086 L p .707 .577 .707 r
F P
0 g
s
.16469 .71086 m .16731 .74898 L .16043 .75302 L p .707 .577 .707 r
F P
0 g
s
.15361 .75227 m .15174 .76898 L .15339 .7847 L p .707 .577 .707 r
F P
0 g
s
.34656 .67583 m .33845 .61875 L .35191 .61568 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17486 .64215 m .18296 .69923 L .16769 .70027 L p .707 .577 .707 r
F P
0 g
s
.16769 .70027 m .15959 .64319 L .17486 .64215 L p .707 .577 .707 r
F P
0 g
s
.35587 .77992 m .35401 .79662 L .35236 .78091 L p .707 .577 .707 r
F P
0 g
s
.35236 .78091 m .35422 .7642 L .35587 .77992 L p .707 .577 .707 r
F P
0 g
s
.36102 .77285 m .36102 .27097 L .37976 .25995 L p .707 .577 .707 r
F P
0 g
s
.36102 .27097 m .36102 .77285 L .35589 .78489 L p .707 .577 .707 r
F P
0 g
s
.15174 .76898 m .15361 .75227 L .16186 .73791 L p .707 .577 .707 r
F P
0 g
s
.63514 .26779 m .63514 .76968 L .61294 .75914 L p .707 .577 .707 r
F P
0 g
s
.61294 .75914 m .61294 .25725 L .63514 .26779 L p .707 .577 .707 r
F P
0 g
s
.16731 .74898 m .16469 .71086 L .18085 .70661 L p .707 .577 .707 r
F P
0 g
s
.16186 .73791 m .15999 .75462 L .15174 .76898 L p .707 .577 .707 r
F P
0 g
s
.18085 .70661 m .18347 .74474 L .16731 .74898 L p .707 .577 .707 r
F P
0 g
s
.33845 .61875 m .34656 .67583 L .32491 .67984 L p .707 .577 .707 r
F P
0 g
s
.32491 .67984 m .31681 .62276 L .33845 .61875 L p .707 .577 .707 r
F P
0 g
s
.19795 .63976 m .20605 .69684 L .18296 .69923 L p .707 .577 .707 r
F P
0 g
s
.18296 .69923 m .17486 .64215 L .19795 .63976 L p .707 .577 .707 r
F P
0 g
s
.35422 .7642 m .35236 .78091 L .34097 .76538 L p .707 .577 .707 r
F P
0 g
s
.34097 .76538 m .34283 .74867 L .35422 .7642 L p .707 .577 .707 r
F P
0 g
s
.34549 .69661 m .34811 .73474 L .32695 .73343 L p .707 .577 .707 r
F P
0 g
s
.32695 .73343 m .32434 .69531 L .34549 .69661 L p .707 .577 .707 r
F P
0 g
s
.15999 .75462 m .16186 .73791 L .1792 .7263 L p .707 .577 .707 r
F P
0 g
s
.37976 .25995 m .37976 .76184 L .36102 .77285 L p .707 .577 .707 r
F P
0 g
s
.37976 .76184 m .37976 .25995 L .41027 .25102 L p .707 .577 .707 r
F P
0 g
s
.18347 .74474 m .18085 .70661 L .20472 .70257 L p .707 .577 .707 r
F P
0 g
s
.31681 .62276 m .32491 .67984 L .29719 .68439 L p .707 .577 .707 r
F P
0 g
s
.1792 .7263 m .17733 .74301 L .15999 .75462 L p .707 .577 .707 r
F P
0 g
s
.20472 .70257 m .20733 .74069 L .18347 .74474 L p .707 .577 .707 r
F P
0 g
s
.29719 .68439 m .28908 .62731 L .31681 .62276 L p .707 .577 .707 r
F P
0 g
s
.22659 .63625 m .2347 .69333 L .20605 .69684 L p .707 .577 .707 r
F P
0 g
s
.20605 .69684 m .19795 .63976 L .22659 .63625 L p .707 .577 .707 r
F P
0 g
s
.61294 .25725 m .61294 .75914 L .57968 .75095 L p .707 .577 .707 r
F P
0 g
s
.57968 .75095 m .57968 .24907 L .61294 .25725 L p .707 .577 .707 r
F P
0 g
s
.34283 .74867 m .34097 .76538 L .32096 .75155 L p .707 .577 .707 r
F P
0 g
s
.32096 .75155 m .32282 .73484 L .34283 .74867 L p .707 .577 .707 r
F P
0 g
s
.32434 .69531 m .32695 .73343 L .29945 .73344 L p .707 .577 .707 r
F P
0 g
s
.29945 .73344 m .29684 .69531 L .32434 .69531 L p .707 .577 .707 r
F P
0 g
s
.73389 .68272 m .742 .63504 L .71091 .62805 L p .707 .577 .707 r
F P
0 g
s
.742 .63504 m .73389 .68272 L .7653 .68424 L p .707 .577 .707 r
F P
0 g
s
.7653 .68424 m .7734 .63657 L .742 .63504 L p .707 .577 .707 r
F P
0 g
s
.70281 .67572 m .71091 .62805 L .68319 .61627 L p .707 .577 .707 r
F P
0 g
s
.71091 .62805 m .70281 .67572 L .73389 .68272 L p .707 .577 .707 r
F P
0 g
s
.28908 .62731 m .29719 .68439 L .2661 .68903 L p .707 .577 .707 r
F P
0 g
s
.17733 .74301 m .1792 .7263 L .20393 .71859 L p .707 .577 .707 r
F P
0 g
s
.258 .63196 m .2661 .68903 L .2347 .69333 L p .707 .577 .707 r
F P
0 g
s
.2347 .69333 m .22659 .63625 L .258 .63196 L p .707 .577 .707 r
F P
0 g
s
.2661 .68903 m .258 .63196 L .28908 .62731 L p .707 .577 .707 r
F P
0 g
s
.7734 .63657 m .7653 .68424 L .79395 .68015 L p .707 .577 .707 r
F P
0 g
s
.79395 .68015 m .80205 .63247 L .7734 .63657 L p .707 .577 .707 r
F P
0 g
s
.20733 .74069 m .20472 .70257 L .23395 .69913 L p .707 .577 .707 r
F P
0 g
s
.23395 .69913 m .23657 .73726 L .20733 .74069 L p .707 .577 .707 r
F P
0 g
s
.67509 .66394 m .68319 .61627 L .66154 .60086 L p .707 .577 .707 r
F P
0 g
s
.68319 .61627 m .67509 .66394 L .70281 .67572 L p .707 .577 .707 r
F P
0 g
s
.20393 .71859 m .20207 .7353 L .17733 .74301 L p .707 .577 .707 r
F P
0 g
s
.29684 .69531 m .29945 .73344 L .26831 .73475 L p .707 .577 .707 r
F P
0 g
s
.26831 .73475 m .2657 .69663 L .29684 .69531 L p .707 .577 .707 r
F P
0 g
s
.41027 .75291 m .41027 .25102 L .44956 .24507 L p .707 .577 .707 r
F P
0 g
s
.41027 .25102 m .41027 .75291 L .37976 .76184 L p .707 .577 .707 r
F P
0 g
s
.32282 .73484 m .32096 .75155 L .29428 .74079 L p .707 .577 .707 r
F P
0 g
s
.29428 .74079 m .29614 .72408 L .32282 .73484 L p .707 .577 .707 r
F P
0 g
s
.23657 .73726 m .23395 .69913 L .2657 .69663 L p .707 .577 .707 r
F P
0 g
s
.80205 .63247 m .79395 .68015 L .81704 .67083 L p .707 .577 .707 r
F P
0 g
s
.81704 .67083 m .82514 .62316 L .80205 .63247 L p .707 .577 .707 r
F P
0 g
s
.2657 .69663 m .26831 .73475 L .23657 .73726 L p .707 .577 .707 r
F P
0 g
s
.73645 .74086 m .73458 .72173 L .70385 .72444 L p .707 .577 .707 r
F P
0 g
s
.73458 .72173 m .73645 .74086 L .76822 .73772 L p .707 .577 .707 r
F P
0 g
s
.76822 .73772 m .76636 .71859 L .73458 .72173 L p .707 .577 .707 r
F P
0 g
s
.70385 .72444 m .70572 .74357 L .73645 .74086 L p .707 .577 .707 r
F P
0 g
s
.20207 .7353 m .20393 .71859 L .23364 .71553 L p .707 .577 .707 r
F P
0 g
s
.57968 .24907 m .57968 .75095 L .53862 .74593 L p .707 .577 .707 r
F P
0 g
s
.53862 .74593 m .53862 .24404 L .57968 .24907 L p .707 .577 .707 r
F P
0 g
s
.76636 .71859 m .76822 .73772 L .79793 .73445 L p .707 .577 .707 r
F P
0 g
s
.79793 .73445 m .79607 .71531 L .76636 .71859 L p .707 .577 .707 r
F P
0 g
s
.73169 .73078 m .7343 .69587 L .70316 .69108 L p .707 .577 .707 r
F P
0 g
s
.7343 .69587 m .73169 .73078 L .76343 .73146 L p .707 .577 .707 r
F P
0 g
s
.76343 .73146 m .76604 .69655 L .7343 .69587 L p .707 .577 .707 r
F P
0 g
s
.76604 .69655 m .76343 .73146 L .79267 .72796 L p .707 .577 .707 r
F P
0 g
s
.79267 .72796 m .79528 .69305 L .76604 .69655 L p .707 .577 .707 r
F P
0 g
s
.70572 .74357 m .70385 .72444 L .67718 .72645 L p .707 .577 .707 r
F P
0 g
s
.70054 .72599 m .70316 .69108 L .67566 .68265 L p .707 .577 .707 r
F P
0 g
s
.70316 .69108 m .70054 .72599 L .73169 .73078 L p .707 .577 .707 r
F P
0 g
s
.67718 .72645 m .67904 .74558 L .70572 .74357 L p .707 .577 .707 r
F P
0 g
s
.65344 .64853 m .66154 .60086 L .64809 .58332 L p .707 .577 .707 r
F P
0 g
s
.66154 .60086 m .65344 .64853 L .67509 .66394 L p .707 .577 .707 r
F P
0 g
s
.29614 .72408 m .29428 .74079 L .26355 .73413 L p .707 .577 .707 r
F P
0 g
s
.26355 .73413 m .26541 .71742 L .29614 .72408 L p .707 .577 .707 r
F P
0 g
s
.23364 .71553 m .23178 .73224 L .20207 .7353 L p .707 .577 .707 r
F P
0 g
s
.23178 .73224 m .23364 .71553 L .26541 .71742 L p .707 .577 .707 r
F P
0 g
s
.79607 .71531 m .79793 .73445 L .82266 .73137 L p .707 .577 .707 r
F P
0 g
s
.82266 .73137 m .8208 .71223 L .79607 .71531 L p .707 .577 .707 r
F P
0 g
s
.26541 .71742 m .26355 .73413 L .23178 .73224 L p .707 .577 .707 r
F P
0 g
s
.44956 .74696 m .44956 .24507 L .49379 .24266 L p .707 .577 .707 r
F P
0 g
s
.44956 .24507 m .44956 .74696 L .41027 .75291 L p .707 .577 .707 r
F P
0 g
s
.82514 .62316 m .81704 .67083 L .8323 .65721 L p .707 .577 .707 r
F P
0 g
s
.8323 .65721 m .84041 .60954 L .82514 .62316 L p .707 .577 .707 r
F P
0 g
s
.79528 .69305 m .79267 .72796 L .81653 .72062 L p .707 .577 .707 r
F P
0 g
s
.81653 .72062 m .81914 .68571 L .79528 .69305 L p .707 .577 .707 r
F P
0 g
s
.53862 .24404 m .53862 .74593 L .49379 .74455 L p .707 .577 .707 r
F P
0 g
s
.49379 .74455 m .49379 .24266 L .53862 .24404 L p .707 .577 .707 r
F P
0 g
s
.67305 .71755 m .67566 .68265 L .6545 .6714 L p .707 .577 .707 r
F P
0 g
s
.67566 .68265 m .67305 .71755 L .70054 .72599 L p .707 .577 .707 r
F P
0 g
s
.49379 .24266 m .49379 .74455 L .44956 .74696 L p .707 .577 .707 r
F P
0 g
s
.67904 .74558 m .67718 .72645 L .65717 .72756 L p .707 .577 .707 r
F P
0 g
s
.65717 .72756 m .65903 .74669 L .67904 .74558 L p .707 .577 .707 r
F P
0 g
s
.63998 .63099 m .64809 .58332 L .64415 .56538 L p .707 .577 .707 r
F P
0 g
s
.64809 .58332 m .63998 .63099 L .65344 .64853 L p .707 .577 .707 r
F P
0 g
s
.8208 .71223 m .82266 .73137 L .84 .72878 L p .707 .577 .707 r
F P
0 g
s
.84 .72878 m .83814 .70965 L .8208 .71223 L p .707 .577 .707 r
F P
0 g
s
.6545 .6714 m .65189 .7063 L .67305 .71755 L p .707 .577 .707 r
F P
0 g
s
.81914 .68571 m .81653 .72062 L .83269 .71017 L p .707 .577 .707 r
F P
0 g
s
.83269 .71017 m .8353 .67526 L .81914 .68571 L p .707 .577 .707 r
F P
0 g
s
.84041 .60954 m .8323 .65721 L .83826 .64062 L p .707 .577 .707 r
F P
0 g
s
.83826 .64062 m .84636 .59294 L .84041 .60954 L p .707 .577 .707 r
F P
0 g
s
.65189 .7063 m .6545 .6714 L .64176 .65843 L p .707 .577 .707 r
F P
0 g
s
.65903 .74669 m .65717 .72756 L .64578 .72766 L p .707 .577 .707 r
F P
0 g
s
.64578 .72766 m .64764 .7468 L .65903 .74669 L p .707 .577 .707 r
F P
0 g
s
.64415 .56538 m .63604 .61305 L .63998 .63099 L p .707 .577 .707 r
F P
0 g
s
.63604 .61305 m .64415 .56538 L .6501 .54878 L p .707 .577 .707 r
F P
0 g
s
.64176 .65843 m .63914 .69333 L .65189 .7063 L p .707 .577 .707 r
F P
0 g
s
.83814 .70965 m .84 .72878 L .84825 .72694 L p .707 .577 .707 r
F P
0 g
s
.84825 .72694 m .84639 .70781 L .83814 .70965 L p .707 .577 .707 r
F P
0 g
s
.8353 .67526 m .83269 .71017 L .83956 .69762 L p .707 .577 .707 r
F P
0 g
s
.83956 .69762 m .84218 .66271 L .8353 .67526 L p .707 .577 .707 r
F P
0 g
s
.84636 .59294 m .83826 .64062 L .83432 .62267 L p .707 .577 .707 r
F P
0 g
s
.83432 .62267 m .84242 .575 L .84636 .59294 L p .707 .577 .707 r
F P
0 g
s
.63914 .69333 m .64176 .65843 L .63867 .64502 L p .707 .577 .707 r
F P
0 g
s
.64764 .7468 m .64578 .72766 L .64413 .72675 L p .707 .577 .707 r
F P
0 g
s
.64413 .72675 m .64599 .74588 L .64764 .7468 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.642 .59646 m .6501 .54878 L .66537 .53516 L p .707 .577 .707 r
F P
0 g
s
.6501 .54878 m .642 .59646 L .63604 .61305 L p .707 .577 .707 r
F P
0 g
s
.63867 .64502 m .63606 .67992 L .63914 .69333 L p .707 .577 .707 r
F P
0 g
s
.84639 .70781 m .84825 .72694 L .8466 .72603 L p .707 .577 .707 r
F P
0 g
s
.8466 .72603 m .84474 .7069 L .84639 .70781 L p .707 .577 .707 r
F P
0 g
s
.84218 .66271 m .83956 .69762 L .83648 .6842 L p .707 .577 .707 r
F P
0 g
s
.83648 .6842 m .83909 .6493 L .84218 .66271 L p .707 .577 .707 r
F P
0 g
s
.84242 .575 m .83432 .62267 L .82086 .60514 L p .707 .577 .707 r
F P
0 g
s
.82086 .60514 m .82897 .55746 L .84242 .575 L p .707 .577 .707 r
F P
0 g
s
.63606 .67992 m .63867 .64502 L .64554 .63247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.66537 .53516 m .65727 .58284 L .642 .59646 L p .707 .577 .707 r
F P
0 g
s
.65727 .58284 m .66537 .53516 L .68846 .52585 L p .707 .577 .707 r
F P
0 g
s
.3859 .60399 m .40412 .5497 L .37443 .53906 L p .707 .577 .707 r
F P
0 g
s
.40412 .5497 m .3859 .60399 L .41605 .61349 L p .707 .577 .707 r
F P
0 g
s
.41605 .61349 m .43427 .5592 L .40412 .5497 L p .707 .577 .707 r
F P
0 g
s
.64599 .74588 m .64413 .72675 L .65238 .72491 L p .707 .577 .707 r
F P
0 g
s
.65238 .72491 m .65424 .74404 L .64599 .74588 L p .707 .577 .707 r
F P
0 g
s
.64554 .63247 m .64293 .66737 L .63606 .67992 L p .707 .577 .707 r
F P
0 g
s
.43427 .5592 m .41605 .61349 L .44371 .62092 L p .707 .577 .707 r
F P
0 g
s
.44371 .62092 m .46193 .56663 L .43427 .5592 L p .707 .577 .707 r
F P
0 g
s
.3562 .59335 m .37443 .53906 L .34809 .52832 L p .707 .577 .707 r
F P
0 g
s
.37443 .53906 m .3562 .59335 L .3859 .60399 L p .707 .577 .707 r
F P
0 g
s
.82897 .55746 m .82086 .60514 L .79921 .58972 L p .707 .577 .707 r
F P
0 g
s
.79921 .58972 m .80732 .54205 L .82897 .55746 L p .707 .577 .707 r
F P
0 g
s
.83909 .6493 m .83648 .6842 L .82373 .67124 L p .707 .577 .707 r
F P
0 g
s
.82373 .67124 m .82634 .63633 L .83909 .6493 L p .707 .577 .707 r
F P
0 g
s
.84474 .7069 m .8466 .72603 L .83522 .72613 L p .707 .577 .707 r
F P
0 g
s
.83522 .72613 m .83335 .707 L .84474 .7069 L p .707 .577 .707 r
F P
0 g
s
.34809 .52832 m .32987 .58261 L .3562 .59335 L p .707 .577 .707 r
F P
0 g
s
.64293 .66737 m .64554 .63247 L .6617 .62201 L p .707 .577 .707 r
F P
0 g
s
.3853 .67361 m .39134 .63641 L .36054 .63019 L p .707 .577 .707 r
F P
0 g
s
.39134 .63641 m .3853 .67361 L .41673 .67791 L p .707 .577 .707 r
F P
0 g
s
.41673 .67791 m .42278 .6407 L .39134 .63641 L p .707 .577 .707 r
F P
0 g
s
.46193 .56663 m .44371 .62092 L .46616 .62555 L p .707 .577 .707 r
F P
0 g
s
.46616 .62555 m .48438 .57127 L .46193 .56663 L p .707 .577 .707 r
F P
0 g
s
.68035 .57352 m .68846 .52585 L .71711 .52175 L p .707 .577 .707 r
F P
0 g
s
.68846 .52585 m .68035 .57352 L .65727 .58284 L p .707 .577 .707 r
F P
0 g
s
.32987 .58261 m .34809 .52832 L .3277 .51853 L p .707 .577 .707 r
F P
0 g
s
.42278 .6407 m .41673 .67791 L .44572 .67986 L p .707 .577 .707 r
F P
0 g
s
.44572 .67986 m .45177 .64266 L .42278 .6407 L p .707 .577 .707 r
F P
0 g
s
.3545 .66739 m .36054 .63019 L .33339 .62266 L p .707 .577 .707 r
F P
0 g
s
.36054 .63019 m .3545 .66739 L .3853 .67361 L p .707 .577 .707 r
F P
0 g
s
.80732 .54205 m .79921 .58972 L .77149 .57794 L p .707 .577 .707 r
F P
0 g
s
.77149 .57794 m .7796 .53027 L .80732 .54205 L p .707 .577 .707 r
F P
0 g
s
.3277 .51853 m .30947 .57282 L .32987 .58261 L p .707 .577 .707 r
F P
0 g
s
.33339 .62266 m .32735 .65986 L .3545 .66739 L p .707 .577 .707 r
F P
0 g
s
.6617 .62201 m .65909 .65692 L .64293 .66737 L p .707 .577 .707 r
F P
0 g
s
.709 .56943 m .71711 .52175 L .74851 .52328 L p .707 .577 .707 r
F P
0 g
s
.71711 .52175 m .709 .56943 L .68035 .57352 L p .707 .577 .707 r
F P
0 g
s
.65424 .74404 m .65238 .72491 L .66972 .72233 L p .707 .577 .707 r
F P
0 g
s
.66972 .72233 m .67158 .74146 L .65424 .74404 L p .707 .577 .707 r
F P
0 g
s
.45177 .64266 m .44572 .67986 L .46943 .67928 L p .707 .577 .707 r
F P
0 g
s
.46943 .67928 m .47547 .64208 L .45177 .64266 L p .707 .577 .707 r
F P
0 g
s
.7796 .53027 m .77149 .57794 L .74041 .57095 L p .707 .577 .707 r
F P
0 g
s
.74041 .57095 m .74851 .52328 L .7796 .53027 L p .707 .577 .707 r
F P
0 g
s
.82634 .63633 m .82373 .67124 L .80257 .65999 L p .707 .577 .707 r
F P
0 g
s
.80257 .65999 m .80518 .62508 L .82634 .63633 L p .707 .577 .707 r
F P
0 g
s
.74851 .52328 m .74041 .57095 L .709 .56943 L p .707 .577 .707 r
F P
0 g
s
.32735 .65986 m .33339 .62266 L .31254 .61456 L p .707 .577 .707 r
F P
0 g
s
.48438 .57127 m .46616 .62555 L .4812 .62694 L p .707 .577 .707 r
F P
0 g
s
.4812 .62694 m .49943 .57265 L .48438 .57127 L p .707 .577 .707 r
F P
0 g
s
.83335 .707 m .83522 .72613 L .8152 .72724 L p .707 .577 .707 r
F P
0 g
s
.8152 .72724 m .81334 .70811 L .83335 .707 L p .707 .577 .707 r
F P
0 g
s
.65909 .65692 m .6617 .62201 L .68556 .61468 L p .707 .577 .707 r
F P
0 g
s
.30947 .57282 m .3277 .51853 L .31524 .51066 L p .707 .577 .707 r
F P
0 g
s
.43317 .72466 m .42881 .70715 L .3977 .71439 L p .707 .577 .707 r
F P
0 g
s
.42881 .70715 m .43317 .72466 L .46235 .71436 L p .707 .577 .707 r
F P
0 g
s
.46235 .71436 m .458 .69685 L .42881 .70715 L p .707 .577 .707 r
F P
0 g
s
.40206 .7319 m .3977 .71439 L .36771 .71785 L p .707 .577 .707 r
F P
0 g
s
.3977 .71439 m .40206 .7319 L .43317 .72466 L p .707 .577 .707 r
F P
0 g
s
.31254 .61456 m .3065 .65176 L .32735 .65986 L p .707 .577 .707 r
F P
0 g
s
.31524 .51066 m .29702 .56495 L .30947 .57282 L p .707 .577 .707 r
F P
0 g
s
.36771 .71785 m .37207 .73536 L .40206 .7319 L p .707 .577 .707 r
F P
0 g
s
.458 .69685 m .46235 .71436 L .48675 .702 L p .707 .577 .707 r
F P
0 g
s
.48675 .702 m .48239 .68449 L .458 .69685 L p .707 .577 .707 r
F P
0 g
s
.37207 .73536 m .36771 .71785 L .34177 .7172 L p .707 .577 .707 r
F P
0 g
s
.47547 .64208 m .46943 .67928 L .48554 .67623 L p .707 .577 .707 r
F P
0 g
s
.48554 .67623 m .49158 .63903 L .47547 .64208 L p .707 .577 .707 r
F P
0 g
s
.68556 .61468 m .68295 .64958 L .65909 .65692 L p .707 .577 .707 r
F P
0 g
s
.80518 .62508 m .80257 .65999 L .77508 .65155 L p .707 .577 .707 r
F P
0 g
s
.77508 .65155 m .77769 .61665 L .80518 .62508 L p .707 .577 .707 r
F P
0 g
s
.67158 .74146 m .66972 .72233 L .69445 .71925 L p .707 .577 .707 r
F P
0 g
s
.69445 .71925 m .69632 .73838 L .67158 .74146 L p .707 .577 .707 r
F P
0 g
s
.68295 .64958 m .68556 .61468 L .7148 .61118 L p .707 .577 .707 r
F P
0 g
s
.3065 .65176 m .31254 .61456 L .30004 .60667 L p .707 .577 .707 r
F P
0 g
s
.34177 .7172 m .34613 .73471 L .37207 .73536 L p .707 .577 .707 r
F P
0 g
s
.81334 .70811 m .8152 .72724 L .78853 .72925 L p .707 .577 .707 r
F P
0 g
s
.78853 .72925 m .78667 .71012 L .81334 .70811 L p .707 .577 .707 r
F P
0 g
s
.48239 .68449 m .48675 .702 L .50397 .68879 L p .707 .577 .707 r
F P
0 g
s
.50397 .68879 m .49962 .67128 L .48239 .68449 L p .707 .577 .707 r
F P
0 g
s
.49943 .57265 m .4812 .62694 L .48738 .62494 L p .707 .577 .707 r
F P
0 g
s
.48738 .62494 m .5056 .57065 L .49943 .57265 L p .707 .577 .707 r
F P
0 g
s
.30004 .60667 m .294 .64387 L .3065 .65176 L p .707 .577 .707 r
F P
0 g
s
.29702 .56495 m .31524 .51066 L .31193 .50547 L p .707 .577 .707 r
F P
0 g
s
.77769 .61665 m .77508 .65155 L .74393 .64676 L p .707 .577 .707 r
F P
0 g
s
.74393 .64676 m .74654 .61186 L .77769 .61665 L p .707 .577 .707 r
F P
0 g
s
.71219 .64608 m .7148 .61118 L .74654 .61186 L p .707 .577 .707 r
F P
0 g
s
.7148 .61118 m .71219 .64608 L .68295 .64958 L p .707 .577 .707 r
F P
0 g
s
.34613 .73471 m .34177 .7172 L .32243 .7125 L p .707 .577 .707 r
F P
0 g
s
.31193 .50547 m .29371 .55975 L .29702 .56495 L p .707 .577 .707 r
F P
0 g
s
.74654 .61186 m .74393 .64676 L .71219 .64608 L p .707 .577 .707 r
F P
0 g
s
.69632 .73838 m .69445 .71925 L .72416 .71597 L p .707 .577 .707 r
F P
0 g
s
.72416 .71597 m .72603 .7351 L .69632 .73838 L p .707 .577 .707 r
F P
0 g
s
.32243 .7125 m .32678 .73001 L .34613 .73471 L p .707 .577 .707 r
F P
0 g
s
.78667 .71012 m .78853 .72925 L .7578 .73196 L p .707 .577 .707 r
F P
0 g
s
.7578 .73196 m .75594 .71283 L .78667 .71012 L p .707 .577 .707 r
F P
0 g
s
.49158 .63903 m .48554 .67623 L .49246 .671 L p .707 .577 .707 r
F P
0 g
s
.49246 .671 m .49851 .6338 L .49158 .63903 L p .707 .577 .707 r
F P
0 g
s
.294 .64387 m .30004 .60667 L .29711 .59977 L p .707 .577 .707 r
F P
0 g
s
.72603 .7351 m .72416 .71597 L .75594 .71283 L p .707 .577 .707 r
F P
0 g
s
.75594 .71283 m .7578 .73196 L .72603 .7351 L p .707 .577 .707 r
F P
0 g
s
.49962 .67128 m .50397 .68879 L .51234 .67603 L p .707 .577 .707 r
F P
0 g
s
.51234 .67603 m .50798 .65852 L .49962 .67128 L p .707 .577 .707 r
F P
0 g
s
.29711 .59977 m .29107 .63698 L .294 .64387 L p .707 .577 .707 r
F P
0 g
s
.32678 .73001 m .32243 .7125 L .31156 .70421 L p .707 .577 .707 r
F P
0 g
s
.5056 .57065 m .48738 .62494 L .48408 .61974 L p .707 .577 .707 r
F P
0 g
s
.48408 .61974 m .5023 .56546 L .5056 .57065 L p .707 .577 .707 r
F P
0 g
s
.29371 .55975 m .31193 .50547 L .31811 .50346 L p .707 .577 .707 r
F P
0 g
s
.31156 .70421 m .31592 .72172 L .32678 .73001 L p .707 .577 .707 r
F P
0 g
s
.31811 .50346 m .29989 .55775 L .29371 .55975 L p .707 .577 .707 r
F P
0 g
s
.49851 .6338 m .49246 .671 L .48953 .6641 L p .707 .577 .707 r
F P
0 g
s
.48953 .6641 m .49557 .6269 L .49851 .6338 L p .707 .577 .707 r
F P
0 g
s
.50798 .65852 m .51234 .67603 L .51102 .66496 L p .707 .577 .707 r
F P
0 g
s
.51102 .66496 m .50667 .64745 L .50798 .65852 L p .707 .577 .707 r
F P
0 g
s
.29107 .63698 m .29711 .59977 L .30403 .59454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31592 .72172 m .31156 .70421 L .31025 .69314 L p .707 .577 .707 r
F P
0 g
s
.30403 .59454 m .29799 .63175 L .29107 .63698 L p .707 .577 .707 r
F P
0 g
s
.5023 .56546 m .48408 .61974 L .47162 .61187 L p .707 .577 .707 r
F P
0 g
s
.47162 .61187 m .48984 .55758 L .5023 .56546 L p .707 .577 .707 r
F P
0 g
s
.29989 .55775 m .31811 .50346 L .33315 .50485 L p .707 .577 .707 r
F P
0 g
s
.31025 .69314 m .31461 .71065 L .31592 .72172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.33315 .50485 m .31493 .55913 L .29989 .55775 L p .707 .577 .707 r
F P
0 g
s
.49557 .6269 m .48953 .6641 L .47703 .65622 L p .707 .577 .707 r
F P
0 g
s
.47703 .65622 m .48307 .61901 L .49557 .6269 L p .707 .577 .707 r
F P
0 g
s
.50667 .64745 m .51102 .66496 L .50016 .65667 L p .707 .577 .707 r
F P
0 g
s
.50016 .65667 m .49581 .63916 L .50667 .64745 L p .707 .577 .707 r
F P
0 g
s
.29799 .63175 m .30403 .59454 L .32014 .59149 L p .707 .577 .707 r
F P
0 g
s
.31461 .71065 m .31025 .69314 L .31862 .68038 L p .707 .577 .707 r
F P
0 g
s
.32014 .59149 m .3141 .62869 L .29799 .63175 L p .707 .577 .707 r
F P
0 g
s
.48984 .55758 m .47162 .61187 L .45122 .60208 L p .707 .577 .707 r
F P
0 g
s
.45122 .60208 m .46944 .54779 L .48984 .55758 L p .707 .577 .707 r
F P
0 g
s
.31493 .55913 m .33315 .50485 L .35561 .50948 L p .707 .577 .707 r
F P
0 g
s
.31862 .68038 m .32297 .69789 L .31461 .71065 L p .707 .577 .707 r
F P
0 g
s
.35561 .50948 m .33738 .56377 L .31493 .55913 L p .707 .577 .707 r
F P
0 g
s
.48307 .61901 m .47703 .65622 L .45618 .64811 L p .707 .577 .707 r
F P
0 g
s
.45618 .64811 m .46223 .61091 L .48307 .61901 L p .707 .577 .707 r
F P
0 g
s
.49581 .63916 m .50016 .65667 L .48082 .65198 L p .707 .577 .707 r
F P
0 g
s
.48082 .65198 m .47646 .63447 L .49581 .63916 L p .707 .577 .707 r
F P
0 g
s
.3141 .62869 m .32014 .59149 L .34385 .59091 L p .707 .577 .707 r
F P
0 g
s
.46944 .54779 m .45122 .60208 L .42489 .59134 L p .707 .577 .707 r
F P
0 g
s
.42489 .59134 m .44311 .53706 L .46944 .54779 L p .707 .577 .707 r
F P
0 g
s
.33738 .56377 m .35561 .50948 L .38326 .51691 L p .707 .577 .707 r
F P
0 g
s
.32297 .69789 m .31862 .68038 L .33584 .66718 L p .707 .577 .707 r
F P
0 g
s
.34385 .59091 m .3378 .62811 L .3141 .62869 L p .707 .577 .707 r
F P
0 g
s
.38326 .51691 m .36504 .5712 L .33738 .56377 L p .707 .577 .707 r
F P
0 g
s
.33584 .66718 m .3402 .68469 L .32297 .69789 L p .707 .577 .707 r
F P
0 g
s
.46223 .61091 m .45618 .64811 L .42903 .64058 L p .707 .577 .707 r
F P
0 g
s
.42903 .64058 m .43507 .60338 L .46223 .61091 L p .707 .577 .707 r
F P
0 g
s
.44311 .53706 m .42489 .59134 L .39519 .5807 L p .707 .577 .707 r
F P
0 g
s
.39519 .5807 m .41341 .52641 L .44311 .53706 L p .707 .577 .707 r
F P
0 g
s
.36504 .5712 m .38326 .51691 L .41341 .52641 L p .707 .577 .707 r
F P
0 g
s
.3378 .62811 m .34385 .59091 L .37284 .59287 L p .707 .577 .707 r
F P
0 g
s
.41341 .52641 m .39519 .5807 L .36504 .5712 L p .707 .577 .707 r
F P
0 g
s
.47646 .63447 m .48082 .65198 L .45488 .65133 L p .707 .577 .707 r
F P
0 g
s
.45488 .65133 m .45052 .63382 L .47646 .63447 L p .707 .577 .707 r
F P
0 g
s
.37284 .59287 m .36679 .63007 L .3378 .62811 L p .707 .577 .707 r
F P
0 g
s
.3402 .68469 m .33584 .66718 L .36024 .65482 L p .707 .577 .707 r
F P
0 g
s
.43507 .60338 m .42903 .64058 L .39823 .63437 L p .707 .577 .707 r
F P
0 g
s
.39823 .63437 m .40427 .59716 L .43507 .60338 L p .707 .577 .707 r
F P
0 g
s
.36679 .63007 m .37284 .59287 L .40427 .59716 L p .707 .577 .707 r
F P
0 g
s
.36024 .65482 m .36459 .67233 L .3402 .68469 L p .707 .577 .707 r
F P
0 g
s
.40427 .59716 m .39823 .63437 L .36679 .63007 L p .707 .577 .707 r
F P
0 g
s
.45052 .63382 m .45488 .65133 L .42489 .65479 L p .707 .577 .707 r
F P
0 g
s
.42489 .65479 m .42053 .63728 L .45052 .63382 L p .707 .577 .707 r
F P
0 g
s
.36459 .67233 m .36024 .65482 L .38942 .64451 L p .707 .577 .707 r
F P
0 g
s
.38942 .64451 m .39378 .66203 L .36459 .67233 L p .707 .577 .707 r
F P
0 g
s
.42053 .63728 m .42489 .65479 L .39378 .66203 L p .707 .577 .707 r
F P
0 g
s
.39378 .66203 m .38942 .64451 L .42053 .63728 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP000080
07Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF1000L7oo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001^Ool006]oo`8000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006aoo`00JGoo0`00
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JWoo001WOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00IWoo00<005YFFUH0
0UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol:0003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol00`00FUH00003
FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Egoo
00<005YF00000eYF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP@000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000@Ool?0016
Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF000;Ool50003FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP002Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0`00?goo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001goo0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00?Goo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH4
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00P00
>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH000Aoo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF009JEP8003Uoo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009oo`800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Moo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00H005YFFUH007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH3000eOol005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000d
Ool005Aoo`03FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00<Woo001COol0
1000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0;goo001COol20002FUH50003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000`Ool005Aoo`05001JEUYFFUH00003FUH50007FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002mo
o`00EGoo0P001eYF00<005YFFUH010000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000_Ool005Moo`03001JEUYF00AJEP03001J
EUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00=JEP03001JEUYF00@000Ioo`L000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005Qoo`8000AJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEP@0015oo`@0009JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FWoo0P0000=JEP00FUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF
FUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH0
0`00FUH00003000IOol40006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005ao
o`<000MJEP03001JEUYF00IJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP80025o
o`8000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00Ggoo0P001EYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00Oomo
o`0SOol300000eYF001JEP05FUH00`00FUIJEP02FUH2000/Ool0065oo`<00003FUH005YF00MJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000015YF001JEP009goo0P001UYF00L005YFFUIJ
EP00FUH0000/Ool005UooaH000QJEP<000MJEP03001JEUYF00AJEP06001JEUYF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10000UYF00<007ooOol09goo00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000=JEP04001JEP000005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001oogoo01=oo`<0015oo`05
001JEUYFFUH00004FUH00`00FUH0000/Ool005Aoo`<000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00@000=JEP<00003FUH005YF00EJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<007ooOol04Goo
1@004Goo0P0000=JEP00FUH00eYF00<005YF0000;7oo001DOol00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH20006FUH01000FUIJEUYF
0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF0P00
4Woo1@004goo0P0015YF00<005YF0000;7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050004FUH01P00FUIJEP00FUH000aJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000EJEP03001JEP00015oo`D001Aoo`03
001JEUYF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEP8000Ioo`T0
0004Ool00000000FOol01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40003FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH6
0004FUH00`00FUIJEP02FUH9000BOol01@00FUH005YF0000;Goo001COol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000<
Ool01@00FUH005YF0000;Goo001<Ool800000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030008Ool300000eYF001o
o`0/Ool004=oo`T000AJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`80009JEP03001JEP0002eoo`00?Goo1P0015YF
00<005YFFUH015YF1@0000AJEP00FUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH500001eYF001JEUYF001JEP0002eoo`00>Goo100000=JEP00FUH0
1EYF2@0015YF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00800004FUH005YFFUH2000^
Ool003Aoo`D000AJEPP000AJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPP000IJEP03001JEUYF00h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000^Ool002moo`D0
0003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@000]J
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF0000000^Ool002]oo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEPH0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002ioo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEPl000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH0
0`00FUIJEP030003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003FUH00`00FUH00008FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUH000030007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH300000eYF001JEP06FUH30007FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP04FUH2
0003FUH400000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004
FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF0P0000=JEP00
FUH01eYF00<005YFFUH0100000=JEP00FUH01UYF00<005YFFUH015YF00D005YF000005YF0080009J
EP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0009JEP80009J
EP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP05FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF0`001eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YF000025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH005YF0P0015YF00@005YF000000IJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUH000001eYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUIJEP<00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30003FUH700000eYF00000003FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH40002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00EJEP<0009J
EPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000=JEP@000=JEPD0
0003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool01@00FUH005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0`0015YF00<005YFFUH015YF
200015YF00<005YFFUH015YF00<005YFFUH01@0000EJEP00FUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8000AJEP04001JEUYF0005FUH00`00FUH000040006FUH50004
FUH00`00FUIJEP05FUH01000FUH000001Woo00D005YF001JEP0002eoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P001EYF00D005YF000007oo008000AJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH>0002FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH0
1000FUIJEUYF0P000eYF00D005YFFUIJEP00009oo`@0009JEP@000EJEP03001JEUYF009JEPD000Mo
o`D002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2`001EYF0P000goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF0P0025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
0P0015YF00<005YFFUH00eYF0P000UYF00@005YFFUH000Iooa0000Yoo`8000=JEP8002ioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1`002Goo0P0015YF
00<007ooOol00goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01EYF0`001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YF00000`000UYF00<007ooOol06goo0`0015YF0P00;Woo000]Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000?Ool01@00FUIJEP00FUH00P001Woo
0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YFFUH00eYF1P0067oo0P000UYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6000;Ool90002FUH40006Ool20004FUH01000FUIJ
EUYF0`000UYF00<005YFFUH025YF00@005YFFUIJEP8000EJEP04001JEP00000;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH90009Ool60004FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<005YF00000UYF7P00
15YF00D005YFFUIJEP00009JEP80009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00QJEP04001J
EP000007FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Goo1@001Goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00T005YFFUIJEP00FUH005YF00001EYF00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01eYF0`0000=JEP00FUH01UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00<Woo1@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03
001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP80009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03001JEUYF008000AJEP03
001JEUYF00IJEP04001JEUYFFUH30008FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000E000/Ool002ioo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000000015YF
00<005YFFUH00P0015YF00<005YFFUH01UYF100000=JEP00FUH025YF0`001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP04001JEUYF0007
FUH00`00FUIJEP05FUH00`00FUIJEP090004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF0000;7oo000/Ool30004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF
00L005YFFUIJEP00FUH00002FUH90004FUH00`00FUH000060006FUH00`00FUIJEP05FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001EYF
0`001eYF00<005YFFUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002aoo`00;7oo00<005YF000015YF00<005YFFUH00UYF1P0015YF00<005YFFUH00UYF
2@001EYF00L005YFFUIJEP00FUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH000IJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;7oo00<005YF000015YF1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00@005YFFUH000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000[
Ool002aoo`03001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000002FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH01000FUIJEUYF3P00:goo000/Ool00`00FUH00002FUH20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH:000]Ool002aoo`03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00AJEP`000=JEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF
1`00=goo000]Ool20003FUH00`00FUIJEP03FUH600000eYF000000080004FUH40002FUH00`00FUIJ
EP05FUH30002FUH01000FUIJEUYF2P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH01000
FUIJEUYF4@000eYF2@00?Woo000]Ool20003FUH00`00FUH0000;0008FUH00`00FUIJEP06FUH40006
FUH01P00FUIJEP00FUH000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP000UYF1P001UYF00<005YFFUH00UYF2@00Agoo000/Ool00`00FUH00003FUH70006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP80009JEP@000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF2000D7oo000/Ool20002FUH3
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF
001JEP04FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH90009FUH01000FUIJEUYF
30001EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH03`0000=JEP000000E7oo000[Ool0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20005FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP060006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP080007FUH00`00FUIJEP03FUH01000FUIJEP00
2Woo10000UYF00<007ooOol0DWoo000[Ool01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF0P000Woo0P0015YF00<0
05YFFUH015YF1P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF1@000UYF00<0
05YFFUH00eYF00@005YFFUH000Qoo`8000AJEP<005Aoo`00:goo0P0000=oo`0000001@000eYF00<0
05YFFUH015YF00<005YFFUH00UYF4P001goo0P0000IJEP00FUIJEP00Ool20004FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP02FUH30005FUH01000FUIJEP001Woo0P0000=JEP00FUH00eYF00<005YF0000E7oo000[Ool20008
Ool?000KOol20002FUH01000Ool0000015YF100025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00@005YFFUH000Aoo`8000=JEP03
001JEUYF009JEP04001JEP00001COol002]oo`8003=oo`04001JEUYFFUH30002FUH20003FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300001UYF001JEUYF001oo`<000EJEP03001JEUYF009JEP04001JEUYF001COol002]o
o`8003Aoo`03001JEUYF00D000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP800003FUH005YF
00EJEP03001JEUYF009JEP04001JEUYF001COol002]oo`<001Yoo`<001Moo`03001JEP0000<000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00=J
EP8005Aoo`00:goo0`006Goo1@005Woo00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00E7oo000[Ool01000FUIJEP00
67oo1@005goo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH00UYF00<007ooOol0Dgoo000[Ool01@00FUIJEUYF00005goo1@0067oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00D005YF
FUIJEP0005Ioo`00:goo00@005YFFUIJEP<001Ioo`<001Qoo`<00003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP04001JEP00001GOol002aoo`04001JEUYF
0002FUH00`00Oomoo`0^Ool200000goo00000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH2001IOol002aoo`03001JEP0000AJEP8002eoo`04001JEP00Ool20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00Oomoo`1HOol0
02eoo`8000IJEP8002Yoo`800004FUH007ooOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020007
FUH01000FUIJEUYF0P00Fgoo000^Ool00`00FUIJEP04FUH01000FUH000009Woo0P0000=JEP000000
1Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF1@001eYF00@005YF000005eoo`00;goo0P0015YF00@005YFFUIJ
EP8002=oo`04001JEUYFFUH20007Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH01000FUH000000eYF1000
Ggoo000aOol01000FUIJEP001UYF10007Goo0P0015YF00<007ooOol027oo10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`0015YF00@0
05YFFUIJEP<006=oo`00<Woo0`001eYF00<005YFFUH010005Goo100000=JEP00FUH00eYF00<007oo
Ool037oo10000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`001EYF00<005YFFUH01EYF0`00H7oo000dOol20006FUH00`00FUIJEP04FUH70009
Ool50005FUH00`00FUIJEP02000COol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH;0002FUH00`00FUIJEP06FUH01000FUH00000GWoo000fOol20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH3000JOol60003FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0?0002Ool40006FUH00`00FUIJEP02FUH2001LOol003Qoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80029ooal00004FUH000000006
Ool50006Ool20004FUH00`00FUIJEP03FUH3001JOol003]oo`<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH2000gOol20006FUH00`00FUIJEP05FUH6000017oo000000002Goo0P00
00=JEP00FUH01EYF00@005YFFUH005Uoo`00?Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003]oo`@00003FUH005YF00QJEP03001JEUYF009JEPH000Uoo`<000AJEP05001JEUYF
FUH0001IOol0049ooaH0045oo`<000QJEP03001JEUYF00IJEP03001JEP0000<000Qoo`<00003FUH0
05YF009JEP8005Qoo`00W7oo0`0015YF00<005YFFUH01eYF00<005YFFUH00eYF3@000UYF00<005YF
0000F7oo002OOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP8005Uoo`00XWoo10001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00
FGoo002VOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001J
Ool00:Yoo`H000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Yoo`00/7oo20000eYF
00<005YFFUH01000Fgoo002hOol6001OOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63496 .75157 m .61674 .70145 L .58659 .71204 L p .707 .577 .707 r
F P
0 g
s
.61674 .70145 m .63496 .75157 L .66261 .73787 L p .707 .577 .707 r
F P
0 g
s
.66261 .73787 m .64439 .68774 L .61674 .70145 L p .707 .577 .707 r
F P
0 g
s
.60481 .76216 m .58659 .71204 L .55689 .71847 L p .707 .577 .707 r
F P
0 g
s
.58659 .71204 m .60481 .76216 L .63496 .75157 L p .707 .577 .707 r
F P
0 g
s
.64439 .68774 m .66261 .73787 L .68506 .72238 L p .707 .577 .707 r
F P
0 g
s
.68506 .72238 m .66684 .67226 L .64439 .68774 L p .707 .577 .707 r
F P
0 g
s
.57511 .76859 m .55689 .71847 L .53056 .72012 L p .707 .577 .707 r
F P
0 g
s
.55689 .71847 m .57511 .76859 L .60481 .76216 L p .707 .577 .707 r
F P
0 g
s
.60177 .81655 m .59573 .78073 L .56493 .78302 L p .707 .577 .707 r
F P
0 g
s
.59573 .78073 m .60177 .81655 L .6332 .81085 L p .707 .577 .707 r
F P
0 g
s
.6332 .81085 m .62716 .77503 L .59573 .78073 L p .707 .577 .707 r
F P
0 g
s
.66684 .67226 m .68506 .72238 L .70011 .70663 L p .707 .577 .707 r
F P
0 g
s
.70011 .70663 m .68189 .65651 L .66684 .67226 L p .707 .577 .707 r
F P
0 g
s
.62716 .77503 m .6332 .81085 L .66219 .80228 L p .707 .577 .707 r
F P
0 g
s
.66219 .80228 m .65615 .76647 L .62716 .77503 L p .707 .577 .707 r
F P
0 g
s
.54878 .77024 m .53056 .72012 L .51016 .71682 L p .707 .577 .707 r
F P
0 g
s
.53056 .72012 m .54878 .77024 L .57511 .76859 L p .707 .577 .707 r
F P
0 g
s
.57511 .84148 m .57947 .82305 L .54947 .81465 L p .707 .577 .707 r
F P
0 g
s
.57947 .82305 m .57511 .84148 L .60622 .84835 L p .707 .577 .707 r
F P
0 g
s
.60622 .84835 m .61058 .82992 L .57947 .82305 L p .707 .577 .707 r
F P
0 g
s
.57097 .81884 m .56493 .78302 L .53777 .78166 L p .707 .577 .707 r
F P
0 g
s
.56493 .78302 m .57097 .81884 L .60177 .81655 L p .707 .577 .707 r
F P
0 g
s
.61058 .82992 m .60622 .84835 L .6354 .85303 L p .707 .577 .707 r
F P
0 g
s
.6354 .85303 m .63976 .8346 L .61058 .82992 L p .707 .577 .707 r
F P
0 g
s
.54947 .81465 m .54512 .83308 L .57511 .84148 L p .707 .577 .707 r
F P
0 g
s
.65615 .76647 m .66219 .80228 L .6859 .7917 L p .707 .577 .707 r
F P
0 g
s
.6859 .7917 m .67986 .75588 L .65615 .76647 L p .707 .577 .707 r
F P
0 g
s
.54512 .83308 m .54947 .81465 L .52353 .80556 L p .707 .577 .707 r
F P
0 g
s
.52353 .80556 m .51918 .82399 L .54512 .83308 L p .707 .577 .707 r
F P
0 g
s
.53777 .78166 m .54381 .81748 L .57097 .81884 L p .707 .577 .707 r
F P
0 g
s
.63976 .8346 m .6354 .85303 L .6598 .85505 L p .707 .577 .707 r
F P
0 g
s
.6598 .85505 m .66415 .83662 L .63976 .8346 L p .707 .577 .707 r
F P
0 g
s
.68189 .65651 m .70011 .70663 L .70629 .69217 L p .707 .577 .707 r
F P
0 g
s
.70629 .69217 m .68806 .64204 L .68189 .65651 L p .707 .577 .707 r
F P
0 g
s
.54381 .81748 m .53777 .78166 L .51692 .77679 L p .707 .577 .707 r
F P
0 g
s
.51016 .71682 m .52838 .76694 L .54878 .77024 L p .707 .577 .707 r
F P
0 g
s
.52838 .76694 m .51016 .71682 L .4977 .70889 L p .707 .577 .707 r
F P
0 g
s
.67986 .75588 m .6859 .7917 L .702 .78012 L p .707 .577 .707 r
F P
0 g
s
.702 .78012 m .69596 .7443 L .67986 .75588 L p .707 .577 .707 r
F P
0 g
s
.51918 .82399 m .52353 .80556 L .50419 .79665 L p .707 .577 .707 r
F P
0 g
s
.50419 .79665 m .49983 .81508 L .51918 .82399 L p .707 .577 .707 r
F P
0 g
s
.51692 .77679 m .52297 .81261 L .54381 .81748 L p .707 .577 .707 r
F P
0 g
s
.66415 .83662 m .6598 .85505 L .67702 .85422 L p .707 .577 .707 r
F P
0 g
s
.67702 .85422 m .68138 .83579 L .66415 .83662 L p .707 .577 .707 r
F P
0 g
s
.52297 .81261 m .51692 .77679 L .50442 .76889 L p .707 .577 .707 r
F P
0 g
s
.4977 .70889 m .51592 .75902 L .52838 .76694 L p .707 .577 .707 r
F P
0 g
s
.68806 .64204 m .70629 .69217 L .70298 .68039 L p .707 .577 .707 r
F P
0 g
s
.70298 .68039 m .68476 .63027 L .68806 .64204 L p .707 .577 .707 r
F P
0 g
s
.49983 .81508 m .50419 .79665 L .49333 .7888 L p .707 .577 .707 r
F P
0 g
s
.69596 .7443 m .702 .78012 L .70893 .7687 L p .707 .577 .707 r
F P
0 g
s
.70893 .7687 m .70289 .73288 L .69596 .7443 L p .707 .577 .707 r
F P
0 g
s
.51592 .75902 m .4977 .70889 L .4944 .69712 L p .707 .577 .707 r
F P
0 g
s
.49333 .7888 m .48897 .80723 L .49983 .81508 L p .707 .577 .707 r
F P
0 g
s
.50442 .76889 m .51047 .8047 L .52297 .81261 L p .707 .577 .707 r
F P
0 g
s
.68138 .83579 m .67702 .85422 L .68539 .85063 L p .707 .577 .707 r
F P
0 g
s
.68539 .85063 m .68974 .83219 L .68138 .83579 L p .707 .577 .707 r
F P
0 g
s
.51047 .8047 m .50442 .76889 L .50149 .75872 L p .707 .577 .707 r
F P
0 g
s
.4944 .69712 m .51262 .74725 L .51592 .75902 L p .707 .577 .707 r
F P
0 g
s
.51262 .74725 m .4944 .69712 L .50057 .68265 L p .707 .577 .707 r
F P
0 g
s
.50149 .75872 m .50754 .79454 L .51047 .8047 L p .707 .577 .707 r
F P
0 g
s
.50754 .79454 m .50149 .75872 L .50842 .7473 L p .707 .577 .707 r
F P
0 g
s
.50057 .68265 m .51879 .73278 L .51262 .74725 L p .707 .577 .707 r
F P
0 g
s
.51879 .73278 m .50057 .68265 L .51562 .66691 L p .707 .577 .707 r
F P
0 g
s
.50842 .7473 m .51446 .78311 L .50754 .79454 L p .707 .577 .707 r
F P
0 g
s
.51446 .78311 m .50842 .7473 L .52452 .73572 L p .707 .577 .707 r
F P
0 g
s
.52452 .73572 m .53057 .77154 L .51446 .78311 L p .707 .577 .707 r
F P
0 g
s
.49603 .79762 m .50038 .77919 L .5176 .77836 L p .707 .577 .707 r
F P
0 g
s
.5176 .77836 m .51325 .79679 L .49603 .79762 L p .707 .577 .707 r
F P
0 g
s
.50621 .82189 m .50621 .32 L .46137 .31862 L p .707 .577 .707 r
F P
0 g
s
.51562 .66691 m .53384 .71703 L .51879 .73278 L p .707 .577 .707 r
F P
0 g
s
.53384 .71703 m .51562 .66691 L .53807 .65142 L p .707 .577 .707 r
F P
0 g
s
.53807 .65142 m .55629 .70154 L .53384 .71703 L p .707 .577 .707 r
F P
0 g
s
.53057 .77154 m .52452 .73572 L .54823 .72513 L p .707 .577 .707 r
F P
0 g
s
.51325 .79679 m .5176 .77836 L .542 .78038 L p .707 .577 .707 r
F P
0 g
s
.54823 .72513 m .55427 .76095 L .53057 .77154 L p .707 .577 .707 r
F P
0 g
s
.542 .78038 m .53765 .79882 L .51325 .79679 L p .707 .577 .707 r
F P
0 g
s
.53765 .79882 m .542 .78038 L .57118 .78506 L p .707 .577 .707 r
F P
0 g
s
.57118 .78506 m .56683 .80349 L .53765 .79882 L p .707 .577 .707 r
F P
0 g
s
.50621 .32 m .50621 .82189 L .55044 .81948 L p .707 .577 .707 r
F P
0 g
s
.55629 .70154 m .53807 .65142 L .56572 .63771 L p .707 .577 .707 r
F P
0 g
s
.55427 .76095 m .54823 .72513 L .57722 .71657 L p .707 .577 .707 r
F P
0 g
s
.55044 .81948 m .55044 .31759 L .50621 .32 L p .707 .577 .707 r
F P
0 g
s
.68476 .63027 m .70298 .68039 L .69052 .67247 L p .707 .577 .707 r
F P
0 g
s
.69052 .67247 m .6723 .62235 L .68476 .63027 L p .707 .577 .707 r
F P
0 g
s
.46137 .82051 m .46137 .31862 L .42032 .31359 L p .707 .577 .707 r
F P
0 g
s
.48897 .80723 m .49333 .7888 L .49201 .78279 L p .707 .577 .707 r
F P
0 g
s
.49201 .78279 m .48766 .80122 L .48897 .80723 L p .707 .577 .707 r
F P
0 g
s
.48766 .80122 m .49201 .78279 L .50038 .77919 L p .707 .577 .707 r
F P
0 g
s
.50038 .77919 m .49603 .79762 L .48766 .80122 L p .707 .577 .707 r
F P
0 g
s
.46137 .31862 m .46137 .82051 L .50621 .82189 L p .707 .577 .707 r
F P
0 g
s
.70289 .73288 m .70893 .7687 L .706 .75853 L p .707 .577 .707 r
F P
0 g
s
.706 .75853 m .69996 .72271 L .70289 .73288 L p .707 .577 .707 r
F P
0 g
s
.58395 .68784 m .56572 .63771 L .59588 .62713 L p .707 .577 .707 r
F P
0 g
s
.56572 .63771 m .58395 .68784 L .55629 .70154 L p .707 .577 .707 r
F P
0 g
s
.58326 .75239 m .57722 .71657 L .60865 .71087 L p .707 .577 .707 r
F P
0 g
s
.57722 .71657 m .58326 .75239 L .55427 .76095 L p .707 .577 .707 r
F P
0 g
s
.60865 .71087 m .6147 .74669 L .58326 .75239 L p .707 .577 .707 r
F P
0 g
s
.56683 .80349 m .57118 .78506 L .60229 .79193 L p .707 .577 .707 r
F P
0 g
s
.60229 .79193 m .59794 .81037 L .56683 .80349 L p .707 .577 .707 r
F P
0 g
s
.55044 .31759 m .55044 .81948 L .58973 .81352 L p .707 .577 .707 r
F P
0 g
s
.59588 .62713 m .6141 .67725 L .58395 .68784 L p .707 .577 .707 r
F P
0 g
s
.58973 .81352 m .58973 .31163 L .55044 .31759 L p .707 .577 .707 r
F P
0 g
s
.42032 .81548 m .42032 .31359 L .38706 .30541 L p .707 .577 .707 r
F P
0 g
s
.42032 .31359 m .42032 .81548 L .46137 .82051 L p .707 .577 .707 r
F P
0 g
s
.68974 .83219 m .68539 .85063 L .68408 .84461 L p .707 .577 .707 r
F P
0 g
s
.68408 .84461 m .68843 .82618 L .68974 .83219 L p .707 .577 .707 r
F P
0 g
s
.6141 .67725 m .59588 .62713 L .62557 .62069 L p .707 .577 .707 r
F P
0 g
s
.63946 .70858 m .6455 .7444 L .6147 .74669 L p .707 .577 .707 r
F P
0 g
s
.6147 .74669 m .60865 .71087 L .63946 .70858 L p .707 .577 .707 r
F P
0 g
s
.63229 .80033 m .62793 .81876 L .59794 .81037 L p .707 .577 .707 r
F P
0 g
s
.59794 .81037 m .60229 .79193 L .63229 .80033 L p .707 .577 .707 r
F P
0 g
s
.58973 .31163 m .58973 .81352 L .62024 .8046 L p .707 .577 .707 r
F P
0 g
s
.62557 .62069 m .64379 .67082 L .6141 .67725 L p .707 .577 .707 r
F P
0 g
s
.62024 .8046 m .62024 .30271 L .58973 .31163 L p .707 .577 .707 r
F P
0 g
s
.6723 .62235 m .69052 .67247 L .67013 .66917 L p .707 .577 .707 r
F P
0 g
s
.67013 .66917 m .65191 .61905 L .6723 .62235 L p .707 .577 .707 r
F P
0 g
s
.2204 .62931 m .22851 .68639 L .25959 .68174 L p .707 .577 .707 r
F P
0 g
s
.25959 .68174 m .25149 .62466 L .2204 .62931 L p .707 .577 .707 r
F P
0 g
s
.25149 .62466 m .25959 .68174 L .291 .67745 L p .707 .577 .707 r
F P
0 g
s
.69996 .72271 m .706 .75853 L .6935 .75063 L p .707 .577 .707 r
F P
0 g
s
.6935 .75063 m .68746 .71481 L .69996 .72271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.291 .67745 m .28289 .62037 L .25149 .62466 L p .707 .577 .707 r
F P
0 g
s
.28289 .62037 m .291 .67745 L .31964 .67393 L p .707 .577 .707 r
F P
0 g
s
.19268 .63386 m .20078 .69094 L .22851 .68639 L p .707 .577 .707 r
F P
0 g
s
.22851 .68639 m .2204 .62931 L .19268 .63386 L p .707 .577 .707 r
F P
0 g
s
.31964 .67393 m .31154 .61685 L .28289 .62037 L p .707 .577 .707 r
F P
0 g
s
.25607 .75893 m .25346 .7208 L .22231 .72212 L p .707 .577 .707 r
F P
0 g
s
.25346 .7208 m .25607 .75893 L .28781 .75643 L p .707 .577 .707 r
F P
0 g
s
.28781 .75643 m .2852 .7183 L .25346 .7208 L p .707 .577 .707 r
F P
0 g
s
.38706 .8073 m .38706 .30541 L .36486 .29486 L p .707 .577 .707 r
F P
0 g
s
.38706 .30541 m .38706 .8073 L .42032 .81548 L p .707 .577 .707 r
F P
0 g
s
.2852 .7183 m .28781 .75643 L .31705 .75299 L p .707 .577 .707 r
F P
0 g
s
.31705 .75299 m .31443 .71486 L .2852 .7183 L p .707 .577 .707 r
F P
0 g
s
.31154 .61685 m .31964 .67393 L .34273 .67154 L p .707 .577 .707 r
F P
0 g
s
.68843 .82618 m .68408 .84461 L .67322 .83676 L p .707 .577 .707 r
F P
0 g
s
.67322 .83676 m .67757 .81833 L .68843 .82618 L p .707 .577 .707 r
F P
0 g
s
.22231 .72212 m .22492 .76025 L .25607 .75893 L p .707 .577 .707 r
F P
0 g
s
.34273 .67154 m .33463 .61446 L .31154 .61685 L p .707 .577 .707 r
F P
0 g
s
.17103 .63787 m .17914 .69495 L .20078 .69094 L p .707 .577 .707 r
F P
0 g
s
.20078 .69094 m .19268 .63386 L .17103 .63787 L p .707 .577 .707 r
F P
0 g
s
.65191 .61905 m .67013 .66917 L .64379 .67082 L p .707 .577 .707 r
F P
0 g
s
.64379 .67082 m .62557 .62069 L .65191 .61905 L p .707 .577 .707 r
F P
0 g
s
.22492 .76025 m .22231 .72212 L .19482 .72213 L p .707 .577 .707 r
F P
0 g
s
.19482 .72213 m .19743 .76025 L .22492 .76025 L p .707 .577 .707 r
F P
0 g
s
.62024 .30271 m .62024 .8046 L .63898 .79358 L p .707 .577 .707 r
F P
0 g
s
.63898 .79358 m .63898 .29169 L .62024 .30271 L p .707 .577 .707 r
F P
0 g
s
.68746 .71481 m .6935 .75063 L .67265 .74576 L p .707 .577 .707 r
F P
0 g
s
.67265 .74576 m .66661 .70994 L .68746 .71481 L p .707 .577 .707 r
F P
0 g
s
.31443 .71486 m .31705 .75299 L .34091 .74895 L p .707 .577 .707 r
F P
0 g
s
.34091 .74895 m .3383 .71082 L .31443 .71486 L p .707 .577 .707 r
F P
0 g
s
.19743 .76025 m .19482 .72213 L .17366 .72082 L p .707 .577 .707 r
F P
0 g
s
.33463 .61446 m .34273 .67154 L .358 .6705 L p .707 .577 .707 r
F P
0 g
s
.358 .6705 m .3499 .61342 L .33463 .61446 L p .707 .577 .707 r
F P
0 g
s
.17366 .72082 m .17627 .75894 L .19743 .76025 L p .707 .577 .707 r
F P
0 g
s
.15758 .64094 m .16568 .69802 L .17914 .69495 L p .707 .577 .707 r
F P
0 g
s
.17914 .69495 m .17103 .63787 L .15758 .64094 L p .707 .577 .707 r
F P
0 g
s
.67757 .81833 m .67322 .83676 L .65387 .82786 L p .707 .577 .707 r
F P
0 g
s
.65387 .82786 m .65822 .80943 L .67757 .81833 L p .707 .577 .707 r
F P
0 g
s
.3383 .71082 m .34091 .74895 L .35707 .7447 L p .707 .577 .707 r
F P
0 g
s
.35707 .7447 m .35446 .70658 L .3383 .71082 L p .707 .577 .707 r
F P
0 g
s
.66661 .70994 m .67265 .74576 L .6455 .7444 L p .707 .577 .707 r
F P
0 g
s
.6455 .7444 m .63946 .70858 L .66661 .70994 L p .707 .577 .707 r
F P
0 g
s
.2422 .83147 m .24406 .81476 L .21333 .80811 L p .707 .577 .707 r
F P
0 g
s
.24406 .81476 m .2422 .83147 L .27397 .83336 L p .707 .577 .707 r
F P
0 g
s
.27397 .83336 m .27584 .81665 L .24406 .81476 L p .707 .577 .707 r
F P
0 g
s
.3499 .61342 m .358 .6705 L .36396 .67092 L p .707 .577 .707 r
F P
0 g
s
.36396 .67092 m .35585 .61384 L .3499 .61342 L p .707 .577 .707 r
F P
0 g
s
.35446 .70658 m .35707 .7447 L .36394 .74066 L p .707 .577 .707 r
F P
0 g
s
.36394 .74066 m .36133 .70254 L .35446 .70658 L p .707 .577 .707 r
F P
0 g
s
.35585 .61384 m .36396 .67092 L .36001 .67276 L p .707 .577 .707 r
F P
0 g
s
.36133 .70254 m .36394 .74066 L .36085 .73723 L p .707 .577 .707 r
F P
0 g
s
.36486 .79675 m .36486 .29486 L .35589 .283 L p .707 .577 .707 r
F P
0 g
s
.36486 .29486 m .36486 .79675 L .38706 .8073 L p .707 .577 .707 r
F P
0 g
s
.27584 .81665 m .27397 .83336 L .30368 .8303 L p .707 .577 .707 r
F P
0 g
s
.30368 .8303 m .30554 .81359 L .27584 .81665 L p .707 .577 .707 r
F P
0 g
s
.21147 .82482 m .21333 .80811 L .18666 .79734 L p .707 .577 .707 r
F P
0 g
s
.21333 .80811 m .21147 .82482 L .2422 .83147 L p .707 .577 .707 r
F P
0 g
s
.17627 .75894 m .17366 .72082 L .16091 .71833 L p .707 .577 .707 r
F P
0 g
s
.63898 .29169 m .63898 .79358 L .64411 .78155 L p .707 .577 .707 r
F P
0 g
s
.64411 .78155 m .64411 .27966 L .63898 .29169 L p .707 .577 .707 r
F P
0 g
s
.16091 .71833 m .16352 .75645 L .17627 .75894 L p .707 .577 .707 r
F P
0 g
s
.30554 .81359 m .30368 .8303 L .32842 .82259 L p .707 .577 .707 r
F P
0 g
s
.32842 .82259 m .33028 .80588 L .30554 .81359 L p .707 .577 .707 r
F P
0 g
s
.18666 .79734 m .18479 .81405 L .21147 .82482 L p .707 .577 .707 r
F P
0 g
s
.65822 .80943 m .65387 .82786 L .62793 .81876 L p .707 .577 .707 r
F P
0 g
s
.62793 .81876 m .63229 .80033 L .65822 .80943 L p .707 .577 .707 r
F P
0 g
s
.15363 .64277 m .16174 .69985 L .16568 .69802 L p .707 .577 .707 r
F P
0 g
s
.16568 .69802 m .15758 .64094 L .15363 .64277 L p .707 .577 .707 r
F P
0 g
s
.18479 .81405 m .18666 .79734 L .16665 .78352 L p .707 .577 .707 r
F P
0 g
s
.16665 .78352 m .16478 .80023 L .18479 .81405 L p .707 .577 .707 r
F P
0 g
s
.33028 .80588 m .32842 .82259 L .34576 .81099 L p .707 .577 .707 r
F P
0 g
s
.34576 .81099 m .34762 .79428 L .33028 .80588 L p .707 .577 .707 r
F P
0 g
s
.16352 .75645 m .16091 .71833 L .15782 .7149 L p .707 .577 .707 r
F P
0 g
s
.16478 .80023 m .16665 .78352 L .15526 .76799 L p .707 .577 .707 r
F P
0 g
s
.15782 .7149 m .16043 .75302 L .16352 .75645 L p .707 .577 .707 r
F P
0 g
s
.36001 .67276 m .35191 .61568 L .35585 .61384 L p .707 .577 .707 r
F P
0 g
s
.36085 .73723 m .35824 .69911 L .36133 .70254 L p .707 .577 .707 r
F P
0 g
s
.35191 .61568 m .36001 .67276 L .34656 .67583 L p .707 .577 .707 r
F P
0 g
s
.35824 .69911 m .36085 .73723 L .34811 .73474 L p .707 .577 .707 r
F P
0 g
s
.34811 .73474 m .34549 .69661 L .35824 .69911 L p .707 .577 .707 r
F P
0 g
s
.35589 .283 m .35589 .78489 L .36486 .79675 L p .707 .577 .707 r
F P
0 g
s
.35589 .78489 m .35589 .283 L .36102 .27097 L p .707 .577 .707 r
F P
0 g
s
.15526 .76799 m .15339 .7847 L .16478 .80023 L p .707 .577 .707 r
F P
0 g
s
.15959 .64319 m .16769 .70027 L .16174 .69985 L p .707 .577 .707 r
F P
0 g
s
.16174 .69985 m .15363 .64277 L .15959 .64319 L p .707 .577 .707 r
F P
0 g
s
.64411 .27966 m .64411 .78155 L .63514 .76968 L p .707 .577 .707 r
F P
0 g
s
.63514 .76968 m .63514 .26779 L .64411 .27966 L p .707 .577 .707 r
F P
0 g
s
.34762 .79428 m .34576 .81099 L .35401 .79662 L p .707 .577 .707 r
F P
0 g
s
.35401 .79662 m .35587 .77992 L .34762 .79428 L p .707 .577 .707 r
F P
0 g
s
.15339 .7847 m .15526 .76799 L .15361 .75227 L p .707 .577 .707 r
F P
0 g
s
.16043 .75302 m .15782 .7149 L .16469 .71086 L p .707 .577 .707 r
F P
0 g
s
.16469 .71086 m .16731 .74898 L .16043 .75302 L p .707 .577 .707 r
F P
0 g
s
.15361 .75227 m .15174 .76898 L .15339 .7847 L p .707 .577 .707 r
F P
0 g
s
.34656 .67583 m .33845 .61875 L .35191 .61568 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17486 .64215 m .18296 .69923 L .16769 .70027 L p .707 .577 .707 r
F P
0 g
s
.16769 .70027 m .15959 .64319 L .17486 .64215 L p .707 .577 .707 r
F P
0 g
s
.35587 .77992 m .35401 .79662 L .35236 .78091 L p .707 .577 .707 r
F P
0 g
s
.35236 .78091 m .35422 .7642 L .35587 .77992 L p .707 .577 .707 r
F P
0 g
s
.36102 .77285 m .36102 .27097 L .37976 .25995 L p .707 .577 .707 r
F P
0 g
s
.36102 .27097 m .36102 .77285 L .35589 .78489 L p .707 .577 .707 r
F P
0 g
s
.15174 .76898 m .15361 .75227 L .16186 .73791 L p .707 .577 .707 r
F P
0 g
s
.63514 .26779 m .63514 .76968 L .61294 .75914 L p .707 .577 .707 r
F P
0 g
s
.61294 .75914 m .61294 .25725 L .63514 .26779 L p .707 .577 .707 r
F P
0 g
s
.16731 .74898 m .16469 .71086 L .18085 .70661 L p .707 .577 .707 r
F P
0 g
s
.16186 .73791 m .15999 .75462 L .15174 .76898 L p .707 .577 .707 r
F P
0 g
s
.18085 .70661 m .18347 .74474 L .16731 .74898 L p .707 .577 .707 r
F P
0 g
s
.33845 .61875 m .34656 .67583 L .32491 .67984 L p .707 .577 .707 r
F P
0 g
s
.32491 .67984 m .31681 .62276 L .33845 .61875 L p .707 .577 .707 r
F P
0 g
s
.19795 .63976 m .20605 .69684 L .18296 .69923 L p .707 .577 .707 r
F P
0 g
s
.18296 .69923 m .17486 .64215 L .19795 .63976 L p .707 .577 .707 r
F P
0 g
s
.35422 .7642 m .35236 .78091 L .34097 .76538 L p .707 .577 .707 r
F P
0 g
s
.34097 .76538 m .34283 .74867 L .35422 .7642 L p .707 .577 .707 r
F P
0 g
s
.34549 .69661 m .34811 .73474 L .32695 .73343 L p .707 .577 .707 r
F P
0 g
s
.32695 .73343 m .32434 .69531 L .34549 .69661 L p .707 .577 .707 r
F P
0 g
s
.15999 .75462 m .16186 .73791 L .1792 .7263 L p .707 .577 .707 r
F P
0 g
s
.37976 .25995 m .37976 .76184 L .36102 .77285 L p .707 .577 .707 r
F P
0 g
s
.37976 .76184 m .37976 .25995 L .41027 .25102 L p .707 .577 .707 r
F P
0 g
s
.18347 .74474 m .18085 .70661 L .20472 .70257 L p .707 .577 .707 r
F P
0 g
s
.31681 .62276 m .32491 .67984 L .29719 .68439 L p .707 .577 .707 r
F P
0 g
s
.1792 .7263 m .17733 .74301 L .15999 .75462 L p .707 .577 .707 r
F P
0 g
s
.20472 .70257 m .20733 .74069 L .18347 .74474 L p .707 .577 .707 r
F P
0 g
s
.29719 .68439 m .28908 .62731 L .31681 .62276 L p .707 .577 .707 r
F P
0 g
s
.22659 .63625 m .2347 .69333 L .20605 .69684 L p .707 .577 .707 r
F P
0 g
s
.20605 .69684 m .19795 .63976 L .22659 .63625 L p .707 .577 .707 r
F P
0 g
s
.61294 .25725 m .61294 .75914 L .57968 .75095 L p .707 .577 .707 r
F P
0 g
s
.57968 .75095 m .57968 .24907 L .61294 .25725 L p .707 .577 .707 r
F P
0 g
s
.34283 .74867 m .34097 .76538 L .32096 .75155 L p .707 .577 .707 r
F P
0 g
s
.32096 .75155 m .32282 .73484 L .34283 .74867 L p .707 .577 .707 r
F P
0 g
s
.32434 .69531 m .32695 .73343 L .29945 .73344 L p .707 .577 .707 r
F P
0 g
s
.29945 .73344 m .29684 .69531 L .32434 .69531 L p .707 .577 .707 r
F P
0 g
s
.73389 .68272 m .742 .63504 L .71091 .62805 L p .707 .577 .707 r
F P
0 g
s
.742 .63504 m .73389 .68272 L .7653 .68424 L p .707 .577 .707 r
F P
0 g
s
.7653 .68424 m .7734 .63657 L .742 .63504 L p .707 .577 .707 r
F P
0 g
s
.70281 .67572 m .71091 .62805 L .68319 .61627 L p .707 .577 .707 r
F P
0 g
s
.71091 .62805 m .70281 .67572 L .73389 .68272 L p .707 .577 .707 r
F P
0 g
s
.28908 .62731 m .29719 .68439 L .2661 .68903 L p .707 .577 .707 r
F P
0 g
s
.17733 .74301 m .1792 .7263 L .20393 .71859 L p .707 .577 .707 r
F P
0 g
s
.258 .63196 m .2661 .68903 L .2347 .69333 L p .707 .577 .707 r
F P
0 g
s
.2347 .69333 m .22659 .63625 L .258 .63196 L p .707 .577 .707 r
F P
0 g
s
.2661 .68903 m .258 .63196 L .28908 .62731 L p .707 .577 .707 r
F P
0 g
s
.7734 .63657 m .7653 .68424 L .79395 .68015 L p .707 .577 .707 r
F P
0 g
s
.79395 .68015 m .80205 .63247 L .7734 .63657 L p .707 .577 .707 r
F P
0 g
s
.20733 .74069 m .20472 .70257 L .23395 .69913 L p .707 .577 .707 r
F P
0 g
s
.23395 .69913 m .23657 .73726 L .20733 .74069 L p .707 .577 .707 r
F P
0 g
s
.67509 .66394 m .68319 .61627 L .66154 .60086 L p .707 .577 .707 r
F P
0 g
s
.68319 .61627 m .67509 .66394 L .70281 .67572 L p .707 .577 .707 r
F P
0 g
s
.20393 .71859 m .20207 .7353 L .17733 .74301 L p .707 .577 .707 r
F P
0 g
s
.29684 .69531 m .29945 .73344 L .26831 .73475 L p .707 .577 .707 r
F P
0 g
s
.26831 .73475 m .2657 .69663 L .29684 .69531 L p .707 .577 .707 r
F P
0 g
s
.41027 .75291 m .41027 .25102 L .44956 .24507 L p .707 .577 .707 r
F P
0 g
s
.41027 .25102 m .41027 .75291 L .37976 .76184 L p .707 .577 .707 r
F P
0 g
s
.32282 .73484 m .32096 .75155 L .29428 .74079 L p .707 .577 .707 r
F P
0 g
s
.29428 .74079 m .29614 .72408 L .32282 .73484 L p .707 .577 .707 r
F P
0 g
s
.23657 .73726 m .23395 .69913 L .2657 .69663 L p .707 .577 .707 r
F P
0 g
s
.80205 .63247 m .79395 .68015 L .81704 .67083 L p .707 .577 .707 r
F P
0 g
s
.81704 .67083 m .82514 .62316 L .80205 .63247 L p .707 .577 .707 r
F P
0 g
s
.2657 .69663 m .26831 .73475 L .23657 .73726 L p .707 .577 .707 r
F P
0 g
s
.73645 .74086 m .73458 .72173 L .70385 .72444 L p .707 .577 .707 r
F P
0 g
s
.73458 .72173 m .73645 .74086 L .76822 .73772 L p .707 .577 .707 r
F P
0 g
s
.76822 .73772 m .76636 .71859 L .73458 .72173 L p .707 .577 .707 r
F P
0 g
s
.70385 .72444 m .70572 .74357 L .73645 .74086 L p .707 .577 .707 r
F P
0 g
s
.20207 .7353 m .20393 .71859 L .23364 .71553 L p .707 .577 .707 r
F P
0 g
s
.57968 .24907 m .57968 .75095 L .53862 .74593 L p .707 .577 .707 r
F P
0 g
s
.53862 .74593 m .53862 .24404 L .57968 .24907 L p .707 .577 .707 r
F P
0 g
s
.76636 .71859 m .76822 .73772 L .79793 .73445 L p .707 .577 .707 r
F P
0 g
s
.79793 .73445 m .79607 .71531 L .76636 .71859 L p .707 .577 .707 r
F P
0 g
s
.73169 .73078 m .7343 .69587 L .70316 .69108 L p .707 .577 .707 r
F P
0 g
s
.7343 .69587 m .73169 .73078 L .76343 .73146 L p .707 .577 .707 r
F P
0 g
s
.76343 .73146 m .76604 .69655 L .7343 .69587 L p .707 .577 .707 r
F P
0 g
s
.76604 .69655 m .76343 .73146 L .79267 .72796 L p .707 .577 .707 r
F P
0 g
s
.79267 .72796 m .79528 .69305 L .76604 .69655 L p .707 .577 .707 r
F P
0 g
s
.70572 .74357 m .70385 .72444 L .67718 .72645 L p .707 .577 .707 r
F P
0 g
s
.70054 .72599 m .70316 .69108 L .67566 .68265 L p .707 .577 .707 r
F P
0 g
s
.70316 .69108 m .70054 .72599 L .73169 .73078 L p .707 .577 .707 r
F P
0 g
s
.67718 .72645 m .67904 .74558 L .70572 .74357 L p .707 .577 .707 r
F P
0 g
s
.65344 .64853 m .66154 .60086 L .64809 .58332 L p .707 .577 .707 r
F P
0 g
s
.66154 .60086 m .65344 .64853 L .67509 .66394 L p .707 .577 .707 r
F P
0 g
s
.29614 .72408 m .29428 .74079 L .26355 .73413 L p .707 .577 .707 r
F P
0 g
s
.26355 .73413 m .26541 .71742 L .29614 .72408 L p .707 .577 .707 r
F P
0 g
s
.23364 .71553 m .23178 .73224 L .20207 .7353 L p .707 .577 .707 r
F P
0 g
s
.23178 .73224 m .23364 .71553 L .26541 .71742 L p .707 .577 .707 r
F P
0 g
s
.79607 .71531 m .79793 .73445 L .82266 .73137 L p .707 .577 .707 r
F P
0 g
s
.82266 .73137 m .8208 .71223 L .79607 .71531 L p .707 .577 .707 r
F P
0 g
s
.26541 .71742 m .26355 .73413 L .23178 .73224 L p .707 .577 .707 r
F P
0 g
s
.44956 .74696 m .44956 .24507 L .49379 .24266 L p .707 .577 .707 r
F P
0 g
s
.44956 .24507 m .44956 .74696 L .41027 .75291 L p .707 .577 .707 r
F P
0 g
s
.82514 .62316 m .81704 .67083 L .8323 .65721 L p .707 .577 .707 r
F P
0 g
s
.8323 .65721 m .84041 .60954 L .82514 .62316 L p .707 .577 .707 r
F P
0 g
s
.79528 .69305 m .79267 .72796 L .81653 .72062 L p .707 .577 .707 r
F P
0 g
s
.81653 .72062 m .81914 .68571 L .79528 .69305 L p .707 .577 .707 r
F P
0 g
s
.53862 .24404 m .53862 .74593 L .49379 .74455 L p .707 .577 .707 r
F P
0 g
s
.49379 .74455 m .49379 .24266 L .53862 .24404 L p .707 .577 .707 r
F P
0 g
s
.67305 .71755 m .67566 .68265 L .6545 .6714 L p .707 .577 .707 r
F P
0 g
s
.67566 .68265 m .67305 .71755 L .70054 .72599 L p .707 .577 .707 r
F P
0 g
s
.49379 .24266 m .49379 .74455 L .44956 .74696 L p .707 .577 .707 r
F P
0 g
s
.67904 .74558 m .67718 .72645 L .65717 .72756 L p .707 .577 .707 r
F P
0 g
s
.65717 .72756 m .65903 .74669 L .67904 .74558 L p .707 .577 .707 r
F P
0 g
s
.63998 .63099 m .64809 .58332 L .64415 .56538 L p .707 .577 .707 r
F P
0 g
s
.64809 .58332 m .63998 .63099 L .65344 .64853 L p .707 .577 .707 r
F P
0 g
s
.8208 .71223 m .82266 .73137 L .84 .72878 L p .707 .577 .707 r
F P
0 g
s
.84 .72878 m .83814 .70965 L .8208 .71223 L p .707 .577 .707 r
F P
0 g
s
.6545 .6714 m .65189 .7063 L .67305 .71755 L p .707 .577 .707 r
F P
0 g
s
.81914 .68571 m .81653 .72062 L .83269 .71017 L p .707 .577 .707 r
F P
0 g
s
.83269 .71017 m .8353 .67526 L .81914 .68571 L p .707 .577 .707 r
F P
0 g
s
.84041 .60954 m .8323 .65721 L .83826 .64062 L p .707 .577 .707 r
F P
0 g
s
.83826 .64062 m .84636 .59294 L .84041 .60954 L p .707 .577 .707 r
F P
0 g
s
.65189 .7063 m .6545 .6714 L .64176 .65843 L p .707 .577 .707 r
F P
0 g
s
.65903 .74669 m .65717 .72756 L .64578 .72766 L p .707 .577 .707 r
F P
0 g
s
.64578 .72766 m .64764 .7468 L .65903 .74669 L p .707 .577 .707 r
F P
0 g
s
.64415 .56538 m .63604 .61305 L .63998 .63099 L p .707 .577 .707 r
F P
0 g
s
.63604 .61305 m .64415 .56538 L .6501 .54878 L p .707 .577 .707 r
F P
0 g
s
.64176 .65843 m .63914 .69333 L .65189 .7063 L p .707 .577 .707 r
F P
0 g
s
.83814 .70965 m .84 .72878 L .84825 .72694 L p .707 .577 .707 r
F P
0 g
s
.84825 .72694 m .84639 .70781 L .83814 .70965 L p .707 .577 .707 r
F P
0 g
s
.8353 .67526 m .83269 .71017 L .83956 .69762 L p .707 .577 .707 r
F P
0 g
s
.83956 .69762 m .84218 .66271 L .8353 .67526 L p .707 .577 .707 r
F P
0 g
s
.84636 .59294 m .83826 .64062 L .83432 .62267 L p .707 .577 .707 r
F P
0 g
s
.83432 .62267 m .84242 .575 L .84636 .59294 L p .707 .577 .707 r
F P
0 g
s
.63914 .69333 m .64176 .65843 L .63867 .64502 L p .707 .577 .707 r
F P
0 g
s
.64764 .7468 m .64578 .72766 L .64413 .72675 L p .707 .577 .707 r
F P
0 g
s
.64413 .72675 m .64599 .74588 L .64764 .7468 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.642 .59646 m .6501 .54878 L .66537 .53516 L p .707 .577 .707 r
F P
0 g
s
.6501 .54878 m .642 .59646 L .63604 .61305 L p .707 .577 .707 r
F P
0 g
s
.63867 .64502 m .63606 .67992 L .63914 .69333 L p .707 .577 .707 r
F P
0 g
s
.84639 .70781 m .84825 .72694 L .8466 .72603 L p .707 .577 .707 r
F P
0 g
s
.8466 .72603 m .84474 .7069 L .84639 .70781 L p .707 .577 .707 r
F P
0 g
s
.84218 .66271 m .83956 .69762 L .83648 .6842 L p .707 .577 .707 r
F P
0 g
s
.83648 .6842 m .83909 .6493 L .84218 .66271 L p .707 .577 .707 r
F P
0 g
s
.84242 .575 m .83432 .62267 L .82086 .60514 L p .707 .577 .707 r
F P
0 g
s
.82086 .60514 m .82897 .55746 L .84242 .575 L p .707 .577 .707 r
F P
0 g
s
.63606 .67992 m .63867 .64502 L .64554 .63247 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.66537 .53516 m .65727 .58284 L .642 .59646 L p .707 .577 .707 r
F P
0 g
s
.65727 .58284 m .66537 .53516 L .68846 .52585 L p .707 .577 .707 r
F P
0 g
s
.3859 .60399 m .40412 .5497 L .37443 .53906 L p .707 .577 .707 r
F P
0 g
s
.40412 .5497 m .3859 .60399 L .41605 .61349 L p .707 .577 .707 r
F P
0 g
s
.41605 .61349 m .43427 .5592 L .40412 .5497 L p .707 .577 .707 r
F P
0 g
s
.64599 .74588 m .64413 .72675 L .65238 .72491 L p .707 .577 .707 r
F P
0 g
s
.65238 .72491 m .65424 .74404 L .64599 .74588 L p .707 .577 .707 r
F P
0 g
s
.64554 .63247 m .64293 .66737 L .63606 .67992 L p .707 .577 .707 r
F P
0 g
s
.43427 .5592 m .41605 .61349 L .44371 .62092 L p .707 .577 .707 r
F P
0 g
s
.44371 .62092 m .46193 .56663 L .43427 .5592 L p .707 .577 .707 r
F P
0 g
s
.3562 .59335 m .37443 .53906 L .34809 .52832 L p .707 .577 .707 r
F P
0 g
s
.37443 .53906 m .3562 .59335 L .3859 .60399 L p .707 .577 .707 r
F P
0 g
s
.82897 .55746 m .82086 .60514 L .79921 .58972 L p .707 .577 .707 r
F P
0 g
s
.79921 .58972 m .80732 .54205 L .82897 .55746 L p .707 .577 .707 r
F P
0 g
s
.83909 .6493 m .83648 .6842 L .82373 .67124 L p .707 .577 .707 r
F P
0 g
s
.82373 .67124 m .82634 .63633 L .83909 .6493 L p .707 .577 .707 r
F P
0 g
s
.84474 .7069 m .8466 .72603 L .83522 .72613 L p .707 .577 .707 r
F P
0 g
s
.83522 .72613 m .83335 .707 L .84474 .7069 L p .707 .577 .707 r
F P
0 g
s
.34809 .52832 m .32987 .58261 L .3562 .59335 L p .707 .577 .707 r
F P
0 g
s
.64293 .66737 m .64554 .63247 L .6617 .62201 L p .707 .577 .707 r
F P
0 g
s
.3853 .67361 m .39134 .63641 L .36054 .63019 L p .707 .577 .707 r
F P
0 g
s
.39134 .63641 m .3853 .67361 L .41673 .67791 L p .707 .577 .707 r
F P
0 g
s
.41673 .67791 m .42278 .6407 L .39134 .63641 L p .707 .577 .707 r
F P
0 g
s
.46193 .56663 m .44371 .62092 L .46616 .62555 L p .707 .577 .707 r
F P
0 g
s
.46616 .62555 m .48438 .57127 L .46193 .56663 L p .707 .577 .707 r
F P
0 g
s
.68035 .57352 m .68846 .52585 L .71711 .52175 L p .707 .577 .707 r
F P
0 g
s
.68846 .52585 m .68035 .57352 L .65727 .58284 L p .707 .577 .707 r
F P
0 g
s
.32987 .58261 m .34809 .52832 L .3277 .51853 L p .707 .577 .707 r
F P
0 g
s
.42278 .6407 m .41673 .67791 L .44572 .67986 L p .707 .577 .707 r
F P
0 g
s
.44572 .67986 m .45177 .64266 L .42278 .6407 L p .707 .577 .707 r
F P
0 g
s
.3545 .66739 m .36054 .63019 L .33339 .62266 L p .707 .577 .707 r
F P
0 g
s
.36054 .63019 m .3545 .66739 L .3853 .67361 L p .707 .577 .707 r
F P
0 g
s
.80732 .54205 m .79921 .58972 L .77149 .57794 L p .707 .577 .707 r
F P
0 g
s
.77149 .57794 m .7796 .53027 L .80732 .54205 L p .707 .577 .707 r
F P
0 g
s
.3277 .51853 m .30947 .57282 L .32987 .58261 L p .707 .577 .707 r
F P
0 g
s
.33339 .62266 m .32735 .65986 L .3545 .66739 L p .707 .577 .707 r
F P
0 g
s
.6617 .62201 m .65909 .65692 L .64293 .66737 L p .707 .577 .707 r
F P
0 g
s
.709 .56943 m .71711 .52175 L .74851 .52328 L p .707 .577 .707 r
F P
0 g
s
.71711 .52175 m .709 .56943 L .68035 .57352 L p .707 .577 .707 r
F P
0 g
s
.65424 .74404 m .65238 .72491 L .66972 .72233 L p .707 .577 .707 r
F P
0 g
s
.66972 .72233 m .67158 .74146 L .65424 .74404 L p .707 .577 .707 r
F P
0 g
s
.45177 .64266 m .44572 .67986 L .46943 .67928 L p .707 .577 .707 r
F P
0 g
s
.46943 .67928 m .47547 .64208 L .45177 .64266 L p .707 .577 .707 r
F P
0 g
s
.7796 .53027 m .77149 .57794 L .74041 .57095 L p .707 .577 .707 r
F P
0 g
s
.74041 .57095 m .74851 .52328 L .7796 .53027 L p .707 .577 .707 r
F P
0 g
s
.82634 .63633 m .82373 .67124 L .80257 .65999 L p .707 .577 .707 r
F P
0 g
s
.80257 .65999 m .80518 .62508 L .82634 .63633 L p .707 .577 .707 r
F P
0 g
s
.74851 .52328 m .74041 .57095 L .709 .56943 L p .707 .577 .707 r
F P
0 g
s
.32735 .65986 m .33339 .62266 L .31254 .61456 L p .707 .577 .707 r
F P
0 g
s
.48438 .57127 m .46616 .62555 L .4812 .62694 L p .707 .577 .707 r
F P
0 g
s
.4812 .62694 m .49943 .57265 L .48438 .57127 L p .707 .577 .707 r
F P
0 g
s
.83335 .707 m .83522 .72613 L .8152 .72724 L p .707 .577 .707 r
F P
0 g
s
.8152 .72724 m .81334 .70811 L .83335 .707 L p .707 .577 .707 r
F P
0 g
s
.65909 .65692 m .6617 .62201 L .68556 .61468 L p .707 .577 .707 r
F P
0 g
s
.30947 .57282 m .3277 .51853 L .31524 .51066 L p .707 .577 .707 r
F P
0 g
s
.43317 .72466 m .42881 .70715 L .3977 .71439 L p .707 .577 .707 r
F P
0 g
s
.42881 .70715 m .43317 .72466 L .46235 .71436 L p .707 .577 .707 r
F P
0 g
s
.46235 .71436 m .458 .69685 L .42881 .70715 L p .707 .577 .707 r
F P
0 g
s
.40206 .7319 m .3977 .71439 L .36771 .71785 L p .707 .577 .707 r
F P
0 g
s
.3977 .71439 m .40206 .7319 L .43317 .72466 L p .707 .577 .707 r
F P
0 g
s
.31254 .61456 m .3065 .65176 L .32735 .65986 L p .707 .577 .707 r
F P
0 g
s
.31524 .51066 m .29702 .56495 L .30947 .57282 L p .707 .577 .707 r
F P
0 g
s
.36771 .71785 m .37207 .73536 L .40206 .7319 L p .707 .577 .707 r
F P
0 g
s
.458 .69685 m .46235 .71436 L .48675 .702 L p .707 .577 .707 r
F P
0 g
s
.48675 .702 m .48239 .68449 L .458 .69685 L p .707 .577 .707 r
F P
0 g
s
.37207 .73536 m .36771 .71785 L .34177 .7172 L p .707 .577 .707 r
F P
0 g
s
.47547 .64208 m .46943 .67928 L .48554 .67623 L p .707 .577 .707 r
F P
0 g
s
.48554 .67623 m .49158 .63903 L .47547 .64208 L p .707 .577 .707 r
F P
0 g
s
.68556 .61468 m .68295 .64958 L .65909 .65692 L p .707 .577 .707 r
F P
0 g
s
.80518 .62508 m .80257 .65999 L .77508 .65155 L p .707 .577 .707 r
F P
0 g
s
.77508 .65155 m .77769 .61665 L .80518 .62508 L p .707 .577 .707 r
F P
0 g
s
.67158 .74146 m .66972 .72233 L .69445 .71925 L p .707 .577 .707 r
F P
0 g
s
.69445 .71925 m .69632 .73838 L .67158 .74146 L p .707 .577 .707 r
F P
0 g
s
.68295 .64958 m .68556 .61468 L .7148 .61118 L p .707 .577 .707 r
F P
0 g
s
.3065 .65176 m .31254 .61456 L .30004 .60667 L p .707 .577 .707 r
F P
0 g
s
.34177 .7172 m .34613 .73471 L .37207 .73536 L p .707 .577 .707 r
F P
0 g
s
.81334 .70811 m .8152 .72724 L .78853 .72925 L p .707 .577 .707 r
F P
0 g
s
.78853 .72925 m .78667 .71012 L .81334 .70811 L p .707 .577 .707 r
F P
0 g
s
.48239 .68449 m .48675 .702 L .50397 .68879 L p .707 .577 .707 r
F P
0 g
s
.50397 .68879 m .49962 .67128 L .48239 .68449 L p .707 .577 .707 r
F P
0 g
s
.49943 .57265 m .4812 .62694 L .48738 .62494 L p .707 .577 .707 r
F P
0 g
s
.48738 .62494 m .5056 .57065 L .49943 .57265 L p .707 .577 .707 r
F P
0 g
s
.30004 .60667 m .294 .64387 L .3065 .65176 L p .707 .577 .707 r
F P
0 g
s
.29702 .56495 m .31524 .51066 L .31193 .50547 L p .707 .577 .707 r
F P
0 g
s
.77769 .61665 m .77508 .65155 L .74393 .64676 L p .707 .577 .707 r
F P
0 g
s
.74393 .64676 m .74654 .61186 L .77769 .61665 L p .707 .577 .707 r
F P
0 g
s
.71219 .64608 m .7148 .61118 L .74654 .61186 L p .707 .577 .707 r
F P
0 g
s
.7148 .61118 m .71219 .64608 L .68295 .64958 L p .707 .577 .707 r
F P
0 g
s
.34613 .73471 m .34177 .7172 L .32243 .7125 L p .707 .577 .707 r
F P
0 g
s
.31193 .50547 m .29371 .55975 L .29702 .56495 L p .707 .577 .707 r
F P
0 g
s
.74654 .61186 m .74393 .64676 L .71219 .64608 L p .707 .577 .707 r
F P
0 g
s
.69632 .73838 m .69445 .71925 L .72416 .71597 L p .707 .577 .707 r
F P
0 g
s
.72416 .71597 m .72603 .7351 L .69632 .73838 L p .707 .577 .707 r
F P
0 g
s
.32243 .7125 m .32678 .73001 L .34613 .73471 L p .707 .577 .707 r
F P
0 g
s
.78667 .71012 m .78853 .72925 L .7578 .73196 L p .707 .577 .707 r
F P
0 g
s
.7578 .73196 m .75594 .71283 L .78667 .71012 L p .707 .577 .707 r
F P
0 g
s
.49158 .63903 m .48554 .67623 L .49246 .671 L p .707 .577 .707 r
F P
0 g
s
.49246 .671 m .49851 .6338 L .49158 .63903 L p .707 .577 .707 r
F P
0 g
s
.294 .64387 m .30004 .60667 L .29711 .59977 L p .707 .577 .707 r
F P
0 g
s
.72603 .7351 m .72416 .71597 L .75594 .71283 L p .707 .577 .707 r
F P
0 g
s
.75594 .71283 m .7578 .73196 L .72603 .7351 L p .707 .577 .707 r
F P
0 g
s
.49962 .67128 m .50397 .68879 L .51234 .67603 L p .707 .577 .707 r
F P
0 g
s
.51234 .67603 m .50798 .65852 L .49962 .67128 L p .707 .577 .707 r
F P
0 g
s
.29711 .59977 m .29107 .63698 L .294 .64387 L p .707 .577 .707 r
F P
0 g
s
.32678 .73001 m .32243 .7125 L .31156 .70421 L p .707 .577 .707 r
F P
0 g
s
.5056 .57065 m .48738 .62494 L .48408 .61974 L p .707 .577 .707 r
F P
0 g
s
.48408 .61974 m .5023 .56546 L .5056 .57065 L p .707 .577 .707 r
F P
0 g
s
.29371 .55975 m .31193 .50547 L .31811 .50346 L p .707 .577 .707 r
F P
0 g
s
.31156 .70421 m .31592 .72172 L .32678 .73001 L p .707 .577 .707 r
F P
0 g
s
.31811 .50346 m .29989 .55775 L .29371 .55975 L p .707 .577 .707 r
F P
0 g
s
.49851 .6338 m .49246 .671 L .48953 .6641 L p .707 .577 .707 r
F P
0 g
s
.48953 .6641 m .49557 .6269 L .49851 .6338 L p .707 .577 .707 r
F P
0 g
s
.50798 .65852 m .51234 .67603 L .51102 .66496 L p .707 .577 .707 r
F P
0 g
s
.51102 .66496 m .50667 .64745 L .50798 .65852 L p .707 .577 .707 r
F P
0 g
s
.29107 .63698 m .29711 .59977 L .30403 .59454 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31592 .72172 m .31156 .70421 L .31025 .69314 L p .707 .577 .707 r
F P
0 g
s
.30403 .59454 m .29799 .63175 L .29107 .63698 L p .707 .577 .707 r
F P
0 g
s
.5023 .56546 m .48408 .61974 L .47162 .61187 L p .707 .577 .707 r
F P
0 g
s
.47162 .61187 m .48984 .55758 L .5023 .56546 L p .707 .577 .707 r
F P
0 g
s
.29989 .55775 m .31811 .50346 L .33315 .50485 L p .707 .577 .707 r
F P
0 g
s
.31025 .69314 m .31461 .71065 L .31592 .72172 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.33315 .50485 m .31493 .55913 L .29989 .55775 L p .707 .577 .707 r
F P
0 g
s
.49557 .6269 m .48953 .6641 L .47703 .65622 L p .707 .577 .707 r
F P
0 g
s
.47703 .65622 m .48307 .61901 L .49557 .6269 L p .707 .577 .707 r
F P
0 g
s
.50667 .64745 m .51102 .66496 L .50016 .65667 L p .707 .577 .707 r
F P
0 g
s
.50016 .65667 m .49581 .63916 L .50667 .64745 L p .707 .577 .707 r
F P
0 g
s
.29799 .63175 m .30403 .59454 L .32014 .59149 L p .707 .577 .707 r
F P
0 g
s
.31461 .71065 m .31025 .69314 L .31862 .68038 L p .707 .577 .707 r
F P
0 g
s
.32014 .59149 m .3141 .62869 L .29799 .63175 L p .707 .577 .707 r
F P
0 g
s
.48984 .55758 m .47162 .61187 L .45122 .60208 L p .707 .577 .707 r
F P
0 g
s
.45122 .60208 m .46944 .54779 L .48984 .55758 L p .707 .577 .707 r
F P
0 g
s
.31493 .55913 m .33315 .50485 L .35561 .50948 L p .707 .577 .707 r
F P
0 g
s
.31862 .68038 m .32297 .69789 L .31461 .71065 L p .707 .577 .707 r
F P
0 g
s
.35561 .50948 m .33738 .56377 L .31493 .55913 L p .707 .577 .707 r
F P
0 g
s
.48307 .61901 m .47703 .65622 L .45618 .64811 L p .707 .577 .707 r
F P
0 g
s
.45618 .64811 m .46223 .61091 L .48307 .61901 L p .707 .577 .707 r
F P
0 g
s
.49581 .63916 m .50016 .65667 L .48082 .65198 L p .707 .577 .707 r
F P
0 g
s
.48082 .65198 m .47646 .63447 L .49581 .63916 L p .707 .577 .707 r
F P
0 g
s
.3141 .62869 m .32014 .59149 L .34385 .59091 L p .707 .577 .707 r
F P
0 g
s
.46944 .54779 m .45122 .60208 L .42489 .59134 L p .707 .577 .707 r
F P
0 g
s
.42489 .59134 m .44311 .53706 L .46944 .54779 L p .707 .577 .707 r
F P
0 g
s
.33738 .56377 m .35561 .50948 L .38326 .51691 L p .707 .577 .707 r
F P
0 g
s
.32297 .69789 m .31862 .68038 L .33584 .66718 L p .707 .577 .707 r
F P
0 g
s
.34385 .59091 m .3378 .62811 L .3141 .62869 L p .707 .577 .707 r
F P
0 g
s
.38326 .51691 m .36504 .5712 L .33738 .56377 L p .707 .577 .707 r
F P
0 g
s
.33584 .66718 m .3402 .68469 L .32297 .69789 L p .707 .577 .707 r
F P
0 g
s
.46223 .61091 m .45618 .64811 L .42903 .64058 L p .707 .577 .707 r
F P
0 g
s
.42903 .64058 m .43507 .60338 L .46223 .61091 L p .707 .577 .707 r
F P
0 g
s
.44311 .53706 m .42489 .59134 L .39519 .5807 L p .707 .577 .707 r
F P
0 g
s
.39519 .5807 m .41341 .52641 L .44311 .53706 L p .707 .577 .707 r
F P
0 g
s
.36504 .5712 m .38326 .51691 L .41341 .52641 L p .707 .577 .707 r
F P
0 g
s
.3378 .62811 m .34385 .59091 L .37284 .59287 L p .707 .577 .707 r
F P
0 g
s
.41341 .52641 m .39519 .5807 L .36504 .5712 L p .707 .577 .707 r
F P
0 g
s
.47646 .63447 m .48082 .65198 L .45488 .65133 L p .707 .577 .707 r
F P
0 g
s
.45488 .65133 m .45052 .63382 L .47646 .63447 L p .707 .577 .707 r
F P
0 g
s
.37284 .59287 m .36679 .63007 L .3378 .62811 L p .707 .577 .707 r
F P
0 g
s
.3402 .68469 m .33584 .66718 L .36024 .65482 L p .707 .577 .707 r
F P
0 g
s
.43507 .60338 m .42903 .64058 L .39823 .63437 L p .707 .577 .707 r
F P
0 g
s
.39823 .63437 m .40427 .59716 L .43507 .60338 L p .707 .577 .707 r
F P
0 g
s
.36679 .63007 m .37284 .59287 L .40427 .59716 L p .707 .577 .707 r
F P
0 g
s
.36024 .65482 m .36459 .67233 L .3402 .68469 L p .707 .577 .707 r
F P
0 g
s
.40427 .59716 m .39823 .63437 L .36679 .63007 L p .707 .577 .707 r
F P
0 g
s
.45052 .63382 m .45488 .65133 L .42489 .65479 L p .707 .577 .707 r
F P
0 g
s
.42489 .65479 m .42053 .63728 L .45052 .63382 L p .707 .577 .707 r
F P
0 g
s
.36459 .67233 m .36024 .65482 L .38942 .64451 L p .707 .577 .707 r
F P
0 g
s
.38942 .64451 m .39378 .66203 L .36459 .67233 L p .707 .577 .707 r
F P
0 g
s
.42053 .63728 m .42489 .65479 L .39378 .66203 L p .707 .577 .707 r
F P
0 g
s
.39378 .66203 m .38942 .64451 L .42053 .63728 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP000080
07Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF1000L7oo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001^Ool006]oo`8000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006aoo`00JGoo0`00
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JWoo001WOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00IWoo00<005YFFUH0
0UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol:0003
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001HOol00`00FUH00003
FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Egoo
00<005YF00000eYF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP@000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000@Ool?0016
Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF000;Ool50003FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000006FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP002Goo0`001eYF00<005YFFUH01UYF00<005YFFUH015YF0`00?goo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001goo0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00?Goo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH4
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00P00
>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH000Aoo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF009JEP8003Uoo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009oo`800003FUH005YF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Moo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00H005YFFUH007oo0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH3000eOol005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000d
Ool005Aoo`03FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00<Woo001COol0
1000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0;goo001COol20002FUH50003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH2000`Ool005Aoo`05001JEUYFFUH00003FUH50007FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002mo
o`00EGoo0P001eYF00<005YFFUH010000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YFFUIJEP0000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000_Ool005Moo`03001JEUYF00AJEP03001J
EUYF00AJEP@000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00=JEP03001JEUYF00@000Ioo`L000IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005Qoo`8000AJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002EYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEP@0015oo`@0009JEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FWoo0P0000=JEP00FUH0
1eYF00<005YFFUH00eYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF
FUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH0
0`00FUH00003000IOol40006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005ao
o`<000MJEP03001JEUYF00IJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYF001J
EP002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0009JEP80025o
o`8000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00Ggoo0P001EYF00<005YF
FUH01UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00Oomo
o`0SOol300000eYF001JEP05FUH00`00FUIJEP02FUH2000/Ool0065oo`<00003FUH005YF00MJEP03
001JEUYF00=JEP<00003FUH005YF00MJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000015YF001JEP009goo0P001UYF00L005YFFUIJ
EP00FUH0000/Ool005UooaH000QJEP<000MJEP03001JEUYF00AJEP06001JEUYF001JEP002eYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF10000UYF00<007ooOol09goo00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000=JEP04001JEP000005FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001oogoo01=oo`<0015oo`05
001JEUYFFUH00004FUH00`00FUH0000/Ool005Aoo`<000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00@000=JEP<00003FUH005YF00EJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF00<007ooOol04Goo
1@004Goo0P0000=JEP00FUH00eYF00<005YF0000;7oo001DOol00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH20006FUH01000FUIJEUYF
0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF0P00
4Woo1@004goo0P0015YF00<005YF0000;7oo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000050004FUH01P00FUIJEP00FUH000aJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000EJEP03001JEP00015oo`D001Aoo`03
001JEUYF009JEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH00UYF0`0035YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00@005YFFUIJEP8000Ioo`T0
0004Ool00000000FOol01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40003FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH6
0004FUH00`00FUIJEP02FUH9000BOol01@00FUH005YF0000;Goo001COol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP0400000eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000<
Ool01@00FUH005YF0000;Goo001<Ool800000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030008Ool300000eYF001o
o`0/Ool004=oo`T000AJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@000aJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`80009JEP03001JEP0002eoo`00?Goo1P0015YF
00<005YFFUH015YF1@0000AJEP00FUIJEPd000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH20002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH500001eYF001JEUYF001JEP0002eoo`00>Goo100000=JEP00FUH0
1EYF2@0015YF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH00eYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00800004FUH005YFFUH2000^
Ool003Aoo`D000AJEPP000AJEP03001JEUYF00IJEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPP000IJEP03001JEUYF00h0009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH2000^Ool002moo`D0
0003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00EJEPh000AJEP03001JEUYF00AJEP03001JEUYF00@000]J
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF0000000^Ool002]oo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEPH0009JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000]JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002ioo`00
:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF009JEPl000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00003FUH005YF00AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP03FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH0
0`00FUIJEP030003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH>0003FUH00`00FUH00008FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUH000030007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH300000eYF001JEP06FUH30007FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP04FUH2
0003FUH400000eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30004
FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF0P0000=JEP00
FUH01eYF00<005YFFUH0100000=JEP00FUH01UYF00<005YFFUH015YF00D005YF000005YF0080009J
EP03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0009JEP80009J
EP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000EJEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH00`00FUIJEP05FUH40005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF0`001eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YF000025YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUIJEP8002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YFFUIJEP8000IJEP03001JEUYF009JEP8000UJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30002FUH30007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH005YF0P0015YF00@005YF000000IJEP03001JEUYF00IJEP<000IJEP03001JEUYF
00EJEP03001JEUYF009JEP800007FUH005YFFUH005YF0000;Goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUH000001eYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUIJEP<00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30003FUH700000eYF00000003FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH40002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00EJEP<0009J
EPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000=JEP@000=JEPD0
0003FUH005YF00MJEPD000AJEP03001JEUYF00EJEP04001JEUYFFUH20004Ool01@00FUH005YF0000
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0`0015YF00<005YFFUH015YF
200015YF00<005YFFUH015YF00<005YFFUH01@0000EJEP00FUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP8000AJEP04001JEUYF0005FUH00`00FUH000040006FUH50004
FUH00`00FUIJEP05FUH01000FUH000001Woo00D005YF001JEP0002eoo`00;7oo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P001EYF00D005YF000007oo008000AJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH>0002FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH0
1000FUIJEUYF0P000eYF00D005YFFUIJEP00009oo`@0009JEP@000EJEP03001JEUYF009JEPD000Mo
o`D002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF2`001EYF0P000goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF0P0025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
0P0015YF00<005YFFUH00eYF0P000UYF00@005YFFUH000Iooa0000Yoo`8000=JEP8002ioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1`002Goo0P0015YF
00<007ooOol00goo0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01EYF0`001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YF00000`000UYF00<007ooOol06goo0`0015YF0P00;Woo000]Ool00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04000?Ool01@00FUIJEP00FUH00P001Woo
0P0015YF00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YFFUH00eYF1P0067oo0P000UYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH6000;Ool90002FUH40006Ool20004FUH01000FUIJ
EUYF0`000UYF00<005YFFUH025YF00@005YFFUIJEP8000EJEP04001JEP00000;FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH90009Ool60004FUH01`00FUIJEUYF001JEP0002ioo`00;Goo00<005YF00000UYF7P00
15YF00D005YFFUIJEP00009JEP80009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00QJEP04001J
EP000007FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Goo1@001Goo20000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00T005YFFUIJEP00FUH005YF00001EYF00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH01eYF0`0000=JEP00FUH01UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00<Woo1@000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03
001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP80009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03001JEUYF008000AJEP03
001JEUYF00IJEP04001JEUYFFUH30008FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000E000/Ool002ioo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000000015YF
00<005YFFUH00P0015YF00<005YFFUH01UYF100000=JEP00FUH025YF0`001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP04001JEUYF0007
FUH00`00FUIJEP05FUH00`00FUIJEP090004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF0000;7oo000/Ool30004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0015YF00<005YFFUH01eYF
00L005YFFUIJEP00FUH00002FUH90004FUH00`00FUH000060006FUH00`00FUIJEP05FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001EYF
0`001eYF00<005YFFUH0200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0002aoo`00;7oo00<005YF000015YF00<005YFFUH00UYF1P0015YF00<005YFFUH00UYF
2@001EYF00L005YFFUIJEP00FUH00005FUH01000FUIJEUYF200015YF00<005YFFUH01UYF00<005YF
FUH00eYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH000IJEP<00003FUH0000000H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;7oo00<005YF000015YF1@0000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000eYF00@005YFFUH000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0004FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000[
Ool002aoo`03001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP04001JEP000002FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUIJEP050002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH01000FUIJEUYF3P00:goo000/Ool00`00FUH00002FUH20006FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH:000]Ool002aoo`03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00AJEP`000=JEP03001JEUYF009JEPL000YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF
1`00=goo000]Ool20003FUH00`00FUIJEP03FUH600000eYF000000080004FUH40002FUH00`00FUIJ
EP05FUH30002FUH01000FUIJEUYF2P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0004FUH01000
FUIJEUYF4@000eYF2@00?Woo000]Ool20003FUH00`00FUH0000;0008FUH00`00FUIJEP06FUH40006
FUH01P00FUIJEP00FUH000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEUYF001J
EP000UYF1P001UYF00<005YFFUH00UYF2@00Agoo000/Ool00`00FUH00003FUH70006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP80009JEP@000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEUYF001JEP030005FUH01000FUIJEUYF2000D7oo000/Ool20002FUH3
0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF
001JEP04FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH90009FUH01000FUIJEUYF
30001EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH03`0000=JEP000000E7oo000[Ool0
0`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20005FUH20002Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP060006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP080007FUH00`00FUIJEP03FUH01000FUIJEP00
2Woo10000UYF00<007ooOol0DWoo000[Ool01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF0P000Woo0P0015YF00<0
05YFFUH015YF1P002eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF1@000UYF00<0
05YFFUH00eYF00@005YFFUH000Qoo`8000AJEP<005Aoo`00:goo0P0000=oo`0000001@000eYF00<0
05YFFUH015YF00<005YFFUH00UYF4P001goo0P0000IJEP00FUIJEP00Ool20004FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP02FUH30005FUH01000FUIJEP001Woo0P0000=JEP00FUH00eYF00<005YF0000E7oo000[Ool20008
Ool?000KOol20002FUH01000Ool0000015YF100025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00@005YFFUH000Aoo`8000=JEP03
001JEUYF009JEP04001JEP00001COol002]oo`8003=oo`04001JEUYFFUH30002FUH20003FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300001UYF001JEUYF001oo`<000EJEP03001JEUYF009JEP04001JEUYF001COol002]o
o`8003Aoo`03001JEUYF00D000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP800003FUH005YF
00EJEP03001JEUYF009JEP04001JEUYF001COol002]oo`<001Yoo`<001Moo`03001JEP0000<000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00=J
EP8005Aoo`00:goo0`006Goo1@005Woo00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF0P00E7oo000[Ool01000FUIJEP00
67oo1@005goo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH00UYF00<007ooOol0Dgoo000[Ool01@00FUIJEUYF00005goo1@0067oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00D005YF
FUIJEP0005Ioo`00:goo00@005YFFUIJEP<001Ioo`<001Qoo`<00003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP04001JEP00001GOol002aoo`04001JEUYF
0002FUH00`00Oomoo`0^Ool200000goo00000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH2001IOol002aoo`03001JEP0000AJEP8002eoo`04001JEP00Ool20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00Oomoo`1HOol0
02eoo`8000IJEP8002Yoo`800004FUH007ooOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020007
FUH01000FUIJEUYF0P00Fgoo000^Ool00`00FUIJEP04FUH01000FUH000009Woo0P0000=JEP000000
1Goo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF1@001eYF00@005YF000005eoo`00;goo0P0015YF00@005YFFUIJ
EP8002=oo`04001JEUYFFUH20007Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH01000FUH000000eYF1000
Ggoo000aOol01000FUIJEP001UYF10007Goo0P0015YF00<007ooOol027oo10001UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF0`0015YF00@0
05YFFUIJEP<006=oo`00<Woo0`001eYF00<005YFFUH010005Goo100000=JEP00FUH00eYF00<007oo
Ool037oo10000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000`001EYF00<005YFFUH01EYF0`00H7oo000dOol20006FUH00`00FUIJEP04FUH70009
Ool50005FUH00`00FUIJEP02000COol50009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH;0002FUH00`00FUIJEP06FUH01000FUH00000GWoo000fOol20004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH3000JOol60003FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0?0002Ool40006FUH00`00FUIJEP02FUH2001LOol003Qoo`<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80029ooal00004FUH000000006
Ool50006Ool20004FUH00`00FUIJEP03FUH3001JOol003]oo`<000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH2000gOol20006FUH00`00FUIJEP05FUH6000017oo000000002Goo0P00
00=JEP00FUH01EYF00@005YFFUH005Uoo`00?Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003]oo`@00003FUH005YF00QJEP03001JEUYF009JEPH000Uoo`<000AJEP05001JEUYF
FUH0001IOol0049ooaH0045oo`<000QJEP03001JEUYF00IJEP03001JEP0000<000Qoo`<00003FUH0
05YF009JEP8005Qoo`00W7oo0`0015YF00<005YFFUH01eYF00<005YFFUH00eYF3@000UYF00<005YF
0000F7oo002OOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEUYF
001JEP8005Uoo`00XWoo10001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00
FGoo002VOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001J
Ool00:Yoo`H000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0005Yoo`00/7oo20000eYF
00<005YFFUH01000Fgoo002hOol6001OOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60166 .75781 m .5903 .70484 L .55965 .70826 L p .707 .577 .707 r
F P
0 g
s
.5903 .70484 m .60166 .75781 L .63283 .75078 L p .707 .577 .707 r
F P
0 g
s
.63283 .75078 m .62147 .69781 L .5903 .70484 L p .707 .577 .707 r
F P
0 g
s
.62147 .69781 m .63283 .75078 L .66148 .74084 L p .707 .577 .707 r
F P
0 g
s
.66148 .74084 m .65011 .68787 L .62147 .69781 L p .707 .577 .707 r
F P
0 g
s
.57101 .76123 m .55965 .70826 L .53252 .70775 L p .707 .577 .707 r
F P
0 g
s
.55965 .70826 m .57101 .76123 L .60166 .75781 L p .707 .577 .707 r
F P
0 g
s
.65011 .68787 m .66148 .74084 L .68479 .72897 L p .707 .577 .707 r
F P
0 g
s
.68479 .72897 m .67343 .67599 L .65011 .68787 L p .707 .577 .707 r
F P
0 g
s
.59965 .81408 m .5959 .77766 L .56487 .77838 L p .707 .577 .707 r
F P
0 g
s
.5959 .77766 m .59965 .81408 L .63133 .81022 L p .707 .577 .707 r
F P
0 g
s
.63133 .81022 m .62758 .7738 L .5959 .77766 L p .707 .577 .707 r
F P
0 g
s
.62758 .7738 m .63133 .81022 L .66055 .8036 L p .707 .577 .707 r
F P
0 g
s
.66055 .8036 m .6568 .76719 L .62758 .7738 L p .707 .577 .707 r
F P
0 g
s
.54389 .76072 m .53252 .70775 L .51157 .70335 L p .707 .577 .707 r
F P
0 g
s
.53252 .70775 m .54389 .76072 L .57101 .76123 L p .707 .577 .707 r
F P
0 g
s
.67343 .67599 m .68479 .72897 L .70049 .71631 L p .707 .577 .707 r
F P
0 g
s
.70049 .71631 m .68912 .66333 L .67343 .67599 L p .707 .577 .707 r
F P
0 g
s
.56861 .8148 m .56487 .77838 L .53751 .77589 L p .707 .577 .707 r
F P
0 g
s
.56487 .77838 m .56861 .8148 L .59965 .81408 L p .707 .577 .707 r
F P
0 g
s
.58318 .84556 m .5859 .82695 L .55525 .82099 L p .707 .577 .707 r
F P
0 g
s
.5859 .82695 m .58318 .84556 L .61476 .84955 L p .707 .577 .707 r
F P
0 g
s
.61476 .84955 m .61748 .83094 L .5859 .82695 L p .707 .577 .707 r
F P
0 g
s
.6568 .76719 m .66055 .8036 L .68445 .79487 L p .707 .577 .707 r
F P
0 g
s
.68445 .79487 m .6807 .75845 L .6568 .76719 L p .707 .577 .707 r
F P
0 g
s
.61748 .83094 m .61476 .84955 L .64419 .85118 L p .707 .577 .707 r
F P
0 g
s
.64419 .85118 m .64691 .83257 L .61748 .83094 L p .707 .577 .707 r
F P
0 g
s
.55525 .82099 m .55253 .83959 L .58318 .84556 L p .707 .577 .707 r
F P
0 g
s
.55253 .83959 m .55525 .82099 L .52854 .81363 L p .707 .577 .707 r
F P
0 g
s
.53751 .77589 m .54125 .81231 L .56861 .8148 L p .707 .577 .707 r
F P
0 g
s
.52854 .81363 m .52582 .83224 L .55253 .83959 L p .707 .577 .707 r
F P
0 g
s
.51157 .70335 m .52294 .75632 L .54389 .76072 L p .707 .577 .707 r
F P
0 g
s
.54125 .81231 m .53751 .77589 L .51651 .77044 L p .707 .577 .707 r
F P
0 g
s
.52294 .75632 m .51157 .70335 L .49885 .69549 L p .707 .577 .707 r
F P
0 g
s
.64691 .83257 m .64419 .85118 L .66859 .85028 L p .707 .577 .707 r
F P
0 g
s
.66859 .85028 m .67131 .83167 L .64691 .83257 L p .707 .577 .707 r
F P
0 g
s
.68912 .66333 m .70049 .71631 L .70703 .70411 L p .707 .577 .707 r
F P
0 g
s
.70703 .70411 m .69567 .65114 L .68912 .66333 L p .707 .577 .707 r
F P
0 g
s
.6807 .75845 m .68445 .79487 L .70069 .78488 L p .707 .577 .707 r
F P
0 g
s
.70069 .78488 m .69694 .74846 L .6807 .75845 L p .707 .577 .707 r
F P
0 g
s
.52582 .83224 m .52854 .81363 L .50839 .8056 L p .707 .577 .707 r
F P
0 g
s
.51651 .77044 m .52025 .80686 L .54125 .81231 L p .707 .577 .707 r
F P
0 g
s
.50839 .8056 m .50567 .82421 L .52582 .83224 L p .707 .577 .707 r
F P
0 g
s
.49885 .69549 m .51022 .74847 L .52294 .75632 L p .707 .577 .707 r
F P
0 g
s
.67131 .83167 m .66859 .85028 L .68556 .84695 L p .707 .577 .707 r
F P
0 g
s
.68556 .84695 m .68829 .82834 L .67131 .83167 L p .707 .577 .707 r
F P
0 g
s
.52025 .80686 m .51651 .77044 L .50392 .76256 L p .707 .577 .707 r
F P
0 g
s
.51022 .74847 m .49885 .69549 L .49561 .68495 L p .707 .577 .707 r
F P
0 g
s
.50567 .82421 m .50839 .8056 L .49676 .79769 L p .707 .577 .707 r
F P
0 g
s
.69694 .74846 m .70069 .78488 L .70768 .77461 L p .707 .577 .707 r
F P
0 g
s
.70768 .77461 m .70393 .73819 L .69694 .74846 L p .707 .577 .707 r
F P
0 g
s
.50392 .76256 m .50767 .79897 L .52025 .80686 L p .707 .577 .707 r
F P
0 g
s
.69567 .65114 m .70703 .70411 L .70379 .69357 L p .707 .577 .707 r
F P
0 g
s
.70379 .69357 m .69242 .6406 L .69567 .65114 L p .707 .577 .707 r
F P
0 g
s
.49676 .79769 m .49404 .8163 L .50567 .82421 L p .707 .577 .707 r
F P
0 g
s
.68829 .82834 m .68556 .84695 L .69346 .8415 L p .707 .577 .707 r
F P
0 g
s
.69346 .8415 m .69618 .82289 L .68829 .82834 L p .707 .577 .707 r
F P
0 g
s
.49561 .68495 m .50697 .73793 L .51022 .74847 L p .707 .577 .707 r
F P
0 g
s
.50767 .79897 m .50392 .76256 L .50098 .75301 L p .707 .577 .707 r
F P
0 g
s
.50697 .73793 m .49561 .68495 L .50215 .67275 L p .707 .577 .707 r
F P
0 g
s
.49404 .8163 m .49676 .79769 L .4948 .79067 L p .707 .577 .707 r
F P
0 g
s
.4948 .79067 m .49208 .80927 L .49404 .8163 L p .707 .577 .707 r
F P
0 g
s
.49208 .80927 m .4948 .79067 L .50269 .78522 L p .707 .577 .707 r
F P
0 g
s
.50269 .78522 m .49997 .80383 L .49208 .80927 L p .707 .577 .707 r
F P
0 g
s
.50098 .75301 m .50472 .78943 L .50767 .79897 L p .707 .577 .707 r
F P
0 g
s
.50472 .78943 m .50098 .75301 L .50797 .74274 L p .707 .577 .707 r
F P
0 g
s
.50797 .74274 m .51172 .77916 L .50472 .78943 L p .707 .577 .707 r
F P
0 g
s
.49997 .80383 m .50269 .78522 L .51966 .78188 L p .707 .577 .707 r
F P
0 g
s
.51966 .78188 m .51694 .80049 L .49997 .80383 L p .707 .577 .707 r
F P
0 g
s
.50018 .82192 m .50018 .32003 L .4556 .31816 L p .707 .577 .707 r
F P
0 g
s
.50215 .67275 m .51352 .72573 L .50697 .73793 L p .707 .577 .707 r
F P
0 g
s
.51352 .72573 m .50215 .67275 L .51785 .6601 L p .707 .577 .707 r
F P
0 g
s
.51785 .6601 m .52921 .71307 L .51352 .72573 L p .707 .577 .707 r
F P
0 g
s
.51172 .77916 m .50797 .74274 L .52421 .73275 L p .707 .577 .707 r
F P
0 g
s
.52921 .71307 m .51785 .6601 L .54116 .64822 L p .707 .577 .707 r
F P
0 g
s
.52421 .73275 m .52796 .76917 L .51172 .77916 L p .707 .577 .707 r
F P
0 g
s
.54116 .64822 m .55252 .70119 L .52921 .71307 L p .707 .577 .707 r
F P
0 g
s
.52796 .76917 m .52421 .73275 L .54811 .72402 L p .707 .577 .707 r
F P
0 g
s
.54811 .72402 m .55186 .76044 L .52796 .76917 L p .707 .577 .707 r
F P
0 g
s
.51694 .80049 m .51966 .78188 L .54406 .78099 L p .707 .577 .707 r
F P
0 g
s
.54406 .78099 m .54134 .79959 L .51694 .80049 L p .707 .577 .707 r
F P
0 g
s
.54134 .79959 m .54406 .78099 L .57349 .78261 L p .707 .577 .707 r
F P
0 g
s
.57349 .78261 m .57077 .80122 L .54134 .79959 L p .707 .577 .707 r
F P
0 g
s
.50018 .32003 m .50018 .82192 L .54475 .82001 L p .707 .577 .707 r
F P
0 g
s
.55252 .70119 m .54116 .64822 L .5698 .63828 L p .707 .577 .707 r
F P
0 g
s
.54475 .82001 m .54475 .31813 L .50018 .32003 L p .707 .577 .707 r
F P
0 g
s
.4556 .82004 m .4556 .31816 L .41536 .31267 L p .707 .577 .707 r
F P
0 g
s
.4556 .31816 m .4556 .82004 L .50018 .82192 L p .707 .577 .707 r
F P
0 g
s
.58117 .69125 m .5698 .63828 L .60098 .63125 L p .707 .577 .707 r
F P
0 g
s
.5698 .63828 m .58117 .69125 L .55252 .70119 L p .707 .577 .707 r
F P
0 g
s
.55186 .76044 m .54811 .72402 L .57733 .7174 L p .707 .577 .707 r
F P
0 g
s
.57733 .7174 m .58108 .75382 L .55186 .76044 L p .707 .577 .707 r
F P
0 g
s
.57077 .80122 m .57349 .78261 L .60508 .7866 L p .707 .577 .707 r
F P
0 g
s
.60508 .7866 m .60235 .80521 L .57077 .80122 L p .707 .577 .707 r
F P
0 g
s
.54475 .31813 m .54475 .82001 L .58493 .8145 L p .707 .577 .707 r
F P
0 g
s
.60098 .63125 m .61234 .68423 L .58117 .69125 L p .707 .577 .707 r
F P
0 g
s
.58108 .75382 m .57733 .7174 L .60901 .71354 L p .707 .577 .707 r
F P
0 g
s
.60901 .71354 m .61275 .74996 L .58108 .75382 L p .707 .577 .707 r
F P
0 g
s
.58493 .8145 m .58493 .31261 L .54475 .31813 L p .707 .577 .707 r
F P
0 g
s
.70393 .73819 m .70768 .77461 L .70474 .76507 L p .707 .577 .707 r
F P
0 g
s
.70474 .76507 m .70099 .72865 L .70393 .73819 L p .707 .577 .707 r
F P
0 g
s
.69242 .6406 m .70379 .69357 L .69107 .68571 L p .707 .577 .707 r
F P
0 g
s
.69107 .68571 m .6797 .63274 L .69242 .6406 L p .707 .577 .707 r
F P
0 g
s
.69618 .82289 m .69346 .8415 L .69149 .83448 L p .707 .577 .707 r
F P
0 g
s
.69149 .83448 m .69421 .81587 L .69618 .82289 L p .707 .577 .707 r
F P
0 g
s
.41536 .81456 m .41536 .31267 L .38341 .30412 L p .707 .577 .707 r
F P
0 g
s
.41536 .31267 m .41536 .81456 L .4556 .82004 L p .707 .577 .707 r
F P
0 g
s
.61234 .68423 m .60098 .63125 L .63163 .62783 L p .707 .577 .707 r
F P
0 g
s
.64005 .71282 m .64379 .74924 L .61275 .74996 L p .707 .577 .707 r
F P
0 g
s
.61275 .74996 m .60901 .71354 L .64005 .71282 L p .707 .577 .707 r
F P
0 g
s
.63572 .79257 m .633 .81118 L .60235 .80521 L p .707 .577 .707 r
F P
0 g
s
.60235 .80521 m .60508 .7866 L .63572 .79257 L p .707 .577 .707 r
F P
0 g
s
.58493 .31261 m .58493 .8145 L .6168 .80593 L p .707 .577 .707 r
F P
0 g
s
.63163 .62783 m .64299 .6808 L .61234 .68423 L p .707 .577 .707 r
F P
0 g
s
.6168 .80593 m .6168 .30404 L .58493 .31261 L p .707 .577 .707 r
F P
0 g
s
.25689 .69401 m .25194 .6367 L .22075 .63888 L p .707 .577 .707 r
F P
0 g
s
.25194 .6367 m .25689 .69401 L .28855 .69103 L p .707 .577 .707 r
F P
0 g
s
.28855 .69103 m .28359 .63371 L .25194 .6367 L p .707 .577 .707 r
F P
0 g
s
.28359 .63371 m .28855 .69103 L .31757 .68752 L p .707 .577 .707 r
F P
0 g
s
.31757 .68752 m .31262 .63021 L .28359 .63371 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22075 .63888 m .2257 .69619 L .25689 .69401 L p .707 .577 .707 r
F P
0 g
s
.70099 .72865 m .70474 .76507 L .69215 .75718 L p .707 .577 .707 r
F P
0 g
s
.69215 .75718 m .68841 .72077 L .70099 .72865 L p .707 .577 .707 r
F P
0 g
s
.6797 .63274 m .69107 .68571 L .67012 .68132 L p .707 .577 .707 r
F P
0 g
s
.67012 .68132 m .65875 .62834 L .6797 .63274 L p .707 .577 .707 r
F P
0 g
s
.2257 .69619 m .22075 .63888 L .19309 .64004 L p .707 .577 .707 r
F P
0 g
s
.19309 .64004 m .19804 .69735 L .2257 .69619 L p .707 .577 .707 r
F P
0 g
s
.31262 .63021 m .31757 .68752 L .34113 .68385 L p .707 .577 .707 r
F P
0 g
s
.34113 .68385 m .33618 .62653 L .31262 .63021 L p .707 .577 .707 r
F P
0 g
s
.25489 .76443 m .25328 .72658 L .22211 .72666 L p .707 .577 .707 r
F P
0 g
s
.25328 .72658 m .25489 .76443 L .28668 .7626 L p .707 .577 .707 r
F P
0 g
s
.28668 .7626 m .28507 .72475 L .25328 .72658 L p .707 .577 .707 r
F P
0 g
s
.28507 .72475 m .28668 .7626 L .316 .75919 L p .707 .577 .707 r
F P
0 g
s
.316 .75919 m .31439 .72134 L .28507 .72475 L p .707 .577 .707 r
F P
0 g
s
.38341 .80601 m .38341 .30412 L .36287 .29334 L p .707 .577 .707 r
F P
0 g
s
.38341 .30412 m .38341 .80601 L .41536 .81456 L p .707 .577 .707 r
F P
0 g
s
.19804 .69735 m .19309 .64004 L .17165 .64007 L p .707 .577 .707 r
F P
0 g
s
.633 .81118 m .63572 .79257 L .66243 .79993 L p .707 .577 .707 r
F P
0 g
s
.6168 .30404 m .6168 .80593 L .63724 .79513 L p .707 .577 .707 r
F P
0 g
s
.64299 .6808 m .63163 .62783 L .65875 .62834 L p .707 .577 .707 r
F P
0 g
s
.63724 .79513 m .63724 .29324 L .6168 .30404 L p .707 .577 .707 r
F P
0 g
s
.69421 .81587 m .69149 .83448 L .67986 .82656 L p .707 .577 .707 r
F P
0 g
s
.67986 .82656 m .68258 .80796 L .69421 .81587 L p .707 .577 .707 r
F P
0 g
s
.22211 .72666 m .22372 .76451 L .25489 .76443 L p .707 .577 .707 r
F P
0 g
s
.22372 .76451 m .22211 .72666 L .19462 .72497 L p .707 .577 .707 r
F P
0 g
s
.17165 .64007 m .1766 .69738 L .19804 .69735 L p .707 .577 .707 r
F P
0 g
s
.65875 .62834 m .67012 .68132 L .64299 .6808 L p .707 .577 .707 r
F P
0 g
s
.19462 .72497 m .19623 .76282 L .22372 .76451 L p .707 .577 .707 r
F P
0 g
s
.31439 .72134 m .316 .75919 L .33996 .75453 L p .707 .577 .707 r
F P
0 g
s
.33996 .75453 m .33835 .71668 L .31439 .72134 L p .707 .577 .707 r
F P
0 g
s
.68841 .72077 m .69215 .75718 L .67115 .75173 L p .707 .577 .707 r
F P
0 g
s
.67115 .75173 m .66741 .71531 L .68841 .72077 L p .707 .577 .707 r
F P
0 g
s
.33618 .62653 m .34113 .68385 L .35691 .68036 L p .707 .577 .707 r
F P
0 g
s
.35691 .68036 m .35196 .62305 L .33618 .62653 L p .707 .577 .707 r
F P
0 g
s
.19623 .76282 m .19462 .72497 L .1735 .72168 L p .707 .577 .707 r
F P
0 g
s
.1766 .69738 m .17165 .64007 L .15855 .63895 L p .707 .577 .707 r
F P
0 g
s
.1735 .72168 m .17511 .75953 L .19623 .76282 L p .707 .577 .707 r
F P
0 g
s
.24625 .82541 m .24741 .80786 L .21648 .80296 L p .707 .577 .707 r
F P
0 g
s
.24741 .80786 m .24625 .82541 L .27809 .82632 L p .707 .577 .707 r
F P
0 g
s
.27809 .82632 m .27925 .80877 L .24741 .80786 L p .707 .577 .707 r
F P
0 g
s
.27925 .80877 m .27809 .82632 L .30772 .82315 L p .707 .577 .707 r
F P
0 g
s
.30772 .82315 m .30888 .8056 L .27925 .80877 L p .707 .577 .707 r
F P
0 g
s
.15855 .63895 m .1635 .69627 L .1766 .69738 L p .707 .577 .707 r
F P
0 g
s
.68258 .80796 m .67986 .82656 L .65971 .81854 L p .707 .577 .707 r
F P
0 g
s
.65971 .81854 m .66243 .79993 L .68258 .80796 L p .707 .577 .707 r
F P
0 g
s
.33835 .71668 m .33996 .75453 L .35622 .74908 L p .707 .577 .707 r
F P
0 g
s
.35622 .74908 m .35461 .71123 L .33835 .71668 L p .707 .577 .707 r
F P
0 g
s
.21532 .82051 m .21648 .80296 L .18949 .79456 L p .707 .577 .707 r
F P
0 g
s
.21648 .80296 m .21532 .82051 L .24625 .82541 L p .707 .577 .707 r
F P
0 g
s
.66741 .71531 m .67115 .75173 L .64379 .74924 L p .707 .577 .707 r
F P
0 g
s
.64379 .74924 m .64005 .71282 L .66741 .71531 L p .707 .577 .707 r
F P
0 g
s
.35196 .62305 m .35691 .68036 L .36337 .6774 L p .707 .577 .707 r
F P
0 g
s
.36337 .6774 m .35842 .62009 L .35196 .62305 L p .707 .577 .707 r
F P
0 g
s
.35461 .71123 m .35622 .74908 L .36319 .74338 L p .707 .577 .707 r
F P
0 g
s
.36319 .74338 m .36158 .70553 L .35461 .71123 L p .707 .577 .707 r
F P
0 g
s
.35842 .62009 m .36337 .6774 L .35988 .67526 L p .707 .577 .707 r
F P
0 g
s
.36158 .70553 m .36319 .74338 L .36019 .73798 L p .707 .577 .707 r
F P
0 g
s
.36287 .79523 m .36287 .29334 L .35575 .28138 L p .707 .577 .707 r
F P
0 g
s
.36287 .29334 m .36287 .79523 L .38341 .80601 L p .707 .577 .707 r
F P
0 g
s
.18949 .79456 m .18833 .81211 L .21532 .82051 L p .707 .577 .707 r
F P
0 g
s
.30888 .8056 m .30772 .82315 L .33225 .81622 L p .707 .577 .707 r
F P
0 g
s
.33225 .81622 m .33341 .79867 L .30888 .8056 L p .707 .577 .707 r
F P
0 g
s
.63724 .29324 m .63724 .79513 L .64424 .78317 L p .707 .577 .707 r
F P
0 g
s
.64424 .78317 m .64424 .28128 L .63724 .29324 L p .707 .577 .707 r
F P
0 g
s
.17511 .75953 m .1735 .72168 L .16082 .71711 L p .707 .577 .707 r
F P
0 g
s
.18833 .81211 m .18949 .79456 L .16908 .78347 L p .707 .577 .707 r
F P
0 g
s
.16082 .71711 m .16243 .75496 L .17511 .75953 L p .707 .577 .707 r
F P
0 g
s
.66243 .79993 m .65971 .81854 L .633 .81118 L p .707 .577 .707 r
F P
0 g
s
.1635 .69627 m .15855 .63895 L .15505 .63682 L p .707 .577 .707 r
F P
0 g
s
.16908 .78347 m .16792 .80102 L .18833 .81211 L p .707 .577 .707 r
F P
0 g
s
.15505 .63682 m .16001 .69413 L .1635 .69627 L p .707 .577 .707 r
F P
0 g
s
.33341 .79867 m .33225 .81622 L .34927 .8062 L p .707 .577 .707 r
F P
0 g
s
.34927 .8062 m .35043 .78865 L .33341 .79867 L p .707 .577 .707 r
F P
0 g
s
.16792 .80102 m .16908 .78347 L .15724 .77078 L p .707 .577 .707 r
F P
0 g
s
.16243 .75496 m .16082 .71711 L .15782 .71171 L p .707 .577 .707 r
F P
0 g
s
.35988 .67526 m .35493 .61795 L .35842 .62009 L p .707 .577 .707 r
F P
0 g
s
.15724 .77078 m .15608 .78833 L .16792 .80102 L p .707 .577 .707 r
F P
0 g
s
.15782 .71171 m .15943 .74956 L .16243 .75496 L p .707 .577 .707 r
F P
0 g
s
.35711 .79407 m .35827 .77652 L .35043 .78865 L p .707 .577 .707 r
F P
0 g
s
.36019 .73798 m .35858 .70013 L .36158 .70553 L p .707 .577 .707 r
F P
0 g
s
.35493 .61795 m .35988 .67526 L .34678 .67415 L p .707 .577 .707 r
F P
0 g
s
.35827 .77652 m .35711 .79407 L .35502 .78103 L p .707 .577 .707 r
F P
0 g
s
.35502 .78103 m .35618 .76348 L .35827 .77652 L p .707 .577 .707 r
F P
0 g
s
.35858 .70013 m .36019 .73798 L .34751 .73341 L p .707 .577 .707 r
F P
0 g
s
.34751 .73341 m .3459 .69556 L .35858 .70013 L p .707 .577 .707 r
F P
0 g
s
.35618 .76348 m .35502 .78103 L .34319 .76834 L p .707 .577 .707 r
F P
0 g
s
.34319 .76834 m .34435 .75079 L .35618 .76348 L p .707 .577 .707 r
F P
0 g
s
.35575 .28138 m .35575 .78327 L .36287 .79523 L p .707 .577 .707 r
F P
0 g
s
.35575 .78327 m .35575 .28138 L .36276 .26942 L p .707 .577 .707 r
F P
0 g
s
.64424 .28128 m .64424 .78317 L .63713 .77121 L p .707 .577 .707 r
F P
0 g
s
.63713 .77121 m .63713 .26932 L .64424 .28128 L p .707 .577 .707 r
F P
0 g
s
.35043 .78865 m .34927 .8062 L .35711 .79407 L p .707 .577 .707 r
F P
0 g
s
.16001 .69413 m .15505 .63682 L .16152 .63386 L p .707 .577 .707 r
F P
0 g
s
.16152 .63386 m .16647 .69117 L .16001 .69413 L p .707 .577 .707 r
F P
0 g
s
.15608 .78833 m .15724 .77078 L .15515 .75774 L p .707 .577 .707 r
F P
0 g
s
.15943 .74956 m .15782 .71171 L .16479 .706 L p .707 .577 .707 r
F P
0 g
s
.15515 .75774 m .15399 .77529 L .15608 .78833 L p .707 .577 .707 r
F P
0 g
s
.34678 .67415 m .34182 .61684 L .35493 .61795 L p .707 .577 .707 r
F P
0 g
s
.16479 .706 m .1664 .74385 L .15943 .74956 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16647 .69117 m .16152 .63386 L .1773 .63037 L p .707 .577 .707 r
F P
0 g
s
.1773 .63037 m .18225 .68769 L .16647 .69117 L p .707 .577 .707 r
F P
0 g
s
.15399 .77529 m .15515 .75774 L .163 .74561 L p .707 .577 .707 r
F P
0 g
s
.36276 .7713 m .36276 .26942 L .38319 .25862 L p .707 .577 .707 r
F P
0 g
s
.36276 .26942 m .36276 .7713 L .35575 .78327 L p .707 .577 .707 r
F P
0 g
s
.63713 .26932 m .63713 .77121 L .61659 .76043 L p .707 .577 .707 r
F P
0 g
s
.61659 .76043 m .61659 .25854 L .63713 .26932 L p .707 .577 .707 r
F P
0 g
s
.163 .74561 m .16183 .76316 L .15399 .77529 L p .707 .577 .707 r
F P
0 g
s
.1664 .74385 m .16479 .706 L .18105 .70056 L p .707 .577 .707 r
F P
0 g
s
.34182 .61684 m .34678 .67415 L .32534 .67418 L p .707 .577 .707 r
F P
0 g
s
.32534 .67418 m .32039 .61686 L .34182 .61684 L p .707 .577 .707 r
F P
0 g
s
.18105 .70056 m .18266 .73841 L .1664 .74385 L p .707 .577 .707 r
F P
0 g
s
.18225 .68769 m .1773 .63037 L .20085 .6267 L p .707 .577 .707 r
F P
0 g
s
.20085 .6267 m .20581 .68401 L .18225 .68769 L p .707 .577 .707 r
F P
0 g
s
.3459 .69556 m .34751 .73341 L .32639 .73012 L p .707 .577 .707 r
F P
0 g
s
.32639 .73012 m .32478 .69227 L .3459 .69556 L p .707 .577 .707 r
F P
0 g
s
.16183 .76316 m .163 .74561 L .18002 .73559 L p .707 .577 .707 r
F P
0 g
s
.32039 .61686 m .32534 .67418 L .29768 .67534 L p .707 .577 .707 r
F P
0 g
s
.29768 .67534 m .29273 .61802 L .32039 .61686 L p .707 .577 .707 r
F P
0 g
s
.18266 .73841 m .18105 .70056 L .20501 .6959 L p .707 .577 .707 r
F P
0 g
s
.18002 .73559 m .17885 .75314 L .16183 .76316 L p .707 .577 .707 r
F P
0 g
s
.38319 .25862 m .38319 .76051 L .36276 .7713 L p .707 .577 .707 r
F P
0 g
s
.38319 .76051 m .38319 .25862 L .41506 .25005 L p .707 .577 .707 r
F P
0 g
s
.61659 .25854 m .61659 .76043 L .58463 .75188 L p .707 .577 .707 r
F P
0 g
s
.58463 .75188 m .58463 .24999 L .61659 .25854 L p .707 .577 .707 r
F P
0 g
s
.20581 .68401 m .20085 .6267 L .22988 .62319 L p .707 .577 .707 r
F P
0 g
s
.20501 .6959 m .20662 .73375 L .18266 .73841 L p .707 .577 .707 r
F P
0 g
s
.34435 .75079 m .34319 .76834 L .32278 .75725 L p .707 .577 .707 r
F P
0 g
s
.32278 .75725 m .32394 .7397 L .34435 .75079 L p .707 .577 .707 r
F P
0 g
s
.22988 .62319 m .23483 .68051 L .20581 .68401 L p .707 .577 .707 r
F P
0 g
s
.32478 .69227 m .32639 .73012 L .2989 .72843 L p .707 .577 .707 r
F P
0 g
s
.2989 .72843 m .29729 .69058 L .32478 .69227 L p .707 .577 .707 r
F P
0 g
s
.73351 .67394 m .73846 .62259 L .70727 .61728 L p .707 .577 .707 r
F P
0 g
s
.73846 .62259 m .73351 .67394 L .76516 .6748 L p .707 .577 .707 r
F P
0 g
s
.76516 .6748 m .77012 .62345 L .73846 .62259 L p .707 .577 .707 r
F P
0 g
s
.29273 .61802 m .29768 .67534 L .26649 .67752 L p .707 .577 .707 r
F P
0 g
s
.26649 .67752 m .26154 .62021 L .29273 .61802 L p .707 .577 .707 r
F P
0 g
s
.77012 .62345 m .76516 .6748 L .79419 .67111 L p .707 .577 .707 r
F P
0 g
s
.79419 .67111 m .79914 .61977 L .77012 .62345 L p .707 .577 .707 r
F P
0 g
s
.70232 .66862 m .70727 .61728 L .67961 .60803 L p .707 .577 .707 r
F P
0 g
s
.70727 .61728 m .70232 .66862 L .73351 .67394 L p .707 .577 .707 r
F P
0 g
s
.23483 .68051 m .22988 .62319 L .26154 .62021 L p .707 .577 .707 r
F P
0 g
s
.17885 .75314 m .18002 .73559 L .20454 .72866 L p .707 .577 .707 r
F P
0 g
s
.20662 .73375 m .20501 .6959 L .23432 .69249 L p .707 .577 .707 r
F P
0 g
s
.26154 .62021 m .26649 .67752 L .23483 .68051 L p .707 .577 .707 r
F P
0 g
s
.20454 .72866 m .20338 .74621 L .17885 .75314 L p .707 .577 .707 r
F P
0 g
s
.23432 .69249 m .23593 .73034 L .20662 .73375 L p .707 .577 .707 r
F P
0 g
s
.29729 .69058 m .2989 .72843 L .26773 .7285 L p .707 .577 .707 r
F P
0 g
s
.26773 .7285 m .26612 .69065 L .29729 .69058 L p .707 .577 .707 r
F P
0 g
s
.79914 .61977 m .79419 .67111 L .81775 .66325 L p .707 .577 .707 r
F P
0 g
s
.81775 .66325 m .8227 .61191 L .79914 .61977 L p .707 .577 .707 r
F P
0 g
s
.32394 .7397 m .32278 .75725 L .29579 .74885 L p .707 .577 .707 r
F P
0 g
s
.29579 .74885 m .29695 .7313 L .32394 .7397 L p .707 .577 .707 r
F P
0 g
s
.67466 .65937 m .67961 .60803 L .65817 .59574 L p .707 .577 .707 r
F P
0 g
s
.67961 .60803 m .67466 .65937 L .70232 .66862 L p .707 .577 .707 r
F P
0 g
s
.23593 .73034 m .23432 .69249 L .26612 .69065 L p .707 .577 .707 r
F P
0 g
s
.41506 .75193 m .41506 .25005 L .45525 .24453 L p .707 .577 .707 r
F P
0 g
s
.41506 .25005 m .41506 .75193 L .38319 .76051 L p .707 .577 .707 r
F P
0 g
s
.58463 .24999 m .58463 .75188 L .5444 .74639 L p .707 .577 .707 r
F P
0 g
s
.5444 .74639 m .5444 .2445 L .58463 .24999 L p .707 .577 .707 r
F P
0 g
s
.26612 .69065 m .26773 .7285 L .23593 .73034 L p .707 .577 .707 r
F P
0 g
s
.73227 .72599 m .73388 .69014 L .70271 .68641 L p .707 .577 .707 r
F P
0 g
s
.73388 .69014 m .73227 .72599 L .76406 .72615 L p .707 .577 .707 r
F P
0 g
s
.76406 .72615 m .76567 .6903 L .73388 .69014 L p .707 .577 .707 r
F P
0 g
s
.20338 .74621 m .20454 .72866 L .23418 .72549 L p .707 .577 .707 r
F P
0 g
s
.76567 .6903 m .76406 .72615 L .79338 .72272 L p .707 .577 .707 r
F P
0 g
s
.79338 .72272 m .79499 .68687 L .76567 .6903 L p .707 .577 .707 r
F P
0 g
s
.73514 .74825 m .73398 .72921 L .70305 .73008 L p .707 .577 .707 r
F P
0 g
s
.73398 .72921 m .73514 .74825 L .76698 .74608 L p .707 .577 .707 r
F P
0 g
s
.76698 .74608 m .76582 .72703 L .73398 .72921 L p .707 .577 .707 r
F P
0 g
s
.7011 .72226 m .70271 .68641 L .67522 .67947 L p .707 .577 .707 r
F P
0 g
s
.70271 .68641 m .7011 .72226 L .73227 .72599 L p .707 .577 .707 r
F P
0 g
s
.76582 .72703 m .76698 .74608 L .79662 .74281 L p .707 .577 .707 r
F P
0 g
s
.79662 .74281 m .79545 .72377 L .76582 .72703 L p .707 .577 .707 r
F P
0 g
s
.70305 .73008 m .70421 .74912 L .73514 .74825 L p .707 .577 .707 r
F P
0 g
s
.23418 .72549 m .23302 .74304 L .20338 .74621 L p .707 .577 .707 r
F P
0 g
s
.29695 .7313 m .29579 .74885 L .26486 .74395 L p .707 .577 .707 r
F P
0 g
s
.26486 .74395 m .26602 .7264 L .29695 .7313 L p .707 .577 .707 r
F P
0 g
s
.23302 .74304 m .23418 .72549 L .26602 .7264 L p .707 .577 .707 r
F P
0 g
s
.70421 .74912 m .70305 .73008 L .67606 .72955 L p .707 .577 .707 r
F P
0 g
s
.8227 .61191 m .81775 .66325 L .83353 .65198 L p .707 .577 .707 r
F P
0 g
s
.83353 .65198 m .83848 .60064 L .8227 .61191 L p .707 .577 .707 r
F P
0 g
s
.65322 .64709 m .65817 .59574 L .64507 .58163 L p .707 .577 .707 r
F P
0 g
s
.65817 .59574 m .65322 .64709 L .67466 .65937 L p .707 .577 .707 r
F P
0 g
s
.26602 .7264 m .26486 .74395 L .23302 .74304 L p .707 .577 .707 r
F P
0 g
s
.67606 .72955 m .67722 .7486 L .70421 .74912 L p .707 .577 .707 r
F P
0 g
s
.79499 .68687 m .79338 .72272 L .81734 .71604 L p .707 .577 .707 r
F P
0 g
s
.81734 .71604 m .81895 .68019 L .79499 .68687 L p .707 .577 .707 r
F P
0 g
s
.45525 .74642 m .45525 .24453 L .49981 .24262 L p .707 .577 .707 r
F P
0 g
s
.45525 .24453 m .45525 .74642 L .41506 .75193 L p .707 .577 .707 r
F P
0 g
s
.5444 .2445 m .5444 .74639 L .49981 .74451 L p .707 .577 .707 r
F P
0 g
s
.49981 .74451 m .49981 .24262 L .5444 .2445 L p .707 .577 .707 r
F P
0 g
s
.79545 .72377 m .79662 .74281 L .82114 .73877 L p .707 .577 .707 r
F P
0 g
s
.82114 .73877 m .81998 .71973 L .79545 .72377 L p .707 .577 .707 r
F P
0 g
s
.67522 .67947 m .67361 .71531 L .7011 .72226 L p .707 .577 .707 r
F P
0 g
s
.67361 .71531 m .67522 .67947 L .6541 .67 L p .707 .577 .707 r
F P
0 g
s
.49981 .24262 m .49981 .74451 L .45525 .74642 L p .707 .577 .707 r
F P
0 g
s
.67722 .7486 m .67606 .72955 L .65565 .72769 L p .707 .577 .707 r
F P
0 g
s
.65565 .72769 m .65681 .74673 L .67722 .7486 L p .707 .577 .707 r
F P
0 g
s
.6541 .67 m .65249 .70584 L .67361 .71531 L p .707 .577 .707 r
F P
0 g
s
.81895 .68019 m .81734 .71604 L .8336 .70675 L p .707 .577 .707 r
F P
0 g
s
.8336 .70675 m .83521 .6709 L .81895 .68019 L p .707 .577 .707 r
F P
0 g
s
.81998 .71973 m .82114 .73877 L .83816 .73436 L p .707 .577 .707 r
F P
0 g
s
.83816 .73436 m .837 .71531 L .81998 .71973 L p .707 .577 .707 r
F P
0 g
s
.83848 .60064 m .83353 .65198 L .83999 .6384 L p .707 .577 .707 r
F P
0 g
s
.83999 .6384 m .84494 .58705 L .83848 .60064 L p .707 .577 .707 r
F P
0 g
s
.64012 .63297 m .64507 .58163 L .64158 .56707 L p .707 .577 .707 r
F P
0 g
s
.64507 .58163 m .64012 .63297 L .65322 .64709 L p .707 .577 .707 r
F P
0 g
s
.65249 .70584 m .6541 .67 L .64142 .65892 L p .707 .577 .707 r
F P
0 g
s
.65681 .74673 m .65565 .72769 L .64382 .72467 L p .707 .577 .707 r
F P
0 g
s
.64382 .72467 m .64498 .74371 L .65681 .74673 L p .707 .577 .707 r
F P
0 g
s
.64142 .65892 m .63981 .69477 L .65249 .70584 L p .707 .577 .707 r
F P
0 g
s
.83521 .6709 m .8336 .70675 L .84057 .69578 L p .707 .577 .707 r
F P
0 g
s
.84057 .69578 m .84218 .65993 L .83521 .6709 L p .707 .577 .707 r
F P
0 g
s
.837 .71531 m .83816 .73436 L .84601 .72999 L p .707 .577 .707 r
F P
0 g
s
.84601 .72999 m .84485 .71095 L .837 .71531 L p .707 .577 .707 r
F P
0 g
s
.64158 .56707 m .63662 .61842 L .64012 .63297 L p .707 .577 .707 r
F P
0 g
s
.84494 .58705 m .83999 .6384 L .8365 .62384 L p .707 .577 .707 r
F P
0 g
s
.8365 .62384 m .84145 .5725 L .84494 .58705 L p .707 .577 .707 r
F P
0 g
s
.63662 .61842 m .64158 .56707 L .64804 .55349 L p .707 .577 .707 r
F P
0 g
s
.63981 .69477 m .64142 .65892 L .63842 .64733 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64498 .74371 m .64382 .72467 L .64172 .72079 L p .707 .577 .707 r
F P
0 g
s
.63842 .64733 m .63681 .68318 L .63981 .69477 L p .707 .577 .707 r
F P
0 g
s
.64172 .72079 m .64288 .73983 L .64498 .74371 L p .707 .577 .707 r
F P
0 g
s
.84218 .65993 m .84057 .69578 L .83757 .68418 L p .707 .577 .707 r
F P
0 g
s
.83757 .68418 m .83918 .64834 L .84218 .65993 L p .707 .577 .707 r
F P
0 g
s
.64804 .55349 m .64308 .60484 L .63662 .61842 L p .707 .577 .707 r
F P
0 g
s
.84145 .5725 m .8365 .62384 L .82339 .60973 L p .707 .577 .707 r
F P
0 g
s
.82339 .60973 m .82835 .55838 L .84145 .5725 L p .707 .577 .707 r
F P
0 g
s
.84485 .71095 m .84601 .72999 L .84391 .72611 L p .707 .577 .707 r
F P
0 g
s
.84391 .72611 m .84275 .70707 L .84485 .71095 L p .707 .577 .707 r
F P
0 g
s
.64308 .60484 m .64804 .55349 L .66382 .54222 L p .707 .577 .707 r
F P
0 g
s
.63681 .68318 m .63842 .64733 L .64539 .63636 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38766 .61082 m .39902 .55522 L .36837 .54794 L p .707 .577 .707 r
F P
0 g
s
.39902 .55522 m .38766 .61082 L .41883 .61637 L p .707 .577 .707 r
F P
0 g
s
.41883 .61637 m .43019 .56076 L .39902 .55522 L p .707 .577 .707 r
F P
0 g
s
.43019 .56076 m .41883 .61637 L .44747 .61964 L p .707 .577 .707 r
F P
0 g
s
.44747 .61964 m .45884 .56403 L .43019 .56076 L p .707 .577 .707 r
F P
0 g
s
.64539 .63636 m .64378 .6722 L .63681 .68318 L p .707 .577 .707 r
F P
0 g
s
.35701 .60354 m .36837 .54794 L .34124 .53964 L p .707 .577 .707 r
F P
0 g
s
.36837 .54794 m .35701 .60354 L .38766 .61082 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64288 .73983 m .64172 .72079 L .64957 .71642 L p .707 .577 .707 r
F P
0 g
s
.64957 .71642 m .65073 .73547 L .64288 .73983 L p .707 .577 .707 r
F P
0 g
s
.82835 .55838 m .82339 .60973 L .80196 .59744 L p .707 .577 .707 r
F P
0 g
s
.80196 .59744 m .80691 .5461 L .82835 .55838 L p .707 .577 .707 r
F P
0 g
s
.83918 .64834 m .83757 .68418 L .82489 .67311 L p .707 .577 .707 r
F P
0 g
s
.82489 .67311 m .8265 .63726 L .83918 .64834 L p .707 .577 .707 r
F P
0 g
s
.66382 .54222 m .65887 .59356 L .64308 .60484 L p .707 .577 .707 r
F P
0 g
s
.65887 .59356 m .66382 .54222 L .68738 .53436 L p .707 .577 .707 r
F P
0 g
s
.34124 .53964 m .32988 .59524 L .35701 .60354 L p .707 .577 .707 r
F P
0 g
s
.45884 .56403 m .44747 .61964 L .47078 .62031 L p .707 .577 .707 r
F P
0 g
s
.47078 .62031 m .48215 .56471 L .45884 .56403 L p .707 .577 .707 r
F P
0 g
s
.84275 .70707 m .84391 .72611 L .83208 .72309 L p .707 .577 .707 r
F P
0 g
s
.83208 .72309 m .83092 .70405 L .84275 .70707 L p .707 .577 .707 r
F P
0 g
s
.38724 .67652 m .39099 .63924 L .35995 .63469 L p .707 .577 .707 r
F P
0 g
s
.39099 .63924 m .38724 .67652 L .41892 .67886 L p .707 .577 .707 r
F P
0 g
s
.41892 .67886 m .42267 .64159 L .39099 .63924 L p .707 .577 .707 r
F P
0 g
s
.32988 .59524 m .34124 .53964 L .3203 .53113 L p .707 .577 .707 r
F P
0 g
s
.64378 .6722 m .64539 .63636 L .66165 .62707 L p .707 .577 .707 r
F P
0 g
s
.42267 .64159 m .41892 .67886 L .44814 .67877 L p .707 .577 .707 r
F P
0 g
s
.44814 .67877 m .45188 .64149 L .42267 .64159 L p .707 .577 .707 r
F P
0 g
s
.35621 .67196 m .35995 .63469 L .33259 .62837 L p .707 .577 .707 r
F P
0 g
s
.35995 .63469 m .35621 .67196 L .38724 .67652 L p .707 .577 .707 r
F P
0 g
s
.3203 .53113 m .30893 .58673 L .32988 .59524 L p .707 .577 .707 r
F P
0 g
s
.80691 .5461 m .80196 .59744 L .7743 .58819 L p .707 .577 .707 r
F P
0 g
s
.7743 .58819 m .77925 .53685 L .80691 .5461 L p .707 .577 .707 r
F P
0 g
s
.68242 .5857 m .68738 .53436 L .7164 .53067 L p .707 .577 .707 r
F P
0 g
s
.68738 .53436 m .68242 .5857 L .65887 .59356 L p .707 .577 .707 r
F P
0 g
s
.66165 .62707 m .66004 .66292 L .64378 .6722 L p .707 .577 .707 r
F P
0 g
s
.33259 .62837 m .32885 .66564 L .35621 .67196 L p .707 .577 .707 r
F P
0 g
s
.45188 .64149 m .44814 .67877 L .47204 .67624 L p .707 .577 .707 r
F P
0 g
s
.47204 .67624 m .47578 .63896 L .45188 .64149 L p .707 .577 .707 r
F P
0 g
s
.65073 .73547 m .64957 .71642 L .66659 .71201 L p .707 .577 .707 r
F P
0 g
s
.8265 .63726 m .82489 .67311 L .80377 .66364 L p .707 .577 .707 r
F P
0 g
s
.80377 .66364 m .80538 .62779 L .8265 .63726 L p .707 .577 .707 r
F P
0 g
s
.66659 .71201 m .66775 .73105 L .65073 .73547 L p .707 .577 .707 r
F P
0 g
s
.48215 .56471 m .47078 .62031 L .48648 .61832 L p .707 .577 .707 r
F P
0 g
s
.48648 .61832 m .49784 .56272 L .48215 .56471 L p .707 .577 .707 r
F P
0 g
s
.32885 .66564 m .33259 .62837 L .31159 .6209 L p .707 .577 .707 r
F P
0 g
s
.30893 .58673 m .3203 .53113 L .30757 .52325 L p .707 .577 .707 r
F P
0 g
s
.39764 .72849 m .39492 .71048 L .36428 .71204 L p .707 .577 .707 r
F P
0 g
s
.39492 .71048 m .39764 .72849 L .42923 .72358 L p .707 .577 .707 r
F P
0 g
s
.42923 .72358 m .42651 .70557 L .39492 .71048 L p .707 .577 .707 r
F P
0 g
s
.42651 .70557 m .42923 .72358 L .45866 .71579 L p .707 .577 .707 r
F P
0 g
s
.45866 .71579 m .45594 .69778 L .42651 .70557 L p .707 .577 .707 r
F P
0 g
s
.77925 .53685 m .7743 .58819 L .74311 .58288 L p .707 .577 .707 r
F P
0 g
s
.74311 .58288 m .74806 .53153 L .77925 .53685 L p .707 .577 .707 r
F P
0 g
s
.71145 .58202 m .7164 .53067 L .74806 .53153 L p .707 .577 .707 r
F P
0 g
s
.7164 .53067 m .71145 .58202 L .68242 .5857 L p .707 .577 .707 r
F P
0 g
s
.66004 .66292 m .66165 .62707 L .68561 .62039 L p .707 .577 .707 r
F P
0 g
s
.83092 .70405 m .83208 .72309 L .81167 .72123 L p .707 .577 .707 r
F P
0 g
s
.81167 .72123 m .81051 .70218 L .83092 .70405 L p .707 .577 .707 r
F P
0 g
s
.36428 .71204 m .367 .73005 L .39764 .72849 L p .707 .577 .707 r
F P
0 g
s
.74806 .53153 m .74311 .58288 L .71145 .58202 L p .707 .577 .707 r
F P
0 g
s
.31159 .6209 m .30785 .65818 L .32885 .66564 L p .707 .577 .707 r
F P
0 g
s
.367 .73005 m .36428 .71204 L .33757 .71009 L p .707 .577 .707 r
F P
0 g
s
.30757 .52325 m .29621 .57885 L .30893 .58673 L p .707 .577 .707 r
F P
0 g
s
.45594 .69778 m .45866 .71579 L .48306 .70589 L p .707 .577 .707 r
F P
0 g
s
.48306 .70589 m .48034 .68788 L .45594 .69778 L p .707 .577 .707 r
F P
0 g
s
.47578 .63896 m .47204 .67624 L .48828 .67152 L p .707 .577 .707 r
F P
0 g
s
.48828 .67152 m .49203 .63425 L .47578 .63896 L p .707 .577 .707 r
F P
0 g
s
.33757 .71009 m .34029 .7281 L .367 .73005 L p .707 .577 .707 r
F P
0 g
s
.68561 .62039 m .684 .65623 L .66004 .66292 L p .707 .577 .707 r
F P
0 g
s
.80538 .62779 m .80377 .66364 L .77628 .6567 L p .707 .577 .707 r
F P
0 g
s
.77628 .6567 m .77789 .62085 L .80538 .62779 L p .707 .577 .707 r
F P
0 g
s
.66775 .73105 m .66659 .71201 L .69112 .70797 L p .707 .577 .707 r
F P
0 g
s
.30785 .65818 m .31159 .6209 L .299 .61301 L p .707 .577 .707 r
F P
0 g
s
.684 .65623 m .68561 .62039 L .71492 .61696 L p .707 .577 .707 r
F P
0 g
s
.69112 .70797 m .69228 .72701 L .66775 .73105 L p .707 .577 .707 r
F P
0 g
s
.49784 .56272 m .48648 .61832 L .49303 .61387 L p .707 .577 .707 r
F P
0 g
s
.49303 .61387 m .50439 .55826 L .49784 .56272 L p .707 .577 .707 r
F P
0 g
s
.34029 .7281 m .33757 .71009 L .31741 .70482 L p .707 .577 .707 r
F P
0 g
s
.29621 .57885 m .30757 .52325 L .30433 .51676 L p .707 .577 .707 r
F P
0 g
s
.48034 .68788 m .48306 .70589 L .50003 .69485 L p .707 .577 .707 r
F P
0 g
s
.50003 .69485 m .49731 .67684 L .48034 .68788 L p .707 .577 .707 r
F P
0 g
s
.81051 .70218 m .81167 .72123 L .78468 .72071 L p .707 .577 .707 r
F P
0 g
s
.78468 .72071 m .78352 .70166 L .81051 .70218 L p .707 .577 .707 r
F P
0 g
s
.299 .61301 m .29526 .65029 L .30785 .65818 L p .707 .577 .707 r
F P
0 g
s
.77789 .62085 m .77628 .6567 L .74511 .65296 L p .707 .577 .707 r
F P
0 g
s
.74511 .65296 m .74672 .61712 L .77789 .62085 L p .707 .577 .707 r
F P
0 g
s
.31741 .70482 m .32014 .72283 L .34029 .7281 L p .707 .577 .707 r
F P
0 g
s
.71331 .6528 m .71492 .61696 L .74672 .61712 L p .707 .577 .707 r
F P
0 g
s
.71492 .61696 m .71331 .6528 L .684 .65623 L p .707 .577 .707 r
F P
0 g
s
.30433 .51676 m .29297 .57236 L .29621 .57885 L p .707 .577 .707 r
F P
0 g
s
.74672 .61712 m .74511 .65296 L .71331 .6528 L p .707 .577 .707 r
F P
0 g
s
.69228 .72701 m .69112 .70797 L .72075 .7047 L p .707 .577 .707 r
F P
0 g
s
.49203 .63425 m .48828 .67152 L .49527 .66509 L p .707 .577 .707 r
F P
0 g
s
.49527 .66509 m .49902 .62781 L .49203 .63425 L p .707 .577 .707 r
F P
0 g
s
.72075 .7047 m .72191 .72375 L .69228 .72701 L p .707 .577 .707 r
F P
0 g
s
.78352 .70166 m .78468 .72071 L .75375 .72157 L p .707 .577 .707 r
F P
0 g
s
.75375 .72157 m .75259 .70253 L .78352 .70166 L p .707 .577 .707 r
F P
0 g
s
.29526 .65029 m .299 .61301 L .29606 .60549 L p .707 .577 .707 r
F P
0 g
s
.32014 .72283 m .31741 .70482 L .30578 .69676 L p .707 .577 .707 r
F P
0 g
s
.72191 .72375 m .72075 .7047 L .75259 .70253 L p .707 .577 .707 r
F P
0 g
s
.49731 .67684 m .50003 .69485 L .50792 .68374 L p .707 .577 .707 r
F P
0 g
s
.50792 .68374 m .5052 .66573 L .49731 .67684 L p .707 .577 .707 r
F P
0 g
s
.75259 .70253 m .75375 .72157 L .72191 .72375 L p .707 .577 .707 r
F P
0 g
s
.50439 .55826 m .49303 .61387 L .48978 .60738 L p .707 .577 .707 r
F P
0 g
s
.48978 .60738 m .50114 .55178 L .50439 .55826 L p .707 .577 .707 r
F P
0 g
s
.30578 .69676 m .30851 .71477 L .32014 .72283 L p .707 .577 .707 r
F P
0 g
s
.29606 .60549 m .29232 .64276 L .29526 .65029 L p .707 .577 .707 r
F P
0 g
s
.29297 .57236 m .30433 .51676 L .31087 .5123 L p .707 .577 .707 r
F P
0 g
s
.31087 .5123 m .29951 .56791 L .29297 .57236 L p .707 .577 .707 r
F P
0 g
s
.49902 .62781 m .49527 .66509 L .49233 .65756 L p .707 .577 .707 r
F P
0 g
s
.49233 .65756 m .49608 .62028 L .49902 .62781 L p .707 .577 .707 r
F P
0 g
s
.30851 .71477 m .30578 .69676 L .30382 .68668 L p .708 .578 .707 r
F P
0 g
s
.29232 .64276 m .29606 .60549 L .30305 .59905 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.5052 .66573 m .50792 .68374 L .50596 .67367 L p .708 .578 .707 r
F P
0 g
s
.50596 .67367 m .50324 .65565 L .5052 .66573 L p .708 .578 .707 r
F P
0 g
s
.30382 .68668 m .30654 .70469 L .30851 .71477 L p .708 .578 .707 r
F P
0 g
s
.50114 .55178 m .48978 .60738 L .47706 .5995 L p .707 .577 .707 r
F P
0 g
s
.47706 .5995 m .48842 .54389 L .50114 .55178 L p .707 .577 .707 r
F P
0 g
s
.30305 .59905 m .29931 .63633 L .29232 .64276 L p .707 .577 .707 r
F P
0 g
s
.29951 .56791 m .31087 .5123 L .32657 .51031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32657 .51031 m .31521 .56592 L .29951 .56791 L p .707 .577 .707 r
F P
0 g
s
.49608 .62028 m .49233 .65756 L .47975 .64967 L p .707 .577 .707 r
F P
0 g
s
.47975 .64967 m .48349 .6124 L .49608 .62028 L p .707 .577 .707 r
F P
0 g
s
.30654 .70469 m .30382 .68668 L .31171 .67557 L p .707 .577 .707 r
F P
0 g
s
.29931 .63633 m .30305 .59905 L .31929 .59434 L p .707 .577 .707 r
F P
0 g
s
.50324 .65565 m .50596 .67367 L .49433 .6656 L p .707 .577 .707 r
F P
0 g
s
.49433 .6656 m .49161 .64759 L .50324 .65565 L p .707 .577 .707 r
F P
0 g
s
.48842 .54389 m .47706 .5995 L .45611 .59099 L p .707 .577 .707 r
F P
0 g
s
.45611 .59099 m .46747 .53538 L .48842 .54389 L p .707 .577 .707 r
F P
0 g
s
.31171 .67557 m .31443 .69359 L .30654 .70469 L p .707 .577 .707 r
F P
0 g
s
.31521 .56592 m .32657 .51031 L .34988 .51099 L p .707 .577 .707 r
F P
0 g
s
.31929 .59434 m .31555 .63161 L .29931 .63633 L p .707 .577 .707 r
F P
0 g
s
.34988 .51099 m .33852 .56659 L .31521 .56592 L p .707 .577 .707 r
F P
0 g
s
.48349 .6124 m .47975 .64967 L .45875 .6422 L p .707 .577 .707 r
F P
0 g
s
.45875 .6422 m .46249 .60493 L .48349 .6124 L p .707 .577 .707 r
F P
0 g
s
.46747 .53538 m .45611 .59099 L .42898 .58269 L p .707 .577 .707 r
F P
0 g
s
.42898 .58269 m .44035 .52708 L .46747 .53538 L p .707 .577 .707 r
F P
0 g
s
.31555 .63161 m .31929 .59434 L .34319 .59181 L p .707 .577 .707 r
F P
0 g
s
.31443 .69359 m .31171 .67557 L .32869 .66453 L p .707 .577 .707 r
F P
0 g
s
.33852 .56659 m .34988 .51099 L .37853 .51426 L p .707 .577 .707 r
F P
0 g
s
.49161 .64759 m .49433 .6656 L .47417 .66033 L p .707 .577 .707 r
F P
0 g
s
.47417 .66033 m .47145 .64232 L .49161 .64759 L p .707 .577 .707 r
F P
0 g
s
.32869 .66453 m .33141 .68254 L .31443 .69359 L p .707 .577 .707 r
F P
0 g
s
.34319 .59181 m .33945 .62908 L .31555 .63161 L p .707 .577 .707 r
F P
0 g
s
.37853 .51426 m .36716 .56986 L .33852 .56659 L p .707 .577 .707 r
F P
0 g
s
.44035 .52708 m .42898 .58269 L .39833 .57541 L p .707 .577 .707 r
F P
0 g
s
.39833 .57541 m .4097 .5198 L .44035 .52708 L p .707 .577 .707 r
F P
0 g
s
.36716 .56986 m .37853 .51426 L .4097 .5198 L p .707 .577 .707 r
F P
0 g
s
.46249 .60493 m .45875 .6422 L .43139 .63588 L p .707 .577 .707 r
F P
0 g
s
.43139 .63588 m .43513 .59861 L .46249 .60493 L p .707 .577 .707 r
F P
0 g
s
.4097 .5198 m .39833 .57541 L .36716 .56986 L p .707 .577 .707 r
F P
0 g
s
.33945 .62908 m .34319 .59181 L .37241 .59171 L p .707 .577 .707 r
F P
0 g
s
.33141 .68254 m .32869 .66453 L .35308 .65463 L p .707 .577 .707 r
F P
0 g
s
.47145 .64232 m .47417 .66033 L .44747 .65838 L p .707 .577 .707 r
F P
0 g
s
.44747 .65838 m .44475 .64037 L .47145 .64232 L p .707 .577 .707 r
F P
0 g
s
.37241 .59171 m .36867 .62898 L .33945 .62908 L p .707 .577 .707 r
F P
0 g
s
.43513 .59861 m .43139 .63588 L .40035 .63133 L p .707 .577 .707 r
F P
0 g
s
.40035 .63133 m .40409 .59405 L .43513 .59861 L p .707 .577 .707 r
F P
0 g
s
.35308 .65463 m .3558 .67264 L .33141 .68254 L p .707 .577 .707 r
F P
0 g
s
.36867 .62898 m .37241 .59171 L .40409 .59405 L p .707 .577 .707 r
F P
0 g
s
.40409 .59405 m .40035 .63133 L .36867 .62898 L p .707 .577 .707 r
F P
0 g
s
.3558 .67264 m .35308 .65463 L .38251 .64685 L p .707 .577 .707 r
F P
0 g
s
.44475 .64037 m .44747 .65838 L .41682 .65994 L p .707 .577 .707 r
F P
0 g
s
.41682 .65994 m .4141 .64193 L .44475 .64037 L p .707 .577 .707 r
F P
0 g
s
.38251 .64685 m .38524 .66486 L .3558 .67264 L p .707 .577 .707 r
F P
0 g
s
.38524 .66486 m .38251 .64685 L .4141 .64193 L p .707 .577 .707 r
F P
0 g
s
.4141 .64193 m .41682 .65994 L .38524 .66486 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPH007Aoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1000L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001WOol006Ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P00
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001VOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol@0004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`<000=JEP03001JEUYF00AJEP04001J
EUYFFUH90005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EWoo0P000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000aJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00011oo`P004eoo`00EGoo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF00002Woo1P000eYF00<005YFFUH00UYF2@00A7oo001EOol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30008FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00008Ool2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000nOol005Eoo`8000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP00008000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000Ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
000lOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000Aoo`8000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH3000iOol005Aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP8003Moo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001oo`800003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Eoo`00E7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=oo`00E7oo00<005YF0000
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo00=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH015YF0P00<7oo001COol00`00FUH00002FUH50003FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0002moo`00Dgoo00<005YF00000`0015YF1`0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00aJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYF000^Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005=o
o`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPH000IJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH00UYF40001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
02aoo`00Egoo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YF000000AJEP03001JEUYF00AJEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP02FUH6000@Ool40002FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002aoo`00F7oo0P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00@005YFFUIJEP<0
00]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEP00
008001Yoo`@000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;7oo001JOol200000eYF0000
000F0003FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH2000QOol400000eYF001JEP05FUH01`00FUIJ
EUYF001JEP0002aoo`00FGoo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF00<005YFFUH00`0000=JEP00FUH00eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF0P005Goo0`003Woo0P001UYF00L005YFFUIJEP00FUH0000/Ool005Ioo`<0
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001J
EUYF00=JEP8000=JEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2000015YF000005YF0`004Woo1@003goo0P0015YF00@005YFFUIJEP8002eoo`00EGoo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
1EYF00L005YF000005YF001JEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP02000@Ool5000AOol20002FUH01000FUIJEUYF0P00;Goo001DOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH400000eYF001JEP02FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH3000=Ool5000COol30003FUH2000]
Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP000080009JEP<00003FUH005YF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP04001JEP00000<Ool3000F
Ool01000FUIJEUYF0P00;Goo001DOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000015YF001JEP00
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00@0
05YFFUIJEP<0021oo`800006FUH005YF001JEP00;Goo001?Ool70003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUHB000<Ool3000025YF001JEP00FUH005YF000]Ool004Io
o`T000AJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00=JEPL000AJEP03001JEUYF00IJEP03
001JEUYF009JEP`000AJEP03001JEUYF00800003FUH007oo02aoo`00?Woo200015YF00<005YFFUH0
1UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040005FUH01`00FUIJEUYF001JEP0002eoo`00=Woo
20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P00;Woo000`Ool6
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH500000eYF
001JEP0600000eYF001JEP03FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0009J
EP04001JEUYFFUH2000^Ool002eoo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000<000EJEP03001JEUYF00=JEPL00003FUH005YF00D0009J
EPL000IJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF0P00;Woo000/Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP05FUH40002FUH00`00FUIJEP03FUH0
1000FUIJEUYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF
6P000eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF1000;goo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF0000009JEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUH000EJEP03001JEUYF00IJEP<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF00=JEP<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF008000YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEPH00003FUH005YF00IJEP03
001JEUYF00EJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP03001JEP0000<00003FUH005YF00MJEP03001JEUYF00AJEQ@000AJEP04001JEUYF000:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUH000030006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF00000005FUH00`00FUIJEP06FUH00`00FUIJEP04
0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0000200001EYF001JEUYF00002UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF0`000eYF0P0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00@005YFFUIJEP8002eoo`00;7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001eYF00<005YFFUH015YF10001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
009JEP80009JEP03001JEUYF00=JEP<00003FUH005YF00MJEP@000EJEP03001JEUYF00EJEP03001J
EP0000<000=JEP04001JEUYFFUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03
001JEUYF00@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000015YF000000002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF1@000eYF00<0
05YFFUH00eYF00<005YFFUH01P0015YF1@0015YF00<005YFFUH00UYF1@0017oo0P0000=JEP00FUH0
0UYF0P00;Goo000]Ool00eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF1P0015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000AJEP8000YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00=JEP80009JEP<0009JEP03001JEUYF009JEP04001JEUYF0005OolB000;
Ool20003FUH2000]Ool002eoo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQ8000EJEP04001JEUYFFUH4000015YF001JEUYF2@0015YF00<005YFFUH01EYF00@005YF
FUIJEPD000EJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0002FUH00`00FUIJEP030005FUH01000FUIJEP0027oo1@0057oo0`000UYF00<007ooOol0;7oo000]
Ool2FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF200000=JEP00FUH025YF00<005YFFUH00UYF
0P001EYF00D005YF000005YF00<00003FUH005YF00=JEP03001JEUYF00<00003FUH0000000h000QJ
EP<0009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH00004FUH30003FUH01000FUIJEP002Goo0`004goo0P000eYF0`00;Woo000]Ool2FUH01@00
FUIJEUYF00000eYF200000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1@00
0Woo00<005YF000015YF00<005YF000010000UYF00<005YFFUH02EYF00<005YFFUH01EYF0P000UYF
00@005YFFUH000UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0005FUH00`00FUH000030002FUH00`00Oomoo`0IOol400000eYF001JEP03FUH2000^Ool002eoo`9J
EP03001JEUYF00D00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP020007Ool00`00FUH00004FUH00`00FUH000040002FUH00`00FUIJEP09FUH0
0`00FUIJEP03FUH20005FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00001EYF00<005YFFUH00eYF1`004Woo1@001EYF00L005YFFUIJEP00FUH0000^Ool0
02eoo`9JEP@000EJEP03001JEUYF00AJEQP0009JEPH000Ioo`03001JEP0000AJEP03001JEP0000@0
009JEP03001JEUYF00UJEP04001JEUYFFUH200000eYF001JEP04FUH2000:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH0
0UYF4P000eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`8000=JEP03001JEUYF
00=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYF0002FUH4
0002Ool00`00FUH00004FUH00`00FUIJEP030003FUH00`00FUIJEP09FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo000^Ool;00000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00FUIJEP03FUH400000eYF001JEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH30006FUH00`00FUIJEP03000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000aOol4
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00
FUIJEP03FUH01P00FUIJEP00FUH000AJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF
00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEQT000=JEP8002moo`00;Woo0`000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF000005YF
00@000EJEP06001JEUYF001JEP0015YF00<005YFFUH01UYF00<005YF000010001EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YF001JEP0000EJEP03001JEUYF00EJEP03001JEP0000L000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00D002moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00H0009JEP03001JEP0000AJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00IJEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH20003FUH00`00FUH00007
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00@005YFFUIJEQ0000IJEP03001JEUYF
00IJEP04001JEP000008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUH00000FUH01`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00D0
05YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00D000aJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
1@0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4P000eYF400000=JEP00
0000;7oo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YF
FUH01EYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUIJEPP000=ooa8000AJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00;7oo
00@005YFFUH000=JEP03001JEUYF00=JEPH000=JEP03001JEUYF00IJEP03001JEUYF009JER@00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP800003FUH005YF009JEQT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0002aoo`00;Goo00<005YF00000eYF00<005YF00000`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0005FUH5000015YF001JEP0015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;Goo
00<005YF00000eYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<000EJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000015YF000000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YF0000031oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5000bOol002eoo`04
001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP05FUH300000eYF
001JEP03FUH00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL003Moo`00;Goo0P000eYF
00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01EYF1P001UYF00<005YFFUH00P0015YF
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF30001UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YF001JEP/000AJEP03001JEUYF009JEQ8003ioo`00
;Goo0P000eYF00<005YF00000`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH00eYF00<005YFFUH01EYF20001EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF20001eYF00<005YFFUH00eYF00<005YF
0000200015YF2@00D7oo000]Ool20003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP04FUH20002Ool00`00FUH00004FUH00`00FUIJ
EP02FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUH000020004FUH00`00FUIJEP03FUH00`00FUH00008Ool300000eYF001JEP02FUH00`00Oomo
o`1BOol002aoo`03001JEP00009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPH000EJEP07001JEP00Ool005YF000015YF00<005YF00000P001EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF0`00
00=JEP00FUH015YF00<005YF000027oo0P0000=JEP0000000eYF0P00Dgoo000/Ool00`00FUH00002
0003Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006Ool20003FUH00`00FUIJEP020000
0eYF001JEP03FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH20005FUH00`00FUH00006Ool200000eYF001JEP02FUH200000eYF0000
001COol002aoo`03001JEP0000aooa80015oo`800003FUH005YF009JEP03001JEP00009JEP<000UJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP<000=JEP03001JEP0000Aoo`8000=JEP03001JEUYF009JEP@005=oo`00:goo00<005YF0000<Woo
0P000eYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P0000EJEP00FUH007oo00<0
00EJEP03001JEUYF00=JEP<005=oo`00:goo0P006goo0`005goo00H005YFFUH005YF0004FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200001EYF000005YF00001UYF00<005YFFUH00eYF00<005YF0000
Dgoo000[Ool3000IOol5000FOol00`00FUH000030004FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0001COol002]oo`800003FUH0000001Mo
o`D001Moo`D000AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP<0009JEP03001JEUYF00EJEP03001J
EUYF009JEP8005Aoo`00:goo0P000eYF00<007ooOol057oo1@0067oo0P0000=JEP00FUH00eYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
E7oo000/Ool01000FUIJEUYF0`005Goo0`0067oo0`0000=JEP00FUH00eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0Dgoo000/Ool01@00
FUIJEUYF00000UYF0P00;Woo00<005YF00000P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
15YF00<005YFFUH015YF00<005YFFUH00P00EWoo000]Ool00`00FUH00005FUH2000ZOol3000015YF
0000000015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH015YF0`00
F7oo000^Ool20005FUH01000FUH000009Woo0P000UYF0P000Woo00<005YFFUH00UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF1@0000=JEP00FUH015YF0P00FWoo000_Ool00`00FUIJEP03FUH01000FUIJ
EUYF0`008Goo0P0015YF0P000goo0P000UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000EJEPL005ao
o`00<7oo0P000eYF00<005YFFUH015YF1P005goo100000=JEP00FUH00eYF00<007ooOol017oo0`00
2EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YF00000P0025YF00<005YF00000P00G7oo000bOol200000eYF001JEP06FUH00`00FUIJ
EP02FUHG0005FUH00`00FUIJEP02FUH00`00Oomoo`06Ool30007FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001JOol003Aoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF008000aoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0009JEPH000IJEP03001JEUYF00AJEP<0
05Qoo`00=goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`004goo1@0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF2`001Woo1000
0UYF00<005YFFUH015YF00@005YFFUH005Moo`00>Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P006Woo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000Eoo`D000]oo`<000EJEP05001JEUYFFUH0001GOol003aoo`H000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000<0029oob4000Uoo`D000ioo`8000=JEP05001JEUYF
FUH0001GOol0049ooaL003Ioo`8000AJEP03001JEUYF00EJEP03001JEUYF00@000Ioo`<0015oo`80
0004FUH005YFFUH2001GOol0095oo`<00003FUH005YF00IJEP03001JEUYF00AJEPL001Eoo`80009J
EP8005Moo`00U7oo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF5P0000=JEP0000000P00Egoo
002GOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3001GOol009]oo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P00Egoo002OOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01P00FUIJEUYF001JEP8005Moo`00Xgoo1`0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00FGoo002ZOol90004FUH01000FUIJEUYF1P00G7oo002cOol8001ROol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]57\[InvisibleSpace]"     "\
\[InvisibleSpace]13.645329329759143`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 57, "     ", 13.645329329759143, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59053 .75449 m .60276 .70169 L .57237 .69293 L p .707 .577 .707 r
F P
0 g
s
.60276 .70169 m .59053 .75449 L .62167 .75991 L p .707 .577 .707 r
F P
0 g
s
.62167 .75991 m .6339 .70711 L .60276 .70169 L p .707 .577 .707 r
F P
0 g
s
.56013 .74573 m .57237 .69293 L .54568 .68167 L p .707 .577 .707 r
F P
0 g
s
.57237 .69293 m .56013 .74573 L .59053 .75449 L p .707 .577 .707 r
F P
0 g
s
.6339 .70711 m .62167 .75991 L .65049 .76144 L p .707 .577 .707 r
F P
0 g
s
.65049 .76144 m .66273 .70864 L .6339 .70711 L p .707 .577 .707 r
F P
0 g
s
.53345 .73447 m .54568 .68167 L .52533 .66903 L p .707 .577 .707 r
F P
0 g
s
.54568 .68167 m .53345 .73447 L .56013 .74573 L p .707 .577 .707 r
F P
0 g
s
.66273 .70864 m .65049 .76144 L .67419 .75895 L p .707 .577 .707 r
F P
0 g
s
.67419 .75895 m .68642 .70615 L .66273 .70864 L p .707 .577 .707 r
F P
0 g
s
.59381 .81317 m .59625 .77647 L .56515 .7725 L p .707 .577 .707 r
F P
0 g
s
.59625 .77647 m .59381 .81317 L .62559 .81426 L p .707 .577 .707 r
F P
0 g
s
.62559 .81426 m .62803 .77755 L .59625 .77647 L p .707 .577 .707 r
F P
0 g
s
.62803 .77755 m .62559 .81426 L .65492 .81236 L p .707 .577 .707 r
F P
0 g
s
.65492 .81236 m .65736 .77566 L .62803 .77755 L p .707 .577 .707 r
F P
0 g
s
.56271 .8092 m .56515 .7725 L .53776 .76603 L p .707 .577 .707 r
F P
0 g
s
.56515 .7725 m .56271 .8092 L .59381 .81317 L p .707 .577 .707 r
F P
0 g
s
.60625 .84511 m .60344 .82651 L .57263 .82943 L p .707 .577 .707 r
F P
0 g
s
.60344 .82651 m .60625 .84511 L .63775 .83998 L p .707 .577 .707 r
F P
0 g
s
.63775 .83998 m .63494 .82138 L .60344 .82651 L p .707 .577 .707 r
F P
0 g
s
.63494 .82138 m .63775 .83998 L .66687 .83315 L p .707 .577 .707 r
F P
0 g
s
.66687 .83315 m .66407 .81455 L .63494 .82138 L p .707 .577 .707 r
F P
0 g
s
.52533 .66903 m .51309 .72183 L .53345 .73447 L p .707 .577 .707 r
F P
0 g
s
.57263 .82943 m .57544 .84803 L .60625 .84511 L p .707 .577 .707 r
F P
0 g
s
.51309 .72183 m .52533 .66903 L .51329 .65623 L p .707 .577 .707 r
F P
0 g
s
.65736 .77566 m .65492 .81236 L .67894 .80766 L p .707 .577 .707 r
F P
0 g
s
.67894 .80766 m .68138 .77096 L .65736 .77566 L p .707 .577 .707 r
F P
0 g
s
.68642 .70615 m .67419 .75895 L .69044 .75267 L p .707 .577 .707 r
F P
0 g
s
.69044 .75267 m .70267 .69987 L .68642 .70615 L p .707 .577 .707 r
F P
0 g
s
.53776 .76603 m .53532 .80274 L .56271 .8092 L p .707 .577 .707 r
F P
0 g
s
.57544 .84803 m .57263 .82943 L .54554 .82987 L p .707 .577 .707 r
F P
0 g
s
.53532 .80274 m .53776 .76603 L .51676 .75771 L p .707 .577 .707 r
F P
0 g
s
.54554 .82987 m .54835 .84846 L .57544 .84803 L p .707 .577 .707 r
F P
0 g
s
.66407 .81455 m .66687 .83315 L .69076 .82528 L p .707 .577 .707 r
F P
0 g
s
.69076 .82528 m .68795 .80668 L .66407 .81455 L p .707 .577 .707 r
F P
0 g
s
.51676 .75771 m .51433 .79442 L .53532 .80274 L p .707 .577 .707 r
F P
0 g
s
.51329 .65623 m .50105 .70903 L .51309 .72183 L p .707 .577 .707 r
F P
0 g
s
.54835 .84846 m .54554 .82987 L .52481 .82776 L p .707 .577 .707 r
F P
0 g
s
.68138 .77096 m .67894 .80766 L .6953 .80062 L p .707 .577 .707 r
F P
0 g
s
.6953 .80062 m .69774 .76392 L .68138 .77096 L p .707 .577 .707 r
F P
0 g
s
.52481 .82776 m .52762 .84636 L .54835 .84846 L p .707 .577 .707 r
F P
0 g
s
.50105 .70903 m .51329 .65623 L .51075 .64453 L p .707 .577 .707 r
F P
0 g
s
.70267 .69987 m .69044 .75267 L .69764 .74322 L p .707 .577 .707 r
F P
0 g
s
.69764 .74322 m .70988 .69042 L .70267 .69987 L p .707 .577 .707 r
F P
0 g
s
.68795 .80668 m .69076 .82528 L .70707 .81715 L p .707 .577 .707 r
F P
0 g
s
.70707 .81715 m .70426 .79855 L .68795 .80668 L p .707 .577 .707 r
F P
0 g
s
.51433 .79442 m .51676 .75771 L .50422 .74835 L p .707 .577 .707 r
F P
0 g
s
.50422 .74835 m .50178 .78506 L .51433 .79442 L p .707 .577 .707 r
F P
0 g
s
.52762 .84636 m .52481 .82776 L .51248 .82333 L p .707 .577 .707 r
F P
0 g
s
.51075 .64453 m .49851 .69733 L .50105 .70903 L p .707 .577 .707 r
F P
0 g
s
.69774 .76392 m .6953 .80062 L .70239 .79193 L p .707 .577 .707 r
F P
0 g
s
.70239 .79193 m .70483 .75523 L .69774 .76392 L p .707 .577 .707 r
F P
0 g
s
.51248 .82333 m .51529 .84193 L .52762 .84636 L p .707 .577 .707 r
F P
0 g
s
.70426 .79855 m .70707 .81715 L .71421 .80955 L p .707 .577 .707 r
F P
0 g
s
.71421 .80955 m .7114 .79095 L .70426 .79855 L p .707 .577 .707 r
F P
0 g
s
.50178 .78506 m .50422 .74835 L .50136 .73886 L p .707 .577 .707 r
F P
0 g
s
.49851 .69733 m .51075 .64453 L .51795 .63508 L p .707 .577 .707 r
F P
0 g
s
.70988 .69042 m .69764 .74322 L .6951 .73152 L p .707 .577 .707 r
F P
0 g
s
.6951 .73152 m .70734 .67872 L .70988 .69042 L p .707 .577 .707 r
F P
0 g
s
.47507 .82195 m .49813 .32311 L .45417 .31838 L p .707 .577 .707 r
F P
0 g
s
.50136 .73886 m .49892 .77556 L .50178 .78506 L p .707 .577 .707 r
F P
0 g
s
.51529 .84193 m .51248 .82333 L .50975 .81701 L p .707 .577 .707 r
F P
0 g
s
.51795 .63508 m .50572 .68788 L .49851 .69733 L p .707 .577 .707 r
F P
0 g
s
.50975 .81701 m .51256 .83561 L .51529 .84193 L p .707 .577 .707 r
F P
0 g
s
.50572 .68788 m .51795 .63508 L .5342 .6288 L p .707 .577 .707 r
F P
0 g
s
.49892 .77556 m .50136 .73886 L .50845 .73016 L p .707 .577 .707 r
F P
0 g
s
.50845 .73016 m .50601 .76687 L .49892 .77556 L p .707 .577 .707 r
F P
0 g
s
.51256 .83561 m .50975 .81701 L .51689 .80941 L p .707 .577 .707 r
F P
0 g
s
.5342 .6288 m .52197 .6816 L .50572 .68788 L p .707 .577 .707 r
F P
0 g
s
.51689 .80941 m .5197 .82801 L .51256 .83561 L p .707 .577 .707 r
F P
0 g
s
.50601 .76687 m .50845 .73016 L .52481 .72312 L p .707 .577 .707 r
F P
0 g
s
.52481 .72312 m .52237 .75983 L .50601 .76687 L p .707 .577 .707 r
F P
0 g
s
.5197 .82801 m .51689 .80941 L .5332 .80128 L p .707 .577 .707 r
F P
0 g
s
.49813 .32311 m .47507 .82195 L .51998 .8227 L p .707 .577 .707 r
F P
0 g
s
.52197 .6816 m .5342 .6288 L .5579 .62631 L p .707 .577 .707 r
F P
0 g
s
.5579 .62631 m .54566 .67911 L .52197 .6816 L p .707 .577 .707 r
F P
0 g
s
.52237 .75983 m .52481 .72312 L .54883 .71843 L p .707 .577 .707 r
F P
0 g
s
.54883 .71843 m .54639 .75513 L .52237 .75983 L p .707 .577 .707 r
F P
0 g
s
.51998 .8227 m .54303 .32385 L .49813 .32311 L p .707 .577 .707 r
F P
0 g
s
.54566 .67911 m .5579 .62631 L .58672 .62784 L p .707 .577 .707 r
F P
0 g
s
.5332 .80128 m .53601 .81987 L .5197 .82801 L p .707 .577 .707 r
F P
0 g
s
.58672 .62784 m .57449 .68064 L .54566 .67911 L p .707 .577 .707 r
F P
0 g
s
.53601 .81987 m .5332 .80128 L .55709 .79341 L p .707 .577 .707 r
F P
0 g
s
.54639 .75513 m .54883 .71843 L .57816 .71653 L p .707 .577 .707 r
F P
0 g
s
.55709 .79341 m .5599 .81201 L .53601 .81987 L p .707 .577 .707 r
F P
0 g
s
.57816 .71653 m .57572 .75323 L .54639 .75513 L p .707 .577 .707 r
F P
0 g
s
.5599 .81201 m .55709 .79341 L .58621 .78658 L p .707 .577 .707 r
F P
0 g
s
.58621 .78658 m .58902 .80517 L .5599 .81201 L p .707 .577 .707 r
F P
0 g
s
.54303 .32385 m .51998 .8227 L .56142 .81939 L p .707 .577 .707 r
F P
0 g
s
.56142 .81939 m .58448 .32054 L .54303 .32385 L p .707 .577 .707 r
F P
0 g
s
.43111 .81723 m .45417 .31838 L .41545 .31014 L p .707 .577 .707 r
F P
0 g
s
.45417 .31838 m .43111 .81723 L .47507 .82195 L p .707 .577 .707 r
F P
0 g
s
.70483 .75523 m .70239 .79193 L .69953 .78244 L p .707 .577 .707 r
F P
0 g
s
.69953 .78244 m .70197 .74573 L .70483 .75523 L p .707 .577 .707 r
F P
0 g
s
.57449 .68064 m .58672 .62784 L .61786 .63326 L p .707 .577 .707 r
F P
0 g
s
.61786 .63326 m .60563 .68606 L .57449 .68064 L p .707 .577 .707 r
F P
0 g
s
.57572 .75323 m .57816 .71653 L .60994 .71762 L p .707 .577 .707 r
F P
0 g
s
.60994 .71762 m .6075 .75432 L .57572 .75323 L p .707 .577 .707 r
F P
0 g
s
.58902 .80517 m .58621 .78658 L .61772 .78145 L p .707 .577 .707 r
F P
0 g
s
.61772 .78145 m .62053 .80005 L .58902 .80517 L p .707 .577 .707 r
F P
0 g
s
.58448 .32054 m .56142 .81939 L .59536 .81235 L p .707 .577 .707 r
F P
0 g
s
.59536 .81235 m .61842 .31351 L .58448 .32054 L p .707 .577 .707 r
F P
0 g
s
.7114 .79095 m .71421 .80955 L .71148 .80322 L p .707 .577 .707 r
F P
0 g
s
.71148 .80322 m .70867 .78462 L .7114 .79095 L p .707 .577 .707 r
F P
0 g
s
.70734 .67872 m .6951 .73152 L .68306 .71872 L p .707 .577 .707 r
F P
0 g
s
.68306 .71872 m .6953 .66592 L .70734 .67872 L p .707 .577 .707 r
F P
0 g
s
.3924 .80898 m .41545 .31014 L .38577 .29919 L p .707 .577 .707 r
F P
0 g
s
.41545 .31014 m .3924 .80898 L .43111 .81723 L p .707 .577 .707 r
F P
0 g
s
.24752 .7189 m .25976 .6661 L .22936 .65734 L p .707 .577 .707 r
F P
0 g
s
.25976 .6661 m .24752 .7189 L .27866 .72432 L p .707 .577 .707 r
F P
0 g
s
.27866 .72432 m .29089 .67152 L .25976 .6661 L p .707 .577 .707 r
F P
0 g
s
.21712 .71014 m .22936 .65734 L .20267 .64608 L p .707 .577 .707 r
F P
0 g
s
.22936 .65734 m .21712 .71014 L .24752 .7189 L p .707 .577 .707 r
F P
0 g
s
.29089 .67152 m .27866 .72432 L .30748 .72585 L p .707 .577 .707 r
F P
0 g
s
.30748 .72585 m .31972 .67305 L .29089 .67152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70197 .74573 m .69953 .78244 L .68699 .77307 L p .707 .577 .707 r
F P
0 g
s
.68699 .77307 m .68942 .73637 L .70197 .74573 L p .707 .577 .707 r
F P
0 g
s
.19044 .69888 m .20267 .64608 L .18232 .63344 L p .707 .577 .707 r
F P
0 g
s
.20267 .64608 m .19044 .69888 L .21712 .71014 L p .707 .577 .707 r
F P
0 g
s
.64826 .64202 m .63602 .69482 L .60563 .68606 L p .707 .577 .707 r
F P
0 g
s
.60563 .68606 m .61786 .63326 L .64826 .64202 L p .707 .577 .707 r
F P
0 g
s
.64104 .72159 m .6386 .75829 L .6075 .75432 L p .707 .577 .707 r
F P
0 g
s
.6075 .75432 m .60994 .71762 L .64104 .72159 L p .707 .577 .707 r
F P
0 g
s
.62053 .80005 m .61772 .78145 L .64852 .77852 L p .707 .577 .707 r
F P
0 g
s
.61842 .31351 m .59536 .81235 L .61846 .80227 L p .707 .577 .707 r
F P
0 g
s
.61846 .80227 m .64152 .30343 L .61842 .31351 L p .707 .577 .707 r
F P
0 g
s
.31972 .67305 m .30748 .72585 L .33118 .72336 L p .707 .577 .707 r
F P
0 g
s
.33118 .72336 m .34342 .67056 L .31972 .67305 L p .707 .577 .707 r
F P
0 g
s
.6953 .66592 m .68306 .71872 L .66271 .70608 L p .707 .577 .707 r
F P
0 g
s
.66271 .70608 m .67494 .65328 L .6953 .66592 L p .707 .577 .707 r
F P
0 g
s
.2508 .7733 m .25324 .73659 L .22214 .73262 L p .707 .577 .707 r
F P
0 g
s
.25324 .73659 m .2508 .7733 L .28258 .77439 L p .707 .577 .707 r
F P
0 g
s
.28258 .77439 m .28502 .73768 L .25324 .73659 L p .707 .577 .707 r
F P
0 g
s
.70867 .78462 m .71148 .80322 L .69915 .79879 L p .707 .577 .707 r
F P
0 g
s
.69915 .79879 m .69634 .78019 L .70867 .78462 L p .707 .577 .707 r
F P
0 g
s
.28502 .73768 m .28258 .77439 L .31191 .77249 L p .707 .577 .707 r
F P
0 g
s
.31191 .77249 m .31435 .73578 L .28502 .73768 L p .707 .577 .707 r
F P
0 g
s
.2197 .76933 m .22214 .73262 L .19475 .72616 L p .707 .577 .707 r
F P
0 g
s
.22214 .73262 m .2197 .76933 L .2508 .7733 L p .707 .577 .707 r
F P
0 g
s
.35463 .70763 m .36687 .65483 L .35966 .66428 L p .707 .577 .707 r
F P
0 g
s
.34494 .77541 m .34775 .79401 L .35781 .78899 L p .707 .577 .707 r
F P
0 g
s
.35781 .78899 m .36406 .78587 L p .35789 .7825 L .707 .577 .707 r
F P
0 g
s
.35789 .7825 m .34494 .77541 L .35781 .78899 L .707 .577 .707 r
F
.34743 .71708 m .35966 .66428 L .34342 .67056 L p F P
0 g
s
.34775 .79401 m .34494 .77541 L .32106 .78327 L p .707 .577 .707 r
F P
0 g
s
.33837 .73108 m .33593 .76779 L .35229 .76075 L p .707 .577 .707 r
F P
0 g
s
.35229 .76075 m .35473 .72404 L .33837 .73108 L p .707 .577 .707 r
F P
0 g
s
.35966 .66428 m .34743 .71708 L .35463 .70763 L p .707 .577 .707 r
F P
0 g
s
.36406 .78587 m .36125 .76728 L .34494 .77541 L p .707 .577 .707 r
F P
0 g
s
.34342 .67056 m .33118 .72336 L .34743 .71708 L p .707 .577 .707 r
F P
0 g
s
.35209 .69593 m .34005 .68313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.36433 .64313 m .35415 .68707 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35415 .68707 m .35209 .69593 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35541 .5041 m .36243 .40758 L .36396 .2736 L .707 .577 .707 r
F
.34005 .68313 m .35229 .63033 L .35452 .6327 L p F P
0 g
s
.35452 .6327 m .36433 .64313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.34005 .68313 m .35452 .6327 L .35433 .6596 L .707 .577 .707 r
F
.35473 .72404 m .35229 .76075 L .35939 .75206 L p F P
0 g
s
.35939 .75206 m .36182 .71535 L .35473 .72404 L p .707 .577 .707 r
F P
0 g
s
.35896 .70586 m .35652 .74257 L .34398 .7332 L p .707 .577 .707 r
F P
0 g
s
.36687 .65483 m .35463 .70763 L .35209 .69593 L p .707 .577 .707 r
F P
0 g
s
.34398 .7332 m .34641 .69649 L .35896 .70586 L p .707 .577 .707 r
F P
0 g
s
.35229 .63033 m .34005 .68313 L .3197 .67049 L p .707 .577 .707 r
F P
0 g
s
.3197 .67049 m .33193 .61769 L .35229 .63033 L p .707 .577 .707 r
F P
0 g
s
.34641 .69649 m .34398 .7332 L .32298 .72488 L p .707 .577 .707 r
F P
0 g
s
.32298 .72488 m .32542 .68817 L .34641 .69649 L p .707 .577 .707 r
F P
0 g
s
.33593 .76779 m .33837 .73108 L .31435 .73578 L p .707 .577 .707 r
F P
0 g
s
.35333 .74892 m .35582 .76535 L p .33542 .76542 L .707 .577 .707 r
F P
0 g
s
.36125 .76728 m .36406 .78587 L .3712 .77827 L p .707 .577 .707 r
F P
0 g
s
.3712 .77827 m .36839 .75968 L .36125 .76728 L p .707 .577 .707 r
F P
0 g
s
.36182 .71535 m .35939 .75206 L .35652 .74257 L p .707 .577 .707 r
F P
0 g
s
.35133 .78995 m .36271 .79803 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .36566 .75335 L .36799 .77177 L .707 .577 .707 r
F
.35713 .76605 m .36144 .75964 L .36402 .76968 L F
.36144 .75964 m .36566 .75335 L .36402 .76968 L F
.36566 .75335 m .36847 .77195 L .36799 .77177 L p F P
0 g
s
.36402 .76968 m .36271 .79803 L .37222 .80154 L p .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .35582 .76535 L .35133 .78995 L .707 .577 .707 r
F
.35209 .69593 m .36433 .64313 L .36687 .65483 L p F P
0 g
s
.35333 .74892 m .36566 .75335 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36803 .28659 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36271 .79803 m .36402 .76968 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .38577 .29919 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.35614 .76752 m .35582 .76535 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.35582 .76535 m .35333 .74892 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36799 .77177 m .35614 .76752 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36839 .75968 m .3712 .77827 L .36847 .77195 L p .707 .577 .707 r
F P
0 g
s
.36847 .77195 m .36566 .75335 L .36839 .75968 L p .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36402 .76968 L p .3924 .80898 L .707 .577 .707 r
F P
0 g
s
.37222 .80154 m .3924 .80898 L p .36402 .76968 L .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .36349 .72327 L .35582 .76535 L .707 .577 .707 r
F
.35582 .76535 m .35614 .76752 L .35543 .76745 L p F P
0 g
s
.35543 .76745 m .33542 .76542 L p .35582 .76535 L .707 .577 .707 r
F P
0 g
s
.33542 .76542 m .33261 .74682 L .35333 .74892 L p .707 .577 .707 r
F P
0 g
s
.36803 .28659 m .34497 .78544 L .35133 .78995 L p .707 .577 .707 r
F P
0 g
s
.35652 .74257 m .35896 .70586 L .36182 .71535 L p .707 .577 .707 r
F P
0 g
s
.36349 .72327 m .36803 .28659 L .35133 .78995 L .707 .577 .707 r
F
.3409 .77244 m .34497 .78544 L p .35541 .5041 L F P
0 g
s
.36396 .2736 m .35578 .45063 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35578 .45063 m .3409 .77244 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.34497 .78544 m .35496 .56935 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35496 .56935 m .36243 .40758 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.36243 .40758 m .36803 .28659 L .36406 .2739 L p .707 .577 .707 r
F P
0 g
s
.36406 .2739 m .36396 .2736 L p .36243 .40758 L .707 .577 .707 r
F P
0 g
s
.26324 .81383 m .26043 .79524 L .22962 .79816 L p .707 .577 .707 r
F P
0 g
s
.26043 .79524 m .26324 .81383 L .29474 .8087 L p .707 .577 .707 r
F P
0 g
s
.29474 .8087 m .29194 .79011 L .26043 .79524 L p .707 .577 .707 r
F P
0 g
s
.29194 .79011 m .29474 .8087 L .32387 .80187 L p .707 .577 .707 r
F P
0 g
s
.32387 .80187 m .32106 .78327 L .29194 .79011 L p .707 .577 .707 r
F P
0 g
s
.18232 .63344 m .17008 .68624 L .19044 .69888 L p .707 .577 .707 r
F P
0 g
s
.31435 .73578 m .31191 .77249 L .33593 .76779 L p .707 .577 .707 r
F P
0 g
s
.17008 .68624 m .18232 .63344 L .17028 .62064 L p .707 .577 .707 r
F P
0 g
s
.22962 .79816 m .23243 .81676 L .26324 .81383 L p .707 .577 .707 r
F P
0 g
s
.19475 .72616 m .19231 .76287 L .2197 .76933 L p .707 .577 .707 r
F P
0 g
s
.67494 .65328 m .66271 .70608 L .63602 .69482 L p .707 .577 .707 r
F P
0 g
s
.63602 .69482 m .64826 .64202 L .67494 .65328 L p .707 .577 .707 r
F P
0 g
s
.68942 .73637 m .68699 .77307 L .66599 .76475 L p .707 .577 .707 r
F P
0 g
s
.66599 .76475 m .66843 .72805 L .68942 .73637 L p .707 .577 .707 r
F P
0 g
s
.23243 .81676 m .22962 .79816 L .20253 .79859 L p .707 .577 .707 r
F P
0 g
s
.19231 .76287 m .19475 .72616 L .17375 .71784 L p .707 .577 .707 r
F P
0 g
s
.20253 .79859 m .20534 .81719 L .23243 .81676 L p .707 .577 .707 r
F P
0 g
s
.32106 .78327 m .32387 .80187 L .34775 .79401 L p .707 .577 .707 r
F P
0 g
s
.69634 .78019 m .69915 .79879 L .67843 .79669 L p .707 .577 .707 r
F P
0 g
s
.67843 .79669 m .67562 .77809 L .69634 .78019 L p .707 .577 .707 r
F P
0 g
s
.17375 .71784 m .17132 .75455 L .19231 .76287 L p .707 .577 .707 r
F P
0 g
s
.64152 .30343 m .61846 .80227 L .62847 .79014 L p .707 .577 .707 r
F P
0 g
s
.62847 .79014 m .65153 .2913 L .64152 .30343 L p .707 .577 .707 r
F P
0 g
s
.17028 .62064 m .15804 .67344 L .17008 .68624 L p .707 .577 .707 r
F P
0 g
s
.20534 .81719 m .20253 .79859 L .1818 .79649 L p .707 .577 .707 r
F P
0 g
s
.1818 .79649 m .18461 .81509 L .20534 .81719 L p .707 .577 .707 r
F P
0 g
s
.66843 .72805 m .66599 .76475 L .6386 .75829 L p .707 .577 .707 r
F P
0 g
s
.6386 .75829 m .64104 .72159 L .66843 .72805 L p .707 .577 .707 r
F P
0 g
s
.15804 .67344 m .17028 .62064 L .16774 .60894 L p .707 .577 .707 r
F P
0 g
s
.17132 .75455 m .17375 .71784 L .16121 .70848 L p .707 .577 .707 r
F P
0 g
s
.67562 .77809 m .67843 .79669 L .65133 .79712 L p .707 .577 .707 r
F P
0 g
s
.65133 .79712 m .64852 .77852 L .67562 .77809 L p .707 .577 .707 r
F P
0 g
s
.16121 .70848 m .15877 .74518 L .17132 .75455 L p .707 .577 .707 r
F P
0 g
s
.18461 .81509 m .1818 .79649 L .16947 .79206 L p .707 .577 .707 r
F P
0 g
s
.16774 .60894 m .1555 .66174 L .15804 .67344 L p .707 .577 .707 r
F P
0 g
s
.16947 .79206 m .17228 .81066 L .18461 .81509 L p .707 .577 .707 r
F P
0 g
s
.64852 .77852 m .65133 .79712 L .62053 .80005 L p .707 .577 .707 r
F P
0 g
s
.15877 .74518 m .16121 .70848 L .15835 .69898 L p .707 .577 .707 r
F P
0 g
s
.1555 .66174 m .16774 .60894 L .17494 .59949 L p .707 .577 .707 r
F P
0 g
s
.65153 .2913 m .62847 .79014 L .6244 .77714 L p .707 .577 .707 r
F P
0 g
s
.6244 .77714 m .64746 .2783 L .65153 .2913 L p .707 .577 .707 r
F P
0 g
s
.15835 .69898 m .15591 .73569 L .15877 .74518 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.3409 .77244 m .36396 .2736 L .37397 .26146 L p .707 .577 .707 r
F P
0 g
s
.17228 .81066 m .16947 .79206 L .16674 .78573 L p .707 .577 .707 r
F P
0 g
s
.17494 .59949 m .16271 .65229 L .1555 .66174 L p .707 .577 .707 r
F P
0 g
s
.16674 .78573 m .16955 .80433 L .17228 .81066 L p .707 .577 .707 r
F P
0 g
s
.15591 .73569 m .15835 .69898 L .16544 .69029 L p .707 .577 .707 r
F P
0 g
s
.16271 .65229 m .17494 .59949 L .19119 .59321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16544 .69029 m .163 .727 L .15591 .73569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64746 .2783 m .6244 .77714 L .60666 .76455 L p .707 .577 .707 r
F P
0 g
s
.60666 .76455 m .62971 .26571 L .64746 .2783 L p .707 .577 .707 r
F P
0 g
s
.19119 .59321 m .17896 .64601 L .16271 .65229 L p .707 .577 .707 r
F P
0 g
s
.16955 .80433 m .16674 .78573 L .17388 .77813 L p .707 .577 .707 r
F P
0 g
s
.17388 .77813 m .17669 .79673 L .16955 .80433 L p .707 .577 .707 r
F P
0 g
s
.17896 .64601 m .19119 .59321 L .21489 .59072 L p .707 .577 .707 r
F P
0 g
s
.163 .727 m .16544 .69029 L .1818 .68325 L p .707 .577 .707 r
F P
0 g
s
.35091 .76031 m .37397 .26146 L .39707 .25139 L p .707 .577 .707 r
F P
0 g
s
.37397 .26146 m .35091 .76031 L .3409 .77244 L p .707 .577 .707 r
F P
0 g
s
.1818 .68325 m .17936 .71996 L .163 .727 L p .707 .577 .707 r
F P
0 g
s
.21489 .59072 m .20265 .64352 L .17896 .64601 L p .707 .577 .707 r
F P
0 g
s
.20265 .64352 m .21489 .59072 L .24372 .59225 L p .707 .577 .707 r
F P
0 g
s
.33193 .61769 m .3197 .67049 L .29301 .65923 L p .707 .577 .707 r
F P
0 g
s
.29301 .65923 m .30525 .60643 L .33193 .61769 L p .707 .577 .707 r
F P
0 g
s
.17669 .79673 m .17388 .77813 L .19019 .77 L p .707 .577 .707 r
F P
0 g
s
.19019 .77 m .193 .7886 L .17669 .79673 L p .707 .577 .707 r
F P
0 g
s
.62971 .26571 m .60666 .76455 L .57697 .7536 L p .707 .577 .707 r
F P
0 g
s
.57697 .7536 m .60003 .25475 L .62971 .26571 L p .707 .577 .707 r
F P
0 g
s
.17936 .71996 m .1818 .68325 L .20582 .67855 L p .707 .577 .707 r
F P
0 g
s
.23148 .64505 m .24372 .59225 L .27485 .59767 L p .707 .577 .707 r
F P
0 g
s
.24372 .59225 m .23148 .64505 L .20265 .64352 L p .707 .577 .707 r
F P
0 g
s
.30525 .60643 m .29301 .65923 L .26262 .65047 L p .707 .577 .707 r
F P
0 g
s
.26262 .65047 m .27485 .59767 L .30525 .60643 L p .707 .577 .707 r
F P
0 g
s
.27485 .59767 m .26262 .65047 L .23148 .64505 L p .707 .577 .707 r
F P
0 g
s
.20582 .67855 m .20338 .71526 L .17936 .71996 L p .707 .577 .707 r
F P
0 g
s
.39707 .25139 m .37401 .75023 L .35091 .76031 L p .707 .577 .707 r
F P
0 g
s
.37401 .75023 m .39707 .25139 L .431 .24435 L p .707 .577 .707 r
F P
0 g
s
.32542 .68817 m .32298 .72488 L .29559 .71842 L p .707 .577 .707 r
F P
0 g
s
.29559 .71842 m .29803 .68171 L .32542 .68817 L p .707 .577 .707 r
F P
0 g
s
.72773 .66246 m .73997 .60966 L .70957 .60089 L p .707 .577 .707 r
F P
0 g
s
.73997 .60966 m .72773 .66246 L .75887 .66787 L p .707 .577 .707 r
F P
0 g
s
.75887 .66787 m .7711 .61507 L .73997 .60966 L p .707 .577 .707 r
F P
0 g
s
.20338 .71526 m .20582 .67855 L .23515 .67665 L p .707 .577 .707 r
F P
0 g
s
.193 .7886 m .19019 .77 L .21408 .76213 L p .707 .577 .707 r
F P
0 g
s
.69734 .65369 m .70957 .60089 L .68289 .58964 L p .707 .577 .707 r
F P
0 g
s
.70957 .60089 m .69734 .65369 L .72773 .66246 L p .707 .577 .707 r
F P
0 g
s
.7711 .61507 m .75887 .66787 L .7877 .6694 L p .707 .577 .707 r
F P
0 g
s
.7877 .6694 m .79993 .6166 L .7711 .61507 L p .707 .577 .707 r
F P
0 g
s
.21408 .76213 m .21689 .78073 L .193 .7886 L p .707 .577 .707 r
F P
0 g
s
.33261 .74682 m .33542 .76542 L .30832 .76585 L p .707 .577 .707 r
F P
0 g
s
.30832 .76585 m .30551 .74725 L .33261 .74682 L p .707 .577 .707 r
F P
0 g
s
.29803 .68171 m .29559 .71842 L .26449 .71445 L p .707 .577 .707 r
F P
0 g
s
.26449 .71445 m .26693 .67774 L .29803 .68171 L p .707 .577 .707 r
F P
0 g
s
.60003 .25475 m .57697 .7536 L .53826 .74535 L p .707 .577 .707 r
F P
0 g
s
.53826 .74535 m .56131 .24651 L .60003 .25475 L p .707 .577 .707 r
F P
0 g
s
.23515 .67665 m .23272 .71336 L .20338 .71526 L p .707 .577 .707 r
F P
0 g
s
.23272 .71336 m .23515 .67665 L .26693 .67774 L p .707 .577 .707 r
F P
0 g
s
.67065 .64244 m .68289 .58964 L .66253 .57699 L p .707 .577 .707 r
F P
0 g
s
.68289 .58964 m .67065 .64244 L .69734 .65369 L p .707 .577 .707 r
F P
0 g
s
.79993 .6166 m .7877 .6694 L .81139 .66691 L p .707 .577 .707 r
F P
0 g
s
.81139 .66691 m .82363 .61411 L .79993 .6166 L p .707 .577 .707 r
F P
0 g
s
.26693 .67774 m .26449 .71445 L .23272 .71336 L p .707 .577 .707 r
F P
0 g
s
.40795 .74319 m .431 .24435 L .47245 .24104 L p .707 .577 .707 r
F P
0 g
s
.431 .24435 m .40795 .74319 L .37401 .75023 L p .707 .577 .707 r
F P
0 g
s
.73102 .72113 m .73346 .68443 L .70235 .68046 L p .707 .577 .707 r
F P
0 g
s
.73346 .68443 m .73102 .72113 L .76279 .72222 L p .707 .577 .707 r
F P
0 g
s
.76279 .72222 m .76523 .68552 L .73346 .68443 L p .707 .577 .707 r
F P
0 g
s
.21689 .78073 m .21408 .76213 L .2432 .7553 L p .707 .577 .707 r
F P
0 g
s
.76523 .68552 m .76279 .72222 L .79213 .72032 L p .707 .577 .707 r
F P
0 g
s
.79213 .72032 m .79456 .68362 L .76523 .68552 L p .707 .577 .707 r
F P
0 g
s
.2432 .7553 m .24601 .7739 L .21689 .78073 L p .707 .577 .707 r
F P
0 g
s
.30551 .74725 m .30832 .76585 L .27752 .76877 L p .707 .577 .707 r
F P
0 g
s
.27752 .76877 m .27471 .75017 L .30551 .74725 L p .707 .577 .707 r
F P
0 g
s
.69991 .71716 m .70235 .68046 L .67496 .674 L p .707 .577 .707 r
F P
0 g
s
.70235 .68046 m .69991 .71716 L .73102 .72113 L p .707 .577 .707 r
F P
0 g
s
.74345 .75307 m .74064 .73447 L .70983 .7374 L p .707 .577 .707 r
F P
0 g
s
.74064 .73447 m .74345 .75307 L .77496 .74794 L p .707 .577 .707 r
F P
0 g
s
.77496 .74794 m .77215 .72934 L .74064 .73447 L p .707 .577 .707 r
F P
0 g
s
.24601 .7739 m .2432 .7553 L .27471 .75017 L p .707 .577 .707 r
F P
0 g
s
.77215 .72934 m .77496 .74794 L .80408 .74111 L p .707 .577 .707 r
F P
0 g
s
.80408 .74111 m .80127 .72251 L .77215 .72934 L p .707 .577 .707 r
F P
0 g
s
.56131 .24651 m .53826 .74535 L .49429 .74063 L p .707 .577 .707 r
F P
0 g
s
.49429 .74063 m .51735 .24178 L .56131 .24651 L p .707 .577 .707 r
F P
0 g
s
.27471 .75017 m .27752 .76877 L .24601 .7739 L p .707 .577 .707 r
F P
0 g
s
.66253 .57699 m .6503 .62979 L .67065 .64244 L p .707 .577 .707 r
F P
0 g
s
.70983 .7374 m .71264 .75599 L .74345 .75307 L p .707 .577 .707 r
F P
0 g
s
.6503 .62979 m .66253 .57699 L .65049 .56419 L p .707 .577 .707 r
F P
0 g
s
.79456 .68362 m .79213 .72032 L .81615 .71563 L p .707 .577 .707 r
F P
0 g
s
.81615 .71563 m .81858 .67892 L .79456 .68362 L p .707 .577 .707 r
F P
0 g
s
.82363 .61411 m .81139 .66691 L .82764 .66063 L p .707 .577 .707 r
F P
0 g
s
.82764 .66063 m .83988 .60783 L .82363 .61411 L p .707 .577 .707 r
F P
0 g
s
.67496 .674 m .67252 .7107 L .69991 .71716 L p .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .45925 .52659 L .48577 .47325 L .707 .577 .707 r
F
.43195 .71667 m .45101 .7122 L p .45012 .71163 L F P
0 g
s
.47245 .24104 m .45376 .64546 L p .41122 .71767 L .707 .577 .707 r
F P
0 g
s
.45376 .64546 m .4507 .71154 L p .43162 .7145 L .707 .577 .707 r
F P
0 g
s
.41122 .71767 m .45376 .64546 L .43162 .7145 L .707 .577 .707 r
F
.44939 .73988 m .40795 .74319 L p .41122 .71767 L F P
0 g
s
.43087 .71684 m .43195 .71667 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.43162 .7145 m .43195 .71667 L p .45012 .71163 L .707 .577 .707 r
F P
0 g
s
.44767 .7049 m .42914 .69807 L .45101 .7122 L .707 .577 .707 r
F
.4507 .71154 m .44939 .73988 L p .42756 .72717 L F P
0 g
s
.41122 .71767 m .43162 .7145 L .42756 .72717 L .707 .577 .707 r
F
.43195 .71667 m .43162 .7145 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .4507 .71154 L .42756 .72717 L .707 .577 .707 r
F
.42914 .69807 m .39763 .7032 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .42914 .69807 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.39763 .7032 m .40044 .7218 L .43087 .71684 L p .707 .577 .707 r
F P
0 g
s
.43104 .71631 m .39763 .7032 L .43087 .71684 L .707 .577 .707 r
F
.42914 .69807 m .43162 .7145 L p .45012 .71163 L F P
0 g
s
.44939 .73988 m .4507 .71154 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.4507 .71154 m .45925 .52659 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.51735 .24178 m .49429 .74063 L .46378 .74012 L p .707 .577 .707 r
F P
0 g
s
.46378 .74012 m .44939 .73988 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .51735 .24178 L .46378 .74012 L .707 .577 .707 r
F
.46107 .70983 m .45826 .69124 L .44305 .6948 L p F P
0 g
s
.44305 .6948 m .42914 .69807 L p .44767 .7049 L .707 .577 .707 r
F P
0 g
s
.46107 .70983 m .44305 .6948 L .44767 .7049 L .707 .577 .707 r
F
.45101 .7122 m .46107 .70983 L p .44767 .7049 L F P
0 g
s
.44469 .63381 m .45692 .58101 L .43283 .57973 L p .707 .577 .707 r
F P
0 g
s
.43283 .57973 m .42809 .57948 L p .42995 .58554 L .707 .577 .707 r
F P
0 g
s
.44469 .63381 m .43283 .57973 L .42995 .58554 L .707 .577 .707 r
F
.47245 .24104 m .51735 .24178 L p .48577 .47325 L F P
0 g
s
.45925 .52659 m .47245 .24104 L p .48577 .47325 L .707 .577 .707 r
F P
0 g
s
.71264 .75599 m .70983 .7374 L .68274 .73783 L p .707 .577 .707 r
F P
0 g
s
.67252 .7107 m .67496 .674 L .65397 .66568 L p .707 .577 .707 r
F P
0 g
s
.68274 .73783 m .68555 .75643 L .71264 .75599 L p .707 .577 .707 r
F P
0 g
s
.80127 .72251 m .80408 .74111 L .82796 .73324 L p .707 .577 .707 r
F P
0 g
s
.82796 .73324 m .82515 .71464 L .80127 .72251 L p .707 .577 .707 r
F P
0 g
s
.65397 .66568 m .65153 .70238 L .67252 .7107 L p .707 .577 .707 r
F P
0 g
s
.65049 .56419 m .63826 .61699 L .6503 .62979 L p .707 .577 .707 r
F P
0 g
s
.68555 .75643 m .68274 .73783 L .66202 .73573 L p .707 .577 .707 r
F P
0 g
s
.81858 .67892 m .81615 .71563 L .83251 .70859 L p .707 .577 .707 r
F P
0 g
s
.83251 .70859 m .83494 .67188 L .81858 .67892 L p .707 .577 .707 r
F P
0 g
s
.66202 .73573 m .66482 .75432 L .68555 .75643 L p .707 .577 .707 r
F P
0 g
s
.63826 .61699 m .65049 .56419 L .64795 .5525 L p .707 .577 .707 r
F P
0 g
s
.83988 .60783 m .82764 .66063 L .83485 .65118 L p .707 .577 .707 r
F P
0 g
s
.83485 .65118 m .84708 .59838 L .83988 .60783 L p .707 .577 .707 r
F P
0 g
s
.82515 .71464 m .82796 .73324 L .84428 .72511 L p .707 .577 .707 r
F P
0 g
s
.84428 .72511 m .84147 .70651 L .82515 .71464 L p .707 .577 .707 r
F P
0 g
s
.65153 .70238 m .65397 .66568 L .64142 .65631 L p .707 .577 .707 r
F P
0 g
s
.64142 .65631 m .63899 .69302 L .65153 .70238 L p .707 .577 .707 r
F P
0 g
s
.66482 .75432 m .66202 .73573 L .64968 .73129 L p .707 .577 .707 r
F P
0 g
s
.64795 .5525 m .63572 .6053 L .63826 .61699 L p .707 .577 .707 r
F P
0 g
s
.83494 .67188 m .83251 .70859 L .8396 .69989 L p .707 .577 .707 r
F P
0 g
s
.8396 .69989 m .84204 .66319 L .83494 .67188 L p .707 .577 .707 r
F P
0 g
s
.64968 .73129 m .65249 .74989 L .66482 .75432 L p .707 .577 .707 r
F P
0 g
s
.84147 .70651 m .84428 .72511 L .85142 .71751 L p .707 .577 .707 r
F P
0 g
s
.85142 .71751 m .84861 .69891 L .84147 .70651 L p .707 .577 .707 r
F P
0 g
s
.63899 .69302 m .64142 .65631 L .63856 .64682 L p .707 .577 .707 r
F P
0 g
s
.63572 .6053 m .64795 .5525 L .65516 .54304 L p .707 .577 .707 r
F P
0 g
s
.84708 .59838 m .83485 .65118 L .83231 .63948 L p .707 .577 .707 r
F P
0 g
s
.83231 .63948 m .84454 .58668 L .84708 .59838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63856 .64682 m .63612 .68352 L .63899 .69302 L p .707 .577 .707 r
F P
0 g
s
.65249 .74989 m .64968 .73129 L .64696 .72497 L p .707 .577 .707 r
F P
0 g
s
.65516 .54304 m .64292 .59584 L .63572 .6053 L p .707 .577 .707 r
F P
0 g
s
.84204 .66319 m .8396 .69989 L .83673 .6904 L p .707 .577 .707 r
F P
0 g
s
.83673 .6904 m .83917 .65369 L .84204 .66319 L p .707 .577 .707 r
F P
0 g
s
.64696 .72497 m .64977 .74357 L .65249 .74989 L p .707 .577 .707 r
F P
0 g
s
.84861 .69891 m .85142 .71751 L .84869 .71118 L p .707 .577 .707 r
F P
0 g
s
.84869 .71118 m .84588 .69259 L .84861 .69891 L p .707 .577 .707 r
F P
0 g
s
.64292 .59584 m .65516 .54304 L .6714 .53676 L p .707 .577 .707 r
F P
0 g
s
.63612 .68352 m .63856 .64682 L .64565 .63813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84454 .58668 m .83231 .63948 L .82027 .62668 L p .707 .577 .707 r
F P
0 g
s
.82027 .62668 m .8325 .57388 L .84454 .58668 L p .707 .577 .707 r
F P
0 g
s
.38472 .62687 m .39696 .57407 L .36656 .5653 L p .707 .577 .707 r
F P
0 g
s
.39696 .57407 m .38472 .62687 L .41586 .63228 L p .707 .577 .707 r
F P
0 g
s
.41586 .63228 m .42809 .57948 L .39696 .57407 L p .707 .577 .707 r
F P
0 g
s
.64565 .63813 m .64322 .67483 L .63612 .68352 L p .707 .577 .707 r
F P
0 g
s
.35433 .6181 m .36656 .5653 L .33988 .55405 L p .707 .577 .707 r
F P
0 g
s
.36656 .5653 m .35433 .6181 L .38472 .62687 L p .707 .577 .707 r
F P
0 g
s
.42809 .57948 m .41586 .63228 L .44469 .63381 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64977 .74357 m .64696 .72497 L .6541 .71737 L p .707 .577 .707 r
F P
0 g
s
.6714 .53676 m .65917 .58956 L .64292 .59584 L p .707 .577 .707 r
F P
0 g
s
.83917 .65369 m .83673 .6904 L .82419 .68104 L p .707 .577 .707 r
F P
0 g
s
.82419 .68104 m .82663 .64433 L .83917 .65369 L p .707 .577 .707 r
F P
0 g
s
.6541 .71737 m .65691 .73597 L .64977 .74357 L p .707 .577 .707 r
F P
0 g
s
.32764 .60685 m .33988 .55405 L .31952 .5414 L p .707 .577 .707 r
F P
0 g
s
.33988 .55405 m .32764 .60685 L .35433 .6181 L p .707 .577 .707 r
F P
0 g
s
.45692 .58101 m .44469 .63381 L .46838 .63132 L p .707 .577 .707 r
F P
0 g
s
.46838 .63132 m .48062 .57852 L .45692 .58101 L p .707 .577 .707 r
F P
0 g
s
.65917 .58956 m .6714 .53676 L .6951 .53427 L p .707 .577 .707 r
F P
0 g
s
.8325 .57388 m .82027 .62668 L .79991 .61404 L p .707 .577 .707 r
F P
0 g
s
.79991 .61404 m .81215 .56124 L .8325 .57388 L p .707 .577 .707 r
F P
0 g
s
.38801 .68126 m .39045 .64455 L .35934 .64058 L p .707 .577 .707 r
F P
0 g
s
.39045 .64455 m .38801 .68126 L .41978 .68235 L p .707 .577 .707 r
F P
0 g
s
.41978 .68235 m .42222 .64564 L .39045 .64455 L p .707 .577 .707 r
F P
0 g
s
.84588 .69259 m .84869 .71118 L .83636 .70675 L p .707 .577 .707 r
F P
0 g
s
.83636 .70675 m .83355 .68816 L .84588 .69259 L p .707 .577 .707 r
F P
0 g
s
.64322 .67483 m .64565 .63813 L .66201 .63109 L p .707 .577 .707 r
F P
0 g
s
.42222 .64564 m .41978 .68235 L .44912 .68045 L p .707 .577 .707 r
F P
0 g
s
.44912 .68045 m .45155 .64374 L .42222 .64564 L p .707 .577 .707 r
F P
0 g
s
.3569 .67729 m .35934 .64058 L .33195 .63412 L p .707 .577 .707 r
F P
0 g
s
.35934 .64058 m .3569 .67729 L .38801 .68126 L p .707 .577 .707 r
F P
0 g
s
.66201 .63109 m .65957 .66779 L .64322 .67483 L p .707 .577 .707 r
F P
0 g
s
.40044 .7218 m .39763 .7032 L .36682 .70612 L p .707 .577 .707 r
F P
0 g
s
.31952 .5414 m .30729 .5942 L .32764 .60685 L p .707 .577 .707 r
F P
0 g
s
.45155 .64374 m .44912 .68045 L .47314 .67575 L p .707 .577 .707 r
F P
0 g
s
.47314 .67575 m .47557 .63905 L .45155 .64374 L p .707 .577 .707 r
F P
0 g
s
.30729 .5942 m .31952 .5414 L .30748 .5286 L p .707 .577 .707 r
F P
0 g
s
.6951 .53427 m .68287 .58707 L .65917 .58956 L p .707 .577 .707 r
F P
0 g
s
.36682 .70612 m .36963 .72472 L .40044 .7218 L p .707 .577 .707 r
F P
0 g
s
.33195 .63412 m .32951 .67083 L .3569 .67729 L p .707 .577 .707 r
F P
0 g
s
.48062 .57852 m .46838 .63132 L .48463 .62504 L p .707 .577 .707 r
F P
0 g
s
.48463 .62504 m .49687 .57224 L .48062 .57852 L p .707 .577 .707 r
F P
0 g
s
.68287 .58707 m .6951 .53427 L .72393 .5358 L p .707 .577 .707 r
F P
0 g
s
.81215 .56124 m .79991 .61404 L .77323 .60278 L p .707 .577 .707 r
F P
0 g
s
.77323 .60278 m .78546 .54998 L .81215 .56124 L p .707 .577 .707 r
F P
0 g
s
.65691 .73597 m .6541 .71737 L .67041 .70924 L p .707 .577 .707 r
F P
0 g
s
.82663 .64433 m .82419 .68104 L .8032 .67272 L p .707 .577 .707 r
F P
0 g
s
.8032 .67272 m .80563 .63601 L .82663 .64433 L p .707 .577 .707 r
F P
0 g
s
.36963 .72472 m .36682 .70612 L .33973 .70655 L p .707 .577 .707 r
F P
0 g
s
.32951 .67083 m .33195 .63412 L .31096 .6258 L p .707 .577 .707 r
F P
0 g
s
.67041 .70924 m .67322 .72784 L .65691 .73597 L p .707 .577 .707 r
F P
0 g
s
.33973 .70655 m .34254 .72515 L .36963 .72472 L p .707 .577 .707 r
F P
0 g
s
.45826 .69124 m .46107 .70983 L .48495 .70197 L p .707 .577 .707 r
F P
0 g
s
.48495 .70197 m .48214 .68337 L .45826 .69124 L p .707 .577 .707 r
F P
0 g
s
.65957 .66779 m .66201 .63109 L .68603 .62639 L p .707 .577 .707 r
F P
0 g
s
.83355 .68816 m .83636 .70675 L .81563 .70465 L p .707 .577 .707 r
F P
0 g
s
.81563 .70465 m .81282 .68605 L .83355 .68816 L p .707 .577 .707 r
F P
0 g
s
.71169 .5886 m .72393 .5358 L .75507 .54122 L p .707 .577 .707 r
F P
0 g
s
.72393 .5358 m .71169 .5886 L .68287 .58707 L p .707 .577 .707 r
F P
0 g
s
.78546 .54998 m .77323 .60278 L .74283 .59402 L p .707 .577 .707 r
F P
0 g
s
.74283 .59402 m .75507 .54122 L .78546 .54998 L p .707 .577 .707 r
F P
0 g
s
.31096 .6258 m .30852 .66251 L .32951 .67083 L p .707 .577 .707 r
F P
0 g
s
.47557 .63905 m .47314 .67575 L .4895 .66871 L p .707 .577 .707 r
F P
0 g
s
.4895 .66871 m .49193 .63201 L .47557 .63905 L p .707 .577 .707 r
F P
0 g
s
.30748 .5286 m .29525 .5814 L .30729 .5942 L p .707 .577 .707 r
F P
0 g
s
.75507 .54122 m .74283 .59402 L .71169 .5886 L p .707 .577 .707 r
F P
0 g
s
.34254 .72515 m .33973 .70655 L .31901 .70445 L p .707 .577 .707 r
F P
0 g
s
.68603 .62639 m .6836 .66309 L .65957 .66779 L p .707 .577 .707 r
F P
0 g
s
.31901 .70445 m .32181 .72305 L .34254 .72515 L p .707 .577 .707 r
F P
0 g
s
.80563 .63601 m .8032 .67272 L .77581 .66625 L p .707 .577 .707 r
F P
0 g
s
.77581 .66625 m .77824 .62955 L .80563 .63601 L p .707 .577 .707 r
F P
0 g
s
.29525 .5814 m .30748 .5286 L .30494 .51691 L p .707 .577 .707 r
F P
0 g
s
.30852 .66251 m .31096 .6258 L .29841 .61644 L p .707 .577 .707 r
F P
0 g
s
.49687 .57224 m .48463 .62504 L .49184 .61559 L p .707 .577 .707 r
F P
0 g
s
.49184 .61559 m .50407 .56279 L .49687 .57224 L p .707 .577 .707 r
F P
0 g
s
.67322 .72784 m .67041 .70924 L .69429 .70137 L p .707 .577 .707 r
F P
0 g
s
.48214 .68337 m .48495 .70197 L .50127 .69384 L p .707 .577 .707 r
F P
0 g
s
.50127 .69384 m .49846 .67524 L .48214 .68337 L p .707 .577 .707 r
F P
0 g
s
.6836 .66309 m .68603 .62639 L .71537 .62449 L p .707 .577 .707 r
F P
0 g
s
.69429 .70137 m .6971 .71997 L .67322 .72784 L p .707 .577 .707 r
F P
0 g
s
.81282 .68605 m .81563 .70465 L .78854 .70508 L p .707 .577 .707 r
F P
0 g
s
.78854 .70508 m .78573 .68649 L .81282 .68605 L p .707 .577 .707 r
F P
0 g
s
.29841 .61644 m .29598 .65314 L .30852 .66251 L p .707 .577 .707 r
F P
0 g
s
.77824 .62955 m .77581 .66625 L .7447 .66228 L p .707 .577 .707 r
F P
0 g
s
.7447 .66228 m .74714 .62558 L .77824 .62955 L p .707 .577 .707 r
F P
0 g
s
.71537 .62449 m .71293 .6612 L .6836 .66309 L p .707 .577 .707 r
F P
0 g
s
.71293 .6612 m .71537 .62449 L .74714 .62558 L p .707 .577 .707 r
F P
0 g
s
.32181 .72305 m .31901 .70445 L .30667 .70002 L p .707 .577 .707 r
F P
0 g
s
.49193 .63201 m .4895 .66871 L .49659 .66002 L p .707 .577 .707 r
F P
0 g
s
.49659 .66002 m .49903 .62331 L .49193 .63201 L p .707 .577 .707 r
F P
0 g
s
.30494 .51691 m .29271 .56971 L .29525 .5814 L p .707 .577 .707 r
F P
0 g
s
.74714 .62558 m .7447 .66228 L .71293 .6612 L p .707 .577 .707 r
F P
0 g
s
.6971 .71997 m .69429 .70137 L .72341 .69454 L p .707 .577 .707 r
F P
0 g
s
.30667 .70002 m .30948 .71862 L .32181 .72305 L p .707 .577 .707 r
F P
0 g
s
.72341 .69454 m .72622 .71314 L .6971 .71997 L p .707 .577 .707 r
F P
0 g
s
.78573 .68649 m .78854 .70508 L .75773 .70801 L p .707 .577 .707 r
F P
0 g
s
.75773 .70801 m .75492 .68941 L .78573 .68649 L p .707 .577 .707 r
F P
0 g
s
.29598 .65314 m .29841 .61644 L .29555 .60694 L p .707 .577 .707 r
F P
0 g
s
.49846 .67524 m .50127 .69384 L .50841 .68623 L p .707 .577 .707 r
F P
0 g
s
.50841 .68623 m .5056 .66764 L .49846 .67524 L p .707 .577 .707 r
F P
0 g
s
.29271 .56971 m .30494 .51691 L .31215 .50745 L p .707 .577 .707 r
F P
0 g
s
.50407 .56279 m .49184 .61559 L .4893 .60389 L p .707 .577 .707 r
F P
0 g
s
.4893 .60389 m .50153 .55109 L .50407 .56279 L p .707 .577 .707 r
F P
0 g
s
.72622 .71314 m .72341 .69454 L .75492 .68941 L p .707 .577 .707 r
F P
0 g
s
.75492 .68941 m .75773 .70801 L .72622 .71314 L p .707 .577 .707 r
F P
0 g
s
.29555 .60694 m .29311 .64365 L .29598 .65314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30948 .71862 m .30667 .70002 L .30395 .6937 L p .707 .577 .707 r
F P
0 g
s
.49903 .62331 m .49659 .66002 L .49372 .65053 L p .707 .577 .707 r
F P
0 g
s
.49372 .65053 m .49616 .61382 L .49903 .62331 L p .707 .577 .707 r
F P
0 g
s
.31215 .50745 m .29991 .56025 L .29271 .56971 L p .707 .577 .707 r
F P
0 g
s
.30395 .6937 m .30675 .71229 L .30948 .71862 L p .707 .577 .707 r
F P
0 g
s
.29311 .64365 m .29555 .60694 L .30264 .59825 L p .707 .577 .707 r
F P
0 g
s
.5056 .66764 m .50841 .68623 L .50568 .67991 L p .707 .577 .707 r
F P
0 g
s
.50568 .67991 m .50287 .66131 L .5056 .66764 L p .707 .577 .707 r
F P
0 g
s
.29991 .56025 m .31215 .50745 L .32839 .50117 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50153 .55109 m .4893 .60389 L .47726 .59109 L p .707 .577 .707 r
F P
0 g
s
.47726 .59109 m .48949 .53829 L .50153 .55109 L p .707 .577 .707 r
F P
0 g
s
.30264 .59825 m .30021 .63496 L .29311 .64365 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32839 .50117 m .31616 .55397 L .29991 .56025 L p .707 .577 .707 r
F P
0 g
s
.30675 .71229 m .30395 .6937 L .31109 .6861 L p .707 .577 .707 r
F P
0 g
s
.49616 .61382 m .49372 .65053 L .48118 .64116 L p .707 .577 .707 r
F P
0 g
s
.48118 .64116 m .48362 .60445 L .49616 .61382 L p .707 .577 .707 r
F P
0 g
s
.31109 .6861 m .3139 .70469 L .30675 .71229 L p .707 .577 .707 r
F P
0 g
s
.31616 .55397 m .32839 .50117 L .35209 .49868 L p .707 .577 .707 r
F P
0 g
s
.48949 .53829 m .47726 .59109 L .4569 .57845 L p .707 .577 .707 r
F P
0 g
s
.4569 .57845 m .46914 .52565 L .48949 .53829 L p .707 .577 .707 r
F P
0 g
s
.30021 .63496 m .30264 .59825 L .319 .59121 L p .707 .577 .707 r
F P
0 g
s
.50287 .66131 m .50568 .67991 L .49335 .67548 L p .707 .577 .707 r
F P
0 g
s
.49335 .67548 m .49054 .65688 L .50287 .66131 L p .707 .577 .707 r
F P
0 g
s
.319 .59121 m .31656 .62792 L .30021 .63496 L p .707 .577 .707 r
F P
0 g
s
.35209 .49868 m .33986 .55148 L .31616 .55397 L p .707 .577 .707 r
F P
0 g
s
.33986 .55148 m .35209 .49868 L .38092 .50021 L p .707 .577 .707 r
F P
0 g
s
.48362 .60445 m .48118 .64116 L .46019 .63284 L p .707 .577 .707 r
F P
0 g
s
.46019 .63284 m .46262 .59613 L .48362 .60445 L p .707 .577 .707 r
F P
0 g
s
.46914 .52565 m .4569 .57845 L .43022 .56719 L p .707 .577 .707 r
F P
0 g
s
.43022 .56719 m .44245 .51439 L .46914 .52565 L p .707 .577 .707 r
F P
0 g
s
.3139 .70469 m .31109 .6861 L .3274 .67796 L p .707 .577 .707 r
F P
0 g
s
.3274 .67796 m .33021 .69656 L .3139 .70469 L p .707 .577 .707 r
F P
0 g
s
.31656 .62792 m .319 .59121 L .34302 .58651 L p .707 .577 .707 r
F P
0 g
s
.49054 .65688 m .49335 .67548 L .47262 .67338 L p .707 .577 .707 r
F P
0 g
s
.47262 .67338 m .46981 .65478 L .49054 .65688 L p .707 .577 .707 r
F P
0 g
s
.36868 .55301 m .38092 .50021 L .41206 .50563 L p .707 .577 .707 r
F P
0 g
s
.38092 .50021 m .36868 .55301 L .33986 .55148 L p .707 .577 .707 r
F P
0 g
s
.44245 .51439 m .43022 .56719 L .39982 .55843 L p .707 .577 .707 r
F P
0 g
s
.39982 .55843 m .41206 .50563 L .44245 .51439 L p .707 .577 .707 r
F P
0 g
s
.41206 .50563 m .39982 .55843 L .36868 .55301 L p .707 .577 .707 r
F P
0 g
s
.34302 .58651 m .34058 .62322 L .31656 .62792 L p .707 .577 .707 r
F P
0 g
s
.46262 .59613 m .46019 .63284 L .4328 .62638 L p .707 .577 .707 r
F P
0 g
s
.4328 .62638 m .43523 .58967 L .46262 .59613 L p .707 .577 .707 r
F P
0 g
s
.34058 .62322 m .34302 .58651 L .37236 .58461 L p .707 .577 .707 r
F P
0 g
s
.33021 .69656 m .3274 .67796 L .35128 .6701 L p .707 .577 .707 r
F P
0 g
s
.35128 .6701 m .35409 .68869 L .33021 .69656 L p .707 .577 .707 r
F P
0 g
s
.46981 .65478 m .47262 .67338 L .44553 .67381 L p .707 .577 .707 r
F P
0 g
s
.44553 .67381 m .44272 .65521 L .46981 .65478 L p .707 .577 .707 r
F P
0 g
s
.43523 .58967 m .4328 .62638 L .40169 .62241 L p .707 .577 .707 r
F P
0 g
s
.40169 .62241 m .40413 .5857 L .43523 .58967 L p .707 .577 .707 r
F P
0 g
s
.37236 .58461 m .36992 .62132 L .34058 .62322 L p .707 .577 .707 r
F P
0 g
s
.36992 .62132 m .37236 .58461 L .40413 .5857 L p .707 .577 .707 r
F P
0 g
s
.40413 .5857 m .40169 .62241 L .36992 .62132 L p .707 .577 .707 r
F P
0 g
s
.35409 .68869 m .35128 .6701 L .3804 .66326 L p .707 .577 .707 r
F P
0 g
s
.3804 .66326 m .38321 .68186 L .35409 .68869 L p .707 .577 .707 r
F P
0 g
s
.44272 .65521 m .44553 .67381 L .41472 .67673 L p .707 .577 .707 r
F P
0 g
s
.41472 .67673 m .41191 .65813 L .44272 .65521 L p .707 .577 .707 r
F P
0 g
s
.38321 .68186 m .3804 .66326 L .41191 .65813 L p .707 .577 .707 r
F P
0 g
s
.41191 .65813 m .41472 .67673 L .38321 .68186 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00PGoo001cOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001kOol0071oo`<000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00KWoo0`002EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001/Ool20002FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000
Kgoo001ZOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH01000FUIJEUYF0`00K7oo001YOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001ZOol0
06Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Qoo`00Igoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF001WOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00IGoo001W
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001W
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00Hgoo001VOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0HGoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo
001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001QOol7
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005aoo`D000=JEP04001JEUYFFUH90005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol005Yoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPH000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00F7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YF000000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Ioo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001GOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0035YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001FOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00EGoo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`L005Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo10000eYF00@005YFFUIJ
EPT004]oo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8000Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF009JEPH0
04Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0017oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P00@Woo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<003moo`00E7oo00<0
05YF00000UYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`00?7oo001DOol20003FUH40003FUH200000goo000000080004FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YF000003Yoo`00E7oo0P0000AJEP00000000IJEP04001JEP000002FUH0
0`00FUIJEP03FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00>7oo001DOol00eYF
00000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`001EYF00<005YFFUH00`0000AJEP00000000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`000UYF00<005YF000010000eYF0`0000=JEP00FUH01UYF00<005YF
FUH015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000goo00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3000dOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEP0000800003FUH0000000<0009JEP04001JEUYFFUH30006FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003Ool00000
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF000cOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPL0009JEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH0000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPL000QJEP80
0003FUH005YF00EJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo02ioo`00Dgoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF0P00
1UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001JEUYFFUH005YF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000002eoo`00E7oo00@005YFFUH000IJEP03001JEP0001H0009JEP03001JEUYF00EJEP04
001JEUYF0003FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02Yoo`00EGoo0`0015YF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF00@005YFFUIJEP<000AJEP<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEPD0009JEP<0009oo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo
02Yoo`00=Goo5@003Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`0000EJEP00001JEP0000IJEP04001JEP000009Ool60007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000cOol200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60008Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20002FUH01000FUH0000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000Uo
o`<00003Ool0000000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool0035o
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000004Ool20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH015YF0`001Goo1@00
0Woo0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEP000080009oo`D000Eoo`<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`0027oo0P0015YF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000/Ool002moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF1P0027oo0`0000=JEP00FUH01EYF00@005YFFUIJEP8002eoo`00;goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00=oo`8000IJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`0015YF00@005YFFUIJEP8002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP800005Ool005YFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP04001JEUYFFUH90003FUH300000eYF000000080004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo
001JEUYF00001EYF00<005YFFUH01EYF40000eYF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YF0000;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUH00003FUH50004FUH01000FUIJEP001EYF1`0015YF2@000eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000Woo0P001UYF200015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00@0
05YFFUIJEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF001JEP80009JEP<000AJEP04001JEUYF0005FUH00`00FUIJEP0<0004
FUH50005FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20003Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP05FUH20002FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP0015YF0`000UYF00@005YFFUH000EJ
EP03001JEUYF00D0009JEP03001JEUYF009JEPP00003FUH0000000=JEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH00P00
00=JEP00Ool0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP04FUH0
0`00FUIJEP0500000eYF001JEP0:FUH20003FUH200000eYF001JEP02FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000goo00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP02FUH00`00
FUH0000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH005YF009JEP<0
009JEP03001JEUYF00UJEPH00003FUH0000000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEP0002ioo`00;Goo
0P000eYF500015YF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQP000EJEP03001JEP00009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000002moo`00;Goo0P0000AJEP00
000000IJEP04001JEP000009Ool60007FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000_Ool002eoo`03FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH30008Ool3000017oo
0000000015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002io
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000IJEP00FUH0
05YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000C000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000000Woo1@00
1Woo0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`002Goo100015YF00<005YFFUH01EYF00<005YFFUH00UYF
1`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@000AJEP04001JEUYFFUHI0004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH60009Ool500000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP02FUH50006FUH00`00Oomoo`09Ool=
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool2000015YF000000000eYF
10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
000000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P00
00=JEP0000000P001UYF0P002Goo1@001Woo1`000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPL0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPl000=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P0000=JEP00FUH00eYF0`0015YF00<005YF000027oo1@003Goo100015YF00H005YFFUH0
05YF000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUH0000F0002FUH00`00FUIJEP05FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF1@0000=JEP00
00000`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEP0000<000=JEP03001oogoo00Eoo`D0015oo`<00007FUH0
05YFFUH005YF0000;Goo000^Ool00`00FUH00004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60004FUH40006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH70008FUH6
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH00eYF1`001Goo0`004Goo1P000UYF00<005YF0000;Goo000_Ool20002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00
FUIJEP04FUH00`00FUIJEP050002FUH>0004FUH00`00FUIJEP05FUH30002FUH01000FUH000002EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF6@000eYF00D005YFFUH005YF008002ioo`00<7oo10001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP@0
00AJEP03001JEUYF00D00003FUH005YF00YJEP04001JEUYFFUH400000eYF001JEP03FUH00`00FUH0
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000C000^Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP0500000eYF001JEP0:FUH40005FUH0
0`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000080004FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUH000020002FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYFFUH20002
FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF00001@001UYF00<005YFFUH015YF00<005YF
00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P0000=JEP00
FUH015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUH00000
15YF00@005YFFUH000IJEP03001JEP0000P000=JEP03001JEUYF00MJEP03001JEUYF009JEP<0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000EJ
EP03001JEUYF009JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002]oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF01@000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Ioo`8000=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
009JEQ8000=JEP03001oogoo02Uoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF3P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1EYF00<005YFFUH00eYF00@005YFFUIJEPD00003FUH007oo02Yoo`00;Goo0P0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP<000IJEP800003FUH005YF00IJ
EP03001JEUYF00AJEPH000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP<0
02]oo`00;Goo0P0015YF00@005YFFUIJEPL000Aoo`<00003FUH0000000P000AJEP04001JEUYF0003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000AFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP040002FUH00`00FUH000020004FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0015YF00<005YF0000:goo000/Ool00`00FUH00003FUH5000>Ool60004FUH700000eYF00000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000DFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20005FUH00`00FUIJ
EP03FUH80002FUH60003FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH00`00FUH0000[Ool002ao
o`04001JEP00FUH2000015YF000000004Woo2`000eYF20000eYF00<005YFFUH01EYF00<005YFFUH0
0UYF1P0065YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00<005YF00000`0000=JEP0000001Goo40001Goo0`001EYF00<005YFFUH00UYF0P00;7oo000/
Ool01P00FUH00000FUH000AJEP<000ioo`D000Moo`X00003FUH0000000h000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP800003FUH005YF00AJEP<00004FUH005YFFUH20008Ool50009Ool400000eYF001JEP06
FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000A
Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20002FUH00`00
FUIJEP020002FUH00`00FUIJEP0200000eYF001oo`08Ool30003Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH60004Ool5000?Ool4
00001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P000UYF100000AJ
EP00000000=JEP03001JEP0000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEQP000EJEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUH005YF500015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`00<goo000/Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH015YF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Moo`00;Goo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0006FUH00`00FUIJEP04FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH80009FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Woo000^Ool00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000=0002FUH00`00FUIJEP04
FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Woo000_Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP090003FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH4
00000eYF001JEP06FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@goo000`Ool20004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJ
EUYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00`001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF
3`00Agoo000bOol300000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20002FUH00`00FUH000020008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH60006FUH00`00FUH0
0009001DOol003Eoo`<000=JEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP<00003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00=JEPX0009JEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol003Qoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh00007
FUH005YFFUH005YF000025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF0`0015YF0P0027oo100015YF00H005YFFUH005YF001DOol003Ioo`80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000EJEP04001JEUYFFUH70002FUH30008FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP020002FUH2000<Ool300001eYF001JEUYF001JEP0005Aoo`00=7oo0`001EYF00<005YFFUH0
1UYF00<005YFFUH0100015YF00<005YFFUH00UYF1`0017oo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF10002goo1P000UYF00<005YF0000E7oo000bOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUHA000;Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0
000017oo1`000eYF00D005YFFUH005YF008005Eoo`00<Goo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH010000goo1@004Goo1P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
5P00EGoo000`Ool20004FUH00`00FUIJEP03FUH40007Ool5000=Ool40004FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001E
Ool002moo`03001JEP0000AJEP03001JEP0000<000aoo`<000Yoo`@0009JEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP02001COol002moo`04001JEUYF0003FUH2000IOol40006FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00;goo00D005YFFUH005YF008001Moo`@00003
FUH005YF00MJEP03001JEUYF00AJEP@00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000MJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080059oo`00<7oo00<005YF00000`0027oo
3`001EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEPh0
00=JEP05001JEUYFFUH0001BOol0031oo`800004FUH005YFFUH80003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000027oo0P001EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1P001EYF00<0
05YFFUH00eYF00<005YFFUH01@000UYF00<007ooOol0D7oo000`Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0037oo0P000eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YF000007oo00800003FUH000000080
055oo`00<7oo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL001Aoo`800003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000=JEP03001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUH0
0000DGoo000`Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP04000MOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH60004FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH01000FUIJEP00DGoo000bOol50003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH6000UOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0D0005Ool30005FUH00`00FUIJEP02FUH3001BOol003Mooa00035o
o`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEPP000Moo`D000Uoo`@00003FUH005YF00IJEP05
001JEUYFFUH0001DOol0085ooaT000moo`D000Aoo`D000EJEP03001JEUYF00EJEP04001JEP00001E
Ool0091oo`05001JEUYF001JEP02000COol300000goo000000020002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH3001GOol0095oo`03001JEP0001X000IJEP03001JEUYF00IJEP03001JEP0000<005Yo
o`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF0`00GWoo002AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04001QOol0095oo`80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD006Eoo`00TWoo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000JWoo002DOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001^Ool009Qooa0007Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58645 .75664 m .60596 .70697 L .5768 .6942 L p .707 .577 .707 r
F P
0 g
s
.60596 .70697 m .58645 .75664 L .61647 .76566 L p .707 .577 .707 r
F P
0 g
s
.61647 .76566 m .63598 .71599 L .60596 .70697 L p .707 .577 .707 r
F P
0 g
s
.55729 .74387 m .5768 .6942 L .55136 .67895 L p .707 .577 .707 r
F P
0 g
s
.5768 .6942 m .55729 .74387 L .58645 .75664 L p .707 .577 .707 r
F P
0 g
s
.63598 .71599 m .61647 .76566 L .64441 .77006 L p .707 .577 .707 r
F P
0 g
s
.64441 .77006 m .66392 .72039 L .63598 .71599 L p .707 .577 .707 r
F P
0 g
s
.53185 .72862 m .55136 .67895 L .53212 .66269 L p .707 .577 .707 r
F P
0 g
s
.55136 .67895 m .53185 .72862 L .55729 .74387 L p .707 .577 .707 r
F P
0 g
s
.66392 .72039 m .64441 .77006 L .66754 .7694 L p .707 .577 .707 r
F P
0 g
s
.66754 .7694 m .68705 .71973 L .66392 .72039 L p .707 .577 .707 r
F P
0 g
s
.59232 .81517 m .59626 .77876 L .56526 .77352 L p .707 .577 .707 r
F P
0 g
s
.59626 .77876 m .59232 .81517 L .62399 .8174 L p .707 .577 .707 r
F P
0 g
s
.62399 .8174 m .62793 .78099 L .59626 .77876 L p .707 .577 .707 r
F P
0 g
s
.6431 .83313 m .63859 .81472 L .60761 .82253 L p .707 .577 .707 r
F P
0 g
s
.63859 .81472 m .6431 .83313 L .6718 .82417 L p .707 .577 .707 r
F P
0 g
s
.6718 .82417 m .66729 .80576 L .63859 .81472 L p .707 .577 .707 r
F P
0 g
s
.62793 .78099 m .62399 .8174 L .65325 .81641 L p .707 .577 .707 r
F P
0 g
s
.65325 .81641 m .65719 .78 L .62793 .78099 L p .707 .577 .707 r
F P
0 g
s
.56132 .80993 m .56526 .77352 L .53798 .7658 L p .707 .577 .707 r
F P
0 g
s
.56526 .77352 m .56132 .80993 L .59232 .81517 L p .707 .577 .707 r
F P
0 g
s
.61212 .84094 m .60761 .82253 L .57739 .82842 L p .707 .577 .707 r
F P
0 g
s
.60761 .82253 m .61212 .84094 L .6431 .83313 L p .707 .577 .707 r
F P
0 g
s
.51261 .71236 m .53212 .66269 L .52097 .64703 L p .707 .577 .707 r
F P
0 g
s
.53212 .66269 m .51261 .71236 L .53185 .72862 L p .707 .577 .707 r
F P
0 g
s
.57739 .82842 m .5819 .84683 L .61212 .84094 L p .707 .577 .707 r
F P
0 g
s
.5819 .84683 m .57739 .82842 L .55088 .83182 L p .707 .577 .707 r
F P
0 g
s
.66729 .80576 m .6718 .82417 L .69542 .81494 L p .707 .577 .707 r
F P
0 g
s
.69542 .81494 m .6909 .79653 L .66729 .80576 L p .707 .577 .707 r
F P
0 g
s
.65719 .78 m .65325 .81641 L .67722 .81229 L p .707 .577 .707 r
F P
0 g
s
.67722 .81229 m .68116 .77588 L .65719 .78 L p .707 .577 .707 r
F P
0 g
s
.53798 .7658 m .53405 .8022 L .56132 .80993 L p .707 .577 .707 r
F P
0 g
s
.68705 .71973 m .66754 .7694 L .68359 .76375 L p .707 .577 .707 r
F P
0 g
s
.68359 .76375 m .7031 .71408 L .68705 .71973 L p .707 .577 .707 r
F P
0 g
s
.55088 .83182 m .5554 .85023 L .5819 .84683 L p .707 .577 .707 r
F P
0 g
s
.53405 .8022 m .53798 .7658 L .51709 .75633 L p .707 .577 .707 r
F P
0 g
s
.51709 .75633 m .51315 .79274 L .53405 .8022 L p .707 .577 .707 r
F P
0 g
s
.52097 .64703 m .50146 .6967 L .51261 .71236 L p .707 .577 .707 r
F P
0 g
s
.5554 .85023 m .55088 .83182 L .53069 .83239 L p .707 .577 .707 r
F P
0 g
s
.50146 .6967 m .52097 .64703 L .519 .6335 L p .707 .577 .707 r
F P
0 g
s
.53069 .83239 m .5352 .8508 L .5554 .85023 L p .707 .577 .707 r
F P
0 g
s
.6909 .79653 m .69542 .81494 L .71163 .80634 L p .707 .577 .707 r
F P
0 g
s
.68116 .77588 m .67722 .81229 L .69356 .80545 L p .707 .577 .707 r
F P
0 g
s
.71163 .80634 m .70712 .78793 L .6909 .79653 L p .707 .577 .707 r
F P
0 g
s
.69356 .80545 m .6975 .76905 L .68116 .77588 L p .707 .577 .707 r
F P
0 g
s
.51315 .79274 m .51709 .75633 L .50463 .74606 L p .707 .577 .707 r
F P
0 g
s
.7031 .71408 m .68359 .76375 L .69099 .75367 L p .707 .577 .707 r
F P
0 g
s
.69099 .75367 m .7105 .704 L .7031 .71408 L p .707 .577 .707 r
F P
0 g
s
.50463 .74606 m .50069 .78247 L .51315 .79274 L p .707 .577 .707 r
F P
0 g
s
.519 .6335 m .49949 .68317 L .50146 .6967 L p .707 .577 .707 r
F P
0 g
s
.5352 .8508 m .53069 .83239 L .51878 .83009 L p .707 .577 .707 r
F P
0 g
s
.51878 .83009 m .52329 .8485 L .5352 .8508 L p .707 .577 .707 r
F P
0 g
s
.6975 .76905 m .69356 .80545 L .70067 .79656 L p .707 .577 .707 r
F P
0 g
s
.70067 .79656 m .70461 .76015 L .6975 .76905 L p .707 .577 .707 r
F P
0 g
s
.49949 .68317 m .519 .6335 L .5264 .62341 L p .707 .577 .707 r
F P
0 g
s
.70712 .78793 m .71163 .80634 L .71887 .79921 L p .707 .577 .707 r
F P
0 g
s
.71887 .79921 m .71435 .7808 L .70712 .78793 L p .707 .577 .707 r
F P
0 g
s
.50069 .78247 m .50463 .74606 L .50181 .73598 L p .707 .577 .707 r
F P
0 g
s
.46555 .82173 m .50283 .32534 L .45895 .31936 L p .707 .577 .707 r
F P
0 g
s
.50181 .73598 m .49787 .77239 L .50069 .78247 L p .707 .577 .707 r
F P
0 g
s
.5264 .62341 m .50689 .67308 L .49949 .68317 L p .707 .577 .707 r
F P
0 g
s
.50689 .67308 m .5264 .62341 L .54245 .61777 L p .707 .577 .707 r
F P
0 g
s
.49787 .77239 m .50181 .73598 L .50892 .72709 L p .707 .577 .707 r
F P
0 g
s
.50892 .72709 m .50498 .7635 L .49787 .77239 L p .707 .577 .707 r
F P
0 g
s
.54245 .61777 m .52294 .66744 L .50689 .67308 L p .707 .577 .707 r
F P
0 g
s
.50498 .7635 m .50892 .72709 L .52526 .72025 L p .707 .577 .707 r
F P
0 g
s
.52526 .72025 m .52132 .75666 L .50498 .7635 L p .707 .577 .707 r
F P
0 g
s
.50283 .32534 m .46555 .82173 L .51038 .82361 L p .707 .577 .707 r
F P
0 g
s
.51038 .82361 m .54766 .32721 L .50283 .32534 L p .707 .577 .707 r
F P
0 g
s
.7105 .704 m .69099 .75367 L .68902 .74013 L p .707 .577 .707 r
F P
0 g
s
.68902 .74013 m .70853 .69046 L .7105 .704 L p .707 .577 .707 r
F P
0 g
s
.52329 .8485 m .51878 .83009 L .51632 .82513 L p .707 .577 .707 r
F P
0 g
s
.51632 .82513 m .52083 .84354 L .52329 .8485 L p .707 .577 .707 r
F P
0 g
s
.52083 .84354 m .51632 .82513 L .52355 .818 L p .707 .577 .707 r
F P
0 g
s
.52294 .66744 m .54245 .61777 L .56558 .61711 L p .707 .577 .707 r
F P
0 g
s
.52355 .818 m .52807 .83641 L .52083 .84354 L p .707 .577 .707 r
F P
0 g
s
.56558 .61711 m .54607 .66678 L .52294 .66744 L p .707 .577 .707 r
F P
0 g
s
.54607 .66678 m .56558 .61711 L .59352 .62151 L p .707 .577 .707 r
F P
0 g
s
.52807 .83641 m .52355 .818 L .53977 .8094 L p .707 .577 .707 r
F P
0 g
s
.53977 .8094 m .54429 .82781 L .52807 .83641 L p .707 .577 .707 r
F P
0 g
s
.52132 .75666 m .52526 .72025 L .54923 .71614 L p .707 .577 .707 r
F P
0 g
s
.59352 .62151 m .57401 .67118 L .54607 .66678 L p .707 .577 .707 r
F P
0 g
s
.54923 .71614 m .5453 .75254 L .52132 .75666 L p .707 .577 .707 r
F P
0 g
s
.54429 .82781 m .53977 .8094 L .56339 .80016 L p .707 .577 .707 r
F P
0 g
s
.5453 .75254 m .54923 .71614 L .57849 .71515 L p .707 .577 .707 r
F P
0 g
s
.56339 .80016 m .5679 .81857 L .54429 .82781 L p .707 .577 .707 r
F P
0 g
s
.57849 .71515 m .57455 .75155 L .5453 .75254 L p .707 .577 .707 r
F P
0 g
s
.54766 .32721 m .51038 .82361 L .55177 .8212 L p .707 .577 .707 r
F P
0 g
s
.55177 .8212 m .58906 .3248 L .54766 .32721 L p .707 .577 .707 r
F P
0 g
s
.42166 .81575 m .45895 .31936 L .42031 .30986 L p .707 .577 .707 r
F P
0 g
s
.45895 .31936 m .42166 .81575 L .46555 .82173 L p .707 .577 .707 r
F P
0 g
s
.70461 .76015 m .70067 .79656 L .69785 .78648 L p .707 .577 .707 r
F P
0 g
s
.69785 .78648 m .70179 .75008 L .70461 .76015 L p .707 .577 .707 r
F P
0 g
s
.71435 .7808 m .71887 .79921 L .71641 .79425 L p .707 .577 .707 r
F P
0 g
s
.71641 .79425 m .7119 .77584 L .71435 .7808 L p .707 .577 .707 r
F P
0 g
s
.57401 .67118 m .59352 .62151 L .62354 .63053 L p .707 .577 .707 r
F P
0 g
s
.62354 .63053 m .60403 .6802 L .57401 .67118 L p .707 .577 .707 r
F P
0 g
s
.57455 .75155 m .57849 .71515 L .61016 .71738 L p .707 .577 .707 r
F P
0 g
s
.61016 .71738 m .60622 .75378 L .57455 .75155 L p .707 .577 .707 r
F P
0 g
s
.5679 .81857 m .56339 .80016 L .59209 .79121 L p .707 .577 .707 r
F P
0 g
s
.59209 .79121 m .5966 .80962 L .5679 .81857 L p .707 .577 .707 r
F P
0 g
s
.58906 .3248 m .55177 .8212 L .58567 .81474 L p .707 .577 .707 r
F P
0 g
s
.58567 .81474 m .62296 .31834 L .58906 .3248 L p .707 .577 .707 r
F P
0 g
s
.38302 .80625 m .42031 .30986 L .39069 .29777 L p .707 .577 .707 r
F P
0 g
s
.42031 .30986 m .38302 .80625 L .42166 .81575 L p .707 .577 .707 r
F P
0 g
s
.70853 .69046 m .68902 .74013 L .67787 .72447 L p .707 .577 .707 r
F P
0 g
s
.67787 .72447 m .69738 .6748 L .70853 .69046 L p .707 .577 .707 r
F P
0 g
s
.24344 .7218 m .26295 .67213 L .2338 .65937 L p .707 .577 .707 r
F P
0 g
s
.26295 .67213 m .24344 .7218 L .27346 .73082 L p .707 .577 .707 r
F P
0 g
s
.27346 .73082 m .29297 .68116 L .26295 .67213 L p .707 .577 .707 r
F P
0 g
s
.21428 .70904 m .2338 .65937 L .20835 .64412 L p .707 .577 .707 r
F P
0 g
s
.2338 .65937 m .21428 .70904 L .24344 .7218 L p .707 .577 .707 r
F P
0 g
s
.29297 .68116 m .27346 .73082 L .3014 .73522 L p .707 .577 .707 r
F P
0 g
s
.3014 .73522 m .32091 .68555 L .29297 .68116 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.18884 .69378 m .20835 .64412 L .18911 .62786 L p .707 .577 .707 r
F P
0 g
s
.20835 .64412 m .18884 .69378 L .21428 .70904 L p .707 .577 .707 r
F P
0 g
s
.70179 .75008 m .69785 .78648 L .68539 .77621 L p .707 .577 .707 r
F P
0 g
s
.68539 .77621 m .68933 .7398 L .70179 .75008 L p .707 .577 .707 r
F P
0 g
s
.6527 .64329 m .63318 .69296 L .60403 .6802 L p .707 .577 .707 r
F P
0 g
s
.60403 .6802 m .62354 .63053 L .6527 .64329 L p .707 .577 .707 r
F P
0 g
s
.64116 .72261 m .63722 .75902 L .60622 .75378 L p .707 .577 .707 r
F P
0 g
s
.60622 .75378 m .61016 .71738 L .64116 .72261 L p .707 .577 .707 r
F P
0 g
s
.5966 .80962 m .59209 .79121 L .62306 .7834 L p .707 .577 .707 r
F P
0 g
s
.62306 .7834 m .62758 .80181 L .5966 .80962 L p .707 .577 .707 r
F P
0 g
s
.62296 .31834 m .58567 .81474 L .60876 .80486 L p .707 .577 .707 r
F P
0 g
s
.60876 .80486 m .64605 .30846 L .62296 .31834 L p .707 .577 .707 r
F P
0 g
s
.7119 .77584 m .71641 .79425 L .7045 .79194 L p .707 .577 .707 r
F P
0 g
s
.7045 .79194 m .69998 .77353 L .7119 .77584 L p .707 .577 .707 r
F P
0 g
s
.32091 .68555 m .3014 .73522 L .32453 .73457 L p .707 .577 .707 r
F P
0 g
s
.32453 .73457 m .34404 .6849 L .32091 .68555 L p .707 .577 .707 r
F P
0 g
s
.69738 .6748 m .67787 .72447 L .65863 .70822 L p .707 .577 .707 r
F P
0 g
s
.65863 .70822 m .67814 .65855 L .69738 .6748 L p .707 .577 .707 r
F P
0 g
s
.24931 .7734 m .25325 .737 L .22225 .73176 L p .707 .577 .707 r
F P
0 g
s
.25325 .737 m .24931 .7734 L .28098 .77563 L p .707 .577 .707 r
F P
0 g
s
.28098 .77563 m .28492 .73923 L .25325 .737 L p .707 .577 .707 r
F P
0 g
s
.28492 .73923 m .28098 .77563 L .31024 .77464 L p .707 .577 .707 r
F P
0 g
s
.31024 .77464 m .31418 .73824 L .28492 .73923 L p .707 .577 .707 r
F P
0 g
s
.34058 .72892 m .36009 .67925 L .34404 .6849 L p .707 .577 .707 r
F P
0 g
s
.34789 .76868 m .35241 .78709 L .36863 .77849 L p .707 .577 .707 r
F P
0 g
s
.36863 .77849 m .36411 .76008 L .34789 .76868 L p .707 .577 .707 r
F P
0 g
s
.36009 .67925 m .34058 .72892 L .34798 .71883 L p .707 .577 .707 r
F P
0 g
s
.34798 .71883 m .36749 .66916 L .36009 .67925 L p .707 .577 .707 r
F P
0 g
s
.35449 .72728 m .35055 .76369 L .35766 .75479 L p .707 .577 .707 r
F P
0 g
s
.35766 .75479 m .3616 .71839 L .35449 .72728 L p .707 .577 .707 r
F P
0 g
s
.36749 .66916 m .34798 .71883 L .34601 .7053 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .36552 .65563 L .36749 .66916 L p .707 .577 .707 r
F P
0 g
s
.3616 .71839 m .35766 .75479 L .35485 .74472 L p .707 .577 .707 r
F P
0 g
s
.35485 .74472 m .35879 .70831 L .3616 .71839 L p .707 .577 .707 r
F P
0 g
s
.34404 .6849 m .32453 .73457 L .34058 .72892 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .33486 .68964 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.36552 .65563 m .34648 .70411 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.34648 .70411 m .34601 .7053 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.373 .28428 m .36897 .27071 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.35241 .78709 m .34789 .76868 L .32428 .77791 L p .707 .577 .707 r
F P
0 g
s
.33815 .73412 m .33421 .77053 L .35055 .76369 L p .707 .577 .707 r
F P
0 g
s
.35055 .76369 m .35449 .72728 L .33815 .73412 L p .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34053 .6752 L p .34691 .67021 L .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34691 .67021 L .34683 .67636 L .707 .577 .707 r
F
.34053 .6752 m .35437 .63997 L .36022 .64818 L p F P
0 g
s
.36022 .64818 m .36552 .65563 L p .34053 .6752 L .707 .577 .707 r
F P
0 g
s
.31418 .73824 m .31024 .77464 L .33421 .77053 L p .707 .577 .707 r
F P
0 g
s
.33421 .77053 m .33815 .73412 L .31418 .73824 L p .707 .577 .707 r
F P
0 g
s
.35437 .63997 m .33486 .68964 L .3274 .68333 L p .707 .577 .707 r
F P
0 g
s
.3274 .68333 m .31562 .67338 L p .32979 .66116 L .707 .577 .707 r
F P
0 g
s
.32979 .66116 m .35437 .63997 L .3274 .68333 L .707 .577 .707 r
F
.36897 .27071 m .34853 .54284 L p .34787 .59421 L F P
0 g
s
.31562 .67338 m .33513 .62371 L .35437 .63997 L p .707 .577 .707 r
F P
0 g
s
.34632 .69804 m .34238 .73445 L .32149 .72498 L p .707 .577 .707 r
F P
0 g
s
.32149 .72498 m .32543 .68858 L .34632 .69804 L p .707 .577 .707 r
F P
0 g
s
.33678 .74626 m .33918 .75605 L p .31479 .76807 L .707 .577 .707 r
F P
0 g
s
.34683 .67636 m .34691 .67021 L .36552 .65563 L .707 .577 .707 r
F
.32428 .77791 m .32879 .79632 L .35241 .78709 L p F P
0 g
s
.35879 .70831 m .35485 .74472 L .34238 .73445 L p .707 .577 .707 r
F P
0 g
s
.34238 .73445 m .34632 .69804 L .35879 .70831 L p .707 .577 .707 r
F P
0 g
s
.33633 .78115 m .3534 .79417 L p .35713 .69729 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .33821 .75209 L p .34222 .7461 L .707 .577 .707 r
F P
0 g
s
.33821 .75209 m .33678 .74626 L .33884 .7462 L p .707 .577 .707 r
F P
0 g
s
.33884 .7462 m .34222 .7461 L p .33821 .75209 L .707 .577 .707 r
F P
0 g
s
.33816 .76507 m .31479 .76807 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.31479 .76807 m .31027 .74966 L .33678 .74626 L p .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .33531 .7793 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33531 .7793 m .33571 .78068 L p .33659 .76728 L .707 .577 .707 r
F P
0 g
s
.33659 .76728 m .34787 .59421 L .33531 .7793 L .707 .577 .707 r
F
.35713 .69729 m .36289 .54728 L .33918 .75605 L F
.35713 .69729 m .33918 .75605 L .33633 .78115 L F
.3534 .79417 m .39069 .29777 L .373 .28428 L p F P
0 g
s
.34129 .76467 m .33918 .75605 L p .35698 .74568 L .707 .577 .707 r
F P
0 g
s
.34222 .7461 m .35698 .74568 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .34129 .76467 L .33816 .76507 L p .707 .577 .707 r
F P
0 g
s
.373 .28428 m .33571 .78068 L .33633 .78115 L p .707 .577 .707 r
F P
0 g
s
.36289 .54728 m .373 .28428 L .33633 .78115 L .707 .577 .707 r
F
.34853 .54284 m .33168 .7671 L p .34787 .59421 L F P
0 g
s
.3475 .62381 m .373 .28428 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .36212 .36191 L p .37899 .25838 L .707 .577 .707 r
F P
0 g
s
.36212 .36191 m .36897 .27071 L .37243 .26645 L p .707 .577 .707 r
F P
0 g
s
.37243 .26645 m .37899 .25838 L p .36212 .36191 L .707 .577 .707 r
F P
0 g
s
.36411 .76008 m .36863 .77849 L .37586 .77136 L p .707 .577 .707 r
F P
0 g
s
.37586 .77136 m .37134 .75295 L .36411 .76008 L p .707 .577 .707 r
F P
0 g
s
.37134 .75295 m .37586 .77136 L .37378 .76716 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .36467 .73141 L .3534 .79417 L .707 .577 .707 r
F
.37378 .76716 m .3734 .7664 L p .37313 .76461 L F P
0 g
s
.37313 .76461 m .37134 .75295 L .37378 .76716 L .707 .577 .707 r
F
.3534 .79417 m .38302 .80625 L p .38306 .80357 L F P
0 g
s
.3734 .7664 m .36889 .74799 L .37134 .75295 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .38594 .61289 L .36467 .73141 L .707 .577 .707 r
F
.39069 .29777 m .36485 .64183 L p .38594 .61289 L F P
0 g
s
.36485 .64183 m .3534 .79417 L p .38594 .61289 L .707 .577 .707 r
F P
0 g
s
.33571 .78068 m .3475 .62381 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.21832 .76816 m .22225 .73176 L .19498 .72403 L p .707 .577 .707 r
F P
0 g
s
.22225 .73176 m .21832 .76816 L .24931 .7734 L p .707 .577 .707 r
F P
0 g
s
.26912 .81309 m .2646 .79468 L .23438 .80057 L p .707 .577 .707 r
F P
0 g
s
.2646 .79468 m .26912 .81309 L .30009 .80528 L p .707 .577 .707 r
F P
0 g
s
.30009 .80528 m .29558 .78687 L .2646 .79468 L p .707 .577 .707 r
F P
0 g
s
.1696 .67753 m .18911 .62786 L .17796 .6122 L p .707 .577 .707 r
F P
0 g
s
.18911 .62786 m .1696 .67753 L .18884 .69378 L p .707 .577 .707 r
F P
0 g
s
.29558 .78687 m .30009 .80528 L .32879 .79632 L p .707 .577 .707 r
F P
0 g
s
.32879 .79632 m .32428 .77791 L .29558 .78687 L p .707 .577 .707 r
F P
0 g
s
.23438 .80057 m .2389 .81898 L .26912 .81309 L p .707 .577 .707 r
F P
0 g
s
.19498 .72403 m .19104 .76044 L .21832 .76816 L p .707 .577 .707 r
F P
0 g
s
.67814 .65855 m .65863 .70822 L .63318 .69296 L p .707 .577 .707 r
F P
0 g
s
.63318 .69296 m .6527 .64329 L .67814 .65855 L p .707 .577 .707 r
F P
0 g
s
.2389 .81898 m .23438 .80057 L .20788 .80397 L p .707 .577 .707 r
F P
0 g
s
.19104 .76044 m .19498 .72403 L .17408 .71457 L p .707 .577 .707 r
F P
0 g
s
.68933 .7398 m .68539 .77621 L .6645 .76675 L p .707 .577 .707 r
F P
0 g
s
.6645 .76675 m .66844 .73034 L .68933 .7398 L p .707 .577 .707 r
F P
0 g
s
.20788 .80397 m .21239 .82238 L .2389 .81898 L p .707 .577 .707 r
F P
0 g
s
.69998 .77353 m .7045 .79194 L .6843 .79252 L p .707 .577 .707 r
F P
0 g
s
.6843 .79252 m .67979 .77411 L .69998 .77353 L p .707 .577 .707 r
F P
0 g
s
.17408 .71457 m .17014 .75097 L .19104 .76044 L p .707 .577 .707 r
F P
0 g
s
.64605 .30846 m .60876 .80486 L .61878 .79253 L p .707 .577 .707 r
F P
0 g
s
.61878 .79253 m .65607 .29613 L .64605 .30846 L p .707 .577 .707 r
F P
0 g
s
.17796 .6122 m .15845 .66187 L .1696 .67753 L p .707 .577 .707 r
F P
0 g
s
.21239 .82238 m .20788 .80397 L .18768 .80454 L p .707 .577 .707 r
F P
0 g
s
.15845 .66187 m .17796 .6122 L .17599 .59867 L p .707 .577 .707 r
F P
0 g
s
.18768 .80454 m .19219 .82295 L .21239 .82238 L p .707 .577 .707 r
F P
0 g
s
.17014 .75097 m .17408 .71457 L .16162 .7043 L p .707 .577 .707 r
F P
0 g
s
.66844 .73034 m .6645 .76675 L .63722 .75902 L p .707 .577 .707 r
F P
0 g
s
.63722 .75902 m .64116 .72261 L .66844 .73034 L p .707 .577 .707 r
F P
0 g
s
.67979 .77411 m .6843 .79252 L .6578 .79592 L p .707 .577 .707 r
F P
0 g
s
.6578 .79592 m .65328 .77751 L .67979 .77411 L p .707 .577 .707 r
F P
0 g
s
.16162 .7043 m .15768 .7407 L .17014 .75097 L p .707 .577 .707 r
F P
0 g
s
.17599 .59867 m .15648 .64834 L .15845 .66187 L p .707 .577 .707 r
F P
0 g
s
.19219 .82295 m .18768 .80454 L .17577 .80224 L p .707 .577 .707 r
F P
0 g
s
.17577 .80224 m .18028 .82065 L .19219 .82295 L p .707 .577 .707 r
F P
0 g
s
.15648 .64834 m .17599 .59867 L .18339 .58858 L p .707 .577 .707 r
F P
0 g
s
.65328 .77751 m .6578 .79592 L .62758 .80181 L p .707 .577 .707 r
F P
0 g
s
.62758 .80181 m .62306 .7834 L .65328 .77751 L p .707 .577 .707 r
F P
0 g
s
.15768 .7407 m .16162 .7043 L .1588 .69422 L p .707 .577 .707 r
F P
0 g
s
.65607 .29613 m .61878 .79253 L .61475 .77895 L p .707 .577 .707 r
F P
0 g
s
.61475 .77895 m .65203 .28256 L .65607 .29613 L p .707 .577 .707 r
F P
0 g
s
.1588 .69422 m .15486 .73063 L .15768 .7407 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18339 .58858 m .16388 .63825 L .15648 .64834 L p .707 .577 .707 r
F P
0 g
s
.18028 .82065 m .17577 .80224 L .17331 .79728 L p .707 .577 .707 r
F P
0 g
s
.17331 .79728 m .17782 .81569 L .18028 .82065 L p .707 .577 .707 r
F P
0 g
s
.16388 .63825 m .18339 .58858 L .19944 .58293 L p .707 .577 .707 r
F P
0 g
s
.15486 .73063 m .1588 .69422 L .16591 .68533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16591 .68533 m .16197 .72173 L .15486 .73063 L p .707 .577 .707 r
F P
0 g
s
.65203 .28256 m .61475 .77895 L .59706 .76546 L p .707 .577 .707 r
F P
0 g
s
.59706 .76546 m .63434 .26907 L .65203 .28256 L p .707 .577 .707 r
F P
0 g
s
.19944 .58293 m .17993 .6326 L .16388 .63825 L p .707 .577 .707 r
F P
0 g
s
.17782 .81569 m .17331 .79728 L .18054 .79015 L p .707 .577 .707 r
F P
0 g
s
.17993 .6326 m .19944 .58293 L .22257 .58228 L p .707 .577 .707 r
F P
0 g
s
.18054 .79015 m .18506 .80856 L .17782 .81569 L p .707 .577 .707 r
F P
0 g
s
.3417 .75477 m .37899 .25838 L .40208 .2485 L p .707 .577 .707 r
F P
0 g
s
.37899 .25838 m .3417 .75477 L .33168 .7671 L p .707 .577 .707 r
F P
0 g
s
.16197 .72173 m .16591 .68533 L .18225 .67849 L p .707 .577 .707 r
F P
0 g
s
.36889 .74799 m .3734 .7664 L .36149 .76409 L p .707 .577 .707 r
F P
0 g
s
.36149 .76409 m .35698 .74568 L .36889 .74799 L p .707 .577 .707 r
F P
0 g
s
.18225 .67849 m .17832 .71489 L .16197 .72173 L p .707 .577 .707 r
F P
0 g
s
.22257 .58228 m .20306 .63195 L .17993 .6326 L p .707 .577 .707 r
F P
0 g
s
.20306 .63195 m .22257 .58228 L .25051 .58667 L p .707 .577 .707 r
F P
0 g
s
.33513 .62371 m .31562 .67338 L .29018 .65813 L p .707 .577 .707 r
F P
0 g
s
.29018 .65813 m .30969 .60846 L .33513 .62371 L p .707 .577 .707 r
F P
0 g
s
.18506 .80856 m .18054 .79015 L .19676 .78155 L p .707 .577 .707 r
F P
0 g
s
.19676 .78155 m .20128 .79996 L .18506 .80856 L p .707 .577 .707 r
F P
0 g
s
.63434 .26907 m .59706 .76546 L .56744 .75337 L p .707 .577 .707 r
F P
0 g
s
.56744 .75337 m .60473 .25698 L .63434 .26907 L p .707 .577 .707 r
F P
0 g
s
.17832 .71489 m .18225 .67849 L .20623 .67437 L p .707 .577 .707 r
F P
0 g
s
.231 .63634 m .25051 .58667 L .28053 .5957 L p .707 .577 .707 r
F P
0 g
s
.25051 .58667 m .231 .63634 L .20306 .63195 L p .707 .577 .707 r
F P
0 g
s
.35698 .74568 m .36149 .76409 L .34129 .76467 L p .707 .577 .707 r
F P
0 g
s
.30969 .60846 m .29018 .65813 L .26102 .64537 L p .707 .577 .707 r
F P
0 g
s
.26102 .64537 m .28053 .5957 L .30969 .60846 L p .707 .577 .707 r
F P
0 g
s
.28053 .5957 m .26102 .64537 L .231 .63634 L p .707 .577 .707 r
F P
0 g
s
.40208 .2485 m .36479 .74489 L .3417 .75477 L p .707 .577 .707 r
F P
0 g
s
.36479 .74489 m .40208 .2485 L .43598 .24204 L p .707 .577 .707 r
F P
0 g
s
.20623 .67437 m .20229 .71078 L .17832 .71489 L p .707 .577 .707 r
F P
0 g
s
.32543 .68858 m .32149 .72498 L .29421 .71726 L p .707 .577 .707 r
F P
0 g
s
.29421 .71726 m .29815 .68085 L .32543 .68858 L p .707 .577 .707 r
F P
0 g
s
.72365 .6646 m .74317 .61493 L .71401 .60216 L p .707 .577 .707 r
F P
0 g
s
.74317 .61493 m .72365 .6646 L .75367 .67362 L p .707 .577 .707 r
F P
0 g
s
.75367 .67362 m .77319 .62395 L .74317 .61493 L p .707 .577 .707 r
F P
0 g
s
.20229 .71078 m .20623 .67437 L .23548 .67338 L p .707 .577 .707 r
F P
0 g
s
.6945 .65183 m .71401 .60216 L .68857 .58691 L p .707 .577 .707 r
F P
0 g
s
.71401 .60216 m .6945 .65183 L .72365 .6646 L p .707 .577 .707 r
F P
0 g
s
.20128 .79996 m .19676 .78155 L .22038 .77231 L p .707 .577 .707 r
F P
0 g
s
.77319 .62395 m .75367 .67362 L .78161 .67802 L p .707 .577 .707 r
F P
0 g
s
.78161 .67802 m .80113 .62835 L .77319 .62395 L p .707 .577 .707 r
F P
0 g
s
.22038 .77231 m .22489 .79072 L .20128 .79996 L p .707 .577 .707 r
F P
0 g
s
.29815 .68085 m .29421 .71726 L .26321 .71202 L p .707 .577 .707 r
F P
0 g
s
.26321 .71202 m .26715 .67561 L .29815 .68085 L p .707 .577 .707 r
F P
0 g
s
.60473 .25698 m .56744 .75337 L .5288 .74388 L p .707 .577 .707 r
F P
0 g
s
.5288 .74388 m .56609 .24748 L .60473 .25698 L p .707 .577 .707 r
F P
0 g
s
.23548 .67338 m .23154 .70979 L .20229 .71078 L p .707 .577 .707 r
F P
0 g
s
.66905 .63658 m .68857 .58691 L .66933 .57066 L p .707 .577 .707 r
F P
0 g
s
.68857 .58691 m .66905 .63658 L .6945 .65183 L p .707 .577 .707 r
F P
0 g
s
.23154 .70979 m .23548 .67338 L .26715 .67561 L p .707 .577 .707 r
F P
0 g
s
.26715 .67561 m .26321 .71202 L .23154 .70979 L p .707 .577 .707 r
F P
0 g
s
.40632 .72105 m .4373 .71324 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .47737 .23963 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40001 .72083 m .43598 .24204 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .40632 .72105 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4373 .71324 m .43278 .69483 L .41015 .70054 L p .707 .577 .707 r
F P
0 g
s
.47737 .23963 m .47631 .25371 L p .40222 .71642 L .707 .577 .707 r
F P
0 g
s
.40214 .71657 m .47737 .23963 L .40222 .71642 L .707 .577 .707 r
F
.4373 .71324 m .41015 .70054 L .40815 .70453 L F
.40632 .72105 m .40421 .71243 L p .40304 .71987 L F P
0 g
s
.43278 .69483 m .4373 .71324 L .466 .70428 L p .707 .577 .707 r
F P
0 g
s
.466 .70428 m .46148 .68587 L .43278 .69483 L p .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .40214 .71657 L .40222 .71642 L .707 .577 .707 r
F
.40013 .73835 m .39869 .73843 L p .47631 .25371 L F P
0 g
s
.39869 .73843 m .40001 .72083 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .36479 .74489 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .41456 .52721 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.41456 .52721 m .39869 .73843 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.37158 .70853 m .3761 .72694 L .40274 .72175 L p .707 .577 .707 r
F P
0 g
s
.40274 .72175 m .40632 .72105 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40304 .71987 m .37158 .70853 L .40274 .72175 L .707 .577 .707 r
F
.44008 .73602 m .40013 .73835 L p .42723 .56598 L F P
0 g
s
.47631 .25371 m .44807 .62977 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.44807 .62977 m .44008 .73602 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.41066 .63879 m .42286 .60774 L p .40016 .58009 L .707 .577 .707 r
F P
0 g
s
.42286 .60774 m .43018 .58912 L .42065 .58625 L p .707 .577 .707 r
F P
0 g
s
.42065 .58625 m .40016 .58009 L p .42286 .60774 L .707 .577 .707 r
F P
0 g
s
.41015 .70054 m .4018 .70264 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .37158 .70853 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .4018 .70264 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .40421 .71243 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.80113 .62835 m .78161 .67802 L .80474 .67736 L p .707 .577 .707 r
F P
0 g
s
.80474 .67736 m .82425 .62769 L .80113 .62835 L p .707 .577 .707 r
F P
0 g
s
.22489 .79072 m .22038 .77231 L .24908 .76336 L p .707 .577 .707 r
F P
0 g
s
.72952 .72313 m .73346 .68672 L .70247 .68149 L p .707 .577 .707 r
F P
0 g
s
.73346 .68672 m .72952 .72313 L .7612 .72536 L p .707 .577 .707 r
F P
0 g
s
.7612 .72536 m .76514 .68895 L .73346 .68672 L p .707 .577 .707 r
F P
0 g
s
.24908 .76336 m .25359 .78177 L .22489 .79072 L p .707 .577 .707 r
F P
0 g
s
.31027 .74966 m .31479 .76807 L .28457 .77396 L p .707 .577 .707 r
F P
0 g
s
.28457 .77396 m .28005 .75555 L .31027 .74966 L p .707 .577 .707 r
F P
0 g
s
.78031 .74109 m .77579 .72268 L .74481 .73049 L p .707 .577 .707 r
F P
0 g
s
.77579 .72268 m .78031 .74109 L .80901 .73213 L p .707 .577 .707 r
F P
0 g
s
.80901 .73213 m .80449 .71372 L .77579 .72268 L p .707 .577 .707 r
F P
0 g
s
.76514 .68895 m .7612 .72536 L .79045 .72437 L p .707 .577 .707 r
F P
0 g
s
.79045 .72437 m .79439 .68796 L .76514 .68895 L p .707 .577 .707 r
F P
0 g
s
.69853 .71789 m .70247 .68149 L .67519 .67376 L p .707 .577 .707 r
F P
0 g
s
.70247 .68149 m .69853 .71789 L .72952 .72313 L p .707 .577 .707 r
F P
0 g
s
.74933 .7489 m .74481 .73049 L .71459 .73638 L p .707 .577 .707 r
F P
0 g
s
.74481 .73049 m .74933 .7489 L .78031 .74109 L p .707 .577 .707 r
F P
0 g
s
.25359 .78177 m .24908 .76336 L .28005 .75555 L p .707 .577 .707 r
F P
0 g
s
.64981 .62033 m .66933 .57066 L .65818 .555 L p .707 .577 .707 r
F P
0 g
s
.66933 .57066 m .64981 .62033 L .66905 .63658 L p .707 .577 .707 r
F P
0 g
s
.56609 .24748 m .5288 .74388 L .48492 .7379 L p .707 .577 .707 r
F P
0 g
s
.46148 .68587 m .466 .70428 L .4696 .70287 L p .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .44008 .73602 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.5222 .2415 m .48508 .73571 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.46171 .68613 m .46148 .68587 L .4696 .70287 L .707 .577 .707 r
F
.4711 .68901 m .46148 .68587 L .47466 .7009 L F
.5222 .2415 m .56609 .24748 L p .48521 .73613 L F P
0 g
s
.48508 .73571 m .5222 .2415 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.48961 .69505 m .4851 .67664 L .46148 .68587 L p .707 .577 .707 r
F P
0 g
s
.48508 .73571 m .48492 .7379 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.4696 .70287 m .47466 .7009 L p .46171 .68613 L .707 .577 .707 r
F P
0 g
s
.47466 .7009 m .48961 .69505 L p .4711 .68901 L .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .48508 .73571 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.71459 .73638 m .71911 .75479 L .74933 .7489 L p .707 .577 .707 r
F P
0 g
s
.28005 .75555 m .28457 .77396 L .25359 .78177 L p .707 .577 .707 r
F P
0 g
s
.44008 .73602 m .45153 .58369 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .45812 .59351 L .44483 .59142 L p .707 .577 .707 r
F P
0 g
s
.44483 .59142 m .43018 .58912 L p .43272 .60542 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .44483 .59142 L .43272 .60542 L .707 .577 .707 r
F
.47737 .23963 m .5222 .2415 L p .46867 .56387 L F P
0 g
s
.45153 .58369 m .47737 .23963 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.71911 .75479 m .71459 .73638 L .68809 .73978 L p .707 .577 .707 r
F P
0 g
s
.80449 .71372 m .80901 .73213 L .83262 .7229 L p .707 .577 .707 r
F P
0 g
s
.83262 .7229 m .82811 .70449 L .80449 .71372 L p .707 .577 .707 r
F P
0 g
s
.79439 .68796 m .79045 .72437 L .81442 .72025 L p .707 .577 .707 r
F P
0 g
s
.81442 .72025 m .81836 .68385 L .79439 .68796 L p .707 .577 .707 r
F P
0 g
s
.67519 .67376 m .67125 .71016 L .69853 .71789 L p .707 .577 .707 r
F P
0 g
s
.82425 .62769 m .80474 .67736 L .82079 .67171 L p .707 .577 .707 r
F P
0 g
s
.82079 .67171 m .8403 .62204 L .82425 .62769 L p .707 .577 .707 r
F P
0 g
s
.68809 .73978 m .6926 .75819 L .71911 .75479 L p .707 .577 .707 r
F P
0 g
s
.67125 .71016 m .67519 .67376 L .65429 .66429 L p .707 .577 .707 r
F P
0 g
s
.65429 .66429 m .65036 .7007 L .67125 .71016 L p .707 .577 .707 r
F P
0 g
s
.65818 .555 m .63866 .60466 L .64981 .62033 L p .707 .577 .707 r
F P
0 g
s
.6926 .75819 m .68809 .73978 L .66789 .74035 L p .707 .577 .707 r
F P
0 g
s
.63866 .60466 m .65818 .555 L .6562 .54146 L p .707 .577 .707 r
F P
0 g
s
.66789 .74035 m .67241 .75877 L .6926 .75819 L p .707 .577 .707 r
F P
0 g
s
.82811 .70449 m .83262 .7229 L .84884 .7143 L p .707 .577 .707 r
F P
0 g
s
.81836 .68385 m .81442 .72025 L .83076 .71341 L p .707 .577 .707 r
F P
0 g
s
.84884 .7143 m .84432 .69589 L .82811 .70449 L p .707 .577 .707 r
F P
0 g
s
.83076 .71341 m .8347 .67701 L .81836 .68385 L p .707 .577 .707 r
F P
0 g
s
.65036 .7007 m .65429 .66429 L .64183 .65402 L p .707 .577 .707 r
F P
0 g
s
.8403 .62204 m .82079 .67171 L .82819 .66163 L p .707 .577 .707 r
F P
0 g
s
.82819 .66163 m .84771 .61196 L .8403 .62204 L p .707 .577 .707 r
F P
0 g
s
.64183 .65402 m .63789 .69043 L .65036 .7007 L p .707 .577 .707 r
F P
0 g
s
.6562 .54146 m .63669 .59113 L .63866 .60466 L p .707 .577 .707 r
F P
0 g
s
.67241 .75877 m .66789 .74035 L .65598 .73805 L p .707 .577 .707 r
F P
0 g
s
.65598 .73805 m .6605 .75646 L .67241 .75877 L p .707 .577 .707 r
F P
0 g
s
.8347 .67701 m .83076 .71341 L .83787 .70452 L p .707 .577 .707 r
F P
0 g
s
.83787 .70452 m .84181 .66811 L .8347 .67701 L p .707 .577 .707 r
F P
0 g
s
.63669 .59113 m .6562 .54146 L .66361 .53138 L p .707 .577 .707 r
F P
0 g
s
.84432 .69589 m .84884 .7143 L .85607 .70717 L p .707 .577 .707 r
F P
0 g
s
.85607 .70717 m .85156 .68876 L .84432 .69589 L p .707 .577 .707 r
F P
0 g
s
.63789 .69043 m .64183 .65402 L .63902 .64395 L p .707 .577 .707 r
F P
0 g
s
.84771 .61196 m .82819 .66163 L .82622 .64809 L p .707 .577 .707 r
F P
0 g
s
.82622 .64809 m .84574 .59842 L .84771 .61196 L p .707 .577 .707 r
F P
0 g
s
.63902 .64395 m .63508 .68035 L .63789 .69043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.66361 .53138 m .64409 .58104 L .63669 .59113 L p .707 .577 .707 r
F P
0 g
s
.6605 .75646 m .65598 .73805 L .65352 .73309 L p .707 .577 .707 r
F P
0 g
s
.65352 .73309 m .65804 .7515 L .6605 .75646 L p .707 .577 .707 r
F P
0 g
s
.84181 .66811 m .83787 .70452 L .83506 .69444 L p .707 .577 .707 r
F P
0 g
s
.83506 .69444 m .839 .65804 L .84181 .66811 L p .707 .577 .707 r
F P
0 g
s
.64409 .58104 m .66361 .53138 L .67966 .52573 L p .707 .577 .707 r
F P
0 g
s
.85156 .68876 m .85607 .70717 L .85361 .70221 L p .707 .577 .707 r
F P
0 g
s
.85361 .70221 m .8491 .6838 L .85156 .68876 L p .707 .577 .707 r
F P
0 g
s
.63508 .68035 m .63902 .64395 L .64613 .63505 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84574 .59842 m .82622 .64809 L .81507 .63243 L p .707 .577 .707 r
F P
0 g
s
.81507 .63243 m .83459 .58276 L .84574 .59842 L p .707 .577 .707 r
F P
0 g
s
.38064 .62976 m .40016 .58009 L .371 .56733 L p .707 .577 .707 r
F P
0 g
s
.40016 .58009 m .38064 .62976 L .41066 .63879 L p .707 .577 .707 r
F P
0 g
s
.35149 .617 m .371 .56733 L .34556 .55208 L p .707 .577 .707 r
F P
0 g
s
.371 .56733 m .35149 .617 L .38064 .62976 L p .707 .577 .707 r
F P
0 g
s
.64613 .63505 m .64219 .67146 L .63508 .68035 L p .707 .577 .707 r
F P
0 g
s
.43018 .58912 m .41066 .63879 L .4386 .64318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67966 .52573 m .66014 .5754 L .64409 .58104 L p .707 .577 .707 r
F P
0 g
s
.65804 .7515 m .65352 .73309 L .66076 .72596 L p .707 .577 .707 r
F P
0 g
s
.66014 .5754 m .67966 .52573 L .70278 .52507 L p .707 .577 .707 r
F P
0 g
s
.66076 .72596 m .66527 .74437 L .65804 .7515 L p .707 .577 .707 r
F P
0 g
s
.32604 .60175 m .34556 .55208 L .32632 .53582 L p .707 .577 .707 r
F P
0 g
s
.34556 .55208 m .32604 .60175 L .35149 .617 L p .707 .577 .707 r
F P
0 g
s
.839 .65804 m .83506 .69444 L .8226 .68417 L p .707 .577 .707 r
F P
0 g
s
.8226 .68417 m .82653 .64777 L .839 .65804 L p .707 .577 .707 r
F P
0 g
s
.8491 .6838 m .85361 .70221 L .8417 .6999 L p .707 .577 .707 r
F P
0 g
s
.8417 .6999 m .83719 .68149 L .8491 .6838 L p .707 .577 .707 r
F P
0 g
s
.45812 .59351 m .4386 .64318 L .46173 .64253 L p .707 .577 .707 r
F P
0 g
s
.46173 .64253 m .48124 .59286 L .45812 .59351 L p .707 .577 .707 r
F P
0 g
s
.83459 .58276 m .81507 .63243 L .79583 .61618 L p .707 .577 .707 r
F P
0 g
s
.79583 .61618 m .81535 .56651 L .83459 .58276 L p .707 .577 .707 r
F P
0 g
s
.64219 .67146 m .64613 .63505 L .66247 .62821 L p .707 .577 .707 r
F P
0 g
s
.38651 .68136 m .39045 .64496 L .35946 .63972 L p .707 .577 .707 r
F P
0 g
s
.39045 .64496 m .38651 .68136 L .41819 .6836 L p .707 .577 .707 r
F P
0 g
s
.41819 .6836 m .42213 .64719 L .39045 .64496 L p .707 .577 .707 r
F P
0 g
s
.42213 .64719 m .41819 .6836 L .44744 .6826 L p .707 .577 .707 r
F P
0 g
s
.44744 .6826 m .45138 .6462 L .42213 .64719 L p .707 .577 .707 r
F P
0 g
s
.35552 .67613 m .35946 .63972 L .33218 .63199 L p .707 .577 .707 r
F P
0 g
s
.35946 .63972 m .35552 .67613 L .38651 .68136 L p .707 .577 .707 r
F P
0 g
s
.66247 .62821 m .65853 .66462 L .64219 .67146 L p .707 .577 .707 r
F P
0 g
s
.3068 .58549 m .32632 .53582 L .31517 .52016 L p .707 .577 .707 r
F P
0 g
s
.32632 .53582 m .3068 .58549 L .32604 .60175 L p .707 .577 .707 r
F P
0 g
s
.70278 .52507 m .68327 .57474 L .66014 .5754 L p .707 .577 .707 r
F P
0 g
s
.68327 .57474 m .70278 .52507 L .73073 .52947 L p .707 .577 .707 r
F P
0 g
s
.45138 .6462 m .44744 .6826 L .47141 .67849 L p .707 .577 .707 r
F P
0 g
s
.47141 .67849 m .47535 .64208 L .45138 .6462 L p .707 .577 .707 r
F P
0 g
s
.33218 .63199 m .32824 .6684 L .35552 .67613 L p .707 .577 .707 r
F P
0 g
s
.66527 .74437 m .66076 .72596 L .67698 .71736 L p .707 .577 .707 r
F P
0 g
s
.81535 .56651 m .79583 .61618 L .77039 .60092 L p .707 .577 .707 r
F P
0 g
s
.77039 .60092 m .7899 .55125 L .81535 .56651 L p .707 .577 .707 r
F P
0 g
s
.3761 .72694 m .37158 .70853 L .34508 .71193 L p .707 .577 .707 r
F P
0 g
s
.32824 .6684 m .33218 .63199 L .31128 .62253 L p .707 .577 .707 r
F P
0 g
s
.82653 .64777 m .8226 .68417 L .8017 .67471 L p .707 .577 .707 r
F P
0 g
s
.8017 .67471 m .80564 .6383 L .82653 .64777 L p .707 .577 .707 r
F P
0 g
s
.48124 .59286 m .46173 .64253 L .47778 .63688 L p .707 .577 .707 r
F P
0 g
s
.47778 .63688 m .49729 .58721 L .48124 .59286 L p .707 .577 .707 r
F P
0 g
s
.67698 .71736 m .68149 .73577 L .66527 .74437 L p .707 .577 .707 r
F P
0 g
s
.34508 .71193 m .34959 .73034 L .3761 .72694 L p .707 .577 .707 r
F P
0 g
s
.83719 .68149 m .8417 .6999 L .82151 .70048 L p .707 .577 .707 r
F P
0 g
s
.82151 .70048 m .81699 .68207 L .83719 .68149 L p .707 .577 .707 r
F P
0 g
s
.65853 .66462 m .66247 .62821 L .68644 .6241 L p .707 .577 .707 r
F P
0 g
s
.71121 .57914 m .73073 .52947 L .76074 .53849 L p .707 .577 .707 r
F P
0 g
s
.73073 .52947 m .71121 .57914 L .68327 .57474 L p .707 .577 .707 r
F P
0 g
s
.7899 .55125 m .77039 .60092 L .74123 .58816 L p .707 .577 .707 r
F P
0 g
s
.74123 .58816 m .76074 .53849 L .7899 .55125 L p .707 .577 .707 r
F P
0 g
s
.31128 .62253 m .30734 .65894 L .32824 .6684 L p .707 .577 .707 r
F P
0 g
s
.76074 .53849 m .74123 .58816 L .71121 .57914 L p .707 .577 .707 r
F P
0 g
s
.31517 .52016 m .29565 .56983 L .3068 .58549 L p .707 .577 .707 r
F P
0 g
s
.47535 .64208 m .47141 .67849 L .48775 .67165 L p .707 .577 .707 r
F P
0 g
s
.48775 .67165 m .49169 .63524 L .47535 .64208 L p .707 .577 .707 r
F P
0 g
s
.34959 .73034 m .34508 .71193 L .32488 .71251 L p .707 .577 .707 r
F P
0 g
s
.29565 .56983 m .31517 .52016 L .31319 .50663 L p .707 .577 .707 r
F P
0 g
s
.68644 .6241 m .6825 .6605 L .65853 .66462 L p .707 .577 .707 r
F P
0 g
s
.32488 .71251 m .3294 .73092 L .34959 .73034 L p .707 .577 .707 r
F P
0 g
s
.30734 .65894 m .31128 .62253 L .29882 .61226 L p .707 .577 .707 r
F P
0 g
s
.4851 .67664 m .48961 .69505 L .50583 .68645 L p .707 .577 .707 r
F P
0 g
s
.50583 .68645 m .50131 .66804 L .4851 .67664 L p .707 .577 .707 r
F P
0 g
s
.80564 .6383 m .8017 .67471 L .77442 .66698 L p .707 .577 .707 r
F P
0 g
s
.77442 .66698 m .77836 .63057 L .80564 .6383 L p .707 .577 .707 r
F P
0 g
s
.68149 .73577 m .67698 .71736 L .70059 .70813 L p .707 .577 .707 r
F P
0 g
s
.6825 .6605 m .68644 .6241 L .71569 .62311 L p .707 .577 .707 r
F P
0 g
s
.49729 .58721 m .47778 .63688 L .48518 .6268 L p .707 .577 .707 r
F P
0 g
s
.48518 .6268 m .5047 .57713 L .49729 .58721 L p .707 .577 .707 r
F P
0 g
s
.70059 .70813 m .70511 .72654 L .68149 .73577 L p .707 .577 .707 r
F P
0 g
s
.81699 .68207 m .82151 .70048 L .795 .70388 L p .707 .577 .707 r
F P
0 g
s
.795 .70388 m .79049 .68547 L .81699 .68207 L p .707 .577 .707 r
F P
0 g
s
.29882 .61226 m .29488 .64866 L .30734 .65894 L p .707 .577 .707 r
F P
0 g
s
.77836 .63057 m .77442 .66698 L .74343 .66174 L p .707 .577 .707 r
F P
0 g
s
.74343 .66174 m .74737 .62534 L .77836 .63057 L p .707 .577 .707 r
F P
0 g
s
.71569 .62311 m .71175 .65951 L .6825 .6605 L p .707 .577 .707 r
F P
0 g
s
.71175 .65951 m .71569 .62311 L .74737 .62534 L p .707 .577 .707 r
F P
0 g
s
.31319 .50663 m .29368 .5563 L .29565 .56983 L p .707 .577 .707 r
F P
0 g
s
.3294 .73092 m .32488 .71251 L .31297 .7102 L p .707 .577 .707 r
F P
0 g
s
.74737 .62534 m .74343 .66174 L .71175 .65951 L p .707 .577 .707 r
F P
0 g
s
.49169 .63524 m .48775 .67165 L .49486 .66276 L p .707 .577 .707 r
F P
0 g
s
.49486 .66276 m .4988 .62635 L .49169 .63524 L p .707 .577 .707 r
F P
0 g
s
.70511 .72654 m .70059 .70813 L .72929 .69917 L p .707 .577 .707 r
F P
0 g
s
.31297 .7102 m .31749 .72861 L .3294 .73092 L p .707 .577 .707 r
F P
0 g
s
.29368 .5563 m .31319 .50663 L .3206 .49654 L p .707 .577 .707 r
F P
0 g
s
.72929 .69917 m .73381 .71758 L .70511 .72654 L p .707 .577 .707 r
F P
0 g
s
.79049 .68547 m .795 .70388 L .76478 .70977 L p .707 .577 .707 r
F P
0 g
s
.76478 .70977 m .76027 .69136 L .79049 .68547 L p .707 .577 .707 r
F P
0 g
s
.50131 .66804 m .50583 .68645 L .51306 .67932 L p .707 .577 .707 r
F P
0 g
s
.51306 .67932 m .50855 .66091 L .50131 .66804 L p .707 .577 .707 r
F P
0 g
s
.29488 .64866 m .29882 .61226 L .29601 .60218 L p .707 .577 .707 r
F P
0 g
s
.73381 .71758 m .72929 .69917 L .76027 .69136 L p .707 .577 .707 r
F P
0 g
s
.76027 .69136 m .76478 .70977 L .73381 .71758 L p .707 .577 .707 r
F P
0 g
s
.5047 .57713 m .48518 .6268 L .48321 .61326 L p .707 .577 .707 r
F P
0 g
s
.48321 .61326 m .50273 .56359 L .5047 .57713 L p .707 .577 .707 r
F P
0 g
s
.29601 .60218 m .29207 .63859 L .29488 .64866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.3206 .49654 m .30108 .54621 L .29368 .5563 L p .707 .577 .707 r
F P
0 g
s
.31749 .72861 m .31297 .7102 L .31051 .70524 L p .707 .577 .707 r
F P
0 g
s
.4988 .62635 m .49486 .66276 L .49205 .65268 L p .707 .577 .707 r
F P
0 g
s
.49205 .65268 m .49599 .61627 L .4988 .62635 L p .707 .577 .707 r
F P
0 g
s
.31051 .70524 m .31503 .72365 L .31749 .72861 L p .707 .577 .707 r
F P
0 g
s
.30108 .54621 m .3206 .49654 L .33665 .49089 L p .707 .577 .707 r
F P
0 g
s
.50855 .66091 m .51306 .67932 L .5106 .67436 L p .707 .577 .707 r
F P
0 g
s
.5106 .67436 m .50609 .65595 L .50855 .66091 L p .707 .577 .707 r
F P
0 g
s
.29207 .63859 m .29601 .60218 L .30312 .59329 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50273 .56359 m .48321 .61326 L .47206 .5976 L p .707 .577 .707 r
F P
0 g
s
.47206 .5976 m .49158 .54793 L .50273 .56359 L p .707 .577 .707 r
F P
0 g
s
.30312 .59329 m .29918 .62969 L .29207 .63859 L p .707 .577 .707 r
F P
0 g
s
.33665 .49089 m .31713 .54056 L .30108 .54621 L p .707 .577 .707 r
F P
0 g
s
.31503 .72365 m .31051 .70524 L .31775 .69811 L p .707 .577 .707 r
F P
0 g
s
.31713 .54056 m .33665 .49089 L .35977 .49024 L p .707 .577 .707 r
F P
0 g
s
.49599 .61627 m .49205 .65268 L .47958 .64241 L p .707 .577 .707 r
F P
0 g
s
.47958 .64241 m .48352 .606 L .49599 .61627 L p .707 .577 .707 r
F P
0 g
s
.31775 .69811 m .32226 .71652 L .31503 .72365 L p .707 .577 .707 r
F P
0 g
s
.29918 .62969 m .30312 .59329 L .31946 .58645 L p .707 .577 .707 r
F P
0 g
s
.50609 .65595 m .5106 .67436 L .49869 .67205 L p .707 .577 .707 r
F P
0 g
s
.49869 .67205 m .49418 .65364 L .50609 .65595 L p .707 .577 .707 r
F P
0 g
s
.49158 .54793 m .47206 .5976 L .45282 .58135 L p .707 .577 .707 r
F P
0 g
s
.45282 .58135 m .47234 .53168 L .49158 .54793 L p .707 .577 .707 r
F P
0 g
s
.31946 .58645 m .31552 .62286 L .29918 .62969 L p .707 .577 .707 r
F P
0 g
s
.35977 .49024 m .34026 .53991 L .31713 .54056 L p .707 .577 .707 r
F P
0 g
s
.34026 .53991 m .35977 .49024 L .38771 .49464 L p .707 .577 .707 r
F P
0 g
s
.48352 .606 m .47958 .64241 L .45869 .63294 L p .707 .577 .707 r
F P
0 g
s
.45869 .63294 m .46263 .59654 L .48352 .606 L p .707 .577 .707 r
F P
0 g
s
.47234 .53168 m .45282 .58135 L .42738 .56609 L p .707 .577 .707 r
F P
0 g
s
.42738 .56609 m .44689 .51642 L .47234 .53168 L p .707 .577 .707 r
F P
0 g
s
.32226 .71652 m .31775 .69811 L .33396 .68951 L p .707 .577 .707 r
F P
0 g
s
.33396 .68951 m .33848 .70792 L .32226 .71652 L p .707 .577 .707 r
F P
0 g
s
.31552 .62286 m .31946 .58645 L .34343 .58233 L p .707 .577 .707 r
F P
0 g
s
.3682 .54431 m .38771 .49464 L .41773 .50366 L p .707 .577 .707 r
F P
0 g
s
.38771 .49464 m .3682 .54431 L .34026 .53991 L p .707 .577 .707 r
F P
0 g
s
.49418 .65364 m .49869 .67205 L .4785 .67263 L p .707 .577 .707 r
F P
0 g
s
.4785 .67263 m .47398 .65422 L .49418 .65364 L p .707 .577 .707 r
F P
0 g
s
.44689 .51642 m .42738 .56609 L .39822 .55333 L p .707 .577 .707 r
F P
0 g
s
.39822 .55333 m .41773 .50366 L .44689 .51642 L p .707 .577 .707 r
F P
0 g
s
.41773 .50366 m .39822 .55333 L .3682 .54431 L p .707 .577 .707 r
F P
0 g
s
.34343 .58233 m .33949 .61874 L .31552 .62286 L p .707 .577 .707 r
F P
0 g
s
.46263 .59654 m .45869 .63294 L .43141 .62522 L p .707 .577 .707 r
F P
0 g
s
.43141 .62522 m .43535 .58881 L .46263 .59654 L p .707 .577 .707 r
F P
0 g
s
.33949 .61874 m .34343 .58233 L .37268 .58134 L p .707 .577 .707 r
F P
0 g
s
.33848 .70792 m .33396 .68951 L .35758 .68028 L p .707 .577 .707 r
F P
0 g
s
.35758 .68028 m .36209 .69869 L .33848 .70792 L p .707 .577 .707 r
F P
0 g
s
.47398 .65422 m .4785 .67263 L .45199 .67603 L p .707 .577 .707 r
F P
0 g
s
.45199 .67603 m .44748 .65762 L .47398 .65422 L p .707 .577 .707 r
F P
0 g
s
.43535 .58881 m .43141 .62522 L .40042 .61998 L p .707 .577 .707 r
F P
0 g
s
.40042 .61998 m .40436 .58357 L .43535 .58881 L p .707 .577 .707 r
F P
0 g
s
.37268 .58134 m .36874 .61775 L .33949 .61874 L p .707 .577 .707 r
F P
0 g
s
.36874 .61775 m .37268 .58134 L .40436 .58357 L p .707 .577 .707 r
F P
0 g
s
.40436 .58357 m .40042 .61998 L .36874 .61775 L p .707 .577 .707 r
F P
0 g
s
.36209 .69869 m .35758 .68028 L .38628 .67132 L p .707 .577 .707 r
F P
0 g
s
.38628 .67132 m .3908 .68973 L .36209 .69869 L p .707 .577 .707 r
F P
0 g
s
.44748 .65762 m .45199 .67603 L .42177 .68192 L p .707 .577 .707 r
F P
0 g
s
.42177 .68192 m .41726 .66351 L .44748 .65762 L p .707 .577 .707 r
F P
0 g
s
.3908 .68973 m .38628 .67132 L .41726 .66351 L p .707 .577 .707 r
F P
0 g
s
.41726 .66351 m .42177 .68192 L .3908 .68973 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007Uooah008Io
o`00MGoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001aOol40006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001kOol006moo`800003FUH005YF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Moo`00KGoo
0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000Lgoo001[Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001`Ool006Yoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP00008006eoo`00JGoo
00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00UYF0`00JWoo001XOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0P00J7oo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P00Igoo001XOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000006Eoo`00J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP05001J
EUYFFUH0001TOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001oogoo065oo`00
J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<007ooOol0HGoo001XOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0<FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001R
Ool006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1ROol006Moo`=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo069oo`00Igoo0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol2FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1R
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP04FUH00`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001OOol;0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05eoo`<000IJEP04001JEUYFFUH60006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`800003
FUH005YF00EJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00FWoo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<000YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Moo`00FGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF0000
0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001IOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00Igoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Yoo`/0059oo`00
EWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0027oo0P0000=JEP00FUH015YF00@005YFFUIJEPH004aoo`00EWoo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Woo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00BGoo001FOol01@00FUIJ
EUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00AWoo001EOol20002
FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF0`00@goo001EOol01000FUH00000
0UYF00@005YFFUH000=oo`03001JEP0000D000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH00000
@Goo001DOol30004FUH01000FUIJEUYF0P0000Eoo`00FUIJEP0000AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEP<003ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF0P000UYF00<005YF
FUH00eYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0P00?7oo001COol200000eYF001JEP02
FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00UYF0P002EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP<0
03Yoo`00Dgoo00<005YFFUH015YF00<005YFFUH01EYF10001EYF00<005YFFUH015YF0P001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH0000iOol005=oo`03001JEP0000=JEP03001JEUYF00EJEP04001J
EUYFFUH20004FUH01000FUIJEUYF0`000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03
001oogoo03Ioo`00Dgoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<0
05YFFUH01@0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo00<005YF0000
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF0P00=Woo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30002FUH50000
0eYF001JEP02FUH20008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00Oomoo`0cOol005Aoo`05
001JEUYFFUH00007FUH00`00FUIJEP06FUH01@00FUH00000FUH01@0000=JEP00FUH015YF0P001EYF
00<005YFFUH015YF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00MJEP<003=oo`00EGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
009JEPD0009JEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool005YF0002FUH;0004
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000<Woo001EOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH025YF0`001eYF00<0
05YFFUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00L0
05YF001ooeYF001JEP020002FUH00`00FUIJEP020004Ool60007FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000`Ool003Qoo`/001=oo`03001JEUYF00EJEQP000YJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P0015YF00<005YFFUH00UYF00<007ooOol01goo0P001EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0;Goo000fOol30006FUH01000FUIJ
EUYF1P003Woo00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF0`0015YF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00AJEP03001oogoo00Qoo`<00003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP8002ioo`00=7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00@005YF000000eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000=JEP04001JEUYF0003FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0004FUH00`00FUIJEP04FUH3000;Ool3
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000^Ool003=oo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP<000Qoo`80009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000T000AJEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP05
001JEUYFFUH0000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00;Goo000c
Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0017oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol01goo0`000Woo0`00
00=JEP00FUH025YF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00<Woo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<00007FUH005YFFUH0
05YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH015YF
00<005YFFUH015YF00<005YFFUH00eYF0P001Woo1@0017oo0P002EYF00<005YFFUH015YF00<005YF
FUH00UYF00<007ooOol0:Woo000bOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF0P0017oo1@001Woo0P001UYF00<005YFFUH015YF00<005YFFUH00eYF00<007oo
Ool0:Woo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
00000P0000=oo`0000000`0027oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000aOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00=JEPD000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000]oo`<000IJEP03001JEUYF009JEP03001JEP0002aoo`00<7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF
00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000;Ool00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000/Ool002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEP0000<0009oo`03001JEUYF00<000IJEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30009Ool00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000]Ool002moo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=J
EP8000AJEP03001oo`00009JEP03001JEUYF008000AJEP03001JEUYF00IJEPH000IJEP03001JEUYF
00=JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005Ool00`00FUIJEP03FUHH0003FUH50005Ool20002FUH00`00FUIJEP02FUH00`00FUH0000]
Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH005YF0P0000AJEP000000009JEP<0009JEP03001JEUYF009JEP800004FUH005YFFUH30003
FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01@000eYF2@001EYF00<005YF0000;Goo000^Ool20002FUH;0004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEP<00004FUH005YF0005FUH00`00FUH0
00070002FUH00`00FUIJEP05FUH400000eYF001JEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00D005YFFUIJEP0000AJEP03001JEP00
02ioo`00;Woo00@005YF0000009JEP04001JEUYF0005Ool60008FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP02FUH500000eYF001JEP07FUH01000FUIJ
EUYF0`0015YF00H005YFFUH005YF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`001EYF00L005YFFUIJEP00FUH0000^Ool002eoo`<000AJEP04001J
EUYFFUH20009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH400000eYF001JEP03FUH:0004FUH00`00FUIJEP04FUH400001eYF001JEUYF001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP06001J
EUYF001JEP00;goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00Oomoo`09Ool300000eYF
001JEP07FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF00000`000eYF0`0000=JEP00
FUH00eYF4@000UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000MJEP00001JEP00FUH0000_Ool002aoo`800003FUH005YF009JEP03001J
EUYF00EJEP03001oogoo00]oo`8000QJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH80008FUH80003FUH01000FUH005YF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<007ooOol0;Goo000/Ool0
0`00FUIJEP04FUH00`00FUIJEP05FUH3000=Ool20006FUH01@00FUIJEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP00Ool0;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0027oo0`000Woo0P0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool50003Ool2000015YF001J
EUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00000_Ool002eoo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001oogoo009oo`D000Eoo`8000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00FUIJEP03FUH0
0`00FUIJEP020007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20004
FUH00`00FUIJEP02FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001eYF00<005YFFUH01UYF0`000Woo1@001goo0P00
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF1`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF0004FUH00`00FUH000050007Ool200000eYF001JEP090004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000^Ool01000FUIJEP001UYF00<005YF
FUH01UYF00@005YFFUIJEP800004Ool00000000:Ool20003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP001eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF001JEP00FUH0
0002FUH40002FUH01@00FUIJEUYF000027oo100000AJEP00000000=JEPL000EJEP03001JEUYF00=J
EP03001JEUYF009JEP8002eoo`00;Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP8000ioo`<0009JEP<000IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01P00FUH005YF001JEP@0009JEP800003FUH005YF00=JEP8000Yoo`D00003FUH005YF00IJ
EP@00003FUH005YF00AJEP03001JEUYF009JEP8002eoo`00;goo00<005YFFUH01EYF40000UYF1000
37oo00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF3@001EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP8000=JEP03001JEUYF009JEP<000EJEP03001oogoo00Moo`X000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP02FUH2000]Ool0031oo`03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
009JEPX000Uoo`03001JEUYF00=JEP03001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF009J
EPh000AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF00<005YFFUH00eYF00<005YF00000`0000=JEP00000027oo1@001Goo30000eYF
00L005YFFUIJEP00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Aoo`8000=JEP04001JEP00FUH30007FUH00`00FUIJEP05FUH60003FUH00`00FUH0
00030002FUH30005FUH00`00FUH00005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH50007Ool3000AOol;000]Ool002mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000L0009JEP06001JEP00001JEP0025YF00<005YFFUH00eYF3@0015YF0P000eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH010004Goo1P000eYF00<005YFFUH00UYF00<005YF
00000P00:goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000020003FUH00`00FUIJEP07FUH00`00FUH00002
000:FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP@000IJEP03001JEUYF00AJEP@00003FUH005YF00YJEP03001JEUYF00YJEP04001JEP000008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool200000eYF
00000005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP05FUH50009FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004Ool40004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>000YOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000EJEP04001JEP000004FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
1Woo1@0000=JEP00FUH01UYF00<005YFFUH00`000eYF00<005YFFUH01eYF00<005YFFUH00UYF2000
00=JEP00FUH00eYF00H005YF001JEP00FUH2000YOol002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH40003FUH60006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20008Ool2000015YF000000001UYF0`001UYF00<005YFFUH01UYF1P000UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00@005YFFUH002Uoo`00;7oo00<005YF00000eYF
00@005YFFUIJEPX000IJEPT000AJEP03001JEUYF009JEP05001JEUYF001JEP090003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool01000FUIJEUYF1P0000=JEP00FUH01eYF00<005YF
FUH00UYF10001eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP8002Yoo`00;7oo00<005YF0000
0eYF10002Woo0P0015YF00<005YFFUH01UYF1P0015YF00@005YF000000EJEP03001JEUYF00AJEP03
001JEUYF015JEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H000Eoo`03001JEUYF008000EJEP03001JEUYF00IJEP03001JEP00
008000=JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEP00001JEP000eYF0P00:goo000/Ool0
1000FUH005YF0P0000AJEP00000000aoo`800003FUH005YF00MJEP03001JEUYF00AJEP80009JEP80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH9
0007FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00@005YF0000
02eoo`00;7oo00H005YF000005YF0004FUH3000;Ool3000015YF000000000eYF00<005YFFUH01UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P00
15YF0P000UYF00<005YFFUH01EYF00<005YFFUH02P000eYF00<005YFFUH00UYF20001UYF0`00;goo
000/Ool20003FUH00`00FUIJEP03FUH01000FUH0000037oo1@0000=JEP00FUH01eYF00<005YFFUH0
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPP0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEP00
00<000AJEP03001JEUYF00AJEP@000Eoo`d000QJEP04001JEUYFFUH2000bOol002aoo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEUYFFUH30009Ool80007FUH01000FUIJEUYF3P002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P001EYF00@005YFFUIJEP8000EJEP04001JEUYFFUH2000:Ool50006FUH00`00FUIJEP06
FUH01000FUH00000=7oo000/Ool01@00FUIJEUYF00001UYF00<005YFFUH015YF1P000goo1@000goo
10000UYF00@005YFFUIJEPH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH01P00FUH00000FUH000Moo`@00003FUH005YF00QJ
EP03001JEUYF00AJEP<003Ioo`00;7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
009JEPT000Ioo`X000AJEP03001JEUYF00=JEP03001JEUYF00EJEQh000UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000EJEP04001JEUYF0002FUH00`00FUIJEP02FUH30002FUH0
0`00Ool000050005FUH00`00FUIJEP07FUH00`00FUIJEP04000iOol002aoo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH60003FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
2@000eYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000]Ool01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEPD000UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@0049oo`00;Woo0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00@005YFFUIJEP@000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF009JEP@000EJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40016Ool0031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH0
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF100000=JEP00
FUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF00@004Yoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF1P0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00D005YFFUIJEP0000=JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00<000IJEP03001J
EUYF00=JEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP02FUH6001>Ool0
03=oo`800003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP03FUH00`00FUH00005FUH01000FUIJEP000eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF0000
1P0015YF3P00E7oo000eOol30006FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<005YF0000
1UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00E7oo000hOol40002FUH00`00FUIJEP04
FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF3P000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF0`0015YF00<005YF00000P0015YF00H0
05YF000005YF0005FUH00`00FUIJEP02FUH2001DOol003aoo`T00003FUH005YF00QJEP03001JEUYF
00AJEPH00003FUH0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH00002Ool;0004
FUH01`00FUIJEUYF001JEP0005Aoo`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH0100000=J
EP00FUH00UYF100015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP800003FUH0000000ioo`<00003FUH0
05YF00D005Aoo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01EYF3@000Woo0P0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0`003Woo1P000UYF00<005YF00000P00DWoo000iOol20003FUH00`00
FUIJEP07FUH00`00FUIJEP04000<Ool300000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30006Ool80003FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000gOol20006FUH00`00FUIJEP04
FUH5000<Ool400001EYF001JEUYF000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF2@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00DGoo000eOol30007FUH00`00FUIJEP04000<
Ool50005FUH01000FUIJEUYF0P000UYF00<005YFFUH04EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YFFUIJEP00055oo`00<goo0P000eYF00<005YFFUH015YF0`0037oo
10000UYF00<005YFFUH01UYF00@005YFFUIJEP@001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00DGoo000bOol20004FUH00`00FUIJEP02FUH2000:Ool50006
FUH00`00FUIJEP06FUH01000FUH000000goo00<005YFFUH045YF00<005YFFUH02eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF3P00D7oo000aOol00`00FUH00005FUH01000FUH0000027oo10000UYF00<0
05YFFUH01eYF00<005YFFUH015YF0`001Woo0P0045YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF200000=JEP00
FUH00eYF00H005YF001JEP00FUH2001@Ool0035oo`04001JEUYF0003FUH30004Ool60006FUH00`00
FUIJEP07FUH00`00FUIJEP04000;Ool2000>FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH60002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEP00D7oo000aOol01@00FUIJEP00FUH02@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF10004Goo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF1P001eYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00DGoo000aOol200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000GOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0`000eYF0P00DWoo000bOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH00002000NOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH01000FUH00000
E7oo000bOol01000FUIJEP001UYF00<005YFFUH015YF00<005YFFUH00UYF1P009goo1P002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF2P000eYF00<005YFFUH01EYF00<005YF0000
0`001EYF0`00EWoo000bOol20002FUH00`00FUIJEP03FUH01000FUIJEUYF2000<goo1P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@001Goo4P000eYF00@005YFFUIJEP8005Uoo`00
<goo0P0000=JEP00FUH00UYF1P00@Goo2P001UYF00<005YFFUH00eYF2@002Goo1P001UYF00<005YF
FUH01UYF00@005YF000005]oo`00=Goo1@00DGoo30000eYF00@005YF000000Uoo`H000UJEP03001J
EUYF00AJEP<005eoo`00TWoo00@005YFFUH000AJEP8000Eoo`H000EJEP03001JEUYF00MJEP03001J
EUYF00@0061oo`00Tgoo00D005YFFUH005YF00T000=JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
06Aoo`00Tgoo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`00J7oo002COol01@00FUH005YF000015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00Jgoo002DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH00UYF1@00KWoo002DOol0
1@00FUIJEUYF000015YF00<005YFFUH00UYF2000Lgoo002DOol>001kOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58645 .75664 m .60596 .70697 L .5768 .6942 L p .707 .577 .707 r
F P
0 g
s
.60596 .70697 m .58645 .75664 L .61647 .76566 L p .707 .577 .707 r
F P
0 g
s
.61647 .76566 m .63598 .71599 L .60596 .70697 L p .707 .577 .707 r
F P
0 g
s
.55729 .74387 m .5768 .6942 L .55136 .67895 L p .707 .577 .707 r
F P
0 g
s
.5768 .6942 m .55729 .74387 L .58645 .75664 L p .707 .577 .707 r
F P
0 g
s
.63598 .71599 m .61647 .76566 L .64441 .77006 L p .707 .577 .707 r
F P
0 g
s
.64441 .77006 m .66392 .72039 L .63598 .71599 L p .707 .577 .707 r
F P
0 g
s
.53185 .72862 m .55136 .67895 L .53212 .66269 L p .707 .577 .707 r
F P
0 g
s
.55136 .67895 m .53185 .72862 L .55729 .74387 L p .707 .577 .707 r
F P
0 g
s
.66392 .72039 m .64441 .77006 L .66754 .7694 L p .707 .577 .707 r
F P
0 g
s
.66754 .7694 m .68705 .71973 L .66392 .72039 L p .707 .577 .707 r
F P
0 g
s
.59232 .81517 m .59626 .77876 L .56526 .77352 L p .707 .577 .707 r
F P
0 g
s
.59626 .77876 m .59232 .81517 L .62399 .8174 L p .707 .577 .707 r
F P
0 g
s
.62399 .8174 m .62793 .78099 L .59626 .77876 L p .707 .577 .707 r
F P
0 g
s
.6431 .83313 m .63859 .81472 L .60761 .82253 L p .707 .577 .707 r
F P
0 g
s
.63859 .81472 m .6431 .83313 L .6718 .82417 L p .707 .577 .707 r
F P
0 g
s
.6718 .82417 m .66729 .80576 L .63859 .81472 L p .707 .577 .707 r
F P
0 g
s
.62793 .78099 m .62399 .8174 L .65325 .81641 L p .707 .577 .707 r
F P
0 g
s
.65325 .81641 m .65719 .78 L .62793 .78099 L p .707 .577 .707 r
F P
0 g
s
.56132 .80993 m .56526 .77352 L .53798 .7658 L p .707 .577 .707 r
F P
0 g
s
.56526 .77352 m .56132 .80993 L .59232 .81517 L p .707 .577 .707 r
F P
0 g
s
.61212 .84094 m .60761 .82253 L .57739 .82842 L p .707 .577 .707 r
F P
0 g
s
.60761 .82253 m .61212 .84094 L .6431 .83313 L p .707 .577 .707 r
F P
0 g
s
.51261 .71236 m .53212 .66269 L .52097 .64703 L p .707 .577 .707 r
F P
0 g
s
.53212 .66269 m .51261 .71236 L .53185 .72862 L p .707 .577 .707 r
F P
0 g
s
.57739 .82842 m .5819 .84683 L .61212 .84094 L p .707 .577 .707 r
F P
0 g
s
.5819 .84683 m .57739 .82842 L .55088 .83182 L p .707 .577 .707 r
F P
0 g
s
.66729 .80576 m .6718 .82417 L .69542 .81494 L p .707 .577 .707 r
F P
0 g
s
.69542 .81494 m .6909 .79653 L .66729 .80576 L p .707 .577 .707 r
F P
0 g
s
.65719 .78 m .65325 .81641 L .67722 .81229 L p .707 .577 .707 r
F P
0 g
s
.67722 .81229 m .68116 .77588 L .65719 .78 L p .707 .577 .707 r
F P
0 g
s
.53798 .7658 m .53405 .8022 L .56132 .80993 L p .707 .577 .707 r
F P
0 g
s
.68705 .71973 m .66754 .7694 L .68359 .76375 L p .707 .577 .707 r
F P
0 g
s
.68359 .76375 m .7031 .71408 L .68705 .71973 L p .707 .577 .707 r
F P
0 g
s
.55088 .83182 m .5554 .85023 L .5819 .84683 L p .707 .577 .707 r
F P
0 g
s
.53405 .8022 m .53798 .7658 L .51709 .75633 L p .707 .577 .707 r
F P
0 g
s
.51709 .75633 m .51315 .79274 L .53405 .8022 L p .707 .577 .707 r
F P
0 g
s
.52097 .64703 m .50146 .6967 L .51261 .71236 L p .707 .577 .707 r
F P
0 g
s
.5554 .85023 m .55088 .83182 L .53069 .83239 L p .707 .577 .707 r
F P
0 g
s
.50146 .6967 m .52097 .64703 L .519 .6335 L p .707 .577 .707 r
F P
0 g
s
.53069 .83239 m .5352 .8508 L .5554 .85023 L p .707 .577 .707 r
F P
0 g
s
.6909 .79653 m .69542 .81494 L .71163 .80634 L p .707 .577 .707 r
F P
0 g
s
.68116 .77588 m .67722 .81229 L .69356 .80545 L p .707 .577 .707 r
F P
0 g
s
.71163 .80634 m .70712 .78793 L .6909 .79653 L p .707 .577 .707 r
F P
0 g
s
.69356 .80545 m .6975 .76905 L .68116 .77588 L p .707 .577 .707 r
F P
0 g
s
.51315 .79274 m .51709 .75633 L .50463 .74606 L p .707 .577 .707 r
F P
0 g
s
.7031 .71408 m .68359 .76375 L .69099 .75367 L p .707 .577 .707 r
F P
0 g
s
.69099 .75367 m .7105 .704 L .7031 .71408 L p .707 .577 .707 r
F P
0 g
s
.50463 .74606 m .50069 .78247 L .51315 .79274 L p .707 .577 .707 r
F P
0 g
s
.519 .6335 m .49949 .68317 L .50146 .6967 L p .707 .577 .707 r
F P
0 g
s
.5352 .8508 m .53069 .83239 L .51878 .83009 L p .707 .577 .707 r
F P
0 g
s
.51878 .83009 m .52329 .8485 L .5352 .8508 L p .707 .577 .707 r
F P
0 g
s
.6975 .76905 m .69356 .80545 L .70067 .79656 L p .707 .577 .707 r
F P
0 g
s
.70067 .79656 m .70461 .76015 L .6975 .76905 L p .707 .577 .707 r
F P
0 g
s
.49949 .68317 m .519 .6335 L .5264 .62341 L p .707 .577 .707 r
F P
0 g
s
.70712 .78793 m .71163 .80634 L .71887 .79921 L p .707 .577 .707 r
F P
0 g
s
.71887 .79921 m .71435 .7808 L .70712 .78793 L p .707 .577 .707 r
F P
0 g
s
.50069 .78247 m .50463 .74606 L .50181 .73598 L p .707 .577 .707 r
F P
0 g
s
.46555 .82173 m .50283 .32534 L .45895 .31936 L p .707 .577 .707 r
F P
0 g
s
.50181 .73598 m .49787 .77239 L .50069 .78247 L p .707 .577 .707 r
F P
0 g
s
.5264 .62341 m .50689 .67308 L .49949 .68317 L p .707 .577 .707 r
F P
0 g
s
.50689 .67308 m .5264 .62341 L .54245 .61777 L p .707 .577 .707 r
F P
0 g
s
.49787 .77239 m .50181 .73598 L .50892 .72709 L p .707 .577 .707 r
F P
0 g
s
.50892 .72709 m .50498 .7635 L .49787 .77239 L p .707 .577 .707 r
F P
0 g
s
.54245 .61777 m .52294 .66744 L .50689 .67308 L p .707 .577 .707 r
F P
0 g
s
.50498 .7635 m .50892 .72709 L .52526 .72025 L p .707 .577 .707 r
F P
0 g
s
.52526 .72025 m .52132 .75666 L .50498 .7635 L p .707 .577 .707 r
F P
0 g
s
.50283 .32534 m .46555 .82173 L .51038 .82361 L p .707 .577 .707 r
F P
0 g
s
.51038 .82361 m .54766 .32721 L .50283 .32534 L p .707 .577 .707 r
F P
0 g
s
.7105 .704 m .69099 .75367 L .68902 .74013 L p .707 .577 .707 r
F P
0 g
s
.68902 .74013 m .70853 .69046 L .7105 .704 L p .707 .577 .707 r
F P
0 g
s
.52329 .8485 m .51878 .83009 L .51632 .82513 L p .707 .577 .707 r
F P
0 g
s
.51632 .82513 m .52083 .84354 L .52329 .8485 L p .707 .577 .707 r
F P
0 g
s
.52083 .84354 m .51632 .82513 L .52355 .818 L p .707 .577 .707 r
F P
0 g
s
.52294 .66744 m .54245 .61777 L .56558 .61711 L p .707 .577 .707 r
F P
0 g
s
.52355 .818 m .52807 .83641 L .52083 .84354 L p .707 .577 .707 r
F P
0 g
s
.56558 .61711 m .54607 .66678 L .52294 .66744 L p .707 .577 .707 r
F P
0 g
s
.54607 .66678 m .56558 .61711 L .59352 .62151 L p .707 .577 .707 r
F P
0 g
s
.52807 .83641 m .52355 .818 L .53977 .8094 L p .707 .577 .707 r
F P
0 g
s
.53977 .8094 m .54429 .82781 L .52807 .83641 L p .707 .577 .707 r
F P
0 g
s
.52132 .75666 m .52526 .72025 L .54923 .71614 L p .707 .577 .707 r
F P
0 g
s
.59352 .62151 m .57401 .67118 L .54607 .66678 L p .707 .577 .707 r
F P
0 g
s
.54923 .71614 m .5453 .75254 L .52132 .75666 L p .707 .577 .707 r
F P
0 g
s
.54429 .82781 m .53977 .8094 L .56339 .80016 L p .707 .577 .707 r
F P
0 g
s
.5453 .75254 m .54923 .71614 L .57849 .71515 L p .707 .577 .707 r
F P
0 g
s
.56339 .80016 m .5679 .81857 L .54429 .82781 L p .707 .577 .707 r
F P
0 g
s
.57849 .71515 m .57455 .75155 L .5453 .75254 L p .707 .577 .707 r
F P
0 g
s
.54766 .32721 m .51038 .82361 L .55177 .8212 L p .707 .577 .707 r
F P
0 g
s
.55177 .8212 m .58906 .3248 L .54766 .32721 L p .707 .577 .707 r
F P
0 g
s
.42166 .81575 m .45895 .31936 L .42031 .30986 L p .707 .577 .707 r
F P
0 g
s
.45895 .31936 m .42166 .81575 L .46555 .82173 L p .707 .577 .707 r
F P
0 g
s
.70461 .76015 m .70067 .79656 L .69785 .78648 L p .707 .577 .707 r
F P
0 g
s
.69785 .78648 m .70179 .75008 L .70461 .76015 L p .707 .577 .707 r
F P
0 g
s
.71435 .7808 m .71887 .79921 L .71641 .79425 L p .707 .577 .707 r
F P
0 g
s
.71641 .79425 m .7119 .77584 L .71435 .7808 L p .707 .577 .707 r
F P
0 g
s
.57401 .67118 m .59352 .62151 L .62354 .63053 L p .707 .577 .707 r
F P
0 g
s
.62354 .63053 m .60403 .6802 L .57401 .67118 L p .707 .577 .707 r
F P
0 g
s
.57455 .75155 m .57849 .71515 L .61016 .71738 L p .707 .577 .707 r
F P
0 g
s
.61016 .71738 m .60622 .75378 L .57455 .75155 L p .707 .577 .707 r
F P
0 g
s
.5679 .81857 m .56339 .80016 L .59209 .79121 L p .707 .577 .707 r
F P
0 g
s
.59209 .79121 m .5966 .80962 L .5679 .81857 L p .707 .577 .707 r
F P
0 g
s
.58906 .3248 m .55177 .8212 L .58567 .81474 L p .707 .577 .707 r
F P
0 g
s
.58567 .81474 m .62296 .31834 L .58906 .3248 L p .707 .577 .707 r
F P
0 g
s
.38302 .80625 m .42031 .30986 L .39069 .29777 L p .707 .577 .707 r
F P
0 g
s
.42031 .30986 m .38302 .80625 L .42166 .81575 L p .707 .577 .707 r
F P
0 g
s
.70853 .69046 m .68902 .74013 L .67787 .72447 L p .707 .577 .707 r
F P
0 g
s
.67787 .72447 m .69738 .6748 L .70853 .69046 L p .707 .577 .707 r
F P
0 g
s
.24344 .7218 m .26295 .67213 L .2338 .65937 L p .707 .577 .707 r
F P
0 g
s
.26295 .67213 m .24344 .7218 L .27346 .73082 L p .707 .577 .707 r
F P
0 g
s
.27346 .73082 m .29297 .68116 L .26295 .67213 L p .707 .577 .707 r
F P
0 g
s
.21428 .70904 m .2338 .65937 L .20835 .64412 L p .707 .577 .707 r
F P
0 g
s
.2338 .65937 m .21428 .70904 L .24344 .7218 L p .707 .577 .707 r
F P
0 g
s
.29297 .68116 m .27346 .73082 L .3014 .73522 L p .707 .577 .707 r
F P
0 g
s
.3014 .73522 m .32091 .68555 L .29297 .68116 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.18884 .69378 m .20835 .64412 L .18911 .62786 L p .707 .577 .707 r
F P
0 g
s
.20835 .64412 m .18884 .69378 L .21428 .70904 L p .707 .577 .707 r
F P
0 g
s
.70179 .75008 m .69785 .78648 L .68539 .77621 L p .707 .577 .707 r
F P
0 g
s
.68539 .77621 m .68933 .7398 L .70179 .75008 L p .707 .577 .707 r
F P
0 g
s
.6527 .64329 m .63318 .69296 L .60403 .6802 L p .707 .577 .707 r
F P
0 g
s
.60403 .6802 m .62354 .63053 L .6527 .64329 L p .707 .577 .707 r
F P
0 g
s
.64116 .72261 m .63722 .75902 L .60622 .75378 L p .707 .577 .707 r
F P
0 g
s
.60622 .75378 m .61016 .71738 L .64116 .72261 L p .707 .577 .707 r
F P
0 g
s
.5966 .80962 m .59209 .79121 L .62306 .7834 L p .707 .577 .707 r
F P
0 g
s
.62306 .7834 m .62758 .80181 L .5966 .80962 L p .707 .577 .707 r
F P
0 g
s
.62296 .31834 m .58567 .81474 L .60876 .80486 L p .707 .577 .707 r
F P
0 g
s
.60876 .80486 m .64605 .30846 L .62296 .31834 L p .707 .577 .707 r
F P
0 g
s
.7119 .77584 m .71641 .79425 L .7045 .79194 L p .707 .577 .707 r
F P
0 g
s
.7045 .79194 m .69998 .77353 L .7119 .77584 L p .707 .577 .707 r
F P
0 g
s
.32091 .68555 m .3014 .73522 L .32453 .73457 L p .707 .577 .707 r
F P
0 g
s
.32453 .73457 m .34404 .6849 L .32091 .68555 L p .707 .577 .707 r
F P
0 g
s
.69738 .6748 m .67787 .72447 L .65863 .70822 L p .707 .577 .707 r
F P
0 g
s
.65863 .70822 m .67814 .65855 L .69738 .6748 L p .707 .577 .707 r
F P
0 g
s
.24931 .7734 m .25325 .737 L .22225 .73176 L p .707 .577 .707 r
F P
0 g
s
.25325 .737 m .24931 .7734 L .28098 .77563 L p .707 .577 .707 r
F P
0 g
s
.28098 .77563 m .28492 .73923 L .25325 .737 L p .707 .577 .707 r
F P
0 g
s
.28492 .73923 m .28098 .77563 L .31024 .77464 L p .707 .577 .707 r
F P
0 g
s
.31024 .77464 m .31418 .73824 L .28492 .73923 L p .707 .577 .707 r
F P
0 g
s
.34058 .72892 m .36009 .67925 L .34404 .6849 L p .707 .577 .707 r
F P
0 g
s
.34789 .76868 m .35241 .78709 L .36863 .77849 L p .707 .577 .707 r
F P
0 g
s
.36863 .77849 m .36411 .76008 L .34789 .76868 L p .707 .577 .707 r
F P
0 g
s
.36009 .67925 m .34058 .72892 L .34798 .71883 L p .707 .577 .707 r
F P
0 g
s
.34798 .71883 m .36749 .66916 L .36009 .67925 L p .707 .577 .707 r
F P
0 g
s
.35449 .72728 m .35055 .76369 L .35766 .75479 L p .707 .577 .707 r
F P
0 g
s
.35766 .75479 m .3616 .71839 L .35449 .72728 L p .707 .577 .707 r
F P
0 g
s
.36749 .66916 m .34798 .71883 L .34601 .7053 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .36552 .65563 L .36749 .66916 L p .707 .577 .707 r
F P
0 g
s
.3616 .71839 m .35766 .75479 L .35485 .74472 L p .707 .577 .707 r
F P
0 g
s
.35485 .74472 m .35879 .70831 L .3616 .71839 L p .707 .577 .707 r
F P
0 g
s
.34404 .6849 m .32453 .73457 L .34058 .72892 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .33486 .68964 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.36552 .65563 m .34648 .70411 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.34648 .70411 m .34601 .7053 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.373 .28428 m .36897 .27071 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.35241 .78709 m .34789 .76868 L .32428 .77791 L p .707 .577 .707 r
F P
0 g
s
.33815 .73412 m .33421 .77053 L .35055 .76369 L p .707 .577 .707 r
F P
0 g
s
.35055 .76369 m .35449 .72728 L .33815 .73412 L p .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34053 .6752 L p .34691 .67021 L .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34691 .67021 L .34683 .67636 L .707 .577 .707 r
F
.34053 .6752 m .35437 .63997 L .36022 .64818 L p F P
0 g
s
.36022 .64818 m .36552 .65563 L p .34053 .6752 L .707 .577 .707 r
F P
0 g
s
.31418 .73824 m .31024 .77464 L .33421 .77053 L p .707 .577 .707 r
F P
0 g
s
.33421 .77053 m .33815 .73412 L .31418 .73824 L p .707 .577 .707 r
F P
0 g
s
.35437 .63997 m .33486 .68964 L .3274 .68333 L p .707 .577 .707 r
F P
0 g
s
.3274 .68333 m .31562 .67338 L p .32979 .66116 L .707 .577 .707 r
F P
0 g
s
.32979 .66116 m .35437 .63997 L .3274 .68333 L .707 .577 .707 r
F
.36897 .27071 m .34853 .54284 L p .34787 .59421 L F P
0 g
s
.31562 .67338 m .33513 .62371 L .35437 .63997 L p .707 .577 .707 r
F P
0 g
s
.34632 .69804 m .34238 .73445 L .32149 .72498 L p .707 .577 .707 r
F P
0 g
s
.32149 .72498 m .32543 .68858 L .34632 .69804 L p .707 .577 .707 r
F P
0 g
s
.33678 .74626 m .33918 .75605 L p .31479 .76807 L .707 .577 .707 r
F P
0 g
s
.34683 .67636 m .34691 .67021 L .36552 .65563 L .707 .577 .707 r
F
.32428 .77791 m .32879 .79632 L .35241 .78709 L p F P
0 g
s
.35879 .70831 m .35485 .74472 L .34238 .73445 L p .707 .577 .707 r
F P
0 g
s
.34238 .73445 m .34632 .69804 L .35879 .70831 L p .707 .577 .707 r
F P
0 g
s
.33633 .78115 m .3534 .79417 L p .35713 .69729 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .33821 .75209 L p .34222 .7461 L .707 .577 .707 r
F P
0 g
s
.33821 .75209 m .33678 .74626 L .33884 .7462 L p .707 .577 .707 r
F P
0 g
s
.33884 .7462 m .34222 .7461 L p .33821 .75209 L .707 .577 .707 r
F P
0 g
s
.33816 .76507 m .31479 .76807 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.31479 .76807 m .31027 .74966 L .33678 .74626 L p .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .33531 .7793 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33531 .7793 m .33571 .78068 L p .33659 .76728 L .707 .577 .707 r
F P
0 g
s
.33659 .76728 m .34787 .59421 L .33531 .7793 L .707 .577 .707 r
F
.35713 .69729 m .36289 .54728 L .33918 .75605 L F
.35713 .69729 m .33918 .75605 L .33633 .78115 L F
.3534 .79417 m .39069 .29777 L .373 .28428 L p F P
0 g
s
.34129 .76467 m .33918 .75605 L p .35698 .74568 L .707 .577 .707 r
F P
0 g
s
.34222 .7461 m .35698 .74568 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .34129 .76467 L .33816 .76507 L p .707 .577 .707 r
F P
0 g
s
.373 .28428 m .33571 .78068 L .33633 .78115 L p .707 .577 .707 r
F P
0 g
s
.36289 .54728 m .373 .28428 L .33633 .78115 L .707 .577 .707 r
F
.34853 .54284 m .33168 .7671 L p .34787 .59421 L F P
0 g
s
.3475 .62381 m .373 .28428 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .36212 .36191 L p .37899 .25838 L .707 .577 .707 r
F P
0 g
s
.36212 .36191 m .36897 .27071 L .37243 .26645 L p .707 .577 .707 r
F P
0 g
s
.37243 .26645 m .37899 .25838 L p .36212 .36191 L .707 .577 .707 r
F P
0 g
s
.36411 .76008 m .36863 .77849 L .37586 .77136 L p .707 .577 .707 r
F P
0 g
s
.37586 .77136 m .37134 .75295 L .36411 .76008 L p .707 .577 .707 r
F P
0 g
s
.37134 .75295 m .37586 .77136 L .37378 .76716 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .36467 .73141 L .3534 .79417 L .707 .577 .707 r
F
.37378 .76716 m .3734 .7664 L p .37313 .76461 L F P
0 g
s
.37313 .76461 m .37134 .75295 L .37378 .76716 L .707 .577 .707 r
F
.3534 .79417 m .38302 .80625 L p .38306 .80357 L F P
0 g
s
.3734 .7664 m .36889 .74799 L .37134 .75295 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .38594 .61289 L .36467 .73141 L .707 .577 .707 r
F
.39069 .29777 m .36485 .64183 L p .38594 .61289 L F P
0 g
s
.36485 .64183 m .3534 .79417 L p .38594 .61289 L .707 .577 .707 r
F P
0 g
s
.33571 .78068 m .3475 .62381 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.21832 .76816 m .22225 .73176 L .19498 .72403 L p .707 .577 .707 r
F P
0 g
s
.22225 .73176 m .21832 .76816 L .24931 .7734 L p .707 .577 .707 r
F P
0 g
s
.26912 .81309 m .2646 .79468 L .23438 .80057 L p .707 .577 .707 r
F P
0 g
s
.2646 .79468 m .26912 .81309 L .30009 .80528 L p .707 .577 .707 r
F P
0 g
s
.30009 .80528 m .29558 .78687 L .2646 .79468 L p .707 .577 .707 r
F P
0 g
s
.1696 .67753 m .18911 .62786 L .17796 .6122 L p .707 .577 .707 r
F P
0 g
s
.18911 .62786 m .1696 .67753 L .18884 .69378 L p .707 .577 .707 r
F P
0 g
s
.29558 .78687 m .30009 .80528 L .32879 .79632 L p .707 .577 .707 r
F P
0 g
s
.32879 .79632 m .32428 .77791 L .29558 .78687 L p .707 .577 .707 r
F P
0 g
s
.23438 .80057 m .2389 .81898 L .26912 .81309 L p .707 .577 .707 r
F P
0 g
s
.19498 .72403 m .19104 .76044 L .21832 .76816 L p .707 .577 .707 r
F P
0 g
s
.67814 .65855 m .65863 .70822 L .63318 .69296 L p .707 .577 .707 r
F P
0 g
s
.63318 .69296 m .6527 .64329 L .67814 .65855 L p .707 .577 .707 r
F P
0 g
s
.2389 .81898 m .23438 .80057 L .20788 .80397 L p .707 .577 .707 r
F P
0 g
s
.19104 .76044 m .19498 .72403 L .17408 .71457 L p .707 .577 .707 r
F P
0 g
s
.68933 .7398 m .68539 .77621 L .6645 .76675 L p .707 .577 .707 r
F P
0 g
s
.6645 .76675 m .66844 .73034 L .68933 .7398 L p .707 .577 .707 r
F P
0 g
s
.20788 .80397 m .21239 .82238 L .2389 .81898 L p .707 .577 .707 r
F P
0 g
s
.69998 .77353 m .7045 .79194 L .6843 .79252 L p .707 .577 .707 r
F P
0 g
s
.6843 .79252 m .67979 .77411 L .69998 .77353 L p .707 .577 .707 r
F P
0 g
s
.17408 .71457 m .17014 .75097 L .19104 .76044 L p .707 .577 .707 r
F P
0 g
s
.64605 .30846 m .60876 .80486 L .61878 .79253 L p .707 .577 .707 r
F P
0 g
s
.61878 .79253 m .65607 .29613 L .64605 .30846 L p .707 .577 .707 r
F P
0 g
s
.17796 .6122 m .15845 .66187 L .1696 .67753 L p .707 .577 .707 r
F P
0 g
s
.21239 .82238 m .20788 .80397 L .18768 .80454 L p .707 .577 .707 r
F P
0 g
s
.15845 .66187 m .17796 .6122 L .17599 .59867 L p .707 .577 .707 r
F P
0 g
s
.18768 .80454 m .19219 .82295 L .21239 .82238 L p .707 .577 .707 r
F P
0 g
s
.17014 .75097 m .17408 .71457 L .16162 .7043 L p .707 .577 .707 r
F P
0 g
s
.66844 .73034 m .6645 .76675 L .63722 .75902 L p .707 .577 .707 r
F P
0 g
s
.63722 .75902 m .64116 .72261 L .66844 .73034 L p .707 .577 .707 r
F P
0 g
s
.67979 .77411 m .6843 .79252 L .6578 .79592 L p .707 .577 .707 r
F P
0 g
s
.6578 .79592 m .65328 .77751 L .67979 .77411 L p .707 .577 .707 r
F P
0 g
s
.16162 .7043 m .15768 .7407 L .17014 .75097 L p .707 .577 .707 r
F P
0 g
s
.17599 .59867 m .15648 .64834 L .15845 .66187 L p .707 .577 .707 r
F P
0 g
s
.19219 .82295 m .18768 .80454 L .17577 .80224 L p .707 .577 .707 r
F P
0 g
s
.17577 .80224 m .18028 .82065 L .19219 .82295 L p .707 .577 .707 r
F P
0 g
s
.15648 .64834 m .17599 .59867 L .18339 .58858 L p .707 .577 .707 r
F P
0 g
s
.65328 .77751 m .6578 .79592 L .62758 .80181 L p .707 .577 .707 r
F P
0 g
s
.62758 .80181 m .62306 .7834 L .65328 .77751 L p .707 .577 .707 r
F P
0 g
s
.15768 .7407 m .16162 .7043 L .1588 .69422 L p .707 .577 .707 r
F P
0 g
s
.65607 .29613 m .61878 .79253 L .61475 .77895 L p .707 .577 .707 r
F P
0 g
s
.61475 .77895 m .65203 .28256 L .65607 .29613 L p .707 .577 .707 r
F P
0 g
s
.1588 .69422 m .15486 .73063 L .15768 .7407 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18339 .58858 m .16388 .63825 L .15648 .64834 L p .707 .577 .707 r
F P
0 g
s
.18028 .82065 m .17577 .80224 L .17331 .79728 L p .707 .577 .707 r
F P
0 g
s
.17331 .79728 m .17782 .81569 L .18028 .82065 L p .707 .577 .707 r
F P
0 g
s
.16388 .63825 m .18339 .58858 L .19944 .58293 L p .707 .577 .707 r
F P
0 g
s
.15486 .73063 m .1588 .69422 L .16591 .68533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16591 .68533 m .16197 .72173 L .15486 .73063 L p .707 .577 .707 r
F P
0 g
s
.65203 .28256 m .61475 .77895 L .59706 .76546 L p .707 .577 .707 r
F P
0 g
s
.59706 .76546 m .63434 .26907 L .65203 .28256 L p .707 .577 .707 r
F P
0 g
s
.19944 .58293 m .17993 .6326 L .16388 .63825 L p .707 .577 .707 r
F P
0 g
s
.17782 .81569 m .17331 .79728 L .18054 .79015 L p .707 .577 .707 r
F P
0 g
s
.17993 .6326 m .19944 .58293 L .22257 .58228 L p .707 .577 .707 r
F P
0 g
s
.18054 .79015 m .18506 .80856 L .17782 .81569 L p .707 .577 .707 r
F P
0 g
s
.3417 .75477 m .37899 .25838 L .40208 .2485 L p .707 .577 .707 r
F P
0 g
s
.37899 .25838 m .3417 .75477 L .33168 .7671 L p .707 .577 .707 r
F P
0 g
s
.16197 .72173 m .16591 .68533 L .18225 .67849 L p .707 .577 .707 r
F P
0 g
s
.36889 .74799 m .3734 .7664 L .36149 .76409 L p .707 .577 .707 r
F P
0 g
s
.36149 .76409 m .35698 .74568 L .36889 .74799 L p .707 .577 .707 r
F P
0 g
s
.18225 .67849 m .17832 .71489 L .16197 .72173 L p .707 .577 .707 r
F P
0 g
s
.22257 .58228 m .20306 .63195 L .17993 .6326 L p .707 .577 .707 r
F P
0 g
s
.20306 .63195 m .22257 .58228 L .25051 .58667 L p .707 .577 .707 r
F P
0 g
s
.33513 .62371 m .31562 .67338 L .29018 .65813 L p .707 .577 .707 r
F P
0 g
s
.29018 .65813 m .30969 .60846 L .33513 .62371 L p .707 .577 .707 r
F P
0 g
s
.18506 .80856 m .18054 .79015 L .19676 .78155 L p .707 .577 .707 r
F P
0 g
s
.19676 .78155 m .20128 .79996 L .18506 .80856 L p .707 .577 .707 r
F P
0 g
s
.63434 .26907 m .59706 .76546 L .56744 .75337 L p .707 .577 .707 r
F P
0 g
s
.56744 .75337 m .60473 .25698 L .63434 .26907 L p .707 .577 .707 r
F P
0 g
s
.17832 .71489 m .18225 .67849 L .20623 .67437 L p .707 .577 .707 r
F P
0 g
s
.231 .63634 m .25051 .58667 L .28053 .5957 L p .707 .577 .707 r
F P
0 g
s
.25051 .58667 m .231 .63634 L .20306 .63195 L p .707 .577 .707 r
F P
0 g
s
.35698 .74568 m .36149 .76409 L .34129 .76467 L p .707 .577 .707 r
F P
0 g
s
.30969 .60846 m .29018 .65813 L .26102 .64537 L p .707 .577 .707 r
F P
0 g
s
.26102 .64537 m .28053 .5957 L .30969 .60846 L p .707 .577 .707 r
F P
0 g
s
.28053 .5957 m .26102 .64537 L .231 .63634 L p .707 .577 .707 r
F P
0 g
s
.40208 .2485 m .36479 .74489 L .3417 .75477 L p .707 .577 .707 r
F P
0 g
s
.36479 .74489 m .40208 .2485 L .43598 .24204 L p .707 .577 .707 r
F P
0 g
s
.20623 .67437 m .20229 .71078 L .17832 .71489 L p .707 .577 .707 r
F P
0 g
s
.32543 .68858 m .32149 .72498 L .29421 .71726 L p .707 .577 .707 r
F P
0 g
s
.29421 .71726 m .29815 .68085 L .32543 .68858 L p .707 .577 .707 r
F P
0 g
s
.72365 .6646 m .74317 .61493 L .71401 .60216 L p .707 .577 .707 r
F P
0 g
s
.74317 .61493 m .72365 .6646 L .75367 .67362 L p .707 .577 .707 r
F P
0 g
s
.75367 .67362 m .77319 .62395 L .74317 .61493 L p .707 .577 .707 r
F P
0 g
s
.20229 .71078 m .20623 .67437 L .23548 .67338 L p .707 .577 .707 r
F P
0 g
s
.6945 .65183 m .71401 .60216 L .68857 .58691 L p .707 .577 .707 r
F P
0 g
s
.71401 .60216 m .6945 .65183 L .72365 .6646 L p .707 .577 .707 r
F P
0 g
s
.20128 .79996 m .19676 .78155 L .22038 .77231 L p .707 .577 .707 r
F P
0 g
s
.77319 .62395 m .75367 .67362 L .78161 .67802 L p .707 .577 .707 r
F P
0 g
s
.78161 .67802 m .80113 .62835 L .77319 .62395 L p .707 .577 .707 r
F P
0 g
s
.22038 .77231 m .22489 .79072 L .20128 .79996 L p .707 .577 .707 r
F P
0 g
s
.29815 .68085 m .29421 .71726 L .26321 .71202 L p .707 .577 .707 r
F P
0 g
s
.26321 .71202 m .26715 .67561 L .29815 .68085 L p .707 .577 .707 r
F P
0 g
s
.60473 .25698 m .56744 .75337 L .5288 .74388 L p .707 .577 .707 r
F P
0 g
s
.5288 .74388 m .56609 .24748 L .60473 .25698 L p .707 .577 .707 r
F P
0 g
s
.23548 .67338 m .23154 .70979 L .20229 .71078 L p .707 .577 .707 r
F P
0 g
s
.66905 .63658 m .68857 .58691 L .66933 .57066 L p .707 .577 .707 r
F P
0 g
s
.68857 .58691 m .66905 .63658 L .6945 .65183 L p .707 .577 .707 r
F P
0 g
s
.23154 .70979 m .23548 .67338 L .26715 .67561 L p .707 .577 .707 r
F P
0 g
s
.26715 .67561 m .26321 .71202 L .23154 .70979 L p .707 .577 .707 r
F P
0 g
s
.40632 .72105 m .4373 .71324 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .47737 .23963 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40001 .72083 m .43598 .24204 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .40632 .72105 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4373 .71324 m .43278 .69483 L .41015 .70054 L p .707 .577 .707 r
F P
0 g
s
.47737 .23963 m .47631 .25371 L p .40222 .71642 L .707 .577 .707 r
F P
0 g
s
.40214 .71657 m .47737 .23963 L .40222 .71642 L .707 .577 .707 r
F
.4373 .71324 m .41015 .70054 L .40815 .70453 L F
.40632 .72105 m .40421 .71243 L p .40304 .71987 L F P
0 g
s
.43278 .69483 m .4373 .71324 L .466 .70428 L p .707 .577 .707 r
F P
0 g
s
.466 .70428 m .46148 .68587 L .43278 .69483 L p .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .40214 .71657 L .40222 .71642 L .707 .577 .707 r
F
.40013 .73835 m .39869 .73843 L p .47631 .25371 L F P
0 g
s
.39869 .73843 m .40001 .72083 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .36479 .74489 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .41456 .52721 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.41456 .52721 m .39869 .73843 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.37158 .70853 m .3761 .72694 L .40274 .72175 L p .707 .577 .707 r
F P
0 g
s
.40274 .72175 m .40632 .72105 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40304 .71987 m .37158 .70853 L .40274 .72175 L .707 .577 .707 r
F
.44008 .73602 m .40013 .73835 L p .42723 .56598 L F P
0 g
s
.47631 .25371 m .44807 .62977 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.44807 .62977 m .44008 .73602 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.41066 .63879 m .42286 .60774 L p .40016 .58009 L .707 .577 .707 r
F P
0 g
s
.42286 .60774 m .43018 .58912 L .42065 .58625 L p .707 .577 .707 r
F P
0 g
s
.42065 .58625 m .40016 .58009 L p .42286 .60774 L .707 .577 .707 r
F P
0 g
s
.41015 .70054 m .4018 .70264 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .37158 .70853 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .4018 .70264 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .40421 .71243 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.80113 .62835 m .78161 .67802 L .80474 .67736 L p .707 .577 .707 r
F P
0 g
s
.80474 .67736 m .82425 .62769 L .80113 .62835 L p .707 .577 .707 r
F P
0 g
s
.22489 .79072 m .22038 .77231 L .24908 .76336 L p .707 .577 .707 r
F P
0 g
s
.72952 .72313 m .73346 .68672 L .70247 .68149 L p .707 .577 .707 r
F P
0 g
s
.73346 .68672 m .72952 .72313 L .7612 .72536 L p .707 .577 .707 r
F P
0 g
s
.7612 .72536 m .76514 .68895 L .73346 .68672 L p .707 .577 .707 r
F P
0 g
s
.24908 .76336 m .25359 .78177 L .22489 .79072 L p .707 .577 .707 r
F P
0 g
s
.31027 .74966 m .31479 .76807 L .28457 .77396 L p .707 .577 .707 r
F P
0 g
s
.28457 .77396 m .28005 .75555 L .31027 .74966 L p .707 .577 .707 r
F P
0 g
s
.78031 .74109 m .77579 .72268 L .74481 .73049 L p .707 .577 .707 r
F P
0 g
s
.77579 .72268 m .78031 .74109 L .80901 .73213 L p .707 .577 .707 r
F P
0 g
s
.80901 .73213 m .80449 .71372 L .77579 .72268 L p .707 .577 .707 r
F P
0 g
s
.76514 .68895 m .7612 .72536 L .79045 .72437 L p .707 .577 .707 r
F P
0 g
s
.79045 .72437 m .79439 .68796 L .76514 .68895 L p .707 .577 .707 r
F P
0 g
s
.69853 .71789 m .70247 .68149 L .67519 .67376 L p .707 .577 .707 r
F P
0 g
s
.70247 .68149 m .69853 .71789 L .72952 .72313 L p .707 .577 .707 r
F P
0 g
s
.74933 .7489 m .74481 .73049 L .71459 .73638 L p .707 .577 .707 r
F P
0 g
s
.74481 .73049 m .74933 .7489 L .78031 .74109 L p .707 .577 .707 r
F P
0 g
s
.25359 .78177 m .24908 .76336 L .28005 .75555 L p .707 .577 .707 r
F P
0 g
s
.64981 .62033 m .66933 .57066 L .65818 .555 L p .707 .577 .707 r
F P
0 g
s
.66933 .57066 m .64981 .62033 L .66905 .63658 L p .707 .577 .707 r
F P
0 g
s
.56609 .24748 m .5288 .74388 L .48492 .7379 L p .707 .577 .707 r
F P
0 g
s
.46148 .68587 m .466 .70428 L .4696 .70287 L p .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .44008 .73602 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.5222 .2415 m .48508 .73571 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.46171 .68613 m .46148 .68587 L .4696 .70287 L .707 .577 .707 r
F
.4711 .68901 m .46148 .68587 L .47466 .7009 L F
.5222 .2415 m .56609 .24748 L p .48521 .73613 L F P
0 g
s
.48508 .73571 m .5222 .2415 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.48961 .69505 m .4851 .67664 L .46148 .68587 L p .707 .577 .707 r
F P
0 g
s
.48508 .73571 m .48492 .7379 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.4696 .70287 m .47466 .7009 L p .46171 .68613 L .707 .577 .707 r
F P
0 g
s
.47466 .7009 m .48961 .69505 L p .4711 .68901 L .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .48508 .73571 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.71459 .73638 m .71911 .75479 L .74933 .7489 L p .707 .577 .707 r
F P
0 g
s
.28005 .75555 m .28457 .77396 L .25359 .78177 L p .707 .577 .707 r
F P
0 g
s
.44008 .73602 m .45153 .58369 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .45812 .59351 L .44483 .59142 L p .707 .577 .707 r
F P
0 g
s
.44483 .59142 m .43018 .58912 L p .43272 .60542 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .44483 .59142 L .43272 .60542 L .707 .577 .707 r
F
.47737 .23963 m .5222 .2415 L p .46867 .56387 L F P
0 g
s
.45153 .58369 m .47737 .23963 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.71911 .75479 m .71459 .73638 L .68809 .73978 L p .707 .577 .707 r
F P
0 g
s
.80449 .71372 m .80901 .73213 L .83262 .7229 L p .707 .577 .707 r
F P
0 g
s
.83262 .7229 m .82811 .70449 L .80449 .71372 L p .707 .577 .707 r
F P
0 g
s
.79439 .68796 m .79045 .72437 L .81442 .72025 L p .707 .577 .707 r
F P
0 g
s
.81442 .72025 m .81836 .68385 L .79439 .68796 L p .707 .577 .707 r
F P
0 g
s
.67519 .67376 m .67125 .71016 L .69853 .71789 L p .707 .577 .707 r
F P
0 g
s
.82425 .62769 m .80474 .67736 L .82079 .67171 L p .707 .577 .707 r
F P
0 g
s
.82079 .67171 m .8403 .62204 L .82425 .62769 L p .707 .577 .707 r
F P
0 g
s
.68809 .73978 m .6926 .75819 L .71911 .75479 L p .707 .577 .707 r
F P
0 g
s
.67125 .71016 m .67519 .67376 L .65429 .66429 L p .707 .577 .707 r
F P
0 g
s
.65429 .66429 m .65036 .7007 L .67125 .71016 L p .707 .577 .707 r
F P
0 g
s
.65818 .555 m .63866 .60466 L .64981 .62033 L p .707 .577 .707 r
F P
0 g
s
.6926 .75819 m .68809 .73978 L .66789 .74035 L p .707 .577 .707 r
F P
0 g
s
.63866 .60466 m .65818 .555 L .6562 .54146 L p .707 .577 .707 r
F P
0 g
s
.66789 .74035 m .67241 .75877 L .6926 .75819 L p .707 .577 .707 r
F P
0 g
s
.82811 .70449 m .83262 .7229 L .84884 .7143 L p .707 .577 .707 r
F P
0 g
s
.81836 .68385 m .81442 .72025 L .83076 .71341 L p .707 .577 .707 r
F P
0 g
s
.84884 .7143 m .84432 .69589 L .82811 .70449 L p .707 .577 .707 r
F P
0 g
s
.83076 .71341 m .8347 .67701 L .81836 .68385 L p .707 .577 .707 r
F P
0 g
s
.65036 .7007 m .65429 .66429 L .64183 .65402 L p .707 .577 .707 r
F P
0 g
s
.8403 .62204 m .82079 .67171 L .82819 .66163 L p .707 .577 .707 r
F P
0 g
s
.82819 .66163 m .84771 .61196 L .8403 .62204 L p .707 .577 .707 r
F P
0 g
s
.64183 .65402 m .63789 .69043 L .65036 .7007 L p .707 .577 .707 r
F P
0 g
s
.6562 .54146 m .63669 .59113 L .63866 .60466 L p .707 .577 .707 r
F P
0 g
s
.67241 .75877 m .66789 .74035 L .65598 .73805 L p .707 .577 .707 r
F P
0 g
s
.65598 .73805 m .6605 .75646 L .67241 .75877 L p .707 .577 .707 r
F P
0 g
s
.8347 .67701 m .83076 .71341 L .83787 .70452 L p .707 .577 .707 r
F P
0 g
s
.83787 .70452 m .84181 .66811 L .8347 .67701 L p .707 .577 .707 r
F P
0 g
s
.63669 .59113 m .6562 .54146 L .66361 .53138 L p .707 .577 .707 r
F P
0 g
s
.84432 .69589 m .84884 .7143 L .85607 .70717 L p .707 .577 .707 r
F P
0 g
s
.85607 .70717 m .85156 .68876 L .84432 .69589 L p .707 .577 .707 r
F P
0 g
s
.63789 .69043 m .64183 .65402 L .63902 .64395 L p .707 .577 .707 r
F P
0 g
s
.84771 .61196 m .82819 .66163 L .82622 .64809 L p .707 .577 .707 r
F P
0 g
s
.82622 .64809 m .84574 .59842 L .84771 .61196 L p .707 .577 .707 r
F P
0 g
s
.63902 .64395 m .63508 .68035 L .63789 .69043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.66361 .53138 m .64409 .58104 L .63669 .59113 L p .707 .577 .707 r
F P
0 g
s
.6605 .75646 m .65598 .73805 L .65352 .73309 L p .707 .577 .707 r
F P
0 g
s
.65352 .73309 m .65804 .7515 L .6605 .75646 L p .707 .577 .707 r
F P
0 g
s
.84181 .66811 m .83787 .70452 L .83506 .69444 L p .707 .577 .707 r
F P
0 g
s
.83506 .69444 m .839 .65804 L .84181 .66811 L p .707 .577 .707 r
F P
0 g
s
.64409 .58104 m .66361 .53138 L .67966 .52573 L p .707 .577 .707 r
F P
0 g
s
.85156 .68876 m .85607 .70717 L .85361 .70221 L p .707 .577 .707 r
F P
0 g
s
.85361 .70221 m .8491 .6838 L .85156 .68876 L p .707 .577 .707 r
F P
0 g
s
.63508 .68035 m .63902 .64395 L .64613 .63505 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84574 .59842 m .82622 .64809 L .81507 .63243 L p .707 .577 .707 r
F P
0 g
s
.81507 .63243 m .83459 .58276 L .84574 .59842 L p .707 .577 .707 r
F P
0 g
s
.38064 .62976 m .40016 .58009 L .371 .56733 L p .707 .577 .707 r
F P
0 g
s
.40016 .58009 m .38064 .62976 L .41066 .63879 L p .707 .577 .707 r
F P
0 g
s
.35149 .617 m .371 .56733 L .34556 .55208 L p .707 .577 .707 r
F P
0 g
s
.371 .56733 m .35149 .617 L .38064 .62976 L p .707 .577 .707 r
F P
0 g
s
.64613 .63505 m .64219 .67146 L .63508 .68035 L p .707 .577 .707 r
F P
0 g
s
.43018 .58912 m .41066 .63879 L .4386 .64318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67966 .52573 m .66014 .5754 L .64409 .58104 L p .707 .577 .707 r
F P
0 g
s
.65804 .7515 m .65352 .73309 L .66076 .72596 L p .707 .577 .707 r
F P
0 g
s
.66014 .5754 m .67966 .52573 L .70278 .52507 L p .707 .577 .707 r
F P
0 g
s
.66076 .72596 m .66527 .74437 L .65804 .7515 L p .707 .577 .707 r
F P
0 g
s
.32604 .60175 m .34556 .55208 L .32632 .53582 L p .707 .577 .707 r
F P
0 g
s
.34556 .55208 m .32604 .60175 L .35149 .617 L p .707 .577 .707 r
F P
0 g
s
.839 .65804 m .83506 .69444 L .8226 .68417 L p .707 .577 .707 r
F P
0 g
s
.8226 .68417 m .82653 .64777 L .839 .65804 L p .707 .577 .707 r
F P
0 g
s
.8491 .6838 m .85361 .70221 L .8417 .6999 L p .707 .577 .707 r
F P
0 g
s
.8417 .6999 m .83719 .68149 L .8491 .6838 L p .707 .577 .707 r
F P
0 g
s
.45812 .59351 m .4386 .64318 L .46173 .64253 L p .707 .577 .707 r
F P
0 g
s
.46173 .64253 m .48124 .59286 L .45812 .59351 L p .707 .577 .707 r
F P
0 g
s
.83459 .58276 m .81507 .63243 L .79583 .61618 L p .707 .577 .707 r
F P
0 g
s
.79583 .61618 m .81535 .56651 L .83459 .58276 L p .707 .577 .707 r
F P
0 g
s
.64219 .67146 m .64613 .63505 L .66247 .62821 L p .707 .577 .707 r
F P
0 g
s
.38651 .68136 m .39045 .64496 L .35946 .63972 L p .707 .577 .707 r
F P
0 g
s
.39045 .64496 m .38651 .68136 L .41819 .6836 L p .707 .577 .707 r
F P
0 g
s
.41819 .6836 m .42213 .64719 L .39045 .64496 L p .707 .577 .707 r
F P
0 g
s
.42213 .64719 m .41819 .6836 L .44744 .6826 L p .707 .577 .707 r
F P
0 g
s
.44744 .6826 m .45138 .6462 L .42213 .64719 L p .707 .577 .707 r
F P
0 g
s
.35552 .67613 m .35946 .63972 L .33218 .63199 L p .707 .577 .707 r
F P
0 g
s
.35946 .63972 m .35552 .67613 L .38651 .68136 L p .707 .577 .707 r
F P
0 g
s
.66247 .62821 m .65853 .66462 L .64219 .67146 L p .707 .577 .707 r
F P
0 g
s
.3068 .58549 m .32632 .53582 L .31517 .52016 L p .707 .577 .707 r
F P
0 g
s
.32632 .53582 m .3068 .58549 L .32604 .60175 L p .707 .577 .707 r
F P
0 g
s
.70278 .52507 m .68327 .57474 L .66014 .5754 L p .707 .577 .707 r
F P
0 g
s
.68327 .57474 m .70278 .52507 L .73073 .52947 L p .707 .577 .707 r
F P
0 g
s
.45138 .6462 m .44744 .6826 L .47141 .67849 L p .707 .577 .707 r
F P
0 g
s
.47141 .67849 m .47535 .64208 L .45138 .6462 L p .707 .577 .707 r
F P
0 g
s
.33218 .63199 m .32824 .6684 L .35552 .67613 L p .707 .577 .707 r
F P
0 g
s
.66527 .74437 m .66076 .72596 L .67698 .71736 L p .707 .577 .707 r
F P
0 g
s
.81535 .56651 m .79583 .61618 L .77039 .60092 L p .707 .577 .707 r
F P
0 g
s
.77039 .60092 m .7899 .55125 L .81535 .56651 L p .707 .577 .707 r
F P
0 g
s
.3761 .72694 m .37158 .70853 L .34508 .71193 L p .707 .577 .707 r
F P
0 g
s
.32824 .6684 m .33218 .63199 L .31128 .62253 L p .707 .577 .707 r
F P
0 g
s
.82653 .64777 m .8226 .68417 L .8017 .67471 L p .707 .577 .707 r
F P
0 g
s
.8017 .67471 m .80564 .6383 L .82653 .64777 L p .707 .577 .707 r
F P
0 g
s
.48124 .59286 m .46173 .64253 L .47778 .63688 L p .707 .577 .707 r
F P
0 g
s
.47778 .63688 m .49729 .58721 L .48124 .59286 L p .707 .577 .707 r
F P
0 g
s
.67698 .71736 m .68149 .73577 L .66527 .74437 L p .707 .577 .707 r
F P
0 g
s
.34508 .71193 m .34959 .73034 L .3761 .72694 L p .707 .577 .707 r
F P
0 g
s
.83719 .68149 m .8417 .6999 L .82151 .70048 L p .707 .577 .707 r
F P
0 g
s
.82151 .70048 m .81699 .68207 L .83719 .68149 L p .707 .577 .707 r
F P
0 g
s
.65853 .66462 m .66247 .62821 L .68644 .6241 L p .707 .577 .707 r
F P
0 g
s
.71121 .57914 m .73073 .52947 L .76074 .53849 L p .707 .577 .707 r
F P
0 g
s
.73073 .52947 m .71121 .57914 L .68327 .57474 L p .707 .577 .707 r
F P
0 g
s
.7899 .55125 m .77039 .60092 L .74123 .58816 L p .707 .577 .707 r
F P
0 g
s
.74123 .58816 m .76074 .53849 L .7899 .55125 L p .707 .577 .707 r
F P
0 g
s
.31128 .62253 m .30734 .65894 L .32824 .6684 L p .707 .577 .707 r
F P
0 g
s
.76074 .53849 m .74123 .58816 L .71121 .57914 L p .707 .577 .707 r
F P
0 g
s
.31517 .52016 m .29565 .56983 L .3068 .58549 L p .707 .577 .707 r
F P
0 g
s
.47535 .64208 m .47141 .67849 L .48775 .67165 L p .707 .577 .707 r
F P
0 g
s
.48775 .67165 m .49169 .63524 L .47535 .64208 L p .707 .577 .707 r
F P
0 g
s
.34959 .73034 m .34508 .71193 L .32488 .71251 L p .707 .577 .707 r
F P
0 g
s
.29565 .56983 m .31517 .52016 L .31319 .50663 L p .707 .577 .707 r
F P
0 g
s
.68644 .6241 m .6825 .6605 L .65853 .66462 L p .707 .577 .707 r
F P
0 g
s
.32488 .71251 m .3294 .73092 L .34959 .73034 L p .707 .577 .707 r
F P
0 g
s
.30734 .65894 m .31128 .62253 L .29882 .61226 L p .707 .577 .707 r
F P
0 g
s
.4851 .67664 m .48961 .69505 L .50583 .68645 L p .707 .577 .707 r
F P
0 g
s
.50583 .68645 m .50131 .66804 L .4851 .67664 L p .707 .577 .707 r
F P
0 g
s
.80564 .6383 m .8017 .67471 L .77442 .66698 L p .707 .577 .707 r
F P
0 g
s
.77442 .66698 m .77836 .63057 L .80564 .6383 L p .707 .577 .707 r
F P
0 g
s
.68149 .73577 m .67698 .71736 L .70059 .70813 L p .707 .577 .707 r
F P
0 g
s
.6825 .6605 m .68644 .6241 L .71569 .62311 L p .707 .577 .707 r
F P
0 g
s
.49729 .58721 m .47778 .63688 L .48518 .6268 L p .707 .577 .707 r
F P
0 g
s
.48518 .6268 m .5047 .57713 L .49729 .58721 L p .707 .577 .707 r
F P
0 g
s
.70059 .70813 m .70511 .72654 L .68149 .73577 L p .707 .577 .707 r
F P
0 g
s
.81699 .68207 m .82151 .70048 L .795 .70388 L p .707 .577 .707 r
F P
0 g
s
.795 .70388 m .79049 .68547 L .81699 .68207 L p .707 .577 .707 r
F P
0 g
s
.29882 .61226 m .29488 .64866 L .30734 .65894 L p .707 .577 .707 r
F P
0 g
s
.77836 .63057 m .77442 .66698 L .74343 .66174 L p .707 .577 .707 r
F P
0 g
s
.74343 .66174 m .74737 .62534 L .77836 .63057 L p .707 .577 .707 r
F P
0 g
s
.71569 .62311 m .71175 .65951 L .6825 .6605 L p .707 .577 .707 r
F P
0 g
s
.71175 .65951 m .71569 .62311 L .74737 .62534 L p .707 .577 .707 r
F P
0 g
s
.31319 .50663 m .29368 .5563 L .29565 .56983 L p .707 .577 .707 r
F P
0 g
s
.3294 .73092 m .32488 .71251 L .31297 .7102 L p .707 .577 .707 r
F P
0 g
s
.74737 .62534 m .74343 .66174 L .71175 .65951 L p .707 .577 .707 r
F P
0 g
s
.49169 .63524 m .48775 .67165 L .49486 .66276 L p .707 .577 .707 r
F P
0 g
s
.49486 .66276 m .4988 .62635 L .49169 .63524 L p .707 .577 .707 r
F P
0 g
s
.70511 .72654 m .70059 .70813 L .72929 .69917 L p .707 .577 .707 r
F P
0 g
s
.31297 .7102 m .31749 .72861 L .3294 .73092 L p .707 .577 .707 r
F P
0 g
s
.29368 .5563 m .31319 .50663 L .3206 .49654 L p .707 .577 .707 r
F P
0 g
s
.72929 .69917 m .73381 .71758 L .70511 .72654 L p .707 .577 .707 r
F P
0 g
s
.79049 .68547 m .795 .70388 L .76478 .70977 L p .707 .577 .707 r
F P
0 g
s
.76478 .70977 m .76027 .69136 L .79049 .68547 L p .707 .577 .707 r
F P
0 g
s
.50131 .66804 m .50583 .68645 L .51306 .67932 L p .707 .577 .707 r
F P
0 g
s
.51306 .67932 m .50855 .66091 L .50131 .66804 L p .707 .577 .707 r
F P
0 g
s
.29488 .64866 m .29882 .61226 L .29601 .60218 L p .707 .577 .707 r
F P
0 g
s
.73381 .71758 m .72929 .69917 L .76027 .69136 L p .707 .577 .707 r
F P
0 g
s
.76027 .69136 m .76478 .70977 L .73381 .71758 L p .707 .577 .707 r
F P
0 g
s
.5047 .57713 m .48518 .6268 L .48321 .61326 L p .707 .577 .707 r
F P
0 g
s
.48321 .61326 m .50273 .56359 L .5047 .57713 L p .707 .577 .707 r
F P
0 g
s
.29601 .60218 m .29207 .63859 L .29488 .64866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.3206 .49654 m .30108 .54621 L .29368 .5563 L p .707 .577 .707 r
F P
0 g
s
.31749 .72861 m .31297 .7102 L .31051 .70524 L p .707 .577 .707 r
F P
0 g
s
.4988 .62635 m .49486 .66276 L .49205 .65268 L p .707 .577 .707 r
F P
0 g
s
.49205 .65268 m .49599 .61627 L .4988 .62635 L p .707 .577 .707 r
F P
0 g
s
.31051 .70524 m .31503 .72365 L .31749 .72861 L p .707 .577 .707 r
F P
0 g
s
.30108 .54621 m .3206 .49654 L .33665 .49089 L p .707 .577 .707 r
F P
0 g
s
.50855 .66091 m .51306 .67932 L .5106 .67436 L p .707 .577 .707 r
F P
0 g
s
.5106 .67436 m .50609 .65595 L .50855 .66091 L p .707 .577 .707 r
F P
0 g
s
.29207 .63859 m .29601 .60218 L .30312 .59329 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50273 .56359 m .48321 .61326 L .47206 .5976 L p .707 .577 .707 r
F P
0 g
s
.47206 .5976 m .49158 .54793 L .50273 .56359 L p .707 .577 .707 r
F P
0 g
s
.30312 .59329 m .29918 .62969 L .29207 .63859 L p .707 .577 .707 r
F P
0 g
s
.33665 .49089 m .31713 .54056 L .30108 .54621 L p .707 .577 .707 r
F P
0 g
s
.31503 .72365 m .31051 .70524 L .31775 .69811 L p .707 .577 .707 r
F P
0 g
s
.31713 .54056 m .33665 .49089 L .35977 .49024 L p .707 .577 .707 r
F P
0 g
s
.49599 .61627 m .49205 .65268 L .47958 .64241 L p .707 .577 .707 r
F P
0 g
s
.47958 .64241 m .48352 .606 L .49599 .61627 L p .707 .577 .707 r
F P
0 g
s
.31775 .69811 m .32226 .71652 L .31503 .72365 L p .707 .577 .707 r
F P
0 g
s
.29918 .62969 m .30312 .59329 L .31946 .58645 L p .707 .577 .707 r
F P
0 g
s
.50609 .65595 m .5106 .67436 L .49869 .67205 L p .707 .577 .707 r
F P
0 g
s
.49869 .67205 m .49418 .65364 L .50609 .65595 L p .707 .577 .707 r
F P
0 g
s
.49158 .54793 m .47206 .5976 L .45282 .58135 L p .707 .577 .707 r
F P
0 g
s
.45282 .58135 m .47234 .53168 L .49158 .54793 L p .707 .577 .707 r
F P
0 g
s
.31946 .58645 m .31552 .62286 L .29918 .62969 L p .707 .577 .707 r
F P
0 g
s
.35977 .49024 m .34026 .53991 L .31713 .54056 L p .707 .577 .707 r
F P
0 g
s
.34026 .53991 m .35977 .49024 L .38771 .49464 L p .707 .577 .707 r
F P
0 g
s
.48352 .606 m .47958 .64241 L .45869 .63294 L p .707 .577 .707 r
F P
0 g
s
.45869 .63294 m .46263 .59654 L .48352 .606 L p .707 .577 .707 r
F P
0 g
s
.47234 .53168 m .45282 .58135 L .42738 .56609 L p .707 .577 .707 r
F P
0 g
s
.42738 .56609 m .44689 .51642 L .47234 .53168 L p .707 .577 .707 r
F P
0 g
s
.32226 .71652 m .31775 .69811 L .33396 .68951 L p .707 .577 .707 r
F P
0 g
s
.33396 .68951 m .33848 .70792 L .32226 .71652 L p .707 .577 .707 r
F P
0 g
s
.31552 .62286 m .31946 .58645 L .34343 .58233 L p .707 .577 .707 r
F P
0 g
s
.3682 .54431 m .38771 .49464 L .41773 .50366 L p .707 .577 .707 r
F P
0 g
s
.38771 .49464 m .3682 .54431 L .34026 .53991 L p .707 .577 .707 r
F P
0 g
s
.49418 .65364 m .49869 .67205 L .4785 .67263 L p .707 .577 .707 r
F P
0 g
s
.4785 .67263 m .47398 .65422 L .49418 .65364 L p .707 .577 .707 r
F P
0 g
s
.44689 .51642 m .42738 .56609 L .39822 .55333 L p .707 .577 .707 r
F P
0 g
s
.39822 .55333 m .41773 .50366 L .44689 .51642 L p .707 .577 .707 r
F P
0 g
s
.41773 .50366 m .39822 .55333 L .3682 .54431 L p .707 .577 .707 r
F P
0 g
s
.34343 .58233 m .33949 .61874 L .31552 .62286 L p .707 .577 .707 r
F P
0 g
s
.46263 .59654 m .45869 .63294 L .43141 .62522 L p .707 .577 .707 r
F P
0 g
s
.43141 .62522 m .43535 .58881 L .46263 .59654 L p .707 .577 .707 r
F P
0 g
s
.33949 .61874 m .34343 .58233 L .37268 .58134 L p .707 .577 .707 r
F P
0 g
s
.33848 .70792 m .33396 .68951 L .35758 .68028 L p .707 .577 .707 r
F P
0 g
s
.35758 .68028 m .36209 .69869 L .33848 .70792 L p .707 .577 .707 r
F P
0 g
s
.47398 .65422 m .4785 .67263 L .45199 .67603 L p .707 .577 .707 r
F P
0 g
s
.45199 .67603 m .44748 .65762 L .47398 .65422 L p .707 .577 .707 r
F P
0 g
s
.43535 .58881 m .43141 .62522 L .40042 .61998 L p .707 .577 .707 r
F P
0 g
s
.40042 .61998 m .40436 .58357 L .43535 .58881 L p .707 .577 .707 r
F P
0 g
s
.37268 .58134 m .36874 .61775 L .33949 .61874 L p .707 .577 .707 r
F P
0 g
s
.36874 .61775 m .37268 .58134 L .40436 .58357 L p .707 .577 .707 r
F P
0 g
s
.40436 .58357 m .40042 .61998 L .36874 .61775 L p .707 .577 .707 r
F P
0 g
s
.36209 .69869 m .35758 .68028 L .38628 .67132 L p .707 .577 .707 r
F P
0 g
s
.38628 .67132 m .3908 .68973 L .36209 .69869 L p .707 .577 .707 r
F P
0 g
s
.44748 .65762 m .45199 .67603 L .42177 .68192 L p .707 .577 .707 r
F P
0 g
s
.42177 .68192 m .41726 .66351 L .44748 .65762 L p .707 .577 .707 r
F P
0 g
s
.3908 .68973 m .38628 .67132 L .41726 .66351 L p .707 .577 .707 r
F P
0 g
s
.41726 .66351 m .42177 .68192 L .3908 .68973 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007Uooah008Io
o`00MGoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001aOol40006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001kOol006moo`800003FUH005YF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Moo`00KGoo
0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000Lgoo001[Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001`Ool006Yoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP00008006eoo`00JGoo
00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00UYF0`00JWoo001XOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0P00J7oo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P00Igoo001XOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000006Eoo`00J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP05001J
EUYFFUH0001TOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001oogoo065oo`00
J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<007ooOol0HGoo001XOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0<FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001R
Ool006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1ROol006Moo`=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo069oo`00Igoo0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol2FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1R
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP04FUH00`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001OOol;0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05eoo`<000IJEP04001JEUYFFUH60006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`800003
FUH005YF00EJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00FWoo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<000YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Moo`00FGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF0000
0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001IOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00Igoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Yoo`/0059oo`00
EWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0027oo0P0000=JEP00FUH015YF00@005YFFUIJEPH004aoo`00EWoo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Woo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00BGoo001FOol01@00FUIJ
EUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00AWoo001EOol20002
FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF0`00@goo001EOol01000FUH00000
0UYF00@005YFFUH000=oo`03001JEP0000D000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH00000
@Goo001DOol30004FUH01000FUIJEUYF0P0000Eoo`00FUIJEP0000AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEP<003ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF0P000UYF00<005YF
FUH00eYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0P00?7oo001COol200000eYF001JEP02
FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00UYF0P002EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP<0
03Yoo`00Dgoo00<005YFFUH015YF00<005YFFUH01EYF10001EYF00<005YFFUH015YF0P001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH0000iOol005=oo`03001JEP0000=JEP03001JEUYF00EJEP04001J
EUYFFUH20004FUH01000FUIJEUYF0`000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03
001oogoo03Ioo`00Dgoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<0
05YFFUH01@0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo00<005YF0000
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF0P00=Woo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30002FUH50000
0eYF001JEP02FUH20008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00Oomoo`0cOol005Aoo`05
001JEUYFFUH00007FUH00`00FUIJEP06FUH01@00FUH00000FUH01@0000=JEP00FUH015YF0P001EYF
00<005YFFUH015YF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00MJEP<003=oo`00EGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
009JEPD0009JEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool005YF0002FUH;0004
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000<Woo001EOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH025YF0`001eYF00<0
05YFFUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00L0
05YF001ooeYF001JEP020002FUH00`00FUIJEP020004Ool60007FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000`Ool003Qoo`/001=oo`03001JEUYF00EJEQP000YJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P0015YF00<005YFFUH00UYF00<007ooOol01goo0P001EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0;Goo000fOol30006FUH01000FUIJ
EUYF1P003Woo00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF0`0015YF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00AJEP03001oogoo00Qoo`<00003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP8002ioo`00=7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00@005YF000000eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000=JEP04001JEUYF0003FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0004FUH00`00FUIJEP04FUH3000;Ool3
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000^Ool003=oo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP<000Qoo`80009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000T000AJEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP05
001JEUYFFUH0000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00;Goo000c
Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0017oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol01goo0`000Woo0`00
00=JEP00FUH025YF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00<Woo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<00007FUH005YFFUH0
05YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH015YF
00<005YFFUH015YF00<005YFFUH00eYF0P001Woo1@0017oo0P002EYF00<005YFFUH015YF00<005YF
FUH00UYF00<007ooOol0:Woo000bOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF0P0017oo1@001Woo0P001UYF00<005YFFUH015YF00<005YFFUH00eYF00<007oo
Ool0:Woo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
00000P0000=oo`0000000`0027oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000aOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00=JEPD000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000]oo`<000IJEP03001JEUYF009JEP03001JEP0002aoo`00<7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF
00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000;Ool00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000/Ool002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEP0000<0009oo`03001JEUYF00<000IJEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30009Ool00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000]Ool002moo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=J
EP8000AJEP03001oo`00009JEP03001JEUYF008000AJEP03001JEUYF00IJEPH000IJEP03001JEUYF
00=JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005Ool00`00FUIJEP03FUHH0003FUH50005Ool20002FUH00`00FUIJEP02FUH00`00FUH0000]
Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH005YF0P0000AJEP000000009JEP<0009JEP03001JEUYF009JEP800004FUH005YFFUH30003
FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01@000eYF2@001EYF00<005YF0000;Goo000^Ool20002FUH;0004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEP<00004FUH005YF0005FUH00`00FUH0
00070002FUH00`00FUIJEP05FUH400000eYF001JEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00D005YFFUIJEP0000AJEP03001JEP00
02ioo`00;Woo00@005YF0000009JEP04001JEUYF0005Ool60008FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP02FUH500000eYF001JEP07FUH01000FUIJ
EUYF0`0015YF00H005YFFUH005YF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`001EYF00L005YFFUIJEP00FUH0000^Ool002eoo`<000AJEP04001J
EUYFFUH20009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH400000eYF001JEP03FUH:0004FUH00`00FUIJEP04FUH400001eYF001JEUYF001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP06001J
EUYF001JEP00;goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00Oomoo`09Ool300000eYF
001JEP07FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF00000`000eYF0`0000=JEP00
FUH00eYF4@000UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000MJEP00001JEP00FUH0000_Ool002aoo`800003FUH005YF009JEP03001J
EUYF00EJEP03001oogoo00]oo`8000QJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH80008FUH80003FUH01000FUH005YF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<007ooOol0;Goo000/Ool0
0`00FUIJEP04FUH00`00FUIJEP05FUH3000=Ool20006FUH01@00FUIJEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP00Ool0;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0027oo0`000Woo0P0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool50003Ool2000015YF001J
EUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00000_Ool002eoo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001oogoo009oo`D000Eoo`8000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00FUIJEP03FUH0
0`00FUIJEP020007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20004
FUH00`00FUIJEP02FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001eYF00<005YFFUH01UYF0`000Woo1@001goo0P00
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF1`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF0004FUH00`00FUH000050007Ool200000eYF001JEP090004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000^Ool01000FUIJEP001UYF00<005YF
FUH01UYF00@005YFFUIJEP800004Ool00000000:Ool20003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP001eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF001JEP00FUH0
0002FUH40002FUH01@00FUIJEUYF000027oo100000AJEP00000000=JEPL000EJEP03001JEUYF00=J
EP03001JEUYF009JEP8002eoo`00;Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP8000ioo`<0009JEP<000IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01P00FUH005YF001JEP@0009JEP800003FUH005YF00=JEP8000Yoo`D00003FUH005YF00IJ
EP@00003FUH005YF00AJEP03001JEUYF009JEP8002eoo`00;goo00<005YFFUH01EYF40000UYF1000
37oo00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF3@001EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP8000=JEP03001JEUYF009JEP<000EJEP03001oogoo00Moo`X000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP02FUH2000]Ool0031oo`03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
009JEPX000Uoo`03001JEUYF00=JEP03001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF009J
EPh000AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF00<005YFFUH00eYF00<005YF00000`0000=JEP00000027oo1@001Goo30000eYF
00L005YFFUIJEP00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Aoo`8000=JEP04001JEP00FUH30007FUH00`00FUIJEP05FUH60003FUH00`00FUH0
00030002FUH30005FUH00`00FUH00005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH50007Ool3000AOol;000]Ool002mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000L0009JEP06001JEP00001JEP0025YF00<005YFFUH00eYF3@0015YF0P000eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH010004Goo1P000eYF00<005YFFUH00UYF00<005YF
00000P00:goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000020003FUH00`00FUIJEP07FUH00`00FUH00002
000:FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP@000IJEP03001JEUYF00AJEP@00003FUH005YF00YJEP03001JEUYF00YJEP04001JEP000008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool200000eYF
00000005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP05FUH50009FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004Ool40004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>000YOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000EJEP04001JEP000004FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
1Woo1@0000=JEP00FUH01UYF00<005YFFUH00`000eYF00<005YFFUH01eYF00<005YFFUH00UYF2000
00=JEP00FUH00eYF00H005YF001JEP00FUH2000YOol002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH40003FUH60006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20008Ool2000015YF000000001UYF0`001UYF00<005YFFUH01UYF1P000UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00@005YFFUH002Uoo`00;7oo00<005YF00000eYF
00@005YFFUIJEPX000IJEPT000AJEP03001JEUYF009JEP05001JEUYF001JEP090003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool01000FUIJEUYF1P0000=JEP00FUH01eYF00<005YF
FUH00UYF10001eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP8002Yoo`00;7oo00<005YF0000
0eYF10002Woo0P0015YF00<005YFFUH01UYF1P0015YF00@005YF000000EJEP03001JEUYF00AJEP03
001JEUYF015JEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H000Eoo`03001JEUYF008000EJEP03001JEUYF00IJEP03001JEP00
008000=JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEP00001JEP000eYF0P00:goo000/Ool0
1000FUH005YF0P0000AJEP00000000aoo`800003FUH005YF00MJEP03001JEUYF00AJEP80009JEP80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH9
0007FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00@005YF0000
02eoo`00;7oo00H005YF000005YF0004FUH3000;Ool3000015YF000000000eYF00<005YFFUH01UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P00
15YF0P000UYF00<005YFFUH01EYF00<005YFFUH02P000eYF00<005YFFUH00UYF20001UYF0`00;goo
000/Ool20003FUH00`00FUIJEP03FUH01000FUH0000037oo1@0000=JEP00FUH01eYF00<005YFFUH0
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPP0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEP00
00<000AJEP03001JEUYF00AJEP@000Eoo`d000QJEP04001JEUYFFUH2000bOol002aoo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEUYFFUH30009Ool80007FUH01000FUIJEUYF3P002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P001EYF00@005YFFUIJEP8000EJEP04001JEUYFFUH2000:Ool50006FUH00`00FUIJEP06
FUH01000FUH00000=7oo000/Ool01@00FUIJEUYF00001UYF00<005YFFUH015YF1P000goo1@000goo
10000UYF00@005YFFUIJEPH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH01P00FUH00000FUH000Moo`@00003FUH005YF00QJ
EP03001JEUYF00AJEP<003Ioo`00;7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
009JEPT000Ioo`X000AJEP03001JEUYF00=JEP03001JEUYF00EJEQh000UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000EJEP04001JEUYF0002FUH00`00FUIJEP02FUH30002FUH0
0`00Ool000050005FUH00`00FUIJEP07FUH00`00FUIJEP04000iOol002aoo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH60003FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
2@000eYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000]Ool01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEPD000UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@0049oo`00;Woo0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00@005YFFUIJEP@000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF009JEP@000EJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40016Ool0031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH0
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF100000=JEP00
FUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF00@004Yoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF1P0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00D005YFFUIJEP0000=JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00<000IJEP03001J
EUYF00=JEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP02FUH6001>Ool0
03=oo`800003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP03FUH00`00FUH00005FUH01000FUIJEP000eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF0000
1P0015YF3P00E7oo000eOol30006FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<005YF0000
1UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00E7oo000hOol40002FUH00`00FUIJEP04
FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF3P000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF0`0015YF00<005YF00000P0015YF00H0
05YF000005YF0005FUH00`00FUIJEP02FUH2001DOol003aoo`T00003FUH005YF00QJEP03001JEUYF
00AJEPH00003FUH0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH00002Ool;0004
FUH01`00FUIJEUYF001JEP0005Aoo`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH0100000=J
EP00FUH00UYF100015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP800003FUH0000000ioo`<00003FUH0
05YF00D005Aoo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01EYF3@000Woo0P0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0`003Woo1P000UYF00<005YF00000P00DWoo000iOol20003FUH00`00
FUIJEP07FUH00`00FUIJEP04000<Ool300000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30006Ool80003FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000gOol20006FUH00`00FUIJEP04
FUH5000<Ool400001EYF001JEUYF000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF2@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00DGoo000eOol30007FUH00`00FUIJEP04000<
Ool50005FUH01000FUIJEUYF0P000UYF00<005YFFUH04EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YFFUIJEP00055oo`00<goo0P000eYF00<005YFFUH015YF0`0037oo
10000UYF00<005YFFUH01UYF00@005YFFUIJEP@001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00DGoo000bOol20004FUH00`00FUIJEP02FUH2000:Ool50006
FUH00`00FUIJEP06FUH01000FUH000000goo00<005YFFUH045YF00<005YFFUH02eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF3P00D7oo000aOol00`00FUH00005FUH01000FUH0000027oo10000UYF00<0
05YFFUH01eYF00<005YFFUH015YF0`001Woo0P0045YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF200000=JEP00
FUH00eYF00H005YF001JEP00FUH2001@Ool0035oo`04001JEUYF0003FUH30004Ool60006FUH00`00
FUIJEP07FUH00`00FUIJEP04000;Ool2000>FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH60002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEP00D7oo000aOol01@00FUIJEP00FUH02@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF10004Goo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF1P001eYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00DGoo000aOol200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000GOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0`000eYF0P00DWoo000bOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH00002000NOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH01000FUH00000
E7oo000bOol01000FUIJEP001UYF00<005YFFUH015YF00<005YFFUH00UYF1P009goo1P002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF2P000eYF00<005YFFUH01EYF00<005YF0000
0`001EYF0`00EWoo000bOol20002FUH00`00FUIJEP03FUH01000FUIJEUYF2000<goo1P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@001Goo4P000eYF00@005YFFUIJEP8005Uoo`00
<goo0P0000=JEP00FUH00UYF1P00@Goo2P001UYF00<005YFFUH00eYF2@002Goo1P001UYF00<005YF
FUH01UYF00@005YF000005]oo`00=Goo1@00DGoo30000eYF00@005YF000000Uoo`H000UJEP03001J
EUYF00AJEP<005eoo`00TWoo00@005YFFUH000AJEP8000Eoo`H000EJEP03001JEUYF00MJEP03001J
EUYF00@0061oo`00Tgoo00D005YFFUH005YF00T000=JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
06Aoo`00Tgoo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`00J7oo002COol01@00FUH005YF000015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00Jgoo002DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH00UYF1@00KWoo002DOol0
1@00FUIJEUYF000015YF00<005YFFUH00UYF2000Lgoo002DOol>001kOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59053 .75449 m .60276 .70169 L .57237 .69293 L p .707 .577 .707 r
F P
0 g
s
.60276 .70169 m .59053 .75449 L .62167 .75991 L p .707 .577 .707 r
F P
0 g
s
.62167 .75991 m .6339 .70711 L .60276 .70169 L p .707 .577 .707 r
F P
0 g
s
.56013 .74573 m .57237 .69293 L .54568 .68167 L p .707 .577 .707 r
F P
0 g
s
.57237 .69293 m .56013 .74573 L .59053 .75449 L p .707 .577 .707 r
F P
0 g
s
.6339 .70711 m .62167 .75991 L .65049 .76144 L p .707 .577 .707 r
F P
0 g
s
.65049 .76144 m .66273 .70864 L .6339 .70711 L p .707 .577 .707 r
F P
0 g
s
.53345 .73447 m .54568 .68167 L .52533 .66903 L p .707 .577 .707 r
F P
0 g
s
.54568 .68167 m .53345 .73447 L .56013 .74573 L p .707 .577 .707 r
F P
0 g
s
.66273 .70864 m .65049 .76144 L .67419 .75895 L p .707 .577 .707 r
F P
0 g
s
.67419 .75895 m .68642 .70615 L .66273 .70864 L p .707 .577 .707 r
F P
0 g
s
.59381 .81317 m .59625 .77647 L .56515 .7725 L p .707 .577 .707 r
F P
0 g
s
.59625 .77647 m .59381 .81317 L .62559 .81426 L p .707 .577 .707 r
F P
0 g
s
.62559 .81426 m .62803 .77755 L .59625 .77647 L p .707 .577 .707 r
F P
0 g
s
.62803 .77755 m .62559 .81426 L .65492 .81236 L p .707 .577 .707 r
F P
0 g
s
.65492 .81236 m .65736 .77566 L .62803 .77755 L p .707 .577 .707 r
F P
0 g
s
.56271 .8092 m .56515 .7725 L .53776 .76603 L p .707 .577 .707 r
F P
0 g
s
.56515 .7725 m .56271 .8092 L .59381 .81317 L p .707 .577 .707 r
F P
0 g
s
.60625 .84511 m .60344 .82651 L .57263 .82943 L p .707 .577 .707 r
F P
0 g
s
.60344 .82651 m .60625 .84511 L .63775 .83998 L p .707 .577 .707 r
F P
0 g
s
.63775 .83998 m .63494 .82138 L .60344 .82651 L p .707 .577 .707 r
F P
0 g
s
.63494 .82138 m .63775 .83998 L .66687 .83315 L p .707 .577 .707 r
F P
0 g
s
.66687 .83315 m .66407 .81455 L .63494 .82138 L p .707 .577 .707 r
F P
0 g
s
.52533 .66903 m .51309 .72183 L .53345 .73447 L p .707 .577 .707 r
F P
0 g
s
.57263 .82943 m .57544 .84803 L .60625 .84511 L p .707 .577 .707 r
F P
0 g
s
.51309 .72183 m .52533 .66903 L .51329 .65623 L p .707 .577 .707 r
F P
0 g
s
.65736 .77566 m .65492 .81236 L .67894 .80766 L p .707 .577 .707 r
F P
0 g
s
.67894 .80766 m .68138 .77096 L .65736 .77566 L p .707 .577 .707 r
F P
0 g
s
.68642 .70615 m .67419 .75895 L .69044 .75267 L p .707 .577 .707 r
F P
0 g
s
.69044 .75267 m .70267 .69987 L .68642 .70615 L p .707 .577 .707 r
F P
0 g
s
.53776 .76603 m .53532 .80274 L .56271 .8092 L p .707 .577 .707 r
F P
0 g
s
.57544 .84803 m .57263 .82943 L .54554 .82987 L p .707 .577 .707 r
F P
0 g
s
.53532 .80274 m .53776 .76603 L .51676 .75771 L p .707 .577 .707 r
F P
0 g
s
.54554 .82987 m .54835 .84846 L .57544 .84803 L p .707 .577 .707 r
F P
0 g
s
.66407 .81455 m .66687 .83315 L .69076 .82528 L p .707 .577 .707 r
F P
0 g
s
.69076 .82528 m .68795 .80668 L .66407 .81455 L p .707 .577 .707 r
F P
0 g
s
.51676 .75771 m .51433 .79442 L .53532 .80274 L p .707 .577 .707 r
F P
0 g
s
.51329 .65623 m .50105 .70903 L .51309 .72183 L p .707 .577 .707 r
F P
0 g
s
.54835 .84846 m .54554 .82987 L .52481 .82776 L p .707 .577 .707 r
F P
0 g
s
.68138 .77096 m .67894 .80766 L .6953 .80062 L p .707 .577 .707 r
F P
0 g
s
.6953 .80062 m .69774 .76392 L .68138 .77096 L p .707 .577 .707 r
F P
0 g
s
.52481 .82776 m .52762 .84636 L .54835 .84846 L p .707 .577 .707 r
F P
0 g
s
.50105 .70903 m .51329 .65623 L .51075 .64453 L p .707 .577 .707 r
F P
0 g
s
.70267 .69987 m .69044 .75267 L .69764 .74322 L p .707 .577 .707 r
F P
0 g
s
.69764 .74322 m .70988 .69042 L .70267 .69987 L p .707 .577 .707 r
F P
0 g
s
.68795 .80668 m .69076 .82528 L .70707 .81715 L p .707 .577 .707 r
F P
0 g
s
.70707 .81715 m .70426 .79855 L .68795 .80668 L p .707 .577 .707 r
F P
0 g
s
.51433 .79442 m .51676 .75771 L .50422 .74835 L p .707 .577 .707 r
F P
0 g
s
.50422 .74835 m .50178 .78506 L .51433 .79442 L p .707 .577 .707 r
F P
0 g
s
.52762 .84636 m .52481 .82776 L .51248 .82333 L p .707 .577 .707 r
F P
0 g
s
.51075 .64453 m .49851 .69733 L .50105 .70903 L p .707 .577 .707 r
F P
0 g
s
.69774 .76392 m .6953 .80062 L .70239 .79193 L p .707 .577 .707 r
F P
0 g
s
.70239 .79193 m .70483 .75523 L .69774 .76392 L p .707 .577 .707 r
F P
0 g
s
.51248 .82333 m .51529 .84193 L .52762 .84636 L p .707 .577 .707 r
F P
0 g
s
.70426 .79855 m .70707 .81715 L .71421 .80955 L p .707 .577 .707 r
F P
0 g
s
.71421 .80955 m .7114 .79095 L .70426 .79855 L p .707 .577 .707 r
F P
0 g
s
.50178 .78506 m .50422 .74835 L .50136 .73886 L p .707 .577 .707 r
F P
0 g
s
.49851 .69733 m .51075 .64453 L .51795 .63508 L p .707 .577 .707 r
F P
0 g
s
.70988 .69042 m .69764 .74322 L .6951 .73152 L p .707 .577 .707 r
F P
0 g
s
.6951 .73152 m .70734 .67872 L .70988 .69042 L p .707 .577 .707 r
F P
0 g
s
.47507 .82195 m .49813 .32311 L .45417 .31838 L p .707 .577 .707 r
F P
0 g
s
.50136 .73886 m .49892 .77556 L .50178 .78506 L p .707 .577 .707 r
F P
0 g
s
.51529 .84193 m .51248 .82333 L .50975 .81701 L p .707 .577 .707 r
F P
0 g
s
.51795 .63508 m .50572 .68788 L .49851 .69733 L p .707 .577 .707 r
F P
0 g
s
.50975 .81701 m .51256 .83561 L .51529 .84193 L p .707 .577 .707 r
F P
0 g
s
.50572 .68788 m .51795 .63508 L .5342 .6288 L p .707 .577 .707 r
F P
0 g
s
.49892 .77556 m .50136 .73886 L .50845 .73016 L p .707 .577 .707 r
F P
0 g
s
.50845 .73016 m .50601 .76687 L .49892 .77556 L p .707 .577 .707 r
F P
0 g
s
.51256 .83561 m .50975 .81701 L .51689 .80941 L p .707 .577 .707 r
F P
0 g
s
.5342 .6288 m .52197 .6816 L .50572 .68788 L p .707 .577 .707 r
F P
0 g
s
.51689 .80941 m .5197 .82801 L .51256 .83561 L p .707 .577 .707 r
F P
0 g
s
.50601 .76687 m .50845 .73016 L .52481 .72312 L p .707 .577 .707 r
F P
0 g
s
.52481 .72312 m .52237 .75983 L .50601 .76687 L p .707 .577 .707 r
F P
0 g
s
.5197 .82801 m .51689 .80941 L .5332 .80128 L p .707 .577 .707 r
F P
0 g
s
.49813 .32311 m .47507 .82195 L .51998 .8227 L p .707 .577 .707 r
F P
0 g
s
.52197 .6816 m .5342 .6288 L .5579 .62631 L p .707 .577 .707 r
F P
0 g
s
.5579 .62631 m .54566 .67911 L .52197 .6816 L p .707 .577 .707 r
F P
0 g
s
.52237 .75983 m .52481 .72312 L .54883 .71843 L p .707 .577 .707 r
F P
0 g
s
.54883 .71843 m .54639 .75513 L .52237 .75983 L p .707 .577 .707 r
F P
0 g
s
.51998 .8227 m .54303 .32385 L .49813 .32311 L p .707 .577 .707 r
F P
0 g
s
.54566 .67911 m .5579 .62631 L .58672 .62784 L p .707 .577 .707 r
F P
0 g
s
.5332 .80128 m .53601 .81987 L .5197 .82801 L p .707 .577 .707 r
F P
0 g
s
.58672 .62784 m .57449 .68064 L .54566 .67911 L p .707 .577 .707 r
F P
0 g
s
.53601 .81987 m .5332 .80128 L .55709 .79341 L p .707 .577 .707 r
F P
0 g
s
.54639 .75513 m .54883 .71843 L .57816 .71653 L p .707 .577 .707 r
F P
0 g
s
.55709 .79341 m .5599 .81201 L .53601 .81987 L p .707 .577 .707 r
F P
0 g
s
.57816 .71653 m .57572 .75323 L .54639 .75513 L p .707 .577 .707 r
F P
0 g
s
.5599 .81201 m .55709 .79341 L .58621 .78658 L p .707 .577 .707 r
F P
0 g
s
.58621 .78658 m .58902 .80517 L .5599 .81201 L p .707 .577 .707 r
F P
0 g
s
.54303 .32385 m .51998 .8227 L .56142 .81939 L p .707 .577 .707 r
F P
0 g
s
.56142 .81939 m .58448 .32054 L .54303 .32385 L p .707 .577 .707 r
F P
0 g
s
.43111 .81723 m .45417 .31838 L .41545 .31014 L p .707 .577 .707 r
F P
0 g
s
.45417 .31838 m .43111 .81723 L .47507 .82195 L p .707 .577 .707 r
F P
0 g
s
.70483 .75523 m .70239 .79193 L .69953 .78244 L p .707 .577 .707 r
F P
0 g
s
.69953 .78244 m .70197 .74573 L .70483 .75523 L p .707 .577 .707 r
F P
0 g
s
.57449 .68064 m .58672 .62784 L .61786 .63326 L p .707 .577 .707 r
F P
0 g
s
.61786 .63326 m .60563 .68606 L .57449 .68064 L p .707 .577 .707 r
F P
0 g
s
.57572 .75323 m .57816 .71653 L .60994 .71762 L p .707 .577 .707 r
F P
0 g
s
.60994 .71762 m .6075 .75432 L .57572 .75323 L p .707 .577 .707 r
F P
0 g
s
.58902 .80517 m .58621 .78658 L .61772 .78145 L p .707 .577 .707 r
F P
0 g
s
.61772 .78145 m .62053 .80005 L .58902 .80517 L p .707 .577 .707 r
F P
0 g
s
.58448 .32054 m .56142 .81939 L .59536 .81235 L p .707 .577 .707 r
F P
0 g
s
.59536 .81235 m .61842 .31351 L .58448 .32054 L p .707 .577 .707 r
F P
0 g
s
.7114 .79095 m .71421 .80955 L .71148 .80322 L p .707 .577 .707 r
F P
0 g
s
.71148 .80322 m .70867 .78462 L .7114 .79095 L p .707 .577 .707 r
F P
0 g
s
.70734 .67872 m .6951 .73152 L .68306 .71872 L p .707 .577 .707 r
F P
0 g
s
.68306 .71872 m .6953 .66592 L .70734 .67872 L p .707 .577 .707 r
F P
0 g
s
.3924 .80898 m .41545 .31014 L .38577 .29919 L p .707 .577 .707 r
F P
0 g
s
.41545 .31014 m .3924 .80898 L .43111 .81723 L p .707 .577 .707 r
F P
0 g
s
.24752 .7189 m .25976 .6661 L .22936 .65734 L p .707 .577 .707 r
F P
0 g
s
.25976 .6661 m .24752 .7189 L .27866 .72432 L p .707 .577 .707 r
F P
0 g
s
.27866 .72432 m .29089 .67152 L .25976 .6661 L p .707 .577 .707 r
F P
0 g
s
.21712 .71014 m .22936 .65734 L .20267 .64608 L p .707 .577 .707 r
F P
0 g
s
.22936 .65734 m .21712 .71014 L .24752 .7189 L p .707 .577 .707 r
F P
0 g
s
.29089 .67152 m .27866 .72432 L .30748 .72585 L p .707 .577 .707 r
F P
0 g
s
.30748 .72585 m .31972 .67305 L .29089 .67152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70197 .74573 m .69953 .78244 L .68699 .77307 L p .707 .577 .707 r
F P
0 g
s
.68699 .77307 m .68942 .73637 L .70197 .74573 L p .707 .577 .707 r
F P
0 g
s
.19044 .69888 m .20267 .64608 L .18232 .63344 L p .707 .577 .707 r
F P
0 g
s
.20267 .64608 m .19044 .69888 L .21712 .71014 L p .707 .577 .707 r
F P
0 g
s
.64826 .64202 m .63602 .69482 L .60563 .68606 L p .707 .577 .707 r
F P
0 g
s
.60563 .68606 m .61786 .63326 L .64826 .64202 L p .707 .577 .707 r
F P
0 g
s
.64104 .72159 m .6386 .75829 L .6075 .75432 L p .707 .577 .707 r
F P
0 g
s
.6075 .75432 m .60994 .71762 L .64104 .72159 L p .707 .577 .707 r
F P
0 g
s
.62053 .80005 m .61772 .78145 L .64852 .77852 L p .707 .577 .707 r
F P
0 g
s
.61842 .31351 m .59536 .81235 L .61846 .80227 L p .707 .577 .707 r
F P
0 g
s
.61846 .80227 m .64152 .30343 L .61842 .31351 L p .707 .577 .707 r
F P
0 g
s
.31972 .67305 m .30748 .72585 L .33118 .72336 L p .707 .577 .707 r
F P
0 g
s
.33118 .72336 m .34342 .67056 L .31972 .67305 L p .707 .577 .707 r
F P
0 g
s
.6953 .66592 m .68306 .71872 L .66271 .70608 L p .707 .577 .707 r
F P
0 g
s
.66271 .70608 m .67494 .65328 L .6953 .66592 L p .707 .577 .707 r
F P
0 g
s
.2508 .7733 m .25324 .73659 L .22214 .73262 L p .707 .577 .707 r
F P
0 g
s
.25324 .73659 m .2508 .7733 L .28258 .77439 L p .707 .577 .707 r
F P
0 g
s
.28258 .77439 m .28502 .73768 L .25324 .73659 L p .707 .577 .707 r
F P
0 g
s
.70867 .78462 m .71148 .80322 L .69915 .79879 L p .707 .577 .707 r
F P
0 g
s
.69915 .79879 m .69634 .78019 L .70867 .78462 L p .707 .577 .707 r
F P
0 g
s
.28502 .73768 m .28258 .77439 L .31191 .77249 L p .707 .577 .707 r
F P
0 g
s
.31191 .77249 m .31435 .73578 L .28502 .73768 L p .707 .577 .707 r
F P
0 g
s
.2197 .76933 m .22214 .73262 L .19475 .72616 L p .707 .577 .707 r
F P
0 g
s
.22214 .73262 m .2197 .76933 L .2508 .7733 L p .707 .577 .707 r
F P
0 g
s
.35463 .70763 m .36687 .65483 L .35966 .66428 L p .707 .577 .707 r
F P
0 g
s
.34494 .77541 m .34775 .79401 L .35781 .78899 L p .707 .577 .707 r
F P
0 g
s
.35781 .78899 m .36406 .78587 L p .35789 .7825 L .707 .577 .707 r
F P
0 g
s
.35789 .7825 m .34494 .77541 L .35781 .78899 L .707 .577 .707 r
F
.34743 .71708 m .35966 .66428 L .34342 .67056 L p F P
0 g
s
.34775 .79401 m .34494 .77541 L .32106 .78327 L p .707 .577 .707 r
F P
0 g
s
.33837 .73108 m .33593 .76779 L .35229 .76075 L p .707 .577 .707 r
F P
0 g
s
.35229 .76075 m .35473 .72404 L .33837 .73108 L p .707 .577 .707 r
F P
0 g
s
.35966 .66428 m .34743 .71708 L .35463 .70763 L p .707 .577 .707 r
F P
0 g
s
.36406 .78587 m .36125 .76728 L .34494 .77541 L p .707 .577 .707 r
F P
0 g
s
.34342 .67056 m .33118 .72336 L .34743 .71708 L p .707 .577 .707 r
F P
0 g
s
.35209 .69593 m .34005 .68313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.36433 .64313 m .35415 .68707 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35415 .68707 m .35209 .69593 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35541 .5041 m .36243 .40758 L .36396 .2736 L .707 .577 .707 r
F
.34005 .68313 m .35229 .63033 L .35452 .6327 L p F P
0 g
s
.35452 .6327 m .36433 .64313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.34005 .68313 m .35452 .6327 L .35433 .6596 L .707 .577 .707 r
F
.35473 .72404 m .35229 .76075 L .35939 .75206 L p F P
0 g
s
.35939 .75206 m .36182 .71535 L .35473 .72404 L p .707 .577 .707 r
F P
0 g
s
.35896 .70586 m .35652 .74257 L .34398 .7332 L p .707 .577 .707 r
F P
0 g
s
.36687 .65483 m .35463 .70763 L .35209 .69593 L p .707 .577 .707 r
F P
0 g
s
.34398 .7332 m .34641 .69649 L .35896 .70586 L p .707 .577 .707 r
F P
0 g
s
.35229 .63033 m .34005 .68313 L .3197 .67049 L p .707 .577 .707 r
F P
0 g
s
.3197 .67049 m .33193 .61769 L .35229 .63033 L p .707 .577 .707 r
F P
0 g
s
.34641 .69649 m .34398 .7332 L .32298 .72488 L p .707 .577 .707 r
F P
0 g
s
.32298 .72488 m .32542 .68817 L .34641 .69649 L p .707 .577 .707 r
F P
0 g
s
.33593 .76779 m .33837 .73108 L .31435 .73578 L p .707 .577 .707 r
F P
0 g
s
.35333 .74892 m .35582 .76535 L p .33542 .76542 L .707 .577 .707 r
F P
0 g
s
.36125 .76728 m .36406 .78587 L .3712 .77827 L p .707 .577 .707 r
F P
0 g
s
.3712 .77827 m .36839 .75968 L .36125 .76728 L p .707 .577 .707 r
F P
0 g
s
.36182 .71535 m .35939 .75206 L .35652 .74257 L p .707 .577 .707 r
F P
0 g
s
.35133 .78995 m .36271 .79803 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .36566 .75335 L .36799 .77177 L .707 .577 .707 r
F
.35713 .76605 m .36144 .75964 L .36402 .76968 L F
.36144 .75964 m .36566 .75335 L .36402 .76968 L F
.36566 .75335 m .36847 .77195 L .36799 .77177 L p F P
0 g
s
.36402 .76968 m .36271 .79803 L .37222 .80154 L p .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .35582 .76535 L .35133 .78995 L .707 .577 .707 r
F
.35209 .69593 m .36433 .64313 L .36687 .65483 L p F P
0 g
s
.35333 .74892 m .36566 .75335 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36803 .28659 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36271 .79803 m .36402 .76968 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .38577 .29919 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.35614 .76752 m .35582 .76535 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.35582 .76535 m .35333 .74892 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36799 .77177 m .35614 .76752 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36839 .75968 m .3712 .77827 L .36847 .77195 L p .707 .577 .707 r
F P
0 g
s
.36847 .77195 m .36566 .75335 L .36839 .75968 L p .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36402 .76968 L p .3924 .80898 L .707 .577 .707 r
F P
0 g
s
.37222 .80154 m .3924 .80898 L p .36402 .76968 L .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .36349 .72327 L .35582 .76535 L .707 .577 .707 r
F
.35582 .76535 m .35614 .76752 L .35543 .76745 L p F P
0 g
s
.35543 .76745 m .33542 .76542 L p .35582 .76535 L .707 .577 .707 r
F P
0 g
s
.33542 .76542 m .33261 .74682 L .35333 .74892 L p .707 .577 .707 r
F P
0 g
s
.36803 .28659 m .34497 .78544 L .35133 .78995 L p .707 .577 .707 r
F P
0 g
s
.35652 .74257 m .35896 .70586 L .36182 .71535 L p .707 .577 .707 r
F P
0 g
s
.36349 .72327 m .36803 .28659 L .35133 .78995 L .707 .577 .707 r
F
.3409 .77244 m .34497 .78544 L p .35541 .5041 L F P
0 g
s
.36396 .2736 m .35578 .45063 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35578 .45063 m .3409 .77244 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.34497 .78544 m .35496 .56935 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35496 .56935 m .36243 .40758 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.36243 .40758 m .36803 .28659 L .36406 .2739 L p .707 .577 .707 r
F P
0 g
s
.36406 .2739 m .36396 .2736 L p .36243 .40758 L .707 .577 .707 r
F P
0 g
s
.26324 .81383 m .26043 .79524 L .22962 .79816 L p .707 .577 .707 r
F P
0 g
s
.26043 .79524 m .26324 .81383 L .29474 .8087 L p .707 .577 .707 r
F P
0 g
s
.29474 .8087 m .29194 .79011 L .26043 .79524 L p .707 .577 .707 r
F P
0 g
s
.29194 .79011 m .29474 .8087 L .32387 .80187 L p .707 .577 .707 r
F P
0 g
s
.32387 .80187 m .32106 .78327 L .29194 .79011 L p .707 .577 .707 r
F P
0 g
s
.18232 .63344 m .17008 .68624 L .19044 .69888 L p .707 .577 .707 r
F P
0 g
s
.31435 .73578 m .31191 .77249 L .33593 .76779 L p .707 .577 .707 r
F P
0 g
s
.17008 .68624 m .18232 .63344 L .17028 .62064 L p .707 .577 .707 r
F P
0 g
s
.22962 .79816 m .23243 .81676 L .26324 .81383 L p .707 .577 .707 r
F P
0 g
s
.19475 .72616 m .19231 .76287 L .2197 .76933 L p .707 .577 .707 r
F P
0 g
s
.67494 .65328 m .66271 .70608 L .63602 .69482 L p .707 .577 .707 r
F P
0 g
s
.63602 .69482 m .64826 .64202 L .67494 .65328 L p .707 .577 .707 r
F P
0 g
s
.68942 .73637 m .68699 .77307 L .66599 .76475 L p .707 .577 .707 r
F P
0 g
s
.66599 .76475 m .66843 .72805 L .68942 .73637 L p .707 .577 .707 r
F P
0 g
s
.23243 .81676 m .22962 .79816 L .20253 .79859 L p .707 .577 .707 r
F P
0 g
s
.19231 .76287 m .19475 .72616 L .17375 .71784 L p .707 .577 .707 r
F P
0 g
s
.20253 .79859 m .20534 .81719 L .23243 .81676 L p .707 .577 .707 r
F P
0 g
s
.32106 .78327 m .32387 .80187 L .34775 .79401 L p .707 .577 .707 r
F P
0 g
s
.69634 .78019 m .69915 .79879 L .67843 .79669 L p .707 .577 .707 r
F P
0 g
s
.67843 .79669 m .67562 .77809 L .69634 .78019 L p .707 .577 .707 r
F P
0 g
s
.17375 .71784 m .17132 .75455 L .19231 .76287 L p .707 .577 .707 r
F P
0 g
s
.64152 .30343 m .61846 .80227 L .62847 .79014 L p .707 .577 .707 r
F P
0 g
s
.62847 .79014 m .65153 .2913 L .64152 .30343 L p .707 .577 .707 r
F P
0 g
s
.17028 .62064 m .15804 .67344 L .17008 .68624 L p .707 .577 .707 r
F P
0 g
s
.20534 .81719 m .20253 .79859 L .1818 .79649 L p .707 .577 .707 r
F P
0 g
s
.1818 .79649 m .18461 .81509 L .20534 .81719 L p .707 .577 .707 r
F P
0 g
s
.66843 .72805 m .66599 .76475 L .6386 .75829 L p .707 .577 .707 r
F P
0 g
s
.6386 .75829 m .64104 .72159 L .66843 .72805 L p .707 .577 .707 r
F P
0 g
s
.15804 .67344 m .17028 .62064 L .16774 .60894 L p .707 .577 .707 r
F P
0 g
s
.17132 .75455 m .17375 .71784 L .16121 .70848 L p .707 .577 .707 r
F P
0 g
s
.67562 .77809 m .67843 .79669 L .65133 .79712 L p .707 .577 .707 r
F P
0 g
s
.65133 .79712 m .64852 .77852 L .67562 .77809 L p .707 .577 .707 r
F P
0 g
s
.16121 .70848 m .15877 .74518 L .17132 .75455 L p .707 .577 .707 r
F P
0 g
s
.18461 .81509 m .1818 .79649 L .16947 .79206 L p .707 .577 .707 r
F P
0 g
s
.16774 .60894 m .1555 .66174 L .15804 .67344 L p .707 .577 .707 r
F P
0 g
s
.16947 .79206 m .17228 .81066 L .18461 .81509 L p .707 .577 .707 r
F P
0 g
s
.64852 .77852 m .65133 .79712 L .62053 .80005 L p .707 .577 .707 r
F P
0 g
s
.15877 .74518 m .16121 .70848 L .15835 .69898 L p .707 .577 .707 r
F P
0 g
s
.1555 .66174 m .16774 .60894 L .17494 .59949 L p .707 .577 .707 r
F P
0 g
s
.65153 .2913 m .62847 .79014 L .6244 .77714 L p .707 .577 .707 r
F P
0 g
s
.6244 .77714 m .64746 .2783 L .65153 .2913 L p .707 .577 .707 r
F P
0 g
s
.15835 .69898 m .15591 .73569 L .15877 .74518 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.3409 .77244 m .36396 .2736 L .37397 .26146 L p .707 .577 .707 r
F P
0 g
s
.17228 .81066 m .16947 .79206 L .16674 .78573 L p .707 .577 .707 r
F P
0 g
s
.17494 .59949 m .16271 .65229 L .1555 .66174 L p .707 .577 .707 r
F P
0 g
s
.16674 .78573 m .16955 .80433 L .17228 .81066 L p .707 .577 .707 r
F P
0 g
s
.15591 .73569 m .15835 .69898 L .16544 .69029 L p .707 .577 .707 r
F P
0 g
s
.16271 .65229 m .17494 .59949 L .19119 .59321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16544 .69029 m .163 .727 L .15591 .73569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64746 .2783 m .6244 .77714 L .60666 .76455 L p .707 .577 .707 r
F P
0 g
s
.60666 .76455 m .62971 .26571 L .64746 .2783 L p .707 .577 .707 r
F P
0 g
s
.19119 .59321 m .17896 .64601 L .16271 .65229 L p .707 .577 .707 r
F P
0 g
s
.16955 .80433 m .16674 .78573 L .17388 .77813 L p .707 .577 .707 r
F P
0 g
s
.17388 .77813 m .17669 .79673 L .16955 .80433 L p .707 .577 .707 r
F P
0 g
s
.17896 .64601 m .19119 .59321 L .21489 .59072 L p .707 .577 .707 r
F P
0 g
s
.163 .727 m .16544 .69029 L .1818 .68325 L p .707 .577 .707 r
F P
0 g
s
.35091 .76031 m .37397 .26146 L .39707 .25139 L p .707 .577 .707 r
F P
0 g
s
.37397 .26146 m .35091 .76031 L .3409 .77244 L p .707 .577 .707 r
F P
0 g
s
.1818 .68325 m .17936 .71996 L .163 .727 L p .707 .577 .707 r
F P
0 g
s
.21489 .59072 m .20265 .64352 L .17896 .64601 L p .707 .577 .707 r
F P
0 g
s
.20265 .64352 m .21489 .59072 L .24372 .59225 L p .707 .577 .707 r
F P
0 g
s
.33193 .61769 m .3197 .67049 L .29301 .65923 L p .707 .577 .707 r
F P
0 g
s
.29301 .65923 m .30525 .60643 L .33193 .61769 L p .707 .577 .707 r
F P
0 g
s
.17669 .79673 m .17388 .77813 L .19019 .77 L p .707 .577 .707 r
F P
0 g
s
.19019 .77 m .193 .7886 L .17669 .79673 L p .707 .577 .707 r
F P
0 g
s
.62971 .26571 m .60666 .76455 L .57697 .7536 L p .707 .577 .707 r
F P
0 g
s
.57697 .7536 m .60003 .25475 L .62971 .26571 L p .707 .577 .707 r
F P
0 g
s
.17936 .71996 m .1818 .68325 L .20582 .67855 L p .707 .577 .707 r
F P
0 g
s
.23148 .64505 m .24372 .59225 L .27485 .59767 L p .707 .577 .707 r
F P
0 g
s
.24372 .59225 m .23148 .64505 L .20265 .64352 L p .707 .577 .707 r
F P
0 g
s
.30525 .60643 m .29301 .65923 L .26262 .65047 L p .707 .577 .707 r
F P
0 g
s
.26262 .65047 m .27485 .59767 L .30525 .60643 L p .707 .577 .707 r
F P
0 g
s
.27485 .59767 m .26262 .65047 L .23148 .64505 L p .707 .577 .707 r
F P
0 g
s
.20582 .67855 m .20338 .71526 L .17936 .71996 L p .707 .577 .707 r
F P
0 g
s
.39707 .25139 m .37401 .75023 L .35091 .76031 L p .707 .577 .707 r
F P
0 g
s
.37401 .75023 m .39707 .25139 L .431 .24435 L p .707 .577 .707 r
F P
0 g
s
.32542 .68817 m .32298 .72488 L .29559 .71842 L p .707 .577 .707 r
F P
0 g
s
.29559 .71842 m .29803 .68171 L .32542 .68817 L p .707 .577 .707 r
F P
0 g
s
.72773 .66246 m .73997 .60966 L .70957 .60089 L p .707 .577 .707 r
F P
0 g
s
.73997 .60966 m .72773 .66246 L .75887 .66787 L p .707 .577 .707 r
F P
0 g
s
.75887 .66787 m .7711 .61507 L .73997 .60966 L p .707 .577 .707 r
F P
0 g
s
.20338 .71526 m .20582 .67855 L .23515 .67665 L p .707 .577 .707 r
F P
0 g
s
.193 .7886 m .19019 .77 L .21408 .76213 L p .707 .577 .707 r
F P
0 g
s
.69734 .65369 m .70957 .60089 L .68289 .58964 L p .707 .577 .707 r
F P
0 g
s
.70957 .60089 m .69734 .65369 L .72773 .66246 L p .707 .577 .707 r
F P
0 g
s
.7711 .61507 m .75887 .66787 L .7877 .6694 L p .707 .577 .707 r
F P
0 g
s
.7877 .6694 m .79993 .6166 L .7711 .61507 L p .707 .577 .707 r
F P
0 g
s
.21408 .76213 m .21689 .78073 L .193 .7886 L p .707 .577 .707 r
F P
0 g
s
.33261 .74682 m .33542 .76542 L .30832 .76585 L p .707 .577 .707 r
F P
0 g
s
.30832 .76585 m .30551 .74725 L .33261 .74682 L p .707 .577 .707 r
F P
0 g
s
.29803 .68171 m .29559 .71842 L .26449 .71445 L p .707 .577 .707 r
F P
0 g
s
.26449 .71445 m .26693 .67774 L .29803 .68171 L p .707 .577 .707 r
F P
0 g
s
.60003 .25475 m .57697 .7536 L .53826 .74535 L p .707 .577 .707 r
F P
0 g
s
.53826 .74535 m .56131 .24651 L .60003 .25475 L p .707 .577 .707 r
F P
0 g
s
.23515 .67665 m .23272 .71336 L .20338 .71526 L p .707 .577 .707 r
F P
0 g
s
.23272 .71336 m .23515 .67665 L .26693 .67774 L p .707 .577 .707 r
F P
0 g
s
.67065 .64244 m .68289 .58964 L .66253 .57699 L p .707 .577 .707 r
F P
0 g
s
.68289 .58964 m .67065 .64244 L .69734 .65369 L p .707 .577 .707 r
F P
0 g
s
.79993 .6166 m .7877 .6694 L .81139 .66691 L p .707 .577 .707 r
F P
0 g
s
.81139 .66691 m .82363 .61411 L .79993 .6166 L p .707 .577 .707 r
F P
0 g
s
.26693 .67774 m .26449 .71445 L .23272 .71336 L p .707 .577 .707 r
F P
0 g
s
.40795 .74319 m .431 .24435 L .47245 .24104 L p .707 .577 .707 r
F P
0 g
s
.431 .24435 m .40795 .74319 L .37401 .75023 L p .707 .577 .707 r
F P
0 g
s
.73102 .72113 m .73346 .68443 L .70235 .68046 L p .707 .577 .707 r
F P
0 g
s
.73346 .68443 m .73102 .72113 L .76279 .72222 L p .707 .577 .707 r
F P
0 g
s
.76279 .72222 m .76523 .68552 L .73346 .68443 L p .707 .577 .707 r
F P
0 g
s
.21689 .78073 m .21408 .76213 L .2432 .7553 L p .707 .577 .707 r
F P
0 g
s
.76523 .68552 m .76279 .72222 L .79213 .72032 L p .707 .577 .707 r
F P
0 g
s
.79213 .72032 m .79456 .68362 L .76523 .68552 L p .707 .577 .707 r
F P
0 g
s
.2432 .7553 m .24601 .7739 L .21689 .78073 L p .707 .577 .707 r
F P
0 g
s
.30551 .74725 m .30832 .76585 L .27752 .76877 L p .707 .577 .707 r
F P
0 g
s
.27752 .76877 m .27471 .75017 L .30551 .74725 L p .707 .577 .707 r
F P
0 g
s
.69991 .71716 m .70235 .68046 L .67496 .674 L p .707 .577 .707 r
F P
0 g
s
.70235 .68046 m .69991 .71716 L .73102 .72113 L p .707 .577 .707 r
F P
0 g
s
.74345 .75307 m .74064 .73447 L .70983 .7374 L p .707 .577 .707 r
F P
0 g
s
.74064 .73447 m .74345 .75307 L .77496 .74794 L p .707 .577 .707 r
F P
0 g
s
.77496 .74794 m .77215 .72934 L .74064 .73447 L p .707 .577 .707 r
F P
0 g
s
.24601 .7739 m .2432 .7553 L .27471 .75017 L p .707 .577 .707 r
F P
0 g
s
.77215 .72934 m .77496 .74794 L .80408 .74111 L p .707 .577 .707 r
F P
0 g
s
.80408 .74111 m .80127 .72251 L .77215 .72934 L p .707 .577 .707 r
F P
0 g
s
.56131 .24651 m .53826 .74535 L .49429 .74063 L p .707 .577 .707 r
F P
0 g
s
.49429 .74063 m .51735 .24178 L .56131 .24651 L p .707 .577 .707 r
F P
0 g
s
.27471 .75017 m .27752 .76877 L .24601 .7739 L p .707 .577 .707 r
F P
0 g
s
.66253 .57699 m .6503 .62979 L .67065 .64244 L p .707 .577 .707 r
F P
0 g
s
.70983 .7374 m .71264 .75599 L .74345 .75307 L p .707 .577 .707 r
F P
0 g
s
.6503 .62979 m .66253 .57699 L .65049 .56419 L p .707 .577 .707 r
F P
0 g
s
.79456 .68362 m .79213 .72032 L .81615 .71563 L p .707 .577 .707 r
F P
0 g
s
.81615 .71563 m .81858 .67892 L .79456 .68362 L p .707 .577 .707 r
F P
0 g
s
.82363 .61411 m .81139 .66691 L .82764 .66063 L p .707 .577 .707 r
F P
0 g
s
.82764 .66063 m .83988 .60783 L .82363 .61411 L p .707 .577 .707 r
F P
0 g
s
.67496 .674 m .67252 .7107 L .69991 .71716 L p .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .45925 .52659 L .48577 .47325 L .707 .577 .707 r
F
.43195 .71667 m .45101 .7122 L p .45012 .71163 L F P
0 g
s
.47245 .24104 m .45376 .64546 L p .41122 .71767 L .707 .577 .707 r
F P
0 g
s
.45376 .64546 m .4507 .71154 L p .43162 .7145 L .707 .577 .707 r
F P
0 g
s
.41122 .71767 m .45376 .64546 L .43162 .7145 L .707 .577 .707 r
F
.44939 .73988 m .40795 .74319 L p .41122 .71767 L F P
0 g
s
.43087 .71684 m .43195 .71667 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.43162 .7145 m .43195 .71667 L p .45012 .71163 L .707 .577 .707 r
F P
0 g
s
.44767 .7049 m .42914 .69807 L .45101 .7122 L .707 .577 .707 r
F
.4507 .71154 m .44939 .73988 L p .42756 .72717 L F P
0 g
s
.41122 .71767 m .43162 .7145 L .42756 .72717 L .707 .577 .707 r
F
.43195 .71667 m .43162 .7145 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .4507 .71154 L .42756 .72717 L .707 .577 .707 r
F
.42914 .69807 m .39763 .7032 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .42914 .69807 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.39763 .7032 m .40044 .7218 L .43087 .71684 L p .707 .577 .707 r
F P
0 g
s
.43104 .71631 m .39763 .7032 L .43087 .71684 L .707 .577 .707 r
F
.42914 .69807 m .43162 .7145 L p .45012 .71163 L F P
0 g
s
.44939 .73988 m .4507 .71154 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.4507 .71154 m .45925 .52659 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.51735 .24178 m .49429 .74063 L .46378 .74012 L p .707 .577 .707 r
F P
0 g
s
.46378 .74012 m .44939 .73988 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .51735 .24178 L .46378 .74012 L .707 .577 .707 r
F
.46107 .70983 m .45826 .69124 L .44305 .6948 L p F P
0 g
s
.44305 .6948 m .42914 .69807 L p .44767 .7049 L .707 .577 .707 r
F P
0 g
s
.46107 .70983 m .44305 .6948 L .44767 .7049 L .707 .577 .707 r
F
.45101 .7122 m .46107 .70983 L p .44767 .7049 L F P
0 g
s
.44469 .63381 m .45692 .58101 L .43283 .57973 L p .707 .577 .707 r
F P
0 g
s
.43283 .57973 m .42809 .57948 L p .42995 .58554 L .707 .577 .707 r
F P
0 g
s
.44469 .63381 m .43283 .57973 L .42995 .58554 L .707 .577 .707 r
F
.47245 .24104 m .51735 .24178 L p .48577 .47325 L F P
0 g
s
.45925 .52659 m .47245 .24104 L p .48577 .47325 L .707 .577 .707 r
F P
0 g
s
.71264 .75599 m .70983 .7374 L .68274 .73783 L p .707 .577 .707 r
F P
0 g
s
.67252 .7107 m .67496 .674 L .65397 .66568 L p .707 .577 .707 r
F P
0 g
s
.68274 .73783 m .68555 .75643 L .71264 .75599 L p .707 .577 .707 r
F P
0 g
s
.80127 .72251 m .80408 .74111 L .82796 .73324 L p .707 .577 .707 r
F P
0 g
s
.82796 .73324 m .82515 .71464 L .80127 .72251 L p .707 .577 .707 r
F P
0 g
s
.65397 .66568 m .65153 .70238 L .67252 .7107 L p .707 .577 .707 r
F P
0 g
s
.65049 .56419 m .63826 .61699 L .6503 .62979 L p .707 .577 .707 r
F P
0 g
s
.68555 .75643 m .68274 .73783 L .66202 .73573 L p .707 .577 .707 r
F P
0 g
s
.81858 .67892 m .81615 .71563 L .83251 .70859 L p .707 .577 .707 r
F P
0 g
s
.83251 .70859 m .83494 .67188 L .81858 .67892 L p .707 .577 .707 r
F P
0 g
s
.66202 .73573 m .66482 .75432 L .68555 .75643 L p .707 .577 .707 r
F P
0 g
s
.63826 .61699 m .65049 .56419 L .64795 .5525 L p .707 .577 .707 r
F P
0 g
s
.83988 .60783 m .82764 .66063 L .83485 .65118 L p .707 .577 .707 r
F P
0 g
s
.83485 .65118 m .84708 .59838 L .83988 .60783 L p .707 .577 .707 r
F P
0 g
s
.82515 .71464 m .82796 .73324 L .84428 .72511 L p .707 .577 .707 r
F P
0 g
s
.84428 .72511 m .84147 .70651 L .82515 .71464 L p .707 .577 .707 r
F P
0 g
s
.65153 .70238 m .65397 .66568 L .64142 .65631 L p .707 .577 .707 r
F P
0 g
s
.64142 .65631 m .63899 .69302 L .65153 .70238 L p .707 .577 .707 r
F P
0 g
s
.66482 .75432 m .66202 .73573 L .64968 .73129 L p .707 .577 .707 r
F P
0 g
s
.64795 .5525 m .63572 .6053 L .63826 .61699 L p .707 .577 .707 r
F P
0 g
s
.83494 .67188 m .83251 .70859 L .8396 .69989 L p .707 .577 .707 r
F P
0 g
s
.8396 .69989 m .84204 .66319 L .83494 .67188 L p .707 .577 .707 r
F P
0 g
s
.64968 .73129 m .65249 .74989 L .66482 .75432 L p .707 .577 .707 r
F P
0 g
s
.84147 .70651 m .84428 .72511 L .85142 .71751 L p .707 .577 .707 r
F P
0 g
s
.85142 .71751 m .84861 .69891 L .84147 .70651 L p .707 .577 .707 r
F P
0 g
s
.63899 .69302 m .64142 .65631 L .63856 .64682 L p .707 .577 .707 r
F P
0 g
s
.63572 .6053 m .64795 .5525 L .65516 .54304 L p .707 .577 .707 r
F P
0 g
s
.84708 .59838 m .83485 .65118 L .83231 .63948 L p .707 .577 .707 r
F P
0 g
s
.83231 .63948 m .84454 .58668 L .84708 .59838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63856 .64682 m .63612 .68352 L .63899 .69302 L p .707 .577 .707 r
F P
0 g
s
.65249 .74989 m .64968 .73129 L .64696 .72497 L p .707 .577 .707 r
F P
0 g
s
.65516 .54304 m .64292 .59584 L .63572 .6053 L p .707 .577 .707 r
F P
0 g
s
.84204 .66319 m .8396 .69989 L .83673 .6904 L p .707 .577 .707 r
F P
0 g
s
.83673 .6904 m .83917 .65369 L .84204 .66319 L p .707 .577 .707 r
F P
0 g
s
.64696 .72497 m .64977 .74357 L .65249 .74989 L p .707 .577 .707 r
F P
0 g
s
.84861 .69891 m .85142 .71751 L .84869 .71118 L p .707 .577 .707 r
F P
0 g
s
.84869 .71118 m .84588 .69259 L .84861 .69891 L p .707 .577 .707 r
F P
0 g
s
.64292 .59584 m .65516 .54304 L .6714 .53676 L p .707 .577 .707 r
F P
0 g
s
.63612 .68352 m .63856 .64682 L .64565 .63813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84454 .58668 m .83231 .63948 L .82027 .62668 L p .707 .577 .707 r
F P
0 g
s
.82027 .62668 m .8325 .57388 L .84454 .58668 L p .707 .577 .707 r
F P
0 g
s
.38472 .62687 m .39696 .57407 L .36656 .5653 L p .707 .577 .707 r
F P
0 g
s
.39696 .57407 m .38472 .62687 L .41586 .63228 L p .707 .577 .707 r
F P
0 g
s
.41586 .63228 m .42809 .57948 L .39696 .57407 L p .707 .577 .707 r
F P
0 g
s
.64565 .63813 m .64322 .67483 L .63612 .68352 L p .707 .577 .707 r
F P
0 g
s
.35433 .6181 m .36656 .5653 L .33988 .55405 L p .707 .577 .707 r
F P
0 g
s
.36656 .5653 m .35433 .6181 L .38472 .62687 L p .707 .577 .707 r
F P
0 g
s
.42809 .57948 m .41586 .63228 L .44469 .63381 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64977 .74357 m .64696 .72497 L .6541 .71737 L p .707 .577 .707 r
F P
0 g
s
.6714 .53676 m .65917 .58956 L .64292 .59584 L p .707 .577 .707 r
F P
0 g
s
.83917 .65369 m .83673 .6904 L .82419 .68104 L p .707 .577 .707 r
F P
0 g
s
.82419 .68104 m .82663 .64433 L .83917 .65369 L p .707 .577 .707 r
F P
0 g
s
.6541 .71737 m .65691 .73597 L .64977 .74357 L p .707 .577 .707 r
F P
0 g
s
.32764 .60685 m .33988 .55405 L .31952 .5414 L p .707 .577 .707 r
F P
0 g
s
.33988 .55405 m .32764 .60685 L .35433 .6181 L p .707 .577 .707 r
F P
0 g
s
.45692 .58101 m .44469 .63381 L .46838 .63132 L p .707 .577 .707 r
F P
0 g
s
.46838 .63132 m .48062 .57852 L .45692 .58101 L p .707 .577 .707 r
F P
0 g
s
.65917 .58956 m .6714 .53676 L .6951 .53427 L p .707 .577 .707 r
F P
0 g
s
.8325 .57388 m .82027 .62668 L .79991 .61404 L p .707 .577 .707 r
F P
0 g
s
.79991 .61404 m .81215 .56124 L .8325 .57388 L p .707 .577 .707 r
F P
0 g
s
.38801 .68126 m .39045 .64455 L .35934 .64058 L p .707 .577 .707 r
F P
0 g
s
.39045 .64455 m .38801 .68126 L .41978 .68235 L p .707 .577 .707 r
F P
0 g
s
.41978 .68235 m .42222 .64564 L .39045 .64455 L p .707 .577 .707 r
F P
0 g
s
.84588 .69259 m .84869 .71118 L .83636 .70675 L p .707 .577 .707 r
F P
0 g
s
.83636 .70675 m .83355 .68816 L .84588 .69259 L p .707 .577 .707 r
F P
0 g
s
.64322 .67483 m .64565 .63813 L .66201 .63109 L p .707 .577 .707 r
F P
0 g
s
.42222 .64564 m .41978 .68235 L .44912 .68045 L p .707 .577 .707 r
F P
0 g
s
.44912 .68045 m .45155 .64374 L .42222 .64564 L p .707 .577 .707 r
F P
0 g
s
.3569 .67729 m .35934 .64058 L .33195 .63412 L p .707 .577 .707 r
F P
0 g
s
.35934 .64058 m .3569 .67729 L .38801 .68126 L p .707 .577 .707 r
F P
0 g
s
.66201 .63109 m .65957 .66779 L .64322 .67483 L p .707 .577 .707 r
F P
0 g
s
.40044 .7218 m .39763 .7032 L .36682 .70612 L p .707 .577 .707 r
F P
0 g
s
.31952 .5414 m .30729 .5942 L .32764 .60685 L p .707 .577 .707 r
F P
0 g
s
.45155 .64374 m .44912 .68045 L .47314 .67575 L p .707 .577 .707 r
F P
0 g
s
.47314 .67575 m .47557 .63905 L .45155 .64374 L p .707 .577 .707 r
F P
0 g
s
.30729 .5942 m .31952 .5414 L .30748 .5286 L p .707 .577 .707 r
F P
0 g
s
.6951 .53427 m .68287 .58707 L .65917 .58956 L p .707 .577 .707 r
F P
0 g
s
.36682 .70612 m .36963 .72472 L .40044 .7218 L p .707 .577 .707 r
F P
0 g
s
.33195 .63412 m .32951 .67083 L .3569 .67729 L p .707 .577 .707 r
F P
0 g
s
.48062 .57852 m .46838 .63132 L .48463 .62504 L p .707 .577 .707 r
F P
0 g
s
.48463 .62504 m .49687 .57224 L .48062 .57852 L p .707 .577 .707 r
F P
0 g
s
.68287 .58707 m .6951 .53427 L .72393 .5358 L p .707 .577 .707 r
F P
0 g
s
.81215 .56124 m .79991 .61404 L .77323 .60278 L p .707 .577 .707 r
F P
0 g
s
.77323 .60278 m .78546 .54998 L .81215 .56124 L p .707 .577 .707 r
F P
0 g
s
.65691 .73597 m .6541 .71737 L .67041 .70924 L p .707 .577 .707 r
F P
0 g
s
.82663 .64433 m .82419 .68104 L .8032 .67272 L p .707 .577 .707 r
F P
0 g
s
.8032 .67272 m .80563 .63601 L .82663 .64433 L p .707 .577 .707 r
F P
0 g
s
.36963 .72472 m .36682 .70612 L .33973 .70655 L p .707 .577 .707 r
F P
0 g
s
.32951 .67083 m .33195 .63412 L .31096 .6258 L p .707 .577 .707 r
F P
0 g
s
.67041 .70924 m .67322 .72784 L .65691 .73597 L p .707 .577 .707 r
F P
0 g
s
.33973 .70655 m .34254 .72515 L .36963 .72472 L p .707 .577 .707 r
F P
0 g
s
.45826 .69124 m .46107 .70983 L .48495 .70197 L p .707 .577 .707 r
F P
0 g
s
.48495 .70197 m .48214 .68337 L .45826 .69124 L p .707 .577 .707 r
F P
0 g
s
.65957 .66779 m .66201 .63109 L .68603 .62639 L p .707 .577 .707 r
F P
0 g
s
.83355 .68816 m .83636 .70675 L .81563 .70465 L p .707 .577 .707 r
F P
0 g
s
.81563 .70465 m .81282 .68605 L .83355 .68816 L p .707 .577 .707 r
F P
0 g
s
.71169 .5886 m .72393 .5358 L .75507 .54122 L p .707 .577 .707 r
F P
0 g
s
.72393 .5358 m .71169 .5886 L .68287 .58707 L p .707 .577 .707 r
F P
0 g
s
.78546 .54998 m .77323 .60278 L .74283 .59402 L p .707 .577 .707 r
F P
0 g
s
.74283 .59402 m .75507 .54122 L .78546 .54998 L p .707 .577 .707 r
F P
0 g
s
.31096 .6258 m .30852 .66251 L .32951 .67083 L p .707 .577 .707 r
F P
0 g
s
.47557 .63905 m .47314 .67575 L .4895 .66871 L p .707 .577 .707 r
F P
0 g
s
.4895 .66871 m .49193 .63201 L .47557 .63905 L p .707 .577 .707 r
F P
0 g
s
.30748 .5286 m .29525 .5814 L .30729 .5942 L p .707 .577 .707 r
F P
0 g
s
.75507 .54122 m .74283 .59402 L .71169 .5886 L p .707 .577 .707 r
F P
0 g
s
.34254 .72515 m .33973 .70655 L .31901 .70445 L p .707 .577 .707 r
F P
0 g
s
.68603 .62639 m .6836 .66309 L .65957 .66779 L p .707 .577 .707 r
F P
0 g
s
.31901 .70445 m .32181 .72305 L .34254 .72515 L p .707 .577 .707 r
F P
0 g
s
.80563 .63601 m .8032 .67272 L .77581 .66625 L p .707 .577 .707 r
F P
0 g
s
.77581 .66625 m .77824 .62955 L .80563 .63601 L p .707 .577 .707 r
F P
0 g
s
.29525 .5814 m .30748 .5286 L .30494 .51691 L p .707 .577 .707 r
F P
0 g
s
.30852 .66251 m .31096 .6258 L .29841 .61644 L p .707 .577 .707 r
F P
0 g
s
.49687 .57224 m .48463 .62504 L .49184 .61559 L p .707 .577 .707 r
F P
0 g
s
.49184 .61559 m .50407 .56279 L .49687 .57224 L p .707 .577 .707 r
F P
0 g
s
.67322 .72784 m .67041 .70924 L .69429 .70137 L p .707 .577 .707 r
F P
0 g
s
.48214 .68337 m .48495 .70197 L .50127 .69384 L p .707 .577 .707 r
F P
0 g
s
.50127 .69384 m .49846 .67524 L .48214 .68337 L p .707 .577 .707 r
F P
0 g
s
.6836 .66309 m .68603 .62639 L .71537 .62449 L p .707 .577 .707 r
F P
0 g
s
.69429 .70137 m .6971 .71997 L .67322 .72784 L p .707 .577 .707 r
F P
0 g
s
.81282 .68605 m .81563 .70465 L .78854 .70508 L p .707 .577 .707 r
F P
0 g
s
.78854 .70508 m .78573 .68649 L .81282 .68605 L p .707 .577 .707 r
F P
0 g
s
.29841 .61644 m .29598 .65314 L .30852 .66251 L p .707 .577 .707 r
F P
0 g
s
.77824 .62955 m .77581 .66625 L .7447 .66228 L p .707 .577 .707 r
F P
0 g
s
.7447 .66228 m .74714 .62558 L .77824 .62955 L p .707 .577 .707 r
F P
0 g
s
.71537 .62449 m .71293 .6612 L .6836 .66309 L p .707 .577 .707 r
F P
0 g
s
.71293 .6612 m .71537 .62449 L .74714 .62558 L p .707 .577 .707 r
F P
0 g
s
.32181 .72305 m .31901 .70445 L .30667 .70002 L p .707 .577 .707 r
F P
0 g
s
.49193 .63201 m .4895 .66871 L .49659 .66002 L p .707 .577 .707 r
F P
0 g
s
.49659 .66002 m .49903 .62331 L .49193 .63201 L p .707 .577 .707 r
F P
0 g
s
.30494 .51691 m .29271 .56971 L .29525 .5814 L p .707 .577 .707 r
F P
0 g
s
.74714 .62558 m .7447 .66228 L .71293 .6612 L p .707 .577 .707 r
F P
0 g
s
.6971 .71997 m .69429 .70137 L .72341 .69454 L p .707 .577 .707 r
F P
0 g
s
.30667 .70002 m .30948 .71862 L .32181 .72305 L p .707 .577 .707 r
F P
0 g
s
.72341 .69454 m .72622 .71314 L .6971 .71997 L p .707 .577 .707 r
F P
0 g
s
.78573 .68649 m .78854 .70508 L .75773 .70801 L p .707 .577 .707 r
F P
0 g
s
.75773 .70801 m .75492 .68941 L .78573 .68649 L p .707 .577 .707 r
F P
0 g
s
.29598 .65314 m .29841 .61644 L .29555 .60694 L p .707 .577 .707 r
F P
0 g
s
.49846 .67524 m .50127 .69384 L .50841 .68623 L p .707 .577 .707 r
F P
0 g
s
.50841 .68623 m .5056 .66764 L .49846 .67524 L p .707 .577 .707 r
F P
0 g
s
.29271 .56971 m .30494 .51691 L .31215 .50745 L p .707 .577 .707 r
F P
0 g
s
.50407 .56279 m .49184 .61559 L .4893 .60389 L p .707 .577 .707 r
F P
0 g
s
.4893 .60389 m .50153 .55109 L .50407 .56279 L p .707 .577 .707 r
F P
0 g
s
.72622 .71314 m .72341 .69454 L .75492 .68941 L p .707 .577 .707 r
F P
0 g
s
.75492 .68941 m .75773 .70801 L .72622 .71314 L p .707 .577 .707 r
F P
0 g
s
.29555 .60694 m .29311 .64365 L .29598 .65314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30948 .71862 m .30667 .70002 L .30395 .6937 L p .707 .577 .707 r
F P
0 g
s
.49903 .62331 m .49659 .66002 L .49372 .65053 L p .707 .577 .707 r
F P
0 g
s
.49372 .65053 m .49616 .61382 L .49903 .62331 L p .707 .577 .707 r
F P
0 g
s
.31215 .50745 m .29991 .56025 L .29271 .56971 L p .707 .577 .707 r
F P
0 g
s
.30395 .6937 m .30675 .71229 L .30948 .71862 L p .707 .577 .707 r
F P
0 g
s
.29311 .64365 m .29555 .60694 L .30264 .59825 L p .707 .577 .707 r
F P
0 g
s
.5056 .66764 m .50841 .68623 L .50568 .67991 L p .707 .577 .707 r
F P
0 g
s
.50568 .67991 m .50287 .66131 L .5056 .66764 L p .707 .577 .707 r
F P
0 g
s
.29991 .56025 m .31215 .50745 L .32839 .50117 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50153 .55109 m .4893 .60389 L .47726 .59109 L p .707 .577 .707 r
F P
0 g
s
.47726 .59109 m .48949 .53829 L .50153 .55109 L p .707 .577 .707 r
F P
0 g
s
.30264 .59825 m .30021 .63496 L .29311 .64365 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32839 .50117 m .31616 .55397 L .29991 .56025 L p .707 .577 .707 r
F P
0 g
s
.30675 .71229 m .30395 .6937 L .31109 .6861 L p .707 .577 .707 r
F P
0 g
s
.49616 .61382 m .49372 .65053 L .48118 .64116 L p .707 .577 .707 r
F P
0 g
s
.48118 .64116 m .48362 .60445 L .49616 .61382 L p .707 .577 .707 r
F P
0 g
s
.31109 .6861 m .3139 .70469 L .30675 .71229 L p .707 .577 .707 r
F P
0 g
s
.31616 .55397 m .32839 .50117 L .35209 .49868 L p .707 .577 .707 r
F P
0 g
s
.48949 .53829 m .47726 .59109 L .4569 .57845 L p .707 .577 .707 r
F P
0 g
s
.4569 .57845 m .46914 .52565 L .48949 .53829 L p .707 .577 .707 r
F P
0 g
s
.30021 .63496 m .30264 .59825 L .319 .59121 L p .707 .577 .707 r
F P
0 g
s
.50287 .66131 m .50568 .67991 L .49335 .67548 L p .707 .577 .707 r
F P
0 g
s
.49335 .67548 m .49054 .65688 L .50287 .66131 L p .707 .577 .707 r
F P
0 g
s
.319 .59121 m .31656 .62792 L .30021 .63496 L p .707 .577 .707 r
F P
0 g
s
.35209 .49868 m .33986 .55148 L .31616 .55397 L p .707 .577 .707 r
F P
0 g
s
.33986 .55148 m .35209 .49868 L .38092 .50021 L p .707 .577 .707 r
F P
0 g
s
.48362 .60445 m .48118 .64116 L .46019 .63284 L p .707 .577 .707 r
F P
0 g
s
.46019 .63284 m .46262 .59613 L .48362 .60445 L p .707 .577 .707 r
F P
0 g
s
.46914 .52565 m .4569 .57845 L .43022 .56719 L p .707 .577 .707 r
F P
0 g
s
.43022 .56719 m .44245 .51439 L .46914 .52565 L p .707 .577 .707 r
F P
0 g
s
.3139 .70469 m .31109 .6861 L .3274 .67796 L p .707 .577 .707 r
F P
0 g
s
.3274 .67796 m .33021 .69656 L .3139 .70469 L p .707 .577 .707 r
F P
0 g
s
.31656 .62792 m .319 .59121 L .34302 .58651 L p .707 .577 .707 r
F P
0 g
s
.49054 .65688 m .49335 .67548 L .47262 .67338 L p .707 .577 .707 r
F P
0 g
s
.47262 .67338 m .46981 .65478 L .49054 .65688 L p .707 .577 .707 r
F P
0 g
s
.36868 .55301 m .38092 .50021 L .41206 .50563 L p .707 .577 .707 r
F P
0 g
s
.38092 .50021 m .36868 .55301 L .33986 .55148 L p .707 .577 .707 r
F P
0 g
s
.44245 .51439 m .43022 .56719 L .39982 .55843 L p .707 .577 .707 r
F P
0 g
s
.39982 .55843 m .41206 .50563 L .44245 .51439 L p .707 .577 .707 r
F P
0 g
s
.41206 .50563 m .39982 .55843 L .36868 .55301 L p .707 .577 .707 r
F P
0 g
s
.34302 .58651 m .34058 .62322 L .31656 .62792 L p .707 .577 .707 r
F P
0 g
s
.46262 .59613 m .46019 .63284 L .4328 .62638 L p .707 .577 .707 r
F P
0 g
s
.4328 .62638 m .43523 .58967 L .46262 .59613 L p .707 .577 .707 r
F P
0 g
s
.34058 .62322 m .34302 .58651 L .37236 .58461 L p .707 .577 .707 r
F P
0 g
s
.33021 .69656 m .3274 .67796 L .35128 .6701 L p .707 .577 .707 r
F P
0 g
s
.35128 .6701 m .35409 .68869 L .33021 .69656 L p .707 .577 .707 r
F P
0 g
s
.46981 .65478 m .47262 .67338 L .44553 .67381 L p .707 .577 .707 r
F P
0 g
s
.44553 .67381 m .44272 .65521 L .46981 .65478 L p .707 .577 .707 r
F P
0 g
s
.43523 .58967 m .4328 .62638 L .40169 .62241 L p .707 .577 .707 r
F P
0 g
s
.40169 .62241 m .40413 .5857 L .43523 .58967 L p .707 .577 .707 r
F P
0 g
s
.37236 .58461 m .36992 .62132 L .34058 .62322 L p .707 .577 .707 r
F P
0 g
s
.36992 .62132 m .37236 .58461 L .40413 .5857 L p .707 .577 .707 r
F P
0 g
s
.40413 .5857 m .40169 .62241 L .36992 .62132 L p .707 .577 .707 r
F P
0 g
s
.35409 .68869 m .35128 .6701 L .3804 .66326 L p .707 .577 .707 r
F P
0 g
s
.3804 .66326 m .38321 .68186 L .35409 .68869 L p .707 .577 .707 r
F P
0 g
s
.44272 .65521 m .44553 .67381 L .41472 .67673 L p .707 .577 .707 r
F P
0 g
s
.41472 .67673 m .41191 .65813 L .44272 .65521 L p .707 .577 .707 r
F P
0 g
s
.38321 .68186 m .3804 .66326 L .41191 .65813 L p .707 .577 .707 r
F P
0 g
s
.41191 .65813 m .41472 .67673 L .38321 .68186 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00PGoo001cOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001kOol0071oo`<000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00KWoo0`002EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001/Ool20002FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000
Kgoo001ZOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH01000FUIJEUYF0`00K7oo001YOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001ZOol0
06Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Qoo`00Igoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF001WOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00IGoo001W
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001W
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00Hgoo001VOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0HGoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo
001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001QOol7
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005aoo`D000=JEP04001JEUYFFUH90005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol005Yoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPH000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00F7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YF000000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Ioo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001GOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0035YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001FOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00EGoo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`L005Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo10000eYF00@005YFFUIJ
EPT004]oo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8000Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF009JEPH0
04Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0017oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P00@Woo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<003moo`00E7oo00<0
05YF00000UYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`00?7oo001DOol20003FUH40003FUH200000goo000000080004FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YF000003Yoo`00E7oo0P0000AJEP00000000IJEP04001JEP000002FUH0
0`00FUIJEP03FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00>7oo001DOol00eYF
00000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`001EYF00<005YFFUH00`0000AJEP00000000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`000UYF00<005YF000010000eYF0`0000=JEP00FUH01UYF00<005YF
FUH015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000goo00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3000dOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEP0000800003FUH0000000<0009JEP04001JEUYFFUH30006FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003Ool00000
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF000cOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPL0009JEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH0000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPL000QJEP80
0003FUH005YF00EJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo02ioo`00Dgoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF0P00
1UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001JEUYFFUH005YF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000002eoo`00E7oo00@005YFFUH000IJEP03001JEP0001H0009JEP03001JEUYF00EJEP04
001JEUYF0003FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02Yoo`00EGoo0`0015YF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF00@005YFFUIJEP<000AJEP<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEPD0009JEP<0009oo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo
02Yoo`00=Goo5@003Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`0000EJEP00001JEP0000IJEP04001JEP000009Ool60007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000cOol200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60008Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20002FUH01000FUH0000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000Uo
o`<00003Ool0000000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool0035o
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000004Ool20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH015YF0`001Goo1@00
0Woo0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEP000080009oo`D000Eoo`<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`0027oo0P0015YF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000/Ool002moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF1P0027oo0`0000=JEP00FUH01EYF00@005YFFUIJEP8002eoo`00;goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00=oo`8000IJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`0015YF00@005YFFUIJEP8002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP800005Ool005YFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP04001JEUYFFUH90003FUH300000eYF000000080004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo
001JEUYF00001EYF00<005YFFUH01EYF40000eYF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YF0000;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUH00003FUH50004FUH01000FUIJEP001EYF1`0015YF2@000eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000Woo0P001UYF200015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00@0
05YFFUIJEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF001JEP80009JEP<000AJEP04001JEUYF0005FUH00`00FUIJEP0<0004
FUH50005FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20003Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP05FUH20002FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP0015YF0`000UYF00@005YFFUH000EJ
EP03001JEUYF00D0009JEP03001JEUYF009JEPP00003FUH0000000=JEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH00P00
00=JEP00Ool0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP04FUH0
0`00FUIJEP0500000eYF001JEP0:FUH20003FUH200000eYF001JEP02FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000goo00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP02FUH00`00
FUH0000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH005YF009JEP<0
009JEP03001JEUYF00UJEPH00003FUH0000000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEP0002ioo`00;Goo
0P000eYF500015YF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQP000EJEP03001JEP00009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000002moo`00;Goo0P0000AJEP00
000000IJEP04001JEP000009Ool60007FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000_Ool002eoo`03FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH30008Ool3000017oo
0000000015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002io
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000IJEP00FUH0
05YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000C000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000000Woo1@00
1Woo0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`002Goo100015YF00<005YFFUH01EYF00<005YFFUH00UYF
1`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@000AJEP04001JEUYFFUHI0004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH60009Ool500000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP02FUH50006FUH00`00Oomoo`09Ool=
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool2000015YF000000000eYF
10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
000000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P00
00=JEP0000000P001UYF0P002Goo1@001Woo1`000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPL0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPl000=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P0000=JEP00FUH00eYF0`0015YF00<005YF000027oo1@003Goo100015YF00H005YFFUH0
05YF000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUH0000F0002FUH00`00FUIJEP05FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF1@0000=JEP00
00000`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEP0000<000=JEP03001oogoo00Eoo`D0015oo`<00007FUH0
05YFFUH005YF0000;Goo000^Ool00`00FUH00004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60004FUH40006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH70008FUH6
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH00eYF1`001Goo0`004Goo1P000UYF00<005YF0000;Goo000_Ool20002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00
FUIJEP04FUH00`00FUIJEP050002FUH>0004FUH00`00FUIJEP05FUH30002FUH01000FUH000002EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF6@000eYF00D005YFFUH005YF008002ioo`00<7oo10001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP@0
00AJEP03001JEUYF00D00003FUH005YF00YJEP04001JEUYFFUH400000eYF001JEP03FUH00`00FUH0
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000C000^Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP0500000eYF001JEP0:FUH40005FUH0
0`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000080004FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUH000020002FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYFFUH20002
FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF00001@001UYF00<005YFFUH015YF00<005YF
00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P0000=JEP00
FUH015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUH00000
15YF00@005YFFUH000IJEP03001JEP0000P000=JEP03001JEUYF00MJEP03001JEUYF009JEP<0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000EJ
EP03001JEUYF009JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002]oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF01@000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Ioo`8000=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
009JEQ8000=JEP03001oogoo02Uoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF3P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1EYF00<005YFFUH00eYF00@005YFFUIJEPD00003FUH007oo02Yoo`00;Goo0P0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP<000IJEP800003FUH005YF00IJ
EP03001JEUYF00AJEPH000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP<0
02]oo`00;Goo0P0015YF00@005YFFUIJEPL000Aoo`<00003FUH0000000P000AJEP04001JEUYF0003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000AFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP040002FUH00`00FUH000020004FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0015YF00<005YF0000:goo000/Ool00`00FUH00003FUH5000>Ool60004FUH700000eYF00000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000DFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20005FUH00`00FUIJ
EP03FUH80002FUH60003FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH00`00FUH0000[Ool002ao
o`04001JEP00FUH2000015YF000000004Woo2`000eYF20000eYF00<005YFFUH01EYF00<005YFFUH0
0UYF1P0065YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00<005YF00000`0000=JEP0000001Goo40001Goo0`001EYF00<005YFFUH00UYF0P00;7oo000/
Ool01P00FUH00000FUH000AJEP<000ioo`D000Moo`X00003FUH0000000h000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP800003FUH005YF00AJEP<00004FUH005YFFUH20008Ool50009Ool400000eYF001JEP06
FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000A
Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20002FUH00`00
FUIJEP020002FUH00`00FUIJEP0200000eYF001oo`08Ool30003Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH60004Ool5000?Ool4
00001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P000UYF100000AJ
EP00000000=JEP03001JEP0000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEQP000EJEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUH005YF500015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`00<goo000/Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH015YF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Moo`00;Goo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0006FUH00`00FUIJEP04FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH80009FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Woo000^Ool00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000=0002FUH00`00FUIJEP04
FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Woo000_Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP090003FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH4
00000eYF001JEP06FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@goo000`Ool20004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJ
EUYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00`001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF
3`00Agoo000bOol300000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20002FUH00`00FUH000020008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH60006FUH00`00FUH0
0009001DOol003Eoo`<000=JEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP<00003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00=JEPX0009JEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol003Qoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh00007
FUH005YFFUH005YF000025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF0`0015YF0P0027oo100015YF00H005YFFUH005YF001DOol003Ioo`80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000EJEP04001JEUYFFUH70002FUH30008FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP020002FUH2000<Ool300001eYF001JEUYF001JEP0005Aoo`00=7oo0`001EYF00<005YFFUH0
1UYF00<005YFFUH0100015YF00<005YFFUH00UYF1`0017oo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF10002goo1P000UYF00<005YF0000E7oo000bOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUHA000;Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0
000017oo1`000eYF00D005YFFUH005YF008005Eoo`00<Goo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH010000goo1@004Goo1P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
5P00EGoo000`Ool20004FUH00`00FUIJEP03FUH40007Ool5000=Ool40004FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001E
Ool002moo`03001JEP0000AJEP03001JEP0000<000aoo`<000Yoo`@0009JEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP02001COol002moo`04001JEUYF0003FUH2000IOol40006FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00;goo00D005YFFUH005YF008001Moo`@00003
FUH005YF00MJEP03001JEUYF00AJEP@00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000MJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080059oo`00<7oo00<005YF00000`0027oo
3`001EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEPh0
00=JEP05001JEUYFFUH0001BOol0031oo`800004FUH005YFFUH80003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000027oo0P001EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1P001EYF00<0
05YFFUH00eYF00<005YFFUH01@000UYF00<007ooOol0D7oo000`Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0037oo0P000eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YF000007oo00800003FUH000000080
055oo`00<7oo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL001Aoo`800003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000=JEP03001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUH0
0000DGoo000`Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP04000MOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH60004FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH01000FUIJEP00DGoo000bOol50003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH6000UOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0D0005Ool30005FUH00`00FUIJEP02FUH3001BOol003Mooa00035o
o`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEPP000Moo`D000Uoo`@00003FUH005YF00IJEP05
001JEUYFFUH0001DOol0085ooaT000moo`D000Aoo`D000EJEP03001JEUYF00EJEP04001JEP00001E
Ool0091oo`05001JEUYF001JEP02000COol300000goo000000020002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH3001GOol0095oo`03001JEP0001X000IJEP03001JEUYF00IJEP03001JEP0000<005Yo
o`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF0`00GWoo002AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04001QOol0095oo`80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD006Eoo`00TWoo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000JWoo002DOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001^Ool009Qooa0007Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60018 .74286 m .58794 .68744 L .55754 .69256 L p .707 .577 .707 r
F P
0 g
s
.58794 .68744 m .60018 .74286 L .63131 .73574 L p .707 .577 .707 r
F P
0 g
s
.63131 .73574 m .61908 .68032 L .58794 .68744 L p .707 .577 .707 r
F P
0 g
s
.61908 .68032 m .63131 .73574 L .66014 .72733 L p .707 .577 .707 r
F P
0 g
s
.66014 .72733 m .64791 .67191 L .61908 .68032 L p .707 .577 .707 r
F P
0 g
s
.56978 .74799 m .55754 .69256 L .53086 .6952 L p .707 .577 .707 r
F P
0 g
s
.55754 .69256 m .56978 .74799 L .60018 .74286 L p .707 .577 .707 r
F P
0 g
s
.64791 .67191 m .66014 .72733 L .68384 .71845 L p .707 .577 .707 r
F P
0 g
s
.68384 .71845 m .6716 .66302 L .64791 .67191 L p .707 .577 .707 r
F P
0 g
s
.53086 .6952 m .5431 .75063 L .56978 .74799 L p .707 .577 .707 r
F P
0 g
s
.5983 .80644 m .59587 .76921 L .56476 .7694 L p .707 .577 .707 r
F P
0 g
s
.59587 .76921 m .5983 .80644 L .63008 .80379 L p .707 .577 .707 r
F P
0 g
s
.63008 .80379 m .62764 .76656 L .59587 .76921 L p .707 .577 .707 r
F P
0 g
s
.62764 .76656 m .63008 .80379 L .65941 .79892 L p .707 .577 .707 r
F P
0 g
s
.65941 .79892 m .65697 .76169 L .62764 .76656 L p .707 .577 .707 r
F P
0 g
s
.5431 .75063 m .53086 .6952 L .5105 .69509 L p .707 .577 .707 r
F P
0 g
s
.5672 .80663 m .56476 .7694 L .53737 .76709 L p .707 .577 .707 r
F P
0 g
s
.56476 .7694 m .5672 .80663 L .5983 .80644 L p .707 .577 .707 r
F P
0 g
s
.6716 .66302 m .68384 .71845 L .70008 .70997 L p .707 .577 .707 r
F P
0 g
s
.70008 .70997 m .68785 .65454 L .6716 .66302 L p .707 .577 .707 r
F P
0 g
s
.65697 .76169 m .65941 .79892 L .68343 .79231 L p .707 .577 .707 r
F P
0 g
s
.68343 .79231 m .681 .75508 L .65697 .76169 L p .707 .577 .707 r
F P
0 g
s
.53737 .76709 m .53981 .80432 L .5672 .80663 L p .707 .577 .707 r
F P
0 g
s
.5105 .69509 m .52274 .75052 L .5431 .75063 L p .707 .577 .707 r
F P
0 g
s
.58528 .85797 m .58809 .83997 L .55728 .83333 L p .707 .577 .707 r
F P
0 g
s
.58809 .83997 m .58528 .85797 L .61678 .86147 L p .707 .577 .707 r
F P
0 g
s
.61678 .86147 m .61959 .84348 L .58809 .83997 L p .707 .577 .707 r
F P
0 g
s
.53981 .80432 m .53737 .76709 L .51638 .76251 L p .707 .577 .707 r
F P
0 g
s
.61959 .84348 m .61678 .86147 L .6459 .86149 L p .707 .577 .707 r
F P
0 g
s
.6459 .86149 m .64871 .8435 L .61959 .84348 L p .707 .577 .707 r
F P
0 g
s
.55447 .85132 m .55728 .83333 L .53019 .82419 L p .707 .577 .707 r
F P
0 g
s
.55728 .83333 m .55447 .85132 L .58528 .85797 L p .707 .577 .707 r
F P
0 g
s
.52274 .75052 m .5105 .69509 L .49847 .69224 L p .707 .577 .707 r
F P
0 g
s
.51638 .76251 m .51882 .79974 L .53981 .80432 L p .707 .577 .707 r
F P
0 g
s
.681 .75508 m .68343 .79231 L .69979 .78461 L p .707 .577 .707 r
F P
0 g
s
.69979 .78461 m .69735 .74738 L .681 .75508 L p .707 .577 .707 r
F P
0 g
s
.53019 .82419 m .52738 .84218 L .55447 .85132 L p .707 .577 .707 r
F P
0 g
s
.68785 .65454 m .70008 .70997 L .70729 .70272 L p .707 .577 .707 r
F P
0 g
s
.70729 .70272 m .69505 .64729 L .68785 .65454 L p .707 .577 .707 r
F P
0 g
s
.64871 .8435 m .6459 .86149 L .66979 .85802 L p .707 .577 .707 r
F P
0 g
s
.66979 .85802 m .6726 .84003 L .64871 .8435 L p .707 .577 .707 r
F P
0 g
s
.49847 .69224 m .5107 .74766 L .52274 .75052 L p .707 .577 .707 r
F P
0 g
s
.52738 .84218 m .53019 .82419 L .50946 .81345 L p .707 .577 .707 r
F P
0 g
s
.51882 .79974 m .51638 .76251 L .50384 .75612 L p .707 .577 .707 r
F P
0 g
s
.50946 .81345 m .50665 .83145 L .52738 .84218 L p .707 .577 .707 r
F P
0 g
s
.50384 .75612 m .50627 .79335 L .51882 .79974 L p .707 .577 .707 r
F P
0 g
s
.69735 .74738 m .69979 .78461 L .70689 .77658 L p .707 .577 .707 r
F P
0 g
s
.70689 .77658 m .70445 .73935 L .69735 .74738 L p .707 .577 .707 r
F P
0 g
s
.5107 .74766 m .49847 .69224 L .49593 .68693 L p .707 .577 .707 r
F P
0 g
s
.6726 .84003 m .66979 .85802 L .6861 .85141 L p .707 .577 .707 r
F P
0 g
s
.6861 .85141 m .68891 .83341 L .6726 .84003 L p .707 .577 .707 r
F P
0 g
s
.50665 .83145 m .50946 .81345 L .49713 .80217 L p .707 .577 .707 r
F P
0 g
s
.69505 .64729 m .70729 .70272 L .70475 .69741 L p .707 .577 .707 r
F P
0 g
s
.70475 .69741 m .69251 .64198 L .69505 .64729 L p .707 .577 .707 r
F P
0 g
s
.49713 .80217 m .49432 .82017 L .50665 .83145 L p .707 .577 .707 r
F P
0 g
s
.49593 .68693 m .50816 .74235 L .5107 .74766 L p .707 .577 .707 r
F P
0 g
s
.50627 .79335 m .50384 .75612 L .50097 .74854 L p .707 .577 .707 r
F P
0 g
s
.50097 .74854 m .50341 .78577 L .50627 .79335 L p .707 .577 .707 r
F P
0 g
s
.50816 .74235 m .49593 .68693 L .50313 .67968 L p .707 .577 .707 r
F P
0 g
s
.50313 .67968 m .51537 .7351 L .50816 .74235 L p .707 .577 .707 r
F P
0 g
s
.50341 .78577 m .50097 .74854 L .50806 .7405 L p .707 .577 .707 r
F P
0 g
s
.50806 .7405 m .5105 .77773 L .50341 .78577 L p .707 .577 .707 r
F P
0 g
s
.49432 .82017 m .49713 .80217 L .4944 .79145 L p .707 .577 .707 r
F P
0 g
s
.4944 .79145 m .49159 .80944 L .49432 .82017 L p .707 .577 .707 r
F P
0 g
s
.49159 .80944 m .4944 .79145 L .50154 .78233 L p .707 .577 .707 r
F P
0 g
s
.50154 .78233 m .49873 .80033 L .49159 .80944 L p .707 .577 .707 r
F P
0 g
s
.49873 .80033 m .50154 .78233 L .51785 .77572 L p .707 .577 .707 r
F P
0 g
s
.51785 .77572 m .51504 .79371 L .49873 .80033 L p .707 .577 .707 r
F P
0 g
s
.5057 .82114 m .48264 .31735 L .43868 .31672 L p .707 .577 .707 r
F P
0 g
s
.51537 .7351 m .50313 .67968 L .51938 .67119 L p .707 .577 .707 r
F P
0 g
s
.51938 .67119 m .53161 .72662 L .51537 .7351 L p .707 .577 .707 r
F P
0 g
s
.5105 .77773 m .50806 .7405 L .52442 .7328 L p .707 .577 .707 r
F P
0 g
s
.52442 .7328 m .52686 .77003 L .5105 .77773 L p .707 .577 .707 r
F P
0 g
s
.53161 .72662 m .51938 .67119 L .54307 .66231 L p .707 .577 .707 r
F P
0 g
s
.54307 .66231 m .55531 .71774 L .53161 .72662 L p .707 .577 .707 r
F P
0 g
s
.52686 .77003 m .52442 .7328 L .54844 .7262 L p .707 .577 .707 r
F P
0 g
s
.54844 .7262 m .55088 .76343 L .52686 .77003 L p .707 .577 .707 r
F P
0 g
s
.51504 .79371 m .51785 .77572 L .54174 .77225 L p .707 .577 .707 r
F P
0 g
s
.54174 .77225 m .53893 .79024 L .51504 .79371 L p .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .54174 .77225 L .55695 .77226 L p .707 .577 .707 r
F P
0 g
s
.55695 .77226 m .57086 .77227 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .55695 .77226 L .55233 .7827 L .707 .577 .707 r
F
.48264 .31735 m .5057 .82114 L .53622 .81914 L p F P
0 g
s
.53622 .81914 m .5506 .8182 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.5506 .8182 m .54929 .78957 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.60236 .77577 m .59956 .79377 L .56913 .79038 L p .707 .577 .707 r
F P
0 g
s
.56896 .78988 m .60236 .77577 L .56913 .79038 L .707 .577 .707 r
F
.54929 .78957 m .5506 .8182 L p .57244 .80016 L F P
0 g
s
.57086 .77227 m .60236 .77577 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .57086 .77227 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.58877 .78667 m .56838 .78817 L .57244 .80016 L .707 .577 .707 r
F
.56838 .78817 m .54929 .78957 L .57244 .80016 L F
.56805 .79026 m .56838 .78817 L p .56896 .78988 L F P
0 g
s
.56913 .79038 m .56805 .79026 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .58877 .78667 L .57244 .80016 L .707 .577 .707 r
F
.5506 .8182 m .5772 .81419 L p .57244 .80016 L F P
0 g
s
.5772 .81419 m .59205 .81196 L p .57244 .80016 L .707 .577 .707 r
F P
0 g
s
.57086 .77227 m .56838 .78817 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.54899 .79025 m .53893 .79024 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.55233 .7827 m .57086 .77227 L .54899 .79025 L .707 .577 .707 r
F
.55531 .71774 m .54307 .66231 L .56716 .65528 L p F P
0 g
s
.56716 .65528 m .5719 .6539 L p .57005 .66102 L .707 .577 .707 r
F P
0 g
s
.55531 .71774 m .56716 .65528 L .57005 .66102 L .707 .577 .707 r
F
.54929 .78957 m .54075 .60279 L p .54732 .79402 L F P
0 g
s
.54075 .60279 m .52755 .3144 L p .53932 .59996 L .707 .577 .707 r
F P
0 g
s
.54075 .60279 m .53932 .59996 L .54732 .79402 L .707 .577 .707 r
F
.5719 .6539 m .58414 .70933 L .55531 .71774 L p F P
0 g
s
.55088 .76343 m .54844 .7262 L .57778 .72133 L p .707 .577 .707 r
F P
0 g
s
.57778 .72133 m .58022 .75856 L .55088 .76343 L p .707 .577 .707 r
F P
0 g
s
.58022 .75856 m .57778 .72133 L .60955 .71867 L p .707 .577 .707 r
F P
0 g
s
.60955 .71867 m .61199 .7559 L .58022 .75856 L p .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .54929 .78957 L p .58877 .78667 L .707 .577 .707 r
F P
0 g
s
.56805 .79026 m .54899 .79025 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .56805 .79026 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .48264 .31735 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.54732 .79402 m .48264 .31735 L .53622 .81914 L .707 .577 .707 r
F
.58414 .70933 m .5719 .6539 L .60304 .64678 L p F P
0 g
s
.60304 .64678 m .61527 .70221 L .58414 .70933 L p .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .56899 .30816 L .52755 .3144 L p .707 .577 .707 r
F P
0 g
s
.68891 .83341 m .6861 .85141 L .69324 .84229 L p .707 .577 .707 r
F P
0 g
s
.69324 .84229 m .69605 .8243 L .68891 .83341 L p .707 .577 .707 r
F P
0 g
s
.70445 .73935 m .70689 .77658 L .70402 .76899 L p .707 .577 .707 r
F P
0 g
s
.70402 .76899 m .70158 .73176 L .70445 .73935 L p .707 .577 .707 r
F P
0 g
s
.46174 .82051 m .43868 .31672 L .39997 .31257 L p .707 .577 .707 r
F P
0 g
s
.43868 .31672 m .46174 .82051 L .5057 .82114 L p .707 .577 .707 r
F P
0 g
s
.69251 .64198 m .70475 .69741 L .69271 .69456 L p .707 .577 .707 r
F P
0 g
s
.69271 .69456 m .68048 .63913 L .69251 .64198 L p .707 .577 .707 r
F P
0 g
s
.61527 .70221 m .60304 .64678 L .63344 .64165 L p .707 .577 .707 r
F P
0 g
s
.64066 .71849 m .64309 .75572 L .61199 .7559 L p .707 .577 .707 r
F P
0 g
s
.61199 .7559 m .60955 .71867 L .64066 .71849 L p .707 .577 .707 r
F P
0 g
s
.63317 .78242 m .63036 .80041 L .59956 .79377 L p .707 .577 .707 r
F P
0 g
s
.59956 .79377 m .60236 .77577 L .63317 .78242 L p .707 .577 .707 r
F P
0 g
s
.56899 .30816 m .59205 .81196 L .62599 .80304 L p .707 .577 .707 r
F P
0 g
s
.63344 .64165 m .64567 .69708 L .61527 .70221 L p .707 .577 .707 r
F P
0 g
s
.62599 .80304 m .60293 .29924 L .56899 .30816 L p .707 .577 .707 r
F P
0 g
s
.25717 .70482 m .24493 .6494 L .21454 .65452 L p .707 .577 .707 r
F P
0 g
s
.24493 .6494 m .25717 .70482 L .2883 .6977 L p .707 .577 .707 r
F P
0 g
s
.2883 .6977 m .27607 .64228 L .24493 .6494 L p .707 .577 .707 r
F P
0 g
s
.27607 .64228 m .2883 .6977 L .31713 .68929 L p .707 .577 .707 r
F P
0 g
s
.31713 .68929 m .3049 .63387 L .27607 .64228 L p .707 .577 .707 r
F P
0 g
s
.42302 .81636 m .39997 .31257 L .37028 .30531 L p .707 .577 .707 r
F P
0 g
s
.39997 .31257 m .42302 .81636 L .46174 .82051 L p .707 .577 .707 r
F P
0 g
s
.69605 .8243 m .69324 .84229 L .69051 .83157 L p .707 .577 .707 r
F P
0 g
s
.69051 .83157 m .69332 .81357 L .69605 .8243 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22677 .70995 m .21454 .65452 L .18785 .65716 L p .707 .577 .707 r
F P
0 g
s
.21454 .65452 m .22677 .70995 L .25717 .70482 L p .707 .577 .707 r
F P
0 g
s
.70158 .73176 m .70402 .76899 L .69148 .7626 L p .707 .577 .707 r
F P
0 g
s
.69148 .7626 m .68904 .72537 L .70158 .73176 L p .707 .577 .707 r
F P
0 g
s
.3049 .63387 m .31713 .68929 L .34083 .68041 L p .707 .577 .707 r
F P
0 g
s
.34083 .68041 m .32859 .62498 L .3049 .63387 L p .707 .577 .707 r
F P
0 g
s
.68048 .63913 m .69271 .69456 L .67235 .69444 L p .707 .577 .707 r
F P
0 g
s
.67235 .69444 m .66012 .63902 L .68048 .63913 L p .707 .577 .707 r
F P
0 g
s
.18785 .65716 m .20009 .71259 L .22677 .70995 L p .707 .577 .707 r
F P
0 g
s
.64567 .69708 m .63344 .64165 L .66012 .63902 L p .707 .577 .707 r
F P
0 g
s
.66805 .72079 m .67048 .75802 L .64309 .75572 L p .707 .577 .707 r
F P
0 g
s
.64309 .75572 m .64066 .71849 L .66805 .72079 L p .707 .577 .707 r
F P
0 g
s
.66027 .79156 m .65746 .80955 L .63036 .80041 L p .707 .577 .707 r
F P
0 g
s
.63036 .80041 m .63317 .78242 L .66027 .79156 L p .707 .577 .707 r
F P
0 g
s
.60293 .29924 m .62599 .80304 L .64909 .79231 L p .707 .577 .707 r
F P
0 g
s
.64909 .79231 m .62603 .28852 L .60293 .29924 L p .707 .577 .707 r
F P
0 g
s
.2553 .77269 m .25286 .73546 L .22175 .73564 L p .707 .577 .707 r
F P
0 g
s
.25286 .73546 m .2553 .77269 L .28707 .77003 L p .707 .577 .707 r
F P
0 g
s
.28707 .77003 m .28463 .7328 L .25286 .73546 L p .707 .577 .707 r
F P
0 g
s
.28463 .7328 m .28707 .77003 L .3164 .76516 L p .707 .577 .707 r
F P
0 g
s
.3164 .76516 m .31396 .72793 L .28463 .7328 L p .707 .577 .707 r
F P
0 g
s
.20009 .71259 m .18785 .65716 L .1675 .65705 L p .707 .577 .707 r
F P
0 g
s
.22419 .77287 m .22175 .73564 L .19436 .73333 L p .707 .577 .707 r
F P
0 g
s
.22175 .73564 m .22419 .77287 L .2553 .77269 L p .707 .577 .707 r
F P
0 g
s
.32859 .62498 m .34083 .68041 L .35707 .67193 L p .707 .577 .707 r
F P
0 g
s
.35707 .67193 m .34484 .6165 L .32859 .62498 L p .707 .577 .707 r
F P
0 g
s
.31396 .72793 m .3164 .76516 L .34042 .75855 L p .707 .577 .707 r
F P
0 g
s
.34042 .75855 m .33799 .72132 L .31396 .72793 L p .707 .577 .707 r
F P
0 g
s
.69332 .81357 m .69051 .83157 L .67818 .82029 L p .707 .577 .707 r
F P
0 g
s
.67818 .82029 m .68099 .80229 L .69332 .81357 L p .707 .577 .707 r
F P
0 g
s
.1675 .65705 m .17973 .71248 L .20009 .71259 L p .707 .577 .707 r
F P
0 g
s
.39334 .8091 m .37028 .30531 L .35254 .29565 L p .707 .577 .707 r
F P
0 g
s
.37028 .30531 m .39334 .8091 L .42302 .81636 L p .707 .577 .707 r
F P
0 g
s
.19436 .73333 m .1968 .77056 L .22419 .77287 L p .707 .577 .707 r
F P
0 g
s
.68904 .72537 m .69148 .7626 L .67048 .75802 L p .707 .577 .707 r
F P
0 g
s
.67048 .75802 m .66805 .72079 L .68904 .72537 L p .707 .577 .707 r
F P
0 g
s
.24227 .81561 m .24508 .79762 L .21427 .79097 L p .707 .577 .707 r
F P
0 g
s
.24508 .79762 m .24227 .81561 L .27377 .81912 L p .707 .577 .707 r
F P
0 g
s
.27377 .81912 m .27658 .80112 L .24508 .79762 L p .707 .577 .707 r
F P
0 g
s
.66012 .63902 m .67235 .69444 L .64567 .69708 L p .707 .577 .707 r
F P
0 g
s
.1968 .77056 m .19436 .73333 L .17337 .72876 L p .707 .577 .707 r
F P
0 g
s
.27658 .80112 m .27377 .81912 L .3029 .81913 L p .707 .577 .707 r
F P
0 g
s
.3029 .81913 m .3057 .80114 L .27658 .80112 L p .707 .577 .707 r
F P
0 g
s
.21146 .80897 m .21427 .79097 L .18718 .78183 L p .707 .577 .707 r
F P
0 g
s
.21427 .79097 m .21146 .80897 L .24227 .81561 L p .707 .577 .707 r
F P
0 g
s
.17973 .71248 m .1675 .65705 L .15546 .6542 L p .707 .577 .707 r
F P
0 g
s
.18718 .78183 m .18437 .79983 L .21146 .80897 L p .707 .577 .707 r
F P
0 g
s
.17337 .72876 m .17581 .76599 L .1968 .77056 L p .707 .577 .707 r
F P
0 g
s
.33799 .72132 m .34042 .75855 L .35678 .75085 L p .707 .577 .707 r
F P
0 g
s
.35678 .75085 m .35434 .71362 L .33799 .72132 L p .707 .577 .707 r
F P
0 g
s
.62603 .28852 m .64909 .79231 L .6591 .78083 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .63604 .27703 L .62603 .28852 L p .707 .577 .707 r
F P
0 g
s
.34484 .6165 m .35707 .67193 L .36428 .66468 L p .707 .577 .707 r
F P
0 g
s
.36428 .66468 m .35205 .60925 L .34484 .6165 L p .707 .577 .707 r
F P
0 g
s
.3057 .80114 m .3029 .81913 L .32678 .81567 L p .707 .577 .707 r
F P
0 g
s
.32678 .81567 m .32959 .79767 L .3057 .80114 L p .707 .577 .707 r
F P
0 g
s
.15546 .6542 m .16769 .70962 L .17973 .71248 L p .707 .577 .707 r
F P
0 g
s
.18437 .79983 m .18718 .78183 L .16645 .7711 L p .707 .577 .707 r
F P
0 g
s
.68099 .80229 m .67818 .82029 L .65746 .80955 L p .707 .577 .707 r
F P
0 g
s
.65746 .80955 m .66027 .79156 L .68099 .80229 L p .707 .577 .707 r
F P
0 g
s
.16645 .7711 m .16364 .78909 L .18437 .79983 L p .707 .577 .707 r
F P
0 g
s
.17581 .76599 m .17337 .72876 L .16083 .72236 L p .707 .577 .707 r
F P
0 g
s
.3756 .79944 m .35254 .29565 L .34847 .28453 L p .707 .577 .707 r
F P
0 g
s
.35254 .29565 m .3756 .79944 L .39334 .8091 L p .707 .577 .707 r
F P
0 g
s
.16083 .72236 m .16326 .75959 L .17581 .76599 L p .707 .577 .707 r
F P
0 g
s
.32959 .79767 m .32678 .81567 L .34309 .80905 L p .707 .577 .707 r
F P
0 g
s
.34309 .80905 m .3459 .79106 L .32959 .79767 L p .707 .577 .707 r
F P
0 g
s
.16769 .70962 m .15546 .6542 L .15292 .64889 L p .707 .577 .707 r
F P
0 g
s
.35434 .71362 m .35678 .75085 L .36388 .74282 L p .707 .577 .707 r
F P
0 g
s
.36388 .74282 m .36144 .70559 L .35434 .71362 L p .707 .577 .707 r
F P
0 g
s
.16364 .78909 m .16645 .7711 L .15412 .75982 L p .707 .577 .707 r
F P
0 g
s
.35205 .60925 m .36428 .66468 L .36174 .65937 L p .707 .577 .707 r
F P
0 g
s
.36174 .65937 m .34951 .60394 L .35205 .60925 L p .707 .577 .707 r
F P
0 g
s
.15412 .75982 m .15131 .77781 L .16364 .78909 L p .707 .577 .707 r
F P
0 g
s
.15292 .64889 m .16515 .70431 L .16769 .70962 L p .707 .577 .707 r
F P
0 g
s
.16326 .75959 m .16083 .72236 L .15796 .71478 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .65503 .76971 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64422 .45583 m .6591 .78083 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .63604 .27703 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.65503 .76971 m .64504 .55148 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64504 .55148 m .63197 .26592 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .65503 .76971 L .64867 .76625 L p .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64386 .73941 L .64456 .73978 L p .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .63651 .68782 L .64418 .73731 L .707 .577 .707 r
F
.63651 .68782 m .63197 .26592 L .64867 .76625 L F
.61423 .25626 m .63197 .26592 L p .63698 .73215 L F P
0 g
s
.64386 .73941 m .64287 .73637 L .63597 .73142 L .707 .577 .707 r
F
.61423 .25626 m .63597 .73142 L p .6076 .75279 L F P
0 g
s
.62778 .75772 m .6076 .75279 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63201 .72857 m .63579 .73203 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63579 .73203 m .64386 .73941 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .63728 .76005 L .62778 .75772 L p .707 .577 .707 r
F P
0 g
s
.63728 .76005 m .63597 .73142 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .61423 .25626 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63433 .71013 m .63152 .72813 L .63201 .72857 L p .707 .577 .707 r
F P
0 g
s
.64287 .73637 m .63433 .71013 L .63201 .72857 L .707 .577 .707 r
F
.64666 .72142 m .63433 .71013 L p .64287 .73637 L F P
0 g
s
.64386 .73941 m .64418 .73731 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64666 .72142 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64867 .76625 m .63728 .76005 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .64418 .73731 L .64867 .76625 L .707 .577 .707 r
F
.64666 .72142 m .64418 .73731 L p .66458 .75015 L F P
0 g
s
.64456 .73978 m .66458 .75015 L p .64418 .73731 L .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .65994 .65848 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.63567 .6002 m .64585 .64633 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.64585 .64633 m .64791 .65563 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64771 .60305 L .64548 .60252 L p .707 .577 .707 r
F P
0 g
s
.64548 .60252 m .63567 .6002 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64548 .60252 L .64566 .62419 L .707 .577 .707 r
F
.63604 .27703 m .64422 .45583 L p .64459 .4989 L F P
0 g
s
.15796 .71478 m .1604 .75201 L .16326 .75959 L p .707 .577 .707 r
F P
0 g
s
.3459 .79106 m .34309 .80905 L .35023 .79993 L p .707 .577 .707 r
F P
0 g
s
.35023 .79993 m .35304 .78194 L .3459 .79106 L p .707 .577 .707 r
F P
0 g
s
.15131 .77781 m .15412 .75982 L .15139 .74909 L p .707 .577 .707 r
F P
0 g
s
.36144 .70559 m .36388 .74282 L .36101 .73524 L p .707 .577 .707 r
F P
0 g
s
.36101 .73524 m .35857 .69801 L .36144 .70559 L p .707 .577 .707 r
F P
0 g
s
.16515 .70431 m .15292 .64889 L .16012 .64164 L p .707 .577 .707 r
F P
0 g
s
.15139 .74909 m .14858 .76709 L .15131 .77781 L p .707 .577 .707 r
F P
0 g
s
.34951 .60394 m .36174 .65937 L .3497 .65652 L p .707 .577 .707 r
F P
0 g
s
.3497 .65652 m .33747 .60109 L .34951 .60394 L p .707 .577 .707 r
F P
0 g
s
.34847 .28453 m .37153 .78833 L .3756 .79944 L p .707 .577 .707 r
F P
0 g
s
.37153 .78833 m .34847 .28453 L .35848 .27305 L p .707 .577 .707 r
F P
0 g
s
.16012 .64164 m .17236 .69706 L .16515 .70431 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1604 .75201 m .15796 .71478 L .16506 .70674 L p .707 .577 .707 r
F P
0 g
s
.35304 .78194 m .35023 .79993 L .3475 .78921 L p .707 .577 .707 r
F P
0 g
s
.3475 .78921 m .35031 .77122 L .35304 .78194 L p .707 .577 .707 r
F P
0 g
s
.16506 .70674 m .16749 .74397 L .1604 .75201 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14858 .76709 m .15139 .74909 L .15853 .73998 L p .707 .577 .707 r
F P
0 g
s
.17236 .69706 m .16012 .64164 L .17637 .63315 L p .707 .577 .707 r
F P
0 g
s
.35857 .69801 m .36101 .73524 L .34847 .72884 L p .707 .577 .707 r
F P
0 g
s
.34847 .72884 m .34603 .69161 L .35857 .69801 L p .707 .577 .707 r
F P
0 g
s
.15853 .73998 m .15572 .75797 L .14858 .76709 L p .707 .577 .707 r
F P
0 g
s
.33747 .60109 m .3497 .65652 L .32935 .6564 L p .707 .577 .707 r
F P
0 g
s
.32935 .6564 m .31711 .60098 L .33747 .60109 L p .707 .577 .707 r
F P
0 g
s
.17637 .63315 m .1886 .68858 L .17236 .69706 L p .707 .577 .707 r
F P
0 g
s
.16749 .74397 m .16506 .70674 L .18141 .69905 L p .707 .577 .707 r
F P
0 g
s
.38154 .77684 m .35848 .27305 L .38158 .26232 L p .707 .577 .707 r
F P
0 g
s
.35848 .27305 m .38154 .77684 L .37153 .78833 L p .707 .577 .707 r
F P
0 g
s
.35031 .77122 m .3475 .78921 L .33517 .77793 L p .707 .577 .707 r
F P
0 g
s
.33517 .77793 m .33798 .75993 L .35031 .77122 L p .707 .577 .707 r
F P
0 g
s
.18141 .69905 m .18385 .73628 L .16749 .74397 L p .707 .577 .707 r
F P
0 g
s
.1886 .68858 m .17637 .63315 L .20007 .62427 L p .707 .577 .707 r
F P
0 g
s
.15572 .75797 m .15853 .73998 L .17484 .73336 L p .707 .577 .707 r
F P
0 g
s
.34603 .69161 m .34847 .72884 L .32747 .72427 L p .707 .577 .707 r
F P
0 g
s
.32747 .72427 m .32504 .68704 L .34603 .69161 L p .707 .577 .707 r
F P
0 g
s
.31711 .60098 m .32935 .6564 L .30266 .65904 L p .707 .577 .707 r
F P
0 g
s
.30266 .65904 m .29043 .60361 L .31711 .60098 L p .707 .577 .707 r
F P
0 g
s
.17484 .73336 m .17203 .75136 L .15572 .75797 L p .707 .577 .707 r
F P
0 g
s
.20007 .62427 m .2123 .6797 L .1886 .68858 L p .707 .577 .707 r
F P
0 g
s
.6076 .75279 m .58454 .249 L .61423 .25626 L p .707 .577 .707 r
F P
0 g
s
.18385 .73628 m .18141 .69905 L .20543 .69244 L p .707 .577 .707 r
F P
0 g
s
.2123 .6797 m .20007 .62427 L .22889 .61586 L p .707 .577 .707 r
F P
0 g
s
.29043 .60361 m .30266 .65904 L .27226 .66417 L p .707 .577 .707 r
F P
0 g
s
.27226 .66417 m .26003 .60874 L .29043 .60361 L p .707 .577 .707 r
F P
0 g
s
.33798 .75993 m .33517 .77793 L .31445 .76719 L p .707 .577 .707 r
F P
0 g
s
.31445 .76719 m .31726 .7492 L .33798 .75993 L p .707 .577 .707 r
F P
0 g
s
.20543 .69244 m .20787 .72967 L .18385 .73628 L p .707 .577 .707 r
F P
0 g
s
.32504 .68704 m .32747 .72427 L .30008 .72196 L p .707 .577 .707 r
F P
0 g
s
.30008 .72196 m .29765 .68473 L .32504 .68704 L p .707 .577 .707 r
F P
0 g
s
.17203 .75136 m .17484 .73336 L .19873 .72989 L p .707 .577 .707 r
F P
0 g
s
.22889 .61586 m .24113 .67129 L .2123 .6797 L p .707 .577 .707 r
F P
0 g
s
.24113 .67129 m .22889 .61586 L .26003 .60874 L p .707 .577 .707 r
F P
0 g
s
.73738 .65082 m .72515 .5954 L .69475 .60053 L p .707 .577 .707 r
F P
0 g
s
.72515 .5954 m .73738 .65082 L .76852 .6437 L p .707 .577 .707 r
F P
0 g
s
.76852 .6437 m .75628 .58828 L .72515 .5954 L p .707 .577 .707 r
F P
0 g
s
.26003 .60874 m .27226 .66417 L .24113 .67129 L p .707 .577 .707 r
F P
0 g
s
.75628 .58828 m .76852 .6437 L .79734 .63529 L p .707 .577 .707 r
F P
0 g
s
.79734 .63529 m .78511 .57987 L .75628 .58828 L p .707 .577 .707 r
F P
0 g
s
.38158 .26232 m .40464 .76612 L .38154 .77684 L p .707 .577 .707 r
F P
0 g
s
.40464 .76612 m .38158 .26232 L .41552 .2534 L p .707 .577 .707 r
F P
0 g
s
.19873 .72989 m .19592 .74789 L .17203 .75136 L p .707 .577 .707 r
F P
0 g
s
.20787 .72967 m .20543 .69244 L .23477 .68757 L p .707 .577 .707 r
F P
0 g
s
.70698 .65595 m .69475 .60053 L .66806 .60316 L p .707 .577 .707 r
F P
0 g
s
.69475 .60053 m .70698 .65595 L .73738 .65082 L p .707 .577 .707 r
F P
0 g
s
.29765 .68473 m .30008 .72196 L .26898 .72214 L p .707 .577 .707 r
F P
0 g
s
.26898 .72214 m .26654 .68491 L .29765 .68473 L p .707 .577 .707 r
F P
0 g
s
.78511 .57987 m .79734 .63529 L .82104 .62641 L p .707 .577 .707 r
F P
0 g
s
.82104 .62641 m .80881 .57099 L .78511 .57987 L p .707 .577 .707 r
F P
0 g
s
.23477 .68757 m .23721 .7248 L .20787 .72967 L p .707 .577 .707 r
F P
0 g
s
.31726 .7492 m .31445 .76719 L .28735 .75806 L p .707 .577 .707 r
F P
0 g
s
.28735 .75806 m .29016 .74006 L .31726 .7492 L p .707 .577 .707 r
F P
0 g
s
.23721 .7248 m .23477 .68757 L .26654 .68491 L p .707 .577 .707 r
F P
0 g
s
.58454 .249 m .6076 .75279 L .56888 .74864 L p .707 .577 .707 r
F P
0 g
s
.56888 .74864 m .54583 .24485 L .58454 .249 L p .707 .577 .707 r
F P
0 g
s
.19592 .74789 m .19873 .72989 L .22785 .72991 L p .707 .577 .707 r
F P
0 g
s
.66806 .60316 m .6803 .65859 L .70698 .65595 L p .707 .577 .707 r
F P
0 g
s
.73551 .7144 m .73307 .67717 L .70197 .67736 L p .707 .577 .707 r
F P
0 g
s
.73307 .67717 m .73551 .7144 L .76728 .71175 L p .707 .577 .707 r
F P
0 g
s
.76728 .71175 m .76484 .67452 L .73307 .67717 L p .707 .577 .707 r
F P
0 g
s
.26654 .68491 m .26898 .72214 L .23721 .7248 L p .707 .577 .707 r
F P
0 g
s
.76484 .67452 m .76728 .71175 L .79662 .70688 L p .707 .577 .707 r
F P
0 g
s
.79662 .70688 m .79418 .66965 L .76484 .67452 L p .707 .577 .707 r
F P
0 g
s
.22785 .72991 m .22504 .74791 L .19592 .74789 L p .707 .577 .707 r
F P
0 g
s
.6803 .65859 m .66806 .60316 L .64771 .60305 L p .707 .577 .707 r
F P
0 g
s
.7044 .71459 m .70197 .67736 L .67458 .67505 L p .707 .577 .707 r
F P
0 g
s
.70197 .67736 m .7044 .71459 L .73551 .7144 L p .707 .577 .707 r
F P
0 g
s
.43857 .7572 m .41552 .2534 L .45696 .24716 L p .707 .577 .707 r
F P
0 g
s
.41552 .2534 m .43857 .7572 L .40464 .76612 L p .707 .577 .707 r
F P
0 g
s
.29016 .74006 m .28735 .75806 L .25655 .75141 L p .707 .577 .707 r
F P
0 g
s
.25655 .75141 m .25936 .73341 L .29016 .74006 L p .707 .577 .707 r
F P
0 g
s
.80881 .57099 m .82104 .62641 L .83729 .61793 L p .707 .577 .707 r
F P
0 g
s
.83729 .61793 m .82505 .5625 L .80881 .57099 L p .707 .577 .707 r
F P
0 g
s
.22504 .74791 m .22785 .72991 L .25936 .73341 L p .707 .577 .707 r
F P
0 g
s
.79418 .66965 m .79662 .70688 L .82064 .70027 L p .707 .577 .707 r
F P
0 g
s
.82064 .70027 m .8182 .66304 L .79418 .66965 L p .707 .577 .707 r
F P
0 g
s
.25936 .73341 m .25655 .75141 L .22504 .74791 L p .707 .577 .707 r
F P
0 g
s
.67458 .67505 m .67702 .71228 L .7044 .71459 L p .707 .577 .707 r
F P
0 g
s
.64771 .60305 m .65994 .65848 L .6803 .65859 L p .707 .577 .707 r
F P
0 g
s
.54583 .24485 m .56888 .74864 L .52492 .74801 L p .707 .577 .707 r
F P
0 g
s
.52492 .74801 m .50187 .24422 L .54583 .24485 L p .707 .577 .707 r
F P
0 g
s
.72248 .76593 m .72529 .74794 L .69448 .74129 L p .707 .577 .707 r
F P
0 g
s
.72529 .74794 m .72248 .76593 L .75399 .76943 L p .707 .577 .707 r
F P
0 g
s
.75399 .76943 m .7568 .75144 L .72529 .74794 L p .707 .577 .707 r
F P
0 g
s
.67702 .71228 m .67458 .67505 L .65358 .67047 L p .707 .577 .707 r
F P
0 g
s
.7568 .75144 m .75399 .76943 L .78311 .76945 L p .707 .577 .707 r
F P
0 g
s
.78311 .76945 m .78592 .75146 L .7568 .75144 L p .707 .577 .707 r
F P
0 g
s
.48002 .75096 m .45696 .24716 L .50187 .24422 L p .707 .577 .707 r
F P
0 g
s
.45696 .24716 m .48002 .75096 L .43857 .7572 L p .707 .577 .707 r
F P
0 g
s
.69167 .75928 m .69448 .74129 L .66739 .73215 L p .707 .577 .707 r
F P
0 g
s
.69448 .74129 m .69167 .75928 L .72248 .76593 L p .707 .577 .707 r
F P
0 g
s
.50187 .24422 m .52492 .74801 L .48002 .75096 L p .707 .577 .707 r
F P
0 g
s
.65358 .67047 m .65602 .7077 L .67702 .71228 L p .707 .577 .707 r
F P
0 g
s
.8182 .66304 m .82064 .70027 L .837 .69257 L p .707 .577 .707 r
F P
0 g
s
.837 .69257 m .83456 .65534 L .8182 .66304 L p .707 .577 .707 r
F P
0 g
s
.66739 .73215 m .66458 .75015 L .69167 .75928 L p .707 .577 .707 r
F P
0 g
s
.82505 .5625 m .83729 .61793 L .84449 .61068 L p .707 .577 .707 r
F P
0 g
s
.84449 .61068 m .83226 .55525 L .82505 .5625 L p .707 .577 .707 r
F P
0 g
s
.78592 .75146 m .78311 .76945 L .80699 .76598 L p .707 .577 .707 r
F P
0 g
s
.80699 .76598 m .8098 .74799 L .78592 .75146 L p .707 .577 .707 r
F P
0 g
s
.66458 .75015 m .66739 .73215 L .64666 .72142 L p .707 .577 .707 r
F P
0 g
s
.65602 .7077 m .65358 .67047 L .64104 .66408 L p .707 .577 .707 r
F P
0 g
s
.64104 .66408 m .64348 .70131 L .65602 .7077 L p .707 .577 .707 r
F P
0 g
s
.83456 .65534 m .837 .69257 L .84409 .68454 L p .707 .577 .707 r
F P
0 g
s
.84409 .68454 m .84165 .64731 L .83456 .65534 L p .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .63567 .6002 L .63313 .59489 L p .707 .577 .707 r
F P
0 g
s
.8098 .74799 m .80699 .76598 L .82331 .75937 L p .707 .577 .707 r
F P
0 g
s
.82331 .75937 m .82612 .74137 L .8098 .74799 L p .707 .577 .707 r
F P
0 g
s
.83226 .55525 m .84449 .61068 L .84195 .60537 L p .707 .577 .707 r
F P
0 g
s
.84195 .60537 m .82972 .54994 L .83226 .55525 L p .707 .577 .707 r
F P
0 g
s
.63313 .59489 m .64536 .65031 L .64791 .65563 L p .707 .577 .707 r
F P
0 g
s
.64348 .70131 m .64104 .66408 L .63817 .6565 L p .707 .577 .707 r
F P
0 g
s
.63817 .6565 m .64061 .69373 L .64348 .70131 L p .707 .577 .707 r
F P
0 g
s
.82612 .74137 m .82331 .75937 L .83045 .75025 L p .707 .577 .707 r
F P
0 g
s
.83045 .75025 m .83326 .73226 L .82612 .74137 L p .707 .577 .707 r
F P
0 g
s
.84165 .64731 m .84409 .68454 L .84123 .67695 L p .707 .577 .707 r
F P
0 g
s
.84123 .67695 m .83879 .63972 L .84165 .64731 L p .707 .577 .707 r
F P
0 g
s
.63152 .72813 m .63433 .71013 L .6316 .69941 L p .707 .577 .707 r
F P
0 g
s
.64536 .65031 m .63313 .59489 L .64034 .58764 L p .707 .577 .707 r
F P
0 g
s
.6316 .69941 m .6288 .71741 L .63152 .72813 L p .707 .577 .707 r
F P
0 g
s
.82972 .54994 m .84195 .60537 L .82992 .60252 L p .707 .577 .707 r
F P
0 g
s
.82992 .60252 m .81768 .54709 L .82972 .54994 L p .707 .577 .707 r
F P
0 g
s
.64034 .58764 m .65257 .64306 L .64536 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64061 .69373 m .63817 .6565 L .64527 .64846 L p .707 .577 .707 r
F P
0 g
s
.39437 .61278 m .38214 .55736 L .35174 .56249 L p .707 .577 .707 r
F P
0 g
s
.38214 .55736 m .39437 .61278 L .42551 .60566 L p .707 .577 .707 r
F P
0 g
s
.42551 .60566 m .41327 .55024 L .38214 .55736 L p .707 .577 .707 r
F P
0 g
s
.41327 .55024 m .42551 .60566 L .45433 .59725 L p .707 .577 .707 r
F P
0 g
s
.45433 .59725 m .4421 .54183 L .41327 .55024 L p .707 .577 .707 r
F P
0 g
s
.64527 .64846 m .64771 .68569 L .64061 .69373 L p .707 .577 .707 r
F P
0 g
s
.83326 .73226 m .83045 .75025 L .82772 .73953 L p .707 .577 .707 r
F P
0 g
s
.82772 .73953 m .83053 .72153 L .83326 .73226 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36397 .61791 m .35174 .56249 L .32505 .56512 L p .707 .577 .707 r
F P
0 g
s
.35174 .56249 m .36397 .61791 L .39437 .61278 L p .707 .577 .707 r
F P
0 g
s
.83879 .63972 m .84123 .67695 L .82868 .67056 L p .707 .577 .707 r
F P
0 g
s
.82868 .67056 m .82624 .63333 L .83879 .63972 L p .707 .577 .707 r
F P
0 g
s
.6288 .71741 m .6316 .69941 L .63875 .69029 L p .707 .577 .707 r
F P
0 g
s
.65257 .64306 m .64034 .58764 L .65658 .57916 L p .707 .577 .707 r
F P
0 g
s
.4421 .54183 m .45433 .59725 L .47803 .58837 L p .707 .577 .707 r
F P
0 g
s
.47803 .58837 m .4658 .53295 L .4421 .54183 L p .707 .577 .707 r
F P
0 g
s
.63875 .69029 m .63594 .70829 L .6288 .71741 L p .707 .577 .707 r
F P
0 g
s
.81768 .54709 m .82992 .60252 L .80956 .60241 L p .707 .577 .707 r
F P
0 g
s
.80956 .60241 m .79732 .54698 L .81768 .54709 L p .707 .577 .707 r
F P
0 g
s
.32505 .56512 m .33729 .62055 L .36397 .61791 L p .707 .577 .707 r
F P
0 g
s
.65658 .57916 m .66882 .63458 L .65257 .64306 L p .707 .577 .707 r
F P
0 g
s
.3925 .68065 m .39006 .64342 L .35896 .6436 L p .707 .577 .707 r
F P
0 g
s
.39006 .64342 m .3925 .68065 L .42427 .67799 L p .707 .577 .707 r
F P
0 g
s
.42427 .67799 m .42183 .64076 L .39006 .64342 L p .707 .577 .707 r
F P
0 g
s
.42183 .64076 m .42427 .67799 L .45361 .67312 L p .707 .577 .707 r
F P
0 g
s
.45361 .67312 m .45117 .63589 L .42183 .64076 L p .707 .577 .707 r
F P
0 g
s
.64771 .68569 m .64527 .64846 L .66163 .64077 L p .707 .577 .707 r
F P
0 g
s
.33729 .62055 m .32505 .56512 L .3047 .56501 L p .707 .577 .707 r
F P
0 g
s
.36139 .68083 m .35896 .6436 L .33157 .64129 L p .707 .577 .707 r
F P
0 g
s
.35896 .6436 m .36139 .68083 L .3925 .68065 L p .707 .577 .707 r
F P
0 g
s
.4658 .53295 m .47803 .58837 L .49428 .57989 L p .707 .577 .707 r
F P
0 g
s
.49428 .57989 m .48204 .52446 L .4658 .53295 L p .707 .577 .707 r
F P
0 g
s
.66163 .64077 m .66406 .678 L .64771 .68569 L p .707 .577 .707 r
F P
0 g
s
.45117 .63589 m .45361 .67312 L .47763 .66651 L p .707 .577 .707 r
F P
0 g
s
.47763 .66651 m .47519 .62928 L .45117 .63589 L p .707 .577 .707 r
F P
0 g
s
.83053 .72153 m .82772 .73953 L .81539 .72825 L p .707 .577 .707 r
F P
0 g
s
.81539 .72825 m .8182 .71025 L .83053 .72153 L p .707 .577 .707 r
F P
0 g
s
.66882 .63458 m .65658 .57916 L .68028 .57028 L p .707 .577 .707 r
F P
0 g
s
.3047 .56501 m .31693 .62044 L .33729 .62055 L p .707 .577 .707 r
F P
0 g
s
.33157 .64129 m .33401 .67852 L .36139 .68083 L p .707 .577 .707 r
F P
0 g
s
.82624 .63333 m .82868 .67056 L .80769 .66599 L p .707 .577 .707 r
F P
0 g
s
.80769 .66599 m .80525 .62876 L .82624 .63333 L p .707 .577 .707 r
F P
0 g
s
.63594 .70829 m .63875 .69029 L .65506 .68368 L p .707 .577 .707 r
F P
0 g
s
.37947 .72357 m .38228 .70558 L .35147 .69893 L p .707 .577 .707 r
F P
0 g
s
.38228 .70558 m .37947 .72357 L .41098 .72708 L p .707 .577 .707 r
F P
0 g
s
.41098 .72708 m .41379 .70908 L .38228 .70558 L p .707 .577 .707 r
F P
0 g
s
.79732 .54698 m .80956 .60241 L .78288 .60504 L p .707 .577 .707 r
F P
0 g
s
.78288 .60504 m .77064 .54962 L .79732 .54698 L p .707 .577 .707 r
F P
0 g
s
.33401 .67852 m .33157 .64129 L .31057 .63672 L p .707 .577 .707 r
F P
0 g
s
.65506 .68368 m .65225 .70167 L .63594 .70829 L p .707 .577 .707 r
F P
0 g
s
.41379 .70908 m .41098 .72708 L .4401 .7271 L p .707 .577 .707 r
F P
0 g
s
.4401 .7271 m .44291 .7091 L .41379 .70908 L p .707 .577 .707 r
F P
0 g
s
.68028 .57028 m .69251 .6257 L .66882 .63458 L p .707 .577 .707 r
F P
0 g
s
.34866 .71693 m .35147 .69893 L .32438 .68979 L p .707 .577 .707 r
F P
0 g
s
.35147 .69893 m .34866 .71693 L .37947 .72357 L p .707 .577 .707 r
F P
0 g
s
.31693 .62044 m .3047 .56501 L .29266 .56216 L p .707 .577 .707 r
F P
0 g
s
.66406 .678 m .66163 .64077 L .68565 .63416 L p .707 .577 .707 r
F P
0 g
s
.32438 .68979 m .32157 .70779 L .34866 .71693 L p .707 .577 .707 r
F P
0 g
s
.31057 .63672 m .31301 .67395 L .33401 .67852 L p .707 .577 .707 r
F P
0 g
s
.47519 .62928 m .47763 .66651 L .49399 .65882 L p .707 .577 .707 r
F P
0 g
s
.49399 .65882 m .49155 .62159 L .47519 .62928 L p .707 .577 .707 r
F P
0 g
s
.69251 .6257 m .68028 .57028 L .70911 .56186 L p .707 .577 .707 r
F P
0 g
s
.48204 .52446 m .49428 .57989 L .50148 .57264 L p .707 .577 .707 r
F P
0 g
s
.50148 .57264 m .48925 .51721 L .48204 .52446 L p .707 .577 .707 r
F P
0 g
s
.44291 .7091 m .4401 .7271 L .46398 .72363 L p .707 .577 .707 r
F P
0 g
s
.46398 .72363 m .46679 .70563 L .44291 .7091 L p .707 .577 .707 r
F P
0 g
s
.77064 .54962 m .78288 .60504 L .75248 .61017 L p .707 .577 .707 r
F P
0 g
s
.75248 .61017 m .74024 .55474 L .77064 .54962 L p .707 .577 .707 r
F P
0 g
s
.68565 .63416 m .68809 .67139 L .66406 .678 L p .707 .577 .707 r
F P
0 g
s
.29266 .56216 m .30489 .61759 L .31693 .62044 L p .707 .577 .707 r
F P
0 g
s
.32157 .70779 m .32438 .68979 L .30365 .67906 L p .707 .577 .707 r
F P
0 g
s
.80525 .62876 m .80769 .66599 L .7803 .66368 L p .707 .577 .707 r
F P
0 g
s
.7803 .66368 m .77786 .62645 L .80525 .62876 L p .707 .577 .707 r
F P
0 g
s
.8182 .71025 m .81539 .72825 L .79466 .71751 L p .707 .577 .707 r
F P
0 g
s
.79466 .71751 m .79747 .69952 L .8182 .71025 L p .707 .577 .707 r
F P
0 g
s
.65225 .70167 m .65506 .68368 L .67894 .68021 L p .707 .577 .707 r
F P
0 g
s
.70911 .56186 m .72134 .61729 L .69251 .6257 L p .707 .577 .707 r
F P
0 g
s
.72134 .61729 m .70911 .56186 L .74024 .55474 L p .707 .577 .707 r
F P
0 g
s
.30365 .67906 m .30084 .69705 L .32157 .70779 L p .707 .577 .707 r
F P
0 g
s
.74024 .55474 m .75248 .61017 L .72134 .61729 L p .707 .577 .707 r
F P
0 g
s
.31301 .67395 m .31057 .63672 L .29803 .63032 L p .707 .577 .707 r
F P
0 g
s
.68809 .67139 m .68565 .63416 L .71498 .62929 L p .707 .577 .707 r
F P
0 g
s
.67894 .68021 m .67613 .69821 L .65225 .70167 L p .707 .577 .707 r
F P
0 g
s
.29803 .63032 m .30047 .66756 L .31301 .67395 L p .707 .577 .707 r
F P
0 g
s
.77786 .62645 m .7803 .66368 L .74919 .66386 L p .707 .577 .707 r
F P
0 g
s
.74919 .66386 m .74676 .62663 L .77786 .62645 L p .707 .577 .707 r
F P
0 g
s
.46679 .70563 m .46398 .72363 L .4803 .71701 L p .707 .577 .707 r
F P
0 g
s
.4803 .71701 m .4831 .69902 L .46679 .70563 L p .707 .577 .707 r
F P
0 g
s
.30489 .61759 m .29266 .56216 L .29012 .55685 L p .707 .577 .707 r
F P
0 g
s
.71498 .62929 m .71742 .66652 L .68809 .67139 L p .707 .577 .707 r
F P
0 g
s
.49155 .62159 m .49399 .65882 L .50108 .65078 L p .707 .577 .707 r
F P
0 g
s
.50108 .65078 m .49864 .61355 L .49155 .62159 L p .707 .577 .707 r
F P
0 g
s
.30084 .69705 m .30365 .67906 L .29132 .66778 L p .707 .577 .707 r
F P
0 g
s
.71742 .66652 m .71498 .62929 L .74676 .62663 L p .707 .577 .707 r
F P
0 g
s
.79747 .69952 m .79466 .71751 L .76757 .70837 L p .707 .577 .707 r
F P
0 g
s
.76757 .70837 m .77038 .69038 L .79747 .69952 L p .707 .577 .707 r
F P
0 g
s
.74676 .62663 m .74919 .66386 L .71742 .66652 L p .707 .577 .707 r
F P
0 g
s
.67613 .69821 m .67894 .68021 L .70806 .68023 L p .707 .577 .707 r
F P
0 g
s
.48925 .51721 m .50148 .57264 L .49894 .56733 L p .707 .577 .707 r
F P
0 g
s
.49894 .56733 m .48671 .5119 L .48925 .51721 L p .707 .577 .707 r
F P
0 g
s
.29132 .66778 m .28851 .68577 L .30084 .69705 L p .707 .577 .707 r
F P
0 g
s
.29012 .55685 m .30235 .61227 L .30489 .61759 L p .707 .577 .707 r
F P
0 g
s
.70806 .68023 m .70525 .69822 L .67613 .69821 L p .707 .577 .707 r
F P
0 g
s
.30047 .66756 m .29803 .63032 L .29516 .62274 L p .707 .577 .707 r
F P
0 g
s
.77038 .69038 m .76757 .70837 L .73676 .70173 L p .707 .577 .707 r
F P
0 g
s
.73676 .70173 m .73957 .68373 L .77038 .69038 L p .707 .577 .707 r
F P
0 g
s
.70525 .69822 m .70806 .68023 L .73957 .68373 L p .707 .577 .707 r
F P
0 g
s
.73957 .68373 m .73676 .70173 L .70525 .69822 L p .707 .577 .707 r
F P
0 g
s
.29516 .62274 m .2976 .65997 L .30047 .66756 L p .707 .577 .707 r
F P
0 g
s
.4831 .69902 m .4803 .71701 L .48744 .7079 L p .707 .577 .707 r
F P
0 g
s
.48744 .7079 m .49025 .6899 L .4831 .69902 L p .707 .577 .707 r
F P
0 g
s
.28851 .68577 m .29132 .66778 L .28859 .65705 L p .707 .577 .707 r
F P
0 g
s
.49864 .61355 m .50108 .65078 L .49821 .6432 L p .707 .577 .707 r
F P
0 g
s
.49821 .6432 m .49578 .60597 L .49864 .61355 L p .707 .577 .707 r
F P
0 g
s
.30235 .61227 m .29012 .55685 L .29733 .5496 L p .707 .577 .707 r
F P
0 g
s
.28859 .65705 m .28578 .67505 L .28851 .68577 L p .707 .577 .707 r
F P
0 g
s
.48671 .5119 m .49894 .56733 L .48691 .56448 L p .707 .577 .707 r
F P
0 g
s
.48691 .56448 m .47467 .50905 L .48671 .5119 L p .707 .577 .707 r
F P
0 g
s
.29733 .5496 m .30956 .60502 L .30235 .61227 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2976 .65997 m .29516 .62274 L .30226 .61471 L p .707 .577 .707 r
F P
0 g
s
.49025 .6899 m .48744 .7079 L .48471 .69717 L p .707 .577 .707 r
F P
0 g
s
.48471 .69717 m .48752 .67918 L .49025 .6899 L p .707 .577 .707 r
F P
0 g
s
.30226 .61471 m .3047 .65194 L .2976 .65997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28578 .67505 m .28859 .65705 L .29573 .64794 L p .707 .577 .707 r
F P
0 g
s
.30956 .60502 m .29733 .5496 L .31357 .54112 L p .707 .577 .707 r
F P
0 g
s
.49578 .60597 m .49821 .6432 L .48567 .6368 L p .707 .577 .707 r
F P
0 g
s
.48567 .6368 m .48323 .59957 L .49578 .60597 L p .707 .577 .707 r
F P
0 g
s
.29573 .64794 m .29293 .66593 L .28578 .67505 L p .707 .577 .707 r
F P
0 g
s
.47467 .50905 m .48691 .56448 L .46655 .56436 L p .707 .577 .707 r
F P
0 g
s
.46655 .56436 m .45431 .50894 L .47467 .50905 L p .707 .577 .707 r
F P
0 g
s
.31357 .54112 m .32581 .59654 L .30956 .60502 L p .707 .577 .707 r
F P
0 g
s
.3047 .65194 m .30226 .61471 L .31862 .60701 L p .707 .577 .707 r
F P
0 g
s
.48752 .67918 m .48471 .69717 L .47238 .68589 L p .707 .577 .707 r
F P
0 g
s
.47238 .68589 m .47519 .6679 L .48752 .67918 L p .707 .577 .707 r
F P
0 g
s
.31862 .60701 m .32105 .64424 L .3047 .65194 L p .707 .577 .707 r
F P
0 g
s
.32581 .59654 m .31357 .54112 L .33727 .53223 L p .707 .577 .707 r
F P
0 g
s
.29293 .66593 m .29573 .64794 L .31205 .64132 L p .707 .577 .707 r
F P
0 g
s
.48323 .59957 m .48567 .6368 L .46468 .63223 L p .707 .577 .707 r
F P
0 g
s
.46468 .63223 m .46224 .595 L .48323 .59957 L p .707 .577 .707 r
F P
0 g
s
.45431 .50894 m .46655 .56436 L .43987 .567 L p .707 .577 .707 r
F P
0 g
s
.43987 .567 m .42763 .51158 L .45431 .50894 L p .707 .577 .707 r
F P
0 g
s
.31205 .64132 m .30924 .65932 L .29293 .66593 L p .707 .577 .707 r
F P
0 g
s
.33727 .53223 m .3495 .58766 L .32581 .59654 L p .707 .577 .707 r
F P
0 g
s
.32105 .64424 m .31862 .60701 L .34264 .6004 L p .707 .577 .707 r
F P
0 g
s
.3495 .58766 m .33727 .53223 L .3661 .52382 L p .707 .577 .707 r
F P
0 g
s
.42763 .51158 m .43987 .567 L .40947 .57213 L p .707 .577 .707 r
F P
0 g
s
.40947 .57213 m .39723 .5167 L .42763 .51158 L p .707 .577 .707 r
F P
0 g
s
.47519 .6679 m .47238 .68589 L .45165 .67516 L p .707 .577 .707 r
F P
0 g
s
.45165 .67516 m .45446 .65716 L .47519 .6679 L p .707 .577 .707 r
F P
0 g
s
.34264 .6004 m .34508 .63763 L .32105 .64424 L p .707 .577 .707 r
F P
0 g
s
.46224 .595 m .46468 .63223 L .43729 .62992 L p .707 .577 .707 r
F P
0 g
s
.43729 .62992 m .43485 .59269 L .46224 .595 L p .707 .577 .707 r
F P
0 g
s
.30924 .65932 m .31205 .64132 L .33593 .63785 L p .707 .577 .707 r
F P
0 g
s
.3661 .52382 m .37833 .57925 L .3495 .58766 L p .707 .577 .707 r
F P
0 g
s
.37833 .57925 m .3661 .52382 L .39723 .5167 L p .707 .577 .707 r
F P
0 g
s
.39723 .5167 m .40947 .57213 L .37833 .57925 L p .707 .577 .707 r
F P
0 g
s
.33593 .63785 m .33312 .65585 L .30924 .65932 L p .707 .577 .707 r
F P
0 g
s
.34508 .63763 m .34264 .6004 L .37197 .59553 L p .707 .577 .707 r
F P
0 g
s
.43485 .59269 m .43729 .62992 L .40618 .6301 L p .707 .577 .707 r
F P
0 g
s
.40618 .6301 m .40375 .59287 L .43485 .59269 L p .707 .577 .707 r
F P
0 g
s
.37197 .59553 m .37441 .63276 L .34508 .63763 L p .707 .577 .707 r
F P
0 g
s
.45446 .65716 m .45165 .67516 L .42456 .66602 L p .707 .577 .707 r
F P
0 g
s
.42456 .66602 m .42737 .64802 L .45446 .65716 L p .707 .577 .707 r
F P
0 g
s
.37441 .63276 m .37197 .59553 L .40375 .59287 L p .707 .577 .707 r
F P
0 g
s
.33312 .65585 m .33593 .63785 L .36505 .63787 L p .707 .577 .707 r
F P
0 g
s
.40375 .59287 m .40618 .6301 L .37441 .63276 L p .707 .577 .707 r
F P
0 g
s
.36505 .63787 m .36224 .65587 L .33312 .65585 L p .707 .577 .707 r
F P
0 g
s
.42737 .64802 m .42456 .66602 L .39375 .65937 L p .707 .577 .707 r
F P
0 g
s
.39375 .65937 m .39656 .64138 L .42737 .64802 L p .707 .577 .707 r
F P
0 g
s
.36224 .65587 m .36505 .63787 L .39656 .64138 L p .707 .577 .707 r
F P
0 g
s
.39656 .64138 m .39375 .65937 L .36224 .65587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6@00O7oo001oOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Uoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0075oo`00M7oo1@00
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00KWoo001_
Ool50002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH3001/Ool006]oo`@000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Yoo`00JGoo0P0000=JEP00FUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0Igoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIY
Ool006Eoo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Ioo`00I7oo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IWoo001TOol20006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1VOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Ioo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0IWoo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1V
Ool006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP03001oogoo06Ioo`00Hgoo
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001SOol00`00FUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006=oo`03001JEP0000MJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0I7oo001TOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001J
EP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH:000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00=JEPT000=J
EP03001JEUYF009JEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<006Aoo`00IWoo00<005YF00000UYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol50005FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001TOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001QOol30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001NOol30008FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005]oo`<00003
FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00FGoo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001EOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000VOol;000cOol005Aoo`03001JEUYF00=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
01ioo`P000=JEP03001JEUYF00=JEP04001JEP00000aOol005=oo`8000EJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8001Moo`L000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080031oo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P004goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF001JES1oo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000?
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001B
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YFFUIJEP/00003FUH0000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH00UYF100015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`000eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;goo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70006FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000_Ool005=oo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF100025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEP000080
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080
02ioo`00E7oo00@005YFFUH000AJEP03001JEUYF00=JEP@000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF
00<005YF00000`000eYF00<005YFFUH01UYF4@000UYF00<005YF00000`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002eoo`00E7oo00@005YFFUH000AJEP<000IJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH8
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Aoo`04001JEUYF0003FUH01@00FUIJEP00FUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008002eoo`00D7oo1@000eYF0`0000=JEP0000000P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol0:goo001<
Ool40002FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF1@00;7oo0018Ool40006
FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000/Ool0
04Aoo`@00003FUH005YF00QJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000]Ool003moo`D000IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP03001oogoo02eoo`00>goo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool003Qoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000aOol003Ioo`<000UJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH0
0002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0M0002FUH2000cOol003Ao
o`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF00AJEP03001JEUYF00AJEQd000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol0035oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP0400000eYF001JEP02FUH50008FUH00`00FUIJEP040004FUH3000015YF001JEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH30000
0eYF000000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000aOol002moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUHA0002FUH50007FUH40002FUH00`00FUIJEP04FUH00`00FUH000020000
0eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF
00D005YF000005YF00<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPh000IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH50004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
000/Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000[Ool00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00:goo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<00003FUH0
05YF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002]oo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH00eYF0`001EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF10000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`001UYF00<005YFFUH01UYF0`000eYF00@005YFFUIJEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH900001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUH005YF0`000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001UYF00<005YFFUH0
0eYF0`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP00004Ool00000000=Ool70003FUH01@00FUIJEUYF0000
;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF100025YF00<005YF0000
0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJ
EP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00009JEP05001JEUYFFUH00005FUH60008Ool50009Ool50005FUH40003FUH00`00Oomoo`0[Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP06FUH3
00000eYF001JEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF0`0000=JEP00FUH01EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000UYF00H005YFFUIJEP00FUH60002FUH20008Ool>0003FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
00000P001UYF00<005YFFUH01UYF0`000UYF00H005YFFUIJEP00FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90002FUH20005FUH01000FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH200000eYF001JEP02FUHB0004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03
FUH40008FUH00`00FUIJEP06FUH30003FUH01000FUIJEP001UYF50001eYF00<005YFFUH00eYF0P00
0eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYF001JEP00FUH00P000UYF40000UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Goo000]Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH0
1EYF30000eYF100015YF0P0027oo00@005YFFUH0009JEPD000QJEP03001JEUYF00EJEP800003FUH0
05YF009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYF001JEP060002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00@005YFFUH000AJEP<000MJEPP000AJEP03
001JEUYF00AJEP05001JEUYFFUH00002FUH60009Ool01000FUIJEP000UYF1@0025YF00<005YFFUH0
1eYF0P000eYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8002ioo`00;Goo00@005YFFUH000=JEP05001JEUYF001J
EP060003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH300000eYF000000020005
Ool01000FUIJEP000UYF1@0025YF00<005YFFUH02EYF00D005YF001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00=JEP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002eoo`04
001JEUYFFUH300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0006FUH00`00FUH000060003Ool01000FUIJEP000eYF100025YF00<005YFFUH02EYF0`0000=JEP00
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
15YF00@005YFFUH0031oo`00;Woo0eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P001UYF00<005YFFUH00eYF10000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP<00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEP0000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH3000a
Ool002ioo`06FUH00000001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP800003FUH0000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000IJEP03001JEUYF00EJEP<0
00=JEP8003=oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH015YF1`0000=JEP00FUH01eYF
00<005YFFUH00eYF1@000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P0000IJEP00000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP03000eOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEQ0000=JEP07001JEUYFFUH005YF00002EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YF000000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000EJEP03001JEUYF00=JEP8003Aoo`00;Goo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP80009JEPL000AJEP03001JEUYF00IJEP03001J
EUYF009JEPP000=JEP03001JEUYF00AJEP8003=oo`00;7oo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH40003FUH20007FUHD0008Ool200000eYF001J
EP05FUH00`00FUH0000bOol002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH00eYF0P000UYF00<005YFFUH01P000UYF0P003Goo1@00
2goo0P001EYF00D005YFFUIJEP00035oo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF5`0015YF00D005YFFUH007oo00P000AJEP03001JEUYF00IJEP04001J
EUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2
0003FUH01000FUH000000UYF00<005YF00000P003Woo1@003Goo0P000eYF00<005YFFUH00UYF00<0
07ooOol0;Woo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF30002goo1P00
0UYF0`0000AJEP00FUIJEP<0009JEP03001JEUYF009JEQ4000MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH2000<
Ool5000?Ool200000eYF001JEP03FUH00`00Oomoo`0^Ool002aoo`04001JEUYF0004FUHA0002Ool5
0007Ool40002FUH00`00FUIJEP04FUH01000FUH000000UYF0`000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH015YF00D005YFFUIJEP00009JEP800003FUH005YF00AJEP<000]oo`<0019oo`8000AJEP03001o
ogoo02ioo`00;7oo00D005YFFUH005YF00@000=JEP03001JEUYF00EJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00AJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP0015YF0`0015YF00<005YFFUH00P0087oo00<005YFFUH00P00<7oo000]Ool00`00FUH000020006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YF00001000
0eYF00<007ooOol07goo1000<7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF1P008Goo0`00<7oo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH015YF00<005YFFUH00UYF00@005YF000000YJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol5000`Ool002aoo`80009JEP04001JEUYFFUH@0004
FUH00`00FUIJEP07FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF0P0000=oo`00FUH02EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF5@0025YF00<005YFFUH02eYF0`0025YF00<0
05YFFUH015YF1`0047oo1@000UYF00<005YF0000<7oo000[Ool20003FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH20005FUH01000FUIJEUYF0P000goo2UYF00<0
05YFFUH01UYF00<005YFFUH01eYF2@0035YF00<005YFFUH01UYF1P000UYF00<005YFFUH02eYF1000
1UYF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH0000`Ool002]oo`80
0005FUH00000FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<0
05YFFUH01UYF0`000eYF00@005YF000000Eoo`YJEP03001JEUYF00IJEP04001JEUYFFUH60008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05000;FUH20002FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000[Ool4
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP050007Ool:FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH2
000:FUH00`00FUIJEP05FUH50006FUH700000eYF000000030006FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Woo000ZOol20003Ool30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00eYF0P0027oo2UYF
00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000=JEP8000EJEP@0009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP00000dOol002Yoo`<000Aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH20007Ool9FUH400000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH200000eYF00000005FUH01000FUIJEUYF0P0000AJEP00Oomoo`L000AJEP03001JEUYF
00EJEP04001JEUYFFUH5000fOol002Yoo`800003FUH0000000Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPT0009oo`8000IJEP03001JEP0000Ioo`MJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000EJEP03001JEUYF009JEP<000Uooa0003]oo`00:Woo0P000eYF00<007ooOol017oo5`00
3Goo0P000eYF00D005YFFUIJEP0000Eoo`EJEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP02FUH00`00FUH0001DOol002]oo`04001JEUYFFUH3000EOol5000@Ool200000eYF001J
EP02FUH00`00Oomoo`03Ool3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF
00L005YFFUIJEP00FUH0001DOol002]oo`05001JEUYFFUH00002FUH2000COol5000BOol20003FUH2
0004Ool2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000IJEP04001JEUYFFUH2
001EOol002aoo`03001JEP0000EJEP<0011oo`D001Aoo`05001JEP00FUH00004Ool00eYF001JEP03
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP8005Eoo`00;Goo
0P001UYF00<005YF00000`003Goo0`005Woo0P0000=JEP00Ool00goo00=JEP00FUH00eYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000IJEP05001JEUYFFUH0001FOol002ioo`03001JEUYF
00AJEP03001JEUYF00=JEP@0029oo`800003FUH007oo00=oo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00mJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH005YF00EJEP04001JEP00001GOol002moo`8000=JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`800003FUH0000000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH0000000EJEP<005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`0047oo1@00
0eYF0P001Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEPH005aoo`00<goo
0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH00006Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00P00GGoo000fOol20004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
27oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF20000eYF00<005YFFUH00eYF0P00Fgoo000hOol300000eYF001J
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool3
0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP040008Ool200000eYF001JEP05FUH2001JOol003]oo`D000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00<000eoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEPH000aoo`8000IJEP04001JEP00001HOol0041oo`T000AJ
EP03001JEUYF00IJEP04001JEUYFFUH5000COol40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP02FUH60002Ool5000=Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1EOol004Uooa4001aoo`P000EJEP03001JEUYF00UJEP03001JEUYF009JEPd000Qoo`D000moo`80
0003FUH005YF00=JEP03001oogoo05Eoo`00OWoo5`0057oo1@004Goo0P0015YF00<007ooOol0EGoo
002=Ool01000FUIJEP0015YF0`004Woo0`0057oo00<005YFFUH00P00Egoo002>Ool30005FUH00`00
FUH00003000VOol4001GOol0091oo`03001JEUYF00=JEP03001JEUYF00=JEPD0029oo`<005Moo`00
TGoo0P000UYF00<005YFFUH01UYF00<005YFFUH0100077oo1@00Egoo002COol30008FUH00`00FUIJ
EP04FUH7000@Ool50002FUH00`00FUH0001GOol009Eoo`8000IJEP03001JEUYF00MJEP03001JEUYF
009JEQ0000=JEP07001JEUYFFUH005YF0000Egoo002GOol20004FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00F7oo002IOol300000eYF001J
EP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001HOol0
09aoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<005Uo
o`00XWoo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005aoo`00Zgoo4000HWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60178 .73811 m .58226 .68425 L .55311 .69364 L p .707 .577 .707 r
F P
0 g
s
.58226 .68425 m .60178 .73811 L .6318 .72714 L p .707 .577 .707 r
F P
0 g
s
.6318 .72714 m .61228 .67328 L .58226 .68425 L p .707 .577 .707 r
F P
0 g
s
.61228 .67328 m .6318 .72714 L .65974 .71567 L p .707 .577 .707 r
F P
0 g
s
.65974 .71567 m .64022 .66182 L .61228 .67328 L p .707 .577 .707 r
F P
0 g
s
.55311 .69364 m .57262 .7475 L .60178 .73811 L p .707 .577 .707 r
F P
0 g
s
.57262 .7475 m .55311 .69364 L .52766 .70054 L p .707 .577 .707 r
F P
0 g
s
.64022 .66182 m .65974 .71567 L .68286 .70483 L p .707 .577 .707 r
F P
0 g
s
.68286 .70483 m .66335 .65097 L .64022 .66182 L p .707 .577 .707 r
F P
0 g
s
.52766 .70054 m .54717 .7544 L .57262 .7475 L p .707 .577 .707 r
F P
0 g
s
.59958 .80429 m .59564 .76703 L .56465 .76851 L p .707 .577 .707 r
F P
0 g
s
.59564 .76703 m .59958 .80429 L .63125 .80046 L p .707 .577 .707 r
F P
0 g
s
.63125 .80046 m .62731 .76321 L .59564 .76703 L p .707 .577 .707 r
F P
0 g
s
.62731 .76321 m .63125 .80046 L .66051 .79467 L p .707 .577 .707 r
F P
0 g
s
.66051 .79467 m .65657 .75742 L .62731 .76321 L p .707 .577 .707 r
F P
0 g
s
.56859 .80576 m .56465 .76851 L .53737 .76749 L p .707 .577 .707 r
F P
0 g
s
.56465 .76851 m .56859 .80576 L .59958 .80429 L p .707 .577 .707 r
F P
0 g
s
.54717 .7544 m .52766 .70054 L .50842 .70428 L p .707 .577 .707 r
F P
0 g
s
.66335 .65097 m .68286 .70483 L .69891 .69568 L p .707 .577 .707 r
F P
0 g
s
.69891 .69568 m .6794 .64182 L .66335 .65097 L p .707 .577 .707 r
F P
0 g
s
.65657 .75742 m .66051 .79467 L .68448 .78747 L p .707 .577 .707 r
F P
0 g
s
.68448 .78747 m .68054 .75022 L .65657 .75742 L p .707 .577 .707 r
F P
0 g
s
.53737 .76749 m .54131 .80474 L .56859 .80576 L p .707 .577 .707 r
F P
0 g
s
.50842 .70428 m .52794 .75814 L .54717 .7544 L p .707 .577 .707 r
F P
0 g
s
.54131 .80474 m .53737 .76749 L .51647 .76408 L p .707 .577 .707 r
F P
0 g
s
.57823 .86164 m .58274 .8442 L .55252 .83471 L p .707 .577 .707 r
F P
0 g
s
.58274 .8442 m .57823 .86164 L .6092 .86771 L p .707 .577 .707 r
F P
0 g
s
.6092 .86771 m .61372 .85027 L .58274 .8442 L p .707 .577 .707 r
F P
0 g
s
.54801 .85215 m .55252 .83471 L .52601 .82273 L p .707 .577 .707 r
F P
0 g
s
.55252 .83471 m .54801 .85215 L .57823 .86164 L p .707 .577 .707 r
F P
0 g
s
.61372 .85027 m .6092 .86771 L .6379 .86976 L p .707 .577 .707 r
F P
0 g
s
.6379 .86976 m .64242 .85232 L .61372 .85027 L p .707 .577 .707 r
F P
0 g
s
.51647 .76408 m .52041 .80133 L .54131 .80474 L p .707 .577 .707 r
F P
0 g
s
.68054 .75022 m .68448 .78747 L .70082 .77957 L p .707 .577 .707 r
F P
0 g
s
.70082 .77957 m .69688 .74232 L .68054 .75022 L p .707 .577 .707 r
F P
0 g
s
.52794 .75814 m .50842 .70428 L .49727 .70448 L p .707 .577 .707 r
F P
0 g
s
.52601 .82273 m .5215 .84017 L .54801 .85215 L p .707 .577 .707 r
F P
0 g
s
.6794 .64182 m .69891 .69568 L .70632 .6891 L p .707 .577 .707 r
F P
0 g
s
.70632 .6891 m .6868 .63524 L .6794 .64182 L p .707 .577 .707 r
F P
0 g
s
.49727 .70448 m .51678 .75834 L .52794 .75814 L p .707 .577 .707 r
F P
0 g
s
.5215 .84017 m .52601 .82273 L .50582 .80943 L p .707 .577 .707 r
F P
0 g
s
.64242 .85232 m .6379 .86976 L .66152 .8676 L p .707 .577 .707 r
F P
0 g
s
.66152 .8676 m .66603 .85016 L .64242 .85232 L p .707 .577 .707 r
F P
0 g
s
.52041 .80133 m .51647 .76408 L .50401 .75861 L p .707 .577 .707 r
F P
0 g
s
.50582 .80943 m .5013 .82688 L .5215 .84017 L p .707 .577 .707 r
F P
0 g
s
.50401 .75861 m .50795 .79586 L .52041 .80133 L p .707 .577 .707 r
F P
0 g
s
.69688 .74232 m .70082 .77957 L .70793 .77174 L p .707 .577 .707 r
F P
0 g
s
.70793 .77174 m .70399 .73449 L .69688 .74232 L p .707 .577 .707 r
F P
0 g
s
.51678 .75834 m .49727 .70448 L .4953 .70113 L p .707 .577 .707 r
F P
0 g
s
.5013 .82688 m .50582 .80943 L .49391 .79612 L p .707 .577 .707 r
F P
0 g
s
.66603 .85016 m .66152 .8676 L .67774 .86144 L p .707 .577 .707 r
F P
0 g
s
.67774 .86144 m .68225 .844 L .66603 .85016 L p .707 .577 .707 r
F P
0 g
s
.6868 .63524 m .70632 .6891 L .70434 .68575 L p .707 .577 .707 r
F P
0 g
s
.70434 .68575 m .68483 .63189 L .6868 .63524 L p .707 .577 .707 r
F P
0 g
s
.4953 .70113 m .51481 .75499 L .51678 .75834 L p .707 .577 .707 r
F P
0 g
s
.49391 .79612 m .48939 .81356 L .5013 .82688 L p .707 .577 .707 r
F P
0 g
s
.50795 .79586 m .50401 .75861 L .50119 .75162 L p .707 .577 .707 r
F P
0 g
s
.51481 .75499 m .4953 .70113 L .5027 .69456 L p .707 .577 .707 r
F P
0 g
s
.5027 .69456 m .52222 .74841 L .51481 .75499 L p .707 .577 .707 r
F P
0 g
s
.50119 .75162 m .50513 .78887 L .50795 .79586 L p .707 .577 .707 r
F P
0 g
s
.50513 .78887 m .50119 .75162 L .50831 .74379 L p .707 .577 .707 r
F P
0 g
s
.50831 .74379 m .51225 .78104 L .50513 .78887 L p .707 .577 .707 r
F P
0 g
s
.52222 .74841 m .5027 .69456 L .51875 .6854 L p .707 .577 .707 r
F P
0 g
s
.51875 .6854 m .53827 .73926 L .52222 .74841 L p .707 .577 .707 r
F P
0 g
s
.51225 .78104 m .50831 .74379 L .52465 .73589 L p .707 .577 .707 r
F P
0 g
s
.49417 .79196 m .49868 .77452 L .5149 .76836 L p .707 .577 .707 r
F P
0 g
s
.5149 .76836 m .51039 .7858 L .49417 .79196 L p .707 .577 .707 r
F P
0 g
s
.52465 .73589 m .52859 .77314 L .51225 .78104 L p .707 .577 .707 r
F P
0 g
s
.53827 .73926 m .51875 .6854 L .54188 .67456 L p .707 .577 .707 r
F P
0 g
s
.54188 .67456 m .56139 .72842 L .53827 .73926 L p .707 .577 .707 r
F P
0 g
s
.52859 .77314 m .52465 .73589 L .54862 .72869 L p .707 .577 .707 r
F P
0 g
s
.51039 .7858 m .5149 .76836 L .53075 .76691 L p .707 .577 .707 r
F P
0 g
s
.54862 .72869 m .55256 .76594 L .52859 .77314 L p .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .55991 .81633 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53075 .76691 m .53843 .7662 L p .5289 .7729 L .707 .577 .707 r
F P
0 g
s
.5289 .7729 m .53843 .7662 L .53839 .76628 L .707 .577 .707 r
F
.51039 .7858 m .53075 .76691 L .5289 .7729 L F
.51492 .8182 m .51508 .82043 L p .54815 .74469 L F P
0 g
s
.53852 .76619 m .534 .78364 L .51039 .7858 L p .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .51492 .8182 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53843 .7662 m .53852 .76619 L p .53839 .76628 L .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .43391 .31667 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .51492 .8182 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51492 .8182 m .47779 .31603 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .54188 .67456 L .55517 .66911 L p .707 .577 .707 r
F P
0 g
s
.55517 .66911 m .56982 .66309 L p .56728 .68279 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .55517 .66911 L .56728 .68279 L .707 .577 .707 r
F
.52263 .31193 m .47779 .31603 L p .53133 .64217 L F P
0 g
s
.56982 .66309 m .58933 .71695 L .56139 .72842 L p .707 .577 .707 r
F P
0 g
s
.55256 .76594 m .54862 .72869 L .57787 .72289 L p .707 .577 .707 r
F P
0 g
s
.57787 .72289 m .58181 .76014 L .55256 .76594 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .54847 .66154 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.54847 .66154 m .52263 .31193 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.58933 .71695 m .57714 .68329 L p .59984 .65213 L .707 .577 .707 r
F P
0 g
s
.57714 .68329 m .56982 .66309 L .57935 .65961 L p .707 .577 .707 r
F P
0 g
s
.57935 .65961 m .59984 .65213 L p .57714 .68329 L .707 .577 .707 r
F P
0 g
s
.629 .64273 m .64851 .69659 L .61935 .70598 L p .707 .577 .707 r
F P
0 g
s
.61935 .70598 m .59984 .65213 L .629 .64273 L p .707 .577 .707 r
F P
0 g
s
.59984 .65213 m .61935 .70598 L .58933 .71695 L p .707 .577 .707 r
F P
0 g
s
.64054 .7176 m .64448 .75485 L .61349 .75632 L p .707 .577 .707 r
F P
0 g
s
.61349 .75632 m .60955 .71907 L .64054 .7176 L p .707 .577 .707 r
F P
0 g
s
.58181 .76014 m .57787 .72289 L .60955 .71907 L p .707 .577 .707 r
F P
0 g
s
.60955 .71907 m .61349 .75632 L .58181 .76014 L p .707 .577 .707 r
F P
0 g
s
.65492 .79578 m .6504 .81323 L .6239 .80125 L p .707 .577 .707 r
F P
0 g
s
.6239 .80125 m .62841 .7838 L .65492 .79578 L p .707 .577 .707 r
F P
0 g
s
.62841 .7838 m .6239 .80125 L .59725 .79288 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .59986 .80943 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.58985 .77268 m .59819 .77432 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.55148 .70221 m .55991 .81633 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .5627 .78569 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59819 .77432 m .59579 .7836 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59579 .7836 m .59368 .79176 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .59819 .77432 L .62841 .7838 L p .707 .577 .707 r
F P
0 g
s
.52263 .31193 m .52368 .32625 L p .59778 .78725 L .707 .577 .707 r
F P
0 g
s
.59696 .79101 m .62841 .7838 L .59725 .79288 L .707 .577 .707 r
F
.60131 .80918 m .59786 .78739 L .59778 .78725 L F
.59786 .78739 m .52263 .31193 L .59778 .78725 L F
.52368 .32625 m .55148 .70221 L p .59579 .7836 L F P
0 g
s
.5627 .78569 m .56722 .76825 L .58985 .77268 L p .707 .577 .707 r
F P
0 g
s
.5627 .78569 m .58985 .77268 L .59185 .77635 L .707 .577 .707 r
F
.59725 .79288 m .59368 .79176 L p .59696 .79101 L F P
0 g
s
.59986 .80943 m .60131 .80918 L p .52368 .32625 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .63521 .79968 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.56402 .30479 m .58544 .59455 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.58544 .59455 m .60131 .80918 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .56402 .30479 L .52263 .31193 L p .707 .577 .707 r
F P
0 g
s
.70399 .73449 m .70793 .77174 L .70512 .76475 L p .707 .577 .707 r
F P
0 g
s
.70512 .76475 m .70118 .72749 L .70399 .73449 L p .707 .577 .707 r
F P
0 g
s
.48939 .81356 m .49391 .79612 L .49145 .78409 L p .707 .577 .707 r
F P
0 g
s
.68225 .844 m .67774 .86144 L .68497 .85187 L p .707 .577 .707 r
F P
0 g
s
.68497 .85187 m .68948 .83443 L .68225 .844 L p .707 .577 .707 r
F P
0 g
s
.47119 .82107 m .43391 .31667 L .39527 .31379 L p .707 .577 .707 r
F P
0 g
s
.49145 .78409 m .48693 .80153 L .48939 .81356 L p .707 .577 .707 r
F P
0 g
s
.48693 .80153 m .49145 .78409 L .49868 .77452 L p .707 .577 .707 r
F P
0 g
s
.49868 .77452 m .49417 .79196 L .48693 .80153 L p .707 .577 .707 r
F P
0 g
s
.43391 .31667 m .47119 .82107 L .51508 .82043 L p .707 .577 .707 r
F P
0 g
s
.68483 .63189 m .70434 .68575 L .69319 .68595 L p .707 .577 .707 r
F P
0 g
s
.69319 .68595 m .67368 .63209 L .68483 .63189 L p .707 .577 .707 r
F P
0 g
s
.63521 .79968 m .59792 .29528 L .56402 .30479 L p .707 .577 .707 r
F P
0 g
s
.25877 .69931 m .23925 .64545 L .2101 .65484 L p .707 .577 .707 r
F P
0 g
s
.23925 .64545 m .25877 .69931 L .28879 .68834 L p .707 .577 .707 r
F P
0 g
s
.28879 .68834 m .26927 .63448 L .23925 .64545 L p .707 .577 .707 r
F P
0 g
s
.26927 .63448 m .28879 .68834 L .31673 .67688 L p .707 .577 .707 r
F P
0 g
s
.31673 .67688 m .29721 .62302 L .26927 .63448 L p .707 .577 .707 r
F P
0 g
s
.43255 .81819 m .39527 .31379 L .36565 .30768 L p .707 .577 .707 r
F P
0 g
s
.39527 .31379 m .43255 .81819 L .47119 .82107 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70118 .72749 m .70512 .76475 L .69265 .75928 L p .707 .577 .707 r
F P
0 g
s
.69265 .75928 m .68871 .72203 L .70118 .72749 L p .707 .577 .707 r
F P
0 g
s
.2101 .65484 m .22961 .7087 L .25877 .69931 L p .707 .577 .707 r
F P
0 g
s
.22961 .7087 m .2101 .65484 L .18465 .66175 L p .707 .577 .707 r
F P
0 g
s
.68948 .83443 m .68497 .85187 L .68251 .83984 L p .707 .577 .707 r
F P
0 g
s
.68251 .83984 m .68703 .8224 L .68948 .83443 L p .707 .577 .707 r
F P
0 g
s
.29721 .62302 m .31673 .67688 L .33985 .66603 L p .707 .577 .707 r
F P
0 g
s
.33985 .66603 m .32034 .61218 L .29721 .62302 L p .707 .577 .707 r
F P
0 g
s
.18465 .66175 m .20417 .7156 L .22961 .7087 L p .707 .577 .707 r
F P
0 g
s
.67368 .63209 m .69319 .68595 L .67396 .68969 L p .707 .577 .707 r
F P
0 g
s
.67396 .68969 m .65444 .63583 L .67368 .63209 L p .707 .577 .707 r
F P
0 g
s
.64851 .69659 m .629 .64273 L .65444 .63583 L p .707 .577 .707 r
F P
0 g
s
.66782 .71862 m .67176 .75587 L .64448 .75485 L p .707 .577 .707 r
F P
0 g
s
.64448 .75485 m .64054 .7176 L .66782 .71862 L p .707 .577 .707 r
F P
0 g
s
.59792 .29528 m .63521 .79968 L .6583 .78875 L p .707 .577 .707 r
F P
0 g
s
.65444 .63583 m .67396 .68969 L .64851 .69659 L p .707 .577 .707 r
F P
0 g
s
.6583 .78875 m .62101 .28435 L .59792 .29528 L p .707 .577 .707 r
F P
0 g
s
.25657 .77242 m .25263 .73517 L .22164 .73664 L p .707 .577 .707 r
F P
0 g
s
.25263 .73517 m .25657 .77242 L .28824 .7686 L p .707 .577 .707 r
F P
0 g
s
.28824 .7686 m .28431 .73135 L .25263 .73517 L p .707 .577 .707 r
F P
0 g
s
.28431 .73135 m .28824 .7686 L .3175 .7628 L p .707 .577 .707 r
F P
0 g
s
.3175 .7628 m .31356 .72555 L .28431 .73135 L p .707 .577 .707 r
F P
0 g
s
.22558 .77389 m .22164 .73664 L .19436 .73562 L p .707 .577 .707 r
F P
0 g
s
.22164 .73664 m .22558 .77389 L .25657 .77242 L p .707 .577 .707 r
F P
0 g
s
.20417 .7156 m .18465 .66175 L .16541 .66548 L p .707 .577 .707 r
F P
0 g
s
.32034 .61218 m .33985 .66603 L .3559 .65688 L p .707 .577 .707 r
F P
0 g
s
.3559 .65688 m .33639 .60302 L .32034 .61218 L p .707 .577 .707 r
F P
0 g
s
.31356 .72555 m .3175 .7628 L .34147 .7556 L p .707 .577 .707 r
F P
0 g
s
.34147 .7556 m .33753 .71835 L .31356 .72555 L p .707 .577 .707 r
F P
0 g
s
.16541 .66548 m .18493 .71934 L .20417 .7156 L p .707 .577 .707 r
F P
0 g
s
.68871 .72203 m .69265 .75928 L .67176 .75587 L p .707 .577 .707 r
F P
0 g
s
.67176 .75587 m .66782 .71862 L .68871 .72203 L p .707 .577 .707 r
F P
0 g
s
.19436 .73562 m .1983 .77288 L .22558 .77389 L p .707 .577 .707 r
F P
0 g
s
.40294 .81207 m .36565 .30768 L .34796 .29893 L p .707 .577 .707 r
F P
0 g
s
.36565 .30768 m .40294 .81207 L .43255 .81819 L p .707 .577 .707 r
F P
0 g
s
.68703 .8224 m .68251 .83984 L .6706 .82652 L p .707 .577 .707 r
F P
0 g
s
.6706 .82652 m .67512 .80908 L .68703 .8224 L p .707 .577 .707 r
F P
0 g
s
.23522 .81586 m .23973 .79842 L .20951 .78893 L p .707 .577 .707 r
F P
0 g
s
.23973 .79842 m .23522 .81586 L .26619 .82193 L p .707 .577 .707 r
F P
0 g
s
.26619 .82193 m .27071 .80449 L .23973 .79842 L p .707 .577 .707 r
F P
0 g
s
.1983 .77288 m .19436 .73562 L .17346 .73221 L p .707 .577 .707 r
F P
0 g
s
.205 .80637 m .20951 .78893 L .18301 .77695 L p .707 .577 .707 r
F P
0 g
s
.20951 .78893 m .205 .80637 L .23522 .81586 L p .707 .577 .707 r
F P
0 g
s
.27071 .80449 m .26619 .82193 L .29489 .82398 L p .707 .577 .707 r
F P
0 g
s
.29489 .82398 m .29941 .80654 L .27071 .80449 L p .707 .577 .707 r
F P
0 g
s
.18493 .71934 m .16541 .66548 L .15426 .66568 L p .707 .577 .707 r
F P
0 g
s
.17346 .73221 m .1774 .76947 L .1983 .77288 L p .707 .577 .707 r
F P
0 g
s
.33753 .71835 m .34147 .7556 L .35781 .7477 L p .707 .577 .707 r
F P
0 g
s
.35781 .7477 m .35387 .71045 L .33753 .71835 L p .707 .577 .707 r
F P
0 g
s
.18301 .77695 m .17849 .79439 L .205 .80637 L p .707 .577 .707 r
F P
0 g
s
.62101 .28435 m .6583 .78875 L .66832 .77747 L p .707 .577 .707 r
F P
0 g
s
.66832 .77747 m .63103 .27307 L .62101 .28435 L p .707 .577 .707 r
F P
0 g
s
.33639 .60302 m .3559 .65688 L .36331 .6503 L p .707 .577 .707 r
F P
0 g
s
.36331 .6503 m .34379 .59644 L .33639 .60302 L p .707 .577 .707 r
F P
0 g
s
.15426 .66568 m .17378 .71954 L .18493 .71934 L p .707 .577 .707 r
F P
0 g
s
.17849 .79439 m .18301 .77695 L .16281 .76365 L p .707 .577 .707 r
F P
0 g
s
.29941 .80654 m .29489 .82398 L .31851 .82182 L p .707 .577 .707 r
F P
0 g
s
.31851 .82182 m .32302 .80438 L .29941 .80654 L p .707 .577 .707 r
F P
0 g
s
.67512 .80908 m .6706 .82652 L .6504 .81323 L p .707 .577 .707 r
F P
0 g
s
.6504 .81323 m .65492 .79578 L .67512 .80908 L p .707 .577 .707 r
F P
0 g
s
.16281 .76365 m .15829 .78109 L .17849 .79439 L p .707 .577 .707 r
F P
0 g
s
.1774 .76947 m .17346 .73221 L .161 .72675 L p .707 .577 .707 r
F P
0 g
s
.161 .72675 m .16494 .764 L .1774 .76947 L p .707 .577 .707 r
F P
0 g
s
.38525 .80332 m .34796 .29893 L .34393 .28839 L p .707 .577 .707 r
F P
0 g
s
.34796 .29893 m .38525 .80332 L .40294 .81207 L p .707 .577 .707 r
F P
0 g
s
.35387 .71045 m .35781 .7477 L .36492 .73987 L p .707 .577 .707 r
F P
0 g
s
.36492 .73987 m .36098 .70262 L .35387 .71045 L p .707 .577 .707 r
F P
0 g
s
.15829 .78109 m .16281 .76365 L .1509 .75034 L p .707 .577 .707 r
F P
0 g
s
.17378 .71954 m .15426 .66568 L .15229 .66233 L p .707 .577 .707 r
F P
0 g
s
.32302 .80438 m .31851 .82182 L .33473 .81566 L p .707 .577 .707 r
F P
0 g
s
.33473 .81566 m .33924 .79821 L .32302 .80438 L p .707 .577 .707 r
F P
0 g
s
.534 .78364 m .53852 .76619 L .56722 .76825 L p .707 .577 .707 r
F P
0 g
s
.34379 .59644 m .36331 .6503 L .36134 .64695 L p .707 .577 .707 r
F P
0 g
s
.36134 .64695 m .34182 .59309 L .34379 .59644 L p .707 .577 .707 r
F P
0 g
s
.1509 .75034 m .14638 .76778 L .15829 .78109 L p .707 .577 .707 r
F P
0 g
s
.15229 .66233 m .1718 .71619 L .17378 .71954 L p .707 .577 .707 r
F P
0 g
s
.56722 .76825 m .5627 .78569 L .534 .78364 L p .707 .577 .707 r
F P
0 g
s
.16494 .764 m .161 .72675 L .15819 .71975 L p .707 .577 .707 r
F P
0 g
s
.6587 .74814 m .66082 .73998 L p .64302 .7174 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .65935 .73378 L .64302 .7174 L .707 .577 .707 r
F
.627 .26254 m .66296 .74905 L p .66082 .73998 L F P
0 g
s
.64287 .66401 m .6371 .51819 L .66082 .73998 L .707 .577 .707 r
F
.6371 .51819 m .627 .26254 L .66082 .73998 L F
.66832 .77747 m .66469 .768 L p .65212 .58635 L F P
0 g
s
.66341 .75396 m .65212 .58635 L .66469 .768 L .707 .577 .707 r
F
.65212 .58635 m .65166 .56027 L .66832 .77747 L F
.63788 .36574 m .66832 .77747 L p .64106 .422 L F P
0 g
s
.627 .26254 m .63103 .27307 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .6525 .60754 L p .65212 .58635 L .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .66514 .6661 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.66116 .72934 m .65778 .72711 L p .66179 .73622 L .707 .577 .707 r
F P
0 g
s
.65778 .72711 m .64302 .7174 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .65778 .72711 L .65935 .73378 L .707 .577 .707 r
F
.60931 .25379 m .627 .26254 L p .64287 .66401 L F P
0 g
s
.64302 .7174 m .63851 .73484 L .6587 .74814 L p .707 .577 .707 r
F P
0 g
s
.64659 .75819 m .63816 .64406 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .60931 .25379 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63851 .73484 m .64302 .7174 L .63111 .70408 L p .707 .577 .707 r
F P
0 g
s
.63111 .70408 m .6266 .72152 L .63851 .73484 L p .707 .577 .707 r
F P
0 g
s
.6266 .72152 m .63111 .70408 L .6311 .70403 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .61406 .56259 L .63533 .69048 L .707 .577 .707 r
F
.6311 .70403 m .62865 .69205 L p .62687 .7176 L F P
0 g
s
.6266 .72152 m .6311 .70403 L .62687 .7176 L .707 .577 .707 r
F
.64659 .75819 m .61698 .75207 L p .61694 .74945 L F P
0 g
s
.62865 .69205 m .62414 .70949 L .6266 .72152 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .63533 .69048 L .64659 .75819 L .707 .577 .707 r
F
.60931 .25379 m .63515 .60339 L p .61406 .56259 L F P
0 g
s
.63515 .60339 m .64659 .75819 L p .61406 .56259 L .707 .577 .707 r
F P
0 g
s
.65317 .64515 m .65033 .63276 L .63448 .61244 L .707 .577 .707 r
F
.64563 .61224 m .63978 .61235 L p .65033 .63276 L F P
0 g
s
.63978 .61235 m .63448 .61244 L p .65033 .63276 L .707 .577 .707 r
F P
0 g
s
.63448 .61244 m .65352 .66501 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65352 .66501 m .65399 .6663 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64842 .55231 L .64106 .422 L .707 .577 .707 r
F
.6525 .60754 m .64842 .55231 L p .65212 .58635 L F P
0 g
s
.64842 .55231 m .627 .26254 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66514 .6661 m .68438 .66236 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.64563 .61224 m .65294 .63243 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.65294 .63243 m .66514 .6661 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.66322 .7307 m .66082 .73998 L p .68521 .76012 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .6587 .74814 L .66184 .74955 L p .707 .577 .707 r
F P
0 g
s
.66296 .74905 m .66428 .76694 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66184 .74955 m .68521 .76012 L p .66082 .73998 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .64659 .75819 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .66179 .73622 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .66322 .7307 L .66116 .72934 L p .707 .577 .707 r
F P
0 g
s
.66469 .768 m .66428 .76694 L p .66341 .75396 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64106 .422 L .65166 .56027 L .707 .577 .707 r
F
.66514 .6661 m .65294 .63243 L p .65317 .64515 L F P
0 g
s
.65294 .63243 m .64563 .61224 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .66487 .60851 L .65173 .61105 L p .707 .577 .707 r
F P
0 g
s
.65173 .61105 m .64563 .61224 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .65173 .61105 L .65229 .62086 L .707 .577 .707 r
F
.63103 .27307 m .63788 .36574 L p .64106 .422 L F P
0 g
s
.15819 .71975 m .16212 .75701 L .16494 .764 L p .707 .577 .707 r
F P
0 g
s
.14638 .76778 m .1509 .75034 L .14844 .73831 L p .707 .577 .707 r
F P
0 g
s
.36098 .70262 m .36492 .73987 L .36211 .73288 L p .707 .577 .707 r
F P
0 g
s
.36211 .73288 m .35817 .69563 L .36098 .70262 L p .707 .577 .707 r
F P
0 g
s
.33924 .79821 m .33473 .81566 L .34196 .80609 L p .707 .577 .707 r
F P
0 g
s
.34196 .80609 m .34648 .78865 L .33924 .79821 L p .707 .577 .707 r
F P
0 g
s
.14844 .73831 m .14392 .75575 L .14638 .76778 L p .707 .577 .707 r
F P
0 g
s
.1718 .71619 m .15229 .66233 L .15969 .65576 L p .707 .577 .707 r
F P
0 g
s
.34182 .59309 m .36134 .64695 L .35018 .64715 L p .707 .577 .707 r
F P
0 g
s
.35018 .64715 m .33067 .5933 L .34182 .59309 L p .707 .577 .707 r
F P
0 g
s
.15969 .65576 m .17921 .70962 L .1718 .71619 L p .707 .577 .707 r
F P
0 g
s
.34393 .28839 m .38122 .79279 L .38525 .80332 L p .707 .577 .707 r
F P
0 g
s
.38122 .79279 m .34393 .28839 L .35395 .27711 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16212 .75701 m .15819 .71975 L .1653 .71192 L p .707 .577 .707 r
F P
0 g
s
.1653 .71192 m .16924 .74918 L .16212 .75701 L p .707 .577 .707 r
F P
0 g
s
.14392 .75575 m .14844 .73831 L .15567 .72874 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34648 .78865 m .34196 .80609 L .3395 .79406 L p .707 .577 .707 r
F P
0 g
s
.3395 .79406 m .34402 .77662 L .34648 .78865 L p .707 .577 .707 r
F P
0 g
s
.35817 .69563 m .36211 .73288 L .34964 .72741 L p .707 .577 .707 r
F P
0 g
s
.34964 .72741 m .3457 .69016 L .35817 .69563 L p .707 .577 .707 r
F P
0 g
s
.15567 .72874 m .15116 .74618 L .14392 .75575 L p .707 .577 .707 r
F P
0 g
s
.17921 .70962 m .15969 .65576 L .17574 .6466 L p .707 .577 .707 r
F P
0 g
s
.33067 .5933 m .35018 .64715 L .33095 .65089 L p .707 .577 .707 r
F P
0 g
s
.33095 .65089 m .31143 .59703 L .33067 .5933 L p .707 .577 .707 r
F P
0 g
s
.17574 .6466 m .19526 .70046 L .17921 .70962 L p .707 .577 .707 r
F P
0 g
s
.16924 .74918 m .1653 .71192 L .18164 .70402 L p .707 .577 .707 r
F P
0 g
s
.39124 .78151 m .35395 .27711 L .37704 .26618 L p .707 .577 .707 r
F P
0 g
s
.35395 .27711 m .39124 .78151 L .38122 .79279 L p .707 .577 .707 r
F P
0 g
s
.15116 .74618 m .15567 .72874 L .17189 .72258 L p .707 .577 .707 r
F P
0 g
s
.18164 .70402 m .18558 .74127 L .16924 .74918 L p .707 .577 .707 r
F P
0 g
s
.34402 .77662 m .3395 .79406 L .32759 .78074 L p .707 .577 .707 r
F P
0 g
s
.32759 .78074 m .33211 .7633 L .34402 .77662 L p .707 .577 .707 r
F P
0 g
s
.3457 .69016 m .34964 .72741 L .32875 .724 L p .707 .577 .707 r
F P
0 g
s
.32875 .724 m .32481 .68675 L .3457 .69016 L p .707 .577 .707 r
F P
0 g
s
.19526 .70046 m .17574 .6466 L .19887 .63576 L p .707 .577 .707 r
F P
0 g
s
.17189 .72258 m .16738 .74002 L .15116 .74618 L p .707 .577 .707 r
F P
0 g
s
.31143 .59703 m .33095 .65089 L .3055 .65779 L p .707 .577 .707 r
F P
0 g
s
.3055 .65779 m .28599 .60393 L .31143 .59703 L p .707 .577 .707 r
F P
0 g
s
.19887 .63576 m .21838 .68962 L .19526 .70046 L p .707 .577 .707 r
F P
0 g
s
.61698 .75207 m .57969 .24767 L .60931 .25379 L p .707 .577 .707 r
F P
0 g
s
.18558 .74127 m .18164 .70402 L .20561 .69682 L p .707 .577 .707 r
F P
0 g
s
.21838 .68962 m .19887 .63576 L .22681 .62429 L p .707 .577 .707 r
F P
0 g
s
.28599 .60393 m .3055 .65779 L .27634 .66719 L p .707 .577 .707 r
F P
0 g
s
.27634 .66719 m .25683 .61333 L .28599 .60393 L p .707 .577 .707 r
F P
0 g
s
.20561 .69682 m .20955 .73407 L .18558 .74127 L p .707 .577 .707 r
F P
0 g
s
.32481 .68675 m .32875 .724 L .30147 .72298 L p .707 .577 .707 r
F P
0 g
s
.30147 .72298 m .29753 .68573 L .32481 .68675 L p .707 .577 .707 r
F P
0 g
s
.16738 .74002 m .17189 .72258 L .19551 .72041 L p .707 .577 .707 r
F P
0 g
s
.33211 .7633 m .32759 .78074 L .30739 .76744 L p .707 .577 .707 r
F P
0 g
s
.30739 .76744 m .31191 .75 L .33211 .7633 L p .707 .577 .707 r
F P
0 g
s
.22681 .62429 m .24632 .67815 L .21838 .68962 L p .707 .577 .707 r
F P
0 g
s
.73898 .64607 m .71947 .59221 L .69031 .6016 L p .707 .577 .707 r
F P
0 g
s
.71947 .59221 m .73898 .64607 L .769 .6351 L p .707 .577 .707 r
F P
0 g
s
.769 .6351 m .74949 .58124 L .71947 .59221 L p .707 .577 .707 r
F P
0 g
s
.74949 .58124 m .769 .6351 L .79694 .62364 L p .707 .577 .707 r
F P
0 g
s
.79694 .62364 m .77743 .56978 L .74949 .58124 L p .707 .577 .707 r
F P
0 g
s
.19551 .72041 m .19099 .73785 L .16738 .74002 L p .707 .577 .707 r
F P
0 g
s
.24632 .67815 m .22681 .62429 L .25683 .61333 L p .707 .577 .707 r
F P
0 g
s
.25683 .61333 m .27634 .66719 L .24632 .67815 L p .707 .577 .707 r
F P
0 g
s
.37704 .26618 m .41433 .77058 L .39124 .78151 L p .707 .577 .707 r
F P
0 g
s
.41433 .77058 m .37704 .26618 L .41094 .25668 L p .707 .577 .707 r
F P
0 g
s
.20955 .73407 m .20561 .69682 L .23486 .69103 L p .707 .577 .707 r
F P
0 g
s
.69031 .6016 m .70982 .65546 L .73898 .64607 L p .707 .577 .707 r
F P
0 g
s
.70982 .65546 m .69031 .6016 L .66487 .60851 L p .707 .577 .707 r
F P
0 g
s
.29753 .68573 m .30147 .72298 L .27048 .72446 L p .707 .577 .707 r
F P
0 g
s
.27048 .72446 m .26654 .68721 L .29753 .68573 L p .707 .577 .707 r
F P
0 g
s
.77743 .56978 m .79694 .62364 L .82007 .61279 L p .707 .577 .707 r
F P
0 g
s
.82007 .61279 m .80055 .55894 L .77743 .56978 L p .707 .577 .707 r
F P
0 g
s
.23486 .69103 m .2388 .72828 L .20955 .73407 L p .707 .577 .707 r
F P
0 g
s
.19099 .73785 m .19551 .72041 L .22421 .72247 L p .707 .577 .707 r
F P
0 g
s
.66487 .60851 m .68438 .66236 L .70982 .65546 L p .707 .577 .707 r
F P
0 g
s
.2388 .72828 m .23486 .69103 L .26654 .68721 L p .707 .577 .707 r
F P
0 g
s
.31191 .75 m .30739 .76744 L .28089 .75546 L p .707 .577 .707 r
F P
0 g
s
.28089 .75546 m .2854 .73802 L .31191 .75 L p .707 .577 .707 r
F P
0 g
s
.73678 .71225 m .73284 .675 L .70185 .67647 L p .707 .577 .707 r
F P
0 g
s
.73284 .675 m .73678 .71225 L .76846 .70843 L p .707 .577 .707 r
F P
0 g
s
.76846 .70843 m .76452 .67118 L .73284 .675 L p .707 .577 .707 r
F P
0 g
s
.57969 .24767 m .61698 .75207 L .57834 .74919 L p .707 .577 .707 r
F P
0 g
s
.57834 .74919 m .54105 .2448 L .57969 .24767 L p .707 .577 .707 r
F P
0 g
s
.26654 .68721 m .27048 .72446 L .2388 .72828 L p .707 .577 .707 r
F P
0 g
s
.76452 .67118 m .76846 .70843 L .79771 .70263 L p .707 .577 .707 r
F P
0 g
s
.79771 .70263 m .79377 .66538 L .76452 .67118 L p .707 .577 .707 r
F P
0 g
s
.22421 .72247 m .21969 .73991 L .19099 .73785 L p .707 .577 .707 r
F P
0 g
s
.70579 .71372 m .70185 .67647 L .67457 .67545 L p .707 .577 .707 r
F P
0 g
s
.70185 .67647 m .70579 .71372 L .73678 .71225 L p .707 .577 .707 r
F P
0 g
s
.21969 .73991 m .22421 .72247 L .25518 .72853 L p .707 .577 .707 r
F P
0 g
s
.80055 .55894 m .82007 .61279 L .83612 .60364 L p .707 .577 .707 r
F P
0 g
s
.83612 .60364 m .8166 .54978 L .80055 .55894 L p .707 .577 .707 r
F P
0 g
s
.2854 .73802 m .28089 .75546 L .25067 .74598 L p .707 .577 .707 r
F P
0 g
s
.25067 .74598 m .25518 .72853 L .2854 .73802 L p .707 .577 .707 r
F P
0 g
s
.79377 .66538 m .79771 .70263 L .82168 .69543 L p .707 .577 .707 r
F P
0 g
s
.82168 .69543 m .81774 .65818 L .79377 .66538 L p .707 .577 .707 r
F P
0 g
s
.44823 .76108 m .41094 .25668 L .45233 .24953 L p .707 .577 .707 r
F P
0 g
s
.41094 .25668 m .44823 .76108 L .41433 .77058 L p .707 .577 .707 r
F P
0 g
s
.67457 .67545 m .67851 .7127 L .70579 .71372 L p .707 .577 .707 r
F P
0 g
s
.25518 .72853 m .25067 .74598 L .21969 .73991 L p .707 .577 .707 r
F P
0 g
s
.54105 .2448 m .57834 .74919 L .53445 .74983 L p .707 .577 .707 r
F P
0 g
s
.53445 .74983 m .49717 .24544 L .54105 .2448 L p .707 .577 .707 r
F P
0 g
s
.67851 .7127 m .67457 .67545 L .65368 .67204 L p .707 .577 .707 r
F P
0 g
s
.71543 .76961 m .71994 .75216 L .68972 .74268 L p .707 .577 .707 r
F P
0 g
s
.71994 .75216 m .71543 .76961 L .74641 .77567 L p .707 .577 .707 r
F P
0 g
s
.74641 .77567 m .75092 .75823 L .71994 .75216 L p .707 .577 .707 r
F P
0 g
s
.48962 .75393 m .45233 .24953 L .49717 .24544 L p .707 .577 .707 r
F P
0 g
s
.45233 .24953 m .48962 .75393 L .44823 .76108 L p .707 .577 .707 r
F P
0 g
s
.68521 .76012 m .68972 .74268 L .66322 .7307 L p .707 .577 .707 r
F P
0 g
s
.68972 .74268 m .68521 .76012 L .71543 .76961 L p .707 .577 .707 r
F P
0 g
s
.75092 .75823 m .74641 .77567 L .77511 .77773 L p .707 .577 .707 r
F P
0 g
s
.77511 .77773 m .77962 .76029 L .75092 .75823 L p .707 .577 .707 r
F P
0 g
s
.65368 .67204 m .65762 .70929 L .67851 .7127 L p .707 .577 .707 r
F P
0 g
s
.81774 .65818 m .82168 .69543 L .83802 .68753 L p .707 .577 .707 r
F P
0 g
s
.83802 .68753 m .83408 .65028 L .81774 .65818 L p .707 .577 .707 r
F P
0 g
s
.49717 .24544 m .53445 .74983 L .48962 .75393 L p .707 .577 .707 r
F P
0 g
s
.8166 .54978 m .83612 .60364 L .84352 .59706 L p .707 .577 .707 r
F P
0 g
s
.84352 .59706 m .82401 .5432 L .8166 .54978 L p .707 .577 .707 r
F P
0 g
s
.77962 .76029 m .77511 .77773 L .79872 .77556 L p .707 .577 .707 r
F P
0 g
s
.79872 .77556 m .80324 .75812 L .77962 .76029 L p .707 .577 .707 r
F P
0 g
s
.65762 .70929 m .65368 .67204 L .64121 .66657 L p .707 .577 .707 r
F P
0 g
s
.64121 .66657 m .64515 .70382 L .65762 .70929 L p .707 .577 .707 r
F P
0 g
s
.83408 .65028 m .83802 .68753 L .84514 .6797 L p .707 .577 .707 r
F P
0 g
s
.84514 .6797 m .8412 .64245 L .83408 .65028 L p .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .63448 .61244 L .6325 .60909 L p .707 .577 .707 r
F P
0 g
s
.80324 .75812 m .79872 .77556 L .81494 .7694 L p .707 .577 .707 r
F P
0 g
s
.81494 .7694 m .81945 .75196 L .80324 .75812 L p .707 .577 .707 r
F P
0 g
s
.82401 .5432 m .84352 .59706 L .84155 .59371 L p .707 .577 .707 r
F P
0 g
s
.84155 .59371 m .82204 .53985 L .82401 .5432 L p .707 .577 .707 r
F P
0 g
s
.6325 .60909 m .65202 .66295 L .65399 .6663 L p .707 .577 .707 r
F P
0 g
s
.64515 .70382 m .64121 .66657 L .6384 .65958 L p .707 .577 .707 r
F P
0 g
s
.6384 .65958 m .64234 .69683 L .64515 .70382 L p .707 .577 .707 r
F P
0 g
s
.8412 .64245 m .84514 .6797 L .84232 .67271 L p .707 .577 .707 r
F P
0 g
s
.84232 .67271 m .83838 .63546 L .8412 .64245 L p .707 .577 .707 r
F P
0 g
s
.81945 .75196 m .81494 .7694 L .82217 .75983 L p .707 .577 .707 r
F P
0 g
s
.82217 .75983 m .82669 .74239 L .81945 .75196 L p .707 .577 .707 r
F P
0 g
s
.65202 .66295 m .6325 .60909 L .63991 .60252 L p .707 .577 .707 r
F P
0 g
s
.82204 .53985 m .84155 .59371 L .8304 .59391 L p .707 .577 .707 r
F P
0 g
s
.8304 .59391 m .81089 .54005 L .82204 .53985 L p .707 .577 .707 r
F P
0 g
s
.63991 .60252 m .65942 .65638 L .65202 .66295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64234 .69683 m .6384 .65958 L .64551 .65175 L p .707 .577 .707 r
F P
0 g
s
.39597 .60727 m .37646 .55341 L .3473 .56281 L p .707 .577 .707 r
F P
0 g
s
.37646 .55341 m .39597 .60727 L .42599 .5963 L p .707 .577 .707 r
F P
0 g
s
.42599 .5963 m .40648 .54244 L .37646 .55341 L p .707 .577 .707 r
F P
0 g
s
.40648 .54244 m .42599 .5963 L .45393 .58484 L p .707 .577 .707 r
F P
0 g
s
.45393 .58484 m .43442 .53098 L .40648 .54244 L p .707 .577 .707 r
F P
0 g
s
.64551 .65175 m .64945 .689 L .64234 .69683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83838 .63546 m .84232 .67271 L .82986 .66724 L p .707 .577 .707 r
F P
0 g
s
.82986 .66724 m .82592 .62999 L .83838 .63546 L p .707 .577 .707 r
F P
0 g
s
.3473 .56281 m .36681 .61666 L .39597 .60727 L p .707 .577 .707 r
F P
0 g
s
.62414 .70949 m .62865 .69205 L .63589 .68248 L p .707 .577 .707 r
F P
0 g
s
.36681 .61666 m .3473 .56281 L .32186 .56971 L p .707 .577 .707 r
F P
0 g
s
.82669 .74239 m .82217 .75983 L .81972 .7478 L p .707 .577 .707 r
F P
0 g
s
.81972 .7478 m .82423 .73036 L .82669 .74239 L p .707 .577 .707 r
F P
0 g
s
.43442 .53098 m .45393 .58484 L .47706 .574 L p .707 .577 .707 r
F P
0 g
s
.47706 .574 m .45754 .52014 L .43442 .53098 L p .707 .577 .707 r
F P
0 g
s
.65942 .65638 m .63991 .60252 L .65596 .59336 L p .707 .577 .707 r
F P
0 g
s
.63589 .68248 m .63137 .69993 L .62414 .70949 L p .707 .577 .707 r
F P
0 g
s
.32186 .56971 m .34137 .62357 L .36681 .61666 L p .707 .577 .707 r
F P
0 g
s
.81089 .54005 m .8304 .59391 L .81116 .59765 L p .707 .577 .707 r
F P
0 g
s
.81116 .59765 m .79165 .54379 L .81089 .54005 L p .707 .577 .707 r
F P
0 g
s
.39377 .68038 m .38983 .64313 L .35884 .6446 L p .707 .577 .707 r
F P
0 g
s
.38983 .64313 m .39377 .68038 L .42545 .67656 L p .707 .577 .707 r
F P
0 g
s
.42545 .67656 m .42151 .63931 L .38983 .64313 L p .707 .577 .707 r
F P
0 g
s
.65596 .59336 m .67547 .64722 L .65942 .65638 L p .707 .577 .707 r
F P
0 g
s
.42151 .63931 m .42545 .67656 L .4547 .67077 L p .707 .577 .707 r
F P
0 g
s
.4547 .67077 m .45076 .63351 L .42151 .63931 L p .707 .577 .707 r
F P
0 g
s
.64945 .689 m .64551 .65175 L .66185 .64385 L p .707 .577 .707 r
F P
0 g
s
.36278 .68185 m .35884 .6446 L .33156 .64359 L p .707 .577 .707 r
F P
0 g
s
.35884 .6446 m .36278 .68185 L .39377 .68038 L p .707 .577 .707 r
F P
0 g
s
.34137 .62357 m .32186 .56971 L .30262 .57344 L p .707 .577 .707 r
F P
0 g
s
.45754 .52014 m .47706 .574 L .49311 .56484 L p .707 .577 .707 r
F P
0 g
s
.49311 .56484 m .47359 .51098 L .45754 .52014 L p .707 .577 .707 r
F P
0 g
s
.45076 .63351 m .4547 .67077 L .47867 .66356 L p .707 .577 .707 r
F P
0 g
s
.47867 .66356 m .47473 .62631 L .45076 .63351 L p .707 .577 .707 r
F P
0 g
s
.66185 .64385 m .66579 .6811 L .64945 .689 L p .707 .577 .707 r
F P
0 g
s
.30262 .57344 m .32213 .6273 L .34137 .62357 L p .707 .577 .707 r
F P
0 g
s
.82592 .62999 m .82986 .66724 L .80896 .66383 L p .707 .577 .707 r
F P
0 g
s
.80896 .66383 m .80502 .62658 L .82592 .62999 L p .707 .577 .707 r
F P
0 g
s
.33156 .64359 m .3355 .68084 L .36278 .68185 L p .707 .577 .707 r
F P
0 g
s
.63137 .69993 m .63589 .68248 L .65211 .67632 L p .707 .577 .707 r
F P
0 g
s
.67547 .64722 m .65596 .59336 L .67908 .58252 L p .707 .577 .707 r
F P
0 g
s
.82423 .73036 m .81972 .7478 L .80781 .73449 L p .707 .577 .707 r
F P
0 g
s
.80781 .73449 m .81232 .71705 L .82423 .73036 L p .707 .577 .707 r
F P
0 g
s
.79165 .54379 m .81116 .59765 L .78572 .60455 L p .707 .577 .707 r
F P
0 g
s
.78572 .60455 m .7662 .55069 L .79165 .54379 L p .707 .577 .707 r
F P
0 g
s
.37242 .72382 m .37693 .70638 L .34671 .69689 L p .707 .577 .707 r
F P
0 g
s
.37693 .70638 m .37242 .72382 L .4034 .72989 L p .707 .577 .707 r
F P
0 g
s
.4034 .72989 m .40791 .71245 L .37693 .70638 L p .707 .577 .707 r
F P
0 g
s
.65211 .67632 m .64759 .69376 L .63137 .69993 L p .707 .577 .707 r
F P
0 g
s
.3355 .68084 m .33156 .64359 L .31067 .64018 L p .707 .577 .707 r
F P
0 g
s
.67908 .58252 m .6986 .63638 L .67547 .64722 L p .707 .577 .707 r
F P
0 g
s
.3422 .71434 m .34671 .69689 L .32021 .68491 L p .707 .577 .707 r
F P
0 g
s
.34671 .69689 m .3422 .71434 L .37242 .72382 L p .707 .577 .707 r
F P
0 g
s
.40791 .71245 m .4034 .72989 L .4321 .73195 L p .707 .577 .707 r
F P
0 g
s
.4321 .73195 m .43661 .7145 L .40791 .71245 L p .707 .577 .707 r
F P
0 g
s
.66579 .6811 m .66185 .64385 L .68582 .63665 L p .707 .577 .707 r
F P
0 g
s
.32213 .6273 m .30262 .57344 L .29147 .57365 L p .707 .577 .707 r
F P
0 g
s
.31067 .64018 m .31461 .67743 L .3355 .68084 L p .707 .577 .707 r
F P
0 g
s
.47473 .62631 m .47867 .66356 L .49501 .65566 L p .707 .577 .707 r
F P
0 g
s
.49501 .65566 m .49107 .61841 L .47473 .62631 L p .707 .577 .707 r
F P
0 g
s
.32021 .68491 m .31569 .70236 L .3422 .71434 L p .707 .577 .707 r
F P
0 g
s
.47359 .51098 m .49311 .56484 L .50051 .55826 L p .707 .577 .707 r
F P
0 g
s
.50051 .55826 m .481 .50441 L .47359 .51098 L p .707 .577 .707 r
F P
0 g
s
.6986 .63638 m .67908 .58252 L .70703 .57105 L p .707 .577 .707 r
F P
0 g
s
.29147 .57365 m .31098 .6275 L .32213 .6273 L p .707 .577 .707 r
F P
0 g
s
.68582 .63665 m .68976 .6739 L .66579 .6811 L p .707 .577 .707 r
F P
0 g
s
.80502 .62658 m .80896 .66383 L .78168 .66281 L p .707 .577 .707 r
F P
0 g
s
.78168 .66281 m .77774 .62556 L .80502 .62658 L p .707 .577 .707 r
F P
0 g
s
.31569 .70236 m .32021 .68491 L .30001 .67162 L p .707 .577 .707 r
F P
0 g
s
.7662 .55069 m .78572 .60455 L .75656 .61395 L p .707 .577 .707 r
F P
0 g
s
.75656 .61395 m .73704 .56009 L .7662 .55069 L p .707 .577 .707 r
F P
0 g
s
.43661 .7145 m .4321 .73195 L .45571 .72978 L p .707 .577 .707 r
F P
0 g
s
.45571 .72978 m .46023 .71234 L .43661 .7145 L p .707 .577 .707 r
F P
0 g
s
.64759 .69376 m .65211 .67632 L .67572 .67416 L p .707 .577 .707 r
F P
0 g
s
.70703 .57105 m .72654 .62491 L .6986 .63638 L p .707 .577 .707 r
F P
0 g
s
.81232 .71705 m .80781 .73449 L .78761 .72119 L p .707 .577 .707 r
F P
0 g
s
.78761 .72119 m .79212 .70375 L .81232 .71705 L p .707 .577 .707 r
F P
0 g
s
.30001 .67162 m .2955 .68906 L .31569 .70236 L p .707 .577 .707 r
F P
0 g
s
.31461 .67743 m .31067 .64018 L .2982 .63471 L p .707 .577 .707 r
F P
0 g
s
.72654 .62491 m .70703 .57105 L .73704 .56009 L p .707 .577 .707 r
F P
0 g
s
.73704 .56009 m .75656 .61395 L .72654 .62491 L p .707 .577 .707 r
F P
0 g
s
.67572 .67416 m .67121 .6916 L .64759 .69376 L p .707 .577 .707 r
F P
0 g
s
.68976 .6739 m .68582 .63665 L .71508 .63085 L p .707 .577 .707 r
F P
0 g
s
.77774 .62556 m .78168 .66281 L .75069 .66428 L p .707 .577 .707 r
F P
0 g
s
.75069 .66428 m .74675 .62703 L .77774 .62556 L p .707 .577 .707 r
F P
0 g
s
.2982 .63471 m .30214 .67196 L .31461 .67743 L p .707 .577 .707 r
F P
0 g
s
.49107 .61841 m .49501 .65566 L .50213 .64783 L p .707 .577 .707 r
F P
0 g
s
.50213 .64783 m .49819 .61058 L .49107 .61841 L p .707 .577 .707 r
F P
0 g
s
.71508 .63085 m .71902 .66811 L .68976 .6739 L p .707 .577 .707 r
F P
0 g
s
.2955 .68906 m .30001 .67162 L .2881 .6583 L p .707 .577 .707 r
F P
0 g
s
.71902 .66811 m .71508 .63085 L .74675 .62703 L p .707 .577 .707 r
F P
0 g
s
.31098 .6275 m .29147 .57365 L .28949 .57029 L p .707 .577 .707 r
F P
0 g
s
.46023 .71234 m .45571 .72978 L .47193 .72362 L p .707 .577 .707 r
F P
0 g
s
.47193 .72362 m .47644 .70618 L .46023 .71234 L p .707 .577 .707 r
F P
0 g
s
.74675 .62703 m .75069 .66428 L .71902 .66811 L p .707 .577 .707 r
F P
0 g
s
.67121 .6916 m .67572 .67416 L .70442 .67621 L p .707 .577 .707 r
F P
0 g
s
.79212 .70375 m .78761 .72119 L .7611 .70921 L p .707 .577 .707 r
F P
0 g
s
.7611 .70921 m .76562 .69177 L .79212 .70375 L p .707 .577 .707 r
F P
0 g
s
.481 .50441 m .50051 .55826 L .49854 .55491 L p .707 .577 .707 r
F P
0 g
s
.49854 .55491 m .47903 .50105 L .481 .50441 L p .707 .577 .707 r
F P
0 g
s
.2881 .6583 m .28359 .67574 L .2955 .68906 L p .707 .577 .707 r
F P
0 g
s
.28949 .57029 m .30901 .62415 L .31098 .6275 L p .707 .577 .707 r
F P
0 g
s
.70442 .67621 m .69991 .69365 L .67121 .6916 L p .707 .577 .707 r
F P
0 g
s
.30214 .67196 m .2982 .63471 L .29539 .62772 L p .707 .577 .707 r
F P
0 g
s
.69991 .69365 m .70442 .67621 L .7354 .68228 L p .707 .577 .707 r
F P
0 g
s
.76562 .69177 m .7611 .70921 L .73088 .69972 L p .707 .577 .707 r
F P
0 g
s
.73088 .69972 m .7354 .68228 L .76562 .69177 L p .707 .577 .707 r
F P
0 g
s
.7354 .68228 m .73088 .69972 L .69991 .69365 L p .707 .577 .707 r
F P
0 g
s
.29539 .62772 m .29933 .66497 L .30214 .67196 L p .707 .577 .707 r
F P
0 g
s
.28359 .67574 m .2881 .6583 L .28564 .64627 L p .707 .577 .707 r
F P
0 g
s
.49819 .61058 m .50213 .64783 L .49931 .64084 L p .707 .577 .707 r
F P
0 g
s
.49931 .64084 m .49537 .60359 L .49819 .61058 L p .707 .577 .707 r
F P
0 g
s
.47644 .70618 m .47193 .72362 L .47916 .71405 L p .707 .577 .707 r
F P
0 g
s
.47916 .71405 m .48368 .69661 L .47644 .70618 L p .707 .577 .707 r
F P
0 g
s
.28564 .64627 m .28113 .66371 L .28359 .67574 L p .707 .577 .707 r
F P
0 g
s
.30901 .62415 m .28949 .57029 L .2969 .56372 L p .707 .577 .707 r
F P
0 g
s
.47903 .50105 m .49854 .55491 L .48739 .55512 L p .707 .577 .707 r
F P
0 g
s
.48739 .55512 m .46788 .50126 L .47903 .50105 L p .707 .577 .707 r
F P
0 g
s
.2969 .56372 m .31641 .61758 L .30901 .62415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29933 .66497 m .29539 .62772 L .3025 .61989 L p .707 .577 .707 r
F P
0 g
s
.3025 .61989 m .30644 .65714 L .29933 .66497 L p .707 .577 .707 r
F P
0 g
s
.28113 .66371 m .28564 .64627 L .29288 .6367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48368 .69661 m .47916 .71405 L .47671 .70202 L p .707 .577 .707 r
F P
0 g
s
.47671 .70202 m .48122 .68458 L .48368 .69661 L p .707 .577 .707 r
F P
0 g
s
.49537 .60359 m .49931 .64084 L .48685 .63537 L p .707 .577 .707 r
F P
0 g
s
.48685 .63537 m .48291 .59812 L .49537 .60359 L p .707 .577 .707 r
F P
0 g
s
.29288 .6367 m .28836 .65414 L .28113 .66371 L p .707 .577 .707 r
F P
0 g
s
.31641 .61758 m .2969 .56372 L .31295 .55456 L p .707 .577 .707 r
F P
0 g
s
.46788 .50126 m .48739 .55512 L .46815 .55885 L p .707 .577 .707 r
F P
0 g
s
.46815 .55885 m .44864 .50499 L .46788 .50126 L p .707 .577 .707 r
F P
0 g
s
.31295 .55456 m .33246 .60842 L .31641 .61758 L p .707 .577 .707 r
F P
0 g
s
.30644 .65714 m .3025 .61989 L .31884 .61198 L p .707 .577 .707 r
F P
0 g
s
.28836 .65414 m .29288 .6367 L .30909 .63054 L p .707 .577 .707 r
F P
0 g
s
.31884 .61198 m .32278 .64923 L .30644 .65714 L p .707 .577 .707 r
F P
0 g
s
.48122 .68458 m .47671 .70202 L .46479 .6887 L p .707 .577 .707 r
F P
0 g
s
.46479 .6887 m .46931 .67126 L .48122 .68458 L p .707 .577 .707 r
F P
0 g
s
.48291 .59812 m .48685 .63537 L .46595 .63196 L p .707 .577 .707 r
F P
0 g
s
.46595 .63196 m .46201 .59471 L .48291 .59812 L p .707 .577 .707 r
F P
0 g
s
.33246 .60842 m .31295 .55456 L .33607 .54372 L p .707 .577 .707 r
F P
0 g
s
.30909 .63054 m .30458 .64798 L .28836 .65414 L p .707 .577 .707 r
F P
0 g
s
.44864 .50499 m .46815 .55885 L .44271 .56575 L p .707 .577 .707 r
F P
0 g
s
.44271 .56575 m .42319 .51189 L .44864 .50499 L p .707 .577 .707 r
F P
0 g
s
.33607 .54372 m .35559 .59758 L .33246 .60842 L p .707 .577 .707 r
F P
0 g
s
.32278 .64923 m .31884 .61198 L .34281 .60478 L p .707 .577 .707 r
F P
0 g
s
.35559 .59758 m .33607 .54372 L .36401 .53226 L p .707 .577 .707 r
F P
0 g
s
.42319 .51189 m .44271 .56575 L .41355 .57515 L p .707 .577 .707 r
F P
0 g
s
.41355 .57515 m .39403 .52129 L .42319 .51189 L p .707 .577 .707 r
F P
0 g
s
.34281 .60478 m .34675 .64203 L .32278 .64923 L p .707 .577 .707 r
F P
0 g
s
.46201 .59471 m .46595 .63196 L .43867 .63094 L p .707 .577 .707 r
F P
0 g
s
.43867 .63094 m .43473 .59369 L .46201 .59471 L p .707 .577 .707 r
F P
0 g
s
.30458 .64798 m .30909 .63054 L .33271 .62837 L p .707 .577 .707 r
F P
0 g
s
.46931 .67126 m .46479 .6887 L .4446 .67541 L p .707 .577 .707 r
F P
0 g
s
.4446 .67541 m .44911 .65796 L .46931 .67126 L p .707 .577 .707 r
F P
0 g
s
.36401 .53226 m .38353 .58611 L .35559 .59758 L p .707 .577 .707 r
F P
0 g
s
.33271 .62837 m .3282 .64582 L .30458 .64798 L p .707 .577 .707 r
F P
0 g
s
.38353 .58611 m .36401 .53226 L .39403 .52129 L p .707 .577 .707 r
F P
0 g
s
.39403 .52129 m .41355 .57515 L .38353 .58611 L p .707 .577 .707 r
F P
0 g
s
.34675 .64203 m .34281 .60478 L .37207 .59899 L p .707 .577 .707 r
F P
0 g
s
.43473 .59369 m .43867 .63094 L .40768 .63242 L p .707 .577 .707 r
F P
0 g
s
.40768 .63242 m .40374 .59517 L .43473 .59369 L p .707 .577 .707 r
F P
0 g
s
.37207 .59899 m .376 .63624 L .34675 .64203 L p .707 .577 .707 r
F P
0 g
s
.3282 .64582 m .33271 .62837 L .36141 .63043 L p .707 .577 .707 r
F P
0 g
s
.376 .63624 m .37207 .59899 L .40374 .59517 L p .707 .577 .707 r
F P
0 g
s
.44911 .65796 m .4446 .67541 L .41809 .66343 L p .707 .577 .707 r
F P
0 g
s
.41809 .66343 m .42261 .64598 L .44911 .65796 L p .707 .577 .707 r
F P
0 g
s
.40374 .59517 m .40768 .63242 L .376 .63624 L p .707 .577 .707 r
F P
0 g
s
.36141 .63043 m .3569 .64787 L .3282 .64582 L p .707 .577 .707 r
F P
0 g
s
.3569 .64787 m .36141 .63043 L .39239 .6365 L p .707 .577 .707 r
F P
0 g
s
.42261 .64598 m .41809 .66343 L .38787 .65394 L p .707 .577 .707 r
F P
0 g
s
.38787 .65394 m .39239 .6365 L .42261 .64598 L p .707 .577 .707 r
F P
0 g
s
.39239 .6365 m .38787 .65394 L .3569 .64787 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo0024Ool60003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001fOol007ioo`H000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@0079oo`00N7oo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000KWoo001bOol60008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH2001/Ool006ioo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJ
EP8006Yoo`00JWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH02eYF00<007ooOol0J7oo001XOol200000eYF001JEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH2001YOol006Io
o`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00YJEP8006Uoo`00I7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02UYF0P00JGoo001SOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1WOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1WOol0065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0
065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH20003FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP02
001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF008006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYF001JEP02001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEP00FUH00P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF008006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYFFUH005YFIGoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Hgoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF1`002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH00UYF100045YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF1@0000=JEP00FUH0
15YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00AJEP<000IJEP03001JEUYF009J
EP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00
FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06=oo`00IWoo00@005YFFUH000EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEP00FUH005YF06Aoo`00IWoo00@005YFFUH0009JEP<00003FUH005YF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH200001EYF001JEP00FUH0I7oo001VOol00`00FUIJEP030005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF001JEP00FUITOol006Ioo`<000QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00Oomoo`1ROol006Aoo`800003FUH005YF00QJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001oogoo069oo`00HGoo0`0015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
02Uoo`H003=oo`00GWoo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo02Eoo`@0009JEP05001JEUYFFUH0000bOol005aoo`800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo025oo`@00003FUH005YF00AJEP04001JEUYF000bOol005Yoo`8000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000NOol40006FUH0
0`00FUIJEP02FUH00`00FUIJEP02000aOol005Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001aoo`800003FUH005YF00MJEP03001JEUYF00=J
EP04001JEUYF000aOol005Moo`8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000IOol30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo001EOol20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000FOol30007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIJEP02000`Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`<00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP04
001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000@Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<7oo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000P001EYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P003Goo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH002moo`00DWoo00@005YFFUH000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000QJEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8000=JEP8000]oo`800003FUH005YF00UJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool0059oo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF009J
EP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20009Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00Aoo`<000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`04001JEUYF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP05FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`02Ool200000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo001DOol00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`020004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo001DOol01000FUIJEP0015YF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH0
1EYF200025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUIJEPH002eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00IJEP8000MJEPT000AJ
EP04001JEUYFFUH70002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1@000UYF00@005YFFUH002eoo`00Dgoo0`0000=JEP00FUH015YF00<005YFFUH00eYF
0P0000=JEP0000001P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00=J
EP8002ioo`00D7oo0`000UYF00@005YFFUH000AJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool004ioo`800003FUH0
05YF009JEP04001JEUYF0005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00<005YFFUH01EYF00D005YFFUIJEP00031oo`00Bgoo0`0015YF00L005YFFUIJ
EP00FUH00003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YF00000P0015YF00<005YFFUH01UYF0`00<Goo0018Ool30007FUH01@00FUIJEUYF00000UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000QJEP03001JEUYF00AJ
EP8003=oo`00AGoo0`0000=JEP00FUH01eYF00@005YFFUIJEP<00003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000eOol0049oo`<000EJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF00IJEP04001JEP00000g
Ool003moo`<000QJEP03001JEUYF00IJEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40008FUH;000iOol003eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPT000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH90004FUH01000FUIJEUYF1P00=Woo
000jOol30004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP050003FUH01000FUIJEUYF
1`0000=JEP00FUH00eYF60000eYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00D0035oo`00=goo0`001eYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH02P002EYF1P0015YF1@000UYF
0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YF00000P00;Woo000eOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH?0004FUH00`00FUIJ
EP04FUH01000FUIJEUYF10001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0035oo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000=J
EP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH500001EYF000005YF00000UYF2@0015YF00<005YFFUH01eYF0`00
1EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002io
o`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00800003FUH0
0000009JEP04001JEP000003FUH00`00FUIJEP05FUH01000FUIJEUYF1P001eYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00<00004FUH0
05YFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH00eYF
0P000UYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUH00006FUH0
1000FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00:goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP800003FUH0000000800005FUH005YFFUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20008FUH30005FUH3000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000[Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF0P001UYF00<005YFFUH01@000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH015YF2@002Woo1@001EYF10000eYF0P00;7oo000[Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0`000eYF00<005YF
FUH00eYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001Goo3P000eYF00<005YFFUH015YF00@0
05YFFUIJEP800003FUH0000002aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008000EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP80009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH;0004
Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000/Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH20008FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70002FUH20006FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP050003
FUH01000FUIJEUYF200015YF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF
0`00;7oo000]Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH01000FUIJEP0015YF0P0000=oo`0000005P002EYF00@005YF000000=JEP06001JEUYF001JEP00
35YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH0100000=JEP0000000P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000;7oo000]Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01eYF0`001UYF00<007ooOol037oo00<005YFFUH01`002EYF00@005YF
FUIJEP800003FUH005YF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00;Goo00@005YFFUH000AJEP03001JEUYF00IJ
EP04001JEP000005FUH>0006FUH4000;Ool00`00FUIJEP070009FUH00`00FUIJEP03FUH20003FUH0
0`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH300000eYF
000000040004FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF1P001Woo00<005YFFUH01`002EYF
00<005YFFUH01EYF00H005YFFUH005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJ
EUYF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP04FUH01000FUH00000<7oo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF1P0000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP<00003FUH0000000Ao
o`05001JEUYF001JEP0300000eYF001JEP09FUH00`00FUIJEP04FUH01000FUH005YF0P002eYF00<0
05YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP8000=JEPD000=JEP03001JEUYF00T000AJEP03
001JEUYF00MJEP<000IJEP03001JEUYF00=JEP<0039oo`00;Woo00@005YFFUH000EJEP03001JEP00
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH40004Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00@005YFFUIJEP800004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP060008FUH00`00FUIJEP020004FUH00`00FUH00003000eOol002moo`03001JEP0000=J
EP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00@00005Ool005YFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00D005YFFUH005YF00800003FUH00000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP800004
FUH00000000iOol002moo`04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH200000eYF0000000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP020003
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0300000eYF001J
EP06FUH2000kOol002moo`03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00MJEP03001JEP0000<000=JEP03001JEUYF
00MJEP03001JEUYF00=JEP800005FUH00000FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
1000FUIJEP0015YF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0025YF0`00>Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP04FUH70006FUH0
0`00FUH000030003FUH200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJ
EP0015YF00<005YFFUH00UYF6`000goo0P001EYF00@005YFFUIJEP8003Moo`00;Goo0`000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`001eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUH000AJEP03001JEUYF009JEP8001Ao
o`<000Moo`8000=JEP03001JEUYF00=JEP03001oogoo03Aoo`00;7oo00@005YFFUH000=JEPT000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5000@Ool50008Ool3
0006FUH2000eOol002aoo`03001JEUYF00D000=JEP04001JEUYFFUH700000eYF001JEP07FUH00`00
FUIJEP02FUH?0003FUH00`00FUIJEP060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF1@002goo1@002Woo00<005YFFUH015YF00<005YF0000=7oo000/Ool00`00
FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH90004Ool60004FUH50002FUH20003
Ool00eYF000000020002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001EYF
00<005YF00000P0027oo1@002goo0P000eYF00D005YFFUIJEP0003=oo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1P000Woo1`0015YF00<005YFFUH015YF00@005YF
FUIJEP@000=oo`05001JEUYF001JEP060004FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00D005YFFUIJ
EP0000Uoo`<000ioo`800003FUH005YF00=JEP03001oogoo031oo`00:goo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF0`000goo00@005YFFUH000EJEP03001JEP0000P000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00YJEP<000AJEP04001JEUYFFUH2000KOol2
0004FUH00`00Oomoo`0`Ool002Yoo`8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH00P000UYF00@005YFFUIJEP8001eoo`03001JEUYF0080039oo`00:Woo
0P000UYF1@0000EJEP00001JEP00009JEPL000IJEP03001JEUYF00MJEP<000EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP03
FUH30003FUH2000MOol00`00FUIJEP02000bOol002Uoo`800003FUH00000009JEP04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0P0017oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF015JEP<00003FUH0
000001ioo`800003FUH007oo035oo`00:Goo0`0000Aoo`00FUIJEP<000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP@000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP05001JEUYFFUH00005
Ool01000FUIJEP0045YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH04UYF00<005YF00000`007Woo00<005YF0000<Woo000XOol30003Ool01000FUH0
00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<0
05YF00001UYF00@005YF000000Ioo`04001JEUYF000@FUH00`00FUIJEP09FUH00`00FUIJEP04FUHN
000<FUH00`00FUIJEP04FUH00`00FUIJEP04FUH5000IOol00`00FUH0000bOol002Qoo`04001JEP00
0002Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0008FUH30005FUH30008Ool01000FUIJEP0045YF00<005YFFUH01eYF2@002UYF0P002eYF00<005YF
FUH01EYF0P002UYF0P0015YF00<005YFFUH01UYF00<005YFFUH010004goo1000<goo000XOol01`00
FUH005YF001oo`0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00EJEP8000IJEP03001JEUYF00D000]oo`04001JEUYF000@FUH01000FUIJEUYF1P0025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00H005YF000005YF0009
FUH00`00FUIJEP04FUH60008Ool50002FUH2000cOol002Qoo`03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF009J
EP8000eoo`03001JEUYF011JEPD00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH01000
FUIJEUYF20000eYF00H005YFFUH005YF000cOol002Uoo`03001JEUYF009JEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00EJEP03001oogoo00Yoo`03001JEUYF00eJEP<000IJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
0003FUH005YF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP04001JEUYF
FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000dOol0
02Uoo`03001JEUYF009JEPL000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL0
009oo`8000IJEP8000]oo`03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001JEUYF00EJEP04
001JEUYFFUH70005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=Goo000ZOol01@00FUIJEUYF0000
0UYF0P000Woo1`0015YF00<005YFFUH00UYF20002goo0P0015YF00<005YF00002goo2EYF0P000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01000
00=JEP00FUH025YF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YF000017oo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000003Ioo`00:goo00<005YF00001EYF0P001goo
2@000Woo1@003Woo00@005YFFUH000=JEP03001oogoo00Qoo`MJEP8000AJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF009JEP8000Uoo`H000AJEP04001JEUYFFUH5000h
Ool002aoo`8000IJEP<0011oo`D000moo`<000=JEP03001oogoo00Qoo`EJEP8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH2000@Ool8000mOol002eoo`03001J
EUYF00=JEP04001JEUYFFUH2000>Ool5000AOol01@00FUIJEUYF00002Woo0eYF0P0025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH00eYF100015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF0P001EYF00@005YF000005Moo`00;Woo0P000eYF00<005YFFUH00eYF0P003Goo
0`004goo00D005YF001JEP0000Uoo`9JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00MJEPL000QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000AJEP<005Uoo`00<7oo
0`0025YF0P008Woo0P0000=JEP00Ool027oo00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00@005YFFUIJEP@0009JEP03001JEP0000UJEP03001J
EUYF00=JEP800003FUH00000008005aoo`00<Woo00<005YFFUH01UYF00<005YF00000P0087oo00<0
05YF00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1@002EYF00@005YFFUIJEPD0061oo`00<goo0P001UYF00<005YFFUH00UYF
0`0077oo0P0000=JEP00Ool027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00D005YF000005YF0080069oo`00=Goo0P00
0eYF00<005YFFUH01UYF1@005Goo0P0000=JEP0000002goo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0`0015YF0P00HGoo000gOol200000eYF001JEP07FUH00`00FUIJEP02FUH90008Ool40003FUH2000;
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP02001OOol003Uoo`<000MJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP07001JEUYFFUH005YF00003Goo0P0000=JEP00FUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`0017oo
0P000eYF00<005YFFUH00UYF00<007ooOol0G7oo000lOol40002FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0047oo0`001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1@002Goo0`001UYF00<007ooOol0Fgoo0010Ool50006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0057oo10000UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P0000=oo`0000000`002Woo00<005YFFUH0
15YF0P00G7oo0015Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000006Woo2000
1EYF00<005YFFUH02UYF00<005YFFUH015YF2@001goo1@002goo0P0015YF00@005YF000005Yoo`00
BGoo1P0015YF00@005YFFUIJEPD002AooaT0011oo`D000eoo`04001JEUYF0004FUH00`00Oomoo`1G
Ool004moo`P003Ioo`8000IJEP<0019oo`<000moo`<000AJEP03001oogoo05Moo`00SWoo00<005YF
FUH015YF00<005YFFUH00P0097oo00@005YFFUIJEP8005Uoo`00Sgoo0P000eYF00<005YFFUH00eYF
0P008goo00<005YFFUH00P00FGoo002AOol200000eYF001JEP06FUH3000QOol200000eYF001oo`1H
Ool009=oo`8000QJEP04001JEP00000POol00`00FUH0001IOol009Eoo`8000EJEP03001JEUYF009J
EP<001eoo`03001JEP0005Uoo`00Ugoo0P000eYF00<005YFFUH01EYF1P005Goo1000FWoo002IOol3
0009FUH00`00FUIJEP02FUH80008Ool50002FUH2001JOol009]oo`<000IJEP03001JEUYF00MJEP04
001JEUYFFUH80003FUH01P00FUIJEP00FUH005Yoo`00WWoo10000UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P00Fgoo002ROol50006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000G7oo002WOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH00000GGoo002[Ool60004FUH01000FUIJEUYF1@00Ggoo002aOol8001TOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60178 .73811 m .58226 .68425 L .55311 .69364 L p .707 .577 .707 r
F P
0 g
s
.58226 .68425 m .60178 .73811 L .6318 .72714 L p .707 .577 .707 r
F P
0 g
s
.6318 .72714 m .61228 .67328 L .58226 .68425 L p .707 .577 .707 r
F P
0 g
s
.61228 .67328 m .6318 .72714 L .65974 .71567 L p .707 .577 .707 r
F P
0 g
s
.65974 .71567 m .64022 .66182 L .61228 .67328 L p .707 .577 .707 r
F P
0 g
s
.55311 .69364 m .57262 .7475 L .60178 .73811 L p .707 .577 .707 r
F P
0 g
s
.57262 .7475 m .55311 .69364 L .52766 .70054 L p .707 .577 .707 r
F P
0 g
s
.64022 .66182 m .65974 .71567 L .68286 .70483 L p .707 .577 .707 r
F P
0 g
s
.68286 .70483 m .66335 .65097 L .64022 .66182 L p .707 .577 .707 r
F P
0 g
s
.52766 .70054 m .54717 .7544 L .57262 .7475 L p .707 .577 .707 r
F P
0 g
s
.59958 .80429 m .59564 .76703 L .56465 .76851 L p .707 .577 .707 r
F P
0 g
s
.59564 .76703 m .59958 .80429 L .63125 .80046 L p .707 .577 .707 r
F P
0 g
s
.63125 .80046 m .62731 .76321 L .59564 .76703 L p .707 .577 .707 r
F P
0 g
s
.62731 .76321 m .63125 .80046 L .66051 .79467 L p .707 .577 .707 r
F P
0 g
s
.66051 .79467 m .65657 .75742 L .62731 .76321 L p .707 .577 .707 r
F P
0 g
s
.56859 .80576 m .56465 .76851 L .53737 .76749 L p .707 .577 .707 r
F P
0 g
s
.56465 .76851 m .56859 .80576 L .59958 .80429 L p .707 .577 .707 r
F P
0 g
s
.54717 .7544 m .52766 .70054 L .50842 .70428 L p .707 .577 .707 r
F P
0 g
s
.66335 .65097 m .68286 .70483 L .69891 .69568 L p .707 .577 .707 r
F P
0 g
s
.69891 .69568 m .6794 .64182 L .66335 .65097 L p .707 .577 .707 r
F P
0 g
s
.65657 .75742 m .66051 .79467 L .68448 .78747 L p .707 .577 .707 r
F P
0 g
s
.68448 .78747 m .68054 .75022 L .65657 .75742 L p .707 .577 .707 r
F P
0 g
s
.53737 .76749 m .54131 .80474 L .56859 .80576 L p .707 .577 .707 r
F P
0 g
s
.50842 .70428 m .52794 .75814 L .54717 .7544 L p .707 .577 .707 r
F P
0 g
s
.54131 .80474 m .53737 .76749 L .51647 .76408 L p .707 .577 .707 r
F P
0 g
s
.57823 .86164 m .58274 .8442 L .55252 .83471 L p .707 .577 .707 r
F P
0 g
s
.58274 .8442 m .57823 .86164 L .6092 .86771 L p .707 .577 .707 r
F P
0 g
s
.6092 .86771 m .61372 .85027 L .58274 .8442 L p .707 .577 .707 r
F P
0 g
s
.54801 .85215 m .55252 .83471 L .52601 .82273 L p .707 .577 .707 r
F P
0 g
s
.55252 .83471 m .54801 .85215 L .57823 .86164 L p .707 .577 .707 r
F P
0 g
s
.61372 .85027 m .6092 .86771 L .6379 .86976 L p .707 .577 .707 r
F P
0 g
s
.6379 .86976 m .64242 .85232 L .61372 .85027 L p .707 .577 .707 r
F P
0 g
s
.51647 .76408 m .52041 .80133 L .54131 .80474 L p .707 .577 .707 r
F P
0 g
s
.68054 .75022 m .68448 .78747 L .70082 .77957 L p .707 .577 .707 r
F P
0 g
s
.70082 .77957 m .69688 .74232 L .68054 .75022 L p .707 .577 .707 r
F P
0 g
s
.52794 .75814 m .50842 .70428 L .49727 .70448 L p .707 .577 .707 r
F P
0 g
s
.52601 .82273 m .5215 .84017 L .54801 .85215 L p .707 .577 .707 r
F P
0 g
s
.6794 .64182 m .69891 .69568 L .70632 .6891 L p .707 .577 .707 r
F P
0 g
s
.70632 .6891 m .6868 .63524 L .6794 .64182 L p .707 .577 .707 r
F P
0 g
s
.49727 .70448 m .51678 .75834 L .52794 .75814 L p .707 .577 .707 r
F P
0 g
s
.5215 .84017 m .52601 .82273 L .50582 .80943 L p .707 .577 .707 r
F P
0 g
s
.64242 .85232 m .6379 .86976 L .66152 .8676 L p .707 .577 .707 r
F P
0 g
s
.66152 .8676 m .66603 .85016 L .64242 .85232 L p .707 .577 .707 r
F P
0 g
s
.52041 .80133 m .51647 .76408 L .50401 .75861 L p .707 .577 .707 r
F P
0 g
s
.50582 .80943 m .5013 .82688 L .5215 .84017 L p .707 .577 .707 r
F P
0 g
s
.50401 .75861 m .50795 .79586 L .52041 .80133 L p .707 .577 .707 r
F P
0 g
s
.69688 .74232 m .70082 .77957 L .70793 .77174 L p .707 .577 .707 r
F P
0 g
s
.70793 .77174 m .70399 .73449 L .69688 .74232 L p .707 .577 .707 r
F P
0 g
s
.51678 .75834 m .49727 .70448 L .4953 .70113 L p .707 .577 .707 r
F P
0 g
s
.5013 .82688 m .50582 .80943 L .49391 .79612 L p .707 .577 .707 r
F P
0 g
s
.66603 .85016 m .66152 .8676 L .67774 .86144 L p .707 .577 .707 r
F P
0 g
s
.67774 .86144 m .68225 .844 L .66603 .85016 L p .707 .577 .707 r
F P
0 g
s
.6868 .63524 m .70632 .6891 L .70434 .68575 L p .707 .577 .707 r
F P
0 g
s
.70434 .68575 m .68483 .63189 L .6868 .63524 L p .707 .577 .707 r
F P
0 g
s
.4953 .70113 m .51481 .75499 L .51678 .75834 L p .707 .577 .707 r
F P
0 g
s
.49391 .79612 m .48939 .81356 L .5013 .82688 L p .707 .577 .707 r
F P
0 g
s
.50795 .79586 m .50401 .75861 L .50119 .75162 L p .707 .577 .707 r
F P
0 g
s
.51481 .75499 m .4953 .70113 L .5027 .69456 L p .707 .577 .707 r
F P
0 g
s
.5027 .69456 m .52222 .74841 L .51481 .75499 L p .707 .577 .707 r
F P
0 g
s
.50119 .75162 m .50513 .78887 L .50795 .79586 L p .707 .577 .707 r
F P
0 g
s
.50513 .78887 m .50119 .75162 L .50831 .74379 L p .707 .577 .707 r
F P
0 g
s
.50831 .74379 m .51225 .78104 L .50513 .78887 L p .707 .577 .707 r
F P
0 g
s
.52222 .74841 m .5027 .69456 L .51875 .6854 L p .707 .577 .707 r
F P
0 g
s
.51875 .6854 m .53827 .73926 L .52222 .74841 L p .707 .577 .707 r
F P
0 g
s
.51225 .78104 m .50831 .74379 L .52465 .73589 L p .707 .577 .707 r
F P
0 g
s
.49417 .79196 m .49868 .77452 L .5149 .76836 L p .707 .577 .707 r
F P
0 g
s
.5149 .76836 m .51039 .7858 L .49417 .79196 L p .707 .577 .707 r
F P
0 g
s
.52465 .73589 m .52859 .77314 L .51225 .78104 L p .707 .577 .707 r
F P
0 g
s
.53827 .73926 m .51875 .6854 L .54188 .67456 L p .707 .577 .707 r
F P
0 g
s
.54188 .67456 m .56139 .72842 L .53827 .73926 L p .707 .577 .707 r
F P
0 g
s
.52859 .77314 m .52465 .73589 L .54862 .72869 L p .707 .577 .707 r
F P
0 g
s
.51039 .7858 m .5149 .76836 L .53075 .76691 L p .707 .577 .707 r
F P
0 g
s
.54862 .72869 m .55256 .76594 L .52859 .77314 L p .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .55991 .81633 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53075 .76691 m .53843 .7662 L p .5289 .7729 L .707 .577 .707 r
F P
0 g
s
.5289 .7729 m .53843 .7662 L .53839 .76628 L .707 .577 .707 r
F
.51039 .7858 m .53075 .76691 L .5289 .7729 L F
.51492 .8182 m .51508 .82043 L p .54815 .74469 L F P
0 g
s
.53852 .76619 m .534 .78364 L .51039 .7858 L p .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .51492 .8182 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53843 .7662 m .53852 .76619 L p .53839 .76628 L .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .43391 .31667 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .51492 .8182 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51492 .8182 m .47779 .31603 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .54188 .67456 L .55517 .66911 L p .707 .577 .707 r
F P
0 g
s
.55517 .66911 m .56982 .66309 L p .56728 .68279 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .55517 .66911 L .56728 .68279 L .707 .577 .707 r
F
.52263 .31193 m .47779 .31603 L p .53133 .64217 L F P
0 g
s
.56982 .66309 m .58933 .71695 L .56139 .72842 L p .707 .577 .707 r
F P
0 g
s
.55256 .76594 m .54862 .72869 L .57787 .72289 L p .707 .577 .707 r
F P
0 g
s
.57787 .72289 m .58181 .76014 L .55256 .76594 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .54847 .66154 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.54847 .66154 m .52263 .31193 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.58933 .71695 m .57714 .68329 L p .59984 .65213 L .707 .577 .707 r
F P
0 g
s
.57714 .68329 m .56982 .66309 L .57935 .65961 L p .707 .577 .707 r
F P
0 g
s
.57935 .65961 m .59984 .65213 L p .57714 .68329 L .707 .577 .707 r
F P
0 g
s
.629 .64273 m .64851 .69659 L .61935 .70598 L p .707 .577 .707 r
F P
0 g
s
.61935 .70598 m .59984 .65213 L .629 .64273 L p .707 .577 .707 r
F P
0 g
s
.59984 .65213 m .61935 .70598 L .58933 .71695 L p .707 .577 .707 r
F P
0 g
s
.64054 .7176 m .64448 .75485 L .61349 .75632 L p .707 .577 .707 r
F P
0 g
s
.61349 .75632 m .60955 .71907 L .64054 .7176 L p .707 .577 .707 r
F P
0 g
s
.58181 .76014 m .57787 .72289 L .60955 .71907 L p .707 .577 .707 r
F P
0 g
s
.60955 .71907 m .61349 .75632 L .58181 .76014 L p .707 .577 .707 r
F P
0 g
s
.65492 .79578 m .6504 .81323 L .6239 .80125 L p .707 .577 .707 r
F P
0 g
s
.6239 .80125 m .62841 .7838 L .65492 .79578 L p .707 .577 .707 r
F P
0 g
s
.62841 .7838 m .6239 .80125 L .59725 .79288 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .59986 .80943 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.58985 .77268 m .59819 .77432 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.55148 .70221 m .55991 .81633 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .5627 .78569 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59819 .77432 m .59579 .7836 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59579 .7836 m .59368 .79176 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .59819 .77432 L .62841 .7838 L p .707 .577 .707 r
F P
0 g
s
.52263 .31193 m .52368 .32625 L p .59778 .78725 L .707 .577 .707 r
F P
0 g
s
.59696 .79101 m .62841 .7838 L .59725 .79288 L .707 .577 .707 r
F
.60131 .80918 m .59786 .78739 L .59778 .78725 L F
.59786 .78739 m .52263 .31193 L .59778 .78725 L F
.52368 .32625 m .55148 .70221 L p .59579 .7836 L F P
0 g
s
.5627 .78569 m .56722 .76825 L .58985 .77268 L p .707 .577 .707 r
F P
0 g
s
.5627 .78569 m .58985 .77268 L .59185 .77635 L .707 .577 .707 r
F
.59725 .79288 m .59368 .79176 L p .59696 .79101 L F P
0 g
s
.59986 .80943 m .60131 .80918 L p .52368 .32625 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .63521 .79968 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.56402 .30479 m .58544 .59455 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.58544 .59455 m .60131 .80918 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .56402 .30479 L .52263 .31193 L p .707 .577 .707 r
F P
0 g
s
.70399 .73449 m .70793 .77174 L .70512 .76475 L p .707 .577 .707 r
F P
0 g
s
.70512 .76475 m .70118 .72749 L .70399 .73449 L p .707 .577 .707 r
F P
0 g
s
.48939 .81356 m .49391 .79612 L .49145 .78409 L p .707 .577 .707 r
F P
0 g
s
.68225 .844 m .67774 .86144 L .68497 .85187 L p .707 .577 .707 r
F P
0 g
s
.68497 .85187 m .68948 .83443 L .68225 .844 L p .707 .577 .707 r
F P
0 g
s
.47119 .82107 m .43391 .31667 L .39527 .31379 L p .707 .577 .707 r
F P
0 g
s
.49145 .78409 m .48693 .80153 L .48939 .81356 L p .707 .577 .707 r
F P
0 g
s
.48693 .80153 m .49145 .78409 L .49868 .77452 L p .707 .577 .707 r
F P
0 g
s
.49868 .77452 m .49417 .79196 L .48693 .80153 L p .707 .577 .707 r
F P
0 g
s
.43391 .31667 m .47119 .82107 L .51508 .82043 L p .707 .577 .707 r
F P
0 g
s
.68483 .63189 m .70434 .68575 L .69319 .68595 L p .707 .577 .707 r
F P
0 g
s
.69319 .68595 m .67368 .63209 L .68483 .63189 L p .707 .577 .707 r
F P
0 g
s
.63521 .79968 m .59792 .29528 L .56402 .30479 L p .707 .577 .707 r
F P
0 g
s
.25877 .69931 m .23925 .64545 L .2101 .65484 L p .707 .577 .707 r
F P
0 g
s
.23925 .64545 m .25877 .69931 L .28879 .68834 L p .707 .577 .707 r
F P
0 g
s
.28879 .68834 m .26927 .63448 L .23925 .64545 L p .707 .577 .707 r
F P
0 g
s
.26927 .63448 m .28879 .68834 L .31673 .67688 L p .707 .577 .707 r
F P
0 g
s
.31673 .67688 m .29721 .62302 L .26927 .63448 L p .707 .577 .707 r
F P
0 g
s
.43255 .81819 m .39527 .31379 L .36565 .30768 L p .707 .577 .707 r
F P
0 g
s
.39527 .31379 m .43255 .81819 L .47119 .82107 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70118 .72749 m .70512 .76475 L .69265 .75928 L p .707 .577 .707 r
F P
0 g
s
.69265 .75928 m .68871 .72203 L .70118 .72749 L p .707 .577 .707 r
F P
0 g
s
.2101 .65484 m .22961 .7087 L .25877 .69931 L p .707 .577 .707 r
F P
0 g
s
.22961 .7087 m .2101 .65484 L .18465 .66175 L p .707 .577 .707 r
F P
0 g
s
.68948 .83443 m .68497 .85187 L .68251 .83984 L p .707 .577 .707 r
F P
0 g
s
.68251 .83984 m .68703 .8224 L .68948 .83443 L p .707 .577 .707 r
F P
0 g
s
.29721 .62302 m .31673 .67688 L .33985 .66603 L p .707 .577 .707 r
F P
0 g
s
.33985 .66603 m .32034 .61218 L .29721 .62302 L p .707 .577 .707 r
F P
0 g
s
.18465 .66175 m .20417 .7156 L .22961 .7087 L p .707 .577 .707 r
F P
0 g
s
.67368 .63209 m .69319 .68595 L .67396 .68969 L p .707 .577 .707 r
F P
0 g
s
.67396 .68969 m .65444 .63583 L .67368 .63209 L p .707 .577 .707 r
F P
0 g
s
.64851 .69659 m .629 .64273 L .65444 .63583 L p .707 .577 .707 r
F P
0 g
s
.66782 .71862 m .67176 .75587 L .64448 .75485 L p .707 .577 .707 r
F P
0 g
s
.64448 .75485 m .64054 .7176 L .66782 .71862 L p .707 .577 .707 r
F P
0 g
s
.59792 .29528 m .63521 .79968 L .6583 .78875 L p .707 .577 .707 r
F P
0 g
s
.65444 .63583 m .67396 .68969 L .64851 .69659 L p .707 .577 .707 r
F P
0 g
s
.6583 .78875 m .62101 .28435 L .59792 .29528 L p .707 .577 .707 r
F P
0 g
s
.25657 .77242 m .25263 .73517 L .22164 .73664 L p .707 .577 .707 r
F P
0 g
s
.25263 .73517 m .25657 .77242 L .28824 .7686 L p .707 .577 .707 r
F P
0 g
s
.28824 .7686 m .28431 .73135 L .25263 .73517 L p .707 .577 .707 r
F P
0 g
s
.28431 .73135 m .28824 .7686 L .3175 .7628 L p .707 .577 .707 r
F P
0 g
s
.3175 .7628 m .31356 .72555 L .28431 .73135 L p .707 .577 .707 r
F P
0 g
s
.22558 .77389 m .22164 .73664 L .19436 .73562 L p .707 .577 .707 r
F P
0 g
s
.22164 .73664 m .22558 .77389 L .25657 .77242 L p .707 .577 .707 r
F P
0 g
s
.20417 .7156 m .18465 .66175 L .16541 .66548 L p .707 .577 .707 r
F P
0 g
s
.32034 .61218 m .33985 .66603 L .3559 .65688 L p .707 .577 .707 r
F P
0 g
s
.3559 .65688 m .33639 .60302 L .32034 .61218 L p .707 .577 .707 r
F P
0 g
s
.31356 .72555 m .3175 .7628 L .34147 .7556 L p .707 .577 .707 r
F P
0 g
s
.34147 .7556 m .33753 .71835 L .31356 .72555 L p .707 .577 .707 r
F P
0 g
s
.16541 .66548 m .18493 .71934 L .20417 .7156 L p .707 .577 .707 r
F P
0 g
s
.68871 .72203 m .69265 .75928 L .67176 .75587 L p .707 .577 .707 r
F P
0 g
s
.67176 .75587 m .66782 .71862 L .68871 .72203 L p .707 .577 .707 r
F P
0 g
s
.19436 .73562 m .1983 .77288 L .22558 .77389 L p .707 .577 .707 r
F P
0 g
s
.40294 .81207 m .36565 .30768 L .34796 .29893 L p .707 .577 .707 r
F P
0 g
s
.36565 .30768 m .40294 .81207 L .43255 .81819 L p .707 .577 .707 r
F P
0 g
s
.68703 .8224 m .68251 .83984 L .6706 .82652 L p .707 .577 .707 r
F P
0 g
s
.6706 .82652 m .67512 .80908 L .68703 .8224 L p .707 .577 .707 r
F P
0 g
s
.23522 .81586 m .23973 .79842 L .20951 .78893 L p .707 .577 .707 r
F P
0 g
s
.23973 .79842 m .23522 .81586 L .26619 .82193 L p .707 .577 .707 r
F P
0 g
s
.26619 .82193 m .27071 .80449 L .23973 .79842 L p .707 .577 .707 r
F P
0 g
s
.1983 .77288 m .19436 .73562 L .17346 .73221 L p .707 .577 .707 r
F P
0 g
s
.205 .80637 m .20951 .78893 L .18301 .77695 L p .707 .577 .707 r
F P
0 g
s
.20951 .78893 m .205 .80637 L .23522 .81586 L p .707 .577 .707 r
F P
0 g
s
.27071 .80449 m .26619 .82193 L .29489 .82398 L p .707 .577 .707 r
F P
0 g
s
.29489 .82398 m .29941 .80654 L .27071 .80449 L p .707 .577 .707 r
F P
0 g
s
.18493 .71934 m .16541 .66548 L .15426 .66568 L p .707 .577 .707 r
F P
0 g
s
.17346 .73221 m .1774 .76947 L .1983 .77288 L p .707 .577 .707 r
F P
0 g
s
.33753 .71835 m .34147 .7556 L .35781 .7477 L p .707 .577 .707 r
F P
0 g
s
.35781 .7477 m .35387 .71045 L .33753 .71835 L p .707 .577 .707 r
F P
0 g
s
.18301 .77695 m .17849 .79439 L .205 .80637 L p .707 .577 .707 r
F P
0 g
s
.62101 .28435 m .6583 .78875 L .66832 .77747 L p .707 .577 .707 r
F P
0 g
s
.66832 .77747 m .63103 .27307 L .62101 .28435 L p .707 .577 .707 r
F P
0 g
s
.33639 .60302 m .3559 .65688 L .36331 .6503 L p .707 .577 .707 r
F P
0 g
s
.36331 .6503 m .34379 .59644 L .33639 .60302 L p .707 .577 .707 r
F P
0 g
s
.15426 .66568 m .17378 .71954 L .18493 .71934 L p .707 .577 .707 r
F P
0 g
s
.17849 .79439 m .18301 .77695 L .16281 .76365 L p .707 .577 .707 r
F P
0 g
s
.29941 .80654 m .29489 .82398 L .31851 .82182 L p .707 .577 .707 r
F P
0 g
s
.31851 .82182 m .32302 .80438 L .29941 .80654 L p .707 .577 .707 r
F P
0 g
s
.67512 .80908 m .6706 .82652 L .6504 .81323 L p .707 .577 .707 r
F P
0 g
s
.6504 .81323 m .65492 .79578 L .67512 .80908 L p .707 .577 .707 r
F P
0 g
s
.16281 .76365 m .15829 .78109 L .17849 .79439 L p .707 .577 .707 r
F P
0 g
s
.1774 .76947 m .17346 .73221 L .161 .72675 L p .707 .577 .707 r
F P
0 g
s
.161 .72675 m .16494 .764 L .1774 .76947 L p .707 .577 .707 r
F P
0 g
s
.38525 .80332 m .34796 .29893 L .34393 .28839 L p .707 .577 .707 r
F P
0 g
s
.34796 .29893 m .38525 .80332 L .40294 .81207 L p .707 .577 .707 r
F P
0 g
s
.35387 .71045 m .35781 .7477 L .36492 .73987 L p .707 .577 .707 r
F P
0 g
s
.36492 .73987 m .36098 .70262 L .35387 .71045 L p .707 .577 .707 r
F P
0 g
s
.15829 .78109 m .16281 .76365 L .1509 .75034 L p .707 .577 .707 r
F P
0 g
s
.17378 .71954 m .15426 .66568 L .15229 .66233 L p .707 .577 .707 r
F P
0 g
s
.32302 .80438 m .31851 .82182 L .33473 .81566 L p .707 .577 .707 r
F P
0 g
s
.33473 .81566 m .33924 .79821 L .32302 .80438 L p .707 .577 .707 r
F P
0 g
s
.534 .78364 m .53852 .76619 L .56722 .76825 L p .707 .577 .707 r
F P
0 g
s
.34379 .59644 m .36331 .6503 L .36134 .64695 L p .707 .577 .707 r
F P
0 g
s
.36134 .64695 m .34182 .59309 L .34379 .59644 L p .707 .577 .707 r
F P
0 g
s
.1509 .75034 m .14638 .76778 L .15829 .78109 L p .707 .577 .707 r
F P
0 g
s
.15229 .66233 m .1718 .71619 L .17378 .71954 L p .707 .577 .707 r
F P
0 g
s
.56722 .76825 m .5627 .78569 L .534 .78364 L p .707 .577 .707 r
F P
0 g
s
.16494 .764 m .161 .72675 L .15819 .71975 L p .707 .577 .707 r
F P
0 g
s
.6587 .74814 m .66082 .73998 L p .64302 .7174 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .65935 .73378 L .64302 .7174 L .707 .577 .707 r
F
.627 .26254 m .66296 .74905 L p .66082 .73998 L F P
0 g
s
.64287 .66401 m .6371 .51819 L .66082 .73998 L .707 .577 .707 r
F
.6371 .51819 m .627 .26254 L .66082 .73998 L F
.66832 .77747 m .66469 .768 L p .65212 .58635 L F P
0 g
s
.66341 .75396 m .65212 .58635 L .66469 .768 L .707 .577 .707 r
F
.65212 .58635 m .65166 .56027 L .66832 .77747 L F
.63788 .36574 m .66832 .77747 L p .64106 .422 L F P
0 g
s
.627 .26254 m .63103 .27307 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .6525 .60754 L p .65212 .58635 L .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .66514 .6661 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.66116 .72934 m .65778 .72711 L p .66179 .73622 L .707 .577 .707 r
F P
0 g
s
.65778 .72711 m .64302 .7174 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .65778 .72711 L .65935 .73378 L .707 .577 .707 r
F
.60931 .25379 m .627 .26254 L p .64287 .66401 L F P
0 g
s
.64302 .7174 m .63851 .73484 L .6587 .74814 L p .707 .577 .707 r
F P
0 g
s
.64659 .75819 m .63816 .64406 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .60931 .25379 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63851 .73484 m .64302 .7174 L .63111 .70408 L p .707 .577 .707 r
F P
0 g
s
.63111 .70408 m .6266 .72152 L .63851 .73484 L p .707 .577 .707 r
F P
0 g
s
.6266 .72152 m .63111 .70408 L .6311 .70403 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .61406 .56259 L .63533 .69048 L .707 .577 .707 r
F
.6311 .70403 m .62865 .69205 L p .62687 .7176 L F P
0 g
s
.6266 .72152 m .6311 .70403 L .62687 .7176 L .707 .577 .707 r
F
.64659 .75819 m .61698 .75207 L p .61694 .74945 L F P
0 g
s
.62865 .69205 m .62414 .70949 L .6266 .72152 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .63533 .69048 L .64659 .75819 L .707 .577 .707 r
F
.60931 .25379 m .63515 .60339 L p .61406 .56259 L F P
0 g
s
.63515 .60339 m .64659 .75819 L p .61406 .56259 L .707 .577 .707 r
F P
0 g
s
.65317 .64515 m .65033 .63276 L .63448 .61244 L .707 .577 .707 r
F
.64563 .61224 m .63978 .61235 L p .65033 .63276 L F P
0 g
s
.63978 .61235 m .63448 .61244 L p .65033 .63276 L .707 .577 .707 r
F P
0 g
s
.63448 .61244 m .65352 .66501 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65352 .66501 m .65399 .6663 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64842 .55231 L .64106 .422 L .707 .577 .707 r
F
.6525 .60754 m .64842 .55231 L p .65212 .58635 L F P
0 g
s
.64842 .55231 m .627 .26254 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66514 .6661 m .68438 .66236 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.64563 .61224 m .65294 .63243 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.65294 .63243 m .66514 .6661 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.66322 .7307 m .66082 .73998 L p .68521 .76012 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .6587 .74814 L .66184 .74955 L p .707 .577 .707 r
F P
0 g
s
.66296 .74905 m .66428 .76694 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66184 .74955 m .68521 .76012 L p .66082 .73998 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .64659 .75819 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .66179 .73622 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .66322 .7307 L .66116 .72934 L p .707 .577 .707 r
F P
0 g
s
.66469 .768 m .66428 .76694 L p .66341 .75396 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64106 .422 L .65166 .56027 L .707 .577 .707 r
F
.66514 .6661 m .65294 .63243 L p .65317 .64515 L F P
0 g
s
.65294 .63243 m .64563 .61224 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .66487 .60851 L .65173 .61105 L p .707 .577 .707 r
F P
0 g
s
.65173 .61105 m .64563 .61224 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .65173 .61105 L .65229 .62086 L .707 .577 .707 r
F
.63103 .27307 m .63788 .36574 L p .64106 .422 L F P
0 g
s
.15819 .71975 m .16212 .75701 L .16494 .764 L p .707 .577 .707 r
F P
0 g
s
.14638 .76778 m .1509 .75034 L .14844 .73831 L p .707 .577 .707 r
F P
0 g
s
.36098 .70262 m .36492 .73987 L .36211 .73288 L p .707 .577 .707 r
F P
0 g
s
.36211 .73288 m .35817 .69563 L .36098 .70262 L p .707 .577 .707 r
F P
0 g
s
.33924 .79821 m .33473 .81566 L .34196 .80609 L p .707 .577 .707 r
F P
0 g
s
.34196 .80609 m .34648 .78865 L .33924 .79821 L p .707 .577 .707 r
F P
0 g
s
.14844 .73831 m .14392 .75575 L .14638 .76778 L p .707 .577 .707 r
F P
0 g
s
.1718 .71619 m .15229 .66233 L .15969 .65576 L p .707 .577 .707 r
F P
0 g
s
.34182 .59309 m .36134 .64695 L .35018 .64715 L p .707 .577 .707 r
F P
0 g
s
.35018 .64715 m .33067 .5933 L .34182 .59309 L p .707 .577 .707 r
F P
0 g
s
.15969 .65576 m .17921 .70962 L .1718 .71619 L p .707 .577 .707 r
F P
0 g
s
.34393 .28839 m .38122 .79279 L .38525 .80332 L p .707 .577 .707 r
F P
0 g
s
.38122 .79279 m .34393 .28839 L .35395 .27711 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16212 .75701 m .15819 .71975 L .1653 .71192 L p .707 .577 .707 r
F P
0 g
s
.1653 .71192 m .16924 .74918 L .16212 .75701 L p .707 .577 .707 r
F P
0 g
s
.14392 .75575 m .14844 .73831 L .15567 .72874 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34648 .78865 m .34196 .80609 L .3395 .79406 L p .707 .577 .707 r
F P
0 g
s
.3395 .79406 m .34402 .77662 L .34648 .78865 L p .707 .577 .707 r
F P
0 g
s
.35817 .69563 m .36211 .73288 L .34964 .72741 L p .707 .577 .707 r
F P
0 g
s
.34964 .72741 m .3457 .69016 L .35817 .69563 L p .707 .577 .707 r
F P
0 g
s
.15567 .72874 m .15116 .74618 L .14392 .75575 L p .707 .577 .707 r
F P
0 g
s
.17921 .70962 m .15969 .65576 L .17574 .6466 L p .707 .577 .707 r
F P
0 g
s
.33067 .5933 m .35018 .64715 L .33095 .65089 L p .707 .577 .707 r
F P
0 g
s
.33095 .65089 m .31143 .59703 L .33067 .5933 L p .707 .577 .707 r
F P
0 g
s
.17574 .6466 m .19526 .70046 L .17921 .70962 L p .707 .577 .707 r
F P
0 g
s
.16924 .74918 m .1653 .71192 L .18164 .70402 L p .707 .577 .707 r
F P
0 g
s
.39124 .78151 m .35395 .27711 L .37704 .26618 L p .707 .577 .707 r
F P
0 g
s
.35395 .27711 m .39124 .78151 L .38122 .79279 L p .707 .577 .707 r
F P
0 g
s
.15116 .74618 m .15567 .72874 L .17189 .72258 L p .707 .577 .707 r
F P
0 g
s
.18164 .70402 m .18558 .74127 L .16924 .74918 L p .707 .577 .707 r
F P
0 g
s
.34402 .77662 m .3395 .79406 L .32759 .78074 L p .707 .577 .707 r
F P
0 g
s
.32759 .78074 m .33211 .7633 L .34402 .77662 L p .707 .577 .707 r
F P
0 g
s
.3457 .69016 m .34964 .72741 L .32875 .724 L p .707 .577 .707 r
F P
0 g
s
.32875 .724 m .32481 .68675 L .3457 .69016 L p .707 .577 .707 r
F P
0 g
s
.19526 .70046 m .17574 .6466 L .19887 .63576 L p .707 .577 .707 r
F P
0 g
s
.17189 .72258 m .16738 .74002 L .15116 .74618 L p .707 .577 .707 r
F P
0 g
s
.31143 .59703 m .33095 .65089 L .3055 .65779 L p .707 .577 .707 r
F P
0 g
s
.3055 .65779 m .28599 .60393 L .31143 .59703 L p .707 .577 .707 r
F P
0 g
s
.19887 .63576 m .21838 .68962 L .19526 .70046 L p .707 .577 .707 r
F P
0 g
s
.61698 .75207 m .57969 .24767 L .60931 .25379 L p .707 .577 .707 r
F P
0 g
s
.18558 .74127 m .18164 .70402 L .20561 .69682 L p .707 .577 .707 r
F P
0 g
s
.21838 .68962 m .19887 .63576 L .22681 .62429 L p .707 .577 .707 r
F P
0 g
s
.28599 .60393 m .3055 .65779 L .27634 .66719 L p .707 .577 .707 r
F P
0 g
s
.27634 .66719 m .25683 .61333 L .28599 .60393 L p .707 .577 .707 r
F P
0 g
s
.20561 .69682 m .20955 .73407 L .18558 .74127 L p .707 .577 .707 r
F P
0 g
s
.32481 .68675 m .32875 .724 L .30147 .72298 L p .707 .577 .707 r
F P
0 g
s
.30147 .72298 m .29753 .68573 L .32481 .68675 L p .707 .577 .707 r
F P
0 g
s
.16738 .74002 m .17189 .72258 L .19551 .72041 L p .707 .577 .707 r
F P
0 g
s
.33211 .7633 m .32759 .78074 L .30739 .76744 L p .707 .577 .707 r
F P
0 g
s
.30739 .76744 m .31191 .75 L .33211 .7633 L p .707 .577 .707 r
F P
0 g
s
.22681 .62429 m .24632 .67815 L .21838 .68962 L p .707 .577 .707 r
F P
0 g
s
.73898 .64607 m .71947 .59221 L .69031 .6016 L p .707 .577 .707 r
F P
0 g
s
.71947 .59221 m .73898 .64607 L .769 .6351 L p .707 .577 .707 r
F P
0 g
s
.769 .6351 m .74949 .58124 L .71947 .59221 L p .707 .577 .707 r
F P
0 g
s
.74949 .58124 m .769 .6351 L .79694 .62364 L p .707 .577 .707 r
F P
0 g
s
.79694 .62364 m .77743 .56978 L .74949 .58124 L p .707 .577 .707 r
F P
0 g
s
.19551 .72041 m .19099 .73785 L .16738 .74002 L p .707 .577 .707 r
F P
0 g
s
.24632 .67815 m .22681 .62429 L .25683 .61333 L p .707 .577 .707 r
F P
0 g
s
.25683 .61333 m .27634 .66719 L .24632 .67815 L p .707 .577 .707 r
F P
0 g
s
.37704 .26618 m .41433 .77058 L .39124 .78151 L p .707 .577 .707 r
F P
0 g
s
.41433 .77058 m .37704 .26618 L .41094 .25668 L p .707 .577 .707 r
F P
0 g
s
.20955 .73407 m .20561 .69682 L .23486 .69103 L p .707 .577 .707 r
F P
0 g
s
.69031 .6016 m .70982 .65546 L .73898 .64607 L p .707 .577 .707 r
F P
0 g
s
.70982 .65546 m .69031 .6016 L .66487 .60851 L p .707 .577 .707 r
F P
0 g
s
.29753 .68573 m .30147 .72298 L .27048 .72446 L p .707 .577 .707 r
F P
0 g
s
.27048 .72446 m .26654 .68721 L .29753 .68573 L p .707 .577 .707 r
F P
0 g
s
.77743 .56978 m .79694 .62364 L .82007 .61279 L p .707 .577 .707 r
F P
0 g
s
.82007 .61279 m .80055 .55894 L .77743 .56978 L p .707 .577 .707 r
F P
0 g
s
.23486 .69103 m .2388 .72828 L .20955 .73407 L p .707 .577 .707 r
F P
0 g
s
.19099 .73785 m .19551 .72041 L .22421 .72247 L p .707 .577 .707 r
F P
0 g
s
.66487 .60851 m .68438 .66236 L .70982 .65546 L p .707 .577 .707 r
F P
0 g
s
.2388 .72828 m .23486 .69103 L .26654 .68721 L p .707 .577 .707 r
F P
0 g
s
.31191 .75 m .30739 .76744 L .28089 .75546 L p .707 .577 .707 r
F P
0 g
s
.28089 .75546 m .2854 .73802 L .31191 .75 L p .707 .577 .707 r
F P
0 g
s
.73678 .71225 m .73284 .675 L .70185 .67647 L p .707 .577 .707 r
F P
0 g
s
.73284 .675 m .73678 .71225 L .76846 .70843 L p .707 .577 .707 r
F P
0 g
s
.76846 .70843 m .76452 .67118 L .73284 .675 L p .707 .577 .707 r
F P
0 g
s
.57969 .24767 m .61698 .75207 L .57834 .74919 L p .707 .577 .707 r
F P
0 g
s
.57834 .74919 m .54105 .2448 L .57969 .24767 L p .707 .577 .707 r
F P
0 g
s
.26654 .68721 m .27048 .72446 L .2388 .72828 L p .707 .577 .707 r
F P
0 g
s
.76452 .67118 m .76846 .70843 L .79771 .70263 L p .707 .577 .707 r
F P
0 g
s
.79771 .70263 m .79377 .66538 L .76452 .67118 L p .707 .577 .707 r
F P
0 g
s
.22421 .72247 m .21969 .73991 L .19099 .73785 L p .707 .577 .707 r
F P
0 g
s
.70579 .71372 m .70185 .67647 L .67457 .67545 L p .707 .577 .707 r
F P
0 g
s
.70185 .67647 m .70579 .71372 L .73678 .71225 L p .707 .577 .707 r
F P
0 g
s
.21969 .73991 m .22421 .72247 L .25518 .72853 L p .707 .577 .707 r
F P
0 g
s
.80055 .55894 m .82007 .61279 L .83612 .60364 L p .707 .577 .707 r
F P
0 g
s
.83612 .60364 m .8166 .54978 L .80055 .55894 L p .707 .577 .707 r
F P
0 g
s
.2854 .73802 m .28089 .75546 L .25067 .74598 L p .707 .577 .707 r
F P
0 g
s
.25067 .74598 m .25518 .72853 L .2854 .73802 L p .707 .577 .707 r
F P
0 g
s
.79377 .66538 m .79771 .70263 L .82168 .69543 L p .707 .577 .707 r
F P
0 g
s
.82168 .69543 m .81774 .65818 L .79377 .66538 L p .707 .577 .707 r
F P
0 g
s
.44823 .76108 m .41094 .25668 L .45233 .24953 L p .707 .577 .707 r
F P
0 g
s
.41094 .25668 m .44823 .76108 L .41433 .77058 L p .707 .577 .707 r
F P
0 g
s
.67457 .67545 m .67851 .7127 L .70579 .71372 L p .707 .577 .707 r
F P
0 g
s
.25518 .72853 m .25067 .74598 L .21969 .73991 L p .707 .577 .707 r
F P
0 g
s
.54105 .2448 m .57834 .74919 L .53445 .74983 L p .707 .577 .707 r
F P
0 g
s
.53445 .74983 m .49717 .24544 L .54105 .2448 L p .707 .577 .707 r
F P
0 g
s
.67851 .7127 m .67457 .67545 L .65368 .67204 L p .707 .577 .707 r
F P
0 g
s
.71543 .76961 m .71994 .75216 L .68972 .74268 L p .707 .577 .707 r
F P
0 g
s
.71994 .75216 m .71543 .76961 L .74641 .77567 L p .707 .577 .707 r
F P
0 g
s
.74641 .77567 m .75092 .75823 L .71994 .75216 L p .707 .577 .707 r
F P
0 g
s
.48962 .75393 m .45233 .24953 L .49717 .24544 L p .707 .577 .707 r
F P
0 g
s
.45233 .24953 m .48962 .75393 L .44823 .76108 L p .707 .577 .707 r
F P
0 g
s
.68521 .76012 m .68972 .74268 L .66322 .7307 L p .707 .577 .707 r
F P
0 g
s
.68972 .74268 m .68521 .76012 L .71543 .76961 L p .707 .577 .707 r
F P
0 g
s
.75092 .75823 m .74641 .77567 L .77511 .77773 L p .707 .577 .707 r
F P
0 g
s
.77511 .77773 m .77962 .76029 L .75092 .75823 L p .707 .577 .707 r
F P
0 g
s
.65368 .67204 m .65762 .70929 L .67851 .7127 L p .707 .577 .707 r
F P
0 g
s
.81774 .65818 m .82168 .69543 L .83802 .68753 L p .707 .577 .707 r
F P
0 g
s
.83802 .68753 m .83408 .65028 L .81774 .65818 L p .707 .577 .707 r
F P
0 g
s
.49717 .24544 m .53445 .74983 L .48962 .75393 L p .707 .577 .707 r
F P
0 g
s
.8166 .54978 m .83612 .60364 L .84352 .59706 L p .707 .577 .707 r
F P
0 g
s
.84352 .59706 m .82401 .5432 L .8166 .54978 L p .707 .577 .707 r
F P
0 g
s
.77962 .76029 m .77511 .77773 L .79872 .77556 L p .707 .577 .707 r
F P
0 g
s
.79872 .77556 m .80324 .75812 L .77962 .76029 L p .707 .577 .707 r
F P
0 g
s
.65762 .70929 m .65368 .67204 L .64121 .66657 L p .707 .577 .707 r
F P
0 g
s
.64121 .66657 m .64515 .70382 L .65762 .70929 L p .707 .577 .707 r
F P
0 g
s
.83408 .65028 m .83802 .68753 L .84514 .6797 L p .707 .577 .707 r
F P
0 g
s
.84514 .6797 m .8412 .64245 L .83408 .65028 L p .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .63448 .61244 L .6325 .60909 L p .707 .577 .707 r
F P
0 g
s
.80324 .75812 m .79872 .77556 L .81494 .7694 L p .707 .577 .707 r
F P
0 g
s
.81494 .7694 m .81945 .75196 L .80324 .75812 L p .707 .577 .707 r
F P
0 g
s
.82401 .5432 m .84352 .59706 L .84155 .59371 L p .707 .577 .707 r
F P
0 g
s
.84155 .59371 m .82204 .53985 L .82401 .5432 L p .707 .577 .707 r
F P
0 g
s
.6325 .60909 m .65202 .66295 L .65399 .6663 L p .707 .577 .707 r
F P
0 g
s
.64515 .70382 m .64121 .66657 L .6384 .65958 L p .707 .577 .707 r
F P
0 g
s
.6384 .65958 m .64234 .69683 L .64515 .70382 L p .707 .577 .707 r
F P
0 g
s
.8412 .64245 m .84514 .6797 L .84232 .67271 L p .707 .577 .707 r
F P
0 g
s
.84232 .67271 m .83838 .63546 L .8412 .64245 L p .707 .577 .707 r
F P
0 g
s
.81945 .75196 m .81494 .7694 L .82217 .75983 L p .707 .577 .707 r
F P
0 g
s
.82217 .75983 m .82669 .74239 L .81945 .75196 L p .707 .577 .707 r
F P
0 g
s
.65202 .66295 m .6325 .60909 L .63991 .60252 L p .707 .577 .707 r
F P
0 g
s
.82204 .53985 m .84155 .59371 L .8304 .59391 L p .707 .577 .707 r
F P
0 g
s
.8304 .59391 m .81089 .54005 L .82204 .53985 L p .707 .577 .707 r
F P
0 g
s
.63991 .60252 m .65942 .65638 L .65202 .66295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64234 .69683 m .6384 .65958 L .64551 .65175 L p .707 .577 .707 r
F P
0 g
s
.39597 .60727 m .37646 .55341 L .3473 .56281 L p .707 .577 .707 r
F P
0 g
s
.37646 .55341 m .39597 .60727 L .42599 .5963 L p .707 .577 .707 r
F P
0 g
s
.42599 .5963 m .40648 .54244 L .37646 .55341 L p .707 .577 .707 r
F P
0 g
s
.40648 .54244 m .42599 .5963 L .45393 .58484 L p .707 .577 .707 r
F P
0 g
s
.45393 .58484 m .43442 .53098 L .40648 .54244 L p .707 .577 .707 r
F P
0 g
s
.64551 .65175 m .64945 .689 L .64234 .69683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83838 .63546 m .84232 .67271 L .82986 .66724 L p .707 .577 .707 r
F P
0 g
s
.82986 .66724 m .82592 .62999 L .83838 .63546 L p .707 .577 .707 r
F P
0 g
s
.3473 .56281 m .36681 .61666 L .39597 .60727 L p .707 .577 .707 r
F P
0 g
s
.62414 .70949 m .62865 .69205 L .63589 .68248 L p .707 .577 .707 r
F P
0 g
s
.36681 .61666 m .3473 .56281 L .32186 .56971 L p .707 .577 .707 r
F P
0 g
s
.82669 .74239 m .82217 .75983 L .81972 .7478 L p .707 .577 .707 r
F P
0 g
s
.81972 .7478 m .82423 .73036 L .82669 .74239 L p .707 .577 .707 r
F P
0 g
s
.43442 .53098 m .45393 .58484 L .47706 .574 L p .707 .577 .707 r
F P
0 g
s
.47706 .574 m .45754 .52014 L .43442 .53098 L p .707 .577 .707 r
F P
0 g
s
.65942 .65638 m .63991 .60252 L .65596 .59336 L p .707 .577 .707 r
F P
0 g
s
.63589 .68248 m .63137 .69993 L .62414 .70949 L p .707 .577 .707 r
F P
0 g
s
.32186 .56971 m .34137 .62357 L .36681 .61666 L p .707 .577 .707 r
F P
0 g
s
.81089 .54005 m .8304 .59391 L .81116 .59765 L p .707 .577 .707 r
F P
0 g
s
.81116 .59765 m .79165 .54379 L .81089 .54005 L p .707 .577 .707 r
F P
0 g
s
.39377 .68038 m .38983 .64313 L .35884 .6446 L p .707 .577 .707 r
F P
0 g
s
.38983 .64313 m .39377 .68038 L .42545 .67656 L p .707 .577 .707 r
F P
0 g
s
.42545 .67656 m .42151 .63931 L .38983 .64313 L p .707 .577 .707 r
F P
0 g
s
.65596 .59336 m .67547 .64722 L .65942 .65638 L p .707 .577 .707 r
F P
0 g
s
.42151 .63931 m .42545 .67656 L .4547 .67077 L p .707 .577 .707 r
F P
0 g
s
.4547 .67077 m .45076 .63351 L .42151 .63931 L p .707 .577 .707 r
F P
0 g
s
.64945 .689 m .64551 .65175 L .66185 .64385 L p .707 .577 .707 r
F P
0 g
s
.36278 .68185 m .35884 .6446 L .33156 .64359 L p .707 .577 .707 r
F P
0 g
s
.35884 .6446 m .36278 .68185 L .39377 .68038 L p .707 .577 .707 r
F P
0 g
s
.34137 .62357 m .32186 .56971 L .30262 .57344 L p .707 .577 .707 r
F P
0 g
s
.45754 .52014 m .47706 .574 L .49311 .56484 L p .707 .577 .707 r
F P
0 g
s
.49311 .56484 m .47359 .51098 L .45754 .52014 L p .707 .577 .707 r
F P
0 g
s
.45076 .63351 m .4547 .67077 L .47867 .66356 L p .707 .577 .707 r
F P
0 g
s
.47867 .66356 m .47473 .62631 L .45076 .63351 L p .707 .577 .707 r
F P
0 g
s
.66185 .64385 m .66579 .6811 L .64945 .689 L p .707 .577 .707 r
F P
0 g
s
.30262 .57344 m .32213 .6273 L .34137 .62357 L p .707 .577 .707 r
F P
0 g
s
.82592 .62999 m .82986 .66724 L .80896 .66383 L p .707 .577 .707 r
F P
0 g
s
.80896 .66383 m .80502 .62658 L .82592 .62999 L p .707 .577 .707 r
F P
0 g
s
.33156 .64359 m .3355 .68084 L .36278 .68185 L p .707 .577 .707 r
F P
0 g
s
.63137 .69993 m .63589 .68248 L .65211 .67632 L p .707 .577 .707 r
F P
0 g
s
.67547 .64722 m .65596 .59336 L .67908 .58252 L p .707 .577 .707 r
F P
0 g
s
.82423 .73036 m .81972 .7478 L .80781 .73449 L p .707 .577 .707 r
F P
0 g
s
.80781 .73449 m .81232 .71705 L .82423 .73036 L p .707 .577 .707 r
F P
0 g
s
.79165 .54379 m .81116 .59765 L .78572 .60455 L p .707 .577 .707 r
F P
0 g
s
.78572 .60455 m .7662 .55069 L .79165 .54379 L p .707 .577 .707 r
F P
0 g
s
.37242 .72382 m .37693 .70638 L .34671 .69689 L p .707 .577 .707 r
F P
0 g
s
.37693 .70638 m .37242 .72382 L .4034 .72989 L p .707 .577 .707 r
F P
0 g
s
.4034 .72989 m .40791 .71245 L .37693 .70638 L p .707 .577 .707 r
F P
0 g
s
.65211 .67632 m .64759 .69376 L .63137 .69993 L p .707 .577 .707 r
F P
0 g
s
.3355 .68084 m .33156 .64359 L .31067 .64018 L p .707 .577 .707 r
F P
0 g
s
.67908 .58252 m .6986 .63638 L .67547 .64722 L p .707 .577 .707 r
F P
0 g
s
.3422 .71434 m .34671 .69689 L .32021 .68491 L p .707 .577 .707 r
F P
0 g
s
.34671 .69689 m .3422 .71434 L .37242 .72382 L p .707 .577 .707 r
F P
0 g
s
.40791 .71245 m .4034 .72989 L .4321 .73195 L p .707 .577 .707 r
F P
0 g
s
.4321 .73195 m .43661 .7145 L .40791 .71245 L p .707 .577 .707 r
F P
0 g
s
.66579 .6811 m .66185 .64385 L .68582 .63665 L p .707 .577 .707 r
F P
0 g
s
.32213 .6273 m .30262 .57344 L .29147 .57365 L p .707 .577 .707 r
F P
0 g
s
.31067 .64018 m .31461 .67743 L .3355 .68084 L p .707 .577 .707 r
F P
0 g
s
.47473 .62631 m .47867 .66356 L .49501 .65566 L p .707 .577 .707 r
F P
0 g
s
.49501 .65566 m .49107 .61841 L .47473 .62631 L p .707 .577 .707 r
F P
0 g
s
.32021 .68491 m .31569 .70236 L .3422 .71434 L p .707 .577 .707 r
F P
0 g
s
.47359 .51098 m .49311 .56484 L .50051 .55826 L p .707 .577 .707 r
F P
0 g
s
.50051 .55826 m .481 .50441 L .47359 .51098 L p .707 .577 .707 r
F P
0 g
s
.6986 .63638 m .67908 .58252 L .70703 .57105 L p .707 .577 .707 r
F P
0 g
s
.29147 .57365 m .31098 .6275 L .32213 .6273 L p .707 .577 .707 r
F P
0 g
s
.68582 .63665 m .68976 .6739 L .66579 .6811 L p .707 .577 .707 r
F P
0 g
s
.80502 .62658 m .80896 .66383 L .78168 .66281 L p .707 .577 .707 r
F P
0 g
s
.78168 .66281 m .77774 .62556 L .80502 .62658 L p .707 .577 .707 r
F P
0 g
s
.31569 .70236 m .32021 .68491 L .30001 .67162 L p .707 .577 .707 r
F P
0 g
s
.7662 .55069 m .78572 .60455 L .75656 .61395 L p .707 .577 .707 r
F P
0 g
s
.75656 .61395 m .73704 .56009 L .7662 .55069 L p .707 .577 .707 r
F P
0 g
s
.43661 .7145 m .4321 .73195 L .45571 .72978 L p .707 .577 .707 r
F P
0 g
s
.45571 .72978 m .46023 .71234 L .43661 .7145 L p .707 .577 .707 r
F P
0 g
s
.64759 .69376 m .65211 .67632 L .67572 .67416 L p .707 .577 .707 r
F P
0 g
s
.70703 .57105 m .72654 .62491 L .6986 .63638 L p .707 .577 .707 r
F P
0 g
s
.81232 .71705 m .80781 .73449 L .78761 .72119 L p .707 .577 .707 r
F P
0 g
s
.78761 .72119 m .79212 .70375 L .81232 .71705 L p .707 .577 .707 r
F P
0 g
s
.30001 .67162 m .2955 .68906 L .31569 .70236 L p .707 .577 .707 r
F P
0 g
s
.31461 .67743 m .31067 .64018 L .2982 .63471 L p .707 .577 .707 r
F P
0 g
s
.72654 .62491 m .70703 .57105 L .73704 .56009 L p .707 .577 .707 r
F P
0 g
s
.73704 .56009 m .75656 .61395 L .72654 .62491 L p .707 .577 .707 r
F P
0 g
s
.67572 .67416 m .67121 .6916 L .64759 .69376 L p .707 .577 .707 r
F P
0 g
s
.68976 .6739 m .68582 .63665 L .71508 .63085 L p .707 .577 .707 r
F P
0 g
s
.77774 .62556 m .78168 .66281 L .75069 .66428 L p .707 .577 .707 r
F P
0 g
s
.75069 .66428 m .74675 .62703 L .77774 .62556 L p .707 .577 .707 r
F P
0 g
s
.2982 .63471 m .30214 .67196 L .31461 .67743 L p .707 .577 .707 r
F P
0 g
s
.49107 .61841 m .49501 .65566 L .50213 .64783 L p .707 .577 .707 r
F P
0 g
s
.50213 .64783 m .49819 .61058 L .49107 .61841 L p .707 .577 .707 r
F P
0 g
s
.71508 .63085 m .71902 .66811 L .68976 .6739 L p .707 .577 .707 r
F P
0 g
s
.2955 .68906 m .30001 .67162 L .2881 .6583 L p .707 .577 .707 r
F P
0 g
s
.71902 .66811 m .71508 .63085 L .74675 .62703 L p .707 .577 .707 r
F P
0 g
s
.31098 .6275 m .29147 .57365 L .28949 .57029 L p .707 .577 .707 r
F P
0 g
s
.46023 .71234 m .45571 .72978 L .47193 .72362 L p .707 .577 .707 r
F P
0 g
s
.47193 .72362 m .47644 .70618 L .46023 .71234 L p .707 .577 .707 r
F P
0 g
s
.74675 .62703 m .75069 .66428 L .71902 .66811 L p .707 .577 .707 r
F P
0 g
s
.67121 .6916 m .67572 .67416 L .70442 .67621 L p .707 .577 .707 r
F P
0 g
s
.79212 .70375 m .78761 .72119 L .7611 .70921 L p .707 .577 .707 r
F P
0 g
s
.7611 .70921 m .76562 .69177 L .79212 .70375 L p .707 .577 .707 r
F P
0 g
s
.481 .50441 m .50051 .55826 L .49854 .55491 L p .707 .577 .707 r
F P
0 g
s
.49854 .55491 m .47903 .50105 L .481 .50441 L p .707 .577 .707 r
F P
0 g
s
.2881 .6583 m .28359 .67574 L .2955 .68906 L p .707 .577 .707 r
F P
0 g
s
.28949 .57029 m .30901 .62415 L .31098 .6275 L p .707 .577 .707 r
F P
0 g
s
.70442 .67621 m .69991 .69365 L .67121 .6916 L p .707 .577 .707 r
F P
0 g
s
.30214 .67196 m .2982 .63471 L .29539 .62772 L p .707 .577 .707 r
F P
0 g
s
.69991 .69365 m .70442 .67621 L .7354 .68228 L p .707 .577 .707 r
F P
0 g
s
.76562 .69177 m .7611 .70921 L .73088 .69972 L p .707 .577 .707 r
F P
0 g
s
.73088 .69972 m .7354 .68228 L .76562 .69177 L p .707 .577 .707 r
F P
0 g
s
.7354 .68228 m .73088 .69972 L .69991 .69365 L p .707 .577 .707 r
F P
0 g
s
.29539 .62772 m .29933 .66497 L .30214 .67196 L p .707 .577 .707 r
F P
0 g
s
.28359 .67574 m .2881 .6583 L .28564 .64627 L p .707 .577 .707 r
F P
0 g
s
.49819 .61058 m .50213 .64783 L .49931 .64084 L p .707 .577 .707 r
F P
0 g
s
.49931 .64084 m .49537 .60359 L .49819 .61058 L p .707 .577 .707 r
F P
0 g
s
.47644 .70618 m .47193 .72362 L .47916 .71405 L p .707 .577 .707 r
F P
0 g
s
.47916 .71405 m .48368 .69661 L .47644 .70618 L p .707 .577 .707 r
F P
0 g
s
.28564 .64627 m .28113 .66371 L .28359 .67574 L p .707 .577 .707 r
F P
0 g
s
.30901 .62415 m .28949 .57029 L .2969 .56372 L p .707 .577 .707 r
F P
0 g
s
.47903 .50105 m .49854 .55491 L .48739 .55512 L p .707 .577 .707 r
F P
0 g
s
.48739 .55512 m .46788 .50126 L .47903 .50105 L p .707 .577 .707 r
F P
0 g
s
.2969 .56372 m .31641 .61758 L .30901 .62415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29933 .66497 m .29539 .62772 L .3025 .61989 L p .707 .577 .707 r
F P
0 g
s
.3025 .61989 m .30644 .65714 L .29933 .66497 L p .707 .577 .707 r
F P
0 g
s
.28113 .66371 m .28564 .64627 L .29288 .6367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48368 .69661 m .47916 .71405 L .47671 .70202 L p .707 .577 .707 r
F P
0 g
s
.47671 .70202 m .48122 .68458 L .48368 .69661 L p .707 .577 .707 r
F P
0 g
s
.49537 .60359 m .49931 .64084 L .48685 .63537 L p .707 .577 .707 r
F P
0 g
s
.48685 .63537 m .48291 .59812 L .49537 .60359 L p .707 .577 .707 r
F P
0 g
s
.29288 .6367 m .28836 .65414 L .28113 .66371 L p .707 .577 .707 r
F P
0 g
s
.31641 .61758 m .2969 .56372 L .31295 .55456 L p .707 .577 .707 r
F P
0 g
s
.46788 .50126 m .48739 .55512 L .46815 .55885 L p .707 .577 .707 r
F P
0 g
s
.46815 .55885 m .44864 .50499 L .46788 .50126 L p .707 .577 .707 r
F P
0 g
s
.31295 .55456 m .33246 .60842 L .31641 .61758 L p .707 .577 .707 r
F P
0 g
s
.30644 .65714 m .3025 .61989 L .31884 .61198 L p .707 .577 .707 r
F P
0 g
s
.28836 .65414 m .29288 .6367 L .30909 .63054 L p .707 .577 .707 r
F P
0 g
s
.31884 .61198 m .32278 .64923 L .30644 .65714 L p .707 .577 .707 r
F P
0 g
s
.48122 .68458 m .47671 .70202 L .46479 .6887 L p .707 .577 .707 r
F P
0 g
s
.46479 .6887 m .46931 .67126 L .48122 .68458 L p .707 .577 .707 r
F P
0 g
s
.48291 .59812 m .48685 .63537 L .46595 .63196 L p .707 .577 .707 r
F P
0 g
s
.46595 .63196 m .46201 .59471 L .48291 .59812 L p .707 .577 .707 r
F P
0 g
s
.33246 .60842 m .31295 .55456 L .33607 .54372 L p .707 .577 .707 r
F P
0 g
s
.30909 .63054 m .30458 .64798 L .28836 .65414 L p .707 .577 .707 r
F P
0 g
s
.44864 .50499 m .46815 .55885 L .44271 .56575 L p .707 .577 .707 r
F P
0 g
s
.44271 .56575 m .42319 .51189 L .44864 .50499 L p .707 .577 .707 r
F P
0 g
s
.33607 .54372 m .35559 .59758 L .33246 .60842 L p .707 .577 .707 r
F P
0 g
s
.32278 .64923 m .31884 .61198 L .34281 .60478 L p .707 .577 .707 r
F P
0 g
s
.35559 .59758 m .33607 .54372 L .36401 .53226 L p .707 .577 .707 r
F P
0 g
s
.42319 .51189 m .44271 .56575 L .41355 .57515 L p .707 .577 .707 r
F P
0 g
s
.41355 .57515 m .39403 .52129 L .42319 .51189 L p .707 .577 .707 r
F P
0 g
s
.34281 .60478 m .34675 .64203 L .32278 .64923 L p .707 .577 .707 r
F P
0 g
s
.46201 .59471 m .46595 .63196 L .43867 .63094 L p .707 .577 .707 r
F P
0 g
s
.43867 .63094 m .43473 .59369 L .46201 .59471 L p .707 .577 .707 r
F P
0 g
s
.30458 .64798 m .30909 .63054 L .33271 .62837 L p .707 .577 .707 r
F P
0 g
s
.46931 .67126 m .46479 .6887 L .4446 .67541 L p .707 .577 .707 r
F P
0 g
s
.4446 .67541 m .44911 .65796 L .46931 .67126 L p .707 .577 .707 r
F P
0 g
s
.36401 .53226 m .38353 .58611 L .35559 .59758 L p .707 .577 .707 r
F P
0 g
s
.33271 .62837 m .3282 .64582 L .30458 .64798 L p .707 .577 .707 r
F P
0 g
s
.38353 .58611 m .36401 .53226 L .39403 .52129 L p .707 .577 .707 r
F P
0 g
s
.39403 .52129 m .41355 .57515 L .38353 .58611 L p .707 .577 .707 r
F P
0 g
s
.34675 .64203 m .34281 .60478 L .37207 .59899 L p .707 .577 .707 r
F P
0 g
s
.43473 .59369 m .43867 .63094 L .40768 .63242 L p .707 .577 .707 r
F P
0 g
s
.40768 .63242 m .40374 .59517 L .43473 .59369 L p .707 .577 .707 r
F P
0 g
s
.37207 .59899 m .376 .63624 L .34675 .64203 L p .707 .577 .707 r
F P
0 g
s
.3282 .64582 m .33271 .62837 L .36141 .63043 L p .707 .577 .707 r
F P
0 g
s
.376 .63624 m .37207 .59899 L .40374 .59517 L p .707 .577 .707 r
F P
0 g
s
.44911 .65796 m .4446 .67541 L .41809 .66343 L p .707 .577 .707 r
F P
0 g
s
.41809 .66343 m .42261 .64598 L .44911 .65796 L p .707 .577 .707 r
F P
0 g
s
.40374 .59517 m .40768 .63242 L .376 .63624 L p .707 .577 .707 r
F P
0 g
s
.36141 .63043 m .3569 .64787 L .3282 .64582 L p .707 .577 .707 r
F P
0 g
s
.3569 .64787 m .36141 .63043 L .39239 .6365 L p .707 .577 .707 r
F P
0 g
s
.42261 .64598 m .41809 .66343 L .38787 .65394 L p .707 .577 .707 r
F P
0 g
s
.38787 .65394 m .39239 .6365 L .42261 .64598 L p .707 .577 .707 r
F P
0 g
s
.39239 .6365 m .38787 .65394 L .3569 .64787 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo0024Ool60003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001fOol007ioo`H000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@0079oo`00N7oo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000KWoo001bOol60008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH2001/Ool006ioo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJ
EP8006Yoo`00JWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH02eYF00<007ooOol0J7oo001XOol200000eYF001JEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH2001YOol006Io
o`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00YJEP8006Uoo`00I7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02UYF0P00JGoo001SOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1WOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1WOol0065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0
065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH20003FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP02
001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF008006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYF001JEP02001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEP00FUH00P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF008006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYFFUH005YFIGoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Hgoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF1`002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH00UYF100045YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF1@0000=JEP00FUH0
15YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00AJEP<000IJEP03001JEUYF009J
EP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00
FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06=oo`00IWoo00@005YFFUH000EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEP00FUH005YF06Aoo`00IWoo00@005YFFUH0009JEP<00003FUH005YF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH200001EYF001JEP00FUH0I7oo001VOol00`00FUIJEP030005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF001JEP00FUITOol006Ioo`<000QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00Oomoo`1ROol006Aoo`800003FUH005YF00QJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001oogoo069oo`00HGoo0`0015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
02Uoo`H003=oo`00GWoo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo02Eoo`@0009JEP05001JEUYFFUH0000bOol005aoo`800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo025oo`@00003FUH005YF00AJEP04001JEUYF000bOol005Yoo`8000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000NOol40006FUH0
0`00FUIJEP02FUH00`00FUIJEP02000aOol005Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001aoo`800003FUH005YF00MJEP03001JEUYF00=J
EP04001JEUYF000aOol005Moo`8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000IOol30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo001EOol20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000FOol30007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIJEP02000`Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`<00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP04
001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000@Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<7oo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000P001EYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P003Goo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH002moo`00DWoo00@005YFFUH000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000QJEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8000=JEP8000]oo`800003FUH005YF00UJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool0059oo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF009J
EP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20009Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00Aoo`<000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`04001JEUYF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP05FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`02Ool200000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo001DOol00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`020004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo001DOol01000FUIJEP0015YF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH0
1EYF200025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUIJEPH002eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00IJEP8000MJEPT000AJ
EP04001JEUYFFUH70002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1@000UYF00@005YFFUH002eoo`00Dgoo0`0000=JEP00FUH015YF00<005YFFUH00eYF
0P0000=JEP0000001P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00=J
EP8002ioo`00D7oo0`000UYF00@005YFFUH000AJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool004ioo`800003FUH0
05YF009JEP04001JEUYF0005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00<005YFFUH01EYF00D005YFFUIJEP00031oo`00Bgoo0`0015YF00L005YFFUIJ
EP00FUH00003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YF00000P0015YF00<005YFFUH01UYF0`00<Goo0018Ool30007FUH01@00FUIJEUYF00000UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000QJEP03001JEUYF00AJ
EP8003=oo`00AGoo0`0000=JEP00FUH01eYF00@005YFFUIJEP<00003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000eOol0049oo`<000EJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF00IJEP04001JEP00000g
Ool003moo`<000QJEP03001JEUYF00IJEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40008FUH;000iOol003eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPT000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH90004FUH01000FUIJEUYF1P00=Woo
000jOol30004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP050003FUH01000FUIJEUYF
1`0000=JEP00FUH00eYF60000eYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00D0035oo`00=goo0`001eYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH02P002EYF1P0015YF1@000UYF
0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YF00000P00;Woo000eOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH?0004FUH00`00FUIJ
EP04FUH01000FUIJEUYF10001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0035oo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000=J
EP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH500001EYF000005YF00000UYF2@0015YF00<005YFFUH01eYF0`00
1EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002io
o`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00800003FUH0
0000009JEP04001JEP000003FUH00`00FUIJEP05FUH01000FUIJEUYF1P001eYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00<00004FUH0
05YFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH00eYF
0P000UYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUH00006FUH0
1000FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00:goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP800003FUH0000000800005FUH005YFFUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20008FUH30005FUH3000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000[Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF0P001UYF00<005YFFUH01@000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH015YF2@002Woo1@001EYF10000eYF0P00;7oo000[Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0`000eYF00<005YF
FUH00eYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001Goo3P000eYF00<005YFFUH015YF00@0
05YFFUIJEP800003FUH0000002aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008000EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP80009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH;0004
Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000/Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH20008FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70002FUH20006FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP050003
FUH01000FUIJEUYF200015YF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF
0`00;7oo000]Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH01000FUIJEP0015YF0P0000=oo`0000005P002EYF00@005YF000000=JEP06001JEUYF001JEP00
35YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH0100000=JEP0000000P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000;7oo000]Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01eYF0`001UYF00<007ooOol037oo00<005YFFUH01`002EYF00@005YF
FUIJEP800003FUH005YF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00;Goo00@005YFFUH000AJEP03001JEUYF00IJ
EP04001JEP000005FUH>0006FUH4000;Ool00`00FUIJEP070009FUH00`00FUIJEP03FUH20003FUH0
0`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH300000eYF
000000040004FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF1P001Woo00<005YFFUH01`002EYF
00<005YFFUH01EYF00H005YFFUH005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJ
EUYF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP04FUH01000FUH00000<7oo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF1P0000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP<00003FUH0000000Ao
o`05001JEUYF001JEP0300000eYF001JEP09FUH00`00FUIJEP04FUH01000FUH005YF0P002eYF00<0
05YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP8000=JEPD000=JEP03001JEUYF00T000AJEP03
001JEUYF00MJEP<000IJEP03001JEUYF00=JEP<0039oo`00;Woo00@005YFFUH000EJEP03001JEP00
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH40004Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00@005YFFUIJEP800004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP060008FUH00`00FUIJEP020004FUH00`00FUH00003000eOol002moo`03001JEP0000=J
EP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00@00005Ool005YFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00D005YFFUH005YF00800003FUH00000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP800004
FUH00000000iOol002moo`04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH200000eYF0000000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP020003
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0300000eYF001J
EP06FUH2000kOol002moo`03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00MJEP03001JEP0000<000=JEP03001JEUYF
00MJEP03001JEUYF00=JEP800005FUH00000FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
1000FUIJEP0015YF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0025YF0`00>Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP04FUH70006FUH0
0`00FUH000030003FUH200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJ
EP0015YF00<005YFFUH00UYF6`000goo0P001EYF00@005YFFUIJEP8003Moo`00;Goo0`000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`001eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUH000AJEP03001JEUYF009JEP8001Ao
o`<000Moo`8000=JEP03001JEUYF00=JEP03001oogoo03Aoo`00;7oo00@005YFFUH000=JEPT000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5000@Ool50008Ool3
0006FUH2000eOol002aoo`03001JEUYF00D000=JEP04001JEUYFFUH700000eYF001JEP07FUH00`00
FUIJEP02FUH?0003FUH00`00FUIJEP060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF1@002goo1@002Woo00<005YFFUH015YF00<005YF0000=7oo000/Ool00`00
FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH90004Ool60004FUH50002FUH20003
Ool00eYF000000020002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001EYF
00<005YF00000P0027oo1@002goo0P000eYF00D005YFFUIJEP0003=oo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1P000Woo1`0015YF00<005YFFUH015YF00@005YF
FUIJEP@000=oo`05001JEUYF001JEP060004FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00D005YFFUIJ
EP0000Uoo`<000ioo`800003FUH005YF00=JEP03001oogoo031oo`00:goo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF0`000goo00@005YFFUH000EJEP03001JEP0000P000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00YJEP<000AJEP04001JEUYFFUH2000KOol2
0004FUH00`00Oomoo`0`Ool002Yoo`8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH00P000UYF00@005YFFUIJEP8001eoo`03001JEUYF0080039oo`00:Woo
0P000UYF1@0000EJEP00001JEP00009JEPL000IJEP03001JEUYF00MJEP<000EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP03
FUH30003FUH2000MOol00`00FUIJEP02000bOol002Uoo`800003FUH00000009JEP04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0P0017oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF015JEP<00003FUH0
000001ioo`800003FUH007oo035oo`00:Goo0`0000Aoo`00FUIJEP<000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP@000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP05001JEUYFFUH00005
Ool01000FUIJEP0045YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH04UYF00<005YF00000`007Woo00<005YF0000<Woo000XOol30003Ool01000FUH0
00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<0
05YF00001UYF00@005YF000000Ioo`04001JEUYF000@FUH00`00FUIJEP09FUH00`00FUIJEP04FUHN
000<FUH00`00FUIJEP04FUH00`00FUIJEP04FUH5000IOol00`00FUH0000bOol002Qoo`04001JEP00
0002Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0008FUH30005FUH30008Ool01000FUIJEP0045YF00<005YFFUH01eYF2@002UYF0P002eYF00<005YF
FUH01EYF0P002UYF0P0015YF00<005YFFUH01UYF00<005YFFUH010004goo1000<goo000XOol01`00
FUH005YF001oo`0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00EJEP8000IJEP03001JEUYF00D000]oo`04001JEUYF000@FUH01000FUIJEUYF1P0025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00H005YF000005YF0009
FUH00`00FUIJEP04FUH60008Ool50002FUH2000cOol002Qoo`03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF009J
EP8000eoo`03001JEUYF011JEPD00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH01000
FUIJEUYF20000eYF00H005YFFUH005YF000cOol002Uoo`03001JEUYF009JEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00EJEP03001oogoo00Yoo`03001JEUYF00eJEP<000IJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
0003FUH005YF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP04001JEUYF
FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000dOol0
02Uoo`03001JEUYF009JEPL000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL0
009oo`8000IJEP8000]oo`03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001JEUYF00EJEP04
001JEUYFFUH70005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=Goo000ZOol01@00FUIJEUYF0000
0UYF0P000Woo1`0015YF00<005YFFUH00UYF20002goo0P0015YF00<005YF00002goo2EYF0P000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01000
00=JEP00FUH025YF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YF000017oo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000003Ioo`00:goo00<005YF00001EYF0P001goo
2@000Woo1@003Woo00@005YFFUH000=JEP03001oogoo00Qoo`MJEP8000AJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF009JEP8000Uoo`H000AJEP04001JEUYFFUH5000h
Ool002aoo`8000IJEP<0011oo`D000moo`<000=JEP03001oogoo00Qoo`EJEP8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH2000@Ool8000mOol002eoo`03001J
EUYF00=JEP04001JEUYFFUH2000>Ool5000AOol01@00FUIJEUYF00002Woo0eYF0P0025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH00eYF100015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF0P001EYF00@005YF000005Moo`00;Woo0P000eYF00<005YFFUH00eYF0P003Goo
0`004goo00D005YF001JEP0000Uoo`9JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00MJEPL000QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000AJEP<005Uoo`00<7oo
0`0025YF0P008Woo0P0000=JEP00Ool027oo00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00@005YFFUIJEP@0009JEP03001JEP0000UJEP03001J
EUYF00=JEP800003FUH00000008005aoo`00<Woo00<005YFFUH01UYF00<005YF00000P0087oo00<0
05YF00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1@002EYF00@005YFFUIJEPD0061oo`00<goo0P001UYF00<005YFFUH00UYF
0`0077oo0P0000=JEP00Ool027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00D005YF000005YF0080069oo`00=Goo0P00
0eYF00<005YFFUH01UYF1@005Goo0P0000=JEP0000002goo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0`0015YF0P00HGoo000gOol200000eYF001JEP07FUH00`00FUIJEP02FUH90008Ool40003FUH2000;
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP02001OOol003Uoo`<000MJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP07001JEUYFFUH005YF00003Goo0P0000=JEP00FUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`0017oo
0P000eYF00<005YFFUH00UYF00<007ooOol0G7oo000lOol40002FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0047oo0`001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1@002Goo0`001UYF00<007ooOol0Fgoo0010Ool50006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0057oo10000UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P0000=oo`0000000`002Woo00<005YFFUH0
15YF0P00G7oo0015Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000006Woo2000
1EYF00<005YFFUH02UYF00<005YFFUH015YF2@001goo1@002goo0P0015YF00@005YF000005Yoo`00
BGoo1P0015YF00@005YFFUIJEPD002AooaT0011oo`D000eoo`04001JEUYF0004FUH00`00Oomoo`1G
Ool004moo`P003Ioo`8000IJEP<0019oo`<000moo`<000AJEP03001oogoo05Moo`00SWoo00<005YF
FUH015YF00<005YFFUH00P0097oo00@005YFFUIJEP8005Uoo`00Sgoo0P000eYF00<005YFFUH00eYF
0P008goo00<005YFFUH00P00FGoo002AOol200000eYF001JEP06FUH3000QOol200000eYF001oo`1H
Ool009=oo`8000QJEP04001JEP00000POol00`00FUH0001IOol009Eoo`8000EJEP03001JEUYF009J
EP<001eoo`03001JEP0005Uoo`00Ugoo0P000eYF00<005YFFUH01EYF1P005Goo1000FWoo002IOol3
0009FUH00`00FUIJEP02FUH80008Ool50002FUH2001JOol009]oo`<000IJEP03001JEUYF00MJEP04
001JEUYFFUH80003FUH01P00FUIJEP00FUH005Yoo`00WWoo10000UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P00Fgoo002ROol50006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000G7oo002WOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH00000GGoo002[Ool60004FUH01000FUIJEUYF1@00Ggoo002aOol8001TOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60018 .74286 m .58794 .68744 L .55754 .69256 L p .707 .577 .707 r
F P
0 g
s
.58794 .68744 m .60018 .74286 L .63131 .73574 L p .707 .577 .707 r
F P
0 g
s
.63131 .73574 m .61908 .68032 L .58794 .68744 L p .707 .577 .707 r
F P
0 g
s
.61908 .68032 m .63131 .73574 L .66014 .72733 L p .707 .577 .707 r
F P
0 g
s
.66014 .72733 m .64791 .67191 L .61908 .68032 L p .707 .577 .707 r
F P
0 g
s
.56978 .74799 m .55754 .69256 L .53086 .6952 L p .707 .577 .707 r
F P
0 g
s
.55754 .69256 m .56978 .74799 L .60018 .74286 L p .707 .577 .707 r
F P
0 g
s
.64791 .67191 m .66014 .72733 L .68384 .71845 L p .707 .577 .707 r
F P
0 g
s
.68384 .71845 m .6716 .66302 L .64791 .67191 L p .707 .577 .707 r
F P
0 g
s
.53086 .6952 m .5431 .75063 L .56978 .74799 L p .707 .577 .707 r
F P
0 g
s
.5983 .80644 m .59587 .76921 L .56476 .7694 L p .707 .577 .707 r
F P
0 g
s
.59587 .76921 m .5983 .80644 L .63008 .80379 L p .707 .577 .707 r
F P
0 g
s
.63008 .80379 m .62764 .76656 L .59587 .76921 L p .707 .577 .707 r
F P
0 g
s
.62764 .76656 m .63008 .80379 L .65941 .79892 L p .707 .577 .707 r
F P
0 g
s
.65941 .79892 m .65697 .76169 L .62764 .76656 L p .707 .577 .707 r
F P
0 g
s
.5431 .75063 m .53086 .6952 L .5105 .69509 L p .707 .577 .707 r
F P
0 g
s
.5672 .80663 m .56476 .7694 L .53737 .76709 L p .707 .577 .707 r
F P
0 g
s
.56476 .7694 m .5672 .80663 L .5983 .80644 L p .707 .577 .707 r
F P
0 g
s
.6716 .66302 m .68384 .71845 L .70008 .70997 L p .707 .577 .707 r
F P
0 g
s
.70008 .70997 m .68785 .65454 L .6716 .66302 L p .707 .577 .707 r
F P
0 g
s
.65697 .76169 m .65941 .79892 L .68343 .79231 L p .707 .577 .707 r
F P
0 g
s
.68343 .79231 m .681 .75508 L .65697 .76169 L p .707 .577 .707 r
F P
0 g
s
.53737 .76709 m .53981 .80432 L .5672 .80663 L p .707 .577 .707 r
F P
0 g
s
.5105 .69509 m .52274 .75052 L .5431 .75063 L p .707 .577 .707 r
F P
0 g
s
.58528 .85797 m .58809 .83997 L .55728 .83333 L p .707 .577 .707 r
F P
0 g
s
.58809 .83997 m .58528 .85797 L .61678 .86147 L p .707 .577 .707 r
F P
0 g
s
.61678 .86147 m .61959 .84348 L .58809 .83997 L p .707 .577 .707 r
F P
0 g
s
.53981 .80432 m .53737 .76709 L .51638 .76251 L p .707 .577 .707 r
F P
0 g
s
.61959 .84348 m .61678 .86147 L .6459 .86149 L p .707 .577 .707 r
F P
0 g
s
.6459 .86149 m .64871 .8435 L .61959 .84348 L p .707 .577 .707 r
F P
0 g
s
.55447 .85132 m .55728 .83333 L .53019 .82419 L p .707 .577 .707 r
F P
0 g
s
.55728 .83333 m .55447 .85132 L .58528 .85797 L p .707 .577 .707 r
F P
0 g
s
.52274 .75052 m .5105 .69509 L .49847 .69224 L p .707 .577 .707 r
F P
0 g
s
.51638 .76251 m .51882 .79974 L .53981 .80432 L p .707 .577 .707 r
F P
0 g
s
.681 .75508 m .68343 .79231 L .69979 .78461 L p .707 .577 .707 r
F P
0 g
s
.69979 .78461 m .69735 .74738 L .681 .75508 L p .707 .577 .707 r
F P
0 g
s
.53019 .82419 m .52738 .84218 L .55447 .85132 L p .707 .577 .707 r
F P
0 g
s
.68785 .65454 m .70008 .70997 L .70729 .70272 L p .707 .577 .707 r
F P
0 g
s
.70729 .70272 m .69505 .64729 L .68785 .65454 L p .707 .577 .707 r
F P
0 g
s
.64871 .8435 m .6459 .86149 L .66979 .85802 L p .707 .577 .707 r
F P
0 g
s
.66979 .85802 m .6726 .84003 L .64871 .8435 L p .707 .577 .707 r
F P
0 g
s
.49847 .69224 m .5107 .74766 L .52274 .75052 L p .707 .577 .707 r
F P
0 g
s
.52738 .84218 m .53019 .82419 L .50946 .81345 L p .707 .577 .707 r
F P
0 g
s
.51882 .79974 m .51638 .76251 L .50384 .75612 L p .707 .577 .707 r
F P
0 g
s
.50946 .81345 m .50665 .83145 L .52738 .84218 L p .707 .577 .707 r
F P
0 g
s
.50384 .75612 m .50627 .79335 L .51882 .79974 L p .707 .577 .707 r
F P
0 g
s
.69735 .74738 m .69979 .78461 L .70689 .77658 L p .707 .577 .707 r
F P
0 g
s
.70689 .77658 m .70445 .73935 L .69735 .74738 L p .707 .577 .707 r
F P
0 g
s
.5107 .74766 m .49847 .69224 L .49593 .68693 L p .707 .577 .707 r
F P
0 g
s
.6726 .84003 m .66979 .85802 L .6861 .85141 L p .707 .577 .707 r
F P
0 g
s
.6861 .85141 m .68891 .83341 L .6726 .84003 L p .707 .577 .707 r
F P
0 g
s
.50665 .83145 m .50946 .81345 L .49713 .80217 L p .707 .577 .707 r
F P
0 g
s
.69505 .64729 m .70729 .70272 L .70475 .69741 L p .707 .577 .707 r
F P
0 g
s
.70475 .69741 m .69251 .64198 L .69505 .64729 L p .707 .577 .707 r
F P
0 g
s
.49713 .80217 m .49432 .82017 L .50665 .83145 L p .707 .577 .707 r
F P
0 g
s
.49593 .68693 m .50816 .74235 L .5107 .74766 L p .707 .577 .707 r
F P
0 g
s
.50627 .79335 m .50384 .75612 L .50097 .74854 L p .707 .577 .707 r
F P
0 g
s
.50097 .74854 m .50341 .78577 L .50627 .79335 L p .707 .577 .707 r
F P
0 g
s
.50816 .74235 m .49593 .68693 L .50313 .67968 L p .707 .577 .707 r
F P
0 g
s
.50313 .67968 m .51537 .7351 L .50816 .74235 L p .707 .577 .707 r
F P
0 g
s
.50341 .78577 m .50097 .74854 L .50806 .7405 L p .707 .577 .707 r
F P
0 g
s
.50806 .7405 m .5105 .77773 L .50341 .78577 L p .707 .577 .707 r
F P
0 g
s
.49432 .82017 m .49713 .80217 L .4944 .79145 L p .707 .577 .707 r
F P
0 g
s
.4944 .79145 m .49159 .80944 L .49432 .82017 L p .707 .577 .707 r
F P
0 g
s
.49159 .80944 m .4944 .79145 L .50154 .78233 L p .707 .577 .707 r
F P
0 g
s
.50154 .78233 m .49873 .80033 L .49159 .80944 L p .707 .577 .707 r
F P
0 g
s
.49873 .80033 m .50154 .78233 L .51785 .77572 L p .707 .577 .707 r
F P
0 g
s
.51785 .77572 m .51504 .79371 L .49873 .80033 L p .707 .577 .707 r
F P
0 g
s
.5057 .82114 m .48264 .31735 L .43868 .31672 L p .707 .577 .707 r
F P
0 g
s
.51537 .7351 m .50313 .67968 L .51938 .67119 L p .707 .577 .707 r
F P
0 g
s
.51938 .67119 m .53161 .72662 L .51537 .7351 L p .707 .577 .707 r
F P
0 g
s
.5105 .77773 m .50806 .7405 L .52442 .7328 L p .707 .577 .707 r
F P
0 g
s
.52442 .7328 m .52686 .77003 L .5105 .77773 L p .707 .577 .707 r
F P
0 g
s
.53161 .72662 m .51938 .67119 L .54307 .66231 L p .707 .577 .707 r
F P
0 g
s
.54307 .66231 m .55531 .71774 L .53161 .72662 L p .707 .577 .707 r
F P
0 g
s
.52686 .77003 m .52442 .7328 L .54844 .7262 L p .707 .577 .707 r
F P
0 g
s
.54844 .7262 m .55088 .76343 L .52686 .77003 L p .707 .577 .707 r
F P
0 g
s
.51504 .79371 m .51785 .77572 L .54174 .77225 L p .707 .577 .707 r
F P
0 g
s
.54174 .77225 m .53893 .79024 L .51504 .79371 L p .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .54174 .77225 L .55695 .77226 L p .707 .577 .707 r
F P
0 g
s
.55695 .77226 m .57086 .77227 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .55695 .77226 L .55233 .7827 L .707 .577 .707 r
F
.48264 .31735 m .5057 .82114 L .53622 .81914 L p F P
0 g
s
.53622 .81914 m .5506 .8182 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.5506 .8182 m .54929 .78957 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.60236 .77577 m .59956 .79377 L .56913 .79038 L p .707 .577 .707 r
F P
0 g
s
.56896 .78988 m .60236 .77577 L .56913 .79038 L .707 .577 .707 r
F
.54929 .78957 m .5506 .8182 L p .57244 .80016 L F P
0 g
s
.57086 .77227 m .60236 .77577 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .57086 .77227 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.58877 .78667 m .56838 .78817 L .57244 .80016 L .707 .577 .707 r
F
.56838 .78817 m .54929 .78957 L .57244 .80016 L F
.56805 .79026 m .56838 .78817 L p .56896 .78988 L F P
0 g
s
.56913 .79038 m .56805 .79026 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .58877 .78667 L .57244 .80016 L .707 .577 .707 r
F
.5506 .8182 m .5772 .81419 L p .57244 .80016 L F P
0 g
s
.5772 .81419 m .59205 .81196 L p .57244 .80016 L .707 .577 .707 r
F P
0 g
s
.57086 .77227 m .56838 .78817 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.54899 .79025 m .53893 .79024 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.55233 .7827 m .57086 .77227 L .54899 .79025 L .707 .577 .707 r
F
.55531 .71774 m .54307 .66231 L .56716 .65528 L p F P
0 g
s
.56716 .65528 m .5719 .6539 L p .57005 .66102 L .707 .577 .707 r
F P
0 g
s
.55531 .71774 m .56716 .65528 L .57005 .66102 L .707 .577 .707 r
F
.54929 .78957 m .54075 .60279 L p .54732 .79402 L F P
0 g
s
.54075 .60279 m .52755 .3144 L p .53932 .59996 L .707 .577 .707 r
F P
0 g
s
.54075 .60279 m .53932 .59996 L .54732 .79402 L .707 .577 .707 r
F
.5719 .6539 m .58414 .70933 L .55531 .71774 L p F P
0 g
s
.55088 .76343 m .54844 .7262 L .57778 .72133 L p .707 .577 .707 r
F P
0 g
s
.57778 .72133 m .58022 .75856 L .55088 .76343 L p .707 .577 .707 r
F P
0 g
s
.58022 .75856 m .57778 .72133 L .60955 .71867 L p .707 .577 .707 r
F P
0 g
s
.60955 .71867 m .61199 .7559 L .58022 .75856 L p .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .54929 .78957 L p .58877 .78667 L .707 .577 .707 r
F P
0 g
s
.56805 .79026 m .54899 .79025 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .56805 .79026 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .48264 .31735 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.54732 .79402 m .48264 .31735 L .53622 .81914 L .707 .577 .707 r
F
.58414 .70933 m .5719 .6539 L .60304 .64678 L p F P
0 g
s
.60304 .64678 m .61527 .70221 L .58414 .70933 L p .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .56899 .30816 L .52755 .3144 L p .707 .577 .707 r
F P
0 g
s
.68891 .83341 m .6861 .85141 L .69324 .84229 L p .707 .577 .707 r
F P
0 g
s
.69324 .84229 m .69605 .8243 L .68891 .83341 L p .707 .577 .707 r
F P
0 g
s
.70445 .73935 m .70689 .77658 L .70402 .76899 L p .707 .577 .707 r
F P
0 g
s
.70402 .76899 m .70158 .73176 L .70445 .73935 L p .707 .577 .707 r
F P
0 g
s
.46174 .82051 m .43868 .31672 L .39997 .31257 L p .707 .577 .707 r
F P
0 g
s
.43868 .31672 m .46174 .82051 L .5057 .82114 L p .707 .577 .707 r
F P
0 g
s
.69251 .64198 m .70475 .69741 L .69271 .69456 L p .707 .577 .707 r
F P
0 g
s
.69271 .69456 m .68048 .63913 L .69251 .64198 L p .707 .577 .707 r
F P
0 g
s
.61527 .70221 m .60304 .64678 L .63344 .64165 L p .707 .577 .707 r
F P
0 g
s
.64066 .71849 m .64309 .75572 L .61199 .7559 L p .707 .577 .707 r
F P
0 g
s
.61199 .7559 m .60955 .71867 L .64066 .71849 L p .707 .577 .707 r
F P
0 g
s
.63317 .78242 m .63036 .80041 L .59956 .79377 L p .707 .577 .707 r
F P
0 g
s
.59956 .79377 m .60236 .77577 L .63317 .78242 L p .707 .577 .707 r
F P
0 g
s
.56899 .30816 m .59205 .81196 L .62599 .80304 L p .707 .577 .707 r
F P
0 g
s
.63344 .64165 m .64567 .69708 L .61527 .70221 L p .707 .577 .707 r
F P
0 g
s
.62599 .80304 m .60293 .29924 L .56899 .30816 L p .707 .577 .707 r
F P
0 g
s
.25717 .70482 m .24493 .6494 L .21454 .65452 L p .707 .577 .707 r
F P
0 g
s
.24493 .6494 m .25717 .70482 L .2883 .6977 L p .707 .577 .707 r
F P
0 g
s
.2883 .6977 m .27607 .64228 L .24493 .6494 L p .707 .577 .707 r
F P
0 g
s
.27607 .64228 m .2883 .6977 L .31713 .68929 L p .707 .577 .707 r
F P
0 g
s
.31713 .68929 m .3049 .63387 L .27607 .64228 L p .707 .577 .707 r
F P
0 g
s
.42302 .81636 m .39997 .31257 L .37028 .30531 L p .707 .577 .707 r
F P
0 g
s
.39997 .31257 m .42302 .81636 L .46174 .82051 L p .707 .577 .707 r
F P
0 g
s
.69605 .8243 m .69324 .84229 L .69051 .83157 L p .707 .577 .707 r
F P
0 g
s
.69051 .83157 m .69332 .81357 L .69605 .8243 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22677 .70995 m .21454 .65452 L .18785 .65716 L p .707 .577 .707 r
F P
0 g
s
.21454 .65452 m .22677 .70995 L .25717 .70482 L p .707 .577 .707 r
F P
0 g
s
.70158 .73176 m .70402 .76899 L .69148 .7626 L p .707 .577 .707 r
F P
0 g
s
.69148 .7626 m .68904 .72537 L .70158 .73176 L p .707 .577 .707 r
F P
0 g
s
.3049 .63387 m .31713 .68929 L .34083 .68041 L p .707 .577 .707 r
F P
0 g
s
.34083 .68041 m .32859 .62498 L .3049 .63387 L p .707 .577 .707 r
F P
0 g
s
.68048 .63913 m .69271 .69456 L .67235 .69444 L p .707 .577 .707 r
F P
0 g
s
.67235 .69444 m .66012 .63902 L .68048 .63913 L p .707 .577 .707 r
F P
0 g
s
.18785 .65716 m .20009 .71259 L .22677 .70995 L p .707 .577 .707 r
F P
0 g
s
.64567 .69708 m .63344 .64165 L .66012 .63902 L p .707 .577 .707 r
F P
0 g
s
.66805 .72079 m .67048 .75802 L .64309 .75572 L p .707 .577 .707 r
F P
0 g
s
.64309 .75572 m .64066 .71849 L .66805 .72079 L p .707 .577 .707 r
F P
0 g
s
.66027 .79156 m .65746 .80955 L .63036 .80041 L p .707 .577 .707 r
F P
0 g
s
.63036 .80041 m .63317 .78242 L .66027 .79156 L p .707 .577 .707 r
F P
0 g
s
.60293 .29924 m .62599 .80304 L .64909 .79231 L p .707 .577 .707 r
F P
0 g
s
.64909 .79231 m .62603 .28852 L .60293 .29924 L p .707 .577 .707 r
F P
0 g
s
.2553 .77269 m .25286 .73546 L .22175 .73564 L p .707 .577 .707 r
F P
0 g
s
.25286 .73546 m .2553 .77269 L .28707 .77003 L p .707 .577 .707 r
F P
0 g
s
.28707 .77003 m .28463 .7328 L .25286 .73546 L p .707 .577 .707 r
F P
0 g
s
.28463 .7328 m .28707 .77003 L .3164 .76516 L p .707 .577 .707 r
F P
0 g
s
.3164 .76516 m .31396 .72793 L .28463 .7328 L p .707 .577 .707 r
F P
0 g
s
.20009 .71259 m .18785 .65716 L .1675 .65705 L p .707 .577 .707 r
F P
0 g
s
.22419 .77287 m .22175 .73564 L .19436 .73333 L p .707 .577 .707 r
F P
0 g
s
.22175 .73564 m .22419 .77287 L .2553 .77269 L p .707 .577 .707 r
F P
0 g
s
.32859 .62498 m .34083 .68041 L .35707 .67193 L p .707 .577 .707 r
F P
0 g
s
.35707 .67193 m .34484 .6165 L .32859 .62498 L p .707 .577 .707 r
F P
0 g
s
.31396 .72793 m .3164 .76516 L .34042 .75855 L p .707 .577 .707 r
F P
0 g
s
.34042 .75855 m .33799 .72132 L .31396 .72793 L p .707 .577 .707 r
F P
0 g
s
.69332 .81357 m .69051 .83157 L .67818 .82029 L p .707 .577 .707 r
F P
0 g
s
.67818 .82029 m .68099 .80229 L .69332 .81357 L p .707 .577 .707 r
F P
0 g
s
.1675 .65705 m .17973 .71248 L .20009 .71259 L p .707 .577 .707 r
F P
0 g
s
.39334 .8091 m .37028 .30531 L .35254 .29565 L p .707 .577 .707 r
F P
0 g
s
.37028 .30531 m .39334 .8091 L .42302 .81636 L p .707 .577 .707 r
F P
0 g
s
.19436 .73333 m .1968 .77056 L .22419 .77287 L p .707 .577 .707 r
F P
0 g
s
.68904 .72537 m .69148 .7626 L .67048 .75802 L p .707 .577 .707 r
F P
0 g
s
.67048 .75802 m .66805 .72079 L .68904 .72537 L p .707 .577 .707 r
F P
0 g
s
.24227 .81561 m .24508 .79762 L .21427 .79097 L p .707 .577 .707 r
F P
0 g
s
.24508 .79762 m .24227 .81561 L .27377 .81912 L p .707 .577 .707 r
F P
0 g
s
.27377 .81912 m .27658 .80112 L .24508 .79762 L p .707 .577 .707 r
F P
0 g
s
.66012 .63902 m .67235 .69444 L .64567 .69708 L p .707 .577 .707 r
F P
0 g
s
.1968 .77056 m .19436 .73333 L .17337 .72876 L p .707 .577 .707 r
F P
0 g
s
.27658 .80112 m .27377 .81912 L .3029 .81913 L p .707 .577 .707 r
F P
0 g
s
.3029 .81913 m .3057 .80114 L .27658 .80112 L p .707 .577 .707 r
F P
0 g
s
.21146 .80897 m .21427 .79097 L .18718 .78183 L p .707 .577 .707 r
F P
0 g
s
.21427 .79097 m .21146 .80897 L .24227 .81561 L p .707 .577 .707 r
F P
0 g
s
.17973 .71248 m .1675 .65705 L .15546 .6542 L p .707 .577 .707 r
F P
0 g
s
.18718 .78183 m .18437 .79983 L .21146 .80897 L p .707 .577 .707 r
F P
0 g
s
.17337 .72876 m .17581 .76599 L .1968 .77056 L p .707 .577 .707 r
F P
0 g
s
.33799 .72132 m .34042 .75855 L .35678 .75085 L p .707 .577 .707 r
F P
0 g
s
.35678 .75085 m .35434 .71362 L .33799 .72132 L p .707 .577 .707 r
F P
0 g
s
.62603 .28852 m .64909 .79231 L .6591 .78083 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .63604 .27703 L .62603 .28852 L p .707 .577 .707 r
F P
0 g
s
.34484 .6165 m .35707 .67193 L .36428 .66468 L p .707 .577 .707 r
F P
0 g
s
.36428 .66468 m .35205 .60925 L .34484 .6165 L p .707 .577 .707 r
F P
0 g
s
.3057 .80114 m .3029 .81913 L .32678 .81567 L p .707 .577 .707 r
F P
0 g
s
.32678 .81567 m .32959 .79767 L .3057 .80114 L p .707 .577 .707 r
F P
0 g
s
.15546 .6542 m .16769 .70962 L .17973 .71248 L p .707 .577 .707 r
F P
0 g
s
.18437 .79983 m .18718 .78183 L .16645 .7711 L p .707 .577 .707 r
F P
0 g
s
.68099 .80229 m .67818 .82029 L .65746 .80955 L p .707 .577 .707 r
F P
0 g
s
.65746 .80955 m .66027 .79156 L .68099 .80229 L p .707 .577 .707 r
F P
0 g
s
.16645 .7711 m .16364 .78909 L .18437 .79983 L p .707 .577 .707 r
F P
0 g
s
.17581 .76599 m .17337 .72876 L .16083 .72236 L p .707 .577 .707 r
F P
0 g
s
.3756 .79944 m .35254 .29565 L .34847 .28453 L p .707 .577 .707 r
F P
0 g
s
.35254 .29565 m .3756 .79944 L .39334 .8091 L p .707 .577 .707 r
F P
0 g
s
.16083 .72236 m .16326 .75959 L .17581 .76599 L p .707 .577 .707 r
F P
0 g
s
.32959 .79767 m .32678 .81567 L .34309 .80905 L p .707 .577 .707 r
F P
0 g
s
.34309 .80905 m .3459 .79106 L .32959 .79767 L p .707 .577 .707 r
F P
0 g
s
.16769 .70962 m .15546 .6542 L .15292 .64889 L p .707 .577 .707 r
F P
0 g
s
.35434 .71362 m .35678 .75085 L .36388 .74282 L p .707 .577 .707 r
F P
0 g
s
.36388 .74282 m .36144 .70559 L .35434 .71362 L p .707 .577 .707 r
F P
0 g
s
.16364 .78909 m .16645 .7711 L .15412 .75982 L p .707 .577 .707 r
F P
0 g
s
.35205 .60925 m .36428 .66468 L .36174 .65937 L p .707 .577 .707 r
F P
0 g
s
.36174 .65937 m .34951 .60394 L .35205 .60925 L p .707 .577 .707 r
F P
0 g
s
.15412 .75982 m .15131 .77781 L .16364 .78909 L p .707 .577 .707 r
F P
0 g
s
.15292 .64889 m .16515 .70431 L .16769 .70962 L p .707 .577 .707 r
F P
0 g
s
.16326 .75959 m .16083 .72236 L .15796 .71478 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .65503 .76971 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64422 .45583 m .6591 .78083 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .63604 .27703 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.65503 .76971 m .64504 .55148 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64504 .55148 m .63197 .26592 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .65503 .76971 L .64867 .76625 L p .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64386 .73941 L .64456 .73978 L p .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .63651 .68782 L .64418 .73731 L .707 .577 .707 r
F
.63651 .68782 m .63197 .26592 L .64867 .76625 L F
.61423 .25626 m .63197 .26592 L p .63698 .73215 L F P
0 g
s
.64386 .73941 m .64287 .73637 L .63597 .73142 L .707 .577 .707 r
F
.61423 .25626 m .63597 .73142 L p .6076 .75279 L F P
0 g
s
.62778 .75772 m .6076 .75279 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63201 .72857 m .63579 .73203 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63579 .73203 m .64386 .73941 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .63728 .76005 L .62778 .75772 L p .707 .577 .707 r
F P
0 g
s
.63728 .76005 m .63597 .73142 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .61423 .25626 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63433 .71013 m .63152 .72813 L .63201 .72857 L p .707 .577 .707 r
F P
0 g
s
.64287 .73637 m .63433 .71013 L .63201 .72857 L .707 .577 .707 r
F
.64666 .72142 m .63433 .71013 L p .64287 .73637 L F P
0 g
s
.64386 .73941 m .64418 .73731 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64666 .72142 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64867 .76625 m .63728 .76005 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .64418 .73731 L .64867 .76625 L .707 .577 .707 r
F
.64666 .72142 m .64418 .73731 L p .66458 .75015 L F P
0 g
s
.64456 .73978 m .66458 .75015 L p .64418 .73731 L .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .65994 .65848 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.63567 .6002 m .64585 .64633 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.64585 .64633 m .64791 .65563 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64771 .60305 L .64548 .60252 L p .707 .577 .707 r
F P
0 g
s
.64548 .60252 m .63567 .6002 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64548 .60252 L .64566 .62419 L .707 .577 .707 r
F
.63604 .27703 m .64422 .45583 L p .64459 .4989 L F P
0 g
s
.15796 .71478 m .1604 .75201 L .16326 .75959 L p .707 .577 .707 r
F P
0 g
s
.3459 .79106 m .34309 .80905 L .35023 .79993 L p .707 .577 .707 r
F P
0 g
s
.35023 .79993 m .35304 .78194 L .3459 .79106 L p .707 .577 .707 r
F P
0 g
s
.15131 .77781 m .15412 .75982 L .15139 .74909 L p .707 .577 .707 r
F P
0 g
s
.36144 .70559 m .36388 .74282 L .36101 .73524 L p .707 .577 .707 r
F P
0 g
s
.36101 .73524 m .35857 .69801 L .36144 .70559 L p .707 .577 .707 r
F P
0 g
s
.16515 .70431 m .15292 .64889 L .16012 .64164 L p .707 .577 .707 r
F P
0 g
s
.15139 .74909 m .14858 .76709 L .15131 .77781 L p .707 .577 .707 r
F P
0 g
s
.34951 .60394 m .36174 .65937 L .3497 .65652 L p .707 .577 .707 r
F P
0 g
s
.3497 .65652 m .33747 .60109 L .34951 .60394 L p .707 .577 .707 r
F P
0 g
s
.34847 .28453 m .37153 .78833 L .3756 .79944 L p .707 .577 .707 r
F P
0 g
s
.37153 .78833 m .34847 .28453 L .35848 .27305 L p .707 .577 .707 r
F P
0 g
s
.16012 .64164 m .17236 .69706 L .16515 .70431 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1604 .75201 m .15796 .71478 L .16506 .70674 L p .707 .577 .707 r
F P
0 g
s
.35304 .78194 m .35023 .79993 L .3475 .78921 L p .707 .577 .707 r
F P
0 g
s
.3475 .78921 m .35031 .77122 L .35304 .78194 L p .707 .577 .707 r
F P
0 g
s
.16506 .70674 m .16749 .74397 L .1604 .75201 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14858 .76709 m .15139 .74909 L .15853 .73998 L p .707 .577 .707 r
F P
0 g
s
.17236 .69706 m .16012 .64164 L .17637 .63315 L p .707 .577 .707 r
F P
0 g
s
.35857 .69801 m .36101 .73524 L .34847 .72884 L p .707 .577 .707 r
F P
0 g
s
.34847 .72884 m .34603 .69161 L .35857 .69801 L p .707 .577 .707 r
F P
0 g
s
.15853 .73998 m .15572 .75797 L .14858 .76709 L p .707 .577 .707 r
F P
0 g
s
.33747 .60109 m .3497 .65652 L .32935 .6564 L p .707 .577 .707 r
F P
0 g
s
.32935 .6564 m .31711 .60098 L .33747 .60109 L p .707 .577 .707 r
F P
0 g
s
.17637 .63315 m .1886 .68858 L .17236 .69706 L p .707 .577 .707 r
F P
0 g
s
.16749 .74397 m .16506 .70674 L .18141 .69905 L p .707 .577 .707 r
F P
0 g
s
.38154 .77684 m .35848 .27305 L .38158 .26232 L p .707 .577 .707 r
F P
0 g
s
.35848 .27305 m .38154 .77684 L .37153 .78833 L p .707 .577 .707 r
F P
0 g
s
.35031 .77122 m .3475 .78921 L .33517 .77793 L p .707 .577 .707 r
F P
0 g
s
.33517 .77793 m .33798 .75993 L .35031 .77122 L p .707 .577 .707 r
F P
0 g
s
.18141 .69905 m .18385 .73628 L .16749 .74397 L p .707 .577 .707 r
F P
0 g
s
.1886 .68858 m .17637 .63315 L .20007 .62427 L p .707 .577 .707 r
F P
0 g
s
.15572 .75797 m .15853 .73998 L .17484 .73336 L p .707 .577 .707 r
F P
0 g
s
.34603 .69161 m .34847 .72884 L .32747 .72427 L p .707 .577 .707 r
F P
0 g
s
.32747 .72427 m .32504 .68704 L .34603 .69161 L p .707 .577 .707 r
F P
0 g
s
.31711 .60098 m .32935 .6564 L .30266 .65904 L p .707 .577 .707 r
F P
0 g
s
.30266 .65904 m .29043 .60361 L .31711 .60098 L p .707 .577 .707 r
F P
0 g
s
.17484 .73336 m .17203 .75136 L .15572 .75797 L p .707 .577 .707 r
F P
0 g
s
.20007 .62427 m .2123 .6797 L .1886 .68858 L p .707 .577 .707 r
F P
0 g
s
.6076 .75279 m .58454 .249 L .61423 .25626 L p .707 .577 .707 r
F P
0 g
s
.18385 .73628 m .18141 .69905 L .20543 .69244 L p .707 .577 .707 r
F P
0 g
s
.2123 .6797 m .20007 .62427 L .22889 .61586 L p .707 .577 .707 r
F P
0 g
s
.29043 .60361 m .30266 .65904 L .27226 .66417 L p .707 .577 .707 r
F P
0 g
s
.27226 .66417 m .26003 .60874 L .29043 .60361 L p .707 .577 .707 r
F P
0 g
s
.33798 .75993 m .33517 .77793 L .31445 .76719 L p .707 .577 .707 r
F P
0 g
s
.31445 .76719 m .31726 .7492 L .33798 .75993 L p .707 .577 .707 r
F P
0 g
s
.20543 .69244 m .20787 .72967 L .18385 .73628 L p .707 .577 .707 r
F P
0 g
s
.32504 .68704 m .32747 .72427 L .30008 .72196 L p .707 .577 .707 r
F P
0 g
s
.30008 .72196 m .29765 .68473 L .32504 .68704 L p .707 .577 .707 r
F P
0 g
s
.17203 .75136 m .17484 .73336 L .19873 .72989 L p .707 .577 .707 r
F P
0 g
s
.22889 .61586 m .24113 .67129 L .2123 .6797 L p .707 .577 .707 r
F P
0 g
s
.24113 .67129 m .22889 .61586 L .26003 .60874 L p .707 .577 .707 r
F P
0 g
s
.73738 .65082 m .72515 .5954 L .69475 .60053 L p .707 .577 .707 r
F P
0 g
s
.72515 .5954 m .73738 .65082 L .76852 .6437 L p .707 .577 .707 r
F P
0 g
s
.76852 .6437 m .75628 .58828 L .72515 .5954 L p .707 .577 .707 r
F P
0 g
s
.26003 .60874 m .27226 .66417 L .24113 .67129 L p .707 .577 .707 r
F P
0 g
s
.75628 .58828 m .76852 .6437 L .79734 .63529 L p .707 .577 .707 r
F P
0 g
s
.79734 .63529 m .78511 .57987 L .75628 .58828 L p .707 .577 .707 r
F P
0 g
s
.38158 .26232 m .40464 .76612 L .38154 .77684 L p .707 .577 .707 r
F P
0 g
s
.40464 .76612 m .38158 .26232 L .41552 .2534 L p .707 .577 .707 r
F P
0 g
s
.19873 .72989 m .19592 .74789 L .17203 .75136 L p .707 .577 .707 r
F P
0 g
s
.20787 .72967 m .20543 .69244 L .23477 .68757 L p .707 .577 .707 r
F P
0 g
s
.70698 .65595 m .69475 .60053 L .66806 .60316 L p .707 .577 .707 r
F P
0 g
s
.69475 .60053 m .70698 .65595 L .73738 .65082 L p .707 .577 .707 r
F P
0 g
s
.29765 .68473 m .30008 .72196 L .26898 .72214 L p .707 .577 .707 r
F P
0 g
s
.26898 .72214 m .26654 .68491 L .29765 .68473 L p .707 .577 .707 r
F P
0 g
s
.78511 .57987 m .79734 .63529 L .82104 .62641 L p .707 .577 .707 r
F P
0 g
s
.82104 .62641 m .80881 .57099 L .78511 .57987 L p .707 .577 .707 r
F P
0 g
s
.23477 .68757 m .23721 .7248 L .20787 .72967 L p .707 .577 .707 r
F P
0 g
s
.31726 .7492 m .31445 .76719 L .28735 .75806 L p .707 .577 .707 r
F P
0 g
s
.28735 .75806 m .29016 .74006 L .31726 .7492 L p .707 .577 .707 r
F P
0 g
s
.23721 .7248 m .23477 .68757 L .26654 .68491 L p .707 .577 .707 r
F P
0 g
s
.58454 .249 m .6076 .75279 L .56888 .74864 L p .707 .577 .707 r
F P
0 g
s
.56888 .74864 m .54583 .24485 L .58454 .249 L p .707 .577 .707 r
F P
0 g
s
.19592 .74789 m .19873 .72989 L .22785 .72991 L p .707 .577 .707 r
F P
0 g
s
.66806 .60316 m .6803 .65859 L .70698 .65595 L p .707 .577 .707 r
F P
0 g
s
.73551 .7144 m .73307 .67717 L .70197 .67736 L p .707 .577 .707 r
F P
0 g
s
.73307 .67717 m .73551 .7144 L .76728 .71175 L p .707 .577 .707 r
F P
0 g
s
.76728 .71175 m .76484 .67452 L .73307 .67717 L p .707 .577 .707 r
F P
0 g
s
.26654 .68491 m .26898 .72214 L .23721 .7248 L p .707 .577 .707 r
F P
0 g
s
.76484 .67452 m .76728 .71175 L .79662 .70688 L p .707 .577 .707 r
F P
0 g
s
.79662 .70688 m .79418 .66965 L .76484 .67452 L p .707 .577 .707 r
F P
0 g
s
.22785 .72991 m .22504 .74791 L .19592 .74789 L p .707 .577 .707 r
F P
0 g
s
.6803 .65859 m .66806 .60316 L .64771 .60305 L p .707 .577 .707 r
F P
0 g
s
.7044 .71459 m .70197 .67736 L .67458 .67505 L p .707 .577 .707 r
F P
0 g
s
.70197 .67736 m .7044 .71459 L .73551 .7144 L p .707 .577 .707 r
F P
0 g
s
.43857 .7572 m .41552 .2534 L .45696 .24716 L p .707 .577 .707 r
F P
0 g
s
.41552 .2534 m .43857 .7572 L .40464 .76612 L p .707 .577 .707 r
F P
0 g
s
.29016 .74006 m .28735 .75806 L .25655 .75141 L p .707 .577 .707 r
F P
0 g
s
.25655 .75141 m .25936 .73341 L .29016 .74006 L p .707 .577 .707 r
F P
0 g
s
.80881 .57099 m .82104 .62641 L .83729 .61793 L p .707 .577 .707 r
F P
0 g
s
.83729 .61793 m .82505 .5625 L .80881 .57099 L p .707 .577 .707 r
F P
0 g
s
.22504 .74791 m .22785 .72991 L .25936 .73341 L p .707 .577 .707 r
F P
0 g
s
.79418 .66965 m .79662 .70688 L .82064 .70027 L p .707 .577 .707 r
F P
0 g
s
.82064 .70027 m .8182 .66304 L .79418 .66965 L p .707 .577 .707 r
F P
0 g
s
.25936 .73341 m .25655 .75141 L .22504 .74791 L p .707 .577 .707 r
F P
0 g
s
.67458 .67505 m .67702 .71228 L .7044 .71459 L p .707 .577 .707 r
F P
0 g
s
.64771 .60305 m .65994 .65848 L .6803 .65859 L p .707 .577 .707 r
F P
0 g
s
.54583 .24485 m .56888 .74864 L .52492 .74801 L p .707 .577 .707 r
F P
0 g
s
.52492 .74801 m .50187 .24422 L .54583 .24485 L p .707 .577 .707 r
F P
0 g
s
.72248 .76593 m .72529 .74794 L .69448 .74129 L p .707 .577 .707 r
F P
0 g
s
.72529 .74794 m .72248 .76593 L .75399 .76943 L p .707 .577 .707 r
F P
0 g
s
.75399 .76943 m .7568 .75144 L .72529 .74794 L p .707 .577 .707 r
F P
0 g
s
.67702 .71228 m .67458 .67505 L .65358 .67047 L p .707 .577 .707 r
F P
0 g
s
.7568 .75144 m .75399 .76943 L .78311 .76945 L p .707 .577 .707 r
F P
0 g
s
.78311 .76945 m .78592 .75146 L .7568 .75144 L p .707 .577 .707 r
F P
0 g
s
.48002 .75096 m .45696 .24716 L .50187 .24422 L p .707 .577 .707 r
F P
0 g
s
.45696 .24716 m .48002 .75096 L .43857 .7572 L p .707 .577 .707 r
F P
0 g
s
.69167 .75928 m .69448 .74129 L .66739 .73215 L p .707 .577 .707 r
F P
0 g
s
.69448 .74129 m .69167 .75928 L .72248 .76593 L p .707 .577 .707 r
F P
0 g
s
.50187 .24422 m .52492 .74801 L .48002 .75096 L p .707 .577 .707 r
F P
0 g
s
.65358 .67047 m .65602 .7077 L .67702 .71228 L p .707 .577 .707 r
F P
0 g
s
.8182 .66304 m .82064 .70027 L .837 .69257 L p .707 .577 .707 r
F P
0 g
s
.837 .69257 m .83456 .65534 L .8182 .66304 L p .707 .577 .707 r
F P
0 g
s
.66739 .73215 m .66458 .75015 L .69167 .75928 L p .707 .577 .707 r
F P
0 g
s
.82505 .5625 m .83729 .61793 L .84449 .61068 L p .707 .577 .707 r
F P
0 g
s
.84449 .61068 m .83226 .55525 L .82505 .5625 L p .707 .577 .707 r
F P
0 g
s
.78592 .75146 m .78311 .76945 L .80699 .76598 L p .707 .577 .707 r
F P
0 g
s
.80699 .76598 m .8098 .74799 L .78592 .75146 L p .707 .577 .707 r
F P
0 g
s
.66458 .75015 m .66739 .73215 L .64666 .72142 L p .707 .577 .707 r
F P
0 g
s
.65602 .7077 m .65358 .67047 L .64104 .66408 L p .707 .577 .707 r
F P
0 g
s
.64104 .66408 m .64348 .70131 L .65602 .7077 L p .707 .577 .707 r
F P
0 g
s
.83456 .65534 m .837 .69257 L .84409 .68454 L p .707 .577 .707 r
F P
0 g
s
.84409 .68454 m .84165 .64731 L .83456 .65534 L p .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .63567 .6002 L .63313 .59489 L p .707 .577 .707 r
F P
0 g
s
.8098 .74799 m .80699 .76598 L .82331 .75937 L p .707 .577 .707 r
F P
0 g
s
.82331 .75937 m .82612 .74137 L .8098 .74799 L p .707 .577 .707 r
F P
0 g
s
.83226 .55525 m .84449 .61068 L .84195 .60537 L p .707 .577 .707 r
F P
0 g
s
.84195 .60537 m .82972 .54994 L .83226 .55525 L p .707 .577 .707 r
F P
0 g
s
.63313 .59489 m .64536 .65031 L .64791 .65563 L p .707 .577 .707 r
F P
0 g
s
.64348 .70131 m .64104 .66408 L .63817 .6565 L p .707 .577 .707 r
F P
0 g
s
.63817 .6565 m .64061 .69373 L .64348 .70131 L p .707 .577 .707 r
F P
0 g
s
.82612 .74137 m .82331 .75937 L .83045 .75025 L p .707 .577 .707 r
F P
0 g
s
.83045 .75025 m .83326 .73226 L .82612 .74137 L p .707 .577 .707 r
F P
0 g
s
.84165 .64731 m .84409 .68454 L .84123 .67695 L p .707 .577 .707 r
F P
0 g
s
.84123 .67695 m .83879 .63972 L .84165 .64731 L p .707 .577 .707 r
F P
0 g
s
.63152 .72813 m .63433 .71013 L .6316 .69941 L p .707 .577 .707 r
F P
0 g
s
.64536 .65031 m .63313 .59489 L .64034 .58764 L p .707 .577 .707 r
F P
0 g
s
.6316 .69941 m .6288 .71741 L .63152 .72813 L p .707 .577 .707 r
F P
0 g
s
.82972 .54994 m .84195 .60537 L .82992 .60252 L p .707 .577 .707 r
F P
0 g
s
.82992 .60252 m .81768 .54709 L .82972 .54994 L p .707 .577 .707 r
F P
0 g
s
.64034 .58764 m .65257 .64306 L .64536 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64061 .69373 m .63817 .6565 L .64527 .64846 L p .707 .577 .707 r
F P
0 g
s
.39437 .61278 m .38214 .55736 L .35174 .56249 L p .707 .577 .707 r
F P
0 g
s
.38214 .55736 m .39437 .61278 L .42551 .60566 L p .707 .577 .707 r
F P
0 g
s
.42551 .60566 m .41327 .55024 L .38214 .55736 L p .707 .577 .707 r
F P
0 g
s
.41327 .55024 m .42551 .60566 L .45433 .59725 L p .707 .577 .707 r
F P
0 g
s
.45433 .59725 m .4421 .54183 L .41327 .55024 L p .707 .577 .707 r
F P
0 g
s
.64527 .64846 m .64771 .68569 L .64061 .69373 L p .707 .577 .707 r
F P
0 g
s
.83326 .73226 m .83045 .75025 L .82772 .73953 L p .707 .577 .707 r
F P
0 g
s
.82772 .73953 m .83053 .72153 L .83326 .73226 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36397 .61791 m .35174 .56249 L .32505 .56512 L p .707 .577 .707 r
F P
0 g
s
.35174 .56249 m .36397 .61791 L .39437 .61278 L p .707 .577 .707 r
F P
0 g
s
.83879 .63972 m .84123 .67695 L .82868 .67056 L p .707 .577 .707 r
F P
0 g
s
.82868 .67056 m .82624 .63333 L .83879 .63972 L p .707 .577 .707 r
F P
0 g
s
.6288 .71741 m .6316 .69941 L .63875 .69029 L p .707 .577 .707 r
F P
0 g
s
.65257 .64306 m .64034 .58764 L .65658 .57916 L p .707 .577 .707 r
F P
0 g
s
.4421 .54183 m .45433 .59725 L .47803 .58837 L p .707 .577 .707 r
F P
0 g
s
.47803 .58837 m .4658 .53295 L .4421 .54183 L p .707 .577 .707 r
F P
0 g
s
.63875 .69029 m .63594 .70829 L .6288 .71741 L p .707 .577 .707 r
F P
0 g
s
.81768 .54709 m .82992 .60252 L .80956 .60241 L p .707 .577 .707 r
F P
0 g
s
.80956 .60241 m .79732 .54698 L .81768 .54709 L p .707 .577 .707 r
F P
0 g
s
.32505 .56512 m .33729 .62055 L .36397 .61791 L p .707 .577 .707 r
F P
0 g
s
.65658 .57916 m .66882 .63458 L .65257 .64306 L p .707 .577 .707 r
F P
0 g
s
.3925 .68065 m .39006 .64342 L .35896 .6436 L p .707 .577 .707 r
F P
0 g
s
.39006 .64342 m .3925 .68065 L .42427 .67799 L p .707 .577 .707 r
F P
0 g
s
.42427 .67799 m .42183 .64076 L .39006 .64342 L p .707 .577 .707 r
F P
0 g
s
.42183 .64076 m .42427 .67799 L .45361 .67312 L p .707 .577 .707 r
F P
0 g
s
.45361 .67312 m .45117 .63589 L .42183 .64076 L p .707 .577 .707 r
F P
0 g
s
.64771 .68569 m .64527 .64846 L .66163 .64077 L p .707 .577 .707 r
F P
0 g
s
.33729 .62055 m .32505 .56512 L .3047 .56501 L p .707 .577 .707 r
F P
0 g
s
.36139 .68083 m .35896 .6436 L .33157 .64129 L p .707 .577 .707 r
F P
0 g
s
.35896 .6436 m .36139 .68083 L .3925 .68065 L p .707 .577 .707 r
F P
0 g
s
.4658 .53295 m .47803 .58837 L .49428 .57989 L p .707 .577 .707 r
F P
0 g
s
.49428 .57989 m .48204 .52446 L .4658 .53295 L p .707 .577 .707 r
F P
0 g
s
.66163 .64077 m .66406 .678 L .64771 .68569 L p .707 .577 .707 r
F P
0 g
s
.45117 .63589 m .45361 .67312 L .47763 .66651 L p .707 .577 .707 r
F P
0 g
s
.47763 .66651 m .47519 .62928 L .45117 .63589 L p .707 .577 .707 r
F P
0 g
s
.83053 .72153 m .82772 .73953 L .81539 .72825 L p .707 .577 .707 r
F P
0 g
s
.81539 .72825 m .8182 .71025 L .83053 .72153 L p .707 .577 .707 r
F P
0 g
s
.66882 .63458 m .65658 .57916 L .68028 .57028 L p .707 .577 .707 r
F P
0 g
s
.3047 .56501 m .31693 .62044 L .33729 .62055 L p .707 .577 .707 r
F P
0 g
s
.33157 .64129 m .33401 .67852 L .36139 .68083 L p .707 .577 .707 r
F P
0 g
s
.82624 .63333 m .82868 .67056 L .80769 .66599 L p .707 .577 .707 r
F P
0 g
s
.80769 .66599 m .80525 .62876 L .82624 .63333 L p .707 .577 .707 r
F P
0 g
s
.63594 .70829 m .63875 .69029 L .65506 .68368 L p .707 .577 .707 r
F P
0 g
s
.37947 .72357 m .38228 .70558 L .35147 .69893 L p .707 .577 .707 r
F P
0 g
s
.38228 .70558 m .37947 .72357 L .41098 .72708 L p .707 .577 .707 r
F P
0 g
s
.41098 .72708 m .41379 .70908 L .38228 .70558 L p .707 .577 .707 r
F P
0 g
s
.79732 .54698 m .80956 .60241 L .78288 .60504 L p .707 .577 .707 r
F P
0 g
s
.78288 .60504 m .77064 .54962 L .79732 .54698 L p .707 .577 .707 r
F P
0 g
s
.33401 .67852 m .33157 .64129 L .31057 .63672 L p .707 .577 .707 r
F P
0 g
s
.65506 .68368 m .65225 .70167 L .63594 .70829 L p .707 .577 .707 r
F P
0 g
s
.41379 .70908 m .41098 .72708 L .4401 .7271 L p .707 .577 .707 r
F P
0 g
s
.4401 .7271 m .44291 .7091 L .41379 .70908 L p .707 .577 .707 r
F P
0 g
s
.68028 .57028 m .69251 .6257 L .66882 .63458 L p .707 .577 .707 r
F P
0 g
s
.34866 .71693 m .35147 .69893 L .32438 .68979 L p .707 .577 .707 r
F P
0 g
s
.35147 .69893 m .34866 .71693 L .37947 .72357 L p .707 .577 .707 r
F P
0 g
s
.31693 .62044 m .3047 .56501 L .29266 .56216 L p .707 .577 .707 r
F P
0 g
s
.66406 .678 m .66163 .64077 L .68565 .63416 L p .707 .577 .707 r
F P
0 g
s
.32438 .68979 m .32157 .70779 L .34866 .71693 L p .707 .577 .707 r
F P
0 g
s
.31057 .63672 m .31301 .67395 L .33401 .67852 L p .707 .577 .707 r
F P
0 g
s
.47519 .62928 m .47763 .66651 L .49399 .65882 L p .707 .577 .707 r
F P
0 g
s
.49399 .65882 m .49155 .62159 L .47519 .62928 L p .707 .577 .707 r
F P
0 g
s
.69251 .6257 m .68028 .57028 L .70911 .56186 L p .707 .577 .707 r
F P
0 g
s
.48204 .52446 m .49428 .57989 L .50148 .57264 L p .707 .577 .707 r
F P
0 g
s
.50148 .57264 m .48925 .51721 L .48204 .52446 L p .707 .577 .707 r
F P
0 g
s
.44291 .7091 m .4401 .7271 L .46398 .72363 L p .707 .577 .707 r
F P
0 g
s
.46398 .72363 m .46679 .70563 L .44291 .7091 L p .707 .577 .707 r
F P
0 g
s
.77064 .54962 m .78288 .60504 L .75248 .61017 L p .707 .577 .707 r
F P
0 g
s
.75248 .61017 m .74024 .55474 L .77064 .54962 L p .707 .577 .707 r
F P
0 g
s
.68565 .63416 m .68809 .67139 L .66406 .678 L p .707 .577 .707 r
F P
0 g
s
.29266 .56216 m .30489 .61759 L .31693 .62044 L p .707 .577 .707 r
F P
0 g
s
.32157 .70779 m .32438 .68979 L .30365 .67906 L p .707 .577 .707 r
F P
0 g
s
.80525 .62876 m .80769 .66599 L .7803 .66368 L p .707 .577 .707 r
F P
0 g
s
.7803 .66368 m .77786 .62645 L .80525 .62876 L p .707 .577 .707 r
F P
0 g
s
.8182 .71025 m .81539 .72825 L .79466 .71751 L p .707 .577 .707 r
F P
0 g
s
.79466 .71751 m .79747 .69952 L .8182 .71025 L p .707 .577 .707 r
F P
0 g
s
.65225 .70167 m .65506 .68368 L .67894 .68021 L p .707 .577 .707 r
F P
0 g
s
.70911 .56186 m .72134 .61729 L .69251 .6257 L p .707 .577 .707 r
F P
0 g
s
.72134 .61729 m .70911 .56186 L .74024 .55474 L p .707 .577 .707 r
F P
0 g
s
.30365 .67906 m .30084 .69705 L .32157 .70779 L p .707 .577 .707 r
F P
0 g
s
.74024 .55474 m .75248 .61017 L .72134 .61729 L p .707 .577 .707 r
F P
0 g
s
.31301 .67395 m .31057 .63672 L .29803 .63032 L p .707 .577 .707 r
F P
0 g
s
.68809 .67139 m .68565 .63416 L .71498 .62929 L p .707 .577 .707 r
F P
0 g
s
.67894 .68021 m .67613 .69821 L .65225 .70167 L p .707 .577 .707 r
F P
0 g
s
.29803 .63032 m .30047 .66756 L .31301 .67395 L p .707 .577 .707 r
F P
0 g
s
.77786 .62645 m .7803 .66368 L .74919 .66386 L p .707 .577 .707 r
F P
0 g
s
.74919 .66386 m .74676 .62663 L .77786 .62645 L p .707 .577 .707 r
F P
0 g
s
.46679 .70563 m .46398 .72363 L .4803 .71701 L p .707 .577 .707 r
F P
0 g
s
.4803 .71701 m .4831 .69902 L .46679 .70563 L p .707 .577 .707 r
F P
0 g
s
.30489 .61759 m .29266 .56216 L .29012 .55685 L p .707 .577 .707 r
F P
0 g
s
.71498 .62929 m .71742 .66652 L .68809 .67139 L p .707 .577 .707 r
F P
0 g
s
.49155 .62159 m .49399 .65882 L .50108 .65078 L p .707 .577 .707 r
F P
0 g
s
.50108 .65078 m .49864 .61355 L .49155 .62159 L p .707 .577 .707 r
F P
0 g
s
.30084 .69705 m .30365 .67906 L .29132 .66778 L p .707 .577 .707 r
F P
0 g
s
.71742 .66652 m .71498 .62929 L .74676 .62663 L p .707 .577 .707 r
F P
0 g
s
.79747 .69952 m .79466 .71751 L .76757 .70837 L p .707 .577 .707 r
F P
0 g
s
.76757 .70837 m .77038 .69038 L .79747 .69952 L p .707 .577 .707 r
F P
0 g
s
.74676 .62663 m .74919 .66386 L .71742 .66652 L p .707 .577 .707 r
F P
0 g
s
.67613 .69821 m .67894 .68021 L .70806 .68023 L p .707 .577 .707 r
F P
0 g
s
.48925 .51721 m .50148 .57264 L .49894 .56733 L p .707 .577 .707 r
F P
0 g
s
.49894 .56733 m .48671 .5119 L .48925 .51721 L p .707 .577 .707 r
F P
0 g
s
.29132 .66778 m .28851 .68577 L .30084 .69705 L p .707 .577 .707 r
F P
0 g
s
.29012 .55685 m .30235 .61227 L .30489 .61759 L p .707 .577 .707 r
F P
0 g
s
.70806 .68023 m .70525 .69822 L .67613 .69821 L p .707 .577 .707 r
F P
0 g
s
.30047 .66756 m .29803 .63032 L .29516 .62274 L p .707 .577 .707 r
F P
0 g
s
.77038 .69038 m .76757 .70837 L .73676 .70173 L p .707 .577 .707 r
F P
0 g
s
.73676 .70173 m .73957 .68373 L .77038 .69038 L p .707 .577 .707 r
F P
0 g
s
.70525 .69822 m .70806 .68023 L .73957 .68373 L p .707 .577 .707 r
F P
0 g
s
.73957 .68373 m .73676 .70173 L .70525 .69822 L p .707 .577 .707 r
F P
0 g
s
.29516 .62274 m .2976 .65997 L .30047 .66756 L p .707 .577 .707 r
F P
0 g
s
.4831 .69902 m .4803 .71701 L .48744 .7079 L p .707 .577 .707 r
F P
0 g
s
.48744 .7079 m .49025 .6899 L .4831 .69902 L p .707 .577 .707 r
F P
0 g
s
.28851 .68577 m .29132 .66778 L .28859 .65705 L p .707 .577 .707 r
F P
0 g
s
.49864 .61355 m .50108 .65078 L .49821 .6432 L p .707 .577 .707 r
F P
0 g
s
.49821 .6432 m .49578 .60597 L .49864 .61355 L p .707 .577 .707 r
F P
0 g
s
.30235 .61227 m .29012 .55685 L .29733 .5496 L p .707 .577 .707 r
F P
0 g
s
.28859 .65705 m .28578 .67505 L .28851 .68577 L p .707 .577 .707 r
F P
0 g
s
.48671 .5119 m .49894 .56733 L .48691 .56448 L p .707 .577 .707 r
F P
0 g
s
.48691 .56448 m .47467 .50905 L .48671 .5119 L p .707 .577 .707 r
F P
0 g
s
.29733 .5496 m .30956 .60502 L .30235 .61227 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2976 .65997 m .29516 .62274 L .30226 .61471 L p .707 .577 .707 r
F P
0 g
s
.49025 .6899 m .48744 .7079 L .48471 .69717 L p .707 .577 .707 r
F P
0 g
s
.48471 .69717 m .48752 .67918 L .49025 .6899 L p .707 .577 .707 r
F P
0 g
s
.30226 .61471 m .3047 .65194 L .2976 .65997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28578 .67505 m .28859 .65705 L .29573 .64794 L p .707 .577 .707 r
F P
0 g
s
.30956 .60502 m .29733 .5496 L .31357 .54112 L p .707 .577 .707 r
F P
0 g
s
.49578 .60597 m .49821 .6432 L .48567 .6368 L p .707 .577 .707 r
F P
0 g
s
.48567 .6368 m .48323 .59957 L .49578 .60597 L p .707 .577 .707 r
F P
0 g
s
.29573 .64794 m .29293 .66593 L .28578 .67505 L p .707 .577 .707 r
F P
0 g
s
.47467 .50905 m .48691 .56448 L .46655 .56436 L p .707 .577 .707 r
F P
0 g
s
.46655 .56436 m .45431 .50894 L .47467 .50905 L p .707 .577 .707 r
F P
0 g
s
.31357 .54112 m .32581 .59654 L .30956 .60502 L p .707 .577 .707 r
F P
0 g
s
.3047 .65194 m .30226 .61471 L .31862 .60701 L p .707 .577 .707 r
F P
0 g
s
.48752 .67918 m .48471 .69717 L .47238 .68589 L p .707 .577 .707 r
F P
0 g
s
.47238 .68589 m .47519 .6679 L .48752 .67918 L p .707 .577 .707 r
F P
0 g
s
.31862 .60701 m .32105 .64424 L .3047 .65194 L p .707 .577 .707 r
F P
0 g
s
.32581 .59654 m .31357 .54112 L .33727 .53223 L p .707 .577 .707 r
F P
0 g
s
.29293 .66593 m .29573 .64794 L .31205 .64132 L p .707 .577 .707 r
F P
0 g
s
.48323 .59957 m .48567 .6368 L .46468 .63223 L p .707 .577 .707 r
F P
0 g
s
.46468 .63223 m .46224 .595 L .48323 .59957 L p .707 .577 .707 r
F P
0 g
s
.45431 .50894 m .46655 .56436 L .43987 .567 L p .707 .577 .707 r
F P
0 g
s
.43987 .567 m .42763 .51158 L .45431 .50894 L p .707 .577 .707 r
F P
0 g
s
.31205 .64132 m .30924 .65932 L .29293 .66593 L p .707 .577 .707 r
F P
0 g
s
.33727 .53223 m .3495 .58766 L .32581 .59654 L p .707 .577 .707 r
F P
0 g
s
.32105 .64424 m .31862 .60701 L .34264 .6004 L p .707 .577 .707 r
F P
0 g
s
.3495 .58766 m .33727 .53223 L .3661 .52382 L p .707 .577 .707 r
F P
0 g
s
.42763 .51158 m .43987 .567 L .40947 .57213 L p .707 .577 .707 r
F P
0 g
s
.40947 .57213 m .39723 .5167 L .42763 .51158 L p .707 .577 .707 r
F P
0 g
s
.47519 .6679 m .47238 .68589 L .45165 .67516 L p .707 .577 .707 r
F P
0 g
s
.45165 .67516 m .45446 .65716 L .47519 .6679 L p .707 .577 .707 r
F P
0 g
s
.34264 .6004 m .34508 .63763 L .32105 .64424 L p .707 .577 .707 r
F P
0 g
s
.46224 .595 m .46468 .63223 L .43729 .62992 L p .707 .577 .707 r
F P
0 g
s
.43729 .62992 m .43485 .59269 L .46224 .595 L p .707 .577 .707 r
F P
0 g
s
.30924 .65932 m .31205 .64132 L .33593 .63785 L p .707 .577 .707 r
F P
0 g
s
.3661 .52382 m .37833 .57925 L .3495 .58766 L p .707 .577 .707 r
F P
0 g
s
.37833 .57925 m .3661 .52382 L .39723 .5167 L p .707 .577 .707 r
F P
0 g
s
.39723 .5167 m .40947 .57213 L .37833 .57925 L p .707 .577 .707 r
F P
0 g
s
.33593 .63785 m .33312 .65585 L .30924 .65932 L p .707 .577 .707 r
F P
0 g
s
.34508 .63763 m .34264 .6004 L .37197 .59553 L p .707 .577 .707 r
F P
0 g
s
.43485 .59269 m .43729 .62992 L .40618 .6301 L p .707 .577 .707 r
F P
0 g
s
.40618 .6301 m .40375 .59287 L .43485 .59269 L p .707 .577 .707 r
F P
0 g
s
.37197 .59553 m .37441 .63276 L .34508 .63763 L p .707 .577 .707 r
F P
0 g
s
.45446 .65716 m .45165 .67516 L .42456 .66602 L p .707 .577 .707 r
F P
0 g
s
.42456 .66602 m .42737 .64802 L .45446 .65716 L p .707 .577 .707 r
F P
0 g
s
.37441 .63276 m .37197 .59553 L .40375 .59287 L p .707 .577 .707 r
F P
0 g
s
.33312 .65585 m .33593 .63785 L .36505 .63787 L p .707 .577 .707 r
F P
0 g
s
.40375 .59287 m .40618 .6301 L .37441 .63276 L p .707 .577 .707 r
F P
0 g
s
.36505 .63787 m .36224 .65587 L .33312 .65585 L p .707 .577 .707 r
F P
0 g
s
.42737 .64802 m .42456 .66602 L .39375 .65937 L p .707 .577 .707 r
F P
0 g
s
.39375 .65937 m .39656 .64138 L .42737 .64802 L p .707 .577 .707 r
F P
0 g
s
.36224 .65587 m .36505 .63787 L .39656 .64138 L p .707 .577 .707 r
F P
0 g
s
.39656 .64138 m .39375 .65937 L .36224 .65587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6@00O7oo001oOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Uoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0075oo`00M7oo1@00
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00KWoo001_
Ool50002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH3001/Ool006]oo`@000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Yoo`00JGoo0P0000=JEP00FUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0Igoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIY
Ool006Eoo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Ioo`00I7oo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IWoo001TOol20006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1VOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Ioo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0IWoo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1V
Ool006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP03001oogoo06Ioo`00Hgoo
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001SOol00`00FUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006=oo`03001JEP0000MJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0I7oo001TOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001J
EP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH:000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00=JEPT000=J
EP03001JEUYF009JEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<006Aoo`00IWoo00<005YF00000UYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol50005FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001TOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001QOol30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001NOol30008FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005]oo`<00003
FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00FGoo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001EOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000VOol;000cOol005Aoo`03001JEUYF00=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
01ioo`P000=JEP03001JEUYF00=JEP04001JEP00000aOol005=oo`8000EJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8001Moo`L000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080031oo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P004goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF001JES1oo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000?
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001B
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YFFUIJEP/00003FUH0000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH00UYF100015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`000eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;goo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70006FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000_Ool005=oo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF100025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEP000080
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080
02ioo`00E7oo00@005YFFUH000AJEP03001JEUYF00=JEP@000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF
00<005YF00000`000eYF00<005YFFUH01UYF4@000UYF00<005YF00000`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002eoo`00E7oo00@005YFFUH000AJEP<000IJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH8
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Aoo`04001JEUYF0003FUH01@00FUIJEP00FUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008002eoo`00D7oo1@000eYF0`0000=JEP0000000P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol0:goo001<
Ool40002FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF1@00;7oo0018Ool40006
FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000/Ool0
04Aoo`@00003FUH005YF00QJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000]Ool003moo`D000IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP03001oogoo02eoo`00>goo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool003Qoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000aOol003Ioo`<000UJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH0
0002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0M0002FUH2000cOol003Ao
o`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF00AJEP03001JEUYF00AJEQd000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol0035oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP0400000eYF001JEP02FUH50008FUH00`00FUIJEP040004FUH3000015YF001JEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH30000
0eYF000000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000aOol002moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUHA0002FUH50007FUH40002FUH00`00FUIJEP04FUH00`00FUH000020000
0eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF
00D005YF000005YF00<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPh000IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH50004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
000/Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000[Ool00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00:goo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<00003FUH0
05YF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002]oo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH00eYF0`001EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF10000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`001UYF00<005YFFUH01UYF0`000eYF00@005YFFUIJEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH900001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUH005YF0`000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001UYF00<005YFFUH0
0eYF0`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP00004Ool00000000=Ool70003FUH01@00FUIJEUYF0000
;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF100025YF00<005YF0000
0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJ
EP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00009JEP05001JEUYFFUH00005FUH60008Ool50009Ool50005FUH40003FUH00`00Oomoo`0[Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP06FUH3
00000eYF001JEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF0`0000=JEP00FUH01EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000UYF00H005YFFUIJEP00FUH60002FUH20008Ool>0003FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
00000P001UYF00<005YFFUH01UYF0`000UYF00H005YFFUIJEP00FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90002FUH20005FUH01000FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH200000eYF001JEP02FUHB0004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03
FUH40008FUH00`00FUIJEP06FUH30003FUH01000FUIJEP001UYF50001eYF00<005YFFUH00eYF0P00
0eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYF001JEP00FUH00P000UYF40000UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Goo000]Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH0
1EYF30000eYF100015YF0P0027oo00@005YFFUH0009JEPD000QJEP03001JEUYF00EJEP800003FUH0
05YF009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYF001JEP060002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00@005YFFUH000AJEP<000MJEPP000AJEP03
001JEUYF00AJEP05001JEUYFFUH00002FUH60009Ool01000FUIJEP000UYF1@0025YF00<005YFFUH0
1eYF0P000eYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8002ioo`00;Goo00@005YFFUH000=JEP05001JEUYF001J
EP060003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH300000eYF000000020005
Ool01000FUIJEP000UYF1@0025YF00<005YFFUH02EYF00D005YF001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00=JEP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002eoo`04
001JEUYFFUH300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0006FUH00`00FUH000060003Ool01000FUIJEP000eYF100025YF00<005YFFUH02EYF0`0000=JEP00
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
15YF00@005YFFUH0031oo`00;Woo0eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P001UYF00<005YFFUH00eYF10000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP<00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEP0000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH3000a
Ool002ioo`06FUH00000001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP800003FUH0000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000IJEP03001JEUYF00EJEP<0
00=JEP8003=oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH015YF1`0000=JEP00FUH01eYF
00<005YFFUH00eYF1@000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P0000IJEP00000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP03000eOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEQ0000=JEP07001JEUYFFUH005YF00002EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YF000000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000EJEP03001JEUYF00=JEP8003Aoo`00;Goo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP80009JEPL000AJEP03001JEUYF00IJEP03001J
EUYF009JEPP000=JEP03001JEUYF00AJEP8003=oo`00;7oo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH40003FUH20007FUHD0008Ool200000eYF001J
EP05FUH00`00FUH0000bOol002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH00eYF0P000UYF00<005YFFUH01P000UYF0P003Goo1@00
2goo0P001EYF00D005YFFUIJEP00035oo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF5`0015YF00D005YFFUH007oo00P000AJEP03001JEUYF00IJEP04001J
EUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2
0003FUH01000FUH000000UYF00<005YF00000P003Woo1@003Goo0P000eYF00<005YFFUH00UYF00<0
07ooOol0;Woo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF30002goo1P00
0UYF0`0000AJEP00FUIJEP<0009JEP03001JEUYF009JEQ4000MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH2000<
Ool5000?Ool200000eYF001JEP03FUH00`00Oomoo`0^Ool002aoo`04001JEUYF0004FUHA0002Ool5
0007Ool40002FUH00`00FUIJEP04FUH01000FUH000000UYF0`000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH015YF00D005YFFUIJEP00009JEP800003FUH005YF00AJEP<000]oo`<0019oo`8000AJEP03001o
ogoo02ioo`00;7oo00D005YFFUH005YF00@000=JEP03001JEUYF00EJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00AJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP0015YF0`0015YF00<005YFFUH00P0087oo00<005YFFUH00P00<7oo000]Ool00`00FUH000020006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YF00001000
0eYF00<007ooOol07goo1000<7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF1P008Goo0`00<7oo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH015YF00<005YFFUH00UYF00@005YF000000YJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol5000`Ool002aoo`80009JEP04001JEUYFFUH@0004
FUH00`00FUIJEP07FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF0P0000=oo`00FUH02EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF5@0025YF00<005YFFUH02eYF0`0025YF00<0
05YFFUH015YF1`0047oo1@000UYF00<005YF0000<7oo000[Ool20003FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH20005FUH01000FUIJEUYF0P000goo2UYF00<0
05YFFUH01UYF00<005YFFUH01eYF2@0035YF00<005YFFUH01UYF1P000UYF00<005YFFUH02eYF1000
1UYF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH0000`Ool002]oo`80
0005FUH00000FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<0
05YFFUH01UYF0`000eYF00@005YF000000Eoo`YJEP03001JEUYF00IJEP04001JEUYFFUH60008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05000;FUH20002FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000[Ool4
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP050007Ool:FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH2
000:FUH00`00FUIJEP05FUH50006FUH700000eYF000000030006FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Woo000ZOol20003Ool30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00eYF0P0027oo2UYF
00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000=JEP8000EJEP@0009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP00000dOol002Yoo`<000Aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH20007Ool9FUH400000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH200000eYF00000005FUH01000FUIJEUYF0P0000AJEP00Oomoo`L000AJEP03001JEUYF
00EJEP04001JEUYFFUH5000fOol002Yoo`800003FUH0000000Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPT0009oo`8000IJEP03001JEP0000Ioo`MJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000EJEP03001JEUYF009JEP<000Uooa0003]oo`00:Woo0P000eYF00<007ooOol017oo5`00
3Goo0P000eYF00D005YFFUIJEP0000Eoo`EJEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP02FUH00`00FUH0001DOol002]oo`04001JEUYFFUH3000EOol5000@Ool200000eYF001J
EP02FUH00`00Oomoo`03Ool3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF
00L005YFFUIJEP00FUH0001DOol002]oo`05001JEUYFFUH00002FUH2000COol5000BOol20003FUH2
0004Ool2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000IJEP04001JEUYFFUH2
001EOol002aoo`03001JEP0000EJEP<0011oo`D001Aoo`05001JEP00FUH00004Ool00eYF001JEP03
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP8005Eoo`00;Goo
0P001UYF00<005YF00000`003Goo0`005Woo0P0000=JEP00Ool00goo00=JEP00FUH00eYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000IJEP05001JEUYFFUH0001FOol002ioo`03001JEUYF
00AJEP03001JEUYF00=JEP@0029oo`800003FUH007oo00=oo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00mJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH005YF00EJEP04001JEP00001GOol002moo`8000=JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`800003FUH0000000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH0000000EJEP<005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`0047oo1@00
0eYF0P001Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEPH005aoo`00<goo
0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH00006Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00P00GGoo000fOol20004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
27oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF20000eYF00<005YFFUH00eYF0P00Fgoo000hOol300000eYF001J
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool3
0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP040008Ool200000eYF001JEP05FUH2001JOol003]oo`D000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00<000eoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEPH000aoo`8000IJEP04001JEP00001HOol0041oo`T000AJ
EP03001JEUYF00IJEP04001JEUYFFUH5000COol40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP02FUH60002Ool5000=Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1EOol004Uooa4001aoo`P000EJEP03001JEUYF00UJEP03001JEUYF009JEPd000Qoo`D000moo`80
0003FUH005YF00=JEP03001oogoo05Eoo`00OWoo5`0057oo1@004Goo0P0015YF00<007ooOol0EGoo
002=Ool01000FUIJEP0015YF0`004Woo0`0057oo00<005YFFUH00P00Egoo002>Ool30005FUH00`00
FUH00003000VOol4001GOol0091oo`03001JEUYF00=JEP03001JEUYF00=JEPD0029oo`<005Moo`00
TGoo0P000UYF00<005YFFUH01UYF00<005YFFUH0100077oo1@00Egoo002COol30008FUH00`00FUIJ
EP04FUH7000@Ool50002FUH00`00FUH0001GOol009Eoo`8000IJEP03001JEUYF00MJEP03001JEUYF
009JEQ0000=JEP07001JEUYFFUH005YF0000Egoo002GOol20004FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00F7oo002IOol300000eYF001J
EP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001HOol0
09aoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<005Uo
o`00XWoo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005aoo`00Zgoo4000HWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59053 .75449 m .60276 .70169 L .57237 .69293 L p .707 .577 .707 r
F P
0 g
s
.60276 .70169 m .59053 .75449 L .62167 .75991 L p .707 .577 .707 r
F P
0 g
s
.62167 .75991 m .6339 .70711 L .60276 .70169 L p .707 .577 .707 r
F P
0 g
s
.56013 .74573 m .57237 .69293 L .54568 .68167 L p .707 .577 .707 r
F P
0 g
s
.57237 .69293 m .56013 .74573 L .59053 .75449 L p .707 .577 .707 r
F P
0 g
s
.6339 .70711 m .62167 .75991 L .65049 .76144 L p .707 .577 .707 r
F P
0 g
s
.65049 .76144 m .66273 .70864 L .6339 .70711 L p .707 .577 .707 r
F P
0 g
s
.53345 .73447 m .54568 .68167 L .52533 .66903 L p .707 .577 .707 r
F P
0 g
s
.54568 .68167 m .53345 .73447 L .56013 .74573 L p .707 .577 .707 r
F P
0 g
s
.66273 .70864 m .65049 .76144 L .67419 .75895 L p .707 .577 .707 r
F P
0 g
s
.67419 .75895 m .68642 .70615 L .66273 .70864 L p .707 .577 .707 r
F P
0 g
s
.59381 .81317 m .59625 .77647 L .56515 .7725 L p .707 .577 .707 r
F P
0 g
s
.59625 .77647 m .59381 .81317 L .62559 .81426 L p .707 .577 .707 r
F P
0 g
s
.62559 .81426 m .62803 .77755 L .59625 .77647 L p .707 .577 .707 r
F P
0 g
s
.62803 .77755 m .62559 .81426 L .65492 .81236 L p .707 .577 .707 r
F P
0 g
s
.65492 .81236 m .65736 .77566 L .62803 .77755 L p .707 .577 .707 r
F P
0 g
s
.56271 .8092 m .56515 .7725 L .53776 .76603 L p .707 .577 .707 r
F P
0 g
s
.56515 .7725 m .56271 .8092 L .59381 .81317 L p .707 .577 .707 r
F P
0 g
s
.60625 .84511 m .60344 .82651 L .57263 .82943 L p .707 .577 .707 r
F P
0 g
s
.60344 .82651 m .60625 .84511 L .63775 .83998 L p .707 .577 .707 r
F P
0 g
s
.63775 .83998 m .63494 .82138 L .60344 .82651 L p .707 .577 .707 r
F P
0 g
s
.63494 .82138 m .63775 .83998 L .66687 .83315 L p .707 .577 .707 r
F P
0 g
s
.66687 .83315 m .66407 .81455 L .63494 .82138 L p .707 .577 .707 r
F P
0 g
s
.52533 .66903 m .51309 .72183 L .53345 .73447 L p .707 .577 .707 r
F P
0 g
s
.57263 .82943 m .57544 .84803 L .60625 .84511 L p .707 .577 .707 r
F P
0 g
s
.51309 .72183 m .52533 .66903 L .51329 .65623 L p .707 .577 .707 r
F P
0 g
s
.65736 .77566 m .65492 .81236 L .67894 .80766 L p .707 .577 .707 r
F P
0 g
s
.67894 .80766 m .68138 .77096 L .65736 .77566 L p .707 .577 .707 r
F P
0 g
s
.68642 .70615 m .67419 .75895 L .69044 .75267 L p .707 .577 .707 r
F P
0 g
s
.69044 .75267 m .70267 .69987 L .68642 .70615 L p .707 .577 .707 r
F P
0 g
s
.53776 .76603 m .53532 .80274 L .56271 .8092 L p .707 .577 .707 r
F P
0 g
s
.57544 .84803 m .57263 .82943 L .54554 .82987 L p .707 .577 .707 r
F P
0 g
s
.53532 .80274 m .53776 .76603 L .51676 .75771 L p .707 .577 .707 r
F P
0 g
s
.54554 .82987 m .54835 .84846 L .57544 .84803 L p .707 .577 .707 r
F P
0 g
s
.66407 .81455 m .66687 .83315 L .69076 .82528 L p .707 .577 .707 r
F P
0 g
s
.69076 .82528 m .68795 .80668 L .66407 .81455 L p .707 .577 .707 r
F P
0 g
s
.51676 .75771 m .51433 .79442 L .53532 .80274 L p .707 .577 .707 r
F P
0 g
s
.51329 .65623 m .50105 .70903 L .51309 .72183 L p .707 .577 .707 r
F P
0 g
s
.54835 .84846 m .54554 .82987 L .52481 .82776 L p .707 .577 .707 r
F P
0 g
s
.68138 .77096 m .67894 .80766 L .6953 .80062 L p .707 .577 .707 r
F P
0 g
s
.6953 .80062 m .69774 .76392 L .68138 .77096 L p .707 .577 .707 r
F P
0 g
s
.52481 .82776 m .52762 .84636 L .54835 .84846 L p .707 .577 .707 r
F P
0 g
s
.50105 .70903 m .51329 .65623 L .51075 .64453 L p .707 .577 .707 r
F P
0 g
s
.70267 .69987 m .69044 .75267 L .69764 .74322 L p .707 .577 .707 r
F P
0 g
s
.69764 .74322 m .70988 .69042 L .70267 .69987 L p .707 .577 .707 r
F P
0 g
s
.68795 .80668 m .69076 .82528 L .70707 .81715 L p .707 .577 .707 r
F P
0 g
s
.70707 .81715 m .70426 .79855 L .68795 .80668 L p .707 .577 .707 r
F P
0 g
s
.51433 .79442 m .51676 .75771 L .50422 .74835 L p .707 .577 .707 r
F P
0 g
s
.50422 .74835 m .50178 .78506 L .51433 .79442 L p .707 .577 .707 r
F P
0 g
s
.52762 .84636 m .52481 .82776 L .51248 .82333 L p .707 .577 .707 r
F P
0 g
s
.51075 .64453 m .49851 .69733 L .50105 .70903 L p .707 .577 .707 r
F P
0 g
s
.69774 .76392 m .6953 .80062 L .70239 .79193 L p .707 .577 .707 r
F P
0 g
s
.70239 .79193 m .70483 .75523 L .69774 .76392 L p .707 .577 .707 r
F P
0 g
s
.51248 .82333 m .51529 .84193 L .52762 .84636 L p .707 .577 .707 r
F P
0 g
s
.70426 .79855 m .70707 .81715 L .71421 .80955 L p .707 .577 .707 r
F P
0 g
s
.71421 .80955 m .7114 .79095 L .70426 .79855 L p .707 .577 .707 r
F P
0 g
s
.50178 .78506 m .50422 .74835 L .50136 .73886 L p .707 .577 .707 r
F P
0 g
s
.49851 .69733 m .51075 .64453 L .51795 .63508 L p .707 .577 .707 r
F P
0 g
s
.70988 .69042 m .69764 .74322 L .6951 .73152 L p .707 .577 .707 r
F P
0 g
s
.6951 .73152 m .70734 .67872 L .70988 .69042 L p .707 .577 .707 r
F P
0 g
s
.47507 .82195 m .49813 .32311 L .45417 .31838 L p .707 .577 .707 r
F P
0 g
s
.50136 .73886 m .49892 .77556 L .50178 .78506 L p .707 .577 .707 r
F P
0 g
s
.51529 .84193 m .51248 .82333 L .50975 .81701 L p .707 .577 .707 r
F P
0 g
s
.51795 .63508 m .50572 .68788 L .49851 .69733 L p .707 .577 .707 r
F P
0 g
s
.50975 .81701 m .51256 .83561 L .51529 .84193 L p .707 .577 .707 r
F P
0 g
s
.50572 .68788 m .51795 .63508 L .5342 .6288 L p .707 .577 .707 r
F P
0 g
s
.49892 .77556 m .50136 .73886 L .50845 .73016 L p .707 .577 .707 r
F P
0 g
s
.50845 .73016 m .50601 .76687 L .49892 .77556 L p .707 .577 .707 r
F P
0 g
s
.51256 .83561 m .50975 .81701 L .51689 .80941 L p .707 .577 .707 r
F P
0 g
s
.5342 .6288 m .52197 .6816 L .50572 .68788 L p .707 .577 .707 r
F P
0 g
s
.51689 .80941 m .5197 .82801 L .51256 .83561 L p .707 .577 .707 r
F P
0 g
s
.50601 .76687 m .50845 .73016 L .52481 .72312 L p .707 .577 .707 r
F P
0 g
s
.52481 .72312 m .52237 .75983 L .50601 .76687 L p .707 .577 .707 r
F P
0 g
s
.5197 .82801 m .51689 .80941 L .5332 .80128 L p .707 .577 .707 r
F P
0 g
s
.49813 .32311 m .47507 .82195 L .51998 .8227 L p .707 .577 .707 r
F P
0 g
s
.52197 .6816 m .5342 .6288 L .5579 .62631 L p .707 .577 .707 r
F P
0 g
s
.5579 .62631 m .54566 .67911 L .52197 .6816 L p .707 .577 .707 r
F P
0 g
s
.52237 .75983 m .52481 .72312 L .54883 .71843 L p .707 .577 .707 r
F P
0 g
s
.54883 .71843 m .54639 .75513 L .52237 .75983 L p .707 .577 .707 r
F P
0 g
s
.51998 .8227 m .54303 .32385 L .49813 .32311 L p .707 .577 .707 r
F P
0 g
s
.54566 .67911 m .5579 .62631 L .58672 .62784 L p .707 .577 .707 r
F P
0 g
s
.5332 .80128 m .53601 .81987 L .5197 .82801 L p .707 .577 .707 r
F P
0 g
s
.58672 .62784 m .57449 .68064 L .54566 .67911 L p .707 .577 .707 r
F P
0 g
s
.53601 .81987 m .5332 .80128 L .55709 .79341 L p .707 .577 .707 r
F P
0 g
s
.54639 .75513 m .54883 .71843 L .57816 .71653 L p .707 .577 .707 r
F P
0 g
s
.55709 .79341 m .5599 .81201 L .53601 .81987 L p .707 .577 .707 r
F P
0 g
s
.57816 .71653 m .57572 .75323 L .54639 .75513 L p .707 .577 .707 r
F P
0 g
s
.5599 .81201 m .55709 .79341 L .58621 .78658 L p .707 .577 .707 r
F P
0 g
s
.58621 .78658 m .58902 .80517 L .5599 .81201 L p .707 .577 .707 r
F P
0 g
s
.54303 .32385 m .51998 .8227 L .56142 .81939 L p .707 .577 .707 r
F P
0 g
s
.56142 .81939 m .58448 .32054 L .54303 .32385 L p .707 .577 .707 r
F P
0 g
s
.43111 .81723 m .45417 .31838 L .41545 .31014 L p .707 .577 .707 r
F P
0 g
s
.45417 .31838 m .43111 .81723 L .47507 .82195 L p .707 .577 .707 r
F P
0 g
s
.70483 .75523 m .70239 .79193 L .69953 .78244 L p .707 .577 .707 r
F P
0 g
s
.69953 .78244 m .70197 .74573 L .70483 .75523 L p .707 .577 .707 r
F P
0 g
s
.57449 .68064 m .58672 .62784 L .61786 .63326 L p .707 .577 .707 r
F P
0 g
s
.61786 .63326 m .60563 .68606 L .57449 .68064 L p .707 .577 .707 r
F P
0 g
s
.57572 .75323 m .57816 .71653 L .60994 .71762 L p .707 .577 .707 r
F P
0 g
s
.60994 .71762 m .6075 .75432 L .57572 .75323 L p .707 .577 .707 r
F P
0 g
s
.58902 .80517 m .58621 .78658 L .61772 .78145 L p .707 .577 .707 r
F P
0 g
s
.61772 .78145 m .62053 .80005 L .58902 .80517 L p .707 .577 .707 r
F P
0 g
s
.58448 .32054 m .56142 .81939 L .59536 .81235 L p .707 .577 .707 r
F P
0 g
s
.59536 .81235 m .61842 .31351 L .58448 .32054 L p .707 .577 .707 r
F P
0 g
s
.7114 .79095 m .71421 .80955 L .71148 .80322 L p .707 .577 .707 r
F P
0 g
s
.71148 .80322 m .70867 .78462 L .7114 .79095 L p .707 .577 .707 r
F P
0 g
s
.70734 .67872 m .6951 .73152 L .68306 .71872 L p .707 .577 .707 r
F P
0 g
s
.68306 .71872 m .6953 .66592 L .70734 .67872 L p .707 .577 .707 r
F P
0 g
s
.3924 .80898 m .41545 .31014 L .38577 .29919 L p .707 .577 .707 r
F P
0 g
s
.41545 .31014 m .3924 .80898 L .43111 .81723 L p .707 .577 .707 r
F P
0 g
s
.24752 .7189 m .25976 .6661 L .22936 .65734 L p .707 .577 .707 r
F P
0 g
s
.25976 .6661 m .24752 .7189 L .27866 .72432 L p .707 .577 .707 r
F P
0 g
s
.27866 .72432 m .29089 .67152 L .25976 .6661 L p .707 .577 .707 r
F P
0 g
s
.21712 .71014 m .22936 .65734 L .20267 .64608 L p .707 .577 .707 r
F P
0 g
s
.22936 .65734 m .21712 .71014 L .24752 .7189 L p .707 .577 .707 r
F P
0 g
s
.29089 .67152 m .27866 .72432 L .30748 .72585 L p .707 .577 .707 r
F P
0 g
s
.30748 .72585 m .31972 .67305 L .29089 .67152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70197 .74573 m .69953 .78244 L .68699 .77307 L p .707 .577 .707 r
F P
0 g
s
.68699 .77307 m .68942 .73637 L .70197 .74573 L p .707 .577 .707 r
F P
0 g
s
.19044 .69888 m .20267 .64608 L .18232 .63344 L p .707 .577 .707 r
F P
0 g
s
.20267 .64608 m .19044 .69888 L .21712 .71014 L p .707 .577 .707 r
F P
0 g
s
.64826 .64202 m .63602 .69482 L .60563 .68606 L p .707 .577 .707 r
F P
0 g
s
.60563 .68606 m .61786 .63326 L .64826 .64202 L p .707 .577 .707 r
F P
0 g
s
.64104 .72159 m .6386 .75829 L .6075 .75432 L p .707 .577 .707 r
F P
0 g
s
.6075 .75432 m .60994 .71762 L .64104 .72159 L p .707 .577 .707 r
F P
0 g
s
.62053 .80005 m .61772 .78145 L .64852 .77852 L p .707 .577 .707 r
F P
0 g
s
.61842 .31351 m .59536 .81235 L .61846 .80227 L p .707 .577 .707 r
F P
0 g
s
.61846 .80227 m .64152 .30343 L .61842 .31351 L p .707 .577 .707 r
F P
0 g
s
.31972 .67305 m .30748 .72585 L .33118 .72336 L p .707 .577 .707 r
F P
0 g
s
.33118 .72336 m .34342 .67056 L .31972 .67305 L p .707 .577 .707 r
F P
0 g
s
.6953 .66592 m .68306 .71872 L .66271 .70608 L p .707 .577 .707 r
F P
0 g
s
.66271 .70608 m .67494 .65328 L .6953 .66592 L p .707 .577 .707 r
F P
0 g
s
.2508 .7733 m .25324 .73659 L .22214 .73262 L p .707 .577 .707 r
F P
0 g
s
.25324 .73659 m .2508 .7733 L .28258 .77439 L p .707 .577 .707 r
F P
0 g
s
.28258 .77439 m .28502 .73768 L .25324 .73659 L p .707 .577 .707 r
F P
0 g
s
.70867 .78462 m .71148 .80322 L .69915 .79879 L p .707 .577 .707 r
F P
0 g
s
.69915 .79879 m .69634 .78019 L .70867 .78462 L p .707 .577 .707 r
F P
0 g
s
.28502 .73768 m .28258 .77439 L .31191 .77249 L p .707 .577 .707 r
F P
0 g
s
.31191 .77249 m .31435 .73578 L .28502 .73768 L p .707 .577 .707 r
F P
0 g
s
.2197 .76933 m .22214 .73262 L .19475 .72616 L p .707 .577 .707 r
F P
0 g
s
.22214 .73262 m .2197 .76933 L .2508 .7733 L p .707 .577 .707 r
F P
0 g
s
.35463 .70763 m .36687 .65483 L .35966 .66428 L p .707 .577 .707 r
F P
0 g
s
.34494 .77541 m .34775 .79401 L .35781 .78899 L p .707 .577 .707 r
F P
0 g
s
.35781 .78899 m .36406 .78587 L p .35789 .7825 L .707 .577 .707 r
F P
0 g
s
.35789 .7825 m .34494 .77541 L .35781 .78899 L .707 .577 .707 r
F
.34743 .71708 m .35966 .66428 L .34342 .67056 L p F P
0 g
s
.34775 .79401 m .34494 .77541 L .32106 .78327 L p .707 .577 .707 r
F P
0 g
s
.33837 .73108 m .33593 .76779 L .35229 .76075 L p .707 .577 .707 r
F P
0 g
s
.35229 .76075 m .35473 .72404 L .33837 .73108 L p .707 .577 .707 r
F P
0 g
s
.35966 .66428 m .34743 .71708 L .35463 .70763 L p .707 .577 .707 r
F P
0 g
s
.36406 .78587 m .36125 .76728 L .34494 .77541 L p .707 .577 .707 r
F P
0 g
s
.34342 .67056 m .33118 .72336 L .34743 .71708 L p .707 .577 .707 r
F P
0 g
s
.35209 .69593 m .34005 .68313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.36433 .64313 m .35415 .68707 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35415 .68707 m .35209 .69593 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35541 .5041 m .36243 .40758 L .36396 .2736 L .707 .577 .707 r
F
.34005 .68313 m .35229 .63033 L .35452 .6327 L p F P
0 g
s
.35452 .6327 m .36433 .64313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.34005 .68313 m .35452 .6327 L .35433 .6596 L .707 .577 .707 r
F
.35473 .72404 m .35229 .76075 L .35939 .75206 L p F P
0 g
s
.35939 .75206 m .36182 .71535 L .35473 .72404 L p .707 .577 .707 r
F P
0 g
s
.35896 .70586 m .35652 .74257 L .34398 .7332 L p .707 .577 .707 r
F P
0 g
s
.36687 .65483 m .35463 .70763 L .35209 .69593 L p .707 .577 .707 r
F P
0 g
s
.34398 .7332 m .34641 .69649 L .35896 .70586 L p .707 .577 .707 r
F P
0 g
s
.35229 .63033 m .34005 .68313 L .3197 .67049 L p .707 .577 .707 r
F P
0 g
s
.3197 .67049 m .33193 .61769 L .35229 .63033 L p .707 .577 .707 r
F P
0 g
s
.34641 .69649 m .34398 .7332 L .32298 .72488 L p .707 .577 .707 r
F P
0 g
s
.32298 .72488 m .32542 .68817 L .34641 .69649 L p .707 .577 .707 r
F P
0 g
s
.33593 .76779 m .33837 .73108 L .31435 .73578 L p .707 .577 .707 r
F P
0 g
s
.35333 .74892 m .35582 .76535 L p .33542 .76542 L .707 .577 .707 r
F P
0 g
s
.36125 .76728 m .36406 .78587 L .3712 .77827 L p .707 .577 .707 r
F P
0 g
s
.3712 .77827 m .36839 .75968 L .36125 .76728 L p .707 .577 .707 r
F P
0 g
s
.36182 .71535 m .35939 .75206 L .35652 .74257 L p .707 .577 .707 r
F P
0 g
s
.35133 .78995 m .36271 .79803 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .36566 .75335 L .36799 .77177 L .707 .577 .707 r
F
.35713 .76605 m .36144 .75964 L .36402 .76968 L F
.36144 .75964 m .36566 .75335 L .36402 .76968 L F
.36566 .75335 m .36847 .77195 L .36799 .77177 L p F P
0 g
s
.36402 .76968 m .36271 .79803 L .37222 .80154 L p .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .35582 .76535 L .35133 .78995 L .707 .577 .707 r
F
.35209 .69593 m .36433 .64313 L .36687 .65483 L p F P
0 g
s
.35333 .74892 m .36566 .75335 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36803 .28659 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36271 .79803 m .36402 .76968 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .38577 .29919 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.35614 .76752 m .35582 .76535 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.35582 .76535 m .35333 .74892 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36799 .77177 m .35614 .76752 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36839 .75968 m .3712 .77827 L .36847 .77195 L p .707 .577 .707 r
F P
0 g
s
.36847 .77195 m .36566 .75335 L .36839 .75968 L p .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36402 .76968 L p .3924 .80898 L .707 .577 .707 r
F P
0 g
s
.37222 .80154 m .3924 .80898 L p .36402 .76968 L .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .36349 .72327 L .35582 .76535 L .707 .577 .707 r
F
.35582 .76535 m .35614 .76752 L .35543 .76745 L p F P
0 g
s
.35543 .76745 m .33542 .76542 L p .35582 .76535 L .707 .577 .707 r
F P
0 g
s
.33542 .76542 m .33261 .74682 L .35333 .74892 L p .707 .577 .707 r
F P
0 g
s
.36803 .28659 m .34497 .78544 L .35133 .78995 L p .707 .577 .707 r
F P
0 g
s
.35652 .74257 m .35896 .70586 L .36182 .71535 L p .707 .577 .707 r
F P
0 g
s
.36349 .72327 m .36803 .28659 L .35133 .78995 L .707 .577 .707 r
F
.3409 .77244 m .34497 .78544 L p .35541 .5041 L F P
0 g
s
.36396 .2736 m .35578 .45063 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35578 .45063 m .3409 .77244 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.34497 .78544 m .35496 .56935 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35496 .56935 m .36243 .40758 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.36243 .40758 m .36803 .28659 L .36406 .2739 L p .707 .577 .707 r
F P
0 g
s
.36406 .2739 m .36396 .2736 L p .36243 .40758 L .707 .577 .707 r
F P
0 g
s
.26324 .81383 m .26043 .79524 L .22962 .79816 L p .707 .577 .707 r
F P
0 g
s
.26043 .79524 m .26324 .81383 L .29474 .8087 L p .707 .577 .707 r
F P
0 g
s
.29474 .8087 m .29194 .79011 L .26043 .79524 L p .707 .577 .707 r
F P
0 g
s
.29194 .79011 m .29474 .8087 L .32387 .80187 L p .707 .577 .707 r
F P
0 g
s
.32387 .80187 m .32106 .78327 L .29194 .79011 L p .707 .577 .707 r
F P
0 g
s
.18232 .63344 m .17008 .68624 L .19044 .69888 L p .707 .577 .707 r
F P
0 g
s
.31435 .73578 m .31191 .77249 L .33593 .76779 L p .707 .577 .707 r
F P
0 g
s
.17008 .68624 m .18232 .63344 L .17028 .62064 L p .707 .577 .707 r
F P
0 g
s
.22962 .79816 m .23243 .81676 L .26324 .81383 L p .707 .577 .707 r
F P
0 g
s
.19475 .72616 m .19231 .76287 L .2197 .76933 L p .707 .577 .707 r
F P
0 g
s
.67494 .65328 m .66271 .70608 L .63602 .69482 L p .707 .577 .707 r
F P
0 g
s
.63602 .69482 m .64826 .64202 L .67494 .65328 L p .707 .577 .707 r
F P
0 g
s
.68942 .73637 m .68699 .77307 L .66599 .76475 L p .707 .577 .707 r
F P
0 g
s
.66599 .76475 m .66843 .72805 L .68942 .73637 L p .707 .577 .707 r
F P
0 g
s
.23243 .81676 m .22962 .79816 L .20253 .79859 L p .707 .577 .707 r
F P
0 g
s
.19231 .76287 m .19475 .72616 L .17375 .71784 L p .707 .577 .707 r
F P
0 g
s
.20253 .79859 m .20534 .81719 L .23243 .81676 L p .707 .577 .707 r
F P
0 g
s
.32106 .78327 m .32387 .80187 L .34775 .79401 L p .707 .577 .707 r
F P
0 g
s
.69634 .78019 m .69915 .79879 L .67843 .79669 L p .707 .577 .707 r
F P
0 g
s
.67843 .79669 m .67562 .77809 L .69634 .78019 L p .707 .577 .707 r
F P
0 g
s
.17375 .71784 m .17132 .75455 L .19231 .76287 L p .707 .577 .707 r
F P
0 g
s
.64152 .30343 m .61846 .80227 L .62847 .79014 L p .707 .577 .707 r
F P
0 g
s
.62847 .79014 m .65153 .2913 L .64152 .30343 L p .707 .577 .707 r
F P
0 g
s
.17028 .62064 m .15804 .67344 L .17008 .68624 L p .707 .577 .707 r
F P
0 g
s
.20534 .81719 m .20253 .79859 L .1818 .79649 L p .707 .577 .707 r
F P
0 g
s
.1818 .79649 m .18461 .81509 L .20534 .81719 L p .707 .577 .707 r
F P
0 g
s
.66843 .72805 m .66599 .76475 L .6386 .75829 L p .707 .577 .707 r
F P
0 g
s
.6386 .75829 m .64104 .72159 L .66843 .72805 L p .707 .577 .707 r
F P
0 g
s
.15804 .67344 m .17028 .62064 L .16774 .60894 L p .707 .577 .707 r
F P
0 g
s
.17132 .75455 m .17375 .71784 L .16121 .70848 L p .707 .577 .707 r
F P
0 g
s
.67562 .77809 m .67843 .79669 L .65133 .79712 L p .707 .577 .707 r
F P
0 g
s
.65133 .79712 m .64852 .77852 L .67562 .77809 L p .707 .577 .707 r
F P
0 g
s
.16121 .70848 m .15877 .74518 L .17132 .75455 L p .707 .577 .707 r
F P
0 g
s
.18461 .81509 m .1818 .79649 L .16947 .79206 L p .707 .577 .707 r
F P
0 g
s
.16774 .60894 m .1555 .66174 L .15804 .67344 L p .707 .577 .707 r
F P
0 g
s
.16947 .79206 m .17228 .81066 L .18461 .81509 L p .707 .577 .707 r
F P
0 g
s
.64852 .77852 m .65133 .79712 L .62053 .80005 L p .707 .577 .707 r
F P
0 g
s
.15877 .74518 m .16121 .70848 L .15835 .69898 L p .707 .577 .707 r
F P
0 g
s
.1555 .66174 m .16774 .60894 L .17494 .59949 L p .707 .577 .707 r
F P
0 g
s
.65153 .2913 m .62847 .79014 L .6244 .77714 L p .707 .577 .707 r
F P
0 g
s
.6244 .77714 m .64746 .2783 L .65153 .2913 L p .707 .577 .707 r
F P
0 g
s
.15835 .69898 m .15591 .73569 L .15877 .74518 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.3409 .77244 m .36396 .2736 L .37397 .26146 L p .707 .577 .707 r
F P
0 g
s
.17228 .81066 m .16947 .79206 L .16674 .78573 L p .707 .577 .707 r
F P
0 g
s
.17494 .59949 m .16271 .65229 L .1555 .66174 L p .707 .577 .707 r
F P
0 g
s
.16674 .78573 m .16955 .80433 L .17228 .81066 L p .707 .577 .707 r
F P
0 g
s
.15591 .73569 m .15835 .69898 L .16544 .69029 L p .707 .577 .707 r
F P
0 g
s
.16271 .65229 m .17494 .59949 L .19119 .59321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16544 .69029 m .163 .727 L .15591 .73569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64746 .2783 m .6244 .77714 L .60666 .76455 L p .707 .577 .707 r
F P
0 g
s
.60666 .76455 m .62971 .26571 L .64746 .2783 L p .707 .577 .707 r
F P
0 g
s
.19119 .59321 m .17896 .64601 L .16271 .65229 L p .707 .577 .707 r
F P
0 g
s
.16955 .80433 m .16674 .78573 L .17388 .77813 L p .707 .577 .707 r
F P
0 g
s
.17388 .77813 m .17669 .79673 L .16955 .80433 L p .707 .577 .707 r
F P
0 g
s
.17896 .64601 m .19119 .59321 L .21489 .59072 L p .707 .577 .707 r
F P
0 g
s
.163 .727 m .16544 .69029 L .1818 .68325 L p .707 .577 .707 r
F P
0 g
s
.35091 .76031 m .37397 .26146 L .39707 .25139 L p .707 .577 .707 r
F P
0 g
s
.37397 .26146 m .35091 .76031 L .3409 .77244 L p .707 .577 .707 r
F P
0 g
s
.1818 .68325 m .17936 .71996 L .163 .727 L p .707 .577 .707 r
F P
0 g
s
.21489 .59072 m .20265 .64352 L .17896 .64601 L p .707 .577 .707 r
F P
0 g
s
.20265 .64352 m .21489 .59072 L .24372 .59225 L p .707 .577 .707 r
F P
0 g
s
.33193 .61769 m .3197 .67049 L .29301 .65923 L p .707 .577 .707 r
F P
0 g
s
.29301 .65923 m .30525 .60643 L .33193 .61769 L p .707 .577 .707 r
F P
0 g
s
.17669 .79673 m .17388 .77813 L .19019 .77 L p .707 .577 .707 r
F P
0 g
s
.19019 .77 m .193 .7886 L .17669 .79673 L p .707 .577 .707 r
F P
0 g
s
.62971 .26571 m .60666 .76455 L .57697 .7536 L p .707 .577 .707 r
F P
0 g
s
.57697 .7536 m .60003 .25475 L .62971 .26571 L p .707 .577 .707 r
F P
0 g
s
.17936 .71996 m .1818 .68325 L .20582 .67855 L p .707 .577 .707 r
F P
0 g
s
.23148 .64505 m .24372 .59225 L .27485 .59767 L p .707 .577 .707 r
F P
0 g
s
.24372 .59225 m .23148 .64505 L .20265 .64352 L p .707 .577 .707 r
F P
0 g
s
.30525 .60643 m .29301 .65923 L .26262 .65047 L p .707 .577 .707 r
F P
0 g
s
.26262 .65047 m .27485 .59767 L .30525 .60643 L p .707 .577 .707 r
F P
0 g
s
.27485 .59767 m .26262 .65047 L .23148 .64505 L p .707 .577 .707 r
F P
0 g
s
.20582 .67855 m .20338 .71526 L .17936 .71996 L p .707 .577 .707 r
F P
0 g
s
.39707 .25139 m .37401 .75023 L .35091 .76031 L p .707 .577 .707 r
F P
0 g
s
.37401 .75023 m .39707 .25139 L .431 .24435 L p .707 .577 .707 r
F P
0 g
s
.32542 .68817 m .32298 .72488 L .29559 .71842 L p .707 .577 .707 r
F P
0 g
s
.29559 .71842 m .29803 .68171 L .32542 .68817 L p .707 .577 .707 r
F P
0 g
s
.72773 .66246 m .73997 .60966 L .70957 .60089 L p .707 .577 .707 r
F P
0 g
s
.73997 .60966 m .72773 .66246 L .75887 .66787 L p .707 .577 .707 r
F P
0 g
s
.75887 .66787 m .7711 .61507 L .73997 .60966 L p .707 .577 .707 r
F P
0 g
s
.20338 .71526 m .20582 .67855 L .23515 .67665 L p .707 .577 .707 r
F P
0 g
s
.193 .7886 m .19019 .77 L .21408 .76213 L p .707 .577 .707 r
F P
0 g
s
.69734 .65369 m .70957 .60089 L .68289 .58964 L p .707 .577 .707 r
F P
0 g
s
.70957 .60089 m .69734 .65369 L .72773 .66246 L p .707 .577 .707 r
F P
0 g
s
.7711 .61507 m .75887 .66787 L .7877 .6694 L p .707 .577 .707 r
F P
0 g
s
.7877 .6694 m .79993 .6166 L .7711 .61507 L p .707 .577 .707 r
F P
0 g
s
.21408 .76213 m .21689 .78073 L .193 .7886 L p .707 .577 .707 r
F P
0 g
s
.33261 .74682 m .33542 .76542 L .30832 .76585 L p .707 .577 .707 r
F P
0 g
s
.30832 .76585 m .30551 .74725 L .33261 .74682 L p .707 .577 .707 r
F P
0 g
s
.29803 .68171 m .29559 .71842 L .26449 .71445 L p .707 .577 .707 r
F P
0 g
s
.26449 .71445 m .26693 .67774 L .29803 .68171 L p .707 .577 .707 r
F P
0 g
s
.60003 .25475 m .57697 .7536 L .53826 .74535 L p .707 .577 .707 r
F P
0 g
s
.53826 .74535 m .56131 .24651 L .60003 .25475 L p .707 .577 .707 r
F P
0 g
s
.23515 .67665 m .23272 .71336 L .20338 .71526 L p .707 .577 .707 r
F P
0 g
s
.23272 .71336 m .23515 .67665 L .26693 .67774 L p .707 .577 .707 r
F P
0 g
s
.67065 .64244 m .68289 .58964 L .66253 .57699 L p .707 .577 .707 r
F P
0 g
s
.68289 .58964 m .67065 .64244 L .69734 .65369 L p .707 .577 .707 r
F P
0 g
s
.79993 .6166 m .7877 .6694 L .81139 .66691 L p .707 .577 .707 r
F P
0 g
s
.81139 .66691 m .82363 .61411 L .79993 .6166 L p .707 .577 .707 r
F P
0 g
s
.26693 .67774 m .26449 .71445 L .23272 .71336 L p .707 .577 .707 r
F P
0 g
s
.40795 .74319 m .431 .24435 L .47245 .24104 L p .707 .577 .707 r
F P
0 g
s
.431 .24435 m .40795 .74319 L .37401 .75023 L p .707 .577 .707 r
F P
0 g
s
.73102 .72113 m .73346 .68443 L .70235 .68046 L p .707 .577 .707 r
F P
0 g
s
.73346 .68443 m .73102 .72113 L .76279 .72222 L p .707 .577 .707 r
F P
0 g
s
.76279 .72222 m .76523 .68552 L .73346 .68443 L p .707 .577 .707 r
F P
0 g
s
.21689 .78073 m .21408 .76213 L .2432 .7553 L p .707 .577 .707 r
F P
0 g
s
.76523 .68552 m .76279 .72222 L .79213 .72032 L p .707 .577 .707 r
F P
0 g
s
.79213 .72032 m .79456 .68362 L .76523 .68552 L p .707 .577 .707 r
F P
0 g
s
.2432 .7553 m .24601 .7739 L .21689 .78073 L p .707 .577 .707 r
F P
0 g
s
.30551 .74725 m .30832 .76585 L .27752 .76877 L p .707 .577 .707 r
F P
0 g
s
.27752 .76877 m .27471 .75017 L .30551 .74725 L p .707 .577 .707 r
F P
0 g
s
.69991 .71716 m .70235 .68046 L .67496 .674 L p .707 .577 .707 r
F P
0 g
s
.70235 .68046 m .69991 .71716 L .73102 .72113 L p .707 .577 .707 r
F P
0 g
s
.74345 .75307 m .74064 .73447 L .70983 .7374 L p .707 .577 .707 r
F P
0 g
s
.74064 .73447 m .74345 .75307 L .77496 .74794 L p .707 .577 .707 r
F P
0 g
s
.77496 .74794 m .77215 .72934 L .74064 .73447 L p .707 .577 .707 r
F P
0 g
s
.24601 .7739 m .2432 .7553 L .27471 .75017 L p .707 .577 .707 r
F P
0 g
s
.77215 .72934 m .77496 .74794 L .80408 .74111 L p .707 .577 .707 r
F P
0 g
s
.80408 .74111 m .80127 .72251 L .77215 .72934 L p .707 .577 .707 r
F P
0 g
s
.56131 .24651 m .53826 .74535 L .49429 .74063 L p .707 .577 .707 r
F P
0 g
s
.49429 .74063 m .51735 .24178 L .56131 .24651 L p .707 .577 .707 r
F P
0 g
s
.27471 .75017 m .27752 .76877 L .24601 .7739 L p .707 .577 .707 r
F P
0 g
s
.66253 .57699 m .6503 .62979 L .67065 .64244 L p .707 .577 .707 r
F P
0 g
s
.70983 .7374 m .71264 .75599 L .74345 .75307 L p .707 .577 .707 r
F P
0 g
s
.6503 .62979 m .66253 .57699 L .65049 .56419 L p .707 .577 .707 r
F P
0 g
s
.79456 .68362 m .79213 .72032 L .81615 .71563 L p .707 .577 .707 r
F P
0 g
s
.81615 .71563 m .81858 .67892 L .79456 .68362 L p .707 .577 .707 r
F P
0 g
s
.82363 .61411 m .81139 .66691 L .82764 .66063 L p .707 .577 .707 r
F P
0 g
s
.82764 .66063 m .83988 .60783 L .82363 .61411 L p .707 .577 .707 r
F P
0 g
s
.67496 .674 m .67252 .7107 L .69991 .71716 L p .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .45925 .52659 L .48577 .47325 L .707 .577 .707 r
F
.43195 .71667 m .45101 .7122 L p .45012 .71163 L F P
0 g
s
.47245 .24104 m .45376 .64546 L p .41122 .71767 L .707 .577 .707 r
F P
0 g
s
.45376 .64546 m .4507 .71154 L p .43162 .7145 L .707 .577 .707 r
F P
0 g
s
.41122 .71767 m .45376 .64546 L .43162 .7145 L .707 .577 .707 r
F
.44939 .73988 m .40795 .74319 L p .41122 .71767 L F P
0 g
s
.43087 .71684 m .43195 .71667 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.43162 .7145 m .43195 .71667 L p .45012 .71163 L .707 .577 .707 r
F P
0 g
s
.44767 .7049 m .42914 .69807 L .45101 .7122 L .707 .577 .707 r
F
.4507 .71154 m .44939 .73988 L p .42756 .72717 L F P
0 g
s
.41122 .71767 m .43162 .7145 L .42756 .72717 L .707 .577 .707 r
F
.43195 .71667 m .43162 .7145 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .4507 .71154 L .42756 .72717 L .707 .577 .707 r
F
.42914 .69807 m .39763 .7032 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .42914 .69807 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.39763 .7032 m .40044 .7218 L .43087 .71684 L p .707 .577 .707 r
F P
0 g
s
.43104 .71631 m .39763 .7032 L .43087 .71684 L .707 .577 .707 r
F
.42914 .69807 m .43162 .7145 L p .45012 .71163 L F P
0 g
s
.44939 .73988 m .4507 .71154 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.4507 .71154 m .45925 .52659 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.51735 .24178 m .49429 .74063 L .46378 .74012 L p .707 .577 .707 r
F P
0 g
s
.46378 .74012 m .44939 .73988 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .51735 .24178 L .46378 .74012 L .707 .577 .707 r
F
.46107 .70983 m .45826 .69124 L .44305 .6948 L p F P
0 g
s
.44305 .6948 m .42914 .69807 L p .44767 .7049 L .707 .577 .707 r
F P
0 g
s
.46107 .70983 m .44305 .6948 L .44767 .7049 L .707 .577 .707 r
F
.45101 .7122 m .46107 .70983 L p .44767 .7049 L F P
0 g
s
.44469 .63381 m .45692 .58101 L .43283 .57973 L p .707 .577 .707 r
F P
0 g
s
.43283 .57973 m .42809 .57948 L p .42995 .58554 L .707 .577 .707 r
F P
0 g
s
.44469 .63381 m .43283 .57973 L .42995 .58554 L .707 .577 .707 r
F
.47245 .24104 m .51735 .24178 L p .48577 .47325 L F P
0 g
s
.45925 .52659 m .47245 .24104 L p .48577 .47325 L .707 .577 .707 r
F P
0 g
s
.71264 .75599 m .70983 .7374 L .68274 .73783 L p .707 .577 .707 r
F P
0 g
s
.67252 .7107 m .67496 .674 L .65397 .66568 L p .707 .577 .707 r
F P
0 g
s
.68274 .73783 m .68555 .75643 L .71264 .75599 L p .707 .577 .707 r
F P
0 g
s
.80127 .72251 m .80408 .74111 L .82796 .73324 L p .707 .577 .707 r
F P
0 g
s
.82796 .73324 m .82515 .71464 L .80127 .72251 L p .707 .577 .707 r
F P
0 g
s
.65397 .66568 m .65153 .70238 L .67252 .7107 L p .707 .577 .707 r
F P
0 g
s
.65049 .56419 m .63826 .61699 L .6503 .62979 L p .707 .577 .707 r
F P
0 g
s
.68555 .75643 m .68274 .73783 L .66202 .73573 L p .707 .577 .707 r
F P
0 g
s
.81858 .67892 m .81615 .71563 L .83251 .70859 L p .707 .577 .707 r
F P
0 g
s
.83251 .70859 m .83494 .67188 L .81858 .67892 L p .707 .577 .707 r
F P
0 g
s
.66202 .73573 m .66482 .75432 L .68555 .75643 L p .707 .577 .707 r
F P
0 g
s
.63826 .61699 m .65049 .56419 L .64795 .5525 L p .707 .577 .707 r
F P
0 g
s
.83988 .60783 m .82764 .66063 L .83485 .65118 L p .707 .577 .707 r
F P
0 g
s
.83485 .65118 m .84708 .59838 L .83988 .60783 L p .707 .577 .707 r
F P
0 g
s
.82515 .71464 m .82796 .73324 L .84428 .72511 L p .707 .577 .707 r
F P
0 g
s
.84428 .72511 m .84147 .70651 L .82515 .71464 L p .707 .577 .707 r
F P
0 g
s
.65153 .70238 m .65397 .66568 L .64142 .65631 L p .707 .577 .707 r
F P
0 g
s
.64142 .65631 m .63899 .69302 L .65153 .70238 L p .707 .577 .707 r
F P
0 g
s
.66482 .75432 m .66202 .73573 L .64968 .73129 L p .707 .577 .707 r
F P
0 g
s
.64795 .5525 m .63572 .6053 L .63826 .61699 L p .707 .577 .707 r
F P
0 g
s
.83494 .67188 m .83251 .70859 L .8396 .69989 L p .707 .577 .707 r
F P
0 g
s
.8396 .69989 m .84204 .66319 L .83494 .67188 L p .707 .577 .707 r
F P
0 g
s
.64968 .73129 m .65249 .74989 L .66482 .75432 L p .707 .577 .707 r
F P
0 g
s
.84147 .70651 m .84428 .72511 L .85142 .71751 L p .707 .577 .707 r
F P
0 g
s
.85142 .71751 m .84861 .69891 L .84147 .70651 L p .707 .577 .707 r
F P
0 g
s
.63899 .69302 m .64142 .65631 L .63856 .64682 L p .707 .577 .707 r
F P
0 g
s
.63572 .6053 m .64795 .5525 L .65516 .54304 L p .707 .577 .707 r
F P
0 g
s
.84708 .59838 m .83485 .65118 L .83231 .63948 L p .707 .577 .707 r
F P
0 g
s
.83231 .63948 m .84454 .58668 L .84708 .59838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63856 .64682 m .63612 .68352 L .63899 .69302 L p .707 .577 .707 r
F P
0 g
s
.65249 .74989 m .64968 .73129 L .64696 .72497 L p .707 .577 .707 r
F P
0 g
s
.65516 .54304 m .64292 .59584 L .63572 .6053 L p .707 .577 .707 r
F P
0 g
s
.84204 .66319 m .8396 .69989 L .83673 .6904 L p .707 .577 .707 r
F P
0 g
s
.83673 .6904 m .83917 .65369 L .84204 .66319 L p .707 .577 .707 r
F P
0 g
s
.64696 .72497 m .64977 .74357 L .65249 .74989 L p .707 .577 .707 r
F P
0 g
s
.84861 .69891 m .85142 .71751 L .84869 .71118 L p .707 .577 .707 r
F P
0 g
s
.84869 .71118 m .84588 .69259 L .84861 .69891 L p .707 .577 .707 r
F P
0 g
s
.64292 .59584 m .65516 .54304 L .6714 .53676 L p .707 .577 .707 r
F P
0 g
s
.63612 .68352 m .63856 .64682 L .64565 .63813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84454 .58668 m .83231 .63948 L .82027 .62668 L p .707 .577 .707 r
F P
0 g
s
.82027 .62668 m .8325 .57388 L .84454 .58668 L p .707 .577 .707 r
F P
0 g
s
.38472 .62687 m .39696 .57407 L .36656 .5653 L p .707 .577 .707 r
F P
0 g
s
.39696 .57407 m .38472 .62687 L .41586 .63228 L p .707 .577 .707 r
F P
0 g
s
.41586 .63228 m .42809 .57948 L .39696 .57407 L p .707 .577 .707 r
F P
0 g
s
.64565 .63813 m .64322 .67483 L .63612 .68352 L p .707 .577 .707 r
F P
0 g
s
.35433 .6181 m .36656 .5653 L .33988 .55405 L p .707 .577 .707 r
F P
0 g
s
.36656 .5653 m .35433 .6181 L .38472 .62687 L p .707 .577 .707 r
F P
0 g
s
.42809 .57948 m .41586 .63228 L .44469 .63381 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64977 .74357 m .64696 .72497 L .6541 .71737 L p .707 .577 .707 r
F P
0 g
s
.6714 .53676 m .65917 .58956 L .64292 .59584 L p .707 .577 .707 r
F P
0 g
s
.83917 .65369 m .83673 .6904 L .82419 .68104 L p .707 .577 .707 r
F P
0 g
s
.82419 .68104 m .82663 .64433 L .83917 .65369 L p .707 .577 .707 r
F P
0 g
s
.6541 .71737 m .65691 .73597 L .64977 .74357 L p .707 .577 .707 r
F P
0 g
s
.32764 .60685 m .33988 .55405 L .31952 .5414 L p .707 .577 .707 r
F P
0 g
s
.33988 .55405 m .32764 .60685 L .35433 .6181 L p .707 .577 .707 r
F P
0 g
s
.45692 .58101 m .44469 .63381 L .46838 .63132 L p .707 .577 .707 r
F P
0 g
s
.46838 .63132 m .48062 .57852 L .45692 .58101 L p .707 .577 .707 r
F P
0 g
s
.65917 .58956 m .6714 .53676 L .6951 .53427 L p .707 .577 .707 r
F P
0 g
s
.8325 .57388 m .82027 .62668 L .79991 .61404 L p .707 .577 .707 r
F P
0 g
s
.79991 .61404 m .81215 .56124 L .8325 .57388 L p .707 .577 .707 r
F P
0 g
s
.38801 .68126 m .39045 .64455 L .35934 .64058 L p .707 .577 .707 r
F P
0 g
s
.39045 .64455 m .38801 .68126 L .41978 .68235 L p .707 .577 .707 r
F P
0 g
s
.41978 .68235 m .42222 .64564 L .39045 .64455 L p .707 .577 .707 r
F P
0 g
s
.84588 .69259 m .84869 .71118 L .83636 .70675 L p .707 .577 .707 r
F P
0 g
s
.83636 .70675 m .83355 .68816 L .84588 .69259 L p .707 .577 .707 r
F P
0 g
s
.64322 .67483 m .64565 .63813 L .66201 .63109 L p .707 .577 .707 r
F P
0 g
s
.42222 .64564 m .41978 .68235 L .44912 .68045 L p .707 .577 .707 r
F P
0 g
s
.44912 .68045 m .45155 .64374 L .42222 .64564 L p .707 .577 .707 r
F P
0 g
s
.3569 .67729 m .35934 .64058 L .33195 .63412 L p .707 .577 .707 r
F P
0 g
s
.35934 .64058 m .3569 .67729 L .38801 .68126 L p .707 .577 .707 r
F P
0 g
s
.66201 .63109 m .65957 .66779 L .64322 .67483 L p .707 .577 .707 r
F P
0 g
s
.40044 .7218 m .39763 .7032 L .36682 .70612 L p .707 .577 .707 r
F P
0 g
s
.31952 .5414 m .30729 .5942 L .32764 .60685 L p .707 .577 .707 r
F P
0 g
s
.45155 .64374 m .44912 .68045 L .47314 .67575 L p .707 .577 .707 r
F P
0 g
s
.47314 .67575 m .47557 .63905 L .45155 .64374 L p .707 .577 .707 r
F P
0 g
s
.30729 .5942 m .31952 .5414 L .30748 .5286 L p .707 .577 .707 r
F P
0 g
s
.6951 .53427 m .68287 .58707 L .65917 .58956 L p .707 .577 .707 r
F P
0 g
s
.36682 .70612 m .36963 .72472 L .40044 .7218 L p .707 .577 .707 r
F P
0 g
s
.33195 .63412 m .32951 .67083 L .3569 .67729 L p .707 .577 .707 r
F P
0 g
s
.48062 .57852 m .46838 .63132 L .48463 .62504 L p .707 .577 .707 r
F P
0 g
s
.48463 .62504 m .49687 .57224 L .48062 .57852 L p .707 .577 .707 r
F P
0 g
s
.68287 .58707 m .6951 .53427 L .72393 .5358 L p .707 .577 .707 r
F P
0 g
s
.81215 .56124 m .79991 .61404 L .77323 .60278 L p .707 .577 .707 r
F P
0 g
s
.77323 .60278 m .78546 .54998 L .81215 .56124 L p .707 .577 .707 r
F P
0 g
s
.65691 .73597 m .6541 .71737 L .67041 .70924 L p .707 .577 .707 r
F P
0 g
s
.82663 .64433 m .82419 .68104 L .8032 .67272 L p .707 .577 .707 r
F P
0 g
s
.8032 .67272 m .80563 .63601 L .82663 .64433 L p .707 .577 .707 r
F P
0 g
s
.36963 .72472 m .36682 .70612 L .33973 .70655 L p .707 .577 .707 r
F P
0 g
s
.32951 .67083 m .33195 .63412 L .31096 .6258 L p .707 .577 .707 r
F P
0 g
s
.67041 .70924 m .67322 .72784 L .65691 .73597 L p .707 .577 .707 r
F P
0 g
s
.33973 .70655 m .34254 .72515 L .36963 .72472 L p .707 .577 .707 r
F P
0 g
s
.45826 .69124 m .46107 .70983 L .48495 .70197 L p .707 .577 .707 r
F P
0 g
s
.48495 .70197 m .48214 .68337 L .45826 .69124 L p .707 .577 .707 r
F P
0 g
s
.65957 .66779 m .66201 .63109 L .68603 .62639 L p .707 .577 .707 r
F P
0 g
s
.83355 .68816 m .83636 .70675 L .81563 .70465 L p .707 .577 .707 r
F P
0 g
s
.81563 .70465 m .81282 .68605 L .83355 .68816 L p .707 .577 .707 r
F P
0 g
s
.71169 .5886 m .72393 .5358 L .75507 .54122 L p .707 .577 .707 r
F P
0 g
s
.72393 .5358 m .71169 .5886 L .68287 .58707 L p .707 .577 .707 r
F P
0 g
s
.78546 .54998 m .77323 .60278 L .74283 .59402 L p .707 .577 .707 r
F P
0 g
s
.74283 .59402 m .75507 .54122 L .78546 .54998 L p .707 .577 .707 r
F P
0 g
s
.31096 .6258 m .30852 .66251 L .32951 .67083 L p .707 .577 .707 r
F P
0 g
s
.47557 .63905 m .47314 .67575 L .4895 .66871 L p .707 .577 .707 r
F P
0 g
s
.4895 .66871 m .49193 .63201 L .47557 .63905 L p .707 .577 .707 r
F P
0 g
s
.30748 .5286 m .29525 .5814 L .30729 .5942 L p .707 .577 .707 r
F P
0 g
s
.75507 .54122 m .74283 .59402 L .71169 .5886 L p .707 .577 .707 r
F P
0 g
s
.34254 .72515 m .33973 .70655 L .31901 .70445 L p .707 .577 .707 r
F P
0 g
s
.68603 .62639 m .6836 .66309 L .65957 .66779 L p .707 .577 .707 r
F P
0 g
s
.31901 .70445 m .32181 .72305 L .34254 .72515 L p .707 .577 .707 r
F P
0 g
s
.80563 .63601 m .8032 .67272 L .77581 .66625 L p .707 .577 .707 r
F P
0 g
s
.77581 .66625 m .77824 .62955 L .80563 .63601 L p .707 .577 .707 r
F P
0 g
s
.29525 .5814 m .30748 .5286 L .30494 .51691 L p .707 .577 .707 r
F P
0 g
s
.30852 .66251 m .31096 .6258 L .29841 .61644 L p .707 .577 .707 r
F P
0 g
s
.49687 .57224 m .48463 .62504 L .49184 .61559 L p .707 .577 .707 r
F P
0 g
s
.49184 .61559 m .50407 .56279 L .49687 .57224 L p .707 .577 .707 r
F P
0 g
s
.67322 .72784 m .67041 .70924 L .69429 .70137 L p .707 .577 .707 r
F P
0 g
s
.48214 .68337 m .48495 .70197 L .50127 .69384 L p .707 .577 .707 r
F P
0 g
s
.50127 .69384 m .49846 .67524 L .48214 .68337 L p .707 .577 .707 r
F P
0 g
s
.6836 .66309 m .68603 .62639 L .71537 .62449 L p .707 .577 .707 r
F P
0 g
s
.69429 .70137 m .6971 .71997 L .67322 .72784 L p .707 .577 .707 r
F P
0 g
s
.81282 .68605 m .81563 .70465 L .78854 .70508 L p .707 .577 .707 r
F P
0 g
s
.78854 .70508 m .78573 .68649 L .81282 .68605 L p .707 .577 .707 r
F P
0 g
s
.29841 .61644 m .29598 .65314 L .30852 .66251 L p .707 .577 .707 r
F P
0 g
s
.77824 .62955 m .77581 .66625 L .7447 .66228 L p .707 .577 .707 r
F P
0 g
s
.7447 .66228 m .74714 .62558 L .77824 .62955 L p .707 .577 .707 r
F P
0 g
s
.71537 .62449 m .71293 .6612 L .6836 .66309 L p .707 .577 .707 r
F P
0 g
s
.71293 .6612 m .71537 .62449 L .74714 .62558 L p .707 .577 .707 r
F P
0 g
s
.32181 .72305 m .31901 .70445 L .30667 .70002 L p .707 .577 .707 r
F P
0 g
s
.49193 .63201 m .4895 .66871 L .49659 .66002 L p .707 .577 .707 r
F P
0 g
s
.49659 .66002 m .49903 .62331 L .49193 .63201 L p .707 .577 .707 r
F P
0 g
s
.30494 .51691 m .29271 .56971 L .29525 .5814 L p .707 .577 .707 r
F P
0 g
s
.74714 .62558 m .7447 .66228 L .71293 .6612 L p .707 .577 .707 r
F P
0 g
s
.6971 .71997 m .69429 .70137 L .72341 .69454 L p .707 .577 .707 r
F P
0 g
s
.30667 .70002 m .30948 .71862 L .32181 .72305 L p .707 .577 .707 r
F P
0 g
s
.72341 .69454 m .72622 .71314 L .6971 .71997 L p .707 .577 .707 r
F P
0 g
s
.78573 .68649 m .78854 .70508 L .75773 .70801 L p .707 .577 .707 r
F P
0 g
s
.75773 .70801 m .75492 .68941 L .78573 .68649 L p .707 .577 .707 r
F P
0 g
s
.29598 .65314 m .29841 .61644 L .29555 .60694 L p .707 .577 .707 r
F P
0 g
s
.49846 .67524 m .50127 .69384 L .50841 .68623 L p .707 .577 .707 r
F P
0 g
s
.50841 .68623 m .5056 .66764 L .49846 .67524 L p .707 .577 .707 r
F P
0 g
s
.29271 .56971 m .30494 .51691 L .31215 .50745 L p .707 .577 .707 r
F P
0 g
s
.50407 .56279 m .49184 .61559 L .4893 .60389 L p .707 .577 .707 r
F P
0 g
s
.4893 .60389 m .50153 .55109 L .50407 .56279 L p .707 .577 .707 r
F P
0 g
s
.72622 .71314 m .72341 .69454 L .75492 .68941 L p .707 .577 .707 r
F P
0 g
s
.75492 .68941 m .75773 .70801 L .72622 .71314 L p .707 .577 .707 r
F P
0 g
s
.29555 .60694 m .29311 .64365 L .29598 .65314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30948 .71862 m .30667 .70002 L .30395 .6937 L p .707 .577 .707 r
F P
0 g
s
.49903 .62331 m .49659 .66002 L .49372 .65053 L p .707 .577 .707 r
F P
0 g
s
.49372 .65053 m .49616 .61382 L .49903 .62331 L p .707 .577 .707 r
F P
0 g
s
.31215 .50745 m .29991 .56025 L .29271 .56971 L p .707 .577 .707 r
F P
0 g
s
.30395 .6937 m .30675 .71229 L .30948 .71862 L p .707 .577 .707 r
F P
0 g
s
.29311 .64365 m .29555 .60694 L .30264 .59825 L p .707 .577 .707 r
F P
0 g
s
.5056 .66764 m .50841 .68623 L .50568 .67991 L p .707 .577 .707 r
F P
0 g
s
.50568 .67991 m .50287 .66131 L .5056 .66764 L p .707 .577 .707 r
F P
0 g
s
.29991 .56025 m .31215 .50745 L .32839 .50117 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50153 .55109 m .4893 .60389 L .47726 .59109 L p .707 .577 .707 r
F P
0 g
s
.47726 .59109 m .48949 .53829 L .50153 .55109 L p .707 .577 .707 r
F P
0 g
s
.30264 .59825 m .30021 .63496 L .29311 .64365 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32839 .50117 m .31616 .55397 L .29991 .56025 L p .707 .577 .707 r
F P
0 g
s
.30675 .71229 m .30395 .6937 L .31109 .6861 L p .707 .577 .707 r
F P
0 g
s
.49616 .61382 m .49372 .65053 L .48118 .64116 L p .707 .577 .707 r
F P
0 g
s
.48118 .64116 m .48362 .60445 L .49616 .61382 L p .707 .577 .707 r
F P
0 g
s
.31109 .6861 m .3139 .70469 L .30675 .71229 L p .707 .577 .707 r
F P
0 g
s
.31616 .55397 m .32839 .50117 L .35209 .49868 L p .707 .577 .707 r
F P
0 g
s
.48949 .53829 m .47726 .59109 L .4569 .57845 L p .707 .577 .707 r
F P
0 g
s
.4569 .57845 m .46914 .52565 L .48949 .53829 L p .707 .577 .707 r
F P
0 g
s
.30021 .63496 m .30264 .59825 L .319 .59121 L p .707 .577 .707 r
F P
0 g
s
.50287 .66131 m .50568 .67991 L .49335 .67548 L p .707 .577 .707 r
F P
0 g
s
.49335 .67548 m .49054 .65688 L .50287 .66131 L p .707 .577 .707 r
F P
0 g
s
.319 .59121 m .31656 .62792 L .30021 .63496 L p .707 .577 .707 r
F P
0 g
s
.35209 .49868 m .33986 .55148 L .31616 .55397 L p .707 .577 .707 r
F P
0 g
s
.33986 .55148 m .35209 .49868 L .38092 .50021 L p .707 .577 .707 r
F P
0 g
s
.48362 .60445 m .48118 .64116 L .46019 .63284 L p .707 .577 .707 r
F P
0 g
s
.46019 .63284 m .46262 .59613 L .48362 .60445 L p .707 .577 .707 r
F P
0 g
s
.46914 .52565 m .4569 .57845 L .43022 .56719 L p .707 .577 .707 r
F P
0 g
s
.43022 .56719 m .44245 .51439 L .46914 .52565 L p .707 .577 .707 r
F P
0 g
s
.3139 .70469 m .31109 .6861 L .3274 .67796 L p .707 .577 .707 r
F P
0 g
s
.3274 .67796 m .33021 .69656 L .3139 .70469 L p .707 .577 .707 r
F P
0 g
s
.31656 .62792 m .319 .59121 L .34302 .58651 L p .707 .577 .707 r
F P
0 g
s
.49054 .65688 m .49335 .67548 L .47262 .67338 L p .707 .577 .707 r
F P
0 g
s
.47262 .67338 m .46981 .65478 L .49054 .65688 L p .707 .577 .707 r
F P
0 g
s
.36868 .55301 m .38092 .50021 L .41206 .50563 L p .707 .577 .707 r
F P
0 g
s
.38092 .50021 m .36868 .55301 L .33986 .55148 L p .707 .577 .707 r
F P
0 g
s
.44245 .51439 m .43022 .56719 L .39982 .55843 L p .707 .577 .707 r
F P
0 g
s
.39982 .55843 m .41206 .50563 L .44245 .51439 L p .707 .577 .707 r
F P
0 g
s
.41206 .50563 m .39982 .55843 L .36868 .55301 L p .707 .577 .707 r
F P
0 g
s
.34302 .58651 m .34058 .62322 L .31656 .62792 L p .707 .577 .707 r
F P
0 g
s
.46262 .59613 m .46019 .63284 L .4328 .62638 L p .707 .577 .707 r
F P
0 g
s
.4328 .62638 m .43523 .58967 L .46262 .59613 L p .707 .577 .707 r
F P
0 g
s
.34058 .62322 m .34302 .58651 L .37236 .58461 L p .707 .577 .707 r
F P
0 g
s
.33021 .69656 m .3274 .67796 L .35128 .6701 L p .707 .577 .707 r
F P
0 g
s
.35128 .6701 m .35409 .68869 L .33021 .69656 L p .707 .577 .707 r
F P
0 g
s
.46981 .65478 m .47262 .67338 L .44553 .67381 L p .707 .577 .707 r
F P
0 g
s
.44553 .67381 m .44272 .65521 L .46981 .65478 L p .707 .577 .707 r
F P
0 g
s
.43523 .58967 m .4328 .62638 L .40169 .62241 L p .707 .577 .707 r
F P
0 g
s
.40169 .62241 m .40413 .5857 L .43523 .58967 L p .707 .577 .707 r
F P
0 g
s
.37236 .58461 m .36992 .62132 L .34058 .62322 L p .707 .577 .707 r
F P
0 g
s
.36992 .62132 m .37236 .58461 L .40413 .5857 L p .707 .577 .707 r
F P
0 g
s
.40413 .5857 m .40169 .62241 L .36992 .62132 L p .707 .577 .707 r
F P
0 g
s
.35409 .68869 m .35128 .6701 L .3804 .66326 L p .707 .577 .707 r
F P
0 g
s
.3804 .66326 m .38321 .68186 L .35409 .68869 L p .707 .577 .707 r
F P
0 g
s
.44272 .65521 m .44553 .67381 L .41472 .67673 L p .707 .577 .707 r
F P
0 g
s
.41472 .67673 m .41191 .65813 L .44272 .65521 L p .707 .577 .707 r
F P
0 g
s
.38321 .68186 m .3804 .66326 L .41191 .65813 L p .707 .577 .707 r
F P
0 g
s
.41191 .65813 m .41472 .67673 L .38321 .68186 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00PGoo001cOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001kOol0071oo`<000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00KWoo0`002EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001/Ool20002FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000
Kgoo001ZOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH01000FUIJEUYF0`00K7oo001YOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001ZOol0
06Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Qoo`00Igoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF001WOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00IGoo001W
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001W
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00Hgoo001VOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0HGoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo
001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001QOol7
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005aoo`D000=JEP04001JEUYFFUH90005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol005Yoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPH000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00F7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YF000000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Ioo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001GOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0035YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001FOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00EGoo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`L005Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo10000eYF00@005YFFUIJ
EPT004]oo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8000Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF009JEPH0
04Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0017oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P00@Woo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<003moo`00E7oo00<0
05YF00000UYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`00?7oo001DOol20003FUH40003FUH200000goo000000080004FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YF000003Yoo`00E7oo0P0000AJEP00000000IJEP04001JEP000002FUH0
0`00FUIJEP03FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00>7oo001DOol00eYF
00000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`001EYF00<005YFFUH00`0000AJEP00000000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`000UYF00<005YF000010000eYF0`0000=JEP00FUH01UYF00<005YF
FUH015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000goo00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3000dOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEP0000800003FUH0000000<0009JEP04001JEUYFFUH30006FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003Ool00000
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF000cOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPL0009JEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH0000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPL000QJEP80
0003FUH005YF00EJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo02ioo`00Dgoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF0P00
1UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001JEUYFFUH005YF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000002eoo`00E7oo00@005YFFUH000IJEP03001JEP0001H0009JEP03001JEUYF00EJEP04
001JEUYF0003FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02Yoo`00EGoo0`0015YF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF00@005YFFUIJEP<000AJEP<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEPD0009JEP<0009oo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo
02Yoo`00=Goo5@003Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`0000EJEP00001JEP0000IJEP04001JEP000009Ool60007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000cOol200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60008Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20002FUH01000FUH0000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000Uo
o`<00003Ool0000000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool0035o
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000004Ool20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH015YF0`001Goo1@00
0Woo0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEP000080009oo`D000Eoo`<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`0027oo0P0015YF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000/Ool002moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF1P0027oo0`0000=JEP00FUH01EYF00@005YFFUIJEP8002eoo`00;goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00=oo`8000IJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`0015YF00@005YFFUIJEP8002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP800005Ool005YFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP04001JEUYFFUH90003FUH300000eYF000000080004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo
001JEUYF00001EYF00<005YFFUH01EYF40000eYF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YF0000;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUH00003FUH50004FUH01000FUIJEP001EYF1`0015YF2@000eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000Woo0P001UYF200015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00@0
05YFFUIJEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF001JEP80009JEP<000AJEP04001JEUYF0005FUH00`00FUIJEP0<0004
FUH50005FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20003Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP05FUH20002FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP0015YF0`000UYF00@005YFFUH000EJ
EP03001JEUYF00D0009JEP03001JEUYF009JEPP00003FUH0000000=JEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH00P00
00=JEP00Ool0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP04FUH0
0`00FUIJEP0500000eYF001JEP0:FUH20003FUH200000eYF001JEP02FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000goo00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP02FUH00`00
FUH0000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH005YF009JEP<0
009JEP03001JEUYF00UJEPH00003FUH0000000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEP0002ioo`00;Goo
0P000eYF500015YF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQP000EJEP03001JEP00009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000002moo`00;Goo0P0000AJEP00
000000IJEP04001JEP000009Ool60007FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000_Ool002eoo`03FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH30008Ool3000017oo
0000000015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002io
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000IJEP00FUH0
05YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000C000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000000Woo1@00
1Woo0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`002Goo100015YF00<005YFFUH01EYF00<005YFFUH00UYF
1`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@000AJEP04001JEUYFFUHI0004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH60009Ool500000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP02FUH50006FUH00`00Oomoo`09Ool=
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool2000015YF000000000eYF
10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
000000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P00
00=JEP0000000P001UYF0P002Goo1@001Woo1`000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPL0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPl000=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P0000=JEP00FUH00eYF0`0015YF00<005YF000027oo1@003Goo100015YF00H005YFFUH0
05YF000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUH0000F0002FUH00`00FUIJEP05FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF1@0000=JEP00
00000`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEP0000<000=JEP03001oogoo00Eoo`D0015oo`<00007FUH0
05YFFUH005YF0000;Goo000^Ool00`00FUH00004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60004FUH40006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH70008FUH6
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH00eYF1`001Goo0`004Goo1P000UYF00<005YF0000;Goo000_Ool20002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00
FUIJEP04FUH00`00FUIJEP050002FUH>0004FUH00`00FUIJEP05FUH30002FUH01000FUH000002EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF6@000eYF00D005YFFUH005YF008002ioo`00<7oo10001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP@0
00AJEP03001JEUYF00D00003FUH005YF00YJEP04001JEUYFFUH400000eYF001JEP03FUH00`00FUH0
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000C000^Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP0500000eYF001JEP0:FUH40005FUH0
0`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000080004FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUH000020002FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYFFUH20002
FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF00001@001UYF00<005YFFUH015YF00<005YF
00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P0000=JEP00
FUH015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUH00000
15YF00@005YFFUH000IJEP03001JEP0000P000=JEP03001JEUYF00MJEP03001JEUYF009JEP<0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000EJ
EP03001JEUYF009JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002]oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF01@000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Ioo`8000=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
009JEQ8000=JEP03001oogoo02Uoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF3P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1EYF00<005YFFUH00eYF00@005YFFUIJEPD00003FUH007oo02Yoo`00;Goo0P0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP<000IJEP800003FUH005YF00IJ
EP03001JEUYF00AJEPH000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP<0
02]oo`00;Goo0P0015YF00@005YFFUIJEPL000Aoo`<00003FUH0000000P000AJEP04001JEUYF0003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000AFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP040002FUH00`00FUH000020004FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0015YF00<005YF0000:goo000/Ool00`00FUH00003FUH5000>Ool60004FUH700000eYF00000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000DFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20005FUH00`00FUIJ
EP03FUH80002FUH60003FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH00`00FUH0000[Ool002ao
o`04001JEP00FUH2000015YF000000004Woo2`000eYF20000eYF00<005YFFUH01EYF00<005YFFUH0
0UYF1P0065YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00<005YF00000`0000=JEP0000001Goo40001Goo0`001EYF00<005YFFUH00UYF0P00;7oo000/
Ool01P00FUH00000FUH000AJEP<000ioo`D000Moo`X00003FUH0000000h000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP800003FUH005YF00AJEP<00004FUH005YFFUH20008Ool50009Ool400000eYF001JEP06
FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000A
Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20002FUH00`00
FUIJEP020002FUH00`00FUIJEP0200000eYF001oo`08Ool30003Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH60004Ool5000?Ool4
00001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P000UYF100000AJ
EP00000000=JEP03001JEP0000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEQP000EJEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUH005YF500015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`00<goo000/Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH015YF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Moo`00;Goo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0006FUH00`00FUIJEP04FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH80009FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Woo000^Ool00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000=0002FUH00`00FUIJEP04
FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Woo000_Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP090003FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH4
00000eYF001JEP06FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@goo000`Ool20004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJ
EUYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00`001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF
3`00Agoo000bOol300000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20002FUH00`00FUH000020008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH60006FUH00`00FUH0
0009001DOol003Eoo`<000=JEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP<00003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00=JEPX0009JEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol003Qoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh00007
FUH005YFFUH005YF000025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF0`0015YF0P0027oo100015YF00H005YFFUH005YF001DOol003Ioo`80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000EJEP04001JEUYFFUH70002FUH30008FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP020002FUH2000<Ool300001eYF001JEUYF001JEP0005Aoo`00=7oo0`001EYF00<005YFFUH0
1UYF00<005YFFUH0100015YF00<005YFFUH00UYF1`0017oo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF10002goo1P000UYF00<005YF0000E7oo000bOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUHA000;Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0
000017oo1`000eYF00D005YFFUH005YF008005Eoo`00<Goo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH010000goo1@004Goo1P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
5P00EGoo000`Ool20004FUH00`00FUIJEP03FUH40007Ool5000=Ool40004FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001E
Ool002moo`03001JEP0000AJEP03001JEP0000<000aoo`<000Yoo`@0009JEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP02001COol002moo`04001JEUYF0003FUH2000IOol40006FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00;goo00D005YFFUH005YF008001Moo`@00003
FUH005YF00MJEP03001JEUYF00AJEP@00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000MJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080059oo`00<7oo00<005YF00000`0027oo
3`001EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEPh0
00=JEP05001JEUYFFUH0001BOol0031oo`800004FUH005YFFUH80003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000027oo0P001EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1P001EYF00<0
05YFFUH00eYF00<005YFFUH01@000UYF00<007ooOol0D7oo000`Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0037oo0P000eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YF000007oo00800003FUH000000080
055oo`00<7oo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL001Aoo`800003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000=JEP03001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUH0
0000DGoo000`Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP04000MOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH60004FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH01000FUIJEP00DGoo000bOol50003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH6000UOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0D0005Ool30005FUH00`00FUIJEP02FUH3001BOol003Mooa00035o
o`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEPP000Moo`D000Uoo`@00003FUH005YF00IJEP05
001JEUYFFUH0001DOol0085ooaT000moo`D000Aoo`D000EJEP03001JEUYF00EJEP04001JEP00001E
Ool0091oo`05001JEUYF001JEP02000COol300000goo000000020002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH3001GOol0095oo`03001JEP0001X000IJEP03001JEUYF00IJEP03001JEP0000<005Yo
o`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF0`00GWoo002AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04001QOol0095oo`80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD006Eoo`00TWoo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000JWoo002DOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001^Ool009Qooa0007Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58645 .75664 m .60596 .70697 L .5768 .6942 L p .707 .577 .707 r
F P
0 g
s
.60596 .70697 m .58645 .75664 L .61647 .76566 L p .707 .577 .707 r
F P
0 g
s
.61647 .76566 m .63598 .71599 L .60596 .70697 L p .707 .577 .707 r
F P
0 g
s
.55729 .74387 m .5768 .6942 L .55136 .67895 L p .707 .577 .707 r
F P
0 g
s
.5768 .6942 m .55729 .74387 L .58645 .75664 L p .707 .577 .707 r
F P
0 g
s
.63598 .71599 m .61647 .76566 L .64441 .77006 L p .707 .577 .707 r
F P
0 g
s
.64441 .77006 m .66392 .72039 L .63598 .71599 L p .707 .577 .707 r
F P
0 g
s
.53185 .72862 m .55136 .67895 L .53212 .66269 L p .707 .577 .707 r
F P
0 g
s
.55136 .67895 m .53185 .72862 L .55729 .74387 L p .707 .577 .707 r
F P
0 g
s
.66392 .72039 m .64441 .77006 L .66754 .7694 L p .707 .577 .707 r
F P
0 g
s
.66754 .7694 m .68705 .71973 L .66392 .72039 L p .707 .577 .707 r
F P
0 g
s
.59232 .81517 m .59626 .77876 L .56526 .77352 L p .707 .577 .707 r
F P
0 g
s
.59626 .77876 m .59232 .81517 L .62399 .8174 L p .707 .577 .707 r
F P
0 g
s
.62399 .8174 m .62793 .78099 L .59626 .77876 L p .707 .577 .707 r
F P
0 g
s
.6431 .83313 m .63859 .81472 L .60761 .82253 L p .707 .577 .707 r
F P
0 g
s
.63859 .81472 m .6431 .83313 L .6718 .82417 L p .707 .577 .707 r
F P
0 g
s
.6718 .82417 m .66729 .80576 L .63859 .81472 L p .707 .577 .707 r
F P
0 g
s
.62793 .78099 m .62399 .8174 L .65325 .81641 L p .707 .577 .707 r
F P
0 g
s
.65325 .81641 m .65719 .78 L .62793 .78099 L p .707 .577 .707 r
F P
0 g
s
.56132 .80993 m .56526 .77352 L .53798 .7658 L p .707 .577 .707 r
F P
0 g
s
.56526 .77352 m .56132 .80993 L .59232 .81517 L p .707 .577 .707 r
F P
0 g
s
.61212 .84094 m .60761 .82253 L .57739 .82842 L p .707 .577 .707 r
F P
0 g
s
.60761 .82253 m .61212 .84094 L .6431 .83313 L p .707 .577 .707 r
F P
0 g
s
.51261 .71236 m .53212 .66269 L .52097 .64703 L p .707 .577 .707 r
F P
0 g
s
.53212 .66269 m .51261 .71236 L .53185 .72862 L p .707 .577 .707 r
F P
0 g
s
.57739 .82842 m .5819 .84683 L .61212 .84094 L p .707 .577 .707 r
F P
0 g
s
.5819 .84683 m .57739 .82842 L .55088 .83182 L p .707 .577 .707 r
F P
0 g
s
.66729 .80576 m .6718 .82417 L .69542 .81494 L p .707 .577 .707 r
F P
0 g
s
.69542 .81494 m .6909 .79653 L .66729 .80576 L p .707 .577 .707 r
F P
0 g
s
.65719 .78 m .65325 .81641 L .67722 .81229 L p .707 .577 .707 r
F P
0 g
s
.67722 .81229 m .68116 .77588 L .65719 .78 L p .707 .577 .707 r
F P
0 g
s
.53798 .7658 m .53405 .8022 L .56132 .80993 L p .707 .577 .707 r
F P
0 g
s
.68705 .71973 m .66754 .7694 L .68359 .76375 L p .707 .577 .707 r
F P
0 g
s
.68359 .76375 m .7031 .71408 L .68705 .71973 L p .707 .577 .707 r
F P
0 g
s
.55088 .83182 m .5554 .85023 L .5819 .84683 L p .707 .577 .707 r
F P
0 g
s
.53405 .8022 m .53798 .7658 L .51709 .75633 L p .707 .577 .707 r
F P
0 g
s
.51709 .75633 m .51315 .79274 L .53405 .8022 L p .707 .577 .707 r
F P
0 g
s
.52097 .64703 m .50146 .6967 L .51261 .71236 L p .707 .577 .707 r
F P
0 g
s
.5554 .85023 m .55088 .83182 L .53069 .83239 L p .707 .577 .707 r
F P
0 g
s
.50146 .6967 m .52097 .64703 L .519 .6335 L p .707 .577 .707 r
F P
0 g
s
.53069 .83239 m .5352 .8508 L .5554 .85023 L p .707 .577 .707 r
F P
0 g
s
.6909 .79653 m .69542 .81494 L .71163 .80634 L p .707 .577 .707 r
F P
0 g
s
.68116 .77588 m .67722 .81229 L .69356 .80545 L p .707 .577 .707 r
F P
0 g
s
.71163 .80634 m .70712 .78793 L .6909 .79653 L p .707 .577 .707 r
F P
0 g
s
.69356 .80545 m .6975 .76905 L .68116 .77588 L p .707 .577 .707 r
F P
0 g
s
.51315 .79274 m .51709 .75633 L .50463 .74606 L p .707 .577 .707 r
F P
0 g
s
.7031 .71408 m .68359 .76375 L .69099 .75367 L p .707 .577 .707 r
F P
0 g
s
.69099 .75367 m .7105 .704 L .7031 .71408 L p .707 .577 .707 r
F P
0 g
s
.50463 .74606 m .50069 .78247 L .51315 .79274 L p .707 .577 .707 r
F P
0 g
s
.519 .6335 m .49949 .68317 L .50146 .6967 L p .707 .577 .707 r
F P
0 g
s
.5352 .8508 m .53069 .83239 L .51878 .83009 L p .707 .577 .707 r
F P
0 g
s
.51878 .83009 m .52329 .8485 L .5352 .8508 L p .707 .577 .707 r
F P
0 g
s
.6975 .76905 m .69356 .80545 L .70067 .79656 L p .707 .577 .707 r
F P
0 g
s
.70067 .79656 m .70461 .76015 L .6975 .76905 L p .707 .577 .707 r
F P
0 g
s
.49949 .68317 m .519 .6335 L .5264 .62341 L p .707 .577 .707 r
F P
0 g
s
.70712 .78793 m .71163 .80634 L .71887 .79921 L p .707 .577 .707 r
F P
0 g
s
.71887 .79921 m .71435 .7808 L .70712 .78793 L p .707 .577 .707 r
F P
0 g
s
.50069 .78247 m .50463 .74606 L .50181 .73598 L p .707 .577 .707 r
F P
0 g
s
.46555 .82173 m .50283 .32534 L .45895 .31936 L p .707 .577 .707 r
F P
0 g
s
.50181 .73598 m .49787 .77239 L .50069 .78247 L p .707 .577 .707 r
F P
0 g
s
.5264 .62341 m .50689 .67308 L .49949 .68317 L p .707 .577 .707 r
F P
0 g
s
.50689 .67308 m .5264 .62341 L .54245 .61777 L p .707 .577 .707 r
F P
0 g
s
.49787 .77239 m .50181 .73598 L .50892 .72709 L p .707 .577 .707 r
F P
0 g
s
.50892 .72709 m .50498 .7635 L .49787 .77239 L p .707 .577 .707 r
F P
0 g
s
.54245 .61777 m .52294 .66744 L .50689 .67308 L p .707 .577 .707 r
F P
0 g
s
.50498 .7635 m .50892 .72709 L .52526 .72025 L p .707 .577 .707 r
F P
0 g
s
.52526 .72025 m .52132 .75666 L .50498 .7635 L p .707 .577 .707 r
F P
0 g
s
.50283 .32534 m .46555 .82173 L .51038 .82361 L p .707 .577 .707 r
F P
0 g
s
.51038 .82361 m .54766 .32721 L .50283 .32534 L p .707 .577 .707 r
F P
0 g
s
.7105 .704 m .69099 .75367 L .68902 .74013 L p .707 .577 .707 r
F P
0 g
s
.68902 .74013 m .70853 .69046 L .7105 .704 L p .707 .577 .707 r
F P
0 g
s
.52329 .8485 m .51878 .83009 L .51632 .82513 L p .707 .577 .707 r
F P
0 g
s
.51632 .82513 m .52083 .84354 L .52329 .8485 L p .707 .577 .707 r
F P
0 g
s
.52083 .84354 m .51632 .82513 L .52355 .818 L p .707 .577 .707 r
F P
0 g
s
.52294 .66744 m .54245 .61777 L .56558 .61711 L p .707 .577 .707 r
F P
0 g
s
.52355 .818 m .52807 .83641 L .52083 .84354 L p .707 .577 .707 r
F P
0 g
s
.56558 .61711 m .54607 .66678 L .52294 .66744 L p .707 .577 .707 r
F P
0 g
s
.54607 .66678 m .56558 .61711 L .59352 .62151 L p .707 .577 .707 r
F P
0 g
s
.52807 .83641 m .52355 .818 L .53977 .8094 L p .707 .577 .707 r
F P
0 g
s
.53977 .8094 m .54429 .82781 L .52807 .83641 L p .707 .577 .707 r
F P
0 g
s
.52132 .75666 m .52526 .72025 L .54923 .71614 L p .707 .577 .707 r
F P
0 g
s
.59352 .62151 m .57401 .67118 L .54607 .66678 L p .707 .577 .707 r
F P
0 g
s
.54923 .71614 m .5453 .75254 L .52132 .75666 L p .707 .577 .707 r
F P
0 g
s
.54429 .82781 m .53977 .8094 L .56339 .80016 L p .707 .577 .707 r
F P
0 g
s
.5453 .75254 m .54923 .71614 L .57849 .71515 L p .707 .577 .707 r
F P
0 g
s
.56339 .80016 m .5679 .81857 L .54429 .82781 L p .707 .577 .707 r
F P
0 g
s
.57849 .71515 m .57455 .75155 L .5453 .75254 L p .707 .577 .707 r
F P
0 g
s
.54766 .32721 m .51038 .82361 L .55177 .8212 L p .707 .577 .707 r
F P
0 g
s
.55177 .8212 m .58906 .3248 L .54766 .32721 L p .707 .577 .707 r
F P
0 g
s
.42166 .81575 m .45895 .31936 L .42031 .30986 L p .707 .577 .707 r
F P
0 g
s
.45895 .31936 m .42166 .81575 L .46555 .82173 L p .707 .577 .707 r
F P
0 g
s
.70461 .76015 m .70067 .79656 L .69785 .78648 L p .707 .577 .707 r
F P
0 g
s
.69785 .78648 m .70179 .75008 L .70461 .76015 L p .707 .577 .707 r
F P
0 g
s
.71435 .7808 m .71887 .79921 L .71641 .79425 L p .707 .577 .707 r
F P
0 g
s
.71641 .79425 m .7119 .77584 L .71435 .7808 L p .707 .577 .707 r
F P
0 g
s
.57401 .67118 m .59352 .62151 L .62354 .63053 L p .707 .577 .707 r
F P
0 g
s
.62354 .63053 m .60403 .6802 L .57401 .67118 L p .707 .577 .707 r
F P
0 g
s
.57455 .75155 m .57849 .71515 L .61016 .71738 L p .707 .577 .707 r
F P
0 g
s
.61016 .71738 m .60622 .75378 L .57455 .75155 L p .707 .577 .707 r
F P
0 g
s
.5679 .81857 m .56339 .80016 L .59209 .79121 L p .707 .577 .707 r
F P
0 g
s
.59209 .79121 m .5966 .80962 L .5679 .81857 L p .707 .577 .707 r
F P
0 g
s
.58906 .3248 m .55177 .8212 L .58567 .81474 L p .707 .577 .707 r
F P
0 g
s
.58567 .81474 m .62296 .31834 L .58906 .3248 L p .707 .577 .707 r
F P
0 g
s
.38302 .80625 m .42031 .30986 L .39069 .29777 L p .707 .577 .707 r
F P
0 g
s
.42031 .30986 m .38302 .80625 L .42166 .81575 L p .707 .577 .707 r
F P
0 g
s
.70853 .69046 m .68902 .74013 L .67787 .72447 L p .707 .577 .707 r
F P
0 g
s
.67787 .72447 m .69738 .6748 L .70853 .69046 L p .707 .577 .707 r
F P
0 g
s
.24344 .7218 m .26295 .67213 L .2338 .65937 L p .707 .577 .707 r
F P
0 g
s
.26295 .67213 m .24344 .7218 L .27346 .73082 L p .707 .577 .707 r
F P
0 g
s
.27346 .73082 m .29297 .68116 L .26295 .67213 L p .707 .577 .707 r
F P
0 g
s
.21428 .70904 m .2338 .65937 L .20835 .64412 L p .707 .577 .707 r
F P
0 g
s
.2338 .65937 m .21428 .70904 L .24344 .7218 L p .707 .577 .707 r
F P
0 g
s
.29297 .68116 m .27346 .73082 L .3014 .73522 L p .707 .577 .707 r
F P
0 g
s
.3014 .73522 m .32091 .68555 L .29297 .68116 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.18884 .69378 m .20835 .64412 L .18911 .62786 L p .707 .577 .707 r
F P
0 g
s
.20835 .64412 m .18884 .69378 L .21428 .70904 L p .707 .577 .707 r
F P
0 g
s
.70179 .75008 m .69785 .78648 L .68539 .77621 L p .707 .577 .707 r
F P
0 g
s
.68539 .77621 m .68933 .7398 L .70179 .75008 L p .707 .577 .707 r
F P
0 g
s
.6527 .64329 m .63318 .69296 L .60403 .6802 L p .707 .577 .707 r
F P
0 g
s
.60403 .6802 m .62354 .63053 L .6527 .64329 L p .707 .577 .707 r
F P
0 g
s
.64116 .72261 m .63722 .75902 L .60622 .75378 L p .707 .577 .707 r
F P
0 g
s
.60622 .75378 m .61016 .71738 L .64116 .72261 L p .707 .577 .707 r
F P
0 g
s
.5966 .80962 m .59209 .79121 L .62306 .7834 L p .707 .577 .707 r
F P
0 g
s
.62306 .7834 m .62758 .80181 L .5966 .80962 L p .707 .577 .707 r
F P
0 g
s
.62296 .31834 m .58567 .81474 L .60876 .80486 L p .707 .577 .707 r
F P
0 g
s
.60876 .80486 m .64605 .30846 L .62296 .31834 L p .707 .577 .707 r
F P
0 g
s
.7119 .77584 m .71641 .79425 L .7045 .79194 L p .707 .577 .707 r
F P
0 g
s
.7045 .79194 m .69998 .77353 L .7119 .77584 L p .707 .577 .707 r
F P
0 g
s
.32091 .68555 m .3014 .73522 L .32453 .73457 L p .707 .577 .707 r
F P
0 g
s
.32453 .73457 m .34404 .6849 L .32091 .68555 L p .707 .577 .707 r
F P
0 g
s
.69738 .6748 m .67787 .72447 L .65863 .70822 L p .707 .577 .707 r
F P
0 g
s
.65863 .70822 m .67814 .65855 L .69738 .6748 L p .707 .577 .707 r
F P
0 g
s
.24931 .7734 m .25325 .737 L .22225 .73176 L p .707 .577 .707 r
F P
0 g
s
.25325 .737 m .24931 .7734 L .28098 .77563 L p .707 .577 .707 r
F P
0 g
s
.28098 .77563 m .28492 .73923 L .25325 .737 L p .707 .577 .707 r
F P
0 g
s
.28492 .73923 m .28098 .77563 L .31024 .77464 L p .707 .577 .707 r
F P
0 g
s
.31024 .77464 m .31418 .73824 L .28492 .73923 L p .707 .577 .707 r
F P
0 g
s
.34058 .72892 m .36009 .67925 L .34404 .6849 L p .707 .577 .707 r
F P
0 g
s
.34789 .76868 m .35241 .78709 L .36863 .77849 L p .707 .577 .707 r
F P
0 g
s
.36863 .77849 m .36411 .76008 L .34789 .76868 L p .707 .577 .707 r
F P
0 g
s
.36009 .67925 m .34058 .72892 L .34798 .71883 L p .707 .577 .707 r
F P
0 g
s
.34798 .71883 m .36749 .66916 L .36009 .67925 L p .707 .577 .707 r
F P
0 g
s
.35449 .72728 m .35055 .76369 L .35766 .75479 L p .707 .577 .707 r
F P
0 g
s
.35766 .75479 m .3616 .71839 L .35449 .72728 L p .707 .577 .707 r
F P
0 g
s
.36749 .66916 m .34798 .71883 L .34601 .7053 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .36552 .65563 L .36749 .66916 L p .707 .577 .707 r
F P
0 g
s
.3616 .71839 m .35766 .75479 L .35485 .74472 L p .707 .577 .707 r
F P
0 g
s
.35485 .74472 m .35879 .70831 L .3616 .71839 L p .707 .577 .707 r
F P
0 g
s
.34404 .6849 m .32453 .73457 L .34058 .72892 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .33486 .68964 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.36552 .65563 m .34648 .70411 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.34648 .70411 m .34601 .7053 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.373 .28428 m .36897 .27071 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.35241 .78709 m .34789 .76868 L .32428 .77791 L p .707 .577 .707 r
F P
0 g
s
.33815 .73412 m .33421 .77053 L .35055 .76369 L p .707 .577 .707 r
F P
0 g
s
.35055 .76369 m .35449 .72728 L .33815 .73412 L p .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34053 .6752 L p .34691 .67021 L .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34691 .67021 L .34683 .67636 L .707 .577 .707 r
F
.34053 .6752 m .35437 .63997 L .36022 .64818 L p F P
0 g
s
.36022 .64818 m .36552 .65563 L p .34053 .6752 L .707 .577 .707 r
F P
0 g
s
.31418 .73824 m .31024 .77464 L .33421 .77053 L p .707 .577 .707 r
F P
0 g
s
.33421 .77053 m .33815 .73412 L .31418 .73824 L p .707 .577 .707 r
F P
0 g
s
.35437 .63997 m .33486 .68964 L .3274 .68333 L p .707 .577 .707 r
F P
0 g
s
.3274 .68333 m .31562 .67338 L p .32979 .66116 L .707 .577 .707 r
F P
0 g
s
.32979 .66116 m .35437 .63997 L .3274 .68333 L .707 .577 .707 r
F
.36897 .27071 m .34853 .54284 L p .34787 .59421 L F P
0 g
s
.31562 .67338 m .33513 .62371 L .35437 .63997 L p .707 .577 .707 r
F P
0 g
s
.34632 .69804 m .34238 .73445 L .32149 .72498 L p .707 .577 .707 r
F P
0 g
s
.32149 .72498 m .32543 .68858 L .34632 .69804 L p .707 .577 .707 r
F P
0 g
s
.33678 .74626 m .33918 .75605 L p .31479 .76807 L .707 .577 .707 r
F P
0 g
s
.34683 .67636 m .34691 .67021 L .36552 .65563 L .707 .577 .707 r
F
.32428 .77791 m .32879 .79632 L .35241 .78709 L p F P
0 g
s
.35879 .70831 m .35485 .74472 L .34238 .73445 L p .707 .577 .707 r
F P
0 g
s
.34238 .73445 m .34632 .69804 L .35879 .70831 L p .707 .577 .707 r
F P
0 g
s
.33633 .78115 m .3534 .79417 L p .35713 .69729 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .33821 .75209 L p .34222 .7461 L .707 .577 .707 r
F P
0 g
s
.33821 .75209 m .33678 .74626 L .33884 .7462 L p .707 .577 .707 r
F P
0 g
s
.33884 .7462 m .34222 .7461 L p .33821 .75209 L .707 .577 .707 r
F P
0 g
s
.33816 .76507 m .31479 .76807 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.31479 .76807 m .31027 .74966 L .33678 .74626 L p .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .33531 .7793 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33531 .7793 m .33571 .78068 L p .33659 .76728 L .707 .577 .707 r
F P
0 g
s
.33659 .76728 m .34787 .59421 L .33531 .7793 L .707 .577 .707 r
F
.35713 .69729 m .36289 .54728 L .33918 .75605 L F
.35713 .69729 m .33918 .75605 L .33633 .78115 L F
.3534 .79417 m .39069 .29777 L .373 .28428 L p F P
0 g
s
.34129 .76467 m .33918 .75605 L p .35698 .74568 L .707 .577 .707 r
F P
0 g
s
.34222 .7461 m .35698 .74568 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .34129 .76467 L .33816 .76507 L p .707 .577 .707 r
F P
0 g
s
.373 .28428 m .33571 .78068 L .33633 .78115 L p .707 .577 .707 r
F P
0 g
s
.36289 .54728 m .373 .28428 L .33633 .78115 L .707 .577 .707 r
F
.34853 .54284 m .33168 .7671 L p .34787 .59421 L F P
0 g
s
.3475 .62381 m .373 .28428 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .36212 .36191 L p .37899 .25838 L .707 .577 .707 r
F P
0 g
s
.36212 .36191 m .36897 .27071 L .37243 .26645 L p .707 .577 .707 r
F P
0 g
s
.37243 .26645 m .37899 .25838 L p .36212 .36191 L .707 .577 .707 r
F P
0 g
s
.36411 .76008 m .36863 .77849 L .37586 .77136 L p .707 .577 .707 r
F P
0 g
s
.37586 .77136 m .37134 .75295 L .36411 .76008 L p .707 .577 .707 r
F P
0 g
s
.37134 .75295 m .37586 .77136 L .37378 .76716 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .36467 .73141 L .3534 .79417 L .707 .577 .707 r
F
.37378 .76716 m .3734 .7664 L p .37313 .76461 L F P
0 g
s
.37313 .76461 m .37134 .75295 L .37378 .76716 L .707 .577 .707 r
F
.3534 .79417 m .38302 .80625 L p .38306 .80357 L F P
0 g
s
.3734 .7664 m .36889 .74799 L .37134 .75295 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .38594 .61289 L .36467 .73141 L .707 .577 .707 r
F
.39069 .29777 m .36485 .64183 L p .38594 .61289 L F P
0 g
s
.36485 .64183 m .3534 .79417 L p .38594 .61289 L .707 .577 .707 r
F P
0 g
s
.33571 .78068 m .3475 .62381 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.21832 .76816 m .22225 .73176 L .19498 .72403 L p .707 .577 .707 r
F P
0 g
s
.22225 .73176 m .21832 .76816 L .24931 .7734 L p .707 .577 .707 r
F P
0 g
s
.26912 .81309 m .2646 .79468 L .23438 .80057 L p .707 .577 .707 r
F P
0 g
s
.2646 .79468 m .26912 .81309 L .30009 .80528 L p .707 .577 .707 r
F P
0 g
s
.30009 .80528 m .29558 .78687 L .2646 .79468 L p .707 .577 .707 r
F P
0 g
s
.1696 .67753 m .18911 .62786 L .17796 .6122 L p .707 .577 .707 r
F P
0 g
s
.18911 .62786 m .1696 .67753 L .18884 .69378 L p .707 .577 .707 r
F P
0 g
s
.29558 .78687 m .30009 .80528 L .32879 .79632 L p .707 .577 .707 r
F P
0 g
s
.32879 .79632 m .32428 .77791 L .29558 .78687 L p .707 .577 .707 r
F P
0 g
s
.23438 .80057 m .2389 .81898 L .26912 .81309 L p .707 .577 .707 r
F P
0 g
s
.19498 .72403 m .19104 .76044 L .21832 .76816 L p .707 .577 .707 r
F P
0 g
s
.67814 .65855 m .65863 .70822 L .63318 .69296 L p .707 .577 .707 r
F P
0 g
s
.63318 .69296 m .6527 .64329 L .67814 .65855 L p .707 .577 .707 r
F P
0 g
s
.2389 .81898 m .23438 .80057 L .20788 .80397 L p .707 .577 .707 r
F P
0 g
s
.19104 .76044 m .19498 .72403 L .17408 .71457 L p .707 .577 .707 r
F P
0 g
s
.68933 .7398 m .68539 .77621 L .6645 .76675 L p .707 .577 .707 r
F P
0 g
s
.6645 .76675 m .66844 .73034 L .68933 .7398 L p .707 .577 .707 r
F P
0 g
s
.20788 .80397 m .21239 .82238 L .2389 .81898 L p .707 .577 .707 r
F P
0 g
s
.69998 .77353 m .7045 .79194 L .6843 .79252 L p .707 .577 .707 r
F P
0 g
s
.6843 .79252 m .67979 .77411 L .69998 .77353 L p .707 .577 .707 r
F P
0 g
s
.17408 .71457 m .17014 .75097 L .19104 .76044 L p .707 .577 .707 r
F P
0 g
s
.64605 .30846 m .60876 .80486 L .61878 .79253 L p .707 .577 .707 r
F P
0 g
s
.61878 .79253 m .65607 .29613 L .64605 .30846 L p .707 .577 .707 r
F P
0 g
s
.17796 .6122 m .15845 .66187 L .1696 .67753 L p .707 .577 .707 r
F P
0 g
s
.21239 .82238 m .20788 .80397 L .18768 .80454 L p .707 .577 .707 r
F P
0 g
s
.15845 .66187 m .17796 .6122 L .17599 .59867 L p .707 .577 .707 r
F P
0 g
s
.18768 .80454 m .19219 .82295 L .21239 .82238 L p .707 .577 .707 r
F P
0 g
s
.17014 .75097 m .17408 .71457 L .16162 .7043 L p .707 .577 .707 r
F P
0 g
s
.66844 .73034 m .6645 .76675 L .63722 .75902 L p .707 .577 .707 r
F P
0 g
s
.63722 .75902 m .64116 .72261 L .66844 .73034 L p .707 .577 .707 r
F P
0 g
s
.67979 .77411 m .6843 .79252 L .6578 .79592 L p .707 .577 .707 r
F P
0 g
s
.6578 .79592 m .65328 .77751 L .67979 .77411 L p .707 .577 .707 r
F P
0 g
s
.16162 .7043 m .15768 .7407 L .17014 .75097 L p .707 .577 .707 r
F P
0 g
s
.17599 .59867 m .15648 .64834 L .15845 .66187 L p .707 .577 .707 r
F P
0 g
s
.19219 .82295 m .18768 .80454 L .17577 .80224 L p .707 .577 .707 r
F P
0 g
s
.17577 .80224 m .18028 .82065 L .19219 .82295 L p .707 .577 .707 r
F P
0 g
s
.15648 .64834 m .17599 .59867 L .18339 .58858 L p .707 .577 .707 r
F P
0 g
s
.65328 .77751 m .6578 .79592 L .62758 .80181 L p .707 .577 .707 r
F P
0 g
s
.62758 .80181 m .62306 .7834 L .65328 .77751 L p .707 .577 .707 r
F P
0 g
s
.15768 .7407 m .16162 .7043 L .1588 .69422 L p .707 .577 .707 r
F P
0 g
s
.65607 .29613 m .61878 .79253 L .61475 .77895 L p .707 .577 .707 r
F P
0 g
s
.61475 .77895 m .65203 .28256 L .65607 .29613 L p .707 .577 .707 r
F P
0 g
s
.1588 .69422 m .15486 .73063 L .15768 .7407 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18339 .58858 m .16388 .63825 L .15648 .64834 L p .707 .577 .707 r
F P
0 g
s
.18028 .82065 m .17577 .80224 L .17331 .79728 L p .707 .577 .707 r
F P
0 g
s
.17331 .79728 m .17782 .81569 L .18028 .82065 L p .707 .577 .707 r
F P
0 g
s
.16388 .63825 m .18339 .58858 L .19944 .58293 L p .707 .577 .707 r
F P
0 g
s
.15486 .73063 m .1588 .69422 L .16591 .68533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16591 .68533 m .16197 .72173 L .15486 .73063 L p .707 .577 .707 r
F P
0 g
s
.65203 .28256 m .61475 .77895 L .59706 .76546 L p .707 .577 .707 r
F P
0 g
s
.59706 .76546 m .63434 .26907 L .65203 .28256 L p .707 .577 .707 r
F P
0 g
s
.19944 .58293 m .17993 .6326 L .16388 .63825 L p .707 .577 .707 r
F P
0 g
s
.17782 .81569 m .17331 .79728 L .18054 .79015 L p .707 .577 .707 r
F P
0 g
s
.17993 .6326 m .19944 .58293 L .22257 .58228 L p .707 .577 .707 r
F P
0 g
s
.18054 .79015 m .18506 .80856 L .17782 .81569 L p .707 .577 .707 r
F P
0 g
s
.3417 .75477 m .37899 .25838 L .40208 .2485 L p .707 .577 .707 r
F P
0 g
s
.37899 .25838 m .3417 .75477 L .33168 .7671 L p .707 .577 .707 r
F P
0 g
s
.16197 .72173 m .16591 .68533 L .18225 .67849 L p .707 .577 .707 r
F P
0 g
s
.36889 .74799 m .3734 .7664 L .36149 .76409 L p .707 .577 .707 r
F P
0 g
s
.36149 .76409 m .35698 .74568 L .36889 .74799 L p .707 .577 .707 r
F P
0 g
s
.18225 .67849 m .17832 .71489 L .16197 .72173 L p .707 .577 .707 r
F P
0 g
s
.22257 .58228 m .20306 .63195 L .17993 .6326 L p .707 .577 .707 r
F P
0 g
s
.20306 .63195 m .22257 .58228 L .25051 .58667 L p .707 .577 .707 r
F P
0 g
s
.33513 .62371 m .31562 .67338 L .29018 .65813 L p .707 .577 .707 r
F P
0 g
s
.29018 .65813 m .30969 .60846 L .33513 .62371 L p .707 .577 .707 r
F P
0 g
s
.18506 .80856 m .18054 .79015 L .19676 .78155 L p .707 .577 .707 r
F P
0 g
s
.19676 .78155 m .20128 .79996 L .18506 .80856 L p .707 .577 .707 r
F P
0 g
s
.63434 .26907 m .59706 .76546 L .56744 .75337 L p .707 .577 .707 r
F P
0 g
s
.56744 .75337 m .60473 .25698 L .63434 .26907 L p .707 .577 .707 r
F P
0 g
s
.17832 .71489 m .18225 .67849 L .20623 .67437 L p .707 .577 .707 r
F P
0 g
s
.231 .63634 m .25051 .58667 L .28053 .5957 L p .707 .577 .707 r
F P
0 g
s
.25051 .58667 m .231 .63634 L .20306 .63195 L p .707 .577 .707 r
F P
0 g
s
.35698 .74568 m .36149 .76409 L .34129 .76467 L p .707 .577 .707 r
F P
0 g
s
.30969 .60846 m .29018 .65813 L .26102 .64537 L p .707 .577 .707 r
F P
0 g
s
.26102 .64537 m .28053 .5957 L .30969 .60846 L p .707 .577 .707 r
F P
0 g
s
.28053 .5957 m .26102 .64537 L .231 .63634 L p .707 .577 .707 r
F P
0 g
s
.40208 .2485 m .36479 .74489 L .3417 .75477 L p .707 .577 .707 r
F P
0 g
s
.36479 .74489 m .40208 .2485 L .43598 .24204 L p .707 .577 .707 r
F P
0 g
s
.20623 .67437 m .20229 .71078 L .17832 .71489 L p .707 .577 .707 r
F P
0 g
s
.32543 .68858 m .32149 .72498 L .29421 .71726 L p .707 .577 .707 r
F P
0 g
s
.29421 .71726 m .29815 .68085 L .32543 .68858 L p .707 .577 .707 r
F P
0 g
s
.72365 .6646 m .74317 .61493 L .71401 .60216 L p .707 .577 .707 r
F P
0 g
s
.74317 .61493 m .72365 .6646 L .75367 .67362 L p .707 .577 .707 r
F P
0 g
s
.75367 .67362 m .77319 .62395 L .74317 .61493 L p .707 .577 .707 r
F P
0 g
s
.20229 .71078 m .20623 .67437 L .23548 .67338 L p .707 .577 .707 r
F P
0 g
s
.6945 .65183 m .71401 .60216 L .68857 .58691 L p .707 .577 .707 r
F P
0 g
s
.71401 .60216 m .6945 .65183 L .72365 .6646 L p .707 .577 .707 r
F P
0 g
s
.20128 .79996 m .19676 .78155 L .22038 .77231 L p .707 .577 .707 r
F P
0 g
s
.77319 .62395 m .75367 .67362 L .78161 .67802 L p .707 .577 .707 r
F P
0 g
s
.78161 .67802 m .80113 .62835 L .77319 .62395 L p .707 .577 .707 r
F P
0 g
s
.22038 .77231 m .22489 .79072 L .20128 .79996 L p .707 .577 .707 r
F P
0 g
s
.29815 .68085 m .29421 .71726 L .26321 .71202 L p .707 .577 .707 r
F P
0 g
s
.26321 .71202 m .26715 .67561 L .29815 .68085 L p .707 .577 .707 r
F P
0 g
s
.60473 .25698 m .56744 .75337 L .5288 .74388 L p .707 .577 .707 r
F P
0 g
s
.5288 .74388 m .56609 .24748 L .60473 .25698 L p .707 .577 .707 r
F P
0 g
s
.23548 .67338 m .23154 .70979 L .20229 .71078 L p .707 .577 .707 r
F P
0 g
s
.66905 .63658 m .68857 .58691 L .66933 .57066 L p .707 .577 .707 r
F P
0 g
s
.68857 .58691 m .66905 .63658 L .6945 .65183 L p .707 .577 .707 r
F P
0 g
s
.23154 .70979 m .23548 .67338 L .26715 .67561 L p .707 .577 .707 r
F P
0 g
s
.26715 .67561 m .26321 .71202 L .23154 .70979 L p .707 .577 .707 r
F P
0 g
s
.40632 .72105 m .4373 .71324 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .47737 .23963 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40001 .72083 m .43598 .24204 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .40632 .72105 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4373 .71324 m .43278 .69483 L .41015 .70054 L p .707 .577 .707 r
F P
0 g
s
.47737 .23963 m .47631 .25371 L p .40222 .71642 L .707 .577 .707 r
F P
0 g
s
.40214 .71657 m .47737 .23963 L .40222 .71642 L .707 .577 .707 r
F
.4373 .71324 m .41015 .70054 L .40815 .70453 L F
.40632 .72105 m .40421 .71243 L p .40304 .71987 L F P
0 g
s
.43278 .69483 m .4373 .71324 L .466 .70428 L p .707 .577 .707 r
F P
0 g
s
.466 .70428 m .46148 .68587 L .43278 .69483 L p .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .40214 .71657 L .40222 .71642 L .707 .577 .707 r
F
.40013 .73835 m .39869 .73843 L p .47631 .25371 L F P
0 g
s
.39869 .73843 m .40001 .72083 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .36479 .74489 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .41456 .52721 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.41456 .52721 m .39869 .73843 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.37158 .70853 m .3761 .72694 L .40274 .72175 L p .707 .577 .707 r
F P
0 g
s
.40274 .72175 m .40632 .72105 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40304 .71987 m .37158 .70853 L .40274 .72175 L .707 .577 .707 r
F
.44008 .73602 m .40013 .73835 L p .42723 .56598 L F P
0 g
s
.47631 .25371 m .44807 .62977 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.44807 .62977 m .44008 .73602 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.41066 .63879 m .42286 .60774 L p .40016 .58009 L .707 .577 .707 r
F P
0 g
s
.42286 .60774 m .43018 .58912 L .42065 .58625 L p .707 .577 .707 r
F P
0 g
s
.42065 .58625 m .40016 .58009 L p .42286 .60774 L .707 .577 .707 r
F P
0 g
s
.41015 .70054 m .4018 .70264 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .37158 .70853 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .4018 .70264 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .40421 .71243 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.80113 .62835 m .78161 .67802 L .80474 .67736 L p .707 .577 .707 r
F P
0 g
s
.80474 .67736 m .82425 .62769 L .80113 .62835 L p .707 .577 .707 r
F P
0 g
s
.22489 .79072 m .22038 .77231 L .24908 .76336 L p .707 .577 .707 r
F P
0 g
s
.72952 .72313 m .73346 .68672 L .70247 .68149 L p .707 .577 .707 r
F P
0 g
s
.73346 .68672 m .72952 .72313 L .7612 .72536 L p .707 .577 .707 r
F P
0 g
s
.7612 .72536 m .76514 .68895 L .73346 .68672 L p .707 .577 .707 r
F P
0 g
s
.24908 .76336 m .25359 .78177 L .22489 .79072 L p .707 .577 .707 r
F P
0 g
s
.31027 .74966 m .31479 .76807 L .28457 .77396 L p .707 .577 .707 r
F P
0 g
s
.28457 .77396 m .28005 .75555 L .31027 .74966 L p .707 .577 .707 r
F P
0 g
s
.78031 .74109 m .77579 .72268 L .74481 .73049 L p .707 .577 .707 r
F P
0 g
s
.77579 .72268 m .78031 .74109 L .80901 .73213 L p .707 .577 .707 r
F P
0 g
s
.80901 .73213 m .80449 .71372 L .77579 .72268 L p .707 .577 .707 r
F P
0 g
s
.76514 .68895 m .7612 .72536 L .79045 .72437 L p .707 .577 .707 r
F P
0 g
s
.79045 .72437 m .79439 .68796 L .76514 .68895 L p .707 .577 .707 r
F P
0 g
s
.69853 .71789 m .70247 .68149 L .67519 .67376 L p .707 .577 .707 r
F P
0 g
s
.70247 .68149 m .69853 .71789 L .72952 .72313 L p .707 .577 .707 r
F P
0 g
s
.74933 .7489 m .74481 .73049 L .71459 .73638 L p .707 .577 .707 r
F P
0 g
s
.74481 .73049 m .74933 .7489 L .78031 .74109 L p .707 .577 .707 r
F P
0 g
s
.25359 .78177 m .24908 .76336 L .28005 .75555 L p .707 .577 .707 r
F P
0 g
s
.64981 .62033 m .66933 .57066 L .65818 .555 L p .707 .577 .707 r
F P
0 g
s
.66933 .57066 m .64981 .62033 L .66905 .63658 L p .707 .577 .707 r
F P
0 g
s
.56609 .24748 m .5288 .74388 L .48492 .7379 L p .707 .577 .707 r
F P
0 g
s
.46148 .68587 m .466 .70428 L .4696 .70287 L p .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .44008 .73602 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.5222 .2415 m .48508 .73571 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.46171 .68613 m .46148 .68587 L .4696 .70287 L .707 .577 .707 r
F
.4711 .68901 m .46148 .68587 L .47466 .7009 L F
.5222 .2415 m .56609 .24748 L p .48521 .73613 L F P
0 g
s
.48508 .73571 m .5222 .2415 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.48961 .69505 m .4851 .67664 L .46148 .68587 L p .707 .577 .707 r
F P
0 g
s
.48508 .73571 m .48492 .7379 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.4696 .70287 m .47466 .7009 L p .46171 .68613 L .707 .577 .707 r
F P
0 g
s
.47466 .7009 m .48961 .69505 L p .4711 .68901 L .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .48508 .73571 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.71459 .73638 m .71911 .75479 L .74933 .7489 L p .707 .577 .707 r
F P
0 g
s
.28005 .75555 m .28457 .77396 L .25359 .78177 L p .707 .577 .707 r
F P
0 g
s
.44008 .73602 m .45153 .58369 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .45812 .59351 L .44483 .59142 L p .707 .577 .707 r
F P
0 g
s
.44483 .59142 m .43018 .58912 L p .43272 .60542 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .44483 .59142 L .43272 .60542 L .707 .577 .707 r
F
.47737 .23963 m .5222 .2415 L p .46867 .56387 L F P
0 g
s
.45153 .58369 m .47737 .23963 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.71911 .75479 m .71459 .73638 L .68809 .73978 L p .707 .577 .707 r
F P
0 g
s
.80449 .71372 m .80901 .73213 L .83262 .7229 L p .707 .577 .707 r
F P
0 g
s
.83262 .7229 m .82811 .70449 L .80449 .71372 L p .707 .577 .707 r
F P
0 g
s
.79439 .68796 m .79045 .72437 L .81442 .72025 L p .707 .577 .707 r
F P
0 g
s
.81442 .72025 m .81836 .68385 L .79439 .68796 L p .707 .577 .707 r
F P
0 g
s
.67519 .67376 m .67125 .71016 L .69853 .71789 L p .707 .577 .707 r
F P
0 g
s
.82425 .62769 m .80474 .67736 L .82079 .67171 L p .707 .577 .707 r
F P
0 g
s
.82079 .67171 m .8403 .62204 L .82425 .62769 L p .707 .577 .707 r
F P
0 g
s
.68809 .73978 m .6926 .75819 L .71911 .75479 L p .707 .577 .707 r
F P
0 g
s
.67125 .71016 m .67519 .67376 L .65429 .66429 L p .707 .577 .707 r
F P
0 g
s
.65429 .66429 m .65036 .7007 L .67125 .71016 L p .707 .577 .707 r
F P
0 g
s
.65818 .555 m .63866 .60466 L .64981 .62033 L p .707 .577 .707 r
F P
0 g
s
.6926 .75819 m .68809 .73978 L .66789 .74035 L p .707 .577 .707 r
F P
0 g
s
.63866 .60466 m .65818 .555 L .6562 .54146 L p .707 .577 .707 r
F P
0 g
s
.66789 .74035 m .67241 .75877 L .6926 .75819 L p .707 .577 .707 r
F P
0 g
s
.82811 .70449 m .83262 .7229 L .84884 .7143 L p .707 .577 .707 r
F P
0 g
s
.81836 .68385 m .81442 .72025 L .83076 .71341 L p .707 .577 .707 r
F P
0 g
s
.84884 .7143 m .84432 .69589 L .82811 .70449 L p .707 .577 .707 r
F P
0 g
s
.83076 .71341 m .8347 .67701 L .81836 .68385 L p .707 .577 .707 r
F P
0 g
s
.65036 .7007 m .65429 .66429 L .64183 .65402 L p .707 .577 .707 r
F P
0 g
s
.8403 .62204 m .82079 .67171 L .82819 .66163 L p .707 .577 .707 r
F P
0 g
s
.82819 .66163 m .84771 .61196 L .8403 .62204 L p .707 .577 .707 r
F P
0 g
s
.64183 .65402 m .63789 .69043 L .65036 .7007 L p .707 .577 .707 r
F P
0 g
s
.6562 .54146 m .63669 .59113 L .63866 .60466 L p .707 .577 .707 r
F P
0 g
s
.67241 .75877 m .66789 .74035 L .65598 .73805 L p .707 .577 .707 r
F P
0 g
s
.65598 .73805 m .6605 .75646 L .67241 .75877 L p .707 .577 .707 r
F P
0 g
s
.8347 .67701 m .83076 .71341 L .83787 .70452 L p .707 .577 .707 r
F P
0 g
s
.83787 .70452 m .84181 .66811 L .8347 .67701 L p .707 .577 .707 r
F P
0 g
s
.63669 .59113 m .6562 .54146 L .66361 .53138 L p .707 .577 .707 r
F P
0 g
s
.84432 .69589 m .84884 .7143 L .85607 .70717 L p .707 .577 .707 r
F P
0 g
s
.85607 .70717 m .85156 .68876 L .84432 .69589 L p .707 .577 .707 r
F P
0 g
s
.63789 .69043 m .64183 .65402 L .63902 .64395 L p .707 .577 .707 r
F P
0 g
s
.84771 .61196 m .82819 .66163 L .82622 .64809 L p .707 .577 .707 r
F P
0 g
s
.82622 .64809 m .84574 .59842 L .84771 .61196 L p .707 .577 .707 r
F P
0 g
s
.63902 .64395 m .63508 .68035 L .63789 .69043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.66361 .53138 m .64409 .58104 L .63669 .59113 L p .707 .577 .707 r
F P
0 g
s
.6605 .75646 m .65598 .73805 L .65352 .73309 L p .707 .577 .707 r
F P
0 g
s
.65352 .73309 m .65804 .7515 L .6605 .75646 L p .707 .577 .707 r
F P
0 g
s
.84181 .66811 m .83787 .70452 L .83506 .69444 L p .707 .577 .707 r
F P
0 g
s
.83506 .69444 m .839 .65804 L .84181 .66811 L p .707 .577 .707 r
F P
0 g
s
.64409 .58104 m .66361 .53138 L .67966 .52573 L p .707 .577 .707 r
F P
0 g
s
.85156 .68876 m .85607 .70717 L .85361 .70221 L p .707 .577 .707 r
F P
0 g
s
.85361 .70221 m .8491 .6838 L .85156 .68876 L p .707 .577 .707 r
F P
0 g
s
.63508 .68035 m .63902 .64395 L .64613 .63505 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84574 .59842 m .82622 .64809 L .81507 .63243 L p .707 .577 .707 r
F P
0 g
s
.81507 .63243 m .83459 .58276 L .84574 .59842 L p .707 .577 .707 r
F P
0 g
s
.38064 .62976 m .40016 .58009 L .371 .56733 L p .707 .577 .707 r
F P
0 g
s
.40016 .58009 m .38064 .62976 L .41066 .63879 L p .707 .577 .707 r
F P
0 g
s
.35149 .617 m .371 .56733 L .34556 .55208 L p .707 .577 .707 r
F P
0 g
s
.371 .56733 m .35149 .617 L .38064 .62976 L p .707 .577 .707 r
F P
0 g
s
.64613 .63505 m .64219 .67146 L .63508 .68035 L p .707 .577 .707 r
F P
0 g
s
.43018 .58912 m .41066 .63879 L .4386 .64318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67966 .52573 m .66014 .5754 L .64409 .58104 L p .707 .577 .707 r
F P
0 g
s
.65804 .7515 m .65352 .73309 L .66076 .72596 L p .707 .577 .707 r
F P
0 g
s
.66014 .5754 m .67966 .52573 L .70278 .52507 L p .707 .577 .707 r
F P
0 g
s
.66076 .72596 m .66527 .74437 L .65804 .7515 L p .707 .577 .707 r
F P
0 g
s
.32604 .60175 m .34556 .55208 L .32632 .53582 L p .707 .577 .707 r
F P
0 g
s
.34556 .55208 m .32604 .60175 L .35149 .617 L p .707 .577 .707 r
F P
0 g
s
.839 .65804 m .83506 .69444 L .8226 .68417 L p .707 .577 .707 r
F P
0 g
s
.8226 .68417 m .82653 .64777 L .839 .65804 L p .707 .577 .707 r
F P
0 g
s
.8491 .6838 m .85361 .70221 L .8417 .6999 L p .707 .577 .707 r
F P
0 g
s
.8417 .6999 m .83719 .68149 L .8491 .6838 L p .707 .577 .707 r
F P
0 g
s
.45812 .59351 m .4386 .64318 L .46173 .64253 L p .707 .577 .707 r
F P
0 g
s
.46173 .64253 m .48124 .59286 L .45812 .59351 L p .707 .577 .707 r
F P
0 g
s
.83459 .58276 m .81507 .63243 L .79583 .61618 L p .707 .577 .707 r
F P
0 g
s
.79583 .61618 m .81535 .56651 L .83459 .58276 L p .707 .577 .707 r
F P
0 g
s
.64219 .67146 m .64613 .63505 L .66247 .62821 L p .707 .577 .707 r
F P
0 g
s
.38651 .68136 m .39045 .64496 L .35946 .63972 L p .707 .577 .707 r
F P
0 g
s
.39045 .64496 m .38651 .68136 L .41819 .6836 L p .707 .577 .707 r
F P
0 g
s
.41819 .6836 m .42213 .64719 L .39045 .64496 L p .707 .577 .707 r
F P
0 g
s
.42213 .64719 m .41819 .6836 L .44744 .6826 L p .707 .577 .707 r
F P
0 g
s
.44744 .6826 m .45138 .6462 L .42213 .64719 L p .707 .577 .707 r
F P
0 g
s
.35552 .67613 m .35946 .63972 L .33218 .63199 L p .707 .577 .707 r
F P
0 g
s
.35946 .63972 m .35552 .67613 L .38651 .68136 L p .707 .577 .707 r
F P
0 g
s
.66247 .62821 m .65853 .66462 L .64219 .67146 L p .707 .577 .707 r
F P
0 g
s
.3068 .58549 m .32632 .53582 L .31517 .52016 L p .707 .577 .707 r
F P
0 g
s
.32632 .53582 m .3068 .58549 L .32604 .60175 L p .707 .577 .707 r
F P
0 g
s
.70278 .52507 m .68327 .57474 L .66014 .5754 L p .707 .577 .707 r
F P
0 g
s
.68327 .57474 m .70278 .52507 L .73073 .52947 L p .707 .577 .707 r
F P
0 g
s
.45138 .6462 m .44744 .6826 L .47141 .67849 L p .707 .577 .707 r
F P
0 g
s
.47141 .67849 m .47535 .64208 L .45138 .6462 L p .707 .577 .707 r
F P
0 g
s
.33218 .63199 m .32824 .6684 L .35552 .67613 L p .707 .577 .707 r
F P
0 g
s
.66527 .74437 m .66076 .72596 L .67698 .71736 L p .707 .577 .707 r
F P
0 g
s
.81535 .56651 m .79583 .61618 L .77039 .60092 L p .707 .577 .707 r
F P
0 g
s
.77039 .60092 m .7899 .55125 L .81535 .56651 L p .707 .577 .707 r
F P
0 g
s
.3761 .72694 m .37158 .70853 L .34508 .71193 L p .707 .577 .707 r
F P
0 g
s
.32824 .6684 m .33218 .63199 L .31128 .62253 L p .707 .577 .707 r
F P
0 g
s
.82653 .64777 m .8226 .68417 L .8017 .67471 L p .707 .577 .707 r
F P
0 g
s
.8017 .67471 m .80564 .6383 L .82653 .64777 L p .707 .577 .707 r
F P
0 g
s
.48124 .59286 m .46173 .64253 L .47778 .63688 L p .707 .577 .707 r
F P
0 g
s
.47778 .63688 m .49729 .58721 L .48124 .59286 L p .707 .577 .707 r
F P
0 g
s
.67698 .71736 m .68149 .73577 L .66527 .74437 L p .707 .577 .707 r
F P
0 g
s
.34508 .71193 m .34959 .73034 L .3761 .72694 L p .707 .577 .707 r
F P
0 g
s
.83719 .68149 m .8417 .6999 L .82151 .70048 L p .707 .577 .707 r
F P
0 g
s
.82151 .70048 m .81699 .68207 L .83719 .68149 L p .707 .577 .707 r
F P
0 g
s
.65853 .66462 m .66247 .62821 L .68644 .6241 L p .707 .577 .707 r
F P
0 g
s
.71121 .57914 m .73073 .52947 L .76074 .53849 L p .707 .577 .707 r
F P
0 g
s
.73073 .52947 m .71121 .57914 L .68327 .57474 L p .707 .577 .707 r
F P
0 g
s
.7899 .55125 m .77039 .60092 L .74123 .58816 L p .707 .577 .707 r
F P
0 g
s
.74123 .58816 m .76074 .53849 L .7899 .55125 L p .707 .577 .707 r
F P
0 g
s
.31128 .62253 m .30734 .65894 L .32824 .6684 L p .707 .577 .707 r
F P
0 g
s
.76074 .53849 m .74123 .58816 L .71121 .57914 L p .707 .577 .707 r
F P
0 g
s
.31517 .52016 m .29565 .56983 L .3068 .58549 L p .707 .577 .707 r
F P
0 g
s
.47535 .64208 m .47141 .67849 L .48775 .67165 L p .707 .577 .707 r
F P
0 g
s
.48775 .67165 m .49169 .63524 L .47535 .64208 L p .707 .577 .707 r
F P
0 g
s
.34959 .73034 m .34508 .71193 L .32488 .71251 L p .707 .577 .707 r
F P
0 g
s
.29565 .56983 m .31517 .52016 L .31319 .50663 L p .707 .577 .707 r
F P
0 g
s
.68644 .6241 m .6825 .6605 L .65853 .66462 L p .707 .577 .707 r
F P
0 g
s
.32488 .71251 m .3294 .73092 L .34959 .73034 L p .707 .577 .707 r
F P
0 g
s
.30734 .65894 m .31128 .62253 L .29882 .61226 L p .707 .577 .707 r
F P
0 g
s
.4851 .67664 m .48961 .69505 L .50583 .68645 L p .707 .577 .707 r
F P
0 g
s
.50583 .68645 m .50131 .66804 L .4851 .67664 L p .707 .577 .707 r
F P
0 g
s
.80564 .6383 m .8017 .67471 L .77442 .66698 L p .707 .577 .707 r
F P
0 g
s
.77442 .66698 m .77836 .63057 L .80564 .6383 L p .707 .577 .707 r
F P
0 g
s
.68149 .73577 m .67698 .71736 L .70059 .70813 L p .707 .577 .707 r
F P
0 g
s
.6825 .6605 m .68644 .6241 L .71569 .62311 L p .707 .577 .707 r
F P
0 g
s
.49729 .58721 m .47778 .63688 L .48518 .6268 L p .707 .577 .707 r
F P
0 g
s
.48518 .6268 m .5047 .57713 L .49729 .58721 L p .707 .577 .707 r
F P
0 g
s
.70059 .70813 m .70511 .72654 L .68149 .73577 L p .707 .577 .707 r
F P
0 g
s
.81699 .68207 m .82151 .70048 L .795 .70388 L p .707 .577 .707 r
F P
0 g
s
.795 .70388 m .79049 .68547 L .81699 .68207 L p .707 .577 .707 r
F P
0 g
s
.29882 .61226 m .29488 .64866 L .30734 .65894 L p .707 .577 .707 r
F P
0 g
s
.77836 .63057 m .77442 .66698 L .74343 .66174 L p .707 .577 .707 r
F P
0 g
s
.74343 .66174 m .74737 .62534 L .77836 .63057 L p .707 .577 .707 r
F P
0 g
s
.71569 .62311 m .71175 .65951 L .6825 .6605 L p .707 .577 .707 r
F P
0 g
s
.71175 .65951 m .71569 .62311 L .74737 .62534 L p .707 .577 .707 r
F P
0 g
s
.31319 .50663 m .29368 .5563 L .29565 .56983 L p .707 .577 .707 r
F P
0 g
s
.3294 .73092 m .32488 .71251 L .31297 .7102 L p .707 .577 .707 r
F P
0 g
s
.74737 .62534 m .74343 .66174 L .71175 .65951 L p .707 .577 .707 r
F P
0 g
s
.49169 .63524 m .48775 .67165 L .49486 .66276 L p .707 .577 .707 r
F P
0 g
s
.49486 .66276 m .4988 .62635 L .49169 .63524 L p .707 .577 .707 r
F P
0 g
s
.70511 .72654 m .70059 .70813 L .72929 .69917 L p .707 .577 .707 r
F P
0 g
s
.31297 .7102 m .31749 .72861 L .3294 .73092 L p .707 .577 .707 r
F P
0 g
s
.29368 .5563 m .31319 .50663 L .3206 .49654 L p .707 .577 .707 r
F P
0 g
s
.72929 .69917 m .73381 .71758 L .70511 .72654 L p .707 .577 .707 r
F P
0 g
s
.79049 .68547 m .795 .70388 L .76478 .70977 L p .707 .577 .707 r
F P
0 g
s
.76478 .70977 m .76027 .69136 L .79049 .68547 L p .707 .577 .707 r
F P
0 g
s
.50131 .66804 m .50583 .68645 L .51306 .67932 L p .707 .577 .707 r
F P
0 g
s
.51306 .67932 m .50855 .66091 L .50131 .66804 L p .707 .577 .707 r
F P
0 g
s
.29488 .64866 m .29882 .61226 L .29601 .60218 L p .707 .577 .707 r
F P
0 g
s
.73381 .71758 m .72929 .69917 L .76027 .69136 L p .707 .577 .707 r
F P
0 g
s
.76027 .69136 m .76478 .70977 L .73381 .71758 L p .707 .577 .707 r
F P
0 g
s
.5047 .57713 m .48518 .6268 L .48321 .61326 L p .707 .577 .707 r
F P
0 g
s
.48321 .61326 m .50273 .56359 L .5047 .57713 L p .707 .577 .707 r
F P
0 g
s
.29601 .60218 m .29207 .63859 L .29488 .64866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.3206 .49654 m .30108 .54621 L .29368 .5563 L p .707 .577 .707 r
F P
0 g
s
.31749 .72861 m .31297 .7102 L .31051 .70524 L p .707 .577 .707 r
F P
0 g
s
.4988 .62635 m .49486 .66276 L .49205 .65268 L p .707 .577 .707 r
F P
0 g
s
.49205 .65268 m .49599 .61627 L .4988 .62635 L p .707 .577 .707 r
F P
0 g
s
.31051 .70524 m .31503 .72365 L .31749 .72861 L p .707 .577 .707 r
F P
0 g
s
.30108 .54621 m .3206 .49654 L .33665 .49089 L p .707 .577 .707 r
F P
0 g
s
.50855 .66091 m .51306 .67932 L .5106 .67436 L p .707 .577 .707 r
F P
0 g
s
.5106 .67436 m .50609 .65595 L .50855 .66091 L p .707 .577 .707 r
F P
0 g
s
.29207 .63859 m .29601 .60218 L .30312 .59329 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50273 .56359 m .48321 .61326 L .47206 .5976 L p .707 .577 .707 r
F P
0 g
s
.47206 .5976 m .49158 .54793 L .50273 .56359 L p .707 .577 .707 r
F P
0 g
s
.30312 .59329 m .29918 .62969 L .29207 .63859 L p .707 .577 .707 r
F P
0 g
s
.33665 .49089 m .31713 .54056 L .30108 .54621 L p .707 .577 .707 r
F P
0 g
s
.31503 .72365 m .31051 .70524 L .31775 .69811 L p .707 .577 .707 r
F P
0 g
s
.31713 .54056 m .33665 .49089 L .35977 .49024 L p .707 .577 .707 r
F P
0 g
s
.49599 .61627 m .49205 .65268 L .47958 .64241 L p .707 .577 .707 r
F P
0 g
s
.47958 .64241 m .48352 .606 L .49599 .61627 L p .707 .577 .707 r
F P
0 g
s
.31775 .69811 m .32226 .71652 L .31503 .72365 L p .707 .577 .707 r
F P
0 g
s
.29918 .62969 m .30312 .59329 L .31946 .58645 L p .707 .577 .707 r
F P
0 g
s
.50609 .65595 m .5106 .67436 L .49869 .67205 L p .707 .577 .707 r
F P
0 g
s
.49869 .67205 m .49418 .65364 L .50609 .65595 L p .707 .577 .707 r
F P
0 g
s
.49158 .54793 m .47206 .5976 L .45282 .58135 L p .707 .577 .707 r
F P
0 g
s
.45282 .58135 m .47234 .53168 L .49158 .54793 L p .707 .577 .707 r
F P
0 g
s
.31946 .58645 m .31552 .62286 L .29918 .62969 L p .707 .577 .707 r
F P
0 g
s
.35977 .49024 m .34026 .53991 L .31713 .54056 L p .707 .577 .707 r
F P
0 g
s
.34026 .53991 m .35977 .49024 L .38771 .49464 L p .707 .577 .707 r
F P
0 g
s
.48352 .606 m .47958 .64241 L .45869 .63294 L p .707 .577 .707 r
F P
0 g
s
.45869 .63294 m .46263 .59654 L .48352 .606 L p .707 .577 .707 r
F P
0 g
s
.47234 .53168 m .45282 .58135 L .42738 .56609 L p .707 .577 .707 r
F P
0 g
s
.42738 .56609 m .44689 .51642 L .47234 .53168 L p .707 .577 .707 r
F P
0 g
s
.32226 .71652 m .31775 .69811 L .33396 .68951 L p .707 .577 .707 r
F P
0 g
s
.33396 .68951 m .33848 .70792 L .32226 .71652 L p .707 .577 .707 r
F P
0 g
s
.31552 .62286 m .31946 .58645 L .34343 .58233 L p .707 .577 .707 r
F P
0 g
s
.3682 .54431 m .38771 .49464 L .41773 .50366 L p .707 .577 .707 r
F P
0 g
s
.38771 .49464 m .3682 .54431 L .34026 .53991 L p .707 .577 .707 r
F P
0 g
s
.49418 .65364 m .49869 .67205 L .4785 .67263 L p .707 .577 .707 r
F P
0 g
s
.4785 .67263 m .47398 .65422 L .49418 .65364 L p .707 .577 .707 r
F P
0 g
s
.44689 .51642 m .42738 .56609 L .39822 .55333 L p .707 .577 .707 r
F P
0 g
s
.39822 .55333 m .41773 .50366 L .44689 .51642 L p .707 .577 .707 r
F P
0 g
s
.41773 .50366 m .39822 .55333 L .3682 .54431 L p .707 .577 .707 r
F P
0 g
s
.34343 .58233 m .33949 .61874 L .31552 .62286 L p .707 .577 .707 r
F P
0 g
s
.46263 .59654 m .45869 .63294 L .43141 .62522 L p .707 .577 .707 r
F P
0 g
s
.43141 .62522 m .43535 .58881 L .46263 .59654 L p .707 .577 .707 r
F P
0 g
s
.33949 .61874 m .34343 .58233 L .37268 .58134 L p .707 .577 .707 r
F P
0 g
s
.33848 .70792 m .33396 .68951 L .35758 .68028 L p .707 .577 .707 r
F P
0 g
s
.35758 .68028 m .36209 .69869 L .33848 .70792 L p .707 .577 .707 r
F P
0 g
s
.47398 .65422 m .4785 .67263 L .45199 .67603 L p .707 .577 .707 r
F P
0 g
s
.45199 .67603 m .44748 .65762 L .47398 .65422 L p .707 .577 .707 r
F P
0 g
s
.43535 .58881 m .43141 .62522 L .40042 .61998 L p .707 .577 .707 r
F P
0 g
s
.40042 .61998 m .40436 .58357 L .43535 .58881 L p .707 .577 .707 r
F P
0 g
s
.37268 .58134 m .36874 .61775 L .33949 .61874 L p .707 .577 .707 r
F P
0 g
s
.36874 .61775 m .37268 .58134 L .40436 .58357 L p .707 .577 .707 r
F P
0 g
s
.40436 .58357 m .40042 .61998 L .36874 .61775 L p .707 .577 .707 r
F P
0 g
s
.36209 .69869 m .35758 .68028 L .38628 .67132 L p .707 .577 .707 r
F P
0 g
s
.38628 .67132 m .3908 .68973 L .36209 .69869 L p .707 .577 .707 r
F P
0 g
s
.44748 .65762 m .45199 .67603 L .42177 .68192 L p .707 .577 .707 r
F P
0 g
s
.42177 .68192 m .41726 .66351 L .44748 .65762 L p .707 .577 .707 r
F P
0 g
s
.3908 .68973 m .38628 .67132 L .41726 .66351 L p .707 .577 .707 r
F P
0 g
s
.41726 .66351 m .42177 .68192 L .3908 .68973 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007Uooah008Io
o`00MGoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001aOol40006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001kOol006moo`800003FUH005YF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Moo`00KGoo
0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000Lgoo001[Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001`Ool006Yoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP00008006eoo`00JGoo
00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00UYF0`00JWoo001XOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0P00J7oo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P00Igoo001XOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000006Eoo`00J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP05001J
EUYFFUH0001TOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001oogoo065oo`00
J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<007ooOol0HGoo001XOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0<FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001R
Ool006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1ROol006Moo`=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo069oo`00Igoo0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol2FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1R
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP04FUH00`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001OOol;0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05eoo`<000IJEP04001JEUYFFUH60006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`800003
FUH005YF00EJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00FWoo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<000YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Moo`00FGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF0000
0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001IOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00Igoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Yoo`/0059oo`00
EWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0027oo0P0000=JEP00FUH015YF00@005YFFUIJEPH004aoo`00EWoo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Woo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00BGoo001FOol01@00FUIJ
EUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00AWoo001EOol20002
FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF0`00@goo001EOol01000FUH00000
0UYF00@005YFFUH000=oo`03001JEP0000D000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH00000
@Goo001DOol30004FUH01000FUIJEUYF0P0000Eoo`00FUIJEP0000AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEP<003ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF0P000UYF00<005YF
FUH00eYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0P00?7oo001COol200000eYF001JEP02
FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00UYF0P002EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP<0
03Yoo`00Dgoo00<005YFFUH015YF00<005YFFUH01EYF10001EYF00<005YFFUH015YF0P001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH0000iOol005=oo`03001JEP0000=JEP03001JEUYF00EJEP04001J
EUYFFUH20004FUH01000FUIJEUYF0`000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03
001oogoo03Ioo`00Dgoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<0
05YFFUH01@0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo00<005YF0000
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF0P00=Woo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30002FUH50000
0eYF001JEP02FUH20008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00Oomoo`0cOol005Aoo`05
001JEUYFFUH00007FUH00`00FUIJEP06FUH01@00FUH00000FUH01@0000=JEP00FUH015YF0P001EYF
00<005YFFUH015YF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00MJEP<003=oo`00EGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
009JEPD0009JEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool005YF0002FUH;0004
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000<Woo001EOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH025YF0`001eYF00<0
05YFFUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00L0
05YF001ooeYF001JEP020002FUH00`00FUIJEP020004Ool60007FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000`Ool003Qoo`/001=oo`03001JEUYF00EJEQP000YJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P0015YF00<005YFFUH00UYF00<007ooOol01goo0P001EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0;Goo000fOol30006FUH01000FUIJ
EUYF1P003Woo00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF0`0015YF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00AJEP03001oogoo00Qoo`<00003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP8002ioo`00=7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00@005YF000000eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000=JEP04001JEUYF0003FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0004FUH00`00FUIJEP04FUH3000;Ool3
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000^Ool003=oo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP<000Qoo`80009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000T000AJEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP05
001JEUYFFUH0000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00;Goo000c
Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0017oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol01goo0`000Woo0`00
00=JEP00FUH025YF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00<Woo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<00007FUH005YFFUH0
05YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH015YF
00<005YFFUH015YF00<005YFFUH00eYF0P001Woo1@0017oo0P002EYF00<005YFFUH015YF00<005YF
FUH00UYF00<007ooOol0:Woo000bOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF0P0017oo1@001Woo0P001UYF00<005YFFUH015YF00<005YFFUH00eYF00<007oo
Ool0:Woo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
00000P0000=oo`0000000`0027oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000aOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00=JEPD000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000]oo`<000IJEP03001JEUYF009JEP03001JEP0002aoo`00<7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF
00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000;Ool00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000/Ool002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEP0000<0009oo`03001JEUYF00<000IJEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30009Ool00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000]Ool002moo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=J
EP8000AJEP03001oo`00009JEP03001JEUYF008000AJEP03001JEUYF00IJEPH000IJEP03001JEUYF
00=JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005Ool00`00FUIJEP03FUHH0003FUH50005Ool20002FUH00`00FUIJEP02FUH00`00FUH0000]
Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH005YF0P0000AJEP000000009JEP<0009JEP03001JEUYF009JEP800004FUH005YFFUH30003
FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01@000eYF2@001EYF00<005YF0000;Goo000^Ool20002FUH;0004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEP<00004FUH005YF0005FUH00`00FUH0
00070002FUH00`00FUIJEP05FUH400000eYF001JEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00D005YFFUIJEP0000AJEP03001JEP00
02ioo`00;Woo00@005YF0000009JEP04001JEUYF0005Ool60008FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP02FUH500000eYF001JEP07FUH01000FUIJ
EUYF0`0015YF00H005YFFUH005YF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`001EYF00L005YFFUIJEP00FUH0000^Ool002eoo`<000AJEP04001J
EUYFFUH20009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH400000eYF001JEP03FUH:0004FUH00`00FUIJEP04FUH400001eYF001JEUYF001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP06001J
EUYF001JEP00;goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00Oomoo`09Ool300000eYF
001JEP07FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF00000`000eYF0`0000=JEP00
FUH00eYF4@000UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000MJEP00001JEP00FUH0000_Ool002aoo`800003FUH005YF009JEP03001J
EUYF00EJEP03001oogoo00]oo`8000QJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH80008FUH80003FUH01000FUH005YF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<007ooOol0;Goo000/Ool0
0`00FUIJEP04FUH00`00FUIJEP05FUH3000=Ool20006FUH01@00FUIJEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP00Ool0;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0027oo0`000Woo0P0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool50003Ool2000015YF001J
EUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00000_Ool002eoo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001oogoo009oo`D000Eoo`8000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00FUIJEP03FUH0
0`00FUIJEP020007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20004
FUH00`00FUIJEP02FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001eYF00<005YFFUH01UYF0`000Woo1@001goo0P00
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF1`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF0004FUH00`00FUH000050007Ool200000eYF001JEP090004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000^Ool01000FUIJEP001UYF00<005YF
FUH01UYF00@005YFFUIJEP800004Ool00000000:Ool20003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP001eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF001JEP00FUH0
0002FUH40002FUH01@00FUIJEUYF000027oo100000AJEP00000000=JEPL000EJEP03001JEUYF00=J
EP03001JEUYF009JEP8002eoo`00;Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP8000ioo`<0009JEP<000IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01P00FUH005YF001JEP@0009JEP800003FUH005YF00=JEP8000Yoo`D00003FUH005YF00IJ
EP@00003FUH005YF00AJEP03001JEUYF009JEP8002eoo`00;goo00<005YFFUH01EYF40000UYF1000
37oo00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF3@001EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP8000=JEP03001JEUYF009JEP<000EJEP03001oogoo00Moo`X000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP02FUH2000]Ool0031oo`03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
009JEPX000Uoo`03001JEUYF00=JEP03001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF009J
EPh000AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF00<005YFFUH00eYF00<005YF00000`0000=JEP00000027oo1@001Goo30000eYF
00L005YFFUIJEP00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Aoo`8000=JEP04001JEP00FUH30007FUH00`00FUIJEP05FUH60003FUH00`00FUH0
00030002FUH30005FUH00`00FUH00005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH50007Ool3000AOol;000]Ool002mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000L0009JEP06001JEP00001JEP0025YF00<005YFFUH00eYF3@0015YF0P000eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH010004Goo1P000eYF00<005YFFUH00UYF00<005YF
00000P00:goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000020003FUH00`00FUIJEP07FUH00`00FUH00002
000:FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP@000IJEP03001JEUYF00AJEP@00003FUH005YF00YJEP03001JEUYF00YJEP04001JEP000008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool200000eYF
00000005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP05FUH50009FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004Ool40004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>000YOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000EJEP04001JEP000004FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
1Woo1@0000=JEP00FUH01UYF00<005YFFUH00`000eYF00<005YFFUH01eYF00<005YFFUH00UYF2000
00=JEP00FUH00eYF00H005YF001JEP00FUH2000YOol002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH40003FUH60006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20008Ool2000015YF000000001UYF0`001UYF00<005YFFUH01UYF1P000UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00@005YFFUH002Uoo`00;7oo00<005YF00000eYF
00@005YFFUIJEPX000IJEPT000AJEP03001JEUYF009JEP05001JEUYF001JEP090003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool01000FUIJEUYF1P0000=JEP00FUH01eYF00<005YF
FUH00UYF10001eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP8002Yoo`00;7oo00<005YF0000
0eYF10002Woo0P0015YF00<005YFFUH01UYF1P0015YF00@005YF000000EJEP03001JEUYF00AJEP03
001JEUYF015JEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H000Eoo`03001JEUYF008000EJEP03001JEUYF00IJEP03001JEP00
008000=JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEP00001JEP000eYF0P00:goo000/Ool0
1000FUH005YF0P0000AJEP00000000aoo`800003FUH005YF00MJEP03001JEUYF00AJEP80009JEP80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH9
0007FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00@005YF0000
02eoo`00;7oo00H005YF000005YF0004FUH3000;Ool3000015YF000000000eYF00<005YFFUH01UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P00
15YF0P000UYF00<005YFFUH01EYF00<005YFFUH02P000eYF00<005YFFUH00UYF20001UYF0`00;goo
000/Ool20003FUH00`00FUIJEP03FUH01000FUH0000037oo1@0000=JEP00FUH01eYF00<005YFFUH0
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPP0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEP00
00<000AJEP03001JEUYF00AJEP@000Eoo`d000QJEP04001JEUYFFUH2000bOol002aoo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEUYFFUH30009Ool80007FUH01000FUIJEUYF3P002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P001EYF00@005YFFUIJEP8000EJEP04001JEUYFFUH2000:Ool50006FUH00`00FUIJEP06
FUH01000FUH00000=7oo000/Ool01@00FUIJEUYF00001UYF00<005YFFUH015YF1P000goo1@000goo
10000UYF00@005YFFUIJEPH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH01P00FUH00000FUH000Moo`@00003FUH005YF00QJ
EP03001JEUYF00AJEP<003Ioo`00;7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
009JEPT000Ioo`X000AJEP03001JEUYF00=JEP03001JEUYF00EJEQh000UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000EJEP04001JEUYF0002FUH00`00FUIJEP02FUH30002FUH0
0`00Ool000050005FUH00`00FUIJEP07FUH00`00FUIJEP04000iOol002aoo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH60003FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
2@000eYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000]Ool01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEPD000UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@0049oo`00;Woo0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00@005YFFUIJEP@000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF009JEP@000EJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40016Ool0031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH0
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF100000=JEP00
FUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF00@004Yoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF1P0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00D005YFFUIJEP0000=JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00<000IJEP03001J
EUYF00=JEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP02FUH6001>Ool0
03=oo`800003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP03FUH00`00FUH00005FUH01000FUIJEP000eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF0000
1P0015YF3P00E7oo000eOol30006FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<005YF0000
1UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00E7oo000hOol40002FUH00`00FUIJEP04
FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF3P000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF0`0015YF00<005YF00000P0015YF00H0
05YF000005YF0005FUH00`00FUIJEP02FUH2001DOol003aoo`T00003FUH005YF00QJEP03001JEUYF
00AJEPH00003FUH0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH00002Ool;0004
FUH01`00FUIJEUYF001JEP0005Aoo`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH0100000=J
EP00FUH00UYF100015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP800003FUH0000000ioo`<00003FUH0
05YF00D005Aoo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01EYF3@000Woo0P0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0`003Woo1P000UYF00<005YF00000P00DWoo000iOol20003FUH00`00
FUIJEP07FUH00`00FUIJEP04000<Ool300000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30006Ool80003FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000gOol20006FUH00`00FUIJEP04
FUH5000<Ool400001EYF001JEUYF000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF2@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00DGoo000eOol30007FUH00`00FUIJEP04000<
Ool50005FUH01000FUIJEUYF0P000UYF00<005YFFUH04EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YFFUIJEP00055oo`00<goo0P000eYF00<005YFFUH015YF0`0037oo
10000UYF00<005YFFUH01UYF00@005YFFUIJEP@001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00DGoo000bOol20004FUH00`00FUIJEP02FUH2000:Ool50006
FUH00`00FUIJEP06FUH01000FUH000000goo00<005YFFUH045YF00<005YFFUH02eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF3P00D7oo000aOol00`00FUH00005FUH01000FUH0000027oo10000UYF00<0
05YFFUH01eYF00<005YFFUH015YF0`001Woo0P0045YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF200000=JEP00
FUH00eYF00H005YF001JEP00FUH2001@Ool0035oo`04001JEUYF0003FUH30004Ool60006FUH00`00
FUIJEP07FUH00`00FUIJEP04000;Ool2000>FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH60002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEP00D7oo000aOol01@00FUIJEP00FUH02@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF10004Goo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF1P001eYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00DGoo000aOol200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000GOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0`000eYF0P00DWoo000bOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH00002000NOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH01000FUH00000
E7oo000bOol01000FUIJEP001UYF00<005YFFUH015YF00<005YFFUH00UYF1P009goo1P002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF2P000eYF00<005YFFUH01EYF00<005YF0000
0`001EYF0`00EWoo000bOol20002FUH00`00FUIJEP03FUH01000FUIJEUYF2000<goo1P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@001Goo4P000eYF00@005YFFUIJEP8005Uoo`00
<goo0P0000=JEP00FUH00UYF1P00@Goo2P001UYF00<005YFFUH00eYF2@002Goo1P001UYF00<005YF
FUH01UYF00@005YF000005]oo`00=Goo1@00DGoo30000eYF00@005YF000000Uoo`H000UJEP03001J
EUYF00AJEP<005eoo`00TWoo00@005YFFUH000AJEP8000Eoo`H000EJEP03001JEUYF00MJEP03001J
EUYF00@0061oo`00Tgoo00D005YFFUH005YF00T000=JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
06Aoo`00Tgoo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`00J7oo002COol01@00FUH005YF000015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00Jgoo002DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH00UYF1@00KWoo002DOol0
1@00FUIJEUYF000015YF00<005YFFUH00UYF2000Lgoo002DOol>001kOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58645 .75664 m .60596 .70697 L .5768 .6942 L p .707 .577 .707 r
F P
0 g
s
.60596 .70697 m .58645 .75664 L .61647 .76566 L p .707 .577 .707 r
F P
0 g
s
.61647 .76566 m .63598 .71599 L .60596 .70697 L p .707 .577 .707 r
F P
0 g
s
.55729 .74387 m .5768 .6942 L .55136 .67895 L p .707 .577 .707 r
F P
0 g
s
.5768 .6942 m .55729 .74387 L .58645 .75664 L p .707 .577 .707 r
F P
0 g
s
.63598 .71599 m .61647 .76566 L .64441 .77006 L p .707 .577 .707 r
F P
0 g
s
.64441 .77006 m .66392 .72039 L .63598 .71599 L p .707 .577 .707 r
F P
0 g
s
.53185 .72862 m .55136 .67895 L .53212 .66269 L p .707 .577 .707 r
F P
0 g
s
.55136 .67895 m .53185 .72862 L .55729 .74387 L p .707 .577 .707 r
F P
0 g
s
.66392 .72039 m .64441 .77006 L .66754 .7694 L p .707 .577 .707 r
F P
0 g
s
.66754 .7694 m .68705 .71973 L .66392 .72039 L p .707 .577 .707 r
F P
0 g
s
.59232 .81517 m .59626 .77876 L .56526 .77352 L p .707 .577 .707 r
F P
0 g
s
.59626 .77876 m .59232 .81517 L .62399 .8174 L p .707 .577 .707 r
F P
0 g
s
.62399 .8174 m .62793 .78099 L .59626 .77876 L p .707 .577 .707 r
F P
0 g
s
.6431 .83313 m .63859 .81472 L .60761 .82253 L p .707 .577 .707 r
F P
0 g
s
.63859 .81472 m .6431 .83313 L .6718 .82417 L p .707 .577 .707 r
F P
0 g
s
.6718 .82417 m .66729 .80576 L .63859 .81472 L p .707 .577 .707 r
F P
0 g
s
.62793 .78099 m .62399 .8174 L .65325 .81641 L p .707 .577 .707 r
F P
0 g
s
.65325 .81641 m .65719 .78 L .62793 .78099 L p .707 .577 .707 r
F P
0 g
s
.56132 .80993 m .56526 .77352 L .53798 .7658 L p .707 .577 .707 r
F P
0 g
s
.56526 .77352 m .56132 .80993 L .59232 .81517 L p .707 .577 .707 r
F P
0 g
s
.61212 .84094 m .60761 .82253 L .57739 .82842 L p .707 .577 .707 r
F P
0 g
s
.60761 .82253 m .61212 .84094 L .6431 .83313 L p .707 .577 .707 r
F P
0 g
s
.51261 .71236 m .53212 .66269 L .52097 .64703 L p .707 .577 .707 r
F P
0 g
s
.53212 .66269 m .51261 .71236 L .53185 .72862 L p .707 .577 .707 r
F P
0 g
s
.57739 .82842 m .5819 .84683 L .61212 .84094 L p .707 .577 .707 r
F P
0 g
s
.5819 .84683 m .57739 .82842 L .55088 .83182 L p .707 .577 .707 r
F P
0 g
s
.66729 .80576 m .6718 .82417 L .69542 .81494 L p .707 .577 .707 r
F P
0 g
s
.69542 .81494 m .6909 .79653 L .66729 .80576 L p .707 .577 .707 r
F P
0 g
s
.65719 .78 m .65325 .81641 L .67722 .81229 L p .707 .577 .707 r
F P
0 g
s
.67722 .81229 m .68116 .77588 L .65719 .78 L p .707 .577 .707 r
F P
0 g
s
.53798 .7658 m .53405 .8022 L .56132 .80993 L p .707 .577 .707 r
F P
0 g
s
.68705 .71973 m .66754 .7694 L .68359 .76375 L p .707 .577 .707 r
F P
0 g
s
.68359 .76375 m .7031 .71408 L .68705 .71973 L p .707 .577 .707 r
F P
0 g
s
.55088 .83182 m .5554 .85023 L .5819 .84683 L p .707 .577 .707 r
F P
0 g
s
.53405 .8022 m .53798 .7658 L .51709 .75633 L p .707 .577 .707 r
F P
0 g
s
.51709 .75633 m .51315 .79274 L .53405 .8022 L p .707 .577 .707 r
F P
0 g
s
.52097 .64703 m .50146 .6967 L .51261 .71236 L p .707 .577 .707 r
F P
0 g
s
.5554 .85023 m .55088 .83182 L .53069 .83239 L p .707 .577 .707 r
F P
0 g
s
.50146 .6967 m .52097 .64703 L .519 .6335 L p .707 .577 .707 r
F P
0 g
s
.53069 .83239 m .5352 .8508 L .5554 .85023 L p .707 .577 .707 r
F P
0 g
s
.6909 .79653 m .69542 .81494 L .71163 .80634 L p .707 .577 .707 r
F P
0 g
s
.68116 .77588 m .67722 .81229 L .69356 .80545 L p .707 .577 .707 r
F P
0 g
s
.71163 .80634 m .70712 .78793 L .6909 .79653 L p .707 .577 .707 r
F P
0 g
s
.69356 .80545 m .6975 .76905 L .68116 .77588 L p .707 .577 .707 r
F P
0 g
s
.51315 .79274 m .51709 .75633 L .50463 .74606 L p .707 .577 .707 r
F P
0 g
s
.7031 .71408 m .68359 .76375 L .69099 .75367 L p .707 .577 .707 r
F P
0 g
s
.69099 .75367 m .7105 .704 L .7031 .71408 L p .707 .577 .707 r
F P
0 g
s
.50463 .74606 m .50069 .78247 L .51315 .79274 L p .707 .577 .707 r
F P
0 g
s
.519 .6335 m .49949 .68317 L .50146 .6967 L p .707 .577 .707 r
F P
0 g
s
.5352 .8508 m .53069 .83239 L .51878 .83009 L p .707 .577 .707 r
F P
0 g
s
.51878 .83009 m .52329 .8485 L .5352 .8508 L p .707 .577 .707 r
F P
0 g
s
.6975 .76905 m .69356 .80545 L .70067 .79656 L p .707 .577 .707 r
F P
0 g
s
.70067 .79656 m .70461 .76015 L .6975 .76905 L p .707 .577 .707 r
F P
0 g
s
.49949 .68317 m .519 .6335 L .5264 .62341 L p .707 .577 .707 r
F P
0 g
s
.70712 .78793 m .71163 .80634 L .71887 .79921 L p .707 .577 .707 r
F P
0 g
s
.71887 .79921 m .71435 .7808 L .70712 .78793 L p .707 .577 .707 r
F P
0 g
s
.50069 .78247 m .50463 .74606 L .50181 .73598 L p .707 .577 .707 r
F P
0 g
s
.46555 .82173 m .50283 .32534 L .45895 .31936 L p .707 .577 .707 r
F P
0 g
s
.50181 .73598 m .49787 .77239 L .50069 .78247 L p .707 .577 .707 r
F P
0 g
s
.5264 .62341 m .50689 .67308 L .49949 .68317 L p .707 .577 .707 r
F P
0 g
s
.50689 .67308 m .5264 .62341 L .54245 .61777 L p .707 .577 .707 r
F P
0 g
s
.49787 .77239 m .50181 .73598 L .50892 .72709 L p .707 .577 .707 r
F P
0 g
s
.50892 .72709 m .50498 .7635 L .49787 .77239 L p .707 .577 .707 r
F P
0 g
s
.54245 .61777 m .52294 .66744 L .50689 .67308 L p .707 .577 .707 r
F P
0 g
s
.50498 .7635 m .50892 .72709 L .52526 .72025 L p .707 .577 .707 r
F P
0 g
s
.52526 .72025 m .52132 .75666 L .50498 .7635 L p .707 .577 .707 r
F P
0 g
s
.50283 .32534 m .46555 .82173 L .51038 .82361 L p .707 .577 .707 r
F P
0 g
s
.51038 .82361 m .54766 .32721 L .50283 .32534 L p .707 .577 .707 r
F P
0 g
s
.7105 .704 m .69099 .75367 L .68902 .74013 L p .707 .577 .707 r
F P
0 g
s
.68902 .74013 m .70853 .69046 L .7105 .704 L p .707 .577 .707 r
F P
0 g
s
.52329 .8485 m .51878 .83009 L .51632 .82513 L p .707 .577 .707 r
F P
0 g
s
.51632 .82513 m .52083 .84354 L .52329 .8485 L p .707 .577 .707 r
F P
0 g
s
.52083 .84354 m .51632 .82513 L .52355 .818 L p .707 .577 .707 r
F P
0 g
s
.52294 .66744 m .54245 .61777 L .56558 .61711 L p .707 .577 .707 r
F P
0 g
s
.52355 .818 m .52807 .83641 L .52083 .84354 L p .707 .577 .707 r
F P
0 g
s
.56558 .61711 m .54607 .66678 L .52294 .66744 L p .707 .577 .707 r
F P
0 g
s
.54607 .66678 m .56558 .61711 L .59352 .62151 L p .707 .577 .707 r
F P
0 g
s
.52807 .83641 m .52355 .818 L .53977 .8094 L p .707 .577 .707 r
F P
0 g
s
.53977 .8094 m .54429 .82781 L .52807 .83641 L p .707 .577 .707 r
F P
0 g
s
.52132 .75666 m .52526 .72025 L .54923 .71614 L p .707 .577 .707 r
F P
0 g
s
.59352 .62151 m .57401 .67118 L .54607 .66678 L p .707 .577 .707 r
F P
0 g
s
.54923 .71614 m .5453 .75254 L .52132 .75666 L p .707 .577 .707 r
F P
0 g
s
.54429 .82781 m .53977 .8094 L .56339 .80016 L p .707 .577 .707 r
F P
0 g
s
.5453 .75254 m .54923 .71614 L .57849 .71515 L p .707 .577 .707 r
F P
0 g
s
.56339 .80016 m .5679 .81857 L .54429 .82781 L p .707 .577 .707 r
F P
0 g
s
.57849 .71515 m .57455 .75155 L .5453 .75254 L p .707 .577 .707 r
F P
0 g
s
.54766 .32721 m .51038 .82361 L .55177 .8212 L p .707 .577 .707 r
F P
0 g
s
.55177 .8212 m .58906 .3248 L .54766 .32721 L p .707 .577 .707 r
F P
0 g
s
.42166 .81575 m .45895 .31936 L .42031 .30986 L p .707 .577 .707 r
F P
0 g
s
.45895 .31936 m .42166 .81575 L .46555 .82173 L p .707 .577 .707 r
F P
0 g
s
.70461 .76015 m .70067 .79656 L .69785 .78648 L p .707 .577 .707 r
F P
0 g
s
.69785 .78648 m .70179 .75008 L .70461 .76015 L p .707 .577 .707 r
F P
0 g
s
.71435 .7808 m .71887 .79921 L .71641 .79425 L p .707 .577 .707 r
F P
0 g
s
.71641 .79425 m .7119 .77584 L .71435 .7808 L p .707 .577 .707 r
F P
0 g
s
.57401 .67118 m .59352 .62151 L .62354 .63053 L p .707 .577 .707 r
F P
0 g
s
.62354 .63053 m .60403 .6802 L .57401 .67118 L p .707 .577 .707 r
F P
0 g
s
.57455 .75155 m .57849 .71515 L .61016 .71738 L p .707 .577 .707 r
F P
0 g
s
.61016 .71738 m .60622 .75378 L .57455 .75155 L p .707 .577 .707 r
F P
0 g
s
.5679 .81857 m .56339 .80016 L .59209 .79121 L p .707 .577 .707 r
F P
0 g
s
.59209 .79121 m .5966 .80962 L .5679 .81857 L p .707 .577 .707 r
F P
0 g
s
.58906 .3248 m .55177 .8212 L .58567 .81474 L p .707 .577 .707 r
F P
0 g
s
.58567 .81474 m .62296 .31834 L .58906 .3248 L p .707 .577 .707 r
F P
0 g
s
.38302 .80625 m .42031 .30986 L .39069 .29777 L p .707 .577 .707 r
F P
0 g
s
.42031 .30986 m .38302 .80625 L .42166 .81575 L p .707 .577 .707 r
F P
0 g
s
.70853 .69046 m .68902 .74013 L .67787 .72447 L p .707 .577 .707 r
F P
0 g
s
.67787 .72447 m .69738 .6748 L .70853 .69046 L p .707 .577 .707 r
F P
0 g
s
.24344 .7218 m .26295 .67213 L .2338 .65937 L p .707 .577 .707 r
F P
0 g
s
.26295 .67213 m .24344 .7218 L .27346 .73082 L p .707 .577 .707 r
F P
0 g
s
.27346 .73082 m .29297 .68116 L .26295 .67213 L p .707 .577 .707 r
F P
0 g
s
.21428 .70904 m .2338 .65937 L .20835 .64412 L p .707 .577 .707 r
F P
0 g
s
.2338 .65937 m .21428 .70904 L .24344 .7218 L p .707 .577 .707 r
F P
0 g
s
.29297 .68116 m .27346 .73082 L .3014 .73522 L p .707 .577 .707 r
F P
0 g
s
.3014 .73522 m .32091 .68555 L .29297 .68116 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.18884 .69378 m .20835 .64412 L .18911 .62786 L p .707 .577 .707 r
F P
0 g
s
.20835 .64412 m .18884 .69378 L .21428 .70904 L p .707 .577 .707 r
F P
0 g
s
.70179 .75008 m .69785 .78648 L .68539 .77621 L p .707 .577 .707 r
F P
0 g
s
.68539 .77621 m .68933 .7398 L .70179 .75008 L p .707 .577 .707 r
F P
0 g
s
.6527 .64329 m .63318 .69296 L .60403 .6802 L p .707 .577 .707 r
F P
0 g
s
.60403 .6802 m .62354 .63053 L .6527 .64329 L p .707 .577 .707 r
F P
0 g
s
.64116 .72261 m .63722 .75902 L .60622 .75378 L p .707 .577 .707 r
F P
0 g
s
.60622 .75378 m .61016 .71738 L .64116 .72261 L p .707 .577 .707 r
F P
0 g
s
.5966 .80962 m .59209 .79121 L .62306 .7834 L p .707 .577 .707 r
F P
0 g
s
.62306 .7834 m .62758 .80181 L .5966 .80962 L p .707 .577 .707 r
F P
0 g
s
.62296 .31834 m .58567 .81474 L .60876 .80486 L p .707 .577 .707 r
F P
0 g
s
.60876 .80486 m .64605 .30846 L .62296 .31834 L p .707 .577 .707 r
F P
0 g
s
.7119 .77584 m .71641 .79425 L .7045 .79194 L p .707 .577 .707 r
F P
0 g
s
.7045 .79194 m .69998 .77353 L .7119 .77584 L p .707 .577 .707 r
F P
0 g
s
.32091 .68555 m .3014 .73522 L .32453 .73457 L p .707 .577 .707 r
F P
0 g
s
.32453 .73457 m .34404 .6849 L .32091 .68555 L p .707 .577 .707 r
F P
0 g
s
.69738 .6748 m .67787 .72447 L .65863 .70822 L p .707 .577 .707 r
F P
0 g
s
.65863 .70822 m .67814 .65855 L .69738 .6748 L p .707 .577 .707 r
F P
0 g
s
.24931 .7734 m .25325 .737 L .22225 .73176 L p .707 .577 .707 r
F P
0 g
s
.25325 .737 m .24931 .7734 L .28098 .77563 L p .707 .577 .707 r
F P
0 g
s
.28098 .77563 m .28492 .73923 L .25325 .737 L p .707 .577 .707 r
F P
0 g
s
.28492 .73923 m .28098 .77563 L .31024 .77464 L p .707 .577 .707 r
F P
0 g
s
.31024 .77464 m .31418 .73824 L .28492 .73923 L p .707 .577 .707 r
F P
0 g
s
.34058 .72892 m .36009 .67925 L .34404 .6849 L p .707 .577 .707 r
F P
0 g
s
.34789 .76868 m .35241 .78709 L .36863 .77849 L p .707 .577 .707 r
F P
0 g
s
.36863 .77849 m .36411 .76008 L .34789 .76868 L p .707 .577 .707 r
F P
0 g
s
.36009 .67925 m .34058 .72892 L .34798 .71883 L p .707 .577 .707 r
F P
0 g
s
.34798 .71883 m .36749 .66916 L .36009 .67925 L p .707 .577 .707 r
F P
0 g
s
.35449 .72728 m .35055 .76369 L .35766 .75479 L p .707 .577 .707 r
F P
0 g
s
.35766 .75479 m .3616 .71839 L .35449 .72728 L p .707 .577 .707 r
F P
0 g
s
.36749 .66916 m .34798 .71883 L .34601 .7053 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .36552 .65563 L .36749 .66916 L p .707 .577 .707 r
F P
0 g
s
.3616 .71839 m .35766 .75479 L .35485 .74472 L p .707 .577 .707 r
F P
0 g
s
.35485 .74472 m .35879 .70831 L .3616 .71839 L p .707 .577 .707 r
F P
0 g
s
.34404 .6849 m .32453 .73457 L .34058 .72892 L p .707 .577 .707 r
F P
0 g
s
.34601 .7053 m .33486 .68964 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.36552 .65563 m .34648 .70411 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.34648 .70411 m .34601 .7053 L p .34683 .67636 L .707 .577 .707 r
F P
0 g
s
.373 .28428 m .36897 .27071 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.35241 .78709 m .34789 .76868 L .32428 .77791 L p .707 .577 .707 r
F P
0 g
s
.33815 .73412 m .33421 .77053 L .35055 .76369 L p .707 .577 .707 r
F P
0 g
s
.35055 .76369 m .35449 .72728 L .33815 .73412 L p .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34053 .6752 L p .34691 .67021 L .707 .577 .707 r
F P
0 g
s
.33486 .68964 m .34691 .67021 L .34683 .67636 L .707 .577 .707 r
F
.34053 .6752 m .35437 .63997 L .36022 .64818 L p F P
0 g
s
.36022 .64818 m .36552 .65563 L p .34053 .6752 L .707 .577 .707 r
F P
0 g
s
.31418 .73824 m .31024 .77464 L .33421 .77053 L p .707 .577 .707 r
F P
0 g
s
.33421 .77053 m .33815 .73412 L .31418 .73824 L p .707 .577 .707 r
F P
0 g
s
.35437 .63997 m .33486 .68964 L .3274 .68333 L p .707 .577 .707 r
F P
0 g
s
.3274 .68333 m .31562 .67338 L p .32979 .66116 L .707 .577 .707 r
F P
0 g
s
.32979 .66116 m .35437 .63997 L .3274 .68333 L .707 .577 .707 r
F
.36897 .27071 m .34853 .54284 L p .34787 .59421 L F P
0 g
s
.31562 .67338 m .33513 .62371 L .35437 .63997 L p .707 .577 .707 r
F P
0 g
s
.34632 .69804 m .34238 .73445 L .32149 .72498 L p .707 .577 .707 r
F P
0 g
s
.32149 .72498 m .32543 .68858 L .34632 .69804 L p .707 .577 .707 r
F P
0 g
s
.33678 .74626 m .33918 .75605 L p .31479 .76807 L .707 .577 .707 r
F P
0 g
s
.34683 .67636 m .34691 .67021 L .36552 .65563 L .707 .577 .707 r
F
.32428 .77791 m .32879 .79632 L .35241 .78709 L p F P
0 g
s
.35879 .70831 m .35485 .74472 L .34238 .73445 L p .707 .577 .707 r
F P
0 g
s
.34238 .73445 m .34632 .69804 L .35879 .70831 L p .707 .577 .707 r
F P
0 g
s
.33633 .78115 m .3534 .79417 L p .35713 .69729 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .33821 .75209 L p .34222 .7461 L .707 .577 .707 r
F P
0 g
s
.33821 .75209 m .33678 .74626 L .33884 .7462 L p .707 .577 .707 r
F P
0 g
s
.33884 .7462 m .34222 .7461 L p .33821 .75209 L .707 .577 .707 r
F P
0 g
s
.33816 .76507 m .31479 .76807 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.31479 .76807 m .31027 .74966 L .33678 .74626 L p .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .33531 .7793 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33531 .7793 m .33571 .78068 L p .33659 .76728 L .707 .577 .707 r
F P
0 g
s
.33659 .76728 m .34787 .59421 L .33531 .7793 L .707 .577 .707 r
F
.35713 .69729 m .36289 .54728 L .33918 .75605 L F
.35713 .69729 m .33918 .75605 L .33633 .78115 L F
.3534 .79417 m .39069 .29777 L .373 .28428 L p F P
0 g
s
.34129 .76467 m .33918 .75605 L p .35698 .74568 L .707 .577 .707 r
F P
0 g
s
.34222 .7461 m .35698 .74568 L p .33918 .75605 L .707 .577 .707 r
F P
0 g
s
.33918 .75605 m .34129 .76467 L .33816 .76507 L p .707 .577 .707 r
F P
0 g
s
.373 .28428 m .33571 .78068 L .33633 .78115 L p .707 .577 .707 r
F P
0 g
s
.36289 .54728 m .373 .28428 L .33633 .78115 L .707 .577 .707 r
F
.34853 .54284 m .33168 .7671 L p .34787 .59421 L F P
0 g
s
.3475 .62381 m .373 .28428 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.33168 .7671 m .36212 .36191 L p .37899 .25838 L .707 .577 .707 r
F P
0 g
s
.36212 .36191 m .36897 .27071 L .37243 .26645 L p .707 .577 .707 r
F P
0 g
s
.37243 .26645 m .37899 .25838 L p .36212 .36191 L .707 .577 .707 r
F P
0 g
s
.36411 .76008 m .36863 .77849 L .37586 .77136 L p .707 .577 .707 r
F P
0 g
s
.37586 .77136 m .37134 .75295 L .36411 .76008 L p .707 .577 .707 r
F P
0 g
s
.37134 .75295 m .37586 .77136 L .37378 .76716 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .36467 .73141 L .3534 .79417 L .707 .577 .707 r
F
.37378 .76716 m .3734 .7664 L p .37313 .76461 L F P
0 g
s
.37313 .76461 m .37134 .75295 L .37378 .76716 L .707 .577 .707 r
F
.3534 .79417 m .38302 .80625 L p .38306 .80357 L F P
0 g
s
.3734 .7664 m .36889 .74799 L .37134 .75295 L p .707 .577 .707 r
F P
0 g
s
.38306 .80357 m .38594 .61289 L .36467 .73141 L .707 .577 .707 r
F
.39069 .29777 m .36485 .64183 L p .38594 .61289 L F P
0 g
s
.36485 .64183 m .3534 .79417 L p .38594 .61289 L .707 .577 .707 r
F P
0 g
s
.33571 .78068 m .3475 .62381 L p .34787 .59421 L .707 .577 .707 r
F P
0 g
s
.21832 .76816 m .22225 .73176 L .19498 .72403 L p .707 .577 .707 r
F P
0 g
s
.22225 .73176 m .21832 .76816 L .24931 .7734 L p .707 .577 .707 r
F P
0 g
s
.26912 .81309 m .2646 .79468 L .23438 .80057 L p .707 .577 .707 r
F P
0 g
s
.2646 .79468 m .26912 .81309 L .30009 .80528 L p .707 .577 .707 r
F P
0 g
s
.30009 .80528 m .29558 .78687 L .2646 .79468 L p .707 .577 .707 r
F P
0 g
s
.1696 .67753 m .18911 .62786 L .17796 .6122 L p .707 .577 .707 r
F P
0 g
s
.18911 .62786 m .1696 .67753 L .18884 .69378 L p .707 .577 .707 r
F P
0 g
s
.29558 .78687 m .30009 .80528 L .32879 .79632 L p .707 .577 .707 r
F P
0 g
s
.32879 .79632 m .32428 .77791 L .29558 .78687 L p .707 .577 .707 r
F P
0 g
s
.23438 .80057 m .2389 .81898 L .26912 .81309 L p .707 .577 .707 r
F P
0 g
s
.19498 .72403 m .19104 .76044 L .21832 .76816 L p .707 .577 .707 r
F P
0 g
s
.67814 .65855 m .65863 .70822 L .63318 .69296 L p .707 .577 .707 r
F P
0 g
s
.63318 .69296 m .6527 .64329 L .67814 .65855 L p .707 .577 .707 r
F P
0 g
s
.2389 .81898 m .23438 .80057 L .20788 .80397 L p .707 .577 .707 r
F P
0 g
s
.19104 .76044 m .19498 .72403 L .17408 .71457 L p .707 .577 .707 r
F P
0 g
s
.68933 .7398 m .68539 .77621 L .6645 .76675 L p .707 .577 .707 r
F P
0 g
s
.6645 .76675 m .66844 .73034 L .68933 .7398 L p .707 .577 .707 r
F P
0 g
s
.20788 .80397 m .21239 .82238 L .2389 .81898 L p .707 .577 .707 r
F P
0 g
s
.69998 .77353 m .7045 .79194 L .6843 .79252 L p .707 .577 .707 r
F P
0 g
s
.6843 .79252 m .67979 .77411 L .69998 .77353 L p .707 .577 .707 r
F P
0 g
s
.17408 .71457 m .17014 .75097 L .19104 .76044 L p .707 .577 .707 r
F P
0 g
s
.64605 .30846 m .60876 .80486 L .61878 .79253 L p .707 .577 .707 r
F P
0 g
s
.61878 .79253 m .65607 .29613 L .64605 .30846 L p .707 .577 .707 r
F P
0 g
s
.17796 .6122 m .15845 .66187 L .1696 .67753 L p .707 .577 .707 r
F P
0 g
s
.21239 .82238 m .20788 .80397 L .18768 .80454 L p .707 .577 .707 r
F P
0 g
s
.15845 .66187 m .17796 .6122 L .17599 .59867 L p .707 .577 .707 r
F P
0 g
s
.18768 .80454 m .19219 .82295 L .21239 .82238 L p .707 .577 .707 r
F P
0 g
s
.17014 .75097 m .17408 .71457 L .16162 .7043 L p .707 .577 .707 r
F P
0 g
s
.66844 .73034 m .6645 .76675 L .63722 .75902 L p .707 .577 .707 r
F P
0 g
s
.63722 .75902 m .64116 .72261 L .66844 .73034 L p .707 .577 .707 r
F P
0 g
s
.67979 .77411 m .6843 .79252 L .6578 .79592 L p .707 .577 .707 r
F P
0 g
s
.6578 .79592 m .65328 .77751 L .67979 .77411 L p .707 .577 .707 r
F P
0 g
s
.16162 .7043 m .15768 .7407 L .17014 .75097 L p .707 .577 .707 r
F P
0 g
s
.17599 .59867 m .15648 .64834 L .15845 .66187 L p .707 .577 .707 r
F P
0 g
s
.19219 .82295 m .18768 .80454 L .17577 .80224 L p .707 .577 .707 r
F P
0 g
s
.17577 .80224 m .18028 .82065 L .19219 .82295 L p .707 .577 .707 r
F P
0 g
s
.15648 .64834 m .17599 .59867 L .18339 .58858 L p .707 .577 .707 r
F P
0 g
s
.65328 .77751 m .6578 .79592 L .62758 .80181 L p .707 .577 .707 r
F P
0 g
s
.62758 .80181 m .62306 .7834 L .65328 .77751 L p .707 .577 .707 r
F P
0 g
s
.15768 .7407 m .16162 .7043 L .1588 .69422 L p .707 .577 .707 r
F P
0 g
s
.65607 .29613 m .61878 .79253 L .61475 .77895 L p .707 .577 .707 r
F P
0 g
s
.61475 .77895 m .65203 .28256 L .65607 .29613 L p .707 .577 .707 r
F P
0 g
s
.1588 .69422 m .15486 .73063 L .15768 .7407 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18339 .58858 m .16388 .63825 L .15648 .64834 L p .707 .577 .707 r
F P
0 g
s
.18028 .82065 m .17577 .80224 L .17331 .79728 L p .707 .577 .707 r
F P
0 g
s
.17331 .79728 m .17782 .81569 L .18028 .82065 L p .707 .577 .707 r
F P
0 g
s
.16388 .63825 m .18339 .58858 L .19944 .58293 L p .707 .577 .707 r
F P
0 g
s
.15486 .73063 m .1588 .69422 L .16591 .68533 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16591 .68533 m .16197 .72173 L .15486 .73063 L p .707 .577 .707 r
F P
0 g
s
.65203 .28256 m .61475 .77895 L .59706 .76546 L p .707 .577 .707 r
F P
0 g
s
.59706 .76546 m .63434 .26907 L .65203 .28256 L p .707 .577 .707 r
F P
0 g
s
.19944 .58293 m .17993 .6326 L .16388 .63825 L p .707 .577 .707 r
F P
0 g
s
.17782 .81569 m .17331 .79728 L .18054 .79015 L p .707 .577 .707 r
F P
0 g
s
.17993 .6326 m .19944 .58293 L .22257 .58228 L p .707 .577 .707 r
F P
0 g
s
.18054 .79015 m .18506 .80856 L .17782 .81569 L p .707 .577 .707 r
F P
0 g
s
.3417 .75477 m .37899 .25838 L .40208 .2485 L p .707 .577 .707 r
F P
0 g
s
.37899 .25838 m .3417 .75477 L .33168 .7671 L p .707 .577 .707 r
F P
0 g
s
.16197 .72173 m .16591 .68533 L .18225 .67849 L p .707 .577 .707 r
F P
0 g
s
.36889 .74799 m .3734 .7664 L .36149 .76409 L p .707 .577 .707 r
F P
0 g
s
.36149 .76409 m .35698 .74568 L .36889 .74799 L p .707 .577 .707 r
F P
0 g
s
.18225 .67849 m .17832 .71489 L .16197 .72173 L p .707 .577 .707 r
F P
0 g
s
.22257 .58228 m .20306 .63195 L .17993 .6326 L p .707 .577 .707 r
F P
0 g
s
.20306 .63195 m .22257 .58228 L .25051 .58667 L p .707 .577 .707 r
F P
0 g
s
.33513 .62371 m .31562 .67338 L .29018 .65813 L p .707 .577 .707 r
F P
0 g
s
.29018 .65813 m .30969 .60846 L .33513 .62371 L p .707 .577 .707 r
F P
0 g
s
.18506 .80856 m .18054 .79015 L .19676 .78155 L p .707 .577 .707 r
F P
0 g
s
.19676 .78155 m .20128 .79996 L .18506 .80856 L p .707 .577 .707 r
F P
0 g
s
.63434 .26907 m .59706 .76546 L .56744 .75337 L p .707 .577 .707 r
F P
0 g
s
.56744 .75337 m .60473 .25698 L .63434 .26907 L p .707 .577 .707 r
F P
0 g
s
.17832 .71489 m .18225 .67849 L .20623 .67437 L p .707 .577 .707 r
F P
0 g
s
.231 .63634 m .25051 .58667 L .28053 .5957 L p .707 .577 .707 r
F P
0 g
s
.25051 .58667 m .231 .63634 L .20306 .63195 L p .707 .577 .707 r
F P
0 g
s
.35698 .74568 m .36149 .76409 L .34129 .76467 L p .707 .577 .707 r
F P
0 g
s
.30969 .60846 m .29018 .65813 L .26102 .64537 L p .707 .577 .707 r
F P
0 g
s
.26102 .64537 m .28053 .5957 L .30969 .60846 L p .707 .577 .707 r
F P
0 g
s
.28053 .5957 m .26102 .64537 L .231 .63634 L p .707 .577 .707 r
F P
0 g
s
.40208 .2485 m .36479 .74489 L .3417 .75477 L p .707 .577 .707 r
F P
0 g
s
.36479 .74489 m .40208 .2485 L .43598 .24204 L p .707 .577 .707 r
F P
0 g
s
.20623 .67437 m .20229 .71078 L .17832 .71489 L p .707 .577 .707 r
F P
0 g
s
.32543 .68858 m .32149 .72498 L .29421 .71726 L p .707 .577 .707 r
F P
0 g
s
.29421 .71726 m .29815 .68085 L .32543 .68858 L p .707 .577 .707 r
F P
0 g
s
.72365 .6646 m .74317 .61493 L .71401 .60216 L p .707 .577 .707 r
F P
0 g
s
.74317 .61493 m .72365 .6646 L .75367 .67362 L p .707 .577 .707 r
F P
0 g
s
.75367 .67362 m .77319 .62395 L .74317 .61493 L p .707 .577 .707 r
F P
0 g
s
.20229 .71078 m .20623 .67437 L .23548 .67338 L p .707 .577 .707 r
F P
0 g
s
.6945 .65183 m .71401 .60216 L .68857 .58691 L p .707 .577 .707 r
F P
0 g
s
.71401 .60216 m .6945 .65183 L .72365 .6646 L p .707 .577 .707 r
F P
0 g
s
.20128 .79996 m .19676 .78155 L .22038 .77231 L p .707 .577 .707 r
F P
0 g
s
.77319 .62395 m .75367 .67362 L .78161 .67802 L p .707 .577 .707 r
F P
0 g
s
.78161 .67802 m .80113 .62835 L .77319 .62395 L p .707 .577 .707 r
F P
0 g
s
.22038 .77231 m .22489 .79072 L .20128 .79996 L p .707 .577 .707 r
F P
0 g
s
.29815 .68085 m .29421 .71726 L .26321 .71202 L p .707 .577 .707 r
F P
0 g
s
.26321 .71202 m .26715 .67561 L .29815 .68085 L p .707 .577 .707 r
F P
0 g
s
.60473 .25698 m .56744 .75337 L .5288 .74388 L p .707 .577 .707 r
F P
0 g
s
.5288 .74388 m .56609 .24748 L .60473 .25698 L p .707 .577 .707 r
F P
0 g
s
.23548 .67338 m .23154 .70979 L .20229 .71078 L p .707 .577 .707 r
F P
0 g
s
.66905 .63658 m .68857 .58691 L .66933 .57066 L p .707 .577 .707 r
F P
0 g
s
.68857 .58691 m .66905 .63658 L .6945 .65183 L p .707 .577 .707 r
F P
0 g
s
.23154 .70979 m .23548 .67338 L .26715 .67561 L p .707 .577 .707 r
F P
0 g
s
.26715 .67561 m .26321 .71202 L .23154 .70979 L p .707 .577 .707 r
F P
0 g
s
.40632 .72105 m .4373 .71324 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .47737 .23963 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40001 .72083 m .43598 .24204 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .40632 .72105 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4373 .71324 m .43278 .69483 L .41015 .70054 L p .707 .577 .707 r
F P
0 g
s
.47737 .23963 m .47631 .25371 L p .40222 .71642 L .707 .577 .707 r
F P
0 g
s
.40214 .71657 m .47737 .23963 L .40222 .71642 L .707 .577 .707 r
F
.4373 .71324 m .41015 .70054 L .40815 .70453 L F
.40632 .72105 m .40421 .71243 L p .40304 .71987 L F P
0 g
s
.43278 .69483 m .4373 .71324 L .466 .70428 L p .707 .577 .707 r
F P
0 g
s
.466 .70428 m .46148 .68587 L .43278 .69483 L p .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .40214 .71657 L .40222 .71642 L .707 .577 .707 r
F
.40013 .73835 m .39869 .73843 L p .47631 .25371 L F P
0 g
s
.39869 .73843 m .40001 .72083 L p .40214 .71657 L .707 .577 .707 r
F P
0 g
s
.39869 .73843 m .36479 .74489 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.43598 .24204 m .41456 .52721 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.41456 .52721 m .39869 .73843 L p .40657 .44975 L .707 .577 .707 r
F P
0 g
s
.37158 .70853 m .3761 .72694 L .40274 .72175 L p .707 .577 .707 r
F P
0 g
s
.40274 .72175 m .40632 .72105 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40304 .71987 m .37158 .70853 L .40274 .72175 L .707 .577 .707 r
F
.44008 .73602 m .40013 .73835 L p .42723 .56598 L F P
0 g
s
.47631 .25371 m .44807 .62977 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.44807 .62977 m .44008 .73602 L p .42723 .56598 L .707 .577 .707 r
F P
0 g
s
.41066 .63879 m .42286 .60774 L p .40016 .58009 L .707 .577 .707 r
F P
0 g
s
.42286 .60774 m .43018 .58912 L .42065 .58625 L p .707 .577 .707 r
F P
0 g
s
.42065 .58625 m .40016 .58009 L p .42286 .60774 L .707 .577 .707 r
F P
0 g
s
.41015 .70054 m .4018 .70264 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .37158 .70853 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.40421 .71243 m .4018 .70264 L p .40304 .71987 L .707 .577 .707 r
F P
0 g
s
.4018 .70264 m .40421 .71243 L p .40815 .70453 L .707 .577 .707 r
F P
0 g
s
.80113 .62835 m .78161 .67802 L .80474 .67736 L p .707 .577 .707 r
F P
0 g
s
.80474 .67736 m .82425 .62769 L .80113 .62835 L p .707 .577 .707 r
F P
0 g
s
.22489 .79072 m .22038 .77231 L .24908 .76336 L p .707 .577 .707 r
F P
0 g
s
.72952 .72313 m .73346 .68672 L .70247 .68149 L p .707 .577 .707 r
F P
0 g
s
.73346 .68672 m .72952 .72313 L .7612 .72536 L p .707 .577 .707 r
F P
0 g
s
.7612 .72536 m .76514 .68895 L .73346 .68672 L p .707 .577 .707 r
F P
0 g
s
.24908 .76336 m .25359 .78177 L .22489 .79072 L p .707 .577 .707 r
F P
0 g
s
.31027 .74966 m .31479 .76807 L .28457 .77396 L p .707 .577 .707 r
F P
0 g
s
.28457 .77396 m .28005 .75555 L .31027 .74966 L p .707 .577 .707 r
F P
0 g
s
.78031 .74109 m .77579 .72268 L .74481 .73049 L p .707 .577 .707 r
F P
0 g
s
.77579 .72268 m .78031 .74109 L .80901 .73213 L p .707 .577 .707 r
F P
0 g
s
.80901 .73213 m .80449 .71372 L .77579 .72268 L p .707 .577 .707 r
F P
0 g
s
.76514 .68895 m .7612 .72536 L .79045 .72437 L p .707 .577 .707 r
F P
0 g
s
.79045 .72437 m .79439 .68796 L .76514 .68895 L p .707 .577 .707 r
F P
0 g
s
.69853 .71789 m .70247 .68149 L .67519 .67376 L p .707 .577 .707 r
F P
0 g
s
.70247 .68149 m .69853 .71789 L .72952 .72313 L p .707 .577 .707 r
F P
0 g
s
.74933 .7489 m .74481 .73049 L .71459 .73638 L p .707 .577 .707 r
F P
0 g
s
.74481 .73049 m .74933 .7489 L .78031 .74109 L p .707 .577 .707 r
F P
0 g
s
.25359 .78177 m .24908 .76336 L .28005 .75555 L p .707 .577 .707 r
F P
0 g
s
.64981 .62033 m .66933 .57066 L .65818 .555 L p .707 .577 .707 r
F P
0 g
s
.66933 .57066 m .64981 .62033 L .66905 .63658 L p .707 .577 .707 r
F P
0 g
s
.56609 .24748 m .5288 .74388 L .48492 .7379 L p .707 .577 .707 r
F P
0 g
s
.46148 .68587 m .466 .70428 L .4696 .70287 L p .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .44008 .73602 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.5222 .2415 m .48508 .73571 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.46171 .68613 m .46148 .68587 L .4696 .70287 L .707 .577 .707 r
F
.4711 .68901 m .46148 .68587 L .47466 .7009 L F
.5222 .2415 m .56609 .24748 L p .48521 .73613 L F P
0 g
s
.48508 .73571 m .5222 .2415 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.48961 .69505 m .4851 .67664 L .46148 .68587 L p .707 .577 .707 r
F P
0 g
s
.48508 .73571 m .48492 .7379 L p .45184 .66521 L .707 .577 .707 r
F P
0 g
s
.4696 .70287 m .47466 .7009 L p .46171 .68613 L .707 .577 .707 r
F P
0 g
s
.47466 .7009 m .48961 .69505 L p .4711 .68901 L .707 .577 .707 r
F P
0 g
s
.48492 .7379 m .48508 .73571 L p .48521 .73613 L .707 .577 .707 r
F P
0 g
s
.71459 .73638 m .71911 .75479 L .74933 .7489 L p .707 .577 .707 r
F P
0 g
s
.28005 .75555 m .28457 .77396 L .25359 .78177 L p .707 .577 .707 r
F P
0 g
s
.44008 .73602 m .45153 .58369 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .45812 .59351 L .44483 .59142 L p .707 .577 .707 r
F P
0 g
s
.44483 .59142 m .43018 .58912 L p .43272 .60542 L .707 .577 .707 r
F P
0 g
s
.4386 .64318 m .44483 .59142 L .43272 .60542 L .707 .577 .707 r
F
.47737 .23963 m .5222 .2415 L p .46867 .56387 L F P
0 g
s
.45153 .58369 m .47737 .23963 L p .46867 .56387 L .707 .577 .707 r
F P
0 g
s
.71911 .75479 m .71459 .73638 L .68809 .73978 L p .707 .577 .707 r
F P
0 g
s
.80449 .71372 m .80901 .73213 L .83262 .7229 L p .707 .577 .707 r
F P
0 g
s
.83262 .7229 m .82811 .70449 L .80449 .71372 L p .707 .577 .707 r
F P
0 g
s
.79439 .68796 m .79045 .72437 L .81442 .72025 L p .707 .577 .707 r
F P
0 g
s
.81442 .72025 m .81836 .68385 L .79439 .68796 L p .707 .577 .707 r
F P
0 g
s
.67519 .67376 m .67125 .71016 L .69853 .71789 L p .707 .577 .707 r
F P
0 g
s
.82425 .62769 m .80474 .67736 L .82079 .67171 L p .707 .577 .707 r
F P
0 g
s
.82079 .67171 m .8403 .62204 L .82425 .62769 L p .707 .577 .707 r
F P
0 g
s
.68809 .73978 m .6926 .75819 L .71911 .75479 L p .707 .577 .707 r
F P
0 g
s
.67125 .71016 m .67519 .67376 L .65429 .66429 L p .707 .577 .707 r
F P
0 g
s
.65429 .66429 m .65036 .7007 L .67125 .71016 L p .707 .577 .707 r
F P
0 g
s
.65818 .555 m .63866 .60466 L .64981 .62033 L p .707 .577 .707 r
F P
0 g
s
.6926 .75819 m .68809 .73978 L .66789 .74035 L p .707 .577 .707 r
F P
0 g
s
.63866 .60466 m .65818 .555 L .6562 .54146 L p .707 .577 .707 r
F P
0 g
s
.66789 .74035 m .67241 .75877 L .6926 .75819 L p .707 .577 .707 r
F P
0 g
s
.82811 .70449 m .83262 .7229 L .84884 .7143 L p .707 .577 .707 r
F P
0 g
s
.81836 .68385 m .81442 .72025 L .83076 .71341 L p .707 .577 .707 r
F P
0 g
s
.84884 .7143 m .84432 .69589 L .82811 .70449 L p .707 .577 .707 r
F P
0 g
s
.83076 .71341 m .8347 .67701 L .81836 .68385 L p .707 .577 .707 r
F P
0 g
s
.65036 .7007 m .65429 .66429 L .64183 .65402 L p .707 .577 .707 r
F P
0 g
s
.8403 .62204 m .82079 .67171 L .82819 .66163 L p .707 .577 .707 r
F P
0 g
s
.82819 .66163 m .84771 .61196 L .8403 .62204 L p .707 .577 .707 r
F P
0 g
s
.64183 .65402 m .63789 .69043 L .65036 .7007 L p .707 .577 .707 r
F P
0 g
s
.6562 .54146 m .63669 .59113 L .63866 .60466 L p .707 .577 .707 r
F P
0 g
s
.67241 .75877 m .66789 .74035 L .65598 .73805 L p .707 .577 .707 r
F P
0 g
s
.65598 .73805 m .6605 .75646 L .67241 .75877 L p .707 .577 .707 r
F P
0 g
s
.8347 .67701 m .83076 .71341 L .83787 .70452 L p .707 .577 .707 r
F P
0 g
s
.83787 .70452 m .84181 .66811 L .8347 .67701 L p .707 .577 .707 r
F P
0 g
s
.63669 .59113 m .6562 .54146 L .66361 .53138 L p .707 .577 .707 r
F P
0 g
s
.84432 .69589 m .84884 .7143 L .85607 .70717 L p .707 .577 .707 r
F P
0 g
s
.85607 .70717 m .85156 .68876 L .84432 .69589 L p .707 .577 .707 r
F P
0 g
s
.63789 .69043 m .64183 .65402 L .63902 .64395 L p .707 .577 .707 r
F P
0 g
s
.84771 .61196 m .82819 .66163 L .82622 .64809 L p .707 .577 .707 r
F P
0 g
s
.82622 .64809 m .84574 .59842 L .84771 .61196 L p .707 .577 .707 r
F P
0 g
s
.63902 .64395 m .63508 .68035 L .63789 .69043 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.66361 .53138 m .64409 .58104 L .63669 .59113 L p .707 .577 .707 r
F P
0 g
s
.6605 .75646 m .65598 .73805 L .65352 .73309 L p .707 .577 .707 r
F P
0 g
s
.65352 .73309 m .65804 .7515 L .6605 .75646 L p .707 .577 .707 r
F P
0 g
s
.84181 .66811 m .83787 .70452 L .83506 .69444 L p .707 .577 .707 r
F P
0 g
s
.83506 .69444 m .839 .65804 L .84181 .66811 L p .707 .577 .707 r
F P
0 g
s
.64409 .58104 m .66361 .53138 L .67966 .52573 L p .707 .577 .707 r
F P
0 g
s
.85156 .68876 m .85607 .70717 L .85361 .70221 L p .707 .577 .707 r
F P
0 g
s
.85361 .70221 m .8491 .6838 L .85156 .68876 L p .707 .577 .707 r
F P
0 g
s
.63508 .68035 m .63902 .64395 L .64613 .63505 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84574 .59842 m .82622 .64809 L .81507 .63243 L p .707 .577 .707 r
F P
0 g
s
.81507 .63243 m .83459 .58276 L .84574 .59842 L p .707 .577 .707 r
F P
0 g
s
.38064 .62976 m .40016 .58009 L .371 .56733 L p .707 .577 .707 r
F P
0 g
s
.40016 .58009 m .38064 .62976 L .41066 .63879 L p .707 .577 .707 r
F P
0 g
s
.35149 .617 m .371 .56733 L .34556 .55208 L p .707 .577 .707 r
F P
0 g
s
.371 .56733 m .35149 .617 L .38064 .62976 L p .707 .577 .707 r
F P
0 g
s
.64613 .63505 m .64219 .67146 L .63508 .68035 L p .707 .577 .707 r
F P
0 g
s
.43018 .58912 m .41066 .63879 L .4386 .64318 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67966 .52573 m .66014 .5754 L .64409 .58104 L p .707 .577 .707 r
F P
0 g
s
.65804 .7515 m .65352 .73309 L .66076 .72596 L p .707 .577 .707 r
F P
0 g
s
.66014 .5754 m .67966 .52573 L .70278 .52507 L p .707 .577 .707 r
F P
0 g
s
.66076 .72596 m .66527 .74437 L .65804 .7515 L p .707 .577 .707 r
F P
0 g
s
.32604 .60175 m .34556 .55208 L .32632 .53582 L p .707 .577 .707 r
F P
0 g
s
.34556 .55208 m .32604 .60175 L .35149 .617 L p .707 .577 .707 r
F P
0 g
s
.839 .65804 m .83506 .69444 L .8226 .68417 L p .707 .577 .707 r
F P
0 g
s
.8226 .68417 m .82653 .64777 L .839 .65804 L p .707 .577 .707 r
F P
0 g
s
.8491 .6838 m .85361 .70221 L .8417 .6999 L p .707 .577 .707 r
F P
0 g
s
.8417 .6999 m .83719 .68149 L .8491 .6838 L p .707 .577 .707 r
F P
0 g
s
.45812 .59351 m .4386 .64318 L .46173 .64253 L p .707 .577 .707 r
F P
0 g
s
.46173 .64253 m .48124 .59286 L .45812 .59351 L p .707 .577 .707 r
F P
0 g
s
.83459 .58276 m .81507 .63243 L .79583 .61618 L p .707 .577 .707 r
F P
0 g
s
.79583 .61618 m .81535 .56651 L .83459 .58276 L p .707 .577 .707 r
F P
0 g
s
.64219 .67146 m .64613 .63505 L .66247 .62821 L p .707 .577 .707 r
F P
0 g
s
.38651 .68136 m .39045 .64496 L .35946 .63972 L p .707 .577 .707 r
F P
0 g
s
.39045 .64496 m .38651 .68136 L .41819 .6836 L p .707 .577 .707 r
F P
0 g
s
.41819 .6836 m .42213 .64719 L .39045 .64496 L p .707 .577 .707 r
F P
0 g
s
.42213 .64719 m .41819 .6836 L .44744 .6826 L p .707 .577 .707 r
F P
0 g
s
.44744 .6826 m .45138 .6462 L .42213 .64719 L p .707 .577 .707 r
F P
0 g
s
.35552 .67613 m .35946 .63972 L .33218 .63199 L p .707 .577 .707 r
F P
0 g
s
.35946 .63972 m .35552 .67613 L .38651 .68136 L p .707 .577 .707 r
F P
0 g
s
.66247 .62821 m .65853 .66462 L .64219 .67146 L p .707 .577 .707 r
F P
0 g
s
.3068 .58549 m .32632 .53582 L .31517 .52016 L p .707 .577 .707 r
F P
0 g
s
.32632 .53582 m .3068 .58549 L .32604 .60175 L p .707 .577 .707 r
F P
0 g
s
.70278 .52507 m .68327 .57474 L .66014 .5754 L p .707 .577 .707 r
F P
0 g
s
.68327 .57474 m .70278 .52507 L .73073 .52947 L p .707 .577 .707 r
F P
0 g
s
.45138 .6462 m .44744 .6826 L .47141 .67849 L p .707 .577 .707 r
F P
0 g
s
.47141 .67849 m .47535 .64208 L .45138 .6462 L p .707 .577 .707 r
F P
0 g
s
.33218 .63199 m .32824 .6684 L .35552 .67613 L p .707 .577 .707 r
F P
0 g
s
.66527 .74437 m .66076 .72596 L .67698 .71736 L p .707 .577 .707 r
F P
0 g
s
.81535 .56651 m .79583 .61618 L .77039 .60092 L p .707 .577 .707 r
F P
0 g
s
.77039 .60092 m .7899 .55125 L .81535 .56651 L p .707 .577 .707 r
F P
0 g
s
.3761 .72694 m .37158 .70853 L .34508 .71193 L p .707 .577 .707 r
F P
0 g
s
.32824 .6684 m .33218 .63199 L .31128 .62253 L p .707 .577 .707 r
F P
0 g
s
.82653 .64777 m .8226 .68417 L .8017 .67471 L p .707 .577 .707 r
F P
0 g
s
.8017 .67471 m .80564 .6383 L .82653 .64777 L p .707 .577 .707 r
F P
0 g
s
.48124 .59286 m .46173 .64253 L .47778 .63688 L p .707 .577 .707 r
F P
0 g
s
.47778 .63688 m .49729 .58721 L .48124 .59286 L p .707 .577 .707 r
F P
0 g
s
.67698 .71736 m .68149 .73577 L .66527 .74437 L p .707 .577 .707 r
F P
0 g
s
.34508 .71193 m .34959 .73034 L .3761 .72694 L p .707 .577 .707 r
F P
0 g
s
.83719 .68149 m .8417 .6999 L .82151 .70048 L p .707 .577 .707 r
F P
0 g
s
.82151 .70048 m .81699 .68207 L .83719 .68149 L p .707 .577 .707 r
F P
0 g
s
.65853 .66462 m .66247 .62821 L .68644 .6241 L p .707 .577 .707 r
F P
0 g
s
.71121 .57914 m .73073 .52947 L .76074 .53849 L p .707 .577 .707 r
F P
0 g
s
.73073 .52947 m .71121 .57914 L .68327 .57474 L p .707 .577 .707 r
F P
0 g
s
.7899 .55125 m .77039 .60092 L .74123 .58816 L p .707 .577 .707 r
F P
0 g
s
.74123 .58816 m .76074 .53849 L .7899 .55125 L p .707 .577 .707 r
F P
0 g
s
.31128 .62253 m .30734 .65894 L .32824 .6684 L p .707 .577 .707 r
F P
0 g
s
.76074 .53849 m .74123 .58816 L .71121 .57914 L p .707 .577 .707 r
F P
0 g
s
.31517 .52016 m .29565 .56983 L .3068 .58549 L p .707 .577 .707 r
F P
0 g
s
.47535 .64208 m .47141 .67849 L .48775 .67165 L p .707 .577 .707 r
F P
0 g
s
.48775 .67165 m .49169 .63524 L .47535 .64208 L p .707 .577 .707 r
F P
0 g
s
.34959 .73034 m .34508 .71193 L .32488 .71251 L p .707 .577 .707 r
F P
0 g
s
.29565 .56983 m .31517 .52016 L .31319 .50663 L p .707 .577 .707 r
F P
0 g
s
.68644 .6241 m .6825 .6605 L .65853 .66462 L p .707 .577 .707 r
F P
0 g
s
.32488 .71251 m .3294 .73092 L .34959 .73034 L p .707 .577 .707 r
F P
0 g
s
.30734 .65894 m .31128 .62253 L .29882 .61226 L p .707 .577 .707 r
F P
0 g
s
.4851 .67664 m .48961 .69505 L .50583 .68645 L p .707 .577 .707 r
F P
0 g
s
.50583 .68645 m .50131 .66804 L .4851 .67664 L p .707 .577 .707 r
F P
0 g
s
.80564 .6383 m .8017 .67471 L .77442 .66698 L p .707 .577 .707 r
F P
0 g
s
.77442 .66698 m .77836 .63057 L .80564 .6383 L p .707 .577 .707 r
F P
0 g
s
.68149 .73577 m .67698 .71736 L .70059 .70813 L p .707 .577 .707 r
F P
0 g
s
.6825 .6605 m .68644 .6241 L .71569 .62311 L p .707 .577 .707 r
F P
0 g
s
.49729 .58721 m .47778 .63688 L .48518 .6268 L p .707 .577 .707 r
F P
0 g
s
.48518 .6268 m .5047 .57713 L .49729 .58721 L p .707 .577 .707 r
F P
0 g
s
.70059 .70813 m .70511 .72654 L .68149 .73577 L p .707 .577 .707 r
F P
0 g
s
.81699 .68207 m .82151 .70048 L .795 .70388 L p .707 .577 .707 r
F P
0 g
s
.795 .70388 m .79049 .68547 L .81699 .68207 L p .707 .577 .707 r
F P
0 g
s
.29882 .61226 m .29488 .64866 L .30734 .65894 L p .707 .577 .707 r
F P
0 g
s
.77836 .63057 m .77442 .66698 L .74343 .66174 L p .707 .577 .707 r
F P
0 g
s
.74343 .66174 m .74737 .62534 L .77836 .63057 L p .707 .577 .707 r
F P
0 g
s
.71569 .62311 m .71175 .65951 L .6825 .6605 L p .707 .577 .707 r
F P
0 g
s
.71175 .65951 m .71569 .62311 L .74737 .62534 L p .707 .577 .707 r
F P
0 g
s
.31319 .50663 m .29368 .5563 L .29565 .56983 L p .707 .577 .707 r
F P
0 g
s
.3294 .73092 m .32488 .71251 L .31297 .7102 L p .707 .577 .707 r
F P
0 g
s
.74737 .62534 m .74343 .66174 L .71175 .65951 L p .707 .577 .707 r
F P
0 g
s
.49169 .63524 m .48775 .67165 L .49486 .66276 L p .707 .577 .707 r
F P
0 g
s
.49486 .66276 m .4988 .62635 L .49169 .63524 L p .707 .577 .707 r
F P
0 g
s
.70511 .72654 m .70059 .70813 L .72929 .69917 L p .707 .577 .707 r
F P
0 g
s
.31297 .7102 m .31749 .72861 L .3294 .73092 L p .707 .577 .707 r
F P
0 g
s
.29368 .5563 m .31319 .50663 L .3206 .49654 L p .707 .577 .707 r
F P
0 g
s
.72929 .69917 m .73381 .71758 L .70511 .72654 L p .707 .577 .707 r
F P
0 g
s
.79049 .68547 m .795 .70388 L .76478 .70977 L p .707 .577 .707 r
F P
0 g
s
.76478 .70977 m .76027 .69136 L .79049 .68547 L p .707 .577 .707 r
F P
0 g
s
.50131 .66804 m .50583 .68645 L .51306 .67932 L p .707 .577 .707 r
F P
0 g
s
.51306 .67932 m .50855 .66091 L .50131 .66804 L p .707 .577 .707 r
F P
0 g
s
.29488 .64866 m .29882 .61226 L .29601 .60218 L p .707 .577 .707 r
F P
0 g
s
.73381 .71758 m .72929 .69917 L .76027 .69136 L p .707 .577 .707 r
F P
0 g
s
.76027 .69136 m .76478 .70977 L .73381 .71758 L p .707 .577 .707 r
F P
0 g
s
.5047 .57713 m .48518 .6268 L .48321 .61326 L p .707 .577 .707 r
F P
0 g
s
.48321 .61326 m .50273 .56359 L .5047 .57713 L p .707 .577 .707 r
F P
0 g
s
.29601 .60218 m .29207 .63859 L .29488 .64866 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.3206 .49654 m .30108 .54621 L .29368 .5563 L p .707 .577 .707 r
F P
0 g
s
.31749 .72861 m .31297 .7102 L .31051 .70524 L p .707 .577 .707 r
F P
0 g
s
.4988 .62635 m .49486 .66276 L .49205 .65268 L p .707 .577 .707 r
F P
0 g
s
.49205 .65268 m .49599 .61627 L .4988 .62635 L p .707 .577 .707 r
F P
0 g
s
.31051 .70524 m .31503 .72365 L .31749 .72861 L p .707 .577 .707 r
F P
0 g
s
.30108 .54621 m .3206 .49654 L .33665 .49089 L p .707 .577 .707 r
F P
0 g
s
.50855 .66091 m .51306 .67932 L .5106 .67436 L p .707 .577 .707 r
F P
0 g
s
.5106 .67436 m .50609 .65595 L .50855 .66091 L p .707 .577 .707 r
F P
0 g
s
.29207 .63859 m .29601 .60218 L .30312 .59329 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50273 .56359 m .48321 .61326 L .47206 .5976 L p .707 .577 .707 r
F P
0 g
s
.47206 .5976 m .49158 .54793 L .50273 .56359 L p .707 .577 .707 r
F P
0 g
s
.30312 .59329 m .29918 .62969 L .29207 .63859 L p .707 .577 .707 r
F P
0 g
s
.33665 .49089 m .31713 .54056 L .30108 .54621 L p .707 .577 .707 r
F P
0 g
s
.31503 .72365 m .31051 .70524 L .31775 .69811 L p .707 .577 .707 r
F P
0 g
s
.31713 .54056 m .33665 .49089 L .35977 .49024 L p .707 .577 .707 r
F P
0 g
s
.49599 .61627 m .49205 .65268 L .47958 .64241 L p .707 .577 .707 r
F P
0 g
s
.47958 .64241 m .48352 .606 L .49599 .61627 L p .707 .577 .707 r
F P
0 g
s
.31775 .69811 m .32226 .71652 L .31503 .72365 L p .707 .577 .707 r
F P
0 g
s
.29918 .62969 m .30312 .59329 L .31946 .58645 L p .707 .577 .707 r
F P
0 g
s
.50609 .65595 m .5106 .67436 L .49869 .67205 L p .707 .577 .707 r
F P
0 g
s
.49869 .67205 m .49418 .65364 L .50609 .65595 L p .707 .577 .707 r
F P
0 g
s
.49158 .54793 m .47206 .5976 L .45282 .58135 L p .707 .577 .707 r
F P
0 g
s
.45282 .58135 m .47234 .53168 L .49158 .54793 L p .707 .577 .707 r
F P
0 g
s
.31946 .58645 m .31552 .62286 L .29918 .62969 L p .707 .577 .707 r
F P
0 g
s
.35977 .49024 m .34026 .53991 L .31713 .54056 L p .707 .577 .707 r
F P
0 g
s
.34026 .53991 m .35977 .49024 L .38771 .49464 L p .707 .577 .707 r
F P
0 g
s
.48352 .606 m .47958 .64241 L .45869 .63294 L p .707 .577 .707 r
F P
0 g
s
.45869 .63294 m .46263 .59654 L .48352 .606 L p .707 .577 .707 r
F P
0 g
s
.47234 .53168 m .45282 .58135 L .42738 .56609 L p .707 .577 .707 r
F P
0 g
s
.42738 .56609 m .44689 .51642 L .47234 .53168 L p .707 .577 .707 r
F P
0 g
s
.32226 .71652 m .31775 .69811 L .33396 .68951 L p .707 .577 .707 r
F P
0 g
s
.33396 .68951 m .33848 .70792 L .32226 .71652 L p .707 .577 .707 r
F P
0 g
s
.31552 .62286 m .31946 .58645 L .34343 .58233 L p .707 .577 .707 r
F P
0 g
s
.3682 .54431 m .38771 .49464 L .41773 .50366 L p .707 .577 .707 r
F P
0 g
s
.38771 .49464 m .3682 .54431 L .34026 .53991 L p .707 .577 .707 r
F P
0 g
s
.49418 .65364 m .49869 .67205 L .4785 .67263 L p .707 .577 .707 r
F P
0 g
s
.4785 .67263 m .47398 .65422 L .49418 .65364 L p .707 .577 .707 r
F P
0 g
s
.44689 .51642 m .42738 .56609 L .39822 .55333 L p .707 .577 .707 r
F P
0 g
s
.39822 .55333 m .41773 .50366 L .44689 .51642 L p .707 .577 .707 r
F P
0 g
s
.41773 .50366 m .39822 .55333 L .3682 .54431 L p .707 .577 .707 r
F P
0 g
s
.34343 .58233 m .33949 .61874 L .31552 .62286 L p .707 .577 .707 r
F P
0 g
s
.46263 .59654 m .45869 .63294 L .43141 .62522 L p .707 .577 .707 r
F P
0 g
s
.43141 .62522 m .43535 .58881 L .46263 .59654 L p .707 .577 .707 r
F P
0 g
s
.33949 .61874 m .34343 .58233 L .37268 .58134 L p .707 .577 .707 r
F P
0 g
s
.33848 .70792 m .33396 .68951 L .35758 .68028 L p .707 .577 .707 r
F P
0 g
s
.35758 .68028 m .36209 .69869 L .33848 .70792 L p .707 .577 .707 r
F P
0 g
s
.47398 .65422 m .4785 .67263 L .45199 .67603 L p .707 .577 .707 r
F P
0 g
s
.45199 .67603 m .44748 .65762 L .47398 .65422 L p .707 .577 .707 r
F P
0 g
s
.43535 .58881 m .43141 .62522 L .40042 .61998 L p .707 .577 .707 r
F P
0 g
s
.40042 .61998 m .40436 .58357 L .43535 .58881 L p .707 .577 .707 r
F P
0 g
s
.37268 .58134 m .36874 .61775 L .33949 .61874 L p .707 .577 .707 r
F P
0 g
s
.36874 .61775 m .37268 .58134 L .40436 .58357 L p .707 .577 .707 r
F P
0 g
s
.40436 .58357 m .40042 .61998 L .36874 .61775 L p .707 .577 .707 r
F P
0 g
s
.36209 .69869 m .35758 .68028 L .38628 .67132 L p .707 .577 .707 r
F P
0 g
s
.38628 .67132 m .3908 .68973 L .36209 .69869 L p .707 .577 .707 r
F P
0 g
s
.44748 .65762 m .45199 .67603 L .42177 .68192 L p .707 .577 .707 r
F P
0 g
s
.42177 .68192 m .41726 .66351 L .44748 .65762 L p .707 .577 .707 r
F P
0 g
s
.3908 .68973 m .38628 .67132 L .41726 .66351 L p .707 .577 .707 r
F P
0 g
s
.41726 .66351 m .42177 .68192 L .3908 .68973 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007Uooah008Io
o`00MGoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00P7oo001aOol40006
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH5001kOol006moo`800003FUH005YF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<007Moo`00KGoo
0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00eYF1000Lgoo001[Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH3001`Ool006Yoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP00008006eoo`00JGoo
00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH00UYF0`00JWoo001XOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0P00J7oo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0P00Igoo001XOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000006Eoo`00J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP05001J
EUYFFUH0001TOol006Qoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001oogoo065oo`00
J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<007ooOol0HGoo001XOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP0<FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001R
Ool006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1POol006Moo`04001JEUYF0006FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUIoo`1ROol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1ROol006Moo`=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo069oo`00Igoo0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol2FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIoo`1R
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP04FUH00`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP03
FUH01000FUIJEP002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Ao
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001OOol;0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05eoo`<000IJEP04001JEUYFFUH60006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`800003
FUH005YF00EJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol0
05Yoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Moo`00FWoo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00EJEP<000YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Moo`00FGoo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF0000
0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Igoo001IOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0`000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00Igoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP05001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Moo`80009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Yoo`/0059oo`00
EWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0027oo0P0000=JEP00FUH015YF00@005YFFUIJEPH004aoo`00EWoo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Woo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF00000P00BGoo001FOol01@00FUIJ
EUYF00001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF0P00
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF0`00AWoo001EOol20002
FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF0`00@goo001EOol01000FUH00000
0UYF00@005YFFUH000=oo`03001JEP0000D000QJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH00000
@Goo001DOol30004FUH01000FUIJEUYF0P0000Eoo`00FUIJEP0000AJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEP<003ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF0P000UYF00<005YF
FUH00eYF00<005YF00000P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF0`0035YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0P00?7oo001COol200000eYF001JEP02
FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00UYF0P002EYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP<0
03Yoo`00Dgoo00<005YFFUH015YF00<005YFFUH01EYF10001EYF00<005YFFUH015YF0P001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH0000iOol005=oo`03001JEP0000=JEP03001JEUYF00EJEP04001J
EUYFFUH20004FUH01000FUIJEUYF0`000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03
001oogoo03Ioo`00Dgoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<0
05YFFUH01@0000=JEP00FUH00P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo00<005YF0000
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF0P00=Woo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30002FUH50000
0eYF001JEP02FUH20008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00Oomoo`0cOol005Aoo`05
001JEUYFFUH00007FUH00`00FUIJEP06FUH01@00FUH00000FUH01@0000=JEP00FUH015YF0P001EYF
00<005YFFUH015YF00<005YFFUH00UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00MJEP<003=oo`00EGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
009JEPD0009JEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP800004Ool005YF0002FUH;0004
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF0000<Woo001EOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH025YF0`001eYF00<0
05YFFUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00L0
05YF001ooeYF001JEP020002FUH00`00FUIJEP020004Ool60007FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000`Ool003Qoo`/001=oo`03001JEUYF00EJEQP000YJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH00000FUH00P0015YF00<005YFFUH00UYF00<007ooOol01goo0P001EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<007ooOol0;Goo000fOol30006FUH01000FUIJ
EUYF1P003Woo00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
1eYF0`0015YF00<005YFFUH00UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00AJEP03001oogoo00Qoo`<00003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP8002ioo`00=7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00@005YF000000eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000=JEP04001JEUYF0003FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0004FUH00`00FUIJEP04FUH3000;Ool3
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0000^Ool003=oo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP<000Qoo`80009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000T000AJEP03001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP05
001JEUYFFUH0000=Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00;Goo000c
Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0017oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF
00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol01goo0`000Woo0`00
00=JEP00FUH025YF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00<Woo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009oo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<00007FUH005YFFUH0
05YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH015YF
00<005YFFUH015YF00<005YFFUH00eYF0P001Woo1@0017oo0P002EYF00<005YFFUH015YF00<005YF
FUH00UYF00<007ooOol0:Woo000bOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF0P0017oo1@001Woo0P001UYF00<005YFFUH015YF00<005YFFUH00eYF00<007oo
Ool0:Woo000aOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YF
00000P0000=oo`0000000`0027oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000aOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000Woo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00=JEPD000Yoo`8000=J
EP03001JEUYF00AJEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000]oo`<000IJEP03001JEUYF009JEP03001JEP0002aoo`00<7oo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF
00<005YFFUH00eYF3P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000;Ool00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0000/Ool002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEP0000<0009oo`03001JEUYF00<000IJEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20004Ool00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30009Ool00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000]Ool002moo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=J
EP8000AJEP03001oo`00009JEP03001JEUYF008000AJEP03001JEUYF00IJEPH000IJEP03001JEUYF
00=JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005Ool00`00FUIJEP03FUHH0003FUH50005Ool20002FUH00`00FUIJEP02FUH00`00FUH0000]
Ool002moo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUH005YF0P0000AJEP000000009JEP<0009JEP03001JEUYF009JEP800004FUH005YFFUH30003
FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo1P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01@000eYF2@001EYF00<005YF0000;Goo000^Ool20002FUH;0004FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEP<00004FUH005YF0005FUH00`00FUH0
00070002FUH00`00FUIJEP05FUH400000eYF001JEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00D005YFFUIJEP0000AJEP03001JEP00
02ioo`00;Woo00@005YF0000009JEP04001JEUYF0005Ool60008FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP02FUH500000eYF001JEP07FUH01000FUIJ
EUYF0`0015YF00H005YFFUH005YF000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUH000000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`001EYF00L005YFFUIJEP00FUH0000^Ool002eoo`<000AJEP04001J
EUYFFUH20009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH400000eYF001JEP03FUH:0004FUH00`00FUIJEP04FUH400001eYF001JEUYF001JEP0000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP<000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP06001J
EUYF001JEP00;goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00Oomoo`09Ool300000eYF
001JEP07FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YF00000`000eYF0`0000=JEP00
FUH00eYF4@000UYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0000MJEP00001JEP00FUH0000_Ool002aoo`800003FUH005YF009JEP03001J
EUYF00EJEP03001oogoo00]oo`8000QJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH80008FUH80003FUH01000FUH005YF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<007ooOol0;Goo000/Ool0
0`00FUIJEP04FUH00`00FUIJEP05FUH3000=Ool20006FUH01@00FUIJEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP00Ool0;goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH01000FUIJEUYF
0P0027oo0`000Woo0P0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo000/
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005Ool50003Ool2000015YF001J
EUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00000_Ool002eoo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001oogoo009oo`D000Eoo`8000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH00`00FUIJEP03FUH0
0`00FUIJEP020007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20004
FUH00`00FUIJEP02FUH?0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001eYF00<005YFFUH01UYF0`000Woo1@001goo0P00
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF1`0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP800004FUH005YF0004FUH00`00FUH000050007Ool200000eYF001JEP090004FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo000^Ool01000FUIJEP001UYF00<005YF
FUH01UYF00@005YFFUIJEP800004Ool00000000:Ool20003FUH200000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP001eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF001JEP00FUH0
0002FUH40002FUH01@00FUIJEUYF000027oo100000AJEP00000000=JEPL000EJEP03001JEUYF00=J
EP03001JEUYF009JEP8002eoo`00;Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00=J
EP8000ioo`<0009JEP<000IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01P00FUH005YF001JEP@0009JEP800003FUH005YF00=JEP8000Yoo`D00003FUH005YF00IJ
EP@00003FUH005YF00AJEP03001JEUYF009JEP8002eoo`00;goo00<005YFFUH01EYF40000UYF1000
37oo00<005YFFUH00eYF10000UYF00<005YFFUH00UYF0P0000=JEP00FUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF3@001EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
001JEP8000=JEP03001JEUYF009JEP<000EJEP03001oogoo00Moo`X000AJEP04001JEUYFFUH20005
FUH00`00FUIJEP02FUH2000]Ool0031oo`03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
009JEPX000Uoo`03001JEUYF00=JEP03001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF009J
EPh000AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P000eYF00<005YFFUH00eYF00<005YF00000`0000=JEP00000027oo1@001Goo30000eYF
00L005YFFUIJEP00FUH0000]Ool0035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Aoo`8000=JEP04001JEP00FUH30007FUH00`00FUIJEP05FUH60003FUH00`00FUH0
00030002FUH30005FUH00`00FUH00005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH50007Ool3000AOol;000]Ool002mo
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000L0009JEP06001JEP00001JEP0025YF00<005YFFUH00eYF3@0015YF0P000eYF00<005YFFUH0
0UYF0P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH010004Goo1P000eYF00<005YFFUH00UYF00<005YF
00000P00:goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000020003FUH00`00FUIJEP07FUH00`00FUH00002
000:FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUHA00000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP@000IJEP03001JEUYF00AJEP@00003FUH005YF00YJEP03001JEUYF00YJEP04001JEP000008
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04
0005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH3000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40002FUH00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF0000:Woo
000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool200000eYF
00000005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP05FUH50009FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004Ool40004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>000YOol002eoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000EJEP04001JEP000004FUH01000FUIJEUYF10000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
1Woo1@0000=JEP00FUH01UYF00<005YFFUH00`000eYF00<005YFFUH01eYF00<005YFFUH00UYF2000
00=JEP00FUH00eYF00H005YF001JEP00FUH2000YOol002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH40003FUH60006
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20008Ool2000015YF000000001UYF0`001UYF00<005YFFUH01UYF1P000UYF
00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00@005YFFUH002Uoo`00;7oo00<005YF00000eYF
00@005YFFUIJEPX000IJEPT000AJEP03001JEUYF009JEP05001JEUYF001JEP090003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool01000FUIJEUYF1P0000=JEP00FUH01eYF00<005YF
FUH00UYF10001eYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP8002Yoo`00;7oo00<005YF0000
0eYF10002Woo0P0015YF00<005YFFUH01UYF1P0015YF00@005YF000000EJEP03001JEUYF00AJEP03
001JEUYF015JEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000H000Eoo`03001JEUYF008000EJEP03001JEUYF00IJEP03001JEP00
008000=JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEP00001JEP000eYF0P00:goo000/Ool0
1000FUH005YF0P0000AJEP00000000aoo`800003FUH005YF00MJEP03001JEUYF00AJEP80009JEP80
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF011JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH9
0007FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP05FUH01000FUIJEUYF1@000eYF00@005YF0000
02eoo`00;7oo00H005YF000005YF0004FUH3000;Ool3000015YF000000000eYF00<005YFFUH01UYF
0`000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001P00
15YF0P000UYF00<005YFFUH01EYF00<005YFFUH02P000eYF00<005YFFUH00UYF20001UYF0`00;goo
000/Ool20003FUH00`00FUIJEP03FUH01000FUH0000037oo1@0000=JEP00FUH01eYF00<005YFFUH0
0P000UYF00<005YFFUH00eYF00@005YFFUIJEPP0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEP00
00<000AJEP03001JEUYF00AJEP@000Eoo`d000QJEP04001JEUYFFUH2000bOol002aoo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEUYFFUH30009Ool80007FUH01000FUIJEUYF3P002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P001EYF00@005YFFUIJEP8000EJEP04001JEUYFFUH2000:Ool50006FUH00`00FUIJEP06
FUH01000FUH00000=7oo000/Ool01@00FUIJEUYF00001UYF00<005YFFUH015YF1P000goo1@000goo
10000UYF00@005YFFUIJEPH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH01P00FUH00000FUH000Moo`@00003FUH005YF00QJ
EP03001JEUYF00AJEP<003Ioo`00;7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF
009JEPT000Ioo`X000AJEP03001JEUYF00=JEP03001JEUYF00EJEQh000UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000EJEP04001JEUYF0002FUH00`00FUIJEP02FUH30002FUH0
0`00Ool000050005FUH00`00FUIJEP07FUH00`00FUIJEP04000iOol002aoo`05001JEUYFFUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH60003FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0
2@000eYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Goo000]Ool01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEPD000UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00@0049oo`00;Woo0`001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00@005YFFUIJEP@000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF009JEP@000EJEP03001J
EUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH40016Ool0031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH0
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF100000=JEP00
FUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00EJ
EP03001JEUYF00@004Yoo`00<Goo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF1P0015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00D005YFFUIJEP0000=JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00<000IJEP03001J
EUYF00=JEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP02FUH6001>Ool0
03=oo`800003FUH005YF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP07FUH00`00
FUIJEP03FUH00`00FUH00005FUH01000FUIJEP000eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF0000
1P0015YF3P00E7oo000eOol30006FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<005YF0000
1UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00E7oo000hOol40002FUH00`00FUIJEP04
FUH30007FUH00`00FUIJEP07FUH01000FUIJEUYF3P000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF0`0015YF00<005YF00000P0015YF00H0
05YF000005YF0005FUH00`00FUIJEP02FUH2001DOol003aoo`T00003FUH005YF00QJEP03001JEUYF
00AJEPH00003FUH0000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH00002Ool;0004
FUH01`00FUIJEUYF001JEP0005Aoo`00?Goo10001UYF00<005YFFUH01UYF00<005YFFUH0100000=J
EP00FUH00UYF100015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP800003FUH0000000ioo`<00003FUH0
05YF00D005Aoo`00>goo0P0000=JEP00FUH01eYF00<005YFFUH01EYF3@000Woo0P0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0`003Woo1P000UYF00<005YF00000P00DWoo000iOol20003FUH00`00
FUIJEP07FUH00`00FUIJEP04000<Ool300000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30006Ool80003FUH00`00FUIJEP03FUH01000FUIJEP00DWoo000gOol20006FUH00`00FUIJEP04
FUH5000<Ool400001EYF001JEUYF000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF2@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00DGoo000eOol30007FUH00`00FUIJEP04000<
Ool50005FUH01000FUIJEUYF0P000UYF00<005YFFUH04EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YFFUIJEP00055oo`00<goo0P000eYF00<005YFFUH015YF0`0037oo
10000UYF00<005YFFUH01UYF00@005YFFUIJEP@001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00008FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP00DGoo000bOol20004FUH00`00FUIJEP02FUH2000:Ool50006
FUH00`00FUIJEP06FUH01000FUH000000goo00<005YFFUH045YF00<005YFFUH02eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH0
1EYF00<005YFFUH00UYF3P00D7oo000aOol00`00FUH00005FUH01000FUH0000027oo10000UYF00<0
05YFFUH01eYF00<005YFFUH015YF0`001Woo0P0045YF00<005YFFUH02UYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF00<005YFFUH00UYF200000=JEP00
FUH00eYF00H005YF001JEP00FUH2001@Ool0035oo`04001JEUYF0003FUH30004Ool60006FUH00`00
FUIJEP07FUH00`00FUIJEP04000;Ool2000>FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH60002FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH20002FUH01000FUIJEP00D7oo000aOol01@00FUIJEP00FUH02@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF10004Goo0P0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF1P001eYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000eYF0P00DGoo000aOol200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000GOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH01000FUIJEUYF10000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0`000eYF0P00DWoo000bOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH00002000NOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH01000FUH00000
E7oo000bOol01000FUIJEP001UYF00<005YFFUH015YF00<005YFFUH00UYF1P009goo1P002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF2P000eYF00<005YFFUH01EYF00<005YF0000
0`001EYF0`00EWoo000bOol20002FUH00`00FUIJEP03FUH01000FUIJEUYF2000<goo1P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@001Goo4P000eYF00@005YFFUIJEP8005Uoo`00
<goo0P0000=JEP00FUH00UYF1P00@Goo2P001UYF00<005YFFUH00eYF2@002Goo1P001UYF00<005YF
FUH01UYF00@005YF000005]oo`00=Goo1@00DGoo30000eYF00@005YF000000Uoo`H000UJEP03001J
EUYF00AJEP<005eoo`00TWoo00@005YFFUH000AJEP8000Eoo`H000EJEP03001JEUYF00MJEP03001J
EUYF00@0061oo`00Tgoo00D005YFFUH005YF00T000=JEP03001JEUYF00EJEP03001JEUYF00IJEP@0
06Aoo`00Tgoo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`00J7oo002COol01@00FUH005YF000015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P00Jgoo002DOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH00UYF1@00KWoo002DOol0
1@00FUIJEUYF000015YF00<005YFFUH00UYF2000Lgoo002DOol>001kOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59053 .75449 m .60276 .70169 L .57237 .69293 L p .707 .577 .707 r
F P
0 g
s
.60276 .70169 m .59053 .75449 L .62167 .75991 L p .707 .577 .707 r
F P
0 g
s
.62167 .75991 m .6339 .70711 L .60276 .70169 L p .707 .577 .707 r
F P
0 g
s
.56013 .74573 m .57237 .69293 L .54568 .68167 L p .707 .577 .707 r
F P
0 g
s
.57237 .69293 m .56013 .74573 L .59053 .75449 L p .707 .577 .707 r
F P
0 g
s
.6339 .70711 m .62167 .75991 L .65049 .76144 L p .707 .577 .707 r
F P
0 g
s
.65049 .76144 m .66273 .70864 L .6339 .70711 L p .707 .577 .707 r
F P
0 g
s
.53345 .73447 m .54568 .68167 L .52533 .66903 L p .707 .577 .707 r
F P
0 g
s
.54568 .68167 m .53345 .73447 L .56013 .74573 L p .707 .577 .707 r
F P
0 g
s
.66273 .70864 m .65049 .76144 L .67419 .75895 L p .707 .577 .707 r
F P
0 g
s
.67419 .75895 m .68642 .70615 L .66273 .70864 L p .707 .577 .707 r
F P
0 g
s
.59381 .81317 m .59625 .77647 L .56515 .7725 L p .707 .577 .707 r
F P
0 g
s
.59625 .77647 m .59381 .81317 L .62559 .81426 L p .707 .577 .707 r
F P
0 g
s
.62559 .81426 m .62803 .77755 L .59625 .77647 L p .707 .577 .707 r
F P
0 g
s
.62803 .77755 m .62559 .81426 L .65492 .81236 L p .707 .577 .707 r
F P
0 g
s
.65492 .81236 m .65736 .77566 L .62803 .77755 L p .707 .577 .707 r
F P
0 g
s
.56271 .8092 m .56515 .7725 L .53776 .76603 L p .707 .577 .707 r
F P
0 g
s
.56515 .7725 m .56271 .8092 L .59381 .81317 L p .707 .577 .707 r
F P
0 g
s
.60625 .84511 m .60344 .82651 L .57263 .82943 L p .707 .577 .707 r
F P
0 g
s
.60344 .82651 m .60625 .84511 L .63775 .83998 L p .707 .577 .707 r
F P
0 g
s
.63775 .83998 m .63494 .82138 L .60344 .82651 L p .707 .577 .707 r
F P
0 g
s
.63494 .82138 m .63775 .83998 L .66687 .83315 L p .707 .577 .707 r
F P
0 g
s
.66687 .83315 m .66407 .81455 L .63494 .82138 L p .707 .577 .707 r
F P
0 g
s
.52533 .66903 m .51309 .72183 L .53345 .73447 L p .707 .577 .707 r
F P
0 g
s
.57263 .82943 m .57544 .84803 L .60625 .84511 L p .707 .577 .707 r
F P
0 g
s
.51309 .72183 m .52533 .66903 L .51329 .65623 L p .707 .577 .707 r
F P
0 g
s
.65736 .77566 m .65492 .81236 L .67894 .80766 L p .707 .577 .707 r
F P
0 g
s
.67894 .80766 m .68138 .77096 L .65736 .77566 L p .707 .577 .707 r
F P
0 g
s
.68642 .70615 m .67419 .75895 L .69044 .75267 L p .707 .577 .707 r
F P
0 g
s
.69044 .75267 m .70267 .69987 L .68642 .70615 L p .707 .577 .707 r
F P
0 g
s
.53776 .76603 m .53532 .80274 L .56271 .8092 L p .707 .577 .707 r
F P
0 g
s
.57544 .84803 m .57263 .82943 L .54554 .82987 L p .707 .577 .707 r
F P
0 g
s
.53532 .80274 m .53776 .76603 L .51676 .75771 L p .707 .577 .707 r
F P
0 g
s
.54554 .82987 m .54835 .84846 L .57544 .84803 L p .707 .577 .707 r
F P
0 g
s
.66407 .81455 m .66687 .83315 L .69076 .82528 L p .707 .577 .707 r
F P
0 g
s
.69076 .82528 m .68795 .80668 L .66407 .81455 L p .707 .577 .707 r
F P
0 g
s
.51676 .75771 m .51433 .79442 L .53532 .80274 L p .707 .577 .707 r
F P
0 g
s
.51329 .65623 m .50105 .70903 L .51309 .72183 L p .707 .577 .707 r
F P
0 g
s
.54835 .84846 m .54554 .82987 L .52481 .82776 L p .707 .577 .707 r
F P
0 g
s
.68138 .77096 m .67894 .80766 L .6953 .80062 L p .707 .577 .707 r
F P
0 g
s
.6953 .80062 m .69774 .76392 L .68138 .77096 L p .707 .577 .707 r
F P
0 g
s
.52481 .82776 m .52762 .84636 L .54835 .84846 L p .707 .577 .707 r
F P
0 g
s
.50105 .70903 m .51329 .65623 L .51075 .64453 L p .707 .577 .707 r
F P
0 g
s
.70267 .69987 m .69044 .75267 L .69764 .74322 L p .707 .577 .707 r
F P
0 g
s
.69764 .74322 m .70988 .69042 L .70267 .69987 L p .707 .577 .707 r
F P
0 g
s
.68795 .80668 m .69076 .82528 L .70707 .81715 L p .707 .577 .707 r
F P
0 g
s
.70707 .81715 m .70426 .79855 L .68795 .80668 L p .707 .577 .707 r
F P
0 g
s
.51433 .79442 m .51676 .75771 L .50422 .74835 L p .707 .577 .707 r
F P
0 g
s
.50422 .74835 m .50178 .78506 L .51433 .79442 L p .707 .577 .707 r
F P
0 g
s
.52762 .84636 m .52481 .82776 L .51248 .82333 L p .707 .577 .707 r
F P
0 g
s
.51075 .64453 m .49851 .69733 L .50105 .70903 L p .707 .577 .707 r
F P
0 g
s
.69774 .76392 m .6953 .80062 L .70239 .79193 L p .707 .577 .707 r
F P
0 g
s
.70239 .79193 m .70483 .75523 L .69774 .76392 L p .707 .577 .707 r
F P
0 g
s
.51248 .82333 m .51529 .84193 L .52762 .84636 L p .707 .577 .707 r
F P
0 g
s
.70426 .79855 m .70707 .81715 L .71421 .80955 L p .707 .577 .707 r
F P
0 g
s
.71421 .80955 m .7114 .79095 L .70426 .79855 L p .707 .577 .707 r
F P
0 g
s
.50178 .78506 m .50422 .74835 L .50136 .73886 L p .707 .577 .707 r
F P
0 g
s
.49851 .69733 m .51075 .64453 L .51795 .63508 L p .707 .577 .707 r
F P
0 g
s
.70988 .69042 m .69764 .74322 L .6951 .73152 L p .707 .577 .707 r
F P
0 g
s
.6951 .73152 m .70734 .67872 L .70988 .69042 L p .707 .577 .707 r
F P
0 g
s
.47507 .82195 m .49813 .32311 L .45417 .31838 L p .707 .577 .707 r
F P
0 g
s
.50136 .73886 m .49892 .77556 L .50178 .78506 L p .707 .577 .707 r
F P
0 g
s
.51529 .84193 m .51248 .82333 L .50975 .81701 L p .707 .577 .707 r
F P
0 g
s
.51795 .63508 m .50572 .68788 L .49851 .69733 L p .707 .577 .707 r
F P
0 g
s
.50975 .81701 m .51256 .83561 L .51529 .84193 L p .707 .577 .707 r
F P
0 g
s
.50572 .68788 m .51795 .63508 L .5342 .6288 L p .707 .577 .707 r
F P
0 g
s
.49892 .77556 m .50136 .73886 L .50845 .73016 L p .707 .577 .707 r
F P
0 g
s
.50845 .73016 m .50601 .76687 L .49892 .77556 L p .707 .577 .707 r
F P
0 g
s
.51256 .83561 m .50975 .81701 L .51689 .80941 L p .707 .577 .707 r
F P
0 g
s
.5342 .6288 m .52197 .6816 L .50572 .68788 L p .707 .577 .707 r
F P
0 g
s
.51689 .80941 m .5197 .82801 L .51256 .83561 L p .707 .577 .707 r
F P
0 g
s
.50601 .76687 m .50845 .73016 L .52481 .72312 L p .707 .577 .707 r
F P
0 g
s
.52481 .72312 m .52237 .75983 L .50601 .76687 L p .707 .577 .707 r
F P
0 g
s
.5197 .82801 m .51689 .80941 L .5332 .80128 L p .707 .577 .707 r
F P
0 g
s
.49813 .32311 m .47507 .82195 L .51998 .8227 L p .707 .577 .707 r
F P
0 g
s
.52197 .6816 m .5342 .6288 L .5579 .62631 L p .707 .577 .707 r
F P
0 g
s
.5579 .62631 m .54566 .67911 L .52197 .6816 L p .707 .577 .707 r
F P
0 g
s
.52237 .75983 m .52481 .72312 L .54883 .71843 L p .707 .577 .707 r
F P
0 g
s
.54883 .71843 m .54639 .75513 L .52237 .75983 L p .707 .577 .707 r
F P
0 g
s
.51998 .8227 m .54303 .32385 L .49813 .32311 L p .707 .577 .707 r
F P
0 g
s
.54566 .67911 m .5579 .62631 L .58672 .62784 L p .707 .577 .707 r
F P
0 g
s
.5332 .80128 m .53601 .81987 L .5197 .82801 L p .707 .577 .707 r
F P
0 g
s
.58672 .62784 m .57449 .68064 L .54566 .67911 L p .707 .577 .707 r
F P
0 g
s
.53601 .81987 m .5332 .80128 L .55709 .79341 L p .707 .577 .707 r
F P
0 g
s
.54639 .75513 m .54883 .71843 L .57816 .71653 L p .707 .577 .707 r
F P
0 g
s
.55709 .79341 m .5599 .81201 L .53601 .81987 L p .707 .577 .707 r
F P
0 g
s
.57816 .71653 m .57572 .75323 L .54639 .75513 L p .707 .577 .707 r
F P
0 g
s
.5599 .81201 m .55709 .79341 L .58621 .78658 L p .707 .577 .707 r
F P
0 g
s
.58621 .78658 m .58902 .80517 L .5599 .81201 L p .707 .577 .707 r
F P
0 g
s
.54303 .32385 m .51998 .8227 L .56142 .81939 L p .707 .577 .707 r
F P
0 g
s
.56142 .81939 m .58448 .32054 L .54303 .32385 L p .707 .577 .707 r
F P
0 g
s
.43111 .81723 m .45417 .31838 L .41545 .31014 L p .707 .577 .707 r
F P
0 g
s
.45417 .31838 m .43111 .81723 L .47507 .82195 L p .707 .577 .707 r
F P
0 g
s
.70483 .75523 m .70239 .79193 L .69953 .78244 L p .707 .577 .707 r
F P
0 g
s
.69953 .78244 m .70197 .74573 L .70483 .75523 L p .707 .577 .707 r
F P
0 g
s
.57449 .68064 m .58672 .62784 L .61786 .63326 L p .707 .577 .707 r
F P
0 g
s
.61786 .63326 m .60563 .68606 L .57449 .68064 L p .707 .577 .707 r
F P
0 g
s
.57572 .75323 m .57816 .71653 L .60994 .71762 L p .707 .577 .707 r
F P
0 g
s
.60994 .71762 m .6075 .75432 L .57572 .75323 L p .707 .577 .707 r
F P
0 g
s
.58902 .80517 m .58621 .78658 L .61772 .78145 L p .707 .577 .707 r
F P
0 g
s
.61772 .78145 m .62053 .80005 L .58902 .80517 L p .707 .577 .707 r
F P
0 g
s
.58448 .32054 m .56142 .81939 L .59536 .81235 L p .707 .577 .707 r
F P
0 g
s
.59536 .81235 m .61842 .31351 L .58448 .32054 L p .707 .577 .707 r
F P
0 g
s
.7114 .79095 m .71421 .80955 L .71148 .80322 L p .707 .577 .707 r
F P
0 g
s
.71148 .80322 m .70867 .78462 L .7114 .79095 L p .707 .577 .707 r
F P
0 g
s
.70734 .67872 m .6951 .73152 L .68306 .71872 L p .707 .577 .707 r
F P
0 g
s
.68306 .71872 m .6953 .66592 L .70734 .67872 L p .707 .577 .707 r
F P
0 g
s
.3924 .80898 m .41545 .31014 L .38577 .29919 L p .707 .577 .707 r
F P
0 g
s
.41545 .31014 m .3924 .80898 L .43111 .81723 L p .707 .577 .707 r
F P
0 g
s
.24752 .7189 m .25976 .6661 L .22936 .65734 L p .707 .577 .707 r
F P
0 g
s
.25976 .6661 m .24752 .7189 L .27866 .72432 L p .707 .577 .707 r
F P
0 g
s
.27866 .72432 m .29089 .67152 L .25976 .6661 L p .707 .577 .707 r
F P
0 g
s
.21712 .71014 m .22936 .65734 L .20267 .64608 L p .707 .577 .707 r
F P
0 g
s
.22936 .65734 m .21712 .71014 L .24752 .7189 L p .707 .577 .707 r
F P
0 g
s
.29089 .67152 m .27866 .72432 L .30748 .72585 L p .707 .577 .707 r
F P
0 g
s
.30748 .72585 m .31972 .67305 L .29089 .67152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70197 .74573 m .69953 .78244 L .68699 .77307 L p .707 .577 .707 r
F P
0 g
s
.68699 .77307 m .68942 .73637 L .70197 .74573 L p .707 .577 .707 r
F P
0 g
s
.19044 .69888 m .20267 .64608 L .18232 .63344 L p .707 .577 .707 r
F P
0 g
s
.20267 .64608 m .19044 .69888 L .21712 .71014 L p .707 .577 .707 r
F P
0 g
s
.64826 .64202 m .63602 .69482 L .60563 .68606 L p .707 .577 .707 r
F P
0 g
s
.60563 .68606 m .61786 .63326 L .64826 .64202 L p .707 .577 .707 r
F P
0 g
s
.64104 .72159 m .6386 .75829 L .6075 .75432 L p .707 .577 .707 r
F P
0 g
s
.6075 .75432 m .60994 .71762 L .64104 .72159 L p .707 .577 .707 r
F P
0 g
s
.62053 .80005 m .61772 .78145 L .64852 .77852 L p .707 .577 .707 r
F P
0 g
s
.61842 .31351 m .59536 .81235 L .61846 .80227 L p .707 .577 .707 r
F P
0 g
s
.61846 .80227 m .64152 .30343 L .61842 .31351 L p .707 .577 .707 r
F P
0 g
s
.31972 .67305 m .30748 .72585 L .33118 .72336 L p .707 .577 .707 r
F P
0 g
s
.33118 .72336 m .34342 .67056 L .31972 .67305 L p .707 .577 .707 r
F P
0 g
s
.6953 .66592 m .68306 .71872 L .66271 .70608 L p .707 .577 .707 r
F P
0 g
s
.66271 .70608 m .67494 .65328 L .6953 .66592 L p .707 .577 .707 r
F P
0 g
s
.2508 .7733 m .25324 .73659 L .22214 .73262 L p .707 .577 .707 r
F P
0 g
s
.25324 .73659 m .2508 .7733 L .28258 .77439 L p .707 .577 .707 r
F P
0 g
s
.28258 .77439 m .28502 .73768 L .25324 .73659 L p .707 .577 .707 r
F P
0 g
s
.70867 .78462 m .71148 .80322 L .69915 .79879 L p .707 .577 .707 r
F P
0 g
s
.69915 .79879 m .69634 .78019 L .70867 .78462 L p .707 .577 .707 r
F P
0 g
s
.28502 .73768 m .28258 .77439 L .31191 .77249 L p .707 .577 .707 r
F P
0 g
s
.31191 .77249 m .31435 .73578 L .28502 .73768 L p .707 .577 .707 r
F P
0 g
s
.2197 .76933 m .22214 .73262 L .19475 .72616 L p .707 .577 .707 r
F P
0 g
s
.22214 .73262 m .2197 .76933 L .2508 .7733 L p .707 .577 .707 r
F P
0 g
s
.35463 .70763 m .36687 .65483 L .35966 .66428 L p .707 .577 .707 r
F P
0 g
s
.34494 .77541 m .34775 .79401 L .35781 .78899 L p .707 .577 .707 r
F P
0 g
s
.35781 .78899 m .36406 .78587 L p .35789 .7825 L .707 .577 .707 r
F P
0 g
s
.35789 .7825 m .34494 .77541 L .35781 .78899 L .707 .577 .707 r
F
.34743 .71708 m .35966 .66428 L .34342 .67056 L p F P
0 g
s
.34775 .79401 m .34494 .77541 L .32106 .78327 L p .707 .577 .707 r
F P
0 g
s
.33837 .73108 m .33593 .76779 L .35229 .76075 L p .707 .577 .707 r
F P
0 g
s
.35229 .76075 m .35473 .72404 L .33837 .73108 L p .707 .577 .707 r
F P
0 g
s
.35966 .66428 m .34743 .71708 L .35463 .70763 L p .707 .577 .707 r
F P
0 g
s
.36406 .78587 m .36125 .76728 L .34494 .77541 L p .707 .577 .707 r
F P
0 g
s
.34342 .67056 m .33118 .72336 L .34743 .71708 L p .707 .577 .707 r
F P
0 g
s
.35209 .69593 m .34005 .68313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.36433 .64313 m .35415 .68707 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35415 .68707 m .35209 .69593 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.35541 .5041 m .36243 .40758 L .36396 .2736 L .707 .577 .707 r
F
.34005 .68313 m .35229 .63033 L .35452 .6327 L p F P
0 g
s
.35452 .6327 m .36433 .64313 L p .35433 .6596 L .707 .577 .707 r
F P
0 g
s
.34005 .68313 m .35452 .6327 L .35433 .6596 L .707 .577 .707 r
F
.35473 .72404 m .35229 .76075 L .35939 .75206 L p F P
0 g
s
.35939 .75206 m .36182 .71535 L .35473 .72404 L p .707 .577 .707 r
F P
0 g
s
.35896 .70586 m .35652 .74257 L .34398 .7332 L p .707 .577 .707 r
F P
0 g
s
.36687 .65483 m .35463 .70763 L .35209 .69593 L p .707 .577 .707 r
F P
0 g
s
.34398 .7332 m .34641 .69649 L .35896 .70586 L p .707 .577 .707 r
F P
0 g
s
.35229 .63033 m .34005 .68313 L .3197 .67049 L p .707 .577 .707 r
F P
0 g
s
.3197 .67049 m .33193 .61769 L .35229 .63033 L p .707 .577 .707 r
F P
0 g
s
.34641 .69649 m .34398 .7332 L .32298 .72488 L p .707 .577 .707 r
F P
0 g
s
.32298 .72488 m .32542 .68817 L .34641 .69649 L p .707 .577 .707 r
F P
0 g
s
.33593 .76779 m .33837 .73108 L .31435 .73578 L p .707 .577 .707 r
F P
0 g
s
.35333 .74892 m .35582 .76535 L p .33542 .76542 L .707 .577 .707 r
F P
0 g
s
.36125 .76728 m .36406 .78587 L .3712 .77827 L p .707 .577 .707 r
F P
0 g
s
.3712 .77827 m .36839 .75968 L .36125 .76728 L p .707 .577 .707 r
F P
0 g
s
.36182 .71535 m .35939 .75206 L .35652 .74257 L p .707 .577 .707 r
F P
0 g
s
.35133 .78995 m .36271 .79803 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .36566 .75335 L .36799 .77177 L .707 .577 .707 r
F
.35713 .76605 m .36144 .75964 L .36402 .76968 L F
.36144 .75964 m .36566 .75335 L .36402 .76968 L F
.36566 .75335 m .36847 .77195 L .36799 .77177 L p F P
0 g
s
.36402 .76968 m .36271 .79803 L .37222 .80154 L p .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .35582 .76535 L .35133 .78995 L .707 .577 .707 r
F
.35209 .69593 m .36433 .64313 L .36687 .65483 L p F P
0 g
s
.35333 .74892 m .36566 .75335 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36803 .28659 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36271 .79803 m .36402 .76968 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.36402 .76968 m .38577 .29919 L p .36301 .76915 L .707 .577 .707 r
F P
0 g
s
.35614 .76752 m .35582 .76535 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.35582 .76535 m .35333 .74892 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36799 .77177 m .35614 .76752 L p .35713 .76605 L .707 .577 .707 r
F P
0 g
s
.36839 .75968 m .3712 .77827 L .36847 .77195 L p .707 .577 .707 r
F P
0 g
s
.36847 .77195 m .36566 .75335 L .36839 .75968 L p .707 .577 .707 r
F P
0 g
s
.38577 .29919 m .36402 .76968 L p .3924 .80898 L .707 .577 .707 r
F P
0 g
s
.37222 .80154 m .3924 .80898 L p .36402 .76968 L .707 .577 .707 r
F P
0 g
s
.36301 .76915 m .36349 .72327 L .35582 .76535 L .707 .577 .707 r
F
.35582 .76535 m .35614 .76752 L .35543 .76745 L p F P
0 g
s
.35543 .76745 m .33542 .76542 L p .35582 .76535 L .707 .577 .707 r
F P
0 g
s
.33542 .76542 m .33261 .74682 L .35333 .74892 L p .707 .577 .707 r
F P
0 g
s
.36803 .28659 m .34497 .78544 L .35133 .78995 L p .707 .577 .707 r
F P
0 g
s
.35652 .74257 m .35896 .70586 L .36182 .71535 L p .707 .577 .707 r
F P
0 g
s
.36349 .72327 m .36803 .28659 L .35133 .78995 L .707 .577 .707 r
F
.3409 .77244 m .34497 .78544 L p .35541 .5041 L F P
0 g
s
.36396 .2736 m .35578 .45063 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35578 .45063 m .3409 .77244 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.34497 .78544 m .35496 .56935 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.35496 .56935 m .36243 .40758 L p .35541 .5041 L .707 .577 .707 r
F P
0 g
s
.36243 .40758 m .36803 .28659 L .36406 .2739 L p .707 .577 .707 r
F P
0 g
s
.36406 .2739 m .36396 .2736 L p .36243 .40758 L .707 .577 .707 r
F P
0 g
s
.26324 .81383 m .26043 .79524 L .22962 .79816 L p .707 .577 .707 r
F P
0 g
s
.26043 .79524 m .26324 .81383 L .29474 .8087 L p .707 .577 .707 r
F P
0 g
s
.29474 .8087 m .29194 .79011 L .26043 .79524 L p .707 .577 .707 r
F P
0 g
s
.29194 .79011 m .29474 .8087 L .32387 .80187 L p .707 .577 .707 r
F P
0 g
s
.32387 .80187 m .32106 .78327 L .29194 .79011 L p .707 .577 .707 r
F P
0 g
s
.18232 .63344 m .17008 .68624 L .19044 .69888 L p .707 .577 .707 r
F P
0 g
s
.31435 .73578 m .31191 .77249 L .33593 .76779 L p .707 .577 .707 r
F P
0 g
s
.17008 .68624 m .18232 .63344 L .17028 .62064 L p .707 .577 .707 r
F P
0 g
s
.22962 .79816 m .23243 .81676 L .26324 .81383 L p .707 .577 .707 r
F P
0 g
s
.19475 .72616 m .19231 .76287 L .2197 .76933 L p .707 .577 .707 r
F P
0 g
s
.67494 .65328 m .66271 .70608 L .63602 .69482 L p .707 .577 .707 r
F P
0 g
s
.63602 .69482 m .64826 .64202 L .67494 .65328 L p .707 .577 .707 r
F P
0 g
s
.68942 .73637 m .68699 .77307 L .66599 .76475 L p .707 .577 .707 r
F P
0 g
s
.66599 .76475 m .66843 .72805 L .68942 .73637 L p .707 .577 .707 r
F P
0 g
s
.23243 .81676 m .22962 .79816 L .20253 .79859 L p .707 .577 .707 r
F P
0 g
s
.19231 .76287 m .19475 .72616 L .17375 .71784 L p .707 .577 .707 r
F P
0 g
s
.20253 .79859 m .20534 .81719 L .23243 .81676 L p .707 .577 .707 r
F P
0 g
s
.32106 .78327 m .32387 .80187 L .34775 .79401 L p .707 .577 .707 r
F P
0 g
s
.69634 .78019 m .69915 .79879 L .67843 .79669 L p .707 .577 .707 r
F P
0 g
s
.67843 .79669 m .67562 .77809 L .69634 .78019 L p .707 .577 .707 r
F P
0 g
s
.17375 .71784 m .17132 .75455 L .19231 .76287 L p .707 .577 .707 r
F P
0 g
s
.64152 .30343 m .61846 .80227 L .62847 .79014 L p .707 .577 .707 r
F P
0 g
s
.62847 .79014 m .65153 .2913 L .64152 .30343 L p .707 .577 .707 r
F P
0 g
s
.17028 .62064 m .15804 .67344 L .17008 .68624 L p .707 .577 .707 r
F P
0 g
s
.20534 .81719 m .20253 .79859 L .1818 .79649 L p .707 .577 .707 r
F P
0 g
s
.1818 .79649 m .18461 .81509 L .20534 .81719 L p .707 .577 .707 r
F P
0 g
s
.66843 .72805 m .66599 .76475 L .6386 .75829 L p .707 .577 .707 r
F P
0 g
s
.6386 .75829 m .64104 .72159 L .66843 .72805 L p .707 .577 .707 r
F P
0 g
s
.15804 .67344 m .17028 .62064 L .16774 .60894 L p .707 .577 .707 r
F P
0 g
s
.17132 .75455 m .17375 .71784 L .16121 .70848 L p .707 .577 .707 r
F P
0 g
s
.67562 .77809 m .67843 .79669 L .65133 .79712 L p .707 .577 .707 r
F P
0 g
s
.65133 .79712 m .64852 .77852 L .67562 .77809 L p .707 .577 .707 r
F P
0 g
s
.16121 .70848 m .15877 .74518 L .17132 .75455 L p .707 .577 .707 r
F P
0 g
s
.18461 .81509 m .1818 .79649 L .16947 .79206 L p .707 .577 .707 r
F P
0 g
s
.16774 .60894 m .1555 .66174 L .15804 .67344 L p .707 .577 .707 r
F P
0 g
s
.16947 .79206 m .17228 .81066 L .18461 .81509 L p .707 .577 .707 r
F P
0 g
s
.64852 .77852 m .65133 .79712 L .62053 .80005 L p .707 .577 .707 r
F P
0 g
s
.15877 .74518 m .16121 .70848 L .15835 .69898 L p .707 .577 .707 r
F P
0 g
s
.1555 .66174 m .16774 .60894 L .17494 .59949 L p .707 .577 .707 r
F P
0 g
s
.65153 .2913 m .62847 .79014 L .6244 .77714 L p .707 .577 .707 r
F P
0 g
s
.6244 .77714 m .64746 .2783 L .65153 .2913 L p .707 .577 .707 r
F P
0 g
s
.15835 .69898 m .15591 .73569 L .15877 .74518 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.3409 .77244 m .36396 .2736 L .37397 .26146 L p .707 .577 .707 r
F P
0 g
s
.17228 .81066 m .16947 .79206 L .16674 .78573 L p .707 .577 .707 r
F P
0 g
s
.17494 .59949 m .16271 .65229 L .1555 .66174 L p .707 .577 .707 r
F P
0 g
s
.16674 .78573 m .16955 .80433 L .17228 .81066 L p .707 .577 .707 r
F P
0 g
s
.15591 .73569 m .15835 .69898 L .16544 .69029 L p .707 .577 .707 r
F P
0 g
s
.16271 .65229 m .17494 .59949 L .19119 .59321 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16544 .69029 m .163 .727 L .15591 .73569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64746 .2783 m .6244 .77714 L .60666 .76455 L p .707 .577 .707 r
F P
0 g
s
.60666 .76455 m .62971 .26571 L .64746 .2783 L p .707 .577 .707 r
F P
0 g
s
.19119 .59321 m .17896 .64601 L .16271 .65229 L p .707 .577 .707 r
F P
0 g
s
.16955 .80433 m .16674 .78573 L .17388 .77813 L p .707 .577 .707 r
F P
0 g
s
.17388 .77813 m .17669 .79673 L .16955 .80433 L p .707 .577 .707 r
F P
0 g
s
.17896 .64601 m .19119 .59321 L .21489 .59072 L p .707 .577 .707 r
F P
0 g
s
.163 .727 m .16544 .69029 L .1818 .68325 L p .707 .577 .707 r
F P
0 g
s
.35091 .76031 m .37397 .26146 L .39707 .25139 L p .707 .577 .707 r
F P
0 g
s
.37397 .26146 m .35091 .76031 L .3409 .77244 L p .707 .577 .707 r
F P
0 g
s
.1818 .68325 m .17936 .71996 L .163 .727 L p .707 .577 .707 r
F P
0 g
s
.21489 .59072 m .20265 .64352 L .17896 .64601 L p .707 .577 .707 r
F P
0 g
s
.20265 .64352 m .21489 .59072 L .24372 .59225 L p .707 .577 .707 r
F P
0 g
s
.33193 .61769 m .3197 .67049 L .29301 .65923 L p .707 .577 .707 r
F P
0 g
s
.29301 .65923 m .30525 .60643 L .33193 .61769 L p .707 .577 .707 r
F P
0 g
s
.17669 .79673 m .17388 .77813 L .19019 .77 L p .707 .577 .707 r
F P
0 g
s
.19019 .77 m .193 .7886 L .17669 .79673 L p .707 .577 .707 r
F P
0 g
s
.62971 .26571 m .60666 .76455 L .57697 .7536 L p .707 .577 .707 r
F P
0 g
s
.57697 .7536 m .60003 .25475 L .62971 .26571 L p .707 .577 .707 r
F P
0 g
s
.17936 .71996 m .1818 .68325 L .20582 .67855 L p .707 .577 .707 r
F P
0 g
s
.23148 .64505 m .24372 .59225 L .27485 .59767 L p .707 .577 .707 r
F P
0 g
s
.24372 .59225 m .23148 .64505 L .20265 .64352 L p .707 .577 .707 r
F P
0 g
s
.30525 .60643 m .29301 .65923 L .26262 .65047 L p .707 .577 .707 r
F P
0 g
s
.26262 .65047 m .27485 .59767 L .30525 .60643 L p .707 .577 .707 r
F P
0 g
s
.27485 .59767 m .26262 .65047 L .23148 .64505 L p .707 .577 .707 r
F P
0 g
s
.20582 .67855 m .20338 .71526 L .17936 .71996 L p .707 .577 .707 r
F P
0 g
s
.39707 .25139 m .37401 .75023 L .35091 .76031 L p .707 .577 .707 r
F P
0 g
s
.37401 .75023 m .39707 .25139 L .431 .24435 L p .707 .577 .707 r
F P
0 g
s
.32542 .68817 m .32298 .72488 L .29559 .71842 L p .707 .577 .707 r
F P
0 g
s
.29559 .71842 m .29803 .68171 L .32542 .68817 L p .707 .577 .707 r
F P
0 g
s
.72773 .66246 m .73997 .60966 L .70957 .60089 L p .707 .577 .707 r
F P
0 g
s
.73997 .60966 m .72773 .66246 L .75887 .66787 L p .707 .577 .707 r
F P
0 g
s
.75887 .66787 m .7711 .61507 L .73997 .60966 L p .707 .577 .707 r
F P
0 g
s
.20338 .71526 m .20582 .67855 L .23515 .67665 L p .707 .577 .707 r
F P
0 g
s
.193 .7886 m .19019 .77 L .21408 .76213 L p .707 .577 .707 r
F P
0 g
s
.69734 .65369 m .70957 .60089 L .68289 .58964 L p .707 .577 .707 r
F P
0 g
s
.70957 .60089 m .69734 .65369 L .72773 .66246 L p .707 .577 .707 r
F P
0 g
s
.7711 .61507 m .75887 .66787 L .7877 .6694 L p .707 .577 .707 r
F P
0 g
s
.7877 .6694 m .79993 .6166 L .7711 .61507 L p .707 .577 .707 r
F P
0 g
s
.21408 .76213 m .21689 .78073 L .193 .7886 L p .707 .577 .707 r
F P
0 g
s
.33261 .74682 m .33542 .76542 L .30832 .76585 L p .707 .577 .707 r
F P
0 g
s
.30832 .76585 m .30551 .74725 L .33261 .74682 L p .707 .577 .707 r
F P
0 g
s
.29803 .68171 m .29559 .71842 L .26449 .71445 L p .707 .577 .707 r
F P
0 g
s
.26449 .71445 m .26693 .67774 L .29803 .68171 L p .707 .577 .707 r
F P
0 g
s
.60003 .25475 m .57697 .7536 L .53826 .74535 L p .707 .577 .707 r
F P
0 g
s
.53826 .74535 m .56131 .24651 L .60003 .25475 L p .707 .577 .707 r
F P
0 g
s
.23515 .67665 m .23272 .71336 L .20338 .71526 L p .707 .577 .707 r
F P
0 g
s
.23272 .71336 m .23515 .67665 L .26693 .67774 L p .707 .577 .707 r
F P
0 g
s
.67065 .64244 m .68289 .58964 L .66253 .57699 L p .707 .577 .707 r
F P
0 g
s
.68289 .58964 m .67065 .64244 L .69734 .65369 L p .707 .577 .707 r
F P
0 g
s
.79993 .6166 m .7877 .6694 L .81139 .66691 L p .707 .577 .707 r
F P
0 g
s
.81139 .66691 m .82363 .61411 L .79993 .6166 L p .707 .577 .707 r
F P
0 g
s
.26693 .67774 m .26449 .71445 L .23272 .71336 L p .707 .577 .707 r
F P
0 g
s
.40795 .74319 m .431 .24435 L .47245 .24104 L p .707 .577 .707 r
F P
0 g
s
.431 .24435 m .40795 .74319 L .37401 .75023 L p .707 .577 .707 r
F P
0 g
s
.73102 .72113 m .73346 .68443 L .70235 .68046 L p .707 .577 .707 r
F P
0 g
s
.73346 .68443 m .73102 .72113 L .76279 .72222 L p .707 .577 .707 r
F P
0 g
s
.76279 .72222 m .76523 .68552 L .73346 .68443 L p .707 .577 .707 r
F P
0 g
s
.21689 .78073 m .21408 .76213 L .2432 .7553 L p .707 .577 .707 r
F P
0 g
s
.76523 .68552 m .76279 .72222 L .79213 .72032 L p .707 .577 .707 r
F P
0 g
s
.79213 .72032 m .79456 .68362 L .76523 .68552 L p .707 .577 .707 r
F P
0 g
s
.2432 .7553 m .24601 .7739 L .21689 .78073 L p .707 .577 .707 r
F P
0 g
s
.30551 .74725 m .30832 .76585 L .27752 .76877 L p .707 .577 .707 r
F P
0 g
s
.27752 .76877 m .27471 .75017 L .30551 .74725 L p .707 .577 .707 r
F P
0 g
s
.69991 .71716 m .70235 .68046 L .67496 .674 L p .707 .577 .707 r
F P
0 g
s
.70235 .68046 m .69991 .71716 L .73102 .72113 L p .707 .577 .707 r
F P
0 g
s
.74345 .75307 m .74064 .73447 L .70983 .7374 L p .707 .577 .707 r
F P
0 g
s
.74064 .73447 m .74345 .75307 L .77496 .74794 L p .707 .577 .707 r
F P
0 g
s
.77496 .74794 m .77215 .72934 L .74064 .73447 L p .707 .577 .707 r
F P
0 g
s
.24601 .7739 m .2432 .7553 L .27471 .75017 L p .707 .577 .707 r
F P
0 g
s
.77215 .72934 m .77496 .74794 L .80408 .74111 L p .707 .577 .707 r
F P
0 g
s
.80408 .74111 m .80127 .72251 L .77215 .72934 L p .707 .577 .707 r
F P
0 g
s
.56131 .24651 m .53826 .74535 L .49429 .74063 L p .707 .577 .707 r
F P
0 g
s
.49429 .74063 m .51735 .24178 L .56131 .24651 L p .707 .577 .707 r
F P
0 g
s
.27471 .75017 m .27752 .76877 L .24601 .7739 L p .707 .577 .707 r
F P
0 g
s
.66253 .57699 m .6503 .62979 L .67065 .64244 L p .707 .577 .707 r
F P
0 g
s
.70983 .7374 m .71264 .75599 L .74345 .75307 L p .707 .577 .707 r
F P
0 g
s
.6503 .62979 m .66253 .57699 L .65049 .56419 L p .707 .577 .707 r
F P
0 g
s
.79456 .68362 m .79213 .72032 L .81615 .71563 L p .707 .577 .707 r
F P
0 g
s
.81615 .71563 m .81858 .67892 L .79456 .68362 L p .707 .577 .707 r
F P
0 g
s
.82363 .61411 m .81139 .66691 L .82764 .66063 L p .707 .577 .707 r
F P
0 g
s
.82764 .66063 m .83988 .60783 L .82363 .61411 L p .707 .577 .707 r
F P
0 g
s
.67496 .674 m .67252 .7107 L .69991 .71716 L p .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .45925 .52659 L .48577 .47325 L .707 .577 .707 r
F
.43195 .71667 m .45101 .7122 L p .45012 .71163 L F P
0 g
s
.47245 .24104 m .45376 .64546 L p .41122 .71767 L .707 .577 .707 r
F P
0 g
s
.45376 .64546 m .4507 .71154 L p .43162 .7145 L .707 .577 .707 r
F P
0 g
s
.41122 .71767 m .45376 .64546 L .43162 .7145 L .707 .577 .707 r
F
.44939 .73988 m .40795 .74319 L p .41122 .71767 L F P
0 g
s
.43087 .71684 m .43195 .71667 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.43162 .7145 m .43195 .71667 L p .45012 .71163 L .707 .577 .707 r
F P
0 g
s
.44767 .7049 m .42914 .69807 L .45101 .7122 L .707 .577 .707 r
F
.4507 .71154 m .44939 .73988 L p .42756 .72717 L F P
0 g
s
.41122 .71767 m .43162 .7145 L .42756 .72717 L .707 .577 .707 r
F
.43195 .71667 m .43162 .7145 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .4507 .71154 L .42756 .72717 L .707 .577 .707 r
F
.42914 .69807 m .39763 .7032 L p .43104 .71631 L F P
0 g
s
.43162 .7145 m .42914 .69807 L p .43104 .71631 L .707 .577 .707 r
F P
0 g
s
.39763 .7032 m .40044 .7218 L .43087 .71684 L p .707 .577 .707 r
F P
0 g
s
.43104 .71631 m .39763 .7032 L .43087 .71684 L .707 .577 .707 r
F
.42914 .69807 m .43162 .7145 L p .45012 .71163 L F P
0 g
s
.44939 .73988 m .4507 .71154 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.4507 .71154 m .45925 .52659 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.51735 .24178 m .49429 .74063 L .46378 .74012 L p .707 .577 .707 r
F P
0 g
s
.46378 .74012 m .44939 .73988 L p .45267 .71584 L .707 .577 .707 r
F P
0 g
s
.45267 .71584 m .51735 .24178 L .46378 .74012 L .707 .577 .707 r
F
.46107 .70983 m .45826 .69124 L .44305 .6948 L p F P
0 g
s
.44305 .6948 m .42914 .69807 L p .44767 .7049 L .707 .577 .707 r
F P
0 g
s
.46107 .70983 m .44305 .6948 L .44767 .7049 L .707 .577 .707 r
F
.45101 .7122 m .46107 .70983 L p .44767 .7049 L F P
0 g
s
.44469 .63381 m .45692 .58101 L .43283 .57973 L p .707 .577 .707 r
F P
0 g
s
.43283 .57973 m .42809 .57948 L p .42995 .58554 L .707 .577 .707 r
F P
0 g
s
.44469 .63381 m .43283 .57973 L .42995 .58554 L .707 .577 .707 r
F
.47245 .24104 m .51735 .24178 L p .48577 .47325 L F P
0 g
s
.45925 .52659 m .47245 .24104 L p .48577 .47325 L .707 .577 .707 r
F P
0 g
s
.71264 .75599 m .70983 .7374 L .68274 .73783 L p .707 .577 .707 r
F P
0 g
s
.67252 .7107 m .67496 .674 L .65397 .66568 L p .707 .577 .707 r
F P
0 g
s
.68274 .73783 m .68555 .75643 L .71264 .75599 L p .707 .577 .707 r
F P
0 g
s
.80127 .72251 m .80408 .74111 L .82796 .73324 L p .707 .577 .707 r
F P
0 g
s
.82796 .73324 m .82515 .71464 L .80127 .72251 L p .707 .577 .707 r
F P
0 g
s
.65397 .66568 m .65153 .70238 L .67252 .7107 L p .707 .577 .707 r
F P
0 g
s
.65049 .56419 m .63826 .61699 L .6503 .62979 L p .707 .577 .707 r
F P
0 g
s
.68555 .75643 m .68274 .73783 L .66202 .73573 L p .707 .577 .707 r
F P
0 g
s
.81858 .67892 m .81615 .71563 L .83251 .70859 L p .707 .577 .707 r
F P
0 g
s
.83251 .70859 m .83494 .67188 L .81858 .67892 L p .707 .577 .707 r
F P
0 g
s
.66202 .73573 m .66482 .75432 L .68555 .75643 L p .707 .577 .707 r
F P
0 g
s
.63826 .61699 m .65049 .56419 L .64795 .5525 L p .707 .577 .707 r
F P
0 g
s
.83988 .60783 m .82764 .66063 L .83485 .65118 L p .707 .577 .707 r
F P
0 g
s
.83485 .65118 m .84708 .59838 L .83988 .60783 L p .707 .577 .707 r
F P
0 g
s
.82515 .71464 m .82796 .73324 L .84428 .72511 L p .707 .577 .707 r
F P
0 g
s
.84428 .72511 m .84147 .70651 L .82515 .71464 L p .707 .577 .707 r
F P
0 g
s
.65153 .70238 m .65397 .66568 L .64142 .65631 L p .707 .577 .707 r
F P
0 g
s
.64142 .65631 m .63899 .69302 L .65153 .70238 L p .707 .577 .707 r
F P
0 g
s
.66482 .75432 m .66202 .73573 L .64968 .73129 L p .707 .577 .707 r
F P
0 g
s
.64795 .5525 m .63572 .6053 L .63826 .61699 L p .707 .577 .707 r
F P
0 g
s
.83494 .67188 m .83251 .70859 L .8396 .69989 L p .707 .577 .707 r
F P
0 g
s
.8396 .69989 m .84204 .66319 L .83494 .67188 L p .707 .577 .707 r
F P
0 g
s
.64968 .73129 m .65249 .74989 L .66482 .75432 L p .707 .577 .707 r
F P
0 g
s
.84147 .70651 m .84428 .72511 L .85142 .71751 L p .707 .577 .707 r
F P
0 g
s
.85142 .71751 m .84861 .69891 L .84147 .70651 L p .707 .577 .707 r
F P
0 g
s
.63899 .69302 m .64142 .65631 L .63856 .64682 L p .707 .577 .707 r
F P
0 g
s
.63572 .6053 m .64795 .5525 L .65516 .54304 L p .707 .577 .707 r
F P
0 g
s
.84708 .59838 m .83485 .65118 L .83231 .63948 L p .707 .577 .707 r
F P
0 g
s
.83231 .63948 m .84454 .58668 L .84708 .59838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63856 .64682 m .63612 .68352 L .63899 .69302 L p .707 .577 .707 r
F P
0 g
s
.65249 .74989 m .64968 .73129 L .64696 .72497 L p .707 .577 .707 r
F P
0 g
s
.65516 .54304 m .64292 .59584 L .63572 .6053 L p .707 .577 .707 r
F P
0 g
s
.84204 .66319 m .8396 .69989 L .83673 .6904 L p .707 .577 .707 r
F P
0 g
s
.83673 .6904 m .83917 .65369 L .84204 .66319 L p .707 .577 .707 r
F P
0 g
s
.64696 .72497 m .64977 .74357 L .65249 .74989 L p .707 .577 .707 r
F P
0 g
s
.84861 .69891 m .85142 .71751 L .84869 .71118 L p .707 .577 .707 r
F P
0 g
s
.84869 .71118 m .84588 .69259 L .84861 .69891 L p .707 .577 .707 r
F P
0 g
s
.64292 .59584 m .65516 .54304 L .6714 .53676 L p .707 .577 .707 r
F P
0 g
s
.63612 .68352 m .63856 .64682 L .64565 .63813 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84454 .58668 m .83231 .63948 L .82027 .62668 L p .707 .577 .707 r
F P
0 g
s
.82027 .62668 m .8325 .57388 L .84454 .58668 L p .707 .577 .707 r
F P
0 g
s
.38472 .62687 m .39696 .57407 L .36656 .5653 L p .707 .577 .707 r
F P
0 g
s
.39696 .57407 m .38472 .62687 L .41586 .63228 L p .707 .577 .707 r
F P
0 g
s
.41586 .63228 m .42809 .57948 L .39696 .57407 L p .707 .577 .707 r
F P
0 g
s
.64565 .63813 m .64322 .67483 L .63612 .68352 L p .707 .577 .707 r
F P
0 g
s
.35433 .6181 m .36656 .5653 L .33988 .55405 L p .707 .577 .707 r
F P
0 g
s
.36656 .5653 m .35433 .6181 L .38472 .62687 L p .707 .577 .707 r
F P
0 g
s
.42809 .57948 m .41586 .63228 L .44469 .63381 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64977 .74357 m .64696 .72497 L .6541 .71737 L p .707 .577 .707 r
F P
0 g
s
.6714 .53676 m .65917 .58956 L .64292 .59584 L p .707 .577 .707 r
F P
0 g
s
.83917 .65369 m .83673 .6904 L .82419 .68104 L p .707 .577 .707 r
F P
0 g
s
.82419 .68104 m .82663 .64433 L .83917 .65369 L p .707 .577 .707 r
F P
0 g
s
.6541 .71737 m .65691 .73597 L .64977 .74357 L p .707 .577 .707 r
F P
0 g
s
.32764 .60685 m .33988 .55405 L .31952 .5414 L p .707 .577 .707 r
F P
0 g
s
.33988 .55405 m .32764 .60685 L .35433 .6181 L p .707 .577 .707 r
F P
0 g
s
.45692 .58101 m .44469 .63381 L .46838 .63132 L p .707 .577 .707 r
F P
0 g
s
.46838 .63132 m .48062 .57852 L .45692 .58101 L p .707 .577 .707 r
F P
0 g
s
.65917 .58956 m .6714 .53676 L .6951 .53427 L p .707 .577 .707 r
F P
0 g
s
.8325 .57388 m .82027 .62668 L .79991 .61404 L p .707 .577 .707 r
F P
0 g
s
.79991 .61404 m .81215 .56124 L .8325 .57388 L p .707 .577 .707 r
F P
0 g
s
.38801 .68126 m .39045 .64455 L .35934 .64058 L p .707 .577 .707 r
F P
0 g
s
.39045 .64455 m .38801 .68126 L .41978 .68235 L p .707 .577 .707 r
F P
0 g
s
.41978 .68235 m .42222 .64564 L .39045 .64455 L p .707 .577 .707 r
F P
0 g
s
.84588 .69259 m .84869 .71118 L .83636 .70675 L p .707 .577 .707 r
F P
0 g
s
.83636 .70675 m .83355 .68816 L .84588 .69259 L p .707 .577 .707 r
F P
0 g
s
.64322 .67483 m .64565 .63813 L .66201 .63109 L p .707 .577 .707 r
F P
0 g
s
.42222 .64564 m .41978 .68235 L .44912 .68045 L p .707 .577 .707 r
F P
0 g
s
.44912 .68045 m .45155 .64374 L .42222 .64564 L p .707 .577 .707 r
F P
0 g
s
.3569 .67729 m .35934 .64058 L .33195 .63412 L p .707 .577 .707 r
F P
0 g
s
.35934 .64058 m .3569 .67729 L .38801 .68126 L p .707 .577 .707 r
F P
0 g
s
.66201 .63109 m .65957 .66779 L .64322 .67483 L p .707 .577 .707 r
F P
0 g
s
.40044 .7218 m .39763 .7032 L .36682 .70612 L p .707 .577 .707 r
F P
0 g
s
.31952 .5414 m .30729 .5942 L .32764 .60685 L p .707 .577 .707 r
F P
0 g
s
.45155 .64374 m .44912 .68045 L .47314 .67575 L p .707 .577 .707 r
F P
0 g
s
.47314 .67575 m .47557 .63905 L .45155 .64374 L p .707 .577 .707 r
F P
0 g
s
.30729 .5942 m .31952 .5414 L .30748 .5286 L p .707 .577 .707 r
F P
0 g
s
.6951 .53427 m .68287 .58707 L .65917 .58956 L p .707 .577 .707 r
F P
0 g
s
.36682 .70612 m .36963 .72472 L .40044 .7218 L p .707 .577 .707 r
F P
0 g
s
.33195 .63412 m .32951 .67083 L .3569 .67729 L p .707 .577 .707 r
F P
0 g
s
.48062 .57852 m .46838 .63132 L .48463 .62504 L p .707 .577 .707 r
F P
0 g
s
.48463 .62504 m .49687 .57224 L .48062 .57852 L p .707 .577 .707 r
F P
0 g
s
.68287 .58707 m .6951 .53427 L .72393 .5358 L p .707 .577 .707 r
F P
0 g
s
.81215 .56124 m .79991 .61404 L .77323 .60278 L p .707 .577 .707 r
F P
0 g
s
.77323 .60278 m .78546 .54998 L .81215 .56124 L p .707 .577 .707 r
F P
0 g
s
.65691 .73597 m .6541 .71737 L .67041 .70924 L p .707 .577 .707 r
F P
0 g
s
.82663 .64433 m .82419 .68104 L .8032 .67272 L p .707 .577 .707 r
F P
0 g
s
.8032 .67272 m .80563 .63601 L .82663 .64433 L p .707 .577 .707 r
F P
0 g
s
.36963 .72472 m .36682 .70612 L .33973 .70655 L p .707 .577 .707 r
F P
0 g
s
.32951 .67083 m .33195 .63412 L .31096 .6258 L p .707 .577 .707 r
F P
0 g
s
.67041 .70924 m .67322 .72784 L .65691 .73597 L p .707 .577 .707 r
F P
0 g
s
.33973 .70655 m .34254 .72515 L .36963 .72472 L p .707 .577 .707 r
F P
0 g
s
.45826 .69124 m .46107 .70983 L .48495 .70197 L p .707 .577 .707 r
F P
0 g
s
.48495 .70197 m .48214 .68337 L .45826 .69124 L p .707 .577 .707 r
F P
0 g
s
.65957 .66779 m .66201 .63109 L .68603 .62639 L p .707 .577 .707 r
F P
0 g
s
.83355 .68816 m .83636 .70675 L .81563 .70465 L p .707 .577 .707 r
F P
0 g
s
.81563 .70465 m .81282 .68605 L .83355 .68816 L p .707 .577 .707 r
F P
0 g
s
.71169 .5886 m .72393 .5358 L .75507 .54122 L p .707 .577 .707 r
F P
0 g
s
.72393 .5358 m .71169 .5886 L .68287 .58707 L p .707 .577 .707 r
F P
0 g
s
.78546 .54998 m .77323 .60278 L .74283 .59402 L p .707 .577 .707 r
F P
0 g
s
.74283 .59402 m .75507 .54122 L .78546 .54998 L p .707 .577 .707 r
F P
0 g
s
.31096 .6258 m .30852 .66251 L .32951 .67083 L p .707 .577 .707 r
F P
0 g
s
.47557 .63905 m .47314 .67575 L .4895 .66871 L p .707 .577 .707 r
F P
0 g
s
.4895 .66871 m .49193 .63201 L .47557 .63905 L p .707 .577 .707 r
F P
0 g
s
.30748 .5286 m .29525 .5814 L .30729 .5942 L p .707 .577 .707 r
F P
0 g
s
.75507 .54122 m .74283 .59402 L .71169 .5886 L p .707 .577 .707 r
F P
0 g
s
.34254 .72515 m .33973 .70655 L .31901 .70445 L p .707 .577 .707 r
F P
0 g
s
.68603 .62639 m .6836 .66309 L .65957 .66779 L p .707 .577 .707 r
F P
0 g
s
.31901 .70445 m .32181 .72305 L .34254 .72515 L p .707 .577 .707 r
F P
0 g
s
.80563 .63601 m .8032 .67272 L .77581 .66625 L p .707 .577 .707 r
F P
0 g
s
.77581 .66625 m .77824 .62955 L .80563 .63601 L p .707 .577 .707 r
F P
0 g
s
.29525 .5814 m .30748 .5286 L .30494 .51691 L p .707 .577 .707 r
F P
0 g
s
.30852 .66251 m .31096 .6258 L .29841 .61644 L p .707 .577 .707 r
F P
0 g
s
.49687 .57224 m .48463 .62504 L .49184 .61559 L p .707 .577 .707 r
F P
0 g
s
.49184 .61559 m .50407 .56279 L .49687 .57224 L p .707 .577 .707 r
F P
0 g
s
.67322 .72784 m .67041 .70924 L .69429 .70137 L p .707 .577 .707 r
F P
0 g
s
.48214 .68337 m .48495 .70197 L .50127 .69384 L p .707 .577 .707 r
F P
0 g
s
.50127 .69384 m .49846 .67524 L .48214 .68337 L p .707 .577 .707 r
F P
0 g
s
.6836 .66309 m .68603 .62639 L .71537 .62449 L p .707 .577 .707 r
F P
0 g
s
.69429 .70137 m .6971 .71997 L .67322 .72784 L p .707 .577 .707 r
F P
0 g
s
.81282 .68605 m .81563 .70465 L .78854 .70508 L p .707 .577 .707 r
F P
0 g
s
.78854 .70508 m .78573 .68649 L .81282 .68605 L p .707 .577 .707 r
F P
0 g
s
.29841 .61644 m .29598 .65314 L .30852 .66251 L p .707 .577 .707 r
F P
0 g
s
.77824 .62955 m .77581 .66625 L .7447 .66228 L p .707 .577 .707 r
F P
0 g
s
.7447 .66228 m .74714 .62558 L .77824 .62955 L p .707 .577 .707 r
F P
0 g
s
.71537 .62449 m .71293 .6612 L .6836 .66309 L p .707 .577 .707 r
F P
0 g
s
.71293 .6612 m .71537 .62449 L .74714 .62558 L p .707 .577 .707 r
F P
0 g
s
.32181 .72305 m .31901 .70445 L .30667 .70002 L p .707 .577 .707 r
F P
0 g
s
.49193 .63201 m .4895 .66871 L .49659 .66002 L p .707 .577 .707 r
F P
0 g
s
.49659 .66002 m .49903 .62331 L .49193 .63201 L p .707 .577 .707 r
F P
0 g
s
.30494 .51691 m .29271 .56971 L .29525 .5814 L p .707 .577 .707 r
F P
0 g
s
.74714 .62558 m .7447 .66228 L .71293 .6612 L p .707 .577 .707 r
F P
0 g
s
.6971 .71997 m .69429 .70137 L .72341 .69454 L p .707 .577 .707 r
F P
0 g
s
.30667 .70002 m .30948 .71862 L .32181 .72305 L p .707 .577 .707 r
F P
0 g
s
.72341 .69454 m .72622 .71314 L .6971 .71997 L p .707 .577 .707 r
F P
0 g
s
.78573 .68649 m .78854 .70508 L .75773 .70801 L p .707 .577 .707 r
F P
0 g
s
.75773 .70801 m .75492 .68941 L .78573 .68649 L p .707 .577 .707 r
F P
0 g
s
.29598 .65314 m .29841 .61644 L .29555 .60694 L p .707 .577 .707 r
F P
0 g
s
.49846 .67524 m .50127 .69384 L .50841 .68623 L p .707 .577 .707 r
F P
0 g
s
.50841 .68623 m .5056 .66764 L .49846 .67524 L p .707 .577 .707 r
F P
0 g
s
.29271 .56971 m .30494 .51691 L .31215 .50745 L p .707 .577 .707 r
F P
0 g
s
.50407 .56279 m .49184 .61559 L .4893 .60389 L p .707 .577 .707 r
F P
0 g
s
.4893 .60389 m .50153 .55109 L .50407 .56279 L p .707 .577 .707 r
F P
0 g
s
.72622 .71314 m .72341 .69454 L .75492 .68941 L p .707 .577 .707 r
F P
0 g
s
.75492 .68941 m .75773 .70801 L .72622 .71314 L p .707 .577 .707 r
F P
0 g
s
.29555 .60694 m .29311 .64365 L .29598 .65314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30948 .71862 m .30667 .70002 L .30395 .6937 L p .707 .577 .707 r
F P
0 g
s
.49903 .62331 m .49659 .66002 L .49372 .65053 L p .707 .577 .707 r
F P
0 g
s
.49372 .65053 m .49616 .61382 L .49903 .62331 L p .707 .577 .707 r
F P
0 g
s
.31215 .50745 m .29991 .56025 L .29271 .56971 L p .707 .577 .707 r
F P
0 g
s
.30395 .6937 m .30675 .71229 L .30948 .71862 L p .707 .577 .707 r
F P
0 g
s
.29311 .64365 m .29555 .60694 L .30264 .59825 L p .707 .577 .707 r
F P
0 g
s
.5056 .66764 m .50841 .68623 L .50568 .67991 L p .707 .577 .707 r
F P
0 g
s
.50568 .67991 m .50287 .66131 L .5056 .66764 L p .707 .577 .707 r
F P
0 g
s
.29991 .56025 m .31215 .50745 L .32839 .50117 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50153 .55109 m .4893 .60389 L .47726 .59109 L p .707 .577 .707 r
F P
0 g
s
.47726 .59109 m .48949 .53829 L .50153 .55109 L p .707 .577 .707 r
F P
0 g
s
.30264 .59825 m .30021 .63496 L .29311 .64365 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32839 .50117 m .31616 .55397 L .29991 .56025 L p .707 .577 .707 r
F P
0 g
s
.30675 .71229 m .30395 .6937 L .31109 .6861 L p .707 .577 .707 r
F P
0 g
s
.49616 .61382 m .49372 .65053 L .48118 .64116 L p .707 .577 .707 r
F P
0 g
s
.48118 .64116 m .48362 .60445 L .49616 .61382 L p .707 .577 .707 r
F P
0 g
s
.31109 .6861 m .3139 .70469 L .30675 .71229 L p .707 .577 .707 r
F P
0 g
s
.31616 .55397 m .32839 .50117 L .35209 .49868 L p .707 .577 .707 r
F P
0 g
s
.48949 .53829 m .47726 .59109 L .4569 .57845 L p .707 .577 .707 r
F P
0 g
s
.4569 .57845 m .46914 .52565 L .48949 .53829 L p .707 .577 .707 r
F P
0 g
s
.30021 .63496 m .30264 .59825 L .319 .59121 L p .707 .577 .707 r
F P
0 g
s
.50287 .66131 m .50568 .67991 L .49335 .67548 L p .707 .577 .707 r
F P
0 g
s
.49335 .67548 m .49054 .65688 L .50287 .66131 L p .707 .577 .707 r
F P
0 g
s
.319 .59121 m .31656 .62792 L .30021 .63496 L p .707 .577 .707 r
F P
0 g
s
.35209 .49868 m .33986 .55148 L .31616 .55397 L p .707 .577 .707 r
F P
0 g
s
.33986 .55148 m .35209 .49868 L .38092 .50021 L p .707 .577 .707 r
F P
0 g
s
.48362 .60445 m .48118 .64116 L .46019 .63284 L p .707 .577 .707 r
F P
0 g
s
.46019 .63284 m .46262 .59613 L .48362 .60445 L p .707 .577 .707 r
F P
0 g
s
.46914 .52565 m .4569 .57845 L .43022 .56719 L p .707 .577 .707 r
F P
0 g
s
.43022 .56719 m .44245 .51439 L .46914 .52565 L p .707 .577 .707 r
F P
0 g
s
.3139 .70469 m .31109 .6861 L .3274 .67796 L p .707 .577 .707 r
F P
0 g
s
.3274 .67796 m .33021 .69656 L .3139 .70469 L p .707 .577 .707 r
F P
0 g
s
.31656 .62792 m .319 .59121 L .34302 .58651 L p .707 .577 .707 r
F P
0 g
s
.49054 .65688 m .49335 .67548 L .47262 .67338 L p .707 .577 .707 r
F P
0 g
s
.47262 .67338 m .46981 .65478 L .49054 .65688 L p .707 .577 .707 r
F P
0 g
s
.36868 .55301 m .38092 .50021 L .41206 .50563 L p .707 .577 .707 r
F P
0 g
s
.38092 .50021 m .36868 .55301 L .33986 .55148 L p .707 .577 .707 r
F P
0 g
s
.44245 .51439 m .43022 .56719 L .39982 .55843 L p .707 .577 .707 r
F P
0 g
s
.39982 .55843 m .41206 .50563 L .44245 .51439 L p .707 .577 .707 r
F P
0 g
s
.41206 .50563 m .39982 .55843 L .36868 .55301 L p .707 .577 .707 r
F P
0 g
s
.34302 .58651 m .34058 .62322 L .31656 .62792 L p .707 .577 .707 r
F P
0 g
s
.46262 .59613 m .46019 .63284 L .4328 .62638 L p .707 .577 .707 r
F P
0 g
s
.4328 .62638 m .43523 .58967 L .46262 .59613 L p .707 .577 .707 r
F P
0 g
s
.34058 .62322 m .34302 .58651 L .37236 .58461 L p .707 .577 .707 r
F P
0 g
s
.33021 .69656 m .3274 .67796 L .35128 .6701 L p .707 .577 .707 r
F P
0 g
s
.35128 .6701 m .35409 .68869 L .33021 .69656 L p .707 .577 .707 r
F P
0 g
s
.46981 .65478 m .47262 .67338 L .44553 .67381 L p .707 .577 .707 r
F P
0 g
s
.44553 .67381 m .44272 .65521 L .46981 .65478 L p .707 .577 .707 r
F P
0 g
s
.43523 .58967 m .4328 .62638 L .40169 .62241 L p .707 .577 .707 r
F P
0 g
s
.40169 .62241 m .40413 .5857 L .43523 .58967 L p .707 .577 .707 r
F P
0 g
s
.37236 .58461 m .36992 .62132 L .34058 .62322 L p .707 .577 .707 r
F P
0 g
s
.36992 .62132 m .37236 .58461 L .40413 .5857 L p .707 .577 .707 r
F P
0 g
s
.40413 .5857 m .40169 .62241 L .36992 .62132 L p .707 .577 .707 r
F P
0 g
s
.35409 .68869 m .35128 .6701 L .3804 .66326 L p .707 .577 .707 r
F P
0 g
s
.3804 .66326 m .38321 .68186 L .35409 .68869 L p .707 .577 .707 r
F P
0 g
s
.44272 .65521 m .44553 .67381 L .41472 .67673 L p .707 .577 .707 r
F P
0 g
s
.41472 .67673 m .41191 .65813 L .44272 .65521 L p .707 .577 .707 r
F P
0 g
s
.38321 .68186 m .3804 .66326 L .41191 .65813 L p .707 .577 .707 r
F P
0 g
s
.41191 .65813 m .41472 .67673 L .38321 .68186 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH01P00PGoo001cOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH6001kOol0071oo`<000MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Eoo`00KWoo0`002EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000LGoo001/Ool20002FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUH00000
Kgoo001ZOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH01000FUIJEUYF0`00K7oo001YOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001ZOol0
06Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Qoo`00Igoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYF001WOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00IGoo001W
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0HWoo001WOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Hgoo001WOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001W
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Moo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8006=oo`00Igoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH015YF0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
0P00Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF0P00Hgoo001VOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<007ooOol0HGoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000Hgoo001VOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFOol0Hgoo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo
001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0Hgoo001VOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFOol0I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0
I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001QOol7
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005aoo`D000=JEP04001JEUYFFUH90005
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001VOol005Yoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
009JEPH000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Ioo`00F7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00@005YF000000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Ioo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001GOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Ioo`8000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP0035YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001FOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJ
EUYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001VOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00EGoo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YF
FUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000]oo`L005Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001goo10000eYF00@005YFFUIJ
EPT004]oo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000]JEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP8000Ioo`<000IJEP03001JEUYF00EJEP03001JEUYF009JEPH0
04Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0017oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P00@Woo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<003moo`00E7oo00<0
05YF00000UYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20003Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`00?7oo001DOol20003FUH40003FUH200000goo000000080004FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YF000003Yoo`00E7oo0P0000AJEP00000000IJEP04001JEP000002FUH0
0`00FUIJEP03FUH70008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00>7oo001DOol00eYF
00000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`001EYF00<005YFFUH00`0000AJEP00000000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P0000Aoo`00FUH000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Ioo`00Dgoo0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`000UYF00<005YF000010000eYF0`0000=JEP00FUH01UYF00<005YF
FUH015YF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000goo00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3000dOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEP0000800003FUH0000000<0009JEP04001JEUYFFUH30006FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003Ool00000
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYF000cOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPL0009JEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP05001JEUYFFUH0000=FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000goo00000003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000aOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEPL000QJEP80
0003FUH005YF00EJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo02ioo`00Dgoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF0P00
1UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH4
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001JEUYFFUH005YF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YF000002eoo`00E7oo00@005YFFUH000IJEP03001JEP0001H0009JEP03001JEUYF00EJEP04
001JEUYF0003FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02Yoo`00EGoo0`0015YF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0015YF00@005YFFUIJEP<000AJEP<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEPD0009JEP<0009oo`T0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo
02Yoo`00=Goo5@003Goo00<005YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0`0000EJEP00001JEP0000IJEP04001JEP000009Ool60007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000cOol200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH60008Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH40002FUH20002FUH01000FUH0000035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000Uo
o`<00003Ool0000000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool0035o
o`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000004Ool20002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH0000200000eYF0000000200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH015YF00<005YFFUH015YF0`001Goo1@00
0Woo0`0000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEP000080009oo`D000Eoo`<000MJEP03001J
EUYF00=JEP03001JEUYF009JEP8002aoo`00<7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`0027oo0P0015YF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000/Ool002moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF1P0027oo0`0000=JEP00FUH01EYF00@005YFFUIJEP8002eoo`00;goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00=oo`8000IJEP04001JEUYFFUH2000]Ool002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`0015YF00@005YFFUIJEP8002eo
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP800005Ool005YFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP04001JEUYFFUH90003FUH300000eYF000000080004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo
001JEUYF00001EYF00<005YFFUH01EYF40000eYF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
00<005YF0000;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUH00003FUH50004FUH01000FUIJEP001EYF1`0015YF2@000eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000Woo0P001UYF200015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH015YF00@0
05YFFUIJEP8002ioo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YF001JEP80009JEP<000AJEP04001JEUYF0005FUH00`00FUIJEP0<0004
FUH50005FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20003Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH6
00000eYF001JEP05FUH20002FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00001JEP0015YF0`000UYF00@005YFFUH000EJ
EP03001JEUYF00D0009JEP03001JEUYF009JEPP00003FUH0000000=JEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF10000eYF00<005YFFUH00P00
00=JEP00Ool0;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUH0000300000eYF001JEP04FUH0
0`00FUIJEP0500000eYF001JEP0:FUH20003FUH200000eYF001JEP02FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000goo00000003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP02FUH00`00
FUH0000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPH00003FUH005YF009JEP<0
009JEP03001JEUYF00UJEPH00003FUH0000000=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008000=JEP03001JEP0002ioo`00;Goo
0P000eYF500015YF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YF
FUIJEQP000EJEP03001JEP00009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0000002moo`00;Goo0P0000AJEP00
000000IJEP04001JEP000009Ool60007FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH4000_Ool002eoo`03FUH00000009JEP03001JEUYF00AJEP04001JEUYFFUH30008Ool3000017oo
0000000015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002io
o`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000IJEP00FUH0
05YF0005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000C000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Woo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000000Woo1@00
1Woo0`0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH02@000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF100015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`002Goo100015YF00<005YFFUH01EYF00<005YFFUH00UYF
1`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@000AJEP04001JEUYFFUHI0004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH60009Ool500000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP02FUH50006FUH00`00Oomoo`09Ool=
0006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003Ool2000015YF000000000eYF
10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
000000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00FUH005YF0P00
00=JEP0000000P001UYF0P002Goo1@001Woo1`000UYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPL0009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPl000=JEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P0000=JEP00FUH00eYF0`0015YF00<005YF000027oo1@003Goo100015YF00H005YFFUH0
05YF000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUH0000F0002FUH00`00FUIJEP05FUH00`00
FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90005FUH01000FUIJEUYF1@0000=JEP00
00000`0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEP0000<000=JEP03001oogoo00Eoo`D0015oo`<00007FUH0
05YFFUH005YF0000;Goo000^Ool00`00FUH00004FUH400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60004FUH40006FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP02FUH70008FUH6
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH00eYF1`001Goo0`004Goo1P000UYF00<005YF0000;Goo000_Ool20002FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00
FUIJEP04FUH00`00FUIJEP050002FUH>0004FUH00`00FUIJEP05FUH30002FUH01000FUH000002EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH00UYF6@000eYF00D005YFFUH005YF008002ioo`00<7oo10001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP@0
00AJEP03001JEUYF00D00003FUH005YF00YJEP04001JEUYFFUH400000eYF001JEP03FUH00`00FUH0
0009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000C000^Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080
00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP0500000eYF001JEP0:FUH40005FUH0
0`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000080004FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUH000020002FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH01EYF10000UYF00<005YFFUH015YF00@0
05YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP04001JEUYFFUH20002
FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YF00001@001UYF00<005YFFUH015YF00<005YF
00000P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P0000=JEP00
FUH015YF00<005YFFUH015YF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUH00000
15YF00@005YFFUH000IJEP03001JEP0000P000=JEP03001JEUYF00MJEP03001JEUYF009JEP<0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Aoo`8000EJ
EP03001JEUYF009JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002]oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF01@000AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP00008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Ioo`8000=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
009JEQ8000=JEP03001oogoo02Uoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF3P001EYF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1EYF00<005YFFUH00eYF00@005YFFUIJEPD00003FUH007oo02Yoo`00;Goo0P0015YF00<005YFFUH0
0eYF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP<000IJEP800003FUH005YF00IJ
EP03001JEUYF00AJEPH000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000<0009JEP<0
02]oo`00;Goo0P0015YF00@005YFFUIJEPL000Aoo`<00003FUH0000000P000AJEP04001JEUYF0003
FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000AFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH20003FUH00`00
FUIJEP05FUH00`00FUIJEP040002FUH00`00FUH000020004FUH00`00FUIJEP06FUH01000FUIJEUYF
1P0015YF00<005YF0000:goo000/Ool00`00FUH00003FUH5000>Ool60004FUH700000eYF00000002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000DFUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20005FUH00`00FUIJ
EP03FUH80002FUH60003FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH00`00FUH0000[Ool002ao
o`04001JEP00FUH2000015YF000000004Woo2`000eYF20000eYF00<005YFFUH01EYF00<005YFFUH0
0UYF1P0065YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00<005YF00000`0000=JEP0000001Goo40001Goo0`001EYF00<005YFFUH00UYF0P00;7oo000/
Ool01P00FUH00000FUH000AJEP<000ioo`D000Moo`X00003FUH0000000h000EJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80009JEP800003FUH005YF00AJEP<00004FUH005YFFUH20008Ool50009Ool400000eYF001JEP06
FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5000A
Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH20002FUH00`00
FUIJEP020002FUH00`00FUIJEP0200000eYF001oo`08Ool30003Ool70005FUH00`00FUIJEP05FUH0
1000FUH00000;Woo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH60004Ool5000?Ool4
00001EYF001JEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P000UYF100000AJ
EP00000000=JEP03001JEP0000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<0031oo`00
;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEQP000EJEP04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH01000FUH005YF500015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`00<goo000/Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH015YF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Moo`00;Goo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYF0006FUH00`00FUIJEP04FUH900000eYF001JEP0;FUH00`00FUIJEP08FUH80009FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000>Woo000^Ool00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0000=0002FUH00`00FUIJEP04
FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00?Woo000_Ool20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP090003FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJ
EP03FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH4
00000eYF001JEP06FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@goo000`Ool20004FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00002FUH01000FUIJ
EUYF0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00`001UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF10000eYF00<005YFFUH00UYF
3`00Agoo000bOol300000eYF001JEP06FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20002FUH00`00FUH000020008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH60006FUH00`00FUH0
0009001DOol003Eoo`<000=JEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP80009JEP<00003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP<00003FUH005YF00=JEPX0009JEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol003Qoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPh00007
FUH005YFFUH005YF000025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF0`0015YF0P0027oo100015YF00H005YFFUH005YF001DOol003Ioo`80
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000EJEP04001JEUYFFUH70002FUH30008FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP020002FUH2000<Ool300001eYF001JEUYF001JEP0005Aoo`00=7oo0`001EYF00<005YFFUH0
1UYF00<005YFFUH0100015YF00<005YFFUH00UYF1`0017oo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF10002goo1P000UYF00<005YF0000E7oo000bOol20002FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUHA000;Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0
000017oo1`000eYF00D005YFFUH005YF008005Eoo`00<Goo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH010000goo1@004Goo1P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
5P00EGoo000`Ool20004FUH00`00FUIJEP03FUH40007Ool5000=Ool40004FUH20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001E
Ool002moo`03001JEP0000AJEP03001JEP0000<000aoo`<000Yoo`@0009JEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP02001COol002moo`04001JEUYF0003FUH2000IOol40006FUH00`00
FUIJEP04FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUIJEP80059oo`00;goo00D005YFFUH005YF008001Moo`@00003
FUH005YF00MJEP03001JEUYF00AJEP@00003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000MJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080059oo`00<7oo00<005YF00000`0027oo
3`001EYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEPh0
00=JEP05001JEUYFFUH0001BOol0031oo`800004FUH005YFFUH80003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000027oo0P001EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1P001EYF00<0
05YFFUH00eYF00<005YFFUH01@000UYF00<007ooOol0D7oo000`Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P0037oo0P000eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH00eYF00D005YF000007oo00800003FUH000000080
055oo`00<7oo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL001Aoo`800003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000=JEP03001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUH0
0000DGoo000`Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP04000MOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH60004FUH00`00FUIJEP02FUH<00000eYF001JEP03FUH01000FUIJEP00DGoo000bOol50003FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH6000UOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0D0005Ool30005FUH00`00FUIJEP02FUH3001BOol003Mooa00035o
o`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEPP000Moo`D000Uoo`@00003FUH005YF00IJEP05
001JEUYFFUH0001DOol0085ooaT000moo`D000Aoo`D000EJEP03001JEUYF00EJEP04001JEP00001E
Ool0091oo`05001JEUYF001JEP02000COol300000goo000000020002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH3001GOol0095oo`03001JEP0001X000IJEP03001JEUYF00IJEP03001JEP0000<005Yo
o`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH015YF0`00GWoo002AOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04001QOol0095oo`80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD006Eoo`00TWoo0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000JWoo002DOol40003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH7001^Ool009Qooa0007Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60018 .74286 m .58794 .68744 L .55754 .69256 L p .707 .577 .707 r
F P
0 g
s
.58794 .68744 m .60018 .74286 L .63131 .73574 L p .707 .577 .707 r
F P
0 g
s
.63131 .73574 m .61908 .68032 L .58794 .68744 L p .707 .577 .707 r
F P
0 g
s
.61908 .68032 m .63131 .73574 L .66014 .72733 L p .707 .577 .707 r
F P
0 g
s
.66014 .72733 m .64791 .67191 L .61908 .68032 L p .707 .577 .707 r
F P
0 g
s
.56978 .74799 m .55754 .69256 L .53086 .6952 L p .707 .577 .707 r
F P
0 g
s
.55754 .69256 m .56978 .74799 L .60018 .74286 L p .707 .577 .707 r
F P
0 g
s
.64791 .67191 m .66014 .72733 L .68384 .71845 L p .707 .577 .707 r
F P
0 g
s
.68384 .71845 m .6716 .66302 L .64791 .67191 L p .707 .577 .707 r
F P
0 g
s
.53086 .6952 m .5431 .75063 L .56978 .74799 L p .707 .577 .707 r
F P
0 g
s
.5983 .80644 m .59587 .76921 L .56476 .7694 L p .707 .577 .707 r
F P
0 g
s
.59587 .76921 m .5983 .80644 L .63008 .80379 L p .707 .577 .707 r
F P
0 g
s
.63008 .80379 m .62764 .76656 L .59587 .76921 L p .707 .577 .707 r
F P
0 g
s
.62764 .76656 m .63008 .80379 L .65941 .79892 L p .707 .577 .707 r
F P
0 g
s
.65941 .79892 m .65697 .76169 L .62764 .76656 L p .707 .577 .707 r
F P
0 g
s
.5431 .75063 m .53086 .6952 L .5105 .69509 L p .707 .577 .707 r
F P
0 g
s
.5672 .80663 m .56476 .7694 L .53737 .76709 L p .707 .577 .707 r
F P
0 g
s
.56476 .7694 m .5672 .80663 L .5983 .80644 L p .707 .577 .707 r
F P
0 g
s
.6716 .66302 m .68384 .71845 L .70008 .70997 L p .707 .577 .707 r
F P
0 g
s
.70008 .70997 m .68785 .65454 L .6716 .66302 L p .707 .577 .707 r
F P
0 g
s
.65697 .76169 m .65941 .79892 L .68343 .79231 L p .707 .577 .707 r
F P
0 g
s
.68343 .79231 m .681 .75508 L .65697 .76169 L p .707 .577 .707 r
F P
0 g
s
.53737 .76709 m .53981 .80432 L .5672 .80663 L p .707 .577 .707 r
F P
0 g
s
.5105 .69509 m .52274 .75052 L .5431 .75063 L p .707 .577 .707 r
F P
0 g
s
.58528 .85797 m .58809 .83997 L .55728 .83333 L p .707 .577 .707 r
F P
0 g
s
.58809 .83997 m .58528 .85797 L .61678 .86147 L p .707 .577 .707 r
F P
0 g
s
.61678 .86147 m .61959 .84348 L .58809 .83997 L p .707 .577 .707 r
F P
0 g
s
.53981 .80432 m .53737 .76709 L .51638 .76251 L p .707 .577 .707 r
F P
0 g
s
.61959 .84348 m .61678 .86147 L .6459 .86149 L p .707 .577 .707 r
F P
0 g
s
.6459 .86149 m .64871 .8435 L .61959 .84348 L p .707 .577 .707 r
F P
0 g
s
.55447 .85132 m .55728 .83333 L .53019 .82419 L p .707 .577 .707 r
F P
0 g
s
.55728 .83333 m .55447 .85132 L .58528 .85797 L p .707 .577 .707 r
F P
0 g
s
.52274 .75052 m .5105 .69509 L .49847 .69224 L p .707 .577 .707 r
F P
0 g
s
.51638 .76251 m .51882 .79974 L .53981 .80432 L p .707 .577 .707 r
F P
0 g
s
.681 .75508 m .68343 .79231 L .69979 .78461 L p .707 .577 .707 r
F P
0 g
s
.69979 .78461 m .69735 .74738 L .681 .75508 L p .707 .577 .707 r
F P
0 g
s
.53019 .82419 m .52738 .84218 L .55447 .85132 L p .707 .577 .707 r
F P
0 g
s
.68785 .65454 m .70008 .70997 L .70729 .70272 L p .707 .577 .707 r
F P
0 g
s
.70729 .70272 m .69505 .64729 L .68785 .65454 L p .707 .577 .707 r
F P
0 g
s
.64871 .8435 m .6459 .86149 L .66979 .85802 L p .707 .577 .707 r
F P
0 g
s
.66979 .85802 m .6726 .84003 L .64871 .8435 L p .707 .577 .707 r
F P
0 g
s
.49847 .69224 m .5107 .74766 L .52274 .75052 L p .707 .577 .707 r
F P
0 g
s
.52738 .84218 m .53019 .82419 L .50946 .81345 L p .707 .577 .707 r
F P
0 g
s
.51882 .79974 m .51638 .76251 L .50384 .75612 L p .707 .577 .707 r
F P
0 g
s
.50946 .81345 m .50665 .83145 L .52738 .84218 L p .707 .577 .707 r
F P
0 g
s
.50384 .75612 m .50627 .79335 L .51882 .79974 L p .707 .577 .707 r
F P
0 g
s
.69735 .74738 m .69979 .78461 L .70689 .77658 L p .707 .577 .707 r
F P
0 g
s
.70689 .77658 m .70445 .73935 L .69735 .74738 L p .707 .577 .707 r
F P
0 g
s
.5107 .74766 m .49847 .69224 L .49593 .68693 L p .707 .577 .707 r
F P
0 g
s
.6726 .84003 m .66979 .85802 L .6861 .85141 L p .707 .577 .707 r
F P
0 g
s
.6861 .85141 m .68891 .83341 L .6726 .84003 L p .707 .577 .707 r
F P
0 g
s
.50665 .83145 m .50946 .81345 L .49713 .80217 L p .707 .577 .707 r
F P
0 g
s
.69505 .64729 m .70729 .70272 L .70475 .69741 L p .707 .577 .707 r
F P
0 g
s
.70475 .69741 m .69251 .64198 L .69505 .64729 L p .707 .577 .707 r
F P
0 g
s
.49713 .80217 m .49432 .82017 L .50665 .83145 L p .707 .577 .707 r
F P
0 g
s
.49593 .68693 m .50816 .74235 L .5107 .74766 L p .707 .577 .707 r
F P
0 g
s
.50627 .79335 m .50384 .75612 L .50097 .74854 L p .707 .577 .707 r
F P
0 g
s
.50097 .74854 m .50341 .78577 L .50627 .79335 L p .707 .577 .707 r
F P
0 g
s
.50816 .74235 m .49593 .68693 L .50313 .67968 L p .707 .577 .707 r
F P
0 g
s
.50313 .67968 m .51537 .7351 L .50816 .74235 L p .707 .577 .707 r
F P
0 g
s
.50341 .78577 m .50097 .74854 L .50806 .7405 L p .707 .577 .707 r
F P
0 g
s
.50806 .7405 m .5105 .77773 L .50341 .78577 L p .707 .577 .707 r
F P
0 g
s
.49432 .82017 m .49713 .80217 L .4944 .79145 L p .707 .577 .707 r
F P
0 g
s
.4944 .79145 m .49159 .80944 L .49432 .82017 L p .707 .577 .707 r
F P
0 g
s
.49159 .80944 m .4944 .79145 L .50154 .78233 L p .707 .577 .707 r
F P
0 g
s
.50154 .78233 m .49873 .80033 L .49159 .80944 L p .707 .577 .707 r
F P
0 g
s
.49873 .80033 m .50154 .78233 L .51785 .77572 L p .707 .577 .707 r
F P
0 g
s
.51785 .77572 m .51504 .79371 L .49873 .80033 L p .707 .577 .707 r
F P
0 g
s
.5057 .82114 m .48264 .31735 L .43868 .31672 L p .707 .577 .707 r
F P
0 g
s
.51537 .7351 m .50313 .67968 L .51938 .67119 L p .707 .577 .707 r
F P
0 g
s
.51938 .67119 m .53161 .72662 L .51537 .7351 L p .707 .577 .707 r
F P
0 g
s
.5105 .77773 m .50806 .7405 L .52442 .7328 L p .707 .577 .707 r
F P
0 g
s
.52442 .7328 m .52686 .77003 L .5105 .77773 L p .707 .577 .707 r
F P
0 g
s
.53161 .72662 m .51938 .67119 L .54307 .66231 L p .707 .577 .707 r
F P
0 g
s
.54307 .66231 m .55531 .71774 L .53161 .72662 L p .707 .577 .707 r
F P
0 g
s
.52686 .77003 m .52442 .7328 L .54844 .7262 L p .707 .577 .707 r
F P
0 g
s
.54844 .7262 m .55088 .76343 L .52686 .77003 L p .707 .577 .707 r
F P
0 g
s
.51504 .79371 m .51785 .77572 L .54174 .77225 L p .707 .577 .707 r
F P
0 g
s
.54174 .77225 m .53893 .79024 L .51504 .79371 L p .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .54174 .77225 L .55695 .77226 L p .707 .577 .707 r
F P
0 g
s
.55695 .77226 m .57086 .77227 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .55695 .77226 L .55233 .7827 L .707 .577 .707 r
F
.48264 .31735 m .5057 .82114 L .53622 .81914 L p F P
0 g
s
.53622 .81914 m .5506 .8182 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.5506 .8182 m .54929 .78957 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.60236 .77577 m .59956 .79377 L .56913 .79038 L p .707 .577 .707 r
F P
0 g
s
.56896 .78988 m .60236 .77577 L .56913 .79038 L .707 .577 .707 r
F
.54929 .78957 m .5506 .8182 L p .57244 .80016 L F P
0 g
s
.57086 .77227 m .60236 .77577 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .57086 .77227 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.58877 .78667 m .56838 .78817 L .57244 .80016 L .707 .577 .707 r
F
.56838 .78817 m .54929 .78957 L .57244 .80016 L F
.56805 .79026 m .56838 .78817 L p .56896 .78988 L F P
0 g
s
.56913 .79038 m .56805 .79026 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .58877 .78667 L .57244 .80016 L .707 .577 .707 r
F
.5506 .8182 m .5772 .81419 L p .57244 .80016 L F P
0 g
s
.5772 .81419 m .59205 .81196 L p .57244 .80016 L .707 .577 .707 r
F P
0 g
s
.57086 .77227 m .56838 .78817 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.54899 .79025 m .53893 .79024 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.55233 .7827 m .57086 .77227 L .54899 .79025 L .707 .577 .707 r
F
.55531 .71774 m .54307 .66231 L .56716 .65528 L p F P
0 g
s
.56716 .65528 m .5719 .6539 L p .57005 .66102 L .707 .577 .707 r
F P
0 g
s
.55531 .71774 m .56716 .65528 L .57005 .66102 L .707 .577 .707 r
F
.54929 .78957 m .54075 .60279 L p .54732 .79402 L F P
0 g
s
.54075 .60279 m .52755 .3144 L p .53932 .59996 L .707 .577 .707 r
F P
0 g
s
.54075 .60279 m .53932 .59996 L .54732 .79402 L .707 .577 .707 r
F
.5719 .6539 m .58414 .70933 L .55531 .71774 L p F P
0 g
s
.55088 .76343 m .54844 .7262 L .57778 .72133 L p .707 .577 .707 r
F P
0 g
s
.57778 .72133 m .58022 .75856 L .55088 .76343 L p .707 .577 .707 r
F P
0 g
s
.58022 .75856 m .57778 .72133 L .60955 .71867 L p .707 .577 .707 r
F P
0 g
s
.60955 .71867 m .61199 .7559 L .58022 .75856 L p .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .54929 .78957 L p .58877 .78667 L .707 .577 .707 r
F P
0 g
s
.56805 .79026 m .54899 .79025 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .56805 .79026 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .48264 .31735 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.54732 .79402 m .48264 .31735 L .53622 .81914 L .707 .577 .707 r
F
.58414 .70933 m .5719 .6539 L .60304 .64678 L p F P
0 g
s
.60304 .64678 m .61527 .70221 L .58414 .70933 L p .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .56899 .30816 L .52755 .3144 L p .707 .577 .707 r
F P
0 g
s
.68891 .83341 m .6861 .85141 L .69324 .84229 L p .707 .577 .707 r
F P
0 g
s
.69324 .84229 m .69605 .8243 L .68891 .83341 L p .707 .577 .707 r
F P
0 g
s
.70445 .73935 m .70689 .77658 L .70402 .76899 L p .707 .577 .707 r
F P
0 g
s
.70402 .76899 m .70158 .73176 L .70445 .73935 L p .707 .577 .707 r
F P
0 g
s
.46174 .82051 m .43868 .31672 L .39997 .31257 L p .707 .577 .707 r
F P
0 g
s
.43868 .31672 m .46174 .82051 L .5057 .82114 L p .707 .577 .707 r
F P
0 g
s
.69251 .64198 m .70475 .69741 L .69271 .69456 L p .707 .577 .707 r
F P
0 g
s
.69271 .69456 m .68048 .63913 L .69251 .64198 L p .707 .577 .707 r
F P
0 g
s
.61527 .70221 m .60304 .64678 L .63344 .64165 L p .707 .577 .707 r
F P
0 g
s
.64066 .71849 m .64309 .75572 L .61199 .7559 L p .707 .577 .707 r
F P
0 g
s
.61199 .7559 m .60955 .71867 L .64066 .71849 L p .707 .577 .707 r
F P
0 g
s
.63317 .78242 m .63036 .80041 L .59956 .79377 L p .707 .577 .707 r
F P
0 g
s
.59956 .79377 m .60236 .77577 L .63317 .78242 L p .707 .577 .707 r
F P
0 g
s
.56899 .30816 m .59205 .81196 L .62599 .80304 L p .707 .577 .707 r
F P
0 g
s
.63344 .64165 m .64567 .69708 L .61527 .70221 L p .707 .577 .707 r
F P
0 g
s
.62599 .80304 m .60293 .29924 L .56899 .30816 L p .707 .577 .707 r
F P
0 g
s
.25717 .70482 m .24493 .6494 L .21454 .65452 L p .707 .577 .707 r
F P
0 g
s
.24493 .6494 m .25717 .70482 L .2883 .6977 L p .707 .577 .707 r
F P
0 g
s
.2883 .6977 m .27607 .64228 L .24493 .6494 L p .707 .577 .707 r
F P
0 g
s
.27607 .64228 m .2883 .6977 L .31713 .68929 L p .707 .577 .707 r
F P
0 g
s
.31713 .68929 m .3049 .63387 L .27607 .64228 L p .707 .577 .707 r
F P
0 g
s
.42302 .81636 m .39997 .31257 L .37028 .30531 L p .707 .577 .707 r
F P
0 g
s
.39997 .31257 m .42302 .81636 L .46174 .82051 L p .707 .577 .707 r
F P
0 g
s
.69605 .8243 m .69324 .84229 L .69051 .83157 L p .707 .577 .707 r
F P
0 g
s
.69051 .83157 m .69332 .81357 L .69605 .8243 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22677 .70995 m .21454 .65452 L .18785 .65716 L p .707 .577 .707 r
F P
0 g
s
.21454 .65452 m .22677 .70995 L .25717 .70482 L p .707 .577 .707 r
F P
0 g
s
.70158 .73176 m .70402 .76899 L .69148 .7626 L p .707 .577 .707 r
F P
0 g
s
.69148 .7626 m .68904 .72537 L .70158 .73176 L p .707 .577 .707 r
F P
0 g
s
.3049 .63387 m .31713 .68929 L .34083 .68041 L p .707 .577 .707 r
F P
0 g
s
.34083 .68041 m .32859 .62498 L .3049 .63387 L p .707 .577 .707 r
F P
0 g
s
.68048 .63913 m .69271 .69456 L .67235 .69444 L p .707 .577 .707 r
F P
0 g
s
.67235 .69444 m .66012 .63902 L .68048 .63913 L p .707 .577 .707 r
F P
0 g
s
.18785 .65716 m .20009 .71259 L .22677 .70995 L p .707 .577 .707 r
F P
0 g
s
.64567 .69708 m .63344 .64165 L .66012 .63902 L p .707 .577 .707 r
F P
0 g
s
.66805 .72079 m .67048 .75802 L .64309 .75572 L p .707 .577 .707 r
F P
0 g
s
.64309 .75572 m .64066 .71849 L .66805 .72079 L p .707 .577 .707 r
F P
0 g
s
.66027 .79156 m .65746 .80955 L .63036 .80041 L p .707 .577 .707 r
F P
0 g
s
.63036 .80041 m .63317 .78242 L .66027 .79156 L p .707 .577 .707 r
F P
0 g
s
.60293 .29924 m .62599 .80304 L .64909 .79231 L p .707 .577 .707 r
F P
0 g
s
.64909 .79231 m .62603 .28852 L .60293 .29924 L p .707 .577 .707 r
F P
0 g
s
.2553 .77269 m .25286 .73546 L .22175 .73564 L p .707 .577 .707 r
F P
0 g
s
.25286 .73546 m .2553 .77269 L .28707 .77003 L p .707 .577 .707 r
F P
0 g
s
.28707 .77003 m .28463 .7328 L .25286 .73546 L p .707 .577 .707 r
F P
0 g
s
.28463 .7328 m .28707 .77003 L .3164 .76516 L p .707 .577 .707 r
F P
0 g
s
.3164 .76516 m .31396 .72793 L .28463 .7328 L p .707 .577 .707 r
F P
0 g
s
.20009 .71259 m .18785 .65716 L .1675 .65705 L p .707 .577 .707 r
F P
0 g
s
.22419 .77287 m .22175 .73564 L .19436 .73333 L p .707 .577 .707 r
F P
0 g
s
.22175 .73564 m .22419 .77287 L .2553 .77269 L p .707 .577 .707 r
F P
0 g
s
.32859 .62498 m .34083 .68041 L .35707 .67193 L p .707 .577 .707 r
F P
0 g
s
.35707 .67193 m .34484 .6165 L .32859 .62498 L p .707 .577 .707 r
F P
0 g
s
.31396 .72793 m .3164 .76516 L .34042 .75855 L p .707 .577 .707 r
F P
0 g
s
.34042 .75855 m .33799 .72132 L .31396 .72793 L p .707 .577 .707 r
F P
0 g
s
.69332 .81357 m .69051 .83157 L .67818 .82029 L p .707 .577 .707 r
F P
0 g
s
.67818 .82029 m .68099 .80229 L .69332 .81357 L p .707 .577 .707 r
F P
0 g
s
.1675 .65705 m .17973 .71248 L .20009 .71259 L p .707 .577 .707 r
F P
0 g
s
.39334 .8091 m .37028 .30531 L .35254 .29565 L p .707 .577 .707 r
F P
0 g
s
.37028 .30531 m .39334 .8091 L .42302 .81636 L p .707 .577 .707 r
F P
0 g
s
.19436 .73333 m .1968 .77056 L .22419 .77287 L p .707 .577 .707 r
F P
0 g
s
.68904 .72537 m .69148 .7626 L .67048 .75802 L p .707 .577 .707 r
F P
0 g
s
.67048 .75802 m .66805 .72079 L .68904 .72537 L p .707 .577 .707 r
F P
0 g
s
.24227 .81561 m .24508 .79762 L .21427 .79097 L p .707 .577 .707 r
F P
0 g
s
.24508 .79762 m .24227 .81561 L .27377 .81912 L p .707 .577 .707 r
F P
0 g
s
.27377 .81912 m .27658 .80112 L .24508 .79762 L p .707 .577 .707 r
F P
0 g
s
.66012 .63902 m .67235 .69444 L .64567 .69708 L p .707 .577 .707 r
F P
0 g
s
.1968 .77056 m .19436 .73333 L .17337 .72876 L p .707 .577 .707 r
F P
0 g
s
.27658 .80112 m .27377 .81912 L .3029 .81913 L p .707 .577 .707 r
F P
0 g
s
.3029 .81913 m .3057 .80114 L .27658 .80112 L p .707 .577 .707 r
F P
0 g
s
.21146 .80897 m .21427 .79097 L .18718 .78183 L p .707 .577 .707 r
F P
0 g
s
.21427 .79097 m .21146 .80897 L .24227 .81561 L p .707 .577 .707 r
F P
0 g
s
.17973 .71248 m .1675 .65705 L .15546 .6542 L p .707 .577 .707 r
F P
0 g
s
.18718 .78183 m .18437 .79983 L .21146 .80897 L p .707 .577 .707 r
F P
0 g
s
.17337 .72876 m .17581 .76599 L .1968 .77056 L p .707 .577 .707 r
F P
0 g
s
.33799 .72132 m .34042 .75855 L .35678 .75085 L p .707 .577 .707 r
F P
0 g
s
.35678 .75085 m .35434 .71362 L .33799 .72132 L p .707 .577 .707 r
F P
0 g
s
.62603 .28852 m .64909 .79231 L .6591 .78083 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .63604 .27703 L .62603 .28852 L p .707 .577 .707 r
F P
0 g
s
.34484 .6165 m .35707 .67193 L .36428 .66468 L p .707 .577 .707 r
F P
0 g
s
.36428 .66468 m .35205 .60925 L .34484 .6165 L p .707 .577 .707 r
F P
0 g
s
.3057 .80114 m .3029 .81913 L .32678 .81567 L p .707 .577 .707 r
F P
0 g
s
.32678 .81567 m .32959 .79767 L .3057 .80114 L p .707 .577 .707 r
F P
0 g
s
.15546 .6542 m .16769 .70962 L .17973 .71248 L p .707 .577 .707 r
F P
0 g
s
.18437 .79983 m .18718 .78183 L .16645 .7711 L p .707 .577 .707 r
F P
0 g
s
.68099 .80229 m .67818 .82029 L .65746 .80955 L p .707 .577 .707 r
F P
0 g
s
.65746 .80955 m .66027 .79156 L .68099 .80229 L p .707 .577 .707 r
F P
0 g
s
.16645 .7711 m .16364 .78909 L .18437 .79983 L p .707 .577 .707 r
F P
0 g
s
.17581 .76599 m .17337 .72876 L .16083 .72236 L p .707 .577 .707 r
F P
0 g
s
.3756 .79944 m .35254 .29565 L .34847 .28453 L p .707 .577 .707 r
F P
0 g
s
.35254 .29565 m .3756 .79944 L .39334 .8091 L p .707 .577 .707 r
F P
0 g
s
.16083 .72236 m .16326 .75959 L .17581 .76599 L p .707 .577 .707 r
F P
0 g
s
.32959 .79767 m .32678 .81567 L .34309 .80905 L p .707 .577 .707 r
F P
0 g
s
.34309 .80905 m .3459 .79106 L .32959 .79767 L p .707 .577 .707 r
F P
0 g
s
.16769 .70962 m .15546 .6542 L .15292 .64889 L p .707 .577 .707 r
F P
0 g
s
.35434 .71362 m .35678 .75085 L .36388 .74282 L p .707 .577 .707 r
F P
0 g
s
.36388 .74282 m .36144 .70559 L .35434 .71362 L p .707 .577 .707 r
F P
0 g
s
.16364 .78909 m .16645 .7711 L .15412 .75982 L p .707 .577 .707 r
F P
0 g
s
.35205 .60925 m .36428 .66468 L .36174 .65937 L p .707 .577 .707 r
F P
0 g
s
.36174 .65937 m .34951 .60394 L .35205 .60925 L p .707 .577 .707 r
F P
0 g
s
.15412 .75982 m .15131 .77781 L .16364 .78909 L p .707 .577 .707 r
F P
0 g
s
.15292 .64889 m .16515 .70431 L .16769 .70962 L p .707 .577 .707 r
F P
0 g
s
.16326 .75959 m .16083 .72236 L .15796 .71478 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .65503 .76971 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64422 .45583 m .6591 .78083 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .63604 .27703 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.65503 .76971 m .64504 .55148 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64504 .55148 m .63197 .26592 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .65503 .76971 L .64867 .76625 L p .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64386 .73941 L .64456 .73978 L p .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .63651 .68782 L .64418 .73731 L .707 .577 .707 r
F
.63651 .68782 m .63197 .26592 L .64867 .76625 L F
.61423 .25626 m .63197 .26592 L p .63698 .73215 L F P
0 g
s
.64386 .73941 m .64287 .73637 L .63597 .73142 L .707 .577 .707 r
F
.61423 .25626 m .63597 .73142 L p .6076 .75279 L F P
0 g
s
.62778 .75772 m .6076 .75279 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63201 .72857 m .63579 .73203 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63579 .73203 m .64386 .73941 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .63728 .76005 L .62778 .75772 L p .707 .577 .707 r
F P
0 g
s
.63728 .76005 m .63597 .73142 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .61423 .25626 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63433 .71013 m .63152 .72813 L .63201 .72857 L p .707 .577 .707 r
F P
0 g
s
.64287 .73637 m .63433 .71013 L .63201 .72857 L .707 .577 .707 r
F
.64666 .72142 m .63433 .71013 L p .64287 .73637 L F P
0 g
s
.64386 .73941 m .64418 .73731 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64666 .72142 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64867 .76625 m .63728 .76005 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .64418 .73731 L .64867 .76625 L .707 .577 .707 r
F
.64666 .72142 m .64418 .73731 L p .66458 .75015 L F P
0 g
s
.64456 .73978 m .66458 .75015 L p .64418 .73731 L .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .65994 .65848 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.63567 .6002 m .64585 .64633 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.64585 .64633 m .64791 .65563 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64771 .60305 L .64548 .60252 L p .707 .577 .707 r
F P
0 g
s
.64548 .60252 m .63567 .6002 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64548 .60252 L .64566 .62419 L .707 .577 .707 r
F
.63604 .27703 m .64422 .45583 L p .64459 .4989 L F P
0 g
s
.15796 .71478 m .1604 .75201 L .16326 .75959 L p .707 .577 .707 r
F P
0 g
s
.3459 .79106 m .34309 .80905 L .35023 .79993 L p .707 .577 .707 r
F P
0 g
s
.35023 .79993 m .35304 .78194 L .3459 .79106 L p .707 .577 .707 r
F P
0 g
s
.15131 .77781 m .15412 .75982 L .15139 .74909 L p .707 .577 .707 r
F P
0 g
s
.36144 .70559 m .36388 .74282 L .36101 .73524 L p .707 .577 .707 r
F P
0 g
s
.36101 .73524 m .35857 .69801 L .36144 .70559 L p .707 .577 .707 r
F P
0 g
s
.16515 .70431 m .15292 .64889 L .16012 .64164 L p .707 .577 .707 r
F P
0 g
s
.15139 .74909 m .14858 .76709 L .15131 .77781 L p .707 .577 .707 r
F P
0 g
s
.34951 .60394 m .36174 .65937 L .3497 .65652 L p .707 .577 .707 r
F P
0 g
s
.3497 .65652 m .33747 .60109 L .34951 .60394 L p .707 .577 .707 r
F P
0 g
s
.34847 .28453 m .37153 .78833 L .3756 .79944 L p .707 .577 .707 r
F P
0 g
s
.37153 .78833 m .34847 .28453 L .35848 .27305 L p .707 .577 .707 r
F P
0 g
s
.16012 .64164 m .17236 .69706 L .16515 .70431 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1604 .75201 m .15796 .71478 L .16506 .70674 L p .707 .577 .707 r
F P
0 g
s
.35304 .78194 m .35023 .79993 L .3475 .78921 L p .707 .577 .707 r
F P
0 g
s
.3475 .78921 m .35031 .77122 L .35304 .78194 L p .707 .577 .707 r
F P
0 g
s
.16506 .70674 m .16749 .74397 L .1604 .75201 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14858 .76709 m .15139 .74909 L .15853 .73998 L p .707 .577 .707 r
F P
0 g
s
.17236 .69706 m .16012 .64164 L .17637 .63315 L p .707 .577 .707 r
F P
0 g
s
.35857 .69801 m .36101 .73524 L .34847 .72884 L p .707 .577 .707 r
F P
0 g
s
.34847 .72884 m .34603 .69161 L .35857 .69801 L p .707 .577 .707 r
F P
0 g
s
.15853 .73998 m .15572 .75797 L .14858 .76709 L p .707 .577 .707 r
F P
0 g
s
.33747 .60109 m .3497 .65652 L .32935 .6564 L p .707 .577 .707 r
F P
0 g
s
.32935 .6564 m .31711 .60098 L .33747 .60109 L p .707 .577 .707 r
F P
0 g
s
.17637 .63315 m .1886 .68858 L .17236 .69706 L p .707 .577 .707 r
F P
0 g
s
.16749 .74397 m .16506 .70674 L .18141 .69905 L p .707 .577 .707 r
F P
0 g
s
.38154 .77684 m .35848 .27305 L .38158 .26232 L p .707 .577 .707 r
F P
0 g
s
.35848 .27305 m .38154 .77684 L .37153 .78833 L p .707 .577 .707 r
F P
0 g
s
.35031 .77122 m .3475 .78921 L .33517 .77793 L p .707 .577 .707 r
F P
0 g
s
.33517 .77793 m .33798 .75993 L .35031 .77122 L p .707 .577 .707 r
F P
0 g
s
.18141 .69905 m .18385 .73628 L .16749 .74397 L p .707 .577 .707 r
F P
0 g
s
.1886 .68858 m .17637 .63315 L .20007 .62427 L p .707 .577 .707 r
F P
0 g
s
.15572 .75797 m .15853 .73998 L .17484 .73336 L p .707 .577 .707 r
F P
0 g
s
.34603 .69161 m .34847 .72884 L .32747 .72427 L p .707 .577 .707 r
F P
0 g
s
.32747 .72427 m .32504 .68704 L .34603 .69161 L p .707 .577 .707 r
F P
0 g
s
.31711 .60098 m .32935 .6564 L .30266 .65904 L p .707 .577 .707 r
F P
0 g
s
.30266 .65904 m .29043 .60361 L .31711 .60098 L p .707 .577 .707 r
F P
0 g
s
.17484 .73336 m .17203 .75136 L .15572 .75797 L p .707 .577 .707 r
F P
0 g
s
.20007 .62427 m .2123 .6797 L .1886 .68858 L p .707 .577 .707 r
F P
0 g
s
.6076 .75279 m .58454 .249 L .61423 .25626 L p .707 .577 .707 r
F P
0 g
s
.18385 .73628 m .18141 .69905 L .20543 .69244 L p .707 .577 .707 r
F P
0 g
s
.2123 .6797 m .20007 .62427 L .22889 .61586 L p .707 .577 .707 r
F P
0 g
s
.29043 .60361 m .30266 .65904 L .27226 .66417 L p .707 .577 .707 r
F P
0 g
s
.27226 .66417 m .26003 .60874 L .29043 .60361 L p .707 .577 .707 r
F P
0 g
s
.33798 .75993 m .33517 .77793 L .31445 .76719 L p .707 .577 .707 r
F P
0 g
s
.31445 .76719 m .31726 .7492 L .33798 .75993 L p .707 .577 .707 r
F P
0 g
s
.20543 .69244 m .20787 .72967 L .18385 .73628 L p .707 .577 .707 r
F P
0 g
s
.32504 .68704 m .32747 .72427 L .30008 .72196 L p .707 .577 .707 r
F P
0 g
s
.30008 .72196 m .29765 .68473 L .32504 .68704 L p .707 .577 .707 r
F P
0 g
s
.17203 .75136 m .17484 .73336 L .19873 .72989 L p .707 .577 .707 r
F P
0 g
s
.22889 .61586 m .24113 .67129 L .2123 .6797 L p .707 .577 .707 r
F P
0 g
s
.24113 .67129 m .22889 .61586 L .26003 .60874 L p .707 .577 .707 r
F P
0 g
s
.73738 .65082 m .72515 .5954 L .69475 .60053 L p .707 .577 .707 r
F P
0 g
s
.72515 .5954 m .73738 .65082 L .76852 .6437 L p .707 .577 .707 r
F P
0 g
s
.76852 .6437 m .75628 .58828 L .72515 .5954 L p .707 .577 .707 r
F P
0 g
s
.26003 .60874 m .27226 .66417 L .24113 .67129 L p .707 .577 .707 r
F P
0 g
s
.75628 .58828 m .76852 .6437 L .79734 .63529 L p .707 .577 .707 r
F P
0 g
s
.79734 .63529 m .78511 .57987 L .75628 .58828 L p .707 .577 .707 r
F P
0 g
s
.38158 .26232 m .40464 .76612 L .38154 .77684 L p .707 .577 .707 r
F P
0 g
s
.40464 .76612 m .38158 .26232 L .41552 .2534 L p .707 .577 .707 r
F P
0 g
s
.19873 .72989 m .19592 .74789 L .17203 .75136 L p .707 .577 .707 r
F P
0 g
s
.20787 .72967 m .20543 .69244 L .23477 .68757 L p .707 .577 .707 r
F P
0 g
s
.70698 .65595 m .69475 .60053 L .66806 .60316 L p .707 .577 .707 r
F P
0 g
s
.69475 .60053 m .70698 .65595 L .73738 .65082 L p .707 .577 .707 r
F P
0 g
s
.29765 .68473 m .30008 .72196 L .26898 .72214 L p .707 .577 .707 r
F P
0 g
s
.26898 .72214 m .26654 .68491 L .29765 .68473 L p .707 .577 .707 r
F P
0 g
s
.78511 .57987 m .79734 .63529 L .82104 .62641 L p .707 .577 .707 r
F P
0 g
s
.82104 .62641 m .80881 .57099 L .78511 .57987 L p .707 .577 .707 r
F P
0 g
s
.23477 .68757 m .23721 .7248 L .20787 .72967 L p .707 .577 .707 r
F P
0 g
s
.31726 .7492 m .31445 .76719 L .28735 .75806 L p .707 .577 .707 r
F P
0 g
s
.28735 .75806 m .29016 .74006 L .31726 .7492 L p .707 .577 .707 r
F P
0 g
s
.23721 .7248 m .23477 .68757 L .26654 .68491 L p .707 .577 .707 r
F P
0 g
s
.58454 .249 m .6076 .75279 L .56888 .74864 L p .707 .577 .707 r
F P
0 g
s
.56888 .74864 m .54583 .24485 L .58454 .249 L p .707 .577 .707 r
F P
0 g
s
.19592 .74789 m .19873 .72989 L .22785 .72991 L p .707 .577 .707 r
F P
0 g
s
.66806 .60316 m .6803 .65859 L .70698 .65595 L p .707 .577 .707 r
F P
0 g
s
.73551 .7144 m .73307 .67717 L .70197 .67736 L p .707 .577 .707 r
F P
0 g
s
.73307 .67717 m .73551 .7144 L .76728 .71175 L p .707 .577 .707 r
F P
0 g
s
.76728 .71175 m .76484 .67452 L .73307 .67717 L p .707 .577 .707 r
F P
0 g
s
.26654 .68491 m .26898 .72214 L .23721 .7248 L p .707 .577 .707 r
F P
0 g
s
.76484 .67452 m .76728 .71175 L .79662 .70688 L p .707 .577 .707 r
F P
0 g
s
.79662 .70688 m .79418 .66965 L .76484 .67452 L p .707 .577 .707 r
F P
0 g
s
.22785 .72991 m .22504 .74791 L .19592 .74789 L p .707 .577 .707 r
F P
0 g
s
.6803 .65859 m .66806 .60316 L .64771 .60305 L p .707 .577 .707 r
F P
0 g
s
.7044 .71459 m .70197 .67736 L .67458 .67505 L p .707 .577 .707 r
F P
0 g
s
.70197 .67736 m .7044 .71459 L .73551 .7144 L p .707 .577 .707 r
F P
0 g
s
.43857 .7572 m .41552 .2534 L .45696 .24716 L p .707 .577 .707 r
F P
0 g
s
.41552 .2534 m .43857 .7572 L .40464 .76612 L p .707 .577 .707 r
F P
0 g
s
.29016 .74006 m .28735 .75806 L .25655 .75141 L p .707 .577 .707 r
F P
0 g
s
.25655 .75141 m .25936 .73341 L .29016 .74006 L p .707 .577 .707 r
F P
0 g
s
.80881 .57099 m .82104 .62641 L .83729 .61793 L p .707 .577 .707 r
F P
0 g
s
.83729 .61793 m .82505 .5625 L .80881 .57099 L p .707 .577 .707 r
F P
0 g
s
.22504 .74791 m .22785 .72991 L .25936 .73341 L p .707 .577 .707 r
F P
0 g
s
.79418 .66965 m .79662 .70688 L .82064 .70027 L p .707 .577 .707 r
F P
0 g
s
.82064 .70027 m .8182 .66304 L .79418 .66965 L p .707 .577 .707 r
F P
0 g
s
.25936 .73341 m .25655 .75141 L .22504 .74791 L p .707 .577 .707 r
F P
0 g
s
.67458 .67505 m .67702 .71228 L .7044 .71459 L p .707 .577 .707 r
F P
0 g
s
.64771 .60305 m .65994 .65848 L .6803 .65859 L p .707 .577 .707 r
F P
0 g
s
.54583 .24485 m .56888 .74864 L .52492 .74801 L p .707 .577 .707 r
F P
0 g
s
.52492 .74801 m .50187 .24422 L .54583 .24485 L p .707 .577 .707 r
F P
0 g
s
.72248 .76593 m .72529 .74794 L .69448 .74129 L p .707 .577 .707 r
F P
0 g
s
.72529 .74794 m .72248 .76593 L .75399 .76943 L p .707 .577 .707 r
F P
0 g
s
.75399 .76943 m .7568 .75144 L .72529 .74794 L p .707 .577 .707 r
F P
0 g
s
.67702 .71228 m .67458 .67505 L .65358 .67047 L p .707 .577 .707 r
F P
0 g
s
.7568 .75144 m .75399 .76943 L .78311 .76945 L p .707 .577 .707 r
F P
0 g
s
.78311 .76945 m .78592 .75146 L .7568 .75144 L p .707 .577 .707 r
F P
0 g
s
.48002 .75096 m .45696 .24716 L .50187 .24422 L p .707 .577 .707 r
F P
0 g
s
.45696 .24716 m .48002 .75096 L .43857 .7572 L p .707 .577 .707 r
F P
0 g
s
.69167 .75928 m .69448 .74129 L .66739 .73215 L p .707 .577 .707 r
F P
0 g
s
.69448 .74129 m .69167 .75928 L .72248 .76593 L p .707 .577 .707 r
F P
0 g
s
.50187 .24422 m .52492 .74801 L .48002 .75096 L p .707 .577 .707 r
F P
0 g
s
.65358 .67047 m .65602 .7077 L .67702 .71228 L p .707 .577 .707 r
F P
0 g
s
.8182 .66304 m .82064 .70027 L .837 .69257 L p .707 .577 .707 r
F P
0 g
s
.837 .69257 m .83456 .65534 L .8182 .66304 L p .707 .577 .707 r
F P
0 g
s
.66739 .73215 m .66458 .75015 L .69167 .75928 L p .707 .577 .707 r
F P
0 g
s
.82505 .5625 m .83729 .61793 L .84449 .61068 L p .707 .577 .707 r
F P
0 g
s
.84449 .61068 m .83226 .55525 L .82505 .5625 L p .707 .577 .707 r
F P
0 g
s
.78592 .75146 m .78311 .76945 L .80699 .76598 L p .707 .577 .707 r
F P
0 g
s
.80699 .76598 m .8098 .74799 L .78592 .75146 L p .707 .577 .707 r
F P
0 g
s
.66458 .75015 m .66739 .73215 L .64666 .72142 L p .707 .577 .707 r
F P
0 g
s
.65602 .7077 m .65358 .67047 L .64104 .66408 L p .707 .577 .707 r
F P
0 g
s
.64104 .66408 m .64348 .70131 L .65602 .7077 L p .707 .577 .707 r
F P
0 g
s
.83456 .65534 m .837 .69257 L .84409 .68454 L p .707 .577 .707 r
F P
0 g
s
.84409 .68454 m .84165 .64731 L .83456 .65534 L p .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .63567 .6002 L .63313 .59489 L p .707 .577 .707 r
F P
0 g
s
.8098 .74799 m .80699 .76598 L .82331 .75937 L p .707 .577 .707 r
F P
0 g
s
.82331 .75937 m .82612 .74137 L .8098 .74799 L p .707 .577 .707 r
F P
0 g
s
.83226 .55525 m .84449 .61068 L .84195 .60537 L p .707 .577 .707 r
F P
0 g
s
.84195 .60537 m .82972 .54994 L .83226 .55525 L p .707 .577 .707 r
F P
0 g
s
.63313 .59489 m .64536 .65031 L .64791 .65563 L p .707 .577 .707 r
F P
0 g
s
.64348 .70131 m .64104 .66408 L .63817 .6565 L p .707 .577 .707 r
F P
0 g
s
.63817 .6565 m .64061 .69373 L .64348 .70131 L p .707 .577 .707 r
F P
0 g
s
.82612 .74137 m .82331 .75937 L .83045 .75025 L p .707 .577 .707 r
F P
0 g
s
.83045 .75025 m .83326 .73226 L .82612 .74137 L p .707 .577 .707 r
F P
0 g
s
.84165 .64731 m .84409 .68454 L .84123 .67695 L p .707 .577 .707 r
F P
0 g
s
.84123 .67695 m .83879 .63972 L .84165 .64731 L p .707 .577 .707 r
F P
0 g
s
.63152 .72813 m .63433 .71013 L .6316 .69941 L p .707 .577 .707 r
F P
0 g
s
.64536 .65031 m .63313 .59489 L .64034 .58764 L p .707 .577 .707 r
F P
0 g
s
.6316 .69941 m .6288 .71741 L .63152 .72813 L p .707 .577 .707 r
F P
0 g
s
.82972 .54994 m .84195 .60537 L .82992 .60252 L p .707 .577 .707 r
F P
0 g
s
.82992 .60252 m .81768 .54709 L .82972 .54994 L p .707 .577 .707 r
F P
0 g
s
.64034 .58764 m .65257 .64306 L .64536 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64061 .69373 m .63817 .6565 L .64527 .64846 L p .707 .577 .707 r
F P
0 g
s
.39437 .61278 m .38214 .55736 L .35174 .56249 L p .707 .577 .707 r
F P
0 g
s
.38214 .55736 m .39437 .61278 L .42551 .60566 L p .707 .577 .707 r
F P
0 g
s
.42551 .60566 m .41327 .55024 L .38214 .55736 L p .707 .577 .707 r
F P
0 g
s
.41327 .55024 m .42551 .60566 L .45433 .59725 L p .707 .577 .707 r
F P
0 g
s
.45433 .59725 m .4421 .54183 L .41327 .55024 L p .707 .577 .707 r
F P
0 g
s
.64527 .64846 m .64771 .68569 L .64061 .69373 L p .707 .577 .707 r
F P
0 g
s
.83326 .73226 m .83045 .75025 L .82772 .73953 L p .707 .577 .707 r
F P
0 g
s
.82772 .73953 m .83053 .72153 L .83326 .73226 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36397 .61791 m .35174 .56249 L .32505 .56512 L p .707 .577 .707 r
F P
0 g
s
.35174 .56249 m .36397 .61791 L .39437 .61278 L p .707 .577 .707 r
F P
0 g
s
.83879 .63972 m .84123 .67695 L .82868 .67056 L p .707 .577 .707 r
F P
0 g
s
.82868 .67056 m .82624 .63333 L .83879 .63972 L p .707 .577 .707 r
F P
0 g
s
.6288 .71741 m .6316 .69941 L .63875 .69029 L p .707 .577 .707 r
F P
0 g
s
.65257 .64306 m .64034 .58764 L .65658 .57916 L p .707 .577 .707 r
F P
0 g
s
.4421 .54183 m .45433 .59725 L .47803 .58837 L p .707 .577 .707 r
F P
0 g
s
.47803 .58837 m .4658 .53295 L .4421 .54183 L p .707 .577 .707 r
F P
0 g
s
.63875 .69029 m .63594 .70829 L .6288 .71741 L p .707 .577 .707 r
F P
0 g
s
.81768 .54709 m .82992 .60252 L .80956 .60241 L p .707 .577 .707 r
F P
0 g
s
.80956 .60241 m .79732 .54698 L .81768 .54709 L p .707 .577 .707 r
F P
0 g
s
.32505 .56512 m .33729 .62055 L .36397 .61791 L p .707 .577 .707 r
F P
0 g
s
.65658 .57916 m .66882 .63458 L .65257 .64306 L p .707 .577 .707 r
F P
0 g
s
.3925 .68065 m .39006 .64342 L .35896 .6436 L p .707 .577 .707 r
F P
0 g
s
.39006 .64342 m .3925 .68065 L .42427 .67799 L p .707 .577 .707 r
F P
0 g
s
.42427 .67799 m .42183 .64076 L .39006 .64342 L p .707 .577 .707 r
F P
0 g
s
.42183 .64076 m .42427 .67799 L .45361 .67312 L p .707 .577 .707 r
F P
0 g
s
.45361 .67312 m .45117 .63589 L .42183 .64076 L p .707 .577 .707 r
F P
0 g
s
.64771 .68569 m .64527 .64846 L .66163 .64077 L p .707 .577 .707 r
F P
0 g
s
.33729 .62055 m .32505 .56512 L .3047 .56501 L p .707 .577 .707 r
F P
0 g
s
.36139 .68083 m .35896 .6436 L .33157 .64129 L p .707 .577 .707 r
F P
0 g
s
.35896 .6436 m .36139 .68083 L .3925 .68065 L p .707 .577 .707 r
F P
0 g
s
.4658 .53295 m .47803 .58837 L .49428 .57989 L p .707 .577 .707 r
F P
0 g
s
.49428 .57989 m .48204 .52446 L .4658 .53295 L p .707 .577 .707 r
F P
0 g
s
.66163 .64077 m .66406 .678 L .64771 .68569 L p .707 .577 .707 r
F P
0 g
s
.45117 .63589 m .45361 .67312 L .47763 .66651 L p .707 .577 .707 r
F P
0 g
s
.47763 .66651 m .47519 .62928 L .45117 .63589 L p .707 .577 .707 r
F P
0 g
s
.83053 .72153 m .82772 .73953 L .81539 .72825 L p .707 .577 .707 r
F P
0 g
s
.81539 .72825 m .8182 .71025 L .83053 .72153 L p .707 .577 .707 r
F P
0 g
s
.66882 .63458 m .65658 .57916 L .68028 .57028 L p .707 .577 .707 r
F P
0 g
s
.3047 .56501 m .31693 .62044 L .33729 .62055 L p .707 .577 .707 r
F P
0 g
s
.33157 .64129 m .33401 .67852 L .36139 .68083 L p .707 .577 .707 r
F P
0 g
s
.82624 .63333 m .82868 .67056 L .80769 .66599 L p .707 .577 .707 r
F P
0 g
s
.80769 .66599 m .80525 .62876 L .82624 .63333 L p .707 .577 .707 r
F P
0 g
s
.63594 .70829 m .63875 .69029 L .65506 .68368 L p .707 .577 .707 r
F P
0 g
s
.37947 .72357 m .38228 .70558 L .35147 .69893 L p .707 .577 .707 r
F P
0 g
s
.38228 .70558 m .37947 .72357 L .41098 .72708 L p .707 .577 .707 r
F P
0 g
s
.41098 .72708 m .41379 .70908 L .38228 .70558 L p .707 .577 .707 r
F P
0 g
s
.79732 .54698 m .80956 .60241 L .78288 .60504 L p .707 .577 .707 r
F P
0 g
s
.78288 .60504 m .77064 .54962 L .79732 .54698 L p .707 .577 .707 r
F P
0 g
s
.33401 .67852 m .33157 .64129 L .31057 .63672 L p .707 .577 .707 r
F P
0 g
s
.65506 .68368 m .65225 .70167 L .63594 .70829 L p .707 .577 .707 r
F P
0 g
s
.41379 .70908 m .41098 .72708 L .4401 .7271 L p .707 .577 .707 r
F P
0 g
s
.4401 .7271 m .44291 .7091 L .41379 .70908 L p .707 .577 .707 r
F P
0 g
s
.68028 .57028 m .69251 .6257 L .66882 .63458 L p .707 .577 .707 r
F P
0 g
s
.34866 .71693 m .35147 .69893 L .32438 .68979 L p .707 .577 .707 r
F P
0 g
s
.35147 .69893 m .34866 .71693 L .37947 .72357 L p .707 .577 .707 r
F P
0 g
s
.31693 .62044 m .3047 .56501 L .29266 .56216 L p .707 .577 .707 r
F P
0 g
s
.66406 .678 m .66163 .64077 L .68565 .63416 L p .707 .577 .707 r
F P
0 g
s
.32438 .68979 m .32157 .70779 L .34866 .71693 L p .707 .577 .707 r
F P
0 g
s
.31057 .63672 m .31301 .67395 L .33401 .67852 L p .707 .577 .707 r
F P
0 g
s
.47519 .62928 m .47763 .66651 L .49399 .65882 L p .707 .577 .707 r
F P
0 g
s
.49399 .65882 m .49155 .62159 L .47519 .62928 L p .707 .577 .707 r
F P
0 g
s
.69251 .6257 m .68028 .57028 L .70911 .56186 L p .707 .577 .707 r
F P
0 g
s
.48204 .52446 m .49428 .57989 L .50148 .57264 L p .707 .577 .707 r
F P
0 g
s
.50148 .57264 m .48925 .51721 L .48204 .52446 L p .707 .577 .707 r
F P
0 g
s
.44291 .7091 m .4401 .7271 L .46398 .72363 L p .707 .577 .707 r
F P
0 g
s
.46398 .72363 m .46679 .70563 L .44291 .7091 L p .707 .577 .707 r
F P
0 g
s
.77064 .54962 m .78288 .60504 L .75248 .61017 L p .707 .577 .707 r
F P
0 g
s
.75248 .61017 m .74024 .55474 L .77064 .54962 L p .707 .577 .707 r
F P
0 g
s
.68565 .63416 m .68809 .67139 L .66406 .678 L p .707 .577 .707 r
F P
0 g
s
.29266 .56216 m .30489 .61759 L .31693 .62044 L p .707 .577 .707 r
F P
0 g
s
.32157 .70779 m .32438 .68979 L .30365 .67906 L p .707 .577 .707 r
F P
0 g
s
.80525 .62876 m .80769 .66599 L .7803 .66368 L p .707 .577 .707 r
F P
0 g
s
.7803 .66368 m .77786 .62645 L .80525 .62876 L p .707 .577 .707 r
F P
0 g
s
.8182 .71025 m .81539 .72825 L .79466 .71751 L p .707 .577 .707 r
F P
0 g
s
.79466 .71751 m .79747 .69952 L .8182 .71025 L p .707 .577 .707 r
F P
0 g
s
.65225 .70167 m .65506 .68368 L .67894 .68021 L p .707 .577 .707 r
F P
0 g
s
.70911 .56186 m .72134 .61729 L .69251 .6257 L p .707 .577 .707 r
F P
0 g
s
.72134 .61729 m .70911 .56186 L .74024 .55474 L p .707 .577 .707 r
F P
0 g
s
.30365 .67906 m .30084 .69705 L .32157 .70779 L p .707 .577 .707 r
F P
0 g
s
.74024 .55474 m .75248 .61017 L .72134 .61729 L p .707 .577 .707 r
F P
0 g
s
.31301 .67395 m .31057 .63672 L .29803 .63032 L p .707 .577 .707 r
F P
0 g
s
.68809 .67139 m .68565 .63416 L .71498 .62929 L p .707 .577 .707 r
F P
0 g
s
.67894 .68021 m .67613 .69821 L .65225 .70167 L p .707 .577 .707 r
F P
0 g
s
.29803 .63032 m .30047 .66756 L .31301 .67395 L p .707 .577 .707 r
F P
0 g
s
.77786 .62645 m .7803 .66368 L .74919 .66386 L p .707 .577 .707 r
F P
0 g
s
.74919 .66386 m .74676 .62663 L .77786 .62645 L p .707 .577 .707 r
F P
0 g
s
.46679 .70563 m .46398 .72363 L .4803 .71701 L p .707 .577 .707 r
F P
0 g
s
.4803 .71701 m .4831 .69902 L .46679 .70563 L p .707 .577 .707 r
F P
0 g
s
.30489 .61759 m .29266 .56216 L .29012 .55685 L p .707 .577 .707 r
F P
0 g
s
.71498 .62929 m .71742 .66652 L .68809 .67139 L p .707 .577 .707 r
F P
0 g
s
.49155 .62159 m .49399 .65882 L .50108 .65078 L p .707 .577 .707 r
F P
0 g
s
.50108 .65078 m .49864 .61355 L .49155 .62159 L p .707 .577 .707 r
F P
0 g
s
.30084 .69705 m .30365 .67906 L .29132 .66778 L p .707 .577 .707 r
F P
0 g
s
.71742 .66652 m .71498 .62929 L .74676 .62663 L p .707 .577 .707 r
F P
0 g
s
.79747 .69952 m .79466 .71751 L .76757 .70837 L p .707 .577 .707 r
F P
0 g
s
.76757 .70837 m .77038 .69038 L .79747 .69952 L p .707 .577 .707 r
F P
0 g
s
.74676 .62663 m .74919 .66386 L .71742 .66652 L p .707 .577 .707 r
F P
0 g
s
.67613 .69821 m .67894 .68021 L .70806 .68023 L p .707 .577 .707 r
F P
0 g
s
.48925 .51721 m .50148 .57264 L .49894 .56733 L p .707 .577 .707 r
F P
0 g
s
.49894 .56733 m .48671 .5119 L .48925 .51721 L p .707 .577 .707 r
F P
0 g
s
.29132 .66778 m .28851 .68577 L .30084 .69705 L p .707 .577 .707 r
F P
0 g
s
.29012 .55685 m .30235 .61227 L .30489 .61759 L p .707 .577 .707 r
F P
0 g
s
.70806 .68023 m .70525 .69822 L .67613 .69821 L p .707 .577 .707 r
F P
0 g
s
.30047 .66756 m .29803 .63032 L .29516 .62274 L p .707 .577 .707 r
F P
0 g
s
.77038 .69038 m .76757 .70837 L .73676 .70173 L p .707 .577 .707 r
F P
0 g
s
.73676 .70173 m .73957 .68373 L .77038 .69038 L p .707 .577 .707 r
F P
0 g
s
.70525 .69822 m .70806 .68023 L .73957 .68373 L p .707 .577 .707 r
F P
0 g
s
.73957 .68373 m .73676 .70173 L .70525 .69822 L p .707 .577 .707 r
F P
0 g
s
.29516 .62274 m .2976 .65997 L .30047 .66756 L p .707 .577 .707 r
F P
0 g
s
.4831 .69902 m .4803 .71701 L .48744 .7079 L p .707 .577 .707 r
F P
0 g
s
.48744 .7079 m .49025 .6899 L .4831 .69902 L p .707 .577 .707 r
F P
0 g
s
.28851 .68577 m .29132 .66778 L .28859 .65705 L p .707 .577 .707 r
F P
0 g
s
.49864 .61355 m .50108 .65078 L .49821 .6432 L p .707 .577 .707 r
F P
0 g
s
.49821 .6432 m .49578 .60597 L .49864 .61355 L p .707 .577 .707 r
F P
0 g
s
.30235 .61227 m .29012 .55685 L .29733 .5496 L p .707 .577 .707 r
F P
0 g
s
.28859 .65705 m .28578 .67505 L .28851 .68577 L p .707 .577 .707 r
F P
0 g
s
.48671 .5119 m .49894 .56733 L .48691 .56448 L p .707 .577 .707 r
F P
0 g
s
.48691 .56448 m .47467 .50905 L .48671 .5119 L p .707 .577 .707 r
F P
0 g
s
.29733 .5496 m .30956 .60502 L .30235 .61227 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2976 .65997 m .29516 .62274 L .30226 .61471 L p .707 .577 .707 r
F P
0 g
s
.49025 .6899 m .48744 .7079 L .48471 .69717 L p .707 .577 .707 r
F P
0 g
s
.48471 .69717 m .48752 .67918 L .49025 .6899 L p .707 .577 .707 r
F P
0 g
s
.30226 .61471 m .3047 .65194 L .2976 .65997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28578 .67505 m .28859 .65705 L .29573 .64794 L p .707 .577 .707 r
F P
0 g
s
.30956 .60502 m .29733 .5496 L .31357 .54112 L p .707 .577 .707 r
F P
0 g
s
.49578 .60597 m .49821 .6432 L .48567 .6368 L p .707 .577 .707 r
F P
0 g
s
.48567 .6368 m .48323 .59957 L .49578 .60597 L p .707 .577 .707 r
F P
0 g
s
.29573 .64794 m .29293 .66593 L .28578 .67505 L p .707 .577 .707 r
F P
0 g
s
.47467 .50905 m .48691 .56448 L .46655 .56436 L p .707 .577 .707 r
F P
0 g
s
.46655 .56436 m .45431 .50894 L .47467 .50905 L p .707 .577 .707 r
F P
0 g
s
.31357 .54112 m .32581 .59654 L .30956 .60502 L p .707 .577 .707 r
F P
0 g
s
.3047 .65194 m .30226 .61471 L .31862 .60701 L p .707 .577 .707 r
F P
0 g
s
.48752 .67918 m .48471 .69717 L .47238 .68589 L p .707 .577 .707 r
F P
0 g
s
.47238 .68589 m .47519 .6679 L .48752 .67918 L p .707 .577 .707 r
F P
0 g
s
.31862 .60701 m .32105 .64424 L .3047 .65194 L p .707 .577 .707 r
F P
0 g
s
.32581 .59654 m .31357 .54112 L .33727 .53223 L p .707 .577 .707 r
F P
0 g
s
.29293 .66593 m .29573 .64794 L .31205 .64132 L p .707 .577 .707 r
F P
0 g
s
.48323 .59957 m .48567 .6368 L .46468 .63223 L p .707 .577 .707 r
F P
0 g
s
.46468 .63223 m .46224 .595 L .48323 .59957 L p .707 .577 .707 r
F P
0 g
s
.45431 .50894 m .46655 .56436 L .43987 .567 L p .707 .577 .707 r
F P
0 g
s
.43987 .567 m .42763 .51158 L .45431 .50894 L p .707 .577 .707 r
F P
0 g
s
.31205 .64132 m .30924 .65932 L .29293 .66593 L p .707 .577 .707 r
F P
0 g
s
.33727 .53223 m .3495 .58766 L .32581 .59654 L p .707 .577 .707 r
F P
0 g
s
.32105 .64424 m .31862 .60701 L .34264 .6004 L p .707 .577 .707 r
F P
0 g
s
.3495 .58766 m .33727 .53223 L .3661 .52382 L p .707 .577 .707 r
F P
0 g
s
.42763 .51158 m .43987 .567 L .40947 .57213 L p .707 .577 .707 r
F P
0 g
s
.40947 .57213 m .39723 .5167 L .42763 .51158 L p .707 .577 .707 r
F P
0 g
s
.47519 .6679 m .47238 .68589 L .45165 .67516 L p .707 .577 .707 r
F P
0 g
s
.45165 .67516 m .45446 .65716 L .47519 .6679 L p .707 .577 .707 r
F P
0 g
s
.34264 .6004 m .34508 .63763 L .32105 .64424 L p .707 .577 .707 r
F P
0 g
s
.46224 .595 m .46468 .63223 L .43729 .62992 L p .707 .577 .707 r
F P
0 g
s
.43729 .62992 m .43485 .59269 L .46224 .595 L p .707 .577 .707 r
F P
0 g
s
.30924 .65932 m .31205 .64132 L .33593 .63785 L p .707 .577 .707 r
F P
0 g
s
.3661 .52382 m .37833 .57925 L .3495 .58766 L p .707 .577 .707 r
F P
0 g
s
.37833 .57925 m .3661 .52382 L .39723 .5167 L p .707 .577 .707 r
F P
0 g
s
.39723 .5167 m .40947 .57213 L .37833 .57925 L p .707 .577 .707 r
F P
0 g
s
.33593 .63785 m .33312 .65585 L .30924 .65932 L p .707 .577 .707 r
F P
0 g
s
.34508 .63763 m .34264 .6004 L .37197 .59553 L p .707 .577 .707 r
F P
0 g
s
.43485 .59269 m .43729 .62992 L .40618 .6301 L p .707 .577 .707 r
F P
0 g
s
.40618 .6301 m .40375 .59287 L .43485 .59269 L p .707 .577 .707 r
F P
0 g
s
.37197 .59553 m .37441 .63276 L .34508 .63763 L p .707 .577 .707 r
F P
0 g
s
.45446 .65716 m .45165 .67516 L .42456 .66602 L p .707 .577 .707 r
F P
0 g
s
.42456 .66602 m .42737 .64802 L .45446 .65716 L p .707 .577 .707 r
F P
0 g
s
.37441 .63276 m .37197 .59553 L .40375 .59287 L p .707 .577 .707 r
F P
0 g
s
.33312 .65585 m .33593 .63785 L .36505 .63787 L p .707 .577 .707 r
F P
0 g
s
.40375 .59287 m .40618 .6301 L .37441 .63276 L p .707 .577 .707 r
F P
0 g
s
.36505 .63787 m .36224 .65587 L .33312 .65585 L p .707 .577 .707 r
F P
0 g
s
.42737 .64802 m .42456 .66602 L .39375 .65937 L p .707 .577 .707 r
F P
0 g
s
.39375 .65937 m .39656 .64138 L .42737 .64802 L p .707 .577 .707 r
F P
0 g
s
.36224 .65587 m .36505 .63787 L .39656 .64138 L p .707 .577 .707 r
F P
0 g
s
.39656 .64138 m .39375 .65937 L .36224 .65587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6@00O7oo001oOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Uoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0075oo`00M7oo1@00
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00KWoo001_
Ool50002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH3001/Ool006]oo`@000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Yoo`00JGoo0P0000=JEP00FUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0Igoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIY
Ool006Eoo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Ioo`00I7oo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IWoo001TOol20006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1VOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Ioo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0IWoo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1V
Ool006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP03001oogoo06Ioo`00Hgoo
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001SOol00`00FUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006=oo`03001JEP0000MJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0I7oo001TOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001J
EP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH:000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00=JEPT000=J
EP03001JEUYF009JEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<006Aoo`00IWoo00<005YF00000UYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol50005FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001TOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001QOol30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001NOol30008FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005]oo`<00003
FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00FGoo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001EOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000VOol;000cOol005Aoo`03001JEUYF00=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
01ioo`P000=JEP03001JEUYF00=JEP04001JEP00000aOol005=oo`8000EJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8001Moo`L000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080031oo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P004goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF001JES1oo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000?
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001B
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YFFUIJEP/00003FUH0000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH00UYF100015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`000eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;goo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70006FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000_Ool005=oo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF100025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEP000080
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080
02ioo`00E7oo00@005YFFUH000AJEP03001JEUYF00=JEP@000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF
00<005YF00000`000eYF00<005YFFUH01UYF4@000UYF00<005YF00000`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002eoo`00E7oo00@005YFFUH000AJEP<000IJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH8
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Aoo`04001JEUYF0003FUH01@00FUIJEP00FUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008002eoo`00D7oo1@000eYF0`0000=JEP0000000P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol0:goo001<
Ool40002FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF1@00;7oo0018Ool40006
FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000/Ool0
04Aoo`@00003FUH005YF00QJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000]Ool003moo`D000IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP03001oogoo02eoo`00>goo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool003Qoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000aOol003Ioo`<000UJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH0
0002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0M0002FUH2000cOol003Ao
o`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF00AJEP03001JEUYF00AJEQd000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol0035oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP0400000eYF001JEP02FUH50008FUH00`00FUIJEP040004FUH3000015YF001JEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH30000
0eYF000000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000aOol002moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUHA0002FUH50007FUH40002FUH00`00FUIJEP04FUH00`00FUH000020000
0eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF
00D005YF000005YF00<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPh000IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH50004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
000/Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000[Ool00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00:goo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<00003FUH0
05YF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002]oo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH00eYF0`001EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF10000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`001UYF00<005YFFUH01UYF0`000eYF00@005YFFUIJEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH900001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUH005YF0`000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001UYF00<005YFFUH0
0eYF0`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP00004Ool00000000=Ool70003FUH01@00FUIJEUYF0000
;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF100025YF00<005YF0000
0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJ
EP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00009JEP05001JEUYFFUH00005FUH60008Ool50009Ool50005FUH40003FUH00`00Oomoo`0[Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP06FUH3
00000eYF001JEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF0`0000=JEP00FUH01EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000UYF00H005YFFUIJEP00FUH60002FUH20008Ool>0003FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
00000P001UYF00<005YFFUH01UYF0`000UYF00H005YFFUIJEP00FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90002FUH20005FUH01000FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH200000eYF001JEP02FUHB0004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03
FUH40008FUH00`00FUIJEP06FUH30003FUH01000FUIJEP001UYF50001eYF00<005YFFUH00eYF0P00
0eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYF001JEP00FUH00P000UYF40000UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Goo000]Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH0
1EYF30000eYF100015YF0P0027oo00@005YFFUH0009JEPD000QJEP03001JEUYF00EJEP800003FUH0
05YF009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYF001JEP060002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00@005YFFUH000AJEP<000MJEPP000AJEP03
001JEUYF00AJEP05001JEUYFFUH00002FUH60009Ool01000FUIJEP000UYF1@0025YF00<005YFFUH0
1eYF0P000eYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8002ioo`00;Goo00@005YFFUH000=JEP05001JEUYF001J
EP060003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH300000eYF000000020005
Ool01000FUIJEP000UYF1@0025YF00<005YFFUH02EYF00D005YF001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00=JEP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002eoo`04
001JEUYFFUH300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0006FUH00`00FUH000060003Ool01000FUIJEP000eYF100025YF00<005YFFUH02EYF0`0000=JEP00
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
15YF00@005YFFUH0031oo`00;Woo0eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P001UYF00<005YFFUH00eYF10000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP<00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEP0000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH3000a
Ool002ioo`06FUH00000001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP800003FUH0000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000IJEP03001JEUYF00EJEP<0
00=JEP8003=oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH015YF1`0000=JEP00FUH01eYF
00<005YFFUH00eYF1@000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P0000IJEP00000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP03000eOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEQ0000=JEP07001JEUYFFUH005YF00002EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YF000000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000EJEP03001JEUYF00=JEP8003Aoo`00;Goo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP80009JEPL000AJEP03001JEUYF00IJEP03001J
EUYF009JEPP000=JEP03001JEUYF00AJEP8003=oo`00;7oo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH40003FUH20007FUHD0008Ool200000eYF001J
EP05FUH00`00FUH0000bOol002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH00eYF0P000UYF00<005YFFUH01P000UYF0P003Goo1@00
2goo0P001EYF00D005YFFUIJEP00035oo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF5`0015YF00D005YFFUH007oo00P000AJEP03001JEUYF00IJEP04001J
EUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2
0003FUH01000FUH000000UYF00<005YF00000P003Woo1@003Goo0P000eYF00<005YFFUH00UYF00<0
07ooOol0;Woo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF30002goo1P00
0UYF0`0000AJEP00FUIJEP<0009JEP03001JEUYF009JEQ4000MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH2000<
Ool5000?Ool200000eYF001JEP03FUH00`00Oomoo`0^Ool002aoo`04001JEUYF0004FUHA0002Ool5
0007Ool40002FUH00`00FUIJEP04FUH01000FUH000000UYF0`000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH015YF00D005YFFUIJEP00009JEP800003FUH005YF00AJEP<000]oo`<0019oo`8000AJEP03001o
ogoo02ioo`00;7oo00D005YFFUH005YF00@000=JEP03001JEUYF00EJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00AJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP0015YF0`0015YF00<005YFFUH00P0087oo00<005YFFUH00P00<7oo000]Ool00`00FUH000020006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YF00001000
0eYF00<007ooOol07goo1000<7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF1P008Goo0`00<7oo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH015YF00<005YFFUH00UYF00@005YF000000YJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol5000`Ool002aoo`80009JEP04001JEUYFFUH@0004
FUH00`00FUIJEP07FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF0P0000=oo`00FUH02EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF5@0025YF00<005YFFUH02eYF0`0025YF00<0
05YFFUH015YF1`0047oo1@000UYF00<005YF0000<7oo000[Ool20003FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH20005FUH01000FUIJEUYF0P000goo2UYF00<0
05YFFUH01UYF00<005YFFUH01eYF2@0035YF00<005YFFUH01UYF1P000UYF00<005YFFUH02eYF1000
1UYF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH0000`Ool002]oo`80
0005FUH00000FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<0
05YFFUH01UYF0`000eYF00@005YF000000Eoo`YJEP03001JEUYF00IJEP04001JEUYFFUH60008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05000;FUH20002FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000[Ool4
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP050007Ool:FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH2
000:FUH00`00FUIJEP05FUH50006FUH700000eYF000000030006FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Woo000ZOol20003Ool30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00eYF0P0027oo2UYF
00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000=JEP8000EJEP@0009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP00000dOol002Yoo`<000Aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH20007Ool9FUH400000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH200000eYF00000005FUH01000FUIJEUYF0P0000AJEP00Oomoo`L000AJEP03001JEUYF
00EJEP04001JEUYFFUH5000fOol002Yoo`800003FUH0000000Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPT0009oo`8000IJEP03001JEP0000Ioo`MJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000EJEP03001JEUYF009JEP<000Uooa0003]oo`00:Woo0P000eYF00<007ooOol017oo5`00
3Goo0P000eYF00D005YFFUIJEP0000Eoo`EJEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP02FUH00`00FUH0001DOol002]oo`04001JEUYFFUH3000EOol5000@Ool200000eYF001J
EP02FUH00`00Oomoo`03Ool3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF
00L005YFFUIJEP00FUH0001DOol002]oo`05001JEUYFFUH00002FUH2000COol5000BOol20003FUH2
0004Ool2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000IJEP04001JEUYFFUH2
001EOol002aoo`03001JEP0000EJEP<0011oo`D001Aoo`05001JEP00FUH00004Ool00eYF001JEP03
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP8005Eoo`00;Goo
0P001UYF00<005YF00000`003Goo0`005Woo0P0000=JEP00Ool00goo00=JEP00FUH00eYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000IJEP05001JEUYFFUH0001FOol002ioo`03001JEUYF
00AJEP03001JEUYF00=JEP@0029oo`800003FUH007oo00=oo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00mJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH005YF00EJEP04001JEP00001GOol002moo`8000=JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`800003FUH0000000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH0000000EJEP<005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`0047oo1@00
0eYF0P001Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEPH005aoo`00<goo
0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH00006Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00P00GGoo000fOol20004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
27oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF20000eYF00<005YFFUH00eYF0P00Fgoo000hOol300000eYF001J
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool3
0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP040008Ool200000eYF001JEP05FUH2001JOol003]oo`D000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00<000eoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEPH000aoo`8000IJEP04001JEP00001HOol0041oo`T000AJ
EP03001JEUYF00IJEP04001JEUYFFUH5000COol40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP02FUH60002Ool5000=Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1EOol004Uooa4001aoo`P000EJEP03001JEUYF00UJEP03001JEUYF009JEPd000Qoo`D000moo`80
0003FUH005YF00=JEP03001oogoo05Eoo`00OWoo5`0057oo1@004Goo0P0015YF00<007ooOol0EGoo
002=Ool01000FUIJEP0015YF0`004Woo0`0057oo00<005YFFUH00P00Egoo002>Ool30005FUH00`00
FUH00003000VOol4001GOol0091oo`03001JEUYF00=JEP03001JEUYF00=JEPD0029oo`<005Moo`00
TGoo0P000UYF00<005YFFUH01UYF00<005YFFUH0100077oo1@00Egoo002COol30008FUH00`00FUIJ
EP04FUH7000@Ool50002FUH00`00FUH0001GOol009Eoo`8000IJEP03001JEUYF00MJEP03001JEUYF
009JEQ0000=JEP07001JEUYFFUH005YF0000Egoo002GOol20004FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00F7oo002IOol300000eYF001J
EP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001HOol0
09aoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<005Uo
o`00XWoo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005aoo`00Zgoo4000HWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60178 .73811 m .58226 .68425 L .55311 .69364 L p .707 .577 .707 r
F P
0 g
s
.58226 .68425 m .60178 .73811 L .6318 .72714 L p .707 .577 .707 r
F P
0 g
s
.6318 .72714 m .61228 .67328 L .58226 .68425 L p .707 .577 .707 r
F P
0 g
s
.61228 .67328 m .6318 .72714 L .65974 .71567 L p .707 .577 .707 r
F P
0 g
s
.65974 .71567 m .64022 .66182 L .61228 .67328 L p .707 .577 .707 r
F P
0 g
s
.55311 .69364 m .57262 .7475 L .60178 .73811 L p .707 .577 .707 r
F P
0 g
s
.57262 .7475 m .55311 .69364 L .52766 .70054 L p .707 .577 .707 r
F P
0 g
s
.64022 .66182 m .65974 .71567 L .68286 .70483 L p .707 .577 .707 r
F P
0 g
s
.68286 .70483 m .66335 .65097 L .64022 .66182 L p .707 .577 .707 r
F P
0 g
s
.52766 .70054 m .54717 .7544 L .57262 .7475 L p .707 .577 .707 r
F P
0 g
s
.59958 .80429 m .59564 .76703 L .56465 .76851 L p .707 .577 .707 r
F P
0 g
s
.59564 .76703 m .59958 .80429 L .63125 .80046 L p .707 .577 .707 r
F P
0 g
s
.63125 .80046 m .62731 .76321 L .59564 .76703 L p .707 .577 .707 r
F P
0 g
s
.62731 .76321 m .63125 .80046 L .66051 .79467 L p .707 .577 .707 r
F P
0 g
s
.66051 .79467 m .65657 .75742 L .62731 .76321 L p .707 .577 .707 r
F P
0 g
s
.56859 .80576 m .56465 .76851 L .53737 .76749 L p .707 .577 .707 r
F P
0 g
s
.56465 .76851 m .56859 .80576 L .59958 .80429 L p .707 .577 .707 r
F P
0 g
s
.54717 .7544 m .52766 .70054 L .50842 .70428 L p .707 .577 .707 r
F P
0 g
s
.66335 .65097 m .68286 .70483 L .69891 .69568 L p .707 .577 .707 r
F P
0 g
s
.69891 .69568 m .6794 .64182 L .66335 .65097 L p .707 .577 .707 r
F P
0 g
s
.65657 .75742 m .66051 .79467 L .68448 .78747 L p .707 .577 .707 r
F P
0 g
s
.68448 .78747 m .68054 .75022 L .65657 .75742 L p .707 .577 .707 r
F P
0 g
s
.53737 .76749 m .54131 .80474 L .56859 .80576 L p .707 .577 .707 r
F P
0 g
s
.50842 .70428 m .52794 .75814 L .54717 .7544 L p .707 .577 .707 r
F P
0 g
s
.54131 .80474 m .53737 .76749 L .51647 .76408 L p .707 .577 .707 r
F P
0 g
s
.57823 .86164 m .58274 .8442 L .55252 .83471 L p .707 .577 .707 r
F P
0 g
s
.58274 .8442 m .57823 .86164 L .6092 .86771 L p .707 .577 .707 r
F P
0 g
s
.6092 .86771 m .61372 .85027 L .58274 .8442 L p .707 .577 .707 r
F P
0 g
s
.54801 .85215 m .55252 .83471 L .52601 .82273 L p .707 .577 .707 r
F P
0 g
s
.55252 .83471 m .54801 .85215 L .57823 .86164 L p .707 .577 .707 r
F P
0 g
s
.61372 .85027 m .6092 .86771 L .6379 .86976 L p .707 .577 .707 r
F P
0 g
s
.6379 .86976 m .64242 .85232 L .61372 .85027 L p .707 .577 .707 r
F P
0 g
s
.51647 .76408 m .52041 .80133 L .54131 .80474 L p .707 .577 .707 r
F P
0 g
s
.68054 .75022 m .68448 .78747 L .70082 .77957 L p .707 .577 .707 r
F P
0 g
s
.70082 .77957 m .69688 .74232 L .68054 .75022 L p .707 .577 .707 r
F P
0 g
s
.52794 .75814 m .50842 .70428 L .49727 .70448 L p .707 .577 .707 r
F P
0 g
s
.52601 .82273 m .5215 .84017 L .54801 .85215 L p .707 .577 .707 r
F P
0 g
s
.6794 .64182 m .69891 .69568 L .70632 .6891 L p .707 .577 .707 r
F P
0 g
s
.70632 .6891 m .6868 .63524 L .6794 .64182 L p .707 .577 .707 r
F P
0 g
s
.49727 .70448 m .51678 .75834 L .52794 .75814 L p .707 .577 .707 r
F P
0 g
s
.5215 .84017 m .52601 .82273 L .50582 .80943 L p .707 .577 .707 r
F P
0 g
s
.64242 .85232 m .6379 .86976 L .66152 .8676 L p .707 .577 .707 r
F P
0 g
s
.66152 .8676 m .66603 .85016 L .64242 .85232 L p .707 .577 .707 r
F P
0 g
s
.52041 .80133 m .51647 .76408 L .50401 .75861 L p .707 .577 .707 r
F P
0 g
s
.50582 .80943 m .5013 .82688 L .5215 .84017 L p .707 .577 .707 r
F P
0 g
s
.50401 .75861 m .50795 .79586 L .52041 .80133 L p .707 .577 .707 r
F P
0 g
s
.69688 .74232 m .70082 .77957 L .70793 .77174 L p .707 .577 .707 r
F P
0 g
s
.70793 .77174 m .70399 .73449 L .69688 .74232 L p .707 .577 .707 r
F P
0 g
s
.51678 .75834 m .49727 .70448 L .4953 .70113 L p .707 .577 .707 r
F P
0 g
s
.5013 .82688 m .50582 .80943 L .49391 .79612 L p .707 .577 .707 r
F P
0 g
s
.66603 .85016 m .66152 .8676 L .67774 .86144 L p .707 .577 .707 r
F P
0 g
s
.67774 .86144 m .68225 .844 L .66603 .85016 L p .707 .577 .707 r
F P
0 g
s
.6868 .63524 m .70632 .6891 L .70434 .68575 L p .707 .577 .707 r
F P
0 g
s
.70434 .68575 m .68483 .63189 L .6868 .63524 L p .707 .577 .707 r
F P
0 g
s
.4953 .70113 m .51481 .75499 L .51678 .75834 L p .707 .577 .707 r
F P
0 g
s
.49391 .79612 m .48939 .81356 L .5013 .82688 L p .707 .577 .707 r
F P
0 g
s
.50795 .79586 m .50401 .75861 L .50119 .75162 L p .707 .577 .707 r
F P
0 g
s
.51481 .75499 m .4953 .70113 L .5027 .69456 L p .707 .577 .707 r
F P
0 g
s
.5027 .69456 m .52222 .74841 L .51481 .75499 L p .707 .577 .707 r
F P
0 g
s
.50119 .75162 m .50513 .78887 L .50795 .79586 L p .707 .577 .707 r
F P
0 g
s
.50513 .78887 m .50119 .75162 L .50831 .74379 L p .707 .577 .707 r
F P
0 g
s
.50831 .74379 m .51225 .78104 L .50513 .78887 L p .707 .577 .707 r
F P
0 g
s
.52222 .74841 m .5027 .69456 L .51875 .6854 L p .707 .577 .707 r
F P
0 g
s
.51875 .6854 m .53827 .73926 L .52222 .74841 L p .707 .577 .707 r
F P
0 g
s
.51225 .78104 m .50831 .74379 L .52465 .73589 L p .707 .577 .707 r
F P
0 g
s
.49417 .79196 m .49868 .77452 L .5149 .76836 L p .707 .577 .707 r
F P
0 g
s
.5149 .76836 m .51039 .7858 L .49417 .79196 L p .707 .577 .707 r
F P
0 g
s
.52465 .73589 m .52859 .77314 L .51225 .78104 L p .707 .577 .707 r
F P
0 g
s
.53827 .73926 m .51875 .6854 L .54188 .67456 L p .707 .577 .707 r
F P
0 g
s
.54188 .67456 m .56139 .72842 L .53827 .73926 L p .707 .577 .707 r
F P
0 g
s
.52859 .77314 m .52465 .73589 L .54862 .72869 L p .707 .577 .707 r
F P
0 g
s
.51039 .7858 m .5149 .76836 L .53075 .76691 L p .707 .577 .707 r
F P
0 g
s
.54862 .72869 m .55256 .76594 L .52859 .77314 L p .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .55991 .81633 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53075 .76691 m .53843 .7662 L p .5289 .7729 L .707 .577 .707 r
F P
0 g
s
.5289 .7729 m .53843 .7662 L .53839 .76628 L .707 .577 .707 r
F
.51039 .7858 m .53075 .76691 L .5289 .7729 L F
.51492 .8182 m .51508 .82043 L p .54815 .74469 L F P
0 g
s
.53852 .76619 m .534 .78364 L .51039 .7858 L p .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .51492 .8182 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53843 .7662 m .53852 .76619 L p .53839 .76628 L .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .43391 .31667 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .51492 .8182 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51492 .8182 m .47779 .31603 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .54188 .67456 L .55517 .66911 L p .707 .577 .707 r
F P
0 g
s
.55517 .66911 m .56982 .66309 L p .56728 .68279 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .55517 .66911 L .56728 .68279 L .707 .577 .707 r
F
.52263 .31193 m .47779 .31603 L p .53133 .64217 L F P
0 g
s
.56982 .66309 m .58933 .71695 L .56139 .72842 L p .707 .577 .707 r
F P
0 g
s
.55256 .76594 m .54862 .72869 L .57787 .72289 L p .707 .577 .707 r
F P
0 g
s
.57787 .72289 m .58181 .76014 L .55256 .76594 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .54847 .66154 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.54847 .66154 m .52263 .31193 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.58933 .71695 m .57714 .68329 L p .59984 .65213 L .707 .577 .707 r
F P
0 g
s
.57714 .68329 m .56982 .66309 L .57935 .65961 L p .707 .577 .707 r
F P
0 g
s
.57935 .65961 m .59984 .65213 L p .57714 .68329 L .707 .577 .707 r
F P
0 g
s
.629 .64273 m .64851 .69659 L .61935 .70598 L p .707 .577 .707 r
F P
0 g
s
.61935 .70598 m .59984 .65213 L .629 .64273 L p .707 .577 .707 r
F P
0 g
s
.59984 .65213 m .61935 .70598 L .58933 .71695 L p .707 .577 .707 r
F P
0 g
s
.64054 .7176 m .64448 .75485 L .61349 .75632 L p .707 .577 .707 r
F P
0 g
s
.61349 .75632 m .60955 .71907 L .64054 .7176 L p .707 .577 .707 r
F P
0 g
s
.58181 .76014 m .57787 .72289 L .60955 .71907 L p .707 .577 .707 r
F P
0 g
s
.60955 .71907 m .61349 .75632 L .58181 .76014 L p .707 .577 .707 r
F P
0 g
s
.65492 .79578 m .6504 .81323 L .6239 .80125 L p .707 .577 .707 r
F P
0 g
s
.6239 .80125 m .62841 .7838 L .65492 .79578 L p .707 .577 .707 r
F P
0 g
s
.62841 .7838 m .6239 .80125 L .59725 .79288 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .59986 .80943 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.58985 .77268 m .59819 .77432 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.55148 .70221 m .55991 .81633 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .5627 .78569 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59819 .77432 m .59579 .7836 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59579 .7836 m .59368 .79176 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .59819 .77432 L .62841 .7838 L p .707 .577 .707 r
F P
0 g
s
.52263 .31193 m .52368 .32625 L p .59778 .78725 L .707 .577 .707 r
F P
0 g
s
.59696 .79101 m .62841 .7838 L .59725 .79288 L .707 .577 .707 r
F
.60131 .80918 m .59786 .78739 L .59778 .78725 L F
.59786 .78739 m .52263 .31193 L .59778 .78725 L F
.52368 .32625 m .55148 .70221 L p .59579 .7836 L F P
0 g
s
.5627 .78569 m .56722 .76825 L .58985 .77268 L p .707 .577 .707 r
F P
0 g
s
.5627 .78569 m .58985 .77268 L .59185 .77635 L .707 .577 .707 r
F
.59725 .79288 m .59368 .79176 L p .59696 .79101 L F P
0 g
s
.59986 .80943 m .60131 .80918 L p .52368 .32625 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .63521 .79968 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.56402 .30479 m .58544 .59455 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.58544 .59455 m .60131 .80918 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .56402 .30479 L .52263 .31193 L p .707 .577 .707 r
F P
0 g
s
.70399 .73449 m .70793 .77174 L .70512 .76475 L p .707 .577 .707 r
F P
0 g
s
.70512 .76475 m .70118 .72749 L .70399 .73449 L p .707 .577 .707 r
F P
0 g
s
.48939 .81356 m .49391 .79612 L .49145 .78409 L p .707 .577 .707 r
F P
0 g
s
.68225 .844 m .67774 .86144 L .68497 .85187 L p .707 .577 .707 r
F P
0 g
s
.68497 .85187 m .68948 .83443 L .68225 .844 L p .707 .577 .707 r
F P
0 g
s
.47119 .82107 m .43391 .31667 L .39527 .31379 L p .707 .577 .707 r
F P
0 g
s
.49145 .78409 m .48693 .80153 L .48939 .81356 L p .707 .577 .707 r
F P
0 g
s
.48693 .80153 m .49145 .78409 L .49868 .77452 L p .707 .577 .707 r
F P
0 g
s
.49868 .77452 m .49417 .79196 L .48693 .80153 L p .707 .577 .707 r
F P
0 g
s
.43391 .31667 m .47119 .82107 L .51508 .82043 L p .707 .577 .707 r
F P
0 g
s
.68483 .63189 m .70434 .68575 L .69319 .68595 L p .707 .577 .707 r
F P
0 g
s
.69319 .68595 m .67368 .63209 L .68483 .63189 L p .707 .577 .707 r
F P
0 g
s
.63521 .79968 m .59792 .29528 L .56402 .30479 L p .707 .577 .707 r
F P
0 g
s
.25877 .69931 m .23925 .64545 L .2101 .65484 L p .707 .577 .707 r
F P
0 g
s
.23925 .64545 m .25877 .69931 L .28879 .68834 L p .707 .577 .707 r
F P
0 g
s
.28879 .68834 m .26927 .63448 L .23925 .64545 L p .707 .577 .707 r
F P
0 g
s
.26927 .63448 m .28879 .68834 L .31673 .67688 L p .707 .577 .707 r
F P
0 g
s
.31673 .67688 m .29721 .62302 L .26927 .63448 L p .707 .577 .707 r
F P
0 g
s
.43255 .81819 m .39527 .31379 L .36565 .30768 L p .707 .577 .707 r
F P
0 g
s
.39527 .31379 m .43255 .81819 L .47119 .82107 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70118 .72749 m .70512 .76475 L .69265 .75928 L p .707 .577 .707 r
F P
0 g
s
.69265 .75928 m .68871 .72203 L .70118 .72749 L p .707 .577 .707 r
F P
0 g
s
.2101 .65484 m .22961 .7087 L .25877 .69931 L p .707 .577 .707 r
F P
0 g
s
.22961 .7087 m .2101 .65484 L .18465 .66175 L p .707 .577 .707 r
F P
0 g
s
.68948 .83443 m .68497 .85187 L .68251 .83984 L p .707 .577 .707 r
F P
0 g
s
.68251 .83984 m .68703 .8224 L .68948 .83443 L p .707 .577 .707 r
F P
0 g
s
.29721 .62302 m .31673 .67688 L .33985 .66603 L p .707 .577 .707 r
F P
0 g
s
.33985 .66603 m .32034 .61218 L .29721 .62302 L p .707 .577 .707 r
F P
0 g
s
.18465 .66175 m .20417 .7156 L .22961 .7087 L p .707 .577 .707 r
F P
0 g
s
.67368 .63209 m .69319 .68595 L .67396 .68969 L p .707 .577 .707 r
F P
0 g
s
.67396 .68969 m .65444 .63583 L .67368 .63209 L p .707 .577 .707 r
F P
0 g
s
.64851 .69659 m .629 .64273 L .65444 .63583 L p .707 .577 .707 r
F P
0 g
s
.66782 .71862 m .67176 .75587 L .64448 .75485 L p .707 .577 .707 r
F P
0 g
s
.64448 .75485 m .64054 .7176 L .66782 .71862 L p .707 .577 .707 r
F P
0 g
s
.59792 .29528 m .63521 .79968 L .6583 .78875 L p .707 .577 .707 r
F P
0 g
s
.65444 .63583 m .67396 .68969 L .64851 .69659 L p .707 .577 .707 r
F P
0 g
s
.6583 .78875 m .62101 .28435 L .59792 .29528 L p .707 .577 .707 r
F P
0 g
s
.25657 .77242 m .25263 .73517 L .22164 .73664 L p .707 .577 .707 r
F P
0 g
s
.25263 .73517 m .25657 .77242 L .28824 .7686 L p .707 .577 .707 r
F P
0 g
s
.28824 .7686 m .28431 .73135 L .25263 .73517 L p .707 .577 .707 r
F P
0 g
s
.28431 .73135 m .28824 .7686 L .3175 .7628 L p .707 .577 .707 r
F P
0 g
s
.3175 .7628 m .31356 .72555 L .28431 .73135 L p .707 .577 .707 r
F P
0 g
s
.22558 .77389 m .22164 .73664 L .19436 .73562 L p .707 .577 .707 r
F P
0 g
s
.22164 .73664 m .22558 .77389 L .25657 .77242 L p .707 .577 .707 r
F P
0 g
s
.20417 .7156 m .18465 .66175 L .16541 .66548 L p .707 .577 .707 r
F P
0 g
s
.32034 .61218 m .33985 .66603 L .3559 .65688 L p .707 .577 .707 r
F P
0 g
s
.3559 .65688 m .33639 .60302 L .32034 .61218 L p .707 .577 .707 r
F P
0 g
s
.31356 .72555 m .3175 .7628 L .34147 .7556 L p .707 .577 .707 r
F P
0 g
s
.34147 .7556 m .33753 .71835 L .31356 .72555 L p .707 .577 .707 r
F P
0 g
s
.16541 .66548 m .18493 .71934 L .20417 .7156 L p .707 .577 .707 r
F P
0 g
s
.68871 .72203 m .69265 .75928 L .67176 .75587 L p .707 .577 .707 r
F P
0 g
s
.67176 .75587 m .66782 .71862 L .68871 .72203 L p .707 .577 .707 r
F P
0 g
s
.19436 .73562 m .1983 .77288 L .22558 .77389 L p .707 .577 .707 r
F P
0 g
s
.40294 .81207 m .36565 .30768 L .34796 .29893 L p .707 .577 .707 r
F P
0 g
s
.36565 .30768 m .40294 .81207 L .43255 .81819 L p .707 .577 .707 r
F P
0 g
s
.68703 .8224 m .68251 .83984 L .6706 .82652 L p .707 .577 .707 r
F P
0 g
s
.6706 .82652 m .67512 .80908 L .68703 .8224 L p .707 .577 .707 r
F P
0 g
s
.23522 .81586 m .23973 .79842 L .20951 .78893 L p .707 .577 .707 r
F P
0 g
s
.23973 .79842 m .23522 .81586 L .26619 .82193 L p .707 .577 .707 r
F P
0 g
s
.26619 .82193 m .27071 .80449 L .23973 .79842 L p .707 .577 .707 r
F P
0 g
s
.1983 .77288 m .19436 .73562 L .17346 .73221 L p .707 .577 .707 r
F P
0 g
s
.205 .80637 m .20951 .78893 L .18301 .77695 L p .707 .577 .707 r
F P
0 g
s
.20951 .78893 m .205 .80637 L .23522 .81586 L p .707 .577 .707 r
F P
0 g
s
.27071 .80449 m .26619 .82193 L .29489 .82398 L p .707 .577 .707 r
F P
0 g
s
.29489 .82398 m .29941 .80654 L .27071 .80449 L p .707 .577 .707 r
F P
0 g
s
.18493 .71934 m .16541 .66548 L .15426 .66568 L p .707 .577 .707 r
F P
0 g
s
.17346 .73221 m .1774 .76947 L .1983 .77288 L p .707 .577 .707 r
F P
0 g
s
.33753 .71835 m .34147 .7556 L .35781 .7477 L p .707 .577 .707 r
F P
0 g
s
.35781 .7477 m .35387 .71045 L .33753 .71835 L p .707 .577 .707 r
F P
0 g
s
.18301 .77695 m .17849 .79439 L .205 .80637 L p .707 .577 .707 r
F P
0 g
s
.62101 .28435 m .6583 .78875 L .66832 .77747 L p .707 .577 .707 r
F P
0 g
s
.66832 .77747 m .63103 .27307 L .62101 .28435 L p .707 .577 .707 r
F P
0 g
s
.33639 .60302 m .3559 .65688 L .36331 .6503 L p .707 .577 .707 r
F P
0 g
s
.36331 .6503 m .34379 .59644 L .33639 .60302 L p .707 .577 .707 r
F P
0 g
s
.15426 .66568 m .17378 .71954 L .18493 .71934 L p .707 .577 .707 r
F P
0 g
s
.17849 .79439 m .18301 .77695 L .16281 .76365 L p .707 .577 .707 r
F P
0 g
s
.29941 .80654 m .29489 .82398 L .31851 .82182 L p .707 .577 .707 r
F P
0 g
s
.31851 .82182 m .32302 .80438 L .29941 .80654 L p .707 .577 .707 r
F P
0 g
s
.67512 .80908 m .6706 .82652 L .6504 .81323 L p .707 .577 .707 r
F P
0 g
s
.6504 .81323 m .65492 .79578 L .67512 .80908 L p .707 .577 .707 r
F P
0 g
s
.16281 .76365 m .15829 .78109 L .17849 .79439 L p .707 .577 .707 r
F P
0 g
s
.1774 .76947 m .17346 .73221 L .161 .72675 L p .707 .577 .707 r
F P
0 g
s
.161 .72675 m .16494 .764 L .1774 .76947 L p .707 .577 .707 r
F P
0 g
s
.38525 .80332 m .34796 .29893 L .34393 .28839 L p .707 .577 .707 r
F P
0 g
s
.34796 .29893 m .38525 .80332 L .40294 .81207 L p .707 .577 .707 r
F P
0 g
s
.35387 .71045 m .35781 .7477 L .36492 .73987 L p .707 .577 .707 r
F P
0 g
s
.36492 .73987 m .36098 .70262 L .35387 .71045 L p .707 .577 .707 r
F P
0 g
s
.15829 .78109 m .16281 .76365 L .1509 .75034 L p .707 .577 .707 r
F P
0 g
s
.17378 .71954 m .15426 .66568 L .15229 .66233 L p .707 .577 .707 r
F P
0 g
s
.32302 .80438 m .31851 .82182 L .33473 .81566 L p .707 .577 .707 r
F P
0 g
s
.33473 .81566 m .33924 .79821 L .32302 .80438 L p .707 .577 .707 r
F P
0 g
s
.534 .78364 m .53852 .76619 L .56722 .76825 L p .707 .577 .707 r
F P
0 g
s
.34379 .59644 m .36331 .6503 L .36134 .64695 L p .707 .577 .707 r
F P
0 g
s
.36134 .64695 m .34182 .59309 L .34379 .59644 L p .707 .577 .707 r
F P
0 g
s
.1509 .75034 m .14638 .76778 L .15829 .78109 L p .707 .577 .707 r
F P
0 g
s
.15229 .66233 m .1718 .71619 L .17378 .71954 L p .707 .577 .707 r
F P
0 g
s
.56722 .76825 m .5627 .78569 L .534 .78364 L p .707 .577 .707 r
F P
0 g
s
.16494 .764 m .161 .72675 L .15819 .71975 L p .707 .577 .707 r
F P
0 g
s
.6587 .74814 m .66082 .73998 L p .64302 .7174 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .65935 .73378 L .64302 .7174 L .707 .577 .707 r
F
.627 .26254 m .66296 .74905 L p .66082 .73998 L F P
0 g
s
.64287 .66401 m .6371 .51819 L .66082 .73998 L .707 .577 .707 r
F
.6371 .51819 m .627 .26254 L .66082 .73998 L F
.66832 .77747 m .66469 .768 L p .65212 .58635 L F P
0 g
s
.66341 .75396 m .65212 .58635 L .66469 .768 L .707 .577 .707 r
F
.65212 .58635 m .65166 .56027 L .66832 .77747 L F
.63788 .36574 m .66832 .77747 L p .64106 .422 L F P
0 g
s
.627 .26254 m .63103 .27307 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .6525 .60754 L p .65212 .58635 L .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .66514 .6661 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.66116 .72934 m .65778 .72711 L p .66179 .73622 L .707 .577 .707 r
F P
0 g
s
.65778 .72711 m .64302 .7174 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .65778 .72711 L .65935 .73378 L .707 .577 .707 r
F
.60931 .25379 m .627 .26254 L p .64287 .66401 L F P
0 g
s
.64302 .7174 m .63851 .73484 L .6587 .74814 L p .707 .577 .707 r
F P
0 g
s
.64659 .75819 m .63816 .64406 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .60931 .25379 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63851 .73484 m .64302 .7174 L .63111 .70408 L p .707 .577 .707 r
F P
0 g
s
.63111 .70408 m .6266 .72152 L .63851 .73484 L p .707 .577 .707 r
F P
0 g
s
.6266 .72152 m .63111 .70408 L .6311 .70403 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .61406 .56259 L .63533 .69048 L .707 .577 .707 r
F
.6311 .70403 m .62865 .69205 L p .62687 .7176 L F P
0 g
s
.6266 .72152 m .6311 .70403 L .62687 .7176 L .707 .577 .707 r
F
.64659 .75819 m .61698 .75207 L p .61694 .74945 L F P
0 g
s
.62865 .69205 m .62414 .70949 L .6266 .72152 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .63533 .69048 L .64659 .75819 L .707 .577 .707 r
F
.60931 .25379 m .63515 .60339 L p .61406 .56259 L F P
0 g
s
.63515 .60339 m .64659 .75819 L p .61406 .56259 L .707 .577 .707 r
F P
0 g
s
.65317 .64515 m .65033 .63276 L .63448 .61244 L .707 .577 .707 r
F
.64563 .61224 m .63978 .61235 L p .65033 .63276 L F P
0 g
s
.63978 .61235 m .63448 .61244 L p .65033 .63276 L .707 .577 .707 r
F P
0 g
s
.63448 .61244 m .65352 .66501 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65352 .66501 m .65399 .6663 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64842 .55231 L .64106 .422 L .707 .577 .707 r
F
.6525 .60754 m .64842 .55231 L p .65212 .58635 L F P
0 g
s
.64842 .55231 m .627 .26254 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66514 .6661 m .68438 .66236 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.64563 .61224 m .65294 .63243 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.65294 .63243 m .66514 .6661 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.66322 .7307 m .66082 .73998 L p .68521 .76012 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .6587 .74814 L .66184 .74955 L p .707 .577 .707 r
F P
0 g
s
.66296 .74905 m .66428 .76694 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66184 .74955 m .68521 .76012 L p .66082 .73998 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .64659 .75819 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .66179 .73622 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .66322 .7307 L .66116 .72934 L p .707 .577 .707 r
F P
0 g
s
.66469 .768 m .66428 .76694 L p .66341 .75396 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64106 .422 L .65166 .56027 L .707 .577 .707 r
F
.66514 .6661 m .65294 .63243 L p .65317 .64515 L F P
0 g
s
.65294 .63243 m .64563 .61224 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .66487 .60851 L .65173 .61105 L p .707 .577 .707 r
F P
0 g
s
.65173 .61105 m .64563 .61224 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .65173 .61105 L .65229 .62086 L .707 .577 .707 r
F
.63103 .27307 m .63788 .36574 L p .64106 .422 L F P
0 g
s
.15819 .71975 m .16212 .75701 L .16494 .764 L p .707 .577 .707 r
F P
0 g
s
.14638 .76778 m .1509 .75034 L .14844 .73831 L p .707 .577 .707 r
F P
0 g
s
.36098 .70262 m .36492 .73987 L .36211 .73288 L p .707 .577 .707 r
F P
0 g
s
.36211 .73288 m .35817 .69563 L .36098 .70262 L p .707 .577 .707 r
F P
0 g
s
.33924 .79821 m .33473 .81566 L .34196 .80609 L p .707 .577 .707 r
F P
0 g
s
.34196 .80609 m .34648 .78865 L .33924 .79821 L p .707 .577 .707 r
F P
0 g
s
.14844 .73831 m .14392 .75575 L .14638 .76778 L p .707 .577 .707 r
F P
0 g
s
.1718 .71619 m .15229 .66233 L .15969 .65576 L p .707 .577 .707 r
F P
0 g
s
.34182 .59309 m .36134 .64695 L .35018 .64715 L p .707 .577 .707 r
F P
0 g
s
.35018 .64715 m .33067 .5933 L .34182 .59309 L p .707 .577 .707 r
F P
0 g
s
.15969 .65576 m .17921 .70962 L .1718 .71619 L p .707 .577 .707 r
F P
0 g
s
.34393 .28839 m .38122 .79279 L .38525 .80332 L p .707 .577 .707 r
F P
0 g
s
.38122 .79279 m .34393 .28839 L .35395 .27711 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16212 .75701 m .15819 .71975 L .1653 .71192 L p .707 .577 .707 r
F P
0 g
s
.1653 .71192 m .16924 .74918 L .16212 .75701 L p .707 .577 .707 r
F P
0 g
s
.14392 .75575 m .14844 .73831 L .15567 .72874 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34648 .78865 m .34196 .80609 L .3395 .79406 L p .707 .577 .707 r
F P
0 g
s
.3395 .79406 m .34402 .77662 L .34648 .78865 L p .707 .577 .707 r
F P
0 g
s
.35817 .69563 m .36211 .73288 L .34964 .72741 L p .707 .577 .707 r
F P
0 g
s
.34964 .72741 m .3457 .69016 L .35817 .69563 L p .707 .577 .707 r
F P
0 g
s
.15567 .72874 m .15116 .74618 L .14392 .75575 L p .707 .577 .707 r
F P
0 g
s
.17921 .70962 m .15969 .65576 L .17574 .6466 L p .707 .577 .707 r
F P
0 g
s
.33067 .5933 m .35018 .64715 L .33095 .65089 L p .707 .577 .707 r
F P
0 g
s
.33095 .65089 m .31143 .59703 L .33067 .5933 L p .707 .577 .707 r
F P
0 g
s
.17574 .6466 m .19526 .70046 L .17921 .70962 L p .707 .577 .707 r
F P
0 g
s
.16924 .74918 m .1653 .71192 L .18164 .70402 L p .707 .577 .707 r
F P
0 g
s
.39124 .78151 m .35395 .27711 L .37704 .26618 L p .707 .577 .707 r
F P
0 g
s
.35395 .27711 m .39124 .78151 L .38122 .79279 L p .707 .577 .707 r
F P
0 g
s
.15116 .74618 m .15567 .72874 L .17189 .72258 L p .707 .577 .707 r
F P
0 g
s
.18164 .70402 m .18558 .74127 L .16924 .74918 L p .707 .577 .707 r
F P
0 g
s
.34402 .77662 m .3395 .79406 L .32759 .78074 L p .707 .577 .707 r
F P
0 g
s
.32759 .78074 m .33211 .7633 L .34402 .77662 L p .707 .577 .707 r
F P
0 g
s
.3457 .69016 m .34964 .72741 L .32875 .724 L p .707 .577 .707 r
F P
0 g
s
.32875 .724 m .32481 .68675 L .3457 .69016 L p .707 .577 .707 r
F P
0 g
s
.19526 .70046 m .17574 .6466 L .19887 .63576 L p .707 .577 .707 r
F P
0 g
s
.17189 .72258 m .16738 .74002 L .15116 .74618 L p .707 .577 .707 r
F P
0 g
s
.31143 .59703 m .33095 .65089 L .3055 .65779 L p .707 .577 .707 r
F P
0 g
s
.3055 .65779 m .28599 .60393 L .31143 .59703 L p .707 .577 .707 r
F P
0 g
s
.19887 .63576 m .21838 .68962 L .19526 .70046 L p .707 .577 .707 r
F P
0 g
s
.61698 .75207 m .57969 .24767 L .60931 .25379 L p .707 .577 .707 r
F P
0 g
s
.18558 .74127 m .18164 .70402 L .20561 .69682 L p .707 .577 .707 r
F P
0 g
s
.21838 .68962 m .19887 .63576 L .22681 .62429 L p .707 .577 .707 r
F P
0 g
s
.28599 .60393 m .3055 .65779 L .27634 .66719 L p .707 .577 .707 r
F P
0 g
s
.27634 .66719 m .25683 .61333 L .28599 .60393 L p .707 .577 .707 r
F P
0 g
s
.20561 .69682 m .20955 .73407 L .18558 .74127 L p .707 .577 .707 r
F P
0 g
s
.32481 .68675 m .32875 .724 L .30147 .72298 L p .707 .577 .707 r
F P
0 g
s
.30147 .72298 m .29753 .68573 L .32481 .68675 L p .707 .577 .707 r
F P
0 g
s
.16738 .74002 m .17189 .72258 L .19551 .72041 L p .707 .577 .707 r
F P
0 g
s
.33211 .7633 m .32759 .78074 L .30739 .76744 L p .707 .577 .707 r
F P
0 g
s
.30739 .76744 m .31191 .75 L .33211 .7633 L p .707 .577 .707 r
F P
0 g
s
.22681 .62429 m .24632 .67815 L .21838 .68962 L p .707 .577 .707 r
F P
0 g
s
.73898 .64607 m .71947 .59221 L .69031 .6016 L p .707 .577 .707 r
F P
0 g
s
.71947 .59221 m .73898 .64607 L .769 .6351 L p .707 .577 .707 r
F P
0 g
s
.769 .6351 m .74949 .58124 L .71947 .59221 L p .707 .577 .707 r
F P
0 g
s
.74949 .58124 m .769 .6351 L .79694 .62364 L p .707 .577 .707 r
F P
0 g
s
.79694 .62364 m .77743 .56978 L .74949 .58124 L p .707 .577 .707 r
F P
0 g
s
.19551 .72041 m .19099 .73785 L .16738 .74002 L p .707 .577 .707 r
F P
0 g
s
.24632 .67815 m .22681 .62429 L .25683 .61333 L p .707 .577 .707 r
F P
0 g
s
.25683 .61333 m .27634 .66719 L .24632 .67815 L p .707 .577 .707 r
F P
0 g
s
.37704 .26618 m .41433 .77058 L .39124 .78151 L p .707 .577 .707 r
F P
0 g
s
.41433 .77058 m .37704 .26618 L .41094 .25668 L p .707 .577 .707 r
F P
0 g
s
.20955 .73407 m .20561 .69682 L .23486 .69103 L p .707 .577 .707 r
F P
0 g
s
.69031 .6016 m .70982 .65546 L .73898 .64607 L p .707 .577 .707 r
F P
0 g
s
.70982 .65546 m .69031 .6016 L .66487 .60851 L p .707 .577 .707 r
F P
0 g
s
.29753 .68573 m .30147 .72298 L .27048 .72446 L p .707 .577 .707 r
F P
0 g
s
.27048 .72446 m .26654 .68721 L .29753 .68573 L p .707 .577 .707 r
F P
0 g
s
.77743 .56978 m .79694 .62364 L .82007 .61279 L p .707 .577 .707 r
F P
0 g
s
.82007 .61279 m .80055 .55894 L .77743 .56978 L p .707 .577 .707 r
F P
0 g
s
.23486 .69103 m .2388 .72828 L .20955 .73407 L p .707 .577 .707 r
F P
0 g
s
.19099 .73785 m .19551 .72041 L .22421 .72247 L p .707 .577 .707 r
F P
0 g
s
.66487 .60851 m .68438 .66236 L .70982 .65546 L p .707 .577 .707 r
F P
0 g
s
.2388 .72828 m .23486 .69103 L .26654 .68721 L p .707 .577 .707 r
F P
0 g
s
.31191 .75 m .30739 .76744 L .28089 .75546 L p .707 .577 .707 r
F P
0 g
s
.28089 .75546 m .2854 .73802 L .31191 .75 L p .707 .577 .707 r
F P
0 g
s
.73678 .71225 m .73284 .675 L .70185 .67647 L p .707 .577 .707 r
F P
0 g
s
.73284 .675 m .73678 .71225 L .76846 .70843 L p .707 .577 .707 r
F P
0 g
s
.76846 .70843 m .76452 .67118 L .73284 .675 L p .707 .577 .707 r
F P
0 g
s
.57969 .24767 m .61698 .75207 L .57834 .74919 L p .707 .577 .707 r
F P
0 g
s
.57834 .74919 m .54105 .2448 L .57969 .24767 L p .707 .577 .707 r
F P
0 g
s
.26654 .68721 m .27048 .72446 L .2388 .72828 L p .707 .577 .707 r
F P
0 g
s
.76452 .67118 m .76846 .70843 L .79771 .70263 L p .707 .577 .707 r
F P
0 g
s
.79771 .70263 m .79377 .66538 L .76452 .67118 L p .707 .577 .707 r
F P
0 g
s
.22421 .72247 m .21969 .73991 L .19099 .73785 L p .707 .577 .707 r
F P
0 g
s
.70579 .71372 m .70185 .67647 L .67457 .67545 L p .707 .577 .707 r
F P
0 g
s
.70185 .67647 m .70579 .71372 L .73678 .71225 L p .707 .577 .707 r
F P
0 g
s
.21969 .73991 m .22421 .72247 L .25518 .72853 L p .707 .577 .707 r
F P
0 g
s
.80055 .55894 m .82007 .61279 L .83612 .60364 L p .707 .577 .707 r
F P
0 g
s
.83612 .60364 m .8166 .54978 L .80055 .55894 L p .707 .577 .707 r
F P
0 g
s
.2854 .73802 m .28089 .75546 L .25067 .74598 L p .707 .577 .707 r
F P
0 g
s
.25067 .74598 m .25518 .72853 L .2854 .73802 L p .707 .577 .707 r
F P
0 g
s
.79377 .66538 m .79771 .70263 L .82168 .69543 L p .707 .577 .707 r
F P
0 g
s
.82168 .69543 m .81774 .65818 L .79377 .66538 L p .707 .577 .707 r
F P
0 g
s
.44823 .76108 m .41094 .25668 L .45233 .24953 L p .707 .577 .707 r
F P
0 g
s
.41094 .25668 m .44823 .76108 L .41433 .77058 L p .707 .577 .707 r
F P
0 g
s
.67457 .67545 m .67851 .7127 L .70579 .71372 L p .707 .577 .707 r
F P
0 g
s
.25518 .72853 m .25067 .74598 L .21969 .73991 L p .707 .577 .707 r
F P
0 g
s
.54105 .2448 m .57834 .74919 L .53445 .74983 L p .707 .577 .707 r
F P
0 g
s
.53445 .74983 m .49717 .24544 L .54105 .2448 L p .707 .577 .707 r
F P
0 g
s
.67851 .7127 m .67457 .67545 L .65368 .67204 L p .707 .577 .707 r
F P
0 g
s
.71543 .76961 m .71994 .75216 L .68972 .74268 L p .707 .577 .707 r
F P
0 g
s
.71994 .75216 m .71543 .76961 L .74641 .77567 L p .707 .577 .707 r
F P
0 g
s
.74641 .77567 m .75092 .75823 L .71994 .75216 L p .707 .577 .707 r
F P
0 g
s
.48962 .75393 m .45233 .24953 L .49717 .24544 L p .707 .577 .707 r
F P
0 g
s
.45233 .24953 m .48962 .75393 L .44823 .76108 L p .707 .577 .707 r
F P
0 g
s
.68521 .76012 m .68972 .74268 L .66322 .7307 L p .707 .577 .707 r
F P
0 g
s
.68972 .74268 m .68521 .76012 L .71543 .76961 L p .707 .577 .707 r
F P
0 g
s
.75092 .75823 m .74641 .77567 L .77511 .77773 L p .707 .577 .707 r
F P
0 g
s
.77511 .77773 m .77962 .76029 L .75092 .75823 L p .707 .577 .707 r
F P
0 g
s
.65368 .67204 m .65762 .70929 L .67851 .7127 L p .707 .577 .707 r
F P
0 g
s
.81774 .65818 m .82168 .69543 L .83802 .68753 L p .707 .577 .707 r
F P
0 g
s
.83802 .68753 m .83408 .65028 L .81774 .65818 L p .707 .577 .707 r
F P
0 g
s
.49717 .24544 m .53445 .74983 L .48962 .75393 L p .707 .577 .707 r
F P
0 g
s
.8166 .54978 m .83612 .60364 L .84352 .59706 L p .707 .577 .707 r
F P
0 g
s
.84352 .59706 m .82401 .5432 L .8166 .54978 L p .707 .577 .707 r
F P
0 g
s
.77962 .76029 m .77511 .77773 L .79872 .77556 L p .707 .577 .707 r
F P
0 g
s
.79872 .77556 m .80324 .75812 L .77962 .76029 L p .707 .577 .707 r
F P
0 g
s
.65762 .70929 m .65368 .67204 L .64121 .66657 L p .707 .577 .707 r
F P
0 g
s
.64121 .66657 m .64515 .70382 L .65762 .70929 L p .707 .577 .707 r
F P
0 g
s
.83408 .65028 m .83802 .68753 L .84514 .6797 L p .707 .577 .707 r
F P
0 g
s
.84514 .6797 m .8412 .64245 L .83408 .65028 L p .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .63448 .61244 L .6325 .60909 L p .707 .577 .707 r
F P
0 g
s
.80324 .75812 m .79872 .77556 L .81494 .7694 L p .707 .577 .707 r
F P
0 g
s
.81494 .7694 m .81945 .75196 L .80324 .75812 L p .707 .577 .707 r
F P
0 g
s
.82401 .5432 m .84352 .59706 L .84155 .59371 L p .707 .577 .707 r
F P
0 g
s
.84155 .59371 m .82204 .53985 L .82401 .5432 L p .707 .577 .707 r
F P
0 g
s
.6325 .60909 m .65202 .66295 L .65399 .6663 L p .707 .577 .707 r
F P
0 g
s
.64515 .70382 m .64121 .66657 L .6384 .65958 L p .707 .577 .707 r
F P
0 g
s
.6384 .65958 m .64234 .69683 L .64515 .70382 L p .707 .577 .707 r
F P
0 g
s
.8412 .64245 m .84514 .6797 L .84232 .67271 L p .707 .577 .707 r
F P
0 g
s
.84232 .67271 m .83838 .63546 L .8412 .64245 L p .707 .577 .707 r
F P
0 g
s
.81945 .75196 m .81494 .7694 L .82217 .75983 L p .707 .577 .707 r
F P
0 g
s
.82217 .75983 m .82669 .74239 L .81945 .75196 L p .707 .577 .707 r
F P
0 g
s
.65202 .66295 m .6325 .60909 L .63991 .60252 L p .707 .577 .707 r
F P
0 g
s
.82204 .53985 m .84155 .59371 L .8304 .59391 L p .707 .577 .707 r
F P
0 g
s
.8304 .59391 m .81089 .54005 L .82204 .53985 L p .707 .577 .707 r
F P
0 g
s
.63991 .60252 m .65942 .65638 L .65202 .66295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64234 .69683 m .6384 .65958 L .64551 .65175 L p .707 .577 .707 r
F P
0 g
s
.39597 .60727 m .37646 .55341 L .3473 .56281 L p .707 .577 .707 r
F P
0 g
s
.37646 .55341 m .39597 .60727 L .42599 .5963 L p .707 .577 .707 r
F P
0 g
s
.42599 .5963 m .40648 .54244 L .37646 .55341 L p .707 .577 .707 r
F P
0 g
s
.40648 .54244 m .42599 .5963 L .45393 .58484 L p .707 .577 .707 r
F P
0 g
s
.45393 .58484 m .43442 .53098 L .40648 .54244 L p .707 .577 .707 r
F P
0 g
s
.64551 .65175 m .64945 .689 L .64234 .69683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83838 .63546 m .84232 .67271 L .82986 .66724 L p .707 .577 .707 r
F P
0 g
s
.82986 .66724 m .82592 .62999 L .83838 .63546 L p .707 .577 .707 r
F P
0 g
s
.3473 .56281 m .36681 .61666 L .39597 .60727 L p .707 .577 .707 r
F P
0 g
s
.62414 .70949 m .62865 .69205 L .63589 .68248 L p .707 .577 .707 r
F P
0 g
s
.36681 .61666 m .3473 .56281 L .32186 .56971 L p .707 .577 .707 r
F P
0 g
s
.82669 .74239 m .82217 .75983 L .81972 .7478 L p .707 .577 .707 r
F P
0 g
s
.81972 .7478 m .82423 .73036 L .82669 .74239 L p .707 .577 .707 r
F P
0 g
s
.43442 .53098 m .45393 .58484 L .47706 .574 L p .707 .577 .707 r
F P
0 g
s
.47706 .574 m .45754 .52014 L .43442 .53098 L p .707 .577 .707 r
F P
0 g
s
.65942 .65638 m .63991 .60252 L .65596 .59336 L p .707 .577 .707 r
F P
0 g
s
.63589 .68248 m .63137 .69993 L .62414 .70949 L p .707 .577 .707 r
F P
0 g
s
.32186 .56971 m .34137 .62357 L .36681 .61666 L p .707 .577 .707 r
F P
0 g
s
.81089 .54005 m .8304 .59391 L .81116 .59765 L p .707 .577 .707 r
F P
0 g
s
.81116 .59765 m .79165 .54379 L .81089 .54005 L p .707 .577 .707 r
F P
0 g
s
.39377 .68038 m .38983 .64313 L .35884 .6446 L p .707 .577 .707 r
F P
0 g
s
.38983 .64313 m .39377 .68038 L .42545 .67656 L p .707 .577 .707 r
F P
0 g
s
.42545 .67656 m .42151 .63931 L .38983 .64313 L p .707 .577 .707 r
F P
0 g
s
.65596 .59336 m .67547 .64722 L .65942 .65638 L p .707 .577 .707 r
F P
0 g
s
.42151 .63931 m .42545 .67656 L .4547 .67077 L p .707 .577 .707 r
F P
0 g
s
.4547 .67077 m .45076 .63351 L .42151 .63931 L p .707 .577 .707 r
F P
0 g
s
.64945 .689 m .64551 .65175 L .66185 .64385 L p .707 .577 .707 r
F P
0 g
s
.36278 .68185 m .35884 .6446 L .33156 .64359 L p .707 .577 .707 r
F P
0 g
s
.35884 .6446 m .36278 .68185 L .39377 .68038 L p .707 .577 .707 r
F P
0 g
s
.34137 .62357 m .32186 .56971 L .30262 .57344 L p .707 .577 .707 r
F P
0 g
s
.45754 .52014 m .47706 .574 L .49311 .56484 L p .707 .577 .707 r
F P
0 g
s
.49311 .56484 m .47359 .51098 L .45754 .52014 L p .707 .577 .707 r
F P
0 g
s
.45076 .63351 m .4547 .67077 L .47867 .66356 L p .707 .577 .707 r
F P
0 g
s
.47867 .66356 m .47473 .62631 L .45076 .63351 L p .707 .577 .707 r
F P
0 g
s
.66185 .64385 m .66579 .6811 L .64945 .689 L p .707 .577 .707 r
F P
0 g
s
.30262 .57344 m .32213 .6273 L .34137 .62357 L p .707 .577 .707 r
F P
0 g
s
.82592 .62999 m .82986 .66724 L .80896 .66383 L p .707 .577 .707 r
F P
0 g
s
.80896 .66383 m .80502 .62658 L .82592 .62999 L p .707 .577 .707 r
F P
0 g
s
.33156 .64359 m .3355 .68084 L .36278 .68185 L p .707 .577 .707 r
F P
0 g
s
.63137 .69993 m .63589 .68248 L .65211 .67632 L p .707 .577 .707 r
F P
0 g
s
.67547 .64722 m .65596 .59336 L .67908 .58252 L p .707 .577 .707 r
F P
0 g
s
.82423 .73036 m .81972 .7478 L .80781 .73449 L p .707 .577 .707 r
F P
0 g
s
.80781 .73449 m .81232 .71705 L .82423 .73036 L p .707 .577 .707 r
F P
0 g
s
.79165 .54379 m .81116 .59765 L .78572 .60455 L p .707 .577 .707 r
F P
0 g
s
.78572 .60455 m .7662 .55069 L .79165 .54379 L p .707 .577 .707 r
F P
0 g
s
.37242 .72382 m .37693 .70638 L .34671 .69689 L p .707 .577 .707 r
F P
0 g
s
.37693 .70638 m .37242 .72382 L .4034 .72989 L p .707 .577 .707 r
F P
0 g
s
.4034 .72989 m .40791 .71245 L .37693 .70638 L p .707 .577 .707 r
F P
0 g
s
.65211 .67632 m .64759 .69376 L .63137 .69993 L p .707 .577 .707 r
F P
0 g
s
.3355 .68084 m .33156 .64359 L .31067 .64018 L p .707 .577 .707 r
F P
0 g
s
.67908 .58252 m .6986 .63638 L .67547 .64722 L p .707 .577 .707 r
F P
0 g
s
.3422 .71434 m .34671 .69689 L .32021 .68491 L p .707 .577 .707 r
F P
0 g
s
.34671 .69689 m .3422 .71434 L .37242 .72382 L p .707 .577 .707 r
F P
0 g
s
.40791 .71245 m .4034 .72989 L .4321 .73195 L p .707 .577 .707 r
F P
0 g
s
.4321 .73195 m .43661 .7145 L .40791 .71245 L p .707 .577 .707 r
F P
0 g
s
.66579 .6811 m .66185 .64385 L .68582 .63665 L p .707 .577 .707 r
F P
0 g
s
.32213 .6273 m .30262 .57344 L .29147 .57365 L p .707 .577 .707 r
F P
0 g
s
.31067 .64018 m .31461 .67743 L .3355 .68084 L p .707 .577 .707 r
F P
0 g
s
.47473 .62631 m .47867 .66356 L .49501 .65566 L p .707 .577 .707 r
F P
0 g
s
.49501 .65566 m .49107 .61841 L .47473 .62631 L p .707 .577 .707 r
F P
0 g
s
.32021 .68491 m .31569 .70236 L .3422 .71434 L p .707 .577 .707 r
F P
0 g
s
.47359 .51098 m .49311 .56484 L .50051 .55826 L p .707 .577 .707 r
F P
0 g
s
.50051 .55826 m .481 .50441 L .47359 .51098 L p .707 .577 .707 r
F P
0 g
s
.6986 .63638 m .67908 .58252 L .70703 .57105 L p .707 .577 .707 r
F P
0 g
s
.29147 .57365 m .31098 .6275 L .32213 .6273 L p .707 .577 .707 r
F P
0 g
s
.68582 .63665 m .68976 .6739 L .66579 .6811 L p .707 .577 .707 r
F P
0 g
s
.80502 .62658 m .80896 .66383 L .78168 .66281 L p .707 .577 .707 r
F P
0 g
s
.78168 .66281 m .77774 .62556 L .80502 .62658 L p .707 .577 .707 r
F P
0 g
s
.31569 .70236 m .32021 .68491 L .30001 .67162 L p .707 .577 .707 r
F P
0 g
s
.7662 .55069 m .78572 .60455 L .75656 .61395 L p .707 .577 .707 r
F P
0 g
s
.75656 .61395 m .73704 .56009 L .7662 .55069 L p .707 .577 .707 r
F P
0 g
s
.43661 .7145 m .4321 .73195 L .45571 .72978 L p .707 .577 .707 r
F P
0 g
s
.45571 .72978 m .46023 .71234 L .43661 .7145 L p .707 .577 .707 r
F P
0 g
s
.64759 .69376 m .65211 .67632 L .67572 .67416 L p .707 .577 .707 r
F P
0 g
s
.70703 .57105 m .72654 .62491 L .6986 .63638 L p .707 .577 .707 r
F P
0 g
s
.81232 .71705 m .80781 .73449 L .78761 .72119 L p .707 .577 .707 r
F P
0 g
s
.78761 .72119 m .79212 .70375 L .81232 .71705 L p .707 .577 .707 r
F P
0 g
s
.30001 .67162 m .2955 .68906 L .31569 .70236 L p .707 .577 .707 r
F P
0 g
s
.31461 .67743 m .31067 .64018 L .2982 .63471 L p .707 .577 .707 r
F P
0 g
s
.72654 .62491 m .70703 .57105 L .73704 .56009 L p .707 .577 .707 r
F P
0 g
s
.73704 .56009 m .75656 .61395 L .72654 .62491 L p .707 .577 .707 r
F P
0 g
s
.67572 .67416 m .67121 .6916 L .64759 .69376 L p .707 .577 .707 r
F P
0 g
s
.68976 .6739 m .68582 .63665 L .71508 .63085 L p .707 .577 .707 r
F P
0 g
s
.77774 .62556 m .78168 .66281 L .75069 .66428 L p .707 .577 .707 r
F P
0 g
s
.75069 .66428 m .74675 .62703 L .77774 .62556 L p .707 .577 .707 r
F P
0 g
s
.2982 .63471 m .30214 .67196 L .31461 .67743 L p .707 .577 .707 r
F P
0 g
s
.49107 .61841 m .49501 .65566 L .50213 .64783 L p .707 .577 .707 r
F P
0 g
s
.50213 .64783 m .49819 .61058 L .49107 .61841 L p .707 .577 .707 r
F P
0 g
s
.71508 .63085 m .71902 .66811 L .68976 .6739 L p .707 .577 .707 r
F P
0 g
s
.2955 .68906 m .30001 .67162 L .2881 .6583 L p .707 .577 .707 r
F P
0 g
s
.71902 .66811 m .71508 .63085 L .74675 .62703 L p .707 .577 .707 r
F P
0 g
s
.31098 .6275 m .29147 .57365 L .28949 .57029 L p .707 .577 .707 r
F P
0 g
s
.46023 .71234 m .45571 .72978 L .47193 .72362 L p .707 .577 .707 r
F P
0 g
s
.47193 .72362 m .47644 .70618 L .46023 .71234 L p .707 .577 .707 r
F P
0 g
s
.74675 .62703 m .75069 .66428 L .71902 .66811 L p .707 .577 .707 r
F P
0 g
s
.67121 .6916 m .67572 .67416 L .70442 .67621 L p .707 .577 .707 r
F P
0 g
s
.79212 .70375 m .78761 .72119 L .7611 .70921 L p .707 .577 .707 r
F P
0 g
s
.7611 .70921 m .76562 .69177 L .79212 .70375 L p .707 .577 .707 r
F P
0 g
s
.481 .50441 m .50051 .55826 L .49854 .55491 L p .707 .577 .707 r
F P
0 g
s
.49854 .55491 m .47903 .50105 L .481 .50441 L p .707 .577 .707 r
F P
0 g
s
.2881 .6583 m .28359 .67574 L .2955 .68906 L p .707 .577 .707 r
F P
0 g
s
.28949 .57029 m .30901 .62415 L .31098 .6275 L p .707 .577 .707 r
F P
0 g
s
.70442 .67621 m .69991 .69365 L .67121 .6916 L p .707 .577 .707 r
F P
0 g
s
.30214 .67196 m .2982 .63471 L .29539 .62772 L p .707 .577 .707 r
F P
0 g
s
.69991 .69365 m .70442 .67621 L .7354 .68228 L p .707 .577 .707 r
F P
0 g
s
.76562 .69177 m .7611 .70921 L .73088 .69972 L p .707 .577 .707 r
F P
0 g
s
.73088 .69972 m .7354 .68228 L .76562 .69177 L p .707 .577 .707 r
F P
0 g
s
.7354 .68228 m .73088 .69972 L .69991 .69365 L p .707 .577 .707 r
F P
0 g
s
.29539 .62772 m .29933 .66497 L .30214 .67196 L p .707 .577 .707 r
F P
0 g
s
.28359 .67574 m .2881 .6583 L .28564 .64627 L p .707 .577 .707 r
F P
0 g
s
.49819 .61058 m .50213 .64783 L .49931 .64084 L p .707 .577 .707 r
F P
0 g
s
.49931 .64084 m .49537 .60359 L .49819 .61058 L p .707 .577 .707 r
F P
0 g
s
.47644 .70618 m .47193 .72362 L .47916 .71405 L p .707 .577 .707 r
F P
0 g
s
.47916 .71405 m .48368 .69661 L .47644 .70618 L p .707 .577 .707 r
F P
0 g
s
.28564 .64627 m .28113 .66371 L .28359 .67574 L p .707 .577 .707 r
F P
0 g
s
.30901 .62415 m .28949 .57029 L .2969 .56372 L p .707 .577 .707 r
F P
0 g
s
.47903 .50105 m .49854 .55491 L .48739 .55512 L p .707 .577 .707 r
F P
0 g
s
.48739 .55512 m .46788 .50126 L .47903 .50105 L p .707 .577 .707 r
F P
0 g
s
.2969 .56372 m .31641 .61758 L .30901 .62415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29933 .66497 m .29539 .62772 L .3025 .61989 L p .707 .577 .707 r
F P
0 g
s
.3025 .61989 m .30644 .65714 L .29933 .66497 L p .707 .577 .707 r
F P
0 g
s
.28113 .66371 m .28564 .64627 L .29288 .6367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48368 .69661 m .47916 .71405 L .47671 .70202 L p .707 .577 .707 r
F P
0 g
s
.47671 .70202 m .48122 .68458 L .48368 .69661 L p .707 .577 .707 r
F P
0 g
s
.49537 .60359 m .49931 .64084 L .48685 .63537 L p .707 .577 .707 r
F P
0 g
s
.48685 .63537 m .48291 .59812 L .49537 .60359 L p .707 .577 .707 r
F P
0 g
s
.29288 .6367 m .28836 .65414 L .28113 .66371 L p .707 .577 .707 r
F P
0 g
s
.31641 .61758 m .2969 .56372 L .31295 .55456 L p .707 .577 .707 r
F P
0 g
s
.46788 .50126 m .48739 .55512 L .46815 .55885 L p .707 .577 .707 r
F P
0 g
s
.46815 .55885 m .44864 .50499 L .46788 .50126 L p .707 .577 .707 r
F P
0 g
s
.31295 .55456 m .33246 .60842 L .31641 .61758 L p .707 .577 .707 r
F P
0 g
s
.30644 .65714 m .3025 .61989 L .31884 .61198 L p .707 .577 .707 r
F P
0 g
s
.28836 .65414 m .29288 .6367 L .30909 .63054 L p .707 .577 .707 r
F P
0 g
s
.31884 .61198 m .32278 .64923 L .30644 .65714 L p .707 .577 .707 r
F P
0 g
s
.48122 .68458 m .47671 .70202 L .46479 .6887 L p .707 .577 .707 r
F P
0 g
s
.46479 .6887 m .46931 .67126 L .48122 .68458 L p .707 .577 .707 r
F P
0 g
s
.48291 .59812 m .48685 .63537 L .46595 .63196 L p .707 .577 .707 r
F P
0 g
s
.46595 .63196 m .46201 .59471 L .48291 .59812 L p .707 .577 .707 r
F P
0 g
s
.33246 .60842 m .31295 .55456 L .33607 .54372 L p .707 .577 .707 r
F P
0 g
s
.30909 .63054 m .30458 .64798 L .28836 .65414 L p .707 .577 .707 r
F P
0 g
s
.44864 .50499 m .46815 .55885 L .44271 .56575 L p .707 .577 .707 r
F P
0 g
s
.44271 .56575 m .42319 .51189 L .44864 .50499 L p .707 .577 .707 r
F P
0 g
s
.33607 .54372 m .35559 .59758 L .33246 .60842 L p .707 .577 .707 r
F P
0 g
s
.32278 .64923 m .31884 .61198 L .34281 .60478 L p .707 .577 .707 r
F P
0 g
s
.35559 .59758 m .33607 .54372 L .36401 .53226 L p .707 .577 .707 r
F P
0 g
s
.42319 .51189 m .44271 .56575 L .41355 .57515 L p .707 .577 .707 r
F P
0 g
s
.41355 .57515 m .39403 .52129 L .42319 .51189 L p .707 .577 .707 r
F P
0 g
s
.34281 .60478 m .34675 .64203 L .32278 .64923 L p .707 .577 .707 r
F P
0 g
s
.46201 .59471 m .46595 .63196 L .43867 .63094 L p .707 .577 .707 r
F P
0 g
s
.43867 .63094 m .43473 .59369 L .46201 .59471 L p .707 .577 .707 r
F P
0 g
s
.30458 .64798 m .30909 .63054 L .33271 .62837 L p .707 .577 .707 r
F P
0 g
s
.46931 .67126 m .46479 .6887 L .4446 .67541 L p .707 .577 .707 r
F P
0 g
s
.4446 .67541 m .44911 .65796 L .46931 .67126 L p .707 .577 .707 r
F P
0 g
s
.36401 .53226 m .38353 .58611 L .35559 .59758 L p .707 .577 .707 r
F P
0 g
s
.33271 .62837 m .3282 .64582 L .30458 .64798 L p .707 .577 .707 r
F P
0 g
s
.38353 .58611 m .36401 .53226 L .39403 .52129 L p .707 .577 .707 r
F P
0 g
s
.39403 .52129 m .41355 .57515 L .38353 .58611 L p .707 .577 .707 r
F P
0 g
s
.34675 .64203 m .34281 .60478 L .37207 .59899 L p .707 .577 .707 r
F P
0 g
s
.43473 .59369 m .43867 .63094 L .40768 .63242 L p .707 .577 .707 r
F P
0 g
s
.40768 .63242 m .40374 .59517 L .43473 .59369 L p .707 .577 .707 r
F P
0 g
s
.37207 .59899 m .376 .63624 L .34675 .64203 L p .707 .577 .707 r
F P
0 g
s
.3282 .64582 m .33271 .62837 L .36141 .63043 L p .707 .577 .707 r
F P
0 g
s
.376 .63624 m .37207 .59899 L .40374 .59517 L p .707 .577 .707 r
F P
0 g
s
.44911 .65796 m .4446 .67541 L .41809 .66343 L p .707 .577 .707 r
F P
0 g
s
.41809 .66343 m .42261 .64598 L .44911 .65796 L p .707 .577 .707 r
F P
0 g
s
.40374 .59517 m .40768 .63242 L .376 .63624 L p .707 .577 .707 r
F P
0 g
s
.36141 .63043 m .3569 .64787 L .3282 .64582 L p .707 .577 .707 r
F P
0 g
s
.3569 .64787 m .36141 .63043 L .39239 .6365 L p .707 .577 .707 r
F P
0 g
s
.42261 .64598 m .41809 .66343 L .38787 .65394 L p .707 .577 .707 r
F P
0 g
s
.38787 .65394 m .39239 .6365 L .42261 .64598 L p .707 .577 .707 r
F P
0 g
s
.39239 .6365 m .38787 .65394 L .3569 .64787 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo0024Ool60003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001fOol007ioo`H000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@0079oo`00N7oo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000KWoo001bOol60008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH2001/Ool006ioo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJ
EP8006Yoo`00JWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH02eYF00<007ooOol0J7oo001XOol200000eYF001JEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH2001YOol006Io
o`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00YJEP8006Uoo`00I7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02UYF0P00JGoo001SOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1WOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1WOol0065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0
065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH20003FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP02
001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF008006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYF001JEP02001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEP00FUH00P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF008006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYFFUH005YFIGoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Hgoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF1`002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH00UYF100045YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF1@0000=JEP00FUH0
15YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00AJEP<000IJEP03001JEUYF009J
EP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00
FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06=oo`00IWoo00@005YFFUH000EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEP00FUH005YF06Aoo`00IWoo00@005YFFUH0009JEP<00003FUH005YF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH200001EYF001JEP00FUH0I7oo001VOol00`00FUIJEP030005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF001JEP00FUITOol006Ioo`<000QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00Oomoo`1ROol006Aoo`800003FUH005YF00QJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001oogoo069oo`00HGoo0`0015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
02Uoo`H003=oo`00GWoo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo02Eoo`@0009JEP05001JEUYFFUH0000bOol005aoo`800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo025oo`@00003FUH005YF00AJEP04001JEUYF000bOol005Yoo`8000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000NOol40006FUH0
0`00FUIJEP02FUH00`00FUIJEP02000aOol005Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001aoo`800003FUH005YF00MJEP03001JEUYF00=J
EP04001JEUYF000aOol005Moo`8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000IOol30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo001EOol20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000FOol30007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIJEP02000`Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`<00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP04
001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000@Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<7oo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000P001EYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P003Goo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH002moo`00DWoo00@005YFFUH000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000QJEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8000=JEP8000]oo`800003FUH005YF00UJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool0059oo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF009J
EP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20009Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00Aoo`<000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`04001JEUYF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP05FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`02Ool200000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo001DOol00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`020004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo001DOol01000FUIJEP0015YF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH0
1EYF200025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUIJEPH002eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00IJEP8000MJEPT000AJ
EP04001JEUYFFUH70002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1@000UYF00@005YFFUH002eoo`00Dgoo0`0000=JEP00FUH015YF00<005YFFUH00eYF
0P0000=JEP0000001P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00=J
EP8002ioo`00D7oo0`000UYF00@005YFFUH000AJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool004ioo`800003FUH0
05YF009JEP04001JEUYF0005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00<005YFFUH01EYF00D005YFFUIJEP00031oo`00Bgoo0`0015YF00L005YFFUIJ
EP00FUH00003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YF00000P0015YF00<005YFFUH01UYF0`00<Goo0018Ool30007FUH01@00FUIJEUYF00000UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000QJEP03001JEUYF00AJ
EP8003=oo`00AGoo0`0000=JEP00FUH01eYF00@005YFFUIJEP<00003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000eOol0049oo`<000EJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF00IJEP04001JEP00000g
Ool003moo`<000QJEP03001JEUYF00IJEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40008FUH;000iOol003eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPT000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH90004FUH01000FUIJEUYF1P00=Woo
000jOol30004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP050003FUH01000FUIJEUYF
1`0000=JEP00FUH00eYF60000eYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00D0035oo`00=goo0`001eYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH02P002EYF1P0015YF1@000UYF
0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YF00000P00;Woo000eOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH?0004FUH00`00FUIJ
EP04FUH01000FUIJEUYF10001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0035oo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000=J
EP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH500001EYF000005YF00000UYF2@0015YF00<005YFFUH01eYF0`00
1EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002io
o`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00800003FUH0
0000009JEP04001JEP000003FUH00`00FUIJEP05FUH01000FUIJEUYF1P001eYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00<00004FUH0
05YFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH00eYF
0P000UYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUH00006FUH0
1000FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00:goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP800003FUH0000000800005FUH005YFFUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20008FUH30005FUH3000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000[Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF0P001UYF00<005YFFUH01@000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH015YF2@002Woo1@001EYF10000eYF0P00;7oo000[Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0`000eYF00<005YF
FUH00eYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001Goo3P000eYF00<005YFFUH015YF00@0
05YFFUIJEP800003FUH0000002aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008000EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP80009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH;0004
Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000/Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH20008FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70002FUH20006FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP050003
FUH01000FUIJEUYF200015YF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF
0`00;7oo000]Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH01000FUIJEP0015YF0P0000=oo`0000005P002EYF00@005YF000000=JEP06001JEUYF001JEP00
35YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH0100000=JEP0000000P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000;7oo000]Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01eYF0`001UYF00<007ooOol037oo00<005YFFUH01`002EYF00@005YF
FUIJEP800003FUH005YF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00;Goo00@005YFFUH000AJEP03001JEUYF00IJ
EP04001JEP000005FUH>0006FUH4000;Ool00`00FUIJEP070009FUH00`00FUIJEP03FUH20003FUH0
0`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH300000eYF
000000040004FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF1P001Woo00<005YFFUH01`002EYF
00<005YFFUH01EYF00H005YFFUH005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJ
EUYF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP04FUH01000FUH00000<7oo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF1P0000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP<00003FUH0000000Ao
o`05001JEUYF001JEP0300000eYF001JEP09FUH00`00FUIJEP04FUH01000FUH005YF0P002eYF00<0
05YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP8000=JEPD000=JEP03001JEUYF00T000AJEP03
001JEUYF00MJEP<000IJEP03001JEUYF00=JEP<0039oo`00;Woo00@005YFFUH000EJEP03001JEP00
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH40004Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00@005YFFUIJEP800004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP060008FUH00`00FUIJEP020004FUH00`00FUH00003000eOol002moo`03001JEP0000=J
EP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00@00005Ool005YFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00D005YFFUH005YF00800003FUH00000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP800004
FUH00000000iOol002moo`04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH200000eYF0000000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP020003
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0300000eYF001J
EP06FUH2000kOol002moo`03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00MJEP03001JEP0000<000=JEP03001JEUYF
00MJEP03001JEUYF00=JEP800005FUH00000FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
1000FUIJEP0015YF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0025YF0`00>Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP04FUH70006FUH0
0`00FUH000030003FUH200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJ
EP0015YF00<005YFFUH00UYF6`000goo0P001EYF00@005YFFUIJEP8003Moo`00;Goo0`000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`001eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUH000AJEP03001JEUYF009JEP8001Ao
o`<000Moo`8000=JEP03001JEUYF00=JEP03001oogoo03Aoo`00;7oo00@005YFFUH000=JEPT000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5000@Ool50008Ool3
0006FUH2000eOol002aoo`03001JEUYF00D000=JEP04001JEUYFFUH700000eYF001JEP07FUH00`00
FUIJEP02FUH?0003FUH00`00FUIJEP060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF1@002goo1@002Woo00<005YFFUH015YF00<005YF0000=7oo000/Ool00`00
FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH90004Ool60004FUH50002FUH20003
Ool00eYF000000020002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001EYF
00<005YF00000P0027oo1@002goo0P000eYF00D005YFFUIJEP0003=oo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1P000Woo1`0015YF00<005YFFUH015YF00@005YF
FUIJEP@000=oo`05001JEUYF001JEP060004FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00D005YFFUIJ
EP0000Uoo`<000ioo`800003FUH005YF00=JEP03001oogoo031oo`00:goo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF0`000goo00@005YFFUH000EJEP03001JEP0000P000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00YJEP<000AJEP04001JEUYFFUH2000KOol2
0004FUH00`00Oomoo`0`Ool002Yoo`8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH00P000UYF00@005YFFUIJEP8001eoo`03001JEUYF0080039oo`00:Woo
0P000UYF1@0000EJEP00001JEP00009JEPL000IJEP03001JEUYF00MJEP<000EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP03
FUH30003FUH2000MOol00`00FUIJEP02000bOol002Uoo`800003FUH00000009JEP04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0P0017oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF015JEP<00003FUH0
000001ioo`800003FUH007oo035oo`00:Goo0`0000Aoo`00FUIJEP<000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP@000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP05001JEUYFFUH00005
Ool01000FUIJEP0045YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH04UYF00<005YF00000`007Woo00<005YF0000<Woo000XOol30003Ool01000FUH0
00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<0
05YF00001UYF00@005YF000000Ioo`04001JEUYF000@FUH00`00FUIJEP09FUH00`00FUIJEP04FUHN
000<FUH00`00FUIJEP04FUH00`00FUIJEP04FUH5000IOol00`00FUH0000bOol002Qoo`04001JEP00
0002Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0008FUH30005FUH30008Ool01000FUIJEP0045YF00<005YFFUH01eYF2@002UYF0P002eYF00<005YF
FUH01EYF0P002UYF0P0015YF00<005YFFUH01UYF00<005YFFUH010004goo1000<goo000XOol01`00
FUH005YF001oo`0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00EJEP8000IJEP03001JEUYF00D000]oo`04001JEUYF000@FUH01000FUIJEUYF1P0025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00H005YF000005YF0009
FUH00`00FUIJEP04FUH60008Ool50002FUH2000cOol002Qoo`03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF009J
EP8000eoo`03001JEUYF011JEPD00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH01000
FUIJEUYF20000eYF00H005YFFUH005YF000cOol002Uoo`03001JEUYF009JEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00EJEP03001oogoo00Yoo`03001JEUYF00eJEP<000IJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
0003FUH005YF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP04001JEUYF
FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000dOol0
02Uoo`03001JEUYF009JEPL000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL0
009oo`8000IJEP8000]oo`03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001JEUYF00EJEP04
001JEUYFFUH70005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=Goo000ZOol01@00FUIJEUYF0000
0UYF0P000Woo1`0015YF00<005YFFUH00UYF20002goo0P0015YF00<005YF00002goo2EYF0P000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01000
00=JEP00FUH025YF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YF000017oo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000003Ioo`00:goo00<005YF00001EYF0P001goo
2@000Woo1@003Woo00@005YFFUH000=JEP03001oogoo00Qoo`MJEP8000AJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF009JEP8000Uoo`H000AJEP04001JEUYFFUH5000h
Ool002aoo`8000IJEP<0011oo`D000moo`<000=JEP03001oogoo00Qoo`EJEP8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH2000@Ool8000mOol002eoo`03001J
EUYF00=JEP04001JEUYFFUH2000>Ool5000AOol01@00FUIJEUYF00002Woo0eYF0P0025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH00eYF100015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF0P001EYF00@005YF000005Moo`00;Woo0P000eYF00<005YFFUH00eYF0P003Goo
0`004goo00D005YF001JEP0000Uoo`9JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00MJEPL000QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000AJEP<005Uoo`00<7oo
0`0025YF0P008Woo0P0000=JEP00Ool027oo00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00@005YFFUIJEP@0009JEP03001JEP0000UJEP03001J
EUYF00=JEP800003FUH00000008005aoo`00<Woo00<005YFFUH01UYF00<005YF00000P0087oo00<0
05YF00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1@002EYF00@005YFFUIJEPD0061oo`00<goo0P001UYF00<005YFFUH00UYF
0`0077oo0P0000=JEP00Ool027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00D005YF000005YF0080069oo`00=Goo0P00
0eYF00<005YFFUH01UYF1@005Goo0P0000=JEP0000002goo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0`0015YF0P00HGoo000gOol200000eYF001JEP07FUH00`00FUIJEP02FUH90008Ool40003FUH2000;
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP02001OOol003Uoo`<000MJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP07001JEUYFFUH005YF00003Goo0P0000=JEP00FUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`0017oo
0P000eYF00<005YFFUH00UYF00<007ooOol0G7oo000lOol40002FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0047oo0`001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1@002Goo0`001UYF00<007ooOol0Fgoo0010Ool50006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0057oo10000UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P0000=oo`0000000`002Woo00<005YFFUH0
15YF0P00G7oo0015Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000006Woo2000
1EYF00<005YFFUH02UYF00<005YFFUH015YF2@001goo1@002goo0P0015YF00@005YF000005Yoo`00
BGoo1P0015YF00@005YFFUIJEPD002AooaT0011oo`D000eoo`04001JEUYF0004FUH00`00Oomoo`1G
Ool004moo`P003Ioo`8000IJEP<0019oo`<000moo`<000AJEP03001oogoo05Moo`00SWoo00<005YF
FUH015YF00<005YFFUH00P0097oo00@005YFFUIJEP8005Uoo`00Sgoo0P000eYF00<005YFFUH00eYF
0P008goo00<005YFFUH00P00FGoo002AOol200000eYF001JEP06FUH3000QOol200000eYF001oo`1H
Ool009=oo`8000QJEP04001JEP00000POol00`00FUH0001IOol009Eoo`8000EJEP03001JEUYF009J
EP<001eoo`03001JEP0005Uoo`00Ugoo0P000eYF00<005YFFUH01EYF1P005Goo1000FWoo002IOol3
0009FUH00`00FUIJEP02FUH80008Ool50002FUH2001JOol009]oo`<000IJEP03001JEUYF00MJEP04
001JEUYFFUH80003FUH01P00FUIJEP00FUH005Yoo`00WWoo10000UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P00Fgoo002ROol50006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000G7oo002WOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH00000GGoo002[Ool60004FUH01000FUIJEUYF1@00Ggoo002aOol8001TOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60178 .73811 m .58226 .68425 L .55311 .69364 L p .707 .577 .707 r
F P
0 g
s
.58226 .68425 m .60178 .73811 L .6318 .72714 L p .707 .577 .707 r
F P
0 g
s
.6318 .72714 m .61228 .67328 L .58226 .68425 L p .707 .577 .707 r
F P
0 g
s
.61228 .67328 m .6318 .72714 L .65974 .71567 L p .707 .577 .707 r
F P
0 g
s
.65974 .71567 m .64022 .66182 L .61228 .67328 L p .707 .577 .707 r
F P
0 g
s
.55311 .69364 m .57262 .7475 L .60178 .73811 L p .707 .577 .707 r
F P
0 g
s
.57262 .7475 m .55311 .69364 L .52766 .70054 L p .707 .577 .707 r
F P
0 g
s
.64022 .66182 m .65974 .71567 L .68286 .70483 L p .707 .577 .707 r
F P
0 g
s
.68286 .70483 m .66335 .65097 L .64022 .66182 L p .707 .577 .707 r
F P
0 g
s
.52766 .70054 m .54717 .7544 L .57262 .7475 L p .707 .577 .707 r
F P
0 g
s
.59958 .80429 m .59564 .76703 L .56465 .76851 L p .707 .577 .707 r
F P
0 g
s
.59564 .76703 m .59958 .80429 L .63125 .80046 L p .707 .577 .707 r
F P
0 g
s
.63125 .80046 m .62731 .76321 L .59564 .76703 L p .707 .577 .707 r
F P
0 g
s
.62731 .76321 m .63125 .80046 L .66051 .79467 L p .707 .577 .707 r
F P
0 g
s
.66051 .79467 m .65657 .75742 L .62731 .76321 L p .707 .577 .707 r
F P
0 g
s
.56859 .80576 m .56465 .76851 L .53737 .76749 L p .707 .577 .707 r
F P
0 g
s
.56465 .76851 m .56859 .80576 L .59958 .80429 L p .707 .577 .707 r
F P
0 g
s
.54717 .7544 m .52766 .70054 L .50842 .70428 L p .707 .577 .707 r
F P
0 g
s
.66335 .65097 m .68286 .70483 L .69891 .69568 L p .707 .577 .707 r
F P
0 g
s
.69891 .69568 m .6794 .64182 L .66335 .65097 L p .707 .577 .707 r
F P
0 g
s
.65657 .75742 m .66051 .79467 L .68448 .78747 L p .707 .577 .707 r
F P
0 g
s
.68448 .78747 m .68054 .75022 L .65657 .75742 L p .707 .577 .707 r
F P
0 g
s
.53737 .76749 m .54131 .80474 L .56859 .80576 L p .707 .577 .707 r
F P
0 g
s
.50842 .70428 m .52794 .75814 L .54717 .7544 L p .707 .577 .707 r
F P
0 g
s
.54131 .80474 m .53737 .76749 L .51647 .76408 L p .707 .577 .707 r
F P
0 g
s
.57823 .86164 m .58274 .8442 L .55252 .83471 L p .707 .577 .707 r
F P
0 g
s
.58274 .8442 m .57823 .86164 L .6092 .86771 L p .707 .577 .707 r
F P
0 g
s
.6092 .86771 m .61372 .85027 L .58274 .8442 L p .707 .577 .707 r
F P
0 g
s
.54801 .85215 m .55252 .83471 L .52601 .82273 L p .707 .577 .707 r
F P
0 g
s
.55252 .83471 m .54801 .85215 L .57823 .86164 L p .707 .577 .707 r
F P
0 g
s
.61372 .85027 m .6092 .86771 L .6379 .86976 L p .707 .577 .707 r
F P
0 g
s
.6379 .86976 m .64242 .85232 L .61372 .85027 L p .707 .577 .707 r
F P
0 g
s
.51647 .76408 m .52041 .80133 L .54131 .80474 L p .707 .577 .707 r
F P
0 g
s
.68054 .75022 m .68448 .78747 L .70082 .77957 L p .707 .577 .707 r
F P
0 g
s
.70082 .77957 m .69688 .74232 L .68054 .75022 L p .707 .577 .707 r
F P
0 g
s
.52794 .75814 m .50842 .70428 L .49727 .70448 L p .707 .577 .707 r
F P
0 g
s
.52601 .82273 m .5215 .84017 L .54801 .85215 L p .707 .577 .707 r
F P
0 g
s
.6794 .64182 m .69891 .69568 L .70632 .6891 L p .707 .577 .707 r
F P
0 g
s
.70632 .6891 m .6868 .63524 L .6794 .64182 L p .707 .577 .707 r
F P
0 g
s
.49727 .70448 m .51678 .75834 L .52794 .75814 L p .707 .577 .707 r
F P
0 g
s
.5215 .84017 m .52601 .82273 L .50582 .80943 L p .707 .577 .707 r
F P
0 g
s
.64242 .85232 m .6379 .86976 L .66152 .8676 L p .707 .577 .707 r
F P
0 g
s
.66152 .8676 m .66603 .85016 L .64242 .85232 L p .707 .577 .707 r
F P
0 g
s
.52041 .80133 m .51647 .76408 L .50401 .75861 L p .707 .577 .707 r
F P
0 g
s
.50582 .80943 m .5013 .82688 L .5215 .84017 L p .707 .577 .707 r
F P
0 g
s
.50401 .75861 m .50795 .79586 L .52041 .80133 L p .707 .577 .707 r
F P
0 g
s
.69688 .74232 m .70082 .77957 L .70793 .77174 L p .707 .577 .707 r
F P
0 g
s
.70793 .77174 m .70399 .73449 L .69688 .74232 L p .707 .577 .707 r
F P
0 g
s
.51678 .75834 m .49727 .70448 L .4953 .70113 L p .707 .577 .707 r
F P
0 g
s
.5013 .82688 m .50582 .80943 L .49391 .79612 L p .707 .577 .707 r
F P
0 g
s
.66603 .85016 m .66152 .8676 L .67774 .86144 L p .707 .577 .707 r
F P
0 g
s
.67774 .86144 m .68225 .844 L .66603 .85016 L p .707 .577 .707 r
F P
0 g
s
.6868 .63524 m .70632 .6891 L .70434 .68575 L p .707 .577 .707 r
F P
0 g
s
.70434 .68575 m .68483 .63189 L .6868 .63524 L p .707 .577 .707 r
F P
0 g
s
.4953 .70113 m .51481 .75499 L .51678 .75834 L p .707 .577 .707 r
F P
0 g
s
.49391 .79612 m .48939 .81356 L .5013 .82688 L p .707 .577 .707 r
F P
0 g
s
.50795 .79586 m .50401 .75861 L .50119 .75162 L p .707 .577 .707 r
F P
0 g
s
.51481 .75499 m .4953 .70113 L .5027 .69456 L p .707 .577 .707 r
F P
0 g
s
.5027 .69456 m .52222 .74841 L .51481 .75499 L p .707 .577 .707 r
F P
0 g
s
.50119 .75162 m .50513 .78887 L .50795 .79586 L p .707 .577 .707 r
F P
0 g
s
.50513 .78887 m .50119 .75162 L .50831 .74379 L p .707 .577 .707 r
F P
0 g
s
.50831 .74379 m .51225 .78104 L .50513 .78887 L p .707 .577 .707 r
F P
0 g
s
.52222 .74841 m .5027 .69456 L .51875 .6854 L p .707 .577 .707 r
F P
0 g
s
.51875 .6854 m .53827 .73926 L .52222 .74841 L p .707 .577 .707 r
F P
0 g
s
.51225 .78104 m .50831 .74379 L .52465 .73589 L p .707 .577 .707 r
F P
0 g
s
.49417 .79196 m .49868 .77452 L .5149 .76836 L p .707 .577 .707 r
F P
0 g
s
.5149 .76836 m .51039 .7858 L .49417 .79196 L p .707 .577 .707 r
F P
0 g
s
.52465 .73589 m .52859 .77314 L .51225 .78104 L p .707 .577 .707 r
F P
0 g
s
.53827 .73926 m .51875 .6854 L .54188 .67456 L p .707 .577 .707 r
F P
0 g
s
.54188 .67456 m .56139 .72842 L .53827 .73926 L p .707 .577 .707 r
F P
0 g
s
.52859 .77314 m .52465 .73589 L .54862 .72869 L p .707 .577 .707 r
F P
0 g
s
.51039 .7858 m .5149 .76836 L .53075 .76691 L p .707 .577 .707 r
F P
0 g
s
.54862 .72869 m .55256 .76594 L .52859 .77314 L p .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .55991 .81633 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53075 .76691 m .53843 .7662 L p .5289 .7729 L .707 .577 .707 r
F P
0 g
s
.5289 .7729 m .53843 .7662 L .53839 .76628 L .707 .577 .707 r
F
.51039 .7858 m .53075 .76691 L .5289 .7729 L F
.51492 .8182 m .51508 .82043 L p .54815 .74469 L F P
0 g
s
.53852 .76619 m .534 .78364 L .51039 .7858 L p .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .51492 .8182 L p .54815 .74469 L .707 .577 .707 r
F P
0 g
s
.53843 .7662 m .53852 .76619 L p .53839 .76628 L .707 .577 .707 r
F P
0 g
s
.47779 .31603 m .43391 .31667 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51508 .82043 m .51492 .8182 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.51492 .8182 m .47779 .31603 L p .51479 .81861 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .54188 .67456 L .55517 .66911 L p .707 .577 .707 r
F P
0 g
s
.55517 .66911 m .56982 .66309 L p .56728 .68279 L .707 .577 .707 r
F P
0 g
s
.56139 .72842 m .55517 .66911 L .56728 .68279 L .707 .577 .707 r
F
.52263 .31193 m .47779 .31603 L p .53133 .64217 L F P
0 g
s
.56982 .66309 m .58933 .71695 L .56139 .72842 L p .707 .577 .707 r
F P
0 g
s
.55256 .76594 m .54862 .72869 L .57787 .72289 L p .707 .577 .707 r
F P
0 g
s
.57787 .72289 m .58181 .76014 L .55256 .76594 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .54847 .66154 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.54847 .66154 m .52263 .31193 L p .53133 .64217 L .707 .577 .707 r
F P
0 g
s
.58933 .71695 m .57714 .68329 L p .59984 .65213 L .707 .577 .707 r
F P
0 g
s
.57714 .68329 m .56982 .66309 L .57935 .65961 L p .707 .577 .707 r
F P
0 g
s
.57935 .65961 m .59984 .65213 L p .57714 .68329 L .707 .577 .707 r
F P
0 g
s
.629 .64273 m .64851 .69659 L .61935 .70598 L p .707 .577 .707 r
F P
0 g
s
.61935 .70598 m .59984 .65213 L .629 .64273 L p .707 .577 .707 r
F P
0 g
s
.59984 .65213 m .61935 .70598 L .58933 .71695 L p .707 .577 .707 r
F P
0 g
s
.64054 .7176 m .64448 .75485 L .61349 .75632 L p .707 .577 .707 r
F P
0 g
s
.61349 .75632 m .60955 .71907 L .64054 .7176 L p .707 .577 .707 r
F P
0 g
s
.58181 .76014 m .57787 .72289 L .60955 .71907 L p .707 .577 .707 r
F P
0 g
s
.60955 .71907 m .61349 .75632 L .58181 .76014 L p .707 .577 .707 r
F P
0 g
s
.65492 .79578 m .6504 .81323 L .6239 .80125 L p .707 .577 .707 r
F P
0 g
s
.6239 .80125 m .62841 .7838 L .65492 .79578 L p .707 .577 .707 r
F P
0 g
s
.62841 .7838 m .6239 .80125 L .59725 .79288 L p .707 .577 .707 r
F P
0 g
s
.55991 .81633 m .59986 .80943 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.58985 .77268 m .59819 .77432 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.55148 .70221 m .55991 .81633 L p .59579 .7836 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .5627 .78569 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59819 .77432 m .59579 .7836 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59579 .7836 m .59368 .79176 L p .59185 .77635 L .707 .577 .707 r
F P
0 g
s
.59368 .79176 m .59819 .77432 L .62841 .7838 L p .707 .577 .707 r
F P
0 g
s
.52263 .31193 m .52368 .32625 L p .59778 .78725 L .707 .577 .707 r
F P
0 g
s
.59696 .79101 m .62841 .7838 L .59725 .79288 L .707 .577 .707 r
F
.60131 .80918 m .59786 .78739 L .59778 .78725 L F
.59786 .78739 m .52263 .31193 L .59778 .78725 L F
.52368 .32625 m .55148 .70221 L p .59579 .7836 L F P
0 g
s
.5627 .78569 m .56722 .76825 L .58985 .77268 L p .707 .577 .707 r
F P
0 g
s
.5627 .78569 m .58985 .77268 L .59185 .77635 L .707 .577 .707 r
F
.59725 .79288 m .59368 .79176 L p .59696 .79101 L F P
0 g
s
.59986 .80943 m .60131 .80918 L p .52368 .32625 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .63521 .79968 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.56402 .30479 m .58544 .59455 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.58544 .59455 m .60131 .80918 L p .59342 .50921 L .707 .577 .707 r
F P
0 g
s
.60131 .80918 m .56402 .30479 L .52263 .31193 L p .707 .577 .707 r
F P
0 g
s
.70399 .73449 m .70793 .77174 L .70512 .76475 L p .707 .577 .707 r
F P
0 g
s
.70512 .76475 m .70118 .72749 L .70399 .73449 L p .707 .577 .707 r
F P
0 g
s
.48939 .81356 m .49391 .79612 L .49145 .78409 L p .707 .577 .707 r
F P
0 g
s
.68225 .844 m .67774 .86144 L .68497 .85187 L p .707 .577 .707 r
F P
0 g
s
.68497 .85187 m .68948 .83443 L .68225 .844 L p .707 .577 .707 r
F P
0 g
s
.47119 .82107 m .43391 .31667 L .39527 .31379 L p .707 .577 .707 r
F P
0 g
s
.49145 .78409 m .48693 .80153 L .48939 .81356 L p .707 .577 .707 r
F P
0 g
s
.48693 .80153 m .49145 .78409 L .49868 .77452 L p .707 .577 .707 r
F P
0 g
s
.49868 .77452 m .49417 .79196 L .48693 .80153 L p .707 .577 .707 r
F P
0 g
s
.43391 .31667 m .47119 .82107 L .51508 .82043 L p .707 .577 .707 r
F P
0 g
s
.68483 .63189 m .70434 .68575 L .69319 .68595 L p .707 .577 .707 r
F P
0 g
s
.69319 .68595 m .67368 .63209 L .68483 .63189 L p .707 .577 .707 r
F P
0 g
s
.63521 .79968 m .59792 .29528 L .56402 .30479 L p .707 .577 .707 r
F P
0 g
s
.25877 .69931 m .23925 .64545 L .2101 .65484 L p .707 .577 .707 r
F P
0 g
s
.23925 .64545 m .25877 .69931 L .28879 .68834 L p .707 .577 .707 r
F P
0 g
s
.28879 .68834 m .26927 .63448 L .23925 .64545 L p .707 .577 .707 r
F P
0 g
s
.26927 .63448 m .28879 .68834 L .31673 .67688 L p .707 .577 .707 r
F P
0 g
s
.31673 .67688 m .29721 .62302 L .26927 .63448 L p .707 .577 .707 r
F P
0 g
s
.43255 .81819 m .39527 .31379 L .36565 .30768 L p .707 .577 .707 r
F P
0 g
s
.39527 .31379 m .43255 .81819 L .47119 .82107 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70118 .72749 m .70512 .76475 L .69265 .75928 L p .707 .577 .707 r
F P
0 g
s
.69265 .75928 m .68871 .72203 L .70118 .72749 L p .707 .577 .707 r
F P
0 g
s
.2101 .65484 m .22961 .7087 L .25877 .69931 L p .707 .577 .707 r
F P
0 g
s
.22961 .7087 m .2101 .65484 L .18465 .66175 L p .707 .577 .707 r
F P
0 g
s
.68948 .83443 m .68497 .85187 L .68251 .83984 L p .707 .577 .707 r
F P
0 g
s
.68251 .83984 m .68703 .8224 L .68948 .83443 L p .707 .577 .707 r
F P
0 g
s
.29721 .62302 m .31673 .67688 L .33985 .66603 L p .707 .577 .707 r
F P
0 g
s
.33985 .66603 m .32034 .61218 L .29721 .62302 L p .707 .577 .707 r
F P
0 g
s
.18465 .66175 m .20417 .7156 L .22961 .7087 L p .707 .577 .707 r
F P
0 g
s
.67368 .63209 m .69319 .68595 L .67396 .68969 L p .707 .577 .707 r
F P
0 g
s
.67396 .68969 m .65444 .63583 L .67368 .63209 L p .707 .577 .707 r
F P
0 g
s
.64851 .69659 m .629 .64273 L .65444 .63583 L p .707 .577 .707 r
F P
0 g
s
.66782 .71862 m .67176 .75587 L .64448 .75485 L p .707 .577 .707 r
F P
0 g
s
.64448 .75485 m .64054 .7176 L .66782 .71862 L p .707 .577 .707 r
F P
0 g
s
.59792 .29528 m .63521 .79968 L .6583 .78875 L p .707 .577 .707 r
F P
0 g
s
.65444 .63583 m .67396 .68969 L .64851 .69659 L p .707 .577 .707 r
F P
0 g
s
.6583 .78875 m .62101 .28435 L .59792 .29528 L p .707 .577 .707 r
F P
0 g
s
.25657 .77242 m .25263 .73517 L .22164 .73664 L p .707 .577 .707 r
F P
0 g
s
.25263 .73517 m .25657 .77242 L .28824 .7686 L p .707 .577 .707 r
F P
0 g
s
.28824 .7686 m .28431 .73135 L .25263 .73517 L p .707 .577 .707 r
F P
0 g
s
.28431 .73135 m .28824 .7686 L .3175 .7628 L p .707 .577 .707 r
F P
0 g
s
.3175 .7628 m .31356 .72555 L .28431 .73135 L p .707 .577 .707 r
F P
0 g
s
.22558 .77389 m .22164 .73664 L .19436 .73562 L p .707 .577 .707 r
F P
0 g
s
.22164 .73664 m .22558 .77389 L .25657 .77242 L p .707 .577 .707 r
F P
0 g
s
.20417 .7156 m .18465 .66175 L .16541 .66548 L p .707 .577 .707 r
F P
0 g
s
.32034 .61218 m .33985 .66603 L .3559 .65688 L p .707 .577 .707 r
F P
0 g
s
.3559 .65688 m .33639 .60302 L .32034 .61218 L p .707 .577 .707 r
F P
0 g
s
.31356 .72555 m .3175 .7628 L .34147 .7556 L p .707 .577 .707 r
F P
0 g
s
.34147 .7556 m .33753 .71835 L .31356 .72555 L p .707 .577 .707 r
F P
0 g
s
.16541 .66548 m .18493 .71934 L .20417 .7156 L p .707 .577 .707 r
F P
0 g
s
.68871 .72203 m .69265 .75928 L .67176 .75587 L p .707 .577 .707 r
F P
0 g
s
.67176 .75587 m .66782 .71862 L .68871 .72203 L p .707 .577 .707 r
F P
0 g
s
.19436 .73562 m .1983 .77288 L .22558 .77389 L p .707 .577 .707 r
F P
0 g
s
.40294 .81207 m .36565 .30768 L .34796 .29893 L p .707 .577 .707 r
F P
0 g
s
.36565 .30768 m .40294 .81207 L .43255 .81819 L p .707 .577 .707 r
F P
0 g
s
.68703 .8224 m .68251 .83984 L .6706 .82652 L p .707 .577 .707 r
F P
0 g
s
.6706 .82652 m .67512 .80908 L .68703 .8224 L p .707 .577 .707 r
F P
0 g
s
.23522 .81586 m .23973 .79842 L .20951 .78893 L p .707 .577 .707 r
F P
0 g
s
.23973 .79842 m .23522 .81586 L .26619 .82193 L p .707 .577 .707 r
F P
0 g
s
.26619 .82193 m .27071 .80449 L .23973 .79842 L p .707 .577 .707 r
F P
0 g
s
.1983 .77288 m .19436 .73562 L .17346 .73221 L p .707 .577 .707 r
F P
0 g
s
.205 .80637 m .20951 .78893 L .18301 .77695 L p .707 .577 .707 r
F P
0 g
s
.20951 .78893 m .205 .80637 L .23522 .81586 L p .707 .577 .707 r
F P
0 g
s
.27071 .80449 m .26619 .82193 L .29489 .82398 L p .707 .577 .707 r
F P
0 g
s
.29489 .82398 m .29941 .80654 L .27071 .80449 L p .707 .577 .707 r
F P
0 g
s
.18493 .71934 m .16541 .66548 L .15426 .66568 L p .707 .577 .707 r
F P
0 g
s
.17346 .73221 m .1774 .76947 L .1983 .77288 L p .707 .577 .707 r
F P
0 g
s
.33753 .71835 m .34147 .7556 L .35781 .7477 L p .707 .577 .707 r
F P
0 g
s
.35781 .7477 m .35387 .71045 L .33753 .71835 L p .707 .577 .707 r
F P
0 g
s
.18301 .77695 m .17849 .79439 L .205 .80637 L p .707 .577 .707 r
F P
0 g
s
.62101 .28435 m .6583 .78875 L .66832 .77747 L p .707 .577 .707 r
F P
0 g
s
.66832 .77747 m .63103 .27307 L .62101 .28435 L p .707 .577 .707 r
F P
0 g
s
.33639 .60302 m .3559 .65688 L .36331 .6503 L p .707 .577 .707 r
F P
0 g
s
.36331 .6503 m .34379 .59644 L .33639 .60302 L p .707 .577 .707 r
F P
0 g
s
.15426 .66568 m .17378 .71954 L .18493 .71934 L p .707 .577 .707 r
F P
0 g
s
.17849 .79439 m .18301 .77695 L .16281 .76365 L p .707 .577 .707 r
F P
0 g
s
.29941 .80654 m .29489 .82398 L .31851 .82182 L p .707 .577 .707 r
F P
0 g
s
.31851 .82182 m .32302 .80438 L .29941 .80654 L p .707 .577 .707 r
F P
0 g
s
.67512 .80908 m .6706 .82652 L .6504 .81323 L p .707 .577 .707 r
F P
0 g
s
.6504 .81323 m .65492 .79578 L .67512 .80908 L p .707 .577 .707 r
F P
0 g
s
.16281 .76365 m .15829 .78109 L .17849 .79439 L p .707 .577 .707 r
F P
0 g
s
.1774 .76947 m .17346 .73221 L .161 .72675 L p .707 .577 .707 r
F P
0 g
s
.161 .72675 m .16494 .764 L .1774 .76947 L p .707 .577 .707 r
F P
0 g
s
.38525 .80332 m .34796 .29893 L .34393 .28839 L p .707 .577 .707 r
F P
0 g
s
.34796 .29893 m .38525 .80332 L .40294 .81207 L p .707 .577 .707 r
F P
0 g
s
.35387 .71045 m .35781 .7477 L .36492 .73987 L p .707 .577 .707 r
F P
0 g
s
.36492 .73987 m .36098 .70262 L .35387 .71045 L p .707 .577 .707 r
F P
0 g
s
.15829 .78109 m .16281 .76365 L .1509 .75034 L p .707 .577 .707 r
F P
0 g
s
.17378 .71954 m .15426 .66568 L .15229 .66233 L p .707 .577 .707 r
F P
0 g
s
.32302 .80438 m .31851 .82182 L .33473 .81566 L p .707 .577 .707 r
F P
0 g
s
.33473 .81566 m .33924 .79821 L .32302 .80438 L p .707 .577 .707 r
F P
0 g
s
.534 .78364 m .53852 .76619 L .56722 .76825 L p .707 .577 .707 r
F P
0 g
s
.34379 .59644 m .36331 .6503 L .36134 .64695 L p .707 .577 .707 r
F P
0 g
s
.36134 .64695 m .34182 .59309 L .34379 .59644 L p .707 .577 .707 r
F P
0 g
s
.1509 .75034 m .14638 .76778 L .15829 .78109 L p .707 .577 .707 r
F P
0 g
s
.15229 .66233 m .1718 .71619 L .17378 .71954 L p .707 .577 .707 r
F P
0 g
s
.56722 .76825 m .5627 .78569 L .534 .78364 L p .707 .577 .707 r
F P
0 g
s
.16494 .764 m .161 .72675 L .15819 .71975 L p .707 .577 .707 r
F P
0 g
s
.6587 .74814 m .66082 .73998 L p .64302 .7174 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .65935 .73378 L .64302 .7174 L .707 .577 .707 r
F
.627 .26254 m .66296 .74905 L p .66082 .73998 L F P
0 g
s
.64287 .66401 m .6371 .51819 L .66082 .73998 L .707 .577 .707 r
F
.6371 .51819 m .627 .26254 L .66082 .73998 L F
.66832 .77747 m .66469 .768 L p .65212 .58635 L F P
0 g
s
.66341 .75396 m .65212 .58635 L .66469 .768 L .707 .577 .707 r
F
.65212 .58635 m .65166 .56027 L .66832 .77747 L F
.63788 .36574 m .66832 .77747 L p .64106 .422 L F P
0 g
s
.627 .26254 m .63103 .27307 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .6525 .60754 L p .65212 .58635 L .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .66514 .6661 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.66116 .72934 m .65778 .72711 L p .66179 .73622 L .707 .577 .707 r
F P
0 g
s
.65778 .72711 m .64302 .7174 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .65778 .72711 L .65935 .73378 L .707 .577 .707 r
F
.60931 .25379 m .627 .26254 L p .64287 .66401 L F P
0 g
s
.64302 .7174 m .63851 .73484 L .6587 .74814 L p .707 .577 .707 r
F P
0 g
s
.64659 .75819 m .63816 .64406 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63816 .64406 m .60931 .25379 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.63851 .73484 m .64302 .7174 L .63111 .70408 L p .707 .577 .707 r
F P
0 g
s
.63111 .70408 m .6266 .72152 L .63851 .73484 L p .707 .577 .707 r
F P
0 g
s
.6266 .72152 m .63111 .70408 L .6311 .70403 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .61406 .56259 L .63533 .69048 L .707 .577 .707 r
F
.6311 .70403 m .62865 .69205 L p .62687 .7176 L F P
0 g
s
.6266 .72152 m .6311 .70403 L .62687 .7176 L .707 .577 .707 r
F
.64659 .75819 m .61698 .75207 L p .61694 .74945 L F P
0 g
s
.62865 .69205 m .62414 .70949 L .6266 .72152 L p .707 .577 .707 r
F P
0 g
s
.61694 .74945 m .63533 .69048 L .64659 .75819 L .707 .577 .707 r
F
.60931 .25379 m .63515 .60339 L p .61406 .56259 L F P
0 g
s
.63515 .60339 m .64659 .75819 L p .61406 .56259 L .707 .577 .707 r
F P
0 g
s
.65317 .64515 m .65033 .63276 L .63448 .61244 L .707 .577 .707 r
F
.64563 .61224 m .63978 .61235 L p .65033 .63276 L F P
0 g
s
.63978 .61235 m .63448 .61244 L p .65033 .63276 L .707 .577 .707 r
F P
0 g
s
.63448 .61244 m .65352 .66501 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65352 .66501 m .65399 .6663 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64842 .55231 L .64106 .422 L .707 .577 .707 r
F
.6525 .60754 m .64842 .55231 L p .65212 .58635 L F P
0 g
s
.64842 .55231 m .627 .26254 L p .64106 .422 L .707 .577 .707 r
F P
0 g
s
.66514 .6661 m .68438 .66236 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.64563 .61224 m .65294 .63243 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.65294 .63243 m .66514 .6661 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.66322 .7307 m .66082 .73998 L p .68521 .76012 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .6587 .74814 L .66184 .74955 L p .707 .577 .707 r
F P
0 g
s
.66296 .74905 m .66428 .76694 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66184 .74955 m .68521 .76012 L p .66082 .73998 L .707 .577 .707 r
F P
0 g
s
.66428 .76694 m .64659 .75819 L p .64287 .66401 L .707 .577 .707 r
F P
0 g
s
.66082 .73998 m .66179 .73622 L p .65935 .73378 L .707 .577 .707 r
F P
0 g
s
.66179 .73622 m .66322 .7307 L .66116 .72934 L p .707 .577 .707 r
F P
0 g
s
.66469 .768 m .66428 .76694 L p .66341 .75396 L .707 .577 .707 r
F P
0 g
s
.65212 .58635 m .64106 .422 L .65166 .56027 L .707 .577 .707 r
F
.66514 .6661 m .65294 .63243 L p .65317 .64515 L F P
0 g
s
.65294 .63243 m .64563 .61224 L p .65317 .64515 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .66487 .60851 L .65173 .61105 L p .707 .577 .707 r
F P
0 g
s
.65173 .61105 m .64563 .61224 L p .65229 .62086 L .707 .577 .707 r
F P
0 g
s
.68438 .66236 m .65173 .61105 L .65229 .62086 L .707 .577 .707 r
F
.63103 .27307 m .63788 .36574 L p .64106 .422 L F P
0 g
s
.15819 .71975 m .16212 .75701 L .16494 .764 L p .707 .577 .707 r
F P
0 g
s
.14638 .76778 m .1509 .75034 L .14844 .73831 L p .707 .577 .707 r
F P
0 g
s
.36098 .70262 m .36492 .73987 L .36211 .73288 L p .707 .577 .707 r
F P
0 g
s
.36211 .73288 m .35817 .69563 L .36098 .70262 L p .707 .577 .707 r
F P
0 g
s
.33924 .79821 m .33473 .81566 L .34196 .80609 L p .707 .577 .707 r
F P
0 g
s
.34196 .80609 m .34648 .78865 L .33924 .79821 L p .707 .577 .707 r
F P
0 g
s
.14844 .73831 m .14392 .75575 L .14638 .76778 L p .707 .577 .707 r
F P
0 g
s
.1718 .71619 m .15229 .66233 L .15969 .65576 L p .707 .577 .707 r
F P
0 g
s
.34182 .59309 m .36134 .64695 L .35018 .64715 L p .707 .577 .707 r
F P
0 g
s
.35018 .64715 m .33067 .5933 L .34182 .59309 L p .707 .577 .707 r
F P
0 g
s
.15969 .65576 m .17921 .70962 L .1718 .71619 L p .707 .577 .707 r
F P
0 g
s
.34393 .28839 m .38122 .79279 L .38525 .80332 L p .707 .577 .707 r
F P
0 g
s
.38122 .79279 m .34393 .28839 L .35395 .27711 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16212 .75701 m .15819 .71975 L .1653 .71192 L p .707 .577 .707 r
F P
0 g
s
.1653 .71192 m .16924 .74918 L .16212 .75701 L p .707 .577 .707 r
F P
0 g
s
.14392 .75575 m .14844 .73831 L .15567 .72874 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34648 .78865 m .34196 .80609 L .3395 .79406 L p .707 .577 .707 r
F P
0 g
s
.3395 .79406 m .34402 .77662 L .34648 .78865 L p .707 .577 .707 r
F P
0 g
s
.35817 .69563 m .36211 .73288 L .34964 .72741 L p .707 .577 .707 r
F P
0 g
s
.34964 .72741 m .3457 .69016 L .35817 .69563 L p .707 .577 .707 r
F P
0 g
s
.15567 .72874 m .15116 .74618 L .14392 .75575 L p .707 .577 .707 r
F P
0 g
s
.17921 .70962 m .15969 .65576 L .17574 .6466 L p .707 .577 .707 r
F P
0 g
s
.33067 .5933 m .35018 .64715 L .33095 .65089 L p .707 .577 .707 r
F P
0 g
s
.33095 .65089 m .31143 .59703 L .33067 .5933 L p .707 .577 .707 r
F P
0 g
s
.17574 .6466 m .19526 .70046 L .17921 .70962 L p .707 .577 .707 r
F P
0 g
s
.16924 .74918 m .1653 .71192 L .18164 .70402 L p .707 .577 .707 r
F P
0 g
s
.39124 .78151 m .35395 .27711 L .37704 .26618 L p .707 .577 .707 r
F P
0 g
s
.35395 .27711 m .39124 .78151 L .38122 .79279 L p .707 .577 .707 r
F P
0 g
s
.15116 .74618 m .15567 .72874 L .17189 .72258 L p .707 .577 .707 r
F P
0 g
s
.18164 .70402 m .18558 .74127 L .16924 .74918 L p .707 .577 .707 r
F P
0 g
s
.34402 .77662 m .3395 .79406 L .32759 .78074 L p .707 .577 .707 r
F P
0 g
s
.32759 .78074 m .33211 .7633 L .34402 .77662 L p .707 .577 .707 r
F P
0 g
s
.3457 .69016 m .34964 .72741 L .32875 .724 L p .707 .577 .707 r
F P
0 g
s
.32875 .724 m .32481 .68675 L .3457 .69016 L p .707 .577 .707 r
F P
0 g
s
.19526 .70046 m .17574 .6466 L .19887 .63576 L p .707 .577 .707 r
F P
0 g
s
.17189 .72258 m .16738 .74002 L .15116 .74618 L p .707 .577 .707 r
F P
0 g
s
.31143 .59703 m .33095 .65089 L .3055 .65779 L p .707 .577 .707 r
F P
0 g
s
.3055 .65779 m .28599 .60393 L .31143 .59703 L p .707 .577 .707 r
F P
0 g
s
.19887 .63576 m .21838 .68962 L .19526 .70046 L p .707 .577 .707 r
F P
0 g
s
.61698 .75207 m .57969 .24767 L .60931 .25379 L p .707 .577 .707 r
F P
0 g
s
.18558 .74127 m .18164 .70402 L .20561 .69682 L p .707 .577 .707 r
F P
0 g
s
.21838 .68962 m .19887 .63576 L .22681 .62429 L p .707 .577 .707 r
F P
0 g
s
.28599 .60393 m .3055 .65779 L .27634 .66719 L p .707 .577 .707 r
F P
0 g
s
.27634 .66719 m .25683 .61333 L .28599 .60393 L p .707 .577 .707 r
F P
0 g
s
.20561 .69682 m .20955 .73407 L .18558 .74127 L p .707 .577 .707 r
F P
0 g
s
.32481 .68675 m .32875 .724 L .30147 .72298 L p .707 .577 .707 r
F P
0 g
s
.30147 .72298 m .29753 .68573 L .32481 .68675 L p .707 .577 .707 r
F P
0 g
s
.16738 .74002 m .17189 .72258 L .19551 .72041 L p .707 .577 .707 r
F P
0 g
s
.33211 .7633 m .32759 .78074 L .30739 .76744 L p .707 .577 .707 r
F P
0 g
s
.30739 .76744 m .31191 .75 L .33211 .7633 L p .707 .577 .707 r
F P
0 g
s
.22681 .62429 m .24632 .67815 L .21838 .68962 L p .707 .577 .707 r
F P
0 g
s
.73898 .64607 m .71947 .59221 L .69031 .6016 L p .707 .577 .707 r
F P
0 g
s
.71947 .59221 m .73898 .64607 L .769 .6351 L p .707 .577 .707 r
F P
0 g
s
.769 .6351 m .74949 .58124 L .71947 .59221 L p .707 .577 .707 r
F P
0 g
s
.74949 .58124 m .769 .6351 L .79694 .62364 L p .707 .577 .707 r
F P
0 g
s
.79694 .62364 m .77743 .56978 L .74949 .58124 L p .707 .577 .707 r
F P
0 g
s
.19551 .72041 m .19099 .73785 L .16738 .74002 L p .707 .577 .707 r
F P
0 g
s
.24632 .67815 m .22681 .62429 L .25683 .61333 L p .707 .577 .707 r
F P
0 g
s
.25683 .61333 m .27634 .66719 L .24632 .67815 L p .707 .577 .707 r
F P
0 g
s
.37704 .26618 m .41433 .77058 L .39124 .78151 L p .707 .577 .707 r
F P
0 g
s
.41433 .77058 m .37704 .26618 L .41094 .25668 L p .707 .577 .707 r
F P
0 g
s
.20955 .73407 m .20561 .69682 L .23486 .69103 L p .707 .577 .707 r
F P
0 g
s
.69031 .6016 m .70982 .65546 L .73898 .64607 L p .707 .577 .707 r
F P
0 g
s
.70982 .65546 m .69031 .6016 L .66487 .60851 L p .707 .577 .707 r
F P
0 g
s
.29753 .68573 m .30147 .72298 L .27048 .72446 L p .707 .577 .707 r
F P
0 g
s
.27048 .72446 m .26654 .68721 L .29753 .68573 L p .707 .577 .707 r
F P
0 g
s
.77743 .56978 m .79694 .62364 L .82007 .61279 L p .707 .577 .707 r
F P
0 g
s
.82007 .61279 m .80055 .55894 L .77743 .56978 L p .707 .577 .707 r
F P
0 g
s
.23486 .69103 m .2388 .72828 L .20955 .73407 L p .707 .577 .707 r
F P
0 g
s
.19099 .73785 m .19551 .72041 L .22421 .72247 L p .707 .577 .707 r
F P
0 g
s
.66487 .60851 m .68438 .66236 L .70982 .65546 L p .707 .577 .707 r
F P
0 g
s
.2388 .72828 m .23486 .69103 L .26654 .68721 L p .707 .577 .707 r
F P
0 g
s
.31191 .75 m .30739 .76744 L .28089 .75546 L p .707 .577 .707 r
F P
0 g
s
.28089 .75546 m .2854 .73802 L .31191 .75 L p .707 .577 .707 r
F P
0 g
s
.73678 .71225 m .73284 .675 L .70185 .67647 L p .707 .577 .707 r
F P
0 g
s
.73284 .675 m .73678 .71225 L .76846 .70843 L p .707 .577 .707 r
F P
0 g
s
.76846 .70843 m .76452 .67118 L .73284 .675 L p .707 .577 .707 r
F P
0 g
s
.57969 .24767 m .61698 .75207 L .57834 .74919 L p .707 .577 .707 r
F P
0 g
s
.57834 .74919 m .54105 .2448 L .57969 .24767 L p .707 .577 .707 r
F P
0 g
s
.26654 .68721 m .27048 .72446 L .2388 .72828 L p .707 .577 .707 r
F P
0 g
s
.76452 .67118 m .76846 .70843 L .79771 .70263 L p .707 .577 .707 r
F P
0 g
s
.79771 .70263 m .79377 .66538 L .76452 .67118 L p .707 .577 .707 r
F P
0 g
s
.22421 .72247 m .21969 .73991 L .19099 .73785 L p .707 .577 .707 r
F P
0 g
s
.70579 .71372 m .70185 .67647 L .67457 .67545 L p .707 .577 .707 r
F P
0 g
s
.70185 .67647 m .70579 .71372 L .73678 .71225 L p .707 .577 .707 r
F P
0 g
s
.21969 .73991 m .22421 .72247 L .25518 .72853 L p .707 .577 .707 r
F P
0 g
s
.80055 .55894 m .82007 .61279 L .83612 .60364 L p .707 .577 .707 r
F P
0 g
s
.83612 .60364 m .8166 .54978 L .80055 .55894 L p .707 .577 .707 r
F P
0 g
s
.2854 .73802 m .28089 .75546 L .25067 .74598 L p .707 .577 .707 r
F P
0 g
s
.25067 .74598 m .25518 .72853 L .2854 .73802 L p .707 .577 .707 r
F P
0 g
s
.79377 .66538 m .79771 .70263 L .82168 .69543 L p .707 .577 .707 r
F P
0 g
s
.82168 .69543 m .81774 .65818 L .79377 .66538 L p .707 .577 .707 r
F P
0 g
s
.44823 .76108 m .41094 .25668 L .45233 .24953 L p .707 .577 .707 r
F P
0 g
s
.41094 .25668 m .44823 .76108 L .41433 .77058 L p .707 .577 .707 r
F P
0 g
s
.67457 .67545 m .67851 .7127 L .70579 .71372 L p .707 .577 .707 r
F P
0 g
s
.25518 .72853 m .25067 .74598 L .21969 .73991 L p .707 .577 .707 r
F P
0 g
s
.54105 .2448 m .57834 .74919 L .53445 .74983 L p .707 .577 .707 r
F P
0 g
s
.53445 .74983 m .49717 .24544 L .54105 .2448 L p .707 .577 .707 r
F P
0 g
s
.67851 .7127 m .67457 .67545 L .65368 .67204 L p .707 .577 .707 r
F P
0 g
s
.71543 .76961 m .71994 .75216 L .68972 .74268 L p .707 .577 .707 r
F P
0 g
s
.71994 .75216 m .71543 .76961 L .74641 .77567 L p .707 .577 .707 r
F P
0 g
s
.74641 .77567 m .75092 .75823 L .71994 .75216 L p .707 .577 .707 r
F P
0 g
s
.48962 .75393 m .45233 .24953 L .49717 .24544 L p .707 .577 .707 r
F P
0 g
s
.45233 .24953 m .48962 .75393 L .44823 .76108 L p .707 .577 .707 r
F P
0 g
s
.68521 .76012 m .68972 .74268 L .66322 .7307 L p .707 .577 .707 r
F P
0 g
s
.68972 .74268 m .68521 .76012 L .71543 .76961 L p .707 .577 .707 r
F P
0 g
s
.75092 .75823 m .74641 .77567 L .77511 .77773 L p .707 .577 .707 r
F P
0 g
s
.77511 .77773 m .77962 .76029 L .75092 .75823 L p .707 .577 .707 r
F P
0 g
s
.65368 .67204 m .65762 .70929 L .67851 .7127 L p .707 .577 .707 r
F P
0 g
s
.81774 .65818 m .82168 .69543 L .83802 .68753 L p .707 .577 .707 r
F P
0 g
s
.83802 .68753 m .83408 .65028 L .81774 .65818 L p .707 .577 .707 r
F P
0 g
s
.49717 .24544 m .53445 .74983 L .48962 .75393 L p .707 .577 .707 r
F P
0 g
s
.8166 .54978 m .83612 .60364 L .84352 .59706 L p .707 .577 .707 r
F P
0 g
s
.84352 .59706 m .82401 .5432 L .8166 .54978 L p .707 .577 .707 r
F P
0 g
s
.77962 .76029 m .77511 .77773 L .79872 .77556 L p .707 .577 .707 r
F P
0 g
s
.79872 .77556 m .80324 .75812 L .77962 .76029 L p .707 .577 .707 r
F P
0 g
s
.65762 .70929 m .65368 .67204 L .64121 .66657 L p .707 .577 .707 r
F P
0 g
s
.64121 .66657 m .64515 .70382 L .65762 .70929 L p .707 .577 .707 r
F P
0 g
s
.83408 .65028 m .83802 .68753 L .84514 .6797 L p .707 .577 .707 r
F P
0 g
s
.84514 .6797 m .8412 .64245 L .83408 .65028 L p .707 .577 .707 r
F P
0 g
s
.65399 .6663 m .63448 .61244 L .6325 .60909 L p .707 .577 .707 r
F P
0 g
s
.80324 .75812 m .79872 .77556 L .81494 .7694 L p .707 .577 .707 r
F P
0 g
s
.81494 .7694 m .81945 .75196 L .80324 .75812 L p .707 .577 .707 r
F P
0 g
s
.82401 .5432 m .84352 .59706 L .84155 .59371 L p .707 .577 .707 r
F P
0 g
s
.84155 .59371 m .82204 .53985 L .82401 .5432 L p .707 .577 .707 r
F P
0 g
s
.6325 .60909 m .65202 .66295 L .65399 .6663 L p .707 .577 .707 r
F P
0 g
s
.64515 .70382 m .64121 .66657 L .6384 .65958 L p .707 .577 .707 r
F P
0 g
s
.6384 .65958 m .64234 .69683 L .64515 .70382 L p .707 .577 .707 r
F P
0 g
s
.8412 .64245 m .84514 .6797 L .84232 .67271 L p .707 .577 .707 r
F P
0 g
s
.84232 .67271 m .83838 .63546 L .8412 .64245 L p .707 .577 .707 r
F P
0 g
s
.81945 .75196 m .81494 .7694 L .82217 .75983 L p .707 .577 .707 r
F P
0 g
s
.82217 .75983 m .82669 .74239 L .81945 .75196 L p .707 .577 .707 r
F P
0 g
s
.65202 .66295 m .6325 .60909 L .63991 .60252 L p .707 .577 .707 r
F P
0 g
s
.82204 .53985 m .84155 .59371 L .8304 .59391 L p .707 .577 .707 r
F P
0 g
s
.8304 .59391 m .81089 .54005 L .82204 .53985 L p .707 .577 .707 r
F P
0 g
s
.63991 .60252 m .65942 .65638 L .65202 .66295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64234 .69683 m .6384 .65958 L .64551 .65175 L p .707 .577 .707 r
F P
0 g
s
.39597 .60727 m .37646 .55341 L .3473 .56281 L p .707 .577 .707 r
F P
0 g
s
.37646 .55341 m .39597 .60727 L .42599 .5963 L p .707 .577 .707 r
F P
0 g
s
.42599 .5963 m .40648 .54244 L .37646 .55341 L p .707 .577 .707 r
F P
0 g
s
.40648 .54244 m .42599 .5963 L .45393 .58484 L p .707 .577 .707 r
F P
0 g
s
.45393 .58484 m .43442 .53098 L .40648 .54244 L p .707 .577 .707 r
F P
0 g
s
.64551 .65175 m .64945 .689 L .64234 .69683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83838 .63546 m .84232 .67271 L .82986 .66724 L p .707 .577 .707 r
F P
0 g
s
.82986 .66724 m .82592 .62999 L .83838 .63546 L p .707 .577 .707 r
F P
0 g
s
.3473 .56281 m .36681 .61666 L .39597 .60727 L p .707 .577 .707 r
F P
0 g
s
.62414 .70949 m .62865 .69205 L .63589 .68248 L p .707 .577 .707 r
F P
0 g
s
.36681 .61666 m .3473 .56281 L .32186 .56971 L p .707 .577 .707 r
F P
0 g
s
.82669 .74239 m .82217 .75983 L .81972 .7478 L p .707 .577 .707 r
F P
0 g
s
.81972 .7478 m .82423 .73036 L .82669 .74239 L p .707 .577 .707 r
F P
0 g
s
.43442 .53098 m .45393 .58484 L .47706 .574 L p .707 .577 .707 r
F P
0 g
s
.47706 .574 m .45754 .52014 L .43442 .53098 L p .707 .577 .707 r
F P
0 g
s
.65942 .65638 m .63991 .60252 L .65596 .59336 L p .707 .577 .707 r
F P
0 g
s
.63589 .68248 m .63137 .69993 L .62414 .70949 L p .707 .577 .707 r
F P
0 g
s
.32186 .56971 m .34137 .62357 L .36681 .61666 L p .707 .577 .707 r
F P
0 g
s
.81089 .54005 m .8304 .59391 L .81116 .59765 L p .707 .577 .707 r
F P
0 g
s
.81116 .59765 m .79165 .54379 L .81089 .54005 L p .707 .577 .707 r
F P
0 g
s
.39377 .68038 m .38983 .64313 L .35884 .6446 L p .707 .577 .707 r
F P
0 g
s
.38983 .64313 m .39377 .68038 L .42545 .67656 L p .707 .577 .707 r
F P
0 g
s
.42545 .67656 m .42151 .63931 L .38983 .64313 L p .707 .577 .707 r
F P
0 g
s
.65596 .59336 m .67547 .64722 L .65942 .65638 L p .707 .577 .707 r
F P
0 g
s
.42151 .63931 m .42545 .67656 L .4547 .67077 L p .707 .577 .707 r
F P
0 g
s
.4547 .67077 m .45076 .63351 L .42151 .63931 L p .707 .577 .707 r
F P
0 g
s
.64945 .689 m .64551 .65175 L .66185 .64385 L p .707 .577 .707 r
F P
0 g
s
.36278 .68185 m .35884 .6446 L .33156 .64359 L p .707 .577 .707 r
F P
0 g
s
.35884 .6446 m .36278 .68185 L .39377 .68038 L p .707 .577 .707 r
F P
0 g
s
.34137 .62357 m .32186 .56971 L .30262 .57344 L p .707 .577 .707 r
F P
0 g
s
.45754 .52014 m .47706 .574 L .49311 .56484 L p .707 .577 .707 r
F P
0 g
s
.49311 .56484 m .47359 .51098 L .45754 .52014 L p .707 .577 .707 r
F P
0 g
s
.45076 .63351 m .4547 .67077 L .47867 .66356 L p .707 .577 .707 r
F P
0 g
s
.47867 .66356 m .47473 .62631 L .45076 .63351 L p .707 .577 .707 r
F P
0 g
s
.66185 .64385 m .66579 .6811 L .64945 .689 L p .707 .577 .707 r
F P
0 g
s
.30262 .57344 m .32213 .6273 L .34137 .62357 L p .707 .577 .707 r
F P
0 g
s
.82592 .62999 m .82986 .66724 L .80896 .66383 L p .707 .577 .707 r
F P
0 g
s
.80896 .66383 m .80502 .62658 L .82592 .62999 L p .707 .577 .707 r
F P
0 g
s
.33156 .64359 m .3355 .68084 L .36278 .68185 L p .707 .577 .707 r
F P
0 g
s
.63137 .69993 m .63589 .68248 L .65211 .67632 L p .707 .577 .707 r
F P
0 g
s
.67547 .64722 m .65596 .59336 L .67908 .58252 L p .707 .577 .707 r
F P
0 g
s
.82423 .73036 m .81972 .7478 L .80781 .73449 L p .707 .577 .707 r
F P
0 g
s
.80781 .73449 m .81232 .71705 L .82423 .73036 L p .707 .577 .707 r
F P
0 g
s
.79165 .54379 m .81116 .59765 L .78572 .60455 L p .707 .577 .707 r
F P
0 g
s
.78572 .60455 m .7662 .55069 L .79165 .54379 L p .707 .577 .707 r
F P
0 g
s
.37242 .72382 m .37693 .70638 L .34671 .69689 L p .707 .577 .707 r
F P
0 g
s
.37693 .70638 m .37242 .72382 L .4034 .72989 L p .707 .577 .707 r
F P
0 g
s
.4034 .72989 m .40791 .71245 L .37693 .70638 L p .707 .577 .707 r
F P
0 g
s
.65211 .67632 m .64759 .69376 L .63137 .69993 L p .707 .577 .707 r
F P
0 g
s
.3355 .68084 m .33156 .64359 L .31067 .64018 L p .707 .577 .707 r
F P
0 g
s
.67908 .58252 m .6986 .63638 L .67547 .64722 L p .707 .577 .707 r
F P
0 g
s
.3422 .71434 m .34671 .69689 L .32021 .68491 L p .707 .577 .707 r
F P
0 g
s
.34671 .69689 m .3422 .71434 L .37242 .72382 L p .707 .577 .707 r
F P
0 g
s
.40791 .71245 m .4034 .72989 L .4321 .73195 L p .707 .577 .707 r
F P
0 g
s
.4321 .73195 m .43661 .7145 L .40791 .71245 L p .707 .577 .707 r
F P
0 g
s
.66579 .6811 m .66185 .64385 L .68582 .63665 L p .707 .577 .707 r
F P
0 g
s
.32213 .6273 m .30262 .57344 L .29147 .57365 L p .707 .577 .707 r
F P
0 g
s
.31067 .64018 m .31461 .67743 L .3355 .68084 L p .707 .577 .707 r
F P
0 g
s
.47473 .62631 m .47867 .66356 L .49501 .65566 L p .707 .577 .707 r
F P
0 g
s
.49501 .65566 m .49107 .61841 L .47473 .62631 L p .707 .577 .707 r
F P
0 g
s
.32021 .68491 m .31569 .70236 L .3422 .71434 L p .707 .577 .707 r
F P
0 g
s
.47359 .51098 m .49311 .56484 L .50051 .55826 L p .707 .577 .707 r
F P
0 g
s
.50051 .55826 m .481 .50441 L .47359 .51098 L p .707 .577 .707 r
F P
0 g
s
.6986 .63638 m .67908 .58252 L .70703 .57105 L p .707 .577 .707 r
F P
0 g
s
.29147 .57365 m .31098 .6275 L .32213 .6273 L p .707 .577 .707 r
F P
0 g
s
.68582 .63665 m .68976 .6739 L .66579 .6811 L p .707 .577 .707 r
F P
0 g
s
.80502 .62658 m .80896 .66383 L .78168 .66281 L p .707 .577 .707 r
F P
0 g
s
.78168 .66281 m .77774 .62556 L .80502 .62658 L p .707 .577 .707 r
F P
0 g
s
.31569 .70236 m .32021 .68491 L .30001 .67162 L p .707 .577 .707 r
F P
0 g
s
.7662 .55069 m .78572 .60455 L .75656 .61395 L p .707 .577 .707 r
F P
0 g
s
.75656 .61395 m .73704 .56009 L .7662 .55069 L p .707 .577 .707 r
F P
0 g
s
.43661 .7145 m .4321 .73195 L .45571 .72978 L p .707 .577 .707 r
F P
0 g
s
.45571 .72978 m .46023 .71234 L .43661 .7145 L p .707 .577 .707 r
F P
0 g
s
.64759 .69376 m .65211 .67632 L .67572 .67416 L p .707 .577 .707 r
F P
0 g
s
.70703 .57105 m .72654 .62491 L .6986 .63638 L p .707 .577 .707 r
F P
0 g
s
.81232 .71705 m .80781 .73449 L .78761 .72119 L p .707 .577 .707 r
F P
0 g
s
.78761 .72119 m .79212 .70375 L .81232 .71705 L p .707 .577 .707 r
F P
0 g
s
.30001 .67162 m .2955 .68906 L .31569 .70236 L p .707 .577 .707 r
F P
0 g
s
.31461 .67743 m .31067 .64018 L .2982 .63471 L p .707 .577 .707 r
F P
0 g
s
.72654 .62491 m .70703 .57105 L .73704 .56009 L p .707 .577 .707 r
F P
0 g
s
.73704 .56009 m .75656 .61395 L .72654 .62491 L p .707 .577 .707 r
F P
0 g
s
.67572 .67416 m .67121 .6916 L .64759 .69376 L p .707 .577 .707 r
F P
0 g
s
.68976 .6739 m .68582 .63665 L .71508 .63085 L p .707 .577 .707 r
F P
0 g
s
.77774 .62556 m .78168 .66281 L .75069 .66428 L p .707 .577 .707 r
F P
0 g
s
.75069 .66428 m .74675 .62703 L .77774 .62556 L p .707 .577 .707 r
F P
0 g
s
.2982 .63471 m .30214 .67196 L .31461 .67743 L p .707 .577 .707 r
F P
0 g
s
.49107 .61841 m .49501 .65566 L .50213 .64783 L p .707 .577 .707 r
F P
0 g
s
.50213 .64783 m .49819 .61058 L .49107 .61841 L p .707 .577 .707 r
F P
0 g
s
.71508 .63085 m .71902 .66811 L .68976 .6739 L p .707 .577 .707 r
F P
0 g
s
.2955 .68906 m .30001 .67162 L .2881 .6583 L p .707 .577 .707 r
F P
0 g
s
.71902 .66811 m .71508 .63085 L .74675 .62703 L p .707 .577 .707 r
F P
0 g
s
.31098 .6275 m .29147 .57365 L .28949 .57029 L p .707 .577 .707 r
F P
0 g
s
.46023 .71234 m .45571 .72978 L .47193 .72362 L p .707 .577 .707 r
F P
0 g
s
.47193 .72362 m .47644 .70618 L .46023 .71234 L p .707 .577 .707 r
F P
0 g
s
.74675 .62703 m .75069 .66428 L .71902 .66811 L p .707 .577 .707 r
F P
0 g
s
.67121 .6916 m .67572 .67416 L .70442 .67621 L p .707 .577 .707 r
F P
0 g
s
.79212 .70375 m .78761 .72119 L .7611 .70921 L p .707 .577 .707 r
F P
0 g
s
.7611 .70921 m .76562 .69177 L .79212 .70375 L p .707 .577 .707 r
F P
0 g
s
.481 .50441 m .50051 .55826 L .49854 .55491 L p .707 .577 .707 r
F P
0 g
s
.49854 .55491 m .47903 .50105 L .481 .50441 L p .707 .577 .707 r
F P
0 g
s
.2881 .6583 m .28359 .67574 L .2955 .68906 L p .707 .577 .707 r
F P
0 g
s
.28949 .57029 m .30901 .62415 L .31098 .6275 L p .707 .577 .707 r
F P
0 g
s
.70442 .67621 m .69991 .69365 L .67121 .6916 L p .707 .577 .707 r
F P
0 g
s
.30214 .67196 m .2982 .63471 L .29539 .62772 L p .707 .577 .707 r
F P
0 g
s
.69991 .69365 m .70442 .67621 L .7354 .68228 L p .707 .577 .707 r
F P
0 g
s
.76562 .69177 m .7611 .70921 L .73088 .69972 L p .707 .577 .707 r
F P
0 g
s
.73088 .69972 m .7354 .68228 L .76562 .69177 L p .707 .577 .707 r
F P
0 g
s
.7354 .68228 m .73088 .69972 L .69991 .69365 L p .707 .577 .707 r
F P
0 g
s
.29539 .62772 m .29933 .66497 L .30214 .67196 L p .707 .577 .707 r
F P
0 g
s
.28359 .67574 m .2881 .6583 L .28564 .64627 L p .707 .577 .707 r
F P
0 g
s
.49819 .61058 m .50213 .64783 L .49931 .64084 L p .707 .577 .707 r
F P
0 g
s
.49931 .64084 m .49537 .60359 L .49819 .61058 L p .707 .577 .707 r
F P
0 g
s
.47644 .70618 m .47193 .72362 L .47916 .71405 L p .707 .577 .707 r
F P
0 g
s
.47916 .71405 m .48368 .69661 L .47644 .70618 L p .707 .577 .707 r
F P
0 g
s
.28564 .64627 m .28113 .66371 L .28359 .67574 L p .707 .577 .707 r
F P
0 g
s
.30901 .62415 m .28949 .57029 L .2969 .56372 L p .707 .577 .707 r
F P
0 g
s
.47903 .50105 m .49854 .55491 L .48739 .55512 L p .707 .577 .707 r
F P
0 g
s
.48739 .55512 m .46788 .50126 L .47903 .50105 L p .707 .577 .707 r
F P
0 g
s
.2969 .56372 m .31641 .61758 L .30901 .62415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29933 .66497 m .29539 .62772 L .3025 .61989 L p .707 .577 .707 r
F P
0 g
s
.3025 .61989 m .30644 .65714 L .29933 .66497 L p .707 .577 .707 r
F P
0 g
s
.28113 .66371 m .28564 .64627 L .29288 .6367 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48368 .69661 m .47916 .71405 L .47671 .70202 L p .707 .577 .707 r
F P
0 g
s
.47671 .70202 m .48122 .68458 L .48368 .69661 L p .707 .577 .707 r
F P
0 g
s
.49537 .60359 m .49931 .64084 L .48685 .63537 L p .707 .577 .707 r
F P
0 g
s
.48685 .63537 m .48291 .59812 L .49537 .60359 L p .707 .577 .707 r
F P
0 g
s
.29288 .6367 m .28836 .65414 L .28113 .66371 L p .707 .577 .707 r
F P
0 g
s
.31641 .61758 m .2969 .56372 L .31295 .55456 L p .707 .577 .707 r
F P
0 g
s
.46788 .50126 m .48739 .55512 L .46815 .55885 L p .707 .577 .707 r
F P
0 g
s
.46815 .55885 m .44864 .50499 L .46788 .50126 L p .707 .577 .707 r
F P
0 g
s
.31295 .55456 m .33246 .60842 L .31641 .61758 L p .707 .577 .707 r
F P
0 g
s
.30644 .65714 m .3025 .61989 L .31884 .61198 L p .707 .577 .707 r
F P
0 g
s
.28836 .65414 m .29288 .6367 L .30909 .63054 L p .707 .577 .707 r
F P
0 g
s
.31884 .61198 m .32278 .64923 L .30644 .65714 L p .707 .577 .707 r
F P
0 g
s
.48122 .68458 m .47671 .70202 L .46479 .6887 L p .707 .577 .707 r
F P
0 g
s
.46479 .6887 m .46931 .67126 L .48122 .68458 L p .707 .577 .707 r
F P
0 g
s
.48291 .59812 m .48685 .63537 L .46595 .63196 L p .707 .577 .707 r
F P
0 g
s
.46595 .63196 m .46201 .59471 L .48291 .59812 L p .707 .577 .707 r
F P
0 g
s
.33246 .60842 m .31295 .55456 L .33607 .54372 L p .707 .577 .707 r
F P
0 g
s
.30909 .63054 m .30458 .64798 L .28836 .65414 L p .707 .577 .707 r
F P
0 g
s
.44864 .50499 m .46815 .55885 L .44271 .56575 L p .707 .577 .707 r
F P
0 g
s
.44271 .56575 m .42319 .51189 L .44864 .50499 L p .707 .577 .707 r
F P
0 g
s
.33607 .54372 m .35559 .59758 L .33246 .60842 L p .707 .577 .707 r
F P
0 g
s
.32278 .64923 m .31884 .61198 L .34281 .60478 L p .707 .577 .707 r
F P
0 g
s
.35559 .59758 m .33607 .54372 L .36401 .53226 L p .707 .577 .707 r
F P
0 g
s
.42319 .51189 m .44271 .56575 L .41355 .57515 L p .707 .577 .707 r
F P
0 g
s
.41355 .57515 m .39403 .52129 L .42319 .51189 L p .707 .577 .707 r
F P
0 g
s
.34281 .60478 m .34675 .64203 L .32278 .64923 L p .707 .577 .707 r
F P
0 g
s
.46201 .59471 m .46595 .63196 L .43867 .63094 L p .707 .577 .707 r
F P
0 g
s
.43867 .63094 m .43473 .59369 L .46201 .59471 L p .707 .577 .707 r
F P
0 g
s
.30458 .64798 m .30909 .63054 L .33271 .62837 L p .707 .577 .707 r
F P
0 g
s
.46931 .67126 m .46479 .6887 L .4446 .67541 L p .707 .577 .707 r
F P
0 g
s
.4446 .67541 m .44911 .65796 L .46931 .67126 L p .707 .577 .707 r
F P
0 g
s
.36401 .53226 m .38353 .58611 L .35559 .59758 L p .707 .577 .707 r
F P
0 g
s
.33271 .62837 m .3282 .64582 L .30458 .64798 L p .707 .577 .707 r
F P
0 g
s
.38353 .58611 m .36401 .53226 L .39403 .52129 L p .707 .577 .707 r
F P
0 g
s
.39403 .52129 m .41355 .57515 L .38353 .58611 L p .707 .577 .707 r
F P
0 g
s
.34675 .64203 m .34281 .60478 L .37207 .59899 L p .707 .577 .707 r
F P
0 g
s
.43473 .59369 m .43867 .63094 L .40768 .63242 L p .707 .577 .707 r
F P
0 g
s
.40768 .63242 m .40374 .59517 L .43473 .59369 L p .707 .577 .707 r
F P
0 g
s
.37207 .59899 m .376 .63624 L .34675 .64203 L p .707 .577 .707 r
F P
0 g
s
.3282 .64582 m .33271 .62837 L .36141 .63043 L p .707 .577 .707 r
F P
0 g
s
.376 .63624 m .37207 .59899 L .40374 .59517 L p .707 .577 .707 r
F P
0 g
s
.44911 .65796 m .4446 .67541 L .41809 .66343 L p .707 .577 .707 r
F P
0 g
s
.41809 .66343 m .42261 .64598 L .44911 .65796 L p .707 .577 .707 r
F P
0 g
s
.40374 .59517 m .40768 .63242 L .376 .63624 L p .707 .577 .707 r
F P
0 g
s
.36141 .63043 m .3569 .64787 L .3282 .64582 L p .707 .577 .707 r
F P
0 g
s
.3569 .64787 m .36141 .63043 L .39239 .6365 L p .707 .577 .707 r
F P
0 g
s
.42261 .64598 m .41809 .66343 L .38787 .65394 L p .707 .577 .707 r
F P
0 g
s
.38787 .65394 m .39239 .6365 L .42261 .64598 L p .707 .577 .707 r
F P
0 g
s
.39239 .6365 m .38787 .65394 L .3569 .64787 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo0024Ool60003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001fOol007ioo`H000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@0079oo`00N7oo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000KWoo001bOol60008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH2001/Ool006ioo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJ
EP8006Yoo`00JWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH02eYF00<007ooOol0J7oo001XOol200000eYF001JEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH2001YOol006Io
o`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00YJEP8006Uoo`00I7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02UYF0P00JGoo001SOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1WOol0065oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1WOol0065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1WOol0
065oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYF
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
069oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2
001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01000FUIJEP001eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001ROol01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001ROol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH20003FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001JEP02
001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF008006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYF001JEP02001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01@00FUIJEP00FUH00P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
FUH005YF008006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000=JEP03001JEWoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYFFUH005YFIGoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0Hgoo001UOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0Hgoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF1`002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH00UYF100045YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF1@0000=JEP00FUH0
15YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00AJEP<000IJEP03001JEUYF009J
EP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00
FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YF00000P0015YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06=oo`00IWoo00@005YFFUH000EJEP<000MJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEP00FUH005YF06Aoo`00IWoo00@005YFFUH0009JEP<00003FUH005YF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH200001EYF001JEP00FUH0I7oo001VOol00`00FUIJEP030005FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YF001JEP00FUITOol006Ioo`<000QJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00Oomoo`1ROol006Aoo`800003FUH005YF00QJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001oogoo069oo`00HGoo0`0015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
02Uoo`H003=oo`00GWoo0`001eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo02Eoo`@0009JEP05001JEUYFFUH0000bOol005aoo`800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo025oo`@00003FUH005YF00AJEP04001JEUYF000bOol005Yoo`8000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000NOol40006FUH0
0`00FUIJEP02FUH00`00FUIJEP02000aOol005Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00L000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001aoo`800003FUH005YF00MJEP03001JEUYF00=J
EP04001JEUYF000aOol005Moo`8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000IOol30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo001EOol20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000FOol30007FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUIJEP02000`Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8001=oo`<00003FUH005YF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000`Ool005=oo`8000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP04
001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000@Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<7oo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000P001EYF00<005YFFUH01EYF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P003Goo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH002moo`00DWoo00@005YFFUH000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP@000QJEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP8000=JEP8000]oo`800003FUH005YF00UJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool0059oo`800003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00IJEP03001JEUYF009J
EP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20009Ool2
0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00
1EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo00Aoo`<000IJEP03001JEUYF00MJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005=oo`04001JEUYF
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP05FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`02Ool200000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo001DOol00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`020004FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP00;Goo001DOol01000FUIJEP0015YF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH0
1EYF200025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`001UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUIJEPH002eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00IJEP8000MJEPT000AJ
EP04001JEUYFFUH70002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0`001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF1@000UYF00@005YFFUH002eoo`00Dgoo0`0000=JEP00FUH015YF00<005YFFUH00eYF
0P0000=JEP0000001P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@002EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00=J
EP8002ioo`00D7oo0`000UYF00@005YFFUH000AJEP03001JEUYF00H000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000007FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool004ioo`800003FUH0
05YF009JEP04001JEUYF0005FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00<005YFFUH01EYF00D005YFFUIJEP00031oo`00Bgoo0`0015YF00L005YFFUIJ
EP00FUH00003FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YF00000P0015YF00<005YFFUH01UYF0`00<Goo0018Ool30007FUH01@00FUIJEUYF00000UYF0`00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YFFUH00P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000QJEP03001JEUYF00AJ
EP8003=oo`00AGoo0`0000=JEP00FUH01eYF00@005YFFUIJEP<00003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000eOol0049oo`<000EJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF00IJEP04001JEP00000g
Ool003moo`<000QJEP03001JEUYF00IJEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40008FUH;000iOol003eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPT000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH90004FUH01000FUIJEUYF1P00=Woo
000jOol30004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP050003FUH01000FUIJEUYF
1`0000=JEP00FUH00eYF60000eYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00IJEP03001JEP0000L000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00D0035oo`00=goo0`001eYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH02P002EYF1P0015YF1@000UYF
0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF
00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YF00000P00;Woo000eOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH?0004FUH00`00FUIJ
EP04FUH01000FUIJEUYF10001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00
0UYF00<005YFFUH00UYF00<005YFFUH010001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<goo0P0015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0`001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool0035oo`8000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000=J
EP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000`Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002FUH500001EYF000005YF00000UYF2@0015YF00<005YFFUH01eYF0`00
1EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002io
o`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00800003FUH0
0000009JEP04001JEP000003FUH00`00FUIJEP05FUH01000FUIJEUYF1P001eYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002eoo`03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00<00004FUH0
05YFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH00eYF
0P000UYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUH00006FUH0
1000FUH000002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00:goo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP800003FUH0000000800005FUH005YFFUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20008FUH30005FUH3000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000[Ool01000FUIJEP0015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00`000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF0P001UYF00<005YFFUH01@000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH015YF2@002Woo1@001EYF10000eYF0P00;7oo000[Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0`000eYF00<005YF
FUH00eYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001Goo3P000eYF00<005YFFUH015YF00@0
05YFFUIJEP800003FUH0000002aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEP00008000EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEP80009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH;0004
Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000/Ool002aoo`04001J
EUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH20008FUH00`00FUIJEP02FUH00`00FUH00004
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70002FUH20006FUH20002FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP050003
FUH01000FUIJEUYF200015YF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF
0`00;7oo000]Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP08
FUH01000FUIJEP0015YF0P0000=oo`0000005P002EYF00@005YF000000=JEP06001JEUYF001JEP00
35YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH0100000=JEP0000000P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000;7oo000]Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH01eYF0`001UYF00<007ooOol037oo00<005YFFUH01`002EYF00@005YF
FUIJEP800003FUH005YF009JEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00;Goo00@005YFFUH000AJEP03001JEUYF00IJ
EP04001JEP000005FUH>0006FUH4000;Ool00`00FUIJEP070009FUH00`00FUIJEP03FUH20003FUH0
0`00FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P00;Woo000^Ool00`00FUH00005FUH00`00FUIJEP04FUH300000eYF
000000040004FUH00`00FUIJEP06FUH20004FUH01000FUIJEUYF1P001Woo00<005YFFUH01`002EYF
00<005YFFUH01EYF00H005YFFUH005YF000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01`00FUIJ
EUYF001JEP0000=JEP04001JEUYFFUH60004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP04FUH01000FUH00000<7oo000^Ool01000FUIJEP0015YF00<005YFFUH00UYF1P0000=J
EP00FUH01eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP<00003FUH0000000Ao
o`05001JEUYF001JEP0300000eYF001JEP09FUH00`00FUIJEP04FUH01000FUH005YF0P002eYF00<0
05YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP8000=JEPD000=JEP03001JEUYF00T000AJEP03
001JEUYF00MJEP<000IJEP03001JEUYF00=JEP<0039oo`00;Woo00@005YFFUH000EJEP03001JEP00
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20008FUH40004Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP0000002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00@005YFFUIJEP800004FUH000000002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP060008FUH00`00FUIJEP020004FUH00`00FUH00003000eOol002moo`03001JEP0000=J
EP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00@00005Ool005YFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00D005YFFUH005YF00800003FUH00000009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP800004
FUH00000000iOol002moo`04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH200000eYF0000000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP020003
FUH300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP0300000eYF001J
EP06FUH2000kOol002moo`03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00MJEP03001JEP0000<000=JEP03001JEUYF
00MJEP03001JEUYF00=JEP800005FUH00000FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
1000FUIJEP0015YF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`0025YF0`00>Goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP04FUH70006FUH0
0`00FUH000030003FUH200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJ
EP0015YF00<005YFFUH00UYF6`000goo0P001EYF00@005YFFUIJEP8003Moo`00;Goo0`000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00`001eYF00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00T005YFFUIJEP00FUH005YF
00002eYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUH000AJEP03001JEUYF009JEP8001Ao
o`<000Moo`8000=JEP03001JEUYF00=JEP03001oogoo03Aoo`00;7oo00@005YFFUH000=JEPT000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5000@Ool50008Ool3
0006FUH2000eOol002aoo`03001JEUYF00D000=JEP04001JEUYFFUH700000eYF001JEP07FUH00`00
FUIJEP02FUH?0003FUH00`00FUIJEP060006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF1@002goo1@002Woo00<005YFFUH015YF00<005YF0000=7oo000/Ool00`00
FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH90004Ool60004FUH50002FUH20003
Ool00eYF000000020002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`001EYF
00<005YF00000P0027oo1@002goo0P000eYF00D005YFFUIJEP0003=oo`00;7oo0P000UYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1P000Woo1`0015YF00<005YFFUH015YF00@005YF
FUIJEP@000=oo`05001JEUYF001JEP060004FUH01000FUIJEUYF1@001eYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF00D005YFFUIJ
EP0000Uoo`<000ioo`800003FUH005YF00=JEP03001oogoo031oo`00:goo0P000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF0`000goo00@005YFFUH000EJEP03001JEP0000P000aJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00YJEP<000AJEP04001JEUYFFUH2000KOol2
0004FUH00`00Oomoo`0`Ool002Yoo`8000=JEP04001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003Ool01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH00P000UYF00@005YFFUIJEP8001eoo`03001JEUYF0080039oo`00:Woo
0P000UYF1@0000EJEP00001JEP00009JEPL000IJEP03001JEUYF00MJEP<000EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000=oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP03
FUH30003FUH2000MOol00`00FUIJEP02000bOol002Uoo`800003FUH00000009JEP04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0P0017oo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF015JEP<00003FUH0
000001ioo`800003FUH007oo035oo`00:Goo0`0000Aoo`00FUIJEP<000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP@000MJEP03001JEUYF00=JEP80009JEP03001JEUYF00AJEP05001JEUYFFUH00005
Ool01000FUIJEP0045YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH04UYF00<005YF00000`007Woo00<005YF0000<Woo000XOol30003Ool01000FUH0
00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<0
05YF00001UYF00@005YF000000Ioo`04001JEUYF000@FUH00`00FUIJEP09FUH00`00FUIJEP04FUHN
000<FUH00`00FUIJEP04FUH00`00FUIJEP04FUH5000IOol00`00FUH0000bOol002Qoo`04001JEP00
0002Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0008FUH30005FUH30008Ool01000FUIJEP0045YF00<005YFFUH01eYF2@002UYF0P002eYF00<005YF
FUH01EYF0P002UYF0P0015YF00<005YFFUH01UYF00<005YFFUH010004goo1000<goo000XOol01`00
FUH005YF001oo`0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00EJEP8000IJEP03001JEUYF00D000]oo`04001JEUYF000@FUH01000FUIJEUYF1P0025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF00000P001EYF00H005YF000005YF0009
FUH00`00FUIJEP04FUH60008Ool50002FUH2000cOol002Qoo`03001JEUYF009JEP8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF009J
EP8000eoo`03001JEUYF011JEPD00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH01000
FUIJEUYF20000eYF00H005YFFUH005YF000cOol002Uoo`03001JEUYF009JEP80009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF
00EJEP03001oogoo00Yoo`03001JEUYF00eJEP<000IJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
0003FUH005YF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF009JEP04001JEUYF
FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000dOol0
02Uoo`03001JEUYF009JEPL000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL0
009oo`8000IJEP8000]oo`03001JEUYF00UJEP@000UJEP03001JEUYF00YJEP03001JEUYF00EJEP04
001JEUYFFUH70005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000=Goo000ZOol01@00FUIJEUYF0000
0UYF0P000Woo1`0015YF00<005YFFUH00UYF20002goo0P0015YF00<005YF00002goo2EYF0P000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01000
00=JEP00FUH025YF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YF000017oo10000UYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF000003Ioo`00:goo00<005YF00001EYF0P001goo
2@000Woo1@003Woo00@005YFFUH000=JEP03001oogoo00Qoo`MJEP8000AJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF009JEP8000Uoo`H000AJEP04001JEUYFFUH5000h
Ool002aoo`8000IJEP<0011oo`D000moo`<000=JEP03001oogoo00Qoo`EJEP8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH2000@Ool8000mOol002eoo`03001J
EUYF00=JEP04001JEUYFFUH2000>Ool5000AOol01@00FUIJEUYF00002Woo0eYF0P0025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH00eYF100015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH015YF0P001EYF00@005YF000005Moo`00;Woo0P000eYF00<005YFFUH00eYF0P003Goo
0`004goo00D005YF001JEP0000Uoo`9JEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00MJEPL000QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000AJEP<005Uoo`00<7oo
0`0025YF0P008Woo0P0000=JEP00Ool027oo00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00@005YFFUIJEP@0009JEP03001JEP0000UJEP03001J
EUYF00=JEP800003FUH00000008005aoo`00<Woo00<005YFFUH01UYF00<005YF00000P0087oo00<0
05YF00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01EYF1@002EYF00@005YFFUIJEPD0061oo`00<goo0P001UYF00<005YFFUH00UYF
0`0077oo0P0000=JEP00Ool027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF0P002eYF00<005YFFUH02EYF00<005YFFUH01eYF00D005YF000005YF0080069oo`00=Goo0P00
0eYF00<005YFFUH01UYF1@005Goo0P0000=JEP0000002goo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
0`0015YF0P00HGoo000gOol200000eYF001JEP07FUH00`00FUIJEP02FUH90008Ool40003FUH2000;
Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP02001OOol003Uoo`<000MJEP03001JEUYF
00IJEP03001JEUYF009JEPP0009JEP07001JEUYFFUH005YF00003Goo0P0000=JEP00FUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`0017oo
0P000eYF00<005YFFUH00UYF00<007ooOol0G7oo000lOol40002FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0047oo0`001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF1@002Goo0`001UYF00<007ooOol0Fgoo0010Ool50006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0057oo10000UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P0000=oo`0000000`002Woo00<005YFFUH0
15YF0P00G7oo0015Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000006Woo2000
1EYF00<005YFFUH02UYF00<005YFFUH015YF2@001goo1@002goo0P0015YF00@005YF000005Yoo`00
BGoo1P0015YF00@005YFFUIJEPD002AooaT0011oo`D000eoo`04001JEUYF0004FUH00`00Oomoo`1G
Ool004moo`P003Ioo`8000IJEP<0019oo`<000moo`<000AJEP03001oogoo05Moo`00SWoo00<005YF
FUH015YF00<005YFFUH00P0097oo00@005YFFUIJEP8005Uoo`00Sgoo0P000eYF00<005YFFUH00eYF
0P008goo00<005YFFUH00P00FGoo002AOol200000eYF001JEP06FUH3000QOol200000eYF001oo`1H
Ool009=oo`8000QJEP04001JEP00000POol00`00FUH0001IOol009Eoo`8000EJEP03001JEUYF009J
EP<001eoo`03001JEP0005Uoo`00Ugoo0P000eYF00<005YFFUH01EYF1P005Goo1000FWoo002IOol3
0009FUH00`00FUIJEP02FUH80008Ool50002FUH2001JOol009]oo`<000IJEP03001JEUYF00MJEP04
001JEUYFFUH80003FUH01P00FUIJEP00FUH005Yoo`00WWoo10000UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P00Fgoo002ROol50006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000G7oo002WOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUH00000GGoo002[Ool60004FUH01000FUIJEUYF1@00Ggoo002aOol8001TOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60018 .74286 m .58794 .68744 L .55754 .69256 L p .707 .577 .707 r
F P
0 g
s
.58794 .68744 m .60018 .74286 L .63131 .73574 L p .707 .577 .707 r
F P
0 g
s
.63131 .73574 m .61908 .68032 L .58794 .68744 L p .707 .577 .707 r
F P
0 g
s
.61908 .68032 m .63131 .73574 L .66014 .72733 L p .707 .577 .707 r
F P
0 g
s
.66014 .72733 m .64791 .67191 L .61908 .68032 L p .707 .577 .707 r
F P
0 g
s
.56978 .74799 m .55754 .69256 L .53086 .6952 L p .707 .577 .707 r
F P
0 g
s
.55754 .69256 m .56978 .74799 L .60018 .74286 L p .707 .577 .707 r
F P
0 g
s
.64791 .67191 m .66014 .72733 L .68384 .71845 L p .707 .577 .707 r
F P
0 g
s
.68384 .71845 m .6716 .66302 L .64791 .67191 L p .707 .577 .707 r
F P
0 g
s
.53086 .6952 m .5431 .75063 L .56978 .74799 L p .707 .577 .707 r
F P
0 g
s
.5983 .80644 m .59587 .76921 L .56476 .7694 L p .707 .577 .707 r
F P
0 g
s
.59587 .76921 m .5983 .80644 L .63008 .80379 L p .707 .577 .707 r
F P
0 g
s
.63008 .80379 m .62764 .76656 L .59587 .76921 L p .707 .577 .707 r
F P
0 g
s
.62764 .76656 m .63008 .80379 L .65941 .79892 L p .707 .577 .707 r
F P
0 g
s
.65941 .79892 m .65697 .76169 L .62764 .76656 L p .707 .577 .707 r
F P
0 g
s
.5431 .75063 m .53086 .6952 L .5105 .69509 L p .707 .577 .707 r
F P
0 g
s
.5672 .80663 m .56476 .7694 L .53737 .76709 L p .707 .577 .707 r
F P
0 g
s
.56476 .7694 m .5672 .80663 L .5983 .80644 L p .707 .577 .707 r
F P
0 g
s
.6716 .66302 m .68384 .71845 L .70008 .70997 L p .707 .577 .707 r
F P
0 g
s
.70008 .70997 m .68785 .65454 L .6716 .66302 L p .707 .577 .707 r
F P
0 g
s
.65697 .76169 m .65941 .79892 L .68343 .79231 L p .707 .577 .707 r
F P
0 g
s
.68343 .79231 m .681 .75508 L .65697 .76169 L p .707 .577 .707 r
F P
0 g
s
.53737 .76709 m .53981 .80432 L .5672 .80663 L p .707 .577 .707 r
F P
0 g
s
.5105 .69509 m .52274 .75052 L .5431 .75063 L p .707 .577 .707 r
F P
0 g
s
.58528 .85797 m .58809 .83997 L .55728 .83333 L p .707 .577 .707 r
F P
0 g
s
.58809 .83997 m .58528 .85797 L .61678 .86147 L p .707 .577 .707 r
F P
0 g
s
.61678 .86147 m .61959 .84348 L .58809 .83997 L p .707 .577 .707 r
F P
0 g
s
.53981 .80432 m .53737 .76709 L .51638 .76251 L p .707 .577 .707 r
F P
0 g
s
.61959 .84348 m .61678 .86147 L .6459 .86149 L p .707 .577 .707 r
F P
0 g
s
.6459 .86149 m .64871 .8435 L .61959 .84348 L p .707 .577 .707 r
F P
0 g
s
.55447 .85132 m .55728 .83333 L .53019 .82419 L p .707 .577 .707 r
F P
0 g
s
.55728 .83333 m .55447 .85132 L .58528 .85797 L p .707 .577 .707 r
F P
0 g
s
.52274 .75052 m .5105 .69509 L .49847 .69224 L p .707 .577 .707 r
F P
0 g
s
.51638 .76251 m .51882 .79974 L .53981 .80432 L p .707 .577 .707 r
F P
0 g
s
.681 .75508 m .68343 .79231 L .69979 .78461 L p .707 .577 .707 r
F P
0 g
s
.69979 .78461 m .69735 .74738 L .681 .75508 L p .707 .577 .707 r
F P
0 g
s
.53019 .82419 m .52738 .84218 L .55447 .85132 L p .707 .577 .707 r
F P
0 g
s
.68785 .65454 m .70008 .70997 L .70729 .70272 L p .707 .577 .707 r
F P
0 g
s
.70729 .70272 m .69505 .64729 L .68785 .65454 L p .707 .577 .707 r
F P
0 g
s
.64871 .8435 m .6459 .86149 L .66979 .85802 L p .707 .577 .707 r
F P
0 g
s
.66979 .85802 m .6726 .84003 L .64871 .8435 L p .707 .577 .707 r
F P
0 g
s
.49847 .69224 m .5107 .74766 L .52274 .75052 L p .707 .577 .707 r
F P
0 g
s
.52738 .84218 m .53019 .82419 L .50946 .81345 L p .707 .577 .707 r
F P
0 g
s
.51882 .79974 m .51638 .76251 L .50384 .75612 L p .707 .577 .707 r
F P
0 g
s
.50946 .81345 m .50665 .83145 L .52738 .84218 L p .707 .577 .707 r
F P
0 g
s
.50384 .75612 m .50627 .79335 L .51882 .79974 L p .707 .577 .707 r
F P
0 g
s
.69735 .74738 m .69979 .78461 L .70689 .77658 L p .707 .577 .707 r
F P
0 g
s
.70689 .77658 m .70445 .73935 L .69735 .74738 L p .707 .577 .707 r
F P
0 g
s
.5107 .74766 m .49847 .69224 L .49593 .68693 L p .707 .577 .707 r
F P
0 g
s
.6726 .84003 m .66979 .85802 L .6861 .85141 L p .707 .577 .707 r
F P
0 g
s
.6861 .85141 m .68891 .83341 L .6726 .84003 L p .707 .577 .707 r
F P
0 g
s
.50665 .83145 m .50946 .81345 L .49713 .80217 L p .707 .577 .707 r
F P
0 g
s
.69505 .64729 m .70729 .70272 L .70475 .69741 L p .707 .577 .707 r
F P
0 g
s
.70475 .69741 m .69251 .64198 L .69505 .64729 L p .707 .577 .707 r
F P
0 g
s
.49713 .80217 m .49432 .82017 L .50665 .83145 L p .707 .577 .707 r
F P
0 g
s
.49593 .68693 m .50816 .74235 L .5107 .74766 L p .707 .577 .707 r
F P
0 g
s
.50627 .79335 m .50384 .75612 L .50097 .74854 L p .707 .577 .707 r
F P
0 g
s
.50097 .74854 m .50341 .78577 L .50627 .79335 L p .707 .577 .707 r
F P
0 g
s
.50816 .74235 m .49593 .68693 L .50313 .67968 L p .707 .577 .707 r
F P
0 g
s
.50313 .67968 m .51537 .7351 L .50816 .74235 L p .707 .577 .707 r
F P
0 g
s
.50341 .78577 m .50097 .74854 L .50806 .7405 L p .707 .577 .707 r
F P
0 g
s
.50806 .7405 m .5105 .77773 L .50341 .78577 L p .707 .577 .707 r
F P
0 g
s
.49432 .82017 m .49713 .80217 L .4944 .79145 L p .707 .577 .707 r
F P
0 g
s
.4944 .79145 m .49159 .80944 L .49432 .82017 L p .707 .577 .707 r
F P
0 g
s
.49159 .80944 m .4944 .79145 L .50154 .78233 L p .707 .577 .707 r
F P
0 g
s
.50154 .78233 m .49873 .80033 L .49159 .80944 L p .707 .577 .707 r
F P
0 g
s
.49873 .80033 m .50154 .78233 L .51785 .77572 L p .707 .577 .707 r
F P
0 g
s
.51785 .77572 m .51504 .79371 L .49873 .80033 L p .707 .577 .707 r
F P
0 g
s
.5057 .82114 m .48264 .31735 L .43868 .31672 L p .707 .577 .707 r
F P
0 g
s
.51537 .7351 m .50313 .67968 L .51938 .67119 L p .707 .577 .707 r
F P
0 g
s
.51938 .67119 m .53161 .72662 L .51537 .7351 L p .707 .577 .707 r
F P
0 g
s
.5105 .77773 m .50806 .7405 L .52442 .7328 L p .707 .577 .707 r
F P
0 g
s
.52442 .7328 m .52686 .77003 L .5105 .77773 L p .707 .577 .707 r
F P
0 g
s
.53161 .72662 m .51938 .67119 L .54307 .66231 L p .707 .577 .707 r
F P
0 g
s
.54307 .66231 m .55531 .71774 L .53161 .72662 L p .707 .577 .707 r
F P
0 g
s
.52686 .77003 m .52442 .7328 L .54844 .7262 L p .707 .577 .707 r
F P
0 g
s
.54844 .7262 m .55088 .76343 L .52686 .77003 L p .707 .577 .707 r
F P
0 g
s
.51504 .79371 m .51785 .77572 L .54174 .77225 L p .707 .577 .707 r
F P
0 g
s
.54174 .77225 m .53893 .79024 L .51504 .79371 L p .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .54174 .77225 L .55695 .77226 L p .707 .577 .707 r
F P
0 g
s
.55695 .77226 m .57086 .77227 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.53893 .79024 m .55695 .77226 L .55233 .7827 L .707 .577 .707 r
F
.48264 .31735 m .5057 .82114 L .53622 .81914 L p F P
0 g
s
.53622 .81914 m .5506 .8182 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.5506 .8182 m .54929 .78957 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.60236 .77577 m .59956 .79377 L .56913 .79038 L p .707 .577 .707 r
F P
0 g
s
.56896 .78988 m .60236 .77577 L .56913 .79038 L .707 .577 .707 r
F
.54929 .78957 m .5506 .8182 L p .57244 .80016 L F P
0 g
s
.57086 .77227 m .60236 .77577 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .57086 .77227 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.58877 .78667 m .56838 .78817 L .57244 .80016 L .707 .577 .707 r
F
.56838 .78817 m .54929 .78957 L .57244 .80016 L F
.56805 .79026 m .56838 .78817 L p .56896 .78988 L F P
0 g
s
.56913 .79038 m .56805 .79026 L p .56896 .78988 L .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .58877 .78667 L .57244 .80016 L .707 .577 .707 r
F
.5506 .8182 m .5772 .81419 L p .57244 .80016 L F P
0 g
s
.5772 .81419 m .59205 .81196 L p .57244 .80016 L .707 .577 .707 r
F P
0 g
s
.57086 .77227 m .56838 .78817 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.54899 .79025 m .53893 .79024 L p .55233 .7827 L .707 .577 .707 r
F P
0 g
s
.55233 .7827 m .57086 .77227 L .54899 .79025 L .707 .577 .707 r
F
.55531 .71774 m .54307 .66231 L .56716 .65528 L p F P
0 g
s
.56716 .65528 m .5719 .6539 L p .57005 .66102 L .707 .577 .707 r
F P
0 g
s
.55531 .71774 m .56716 .65528 L .57005 .66102 L .707 .577 .707 r
F
.54929 .78957 m .54075 .60279 L p .54732 .79402 L F P
0 g
s
.54075 .60279 m .52755 .3144 L p .53932 .59996 L .707 .577 .707 r
F P
0 g
s
.54075 .60279 m .53932 .59996 L .54732 .79402 L .707 .577 .707 r
F
.5719 .6539 m .58414 .70933 L .55531 .71774 L p F P
0 g
s
.55088 .76343 m .54844 .7262 L .57778 .72133 L p .707 .577 .707 r
F P
0 g
s
.57778 .72133 m .58022 .75856 L .55088 .76343 L p .707 .577 .707 r
F P
0 g
s
.58022 .75856 m .57778 .72133 L .60955 .71867 L p .707 .577 .707 r
F P
0 g
s
.60955 .71867 m .61199 .7559 L .58022 .75856 L p .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .54929 .78957 L p .58877 .78667 L .707 .577 .707 r
F P
0 g
s
.56805 .79026 m .54899 .79025 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.56838 .78817 m .56805 .79026 L p .54987 .78952 L .707 .577 .707 r
F P
0 g
s
.52755 .3144 m .48264 .31735 L p .54732 .79402 L .707 .577 .707 r
F P
0 g
s
.54732 .79402 m .48264 .31735 L .53622 .81914 L .707 .577 .707 r
F
.58414 .70933 m .5719 .6539 L .60304 .64678 L p F P
0 g
s
.60304 .64678 m .61527 .70221 L .58414 .70933 L p .707 .577 .707 r
F P
0 g
s
.59205 .81196 m .56899 .30816 L .52755 .3144 L p .707 .577 .707 r
F P
0 g
s
.68891 .83341 m .6861 .85141 L .69324 .84229 L p .707 .577 .707 r
F P
0 g
s
.69324 .84229 m .69605 .8243 L .68891 .83341 L p .707 .577 .707 r
F P
0 g
s
.70445 .73935 m .70689 .77658 L .70402 .76899 L p .707 .577 .707 r
F P
0 g
s
.70402 .76899 m .70158 .73176 L .70445 .73935 L p .707 .577 .707 r
F P
0 g
s
.46174 .82051 m .43868 .31672 L .39997 .31257 L p .707 .577 .707 r
F P
0 g
s
.43868 .31672 m .46174 .82051 L .5057 .82114 L p .707 .577 .707 r
F P
0 g
s
.69251 .64198 m .70475 .69741 L .69271 .69456 L p .707 .577 .707 r
F P
0 g
s
.69271 .69456 m .68048 .63913 L .69251 .64198 L p .707 .577 .707 r
F P
0 g
s
.61527 .70221 m .60304 .64678 L .63344 .64165 L p .707 .577 .707 r
F P
0 g
s
.64066 .71849 m .64309 .75572 L .61199 .7559 L p .707 .577 .707 r
F P
0 g
s
.61199 .7559 m .60955 .71867 L .64066 .71849 L p .707 .577 .707 r
F P
0 g
s
.63317 .78242 m .63036 .80041 L .59956 .79377 L p .707 .577 .707 r
F P
0 g
s
.59956 .79377 m .60236 .77577 L .63317 .78242 L p .707 .577 .707 r
F P
0 g
s
.56899 .30816 m .59205 .81196 L .62599 .80304 L p .707 .577 .707 r
F P
0 g
s
.63344 .64165 m .64567 .69708 L .61527 .70221 L p .707 .577 .707 r
F P
0 g
s
.62599 .80304 m .60293 .29924 L .56899 .30816 L p .707 .577 .707 r
F P
0 g
s
.25717 .70482 m .24493 .6494 L .21454 .65452 L p .707 .577 .707 r
F P
0 g
s
.24493 .6494 m .25717 .70482 L .2883 .6977 L p .707 .577 .707 r
F P
0 g
s
.2883 .6977 m .27607 .64228 L .24493 .6494 L p .707 .577 .707 r
F P
0 g
s
.27607 .64228 m .2883 .6977 L .31713 .68929 L p .707 .577 .707 r
F P
0 g
s
.31713 .68929 m .3049 .63387 L .27607 .64228 L p .707 .577 .707 r
F P
0 g
s
.42302 .81636 m .39997 .31257 L .37028 .30531 L p .707 .577 .707 r
F P
0 g
s
.39997 .31257 m .42302 .81636 L .46174 .82051 L p .707 .577 .707 r
F P
0 g
s
.69605 .8243 m .69324 .84229 L .69051 .83157 L p .707 .577 .707 r
F P
0 g
s
.69051 .83157 m .69332 .81357 L .69605 .8243 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22677 .70995 m .21454 .65452 L .18785 .65716 L p .707 .577 .707 r
F P
0 g
s
.21454 .65452 m .22677 .70995 L .25717 .70482 L p .707 .577 .707 r
F P
0 g
s
.70158 .73176 m .70402 .76899 L .69148 .7626 L p .707 .577 .707 r
F P
0 g
s
.69148 .7626 m .68904 .72537 L .70158 .73176 L p .707 .577 .707 r
F P
0 g
s
.3049 .63387 m .31713 .68929 L .34083 .68041 L p .707 .577 .707 r
F P
0 g
s
.34083 .68041 m .32859 .62498 L .3049 .63387 L p .707 .577 .707 r
F P
0 g
s
.68048 .63913 m .69271 .69456 L .67235 .69444 L p .707 .577 .707 r
F P
0 g
s
.67235 .69444 m .66012 .63902 L .68048 .63913 L p .707 .577 .707 r
F P
0 g
s
.18785 .65716 m .20009 .71259 L .22677 .70995 L p .707 .577 .707 r
F P
0 g
s
.64567 .69708 m .63344 .64165 L .66012 .63902 L p .707 .577 .707 r
F P
0 g
s
.66805 .72079 m .67048 .75802 L .64309 .75572 L p .707 .577 .707 r
F P
0 g
s
.64309 .75572 m .64066 .71849 L .66805 .72079 L p .707 .577 .707 r
F P
0 g
s
.66027 .79156 m .65746 .80955 L .63036 .80041 L p .707 .577 .707 r
F P
0 g
s
.63036 .80041 m .63317 .78242 L .66027 .79156 L p .707 .577 .707 r
F P
0 g
s
.60293 .29924 m .62599 .80304 L .64909 .79231 L p .707 .577 .707 r
F P
0 g
s
.64909 .79231 m .62603 .28852 L .60293 .29924 L p .707 .577 .707 r
F P
0 g
s
.2553 .77269 m .25286 .73546 L .22175 .73564 L p .707 .577 .707 r
F P
0 g
s
.25286 .73546 m .2553 .77269 L .28707 .77003 L p .707 .577 .707 r
F P
0 g
s
.28707 .77003 m .28463 .7328 L .25286 .73546 L p .707 .577 .707 r
F P
0 g
s
.28463 .7328 m .28707 .77003 L .3164 .76516 L p .707 .577 .707 r
F P
0 g
s
.3164 .76516 m .31396 .72793 L .28463 .7328 L p .707 .577 .707 r
F P
0 g
s
.20009 .71259 m .18785 .65716 L .1675 .65705 L p .707 .577 .707 r
F P
0 g
s
.22419 .77287 m .22175 .73564 L .19436 .73333 L p .707 .577 .707 r
F P
0 g
s
.22175 .73564 m .22419 .77287 L .2553 .77269 L p .707 .577 .707 r
F P
0 g
s
.32859 .62498 m .34083 .68041 L .35707 .67193 L p .707 .577 .707 r
F P
0 g
s
.35707 .67193 m .34484 .6165 L .32859 .62498 L p .707 .577 .707 r
F P
0 g
s
.31396 .72793 m .3164 .76516 L .34042 .75855 L p .707 .577 .707 r
F P
0 g
s
.34042 .75855 m .33799 .72132 L .31396 .72793 L p .707 .577 .707 r
F P
0 g
s
.69332 .81357 m .69051 .83157 L .67818 .82029 L p .707 .577 .707 r
F P
0 g
s
.67818 .82029 m .68099 .80229 L .69332 .81357 L p .707 .577 .707 r
F P
0 g
s
.1675 .65705 m .17973 .71248 L .20009 .71259 L p .707 .577 .707 r
F P
0 g
s
.39334 .8091 m .37028 .30531 L .35254 .29565 L p .707 .577 .707 r
F P
0 g
s
.37028 .30531 m .39334 .8091 L .42302 .81636 L p .707 .577 .707 r
F P
0 g
s
.19436 .73333 m .1968 .77056 L .22419 .77287 L p .707 .577 .707 r
F P
0 g
s
.68904 .72537 m .69148 .7626 L .67048 .75802 L p .707 .577 .707 r
F P
0 g
s
.67048 .75802 m .66805 .72079 L .68904 .72537 L p .707 .577 .707 r
F P
0 g
s
.24227 .81561 m .24508 .79762 L .21427 .79097 L p .707 .577 .707 r
F P
0 g
s
.24508 .79762 m .24227 .81561 L .27377 .81912 L p .707 .577 .707 r
F P
0 g
s
.27377 .81912 m .27658 .80112 L .24508 .79762 L p .707 .577 .707 r
F P
0 g
s
.66012 .63902 m .67235 .69444 L .64567 .69708 L p .707 .577 .707 r
F P
0 g
s
.1968 .77056 m .19436 .73333 L .17337 .72876 L p .707 .577 .707 r
F P
0 g
s
.27658 .80112 m .27377 .81912 L .3029 .81913 L p .707 .577 .707 r
F P
0 g
s
.3029 .81913 m .3057 .80114 L .27658 .80112 L p .707 .577 .707 r
F P
0 g
s
.21146 .80897 m .21427 .79097 L .18718 .78183 L p .707 .577 .707 r
F P
0 g
s
.21427 .79097 m .21146 .80897 L .24227 .81561 L p .707 .577 .707 r
F P
0 g
s
.17973 .71248 m .1675 .65705 L .15546 .6542 L p .707 .577 .707 r
F P
0 g
s
.18718 .78183 m .18437 .79983 L .21146 .80897 L p .707 .577 .707 r
F P
0 g
s
.17337 .72876 m .17581 .76599 L .1968 .77056 L p .707 .577 .707 r
F P
0 g
s
.33799 .72132 m .34042 .75855 L .35678 .75085 L p .707 .577 .707 r
F P
0 g
s
.35678 .75085 m .35434 .71362 L .33799 .72132 L p .707 .577 .707 r
F P
0 g
s
.62603 .28852 m .64909 .79231 L .6591 .78083 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .63604 .27703 L .62603 .28852 L p .707 .577 .707 r
F P
0 g
s
.34484 .6165 m .35707 .67193 L .36428 .66468 L p .707 .577 .707 r
F P
0 g
s
.36428 .66468 m .35205 .60925 L .34484 .6165 L p .707 .577 .707 r
F P
0 g
s
.3057 .80114 m .3029 .81913 L .32678 .81567 L p .707 .577 .707 r
F P
0 g
s
.32678 .81567 m .32959 .79767 L .3057 .80114 L p .707 .577 .707 r
F P
0 g
s
.15546 .6542 m .16769 .70962 L .17973 .71248 L p .707 .577 .707 r
F P
0 g
s
.18437 .79983 m .18718 .78183 L .16645 .7711 L p .707 .577 .707 r
F P
0 g
s
.68099 .80229 m .67818 .82029 L .65746 .80955 L p .707 .577 .707 r
F P
0 g
s
.65746 .80955 m .66027 .79156 L .68099 .80229 L p .707 .577 .707 r
F P
0 g
s
.16645 .7711 m .16364 .78909 L .18437 .79983 L p .707 .577 .707 r
F P
0 g
s
.17581 .76599 m .17337 .72876 L .16083 .72236 L p .707 .577 .707 r
F P
0 g
s
.3756 .79944 m .35254 .29565 L .34847 .28453 L p .707 .577 .707 r
F P
0 g
s
.35254 .29565 m .3756 .79944 L .39334 .8091 L p .707 .577 .707 r
F P
0 g
s
.16083 .72236 m .16326 .75959 L .17581 .76599 L p .707 .577 .707 r
F P
0 g
s
.32959 .79767 m .32678 .81567 L .34309 .80905 L p .707 .577 .707 r
F P
0 g
s
.34309 .80905 m .3459 .79106 L .32959 .79767 L p .707 .577 .707 r
F P
0 g
s
.16769 .70962 m .15546 .6542 L .15292 .64889 L p .707 .577 .707 r
F P
0 g
s
.35434 .71362 m .35678 .75085 L .36388 .74282 L p .707 .577 .707 r
F P
0 g
s
.36388 .74282 m .36144 .70559 L .35434 .71362 L p .707 .577 .707 r
F P
0 g
s
.16364 .78909 m .16645 .7711 L .15412 .75982 L p .707 .577 .707 r
F P
0 g
s
.35205 .60925 m .36428 .66468 L .36174 .65937 L p .707 .577 .707 r
F P
0 g
s
.36174 .65937 m .34951 .60394 L .35205 .60925 L p .707 .577 .707 r
F P
0 g
s
.15412 .75982 m .15131 .77781 L .16364 .78909 L p .707 .577 .707 r
F P
0 g
s
.15292 .64889 m .16515 .70431 L .16769 .70962 L p .707 .577 .707 r
F P
0 g
s
.16326 .75959 m .16083 .72236 L .15796 .71478 L p .707 .577 .707 r
F P
0 g
s
.6591 .78083 m .65503 .76971 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64422 .45583 m .6591 .78083 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .63604 .27703 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.65503 .76971 m .64504 .55148 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.64504 .55148 m .63197 .26592 L p .64459 .4989 L .707 .577 .707 r
F P
0 g
s
.63197 .26592 m .65503 .76971 L .64867 .76625 L p .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64386 .73941 L .64456 .73978 L p .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .63651 .68782 L .64418 .73731 L .707 .577 .707 r
F
.63651 .68782 m .63197 .26592 L .64867 .76625 L F
.61423 .25626 m .63197 .26592 L p .63698 .73215 L F P
0 g
s
.64386 .73941 m .64287 .73637 L .63597 .73142 L .707 .577 .707 r
F
.61423 .25626 m .63597 .73142 L p .6076 .75279 L F P
0 g
s
.62778 .75772 m .6076 .75279 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63201 .72857 m .63579 .73203 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63579 .73203 m .64386 .73941 L p .63597 .73142 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .63728 .76005 L .62778 .75772 L p .707 .577 .707 r
F P
0 g
s
.63728 .76005 m .63597 .73142 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63597 .73142 m .61423 .25626 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63433 .71013 m .63152 .72813 L .63201 .72857 L p .707 .577 .707 r
F P
0 g
s
.64287 .73637 m .63433 .71013 L .63201 .72857 L .707 .577 .707 r
F
.64666 .72142 m .63433 .71013 L p .64287 .73637 L F P
0 g
s
.64386 .73941 m .64418 .73731 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64418 .73731 m .64666 .72142 L p .64287 .73637 L .707 .577 .707 r
F P
0 g
s
.64867 .76625 m .63728 .76005 L p .63698 .73215 L .707 .577 .707 r
F P
0 g
s
.63698 .73215 m .64418 .73731 L .64867 .76625 L .707 .577 .707 r
F
.64666 .72142 m .64418 .73731 L p .66458 .75015 L F P
0 g
s
.64456 .73978 m .66458 .75015 L p .64418 .73731 L .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .65994 .65848 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.63567 .6002 m .64585 .64633 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.64585 .64633 m .64791 .65563 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64771 .60305 L .64548 .60252 L p .707 .577 .707 r
F P
0 g
s
.64548 .60252 m .63567 .6002 L p .64566 .62419 L .707 .577 .707 r
F P
0 g
s
.65994 .65848 m .64548 .60252 L .64566 .62419 L .707 .577 .707 r
F
.63604 .27703 m .64422 .45583 L p .64459 .4989 L F P
0 g
s
.15796 .71478 m .1604 .75201 L .16326 .75959 L p .707 .577 .707 r
F P
0 g
s
.3459 .79106 m .34309 .80905 L .35023 .79993 L p .707 .577 .707 r
F P
0 g
s
.35023 .79993 m .35304 .78194 L .3459 .79106 L p .707 .577 .707 r
F P
0 g
s
.15131 .77781 m .15412 .75982 L .15139 .74909 L p .707 .577 .707 r
F P
0 g
s
.36144 .70559 m .36388 .74282 L .36101 .73524 L p .707 .577 .707 r
F P
0 g
s
.36101 .73524 m .35857 .69801 L .36144 .70559 L p .707 .577 .707 r
F P
0 g
s
.16515 .70431 m .15292 .64889 L .16012 .64164 L p .707 .577 .707 r
F P
0 g
s
.15139 .74909 m .14858 .76709 L .15131 .77781 L p .707 .577 .707 r
F P
0 g
s
.34951 .60394 m .36174 .65937 L .3497 .65652 L p .707 .577 .707 r
F P
0 g
s
.3497 .65652 m .33747 .60109 L .34951 .60394 L p .707 .577 .707 r
F P
0 g
s
.34847 .28453 m .37153 .78833 L .3756 .79944 L p .707 .577 .707 r
F P
0 g
s
.37153 .78833 m .34847 .28453 L .35848 .27305 L p .707 .577 .707 r
F P
0 g
s
.16012 .64164 m .17236 .69706 L .16515 .70431 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1604 .75201 m .15796 .71478 L .16506 .70674 L p .707 .577 .707 r
F P
0 g
s
.35304 .78194 m .35023 .79993 L .3475 .78921 L p .707 .577 .707 r
F P
0 g
s
.3475 .78921 m .35031 .77122 L .35304 .78194 L p .707 .577 .707 r
F P
0 g
s
.16506 .70674 m .16749 .74397 L .1604 .75201 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14858 .76709 m .15139 .74909 L .15853 .73998 L p .707 .577 .707 r
F P
0 g
s
.17236 .69706 m .16012 .64164 L .17637 .63315 L p .707 .577 .707 r
F P
0 g
s
.35857 .69801 m .36101 .73524 L .34847 .72884 L p .707 .577 .707 r
F P
0 g
s
.34847 .72884 m .34603 .69161 L .35857 .69801 L p .707 .577 .707 r
F P
0 g
s
.15853 .73998 m .15572 .75797 L .14858 .76709 L p .707 .577 .707 r
F P
0 g
s
.33747 .60109 m .3497 .65652 L .32935 .6564 L p .707 .577 .707 r
F P
0 g
s
.32935 .6564 m .31711 .60098 L .33747 .60109 L p .707 .577 .707 r
F P
0 g
s
.17637 .63315 m .1886 .68858 L .17236 .69706 L p .707 .577 .707 r
F P
0 g
s
.16749 .74397 m .16506 .70674 L .18141 .69905 L p .707 .577 .707 r
F P
0 g
s
.38154 .77684 m .35848 .27305 L .38158 .26232 L p .707 .577 .707 r
F P
0 g
s
.35848 .27305 m .38154 .77684 L .37153 .78833 L p .707 .577 .707 r
F P
0 g
s
.35031 .77122 m .3475 .78921 L .33517 .77793 L p .707 .577 .707 r
F P
0 g
s
.33517 .77793 m .33798 .75993 L .35031 .77122 L p .707 .577 .707 r
F P
0 g
s
.18141 .69905 m .18385 .73628 L .16749 .74397 L p .707 .577 .707 r
F P
0 g
s
.1886 .68858 m .17637 .63315 L .20007 .62427 L p .707 .577 .707 r
F P
0 g
s
.15572 .75797 m .15853 .73998 L .17484 .73336 L p .707 .577 .707 r
F P
0 g
s
.34603 .69161 m .34847 .72884 L .32747 .72427 L p .707 .577 .707 r
F P
0 g
s
.32747 .72427 m .32504 .68704 L .34603 .69161 L p .707 .577 .707 r
F P
0 g
s
.31711 .60098 m .32935 .6564 L .30266 .65904 L p .707 .577 .707 r
F P
0 g
s
.30266 .65904 m .29043 .60361 L .31711 .60098 L p .707 .577 .707 r
F P
0 g
s
.17484 .73336 m .17203 .75136 L .15572 .75797 L p .707 .577 .707 r
F P
0 g
s
.20007 .62427 m .2123 .6797 L .1886 .68858 L p .707 .577 .707 r
F P
0 g
s
.6076 .75279 m .58454 .249 L .61423 .25626 L p .707 .577 .707 r
F P
0 g
s
.18385 .73628 m .18141 .69905 L .20543 .69244 L p .707 .577 .707 r
F P
0 g
s
.2123 .6797 m .20007 .62427 L .22889 .61586 L p .707 .577 .707 r
F P
0 g
s
.29043 .60361 m .30266 .65904 L .27226 .66417 L p .707 .577 .707 r
F P
0 g
s
.27226 .66417 m .26003 .60874 L .29043 .60361 L p .707 .577 .707 r
F P
0 g
s
.33798 .75993 m .33517 .77793 L .31445 .76719 L p .707 .577 .707 r
F P
0 g
s
.31445 .76719 m .31726 .7492 L .33798 .75993 L p .707 .577 .707 r
F P
0 g
s
.20543 .69244 m .20787 .72967 L .18385 .73628 L p .707 .577 .707 r
F P
0 g
s
.32504 .68704 m .32747 .72427 L .30008 .72196 L p .707 .577 .707 r
F P
0 g
s
.30008 .72196 m .29765 .68473 L .32504 .68704 L p .707 .577 .707 r
F P
0 g
s
.17203 .75136 m .17484 .73336 L .19873 .72989 L p .707 .577 .707 r
F P
0 g
s
.22889 .61586 m .24113 .67129 L .2123 .6797 L p .707 .577 .707 r
F P
0 g
s
.24113 .67129 m .22889 .61586 L .26003 .60874 L p .707 .577 .707 r
F P
0 g
s
.73738 .65082 m .72515 .5954 L .69475 .60053 L p .707 .577 .707 r
F P
0 g
s
.72515 .5954 m .73738 .65082 L .76852 .6437 L p .707 .577 .707 r
F P
0 g
s
.76852 .6437 m .75628 .58828 L .72515 .5954 L p .707 .577 .707 r
F P
0 g
s
.26003 .60874 m .27226 .66417 L .24113 .67129 L p .707 .577 .707 r
F P
0 g
s
.75628 .58828 m .76852 .6437 L .79734 .63529 L p .707 .577 .707 r
F P
0 g
s
.79734 .63529 m .78511 .57987 L .75628 .58828 L p .707 .577 .707 r
F P
0 g
s
.38158 .26232 m .40464 .76612 L .38154 .77684 L p .707 .577 .707 r
F P
0 g
s
.40464 .76612 m .38158 .26232 L .41552 .2534 L p .707 .577 .707 r
F P
0 g
s
.19873 .72989 m .19592 .74789 L .17203 .75136 L p .707 .577 .707 r
F P
0 g
s
.20787 .72967 m .20543 .69244 L .23477 .68757 L p .707 .577 .707 r
F P
0 g
s
.70698 .65595 m .69475 .60053 L .66806 .60316 L p .707 .577 .707 r
F P
0 g
s
.69475 .60053 m .70698 .65595 L .73738 .65082 L p .707 .577 .707 r
F P
0 g
s
.29765 .68473 m .30008 .72196 L .26898 .72214 L p .707 .577 .707 r
F P
0 g
s
.26898 .72214 m .26654 .68491 L .29765 .68473 L p .707 .577 .707 r
F P
0 g
s
.78511 .57987 m .79734 .63529 L .82104 .62641 L p .707 .577 .707 r
F P
0 g
s
.82104 .62641 m .80881 .57099 L .78511 .57987 L p .707 .577 .707 r
F P
0 g
s
.23477 .68757 m .23721 .7248 L .20787 .72967 L p .707 .577 .707 r
F P
0 g
s
.31726 .7492 m .31445 .76719 L .28735 .75806 L p .707 .577 .707 r
F P
0 g
s
.28735 .75806 m .29016 .74006 L .31726 .7492 L p .707 .577 .707 r
F P
0 g
s
.23721 .7248 m .23477 .68757 L .26654 .68491 L p .707 .577 .707 r
F P
0 g
s
.58454 .249 m .6076 .75279 L .56888 .74864 L p .707 .577 .707 r
F P
0 g
s
.56888 .74864 m .54583 .24485 L .58454 .249 L p .707 .577 .707 r
F P
0 g
s
.19592 .74789 m .19873 .72989 L .22785 .72991 L p .707 .577 .707 r
F P
0 g
s
.66806 .60316 m .6803 .65859 L .70698 .65595 L p .707 .577 .707 r
F P
0 g
s
.73551 .7144 m .73307 .67717 L .70197 .67736 L p .707 .577 .707 r
F P
0 g
s
.73307 .67717 m .73551 .7144 L .76728 .71175 L p .707 .577 .707 r
F P
0 g
s
.76728 .71175 m .76484 .67452 L .73307 .67717 L p .707 .577 .707 r
F P
0 g
s
.26654 .68491 m .26898 .72214 L .23721 .7248 L p .707 .577 .707 r
F P
0 g
s
.76484 .67452 m .76728 .71175 L .79662 .70688 L p .707 .577 .707 r
F P
0 g
s
.79662 .70688 m .79418 .66965 L .76484 .67452 L p .707 .577 .707 r
F P
0 g
s
.22785 .72991 m .22504 .74791 L .19592 .74789 L p .707 .577 .707 r
F P
0 g
s
.6803 .65859 m .66806 .60316 L .64771 .60305 L p .707 .577 .707 r
F P
0 g
s
.7044 .71459 m .70197 .67736 L .67458 .67505 L p .707 .577 .707 r
F P
0 g
s
.70197 .67736 m .7044 .71459 L .73551 .7144 L p .707 .577 .707 r
F P
0 g
s
.43857 .7572 m .41552 .2534 L .45696 .24716 L p .707 .577 .707 r
F P
0 g
s
.41552 .2534 m .43857 .7572 L .40464 .76612 L p .707 .577 .707 r
F P
0 g
s
.29016 .74006 m .28735 .75806 L .25655 .75141 L p .707 .577 .707 r
F P
0 g
s
.25655 .75141 m .25936 .73341 L .29016 .74006 L p .707 .577 .707 r
F P
0 g
s
.80881 .57099 m .82104 .62641 L .83729 .61793 L p .707 .577 .707 r
F P
0 g
s
.83729 .61793 m .82505 .5625 L .80881 .57099 L p .707 .577 .707 r
F P
0 g
s
.22504 .74791 m .22785 .72991 L .25936 .73341 L p .707 .577 .707 r
F P
0 g
s
.79418 .66965 m .79662 .70688 L .82064 .70027 L p .707 .577 .707 r
F P
0 g
s
.82064 .70027 m .8182 .66304 L .79418 .66965 L p .707 .577 .707 r
F P
0 g
s
.25936 .73341 m .25655 .75141 L .22504 .74791 L p .707 .577 .707 r
F P
0 g
s
.67458 .67505 m .67702 .71228 L .7044 .71459 L p .707 .577 .707 r
F P
0 g
s
.64771 .60305 m .65994 .65848 L .6803 .65859 L p .707 .577 .707 r
F P
0 g
s
.54583 .24485 m .56888 .74864 L .52492 .74801 L p .707 .577 .707 r
F P
0 g
s
.52492 .74801 m .50187 .24422 L .54583 .24485 L p .707 .577 .707 r
F P
0 g
s
.72248 .76593 m .72529 .74794 L .69448 .74129 L p .707 .577 .707 r
F P
0 g
s
.72529 .74794 m .72248 .76593 L .75399 .76943 L p .707 .577 .707 r
F P
0 g
s
.75399 .76943 m .7568 .75144 L .72529 .74794 L p .707 .577 .707 r
F P
0 g
s
.67702 .71228 m .67458 .67505 L .65358 .67047 L p .707 .577 .707 r
F P
0 g
s
.7568 .75144 m .75399 .76943 L .78311 .76945 L p .707 .577 .707 r
F P
0 g
s
.78311 .76945 m .78592 .75146 L .7568 .75144 L p .707 .577 .707 r
F P
0 g
s
.48002 .75096 m .45696 .24716 L .50187 .24422 L p .707 .577 .707 r
F P
0 g
s
.45696 .24716 m .48002 .75096 L .43857 .7572 L p .707 .577 .707 r
F P
0 g
s
.69167 .75928 m .69448 .74129 L .66739 .73215 L p .707 .577 .707 r
F P
0 g
s
.69448 .74129 m .69167 .75928 L .72248 .76593 L p .707 .577 .707 r
F P
0 g
s
.50187 .24422 m .52492 .74801 L .48002 .75096 L p .707 .577 .707 r
F P
0 g
s
.65358 .67047 m .65602 .7077 L .67702 .71228 L p .707 .577 .707 r
F P
0 g
s
.8182 .66304 m .82064 .70027 L .837 .69257 L p .707 .577 .707 r
F P
0 g
s
.837 .69257 m .83456 .65534 L .8182 .66304 L p .707 .577 .707 r
F P
0 g
s
.66739 .73215 m .66458 .75015 L .69167 .75928 L p .707 .577 .707 r
F P
0 g
s
.82505 .5625 m .83729 .61793 L .84449 .61068 L p .707 .577 .707 r
F P
0 g
s
.84449 .61068 m .83226 .55525 L .82505 .5625 L p .707 .577 .707 r
F P
0 g
s
.78592 .75146 m .78311 .76945 L .80699 .76598 L p .707 .577 .707 r
F P
0 g
s
.80699 .76598 m .8098 .74799 L .78592 .75146 L p .707 .577 .707 r
F P
0 g
s
.66458 .75015 m .66739 .73215 L .64666 .72142 L p .707 .577 .707 r
F P
0 g
s
.65602 .7077 m .65358 .67047 L .64104 .66408 L p .707 .577 .707 r
F P
0 g
s
.64104 .66408 m .64348 .70131 L .65602 .7077 L p .707 .577 .707 r
F P
0 g
s
.83456 .65534 m .837 .69257 L .84409 .68454 L p .707 .577 .707 r
F P
0 g
s
.84409 .68454 m .84165 .64731 L .83456 .65534 L p .707 .577 .707 r
F P
0 g
s
.64791 .65563 m .63567 .6002 L .63313 .59489 L p .707 .577 .707 r
F P
0 g
s
.8098 .74799 m .80699 .76598 L .82331 .75937 L p .707 .577 .707 r
F P
0 g
s
.82331 .75937 m .82612 .74137 L .8098 .74799 L p .707 .577 .707 r
F P
0 g
s
.83226 .55525 m .84449 .61068 L .84195 .60537 L p .707 .577 .707 r
F P
0 g
s
.84195 .60537 m .82972 .54994 L .83226 .55525 L p .707 .577 .707 r
F P
0 g
s
.63313 .59489 m .64536 .65031 L .64791 .65563 L p .707 .577 .707 r
F P
0 g
s
.64348 .70131 m .64104 .66408 L .63817 .6565 L p .707 .577 .707 r
F P
0 g
s
.63817 .6565 m .64061 .69373 L .64348 .70131 L p .707 .577 .707 r
F P
0 g
s
.82612 .74137 m .82331 .75937 L .83045 .75025 L p .707 .577 .707 r
F P
0 g
s
.83045 .75025 m .83326 .73226 L .82612 .74137 L p .707 .577 .707 r
F P
0 g
s
.84165 .64731 m .84409 .68454 L .84123 .67695 L p .707 .577 .707 r
F P
0 g
s
.84123 .67695 m .83879 .63972 L .84165 .64731 L p .707 .577 .707 r
F P
0 g
s
.63152 .72813 m .63433 .71013 L .6316 .69941 L p .707 .577 .707 r
F P
0 g
s
.64536 .65031 m .63313 .59489 L .64034 .58764 L p .707 .577 .707 r
F P
0 g
s
.6316 .69941 m .6288 .71741 L .63152 .72813 L p .707 .577 .707 r
F P
0 g
s
.82972 .54994 m .84195 .60537 L .82992 .60252 L p .707 .577 .707 r
F P
0 g
s
.82992 .60252 m .81768 .54709 L .82972 .54994 L p .707 .577 .707 r
F P
0 g
s
.64034 .58764 m .65257 .64306 L .64536 .65031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64061 .69373 m .63817 .6565 L .64527 .64846 L p .707 .577 .707 r
F P
0 g
s
.39437 .61278 m .38214 .55736 L .35174 .56249 L p .707 .577 .707 r
F P
0 g
s
.38214 .55736 m .39437 .61278 L .42551 .60566 L p .707 .577 .707 r
F P
0 g
s
.42551 .60566 m .41327 .55024 L .38214 .55736 L p .707 .577 .707 r
F P
0 g
s
.41327 .55024 m .42551 .60566 L .45433 .59725 L p .707 .577 .707 r
F P
0 g
s
.45433 .59725 m .4421 .54183 L .41327 .55024 L p .707 .577 .707 r
F P
0 g
s
.64527 .64846 m .64771 .68569 L .64061 .69373 L p .707 .577 .707 r
F P
0 g
s
.83326 .73226 m .83045 .75025 L .82772 .73953 L p .707 .577 .707 r
F P
0 g
s
.82772 .73953 m .83053 .72153 L .83326 .73226 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36397 .61791 m .35174 .56249 L .32505 .56512 L p .707 .577 .707 r
F P
0 g
s
.35174 .56249 m .36397 .61791 L .39437 .61278 L p .707 .577 .707 r
F P
0 g
s
.83879 .63972 m .84123 .67695 L .82868 .67056 L p .707 .577 .707 r
F P
0 g
s
.82868 .67056 m .82624 .63333 L .83879 .63972 L p .707 .577 .707 r
F P
0 g
s
.6288 .71741 m .6316 .69941 L .63875 .69029 L p .707 .577 .707 r
F P
0 g
s
.65257 .64306 m .64034 .58764 L .65658 .57916 L p .707 .577 .707 r
F P
0 g
s
.4421 .54183 m .45433 .59725 L .47803 .58837 L p .707 .577 .707 r
F P
0 g
s
.47803 .58837 m .4658 .53295 L .4421 .54183 L p .707 .577 .707 r
F P
0 g
s
.63875 .69029 m .63594 .70829 L .6288 .71741 L p .707 .577 .707 r
F P
0 g
s
.81768 .54709 m .82992 .60252 L .80956 .60241 L p .707 .577 .707 r
F P
0 g
s
.80956 .60241 m .79732 .54698 L .81768 .54709 L p .707 .577 .707 r
F P
0 g
s
.32505 .56512 m .33729 .62055 L .36397 .61791 L p .707 .577 .707 r
F P
0 g
s
.65658 .57916 m .66882 .63458 L .65257 .64306 L p .707 .577 .707 r
F P
0 g
s
.3925 .68065 m .39006 .64342 L .35896 .6436 L p .707 .577 .707 r
F P
0 g
s
.39006 .64342 m .3925 .68065 L .42427 .67799 L p .707 .577 .707 r
F P
0 g
s
.42427 .67799 m .42183 .64076 L .39006 .64342 L p .707 .577 .707 r
F P
0 g
s
.42183 .64076 m .42427 .67799 L .45361 .67312 L p .707 .577 .707 r
F P
0 g
s
.45361 .67312 m .45117 .63589 L .42183 .64076 L p .707 .577 .707 r
F P
0 g
s
.64771 .68569 m .64527 .64846 L .66163 .64077 L p .707 .577 .707 r
F P
0 g
s
.33729 .62055 m .32505 .56512 L .3047 .56501 L p .707 .577 .707 r
F P
0 g
s
.36139 .68083 m .35896 .6436 L .33157 .64129 L p .707 .577 .707 r
F P
0 g
s
.35896 .6436 m .36139 .68083 L .3925 .68065 L p .707 .577 .707 r
F P
0 g
s
.4658 .53295 m .47803 .58837 L .49428 .57989 L p .707 .577 .707 r
F P
0 g
s
.49428 .57989 m .48204 .52446 L .4658 .53295 L p .707 .577 .707 r
F P
0 g
s
.66163 .64077 m .66406 .678 L .64771 .68569 L p .707 .577 .707 r
F P
0 g
s
.45117 .63589 m .45361 .67312 L .47763 .66651 L p .707 .577 .707 r
F P
0 g
s
.47763 .66651 m .47519 .62928 L .45117 .63589 L p .707 .577 .707 r
F P
0 g
s
.83053 .72153 m .82772 .73953 L .81539 .72825 L p .707 .577 .707 r
F P
0 g
s
.81539 .72825 m .8182 .71025 L .83053 .72153 L p .707 .577 .707 r
F P
0 g
s
.66882 .63458 m .65658 .57916 L .68028 .57028 L p .707 .577 .707 r
F P
0 g
s
.3047 .56501 m .31693 .62044 L .33729 .62055 L p .707 .577 .707 r
F P
0 g
s
.33157 .64129 m .33401 .67852 L .36139 .68083 L p .707 .577 .707 r
F P
0 g
s
.82624 .63333 m .82868 .67056 L .80769 .66599 L p .707 .577 .707 r
F P
0 g
s
.80769 .66599 m .80525 .62876 L .82624 .63333 L p .707 .577 .707 r
F P
0 g
s
.63594 .70829 m .63875 .69029 L .65506 .68368 L p .707 .577 .707 r
F P
0 g
s
.37947 .72357 m .38228 .70558 L .35147 .69893 L p .707 .577 .707 r
F P
0 g
s
.38228 .70558 m .37947 .72357 L .41098 .72708 L p .707 .577 .707 r
F P
0 g
s
.41098 .72708 m .41379 .70908 L .38228 .70558 L p .707 .577 .707 r
F P
0 g
s
.79732 .54698 m .80956 .60241 L .78288 .60504 L p .707 .577 .707 r
F P
0 g
s
.78288 .60504 m .77064 .54962 L .79732 .54698 L p .707 .577 .707 r
F P
0 g
s
.33401 .67852 m .33157 .64129 L .31057 .63672 L p .707 .577 .707 r
F P
0 g
s
.65506 .68368 m .65225 .70167 L .63594 .70829 L p .707 .577 .707 r
F P
0 g
s
.41379 .70908 m .41098 .72708 L .4401 .7271 L p .707 .577 .707 r
F P
0 g
s
.4401 .7271 m .44291 .7091 L .41379 .70908 L p .707 .577 .707 r
F P
0 g
s
.68028 .57028 m .69251 .6257 L .66882 .63458 L p .707 .577 .707 r
F P
0 g
s
.34866 .71693 m .35147 .69893 L .32438 .68979 L p .707 .577 .707 r
F P
0 g
s
.35147 .69893 m .34866 .71693 L .37947 .72357 L p .707 .577 .707 r
F P
0 g
s
.31693 .62044 m .3047 .56501 L .29266 .56216 L p .707 .577 .707 r
F P
0 g
s
.66406 .678 m .66163 .64077 L .68565 .63416 L p .707 .577 .707 r
F P
0 g
s
.32438 .68979 m .32157 .70779 L .34866 .71693 L p .707 .577 .707 r
F P
0 g
s
.31057 .63672 m .31301 .67395 L .33401 .67852 L p .707 .577 .707 r
F P
0 g
s
.47519 .62928 m .47763 .66651 L .49399 .65882 L p .707 .577 .707 r
F P
0 g
s
.49399 .65882 m .49155 .62159 L .47519 .62928 L p .707 .577 .707 r
F P
0 g
s
.69251 .6257 m .68028 .57028 L .70911 .56186 L p .707 .577 .707 r
F P
0 g
s
.48204 .52446 m .49428 .57989 L .50148 .57264 L p .707 .577 .707 r
F P
0 g
s
.50148 .57264 m .48925 .51721 L .48204 .52446 L p .707 .577 .707 r
F P
0 g
s
.44291 .7091 m .4401 .7271 L .46398 .72363 L p .707 .577 .707 r
F P
0 g
s
.46398 .72363 m .46679 .70563 L .44291 .7091 L p .707 .577 .707 r
F P
0 g
s
.77064 .54962 m .78288 .60504 L .75248 .61017 L p .707 .577 .707 r
F P
0 g
s
.75248 .61017 m .74024 .55474 L .77064 .54962 L p .707 .577 .707 r
F P
0 g
s
.68565 .63416 m .68809 .67139 L .66406 .678 L p .707 .577 .707 r
F P
0 g
s
.29266 .56216 m .30489 .61759 L .31693 .62044 L p .707 .577 .707 r
F P
0 g
s
.32157 .70779 m .32438 .68979 L .30365 .67906 L p .707 .577 .707 r
F P
0 g
s
.80525 .62876 m .80769 .66599 L .7803 .66368 L p .707 .577 .707 r
F P
0 g
s
.7803 .66368 m .77786 .62645 L .80525 .62876 L p .707 .577 .707 r
F P
0 g
s
.8182 .71025 m .81539 .72825 L .79466 .71751 L p .707 .577 .707 r
F P
0 g
s
.79466 .71751 m .79747 .69952 L .8182 .71025 L p .707 .577 .707 r
F P
0 g
s
.65225 .70167 m .65506 .68368 L .67894 .68021 L p .707 .577 .707 r
F P
0 g
s
.70911 .56186 m .72134 .61729 L .69251 .6257 L p .707 .577 .707 r
F P
0 g
s
.72134 .61729 m .70911 .56186 L .74024 .55474 L p .707 .577 .707 r
F P
0 g
s
.30365 .67906 m .30084 .69705 L .32157 .70779 L p .707 .577 .707 r
F P
0 g
s
.74024 .55474 m .75248 .61017 L .72134 .61729 L p .707 .577 .707 r
F P
0 g
s
.31301 .67395 m .31057 .63672 L .29803 .63032 L p .707 .577 .707 r
F P
0 g
s
.68809 .67139 m .68565 .63416 L .71498 .62929 L p .707 .577 .707 r
F P
0 g
s
.67894 .68021 m .67613 .69821 L .65225 .70167 L p .707 .577 .707 r
F P
0 g
s
.29803 .63032 m .30047 .66756 L .31301 .67395 L p .707 .577 .707 r
F P
0 g
s
.77786 .62645 m .7803 .66368 L .74919 .66386 L p .707 .577 .707 r
F P
0 g
s
.74919 .66386 m .74676 .62663 L .77786 .62645 L p .707 .577 .707 r
F P
0 g
s
.46679 .70563 m .46398 .72363 L .4803 .71701 L p .707 .577 .707 r
F P
0 g
s
.4803 .71701 m .4831 .69902 L .46679 .70563 L p .707 .577 .707 r
F P
0 g
s
.30489 .61759 m .29266 .56216 L .29012 .55685 L p .707 .577 .707 r
F P
0 g
s
.71498 .62929 m .71742 .66652 L .68809 .67139 L p .707 .577 .707 r
F P
0 g
s
.49155 .62159 m .49399 .65882 L .50108 .65078 L p .707 .577 .707 r
F P
0 g
s
.50108 .65078 m .49864 .61355 L .49155 .62159 L p .707 .577 .707 r
F P
0 g
s
.30084 .69705 m .30365 .67906 L .29132 .66778 L p .707 .577 .707 r
F P
0 g
s
.71742 .66652 m .71498 .62929 L .74676 .62663 L p .707 .577 .707 r
F P
0 g
s
.79747 .69952 m .79466 .71751 L .76757 .70837 L p .707 .577 .707 r
F P
0 g
s
.76757 .70837 m .77038 .69038 L .79747 .69952 L p .707 .577 .707 r
F P
0 g
s
.74676 .62663 m .74919 .66386 L .71742 .66652 L p .707 .577 .707 r
F P
0 g
s
.67613 .69821 m .67894 .68021 L .70806 .68023 L p .707 .577 .707 r
F P
0 g
s
.48925 .51721 m .50148 .57264 L .49894 .56733 L p .707 .577 .707 r
F P
0 g
s
.49894 .56733 m .48671 .5119 L .48925 .51721 L p .707 .577 .707 r
F P
0 g
s
.29132 .66778 m .28851 .68577 L .30084 .69705 L p .707 .577 .707 r
F P
0 g
s
.29012 .55685 m .30235 .61227 L .30489 .61759 L p .707 .577 .707 r
F P
0 g
s
.70806 .68023 m .70525 .69822 L .67613 .69821 L p .707 .577 .707 r
F P
0 g
s
.30047 .66756 m .29803 .63032 L .29516 .62274 L p .707 .577 .707 r
F P
0 g
s
.77038 .69038 m .76757 .70837 L .73676 .70173 L p .707 .577 .707 r
F P
0 g
s
.73676 .70173 m .73957 .68373 L .77038 .69038 L p .707 .577 .707 r
F P
0 g
s
.70525 .69822 m .70806 .68023 L .73957 .68373 L p .707 .577 .707 r
F P
0 g
s
.73957 .68373 m .73676 .70173 L .70525 .69822 L p .707 .577 .707 r
F P
0 g
s
.29516 .62274 m .2976 .65997 L .30047 .66756 L p .707 .577 .707 r
F P
0 g
s
.4831 .69902 m .4803 .71701 L .48744 .7079 L p .707 .577 .707 r
F P
0 g
s
.48744 .7079 m .49025 .6899 L .4831 .69902 L p .707 .577 .707 r
F P
0 g
s
.28851 .68577 m .29132 .66778 L .28859 .65705 L p .707 .577 .707 r
F P
0 g
s
.49864 .61355 m .50108 .65078 L .49821 .6432 L p .707 .577 .707 r
F P
0 g
s
.49821 .6432 m .49578 .60597 L .49864 .61355 L p .707 .577 .707 r
F P
0 g
s
.30235 .61227 m .29012 .55685 L .29733 .5496 L p .707 .577 .707 r
F P
0 g
s
.28859 .65705 m .28578 .67505 L .28851 .68577 L p .707 .577 .707 r
F P
0 g
s
.48671 .5119 m .49894 .56733 L .48691 .56448 L p .707 .577 .707 r
F P
0 g
s
.48691 .56448 m .47467 .50905 L .48671 .5119 L p .707 .577 .707 r
F P
0 g
s
.29733 .5496 m .30956 .60502 L .30235 .61227 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2976 .65997 m .29516 .62274 L .30226 .61471 L p .707 .577 .707 r
F P
0 g
s
.49025 .6899 m .48744 .7079 L .48471 .69717 L p .707 .577 .707 r
F P
0 g
s
.48471 .69717 m .48752 .67918 L .49025 .6899 L p .707 .577 .707 r
F P
0 g
s
.30226 .61471 m .3047 .65194 L .2976 .65997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28578 .67505 m .28859 .65705 L .29573 .64794 L p .707 .577 .707 r
F P
0 g
s
.30956 .60502 m .29733 .5496 L .31357 .54112 L p .707 .577 .707 r
F P
0 g
s
.49578 .60597 m .49821 .6432 L .48567 .6368 L p .707 .577 .707 r
F P
0 g
s
.48567 .6368 m .48323 .59957 L .49578 .60597 L p .707 .577 .707 r
F P
0 g
s
.29573 .64794 m .29293 .66593 L .28578 .67505 L p .707 .577 .707 r
F P
0 g
s
.47467 .50905 m .48691 .56448 L .46655 .56436 L p .707 .577 .707 r
F P
0 g
s
.46655 .56436 m .45431 .50894 L .47467 .50905 L p .707 .577 .707 r
F P
0 g
s
.31357 .54112 m .32581 .59654 L .30956 .60502 L p .707 .577 .707 r
F P
0 g
s
.3047 .65194 m .30226 .61471 L .31862 .60701 L p .707 .577 .707 r
F P
0 g
s
.48752 .67918 m .48471 .69717 L .47238 .68589 L p .707 .577 .707 r
F P
0 g
s
.47238 .68589 m .47519 .6679 L .48752 .67918 L p .707 .577 .707 r
F P
0 g
s
.31862 .60701 m .32105 .64424 L .3047 .65194 L p .707 .577 .707 r
F P
0 g
s
.32581 .59654 m .31357 .54112 L .33727 .53223 L p .707 .577 .707 r
F P
0 g
s
.29293 .66593 m .29573 .64794 L .31205 .64132 L p .707 .577 .707 r
F P
0 g
s
.48323 .59957 m .48567 .6368 L .46468 .63223 L p .707 .577 .707 r
F P
0 g
s
.46468 .63223 m .46224 .595 L .48323 .59957 L p .707 .577 .707 r
F P
0 g
s
.45431 .50894 m .46655 .56436 L .43987 .567 L p .707 .577 .707 r
F P
0 g
s
.43987 .567 m .42763 .51158 L .45431 .50894 L p .707 .577 .707 r
F P
0 g
s
.31205 .64132 m .30924 .65932 L .29293 .66593 L p .707 .577 .707 r
F P
0 g
s
.33727 .53223 m .3495 .58766 L .32581 .59654 L p .707 .577 .707 r
F P
0 g
s
.32105 .64424 m .31862 .60701 L .34264 .6004 L p .707 .577 .707 r
F P
0 g
s
.3495 .58766 m .33727 .53223 L .3661 .52382 L p .707 .577 .707 r
F P
0 g
s
.42763 .51158 m .43987 .567 L .40947 .57213 L p .707 .577 .707 r
F P
0 g
s
.40947 .57213 m .39723 .5167 L .42763 .51158 L p .707 .577 .707 r
F P
0 g
s
.47519 .6679 m .47238 .68589 L .45165 .67516 L p .707 .577 .707 r
F P
0 g
s
.45165 .67516 m .45446 .65716 L .47519 .6679 L p .707 .577 .707 r
F P
0 g
s
.34264 .6004 m .34508 .63763 L .32105 .64424 L p .707 .577 .707 r
F P
0 g
s
.46224 .595 m .46468 .63223 L .43729 .62992 L p .707 .577 .707 r
F P
0 g
s
.43729 .62992 m .43485 .59269 L .46224 .595 L p .707 .577 .707 r
F P
0 g
s
.30924 .65932 m .31205 .64132 L .33593 .63785 L p .707 .577 .707 r
F P
0 g
s
.3661 .52382 m .37833 .57925 L .3495 .58766 L p .707 .577 .707 r
F P
0 g
s
.37833 .57925 m .3661 .52382 L .39723 .5167 L p .707 .577 .707 r
F P
0 g
s
.39723 .5167 m .40947 .57213 L .37833 .57925 L p .707 .577 .707 r
F P
0 g
s
.33593 .63785 m .33312 .65585 L .30924 .65932 L p .707 .577 .707 r
F P
0 g
s
.34508 .63763 m .34264 .6004 L .37197 .59553 L p .707 .577 .707 r
F P
0 g
s
.43485 .59269 m .43729 .62992 L .40618 .6301 L p .707 .577 .707 r
F P
0 g
s
.40618 .6301 m .40375 .59287 L .43485 .59269 L p .707 .577 .707 r
F P
0 g
s
.37197 .59553 m .37441 .63276 L .34508 .63763 L p .707 .577 .707 r
F P
0 g
s
.45446 .65716 m .45165 .67516 L .42456 .66602 L p .707 .577 .707 r
F P
0 g
s
.42456 .66602 m .42737 .64802 L .45446 .65716 L p .707 .577 .707 r
F P
0 g
s
.37441 .63276 m .37197 .59553 L .40375 .59287 L p .707 .577 .707 r
F P
0 g
s
.33312 .65585 m .33593 .63785 L .36505 .63787 L p .707 .577 .707 r
F P
0 g
s
.40375 .59287 m .40618 .6301 L .37441 .63276 L p .707 .577 .707 r
F P
0 g
s
.36505 .63787 m .36224 .65587 L .33312 .65585 L p .707 .577 .707 r
F P
0 g
s
.42737 .64802 m .42456 .66602 L .39375 .65937 L p .707 .577 .707 r
F P
0 g
s
.39375 .65937 m .39656 .64138 L .42737 .64802 L p .707 .577 .707 r
F P
0 g
s
.36224 .65587 m .36505 .63787 L .39656 .64138 L p .707 .577 .707 r
F P
0 g
s
.39656 .64138 m .39375 .65937 L .36224 .65587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6@00O7oo001oOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001eOol007Uoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0075oo`00M7oo1@00
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00KWoo001_
Ool50002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH3001/Ool006]oo`@000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Yoo`00JGoo0P0000=JEP00FUH025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0Igoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIY
Ool006Eoo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06Ioo`00I7oo0P001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IWoo001TOol20006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1VOol006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Ioo`00Hgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
07ooOol0IWoo001SOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1V
Ool006=oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP03001oogoo06Ioo`00Hgoo
00<005YF00001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo001SOol00`00FUH0
0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006=oo`03001JEP0000MJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00Hgoo00<005YF00001eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006Aoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00Igoo001TOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00
I7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<007ooOol0I7oo001TOol00`00
FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1TOol006Aoo`03001JEP0000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<005YF00001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001J
EP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH:000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF00=JEPT000=J
EP03001JEUYF009JEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF1P0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<006Aoo`00IWoo00<005YF00000UYF100000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol50005FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001TOol300000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001QOol30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001NOol30008FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol005]oo`<00003
FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Aoo`00FGoo0P0015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001GOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001EOol20002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000VOol;000cOol005Aoo`03001JEUYF00=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
01ioo`P000=JEP03001JEUYF00=JEP04001JEP00000aOol005=oo`8000EJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8001Moo`L000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080031oo`00DWoo00<0
05YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P004goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF001JES1oo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000?
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001B
Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YFFUIJEP/00003FUH0000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000eoo`800003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF20001EYF00<005YFFUH00UYF100015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P002Woo0`000eYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;goo
001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70006FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20007Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000_Ool005=oo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF100025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEP000080
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000UJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF0080
02ioo`00E7oo00@005YFFUH000AJEP03001JEUYF00=JEP@000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP0015YF
00<005YF00000`000eYF00<005YFFUH01UYF4@000UYF00<005YF00000`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJ
EP8002eoo`00E7oo00@005YFFUH000AJEP<000IJEPT000AJEP03001JEUYF00IJEP04001JEUYFFUH8
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool005Aoo`04001JEUYF0003FUH01@00FUIJEP00FUH01P00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010002EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF00D005YFFUIJEP0000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
008002eoo`00D7oo1@000eYF0`0000=JEP0000000P0000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<007ooOol0:goo001<
Ool40002FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH00UYF1@00;7oo0018Ool40006
FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00EJEPH000MJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000/Ool0
04Aoo`@00003FUH005YF00QJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH3000]Ool003moo`D000IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJEPD000QJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP03001oogoo02eoo`00>goo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool003Qoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJ
EP02FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000aOol003Ioo`<000UJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH0
0002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0M0002FUH2000cOol003Ao
o`80009JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF00AJEP03001JEUYF00AJEQd000AJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000003FUH40002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol0035oo`<000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP0400000eYF001JEP02FUH50008FUH00`00FUIJEP040004FUH3000015YF001JEUYF0P0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH30000
0eYF000000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH3000aOol002moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP04001JEUYF0004FUHA0002FUH50007FUH40002FUH00`00FUIJEP04FUH00`00FUH000020000
0eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF
00D005YF000005YF00<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP03001JEP00008002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUH005YF00@000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPh000IJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH50004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
000/Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000[Ool00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00:goo00@005YFFUH000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<00003FUH0
05YF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool002]oo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH00eYF0`001EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF10000eYF00<005YFFUH01EYF
00<005YFFUH00UYF1`001UYF00<005YFFUH01UYF0`000eYF00@005YFFUIJEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH900001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH00P002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ4000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUH005YF0`000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001UYF00<005YFFUH0
0eYF0`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPP00004Ool00000000=Ool70003FUH01@00FUIJEUYF0000
;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF100025YF00<005YF0000
0P000UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000AJ
EP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EP00009JEP05001JEUYFFUH00005FUH60008Ool50009Ool50005FUH40003FUH00`00Oomoo`0[Ool0
02aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP06FUH3
00000eYF001JEP02FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF0`0000=JEP00FUH01EYF0P002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000UYF00H005YFFUIJEP00FUH60002FUH20008Ool>0003FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0000=JEP00Ool0;7oo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
00000P001UYF00<005YFFUH01UYF0`000UYF00H005YFFUIJEP00FUH70004FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90002FUH20005FUH01000FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH200000eYF001JEP02FUHB0004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eoo`04001JEUYF0004FUH00`00FUIJEP03
FUH40008FUH00`00FUIJEP06FUH30003FUH01000FUIJEP001UYF50001eYF00<005YFFUH00eYF0P00
0eYF00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001J
EUYF001JEP00FUH00P000UYF40000UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;Goo000]Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH0
1EYF30000eYF100015YF0P0027oo00@005YFFUH0009JEPD000QJEP03001JEUYF00EJEP800003FUH0
05YF009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYF001JEP060002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00@005YFFUH000AJEP<000MJEPP000AJEP03
001JEUYF00AJEP05001JEUYFFUH00002FUH60009Ool01000FUIJEP000UYF1@0025YF00<005YFFUH0
1eYF0P000eYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH0
1UYF00<005YFFUH01EYF00@005YFFUIJEP8002ioo`00;Goo00@005YFFUH000=JEP05001JEUYF001J
EP060003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH300000eYF000000020005
Ool01000FUIJEP000UYF1@0025YF00<005YFFUH02EYF00D005YF001JEP0000QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00=JEP@000IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002eoo`04
001JEUYFFUH300000eYF0000000200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2
0006FUH00`00FUH000060003Ool01000FUIJEP000eYF100025YF00<005YFFUH02EYF0`0000=JEP00
FUH01eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH0
15YF00@005YFFUH0031oo`00;Woo0eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0P001UYF00<005YFFUH00eYF10000Woo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP<00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEP0000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30006FUH3000a
Ool002ioo`06FUH00000001JEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP800003FUH0000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF009JEPL000IJEP03001JEUYF00EJEP<0
00=JEP8003=oo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH015YF1`0000=JEP00FUH01eYF
00<005YFFUH00eYF1@000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P0000IJEP00000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP03000eOol002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJEP03001J
EUYF009JEQ0000=JEP07001JEUYFFUH005YF00002EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YF000000=JEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000EJEP03001JEUYF00=JEP8003Aoo`00;Goo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]JEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP@000=JEP80009JEPL000AJEP03001JEUYF00IJEP03001J
EUYF009JEPP000=JEP03001JEUYF00AJEP8003=oo`00;7oo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@0
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH40003FUH20007FUHD0008Ool200000eYF001J
EP05FUH00`00FUH0000bOol002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH00eYF0P000UYF00<005YFFUH01P000UYF0P003Goo1@00
2goo0P001EYF00D005YFFUIJEP00035oo`00;7oo00<005YF00001EYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF5`0015YF00D005YFFUH007oo00P000AJEP03001JEUYF00IJEP04001J
EUYFFUH40003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2
0003FUH01000FUH000000UYF00<005YF00000P003Woo1@003Goo0P000eYF00<005YFFUH00UYF00<0
07ooOol0;Woo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF30002goo1P00
0UYF0`0000AJEP00FUIJEP<0009JEP03001JEUYF009JEQ4000MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP02FUH2000<
Ool5000?Ool200000eYF001JEP03FUH00`00Oomoo`0^Ool002aoo`04001JEUYF0004FUHA0002Ool5
0007Ool40002FUH00`00FUIJEP04FUH01000FUH000000UYF0`000UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH015YF00D005YFFUIJEP00009JEP800003FUH005YF00AJEP<000]oo`<0019oo`8000AJEP03001o
ogoo02ioo`00;7oo00D005YFFUH005YF00@000=JEP03001JEUYF00EJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00AJEP04001JEUYFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP0015YF0`0015YF00<005YFFUH00P0087oo00<005YFFUH00P00<7oo000]Ool00`00FUH000020006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP050008FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YF00001000
0eYF00<007ooOol07goo1000<7oo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000:FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF1P008Goo0`00<7oo000/Ool20002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH015YF00<005YFFUH00UYF00@005YF000000YJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol5000`Ool002aoo`80009JEP04001JEUYFFUH@0004
FUH00`00FUIJEP07FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF0P0000=oo`00FUH02EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF5@0025YF00<005YFFUH02eYF0`0025YF00<0
05YFFUH015YF1`0047oo1@000UYF00<005YF0000<7oo000[Ool20003FUH40003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP05FUH20005FUH01000FUIJEUYF0P000goo2UYF00<0
05YFFUH01UYF00<005YFFUH01eYF2@0035YF00<005YFFUH01UYF1P000UYF00<005YFFUH02eYF1000
1UYF00<005YFFUH01eYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH0000`Ool002]oo`80
0005FUH00000FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<0
05YFFUH01UYF0`000eYF00@005YF000000Eoo`YJEP03001JEUYF00IJEP04001JEUYFFUH60008FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05000;FUH20002FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00<Goo000[Ool4
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH0
0`00FUIJEP050007Ool:FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH2
000:FUH00`00FUIJEP05FUH50006FUH700000eYF000000030006FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<Woo000ZOol20003Ool30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00eYF0P0027oo2UYF
00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000=JEP8000EJEP@0009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP00000dOol002Yoo`<000Aoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH20007Ool9FUH400000eYF
001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH200000eYF00000005FUH01000FUIJEUYF0P0000AJEP00Oomoo`L000AJEP03001JEUYF
00EJEP04001JEUYFFUH5000fOol002Yoo`800003FUH0000000Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEPT0009oo`8000IJEP03001JEP0000Ioo`MJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000EJEP03001JEUYF009JEP<000Uooa0003]oo`00:Woo0P000eYF00<007ooOol017oo5`00
3Goo0P000eYF00D005YFFUIJEP0000Eoo`EJEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP02FUH00`00FUH0001DOol002]oo`04001JEUYFFUH3000EOol5000@Ool200000eYF001J
EP02FUH00`00Oomoo`03Ool3FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000001UYF
00L005YFFUIJEP00FUH0001DOol002]oo`05001JEUYFFUH00002FUH2000COol5000BOol20003FUH2
0004Ool2FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000IJEP04001JEUYFFUH2
001EOol002aoo`03001JEP0000EJEP<0011oo`D001Aoo`05001JEP00FUH00004Ool00eYF001JEP03
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001UYF00@005YFFUIJEP8005Eoo`00;Goo
0P001UYF00<005YF00000`003Goo0`005Woo0P0000=JEP00Ool00goo00=JEP00FUH00eYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000IJEP05001JEUYFFUH0001FOol002ioo`03001JEUYF
00AJEP03001JEUYF00=JEP@0029oo`800003FUH007oo00=oo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00mJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH005YF00EJEP04001JEP00001GOol002moo`8000=JEP03001JEUYF00EJEP03
001JEUYF00@001aoo`800003FUH0000000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80
0003FUH0000000EJEP<005Uoo`00<Goo0P0000=JEP00FUH01UYF00<005YFFUH015YF1`0047oo1@00
0eYF0P001Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEPH005aoo`00<goo
0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00L005YFFUIJEP00FUH00006Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUH000001UYF00<005YFFUH00P00GGoo000fOol20004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
27oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF20000eYF00<005YFFUH00eYF0P00Fgoo000hOol300000eYF001J
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000:Ool3
0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP040008Ool200000eYF001JEP05FUH2001JOol003]oo`D000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00<000eoo`<000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEPH000aoo`8000IJEP04001JEP00001HOol0041oo`T000AJ
EP03001JEUYF00IJEP04001JEUYFFUH5000COol40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP02FUH60002Ool5000=Ool20003FUH00`00FUIJEP02FUH00`00Oomo
o`1EOol004Uooa4001aoo`P000EJEP03001JEUYF00UJEP03001JEUYF009JEPd000Qoo`D000moo`80
0003FUH005YF00=JEP03001oogoo05Eoo`00OWoo5`0057oo1@004Goo0P0015YF00<007ooOol0EGoo
002=Ool01000FUIJEP0015YF0`004Woo0`0057oo00<005YFFUH00P00Egoo002>Ool30005FUH00`00
FUH00003000VOol4001GOol0091oo`03001JEUYF00=JEP03001JEUYF00=JEPD0029oo`<005Moo`00
TGoo0P000UYF00<005YFFUH01UYF00<005YFFUH0100077oo1@00Egoo002COol30008FUH00`00FUIJ
EP04FUH7000@Ool50002FUH00`00FUH0001GOol009Eoo`8000IJEP03001JEUYF00MJEP03001JEUYF
009JEQ0000=JEP07001JEUYFFUH005YF0000Egoo002GOol20004FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00F7oo002IOol300000eYF001J
EP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001HOol0
09aoo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<005Uo
o`00XWoo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005aoo`00Zgoo4000HWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]58\[InvisibleSpace]"     "\
\[InvisibleSpace]13.825563588829256`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 58, "     ", 13.825563588829256, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60318 .7456 m .59546 .68977 L .56459 .69228 L p .707 .577 .707 r
F P
0 g
s
.59546 .68977 m .60318 .7456 L .63474 .74084 L p .707 .577 .707 r
F P
0 g
s
.63474 .74084 m .62702 .68501 L .59546 .68977 L p .707 .577 .707 r
F P
0 g
s
.62702 .68501 m .63474 .74084 L .6639 .7343 L p .707 .577 .707 r
F P
0 g
s
.6639 .7343 m .65618 .67847 L .62702 .68501 L p .707 .577 .707 r
F P
0 g
s
.57231 .74811 m .56459 .69228 L .53744 .6923 L p .707 .577 .707 r
F P
0 g
s
.56459 .69228 m .57231 .74811 L .60318 .7456 L p .707 .577 .707 r
F P
0 g
s
.65618 .67847 m .6639 .7343 L .68781 .72662 L p .707 .577 .707 r
F P
0 g
s
.68781 .72662 m .68009 .67079 L .65618 .67847 L p .707 .577 .707 r
F P
0 g
s
.53744 .6923 m .54516 .74813 L .57231 .74811 L p .707 .577 .707 r
F P
0 g
s
.54516 .74813 m .53744 .6923 L .51666 .68983 L p .707 .577 .707 r
F P
0 g
s
.59045 .80474 m .58532 .76752 L .55445 .77002 L p .707 .577 .707 r
F P
0 g
s
.58532 .76752 m .59045 .80474 L .62201 .79999 L p .707 .577 .707 r
F P
0 g
s
.62201 .79999 m .61688 .76277 L .58532 .76752 L p .707 .577 .707 r
F P
0 g
s
.61688 .76277 m .62201 .79999 L .65118 .79346 L p .707 .577 .707 r
F P
0 g
s
.65118 .79346 m .64605 .75624 L .61688 .76277 L p .707 .577 .707 r
F P
0 g
s
.68009 .67079 m .68781 .72662 L .70413 .71856 L p .707 .577 .707 r
F P
0 g
s
.70413 .71856 m .69642 .66273 L .68009 .67079 L p .707 .577 .707 r
F P
0 g
s
.55958 .80724 m .55445 .77002 L .5273 .77003 L p .707 .577 .707 r
F P
0 g
s
.55445 .77002 m .55958 .80724 L .59045 .80474 L p .707 .577 .707 r
F P
0 g
s
.51666 .68983 m .52438 .74566 L .54516 .74813 L p .707 .577 .707 r
F P
0 g
s
.59881 .85772 m .60243 .83997 L .57186 .83198 L p .707 .577 .707 r
F P
0 g
s
.60243 .83997 m .59881 .85772 L .6301 .86244 L p .707 .577 .707 r
F P
0 g
s
.6301 .86244 m .63371 .84468 L .60243 .83997 L p .707 .577 .707 r
F P
0 g
s
.64605 .75624 m .65118 .79346 L .67509 .78579 L p .707 .577 .707 r
F P
0 g
s
.67509 .78579 m .66996 .74857 L .64605 .75624 L p .707 .577 .707 r
F P
0 g
s
.5273 .77003 m .53243 .80725 L .55958 .80724 L p .707 .577 .707 r
F P
0 g
s
.63371 .84468 m .6301 .86244 L .65905 .86342 L p .707 .577 .707 r
F P
0 g
s
.65905 .86342 m .66266 .84567 L .63371 .84468 L p .707 .577 .707 r
F P
0 g
s
.56825 .84973 m .57186 .83198 L .54501 .82149 L p .707 .577 .707 r
F P
0 g
s
.57186 .83198 m .56825 .84973 L .59881 .85772 L p .707 .577 .707 r
F P
0 g
s
.52438 .74566 m .51666 .68983 L .50429 .68511 L p .707 .577 .707 r
F P
0 g
s
.54501 .82149 m .5414 .83925 L .56825 .84973 L p .707 .577 .707 r
F P
0 g
s
.53243 .80725 m .5273 .77003 L .50652 .76754 L p .707 .577 .707 r
F P
0 g
s
.66266 .84567 m .65905 .86342 L .68282 .86057 L p .707 .577 .707 r
F P
0 g
s
.68282 .86057 m .68644 .84281 L .66266 .84567 L p .707 .577 .707 r
F P
0 g
s
.5414 .83925 m .54501 .82149 L .5245 .80955 L p .707 .577 .707 r
F P
0 g
s
.66996 .74857 m .67509 .78579 L .69141 .77773 L p .707 .577 .707 r
F P
0 g
s
.69141 .77773 m .68628 .74051 L .66996 .74857 L p .707 .577 .707 r
F P
0 g
s
.50652 .76754 m .51165 .80477 L .53243 .80725 L p .707 .577 .707 r
F P
0 g
s
.69642 .66273 m .70413 .71856 L .71126 .71089 L p .707 .577 .707 r
F P
0 g
s
.71126 .71089 m .70355 .65506 L .69642 .66273 L p .707 .577 .707 r
F P
0 g
s
.50429 .68511 m .512 .74094 L .52438 .74566 L p .707 .577 .707 r
F P
0 g
s
.5245 .80955 m .52089 .8273 L .5414 .83925 L p .707 .577 .707 r
F P
0 g
s
.51165 .80477 m .50652 .76754 L .49414 .76281 L p .707 .577 .707 r
F P
0 g
s
.512 .74094 m .50429 .68511 L .50153 .67859 L p .707 .577 .707 r
F P
0 g
s
.68644 .84281 m .68282 .86057 L .6991 .85417 L p .707 .577 .707 r
F P
0 g
s
.6991 .85417 m .70271 .83641 L .68644 .84281 L p .707 .577 .707 r
F P
0 g
s
.52089 .8273 m .5245 .80955 L .51234 .7973 L p .707 .577 .707 r
F P
0 g
s
.49414 .76281 m .49927 .80003 L .51165 .80477 L p .707 .577 .707 r
F P
0 g
s
.68628 .74051 m .69141 .77773 L .69854 .77006 L p .707 .577 .707 r
F P
0 g
s
.69854 .77006 m .69341 .73284 L .68628 .74051 L p .707 .577 .707 r
F P
0 g
s
.51234 .7973 m .50873 .81506 L .52089 .8273 L p .707 .577 .707 r
F P
0 g
s
.70355 .65506 m .71126 .71089 L .70851 .70438 L p .707 .577 .707 r
F P
0 g
s
.70851 .70438 m .70079 .64855 L .70355 .65506 L p .707 .577 .707 r
F P
0 g
s
.50153 .67859 m .50925 .73442 L .512 .74094 L p .707 .577 .707 r
F P
0 g
s
.48793 .82189 m .4916 .32041 L .44759 .3174 L p .707 .577 .707 r
F P
0 g
s
.49927 .80003 m .49414 .76281 L .49139 .75629 L p .707 .577 .707 r
F P
0 g
s
.50873 .81506 m .51234 .7973 L .50972 .78596 L p .707 .577 .707 r
F P
0 g
s
.50925 .73442 m .50153 .67859 L .50866 .67093 L p .707 .577 .707 r
F P
0 g
s
.49139 .75629 m .49652 .79351 L .49927 .80003 L p .707 .577 .707 r
F P
0 g
s
.50972 .78596 m .50611 .80372 L .50873 .81506 L p .707 .577 .707 r
F P
0 g
s
.50866 .67093 m .51638 .72676 L .50925 .73442 L p .707 .577 .707 r
F P
0 g
s
.49652 .79351 m .49139 .75629 L .49852 .74862 L p .707 .577 .707 r
F P
0 g
s
.50611 .80372 m .50972 .78596 L .5169 .77663 L p .707 .577 .707 r
F P
0 g
s
.51638 .72676 m .50866 .67093 L .52498 .66286 L p .707 .577 .707 r
F P
0 g
s
.5169 .77663 m .51329 .79439 L .50611 .80372 L p .707 .577 .707 r
F P
0 g
s
.49852 .74862 m .50365 .78584 L .49652 .79351 L p .707 .577 .707 r
F P
0 g
s
.52498 .66286 m .5327 .71869 L .51638 .72676 L p .707 .577 .707 r
F P
0 g
s
.50365 .78584 m .49852 .74862 L .51484 .74056 L p .707 .577 .707 r
F P
0 g
s
.51329 .79439 m .5169 .77663 L .53318 .77023 L p .707 .577 .707 r
F P
0 g
s
.53318 .77023 m .52956 .78799 L .51329 .79439 L p .707 .577 .707 r
F P
0 g
s
.51484 .74056 m .51997 .77778 L .50365 .78584 L p .707 .577 .707 r
F P
0 g
s
.51997 .77778 m .51484 .74056 L .53875 .73289 L p .707 .577 .707 r
F P
0 g
s
.52956 .78799 m .53318 .77023 L .55695 .76738 L p .707 .577 .707 r
F P
0 g
s
.55695 .76738 m .55334 .78514 L .52956 .78799 L p .707 .577 .707 r
F P
0 g
s
.53875 .73289 m .54388 .77011 L .51997 .77778 L p .707 .577 .707 r
F P
0 g
s
.4916 .32041 m .48793 .82189 L .53287 .82108 L p .707 .577 .707 r
F P
0 g
s
.5327 .71869 m .52498 .66286 L .5489 .65518 L p .707 .577 .707 r
F P
0 g
s
.5489 .65518 m .55661 .71101 L .5327 .71869 L p .707 .577 .707 r
F P
0 g
s
.53287 .82108 m .53654 .3196 L .4916 .32041 L p .707 .577 .707 r
F P
0 g
s
.70271 .83641 m .6991 .85417 L .70628 .84484 L p .707 .577 .707 r
F P
0 g
s
.70628 .84484 m .70989 .82708 L .70271 .83641 L p .707 .577 .707 r
F P
0 g
s
.55661 .71101 m .5489 .65518 L .57806 .64864 L p .707 .577 .707 r
F P
0 g
s
.57806 .64864 m .58578 .70448 L .55661 .71101 L p .707 .577 .707 r
F P
0 g
s
.54388 .77011 m .53875 .73289 L .56792 .72636 L p .707 .577 .707 r
F P
0 g
s
.55334 .78514 m .55695 .76738 L .5859 .76836 L p .707 .577 .707 r
F P
0 g
s
.56792 .72636 m .57305 .76358 L .54388 .77011 L p .707 .577 .707 r
F P
0 g
s
.5859 .76836 m .58229 .78612 L .55334 .78514 L p .707 .577 .707 r
F P
0 g
s
.53654 .3196 m .53287 .82108 L .57435 .81655 L p .707 .577 .707 r
F P
0 g
s
.57305 .76358 m .56792 .72636 L .59948 .72161 L p .707 .577 .707 r
F P
0 g
s
.59948 .72161 m .60461 .75883 L .57305 .76358 L p .707 .577 .707 r
F P
0 g
s
.57435 .81655 m .57802 .31507 L .53654 .3196 L p .707 .577 .707 r
F P
0 g
s
.44392 .81888 m .44759 .3174 L .40883 .31087 L p .707 .577 .707 r
F P
0 g
s
.44759 .3174 m .44392 .81888 L .48793 .82189 L p .707 .577 .707 r
F P
0 g
s
.69341 .73284 m .69854 .77006 L .69579 .76354 L p .707 .577 .707 r
F P
0 g
s
.69579 .76354 m .69066 .72632 L .69341 .73284 L p .707 .577 .707 r
F P
0 g
s
.70079 .64855 m .70851 .70438 L .69613 .69965 L p .707 .577 .707 r
F P
0 g
s
.69613 .69965 m .68842 .64382 L .70079 .64855 L p .707 .577 .707 r
F P
0 g
s
.58578 .70448 m .57806 .64864 L .60962 .64389 L p .707 .577 .707 r
F P
0 g
s
.60962 .64389 m .61733 .69972 L .58578 .70448 L p .707 .577 .707 r
F P
0 g
s
.63035 .71911 m .63548 .75633 L .60461 .75883 L p .707 .577 .707 r
F P
0 g
s
.60461 .75883 m .59948 .72161 L .63035 .71911 L p .707 .577 .707 r
F P
0 g
s
.58229 .78612 m .5859 .76836 L .61719 .77308 L p .707 .577 .707 r
F P
0 g
s
.61719 .77308 m .61357 .79083 L .58229 .78612 L p .707 .577 .707 r
F P
0 g
s
.57802 .31507 m .57435 .81655 L .60831 .80872 L p .707 .577 .707 r
F P
0 g
s
.60831 .80872 m .61198 .30724 L .57802 .31507 L p .707 .577 .707 r
F P
0 g
s
.26017 .70875 m .25245 .65292 L .22158 .65543 L p .707 .577 .707 r
F P
0 g
s
.25245 .65292 m .26017 .70875 L .29173 .70399 L p .707 .577 .707 r
F P
0 g
s
.29173 .70399 m .28401 .64816 L .25245 .65292 L p .707 .577 .707 r
F P
0 g
s
.40516 .81235 m .40883 .31087 L .3791 .30147 L p .707 .577 .707 r
F P
0 g
s
.40883 .31087 m .40516 .81235 L .44392 .81888 L p .707 .577 .707 r
F P
0 g
s
.28401 .64816 m .29173 .70399 L .32089 .69745 L p .707 .577 .707 r
F P
0 g
s
.32089 .69745 m .31317 .64162 L .28401 .64816 L p .707 .577 .707 r
F P
0 g
s
.70989 .82708 m .70628 .84484 L .70366 .8335 L p .707 .577 .707 r
F P
0 g
s
.70366 .8335 m .70727 .81574 L .70989 .82708 L p .707 .577 .707 r
F P
0 g
s
.2293 .71126 m .22158 .65543 L .19443 .65545 L p .707 .577 .707 r
F P
0 g
s
.22158 .65543 m .2293 .71126 L .26017 .70875 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31317 .64162 m .32089 .69745 L .3448 .68977 L p .707 .577 .707 r
F P
0 g
s
.3448 .68977 m .33709 .63394 L .31317 .64162 L p .707 .577 .707 r
F P
0 g
s
.69066 .72632 m .69579 .76354 L .68341 .75881 L p .707 .577 .707 r
F P
0 g
s
.68341 .75881 m .67828 .72159 L .69066 .72632 L p .707 .577 .707 r
F P
0 g
s
.68842 .64382 m .69613 .69965 L .67535 .69718 L p .707 .577 .707 r
F P
0 g
s
.67535 .69718 m .66764 .64135 L .68842 .64382 L p .707 .577 .707 r
F P
0 g
s
.64049 .64137 m .6482 .6972 L .61733 .69972 L p .707 .577 .707 r
F P
0 g
s
.61733 .69972 m .60962 .64389 L .64049 .64137 L p .707 .577 .707 r
F P
0 g
s
.64775 .78107 m .64414 .79882 L .61357 .79083 L p .707 .577 .707 r
F P
0 g
s
.61357 .79083 m .61719 .77308 L .64775 .78107 L p .707 .577 .707 r
F P
0 g
s
.61198 .30724 m .60831 .80872 L .63142 .79837 L p .707 .577 .707 r
F P
0 g
s
.63548 .75633 m .63035 .71911 L .6575 .7191 L p .707 .577 .707 r
F P
0 g
s
.63142 .79837 m .63509 .29689 L .61198 .30724 L p .707 .577 .707 r
F P
0 g
s
.19443 .65545 m .20215 .71128 L .2293 .71126 L p .707 .577 .707 r
F P
0 g
s
.20215 .71128 m .19443 .65545 L .17365 .65298 L p .707 .577 .707 r
F P
0 g
s
.24744 .76782 m .24231 .7306 L .21145 .7331 L p .707 .577 .707 r
F P
0 g
s
.24231 .7306 m .24744 .76782 L .279 .76307 L p .707 .577 .707 r
F P
0 g
s
.279 .76307 m .27388 .72585 L .24231 .7306 L p .707 .577 .707 r
F P
0 g
s
.27388 .72585 m .279 .76307 L .30817 .75654 L p .707 .577 .707 r
F P
0 g
s
.30817 .75654 m .30304 .71932 L .27388 .72585 L p .707 .577 .707 r
F P
0 g
s
.70727 .81574 m .70366 .8335 L .6915 .82125 L p .707 .577 .707 r
F P
0 g
s
.6915 .82125 m .69511 .8035 L .70727 .81574 L p .707 .577 .707 r
F P
0 g
s
.33709 .63394 m .3448 .68977 L .36112 .68171 L p .707 .577 .707 r
F P
0 g
s
.36112 .68171 m .35341 .62587 L .33709 .63394 L p .707 .577 .707 r
F P
0 g
s
.21657 .77032 m .21145 .7331 L .18429 .73311 L p .707 .577 .707 r
F P
0 g
s
.21145 .7331 m .21657 .77032 L .24744 .76782 L p .707 .577 .707 r
F P
0 g
s
.37544 .80295 m .3791 .30147 L .36133 .2901 L p .707 .577 .707 r
F P
0 g
s
.3791 .30147 m .37544 .80295 L .40516 .81235 L p .707 .577 .707 r
F P
0 g
s
.17365 .65298 m .18137 .70881 L .20215 .71128 L p .707 .577 .707 r
F P
0 g
s
.30304 .71932 m .30817 .75654 L .33208 .74887 L p .707 .577 .707 r
F P
0 g
s
.33208 .74887 m .32695 .71165 L .30304 .71932 L p .707 .577 .707 r
F P
0 g
s
.2558 .82135 m .25942 .80359 L .22885 .7956 L p .707 .577 .707 r
F P
0 g
s
.25942 .80359 m .2558 .82135 L .28709 .82607 L p .707 .577 .707 r
F P
0 g
s
.28709 .82607 m .29071 .80831 L .25942 .80359 L p .707 .577 .707 r
F P
0 g
s
.66764 .64135 m .67535 .69718 L .6482 .6972 L p .707 .577 .707 r
F P
0 g
s
.6482 .6972 m .64049 .64137 L .66764 .64135 L p .707 .577 .707 r
F P
0 g
s
.18429 .73311 m .18942 .77033 L .21657 .77032 L p .707 .577 .707 r
F P
0 g
s
.67828 .72159 m .68341 .75881 L .66263 .75632 L p .707 .577 .707 r
F P
0 g
s
.66263 .75632 m .6575 .7191 L .67828 .72159 L p .707 .577 .707 r
F P
0 g
s
.29071 .80831 m .28709 .82607 L .31604 .82705 L p .707 .577 .707 r
F P
0 g
s
.31604 .82705 m .31965 .80929 L .29071 .80831 L p .707 .577 .707 r
F P
0 g
s
.22524 .81336 m .22885 .7956 L .202 .78512 L p .707 .577 .707 r
F P
0 g
s
.22885 .7956 m .22524 .81336 L .2558 .82135 L p .707 .577 .707 r
F P
0 g
s
.18137 .70881 m .17365 .65298 L .16128 .64825 L p .707 .577 .707 r
F P
0 g
s
.202 .78512 m .19839 .80288 L .22524 .81336 L p .707 .577 .707 r
F P
0 g
s
.18942 .77033 m .18429 .73311 L .16351 .73062 L p .707 .577 .707 r
F P
0 g
s
.6575 .7191 m .66263 .75632 L .63548 .75633 L p .707 .577 .707 r
F P
0 g
s
.63509 .29689 m .63142 .79837 L .64142 .78651 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .64508 .28503 L .63509 .29689 L p .707 .577 .707 r
F P
0 g
s
.31965 .80929 m .31604 .82705 L .33981 .8242 L p .707 .577 .707 r
F P
0 g
s
.33981 .8242 m .34343 .80644 L .31965 .80929 L p .707 .577 .707 r
F P
0 g
s
.19839 .80288 m .202 .78512 L .18149 .77317 L p .707 .577 .707 r
F P
0 g
s
.32695 .71165 m .33208 .74887 L .3484 .74081 L p .707 .577 .707 r
F P
0 g
s
.3484 .74081 m .34327 .70359 L .32695 .71165 L p .707 .577 .707 r
F P
0 g
s
.16351 .73062 m .16864 .76785 L .18942 .77033 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35724 .27789 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.35341 .62587 m .36112 .68171 L .36644 .67599 L p .707 .577 .707 r
F P
0 g
s
.36614 .66717 m .35341 .62587 L .36644 .67599 L .707 .577 .707 r
F
.36825 .67404 m .36054 .61821 L .35341 .62587 L p F P
0 g
s
.35778 .6117 m .36054 .61821 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.3655 .66753 m .36285 .64836 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .35778 .6117 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.35778 .6117 m .36285 .64836 L p .35312 .6628 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .3655 .66753 L .36207 .66622 L p .707 .577 .707 r
F P
0 g
s
.36207 .66622 m .35312 .6628 L p .36285 .64836 L .707 .577 .707 r
F P
0 g
s
.34327 .70359 m .3484 .74081 L .35553 .73314 L p .707 .577 .707 r
F P
0 g
s
.35553 .73314 m .35041 .69592 L .34327 .70359 L p .707 .577 .707 r
F P
0 g
s
.35041 .69592 m .35553 .73314 L .35278 .72662 L p .707 .577 .707 r
F P
0 g
s
.35312 .6628 m .34541 .60697 L .35778 .6117 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .34849 .78488 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.36426 .77937 m .3618 .79145 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.3618 .79145 m .36065 .79712 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .3521 .76712 L .36135 .77643 L p .707 .577 .707 r
F P
0 g
s
.36135 .77643 m .36426 .77937 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .36135 .77643 L .36147 .78034 L .707 .577 .707 r
F
.35764 .76737 m .35754 .65014 L .3567 .78873 L F
.35754 .65014 m .35724 .27789 L .35687 .62788 L F
.35754 .65014 m .35687 .62788 L .3567 .78873 L F
.35357 .77937 m .3567 .78873 L p .35687 .62788 L F P
0 g
s
.35724 .27789 m .35511 .56932 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.35511 .56932 m .35357 .77937 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.3567 .78873 m .35766 .79158 L p .35764 .76737 L .707 .577 .707 r
F P
0 g
s
.35753 .63446 m .3599 .48527 L .35735 .41085 L .707 .577 .707 r
F
.35766 .79158 m .35878 .63774 L p .35753 .63446 L F P
0 g
s
.35878 .63774 m .3599 .48527 L p .35753 .63446 L .707 .577 .707 r
F P
0 g
s
.3599 .48527 m .36133 .2901 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.36644 .67599 m .36825 .67404 L p .36614 .66717 L .707 .577 .707 r
F P
0 g
s
.69511 .8035 m .6915 .82125 L .67099 .80931 L p .707 .577 .707 r
F P
0 g
s
.67099 .80931 m .6746 .79155 L .69511 .8035 L p .707 .577 .707 r
F P
0 g
s
.16128 .64825 m .16899 .70409 L .18137 .70881 L p .707 .577 .707 r
F P
0 g
s
.18149 .77317 m .17788 .79093 L .19839 .80288 L p .707 .577 .707 r
F P
0 g
s
.36054 .61821 m .36825 .67404 L .3655 .66753 L p .707 .577 .707 r
F P
0 g
s
.36327 .80846 m .36688 .79071 L .3597 .80004 L p .707 .577 .707 r
F P
0 g
s
.36688 .79071 m .36327 .80846 L .36065 .79712 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .36426 .77937 L .36688 .79071 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35766 .79158 L .37544 .80295 L p .707 .577 .707 r
F P
0 g
s
.16864 .76785 m .16351 .73062 L .15114 .72589 L p .707 .577 .707 r
F P
0 g
s
.16899 .70409 m .16128 .64825 L .15852 .64174 L p .707 .577 .707 r
F P
0 g
s
.34343 .80644 m .33981 .8242 L .35609 .81779 L p .707 .577 .707 r
F P
0 g
s
.35609 .81779 m .3597 .80004 L .34343 .80644 L p .707 .577 .707 r
F P
0 g
s
.17788 .79093 m .18149 .77317 L .16933 .76093 L p .707 .577 .707 r
F P
0 g
s
.6746 .79155 m .67099 .80931 L .64414 .79882 L p .707 .577 .707 r
F P
0 g
s
.64414 .79882 m .64775 .78107 L .6746 .79155 L p .707 .577 .707 r
F P
0 g
s
.15114 .72589 m .15626 .76311 L .16864 .76785 L p .707 .577 .707 r
F P
0 g
s
.16933 .76093 m .16572 .77869 L .17788 .79093 L p .707 .577 .707 r
F P
0 g
s
.15852 .64174 m .16624 .69757 L .16899 .70409 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .63733 .7743 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.64381 .45978 m .64142 .78651 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .64508 .28503 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63733 .7743 m .63879 .5747 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63879 .5747 m .641 .27282 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .63733 .7743 L .61955 .76294 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .64885 .71273 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63135 .67077 m .63381 .68866 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63381 .68866 m .63648 .70799 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .64372 .67551 L .63454 .67199 L p .707 .577 .707 r
F P
0 g
s
.63454 .67199 m .63135 .67077 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .63454 .67199 L .63429 .67782 L .707 .577 .707 r
F
.64508 .28503 m .64381 .45978 L p .64146 .51343 L F P
0 g
s
.15626 .76311 m .15114 .72589 L .14838 .71937 L p .707 .577 .707 r
F P
0 g
s
.3597 .80004 m .35609 .81779 L .36327 .80846 L p .707 .577 .707 r
F P
0 g
s
.16572 .77869 m .16933 .76093 L .16672 .74959 L p .707 .577 .707 r
F P
0 g
s
.16624 .69757 m .15852 .64174 L .16565 .63408 L p .707 .577 .707 r
F P
0 g
s
.14838 .71937 m .15351 .75659 L .15626 .76311 L p .707 .577 .707 r
F P
0 g
s
.16672 .74959 m .1631 .76734 L .16572 .77869 L p .707 .577 .707 r
F P
0 g
s
.35278 .72662 m .34765 .6894 L .35041 .69592 L p .707 .577 .707 r
F P
0 g
s
.35357 .77937 m .35724 .27789 L .36724 .26603 L p .707 .577 .707 r
F P
0 g
s
.16565 .63408 m .17337 .68991 L .16624 .69757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15351 .75659 m .14838 .71937 L .15551 .7117 L p .707 .577 .707 r
F P
0 g
s
.1631 .76734 m .16672 .74959 L .17389 .74026 L p .707 .577 .707 r
F P
0 g
s
.17337 .68991 m .16565 .63408 L .18197 .62601 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17389 .74026 m .17028 .75801 L .1631 .76734 L p .707 .577 .707 r
F P
0 g
s
.61955 .76294 m .62322 .26146 L .641 .27282 L p .707 .577 .707 r
F P
0 g
s
.15551 .7117 m .16064 .74892 L .15351 .75659 L p .707 .577 .707 r
F P
0 g
s
.34765 .6894 m .35278 .72662 L .3404 .72189 L p .707 .577 .707 r
F P
0 g
s
.3404 .72189 m .33527 .68467 L .34765 .6894 L p .707 .577 .707 r
F P
0 g
s
.34541 .60697 m .35312 .6628 L .33234 .66033 L p .707 .577 .707 r
F P
0 g
s
.33234 .66033 m .32463 .6045 L .34541 .60697 L p .707 .577 .707 r
F P
0 g
s
.18197 .62601 m .18969 .68184 L .17337 .68991 L p .707 .577 .707 r
F P
0 g
s
.36357 .76751 m .36724 .26603 L .39035 .25568 L p .707 .577 .707 r
F P
0 g
s
.36724 .26603 m .36357 .76751 L .35357 .77937 L p .707 .577 .707 r
F P
0 g
s
.16064 .74892 m .15551 .7117 L .17183 .70364 L p .707 .577 .707 r
F P
0 g
s
.17028 .75801 m .17389 .74026 L .19017 .73386 L p .707 .577 .707 r
F P
0 g
s
.18969 .68184 m .18197 .62601 L .20589 .61833 L p .707 .577 .707 r
F P
0 g
s
.19017 .73386 m .18655 .75161 L .17028 .75801 L p .707 .577 .707 r
F P
0 g
s
.17183 .70364 m .17696 .74086 L .16064 .74892 L p .707 .577 .707 r
F P
0 g
s
.32463 .6045 m .33234 .66033 L .30519 .66035 L p .707 .577 .707 r
F P
0 g
s
.30519 .66035 m .29748 .60452 L .32463 .6045 L p .707 .577 .707 r
F P
0 g
s
.33527 .68467 m .3404 .72189 L .31962 .7194 L p .707 .577 .707 r
F P
0 g
s
.31962 .7194 m .31449 .68218 L .33527 .68467 L p .707 .577 .707 r
F P
0 g
s
.20589 .61833 m .2136 .67416 L .18969 .68184 L p .707 .577 .707 r
F P
0 g
s
.62322 .26146 m .61955 .76294 L .58983 .75353 L p .707 .577 .707 r
F P
0 g
s
.58983 .75353 m .5935 .25205 L .62322 .26146 L p .707 .577 .707 r
F P
0 g
s
.2136 .67416 m .20589 .61833 L .23505 .61179 L p .707 .577 .707 r
F P
0 g
s
.29748 .60452 m .30519 .66035 L .27433 .66286 L p .707 .577 .707 r
F P
0 g
s
.27433 .66286 m .26661 .60703 L .29748 .60452 L p .707 .577 .707 r
F P
0 g
s
.3521 .76712 m .34849 .78488 L .32798 .77293 L p .707 .577 .707 r
F P
0 g
s
.32798 .77293 m .3316 .75518 L .3521 .76712 L p .707 .577 .707 r
F P
0 g
s
.17696 .74086 m .17183 .70364 L .19574 .69597 L p .707 .577 .707 r
F P
0 g
s
.18655 .75161 m .19017 .73386 L .21394 .731 L p .707 .577 .707 r
F P
0 g
s
.24277 .66762 m .23505 .61179 L .26661 .60703 L p .707 .577 .707 r
F P
0 g
s
.23505 .61179 m .24277 .66762 L .2136 .67416 L p .707 .577 .707 r
F P
0 g
s
.39035 .25568 m .38668 .75716 L .36357 .76751 L p .707 .577 .707 r
F P
0 g
s
.38668 .75716 m .39035 .25568 L .4243 .24786 L p .707 .577 .707 r
F P
0 g
s
.74038 .65356 m .73266 .59773 L .7018 .60024 L p .707 .577 .707 r
F P
0 g
s
.73266 .59773 m .74038 .65356 L .77194 .6488 L p .707 .577 .707 r
F P
0 g
s
.77194 .6488 m .76422 .59297 L .73266 .59773 L p .707 .577 .707 r
F P
0 g
s
.26661 .60703 m .27433 .66286 L .24277 .66762 L p .707 .577 .707 r
F P
0 g
s
.21394 .731 m .21033 .74876 L .18655 .75161 L p .707 .577 .707 r
F P
0 g
s
.31449 .68218 m .31962 .7194 L .29247 .71941 L p .707 .577 .707 r
F P
0 g
s
.29247 .71941 m .28734 .68219 L .31449 .68218 L p .707 .577 .707 r
F P
0 g
s
.19574 .69597 m .20087 .73319 L .17696 .74086 L p .707 .577 .707 r
F P
0 g
s
.76422 .59297 m .77194 .6488 L .8011 .64226 L p .707 .577 .707 r
F P
0 g
s
.8011 .64226 m .79339 .58643 L .76422 .59297 L p .707 .577 .707 r
F P
0 g
s
.70951 .65608 m .7018 .60024 L .67464 .60027 L p .707 .577 .707 r
F P
0 g
s
.7018 .60024 m .70951 .65608 L .74038 .65356 L p .707 .577 .707 r
F P
0 g
s
.20087 .73319 m .19574 .69597 L .22491 .68944 L p .707 .577 .707 r
F P
0 g
s
.79339 .58643 m .8011 .64226 L .82502 .63459 L p .707 .577 .707 r
F P
0 g
s
.82502 .63459 m .8173 .57876 L .79339 .58643 L p .707 .577 .707 r
F P
0 g
s
.3316 .75518 m .32798 .77293 L .30113 .76245 L p .707 .577 .707 r
F P
0 g
s
.30113 .76245 m .30474 .74469 L .3316 .75518 L p .707 .577 .707 r
F P
0 g
s
.21033 .74876 m .21394 .731 L .24289 .73199 L p .707 .577 .707 r
F P
0 g
s
.5935 .25205 m .58983 .75353 L .55107 .74701 L p .707 .577 .707 r
F P
0 g
s
.55107 .74701 m .55473 .24552 L .5935 .25205 L p .707 .577 .707 r
F P
0 g
s
.28734 .68219 m .29247 .71941 L .2616 .72191 L p .707 .577 .707 r
F P
0 g
s
.2616 .72191 m .25647 .68469 L .28734 .68219 L p .707 .577 .707 r
F P
0 g
s
.67464 .60027 m .68236 .6561 L .70951 .65608 L p .707 .577 .707 r
F P
0 g
s
.22491 .68944 m .23004 .72666 L .20087 .73319 L p .707 .577 .707 r
F P
0 g
s
.24289 .73199 m .23928 .74974 L .21033 .74876 L p .707 .577 .707 r
F P
0 g
s
.23004 .72666 m .22491 .68944 L .25647 .68469 L p .707 .577 .707 r
F P
0 g
s
.68236 .6561 m .67464 .60027 L .65386 .59779 L p .707 .577 .707 r
F P
0 g
s
.72766 .7127 m .72253 .67548 L .69166 .67798 L p .707 .577 .707 r
F P
0 g
s
.72253 .67548 m .72766 .7127 L .75922 .70796 L p .707 .577 .707 r
F P
0 g
s
.75922 .70796 m .75409 .67073 L .72253 .67548 L p .707 .577 .707 r
F P
0 g
s
.25647 .68469 m .2616 .72191 L .23004 .72666 L p .707 .577 .707 r
F P
0 g
s
.42064 .74934 m .4243 .24786 L .46578 .24332 L p .707 .577 .707 r
F P
0 g
s
.4243 .24786 m .42085 .71973 L p .38668 .75716 L .707 .577 .707 r
F P
0 g
s
.46578 .24332 m .46212 .7448 L .42064 .74934 L p .707 .577 .707 r
F P
0 g
s
.42121 .55612 m .42893 .61195 L .45001 .60722 L p .707 .577 .707 r
F P
0 g
s
.45001 .60722 m .45809 .60541 L p .45244 .59785 L .707 .577 .707 r
F P
0 g
s
.45244 .59785 m .42121 .55612 L .45001 .60722 L .707 .577 .707 r
F
.42085 .71973 m .42064 .74934 L .4127 .75117 L p F P
0 g
s
.4127 .75117 m .38668 .75716 L p .42085 .71973 L .707 .577 .707 r
F P
0 g
s
.75409 .67073 m .75922 .70796 L .78838 .70143 L p .707 .577 .707 r
F P
0 g
s
.78838 .70143 m .78325 .66421 L .75409 .67073 L p .707 .577 .707 r
F P
0 g
s
.30474 .74469 m .30113 .76245 L .27056 .75446 L p .707 .577 .707 r
F P
0 g
s
.27056 .75446 m .27418 .7367 L .30474 .74469 L p .707 .577 .707 r
F P
0 g
s
.23928 .74974 m .24289 .73199 L .27418 .7367 L p .707 .577 .707 r
F P
0 g
s
.8173 .57876 m .82502 .63459 L .84134 .62652 L p .707 .577 .707 r
F P
0 g
s
.84134 .62652 m .83362 .57069 L .8173 .57876 L p .707 .577 .707 r
F P
0 g
s
.27418 .7367 m .27056 .75446 L .23928 .74974 L p .707 .577 .707 r
F P
0 g
s
.69679 .7152 m .69166 .67798 L .6645 .67799 L p .707 .577 .707 r
F P
0 g
s
.69166 .67798 m .69679 .7152 L .72766 .7127 L p .707 .577 .707 r
F P
0 g
s
.65386 .59779 m .66158 .65362 L .68236 .6561 L p .707 .577 .707 r
F P
0 g
s
.73602 .76569 m .73963 .74793 L .70906 .73994 L p .707 .577 .707 r
F P
0 g
s
.73963 .74793 m .73602 .76569 L .76731 .7704 L p .707 .577 .707 r
F P
0 g
s
.76731 .7704 m .77092 .75265 L .73963 .74793 L p .707 .577 .707 r
F P
0 g
s
.78325 .66421 m .78838 .70143 L .8123 .69375 L p .707 .577 .707 r
F P
0 g
s
.8123 .69375 m .80717 .65653 L .78325 .66421 L p .707 .577 .707 r
F P
0 g
s
.55473 .24552 m .55107 .74701 L .50706 .744 L p .707 .577 .707 r
F P
0 g
s
.50706 .744 m .51073 .24252 L .55473 .24552 L p .707 .577 .707 r
F P
0 g
s
.6645 .67799 m .66963 .71521 L .69679 .7152 L p .707 .577 .707 r
F P
0 g
s
.77092 .75265 m .76731 .7704 L .79625 .77138 L p .707 .577 .707 r
F P
0 g
s
.79625 .77138 m .79987 .75363 L .77092 .75265 L p .707 .577 .707 r
F P
0 g
s
.70545 .7577 m .70906 .73994 L .68221 .72946 L p .707 .577 .707 r
F P
0 g
s
.70906 .73994 m .70545 .7577 L .73602 .76569 L p .707 .577 .707 r
F P
0 g
s
.46212 .7448 m .46578 .24332 L .51073 .24252 L p .707 .577 .707 r
F P
0 g
s
.51073 .24252 m .50706 .744 L .46212 .7448 L p .707 .577 .707 r
F P
0 g
s
.66158 .65362 m .65386 .59779 L .64149 .59307 L p .707 .577 .707 r
F P
0 g
s
.68221 .72946 m .6786 .74721 L .70545 .7577 L p .707 .577 .707 r
F P
0 g
s
.66963 .71521 m .6645 .67799 L .64372 .67551 L p .707 .577 .707 r
F P
0 g
s
.79987 .75363 m .79625 .77138 L .82003 .76853 L p .707 .577 .707 r
F P
0 g
s
.82003 .76853 m .82364 .75078 L .79987 .75363 L p .707 .577 .707 r
F P
0 g
s
.6786 .74721 m .68221 .72946 L .6617 .71751 L p .707 .577 .707 r
F P
0 g
s
.80717 .65653 m .8123 .69375 L .82862 .68569 L p .707 .577 .707 r
F P
0 g
s
.82862 .68569 m .82349 .64847 L .80717 .65653 L p .707 .577 .707 r
F P
0 g
s
.64372 .67551 m .64885 .71273 L .66963 .71521 L p .707 .577 .707 r
F P
0 g
s
.83362 .57069 m .84134 .62652 L .84847 .61885 L p .707 .577 .707 r
F P
0 g
s
.84847 .61885 m .84075 .56302 L .83362 .57069 L p .707 .577 .707 r
F P
0 g
s
.64149 .59307 m .64921 .6489 L .66158 .65362 L p .707 .577 .707 r
F P
0 g
s
.6617 .71751 m .65809 .73527 L .6786 .74721 L p .707 .577 .707 r
F P
0 g
s
.64921 .6489 m .64149 .59307 L .63874 .58656 L p .707 .577 .707 r
F P
0 g
s
.82364 .75078 m .82003 .76853 L .8363 .76213 L p .707 .577 .707 r
F P
0 g
s
.8363 .76213 m .83991 .74437 L .82364 .75078 L p .707 .577 .707 r
F P
0 g
s
.65809 .73527 m .6617 .71751 L .64955 .70527 L p .707 .577 .707 r
F P
0 g
s
.82349 .64847 m .82862 .68569 L .83575 .67802 L p .707 .577 .707 r
F P
0 g
s
.83575 .67802 m .83062 .6408 L .82349 .64847 L p .707 .577 .707 r
F P
0 g
s
.64955 .70527 m .64593 .72302 L .65809 .73527 L p .707 .577 .707 r
F P
0 g
s
.84075 .56302 m .84847 .61885 L .84571 .61234 L p .707 .577 .707 r
F P
0 g
s
.84571 .61234 m .838 .55651 L .84075 .56302 L p .707 .577 .707 r
F P
0 g
s
.63874 .58656 m .64645 .64239 L .64921 .6489 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .63135 .67077 L .62859 .66425 L p .707 .577 .707 r
F P
0 g
s
.83991 .74437 m .8363 .76213 L .84348 .7528 L p .707 .577 .707 r
F P
0 g
s
.84348 .7528 m .84709 .73504 L .83991 .74437 L p .707 .577 .707 r
F P
0 g
s
.64593 .72302 m .64955 .70527 L .64693 .69392 L p .707 .577 .707 r
F P
0 g
s
.64645 .64239 m .63874 .58656 L .64587 .57889 L p .707 .577 .707 r
F P
0 g
s
.62859 .66425 m .63372 .70147 L .63648 .70799 L p .707 .577 .707 r
F P
0 g
s
.64693 .69392 m .64332 .71168 L .64593 .72302 L p .707 .577 .707 r
F P
0 g
s
.83062 .6408 m .83575 .67802 L .83299 .6715 L p .707 .577 .707 r
F P
0 g
s
.83299 .6715 m .82786 .63428 L .83062 .6408 L p .707 .577 .707 r
F P
0 g
s
.838 .55651 m .84571 .61234 L .83334 .60762 L p .707 .577 .707 r
F P
0 g
s
.83334 .60762 m .82562 .55178 L .838 .55651 L p .707 .577 .707 r
F P
0 g
s
.64587 .57889 m .65358 .63472 L .64645 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39737 .61671 m .38965 .56088 L .35879 .56339 L p .707 .577 .707 r
F P
0 g
s
.38965 .56088 m .39737 .61671 L .42893 .61195 L p .707 .577 .707 r
F P
0 g
s
.42893 .61195 m .42121 .55612 L .38965 .56088 L p .707 .577 .707 r
F P
0 g
s
.45809 .60541 m .45038 .54958 L .42121 .55612 L p .707 .577 .707 r
F P
0 g
s
.84709 .73504 m .84348 .7528 L .84086 .74146 L p .707 .577 .707 r
F P
0 g
s
.84086 .74146 m .84448 .7237 L .84709 .73504 L p .707 .577 .707 r
F P
0 g
s
.63372 .70147 m .62859 .66425 L .63572 .65659 L p .707 .577 .707 r
F P
0 g
s
.64332 .71168 m .64693 .69392 L .65411 .68459 L p .707 .577 .707 r
F P
0 g
s
.65358 .63472 m .64587 .57889 L .66219 .57082 L p .707 .577 .707 r
F P
0 g
s
.3665 .61922 m .35879 .56339 L .33163 .56341 L p .707 .577 .707 r
F P
0 g
s
.35879 .56339 m .3665 .61922 L .39737 .61671 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65411 .68459 m .65049 .70235 L .64332 .71168 L p .707 .577 .707 r
F P
0 g
s
.63572 .65659 m .64085 .69381 L .63372 .70147 L p .707 .577 .707 r
F P
0 g
s
.45038 .54958 m .45809 .60541 L .48201 .59773 L p .707 .577 .707 r
F P
0 g
s
.48201 .59773 m .47429 .5419 L .45038 .54958 L p .707 .577 .707 r
F P
0 g
s
.82786 .63428 m .83299 .6715 L .82062 .66677 L p .707 .577 .707 r
F P
0 g
s
.82062 .66677 m .81549 .62955 L .82786 .63428 L p .707 .577 .707 r
F P
0 g
s
.82562 .55178 m .83334 .60762 L .81256 .60514 L p .707 .577 .707 r
F P
0 g
s
.81256 .60514 m .80484 .54931 L .82562 .55178 L p .707 .577 .707 r
F P
0 g
s
.66219 .57082 m .6699 .62665 L .65358 .63472 L p .707 .577 .707 r
F P
0 g
s
.33163 .56341 m .33935 .61924 L .3665 .61922 L p .707 .577 .707 r
F P
0 g
s
.33935 .61924 m .33163 .56341 L .31085 .56094 L p .707 .577 .707 r
F P
0 g
s
.38465 .67578 m .37952 .63856 L .34865 .64106 L p .707 .577 .707 r
F P
0 g
s
.37952 .63856 m .38465 .67578 L .41621 .67104 L p .707 .577 .707 r
F P
0 g
s
.41621 .67104 m .41108 .63381 L .37952 .63856 L p .707 .577 .707 r
F P
0 g
s
.41108 .63381 m .41621 .67104 L .44537 .66451 L p .707 .577 .707 r
F P
0 g
s
.44537 .66451 m .44024 .62729 L .41108 .63381 L p .707 .577 .707 r
F P
0 g
s
.84448 .7237 m .84086 .74146 L .8287 .72922 L p .707 .577 .707 r
F P
0 g
s
.8287 .72922 m .83232 .71146 L .84448 .7237 L p .707 .577 .707 r
F P
0 g
s
.47429 .5419 m .48201 .59773 L .49833 .58967 L p .707 .577 .707 r
F P
0 g
s
.49833 .58967 m .49061 .53384 L .47429 .5419 L p .707 .577 .707 r
F P
0 g
s
.64085 .69381 m .63572 .65659 L .65204 .64852 L p .707 .577 .707 r
F P
0 g
s
.65049 .70235 m .65411 .68459 L .67038 .67819 L p .707 .577 .707 r
F P
0 g
s
.6699 .62665 m .66219 .57082 L .6861 .56314 L p .707 .577 .707 r
F P
0 g
s
.35378 .67828 m .34865 .64106 L .32149 .64107 L p .707 .577 .707 r
F P
0 g
s
.34865 .64106 m .35378 .67828 L .38465 .67578 L p .707 .577 .707 r
F P
0 g
s
.31085 .56094 m .31857 .61677 L .33935 .61924 L p .707 .577 .707 r
F P
0 g
s
.44024 .62729 m .44537 .66451 L .46929 .65683 L p .707 .577 .707 r
F P
0 g
s
.46929 .65683 m .46416 .61961 L .44024 .62729 L p .707 .577 .707 r
F P
0 g
s
.39301 .72931 m .39662 .71156 L .36605 .70356 L p .707 .577 .707 r
F P
0 g
s
.39662 .71156 m .39301 .72931 L .4243 .73403 L p .707 .577 .707 r
F P
0 g
s
.4243 .73403 m .42791 .71627 L .39662 .71156 L p .707 .577 .707 r
F P
0 g
s
.67038 .67819 m .66677 .69595 L .65049 .70235 L p .707 .577 .707 r
F P
0 g
s
.65204 .64852 m .65717 .68574 L .64085 .69381 L p .707 .577 .707 r
F P
0 g
s
.80484 .54931 m .81256 .60514 L .78541 .60516 L p .707 .577 .707 r
F P
0 g
s
.78541 .60516 m .77769 .54933 L .80484 .54931 L p .707 .577 .707 r
F P
0 g
s
.32149 .64107 m .32662 .67829 L .35378 .67828 L p .707 .577 .707 r
F P
0 g
s
.81549 .62955 m .82062 .66677 L .79984 .66428 L p .707 .577 .707 r
F P
0 g
s
.79984 .66428 m .79471 .62706 L .81549 .62955 L p .707 .577 .707 r
F P
0 g
s
.42791 .71627 m .4243 .73403 L .45324 .73501 L p .707 .577 .707 r
F P
0 g
s
.45324 .73501 m .45686 .71725 L .42791 .71627 L p .707 .577 .707 r
F P
0 g
s
.36244 .72132 m .36605 .70356 L .3392 .69308 L p .707 .577 .707 r
F P
0 g
s
.36605 .70356 m .36244 .72132 L .39301 .72931 L p .707 .577 .707 r
F P
0 g
s
.6861 .56314 m .69382 .61898 L .6699 .62665 L p .707 .577 .707 r
F P
0 g
s
.31857 .61677 m .31085 .56094 L .29848 .55622 L p .707 .577 .707 r
F P
0 g
s
.3392 .69308 m .33559 .71084 L .36244 .72132 L p .707 .577 .707 r
F P
0 g
s
.32662 .67829 m .32149 .64107 L .30071 .63859 L p .707 .577 .707 r
F P
0 g
s
.69382 .61898 m .6861 .56314 L .71526 .55661 L p .707 .577 .707 r
F P
0 g
s
.45686 .71725 m .45324 .73501 L .47702 .73216 L p .707 .577 .707 r
F P
0 g
s
.47702 .73216 m .48063 .7144 L .45686 .71725 L p .707 .577 .707 r
F P
0 g
s
.33559 .71084 m .3392 .69308 L .31869 .68113 L p .707 .577 .707 r
F P
0 g
s
.77769 .54933 m .78541 .60516 L .75454 .60768 L p .707 .577 .707 r
F P
0 g
s
.75454 .60768 m .74682 .55185 L .77769 .54933 L p .707 .577 .707 r
F P
0 g
s
.46416 .61961 m .46929 .65683 L .48561 .64877 L p .707 .577 .707 r
F P
0 g
s
.48561 .64877 m .48048 .61155 L .46416 .61961 L p .707 .577 .707 r
F P
0 g
s
.30071 .63859 m .30584 .67581 L .32662 .67829 L p .707 .577 .707 r
F P
0 g
s
.49061 .53384 m .49833 .58967 L .50546 .582 L p .707 .577 .707 r
F P
0 g
s
.50546 .582 m .49774 .52617 L .49061 .53384 L p .707 .577 .707 r
F P
0 g
s
.83232 .71146 m .8287 .72922 L .8082 .71727 L p .707 .577 .707 r
F P
0 g
s
.8082 .71727 m .81181 .69951 L .83232 .71146 L p .707 .577 .707 r
F P
0 g
s
.65717 .68574 m .65204 .64852 L .67596 .64085 L p .707 .577 .707 r
F P
0 g
s
.66677 .69595 m .67038 .67819 L .69416 .67534 L p .707 .577 .707 r
F P
0 g
s
.29848 .55622 m .3062 .61205 L .31857 .61677 L p .707 .577 .707 r
F P
0 g
s
.31869 .68113 m .31508 .69889 L .33559 .71084 L p .707 .577 .707 r
F P
0 g
s
.72298 .61244 m .71526 .55661 L .74682 .55185 L p .707 .577 .707 r
F P
0 g
s
.71526 .55661 m .72298 .61244 L .69382 .61898 L p .707 .577 .707 r
F P
0 g
s
.74682 .55185 m .75454 .60768 L .72298 .61244 L p .707 .577 .707 r
F P
0 g
s
.69416 .67534 m .69054 .6931 L .66677 .69595 L p .707 .577 .707 r
F P
0 g
s
.79471 .62706 m .79984 .66428 L .77268 .66429 L p .707 .577 .707 r
F P
0 g
s
.77268 .66429 m .76755 .62707 L .79471 .62706 L p .707 .577 .707 r
F P
0 g
s
.67596 .64085 m .68109 .67807 L .65717 .68574 L p .707 .577 .707 r
F P
0 g
s
.30584 .67581 m .30071 .63859 L .28834 .63385 L p .707 .577 .707 r
F P
0 g
s
.3062 .61205 m .29848 .55622 L .29572 .5497 L p .707 .577 .707 r
F P
0 g
s
.48063 .7144 m .47702 .73216 L .49329 .72576 L p .707 .577 .707 r
F P
0 g
s
.49329 .72576 m .4969 .708 L .48063 .7144 L p .707 .577 .707 r
F P
0 g
s
.68109 .67807 m .67596 .64085 L .70512 .63432 L p .707 .577 .707 r
F P
0 g
s
.31508 .69889 m .31869 .68113 L .30654 .66889 L p .707 .577 .707 r
F P
0 g
s
.81181 .69951 m .8082 .71727 L .78134 .70679 L p .707 .577 .707 r
F P
0 g
s
.78134 .70679 m .78496 .68903 L .81181 .69951 L p .707 .577 .707 r
F P
0 g
s
.69054 .6931 m .69416 .67534 L .7231 .67632 L p .707 .577 .707 r
F P
0 g
s
.28834 .63385 m .29347 .67107 L .30584 .67581 L p .707 .577 .707 r
F P
0 g
s
.76755 .62707 m .77268 .66429 L .74181 .66679 L p .707 .577 .707 r
F P
0 g
s
.74181 .66679 m .73668 .62957 L .76755 .62707 L p .707 .577 .707 r
F P
0 g
s
.48048 .61155 m .48561 .64877 L .49274 .6411 L p .707 .577 .707 r
F P
0 g
s
.49274 .6411 m .48761 .60388 L .48048 .61155 L p .707 .577 .707 r
F P
0 g
s
.30654 .66889 m .30292 .68665 L .31508 .69889 L p .707 .577 .707 r
F P
0 g
s
.70512 .63432 m .71025 .67154 L .68109 .67807 L p .707 .577 .707 r
F P
0 g
s
.7231 .67632 m .71949 .69408 L .69054 .6931 L p .707 .577 .707 r
F P
0 g
s
.49774 .52617 m .50546 .582 L .5027 .57549 L p .707 .577 .707 r
F P
0 g
s
.5027 .57549 m .49499 .51966 L .49774 .52617 L p .707 .577 .707 r
F P
0 g
s
.29572 .5497 m .30344 .60553 L .3062 .61205 L p .707 .577 .707 r
F P
0 g
s
.71025 .67154 m .70512 .63432 L .73668 .62957 L p .707 .577 .707 r
F P
0 g
s
.73668 .62957 m .74181 .66679 L .71025 .67154 L p .707 .577 .707 r
F P
0 g
s
.78496 .68903 m .78134 .70679 L .75078 .69879 L p .707 .577 .707 r
F P
0 g
s
.75078 .69879 m .75439 .68104 L .78496 .68903 L p .707 .577 .707 r
F P
0 g
s
.71949 .69408 m .7231 .67632 L .75439 .68104 L p .707 .577 .707 r
F P
0 g
s
.75439 .68104 m .75078 .69879 L .71949 .69408 L p .707 .577 .707 r
F P
0 g
s
.29347 .67107 m .28834 .63385 L .28558 .62733 L p .707 .577 .707 r
F P
0 g
s
.4969 .708 m .49329 .72576 L .50047 .71643 L p .707 .577 .707 r
F P
0 g
s
.50047 .71643 m .50408 .69867 L .4969 .708 L p .707 .577 .707 r
F P
0 g
s
.30292 .68665 m .30654 .66889 L .30392 .65755 L p .707 .577 .707 r
F P
0 g
s
.30344 .60553 m .29572 .5497 L .30286 .54204 L p .707 .577 .707 r
F P
0 g
s
.28558 .62733 m .29071 .66455 L .29347 .67107 L p .707 .577 .707 r
F P
0 g
s
.30392 .65755 m .3003 .67531 L .30292 .68665 L p .707 .577 .707 r
F P
0 g
s
.48761 .60388 m .49274 .6411 L .48998 .63458 L p .707 .577 .707 r
F P
0 g
s
.48998 .63458 m .48485 .59736 L .48761 .60388 L p .707 .577 .707 r
F P
0 g
s
.49499 .51966 m .5027 .57549 L .49033 .57076 L p .707 .577 .707 r
F P
0 g
s
.49033 .57076 m .48261 .51493 L .49499 .51966 L p .707 .577 .707 r
F P
0 g
s
.30286 .54204 m .31057 .59787 L .30344 .60553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50408 .69867 m .50047 .71643 L .49785 .70508 L p .707 .577 .707 r
F P
0 g
s
.49785 .70508 m .50147 .68733 L .50408 .69867 L p .707 .577 .707 r
F P
0 g
s
.29071 .66455 m .28558 .62733 L .29271 .61966 L p .707 .577 .707 r
F P
0 g
s
.3003 .67531 m .30392 .65755 L .3111 .64822 L p .707 .577 .707 r
F P
0 g
s
.31057 .59787 m .30286 .54204 L .31918 .53397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3111 .64822 m .30748 .66598 L .3003 .67531 L p .707 .577 .707 r
F P
0 g
s
.29271 .61966 m .29784 .65689 L .29071 .66455 L p .707 .577 .707 r
F P
0 g
s
.48485 .59736 m .48998 .63458 L .47761 .62985 L p .707 .577 .707 r
F P
0 g
s
.47761 .62985 m .47248 .59263 L .48485 .59736 L p .707 .577 .707 r
F P
0 g
s
.48261 .51493 m .49033 .57076 L .46955 .56829 L p .707 .577 .707 r
F P
0 g
s
.46955 .56829 m .46183 .51246 L .48261 .51493 L p .707 .577 .707 r
F P
0 g
s
.31918 .53397 m .32689 .5898 L .31057 .59787 L p .707 .577 .707 r
F P
0 g
s
.50147 .68733 m .49785 .70508 L .48569 .69284 L p .707 .577 .707 r
F P
0 g
s
.48569 .69284 m .48931 .67508 L .50147 .68733 L p .707 .577 .707 r
F P
0 g
s
.29784 .65689 m .29271 .61966 L .30903 .6116 L p .707 .577 .707 r
F P
0 g
s
.30748 .66598 m .3111 .64822 L .32737 .64182 L p .707 .577 .707 r
F P
0 g
s
.32689 .5898 m .31918 .53397 L .34309 .52629 L p .707 .577 .707 r
F P
0 g
s
.32737 .64182 m .32376 .65957 L .30748 .66598 L p .707 .577 .707 r
F P
0 g
s
.30903 .6116 m .31416 .64882 L .29784 .65689 L p .707 .577 .707 r
F P
0 g
s
.46183 .51246 m .46955 .56829 L .4424 .56831 L p .707 .577 .707 r
F P
0 g
s
.4424 .56831 m .43468 .51248 L .46183 .51246 L p .707 .577 .707 r
F P
0 g
s
.47248 .59263 m .47761 .62985 L .45682 .62736 L p .707 .577 .707 r
F P
0 g
s
.45682 .62736 m .4517 .59014 L .47248 .59263 L p .707 .577 .707 r
F P
0 g
s
.34309 .52629 m .35081 .58212 L .32689 .5898 L p .707 .577 .707 r
F P
0 g
s
.35081 .58212 m .34309 .52629 L .37225 .51975 L p .707 .577 .707 r
F P
0 g
s
.43468 .51248 m .4424 .56831 L .41153 .57083 L p .707 .577 .707 r
F P
0 g
s
.41153 .57083 m .40381 .51499 L .43468 .51248 L p .707 .577 .707 r
F P
0 g
s
.48931 .67508 m .48569 .69284 L .46519 .68089 L p .707 .577 .707 r
F P
0 g
s
.46519 .68089 m .4688 .66314 L .48931 .67508 L p .707 .577 .707 r
F P
0 g
s
.31416 .64882 m .30903 .6116 L .33295 .60393 L p .707 .577 .707 r
F P
0 g
s
.32376 .65957 m .32737 .64182 L .35114 .63897 L p .707 .577 .707 r
F P
0 g
s
.37997 .57558 m .37225 .51975 L .40381 .51499 L p .707 .577 .707 r
F P
0 g
s
.37225 .51975 m .37997 .57558 L .35081 .58212 L p .707 .577 .707 r
F P
0 g
s
.40381 .51499 m .41153 .57083 L .37997 .57558 L p .707 .577 .707 r
F P
0 g
s
.35114 .63897 m .34753 .65672 L .32376 .65957 L p .707 .577 .707 r
F P
0 g
s
.4517 .59014 m .45682 .62736 L .42967 .62737 L p .707 .577 .707 r
F P
0 g
s
.42967 .62737 m .42454 .59015 L .4517 .59014 L p .707 .577 .707 r
F P
0 g
s
.33295 .60393 m .33808 .64115 L .31416 .64882 L p .707 .577 .707 r
F P
0 g
s
.33808 .64115 m .33295 .60393 L .36211 .5974 L p .707 .577 .707 r
F P
0 g
s
.4688 .66314 m .46519 .68089 L .43833 .67041 L p .707 .577 .707 r
F P
0 g
s
.43833 .67041 m .44195 .65265 L .4688 .66314 L p .707 .577 .707 r
F P
0 g
s
.34753 .65672 m .35114 .63897 L .38009 .63995 L p .707 .577 .707 r
F P
0 g
s
.42454 .59015 m .42967 .62737 L .3988 .62987 L p .707 .577 .707 r
F P
0 g
s
.3988 .62987 m .39367 .59265 L .42454 .59015 L p .707 .577 .707 r
F P
0 g
s
.36211 .5974 m .36724 .63462 L .33808 .64115 L p .707 .577 .707 r
F P
0 g
s
.38009 .63995 m .37648 .6577 L .34753 .65672 L p .707 .577 .707 r
F P
0 g
s
.36724 .63462 m .36211 .5974 L .39367 .59265 L p .707 .577 .707 r
F P
0 g
s
.39367 .59265 m .3988 .62987 L .36724 .63462 L p .707 .577 .707 r
F P
0 g
s
.44195 .65265 m .43833 .67041 L .40777 .66242 L p .707 .577 .707 r
F P
0 g
s
.40777 .66242 m .41138 .64466 L .44195 .65265 L p .707 .577 .707 r
F P
0 g
s
.37648 .6577 m .38009 .63995 L .41138 .64466 L p .707 .577 .707 r
F P
0 g
s
.41138 .64466 m .40777 .66242 L .37648 .6577 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1UYF0P002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001o
ogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo
001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002
FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009J
EP03001JEUYF009JEP03001JEUYF00MJEPl000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00UYF2P0015YF
00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00IGoo001TOol200000eYF000000050004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IGoo001TOol400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001POol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005aoo`@00003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005Yoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<006Eoo`00FGoo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EWoo
00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000KOolI000bOol005Aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8001Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P004goo10001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H0
05YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYF000^Ool005Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000QJEP03001JEUYF00AJEPD00004FUH00000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001EOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`04
001JEUYF0003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00@005YFFUH0009JEP05
001JEUYFFUH00006FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP0500000eYF
001JEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol2FUH30004FUH00`00FUIJ
EP03FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;7oo001FOol2FUH20005FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00D7oo1P0000AJEP00FUH000=JEP@000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000/Ool004Moo`T000AJEP05001JEP00001JEP0400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF6@000eYF00<007oo
Ool0:Woo0011Ool60004FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH0000002]oo`00?Goo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0
0003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00>Goo
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002]oo`00=goo0P0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0eYF0P00;7oo000eOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool003=o
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00@005YFFUIJEP8002eo
o`00<Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00AJEP03001JEUYF00D00003FUH005YF008002moo`00;goo0P000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH015YF40001UYF00<005YFFUH015YF00<005YFFUH00UYF10000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH0
15YF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00<Goo
000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP0@00000eYF001JEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000aOol002eoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0004FUH00`00FUIJEP03FUH50008FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH01000FUIJEUYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<0
05YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
10000UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH30002FUH00`00FUIJEP02FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJ
EP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080031oo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH01000FUH000001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00<7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF0P000eYF1@000eYF00@005YFFUIJEPP000AJEP03001JEUYF00MJEP04001JEUYF
FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH:0002FUH200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YF
FUH01`001UYF00<005YFFUH01EYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPl000=JEP03001JEUYF008002moo`00;Woo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH015YF1`001eYF0`0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF10000UYF00<005YFFUH01UYF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF009J
EPT0009oo`@00003FUH005YF00EJEPH00003FUH0000002moo`00;Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00@005YF001JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH00000008000MJEP03001JEUYF008000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEPH0009oo`T000EJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
02moo`00;Woo00<005YF000015YF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH015YF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP050007Ool500000eYF001J
EP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000_Ool002ioo`03001JEP0000AJEP03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEQL000MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF5@0000=JEP00FUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000^Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF2P000eYF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00UJEP8000IJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP03
001JEUYF009JEPL000IJEP03001JEUYF00AJEP03001JEUYF009JEP80031oo`00;Woo00@005YFFUH0
009JEP05001JEUYFFUH00007FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP02FUH01000FUIJEUYF
1P000UYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00@005YF000000=J
EP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02moo`00;goo0UYF0`0015YF00<005YFFUH0
1EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03
001JEP0000D0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP05001JEUYFFUH00002FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH01000
FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000
1EYF00<005YFFUH00P00<Woo000_Ool2FUH20005FUH01000FUIJEUYF1P001UYF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YF000015YF0P000UYF00<007oo00000UYF00<005YFFUH00eYF1P0015YF
00<005YFFUH02EYF00<005YFFUH00UYF0`000eYF00<005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUH0009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF0`00=7oo000_Ool015YF001JEP000eYF1P00
0eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1@000UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH015YF00@005YFFUIJEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEQD000AJEP03001JEUYF00MJEP04
001JEUYFFUH4000fOol002moo`80009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH00000FUH00P0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01`001UYF00<005YFFUH015YF0P00=Woo000_Ool200000eYF00000003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH01000FUIJEUYF
10001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP0000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEPD0009JEP03001JEUYF00EJEP<003Aoo`00<7oo0P001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00@005YFFUH003=oo`00;Woo0`001eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
25YF00<005YF00000`002EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF009JEPL000Ioo`8000=JEP03001JEUYF009JEP80035oo`00;7oo0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0P001eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000EJ
EP00001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH8000?Ool200000eYF001JEP05FUH00`00Oomoo`0^
Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEQD000=J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEQ00
00Ioo`<0011oo`8000IJEP8002moo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00<005YFFUH00`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP04001J
EUYFFUH20007Ool5000AOol20004FUH01000FUH00000;Goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000goo000000020002FUH00`00FUIJEP04FUH5
0002FUH00`00FUH000020006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0015YF1P0000=JEP00FUH00P002Goo1@004goo00@005YFFUH000AJEP03001oogoo02Yoo`00:Woo
00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P0000=oo`0000001`001UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000UYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00800004FUH00000000;Ool5
000DOol30004FUH00`00Oomoo`0ZOol002Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
01000003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF
00=JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00005FUH200000eYF
001oo`0;Ool3000GOol01000FUIJEUYF0P00;7oo000ZOol01000FUIJEP0015YF00<005YFFUH00eYF
1@0015YF2`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF200015YF00@005YFFUIJEPD000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP8000EJEP03001JEP00008002Ioo`03001JEUYF
008002aoo`00:Woo00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYF
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool0:goo000[
Ool00`00FUH00003FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF0`000UYF00<005YFFUH01EYF10008Woo00<005YF0000;7oo000[
Ool01000FUH005YF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF10001UYF00@005YF0000009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
0008FUH00`00FUIJEP04000NOol00`00FUH0000/Ool002]oo`05001JEP00001JEP020003FUH01000
FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP<000Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@005goo
1000;Goo000[Ool20002FUH20003FUH50003FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00@0
05YFFUIJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002FUH2000]Ool002]oo`80
009JEP800005FUH00000FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP070006FUH00`00FUIJEP05
FUH20005Ool01000FUIJEP001EYF00<005YFFUH010002UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<0
05YF00000P0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF000]Ool002]o
o`80009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP@0009JEP03001J
EUYF00IJEP<000=oo`04001JEUYF0005FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH>0002FUH60006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002aoo`03
001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPX000MJEP04001J
EUYF0002Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF0`001UYF00<005YFFUH00UYF
100017oo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00;Goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002Woo0P0015YF
00<005YFFUH00UYF0`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH30006FUH0
0`00FUIJEP03FUH30008Ool50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo
000^Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF1`0047oo0`0000=JEP00
FUH01EYF00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000EJEP00001JEP0000IJ
EP03001JEUYF009JEP03001JEP0000eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5000bOol0
02ioo`8000=JEPl000Ioo`<0015oo`8000IJEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP@00003FUH005YF00EJEP03001JEUYF009JEP80019oo`h003Moo`00;goo00@005YFFUIJEP<0
015oo`D0019oo`8000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP00
1UYF00<005YFFUH00UYF0P00Egoo000_Ool01@00FUIJEUYF00000UYF00<007ooOol03Woo1@0057oo
00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH01000
FUIJEUYF0P00F7oo000`Ool00`00FUH00004FUH2000>Ool5000EOol50004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH01000FUH00000FWoo000aOol20006FUH2000=Ool3000H
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF0080009J
EP<005aoo`00<Woo00<005YFFUH015YF00@005YF000002Moo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00009JEP04001JEUYFFUH2001OOol003=oo`8000AJEP04001JEUYFFUH3000U
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH2001M
Ool003Eoo`04001JEUYF0007FUH3000SOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30000
0eYF001JEP06FUH3001KOol003Ioo`<000QJEP03001JEP0000<001ioo`H000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009oo`<000IJEP03001JEUYF008005Uoo`00>7oo0P001eYF00<005YFFUH00eYF1`005Goo0P00
00=JEP0000000Woo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YF00000`001goo0P000eYF00<005YFFUH00eYF0P00Egoo000j
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool50003FUH20005Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH3000=
Ool200000eYF001JEP05FUH2001FOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH80003FUH01000FUIJEUYF0P002Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF1@0047oo0P001UYF00@005YF000005Aoo`00?goo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000moo`H0009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000800003Ool0000000<0015oo`80
00=JEP03001JEUYF009JEP03001oogoo055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8001Ioo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJ
EPL000Aoo`D001=oo`800003FUH005YF00=JEP03001oogoo055oo`00AWoo1`0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000021ooaX000]oo`D001Eoo`8000AJEP03001oogoo055oo`00
CGoo200015YF00@005YFFUIJEPD0035oo`8000EJEP04001JEP00000<Ool3000HOol00`00FUIJEP02
001COol005Eoo`P003Moo`03001JEUYF00=JEP04001JEUYFFUH3000UOol01000FUH00000Dgoo002E
Ool20002FUH00`00FUIJEP05FUH4000ROol3001COol009Moo`<000QJEP03001JEUYF00@001ioo`<0
05=oo`00VGoo0P001eYF00<005YFFUH015YF1@005goo1000E7oo002KOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP04000>Ool50002FUH2001DOol009eoo`<00003FUH005YF00QJEP03001JEUYF00AJ
EPh000=JEP06001JEUYF001JEP00E7oo002POol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001EOol00:Aoo`@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:Qoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEP00001GOol00:eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001IOol00;5o
o`h005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60719 .74291 m .59478 .68751 L .5644 .69274 L p .707 .577 .707 r
F P
0 g
s
.59478 .68751 m .60719 .74291 L .63831 .7357 L p .707 .577 .707 r
F P
0 g
s
.63831 .7357 m .62589 .68029 L .59478 .68751 L p .707 .577 .707 r
F P
0 g
s
.62589 .68029 m .63831 .7357 L .66712 .72721 L p .707 .577 .707 r
F P
0 g
s
.66712 .72721 m .6547 .67181 L .62589 .68029 L p .707 .577 .707 r
F P
0 g
s
.57682 .74814 m .5644 .69274 L .53774 .69548 L p .707 .577 .707 r
F P
0 g
s
.5644 .69274 m .57682 .74814 L .60719 .74291 L p .707 .577 .707 r
F P
0 g
s
.6547 .67181 m .66712 .72721 L .69081 .71828 L p .707 .577 .707 r
F P
0 g
s
.69081 .71828 m .67839 .66288 L .6547 .67181 L p .707 .577 .707 r
F P
0 g
s
.53774 .69548 m .55016 .75088 L .57682 .74814 L p .707 .577 .707 r
F P
0 g
s
.55016 .75088 m .53774 .69548 L .51741 .69546 L p .707 .577 .707 r
F P
0 g
s
.58662 .80139 m .57837 .76446 L .54799 .76967 L p .707 .577 .707 r
F P
0 g
s
.57837 .76446 m .58662 .80139 L .61774 .7942 L p .707 .577 .707 r
F P
0 g
s
.61774 .7942 m .60949 .75726 L .57837 .76446 L p .707 .577 .707 r
F P
0 g
s
.60949 .75726 m .61774 .7942 L .64655 .78573 L p .707 .577 .707 r
F P
0 g
s
.64655 .78573 m .6383 .74879 L .60949 .75726 L p .707 .577 .707 r
F P
0 g
s
.67839 .66288 m .69081 .71828 L .70705 .70978 L p .707 .577 .707 r
F P
0 g
s
.70705 .70978 m .69463 .65438 L .67839 .66288 L p .707 .577 .707 r
F P
0 g
s
.54799 .76967 m .55624 .80661 L .58662 .80139 L p .707 .577 .707 r
F P
0 g
s
.51741 .69546 m .52982 .75087 L .55016 .75088 L p .707 .577 .707 r
F P
0 g
s
.55624 .80661 m .54799 .76967 L .52132 .77239 L p .707 .577 .707 r
F P
0 g
s
.59991 .86109 m .60569 .84418 L .5761 .8326 L p .707 .577 .707 r
F P
0 g
s
.60569 .84418 m .59991 .86109 L .63032 .86904 L p .707 .577 .707 r
F P
0 g
s
.63032 .86904 m .6361 .85213 L .60569 .84418 L p .707 .577 .707 r
F P
0 g
s
.6383 .74879 m .64655 .78573 L .67024 .77681 L p .707 .577 .707 r
F P
0 g
s
.67024 .77681 m .66199 .73987 L .6383 .74879 L p .707 .577 .707 r
F P
0 g
s
.57031 .84951 m .5761 .8326 L .55022 .81853 L p .707 .577 .707 r
F P
0 g
s
.5761 .8326 m .57031 .84951 L .59991 .86109 L p .707 .577 .707 r
F P
0 g
s
.52132 .77239 m .52958 .80933 L .55624 .80661 L p .707 .577 .707 r
F P
0 g
s
.6361 .85213 m .63032 .86904 L .65857 .87259 L p .707 .577 .707 r
F P
0 g
s
.65857 .87259 m .66435 .85568 L .6361 .85213 L p .707 .577 .707 r
F P
0 g
s
.55022 .81853 m .54444 .83544 L .57031 .84951 L p .707 .577 .707 r
F P
0 g
s
.52982 .75087 m .51741 .69546 L .50539 .69269 L p .707 .577 .707 r
F P
0 g
s
.52958 .80933 m .52132 .77239 L .50098 .77235 L p .707 .577 .707 r
F P
0 g
s
.54444 .83544 m .55022 .81853 L .53059 .80335 L p .707 .577 .707 r
F P
0 g
s
.69463 .65438 m .70705 .70978 L .71426 .70255 L p .707 .577 .707 r
F P
0 g
s
.71426 .70255 m .70184 .64715 L .69463 .65438 L p .707 .577 .707 r
F P
0 g
s
.66435 .85568 m .65857 .87259 L .6819 .87139 L p .707 .577 .707 r
F P
0 g
s
.6819 .87139 m .68768 .85448 L .66435 .85568 L p .707 .577 .707 r
F P
0 g
s
.66199 .73987 m .67024 .77681 L .68649 .76831 L p .707 .577 .707 r
F P
0 g
s
.68649 .76831 m .67823 .73138 L .66199 .73987 L p .707 .577 .707 r
F P
0 g
s
.50539 .69269 m .5178 .74809 L .52982 .75087 L p .707 .577 .707 r
F P
0 g
s
.50098 .77235 m .50924 .80929 L .52958 .80933 L p .707 .577 .707 r
F P
0 g
s
.53059 .80335 m .5248 .82026 L .54444 .83544 L p .707 .577 .707 r
F P
0 g
s
.5248 .82026 m .53059 .80335 L .51912 .78853 L p .707 .577 .707 r
F P
0 g
s
.50924 .80929 m .50098 .77235 L .48896 .76956 L p .707 .577 .707 r
F P
0 g
s
.5178 .74809 m .50539 .69269 L .50286 .68742 L p .707 .577 .707 r
F P
0 g
s
.68768 .85448 m .6819 .87139 L .69802 .86556 L p .707 .577 .707 r
F P
0 g
s
.69802 .86556 m .7038 .84865 L .68768 .85448 L p .707 .577 .707 r
F P
0 g
s
.51912 .78853 m .51334 .80544 L .5248 .82026 L p .707 .577 .707 r
F P
0 g
s
.48896 .76956 m .49721 .8065 L .50924 .80929 L p .707 .577 .707 r
F P
0 g
s
.67823 .73138 m .68649 .76831 L .69369 .76108 L p .707 .577 .707 r
F P
0 g
s
.69369 .76108 m .68544 .72414 L .67823 .73138 L p .707 .577 .707 r
F P
0 g
s
.70184 .64715 m .71426 .70255 L .71173 .69729 L p .707 .577 .707 r
F P
0 g
s
.71173 .69729 m .69931 .64188 L .70184 .64715 L p .707 .577 .707 r
F P
0 g
s
.50286 .68742 m .51527 .74283 L .5178 .74809 L p .707 .577 .707 r
F P
0 g
s
.51334 .80544 m .51912 .78853 L .51695 .77554 L p .707 .577 .707 r
F P
0 g
s
.49721 .8065 m .48896 .76956 L .48643 .76429 L p .707 .577 .707 r
F P
0 g
s
.48643 .76429 m .49468 .80122 L .49721 .8065 L p .707 .577 .707 r
F P
0 g
s
.49468 .80122 m .48643 .76429 L .49364 .75705 L p .707 .577 .707 r
F P
0 g
s
.48638 .82191 m .49231 .3207 L .44831 .31749 L p .707 .577 .707 r
F P
0 g
s
.51695 .77554 m .51117 .79245 L .51334 .80544 L p .707 .577 .707 r
F P
0 g
s
.51527 .74283 m .50286 .68742 L .51007 .68019 L p .707 .577 .707 r
F P
0 g
s
.51007 .68019 m .52248 .73559 L .51527 .74283 L p .707 .577 .707 r
F P
0 g
s
.51117 .79245 m .51695 .77554 L .52429 .76565 L p .707 .577 .707 r
F P
0 g
s
.52429 .76565 m .5185 .78256 L .51117 .79245 L p .707 .577 .707 r
F P
0 g
s
.52248 .73559 m .51007 .68019 L .52631 .67169 L p .707 .577 .707 r
F P
0 g
s
.49364 .75705 m .50189 .79399 L .49468 .80122 L p .707 .577 .707 r
F P
0 g
s
.52631 .67169 m .53872 .72709 L .52248 .73559 L p .707 .577 .707 r
F P
0 g
s
.5185 .78256 m .52429 .76565 L .54041 .75981 L p .707 .577 .707 r
F P
0 g
s
.54041 .75981 m .53462 .77672 L .5185 .78256 L p .707 .577 .707 r
F P
0 g
s
.50189 .79399 m .49364 .75705 L .50988 .74855 L p .707 .577 .707 r
F P
0 g
s
.50988 .74855 m .51813 .78549 L .50189 .79399 L p .707 .577 .707 r
F P
0 g
s
.51813 .78549 m .50988 .74855 L .53357 .73964 L p .707 .577 .707 r
F P
0 g
s
.53462 .77672 m .54041 .75981 L .56373 .75861 L p .707 .577 .707 r
F P
0 g
s
.56373 .75861 m .55795 .77552 L .53462 .77672 L p .707 .577 .707 r
F P
0 g
s
.53357 .73964 m .54182 .77657 L .51813 .78549 L p .707 .577 .707 r
F P
0 g
s
.49231 .3207 m .48638 .82191 L .53132 .82129 L p .707 .577 .707 r
F P
0 g
s
.53872 .72709 m .52631 .67169 L .55 .66276 L p .707 .577 .707 r
F P
0 g
s
.53132 .82129 m .53725 .32007 L .49231 .3207 L p .707 .577 .707 r
F P
0 g
s
.55 .66276 m .56241 .71816 L .53872 .72709 L p .707 .577 .707 r
F P
0 g
s
.56241 .71816 m .55 .66276 L .57881 .65428 L p .707 .577 .707 r
F P
0 g
s
.57881 .65428 m .59122 .70968 L .56241 .71816 L p .707 .577 .707 r
F P
0 g
s
.55795 .77552 m .56373 .75861 L .59198 .76216 L p .707 .577 .707 r
F P
0 g
s
.59198 .76216 m .5862 .77907 L .55795 .77552 L p .707 .577 .707 r
F P
0 g
s
.54182 .77657 m .53357 .73964 L .56238 .73116 L p .707 .577 .707 r
F P
0 g
s
.56238 .73116 m .57063 .7681 L .54182 .77657 L p .707 .577 .707 r
F P
0 g
s
.57063 .7681 m .56238 .73116 L .5935 .72397 L p .707 .577 .707 r
F P
0 g
s
.53725 .32007 m .53132 .82129 L .5728 .81689 L p .707 .577 .707 r
F P
0 g
s
.5862 .77907 m .59198 .76216 L .6224 .77011 L p .707 .577 .707 r
F P
0 g
s
.5935 .72397 m .60175 .76091 L .57063 .7681 L p .707 .577 .707 r
F P
0 g
s
.5728 .81689 m .57873 .31568 L .53725 .32007 L p .707 .577 .707 r
F P
0 g
s
.7038 .84865 m .69802 .86556 L .70535 .85566 L p .707 .577 .707 r
F P
0 g
s
.70535 .85566 m .71113 .83875 L .7038 .84865 L p .707 .577 .707 r
F P
0 g
s
.44238 .8187 m .44831 .31749 L .40955 .31076 L p .707 .577 .707 r
F P
0 g
s
.44831 .31749 m .44238 .8187 L .48638 .82191 L p .707 .577 .707 r
F P
0 g
s
.68544 .72414 m .69369 .76108 L .69116 .7558 L p .707 .577 .707 r
F P
0 g
s
.69116 .7558 m .68291 .71887 L .68544 .72414 L p .707 .577 .707 r
F P
0 g
s
.69931 .64188 m .71173 .69729 L .69971 .69451 L p .707 .577 .707 r
F P
0 g
s
.69971 .69451 m .68729 .63911 L .69931 .64188 L p .707 .577 .707 r
F P
0 g
s
.59122 .70968 m .57881 .65428 L .60992 .64706 L p .707 .577 .707 r
F P
0 g
s
.60992 .64706 m .62234 .70247 L .59122 .70968 L p .707 .577 .707 r
F P
0 g
s
.62388 .71876 m .63213 .7557 L .60175 .76091 L p .707 .577 .707 r
F P
0 g
s
.60175 .76091 m .5935 .72397 L .62388 .71876 L p .707 .577 .707 r
F P
0 g
s
.6224 .77011 m .61661 .78702 L .5862 .77907 L p .707 .577 .707 r
F P
0 g
s
.57873 .31568 m .5728 .81689 L .60676 .80916 L p .707 .577 .707 r
F P
0 g
s
.60676 .80916 m .61269 .30795 L .57873 .31568 L p .707 .577 .707 r
F P
0 g
s
.26418 .70603 m .25177 .65063 L .2214 .65587 L p .707 .577 .707 r
F P
0 g
s
.25177 .65063 m .26418 .70603 L .2953 .69882 L p .707 .577 .707 r
F P
0 g
s
.2953 .69882 m .28289 .64342 L .25177 .65063 L p .707 .577 .707 r
F P
0 g
s
.28289 .64342 m .2953 .69882 L .32411 .69033 L p .707 .577 .707 r
F P
0 g
s
.32411 .69033 m .3117 .63493 L .28289 .64342 L p .707 .577 .707 r
F P
0 g
s
.40361 .81197 m .40955 .31076 L .37982 .30117 L p .707 .577 .707 r
F P
0 g
s
.40955 .31076 m .40361 .81197 L .44238 .8187 L p .707 .577 .707 r
F P
0 g
s
.71113 .83875 m .70535 .85566 L .70318 .84267 L p .707 .577 .707 r
F P
0 g
s
.70318 .84267 m .70896 .82576 L .71113 .83875 L p .707 .577 .707 r
F P
0 g
s
.23381 .71127 m .2214 .65587 L .19474 .65861 L p .707 .577 .707 r
F P
0 g
s
.2214 .65587 m .23381 .71127 L .26418 .70603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3117 .63493 m .32411 .69033 L .3478 .68141 L p .707 .577 .707 r
F P
0 g
s
.3478 .68141 m .33538 .626 L .3117 .63493 L p .707 .577 .707 r
F P
0 g
s
.68291 .71887 m .69116 .7558 L .67914 .75301 L p .707 .577 .707 r
F P
0 g
s
.67914 .75301 m .67089 .71607 L .68291 .71887 L p .707 .577 .707 r
F P
0 g
s
.68729 .63911 m .69971 .69451 L .67937 .69449 L p .707 .577 .707 r
F P
0 g
s
.67937 .69449 m .66696 .63909 L .68729 .63911 L p .707 .577 .707 r
F P
0 g
s
.19474 .65861 m .20715 .71401 L .23381 .71127 L p .707 .577 .707 r
F P
0 g
s
.6403 .64183 m .65271 .69723 L .62234 .70247 L p .707 .577 .707 r
F P
0 g
s
.62234 .70247 m .60992 .64706 L .6403 .64183 L p .707 .577 .707 r
F P
0 g
s
.63213 .7557 m .62388 .71876 L .65055 .71604 L p .707 .577 .707 r
F P
0 g
s
.65199 .78169 m .64621 .7986 L .61661 .78702 L p .707 .577 .707 r
F P
0 g
s
.61661 .78702 m .6224 .77011 L .65199 .78169 L p .707 .577 .707 r
F P
0 g
s
.61269 .30795 m .60676 .80916 L .62986 .79884 L p .707 .577 .707 r
F P
0 g
s
.62986 .79884 m .6358 .29763 L .61269 .30795 L p .707 .577 .707 r
F P
0 g
s
.20715 .71401 m .19474 .65861 L .1744 .65859 L p .707 .577 .707 r
F P
0 g
s
.24361 .76441 m .23536 .72747 L .20498 .73268 L p .707 .577 .707 r
F P
0 g
s
.23536 .72747 m .24361 .76441 L .27473 .75721 L p .707 .577 .707 r
F P
0 g
s
.27473 .75721 m .26648 .72028 L .23536 .72747 L p .707 .577 .707 r
F P
0 g
s
.26648 .72028 m .27473 .75721 L .30354 .74874 L p .707 .577 .707 r
F P
0 g
s
.30354 .74874 m .29529 .71181 L .26648 .72028 L p .707 .577 .707 r
F P
0 g
s
.33538 .626 m .3478 .68141 L .36404 .67291 L p .707 .577 .707 r
F P
0 g
s
.36404 .67291 m .35162 .61751 L .33538 .626 L p .707 .577 .707 r
F P
0 g
s
.35162 .61751 m .36404 .67291 L .36679 .67014 L p .707 .577 .707 r
F P
0 g
s
.36679 .67014 m .37125 .66567 L p .36586 .65245 L .707 .577 .707 r
F P
0 g
s
.36586 .65245 m .35162 .61751 L .36679 .67014 L .707 .577 .707 r
F
.36205 .28967 m .35796 .27736 L p .3572 .48808 L F P
0 g
s
.37125 .66567 m .35883 .61027 L .35162 .61751 L p .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .35883 .61027 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.36872 .66041 m .3622 .63133 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .3563 .60501 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .3622 .63133 L p .3567 .65763 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .36872 .66041 L .36019 .65844 L p .707 .577 .707 r
F P
0 g
s
.36019 .65844 m .3567 .65763 L p .3622 .63133 L .707 .577 .707 r
F P
0 g
s
.3567 .65763 m .34428 .60223 L .3563 .60501 L p .707 .577 .707 r
F P
0 g
s
.34428 .60223 m .3567 .65763 L .33636 .65761 L p .707 .577 .707 r
F P
0 g
s
.35641 .70954 m .35924 .52677 L .3572 .48808 L .707 .577 .707 r
F
.36595 .78966 m .36017 .80657 L .36012 .8065 L p F P
0 g
s
.36012 .8065 m .34871 .79176 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.35942 .79045 m .36595 .78966 L .36012 .8065 L .707 .577 .707 r
F
.35637 .72066 m .35721 .69877 L .35641 .70954 L F
.34871 .79176 m .35449 .77485 L .35899 .78066 L p F P
0 g
s
.35899 .78066 m .36595 .78966 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.34871 .79176 m .35899 .78066 L .35942 .79045 L .707 .577 .707 r
F
.35449 .77485 m .34871 .79176 L .34056 .78546 L p F P
0 g
s
.34056 .78546 m .32908 .77657 L p .34105 .77576 L .707 .577 .707 r
F P
0 g
s
.34105 .77576 m .35449 .77485 L .34056 .78546 L .707 .577 .707 r
F
.35637 .72066 m .35674 .61823 L .35479 .68453 L F
.32908 .77657 m .33486 .75966 L .35449 .77485 L p F P
0 g
s
.35637 .72066 m .35479 .68453 L .35203 .77858 L .707 .577 .707 r
F
.35721 .69877 m .35924 .52677 L p .35641 .70954 L F P
0 g
s
.35796 .27736 m .354 .61168 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.354 .61168 m .35203 .77858 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.35924 .52677 m .36205 .28967 L p .3572 .48808 L .707 .577 .707 r
F P
0 g
s
.35883 .61027 m .37125 .66567 L .36872 .66041 L p .707 .577 .707 r
F P
0 g
s
.37389 .80239 m .37982 .30117 L .36205 .28967 L p .707 .577 .707 r
F P
0 g
s
.36017 .80657 m .36595 .78966 L .36812 .80265 L p .707 .577 .707 r
F P
0 g
s
.36205 .28967 m .35612 .79088 L .37389 .80239 L p .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35551 .48431 L p .36796 .26547 L .707 .577 .707 r
F P
0 g
s
.35551 .48431 m .35796 .27736 L .36627 .26748 L p .707 .577 .707 r
F P
0 g
s
.36627 .26748 m .36796 .26547 L p .35551 .48431 L .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35612 .79088 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35612 .79088 m .35682 .73109 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35682 .73109 m .35721 .69877 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.37982 .30117 m .37389 .80239 L .40361 .81197 L p .707 .577 .707 r
F P
0 g
s
.70896 .82576 m .70318 .84267 L .69172 .82786 L p .707 .577 .707 r
F P
0 g
s
.69172 .82786 m .6975 .81095 L .70896 .82576 L p .707 .577 .707 r
F P
0 g
s
.20498 .73268 m .21323 .76962 L .24361 .76441 L p .707 .577 .707 r
F P
0 g
s
.1744 .65859 m .18681 .71399 L .20715 .71401 L p .707 .577 .707 r
F P
0 g
s
.21323 .76962 m .20498 .73268 L .17831 .7354 L p .707 .577 .707 r
F P
0 g
s
.2569 .82499 m .26268 .80808 L .23309 .7965 L p .707 .577 .707 r
F P
0 g
s
.26268 .80808 m .2569 .82499 L .28731 .83294 L p .707 .577 .707 r
F P
0 g
s
.28731 .83294 m .29309 .81603 L .26268 .80808 L p .707 .577 .707 r
F P
0 g
s
.29529 .71181 m .30354 .74874 L .32723 .73982 L p .707 .577 .707 r
F P
0 g
s
.32723 .73982 m .31898 .70289 L .29529 .71181 L p .707 .577 .707 r
F P
0 g
s
.66696 .63909 m .67937 .69449 L .65271 .69723 L p .707 .577 .707 r
F P
0 g
s
.65271 .69723 m .6403 .64183 L .66696 .63909 L p .707 .577 .707 r
F P
0 g
s
.22731 .81341 m .23309 .7965 L .20721 .78243 L p .707 .577 .707 r
F P
0 g
s
.23309 .7965 m .22731 .81341 L .2569 .82499 L p .707 .577 .707 r
F P
0 g
s
.17831 .7354 m .18657 .77234 L .21323 .76962 L p .707 .577 .707 r
F P
0 g
s
.29309 .81603 m .28731 .83294 L .31556 .83649 L p .707 .577 .707 r
F P
0 g
s
.31556 .83649 m .32134 .81958 L .29309 .81603 L p .707 .577 .707 r
F P
0 g
s
.67089 .71607 m .67914 .75301 L .6588 .75297 L p .707 .577 .707 r
F P
0 g
s
.6588 .75297 m .65055 .71604 L .67089 .71607 L p .707 .577 .707 r
F P
0 g
s
.20721 .78243 m .20143 .79934 L .22731 .81341 L p .707 .577 .707 r
F P
0 g
s
.18681 .71399 m .1744 .65859 L .16238 .65581 L p .707 .577 .707 r
F P
0 g
s
.18657 .77234 m .17831 .7354 L .15797 .73537 L p .707 .577 .707 r
F P
0 g
s
.20143 .79934 m .20721 .78243 L .18758 .76725 L p .707 .577 .707 r
F P
0 g
s
.65055 .71604 m .6588 .75297 L .63213 .7557 L p .707 .577 .707 r
F P
0 g
s
.6358 .29763 m .62986 .79884 L .63987 .78695 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .6458 .28574 L .6358 .29763 L p .707 .577 .707 r
F P
0 g
s
.32134 .81958 m .31556 .83649 L .33889 .83529 L p .707 .577 .707 r
F P
0 g
s
.33889 .83529 m .34467 .81838 L .32134 .81958 L p .707 .577 .707 r
F P
0 g
s
.31898 .70289 m .32723 .73982 L .34348 .73133 L p .707 .577 .707 r
F P
0 g
s
.34348 .73133 m .33522 .69439 L .31898 .70289 L p .707 .577 .707 r
F P
0 g
s
.6975 .81095 m .69172 .82786 L .67209 .81267 L p .707 .577 .707 r
F P
0 g
s
.67209 .81267 m .67787 .79576 L .6975 .81095 L p .707 .577 .707 r
F P
0 g
s
.16238 .65581 m .17479 .71121 L .18681 .71399 L p .707 .577 .707 r
F P
0 g
s
.15797 .73537 m .16623 .7723 L .18657 .77234 L p .707 .577 .707 r
F P
0 g
s
.18758 .76725 m .18179 .78415 L .20143 .79934 L p .707 .577 .707 r
F P
0 g
s
.18179 .78415 m .18758 .76725 L .17611 .75243 L p .707 .577 .707 r
F P
0 g
s
.16623 .7723 m .15797 .73537 L .14595 .73257 L p .707 .577 .707 r
F P
0 g
s
.17479 .71121 m .16238 .65581 L .15985 .65055 L p .707 .577 .707 r
F P
0 g
s
.67787 .79576 m .67209 .81267 L .64621 .7986 L p .707 .577 .707 r
F P
0 g
s
.64621 .7986 m .65199 .78169 L .67787 .79576 L p .707 .577 .707 r
F P
0 g
s
.34467 .81838 m .33889 .83529 L .35501 .82946 L p .707 .577 .707 r
F P
0 g
s
.35501 .82946 m .36079 .81255 L .34467 .81838 L p .707 .577 .707 r
F P
0 g
s
.17611 .75243 m .17033 .76934 L .18179 .78415 L p .707 .577 .707 r
F P
0 g
s
.14595 .73257 m .1542 .76951 L .16623 .7723 L p .707 .577 .707 r
F P
0 g
s
.33522 .69439 m .34348 .73133 L .35069 .72409 L p .707 .577 .707 r
F P
0 g
s
.35069 .72409 m .34243 .68715 L .33522 .69439 L p .707 .577 .707 r
F P
0 g
s
.15985 .65055 m .17226 .70595 L .17479 .71121 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .63578 .77465 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64244 .56957 m .63987 .78695 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .6458 .28574 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.63578 .77465 m .6374 .63778 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.6374 .63778 m .64171 .27343 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .63578 .77465 L .618 .76314 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .64644 .71725 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.62616 .67752 m .6324 .70543 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.6324 .70543 m .63442 .71446 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63819 .68031 L .63432 .67942 L p .707 .577 .707 r
F P
0 g
s
.63432 .67942 m .62616 .67752 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63432 .67942 L .63341 .69172 L .707 .577 .707 r
F
.6458 .28574 m .64244 .56957 L p .63904 .61559 L F P
0 g
s
.17033 .76934 m .17611 .75243 L .17394 .73944 L p .707 .577 .707 r
F P
0 g
s
.1542 .76951 m .14595 .73257 L .14342 .7273 L p .707 .577 .707 r
F P
0 g
s
.17394 .73944 m .16816 .75635 L .17033 .76934 L p .707 .577 .707 r
F P
0 g
s
.36079 .81255 m .35501 .82946 L .36234 .81956 L p .707 .577 .707 r
F P
0 g
s
.36234 .81956 m .36812 .80265 L .36079 .81255 L p .707 .577 .707 r
F P
0 g
s
.17226 .70595 m .15985 .65055 L .16706 .64331 L p .707 .577 .707 r
F P
0 g
s
.14342 .7273 m .15167 .76424 L .1542 .76951 L p .707 .577 .707 r
F P
0 g
s
.34243 .68715 m .35069 .72409 L .34815 .71882 L p .707 .577 .707 r
F P
0 g
s
.34815 .71882 m .3399 .68188 L .34243 .68715 L p .707 .577 .707 r
F P
0 g
s
.16706 .64331 m .17947 .69872 L .17226 .70595 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16816 .75635 m .17394 .73944 L .18128 .72955 L p .707 .577 .707 r
F P
0 g
s
.18128 .72955 m .1755 .74645 L .16816 .75635 L p .707 .577 .707 r
F P
0 g
s
.36812 .80265 m .36234 .81956 L .36017 .80657 L p .707 .577 .707 r
F P
0 g
s
.15167 .76424 m .14342 .7273 L .15063 .72006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17947 .69872 m .16706 .64331 L .1833 .63482 L p .707 .577 .707 r
F P
0 g
s
.618 .76314 m .62393 .26193 L .64171 .27343 L p .707 .577 .707 r
F P
0 g
s
.15063 .72006 m .15888 .757 L .15167 .76424 L p .707 .577 .707 r
F P
0 g
s
.3399 .68188 m .34815 .71882 L .33613 .71603 L p .707 .577 .707 r
F P
0 g
s
.33613 .71603 m .32788 .67909 L .3399 .68188 L p .707 .577 .707 r
F P
0 g
s
.33636 .65761 m .32395 .60221 L .34428 .60223 L p .707 .577 .707 r
F P
0 g
s
.1833 .63482 m .19571 .69022 L .17947 .69872 L p .707 .577 .707 r
F P
0 g
s
.36203 .76669 m .36796 .26547 L .39107 .25515 L p .707 .577 .707 r
F P
0 g
s
.36796 .26547 m .36203 .76669 L .35203 .77858 L p .707 .577 .707 r
F P
0 g
s
.1755 .74645 m .18128 .72955 L .1974 .72371 L p .707 .577 .707 r
F P
0 g
s
.1974 .72371 m .19161 .74062 L .1755 .74645 L p .707 .577 .707 r
F P
0 g
s
.19571 .69022 m .1833 .63482 L .20699 .62589 L p .707 .577 .707 r
F P
0 g
s
.15888 .757 m .15063 .72006 L .16687 .71157 L p .707 .577 .707 r
F P
0 g
s
.32395 .60221 m .33636 .65761 L .3097 .66036 L p .707 .577 .707 r
F P
0 g
s
.3097 .66036 m .29729 .60496 L .32395 .60221 L p .707 .577 .707 r
F P
0 g
s
.16687 .71157 m .17512 .74851 L .15888 .757 L p .707 .577 .707 r
F P
0 g
s
.32788 .67909 m .33613 .71603 L .31579 .71599 L p .707 .577 .707 r
F P
0 g
s
.31579 .71599 m .30754 .67905 L .32788 .67909 L p .707 .577 .707 r
F P
0 g
s
.20699 .62589 m .2194 .68129 L .19571 .69022 L p .707 .577 .707 r
F P
0 g
s
.62393 .26193 m .618 .76314 L .58828 .75356 L p .707 .577 .707 r
F P
0 g
s
.58828 .75356 m .59421 .25234 L .62393 .26193 L p .707 .577 .707 r
F P
0 g
s
.19161 .74062 m .1974 .72371 L .22072 .72251 L p .707 .577 .707 r
F P
0 g
s
.2194 .68129 m .20699 .62589 L .2358 .6174 L p .707 .577 .707 r
F P
0 g
s
.29729 .60496 m .3097 .66036 L .27933 .66559 L p .707 .577 .707 r
F P
0 g
s
.27933 .66559 m .26691 .61019 L .29729 .60496 L p .707 .577 .707 r
F P
0 g
s
.22072 .72251 m .21494 .73942 L .19161 .74062 L p .707 .577 .707 r
F P
0 g
s
.17512 .74851 m .16687 .71157 L .19056 .70265 L p .707 .577 .707 r
F P
0 g
s
.39107 .25515 m .38514 .75637 L .36203 .76669 L p .707 .577 .707 r
F P
0 g
s
.38514 .75637 m .39107 .25515 L .42502 .24742 L p .707 .577 .707 r
F P
0 g
s
.2358 .6174 m .24821 .6728 L .2194 .68129 L p .707 .577 .707 r
F P
0 g
s
.7444 .65087 m .73198 .59547 L .70161 .6007 L p .707 .577 .707 r
F P
0 g
s
.73198 .59547 m .7444 .65087 L .77551 .64366 L p .707 .577 .707 r
F P
0 g
s
.77551 .64366 m .7631 .58826 L .73198 .59547 L p .707 .577 .707 r
F P
0 g
s
.24821 .6728 m .2358 .6174 L .26691 .61019 L p .707 .577 .707 r
F P
0 g
s
.7631 .58826 m .77551 .64366 L .80432 .63517 L p .707 .577 .707 r
F P
0 g
s
.80432 .63517 m .79191 .57977 L .7631 .58826 L p .707 .577 .707 r
F P
0 g
s
.26691 .61019 m .27933 .66559 L .24821 .6728 L p .707 .577 .707 r
F P
0 g
s
.30754 .67905 m .31579 .71599 L .28912 .71871 L p .707 .577 .707 r
F P
0 g
s
.28912 .71871 m .28087 .68177 L .30754 .67905 L p .707 .577 .707 r
F P
0 g
s
.19056 .70265 m .19881 .73959 L .17512 .74851 L p .707 .577 .707 r
F P
0 g
s
.71402 .6561 m .70161 .6007 L .67495 .60344 L p .707 .577 .707 r
F P
0 g
s
.70161 .6007 m .71402 .6561 L .7444 .65087 L p .707 .577 .707 r
F P
0 g
s
.21494 .73942 m .22072 .72251 L .24897 .72606 L p .707 .577 .707 r
F P
0 g
s
.79191 .57977 m .80432 .63517 L .82801 .62624 L p .707 .577 .707 r
F P
0 g
s
.82801 .62624 m .8156 .57084 L .79191 .57977 L p .707 .577 .707 r
F P
0 g
s
.33486 .75966 m .32908 .77657 L .3032 .7625 L p .707 .577 .707 r
F P
0 g
s
.3032 .7625 m .30898 .74559 L .33486 .75966 L p .707 .577 .707 r
F P
0 g
s
.59421 .25234 m .58828 .75356 L .54952 .74683 L p .707 .577 .707 r
F P
0 g
s
.54952 .74683 m .55545 .24561 L .59421 .25234 L p .707 .577 .707 r
F P
0 g
s
.19881 .73959 m .19056 .70265 L .21937 .69418 L p .707 .577 .707 r
F P
0 g
s
.24897 .72606 m .24319 .74297 L .21494 .73942 L p .707 .577 .707 r
F P
0 g
s
.67495 .60344 m .68736 .65885 L .71402 .6561 L p .707 .577 .707 r
F P
0 g
s
.28087 .68177 m .28912 .71871 L .25874 .72392 L p .707 .577 .707 r
F P
0 g
s
.25874 .72392 m .25049 .68699 L .28087 .68177 L p .707 .577 .707 r
F P
0 g
s
.21937 .69418 m .22762 .73112 L .19881 .73959 L p .707 .577 .707 r
F P
0 g
s
.24319 .74297 m .24897 .72606 L .27939 .73401 L p .707 .577 .707 r
F P
0 g
s
.68736 .65885 m .67495 .60344 L .65461 .60343 L p .707 .577 .707 r
F P
0 g
s
.30898 .74559 m .3032 .7625 L .2736 .75092 L p .707 .577 .707 r
F P
0 g
s
.2736 .75092 m .27939 .73401 L .30898 .74559 L p .707 .577 .707 r
F P
0 g
s
.41909 .74863 m .42502 .24742 L .4665 .24303 L p .707 .577 .707 r
F P
0 g
s
.42502 .24742 m .42018 .65652 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.4665 .24303 m .46057 .74424 L .41909 .74863 L p .707 .577 .707 r
F P
0 g
s
.42009 .55138 m .4325 .60678 L .44088 .60431 L p .707 .577 .707 r
F P
0 g
s
.44088 .60431 m .46131 .5983 L p .44888 .58414 L .707 .577 .707 r
F P
0 g
s
.44888 .58414 m .42009 .55138 L .44088 .60431 L .707 .577 .707 r
F
.41909 .74863 m .38514 .75637 L p .38626 .7421 L F P
0 g
s
.42018 .65652 m .41909 .74863 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.72382 .70935 m .71557 .67242 L .68519 .67763 L p .707 .577 .707 r
F P
0 g
s
.71557 .67242 m .72382 .70935 L .75494 .70216 L p .707 .577 .707 r
F P
0 g
s
.75494 .70216 m .74669 .66522 L .71557 .67242 L p .707 .577 .707 r
F P
0 g
s
.22762 .73112 m .21937 .69418 L .25049 .68699 L p .707 .577 .707 r
F P
0 g
s
.74669 .66522 m .75494 .70216 L .78376 .69369 L p .707 .577 .707 r
F P
0 g
s
.78376 .69369 m .77551 .65675 L .74669 .66522 L p .707 .577 .707 r
F P
0 g
s
.25049 .68699 m .25874 .72392 L .22762 .73112 L p .707 .577 .707 r
F P
0 g
s
.27939 .73401 m .2736 .75092 L .24319 .74297 L p .707 .577 .707 r
F P
0 g
s
.8156 .57084 m .82801 .62624 L .84425 .61774 L p .707 .577 .707 r
F P
0 g
s
.84425 .61774 m .83184 .56234 L .8156 .57084 L p .707 .577 .707 r
F P
0 g
s
.68519 .67763 m .69344 .71457 L .72382 .70935 L p .707 .577 .707 r
F P
0 g
s
.65461 .60343 m .66703 .65883 L .68736 .65885 L p .707 .577 .707 r
F P
0 g
s
.69344 .71457 m .68519 .67763 L .65853 .68035 L p .707 .577 .707 r
F P
0 g
s
.73711 .76905 m .74289 .75214 L .7133 .74056 L p .707 .577 .707 r
F P
0 g
s
.74289 .75214 m .73711 .76905 L .76752 .77701 L p .707 .577 .707 r
F P
0 g
s
.76752 .77701 m .7733 .7601 L .74289 .75214 L p .707 .577 .707 r
F P
0 g
s
.55545 .24561 m .54952 .74683 L .50551 .74362 L p .707 .577 .707 r
F P
0 g
s
.50551 .74362 m .51145 .2424 L .55545 .24561 L p .707 .577 .707 r
F P
0 g
s
.77551 .65675 m .78376 .69369 L .80745 .68477 L p .707 .577 .707 r
F P
0 g
s
.80745 .68477 m .79919 .64783 L .77551 .65675 L p .707 .577 .707 r
F P
0 g
s
.70752 .75747 m .7133 .74056 L .68742 .72649 L p .707 .577 .707 r
F P
0 g
s
.7133 .74056 m .70752 .75747 L .73711 .76905 L p .707 .577 .707 r
F P
0 g
s
.65853 .68035 m .66678 .71729 L .69344 .71457 L p .707 .577 .707 r
F P
0 g
s
.46057 .74424 m .4665 .24303 L .51145 .2424 L p .707 .577 .707 r
F P
0 g
s
.7733 .7601 m .76752 .77701 L .79577 .78056 L p .707 .577 .707 r
F P
0 g
s
.79577 .78056 m .80156 .76365 L .7733 .7601 L p .707 .577 .707 r
F P
0 g
s
.51145 .2424 m .50551 .74362 L .46057 .74424 L p .707 .577 .707 r
F P
0 g
s
.68742 .72649 m .68164 .7434 L .70752 .75747 L p .707 .577 .707 r
F P
0 g
s
.66703 .65883 m .65461 .60343 L .64259 .60065 L p .707 .577 .707 r
F P
0 g
s
.66678 .71729 m .65853 .68035 L .63819 .68031 L p .707 .577 .707 r
F P
0 g
s
.68164 .7434 m .68742 .72649 L .66779 .71131 L p .707 .577 .707 r
F P
0 g
s
.83184 .56234 m .84425 .61774 L .85146 .61051 L p .707 .577 .707 r
F P
0 g
s
.85146 .61051 m .83905 .55511 L .83184 .56234 L p .707 .577 .707 r
F P
0 g
s
.80156 .76365 m .79577 .78056 L .8191 .77935 L p .707 .577 .707 r
F P
0 g
s
.8191 .77935 m .82488 .76245 L .80156 .76365 L p .707 .577 .707 r
F P
0 g
s
.79919 .64783 m .80745 .68477 L .82369 .67628 L p .707 .577 .707 r
F P
0 g
s
.82369 .67628 m .81544 .63934 L .79919 .64783 L p .707 .577 .707 r
F P
0 g
s
.64259 .60065 m .65501 .65605 L .66703 .65883 L p .707 .577 .707 r
F P
0 g
s
.63819 .68031 m .64644 .71725 L .66678 .71729 L p .707 .577 .707 r
F P
0 g
s
.66779 .71131 m .66201 .72822 L .68164 .7434 L p .707 .577 .707 r
F P
0 g
s
.66201 .72822 m .66779 .71131 L .65633 .6965 L p .707 .577 .707 r
F P
0 g
s
.65501 .65605 m .64259 .60065 L .64006 .59539 L p .707 .577 .707 r
F P
0 g
s
.82488 .76245 m .8191 .77935 L .83522 .77352 L p .707 .577 .707 r
F P
0 g
s
.83522 .77352 m .841 .75661 L .82488 .76245 L p .707 .577 .707 r
F P
0 g
s
.65633 .6965 m .65055 .71341 L .66201 .72822 L p .707 .577 .707 r
F P
0 g
s
.81544 .63934 m .82369 .67628 L .8309 .66904 L p .707 .577 .707 r
F P
0 g
s
.8309 .66904 m .82265 .6321 L .81544 .63934 L p .707 .577 .707 r
F P
0 g
s
.83905 .55511 m .85146 .61051 L .84893 .60525 L p .707 .577 .707 r
F P
0 g
s
.84893 .60525 m .83652 .54985 L .83905 .55511 L p .707 .577 .707 r
F P
0 g
s
.64006 .59539 m .65248 .65079 L .65501 .65605 L p .707 .577 .707 r
F P
0 g
s
.65055 .71341 m .65633 .6965 L .65416 .68351 L p .707 .577 .707 r
F P
0 g
s
.65416 .68351 m .64838 .70041 L .65055 .71341 L p .707 .577 .707 r
F P
0 g
s
.841 .75661 m .83522 .77352 L .84255 .76362 L p .707 .577 .707 r
F P
0 g
s
.84255 .76362 m .84834 .74671 L .841 .75661 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .62616 .67752 L .62363 .67225 L p .707 .577 .707 r
F P
0 g
s
.65248 .65079 m .64006 .59539 L .64727 .58815 L p .707 .577 .707 r
F P
0 g
s
.62363 .67225 m .63188 .70919 L .63442 .71446 L p .707 .577 .707 r
F P
0 g
s
.82265 .6321 m .8309 .66904 L .82837 .66377 L p .707 .577 .707 r
F P
0 g
s
.82837 .66377 m .82012 .62683 L .82265 .6321 L p .707 .577 .707 r
F P
0 g
s
.83652 .54985 m .84893 .60525 L .83691 .60247 L p .707 .577 .707 r
F P
0 g
s
.83691 .60247 m .8245 .54707 L .83652 .54985 L p .707 .577 .707 r
F P
0 g
s
.64727 .58815 m .65969 .64355 L .65248 .65079 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64838 .70041 m .65416 .68351 L .66149 .67361 L p .707 .577 .707 r
F P
0 g
s
.40139 .61399 m .38897 .55859 L .3586 .56383 L p .707 .577 .707 r
F P
0 g
s
.38897 .55859 m .40139 .61399 L .4325 .60678 L p .707 .577 .707 r
F P
0 g
s
.4325 .60678 m .42009 .55138 L .38897 .55859 L p .707 .577 .707 r
F P
0 g
s
.46131 .5983 m .4489 .54289 L .42009 .55138 L p .707 .577 .707 r
F P
0 g
s
.66149 .67361 m .65571 .69052 L .64838 .70041 L p .707 .577 .707 r
F P
0 g
s
.84834 .74671 m .84255 .76362 L .84038 .75063 L p .707 .577 .707 r
F P
0 g
s
.84038 .75063 m .84617 .73372 L .84834 .74671 L p .707 .577 .707 r
F P
0 g
s
.63188 .70919 m .62363 .67225 L .63084 .66501 L p .707 .577 .707 r
F P
0 g
s
.37101 .61923 m .3586 .56383 L .33194 .56657 L p .707 .577 .707 r
F P
0 g
s
.3586 .56383 m .37101 .61923 L .40139 .61399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65969 .64355 m .64727 .58815 L .66351 .57965 L p .707 .577 .707 r
F P
0 g
s
.4489 .54289 m .46131 .5983 L .485 .58937 L p .707 .577 .707 r
F P
0 g
s
.485 .58937 m .47259 .53396 L .4489 .54289 L p .707 .577 .707 r
F P
0 g
s
.63084 .66501 m .63909 .70195 L .63188 .70919 L p .707 .577 .707 r
F P
0 g
s
.82012 .62683 m .82837 .66377 L .81634 .66097 L p .707 .577 .707 r
F P
0 g
s
.81634 .66097 m .80809 .62404 L .82012 .62683 L p .707 .577 .707 r
F P
0 g
s
.8245 .54707 m .83691 .60247 L .81658 .60245 L p .707 .577 .707 r
F P
0 g
s
.81658 .60245 m .80416 .54705 L .8245 .54707 L p .707 .577 .707 r
F P
0 g
s
.33194 .56657 m .34435 .62197 L .37101 .61923 L p .707 .577 .707 r
F P
0 g
s
.66351 .57965 m .67593 .63506 L .65969 .64355 L p .707 .577 .707 r
F P
0 g
s
.34435 .62197 m .33194 .56657 L .3116 .56655 L p .707 .577 .707 r
F P
0 g
s
.65571 .69052 m .66149 .67361 L .67761 .66777 L p .707 .577 .707 r
F P
0 g
s
.38081 .67237 m .37256 .63543 L .34218 .64064 L p .707 .577 .707 r
F P
0 g
s
.37256 .63543 m .38081 .67237 L .41193 .66518 L p .707 .577 .707 r
F P
0 g
s
.41193 .66518 m .40368 .62824 L .37256 .63543 L p .707 .577 .707 r
F P
0 g
s
.40368 .62824 m .41193 .66518 L .44075 .6567 L p .707 .577 .707 r
F P
0 g
s
.44075 .6567 m .4325 .61977 L .40368 .62824 L p .707 .577 .707 r
F P
0 g
s
.47259 .53396 m .485 .58937 L .50124 .58087 L p .707 .577 .707 r
F P
0 g
s
.50124 .58087 m .48883 .52547 L .47259 .53396 L p .707 .577 .707 r
F P
0 g
s
.67761 .66777 m .67183 .68468 L .65571 .69052 L p .707 .577 .707 r
F P
0 g
s
.84617 .73372 m .84038 .75063 L .82892 .73582 L p .707 .577 .707 r
F P
0 g
s
.82892 .73582 m .8347 .71891 L .84617 .73372 L p .707 .577 .707 r
F P
0 g
s
.34218 .64064 m .35043 .67758 L .38081 .67237 L p .707 .577 .707 r
F P
0 g
s
.67593 .63506 m .66351 .57965 L .6872 .57072 L p .707 .577 .707 r
F P
0 g
s
.3116 .56655 m .32402 .62195 L .34435 .62197 L p .707 .577 .707 r
F P
0 g
s
.35043 .67758 m .34218 .64064 L .31552 .64337 L p .707 .577 .707 r
F P
0 g
s
.63909 .70195 m .63084 .66501 L .64708 .65652 L p .707 .577 .707 r
F P
0 g
s
.3941 .73295 m .39988 .71604 L .37029 .70446 L p .707 .577 .707 r
F P
0 g
s
.39988 .71604 m .3941 .73295 L .42451 .7409 L p .707 .577 .707 r
F P
0 g
s
.42451 .7409 m .43029 .724 L .39988 .71604 L p .707 .577 .707 r
F P
0 g
s
.4325 .61977 m .44075 .6567 L .46444 .64779 L p .707 .577 .707 r
F P
0 g
s
.46444 .64779 m .45618 .61085 L .4325 .61977 L p .707 .577 .707 r
F P
0 g
s
.80416 .54705 m .81658 .60245 L .78992 .60519 L p .707 .577 .707 r
F P
0 g
s
.78992 .60519 m .7775 .54979 L .80416 .54705 L p .707 .577 .707 r
F P
0 g
s
.36451 .72137 m .37029 .70446 L .34441 .69039 L p .707 .577 .707 r
F P
0 g
s
.37029 .70446 m .36451 .72137 L .3941 .73295 L p .707 .577 .707 r
F P
0 g
s
.31552 .64337 m .32377 .6803 L .35043 .67758 L p .707 .577 .707 r
F P
0 g
s
.64708 .65652 m .65534 .69345 L .63909 .70195 L p .707 .577 .707 r
F P
0 g
s
.43029 .724 m .42451 .7409 L .45276 .74445 L p .707 .577 .707 r
F P
0 g
s
.45276 .74445 m .45855 .72754 L .43029 .724 L p .707 .577 .707 r
F P
0 g
s
.80809 .62404 m .81634 .66097 L .796 .66094 L p .707 .577 .707 r
F P
0 g
s
.796 .66094 m .78775 .624 L .80809 .62404 L p .707 .577 .707 r
F P
0 g
s
.6872 .57072 m .69961 .62613 L .67593 .63506 L p .707 .577 .707 r
F P
0 g
s
.34441 .69039 m .33863 .7073 L .36451 .72137 L p .707 .577 .707 r
F P
0 g
s
.32402 .62195 m .3116 .56655 L .29958 .56377 L p .707 .577 .707 r
F P
0 g
s
.32377 .6803 m .31552 .64337 L .29518 .64333 L p .707 .577 .707 r
F P
0 g
s
.67183 .68468 m .67761 .66777 L .70094 .66657 L p .707 .577 .707 r
F P
0 g
s
.33863 .7073 m .34441 .69039 L .32478 .67521 L p .707 .577 .707 r
F P
0 g
s
.69961 .62613 m .6872 .57072 L .71601 .56224 L p .707 .577 .707 r
F P
0 g
s
.48883 .52547 m .50124 .58087 L .50845 .57363 L p .707 .577 .707 r
F P
0 g
s
.50845 .57363 m .49604 .51823 L .48883 .52547 L p .707 .577 .707 r
F P
0 g
s
.7775 .54979 m .78992 .60519 L .75954 .61043 L p .707 .577 .707 r
F P
0 g
s
.75954 .61043 m .74713 .55503 L .7775 .54979 L p .707 .577 .707 r
F P
0 g
s
.45855 .72754 m .45276 .74445 L .47609 .74325 L p .707 .577 .707 r
F P
0 g
s
.47609 .74325 m .48187 .72634 L .45855 .72754 L p .707 .577 .707 r
F P
0 g
s
.45618 .61085 m .46444 .64779 L .48068 .63929 L p .707 .577 .707 r
F P
0 g
s
.48068 .63929 m .47243 .60235 L .45618 .61085 L p .707 .577 .707 r
F P
0 g
s
.8347 .71891 m .82892 .73582 L .80929 .72063 L p .707 .577 .707 r
F P
0 g
s
.80929 .72063 m .81507 .70373 L .8347 .71891 L p .707 .577 .707 r
F P
0 g
s
.29958 .56377 m .312 .61917 L .32402 .62195 L p .707 .577 .707 r
F P
0 g
s
.29518 .64333 m .30343 .68027 L .32377 .6803 L p .707 .577 .707 r
F P
0 g
s
.70094 .66657 m .69516 .68348 L .67183 .68468 L p .707 .577 .707 r
F P
0 g
s
.32478 .67521 m .319 .69212 L .33863 .7073 L p .707 .577 .707 r
F P
0 g
s
.65534 .69345 m .64708 .65652 L .67077 .6476 L p .707 .577 .707 r
F P
0 g
s
.71601 .56224 m .72843 .61764 L .69961 .62613 L p .707 .577 .707 r
F P
0 g
s
.72843 .61764 m .71601 .56224 L .74713 .55503 L p .707 .577 .707 r
F P
0 g
s
.74713 .55503 m .75954 .61043 L .72843 .61764 L p .707 .577 .707 r
F P
0 g
s
.78775 .624 m .796 .66094 L .76934 .66366 L p .707 .577 .707 r
F P
0 g
s
.76934 .66366 m .76109 .62672 L .78775 .624 L p .707 .577 .707 r
F P
0 g
s
.67077 .6476 m .67902 .68453 L .65534 .69345 L p .707 .577 .707 r
F P
0 g
s
.319 .69212 m .32478 .67521 L .31332 .66039 L p .707 .577 .707 r
F P
0 g
s
.69516 .68348 m .70094 .66657 L .72919 .67012 L p .707 .577 .707 r
F P
0 g
s
.30343 .68027 m .29518 .64333 L .28315 .64054 L p .707 .577 .707 r
F P
0 g
s
.312 .61917 m .29958 .56377 L .29705 .55851 L p .707 .577 .707 r
F P
0 g
s
.81507 .70373 m .80929 .72063 L .78341 .70656 L p .707 .577 .707 r
F P
0 g
s
.78341 .70656 m .78919 .68965 L .81507 .70373 L p .707 .577 .707 r
F P
0 g
s
.48187 .72634 m .47609 .74325 L .49221 .73742 L p .707 .577 .707 r
F P
0 g
s
.49221 .73742 m .49799 .72051 L .48187 .72634 L p .707 .577 .707 r
F P
0 g
s
.31332 .66039 m .30754 .6773 L .319 .69212 L p .707 .577 .707 r
F P
0 g
s
.72919 .67012 m .72341 .68703 L .69516 .68348 L p .707 .577 .707 r
F P
0 g
s
.67902 .68453 m .67077 .6476 L .69959 .63913 L p .707 .577 .707 r
F P
0 g
s
.28315 .64054 m .29141 .67747 L .30343 .68027 L p .707 .577 .707 r
F P
0 g
s
.47243 .60235 m .48068 .63929 L .48789 .63205 L p .707 .577 .707 r
F P
0 g
s
.48789 .63205 m .47964 .59512 L .47243 .60235 L p .707 .577 .707 r
F P
0 g
s
.76109 .62672 m .76934 .66366 L .73896 .66887 L p .707 .577 .707 r
F P
0 g
s
.73896 .66887 m .73071 .63193 L .76109 .62672 L p .707 .577 .707 r
F P
0 g
s
.49604 .51823 m .50845 .57363 L .50592 .56837 L p .707 .577 .707 r
F P
0 g
s
.50592 .56837 m .49351 .51297 L .49604 .51823 L p .707 .577 .707 r
F P
0 g
s
.29705 .55851 m .30947 .61391 L .312 .61917 L p .707 .577 .707 r
F P
0 g
s
.69959 .63913 m .70784 .67606 L .67902 .68453 L p .707 .577 .707 r
F P
0 g
s
.72341 .68703 m .72919 .67012 L .7596 .67808 L p .707 .577 .707 r
F P
0 g
s
.78919 .68965 m .78341 .70656 L .75382 .69498 L p .707 .577 .707 r
F P
0 g
s
.75382 .69498 m .7596 .67808 L .78919 .68965 L p .707 .577 .707 r
F P
0 g
s
.70784 .67606 m .69959 .63913 L .73071 .63193 L p .707 .577 .707 r
F P
0 g
s
.73071 .63193 m .73896 .66887 L .70784 .67606 L p .707 .577 .707 r
F P
0 g
s
.7596 .67808 m .75382 .69498 L .72341 .68703 L p .707 .577 .707 r
F P
0 g
s
.30754 .6773 m .31332 .66039 L .31115 .6474 L p .707 .577 .707 r
F P
0 g
s
.29141 .67747 m .28315 .64054 L .28062 .63526 L p .707 .577 .707 r
F P
0 g
s
.31115 .6474 m .30537 .66431 L .30754 .6773 L p .707 .577 .707 r
F P
0 g
s
.49799 .72051 m .49221 .73742 L .49954 .72752 L p .707 .577 .707 r
F P
0 g
s
.49954 .72752 m .50533 .71061 L .49799 .72051 L p .707 .577 .707 r
F P
0 g
s
.30947 .61391 m .29705 .55851 L .30426 .55128 L p .707 .577 .707 r
F P
0 g
s
.28062 .63526 m .28887 .6722 L .29141 .67747 L p .707 .577 .707 r
F P
0 g
s
.47964 .59512 m .48789 .63205 L .48536 .62678 L p .707 .577 .707 r
F P
0 g
s
.48536 .62678 m .4771 .58984 L .47964 .59512 L p .707 .577 .707 r
F P
0 g
s
.49351 .51297 m .50592 .56837 L .4939 .56559 L p .707 .577 .707 r
F P
0 g
s
.4939 .56559 m .48149 .51019 L .49351 .51297 L p .707 .577 .707 r
F P
0 g
s
.30426 .55128 m .31668 .60668 L .30947 .61391 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30537 .66431 m .31115 .6474 L .31848 .63751 L p .707 .577 .707 r
F P
0 g
s
.31848 .63751 m .3127 .65442 L .30537 .66431 L p .707 .577 .707 r
F P
0 g
s
.50533 .71061 m .49954 .72752 L .49737 .71453 L p .707 .577 .707 r
F P
0 g
s
.49737 .71453 m .50316 .69762 L .50533 .71061 L p .707 .577 .707 r
F P
0 g
s
.28887 .6722 m .28062 .63526 L .28783 .62803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31668 .60668 m .30426 .55128 L .3205 .54278 L p .707 .577 .707 r
F P
0 g
s
.28783 .62803 m .29608 .66496 L .28887 .6722 L p .707 .577 .707 r
F P
0 g
s
.4771 .58984 m .48536 .62678 L .47333 .62399 L p .707 .577 .707 r
F P
0 g
s
.47333 .62399 m .46508 .58705 L .4771 .58984 L p .707 .577 .707 r
F P
0 g
s
.48149 .51019 m .4939 .56559 L .47357 .56558 L p .707 .577 .707 r
F P
0 g
s
.47357 .56558 m .46115 .51017 L .48149 .51019 L p .707 .577 .707 r
F P
0 g
s
.3205 .54278 m .33292 .59818 L .31668 .60668 L p .707 .577 .707 r
F P
0 g
s
.3127 .65442 m .31848 .63751 L .3346 .63167 L p .707 .577 .707 r
F P
0 g
s
.3346 .63167 m .32882 .64858 L .3127 .65442 L p .707 .577 .707 r
F P
0 g
s
.50316 .69762 m .49737 .71453 L .48591 .69972 L p .707 .577 .707 r
F P
0 g
s
.48591 .69972 m .49169 .68281 L .50316 .69762 L p .707 .577 .707 r
F P
0 g
s
.33292 .59818 m .3205 .54278 L .34419 .53385 L p .707 .577 .707 r
F P
0 g
s
.29608 .66496 m .28783 .62803 L .30407 .61953 L p .707 .577 .707 r
F P
0 g
s
.46115 .51017 m .47357 .56558 L .44691 .56832 L p .707 .577 .707 r
F P
0 g
s
.44691 .56832 m .43449 .51292 L .46115 .51017 L p .707 .577 .707 r
F P
0 g
s
.30407 .61953 m .31233 .65647 L .29608 .66496 L p .707 .577 .707 r
F P
0 g
s
.46508 .58705 m .47333 .62399 L .45299 .62395 L p .707 .577 .707 r
F P
0 g
s
.45299 .62395 m .44474 .58701 L .46508 .58705 L p .707 .577 .707 r
F P
0 g
s
.34419 .53385 m .3566 .58925 L .33292 .59818 L p .707 .577 .707 r
F P
0 g
s
.32882 .64858 m .3346 .63167 L .35793 .63047 L p .707 .577 .707 r
F P
0 g
s
.3566 .58925 m .34419 .53385 L .373 .52536 L p .707 .577 .707 r
F P
0 g
s
.43449 .51292 m .44691 .56832 L .41653 .57355 L p .707 .577 .707 r
F P
0 g
s
.41653 .57355 m .40412 .51815 L .43449 .51292 L p .707 .577 .707 r
F P
0 g
s
.49169 .68281 m .48591 .69972 L .46628 .68453 L p .707 .577 .707 r
F P
0 g
s
.46628 .68453 m .47206 .66762 L .49169 .68281 L p .707 .577 .707 r
F P
0 g
s
.35793 .63047 m .35214 .64738 L .32882 .64858 L p .707 .577 .707 r
F P
0 g
s
.31233 .65647 m .30407 .61953 L .32776 .61061 L p .707 .577 .707 r
F P
0 g
s
.373 .52536 m .38542 .58076 L .3566 .58925 L p .707 .577 .707 r
F P
0 g
s
.38542 .58076 m .373 .52536 L .40412 .51815 L p .707 .577 .707 r
F P
0 g
s
.40412 .51815 m .41653 .57355 L .38542 .58076 L p .707 .577 .707 r
F P
0 g
s
.44474 .58701 m .45299 .62395 L .42633 .62667 L p .707 .577 .707 r
F P
0 g
s
.42633 .62667 m .41808 .58973 L .44474 .58701 L p .707 .577 .707 r
F P
0 g
s
.32776 .61061 m .33601 .64755 L .31233 .65647 L p .707 .577 .707 r
F P
0 g
s
.35214 .64738 m .35793 .63047 L .38618 .63402 L p .707 .577 .707 r
F P
0 g
s
.47206 .66762 m .46628 .68453 L .4404 .67046 L p .707 .577 .707 r
F P
0 g
s
.4404 .67046 m .44618 .65355 L .47206 .66762 L p .707 .577 .707 r
F P
0 g
s
.33601 .64755 m .32776 .61061 L .35658 .60214 L p .707 .577 .707 r
F P
0 g
s
.38618 .63402 m .3804 .65093 L .35214 .64738 L p .707 .577 .707 r
F P
0 g
s
.41808 .58973 m .42633 .62667 L .39595 .63188 L p .707 .577 .707 r
F P
0 g
s
.39595 .63188 m .3877 .59495 L .41808 .58973 L p .707 .577 .707 r
F P
0 g
s
.35658 .60214 m .36483 .63908 L .33601 .64755 L p .707 .577 .707 r
F P
0 g
s
.3804 .65093 m .38618 .63402 L .41659 .64197 L p .707 .577 .707 r
F P
0 g
s
.44618 .65355 m .4404 .67046 L .41081 .65888 L p .707 .577 .707 r
F P
0 g
s
.41081 .65888 m .41659 .64197 L .44618 .65355 L p .707 .577 .707 r
F P
0 g
s
.36483 .63908 m .35658 .60214 L .3877 .59495 L p .707 .577 .707 r
F P
0 g
s
.3877 .59495 m .39595 .63188 L .36483 .63908 L p .707 .577 .707 r
F P
0 g
s
.41659 .64197 m .41081 .65888 L .3804 .65093 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001XOol00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`<000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH0000C0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`800003FUH005YF00EJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo0P0000=JEP00FUH015YF100000=JEP00FUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00000010001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00HGoo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001OOol30009FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005eoo`80009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
FWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00:Woo2`00<Goo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol80003
FUH00`00FUIJEP03FUH01000FUH00000;goo001EOol20005FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000KOol70003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`03001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Moo`@0
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH^Ool005Aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000COol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/00003FUH0000000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80015oo`800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF1000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Woo0`000eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P002goo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo001EOol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000]Ool005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUIJEP0015YF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01UYF00<005YF00002P000eYF00@005YF000000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF008002aoo`00EWoo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEP00001JEP020005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;7oo001FOol01000FUIJEP0015YF00@005YFFUIJEP8000=JEP03001JEUYF00IJEPD0
0003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000[
Ool005Ioo`04001JEUYF0004FUH01000FUH000001EYF00<005YFFUH00UYF1@001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo
00@005YFFUH000AJEP<000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00:goo001FOol01P00FUIJEUYF001J
EP80009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPX0009JEP03001oogoo02Uoo`00D7oo1`000eYF0P0015YF100000=JEP00FUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
0UYF1@00:Woo001:Ool60004FUH01000FUIJEUYF0P0000=JEP0000000`001EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1P001eYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUH002Yoo`00AWoo100000=JEP00FUH025YF00D005YF000005YF00800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002]oo`00@Goo1@001EYF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP@000QJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00?Goo10000UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001J
EUYF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0
000^Ool003Yoo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH;00000eYF00000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUH0000:0004FUH3000_Ool0
03Qoo`<000UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03
001JEUYF00=JEP@000UJEP03001JEP0000L000=JEP03001JEUYF00=JEP03001JEP0000@0035oo`00
=Woo0P000UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEP00008000AJEP04001JEUYFFUH70004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00<goo000cOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0:0007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000017oo001JEP001EYF0P001eYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH003=oo`00<Goo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF10000eYF00<005YFFUH010001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00
FUH000=JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YF
FUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP<000AJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol002ioo`8000EJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
1EYF00<005YF00000`001eYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YF
FUH20003FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00<Woo000^Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30006FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20003FUH00`00FUH000030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`00
15YF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF1P0035YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF100000=JEP00FUH01eYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<Goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0004
FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH300000eYF001JEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH01000FUH000001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
25YF00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2`0000=JEP00Ool0<7oo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002FUH30002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH40004
FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP02FUH3000aOol002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH50002FUH300000eYF001JEP020006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH500001UYF00000000FUH000MJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000<7oo000^Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YF001J
EP800005FUH005YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH2
0008FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00<7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1EYF1@0025YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00
FUIJEP04FUH20005FUH01000FUIJEP001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0
0000008000QJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00;Woo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00IJEP80009JEP8000AJEP04001JEUYFFUH8
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF10000UYF00<005YFFUH015YF100015YF00<005YFFUH01EYF00@005YFFUIJ
EP80039oo`00;goo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJEP03001JEUYF009JEP/0009J
EP03001JEP0000<00006FUH00000001JEP001UYF00<005YF00000P001EYF00<005YFFUH025YF0`00
1EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01UYF00@005YF
0000009JEP03001JEUYF00EJEP04001JEP00000dOol002moo`04001JEUYF0004FUH01000FUIJEUYF
0P000eYF00<005YFFUH01UYF1@0000=JEP00FUH01UYF0P000UYF00<005YFFUH010000Woo00<005YF
00001UYF1P0015YF00<005YFFUH025YF00<005YF00001UYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEP00001JEP0015YF00<005YFFUH015YF2@0015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP<003Ioo`00;goo00@005YFFUH000AJEP04001JEP000005FUH00`00
FUIJEP02FUH50006FUH00`00FUIJEP04FUH01000FUH000001EYF0P000Woo00<005YF00001UYF1P00
15YF00<005YFFUH025YF00<005YFFUH00P0015YF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH7
0006FUH00`00FUIJEP04FUH20003FUH2000iOol002moo`04001JEUYF0004FUH30006FUH50002FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH01P00Oomoo`00FUH000IJEPH000AJEP03
001JEUYF00QJEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000005FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH01UYF0`00>goo000_Ool01P00FUIJEUYF001JEP80009JEP04001JEUYF
FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF100000=JEP00FUH01EYF
00<005YF00000P001EYF00<005YFFUH025YF00<005YFFUH00eYF0`000eYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH40007FUH01000FUH00000>Woo000`Ool3FUH20004FUH400000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH00`001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000005FUH01000FUIJEUYF0P00>7oo000`Ool015YF000005YF
1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=J
EP00FUH015YF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH00000FUH20007
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500001Woo00000000FUH000IJEP8003Ioo`00<7oo0P00
00EJEP00001JEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<000MJEP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF
00000007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`0cOol0031oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8000QJEP03001JEP00008000UJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000eYF0P001UYF00<005YF
FUH01EYF10003goo0P001UYF0`00<goo000^Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH00UYF
0`001eYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00@001Eoo`80
00=JEP05001JEUYFFUH0000bOol002aoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH;000015YF000000000eYF00<005YFFUH01EYF10000eYF
00<005YFFUH025YF00<005YFFUH025YF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1P000eYF2`002Goo0`003goo0P0000=JEP00FUH00eYF0P00<7oo000ZOol20003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP02
FUH80009FUH00`00FUIJEP04000:FUH00`00FUIJEP07FUH4000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUH00002FUH00`00FUIJEP05000;Ool5000@Ool20006
FUH00`00Oomoo`0]Ool002Uoo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030008FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP05FUH2000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF0P0000=JEP00FUH00eYF0P003Goo1@004Woo00<005YFFUH00eYF0P00
;Woo000XOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02P001eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0009JEP<000AJEP03001JEUYF00MJEP04
001JEUYFFUH<0002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUH000001UYF00<007ooOol02Woo1@004goo00L005YFFUIJEP00FUH0000^
Ool002Qoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04
0007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00Oomoo`00FUH000EJEP<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH01000FUIJEP001UYF0`002goo0`005Goo
00@005YFFUH0009JEP03001oogoo02]oo`00:Goo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000=oo`03
001JEP0000IJEP03001JEP00008000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP05
001JEUYFFUH00004FUH01000FUIJEUYF0P008Woo0P0015YF00<007ooOol0:Woo000YOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUH000030007FUH00`00FUIJEP07FUH30003FUH00`00FUIJEP05
FUH30004Ool00`00FUH00006FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP80025oo`03001JEUYF009JEP03
001oogoo02Yoo`00:Goo00@005YFFUH000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP05FUH20006Ool00`00FUH00006FUH00`00FUIJEP06FUH60004FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF0P0087oo00<005YFFUH00P00;7oo000Y
Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH00eYF1P001eYF00<005YFFUH00eYF
0`0000=JEP0000000P0027oo00<005YF000045YF00<005YFFUH00UYF6P001UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF00<005YF00000P00
7Goo00H005YFFUH005YF000[Ool002Yoo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00@0009JEP03001JEUYF00IJEP8000aoo`03001JEP0000mJEPP000aJEP03001JEUYF00UJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP04001JEP000006FUH0
0`00FUIJEP02FUH3000KOol20002FUH00`00Oomoo`0YOol002Yoo`03001JEP0000=JEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40008FUH3000:Ool00`00FUH0000<FUH30007FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH3000IOol01000
FUIJEP00:goo000ZOol00`00FUIJEP0400000eYF00000007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH40004FUH01000FUIJEUYF0P0027oo00<005YF000025YF10002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF4@0000Eoo`00001JEP00
00UJEP04001JEP00000GOol00`00FUH0000/Ool002Yoo`03001JEUYF00<00003FUH005YF008000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@0009oo`<00003FUH005YF00AJEP8000Ioo`03001JEP00
00EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP8000AJEP03001JEUYF009JEP<000IJEP03001JEUYF009JEP04001JEP000002Ool3
0007FUH00`00FUIJEP02FUH3000COol200000eYF001oo`0[Ool002]oo`03FUH005YF00800005FUH0
05YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20007FUH20004Ool00`00FUH00003
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300000eYF001JEP03FUH30006FUH00`00FUIJEP02FUH01000FUIJEP001Goo0P001EYF
00<005YFFUH01EYF1@0027oo1P0000=JEP000000;Goo000[Ool01P00FUIJEP00FUH000=JEP03001J
EUYF00EJEP03001JEUYF009JEPL000moo`8000EJEP03001JEP0000=oo`04001JEP00FUH30007FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
1000FUH0000015YF0`001UYF00<005YFFUH00eYF0P0027oo0`0000=JEP00FUH025YF00@005YFFUIJ
EPP000=JEP04001JEUYFFUH2000]Ool002]oo`80009JEP8000AJEP04001JEUYFFUH8000HOol20003
FUH00`00FUIJEP0200000goo001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`00
1eYF00@005YFFUIJEP8000aoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002eoo`D0009JEP03001JEP00008000moo`<0011oo`<000EJEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEPD000MJEP04001JEP00000BOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool0035oo`04001JEUYF0002FUH2000>Ool5000AOol00`00FUIJEP04FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40006FUH3000HOol60004FUH00`00FUIJEP03FUH0
1000FUH00000<Goo000bOol20005FUH00`00Oomoo`0;Ool5000BOol00`00FUIJEP03FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH50003FUH2000QOol<000cOol003=oo`03001JEUYF00AJEP03
001oogoo00Yoo`D001=oo`03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP00009JEP<0069oo`00=7oo00<005YFFUH00eYF0`002goo0`005Goo00H005YFFUH005YF0004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH3001QOol003Eoo`03001JEUYF009J
EP03001JEUYF0080029oo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=J
EP04001JEUYFFUH2001OOol003Ioo`800003FUH005YF00AJEP80029oo`04001JEUYF0003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH2001MOol003Qoo`8000MJEP<0021o
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001oogoo
05Yoo`00>Goo00<005YFFUH01UYF00@005YF000001ioo`03001JEUYF00@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000QJEP<005Yoo`00>Woo0P001EYF00<005YFFUH00UYF0`0077oo0P0000=JEP00Ool0
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP8000Ioo`8000IJEP04001JEUYF001IOol003aoo`8000=JEP03001JEUYF
00EJEP<001Yoo`03001JEP0000=oo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000:Ool20003FUH00`00FUIJEP02FUH2
001GOol003ioo`<000UJEP03001JEP00008001Moo`03001JEP0000Moo`D000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000ioo`800003FUH005YF00EJEP03
001oogoo05Aoo`00@7oo0P0025YF00<005YFFUH00UYF0`004Woo10003Goo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02@0047oo0P001UYF0P00EGoo0012Ool3
0004FUH00`00FUIJEP06FUH50008Ool5000015YF001JEP004goo2@001UYF00<005YFFUH02UYF00<0
05YFFUH00eYF200017oo1@004Woo00<005YFFUH00UYF00<005YF0000EGoo0015Ool300000eYF001J
EP07FUH00`00FUIJEP02FUH80002FUH01`00FUIJEUYF001JEP0001aooa/000Yoo`D001=oo`80009J
EP04001JEUYF001DOol004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0
02moo`03001JEUYF009JEP04001JEUYFFUH20009Ool3000FOol20004FUH00`00Oomoo`1AOol004]o
o`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol20002FUH00`00FUIJ
EP03FUH2000QOol00`00FUIJEP02FUH00`00Oomoo`1AOol004moo`H000AJEP03001JEUYF00AJEP04
001JEP00000eOol20008FUH2000POol00`00FUIJEP02001COol005Eoo`d003Qoo`03001JEUYF00IJ
EP04001JEP00000NOol01P00FUIJEP00FUH0059oo`00Vgoo0P001UYF00@005YFFUIJEP8001eoo`80
009JEP03001oogoo051oo`00WGoo0P000eYF00<005YFFUH015YF0P0077oo00@005YFFUH0059oo`00
Wgoo0P0000=JEP00FUH01eYF0`006Goo00<005YF0000Dgoo002QOol30007FUH00`00FUIJEP04000D
Ool200000eYF001oo`1BOol00:Aoo`8000EJEP03001JEUYF00AJEPH000Qoo`H0009JEP03001oogoo
059oo`00YWoo0`0000=JEP00FUH025YF00@005YFFUIJEPP000=JEP04001JEUYFFUH2001DOol00:Uo
o`<000QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05=oo`00[7oo
0`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00[goo0`0000=JEP00
FUH01UYF00<005YFFUH00eYF00<005YFFUH00`00EWoo002bOol50004FUH01000FUIJEUYF1@00FGoo
002gOol8001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60719 .74291 m .59478 .68751 L .5644 .69274 L p .707 .577 .707 r
F P
0 g
s
.59478 .68751 m .60719 .74291 L .63831 .7357 L p .707 .577 .707 r
F P
0 g
s
.63831 .7357 m .62589 .68029 L .59478 .68751 L p .707 .577 .707 r
F P
0 g
s
.62589 .68029 m .63831 .7357 L .66712 .72721 L p .707 .577 .707 r
F P
0 g
s
.66712 .72721 m .6547 .67181 L .62589 .68029 L p .707 .577 .707 r
F P
0 g
s
.57682 .74814 m .5644 .69274 L .53774 .69548 L p .707 .577 .707 r
F P
0 g
s
.5644 .69274 m .57682 .74814 L .60719 .74291 L p .707 .577 .707 r
F P
0 g
s
.6547 .67181 m .66712 .72721 L .69081 .71828 L p .707 .577 .707 r
F P
0 g
s
.69081 .71828 m .67839 .66288 L .6547 .67181 L p .707 .577 .707 r
F P
0 g
s
.53774 .69548 m .55016 .75088 L .57682 .74814 L p .707 .577 .707 r
F P
0 g
s
.55016 .75088 m .53774 .69548 L .51741 .69546 L p .707 .577 .707 r
F P
0 g
s
.58662 .80139 m .57837 .76446 L .54799 .76967 L p .707 .577 .707 r
F P
0 g
s
.57837 .76446 m .58662 .80139 L .61774 .7942 L p .707 .577 .707 r
F P
0 g
s
.61774 .7942 m .60949 .75726 L .57837 .76446 L p .707 .577 .707 r
F P
0 g
s
.60949 .75726 m .61774 .7942 L .64655 .78573 L p .707 .577 .707 r
F P
0 g
s
.64655 .78573 m .6383 .74879 L .60949 .75726 L p .707 .577 .707 r
F P
0 g
s
.67839 .66288 m .69081 .71828 L .70705 .70978 L p .707 .577 .707 r
F P
0 g
s
.70705 .70978 m .69463 .65438 L .67839 .66288 L p .707 .577 .707 r
F P
0 g
s
.54799 .76967 m .55624 .80661 L .58662 .80139 L p .707 .577 .707 r
F P
0 g
s
.51741 .69546 m .52982 .75087 L .55016 .75088 L p .707 .577 .707 r
F P
0 g
s
.55624 .80661 m .54799 .76967 L .52132 .77239 L p .707 .577 .707 r
F P
0 g
s
.59991 .86109 m .60569 .84418 L .5761 .8326 L p .707 .577 .707 r
F P
0 g
s
.60569 .84418 m .59991 .86109 L .63032 .86904 L p .707 .577 .707 r
F P
0 g
s
.63032 .86904 m .6361 .85213 L .60569 .84418 L p .707 .577 .707 r
F P
0 g
s
.6383 .74879 m .64655 .78573 L .67024 .77681 L p .707 .577 .707 r
F P
0 g
s
.67024 .77681 m .66199 .73987 L .6383 .74879 L p .707 .577 .707 r
F P
0 g
s
.57031 .84951 m .5761 .8326 L .55022 .81853 L p .707 .577 .707 r
F P
0 g
s
.5761 .8326 m .57031 .84951 L .59991 .86109 L p .707 .577 .707 r
F P
0 g
s
.52132 .77239 m .52958 .80933 L .55624 .80661 L p .707 .577 .707 r
F P
0 g
s
.6361 .85213 m .63032 .86904 L .65857 .87259 L p .707 .577 .707 r
F P
0 g
s
.65857 .87259 m .66435 .85568 L .6361 .85213 L p .707 .577 .707 r
F P
0 g
s
.55022 .81853 m .54444 .83544 L .57031 .84951 L p .707 .577 .707 r
F P
0 g
s
.52982 .75087 m .51741 .69546 L .50539 .69269 L p .707 .577 .707 r
F P
0 g
s
.52958 .80933 m .52132 .77239 L .50098 .77235 L p .707 .577 .707 r
F P
0 g
s
.54444 .83544 m .55022 .81853 L .53059 .80335 L p .707 .577 .707 r
F P
0 g
s
.69463 .65438 m .70705 .70978 L .71426 .70255 L p .707 .577 .707 r
F P
0 g
s
.71426 .70255 m .70184 .64715 L .69463 .65438 L p .707 .577 .707 r
F P
0 g
s
.66435 .85568 m .65857 .87259 L .6819 .87139 L p .707 .577 .707 r
F P
0 g
s
.6819 .87139 m .68768 .85448 L .66435 .85568 L p .707 .577 .707 r
F P
0 g
s
.66199 .73987 m .67024 .77681 L .68649 .76831 L p .707 .577 .707 r
F P
0 g
s
.68649 .76831 m .67823 .73138 L .66199 .73987 L p .707 .577 .707 r
F P
0 g
s
.50539 .69269 m .5178 .74809 L .52982 .75087 L p .707 .577 .707 r
F P
0 g
s
.50098 .77235 m .50924 .80929 L .52958 .80933 L p .707 .577 .707 r
F P
0 g
s
.53059 .80335 m .5248 .82026 L .54444 .83544 L p .707 .577 .707 r
F P
0 g
s
.5248 .82026 m .53059 .80335 L .51912 .78853 L p .707 .577 .707 r
F P
0 g
s
.50924 .80929 m .50098 .77235 L .48896 .76956 L p .707 .577 .707 r
F P
0 g
s
.5178 .74809 m .50539 .69269 L .50286 .68742 L p .707 .577 .707 r
F P
0 g
s
.68768 .85448 m .6819 .87139 L .69802 .86556 L p .707 .577 .707 r
F P
0 g
s
.69802 .86556 m .7038 .84865 L .68768 .85448 L p .707 .577 .707 r
F P
0 g
s
.51912 .78853 m .51334 .80544 L .5248 .82026 L p .707 .577 .707 r
F P
0 g
s
.48896 .76956 m .49721 .8065 L .50924 .80929 L p .707 .577 .707 r
F P
0 g
s
.67823 .73138 m .68649 .76831 L .69369 .76108 L p .707 .577 .707 r
F P
0 g
s
.69369 .76108 m .68544 .72414 L .67823 .73138 L p .707 .577 .707 r
F P
0 g
s
.70184 .64715 m .71426 .70255 L .71173 .69729 L p .707 .577 .707 r
F P
0 g
s
.71173 .69729 m .69931 .64188 L .70184 .64715 L p .707 .577 .707 r
F P
0 g
s
.50286 .68742 m .51527 .74283 L .5178 .74809 L p .707 .577 .707 r
F P
0 g
s
.51334 .80544 m .51912 .78853 L .51695 .77554 L p .707 .577 .707 r
F P
0 g
s
.49721 .8065 m .48896 .76956 L .48643 .76429 L p .707 .577 .707 r
F P
0 g
s
.48643 .76429 m .49468 .80122 L .49721 .8065 L p .707 .577 .707 r
F P
0 g
s
.49468 .80122 m .48643 .76429 L .49364 .75705 L p .707 .577 .707 r
F P
0 g
s
.48638 .82191 m .49231 .3207 L .44831 .31749 L p .707 .577 .707 r
F P
0 g
s
.51695 .77554 m .51117 .79245 L .51334 .80544 L p .707 .577 .707 r
F P
0 g
s
.51527 .74283 m .50286 .68742 L .51007 .68019 L p .707 .577 .707 r
F P
0 g
s
.51007 .68019 m .52248 .73559 L .51527 .74283 L p .707 .577 .707 r
F P
0 g
s
.51117 .79245 m .51695 .77554 L .52429 .76565 L p .707 .577 .707 r
F P
0 g
s
.52429 .76565 m .5185 .78256 L .51117 .79245 L p .707 .577 .707 r
F P
0 g
s
.52248 .73559 m .51007 .68019 L .52631 .67169 L p .707 .577 .707 r
F P
0 g
s
.49364 .75705 m .50189 .79399 L .49468 .80122 L p .707 .577 .707 r
F P
0 g
s
.52631 .67169 m .53872 .72709 L .52248 .73559 L p .707 .577 .707 r
F P
0 g
s
.5185 .78256 m .52429 .76565 L .54041 .75981 L p .707 .577 .707 r
F P
0 g
s
.54041 .75981 m .53462 .77672 L .5185 .78256 L p .707 .577 .707 r
F P
0 g
s
.50189 .79399 m .49364 .75705 L .50988 .74855 L p .707 .577 .707 r
F P
0 g
s
.50988 .74855 m .51813 .78549 L .50189 .79399 L p .707 .577 .707 r
F P
0 g
s
.51813 .78549 m .50988 .74855 L .53357 .73964 L p .707 .577 .707 r
F P
0 g
s
.53462 .77672 m .54041 .75981 L .56373 .75861 L p .707 .577 .707 r
F P
0 g
s
.56373 .75861 m .55795 .77552 L .53462 .77672 L p .707 .577 .707 r
F P
0 g
s
.53357 .73964 m .54182 .77657 L .51813 .78549 L p .707 .577 .707 r
F P
0 g
s
.49231 .3207 m .48638 .82191 L .53132 .82129 L p .707 .577 .707 r
F P
0 g
s
.53872 .72709 m .52631 .67169 L .55 .66276 L p .707 .577 .707 r
F P
0 g
s
.53132 .82129 m .53725 .32007 L .49231 .3207 L p .707 .577 .707 r
F P
0 g
s
.55 .66276 m .56241 .71816 L .53872 .72709 L p .707 .577 .707 r
F P
0 g
s
.56241 .71816 m .55 .66276 L .57881 .65428 L p .707 .577 .707 r
F P
0 g
s
.57881 .65428 m .59122 .70968 L .56241 .71816 L p .707 .577 .707 r
F P
0 g
s
.55795 .77552 m .56373 .75861 L .59198 .76216 L p .707 .577 .707 r
F P
0 g
s
.59198 .76216 m .5862 .77907 L .55795 .77552 L p .707 .577 .707 r
F P
0 g
s
.54182 .77657 m .53357 .73964 L .56238 .73116 L p .707 .577 .707 r
F P
0 g
s
.56238 .73116 m .57063 .7681 L .54182 .77657 L p .707 .577 .707 r
F P
0 g
s
.57063 .7681 m .56238 .73116 L .5935 .72397 L p .707 .577 .707 r
F P
0 g
s
.53725 .32007 m .53132 .82129 L .5728 .81689 L p .707 .577 .707 r
F P
0 g
s
.5862 .77907 m .59198 .76216 L .6224 .77011 L p .707 .577 .707 r
F P
0 g
s
.5935 .72397 m .60175 .76091 L .57063 .7681 L p .707 .577 .707 r
F P
0 g
s
.5728 .81689 m .57873 .31568 L .53725 .32007 L p .707 .577 .707 r
F P
0 g
s
.7038 .84865 m .69802 .86556 L .70535 .85566 L p .707 .577 .707 r
F P
0 g
s
.70535 .85566 m .71113 .83875 L .7038 .84865 L p .707 .577 .707 r
F P
0 g
s
.44238 .8187 m .44831 .31749 L .40955 .31076 L p .707 .577 .707 r
F P
0 g
s
.44831 .31749 m .44238 .8187 L .48638 .82191 L p .707 .577 .707 r
F P
0 g
s
.68544 .72414 m .69369 .76108 L .69116 .7558 L p .707 .577 .707 r
F P
0 g
s
.69116 .7558 m .68291 .71887 L .68544 .72414 L p .707 .577 .707 r
F P
0 g
s
.69931 .64188 m .71173 .69729 L .69971 .69451 L p .707 .577 .707 r
F P
0 g
s
.69971 .69451 m .68729 .63911 L .69931 .64188 L p .707 .577 .707 r
F P
0 g
s
.59122 .70968 m .57881 .65428 L .60992 .64706 L p .707 .577 .707 r
F P
0 g
s
.60992 .64706 m .62234 .70247 L .59122 .70968 L p .707 .577 .707 r
F P
0 g
s
.62388 .71876 m .63213 .7557 L .60175 .76091 L p .707 .577 .707 r
F P
0 g
s
.60175 .76091 m .5935 .72397 L .62388 .71876 L p .707 .577 .707 r
F P
0 g
s
.6224 .77011 m .61661 .78702 L .5862 .77907 L p .707 .577 .707 r
F P
0 g
s
.57873 .31568 m .5728 .81689 L .60676 .80916 L p .707 .577 .707 r
F P
0 g
s
.60676 .80916 m .61269 .30795 L .57873 .31568 L p .707 .577 .707 r
F P
0 g
s
.26418 .70603 m .25177 .65063 L .2214 .65587 L p .707 .577 .707 r
F P
0 g
s
.25177 .65063 m .26418 .70603 L .2953 .69882 L p .707 .577 .707 r
F P
0 g
s
.2953 .69882 m .28289 .64342 L .25177 .65063 L p .707 .577 .707 r
F P
0 g
s
.28289 .64342 m .2953 .69882 L .32411 .69033 L p .707 .577 .707 r
F P
0 g
s
.32411 .69033 m .3117 .63493 L .28289 .64342 L p .707 .577 .707 r
F P
0 g
s
.40361 .81197 m .40955 .31076 L .37982 .30117 L p .707 .577 .707 r
F P
0 g
s
.40955 .31076 m .40361 .81197 L .44238 .8187 L p .707 .577 .707 r
F P
0 g
s
.71113 .83875 m .70535 .85566 L .70318 .84267 L p .707 .577 .707 r
F P
0 g
s
.70318 .84267 m .70896 .82576 L .71113 .83875 L p .707 .577 .707 r
F P
0 g
s
.23381 .71127 m .2214 .65587 L .19474 .65861 L p .707 .577 .707 r
F P
0 g
s
.2214 .65587 m .23381 .71127 L .26418 .70603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3117 .63493 m .32411 .69033 L .3478 .68141 L p .707 .577 .707 r
F P
0 g
s
.3478 .68141 m .33538 .626 L .3117 .63493 L p .707 .577 .707 r
F P
0 g
s
.68291 .71887 m .69116 .7558 L .67914 .75301 L p .707 .577 .707 r
F P
0 g
s
.67914 .75301 m .67089 .71607 L .68291 .71887 L p .707 .577 .707 r
F P
0 g
s
.68729 .63911 m .69971 .69451 L .67937 .69449 L p .707 .577 .707 r
F P
0 g
s
.67937 .69449 m .66696 .63909 L .68729 .63911 L p .707 .577 .707 r
F P
0 g
s
.19474 .65861 m .20715 .71401 L .23381 .71127 L p .707 .577 .707 r
F P
0 g
s
.6403 .64183 m .65271 .69723 L .62234 .70247 L p .707 .577 .707 r
F P
0 g
s
.62234 .70247 m .60992 .64706 L .6403 .64183 L p .707 .577 .707 r
F P
0 g
s
.63213 .7557 m .62388 .71876 L .65055 .71604 L p .707 .577 .707 r
F P
0 g
s
.65199 .78169 m .64621 .7986 L .61661 .78702 L p .707 .577 .707 r
F P
0 g
s
.61661 .78702 m .6224 .77011 L .65199 .78169 L p .707 .577 .707 r
F P
0 g
s
.61269 .30795 m .60676 .80916 L .62986 .79884 L p .707 .577 .707 r
F P
0 g
s
.62986 .79884 m .6358 .29763 L .61269 .30795 L p .707 .577 .707 r
F P
0 g
s
.20715 .71401 m .19474 .65861 L .1744 .65859 L p .707 .577 .707 r
F P
0 g
s
.24361 .76441 m .23536 .72747 L .20498 .73268 L p .707 .577 .707 r
F P
0 g
s
.23536 .72747 m .24361 .76441 L .27473 .75721 L p .707 .577 .707 r
F P
0 g
s
.27473 .75721 m .26648 .72028 L .23536 .72747 L p .707 .577 .707 r
F P
0 g
s
.26648 .72028 m .27473 .75721 L .30354 .74874 L p .707 .577 .707 r
F P
0 g
s
.30354 .74874 m .29529 .71181 L .26648 .72028 L p .707 .577 .707 r
F P
0 g
s
.33538 .626 m .3478 .68141 L .36404 .67291 L p .707 .577 .707 r
F P
0 g
s
.36404 .67291 m .35162 .61751 L .33538 .626 L p .707 .577 .707 r
F P
0 g
s
.35162 .61751 m .36404 .67291 L .36679 .67014 L p .707 .577 .707 r
F P
0 g
s
.36679 .67014 m .37125 .66567 L p .36586 .65245 L .707 .577 .707 r
F P
0 g
s
.36586 .65245 m .35162 .61751 L .36679 .67014 L .707 .577 .707 r
F
.36205 .28967 m .35796 .27736 L p .3572 .48808 L F P
0 g
s
.37125 .66567 m .35883 .61027 L .35162 .61751 L p .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .35883 .61027 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.36872 .66041 m .3622 .63133 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .3563 .60501 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .3622 .63133 L p .3567 .65763 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .36872 .66041 L .36019 .65844 L p .707 .577 .707 r
F P
0 g
s
.36019 .65844 m .3567 .65763 L p .3622 .63133 L .707 .577 .707 r
F P
0 g
s
.3567 .65763 m .34428 .60223 L .3563 .60501 L p .707 .577 .707 r
F P
0 g
s
.34428 .60223 m .3567 .65763 L .33636 .65761 L p .707 .577 .707 r
F P
0 g
s
.35641 .70954 m .35924 .52677 L .3572 .48808 L .707 .577 .707 r
F
.36595 .78966 m .36017 .80657 L .36012 .8065 L p F P
0 g
s
.36012 .8065 m .34871 .79176 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.35942 .79045 m .36595 .78966 L .36012 .8065 L .707 .577 .707 r
F
.35637 .72066 m .35721 .69877 L .35641 .70954 L F
.34871 .79176 m .35449 .77485 L .35899 .78066 L p F P
0 g
s
.35899 .78066 m .36595 .78966 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.34871 .79176 m .35899 .78066 L .35942 .79045 L .707 .577 .707 r
F
.35449 .77485 m .34871 .79176 L .34056 .78546 L p F P
0 g
s
.34056 .78546 m .32908 .77657 L p .34105 .77576 L .707 .577 .707 r
F P
0 g
s
.34105 .77576 m .35449 .77485 L .34056 .78546 L .707 .577 .707 r
F
.35637 .72066 m .35674 .61823 L .35479 .68453 L F
.32908 .77657 m .33486 .75966 L .35449 .77485 L p F P
0 g
s
.35637 .72066 m .35479 .68453 L .35203 .77858 L .707 .577 .707 r
F
.35721 .69877 m .35924 .52677 L p .35641 .70954 L F P
0 g
s
.35796 .27736 m .354 .61168 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.354 .61168 m .35203 .77858 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.35924 .52677 m .36205 .28967 L p .3572 .48808 L .707 .577 .707 r
F P
0 g
s
.35883 .61027 m .37125 .66567 L .36872 .66041 L p .707 .577 .707 r
F P
0 g
s
.37389 .80239 m .37982 .30117 L .36205 .28967 L p .707 .577 .707 r
F P
0 g
s
.36017 .80657 m .36595 .78966 L .36812 .80265 L p .707 .577 .707 r
F P
0 g
s
.36205 .28967 m .35612 .79088 L .37389 .80239 L p .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35551 .48431 L p .36796 .26547 L .707 .577 .707 r
F P
0 g
s
.35551 .48431 m .35796 .27736 L .36627 .26748 L p .707 .577 .707 r
F P
0 g
s
.36627 .26748 m .36796 .26547 L p .35551 .48431 L .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35612 .79088 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35612 .79088 m .35682 .73109 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35682 .73109 m .35721 .69877 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.37982 .30117 m .37389 .80239 L .40361 .81197 L p .707 .577 .707 r
F P
0 g
s
.70896 .82576 m .70318 .84267 L .69172 .82786 L p .707 .577 .707 r
F P
0 g
s
.69172 .82786 m .6975 .81095 L .70896 .82576 L p .707 .577 .707 r
F P
0 g
s
.20498 .73268 m .21323 .76962 L .24361 .76441 L p .707 .577 .707 r
F P
0 g
s
.1744 .65859 m .18681 .71399 L .20715 .71401 L p .707 .577 .707 r
F P
0 g
s
.21323 .76962 m .20498 .73268 L .17831 .7354 L p .707 .577 .707 r
F P
0 g
s
.2569 .82499 m .26268 .80808 L .23309 .7965 L p .707 .577 .707 r
F P
0 g
s
.26268 .80808 m .2569 .82499 L .28731 .83294 L p .707 .577 .707 r
F P
0 g
s
.28731 .83294 m .29309 .81603 L .26268 .80808 L p .707 .577 .707 r
F P
0 g
s
.29529 .71181 m .30354 .74874 L .32723 .73982 L p .707 .577 .707 r
F P
0 g
s
.32723 .73982 m .31898 .70289 L .29529 .71181 L p .707 .577 .707 r
F P
0 g
s
.66696 .63909 m .67937 .69449 L .65271 .69723 L p .707 .577 .707 r
F P
0 g
s
.65271 .69723 m .6403 .64183 L .66696 .63909 L p .707 .577 .707 r
F P
0 g
s
.22731 .81341 m .23309 .7965 L .20721 .78243 L p .707 .577 .707 r
F P
0 g
s
.23309 .7965 m .22731 .81341 L .2569 .82499 L p .707 .577 .707 r
F P
0 g
s
.17831 .7354 m .18657 .77234 L .21323 .76962 L p .707 .577 .707 r
F P
0 g
s
.29309 .81603 m .28731 .83294 L .31556 .83649 L p .707 .577 .707 r
F P
0 g
s
.31556 .83649 m .32134 .81958 L .29309 .81603 L p .707 .577 .707 r
F P
0 g
s
.67089 .71607 m .67914 .75301 L .6588 .75297 L p .707 .577 .707 r
F P
0 g
s
.6588 .75297 m .65055 .71604 L .67089 .71607 L p .707 .577 .707 r
F P
0 g
s
.20721 .78243 m .20143 .79934 L .22731 .81341 L p .707 .577 .707 r
F P
0 g
s
.18681 .71399 m .1744 .65859 L .16238 .65581 L p .707 .577 .707 r
F P
0 g
s
.18657 .77234 m .17831 .7354 L .15797 .73537 L p .707 .577 .707 r
F P
0 g
s
.20143 .79934 m .20721 .78243 L .18758 .76725 L p .707 .577 .707 r
F P
0 g
s
.65055 .71604 m .6588 .75297 L .63213 .7557 L p .707 .577 .707 r
F P
0 g
s
.6358 .29763 m .62986 .79884 L .63987 .78695 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .6458 .28574 L .6358 .29763 L p .707 .577 .707 r
F P
0 g
s
.32134 .81958 m .31556 .83649 L .33889 .83529 L p .707 .577 .707 r
F P
0 g
s
.33889 .83529 m .34467 .81838 L .32134 .81958 L p .707 .577 .707 r
F P
0 g
s
.31898 .70289 m .32723 .73982 L .34348 .73133 L p .707 .577 .707 r
F P
0 g
s
.34348 .73133 m .33522 .69439 L .31898 .70289 L p .707 .577 .707 r
F P
0 g
s
.6975 .81095 m .69172 .82786 L .67209 .81267 L p .707 .577 .707 r
F P
0 g
s
.67209 .81267 m .67787 .79576 L .6975 .81095 L p .707 .577 .707 r
F P
0 g
s
.16238 .65581 m .17479 .71121 L .18681 .71399 L p .707 .577 .707 r
F P
0 g
s
.15797 .73537 m .16623 .7723 L .18657 .77234 L p .707 .577 .707 r
F P
0 g
s
.18758 .76725 m .18179 .78415 L .20143 .79934 L p .707 .577 .707 r
F P
0 g
s
.18179 .78415 m .18758 .76725 L .17611 .75243 L p .707 .577 .707 r
F P
0 g
s
.16623 .7723 m .15797 .73537 L .14595 .73257 L p .707 .577 .707 r
F P
0 g
s
.17479 .71121 m .16238 .65581 L .15985 .65055 L p .707 .577 .707 r
F P
0 g
s
.67787 .79576 m .67209 .81267 L .64621 .7986 L p .707 .577 .707 r
F P
0 g
s
.64621 .7986 m .65199 .78169 L .67787 .79576 L p .707 .577 .707 r
F P
0 g
s
.34467 .81838 m .33889 .83529 L .35501 .82946 L p .707 .577 .707 r
F P
0 g
s
.35501 .82946 m .36079 .81255 L .34467 .81838 L p .707 .577 .707 r
F P
0 g
s
.17611 .75243 m .17033 .76934 L .18179 .78415 L p .707 .577 .707 r
F P
0 g
s
.14595 .73257 m .1542 .76951 L .16623 .7723 L p .707 .577 .707 r
F P
0 g
s
.33522 .69439 m .34348 .73133 L .35069 .72409 L p .707 .577 .707 r
F P
0 g
s
.35069 .72409 m .34243 .68715 L .33522 .69439 L p .707 .577 .707 r
F P
0 g
s
.15985 .65055 m .17226 .70595 L .17479 .71121 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .63578 .77465 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64244 .56957 m .63987 .78695 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .6458 .28574 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.63578 .77465 m .6374 .63778 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.6374 .63778 m .64171 .27343 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .63578 .77465 L .618 .76314 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .64644 .71725 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.62616 .67752 m .6324 .70543 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.6324 .70543 m .63442 .71446 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63819 .68031 L .63432 .67942 L p .707 .577 .707 r
F P
0 g
s
.63432 .67942 m .62616 .67752 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63432 .67942 L .63341 .69172 L .707 .577 .707 r
F
.6458 .28574 m .64244 .56957 L p .63904 .61559 L F P
0 g
s
.17033 .76934 m .17611 .75243 L .17394 .73944 L p .707 .577 .707 r
F P
0 g
s
.1542 .76951 m .14595 .73257 L .14342 .7273 L p .707 .577 .707 r
F P
0 g
s
.17394 .73944 m .16816 .75635 L .17033 .76934 L p .707 .577 .707 r
F P
0 g
s
.36079 .81255 m .35501 .82946 L .36234 .81956 L p .707 .577 .707 r
F P
0 g
s
.36234 .81956 m .36812 .80265 L .36079 .81255 L p .707 .577 .707 r
F P
0 g
s
.17226 .70595 m .15985 .65055 L .16706 .64331 L p .707 .577 .707 r
F P
0 g
s
.14342 .7273 m .15167 .76424 L .1542 .76951 L p .707 .577 .707 r
F P
0 g
s
.34243 .68715 m .35069 .72409 L .34815 .71882 L p .707 .577 .707 r
F P
0 g
s
.34815 .71882 m .3399 .68188 L .34243 .68715 L p .707 .577 .707 r
F P
0 g
s
.16706 .64331 m .17947 .69872 L .17226 .70595 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16816 .75635 m .17394 .73944 L .18128 .72955 L p .707 .577 .707 r
F P
0 g
s
.18128 .72955 m .1755 .74645 L .16816 .75635 L p .707 .577 .707 r
F P
0 g
s
.36812 .80265 m .36234 .81956 L .36017 .80657 L p .707 .577 .707 r
F P
0 g
s
.15167 .76424 m .14342 .7273 L .15063 .72006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17947 .69872 m .16706 .64331 L .1833 .63482 L p .707 .577 .707 r
F P
0 g
s
.618 .76314 m .62393 .26193 L .64171 .27343 L p .707 .577 .707 r
F P
0 g
s
.15063 .72006 m .15888 .757 L .15167 .76424 L p .707 .577 .707 r
F P
0 g
s
.3399 .68188 m .34815 .71882 L .33613 .71603 L p .707 .577 .707 r
F P
0 g
s
.33613 .71603 m .32788 .67909 L .3399 .68188 L p .707 .577 .707 r
F P
0 g
s
.33636 .65761 m .32395 .60221 L .34428 .60223 L p .707 .577 .707 r
F P
0 g
s
.1833 .63482 m .19571 .69022 L .17947 .69872 L p .707 .577 .707 r
F P
0 g
s
.36203 .76669 m .36796 .26547 L .39107 .25515 L p .707 .577 .707 r
F P
0 g
s
.36796 .26547 m .36203 .76669 L .35203 .77858 L p .707 .577 .707 r
F P
0 g
s
.1755 .74645 m .18128 .72955 L .1974 .72371 L p .707 .577 .707 r
F P
0 g
s
.1974 .72371 m .19161 .74062 L .1755 .74645 L p .707 .577 .707 r
F P
0 g
s
.19571 .69022 m .1833 .63482 L .20699 .62589 L p .707 .577 .707 r
F P
0 g
s
.15888 .757 m .15063 .72006 L .16687 .71157 L p .707 .577 .707 r
F P
0 g
s
.32395 .60221 m .33636 .65761 L .3097 .66036 L p .707 .577 .707 r
F P
0 g
s
.3097 .66036 m .29729 .60496 L .32395 .60221 L p .707 .577 .707 r
F P
0 g
s
.16687 .71157 m .17512 .74851 L .15888 .757 L p .707 .577 .707 r
F P
0 g
s
.32788 .67909 m .33613 .71603 L .31579 .71599 L p .707 .577 .707 r
F P
0 g
s
.31579 .71599 m .30754 .67905 L .32788 .67909 L p .707 .577 .707 r
F P
0 g
s
.20699 .62589 m .2194 .68129 L .19571 .69022 L p .707 .577 .707 r
F P
0 g
s
.62393 .26193 m .618 .76314 L .58828 .75356 L p .707 .577 .707 r
F P
0 g
s
.58828 .75356 m .59421 .25234 L .62393 .26193 L p .707 .577 .707 r
F P
0 g
s
.19161 .74062 m .1974 .72371 L .22072 .72251 L p .707 .577 .707 r
F P
0 g
s
.2194 .68129 m .20699 .62589 L .2358 .6174 L p .707 .577 .707 r
F P
0 g
s
.29729 .60496 m .3097 .66036 L .27933 .66559 L p .707 .577 .707 r
F P
0 g
s
.27933 .66559 m .26691 .61019 L .29729 .60496 L p .707 .577 .707 r
F P
0 g
s
.22072 .72251 m .21494 .73942 L .19161 .74062 L p .707 .577 .707 r
F P
0 g
s
.17512 .74851 m .16687 .71157 L .19056 .70265 L p .707 .577 .707 r
F P
0 g
s
.39107 .25515 m .38514 .75637 L .36203 .76669 L p .707 .577 .707 r
F P
0 g
s
.38514 .75637 m .39107 .25515 L .42502 .24742 L p .707 .577 .707 r
F P
0 g
s
.2358 .6174 m .24821 .6728 L .2194 .68129 L p .707 .577 .707 r
F P
0 g
s
.7444 .65087 m .73198 .59547 L .70161 .6007 L p .707 .577 .707 r
F P
0 g
s
.73198 .59547 m .7444 .65087 L .77551 .64366 L p .707 .577 .707 r
F P
0 g
s
.77551 .64366 m .7631 .58826 L .73198 .59547 L p .707 .577 .707 r
F P
0 g
s
.24821 .6728 m .2358 .6174 L .26691 .61019 L p .707 .577 .707 r
F P
0 g
s
.7631 .58826 m .77551 .64366 L .80432 .63517 L p .707 .577 .707 r
F P
0 g
s
.80432 .63517 m .79191 .57977 L .7631 .58826 L p .707 .577 .707 r
F P
0 g
s
.26691 .61019 m .27933 .66559 L .24821 .6728 L p .707 .577 .707 r
F P
0 g
s
.30754 .67905 m .31579 .71599 L .28912 .71871 L p .707 .577 .707 r
F P
0 g
s
.28912 .71871 m .28087 .68177 L .30754 .67905 L p .707 .577 .707 r
F P
0 g
s
.19056 .70265 m .19881 .73959 L .17512 .74851 L p .707 .577 .707 r
F P
0 g
s
.71402 .6561 m .70161 .6007 L .67495 .60344 L p .707 .577 .707 r
F P
0 g
s
.70161 .6007 m .71402 .6561 L .7444 .65087 L p .707 .577 .707 r
F P
0 g
s
.21494 .73942 m .22072 .72251 L .24897 .72606 L p .707 .577 .707 r
F P
0 g
s
.79191 .57977 m .80432 .63517 L .82801 .62624 L p .707 .577 .707 r
F P
0 g
s
.82801 .62624 m .8156 .57084 L .79191 .57977 L p .707 .577 .707 r
F P
0 g
s
.33486 .75966 m .32908 .77657 L .3032 .7625 L p .707 .577 .707 r
F P
0 g
s
.3032 .7625 m .30898 .74559 L .33486 .75966 L p .707 .577 .707 r
F P
0 g
s
.59421 .25234 m .58828 .75356 L .54952 .74683 L p .707 .577 .707 r
F P
0 g
s
.54952 .74683 m .55545 .24561 L .59421 .25234 L p .707 .577 .707 r
F P
0 g
s
.19881 .73959 m .19056 .70265 L .21937 .69418 L p .707 .577 .707 r
F P
0 g
s
.24897 .72606 m .24319 .74297 L .21494 .73942 L p .707 .577 .707 r
F P
0 g
s
.67495 .60344 m .68736 .65885 L .71402 .6561 L p .707 .577 .707 r
F P
0 g
s
.28087 .68177 m .28912 .71871 L .25874 .72392 L p .707 .577 .707 r
F P
0 g
s
.25874 .72392 m .25049 .68699 L .28087 .68177 L p .707 .577 .707 r
F P
0 g
s
.21937 .69418 m .22762 .73112 L .19881 .73959 L p .707 .577 .707 r
F P
0 g
s
.24319 .74297 m .24897 .72606 L .27939 .73401 L p .707 .577 .707 r
F P
0 g
s
.68736 .65885 m .67495 .60344 L .65461 .60343 L p .707 .577 .707 r
F P
0 g
s
.30898 .74559 m .3032 .7625 L .2736 .75092 L p .707 .577 .707 r
F P
0 g
s
.2736 .75092 m .27939 .73401 L .30898 .74559 L p .707 .577 .707 r
F P
0 g
s
.41909 .74863 m .42502 .24742 L .4665 .24303 L p .707 .577 .707 r
F P
0 g
s
.42502 .24742 m .42018 .65652 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.4665 .24303 m .46057 .74424 L .41909 .74863 L p .707 .577 .707 r
F P
0 g
s
.42009 .55138 m .4325 .60678 L .44088 .60431 L p .707 .577 .707 r
F P
0 g
s
.44088 .60431 m .46131 .5983 L p .44888 .58414 L .707 .577 .707 r
F P
0 g
s
.44888 .58414 m .42009 .55138 L .44088 .60431 L .707 .577 .707 r
F
.41909 .74863 m .38514 .75637 L p .38626 .7421 L F P
0 g
s
.42018 .65652 m .41909 .74863 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.72382 .70935 m .71557 .67242 L .68519 .67763 L p .707 .577 .707 r
F P
0 g
s
.71557 .67242 m .72382 .70935 L .75494 .70216 L p .707 .577 .707 r
F P
0 g
s
.75494 .70216 m .74669 .66522 L .71557 .67242 L p .707 .577 .707 r
F P
0 g
s
.22762 .73112 m .21937 .69418 L .25049 .68699 L p .707 .577 .707 r
F P
0 g
s
.74669 .66522 m .75494 .70216 L .78376 .69369 L p .707 .577 .707 r
F P
0 g
s
.78376 .69369 m .77551 .65675 L .74669 .66522 L p .707 .577 .707 r
F P
0 g
s
.25049 .68699 m .25874 .72392 L .22762 .73112 L p .707 .577 .707 r
F P
0 g
s
.27939 .73401 m .2736 .75092 L .24319 .74297 L p .707 .577 .707 r
F P
0 g
s
.8156 .57084 m .82801 .62624 L .84425 .61774 L p .707 .577 .707 r
F P
0 g
s
.84425 .61774 m .83184 .56234 L .8156 .57084 L p .707 .577 .707 r
F P
0 g
s
.68519 .67763 m .69344 .71457 L .72382 .70935 L p .707 .577 .707 r
F P
0 g
s
.65461 .60343 m .66703 .65883 L .68736 .65885 L p .707 .577 .707 r
F P
0 g
s
.69344 .71457 m .68519 .67763 L .65853 .68035 L p .707 .577 .707 r
F P
0 g
s
.73711 .76905 m .74289 .75214 L .7133 .74056 L p .707 .577 .707 r
F P
0 g
s
.74289 .75214 m .73711 .76905 L .76752 .77701 L p .707 .577 .707 r
F P
0 g
s
.76752 .77701 m .7733 .7601 L .74289 .75214 L p .707 .577 .707 r
F P
0 g
s
.55545 .24561 m .54952 .74683 L .50551 .74362 L p .707 .577 .707 r
F P
0 g
s
.50551 .74362 m .51145 .2424 L .55545 .24561 L p .707 .577 .707 r
F P
0 g
s
.77551 .65675 m .78376 .69369 L .80745 .68477 L p .707 .577 .707 r
F P
0 g
s
.80745 .68477 m .79919 .64783 L .77551 .65675 L p .707 .577 .707 r
F P
0 g
s
.70752 .75747 m .7133 .74056 L .68742 .72649 L p .707 .577 .707 r
F P
0 g
s
.7133 .74056 m .70752 .75747 L .73711 .76905 L p .707 .577 .707 r
F P
0 g
s
.65853 .68035 m .66678 .71729 L .69344 .71457 L p .707 .577 .707 r
F P
0 g
s
.46057 .74424 m .4665 .24303 L .51145 .2424 L p .707 .577 .707 r
F P
0 g
s
.7733 .7601 m .76752 .77701 L .79577 .78056 L p .707 .577 .707 r
F P
0 g
s
.79577 .78056 m .80156 .76365 L .7733 .7601 L p .707 .577 .707 r
F P
0 g
s
.51145 .2424 m .50551 .74362 L .46057 .74424 L p .707 .577 .707 r
F P
0 g
s
.68742 .72649 m .68164 .7434 L .70752 .75747 L p .707 .577 .707 r
F P
0 g
s
.66703 .65883 m .65461 .60343 L .64259 .60065 L p .707 .577 .707 r
F P
0 g
s
.66678 .71729 m .65853 .68035 L .63819 .68031 L p .707 .577 .707 r
F P
0 g
s
.68164 .7434 m .68742 .72649 L .66779 .71131 L p .707 .577 .707 r
F P
0 g
s
.83184 .56234 m .84425 .61774 L .85146 .61051 L p .707 .577 .707 r
F P
0 g
s
.85146 .61051 m .83905 .55511 L .83184 .56234 L p .707 .577 .707 r
F P
0 g
s
.80156 .76365 m .79577 .78056 L .8191 .77935 L p .707 .577 .707 r
F P
0 g
s
.8191 .77935 m .82488 .76245 L .80156 .76365 L p .707 .577 .707 r
F P
0 g
s
.79919 .64783 m .80745 .68477 L .82369 .67628 L p .707 .577 .707 r
F P
0 g
s
.82369 .67628 m .81544 .63934 L .79919 .64783 L p .707 .577 .707 r
F P
0 g
s
.64259 .60065 m .65501 .65605 L .66703 .65883 L p .707 .577 .707 r
F P
0 g
s
.63819 .68031 m .64644 .71725 L .66678 .71729 L p .707 .577 .707 r
F P
0 g
s
.66779 .71131 m .66201 .72822 L .68164 .7434 L p .707 .577 .707 r
F P
0 g
s
.66201 .72822 m .66779 .71131 L .65633 .6965 L p .707 .577 .707 r
F P
0 g
s
.65501 .65605 m .64259 .60065 L .64006 .59539 L p .707 .577 .707 r
F P
0 g
s
.82488 .76245 m .8191 .77935 L .83522 .77352 L p .707 .577 .707 r
F P
0 g
s
.83522 .77352 m .841 .75661 L .82488 .76245 L p .707 .577 .707 r
F P
0 g
s
.65633 .6965 m .65055 .71341 L .66201 .72822 L p .707 .577 .707 r
F P
0 g
s
.81544 .63934 m .82369 .67628 L .8309 .66904 L p .707 .577 .707 r
F P
0 g
s
.8309 .66904 m .82265 .6321 L .81544 .63934 L p .707 .577 .707 r
F P
0 g
s
.83905 .55511 m .85146 .61051 L .84893 .60525 L p .707 .577 .707 r
F P
0 g
s
.84893 .60525 m .83652 .54985 L .83905 .55511 L p .707 .577 .707 r
F P
0 g
s
.64006 .59539 m .65248 .65079 L .65501 .65605 L p .707 .577 .707 r
F P
0 g
s
.65055 .71341 m .65633 .6965 L .65416 .68351 L p .707 .577 .707 r
F P
0 g
s
.65416 .68351 m .64838 .70041 L .65055 .71341 L p .707 .577 .707 r
F P
0 g
s
.841 .75661 m .83522 .77352 L .84255 .76362 L p .707 .577 .707 r
F P
0 g
s
.84255 .76362 m .84834 .74671 L .841 .75661 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .62616 .67752 L .62363 .67225 L p .707 .577 .707 r
F P
0 g
s
.65248 .65079 m .64006 .59539 L .64727 .58815 L p .707 .577 .707 r
F P
0 g
s
.62363 .67225 m .63188 .70919 L .63442 .71446 L p .707 .577 .707 r
F P
0 g
s
.82265 .6321 m .8309 .66904 L .82837 .66377 L p .707 .577 .707 r
F P
0 g
s
.82837 .66377 m .82012 .62683 L .82265 .6321 L p .707 .577 .707 r
F P
0 g
s
.83652 .54985 m .84893 .60525 L .83691 .60247 L p .707 .577 .707 r
F P
0 g
s
.83691 .60247 m .8245 .54707 L .83652 .54985 L p .707 .577 .707 r
F P
0 g
s
.64727 .58815 m .65969 .64355 L .65248 .65079 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64838 .70041 m .65416 .68351 L .66149 .67361 L p .707 .577 .707 r
F P
0 g
s
.40139 .61399 m .38897 .55859 L .3586 .56383 L p .707 .577 .707 r
F P
0 g
s
.38897 .55859 m .40139 .61399 L .4325 .60678 L p .707 .577 .707 r
F P
0 g
s
.4325 .60678 m .42009 .55138 L .38897 .55859 L p .707 .577 .707 r
F P
0 g
s
.46131 .5983 m .4489 .54289 L .42009 .55138 L p .707 .577 .707 r
F P
0 g
s
.66149 .67361 m .65571 .69052 L .64838 .70041 L p .707 .577 .707 r
F P
0 g
s
.84834 .74671 m .84255 .76362 L .84038 .75063 L p .707 .577 .707 r
F P
0 g
s
.84038 .75063 m .84617 .73372 L .84834 .74671 L p .707 .577 .707 r
F P
0 g
s
.63188 .70919 m .62363 .67225 L .63084 .66501 L p .707 .577 .707 r
F P
0 g
s
.37101 .61923 m .3586 .56383 L .33194 .56657 L p .707 .577 .707 r
F P
0 g
s
.3586 .56383 m .37101 .61923 L .40139 .61399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65969 .64355 m .64727 .58815 L .66351 .57965 L p .707 .577 .707 r
F P
0 g
s
.4489 .54289 m .46131 .5983 L .485 .58937 L p .707 .577 .707 r
F P
0 g
s
.485 .58937 m .47259 .53396 L .4489 .54289 L p .707 .577 .707 r
F P
0 g
s
.63084 .66501 m .63909 .70195 L .63188 .70919 L p .707 .577 .707 r
F P
0 g
s
.82012 .62683 m .82837 .66377 L .81634 .66097 L p .707 .577 .707 r
F P
0 g
s
.81634 .66097 m .80809 .62404 L .82012 .62683 L p .707 .577 .707 r
F P
0 g
s
.8245 .54707 m .83691 .60247 L .81658 .60245 L p .707 .577 .707 r
F P
0 g
s
.81658 .60245 m .80416 .54705 L .8245 .54707 L p .707 .577 .707 r
F P
0 g
s
.33194 .56657 m .34435 .62197 L .37101 .61923 L p .707 .577 .707 r
F P
0 g
s
.66351 .57965 m .67593 .63506 L .65969 .64355 L p .707 .577 .707 r
F P
0 g
s
.34435 .62197 m .33194 .56657 L .3116 .56655 L p .707 .577 .707 r
F P
0 g
s
.65571 .69052 m .66149 .67361 L .67761 .66777 L p .707 .577 .707 r
F P
0 g
s
.38081 .67237 m .37256 .63543 L .34218 .64064 L p .707 .577 .707 r
F P
0 g
s
.37256 .63543 m .38081 .67237 L .41193 .66518 L p .707 .577 .707 r
F P
0 g
s
.41193 .66518 m .40368 .62824 L .37256 .63543 L p .707 .577 .707 r
F P
0 g
s
.40368 .62824 m .41193 .66518 L .44075 .6567 L p .707 .577 .707 r
F P
0 g
s
.44075 .6567 m .4325 .61977 L .40368 .62824 L p .707 .577 .707 r
F P
0 g
s
.47259 .53396 m .485 .58937 L .50124 .58087 L p .707 .577 .707 r
F P
0 g
s
.50124 .58087 m .48883 .52547 L .47259 .53396 L p .707 .577 .707 r
F P
0 g
s
.67761 .66777 m .67183 .68468 L .65571 .69052 L p .707 .577 .707 r
F P
0 g
s
.84617 .73372 m .84038 .75063 L .82892 .73582 L p .707 .577 .707 r
F P
0 g
s
.82892 .73582 m .8347 .71891 L .84617 .73372 L p .707 .577 .707 r
F P
0 g
s
.34218 .64064 m .35043 .67758 L .38081 .67237 L p .707 .577 .707 r
F P
0 g
s
.67593 .63506 m .66351 .57965 L .6872 .57072 L p .707 .577 .707 r
F P
0 g
s
.3116 .56655 m .32402 .62195 L .34435 .62197 L p .707 .577 .707 r
F P
0 g
s
.35043 .67758 m .34218 .64064 L .31552 .64337 L p .707 .577 .707 r
F P
0 g
s
.63909 .70195 m .63084 .66501 L .64708 .65652 L p .707 .577 .707 r
F P
0 g
s
.3941 .73295 m .39988 .71604 L .37029 .70446 L p .707 .577 .707 r
F P
0 g
s
.39988 .71604 m .3941 .73295 L .42451 .7409 L p .707 .577 .707 r
F P
0 g
s
.42451 .7409 m .43029 .724 L .39988 .71604 L p .707 .577 .707 r
F P
0 g
s
.4325 .61977 m .44075 .6567 L .46444 .64779 L p .707 .577 .707 r
F P
0 g
s
.46444 .64779 m .45618 .61085 L .4325 .61977 L p .707 .577 .707 r
F P
0 g
s
.80416 .54705 m .81658 .60245 L .78992 .60519 L p .707 .577 .707 r
F P
0 g
s
.78992 .60519 m .7775 .54979 L .80416 .54705 L p .707 .577 .707 r
F P
0 g
s
.36451 .72137 m .37029 .70446 L .34441 .69039 L p .707 .577 .707 r
F P
0 g
s
.37029 .70446 m .36451 .72137 L .3941 .73295 L p .707 .577 .707 r
F P
0 g
s
.31552 .64337 m .32377 .6803 L .35043 .67758 L p .707 .577 .707 r
F P
0 g
s
.64708 .65652 m .65534 .69345 L .63909 .70195 L p .707 .577 .707 r
F P
0 g
s
.43029 .724 m .42451 .7409 L .45276 .74445 L p .707 .577 .707 r
F P
0 g
s
.45276 .74445 m .45855 .72754 L .43029 .724 L p .707 .577 .707 r
F P
0 g
s
.80809 .62404 m .81634 .66097 L .796 .66094 L p .707 .577 .707 r
F P
0 g
s
.796 .66094 m .78775 .624 L .80809 .62404 L p .707 .577 .707 r
F P
0 g
s
.6872 .57072 m .69961 .62613 L .67593 .63506 L p .707 .577 .707 r
F P
0 g
s
.34441 .69039 m .33863 .7073 L .36451 .72137 L p .707 .577 .707 r
F P
0 g
s
.32402 .62195 m .3116 .56655 L .29958 .56377 L p .707 .577 .707 r
F P
0 g
s
.32377 .6803 m .31552 .64337 L .29518 .64333 L p .707 .577 .707 r
F P
0 g
s
.67183 .68468 m .67761 .66777 L .70094 .66657 L p .707 .577 .707 r
F P
0 g
s
.33863 .7073 m .34441 .69039 L .32478 .67521 L p .707 .577 .707 r
F P
0 g
s
.69961 .62613 m .6872 .57072 L .71601 .56224 L p .707 .577 .707 r
F P
0 g
s
.48883 .52547 m .50124 .58087 L .50845 .57363 L p .707 .577 .707 r
F P
0 g
s
.50845 .57363 m .49604 .51823 L .48883 .52547 L p .707 .577 .707 r
F P
0 g
s
.7775 .54979 m .78992 .60519 L .75954 .61043 L p .707 .577 .707 r
F P
0 g
s
.75954 .61043 m .74713 .55503 L .7775 .54979 L p .707 .577 .707 r
F P
0 g
s
.45855 .72754 m .45276 .74445 L .47609 .74325 L p .707 .577 .707 r
F P
0 g
s
.47609 .74325 m .48187 .72634 L .45855 .72754 L p .707 .577 .707 r
F P
0 g
s
.45618 .61085 m .46444 .64779 L .48068 .63929 L p .707 .577 .707 r
F P
0 g
s
.48068 .63929 m .47243 .60235 L .45618 .61085 L p .707 .577 .707 r
F P
0 g
s
.8347 .71891 m .82892 .73582 L .80929 .72063 L p .707 .577 .707 r
F P
0 g
s
.80929 .72063 m .81507 .70373 L .8347 .71891 L p .707 .577 .707 r
F P
0 g
s
.29958 .56377 m .312 .61917 L .32402 .62195 L p .707 .577 .707 r
F P
0 g
s
.29518 .64333 m .30343 .68027 L .32377 .6803 L p .707 .577 .707 r
F P
0 g
s
.70094 .66657 m .69516 .68348 L .67183 .68468 L p .707 .577 .707 r
F P
0 g
s
.32478 .67521 m .319 .69212 L .33863 .7073 L p .707 .577 .707 r
F P
0 g
s
.65534 .69345 m .64708 .65652 L .67077 .6476 L p .707 .577 .707 r
F P
0 g
s
.71601 .56224 m .72843 .61764 L .69961 .62613 L p .707 .577 .707 r
F P
0 g
s
.72843 .61764 m .71601 .56224 L .74713 .55503 L p .707 .577 .707 r
F P
0 g
s
.74713 .55503 m .75954 .61043 L .72843 .61764 L p .707 .577 .707 r
F P
0 g
s
.78775 .624 m .796 .66094 L .76934 .66366 L p .707 .577 .707 r
F P
0 g
s
.76934 .66366 m .76109 .62672 L .78775 .624 L p .707 .577 .707 r
F P
0 g
s
.67077 .6476 m .67902 .68453 L .65534 .69345 L p .707 .577 .707 r
F P
0 g
s
.319 .69212 m .32478 .67521 L .31332 .66039 L p .707 .577 .707 r
F P
0 g
s
.69516 .68348 m .70094 .66657 L .72919 .67012 L p .707 .577 .707 r
F P
0 g
s
.30343 .68027 m .29518 .64333 L .28315 .64054 L p .707 .577 .707 r
F P
0 g
s
.312 .61917 m .29958 .56377 L .29705 .55851 L p .707 .577 .707 r
F P
0 g
s
.81507 .70373 m .80929 .72063 L .78341 .70656 L p .707 .577 .707 r
F P
0 g
s
.78341 .70656 m .78919 .68965 L .81507 .70373 L p .707 .577 .707 r
F P
0 g
s
.48187 .72634 m .47609 .74325 L .49221 .73742 L p .707 .577 .707 r
F P
0 g
s
.49221 .73742 m .49799 .72051 L .48187 .72634 L p .707 .577 .707 r
F P
0 g
s
.31332 .66039 m .30754 .6773 L .319 .69212 L p .707 .577 .707 r
F P
0 g
s
.72919 .67012 m .72341 .68703 L .69516 .68348 L p .707 .577 .707 r
F P
0 g
s
.67902 .68453 m .67077 .6476 L .69959 .63913 L p .707 .577 .707 r
F P
0 g
s
.28315 .64054 m .29141 .67747 L .30343 .68027 L p .707 .577 .707 r
F P
0 g
s
.47243 .60235 m .48068 .63929 L .48789 .63205 L p .707 .577 .707 r
F P
0 g
s
.48789 .63205 m .47964 .59512 L .47243 .60235 L p .707 .577 .707 r
F P
0 g
s
.76109 .62672 m .76934 .66366 L .73896 .66887 L p .707 .577 .707 r
F P
0 g
s
.73896 .66887 m .73071 .63193 L .76109 .62672 L p .707 .577 .707 r
F P
0 g
s
.49604 .51823 m .50845 .57363 L .50592 .56837 L p .707 .577 .707 r
F P
0 g
s
.50592 .56837 m .49351 .51297 L .49604 .51823 L p .707 .577 .707 r
F P
0 g
s
.29705 .55851 m .30947 .61391 L .312 .61917 L p .707 .577 .707 r
F P
0 g
s
.69959 .63913 m .70784 .67606 L .67902 .68453 L p .707 .577 .707 r
F P
0 g
s
.72341 .68703 m .72919 .67012 L .7596 .67808 L p .707 .577 .707 r
F P
0 g
s
.78919 .68965 m .78341 .70656 L .75382 .69498 L p .707 .577 .707 r
F P
0 g
s
.75382 .69498 m .7596 .67808 L .78919 .68965 L p .707 .577 .707 r
F P
0 g
s
.70784 .67606 m .69959 .63913 L .73071 .63193 L p .707 .577 .707 r
F P
0 g
s
.73071 .63193 m .73896 .66887 L .70784 .67606 L p .707 .577 .707 r
F P
0 g
s
.7596 .67808 m .75382 .69498 L .72341 .68703 L p .707 .577 .707 r
F P
0 g
s
.30754 .6773 m .31332 .66039 L .31115 .6474 L p .707 .577 .707 r
F P
0 g
s
.29141 .67747 m .28315 .64054 L .28062 .63526 L p .707 .577 .707 r
F P
0 g
s
.31115 .6474 m .30537 .66431 L .30754 .6773 L p .707 .577 .707 r
F P
0 g
s
.49799 .72051 m .49221 .73742 L .49954 .72752 L p .707 .577 .707 r
F P
0 g
s
.49954 .72752 m .50533 .71061 L .49799 .72051 L p .707 .577 .707 r
F P
0 g
s
.30947 .61391 m .29705 .55851 L .30426 .55128 L p .707 .577 .707 r
F P
0 g
s
.28062 .63526 m .28887 .6722 L .29141 .67747 L p .707 .577 .707 r
F P
0 g
s
.47964 .59512 m .48789 .63205 L .48536 .62678 L p .707 .577 .707 r
F P
0 g
s
.48536 .62678 m .4771 .58984 L .47964 .59512 L p .707 .577 .707 r
F P
0 g
s
.49351 .51297 m .50592 .56837 L .4939 .56559 L p .707 .577 .707 r
F P
0 g
s
.4939 .56559 m .48149 .51019 L .49351 .51297 L p .707 .577 .707 r
F P
0 g
s
.30426 .55128 m .31668 .60668 L .30947 .61391 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30537 .66431 m .31115 .6474 L .31848 .63751 L p .707 .577 .707 r
F P
0 g
s
.31848 .63751 m .3127 .65442 L .30537 .66431 L p .707 .577 .707 r
F P
0 g
s
.50533 .71061 m .49954 .72752 L .49737 .71453 L p .707 .577 .707 r
F P
0 g
s
.49737 .71453 m .50316 .69762 L .50533 .71061 L p .707 .577 .707 r
F P
0 g
s
.28887 .6722 m .28062 .63526 L .28783 .62803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31668 .60668 m .30426 .55128 L .3205 .54278 L p .707 .577 .707 r
F P
0 g
s
.28783 .62803 m .29608 .66496 L .28887 .6722 L p .707 .577 .707 r
F P
0 g
s
.4771 .58984 m .48536 .62678 L .47333 .62399 L p .707 .577 .707 r
F P
0 g
s
.47333 .62399 m .46508 .58705 L .4771 .58984 L p .707 .577 .707 r
F P
0 g
s
.48149 .51019 m .4939 .56559 L .47357 .56558 L p .707 .577 .707 r
F P
0 g
s
.47357 .56558 m .46115 .51017 L .48149 .51019 L p .707 .577 .707 r
F P
0 g
s
.3205 .54278 m .33292 .59818 L .31668 .60668 L p .707 .577 .707 r
F P
0 g
s
.3127 .65442 m .31848 .63751 L .3346 .63167 L p .707 .577 .707 r
F P
0 g
s
.3346 .63167 m .32882 .64858 L .3127 .65442 L p .707 .577 .707 r
F P
0 g
s
.50316 .69762 m .49737 .71453 L .48591 .69972 L p .707 .577 .707 r
F P
0 g
s
.48591 .69972 m .49169 .68281 L .50316 .69762 L p .707 .577 .707 r
F P
0 g
s
.33292 .59818 m .3205 .54278 L .34419 .53385 L p .707 .577 .707 r
F P
0 g
s
.29608 .66496 m .28783 .62803 L .30407 .61953 L p .707 .577 .707 r
F P
0 g
s
.46115 .51017 m .47357 .56558 L .44691 .56832 L p .707 .577 .707 r
F P
0 g
s
.44691 .56832 m .43449 .51292 L .46115 .51017 L p .707 .577 .707 r
F P
0 g
s
.30407 .61953 m .31233 .65647 L .29608 .66496 L p .707 .577 .707 r
F P
0 g
s
.46508 .58705 m .47333 .62399 L .45299 .62395 L p .707 .577 .707 r
F P
0 g
s
.45299 .62395 m .44474 .58701 L .46508 .58705 L p .707 .577 .707 r
F P
0 g
s
.34419 .53385 m .3566 .58925 L .33292 .59818 L p .707 .577 .707 r
F P
0 g
s
.32882 .64858 m .3346 .63167 L .35793 .63047 L p .707 .577 .707 r
F P
0 g
s
.3566 .58925 m .34419 .53385 L .373 .52536 L p .707 .577 .707 r
F P
0 g
s
.43449 .51292 m .44691 .56832 L .41653 .57355 L p .707 .577 .707 r
F P
0 g
s
.41653 .57355 m .40412 .51815 L .43449 .51292 L p .707 .577 .707 r
F P
0 g
s
.49169 .68281 m .48591 .69972 L .46628 .68453 L p .707 .577 .707 r
F P
0 g
s
.46628 .68453 m .47206 .66762 L .49169 .68281 L p .707 .577 .707 r
F P
0 g
s
.35793 .63047 m .35214 .64738 L .32882 .64858 L p .707 .577 .707 r
F P
0 g
s
.31233 .65647 m .30407 .61953 L .32776 .61061 L p .707 .577 .707 r
F P
0 g
s
.373 .52536 m .38542 .58076 L .3566 .58925 L p .707 .577 .707 r
F P
0 g
s
.38542 .58076 m .373 .52536 L .40412 .51815 L p .707 .577 .707 r
F P
0 g
s
.40412 .51815 m .41653 .57355 L .38542 .58076 L p .707 .577 .707 r
F P
0 g
s
.44474 .58701 m .45299 .62395 L .42633 .62667 L p .707 .577 .707 r
F P
0 g
s
.42633 .62667 m .41808 .58973 L .44474 .58701 L p .707 .577 .707 r
F P
0 g
s
.32776 .61061 m .33601 .64755 L .31233 .65647 L p .707 .577 .707 r
F P
0 g
s
.35214 .64738 m .35793 .63047 L .38618 .63402 L p .707 .577 .707 r
F P
0 g
s
.47206 .66762 m .46628 .68453 L .4404 .67046 L p .707 .577 .707 r
F P
0 g
s
.4404 .67046 m .44618 .65355 L .47206 .66762 L p .707 .577 .707 r
F P
0 g
s
.33601 .64755 m .32776 .61061 L .35658 .60214 L p .707 .577 .707 r
F P
0 g
s
.38618 .63402 m .3804 .65093 L .35214 .64738 L p .707 .577 .707 r
F P
0 g
s
.41808 .58973 m .42633 .62667 L .39595 .63188 L p .707 .577 .707 r
F P
0 g
s
.39595 .63188 m .3877 .59495 L .41808 .58973 L p .707 .577 .707 r
F P
0 g
s
.35658 .60214 m .36483 .63908 L .33601 .64755 L p .707 .577 .707 r
F P
0 g
s
.3804 .65093 m .38618 .63402 L .41659 .64197 L p .707 .577 .707 r
F P
0 g
s
.44618 .65355 m .4404 .67046 L .41081 .65888 L p .707 .577 .707 r
F P
0 g
s
.41081 .65888 m .41659 .64197 L .44618 .65355 L p .707 .577 .707 r
F P
0 g
s
.36483 .63908 m .35658 .60214 L .3877 .59495 L p .707 .577 .707 r
F P
0 g
s
.3877 .59495 m .39595 .63188 L .36483 .63908 L p .707 .577 .707 r
F P
0 g
s
.41659 .64197 m .41081 .65888 L .3804 .65093 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001XOol00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`<000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH0000C0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`800003FUH005YF00EJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo0P0000=JEP00FUH015YF100000=JEP00FUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00000010001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00HGoo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001OOol30009FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005eoo`80009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
FWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00:Woo2`00<Goo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol80003
FUH00`00FUIJEP03FUH01000FUH00000;goo001EOol20005FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000KOol70003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`03001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Moo`@0
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH^Ool005Aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000COol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/00003FUH0000000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80015oo`800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF1000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Woo0`000eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P002goo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo001EOol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000]Ool005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUIJEP0015YF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01UYF00<005YF00002P000eYF00@005YF000000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF008002aoo`00EWoo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEP00001JEP020005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;7oo001FOol01000FUIJEP0015YF00@005YFFUIJEP8000=JEP03001JEUYF00IJEPD0
0003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000[
Ool005Ioo`04001JEUYF0004FUH01000FUH000001EYF00<005YFFUH00UYF1@001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo
00@005YFFUH000AJEP<000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00:goo001FOol01P00FUIJEUYF001J
EP80009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPX0009JEP03001oogoo02Uoo`00D7oo1`000eYF0P0015YF100000=JEP00FUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
0UYF1@00:Woo001:Ool60004FUH01000FUIJEUYF0P0000=JEP0000000`001EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1P001eYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUH002Yoo`00AWoo100000=JEP00FUH025YF00D005YF000005YF00800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002]oo`00@Goo1@001EYF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP@000QJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00?Goo10000UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001J
EUYF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0
000^Ool003Yoo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH;00000eYF00000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUH0000:0004FUH3000_Ool0
03Qoo`<000UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03
001JEUYF00=JEP@000UJEP03001JEP0000L000=JEP03001JEUYF00=JEP03001JEP0000@0035oo`00
=Woo0P000UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEP00008000AJEP04001JEUYFFUH70004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00<goo000cOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0:0007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000017oo001JEP001EYF0P001eYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH003=oo`00<Goo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF10000eYF00<005YFFUH010001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00
FUH000=JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YF
FUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP<000AJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol002ioo`8000EJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
1EYF00<005YF00000`001eYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YF
FUH20003FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00<Woo000^Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30006FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20003FUH00`00FUH000030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`00
15YF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF1P0035YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF100000=JEP00FUH01eYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<Goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0004
FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH300000eYF001JEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH01000FUH000001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
25YF00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2`0000=JEP00Ool0<7oo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002FUH30002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH40004
FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP02FUH3000aOol002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH50002FUH300000eYF001JEP020006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH500001UYF00000000FUH000MJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000<7oo000^Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YF001J
EP800005FUH005YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH2
0008FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00<7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1EYF1@0025YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00
FUIJEP04FUH20005FUH01000FUIJEP001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0
0000008000QJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00;Woo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00IJEP80009JEP8000AJEP04001JEUYFFUH8
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF10000UYF00<005YFFUH015YF100015YF00<005YFFUH01EYF00@005YFFUIJ
EP80039oo`00;goo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJEP03001JEUYF009JEP/0009J
EP03001JEP0000<00006FUH00000001JEP001UYF00<005YF00000P001EYF00<005YFFUH025YF0`00
1EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01UYF00@005YF
0000009JEP03001JEUYF00EJEP04001JEP00000dOol002moo`04001JEUYF0004FUH01000FUIJEUYF
0P000eYF00<005YFFUH01UYF1@0000=JEP00FUH01UYF0P000UYF00<005YFFUH010000Woo00<005YF
00001UYF1P0015YF00<005YFFUH025YF00<005YF00001UYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEP00001JEP0015YF00<005YFFUH015YF2@0015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP<003Ioo`00;goo00@005YFFUH000AJEP04001JEP000005FUH00`00
FUIJEP02FUH50006FUH00`00FUIJEP04FUH01000FUH000001EYF0P000Woo00<005YF00001UYF1P00
15YF00<005YFFUH025YF00<005YFFUH00P0015YF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH7
0006FUH00`00FUIJEP04FUH20003FUH2000iOol002moo`04001JEUYF0004FUH30006FUH50002FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH01P00Oomoo`00FUH000IJEPH000AJEP03
001JEUYF00QJEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000005FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH01UYF0`00>goo000_Ool01P00FUIJEUYF001JEP80009JEP04001JEUYF
FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF100000=JEP00FUH01EYF
00<005YF00000P001EYF00<005YFFUH025YF00<005YFFUH00eYF0`000eYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH40007FUH01000FUH00000>Woo000`Ool3FUH20004FUH400000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH00`001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000005FUH01000FUIJEUYF0P00>7oo000`Ool015YF000005YF
1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=J
EP00FUH015YF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH00000FUH20007
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500001Woo00000000FUH000IJEP8003Ioo`00<7oo0P00
00EJEP00001JEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<000MJEP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF
00000007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`0cOol0031oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8000QJEP03001JEP00008000UJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000eYF0P001UYF00<005YF
FUH01EYF10003goo0P001UYF0`00<goo000^Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH00UYF
0`001eYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00@001Eoo`80
00=JEP05001JEUYFFUH0000bOol002aoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH;000015YF000000000eYF00<005YFFUH01EYF10000eYF
00<005YFFUH025YF00<005YFFUH025YF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1P000eYF2`002Goo0`003goo0P0000=JEP00FUH00eYF0P00<7oo000ZOol20003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP02
FUH80009FUH00`00FUIJEP04000:FUH00`00FUIJEP07FUH4000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUH00002FUH00`00FUIJEP05000;Ool5000@Ool20006
FUH00`00Oomoo`0]Ool002Uoo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030008FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP05FUH2000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF0P0000=JEP00FUH00eYF0P003Goo1@004Woo00<005YFFUH00eYF0P00
;Woo000XOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02P001eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0009JEP<000AJEP03001JEUYF00MJEP04
001JEUYFFUH<0002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUH000001UYF00<007ooOol02Woo1@004goo00L005YFFUIJEP00FUH0000^
Ool002Qoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04
0007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00Oomoo`00FUH000EJEP<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH01000FUIJEP001UYF0`002goo0`005Goo
00@005YFFUH0009JEP03001oogoo02]oo`00:Goo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000=oo`03
001JEP0000IJEP03001JEP00008000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP05
001JEUYFFUH00004FUH01000FUIJEUYF0P008Woo0P0015YF00<007ooOol0:Woo000YOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUH000030007FUH00`00FUIJEP07FUH30003FUH00`00FUIJEP05
FUH30004Ool00`00FUH00006FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP80025oo`03001JEUYF009JEP03
001oogoo02Yoo`00:Goo00@005YFFUH000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP05FUH20006Ool00`00FUH00006FUH00`00FUIJEP06FUH60004FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF0P0087oo00<005YFFUH00P00;7oo000Y
Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH00eYF1P001eYF00<005YFFUH00eYF
0`0000=JEP0000000P0027oo00<005YF000045YF00<005YFFUH00UYF6P001UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF00<005YF00000P00
7Goo00H005YFFUH005YF000[Ool002Yoo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00@0009JEP03001JEUYF00IJEP8000aoo`03001JEP0000mJEPP000aJEP03001JEUYF00UJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP04001JEP000006FUH0
0`00FUIJEP02FUH3000KOol20002FUH00`00Oomoo`0YOol002Yoo`03001JEP0000=JEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40008FUH3000:Ool00`00FUH0000<FUH30007FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH3000IOol01000
FUIJEP00:goo000ZOol00`00FUIJEP0400000eYF00000007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH40004FUH01000FUIJEUYF0P0027oo00<005YF000025YF10002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF4@0000Eoo`00001JEP00
00UJEP04001JEP00000GOol00`00FUH0000/Ool002Yoo`03001JEUYF00<00003FUH005YF008000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@0009oo`<00003FUH005YF00AJEP8000Ioo`03001JEP00
00EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP8000AJEP03001JEUYF009JEP<000IJEP03001JEUYF009JEP04001JEP000002Ool3
0007FUH00`00FUIJEP02FUH3000COol200000eYF001oo`0[Ool002]oo`03FUH005YF00800005FUH0
05YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20007FUH20004Ool00`00FUH00003
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300000eYF001JEP03FUH30006FUH00`00FUIJEP02FUH01000FUIJEP001Goo0P001EYF
00<005YFFUH01EYF1@0027oo1P0000=JEP000000;Goo000[Ool01P00FUIJEP00FUH000=JEP03001J
EUYF00EJEP03001JEUYF009JEPL000moo`8000EJEP03001JEP0000=oo`04001JEP00FUH30007FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
1000FUH0000015YF0`001UYF00<005YFFUH00eYF0P0027oo0`0000=JEP00FUH025YF00@005YFFUIJ
EPP000=JEP04001JEUYFFUH2000]Ool002]oo`80009JEP8000AJEP04001JEUYFFUH8000HOol20003
FUH00`00FUIJEP0200000goo001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`00
1eYF00@005YFFUIJEP8000aoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002eoo`D0009JEP03001JEP00008000moo`<0011oo`<000EJEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEPD000MJEP04001JEP00000BOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool0035oo`04001JEUYF0002FUH2000>Ool5000AOol00`00FUIJEP04FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40006FUH3000HOol60004FUH00`00FUIJEP03FUH0
1000FUH00000<Goo000bOol20005FUH00`00Oomoo`0;Ool5000BOol00`00FUIJEP03FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH50003FUH2000QOol<000cOol003=oo`03001JEUYF00AJEP03
001oogoo00Yoo`D001=oo`03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP00009JEP<0069oo`00=7oo00<005YFFUH00eYF0`002goo0`005Goo00H005YFFUH005YF0004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH3001QOol003Eoo`03001JEUYF009J
EP03001JEUYF0080029oo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=J
EP04001JEUYFFUH2001OOol003Ioo`800003FUH005YF00AJEP80029oo`04001JEUYF0003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH2001MOol003Qoo`8000MJEP<0021o
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001oogoo
05Yoo`00>Goo00<005YFFUH01UYF00@005YF000001ioo`03001JEUYF00@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000QJEP<005Yoo`00>Woo0P001EYF00<005YFFUH00UYF0`0077oo0P0000=JEP00Ool0
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP8000Ioo`8000IJEP04001JEUYF001IOol003aoo`8000=JEP03001JEUYF
00EJEP<001Yoo`03001JEP0000=oo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000:Ool20003FUH00`00FUIJEP02FUH2
001GOol003ioo`<000UJEP03001JEP00008001Moo`03001JEP0000Moo`D000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000ioo`800003FUH005YF00EJEP03
001oogoo05Aoo`00@7oo0P0025YF00<005YFFUH00UYF0`004Woo10003Goo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02@0047oo0P001UYF0P00EGoo0012Ool3
0004FUH00`00FUIJEP06FUH50008Ool5000015YF001JEP004goo2@001UYF00<005YFFUH02UYF00<0
05YFFUH00eYF200017oo1@004Woo00<005YFFUH00UYF00<005YF0000EGoo0015Ool300000eYF001J
EP07FUH00`00FUIJEP02FUH80002FUH01`00FUIJEUYF001JEP0001aooa/000Yoo`D001=oo`80009J
EP04001JEUYF001DOol004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0
02moo`03001JEUYF009JEP04001JEUYFFUH20009Ool3000FOol20004FUH00`00Oomoo`1AOol004]o
o`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol20002FUH00`00FUIJ
EP03FUH2000QOol00`00FUIJEP02FUH00`00Oomoo`1AOol004moo`H000AJEP03001JEUYF00AJEP04
001JEP00000eOol20008FUH2000POol00`00FUIJEP02001COol005Eoo`d003Qoo`03001JEUYF00IJ
EP04001JEP00000NOol01P00FUIJEP00FUH0059oo`00Vgoo0P001UYF00@005YFFUIJEP8001eoo`80
009JEP03001oogoo051oo`00WGoo0P000eYF00<005YFFUH015YF0P0077oo00@005YFFUH0059oo`00
Wgoo0P0000=JEP00FUH01eYF0`006Goo00<005YF0000Dgoo002QOol30007FUH00`00FUIJEP04000D
Ool200000eYF001oo`1BOol00:Aoo`8000EJEP03001JEUYF00AJEPH000Qoo`H0009JEP03001oogoo
059oo`00YWoo0`0000=JEP00FUH025YF00@005YFFUIJEPP000=JEP04001JEUYFFUH2001DOol00:Uo
o`<000QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05=oo`00[7oo
0`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00[goo0`0000=JEP00
FUH01UYF00<005YFFUH00eYF00<005YFFUH00`00EWoo002bOol50004FUH01000FUIJEUYF1@00FGoo
002gOol8001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60318 .7456 m .59546 .68977 L .56459 .69228 L p .707 .577 .707 r
F P
0 g
s
.59546 .68977 m .60318 .7456 L .63474 .74084 L p .707 .577 .707 r
F P
0 g
s
.63474 .74084 m .62702 .68501 L .59546 .68977 L p .707 .577 .707 r
F P
0 g
s
.62702 .68501 m .63474 .74084 L .6639 .7343 L p .707 .577 .707 r
F P
0 g
s
.6639 .7343 m .65618 .67847 L .62702 .68501 L p .707 .577 .707 r
F P
0 g
s
.57231 .74811 m .56459 .69228 L .53744 .6923 L p .707 .577 .707 r
F P
0 g
s
.56459 .69228 m .57231 .74811 L .60318 .7456 L p .707 .577 .707 r
F P
0 g
s
.65618 .67847 m .6639 .7343 L .68781 .72662 L p .707 .577 .707 r
F P
0 g
s
.68781 .72662 m .68009 .67079 L .65618 .67847 L p .707 .577 .707 r
F P
0 g
s
.53744 .6923 m .54516 .74813 L .57231 .74811 L p .707 .577 .707 r
F P
0 g
s
.54516 .74813 m .53744 .6923 L .51666 .68983 L p .707 .577 .707 r
F P
0 g
s
.59045 .80474 m .58532 .76752 L .55445 .77002 L p .707 .577 .707 r
F P
0 g
s
.58532 .76752 m .59045 .80474 L .62201 .79999 L p .707 .577 .707 r
F P
0 g
s
.62201 .79999 m .61688 .76277 L .58532 .76752 L p .707 .577 .707 r
F P
0 g
s
.61688 .76277 m .62201 .79999 L .65118 .79346 L p .707 .577 .707 r
F P
0 g
s
.65118 .79346 m .64605 .75624 L .61688 .76277 L p .707 .577 .707 r
F P
0 g
s
.68009 .67079 m .68781 .72662 L .70413 .71856 L p .707 .577 .707 r
F P
0 g
s
.70413 .71856 m .69642 .66273 L .68009 .67079 L p .707 .577 .707 r
F P
0 g
s
.55958 .80724 m .55445 .77002 L .5273 .77003 L p .707 .577 .707 r
F P
0 g
s
.55445 .77002 m .55958 .80724 L .59045 .80474 L p .707 .577 .707 r
F P
0 g
s
.51666 .68983 m .52438 .74566 L .54516 .74813 L p .707 .577 .707 r
F P
0 g
s
.59881 .85772 m .60243 .83997 L .57186 .83198 L p .707 .577 .707 r
F P
0 g
s
.60243 .83997 m .59881 .85772 L .6301 .86244 L p .707 .577 .707 r
F P
0 g
s
.6301 .86244 m .63371 .84468 L .60243 .83997 L p .707 .577 .707 r
F P
0 g
s
.64605 .75624 m .65118 .79346 L .67509 .78579 L p .707 .577 .707 r
F P
0 g
s
.67509 .78579 m .66996 .74857 L .64605 .75624 L p .707 .577 .707 r
F P
0 g
s
.5273 .77003 m .53243 .80725 L .55958 .80724 L p .707 .577 .707 r
F P
0 g
s
.63371 .84468 m .6301 .86244 L .65905 .86342 L p .707 .577 .707 r
F P
0 g
s
.65905 .86342 m .66266 .84567 L .63371 .84468 L p .707 .577 .707 r
F P
0 g
s
.56825 .84973 m .57186 .83198 L .54501 .82149 L p .707 .577 .707 r
F P
0 g
s
.57186 .83198 m .56825 .84973 L .59881 .85772 L p .707 .577 .707 r
F P
0 g
s
.52438 .74566 m .51666 .68983 L .50429 .68511 L p .707 .577 .707 r
F P
0 g
s
.54501 .82149 m .5414 .83925 L .56825 .84973 L p .707 .577 .707 r
F P
0 g
s
.53243 .80725 m .5273 .77003 L .50652 .76754 L p .707 .577 .707 r
F P
0 g
s
.66266 .84567 m .65905 .86342 L .68282 .86057 L p .707 .577 .707 r
F P
0 g
s
.68282 .86057 m .68644 .84281 L .66266 .84567 L p .707 .577 .707 r
F P
0 g
s
.5414 .83925 m .54501 .82149 L .5245 .80955 L p .707 .577 .707 r
F P
0 g
s
.66996 .74857 m .67509 .78579 L .69141 .77773 L p .707 .577 .707 r
F P
0 g
s
.69141 .77773 m .68628 .74051 L .66996 .74857 L p .707 .577 .707 r
F P
0 g
s
.50652 .76754 m .51165 .80477 L .53243 .80725 L p .707 .577 .707 r
F P
0 g
s
.69642 .66273 m .70413 .71856 L .71126 .71089 L p .707 .577 .707 r
F P
0 g
s
.71126 .71089 m .70355 .65506 L .69642 .66273 L p .707 .577 .707 r
F P
0 g
s
.50429 .68511 m .512 .74094 L .52438 .74566 L p .707 .577 .707 r
F P
0 g
s
.5245 .80955 m .52089 .8273 L .5414 .83925 L p .707 .577 .707 r
F P
0 g
s
.51165 .80477 m .50652 .76754 L .49414 .76281 L p .707 .577 .707 r
F P
0 g
s
.512 .74094 m .50429 .68511 L .50153 .67859 L p .707 .577 .707 r
F P
0 g
s
.68644 .84281 m .68282 .86057 L .6991 .85417 L p .707 .577 .707 r
F P
0 g
s
.6991 .85417 m .70271 .83641 L .68644 .84281 L p .707 .577 .707 r
F P
0 g
s
.52089 .8273 m .5245 .80955 L .51234 .7973 L p .707 .577 .707 r
F P
0 g
s
.49414 .76281 m .49927 .80003 L .51165 .80477 L p .707 .577 .707 r
F P
0 g
s
.68628 .74051 m .69141 .77773 L .69854 .77006 L p .707 .577 .707 r
F P
0 g
s
.69854 .77006 m .69341 .73284 L .68628 .74051 L p .707 .577 .707 r
F P
0 g
s
.51234 .7973 m .50873 .81506 L .52089 .8273 L p .707 .577 .707 r
F P
0 g
s
.70355 .65506 m .71126 .71089 L .70851 .70438 L p .707 .577 .707 r
F P
0 g
s
.70851 .70438 m .70079 .64855 L .70355 .65506 L p .707 .577 .707 r
F P
0 g
s
.50153 .67859 m .50925 .73442 L .512 .74094 L p .707 .577 .707 r
F P
0 g
s
.48793 .82189 m .4916 .32041 L .44759 .3174 L p .707 .577 .707 r
F P
0 g
s
.49927 .80003 m .49414 .76281 L .49139 .75629 L p .707 .577 .707 r
F P
0 g
s
.50873 .81506 m .51234 .7973 L .50972 .78596 L p .707 .577 .707 r
F P
0 g
s
.50925 .73442 m .50153 .67859 L .50866 .67093 L p .707 .577 .707 r
F P
0 g
s
.49139 .75629 m .49652 .79351 L .49927 .80003 L p .707 .577 .707 r
F P
0 g
s
.50972 .78596 m .50611 .80372 L .50873 .81506 L p .707 .577 .707 r
F P
0 g
s
.50866 .67093 m .51638 .72676 L .50925 .73442 L p .707 .577 .707 r
F P
0 g
s
.49652 .79351 m .49139 .75629 L .49852 .74862 L p .707 .577 .707 r
F P
0 g
s
.50611 .80372 m .50972 .78596 L .5169 .77663 L p .707 .577 .707 r
F P
0 g
s
.51638 .72676 m .50866 .67093 L .52498 .66286 L p .707 .577 .707 r
F P
0 g
s
.5169 .77663 m .51329 .79439 L .50611 .80372 L p .707 .577 .707 r
F P
0 g
s
.49852 .74862 m .50365 .78584 L .49652 .79351 L p .707 .577 .707 r
F P
0 g
s
.52498 .66286 m .5327 .71869 L .51638 .72676 L p .707 .577 .707 r
F P
0 g
s
.50365 .78584 m .49852 .74862 L .51484 .74056 L p .707 .577 .707 r
F P
0 g
s
.51329 .79439 m .5169 .77663 L .53318 .77023 L p .707 .577 .707 r
F P
0 g
s
.53318 .77023 m .52956 .78799 L .51329 .79439 L p .707 .577 .707 r
F P
0 g
s
.51484 .74056 m .51997 .77778 L .50365 .78584 L p .707 .577 .707 r
F P
0 g
s
.51997 .77778 m .51484 .74056 L .53875 .73289 L p .707 .577 .707 r
F P
0 g
s
.52956 .78799 m .53318 .77023 L .55695 .76738 L p .707 .577 .707 r
F P
0 g
s
.55695 .76738 m .55334 .78514 L .52956 .78799 L p .707 .577 .707 r
F P
0 g
s
.53875 .73289 m .54388 .77011 L .51997 .77778 L p .707 .577 .707 r
F P
0 g
s
.4916 .32041 m .48793 .82189 L .53287 .82108 L p .707 .577 .707 r
F P
0 g
s
.5327 .71869 m .52498 .66286 L .5489 .65518 L p .707 .577 .707 r
F P
0 g
s
.5489 .65518 m .55661 .71101 L .5327 .71869 L p .707 .577 .707 r
F P
0 g
s
.53287 .82108 m .53654 .3196 L .4916 .32041 L p .707 .577 .707 r
F P
0 g
s
.70271 .83641 m .6991 .85417 L .70628 .84484 L p .707 .577 .707 r
F P
0 g
s
.70628 .84484 m .70989 .82708 L .70271 .83641 L p .707 .577 .707 r
F P
0 g
s
.55661 .71101 m .5489 .65518 L .57806 .64864 L p .707 .577 .707 r
F P
0 g
s
.57806 .64864 m .58578 .70448 L .55661 .71101 L p .707 .577 .707 r
F P
0 g
s
.54388 .77011 m .53875 .73289 L .56792 .72636 L p .707 .577 .707 r
F P
0 g
s
.55334 .78514 m .55695 .76738 L .5859 .76836 L p .707 .577 .707 r
F P
0 g
s
.56792 .72636 m .57305 .76358 L .54388 .77011 L p .707 .577 .707 r
F P
0 g
s
.5859 .76836 m .58229 .78612 L .55334 .78514 L p .707 .577 .707 r
F P
0 g
s
.53654 .3196 m .53287 .82108 L .57435 .81655 L p .707 .577 .707 r
F P
0 g
s
.57305 .76358 m .56792 .72636 L .59948 .72161 L p .707 .577 .707 r
F P
0 g
s
.59948 .72161 m .60461 .75883 L .57305 .76358 L p .707 .577 .707 r
F P
0 g
s
.57435 .81655 m .57802 .31507 L .53654 .3196 L p .707 .577 .707 r
F P
0 g
s
.44392 .81888 m .44759 .3174 L .40883 .31087 L p .707 .577 .707 r
F P
0 g
s
.44759 .3174 m .44392 .81888 L .48793 .82189 L p .707 .577 .707 r
F P
0 g
s
.69341 .73284 m .69854 .77006 L .69579 .76354 L p .707 .577 .707 r
F P
0 g
s
.69579 .76354 m .69066 .72632 L .69341 .73284 L p .707 .577 .707 r
F P
0 g
s
.70079 .64855 m .70851 .70438 L .69613 .69965 L p .707 .577 .707 r
F P
0 g
s
.69613 .69965 m .68842 .64382 L .70079 .64855 L p .707 .577 .707 r
F P
0 g
s
.58578 .70448 m .57806 .64864 L .60962 .64389 L p .707 .577 .707 r
F P
0 g
s
.60962 .64389 m .61733 .69972 L .58578 .70448 L p .707 .577 .707 r
F P
0 g
s
.63035 .71911 m .63548 .75633 L .60461 .75883 L p .707 .577 .707 r
F P
0 g
s
.60461 .75883 m .59948 .72161 L .63035 .71911 L p .707 .577 .707 r
F P
0 g
s
.58229 .78612 m .5859 .76836 L .61719 .77308 L p .707 .577 .707 r
F P
0 g
s
.61719 .77308 m .61357 .79083 L .58229 .78612 L p .707 .577 .707 r
F P
0 g
s
.57802 .31507 m .57435 .81655 L .60831 .80872 L p .707 .577 .707 r
F P
0 g
s
.60831 .80872 m .61198 .30724 L .57802 .31507 L p .707 .577 .707 r
F P
0 g
s
.26017 .70875 m .25245 .65292 L .22158 .65543 L p .707 .577 .707 r
F P
0 g
s
.25245 .65292 m .26017 .70875 L .29173 .70399 L p .707 .577 .707 r
F P
0 g
s
.29173 .70399 m .28401 .64816 L .25245 .65292 L p .707 .577 .707 r
F P
0 g
s
.40516 .81235 m .40883 .31087 L .3791 .30147 L p .707 .577 .707 r
F P
0 g
s
.40883 .31087 m .40516 .81235 L .44392 .81888 L p .707 .577 .707 r
F P
0 g
s
.28401 .64816 m .29173 .70399 L .32089 .69745 L p .707 .577 .707 r
F P
0 g
s
.32089 .69745 m .31317 .64162 L .28401 .64816 L p .707 .577 .707 r
F P
0 g
s
.70989 .82708 m .70628 .84484 L .70366 .8335 L p .707 .577 .707 r
F P
0 g
s
.70366 .8335 m .70727 .81574 L .70989 .82708 L p .707 .577 .707 r
F P
0 g
s
.2293 .71126 m .22158 .65543 L .19443 .65545 L p .707 .577 .707 r
F P
0 g
s
.22158 .65543 m .2293 .71126 L .26017 .70875 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31317 .64162 m .32089 .69745 L .3448 .68977 L p .707 .577 .707 r
F P
0 g
s
.3448 .68977 m .33709 .63394 L .31317 .64162 L p .707 .577 .707 r
F P
0 g
s
.69066 .72632 m .69579 .76354 L .68341 .75881 L p .707 .577 .707 r
F P
0 g
s
.68341 .75881 m .67828 .72159 L .69066 .72632 L p .707 .577 .707 r
F P
0 g
s
.68842 .64382 m .69613 .69965 L .67535 .69718 L p .707 .577 .707 r
F P
0 g
s
.67535 .69718 m .66764 .64135 L .68842 .64382 L p .707 .577 .707 r
F P
0 g
s
.64049 .64137 m .6482 .6972 L .61733 .69972 L p .707 .577 .707 r
F P
0 g
s
.61733 .69972 m .60962 .64389 L .64049 .64137 L p .707 .577 .707 r
F P
0 g
s
.64775 .78107 m .64414 .79882 L .61357 .79083 L p .707 .577 .707 r
F P
0 g
s
.61357 .79083 m .61719 .77308 L .64775 .78107 L p .707 .577 .707 r
F P
0 g
s
.61198 .30724 m .60831 .80872 L .63142 .79837 L p .707 .577 .707 r
F P
0 g
s
.63548 .75633 m .63035 .71911 L .6575 .7191 L p .707 .577 .707 r
F P
0 g
s
.63142 .79837 m .63509 .29689 L .61198 .30724 L p .707 .577 .707 r
F P
0 g
s
.19443 .65545 m .20215 .71128 L .2293 .71126 L p .707 .577 .707 r
F P
0 g
s
.20215 .71128 m .19443 .65545 L .17365 .65298 L p .707 .577 .707 r
F P
0 g
s
.24744 .76782 m .24231 .7306 L .21145 .7331 L p .707 .577 .707 r
F P
0 g
s
.24231 .7306 m .24744 .76782 L .279 .76307 L p .707 .577 .707 r
F P
0 g
s
.279 .76307 m .27388 .72585 L .24231 .7306 L p .707 .577 .707 r
F P
0 g
s
.27388 .72585 m .279 .76307 L .30817 .75654 L p .707 .577 .707 r
F P
0 g
s
.30817 .75654 m .30304 .71932 L .27388 .72585 L p .707 .577 .707 r
F P
0 g
s
.70727 .81574 m .70366 .8335 L .6915 .82125 L p .707 .577 .707 r
F P
0 g
s
.6915 .82125 m .69511 .8035 L .70727 .81574 L p .707 .577 .707 r
F P
0 g
s
.33709 .63394 m .3448 .68977 L .36112 .68171 L p .707 .577 .707 r
F P
0 g
s
.36112 .68171 m .35341 .62587 L .33709 .63394 L p .707 .577 .707 r
F P
0 g
s
.21657 .77032 m .21145 .7331 L .18429 .73311 L p .707 .577 .707 r
F P
0 g
s
.21145 .7331 m .21657 .77032 L .24744 .76782 L p .707 .577 .707 r
F P
0 g
s
.37544 .80295 m .3791 .30147 L .36133 .2901 L p .707 .577 .707 r
F P
0 g
s
.3791 .30147 m .37544 .80295 L .40516 .81235 L p .707 .577 .707 r
F P
0 g
s
.17365 .65298 m .18137 .70881 L .20215 .71128 L p .707 .577 .707 r
F P
0 g
s
.30304 .71932 m .30817 .75654 L .33208 .74887 L p .707 .577 .707 r
F P
0 g
s
.33208 .74887 m .32695 .71165 L .30304 .71932 L p .707 .577 .707 r
F P
0 g
s
.2558 .82135 m .25942 .80359 L .22885 .7956 L p .707 .577 .707 r
F P
0 g
s
.25942 .80359 m .2558 .82135 L .28709 .82607 L p .707 .577 .707 r
F P
0 g
s
.28709 .82607 m .29071 .80831 L .25942 .80359 L p .707 .577 .707 r
F P
0 g
s
.66764 .64135 m .67535 .69718 L .6482 .6972 L p .707 .577 .707 r
F P
0 g
s
.6482 .6972 m .64049 .64137 L .66764 .64135 L p .707 .577 .707 r
F P
0 g
s
.18429 .73311 m .18942 .77033 L .21657 .77032 L p .707 .577 .707 r
F P
0 g
s
.67828 .72159 m .68341 .75881 L .66263 .75632 L p .707 .577 .707 r
F P
0 g
s
.66263 .75632 m .6575 .7191 L .67828 .72159 L p .707 .577 .707 r
F P
0 g
s
.29071 .80831 m .28709 .82607 L .31604 .82705 L p .707 .577 .707 r
F P
0 g
s
.31604 .82705 m .31965 .80929 L .29071 .80831 L p .707 .577 .707 r
F P
0 g
s
.22524 .81336 m .22885 .7956 L .202 .78512 L p .707 .577 .707 r
F P
0 g
s
.22885 .7956 m .22524 .81336 L .2558 .82135 L p .707 .577 .707 r
F P
0 g
s
.18137 .70881 m .17365 .65298 L .16128 .64825 L p .707 .577 .707 r
F P
0 g
s
.202 .78512 m .19839 .80288 L .22524 .81336 L p .707 .577 .707 r
F P
0 g
s
.18942 .77033 m .18429 .73311 L .16351 .73062 L p .707 .577 .707 r
F P
0 g
s
.6575 .7191 m .66263 .75632 L .63548 .75633 L p .707 .577 .707 r
F P
0 g
s
.63509 .29689 m .63142 .79837 L .64142 .78651 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .64508 .28503 L .63509 .29689 L p .707 .577 .707 r
F P
0 g
s
.31965 .80929 m .31604 .82705 L .33981 .8242 L p .707 .577 .707 r
F P
0 g
s
.33981 .8242 m .34343 .80644 L .31965 .80929 L p .707 .577 .707 r
F P
0 g
s
.19839 .80288 m .202 .78512 L .18149 .77317 L p .707 .577 .707 r
F P
0 g
s
.32695 .71165 m .33208 .74887 L .3484 .74081 L p .707 .577 .707 r
F P
0 g
s
.3484 .74081 m .34327 .70359 L .32695 .71165 L p .707 .577 .707 r
F P
0 g
s
.16351 .73062 m .16864 .76785 L .18942 .77033 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35724 .27789 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.35341 .62587 m .36112 .68171 L .36644 .67599 L p .707 .577 .707 r
F P
0 g
s
.36614 .66717 m .35341 .62587 L .36644 .67599 L .707 .577 .707 r
F
.36825 .67404 m .36054 .61821 L .35341 .62587 L p F P
0 g
s
.35778 .6117 m .36054 .61821 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.3655 .66753 m .36285 .64836 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .35778 .6117 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.35778 .6117 m .36285 .64836 L p .35312 .6628 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .3655 .66753 L .36207 .66622 L p .707 .577 .707 r
F P
0 g
s
.36207 .66622 m .35312 .6628 L p .36285 .64836 L .707 .577 .707 r
F P
0 g
s
.34327 .70359 m .3484 .74081 L .35553 .73314 L p .707 .577 .707 r
F P
0 g
s
.35553 .73314 m .35041 .69592 L .34327 .70359 L p .707 .577 .707 r
F P
0 g
s
.35041 .69592 m .35553 .73314 L .35278 .72662 L p .707 .577 .707 r
F P
0 g
s
.35312 .6628 m .34541 .60697 L .35778 .6117 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .34849 .78488 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.36426 .77937 m .3618 .79145 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.3618 .79145 m .36065 .79712 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .3521 .76712 L .36135 .77643 L p .707 .577 .707 r
F P
0 g
s
.36135 .77643 m .36426 .77937 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .36135 .77643 L .36147 .78034 L .707 .577 .707 r
F
.35764 .76737 m .35754 .65014 L .3567 .78873 L F
.35754 .65014 m .35724 .27789 L .35687 .62788 L F
.35754 .65014 m .35687 .62788 L .3567 .78873 L F
.35357 .77937 m .3567 .78873 L p .35687 .62788 L F P
0 g
s
.35724 .27789 m .35511 .56932 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.35511 .56932 m .35357 .77937 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.3567 .78873 m .35766 .79158 L p .35764 .76737 L .707 .577 .707 r
F P
0 g
s
.35753 .63446 m .3599 .48527 L .35735 .41085 L .707 .577 .707 r
F
.35766 .79158 m .35878 .63774 L p .35753 .63446 L F P
0 g
s
.35878 .63774 m .3599 .48527 L p .35753 .63446 L .707 .577 .707 r
F P
0 g
s
.3599 .48527 m .36133 .2901 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.36644 .67599 m .36825 .67404 L p .36614 .66717 L .707 .577 .707 r
F P
0 g
s
.69511 .8035 m .6915 .82125 L .67099 .80931 L p .707 .577 .707 r
F P
0 g
s
.67099 .80931 m .6746 .79155 L .69511 .8035 L p .707 .577 .707 r
F P
0 g
s
.16128 .64825 m .16899 .70409 L .18137 .70881 L p .707 .577 .707 r
F P
0 g
s
.18149 .77317 m .17788 .79093 L .19839 .80288 L p .707 .577 .707 r
F P
0 g
s
.36054 .61821 m .36825 .67404 L .3655 .66753 L p .707 .577 .707 r
F P
0 g
s
.36327 .80846 m .36688 .79071 L .3597 .80004 L p .707 .577 .707 r
F P
0 g
s
.36688 .79071 m .36327 .80846 L .36065 .79712 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .36426 .77937 L .36688 .79071 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35766 .79158 L .37544 .80295 L p .707 .577 .707 r
F P
0 g
s
.16864 .76785 m .16351 .73062 L .15114 .72589 L p .707 .577 .707 r
F P
0 g
s
.16899 .70409 m .16128 .64825 L .15852 .64174 L p .707 .577 .707 r
F P
0 g
s
.34343 .80644 m .33981 .8242 L .35609 .81779 L p .707 .577 .707 r
F P
0 g
s
.35609 .81779 m .3597 .80004 L .34343 .80644 L p .707 .577 .707 r
F P
0 g
s
.17788 .79093 m .18149 .77317 L .16933 .76093 L p .707 .577 .707 r
F P
0 g
s
.6746 .79155 m .67099 .80931 L .64414 .79882 L p .707 .577 .707 r
F P
0 g
s
.64414 .79882 m .64775 .78107 L .6746 .79155 L p .707 .577 .707 r
F P
0 g
s
.15114 .72589 m .15626 .76311 L .16864 .76785 L p .707 .577 .707 r
F P
0 g
s
.16933 .76093 m .16572 .77869 L .17788 .79093 L p .707 .577 .707 r
F P
0 g
s
.15852 .64174 m .16624 .69757 L .16899 .70409 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .63733 .7743 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.64381 .45978 m .64142 .78651 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .64508 .28503 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63733 .7743 m .63879 .5747 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63879 .5747 m .641 .27282 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .63733 .7743 L .61955 .76294 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .64885 .71273 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63135 .67077 m .63381 .68866 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63381 .68866 m .63648 .70799 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .64372 .67551 L .63454 .67199 L p .707 .577 .707 r
F P
0 g
s
.63454 .67199 m .63135 .67077 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .63454 .67199 L .63429 .67782 L .707 .577 .707 r
F
.64508 .28503 m .64381 .45978 L p .64146 .51343 L F P
0 g
s
.15626 .76311 m .15114 .72589 L .14838 .71937 L p .707 .577 .707 r
F P
0 g
s
.3597 .80004 m .35609 .81779 L .36327 .80846 L p .707 .577 .707 r
F P
0 g
s
.16572 .77869 m .16933 .76093 L .16672 .74959 L p .707 .577 .707 r
F P
0 g
s
.16624 .69757 m .15852 .64174 L .16565 .63408 L p .707 .577 .707 r
F P
0 g
s
.14838 .71937 m .15351 .75659 L .15626 .76311 L p .707 .577 .707 r
F P
0 g
s
.16672 .74959 m .1631 .76734 L .16572 .77869 L p .707 .577 .707 r
F P
0 g
s
.35278 .72662 m .34765 .6894 L .35041 .69592 L p .707 .577 .707 r
F P
0 g
s
.35357 .77937 m .35724 .27789 L .36724 .26603 L p .707 .577 .707 r
F P
0 g
s
.16565 .63408 m .17337 .68991 L .16624 .69757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15351 .75659 m .14838 .71937 L .15551 .7117 L p .707 .577 .707 r
F P
0 g
s
.1631 .76734 m .16672 .74959 L .17389 .74026 L p .707 .577 .707 r
F P
0 g
s
.17337 .68991 m .16565 .63408 L .18197 .62601 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17389 .74026 m .17028 .75801 L .1631 .76734 L p .707 .577 .707 r
F P
0 g
s
.61955 .76294 m .62322 .26146 L .641 .27282 L p .707 .577 .707 r
F P
0 g
s
.15551 .7117 m .16064 .74892 L .15351 .75659 L p .707 .577 .707 r
F P
0 g
s
.34765 .6894 m .35278 .72662 L .3404 .72189 L p .707 .577 .707 r
F P
0 g
s
.3404 .72189 m .33527 .68467 L .34765 .6894 L p .707 .577 .707 r
F P
0 g
s
.34541 .60697 m .35312 .6628 L .33234 .66033 L p .707 .577 .707 r
F P
0 g
s
.33234 .66033 m .32463 .6045 L .34541 .60697 L p .707 .577 .707 r
F P
0 g
s
.18197 .62601 m .18969 .68184 L .17337 .68991 L p .707 .577 .707 r
F P
0 g
s
.36357 .76751 m .36724 .26603 L .39035 .25568 L p .707 .577 .707 r
F P
0 g
s
.36724 .26603 m .36357 .76751 L .35357 .77937 L p .707 .577 .707 r
F P
0 g
s
.16064 .74892 m .15551 .7117 L .17183 .70364 L p .707 .577 .707 r
F P
0 g
s
.17028 .75801 m .17389 .74026 L .19017 .73386 L p .707 .577 .707 r
F P
0 g
s
.18969 .68184 m .18197 .62601 L .20589 .61833 L p .707 .577 .707 r
F P
0 g
s
.19017 .73386 m .18655 .75161 L .17028 .75801 L p .707 .577 .707 r
F P
0 g
s
.17183 .70364 m .17696 .74086 L .16064 .74892 L p .707 .577 .707 r
F P
0 g
s
.32463 .6045 m .33234 .66033 L .30519 .66035 L p .707 .577 .707 r
F P
0 g
s
.30519 .66035 m .29748 .60452 L .32463 .6045 L p .707 .577 .707 r
F P
0 g
s
.33527 .68467 m .3404 .72189 L .31962 .7194 L p .707 .577 .707 r
F P
0 g
s
.31962 .7194 m .31449 .68218 L .33527 .68467 L p .707 .577 .707 r
F P
0 g
s
.20589 .61833 m .2136 .67416 L .18969 .68184 L p .707 .577 .707 r
F P
0 g
s
.62322 .26146 m .61955 .76294 L .58983 .75353 L p .707 .577 .707 r
F P
0 g
s
.58983 .75353 m .5935 .25205 L .62322 .26146 L p .707 .577 .707 r
F P
0 g
s
.2136 .67416 m .20589 .61833 L .23505 .61179 L p .707 .577 .707 r
F P
0 g
s
.29748 .60452 m .30519 .66035 L .27433 .66286 L p .707 .577 .707 r
F P
0 g
s
.27433 .66286 m .26661 .60703 L .29748 .60452 L p .707 .577 .707 r
F P
0 g
s
.3521 .76712 m .34849 .78488 L .32798 .77293 L p .707 .577 .707 r
F P
0 g
s
.32798 .77293 m .3316 .75518 L .3521 .76712 L p .707 .577 .707 r
F P
0 g
s
.17696 .74086 m .17183 .70364 L .19574 .69597 L p .707 .577 .707 r
F P
0 g
s
.18655 .75161 m .19017 .73386 L .21394 .731 L p .707 .577 .707 r
F P
0 g
s
.24277 .66762 m .23505 .61179 L .26661 .60703 L p .707 .577 .707 r
F P
0 g
s
.23505 .61179 m .24277 .66762 L .2136 .67416 L p .707 .577 .707 r
F P
0 g
s
.39035 .25568 m .38668 .75716 L .36357 .76751 L p .707 .577 .707 r
F P
0 g
s
.38668 .75716 m .39035 .25568 L .4243 .24786 L p .707 .577 .707 r
F P
0 g
s
.74038 .65356 m .73266 .59773 L .7018 .60024 L p .707 .577 .707 r
F P
0 g
s
.73266 .59773 m .74038 .65356 L .77194 .6488 L p .707 .577 .707 r
F P
0 g
s
.77194 .6488 m .76422 .59297 L .73266 .59773 L p .707 .577 .707 r
F P
0 g
s
.26661 .60703 m .27433 .66286 L .24277 .66762 L p .707 .577 .707 r
F P
0 g
s
.21394 .731 m .21033 .74876 L .18655 .75161 L p .707 .577 .707 r
F P
0 g
s
.31449 .68218 m .31962 .7194 L .29247 .71941 L p .707 .577 .707 r
F P
0 g
s
.29247 .71941 m .28734 .68219 L .31449 .68218 L p .707 .577 .707 r
F P
0 g
s
.19574 .69597 m .20087 .73319 L .17696 .74086 L p .707 .577 .707 r
F P
0 g
s
.76422 .59297 m .77194 .6488 L .8011 .64226 L p .707 .577 .707 r
F P
0 g
s
.8011 .64226 m .79339 .58643 L .76422 .59297 L p .707 .577 .707 r
F P
0 g
s
.70951 .65608 m .7018 .60024 L .67464 .60027 L p .707 .577 .707 r
F P
0 g
s
.7018 .60024 m .70951 .65608 L .74038 .65356 L p .707 .577 .707 r
F P
0 g
s
.20087 .73319 m .19574 .69597 L .22491 .68944 L p .707 .577 .707 r
F P
0 g
s
.79339 .58643 m .8011 .64226 L .82502 .63459 L p .707 .577 .707 r
F P
0 g
s
.82502 .63459 m .8173 .57876 L .79339 .58643 L p .707 .577 .707 r
F P
0 g
s
.3316 .75518 m .32798 .77293 L .30113 .76245 L p .707 .577 .707 r
F P
0 g
s
.30113 .76245 m .30474 .74469 L .3316 .75518 L p .707 .577 .707 r
F P
0 g
s
.21033 .74876 m .21394 .731 L .24289 .73199 L p .707 .577 .707 r
F P
0 g
s
.5935 .25205 m .58983 .75353 L .55107 .74701 L p .707 .577 .707 r
F P
0 g
s
.55107 .74701 m .55473 .24552 L .5935 .25205 L p .707 .577 .707 r
F P
0 g
s
.28734 .68219 m .29247 .71941 L .2616 .72191 L p .707 .577 .707 r
F P
0 g
s
.2616 .72191 m .25647 .68469 L .28734 .68219 L p .707 .577 .707 r
F P
0 g
s
.67464 .60027 m .68236 .6561 L .70951 .65608 L p .707 .577 .707 r
F P
0 g
s
.22491 .68944 m .23004 .72666 L .20087 .73319 L p .707 .577 .707 r
F P
0 g
s
.24289 .73199 m .23928 .74974 L .21033 .74876 L p .707 .577 .707 r
F P
0 g
s
.23004 .72666 m .22491 .68944 L .25647 .68469 L p .707 .577 .707 r
F P
0 g
s
.68236 .6561 m .67464 .60027 L .65386 .59779 L p .707 .577 .707 r
F P
0 g
s
.72766 .7127 m .72253 .67548 L .69166 .67798 L p .707 .577 .707 r
F P
0 g
s
.72253 .67548 m .72766 .7127 L .75922 .70796 L p .707 .577 .707 r
F P
0 g
s
.75922 .70796 m .75409 .67073 L .72253 .67548 L p .707 .577 .707 r
F P
0 g
s
.25647 .68469 m .2616 .72191 L .23004 .72666 L p .707 .577 .707 r
F P
0 g
s
.42064 .74934 m .4243 .24786 L .46578 .24332 L p .707 .577 .707 r
F P
0 g
s
.4243 .24786 m .42085 .71973 L p .38668 .75716 L .707 .577 .707 r
F P
0 g
s
.46578 .24332 m .46212 .7448 L .42064 .74934 L p .707 .577 .707 r
F P
0 g
s
.42121 .55612 m .42893 .61195 L .45001 .60722 L p .707 .577 .707 r
F P
0 g
s
.45001 .60722 m .45809 .60541 L p .45244 .59785 L .707 .577 .707 r
F P
0 g
s
.45244 .59785 m .42121 .55612 L .45001 .60722 L .707 .577 .707 r
F
.42085 .71973 m .42064 .74934 L .4127 .75117 L p F P
0 g
s
.4127 .75117 m .38668 .75716 L p .42085 .71973 L .707 .577 .707 r
F P
0 g
s
.75409 .67073 m .75922 .70796 L .78838 .70143 L p .707 .577 .707 r
F P
0 g
s
.78838 .70143 m .78325 .66421 L .75409 .67073 L p .707 .577 .707 r
F P
0 g
s
.30474 .74469 m .30113 .76245 L .27056 .75446 L p .707 .577 .707 r
F P
0 g
s
.27056 .75446 m .27418 .7367 L .30474 .74469 L p .707 .577 .707 r
F P
0 g
s
.23928 .74974 m .24289 .73199 L .27418 .7367 L p .707 .577 .707 r
F P
0 g
s
.8173 .57876 m .82502 .63459 L .84134 .62652 L p .707 .577 .707 r
F P
0 g
s
.84134 .62652 m .83362 .57069 L .8173 .57876 L p .707 .577 .707 r
F P
0 g
s
.27418 .7367 m .27056 .75446 L .23928 .74974 L p .707 .577 .707 r
F P
0 g
s
.69679 .7152 m .69166 .67798 L .6645 .67799 L p .707 .577 .707 r
F P
0 g
s
.69166 .67798 m .69679 .7152 L .72766 .7127 L p .707 .577 .707 r
F P
0 g
s
.65386 .59779 m .66158 .65362 L .68236 .6561 L p .707 .577 .707 r
F P
0 g
s
.73602 .76569 m .73963 .74793 L .70906 .73994 L p .707 .577 .707 r
F P
0 g
s
.73963 .74793 m .73602 .76569 L .76731 .7704 L p .707 .577 .707 r
F P
0 g
s
.76731 .7704 m .77092 .75265 L .73963 .74793 L p .707 .577 .707 r
F P
0 g
s
.78325 .66421 m .78838 .70143 L .8123 .69375 L p .707 .577 .707 r
F P
0 g
s
.8123 .69375 m .80717 .65653 L .78325 .66421 L p .707 .577 .707 r
F P
0 g
s
.55473 .24552 m .55107 .74701 L .50706 .744 L p .707 .577 .707 r
F P
0 g
s
.50706 .744 m .51073 .24252 L .55473 .24552 L p .707 .577 .707 r
F P
0 g
s
.6645 .67799 m .66963 .71521 L .69679 .7152 L p .707 .577 .707 r
F P
0 g
s
.77092 .75265 m .76731 .7704 L .79625 .77138 L p .707 .577 .707 r
F P
0 g
s
.79625 .77138 m .79987 .75363 L .77092 .75265 L p .707 .577 .707 r
F P
0 g
s
.70545 .7577 m .70906 .73994 L .68221 .72946 L p .707 .577 .707 r
F P
0 g
s
.70906 .73994 m .70545 .7577 L .73602 .76569 L p .707 .577 .707 r
F P
0 g
s
.46212 .7448 m .46578 .24332 L .51073 .24252 L p .707 .577 .707 r
F P
0 g
s
.51073 .24252 m .50706 .744 L .46212 .7448 L p .707 .577 .707 r
F P
0 g
s
.66158 .65362 m .65386 .59779 L .64149 .59307 L p .707 .577 .707 r
F P
0 g
s
.68221 .72946 m .6786 .74721 L .70545 .7577 L p .707 .577 .707 r
F P
0 g
s
.66963 .71521 m .6645 .67799 L .64372 .67551 L p .707 .577 .707 r
F P
0 g
s
.79987 .75363 m .79625 .77138 L .82003 .76853 L p .707 .577 .707 r
F P
0 g
s
.82003 .76853 m .82364 .75078 L .79987 .75363 L p .707 .577 .707 r
F P
0 g
s
.6786 .74721 m .68221 .72946 L .6617 .71751 L p .707 .577 .707 r
F P
0 g
s
.80717 .65653 m .8123 .69375 L .82862 .68569 L p .707 .577 .707 r
F P
0 g
s
.82862 .68569 m .82349 .64847 L .80717 .65653 L p .707 .577 .707 r
F P
0 g
s
.64372 .67551 m .64885 .71273 L .66963 .71521 L p .707 .577 .707 r
F P
0 g
s
.83362 .57069 m .84134 .62652 L .84847 .61885 L p .707 .577 .707 r
F P
0 g
s
.84847 .61885 m .84075 .56302 L .83362 .57069 L p .707 .577 .707 r
F P
0 g
s
.64149 .59307 m .64921 .6489 L .66158 .65362 L p .707 .577 .707 r
F P
0 g
s
.6617 .71751 m .65809 .73527 L .6786 .74721 L p .707 .577 .707 r
F P
0 g
s
.64921 .6489 m .64149 .59307 L .63874 .58656 L p .707 .577 .707 r
F P
0 g
s
.82364 .75078 m .82003 .76853 L .8363 .76213 L p .707 .577 .707 r
F P
0 g
s
.8363 .76213 m .83991 .74437 L .82364 .75078 L p .707 .577 .707 r
F P
0 g
s
.65809 .73527 m .6617 .71751 L .64955 .70527 L p .707 .577 .707 r
F P
0 g
s
.82349 .64847 m .82862 .68569 L .83575 .67802 L p .707 .577 .707 r
F P
0 g
s
.83575 .67802 m .83062 .6408 L .82349 .64847 L p .707 .577 .707 r
F P
0 g
s
.64955 .70527 m .64593 .72302 L .65809 .73527 L p .707 .577 .707 r
F P
0 g
s
.84075 .56302 m .84847 .61885 L .84571 .61234 L p .707 .577 .707 r
F P
0 g
s
.84571 .61234 m .838 .55651 L .84075 .56302 L p .707 .577 .707 r
F P
0 g
s
.63874 .58656 m .64645 .64239 L .64921 .6489 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .63135 .67077 L .62859 .66425 L p .707 .577 .707 r
F P
0 g
s
.83991 .74437 m .8363 .76213 L .84348 .7528 L p .707 .577 .707 r
F P
0 g
s
.84348 .7528 m .84709 .73504 L .83991 .74437 L p .707 .577 .707 r
F P
0 g
s
.64593 .72302 m .64955 .70527 L .64693 .69392 L p .707 .577 .707 r
F P
0 g
s
.64645 .64239 m .63874 .58656 L .64587 .57889 L p .707 .577 .707 r
F P
0 g
s
.62859 .66425 m .63372 .70147 L .63648 .70799 L p .707 .577 .707 r
F P
0 g
s
.64693 .69392 m .64332 .71168 L .64593 .72302 L p .707 .577 .707 r
F P
0 g
s
.83062 .6408 m .83575 .67802 L .83299 .6715 L p .707 .577 .707 r
F P
0 g
s
.83299 .6715 m .82786 .63428 L .83062 .6408 L p .707 .577 .707 r
F P
0 g
s
.838 .55651 m .84571 .61234 L .83334 .60762 L p .707 .577 .707 r
F P
0 g
s
.83334 .60762 m .82562 .55178 L .838 .55651 L p .707 .577 .707 r
F P
0 g
s
.64587 .57889 m .65358 .63472 L .64645 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39737 .61671 m .38965 .56088 L .35879 .56339 L p .707 .577 .707 r
F P
0 g
s
.38965 .56088 m .39737 .61671 L .42893 .61195 L p .707 .577 .707 r
F P
0 g
s
.42893 .61195 m .42121 .55612 L .38965 .56088 L p .707 .577 .707 r
F P
0 g
s
.45809 .60541 m .45038 .54958 L .42121 .55612 L p .707 .577 .707 r
F P
0 g
s
.84709 .73504 m .84348 .7528 L .84086 .74146 L p .707 .577 .707 r
F P
0 g
s
.84086 .74146 m .84448 .7237 L .84709 .73504 L p .707 .577 .707 r
F P
0 g
s
.63372 .70147 m .62859 .66425 L .63572 .65659 L p .707 .577 .707 r
F P
0 g
s
.64332 .71168 m .64693 .69392 L .65411 .68459 L p .707 .577 .707 r
F P
0 g
s
.65358 .63472 m .64587 .57889 L .66219 .57082 L p .707 .577 .707 r
F P
0 g
s
.3665 .61922 m .35879 .56339 L .33163 .56341 L p .707 .577 .707 r
F P
0 g
s
.35879 .56339 m .3665 .61922 L .39737 .61671 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65411 .68459 m .65049 .70235 L .64332 .71168 L p .707 .577 .707 r
F P
0 g
s
.63572 .65659 m .64085 .69381 L .63372 .70147 L p .707 .577 .707 r
F P
0 g
s
.45038 .54958 m .45809 .60541 L .48201 .59773 L p .707 .577 .707 r
F P
0 g
s
.48201 .59773 m .47429 .5419 L .45038 .54958 L p .707 .577 .707 r
F P
0 g
s
.82786 .63428 m .83299 .6715 L .82062 .66677 L p .707 .577 .707 r
F P
0 g
s
.82062 .66677 m .81549 .62955 L .82786 .63428 L p .707 .577 .707 r
F P
0 g
s
.82562 .55178 m .83334 .60762 L .81256 .60514 L p .707 .577 .707 r
F P
0 g
s
.81256 .60514 m .80484 .54931 L .82562 .55178 L p .707 .577 .707 r
F P
0 g
s
.66219 .57082 m .6699 .62665 L .65358 .63472 L p .707 .577 .707 r
F P
0 g
s
.33163 .56341 m .33935 .61924 L .3665 .61922 L p .707 .577 .707 r
F P
0 g
s
.33935 .61924 m .33163 .56341 L .31085 .56094 L p .707 .577 .707 r
F P
0 g
s
.38465 .67578 m .37952 .63856 L .34865 .64106 L p .707 .577 .707 r
F P
0 g
s
.37952 .63856 m .38465 .67578 L .41621 .67104 L p .707 .577 .707 r
F P
0 g
s
.41621 .67104 m .41108 .63381 L .37952 .63856 L p .707 .577 .707 r
F P
0 g
s
.41108 .63381 m .41621 .67104 L .44537 .66451 L p .707 .577 .707 r
F P
0 g
s
.44537 .66451 m .44024 .62729 L .41108 .63381 L p .707 .577 .707 r
F P
0 g
s
.84448 .7237 m .84086 .74146 L .8287 .72922 L p .707 .577 .707 r
F P
0 g
s
.8287 .72922 m .83232 .71146 L .84448 .7237 L p .707 .577 .707 r
F P
0 g
s
.47429 .5419 m .48201 .59773 L .49833 .58967 L p .707 .577 .707 r
F P
0 g
s
.49833 .58967 m .49061 .53384 L .47429 .5419 L p .707 .577 .707 r
F P
0 g
s
.64085 .69381 m .63572 .65659 L .65204 .64852 L p .707 .577 .707 r
F P
0 g
s
.65049 .70235 m .65411 .68459 L .67038 .67819 L p .707 .577 .707 r
F P
0 g
s
.6699 .62665 m .66219 .57082 L .6861 .56314 L p .707 .577 .707 r
F P
0 g
s
.35378 .67828 m .34865 .64106 L .32149 .64107 L p .707 .577 .707 r
F P
0 g
s
.34865 .64106 m .35378 .67828 L .38465 .67578 L p .707 .577 .707 r
F P
0 g
s
.31085 .56094 m .31857 .61677 L .33935 .61924 L p .707 .577 .707 r
F P
0 g
s
.44024 .62729 m .44537 .66451 L .46929 .65683 L p .707 .577 .707 r
F P
0 g
s
.46929 .65683 m .46416 .61961 L .44024 .62729 L p .707 .577 .707 r
F P
0 g
s
.39301 .72931 m .39662 .71156 L .36605 .70356 L p .707 .577 .707 r
F P
0 g
s
.39662 .71156 m .39301 .72931 L .4243 .73403 L p .707 .577 .707 r
F P
0 g
s
.4243 .73403 m .42791 .71627 L .39662 .71156 L p .707 .577 .707 r
F P
0 g
s
.67038 .67819 m .66677 .69595 L .65049 .70235 L p .707 .577 .707 r
F P
0 g
s
.65204 .64852 m .65717 .68574 L .64085 .69381 L p .707 .577 .707 r
F P
0 g
s
.80484 .54931 m .81256 .60514 L .78541 .60516 L p .707 .577 .707 r
F P
0 g
s
.78541 .60516 m .77769 .54933 L .80484 .54931 L p .707 .577 .707 r
F P
0 g
s
.32149 .64107 m .32662 .67829 L .35378 .67828 L p .707 .577 .707 r
F P
0 g
s
.81549 .62955 m .82062 .66677 L .79984 .66428 L p .707 .577 .707 r
F P
0 g
s
.79984 .66428 m .79471 .62706 L .81549 .62955 L p .707 .577 .707 r
F P
0 g
s
.42791 .71627 m .4243 .73403 L .45324 .73501 L p .707 .577 .707 r
F P
0 g
s
.45324 .73501 m .45686 .71725 L .42791 .71627 L p .707 .577 .707 r
F P
0 g
s
.36244 .72132 m .36605 .70356 L .3392 .69308 L p .707 .577 .707 r
F P
0 g
s
.36605 .70356 m .36244 .72132 L .39301 .72931 L p .707 .577 .707 r
F P
0 g
s
.6861 .56314 m .69382 .61898 L .6699 .62665 L p .707 .577 .707 r
F P
0 g
s
.31857 .61677 m .31085 .56094 L .29848 .55622 L p .707 .577 .707 r
F P
0 g
s
.3392 .69308 m .33559 .71084 L .36244 .72132 L p .707 .577 .707 r
F P
0 g
s
.32662 .67829 m .32149 .64107 L .30071 .63859 L p .707 .577 .707 r
F P
0 g
s
.69382 .61898 m .6861 .56314 L .71526 .55661 L p .707 .577 .707 r
F P
0 g
s
.45686 .71725 m .45324 .73501 L .47702 .73216 L p .707 .577 .707 r
F P
0 g
s
.47702 .73216 m .48063 .7144 L .45686 .71725 L p .707 .577 .707 r
F P
0 g
s
.33559 .71084 m .3392 .69308 L .31869 .68113 L p .707 .577 .707 r
F P
0 g
s
.77769 .54933 m .78541 .60516 L .75454 .60768 L p .707 .577 .707 r
F P
0 g
s
.75454 .60768 m .74682 .55185 L .77769 .54933 L p .707 .577 .707 r
F P
0 g
s
.46416 .61961 m .46929 .65683 L .48561 .64877 L p .707 .577 .707 r
F P
0 g
s
.48561 .64877 m .48048 .61155 L .46416 .61961 L p .707 .577 .707 r
F P
0 g
s
.30071 .63859 m .30584 .67581 L .32662 .67829 L p .707 .577 .707 r
F P
0 g
s
.49061 .53384 m .49833 .58967 L .50546 .582 L p .707 .577 .707 r
F P
0 g
s
.50546 .582 m .49774 .52617 L .49061 .53384 L p .707 .577 .707 r
F P
0 g
s
.83232 .71146 m .8287 .72922 L .8082 .71727 L p .707 .577 .707 r
F P
0 g
s
.8082 .71727 m .81181 .69951 L .83232 .71146 L p .707 .577 .707 r
F P
0 g
s
.65717 .68574 m .65204 .64852 L .67596 .64085 L p .707 .577 .707 r
F P
0 g
s
.66677 .69595 m .67038 .67819 L .69416 .67534 L p .707 .577 .707 r
F P
0 g
s
.29848 .55622 m .3062 .61205 L .31857 .61677 L p .707 .577 .707 r
F P
0 g
s
.31869 .68113 m .31508 .69889 L .33559 .71084 L p .707 .577 .707 r
F P
0 g
s
.72298 .61244 m .71526 .55661 L .74682 .55185 L p .707 .577 .707 r
F P
0 g
s
.71526 .55661 m .72298 .61244 L .69382 .61898 L p .707 .577 .707 r
F P
0 g
s
.74682 .55185 m .75454 .60768 L .72298 .61244 L p .707 .577 .707 r
F P
0 g
s
.69416 .67534 m .69054 .6931 L .66677 .69595 L p .707 .577 .707 r
F P
0 g
s
.79471 .62706 m .79984 .66428 L .77268 .66429 L p .707 .577 .707 r
F P
0 g
s
.77268 .66429 m .76755 .62707 L .79471 .62706 L p .707 .577 .707 r
F P
0 g
s
.67596 .64085 m .68109 .67807 L .65717 .68574 L p .707 .577 .707 r
F P
0 g
s
.30584 .67581 m .30071 .63859 L .28834 .63385 L p .707 .577 .707 r
F P
0 g
s
.3062 .61205 m .29848 .55622 L .29572 .5497 L p .707 .577 .707 r
F P
0 g
s
.48063 .7144 m .47702 .73216 L .49329 .72576 L p .707 .577 .707 r
F P
0 g
s
.49329 .72576 m .4969 .708 L .48063 .7144 L p .707 .577 .707 r
F P
0 g
s
.68109 .67807 m .67596 .64085 L .70512 .63432 L p .707 .577 .707 r
F P
0 g
s
.31508 .69889 m .31869 .68113 L .30654 .66889 L p .707 .577 .707 r
F P
0 g
s
.81181 .69951 m .8082 .71727 L .78134 .70679 L p .707 .577 .707 r
F P
0 g
s
.78134 .70679 m .78496 .68903 L .81181 .69951 L p .707 .577 .707 r
F P
0 g
s
.69054 .6931 m .69416 .67534 L .7231 .67632 L p .707 .577 .707 r
F P
0 g
s
.28834 .63385 m .29347 .67107 L .30584 .67581 L p .707 .577 .707 r
F P
0 g
s
.76755 .62707 m .77268 .66429 L .74181 .66679 L p .707 .577 .707 r
F P
0 g
s
.74181 .66679 m .73668 .62957 L .76755 .62707 L p .707 .577 .707 r
F P
0 g
s
.48048 .61155 m .48561 .64877 L .49274 .6411 L p .707 .577 .707 r
F P
0 g
s
.49274 .6411 m .48761 .60388 L .48048 .61155 L p .707 .577 .707 r
F P
0 g
s
.30654 .66889 m .30292 .68665 L .31508 .69889 L p .707 .577 .707 r
F P
0 g
s
.70512 .63432 m .71025 .67154 L .68109 .67807 L p .707 .577 .707 r
F P
0 g
s
.7231 .67632 m .71949 .69408 L .69054 .6931 L p .707 .577 .707 r
F P
0 g
s
.49774 .52617 m .50546 .582 L .5027 .57549 L p .707 .577 .707 r
F P
0 g
s
.5027 .57549 m .49499 .51966 L .49774 .52617 L p .707 .577 .707 r
F P
0 g
s
.29572 .5497 m .30344 .60553 L .3062 .61205 L p .707 .577 .707 r
F P
0 g
s
.71025 .67154 m .70512 .63432 L .73668 .62957 L p .707 .577 .707 r
F P
0 g
s
.73668 .62957 m .74181 .66679 L .71025 .67154 L p .707 .577 .707 r
F P
0 g
s
.78496 .68903 m .78134 .70679 L .75078 .69879 L p .707 .577 .707 r
F P
0 g
s
.75078 .69879 m .75439 .68104 L .78496 .68903 L p .707 .577 .707 r
F P
0 g
s
.71949 .69408 m .7231 .67632 L .75439 .68104 L p .707 .577 .707 r
F P
0 g
s
.75439 .68104 m .75078 .69879 L .71949 .69408 L p .707 .577 .707 r
F P
0 g
s
.29347 .67107 m .28834 .63385 L .28558 .62733 L p .707 .577 .707 r
F P
0 g
s
.4969 .708 m .49329 .72576 L .50047 .71643 L p .707 .577 .707 r
F P
0 g
s
.50047 .71643 m .50408 .69867 L .4969 .708 L p .707 .577 .707 r
F P
0 g
s
.30292 .68665 m .30654 .66889 L .30392 .65755 L p .707 .577 .707 r
F P
0 g
s
.30344 .60553 m .29572 .5497 L .30286 .54204 L p .707 .577 .707 r
F P
0 g
s
.28558 .62733 m .29071 .66455 L .29347 .67107 L p .707 .577 .707 r
F P
0 g
s
.30392 .65755 m .3003 .67531 L .30292 .68665 L p .707 .577 .707 r
F P
0 g
s
.48761 .60388 m .49274 .6411 L .48998 .63458 L p .707 .577 .707 r
F P
0 g
s
.48998 .63458 m .48485 .59736 L .48761 .60388 L p .707 .577 .707 r
F P
0 g
s
.49499 .51966 m .5027 .57549 L .49033 .57076 L p .707 .577 .707 r
F P
0 g
s
.49033 .57076 m .48261 .51493 L .49499 .51966 L p .707 .577 .707 r
F P
0 g
s
.30286 .54204 m .31057 .59787 L .30344 .60553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50408 .69867 m .50047 .71643 L .49785 .70508 L p .707 .577 .707 r
F P
0 g
s
.49785 .70508 m .50147 .68733 L .50408 .69867 L p .707 .577 .707 r
F P
0 g
s
.29071 .66455 m .28558 .62733 L .29271 .61966 L p .707 .577 .707 r
F P
0 g
s
.3003 .67531 m .30392 .65755 L .3111 .64822 L p .707 .577 .707 r
F P
0 g
s
.31057 .59787 m .30286 .54204 L .31918 .53397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3111 .64822 m .30748 .66598 L .3003 .67531 L p .707 .577 .707 r
F P
0 g
s
.29271 .61966 m .29784 .65689 L .29071 .66455 L p .707 .577 .707 r
F P
0 g
s
.48485 .59736 m .48998 .63458 L .47761 .62985 L p .707 .577 .707 r
F P
0 g
s
.47761 .62985 m .47248 .59263 L .48485 .59736 L p .707 .577 .707 r
F P
0 g
s
.48261 .51493 m .49033 .57076 L .46955 .56829 L p .707 .577 .707 r
F P
0 g
s
.46955 .56829 m .46183 .51246 L .48261 .51493 L p .707 .577 .707 r
F P
0 g
s
.31918 .53397 m .32689 .5898 L .31057 .59787 L p .707 .577 .707 r
F P
0 g
s
.50147 .68733 m .49785 .70508 L .48569 .69284 L p .707 .577 .707 r
F P
0 g
s
.48569 .69284 m .48931 .67508 L .50147 .68733 L p .707 .577 .707 r
F P
0 g
s
.29784 .65689 m .29271 .61966 L .30903 .6116 L p .707 .577 .707 r
F P
0 g
s
.30748 .66598 m .3111 .64822 L .32737 .64182 L p .707 .577 .707 r
F P
0 g
s
.32689 .5898 m .31918 .53397 L .34309 .52629 L p .707 .577 .707 r
F P
0 g
s
.32737 .64182 m .32376 .65957 L .30748 .66598 L p .707 .577 .707 r
F P
0 g
s
.30903 .6116 m .31416 .64882 L .29784 .65689 L p .707 .577 .707 r
F P
0 g
s
.46183 .51246 m .46955 .56829 L .4424 .56831 L p .707 .577 .707 r
F P
0 g
s
.4424 .56831 m .43468 .51248 L .46183 .51246 L p .707 .577 .707 r
F P
0 g
s
.47248 .59263 m .47761 .62985 L .45682 .62736 L p .707 .577 .707 r
F P
0 g
s
.45682 .62736 m .4517 .59014 L .47248 .59263 L p .707 .577 .707 r
F P
0 g
s
.34309 .52629 m .35081 .58212 L .32689 .5898 L p .707 .577 .707 r
F P
0 g
s
.35081 .58212 m .34309 .52629 L .37225 .51975 L p .707 .577 .707 r
F P
0 g
s
.43468 .51248 m .4424 .56831 L .41153 .57083 L p .707 .577 .707 r
F P
0 g
s
.41153 .57083 m .40381 .51499 L .43468 .51248 L p .707 .577 .707 r
F P
0 g
s
.48931 .67508 m .48569 .69284 L .46519 .68089 L p .707 .577 .707 r
F P
0 g
s
.46519 .68089 m .4688 .66314 L .48931 .67508 L p .707 .577 .707 r
F P
0 g
s
.31416 .64882 m .30903 .6116 L .33295 .60393 L p .707 .577 .707 r
F P
0 g
s
.32376 .65957 m .32737 .64182 L .35114 .63897 L p .707 .577 .707 r
F P
0 g
s
.37997 .57558 m .37225 .51975 L .40381 .51499 L p .707 .577 .707 r
F P
0 g
s
.37225 .51975 m .37997 .57558 L .35081 .58212 L p .707 .577 .707 r
F P
0 g
s
.40381 .51499 m .41153 .57083 L .37997 .57558 L p .707 .577 .707 r
F P
0 g
s
.35114 .63897 m .34753 .65672 L .32376 .65957 L p .707 .577 .707 r
F P
0 g
s
.4517 .59014 m .45682 .62736 L .42967 .62737 L p .707 .577 .707 r
F P
0 g
s
.42967 .62737 m .42454 .59015 L .4517 .59014 L p .707 .577 .707 r
F P
0 g
s
.33295 .60393 m .33808 .64115 L .31416 .64882 L p .707 .577 .707 r
F P
0 g
s
.33808 .64115 m .33295 .60393 L .36211 .5974 L p .707 .577 .707 r
F P
0 g
s
.4688 .66314 m .46519 .68089 L .43833 .67041 L p .707 .577 .707 r
F P
0 g
s
.43833 .67041 m .44195 .65265 L .4688 .66314 L p .707 .577 .707 r
F P
0 g
s
.34753 .65672 m .35114 .63897 L .38009 .63995 L p .707 .577 .707 r
F P
0 g
s
.42454 .59015 m .42967 .62737 L .3988 .62987 L p .707 .577 .707 r
F P
0 g
s
.3988 .62987 m .39367 .59265 L .42454 .59015 L p .707 .577 .707 r
F P
0 g
s
.36211 .5974 m .36724 .63462 L .33808 .64115 L p .707 .577 .707 r
F P
0 g
s
.38009 .63995 m .37648 .6577 L .34753 .65672 L p .707 .577 .707 r
F P
0 g
s
.36724 .63462 m .36211 .5974 L .39367 .59265 L p .707 .577 .707 r
F P
0 g
s
.39367 .59265 m .3988 .62987 L .36724 .63462 L p .707 .577 .707 r
F P
0 g
s
.44195 .65265 m .43833 .67041 L .40777 .66242 L p .707 .577 .707 r
F P
0 g
s
.40777 .66242 m .41138 .64466 L .44195 .65265 L p .707 .577 .707 r
F P
0 g
s
.37648 .6577 m .38009 .63995 L .41138 .64466 L p .707 .577 .707 r
F P
0 g
s
.41138 .64466 m .40777 .66242 L .37648 .6577 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1UYF0P002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001o
ogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo
001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002
FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009J
EP03001JEUYF009JEP03001JEUYF00MJEPl000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00UYF2P0015YF
00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00IGoo001TOol200000eYF000000050004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IGoo001TOol400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001POol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005aoo`@00003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005Yoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<006Eoo`00FGoo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EWoo
00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000KOolI000bOol005Aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8001Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P004goo10001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H0
05YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYF000^Ool005Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000QJEP03001JEUYF00AJEPD00004FUH00000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001EOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`04
001JEUYF0003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00@005YFFUH0009JEP05
001JEUYFFUH00006FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP0500000eYF
001JEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol2FUH30004FUH00`00FUIJ
EP03FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;7oo001FOol2FUH20005FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00D7oo1P0000AJEP00FUH000=JEP@000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000/Ool004Moo`T000AJEP05001JEP00001JEP0400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF6@000eYF00<007oo
Ool0:Woo0011Ool60004FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH0000002]oo`00?Goo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0
0003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00>Goo
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002]oo`00=goo0P0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0eYF0P00;7oo000eOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool003=o
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00@005YFFUIJEP8002eo
o`00<Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00AJEP03001JEUYF00D00003FUH005YF008002moo`00;goo0P000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH015YF40001UYF00<005YFFUH015YF00<005YFFUH00UYF10000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH0
15YF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00<Goo
000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP0@00000eYF001JEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000aOol002eoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0004FUH00`00FUIJEP03FUH50008FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH01000FUIJEUYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<0
05YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
10000UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH30002FUH00`00FUIJEP02FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJ
EP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080031oo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH01000FUH000001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00<7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF0P000eYF1@000eYF00@005YFFUIJEPP000AJEP03001JEUYF00MJEP04001JEUYF
FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH:0002FUH200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YF
FUH01`001UYF00<005YFFUH01EYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPl000=JEP03001JEUYF008002moo`00;Woo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH015YF1`001eYF0`0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF10000UYF00<005YFFUH01UYF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF009J
EPT0009oo`@00003FUH005YF00EJEPH00003FUH0000002moo`00;Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00@005YF001JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH00000008000MJEP03001JEUYF008000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEPH0009oo`T000EJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
02moo`00;Woo00<005YF000015YF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH015YF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP050007Ool500000eYF001J
EP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000_Ool002ioo`03001JEP0000AJEP03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEQL000MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF5@0000=JEP00FUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000^Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF2P000eYF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00UJEP8000IJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP03
001JEUYF009JEPL000IJEP03001JEUYF00AJEP03001JEUYF009JEP80031oo`00;Woo00@005YFFUH0
009JEP05001JEUYFFUH00007FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP02FUH01000FUIJEUYF
1P000UYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00@005YF000000=J
EP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02moo`00;goo0UYF0`0015YF00<005YFFUH0
1EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03
001JEP0000D0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP05001JEUYFFUH00002FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH01000
FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000
1EYF00<005YFFUH00P00<Woo000_Ool2FUH20005FUH01000FUIJEUYF1P001UYF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YF000015YF0P000UYF00<007oo00000UYF00<005YFFUH00eYF1P0015YF
00<005YFFUH02EYF00<005YFFUH00UYF0`000eYF00<005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUH0009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF0`00=7oo000_Ool015YF001JEP000eYF1P00
0eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1@000UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH015YF00@005YFFUIJEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEQD000AJEP03001JEUYF00MJEP04
001JEUYFFUH4000fOol002moo`80009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH00000FUH00P0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01`001UYF00<005YFFUH015YF0P00=Woo000_Ool200000eYF00000003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH01000FUIJEUYF
10001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP0000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEPD0009JEP03001JEUYF00EJEP<003Aoo`00<7oo0P001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00@005YFFUH003=oo`00;Woo0`001eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
25YF00<005YF00000`002EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF009JEPL000Ioo`8000=JEP03001JEUYF009JEP80035oo`00;7oo0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0P001eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000EJ
EP00001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH8000?Ool200000eYF001JEP05FUH00`00Oomoo`0^
Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEQD000=J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEQ00
00Ioo`<0011oo`8000IJEP8002moo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00<005YFFUH00`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP04001J
EUYFFUH20007Ool5000AOol20004FUH01000FUH00000;Goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000goo000000020002FUH00`00FUIJEP04FUH5
0002FUH00`00FUH000020006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0015YF1P0000=JEP00FUH00P002Goo1@004goo00@005YFFUH000AJEP03001oogoo02Yoo`00:Woo
00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P0000=oo`0000001`001UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000UYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00800004FUH00000000;Ool5
000DOol30004FUH00`00Oomoo`0ZOol002Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
01000003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF
00=JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00005FUH200000eYF
001oo`0;Ool3000GOol01000FUIJEUYF0P00;7oo000ZOol01000FUIJEP0015YF00<005YFFUH00eYF
1@0015YF2`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF200015YF00@005YFFUIJEPD000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP8000EJEP03001JEP00008002Ioo`03001JEUYF
008002aoo`00:Woo00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYF
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool0:goo000[
Ool00`00FUH00003FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF0`000UYF00<005YFFUH01EYF10008Woo00<005YF0000;7oo000[
Ool01000FUH005YF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF10001UYF00@005YF0000009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
0008FUH00`00FUIJEP04000NOol00`00FUH0000/Ool002]oo`05001JEP00001JEP020003FUH01000
FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP<000Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@005goo
1000;Goo000[Ool20002FUH20003FUH50003FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00@0
05YFFUIJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002FUH2000]Ool002]oo`80
009JEP800005FUH00000FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP070006FUH00`00FUIJEP05
FUH20005Ool01000FUIJEP001EYF00<005YFFUH010002UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<0
05YF00000P0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF000]Ool002]o
o`80009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP@0009JEP03001J
EUYF00IJEP<000=oo`04001JEUYF0005FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH>0002FUH60006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002aoo`03
001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPX000MJEP04001J
EUYF0002Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF0`001UYF00<005YFFUH00UYF
100017oo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00;Goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002Woo0P0015YF
00<005YFFUH00UYF0`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH30006FUH0
0`00FUIJEP03FUH30008Ool50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo
000^Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF1`0047oo0`0000=JEP00
FUH01EYF00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000EJEP00001JEP0000IJ
EP03001JEUYF009JEP03001JEP0000eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5000bOol0
02ioo`8000=JEPl000Ioo`<0015oo`8000IJEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP@00003FUH005YF00EJEP03001JEUYF009JEP80019oo`h003Moo`00;goo00@005YFFUIJEP<0
015oo`D0019oo`8000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP00
1UYF00<005YFFUH00UYF0P00Egoo000_Ool01@00FUIJEUYF00000UYF00<007ooOol03Woo1@0057oo
00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH01000
FUIJEUYF0P00F7oo000`Ool00`00FUH00004FUH2000>Ool5000EOol50004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH01000FUH00000FWoo000aOol20006FUH2000=Ool3000H
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF0080009J
EP<005aoo`00<Woo00<005YFFUH015YF00@005YF000002Moo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00009JEP04001JEUYFFUH2001OOol003=oo`8000AJEP04001JEUYFFUH3000U
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH2001M
Ool003Eoo`04001JEUYF0007FUH3000SOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30000
0eYF001JEP06FUH3001KOol003Ioo`<000QJEP03001JEP0000<001ioo`H000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009oo`<000IJEP03001JEUYF008005Uoo`00>7oo0P001eYF00<005YFFUH00eYF1`005Goo0P00
00=JEP0000000Woo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YF00000`001goo0P000eYF00<005YFFUH00eYF0P00Egoo000j
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool50003FUH20005Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH3000=
Ool200000eYF001JEP05FUH2001FOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH80003FUH01000FUIJEUYF0P002Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF1@0047oo0P001UYF00@005YF000005Aoo`00?goo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000moo`H0009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000800003Ool0000000<0015oo`80
00=JEP03001JEUYF009JEP03001oogoo055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8001Ioo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJ
EPL000Aoo`D001=oo`800003FUH005YF00=JEP03001oogoo055oo`00AWoo1`0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000021ooaX000]oo`D001Eoo`8000AJEP03001oogoo055oo`00
CGoo200015YF00@005YFFUIJEPD0035oo`8000EJEP04001JEP00000<Ool3000HOol00`00FUIJEP02
001COol005Eoo`P003Moo`03001JEUYF00=JEP04001JEUYFFUH3000UOol01000FUH00000Dgoo002E
Ool20002FUH00`00FUIJEP05FUH4000ROol3001COol009Moo`<000QJEP03001JEUYF00@001ioo`<0
05=oo`00VGoo0P001eYF00<005YFFUH015YF1@005goo1000E7oo002KOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP04000>Ool50002FUH2001DOol009eoo`<00003FUH005YF00QJEP03001JEUYF00AJ
EPh000=JEP06001JEUYF001JEP00E7oo002POol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001EOol00:Aoo`@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:Qoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEP00001GOol00:eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001IOol00;5o
o`h005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58847 .75275 m .59618 .69857 L .56532 .69232 L p .707 .577 .707 r
F P
0 g
s
.59618 .69857 m .58847 .75275 L .62003 .75589 L p .707 .577 .707 r
F P
0 g
s
.62003 .75589 m .62774 .70172 L .59618 .69857 L p .707 .577 .707 r
F P
0 g
s
.62774 .70172 m .62003 .75589 L .64919 .75563 L p .707 .577 .707 r
F P
0 g
s
.64919 .75563 m .65691 .70145 L .62774 .70172 L p .707 .577 .707 r
F P
0 g
s
.5576 .7465 m .56532 .69232 L .53817 .68358 L p .707 .577 .707 r
F P
0 g
s
.56532 .69232 m .5576 .7465 L .58847 .75275 L p .707 .577 .707 r
F P
0 g
s
.65691 .70145 m .64919 .75563 L .6731 .75197 L p .707 .577 .707 r
F P
0 g
s
.6731 .75197 m .68082 .6978 L .65691 .70145 L p .707 .577 .707 r
F P
0 g
s
.60119 .81453 m .60632 .77841 L .57546 .77217 L p .707 .577 .707 r
F P
0 g
s
.60632 .77841 m .60119 .81453 L .63276 .81766 L p .707 .577 .707 r
F P
0 g
s
.63276 .81766 m .63789 .78154 L .60632 .77841 L p .707 .577 .707 r
F P
0 g
s
.53045 .73776 m .53817 .68358 L .51739 .67321 L p .707 .577 .707 r
F P
0 g
s
.53817 .68358 m .53045 .73776 L .5576 .7465 L p .707 .577 .707 r
F P
0 g
s
.63789 .78154 m .63276 .81766 L .66192 .81738 L p .707 .577 .707 r
F P
0 g
s
.66192 .81738 m .66705 .78126 L .63789 .78154 L p .707 .577 .707 r
F P
0 g
s
.57033 .80829 m .57546 .77217 L .5483 .76344 L p .707 .577 .707 r
F P
0 g
s
.57546 .77217 m .57033 .80829 L .60119 .81453 L p .707 .577 .707 r
F P
0 g
s
.66705 .78126 m .66192 .81738 L .68583 .81373 L p .707 .577 .707 r
F P
0 g
s
.68583 .81373 m .69096 .77761 L .66705 .78126 L p .707 .577 .707 r
F P
0 g
s
.5483 .76344 m .54317 .79956 L .57033 .80829 L p .707 .577 .707 r
F P
0 g
s
.54317 .79956 m .5483 .76344 L .52752 .75308 L p .707 .577 .707 r
F P
0 g
s
.68082 .6978 m .6731 .75197 L .68942 .7453 L p .707 .577 .707 r
F P
0 g
s
.68942 .7453 m .69714 .69112 L .68082 .6978 L p .707 .577 .707 r
F P
0 g
s
.51739 .67321 m .50967 .72738 L .53045 .73776 L p .707 .577 .707 r
F P
0 g
s
.59223 .84515 m .58862 .82662 L .55805 .83094 L p .707 .577 .707 r
F P
0 g
s
.58862 .82662 m .59223 .84515 L .62352 .83876 L p .707 .577 .707 r
F P
0 g
s
.62352 .83876 m .6199 .82023 L .58862 .82662 L p .707 .577 .707 r
F P
0 g
s
.6199 .82023 m .62352 .83876 L .65247 .83093 L p .707 .577 .707 r
F P
0 g
s
.65247 .83093 m .64885 .8124 L .6199 .82023 L p .707 .577 .707 r
F P
0 g
s
.50967 .72738 m .51739 .67321 L .50501 .66221 L p .707 .577 .707 r
F P
0 g
s
.55805 .83094 m .56166 .84947 L .59223 .84515 L p .707 .577 .707 r
F P
0 g
s
.56166 .84947 m .55805 .83094 L .5312 .83276 L p .707 .577 .707 r
F P
0 g
s
.52752 .75308 m .52239 .7892 L .54317 .79956 L p .707 .577 .707 r
F P
0 g
s
.5312 .83276 m .53481 .8513 L .56166 .84947 L p .707 .577 .707 r
F P
0 g
s
.64885 .8124 m .65247 .83093 L .67624 .82242 L p .707 .577 .707 r
F P
0 g
s
.67624 .82242 m .67263 .80389 L .64885 .8124 L p .707 .577 .707 r
F P
0 g
s
.69096 .77761 m .68583 .81373 L .70216 .80705 L p .707 .577 .707 r
F P
0 g
s
.70216 .80705 m .70728 .77093 L .69096 .77761 L p .707 .577 .707 r
F P
0 g
s
.52239 .7892 m .52752 .75308 L .51514 .74209 L p .707 .577 .707 r
F P
0 g
s
.50501 .66221 m .4973 .71638 L .50967 .72738 L p .707 .577 .707 r
F P
0 g
s
.53481 .8513 m .5312 .83276 L .51069 .83192 L p .707 .577 .707 r
F P
0 g
s
.69714 .69112 m .68942 .7453 L .69656 .73624 L p .707 .577 .707 r
F P
0 g
s
.69656 .73624 m .70427 .68207 L .69714 .69112 L p .707 .577 .707 r
F P
0 g
s
.51069 .83192 m .5143 .85045 L .53481 .8513 L p .707 .577 .707 r
F P
0 g
s
.4973 .71638 m .50501 .66221 L .50226 .65167 L p .707 .577 .707 r
F P
0 g
s
.67263 .80389 m .67624 .82242 L .69251 .81407 L p .707 .577 .707 r
F P
0 g
s
.69251 .81407 m .6889 .79553 L .67263 .80389 L p .707 .577 .707 r
F P
0 g
s
.51514 .74209 m .51002 .77821 L .52239 .7892 L p .707 .577 .707 r
F P
0 g
s
.70728 .77093 m .70216 .80705 L .70929 .79799 L p .707 .577 .707 r
F P
0 g
s
.70929 .79799 m .71442 .76187 L .70728 .77093 L p .707 .577 .707 r
F P
0 g
s
.51002 .77821 m .51514 .74209 L .51239 .73155 L p .707 .577 .707 r
F P
0 g
s
.50226 .65167 m .49454 .70584 L .4973 .71638 L p .707 .577 .707 r
F P
0 g
s
.5143 .85045 m .51069 .83192 L .49853 .82849 L p .707 .577 .707 r
F P
0 g
s
.49853 .82849 m .50215 .84702 L .5143 .85045 L p .707 .577 .707 r
F P
0 g
s
.70427 .68207 m .69656 .73624 L .6938 .7257 L p .707 .577 .707 r
F P
0 g
s
.6938 .7257 m .70152 .67153 L .70427 .68207 L p .707 .577 .707 r
F P
0 g
s
.6889 .79553 m .69251 .81407 L .69969 .80669 L p .707 .577 .707 r
F P
0 g
s
.69969 .80669 m .69608 .78815 L .6889 .79553 L p .707 .577 .707 r
F P
0 g
s
.49454 .70584 m .50226 .65167 L .50939 .64262 L p .707 .577 .707 r
F P
0 g
s
.51239 .73155 m .50726 .76767 L .51002 .77821 L p .707 .577 .707 r
F P
0 g
s
.49294 .82177 m .48927 .31951 L .44527 .31715 L p .707 .577 .707 r
F P
0 g
s
.50726 .76767 m .51239 .73155 L .51952 .7225 L p .707 .577 .707 r
F P
0 g
s
.50939 .64262 m .50167 .69679 L .49454 .70584 L p .707 .577 .707 r
F P
0 g
s
.50167 .69679 m .50939 .64262 L .52571 .63594 L p .707 .577 .707 r
F P
0 g
s
.51952 .7225 m .51439 .75862 L .50726 .76767 L p .707 .577 .707 r
F P
0 g
s
.51439 .75862 m .51952 .7225 L .53584 .71582 L p .707 .577 .707 r
F P
0 g
s
.52571 .63594 m .51799 .69011 L .50167 .69679 L p .707 .577 .707 r
F P
0 g
s
.50215 .84702 m .49853 .82849 L .49591 .82281 L p .707 .577 .707 r
F P
0 g
s
.49591 .82281 m .49953 .84134 L .50215 .84702 L p .707 .577 .707 r
F P
0 g
s
.49953 .84134 m .49591 .82281 L .50309 .81543 L p .707 .577 .707 r
F P
0 g
s
.50309 .81543 m .50671 .83396 L .49953 .84134 L p .707 .577 .707 r
F P
0 g
s
.51799 .69011 m .52571 .63594 L .54962 .63229 L p .707 .577 .707 r
F P
0 g
s
.53584 .71582 m .53071 .75194 L .51439 .75862 L p .707 .577 .707 r
F P
0 g
s
.53071 .75194 m .53584 .71582 L .55975 .71216 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .5419 .68646 L .51799 .69011 L p .707 .577 .707 r
F P
0 g
s
.50671 .83396 m .50309 .81543 L .51937 .80707 L p .707 .577 .707 r
F P
0 g
s
.51937 .80707 m .52298 .82561 L .50671 .83396 L p .707 .577 .707 r
F P
0 g
s
.55975 .71216 m .55462 .74829 L .53071 .75194 L p .707 .577 .707 r
F P
0 g
s
.52298 .82561 m .51937 .80707 L .54314 .79857 L p .707 .577 .707 r
F P
0 g
s
.54314 .79857 m .54675 .8171 L .52298 .82561 L p .707 .577 .707 r
F P
0 g
s
.48927 .31951 m .49294 .82177 L .53788 .82038 L p .707 .577 .707 r
F P
0 g
s
.53788 .82038 m .53422 .31812 L .48927 .31951 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .57878 .63202 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.5419 .68646 m .54455 .66786 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.54455 .66786 m .54962 .63229 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.64121 .64141 m .63349 .69559 L .60263 .68934 L p .707 .577 .707 r
F P
0 g
s
.60263 .68934 m .61034 .63516 L .64121 .64141 L p .707 .577 .707 r
F P
0 g
s
.57107 .68619 m .57878 .63202 L .61034 .63516 L p .707 .577 .707 r
F P
0 g
s
.57878 .63202 m .57107 .68619 L .5419 .68646 L p .707 .577 .707 r
F P
0 g
s
.61034 .63516 m .60263 .68934 L .57107 .68619 L p .707 .577 .707 r
F P
0 g
s
.55462 .74829 m .55975 .71216 L .58892 .71189 L p .707 .577 .707 r
F P
0 g
s
.58892 .71189 m .58379 .74801 L .55462 .74829 L p .707 .577 .707 r
F P
0 g
s
.58379 .74801 m .58892 .71189 L .62048 .71502 L p .707 .577 .707 r
F P
0 g
s
.62048 .71502 m .61535 .75114 L .58379 .74801 L p .707 .577 .707 r
F P
0 g
s
.63394 .78003 m .63756 .79856 L .60699 .80288 L p .707 .577 .707 r
F P
0 g
s
.60699 .80288 m .60338 .78435 L .63394 .78003 L p .707 .577 .707 r
F P
0 g
s
.5757 .80927 m .57209 .79073 L .60338 .78435 L p .707 .577 .707 r
F P
0 g
s
.60338 .78435 m .60699 .80288 L .5757 .80927 L p .707 .577 .707 r
F P
0 g
s
.5757 .31311 m .57915 .78572 L p .61332 .80725 L .707 .577 .707 r
F P
0 g
s
.57915 .78572 m .57936 .81538 L .58729 .81348 L p .707 .577 .707 r
F P
0 g
s
.58729 .81348 m .61332 .80725 L p .57915 .78572 L .707 .577 .707 r
F P
0 g
s
.54675 .8171 m .54314 .79857 L .57209 .79073 L p .707 .577 .707 r
F P
0 g
s
.57209 .79073 m .5757 .80927 L .54675 .8171 L p .707 .577 .707 r
F P
0 g
s
.53422 .31812 m .53788 .82038 L .57936 .81538 L p .707 .577 .707 r
F P
0 g
s
.57936 .81538 m .5757 .31311 L .53422 .31812 L p .707 .577 .707 r
F P
0 g
s
.44893 .81942 m .44527 .31715 L .4065 .31127 L p .707 .577 .707 r
F P
0 g
s
.44527 .31715 m .44893 .81942 L .49294 .82177 L p .707 .577 .707 r
F P
0 g
s
.71442 .76187 m .70929 .79799 L .70653 .78746 L p .707 .577 .707 r
F P
0 g
s
.70653 .78746 m .71166 .75134 L .71442 .76187 L p .707 .577 .707 r
F P
0 g
s
.61332 .80725 m .60965 .30499 L .5757 .31311 L p .707 .577 .707 r
F P
0 g
s
.70152 .67153 m .6938 .7257 L .68143 .7147 L p .707 .577 .707 r
F P
0 g
s
.68143 .7147 m .68914 .66053 L .70152 .67153 L p .707 .577 .707 r
F P
0 g
s
.69608 .78815 m .69969 .80669 L .69707 .801 L p .707 .577 .707 r
F P
0 g
s
.69707 .801 m .69346 .78247 L .69608 .78815 L p .707 .577 .707 r
F P
0 g
s
.24546 .71597 m .25318 .66179 L .22231 .65555 L p .707 .577 .707 r
F P
0 g
s
.25318 .66179 m .24546 .71597 L .27702 .71911 L p .707 .577 .707 r
F P
0 g
s
.27702 .71911 m .28473 .66494 L .25318 .66179 L p .707 .577 .707 r
F P
0 g
s
.41017 .81354 m .4065 .31127 L .37678 .30246 L p .707 .577 .707 r
F P
0 g
s
.4065 .31127 m .41017 .81354 L .44893 .81942 L p .707 .577 .707 r
F P
0 g
s
.28473 .66494 m .27702 .71911 L .30618 .71885 L p .707 .577 .707 r
F P
0 g
s
.30618 .71885 m .3139 .66467 L .28473 .66494 L p .707 .577 .707 r
F P
0 g
s
.21459 .70972 m .22231 .65555 L .19516 .6468 L p .707 .577 .707 r
F P
0 g
s
.22231 .65555 m .21459 .70972 L .24546 .71597 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71166 .75134 m .70653 .78746 L .69415 .77647 L p .707 .577 .707 r
F P
0 g
s
.69415 .77647 m .69928 .74035 L .71166 .75134 L p .707 .577 .707 r
F P
0 g
s
.3139 .66467 m .30618 .71885 L .33009 .7152 L p .707 .577 .707 r
F P
0 g
s
.33009 .7152 m .33781 .66102 L .3139 .66467 L p .707 .577 .707 r
F P
0 g
s
.65135 .72126 m .64622 .75738 L .61535 .75114 L p .707 .577 .707 r
F P
0 g
s
.61535 .75114 m .62048 .71502 L .65135 .72126 L p .707 .577 .707 r
F P
0 g
s
.63756 .79856 m .63394 .78003 L .66079 .7782 L p .707 .577 .707 r
F P
0 g
s
.60965 .30499 m .61332 .80725 L .63643 .7968 L p .707 .577 .707 r
F P
0 g
s
.66836 .65015 m .66065 .70433 L .63349 .69559 L p .707 .577 .707 r
F P
0 g
s
.63349 .69559 m .64121 .64141 L .66836 .65015 L p .707 .577 .707 r
F P
0 g
s
.63643 .7968 m .63276 .29453 L .60965 .30499 L p .707 .577 .707 r
F P
0 g
s
.25819 .77781 m .26332 .74169 L .23245 .73546 L p .707 .577 .707 r
F P
0 g
s
.26332 .74169 m .25819 .77781 L .28975 .78095 L p .707 .577 .707 r
F P
0 g
s
.28975 .78095 m .29488 .74483 L .26332 .74169 L p .707 .577 .707 r
F P
0 g
s
.68914 .66053 m .68143 .7147 L .66065 .70433 L p .707 .577 .707 r
F P
0 g
s
.66065 .70433 m .66836 .65015 L .68914 .66053 L p .707 .577 .707 r
F P
0 g
s
.18744 .70098 m .19516 .6468 L .17438 .63643 L p .707 .577 .707 r
F P
0 g
s
.19516 .6468 m .18744 .70098 L .21459 .70972 L p .707 .577 .707 r
F P
0 g
s
.29488 .74483 m .28975 .78095 L .31891 .78067 L p .707 .577 .707 r
F P
0 g
s
.31891 .78067 m .32404 .74455 L .29488 .74483 L p .707 .577 .707 r
F P
0 g
s
.22732 .77158 m .23245 .73546 L .20529 .72673 L p .707 .577 .707 r
F P
0 g
s
.23245 .73546 m .22732 .77158 L .25819 .77781 L p .707 .577 .707 r
F P
0 g
s
.69346 .78247 m .69707 .801 L .68492 .79757 L p .707 .577 .707 r
F P
0 g
s
.68492 .79757 m .6813 .77904 L .69346 .78247 L p .707 .577 .707 r
F P
0 g
s
.38044 .80472 m .37678 .30246 L .359 .29156 L p .707 .577 .707 r
F P
0 g
s
.37678 .30246 m .38044 .80472 L .41017 .81354 L p .707 .577 .707 r
F P
0 g
s
.32404 .74455 m .31891 .78067 L .34283 .77702 L p .707 .577 .707 r
F P
0 g
s
.34283 .77702 m .34795 .7409 L .32404 .74455 L p .707 .577 .707 r
F P
0 g
s
.20529 .72673 m .20016 .76285 L .22732 .77158 L p .707 .577 .707 r
F P
0 g
s
.69928 .74035 m .69415 .77647 L .67337 .76611 L p .707 .577 .707 r
F P
0 g
s
.67337 .76611 m .6785 .72999 L .69928 .74035 L p .707 .577 .707 r
F P
0 g
s
.20016 .76285 m .20529 .72673 L .18451 .71637 L p .707 .577 .707 r
F P
0 g
s
.33781 .66102 m .33009 .7152 L .34642 .70852 L p .707 .577 .707 r
F P
0 g
s
.34642 .70852 m .35413 .65434 L .33781 .66102 L p .707 .577 .707 r
F P
0 g
s
.17438 .63643 m .16666 .6906 L .18744 .70098 L p .707 .577 .707 r
F P
0 g
s
.24922 .80789 m .24561 .78936 L .21504 .79368 L p .707 .577 .707 r
F P
0 g
s
.24561 .78936 m .24922 .80789 L .28051 .8015 L p .707 .577 .707 r
F P
0 g
s
.28051 .8015 m .27689 .78297 L .24561 .78936 L p .707 .577 .707 r
F P
0 g
s
.27689 .78297 m .28051 .8015 L .30946 .79367 L p .707 .577 .707 r
F P
0 g
s
.30946 .79367 m .30584 .77514 L .27689 .78297 L p .707 .577 .707 r
F P
0 g
s
.16666 .6906 m .17438 .63643 L .162 .62543 L p .707 .577 .707 r
F P
0 g
s
.21504 .79368 m .21865 .81221 L .24922 .80789 L p .707 .577 .707 r
F P
0 g
s
.21865 .81221 m .21504 .79368 L .18819 .79551 L p .707 .577 .707 r
F P
0 g
s
.18451 .71637 m .17938 .75249 L .20016 .76285 L p .707 .577 .707 r
F P
0 g
s
.18819 .79551 m .1918 .81404 L .21865 .81221 L p .707 .577 .707 r
F P
0 g
s
.30584 .77514 m .30946 .79367 L .33323 .78516 L p .707 .577 .707 r
F P
0 g
s
.33323 .78516 m .32962 .76663 L .30584 .77514 L p .707 .577 .707 r
F P
0 g
s
.63276 .29453 m .63643 .7968 L .64643 .78504 L p .707 .577 .707 r
F P
0 g
s
.6785 .72999 m .67337 .76611 L .64622 .75738 L p .707 .577 .707 r
F P
0 g
s
.64622 .75738 m .65135 .72126 L .6785 .72999 L p .707 .577 .707 r
F P
0 g
s
.64643 .78504 m .64276 .28278 L .63276 .29453 L p .707 .577 .707 r
F P
0 g
s
.6813 .77904 m .68492 .79757 L .66441 .79673 L p .707 .577 .707 r
F P
0 g
s
.66441 .79673 m .66079 .7782 L .6813 .77904 L p .707 .577 .707 r
F P
0 g
s
.34795 .7409 m .34283 .77702 L .35915 .77034 L p .707 .577 .707 r
F P
0 g
s
.35915 .77034 m .36428 .73422 L .34795 .7409 L p .707 .577 .707 r
F P
0 g
s
.17938 .75249 m .18451 .71637 L .17214 .70538 L p .707 .577 .707 r
F P
0 g
s
.162 .62543 m .15429 .67961 L .16666 .6906 L p .707 .577 .707 r
F P
0 g
s
.1918 .81404 m .18819 .79551 L .16768 .79466 L p .707 .577 .707 r
F P
0 g
s
.35413 .65434 m .34642 .70852 L .35355 .69946 L p .707 .577 .707 r
F P
0 g
s
.35355 .69946 m .36126 .64529 L .35413 .65434 L p .707 .577 .707 r
F P
0 g
s
.16768 .79466 m .17129 .8132 L .1918 .81404 L p .707 .577 .707 r
F P
0 g
s
.15429 .67961 m .162 .62543 L .15925 .61489 L p .707 .577 .707 r
F P
0 g
s
.32962 .76663 m .33323 .78516 L .3495 .77681 L p .707 .577 .707 r
F P
0 g
s
.3495 .77681 m .34589 .75828 L .32962 .76663 L p .707 .577 .707 r
F P
0 g
s
.17214 .70538 m .16701 .7415 L .17938 .75249 L p .707 .577 .707 r
F P
0 g
s
.36428 .73422 m .35915 .77034 L .36628 .76128 L p .707 .577 .707 r
F P
0 g
s
.36126 .64529 m .35355 .69946 L .35079 .68892 L p .707 .577 .707 r
F P
0 g
s
.35079 .68892 m .35851 .63475 L .36126 .64529 L p .707 .577 .707 r
F P
0 g
s
.36628 .76128 m .37141 .72516 L .36428 .73422 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .35115 .73976 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36865 .71463 m .36618 .73199 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36618 .73199 m .36352 .75075 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.359 .29156 m .35491 .27965 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .35627 .70364 L .36546 .71179 L p .707 .577 .707 r
F P
0 g
s
.36546 .71179 m .36865 .71463 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .36546 .71179 L .36571 .71885 L .707 .577 .707 r
F
.35858 .78192 m .36267 .79383 L p .35853 .51967 L F P
0 g
s
.35491 .27965 m .35619 .45467 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35851 .63475 m .35079 .68892 L .34296 .68197 L p .707 .577 .707 r
F P
0 g
s
.34296 .68197 m .33842 .67793 L p .34345 .6671 L .707 .577 .707 r
F P
0 g
s
.34345 .6671 m .35851 .63475 L .34296 .68197 L .707 .577 .707 r
F
.33842 .67793 m .34613 .62375 L .35851 .63475 L p F P
0 g
s
.35619 .45467 m .35858 .78192 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36267 .79383 m .36121 .59391 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36121 .59391 m .359 .29156 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.37141 .72516 m .36628 .76128 L .36352 .75075 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .36865 .71463 L .37141 .72516 L p .707 .577 .707 r
F P
0 g
s
.359 .29156 m .36267 .79383 L .38044 .80472 L p .707 .577 .707 r
F P
0 g
s
.35858 .78192 m .35515 .31159 L p .36491 .26789 L .707 .577 .707 r
F P
0 g
s
.35515 .31159 m .35491 .27965 L .35625 .27808 L p .707 .577 .707 r
F P
0 g
s
.35625 .27808 m .36491 .26789 L p .35515 .31159 L .707 .577 .707 r
F P
0 g
s
.66079 .7782 m .66441 .79673 L .63756 .79856 L p .707 .577 .707 r
F P
0 g
s
.16701 .7415 m .17214 .70538 L .16938 .69484 L p .707 .577 .707 r
F P
0 g
s
.15925 .61489 m .15153 .66907 L .15429 .67961 L p .707 .577 .707 r
F P
0 g
s
.17129 .8132 m .16768 .79466 L .15552 .79123 L p .707 .577 .707 r
F P
0 g
s
.15552 .79123 m .15914 .80977 L .17129 .8132 L p .707 .577 .707 r
F P
0 g
s
.34589 .75828 m .3495 .77681 L .35668 .76943 L p .707 .577 .707 r
F P
0 g
s
.35668 .76943 m .35307 .7509 L .34589 .75828 L p .707 .577 .707 r
F P
0 g
s
.64276 .28278 m .64643 .78504 L .64329 .77592 L p .707 .577 .707 r
F P
0 g
s
.64236 .75002 m .64276 .28278 L .64329 .77592 L .707 .577 .707 r
F
.63867 .27087 m .64276 .28278 L p .64247 .62315 L F P
0 g
s
.64234 .77313 m .64121 .61905 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.64121 .61905 m .63867 .27087 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.63867 .27087 m .64234 .77313 L .62456 .76224 L p .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63946 .55963 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.6345 .62435 m .63715 .60574 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .64222 .57017 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63715 .60574 L p .64687 .63534 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .6345 .62435 L .63793 .6274 L p .707 .577 .707 r
F P
0 g
s
.63793 .6274 m .64687 .63534 L p .63715 .60574 L .707 .577 .707 r
F P
0 g
s
.64329 .77592 m .64234 .77313 L p .64236 .75002 L .707 .577 .707 r
F P
0 g
s
.15153 .66907 m .15925 .61489 L .16638 .60584 L p .707 .577 .707 r
F P
0 g
s
.16938 .69484 m .16425 .73096 L .16701 .7415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16425 .73096 m .16938 .69484 L .17651 .68579 L p .707 .577 .707 r
F P
0 g
s
.16638 .60584 m .15866 .66001 L .15153 .66907 L p .707 .577 .707 r
F P
0 g
s
.15914 .80977 m .15552 .79123 L .1529 .78555 L p .707 .577 .707 r
F P
0 g
s
.1529 .78555 m .15652 .80408 L .15914 .80977 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35307 .7509 m .35668 .76943 L .35406 .76375 L p .707 .577 .707 r
F P
0 g
s
.35406 .76375 m .35045 .74522 L .35307 .7509 L p .707 .577 .707 r
F P
0 g
s
.15866 .66001 m .16638 .60584 L .1827 .59916 L p .707 .577 .707 r
F P
0 g
s
.17651 .68579 m .17138 .72191 L .16425 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62456 .76224 m .6209 .25997 L .63867 .27087 L p .707 .577 .707 r
F P
0 g
s
.17138 .72191 m .17651 .68579 L .19283 .67911 L p .707 .577 .707 r
F P
0 g
s
.1827 .59916 m .17498 .65333 L .15866 .66001 L p .707 .577 .707 r
F P
0 g
s
.15652 .80408 m .1529 .78555 L .16008 .77817 L p .707 .577 .707 r
F P
0 g
s
.34613 .62375 m .33842 .67793 L .31764 .66755 L p .707 .577 .707 r
F P
0 g
s
.31764 .66755 m .32535 .61338 L .34613 .62375 L p .707 .577 .707 r
F P
0 g
s
.16008 .77817 m .1637 .7967 L .15652 .80408 L p .707 .577 .707 r
F P
0 g
s
.17498 .65333 m .1827 .59916 L .20661 .59551 L p .707 .577 .707 r
F P
0 g
s
.35045 .74522 m .35406 .76375 L .34191 .76032 L p .707 .577 .707 r
F P
0 g
s
.34191 .76032 m .33829 .74178 L .35045 .74522 L p .707 .577 .707 r
F P
0 g
s
.36858 .77016 m .36491 .26789 L .38802 .25744 L p .707 .577 .707 r
F P
0 g
s
.36491 .26789 m .36858 .77016 L .35858 .78192 L p .707 .577 .707 r
F P
0 g
s
.19283 .67911 m .1877 .71523 L .17138 .72191 L p .707 .577 .707 r
F P
0 g
s
.35627 .70364 m .35115 .73976 L .33036 .7294 L p .707 .577 .707 r
F P
0 g
s
.33036 .7294 m .33549 .69328 L .35627 .70364 L p .707 .577 .707 r
F P
0 g
s
.1877 .71523 m .19283 .67911 L .21674 .67545 L p .707 .577 .707 r
F P
0 g
s
.32535 .61338 m .31764 .66755 L .29048 .65881 L p .707 .577 .707 r
F P
0 g
s
.29048 .65881 m .2982 .60463 L .32535 .61338 L p .707 .577 .707 r
F P
0 g
s
.20661 .59551 m .19889 .64968 L .17498 .65333 L p .707 .577 .707 r
F P
0 g
s
.19889 .64968 m .20661 .59551 L .23577 .59524 L p .707 .577 .707 r
F P
0 g
s
.1637 .7967 m .16008 .77817 L .17636 .76982 L p .707 .577 .707 r
F P
0 g
s
.6209 .25997 m .62456 .76224 L .59484 .75342 L p .707 .577 .707 r
F P
0 g
s
.59484 .75342 m .59117 .25115 L .6209 .25997 L p .707 .577 .707 r
F P
0 g
s
.17636 .76982 m .17997 .78835 L .1637 .7967 L p .707 .577 .707 r
F P
0 g
s
.21674 .67545 m .21162 .71157 L .1877 .71523 L p .707 .577 .707 r
F P
0 g
s
.33829 .74178 m .34191 .76032 L .3214 .75947 L p .707 .577 .707 r
F P
0 g
s
.3214 .75947 m .31778 .74094 L .33829 .74178 L p .707 .577 .707 r
F P
0 g
s
.2982 .60463 m .29048 .65881 L .25962 .65256 L p .707 .577 .707 r
F P
0 g
s
.25962 .65256 m .26733 .59839 L .2982 .60463 L p .707 .577 .707 r
F P
0 g
s
.22806 .64942 m .23577 .59524 L .26733 .59839 L p .707 .577 .707 r
F P
0 g
s
.23577 .59524 m .22806 .64942 L .19889 .64968 L p .707 .577 .707 r
F P
0 g
s
.33549 .69328 m .33036 .7294 L .30321 .72067 L p .707 .577 .707 r
F P
0 g
s
.30321 .72067 m .30834 .68455 L .33549 .69328 L p .707 .577 .707 r
F P
0 g
s
.26733 .59839 m .25962 .65256 L .22806 .64942 L p .707 .577 .707 r
F P
0 g
s
.21162 .71157 m .21674 .67545 L .24591 .67518 L p .707 .577 .707 r
F P
0 g
s
.38802 .25744 m .39169 .75971 L .36858 .77016 L p .707 .577 .707 r
F P
0 g
s
.39169 .75971 m .38802 .25744 L .42198 .24931 L p .707 .577 .707 r
F P
0 g
s
.72567 .66071 m .73339 .60653 L .70252 .60028 L p .707 .577 .707 r
F P
0 g
s
.73339 .60653 m .72567 .66071 L .75723 .66385 L p .707 .577 .707 r
F P
0 g
s
.75723 .66385 m .76495 .60968 L .73339 .60653 L p .707 .577 .707 r
F P
0 g
s
.76495 .60968 m .75723 .66385 L .7864 .66359 L p .707 .577 .707 r
F P
0 g
s
.7864 .66359 m .79411 .60941 L .76495 .60968 L p .707 .577 .707 r
F P
0 g
s
.69481 .65446 m .70252 .60028 L .67537 .59154 L p .707 .577 .707 r
F P
0 g
s
.70252 .60028 m .69481 .65446 L .72567 .66071 L p .707 .577 .707 r
F P
0 g
s
.17997 .78835 m .17636 .76982 L .20013 .76131 L p .707 .577 .707 r
F P
0 g
s
.30834 .68455 m .30321 .72067 L .27234 .71443 L p .707 .577 .707 r
F P
0 g
s
.27234 .71443 m .27747 .67831 L .30834 .68455 L p .707 .577 .707 r
F P
0 g
s
.24591 .67518 m .24078 .7113 L .21162 .71157 L p .707 .577 .707 r
F P
0 g
s
.24078 .7113 m .24591 .67518 L .27747 .67831 L p .707 .577 .707 r
F P
0 g
s
.20013 .76131 m .20374 .77984 L .17997 .78835 L p .707 .577 .707 r
F P
0 g
s
.27747 .67831 m .27234 .71443 L .24078 .7113 L p .707 .577 .707 r
F P
0 g
s
.31778 .74094 m .3214 .75947 L .29455 .7613 L p .707 .577 .707 r
F P
0 g
s
.29455 .7613 m .29093 .74277 L .31778 .74094 L p .707 .577 .707 r
F P
0 g
s
.59117 .25115 m .59484 .75342 L .55607 .74754 L p .707 .577 .707 r
F P
0 g
s
.55607 .74754 m .55241 .24527 L .59117 .25115 L p .707 .577 .707 r
F P
0 g
s
.79411 .60941 m .7864 .66359 L .81031 .65994 L p .707 .577 .707 r
F P
0 g
s
.81031 .65994 m .81802 .60576 L .79411 .60941 L p .707 .577 .707 r
F P
0 g
s
.7384 .72249 m .74353 .68637 L .71266 .68013 L p .707 .577 .707 r
F P
0 g
s
.74353 .68637 m .7384 .72249 L .76996 .72562 L p .707 .577 .707 r
F P
0 g
s
.76996 .72562 m .77509 .6895 L .74353 .68637 L p .707 .577 .707 r
F P
0 g
s
.66765 .64572 m .67537 .59154 L .65459 .58117 L p .707 .577 .707 r
F P
0 g
s
.67537 .59154 m .66765 .64572 L .69481 .65446 L p .707 .577 .707 r
F P
0 g
s
.77509 .6895 m .76996 .72562 L .79913 .72535 L p .707 .577 .707 r
F P
0 g
s
.79913 .72535 m .80425 .68923 L .77509 .6895 L p .707 .577 .707 r
F P
0 g
s
.70753 .71625 m .71266 .68013 L .68551 .6714 L p .707 .577 .707 r
F P
0 g
s
.71266 .68013 m .70753 .71625 L .7384 .72249 L p .707 .577 .707 r
F P
0 g
s
.42564 .75158 m .42198 .24931 L .46346 .24431 L p .707 .577 .707 r
F P
0 g
s
.42198 .24931 m .42564 .75158 L .39169 .75971 L p .707 .577 .707 r
F P
0 g
s
.20374 .77984 m .20013 .76131 L .22908 .75348 L p .707 .577 .707 r
F P
0 g
s
.22908 .75348 m .23269 .77201 L .20374 .77984 L p .707 .577 .707 r
F P
0 g
s
.29093 .74277 m .29455 .7613 L .26398 .76562 L p .707 .577 .707 r
F P
0 g
s
.26398 .76562 m .26037 .74709 L .29093 .74277 L p .707 .577 .707 r
F P
0 g
s
.80425 .68923 m .79913 .72535 L .82304 .72169 L p .707 .577 .707 r
F P
0 g
s
.82304 .72169 m .82817 .68557 L .80425 .68923 L p .707 .577 .707 r
F P
0 g
s
.68551 .6714 m .68038 .70752 L .70753 .71625 L p .707 .577 .707 r
F P
0 g
s
.55241 .24527 m .55607 .74754 L .51207 .74519 L p .707 .577 .707 r
F P
0 g
s
.51207 .74519 m .5084 .24292 L .55241 .24527 L p .707 .577 .707 r
F P
0 g
s
.68038 .70752 m .68551 .6714 L .66472 .66104 L p .707 .577 .707 r
F P
0 g
s
.81802 .60576 m .81031 .65994 L .82663 .65326 L p .707 .577 .707 r
F P
0 g
s
.82663 .65326 m .83434 .59908 L .81802 .60576 L p .707 .577 .707 r
F P
0 g
s
.65459 .58117 m .64687 .63534 L .66765 .64572 L p .707 .577 .707 r
F P
0 g
s
.23269 .77201 m .22908 .75348 L .26037 .74709 L p .707 .577 .707 r
F P
0 g
s
.72943 .75311 m .72582 .73458 L .69525 .7389 L p .707 .577 .707 r
F P
0 g
s
.72582 .73458 m .72943 .75311 L .76072 .74672 L p .707 .577 .707 r
F P
0 g
s
.76072 .74672 m .75711 .72819 L .72582 .73458 L p .707 .577 .707 r
F P
0 g
s
.26037 .74709 m .26398 .76562 L .23269 .77201 L p .707 .577 .707 r
F P
0 g
s
.75711 .72819 m .76072 .74672 L .78967 .73889 L p .707 .577 .707 r
F P
0 g
s
.78967 .73889 m .78606 .72036 L .75711 .72819 L p .707 .577 .707 r
F P
0 g
s
.64687 .63534 m .65459 .58117 L .64222 .57017 L p .707 .577 .707 r
F P
0 g
s
.69525 .7389 m .69887 .75743 L .72943 .75311 L p .707 .577 .707 r
F P
0 g
s
.46712 .74658 m .46346 .24431 L .5084 .24292 L p .707 .577 .707 r
F P
0 g
s
.46346 .24431 m .46712 .74658 L .42564 .75158 L p .707 .577 .707 r
F P
0 g
s
.69887 .75743 m .69525 .7389 L .6684 .74073 L p .707 .577 .707 r
F P
0 g
s
.5084 .24292 m .51207 .74519 L .46712 .74658 L p .707 .577 .707 r
F P
0 g
s
.66472 .66104 m .6596 .69716 L .68038 .70752 L p .707 .577 .707 r
F P
0 g
s
.6684 .74073 m .67202 .75926 L .69887 .75743 L p .707 .577 .707 r
F P
0 g
s
.78606 .72036 m .78967 .73889 L .81344 .73038 L p .707 .577 .707 r
F P
0 g
s
.81344 .73038 m .80983 .71185 L .78606 .72036 L p .707 .577 .707 r
F P
0 g
s
.82817 .68557 m .82304 .72169 L .83936 .71501 L p .707 .577 .707 r
F P
0 g
s
.83936 .71501 m .84449 .67889 L .82817 .68557 L p .707 .577 .707 r
F P
0 g
s
.6596 .69716 m .66472 .66104 L .65235 .65005 L p .707 .577 .707 r
F P
0 g
s
.67202 .75926 m .6684 .74073 L .64789 .73988 L p .707 .577 .707 r
F P
0 g
s
.83434 .59908 m .82663 .65326 L .83376 .6442 L p .707 .577 .707 r
F P
0 g
s
.83376 .6442 m .84148 .59003 L .83434 .59908 L p .707 .577 .707 r
F P
0 g
s
.64789 .73988 m .65151 .75841 L .67202 .75926 L p .707 .577 .707 r
F P
0 g
s
.80983 .71185 m .81344 .73038 L .82972 .72203 L p .707 .577 .707 r
F P
0 g
s
.82972 .72203 m .8261 .7035 L .80983 .71185 L p .707 .577 .707 r
F P
0 g
s
.65235 .65005 m .64722 .68617 L .6596 .69716 L p .707 .577 .707 r
F P
0 g
s
.84449 .67889 m .83936 .71501 L .84649 .70596 L p .707 .577 .707 r
F P
0 g
s
.84649 .70596 m .85162 .66984 L .84449 .67889 L p .707 .577 .707 r
F P
0 g
s
.64722 .68617 m .65235 .65005 L .64959 .63952 L p .707 .577 .707 r
F P
0 g
s
.63946 .55963 m .63174 .6138 L .6345 .62435 L p .707 .577 .707 r
F P
0 g
s
.65151 .75841 m .64789 .73988 L .63574 .73645 L p .707 .577 .707 r
F P
0 g
s
.63574 .73645 m .63935 .75498 L .65151 .75841 L p .707 .577 .707 r
F P
0 g
s
.84148 .59003 m .83376 .6442 L .831 .63366 L p .707 .577 .707 r
F P
0 g
s
.831 .63366 m .83872 .57949 L .84148 .59003 L p .707 .577 .707 r
F P
0 g
s
.8261 .7035 m .82972 .72203 L .8369 .71465 L p .707 .577 .707 r
F P
0 g
s
.8369 .71465 m .83328 .69612 L .8261 .7035 L p .707 .577 .707 r
F P
0 g
s
.63174 .6138 m .63946 .55963 L .64659 .55058 L p .707 .577 .707 r
F P
0 g
s
.64959 .63952 m .64446 .67564 L .64722 .68617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.85162 .66984 m .84649 .70596 L .84373 .69542 L p .707 .577 .707 r
F P
0 g
s
.84373 .69542 m .84886 .6593 L .85162 .66984 L p .707 .577 .707 r
F P
0 g
s
.64446 .67564 m .64959 .63952 L .65672 .63046 L p .707 .577 .707 r
F P
0 g
s
.64659 .55058 m .63888 .60475 L .63174 .6138 L p .707 .577 .707 r
F P
0 g
s
.63935 .75498 m .63574 .73645 L .63312 .73077 L p .707 .577 .707 r
F P
0 g
s
.63312 .73077 m .63673 .7493 L .63935 .75498 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83872 .57949 m .831 .63366 L .81863 .62267 L p .707 .577 .707 r
F P
0 g
s
.81863 .62267 m .82635 .56849 L .83872 .57949 L p .707 .577 .707 r
F P
0 g
s
.83328 .69612 m .8369 .71465 L .83428 .70897 L p .707 .577 .707 r
F P
0 g
s
.83428 .70897 m .83067 .69043 L .83328 .69612 L p .707 .577 .707 r
F P
0 g
s
.63888 .60475 m .64659 .55058 L .66291 .5439 L p .707 .577 .707 r
F P
0 g
s
.65672 .63046 m .65159 .66658 L .64446 .67564 L p .707 .577 .707 r
F P
0 g
s
.38266 .62393 m .39038 .56975 L .35951 .56351 L p .707 .577 .707 r
F P
0 g
s
.39038 .56975 m .38266 .62393 L .41422 .62707 L p .707 .577 .707 r
F P
0 g
s
.41422 .62707 m .42194 .5729 L .39038 .56975 L p .707 .577 .707 r
F P
0 g
s
.42194 .5729 m .41422 .62707 L .44339 .62681 L p .707 .577 .707 r
F P
0 g
s
.44339 .62681 m .4511 .57263 L .42194 .5729 L p .707 .577 .707 r
F P
0 g
s
.3518 .61768 m .35951 .56351 L .33236 .55477 L p .707 .577 .707 r
F P
0 g
s
.35951 .56351 m .3518 .61768 L .38266 .62393 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84886 .6593 m .84373 .69542 L .83136 .68443 L p .707 .577 .707 r
F P
0 g
s
.83136 .68443 m .83649 .64831 L .84886 .6593 L p .707 .577 .707 r
F P
0 g
s
.65159 .66658 m .65672 .63046 L .67304 .62378 L p .707 .577 .707 r
F P
0 g
s
.66291 .5439 m .6552 .59807 L .63888 .60475 L p .707 .577 .707 r
F P
0 g
s
.4511 .57263 m .44339 .62681 L .4673 .62316 L p .707 .577 .707 r
F P
0 g
s
.4673 .62316 m .47501 .56898 L .4511 .57263 L p .707 .577 .707 r
F P
0 g
s
.63673 .7493 m .63312 .73077 L .6403 .72339 L p .707 .577 .707 r
F P
0 g
s
.39539 .68578 m .40052 .64966 L .36965 .64342 L p .707 .577 .707 r
F P
0 g
s
.40052 .64966 m .39539 .68578 L .42695 .68891 L p .707 .577 .707 r
F P
0 g
s
.42695 .68891 m .43208 .65279 L .40052 .64966 L p .707 .577 .707 r
F P
0 g
s
.82635 .56849 m .81863 .62267 L .79785 .61229 L p .707 .577 .707 r
F P
0 g
s
.79785 .61229 m .80557 .55811 L .82635 .56849 L p .707 .577 .707 r
F P
0 g
s
.32464 .60894 m .33236 .55477 L .31158 .54439 L p .707 .577 .707 r
F P
0 g
s
.33236 .55477 m .32464 .60894 L .3518 .61768 L p .707 .577 .707 r
F P
0 g
s
.6403 .72339 m .64391 .74192 L .63673 .7493 L p .707 .577 .707 r
F P
0 g
s
.43208 .65279 m .42695 .68891 L .45612 .68864 L p .707 .577 .707 r
F P
0 g
s
.45612 .68864 m .46124 .65251 L .43208 .65279 L p .707 .577 .707 r
F P
0 g
s
.36452 .67954 m .36965 .64342 L .3425 .63469 L p .707 .577 .707 r
F P
0 g
s
.36965 .64342 m .36452 .67954 L .39539 .68578 L p .707 .577 .707 r
F P
0 g
s
.6552 .59807 m .66291 .5439 L .68682 .54025 L p .707 .577 .707 r
F P
0 g
s
.83067 .69043 m .83428 .70897 L .82212 .70553 L p .707 .577 .707 r
F P
0 g
s
.82212 .70553 m .81851 .687 L .83067 .69043 L p .707 .577 .707 r
F P
0 g
s
.67304 .62378 m .66792 .6599 L .65159 .66658 L p .707 .577 .707 r
F P
0 g
s
.46124 .65251 m .45612 .68864 L .48003 .68498 L p .707 .577 .707 r
F P
0 g
s
.48003 .68498 m .48516 .64886 L .46124 .65251 L p .707 .577 .707 r
F P
0 g
s
.3425 .63469 m .33737 .67081 L .36452 .67954 L p .707 .577 .707 r
F P
0 g
s
.83649 .64831 m .83136 .68443 L .81058 .67407 L p .707 .577 .707 r
F P
0 g
s
.81058 .67407 m .81571 .63795 L .83649 .64831 L p .707 .577 .707 r
F P
0 g
s
.33737 .67081 m .3425 .63469 L .32171 .62433 L p .707 .577 .707 r
F P
0 g
s
.47501 .56898 m .4673 .62316 L .48362 .61648 L p .707 .577 .707 r
F P
0 g
s
.48362 .61648 m .49133 .5623 L .47501 .56898 L p .707 .577 .707 r
F P
0 g
s
.31158 .54439 m .30386 .59856 L .32464 .60894 L p .707 .577 .707 r
F P
0 g
s
.38642 .71585 m .38281 .69732 L .35224 .70164 L p .707 .577 .707 r
F P
0 g
s
.38281 .69732 m .38642 .71585 L .41771 .70947 L p .707 .577 .707 r
F P
0 g
s
.41771 .70947 m .4141 .69093 L .38281 .69732 L p .707 .577 .707 r
F P
0 g
s
.4141 .69093 m .41771 .70947 L .44666 .70163 L p .707 .577 .707 r
F P
0 g
s
.44666 .70163 m .44305 .6831 L .4141 .69093 L p .707 .577 .707 r
F P
0 g
s
.66792 .6599 m .67304 .62378 L .69696 .62013 L p .707 .577 .707 r
F P
0 g
s
.80557 .55811 m .79785 .61229 L .7707 .60355 L p .707 .577 .707 r
F P
0 g
s
.7707 .60355 m .77841 .54937 L .80557 .55811 L p .707 .577 .707 r
F P
0 g
s
.68682 .54025 m .67911 .59442 L .6552 .59807 L p .707 .577 .707 r
F P
0 g
s
.30386 .59856 m .31158 .54439 L .29921 .53339 L p .707 .577 .707 r
F P
0 g
s
.35224 .70164 m .35586 .72017 L .38642 .71585 L p .707 .577 .707 r
F P
0 g
s
.67911 .59442 m .68682 .54025 L .71599 .53998 L p .707 .577 .707 r
F P
0 g
s
.35586 .72017 m .35224 .70164 L .32539 .70347 L p .707 .577 .707 r
F P
0 g
s
.64391 .74192 m .6403 .72339 L .65657 .71504 L p .707 .577 .707 r
F P
0 g
s
.32171 .62433 m .31658 .66045 L .33737 .67081 L p .707 .577 .707 r
F P
0 g
s
.32539 .70347 m .32901 .722 L .35586 .72017 L p .707 .577 .707 r
F P
0 g
s
.44305 .6831 m .44666 .70163 L .47043 .69312 L p .707 .577 .707 r
F P
0 g
s
.47043 .69312 m .46682 .67459 L .44305 .6831 L p .707 .577 .707 r
F P
0 g
s
.65657 .71504 m .66018 .73357 L .64391 .74192 L p .707 .577 .707 r
F P
0 g
s
.69696 .62013 m .69183 .65625 L .66792 .6599 L p .707 .577 .707 r
F P
0 g
s
.81851 .687 m .82212 .70553 L .80161 .70469 L p .707 .577 .707 r
F P
0 g
s
.80161 .70469 m .798 .68616 L .81851 .687 L p .707 .577 .707 r
F P
0 g
s
.48516 .64886 m .48003 .68498 L .49635 .6783 L p .707 .577 .707 r
F P
0 g
s
.49635 .6783 m .50148 .64218 L .48516 .64886 L p .707 .577 .707 r
F P
0 g
s
.77841 .54937 m .7707 .60355 L .73983 .5973 L p .707 .577 .707 r
F P
0 g
s
.73983 .5973 m .74755 .54313 L .77841 .54937 L p .707 .577 .707 r
F P
0 g
s
.70827 .59416 m .71599 .53998 L .74755 .54313 L p .707 .577 .707 r
F P
0 g
s
.71599 .53998 m .70827 .59416 L .67911 .59442 L p .707 .577 .707 r
F P
0 g
s
.81571 .63795 m .81058 .67407 L .78342 .66534 L p .707 .577 .707 r
F P
0 g
s
.78342 .66534 m .78855 .62922 L .81571 .63795 L p .707 .577 .707 r
F P
0 g
s
.31658 .66045 m .32171 .62433 L .30934 .61334 L p .707 .577 .707 r
F P
0 g
s
.29921 .53339 m .29149 .58757 L .30386 .59856 L p .707 .577 .707 r
F P
0 g
s
.74755 .54313 m .73983 .5973 L .70827 .59416 L p .707 .577 .707 r
F P
0 g
s
.69183 .65625 m .69696 .62013 L .72612 .61985 L p .707 .577 .707 r
F P
0 g
s
.32901 .722 m .32539 .70347 L .30488 .70263 L p .707 .577 .707 r
F P
0 g
s
.49133 .5623 m .48362 .61648 L .49075 .60743 L p .707 .577 .707 r
F P
0 g
s
.49075 .60743 m .49847 .55325 L .49133 .5623 L p .707 .577 .707 r
F P
0 g
s
.30488 .70263 m .3085 .72116 L .32901 .722 L p .707 .577 .707 r
F P
0 g
s
.29149 .58757 m .29921 .53339 L .29645 .52285 L p .707 .577 .707 r
F P
0 g
s
.46682 .67459 m .47043 .69312 L .48671 .68477 L p .707 .577 .707 r
F P
0 g
s
.48671 .68477 m .48309 .66624 L .46682 .67459 L p .707 .577 .707 r
F P
0 g
s
.30934 .61334 m .30421 .64946 L .31658 .66045 L p .707 .577 .707 r
F P
0 g
s
.66018 .73357 m .65657 .71504 L .68034 .70653 L p .707 .577 .707 r
F P
0 g
s
.78855 .62922 m .78342 .66534 L .75256 .65911 L p .707 .577 .707 r
F P
0 g
s
.75256 .65911 m .75768 .62299 L .78855 .62922 L p .707 .577 .707 r
F P
0 g
s
.72612 .61985 m .72099 .65597 L .69183 .65625 L p .707 .577 .707 r
F P
0 g
s
.72099 .65597 m .72612 .61985 L .75768 .62299 L p .707 .577 .707 r
F P
0 g
s
.68034 .70653 m .68396 .72506 L .66018 .73357 L p .707 .577 .707 r
F P
0 g
s
.75768 .62299 m .75256 .65911 L .72099 .65597 L p .707 .577 .707 r
F P
0 g
s
.798 .68616 m .80161 .70469 L .77476 .70652 L p .707 .577 .707 r
F P
0 g
s
.77476 .70652 m .77115 .68799 L .798 .68616 L p .707 .577 .707 r
F P
0 g
s
.50148 .64218 m .49635 .6783 L .50348 .66925 L p .707 .577 .707 r
F P
0 g
s
.50348 .66925 m .50861 .63313 L .50148 .64218 L p .707 .577 .707 r
F P
0 g
s
.30421 .64946 m .30934 .61334 L .30658 .6028 L p .707 .577 .707 r
F P
0 g
s
.29645 .52285 m .28873 .57703 L .29149 .58757 L p .707 .577 .707 r
F P
0 g
s
.3085 .72116 m .30488 .70263 L .29273 .6992 L p .707 .577 .707 r
F P
0 g
s
.29273 .6992 m .29634 .71773 L .3085 .72116 L p .707 .577 .707 r
F P
0 g
s
.68396 .72506 m .68034 .70653 L .70929 .6987 L p .707 .577 .707 r
F P
0 g
s
.49847 .55325 m .49075 .60743 L .48799 .59688 L p .707 .577 .707 r
F P
0 g
s
.48799 .59688 m .49571 .54271 L .49847 .55325 L p .707 .577 .707 r
F P
0 g
s
.48309 .66624 m .48671 .68477 L .49389 .67739 L p .707 .577 .707 r
F P
0 g
s
.49389 .67739 m .49027 .65886 L .48309 .66624 L p .707 .577 .707 r
F P
0 g
s
.70929 .6987 m .71291 .71723 L .68396 .72506 L p .707 .577 .707 r
F P
0 g
s
.77115 .68799 m .77476 .70652 L .74419 .71084 L p .707 .577 .707 r
F P
0 g
s
.74419 .71084 m .74058 .69231 L .77115 .68799 L p .707 .577 .707 r
F P
0 g
s
.28873 .57703 m .29645 .52285 L .30358 .5138 L p .707 .577 .707 r
F P
0 g
s
.30658 .6028 m .30145 .63893 L .30421 .64946 L p .707 .577 .707 r
F P
0 g
s
.71291 .71723 m .70929 .6987 L .74058 .69231 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74058 .69231 m .74419 .71084 L .71291 .71723 L p .707 .577 .707 r
F P
0 g
s
.50861 .63313 m .50348 .66925 L .50072 .65871 L p .707 .577 .707 r
F P
0 g
s
.50072 .65871 m .50585 .62259 L .50861 .63313 L p .707 .577 .707 r
F P
0 g
s
.30145 .63893 m .30658 .6028 L .31371 .59375 L p .707 .577 .707 r
F P
0 g
s
.30358 .5138 m .29586 .56797 L .28873 .57703 L p .707 .577 .707 r
F P
0 g
s
.29634 .71773 m .29273 .6992 L .29011 .69351 L p .707 .577 .707 r
F P
0 g
s
.29011 .69351 m .29372 .71204 L .29634 .71773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49571 .54271 m .48799 .59688 L .47562 .58589 L p .707 .577 .707 r
F P
0 g
s
.47562 .58589 m .48334 .53171 L .49571 .54271 L p .707 .577 .707 r
F P
0 g
s
.49027 .65886 m .49389 .67739 L .49127 .67171 L p .707 .577 .707 r
F P
0 g
s
.49127 .67171 m .48765 .65318 L .49027 .65886 L p .707 .577 .707 r
F P
0 g
s
.29586 .56797 m .30358 .5138 L .3199 .50712 L p .707 .577 .707 r
F P
0 g
s
.31371 .59375 m .30858 .62987 L .30145 .63893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50585 .62259 m .50072 .65871 L .48835 .64772 L p .707 .577 .707 r
F P
0 g
s
.48835 .64772 m .49348 .6116 L .50585 .62259 L p .707 .577 .707 r
F P
0 g
s
.30858 .62987 m .31371 .59375 L .33003 .58707 L p .707 .577 .707 r
F P
0 g
s
.3199 .50712 m .31219 .56129 L .29586 .56797 L p .707 .577 .707 r
F P
0 g
s
.29372 .71204 m .29011 .69351 L .29729 .68613 L p .707 .577 .707 r
F P
0 g
s
.48334 .53171 m .47562 .58589 L .45484 .57551 L p .707 .577 .707 r
F P
0 g
s
.45484 .57551 m .46256 .52134 L .48334 .53171 L p .707 .577 .707 r
F P
0 g
s
.29729 .68613 m .3009 .70467 L .29372 .71204 L p .707 .577 .707 r
F P
0 g
s
.31219 .56129 m .3199 .50712 L .34381 .50347 L p .707 .577 .707 r
F P
0 g
s
.48765 .65318 m .49127 .67171 L .47911 .66828 L p .707 .577 .707 r
F P
0 g
s
.47911 .66828 m .4755 .64975 L .48765 .65318 L p .707 .577 .707 r
F P
0 g
s
.33003 .58707 m .32491 .62319 L .30858 .62987 L p .707 .577 .707 r
F P
0 g
s
.49348 .6116 m .48835 .64772 L .46757 .63736 L p .707 .577 .707 r
F P
0 g
s
.46757 .63736 m .4727 .60124 L .49348 .6116 L p .707 .577 .707 r
F P
0 g
s
.32491 .62319 m .33003 .58707 L .35395 .58342 L p .707 .577 .707 r
F P
0 g
s
.46256 .52134 m .45484 .57551 L .42769 .56677 L p .707 .577 .707 r
F P
0 g
s
.42769 .56677 m .4354 .5126 L .46256 .52134 L p .707 .577 .707 r
F P
0 g
s
.34381 .50347 m .3361 .55764 L .31219 .56129 L p .707 .577 .707 r
F P
0 g
s
.3361 .55764 m .34381 .50347 L .37298 .5032 L p .707 .577 .707 r
F P
0 g
s
.3009 .70467 m .29729 .68613 L .31356 .67778 L p .707 .577 .707 r
F P
0 g
s
.31356 .67778 m .31717 .69631 L .3009 .70467 L p .707 .577 .707 r
F P
0 g
s
.35395 .58342 m .34882 .61954 L .32491 .62319 L p .707 .577 .707 r
F P
0 g
s
.4755 .64975 m .47911 .66828 L .4586 .66744 L p .707 .577 .707 r
F P
0 g
s
.4586 .66744 m .45499 .6489 L .4755 .64975 L p .707 .577 .707 r
F P
0 g
s
.4354 .5126 m .42769 .56677 L .39682 .56052 L p .707 .577 .707 r
F P
0 g
s
.39682 .56052 m .40454 .50635 L .4354 .5126 L p .707 .577 .707 r
F P
0 g
s
.36526 .55738 m .37298 .5032 L .40454 .50635 L p .707 .577 .707 r
F P
0 g
s
.37298 .5032 m .36526 .55738 L .3361 .55764 L p .707 .577 .707 r
F P
0 g
s
.4727 .60124 m .46757 .63736 L .44041 .62863 L p .707 .577 .707 r
F P
0 g
s
.44041 .62863 m .44554 .59251 L .4727 .60124 L p .707 .577 .707 r
F P
0 g
s
.40454 .50635 m .39682 .56052 L .36526 .55738 L p .707 .577 .707 r
F P
0 g
s
.34882 .61954 m .35395 .58342 L .38311 .58314 L p .707 .577 .707 r
F P
0 g
s
.31717 .69631 m .31356 .67778 L .33733 .66927 L p .707 .577 .707 r
F P
0 g
s
.44554 .59251 m .44041 .62863 L .40954 .62239 L p .707 .577 .707 r
F P
0 g
s
.40954 .62239 m .41467 .58627 L .44554 .59251 L p .707 .577 .707 r
F P
0 g
s
.38311 .58314 m .37798 .61926 L .34882 .61954 L p .707 .577 .707 r
F P
0 g
s
.37798 .61926 m .38311 .58314 L .41467 .58627 L p .707 .577 .707 r
F P
0 g
s
.33733 .66927 m .34095 .6878 L .31717 .69631 L p .707 .577 .707 r
F P
0 g
s
.41467 .58627 m .40954 .62239 L .37798 .61926 L p .707 .577 .707 r
F P
0 g
s
.45499 .6489 m .4586 .66744 L .43175 .66926 L p .707 .577 .707 r
F P
0 g
s
.43175 .66926 m .42814 .65073 L .45499 .6489 L p .707 .577 .707 r
F P
0 g
s
.34095 .6878 m .33733 .66927 L .36628 .66144 L p .707 .577 .707 r
F P
0 g
s
.36628 .66144 m .3699 .67997 L .34095 .6878 L p .707 .577 .707 r
F P
0 g
s
.42814 .65073 m .43175 .66926 L .40118 .67358 L p .707 .577 .707 r
F P
0 g
s
.40118 .67358 m .39757 .65505 L .42814 .65073 L p .707 .577 .707 r
F P
0 g
s
.3699 .67997 m .36628 .66144 L .39757 .65505 L p .707 .577 .707 r
F P
0 g
s
.39757 .65505 m .40118 .67358 L .3699 .67997 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8P00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001YOol2
0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00GWoo4@002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001JOol4
0003FUH00`00FUIJEP06FUH01000FUIJEUYF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001HOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60007FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001VOol005Ioo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
IWoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool@
001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool50003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70016Ool005=oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo0000
05YF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@Woo001COol00`00FUH0
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF1000?Woo001COol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00
>Woo001COol20003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH2000hOol005=oo`8000=JEP@0009JEP04001JEUYFFUH40002FUH01000
FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo
00@005YF001JEP8000IJEP03001JEUYF00AJEP@000EJEPT0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008003Aoo`00DWoo00H005YF000005YF0005FUH00`00FUIJEP06
FUH00`00FUH000030002FUH50004FUH40006FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00<Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUHC0002FUH0
0`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P00<Goo001BOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF0P00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01000FUH00000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00@005YFFUIJEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJ
EQ0000IJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH20004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DWoo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000MJEP03001JEUYF00AJEP80009JEP03001JEP0000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0UYF0P00;Goo001BOol01@00FUIJEUYF000015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH015YF00L005YF001JEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
009JEP8002eoo`00Dgoo00@005YFFUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF0000;Goo000gOolA000<Ool300000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP03FUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF200027oo
1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool003=oo`@000=J
EP03001JEUYF00IJEP03001JEUYF009JEPP000Ioo`04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF1P0000=JEP00FUH0
15YF1@001Woo2@000UYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUIJEP00FUH^Ool0035o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH600000goo00000004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0`00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH010000Woo1@0017oo10001EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH^Ool002moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000EJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Qoo`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002io
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH400000eYF
0000000:00000eYF001JEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20005FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH@0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00UYF0P00;goo000]
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP020003FUH500000eYF00000002Ool01@00FUIJEP00FUH03`0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000eYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH015YF0P000eYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEPD000AJEP800005Ool005YFFUH00006
FUH@0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P001EYF00<005YF00000UYF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000eYF00<005YFFUH01000;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000EJEPD000EJEP03001JEUYF00IJEP800003FUH005YF00EJEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH00UYF0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
000300000eYF001JEP04FUH50005FUH00`00FUIJEP08FUH20006FUH01000FUIJEUYF0`0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF0P00<7oo
000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH30006FUH00`00FUIJ
EP09FUH30003FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP<00003FUH00000031oo`00;7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000@000QJEP03001JEUYF00UJEP03001JEUYF0080
0003FUH005YF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03000`Ool002aoo`8000=JEP04001JEUYFFUH@0004FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1`000UYF00<005YFFUH00eYF3@000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000eYF10000UYF00@0
05YFFUIJEP<000Moo`L000IJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP000080009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP8002ioo`00:goo00@005YF001JEP8000IJEP03001JEUYF00AJEP<000Ioo`T0009JEP03001JEUYF
00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0400000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF00@005YF000002aoo`00:goo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUH0
00030002Ool50004Ool40005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP0200001UYF00000000FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP@00003
FUH0000000Ioo`h000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qoo`@0009JEP8000=J
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EP00001JEP0300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP040004FUH2000>Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000:goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF0000000=00001EYF000005YF00000UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P000eYF00X005YFFUH005YF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800005FUH00000FUH00002FUH20002FUH01000FUH000002Woo0`0027oo
10001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:Woo000[Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
10001UYF00<005YFFUH01eYF00<005YFFUH00UYF20000eYF00<005YFFUH01@0000QJEP00000005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH0
0UYF0`000eYF00<007ooOol01Woo1@002goo10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000ZOol002]oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00AJEPL0
009JEP03001JEUYF00IJEP@000=JEPH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP06001JEP00001JEP0027oo1@003goo0`00
1EYF00L005YFFUIJEP00FUH0000ZOol002]oo`05001JEUYFFUH00006FUH01000FUIJEUYF5`0025YF
0P0015YF00<005YFFUH01eYF00<005YFFUH01@0025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP04001JEUYFFUH30007Ool5000BOol20003FUH01`00FUIJEUYF001J
EP0002Yoo`00:goo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@0009JEP<000IJEP03001JEUYF00AJEPD000=JEP<000MJEP03001JEUYF00=JEP8000=J
EP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP@000Aoo`<001Eoo`800003FUH005YF
009JEP8002]oo`00;7oo00@005YFFUH000AJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEP80009JEP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00T000IJEP03001J
EUYF00<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00@001Uoo`<000=JEP8002]oo`00;Goo0`000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF1P000UYF00<005YF
FUH00eYF3P0000=JEP00FUH01UYF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH015YF6@0000QJEP00FUH005YF001JEP00:goo000_Ool01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@005YFFUIJEP8000=JEP<0
009JEP03001JEUYF00=JEPX000EJEP03001JEUYF00EJEP<000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00=JEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000800005FUH00000
FUH0000[Ool0031oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP07001JEUYFFUH005YF00001EYF00<005YF00000`000eYF0`000UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUH0
000[Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF0003FUH30003FUH400000eYF00000002FUH70006FUH00`00FUIJEP06FUH00`00
FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF0P00;7oo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00P001UYF00<005YF00001`00
0eYF00<005YFFUH01eYF00<005YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00@0
0003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P00;7oo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P000UYF1P001EYF00<005YFFUH01eYF00<005YFFUH015YF4@000UYF
00@005YF000002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF1@002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH0100000=JEP00FUH01UYF00<005YFFUH00UYF2000;Goo000_Ool00`00FUH00003FUH01000
FUIJEUYF400015YF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00IJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00EJEP03001JEP000080009JEP03001JEUYF00<002eo
o`00;goo0P000eYF1@002Woo3`0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEPH0009J
EP<000MJEP03001JEUYF00=JEP@00003FUH005YF00=JEP04001JEP00000^Ool002moo`03FUH005YF
00D001=oo``00003FUH005YF00AJEP03001JEUYF009JEPP000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF00IJEP03001JEUYF009JEP80009oo`@00003FUH0000000<000EJEP04001J
EUYFFUH30005FUH00`00FUIJEP02FUH2000`Ool002ioo`04001JEP000002FUH00`00FUIJEP02000?
Ool3000;Ool<0002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF00<005YF00000P0027oo1`0015YF00H005YF000005YF0007FUH01@00FUIJEUYF
0000<Goo000^Ool20004FUH00`00FUIJEP02FUH3000;Ool5000>Ool200000eYF001JEP05FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH60009Ool5
00000goo000000040003FUH00`00FUIJEP05FUH01000FUH00000<Woo000^Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUH000002Goo1@0047oo0P001UYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`000eYF0P002goo20001UYF00<0
05YFFUH015YF0`00=7oo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Woo
1@004Woo0P000eYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH00UYF0P000eYF0`0000=JEP0000001Woo1`0015YF00<005YFFUH01UYF00@005YFFUIJ
EP8003Moo`00;goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEPD0009oo`<001Eoo`800004FUH0
05YF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUH000001EYF00<0
05YFFUH00`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Uoo`00;goo
00D005YFFUIJEP0000EJEP03001JEUYF00IJEP04001JEUYFFUH90008Ool=00001EYF001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000eYF4@001UYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>goo000`Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF00<005YF00000`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUH005YF
001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?Woo
000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEP`0
0003FUH005YF00YJEPT000QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0049oo`00<goo00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000Agoo000dOol20002FUH00`00FUIJEP04FUH50006
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP040006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF1`00Bgoo000fOol30002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUHE
001AOol003Moo`@000IJEP03001JEUYF00MJEP03001JEUYF009JEPP000=JEP03001JEUYF00D00003
FUH00000009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001oo`0000<0009JEP03001JEUYF00=J
EP07001JEUYFFUH005YF0000DGoo000dOol300000eYF001JEP08FUH00`00FUIJEP04FUH70002FUH0
0`00FUIJEP06FUH40003FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP03001o
ogoo00=oo`<000EJEP07001JEUYFFUH005YF0000DGoo000bOol20004FUH00`00FUIJEP07FUH00`00
FUIJEP050008FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH00002FUH00`00FUH00002
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001oo`07Ool20003FUH01`00FUIJEUYF001JEP00055oo`00
<7oo0`001UYF00<005YFFUH015YF1@000eYF0`001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF0`000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000Yoo`800003FUH0
05YF009JEP80059oo`00;Woo0P000UYF00<005YFFUH015YF00<005YFFUH010000goo2@001UYF00<0
05YFFUH00`001EYF00<005YFFUH00eYF00D007oo001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP00000<Ool20003FUH2001BOol002eoo`03001JEUYF009JEP03001JEUYF00AJEP<0
00]oo`L000=JEP@00003FUH005YF00IJEP03001JEUYF0080009oo`<000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0001000004FUH005YF001BOol002aoo`8000EJEP04001JEUYFFUH2000>
Ool:0005FUH00`00FUIJEP05FUH30004Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YF00000P0000EJEP00001JEP00059oo`00:goo
00<005YF00001EYF00@005YF0000015oo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000Mo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YF0000DWoo000[Ool01000FUIJEP000eYF0`003Goo1P001UYF00<005YF
FUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP8005=oo`00:goo00D005YFFUH005YF008000Qoo`P0
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000ioo`03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P00Dgoo000/Ool01000FUH0
00000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010004Woo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000eYF2`000UYF00@005YF000005=oo`00;7oo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0067oo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEPL000=JEP03001JEUYF009JEPP005Aoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010007goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEUYF00<005Aoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P009Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00@005YF000005Eoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH00UYF2000;Goo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF10001UYF
00<005YFFUH015YF0P000eYF00<005YFFUH00UYF0P00Egoo000_Ool<000hOol70005FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH=0004FUH01000FUIJEUYF0`001UYF00D005YFFUIJ
EP0005Qoo`00NWoo30001UYF00<005YFFUH02EYF00@005YFFUIJEPH000Moo`D00003Ool0000000H0
0003FUH005YF00IJEP04001JEP00001IOol008IooaH000eoo`X000EJEP03001JEUYF00AJEP<005]o
o`00S7oo00@005YFFUH000AJEP8001Aoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH2001NOol0
08aoo`05001JEUYFFUH00002FUH00`00Oomoo`0=Ool70006FUH00`00FUIJEP06FUH01000FUH00000
H7oo002<Ool01000FUIJEUYF4`0015YF00<005YFFUH01eYF00<005YFFUH015YF0`00HWoo002=Ool0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
001UOol008eoo`<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJ
EPD006Uoo`00SGoo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01000KWoo002>Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001b
Ool0091oo`D000=JEP04001JEUYFFUH8001iOol009Eoo`L0085oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58347 .7544 m .59588 .70166 L .56551 .6928 L p .707 .577 .707 r
F P
0 g
s
.59588 .70166 m .58347 .7544 L .61458 .7599 L p .707 .577 .707 r
F P
0 g
s
.61458 .7599 m .627 .70717 L .59588 .70166 L p .707 .577 .707 r
F P
0 g
s
.55309 .74554 m .56551 .6928 L .53885 .68144 L p .707 .577 .707 r
F P
0 g
s
.56551 .6928 m .55309 .74554 L .58347 .7544 L p .707 .577 .707 r
F P
0 g
s
.627 .70717 m .61458 .7599 L .64339 .76151 L p .707 .577 .707 r
F P
0 g
s
.64339 .76151 m .65581 .70877 L .627 .70717 L p .707 .577 .707 r
F P
0 g
s
.60405 .81715 m .6123 .78198 L .58192 .77314 L p .707 .577 .707 r
F P
0 g
s
.6123 .78198 m .60405 .81715 L .63517 .82264 L p .707 .577 .707 r
F P
0 g
s
.63517 .82264 m .64342 .78747 L .6123 .78198 L p .707 .577 .707 r
F P
0 g
s
.52643 .73418 m .53885 .68144 L .51851 .66871 L p .707 .577 .707 r
F P
0 g
s
.53885 .68144 m .52643 .73418 L .55309 .74554 L p .707 .577 .707 r
F P
0 g
s
.65581 .70877 m .64339 .76151 L .66708 .75906 L p .707 .577 .707 r
F P
0 g
s
.66708 .75906 m .67949 .70632 L .65581 .70877 L p .707 .577 .707 r
F P
0 g
s
.57367 .80831 m .58192 .77314 L .55526 .76181 L p .707 .577 .707 r
F P
0 g
s
.58192 .77314 m .57367 .80831 L .60405 .81715 L p .707 .577 .707 r
F P
0 g
s
.64342 .78747 m .63517 .82264 L .66398 .82423 L p .707 .577 .707 r
F P
0 g
s
.66398 .82423 m .67223 .78906 L .64342 .78747 L p .707 .577 .707 r
F P
0 g
s
.55526 .76181 m .547 .79697 L .57367 .80831 L p .707 .577 .707 r
F P
0 g
s
.547 .79697 m .55526 .76181 L .53492 .74909 L p .707 .577 .707 r
F P
0 g
s
.67223 .78906 m .66398 .82423 L .68767 .82177 L p .707 .577 .707 r
F P
0 g
s
.68767 .82177 m .69592 .7866 L .67223 .78906 L p .707 .577 .707 r
F P
0 g
s
.51851 .66871 m .5061 .72145 L .52643 .73418 L p .707 .577 .707 r
F P
0 g
s
.58919 .84096 m .58341 .82281 L .55381 .83092 L p .707 .577 .707 r
F P
0 g
s
.58341 .82281 m .58919 .84096 L .6196 .83114 L p .707 .577 .707 r
F P
0 g
s
.6196 .83114 m .61382 .81299 L .58341 .82281 L p .707 .577 .707 r
F P
0 g
s
.5061 .72145 m .51851 .66871 L .50649 .65584 L p .707 .577 .707 r
F P
0 g
s
.61382 .81299 m .6196 .83114 L .64785 .82059 L p .707 .577 .707 r
F P
0 g
s
.64785 .82059 m .64207 .80244 L .61382 .81299 L p .707 .577 .707 r
F P
0 g
s
.67949 .70632 m .66708 .75906 L .68332 .75279 L p .707 .577 .707 r
F P
0 g
s
.68332 .75279 m .69574 .70006 L .67949 .70632 L p .707 .577 .707 r
F P
0 g
s
.55381 .83092 m .5596 .84907 L .58919 .84096 L p .707 .577 .707 r
F P
0 g
s
.53492 .74909 m .52666 .78425 L .547 .79697 L p .707 .577 .707 r
F P
0 g
s
.5596 .84907 m .55381 .83092 L .52794 .83655 L p .707 .577 .707 r
F P
0 g
s
.64207 .80244 m .64785 .82059 L .67118 .81034 L p .707 .577 .707 r
F P
0 g
s
.67118 .81034 m .6654 .79219 L .64207 .80244 L p .707 .577 .707 r
F P
0 g
s
.52794 .83655 m .53372 .8547 L .5596 .84907 L p .707 .577 .707 r
F P
0 g
s
.52666 .78425 m .53492 .74909 L .52289 .73623 L p .707 .577 .707 r
F P
0 g
s
.69592 .7866 m .68767 .82177 L .70391 .8155 L p .707 .577 .707 r
F P
0 g
s
.70391 .8155 m .71217 .78033 L .69592 .7866 L p .707 .577 .707 r
F P
0 g
s
.50649 .65584 m .49407 .70858 L .5061 .72145 L p .707 .577 .707 r
F P
0 g
s
.53372 .8547 m .52794 .83655 L .5083 .83913 L p .707 .577 .707 r
F P
0 g
s
.49407 .70858 m .50649 .65584 L .50396 .6441 L p .707 .577 .707 r
F P
0 g
s
.69574 .70006 m .68332 .75279 L .69053 .74333 L p .707 .577 .707 r
F P
0 g
s
.69053 .74333 m .70295 .69059 L .69574 .70006 L p .707 .577 .707 r
F P
0 g
s
.52289 .73623 m .51464 .7714 L .52666 .78425 L p .707 .577 .707 r
F P
0 g
s
.5083 .83913 m .51409 .85728 L .53372 .8547 L p .707 .577 .707 r
F P
0 g
s
.6654 .79219 m .67118 .81034 L .6873 .80139 L p .707 .577 .707 r
F P
0 g
s
.6873 .80139 m .68152 .78324 L .6654 .79219 L p .707 .577 .707 r
F P
0 g
s
.51464 .7714 m .52289 .73623 L .52036 .7245 L p .707 .577 .707 r
F P
0 g
s
.71217 .78033 m .70391 .8155 L .71112 .80604 L p .707 .577 .707 r
F P
0 g
s
.71112 .80604 m .71938 .77087 L .71217 .78033 L p .707 .577 .707 r
F P
0 g
s
.50396 .6441 m .49155 .69683 L .49407 .70858 L p .707 .577 .707 r
F P
0 g
s
.51409 .85728 m .5083 .83913 L .49684 .83842 L p .707 .577 .707 r
F P
0 g
s
.49684 .83842 m .50262 .85657 L .51409 .85728 L p .707 .577 .707 r
F P
0 g
s
.52036 .7245 m .51211 .75967 L .51464 .7714 L p .707 .577 .707 r
F P
0 g
s
.49155 .69683 m .50396 .6441 L .51117 .63463 L p .707 .577 .707 r
F P
0 g
s
.68152 .78324 m .6873 .80139 L .69463 .79461 L p .707 .577 .707 r
F P
0 g
s
.69463 .79461 m .68885 .77646 L .68152 .78324 L p .707 .577 .707 r
F P
0 g
s
.70295 .69059 m .69053 .74333 L .688 .73158 L p .707 .577 .707 r
F P
0 g
s
.688 .73158 m .70042 .67885 L .70295 .69059 L p .707 .577 .707 r
F P
0 g
s
.51117 .63463 m .49875 .68737 L .49155 .69683 L p .707 .577 .707 r
F P
0 g
s
.49448 .82173 m .48855 .31924 L .44455 .31708 L p .707 .577 .707 r
F P
0 g
s
.51211 .75967 m .52036 .7245 L .52757 .71504 L p .707 .577 .707 r
F P
0 g
s
.52757 .71504 m .51932 .7502 L .51211 .75967 L p .707 .577 .707 r
F P
0 g
s
.49875 .68737 m .51117 .63463 L .52741 .62836 L p .707 .577 .707 r
F P
0 g
s
.51932 .7502 m .52757 .71504 L .54381 .70877 L p .707 .577 .707 r
F P
0 g
s
.52741 .62836 m .515 .6811 L .49875 .68737 L p .707 .577 .707 r
F P
0 g
s
.515 .6811 m .52741 .62836 L .5511 .62592 L p .707 .577 .707 r
F P
0 g
s
.54381 .70877 m .53556 .74393 L .51932 .7502 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .53868 .67865 L .515 .6811 L p .707 .577 .707 r
F P
0 g
s
.50779 .84585 m .502 .8277 L .51812 .81875 L p .707 .577 .707 r
F P
0 g
s
.51812 .81875 m .52391 .8369 L .50779 .84585 L p .707 .577 .707 r
F P
0 g
s
.52391 .8369 m .51812 .81875 L .54145 .8085 L p .707 .577 .707 r
F P
0 g
s
.54145 .8085 m .54723 .82665 L .52391 .8369 L p .707 .577 .707 r
F P
0 g
s
.48855 .31924 m .49448 .82173 L .53943 .82015 L p .707 .577 .707 r
F P
0 g
s
.53556 .74393 m .54381 .70877 L .5675 .70631 L p .707 .577 .707 r
F P
0 g
s
.5675 .70631 m .55925 .74148 L .53556 .74393 L p .707 .577 .707 r
F P
0 g
s
.53943 .82015 m .53349 .31767 L .48855 .31924 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .57991 .62752 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.53868 .67865 m .5452 .65097 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.5452 .65097 m .5511 .62592 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.62971 .78001 m .63549 .79816 L .6059 .80628 L p .707 .577 .707 r
F P
0 g
s
.6059 .80628 m .60011 .78813 L .62971 .78001 L p .707 .577 .707 r
F P
0 g
s
.60011 .78813 m .6059 .80628 L .57548 .8161 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .61486 .80679 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.56749 .68026 m .57991 .62752 L .61102 .63303 L p .707 .577 .707 r
F P
0 g
s
.57991 .62752 m .56749 .68026 L .53868 .67865 L p .707 .577 .707 r
F P
0 g
s
.6414 .64189 m .62898 .69463 L .59861 .68576 L p .707 .577 .707 r
F P
0 g
s
.59861 .68576 m .61102 .63303 L .6414 .64189 L p .707 .577 .707 r
F P
0 g
s
.55925 .74148 m .5675 .70631 L .59632 .7079 L p .707 .577 .707 r
F P
0 g
s
.61102 .63303 m .59861 .68576 L .56749 .68026 L p .707 .577 .707 r
F P
0 g
s
.59632 .7079 m .58806 .74307 L .55925 .74148 L p .707 .577 .707 r
F P
0 g
s
.58806 .74307 m .59632 .7079 L .62744 .71339 L p .707 .577 .707 r
F P
0 g
s
.62744 .71339 m .61918 .74855 L .58806 .74307 L p .707 .577 .707 r
F P
0 g
s
.57497 .31252 m .57981 .72266 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.57548 .8161 m .5697 .79795 L .60011 .78813 L p .707 .577 .707 r
F P
0 g
s
.57981 .72266 m .5809 .81501 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.54723 .82665 m .54145 .8085 L .5697 .79795 L p .707 .577 .707 r
F P
0 g
s
.5697 .79795 m .57548 .8161 L .54723 .82665 L p .707 .577 .707 r
F P
0 g
s
.53349 .31767 m .53943 .82015 L .5809 .81501 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .57497 .31252 L .53349 .31767 L p .707 .577 .707 r
F P
0 g
s
.45048 .81957 m .44455 .31708 L .40579 .31141 L p .707 .577 .707 r
F P
0 g
s
.44455 .31708 m .45048 .81957 L .49448 .82173 L p .707 .577 .707 r
F P
0 g
s
.71938 .77087 m .71112 .80604 L .70859 .7943 L p .707 .577 .707 r
F P
0 g
s
.70859 .7943 m .71684 .75914 L .71938 .77087 L p .707 .577 .707 r
F P
0 g
s
.61486 .80679 m .60893 .3043 L .57497 .31252 L p .707 .577 .707 r
F P
0 g
s
.50262 .85657 m .49684 .83842 L .49467 .83448 L p .707 .577 .707 r
F P
0 g
s
.49467 .83448 m .50045 .85263 L .50262 .85657 L p .707 .577 .707 r
F P
0 g
s
.70042 .67885 m .688 .73158 L .67598 .71872 L p .707 .577 .707 r
F P
0 g
s
.67598 .71872 m .68839 .66598 L .70042 .67885 L p .707 .577 .707 r
F P
0 g
s
.68885 .77646 m .69463 .79461 L .69246 .79067 L p .707 .577 .707 r
F P
0 g
s
.69246 .79067 m .68668 .77252 L .68885 .77646 L p .707 .577 .707 r
F P
0 g
s
.41172 .8139 m .40579 .31141 L .37606 .30277 L p .707 .577 .707 r
F P
0 g
s
.40579 .31141 m .41172 .8139 L .45048 .81957 L p .707 .577 .707 r
F P
0 g
s
.24046 .71764 m .25287 .66491 L .2225 .65604 L p .707 .577 .707 r
F P
0 g
s
.25287 .66491 m .24046 .71764 L .27157 .72315 L p .707 .577 .707 r
F P
0 g
s
.27157 .72315 m .28399 .67041 L .25287 .66491 L p .707 .577 .707 r
F P
0 g
s
.21008 .70878 m .2225 .65604 L .19584 .64469 L p .707 .577 .707 r
F P
0 g
s
.2225 .65604 m .21008 .70878 L .24046 .71764 L p .707 .577 .707 r
F P
0 g
s
.28399 .67041 m .27157 .72315 L .30038 .72475 L p .707 .577 .707 r
F P
0 g
s
.30038 .72475 m .3128 .67202 L .28399 .67041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71684 .75914 m .70859 .7943 L .69657 .78145 L p .707 .577 .707 r
F P
0 g
s
.69657 .78145 m .70482 .74628 L .71684 .75914 L p .707 .577 .707 r
F P
0 g
s
.26104 .7805 m .26929 .74534 L .23891 .73649 L p .707 .577 .707 r
F P
0 g
s
.26929 .74534 m .26104 .7805 L .29216 .78599 L p .707 .577 .707 r
F P
0 g
s
.29216 .78599 m .30041 .75082 L .26929 .74534 L p .707 .577 .707 r
F P
0 g
s
.66806 .65324 m .65564 .70598 L .62898 .69463 L p .707 .577 .707 r
F P
0 g
s
.62898 .69463 m .6414 .64189 L .66806 .65324 L p .707 .577 .707 r
F P
0 g
s
.65781 .72223 m .64956 .7574 L .61918 .74855 L p .707 .577 .707 r
F P
0 g
s
.61918 .74855 m .62744 .71339 L .65781 .72223 L p .707 .577 .707 r
F P
0 g
s
.65559 .77439 m .66137 .79254 L .63549 .79816 L p .707 .577 .707 r
F P
0 g
s
.63549 .79816 m .62971 .78001 L .65559 .77439 L p .707 .577 .707 r
F P
0 g
s
.60893 .3043 m .61486 .80679 L .63797 .7963 L p .707 .577 .707 r
F P
0 g
s
.63797 .7963 m .63204 .29382 L .60893 .3043 L p .707 .577 .707 r
F P
0 g
s
.18342 .69743 m .19584 .64469 L .1755 .63195 L p .707 .577 .707 r
F P
0 g
s
.19584 .64469 m .18342 .69743 L .21008 .70878 L p .707 .577 .707 r
F P
0 g
s
.3128 .67202 m .30038 .72475 L .32407 .7223 L p .707 .577 .707 r
F P
0 g
s
.32407 .7223 m .33648 .66957 L .3128 .67202 L p .707 .577 .707 r
F P
0 g
s
.23066 .77166 m .23891 .73649 L .21225 .72516 L p .707 .577 .707 r
F P
0 g
s
.23891 .73649 m .23066 .77166 L .26104 .7805 L p .707 .577 .707 r
F P
0 g
s
.50045 .85263 m .49467 .83448 L .502 .8277 L p .707 .577 .707 r
F P
0 g
s
.30041 .75082 m .29216 .78599 L .32097 .78758 L p .707 .577 .707 r
F P
0 g
s
.32097 .78758 m .32923 .75242 L .30041 .75082 L p .707 .577 .707 r
F P
0 g
s
.68839 .66598 m .67598 .71872 L .65564 .70598 L p .707 .577 .707 r
F P
0 g
s
.65564 .70598 m .66806 .65324 L .68839 .66598 L p .707 .577 .707 r
F P
0 g
s
.502 .8277 m .50779 .84585 L .50045 .85263 L p .707 .577 .707 r
F P
0 g
s
.68668 .77252 m .69246 .79067 L .681 .78996 L p .707 .577 .707 r
F P
0 g
s
.681 .78996 m .67522 .77181 L .68668 .77252 L p .707 .577 .707 r
F P
0 g
s
.382 .80526 m .37606 .30277 L .35829 .29202 L p .707 .577 .707 r
F P
0 g
s
.37606 .30277 m .382 .80526 L .41172 .8139 L p .707 .577 .707 r
F P
0 g
s
.21225 .72516 m .204 .76033 L .23066 .77166 L p .707 .577 .707 r
F P
0 g
s
.204 .76033 m .21225 .72516 L .19191 .71244 L p .707 .577 .707 r
F P
0 g
s
.32923 .75242 m .32097 .78758 L .34466 .78512 L p .707 .577 .707 r
F P
0 g
s
.34466 .78512 m .35291 .74996 L .32923 .75242 L p .707 .577 .707 r
F P
0 g
s
.70482 .74628 m .69657 .78145 L .67623 .76873 L p .707 .577 .707 r
F P
0 g
s
.67623 .76873 m .68448 .73357 L .70482 .74628 L p .707 .577 .707 r
F P
0 g
s
.1755 .63195 m .16309 .68469 L .18342 .69743 L p .707 .577 .707 r
F P
0 g
s
.24618 .80343 m .2404 .78528 L .21081 .7934 L p .707 .577 .707 r
F P
0 g
s
.2404 .78528 m .24618 .80343 L .27659 .79362 L p .707 .577 .707 r
F P
0 g
s
.27659 .79362 m .27081 .77547 L .2404 .78528 L p .707 .577 .707 r
F P
0 g
s
.16309 .68469 m .1755 .63195 L .16348 .61908 L p .707 .577 .707 r
F P
0 g
s
.27081 .77547 m .27659 .79362 L .30484 .78307 L p .707 .577 .707 r
F P
0 g
s
.30484 .78307 m .29906 .76492 L .27081 .77547 L p .707 .577 .707 r
F P
0 g
s
.33648 .66957 m .32407 .7223 L .34031 .71604 L p .707 .577 .707 r
F P
0 g
s
.34031 .71604 m .35273 .6633 L .33648 .66957 L p .707 .577 .707 r
F P
0 g
s
.21081 .7934 m .21659 .81155 L .24618 .80343 L p .707 .577 .707 r
F P
0 g
s
.19191 .71244 m .18366 .74761 L .204 .76033 L p .707 .577 .707 r
F P
0 g
s
.21659 .81155 m .21081 .7934 L .18493 .79902 L p .707 .577 .707 r
F P
0 g
s
.29906 .76492 m .30484 .78307 L .32817 .77281 L p .707 .577 .707 r
F P
0 g
s
.32817 .77281 m .32239 .75466 L .29906 .76492 L p .707 .577 .707 r
F P
0 g
s
.18493 .79902 m .19071 .81717 L .21659 .81155 L p .707 .577 .707 r
F P
0 g
s
.63204 .29382 m .63797 .7963 L .64797 .78458 L p .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64204 .28209 L .63204 .29382 L p .707 .577 .707 r
F P
0 g
s
.18366 .74761 m .19191 .71244 L .17988 .69959 L p .707 .577 .707 r
F P
0 g
s
.67522 .77181 m .681 .78996 L .66137 .79254 L p .707 .577 .707 r
F P
0 g
s
.66137 .79254 m .65559 .77439 L .67522 .77181 L p .707 .577 .707 r
F P
0 g
s
.35291 .74996 m .34466 .78512 L .36091 .77886 L p .707 .577 .707 r
F P
0 g
s
.36091 .77886 m .36916 .74369 L .35291 .74996 L p .707 .577 .707 r
F P
0 g
s
.68448 .73357 m .67623 .76873 L .64956 .7574 L p .707 .577 .707 r
F P
0 g
s
.64956 .7574 m .65781 .72223 L .68448 .73357 L p .707 .577 .707 r
F P
0 g
s
.16348 .61908 m .15107 .67182 L .16309 .68469 L p .707 .577 .707 r
F P
0 g
s
.19071 .81717 m .18493 .79902 L .1653 .8016 L p .707 .577 .707 r
F P
0 g
s
.15107 .67182 m .16348 .61908 L .16095 .60734 L p .707 .577 .707 r
F P
0 g
s
.35273 .6633 m .34031 .71604 L .34752 .70657 L p .707 .577 .707 r
F P
0 g
s
.34752 .70657 m .35994 .65384 L .35273 .6633 L p .707 .577 .707 r
F P
0 g
s
.17988 .69959 m .17163 .73475 L .18366 .74761 L p .707 .577 .707 r
F P
0 g
s
.1653 .8016 m .17108 .81975 L .19071 .81717 L p .707 .577 .707 r
F P
0 g
s
.32239 .75466 m .32817 .77281 L .34429 .76386 L p .707 .577 .707 r
F P
0 g
s
.34429 .76386 m .33851 .74571 L .32239 .75466 L p .707 .577 .707 r
F P
0 g
s
.36916 .74369 m .36091 .77886 L .36811 .76939 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .35356 .7448 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.37383 .72249 m .3676 .74906 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.3676 .74906 m .36558 .75766 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .3542 .2802 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36181 .70964 L .36568 .71377 L p .707 .577 .707 r
F P
0 g
s
.36568 .71377 m .37383 .72249 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36568 .71377 L .36659 .73047 L .707 .577 .707 r
F
.35162 .75708 m .34584 .73893 L .33851 .74571 L p F P
0 g
s
.36181 .70964 m .35356 .7448 L .34754 .74104 L p .707 .577 .707 r
F P
0 g
s
.34584 .73893 m .35162 .75708 L .34945 .75314 L p .707 .577 .707 r
F P
0 g
s
.34945 .75314 m .34367 .73499 L .34584 .73893 L p .707 .577 .707 r
F P
0 g
s
.33851 .74571 m .34429 .76386 L .35162 .75708 L p .707 .577 .707 r
F P
0 g
s
.34367 .73499 m .34945 .75314 L .33799 .75243 L p .707 .577 .707 r
F P
0 g
s
.33799 .75243 m .33221 .73428 L .34367 .73499 L p .707 .577 .707 r
F P
0 g
s
.34754 .74104 m .33322 .73209 L p .34793 .72054 L .707 .577 .707 r
F P
0 g
s
.34793 .72054 m .36181 .70964 L .34754 .74104 L .707 .577 .707 r
F
.35994 .65384 m .34752 .70657 L .34499 .69483 L p F P
0 g
s
.33322 .73209 m .34147 .69692 L .36181 .70964 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .36422 .79451 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3542 .2802 m .35756 .56475 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.34499 .69483 m .35741 .64209 L .35994 .65384 L p .707 .577 .707 r
F P
0 g
s
.35756 .56475 m .36013 .78269 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36422 .79451 m .3626 .6573 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3626 .6573 m .35829 .29202 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36811 .76939 m .37637 .73422 L .36916 .74369 L p .707 .577 .707 r
F P
0 g
s
.37637 .73422 m .36811 .76939 L .36558 .75766 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .37383 .72249 L .37637 .73422 L p .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .36422 .79451 L .382 .80526 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .35497 .34512 L p .3642 .26848 L .707 .577 .707 r
F P
0 g
s
.35497 .34512 m .3542 .2802 L .35623 .27782 L p .707 .577 .707 r
F P
0 g
s
.35623 .27782 m .3642 .26848 L p .35497 .34512 L .707 .577 .707 r
F P
0 g
s
.17163 .73475 m .17988 .69959 L .17735 .68785 L p .707 .577 .707 r
F P
0 g
s
.16095 .60734 m .14854 .66008 L .15107 .67182 L p .707 .577 .707 r
F P
0 g
s
.17108 .81975 m .1653 .8016 L .15383 .80089 L p .707 .577 .707 r
F P
0 g
s
.15383 .80089 m .15961 .81904 L .17108 .81975 L p .707 .577 .707 r
F P
0 g
s
.17735 .68785 m .1691 .72302 L .17163 .73475 L p .707 .577 .707 r
F P
0 g
s
.14854 .66008 m .16095 .60734 L .16816 .59787 L p .707 .577 .707 r
F P
0 g
s
.64204 .28209 m .64783 .77275 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64204 .28209 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64388 .77276 m .64188 .603 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64188 .603 m .63795 .27027 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64388 .77276 L .62611 .76201 L p .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .64116 .55206 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.63128 .61654 m .6378 .58885 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .64369 .5638 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .6378 .58885 L p .6433 .62941 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .63128 .61654 L .6398 .62566 L p .707 .577 .707 r
F P
0 g
s
.6398 .62566 m .6433 .62941 L p .6378 .58885 L .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64388 .77276 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.64783 .77275 m .64797 .78458 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1691 .72302 m .17735 .68785 L .18456 .67839 L p .707 .577 .707 r
F P
0 g
s
.16816 .59787 m .15575 .65061 L .14854 .66008 L p .707 .577 .707 r
F P
0 g
s
.15961 .81904 m .15383 .80089 L .15166 .79695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15166 .79695 m .15744 .8151 L .15961 .81904 L p .707 .577 .707 r
F P
0 g
s
.18456 .67839 m .17631 .71356 L .1691 .72302 L p .707 .577 .707 r
F P
0 g
s
.15575 .65061 m .16816 .59787 L .1844 .59161 L p .707 .577 .707 r
F P
0 g
s
.35741 .64209 m .34499 .69483 L .33297 .68196 L p .707 .577 .707 r
F P
0 g
s
.33297 .68196 m .34539 .62922 L .35741 .64209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62611 .76201 m .62017 .25952 L .63795 .27027 L p .707 .577 .707 r
F P
0 g
s
.17631 .71356 m .18456 .67839 L .2008 .67212 L p .707 .577 .707 r
F P
0 g
s
.1844 .59161 m .17199 .64435 L .15575 .65061 L p .707 .577 .707 r
F P
0 g
s
.17199 .64435 m .1844 .59161 L .20809 .58916 L p .707 .577 .707 r
F P
0 g
s
.15744 .8151 m .15166 .79695 L .159 .79018 L p .707 .577 .707 r
F P
0 g
s
.34539 .62922 m .33297 .68196 L .31263 .66923 L p .707 .577 .707 r
F P
0 g
s
.31263 .66923 m .32505 .61649 L .34539 .62922 L p .707 .577 .707 r
F P
0 g
s
.2008 .67212 m .19255 .70729 L .17631 .71356 L p .707 .577 .707 r
F P
0 g
s
.159 .79018 m .16478 .80833 L .15744 .8151 L p .707 .577 .707 r
F P
0 g
s
.37013 .77096 m .3642 .26848 L .38731 .25799 L p .707 .577 .707 r
F P
0 g
s
.3642 .26848 m .37013 .77096 L .36013 .78269 L p .707 .577 .707 r
F P
0 g
s
.19255 .70729 m .2008 .67212 L .22449 .66966 L p .707 .577 .707 r
F P
0 g
s
.20809 .58916 m .19567 .6419 L .17199 .64435 L p .707 .577 .707 r
F P
0 g
s
.19567 .6419 m .20809 .58916 L .2369 .59077 L p .707 .577 .707 r
F P
0 g
s
.32505 .61649 m .31263 .66923 L .28597 .65787 L p .707 .577 .707 r
F P
0 g
s
.28597 .65787 m .29839 .60513 L .32505 .61649 L p .707 .577 .707 r
F P
0 g
s
.62017 .25952 m .62611 .76201 L .59638 .75337 L p .707 .577 .707 r
F P
0 g
s
.59638 .75337 m .59045 .25088 L .62017 .25952 L p .707 .577 .707 r
F P
0 g
s
.22449 .66966 m .21624 .70483 L .19255 .70729 L p .707 .577 .707 r
F P
0 g
s
.16478 .80833 m .159 .79018 L .17511 .78122 L p .707 .577 .707 r
F P
0 g
s
.17511 .78122 m .1809 .79937 L .16478 .80833 L p .707 .577 .707 r
F P
0 g
s
.22448 .6435 m .2369 .59077 L .26802 .59627 L p .707 .577 .707 r
F P
0 g
s
.2369 .59077 m .22448 .6435 L .19567 .6419 L p .707 .577 .707 r
F P
0 g
s
.29839 .60513 m .28597 .65787 L .2556 .64901 L p .707 .577 .707 r
F P
0 g
s
.2556 .64901 m .26802 .59627 L .29839 .60513 L p .707 .577 .707 r
F P
0 g
s
.33221 .73428 m .33799 .75243 L .31836 .75501 L p .707 .577 .707 r
F P
0 g
s
.31836 .75501 m .31258 .73686 L .33221 .73428 L p .707 .577 .707 r
F P
0 g
s
.21624 .70483 m .22449 .66966 L .25331 .67126 L p .707 .577 .707 r
F P
0 g
s
.34147 .69692 m .33322 .73209 L .30655 .72075 L p .707 .577 .707 r
F P
0 g
s
.30655 .72075 m .31481 .68558 L .34147 .69692 L p .707 .577 .707 r
F P
0 g
s
.26802 .59627 m .2556 .64901 L .22448 .6435 L p .707 .577 .707 r
F P
0 g
s
.38731 .25799 m .39324 .76048 L .37013 .77096 L p .707 .577 .707 r
F P
0 g
s
.39324 .76048 m .38731 .25799 L .42127 .24977 L p .707 .577 .707 r
F P
0 g
s
.72067 .66236 m .73308 .60962 L .70271 .60076 L p .707 .577 .707 r
F P
0 g
s
.73308 .60962 m .72067 .66236 L .75179 .66786 L p .707 .577 .707 r
F P
0 g
s
.75179 .66786 m .7642 .61513 L .73308 .60962 L p .707 .577 .707 r
F P
0 g
s
.25331 .67126 m .24505 .70642 L .21624 .70483 L p .707 .577 .707 r
F P
0 g
s
.24505 .70642 m .25331 .67126 L .28443 .67674 L p .707 .577 .707 r
F P
0 g
s
.6903 .6535 m .70271 .60076 L .67605 .58941 L p .707 .577 .707 r
F P
0 g
s
.70271 .60076 m .6903 .6535 L .72067 .66236 L p .707 .577 .707 r
F P
0 g
s
.31481 .68558 m .30655 .72075 L .27617 .71191 L p .707 .577 .707 r
F P
0 g
s
.27617 .71191 m .28443 .67674 L .31481 .68558 L p .707 .577 .707 r
F P
0 g
s
.7642 .61513 m .75179 .66786 L .7806 .66947 L p .707 .577 .707 r
F P
0 g
s
.7806 .66947 m .79301 .61673 L .7642 .61513 L p .707 .577 .707 r
F P
0 g
s
.28443 .67674 m .27617 .71191 L .24505 .70642 L p .707 .577 .707 r
F P
0 g
s
.1809 .79937 m .17511 .78122 L .19844 .77097 L p .707 .577 .707 r
F P
0 g
s
.19844 .77097 m .20422 .78912 L .1809 .79937 L p .707 .577 .707 r
F P
0 g
s
.31258 .73686 m .31836 .75501 L .29248 .76064 L p .707 .577 .707 r
F P
0 g
s
.29248 .76064 m .2867 .74249 L .31258 .73686 L p .707 .577 .707 r
F P
0 g
s
.59045 .25088 m .59638 .75337 L .55762 .7477 L p .707 .577 .707 r
F P
0 g
s
.55762 .7477 m .55169 .24521 L .59045 .25088 L p .707 .577 .707 r
F P
0 g
s
.74125 .72511 m .7495 .68995 L .71913 .6811 L p .707 .577 .707 r
F P
0 g
s
.7495 .68995 m .74125 .72511 L .77237 .7306 L p .707 .577 .707 r
F P
0 g
s
.77237 .7306 m .78062 .69543 L .7495 .68995 L p .707 .577 .707 r
F P
0 g
s
.66364 .64214 m .67605 .58941 L .65571 .57667 L p .707 .577 .707 r
F P
0 g
s
.67605 .58941 m .66364 .64214 L .6903 .6535 L p .707 .577 .707 r
F P
0 g
s
.79301 .61673 m .7806 .66947 L .80428 .66702 L p .707 .577 .707 r
F P
0 g
s
.80428 .66702 m .8167 .61428 L .79301 .61673 L p .707 .577 .707 r
F P
0 g
s
.71087 .71627 m .71913 .6811 L .69246 .66977 L p .707 .577 .707 r
F P
0 g
s
.71913 .6811 m .71087 .71627 L .74125 .72511 L p .707 .577 .707 r
F P
0 g
s
.78062 .69543 m .77237 .7306 L .80119 .73219 L p .707 .577 .707 r
F P
0 g
s
.80119 .73219 m .80944 .69702 L .78062 .69543 L p .707 .577 .707 r
F P
0 g
s
.4272 .75226 m .42127 .24977 L .46274 .24463 L p .707 .577 .707 r
F P
0 g
s
.42127 .24977 m .4272 .75226 L .39324 .76048 L p .707 .577 .707 r
F P
0 g
s
.20422 .78912 m .19844 .77097 L .22669 .76042 L p .707 .577 .707 r
F P
0 g
s
.2867 .74249 m .29248 .76064 L .26289 .76875 L p .707 .577 .707 r
F P
0 g
s
.26289 .76875 m .2571 .7506 L .2867 .74249 L p .707 .577 .707 r
F P
0 g
s
.22669 .76042 m .23247 .77857 L .20422 .78912 L p .707 .577 .707 r
F P
0 g
s
.69246 .66977 m .68421 .70493 L .71087 .71627 L p .707 .577 .707 r
F P
0 g
s
.68421 .70493 m .69246 .66977 L .67212 .65705 L p .707 .577 .707 r
F P
0 g
s
.80944 .69702 m .80119 .73219 L .82488 .72973 L p .707 .577 .707 r
F P
0 g
s
.82488 .72973 m .83313 .69456 L .80944 .69702 L p .707 .577 .707 r
F P
0 g
s
.55169 .24521 m .55762 .7477 L .51362 .74554 L p .707 .577 .707 r
F P
0 g
s
.51362 .74554 m .50769 .24305 L .55169 .24521 L p .707 .577 .707 r
F P
0 g
s
.65571 .57667 m .6433 .62941 L .66364 .64214 L p .707 .577 .707 r
F P
0 g
s
.72639 .74892 m .72061 .73077 L .69102 .73889 L p .707 .577 .707 r
F P
0 g
s
.72061 .73077 m .72639 .74892 L .7568 .73911 L p .707 .577 .707 r
F P
0 g
s
.7568 .73911 m .75102 .72096 L .72061 .73077 L p .707 .577 .707 r
F P
0 g
s
.6433 .62941 m .65571 .57667 L .64369 .5638 L p .707 .577 .707 r
F P
0 g
s
.75102 .72096 m .7568 .73911 L .78506 .72856 L p .707 .577 .707 r
F P
0 g
s
.78506 .72856 m .77927 .71041 L .75102 .72096 L p .707 .577 .707 r
F P
0 g
s
.8167 .61428 m .80428 .66702 L .82053 .66076 L p .707 .577 .707 r
F P
0 g
s
.82053 .66076 m .83294 .60802 L .8167 .61428 L p .707 .577 .707 r
F P
0 g
s
.23247 .77857 m .22669 .76042 L .2571 .7506 L p .707 .577 .707 r
F P
0 g
s
.2571 .7506 m .26289 .76875 L .23247 .77857 L p .707 .577 .707 r
F P
0 g
s
.69102 .73889 m .6968 .75704 L .72639 .74892 L p .707 .577 .707 r
F P
0 g
s
.46868 .74711 m .46274 .24463 L .50769 .24305 L p .707 .577 .707 r
F P
0 g
s
.46274 .24463 m .46868 .74711 L .4272 .75226 L p .707 .577 .707 r
F P
0 g
s
.67212 .65705 m .66387 .69222 L .68421 .70493 L p .707 .577 .707 r
F P
0 g
s
.50769 .24305 m .51362 .74554 L .46868 .74711 L p .707 .577 .707 r
F P
0 g
s
.6968 .75704 m .69102 .73889 L .66514 .74451 L p .707 .577 .707 r
F P
0 g
s
.77927 .71041 m .78506 .72856 L .80838 .7183 L p .707 .577 .707 r
F P
0 g
s
.80838 .7183 m .8026 .70015 L .77927 .71041 L p .707 .577 .707 r
F P
0 g
s
.66514 .74451 m .67092 .76266 L .6968 .75704 L p .707 .577 .707 r
F P
0 g
s
.66387 .69222 m .67212 .65705 L .6601 .6442 L p .707 .577 .707 r
F P
0 g
s
.83313 .69456 m .82488 .72973 L .84112 .72346 L p .707 .577 .707 r
F P
0 g
s
.84112 .72346 m .84937 .6883 L .83313 .69456 L p .707 .577 .707 r
F P
0 g
s
.67092 .76266 m .66514 .74451 L .64551 .74709 L p .707 .577 .707 r
F P
0 g
s
.83294 .60802 m .82053 .66076 L .82774 .65129 L p .707 .577 .707 r
F P
0 g
s
.82774 .65129 m .84015 .59855 L .83294 .60802 L p .707 .577 .707 r
F P
0 g
s
.6601 .6442 m .65184 .67936 L .66387 .69222 L p .707 .577 .707 r
F P
0 g
s
.64551 .74709 m .65129 .76524 L .67092 .76266 L p .707 .577 .707 r
F P
0 g
s
.8026 .70015 m .80838 .7183 L .8245 .70935 L p .707 .577 .707 r
F P
0 g
s
.8245 .70935 m .81872 .6912 L .8026 .70015 L p .707 .577 .707 r
F P
0 g
s
.65184 .67936 m .6601 .6442 L .65756 .63246 L p .707 .577 .707 r
F P
0 g
s
.84937 .6883 m .84112 .72346 L .84833 .714 L p .707 .577 .707 r
F P
0 g
s
.84833 .714 m .85658 .67883 L .84937 .6883 L p .707 .577 .707 r
F P
0 g
s
.64116 .55206 m .62875 .6048 L .63128 .61654 L p .707 .577 .707 r
F P
0 g
s
.65129 .76524 m .64551 .74709 L .63405 .74638 L p .707 .577 .707 r
F P
0 g
s
.63405 .74638 m .63983 .76453 L .65129 .76524 L p .707 .577 .707 r
F P
0 g
s
.65756 .63246 m .64931 .66763 L .65184 .67936 L p .707 .577 .707 r
F P
0 g
s
.62875 .6048 m .64116 .55206 L .64837 .54259 L p .707 .577 .707 r
F P
0 g
s
.81872 .6912 m .8245 .70935 L .83184 .70257 L p .707 .577 .707 r
F P
0 g
s
.83184 .70257 m .82605 .68442 L .81872 .6912 L p .707 .577 .707 r
F P
0 g
s
.84015 .59855 m .82774 .65129 L .82521 .63955 L p .707 .577 .707 r
F P
0 g
s
.82521 .63955 m .83762 .58681 L .84015 .59855 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64931 .66763 m .65756 .63246 L .66477 .623 L p .707 .577 .707 r
F P
0 g
s
.85658 .67883 m .84833 .714 L .8458 .70227 L p .707 .577 .707 r
F P
0 g
s
.8458 .70227 m .85405 .6671 L .85658 .67883 L p .707 .577 .707 r
F P
0 g
s
.64837 .54259 m .63596 .59533 L .62875 .6048 L p .707 .577 .707 r
F P
0 g
s
.63983 .76453 m .63405 .74638 L .63188 .74244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63188 .74244 m .63766 .76059 L .63983 .76453 L p .707 .577 .707 r
F P
0 g
s
.66477 .623 m .65652 .65816 L .64931 .66763 L p .707 .577 .707 r
F P
0 g
s
.63596 .59533 m .64837 .54259 L .66462 .53633 L p .707 .577 .707 r
F P
0 g
s
.83762 .58681 m .82521 .63955 L .81318 .62668 L p .707 .577 .707 r
F P
0 g
s
.81318 .62668 m .8256 .57394 L .83762 .58681 L p .707 .577 .707 r
F P
0 g
s
.82605 .68442 m .83184 .70257 L .82967 .69863 L p .707 .577 .707 r
F P
0 g
s
.82967 .69863 m .82388 .68048 L .82605 .68442 L p .707 .577 .707 r
F P
0 g
s
.37766 .62561 m .39007 .57287 L .3597 .564 L p .707 .577 .707 r
F P
0 g
s
.39007 .57287 m .37766 .62561 L .40878 .63111 L p .707 .577 .707 r
F P
0 g
s
.40878 .63111 m .42119 .57837 L .39007 .57287 L p .707 .577 .707 r
F P
0 g
s
.34729 .61674 m .3597 .564 L .33304 .55265 L p .707 .577 .707 r
F P
0 g
s
.3597 .564 m .34729 .61674 L .37766 .62561 L p .707 .577 .707 r
F P
0 g
s
.42119 .57837 m .40878 .63111 L .43759 .63271 L p .707 .577 .707 r
F P
0 g
s
.43759 .63271 m .45 .57998 L .42119 .57837 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65652 .65816 m .66477 .623 L .68102 .61673 L p .707 .577 .707 r
F P
0 g
s
.85405 .6671 m .8458 .70227 L .83377 .68941 L p .707 .577 .707 r
F P
0 g
s
.83377 .68941 m .84202 .65424 L .85405 .6671 L p .707 .577 .707 r
F P
0 g
s
.66462 .53633 m .6522 .58906 L .63596 .59533 L p .707 .577 .707 r
F P
0 g
s
.39824 .68847 m .4065 .6533 L .37612 .64446 L p .707 .577 .707 r
F P
0 g
s
.4065 .6533 m .39824 .68847 L .42936 .69395 L p .707 .577 .707 r
F P
0 g
s
.42936 .69395 m .43762 .65879 L .4065 .6533 L p .707 .577 .707 r
F P
0 g
s
.32063 .60539 m .33304 .55265 L .3127 .53991 L p .707 .577 .707 r
F P
0 g
s
.33304 .55265 m .32063 .60539 L .34729 .61674 L p .707 .577 .707 r
F P
0 g
s
.45 .57998 m .43759 .63271 L .46127 .63027 L p .707 .577 .707 r
F P
0 g
s
.46127 .63027 m .47369 .57753 L .45 .57998 L p .707 .577 .707 r
F P
0 g
s
.6522 .58906 m .66462 .53633 L .6883 .53388 L p .707 .577 .707 r
F P
0 g
s
.36786 .67962 m .37612 .64446 L .34945 .63312 L p .707 .577 .707 r
F P
0 g
s
.37612 .64446 m .36786 .67962 L .39824 .68847 L p .707 .577 .707 r
F P
0 g
s
.63766 .76059 m .63188 .74244 L .63921 .73567 L p .707 .577 .707 r
F P
0 g
s
.43762 .65879 m .42936 .69395 L .45818 .69554 L p .707 .577 .707 r
F P
0 g
s
.45818 .69554 m .46643 .66038 L .43762 .65879 L p .707 .577 .707 r
F P
0 g
s
.8256 .57394 m .81318 .62668 L .79285 .61394 L p .707 .577 .707 r
F P
0 g
s
.79285 .61394 m .80526 .5612 L .8256 .57394 L p .707 .577 .707 r
F P
0 g
s
.68102 .61673 m .67277 .6519 L .65652 .65816 L p .707 .577 .707 r
F P
0 g
s
.63921 .73567 m .64499 .75382 L .63766 .76059 L p .707 .577 .707 r
F P
0 g
s
.82388 .68048 m .82967 .69863 L .8182 .69792 L p .707 .577 .707 r
F P
0 g
s
.8182 .69792 m .81242 .67977 L .82388 .68048 L p .707 .577 .707 r
F P
0 g
s
.34945 .63312 m .3412 .66829 L .36786 .67962 L p .707 .577 .707 r
F P
0 g
s
.3412 .66829 m .34945 .63312 L .32911 .6204 L p .707 .577 .707 r
F P
0 g
s
.46643 .66038 m .45818 .69554 L .48187 .69308 L p .707 .577 .707 r
F P
0 g
s
.48187 .69308 m .49012 .65792 L .46643 .66038 L p .707 .577 .707 r
F P
0 g
s
.67277 .6519 m .68102 .61673 L .70471 .61427 L p .707 .577 .707 r
F P
0 g
s
.84202 .65424 m .83377 .68941 L .81343 .67669 L p .707 .577 .707 r
F P
0 g
s
.81343 .67669 m .82168 .64153 L .84202 .65424 L p .707 .577 .707 r
F P
0 g
s
.3127 .53991 m .30029 .59265 L .32063 .60539 L p .707 .577 .707 r
F P
0 g
s
.38338 .71139 m .3776 .69324 L .34801 .70136 L p .707 .577 .707 r
F P
0 g
s
.3776 .69324 m .38338 .71139 L .41379 .70158 L p .707 .577 .707 r
F P
0 g
s
.41379 .70158 m .40801 .68343 L .3776 .69324 L p .707 .577 .707 r
F P
0 g
s
.30029 .59265 m .3127 .53991 L .30068 .52705 L p .707 .577 .707 r
F P
0 g
s
.40801 .68343 m .41379 .70158 L .44205 .69103 L p .707 .577 .707 r
F P
0 g
s
.44205 .69103 m .43627 .67288 L .40801 .68343 L p .707 .577 .707 r
F P
0 g
s
.6883 .53388 m .67589 .58661 L .6522 .58906 L p .707 .577 .707 r
F P
0 g
s
.47369 .57753 m .46127 .63027 L .47752 .624 L p .707 .577 .707 r
F P
0 g
s
.47752 .624 m .48993 .57126 L .47369 .57753 L p .707 .577 .707 r
F P
0 g
s
.67589 .58661 m .6883 .53388 L .71711 .53548 L p .707 .577 .707 r
F P
0 g
s
.34801 .70136 m .35379 .71951 L .38338 .71139 L p .707 .577 .707 r
F P
0 g
s
.80526 .5612 m .79285 .61394 L .76619 .60259 L p .707 .577 .707 r
F P
0 g
s
.76619 .60259 m .7786 .54985 L .80526 .5612 L p .707 .577 .707 r
F P
0 g
s
.32911 .6204 m .32086 .65557 L .3412 .66829 L p .707 .577 .707 r
F P
0 g
s
.35379 .71951 m .34801 .70136 L .32213 .70698 L p .707 .577 .707 r
F P
0 g
s
.70471 .61427 m .69645 .64944 L .67277 .6519 L p .707 .577 .707 r
F P
0 g
s
.43627 .67288 m .44205 .69103 L .46537 .68077 L p .707 .577 .707 r
F P
0 g
s
.46537 .68077 m .45959 .66262 L .43627 .67288 L p .707 .577 .707 r
F P
0 g
s
.32213 .70698 m .32791 .72513 L .35379 .71951 L p .707 .577 .707 r
F P
0 g
s
.64499 .75382 m .63921 .73567 L .65533 .72671 L p .707 .577 .707 r
F P
0 g
s
.65533 .72671 m .66111 .74486 L .64499 .75382 L p .707 .577 .707 r
F P
0 g
s
.32086 .65557 m .32911 .6204 L .31709 .60755 L p .707 .577 .707 r
F P
0 g
s
.7047 .58822 m .71711 .53548 L .74823 .54099 L p .707 .577 .707 r
F P
0 g
s
.71711 .53548 m .7047 .58822 L .67589 .58661 L p .707 .577 .707 r
F P
0 g
s
.7786 .54985 m .76619 .60259 L .73581 .59372 L p .707 .577 .707 r
F P
0 g
s
.73581 .59372 m .74823 .54099 L .7786 .54985 L p .707 .577 .707 r
F P
0 g
s
.81242 .67977 m .8182 .69792 L .79857 .7005 L p .707 .577 .707 r
F P
0 g
s
.79857 .7005 m .79279 .68235 L .81242 .67977 L p .707 .577 .707 r
F P
0 g
s
.49012 .65792 m .48187 .69308 L .49811 .68682 L p .707 .577 .707 r
F P
0 g
s
.49811 .68682 m .50636 .65165 L .49012 .65792 L p .707 .577 .707 r
F P
0 g
s
.69645 .64944 m .70471 .61427 L .73352 .61586 L p .707 .577 .707 r
F P
0 g
s
.82168 .64153 m .81343 .67669 L .78677 .66536 L p .707 .577 .707 r
F P
0 g
s
.78677 .66536 m .79502 .63019 L .82168 .64153 L p .707 .577 .707 r
F P
0 g
s
.30068 .52705 m .28827 .57978 L .30029 .59265 L p .707 .577 .707 r
F P
0 g
s
.74823 .54099 m .73581 .59372 L .7047 .58822 L p .707 .577 .707 r
F P
0 g
s
.32791 .72513 m .32213 .70698 L .3025 .70957 L p .707 .577 .707 r
F P
0 g
s
.28827 .57978 m .30068 .52705 L .29815 .5153 L p .707 .577 .707 r
F P
0 g
s
.48993 .57126 m .47752 .624 L .48473 .61453 L p .707 .577 .707 r
F P
0 g
s
.48473 .61453 m .49714 .5618 L .48993 .57126 L p .707 .577 .707 r
F P
0 g
s
.31709 .60755 m .30883 .64272 L .32086 .65557 L p .707 .577 .707 r
F P
0 g
s
.3025 .70957 m .30828 .72772 L .32791 .72513 L p .707 .577 .707 r
F P
0 g
s
.45959 .66262 m .46537 .68077 L .48149 .67182 L p .707 .577 .707 r
F P
0 g
s
.48149 .67182 m .47571 .65367 L .45959 .66262 L p .707 .577 .707 r
F P
0 g
s
.73352 .61586 m .72527 .65103 L .69645 .64944 L p .707 .577 .707 r
F P
0 g
s
.72527 .65103 m .73352 .61586 L .76464 .62135 L p .707 .577 .707 r
F P
0 g
s
.79502 .63019 m .78677 .66536 L .75639 .65652 L p .707 .577 .707 r
F P
0 g
s
.75639 .65652 m .76464 .62135 L .79502 .63019 L p .707 .577 .707 r
F P
0 g
s
.76464 .62135 m .75639 .65652 L .72527 .65103 L p .707 .577 .707 r
F P
0 g
s
.66111 .74486 m .65533 .72671 L .67866 .71646 L p .707 .577 .707 r
F P
0 g
s
.67866 .71646 m .68444 .73461 L .66111 .74486 L p .707 .577 .707 r
F P
0 g
s
.79279 .68235 m .79857 .7005 L .77269 .70613 L p .707 .577 .707 r
F P
0 g
s
.77269 .70613 m .76691 .68798 L .79279 .68235 L p .707 .577 .707 r
F P
0 g
s
.30883 .64272 m .31709 .60755 L .31455 .59582 L p .707 .577 .707 r
F P
0 g
s
.50636 .65165 m .49811 .68682 L .50532 .67735 L p .707 .577 .707 r
F P
0 g
s
.50532 .67735 m .51357 .64219 L .50636 .65165 L p .707 .577 .707 r
F P
0 g
s
.29815 .5153 m .28574 .56804 L .28827 .57978 L p .707 .577 .707 r
F P
0 g
s
.30828 .72772 m .3025 .70957 L .29104 .70885 L p .707 .577 .707 r
F P
0 g
s
.29104 .70885 m .29682 .727 L .30828 .72772 L p .707 .577 .707 r
F P
0 g
s
.31455 .59582 m .3063 .63098 L .30883 .64272 L p .707 .577 .707 r
F P
0 g
s
.28574 .56804 m .29815 .5153 L .30536 .50584 L p .707 .577 .707 r
F P
0 g
s
.47571 .65367 m .48149 .67182 L .48883 .66504 L p .707 .577 .707 r
F P
0 g
s
.48883 .66504 m .48304 .64689 L .47571 .65367 L p .707 .577 .707 r
F P
0 g
s
.68444 .73461 m .67866 .71646 L .70691 .70591 L p .707 .577 .707 r
F P
0 g
s
.49714 .5618 m .48473 .61453 L .4822 .60279 L p .707 .577 .707 r
F P
0 g
s
.4822 .60279 m .49461 .55005 L .49714 .5618 L p .707 .577 .707 r
F P
0 g
s
.76691 .68798 m .77269 .70613 L .7431 .71424 L p .707 .577 .707 r
F P
0 g
s
.7431 .71424 m .73732 .69609 L .76691 .68798 L p .707 .577 .707 r
F P
0 g
s
.70691 .70591 m .71269 .72406 L .68444 .73461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71269 .72406 m .70691 .70591 L .73732 .69609 L p .707 .577 .707 r
F P
0 g
s
.73732 .69609 m .7431 .71424 L .71269 .72406 L p .707 .577 .707 r
F P
0 g
s
.3063 .63098 m .31455 .59582 L .32176 .58635 L p .707 .577 .707 r
F P
0 g
s
.51357 .64219 m .50532 .67735 L .50279 .66562 L p .707 .577 .707 r
F P
0 g
s
.50279 .66562 m .51104 .63045 L .51357 .64219 L p .707 .577 .707 r
F P
0 g
s
.30536 .50584 m .29295 .55857 L .28574 .56804 L p .707 .577 .707 r
F P
0 g
s
.29682 .727 m .29104 .70885 L .28887 .70491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28887 .70491 m .29465 .72306 L .29682 .727 L p .707 .577 .707 r
F P
0 g
s
.32176 .58635 m .31351 .62152 L .3063 .63098 L p .707 .577 .707 r
F P
0 g
s
.29295 .55857 m .30536 .50584 L .32161 .49957 L p .707 .577 .707 r
F P
0 g
s
.48304 .64689 m .48883 .66504 L .48666 .6611 L p .707 .577 .707 r
F P
0 g
s
.48666 .6611 m .48087 .64295 L .48304 .64689 L p .707 .577 .707 r
F P
0 g
s
.49461 .55005 m .4822 .60279 L .47017 .58992 L p .707 .577 .707 r
F P
0 g
s
.47017 .58992 m .48259 .53718 L .49461 .55005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31351 .62152 m .32176 .58635 L .33801 .58008 L p .707 .577 .707 r
F P
0 g
s
.51104 .63045 m .50279 .66562 L .49076 .65276 L p .707 .577 .707 r
F P
0 g
s
.49076 .65276 m .49901 .6176 L .51104 .63045 L p .707 .577 .707 r
F P
0 g
s
.32161 .49957 m .30919 .55231 L .29295 .55857 L p .707 .577 .707 r
F P
0 g
s
.30919 .55231 m .32161 .49957 L .34529 .49712 L p .707 .577 .707 r
F P
0 g
s
.29465 .72306 m .28887 .70491 L .2962 .69814 L p .707 .577 .707 r
F P
0 g
s
.48259 .53718 m .47017 .58992 L .44984 .57719 L p .707 .577 .707 r
F P
0 g
s
.44984 .57719 m .46225 .52445 L .48259 .53718 L p .707 .577 .707 r
F P
0 g
s
.33801 .58008 m .32975 .61525 L .31351 .62152 L p .707 .577 .707 r
F P
0 g
s
.2962 .69814 m .30198 .71629 L .29465 .72306 L p .707 .577 .707 r
F P
0 g
s
.48087 .64295 m .48666 .6611 L .47519 .66039 L p .707 .577 .707 r
F P
0 g
s
.47519 .66039 m .46941 .64224 L .48087 .64295 L p .707 .577 .707 r
F P
0 g
s
.32975 .61525 m .33801 .58008 L .3617 .57762 L p .707 .577 .707 r
F P
0 g
s
.49901 .6176 m .49076 .65276 L .47042 .64005 L p .707 .577 .707 r
F P
0 g
s
.47042 .64005 m .47867 .60488 L .49901 .6176 L p .707 .577 .707 r
F P
0 g
s
.34529 .49712 m .33288 .54986 L .30919 .55231 L p .707 .577 .707 r
F P
0 g
s
.33288 .54986 m .34529 .49712 L .3741 .49873 L p .707 .577 .707 r
F P
0 g
s
.46225 .52445 m .44984 .57719 L .42318 .56583 L p .707 .577 .707 r
F P
0 g
s
.42318 .56583 m .43559 .51309 L .46225 .52445 L p .707 .577 .707 r
F P
0 g
s
.3617 .57762 m .35344 .61279 L .32975 .61525 L p .707 .577 .707 r
F P
0 g
s
.30198 .71629 m .2962 .69814 L .31232 .68918 L p .707 .577 .707 r
F P
0 g
s
.31232 .68918 m .3181 .70733 L .30198 .71629 L p .707 .577 .707 r
F P
0 g
s
.36169 .55146 m .3741 .49873 L .40522 .50423 L p .707 .577 .707 r
F P
0 g
s
.3741 .49873 m .36169 .55146 L .33288 .54986 L p .707 .577 .707 r
F P
0 g
s
.43559 .51309 m .42318 .56583 L .3928 .55697 L p .707 .577 .707 r
F P
0 g
s
.3928 .55697 m .40522 .50423 L .43559 .51309 L p .707 .577 .707 r
F P
0 g
s
.46941 .64224 m .47519 .66039 L .45556 .66297 L p .707 .577 .707 r
F P
0 g
s
.45556 .66297 m .44978 .64482 L .46941 .64224 L p .707 .577 .707 r
F P
0 g
s
.35344 .61279 m .3617 .57762 L .39051 .57922 L p .707 .577 .707 r
F P
0 g
s
.47867 .60488 m .47042 .64005 L .44376 .62871 L p .707 .577 .707 r
F P
0 g
s
.44376 .62871 m .45201 .59355 L .47867 .60488 L p .707 .577 .707 r
F P
0 g
s
.40522 .50423 m .3928 .55697 L .36169 .55146 L p .707 .577 .707 r
F P
0 g
s
.39051 .57922 m .38226 .61438 L .35344 .61279 L p .707 .577 .707 r
F P
0 g
s
.38226 .61438 m .39051 .57922 L .42163 .5847 L p .707 .577 .707 r
F P
0 g
s
.45201 .59355 m .44376 .62871 L .41338 .61987 L p .707 .577 .707 r
F P
0 g
s
.41338 .61987 m .42163 .5847 L .45201 .59355 L p .707 .577 .707 r
F P
0 g
s
.42163 .5847 m .41338 .61987 L .38226 .61438 L p .707 .577 .707 r
F P
0 g
s
.3181 .70733 m .31232 .68918 L .33564 .67893 L p .707 .577 .707 r
F P
0 g
s
.33564 .67893 m .34143 .69708 L .3181 .70733 L p .707 .577 .707 r
F P
0 g
s
.44978 .64482 m .45556 .66297 L .42968 .6686 L p .707 .577 .707 r
F P
0 g
s
.42968 .6686 m .4239 .65045 L .44978 .64482 L p .707 .577 .707 r
F P
0 g
s
.34143 .69708 m .33564 .67893 L .3639 .66838 L p .707 .577 .707 r
F P
0 g
s
.4239 .65045 m .42968 .6686 L .40009 .67671 L p .707 .577 .707 r
F P
0 g
s
.40009 .67671 m .39431 .65856 L .4239 .65045 L p .707 .577 .707 r
F P
0 g
s
.3639 .66838 m .36968 .68653 L .34143 .69708 L p .707 .577 .707 r
F P
0 g
s
.36968 .68653 m .3639 .66838 L .39431 .65856 L p .707 .577 .707 r
F P
0 g
s
.39431 .65856 m .40009 .67671 L .36968 .68653 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol005moo`h00003FUH005YF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Eoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001FOol30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`80
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`L005Ioo`00Dgoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo
10000eYF00@005YFFUIJEPT004eoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00Agoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020014Ool0059oo`03001JEP00
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH30011Ool0059oo`8000=JEP04001JEUYFFUH>0007FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`00?Woo001BOol20002FUH50003FUH20005Ool00`00FUIJEP050002
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003aoo`00DWoo00IJEP00
000005YF0006FUH01000FUH000000goo00@005YFFUH000AJEPD000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8003Yoo`00DGoo0P0015YF00<005YFFUH015YF00@005YFFUIJEP@0
009JEP03001JEUYF00AJEPL0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000hOol0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP@000EJEPD000=JEP<000MJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00DGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF00000`000UYF1@001EYF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EP00=Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70005FUH0
0`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<goo001AOol0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70003FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo031oo`00DGoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YF00004@0015YF2`001UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000aOol0059oo`05001JEUYFFUH00005FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH30004FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00
Dgoo00<005YF00001EYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@00
1EYF00<005YFFUH00P0000=JEP00FUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUIJEP0000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003Qoo`L0
01Eoo`8000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00D000EJEP8000AJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPD0009JEP<0009oo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02aoo`00<goo1@000eYF00@005YFFUIJEPT000eoo`03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
00AJEP8000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
001JEP0200000eYF001JEP05FUH01000FUH000002Goo1P001eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002ioo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P0027oo0P0000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0`000UYF00@005YF001JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000]oo`@000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002moo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000008Ool30003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP030002FUH30006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH015YF0`001goo200000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00000P0017oo1@000goo0`001eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000goo000000030006Ool20004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000Qo
o`<00003FUH005YF00EJEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUHB0006FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF1`0015YF00<005YFFUH0
0UYF20000goo0P001UYF00@005YFFUIJEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP000000
17oo10001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUH000040003FUH01000FUIJEUYF2@0015YF00@005YFFUIJEPL000AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000Ioo`@0009JEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60006FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000_Ool002aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH20004FUH40004Ool00`00FUIJEP060006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YF001JEP0000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH20005FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000
0eYF00<005YFFUH00UYF0`000eYF00<005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00`00
0Woo00@005YFFUH000EJEP@0009JEP03001JEUYF00EJEP<000MJEP03001JEUYF00=JEP04001JEUYF
FUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40006FUH01000
FUIJEUYF0P00<7oo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEQ<0
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<00004FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30004FUH20002FUH2000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP8000=JEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800004Ool000000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01P00FUH00000FUH0009JEP800003FUH007oo02moo`00:goo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00UYF00<005YFFUH015YF00H005YF000005YF0005FUH50006FUH00`00FUIJEP07FUH3
0006FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YFFUIJEP<0009JEP03001JEP00031oo`00:goo00<005YF00000UYF00@005YFFUIJEPL000AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF009JEP8000IJEP<000MJEP03001JEUYF00MJEP<000IJEP04001JEUYFFUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00Ool0
;goo000[Ool20003FUH40003FUH20002Ool90004FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH015YF10000UYF00<005YFFUH01eYF00<005YFFUH01`000UYF0`00
0eYF00<005YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1000
00=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`00<Goo000[Ool00eYF001JEP030006FUH01000FUH000002Goo1P0025YF00<0
05YFFUH015YF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH010001UYF1@000eYF00<005YF
FUH015YF00H005YF000005YF0003FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUH005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF000`Ool002Yoo`04001JEP000002FUH00`00FUIJEP04
FUH01000FUIJEUYF0`002Woo1@0015YF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<005YF
FUH015YF1P0000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF200015YF200015YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000ZOol20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH30006Ool500001Woo00000000FUH000MJEP03001JEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00800003FUH0
07oo00Eoo`8000EJEP03001JEUYF009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo02]oo`00:Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000Aoo`D000Ao
o`<000IJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP05
FUH01000FUIJEUYF100000AJEP000000009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP800003FUH0000000=JEP8000Moo`<00003FUH005YF00QJEP03001JEP00008000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8002aoo`00:Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0000=oo`0000000`001goo0P0015YF00@005YFFUIJEP80009JEP03
001JEUYF00EJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00AJEPD0009JEP03001JEP00
00800004FUH00000FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH00`00FUIJEP020008Ool60004FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEP00:goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH60009Ool200000eYF001JEP05FUH20008FUH30004FUH00`00FUIJEP07FUH00`00FUH000060005
FUH00`00FUH00003FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF00<007ooOol02goo200015YF10001eYF00<005YF
FUH00eYF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
15YF3@000UYF20000goo0P001UYF0`0015YF0`0025YF00<005YFFUH015YF10000UYF0P000eYF00<0
05YFFUH00UYF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF0P002Woo1@0017oo2P0015YF00<005YFFUH0
15YF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00001@00
0UYF00<005YFFUH01UYF00<005YF00000`000UYF00@005YFFUIJEPL000AJEP03001JEUYF00@00003
FUH005YF00QJEP03001JEUYF00@000=JEP<000EJEP03001JEUYF009JEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF
00AJEP04001JEP000008Ool5000>Ool300000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0X
Ool002]oo`04001JEUYF0005FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50005FUH00`00FUIJEP02000015YF001JEUYF0`0015YF00<005YFFUH01EYF100015YF0`0000=J
EP00FUH01UYF00H005YF000005YF0004FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Goo1@004Goo0P00
1EYF00L005YFFUIJEP00FUH0000YOol002aoo`<000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00=JEP@000MJEP03001JEUYF00=JEP@0
00=JEP<000AJEP03001JEUYF00AJEP<000=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH30003Ool3000@Ool50004FUH01`00FUIJEUYF001JEP0002Uoo`00;Woo00<005YFFUH00UYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`0000=JEP00
FUH025YF00<005YF00002@0025YF00@005YFFUIJEP<000EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF
00<005YFFUH01UYF00<005YF00000P003Goo1P000UYF00<005YFFUH00P000UYF00L005YFFUIJEP00
FUH0000YOol002moo`800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00EJEP<000=JEPH000UJEP06001JEP00001JEP00
1UYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0017oo1P000eYF00<005YF
FUH00eYF00<005YFFUH00`0015YF00<005YF0000:Goo000aOol30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP03FUH200000eYF001J
EP02FUH600000eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP80
02Yoo`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF00<005YFFUH01EYF00<005YF00000`000UYF10000UYF0`000UYF00<005YFFUH00eYF
40001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF
00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00<0009JEP03001JEP0002Yoo`00<Goo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
15YF100000=oo`0000000P000UYF00<005YFFUH01eYF00<005YF00000P002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUH000QJEP03001JEP0000800003FUH005YF00MJEP03001JEUYF00EJEP04001JEUYF
FUH700001UYF00000000FUH002Yoo`00<Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP800003FUH00000008000IJ
EP03001JEUYF00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00AJEP<000MJEP<000EJEP03
001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUIJEP000eYF00<005YF0000:Woo000aOol20003
FUH01000FUIJEUYF3P001UYF00L005YFFUIJEP00FUH00005FUH00`00FUH0000400000eYF001JEP08
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40006FUH30003FUH30008FUH00`00FUIJEP05
FUH50002FUH200000eYF001JEP04FUH20004FUH00`00FUH0000ZOol0035oo`80009JEPP000QJEP03
001JEUYF00@0009JEP05001JEUYFFUH00002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<0
05YF00000P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF1P0015YF00<005YFFUH00`0000=JEP00FUH025YF00<005YF
FUH00eYF0P000UYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0015YF0P00:goo000aOol01UYF
00000000FUH000Ioo`<000AJEP03001JEUYF00EJEPD00006FUH005YFFUH005YF0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP00
009JEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEP00008000AJEP<000IJEP03001JEUYF
00800003FUH005YF00=JEP8002]oo`00<7oo0P0015YF0`001goo0`0000=JEP00FUH01eYF00@005YF
FUIJEP<00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP<000AJEP@000MJEP03001JEUYF00EJEP@000EJEP800003FUH005YF00IJEP<000=J
EP07001JEUYFFUH005YF0000:goo000`Ool20004FUH01000FUIJEP002Goo1P0015YF00<005YFFUH0
0eYF0P0000=JEP00FUH015YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF0`002EYF00<005YFFUH020000UYF0`0015YF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<005YFFUH00UYF0P0037oo2@000UYF
0P000UYF00<005YFFUH00eYF00<005YF00000`000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1`000eYF00<005YFFUH01EYF100000=oo`0000001`001eYF00<005YFFUH0
0UYF0P001EYF00@005YFFUIJEP8002eoo`00<7oo0P000eYF00<005YFFUH015YF0P002Goo1@001Goo
3`001EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP000000
1EYF00<005YFFUH00eYF0P001Woo1`002EYF00H005YF000005YF0005FUH01000FUH00000;goo000`
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUH000001goo1@0047oo0`001UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10001eYF00<005YF00000P0017oo10000UYF
0`000UYF00<005YFFUH01EYF0`000UYF00@005YFFUIJEPD0035oo`00<7oo00<005YFFUH00UYF00<0
05YFFUH015YF00@005YFFUIJEP8000Eoo`D0011oo`<000IJEP80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP<00003FUH007oo009oo`800003FUH0
05YF00QJEP03001JEUYF00=JEP800003Ool0000000H003Ioo`00<Goo00D005YFFUIJEP0000EJEP03
001JEUYF00AJEP@0009oo`<000aoo`D0009JEP<000=JEP03001JEP00009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00005FUH01000FUIJEUYF0P0000EJEP00000007oo00<000AJEP03
001JEUYF00MJEP03001JEP000080045oo`00<Woo00<005YF00001UYF00<005YFFUH01EYF00<005YF
FUH010002Goo100000=JEP00FUH01EYF00P005YF000005YF001JEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P001EYF00@005YF0000009JEPD000MJEP03001JEUYF00EJEP@004Ao
o`00<goo0P001UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000Aoo`00000000IJEP03001JEUYF
00=JEP03001JEUYF00<00005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00
FUIJEP02FUH60003FUH00`00FUIJEP07FUH00`00FUIJEP040018Ool003Aoo`03001JEUYF00AJEP03
001JEUYF00AJEP03001JEUYF00MJEP@00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00009o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001JEUYF00EJ
EP03001JEP00009JEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4001<Ool0
03Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP04001JEUYF
FUH400000eYF000000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH9000;FUH00`00FUIJEP0:
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00D7oo000gOol01000FUIJEP001eYF00<005YFFUH00`0000=JEP00FUH0
1eYF00<005YFFUH015YF1@000UYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00=J
EP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP04
001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUH00002001BOol003Qoo`<000MJEP<000AJ
EP03001JEUYF00MJEP03001JEP0000H000EJEP03001JEP00009JEP04001JEUYF0005FUH00`00FUH0
0004000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH50003FUH00`00Oomoo`1?Ool003Yo
o`8000=JEP<000QJEP03001JEUYF00AJEP@0009JEP8000=JEP03001JEUYF009JEP<0009JEP04001J
EUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH40003FUH01@00FUIJEUYF00000UYF1`0015YF00D005YFFUIJEP00055oo`00
?7oo0`0000=JEP00FUH025YF00<005YFFUH010000eYF0`001EYF00<005YFFUH00UYF00<005YF0000
0UYF00@005YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF0000000800000eYF001JEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`1?Ool003Yoo`<000AJEP03001JEUYF00EJEP@000AJEP<00003FUH0
05YF00IJEP06001JEP00001JEP000eYF00D005YFFUH005YF008000QJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP03001oogoo00Aoo`8000EJEP07001JEUYFFUH005YF0000D7oo000gOol30007FUH00`00FUIJEP03
FUH40003FUH30004FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF00000UYF0P0000=JEP00FUH0
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF100017oo1@0015YF00L005YFFUIJEP00FUH0001@Ool003Eoo`800003FUH0
05YF00QJEP03001JEP0000T000QJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000D0009JEP03001JEUYF0080009JEP07001JEUYF
FUH005YF0000D7oo000cOol20004FUH00`00FUIJEP05FUH30003Ool60009FUH01P00FUH00000FUH0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00<005YFFUH00`0015YF00<005YF0000D7oo000aOol20006FUH00`00FUIJEP03FUH20005Ool60000
0eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01@00FUH00000Ool00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00H005YFFUH005YF0005FUH01000FUIJEUYF0P0015YF0P00DGoo000_Ool30008
FUH00`00FUH000020003Ool40002FUH30002FUH00`00FUIJEP03FUH@0003Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<0
05YF0000DGoo000]Ool20003FUH00`00FUIJEP04FUH30002Ool40002FUH00`00FUIJEP07FUH00`00
FUH00002000DOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH0
1000FUIJEUYF1`0000IJEP00000005YF001AOol002aoo`8000AJEP03001JEUYF009JEP800003Ool0
0000008000IJEP03001JEUYF00IJEP<001Moo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP800003FUH0000000D000=JEP04001JEUYF0003FUH00`00FUH0001AOol002]oo`03001JEP00
00EJEP03001JEP0000@00003FUH005YF00QJEP03001JEUYF009JEP<001]oo`80009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP800003FUH005YF00AJEP8000AJEP03001JEP00055oo`00:goo
00@005YFFUH000=JEP@000IJEP03001JEUYF00IJEP03001JEP000080021oo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH2000015YF001JEUYF0P000eYF00<005YFFUH00eYF0P0015YF0P00DWoo000[Ool01@00FUIJEP00
FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`009Goo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP<0
00IJEP03001JEUYF00800003FUH005YF00=JEP80059oo`00;7oo00@005YF000000EJEP03001JEUYF
00EJEP03001JEUYF00@002Yoo`<000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00AJEP@000=JEP800003FUH005YF00IJEP<000=JEP07001JEUYF
FUH005YF0000DWoo000/Ool200000eYF001JEP04FUH00`00FUIJEP04FUH4000aOol300000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP050003FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000/Ool20002FUH00`00FUIJ
EP03FUH00`00FUH00003000hOol40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH=0007FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P00E7oo000]Ool200000eYF001JEP02
FUH40010Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF20000goo1`002EYF
00H005YF000005YF0005FUH01000FUH00000EWoo000_Ool5001:OolO0003FUH20002Ool400000eYF
0000000300000eYF001JEP06FUH30002FUH01000FUIJEUYF1@00F7oo002?Ool20002FUH00`00FUIJ
EP05FUH00`00FUH000020002Ool200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH200000goo
00000006001MOol008ioo`03001JEUYF00=JEP03001JEUYF00=JEP<0009oo`<000AJEP03001JEUYF
00MJEP03001JEP00008006Qoo`00SGoo0P001EYF00<005YF000020001eYF00<005YFFUH01UYF0`00
Jgoo002<Ool01000FUIJEP0015YF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00KWoo002<
Ool01000FUIJEP000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEP000080075oo`00SGoo
00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH01EYF0`00M7oo002=Ool00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP04001gOol008ioo`04FUH005YF0005FUH00`00FUIJEP04
FUH4001kOol008ioo`05001JEUYFFUH00004FUH00`00FUIJEP04001oOol008ioo``008=oo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58347 .7544 m .59588 .70166 L .56551 .6928 L p .707 .577 .707 r
F P
0 g
s
.59588 .70166 m .58347 .7544 L .61458 .7599 L p .707 .577 .707 r
F P
0 g
s
.61458 .7599 m .627 .70717 L .59588 .70166 L p .707 .577 .707 r
F P
0 g
s
.55309 .74554 m .56551 .6928 L .53885 .68144 L p .707 .577 .707 r
F P
0 g
s
.56551 .6928 m .55309 .74554 L .58347 .7544 L p .707 .577 .707 r
F P
0 g
s
.627 .70717 m .61458 .7599 L .64339 .76151 L p .707 .577 .707 r
F P
0 g
s
.64339 .76151 m .65581 .70877 L .627 .70717 L p .707 .577 .707 r
F P
0 g
s
.60405 .81715 m .6123 .78198 L .58192 .77314 L p .707 .577 .707 r
F P
0 g
s
.6123 .78198 m .60405 .81715 L .63517 .82264 L p .707 .577 .707 r
F P
0 g
s
.63517 .82264 m .64342 .78747 L .6123 .78198 L p .707 .577 .707 r
F P
0 g
s
.52643 .73418 m .53885 .68144 L .51851 .66871 L p .707 .577 .707 r
F P
0 g
s
.53885 .68144 m .52643 .73418 L .55309 .74554 L p .707 .577 .707 r
F P
0 g
s
.65581 .70877 m .64339 .76151 L .66708 .75906 L p .707 .577 .707 r
F P
0 g
s
.66708 .75906 m .67949 .70632 L .65581 .70877 L p .707 .577 .707 r
F P
0 g
s
.57367 .80831 m .58192 .77314 L .55526 .76181 L p .707 .577 .707 r
F P
0 g
s
.58192 .77314 m .57367 .80831 L .60405 .81715 L p .707 .577 .707 r
F P
0 g
s
.64342 .78747 m .63517 .82264 L .66398 .82423 L p .707 .577 .707 r
F P
0 g
s
.66398 .82423 m .67223 .78906 L .64342 .78747 L p .707 .577 .707 r
F P
0 g
s
.55526 .76181 m .547 .79697 L .57367 .80831 L p .707 .577 .707 r
F P
0 g
s
.547 .79697 m .55526 .76181 L .53492 .74909 L p .707 .577 .707 r
F P
0 g
s
.67223 .78906 m .66398 .82423 L .68767 .82177 L p .707 .577 .707 r
F P
0 g
s
.68767 .82177 m .69592 .7866 L .67223 .78906 L p .707 .577 .707 r
F P
0 g
s
.51851 .66871 m .5061 .72145 L .52643 .73418 L p .707 .577 .707 r
F P
0 g
s
.58919 .84096 m .58341 .82281 L .55381 .83092 L p .707 .577 .707 r
F P
0 g
s
.58341 .82281 m .58919 .84096 L .6196 .83114 L p .707 .577 .707 r
F P
0 g
s
.6196 .83114 m .61382 .81299 L .58341 .82281 L p .707 .577 .707 r
F P
0 g
s
.5061 .72145 m .51851 .66871 L .50649 .65584 L p .707 .577 .707 r
F P
0 g
s
.61382 .81299 m .6196 .83114 L .64785 .82059 L p .707 .577 .707 r
F P
0 g
s
.64785 .82059 m .64207 .80244 L .61382 .81299 L p .707 .577 .707 r
F P
0 g
s
.67949 .70632 m .66708 .75906 L .68332 .75279 L p .707 .577 .707 r
F P
0 g
s
.68332 .75279 m .69574 .70006 L .67949 .70632 L p .707 .577 .707 r
F P
0 g
s
.55381 .83092 m .5596 .84907 L .58919 .84096 L p .707 .577 .707 r
F P
0 g
s
.53492 .74909 m .52666 .78425 L .547 .79697 L p .707 .577 .707 r
F P
0 g
s
.5596 .84907 m .55381 .83092 L .52794 .83655 L p .707 .577 .707 r
F P
0 g
s
.64207 .80244 m .64785 .82059 L .67118 .81034 L p .707 .577 .707 r
F P
0 g
s
.67118 .81034 m .6654 .79219 L .64207 .80244 L p .707 .577 .707 r
F P
0 g
s
.52794 .83655 m .53372 .8547 L .5596 .84907 L p .707 .577 .707 r
F P
0 g
s
.52666 .78425 m .53492 .74909 L .52289 .73623 L p .707 .577 .707 r
F P
0 g
s
.69592 .7866 m .68767 .82177 L .70391 .8155 L p .707 .577 .707 r
F P
0 g
s
.70391 .8155 m .71217 .78033 L .69592 .7866 L p .707 .577 .707 r
F P
0 g
s
.50649 .65584 m .49407 .70858 L .5061 .72145 L p .707 .577 .707 r
F P
0 g
s
.53372 .8547 m .52794 .83655 L .5083 .83913 L p .707 .577 .707 r
F P
0 g
s
.49407 .70858 m .50649 .65584 L .50396 .6441 L p .707 .577 .707 r
F P
0 g
s
.69574 .70006 m .68332 .75279 L .69053 .74333 L p .707 .577 .707 r
F P
0 g
s
.69053 .74333 m .70295 .69059 L .69574 .70006 L p .707 .577 .707 r
F P
0 g
s
.52289 .73623 m .51464 .7714 L .52666 .78425 L p .707 .577 .707 r
F P
0 g
s
.5083 .83913 m .51409 .85728 L .53372 .8547 L p .707 .577 .707 r
F P
0 g
s
.6654 .79219 m .67118 .81034 L .6873 .80139 L p .707 .577 .707 r
F P
0 g
s
.6873 .80139 m .68152 .78324 L .6654 .79219 L p .707 .577 .707 r
F P
0 g
s
.51464 .7714 m .52289 .73623 L .52036 .7245 L p .707 .577 .707 r
F P
0 g
s
.71217 .78033 m .70391 .8155 L .71112 .80604 L p .707 .577 .707 r
F P
0 g
s
.71112 .80604 m .71938 .77087 L .71217 .78033 L p .707 .577 .707 r
F P
0 g
s
.50396 .6441 m .49155 .69683 L .49407 .70858 L p .707 .577 .707 r
F P
0 g
s
.51409 .85728 m .5083 .83913 L .49684 .83842 L p .707 .577 .707 r
F P
0 g
s
.49684 .83842 m .50262 .85657 L .51409 .85728 L p .707 .577 .707 r
F P
0 g
s
.52036 .7245 m .51211 .75967 L .51464 .7714 L p .707 .577 .707 r
F P
0 g
s
.49155 .69683 m .50396 .6441 L .51117 .63463 L p .707 .577 .707 r
F P
0 g
s
.68152 .78324 m .6873 .80139 L .69463 .79461 L p .707 .577 .707 r
F P
0 g
s
.69463 .79461 m .68885 .77646 L .68152 .78324 L p .707 .577 .707 r
F P
0 g
s
.70295 .69059 m .69053 .74333 L .688 .73158 L p .707 .577 .707 r
F P
0 g
s
.688 .73158 m .70042 .67885 L .70295 .69059 L p .707 .577 .707 r
F P
0 g
s
.51117 .63463 m .49875 .68737 L .49155 .69683 L p .707 .577 .707 r
F P
0 g
s
.49448 .82173 m .48855 .31924 L .44455 .31708 L p .707 .577 .707 r
F P
0 g
s
.51211 .75967 m .52036 .7245 L .52757 .71504 L p .707 .577 .707 r
F P
0 g
s
.52757 .71504 m .51932 .7502 L .51211 .75967 L p .707 .577 .707 r
F P
0 g
s
.49875 .68737 m .51117 .63463 L .52741 .62836 L p .707 .577 .707 r
F P
0 g
s
.51932 .7502 m .52757 .71504 L .54381 .70877 L p .707 .577 .707 r
F P
0 g
s
.52741 .62836 m .515 .6811 L .49875 .68737 L p .707 .577 .707 r
F P
0 g
s
.515 .6811 m .52741 .62836 L .5511 .62592 L p .707 .577 .707 r
F P
0 g
s
.54381 .70877 m .53556 .74393 L .51932 .7502 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .53868 .67865 L .515 .6811 L p .707 .577 .707 r
F P
0 g
s
.50779 .84585 m .502 .8277 L .51812 .81875 L p .707 .577 .707 r
F P
0 g
s
.51812 .81875 m .52391 .8369 L .50779 .84585 L p .707 .577 .707 r
F P
0 g
s
.52391 .8369 m .51812 .81875 L .54145 .8085 L p .707 .577 .707 r
F P
0 g
s
.54145 .8085 m .54723 .82665 L .52391 .8369 L p .707 .577 .707 r
F P
0 g
s
.48855 .31924 m .49448 .82173 L .53943 .82015 L p .707 .577 .707 r
F P
0 g
s
.53556 .74393 m .54381 .70877 L .5675 .70631 L p .707 .577 .707 r
F P
0 g
s
.5675 .70631 m .55925 .74148 L .53556 .74393 L p .707 .577 .707 r
F P
0 g
s
.53943 .82015 m .53349 .31767 L .48855 .31924 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .57991 .62752 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.53868 .67865 m .5452 .65097 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.5452 .65097 m .5511 .62592 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.62971 .78001 m .63549 .79816 L .6059 .80628 L p .707 .577 .707 r
F P
0 g
s
.6059 .80628 m .60011 .78813 L .62971 .78001 L p .707 .577 .707 r
F P
0 g
s
.60011 .78813 m .6059 .80628 L .57548 .8161 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .61486 .80679 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.56749 .68026 m .57991 .62752 L .61102 .63303 L p .707 .577 .707 r
F P
0 g
s
.57991 .62752 m .56749 .68026 L .53868 .67865 L p .707 .577 .707 r
F P
0 g
s
.6414 .64189 m .62898 .69463 L .59861 .68576 L p .707 .577 .707 r
F P
0 g
s
.59861 .68576 m .61102 .63303 L .6414 .64189 L p .707 .577 .707 r
F P
0 g
s
.55925 .74148 m .5675 .70631 L .59632 .7079 L p .707 .577 .707 r
F P
0 g
s
.61102 .63303 m .59861 .68576 L .56749 .68026 L p .707 .577 .707 r
F P
0 g
s
.59632 .7079 m .58806 .74307 L .55925 .74148 L p .707 .577 .707 r
F P
0 g
s
.58806 .74307 m .59632 .7079 L .62744 .71339 L p .707 .577 .707 r
F P
0 g
s
.62744 .71339 m .61918 .74855 L .58806 .74307 L p .707 .577 .707 r
F P
0 g
s
.57497 .31252 m .57981 .72266 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.57548 .8161 m .5697 .79795 L .60011 .78813 L p .707 .577 .707 r
F P
0 g
s
.57981 .72266 m .5809 .81501 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.54723 .82665 m .54145 .8085 L .5697 .79795 L p .707 .577 .707 r
F P
0 g
s
.5697 .79795 m .57548 .8161 L .54723 .82665 L p .707 .577 .707 r
F P
0 g
s
.53349 .31767 m .53943 .82015 L .5809 .81501 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .57497 .31252 L .53349 .31767 L p .707 .577 .707 r
F P
0 g
s
.45048 .81957 m .44455 .31708 L .40579 .31141 L p .707 .577 .707 r
F P
0 g
s
.44455 .31708 m .45048 .81957 L .49448 .82173 L p .707 .577 .707 r
F P
0 g
s
.71938 .77087 m .71112 .80604 L .70859 .7943 L p .707 .577 .707 r
F P
0 g
s
.70859 .7943 m .71684 .75914 L .71938 .77087 L p .707 .577 .707 r
F P
0 g
s
.61486 .80679 m .60893 .3043 L .57497 .31252 L p .707 .577 .707 r
F P
0 g
s
.50262 .85657 m .49684 .83842 L .49467 .83448 L p .707 .577 .707 r
F P
0 g
s
.49467 .83448 m .50045 .85263 L .50262 .85657 L p .707 .577 .707 r
F P
0 g
s
.70042 .67885 m .688 .73158 L .67598 .71872 L p .707 .577 .707 r
F P
0 g
s
.67598 .71872 m .68839 .66598 L .70042 .67885 L p .707 .577 .707 r
F P
0 g
s
.68885 .77646 m .69463 .79461 L .69246 .79067 L p .707 .577 .707 r
F P
0 g
s
.69246 .79067 m .68668 .77252 L .68885 .77646 L p .707 .577 .707 r
F P
0 g
s
.41172 .8139 m .40579 .31141 L .37606 .30277 L p .707 .577 .707 r
F P
0 g
s
.40579 .31141 m .41172 .8139 L .45048 .81957 L p .707 .577 .707 r
F P
0 g
s
.24046 .71764 m .25287 .66491 L .2225 .65604 L p .707 .577 .707 r
F P
0 g
s
.25287 .66491 m .24046 .71764 L .27157 .72315 L p .707 .577 .707 r
F P
0 g
s
.27157 .72315 m .28399 .67041 L .25287 .66491 L p .707 .577 .707 r
F P
0 g
s
.21008 .70878 m .2225 .65604 L .19584 .64469 L p .707 .577 .707 r
F P
0 g
s
.2225 .65604 m .21008 .70878 L .24046 .71764 L p .707 .577 .707 r
F P
0 g
s
.28399 .67041 m .27157 .72315 L .30038 .72475 L p .707 .577 .707 r
F P
0 g
s
.30038 .72475 m .3128 .67202 L .28399 .67041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71684 .75914 m .70859 .7943 L .69657 .78145 L p .707 .577 .707 r
F P
0 g
s
.69657 .78145 m .70482 .74628 L .71684 .75914 L p .707 .577 .707 r
F P
0 g
s
.26104 .7805 m .26929 .74534 L .23891 .73649 L p .707 .577 .707 r
F P
0 g
s
.26929 .74534 m .26104 .7805 L .29216 .78599 L p .707 .577 .707 r
F P
0 g
s
.29216 .78599 m .30041 .75082 L .26929 .74534 L p .707 .577 .707 r
F P
0 g
s
.66806 .65324 m .65564 .70598 L .62898 .69463 L p .707 .577 .707 r
F P
0 g
s
.62898 .69463 m .6414 .64189 L .66806 .65324 L p .707 .577 .707 r
F P
0 g
s
.65781 .72223 m .64956 .7574 L .61918 .74855 L p .707 .577 .707 r
F P
0 g
s
.61918 .74855 m .62744 .71339 L .65781 .72223 L p .707 .577 .707 r
F P
0 g
s
.65559 .77439 m .66137 .79254 L .63549 .79816 L p .707 .577 .707 r
F P
0 g
s
.63549 .79816 m .62971 .78001 L .65559 .77439 L p .707 .577 .707 r
F P
0 g
s
.60893 .3043 m .61486 .80679 L .63797 .7963 L p .707 .577 .707 r
F P
0 g
s
.63797 .7963 m .63204 .29382 L .60893 .3043 L p .707 .577 .707 r
F P
0 g
s
.18342 .69743 m .19584 .64469 L .1755 .63195 L p .707 .577 .707 r
F P
0 g
s
.19584 .64469 m .18342 .69743 L .21008 .70878 L p .707 .577 .707 r
F P
0 g
s
.3128 .67202 m .30038 .72475 L .32407 .7223 L p .707 .577 .707 r
F P
0 g
s
.32407 .7223 m .33648 .66957 L .3128 .67202 L p .707 .577 .707 r
F P
0 g
s
.23066 .77166 m .23891 .73649 L .21225 .72516 L p .707 .577 .707 r
F P
0 g
s
.23891 .73649 m .23066 .77166 L .26104 .7805 L p .707 .577 .707 r
F P
0 g
s
.50045 .85263 m .49467 .83448 L .502 .8277 L p .707 .577 .707 r
F P
0 g
s
.30041 .75082 m .29216 .78599 L .32097 .78758 L p .707 .577 .707 r
F P
0 g
s
.32097 .78758 m .32923 .75242 L .30041 .75082 L p .707 .577 .707 r
F P
0 g
s
.68839 .66598 m .67598 .71872 L .65564 .70598 L p .707 .577 .707 r
F P
0 g
s
.65564 .70598 m .66806 .65324 L .68839 .66598 L p .707 .577 .707 r
F P
0 g
s
.502 .8277 m .50779 .84585 L .50045 .85263 L p .707 .577 .707 r
F P
0 g
s
.68668 .77252 m .69246 .79067 L .681 .78996 L p .707 .577 .707 r
F P
0 g
s
.681 .78996 m .67522 .77181 L .68668 .77252 L p .707 .577 .707 r
F P
0 g
s
.382 .80526 m .37606 .30277 L .35829 .29202 L p .707 .577 .707 r
F P
0 g
s
.37606 .30277 m .382 .80526 L .41172 .8139 L p .707 .577 .707 r
F P
0 g
s
.21225 .72516 m .204 .76033 L .23066 .77166 L p .707 .577 .707 r
F P
0 g
s
.204 .76033 m .21225 .72516 L .19191 .71244 L p .707 .577 .707 r
F P
0 g
s
.32923 .75242 m .32097 .78758 L .34466 .78512 L p .707 .577 .707 r
F P
0 g
s
.34466 .78512 m .35291 .74996 L .32923 .75242 L p .707 .577 .707 r
F P
0 g
s
.70482 .74628 m .69657 .78145 L .67623 .76873 L p .707 .577 .707 r
F P
0 g
s
.67623 .76873 m .68448 .73357 L .70482 .74628 L p .707 .577 .707 r
F P
0 g
s
.1755 .63195 m .16309 .68469 L .18342 .69743 L p .707 .577 .707 r
F P
0 g
s
.24618 .80343 m .2404 .78528 L .21081 .7934 L p .707 .577 .707 r
F P
0 g
s
.2404 .78528 m .24618 .80343 L .27659 .79362 L p .707 .577 .707 r
F P
0 g
s
.27659 .79362 m .27081 .77547 L .2404 .78528 L p .707 .577 .707 r
F P
0 g
s
.16309 .68469 m .1755 .63195 L .16348 .61908 L p .707 .577 .707 r
F P
0 g
s
.27081 .77547 m .27659 .79362 L .30484 .78307 L p .707 .577 .707 r
F P
0 g
s
.30484 .78307 m .29906 .76492 L .27081 .77547 L p .707 .577 .707 r
F P
0 g
s
.33648 .66957 m .32407 .7223 L .34031 .71604 L p .707 .577 .707 r
F P
0 g
s
.34031 .71604 m .35273 .6633 L .33648 .66957 L p .707 .577 .707 r
F P
0 g
s
.21081 .7934 m .21659 .81155 L .24618 .80343 L p .707 .577 .707 r
F P
0 g
s
.19191 .71244 m .18366 .74761 L .204 .76033 L p .707 .577 .707 r
F P
0 g
s
.21659 .81155 m .21081 .7934 L .18493 .79902 L p .707 .577 .707 r
F P
0 g
s
.29906 .76492 m .30484 .78307 L .32817 .77281 L p .707 .577 .707 r
F P
0 g
s
.32817 .77281 m .32239 .75466 L .29906 .76492 L p .707 .577 .707 r
F P
0 g
s
.18493 .79902 m .19071 .81717 L .21659 .81155 L p .707 .577 .707 r
F P
0 g
s
.63204 .29382 m .63797 .7963 L .64797 .78458 L p .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64204 .28209 L .63204 .29382 L p .707 .577 .707 r
F P
0 g
s
.18366 .74761 m .19191 .71244 L .17988 .69959 L p .707 .577 .707 r
F P
0 g
s
.67522 .77181 m .681 .78996 L .66137 .79254 L p .707 .577 .707 r
F P
0 g
s
.66137 .79254 m .65559 .77439 L .67522 .77181 L p .707 .577 .707 r
F P
0 g
s
.35291 .74996 m .34466 .78512 L .36091 .77886 L p .707 .577 .707 r
F P
0 g
s
.36091 .77886 m .36916 .74369 L .35291 .74996 L p .707 .577 .707 r
F P
0 g
s
.68448 .73357 m .67623 .76873 L .64956 .7574 L p .707 .577 .707 r
F P
0 g
s
.64956 .7574 m .65781 .72223 L .68448 .73357 L p .707 .577 .707 r
F P
0 g
s
.16348 .61908 m .15107 .67182 L .16309 .68469 L p .707 .577 .707 r
F P
0 g
s
.19071 .81717 m .18493 .79902 L .1653 .8016 L p .707 .577 .707 r
F P
0 g
s
.15107 .67182 m .16348 .61908 L .16095 .60734 L p .707 .577 .707 r
F P
0 g
s
.35273 .6633 m .34031 .71604 L .34752 .70657 L p .707 .577 .707 r
F P
0 g
s
.34752 .70657 m .35994 .65384 L .35273 .6633 L p .707 .577 .707 r
F P
0 g
s
.17988 .69959 m .17163 .73475 L .18366 .74761 L p .707 .577 .707 r
F P
0 g
s
.1653 .8016 m .17108 .81975 L .19071 .81717 L p .707 .577 .707 r
F P
0 g
s
.32239 .75466 m .32817 .77281 L .34429 .76386 L p .707 .577 .707 r
F P
0 g
s
.34429 .76386 m .33851 .74571 L .32239 .75466 L p .707 .577 .707 r
F P
0 g
s
.36916 .74369 m .36091 .77886 L .36811 .76939 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .35356 .7448 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.37383 .72249 m .3676 .74906 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.3676 .74906 m .36558 .75766 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .3542 .2802 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36181 .70964 L .36568 .71377 L p .707 .577 .707 r
F P
0 g
s
.36568 .71377 m .37383 .72249 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36568 .71377 L .36659 .73047 L .707 .577 .707 r
F
.35162 .75708 m .34584 .73893 L .33851 .74571 L p F P
0 g
s
.36181 .70964 m .35356 .7448 L .34754 .74104 L p .707 .577 .707 r
F P
0 g
s
.34584 .73893 m .35162 .75708 L .34945 .75314 L p .707 .577 .707 r
F P
0 g
s
.34945 .75314 m .34367 .73499 L .34584 .73893 L p .707 .577 .707 r
F P
0 g
s
.33851 .74571 m .34429 .76386 L .35162 .75708 L p .707 .577 .707 r
F P
0 g
s
.34367 .73499 m .34945 .75314 L .33799 .75243 L p .707 .577 .707 r
F P
0 g
s
.33799 .75243 m .33221 .73428 L .34367 .73499 L p .707 .577 .707 r
F P
0 g
s
.34754 .74104 m .33322 .73209 L p .34793 .72054 L .707 .577 .707 r
F P
0 g
s
.34793 .72054 m .36181 .70964 L .34754 .74104 L .707 .577 .707 r
F
.35994 .65384 m .34752 .70657 L .34499 .69483 L p F P
0 g
s
.33322 .73209 m .34147 .69692 L .36181 .70964 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .36422 .79451 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3542 .2802 m .35756 .56475 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.34499 .69483 m .35741 .64209 L .35994 .65384 L p .707 .577 .707 r
F P
0 g
s
.35756 .56475 m .36013 .78269 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36422 .79451 m .3626 .6573 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3626 .6573 m .35829 .29202 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36811 .76939 m .37637 .73422 L .36916 .74369 L p .707 .577 .707 r
F P
0 g
s
.37637 .73422 m .36811 .76939 L .36558 .75766 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .37383 .72249 L .37637 .73422 L p .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .36422 .79451 L .382 .80526 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .35497 .34512 L p .3642 .26848 L .707 .577 .707 r
F P
0 g
s
.35497 .34512 m .3542 .2802 L .35623 .27782 L p .707 .577 .707 r
F P
0 g
s
.35623 .27782 m .3642 .26848 L p .35497 .34512 L .707 .577 .707 r
F P
0 g
s
.17163 .73475 m .17988 .69959 L .17735 .68785 L p .707 .577 .707 r
F P
0 g
s
.16095 .60734 m .14854 .66008 L .15107 .67182 L p .707 .577 .707 r
F P
0 g
s
.17108 .81975 m .1653 .8016 L .15383 .80089 L p .707 .577 .707 r
F P
0 g
s
.15383 .80089 m .15961 .81904 L .17108 .81975 L p .707 .577 .707 r
F P
0 g
s
.17735 .68785 m .1691 .72302 L .17163 .73475 L p .707 .577 .707 r
F P
0 g
s
.14854 .66008 m .16095 .60734 L .16816 .59787 L p .707 .577 .707 r
F P
0 g
s
.64204 .28209 m .64783 .77275 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64204 .28209 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64388 .77276 m .64188 .603 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64188 .603 m .63795 .27027 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64388 .77276 L .62611 .76201 L p .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .64116 .55206 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.63128 .61654 m .6378 .58885 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .64369 .5638 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .6378 .58885 L p .6433 .62941 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .63128 .61654 L .6398 .62566 L p .707 .577 .707 r
F P
0 g
s
.6398 .62566 m .6433 .62941 L p .6378 .58885 L .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64388 .77276 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.64783 .77275 m .64797 .78458 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1691 .72302 m .17735 .68785 L .18456 .67839 L p .707 .577 .707 r
F P
0 g
s
.16816 .59787 m .15575 .65061 L .14854 .66008 L p .707 .577 .707 r
F P
0 g
s
.15961 .81904 m .15383 .80089 L .15166 .79695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15166 .79695 m .15744 .8151 L .15961 .81904 L p .707 .577 .707 r
F P
0 g
s
.18456 .67839 m .17631 .71356 L .1691 .72302 L p .707 .577 .707 r
F P
0 g
s
.15575 .65061 m .16816 .59787 L .1844 .59161 L p .707 .577 .707 r
F P
0 g
s
.35741 .64209 m .34499 .69483 L .33297 .68196 L p .707 .577 .707 r
F P
0 g
s
.33297 .68196 m .34539 .62922 L .35741 .64209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62611 .76201 m .62017 .25952 L .63795 .27027 L p .707 .577 .707 r
F P
0 g
s
.17631 .71356 m .18456 .67839 L .2008 .67212 L p .707 .577 .707 r
F P
0 g
s
.1844 .59161 m .17199 .64435 L .15575 .65061 L p .707 .577 .707 r
F P
0 g
s
.17199 .64435 m .1844 .59161 L .20809 .58916 L p .707 .577 .707 r
F P
0 g
s
.15744 .8151 m .15166 .79695 L .159 .79018 L p .707 .577 .707 r
F P
0 g
s
.34539 .62922 m .33297 .68196 L .31263 .66923 L p .707 .577 .707 r
F P
0 g
s
.31263 .66923 m .32505 .61649 L .34539 .62922 L p .707 .577 .707 r
F P
0 g
s
.2008 .67212 m .19255 .70729 L .17631 .71356 L p .707 .577 .707 r
F P
0 g
s
.159 .79018 m .16478 .80833 L .15744 .8151 L p .707 .577 .707 r
F P
0 g
s
.37013 .77096 m .3642 .26848 L .38731 .25799 L p .707 .577 .707 r
F P
0 g
s
.3642 .26848 m .37013 .77096 L .36013 .78269 L p .707 .577 .707 r
F P
0 g
s
.19255 .70729 m .2008 .67212 L .22449 .66966 L p .707 .577 .707 r
F P
0 g
s
.20809 .58916 m .19567 .6419 L .17199 .64435 L p .707 .577 .707 r
F P
0 g
s
.19567 .6419 m .20809 .58916 L .2369 .59077 L p .707 .577 .707 r
F P
0 g
s
.32505 .61649 m .31263 .66923 L .28597 .65787 L p .707 .577 .707 r
F P
0 g
s
.28597 .65787 m .29839 .60513 L .32505 .61649 L p .707 .577 .707 r
F P
0 g
s
.62017 .25952 m .62611 .76201 L .59638 .75337 L p .707 .577 .707 r
F P
0 g
s
.59638 .75337 m .59045 .25088 L .62017 .25952 L p .707 .577 .707 r
F P
0 g
s
.22449 .66966 m .21624 .70483 L .19255 .70729 L p .707 .577 .707 r
F P
0 g
s
.16478 .80833 m .159 .79018 L .17511 .78122 L p .707 .577 .707 r
F P
0 g
s
.17511 .78122 m .1809 .79937 L .16478 .80833 L p .707 .577 .707 r
F P
0 g
s
.22448 .6435 m .2369 .59077 L .26802 .59627 L p .707 .577 .707 r
F P
0 g
s
.2369 .59077 m .22448 .6435 L .19567 .6419 L p .707 .577 .707 r
F P
0 g
s
.29839 .60513 m .28597 .65787 L .2556 .64901 L p .707 .577 .707 r
F P
0 g
s
.2556 .64901 m .26802 .59627 L .29839 .60513 L p .707 .577 .707 r
F P
0 g
s
.33221 .73428 m .33799 .75243 L .31836 .75501 L p .707 .577 .707 r
F P
0 g
s
.31836 .75501 m .31258 .73686 L .33221 .73428 L p .707 .577 .707 r
F P
0 g
s
.21624 .70483 m .22449 .66966 L .25331 .67126 L p .707 .577 .707 r
F P
0 g
s
.34147 .69692 m .33322 .73209 L .30655 .72075 L p .707 .577 .707 r
F P
0 g
s
.30655 .72075 m .31481 .68558 L .34147 .69692 L p .707 .577 .707 r
F P
0 g
s
.26802 .59627 m .2556 .64901 L .22448 .6435 L p .707 .577 .707 r
F P
0 g
s
.38731 .25799 m .39324 .76048 L .37013 .77096 L p .707 .577 .707 r
F P
0 g
s
.39324 .76048 m .38731 .25799 L .42127 .24977 L p .707 .577 .707 r
F P
0 g
s
.72067 .66236 m .73308 .60962 L .70271 .60076 L p .707 .577 .707 r
F P
0 g
s
.73308 .60962 m .72067 .66236 L .75179 .66786 L p .707 .577 .707 r
F P
0 g
s
.75179 .66786 m .7642 .61513 L .73308 .60962 L p .707 .577 .707 r
F P
0 g
s
.25331 .67126 m .24505 .70642 L .21624 .70483 L p .707 .577 .707 r
F P
0 g
s
.24505 .70642 m .25331 .67126 L .28443 .67674 L p .707 .577 .707 r
F P
0 g
s
.6903 .6535 m .70271 .60076 L .67605 .58941 L p .707 .577 .707 r
F P
0 g
s
.70271 .60076 m .6903 .6535 L .72067 .66236 L p .707 .577 .707 r
F P
0 g
s
.31481 .68558 m .30655 .72075 L .27617 .71191 L p .707 .577 .707 r
F P
0 g
s
.27617 .71191 m .28443 .67674 L .31481 .68558 L p .707 .577 .707 r
F P
0 g
s
.7642 .61513 m .75179 .66786 L .7806 .66947 L p .707 .577 .707 r
F P
0 g
s
.7806 .66947 m .79301 .61673 L .7642 .61513 L p .707 .577 .707 r
F P
0 g
s
.28443 .67674 m .27617 .71191 L .24505 .70642 L p .707 .577 .707 r
F P
0 g
s
.1809 .79937 m .17511 .78122 L .19844 .77097 L p .707 .577 .707 r
F P
0 g
s
.19844 .77097 m .20422 .78912 L .1809 .79937 L p .707 .577 .707 r
F P
0 g
s
.31258 .73686 m .31836 .75501 L .29248 .76064 L p .707 .577 .707 r
F P
0 g
s
.29248 .76064 m .2867 .74249 L .31258 .73686 L p .707 .577 .707 r
F P
0 g
s
.59045 .25088 m .59638 .75337 L .55762 .7477 L p .707 .577 .707 r
F P
0 g
s
.55762 .7477 m .55169 .24521 L .59045 .25088 L p .707 .577 .707 r
F P
0 g
s
.74125 .72511 m .7495 .68995 L .71913 .6811 L p .707 .577 .707 r
F P
0 g
s
.7495 .68995 m .74125 .72511 L .77237 .7306 L p .707 .577 .707 r
F P
0 g
s
.77237 .7306 m .78062 .69543 L .7495 .68995 L p .707 .577 .707 r
F P
0 g
s
.66364 .64214 m .67605 .58941 L .65571 .57667 L p .707 .577 .707 r
F P
0 g
s
.67605 .58941 m .66364 .64214 L .6903 .6535 L p .707 .577 .707 r
F P
0 g
s
.79301 .61673 m .7806 .66947 L .80428 .66702 L p .707 .577 .707 r
F P
0 g
s
.80428 .66702 m .8167 .61428 L .79301 .61673 L p .707 .577 .707 r
F P
0 g
s
.71087 .71627 m .71913 .6811 L .69246 .66977 L p .707 .577 .707 r
F P
0 g
s
.71913 .6811 m .71087 .71627 L .74125 .72511 L p .707 .577 .707 r
F P
0 g
s
.78062 .69543 m .77237 .7306 L .80119 .73219 L p .707 .577 .707 r
F P
0 g
s
.80119 .73219 m .80944 .69702 L .78062 .69543 L p .707 .577 .707 r
F P
0 g
s
.4272 .75226 m .42127 .24977 L .46274 .24463 L p .707 .577 .707 r
F P
0 g
s
.42127 .24977 m .4272 .75226 L .39324 .76048 L p .707 .577 .707 r
F P
0 g
s
.20422 .78912 m .19844 .77097 L .22669 .76042 L p .707 .577 .707 r
F P
0 g
s
.2867 .74249 m .29248 .76064 L .26289 .76875 L p .707 .577 .707 r
F P
0 g
s
.26289 .76875 m .2571 .7506 L .2867 .74249 L p .707 .577 .707 r
F P
0 g
s
.22669 .76042 m .23247 .77857 L .20422 .78912 L p .707 .577 .707 r
F P
0 g
s
.69246 .66977 m .68421 .70493 L .71087 .71627 L p .707 .577 .707 r
F P
0 g
s
.68421 .70493 m .69246 .66977 L .67212 .65705 L p .707 .577 .707 r
F P
0 g
s
.80944 .69702 m .80119 .73219 L .82488 .72973 L p .707 .577 .707 r
F P
0 g
s
.82488 .72973 m .83313 .69456 L .80944 .69702 L p .707 .577 .707 r
F P
0 g
s
.55169 .24521 m .55762 .7477 L .51362 .74554 L p .707 .577 .707 r
F P
0 g
s
.51362 .74554 m .50769 .24305 L .55169 .24521 L p .707 .577 .707 r
F P
0 g
s
.65571 .57667 m .6433 .62941 L .66364 .64214 L p .707 .577 .707 r
F P
0 g
s
.72639 .74892 m .72061 .73077 L .69102 .73889 L p .707 .577 .707 r
F P
0 g
s
.72061 .73077 m .72639 .74892 L .7568 .73911 L p .707 .577 .707 r
F P
0 g
s
.7568 .73911 m .75102 .72096 L .72061 .73077 L p .707 .577 .707 r
F P
0 g
s
.6433 .62941 m .65571 .57667 L .64369 .5638 L p .707 .577 .707 r
F P
0 g
s
.75102 .72096 m .7568 .73911 L .78506 .72856 L p .707 .577 .707 r
F P
0 g
s
.78506 .72856 m .77927 .71041 L .75102 .72096 L p .707 .577 .707 r
F P
0 g
s
.8167 .61428 m .80428 .66702 L .82053 .66076 L p .707 .577 .707 r
F P
0 g
s
.82053 .66076 m .83294 .60802 L .8167 .61428 L p .707 .577 .707 r
F P
0 g
s
.23247 .77857 m .22669 .76042 L .2571 .7506 L p .707 .577 .707 r
F P
0 g
s
.2571 .7506 m .26289 .76875 L .23247 .77857 L p .707 .577 .707 r
F P
0 g
s
.69102 .73889 m .6968 .75704 L .72639 .74892 L p .707 .577 .707 r
F P
0 g
s
.46868 .74711 m .46274 .24463 L .50769 .24305 L p .707 .577 .707 r
F P
0 g
s
.46274 .24463 m .46868 .74711 L .4272 .75226 L p .707 .577 .707 r
F P
0 g
s
.67212 .65705 m .66387 .69222 L .68421 .70493 L p .707 .577 .707 r
F P
0 g
s
.50769 .24305 m .51362 .74554 L .46868 .74711 L p .707 .577 .707 r
F P
0 g
s
.6968 .75704 m .69102 .73889 L .66514 .74451 L p .707 .577 .707 r
F P
0 g
s
.77927 .71041 m .78506 .72856 L .80838 .7183 L p .707 .577 .707 r
F P
0 g
s
.80838 .7183 m .8026 .70015 L .77927 .71041 L p .707 .577 .707 r
F P
0 g
s
.66514 .74451 m .67092 .76266 L .6968 .75704 L p .707 .577 .707 r
F P
0 g
s
.66387 .69222 m .67212 .65705 L .6601 .6442 L p .707 .577 .707 r
F P
0 g
s
.83313 .69456 m .82488 .72973 L .84112 .72346 L p .707 .577 .707 r
F P
0 g
s
.84112 .72346 m .84937 .6883 L .83313 .69456 L p .707 .577 .707 r
F P
0 g
s
.67092 .76266 m .66514 .74451 L .64551 .74709 L p .707 .577 .707 r
F P
0 g
s
.83294 .60802 m .82053 .66076 L .82774 .65129 L p .707 .577 .707 r
F P
0 g
s
.82774 .65129 m .84015 .59855 L .83294 .60802 L p .707 .577 .707 r
F P
0 g
s
.6601 .6442 m .65184 .67936 L .66387 .69222 L p .707 .577 .707 r
F P
0 g
s
.64551 .74709 m .65129 .76524 L .67092 .76266 L p .707 .577 .707 r
F P
0 g
s
.8026 .70015 m .80838 .7183 L .8245 .70935 L p .707 .577 .707 r
F P
0 g
s
.8245 .70935 m .81872 .6912 L .8026 .70015 L p .707 .577 .707 r
F P
0 g
s
.65184 .67936 m .6601 .6442 L .65756 .63246 L p .707 .577 .707 r
F P
0 g
s
.84937 .6883 m .84112 .72346 L .84833 .714 L p .707 .577 .707 r
F P
0 g
s
.84833 .714 m .85658 .67883 L .84937 .6883 L p .707 .577 .707 r
F P
0 g
s
.64116 .55206 m .62875 .6048 L .63128 .61654 L p .707 .577 .707 r
F P
0 g
s
.65129 .76524 m .64551 .74709 L .63405 .74638 L p .707 .577 .707 r
F P
0 g
s
.63405 .74638 m .63983 .76453 L .65129 .76524 L p .707 .577 .707 r
F P
0 g
s
.65756 .63246 m .64931 .66763 L .65184 .67936 L p .707 .577 .707 r
F P
0 g
s
.62875 .6048 m .64116 .55206 L .64837 .54259 L p .707 .577 .707 r
F P
0 g
s
.81872 .6912 m .8245 .70935 L .83184 .70257 L p .707 .577 .707 r
F P
0 g
s
.83184 .70257 m .82605 .68442 L .81872 .6912 L p .707 .577 .707 r
F P
0 g
s
.84015 .59855 m .82774 .65129 L .82521 .63955 L p .707 .577 .707 r
F P
0 g
s
.82521 .63955 m .83762 .58681 L .84015 .59855 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64931 .66763 m .65756 .63246 L .66477 .623 L p .707 .577 .707 r
F P
0 g
s
.85658 .67883 m .84833 .714 L .8458 .70227 L p .707 .577 .707 r
F P
0 g
s
.8458 .70227 m .85405 .6671 L .85658 .67883 L p .707 .577 .707 r
F P
0 g
s
.64837 .54259 m .63596 .59533 L .62875 .6048 L p .707 .577 .707 r
F P
0 g
s
.63983 .76453 m .63405 .74638 L .63188 .74244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63188 .74244 m .63766 .76059 L .63983 .76453 L p .707 .577 .707 r
F P
0 g
s
.66477 .623 m .65652 .65816 L .64931 .66763 L p .707 .577 .707 r
F P
0 g
s
.63596 .59533 m .64837 .54259 L .66462 .53633 L p .707 .577 .707 r
F P
0 g
s
.83762 .58681 m .82521 .63955 L .81318 .62668 L p .707 .577 .707 r
F P
0 g
s
.81318 .62668 m .8256 .57394 L .83762 .58681 L p .707 .577 .707 r
F P
0 g
s
.82605 .68442 m .83184 .70257 L .82967 .69863 L p .707 .577 .707 r
F P
0 g
s
.82967 .69863 m .82388 .68048 L .82605 .68442 L p .707 .577 .707 r
F P
0 g
s
.37766 .62561 m .39007 .57287 L .3597 .564 L p .707 .577 .707 r
F P
0 g
s
.39007 .57287 m .37766 .62561 L .40878 .63111 L p .707 .577 .707 r
F P
0 g
s
.40878 .63111 m .42119 .57837 L .39007 .57287 L p .707 .577 .707 r
F P
0 g
s
.34729 .61674 m .3597 .564 L .33304 .55265 L p .707 .577 .707 r
F P
0 g
s
.3597 .564 m .34729 .61674 L .37766 .62561 L p .707 .577 .707 r
F P
0 g
s
.42119 .57837 m .40878 .63111 L .43759 .63271 L p .707 .577 .707 r
F P
0 g
s
.43759 .63271 m .45 .57998 L .42119 .57837 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65652 .65816 m .66477 .623 L .68102 .61673 L p .707 .577 .707 r
F P
0 g
s
.85405 .6671 m .8458 .70227 L .83377 .68941 L p .707 .577 .707 r
F P
0 g
s
.83377 .68941 m .84202 .65424 L .85405 .6671 L p .707 .577 .707 r
F P
0 g
s
.66462 .53633 m .6522 .58906 L .63596 .59533 L p .707 .577 .707 r
F P
0 g
s
.39824 .68847 m .4065 .6533 L .37612 .64446 L p .707 .577 .707 r
F P
0 g
s
.4065 .6533 m .39824 .68847 L .42936 .69395 L p .707 .577 .707 r
F P
0 g
s
.42936 .69395 m .43762 .65879 L .4065 .6533 L p .707 .577 .707 r
F P
0 g
s
.32063 .60539 m .33304 .55265 L .3127 .53991 L p .707 .577 .707 r
F P
0 g
s
.33304 .55265 m .32063 .60539 L .34729 .61674 L p .707 .577 .707 r
F P
0 g
s
.45 .57998 m .43759 .63271 L .46127 .63027 L p .707 .577 .707 r
F P
0 g
s
.46127 .63027 m .47369 .57753 L .45 .57998 L p .707 .577 .707 r
F P
0 g
s
.6522 .58906 m .66462 .53633 L .6883 .53388 L p .707 .577 .707 r
F P
0 g
s
.36786 .67962 m .37612 .64446 L .34945 .63312 L p .707 .577 .707 r
F P
0 g
s
.37612 .64446 m .36786 .67962 L .39824 .68847 L p .707 .577 .707 r
F P
0 g
s
.63766 .76059 m .63188 .74244 L .63921 .73567 L p .707 .577 .707 r
F P
0 g
s
.43762 .65879 m .42936 .69395 L .45818 .69554 L p .707 .577 .707 r
F P
0 g
s
.45818 .69554 m .46643 .66038 L .43762 .65879 L p .707 .577 .707 r
F P
0 g
s
.8256 .57394 m .81318 .62668 L .79285 .61394 L p .707 .577 .707 r
F P
0 g
s
.79285 .61394 m .80526 .5612 L .8256 .57394 L p .707 .577 .707 r
F P
0 g
s
.68102 .61673 m .67277 .6519 L .65652 .65816 L p .707 .577 .707 r
F P
0 g
s
.63921 .73567 m .64499 .75382 L .63766 .76059 L p .707 .577 .707 r
F P
0 g
s
.82388 .68048 m .82967 .69863 L .8182 .69792 L p .707 .577 .707 r
F P
0 g
s
.8182 .69792 m .81242 .67977 L .82388 .68048 L p .707 .577 .707 r
F P
0 g
s
.34945 .63312 m .3412 .66829 L .36786 .67962 L p .707 .577 .707 r
F P
0 g
s
.3412 .66829 m .34945 .63312 L .32911 .6204 L p .707 .577 .707 r
F P
0 g
s
.46643 .66038 m .45818 .69554 L .48187 .69308 L p .707 .577 .707 r
F P
0 g
s
.48187 .69308 m .49012 .65792 L .46643 .66038 L p .707 .577 .707 r
F P
0 g
s
.67277 .6519 m .68102 .61673 L .70471 .61427 L p .707 .577 .707 r
F P
0 g
s
.84202 .65424 m .83377 .68941 L .81343 .67669 L p .707 .577 .707 r
F P
0 g
s
.81343 .67669 m .82168 .64153 L .84202 .65424 L p .707 .577 .707 r
F P
0 g
s
.3127 .53991 m .30029 .59265 L .32063 .60539 L p .707 .577 .707 r
F P
0 g
s
.38338 .71139 m .3776 .69324 L .34801 .70136 L p .707 .577 .707 r
F P
0 g
s
.3776 .69324 m .38338 .71139 L .41379 .70158 L p .707 .577 .707 r
F P
0 g
s
.41379 .70158 m .40801 .68343 L .3776 .69324 L p .707 .577 .707 r
F P
0 g
s
.30029 .59265 m .3127 .53991 L .30068 .52705 L p .707 .577 .707 r
F P
0 g
s
.40801 .68343 m .41379 .70158 L .44205 .69103 L p .707 .577 .707 r
F P
0 g
s
.44205 .69103 m .43627 .67288 L .40801 .68343 L p .707 .577 .707 r
F P
0 g
s
.6883 .53388 m .67589 .58661 L .6522 .58906 L p .707 .577 .707 r
F P
0 g
s
.47369 .57753 m .46127 .63027 L .47752 .624 L p .707 .577 .707 r
F P
0 g
s
.47752 .624 m .48993 .57126 L .47369 .57753 L p .707 .577 .707 r
F P
0 g
s
.67589 .58661 m .6883 .53388 L .71711 .53548 L p .707 .577 .707 r
F P
0 g
s
.34801 .70136 m .35379 .71951 L .38338 .71139 L p .707 .577 .707 r
F P
0 g
s
.80526 .5612 m .79285 .61394 L .76619 .60259 L p .707 .577 .707 r
F P
0 g
s
.76619 .60259 m .7786 .54985 L .80526 .5612 L p .707 .577 .707 r
F P
0 g
s
.32911 .6204 m .32086 .65557 L .3412 .66829 L p .707 .577 .707 r
F P
0 g
s
.35379 .71951 m .34801 .70136 L .32213 .70698 L p .707 .577 .707 r
F P
0 g
s
.70471 .61427 m .69645 .64944 L .67277 .6519 L p .707 .577 .707 r
F P
0 g
s
.43627 .67288 m .44205 .69103 L .46537 .68077 L p .707 .577 .707 r
F P
0 g
s
.46537 .68077 m .45959 .66262 L .43627 .67288 L p .707 .577 .707 r
F P
0 g
s
.32213 .70698 m .32791 .72513 L .35379 .71951 L p .707 .577 .707 r
F P
0 g
s
.64499 .75382 m .63921 .73567 L .65533 .72671 L p .707 .577 .707 r
F P
0 g
s
.65533 .72671 m .66111 .74486 L .64499 .75382 L p .707 .577 .707 r
F P
0 g
s
.32086 .65557 m .32911 .6204 L .31709 .60755 L p .707 .577 .707 r
F P
0 g
s
.7047 .58822 m .71711 .53548 L .74823 .54099 L p .707 .577 .707 r
F P
0 g
s
.71711 .53548 m .7047 .58822 L .67589 .58661 L p .707 .577 .707 r
F P
0 g
s
.7786 .54985 m .76619 .60259 L .73581 .59372 L p .707 .577 .707 r
F P
0 g
s
.73581 .59372 m .74823 .54099 L .7786 .54985 L p .707 .577 .707 r
F P
0 g
s
.81242 .67977 m .8182 .69792 L .79857 .7005 L p .707 .577 .707 r
F P
0 g
s
.79857 .7005 m .79279 .68235 L .81242 .67977 L p .707 .577 .707 r
F P
0 g
s
.49012 .65792 m .48187 .69308 L .49811 .68682 L p .707 .577 .707 r
F P
0 g
s
.49811 .68682 m .50636 .65165 L .49012 .65792 L p .707 .577 .707 r
F P
0 g
s
.69645 .64944 m .70471 .61427 L .73352 .61586 L p .707 .577 .707 r
F P
0 g
s
.82168 .64153 m .81343 .67669 L .78677 .66536 L p .707 .577 .707 r
F P
0 g
s
.78677 .66536 m .79502 .63019 L .82168 .64153 L p .707 .577 .707 r
F P
0 g
s
.30068 .52705 m .28827 .57978 L .30029 .59265 L p .707 .577 .707 r
F P
0 g
s
.74823 .54099 m .73581 .59372 L .7047 .58822 L p .707 .577 .707 r
F P
0 g
s
.32791 .72513 m .32213 .70698 L .3025 .70957 L p .707 .577 .707 r
F P
0 g
s
.28827 .57978 m .30068 .52705 L .29815 .5153 L p .707 .577 .707 r
F P
0 g
s
.48993 .57126 m .47752 .624 L .48473 .61453 L p .707 .577 .707 r
F P
0 g
s
.48473 .61453 m .49714 .5618 L .48993 .57126 L p .707 .577 .707 r
F P
0 g
s
.31709 .60755 m .30883 .64272 L .32086 .65557 L p .707 .577 .707 r
F P
0 g
s
.3025 .70957 m .30828 .72772 L .32791 .72513 L p .707 .577 .707 r
F P
0 g
s
.45959 .66262 m .46537 .68077 L .48149 .67182 L p .707 .577 .707 r
F P
0 g
s
.48149 .67182 m .47571 .65367 L .45959 .66262 L p .707 .577 .707 r
F P
0 g
s
.73352 .61586 m .72527 .65103 L .69645 .64944 L p .707 .577 .707 r
F P
0 g
s
.72527 .65103 m .73352 .61586 L .76464 .62135 L p .707 .577 .707 r
F P
0 g
s
.79502 .63019 m .78677 .66536 L .75639 .65652 L p .707 .577 .707 r
F P
0 g
s
.75639 .65652 m .76464 .62135 L .79502 .63019 L p .707 .577 .707 r
F P
0 g
s
.76464 .62135 m .75639 .65652 L .72527 .65103 L p .707 .577 .707 r
F P
0 g
s
.66111 .74486 m .65533 .72671 L .67866 .71646 L p .707 .577 .707 r
F P
0 g
s
.67866 .71646 m .68444 .73461 L .66111 .74486 L p .707 .577 .707 r
F P
0 g
s
.79279 .68235 m .79857 .7005 L .77269 .70613 L p .707 .577 .707 r
F P
0 g
s
.77269 .70613 m .76691 .68798 L .79279 .68235 L p .707 .577 .707 r
F P
0 g
s
.30883 .64272 m .31709 .60755 L .31455 .59582 L p .707 .577 .707 r
F P
0 g
s
.50636 .65165 m .49811 .68682 L .50532 .67735 L p .707 .577 .707 r
F P
0 g
s
.50532 .67735 m .51357 .64219 L .50636 .65165 L p .707 .577 .707 r
F P
0 g
s
.29815 .5153 m .28574 .56804 L .28827 .57978 L p .707 .577 .707 r
F P
0 g
s
.30828 .72772 m .3025 .70957 L .29104 .70885 L p .707 .577 .707 r
F P
0 g
s
.29104 .70885 m .29682 .727 L .30828 .72772 L p .707 .577 .707 r
F P
0 g
s
.31455 .59582 m .3063 .63098 L .30883 .64272 L p .707 .577 .707 r
F P
0 g
s
.28574 .56804 m .29815 .5153 L .30536 .50584 L p .707 .577 .707 r
F P
0 g
s
.47571 .65367 m .48149 .67182 L .48883 .66504 L p .707 .577 .707 r
F P
0 g
s
.48883 .66504 m .48304 .64689 L .47571 .65367 L p .707 .577 .707 r
F P
0 g
s
.68444 .73461 m .67866 .71646 L .70691 .70591 L p .707 .577 .707 r
F P
0 g
s
.49714 .5618 m .48473 .61453 L .4822 .60279 L p .707 .577 .707 r
F P
0 g
s
.4822 .60279 m .49461 .55005 L .49714 .5618 L p .707 .577 .707 r
F P
0 g
s
.76691 .68798 m .77269 .70613 L .7431 .71424 L p .707 .577 .707 r
F P
0 g
s
.7431 .71424 m .73732 .69609 L .76691 .68798 L p .707 .577 .707 r
F P
0 g
s
.70691 .70591 m .71269 .72406 L .68444 .73461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71269 .72406 m .70691 .70591 L .73732 .69609 L p .707 .577 .707 r
F P
0 g
s
.73732 .69609 m .7431 .71424 L .71269 .72406 L p .707 .577 .707 r
F P
0 g
s
.3063 .63098 m .31455 .59582 L .32176 .58635 L p .707 .577 .707 r
F P
0 g
s
.51357 .64219 m .50532 .67735 L .50279 .66562 L p .707 .577 .707 r
F P
0 g
s
.50279 .66562 m .51104 .63045 L .51357 .64219 L p .707 .577 .707 r
F P
0 g
s
.30536 .50584 m .29295 .55857 L .28574 .56804 L p .707 .577 .707 r
F P
0 g
s
.29682 .727 m .29104 .70885 L .28887 .70491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28887 .70491 m .29465 .72306 L .29682 .727 L p .707 .577 .707 r
F P
0 g
s
.32176 .58635 m .31351 .62152 L .3063 .63098 L p .707 .577 .707 r
F P
0 g
s
.29295 .55857 m .30536 .50584 L .32161 .49957 L p .707 .577 .707 r
F P
0 g
s
.48304 .64689 m .48883 .66504 L .48666 .6611 L p .707 .577 .707 r
F P
0 g
s
.48666 .6611 m .48087 .64295 L .48304 .64689 L p .707 .577 .707 r
F P
0 g
s
.49461 .55005 m .4822 .60279 L .47017 .58992 L p .707 .577 .707 r
F P
0 g
s
.47017 .58992 m .48259 .53718 L .49461 .55005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31351 .62152 m .32176 .58635 L .33801 .58008 L p .707 .577 .707 r
F P
0 g
s
.51104 .63045 m .50279 .66562 L .49076 .65276 L p .707 .577 .707 r
F P
0 g
s
.49076 .65276 m .49901 .6176 L .51104 .63045 L p .707 .577 .707 r
F P
0 g
s
.32161 .49957 m .30919 .55231 L .29295 .55857 L p .707 .577 .707 r
F P
0 g
s
.30919 .55231 m .32161 .49957 L .34529 .49712 L p .707 .577 .707 r
F P
0 g
s
.29465 .72306 m .28887 .70491 L .2962 .69814 L p .707 .577 .707 r
F P
0 g
s
.48259 .53718 m .47017 .58992 L .44984 .57719 L p .707 .577 .707 r
F P
0 g
s
.44984 .57719 m .46225 .52445 L .48259 .53718 L p .707 .577 .707 r
F P
0 g
s
.33801 .58008 m .32975 .61525 L .31351 .62152 L p .707 .577 .707 r
F P
0 g
s
.2962 .69814 m .30198 .71629 L .29465 .72306 L p .707 .577 .707 r
F P
0 g
s
.48087 .64295 m .48666 .6611 L .47519 .66039 L p .707 .577 .707 r
F P
0 g
s
.47519 .66039 m .46941 .64224 L .48087 .64295 L p .707 .577 .707 r
F P
0 g
s
.32975 .61525 m .33801 .58008 L .3617 .57762 L p .707 .577 .707 r
F P
0 g
s
.49901 .6176 m .49076 .65276 L .47042 .64005 L p .707 .577 .707 r
F P
0 g
s
.47042 .64005 m .47867 .60488 L .49901 .6176 L p .707 .577 .707 r
F P
0 g
s
.34529 .49712 m .33288 .54986 L .30919 .55231 L p .707 .577 .707 r
F P
0 g
s
.33288 .54986 m .34529 .49712 L .3741 .49873 L p .707 .577 .707 r
F P
0 g
s
.46225 .52445 m .44984 .57719 L .42318 .56583 L p .707 .577 .707 r
F P
0 g
s
.42318 .56583 m .43559 .51309 L .46225 .52445 L p .707 .577 .707 r
F P
0 g
s
.3617 .57762 m .35344 .61279 L .32975 .61525 L p .707 .577 .707 r
F P
0 g
s
.30198 .71629 m .2962 .69814 L .31232 .68918 L p .707 .577 .707 r
F P
0 g
s
.31232 .68918 m .3181 .70733 L .30198 .71629 L p .707 .577 .707 r
F P
0 g
s
.36169 .55146 m .3741 .49873 L .40522 .50423 L p .707 .577 .707 r
F P
0 g
s
.3741 .49873 m .36169 .55146 L .33288 .54986 L p .707 .577 .707 r
F P
0 g
s
.43559 .51309 m .42318 .56583 L .3928 .55697 L p .707 .577 .707 r
F P
0 g
s
.3928 .55697 m .40522 .50423 L .43559 .51309 L p .707 .577 .707 r
F P
0 g
s
.46941 .64224 m .47519 .66039 L .45556 .66297 L p .707 .577 .707 r
F P
0 g
s
.45556 .66297 m .44978 .64482 L .46941 .64224 L p .707 .577 .707 r
F P
0 g
s
.35344 .61279 m .3617 .57762 L .39051 .57922 L p .707 .577 .707 r
F P
0 g
s
.47867 .60488 m .47042 .64005 L .44376 .62871 L p .707 .577 .707 r
F P
0 g
s
.44376 .62871 m .45201 .59355 L .47867 .60488 L p .707 .577 .707 r
F P
0 g
s
.40522 .50423 m .3928 .55697 L .36169 .55146 L p .707 .577 .707 r
F P
0 g
s
.39051 .57922 m .38226 .61438 L .35344 .61279 L p .707 .577 .707 r
F P
0 g
s
.38226 .61438 m .39051 .57922 L .42163 .5847 L p .707 .577 .707 r
F P
0 g
s
.45201 .59355 m .44376 .62871 L .41338 .61987 L p .707 .577 .707 r
F P
0 g
s
.41338 .61987 m .42163 .5847 L .45201 .59355 L p .707 .577 .707 r
F P
0 g
s
.42163 .5847 m .41338 .61987 L .38226 .61438 L p .707 .577 .707 r
F P
0 g
s
.3181 .70733 m .31232 .68918 L .33564 .67893 L p .707 .577 .707 r
F P
0 g
s
.33564 .67893 m .34143 .69708 L .3181 .70733 L p .707 .577 .707 r
F P
0 g
s
.44978 .64482 m .45556 .66297 L .42968 .6686 L p .707 .577 .707 r
F P
0 g
s
.42968 .6686 m .4239 .65045 L .44978 .64482 L p .707 .577 .707 r
F P
0 g
s
.34143 .69708 m .33564 .67893 L .3639 .66838 L p .707 .577 .707 r
F P
0 g
s
.4239 .65045 m .42968 .6686 L .40009 .67671 L p .707 .577 .707 r
F P
0 g
s
.40009 .67671 m .39431 .65856 L .4239 .65045 L p .707 .577 .707 r
F P
0 g
s
.3639 .66838 m .36968 .68653 L .34143 .69708 L p .707 .577 .707 r
F P
0 g
s
.36968 .68653 m .3639 .66838 L .39431 .65856 L p .707 .577 .707 r
F P
0 g
s
.39431 .65856 m .40009 .67671 L .36968 .68653 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol005moo`h00003FUH005YF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Eoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001FOol30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`80
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`L005Ioo`00Dgoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo
10000eYF00@005YFFUIJEPT004eoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00Agoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020014Ool0059oo`03001JEP00
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH30011Ool0059oo`8000=JEP04001JEUYFFUH>0007FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`00?Woo001BOol20002FUH50003FUH20005Ool00`00FUIJEP050002
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003aoo`00DWoo00IJEP00
000005YF0006FUH01000FUH000000goo00@005YFFUH000AJEPD000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8003Yoo`00DGoo0P0015YF00<005YFFUH015YF00@005YFFUIJEP@0
009JEP03001JEUYF00AJEPL0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000hOol0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP@000EJEPD000=JEP<000MJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00DGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF00000`000UYF1@001EYF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EP00=Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70005FUH0
0`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<goo001AOol0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70003FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo031oo`00DGoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YF00004@0015YF2`001UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000aOol0059oo`05001JEUYFFUH00005FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH30004FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00
Dgoo00<005YF00001EYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@00
1EYF00<005YFFUH00P0000=JEP00FUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUIJEP0000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003Qoo`L0
01Eoo`8000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00D000EJEP8000AJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPD0009JEP<0009oo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02aoo`00<goo1@000eYF00@005YFFUIJEPT000eoo`03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
00AJEP8000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
001JEP0200000eYF001JEP05FUH01000FUH000002Goo1P001eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002ioo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P0027oo0P0000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0`000UYF00@005YF001JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000]oo`@000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002moo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000008Ool30003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP030002FUH30006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH015YF0`001goo200000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00000P0017oo1@000goo0`001eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000goo000000030006Ool20004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000Qo
o`<00003FUH005YF00EJEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUHB0006FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF1`0015YF00<005YFFUH0
0UYF20000goo0P001UYF00@005YFFUIJEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP000000
17oo10001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUH000040003FUH01000FUIJEUYF2@0015YF00@005YFFUIJEPL000AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000Ioo`@0009JEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60006FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000_Ool002aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH20004FUH40004Ool00`00FUIJEP060006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YF001JEP0000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH20005FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000
0eYF00<005YFFUH00UYF0`000eYF00<005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00`00
0Woo00@005YFFUH000EJEP@0009JEP03001JEUYF00EJEP<000MJEP03001JEUYF00=JEP04001JEUYF
FUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40006FUH01000
FUIJEUYF0P00<7oo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEQ<0
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<00004FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30004FUH20002FUH2000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP8000=JEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800004Ool000000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01P00FUH00000FUH0009JEP800003FUH007oo02moo`00:goo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00UYF00<005YFFUH015YF00H005YF000005YF0005FUH50006FUH00`00FUIJEP07FUH3
0006FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YFFUIJEP<0009JEP03001JEP00031oo`00:goo00<005YF00000UYF00@005YFFUIJEPL000AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF009JEP8000IJEP<000MJEP03001JEUYF00MJEP<000IJEP04001JEUYFFUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00Ool0
;goo000[Ool20003FUH40003FUH20002Ool90004FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH015YF10000UYF00<005YFFUH01eYF00<005YFFUH01`000UYF0`00
0eYF00<005YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1000
00=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`00<Goo000[Ool00eYF001JEP030006FUH01000FUH000002Goo1P0025YF00<0
05YFFUH015YF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH010001UYF1@000eYF00<005YF
FUH015YF00H005YF000005YF0003FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUH005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF000`Ool002Yoo`04001JEP000002FUH00`00FUIJEP04
FUH01000FUIJEUYF0`002Woo1@0015YF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<005YF
FUH015YF1P0000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF200015YF200015YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000ZOol20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH30006Ool500001Woo00000000FUH000MJEP03001JEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00800003FUH0
07oo00Eoo`8000EJEP03001JEUYF009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo02]oo`00:Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000Aoo`D000Ao
o`<000IJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP05
FUH01000FUIJEUYF100000AJEP000000009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP800003FUH0000000=JEP8000Moo`<00003FUH005YF00QJEP03001JEP00008000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8002aoo`00:Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0000=oo`0000000`001goo0P0015YF00@005YFFUIJEP80009JEP03
001JEUYF00EJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00AJEPD0009JEP03001JEP00
00800004FUH00000FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH00`00FUIJEP020008Ool60004FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEP00:goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH60009Ool200000eYF001JEP05FUH20008FUH30004FUH00`00FUIJEP07FUH00`00FUH000060005
FUH00`00FUH00003FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF00<007ooOol02goo200015YF10001eYF00<005YF
FUH00eYF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
15YF3@000UYF20000goo0P001UYF0`0015YF0`0025YF00<005YFFUH015YF10000UYF0P000eYF00<0
05YFFUH00UYF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF0P002Woo1@0017oo2P0015YF00<005YFFUH0
15YF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00001@00
0UYF00<005YFFUH01UYF00<005YF00000`000UYF00@005YFFUIJEPL000AJEP03001JEUYF00@00003
FUH005YF00QJEP03001JEUYF00@000=JEP<000EJEP03001JEUYF009JEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF
00AJEP04001JEP000008Ool5000>Ool300000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0X
Ool002]oo`04001JEUYF0005FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50005FUH00`00FUIJEP02000015YF001JEUYF0`0015YF00<005YFFUH01EYF100015YF0`0000=J
EP00FUH01UYF00H005YF000005YF0004FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Goo1@004Goo0P00
1EYF00L005YFFUIJEP00FUH0000YOol002aoo`<000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00=JEP@000MJEP03001JEUYF00=JEP@0
00=JEP<000AJEP03001JEUYF00AJEP<000=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH30003Ool3000@Ool50004FUH01`00FUIJEUYF001JEP0002Uoo`00;Woo00<005YFFUH00UYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`0000=JEP00
FUH025YF00<005YF00002@0025YF00@005YFFUIJEP<000EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF
00<005YFFUH01UYF00<005YF00000P003Goo1P000UYF00<005YFFUH00P000UYF00L005YFFUIJEP00
FUH0000YOol002moo`800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00EJEP<000=JEPH000UJEP06001JEP00001JEP00
1UYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0017oo1P000eYF00<005YF
FUH00eYF00<005YFFUH00`0015YF00<005YF0000:Goo000aOol30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP03FUH200000eYF001J
EP02FUH600000eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP80
02Yoo`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF00<005YFFUH01EYF00<005YF00000`000UYF10000UYF0`000UYF00<005YFFUH00eYF
40001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF
00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00<0009JEP03001JEP0002Yoo`00<Goo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
15YF100000=oo`0000000P000UYF00<005YFFUH01eYF00<005YF00000P002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUH000QJEP03001JEP0000800003FUH005YF00MJEP03001JEUYF00EJEP04001JEUYF
FUH700001UYF00000000FUH002Yoo`00<Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP800003FUH00000008000IJ
EP03001JEUYF00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00AJEP<000MJEP<000EJEP03
001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUIJEP000eYF00<005YF0000:Woo000aOol20003
FUH01000FUIJEUYF3P001UYF00L005YFFUIJEP00FUH00005FUH00`00FUH0000400000eYF001JEP08
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40006FUH30003FUH30008FUH00`00FUIJEP05
FUH50002FUH200000eYF001JEP04FUH20004FUH00`00FUH0000ZOol0035oo`80009JEPP000QJEP03
001JEUYF00@0009JEP05001JEUYFFUH00002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<0
05YF00000P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF1P0015YF00<005YFFUH00`0000=JEP00FUH025YF00<005YF
FUH00eYF0P000UYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0015YF0P00:goo000aOol01UYF
00000000FUH000Ioo`<000AJEP03001JEUYF00EJEPD00006FUH005YFFUH005YF0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP00
009JEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEP00008000AJEP<000IJEP03001JEUYF
00800003FUH005YF00=JEP8002]oo`00<7oo0P0015YF0`001goo0`0000=JEP00FUH01eYF00@005YF
FUIJEP<00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP<000AJEP@000MJEP03001JEUYF00EJEP@000EJEP800003FUH005YF00IJEP<000=J
EP07001JEUYFFUH005YF0000:goo000`Ool20004FUH01000FUIJEP002Goo1P0015YF00<005YFFUH0
0eYF0P0000=JEP00FUH015YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF0`002EYF00<005YFFUH020000UYF0`0015YF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<005YFFUH00UYF0P0037oo2@000UYF
0P000UYF00<005YFFUH00eYF00<005YF00000`000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1`000eYF00<005YFFUH01EYF100000=oo`0000001`001eYF00<005YFFUH0
0UYF0P001EYF00@005YFFUIJEP8002eoo`00<7oo0P000eYF00<005YFFUH015YF0P002Goo1@001Goo
3`001EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP000000
1EYF00<005YFFUH00eYF0P001Woo1`002EYF00H005YF000005YF0005FUH01000FUH00000;goo000`
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUH000001goo1@0047oo0`001UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10001eYF00<005YF00000P0017oo10000UYF
0`000UYF00<005YFFUH01EYF0`000UYF00@005YFFUIJEPD0035oo`00<7oo00<005YFFUH00UYF00<0
05YFFUH015YF00@005YFFUIJEP8000Eoo`D0011oo`<000IJEP80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP<00003FUH007oo009oo`800003FUH0
05YF00QJEP03001JEUYF00=JEP800003Ool0000000H003Ioo`00<Goo00D005YFFUIJEP0000EJEP03
001JEUYF00AJEP@0009oo`<000aoo`D0009JEP<000=JEP03001JEP00009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00005FUH01000FUIJEUYF0P0000EJEP00000007oo00<000AJEP03
001JEUYF00MJEP03001JEP000080045oo`00<Woo00<005YF00001UYF00<005YFFUH01EYF00<005YF
FUH010002Goo100000=JEP00FUH01EYF00P005YF000005YF001JEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P001EYF00@005YF0000009JEPD000MJEP03001JEUYF00EJEP@004Ao
o`00<goo0P001UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000Aoo`00000000IJEP03001JEUYF
00=JEP03001JEUYF00<00005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00
FUIJEP02FUH60003FUH00`00FUIJEP07FUH00`00FUIJEP040018Ool003Aoo`03001JEUYF00AJEP03
001JEUYF00AJEP03001JEUYF00MJEP@00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00009o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001JEUYF00EJ
EP03001JEP00009JEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4001<Ool0
03Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP04001JEUYF
FUH400000eYF000000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH9000;FUH00`00FUIJEP0:
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00D7oo000gOol01000FUIJEP001eYF00<005YFFUH00`0000=JEP00FUH0
1eYF00<005YFFUH015YF1@000UYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00=J
EP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP04
001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUH00002001BOol003Qoo`<000MJEP<000AJ
EP03001JEUYF00MJEP03001JEP0000H000EJEP03001JEP00009JEP04001JEUYF0005FUH00`00FUH0
0004000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH50003FUH00`00Oomoo`1?Ool003Yo
o`8000=JEP<000QJEP03001JEUYF00AJEP@0009JEP8000=JEP03001JEUYF009JEP<0009JEP04001J
EUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH40003FUH01@00FUIJEUYF00000UYF1`0015YF00D005YFFUIJEP00055oo`00
?7oo0`0000=JEP00FUH025YF00<005YFFUH010000eYF0`001EYF00<005YFFUH00UYF00<005YF0000
0UYF00@005YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF0000000800000eYF001JEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`1?Ool003Yoo`<000AJEP03001JEUYF00EJEP@000AJEP<00003FUH0
05YF00IJEP06001JEP00001JEP000eYF00D005YFFUH005YF008000QJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP03001oogoo00Aoo`8000EJEP07001JEUYFFUH005YF0000D7oo000gOol30007FUH00`00FUIJEP03
FUH40003FUH30004FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF00000UYF0P0000=JEP00FUH0
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF100017oo1@0015YF00L005YFFUIJEP00FUH0001@Ool003Eoo`800003FUH0
05YF00QJEP03001JEP0000T000QJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000D0009JEP03001JEUYF0080009JEP07001JEUYF
FUH005YF0000D7oo000cOol20004FUH00`00FUIJEP05FUH30003Ool60009FUH01P00FUH00000FUH0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00<005YFFUH00`0015YF00<005YF0000D7oo000aOol20006FUH00`00FUIJEP03FUH20005Ool60000
0eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01@00FUH00000Ool00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00H005YFFUH005YF0005FUH01000FUIJEUYF0P0015YF0P00DGoo000_Ool30008
FUH00`00FUH000020003Ool40002FUH30002FUH00`00FUIJEP03FUH@0003Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<0
05YF0000DGoo000]Ool20003FUH00`00FUIJEP04FUH30002Ool40002FUH00`00FUIJEP07FUH00`00
FUH00002000DOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH0
1000FUIJEUYF1`0000IJEP00000005YF001AOol002aoo`8000AJEP03001JEUYF009JEP800003Ool0
0000008000IJEP03001JEUYF00IJEP<001Moo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP800003FUH0000000D000=JEP04001JEUYF0003FUH00`00FUH0001AOol002]oo`03001JEP00
00EJEP03001JEP0000@00003FUH005YF00QJEP03001JEUYF009JEP<001]oo`80009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP800003FUH005YF00AJEP8000AJEP03001JEP00055oo`00:goo
00@005YFFUH000=JEP@000IJEP03001JEUYF00IJEP03001JEP000080021oo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH2000015YF001JEUYF0P000eYF00<005YFFUH00eYF0P0015YF0P00DWoo000[Ool01@00FUIJEP00
FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`009Goo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP<0
00IJEP03001JEUYF00800003FUH005YF00=JEP80059oo`00;7oo00@005YF000000EJEP03001JEUYF
00EJEP03001JEUYF00@002Yoo`<000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00AJEP@000=JEP800003FUH005YF00IJEP<000=JEP07001JEUYF
FUH005YF0000DWoo000/Ool200000eYF001JEP04FUH00`00FUIJEP04FUH4000aOol300000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP050003FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000/Ool20002FUH00`00FUIJ
EP03FUH00`00FUH00003000hOol40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH=0007FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P00E7oo000]Ool200000eYF001JEP02
FUH40010Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF20000goo1`002EYF
00H005YF000005YF0005FUH01000FUH00000EWoo000_Ool5001:OolO0003FUH20002Ool400000eYF
0000000300000eYF001JEP06FUH30002FUH01000FUIJEUYF1@00F7oo002?Ool20002FUH00`00FUIJ
EP05FUH00`00FUH000020002Ool200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH200000goo
00000006001MOol008ioo`03001JEUYF00=JEP03001JEUYF00=JEP<0009oo`<000AJEP03001JEUYF
00MJEP03001JEP00008006Qoo`00SGoo0P001EYF00<005YF000020001eYF00<005YFFUH01UYF0`00
Jgoo002<Ool01000FUIJEP0015YF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00KWoo002<
Ool01000FUIJEP000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEP000080075oo`00SGoo
00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH01EYF0`00M7oo002=Ool00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP04001gOol008ioo`04FUH005YF0005FUH00`00FUIJEP04
FUH4001kOol008ioo`05001JEUYFFUH00004FUH00`00FUIJEP04001oOol008ioo``008=oo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58847 .75275 m .59618 .69857 L .56532 .69232 L p .707 .577 .707 r
F P
0 g
s
.59618 .69857 m .58847 .75275 L .62003 .75589 L p .707 .577 .707 r
F P
0 g
s
.62003 .75589 m .62774 .70172 L .59618 .69857 L p .707 .577 .707 r
F P
0 g
s
.62774 .70172 m .62003 .75589 L .64919 .75563 L p .707 .577 .707 r
F P
0 g
s
.64919 .75563 m .65691 .70145 L .62774 .70172 L p .707 .577 .707 r
F P
0 g
s
.5576 .7465 m .56532 .69232 L .53817 .68358 L p .707 .577 .707 r
F P
0 g
s
.56532 .69232 m .5576 .7465 L .58847 .75275 L p .707 .577 .707 r
F P
0 g
s
.65691 .70145 m .64919 .75563 L .6731 .75197 L p .707 .577 .707 r
F P
0 g
s
.6731 .75197 m .68082 .6978 L .65691 .70145 L p .707 .577 .707 r
F P
0 g
s
.60119 .81453 m .60632 .77841 L .57546 .77217 L p .707 .577 .707 r
F P
0 g
s
.60632 .77841 m .60119 .81453 L .63276 .81766 L p .707 .577 .707 r
F P
0 g
s
.63276 .81766 m .63789 .78154 L .60632 .77841 L p .707 .577 .707 r
F P
0 g
s
.53045 .73776 m .53817 .68358 L .51739 .67321 L p .707 .577 .707 r
F P
0 g
s
.53817 .68358 m .53045 .73776 L .5576 .7465 L p .707 .577 .707 r
F P
0 g
s
.63789 .78154 m .63276 .81766 L .66192 .81738 L p .707 .577 .707 r
F P
0 g
s
.66192 .81738 m .66705 .78126 L .63789 .78154 L p .707 .577 .707 r
F P
0 g
s
.57033 .80829 m .57546 .77217 L .5483 .76344 L p .707 .577 .707 r
F P
0 g
s
.57546 .77217 m .57033 .80829 L .60119 .81453 L p .707 .577 .707 r
F P
0 g
s
.66705 .78126 m .66192 .81738 L .68583 .81373 L p .707 .577 .707 r
F P
0 g
s
.68583 .81373 m .69096 .77761 L .66705 .78126 L p .707 .577 .707 r
F P
0 g
s
.5483 .76344 m .54317 .79956 L .57033 .80829 L p .707 .577 .707 r
F P
0 g
s
.54317 .79956 m .5483 .76344 L .52752 .75308 L p .707 .577 .707 r
F P
0 g
s
.68082 .6978 m .6731 .75197 L .68942 .7453 L p .707 .577 .707 r
F P
0 g
s
.68942 .7453 m .69714 .69112 L .68082 .6978 L p .707 .577 .707 r
F P
0 g
s
.51739 .67321 m .50967 .72738 L .53045 .73776 L p .707 .577 .707 r
F P
0 g
s
.59223 .84515 m .58862 .82662 L .55805 .83094 L p .707 .577 .707 r
F P
0 g
s
.58862 .82662 m .59223 .84515 L .62352 .83876 L p .707 .577 .707 r
F P
0 g
s
.62352 .83876 m .6199 .82023 L .58862 .82662 L p .707 .577 .707 r
F P
0 g
s
.6199 .82023 m .62352 .83876 L .65247 .83093 L p .707 .577 .707 r
F P
0 g
s
.65247 .83093 m .64885 .8124 L .6199 .82023 L p .707 .577 .707 r
F P
0 g
s
.50967 .72738 m .51739 .67321 L .50501 .66221 L p .707 .577 .707 r
F P
0 g
s
.55805 .83094 m .56166 .84947 L .59223 .84515 L p .707 .577 .707 r
F P
0 g
s
.56166 .84947 m .55805 .83094 L .5312 .83276 L p .707 .577 .707 r
F P
0 g
s
.52752 .75308 m .52239 .7892 L .54317 .79956 L p .707 .577 .707 r
F P
0 g
s
.5312 .83276 m .53481 .8513 L .56166 .84947 L p .707 .577 .707 r
F P
0 g
s
.64885 .8124 m .65247 .83093 L .67624 .82242 L p .707 .577 .707 r
F P
0 g
s
.67624 .82242 m .67263 .80389 L .64885 .8124 L p .707 .577 .707 r
F P
0 g
s
.69096 .77761 m .68583 .81373 L .70216 .80705 L p .707 .577 .707 r
F P
0 g
s
.70216 .80705 m .70728 .77093 L .69096 .77761 L p .707 .577 .707 r
F P
0 g
s
.52239 .7892 m .52752 .75308 L .51514 .74209 L p .707 .577 .707 r
F P
0 g
s
.50501 .66221 m .4973 .71638 L .50967 .72738 L p .707 .577 .707 r
F P
0 g
s
.53481 .8513 m .5312 .83276 L .51069 .83192 L p .707 .577 .707 r
F P
0 g
s
.69714 .69112 m .68942 .7453 L .69656 .73624 L p .707 .577 .707 r
F P
0 g
s
.69656 .73624 m .70427 .68207 L .69714 .69112 L p .707 .577 .707 r
F P
0 g
s
.51069 .83192 m .5143 .85045 L .53481 .8513 L p .707 .577 .707 r
F P
0 g
s
.4973 .71638 m .50501 .66221 L .50226 .65167 L p .707 .577 .707 r
F P
0 g
s
.67263 .80389 m .67624 .82242 L .69251 .81407 L p .707 .577 .707 r
F P
0 g
s
.69251 .81407 m .6889 .79553 L .67263 .80389 L p .707 .577 .707 r
F P
0 g
s
.51514 .74209 m .51002 .77821 L .52239 .7892 L p .707 .577 .707 r
F P
0 g
s
.70728 .77093 m .70216 .80705 L .70929 .79799 L p .707 .577 .707 r
F P
0 g
s
.70929 .79799 m .71442 .76187 L .70728 .77093 L p .707 .577 .707 r
F P
0 g
s
.51002 .77821 m .51514 .74209 L .51239 .73155 L p .707 .577 .707 r
F P
0 g
s
.50226 .65167 m .49454 .70584 L .4973 .71638 L p .707 .577 .707 r
F P
0 g
s
.5143 .85045 m .51069 .83192 L .49853 .82849 L p .707 .577 .707 r
F P
0 g
s
.49853 .82849 m .50215 .84702 L .5143 .85045 L p .707 .577 .707 r
F P
0 g
s
.70427 .68207 m .69656 .73624 L .6938 .7257 L p .707 .577 .707 r
F P
0 g
s
.6938 .7257 m .70152 .67153 L .70427 .68207 L p .707 .577 .707 r
F P
0 g
s
.6889 .79553 m .69251 .81407 L .69969 .80669 L p .707 .577 .707 r
F P
0 g
s
.69969 .80669 m .69608 .78815 L .6889 .79553 L p .707 .577 .707 r
F P
0 g
s
.49454 .70584 m .50226 .65167 L .50939 .64262 L p .707 .577 .707 r
F P
0 g
s
.51239 .73155 m .50726 .76767 L .51002 .77821 L p .707 .577 .707 r
F P
0 g
s
.49294 .82177 m .48927 .31951 L .44527 .31715 L p .707 .577 .707 r
F P
0 g
s
.50726 .76767 m .51239 .73155 L .51952 .7225 L p .707 .577 .707 r
F P
0 g
s
.50939 .64262 m .50167 .69679 L .49454 .70584 L p .707 .577 .707 r
F P
0 g
s
.50167 .69679 m .50939 .64262 L .52571 .63594 L p .707 .577 .707 r
F P
0 g
s
.51952 .7225 m .51439 .75862 L .50726 .76767 L p .707 .577 .707 r
F P
0 g
s
.51439 .75862 m .51952 .7225 L .53584 .71582 L p .707 .577 .707 r
F P
0 g
s
.52571 .63594 m .51799 .69011 L .50167 .69679 L p .707 .577 .707 r
F P
0 g
s
.50215 .84702 m .49853 .82849 L .49591 .82281 L p .707 .577 .707 r
F P
0 g
s
.49591 .82281 m .49953 .84134 L .50215 .84702 L p .707 .577 .707 r
F P
0 g
s
.49953 .84134 m .49591 .82281 L .50309 .81543 L p .707 .577 .707 r
F P
0 g
s
.50309 .81543 m .50671 .83396 L .49953 .84134 L p .707 .577 .707 r
F P
0 g
s
.51799 .69011 m .52571 .63594 L .54962 .63229 L p .707 .577 .707 r
F P
0 g
s
.53584 .71582 m .53071 .75194 L .51439 .75862 L p .707 .577 .707 r
F P
0 g
s
.53071 .75194 m .53584 .71582 L .55975 .71216 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .5419 .68646 L .51799 .69011 L p .707 .577 .707 r
F P
0 g
s
.50671 .83396 m .50309 .81543 L .51937 .80707 L p .707 .577 .707 r
F P
0 g
s
.51937 .80707 m .52298 .82561 L .50671 .83396 L p .707 .577 .707 r
F P
0 g
s
.55975 .71216 m .55462 .74829 L .53071 .75194 L p .707 .577 .707 r
F P
0 g
s
.52298 .82561 m .51937 .80707 L .54314 .79857 L p .707 .577 .707 r
F P
0 g
s
.54314 .79857 m .54675 .8171 L .52298 .82561 L p .707 .577 .707 r
F P
0 g
s
.48927 .31951 m .49294 .82177 L .53788 .82038 L p .707 .577 .707 r
F P
0 g
s
.53788 .82038 m .53422 .31812 L .48927 .31951 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .57878 .63202 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.5419 .68646 m .54455 .66786 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.54455 .66786 m .54962 .63229 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.64121 .64141 m .63349 .69559 L .60263 .68934 L p .707 .577 .707 r
F P
0 g
s
.60263 .68934 m .61034 .63516 L .64121 .64141 L p .707 .577 .707 r
F P
0 g
s
.57107 .68619 m .57878 .63202 L .61034 .63516 L p .707 .577 .707 r
F P
0 g
s
.57878 .63202 m .57107 .68619 L .5419 .68646 L p .707 .577 .707 r
F P
0 g
s
.61034 .63516 m .60263 .68934 L .57107 .68619 L p .707 .577 .707 r
F P
0 g
s
.55462 .74829 m .55975 .71216 L .58892 .71189 L p .707 .577 .707 r
F P
0 g
s
.58892 .71189 m .58379 .74801 L .55462 .74829 L p .707 .577 .707 r
F P
0 g
s
.58379 .74801 m .58892 .71189 L .62048 .71502 L p .707 .577 .707 r
F P
0 g
s
.62048 .71502 m .61535 .75114 L .58379 .74801 L p .707 .577 .707 r
F P
0 g
s
.63394 .78003 m .63756 .79856 L .60699 .80288 L p .707 .577 .707 r
F P
0 g
s
.60699 .80288 m .60338 .78435 L .63394 .78003 L p .707 .577 .707 r
F P
0 g
s
.5757 .80927 m .57209 .79073 L .60338 .78435 L p .707 .577 .707 r
F P
0 g
s
.60338 .78435 m .60699 .80288 L .5757 .80927 L p .707 .577 .707 r
F P
0 g
s
.5757 .31311 m .57915 .78572 L p .61332 .80725 L .707 .577 .707 r
F P
0 g
s
.57915 .78572 m .57936 .81538 L .58729 .81348 L p .707 .577 .707 r
F P
0 g
s
.58729 .81348 m .61332 .80725 L p .57915 .78572 L .707 .577 .707 r
F P
0 g
s
.54675 .8171 m .54314 .79857 L .57209 .79073 L p .707 .577 .707 r
F P
0 g
s
.57209 .79073 m .5757 .80927 L .54675 .8171 L p .707 .577 .707 r
F P
0 g
s
.53422 .31812 m .53788 .82038 L .57936 .81538 L p .707 .577 .707 r
F P
0 g
s
.57936 .81538 m .5757 .31311 L .53422 .31812 L p .707 .577 .707 r
F P
0 g
s
.44893 .81942 m .44527 .31715 L .4065 .31127 L p .707 .577 .707 r
F P
0 g
s
.44527 .31715 m .44893 .81942 L .49294 .82177 L p .707 .577 .707 r
F P
0 g
s
.71442 .76187 m .70929 .79799 L .70653 .78746 L p .707 .577 .707 r
F P
0 g
s
.70653 .78746 m .71166 .75134 L .71442 .76187 L p .707 .577 .707 r
F P
0 g
s
.61332 .80725 m .60965 .30499 L .5757 .31311 L p .707 .577 .707 r
F P
0 g
s
.70152 .67153 m .6938 .7257 L .68143 .7147 L p .707 .577 .707 r
F P
0 g
s
.68143 .7147 m .68914 .66053 L .70152 .67153 L p .707 .577 .707 r
F P
0 g
s
.69608 .78815 m .69969 .80669 L .69707 .801 L p .707 .577 .707 r
F P
0 g
s
.69707 .801 m .69346 .78247 L .69608 .78815 L p .707 .577 .707 r
F P
0 g
s
.24546 .71597 m .25318 .66179 L .22231 .65555 L p .707 .577 .707 r
F P
0 g
s
.25318 .66179 m .24546 .71597 L .27702 .71911 L p .707 .577 .707 r
F P
0 g
s
.27702 .71911 m .28473 .66494 L .25318 .66179 L p .707 .577 .707 r
F P
0 g
s
.41017 .81354 m .4065 .31127 L .37678 .30246 L p .707 .577 .707 r
F P
0 g
s
.4065 .31127 m .41017 .81354 L .44893 .81942 L p .707 .577 .707 r
F P
0 g
s
.28473 .66494 m .27702 .71911 L .30618 .71885 L p .707 .577 .707 r
F P
0 g
s
.30618 .71885 m .3139 .66467 L .28473 .66494 L p .707 .577 .707 r
F P
0 g
s
.21459 .70972 m .22231 .65555 L .19516 .6468 L p .707 .577 .707 r
F P
0 g
s
.22231 .65555 m .21459 .70972 L .24546 .71597 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71166 .75134 m .70653 .78746 L .69415 .77647 L p .707 .577 .707 r
F P
0 g
s
.69415 .77647 m .69928 .74035 L .71166 .75134 L p .707 .577 .707 r
F P
0 g
s
.3139 .66467 m .30618 .71885 L .33009 .7152 L p .707 .577 .707 r
F P
0 g
s
.33009 .7152 m .33781 .66102 L .3139 .66467 L p .707 .577 .707 r
F P
0 g
s
.65135 .72126 m .64622 .75738 L .61535 .75114 L p .707 .577 .707 r
F P
0 g
s
.61535 .75114 m .62048 .71502 L .65135 .72126 L p .707 .577 .707 r
F P
0 g
s
.63756 .79856 m .63394 .78003 L .66079 .7782 L p .707 .577 .707 r
F P
0 g
s
.60965 .30499 m .61332 .80725 L .63643 .7968 L p .707 .577 .707 r
F P
0 g
s
.66836 .65015 m .66065 .70433 L .63349 .69559 L p .707 .577 .707 r
F P
0 g
s
.63349 .69559 m .64121 .64141 L .66836 .65015 L p .707 .577 .707 r
F P
0 g
s
.63643 .7968 m .63276 .29453 L .60965 .30499 L p .707 .577 .707 r
F P
0 g
s
.25819 .77781 m .26332 .74169 L .23245 .73546 L p .707 .577 .707 r
F P
0 g
s
.26332 .74169 m .25819 .77781 L .28975 .78095 L p .707 .577 .707 r
F P
0 g
s
.28975 .78095 m .29488 .74483 L .26332 .74169 L p .707 .577 .707 r
F P
0 g
s
.68914 .66053 m .68143 .7147 L .66065 .70433 L p .707 .577 .707 r
F P
0 g
s
.66065 .70433 m .66836 .65015 L .68914 .66053 L p .707 .577 .707 r
F P
0 g
s
.18744 .70098 m .19516 .6468 L .17438 .63643 L p .707 .577 .707 r
F P
0 g
s
.19516 .6468 m .18744 .70098 L .21459 .70972 L p .707 .577 .707 r
F P
0 g
s
.29488 .74483 m .28975 .78095 L .31891 .78067 L p .707 .577 .707 r
F P
0 g
s
.31891 .78067 m .32404 .74455 L .29488 .74483 L p .707 .577 .707 r
F P
0 g
s
.22732 .77158 m .23245 .73546 L .20529 .72673 L p .707 .577 .707 r
F P
0 g
s
.23245 .73546 m .22732 .77158 L .25819 .77781 L p .707 .577 .707 r
F P
0 g
s
.69346 .78247 m .69707 .801 L .68492 .79757 L p .707 .577 .707 r
F P
0 g
s
.68492 .79757 m .6813 .77904 L .69346 .78247 L p .707 .577 .707 r
F P
0 g
s
.38044 .80472 m .37678 .30246 L .359 .29156 L p .707 .577 .707 r
F P
0 g
s
.37678 .30246 m .38044 .80472 L .41017 .81354 L p .707 .577 .707 r
F P
0 g
s
.32404 .74455 m .31891 .78067 L .34283 .77702 L p .707 .577 .707 r
F P
0 g
s
.34283 .77702 m .34795 .7409 L .32404 .74455 L p .707 .577 .707 r
F P
0 g
s
.20529 .72673 m .20016 .76285 L .22732 .77158 L p .707 .577 .707 r
F P
0 g
s
.69928 .74035 m .69415 .77647 L .67337 .76611 L p .707 .577 .707 r
F P
0 g
s
.67337 .76611 m .6785 .72999 L .69928 .74035 L p .707 .577 .707 r
F P
0 g
s
.20016 .76285 m .20529 .72673 L .18451 .71637 L p .707 .577 .707 r
F P
0 g
s
.33781 .66102 m .33009 .7152 L .34642 .70852 L p .707 .577 .707 r
F P
0 g
s
.34642 .70852 m .35413 .65434 L .33781 .66102 L p .707 .577 .707 r
F P
0 g
s
.17438 .63643 m .16666 .6906 L .18744 .70098 L p .707 .577 .707 r
F P
0 g
s
.24922 .80789 m .24561 .78936 L .21504 .79368 L p .707 .577 .707 r
F P
0 g
s
.24561 .78936 m .24922 .80789 L .28051 .8015 L p .707 .577 .707 r
F P
0 g
s
.28051 .8015 m .27689 .78297 L .24561 .78936 L p .707 .577 .707 r
F P
0 g
s
.27689 .78297 m .28051 .8015 L .30946 .79367 L p .707 .577 .707 r
F P
0 g
s
.30946 .79367 m .30584 .77514 L .27689 .78297 L p .707 .577 .707 r
F P
0 g
s
.16666 .6906 m .17438 .63643 L .162 .62543 L p .707 .577 .707 r
F P
0 g
s
.21504 .79368 m .21865 .81221 L .24922 .80789 L p .707 .577 .707 r
F P
0 g
s
.21865 .81221 m .21504 .79368 L .18819 .79551 L p .707 .577 .707 r
F P
0 g
s
.18451 .71637 m .17938 .75249 L .20016 .76285 L p .707 .577 .707 r
F P
0 g
s
.18819 .79551 m .1918 .81404 L .21865 .81221 L p .707 .577 .707 r
F P
0 g
s
.30584 .77514 m .30946 .79367 L .33323 .78516 L p .707 .577 .707 r
F P
0 g
s
.33323 .78516 m .32962 .76663 L .30584 .77514 L p .707 .577 .707 r
F P
0 g
s
.63276 .29453 m .63643 .7968 L .64643 .78504 L p .707 .577 .707 r
F P
0 g
s
.6785 .72999 m .67337 .76611 L .64622 .75738 L p .707 .577 .707 r
F P
0 g
s
.64622 .75738 m .65135 .72126 L .6785 .72999 L p .707 .577 .707 r
F P
0 g
s
.64643 .78504 m .64276 .28278 L .63276 .29453 L p .707 .577 .707 r
F P
0 g
s
.6813 .77904 m .68492 .79757 L .66441 .79673 L p .707 .577 .707 r
F P
0 g
s
.66441 .79673 m .66079 .7782 L .6813 .77904 L p .707 .577 .707 r
F P
0 g
s
.34795 .7409 m .34283 .77702 L .35915 .77034 L p .707 .577 .707 r
F P
0 g
s
.35915 .77034 m .36428 .73422 L .34795 .7409 L p .707 .577 .707 r
F P
0 g
s
.17938 .75249 m .18451 .71637 L .17214 .70538 L p .707 .577 .707 r
F P
0 g
s
.162 .62543 m .15429 .67961 L .16666 .6906 L p .707 .577 .707 r
F P
0 g
s
.1918 .81404 m .18819 .79551 L .16768 .79466 L p .707 .577 .707 r
F P
0 g
s
.35413 .65434 m .34642 .70852 L .35355 .69946 L p .707 .577 .707 r
F P
0 g
s
.35355 .69946 m .36126 .64529 L .35413 .65434 L p .707 .577 .707 r
F P
0 g
s
.16768 .79466 m .17129 .8132 L .1918 .81404 L p .707 .577 .707 r
F P
0 g
s
.15429 .67961 m .162 .62543 L .15925 .61489 L p .707 .577 .707 r
F P
0 g
s
.32962 .76663 m .33323 .78516 L .3495 .77681 L p .707 .577 .707 r
F P
0 g
s
.3495 .77681 m .34589 .75828 L .32962 .76663 L p .707 .577 .707 r
F P
0 g
s
.17214 .70538 m .16701 .7415 L .17938 .75249 L p .707 .577 .707 r
F P
0 g
s
.36428 .73422 m .35915 .77034 L .36628 .76128 L p .707 .577 .707 r
F P
0 g
s
.36126 .64529 m .35355 .69946 L .35079 .68892 L p .707 .577 .707 r
F P
0 g
s
.35079 .68892 m .35851 .63475 L .36126 .64529 L p .707 .577 .707 r
F P
0 g
s
.36628 .76128 m .37141 .72516 L .36428 .73422 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .35115 .73976 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36865 .71463 m .36618 .73199 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36618 .73199 m .36352 .75075 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.359 .29156 m .35491 .27965 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .35627 .70364 L .36546 .71179 L p .707 .577 .707 r
F P
0 g
s
.36546 .71179 m .36865 .71463 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .36546 .71179 L .36571 .71885 L .707 .577 .707 r
F
.35858 .78192 m .36267 .79383 L p .35853 .51967 L F P
0 g
s
.35491 .27965 m .35619 .45467 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35851 .63475 m .35079 .68892 L .34296 .68197 L p .707 .577 .707 r
F P
0 g
s
.34296 .68197 m .33842 .67793 L p .34345 .6671 L .707 .577 .707 r
F P
0 g
s
.34345 .6671 m .35851 .63475 L .34296 .68197 L .707 .577 .707 r
F
.33842 .67793 m .34613 .62375 L .35851 .63475 L p F P
0 g
s
.35619 .45467 m .35858 .78192 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36267 .79383 m .36121 .59391 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36121 .59391 m .359 .29156 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.37141 .72516 m .36628 .76128 L .36352 .75075 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .36865 .71463 L .37141 .72516 L p .707 .577 .707 r
F P
0 g
s
.359 .29156 m .36267 .79383 L .38044 .80472 L p .707 .577 .707 r
F P
0 g
s
.35858 .78192 m .35515 .31159 L p .36491 .26789 L .707 .577 .707 r
F P
0 g
s
.35515 .31159 m .35491 .27965 L .35625 .27808 L p .707 .577 .707 r
F P
0 g
s
.35625 .27808 m .36491 .26789 L p .35515 .31159 L .707 .577 .707 r
F P
0 g
s
.66079 .7782 m .66441 .79673 L .63756 .79856 L p .707 .577 .707 r
F P
0 g
s
.16701 .7415 m .17214 .70538 L .16938 .69484 L p .707 .577 .707 r
F P
0 g
s
.15925 .61489 m .15153 .66907 L .15429 .67961 L p .707 .577 .707 r
F P
0 g
s
.17129 .8132 m .16768 .79466 L .15552 .79123 L p .707 .577 .707 r
F P
0 g
s
.15552 .79123 m .15914 .80977 L .17129 .8132 L p .707 .577 .707 r
F P
0 g
s
.34589 .75828 m .3495 .77681 L .35668 .76943 L p .707 .577 .707 r
F P
0 g
s
.35668 .76943 m .35307 .7509 L .34589 .75828 L p .707 .577 .707 r
F P
0 g
s
.64276 .28278 m .64643 .78504 L .64329 .77592 L p .707 .577 .707 r
F P
0 g
s
.64236 .75002 m .64276 .28278 L .64329 .77592 L .707 .577 .707 r
F
.63867 .27087 m .64276 .28278 L p .64247 .62315 L F P
0 g
s
.64234 .77313 m .64121 .61905 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.64121 .61905 m .63867 .27087 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.63867 .27087 m .64234 .77313 L .62456 .76224 L p .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63946 .55963 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.6345 .62435 m .63715 .60574 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .64222 .57017 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63715 .60574 L p .64687 .63534 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .6345 .62435 L .63793 .6274 L p .707 .577 .707 r
F P
0 g
s
.63793 .6274 m .64687 .63534 L p .63715 .60574 L .707 .577 .707 r
F P
0 g
s
.64329 .77592 m .64234 .77313 L p .64236 .75002 L .707 .577 .707 r
F P
0 g
s
.15153 .66907 m .15925 .61489 L .16638 .60584 L p .707 .577 .707 r
F P
0 g
s
.16938 .69484 m .16425 .73096 L .16701 .7415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16425 .73096 m .16938 .69484 L .17651 .68579 L p .707 .577 .707 r
F P
0 g
s
.16638 .60584 m .15866 .66001 L .15153 .66907 L p .707 .577 .707 r
F P
0 g
s
.15914 .80977 m .15552 .79123 L .1529 .78555 L p .707 .577 .707 r
F P
0 g
s
.1529 .78555 m .15652 .80408 L .15914 .80977 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35307 .7509 m .35668 .76943 L .35406 .76375 L p .707 .577 .707 r
F P
0 g
s
.35406 .76375 m .35045 .74522 L .35307 .7509 L p .707 .577 .707 r
F P
0 g
s
.15866 .66001 m .16638 .60584 L .1827 .59916 L p .707 .577 .707 r
F P
0 g
s
.17651 .68579 m .17138 .72191 L .16425 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62456 .76224 m .6209 .25997 L .63867 .27087 L p .707 .577 .707 r
F P
0 g
s
.17138 .72191 m .17651 .68579 L .19283 .67911 L p .707 .577 .707 r
F P
0 g
s
.1827 .59916 m .17498 .65333 L .15866 .66001 L p .707 .577 .707 r
F P
0 g
s
.15652 .80408 m .1529 .78555 L .16008 .77817 L p .707 .577 .707 r
F P
0 g
s
.34613 .62375 m .33842 .67793 L .31764 .66755 L p .707 .577 .707 r
F P
0 g
s
.31764 .66755 m .32535 .61338 L .34613 .62375 L p .707 .577 .707 r
F P
0 g
s
.16008 .77817 m .1637 .7967 L .15652 .80408 L p .707 .577 .707 r
F P
0 g
s
.17498 .65333 m .1827 .59916 L .20661 .59551 L p .707 .577 .707 r
F P
0 g
s
.35045 .74522 m .35406 .76375 L .34191 .76032 L p .707 .577 .707 r
F P
0 g
s
.34191 .76032 m .33829 .74178 L .35045 .74522 L p .707 .577 .707 r
F P
0 g
s
.36858 .77016 m .36491 .26789 L .38802 .25744 L p .707 .577 .707 r
F P
0 g
s
.36491 .26789 m .36858 .77016 L .35858 .78192 L p .707 .577 .707 r
F P
0 g
s
.19283 .67911 m .1877 .71523 L .17138 .72191 L p .707 .577 .707 r
F P
0 g
s
.35627 .70364 m .35115 .73976 L .33036 .7294 L p .707 .577 .707 r
F P
0 g
s
.33036 .7294 m .33549 .69328 L .35627 .70364 L p .707 .577 .707 r
F P
0 g
s
.1877 .71523 m .19283 .67911 L .21674 .67545 L p .707 .577 .707 r
F P
0 g
s
.32535 .61338 m .31764 .66755 L .29048 .65881 L p .707 .577 .707 r
F P
0 g
s
.29048 .65881 m .2982 .60463 L .32535 .61338 L p .707 .577 .707 r
F P
0 g
s
.20661 .59551 m .19889 .64968 L .17498 .65333 L p .707 .577 .707 r
F P
0 g
s
.19889 .64968 m .20661 .59551 L .23577 .59524 L p .707 .577 .707 r
F P
0 g
s
.1637 .7967 m .16008 .77817 L .17636 .76982 L p .707 .577 .707 r
F P
0 g
s
.6209 .25997 m .62456 .76224 L .59484 .75342 L p .707 .577 .707 r
F P
0 g
s
.59484 .75342 m .59117 .25115 L .6209 .25997 L p .707 .577 .707 r
F P
0 g
s
.17636 .76982 m .17997 .78835 L .1637 .7967 L p .707 .577 .707 r
F P
0 g
s
.21674 .67545 m .21162 .71157 L .1877 .71523 L p .707 .577 .707 r
F P
0 g
s
.33829 .74178 m .34191 .76032 L .3214 .75947 L p .707 .577 .707 r
F P
0 g
s
.3214 .75947 m .31778 .74094 L .33829 .74178 L p .707 .577 .707 r
F P
0 g
s
.2982 .60463 m .29048 .65881 L .25962 .65256 L p .707 .577 .707 r
F P
0 g
s
.25962 .65256 m .26733 .59839 L .2982 .60463 L p .707 .577 .707 r
F P
0 g
s
.22806 .64942 m .23577 .59524 L .26733 .59839 L p .707 .577 .707 r
F P
0 g
s
.23577 .59524 m .22806 .64942 L .19889 .64968 L p .707 .577 .707 r
F P
0 g
s
.33549 .69328 m .33036 .7294 L .30321 .72067 L p .707 .577 .707 r
F P
0 g
s
.30321 .72067 m .30834 .68455 L .33549 .69328 L p .707 .577 .707 r
F P
0 g
s
.26733 .59839 m .25962 .65256 L .22806 .64942 L p .707 .577 .707 r
F P
0 g
s
.21162 .71157 m .21674 .67545 L .24591 .67518 L p .707 .577 .707 r
F P
0 g
s
.38802 .25744 m .39169 .75971 L .36858 .77016 L p .707 .577 .707 r
F P
0 g
s
.39169 .75971 m .38802 .25744 L .42198 .24931 L p .707 .577 .707 r
F P
0 g
s
.72567 .66071 m .73339 .60653 L .70252 .60028 L p .707 .577 .707 r
F P
0 g
s
.73339 .60653 m .72567 .66071 L .75723 .66385 L p .707 .577 .707 r
F P
0 g
s
.75723 .66385 m .76495 .60968 L .73339 .60653 L p .707 .577 .707 r
F P
0 g
s
.76495 .60968 m .75723 .66385 L .7864 .66359 L p .707 .577 .707 r
F P
0 g
s
.7864 .66359 m .79411 .60941 L .76495 .60968 L p .707 .577 .707 r
F P
0 g
s
.69481 .65446 m .70252 .60028 L .67537 .59154 L p .707 .577 .707 r
F P
0 g
s
.70252 .60028 m .69481 .65446 L .72567 .66071 L p .707 .577 .707 r
F P
0 g
s
.17997 .78835 m .17636 .76982 L .20013 .76131 L p .707 .577 .707 r
F P
0 g
s
.30834 .68455 m .30321 .72067 L .27234 .71443 L p .707 .577 .707 r
F P
0 g
s
.27234 .71443 m .27747 .67831 L .30834 .68455 L p .707 .577 .707 r
F P
0 g
s
.24591 .67518 m .24078 .7113 L .21162 .71157 L p .707 .577 .707 r
F P
0 g
s
.24078 .7113 m .24591 .67518 L .27747 .67831 L p .707 .577 .707 r
F P
0 g
s
.20013 .76131 m .20374 .77984 L .17997 .78835 L p .707 .577 .707 r
F P
0 g
s
.27747 .67831 m .27234 .71443 L .24078 .7113 L p .707 .577 .707 r
F P
0 g
s
.31778 .74094 m .3214 .75947 L .29455 .7613 L p .707 .577 .707 r
F P
0 g
s
.29455 .7613 m .29093 .74277 L .31778 .74094 L p .707 .577 .707 r
F P
0 g
s
.59117 .25115 m .59484 .75342 L .55607 .74754 L p .707 .577 .707 r
F P
0 g
s
.55607 .74754 m .55241 .24527 L .59117 .25115 L p .707 .577 .707 r
F P
0 g
s
.79411 .60941 m .7864 .66359 L .81031 .65994 L p .707 .577 .707 r
F P
0 g
s
.81031 .65994 m .81802 .60576 L .79411 .60941 L p .707 .577 .707 r
F P
0 g
s
.7384 .72249 m .74353 .68637 L .71266 .68013 L p .707 .577 .707 r
F P
0 g
s
.74353 .68637 m .7384 .72249 L .76996 .72562 L p .707 .577 .707 r
F P
0 g
s
.76996 .72562 m .77509 .6895 L .74353 .68637 L p .707 .577 .707 r
F P
0 g
s
.66765 .64572 m .67537 .59154 L .65459 .58117 L p .707 .577 .707 r
F P
0 g
s
.67537 .59154 m .66765 .64572 L .69481 .65446 L p .707 .577 .707 r
F P
0 g
s
.77509 .6895 m .76996 .72562 L .79913 .72535 L p .707 .577 .707 r
F P
0 g
s
.79913 .72535 m .80425 .68923 L .77509 .6895 L p .707 .577 .707 r
F P
0 g
s
.70753 .71625 m .71266 .68013 L .68551 .6714 L p .707 .577 .707 r
F P
0 g
s
.71266 .68013 m .70753 .71625 L .7384 .72249 L p .707 .577 .707 r
F P
0 g
s
.42564 .75158 m .42198 .24931 L .46346 .24431 L p .707 .577 .707 r
F P
0 g
s
.42198 .24931 m .42564 .75158 L .39169 .75971 L p .707 .577 .707 r
F P
0 g
s
.20374 .77984 m .20013 .76131 L .22908 .75348 L p .707 .577 .707 r
F P
0 g
s
.22908 .75348 m .23269 .77201 L .20374 .77984 L p .707 .577 .707 r
F P
0 g
s
.29093 .74277 m .29455 .7613 L .26398 .76562 L p .707 .577 .707 r
F P
0 g
s
.26398 .76562 m .26037 .74709 L .29093 .74277 L p .707 .577 .707 r
F P
0 g
s
.80425 .68923 m .79913 .72535 L .82304 .72169 L p .707 .577 .707 r
F P
0 g
s
.82304 .72169 m .82817 .68557 L .80425 .68923 L p .707 .577 .707 r
F P
0 g
s
.68551 .6714 m .68038 .70752 L .70753 .71625 L p .707 .577 .707 r
F P
0 g
s
.55241 .24527 m .55607 .74754 L .51207 .74519 L p .707 .577 .707 r
F P
0 g
s
.51207 .74519 m .5084 .24292 L .55241 .24527 L p .707 .577 .707 r
F P
0 g
s
.68038 .70752 m .68551 .6714 L .66472 .66104 L p .707 .577 .707 r
F P
0 g
s
.81802 .60576 m .81031 .65994 L .82663 .65326 L p .707 .577 .707 r
F P
0 g
s
.82663 .65326 m .83434 .59908 L .81802 .60576 L p .707 .577 .707 r
F P
0 g
s
.65459 .58117 m .64687 .63534 L .66765 .64572 L p .707 .577 .707 r
F P
0 g
s
.23269 .77201 m .22908 .75348 L .26037 .74709 L p .707 .577 .707 r
F P
0 g
s
.72943 .75311 m .72582 .73458 L .69525 .7389 L p .707 .577 .707 r
F P
0 g
s
.72582 .73458 m .72943 .75311 L .76072 .74672 L p .707 .577 .707 r
F P
0 g
s
.76072 .74672 m .75711 .72819 L .72582 .73458 L p .707 .577 .707 r
F P
0 g
s
.26037 .74709 m .26398 .76562 L .23269 .77201 L p .707 .577 .707 r
F P
0 g
s
.75711 .72819 m .76072 .74672 L .78967 .73889 L p .707 .577 .707 r
F P
0 g
s
.78967 .73889 m .78606 .72036 L .75711 .72819 L p .707 .577 .707 r
F P
0 g
s
.64687 .63534 m .65459 .58117 L .64222 .57017 L p .707 .577 .707 r
F P
0 g
s
.69525 .7389 m .69887 .75743 L .72943 .75311 L p .707 .577 .707 r
F P
0 g
s
.46712 .74658 m .46346 .24431 L .5084 .24292 L p .707 .577 .707 r
F P
0 g
s
.46346 .24431 m .46712 .74658 L .42564 .75158 L p .707 .577 .707 r
F P
0 g
s
.69887 .75743 m .69525 .7389 L .6684 .74073 L p .707 .577 .707 r
F P
0 g
s
.5084 .24292 m .51207 .74519 L .46712 .74658 L p .707 .577 .707 r
F P
0 g
s
.66472 .66104 m .6596 .69716 L .68038 .70752 L p .707 .577 .707 r
F P
0 g
s
.6684 .74073 m .67202 .75926 L .69887 .75743 L p .707 .577 .707 r
F P
0 g
s
.78606 .72036 m .78967 .73889 L .81344 .73038 L p .707 .577 .707 r
F P
0 g
s
.81344 .73038 m .80983 .71185 L .78606 .72036 L p .707 .577 .707 r
F P
0 g
s
.82817 .68557 m .82304 .72169 L .83936 .71501 L p .707 .577 .707 r
F P
0 g
s
.83936 .71501 m .84449 .67889 L .82817 .68557 L p .707 .577 .707 r
F P
0 g
s
.6596 .69716 m .66472 .66104 L .65235 .65005 L p .707 .577 .707 r
F P
0 g
s
.67202 .75926 m .6684 .74073 L .64789 .73988 L p .707 .577 .707 r
F P
0 g
s
.83434 .59908 m .82663 .65326 L .83376 .6442 L p .707 .577 .707 r
F P
0 g
s
.83376 .6442 m .84148 .59003 L .83434 .59908 L p .707 .577 .707 r
F P
0 g
s
.64789 .73988 m .65151 .75841 L .67202 .75926 L p .707 .577 .707 r
F P
0 g
s
.80983 .71185 m .81344 .73038 L .82972 .72203 L p .707 .577 .707 r
F P
0 g
s
.82972 .72203 m .8261 .7035 L .80983 .71185 L p .707 .577 .707 r
F P
0 g
s
.65235 .65005 m .64722 .68617 L .6596 .69716 L p .707 .577 .707 r
F P
0 g
s
.84449 .67889 m .83936 .71501 L .84649 .70596 L p .707 .577 .707 r
F P
0 g
s
.84649 .70596 m .85162 .66984 L .84449 .67889 L p .707 .577 .707 r
F P
0 g
s
.64722 .68617 m .65235 .65005 L .64959 .63952 L p .707 .577 .707 r
F P
0 g
s
.63946 .55963 m .63174 .6138 L .6345 .62435 L p .707 .577 .707 r
F P
0 g
s
.65151 .75841 m .64789 .73988 L .63574 .73645 L p .707 .577 .707 r
F P
0 g
s
.63574 .73645 m .63935 .75498 L .65151 .75841 L p .707 .577 .707 r
F P
0 g
s
.84148 .59003 m .83376 .6442 L .831 .63366 L p .707 .577 .707 r
F P
0 g
s
.831 .63366 m .83872 .57949 L .84148 .59003 L p .707 .577 .707 r
F P
0 g
s
.8261 .7035 m .82972 .72203 L .8369 .71465 L p .707 .577 .707 r
F P
0 g
s
.8369 .71465 m .83328 .69612 L .8261 .7035 L p .707 .577 .707 r
F P
0 g
s
.63174 .6138 m .63946 .55963 L .64659 .55058 L p .707 .577 .707 r
F P
0 g
s
.64959 .63952 m .64446 .67564 L .64722 .68617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.85162 .66984 m .84649 .70596 L .84373 .69542 L p .707 .577 .707 r
F P
0 g
s
.84373 .69542 m .84886 .6593 L .85162 .66984 L p .707 .577 .707 r
F P
0 g
s
.64446 .67564 m .64959 .63952 L .65672 .63046 L p .707 .577 .707 r
F P
0 g
s
.64659 .55058 m .63888 .60475 L .63174 .6138 L p .707 .577 .707 r
F P
0 g
s
.63935 .75498 m .63574 .73645 L .63312 .73077 L p .707 .577 .707 r
F P
0 g
s
.63312 .73077 m .63673 .7493 L .63935 .75498 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83872 .57949 m .831 .63366 L .81863 .62267 L p .707 .577 .707 r
F P
0 g
s
.81863 .62267 m .82635 .56849 L .83872 .57949 L p .707 .577 .707 r
F P
0 g
s
.83328 .69612 m .8369 .71465 L .83428 .70897 L p .707 .577 .707 r
F P
0 g
s
.83428 .70897 m .83067 .69043 L .83328 .69612 L p .707 .577 .707 r
F P
0 g
s
.63888 .60475 m .64659 .55058 L .66291 .5439 L p .707 .577 .707 r
F P
0 g
s
.65672 .63046 m .65159 .66658 L .64446 .67564 L p .707 .577 .707 r
F P
0 g
s
.38266 .62393 m .39038 .56975 L .35951 .56351 L p .707 .577 .707 r
F P
0 g
s
.39038 .56975 m .38266 .62393 L .41422 .62707 L p .707 .577 .707 r
F P
0 g
s
.41422 .62707 m .42194 .5729 L .39038 .56975 L p .707 .577 .707 r
F P
0 g
s
.42194 .5729 m .41422 .62707 L .44339 .62681 L p .707 .577 .707 r
F P
0 g
s
.44339 .62681 m .4511 .57263 L .42194 .5729 L p .707 .577 .707 r
F P
0 g
s
.3518 .61768 m .35951 .56351 L .33236 .55477 L p .707 .577 .707 r
F P
0 g
s
.35951 .56351 m .3518 .61768 L .38266 .62393 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84886 .6593 m .84373 .69542 L .83136 .68443 L p .707 .577 .707 r
F P
0 g
s
.83136 .68443 m .83649 .64831 L .84886 .6593 L p .707 .577 .707 r
F P
0 g
s
.65159 .66658 m .65672 .63046 L .67304 .62378 L p .707 .577 .707 r
F P
0 g
s
.66291 .5439 m .6552 .59807 L .63888 .60475 L p .707 .577 .707 r
F P
0 g
s
.4511 .57263 m .44339 .62681 L .4673 .62316 L p .707 .577 .707 r
F P
0 g
s
.4673 .62316 m .47501 .56898 L .4511 .57263 L p .707 .577 .707 r
F P
0 g
s
.63673 .7493 m .63312 .73077 L .6403 .72339 L p .707 .577 .707 r
F P
0 g
s
.39539 .68578 m .40052 .64966 L .36965 .64342 L p .707 .577 .707 r
F P
0 g
s
.40052 .64966 m .39539 .68578 L .42695 .68891 L p .707 .577 .707 r
F P
0 g
s
.42695 .68891 m .43208 .65279 L .40052 .64966 L p .707 .577 .707 r
F P
0 g
s
.82635 .56849 m .81863 .62267 L .79785 .61229 L p .707 .577 .707 r
F P
0 g
s
.79785 .61229 m .80557 .55811 L .82635 .56849 L p .707 .577 .707 r
F P
0 g
s
.32464 .60894 m .33236 .55477 L .31158 .54439 L p .707 .577 .707 r
F P
0 g
s
.33236 .55477 m .32464 .60894 L .3518 .61768 L p .707 .577 .707 r
F P
0 g
s
.6403 .72339 m .64391 .74192 L .63673 .7493 L p .707 .577 .707 r
F P
0 g
s
.43208 .65279 m .42695 .68891 L .45612 .68864 L p .707 .577 .707 r
F P
0 g
s
.45612 .68864 m .46124 .65251 L .43208 .65279 L p .707 .577 .707 r
F P
0 g
s
.36452 .67954 m .36965 .64342 L .3425 .63469 L p .707 .577 .707 r
F P
0 g
s
.36965 .64342 m .36452 .67954 L .39539 .68578 L p .707 .577 .707 r
F P
0 g
s
.6552 .59807 m .66291 .5439 L .68682 .54025 L p .707 .577 .707 r
F P
0 g
s
.83067 .69043 m .83428 .70897 L .82212 .70553 L p .707 .577 .707 r
F P
0 g
s
.82212 .70553 m .81851 .687 L .83067 .69043 L p .707 .577 .707 r
F P
0 g
s
.67304 .62378 m .66792 .6599 L .65159 .66658 L p .707 .577 .707 r
F P
0 g
s
.46124 .65251 m .45612 .68864 L .48003 .68498 L p .707 .577 .707 r
F P
0 g
s
.48003 .68498 m .48516 .64886 L .46124 .65251 L p .707 .577 .707 r
F P
0 g
s
.3425 .63469 m .33737 .67081 L .36452 .67954 L p .707 .577 .707 r
F P
0 g
s
.83649 .64831 m .83136 .68443 L .81058 .67407 L p .707 .577 .707 r
F P
0 g
s
.81058 .67407 m .81571 .63795 L .83649 .64831 L p .707 .577 .707 r
F P
0 g
s
.33737 .67081 m .3425 .63469 L .32171 .62433 L p .707 .577 .707 r
F P
0 g
s
.47501 .56898 m .4673 .62316 L .48362 .61648 L p .707 .577 .707 r
F P
0 g
s
.48362 .61648 m .49133 .5623 L .47501 .56898 L p .707 .577 .707 r
F P
0 g
s
.31158 .54439 m .30386 .59856 L .32464 .60894 L p .707 .577 .707 r
F P
0 g
s
.38642 .71585 m .38281 .69732 L .35224 .70164 L p .707 .577 .707 r
F P
0 g
s
.38281 .69732 m .38642 .71585 L .41771 .70947 L p .707 .577 .707 r
F P
0 g
s
.41771 .70947 m .4141 .69093 L .38281 .69732 L p .707 .577 .707 r
F P
0 g
s
.4141 .69093 m .41771 .70947 L .44666 .70163 L p .707 .577 .707 r
F P
0 g
s
.44666 .70163 m .44305 .6831 L .4141 .69093 L p .707 .577 .707 r
F P
0 g
s
.66792 .6599 m .67304 .62378 L .69696 .62013 L p .707 .577 .707 r
F P
0 g
s
.80557 .55811 m .79785 .61229 L .7707 .60355 L p .707 .577 .707 r
F P
0 g
s
.7707 .60355 m .77841 .54937 L .80557 .55811 L p .707 .577 .707 r
F P
0 g
s
.68682 .54025 m .67911 .59442 L .6552 .59807 L p .707 .577 .707 r
F P
0 g
s
.30386 .59856 m .31158 .54439 L .29921 .53339 L p .707 .577 .707 r
F P
0 g
s
.35224 .70164 m .35586 .72017 L .38642 .71585 L p .707 .577 .707 r
F P
0 g
s
.67911 .59442 m .68682 .54025 L .71599 .53998 L p .707 .577 .707 r
F P
0 g
s
.35586 .72017 m .35224 .70164 L .32539 .70347 L p .707 .577 .707 r
F P
0 g
s
.64391 .74192 m .6403 .72339 L .65657 .71504 L p .707 .577 .707 r
F P
0 g
s
.32171 .62433 m .31658 .66045 L .33737 .67081 L p .707 .577 .707 r
F P
0 g
s
.32539 .70347 m .32901 .722 L .35586 .72017 L p .707 .577 .707 r
F P
0 g
s
.44305 .6831 m .44666 .70163 L .47043 .69312 L p .707 .577 .707 r
F P
0 g
s
.47043 .69312 m .46682 .67459 L .44305 .6831 L p .707 .577 .707 r
F P
0 g
s
.65657 .71504 m .66018 .73357 L .64391 .74192 L p .707 .577 .707 r
F P
0 g
s
.69696 .62013 m .69183 .65625 L .66792 .6599 L p .707 .577 .707 r
F P
0 g
s
.81851 .687 m .82212 .70553 L .80161 .70469 L p .707 .577 .707 r
F P
0 g
s
.80161 .70469 m .798 .68616 L .81851 .687 L p .707 .577 .707 r
F P
0 g
s
.48516 .64886 m .48003 .68498 L .49635 .6783 L p .707 .577 .707 r
F P
0 g
s
.49635 .6783 m .50148 .64218 L .48516 .64886 L p .707 .577 .707 r
F P
0 g
s
.77841 .54937 m .7707 .60355 L .73983 .5973 L p .707 .577 .707 r
F P
0 g
s
.73983 .5973 m .74755 .54313 L .77841 .54937 L p .707 .577 .707 r
F P
0 g
s
.70827 .59416 m .71599 .53998 L .74755 .54313 L p .707 .577 .707 r
F P
0 g
s
.71599 .53998 m .70827 .59416 L .67911 .59442 L p .707 .577 .707 r
F P
0 g
s
.81571 .63795 m .81058 .67407 L .78342 .66534 L p .707 .577 .707 r
F P
0 g
s
.78342 .66534 m .78855 .62922 L .81571 .63795 L p .707 .577 .707 r
F P
0 g
s
.31658 .66045 m .32171 .62433 L .30934 .61334 L p .707 .577 .707 r
F P
0 g
s
.29921 .53339 m .29149 .58757 L .30386 .59856 L p .707 .577 .707 r
F P
0 g
s
.74755 .54313 m .73983 .5973 L .70827 .59416 L p .707 .577 .707 r
F P
0 g
s
.69183 .65625 m .69696 .62013 L .72612 .61985 L p .707 .577 .707 r
F P
0 g
s
.32901 .722 m .32539 .70347 L .30488 .70263 L p .707 .577 .707 r
F P
0 g
s
.49133 .5623 m .48362 .61648 L .49075 .60743 L p .707 .577 .707 r
F P
0 g
s
.49075 .60743 m .49847 .55325 L .49133 .5623 L p .707 .577 .707 r
F P
0 g
s
.30488 .70263 m .3085 .72116 L .32901 .722 L p .707 .577 .707 r
F P
0 g
s
.29149 .58757 m .29921 .53339 L .29645 .52285 L p .707 .577 .707 r
F P
0 g
s
.46682 .67459 m .47043 .69312 L .48671 .68477 L p .707 .577 .707 r
F P
0 g
s
.48671 .68477 m .48309 .66624 L .46682 .67459 L p .707 .577 .707 r
F P
0 g
s
.30934 .61334 m .30421 .64946 L .31658 .66045 L p .707 .577 .707 r
F P
0 g
s
.66018 .73357 m .65657 .71504 L .68034 .70653 L p .707 .577 .707 r
F P
0 g
s
.78855 .62922 m .78342 .66534 L .75256 .65911 L p .707 .577 .707 r
F P
0 g
s
.75256 .65911 m .75768 .62299 L .78855 .62922 L p .707 .577 .707 r
F P
0 g
s
.72612 .61985 m .72099 .65597 L .69183 .65625 L p .707 .577 .707 r
F P
0 g
s
.72099 .65597 m .72612 .61985 L .75768 .62299 L p .707 .577 .707 r
F P
0 g
s
.68034 .70653 m .68396 .72506 L .66018 .73357 L p .707 .577 .707 r
F P
0 g
s
.75768 .62299 m .75256 .65911 L .72099 .65597 L p .707 .577 .707 r
F P
0 g
s
.798 .68616 m .80161 .70469 L .77476 .70652 L p .707 .577 .707 r
F P
0 g
s
.77476 .70652 m .77115 .68799 L .798 .68616 L p .707 .577 .707 r
F P
0 g
s
.50148 .64218 m .49635 .6783 L .50348 .66925 L p .707 .577 .707 r
F P
0 g
s
.50348 .66925 m .50861 .63313 L .50148 .64218 L p .707 .577 .707 r
F P
0 g
s
.30421 .64946 m .30934 .61334 L .30658 .6028 L p .707 .577 .707 r
F P
0 g
s
.29645 .52285 m .28873 .57703 L .29149 .58757 L p .707 .577 .707 r
F P
0 g
s
.3085 .72116 m .30488 .70263 L .29273 .6992 L p .707 .577 .707 r
F P
0 g
s
.29273 .6992 m .29634 .71773 L .3085 .72116 L p .707 .577 .707 r
F P
0 g
s
.68396 .72506 m .68034 .70653 L .70929 .6987 L p .707 .577 .707 r
F P
0 g
s
.49847 .55325 m .49075 .60743 L .48799 .59688 L p .707 .577 .707 r
F P
0 g
s
.48799 .59688 m .49571 .54271 L .49847 .55325 L p .707 .577 .707 r
F P
0 g
s
.48309 .66624 m .48671 .68477 L .49389 .67739 L p .707 .577 .707 r
F P
0 g
s
.49389 .67739 m .49027 .65886 L .48309 .66624 L p .707 .577 .707 r
F P
0 g
s
.70929 .6987 m .71291 .71723 L .68396 .72506 L p .707 .577 .707 r
F P
0 g
s
.77115 .68799 m .77476 .70652 L .74419 .71084 L p .707 .577 .707 r
F P
0 g
s
.74419 .71084 m .74058 .69231 L .77115 .68799 L p .707 .577 .707 r
F P
0 g
s
.28873 .57703 m .29645 .52285 L .30358 .5138 L p .707 .577 .707 r
F P
0 g
s
.30658 .6028 m .30145 .63893 L .30421 .64946 L p .707 .577 .707 r
F P
0 g
s
.71291 .71723 m .70929 .6987 L .74058 .69231 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74058 .69231 m .74419 .71084 L .71291 .71723 L p .707 .577 .707 r
F P
0 g
s
.50861 .63313 m .50348 .66925 L .50072 .65871 L p .707 .577 .707 r
F P
0 g
s
.50072 .65871 m .50585 .62259 L .50861 .63313 L p .707 .577 .707 r
F P
0 g
s
.30145 .63893 m .30658 .6028 L .31371 .59375 L p .707 .577 .707 r
F P
0 g
s
.30358 .5138 m .29586 .56797 L .28873 .57703 L p .707 .577 .707 r
F P
0 g
s
.29634 .71773 m .29273 .6992 L .29011 .69351 L p .707 .577 .707 r
F P
0 g
s
.29011 .69351 m .29372 .71204 L .29634 .71773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49571 .54271 m .48799 .59688 L .47562 .58589 L p .707 .577 .707 r
F P
0 g
s
.47562 .58589 m .48334 .53171 L .49571 .54271 L p .707 .577 .707 r
F P
0 g
s
.49027 .65886 m .49389 .67739 L .49127 .67171 L p .707 .577 .707 r
F P
0 g
s
.49127 .67171 m .48765 .65318 L .49027 .65886 L p .707 .577 .707 r
F P
0 g
s
.29586 .56797 m .30358 .5138 L .3199 .50712 L p .707 .577 .707 r
F P
0 g
s
.31371 .59375 m .30858 .62987 L .30145 .63893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50585 .62259 m .50072 .65871 L .48835 .64772 L p .707 .577 .707 r
F P
0 g
s
.48835 .64772 m .49348 .6116 L .50585 .62259 L p .707 .577 .707 r
F P
0 g
s
.30858 .62987 m .31371 .59375 L .33003 .58707 L p .707 .577 .707 r
F P
0 g
s
.3199 .50712 m .31219 .56129 L .29586 .56797 L p .707 .577 .707 r
F P
0 g
s
.29372 .71204 m .29011 .69351 L .29729 .68613 L p .707 .577 .707 r
F P
0 g
s
.48334 .53171 m .47562 .58589 L .45484 .57551 L p .707 .577 .707 r
F P
0 g
s
.45484 .57551 m .46256 .52134 L .48334 .53171 L p .707 .577 .707 r
F P
0 g
s
.29729 .68613 m .3009 .70467 L .29372 .71204 L p .707 .577 .707 r
F P
0 g
s
.31219 .56129 m .3199 .50712 L .34381 .50347 L p .707 .577 .707 r
F P
0 g
s
.48765 .65318 m .49127 .67171 L .47911 .66828 L p .707 .577 .707 r
F P
0 g
s
.47911 .66828 m .4755 .64975 L .48765 .65318 L p .707 .577 .707 r
F P
0 g
s
.33003 .58707 m .32491 .62319 L .30858 .62987 L p .707 .577 .707 r
F P
0 g
s
.49348 .6116 m .48835 .64772 L .46757 .63736 L p .707 .577 .707 r
F P
0 g
s
.46757 .63736 m .4727 .60124 L .49348 .6116 L p .707 .577 .707 r
F P
0 g
s
.32491 .62319 m .33003 .58707 L .35395 .58342 L p .707 .577 .707 r
F P
0 g
s
.46256 .52134 m .45484 .57551 L .42769 .56677 L p .707 .577 .707 r
F P
0 g
s
.42769 .56677 m .4354 .5126 L .46256 .52134 L p .707 .577 .707 r
F P
0 g
s
.34381 .50347 m .3361 .55764 L .31219 .56129 L p .707 .577 .707 r
F P
0 g
s
.3361 .55764 m .34381 .50347 L .37298 .5032 L p .707 .577 .707 r
F P
0 g
s
.3009 .70467 m .29729 .68613 L .31356 .67778 L p .707 .577 .707 r
F P
0 g
s
.31356 .67778 m .31717 .69631 L .3009 .70467 L p .707 .577 .707 r
F P
0 g
s
.35395 .58342 m .34882 .61954 L .32491 .62319 L p .707 .577 .707 r
F P
0 g
s
.4755 .64975 m .47911 .66828 L .4586 .66744 L p .707 .577 .707 r
F P
0 g
s
.4586 .66744 m .45499 .6489 L .4755 .64975 L p .707 .577 .707 r
F P
0 g
s
.4354 .5126 m .42769 .56677 L .39682 .56052 L p .707 .577 .707 r
F P
0 g
s
.39682 .56052 m .40454 .50635 L .4354 .5126 L p .707 .577 .707 r
F P
0 g
s
.36526 .55738 m .37298 .5032 L .40454 .50635 L p .707 .577 .707 r
F P
0 g
s
.37298 .5032 m .36526 .55738 L .3361 .55764 L p .707 .577 .707 r
F P
0 g
s
.4727 .60124 m .46757 .63736 L .44041 .62863 L p .707 .577 .707 r
F P
0 g
s
.44041 .62863 m .44554 .59251 L .4727 .60124 L p .707 .577 .707 r
F P
0 g
s
.40454 .50635 m .39682 .56052 L .36526 .55738 L p .707 .577 .707 r
F P
0 g
s
.34882 .61954 m .35395 .58342 L .38311 .58314 L p .707 .577 .707 r
F P
0 g
s
.31717 .69631 m .31356 .67778 L .33733 .66927 L p .707 .577 .707 r
F P
0 g
s
.44554 .59251 m .44041 .62863 L .40954 .62239 L p .707 .577 .707 r
F P
0 g
s
.40954 .62239 m .41467 .58627 L .44554 .59251 L p .707 .577 .707 r
F P
0 g
s
.38311 .58314 m .37798 .61926 L .34882 .61954 L p .707 .577 .707 r
F P
0 g
s
.37798 .61926 m .38311 .58314 L .41467 .58627 L p .707 .577 .707 r
F P
0 g
s
.33733 .66927 m .34095 .6878 L .31717 .69631 L p .707 .577 .707 r
F P
0 g
s
.41467 .58627 m .40954 .62239 L .37798 .61926 L p .707 .577 .707 r
F P
0 g
s
.45499 .6489 m .4586 .66744 L .43175 .66926 L p .707 .577 .707 r
F P
0 g
s
.43175 .66926 m .42814 .65073 L .45499 .6489 L p .707 .577 .707 r
F P
0 g
s
.34095 .6878 m .33733 .66927 L .36628 .66144 L p .707 .577 .707 r
F P
0 g
s
.36628 .66144 m .3699 .67997 L .34095 .6878 L p .707 .577 .707 r
F P
0 g
s
.42814 .65073 m .43175 .66926 L .40118 .67358 L p .707 .577 .707 r
F P
0 g
s
.40118 .67358 m .39757 .65505 L .42814 .65073 L p .707 .577 .707 r
F P
0 g
s
.3699 .67997 m .36628 .66144 L .39757 .65505 L p .707 .577 .707 r
F P
0 g
s
.39757 .65505 m .40118 .67358 L .3699 .67997 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8P00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001YOol2
0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00GWoo4@002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001JOol4
0003FUH00`00FUIJEP06FUH01000FUIJEUYF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001HOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60007FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001VOol005Ioo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
IWoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool@
001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool50003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70016Ool005=oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo0000
05YF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@Woo001COol00`00FUH0
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF1000?Woo001COol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00
>Woo001COol20003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH2000hOol005=oo`8000=JEP@0009JEP04001JEUYFFUH40002FUH01000
FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo
00@005YF001JEP8000IJEP03001JEUYF00AJEP@000EJEPT0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008003Aoo`00DWoo00H005YF000005YF0005FUH00`00FUIJEP06
FUH00`00FUH000030002FUH50004FUH40006FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00<Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUHC0002FUH0
0`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P00<Goo001BOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF0P00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01000FUH00000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00@005YFFUIJEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJ
EQ0000IJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH20004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DWoo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000MJEP03001JEUYF00AJEP80009JEP03001JEP0000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0UYF0P00;Goo001BOol01@00FUIJEUYF000015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH015YF00L005YF001JEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
009JEP8002eoo`00Dgoo00@005YFFUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF0000;Goo000gOolA000<Ool300000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP03FUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF200027oo
1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool003=oo`@000=J
EP03001JEUYF00IJEP03001JEUYF009JEPP000Ioo`04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF1P0000=JEP00FUH0
15YF1@001Woo2@000UYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUIJEP00FUH^Ool0035o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH600000goo00000004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0`00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH010000Woo1@0017oo10001EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH^Ool002moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000EJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Qoo`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002io
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH400000eYF
0000000:00000eYF001JEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20005FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH@0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00UYF0P00;goo000]
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP020003FUH500000eYF00000002Ool01@00FUIJEP00FUH03`0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000eYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH015YF0P000eYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEPD000AJEP800005Ool005YFFUH00006
FUH@0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P001EYF00<005YF00000UYF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000eYF00<005YFFUH01000;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000EJEPD000EJEP03001JEUYF00IJEP800003FUH005YF00EJEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH00UYF0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
000300000eYF001JEP04FUH50005FUH00`00FUIJEP08FUH20006FUH01000FUIJEUYF0`0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF0P00<7oo
000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH30006FUH00`00FUIJ
EP09FUH30003FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP<00003FUH00000031oo`00;7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000@000QJEP03001JEUYF00UJEP03001JEUYF0080
0003FUH005YF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03000`Ool002aoo`8000=JEP04001JEUYFFUH@0004FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1`000UYF00<005YFFUH00eYF3@000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000eYF10000UYF00@0
05YFFUIJEP<000Moo`L000IJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP000080009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP8002ioo`00:goo00@005YF001JEP8000IJEP03001JEUYF00AJEP<000Ioo`T0009JEP03001JEUYF
00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0400000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF00@005YF000002aoo`00:goo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUH0
00030002Ool50004Ool40005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP0200001UYF00000000FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP@00003
FUH0000000Ioo`h000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qoo`@0009JEP8000=J
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EP00001JEP0300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP040004FUH2000>Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000:goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF0000000=00001EYF000005YF00000UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P000eYF00X005YFFUH005YF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800005FUH00000FUH00002FUH20002FUH01000FUH000002Woo0`0027oo
10001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:Woo000[Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
10001UYF00<005YFFUH01eYF00<005YFFUH00UYF20000eYF00<005YFFUH01@0000QJEP00000005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH0
0UYF0`000eYF00<007ooOol01Woo1@002goo10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000ZOol002]oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00AJEPL0
009JEP03001JEUYF00IJEP@000=JEPH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP06001JEP00001JEP0027oo1@003goo0`00
1EYF00L005YFFUIJEP00FUH0000ZOol002]oo`05001JEUYFFUH00006FUH01000FUIJEUYF5`0025YF
0P0015YF00<005YFFUH01eYF00<005YFFUH01@0025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP04001JEUYFFUH30007Ool5000BOol20003FUH01`00FUIJEUYF001J
EP0002Yoo`00:goo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@0009JEP<000IJEP03001JEUYF00AJEPD000=JEP<000MJEP03001JEUYF00=JEP8000=J
EP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP@000Aoo`<001Eoo`800003FUH005YF
009JEP8002]oo`00;7oo00@005YFFUH000AJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEP80009JEP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00T000IJEP03001J
EUYF00<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00@001Uoo`<000=JEP8002]oo`00;Goo0`000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF1P000UYF00<005YF
FUH00eYF3P0000=JEP00FUH01UYF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH015YF6@0000QJEP00FUH005YF001JEP00:goo000_Ool01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@005YFFUIJEP8000=JEP<0
009JEP03001JEUYF00=JEPX000EJEP03001JEUYF00EJEP<000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00=JEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000800005FUH00000
FUH0000[Ool0031oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP07001JEUYFFUH005YF00001EYF00<005YF00000`000eYF0`000UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUH0
000[Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF0003FUH30003FUH400000eYF00000002FUH70006FUH00`00FUIJEP06FUH00`00
FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF0P00;7oo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00P001UYF00<005YF00001`00
0eYF00<005YFFUH01eYF00<005YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00@0
0003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P00;7oo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P000UYF1P001EYF00<005YFFUH01eYF00<005YFFUH015YF4@000UYF
00@005YF000002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF1@002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH0100000=JEP00FUH01UYF00<005YFFUH00UYF2000;Goo000_Ool00`00FUH00003FUH01000
FUIJEUYF400015YF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00IJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00EJEP03001JEP000080009JEP03001JEUYF00<002eo
o`00;goo0P000eYF1@002Woo3`0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEPH0009J
EP<000MJEP03001JEUYF00=JEP@00003FUH005YF00=JEP04001JEP00000^Ool002moo`03FUH005YF
00D001=oo``00003FUH005YF00AJEP03001JEUYF009JEPP000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF00IJEP03001JEUYF009JEP80009oo`@00003FUH0000000<000EJEP04001J
EUYFFUH30005FUH00`00FUIJEP02FUH2000`Ool002ioo`04001JEP000002FUH00`00FUIJEP02000?
Ool3000;Ool<0002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF00<005YF00000P0027oo1`0015YF00H005YF000005YF0007FUH01@00FUIJEUYF
0000<Goo000^Ool20004FUH00`00FUIJEP02FUH3000;Ool5000>Ool200000eYF001JEP05FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH60009Ool5
00000goo000000040003FUH00`00FUIJEP05FUH01000FUH00000<Woo000^Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUH000002Goo1@0047oo0P001UYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`000eYF0P002goo20001UYF00<0
05YFFUH015YF0`00=7oo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Woo
1@004Woo0P000eYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH00UYF0P000eYF0`0000=JEP0000001Woo1`0015YF00<005YFFUH01UYF00@005YFFUIJ
EP8003Moo`00;goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEPD0009oo`<001Eoo`800004FUH0
05YF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUH000001EYF00<0
05YFFUH00`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Uoo`00;goo
00D005YFFUIJEP0000EJEP03001JEUYF00IJEP04001JEUYFFUH90008Ool=00001EYF001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000eYF4@001UYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>goo000`Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF00<005YF00000`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUH005YF
001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?Woo
000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEP`0
0003FUH005YF00YJEPT000QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0049oo`00<goo00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000Agoo000dOol20002FUH00`00FUIJEP04FUH50006
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP040006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF1`00Bgoo000fOol30002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUHE
001AOol003Moo`@000IJEP03001JEUYF00MJEP03001JEUYF009JEPP000=JEP03001JEUYF00D00003
FUH00000009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001oo`0000<0009JEP03001JEUYF00=J
EP07001JEUYFFUH005YF0000DGoo000dOol300000eYF001JEP08FUH00`00FUIJEP04FUH70002FUH0
0`00FUIJEP06FUH40003FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP03001o
ogoo00=oo`<000EJEP07001JEUYFFUH005YF0000DGoo000bOol20004FUH00`00FUIJEP07FUH00`00
FUIJEP050008FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH00002FUH00`00FUH00002
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001oo`07Ool20003FUH01`00FUIJEUYF001JEP00055oo`00
<7oo0`001UYF00<005YFFUH015YF1@000eYF0`001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF0`000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000Yoo`800003FUH0
05YF009JEP80059oo`00;Woo0P000UYF00<005YFFUH015YF00<005YFFUH010000goo2@001UYF00<0
05YFFUH00`001EYF00<005YFFUH00eYF00D007oo001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP00000<Ool20003FUH2001BOol002eoo`03001JEUYF009JEP03001JEUYF00AJEP<0
00]oo`L000=JEP@00003FUH005YF00IJEP03001JEUYF0080009oo`<000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0001000004FUH005YF001BOol002aoo`8000EJEP04001JEUYFFUH2000>
Ool:0005FUH00`00FUIJEP05FUH30004Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YF00000P0000EJEP00001JEP00059oo`00:goo
00<005YF00001EYF00@005YF0000015oo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000Mo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YF0000DWoo000[Ool01000FUIJEP000eYF0`003Goo1P001UYF00<005YF
FUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP8005=oo`00:goo00D005YFFUH005YF008000Qoo`P0
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000ioo`03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P00Dgoo000/Ool01000FUH0
00000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010004Woo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000eYF2`000UYF00@005YF000005=oo`00;7oo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0067oo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEPL000=JEP03001JEUYF009JEPP005Aoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010007goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEUYF00<005Aoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P009Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00@005YF000005Eoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH00UYF2000;Goo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF10001UYF
00<005YFFUH015YF0P000eYF00<005YFFUH00UYF0P00Egoo000_Ool<000hOol70005FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH=0004FUH01000FUIJEUYF0`001UYF00D005YFFUIJ
EP0005Qoo`00NWoo30001UYF00<005YFFUH02EYF00@005YFFUIJEPH000Moo`D00003Ool0000000H0
0003FUH005YF00IJEP04001JEP00001IOol008IooaH000eoo`X000EJEP03001JEUYF00AJEP<005]o
o`00S7oo00@005YFFUH000AJEP8001Aoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH2001NOol0
08aoo`05001JEUYFFUH00002FUH00`00Oomoo`0=Ool70006FUH00`00FUIJEP06FUH01000FUH00000
H7oo002<Ool01000FUIJEUYF4`0015YF00<005YFFUH01eYF00<005YFFUH015YF0`00HWoo002=Ool0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
001UOol008eoo`<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJ
EPD006Uoo`00SGoo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01000KWoo002>Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001b
Ool0091oo`D000=JEP04001JEUYFFUH8001iOol009Eoo`L0085oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60318 .7456 m .59546 .68977 L .56459 .69228 L p .707 .577 .707 r
F P
0 g
s
.59546 .68977 m .60318 .7456 L .63474 .74084 L p .707 .577 .707 r
F P
0 g
s
.63474 .74084 m .62702 .68501 L .59546 .68977 L p .707 .577 .707 r
F P
0 g
s
.62702 .68501 m .63474 .74084 L .6639 .7343 L p .707 .577 .707 r
F P
0 g
s
.6639 .7343 m .65618 .67847 L .62702 .68501 L p .707 .577 .707 r
F P
0 g
s
.57231 .74811 m .56459 .69228 L .53744 .6923 L p .707 .577 .707 r
F P
0 g
s
.56459 .69228 m .57231 .74811 L .60318 .7456 L p .707 .577 .707 r
F P
0 g
s
.65618 .67847 m .6639 .7343 L .68781 .72662 L p .707 .577 .707 r
F P
0 g
s
.68781 .72662 m .68009 .67079 L .65618 .67847 L p .707 .577 .707 r
F P
0 g
s
.53744 .6923 m .54516 .74813 L .57231 .74811 L p .707 .577 .707 r
F P
0 g
s
.54516 .74813 m .53744 .6923 L .51666 .68983 L p .707 .577 .707 r
F P
0 g
s
.59045 .80474 m .58532 .76752 L .55445 .77002 L p .707 .577 .707 r
F P
0 g
s
.58532 .76752 m .59045 .80474 L .62201 .79999 L p .707 .577 .707 r
F P
0 g
s
.62201 .79999 m .61688 .76277 L .58532 .76752 L p .707 .577 .707 r
F P
0 g
s
.61688 .76277 m .62201 .79999 L .65118 .79346 L p .707 .577 .707 r
F P
0 g
s
.65118 .79346 m .64605 .75624 L .61688 .76277 L p .707 .577 .707 r
F P
0 g
s
.68009 .67079 m .68781 .72662 L .70413 .71856 L p .707 .577 .707 r
F P
0 g
s
.70413 .71856 m .69642 .66273 L .68009 .67079 L p .707 .577 .707 r
F P
0 g
s
.55958 .80724 m .55445 .77002 L .5273 .77003 L p .707 .577 .707 r
F P
0 g
s
.55445 .77002 m .55958 .80724 L .59045 .80474 L p .707 .577 .707 r
F P
0 g
s
.51666 .68983 m .52438 .74566 L .54516 .74813 L p .707 .577 .707 r
F P
0 g
s
.59881 .85772 m .60243 .83997 L .57186 .83198 L p .707 .577 .707 r
F P
0 g
s
.60243 .83997 m .59881 .85772 L .6301 .86244 L p .707 .577 .707 r
F P
0 g
s
.6301 .86244 m .63371 .84468 L .60243 .83997 L p .707 .577 .707 r
F P
0 g
s
.64605 .75624 m .65118 .79346 L .67509 .78579 L p .707 .577 .707 r
F P
0 g
s
.67509 .78579 m .66996 .74857 L .64605 .75624 L p .707 .577 .707 r
F P
0 g
s
.5273 .77003 m .53243 .80725 L .55958 .80724 L p .707 .577 .707 r
F P
0 g
s
.63371 .84468 m .6301 .86244 L .65905 .86342 L p .707 .577 .707 r
F P
0 g
s
.65905 .86342 m .66266 .84567 L .63371 .84468 L p .707 .577 .707 r
F P
0 g
s
.56825 .84973 m .57186 .83198 L .54501 .82149 L p .707 .577 .707 r
F P
0 g
s
.57186 .83198 m .56825 .84973 L .59881 .85772 L p .707 .577 .707 r
F P
0 g
s
.52438 .74566 m .51666 .68983 L .50429 .68511 L p .707 .577 .707 r
F P
0 g
s
.54501 .82149 m .5414 .83925 L .56825 .84973 L p .707 .577 .707 r
F P
0 g
s
.53243 .80725 m .5273 .77003 L .50652 .76754 L p .707 .577 .707 r
F P
0 g
s
.66266 .84567 m .65905 .86342 L .68282 .86057 L p .707 .577 .707 r
F P
0 g
s
.68282 .86057 m .68644 .84281 L .66266 .84567 L p .707 .577 .707 r
F P
0 g
s
.5414 .83925 m .54501 .82149 L .5245 .80955 L p .707 .577 .707 r
F P
0 g
s
.66996 .74857 m .67509 .78579 L .69141 .77773 L p .707 .577 .707 r
F P
0 g
s
.69141 .77773 m .68628 .74051 L .66996 .74857 L p .707 .577 .707 r
F P
0 g
s
.50652 .76754 m .51165 .80477 L .53243 .80725 L p .707 .577 .707 r
F P
0 g
s
.69642 .66273 m .70413 .71856 L .71126 .71089 L p .707 .577 .707 r
F P
0 g
s
.71126 .71089 m .70355 .65506 L .69642 .66273 L p .707 .577 .707 r
F P
0 g
s
.50429 .68511 m .512 .74094 L .52438 .74566 L p .707 .577 .707 r
F P
0 g
s
.5245 .80955 m .52089 .8273 L .5414 .83925 L p .707 .577 .707 r
F P
0 g
s
.51165 .80477 m .50652 .76754 L .49414 .76281 L p .707 .577 .707 r
F P
0 g
s
.512 .74094 m .50429 .68511 L .50153 .67859 L p .707 .577 .707 r
F P
0 g
s
.68644 .84281 m .68282 .86057 L .6991 .85417 L p .707 .577 .707 r
F P
0 g
s
.6991 .85417 m .70271 .83641 L .68644 .84281 L p .707 .577 .707 r
F P
0 g
s
.52089 .8273 m .5245 .80955 L .51234 .7973 L p .707 .577 .707 r
F P
0 g
s
.49414 .76281 m .49927 .80003 L .51165 .80477 L p .707 .577 .707 r
F P
0 g
s
.68628 .74051 m .69141 .77773 L .69854 .77006 L p .707 .577 .707 r
F P
0 g
s
.69854 .77006 m .69341 .73284 L .68628 .74051 L p .707 .577 .707 r
F P
0 g
s
.51234 .7973 m .50873 .81506 L .52089 .8273 L p .707 .577 .707 r
F P
0 g
s
.70355 .65506 m .71126 .71089 L .70851 .70438 L p .707 .577 .707 r
F P
0 g
s
.70851 .70438 m .70079 .64855 L .70355 .65506 L p .707 .577 .707 r
F P
0 g
s
.50153 .67859 m .50925 .73442 L .512 .74094 L p .707 .577 .707 r
F P
0 g
s
.48793 .82189 m .4916 .32041 L .44759 .3174 L p .707 .577 .707 r
F P
0 g
s
.49927 .80003 m .49414 .76281 L .49139 .75629 L p .707 .577 .707 r
F P
0 g
s
.50873 .81506 m .51234 .7973 L .50972 .78596 L p .707 .577 .707 r
F P
0 g
s
.50925 .73442 m .50153 .67859 L .50866 .67093 L p .707 .577 .707 r
F P
0 g
s
.49139 .75629 m .49652 .79351 L .49927 .80003 L p .707 .577 .707 r
F P
0 g
s
.50972 .78596 m .50611 .80372 L .50873 .81506 L p .707 .577 .707 r
F P
0 g
s
.50866 .67093 m .51638 .72676 L .50925 .73442 L p .707 .577 .707 r
F P
0 g
s
.49652 .79351 m .49139 .75629 L .49852 .74862 L p .707 .577 .707 r
F P
0 g
s
.50611 .80372 m .50972 .78596 L .5169 .77663 L p .707 .577 .707 r
F P
0 g
s
.51638 .72676 m .50866 .67093 L .52498 .66286 L p .707 .577 .707 r
F P
0 g
s
.5169 .77663 m .51329 .79439 L .50611 .80372 L p .707 .577 .707 r
F P
0 g
s
.49852 .74862 m .50365 .78584 L .49652 .79351 L p .707 .577 .707 r
F P
0 g
s
.52498 .66286 m .5327 .71869 L .51638 .72676 L p .707 .577 .707 r
F P
0 g
s
.50365 .78584 m .49852 .74862 L .51484 .74056 L p .707 .577 .707 r
F P
0 g
s
.51329 .79439 m .5169 .77663 L .53318 .77023 L p .707 .577 .707 r
F P
0 g
s
.53318 .77023 m .52956 .78799 L .51329 .79439 L p .707 .577 .707 r
F P
0 g
s
.51484 .74056 m .51997 .77778 L .50365 .78584 L p .707 .577 .707 r
F P
0 g
s
.51997 .77778 m .51484 .74056 L .53875 .73289 L p .707 .577 .707 r
F P
0 g
s
.52956 .78799 m .53318 .77023 L .55695 .76738 L p .707 .577 .707 r
F P
0 g
s
.55695 .76738 m .55334 .78514 L .52956 .78799 L p .707 .577 .707 r
F P
0 g
s
.53875 .73289 m .54388 .77011 L .51997 .77778 L p .707 .577 .707 r
F P
0 g
s
.4916 .32041 m .48793 .82189 L .53287 .82108 L p .707 .577 .707 r
F P
0 g
s
.5327 .71869 m .52498 .66286 L .5489 .65518 L p .707 .577 .707 r
F P
0 g
s
.5489 .65518 m .55661 .71101 L .5327 .71869 L p .707 .577 .707 r
F P
0 g
s
.53287 .82108 m .53654 .3196 L .4916 .32041 L p .707 .577 .707 r
F P
0 g
s
.70271 .83641 m .6991 .85417 L .70628 .84484 L p .707 .577 .707 r
F P
0 g
s
.70628 .84484 m .70989 .82708 L .70271 .83641 L p .707 .577 .707 r
F P
0 g
s
.55661 .71101 m .5489 .65518 L .57806 .64864 L p .707 .577 .707 r
F P
0 g
s
.57806 .64864 m .58578 .70448 L .55661 .71101 L p .707 .577 .707 r
F P
0 g
s
.54388 .77011 m .53875 .73289 L .56792 .72636 L p .707 .577 .707 r
F P
0 g
s
.55334 .78514 m .55695 .76738 L .5859 .76836 L p .707 .577 .707 r
F P
0 g
s
.56792 .72636 m .57305 .76358 L .54388 .77011 L p .707 .577 .707 r
F P
0 g
s
.5859 .76836 m .58229 .78612 L .55334 .78514 L p .707 .577 .707 r
F P
0 g
s
.53654 .3196 m .53287 .82108 L .57435 .81655 L p .707 .577 .707 r
F P
0 g
s
.57305 .76358 m .56792 .72636 L .59948 .72161 L p .707 .577 .707 r
F P
0 g
s
.59948 .72161 m .60461 .75883 L .57305 .76358 L p .707 .577 .707 r
F P
0 g
s
.57435 .81655 m .57802 .31507 L .53654 .3196 L p .707 .577 .707 r
F P
0 g
s
.44392 .81888 m .44759 .3174 L .40883 .31087 L p .707 .577 .707 r
F P
0 g
s
.44759 .3174 m .44392 .81888 L .48793 .82189 L p .707 .577 .707 r
F P
0 g
s
.69341 .73284 m .69854 .77006 L .69579 .76354 L p .707 .577 .707 r
F P
0 g
s
.69579 .76354 m .69066 .72632 L .69341 .73284 L p .707 .577 .707 r
F P
0 g
s
.70079 .64855 m .70851 .70438 L .69613 .69965 L p .707 .577 .707 r
F P
0 g
s
.69613 .69965 m .68842 .64382 L .70079 .64855 L p .707 .577 .707 r
F P
0 g
s
.58578 .70448 m .57806 .64864 L .60962 .64389 L p .707 .577 .707 r
F P
0 g
s
.60962 .64389 m .61733 .69972 L .58578 .70448 L p .707 .577 .707 r
F P
0 g
s
.63035 .71911 m .63548 .75633 L .60461 .75883 L p .707 .577 .707 r
F P
0 g
s
.60461 .75883 m .59948 .72161 L .63035 .71911 L p .707 .577 .707 r
F P
0 g
s
.58229 .78612 m .5859 .76836 L .61719 .77308 L p .707 .577 .707 r
F P
0 g
s
.61719 .77308 m .61357 .79083 L .58229 .78612 L p .707 .577 .707 r
F P
0 g
s
.57802 .31507 m .57435 .81655 L .60831 .80872 L p .707 .577 .707 r
F P
0 g
s
.60831 .80872 m .61198 .30724 L .57802 .31507 L p .707 .577 .707 r
F P
0 g
s
.26017 .70875 m .25245 .65292 L .22158 .65543 L p .707 .577 .707 r
F P
0 g
s
.25245 .65292 m .26017 .70875 L .29173 .70399 L p .707 .577 .707 r
F P
0 g
s
.29173 .70399 m .28401 .64816 L .25245 .65292 L p .707 .577 .707 r
F P
0 g
s
.40516 .81235 m .40883 .31087 L .3791 .30147 L p .707 .577 .707 r
F P
0 g
s
.40883 .31087 m .40516 .81235 L .44392 .81888 L p .707 .577 .707 r
F P
0 g
s
.28401 .64816 m .29173 .70399 L .32089 .69745 L p .707 .577 .707 r
F P
0 g
s
.32089 .69745 m .31317 .64162 L .28401 .64816 L p .707 .577 .707 r
F P
0 g
s
.70989 .82708 m .70628 .84484 L .70366 .8335 L p .707 .577 .707 r
F P
0 g
s
.70366 .8335 m .70727 .81574 L .70989 .82708 L p .707 .577 .707 r
F P
0 g
s
.2293 .71126 m .22158 .65543 L .19443 .65545 L p .707 .577 .707 r
F P
0 g
s
.22158 .65543 m .2293 .71126 L .26017 .70875 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31317 .64162 m .32089 .69745 L .3448 .68977 L p .707 .577 .707 r
F P
0 g
s
.3448 .68977 m .33709 .63394 L .31317 .64162 L p .707 .577 .707 r
F P
0 g
s
.69066 .72632 m .69579 .76354 L .68341 .75881 L p .707 .577 .707 r
F P
0 g
s
.68341 .75881 m .67828 .72159 L .69066 .72632 L p .707 .577 .707 r
F P
0 g
s
.68842 .64382 m .69613 .69965 L .67535 .69718 L p .707 .577 .707 r
F P
0 g
s
.67535 .69718 m .66764 .64135 L .68842 .64382 L p .707 .577 .707 r
F P
0 g
s
.64049 .64137 m .6482 .6972 L .61733 .69972 L p .707 .577 .707 r
F P
0 g
s
.61733 .69972 m .60962 .64389 L .64049 .64137 L p .707 .577 .707 r
F P
0 g
s
.64775 .78107 m .64414 .79882 L .61357 .79083 L p .707 .577 .707 r
F P
0 g
s
.61357 .79083 m .61719 .77308 L .64775 .78107 L p .707 .577 .707 r
F P
0 g
s
.61198 .30724 m .60831 .80872 L .63142 .79837 L p .707 .577 .707 r
F P
0 g
s
.63548 .75633 m .63035 .71911 L .6575 .7191 L p .707 .577 .707 r
F P
0 g
s
.63142 .79837 m .63509 .29689 L .61198 .30724 L p .707 .577 .707 r
F P
0 g
s
.19443 .65545 m .20215 .71128 L .2293 .71126 L p .707 .577 .707 r
F P
0 g
s
.20215 .71128 m .19443 .65545 L .17365 .65298 L p .707 .577 .707 r
F P
0 g
s
.24744 .76782 m .24231 .7306 L .21145 .7331 L p .707 .577 .707 r
F P
0 g
s
.24231 .7306 m .24744 .76782 L .279 .76307 L p .707 .577 .707 r
F P
0 g
s
.279 .76307 m .27388 .72585 L .24231 .7306 L p .707 .577 .707 r
F P
0 g
s
.27388 .72585 m .279 .76307 L .30817 .75654 L p .707 .577 .707 r
F P
0 g
s
.30817 .75654 m .30304 .71932 L .27388 .72585 L p .707 .577 .707 r
F P
0 g
s
.70727 .81574 m .70366 .8335 L .6915 .82125 L p .707 .577 .707 r
F P
0 g
s
.6915 .82125 m .69511 .8035 L .70727 .81574 L p .707 .577 .707 r
F P
0 g
s
.33709 .63394 m .3448 .68977 L .36112 .68171 L p .707 .577 .707 r
F P
0 g
s
.36112 .68171 m .35341 .62587 L .33709 .63394 L p .707 .577 .707 r
F P
0 g
s
.21657 .77032 m .21145 .7331 L .18429 .73311 L p .707 .577 .707 r
F P
0 g
s
.21145 .7331 m .21657 .77032 L .24744 .76782 L p .707 .577 .707 r
F P
0 g
s
.37544 .80295 m .3791 .30147 L .36133 .2901 L p .707 .577 .707 r
F P
0 g
s
.3791 .30147 m .37544 .80295 L .40516 .81235 L p .707 .577 .707 r
F P
0 g
s
.17365 .65298 m .18137 .70881 L .20215 .71128 L p .707 .577 .707 r
F P
0 g
s
.30304 .71932 m .30817 .75654 L .33208 .74887 L p .707 .577 .707 r
F P
0 g
s
.33208 .74887 m .32695 .71165 L .30304 .71932 L p .707 .577 .707 r
F P
0 g
s
.2558 .82135 m .25942 .80359 L .22885 .7956 L p .707 .577 .707 r
F P
0 g
s
.25942 .80359 m .2558 .82135 L .28709 .82607 L p .707 .577 .707 r
F P
0 g
s
.28709 .82607 m .29071 .80831 L .25942 .80359 L p .707 .577 .707 r
F P
0 g
s
.66764 .64135 m .67535 .69718 L .6482 .6972 L p .707 .577 .707 r
F P
0 g
s
.6482 .6972 m .64049 .64137 L .66764 .64135 L p .707 .577 .707 r
F P
0 g
s
.18429 .73311 m .18942 .77033 L .21657 .77032 L p .707 .577 .707 r
F P
0 g
s
.67828 .72159 m .68341 .75881 L .66263 .75632 L p .707 .577 .707 r
F P
0 g
s
.66263 .75632 m .6575 .7191 L .67828 .72159 L p .707 .577 .707 r
F P
0 g
s
.29071 .80831 m .28709 .82607 L .31604 .82705 L p .707 .577 .707 r
F P
0 g
s
.31604 .82705 m .31965 .80929 L .29071 .80831 L p .707 .577 .707 r
F P
0 g
s
.22524 .81336 m .22885 .7956 L .202 .78512 L p .707 .577 .707 r
F P
0 g
s
.22885 .7956 m .22524 .81336 L .2558 .82135 L p .707 .577 .707 r
F P
0 g
s
.18137 .70881 m .17365 .65298 L .16128 .64825 L p .707 .577 .707 r
F P
0 g
s
.202 .78512 m .19839 .80288 L .22524 .81336 L p .707 .577 .707 r
F P
0 g
s
.18942 .77033 m .18429 .73311 L .16351 .73062 L p .707 .577 .707 r
F P
0 g
s
.6575 .7191 m .66263 .75632 L .63548 .75633 L p .707 .577 .707 r
F P
0 g
s
.63509 .29689 m .63142 .79837 L .64142 .78651 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .64508 .28503 L .63509 .29689 L p .707 .577 .707 r
F P
0 g
s
.31965 .80929 m .31604 .82705 L .33981 .8242 L p .707 .577 .707 r
F P
0 g
s
.33981 .8242 m .34343 .80644 L .31965 .80929 L p .707 .577 .707 r
F P
0 g
s
.19839 .80288 m .202 .78512 L .18149 .77317 L p .707 .577 .707 r
F P
0 g
s
.32695 .71165 m .33208 .74887 L .3484 .74081 L p .707 .577 .707 r
F P
0 g
s
.3484 .74081 m .34327 .70359 L .32695 .71165 L p .707 .577 .707 r
F P
0 g
s
.16351 .73062 m .16864 .76785 L .18942 .77033 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35724 .27789 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.35341 .62587 m .36112 .68171 L .36644 .67599 L p .707 .577 .707 r
F P
0 g
s
.36614 .66717 m .35341 .62587 L .36644 .67599 L .707 .577 .707 r
F
.36825 .67404 m .36054 .61821 L .35341 .62587 L p F P
0 g
s
.35778 .6117 m .36054 .61821 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.3655 .66753 m .36285 .64836 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .35778 .6117 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.35778 .6117 m .36285 .64836 L p .35312 .6628 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .3655 .66753 L .36207 .66622 L p .707 .577 .707 r
F P
0 g
s
.36207 .66622 m .35312 .6628 L p .36285 .64836 L .707 .577 .707 r
F P
0 g
s
.34327 .70359 m .3484 .74081 L .35553 .73314 L p .707 .577 .707 r
F P
0 g
s
.35553 .73314 m .35041 .69592 L .34327 .70359 L p .707 .577 .707 r
F P
0 g
s
.35041 .69592 m .35553 .73314 L .35278 .72662 L p .707 .577 .707 r
F P
0 g
s
.35312 .6628 m .34541 .60697 L .35778 .6117 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .34849 .78488 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.36426 .77937 m .3618 .79145 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.3618 .79145 m .36065 .79712 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .3521 .76712 L .36135 .77643 L p .707 .577 .707 r
F P
0 g
s
.36135 .77643 m .36426 .77937 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .36135 .77643 L .36147 .78034 L .707 .577 .707 r
F
.35764 .76737 m .35754 .65014 L .3567 .78873 L F
.35754 .65014 m .35724 .27789 L .35687 .62788 L F
.35754 .65014 m .35687 .62788 L .3567 .78873 L F
.35357 .77937 m .3567 .78873 L p .35687 .62788 L F P
0 g
s
.35724 .27789 m .35511 .56932 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.35511 .56932 m .35357 .77937 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.3567 .78873 m .35766 .79158 L p .35764 .76737 L .707 .577 .707 r
F P
0 g
s
.35753 .63446 m .3599 .48527 L .35735 .41085 L .707 .577 .707 r
F
.35766 .79158 m .35878 .63774 L p .35753 .63446 L F P
0 g
s
.35878 .63774 m .3599 .48527 L p .35753 .63446 L .707 .577 .707 r
F P
0 g
s
.3599 .48527 m .36133 .2901 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.36644 .67599 m .36825 .67404 L p .36614 .66717 L .707 .577 .707 r
F P
0 g
s
.69511 .8035 m .6915 .82125 L .67099 .80931 L p .707 .577 .707 r
F P
0 g
s
.67099 .80931 m .6746 .79155 L .69511 .8035 L p .707 .577 .707 r
F P
0 g
s
.16128 .64825 m .16899 .70409 L .18137 .70881 L p .707 .577 .707 r
F P
0 g
s
.18149 .77317 m .17788 .79093 L .19839 .80288 L p .707 .577 .707 r
F P
0 g
s
.36054 .61821 m .36825 .67404 L .3655 .66753 L p .707 .577 .707 r
F P
0 g
s
.36327 .80846 m .36688 .79071 L .3597 .80004 L p .707 .577 .707 r
F P
0 g
s
.36688 .79071 m .36327 .80846 L .36065 .79712 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .36426 .77937 L .36688 .79071 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35766 .79158 L .37544 .80295 L p .707 .577 .707 r
F P
0 g
s
.16864 .76785 m .16351 .73062 L .15114 .72589 L p .707 .577 .707 r
F P
0 g
s
.16899 .70409 m .16128 .64825 L .15852 .64174 L p .707 .577 .707 r
F P
0 g
s
.34343 .80644 m .33981 .8242 L .35609 .81779 L p .707 .577 .707 r
F P
0 g
s
.35609 .81779 m .3597 .80004 L .34343 .80644 L p .707 .577 .707 r
F P
0 g
s
.17788 .79093 m .18149 .77317 L .16933 .76093 L p .707 .577 .707 r
F P
0 g
s
.6746 .79155 m .67099 .80931 L .64414 .79882 L p .707 .577 .707 r
F P
0 g
s
.64414 .79882 m .64775 .78107 L .6746 .79155 L p .707 .577 .707 r
F P
0 g
s
.15114 .72589 m .15626 .76311 L .16864 .76785 L p .707 .577 .707 r
F P
0 g
s
.16933 .76093 m .16572 .77869 L .17788 .79093 L p .707 .577 .707 r
F P
0 g
s
.15852 .64174 m .16624 .69757 L .16899 .70409 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .63733 .7743 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.64381 .45978 m .64142 .78651 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .64508 .28503 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63733 .7743 m .63879 .5747 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63879 .5747 m .641 .27282 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .63733 .7743 L .61955 .76294 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .64885 .71273 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63135 .67077 m .63381 .68866 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63381 .68866 m .63648 .70799 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .64372 .67551 L .63454 .67199 L p .707 .577 .707 r
F P
0 g
s
.63454 .67199 m .63135 .67077 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .63454 .67199 L .63429 .67782 L .707 .577 .707 r
F
.64508 .28503 m .64381 .45978 L p .64146 .51343 L F P
0 g
s
.15626 .76311 m .15114 .72589 L .14838 .71937 L p .707 .577 .707 r
F P
0 g
s
.3597 .80004 m .35609 .81779 L .36327 .80846 L p .707 .577 .707 r
F P
0 g
s
.16572 .77869 m .16933 .76093 L .16672 .74959 L p .707 .577 .707 r
F P
0 g
s
.16624 .69757 m .15852 .64174 L .16565 .63408 L p .707 .577 .707 r
F P
0 g
s
.14838 .71937 m .15351 .75659 L .15626 .76311 L p .707 .577 .707 r
F P
0 g
s
.16672 .74959 m .1631 .76734 L .16572 .77869 L p .707 .577 .707 r
F P
0 g
s
.35278 .72662 m .34765 .6894 L .35041 .69592 L p .707 .577 .707 r
F P
0 g
s
.35357 .77937 m .35724 .27789 L .36724 .26603 L p .707 .577 .707 r
F P
0 g
s
.16565 .63408 m .17337 .68991 L .16624 .69757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15351 .75659 m .14838 .71937 L .15551 .7117 L p .707 .577 .707 r
F P
0 g
s
.1631 .76734 m .16672 .74959 L .17389 .74026 L p .707 .577 .707 r
F P
0 g
s
.17337 .68991 m .16565 .63408 L .18197 .62601 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17389 .74026 m .17028 .75801 L .1631 .76734 L p .707 .577 .707 r
F P
0 g
s
.61955 .76294 m .62322 .26146 L .641 .27282 L p .707 .577 .707 r
F P
0 g
s
.15551 .7117 m .16064 .74892 L .15351 .75659 L p .707 .577 .707 r
F P
0 g
s
.34765 .6894 m .35278 .72662 L .3404 .72189 L p .707 .577 .707 r
F P
0 g
s
.3404 .72189 m .33527 .68467 L .34765 .6894 L p .707 .577 .707 r
F P
0 g
s
.34541 .60697 m .35312 .6628 L .33234 .66033 L p .707 .577 .707 r
F P
0 g
s
.33234 .66033 m .32463 .6045 L .34541 .60697 L p .707 .577 .707 r
F P
0 g
s
.18197 .62601 m .18969 .68184 L .17337 .68991 L p .707 .577 .707 r
F P
0 g
s
.36357 .76751 m .36724 .26603 L .39035 .25568 L p .707 .577 .707 r
F P
0 g
s
.36724 .26603 m .36357 .76751 L .35357 .77937 L p .707 .577 .707 r
F P
0 g
s
.16064 .74892 m .15551 .7117 L .17183 .70364 L p .707 .577 .707 r
F P
0 g
s
.17028 .75801 m .17389 .74026 L .19017 .73386 L p .707 .577 .707 r
F P
0 g
s
.18969 .68184 m .18197 .62601 L .20589 .61833 L p .707 .577 .707 r
F P
0 g
s
.19017 .73386 m .18655 .75161 L .17028 .75801 L p .707 .577 .707 r
F P
0 g
s
.17183 .70364 m .17696 .74086 L .16064 .74892 L p .707 .577 .707 r
F P
0 g
s
.32463 .6045 m .33234 .66033 L .30519 .66035 L p .707 .577 .707 r
F P
0 g
s
.30519 .66035 m .29748 .60452 L .32463 .6045 L p .707 .577 .707 r
F P
0 g
s
.33527 .68467 m .3404 .72189 L .31962 .7194 L p .707 .577 .707 r
F P
0 g
s
.31962 .7194 m .31449 .68218 L .33527 .68467 L p .707 .577 .707 r
F P
0 g
s
.20589 .61833 m .2136 .67416 L .18969 .68184 L p .707 .577 .707 r
F P
0 g
s
.62322 .26146 m .61955 .76294 L .58983 .75353 L p .707 .577 .707 r
F P
0 g
s
.58983 .75353 m .5935 .25205 L .62322 .26146 L p .707 .577 .707 r
F P
0 g
s
.2136 .67416 m .20589 .61833 L .23505 .61179 L p .707 .577 .707 r
F P
0 g
s
.29748 .60452 m .30519 .66035 L .27433 .66286 L p .707 .577 .707 r
F P
0 g
s
.27433 .66286 m .26661 .60703 L .29748 .60452 L p .707 .577 .707 r
F P
0 g
s
.3521 .76712 m .34849 .78488 L .32798 .77293 L p .707 .577 .707 r
F P
0 g
s
.32798 .77293 m .3316 .75518 L .3521 .76712 L p .707 .577 .707 r
F P
0 g
s
.17696 .74086 m .17183 .70364 L .19574 .69597 L p .707 .577 .707 r
F P
0 g
s
.18655 .75161 m .19017 .73386 L .21394 .731 L p .707 .577 .707 r
F P
0 g
s
.24277 .66762 m .23505 .61179 L .26661 .60703 L p .707 .577 .707 r
F P
0 g
s
.23505 .61179 m .24277 .66762 L .2136 .67416 L p .707 .577 .707 r
F P
0 g
s
.39035 .25568 m .38668 .75716 L .36357 .76751 L p .707 .577 .707 r
F P
0 g
s
.38668 .75716 m .39035 .25568 L .4243 .24786 L p .707 .577 .707 r
F P
0 g
s
.74038 .65356 m .73266 .59773 L .7018 .60024 L p .707 .577 .707 r
F P
0 g
s
.73266 .59773 m .74038 .65356 L .77194 .6488 L p .707 .577 .707 r
F P
0 g
s
.77194 .6488 m .76422 .59297 L .73266 .59773 L p .707 .577 .707 r
F P
0 g
s
.26661 .60703 m .27433 .66286 L .24277 .66762 L p .707 .577 .707 r
F P
0 g
s
.21394 .731 m .21033 .74876 L .18655 .75161 L p .707 .577 .707 r
F P
0 g
s
.31449 .68218 m .31962 .7194 L .29247 .71941 L p .707 .577 .707 r
F P
0 g
s
.29247 .71941 m .28734 .68219 L .31449 .68218 L p .707 .577 .707 r
F P
0 g
s
.19574 .69597 m .20087 .73319 L .17696 .74086 L p .707 .577 .707 r
F P
0 g
s
.76422 .59297 m .77194 .6488 L .8011 .64226 L p .707 .577 .707 r
F P
0 g
s
.8011 .64226 m .79339 .58643 L .76422 .59297 L p .707 .577 .707 r
F P
0 g
s
.70951 .65608 m .7018 .60024 L .67464 .60027 L p .707 .577 .707 r
F P
0 g
s
.7018 .60024 m .70951 .65608 L .74038 .65356 L p .707 .577 .707 r
F P
0 g
s
.20087 .73319 m .19574 .69597 L .22491 .68944 L p .707 .577 .707 r
F P
0 g
s
.79339 .58643 m .8011 .64226 L .82502 .63459 L p .707 .577 .707 r
F P
0 g
s
.82502 .63459 m .8173 .57876 L .79339 .58643 L p .707 .577 .707 r
F P
0 g
s
.3316 .75518 m .32798 .77293 L .30113 .76245 L p .707 .577 .707 r
F P
0 g
s
.30113 .76245 m .30474 .74469 L .3316 .75518 L p .707 .577 .707 r
F P
0 g
s
.21033 .74876 m .21394 .731 L .24289 .73199 L p .707 .577 .707 r
F P
0 g
s
.5935 .25205 m .58983 .75353 L .55107 .74701 L p .707 .577 .707 r
F P
0 g
s
.55107 .74701 m .55473 .24552 L .5935 .25205 L p .707 .577 .707 r
F P
0 g
s
.28734 .68219 m .29247 .71941 L .2616 .72191 L p .707 .577 .707 r
F P
0 g
s
.2616 .72191 m .25647 .68469 L .28734 .68219 L p .707 .577 .707 r
F P
0 g
s
.67464 .60027 m .68236 .6561 L .70951 .65608 L p .707 .577 .707 r
F P
0 g
s
.22491 .68944 m .23004 .72666 L .20087 .73319 L p .707 .577 .707 r
F P
0 g
s
.24289 .73199 m .23928 .74974 L .21033 .74876 L p .707 .577 .707 r
F P
0 g
s
.23004 .72666 m .22491 .68944 L .25647 .68469 L p .707 .577 .707 r
F P
0 g
s
.68236 .6561 m .67464 .60027 L .65386 .59779 L p .707 .577 .707 r
F P
0 g
s
.72766 .7127 m .72253 .67548 L .69166 .67798 L p .707 .577 .707 r
F P
0 g
s
.72253 .67548 m .72766 .7127 L .75922 .70796 L p .707 .577 .707 r
F P
0 g
s
.75922 .70796 m .75409 .67073 L .72253 .67548 L p .707 .577 .707 r
F P
0 g
s
.25647 .68469 m .2616 .72191 L .23004 .72666 L p .707 .577 .707 r
F P
0 g
s
.42064 .74934 m .4243 .24786 L .46578 .24332 L p .707 .577 .707 r
F P
0 g
s
.4243 .24786 m .42085 .71973 L p .38668 .75716 L .707 .577 .707 r
F P
0 g
s
.46578 .24332 m .46212 .7448 L .42064 .74934 L p .707 .577 .707 r
F P
0 g
s
.42121 .55612 m .42893 .61195 L .45001 .60722 L p .707 .577 .707 r
F P
0 g
s
.45001 .60722 m .45809 .60541 L p .45244 .59785 L .707 .577 .707 r
F P
0 g
s
.45244 .59785 m .42121 .55612 L .45001 .60722 L .707 .577 .707 r
F
.42085 .71973 m .42064 .74934 L .4127 .75117 L p F P
0 g
s
.4127 .75117 m .38668 .75716 L p .42085 .71973 L .707 .577 .707 r
F P
0 g
s
.75409 .67073 m .75922 .70796 L .78838 .70143 L p .707 .577 .707 r
F P
0 g
s
.78838 .70143 m .78325 .66421 L .75409 .67073 L p .707 .577 .707 r
F P
0 g
s
.30474 .74469 m .30113 .76245 L .27056 .75446 L p .707 .577 .707 r
F P
0 g
s
.27056 .75446 m .27418 .7367 L .30474 .74469 L p .707 .577 .707 r
F P
0 g
s
.23928 .74974 m .24289 .73199 L .27418 .7367 L p .707 .577 .707 r
F P
0 g
s
.8173 .57876 m .82502 .63459 L .84134 .62652 L p .707 .577 .707 r
F P
0 g
s
.84134 .62652 m .83362 .57069 L .8173 .57876 L p .707 .577 .707 r
F P
0 g
s
.27418 .7367 m .27056 .75446 L .23928 .74974 L p .707 .577 .707 r
F P
0 g
s
.69679 .7152 m .69166 .67798 L .6645 .67799 L p .707 .577 .707 r
F P
0 g
s
.69166 .67798 m .69679 .7152 L .72766 .7127 L p .707 .577 .707 r
F P
0 g
s
.65386 .59779 m .66158 .65362 L .68236 .6561 L p .707 .577 .707 r
F P
0 g
s
.73602 .76569 m .73963 .74793 L .70906 .73994 L p .707 .577 .707 r
F P
0 g
s
.73963 .74793 m .73602 .76569 L .76731 .7704 L p .707 .577 .707 r
F P
0 g
s
.76731 .7704 m .77092 .75265 L .73963 .74793 L p .707 .577 .707 r
F P
0 g
s
.78325 .66421 m .78838 .70143 L .8123 .69375 L p .707 .577 .707 r
F P
0 g
s
.8123 .69375 m .80717 .65653 L .78325 .66421 L p .707 .577 .707 r
F P
0 g
s
.55473 .24552 m .55107 .74701 L .50706 .744 L p .707 .577 .707 r
F P
0 g
s
.50706 .744 m .51073 .24252 L .55473 .24552 L p .707 .577 .707 r
F P
0 g
s
.6645 .67799 m .66963 .71521 L .69679 .7152 L p .707 .577 .707 r
F P
0 g
s
.77092 .75265 m .76731 .7704 L .79625 .77138 L p .707 .577 .707 r
F P
0 g
s
.79625 .77138 m .79987 .75363 L .77092 .75265 L p .707 .577 .707 r
F P
0 g
s
.70545 .7577 m .70906 .73994 L .68221 .72946 L p .707 .577 .707 r
F P
0 g
s
.70906 .73994 m .70545 .7577 L .73602 .76569 L p .707 .577 .707 r
F P
0 g
s
.46212 .7448 m .46578 .24332 L .51073 .24252 L p .707 .577 .707 r
F P
0 g
s
.51073 .24252 m .50706 .744 L .46212 .7448 L p .707 .577 .707 r
F P
0 g
s
.66158 .65362 m .65386 .59779 L .64149 .59307 L p .707 .577 .707 r
F P
0 g
s
.68221 .72946 m .6786 .74721 L .70545 .7577 L p .707 .577 .707 r
F P
0 g
s
.66963 .71521 m .6645 .67799 L .64372 .67551 L p .707 .577 .707 r
F P
0 g
s
.79987 .75363 m .79625 .77138 L .82003 .76853 L p .707 .577 .707 r
F P
0 g
s
.82003 .76853 m .82364 .75078 L .79987 .75363 L p .707 .577 .707 r
F P
0 g
s
.6786 .74721 m .68221 .72946 L .6617 .71751 L p .707 .577 .707 r
F P
0 g
s
.80717 .65653 m .8123 .69375 L .82862 .68569 L p .707 .577 .707 r
F P
0 g
s
.82862 .68569 m .82349 .64847 L .80717 .65653 L p .707 .577 .707 r
F P
0 g
s
.64372 .67551 m .64885 .71273 L .66963 .71521 L p .707 .577 .707 r
F P
0 g
s
.83362 .57069 m .84134 .62652 L .84847 .61885 L p .707 .577 .707 r
F P
0 g
s
.84847 .61885 m .84075 .56302 L .83362 .57069 L p .707 .577 .707 r
F P
0 g
s
.64149 .59307 m .64921 .6489 L .66158 .65362 L p .707 .577 .707 r
F P
0 g
s
.6617 .71751 m .65809 .73527 L .6786 .74721 L p .707 .577 .707 r
F P
0 g
s
.64921 .6489 m .64149 .59307 L .63874 .58656 L p .707 .577 .707 r
F P
0 g
s
.82364 .75078 m .82003 .76853 L .8363 .76213 L p .707 .577 .707 r
F P
0 g
s
.8363 .76213 m .83991 .74437 L .82364 .75078 L p .707 .577 .707 r
F P
0 g
s
.65809 .73527 m .6617 .71751 L .64955 .70527 L p .707 .577 .707 r
F P
0 g
s
.82349 .64847 m .82862 .68569 L .83575 .67802 L p .707 .577 .707 r
F P
0 g
s
.83575 .67802 m .83062 .6408 L .82349 .64847 L p .707 .577 .707 r
F P
0 g
s
.64955 .70527 m .64593 .72302 L .65809 .73527 L p .707 .577 .707 r
F P
0 g
s
.84075 .56302 m .84847 .61885 L .84571 .61234 L p .707 .577 .707 r
F P
0 g
s
.84571 .61234 m .838 .55651 L .84075 .56302 L p .707 .577 .707 r
F P
0 g
s
.63874 .58656 m .64645 .64239 L .64921 .6489 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .63135 .67077 L .62859 .66425 L p .707 .577 .707 r
F P
0 g
s
.83991 .74437 m .8363 .76213 L .84348 .7528 L p .707 .577 .707 r
F P
0 g
s
.84348 .7528 m .84709 .73504 L .83991 .74437 L p .707 .577 .707 r
F P
0 g
s
.64593 .72302 m .64955 .70527 L .64693 .69392 L p .707 .577 .707 r
F P
0 g
s
.64645 .64239 m .63874 .58656 L .64587 .57889 L p .707 .577 .707 r
F P
0 g
s
.62859 .66425 m .63372 .70147 L .63648 .70799 L p .707 .577 .707 r
F P
0 g
s
.64693 .69392 m .64332 .71168 L .64593 .72302 L p .707 .577 .707 r
F P
0 g
s
.83062 .6408 m .83575 .67802 L .83299 .6715 L p .707 .577 .707 r
F P
0 g
s
.83299 .6715 m .82786 .63428 L .83062 .6408 L p .707 .577 .707 r
F P
0 g
s
.838 .55651 m .84571 .61234 L .83334 .60762 L p .707 .577 .707 r
F P
0 g
s
.83334 .60762 m .82562 .55178 L .838 .55651 L p .707 .577 .707 r
F P
0 g
s
.64587 .57889 m .65358 .63472 L .64645 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39737 .61671 m .38965 .56088 L .35879 .56339 L p .707 .577 .707 r
F P
0 g
s
.38965 .56088 m .39737 .61671 L .42893 .61195 L p .707 .577 .707 r
F P
0 g
s
.42893 .61195 m .42121 .55612 L .38965 .56088 L p .707 .577 .707 r
F P
0 g
s
.45809 .60541 m .45038 .54958 L .42121 .55612 L p .707 .577 .707 r
F P
0 g
s
.84709 .73504 m .84348 .7528 L .84086 .74146 L p .707 .577 .707 r
F P
0 g
s
.84086 .74146 m .84448 .7237 L .84709 .73504 L p .707 .577 .707 r
F P
0 g
s
.63372 .70147 m .62859 .66425 L .63572 .65659 L p .707 .577 .707 r
F P
0 g
s
.64332 .71168 m .64693 .69392 L .65411 .68459 L p .707 .577 .707 r
F P
0 g
s
.65358 .63472 m .64587 .57889 L .66219 .57082 L p .707 .577 .707 r
F P
0 g
s
.3665 .61922 m .35879 .56339 L .33163 .56341 L p .707 .577 .707 r
F P
0 g
s
.35879 .56339 m .3665 .61922 L .39737 .61671 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65411 .68459 m .65049 .70235 L .64332 .71168 L p .707 .577 .707 r
F P
0 g
s
.63572 .65659 m .64085 .69381 L .63372 .70147 L p .707 .577 .707 r
F P
0 g
s
.45038 .54958 m .45809 .60541 L .48201 .59773 L p .707 .577 .707 r
F P
0 g
s
.48201 .59773 m .47429 .5419 L .45038 .54958 L p .707 .577 .707 r
F P
0 g
s
.82786 .63428 m .83299 .6715 L .82062 .66677 L p .707 .577 .707 r
F P
0 g
s
.82062 .66677 m .81549 .62955 L .82786 .63428 L p .707 .577 .707 r
F P
0 g
s
.82562 .55178 m .83334 .60762 L .81256 .60514 L p .707 .577 .707 r
F P
0 g
s
.81256 .60514 m .80484 .54931 L .82562 .55178 L p .707 .577 .707 r
F P
0 g
s
.66219 .57082 m .6699 .62665 L .65358 .63472 L p .707 .577 .707 r
F P
0 g
s
.33163 .56341 m .33935 .61924 L .3665 .61922 L p .707 .577 .707 r
F P
0 g
s
.33935 .61924 m .33163 .56341 L .31085 .56094 L p .707 .577 .707 r
F P
0 g
s
.38465 .67578 m .37952 .63856 L .34865 .64106 L p .707 .577 .707 r
F P
0 g
s
.37952 .63856 m .38465 .67578 L .41621 .67104 L p .707 .577 .707 r
F P
0 g
s
.41621 .67104 m .41108 .63381 L .37952 .63856 L p .707 .577 .707 r
F P
0 g
s
.41108 .63381 m .41621 .67104 L .44537 .66451 L p .707 .577 .707 r
F P
0 g
s
.44537 .66451 m .44024 .62729 L .41108 .63381 L p .707 .577 .707 r
F P
0 g
s
.84448 .7237 m .84086 .74146 L .8287 .72922 L p .707 .577 .707 r
F P
0 g
s
.8287 .72922 m .83232 .71146 L .84448 .7237 L p .707 .577 .707 r
F P
0 g
s
.47429 .5419 m .48201 .59773 L .49833 .58967 L p .707 .577 .707 r
F P
0 g
s
.49833 .58967 m .49061 .53384 L .47429 .5419 L p .707 .577 .707 r
F P
0 g
s
.64085 .69381 m .63572 .65659 L .65204 .64852 L p .707 .577 .707 r
F P
0 g
s
.65049 .70235 m .65411 .68459 L .67038 .67819 L p .707 .577 .707 r
F P
0 g
s
.6699 .62665 m .66219 .57082 L .6861 .56314 L p .707 .577 .707 r
F P
0 g
s
.35378 .67828 m .34865 .64106 L .32149 .64107 L p .707 .577 .707 r
F P
0 g
s
.34865 .64106 m .35378 .67828 L .38465 .67578 L p .707 .577 .707 r
F P
0 g
s
.31085 .56094 m .31857 .61677 L .33935 .61924 L p .707 .577 .707 r
F P
0 g
s
.44024 .62729 m .44537 .66451 L .46929 .65683 L p .707 .577 .707 r
F P
0 g
s
.46929 .65683 m .46416 .61961 L .44024 .62729 L p .707 .577 .707 r
F P
0 g
s
.39301 .72931 m .39662 .71156 L .36605 .70356 L p .707 .577 .707 r
F P
0 g
s
.39662 .71156 m .39301 .72931 L .4243 .73403 L p .707 .577 .707 r
F P
0 g
s
.4243 .73403 m .42791 .71627 L .39662 .71156 L p .707 .577 .707 r
F P
0 g
s
.67038 .67819 m .66677 .69595 L .65049 .70235 L p .707 .577 .707 r
F P
0 g
s
.65204 .64852 m .65717 .68574 L .64085 .69381 L p .707 .577 .707 r
F P
0 g
s
.80484 .54931 m .81256 .60514 L .78541 .60516 L p .707 .577 .707 r
F P
0 g
s
.78541 .60516 m .77769 .54933 L .80484 .54931 L p .707 .577 .707 r
F P
0 g
s
.32149 .64107 m .32662 .67829 L .35378 .67828 L p .707 .577 .707 r
F P
0 g
s
.81549 .62955 m .82062 .66677 L .79984 .66428 L p .707 .577 .707 r
F P
0 g
s
.79984 .66428 m .79471 .62706 L .81549 .62955 L p .707 .577 .707 r
F P
0 g
s
.42791 .71627 m .4243 .73403 L .45324 .73501 L p .707 .577 .707 r
F P
0 g
s
.45324 .73501 m .45686 .71725 L .42791 .71627 L p .707 .577 .707 r
F P
0 g
s
.36244 .72132 m .36605 .70356 L .3392 .69308 L p .707 .577 .707 r
F P
0 g
s
.36605 .70356 m .36244 .72132 L .39301 .72931 L p .707 .577 .707 r
F P
0 g
s
.6861 .56314 m .69382 .61898 L .6699 .62665 L p .707 .577 .707 r
F P
0 g
s
.31857 .61677 m .31085 .56094 L .29848 .55622 L p .707 .577 .707 r
F P
0 g
s
.3392 .69308 m .33559 .71084 L .36244 .72132 L p .707 .577 .707 r
F P
0 g
s
.32662 .67829 m .32149 .64107 L .30071 .63859 L p .707 .577 .707 r
F P
0 g
s
.69382 .61898 m .6861 .56314 L .71526 .55661 L p .707 .577 .707 r
F P
0 g
s
.45686 .71725 m .45324 .73501 L .47702 .73216 L p .707 .577 .707 r
F P
0 g
s
.47702 .73216 m .48063 .7144 L .45686 .71725 L p .707 .577 .707 r
F P
0 g
s
.33559 .71084 m .3392 .69308 L .31869 .68113 L p .707 .577 .707 r
F P
0 g
s
.77769 .54933 m .78541 .60516 L .75454 .60768 L p .707 .577 .707 r
F P
0 g
s
.75454 .60768 m .74682 .55185 L .77769 .54933 L p .707 .577 .707 r
F P
0 g
s
.46416 .61961 m .46929 .65683 L .48561 .64877 L p .707 .577 .707 r
F P
0 g
s
.48561 .64877 m .48048 .61155 L .46416 .61961 L p .707 .577 .707 r
F P
0 g
s
.30071 .63859 m .30584 .67581 L .32662 .67829 L p .707 .577 .707 r
F P
0 g
s
.49061 .53384 m .49833 .58967 L .50546 .582 L p .707 .577 .707 r
F P
0 g
s
.50546 .582 m .49774 .52617 L .49061 .53384 L p .707 .577 .707 r
F P
0 g
s
.83232 .71146 m .8287 .72922 L .8082 .71727 L p .707 .577 .707 r
F P
0 g
s
.8082 .71727 m .81181 .69951 L .83232 .71146 L p .707 .577 .707 r
F P
0 g
s
.65717 .68574 m .65204 .64852 L .67596 .64085 L p .707 .577 .707 r
F P
0 g
s
.66677 .69595 m .67038 .67819 L .69416 .67534 L p .707 .577 .707 r
F P
0 g
s
.29848 .55622 m .3062 .61205 L .31857 .61677 L p .707 .577 .707 r
F P
0 g
s
.31869 .68113 m .31508 .69889 L .33559 .71084 L p .707 .577 .707 r
F P
0 g
s
.72298 .61244 m .71526 .55661 L .74682 .55185 L p .707 .577 .707 r
F P
0 g
s
.71526 .55661 m .72298 .61244 L .69382 .61898 L p .707 .577 .707 r
F P
0 g
s
.74682 .55185 m .75454 .60768 L .72298 .61244 L p .707 .577 .707 r
F P
0 g
s
.69416 .67534 m .69054 .6931 L .66677 .69595 L p .707 .577 .707 r
F P
0 g
s
.79471 .62706 m .79984 .66428 L .77268 .66429 L p .707 .577 .707 r
F P
0 g
s
.77268 .66429 m .76755 .62707 L .79471 .62706 L p .707 .577 .707 r
F P
0 g
s
.67596 .64085 m .68109 .67807 L .65717 .68574 L p .707 .577 .707 r
F P
0 g
s
.30584 .67581 m .30071 .63859 L .28834 .63385 L p .707 .577 .707 r
F P
0 g
s
.3062 .61205 m .29848 .55622 L .29572 .5497 L p .707 .577 .707 r
F P
0 g
s
.48063 .7144 m .47702 .73216 L .49329 .72576 L p .707 .577 .707 r
F P
0 g
s
.49329 .72576 m .4969 .708 L .48063 .7144 L p .707 .577 .707 r
F P
0 g
s
.68109 .67807 m .67596 .64085 L .70512 .63432 L p .707 .577 .707 r
F P
0 g
s
.31508 .69889 m .31869 .68113 L .30654 .66889 L p .707 .577 .707 r
F P
0 g
s
.81181 .69951 m .8082 .71727 L .78134 .70679 L p .707 .577 .707 r
F P
0 g
s
.78134 .70679 m .78496 .68903 L .81181 .69951 L p .707 .577 .707 r
F P
0 g
s
.69054 .6931 m .69416 .67534 L .7231 .67632 L p .707 .577 .707 r
F P
0 g
s
.28834 .63385 m .29347 .67107 L .30584 .67581 L p .707 .577 .707 r
F P
0 g
s
.76755 .62707 m .77268 .66429 L .74181 .66679 L p .707 .577 .707 r
F P
0 g
s
.74181 .66679 m .73668 .62957 L .76755 .62707 L p .707 .577 .707 r
F P
0 g
s
.48048 .61155 m .48561 .64877 L .49274 .6411 L p .707 .577 .707 r
F P
0 g
s
.49274 .6411 m .48761 .60388 L .48048 .61155 L p .707 .577 .707 r
F P
0 g
s
.30654 .66889 m .30292 .68665 L .31508 .69889 L p .707 .577 .707 r
F P
0 g
s
.70512 .63432 m .71025 .67154 L .68109 .67807 L p .707 .577 .707 r
F P
0 g
s
.7231 .67632 m .71949 .69408 L .69054 .6931 L p .707 .577 .707 r
F P
0 g
s
.49774 .52617 m .50546 .582 L .5027 .57549 L p .707 .577 .707 r
F P
0 g
s
.5027 .57549 m .49499 .51966 L .49774 .52617 L p .707 .577 .707 r
F P
0 g
s
.29572 .5497 m .30344 .60553 L .3062 .61205 L p .707 .577 .707 r
F P
0 g
s
.71025 .67154 m .70512 .63432 L .73668 .62957 L p .707 .577 .707 r
F P
0 g
s
.73668 .62957 m .74181 .66679 L .71025 .67154 L p .707 .577 .707 r
F P
0 g
s
.78496 .68903 m .78134 .70679 L .75078 .69879 L p .707 .577 .707 r
F P
0 g
s
.75078 .69879 m .75439 .68104 L .78496 .68903 L p .707 .577 .707 r
F P
0 g
s
.71949 .69408 m .7231 .67632 L .75439 .68104 L p .707 .577 .707 r
F P
0 g
s
.75439 .68104 m .75078 .69879 L .71949 .69408 L p .707 .577 .707 r
F P
0 g
s
.29347 .67107 m .28834 .63385 L .28558 .62733 L p .707 .577 .707 r
F P
0 g
s
.4969 .708 m .49329 .72576 L .50047 .71643 L p .707 .577 .707 r
F P
0 g
s
.50047 .71643 m .50408 .69867 L .4969 .708 L p .707 .577 .707 r
F P
0 g
s
.30292 .68665 m .30654 .66889 L .30392 .65755 L p .707 .577 .707 r
F P
0 g
s
.30344 .60553 m .29572 .5497 L .30286 .54204 L p .707 .577 .707 r
F P
0 g
s
.28558 .62733 m .29071 .66455 L .29347 .67107 L p .707 .577 .707 r
F P
0 g
s
.30392 .65755 m .3003 .67531 L .30292 .68665 L p .707 .577 .707 r
F P
0 g
s
.48761 .60388 m .49274 .6411 L .48998 .63458 L p .707 .577 .707 r
F P
0 g
s
.48998 .63458 m .48485 .59736 L .48761 .60388 L p .707 .577 .707 r
F P
0 g
s
.49499 .51966 m .5027 .57549 L .49033 .57076 L p .707 .577 .707 r
F P
0 g
s
.49033 .57076 m .48261 .51493 L .49499 .51966 L p .707 .577 .707 r
F P
0 g
s
.30286 .54204 m .31057 .59787 L .30344 .60553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50408 .69867 m .50047 .71643 L .49785 .70508 L p .707 .577 .707 r
F P
0 g
s
.49785 .70508 m .50147 .68733 L .50408 .69867 L p .707 .577 .707 r
F P
0 g
s
.29071 .66455 m .28558 .62733 L .29271 .61966 L p .707 .577 .707 r
F P
0 g
s
.3003 .67531 m .30392 .65755 L .3111 .64822 L p .707 .577 .707 r
F P
0 g
s
.31057 .59787 m .30286 .54204 L .31918 .53397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3111 .64822 m .30748 .66598 L .3003 .67531 L p .707 .577 .707 r
F P
0 g
s
.29271 .61966 m .29784 .65689 L .29071 .66455 L p .707 .577 .707 r
F P
0 g
s
.48485 .59736 m .48998 .63458 L .47761 .62985 L p .707 .577 .707 r
F P
0 g
s
.47761 .62985 m .47248 .59263 L .48485 .59736 L p .707 .577 .707 r
F P
0 g
s
.48261 .51493 m .49033 .57076 L .46955 .56829 L p .707 .577 .707 r
F P
0 g
s
.46955 .56829 m .46183 .51246 L .48261 .51493 L p .707 .577 .707 r
F P
0 g
s
.31918 .53397 m .32689 .5898 L .31057 .59787 L p .707 .577 .707 r
F P
0 g
s
.50147 .68733 m .49785 .70508 L .48569 .69284 L p .707 .577 .707 r
F P
0 g
s
.48569 .69284 m .48931 .67508 L .50147 .68733 L p .707 .577 .707 r
F P
0 g
s
.29784 .65689 m .29271 .61966 L .30903 .6116 L p .707 .577 .707 r
F P
0 g
s
.30748 .66598 m .3111 .64822 L .32737 .64182 L p .707 .577 .707 r
F P
0 g
s
.32689 .5898 m .31918 .53397 L .34309 .52629 L p .707 .577 .707 r
F P
0 g
s
.32737 .64182 m .32376 .65957 L .30748 .66598 L p .707 .577 .707 r
F P
0 g
s
.30903 .6116 m .31416 .64882 L .29784 .65689 L p .707 .577 .707 r
F P
0 g
s
.46183 .51246 m .46955 .56829 L .4424 .56831 L p .707 .577 .707 r
F P
0 g
s
.4424 .56831 m .43468 .51248 L .46183 .51246 L p .707 .577 .707 r
F P
0 g
s
.47248 .59263 m .47761 .62985 L .45682 .62736 L p .707 .577 .707 r
F P
0 g
s
.45682 .62736 m .4517 .59014 L .47248 .59263 L p .707 .577 .707 r
F P
0 g
s
.34309 .52629 m .35081 .58212 L .32689 .5898 L p .707 .577 .707 r
F P
0 g
s
.35081 .58212 m .34309 .52629 L .37225 .51975 L p .707 .577 .707 r
F P
0 g
s
.43468 .51248 m .4424 .56831 L .41153 .57083 L p .707 .577 .707 r
F P
0 g
s
.41153 .57083 m .40381 .51499 L .43468 .51248 L p .707 .577 .707 r
F P
0 g
s
.48931 .67508 m .48569 .69284 L .46519 .68089 L p .707 .577 .707 r
F P
0 g
s
.46519 .68089 m .4688 .66314 L .48931 .67508 L p .707 .577 .707 r
F P
0 g
s
.31416 .64882 m .30903 .6116 L .33295 .60393 L p .707 .577 .707 r
F P
0 g
s
.32376 .65957 m .32737 .64182 L .35114 .63897 L p .707 .577 .707 r
F P
0 g
s
.37997 .57558 m .37225 .51975 L .40381 .51499 L p .707 .577 .707 r
F P
0 g
s
.37225 .51975 m .37997 .57558 L .35081 .58212 L p .707 .577 .707 r
F P
0 g
s
.40381 .51499 m .41153 .57083 L .37997 .57558 L p .707 .577 .707 r
F P
0 g
s
.35114 .63897 m .34753 .65672 L .32376 .65957 L p .707 .577 .707 r
F P
0 g
s
.4517 .59014 m .45682 .62736 L .42967 .62737 L p .707 .577 .707 r
F P
0 g
s
.42967 .62737 m .42454 .59015 L .4517 .59014 L p .707 .577 .707 r
F P
0 g
s
.33295 .60393 m .33808 .64115 L .31416 .64882 L p .707 .577 .707 r
F P
0 g
s
.33808 .64115 m .33295 .60393 L .36211 .5974 L p .707 .577 .707 r
F P
0 g
s
.4688 .66314 m .46519 .68089 L .43833 .67041 L p .707 .577 .707 r
F P
0 g
s
.43833 .67041 m .44195 .65265 L .4688 .66314 L p .707 .577 .707 r
F P
0 g
s
.34753 .65672 m .35114 .63897 L .38009 .63995 L p .707 .577 .707 r
F P
0 g
s
.42454 .59015 m .42967 .62737 L .3988 .62987 L p .707 .577 .707 r
F P
0 g
s
.3988 .62987 m .39367 .59265 L .42454 .59015 L p .707 .577 .707 r
F P
0 g
s
.36211 .5974 m .36724 .63462 L .33808 .64115 L p .707 .577 .707 r
F P
0 g
s
.38009 .63995 m .37648 .6577 L .34753 .65672 L p .707 .577 .707 r
F P
0 g
s
.36724 .63462 m .36211 .5974 L .39367 .59265 L p .707 .577 .707 r
F P
0 g
s
.39367 .59265 m .3988 .62987 L .36724 .63462 L p .707 .577 .707 r
F P
0 g
s
.44195 .65265 m .43833 .67041 L .40777 .66242 L p .707 .577 .707 r
F P
0 g
s
.40777 .66242 m .41138 .64466 L .44195 .65265 L p .707 .577 .707 r
F P
0 g
s
.37648 .6577 m .38009 .63995 L .41138 .64466 L p .707 .577 .707 r
F P
0 g
s
.41138 .64466 m .40777 .66242 L .37648 .6577 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1UYF0P002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001o
ogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo
001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002
FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009J
EP03001JEUYF009JEP03001JEUYF00MJEPl000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00UYF2P0015YF
00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00IGoo001TOol200000eYF000000050004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IGoo001TOol400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001POol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005aoo`@00003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005Yoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<006Eoo`00FGoo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EWoo
00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000KOolI000bOol005Aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8001Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P004goo10001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H0
05YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYF000^Ool005Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000QJEP03001JEUYF00AJEPD00004FUH00000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001EOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`04
001JEUYF0003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00@005YFFUH0009JEP05
001JEUYFFUH00006FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP0500000eYF
001JEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol2FUH30004FUH00`00FUIJ
EP03FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;7oo001FOol2FUH20005FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00D7oo1P0000AJEP00FUH000=JEP@000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000/Ool004Moo`T000AJEP05001JEP00001JEP0400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF6@000eYF00<007oo
Ool0:Woo0011Ool60004FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH0000002]oo`00?Goo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0
0003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00>Goo
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002]oo`00=goo0P0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0eYF0P00;7oo000eOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool003=o
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00@005YFFUIJEP8002eo
o`00<Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00AJEP03001JEUYF00D00003FUH005YF008002moo`00;goo0P000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH015YF40001UYF00<005YFFUH015YF00<005YFFUH00UYF10000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH0
15YF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00<Goo
000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP0@00000eYF001JEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000aOol002eoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0004FUH00`00FUIJEP03FUH50008FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH01000FUIJEUYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<0
05YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
10000UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH30002FUH00`00FUIJEP02FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJ
EP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080031oo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH01000FUH000001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00<7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF0P000eYF1@000eYF00@005YFFUIJEPP000AJEP03001JEUYF00MJEP04001JEUYF
FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH:0002FUH200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YF
FUH01`001UYF00<005YFFUH01EYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPl000=JEP03001JEUYF008002moo`00;Woo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH015YF1`001eYF0`0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF10000UYF00<005YFFUH01UYF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF009J
EPT0009oo`@00003FUH005YF00EJEPH00003FUH0000002moo`00;Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00@005YF001JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH00000008000MJEP03001JEUYF008000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEPH0009oo`T000EJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
02moo`00;Woo00<005YF000015YF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH015YF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP050007Ool500000eYF001J
EP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000_Ool002ioo`03001JEP0000AJEP03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEQL000MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF5@0000=JEP00FUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000^Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF2P000eYF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00UJEP8000IJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP03
001JEUYF009JEPL000IJEP03001JEUYF00AJEP03001JEUYF009JEP80031oo`00;Woo00@005YFFUH0
009JEP05001JEUYFFUH00007FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP02FUH01000FUIJEUYF
1P000UYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00@005YF000000=J
EP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02moo`00;goo0UYF0`0015YF00<005YFFUH0
1EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03
001JEP0000D0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP05001JEUYFFUH00002FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH01000
FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000
1EYF00<005YFFUH00P00<Woo000_Ool2FUH20005FUH01000FUIJEUYF1P001UYF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YF000015YF0P000UYF00<007oo00000UYF00<005YFFUH00eYF1P0015YF
00<005YFFUH02EYF00<005YFFUH00UYF0`000eYF00<005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUH0009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF0`00=7oo000_Ool015YF001JEP000eYF1P00
0eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1@000UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH015YF00@005YFFUIJEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEQD000AJEP03001JEUYF00MJEP04
001JEUYFFUH4000fOol002moo`80009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH00000FUH00P0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01`001UYF00<005YFFUH015YF0P00=Woo000_Ool200000eYF00000003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH01000FUIJEUYF
10001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP0000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEPD0009JEP03001JEUYF00EJEP<003Aoo`00<7oo0P001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00@005YFFUH003=oo`00;Woo0`001eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
25YF00<005YF00000`002EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF009JEPL000Ioo`8000=JEP03001JEUYF009JEP80035oo`00;7oo0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0P001eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000EJ
EP00001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH8000?Ool200000eYF001JEP05FUH00`00Oomoo`0^
Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEQD000=J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEQ00
00Ioo`<0011oo`8000IJEP8002moo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00<005YFFUH00`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP04001J
EUYFFUH20007Ool5000AOol20004FUH01000FUH00000;Goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000goo000000020002FUH00`00FUIJEP04FUH5
0002FUH00`00FUH000020006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0015YF1P0000=JEP00FUH00P002Goo1@004goo00@005YFFUH000AJEP03001oogoo02Yoo`00:Woo
00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P0000=oo`0000001`001UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000UYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00800004FUH00000000;Ool5
000DOol30004FUH00`00Oomoo`0ZOol002Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
01000003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF
00=JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00005FUH200000eYF
001oo`0;Ool3000GOol01000FUIJEUYF0P00;7oo000ZOol01000FUIJEP0015YF00<005YFFUH00eYF
1@0015YF2`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF200015YF00@005YFFUIJEPD000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP8000EJEP03001JEP00008002Ioo`03001JEUYF
008002aoo`00:Woo00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYF
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool0:goo000[
Ool00`00FUH00003FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF0`000UYF00<005YFFUH01EYF10008Woo00<005YF0000;7oo000[
Ool01000FUH005YF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF10001UYF00@005YF0000009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
0008FUH00`00FUIJEP04000NOol00`00FUH0000/Ool002]oo`05001JEP00001JEP020003FUH01000
FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP<000Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@005goo
1000;Goo000[Ool20002FUH20003FUH50003FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00@0
05YFFUIJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002FUH2000]Ool002]oo`80
009JEP800005FUH00000FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP070006FUH00`00FUIJEP05
FUH20005Ool01000FUIJEP001EYF00<005YFFUH010002UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<0
05YF00000P0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF000]Ool002]o
o`80009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP@0009JEP03001J
EUYF00IJEP<000=oo`04001JEUYF0005FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH>0002FUH60006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002aoo`03
001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPX000MJEP04001J
EUYF0002Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF0`001UYF00<005YFFUH00UYF
100017oo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00;Goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002Woo0P0015YF
00<005YFFUH00UYF0`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH30006FUH0
0`00FUIJEP03FUH30008Ool50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo
000^Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF1`0047oo0`0000=JEP00
FUH01EYF00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000EJEP00001JEP0000IJ
EP03001JEUYF009JEP03001JEP0000eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5000bOol0
02ioo`8000=JEPl000Ioo`<0015oo`8000IJEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP@00003FUH005YF00EJEP03001JEUYF009JEP80019oo`h003Moo`00;goo00@005YFFUIJEP<0
015oo`D0019oo`8000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP00
1UYF00<005YFFUH00UYF0P00Egoo000_Ool01@00FUIJEUYF00000UYF00<007ooOol03Woo1@0057oo
00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH01000
FUIJEUYF0P00F7oo000`Ool00`00FUH00004FUH2000>Ool5000EOol50004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH01000FUH00000FWoo000aOol20006FUH2000=Ool3000H
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF0080009J
EP<005aoo`00<Woo00<005YFFUH015YF00@005YF000002Moo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00009JEP04001JEUYFFUH2001OOol003=oo`8000AJEP04001JEUYFFUH3000U
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH2001M
Ool003Eoo`04001JEUYF0007FUH3000SOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30000
0eYF001JEP06FUH3001KOol003Ioo`<000QJEP03001JEP0000<001ioo`H000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009oo`<000IJEP03001JEUYF008005Uoo`00>7oo0P001eYF00<005YFFUH00eYF1`005Goo0P00
00=JEP0000000Woo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YF00000`001goo0P000eYF00<005YFFUH00eYF0P00Egoo000j
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool50003FUH20005Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH3000=
Ool200000eYF001JEP05FUH2001FOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH80003FUH01000FUIJEUYF0P002Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF1@0047oo0P001UYF00@005YF000005Aoo`00?goo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000moo`H0009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000800003Ool0000000<0015oo`80
00=JEP03001JEUYF009JEP03001oogoo055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8001Ioo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJ
EPL000Aoo`D001=oo`800003FUH005YF00=JEP03001oogoo055oo`00AWoo1`0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000021ooaX000]oo`D001Eoo`8000AJEP03001oogoo055oo`00
CGoo200015YF00@005YFFUIJEPD0035oo`8000EJEP04001JEP00000<Ool3000HOol00`00FUIJEP02
001COol005Eoo`P003Moo`03001JEUYF00=JEP04001JEUYFFUH3000UOol01000FUH00000Dgoo002E
Ool20002FUH00`00FUIJEP05FUH4000ROol3001COol009Moo`<000QJEP03001JEUYF00@001ioo`<0
05=oo`00VGoo0P001eYF00<005YFFUH015YF1@005goo1000E7oo002KOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP04000>Ool50002FUH2001DOol009eoo`<00003FUH005YF00QJEP03001JEUYF00AJ
EPh000=JEP06001JEUYF001JEP00E7oo002POol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001EOol00:Aoo`@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:Qoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEP00001GOol00:eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001IOol00;5o
o`h005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60719 .74291 m .59478 .68751 L .5644 .69274 L p .707 .577 .707 r
F P
0 g
s
.59478 .68751 m .60719 .74291 L .63831 .7357 L p .707 .577 .707 r
F P
0 g
s
.63831 .7357 m .62589 .68029 L .59478 .68751 L p .707 .577 .707 r
F P
0 g
s
.62589 .68029 m .63831 .7357 L .66712 .72721 L p .707 .577 .707 r
F P
0 g
s
.66712 .72721 m .6547 .67181 L .62589 .68029 L p .707 .577 .707 r
F P
0 g
s
.57682 .74814 m .5644 .69274 L .53774 .69548 L p .707 .577 .707 r
F P
0 g
s
.5644 .69274 m .57682 .74814 L .60719 .74291 L p .707 .577 .707 r
F P
0 g
s
.6547 .67181 m .66712 .72721 L .69081 .71828 L p .707 .577 .707 r
F P
0 g
s
.69081 .71828 m .67839 .66288 L .6547 .67181 L p .707 .577 .707 r
F P
0 g
s
.53774 .69548 m .55016 .75088 L .57682 .74814 L p .707 .577 .707 r
F P
0 g
s
.55016 .75088 m .53774 .69548 L .51741 .69546 L p .707 .577 .707 r
F P
0 g
s
.58662 .80139 m .57837 .76446 L .54799 .76967 L p .707 .577 .707 r
F P
0 g
s
.57837 .76446 m .58662 .80139 L .61774 .7942 L p .707 .577 .707 r
F P
0 g
s
.61774 .7942 m .60949 .75726 L .57837 .76446 L p .707 .577 .707 r
F P
0 g
s
.60949 .75726 m .61774 .7942 L .64655 .78573 L p .707 .577 .707 r
F P
0 g
s
.64655 .78573 m .6383 .74879 L .60949 .75726 L p .707 .577 .707 r
F P
0 g
s
.67839 .66288 m .69081 .71828 L .70705 .70978 L p .707 .577 .707 r
F P
0 g
s
.70705 .70978 m .69463 .65438 L .67839 .66288 L p .707 .577 .707 r
F P
0 g
s
.54799 .76967 m .55624 .80661 L .58662 .80139 L p .707 .577 .707 r
F P
0 g
s
.51741 .69546 m .52982 .75087 L .55016 .75088 L p .707 .577 .707 r
F P
0 g
s
.55624 .80661 m .54799 .76967 L .52132 .77239 L p .707 .577 .707 r
F P
0 g
s
.59991 .86109 m .60569 .84418 L .5761 .8326 L p .707 .577 .707 r
F P
0 g
s
.60569 .84418 m .59991 .86109 L .63032 .86904 L p .707 .577 .707 r
F P
0 g
s
.63032 .86904 m .6361 .85213 L .60569 .84418 L p .707 .577 .707 r
F P
0 g
s
.6383 .74879 m .64655 .78573 L .67024 .77681 L p .707 .577 .707 r
F P
0 g
s
.67024 .77681 m .66199 .73987 L .6383 .74879 L p .707 .577 .707 r
F P
0 g
s
.57031 .84951 m .5761 .8326 L .55022 .81853 L p .707 .577 .707 r
F P
0 g
s
.5761 .8326 m .57031 .84951 L .59991 .86109 L p .707 .577 .707 r
F P
0 g
s
.52132 .77239 m .52958 .80933 L .55624 .80661 L p .707 .577 .707 r
F P
0 g
s
.6361 .85213 m .63032 .86904 L .65857 .87259 L p .707 .577 .707 r
F P
0 g
s
.65857 .87259 m .66435 .85568 L .6361 .85213 L p .707 .577 .707 r
F P
0 g
s
.55022 .81853 m .54444 .83544 L .57031 .84951 L p .707 .577 .707 r
F P
0 g
s
.52982 .75087 m .51741 .69546 L .50539 .69269 L p .707 .577 .707 r
F P
0 g
s
.52958 .80933 m .52132 .77239 L .50098 .77235 L p .707 .577 .707 r
F P
0 g
s
.54444 .83544 m .55022 .81853 L .53059 .80335 L p .707 .577 .707 r
F P
0 g
s
.69463 .65438 m .70705 .70978 L .71426 .70255 L p .707 .577 .707 r
F P
0 g
s
.71426 .70255 m .70184 .64715 L .69463 .65438 L p .707 .577 .707 r
F P
0 g
s
.66435 .85568 m .65857 .87259 L .6819 .87139 L p .707 .577 .707 r
F P
0 g
s
.6819 .87139 m .68768 .85448 L .66435 .85568 L p .707 .577 .707 r
F P
0 g
s
.66199 .73987 m .67024 .77681 L .68649 .76831 L p .707 .577 .707 r
F P
0 g
s
.68649 .76831 m .67823 .73138 L .66199 .73987 L p .707 .577 .707 r
F P
0 g
s
.50539 .69269 m .5178 .74809 L .52982 .75087 L p .707 .577 .707 r
F P
0 g
s
.50098 .77235 m .50924 .80929 L .52958 .80933 L p .707 .577 .707 r
F P
0 g
s
.53059 .80335 m .5248 .82026 L .54444 .83544 L p .707 .577 .707 r
F P
0 g
s
.5248 .82026 m .53059 .80335 L .51912 .78853 L p .707 .577 .707 r
F P
0 g
s
.50924 .80929 m .50098 .77235 L .48896 .76956 L p .707 .577 .707 r
F P
0 g
s
.5178 .74809 m .50539 .69269 L .50286 .68742 L p .707 .577 .707 r
F P
0 g
s
.68768 .85448 m .6819 .87139 L .69802 .86556 L p .707 .577 .707 r
F P
0 g
s
.69802 .86556 m .7038 .84865 L .68768 .85448 L p .707 .577 .707 r
F P
0 g
s
.51912 .78853 m .51334 .80544 L .5248 .82026 L p .707 .577 .707 r
F P
0 g
s
.48896 .76956 m .49721 .8065 L .50924 .80929 L p .707 .577 .707 r
F P
0 g
s
.67823 .73138 m .68649 .76831 L .69369 .76108 L p .707 .577 .707 r
F P
0 g
s
.69369 .76108 m .68544 .72414 L .67823 .73138 L p .707 .577 .707 r
F P
0 g
s
.70184 .64715 m .71426 .70255 L .71173 .69729 L p .707 .577 .707 r
F P
0 g
s
.71173 .69729 m .69931 .64188 L .70184 .64715 L p .707 .577 .707 r
F P
0 g
s
.50286 .68742 m .51527 .74283 L .5178 .74809 L p .707 .577 .707 r
F P
0 g
s
.51334 .80544 m .51912 .78853 L .51695 .77554 L p .707 .577 .707 r
F P
0 g
s
.49721 .8065 m .48896 .76956 L .48643 .76429 L p .707 .577 .707 r
F P
0 g
s
.48643 .76429 m .49468 .80122 L .49721 .8065 L p .707 .577 .707 r
F P
0 g
s
.49468 .80122 m .48643 .76429 L .49364 .75705 L p .707 .577 .707 r
F P
0 g
s
.48638 .82191 m .49231 .3207 L .44831 .31749 L p .707 .577 .707 r
F P
0 g
s
.51695 .77554 m .51117 .79245 L .51334 .80544 L p .707 .577 .707 r
F P
0 g
s
.51527 .74283 m .50286 .68742 L .51007 .68019 L p .707 .577 .707 r
F P
0 g
s
.51007 .68019 m .52248 .73559 L .51527 .74283 L p .707 .577 .707 r
F P
0 g
s
.51117 .79245 m .51695 .77554 L .52429 .76565 L p .707 .577 .707 r
F P
0 g
s
.52429 .76565 m .5185 .78256 L .51117 .79245 L p .707 .577 .707 r
F P
0 g
s
.52248 .73559 m .51007 .68019 L .52631 .67169 L p .707 .577 .707 r
F P
0 g
s
.49364 .75705 m .50189 .79399 L .49468 .80122 L p .707 .577 .707 r
F P
0 g
s
.52631 .67169 m .53872 .72709 L .52248 .73559 L p .707 .577 .707 r
F P
0 g
s
.5185 .78256 m .52429 .76565 L .54041 .75981 L p .707 .577 .707 r
F P
0 g
s
.54041 .75981 m .53462 .77672 L .5185 .78256 L p .707 .577 .707 r
F P
0 g
s
.50189 .79399 m .49364 .75705 L .50988 .74855 L p .707 .577 .707 r
F P
0 g
s
.50988 .74855 m .51813 .78549 L .50189 .79399 L p .707 .577 .707 r
F P
0 g
s
.51813 .78549 m .50988 .74855 L .53357 .73964 L p .707 .577 .707 r
F P
0 g
s
.53462 .77672 m .54041 .75981 L .56373 .75861 L p .707 .577 .707 r
F P
0 g
s
.56373 .75861 m .55795 .77552 L .53462 .77672 L p .707 .577 .707 r
F P
0 g
s
.53357 .73964 m .54182 .77657 L .51813 .78549 L p .707 .577 .707 r
F P
0 g
s
.49231 .3207 m .48638 .82191 L .53132 .82129 L p .707 .577 .707 r
F P
0 g
s
.53872 .72709 m .52631 .67169 L .55 .66276 L p .707 .577 .707 r
F P
0 g
s
.53132 .82129 m .53725 .32007 L .49231 .3207 L p .707 .577 .707 r
F P
0 g
s
.55 .66276 m .56241 .71816 L .53872 .72709 L p .707 .577 .707 r
F P
0 g
s
.56241 .71816 m .55 .66276 L .57881 .65428 L p .707 .577 .707 r
F P
0 g
s
.57881 .65428 m .59122 .70968 L .56241 .71816 L p .707 .577 .707 r
F P
0 g
s
.55795 .77552 m .56373 .75861 L .59198 .76216 L p .707 .577 .707 r
F P
0 g
s
.59198 .76216 m .5862 .77907 L .55795 .77552 L p .707 .577 .707 r
F P
0 g
s
.54182 .77657 m .53357 .73964 L .56238 .73116 L p .707 .577 .707 r
F P
0 g
s
.56238 .73116 m .57063 .7681 L .54182 .77657 L p .707 .577 .707 r
F P
0 g
s
.57063 .7681 m .56238 .73116 L .5935 .72397 L p .707 .577 .707 r
F P
0 g
s
.53725 .32007 m .53132 .82129 L .5728 .81689 L p .707 .577 .707 r
F P
0 g
s
.5862 .77907 m .59198 .76216 L .6224 .77011 L p .707 .577 .707 r
F P
0 g
s
.5935 .72397 m .60175 .76091 L .57063 .7681 L p .707 .577 .707 r
F P
0 g
s
.5728 .81689 m .57873 .31568 L .53725 .32007 L p .707 .577 .707 r
F P
0 g
s
.7038 .84865 m .69802 .86556 L .70535 .85566 L p .707 .577 .707 r
F P
0 g
s
.70535 .85566 m .71113 .83875 L .7038 .84865 L p .707 .577 .707 r
F P
0 g
s
.44238 .8187 m .44831 .31749 L .40955 .31076 L p .707 .577 .707 r
F P
0 g
s
.44831 .31749 m .44238 .8187 L .48638 .82191 L p .707 .577 .707 r
F P
0 g
s
.68544 .72414 m .69369 .76108 L .69116 .7558 L p .707 .577 .707 r
F P
0 g
s
.69116 .7558 m .68291 .71887 L .68544 .72414 L p .707 .577 .707 r
F P
0 g
s
.69931 .64188 m .71173 .69729 L .69971 .69451 L p .707 .577 .707 r
F P
0 g
s
.69971 .69451 m .68729 .63911 L .69931 .64188 L p .707 .577 .707 r
F P
0 g
s
.59122 .70968 m .57881 .65428 L .60992 .64706 L p .707 .577 .707 r
F P
0 g
s
.60992 .64706 m .62234 .70247 L .59122 .70968 L p .707 .577 .707 r
F P
0 g
s
.62388 .71876 m .63213 .7557 L .60175 .76091 L p .707 .577 .707 r
F P
0 g
s
.60175 .76091 m .5935 .72397 L .62388 .71876 L p .707 .577 .707 r
F P
0 g
s
.6224 .77011 m .61661 .78702 L .5862 .77907 L p .707 .577 .707 r
F P
0 g
s
.57873 .31568 m .5728 .81689 L .60676 .80916 L p .707 .577 .707 r
F P
0 g
s
.60676 .80916 m .61269 .30795 L .57873 .31568 L p .707 .577 .707 r
F P
0 g
s
.26418 .70603 m .25177 .65063 L .2214 .65587 L p .707 .577 .707 r
F P
0 g
s
.25177 .65063 m .26418 .70603 L .2953 .69882 L p .707 .577 .707 r
F P
0 g
s
.2953 .69882 m .28289 .64342 L .25177 .65063 L p .707 .577 .707 r
F P
0 g
s
.28289 .64342 m .2953 .69882 L .32411 .69033 L p .707 .577 .707 r
F P
0 g
s
.32411 .69033 m .3117 .63493 L .28289 .64342 L p .707 .577 .707 r
F P
0 g
s
.40361 .81197 m .40955 .31076 L .37982 .30117 L p .707 .577 .707 r
F P
0 g
s
.40955 .31076 m .40361 .81197 L .44238 .8187 L p .707 .577 .707 r
F P
0 g
s
.71113 .83875 m .70535 .85566 L .70318 .84267 L p .707 .577 .707 r
F P
0 g
s
.70318 .84267 m .70896 .82576 L .71113 .83875 L p .707 .577 .707 r
F P
0 g
s
.23381 .71127 m .2214 .65587 L .19474 .65861 L p .707 .577 .707 r
F P
0 g
s
.2214 .65587 m .23381 .71127 L .26418 .70603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3117 .63493 m .32411 .69033 L .3478 .68141 L p .707 .577 .707 r
F P
0 g
s
.3478 .68141 m .33538 .626 L .3117 .63493 L p .707 .577 .707 r
F P
0 g
s
.68291 .71887 m .69116 .7558 L .67914 .75301 L p .707 .577 .707 r
F P
0 g
s
.67914 .75301 m .67089 .71607 L .68291 .71887 L p .707 .577 .707 r
F P
0 g
s
.68729 .63911 m .69971 .69451 L .67937 .69449 L p .707 .577 .707 r
F P
0 g
s
.67937 .69449 m .66696 .63909 L .68729 .63911 L p .707 .577 .707 r
F P
0 g
s
.19474 .65861 m .20715 .71401 L .23381 .71127 L p .707 .577 .707 r
F P
0 g
s
.6403 .64183 m .65271 .69723 L .62234 .70247 L p .707 .577 .707 r
F P
0 g
s
.62234 .70247 m .60992 .64706 L .6403 .64183 L p .707 .577 .707 r
F P
0 g
s
.63213 .7557 m .62388 .71876 L .65055 .71604 L p .707 .577 .707 r
F P
0 g
s
.65199 .78169 m .64621 .7986 L .61661 .78702 L p .707 .577 .707 r
F P
0 g
s
.61661 .78702 m .6224 .77011 L .65199 .78169 L p .707 .577 .707 r
F P
0 g
s
.61269 .30795 m .60676 .80916 L .62986 .79884 L p .707 .577 .707 r
F P
0 g
s
.62986 .79884 m .6358 .29763 L .61269 .30795 L p .707 .577 .707 r
F P
0 g
s
.20715 .71401 m .19474 .65861 L .1744 .65859 L p .707 .577 .707 r
F P
0 g
s
.24361 .76441 m .23536 .72747 L .20498 .73268 L p .707 .577 .707 r
F P
0 g
s
.23536 .72747 m .24361 .76441 L .27473 .75721 L p .707 .577 .707 r
F P
0 g
s
.27473 .75721 m .26648 .72028 L .23536 .72747 L p .707 .577 .707 r
F P
0 g
s
.26648 .72028 m .27473 .75721 L .30354 .74874 L p .707 .577 .707 r
F P
0 g
s
.30354 .74874 m .29529 .71181 L .26648 .72028 L p .707 .577 .707 r
F P
0 g
s
.33538 .626 m .3478 .68141 L .36404 .67291 L p .707 .577 .707 r
F P
0 g
s
.36404 .67291 m .35162 .61751 L .33538 .626 L p .707 .577 .707 r
F P
0 g
s
.35162 .61751 m .36404 .67291 L .36679 .67014 L p .707 .577 .707 r
F P
0 g
s
.36679 .67014 m .37125 .66567 L p .36586 .65245 L .707 .577 .707 r
F P
0 g
s
.36586 .65245 m .35162 .61751 L .36679 .67014 L .707 .577 .707 r
F
.36205 .28967 m .35796 .27736 L p .3572 .48808 L F P
0 g
s
.37125 .66567 m .35883 .61027 L .35162 .61751 L p .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .35883 .61027 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.36872 .66041 m .3622 .63133 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .3563 .60501 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .3622 .63133 L p .3567 .65763 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .36872 .66041 L .36019 .65844 L p .707 .577 .707 r
F P
0 g
s
.36019 .65844 m .3567 .65763 L p .3622 .63133 L .707 .577 .707 r
F P
0 g
s
.3567 .65763 m .34428 .60223 L .3563 .60501 L p .707 .577 .707 r
F P
0 g
s
.34428 .60223 m .3567 .65763 L .33636 .65761 L p .707 .577 .707 r
F P
0 g
s
.35641 .70954 m .35924 .52677 L .3572 .48808 L .707 .577 .707 r
F
.36595 .78966 m .36017 .80657 L .36012 .8065 L p F P
0 g
s
.36012 .8065 m .34871 .79176 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.35942 .79045 m .36595 .78966 L .36012 .8065 L .707 .577 .707 r
F
.35637 .72066 m .35721 .69877 L .35641 .70954 L F
.34871 .79176 m .35449 .77485 L .35899 .78066 L p F P
0 g
s
.35899 .78066 m .36595 .78966 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.34871 .79176 m .35899 .78066 L .35942 .79045 L .707 .577 .707 r
F
.35449 .77485 m .34871 .79176 L .34056 .78546 L p F P
0 g
s
.34056 .78546 m .32908 .77657 L p .34105 .77576 L .707 .577 .707 r
F P
0 g
s
.34105 .77576 m .35449 .77485 L .34056 .78546 L .707 .577 .707 r
F
.35637 .72066 m .35674 .61823 L .35479 .68453 L F
.32908 .77657 m .33486 .75966 L .35449 .77485 L p F P
0 g
s
.35637 .72066 m .35479 .68453 L .35203 .77858 L .707 .577 .707 r
F
.35721 .69877 m .35924 .52677 L p .35641 .70954 L F P
0 g
s
.35796 .27736 m .354 .61168 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.354 .61168 m .35203 .77858 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.35924 .52677 m .36205 .28967 L p .3572 .48808 L .707 .577 .707 r
F P
0 g
s
.35883 .61027 m .37125 .66567 L .36872 .66041 L p .707 .577 .707 r
F P
0 g
s
.37389 .80239 m .37982 .30117 L .36205 .28967 L p .707 .577 .707 r
F P
0 g
s
.36017 .80657 m .36595 .78966 L .36812 .80265 L p .707 .577 .707 r
F P
0 g
s
.36205 .28967 m .35612 .79088 L .37389 .80239 L p .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35551 .48431 L p .36796 .26547 L .707 .577 .707 r
F P
0 g
s
.35551 .48431 m .35796 .27736 L .36627 .26748 L p .707 .577 .707 r
F P
0 g
s
.36627 .26748 m .36796 .26547 L p .35551 .48431 L .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35612 .79088 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35612 .79088 m .35682 .73109 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35682 .73109 m .35721 .69877 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.37982 .30117 m .37389 .80239 L .40361 .81197 L p .707 .577 .707 r
F P
0 g
s
.70896 .82576 m .70318 .84267 L .69172 .82786 L p .707 .577 .707 r
F P
0 g
s
.69172 .82786 m .6975 .81095 L .70896 .82576 L p .707 .577 .707 r
F P
0 g
s
.20498 .73268 m .21323 .76962 L .24361 .76441 L p .707 .577 .707 r
F P
0 g
s
.1744 .65859 m .18681 .71399 L .20715 .71401 L p .707 .577 .707 r
F P
0 g
s
.21323 .76962 m .20498 .73268 L .17831 .7354 L p .707 .577 .707 r
F P
0 g
s
.2569 .82499 m .26268 .80808 L .23309 .7965 L p .707 .577 .707 r
F P
0 g
s
.26268 .80808 m .2569 .82499 L .28731 .83294 L p .707 .577 .707 r
F P
0 g
s
.28731 .83294 m .29309 .81603 L .26268 .80808 L p .707 .577 .707 r
F P
0 g
s
.29529 .71181 m .30354 .74874 L .32723 .73982 L p .707 .577 .707 r
F P
0 g
s
.32723 .73982 m .31898 .70289 L .29529 .71181 L p .707 .577 .707 r
F P
0 g
s
.66696 .63909 m .67937 .69449 L .65271 .69723 L p .707 .577 .707 r
F P
0 g
s
.65271 .69723 m .6403 .64183 L .66696 .63909 L p .707 .577 .707 r
F P
0 g
s
.22731 .81341 m .23309 .7965 L .20721 .78243 L p .707 .577 .707 r
F P
0 g
s
.23309 .7965 m .22731 .81341 L .2569 .82499 L p .707 .577 .707 r
F P
0 g
s
.17831 .7354 m .18657 .77234 L .21323 .76962 L p .707 .577 .707 r
F P
0 g
s
.29309 .81603 m .28731 .83294 L .31556 .83649 L p .707 .577 .707 r
F P
0 g
s
.31556 .83649 m .32134 .81958 L .29309 .81603 L p .707 .577 .707 r
F P
0 g
s
.67089 .71607 m .67914 .75301 L .6588 .75297 L p .707 .577 .707 r
F P
0 g
s
.6588 .75297 m .65055 .71604 L .67089 .71607 L p .707 .577 .707 r
F P
0 g
s
.20721 .78243 m .20143 .79934 L .22731 .81341 L p .707 .577 .707 r
F P
0 g
s
.18681 .71399 m .1744 .65859 L .16238 .65581 L p .707 .577 .707 r
F P
0 g
s
.18657 .77234 m .17831 .7354 L .15797 .73537 L p .707 .577 .707 r
F P
0 g
s
.20143 .79934 m .20721 .78243 L .18758 .76725 L p .707 .577 .707 r
F P
0 g
s
.65055 .71604 m .6588 .75297 L .63213 .7557 L p .707 .577 .707 r
F P
0 g
s
.6358 .29763 m .62986 .79884 L .63987 .78695 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .6458 .28574 L .6358 .29763 L p .707 .577 .707 r
F P
0 g
s
.32134 .81958 m .31556 .83649 L .33889 .83529 L p .707 .577 .707 r
F P
0 g
s
.33889 .83529 m .34467 .81838 L .32134 .81958 L p .707 .577 .707 r
F P
0 g
s
.31898 .70289 m .32723 .73982 L .34348 .73133 L p .707 .577 .707 r
F P
0 g
s
.34348 .73133 m .33522 .69439 L .31898 .70289 L p .707 .577 .707 r
F P
0 g
s
.6975 .81095 m .69172 .82786 L .67209 .81267 L p .707 .577 .707 r
F P
0 g
s
.67209 .81267 m .67787 .79576 L .6975 .81095 L p .707 .577 .707 r
F P
0 g
s
.16238 .65581 m .17479 .71121 L .18681 .71399 L p .707 .577 .707 r
F P
0 g
s
.15797 .73537 m .16623 .7723 L .18657 .77234 L p .707 .577 .707 r
F P
0 g
s
.18758 .76725 m .18179 .78415 L .20143 .79934 L p .707 .577 .707 r
F P
0 g
s
.18179 .78415 m .18758 .76725 L .17611 .75243 L p .707 .577 .707 r
F P
0 g
s
.16623 .7723 m .15797 .73537 L .14595 .73257 L p .707 .577 .707 r
F P
0 g
s
.17479 .71121 m .16238 .65581 L .15985 .65055 L p .707 .577 .707 r
F P
0 g
s
.67787 .79576 m .67209 .81267 L .64621 .7986 L p .707 .577 .707 r
F P
0 g
s
.64621 .7986 m .65199 .78169 L .67787 .79576 L p .707 .577 .707 r
F P
0 g
s
.34467 .81838 m .33889 .83529 L .35501 .82946 L p .707 .577 .707 r
F P
0 g
s
.35501 .82946 m .36079 .81255 L .34467 .81838 L p .707 .577 .707 r
F P
0 g
s
.17611 .75243 m .17033 .76934 L .18179 .78415 L p .707 .577 .707 r
F P
0 g
s
.14595 .73257 m .1542 .76951 L .16623 .7723 L p .707 .577 .707 r
F P
0 g
s
.33522 .69439 m .34348 .73133 L .35069 .72409 L p .707 .577 .707 r
F P
0 g
s
.35069 .72409 m .34243 .68715 L .33522 .69439 L p .707 .577 .707 r
F P
0 g
s
.15985 .65055 m .17226 .70595 L .17479 .71121 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .63578 .77465 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64244 .56957 m .63987 .78695 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .6458 .28574 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.63578 .77465 m .6374 .63778 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.6374 .63778 m .64171 .27343 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .63578 .77465 L .618 .76314 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .64644 .71725 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.62616 .67752 m .6324 .70543 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.6324 .70543 m .63442 .71446 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63819 .68031 L .63432 .67942 L p .707 .577 .707 r
F P
0 g
s
.63432 .67942 m .62616 .67752 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63432 .67942 L .63341 .69172 L .707 .577 .707 r
F
.6458 .28574 m .64244 .56957 L p .63904 .61559 L F P
0 g
s
.17033 .76934 m .17611 .75243 L .17394 .73944 L p .707 .577 .707 r
F P
0 g
s
.1542 .76951 m .14595 .73257 L .14342 .7273 L p .707 .577 .707 r
F P
0 g
s
.17394 .73944 m .16816 .75635 L .17033 .76934 L p .707 .577 .707 r
F P
0 g
s
.36079 .81255 m .35501 .82946 L .36234 .81956 L p .707 .577 .707 r
F P
0 g
s
.36234 .81956 m .36812 .80265 L .36079 .81255 L p .707 .577 .707 r
F P
0 g
s
.17226 .70595 m .15985 .65055 L .16706 .64331 L p .707 .577 .707 r
F P
0 g
s
.14342 .7273 m .15167 .76424 L .1542 .76951 L p .707 .577 .707 r
F P
0 g
s
.34243 .68715 m .35069 .72409 L .34815 .71882 L p .707 .577 .707 r
F P
0 g
s
.34815 .71882 m .3399 .68188 L .34243 .68715 L p .707 .577 .707 r
F P
0 g
s
.16706 .64331 m .17947 .69872 L .17226 .70595 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16816 .75635 m .17394 .73944 L .18128 .72955 L p .707 .577 .707 r
F P
0 g
s
.18128 .72955 m .1755 .74645 L .16816 .75635 L p .707 .577 .707 r
F P
0 g
s
.36812 .80265 m .36234 .81956 L .36017 .80657 L p .707 .577 .707 r
F P
0 g
s
.15167 .76424 m .14342 .7273 L .15063 .72006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17947 .69872 m .16706 .64331 L .1833 .63482 L p .707 .577 .707 r
F P
0 g
s
.618 .76314 m .62393 .26193 L .64171 .27343 L p .707 .577 .707 r
F P
0 g
s
.15063 .72006 m .15888 .757 L .15167 .76424 L p .707 .577 .707 r
F P
0 g
s
.3399 .68188 m .34815 .71882 L .33613 .71603 L p .707 .577 .707 r
F P
0 g
s
.33613 .71603 m .32788 .67909 L .3399 .68188 L p .707 .577 .707 r
F P
0 g
s
.33636 .65761 m .32395 .60221 L .34428 .60223 L p .707 .577 .707 r
F P
0 g
s
.1833 .63482 m .19571 .69022 L .17947 .69872 L p .707 .577 .707 r
F P
0 g
s
.36203 .76669 m .36796 .26547 L .39107 .25515 L p .707 .577 .707 r
F P
0 g
s
.36796 .26547 m .36203 .76669 L .35203 .77858 L p .707 .577 .707 r
F P
0 g
s
.1755 .74645 m .18128 .72955 L .1974 .72371 L p .707 .577 .707 r
F P
0 g
s
.1974 .72371 m .19161 .74062 L .1755 .74645 L p .707 .577 .707 r
F P
0 g
s
.19571 .69022 m .1833 .63482 L .20699 .62589 L p .707 .577 .707 r
F P
0 g
s
.15888 .757 m .15063 .72006 L .16687 .71157 L p .707 .577 .707 r
F P
0 g
s
.32395 .60221 m .33636 .65761 L .3097 .66036 L p .707 .577 .707 r
F P
0 g
s
.3097 .66036 m .29729 .60496 L .32395 .60221 L p .707 .577 .707 r
F P
0 g
s
.16687 .71157 m .17512 .74851 L .15888 .757 L p .707 .577 .707 r
F P
0 g
s
.32788 .67909 m .33613 .71603 L .31579 .71599 L p .707 .577 .707 r
F P
0 g
s
.31579 .71599 m .30754 .67905 L .32788 .67909 L p .707 .577 .707 r
F P
0 g
s
.20699 .62589 m .2194 .68129 L .19571 .69022 L p .707 .577 .707 r
F P
0 g
s
.62393 .26193 m .618 .76314 L .58828 .75356 L p .707 .577 .707 r
F P
0 g
s
.58828 .75356 m .59421 .25234 L .62393 .26193 L p .707 .577 .707 r
F P
0 g
s
.19161 .74062 m .1974 .72371 L .22072 .72251 L p .707 .577 .707 r
F P
0 g
s
.2194 .68129 m .20699 .62589 L .2358 .6174 L p .707 .577 .707 r
F P
0 g
s
.29729 .60496 m .3097 .66036 L .27933 .66559 L p .707 .577 .707 r
F P
0 g
s
.27933 .66559 m .26691 .61019 L .29729 .60496 L p .707 .577 .707 r
F P
0 g
s
.22072 .72251 m .21494 .73942 L .19161 .74062 L p .707 .577 .707 r
F P
0 g
s
.17512 .74851 m .16687 .71157 L .19056 .70265 L p .707 .577 .707 r
F P
0 g
s
.39107 .25515 m .38514 .75637 L .36203 .76669 L p .707 .577 .707 r
F P
0 g
s
.38514 .75637 m .39107 .25515 L .42502 .24742 L p .707 .577 .707 r
F P
0 g
s
.2358 .6174 m .24821 .6728 L .2194 .68129 L p .707 .577 .707 r
F P
0 g
s
.7444 .65087 m .73198 .59547 L .70161 .6007 L p .707 .577 .707 r
F P
0 g
s
.73198 .59547 m .7444 .65087 L .77551 .64366 L p .707 .577 .707 r
F P
0 g
s
.77551 .64366 m .7631 .58826 L .73198 .59547 L p .707 .577 .707 r
F P
0 g
s
.24821 .6728 m .2358 .6174 L .26691 .61019 L p .707 .577 .707 r
F P
0 g
s
.7631 .58826 m .77551 .64366 L .80432 .63517 L p .707 .577 .707 r
F P
0 g
s
.80432 .63517 m .79191 .57977 L .7631 .58826 L p .707 .577 .707 r
F P
0 g
s
.26691 .61019 m .27933 .66559 L .24821 .6728 L p .707 .577 .707 r
F P
0 g
s
.30754 .67905 m .31579 .71599 L .28912 .71871 L p .707 .577 .707 r
F P
0 g
s
.28912 .71871 m .28087 .68177 L .30754 .67905 L p .707 .577 .707 r
F P
0 g
s
.19056 .70265 m .19881 .73959 L .17512 .74851 L p .707 .577 .707 r
F P
0 g
s
.71402 .6561 m .70161 .6007 L .67495 .60344 L p .707 .577 .707 r
F P
0 g
s
.70161 .6007 m .71402 .6561 L .7444 .65087 L p .707 .577 .707 r
F P
0 g
s
.21494 .73942 m .22072 .72251 L .24897 .72606 L p .707 .577 .707 r
F P
0 g
s
.79191 .57977 m .80432 .63517 L .82801 .62624 L p .707 .577 .707 r
F P
0 g
s
.82801 .62624 m .8156 .57084 L .79191 .57977 L p .707 .577 .707 r
F P
0 g
s
.33486 .75966 m .32908 .77657 L .3032 .7625 L p .707 .577 .707 r
F P
0 g
s
.3032 .7625 m .30898 .74559 L .33486 .75966 L p .707 .577 .707 r
F P
0 g
s
.59421 .25234 m .58828 .75356 L .54952 .74683 L p .707 .577 .707 r
F P
0 g
s
.54952 .74683 m .55545 .24561 L .59421 .25234 L p .707 .577 .707 r
F P
0 g
s
.19881 .73959 m .19056 .70265 L .21937 .69418 L p .707 .577 .707 r
F P
0 g
s
.24897 .72606 m .24319 .74297 L .21494 .73942 L p .707 .577 .707 r
F P
0 g
s
.67495 .60344 m .68736 .65885 L .71402 .6561 L p .707 .577 .707 r
F P
0 g
s
.28087 .68177 m .28912 .71871 L .25874 .72392 L p .707 .577 .707 r
F P
0 g
s
.25874 .72392 m .25049 .68699 L .28087 .68177 L p .707 .577 .707 r
F P
0 g
s
.21937 .69418 m .22762 .73112 L .19881 .73959 L p .707 .577 .707 r
F P
0 g
s
.24319 .74297 m .24897 .72606 L .27939 .73401 L p .707 .577 .707 r
F P
0 g
s
.68736 .65885 m .67495 .60344 L .65461 .60343 L p .707 .577 .707 r
F P
0 g
s
.30898 .74559 m .3032 .7625 L .2736 .75092 L p .707 .577 .707 r
F P
0 g
s
.2736 .75092 m .27939 .73401 L .30898 .74559 L p .707 .577 .707 r
F P
0 g
s
.41909 .74863 m .42502 .24742 L .4665 .24303 L p .707 .577 .707 r
F P
0 g
s
.42502 .24742 m .42018 .65652 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.4665 .24303 m .46057 .74424 L .41909 .74863 L p .707 .577 .707 r
F P
0 g
s
.42009 .55138 m .4325 .60678 L .44088 .60431 L p .707 .577 .707 r
F P
0 g
s
.44088 .60431 m .46131 .5983 L p .44888 .58414 L .707 .577 .707 r
F P
0 g
s
.44888 .58414 m .42009 .55138 L .44088 .60431 L .707 .577 .707 r
F
.41909 .74863 m .38514 .75637 L p .38626 .7421 L F P
0 g
s
.42018 .65652 m .41909 .74863 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.72382 .70935 m .71557 .67242 L .68519 .67763 L p .707 .577 .707 r
F P
0 g
s
.71557 .67242 m .72382 .70935 L .75494 .70216 L p .707 .577 .707 r
F P
0 g
s
.75494 .70216 m .74669 .66522 L .71557 .67242 L p .707 .577 .707 r
F P
0 g
s
.22762 .73112 m .21937 .69418 L .25049 .68699 L p .707 .577 .707 r
F P
0 g
s
.74669 .66522 m .75494 .70216 L .78376 .69369 L p .707 .577 .707 r
F P
0 g
s
.78376 .69369 m .77551 .65675 L .74669 .66522 L p .707 .577 .707 r
F P
0 g
s
.25049 .68699 m .25874 .72392 L .22762 .73112 L p .707 .577 .707 r
F P
0 g
s
.27939 .73401 m .2736 .75092 L .24319 .74297 L p .707 .577 .707 r
F P
0 g
s
.8156 .57084 m .82801 .62624 L .84425 .61774 L p .707 .577 .707 r
F P
0 g
s
.84425 .61774 m .83184 .56234 L .8156 .57084 L p .707 .577 .707 r
F P
0 g
s
.68519 .67763 m .69344 .71457 L .72382 .70935 L p .707 .577 .707 r
F P
0 g
s
.65461 .60343 m .66703 .65883 L .68736 .65885 L p .707 .577 .707 r
F P
0 g
s
.69344 .71457 m .68519 .67763 L .65853 .68035 L p .707 .577 .707 r
F P
0 g
s
.73711 .76905 m .74289 .75214 L .7133 .74056 L p .707 .577 .707 r
F P
0 g
s
.74289 .75214 m .73711 .76905 L .76752 .77701 L p .707 .577 .707 r
F P
0 g
s
.76752 .77701 m .7733 .7601 L .74289 .75214 L p .707 .577 .707 r
F P
0 g
s
.55545 .24561 m .54952 .74683 L .50551 .74362 L p .707 .577 .707 r
F P
0 g
s
.50551 .74362 m .51145 .2424 L .55545 .24561 L p .707 .577 .707 r
F P
0 g
s
.77551 .65675 m .78376 .69369 L .80745 .68477 L p .707 .577 .707 r
F P
0 g
s
.80745 .68477 m .79919 .64783 L .77551 .65675 L p .707 .577 .707 r
F P
0 g
s
.70752 .75747 m .7133 .74056 L .68742 .72649 L p .707 .577 .707 r
F P
0 g
s
.7133 .74056 m .70752 .75747 L .73711 .76905 L p .707 .577 .707 r
F P
0 g
s
.65853 .68035 m .66678 .71729 L .69344 .71457 L p .707 .577 .707 r
F P
0 g
s
.46057 .74424 m .4665 .24303 L .51145 .2424 L p .707 .577 .707 r
F P
0 g
s
.7733 .7601 m .76752 .77701 L .79577 .78056 L p .707 .577 .707 r
F P
0 g
s
.79577 .78056 m .80156 .76365 L .7733 .7601 L p .707 .577 .707 r
F P
0 g
s
.51145 .2424 m .50551 .74362 L .46057 .74424 L p .707 .577 .707 r
F P
0 g
s
.68742 .72649 m .68164 .7434 L .70752 .75747 L p .707 .577 .707 r
F P
0 g
s
.66703 .65883 m .65461 .60343 L .64259 .60065 L p .707 .577 .707 r
F P
0 g
s
.66678 .71729 m .65853 .68035 L .63819 .68031 L p .707 .577 .707 r
F P
0 g
s
.68164 .7434 m .68742 .72649 L .66779 .71131 L p .707 .577 .707 r
F P
0 g
s
.83184 .56234 m .84425 .61774 L .85146 .61051 L p .707 .577 .707 r
F P
0 g
s
.85146 .61051 m .83905 .55511 L .83184 .56234 L p .707 .577 .707 r
F P
0 g
s
.80156 .76365 m .79577 .78056 L .8191 .77935 L p .707 .577 .707 r
F P
0 g
s
.8191 .77935 m .82488 .76245 L .80156 .76365 L p .707 .577 .707 r
F P
0 g
s
.79919 .64783 m .80745 .68477 L .82369 .67628 L p .707 .577 .707 r
F P
0 g
s
.82369 .67628 m .81544 .63934 L .79919 .64783 L p .707 .577 .707 r
F P
0 g
s
.64259 .60065 m .65501 .65605 L .66703 .65883 L p .707 .577 .707 r
F P
0 g
s
.63819 .68031 m .64644 .71725 L .66678 .71729 L p .707 .577 .707 r
F P
0 g
s
.66779 .71131 m .66201 .72822 L .68164 .7434 L p .707 .577 .707 r
F P
0 g
s
.66201 .72822 m .66779 .71131 L .65633 .6965 L p .707 .577 .707 r
F P
0 g
s
.65501 .65605 m .64259 .60065 L .64006 .59539 L p .707 .577 .707 r
F P
0 g
s
.82488 .76245 m .8191 .77935 L .83522 .77352 L p .707 .577 .707 r
F P
0 g
s
.83522 .77352 m .841 .75661 L .82488 .76245 L p .707 .577 .707 r
F P
0 g
s
.65633 .6965 m .65055 .71341 L .66201 .72822 L p .707 .577 .707 r
F P
0 g
s
.81544 .63934 m .82369 .67628 L .8309 .66904 L p .707 .577 .707 r
F P
0 g
s
.8309 .66904 m .82265 .6321 L .81544 .63934 L p .707 .577 .707 r
F P
0 g
s
.83905 .55511 m .85146 .61051 L .84893 .60525 L p .707 .577 .707 r
F P
0 g
s
.84893 .60525 m .83652 .54985 L .83905 .55511 L p .707 .577 .707 r
F P
0 g
s
.64006 .59539 m .65248 .65079 L .65501 .65605 L p .707 .577 .707 r
F P
0 g
s
.65055 .71341 m .65633 .6965 L .65416 .68351 L p .707 .577 .707 r
F P
0 g
s
.65416 .68351 m .64838 .70041 L .65055 .71341 L p .707 .577 .707 r
F P
0 g
s
.841 .75661 m .83522 .77352 L .84255 .76362 L p .707 .577 .707 r
F P
0 g
s
.84255 .76362 m .84834 .74671 L .841 .75661 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .62616 .67752 L .62363 .67225 L p .707 .577 .707 r
F P
0 g
s
.65248 .65079 m .64006 .59539 L .64727 .58815 L p .707 .577 .707 r
F P
0 g
s
.62363 .67225 m .63188 .70919 L .63442 .71446 L p .707 .577 .707 r
F P
0 g
s
.82265 .6321 m .8309 .66904 L .82837 .66377 L p .707 .577 .707 r
F P
0 g
s
.82837 .66377 m .82012 .62683 L .82265 .6321 L p .707 .577 .707 r
F P
0 g
s
.83652 .54985 m .84893 .60525 L .83691 .60247 L p .707 .577 .707 r
F P
0 g
s
.83691 .60247 m .8245 .54707 L .83652 .54985 L p .707 .577 .707 r
F P
0 g
s
.64727 .58815 m .65969 .64355 L .65248 .65079 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64838 .70041 m .65416 .68351 L .66149 .67361 L p .707 .577 .707 r
F P
0 g
s
.40139 .61399 m .38897 .55859 L .3586 .56383 L p .707 .577 .707 r
F P
0 g
s
.38897 .55859 m .40139 .61399 L .4325 .60678 L p .707 .577 .707 r
F P
0 g
s
.4325 .60678 m .42009 .55138 L .38897 .55859 L p .707 .577 .707 r
F P
0 g
s
.46131 .5983 m .4489 .54289 L .42009 .55138 L p .707 .577 .707 r
F P
0 g
s
.66149 .67361 m .65571 .69052 L .64838 .70041 L p .707 .577 .707 r
F P
0 g
s
.84834 .74671 m .84255 .76362 L .84038 .75063 L p .707 .577 .707 r
F P
0 g
s
.84038 .75063 m .84617 .73372 L .84834 .74671 L p .707 .577 .707 r
F P
0 g
s
.63188 .70919 m .62363 .67225 L .63084 .66501 L p .707 .577 .707 r
F P
0 g
s
.37101 .61923 m .3586 .56383 L .33194 .56657 L p .707 .577 .707 r
F P
0 g
s
.3586 .56383 m .37101 .61923 L .40139 .61399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65969 .64355 m .64727 .58815 L .66351 .57965 L p .707 .577 .707 r
F P
0 g
s
.4489 .54289 m .46131 .5983 L .485 .58937 L p .707 .577 .707 r
F P
0 g
s
.485 .58937 m .47259 .53396 L .4489 .54289 L p .707 .577 .707 r
F P
0 g
s
.63084 .66501 m .63909 .70195 L .63188 .70919 L p .707 .577 .707 r
F P
0 g
s
.82012 .62683 m .82837 .66377 L .81634 .66097 L p .707 .577 .707 r
F P
0 g
s
.81634 .66097 m .80809 .62404 L .82012 .62683 L p .707 .577 .707 r
F P
0 g
s
.8245 .54707 m .83691 .60247 L .81658 .60245 L p .707 .577 .707 r
F P
0 g
s
.81658 .60245 m .80416 .54705 L .8245 .54707 L p .707 .577 .707 r
F P
0 g
s
.33194 .56657 m .34435 .62197 L .37101 .61923 L p .707 .577 .707 r
F P
0 g
s
.66351 .57965 m .67593 .63506 L .65969 .64355 L p .707 .577 .707 r
F P
0 g
s
.34435 .62197 m .33194 .56657 L .3116 .56655 L p .707 .577 .707 r
F P
0 g
s
.65571 .69052 m .66149 .67361 L .67761 .66777 L p .707 .577 .707 r
F P
0 g
s
.38081 .67237 m .37256 .63543 L .34218 .64064 L p .707 .577 .707 r
F P
0 g
s
.37256 .63543 m .38081 .67237 L .41193 .66518 L p .707 .577 .707 r
F P
0 g
s
.41193 .66518 m .40368 .62824 L .37256 .63543 L p .707 .577 .707 r
F P
0 g
s
.40368 .62824 m .41193 .66518 L .44075 .6567 L p .707 .577 .707 r
F P
0 g
s
.44075 .6567 m .4325 .61977 L .40368 .62824 L p .707 .577 .707 r
F P
0 g
s
.47259 .53396 m .485 .58937 L .50124 .58087 L p .707 .577 .707 r
F P
0 g
s
.50124 .58087 m .48883 .52547 L .47259 .53396 L p .707 .577 .707 r
F P
0 g
s
.67761 .66777 m .67183 .68468 L .65571 .69052 L p .707 .577 .707 r
F P
0 g
s
.84617 .73372 m .84038 .75063 L .82892 .73582 L p .707 .577 .707 r
F P
0 g
s
.82892 .73582 m .8347 .71891 L .84617 .73372 L p .707 .577 .707 r
F P
0 g
s
.34218 .64064 m .35043 .67758 L .38081 .67237 L p .707 .577 .707 r
F P
0 g
s
.67593 .63506 m .66351 .57965 L .6872 .57072 L p .707 .577 .707 r
F P
0 g
s
.3116 .56655 m .32402 .62195 L .34435 .62197 L p .707 .577 .707 r
F P
0 g
s
.35043 .67758 m .34218 .64064 L .31552 .64337 L p .707 .577 .707 r
F P
0 g
s
.63909 .70195 m .63084 .66501 L .64708 .65652 L p .707 .577 .707 r
F P
0 g
s
.3941 .73295 m .39988 .71604 L .37029 .70446 L p .707 .577 .707 r
F P
0 g
s
.39988 .71604 m .3941 .73295 L .42451 .7409 L p .707 .577 .707 r
F P
0 g
s
.42451 .7409 m .43029 .724 L .39988 .71604 L p .707 .577 .707 r
F P
0 g
s
.4325 .61977 m .44075 .6567 L .46444 .64779 L p .707 .577 .707 r
F P
0 g
s
.46444 .64779 m .45618 .61085 L .4325 .61977 L p .707 .577 .707 r
F P
0 g
s
.80416 .54705 m .81658 .60245 L .78992 .60519 L p .707 .577 .707 r
F P
0 g
s
.78992 .60519 m .7775 .54979 L .80416 .54705 L p .707 .577 .707 r
F P
0 g
s
.36451 .72137 m .37029 .70446 L .34441 .69039 L p .707 .577 .707 r
F P
0 g
s
.37029 .70446 m .36451 .72137 L .3941 .73295 L p .707 .577 .707 r
F P
0 g
s
.31552 .64337 m .32377 .6803 L .35043 .67758 L p .707 .577 .707 r
F P
0 g
s
.64708 .65652 m .65534 .69345 L .63909 .70195 L p .707 .577 .707 r
F P
0 g
s
.43029 .724 m .42451 .7409 L .45276 .74445 L p .707 .577 .707 r
F P
0 g
s
.45276 .74445 m .45855 .72754 L .43029 .724 L p .707 .577 .707 r
F P
0 g
s
.80809 .62404 m .81634 .66097 L .796 .66094 L p .707 .577 .707 r
F P
0 g
s
.796 .66094 m .78775 .624 L .80809 .62404 L p .707 .577 .707 r
F P
0 g
s
.6872 .57072 m .69961 .62613 L .67593 .63506 L p .707 .577 .707 r
F P
0 g
s
.34441 .69039 m .33863 .7073 L .36451 .72137 L p .707 .577 .707 r
F P
0 g
s
.32402 .62195 m .3116 .56655 L .29958 .56377 L p .707 .577 .707 r
F P
0 g
s
.32377 .6803 m .31552 .64337 L .29518 .64333 L p .707 .577 .707 r
F P
0 g
s
.67183 .68468 m .67761 .66777 L .70094 .66657 L p .707 .577 .707 r
F P
0 g
s
.33863 .7073 m .34441 .69039 L .32478 .67521 L p .707 .577 .707 r
F P
0 g
s
.69961 .62613 m .6872 .57072 L .71601 .56224 L p .707 .577 .707 r
F P
0 g
s
.48883 .52547 m .50124 .58087 L .50845 .57363 L p .707 .577 .707 r
F P
0 g
s
.50845 .57363 m .49604 .51823 L .48883 .52547 L p .707 .577 .707 r
F P
0 g
s
.7775 .54979 m .78992 .60519 L .75954 .61043 L p .707 .577 .707 r
F P
0 g
s
.75954 .61043 m .74713 .55503 L .7775 .54979 L p .707 .577 .707 r
F P
0 g
s
.45855 .72754 m .45276 .74445 L .47609 .74325 L p .707 .577 .707 r
F P
0 g
s
.47609 .74325 m .48187 .72634 L .45855 .72754 L p .707 .577 .707 r
F P
0 g
s
.45618 .61085 m .46444 .64779 L .48068 .63929 L p .707 .577 .707 r
F P
0 g
s
.48068 .63929 m .47243 .60235 L .45618 .61085 L p .707 .577 .707 r
F P
0 g
s
.8347 .71891 m .82892 .73582 L .80929 .72063 L p .707 .577 .707 r
F P
0 g
s
.80929 .72063 m .81507 .70373 L .8347 .71891 L p .707 .577 .707 r
F P
0 g
s
.29958 .56377 m .312 .61917 L .32402 .62195 L p .707 .577 .707 r
F P
0 g
s
.29518 .64333 m .30343 .68027 L .32377 .6803 L p .707 .577 .707 r
F P
0 g
s
.70094 .66657 m .69516 .68348 L .67183 .68468 L p .707 .577 .707 r
F P
0 g
s
.32478 .67521 m .319 .69212 L .33863 .7073 L p .707 .577 .707 r
F P
0 g
s
.65534 .69345 m .64708 .65652 L .67077 .6476 L p .707 .577 .707 r
F P
0 g
s
.71601 .56224 m .72843 .61764 L .69961 .62613 L p .707 .577 .707 r
F P
0 g
s
.72843 .61764 m .71601 .56224 L .74713 .55503 L p .707 .577 .707 r
F P
0 g
s
.74713 .55503 m .75954 .61043 L .72843 .61764 L p .707 .577 .707 r
F P
0 g
s
.78775 .624 m .796 .66094 L .76934 .66366 L p .707 .577 .707 r
F P
0 g
s
.76934 .66366 m .76109 .62672 L .78775 .624 L p .707 .577 .707 r
F P
0 g
s
.67077 .6476 m .67902 .68453 L .65534 .69345 L p .707 .577 .707 r
F P
0 g
s
.319 .69212 m .32478 .67521 L .31332 .66039 L p .707 .577 .707 r
F P
0 g
s
.69516 .68348 m .70094 .66657 L .72919 .67012 L p .707 .577 .707 r
F P
0 g
s
.30343 .68027 m .29518 .64333 L .28315 .64054 L p .707 .577 .707 r
F P
0 g
s
.312 .61917 m .29958 .56377 L .29705 .55851 L p .707 .577 .707 r
F P
0 g
s
.81507 .70373 m .80929 .72063 L .78341 .70656 L p .707 .577 .707 r
F P
0 g
s
.78341 .70656 m .78919 .68965 L .81507 .70373 L p .707 .577 .707 r
F P
0 g
s
.48187 .72634 m .47609 .74325 L .49221 .73742 L p .707 .577 .707 r
F P
0 g
s
.49221 .73742 m .49799 .72051 L .48187 .72634 L p .707 .577 .707 r
F P
0 g
s
.31332 .66039 m .30754 .6773 L .319 .69212 L p .707 .577 .707 r
F P
0 g
s
.72919 .67012 m .72341 .68703 L .69516 .68348 L p .707 .577 .707 r
F P
0 g
s
.67902 .68453 m .67077 .6476 L .69959 .63913 L p .707 .577 .707 r
F P
0 g
s
.28315 .64054 m .29141 .67747 L .30343 .68027 L p .707 .577 .707 r
F P
0 g
s
.47243 .60235 m .48068 .63929 L .48789 .63205 L p .707 .577 .707 r
F P
0 g
s
.48789 .63205 m .47964 .59512 L .47243 .60235 L p .707 .577 .707 r
F P
0 g
s
.76109 .62672 m .76934 .66366 L .73896 .66887 L p .707 .577 .707 r
F P
0 g
s
.73896 .66887 m .73071 .63193 L .76109 .62672 L p .707 .577 .707 r
F P
0 g
s
.49604 .51823 m .50845 .57363 L .50592 .56837 L p .707 .577 .707 r
F P
0 g
s
.50592 .56837 m .49351 .51297 L .49604 .51823 L p .707 .577 .707 r
F P
0 g
s
.29705 .55851 m .30947 .61391 L .312 .61917 L p .707 .577 .707 r
F P
0 g
s
.69959 .63913 m .70784 .67606 L .67902 .68453 L p .707 .577 .707 r
F P
0 g
s
.72341 .68703 m .72919 .67012 L .7596 .67808 L p .707 .577 .707 r
F P
0 g
s
.78919 .68965 m .78341 .70656 L .75382 .69498 L p .707 .577 .707 r
F P
0 g
s
.75382 .69498 m .7596 .67808 L .78919 .68965 L p .707 .577 .707 r
F P
0 g
s
.70784 .67606 m .69959 .63913 L .73071 .63193 L p .707 .577 .707 r
F P
0 g
s
.73071 .63193 m .73896 .66887 L .70784 .67606 L p .707 .577 .707 r
F P
0 g
s
.7596 .67808 m .75382 .69498 L .72341 .68703 L p .707 .577 .707 r
F P
0 g
s
.30754 .6773 m .31332 .66039 L .31115 .6474 L p .707 .577 .707 r
F P
0 g
s
.29141 .67747 m .28315 .64054 L .28062 .63526 L p .707 .577 .707 r
F P
0 g
s
.31115 .6474 m .30537 .66431 L .30754 .6773 L p .707 .577 .707 r
F P
0 g
s
.49799 .72051 m .49221 .73742 L .49954 .72752 L p .707 .577 .707 r
F P
0 g
s
.49954 .72752 m .50533 .71061 L .49799 .72051 L p .707 .577 .707 r
F P
0 g
s
.30947 .61391 m .29705 .55851 L .30426 .55128 L p .707 .577 .707 r
F P
0 g
s
.28062 .63526 m .28887 .6722 L .29141 .67747 L p .707 .577 .707 r
F P
0 g
s
.47964 .59512 m .48789 .63205 L .48536 .62678 L p .707 .577 .707 r
F P
0 g
s
.48536 .62678 m .4771 .58984 L .47964 .59512 L p .707 .577 .707 r
F P
0 g
s
.49351 .51297 m .50592 .56837 L .4939 .56559 L p .707 .577 .707 r
F P
0 g
s
.4939 .56559 m .48149 .51019 L .49351 .51297 L p .707 .577 .707 r
F P
0 g
s
.30426 .55128 m .31668 .60668 L .30947 .61391 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30537 .66431 m .31115 .6474 L .31848 .63751 L p .707 .577 .707 r
F P
0 g
s
.31848 .63751 m .3127 .65442 L .30537 .66431 L p .707 .577 .707 r
F P
0 g
s
.50533 .71061 m .49954 .72752 L .49737 .71453 L p .707 .577 .707 r
F P
0 g
s
.49737 .71453 m .50316 .69762 L .50533 .71061 L p .707 .577 .707 r
F P
0 g
s
.28887 .6722 m .28062 .63526 L .28783 .62803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31668 .60668 m .30426 .55128 L .3205 .54278 L p .707 .577 .707 r
F P
0 g
s
.28783 .62803 m .29608 .66496 L .28887 .6722 L p .707 .577 .707 r
F P
0 g
s
.4771 .58984 m .48536 .62678 L .47333 .62399 L p .707 .577 .707 r
F P
0 g
s
.47333 .62399 m .46508 .58705 L .4771 .58984 L p .707 .577 .707 r
F P
0 g
s
.48149 .51019 m .4939 .56559 L .47357 .56558 L p .707 .577 .707 r
F P
0 g
s
.47357 .56558 m .46115 .51017 L .48149 .51019 L p .707 .577 .707 r
F P
0 g
s
.3205 .54278 m .33292 .59818 L .31668 .60668 L p .707 .577 .707 r
F P
0 g
s
.3127 .65442 m .31848 .63751 L .3346 .63167 L p .707 .577 .707 r
F P
0 g
s
.3346 .63167 m .32882 .64858 L .3127 .65442 L p .707 .577 .707 r
F P
0 g
s
.50316 .69762 m .49737 .71453 L .48591 .69972 L p .707 .577 .707 r
F P
0 g
s
.48591 .69972 m .49169 .68281 L .50316 .69762 L p .707 .577 .707 r
F P
0 g
s
.33292 .59818 m .3205 .54278 L .34419 .53385 L p .707 .577 .707 r
F P
0 g
s
.29608 .66496 m .28783 .62803 L .30407 .61953 L p .707 .577 .707 r
F P
0 g
s
.46115 .51017 m .47357 .56558 L .44691 .56832 L p .707 .577 .707 r
F P
0 g
s
.44691 .56832 m .43449 .51292 L .46115 .51017 L p .707 .577 .707 r
F P
0 g
s
.30407 .61953 m .31233 .65647 L .29608 .66496 L p .707 .577 .707 r
F P
0 g
s
.46508 .58705 m .47333 .62399 L .45299 .62395 L p .707 .577 .707 r
F P
0 g
s
.45299 .62395 m .44474 .58701 L .46508 .58705 L p .707 .577 .707 r
F P
0 g
s
.34419 .53385 m .3566 .58925 L .33292 .59818 L p .707 .577 .707 r
F P
0 g
s
.32882 .64858 m .3346 .63167 L .35793 .63047 L p .707 .577 .707 r
F P
0 g
s
.3566 .58925 m .34419 .53385 L .373 .52536 L p .707 .577 .707 r
F P
0 g
s
.43449 .51292 m .44691 .56832 L .41653 .57355 L p .707 .577 .707 r
F P
0 g
s
.41653 .57355 m .40412 .51815 L .43449 .51292 L p .707 .577 .707 r
F P
0 g
s
.49169 .68281 m .48591 .69972 L .46628 .68453 L p .707 .577 .707 r
F P
0 g
s
.46628 .68453 m .47206 .66762 L .49169 .68281 L p .707 .577 .707 r
F P
0 g
s
.35793 .63047 m .35214 .64738 L .32882 .64858 L p .707 .577 .707 r
F P
0 g
s
.31233 .65647 m .30407 .61953 L .32776 .61061 L p .707 .577 .707 r
F P
0 g
s
.373 .52536 m .38542 .58076 L .3566 .58925 L p .707 .577 .707 r
F P
0 g
s
.38542 .58076 m .373 .52536 L .40412 .51815 L p .707 .577 .707 r
F P
0 g
s
.40412 .51815 m .41653 .57355 L .38542 .58076 L p .707 .577 .707 r
F P
0 g
s
.44474 .58701 m .45299 .62395 L .42633 .62667 L p .707 .577 .707 r
F P
0 g
s
.42633 .62667 m .41808 .58973 L .44474 .58701 L p .707 .577 .707 r
F P
0 g
s
.32776 .61061 m .33601 .64755 L .31233 .65647 L p .707 .577 .707 r
F P
0 g
s
.35214 .64738 m .35793 .63047 L .38618 .63402 L p .707 .577 .707 r
F P
0 g
s
.47206 .66762 m .46628 .68453 L .4404 .67046 L p .707 .577 .707 r
F P
0 g
s
.4404 .67046 m .44618 .65355 L .47206 .66762 L p .707 .577 .707 r
F P
0 g
s
.33601 .64755 m .32776 .61061 L .35658 .60214 L p .707 .577 .707 r
F P
0 g
s
.38618 .63402 m .3804 .65093 L .35214 .64738 L p .707 .577 .707 r
F P
0 g
s
.41808 .58973 m .42633 .62667 L .39595 .63188 L p .707 .577 .707 r
F P
0 g
s
.39595 .63188 m .3877 .59495 L .41808 .58973 L p .707 .577 .707 r
F P
0 g
s
.35658 .60214 m .36483 .63908 L .33601 .64755 L p .707 .577 .707 r
F P
0 g
s
.3804 .65093 m .38618 .63402 L .41659 .64197 L p .707 .577 .707 r
F P
0 g
s
.44618 .65355 m .4404 .67046 L .41081 .65888 L p .707 .577 .707 r
F P
0 g
s
.41081 .65888 m .41659 .64197 L .44618 .65355 L p .707 .577 .707 r
F P
0 g
s
.36483 .63908 m .35658 .60214 L .3877 .59495 L p .707 .577 .707 r
F P
0 g
s
.3877 .59495 m .39595 .63188 L .36483 .63908 L p .707 .577 .707 r
F P
0 g
s
.41659 .64197 m .41081 .65888 L .3804 .65093 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001XOol00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`<000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH0000C0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`800003FUH005YF00EJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo0P0000=JEP00FUH015YF100000=JEP00FUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00000010001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00HGoo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001OOol30009FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005eoo`80009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
FWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00:Woo2`00<Goo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol80003
FUH00`00FUIJEP03FUH01000FUH00000;goo001EOol20005FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000KOol70003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`03001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Moo`@0
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH^Ool005Aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000COol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/00003FUH0000000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80015oo`800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF1000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Woo0`000eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P002goo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo001EOol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000]Ool005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUIJEP0015YF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01UYF00<005YF00002P000eYF00@005YF000000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF008002aoo`00EWoo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEP00001JEP020005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;7oo001FOol01000FUIJEP0015YF00@005YFFUIJEP8000=JEP03001JEUYF00IJEPD0
0003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000[
Ool005Ioo`04001JEUYF0004FUH01000FUH000001EYF00<005YFFUH00UYF1@001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo
00@005YFFUH000AJEP<000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00:goo001FOol01P00FUIJEUYF001J
EP80009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPX0009JEP03001oogoo02Uoo`00D7oo1`000eYF0P0015YF100000=JEP00FUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
0UYF1@00:Woo001:Ool60004FUH01000FUIJEUYF0P0000=JEP0000000`001EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1P001eYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUH002Yoo`00AWoo100000=JEP00FUH025YF00D005YF000005YF00800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002]oo`00@Goo1@001EYF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP@000QJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00?Goo10000UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001J
EUYF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0
000^Ool003Yoo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH;00000eYF00000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUH0000:0004FUH3000_Ool0
03Qoo`<000UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03
001JEUYF00=JEP@000UJEP03001JEP0000L000=JEP03001JEUYF00=JEP03001JEP0000@0035oo`00
=Woo0P000UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEP00008000AJEP04001JEUYFFUH70004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00<goo000cOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0:0007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000017oo001JEP001EYF0P001eYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH003=oo`00<Goo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF10000eYF00<005YFFUH010001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00
FUH000=JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YF
FUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP<000AJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol002ioo`8000EJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
1EYF00<005YF00000`001eYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YF
FUH20003FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00<Woo000^Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30006FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20003FUH00`00FUH000030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`00
15YF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF1P0035YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF100000=JEP00FUH01eYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<Goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0004
FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH300000eYF001JEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH01000FUH000001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
25YF00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2`0000=JEP00Ool0<7oo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002FUH30002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH40004
FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP02FUH3000aOol002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH50002FUH300000eYF001JEP020006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH500001UYF00000000FUH000MJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000<7oo000^Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YF001J
EP800005FUH005YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH2
0008FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00<7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1EYF1@0025YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00
FUIJEP04FUH20005FUH01000FUIJEP001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0
0000008000QJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00;Woo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00IJEP80009JEP8000AJEP04001JEUYFFUH8
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF10000UYF00<005YFFUH015YF100015YF00<005YFFUH01EYF00@005YFFUIJ
EP80039oo`00;goo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJEP03001JEUYF009JEP/0009J
EP03001JEP0000<00006FUH00000001JEP001UYF00<005YF00000P001EYF00<005YFFUH025YF0`00
1EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01UYF00@005YF
0000009JEP03001JEUYF00EJEP04001JEP00000dOol002moo`04001JEUYF0004FUH01000FUIJEUYF
0P000eYF00<005YFFUH01UYF1@0000=JEP00FUH01UYF0P000UYF00<005YFFUH010000Woo00<005YF
00001UYF1P0015YF00<005YFFUH025YF00<005YF00001UYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEP00001JEP0015YF00<005YFFUH015YF2@0015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP<003Ioo`00;goo00@005YFFUH000AJEP04001JEP000005FUH00`00
FUIJEP02FUH50006FUH00`00FUIJEP04FUH01000FUH000001EYF0P000Woo00<005YF00001UYF1P00
15YF00<005YFFUH025YF00<005YFFUH00P0015YF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH7
0006FUH00`00FUIJEP04FUH20003FUH2000iOol002moo`04001JEUYF0004FUH30006FUH50002FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH01P00Oomoo`00FUH000IJEPH000AJEP03
001JEUYF00QJEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000005FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH01UYF0`00>goo000_Ool01P00FUIJEUYF001JEP80009JEP04001JEUYF
FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF100000=JEP00FUH01EYF
00<005YF00000P001EYF00<005YFFUH025YF00<005YFFUH00eYF0`000eYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH40007FUH01000FUH00000>Woo000`Ool3FUH20004FUH400000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH00`001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000005FUH01000FUIJEUYF0P00>7oo000`Ool015YF000005YF
1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=J
EP00FUH015YF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH00000FUH20007
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500001Woo00000000FUH000IJEP8003Ioo`00<7oo0P00
00EJEP00001JEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<000MJEP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF
00000007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`0cOol0031oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8000QJEP03001JEP00008000UJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000eYF0P001UYF00<005YF
FUH01EYF10003goo0P001UYF0`00<goo000^Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH00UYF
0`001eYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00@001Eoo`80
00=JEP05001JEUYFFUH0000bOol002aoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH;000015YF000000000eYF00<005YFFUH01EYF10000eYF
00<005YFFUH025YF00<005YFFUH025YF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1P000eYF2`002Goo0`003goo0P0000=JEP00FUH00eYF0P00<7oo000ZOol20003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP02
FUH80009FUH00`00FUIJEP04000:FUH00`00FUIJEP07FUH4000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUH00002FUH00`00FUIJEP05000;Ool5000@Ool20006
FUH00`00Oomoo`0]Ool002Uoo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030008FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP05FUH2000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF0P0000=JEP00FUH00eYF0P003Goo1@004Woo00<005YFFUH00eYF0P00
;Woo000XOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02P001eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0009JEP<000AJEP03001JEUYF00MJEP04
001JEUYFFUH<0002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUH000001UYF00<007ooOol02Woo1@004goo00L005YFFUIJEP00FUH0000^
Ool002Qoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04
0007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00Oomoo`00FUH000EJEP<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH01000FUIJEP001UYF0`002goo0`005Goo
00@005YFFUH0009JEP03001oogoo02]oo`00:Goo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000=oo`03
001JEP0000IJEP03001JEP00008000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP05
001JEUYFFUH00004FUH01000FUIJEUYF0P008Woo0P0015YF00<007ooOol0:Woo000YOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUH000030007FUH00`00FUIJEP07FUH30003FUH00`00FUIJEP05
FUH30004Ool00`00FUH00006FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP80025oo`03001JEUYF009JEP03
001oogoo02Yoo`00:Goo00@005YFFUH000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP05FUH20006Ool00`00FUH00006FUH00`00FUIJEP06FUH60004FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF0P0087oo00<005YFFUH00P00;7oo000Y
Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH00eYF1P001eYF00<005YFFUH00eYF
0`0000=JEP0000000P0027oo00<005YF000045YF00<005YFFUH00UYF6P001UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF00<005YF00000P00
7Goo00H005YFFUH005YF000[Ool002Yoo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00@0009JEP03001JEUYF00IJEP8000aoo`03001JEP0000mJEPP000aJEP03001JEUYF00UJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP04001JEP000006FUH0
0`00FUIJEP02FUH3000KOol20002FUH00`00Oomoo`0YOol002Yoo`03001JEP0000=JEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40008FUH3000:Ool00`00FUH0000<FUH30007FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH3000IOol01000
FUIJEP00:goo000ZOol00`00FUIJEP0400000eYF00000007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH40004FUH01000FUIJEUYF0P0027oo00<005YF000025YF10002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF4@0000Eoo`00001JEP00
00UJEP04001JEP00000GOol00`00FUH0000/Ool002Yoo`03001JEUYF00<00003FUH005YF008000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@0009oo`<00003FUH005YF00AJEP8000Ioo`03001JEP00
00EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP8000AJEP03001JEUYF009JEP<000IJEP03001JEUYF009JEP04001JEP000002Ool3
0007FUH00`00FUIJEP02FUH3000COol200000eYF001oo`0[Ool002]oo`03FUH005YF00800005FUH0
05YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20007FUH20004Ool00`00FUH00003
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300000eYF001JEP03FUH30006FUH00`00FUIJEP02FUH01000FUIJEP001Goo0P001EYF
00<005YFFUH01EYF1@0027oo1P0000=JEP000000;Goo000[Ool01P00FUIJEP00FUH000=JEP03001J
EUYF00EJEP03001JEUYF009JEPL000moo`8000EJEP03001JEP0000=oo`04001JEP00FUH30007FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
1000FUH0000015YF0`001UYF00<005YFFUH00eYF0P0027oo0`0000=JEP00FUH025YF00@005YFFUIJ
EPP000=JEP04001JEUYFFUH2000]Ool002]oo`80009JEP8000AJEP04001JEUYFFUH8000HOol20003
FUH00`00FUIJEP0200000goo001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`00
1eYF00@005YFFUIJEP8000aoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002eoo`D0009JEP03001JEP00008000moo`<0011oo`<000EJEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEPD000MJEP04001JEP00000BOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool0035oo`04001JEUYF0002FUH2000>Ool5000AOol00`00FUIJEP04FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40006FUH3000HOol60004FUH00`00FUIJEP03FUH0
1000FUH00000<Goo000bOol20005FUH00`00Oomoo`0;Ool5000BOol00`00FUIJEP03FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH50003FUH2000QOol<000cOol003=oo`03001JEUYF00AJEP03
001oogoo00Yoo`D001=oo`03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP00009JEP<0069oo`00=7oo00<005YFFUH00eYF0`002goo0`005Goo00H005YFFUH005YF0004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH3001QOol003Eoo`03001JEUYF009J
EP03001JEUYF0080029oo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=J
EP04001JEUYFFUH2001OOol003Ioo`800003FUH005YF00AJEP80029oo`04001JEUYF0003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH2001MOol003Qoo`8000MJEP<0021o
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001oogoo
05Yoo`00>Goo00<005YFFUH01UYF00@005YF000001ioo`03001JEUYF00@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000QJEP<005Yoo`00>Woo0P001EYF00<005YFFUH00UYF0`0077oo0P0000=JEP00Ool0
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP8000Ioo`8000IJEP04001JEUYF001IOol003aoo`8000=JEP03001JEUYF
00EJEP<001Yoo`03001JEP0000=oo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000:Ool20003FUH00`00FUIJEP02FUH2
001GOol003ioo`<000UJEP03001JEP00008001Moo`03001JEP0000Moo`D000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000ioo`800003FUH005YF00EJEP03
001oogoo05Aoo`00@7oo0P0025YF00<005YFFUH00UYF0`004Woo10003Goo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02@0047oo0P001UYF0P00EGoo0012Ool3
0004FUH00`00FUIJEP06FUH50008Ool5000015YF001JEP004goo2@001UYF00<005YFFUH02UYF00<0
05YFFUH00eYF200017oo1@004Woo00<005YFFUH00UYF00<005YF0000EGoo0015Ool300000eYF001J
EP07FUH00`00FUIJEP02FUH80002FUH01`00FUIJEUYF001JEP0001aooa/000Yoo`D001=oo`80009J
EP04001JEUYF001DOol004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0
02moo`03001JEUYF009JEP04001JEUYFFUH20009Ool3000FOol20004FUH00`00Oomoo`1AOol004]o
o`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol20002FUH00`00FUIJ
EP03FUH2000QOol00`00FUIJEP02FUH00`00Oomoo`1AOol004moo`H000AJEP03001JEUYF00AJEP04
001JEP00000eOol20008FUH2000POol00`00FUIJEP02001COol005Eoo`d003Qoo`03001JEUYF00IJ
EP04001JEP00000NOol01P00FUIJEP00FUH0059oo`00Vgoo0P001UYF00@005YFFUIJEP8001eoo`80
009JEP03001oogoo051oo`00WGoo0P000eYF00<005YFFUH015YF0P0077oo00@005YFFUH0059oo`00
Wgoo0P0000=JEP00FUH01eYF0`006Goo00<005YF0000Dgoo002QOol30007FUH00`00FUIJEP04000D
Ool200000eYF001oo`1BOol00:Aoo`8000EJEP03001JEUYF00AJEPH000Qoo`H0009JEP03001oogoo
059oo`00YWoo0`0000=JEP00FUH025YF00@005YFFUIJEPP000=JEP04001JEUYFFUH2001DOol00:Uo
o`<000QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05=oo`00[7oo
0`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00[goo0`0000=JEP00
FUH01UYF00<005YFFUH00eYF00<005YFFUH00`00EWoo002bOol50004FUH01000FUIJEUYF1@00FGoo
002gOol8001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60719 .74291 m .59478 .68751 L .5644 .69274 L p .707 .577 .707 r
F P
0 g
s
.59478 .68751 m .60719 .74291 L .63831 .7357 L p .707 .577 .707 r
F P
0 g
s
.63831 .7357 m .62589 .68029 L .59478 .68751 L p .707 .577 .707 r
F P
0 g
s
.62589 .68029 m .63831 .7357 L .66712 .72721 L p .707 .577 .707 r
F P
0 g
s
.66712 .72721 m .6547 .67181 L .62589 .68029 L p .707 .577 .707 r
F P
0 g
s
.57682 .74814 m .5644 .69274 L .53774 .69548 L p .707 .577 .707 r
F P
0 g
s
.5644 .69274 m .57682 .74814 L .60719 .74291 L p .707 .577 .707 r
F P
0 g
s
.6547 .67181 m .66712 .72721 L .69081 .71828 L p .707 .577 .707 r
F P
0 g
s
.69081 .71828 m .67839 .66288 L .6547 .67181 L p .707 .577 .707 r
F P
0 g
s
.53774 .69548 m .55016 .75088 L .57682 .74814 L p .707 .577 .707 r
F P
0 g
s
.55016 .75088 m .53774 .69548 L .51741 .69546 L p .707 .577 .707 r
F P
0 g
s
.58662 .80139 m .57837 .76446 L .54799 .76967 L p .707 .577 .707 r
F P
0 g
s
.57837 .76446 m .58662 .80139 L .61774 .7942 L p .707 .577 .707 r
F P
0 g
s
.61774 .7942 m .60949 .75726 L .57837 .76446 L p .707 .577 .707 r
F P
0 g
s
.60949 .75726 m .61774 .7942 L .64655 .78573 L p .707 .577 .707 r
F P
0 g
s
.64655 .78573 m .6383 .74879 L .60949 .75726 L p .707 .577 .707 r
F P
0 g
s
.67839 .66288 m .69081 .71828 L .70705 .70978 L p .707 .577 .707 r
F P
0 g
s
.70705 .70978 m .69463 .65438 L .67839 .66288 L p .707 .577 .707 r
F P
0 g
s
.54799 .76967 m .55624 .80661 L .58662 .80139 L p .707 .577 .707 r
F P
0 g
s
.51741 .69546 m .52982 .75087 L .55016 .75088 L p .707 .577 .707 r
F P
0 g
s
.55624 .80661 m .54799 .76967 L .52132 .77239 L p .707 .577 .707 r
F P
0 g
s
.59991 .86109 m .60569 .84418 L .5761 .8326 L p .707 .577 .707 r
F P
0 g
s
.60569 .84418 m .59991 .86109 L .63032 .86904 L p .707 .577 .707 r
F P
0 g
s
.63032 .86904 m .6361 .85213 L .60569 .84418 L p .707 .577 .707 r
F P
0 g
s
.6383 .74879 m .64655 .78573 L .67024 .77681 L p .707 .577 .707 r
F P
0 g
s
.67024 .77681 m .66199 .73987 L .6383 .74879 L p .707 .577 .707 r
F P
0 g
s
.57031 .84951 m .5761 .8326 L .55022 .81853 L p .707 .577 .707 r
F P
0 g
s
.5761 .8326 m .57031 .84951 L .59991 .86109 L p .707 .577 .707 r
F P
0 g
s
.52132 .77239 m .52958 .80933 L .55624 .80661 L p .707 .577 .707 r
F P
0 g
s
.6361 .85213 m .63032 .86904 L .65857 .87259 L p .707 .577 .707 r
F P
0 g
s
.65857 .87259 m .66435 .85568 L .6361 .85213 L p .707 .577 .707 r
F P
0 g
s
.55022 .81853 m .54444 .83544 L .57031 .84951 L p .707 .577 .707 r
F P
0 g
s
.52982 .75087 m .51741 .69546 L .50539 .69269 L p .707 .577 .707 r
F P
0 g
s
.52958 .80933 m .52132 .77239 L .50098 .77235 L p .707 .577 .707 r
F P
0 g
s
.54444 .83544 m .55022 .81853 L .53059 .80335 L p .707 .577 .707 r
F P
0 g
s
.69463 .65438 m .70705 .70978 L .71426 .70255 L p .707 .577 .707 r
F P
0 g
s
.71426 .70255 m .70184 .64715 L .69463 .65438 L p .707 .577 .707 r
F P
0 g
s
.66435 .85568 m .65857 .87259 L .6819 .87139 L p .707 .577 .707 r
F P
0 g
s
.6819 .87139 m .68768 .85448 L .66435 .85568 L p .707 .577 .707 r
F P
0 g
s
.66199 .73987 m .67024 .77681 L .68649 .76831 L p .707 .577 .707 r
F P
0 g
s
.68649 .76831 m .67823 .73138 L .66199 .73987 L p .707 .577 .707 r
F P
0 g
s
.50539 .69269 m .5178 .74809 L .52982 .75087 L p .707 .577 .707 r
F P
0 g
s
.50098 .77235 m .50924 .80929 L .52958 .80933 L p .707 .577 .707 r
F P
0 g
s
.53059 .80335 m .5248 .82026 L .54444 .83544 L p .707 .577 .707 r
F P
0 g
s
.5248 .82026 m .53059 .80335 L .51912 .78853 L p .707 .577 .707 r
F P
0 g
s
.50924 .80929 m .50098 .77235 L .48896 .76956 L p .707 .577 .707 r
F P
0 g
s
.5178 .74809 m .50539 .69269 L .50286 .68742 L p .707 .577 .707 r
F P
0 g
s
.68768 .85448 m .6819 .87139 L .69802 .86556 L p .707 .577 .707 r
F P
0 g
s
.69802 .86556 m .7038 .84865 L .68768 .85448 L p .707 .577 .707 r
F P
0 g
s
.51912 .78853 m .51334 .80544 L .5248 .82026 L p .707 .577 .707 r
F P
0 g
s
.48896 .76956 m .49721 .8065 L .50924 .80929 L p .707 .577 .707 r
F P
0 g
s
.67823 .73138 m .68649 .76831 L .69369 .76108 L p .707 .577 .707 r
F P
0 g
s
.69369 .76108 m .68544 .72414 L .67823 .73138 L p .707 .577 .707 r
F P
0 g
s
.70184 .64715 m .71426 .70255 L .71173 .69729 L p .707 .577 .707 r
F P
0 g
s
.71173 .69729 m .69931 .64188 L .70184 .64715 L p .707 .577 .707 r
F P
0 g
s
.50286 .68742 m .51527 .74283 L .5178 .74809 L p .707 .577 .707 r
F P
0 g
s
.51334 .80544 m .51912 .78853 L .51695 .77554 L p .707 .577 .707 r
F P
0 g
s
.49721 .8065 m .48896 .76956 L .48643 .76429 L p .707 .577 .707 r
F P
0 g
s
.48643 .76429 m .49468 .80122 L .49721 .8065 L p .707 .577 .707 r
F P
0 g
s
.49468 .80122 m .48643 .76429 L .49364 .75705 L p .707 .577 .707 r
F P
0 g
s
.48638 .82191 m .49231 .3207 L .44831 .31749 L p .707 .577 .707 r
F P
0 g
s
.51695 .77554 m .51117 .79245 L .51334 .80544 L p .707 .577 .707 r
F P
0 g
s
.51527 .74283 m .50286 .68742 L .51007 .68019 L p .707 .577 .707 r
F P
0 g
s
.51007 .68019 m .52248 .73559 L .51527 .74283 L p .707 .577 .707 r
F P
0 g
s
.51117 .79245 m .51695 .77554 L .52429 .76565 L p .707 .577 .707 r
F P
0 g
s
.52429 .76565 m .5185 .78256 L .51117 .79245 L p .707 .577 .707 r
F P
0 g
s
.52248 .73559 m .51007 .68019 L .52631 .67169 L p .707 .577 .707 r
F P
0 g
s
.49364 .75705 m .50189 .79399 L .49468 .80122 L p .707 .577 .707 r
F P
0 g
s
.52631 .67169 m .53872 .72709 L .52248 .73559 L p .707 .577 .707 r
F P
0 g
s
.5185 .78256 m .52429 .76565 L .54041 .75981 L p .707 .577 .707 r
F P
0 g
s
.54041 .75981 m .53462 .77672 L .5185 .78256 L p .707 .577 .707 r
F P
0 g
s
.50189 .79399 m .49364 .75705 L .50988 .74855 L p .707 .577 .707 r
F P
0 g
s
.50988 .74855 m .51813 .78549 L .50189 .79399 L p .707 .577 .707 r
F P
0 g
s
.51813 .78549 m .50988 .74855 L .53357 .73964 L p .707 .577 .707 r
F P
0 g
s
.53462 .77672 m .54041 .75981 L .56373 .75861 L p .707 .577 .707 r
F P
0 g
s
.56373 .75861 m .55795 .77552 L .53462 .77672 L p .707 .577 .707 r
F P
0 g
s
.53357 .73964 m .54182 .77657 L .51813 .78549 L p .707 .577 .707 r
F P
0 g
s
.49231 .3207 m .48638 .82191 L .53132 .82129 L p .707 .577 .707 r
F P
0 g
s
.53872 .72709 m .52631 .67169 L .55 .66276 L p .707 .577 .707 r
F P
0 g
s
.53132 .82129 m .53725 .32007 L .49231 .3207 L p .707 .577 .707 r
F P
0 g
s
.55 .66276 m .56241 .71816 L .53872 .72709 L p .707 .577 .707 r
F P
0 g
s
.56241 .71816 m .55 .66276 L .57881 .65428 L p .707 .577 .707 r
F P
0 g
s
.57881 .65428 m .59122 .70968 L .56241 .71816 L p .707 .577 .707 r
F P
0 g
s
.55795 .77552 m .56373 .75861 L .59198 .76216 L p .707 .577 .707 r
F P
0 g
s
.59198 .76216 m .5862 .77907 L .55795 .77552 L p .707 .577 .707 r
F P
0 g
s
.54182 .77657 m .53357 .73964 L .56238 .73116 L p .707 .577 .707 r
F P
0 g
s
.56238 .73116 m .57063 .7681 L .54182 .77657 L p .707 .577 .707 r
F P
0 g
s
.57063 .7681 m .56238 .73116 L .5935 .72397 L p .707 .577 .707 r
F P
0 g
s
.53725 .32007 m .53132 .82129 L .5728 .81689 L p .707 .577 .707 r
F P
0 g
s
.5862 .77907 m .59198 .76216 L .6224 .77011 L p .707 .577 .707 r
F P
0 g
s
.5935 .72397 m .60175 .76091 L .57063 .7681 L p .707 .577 .707 r
F P
0 g
s
.5728 .81689 m .57873 .31568 L .53725 .32007 L p .707 .577 .707 r
F P
0 g
s
.7038 .84865 m .69802 .86556 L .70535 .85566 L p .707 .577 .707 r
F P
0 g
s
.70535 .85566 m .71113 .83875 L .7038 .84865 L p .707 .577 .707 r
F P
0 g
s
.44238 .8187 m .44831 .31749 L .40955 .31076 L p .707 .577 .707 r
F P
0 g
s
.44831 .31749 m .44238 .8187 L .48638 .82191 L p .707 .577 .707 r
F P
0 g
s
.68544 .72414 m .69369 .76108 L .69116 .7558 L p .707 .577 .707 r
F P
0 g
s
.69116 .7558 m .68291 .71887 L .68544 .72414 L p .707 .577 .707 r
F P
0 g
s
.69931 .64188 m .71173 .69729 L .69971 .69451 L p .707 .577 .707 r
F P
0 g
s
.69971 .69451 m .68729 .63911 L .69931 .64188 L p .707 .577 .707 r
F P
0 g
s
.59122 .70968 m .57881 .65428 L .60992 .64706 L p .707 .577 .707 r
F P
0 g
s
.60992 .64706 m .62234 .70247 L .59122 .70968 L p .707 .577 .707 r
F P
0 g
s
.62388 .71876 m .63213 .7557 L .60175 .76091 L p .707 .577 .707 r
F P
0 g
s
.60175 .76091 m .5935 .72397 L .62388 .71876 L p .707 .577 .707 r
F P
0 g
s
.6224 .77011 m .61661 .78702 L .5862 .77907 L p .707 .577 .707 r
F P
0 g
s
.57873 .31568 m .5728 .81689 L .60676 .80916 L p .707 .577 .707 r
F P
0 g
s
.60676 .80916 m .61269 .30795 L .57873 .31568 L p .707 .577 .707 r
F P
0 g
s
.26418 .70603 m .25177 .65063 L .2214 .65587 L p .707 .577 .707 r
F P
0 g
s
.25177 .65063 m .26418 .70603 L .2953 .69882 L p .707 .577 .707 r
F P
0 g
s
.2953 .69882 m .28289 .64342 L .25177 .65063 L p .707 .577 .707 r
F P
0 g
s
.28289 .64342 m .2953 .69882 L .32411 .69033 L p .707 .577 .707 r
F P
0 g
s
.32411 .69033 m .3117 .63493 L .28289 .64342 L p .707 .577 .707 r
F P
0 g
s
.40361 .81197 m .40955 .31076 L .37982 .30117 L p .707 .577 .707 r
F P
0 g
s
.40955 .31076 m .40361 .81197 L .44238 .8187 L p .707 .577 .707 r
F P
0 g
s
.71113 .83875 m .70535 .85566 L .70318 .84267 L p .707 .577 .707 r
F P
0 g
s
.70318 .84267 m .70896 .82576 L .71113 .83875 L p .707 .577 .707 r
F P
0 g
s
.23381 .71127 m .2214 .65587 L .19474 .65861 L p .707 .577 .707 r
F P
0 g
s
.2214 .65587 m .23381 .71127 L .26418 .70603 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3117 .63493 m .32411 .69033 L .3478 .68141 L p .707 .577 .707 r
F P
0 g
s
.3478 .68141 m .33538 .626 L .3117 .63493 L p .707 .577 .707 r
F P
0 g
s
.68291 .71887 m .69116 .7558 L .67914 .75301 L p .707 .577 .707 r
F P
0 g
s
.67914 .75301 m .67089 .71607 L .68291 .71887 L p .707 .577 .707 r
F P
0 g
s
.68729 .63911 m .69971 .69451 L .67937 .69449 L p .707 .577 .707 r
F P
0 g
s
.67937 .69449 m .66696 .63909 L .68729 .63911 L p .707 .577 .707 r
F P
0 g
s
.19474 .65861 m .20715 .71401 L .23381 .71127 L p .707 .577 .707 r
F P
0 g
s
.6403 .64183 m .65271 .69723 L .62234 .70247 L p .707 .577 .707 r
F P
0 g
s
.62234 .70247 m .60992 .64706 L .6403 .64183 L p .707 .577 .707 r
F P
0 g
s
.63213 .7557 m .62388 .71876 L .65055 .71604 L p .707 .577 .707 r
F P
0 g
s
.65199 .78169 m .64621 .7986 L .61661 .78702 L p .707 .577 .707 r
F P
0 g
s
.61661 .78702 m .6224 .77011 L .65199 .78169 L p .707 .577 .707 r
F P
0 g
s
.61269 .30795 m .60676 .80916 L .62986 .79884 L p .707 .577 .707 r
F P
0 g
s
.62986 .79884 m .6358 .29763 L .61269 .30795 L p .707 .577 .707 r
F P
0 g
s
.20715 .71401 m .19474 .65861 L .1744 .65859 L p .707 .577 .707 r
F P
0 g
s
.24361 .76441 m .23536 .72747 L .20498 .73268 L p .707 .577 .707 r
F P
0 g
s
.23536 .72747 m .24361 .76441 L .27473 .75721 L p .707 .577 .707 r
F P
0 g
s
.27473 .75721 m .26648 .72028 L .23536 .72747 L p .707 .577 .707 r
F P
0 g
s
.26648 .72028 m .27473 .75721 L .30354 .74874 L p .707 .577 .707 r
F P
0 g
s
.30354 .74874 m .29529 .71181 L .26648 .72028 L p .707 .577 .707 r
F P
0 g
s
.33538 .626 m .3478 .68141 L .36404 .67291 L p .707 .577 .707 r
F P
0 g
s
.36404 .67291 m .35162 .61751 L .33538 .626 L p .707 .577 .707 r
F P
0 g
s
.35162 .61751 m .36404 .67291 L .36679 .67014 L p .707 .577 .707 r
F P
0 g
s
.36679 .67014 m .37125 .66567 L p .36586 .65245 L .707 .577 .707 r
F P
0 g
s
.36586 .65245 m .35162 .61751 L .36679 .67014 L .707 .577 .707 r
F
.36205 .28967 m .35796 .27736 L p .3572 .48808 L F P
0 g
s
.37125 .66567 m .35883 .61027 L .35162 .61751 L p .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .35883 .61027 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.36872 .66041 m .3622 .63133 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .3563 .60501 L p .36369 .63488 L .707 .577 .707 r
F P
0 g
s
.3563 .60501 m .3622 .63133 L p .3567 .65763 L .707 .577 .707 r
F P
0 g
s
.3622 .63133 m .36872 .66041 L .36019 .65844 L p .707 .577 .707 r
F P
0 g
s
.36019 .65844 m .3567 .65763 L p .3622 .63133 L .707 .577 .707 r
F P
0 g
s
.3567 .65763 m .34428 .60223 L .3563 .60501 L p .707 .577 .707 r
F P
0 g
s
.34428 .60223 m .3567 .65763 L .33636 .65761 L p .707 .577 .707 r
F P
0 g
s
.35641 .70954 m .35924 .52677 L .3572 .48808 L .707 .577 .707 r
F
.36595 .78966 m .36017 .80657 L .36012 .8065 L p F P
0 g
s
.36012 .8065 m .34871 .79176 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.35942 .79045 m .36595 .78966 L .36012 .8065 L .707 .577 .707 r
F
.35637 .72066 m .35721 .69877 L .35641 .70954 L F
.34871 .79176 m .35449 .77485 L .35899 .78066 L p F P
0 g
s
.35899 .78066 m .36595 .78966 L p .35942 .79045 L .707 .577 .707 r
F P
0 g
s
.34871 .79176 m .35899 .78066 L .35942 .79045 L .707 .577 .707 r
F
.35449 .77485 m .34871 .79176 L .34056 .78546 L p F P
0 g
s
.34056 .78546 m .32908 .77657 L p .34105 .77576 L .707 .577 .707 r
F P
0 g
s
.34105 .77576 m .35449 .77485 L .34056 .78546 L .707 .577 .707 r
F
.35637 .72066 m .35674 .61823 L .35479 .68453 L F
.32908 .77657 m .33486 .75966 L .35449 .77485 L p F P
0 g
s
.35637 .72066 m .35479 .68453 L .35203 .77858 L .707 .577 .707 r
F
.35721 .69877 m .35924 .52677 L p .35641 .70954 L F P
0 g
s
.35796 .27736 m .354 .61168 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.354 .61168 m .35203 .77858 L p .35674 .61823 L .707 .577 .707 r
F P
0 g
s
.35924 .52677 m .36205 .28967 L p .3572 .48808 L .707 .577 .707 r
F P
0 g
s
.35883 .61027 m .37125 .66567 L .36872 .66041 L p .707 .577 .707 r
F P
0 g
s
.37389 .80239 m .37982 .30117 L .36205 .28967 L p .707 .577 .707 r
F P
0 g
s
.36017 .80657 m .36595 .78966 L .36812 .80265 L p .707 .577 .707 r
F P
0 g
s
.36205 .28967 m .35612 .79088 L .37389 .80239 L p .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35551 .48431 L p .36796 .26547 L .707 .577 .707 r
F P
0 g
s
.35551 .48431 m .35796 .27736 L .36627 .26748 L p .707 .577 .707 r
F P
0 g
s
.36627 .26748 m .36796 .26547 L p .35551 .48431 L .707 .577 .707 r
F P
0 g
s
.35203 .77858 m .35612 .79088 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35612 .79088 m .35682 .73109 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.35682 .73109 m .35721 .69877 L p .35637 .72066 L .707 .577 .707 r
F P
0 g
s
.37982 .30117 m .37389 .80239 L .40361 .81197 L p .707 .577 .707 r
F P
0 g
s
.70896 .82576 m .70318 .84267 L .69172 .82786 L p .707 .577 .707 r
F P
0 g
s
.69172 .82786 m .6975 .81095 L .70896 .82576 L p .707 .577 .707 r
F P
0 g
s
.20498 .73268 m .21323 .76962 L .24361 .76441 L p .707 .577 .707 r
F P
0 g
s
.1744 .65859 m .18681 .71399 L .20715 .71401 L p .707 .577 .707 r
F P
0 g
s
.21323 .76962 m .20498 .73268 L .17831 .7354 L p .707 .577 .707 r
F P
0 g
s
.2569 .82499 m .26268 .80808 L .23309 .7965 L p .707 .577 .707 r
F P
0 g
s
.26268 .80808 m .2569 .82499 L .28731 .83294 L p .707 .577 .707 r
F P
0 g
s
.28731 .83294 m .29309 .81603 L .26268 .80808 L p .707 .577 .707 r
F P
0 g
s
.29529 .71181 m .30354 .74874 L .32723 .73982 L p .707 .577 .707 r
F P
0 g
s
.32723 .73982 m .31898 .70289 L .29529 .71181 L p .707 .577 .707 r
F P
0 g
s
.66696 .63909 m .67937 .69449 L .65271 .69723 L p .707 .577 .707 r
F P
0 g
s
.65271 .69723 m .6403 .64183 L .66696 .63909 L p .707 .577 .707 r
F P
0 g
s
.22731 .81341 m .23309 .7965 L .20721 .78243 L p .707 .577 .707 r
F P
0 g
s
.23309 .7965 m .22731 .81341 L .2569 .82499 L p .707 .577 .707 r
F P
0 g
s
.17831 .7354 m .18657 .77234 L .21323 .76962 L p .707 .577 .707 r
F P
0 g
s
.29309 .81603 m .28731 .83294 L .31556 .83649 L p .707 .577 .707 r
F P
0 g
s
.31556 .83649 m .32134 .81958 L .29309 .81603 L p .707 .577 .707 r
F P
0 g
s
.67089 .71607 m .67914 .75301 L .6588 .75297 L p .707 .577 .707 r
F P
0 g
s
.6588 .75297 m .65055 .71604 L .67089 .71607 L p .707 .577 .707 r
F P
0 g
s
.20721 .78243 m .20143 .79934 L .22731 .81341 L p .707 .577 .707 r
F P
0 g
s
.18681 .71399 m .1744 .65859 L .16238 .65581 L p .707 .577 .707 r
F P
0 g
s
.18657 .77234 m .17831 .7354 L .15797 .73537 L p .707 .577 .707 r
F P
0 g
s
.20143 .79934 m .20721 .78243 L .18758 .76725 L p .707 .577 .707 r
F P
0 g
s
.65055 .71604 m .6588 .75297 L .63213 .7557 L p .707 .577 .707 r
F P
0 g
s
.6358 .29763 m .62986 .79884 L .63987 .78695 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .6458 .28574 L .6358 .29763 L p .707 .577 .707 r
F P
0 g
s
.32134 .81958 m .31556 .83649 L .33889 .83529 L p .707 .577 .707 r
F P
0 g
s
.33889 .83529 m .34467 .81838 L .32134 .81958 L p .707 .577 .707 r
F P
0 g
s
.31898 .70289 m .32723 .73982 L .34348 .73133 L p .707 .577 .707 r
F P
0 g
s
.34348 .73133 m .33522 .69439 L .31898 .70289 L p .707 .577 .707 r
F P
0 g
s
.6975 .81095 m .69172 .82786 L .67209 .81267 L p .707 .577 .707 r
F P
0 g
s
.67209 .81267 m .67787 .79576 L .6975 .81095 L p .707 .577 .707 r
F P
0 g
s
.16238 .65581 m .17479 .71121 L .18681 .71399 L p .707 .577 .707 r
F P
0 g
s
.15797 .73537 m .16623 .7723 L .18657 .77234 L p .707 .577 .707 r
F P
0 g
s
.18758 .76725 m .18179 .78415 L .20143 .79934 L p .707 .577 .707 r
F P
0 g
s
.18179 .78415 m .18758 .76725 L .17611 .75243 L p .707 .577 .707 r
F P
0 g
s
.16623 .7723 m .15797 .73537 L .14595 .73257 L p .707 .577 .707 r
F P
0 g
s
.17479 .71121 m .16238 .65581 L .15985 .65055 L p .707 .577 .707 r
F P
0 g
s
.67787 .79576 m .67209 .81267 L .64621 .7986 L p .707 .577 .707 r
F P
0 g
s
.64621 .7986 m .65199 .78169 L .67787 .79576 L p .707 .577 .707 r
F P
0 g
s
.34467 .81838 m .33889 .83529 L .35501 .82946 L p .707 .577 .707 r
F P
0 g
s
.35501 .82946 m .36079 .81255 L .34467 .81838 L p .707 .577 .707 r
F P
0 g
s
.17611 .75243 m .17033 .76934 L .18179 .78415 L p .707 .577 .707 r
F P
0 g
s
.14595 .73257 m .1542 .76951 L .16623 .7723 L p .707 .577 .707 r
F P
0 g
s
.33522 .69439 m .34348 .73133 L .35069 .72409 L p .707 .577 .707 r
F P
0 g
s
.35069 .72409 m .34243 .68715 L .33522 .69439 L p .707 .577 .707 r
F P
0 g
s
.15985 .65055 m .17226 .70595 L .17479 .71121 L p .707 .577 .707 r
F P
0 g
s
.63987 .78695 m .63578 .77465 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64244 .56957 m .63987 .78695 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .6458 .28574 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.63578 .77465 m .6374 .63778 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.6374 .63778 m .64171 .27343 L p .63904 .61559 L .707 .577 .707 r
F P
0 g
s
.64171 .27343 m .63578 .77465 L .618 .76314 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .64644 .71725 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.62616 .67752 m .6324 .70543 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.6324 .70543 m .63442 .71446 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63819 .68031 L .63432 .67942 L p .707 .577 .707 r
F P
0 g
s
.63432 .67942 m .62616 .67752 L p .63341 .69172 L .707 .577 .707 r
F P
0 g
s
.64644 .71725 m .63432 .67942 L .63341 .69172 L .707 .577 .707 r
F
.6458 .28574 m .64244 .56957 L p .63904 .61559 L F P
0 g
s
.17033 .76934 m .17611 .75243 L .17394 .73944 L p .707 .577 .707 r
F P
0 g
s
.1542 .76951 m .14595 .73257 L .14342 .7273 L p .707 .577 .707 r
F P
0 g
s
.17394 .73944 m .16816 .75635 L .17033 .76934 L p .707 .577 .707 r
F P
0 g
s
.36079 .81255 m .35501 .82946 L .36234 .81956 L p .707 .577 .707 r
F P
0 g
s
.36234 .81956 m .36812 .80265 L .36079 .81255 L p .707 .577 .707 r
F P
0 g
s
.17226 .70595 m .15985 .65055 L .16706 .64331 L p .707 .577 .707 r
F P
0 g
s
.14342 .7273 m .15167 .76424 L .1542 .76951 L p .707 .577 .707 r
F P
0 g
s
.34243 .68715 m .35069 .72409 L .34815 .71882 L p .707 .577 .707 r
F P
0 g
s
.34815 .71882 m .3399 .68188 L .34243 .68715 L p .707 .577 .707 r
F P
0 g
s
.16706 .64331 m .17947 .69872 L .17226 .70595 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16816 .75635 m .17394 .73944 L .18128 .72955 L p .707 .577 .707 r
F P
0 g
s
.18128 .72955 m .1755 .74645 L .16816 .75635 L p .707 .577 .707 r
F P
0 g
s
.36812 .80265 m .36234 .81956 L .36017 .80657 L p .707 .577 .707 r
F P
0 g
s
.15167 .76424 m .14342 .7273 L .15063 .72006 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17947 .69872 m .16706 .64331 L .1833 .63482 L p .707 .577 .707 r
F P
0 g
s
.618 .76314 m .62393 .26193 L .64171 .27343 L p .707 .577 .707 r
F P
0 g
s
.15063 .72006 m .15888 .757 L .15167 .76424 L p .707 .577 .707 r
F P
0 g
s
.3399 .68188 m .34815 .71882 L .33613 .71603 L p .707 .577 .707 r
F P
0 g
s
.33613 .71603 m .32788 .67909 L .3399 .68188 L p .707 .577 .707 r
F P
0 g
s
.33636 .65761 m .32395 .60221 L .34428 .60223 L p .707 .577 .707 r
F P
0 g
s
.1833 .63482 m .19571 .69022 L .17947 .69872 L p .707 .577 .707 r
F P
0 g
s
.36203 .76669 m .36796 .26547 L .39107 .25515 L p .707 .577 .707 r
F P
0 g
s
.36796 .26547 m .36203 .76669 L .35203 .77858 L p .707 .577 .707 r
F P
0 g
s
.1755 .74645 m .18128 .72955 L .1974 .72371 L p .707 .577 .707 r
F P
0 g
s
.1974 .72371 m .19161 .74062 L .1755 .74645 L p .707 .577 .707 r
F P
0 g
s
.19571 .69022 m .1833 .63482 L .20699 .62589 L p .707 .577 .707 r
F P
0 g
s
.15888 .757 m .15063 .72006 L .16687 .71157 L p .707 .577 .707 r
F P
0 g
s
.32395 .60221 m .33636 .65761 L .3097 .66036 L p .707 .577 .707 r
F P
0 g
s
.3097 .66036 m .29729 .60496 L .32395 .60221 L p .707 .577 .707 r
F P
0 g
s
.16687 .71157 m .17512 .74851 L .15888 .757 L p .707 .577 .707 r
F P
0 g
s
.32788 .67909 m .33613 .71603 L .31579 .71599 L p .707 .577 .707 r
F P
0 g
s
.31579 .71599 m .30754 .67905 L .32788 .67909 L p .707 .577 .707 r
F P
0 g
s
.20699 .62589 m .2194 .68129 L .19571 .69022 L p .707 .577 .707 r
F P
0 g
s
.62393 .26193 m .618 .76314 L .58828 .75356 L p .707 .577 .707 r
F P
0 g
s
.58828 .75356 m .59421 .25234 L .62393 .26193 L p .707 .577 .707 r
F P
0 g
s
.19161 .74062 m .1974 .72371 L .22072 .72251 L p .707 .577 .707 r
F P
0 g
s
.2194 .68129 m .20699 .62589 L .2358 .6174 L p .707 .577 .707 r
F P
0 g
s
.29729 .60496 m .3097 .66036 L .27933 .66559 L p .707 .577 .707 r
F P
0 g
s
.27933 .66559 m .26691 .61019 L .29729 .60496 L p .707 .577 .707 r
F P
0 g
s
.22072 .72251 m .21494 .73942 L .19161 .74062 L p .707 .577 .707 r
F P
0 g
s
.17512 .74851 m .16687 .71157 L .19056 .70265 L p .707 .577 .707 r
F P
0 g
s
.39107 .25515 m .38514 .75637 L .36203 .76669 L p .707 .577 .707 r
F P
0 g
s
.38514 .75637 m .39107 .25515 L .42502 .24742 L p .707 .577 .707 r
F P
0 g
s
.2358 .6174 m .24821 .6728 L .2194 .68129 L p .707 .577 .707 r
F P
0 g
s
.7444 .65087 m .73198 .59547 L .70161 .6007 L p .707 .577 .707 r
F P
0 g
s
.73198 .59547 m .7444 .65087 L .77551 .64366 L p .707 .577 .707 r
F P
0 g
s
.77551 .64366 m .7631 .58826 L .73198 .59547 L p .707 .577 .707 r
F P
0 g
s
.24821 .6728 m .2358 .6174 L .26691 .61019 L p .707 .577 .707 r
F P
0 g
s
.7631 .58826 m .77551 .64366 L .80432 .63517 L p .707 .577 .707 r
F P
0 g
s
.80432 .63517 m .79191 .57977 L .7631 .58826 L p .707 .577 .707 r
F P
0 g
s
.26691 .61019 m .27933 .66559 L .24821 .6728 L p .707 .577 .707 r
F P
0 g
s
.30754 .67905 m .31579 .71599 L .28912 .71871 L p .707 .577 .707 r
F P
0 g
s
.28912 .71871 m .28087 .68177 L .30754 .67905 L p .707 .577 .707 r
F P
0 g
s
.19056 .70265 m .19881 .73959 L .17512 .74851 L p .707 .577 .707 r
F P
0 g
s
.71402 .6561 m .70161 .6007 L .67495 .60344 L p .707 .577 .707 r
F P
0 g
s
.70161 .6007 m .71402 .6561 L .7444 .65087 L p .707 .577 .707 r
F P
0 g
s
.21494 .73942 m .22072 .72251 L .24897 .72606 L p .707 .577 .707 r
F P
0 g
s
.79191 .57977 m .80432 .63517 L .82801 .62624 L p .707 .577 .707 r
F P
0 g
s
.82801 .62624 m .8156 .57084 L .79191 .57977 L p .707 .577 .707 r
F P
0 g
s
.33486 .75966 m .32908 .77657 L .3032 .7625 L p .707 .577 .707 r
F P
0 g
s
.3032 .7625 m .30898 .74559 L .33486 .75966 L p .707 .577 .707 r
F P
0 g
s
.59421 .25234 m .58828 .75356 L .54952 .74683 L p .707 .577 .707 r
F P
0 g
s
.54952 .74683 m .55545 .24561 L .59421 .25234 L p .707 .577 .707 r
F P
0 g
s
.19881 .73959 m .19056 .70265 L .21937 .69418 L p .707 .577 .707 r
F P
0 g
s
.24897 .72606 m .24319 .74297 L .21494 .73942 L p .707 .577 .707 r
F P
0 g
s
.67495 .60344 m .68736 .65885 L .71402 .6561 L p .707 .577 .707 r
F P
0 g
s
.28087 .68177 m .28912 .71871 L .25874 .72392 L p .707 .577 .707 r
F P
0 g
s
.25874 .72392 m .25049 .68699 L .28087 .68177 L p .707 .577 .707 r
F P
0 g
s
.21937 .69418 m .22762 .73112 L .19881 .73959 L p .707 .577 .707 r
F P
0 g
s
.24319 .74297 m .24897 .72606 L .27939 .73401 L p .707 .577 .707 r
F P
0 g
s
.68736 .65885 m .67495 .60344 L .65461 .60343 L p .707 .577 .707 r
F P
0 g
s
.30898 .74559 m .3032 .7625 L .2736 .75092 L p .707 .577 .707 r
F P
0 g
s
.2736 .75092 m .27939 .73401 L .30898 .74559 L p .707 .577 .707 r
F P
0 g
s
.41909 .74863 m .42502 .24742 L .4665 .24303 L p .707 .577 .707 r
F P
0 g
s
.42502 .24742 m .42018 .65652 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.4665 .24303 m .46057 .74424 L .41909 .74863 L p .707 .577 .707 r
F P
0 g
s
.42009 .55138 m .4325 .60678 L .44088 .60431 L p .707 .577 .707 r
F P
0 g
s
.44088 .60431 m .46131 .5983 L p .44888 .58414 L .707 .577 .707 r
F P
0 g
s
.44888 .58414 m .42009 .55138 L .44088 .60431 L .707 .577 .707 r
F
.41909 .74863 m .38514 .75637 L p .38626 .7421 L F P
0 g
s
.42018 .65652 m .41909 .74863 L p .38626 .7421 L .707 .577 .707 r
F P
0 g
s
.72382 .70935 m .71557 .67242 L .68519 .67763 L p .707 .577 .707 r
F P
0 g
s
.71557 .67242 m .72382 .70935 L .75494 .70216 L p .707 .577 .707 r
F P
0 g
s
.75494 .70216 m .74669 .66522 L .71557 .67242 L p .707 .577 .707 r
F P
0 g
s
.22762 .73112 m .21937 .69418 L .25049 .68699 L p .707 .577 .707 r
F P
0 g
s
.74669 .66522 m .75494 .70216 L .78376 .69369 L p .707 .577 .707 r
F P
0 g
s
.78376 .69369 m .77551 .65675 L .74669 .66522 L p .707 .577 .707 r
F P
0 g
s
.25049 .68699 m .25874 .72392 L .22762 .73112 L p .707 .577 .707 r
F P
0 g
s
.27939 .73401 m .2736 .75092 L .24319 .74297 L p .707 .577 .707 r
F P
0 g
s
.8156 .57084 m .82801 .62624 L .84425 .61774 L p .707 .577 .707 r
F P
0 g
s
.84425 .61774 m .83184 .56234 L .8156 .57084 L p .707 .577 .707 r
F P
0 g
s
.68519 .67763 m .69344 .71457 L .72382 .70935 L p .707 .577 .707 r
F P
0 g
s
.65461 .60343 m .66703 .65883 L .68736 .65885 L p .707 .577 .707 r
F P
0 g
s
.69344 .71457 m .68519 .67763 L .65853 .68035 L p .707 .577 .707 r
F P
0 g
s
.73711 .76905 m .74289 .75214 L .7133 .74056 L p .707 .577 .707 r
F P
0 g
s
.74289 .75214 m .73711 .76905 L .76752 .77701 L p .707 .577 .707 r
F P
0 g
s
.76752 .77701 m .7733 .7601 L .74289 .75214 L p .707 .577 .707 r
F P
0 g
s
.55545 .24561 m .54952 .74683 L .50551 .74362 L p .707 .577 .707 r
F P
0 g
s
.50551 .74362 m .51145 .2424 L .55545 .24561 L p .707 .577 .707 r
F P
0 g
s
.77551 .65675 m .78376 .69369 L .80745 .68477 L p .707 .577 .707 r
F P
0 g
s
.80745 .68477 m .79919 .64783 L .77551 .65675 L p .707 .577 .707 r
F P
0 g
s
.70752 .75747 m .7133 .74056 L .68742 .72649 L p .707 .577 .707 r
F P
0 g
s
.7133 .74056 m .70752 .75747 L .73711 .76905 L p .707 .577 .707 r
F P
0 g
s
.65853 .68035 m .66678 .71729 L .69344 .71457 L p .707 .577 .707 r
F P
0 g
s
.46057 .74424 m .4665 .24303 L .51145 .2424 L p .707 .577 .707 r
F P
0 g
s
.7733 .7601 m .76752 .77701 L .79577 .78056 L p .707 .577 .707 r
F P
0 g
s
.79577 .78056 m .80156 .76365 L .7733 .7601 L p .707 .577 .707 r
F P
0 g
s
.51145 .2424 m .50551 .74362 L .46057 .74424 L p .707 .577 .707 r
F P
0 g
s
.68742 .72649 m .68164 .7434 L .70752 .75747 L p .707 .577 .707 r
F P
0 g
s
.66703 .65883 m .65461 .60343 L .64259 .60065 L p .707 .577 .707 r
F P
0 g
s
.66678 .71729 m .65853 .68035 L .63819 .68031 L p .707 .577 .707 r
F P
0 g
s
.68164 .7434 m .68742 .72649 L .66779 .71131 L p .707 .577 .707 r
F P
0 g
s
.83184 .56234 m .84425 .61774 L .85146 .61051 L p .707 .577 .707 r
F P
0 g
s
.85146 .61051 m .83905 .55511 L .83184 .56234 L p .707 .577 .707 r
F P
0 g
s
.80156 .76365 m .79577 .78056 L .8191 .77935 L p .707 .577 .707 r
F P
0 g
s
.8191 .77935 m .82488 .76245 L .80156 .76365 L p .707 .577 .707 r
F P
0 g
s
.79919 .64783 m .80745 .68477 L .82369 .67628 L p .707 .577 .707 r
F P
0 g
s
.82369 .67628 m .81544 .63934 L .79919 .64783 L p .707 .577 .707 r
F P
0 g
s
.64259 .60065 m .65501 .65605 L .66703 .65883 L p .707 .577 .707 r
F P
0 g
s
.63819 .68031 m .64644 .71725 L .66678 .71729 L p .707 .577 .707 r
F P
0 g
s
.66779 .71131 m .66201 .72822 L .68164 .7434 L p .707 .577 .707 r
F P
0 g
s
.66201 .72822 m .66779 .71131 L .65633 .6965 L p .707 .577 .707 r
F P
0 g
s
.65501 .65605 m .64259 .60065 L .64006 .59539 L p .707 .577 .707 r
F P
0 g
s
.82488 .76245 m .8191 .77935 L .83522 .77352 L p .707 .577 .707 r
F P
0 g
s
.83522 .77352 m .841 .75661 L .82488 .76245 L p .707 .577 .707 r
F P
0 g
s
.65633 .6965 m .65055 .71341 L .66201 .72822 L p .707 .577 .707 r
F P
0 g
s
.81544 .63934 m .82369 .67628 L .8309 .66904 L p .707 .577 .707 r
F P
0 g
s
.8309 .66904 m .82265 .6321 L .81544 .63934 L p .707 .577 .707 r
F P
0 g
s
.83905 .55511 m .85146 .61051 L .84893 .60525 L p .707 .577 .707 r
F P
0 g
s
.84893 .60525 m .83652 .54985 L .83905 .55511 L p .707 .577 .707 r
F P
0 g
s
.64006 .59539 m .65248 .65079 L .65501 .65605 L p .707 .577 .707 r
F P
0 g
s
.65055 .71341 m .65633 .6965 L .65416 .68351 L p .707 .577 .707 r
F P
0 g
s
.65416 .68351 m .64838 .70041 L .65055 .71341 L p .707 .577 .707 r
F P
0 g
s
.841 .75661 m .83522 .77352 L .84255 .76362 L p .707 .577 .707 r
F P
0 g
s
.84255 .76362 m .84834 .74671 L .841 .75661 L p .707 .577 .707 r
F P
0 g
s
.63442 .71446 m .62616 .67752 L .62363 .67225 L p .707 .577 .707 r
F P
0 g
s
.65248 .65079 m .64006 .59539 L .64727 .58815 L p .707 .577 .707 r
F P
0 g
s
.62363 .67225 m .63188 .70919 L .63442 .71446 L p .707 .577 .707 r
F P
0 g
s
.82265 .6321 m .8309 .66904 L .82837 .66377 L p .707 .577 .707 r
F P
0 g
s
.82837 .66377 m .82012 .62683 L .82265 .6321 L p .707 .577 .707 r
F P
0 g
s
.83652 .54985 m .84893 .60525 L .83691 .60247 L p .707 .577 .707 r
F P
0 g
s
.83691 .60247 m .8245 .54707 L .83652 .54985 L p .707 .577 .707 r
F P
0 g
s
.64727 .58815 m .65969 .64355 L .65248 .65079 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64838 .70041 m .65416 .68351 L .66149 .67361 L p .707 .577 .707 r
F P
0 g
s
.40139 .61399 m .38897 .55859 L .3586 .56383 L p .707 .577 .707 r
F P
0 g
s
.38897 .55859 m .40139 .61399 L .4325 .60678 L p .707 .577 .707 r
F P
0 g
s
.4325 .60678 m .42009 .55138 L .38897 .55859 L p .707 .577 .707 r
F P
0 g
s
.46131 .5983 m .4489 .54289 L .42009 .55138 L p .707 .577 .707 r
F P
0 g
s
.66149 .67361 m .65571 .69052 L .64838 .70041 L p .707 .577 .707 r
F P
0 g
s
.84834 .74671 m .84255 .76362 L .84038 .75063 L p .707 .577 .707 r
F P
0 g
s
.84038 .75063 m .84617 .73372 L .84834 .74671 L p .707 .577 .707 r
F P
0 g
s
.63188 .70919 m .62363 .67225 L .63084 .66501 L p .707 .577 .707 r
F P
0 g
s
.37101 .61923 m .3586 .56383 L .33194 .56657 L p .707 .577 .707 r
F P
0 g
s
.3586 .56383 m .37101 .61923 L .40139 .61399 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65969 .64355 m .64727 .58815 L .66351 .57965 L p .707 .577 .707 r
F P
0 g
s
.4489 .54289 m .46131 .5983 L .485 .58937 L p .707 .577 .707 r
F P
0 g
s
.485 .58937 m .47259 .53396 L .4489 .54289 L p .707 .577 .707 r
F P
0 g
s
.63084 .66501 m .63909 .70195 L .63188 .70919 L p .707 .577 .707 r
F P
0 g
s
.82012 .62683 m .82837 .66377 L .81634 .66097 L p .707 .577 .707 r
F P
0 g
s
.81634 .66097 m .80809 .62404 L .82012 .62683 L p .707 .577 .707 r
F P
0 g
s
.8245 .54707 m .83691 .60247 L .81658 .60245 L p .707 .577 .707 r
F P
0 g
s
.81658 .60245 m .80416 .54705 L .8245 .54707 L p .707 .577 .707 r
F P
0 g
s
.33194 .56657 m .34435 .62197 L .37101 .61923 L p .707 .577 .707 r
F P
0 g
s
.66351 .57965 m .67593 .63506 L .65969 .64355 L p .707 .577 .707 r
F P
0 g
s
.34435 .62197 m .33194 .56657 L .3116 .56655 L p .707 .577 .707 r
F P
0 g
s
.65571 .69052 m .66149 .67361 L .67761 .66777 L p .707 .577 .707 r
F P
0 g
s
.38081 .67237 m .37256 .63543 L .34218 .64064 L p .707 .577 .707 r
F P
0 g
s
.37256 .63543 m .38081 .67237 L .41193 .66518 L p .707 .577 .707 r
F P
0 g
s
.41193 .66518 m .40368 .62824 L .37256 .63543 L p .707 .577 .707 r
F P
0 g
s
.40368 .62824 m .41193 .66518 L .44075 .6567 L p .707 .577 .707 r
F P
0 g
s
.44075 .6567 m .4325 .61977 L .40368 .62824 L p .707 .577 .707 r
F P
0 g
s
.47259 .53396 m .485 .58937 L .50124 .58087 L p .707 .577 .707 r
F P
0 g
s
.50124 .58087 m .48883 .52547 L .47259 .53396 L p .707 .577 .707 r
F P
0 g
s
.67761 .66777 m .67183 .68468 L .65571 .69052 L p .707 .577 .707 r
F P
0 g
s
.84617 .73372 m .84038 .75063 L .82892 .73582 L p .707 .577 .707 r
F P
0 g
s
.82892 .73582 m .8347 .71891 L .84617 .73372 L p .707 .577 .707 r
F P
0 g
s
.34218 .64064 m .35043 .67758 L .38081 .67237 L p .707 .577 .707 r
F P
0 g
s
.67593 .63506 m .66351 .57965 L .6872 .57072 L p .707 .577 .707 r
F P
0 g
s
.3116 .56655 m .32402 .62195 L .34435 .62197 L p .707 .577 .707 r
F P
0 g
s
.35043 .67758 m .34218 .64064 L .31552 .64337 L p .707 .577 .707 r
F P
0 g
s
.63909 .70195 m .63084 .66501 L .64708 .65652 L p .707 .577 .707 r
F P
0 g
s
.3941 .73295 m .39988 .71604 L .37029 .70446 L p .707 .577 .707 r
F P
0 g
s
.39988 .71604 m .3941 .73295 L .42451 .7409 L p .707 .577 .707 r
F P
0 g
s
.42451 .7409 m .43029 .724 L .39988 .71604 L p .707 .577 .707 r
F P
0 g
s
.4325 .61977 m .44075 .6567 L .46444 .64779 L p .707 .577 .707 r
F P
0 g
s
.46444 .64779 m .45618 .61085 L .4325 .61977 L p .707 .577 .707 r
F P
0 g
s
.80416 .54705 m .81658 .60245 L .78992 .60519 L p .707 .577 .707 r
F P
0 g
s
.78992 .60519 m .7775 .54979 L .80416 .54705 L p .707 .577 .707 r
F P
0 g
s
.36451 .72137 m .37029 .70446 L .34441 .69039 L p .707 .577 .707 r
F P
0 g
s
.37029 .70446 m .36451 .72137 L .3941 .73295 L p .707 .577 .707 r
F P
0 g
s
.31552 .64337 m .32377 .6803 L .35043 .67758 L p .707 .577 .707 r
F P
0 g
s
.64708 .65652 m .65534 .69345 L .63909 .70195 L p .707 .577 .707 r
F P
0 g
s
.43029 .724 m .42451 .7409 L .45276 .74445 L p .707 .577 .707 r
F P
0 g
s
.45276 .74445 m .45855 .72754 L .43029 .724 L p .707 .577 .707 r
F P
0 g
s
.80809 .62404 m .81634 .66097 L .796 .66094 L p .707 .577 .707 r
F P
0 g
s
.796 .66094 m .78775 .624 L .80809 .62404 L p .707 .577 .707 r
F P
0 g
s
.6872 .57072 m .69961 .62613 L .67593 .63506 L p .707 .577 .707 r
F P
0 g
s
.34441 .69039 m .33863 .7073 L .36451 .72137 L p .707 .577 .707 r
F P
0 g
s
.32402 .62195 m .3116 .56655 L .29958 .56377 L p .707 .577 .707 r
F P
0 g
s
.32377 .6803 m .31552 .64337 L .29518 .64333 L p .707 .577 .707 r
F P
0 g
s
.67183 .68468 m .67761 .66777 L .70094 .66657 L p .707 .577 .707 r
F P
0 g
s
.33863 .7073 m .34441 .69039 L .32478 .67521 L p .707 .577 .707 r
F P
0 g
s
.69961 .62613 m .6872 .57072 L .71601 .56224 L p .707 .577 .707 r
F P
0 g
s
.48883 .52547 m .50124 .58087 L .50845 .57363 L p .707 .577 .707 r
F P
0 g
s
.50845 .57363 m .49604 .51823 L .48883 .52547 L p .707 .577 .707 r
F P
0 g
s
.7775 .54979 m .78992 .60519 L .75954 .61043 L p .707 .577 .707 r
F P
0 g
s
.75954 .61043 m .74713 .55503 L .7775 .54979 L p .707 .577 .707 r
F P
0 g
s
.45855 .72754 m .45276 .74445 L .47609 .74325 L p .707 .577 .707 r
F P
0 g
s
.47609 .74325 m .48187 .72634 L .45855 .72754 L p .707 .577 .707 r
F P
0 g
s
.45618 .61085 m .46444 .64779 L .48068 .63929 L p .707 .577 .707 r
F P
0 g
s
.48068 .63929 m .47243 .60235 L .45618 .61085 L p .707 .577 .707 r
F P
0 g
s
.8347 .71891 m .82892 .73582 L .80929 .72063 L p .707 .577 .707 r
F P
0 g
s
.80929 .72063 m .81507 .70373 L .8347 .71891 L p .707 .577 .707 r
F P
0 g
s
.29958 .56377 m .312 .61917 L .32402 .62195 L p .707 .577 .707 r
F P
0 g
s
.29518 .64333 m .30343 .68027 L .32377 .6803 L p .707 .577 .707 r
F P
0 g
s
.70094 .66657 m .69516 .68348 L .67183 .68468 L p .707 .577 .707 r
F P
0 g
s
.32478 .67521 m .319 .69212 L .33863 .7073 L p .707 .577 .707 r
F P
0 g
s
.65534 .69345 m .64708 .65652 L .67077 .6476 L p .707 .577 .707 r
F P
0 g
s
.71601 .56224 m .72843 .61764 L .69961 .62613 L p .707 .577 .707 r
F P
0 g
s
.72843 .61764 m .71601 .56224 L .74713 .55503 L p .707 .577 .707 r
F P
0 g
s
.74713 .55503 m .75954 .61043 L .72843 .61764 L p .707 .577 .707 r
F P
0 g
s
.78775 .624 m .796 .66094 L .76934 .66366 L p .707 .577 .707 r
F P
0 g
s
.76934 .66366 m .76109 .62672 L .78775 .624 L p .707 .577 .707 r
F P
0 g
s
.67077 .6476 m .67902 .68453 L .65534 .69345 L p .707 .577 .707 r
F P
0 g
s
.319 .69212 m .32478 .67521 L .31332 .66039 L p .707 .577 .707 r
F P
0 g
s
.69516 .68348 m .70094 .66657 L .72919 .67012 L p .707 .577 .707 r
F P
0 g
s
.30343 .68027 m .29518 .64333 L .28315 .64054 L p .707 .577 .707 r
F P
0 g
s
.312 .61917 m .29958 .56377 L .29705 .55851 L p .707 .577 .707 r
F P
0 g
s
.81507 .70373 m .80929 .72063 L .78341 .70656 L p .707 .577 .707 r
F P
0 g
s
.78341 .70656 m .78919 .68965 L .81507 .70373 L p .707 .577 .707 r
F P
0 g
s
.48187 .72634 m .47609 .74325 L .49221 .73742 L p .707 .577 .707 r
F P
0 g
s
.49221 .73742 m .49799 .72051 L .48187 .72634 L p .707 .577 .707 r
F P
0 g
s
.31332 .66039 m .30754 .6773 L .319 .69212 L p .707 .577 .707 r
F P
0 g
s
.72919 .67012 m .72341 .68703 L .69516 .68348 L p .707 .577 .707 r
F P
0 g
s
.67902 .68453 m .67077 .6476 L .69959 .63913 L p .707 .577 .707 r
F P
0 g
s
.28315 .64054 m .29141 .67747 L .30343 .68027 L p .707 .577 .707 r
F P
0 g
s
.47243 .60235 m .48068 .63929 L .48789 .63205 L p .707 .577 .707 r
F P
0 g
s
.48789 .63205 m .47964 .59512 L .47243 .60235 L p .707 .577 .707 r
F P
0 g
s
.76109 .62672 m .76934 .66366 L .73896 .66887 L p .707 .577 .707 r
F P
0 g
s
.73896 .66887 m .73071 .63193 L .76109 .62672 L p .707 .577 .707 r
F P
0 g
s
.49604 .51823 m .50845 .57363 L .50592 .56837 L p .707 .577 .707 r
F P
0 g
s
.50592 .56837 m .49351 .51297 L .49604 .51823 L p .707 .577 .707 r
F P
0 g
s
.29705 .55851 m .30947 .61391 L .312 .61917 L p .707 .577 .707 r
F P
0 g
s
.69959 .63913 m .70784 .67606 L .67902 .68453 L p .707 .577 .707 r
F P
0 g
s
.72341 .68703 m .72919 .67012 L .7596 .67808 L p .707 .577 .707 r
F P
0 g
s
.78919 .68965 m .78341 .70656 L .75382 .69498 L p .707 .577 .707 r
F P
0 g
s
.75382 .69498 m .7596 .67808 L .78919 .68965 L p .707 .577 .707 r
F P
0 g
s
.70784 .67606 m .69959 .63913 L .73071 .63193 L p .707 .577 .707 r
F P
0 g
s
.73071 .63193 m .73896 .66887 L .70784 .67606 L p .707 .577 .707 r
F P
0 g
s
.7596 .67808 m .75382 .69498 L .72341 .68703 L p .707 .577 .707 r
F P
0 g
s
.30754 .6773 m .31332 .66039 L .31115 .6474 L p .707 .577 .707 r
F P
0 g
s
.29141 .67747 m .28315 .64054 L .28062 .63526 L p .707 .577 .707 r
F P
0 g
s
.31115 .6474 m .30537 .66431 L .30754 .6773 L p .707 .577 .707 r
F P
0 g
s
.49799 .72051 m .49221 .73742 L .49954 .72752 L p .707 .577 .707 r
F P
0 g
s
.49954 .72752 m .50533 .71061 L .49799 .72051 L p .707 .577 .707 r
F P
0 g
s
.30947 .61391 m .29705 .55851 L .30426 .55128 L p .707 .577 .707 r
F P
0 g
s
.28062 .63526 m .28887 .6722 L .29141 .67747 L p .707 .577 .707 r
F P
0 g
s
.47964 .59512 m .48789 .63205 L .48536 .62678 L p .707 .577 .707 r
F P
0 g
s
.48536 .62678 m .4771 .58984 L .47964 .59512 L p .707 .577 .707 r
F P
0 g
s
.49351 .51297 m .50592 .56837 L .4939 .56559 L p .707 .577 .707 r
F P
0 g
s
.4939 .56559 m .48149 .51019 L .49351 .51297 L p .707 .577 .707 r
F P
0 g
s
.30426 .55128 m .31668 .60668 L .30947 .61391 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30537 .66431 m .31115 .6474 L .31848 .63751 L p .707 .577 .707 r
F P
0 g
s
.31848 .63751 m .3127 .65442 L .30537 .66431 L p .707 .577 .707 r
F P
0 g
s
.50533 .71061 m .49954 .72752 L .49737 .71453 L p .707 .577 .707 r
F P
0 g
s
.49737 .71453 m .50316 .69762 L .50533 .71061 L p .707 .577 .707 r
F P
0 g
s
.28887 .6722 m .28062 .63526 L .28783 .62803 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31668 .60668 m .30426 .55128 L .3205 .54278 L p .707 .577 .707 r
F P
0 g
s
.28783 .62803 m .29608 .66496 L .28887 .6722 L p .707 .577 .707 r
F P
0 g
s
.4771 .58984 m .48536 .62678 L .47333 .62399 L p .707 .577 .707 r
F P
0 g
s
.47333 .62399 m .46508 .58705 L .4771 .58984 L p .707 .577 .707 r
F P
0 g
s
.48149 .51019 m .4939 .56559 L .47357 .56558 L p .707 .577 .707 r
F P
0 g
s
.47357 .56558 m .46115 .51017 L .48149 .51019 L p .707 .577 .707 r
F P
0 g
s
.3205 .54278 m .33292 .59818 L .31668 .60668 L p .707 .577 .707 r
F P
0 g
s
.3127 .65442 m .31848 .63751 L .3346 .63167 L p .707 .577 .707 r
F P
0 g
s
.3346 .63167 m .32882 .64858 L .3127 .65442 L p .707 .577 .707 r
F P
0 g
s
.50316 .69762 m .49737 .71453 L .48591 .69972 L p .707 .577 .707 r
F P
0 g
s
.48591 .69972 m .49169 .68281 L .50316 .69762 L p .707 .577 .707 r
F P
0 g
s
.33292 .59818 m .3205 .54278 L .34419 .53385 L p .707 .577 .707 r
F P
0 g
s
.29608 .66496 m .28783 .62803 L .30407 .61953 L p .707 .577 .707 r
F P
0 g
s
.46115 .51017 m .47357 .56558 L .44691 .56832 L p .707 .577 .707 r
F P
0 g
s
.44691 .56832 m .43449 .51292 L .46115 .51017 L p .707 .577 .707 r
F P
0 g
s
.30407 .61953 m .31233 .65647 L .29608 .66496 L p .707 .577 .707 r
F P
0 g
s
.46508 .58705 m .47333 .62399 L .45299 .62395 L p .707 .577 .707 r
F P
0 g
s
.45299 .62395 m .44474 .58701 L .46508 .58705 L p .707 .577 .707 r
F P
0 g
s
.34419 .53385 m .3566 .58925 L .33292 .59818 L p .707 .577 .707 r
F P
0 g
s
.32882 .64858 m .3346 .63167 L .35793 .63047 L p .707 .577 .707 r
F P
0 g
s
.3566 .58925 m .34419 .53385 L .373 .52536 L p .707 .577 .707 r
F P
0 g
s
.43449 .51292 m .44691 .56832 L .41653 .57355 L p .707 .577 .707 r
F P
0 g
s
.41653 .57355 m .40412 .51815 L .43449 .51292 L p .707 .577 .707 r
F P
0 g
s
.49169 .68281 m .48591 .69972 L .46628 .68453 L p .707 .577 .707 r
F P
0 g
s
.46628 .68453 m .47206 .66762 L .49169 .68281 L p .707 .577 .707 r
F P
0 g
s
.35793 .63047 m .35214 .64738 L .32882 .64858 L p .707 .577 .707 r
F P
0 g
s
.31233 .65647 m .30407 .61953 L .32776 .61061 L p .707 .577 .707 r
F P
0 g
s
.373 .52536 m .38542 .58076 L .3566 .58925 L p .707 .577 .707 r
F P
0 g
s
.38542 .58076 m .373 .52536 L .40412 .51815 L p .707 .577 .707 r
F P
0 g
s
.40412 .51815 m .41653 .57355 L .38542 .58076 L p .707 .577 .707 r
F P
0 g
s
.44474 .58701 m .45299 .62395 L .42633 .62667 L p .707 .577 .707 r
F P
0 g
s
.42633 .62667 m .41808 .58973 L .44474 .58701 L p .707 .577 .707 r
F P
0 g
s
.32776 .61061 m .33601 .64755 L .31233 .65647 L p .707 .577 .707 r
F P
0 g
s
.35214 .64738 m .35793 .63047 L .38618 .63402 L p .707 .577 .707 r
F P
0 g
s
.47206 .66762 m .46628 .68453 L .4404 .67046 L p .707 .577 .707 r
F P
0 g
s
.4404 .67046 m .44618 .65355 L .47206 .66762 L p .707 .577 .707 r
F P
0 g
s
.33601 .64755 m .32776 .61061 L .35658 .60214 L p .707 .577 .707 r
F P
0 g
s
.38618 .63402 m .3804 .65093 L .35214 .64738 L p .707 .577 .707 r
F P
0 g
s
.41808 .58973 m .42633 .62667 L .39595 .63188 L p .707 .577 .707 r
F P
0 g
s
.39595 .63188 m .3877 .59495 L .41808 .58973 L p .707 .577 .707 r
F P
0 g
s
.35658 .60214 m .36483 .63908 L .33601 .64755 L p .707 .577 .707 r
F P
0 g
s
.3804 .65093 m .38618 .63402 L .41659 .64197 L p .707 .577 .707 r
F P
0 g
s
.44618 .65355 m .4404 .67046 L .41081 .65888 L p .707 .577 .707 r
F P
0 g
s
.41081 .65888 m .41659 .64197 L .44618 .65355 L p .707 .577 .707 r
F P
0 g
s
.36483 .63908 m .35658 .60214 L .3877 .59495 L p .707 .577 .707 r
F P
0 g
s
.3877 .59495 m .39595 .63188 L .36483 .63908 L p .707 .577 .707 r
F P
0 g
s
.41659 .64197 m .41081 .65888 L .3804 .65093 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001XOol00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`<000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH0000C0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`800003FUH005YF00EJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00I7oo0P0000=JEP00FUH015YF100000=JEP00FUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00000010001EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00HGoo0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001OOol30009FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005eoo`80009JEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
FWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00:Woo2`00<Goo001FOol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000ROol80003
FUH00`00FUIJEP03FUH01000FUH00000;goo001EOol20005FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP03
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000KOol70003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005Aoo`03001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Moo`@0
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH^Ool005Aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000COol40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/00003FUH0000000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP80015oo`800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF1000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003Woo0`000eYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P002goo0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo001EOol01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1@0025YF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH0000]Ool005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000goo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01000FUIJEP0015YF00<005YFFUH01EYF
00<005YFFUH0100015YF00<005YFFUH01UYF00<005YF00002P000eYF00@005YF000000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEUYF008002aoo`00EWoo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJ
EP03001JEUYF009JEPH000=JEP03001JEUYF00=JEP05001JEP00001JEP020005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;7oo001FOol01000FUIJEP0015YF00@005YFFUIJEP8000=JEP03001JEUYF00IJEPD0
0003FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000[
Ool005Ioo`04001JEUYF0004FUH01000FUH000001EYF00<005YFFUH00UYF1@001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo
00@005YFFUH000AJEP<000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00:goo001FOol01P00FUIJEUYF001J
EP80009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPX0009JEP03001oogoo02Uoo`00D7oo1`000eYF0P0015YF100000=JEP00FUH0
25YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
0UYF1@00:Woo001:Ool60004FUH01000FUIJEUYF0P0000=JEP0000000`001EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1P001eYF00<005YFFUH015YF00<005YFFUH00UYF
00@005YFFUH002Yoo`00AWoo100000=JEP00FUH025YF00D005YF000005YF00800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002]oo`00@Goo1@001EYF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP@000QJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00?Goo10000UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00AJEP03001J
EUYF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0
000^Ool003Yoo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH005YF00IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH;00000eYF00000004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH0
0`00FUIJEP04FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUH0000:0004FUH3000_Ool0
03Qoo`<000UJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF009JEP03
001JEUYF00=JEP@000UJEP03001JEP0000L000=JEP03001JEUYF00=JEP03001JEP0000@0035oo`00
=Woo0P000UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEP00008000AJEP04001JEUYFFUH70004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00<goo000cOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0:0007FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000017oo001JEP001EYF0P001eYF10000UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH003=oo`00<Goo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF10000eYF00<005YFFUH010001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00
FUH000=JEP800003FUH005YF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YF
FUH015YF100015YF00<005YFFUH015YF00D005YFFUIJEP0000MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP<000AJEP<00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol002ioo`8000EJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
1EYF00<005YF00000`001eYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP<000QJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YF
FUH20003FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00<Woo000^Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH:0004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30006FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20003FUH00`00FUH000030007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`00
15YF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF1P0035YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF100000=JEP00FUH01eYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<Goo000]Ool01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0004
FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH300000eYF001JEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00<Goo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH01000FUH000001eYF00<005YFFUH01UYF00<005YFFUH015YF1000
25YF00<005YFFUH00P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
2`0000=JEP00Ool0<7oo000^Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002FUH30002FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH40004
FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH60005FUH00`00FUIJEP02FUH3000aOol002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH50002FUH300000eYF001JEP020006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH500001UYF00000000FUH000MJEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH00000<7oo000^Ool0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YF001J
EP800005FUH005YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH2
0008FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP00<7oo000^Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1EYF1@0025YF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00
FUIJEP04FUH20005FUH01000FUIJEP001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0
0000008000QJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00;Woo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00IJEP80009JEP8000AJEP04001JEUYFFUH8
0005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF00001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH01EYF10000UYF00<005YFFUH015YF100015YF00<005YFFUH01EYF00@005YFFUIJ
EP80039oo`00;goo00@005YFFUH000=JEP03001JEUYF00AJEP@000QJEP03001JEUYF009JEP/0009J
EP03001JEP0000<00006FUH00000001JEP001UYF00<005YF00000P001EYF00<005YFFUH025YF0`00
1EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF0000
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01UYF00@005YF
0000009JEP03001JEUYF00EJEP04001JEP00000dOol002moo`04001JEUYF0004FUH01000FUIJEUYF
0P000eYF00<005YFFUH01UYF1@0000=JEP00FUH01UYF0P000UYF00<005YFFUH010000Woo00<005YF
00001UYF1P0015YF00<005YFFUH025YF00<005YF00001UYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEP00001JEP0015YF00<005YFFUH015YF2@0015YF00<005YFFUH0
1eYF00@005YFFUIJEP<000IJEP<003Ioo`00;goo00@005YFFUH000AJEP04001JEP000005FUH00`00
FUIJEP02FUH50006FUH00`00FUIJEP04FUH01000FUH000001EYF0P000Woo00<005YF00001UYF1P00
15YF00<005YFFUH025YF00<005YFFUH00P0015YF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH7
0006FUH00`00FUIJEP04FUH20003FUH2000iOol002moo`04001JEUYF0004FUH30006FUH50002FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00006FUH01P00Oomoo`00FUH000IJEPH000AJEP03
001JEUYF00QJEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP04001JEP000005FUH00`00FUIJEP06FUH01000FUIJ
EUYF10000UYF00<005YFFUH01UYF0`00>goo000_Ool01P00FUIJEUYF001JEP80009JEP04001JEUYF
FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF100000=JEP00FUH01EYF
00<005YF00000P001EYF00<005YFFUH025YF00<005YFFUH00eYF0`000eYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH40007FUH01000FUH00000>Woo000`Ool3FUH20004FUH400000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YFFUH00`001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEP000005FUH01000FUIJEUYF0P00>7oo000`Ool015YF000005YF
1@001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=J
EP00FUH015YF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH00000FUH20007
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH500001Woo00000000FUH000IJEP8003Ioo`00<7oo0P00
00EJEP00001JEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP<000MJEP<0009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF
00000007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`0cOol0031oo`<0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP8000QJEP03001JEP00008000UJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000eYF0P001UYF00<005YF
FUH01EYF10003goo0P001UYF0`00<goo000^Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH00UYF
0`001eYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP80009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00@001Eoo`80
00=JEP05001JEUYFFUH0000bOol002aoo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH;000015YF000000000eYF00<005YFFUH01EYF10000eYF
00<005YFFUH025YF00<005YFFUH025YF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF1P000eYF2`002Goo0`003goo0P0000=JEP00FUH00eYF0P00<7oo000ZOol20003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP02
FUH80009FUH00`00FUIJEP04000:FUH00`00FUIJEP07FUH4000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002FUH00`00FUH00002FUH00`00FUIJEP05000;Ool5000@Ool20006
FUH00`00Oomoo`0]Ool002Uoo`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL000IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP030008FUH00`00FUIJEP04
FUH60004FUH00`00FUIJEP05FUH2000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF0P0000=JEP00FUH00eYF0P003Goo1@004Woo00<005YFFUH00eYF0P00
;Woo000XOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02P001eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0009JEP<000AJEP03001JEUYF00MJEP04
001JEUYFFUH<0002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUH000001UYF00<007ooOol02Woo1@004goo00L005YFFUIJEP00FUH0000^
Ool002Qoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04
0007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00Oomoo`00FUH000EJEP<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH01000FUIJEP001UYF0`002goo0`005Goo
00@005YFFUH0009JEP03001oogoo02]oo`00:Goo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P001eYF00<005YFFUH015YF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000=oo`03
001JEP0000IJEP03001JEP00008000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP05
001JEUYFFUH00004FUH01000FUIJEUYF0P008Woo0P0015YF00<007ooOol0:Woo000YOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUH000030007FUH00`00FUIJEP07FUH30003FUH00`00FUIJEP05
FUH30004Ool00`00FUH00006FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP80025oo`03001JEUYF009JEP03
001oogoo02Yoo`00:Goo00@005YFFUH000AJEP03001JEUYF00=JEPX000AJEP03001JEUYF00IJEP04
001JEUYFFUH200000eYF001JEP05FUH20006Ool00`00FUH00006FUH00`00FUIJEP06FUH60004FUH0
0`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF0P0087oo00<005YFFUH00P00;7oo000Y
Ool01000FUIJEP0015YF00<005YF00000`0015YF00<005YFFUH00eYF1P001eYF00<005YFFUH00eYF
0`0000=JEP0000000P0027oo00<005YF000045YF00<005YFFUH00UYF6P001UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0P0025YF00<005YF00000P00
7Goo00H005YFFUH005YF000[Ool002Yoo`03001JEP0000AJEP<000MJEP03001JEUYF00IJEP03001J
EUYF00@0009JEP03001JEUYF00IJEP8000aoo`03001JEP0000mJEPP000aJEP03001JEUYF00UJEPT0
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP04001JEP000006FUH0
0`00FUIJEP02FUH3000KOol20002FUH00`00Oomoo`0YOol002Yoo`03001JEP0000=JEP04001JEP00
0007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40008FUH3000:Ool00`00FUH0000<FUH30007FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH3000IOol01000
FUIJEP00:goo000ZOol00`00FUIJEP0400000eYF00000007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH40004FUH01000FUIJEUYF0P0027oo00<005YF000025YF10002UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF4@0000Eoo`00001JEP00
00UJEP04001JEP00000GOol00`00FUH0000/Ool002Yoo`03001JEUYF00<00003FUH005YF008000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@0009oo`<00003FUH005YF00AJEP8000Ioo`03001JEP00
00EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP8000AJEP03001JEUYF009JEP<000IJEP03001JEUYF009JEP04001JEP000002Ool3
0007FUH00`00FUIJEP02FUH3000COol200000eYF001oo`0[Ool002]oo`03FUH005YF00800005FUH0
05YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20007FUH20004Ool00`00FUH00003
FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH300000eYF001JEP03FUH30006FUH00`00FUIJEP02FUH01000FUIJEP001Goo0P001EYF
00<005YFFUH01EYF1@0027oo1P0000=JEP000000;Goo000[Ool01P00FUIJEP00FUH000=JEP03001J
EUYF00EJEP03001JEUYF009JEPL000moo`8000EJEP03001JEP0000=oo`04001JEP00FUH30007FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
1000FUH0000015YF0`001UYF00<005YFFUH00eYF0P0027oo0`0000=JEP00FUH025YF00@005YFFUIJ
EPP000=JEP04001JEUYFFUH2000]Ool002]oo`80009JEP8000AJEP04001JEUYFFUH8000HOol20003
FUH00`00FUIJEP0200000goo001JEP020002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0`00
1eYF00@005YFFUIJEP8000aoo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002eoo`D0009JEP03001JEP00008000moo`<0011oo`<000EJEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEPD000MJEP04001JEP00000BOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02000_Ool0035oo`04001JEUYF0002FUH2000>Ool5000AOol00`00FUIJEP04FUH2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40006FUH3000HOol60004FUH00`00FUIJEP03FUH0
1000FUH00000<Goo000bOol20005FUH00`00Oomoo`0;Ool5000BOol00`00FUIJEP03FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH50003FUH2000QOol<000cOol003=oo`03001JEUYF00AJEP03
001oogoo00Yoo`D001=oo`03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP00009JEP<0069oo`00=7oo00<005YFFUH00eYF0`002goo0`005Goo00H005YFFUH005YF0004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH3001QOol003Eoo`03001JEUYF009J
EP03001JEUYF0080029oo`<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=J
EP04001JEUYFFUH2001OOol003Ioo`800003FUH005YF00AJEP80029oo`04001JEUYF0003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP03FUH2001MOol003Qoo`8000MJEP<0021o
o`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001oogoo
05Yoo`00>Goo00<005YFFUH01UYF00@005YF000001ioo`03001JEUYF00@000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP80009oo`8000QJEP<005Yoo`00>Woo0P001EYF00<005YFFUH00UYF0`0077oo0P0000=JEP00Ool0
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00@005YFFUIJEP8000Ioo`8000IJEP04001JEUYF001IOol003aoo`8000=JEP03001JEUYF
00EJEP<001Yoo`03001JEP0000=oo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00000:Ool20003FUH00`00FUIJEP02FUH2
001GOol003ioo`<000UJEP03001JEP00008001Moo`03001JEP0000Moo`D000QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000ioo`800003FUH005YF00EJEP03
001oogoo05Aoo`00@7oo0P0025YF00<005YFFUH00UYF0`004Woo10003Goo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02@0047oo0P001UYF0P00EGoo0012Ool3
0004FUH00`00FUIJEP06FUH50008Ool5000015YF001JEP004goo2@001UYF00<005YFFUH02UYF00<0
05YFFUH00eYF200017oo1@004Woo00<005YFFUH00UYF00<005YF0000EGoo0015Ool300000eYF001J
EP07FUH00`00FUIJEP02FUH80002FUH01`00FUIJEUYF001JEP0001aooa/000Yoo`D001=oo`80009J
EP04001JEUYF001DOol004Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0
02moo`03001JEUYF009JEP04001JEUYFFUH20009Ool3000FOol20004FUH00`00Oomoo`1AOol004]o
o`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000bOol20002FUH00`00FUIJ
EP03FUH2000QOol00`00FUIJEP02FUH00`00Oomoo`1AOol004moo`H000AJEP03001JEUYF00AJEP04
001JEP00000eOol20008FUH2000POol00`00FUIJEP02001COol005Eoo`d003Qoo`03001JEUYF00IJ
EP04001JEP00000NOol01P00FUIJEP00FUH0059oo`00Vgoo0P001UYF00@005YFFUIJEP8001eoo`80
009JEP03001oogoo051oo`00WGoo0P000eYF00<005YFFUH015YF0P0077oo00@005YFFUH0059oo`00
Wgoo0P0000=JEP00FUH01eYF0`006Goo00<005YF0000Dgoo002QOol30007FUH00`00FUIJEP04000D
Ool200000eYF001oo`1BOol00:Aoo`8000EJEP03001JEUYF00AJEPH000Qoo`H0009JEP03001oogoo
059oo`00YWoo0`0000=JEP00FUH025YF00@005YFFUIJEPP000=JEP04001JEUYFFUH2001DOol00:Uo
o`<000QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05=oo`00[7oo
0`0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00[goo0`0000=JEP00
FUH01UYF00<005YFFUH00eYF00<005YFFUH00`00EWoo002bOol50004FUH01000FUIJEUYF1@00FGoo
002gOol8001NOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60318 .7456 m .59546 .68977 L .56459 .69228 L p .707 .577 .707 r
F P
0 g
s
.59546 .68977 m .60318 .7456 L .63474 .74084 L p .707 .577 .707 r
F P
0 g
s
.63474 .74084 m .62702 .68501 L .59546 .68977 L p .707 .577 .707 r
F P
0 g
s
.62702 .68501 m .63474 .74084 L .6639 .7343 L p .707 .577 .707 r
F P
0 g
s
.6639 .7343 m .65618 .67847 L .62702 .68501 L p .707 .577 .707 r
F P
0 g
s
.57231 .74811 m .56459 .69228 L .53744 .6923 L p .707 .577 .707 r
F P
0 g
s
.56459 .69228 m .57231 .74811 L .60318 .7456 L p .707 .577 .707 r
F P
0 g
s
.65618 .67847 m .6639 .7343 L .68781 .72662 L p .707 .577 .707 r
F P
0 g
s
.68781 .72662 m .68009 .67079 L .65618 .67847 L p .707 .577 .707 r
F P
0 g
s
.53744 .6923 m .54516 .74813 L .57231 .74811 L p .707 .577 .707 r
F P
0 g
s
.54516 .74813 m .53744 .6923 L .51666 .68983 L p .707 .577 .707 r
F P
0 g
s
.59045 .80474 m .58532 .76752 L .55445 .77002 L p .707 .577 .707 r
F P
0 g
s
.58532 .76752 m .59045 .80474 L .62201 .79999 L p .707 .577 .707 r
F P
0 g
s
.62201 .79999 m .61688 .76277 L .58532 .76752 L p .707 .577 .707 r
F P
0 g
s
.61688 .76277 m .62201 .79999 L .65118 .79346 L p .707 .577 .707 r
F P
0 g
s
.65118 .79346 m .64605 .75624 L .61688 .76277 L p .707 .577 .707 r
F P
0 g
s
.68009 .67079 m .68781 .72662 L .70413 .71856 L p .707 .577 .707 r
F P
0 g
s
.70413 .71856 m .69642 .66273 L .68009 .67079 L p .707 .577 .707 r
F P
0 g
s
.55958 .80724 m .55445 .77002 L .5273 .77003 L p .707 .577 .707 r
F P
0 g
s
.55445 .77002 m .55958 .80724 L .59045 .80474 L p .707 .577 .707 r
F P
0 g
s
.51666 .68983 m .52438 .74566 L .54516 .74813 L p .707 .577 .707 r
F P
0 g
s
.59881 .85772 m .60243 .83997 L .57186 .83198 L p .707 .577 .707 r
F P
0 g
s
.60243 .83997 m .59881 .85772 L .6301 .86244 L p .707 .577 .707 r
F P
0 g
s
.6301 .86244 m .63371 .84468 L .60243 .83997 L p .707 .577 .707 r
F P
0 g
s
.64605 .75624 m .65118 .79346 L .67509 .78579 L p .707 .577 .707 r
F P
0 g
s
.67509 .78579 m .66996 .74857 L .64605 .75624 L p .707 .577 .707 r
F P
0 g
s
.5273 .77003 m .53243 .80725 L .55958 .80724 L p .707 .577 .707 r
F P
0 g
s
.63371 .84468 m .6301 .86244 L .65905 .86342 L p .707 .577 .707 r
F P
0 g
s
.65905 .86342 m .66266 .84567 L .63371 .84468 L p .707 .577 .707 r
F P
0 g
s
.56825 .84973 m .57186 .83198 L .54501 .82149 L p .707 .577 .707 r
F P
0 g
s
.57186 .83198 m .56825 .84973 L .59881 .85772 L p .707 .577 .707 r
F P
0 g
s
.52438 .74566 m .51666 .68983 L .50429 .68511 L p .707 .577 .707 r
F P
0 g
s
.54501 .82149 m .5414 .83925 L .56825 .84973 L p .707 .577 .707 r
F P
0 g
s
.53243 .80725 m .5273 .77003 L .50652 .76754 L p .707 .577 .707 r
F P
0 g
s
.66266 .84567 m .65905 .86342 L .68282 .86057 L p .707 .577 .707 r
F P
0 g
s
.68282 .86057 m .68644 .84281 L .66266 .84567 L p .707 .577 .707 r
F P
0 g
s
.5414 .83925 m .54501 .82149 L .5245 .80955 L p .707 .577 .707 r
F P
0 g
s
.66996 .74857 m .67509 .78579 L .69141 .77773 L p .707 .577 .707 r
F P
0 g
s
.69141 .77773 m .68628 .74051 L .66996 .74857 L p .707 .577 .707 r
F P
0 g
s
.50652 .76754 m .51165 .80477 L .53243 .80725 L p .707 .577 .707 r
F P
0 g
s
.69642 .66273 m .70413 .71856 L .71126 .71089 L p .707 .577 .707 r
F P
0 g
s
.71126 .71089 m .70355 .65506 L .69642 .66273 L p .707 .577 .707 r
F P
0 g
s
.50429 .68511 m .512 .74094 L .52438 .74566 L p .707 .577 .707 r
F P
0 g
s
.5245 .80955 m .52089 .8273 L .5414 .83925 L p .707 .577 .707 r
F P
0 g
s
.51165 .80477 m .50652 .76754 L .49414 .76281 L p .707 .577 .707 r
F P
0 g
s
.512 .74094 m .50429 .68511 L .50153 .67859 L p .707 .577 .707 r
F P
0 g
s
.68644 .84281 m .68282 .86057 L .6991 .85417 L p .707 .577 .707 r
F P
0 g
s
.6991 .85417 m .70271 .83641 L .68644 .84281 L p .707 .577 .707 r
F P
0 g
s
.52089 .8273 m .5245 .80955 L .51234 .7973 L p .707 .577 .707 r
F P
0 g
s
.49414 .76281 m .49927 .80003 L .51165 .80477 L p .707 .577 .707 r
F P
0 g
s
.68628 .74051 m .69141 .77773 L .69854 .77006 L p .707 .577 .707 r
F P
0 g
s
.69854 .77006 m .69341 .73284 L .68628 .74051 L p .707 .577 .707 r
F P
0 g
s
.51234 .7973 m .50873 .81506 L .52089 .8273 L p .707 .577 .707 r
F P
0 g
s
.70355 .65506 m .71126 .71089 L .70851 .70438 L p .707 .577 .707 r
F P
0 g
s
.70851 .70438 m .70079 .64855 L .70355 .65506 L p .707 .577 .707 r
F P
0 g
s
.50153 .67859 m .50925 .73442 L .512 .74094 L p .707 .577 .707 r
F P
0 g
s
.48793 .82189 m .4916 .32041 L .44759 .3174 L p .707 .577 .707 r
F P
0 g
s
.49927 .80003 m .49414 .76281 L .49139 .75629 L p .707 .577 .707 r
F P
0 g
s
.50873 .81506 m .51234 .7973 L .50972 .78596 L p .707 .577 .707 r
F P
0 g
s
.50925 .73442 m .50153 .67859 L .50866 .67093 L p .707 .577 .707 r
F P
0 g
s
.49139 .75629 m .49652 .79351 L .49927 .80003 L p .707 .577 .707 r
F P
0 g
s
.50972 .78596 m .50611 .80372 L .50873 .81506 L p .707 .577 .707 r
F P
0 g
s
.50866 .67093 m .51638 .72676 L .50925 .73442 L p .707 .577 .707 r
F P
0 g
s
.49652 .79351 m .49139 .75629 L .49852 .74862 L p .707 .577 .707 r
F P
0 g
s
.50611 .80372 m .50972 .78596 L .5169 .77663 L p .707 .577 .707 r
F P
0 g
s
.51638 .72676 m .50866 .67093 L .52498 .66286 L p .707 .577 .707 r
F P
0 g
s
.5169 .77663 m .51329 .79439 L .50611 .80372 L p .707 .577 .707 r
F P
0 g
s
.49852 .74862 m .50365 .78584 L .49652 .79351 L p .707 .577 .707 r
F P
0 g
s
.52498 .66286 m .5327 .71869 L .51638 .72676 L p .707 .577 .707 r
F P
0 g
s
.50365 .78584 m .49852 .74862 L .51484 .74056 L p .707 .577 .707 r
F P
0 g
s
.51329 .79439 m .5169 .77663 L .53318 .77023 L p .707 .577 .707 r
F P
0 g
s
.53318 .77023 m .52956 .78799 L .51329 .79439 L p .707 .577 .707 r
F P
0 g
s
.51484 .74056 m .51997 .77778 L .50365 .78584 L p .707 .577 .707 r
F P
0 g
s
.51997 .77778 m .51484 .74056 L .53875 .73289 L p .707 .577 .707 r
F P
0 g
s
.52956 .78799 m .53318 .77023 L .55695 .76738 L p .707 .577 .707 r
F P
0 g
s
.55695 .76738 m .55334 .78514 L .52956 .78799 L p .707 .577 .707 r
F P
0 g
s
.53875 .73289 m .54388 .77011 L .51997 .77778 L p .707 .577 .707 r
F P
0 g
s
.4916 .32041 m .48793 .82189 L .53287 .82108 L p .707 .577 .707 r
F P
0 g
s
.5327 .71869 m .52498 .66286 L .5489 .65518 L p .707 .577 .707 r
F P
0 g
s
.5489 .65518 m .55661 .71101 L .5327 .71869 L p .707 .577 .707 r
F P
0 g
s
.53287 .82108 m .53654 .3196 L .4916 .32041 L p .707 .577 .707 r
F P
0 g
s
.70271 .83641 m .6991 .85417 L .70628 .84484 L p .707 .577 .707 r
F P
0 g
s
.70628 .84484 m .70989 .82708 L .70271 .83641 L p .707 .577 .707 r
F P
0 g
s
.55661 .71101 m .5489 .65518 L .57806 .64864 L p .707 .577 .707 r
F P
0 g
s
.57806 .64864 m .58578 .70448 L .55661 .71101 L p .707 .577 .707 r
F P
0 g
s
.54388 .77011 m .53875 .73289 L .56792 .72636 L p .707 .577 .707 r
F P
0 g
s
.55334 .78514 m .55695 .76738 L .5859 .76836 L p .707 .577 .707 r
F P
0 g
s
.56792 .72636 m .57305 .76358 L .54388 .77011 L p .707 .577 .707 r
F P
0 g
s
.5859 .76836 m .58229 .78612 L .55334 .78514 L p .707 .577 .707 r
F P
0 g
s
.53654 .3196 m .53287 .82108 L .57435 .81655 L p .707 .577 .707 r
F P
0 g
s
.57305 .76358 m .56792 .72636 L .59948 .72161 L p .707 .577 .707 r
F P
0 g
s
.59948 .72161 m .60461 .75883 L .57305 .76358 L p .707 .577 .707 r
F P
0 g
s
.57435 .81655 m .57802 .31507 L .53654 .3196 L p .707 .577 .707 r
F P
0 g
s
.44392 .81888 m .44759 .3174 L .40883 .31087 L p .707 .577 .707 r
F P
0 g
s
.44759 .3174 m .44392 .81888 L .48793 .82189 L p .707 .577 .707 r
F P
0 g
s
.69341 .73284 m .69854 .77006 L .69579 .76354 L p .707 .577 .707 r
F P
0 g
s
.69579 .76354 m .69066 .72632 L .69341 .73284 L p .707 .577 .707 r
F P
0 g
s
.70079 .64855 m .70851 .70438 L .69613 .69965 L p .707 .577 .707 r
F P
0 g
s
.69613 .69965 m .68842 .64382 L .70079 .64855 L p .707 .577 .707 r
F P
0 g
s
.58578 .70448 m .57806 .64864 L .60962 .64389 L p .707 .577 .707 r
F P
0 g
s
.60962 .64389 m .61733 .69972 L .58578 .70448 L p .707 .577 .707 r
F P
0 g
s
.63035 .71911 m .63548 .75633 L .60461 .75883 L p .707 .577 .707 r
F P
0 g
s
.60461 .75883 m .59948 .72161 L .63035 .71911 L p .707 .577 .707 r
F P
0 g
s
.58229 .78612 m .5859 .76836 L .61719 .77308 L p .707 .577 .707 r
F P
0 g
s
.61719 .77308 m .61357 .79083 L .58229 .78612 L p .707 .577 .707 r
F P
0 g
s
.57802 .31507 m .57435 .81655 L .60831 .80872 L p .707 .577 .707 r
F P
0 g
s
.60831 .80872 m .61198 .30724 L .57802 .31507 L p .707 .577 .707 r
F P
0 g
s
.26017 .70875 m .25245 .65292 L .22158 .65543 L p .707 .577 .707 r
F P
0 g
s
.25245 .65292 m .26017 .70875 L .29173 .70399 L p .707 .577 .707 r
F P
0 g
s
.29173 .70399 m .28401 .64816 L .25245 .65292 L p .707 .577 .707 r
F P
0 g
s
.40516 .81235 m .40883 .31087 L .3791 .30147 L p .707 .577 .707 r
F P
0 g
s
.40883 .31087 m .40516 .81235 L .44392 .81888 L p .707 .577 .707 r
F P
0 g
s
.28401 .64816 m .29173 .70399 L .32089 .69745 L p .707 .577 .707 r
F P
0 g
s
.32089 .69745 m .31317 .64162 L .28401 .64816 L p .707 .577 .707 r
F P
0 g
s
.70989 .82708 m .70628 .84484 L .70366 .8335 L p .707 .577 .707 r
F P
0 g
s
.70366 .8335 m .70727 .81574 L .70989 .82708 L p .707 .577 .707 r
F P
0 g
s
.2293 .71126 m .22158 .65543 L .19443 .65545 L p .707 .577 .707 r
F P
0 g
s
.22158 .65543 m .2293 .71126 L .26017 .70875 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31317 .64162 m .32089 .69745 L .3448 .68977 L p .707 .577 .707 r
F P
0 g
s
.3448 .68977 m .33709 .63394 L .31317 .64162 L p .707 .577 .707 r
F P
0 g
s
.69066 .72632 m .69579 .76354 L .68341 .75881 L p .707 .577 .707 r
F P
0 g
s
.68341 .75881 m .67828 .72159 L .69066 .72632 L p .707 .577 .707 r
F P
0 g
s
.68842 .64382 m .69613 .69965 L .67535 .69718 L p .707 .577 .707 r
F P
0 g
s
.67535 .69718 m .66764 .64135 L .68842 .64382 L p .707 .577 .707 r
F P
0 g
s
.64049 .64137 m .6482 .6972 L .61733 .69972 L p .707 .577 .707 r
F P
0 g
s
.61733 .69972 m .60962 .64389 L .64049 .64137 L p .707 .577 .707 r
F P
0 g
s
.64775 .78107 m .64414 .79882 L .61357 .79083 L p .707 .577 .707 r
F P
0 g
s
.61357 .79083 m .61719 .77308 L .64775 .78107 L p .707 .577 .707 r
F P
0 g
s
.61198 .30724 m .60831 .80872 L .63142 .79837 L p .707 .577 .707 r
F P
0 g
s
.63548 .75633 m .63035 .71911 L .6575 .7191 L p .707 .577 .707 r
F P
0 g
s
.63142 .79837 m .63509 .29689 L .61198 .30724 L p .707 .577 .707 r
F P
0 g
s
.19443 .65545 m .20215 .71128 L .2293 .71126 L p .707 .577 .707 r
F P
0 g
s
.20215 .71128 m .19443 .65545 L .17365 .65298 L p .707 .577 .707 r
F P
0 g
s
.24744 .76782 m .24231 .7306 L .21145 .7331 L p .707 .577 .707 r
F P
0 g
s
.24231 .7306 m .24744 .76782 L .279 .76307 L p .707 .577 .707 r
F P
0 g
s
.279 .76307 m .27388 .72585 L .24231 .7306 L p .707 .577 .707 r
F P
0 g
s
.27388 .72585 m .279 .76307 L .30817 .75654 L p .707 .577 .707 r
F P
0 g
s
.30817 .75654 m .30304 .71932 L .27388 .72585 L p .707 .577 .707 r
F P
0 g
s
.70727 .81574 m .70366 .8335 L .6915 .82125 L p .707 .577 .707 r
F P
0 g
s
.6915 .82125 m .69511 .8035 L .70727 .81574 L p .707 .577 .707 r
F P
0 g
s
.33709 .63394 m .3448 .68977 L .36112 .68171 L p .707 .577 .707 r
F P
0 g
s
.36112 .68171 m .35341 .62587 L .33709 .63394 L p .707 .577 .707 r
F P
0 g
s
.21657 .77032 m .21145 .7331 L .18429 .73311 L p .707 .577 .707 r
F P
0 g
s
.21145 .7331 m .21657 .77032 L .24744 .76782 L p .707 .577 .707 r
F P
0 g
s
.37544 .80295 m .3791 .30147 L .36133 .2901 L p .707 .577 .707 r
F P
0 g
s
.3791 .30147 m .37544 .80295 L .40516 .81235 L p .707 .577 .707 r
F P
0 g
s
.17365 .65298 m .18137 .70881 L .20215 .71128 L p .707 .577 .707 r
F P
0 g
s
.30304 .71932 m .30817 .75654 L .33208 .74887 L p .707 .577 .707 r
F P
0 g
s
.33208 .74887 m .32695 .71165 L .30304 .71932 L p .707 .577 .707 r
F P
0 g
s
.2558 .82135 m .25942 .80359 L .22885 .7956 L p .707 .577 .707 r
F P
0 g
s
.25942 .80359 m .2558 .82135 L .28709 .82607 L p .707 .577 .707 r
F P
0 g
s
.28709 .82607 m .29071 .80831 L .25942 .80359 L p .707 .577 .707 r
F P
0 g
s
.66764 .64135 m .67535 .69718 L .6482 .6972 L p .707 .577 .707 r
F P
0 g
s
.6482 .6972 m .64049 .64137 L .66764 .64135 L p .707 .577 .707 r
F P
0 g
s
.18429 .73311 m .18942 .77033 L .21657 .77032 L p .707 .577 .707 r
F P
0 g
s
.67828 .72159 m .68341 .75881 L .66263 .75632 L p .707 .577 .707 r
F P
0 g
s
.66263 .75632 m .6575 .7191 L .67828 .72159 L p .707 .577 .707 r
F P
0 g
s
.29071 .80831 m .28709 .82607 L .31604 .82705 L p .707 .577 .707 r
F P
0 g
s
.31604 .82705 m .31965 .80929 L .29071 .80831 L p .707 .577 .707 r
F P
0 g
s
.22524 .81336 m .22885 .7956 L .202 .78512 L p .707 .577 .707 r
F P
0 g
s
.22885 .7956 m .22524 .81336 L .2558 .82135 L p .707 .577 .707 r
F P
0 g
s
.18137 .70881 m .17365 .65298 L .16128 .64825 L p .707 .577 .707 r
F P
0 g
s
.202 .78512 m .19839 .80288 L .22524 .81336 L p .707 .577 .707 r
F P
0 g
s
.18942 .77033 m .18429 .73311 L .16351 .73062 L p .707 .577 .707 r
F P
0 g
s
.6575 .7191 m .66263 .75632 L .63548 .75633 L p .707 .577 .707 r
F P
0 g
s
.63509 .29689 m .63142 .79837 L .64142 .78651 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .64508 .28503 L .63509 .29689 L p .707 .577 .707 r
F P
0 g
s
.31965 .80929 m .31604 .82705 L .33981 .8242 L p .707 .577 .707 r
F P
0 g
s
.33981 .8242 m .34343 .80644 L .31965 .80929 L p .707 .577 .707 r
F P
0 g
s
.19839 .80288 m .202 .78512 L .18149 .77317 L p .707 .577 .707 r
F P
0 g
s
.32695 .71165 m .33208 .74887 L .3484 .74081 L p .707 .577 .707 r
F P
0 g
s
.3484 .74081 m .34327 .70359 L .32695 .71165 L p .707 .577 .707 r
F P
0 g
s
.16351 .73062 m .16864 .76785 L .18942 .77033 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35724 .27789 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.35341 .62587 m .36112 .68171 L .36644 .67599 L p .707 .577 .707 r
F P
0 g
s
.36614 .66717 m .35341 .62587 L .36644 .67599 L .707 .577 .707 r
F
.36825 .67404 m .36054 .61821 L .35341 .62587 L p F P
0 g
s
.35778 .6117 m .36054 .61821 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.3655 .66753 m .36285 .64836 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .35778 .6117 L p .36383 .65091 L .707 .577 .707 r
F P
0 g
s
.35778 .6117 m .36285 .64836 L p .35312 .6628 L .707 .577 .707 r
F P
0 g
s
.36285 .64836 m .3655 .66753 L .36207 .66622 L p .707 .577 .707 r
F P
0 g
s
.36207 .66622 m .35312 .6628 L p .36285 .64836 L .707 .577 .707 r
F P
0 g
s
.34327 .70359 m .3484 .74081 L .35553 .73314 L p .707 .577 .707 r
F P
0 g
s
.35553 .73314 m .35041 .69592 L .34327 .70359 L p .707 .577 .707 r
F P
0 g
s
.35041 .69592 m .35553 .73314 L .35278 .72662 L p .707 .577 .707 r
F P
0 g
s
.35312 .6628 m .34541 .60697 L .35778 .6117 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .34849 .78488 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.36426 .77937 m .3618 .79145 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.3618 .79145 m .36065 .79712 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .3521 .76712 L .36135 .77643 L p .707 .577 .707 r
F P
0 g
s
.36135 .77643 m .36426 .77937 L p .36147 .78034 L .707 .577 .707 r
F P
0 g
s
.34849 .78488 m .36135 .77643 L .36147 .78034 L .707 .577 .707 r
F
.35764 .76737 m .35754 .65014 L .3567 .78873 L F
.35754 .65014 m .35724 .27789 L .35687 .62788 L F
.35754 .65014 m .35687 .62788 L .3567 .78873 L F
.35357 .77937 m .3567 .78873 L p .35687 .62788 L F P
0 g
s
.35724 .27789 m .35511 .56932 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.35511 .56932 m .35357 .77937 L p .35687 .62788 L .707 .577 .707 r
F P
0 g
s
.3567 .78873 m .35766 .79158 L p .35764 .76737 L .707 .577 .707 r
F P
0 g
s
.35753 .63446 m .3599 .48527 L .35735 .41085 L .707 .577 .707 r
F
.35766 .79158 m .35878 .63774 L p .35753 .63446 L F P
0 g
s
.35878 .63774 m .3599 .48527 L p .35753 .63446 L .707 .577 .707 r
F P
0 g
s
.3599 .48527 m .36133 .2901 L p .35735 .41085 L .707 .577 .707 r
F P
0 g
s
.36644 .67599 m .36825 .67404 L p .36614 .66717 L .707 .577 .707 r
F P
0 g
s
.69511 .8035 m .6915 .82125 L .67099 .80931 L p .707 .577 .707 r
F P
0 g
s
.67099 .80931 m .6746 .79155 L .69511 .8035 L p .707 .577 .707 r
F P
0 g
s
.16128 .64825 m .16899 .70409 L .18137 .70881 L p .707 .577 .707 r
F P
0 g
s
.18149 .77317 m .17788 .79093 L .19839 .80288 L p .707 .577 .707 r
F P
0 g
s
.36054 .61821 m .36825 .67404 L .3655 .66753 L p .707 .577 .707 r
F P
0 g
s
.36327 .80846 m .36688 .79071 L .3597 .80004 L p .707 .577 .707 r
F P
0 g
s
.36688 .79071 m .36327 .80846 L .36065 .79712 L p .707 .577 .707 r
F P
0 g
s
.36065 .79712 m .36426 .77937 L .36688 .79071 L p .707 .577 .707 r
F P
0 g
s
.36133 .2901 m .35766 .79158 L .37544 .80295 L p .707 .577 .707 r
F P
0 g
s
.16864 .76785 m .16351 .73062 L .15114 .72589 L p .707 .577 .707 r
F P
0 g
s
.16899 .70409 m .16128 .64825 L .15852 .64174 L p .707 .577 .707 r
F P
0 g
s
.34343 .80644 m .33981 .8242 L .35609 .81779 L p .707 .577 .707 r
F P
0 g
s
.35609 .81779 m .3597 .80004 L .34343 .80644 L p .707 .577 .707 r
F P
0 g
s
.17788 .79093 m .18149 .77317 L .16933 .76093 L p .707 .577 .707 r
F P
0 g
s
.6746 .79155 m .67099 .80931 L .64414 .79882 L p .707 .577 .707 r
F P
0 g
s
.64414 .79882 m .64775 .78107 L .6746 .79155 L p .707 .577 .707 r
F P
0 g
s
.15114 .72589 m .15626 .76311 L .16864 .76785 L p .707 .577 .707 r
F P
0 g
s
.16933 .76093 m .16572 .77869 L .17788 .79093 L p .707 .577 .707 r
F P
0 g
s
.15852 .64174 m .16624 .69757 L .16899 .70409 L p .707 .577 .707 r
F P
0 g
s
.64142 .78651 m .63733 .7743 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.64381 .45978 m .64142 .78651 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .64508 .28503 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63733 .7743 m .63879 .5747 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.63879 .5747 m .641 .27282 L p .64146 .51343 L .707 .577 .707 r
F P
0 g
s
.641 .27282 m .63733 .7743 L .61955 .76294 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .64885 .71273 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63135 .67077 m .63381 .68866 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.63381 .68866 m .63648 .70799 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .64372 .67551 L .63454 .67199 L p .707 .577 .707 r
F P
0 g
s
.63454 .67199 m .63135 .67077 L p .63429 .67782 L .707 .577 .707 r
F P
0 g
s
.64885 .71273 m .63454 .67199 L .63429 .67782 L .707 .577 .707 r
F
.64508 .28503 m .64381 .45978 L p .64146 .51343 L F P
0 g
s
.15626 .76311 m .15114 .72589 L .14838 .71937 L p .707 .577 .707 r
F P
0 g
s
.3597 .80004 m .35609 .81779 L .36327 .80846 L p .707 .577 .707 r
F P
0 g
s
.16572 .77869 m .16933 .76093 L .16672 .74959 L p .707 .577 .707 r
F P
0 g
s
.16624 .69757 m .15852 .64174 L .16565 .63408 L p .707 .577 .707 r
F P
0 g
s
.14838 .71937 m .15351 .75659 L .15626 .76311 L p .707 .577 .707 r
F P
0 g
s
.16672 .74959 m .1631 .76734 L .16572 .77869 L p .707 .577 .707 r
F P
0 g
s
.35278 .72662 m .34765 .6894 L .35041 .69592 L p .707 .577 .707 r
F P
0 g
s
.35357 .77937 m .35724 .27789 L .36724 .26603 L p .707 .577 .707 r
F P
0 g
s
.16565 .63408 m .17337 .68991 L .16624 .69757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15351 .75659 m .14838 .71937 L .15551 .7117 L p .707 .577 .707 r
F P
0 g
s
.1631 .76734 m .16672 .74959 L .17389 .74026 L p .707 .577 .707 r
F P
0 g
s
.17337 .68991 m .16565 .63408 L .18197 .62601 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17389 .74026 m .17028 .75801 L .1631 .76734 L p .707 .577 .707 r
F P
0 g
s
.61955 .76294 m .62322 .26146 L .641 .27282 L p .707 .577 .707 r
F P
0 g
s
.15551 .7117 m .16064 .74892 L .15351 .75659 L p .707 .577 .707 r
F P
0 g
s
.34765 .6894 m .35278 .72662 L .3404 .72189 L p .707 .577 .707 r
F P
0 g
s
.3404 .72189 m .33527 .68467 L .34765 .6894 L p .707 .577 .707 r
F P
0 g
s
.34541 .60697 m .35312 .6628 L .33234 .66033 L p .707 .577 .707 r
F P
0 g
s
.33234 .66033 m .32463 .6045 L .34541 .60697 L p .707 .577 .707 r
F P
0 g
s
.18197 .62601 m .18969 .68184 L .17337 .68991 L p .707 .577 .707 r
F P
0 g
s
.36357 .76751 m .36724 .26603 L .39035 .25568 L p .707 .577 .707 r
F P
0 g
s
.36724 .26603 m .36357 .76751 L .35357 .77937 L p .707 .577 .707 r
F P
0 g
s
.16064 .74892 m .15551 .7117 L .17183 .70364 L p .707 .577 .707 r
F P
0 g
s
.17028 .75801 m .17389 .74026 L .19017 .73386 L p .707 .577 .707 r
F P
0 g
s
.18969 .68184 m .18197 .62601 L .20589 .61833 L p .707 .577 .707 r
F P
0 g
s
.19017 .73386 m .18655 .75161 L .17028 .75801 L p .707 .577 .707 r
F P
0 g
s
.17183 .70364 m .17696 .74086 L .16064 .74892 L p .707 .577 .707 r
F P
0 g
s
.32463 .6045 m .33234 .66033 L .30519 .66035 L p .707 .577 .707 r
F P
0 g
s
.30519 .66035 m .29748 .60452 L .32463 .6045 L p .707 .577 .707 r
F P
0 g
s
.33527 .68467 m .3404 .72189 L .31962 .7194 L p .707 .577 .707 r
F P
0 g
s
.31962 .7194 m .31449 .68218 L .33527 .68467 L p .707 .577 .707 r
F P
0 g
s
.20589 .61833 m .2136 .67416 L .18969 .68184 L p .707 .577 .707 r
F P
0 g
s
.62322 .26146 m .61955 .76294 L .58983 .75353 L p .707 .577 .707 r
F P
0 g
s
.58983 .75353 m .5935 .25205 L .62322 .26146 L p .707 .577 .707 r
F P
0 g
s
.2136 .67416 m .20589 .61833 L .23505 .61179 L p .707 .577 .707 r
F P
0 g
s
.29748 .60452 m .30519 .66035 L .27433 .66286 L p .707 .577 .707 r
F P
0 g
s
.27433 .66286 m .26661 .60703 L .29748 .60452 L p .707 .577 .707 r
F P
0 g
s
.3521 .76712 m .34849 .78488 L .32798 .77293 L p .707 .577 .707 r
F P
0 g
s
.32798 .77293 m .3316 .75518 L .3521 .76712 L p .707 .577 .707 r
F P
0 g
s
.17696 .74086 m .17183 .70364 L .19574 .69597 L p .707 .577 .707 r
F P
0 g
s
.18655 .75161 m .19017 .73386 L .21394 .731 L p .707 .577 .707 r
F P
0 g
s
.24277 .66762 m .23505 .61179 L .26661 .60703 L p .707 .577 .707 r
F P
0 g
s
.23505 .61179 m .24277 .66762 L .2136 .67416 L p .707 .577 .707 r
F P
0 g
s
.39035 .25568 m .38668 .75716 L .36357 .76751 L p .707 .577 .707 r
F P
0 g
s
.38668 .75716 m .39035 .25568 L .4243 .24786 L p .707 .577 .707 r
F P
0 g
s
.74038 .65356 m .73266 .59773 L .7018 .60024 L p .707 .577 .707 r
F P
0 g
s
.73266 .59773 m .74038 .65356 L .77194 .6488 L p .707 .577 .707 r
F P
0 g
s
.77194 .6488 m .76422 .59297 L .73266 .59773 L p .707 .577 .707 r
F P
0 g
s
.26661 .60703 m .27433 .66286 L .24277 .66762 L p .707 .577 .707 r
F P
0 g
s
.21394 .731 m .21033 .74876 L .18655 .75161 L p .707 .577 .707 r
F P
0 g
s
.31449 .68218 m .31962 .7194 L .29247 .71941 L p .707 .577 .707 r
F P
0 g
s
.29247 .71941 m .28734 .68219 L .31449 .68218 L p .707 .577 .707 r
F P
0 g
s
.19574 .69597 m .20087 .73319 L .17696 .74086 L p .707 .577 .707 r
F P
0 g
s
.76422 .59297 m .77194 .6488 L .8011 .64226 L p .707 .577 .707 r
F P
0 g
s
.8011 .64226 m .79339 .58643 L .76422 .59297 L p .707 .577 .707 r
F P
0 g
s
.70951 .65608 m .7018 .60024 L .67464 .60027 L p .707 .577 .707 r
F P
0 g
s
.7018 .60024 m .70951 .65608 L .74038 .65356 L p .707 .577 .707 r
F P
0 g
s
.20087 .73319 m .19574 .69597 L .22491 .68944 L p .707 .577 .707 r
F P
0 g
s
.79339 .58643 m .8011 .64226 L .82502 .63459 L p .707 .577 .707 r
F P
0 g
s
.82502 .63459 m .8173 .57876 L .79339 .58643 L p .707 .577 .707 r
F P
0 g
s
.3316 .75518 m .32798 .77293 L .30113 .76245 L p .707 .577 .707 r
F P
0 g
s
.30113 .76245 m .30474 .74469 L .3316 .75518 L p .707 .577 .707 r
F P
0 g
s
.21033 .74876 m .21394 .731 L .24289 .73199 L p .707 .577 .707 r
F P
0 g
s
.5935 .25205 m .58983 .75353 L .55107 .74701 L p .707 .577 .707 r
F P
0 g
s
.55107 .74701 m .55473 .24552 L .5935 .25205 L p .707 .577 .707 r
F P
0 g
s
.28734 .68219 m .29247 .71941 L .2616 .72191 L p .707 .577 .707 r
F P
0 g
s
.2616 .72191 m .25647 .68469 L .28734 .68219 L p .707 .577 .707 r
F P
0 g
s
.67464 .60027 m .68236 .6561 L .70951 .65608 L p .707 .577 .707 r
F P
0 g
s
.22491 .68944 m .23004 .72666 L .20087 .73319 L p .707 .577 .707 r
F P
0 g
s
.24289 .73199 m .23928 .74974 L .21033 .74876 L p .707 .577 .707 r
F P
0 g
s
.23004 .72666 m .22491 .68944 L .25647 .68469 L p .707 .577 .707 r
F P
0 g
s
.68236 .6561 m .67464 .60027 L .65386 .59779 L p .707 .577 .707 r
F P
0 g
s
.72766 .7127 m .72253 .67548 L .69166 .67798 L p .707 .577 .707 r
F P
0 g
s
.72253 .67548 m .72766 .7127 L .75922 .70796 L p .707 .577 .707 r
F P
0 g
s
.75922 .70796 m .75409 .67073 L .72253 .67548 L p .707 .577 .707 r
F P
0 g
s
.25647 .68469 m .2616 .72191 L .23004 .72666 L p .707 .577 .707 r
F P
0 g
s
.42064 .74934 m .4243 .24786 L .46578 .24332 L p .707 .577 .707 r
F P
0 g
s
.4243 .24786 m .42085 .71973 L p .38668 .75716 L .707 .577 .707 r
F P
0 g
s
.46578 .24332 m .46212 .7448 L .42064 .74934 L p .707 .577 .707 r
F P
0 g
s
.42121 .55612 m .42893 .61195 L .45001 .60722 L p .707 .577 .707 r
F P
0 g
s
.45001 .60722 m .45809 .60541 L p .45244 .59785 L .707 .577 .707 r
F P
0 g
s
.45244 .59785 m .42121 .55612 L .45001 .60722 L .707 .577 .707 r
F
.42085 .71973 m .42064 .74934 L .4127 .75117 L p F P
0 g
s
.4127 .75117 m .38668 .75716 L p .42085 .71973 L .707 .577 .707 r
F P
0 g
s
.75409 .67073 m .75922 .70796 L .78838 .70143 L p .707 .577 .707 r
F P
0 g
s
.78838 .70143 m .78325 .66421 L .75409 .67073 L p .707 .577 .707 r
F P
0 g
s
.30474 .74469 m .30113 .76245 L .27056 .75446 L p .707 .577 .707 r
F P
0 g
s
.27056 .75446 m .27418 .7367 L .30474 .74469 L p .707 .577 .707 r
F P
0 g
s
.23928 .74974 m .24289 .73199 L .27418 .7367 L p .707 .577 .707 r
F P
0 g
s
.8173 .57876 m .82502 .63459 L .84134 .62652 L p .707 .577 .707 r
F P
0 g
s
.84134 .62652 m .83362 .57069 L .8173 .57876 L p .707 .577 .707 r
F P
0 g
s
.27418 .7367 m .27056 .75446 L .23928 .74974 L p .707 .577 .707 r
F P
0 g
s
.69679 .7152 m .69166 .67798 L .6645 .67799 L p .707 .577 .707 r
F P
0 g
s
.69166 .67798 m .69679 .7152 L .72766 .7127 L p .707 .577 .707 r
F P
0 g
s
.65386 .59779 m .66158 .65362 L .68236 .6561 L p .707 .577 .707 r
F P
0 g
s
.73602 .76569 m .73963 .74793 L .70906 .73994 L p .707 .577 .707 r
F P
0 g
s
.73963 .74793 m .73602 .76569 L .76731 .7704 L p .707 .577 .707 r
F P
0 g
s
.76731 .7704 m .77092 .75265 L .73963 .74793 L p .707 .577 .707 r
F P
0 g
s
.78325 .66421 m .78838 .70143 L .8123 .69375 L p .707 .577 .707 r
F P
0 g
s
.8123 .69375 m .80717 .65653 L .78325 .66421 L p .707 .577 .707 r
F P
0 g
s
.55473 .24552 m .55107 .74701 L .50706 .744 L p .707 .577 .707 r
F P
0 g
s
.50706 .744 m .51073 .24252 L .55473 .24552 L p .707 .577 .707 r
F P
0 g
s
.6645 .67799 m .66963 .71521 L .69679 .7152 L p .707 .577 .707 r
F P
0 g
s
.77092 .75265 m .76731 .7704 L .79625 .77138 L p .707 .577 .707 r
F P
0 g
s
.79625 .77138 m .79987 .75363 L .77092 .75265 L p .707 .577 .707 r
F P
0 g
s
.70545 .7577 m .70906 .73994 L .68221 .72946 L p .707 .577 .707 r
F P
0 g
s
.70906 .73994 m .70545 .7577 L .73602 .76569 L p .707 .577 .707 r
F P
0 g
s
.46212 .7448 m .46578 .24332 L .51073 .24252 L p .707 .577 .707 r
F P
0 g
s
.51073 .24252 m .50706 .744 L .46212 .7448 L p .707 .577 .707 r
F P
0 g
s
.66158 .65362 m .65386 .59779 L .64149 .59307 L p .707 .577 .707 r
F P
0 g
s
.68221 .72946 m .6786 .74721 L .70545 .7577 L p .707 .577 .707 r
F P
0 g
s
.66963 .71521 m .6645 .67799 L .64372 .67551 L p .707 .577 .707 r
F P
0 g
s
.79987 .75363 m .79625 .77138 L .82003 .76853 L p .707 .577 .707 r
F P
0 g
s
.82003 .76853 m .82364 .75078 L .79987 .75363 L p .707 .577 .707 r
F P
0 g
s
.6786 .74721 m .68221 .72946 L .6617 .71751 L p .707 .577 .707 r
F P
0 g
s
.80717 .65653 m .8123 .69375 L .82862 .68569 L p .707 .577 .707 r
F P
0 g
s
.82862 .68569 m .82349 .64847 L .80717 .65653 L p .707 .577 .707 r
F P
0 g
s
.64372 .67551 m .64885 .71273 L .66963 .71521 L p .707 .577 .707 r
F P
0 g
s
.83362 .57069 m .84134 .62652 L .84847 .61885 L p .707 .577 .707 r
F P
0 g
s
.84847 .61885 m .84075 .56302 L .83362 .57069 L p .707 .577 .707 r
F P
0 g
s
.64149 .59307 m .64921 .6489 L .66158 .65362 L p .707 .577 .707 r
F P
0 g
s
.6617 .71751 m .65809 .73527 L .6786 .74721 L p .707 .577 .707 r
F P
0 g
s
.64921 .6489 m .64149 .59307 L .63874 .58656 L p .707 .577 .707 r
F P
0 g
s
.82364 .75078 m .82003 .76853 L .8363 .76213 L p .707 .577 .707 r
F P
0 g
s
.8363 .76213 m .83991 .74437 L .82364 .75078 L p .707 .577 .707 r
F P
0 g
s
.65809 .73527 m .6617 .71751 L .64955 .70527 L p .707 .577 .707 r
F P
0 g
s
.82349 .64847 m .82862 .68569 L .83575 .67802 L p .707 .577 .707 r
F P
0 g
s
.83575 .67802 m .83062 .6408 L .82349 .64847 L p .707 .577 .707 r
F P
0 g
s
.64955 .70527 m .64593 .72302 L .65809 .73527 L p .707 .577 .707 r
F P
0 g
s
.84075 .56302 m .84847 .61885 L .84571 .61234 L p .707 .577 .707 r
F P
0 g
s
.84571 .61234 m .838 .55651 L .84075 .56302 L p .707 .577 .707 r
F P
0 g
s
.63874 .58656 m .64645 .64239 L .64921 .6489 L p .707 .577 .707 r
F P
0 g
s
.63648 .70799 m .63135 .67077 L .62859 .66425 L p .707 .577 .707 r
F P
0 g
s
.83991 .74437 m .8363 .76213 L .84348 .7528 L p .707 .577 .707 r
F P
0 g
s
.84348 .7528 m .84709 .73504 L .83991 .74437 L p .707 .577 .707 r
F P
0 g
s
.64593 .72302 m .64955 .70527 L .64693 .69392 L p .707 .577 .707 r
F P
0 g
s
.64645 .64239 m .63874 .58656 L .64587 .57889 L p .707 .577 .707 r
F P
0 g
s
.62859 .66425 m .63372 .70147 L .63648 .70799 L p .707 .577 .707 r
F P
0 g
s
.64693 .69392 m .64332 .71168 L .64593 .72302 L p .707 .577 .707 r
F P
0 g
s
.83062 .6408 m .83575 .67802 L .83299 .6715 L p .707 .577 .707 r
F P
0 g
s
.83299 .6715 m .82786 .63428 L .83062 .6408 L p .707 .577 .707 r
F P
0 g
s
.838 .55651 m .84571 .61234 L .83334 .60762 L p .707 .577 .707 r
F P
0 g
s
.83334 .60762 m .82562 .55178 L .838 .55651 L p .707 .577 .707 r
F P
0 g
s
.64587 .57889 m .65358 .63472 L .64645 .64239 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39737 .61671 m .38965 .56088 L .35879 .56339 L p .707 .577 .707 r
F P
0 g
s
.38965 .56088 m .39737 .61671 L .42893 .61195 L p .707 .577 .707 r
F P
0 g
s
.42893 .61195 m .42121 .55612 L .38965 .56088 L p .707 .577 .707 r
F P
0 g
s
.45809 .60541 m .45038 .54958 L .42121 .55612 L p .707 .577 .707 r
F P
0 g
s
.84709 .73504 m .84348 .7528 L .84086 .74146 L p .707 .577 .707 r
F P
0 g
s
.84086 .74146 m .84448 .7237 L .84709 .73504 L p .707 .577 .707 r
F P
0 g
s
.63372 .70147 m .62859 .66425 L .63572 .65659 L p .707 .577 .707 r
F P
0 g
s
.64332 .71168 m .64693 .69392 L .65411 .68459 L p .707 .577 .707 r
F P
0 g
s
.65358 .63472 m .64587 .57889 L .66219 .57082 L p .707 .577 .707 r
F P
0 g
s
.3665 .61922 m .35879 .56339 L .33163 .56341 L p .707 .577 .707 r
F P
0 g
s
.35879 .56339 m .3665 .61922 L .39737 .61671 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65411 .68459 m .65049 .70235 L .64332 .71168 L p .707 .577 .707 r
F P
0 g
s
.63572 .65659 m .64085 .69381 L .63372 .70147 L p .707 .577 .707 r
F P
0 g
s
.45038 .54958 m .45809 .60541 L .48201 .59773 L p .707 .577 .707 r
F P
0 g
s
.48201 .59773 m .47429 .5419 L .45038 .54958 L p .707 .577 .707 r
F P
0 g
s
.82786 .63428 m .83299 .6715 L .82062 .66677 L p .707 .577 .707 r
F P
0 g
s
.82062 .66677 m .81549 .62955 L .82786 .63428 L p .707 .577 .707 r
F P
0 g
s
.82562 .55178 m .83334 .60762 L .81256 .60514 L p .707 .577 .707 r
F P
0 g
s
.81256 .60514 m .80484 .54931 L .82562 .55178 L p .707 .577 .707 r
F P
0 g
s
.66219 .57082 m .6699 .62665 L .65358 .63472 L p .707 .577 .707 r
F P
0 g
s
.33163 .56341 m .33935 .61924 L .3665 .61922 L p .707 .577 .707 r
F P
0 g
s
.33935 .61924 m .33163 .56341 L .31085 .56094 L p .707 .577 .707 r
F P
0 g
s
.38465 .67578 m .37952 .63856 L .34865 .64106 L p .707 .577 .707 r
F P
0 g
s
.37952 .63856 m .38465 .67578 L .41621 .67104 L p .707 .577 .707 r
F P
0 g
s
.41621 .67104 m .41108 .63381 L .37952 .63856 L p .707 .577 .707 r
F P
0 g
s
.41108 .63381 m .41621 .67104 L .44537 .66451 L p .707 .577 .707 r
F P
0 g
s
.44537 .66451 m .44024 .62729 L .41108 .63381 L p .707 .577 .707 r
F P
0 g
s
.84448 .7237 m .84086 .74146 L .8287 .72922 L p .707 .577 .707 r
F P
0 g
s
.8287 .72922 m .83232 .71146 L .84448 .7237 L p .707 .577 .707 r
F P
0 g
s
.47429 .5419 m .48201 .59773 L .49833 .58967 L p .707 .577 .707 r
F P
0 g
s
.49833 .58967 m .49061 .53384 L .47429 .5419 L p .707 .577 .707 r
F P
0 g
s
.64085 .69381 m .63572 .65659 L .65204 .64852 L p .707 .577 .707 r
F P
0 g
s
.65049 .70235 m .65411 .68459 L .67038 .67819 L p .707 .577 .707 r
F P
0 g
s
.6699 .62665 m .66219 .57082 L .6861 .56314 L p .707 .577 .707 r
F P
0 g
s
.35378 .67828 m .34865 .64106 L .32149 .64107 L p .707 .577 .707 r
F P
0 g
s
.34865 .64106 m .35378 .67828 L .38465 .67578 L p .707 .577 .707 r
F P
0 g
s
.31085 .56094 m .31857 .61677 L .33935 .61924 L p .707 .577 .707 r
F P
0 g
s
.44024 .62729 m .44537 .66451 L .46929 .65683 L p .707 .577 .707 r
F P
0 g
s
.46929 .65683 m .46416 .61961 L .44024 .62729 L p .707 .577 .707 r
F P
0 g
s
.39301 .72931 m .39662 .71156 L .36605 .70356 L p .707 .577 .707 r
F P
0 g
s
.39662 .71156 m .39301 .72931 L .4243 .73403 L p .707 .577 .707 r
F P
0 g
s
.4243 .73403 m .42791 .71627 L .39662 .71156 L p .707 .577 .707 r
F P
0 g
s
.67038 .67819 m .66677 .69595 L .65049 .70235 L p .707 .577 .707 r
F P
0 g
s
.65204 .64852 m .65717 .68574 L .64085 .69381 L p .707 .577 .707 r
F P
0 g
s
.80484 .54931 m .81256 .60514 L .78541 .60516 L p .707 .577 .707 r
F P
0 g
s
.78541 .60516 m .77769 .54933 L .80484 .54931 L p .707 .577 .707 r
F P
0 g
s
.32149 .64107 m .32662 .67829 L .35378 .67828 L p .707 .577 .707 r
F P
0 g
s
.81549 .62955 m .82062 .66677 L .79984 .66428 L p .707 .577 .707 r
F P
0 g
s
.79984 .66428 m .79471 .62706 L .81549 .62955 L p .707 .577 .707 r
F P
0 g
s
.42791 .71627 m .4243 .73403 L .45324 .73501 L p .707 .577 .707 r
F P
0 g
s
.45324 .73501 m .45686 .71725 L .42791 .71627 L p .707 .577 .707 r
F P
0 g
s
.36244 .72132 m .36605 .70356 L .3392 .69308 L p .707 .577 .707 r
F P
0 g
s
.36605 .70356 m .36244 .72132 L .39301 .72931 L p .707 .577 .707 r
F P
0 g
s
.6861 .56314 m .69382 .61898 L .6699 .62665 L p .707 .577 .707 r
F P
0 g
s
.31857 .61677 m .31085 .56094 L .29848 .55622 L p .707 .577 .707 r
F P
0 g
s
.3392 .69308 m .33559 .71084 L .36244 .72132 L p .707 .577 .707 r
F P
0 g
s
.32662 .67829 m .32149 .64107 L .30071 .63859 L p .707 .577 .707 r
F P
0 g
s
.69382 .61898 m .6861 .56314 L .71526 .55661 L p .707 .577 .707 r
F P
0 g
s
.45686 .71725 m .45324 .73501 L .47702 .73216 L p .707 .577 .707 r
F P
0 g
s
.47702 .73216 m .48063 .7144 L .45686 .71725 L p .707 .577 .707 r
F P
0 g
s
.33559 .71084 m .3392 .69308 L .31869 .68113 L p .707 .577 .707 r
F P
0 g
s
.77769 .54933 m .78541 .60516 L .75454 .60768 L p .707 .577 .707 r
F P
0 g
s
.75454 .60768 m .74682 .55185 L .77769 .54933 L p .707 .577 .707 r
F P
0 g
s
.46416 .61961 m .46929 .65683 L .48561 .64877 L p .707 .577 .707 r
F P
0 g
s
.48561 .64877 m .48048 .61155 L .46416 .61961 L p .707 .577 .707 r
F P
0 g
s
.30071 .63859 m .30584 .67581 L .32662 .67829 L p .707 .577 .707 r
F P
0 g
s
.49061 .53384 m .49833 .58967 L .50546 .582 L p .707 .577 .707 r
F P
0 g
s
.50546 .582 m .49774 .52617 L .49061 .53384 L p .707 .577 .707 r
F P
0 g
s
.83232 .71146 m .8287 .72922 L .8082 .71727 L p .707 .577 .707 r
F P
0 g
s
.8082 .71727 m .81181 .69951 L .83232 .71146 L p .707 .577 .707 r
F P
0 g
s
.65717 .68574 m .65204 .64852 L .67596 .64085 L p .707 .577 .707 r
F P
0 g
s
.66677 .69595 m .67038 .67819 L .69416 .67534 L p .707 .577 .707 r
F P
0 g
s
.29848 .55622 m .3062 .61205 L .31857 .61677 L p .707 .577 .707 r
F P
0 g
s
.31869 .68113 m .31508 .69889 L .33559 .71084 L p .707 .577 .707 r
F P
0 g
s
.72298 .61244 m .71526 .55661 L .74682 .55185 L p .707 .577 .707 r
F P
0 g
s
.71526 .55661 m .72298 .61244 L .69382 .61898 L p .707 .577 .707 r
F P
0 g
s
.74682 .55185 m .75454 .60768 L .72298 .61244 L p .707 .577 .707 r
F P
0 g
s
.69416 .67534 m .69054 .6931 L .66677 .69595 L p .707 .577 .707 r
F P
0 g
s
.79471 .62706 m .79984 .66428 L .77268 .66429 L p .707 .577 .707 r
F P
0 g
s
.77268 .66429 m .76755 .62707 L .79471 .62706 L p .707 .577 .707 r
F P
0 g
s
.67596 .64085 m .68109 .67807 L .65717 .68574 L p .707 .577 .707 r
F P
0 g
s
.30584 .67581 m .30071 .63859 L .28834 .63385 L p .707 .577 .707 r
F P
0 g
s
.3062 .61205 m .29848 .55622 L .29572 .5497 L p .707 .577 .707 r
F P
0 g
s
.48063 .7144 m .47702 .73216 L .49329 .72576 L p .707 .577 .707 r
F P
0 g
s
.49329 .72576 m .4969 .708 L .48063 .7144 L p .707 .577 .707 r
F P
0 g
s
.68109 .67807 m .67596 .64085 L .70512 .63432 L p .707 .577 .707 r
F P
0 g
s
.31508 .69889 m .31869 .68113 L .30654 .66889 L p .707 .577 .707 r
F P
0 g
s
.81181 .69951 m .8082 .71727 L .78134 .70679 L p .707 .577 .707 r
F P
0 g
s
.78134 .70679 m .78496 .68903 L .81181 .69951 L p .707 .577 .707 r
F P
0 g
s
.69054 .6931 m .69416 .67534 L .7231 .67632 L p .707 .577 .707 r
F P
0 g
s
.28834 .63385 m .29347 .67107 L .30584 .67581 L p .707 .577 .707 r
F P
0 g
s
.76755 .62707 m .77268 .66429 L .74181 .66679 L p .707 .577 .707 r
F P
0 g
s
.74181 .66679 m .73668 .62957 L .76755 .62707 L p .707 .577 .707 r
F P
0 g
s
.48048 .61155 m .48561 .64877 L .49274 .6411 L p .707 .577 .707 r
F P
0 g
s
.49274 .6411 m .48761 .60388 L .48048 .61155 L p .707 .577 .707 r
F P
0 g
s
.30654 .66889 m .30292 .68665 L .31508 .69889 L p .707 .577 .707 r
F P
0 g
s
.70512 .63432 m .71025 .67154 L .68109 .67807 L p .707 .577 .707 r
F P
0 g
s
.7231 .67632 m .71949 .69408 L .69054 .6931 L p .707 .577 .707 r
F P
0 g
s
.49774 .52617 m .50546 .582 L .5027 .57549 L p .707 .577 .707 r
F P
0 g
s
.5027 .57549 m .49499 .51966 L .49774 .52617 L p .707 .577 .707 r
F P
0 g
s
.29572 .5497 m .30344 .60553 L .3062 .61205 L p .707 .577 .707 r
F P
0 g
s
.71025 .67154 m .70512 .63432 L .73668 .62957 L p .707 .577 .707 r
F P
0 g
s
.73668 .62957 m .74181 .66679 L .71025 .67154 L p .707 .577 .707 r
F P
0 g
s
.78496 .68903 m .78134 .70679 L .75078 .69879 L p .707 .577 .707 r
F P
0 g
s
.75078 .69879 m .75439 .68104 L .78496 .68903 L p .707 .577 .707 r
F P
0 g
s
.71949 .69408 m .7231 .67632 L .75439 .68104 L p .707 .577 .707 r
F P
0 g
s
.75439 .68104 m .75078 .69879 L .71949 .69408 L p .707 .577 .707 r
F P
0 g
s
.29347 .67107 m .28834 .63385 L .28558 .62733 L p .707 .577 .707 r
F P
0 g
s
.4969 .708 m .49329 .72576 L .50047 .71643 L p .707 .577 .707 r
F P
0 g
s
.50047 .71643 m .50408 .69867 L .4969 .708 L p .707 .577 .707 r
F P
0 g
s
.30292 .68665 m .30654 .66889 L .30392 .65755 L p .707 .577 .707 r
F P
0 g
s
.30344 .60553 m .29572 .5497 L .30286 .54204 L p .707 .577 .707 r
F P
0 g
s
.28558 .62733 m .29071 .66455 L .29347 .67107 L p .707 .577 .707 r
F P
0 g
s
.30392 .65755 m .3003 .67531 L .30292 .68665 L p .707 .577 .707 r
F P
0 g
s
.48761 .60388 m .49274 .6411 L .48998 .63458 L p .707 .577 .707 r
F P
0 g
s
.48998 .63458 m .48485 .59736 L .48761 .60388 L p .707 .577 .707 r
F P
0 g
s
.49499 .51966 m .5027 .57549 L .49033 .57076 L p .707 .577 .707 r
F P
0 g
s
.49033 .57076 m .48261 .51493 L .49499 .51966 L p .707 .577 .707 r
F P
0 g
s
.30286 .54204 m .31057 .59787 L .30344 .60553 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50408 .69867 m .50047 .71643 L .49785 .70508 L p .707 .577 .707 r
F P
0 g
s
.49785 .70508 m .50147 .68733 L .50408 .69867 L p .707 .577 .707 r
F P
0 g
s
.29071 .66455 m .28558 .62733 L .29271 .61966 L p .707 .577 .707 r
F P
0 g
s
.3003 .67531 m .30392 .65755 L .3111 .64822 L p .707 .577 .707 r
F P
0 g
s
.31057 .59787 m .30286 .54204 L .31918 .53397 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.3111 .64822 m .30748 .66598 L .3003 .67531 L p .707 .577 .707 r
F P
0 g
s
.29271 .61966 m .29784 .65689 L .29071 .66455 L p .707 .577 .707 r
F P
0 g
s
.48485 .59736 m .48998 .63458 L .47761 .62985 L p .707 .577 .707 r
F P
0 g
s
.47761 .62985 m .47248 .59263 L .48485 .59736 L p .707 .577 .707 r
F P
0 g
s
.48261 .51493 m .49033 .57076 L .46955 .56829 L p .707 .577 .707 r
F P
0 g
s
.46955 .56829 m .46183 .51246 L .48261 .51493 L p .707 .577 .707 r
F P
0 g
s
.31918 .53397 m .32689 .5898 L .31057 .59787 L p .707 .577 .707 r
F P
0 g
s
.50147 .68733 m .49785 .70508 L .48569 .69284 L p .707 .577 .707 r
F P
0 g
s
.48569 .69284 m .48931 .67508 L .50147 .68733 L p .707 .577 .707 r
F P
0 g
s
.29784 .65689 m .29271 .61966 L .30903 .6116 L p .707 .577 .707 r
F P
0 g
s
.30748 .66598 m .3111 .64822 L .32737 .64182 L p .707 .577 .707 r
F P
0 g
s
.32689 .5898 m .31918 .53397 L .34309 .52629 L p .707 .577 .707 r
F P
0 g
s
.32737 .64182 m .32376 .65957 L .30748 .66598 L p .707 .577 .707 r
F P
0 g
s
.30903 .6116 m .31416 .64882 L .29784 .65689 L p .707 .577 .707 r
F P
0 g
s
.46183 .51246 m .46955 .56829 L .4424 .56831 L p .707 .577 .707 r
F P
0 g
s
.4424 .56831 m .43468 .51248 L .46183 .51246 L p .707 .577 .707 r
F P
0 g
s
.47248 .59263 m .47761 .62985 L .45682 .62736 L p .707 .577 .707 r
F P
0 g
s
.45682 .62736 m .4517 .59014 L .47248 .59263 L p .707 .577 .707 r
F P
0 g
s
.34309 .52629 m .35081 .58212 L .32689 .5898 L p .707 .577 .707 r
F P
0 g
s
.35081 .58212 m .34309 .52629 L .37225 .51975 L p .707 .577 .707 r
F P
0 g
s
.43468 .51248 m .4424 .56831 L .41153 .57083 L p .707 .577 .707 r
F P
0 g
s
.41153 .57083 m .40381 .51499 L .43468 .51248 L p .707 .577 .707 r
F P
0 g
s
.48931 .67508 m .48569 .69284 L .46519 .68089 L p .707 .577 .707 r
F P
0 g
s
.46519 .68089 m .4688 .66314 L .48931 .67508 L p .707 .577 .707 r
F P
0 g
s
.31416 .64882 m .30903 .6116 L .33295 .60393 L p .707 .577 .707 r
F P
0 g
s
.32376 .65957 m .32737 .64182 L .35114 .63897 L p .707 .577 .707 r
F P
0 g
s
.37997 .57558 m .37225 .51975 L .40381 .51499 L p .707 .577 .707 r
F P
0 g
s
.37225 .51975 m .37997 .57558 L .35081 .58212 L p .707 .577 .707 r
F P
0 g
s
.40381 .51499 m .41153 .57083 L .37997 .57558 L p .707 .577 .707 r
F P
0 g
s
.35114 .63897 m .34753 .65672 L .32376 .65957 L p .707 .577 .707 r
F P
0 g
s
.4517 .59014 m .45682 .62736 L .42967 .62737 L p .707 .577 .707 r
F P
0 g
s
.42967 .62737 m .42454 .59015 L .4517 .59014 L p .707 .577 .707 r
F P
0 g
s
.33295 .60393 m .33808 .64115 L .31416 .64882 L p .707 .577 .707 r
F P
0 g
s
.33808 .64115 m .33295 .60393 L .36211 .5974 L p .707 .577 .707 r
F P
0 g
s
.4688 .66314 m .46519 .68089 L .43833 .67041 L p .707 .577 .707 r
F P
0 g
s
.43833 .67041 m .44195 .65265 L .4688 .66314 L p .707 .577 .707 r
F P
0 g
s
.34753 .65672 m .35114 .63897 L .38009 .63995 L p .707 .577 .707 r
F P
0 g
s
.42454 .59015 m .42967 .62737 L .3988 .62987 L p .707 .577 .707 r
F P
0 g
s
.3988 .62987 m .39367 .59265 L .42454 .59015 L p .707 .577 .707 r
F P
0 g
s
.36211 .5974 m .36724 .63462 L .33808 .64115 L p .707 .577 .707 r
F P
0 g
s
.38009 .63995 m .37648 .6577 L .34753 .65672 L p .707 .577 .707 r
F P
0 g
s
.36724 .63462 m .36211 .5974 L .39367 .59265 L p .707 .577 .707 r
F P
0 g
s
.39367 .59265 m .3988 .62987 L .36724 .63462 L p .707 .577 .707 r
F P
0 g
s
.44195 .65265 m .43833 .67041 L .40777 .66242 L p .707 .577 .707 r
F P
0 g
s
.40777 .66242 m .41138 .64466 L .44195 .65265 L p .707 .577 .707 r
F P
0 g
s
.37648 .6577 m .38009 .63995 L .41138 .64466 L p .707 .577 .707 r
F P
0 g
s
.41138 .64466 m .40777 .66242 L .37648 .6577 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001WOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1UYF0P002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<007ooOol0Hgoo001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00Oomoo`1SOol006Aoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001o
ogoo06=oo`00I7oo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0Hgoo
001TOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80
009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06=oo`00I7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<007ooOol0Hgoo001TOol20002
FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Aoo`80009J
EP03001JEUYF009JEP03001JEUYF00MJEPl000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001oogoo06=oo`00I7oo0P000UYF00<005YFFUH00UYF2P0015YF
00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00IGoo001TOol200000eYF000000050004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IGoo001TOol400000eYF001JEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001POol40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005aoo`@00003FUH005YF00MJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001UOol005Yoo`80
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<006Eoo`00FGoo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EWoo
00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=J
EP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000KOolI000bOol005Aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8001Moo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00E7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P004goo10001UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H0
05YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000?Ool40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000;Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001EOol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?0003FUH01P00FUIJ
EP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Moo`@00003FUH0
05YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYF000^Ool005Eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPP000QJEP03001JEUYF00AJEPD00004FUH00000000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20004Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo001EOol00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF1@00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00D005YFFUIJEP0002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF10002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
02eoo`00EGoo00<005YF000015YF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`03001J
EP0000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool005Eoo`04
001JEUYF0003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0006FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00EGoo00@005YFFUH0009JEP05
001JEUYFFUH00006FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP0500000eYF
001JEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001FOol2FUH30004FUH00`00FUIJ
EP03FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;7oo001FOol2FUH20005FUH00`00FUH0000300000eYF
001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008002aoo`00D7oo1P0000AJEP00FUH000=JEP@000EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000/Ool004Moo`T000AJEP05001JEP00001JEP0400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF6@000eYF00<007oo
Ool0:Woo0011Ool60004FUH00`00FUIJEP06FUH00`00FUH000020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH010001UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP800003FUH0000002]oo`00?Goo100000=JEP00FUH01eYF00<005YFFUH0
1UYF00@005YF000000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEP@0
0003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP@002]oo`00>Goo
10001EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00@005YFFUH002]oo`00=goo0P0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0eYF0P00;7oo000eOol20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000/Ool003=o
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPh000=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEUYF10001eYF00<005YFFUH01UYF00<005YFFUH00UYF3P001UYF00@005YFFUIJEP8002eo
o`00<Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP0000000P000UYF00<005YF
FUH015YF1@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00AJEP03001JEUYF00D00003FUH005YF008002moo`00;goo0P000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
1EYF00<005YFFUH015YF40001UYF00<005YFFUH015YF00<005YFFUH00UYF10000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0`0015YF00<005YFFUH0
15YF1P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00<Goo
000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP0@00000eYF001JEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00@00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000aOol002eoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
0004FUH00`00FUIJEP03FUH50008FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40002FUH01000FUIJEUYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<0
05YF00000`0015YF00<005YFFUH01UYF00<005YFFUH00eYF1@001UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
10000UYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH30002FUH00`00FUIJEP02FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJ
EP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080031oo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH30003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH01000FUH000001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00<7oo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH00UYF00@005YFFUIJEPL000AJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00031o
o`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF0P000eYF1@000eYF00@005YFFUIJEPP000AJEP03001JEUYF00MJEP04001JEUYF
FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00<7oo000^Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH:0002FUH200001EYF000005YF00001eYF00<005YFFUH01EYF00<005YF
FUH01`001UYF00<005YFFUH01EYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00D005YF001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPl000=JEP03001JEUYF008002moo`00;Woo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH015YF1`001eYF0`0000=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF10000UYF00<005YFFUH01UYF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF009J
EPT0009oo`@00003FUH005YF00EJEPH00003FUH0000002moo`00;Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00@005YF001JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH00000008000MJEP03001JEUYF008000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00AJEPH0009oo`T000EJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
02moo`00;Woo00<005YF000015YF00<005YFFUH00eYF100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YF
FUH015YF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP050007Ool500000eYF001J
EP07FUH00`00FUIJEP03FUH00`00FUIJEP03FUH3000_Ool002ioo`03001JEP0000AJEP03001JEP00
00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEQL000MJEP03001J
EUYF00IJEP<00003FUH005YF00EJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF5@0000=JEP00FUH01eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;goo000^Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF2P000eYF0P001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03
001JEP00008000EJEP03001JEUYF00UJEP8000IJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00@005YFFUIJEP8000EJEP03001JEUYF00EJEP03
001JEUYF009JEPL000IJEP03001JEUYF00AJEP03001JEUYF009JEP80031oo`00;Woo00@005YFFUH0
009JEP05001JEUYFFUH00007FUH00`00FUIJEP03FUH70004FUH00`00FUIJEP02FUH01000FUIJEUYF
1P000UYF00<005YF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00@005YF000000=J
EP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@0009J
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02moo`00;goo0UYF0`0015YF00<005YFFUH0
1EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03
001JEP0000D0009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP05001JEUYFFUH00002FUH0
1`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH01000
FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000
1EYF00<005YFFUH00P00<Woo000_Ool2FUH20005FUH01000FUIJEUYF1P001UYF00<005YFFUH01eYF
00<005YFFUH00UYF00<005YF000015YF0P000UYF00<007oo00000UYF00<005YFFUH00eYF1P0015YF
00<005YFFUH02EYF00<005YFFUH00UYF0`000eYF00<005YF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUH0009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUH000000eYF0`00=7oo000_Ool015YF001JEP000eYF1P00
0eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001UYF1@000UYF00<005YFFUH0
0eYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH015YF00@005YFFUIJEP<000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEQD000AJEP03001JEUYF00MJEP04
001JEUYFFUH4000fOol002moo`80009JEP<00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP000080009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEP00FUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH00000FUH00P0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01`001UYF00<005YFFUH015YF0P00=Woo000_Ool200000eYF00000003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH01000FUIJEUYF
10001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01UYF0P0000=JEP0000002eYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEPD0009JEP03001JEUYF00EJEP<003Aoo`00<7oo0P001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000UYF00<005YF
FUH01EYF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF00@005YFFUH003=oo`00;Woo0`001eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00`00
25YF00<005YF00000`002EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF009JEPL000Ioo`8000=JEP03001JEUYF009JEP80035oo`00;7oo0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00UYF0P001eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00<005YFFUH015YF0P0000EJ
EP00001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YF
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH8000?Ool200000eYF001JEP05FUH00`00Oomoo`0^
Ool002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEQD000=J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEQ00
00Ioo`<0011oo`8000IJEP8002moo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF00<005YFFUH00`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP04001J
EUYFFUH20007Ool5000AOol20004FUH01000FUH00000;Goo000ZOol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000goo000000020002FUH00`00FUIJEP04FUH5
0002FUH00`00FUH000020006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0015YF1P0000=JEP00FUH00P002Goo1@004goo00@005YFFUH000AJEP03001oogoo02Yoo`00:Woo
00<005YF000015YF00<005YFFUH01EYF00<005YFFUH015YF1P0000=oo`0000001`001UYF00<005YF
FUH015YF00<005YFFUH00UYF0`000UYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00800004FUH00000000;Ool5
000DOol30004FUH00`00Oomoo`0ZOol002Yoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
01000003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF
00=JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00005FUH200000eYF
001oo`0;Ool3000GOol01000FUIJEUYF0P00;7oo000ZOol01000FUIJEP0015YF00<005YFFUH00eYF
1@0015YF2`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF200015YF00@005YFFUIJEPD000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP8000EJEP03001JEP00008002Ioo`03001JEUYF
008002aoo`00:Woo00@005YFFUH000AJEP03001JEP0000<000AJEP03001JEUYF00IJEP04001JEUYF
FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0`009Goo0P0000=JEP00Ool0:goo000[
Ool00`00FUH00003FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP040003FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF0`000UYF00<005YFFUH01EYF10008Woo00<005YF0000;7oo000[
Ool01000FUH005YF0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF10001UYF00@005YF0000009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP07
FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
0008FUH00`00FUIJEP04000NOol00`00FUH0000/Ool002]oo`05001JEP00001JEP020003FUH01000
FUIJEUYF1`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP<000Aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02EYF2@0025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF1@005goo
1000;Goo000[Ool20002FUH20003FUH50003FUH01000FUIJEUYF200015YF00<005YFFUH01eYF00@0
05YFFUIJEP<000Moo`04001JEUYF0005FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP03FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50002FUH2000]Ool002]oo`80
009JEP800005FUH00000FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP070006FUH00`00FUIJEP05
FUH20005Ool01000FUIJEP001EYF00<005YFFUH010002UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YF000010001UYF00<005YFFUH00UYF0P001EYF00<005YFFUH00eYF00<0
05YF00000P0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF000]Ool002]o
o`80009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP@0009JEP03001J
EUYF00IJEP<000=oo`04001JEUYF0005FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH>0002FUH60006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002aoo`03
001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPX000MJEP04001J
EUYF0002Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF00000P0015YF0`001UYF00<005YFFUH00UYF
100017oo10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
02moo`00;Goo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH010002Woo0P0015YF
00<005YFFUH00UYF0`000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYFFUH30006FUH0
0`00FUIJEP03FUH30008Ool50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo
000^Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH00UYF1`0047oo0`0000=JEP00
FUH01EYF00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000EJEP00001JEP0000IJ
EP03001JEUYF009JEP03001JEP0000eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5000bOol0
02ioo`8000=JEPl000Ioo`<0015oo`8000IJEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP@00003FUH005YF00EJEP03001JEUYF009JEP80019oo`h003Moo`00;goo00@005YFFUIJEP<0
015oo`D0019oo`8000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP00
1UYF00<005YFFUH00UYF0P00Egoo000_Ool01@00FUIJEUYF00000UYF00<007ooOol03Woo1@0057oo
00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YF000005YF0006FUH01000
FUIJEUYF0P00F7oo000`Ool00`00FUH00004FUH2000>Ool5000EOol50004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH01000FUH00000FWoo000aOol20006FUH2000=Ool3000H
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEP00FUH005YF0080009J
EP<005aoo`00<Woo00<005YFFUH015YF00@005YF000002Moo`8000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00009JEP04001JEUYFFUH2001OOol003=oo`8000AJEP04001JEUYFFUH3000U
Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH2001M
Ool003Eoo`04001JEUYF0007FUH3000SOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30000
0eYF001JEP06FUH3001KOol003Ioo`<000QJEP03001JEP0000<001ioo`H000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009oo`<000IJEP03001JEUYF008005Uoo`00>7oo0P001eYF00<005YFFUH00eYF1`005Goo0P00
00=JEP0000000Woo0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YF00000`001goo0P000eYF00<005YFFUH00eYF0P00Egoo000j
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80008Ool50003FUH20005Ool40002FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH3000=
Ool200000eYF001JEP05FUH2001FOol003aoo`<00003FUH005YF00MJEP03001JEUYF00IJEP04001J
EUYFFUH80003FUH01000FUIJEUYF0P002Woo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH00UYF1@0047oo0P001UYF00@005YF000005Aoo`00?goo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000moo`H0009JEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000800003Ool0000000<0015oo`80
00=JEP03001JEUYF009JEP03001oogoo055oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUIJEP8001Ioo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJ
EPL000Aoo`D001=oo`800003FUH005YF00=JEP03001oogoo055oo`00AWoo1`0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000021ooaX000]oo`D001Eoo`8000AJEP03001oogoo055oo`00
CGoo200015YF00@005YFFUIJEPD0035oo`8000EJEP04001JEP00000<Ool3000HOol00`00FUIJEP02
001COol005Eoo`P003Moo`03001JEUYF00=JEP04001JEUYFFUH3000UOol01000FUH00000Dgoo002E
Ool20002FUH00`00FUIJEP05FUH4000ROol3001COol009Moo`<000QJEP03001JEUYF00@001ioo`<0
05=oo`00VGoo0P001eYF00<005YFFUH015YF1@005goo1000E7oo002KOol20004FUH00`00FUIJEP07
FUH00`00FUIJEP04000>Ool50002FUH2001DOol009eoo`<00003FUH005YF00QJEP03001JEUYF00AJ
EPh000=JEP06001JEUYF001JEP00E7oo002POol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02001EOol00:Aoo`@0009JEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH0001FOol00:Qoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEP00001GOol00:eoo`@0009JEP03001JEUYF00EJEP04001JEUYFFUH5001IOol00;5o
o`h005ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58847 .75275 m .59618 .69857 L .56532 .69232 L p .707 .577 .707 r
F P
0 g
s
.59618 .69857 m .58847 .75275 L .62003 .75589 L p .707 .577 .707 r
F P
0 g
s
.62003 .75589 m .62774 .70172 L .59618 .69857 L p .707 .577 .707 r
F P
0 g
s
.62774 .70172 m .62003 .75589 L .64919 .75563 L p .707 .577 .707 r
F P
0 g
s
.64919 .75563 m .65691 .70145 L .62774 .70172 L p .707 .577 .707 r
F P
0 g
s
.5576 .7465 m .56532 .69232 L .53817 .68358 L p .707 .577 .707 r
F P
0 g
s
.56532 .69232 m .5576 .7465 L .58847 .75275 L p .707 .577 .707 r
F P
0 g
s
.65691 .70145 m .64919 .75563 L .6731 .75197 L p .707 .577 .707 r
F P
0 g
s
.6731 .75197 m .68082 .6978 L .65691 .70145 L p .707 .577 .707 r
F P
0 g
s
.60119 .81453 m .60632 .77841 L .57546 .77217 L p .707 .577 .707 r
F P
0 g
s
.60632 .77841 m .60119 .81453 L .63276 .81766 L p .707 .577 .707 r
F P
0 g
s
.63276 .81766 m .63789 .78154 L .60632 .77841 L p .707 .577 .707 r
F P
0 g
s
.53045 .73776 m .53817 .68358 L .51739 .67321 L p .707 .577 .707 r
F P
0 g
s
.53817 .68358 m .53045 .73776 L .5576 .7465 L p .707 .577 .707 r
F P
0 g
s
.63789 .78154 m .63276 .81766 L .66192 .81738 L p .707 .577 .707 r
F P
0 g
s
.66192 .81738 m .66705 .78126 L .63789 .78154 L p .707 .577 .707 r
F P
0 g
s
.57033 .80829 m .57546 .77217 L .5483 .76344 L p .707 .577 .707 r
F P
0 g
s
.57546 .77217 m .57033 .80829 L .60119 .81453 L p .707 .577 .707 r
F P
0 g
s
.66705 .78126 m .66192 .81738 L .68583 .81373 L p .707 .577 .707 r
F P
0 g
s
.68583 .81373 m .69096 .77761 L .66705 .78126 L p .707 .577 .707 r
F P
0 g
s
.5483 .76344 m .54317 .79956 L .57033 .80829 L p .707 .577 .707 r
F P
0 g
s
.54317 .79956 m .5483 .76344 L .52752 .75308 L p .707 .577 .707 r
F P
0 g
s
.68082 .6978 m .6731 .75197 L .68942 .7453 L p .707 .577 .707 r
F P
0 g
s
.68942 .7453 m .69714 .69112 L .68082 .6978 L p .707 .577 .707 r
F P
0 g
s
.51739 .67321 m .50967 .72738 L .53045 .73776 L p .707 .577 .707 r
F P
0 g
s
.59223 .84515 m .58862 .82662 L .55805 .83094 L p .707 .577 .707 r
F P
0 g
s
.58862 .82662 m .59223 .84515 L .62352 .83876 L p .707 .577 .707 r
F P
0 g
s
.62352 .83876 m .6199 .82023 L .58862 .82662 L p .707 .577 .707 r
F P
0 g
s
.6199 .82023 m .62352 .83876 L .65247 .83093 L p .707 .577 .707 r
F P
0 g
s
.65247 .83093 m .64885 .8124 L .6199 .82023 L p .707 .577 .707 r
F P
0 g
s
.50967 .72738 m .51739 .67321 L .50501 .66221 L p .707 .577 .707 r
F P
0 g
s
.55805 .83094 m .56166 .84947 L .59223 .84515 L p .707 .577 .707 r
F P
0 g
s
.56166 .84947 m .55805 .83094 L .5312 .83276 L p .707 .577 .707 r
F P
0 g
s
.52752 .75308 m .52239 .7892 L .54317 .79956 L p .707 .577 .707 r
F P
0 g
s
.5312 .83276 m .53481 .8513 L .56166 .84947 L p .707 .577 .707 r
F P
0 g
s
.64885 .8124 m .65247 .83093 L .67624 .82242 L p .707 .577 .707 r
F P
0 g
s
.67624 .82242 m .67263 .80389 L .64885 .8124 L p .707 .577 .707 r
F P
0 g
s
.69096 .77761 m .68583 .81373 L .70216 .80705 L p .707 .577 .707 r
F P
0 g
s
.70216 .80705 m .70728 .77093 L .69096 .77761 L p .707 .577 .707 r
F P
0 g
s
.52239 .7892 m .52752 .75308 L .51514 .74209 L p .707 .577 .707 r
F P
0 g
s
.50501 .66221 m .4973 .71638 L .50967 .72738 L p .707 .577 .707 r
F P
0 g
s
.53481 .8513 m .5312 .83276 L .51069 .83192 L p .707 .577 .707 r
F P
0 g
s
.69714 .69112 m .68942 .7453 L .69656 .73624 L p .707 .577 .707 r
F P
0 g
s
.69656 .73624 m .70427 .68207 L .69714 .69112 L p .707 .577 .707 r
F P
0 g
s
.51069 .83192 m .5143 .85045 L .53481 .8513 L p .707 .577 .707 r
F P
0 g
s
.4973 .71638 m .50501 .66221 L .50226 .65167 L p .707 .577 .707 r
F P
0 g
s
.67263 .80389 m .67624 .82242 L .69251 .81407 L p .707 .577 .707 r
F P
0 g
s
.69251 .81407 m .6889 .79553 L .67263 .80389 L p .707 .577 .707 r
F P
0 g
s
.51514 .74209 m .51002 .77821 L .52239 .7892 L p .707 .577 .707 r
F P
0 g
s
.70728 .77093 m .70216 .80705 L .70929 .79799 L p .707 .577 .707 r
F P
0 g
s
.70929 .79799 m .71442 .76187 L .70728 .77093 L p .707 .577 .707 r
F P
0 g
s
.51002 .77821 m .51514 .74209 L .51239 .73155 L p .707 .577 .707 r
F P
0 g
s
.50226 .65167 m .49454 .70584 L .4973 .71638 L p .707 .577 .707 r
F P
0 g
s
.5143 .85045 m .51069 .83192 L .49853 .82849 L p .707 .577 .707 r
F P
0 g
s
.49853 .82849 m .50215 .84702 L .5143 .85045 L p .707 .577 .707 r
F P
0 g
s
.70427 .68207 m .69656 .73624 L .6938 .7257 L p .707 .577 .707 r
F P
0 g
s
.6938 .7257 m .70152 .67153 L .70427 .68207 L p .707 .577 .707 r
F P
0 g
s
.6889 .79553 m .69251 .81407 L .69969 .80669 L p .707 .577 .707 r
F P
0 g
s
.69969 .80669 m .69608 .78815 L .6889 .79553 L p .707 .577 .707 r
F P
0 g
s
.49454 .70584 m .50226 .65167 L .50939 .64262 L p .707 .577 .707 r
F P
0 g
s
.51239 .73155 m .50726 .76767 L .51002 .77821 L p .707 .577 .707 r
F P
0 g
s
.49294 .82177 m .48927 .31951 L .44527 .31715 L p .707 .577 .707 r
F P
0 g
s
.50726 .76767 m .51239 .73155 L .51952 .7225 L p .707 .577 .707 r
F P
0 g
s
.50939 .64262 m .50167 .69679 L .49454 .70584 L p .707 .577 .707 r
F P
0 g
s
.50167 .69679 m .50939 .64262 L .52571 .63594 L p .707 .577 .707 r
F P
0 g
s
.51952 .7225 m .51439 .75862 L .50726 .76767 L p .707 .577 .707 r
F P
0 g
s
.51439 .75862 m .51952 .7225 L .53584 .71582 L p .707 .577 .707 r
F P
0 g
s
.52571 .63594 m .51799 .69011 L .50167 .69679 L p .707 .577 .707 r
F P
0 g
s
.50215 .84702 m .49853 .82849 L .49591 .82281 L p .707 .577 .707 r
F P
0 g
s
.49591 .82281 m .49953 .84134 L .50215 .84702 L p .707 .577 .707 r
F P
0 g
s
.49953 .84134 m .49591 .82281 L .50309 .81543 L p .707 .577 .707 r
F P
0 g
s
.50309 .81543 m .50671 .83396 L .49953 .84134 L p .707 .577 .707 r
F P
0 g
s
.51799 .69011 m .52571 .63594 L .54962 .63229 L p .707 .577 .707 r
F P
0 g
s
.53584 .71582 m .53071 .75194 L .51439 .75862 L p .707 .577 .707 r
F P
0 g
s
.53071 .75194 m .53584 .71582 L .55975 .71216 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .5419 .68646 L .51799 .69011 L p .707 .577 .707 r
F P
0 g
s
.50671 .83396 m .50309 .81543 L .51937 .80707 L p .707 .577 .707 r
F P
0 g
s
.51937 .80707 m .52298 .82561 L .50671 .83396 L p .707 .577 .707 r
F P
0 g
s
.55975 .71216 m .55462 .74829 L .53071 .75194 L p .707 .577 .707 r
F P
0 g
s
.52298 .82561 m .51937 .80707 L .54314 .79857 L p .707 .577 .707 r
F P
0 g
s
.54314 .79857 m .54675 .8171 L .52298 .82561 L p .707 .577 .707 r
F P
0 g
s
.48927 .31951 m .49294 .82177 L .53788 .82038 L p .707 .577 .707 r
F P
0 g
s
.53788 .82038 m .53422 .31812 L .48927 .31951 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .57878 .63202 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.5419 .68646 m .54455 .66786 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.54455 .66786 m .54962 .63229 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.64121 .64141 m .63349 .69559 L .60263 .68934 L p .707 .577 .707 r
F P
0 g
s
.60263 .68934 m .61034 .63516 L .64121 .64141 L p .707 .577 .707 r
F P
0 g
s
.57107 .68619 m .57878 .63202 L .61034 .63516 L p .707 .577 .707 r
F P
0 g
s
.57878 .63202 m .57107 .68619 L .5419 .68646 L p .707 .577 .707 r
F P
0 g
s
.61034 .63516 m .60263 .68934 L .57107 .68619 L p .707 .577 .707 r
F P
0 g
s
.55462 .74829 m .55975 .71216 L .58892 .71189 L p .707 .577 .707 r
F P
0 g
s
.58892 .71189 m .58379 .74801 L .55462 .74829 L p .707 .577 .707 r
F P
0 g
s
.58379 .74801 m .58892 .71189 L .62048 .71502 L p .707 .577 .707 r
F P
0 g
s
.62048 .71502 m .61535 .75114 L .58379 .74801 L p .707 .577 .707 r
F P
0 g
s
.63394 .78003 m .63756 .79856 L .60699 .80288 L p .707 .577 .707 r
F P
0 g
s
.60699 .80288 m .60338 .78435 L .63394 .78003 L p .707 .577 .707 r
F P
0 g
s
.5757 .80927 m .57209 .79073 L .60338 .78435 L p .707 .577 .707 r
F P
0 g
s
.60338 .78435 m .60699 .80288 L .5757 .80927 L p .707 .577 .707 r
F P
0 g
s
.5757 .31311 m .57915 .78572 L p .61332 .80725 L .707 .577 .707 r
F P
0 g
s
.57915 .78572 m .57936 .81538 L .58729 .81348 L p .707 .577 .707 r
F P
0 g
s
.58729 .81348 m .61332 .80725 L p .57915 .78572 L .707 .577 .707 r
F P
0 g
s
.54675 .8171 m .54314 .79857 L .57209 .79073 L p .707 .577 .707 r
F P
0 g
s
.57209 .79073 m .5757 .80927 L .54675 .8171 L p .707 .577 .707 r
F P
0 g
s
.53422 .31812 m .53788 .82038 L .57936 .81538 L p .707 .577 .707 r
F P
0 g
s
.57936 .81538 m .5757 .31311 L .53422 .31812 L p .707 .577 .707 r
F P
0 g
s
.44893 .81942 m .44527 .31715 L .4065 .31127 L p .707 .577 .707 r
F P
0 g
s
.44527 .31715 m .44893 .81942 L .49294 .82177 L p .707 .577 .707 r
F P
0 g
s
.71442 .76187 m .70929 .79799 L .70653 .78746 L p .707 .577 .707 r
F P
0 g
s
.70653 .78746 m .71166 .75134 L .71442 .76187 L p .707 .577 .707 r
F P
0 g
s
.61332 .80725 m .60965 .30499 L .5757 .31311 L p .707 .577 .707 r
F P
0 g
s
.70152 .67153 m .6938 .7257 L .68143 .7147 L p .707 .577 .707 r
F P
0 g
s
.68143 .7147 m .68914 .66053 L .70152 .67153 L p .707 .577 .707 r
F P
0 g
s
.69608 .78815 m .69969 .80669 L .69707 .801 L p .707 .577 .707 r
F P
0 g
s
.69707 .801 m .69346 .78247 L .69608 .78815 L p .707 .577 .707 r
F P
0 g
s
.24546 .71597 m .25318 .66179 L .22231 .65555 L p .707 .577 .707 r
F P
0 g
s
.25318 .66179 m .24546 .71597 L .27702 .71911 L p .707 .577 .707 r
F P
0 g
s
.27702 .71911 m .28473 .66494 L .25318 .66179 L p .707 .577 .707 r
F P
0 g
s
.41017 .81354 m .4065 .31127 L .37678 .30246 L p .707 .577 .707 r
F P
0 g
s
.4065 .31127 m .41017 .81354 L .44893 .81942 L p .707 .577 .707 r
F P
0 g
s
.28473 .66494 m .27702 .71911 L .30618 .71885 L p .707 .577 .707 r
F P
0 g
s
.30618 .71885 m .3139 .66467 L .28473 .66494 L p .707 .577 .707 r
F P
0 g
s
.21459 .70972 m .22231 .65555 L .19516 .6468 L p .707 .577 .707 r
F P
0 g
s
.22231 .65555 m .21459 .70972 L .24546 .71597 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71166 .75134 m .70653 .78746 L .69415 .77647 L p .707 .577 .707 r
F P
0 g
s
.69415 .77647 m .69928 .74035 L .71166 .75134 L p .707 .577 .707 r
F P
0 g
s
.3139 .66467 m .30618 .71885 L .33009 .7152 L p .707 .577 .707 r
F P
0 g
s
.33009 .7152 m .33781 .66102 L .3139 .66467 L p .707 .577 .707 r
F P
0 g
s
.65135 .72126 m .64622 .75738 L .61535 .75114 L p .707 .577 .707 r
F P
0 g
s
.61535 .75114 m .62048 .71502 L .65135 .72126 L p .707 .577 .707 r
F P
0 g
s
.63756 .79856 m .63394 .78003 L .66079 .7782 L p .707 .577 .707 r
F P
0 g
s
.60965 .30499 m .61332 .80725 L .63643 .7968 L p .707 .577 .707 r
F P
0 g
s
.66836 .65015 m .66065 .70433 L .63349 .69559 L p .707 .577 .707 r
F P
0 g
s
.63349 .69559 m .64121 .64141 L .66836 .65015 L p .707 .577 .707 r
F P
0 g
s
.63643 .7968 m .63276 .29453 L .60965 .30499 L p .707 .577 .707 r
F P
0 g
s
.25819 .77781 m .26332 .74169 L .23245 .73546 L p .707 .577 .707 r
F P
0 g
s
.26332 .74169 m .25819 .77781 L .28975 .78095 L p .707 .577 .707 r
F P
0 g
s
.28975 .78095 m .29488 .74483 L .26332 .74169 L p .707 .577 .707 r
F P
0 g
s
.68914 .66053 m .68143 .7147 L .66065 .70433 L p .707 .577 .707 r
F P
0 g
s
.66065 .70433 m .66836 .65015 L .68914 .66053 L p .707 .577 .707 r
F P
0 g
s
.18744 .70098 m .19516 .6468 L .17438 .63643 L p .707 .577 .707 r
F P
0 g
s
.19516 .6468 m .18744 .70098 L .21459 .70972 L p .707 .577 .707 r
F P
0 g
s
.29488 .74483 m .28975 .78095 L .31891 .78067 L p .707 .577 .707 r
F P
0 g
s
.31891 .78067 m .32404 .74455 L .29488 .74483 L p .707 .577 .707 r
F P
0 g
s
.22732 .77158 m .23245 .73546 L .20529 .72673 L p .707 .577 .707 r
F P
0 g
s
.23245 .73546 m .22732 .77158 L .25819 .77781 L p .707 .577 .707 r
F P
0 g
s
.69346 .78247 m .69707 .801 L .68492 .79757 L p .707 .577 .707 r
F P
0 g
s
.68492 .79757 m .6813 .77904 L .69346 .78247 L p .707 .577 .707 r
F P
0 g
s
.38044 .80472 m .37678 .30246 L .359 .29156 L p .707 .577 .707 r
F P
0 g
s
.37678 .30246 m .38044 .80472 L .41017 .81354 L p .707 .577 .707 r
F P
0 g
s
.32404 .74455 m .31891 .78067 L .34283 .77702 L p .707 .577 .707 r
F P
0 g
s
.34283 .77702 m .34795 .7409 L .32404 .74455 L p .707 .577 .707 r
F P
0 g
s
.20529 .72673 m .20016 .76285 L .22732 .77158 L p .707 .577 .707 r
F P
0 g
s
.69928 .74035 m .69415 .77647 L .67337 .76611 L p .707 .577 .707 r
F P
0 g
s
.67337 .76611 m .6785 .72999 L .69928 .74035 L p .707 .577 .707 r
F P
0 g
s
.20016 .76285 m .20529 .72673 L .18451 .71637 L p .707 .577 .707 r
F P
0 g
s
.33781 .66102 m .33009 .7152 L .34642 .70852 L p .707 .577 .707 r
F P
0 g
s
.34642 .70852 m .35413 .65434 L .33781 .66102 L p .707 .577 .707 r
F P
0 g
s
.17438 .63643 m .16666 .6906 L .18744 .70098 L p .707 .577 .707 r
F P
0 g
s
.24922 .80789 m .24561 .78936 L .21504 .79368 L p .707 .577 .707 r
F P
0 g
s
.24561 .78936 m .24922 .80789 L .28051 .8015 L p .707 .577 .707 r
F P
0 g
s
.28051 .8015 m .27689 .78297 L .24561 .78936 L p .707 .577 .707 r
F P
0 g
s
.27689 .78297 m .28051 .8015 L .30946 .79367 L p .707 .577 .707 r
F P
0 g
s
.30946 .79367 m .30584 .77514 L .27689 .78297 L p .707 .577 .707 r
F P
0 g
s
.16666 .6906 m .17438 .63643 L .162 .62543 L p .707 .577 .707 r
F P
0 g
s
.21504 .79368 m .21865 .81221 L .24922 .80789 L p .707 .577 .707 r
F P
0 g
s
.21865 .81221 m .21504 .79368 L .18819 .79551 L p .707 .577 .707 r
F P
0 g
s
.18451 .71637 m .17938 .75249 L .20016 .76285 L p .707 .577 .707 r
F P
0 g
s
.18819 .79551 m .1918 .81404 L .21865 .81221 L p .707 .577 .707 r
F P
0 g
s
.30584 .77514 m .30946 .79367 L .33323 .78516 L p .707 .577 .707 r
F P
0 g
s
.33323 .78516 m .32962 .76663 L .30584 .77514 L p .707 .577 .707 r
F P
0 g
s
.63276 .29453 m .63643 .7968 L .64643 .78504 L p .707 .577 .707 r
F P
0 g
s
.6785 .72999 m .67337 .76611 L .64622 .75738 L p .707 .577 .707 r
F P
0 g
s
.64622 .75738 m .65135 .72126 L .6785 .72999 L p .707 .577 .707 r
F P
0 g
s
.64643 .78504 m .64276 .28278 L .63276 .29453 L p .707 .577 .707 r
F P
0 g
s
.6813 .77904 m .68492 .79757 L .66441 .79673 L p .707 .577 .707 r
F P
0 g
s
.66441 .79673 m .66079 .7782 L .6813 .77904 L p .707 .577 .707 r
F P
0 g
s
.34795 .7409 m .34283 .77702 L .35915 .77034 L p .707 .577 .707 r
F P
0 g
s
.35915 .77034 m .36428 .73422 L .34795 .7409 L p .707 .577 .707 r
F P
0 g
s
.17938 .75249 m .18451 .71637 L .17214 .70538 L p .707 .577 .707 r
F P
0 g
s
.162 .62543 m .15429 .67961 L .16666 .6906 L p .707 .577 .707 r
F P
0 g
s
.1918 .81404 m .18819 .79551 L .16768 .79466 L p .707 .577 .707 r
F P
0 g
s
.35413 .65434 m .34642 .70852 L .35355 .69946 L p .707 .577 .707 r
F P
0 g
s
.35355 .69946 m .36126 .64529 L .35413 .65434 L p .707 .577 .707 r
F P
0 g
s
.16768 .79466 m .17129 .8132 L .1918 .81404 L p .707 .577 .707 r
F P
0 g
s
.15429 .67961 m .162 .62543 L .15925 .61489 L p .707 .577 .707 r
F P
0 g
s
.32962 .76663 m .33323 .78516 L .3495 .77681 L p .707 .577 .707 r
F P
0 g
s
.3495 .77681 m .34589 .75828 L .32962 .76663 L p .707 .577 .707 r
F P
0 g
s
.17214 .70538 m .16701 .7415 L .17938 .75249 L p .707 .577 .707 r
F P
0 g
s
.36428 .73422 m .35915 .77034 L .36628 .76128 L p .707 .577 .707 r
F P
0 g
s
.36126 .64529 m .35355 .69946 L .35079 .68892 L p .707 .577 .707 r
F P
0 g
s
.35079 .68892 m .35851 .63475 L .36126 .64529 L p .707 .577 .707 r
F P
0 g
s
.36628 .76128 m .37141 .72516 L .36428 .73422 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .35115 .73976 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36865 .71463 m .36618 .73199 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36618 .73199 m .36352 .75075 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.359 .29156 m .35491 .27965 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .35627 .70364 L .36546 .71179 L p .707 .577 .707 r
F P
0 g
s
.36546 .71179 m .36865 .71463 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .36546 .71179 L .36571 .71885 L .707 .577 .707 r
F
.35858 .78192 m .36267 .79383 L p .35853 .51967 L F P
0 g
s
.35491 .27965 m .35619 .45467 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35851 .63475 m .35079 .68892 L .34296 .68197 L p .707 .577 .707 r
F P
0 g
s
.34296 .68197 m .33842 .67793 L p .34345 .6671 L .707 .577 .707 r
F P
0 g
s
.34345 .6671 m .35851 .63475 L .34296 .68197 L .707 .577 .707 r
F
.33842 .67793 m .34613 .62375 L .35851 .63475 L p F P
0 g
s
.35619 .45467 m .35858 .78192 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36267 .79383 m .36121 .59391 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36121 .59391 m .359 .29156 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.37141 .72516 m .36628 .76128 L .36352 .75075 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .36865 .71463 L .37141 .72516 L p .707 .577 .707 r
F P
0 g
s
.359 .29156 m .36267 .79383 L .38044 .80472 L p .707 .577 .707 r
F P
0 g
s
.35858 .78192 m .35515 .31159 L p .36491 .26789 L .707 .577 .707 r
F P
0 g
s
.35515 .31159 m .35491 .27965 L .35625 .27808 L p .707 .577 .707 r
F P
0 g
s
.35625 .27808 m .36491 .26789 L p .35515 .31159 L .707 .577 .707 r
F P
0 g
s
.66079 .7782 m .66441 .79673 L .63756 .79856 L p .707 .577 .707 r
F P
0 g
s
.16701 .7415 m .17214 .70538 L .16938 .69484 L p .707 .577 .707 r
F P
0 g
s
.15925 .61489 m .15153 .66907 L .15429 .67961 L p .707 .577 .707 r
F P
0 g
s
.17129 .8132 m .16768 .79466 L .15552 .79123 L p .707 .577 .707 r
F P
0 g
s
.15552 .79123 m .15914 .80977 L .17129 .8132 L p .707 .577 .707 r
F P
0 g
s
.34589 .75828 m .3495 .77681 L .35668 .76943 L p .707 .577 .707 r
F P
0 g
s
.35668 .76943 m .35307 .7509 L .34589 .75828 L p .707 .577 .707 r
F P
0 g
s
.64276 .28278 m .64643 .78504 L .64329 .77592 L p .707 .577 .707 r
F P
0 g
s
.64236 .75002 m .64276 .28278 L .64329 .77592 L .707 .577 .707 r
F
.63867 .27087 m .64276 .28278 L p .64247 .62315 L F P
0 g
s
.64234 .77313 m .64121 .61905 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.64121 .61905 m .63867 .27087 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.63867 .27087 m .64234 .77313 L .62456 .76224 L p .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63946 .55963 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.6345 .62435 m .63715 .60574 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .64222 .57017 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63715 .60574 L p .64687 .63534 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .6345 .62435 L .63793 .6274 L p .707 .577 .707 r
F P
0 g
s
.63793 .6274 m .64687 .63534 L p .63715 .60574 L .707 .577 .707 r
F P
0 g
s
.64329 .77592 m .64234 .77313 L p .64236 .75002 L .707 .577 .707 r
F P
0 g
s
.15153 .66907 m .15925 .61489 L .16638 .60584 L p .707 .577 .707 r
F P
0 g
s
.16938 .69484 m .16425 .73096 L .16701 .7415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16425 .73096 m .16938 .69484 L .17651 .68579 L p .707 .577 .707 r
F P
0 g
s
.16638 .60584 m .15866 .66001 L .15153 .66907 L p .707 .577 .707 r
F P
0 g
s
.15914 .80977 m .15552 .79123 L .1529 .78555 L p .707 .577 .707 r
F P
0 g
s
.1529 .78555 m .15652 .80408 L .15914 .80977 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35307 .7509 m .35668 .76943 L .35406 .76375 L p .707 .577 .707 r
F P
0 g
s
.35406 .76375 m .35045 .74522 L .35307 .7509 L p .707 .577 .707 r
F P
0 g
s
.15866 .66001 m .16638 .60584 L .1827 .59916 L p .707 .577 .707 r
F P
0 g
s
.17651 .68579 m .17138 .72191 L .16425 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62456 .76224 m .6209 .25997 L .63867 .27087 L p .707 .577 .707 r
F P
0 g
s
.17138 .72191 m .17651 .68579 L .19283 .67911 L p .707 .577 .707 r
F P
0 g
s
.1827 .59916 m .17498 .65333 L .15866 .66001 L p .707 .577 .707 r
F P
0 g
s
.15652 .80408 m .1529 .78555 L .16008 .77817 L p .707 .577 .707 r
F P
0 g
s
.34613 .62375 m .33842 .67793 L .31764 .66755 L p .707 .577 .707 r
F P
0 g
s
.31764 .66755 m .32535 .61338 L .34613 .62375 L p .707 .577 .707 r
F P
0 g
s
.16008 .77817 m .1637 .7967 L .15652 .80408 L p .707 .577 .707 r
F P
0 g
s
.17498 .65333 m .1827 .59916 L .20661 .59551 L p .707 .577 .707 r
F P
0 g
s
.35045 .74522 m .35406 .76375 L .34191 .76032 L p .707 .577 .707 r
F P
0 g
s
.34191 .76032 m .33829 .74178 L .35045 .74522 L p .707 .577 .707 r
F P
0 g
s
.36858 .77016 m .36491 .26789 L .38802 .25744 L p .707 .577 .707 r
F P
0 g
s
.36491 .26789 m .36858 .77016 L .35858 .78192 L p .707 .577 .707 r
F P
0 g
s
.19283 .67911 m .1877 .71523 L .17138 .72191 L p .707 .577 .707 r
F P
0 g
s
.35627 .70364 m .35115 .73976 L .33036 .7294 L p .707 .577 .707 r
F P
0 g
s
.33036 .7294 m .33549 .69328 L .35627 .70364 L p .707 .577 .707 r
F P
0 g
s
.1877 .71523 m .19283 .67911 L .21674 .67545 L p .707 .577 .707 r
F P
0 g
s
.32535 .61338 m .31764 .66755 L .29048 .65881 L p .707 .577 .707 r
F P
0 g
s
.29048 .65881 m .2982 .60463 L .32535 .61338 L p .707 .577 .707 r
F P
0 g
s
.20661 .59551 m .19889 .64968 L .17498 .65333 L p .707 .577 .707 r
F P
0 g
s
.19889 .64968 m .20661 .59551 L .23577 .59524 L p .707 .577 .707 r
F P
0 g
s
.1637 .7967 m .16008 .77817 L .17636 .76982 L p .707 .577 .707 r
F P
0 g
s
.6209 .25997 m .62456 .76224 L .59484 .75342 L p .707 .577 .707 r
F P
0 g
s
.59484 .75342 m .59117 .25115 L .6209 .25997 L p .707 .577 .707 r
F P
0 g
s
.17636 .76982 m .17997 .78835 L .1637 .7967 L p .707 .577 .707 r
F P
0 g
s
.21674 .67545 m .21162 .71157 L .1877 .71523 L p .707 .577 .707 r
F P
0 g
s
.33829 .74178 m .34191 .76032 L .3214 .75947 L p .707 .577 .707 r
F P
0 g
s
.3214 .75947 m .31778 .74094 L .33829 .74178 L p .707 .577 .707 r
F P
0 g
s
.2982 .60463 m .29048 .65881 L .25962 .65256 L p .707 .577 .707 r
F P
0 g
s
.25962 .65256 m .26733 .59839 L .2982 .60463 L p .707 .577 .707 r
F P
0 g
s
.22806 .64942 m .23577 .59524 L .26733 .59839 L p .707 .577 .707 r
F P
0 g
s
.23577 .59524 m .22806 .64942 L .19889 .64968 L p .707 .577 .707 r
F P
0 g
s
.33549 .69328 m .33036 .7294 L .30321 .72067 L p .707 .577 .707 r
F P
0 g
s
.30321 .72067 m .30834 .68455 L .33549 .69328 L p .707 .577 .707 r
F P
0 g
s
.26733 .59839 m .25962 .65256 L .22806 .64942 L p .707 .577 .707 r
F P
0 g
s
.21162 .71157 m .21674 .67545 L .24591 .67518 L p .707 .577 .707 r
F P
0 g
s
.38802 .25744 m .39169 .75971 L .36858 .77016 L p .707 .577 .707 r
F P
0 g
s
.39169 .75971 m .38802 .25744 L .42198 .24931 L p .707 .577 .707 r
F P
0 g
s
.72567 .66071 m .73339 .60653 L .70252 .60028 L p .707 .577 .707 r
F P
0 g
s
.73339 .60653 m .72567 .66071 L .75723 .66385 L p .707 .577 .707 r
F P
0 g
s
.75723 .66385 m .76495 .60968 L .73339 .60653 L p .707 .577 .707 r
F P
0 g
s
.76495 .60968 m .75723 .66385 L .7864 .66359 L p .707 .577 .707 r
F P
0 g
s
.7864 .66359 m .79411 .60941 L .76495 .60968 L p .707 .577 .707 r
F P
0 g
s
.69481 .65446 m .70252 .60028 L .67537 .59154 L p .707 .577 .707 r
F P
0 g
s
.70252 .60028 m .69481 .65446 L .72567 .66071 L p .707 .577 .707 r
F P
0 g
s
.17997 .78835 m .17636 .76982 L .20013 .76131 L p .707 .577 .707 r
F P
0 g
s
.30834 .68455 m .30321 .72067 L .27234 .71443 L p .707 .577 .707 r
F P
0 g
s
.27234 .71443 m .27747 .67831 L .30834 .68455 L p .707 .577 .707 r
F P
0 g
s
.24591 .67518 m .24078 .7113 L .21162 .71157 L p .707 .577 .707 r
F P
0 g
s
.24078 .7113 m .24591 .67518 L .27747 .67831 L p .707 .577 .707 r
F P
0 g
s
.20013 .76131 m .20374 .77984 L .17997 .78835 L p .707 .577 .707 r
F P
0 g
s
.27747 .67831 m .27234 .71443 L .24078 .7113 L p .707 .577 .707 r
F P
0 g
s
.31778 .74094 m .3214 .75947 L .29455 .7613 L p .707 .577 .707 r
F P
0 g
s
.29455 .7613 m .29093 .74277 L .31778 .74094 L p .707 .577 .707 r
F P
0 g
s
.59117 .25115 m .59484 .75342 L .55607 .74754 L p .707 .577 .707 r
F P
0 g
s
.55607 .74754 m .55241 .24527 L .59117 .25115 L p .707 .577 .707 r
F P
0 g
s
.79411 .60941 m .7864 .66359 L .81031 .65994 L p .707 .577 .707 r
F P
0 g
s
.81031 .65994 m .81802 .60576 L .79411 .60941 L p .707 .577 .707 r
F P
0 g
s
.7384 .72249 m .74353 .68637 L .71266 .68013 L p .707 .577 .707 r
F P
0 g
s
.74353 .68637 m .7384 .72249 L .76996 .72562 L p .707 .577 .707 r
F P
0 g
s
.76996 .72562 m .77509 .6895 L .74353 .68637 L p .707 .577 .707 r
F P
0 g
s
.66765 .64572 m .67537 .59154 L .65459 .58117 L p .707 .577 .707 r
F P
0 g
s
.67537 .59154 m .66765 .64572 L .69481 .65446 L p .707 .577 .707 r
F P
0 g
s
.77509 .6895 m .76996 .72562 L .79913 .72535 L p .707 .577 .707 r
F P
0 g
s
.79913 .72535 m .80425 .68923 L .77509 .6895 L p .707 .577 .707 r
F P
0 g
s
.70753 .71625 m .71266 .68013 L .68551 .6714 L p .707 .577 .707 r
F P
0 g
s
.71266 .68013 m .70753 .71625 L .7384 .72249 L p .707 .577 .707 r
F P
0 g
s
.42564 .75158 m .42198 .24931 L .46346 .24431 L p .707 .577 .707 r
F P
0 g
s
.42198 .24931 m .42564 .75158 L .39169 .75971 L p .707 .577 .707 r
F P
0 g
s
.20374 .77984 m .20013 .76131 L .22908 .75348 L p .707 .577 .707 r
F P
0 g
s
.22908 .75348 m .23269 .77201 L .20374 .77984 L p .707 .577 .707 r
F P
0 g
s
.29093 .74277 m .29455 .7613 L .26398 .76562 L p .707 .577 .707 r
F P
0 g
s
.26398 .76562 m .26037 .74709 L .29093 .74277 L p .707 .577 .707 r
F P
0 g
s
.80425 .68923 m .79913 .72535 L .82304 .72169 L p .707 .577 .707 r
F P
0 g
s
.82304 .72169 m .82817 .68557 L .80425 .68923 L p .707 .577 .707 r
F P
0 g
s
.68551 .6714 m .68038 .70752 L .70753 .71625 L p .707 .577 .707 r
F P
0 g
s
.55241 .24527 m .55607 .74754 L .51207 .74519 L p .707 .577 .707 r
F P
0 g
s
.51207 .74519 m .5084 .24292 L .55241 .24527 L p .707 .577 .707 r
F P
0 g
s
.68038 .70752 m .68551 .6714 L .66472 .66104 L p .707 .577 .707 r
F P
0 g
s
.81802 .60576 m .81031 .65994 L .82663 .65326 L p .707 .577 .707 r
F P
0 g
s
.82663 .65326 m .83434 .59908 L .81802 .60576 L p .707 .577 .707 r
F P
0 g
s
.65459 .58117 m .64687 .63534 L .66765 .64572 L p .707 .577 .707 r
F P
0 g
s
.23269 .77201 m .22908 .75348 L .26037 .74709 L p .707 .577 .707 r
F P
0 g
s
.72943 .75311 m .72582 .73458 L .69525 .7389 L p .707 .577 .707 r
F P
0 g
s
.72582 .73458 m .72943 .75311 L .76072 .74672 L p .707 .577 .707 r
F P
0 g
s
.76072 .74672 m .75711 .72819 L .72582 .73458 L p .707 .577 .707 r
F P
0 g
s
.26037 .74709 m .26398 .76562 L .23269 .77201 L p .707 .577 .707 r
F P
0 g
s
.75711 .72819 m .76072 .74672 L .78967 .73889 L p .707 .577 .707 r
F P
0 g
s
.78967 .73889 m .78606 .72036 L .75711 .72819 L p .707 .577 .707 r
F P
0 g
s
.64687 .63534 m .65459 .58117 L .64222 .57017 L p .707 .577 .707 r
F P
0 g
s
.69525 .7389 m .69887 .75743 L .72943 .75311 L p .707 .577 .707 r
F P
0 g
s
.46712 .74658 m .46346 .24431 L .5084 .24292 L p .707 .577 .707 r
F P
0 g
s
.46346 .24431 m .46712 .74658 L .42564 .75158 L p .707 .577 .707 r
F P
0 g
s
.69887 .75743 m .69525 .7389 L .6684 .74073 L p .707 .577 .707 r
F P
0 g
s
.5084 .24292 m .51207 .74519 L .46712 .74658 L p .707 .577 .707 r
F P
0 g
s
.66472 .66104 m .6596 .69716 L .68038 .70752 L p .707 .577 .707 r
F P
0 g
s
.6684 .74073 m .67202 .75926 L .69887 .75743 L p .707 .577 .707 r
F P
0 g
s
.78606 .72036 m .78967 .73889 L .81344 .73038 L p .707 .577 .707 r
F P
0 g
s
.81344 .73038 m .80983 .71185 L .78606 .72036 L p .707 .577 .707 r
F P
0 g
s
.82817 .68557 m .82304 .72169 L .83936 .71501 L p .707 .577 .707 r
F P
0 g
s
.83936 .71501 m .84449 .67889 L .82817 .68557 L p .707 .577 .707 r
F P
0 g
s
.6596 .69716 m .66472 .66104 L .65235 .65005 L p .707 .577 .707 r
F P
0 g
s
.67202 .75926 m .6684 .74073 L .64789 .73988 L p .707 .577 .707 r
F P
0 g
s
.83434 .59908 m .82663 .65326 L .83376 .6442 L p .707 .577 .707 r
F P
0 g
s
.83376 .6442 m .84148 .59003 L .83434 .59908 L p .707 .577 .707 r
F P
0 g
s
.64789 .73988 m .65151 .75841 L .67202 .75926 L p .707 .577 .707 r
F P
0 g
s
.80983 .71185 m .81344 .73038 L .82972 .72203 L p .707 .577 .707 r
F P
0 g
s
.82972 .72203 m .8261 .7035 L .80983 .71185 L p .707 .577 .707 r
F P
0 g
s
.65235 .65005 m .64722 .68617 L .6596 .69716 L p .707 .577 .707 r
F P
0 g
s
.84449 .67889 m .83936 .71501 L .84649 .70596 L p .707 .577 .707 r
F P
0 g
s
.84649 .70596 m .85162 .66984 L .84449 .67889 L p .707 .577 .707 r
F P
0 g
s
.64722 .68617 m .65235 .65005 L .64959 .63952 L p .707 .577 .707 r
F P
0 g
s
.63946 .55963 m .63174 .6138 L .6345 .62435 L p .707 .577 .707 r
F P
0 g
s
.65151 .75841 m .64789 .73988 L .63574 .73645 L p .707 .577 .707 r
F P
0 g
s
.63574 .73645 m .63935 .75498 L .65151 .75841 L p .707 .577 .707 r
F P
0 g
s
.84148 .59003 m .83376 .6442 L .831 .63366 L p .707 .577 .707 r
F P
0 g
s
.831 .63366 m .83872 .57949 L .84148 .59003 L p .707 .577 .707 r
F P
0 g
s
.8261 .7035 m .82972 .72203 L .8369 .71465 L p .707 .577 .707 r
F P
0 g
s
.8369 .71465 m .83328 .69612 L .8261 .7035 L p .707 .577 .707 r
F P
0 g
s
.63174 .6138 m .63946 .55963 L .64659 .55058 L p .707 .577 .707 r
F P
0 g
s
.64959 .63952 m .64446 .67564 L .64722 .68617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.85162 .66984 m .84649 .70596 L .84373 .69542 L p .707 .577 .707 r
F P
0 g
s
.84373 .69542 m .84886 .6593 L .85162 .66984 L p .707 .577 .707 r
F P
0 g
s
.64446 .67564 m .64959 .63952 L .65672 .63046 L p .707 .577 .707 r
F P
0 g
s
.64659 .55058 m .63888 .60475 L .63174 .6138 L p .707 .577 .707 r
F P
0 g
s
.63935 .75498 m .63574 .73645 L .63312 .73077 L p .707 .577 .707 r
F P
0 g
s
.63312 .73077 m .63673 .7493 L .63935 .75498 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83872 .57949 m .831 .63366 L .81863 .62267 L p .707 .577 .707 r
F P
0 g
s
.81863 .62267 m .82635 .56849 L .83872 .57949 L p .707 .577 .707 r
F P
0 g
s
.83328 .69612 m .8369 .71465 L .83428 .70897 L p .707 .577 .707 r
F P
0 g
s
.83428 .70897 m .83067 .69043 L .83328 .69612 L p .707 .577 .707 r
F P
0 g
s
.63888 .60475 m .64659 .55058 L .66291 .5439 L p .707 .577 .707 r
F P
0 g
s
.65672 .63046 m .65159 .66658 L .64446 .67564 L p .707 .577 .707 r
F P
0 g
s
.38266 .62393 m .39038 .56975 L .35951 .56351 L p .707 .577 .707 r
F P
0 g
s
.39038 .56975 m .38266 .62393 L .41422 .62707 L p .707 .577 .707 r
F P
0 g
s
.41422 .62707 m .42194 .5729 L .39038 .56975 L p .707 .577 .707 r
F P
0 g
s
.42194 .5729 m .41422 .62707 L .44339 .62681 L p .707 .577 .707 r
F P
0 g
s
.44339 .62681 m .4511 .57263 L .42194 .5729 L p .707 .577 .707 r
F P
0 g
s
.3518 .61768 m .35951 .56351 L .33236 .55477 L p .707 .577 .707 r
F P
0 g
s
.35951 .56351 m .3518 .61768 L .38266 .62393 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84886 .6593 m .84373 .69542 L .83136 .68443 L p .707 .577 .707 r
F P
0 g
s
.83136 .68443 m .83649 .64831 L .84886 .6593 L p .707 .577 .707 r
F P
0 g
s
.65159 .66658 m .65672 .63046 L .67304 .62378 L p .707 .577 .707 r
F P
0 g
s
.66291 .5439 m .6552 .59807 L .63888 .60475 L p .707 .577 .707 r
F P
0 g
s
.4511 .57263 m .44339 .62681 L .4673 .62316 L p .707 .577 .707 r
F P
0 g
s
.4673 .62316 m .47501 .56898 L .4511 .57263 L p .707 .577 .707 r
F P
0 g
s
.63673 .7493 m .63312 .73077 L .6403 .72339 L p .707 .577 .707 r
F P
0 g
s
.39539 .68578 m .40052 .64966 L .36965 .64342 L p .707 .577 .707 r
F P
0 g
s
.40052 .64966 m .39539 .68578 L .42695 .68891 L p .707 .577 .707 r
F P
0 g
s
.42695 .68891 m .43208 .65279 L .40052 .64966 L p .707 .577 .707 r
F P
0 g
s
.82635 .56849 m .81863 .62267 L .79785 .61229 L p .707 .577 .707 r
F P
0 g
s
.79785 .61229 m .80557 .55811 L .82635 .56849 L p .707 .577 .707 r
F P
0 g
s
.32464 .60894 m .33236 .55477 L .31158 .54439 L p .707 .577 .707 r
F P
0 g
s
.33236 .55477 m .32464 .60894 L .3518 .61768 L p .707 .577 .707 r
F P
0 g
s
.6403 .72339 m .64391 .74192 L .63673 .7493 L p .707 .577 .707 r
F P
0 g
s
.43208 .65279 m .42695 .68891 L .45612 .68864 L p .707 .577 .707 r
F P
0 g
s
.45612 .68864 m .46124 .65251 L .43208 .65279 L p .707 .577 .707 r
F P
0 g
s
.36452 .67954 m .36965 .64342 L .3425 .63469 L p .707 .577 .707 r
F P
0 g
s
.36965 .64342 m .36452 .67954 L .39539 .68578 L p .707 .577 .707 r
F P
0 g
s
.6552 .59807 m .66291 .5439 L .68682 .54025 L p .707 .577 .707 r
F P
0 g
s
.83067 .69043 m .83428 .70897 L .82212 .70553 L p .707 .577 .707 r
F P
0 g
s
.82212 .70553 m .81851 .687 L .83067 .69043 L p .707 .577 .707 r
F P
0 g
s
.67304 .62378 m .66792 .6599 L .65159 .66658 L p .707 .577 .707 r
F P
0 g
s
.46124 .65251 m .45612 .68864 L .48003 .68498 L p .707 .577 .707 r
F P
0 g
s
.48003 .68498 m .48516 .64886 L .46124 .65251 L p .707 .577 .707 r
F P
0 g
s
.3425 .63469 m .33737 .67081 L .36452 .67954 L p .707 .577 .707 r
F P
0 g
s
.83649 .64831 m .83136 .68443 L .81058 .67407 L p .707 .577 .707 r
F P
0 g
s
.81058 .67407 m .81571 .63795 L .83649 .64831 L p .707 .577 .707 r
F P
0 g
s
.33737 .67081 m .3425 .63469 L .32171 .62433 L p .707 .577 .707 r
F P
0 g
s
.47501 .56898 m .4673 .62316 L .48362 .61648 L p .707 .577 .707 r
F P
0 g
s
.48362 .61648 m .49133 .5623 L .47501 .56898 L p .707 .577 .707 r
F P
0 g
s
.31158 .54439 m .30386 .59856 L .32464 .60894 L p .707 .577 .707 r
F P
0 g
s
.38642 .71585 m .38281 .69732 L .35224 .70164 L p .707 .577 .707 r
F P
0 g
s
.38281 .69732 m .38642 .71585 L .41771 .70947 L p .707 .577 .707 r
F P
0 g
s
.41771 .70947 m .4141 .69093 L .38281 .69732 L p .707 .577 .707 r
F P
0 g
s
.4141 .69093 m .41771 .70947 L .44666 .70163 L p .707 .577 .707 r
F P
0 g
s
.44666 .70163 m .44305 .6831 L .4141 .69093 L p .707 .577 .707 r
F P
0 g
s
.66792 .6599 m .67304 .62378 L .69696 .62013 L p .707 .577 .707 r
F P
0 g
s
.80557 .55811 m .79785 .61229 L .7707 .60355 L p .707 .577 .707 r
F P
0 g
s
.7707 .60355 m .77841 .54937 L .80557 .55811 L p .707 .577 .707 r
F P
0 g
s
.68682 .54025 m .67911 .59442 L .6552 .59807 L p .707 .577 .707 r
F P
0 g
s
.30386 .59856 m .31158 .54439 L .29921 .53339 L p .707 .577 .707 r
F P
0 g
s
.35224 .70164 m .35586 .72017 L .38642 .71585 L p .707 .577 .707 r
F P
0 g
s
.67911 .59442 m .68682 .54025 L .71599 .53998 L p .707 .577 .707 r
F P
0 g
s
.35586 .72017 m .35224 .70164 L .32539 .70347 L p .707 .577 .707 r
F P
0 g
s
.64391 .74192 m .6403 .72339 L .65657 .71504 L p .707 .577 .707 r
F P
0 g
s
.32171 .62433 m .31658 .66045 L .33737 .67081 L p .707 .577 .707 r
F P
0 g
s
.32539 .70347 m .32901 .722 L .35586 .72017 L p .707 .577 .707 r
F P
0 g
s
.44305 .6831 m .44666 .70163 L .47043 .69312 L p .707 .577 .707 r
F P
0 g
s
.47043 .69312 m .46682 .67459 L .44305 .6831 L p .707 .577 .707 r
F P
0 g
s
.65657 .71504 m .66018 .73357 L .64391 .74192 L p .707 .577 .707 r
F P
0 g
s
.69696 .62013 m .69183 .65625 L .66792 .6599 L p .707 .577 .707 r
F P
0 g
s
.81851 .687 m .82212 .70553 L .80161 .70469 L p .707 .577 .707 r
F P
0 g
s
.80161 .70469 m .798 .68616 L .81851 .687 L p .707 .577 .707 r
F P
0 g
s
.48516 .64886 m .48003 .68498 L .49635 .6783 L p .707 .577 .707 r
F P
0 g
s
.49635 .6783 m .50148 .64218 L .48516 .64886 L p .707 .577 .707 r
F P
0 g
s
.77841 .54937 m .7707 .60355 L .73983 .5973 L p .707 .577 .707 r
F P
0 g
s
.73983 .5973 m .74755 .54313 L .77841 .54937 L p .707 .577 .707 r
F P
0 g
s
.70827 .59416 m .71599 .53998 L .74755 .54313 L p .707 .577 .707 r
F P
0 g
s
.71599 .53998 m .70827 .59416 L .67911 .59442 L p .707 .577 .707 r
F P
0 g
s
.81571 .63795 m .81058 .67407 L .78342 .66534 L p .707 .577 .707 r
F P
0 g
s
.78342 .66534 m .78855 .62922 L .81571 .63795 L p .707 .577 .707 r
F P
0 g
s
.31658 .66045 m .32171 .62433 L .30934 .61334 L p .707 .577 .707 r
F P
0 g
s
.29921 .53339 m .29149 .58757 L .30386 .59856 L p .707 .577 .707 r
F P
0 g
s
.74755 .54313 m .73983 .5973 L .70827 .59416 L p .707 .577 .707 r
F P
0 g
s
.69183 .65625 m .69696 .62013 L .72612 .61985 L p .707 .577 .707 r
F P
0 g
s
.32901 .722 m .32539 .70347 L .30488 .70263 L p .707 .577 .707 r
F P
0 g
s
.49133 .5623 m .48362 .61648 L .49075 .60743 L p .707 .577 .707 r
F P
0 g
s
.49075 .60743 m .49847 .55325 L .49133 .5623 L p .707 .577 .707 r
F P
0 g
s
.30488 .70263 m .3085 .72116 L .32901 .722 L p .707 .577 .707 r
F P
0 g
s
.29149 .58757 m .29921 .53339 L .29645 .52285 L p .707 .577 .707 r
F P
0 g
s
.46682 .67459 m .47043 .69312 L .48671 .68477 L p .707 .577 .707 r
F P
0 g
s
.48671 .68477 m .48309 .66624 L .46682 .67459 L p .707 .577 .707 r
F P
0 g
s
.30934 .61334 m .30421 .64946 L .31658 .66045 L p .707 .577 .707 r
F P
0 g
s
.66018 .73357 m .65657 .71504 L .68034 .70653 L p .707 .577 .707 r
F P
0 g
s
.78855 .62922 m .78342 .66534 L .75256 .65911 L p .707 .577 .707 r
F P
0 g
s
.75256 .65911 m .75768 .62299 L .78855 .62922 L p .707 .577 .707 r
F P
0 g
s
.72612 .61985 m .72099 .65597 L .69183 .65625 L p .707 .577 .707 r
F P
0 g
s
.72099 .65597 m .72612 .61985 L .75768 .62299 L p .707 .577 .707 r
F P
0 g
s
.68034 .70653 m .68396 .72506 L .66018 .73357 L p .707 .577 .707 r
F P
0 g
s
.75768 .62299 m .75256 .65911 L .72099 .65597 L p .707 .577 .707 r
F P
0 g
s
.798 .68616 m .80161 .70469 L .77476 .70652 L p .707 .577 .707 r
F P
0 g
s
.77476 .70652 m .77115 .68799 L .798 .68616 L p .707 .577 .707 r
F P
0 g
s
.50148 .64218 m .49635 .6783 L .50348 .66925 L p .707 .577 .707 r
F P
0 g
s
.50348 .66925 m .50861 .63313 L .50148 .64218 L p .707 .577 .707 r
F P
0 g
s
.30421 .64946 m .30934 .61334 L .30658 .6028 L p .707 .577 .707 r
F P
0 g
s
.29645 .52285 m .28873 .57703 L .29149 .58757 L p .707 .577 .707 r
F P
0 g
s
.3085 .72116 m .30488 .70263 L .29273 .6992 L p .707 .577 .707 r
F P
0 g
s
.29273 .6992 m .29634 .71773 L .3085 .72116 L p .707 .577 .707 r
F P
0 g
s
.68396 .72506 m .68034 .70653 L .70929 .6987 L p .707 .577 .707 r
F P
0 g
s
.49847 .55325 m .49075 .60743 L .48799 .59688 L p .707 .577 .707 r
F P
0 g
s
.48799 .59688 m .49571 .54271 L .49847 .55325 L p .707 .577 .707 r
F P
0 g
s
.48309 .66624 m .48671 .68477 L .49389 .67739 L p .707 .577 .707 r
F P
0 g
s
.49389 .67739 m .49027 .65886 L .48309 .66624 L p .707 .577 .707 r
F P
0 g
s
.70929 .6987 m .71291 .71723 L .68396 .72506 L p .707 .577 .707 r
F P
0 g
s
.77115 .68799 m .77476 .70652 L .74419 .71084 L p .707 .577 .707 r
F P
0 g
s
.74419 .71084 m .74058 .69231 L .77115 .68799 L p .707 .577 .707 r
F P
0 g
s
.28873 .57703 m .29645 .52285 L .30358 .5138 L p .707 .577 .707 r
F P
0 g
s
.30658 .6028 m .30145 .63893 L .30421 .64946 L p .707 .577 .707 r
F P
0 g
s
.71291 .71723 m .70929 .6987 L .74058 .69231 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74058 .69231 m .74419 .71084 L .71291 .71723 L p .707 .577 .707 r
F P
0 g
s
.50861 .63313 m .50348 .66925 L .50072 .65871 L p .707 .577 .707 r
F P
0 g
s
.50072 .65871 m .50585 .62259 L .50861 .63313 L p .707 .577 .707 r
F P
0 g
s
.30145 .63893 m .30658 .6028 L .31371 .59375 L p .707 .577 .707 r
F P
0 g
s
.30358 .5138 m .29586 .56797 L .28873 .57703 L p .707 .577 .707 r
F P
0 g
s
.29634 .71773 m .29273 .6992 L .29011 .69351 L p .707 .577 .707 r
F P
0 g
s
.29011 .69351 m .29372 .71204 L .29634 .71773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49571 .54271 m .48799 .59688 L .47562 .58589 L p .707 .577 .707 r
F P
0 g
s
.47562 .58589 m .48334 .53171 L .49571 .54271 L p .707 .577 .707 r
F P
0 g
s
.49027 .65886 m .49389 .67739 L .49127 .67171 L p .707 .577 .707 r
F P
0 g
s
.49127 .67171 m .48765 .65318 L .49027 .65886 L p .707 .577 .707 r
F P
0 g
s
.29586 .56797 m .30358 .5138 L .3199 .50712 L p .707 .577 .707 r
F P
0 g
s
.31371 .59375 m .30858 .62987 L .30145 .63893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50585 .62259 m .50072 .65871 L .48835 .64772 L p .707 .577 .707 r
F P
0 g
s
.48835 .64772 m .49348 .6116 L .50585 .62259 L p .707 .577 .707 r
F P
0 g
s
.30858 .62987 m .31371 .59375 L .33003 .58707 L p .707 .577 .707 r
F P
0 g
s
.3199 .50712 m .31219 .56129 L .29586 .56797 L p .707 .577 .707 r
F P
0 g
s
.29372 .71204 m .29011 .69351 L .29729 .68613 L p .707 .577 .707 r
F P
0 g
s
.48334 .53171 m .47562 .58589 L .45484 .57551 L p .707 .577 .707 r
F P
0 g
s
.45484 .57551 m .46256 .52134 L .48334 .53171 L p .707 .577 .707 r
F P
0 g
s
.29729 .68613 m .3009 .70467 L .29372 .71204 L p .707 .577 .707 r
F P
0 g
s
.31219 .56129 m .3199 .50712 L .34381 .50347 L p .707 .577 .707 r
F P
0 g
s
.48765 .65318 m .49127 .67171 L .47911 .66828 L p .707 .577 .707 r
F P
0 g
s
.47911 .66828 m .4755 .64975 L .48765 .65318 L p .707 .577 .707 r
F P
0 g
s
.33003 .58707 m .32491 .62319 L .30858 .62987 L p .707 .577 .707 r
F P
0 g
s
.49348 .6116 m .48835 .64772 L .46757 .63736 L p .707 .577 .707 r
F P
0 g
s
.46757 .63736 m .4727 .60124 L .49348 .6116 L p .707 .577 .707 r
F P
0 g
s
.32491 .62319 m .33003 .58707 L .35395 .58342 L p .707 .577 .707 r
F P
0 g
s
.46256 .52134 m .45484 .57551 L .42769 .56677 L p .707 .577 .707 r
F P
0 g
s
.42769 .56677 m .4354 .5126 L .46256 .52134 L p .707 .577 .707 r
F P
0 g
s
.34381 .50347 m .3361 .55764 L .31219 .56129 L p .707 .577 .707 r
F P
0 g
s
.3361 .55764 m .34381 .50347 L .37298 .5032 L p .707 .577 .707 r
F P
0 g
s
.3009 .70467 m .29729 .68613 L .31356 .67778 L p .707 .577 .707 r
F P
0 g
s
.31356 .67778 m .31717 .69631 L .3009 .70467 L p .707 .577 .707 r
F P
0 g
s
.35395 .58342 m .34882 .61954 L .32491 .62319 L p .707 .577 .707 r
F P
0 g
s
.4755 .64975 m .47911 .66828 L .4586 .66744 L p .707 .577 .707 r
F P
0 g
s
.4586 .66744 m .45499 .6489 L .4755 .64975 L p .707 .577 .707 r
F P
0 g
s
.4354 .5126 m .42769 .56677 L .39682 .56052 L p .707 .577 .707 r
F P
0 g
s
.39682 .56052 m .40454 .50635 L .4354 .5126 L p .707 .577 .707 r
F P
0 g
s
.36526 .55738 m .37298 .5032 L .40454 .50635 L p .707 .577 .707 r
F P
0 g
s
.37298 .5032 m .36526 .55738 L .3361 .55764 L p .707 .577 .707 r
F P
0 g
s
.4727 .60124 m .46757 .63736 L .44041 .62863 L p .707 .577 .707 r
F P
0 g
s
.44041 .62863 m .44554 .59251 L .4727 .60124 L p .707 .577 .707 r
F P
0 g
s
.40454 .50635 m .39682 .56052 L .36526 .55738 L p .707 .577 .707 r
F P
0 g
s
.34882 .61954 m .35395 .58342 L .38311 .58314 L p .707 .577 .707 r
F P
0 g
s
.31717 .69631 m .31356 .67778 L .33733 .66927 L p .707 .577 .707 r
F P
0 g
s
.44554 .59251 m .44041 .62863 L .40954 .62239 L p .707 .577 .707 r
F P
0 g
s
.40954 .62239 m .41467 .58627 L .44554 .59251 L p .707 .577 .707 r
F P
0 g
s
.38311 .58314 m .37798 .61926 L .34882 .61954 L p .707 .577 .707 r
F P
0 g
s
.37798 .61926 m .38311 .58314 L .41467 .58627 L p .707 .577 .707 r
F P
0 g
s
.33733 .66927 m .34095 .6878 L .31717 .69631 L p .707 .577 .707 r
F P
0 g
s
.41467 .58627 m .40954 .62239 L .37798 .61926 L p .707 .577 .707 r
F P
0 g
s
.45499 .6489 m .4586 .66744 L .43175 .66926 L p .707 .577 .707 r
F P
0 g
s
.43175 .66926 m .42814 .65073 L .45499 .6489 L p .707 .577 .707 r
F P
0 g
s
.34095 .6878 m .33733 .66927 L .36628 .66144 L p .707 .577 .707 r
F P
0 g
s
.36628 .66144 m .3699 .67997 L .34095 .6878 L p .707 .577 .707 r
F P
0 g
s
.42814 .65073 m .43175 .66926 L .40118 .67358 L p .707 .577 .707 r
F P
0 g
s
.40118 .67358 m .39757 .65505 L .42814 .65073 L p .707 .577 .707 r
F P
0 g
s
.3699 .67997 m .36628 .66144 L .39757 .65505 L p .707 .577 .707 r
F P
0 g
s
.39757 .65505 m .40118 .67358 L .3699 .67997 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8P00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001YOol2
0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00GWoo4@002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001JOol4
0003FUH00`00FUIJEP06FUH01000FUIJEUYF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001HOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60007FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001VOol005Ioo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
IWoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool@
001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool50003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70016Ool005=oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo0000
05YF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@Woo001COol00`00FUH0
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF1000?Woo001COol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00
>Woo001COol20003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH2000hOol005=oo`8000=JEP@0009JEP04001JEUYFFUH40002FUH01000
FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo
00@005YF001JEP8000IJEP03001JEUYF00AJEP@000EJEPT0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008003Aoo`00DWoo00H005YF000005YF0005FUH00`00FUIJEP06
FUH00`00FUH000030002FUH50004FUH40006FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00<Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUHC0002FUH0
0`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P00<Goo001BOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF0P00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01000FUH00000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00@005YFFUIJEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJ
EQ0000IJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH20004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DWoo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000MJEP03001JEUYF00AJEP80009JEP03001JEP0000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0UYF0P00;Goo001BOol01@00FUIJEUYF000015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH015YF00L005YF001JEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
009JEP8002eoo`00Dgoo00@005YFFUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF0000;Goo000gOolA000<Ool300000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP03FUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF200027oo
1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool003=oo`@000=J
EP03001JEUYF00IJEP03001JEUYF009JEPP000Ioo`04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF1P0000=JEP00FUH0
15YF1@001Woo2@000UYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUIJEP00FUH^Ool0035o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH600000goo00000004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0`00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH010000Woo1@0017oo10001EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH^Ool002moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000EJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Qoo`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002io
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH400000eYF
0000000:00000eYF001JEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20005FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH@0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00UYF0P00;goo000]
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP020003FUH500000eYF00000002Ool01@00FUIJEP00FUH03`0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000eYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH015YF0P000eYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEPD000AJEP800005Ool005YFFUH00006
FUH@0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P001EYF00<005YF00000UYF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000eYF00<005YFFUH01000;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000EJEPD000EJEP03001JEUYF00IJEP800003FUH005YF00EJEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH00UYF0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
000300000eYF001JEP04FUH50005FUH00`00FUIJEP08FUH20006FUH01000FUIJEUYF0`0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF0P00<7oo
000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH30006FUH00`00FUIJ
EP09FUH30003FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP<00003FUH00000031oo`00;7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000@000QJEP03001JEUYF00UJEP03001JEUYF0080
0003FUH005YF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03000`Ool002aoo`8000=JEP04001JEUYFFUH@0004FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1`000UYF00<005YFFUH00eYF3@000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000eYF10000UYF00@0
05YFFUIJEP<000Moo`L000IJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP000080009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP8002ioo`00:goo00@005YF001JEP8000IJEP03001JEUYF00AJEP<000Ioo`T0009JEP03001JEUYF
00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0400000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF00@005YF000002aoo`00:goo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUH0
00030002Ool50004Ool40005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP0200001UYF00000000FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP@00003
FUH0000000Ioo`h000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qoo`@0009JEP8000=J
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EP00001JEP0300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP040004FUH2000>Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000:goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF0000000=00001EYF000005YF00000UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P000eYF00X005YFFUH005YF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800005FUH00000FUH00002FUH20002FUH01000FUH000002Woo0`0027oo
10001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:Woo000[Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
10001UYF00<005YFFUH01eYF00<005YFFUH00UYF20000eYF00<005YFFUH01@0000QJEP00000005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH0
0UYF0`000eYF00<007ooOol01Woo1@002goo10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000ZOol002]oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00AJEPL0
009JEP03001JEUYF00IJEP@000=JEPH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP06001JEP00001JEP0027oo1@003goo0`00
1EYF00L005YFFUIJEP00FUH0000ZOol002]oo`05001JEUYFFUH00006FUH01000FUIJEUYF5`0025YF
0P0015YF00<005YFFUH01eYF00<005YFFUH01@0025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP04001JEUYFFUH30007Ool5000BOol20003FUH01`00FUIJEUYF001J
EP0002Yoo`00:goo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@0009JEP<000IJEP03001JEUYF00AJEPD000=JEP<000MJEP03001JEUYF00=JEP8000=J
EP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP@000Aoo`<001Eoo`800003FUH005YF
009JEP8002]oo`00;7oo00@005YFFUH000AJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEP80009JEP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00T000IJEP03001J
EUYF00<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00@001Uoo`<000=JEP8002]oo`00;Goo0`000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF1P000UYF00<005YF
FUH00eYF3P0000=JEP00FUH01UYF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH015YF6@0000QJEP00FUH005YF001JEP00:goo000_Ool01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@005YFFUIJEP8000=JEP<0
009JEP03001JEUYF00=JEPX000EJEP03001JEUYF00EJEP<000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00=JEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000800005FUH00000
FUH0000[Ool0031oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP07001JEUYFFUH005YF00001EYF00<005YF00000`000eYF0`000UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUH0
000[Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF0003FUH30003FUH400000eYF00000002FUH70006FUH00`00FUIJEP06FUH00`00
FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF0P00;7oo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00P001UYF00<005YF00001`00
0eYF00<005YFFUH01eYF00<005YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00@0
0003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P00;7oo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P000UYF1P001EYF00<005YFFUH01eYF00<005YFFUH015YF4@000UYF
00@005YF000002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF1@002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH0100000=JEP00FUH01UYF00<005YFFUH00UYF2000;Goo000_Ool00`00FUH00003FUH01000
FUIJEUYF400015YF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00IJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00EJEP03001JEP000080009JEP03001JEUYF00<002eo
o`00;goo0P000eYF1@002Woo3`0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEPH0009J
EP<000MJEP03001JEUYF00=JEP@00003FUH005YF00=JEP04001JEP00000^Ool002moo`03FUH005YF
00D001=oo``00003FUH005YF00AJEP03001JEUYF009JEPP000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF00IJEP03001JEUYF009JEP80009oo`@00003FUH0000000<000EJEP04001J
EUYFFUH30005FUH00`00FUIJEP02FUH2000`Ool002ioo`04001JEP000002FUH00`00FUIJEP02000?
Ool3000;Ool<0002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF00<005YF00000P0027oo1`0015YF00H005YF000005YF0007FUH01@00FUIJEUYF
0000<Goo000^Ool20004FUH00`00FUIJEP02FUH3000;Ool5000>Ool200000eYF001JEP05FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH60009Ool5
00000goo000000040003FUH00`00FUIJEP05FUH01000FUH00000<Woo000^Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUH000002Goo1@0047oo0P001UYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`000eYF0P002goo20001UYF00<0
05YFFUH015YF0`00=7oo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Woo
1@004Woo0P000eYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH00UYF0P000eYF0`0000=JEP0000001Woo1`0015YF00<005YFFUH01UYF00@005YFFUIJ
EP8003Moo`00;goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEPD0009oo`<001Eoo`800004FUH0
05YF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUH000001EYF00<0
05YFFUH00`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Uoo`00;goo
00D005YFFUIJEP0000EJEP03001JEUYF00IJEP04001JEUYFFUH90008Ool=00001EYF001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000eYF4@001UYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>goo000`Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF00<005YF00000`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUH005YF
001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?Woo
000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEP`0
0003FUH005YF00YJEPT000QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0049oo`00<goo00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000Agoo000dOol20002FUH00`00FUIJEP04FUH50006
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP040006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF1`00Bgoo000fOol30002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUHE
001AOol003Moo`@000IJEP03001JEUYF00MJEP03001JEUYF009JEPP000=JEP03001JEUYF00D00003
FUH00000009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001oo`0000<0009JEP03001JEUYF00=J
EP07001JEUYFFUH005YF0000DGoo000dOol300000eYF001JEP08FUH00`00FUIJEP04FUH70002FUH0
0`00FUIJEP06FUH40003FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP03001o
ogoo00=oo`<000EJEP07001JEUYFFUH005YF0000DGoo000bOol20004FUH00`00FUIJEP07FUH00`00
FUIJEP050008FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH00002FUH00`00FUH00002
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001oo`07Ool20003FUH01`00FUIJEUYF001JEP00055oo`00
<7oo0`001UYF00<005YFFUH015YF1@000eYF0`001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF0`000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000Yoo`800003FUH0
05YF009JEP80059oo`00;Woo0P000UYF00<005YFFUH015YF00<005YFFUH010000goo2@001UYF00<0
05YFFUH00`001EYF00<005YFFUH00eYF00D007oo001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP00000<Ool20003FUH2001BOol002eoo`03001JEUYF009JEP03001JEUYF00AJEP<0
00]oo`L000=JEP@00003FUH005YF00IJEP03001JEUYF0080009oo`<000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0001000004FUH005YF001BOol002aoo`8000EJEP04001JEUYFFUH2000>
Ool:0005FUH00`00FUIJEP05FUH30004Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YF00000P0000EJEP00001JEP00059oo`00:goo
00<005YF00001EYF00@005YF0000015oo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000Mo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YF0000DWoo000[Ool01000FUIJEP000eYF0`003Goo1P001UYF00<005YF
FUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP8005=oo`00:goo00D005YFFUH005YF008000Qoo`P0
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000ioo`03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P00Dgoo000/Ool01000FUH0
00000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010004Woo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000eYF2`000UYF00@005YF000005=oo`00;7oo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0067oo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEPL000=JEP03001JEUYF009JEPP005Aoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010007goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEUYF00<005Aoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P009Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00@005YF000005Eoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH00UYF2000;Goo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF10001UYF
00<005YFFUH015YF0P000eYF00<005YFFUH00UYF0P00Egoo000_Ool<000hOol70005FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH=0004FUH01000FUIJEUYF0`001UYF00D005YFFUIJ
EP0005Qoo`00NWoo30001UYF00<005YFFUH02EYF00@005YFFUIJEPH000Moo`D00003Ool0000000H0
0003FUH005YF00IJEP04001JEP00001IOol008IooaH000eoo`X000EJEP03001JEUYF00AJEP<005]o
o`00S7oo00@005YFFUH000AJEP8001Aoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH2001NOol0
08aoo`05001JEUYFFUH00002FUH00`00Oomoo`0=Ool70006FUH00`00FUIJEP06FUH01000FUH00000
H7oo002<Ool01000FUIJEUYF4`0015YF00<005YFFUH01eYF00<005YFFUH015YF0`00HWoo002=Ool0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
001UOol008eoo`<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJ
EPD006Uoo`00SGoo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01000KWoo002>Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001b
Ool0091oo`D000=JEP04001JEUYFFUH8001iOol009Eoo`L0085oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58347 .7544 m .59588 .70166 L .56551 .6928 L p .707 .577 .707 r
F P
0 g
s
.59588 .70166 m .58347 .7544 L .61458 .7599 L p .707 .577 .707 r
F P
0 g
s
.61458 .7599 m .627 .70717 L .59588 .70166 L p .707 .577 .707 r
F P
0 g
s
.55309 .74554 m .56551 .6928 L .53885 .68144 L p .707 .577 .707 r
F P
0 g
s
.56551 .6928 m .55309 .74554 L .58347 .7544 L p .707 .577 .707 r
F P
0 g
s
.627 .70717 m .61458 .7599 L .64339 .76151 L p .707 .577 .707 r
F P
0 g
s
.64339 .76151 m .65581 .70877 L .627 .70717 L p .707 .577 .707 r
F P
0 g
s
.60405 .81715 m .6123 .78198 L .58192 .77314 L p .707 .577 .707 r
F P
0 g
s
.6123 .78198 m .60405 .81715 L .63517 .82264 L p .707 .577 .707 r
F P
0 g
s
.63517 .82264 m .64342 .78747 L .6123 .78198 L p .707 .577 .707 r
F P
0 g
s
.52643 .73418 m .53885 .68144 L .51851 .66871 L p .707 .577 .707 r
F P
0 g
s
.53885 .68144 m .52643 .73418 L .55309 .74554 L p .707 .577 .707 r
F P
0 g
s
.65581 .70877 m .64339 .76151 L .66708 .75906 L p .707 .577 .707 r
F P
0 g
s
.66708 .75906 m .67949 .70632 L .65581 .70877 L p .707 .577 .707 r
F P
0 g
s
.57367 .80831 m .58192 .77314 L .55526 .76181 L p .707 .577 .707 r
F P
0 g
s
.58192 .77314 m .57367 .80831 L .60405 .81715 L p .707 .577 .707 r
F P
0 g
s
.64342 .78747 m .63517 .82264 L .66398 .82423 L p .707 .577 .707 r
F P
0 g
s
.66398 .82423 m .67223 .78906 L .64342 .78747 L p .707 .577 .707 r
F P
0 g
s
.55526 .76181 m .547 .79697 L .57367 .80831 L p .707 .577 .707 r
F P
0 g
s
.547 .79697 m .55526 .76181 L .53492 .74909 L p .707 .577 .707 r
F P
0 g
s
.67223 .78906 m .66398 .82423 L .68767 .82177 L p .707 .577 .707 r
F P
0 g
s
.68767 .82177 m .69592 .7866 L .67223 .78906 L p .707 .577 .707 r
F P
0 g
s
.51851 .66871 m .5061 .72145 L .52643 .73418 L p .707 .577 .707 r
F P
0 g
s
.58919 .84096 m .58341 .82281 L .55381 .83092 L p .707 .577 .707 r
F P
0 g
s
.58341 .82281 m .58919 .84096 L .6196 .83114 L p .707 .577 .707 r
F P
0 g
s
.6196 .83114 m .61382 .81299 L .58341 .82281 L p .707 .577 .707 r
F P
0 g
s
.5061 .72145 m .51851 .66871 L .50649 .65584 L p .707 .577 .707 r
F P
0 g
s
.61382 .81299 m .6196 .83114 L .64785 .82059 L p .707 .577 .707 r
F P
0 g
s
.64785 .82059 m .64207 .80244 L .61382 .81299 L p .707 .577 .707 r
F P
0 g
s
.67949 .70632 m .66708 .75906 L .68332 .75279 L p .707 .577 .707 r
F P
0 g
s
.68332 .75279 m .69574 .70006 L .67949 .70632 L p .707 .577 .707 r
F P
0 g
s
.55381 .83092 m .5596 .84907 L .58919 .84096 L p .707 .577 .707 r
F P
0 g
s
.53492 .74909 m .52666 .78425 L .547 .79697 L p .707 .577 .707 r
F P
0 g
s
.5596 .84907 m .55381 .83092 L .52794 .83655 L p .707 .577 .707 r
F P
0 g
s
.64207 .80244 m .64785 .82059 L .67118 .81034 L p .707 .577 .707 r
F P
0 g
s
.67118 .81034 m .6654 .79219 L .64207 .80244 L p .707 .577 .707 r
F P
0 g
s
.52794 .83655 m .53372 .8547 L .5596 .84907 L p .707 .577 .707 r
F P
0 g
s
.52666 .78425 m .53492 .74909 L .52289 .73623 L p .707 .577 .707 r
F P
0 g
s
.69592 .7866 m .68767 .82177 L .70391 .8155 L p .707 .577 .707 r
F P
0 g
s
.70391 .8155 m .71217 .78033 L .69592 .7866 L p .707 .577 .707 r
F P
0 g
s
.50649 .65584 m .49407 .70858 L .5061 .72145 L p .707 .577 .707 r
F P
0 g
s
.53372 .8547 m .52794 .83655 L .5083 .83913 L p .707 .577 .707 r
F P
0 g
s
.49407 .70858 m .50649 .65584 L .50396 .6441 L p .707 .577 .707 r
F P
0 g
s
.69574 .70006 m .68332 .75279 L .69053 .74333 L p .707 .577 .707 r
F P
0 g
s
.69053 .74333 m .70295 .69059 L .69574 .70006 L p .707 .577 .707 r
F P
0 g
s
.52289 .73623 m .51464 .7714 L .52666 .78425 L p .707 .577 .707 r
F P
0 g
s
.5083 .83913 m .51409 .85728 L .53372 .8547 L p .707 .577 .707 r
F P
0 g
s
.6654 .79219 m .67118 .81034 L .6873 .80139 L p .707 .577 .707 r
F P
0 g
s
.6873 .80139 m .68152 .78324 L .6654 .79219 L p .707 .577 .707 r
F P
0 g
s
.51464 .7714 m .52289 .73623 L .52036 .7245 L p .707 .577 .707 r
F P
0 g
s
.71217 .78033 m .70391 .8155 L .71112 .80604 L p .707 .577 .707 r
F P
0 g
s
.71112 .80604 m .71938 .77087 L .71217 .78033 L p .707 .577 .707 r
F P
0 g
s
.50396 .6441 m .49155 .69683 L .49407 .70858 L p .707 .577 .707 r
F P
0 g
s
.51409 .85728 m .5083 .83913 L .49684 .83842 L p .707 .577 .707 r
F P
0 g
s
.49684 .83842 m .50262 .85657 L .51409 .85728 L p .707 .577 .707 r
F P
0 g
s
.52036 .7245 m .51211 .75967 L .51464 .7714 L p .707 .577 .707 r
F P
0 g
s
.49155 .69683 m .50396 .6441 L .51117 .63463 L p .707 .577 .707 r
F P
0 g
s
.68152 .78324 m .6873 .80139 L .69463 .79461 L p .707 .577 .707 r
F P
0 g
s
.69463 .79461 m .68885 .77646 L .68152 .78324 L p .707 .577 .707 r
F P
0 g
s
.70295 .69059 m .69053 .74333 L .688 .73158 L p .707 .577 .707 r
F P
0 g
s
.688 .73158 m .70042 .67885 L .70295 .69059 L p .707 .577 .707 r
F P
0 g
s
.51117 .63463 m .49875 .68737 L .49155 .69683 L p .707 .577 .707 r
F P
0 g
s
.49448 .82173 m .48855 .31924 L .44455 .31708 L p .707 .577 .707 r
F P
0 g
s
.51211 .75967 m .52036 .7245 L .52757 .71504 L p .707 .577 .707 r
F P
0 g
s
.52757 .71504 m .51932 .7502 L .51211 .75967 L p .707 .577 .707 r
F P
0 g
s
.49875 .68737 m .51117 .63463 L .52741 .62836 L p .707 .577 .707 r
F P
0 g
s
.51932 .7502 m .52757 .71504 L .54381 .70877 L p .707 .577 .707 r
F P
0 g
s
.52741 .62836 m .515 .6811 L .49875 .68737 L p .707 .577 .707 r
F P
0 g
s
.515 .6811 m .52741 .62836 L .5511 .62592 L p .707 .577 .707 r
F P
0 g
s
.54381 .70877 m .53556 .74393 L .51932 .7502 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .53868 .67865 L .515 .6811 L p .707 .577 .707 r
F P
0 g
s
.50779 .84585 m .502 .8277 L .51812 .81875 L p .707 .577 .707 r
F P
0 g
s
.51812 .81875 m .52391 .8369 L .50779 .84585 L p .707 .577 .707 r
F P
0 g
s
.52391 .8369 m .51812 .81875 L .54145 .8085 L p .707 .577 .707 r
F P
0 g
s
.54145 .8085 m .54723 .82665 L .52391 .8369 L p .707 .577 .707 r
F P
0 g
s
.48855 .31924 m .49448 .82173 L .53943 .82015 L p .707 .577 .707 r
F P
0 g
s
.53556 .74393 m .54381 .70877 L .5675 .70631 L p .707 .577 .707 r
F P
0 g
s
.5675 .70631 m .55925 .74148 L .53556 .74393 L p .707 .577 .707 r
F P
0 g
s
.53943 .82015 m .53349 .31767 L .48855 .31924 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .57991 .62752 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.53868 .67865 m .5452 .65097 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.5452 .65097 m .5511 .62592 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.62971 .78001 m .63549 .79816 L .6059 .80628 L p .707 .577 .707 r
F P
0 g
s
.6059 .80628 m .60011 .78813 L .62971 .78001 L p .707 .577 .707 r
F P
0 g
s
.60011 .78813 m .6059 .80628 L .57548 .8161 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .61486 .80679 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.56749 .68026 m .57991 .62752 L .61102 .63303 L p .707 .577 .707 r
F P
0 g
s
.57991 .62752 m .56749 .68026 L .53868 .67865 L p .707 .577 .707 r
F P
0 g
s
.6414 .64189 m .62898 .69463 L .59861 .68576 L p .707 .577 .707 r
F P
0 g
s
.59861 .68576 m .61102 .63303 L .6414 .64189 L p .707 .577 .707 r
F P
0 g
s
.55925 .74148 m .5675 .70631 L .59632 .7079 L p .707 .577 .707 r
F P
0 g
s
.61102 .63303 m .59861 .68576 L .56749 .68026 L p .707 .577 .707 r
F P
0 g
s
.59632 .7079 m .58806 .74307 L .55925 .74148 L p .707 .577 .707 r
F P
0 g
s
.58806 .74307 m .59632 .7079 L .62744 .71339 L p .707 .577 .707 r
F P
0 g
s
.62744 .71339 m .61918 .74855 L .58806 .74307 L p .707 .577 .707 r
F P
0 g
s
.57497 .31252 m .57981 .72266 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.57548 .8161 m .5697 .79795 L .60011 .78813 L p .707 .577 .707 r
F P
0 g
s
.57981 .72266 m .5809 .81501 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.54723 .82665 m .54145 .8085 L .5697 .79795 L p .707 .577 .707 r
F P
0 g
s
.5697 .79795 m .57548 .8161 L .54723 .82665 L p .707 .577 .707 r
F P
0 g
s
.53349 .31767 m .53943 .82015 L .5809 .81501 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .57497 .31252 L .53349 .31767 L p .707 .577 .707 r
F P
0 g
s
.45048 .81957 m .44455 .31708 L .40579 .31141 L p .707 .577 .707 r
F P
0 g
s
.44455 .31708 m .45048 .81957 L .49448 .82173 L p .707 .577 .707 r
F P
0 g
s
.71938 .77087 m .71112 .80604 L .70859 .7943 L p .707 .577 .707 r
F P
0 g
s
.70859 .7943 m .71684 .75914 L .71938 .77087 L p .707 .577 .707 r
F P
0 g
s
.61486 .80679 m .60893 .3043 L .57497 .31252 L p .707 .577 .707 r
F P
0 g
s
.50262 .85657 m .49684 .83842 L .49467 .83448 L p .707 .577 .707 r
F P
0 g
s
.49467 .83448 m .50045 .85263 L .50262 .85657 L p .707 .577 .707 r
F P
0 g
s
.70042 .67885 m .688 .73158 L .67598 .71872 L p .707 .577 .707 r
F P
0 g
s
.67598 .71872 m .68839 .66598 L .70042 .67885 L p .707 .577 .707 r
F P
0 g
s
.68885 .77646 m .69463 .79461 L .69246 .79067 L p .707 .577 .707 r
F P
0 g
s
.69246 .79067 m .68668 .77252 L .68885 .77646 L p .707 .577 .707 r
F P
0 g
s
.41172 .8139 m .40579 .31141 L .37606 .30277 L p .707 .577 .707 r
F P
0 g
s
.40579 .31141 m .41172 .8139 L .45048 .81957 L p .707 .577 .707 r
F P
0 g
s
.24046 .71764 m .25287 .66491 L .2225 .65604 L p .707 .577 .707 r
F P
0 g
s
.25287 .66491 m .24046 .71764 L .27157 .72315 L p .707 .577 .707 r
F P
0 g
s
.27157 .72315 m .28399 .67041 L .25287 .66491 L p .707 .577 .707 r
F P
0 g
s
.21008 .70878 m .2225 .65604 L .19584 .64469 L p .707 .577 .707 r
F P
0 g
s
.2225 .65604 m .21008 .70878 L .24046 .71764 L p .707 .577 .707 r
F P
0 g
s
.28399 .67041 m .27157 .72315 L .30038 .72475 L p .707 .577 .707 r
F P
0 g
s
.30038 .72475 m .3128 .67202 L .28399 .67041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71684 .75914 m .70859 .7943 L .69657 .78145 L p .707 .577 .707 r
F P
0 g
s
.69657 .78145 m .70482 .74628 L .71684 .75914 L p .707 .577 .707 r
F P
0 g
s
.26104 .7805 m .26929 .74534 L .23891 .73649 L p .707 .577 .707 r
F P
0 g
s
.26929 .74534 m .26104 .7805 L .29216 .78599 L p .707 .577 .707 r
F P
0 g
s
.29216 .78599 m .30041 .75082 L .26929 .74534 L p .707 .577 .707 r
F P
0 g
s
.66806 .65324 m .65564 .70598 L .62898 .69463 L p .707 .577 .707 r
F P
0 g
s
.62898 .69463 m .6414 .64189 L .66806 .65324 L p .707 .577 .707 r
F P
0 g
s
.65781 .72223 m .64956 .7574 L .61918 .74855 L p .707 .577 .707 r
F P
0 g
s
.61918 .74855 m .62744 .71339 L .65781 .72223 L p .707 .577 .707 r
F P
0 g
s
.65559 .77439 m .66137 .79254 L .63549 .79816 L p .707 .577 .707 r
F P
0 g
s
.63549 .79816 m .62971 .78001 L .65559 .77439 L p .707 .577 .707 r
F P
0 g
s
.60893 .3043 m .61486 .80679 L .63797 .7963 L p .707 .577 .707 r
F P
0 g
s
.63797 .7963 m .63204 .29382 L .60893 .3043 L p .707 .577 .707 r
F P
0 g
s
.18342 .69743 m .19584 .64469 L .1755 .63195 L p .707 .577 .707 r
F P
0 g
s
.19584 .64469 m .18342 .69743 L .21008 .70878 L p .707 .577 .707 r
F P
0 g
s
.3128 .67202 m .30038 .72475 L .32407 .7223 L p .707 .577 .707 r
F P
0 g
s
.32407 .7223 m .33648 .66957 L .3128 .67202 L p .707 .577 .707 r
F P
0 g
s
.23066 .77166 m .23891 .73649 L .21225 .72516 L p .707 .577 .707 r
F P
0 g
s
.23891 .73649 m .23066 .77166 L .26104 .7805 L p .707 .577 .707 r
F P
0 g
s
.50045 .85263 m .49467 .83448 L .502 .8277 L p .707 .577 .707 r
F P
0 g
s
.30041 .75082 m .29216 .78599 L .32097 .78758 L p .707 .577 .707 r
F P
0 g
s
.32097 .78758 m .32923 .75242 L .30041 .75082 L p .707 .577 .707 r
F P
0 g
s
.68839 .66598 m .67598 .71872 L .65564 .70598 L p .707 .577 .707 r
F P
0 g
s
.65564 .70598 m .66806 .65324 L .68839 .66598 L p .707 .577 .707 r
F P
0 g
s
.502 .8277 m .50779 .84585 L .50045 .85263 L p .707 .577 .707 r
F P
0 g
s
.68668 .77252 m .69246 .79067 L .681 .78996 L p .707 .577 .707 r
F P
0 g
s
.681 .78996 m .67522 .77181 L .68668 .77252 L p .707 .577 .707 r
F P
0 g
s
.382 .80526 m .37606 .30277 L .35829 .29202 L p .707 .577 .707 r
F P
0 g
s
.37606 .30277 m .382 .80526 L .41172 .8139 L p .707 .577 .707 r
F P
0 g
s
.21225 .72516 m .204 .76033 L .23066 .77166 L p .707 .577 .707 r
F P
0 g
s
.204 .76033 m .21225 .72516 L .19191 .71244 L p .707 .577 .707 r
F P
0 g
s
.32923 .75242 m .32097 .78758 L .34466 .78512 L p .707 .577 .707 r
F P
0 g
s
.34466 .78512 m .35291 .74996 L .32923 .75242 L p .707 .577 .707 r
F P
0 g
s
.70482 .74628 m .69657 .78145 L .67623 .76873 L p .707 .577 .707 r
F P
0 g
s
.67623 .76873 m .68448 .73357 L .70482 .74628 L p .707 .577 .707 r
F P
0 g
s
.1755 .63195 m .16309 .68469 L .18342 .69743 L p .707 .577 .707 r
F P
0 g
s
.24618 .80343 m .2404 .78528 L .21081 .7934 L p .707 .577 .707 r
F P
0 g
s
.2404 .78528 m .24618 .80343 L .27659 .79362 L p .707 .577 .707 r
F P
0 g
s
.27659 .79362 m .27081 .77547 L .2404 .78528 L p .707 .577 .707 r
F P
0 g
s
.16309 .68469 m .1755 .63195 L .16348 .61908 L p .707 .577 .707 r
F P
0 g
s
.27081 .77547 m .27659 .79362 L .30484 .78307 L p .707 .577 .707 r
F P
0 g
s
.30484 .78307 m .29906 .76492 L .27081 .77547 L p .707 .577 .707 r
F P
0 g
s
.33648 .66957 m .32407 .7223 L .34031 .71604 L p .707 .577 .707 r
F P
0 g
s
.34031 .71604 m .35273 .6633 L .33648 .66957 L p .707 .577 .707 r
F P
0 g
s
.21081 .7934 m .21659 .81155 L .24618 .80343 L p .707 .577 .707 r
F P
0 g
s
.19191 .71244 m .18366 .74761 L .204 .76033 L p .707 .577 .707 r
F P
0 g
s
.21659 .81155 m .21081 .7934 L .18493 .79902 L p .707 .577 .707 r
F P
0 g
s
.29906 .76492 m .30484 .78307 L .32817 .77281 L p .707 .577 .707 r
F P
0 g
s
.32817 .77281 m .32239 .75466 L .29906 .76492 L p .707 .577 .707 r
F P
0 g
s
.18493 .79902 m .19071 .81717 L .21659 .81155 L p .707 .577 .707 r
F P
0 g
s
.63204 .29382 m .63797 .7963 L .64797 .78458 L p .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64204 .28209 L .63204 .29382 L p .707 .577 .707 r
F P
0 g
s
.18366 .74761 m .19191 .71244 L .17988 .69959 L p .707 .577 .707 r
F P
0 g
s
.67522 .77181 m .681 .78996 L .66137 .79254 L p .707 .577 .707 r
F P
0 g
s
.66137 .79254 m .65559 .77439 L .67522 .77181 L p .707 .577 .707 r
F P
0 g
s
.35291 .74996 m .34466 .78512 L .36091 .77886 L p .707 .577 .707 r
F P
0 g
s
.36091 .77886 m .36916 .74369 L .35291 .74996 L p .707 .577 .707 r
F P
0 g
s
.68448 .73357 m .67623 .76873 L .64956 .7574 L p .707 .577 .707 r
F P
0 g
s
.64956 .7574 m .65781 .72223 L .68448 .73357 L p .707 .577 .707 r
F P
0 g
s
.16348 .61908 m .15107 .67182 L .16309 .68469 L p .707 .577 .707 r
F P
0 g
s
.19071 .81717 m .18493 .79902 L .1653 .8016 L p .707 .577 .707 r
F P
0 g
s
.15107 .67182 m .16348 .61908 L .16095 .60734 L p .707 .577 .707 r
F P
0 g
s
.35273 .6633 m .34031 .71604 L .34752 .70657 L p .707 .577 .707 r
F P
0 g
s
.34752 .70657 m .35994 .65384 L .35273 .6633 L p .707 .577 .707 r
F P
0 g
s
.17988 .69959 m .17163 .73475 L .18366 .74761 L p .707 .577 .707 r
F P
0 g
s
.1653 .8016 m .17108 .81975 L .19071 .81717 L p .707 .577 .707 r
F P
0 g
s
.32239 .75466 m .32817 .77281 L .34429 .76386 L p .707 .577 .707 r
F P
0 g
s
.34429 .76386 m .33851 .74571 L .32239 .75466 L p .707 .577 .707 r
F P
0 g
s
.36916 .74369 m .36091 .77886 L .36811 .76939 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .35356 .7448 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.37383 .72249 m .3676 .74906 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.3676 .74906 m .36558 .75766 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .3542 .2802 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36181 .70964 L .36568 .71377 L p .707 .577 .707 r
F P
0 g
s
.36568 .71377 m .37383 .72249 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36568 .71377 L .36659 .73047 L .707 .577 .707 r
F
.35162 .75708 m .34584 .73893 L .33851 .74571 L p F P
0 g
s
.36181 .70964 m .35356 .7448 L .34754 .74104 L p .707 .577 .707 r
F P
0 g
s
.34584 .73893 m .35162 .75708 L .34945 .75314 L p .707 .577 .707 r
F P
0 g
s
.34945 .75314 m .34367 .73499 L .34584 .73893 L p .707 .577 .707 r
F P
0 g
s
.33851 .74571 m .34429 .76386 L .35162 .75708 L p .707 .577 .707 r
F P
0 g
s
.34367 .73499 m .34945 .75314 L .33799 .75243 L p .707 .577 .707 r
F P
0 g
s
.33799 .75243 m .33221 .73428 L .34367 .73499 L p .707 .577 .707 r
F P
0 g
s
.34754 .74104 m .33322 .73209 L p .34793 .72054 L .707 .577 .707 r
F P
0 g
s
.34793 .72054 m .36181 .70964 L .34754 .74104 L .707 .577 .707 r
F
.35994 .65384 m .34752 .70657 L .34499 .69483 L p F P
0 g
s
.33322 .73209 m .34147 .69692 L .36181 .70964 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .36422 .79451 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3542 .2802 m .35756 .56475 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.34499 .69483 m .35741 .64209 L .35994 .65384 L p .707 .577 .707 r
F P
0 g
s
.35756 .56475 m .36013 .78269 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36422 .79451 m .3626 .6573 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3626 .6573 m .35829 .29202 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36811 .76939 m .37637 .73422 L .36916 .74369 L p .707 .577 .707 r
F P
0 g
s
.37637 .73422 m .36811 .76939 L .36558 .75766 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .37383 .72249 L .37637 .73422 L p .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .36422 .79451 L .382 .80526 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .35497 .34512 L p .3642 .26848 L .707 .577 .707 r
F P
0 g
s
.35497 .34512 m .3542 .2802 L .35623 .27782 L p .707 .577 .707 r
F P
0 g
s
.35623 .27782 m .3642 .26848 L p .35497 .34512 L .707 .577 .707 r
F P
0 g
s
.17163 .73475 m .17988 .69959 L .17735 .68785 L p .707 .577 .707 r
F P
0 g
s
.16095 .60734 m .14854 .66008 L .15107 .67182 L p .707 .577 .707 r
F P
0 g
s
.17108 .81975 m .1653 .8016 L .15383 .80089 L p .707 .577 .707 r
F P
0 g
s
.15383 .80089 m .15961 .81904 L .17108 .81975 L p .707 .577 .707 r
F P
0 g
s
.17735 .68785 m .1691 .72302 L .17163 .73475 L p .707 .577 .707 r
F P
0 g
s
.14854 .66008 m .16095 .60734 L .16816 .59787 L p .707 .577 .707 r
F P
0 g
s
.64204 .28209 m .64783 .77275 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64204 .28209 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64388 .77276 m .64188 .603 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64188 .603 m .63795 .27027 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64388 .77276 L .62611 .76201 L p .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .64116 .55206 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.63128 .61654 m .6378 .58885 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .64369 .5638 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .6378 .58885 L p .6433 .62941 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .63128 .61654 L .6398 .62566 L p .707 .577 .707 r
F P
0 g
s
.6398 .62566 m .6433 .62941 L p .6378 .58885 L .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64388 .77276 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.64783 .77275 m .64797 .78458 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1691 .72302 m .17735 .68785 L .18456 .67839 L p .707 .577 .707 r
F P
0 g
s
.16816 .59787 m .15575 .65061 L .14854 .66008 L p .707 .577 .707 r
F P
0 g
s
.15961 .81904 m .15383 .80089 L .15166 .79695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15166 .79695 m .15744 .8151 L .15961 .81904 L p .707 .577 .707 r
F P
0 g
s
.18456 .67839 m .17631 .71356 L .1691 .72302 L p .707 .577 .707 r
F P
0 g
s
.15575 .65061 m .16816 .59787 L .1844 .59161 L p .707 .577 .707 r
F P
0 g
s
.35741 .64209 m .34499 .69483 L .33297 .68196 L p .707 .577 .707 r
F P
0 g
s
.33297 .68196 m .34539 .62922 L .35741 .64209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62611 .76201 m .62017 .25952 L .63795 .27027 L p .707 .577 .707 r
F P
0 g
s
.17631 .71356 m .18456 .67839 L .2008 .67212 L p .707 .577 .707 r
F P
0 g
s
.1844 .59161 m .17199 .64435 L .15575 .65061 L p .707 .577 .707 r
F P
0 g
s
.17199 .64435 m .1844 .59161 L .20809 .58916 L p .707 .577 .707 r
F P
0 g
s
.15744 .8151 m .15166 .79695 L .159 .79018 L p .707 .577 .707 r
F P
0 g
s
.34539 .62922 m .33297 .68196 L .31263 .66923 L p .707 .577 .707 r
F P
0 g
s
.31263 .66923 m .32505 .61649 L .34539 .62922 L p .707 .577 .707 r
F P
0 g
s
.2008 .67212 m .19255 .70729 L .17631 .71356 L p .707 .577 .707 r
F P
0 g
s
.159 .79018 m .16478 .80833 L .15744 .8151 L p .707 .577 .707 r
F P
0 g
s
.37013 .77096 m .3642 .26848 L .38731 .25799 L p .707 .577 .707 r
F P
0 g
s
.3642 .26848 m .37013 .77096 L .36013 .78269 L p .707 .577 .707 r
F P
0 g
s
.19255 .70729 m .2008 .67212 L .22449 .66966 L p .707 .577 .707 r
F P
0 g
s
.20809 .58916 m .19567 .6419 L .17199 .64435 L p .707 .577 .707 r
F P
0 g
s
.19567 .6419 m .20809 .58916 L .2369 .59077 L p .707 .577 .707 r
F P
0 g
s
.32505 .61649 m .31263 .66923 L .28597 .65787 L p .707 .577 .707 r
F P
0 g
s
.28597 .65787 m .29839 .60513 L .32505 .61649 L p .707 .577 .707 r
F P
0 g
s
.62017 .25952 m .62611 .76201 L .59638 .75337 L p .707 .577 .707 r
F P
0 g
s
.59638 .75337 m .59045 .25088 L .62017 .25952 L p .707 .577 .707 r
F P
0 g
s
.22449 .66966 m .21624 .70483 L .19255 .70729 L p .707 .577 .707 r
F P
0 g
s
.16478 .80833 m .159 .79018 L .17511 .78122 L p .707 .577 .707 r
F P
0 g
s
.17511 .78122 m .1809 .79937 L .16478 .80833 L p .707 .577 .707 r
F P
0 g
s
.22448 .6435 m .2369 .59077 L .26802 .59627 L p .707 .577 .707 r
F P
0 g
s
.2369 .59077 m .22448 .6435 L .19567 .6419 L p .707 .577 .707 r
F P
0 g
s
.29839 .60513 m .28597 .65787 L .2556 .64901 L p .707 .577 .707 r
F P
0 g
s
.2556 .64901 m .26802 .59627 L .29839 .60513 L p .707 .577 .707 r
F P
0 g
s
.33221 .73428 m .33799 .75243 L .31836 .75501 L p .707 .577 .707 r
F P
0 g
s
.31836 .75501 m .31258 .73686 L .33221 .73428 L p .707 .577 .707 r
F P
0 g
s
.21624 .70483 m .22449 .66966 L .25331 .67126 L p .707 .577 .707 r
F P
0 g
s
.34147 .69692 m .33322 .73209 L .30655 .72075 L p .707 .577 .707 r
F P
0 g
s
.30655 .72075 m .31481 .68558 L .34147 .69692 L p .707 .577 .707 r
F P
0 g
s
.26802 .59627 m .2556 .64901 L .22448 .6435 L p .707 .577 .707 r
F P
0 g
s
.38731 .25799 m .39324 .76048 L .37013 .77096 L p .707 .577 .707 r
F P
0 g
s
.39324 .76048 m .38731 .25799 L .42127 .24977 L p .707 .577 .707 r
F P
0 g
s
.72067 .66236 m .73308 .60962 L .70271 .60076 L p .707 .577 .707 r
F P
0 g
s
.73308 .60962 m .72067 .66236 L .75179 .66786 L p .707 .577 .707 r
F P
0 g
s
.75179 .66786 m .7642 .61513 L .73308 .60962 L p .707 .577 .707 r
F P
0 g
s
.25331 .67126 m .24505 .70642 L .21624 .70483 L p .707 .577 .707 r
F P
0 g
s
.24505 .70642 m .25331 .67126 L .28443 .67674 L p .707 .577 .707 r
F P
0 g
s
.6903 .6535 m .70271 .60076 L .67605 .58941 L p .707 .577 .707 r
F P
0 g
s
.70271 .60076 m .6903 .6535 L .72067 .66236 L p .707 .577 .707 r
F P
0 g
s
.31481 .68558 m .30655 .72075 L .27617 .71191 L p .707 .577 .707 r
F P
0 g
s
.27617 .71191 m .28443 .67674 L .31481 .68558 L p .707 .577 .707 r
F P
0 g
s
.7642 .61513 m .75179 .66786 L .7806 .66947 L p .707 .577 .707 r
F P
0 g
s
.7806 .66947 m .79301 .61673 L .7642 .61513 L p .707 .577 .707 r
F P
0 g
s
.28443 .67674 m .27617 .71191 L .24505 .70642 L p .707 .577 .707 r
F P
0 g
s
.1809 .79937 m .17511 .78122 L .19844 .77097 L p .707 .577 .707 r
F P
0 g
s
.19844 .77097 m .20422 .78912 L .1809 .79937 L p .707 .577 .707 r
F P
0 g
s
.31258 .73686 m .31836 .75501 L .29248 .76064 L p .707 .577 .707 r
F P
0 g
s
.29248 .76064 m .2867 .74249 L .31258 .73686 L p .707 .577 .707 r
F P
0 g
s
.59045 .25088 m .59638 .75337 L .55762 .7477 L p .707 .577 .707 r
F P
0 g
s
.55762 .7477 m .55169 .24521 L .59045 .25088 L p .707 .577 .707 r
F P
0 g
s
.74125 .72511 m .7495 .68995 L .71913 .6811 L p .707 .577 .707 r
F P
0 g
s
.7495 .68995 m .74125 .72511 L .77237 .7306 L p .707 .577 .707 r
F P
0 g
s
.77237 .7306 m .78062 .69543 L .7495 .68995 L p .707 .577 .707 r
F P
0 g
s
.66364 .64214 m .67605 .58941 L .65571 .57667 L p .707 .577 .707 r
F P
0 g
s
.67605 .58941 m .66364 .64214 L .6903 .6535 L p .707 .577 .707 r
F P
0 g
s
.79301 .61673 m .7806 .66947 L .80428 .66702 L p .707 .577 .707 r
F P
0 g
s
.80428 .66702 m .8167 .61428 L .79301 .61673 L p .707 .577 .707 r
F P
0 g
s
.71087 .71627 m .71913 .6811 L .69246 .66977 L p .707 .577 .707 r
F P
0 g
s
.71913 .6811 m .71087 .71627 L .74125 .72511 L p .707 .577 .707 r
F P
0 g
s
.78062 .69543 m .77237 .7306 L .80119 .73219 L p .707 .577 .707 r
F P
0 g
s
.80119 .73219 m .80944 .69702 L .78062 .69543 L p .707 .577 .707 r
F P
0 g
s
.4272 .75226 m .42127 .24977 L .46274 .24463 L p .707 .577 .707 r
F P
0 g
s
.42127 .24977 m .4272 .75226 L .39324 .76048 L p .707 .577 .707 r
F P
0 g
s
.20422 .78912 m .19844 .77097 L .22669 .76042 L p .707 .577 .707 r
F P
0 g
s
.2867 .74249 m .29248 .76064 L .26289 .76875 L p .707 .577 .707 r
F P
0 g
s
.26289 .76875 m .2571 .7506 L .2867 .74249 L p .707 .577 .707 r
F P
0 g
s
.22669 .76042 m .23247 .77857 L .20422 .78912 L p .707 .577 .707 r
F P
0 g
s
.69246 .66977 m .68421 .70493 L .71087 .71627 L p .707 .577 .707 r
F P
0 g
s
.68421 .70493 m .69246 .66977 L .67212 .65705 L p .707 .577 .707 r
F P
0 g
s
.80944 .69702 m .80119 .73219 L .82488 .72973 L p .707 .577 .707 r
F P
0 g
s
.82488 .72973 m .83313 .69456 L .80944 .69702 L p .707 .577 .707 r
F P
0 g
s
.55169 .24521 m .55762 .7477 L .51362 .74554 L p .707 .577 .707 r
F P
0 g
s
.51362 .74554 m .50769 .24305 L .55169 .24521 L p .707 .577 .707 r
F P
0 g
s
.65571 .57667 m .6433 .62941 L .66364 .64214 L p .707 .577 .707 r
F P
0 g
s
.72639 .74892 m .72061 .73077 L .69102 .73889 L p .707 .577 .707 r
F P
0 g
s
.72061 .73077 m .72639 .74892 L .7568 .73911 L p .707 .577 .707 r
F P
0 g
s
.7568 .73911 m .75102 .72096 L .72061 .73077 L p .707 .577 .707 r
F P
0 g
s
.6433 .62941 m .65571 .57667 L .64369 .5638 L p .707 .577 .707 r
F P
0 g
s
.75102 .72096 m .7568 .73911 L .78506 .72856 L p .707 .577 .707 r
F P
0 g
s
.78506 .72856 m .77927 .71041 L .75102 .72096 L p .707 .577 .707 r
F P
0 g
s
.8167 .61428 m .80428 .66702 L .82053 .66076 L p .707 .577 .707 r
F P
0 g
s
.82053 .66076 m .83294 .60802 L .8167 .61428 L p .707 .577 .707 r
F P
0 g
s
.23247 .77857 m .22669 .76042 L .2571 .7506 L p .707 .577 .707 r
F P
0 g
s
.2571 .7506 m .26289 .76875 L .23247 .77857 L p .707 .577 .707 r
F P
0 g
s
.69102 .73889 m .6968 .75704 L .72639 .74892 L p .707 .577 .707 r
F P
0 g
s
.46868 .74711 m .46274 .24463 L .50769 .24305 L p .707 .577 .707 r
F P
0 g
s
.46274 .24463 m .46868 .74711 L .4272 .75226 L p .707 .577 .707 r
F P
0 g
s
.67212 .65705 m .66387 .69222 L .68421 .70493 L p .707 .577 .707 r
F P
0 g
s
.50769 .24305 m .51362 .74554 L .46868 .74711 L p .707 .577 .707 r
F P
0 g
s
.6968 .75704 m .69102 .73889 L .66514 .74451 L p .707 .577 .707 r
F P
0 g
s
.77927 .71041 m .78506 .72856 L .80838 .7183 L p .707 .577 .707 r
F P
0 g
s
.80838 .7183 m .8026 .70015 L .77927 .71041 L p .707 .577 .707 r
F P
0 g
s
.66514 .74451 m .67092 .76266 L .6968 .75704 L p .707 .577 .707 r
F P
0 g
s
.66387 .69222 m .67212 .65705 L .6601 .6442 L p .707 .577 .707 r
F P
0 g
s
.83313 .69456 m .82488 .72973 L .84112 .72346 L p .707 .577 .707 r
F P
0 g
s
.84112 .72346 m .84937 .6883 L .83313 .69456 L p .707 .577 .707 r
F P
0 g
s
.67092 .76266 m .66514 .74451 L .64551 .74709 L p .707 .577 .707 r
F P
0 g
s
.83294 .60802 m .82053 .66076 L .82774 .65129 L p .707 .577 .707 r
F P
0 g
s
.82774 .65129 m .84015 .59855 L .83294 .60802 L p .707 .577 .707 r
F P
0 g
s
.6601 .6442 m .65184 .67936 L .66387 .69222 L p .707 .577 .707 r
F P
0 g
s
.64551 .74709 m .65129 .76524 L .67092 .76266 L p .707 .577 .707 r
F P
0 g
s
.8026 .70015 m .80838 .7183 L .8245 .70935 L p .707 .577 .707 r
F P
0 g
s
.8245 .70935 m .81872 .6912 L .8026 .70015 L p .707 .577 .707 r
F P
0 g
s
.65184 .67936 m .6601 .6442 L .65756 .63246 L p .707 .577 .707 r
F P
0 g
s
.84937 .6883 m .84112 .72346 L .84833 .714 L p .707 .577 .707 r
F P
0 g
s
.84833 .714 m .85658 .67883 L .84937 .6883 L p .707 .577 .707 r
F P
0 g
s
.64116 .55206 m .62875 .6048 L .63128 .61654 L p .707 .577 .707 r
F P
0 g
s
.65129 .76524 m .64551 .74709 L .63405 .74638 L p .707 .577 .707 r
F P
0 g
s
.63405 .74638 m .63983 .76453 L .65129 .76524 L p .707 .577 .707 r
F P
0 g
s
.65756 .63246 m .64931 .66763 L .65184 .67936 L p .707 .577 .707 r
F P
0 g
s
.62875 .6048 m .64116 .55206 L .64837 .54259 L p .707 .577 .707 r
F P
0 g
s
.81872 .6912 m .8245 .70935 L .83184 .70257 L p .707 .577 .707 r
F P
0 g
s
.83184 .70257 m .82605 .68442 L .81872 .6912 L p .707 .577 .707 r
F P
0 g
s
.84015 .59855 m .82774 .65129 L .82521 .63955 L p .707 .577 .707 r
F P
0 g
s
.82521 .63955 m .83762 .58681 L .84015 .59855 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64931 .66763 m .65756 .63246 L .66477 .623 L p .707 .577 .707 r
F P
0 g
s
.85658 .67883 m .84833 .714 L .8458 .70227 L p .707 .577 .707 r
F P
0 g
s
.8458 .70227 m .85405 .6671 L .85658 .67883 L p .707 .577 .707 r
F P
0 g
s
.64837 .54259 m .63596 .59533 L .62875 .6048 L p .707 .577 .707 r
F P
0 g
s
.63983 .76453 m .63405 .74638 L .63188 .74244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63188 .74244 m .63766 .76059 L .63983 .76453 L p .707 .577 .707 r
F P
0 g
s
.66477 .623 m .65652 .65816 L .64931 .66763 L p .707 .577 .707 r
F P
0 g
s
.63596 .59533 m .64837 .54259 L .66462 .53633 L p .707 .577 .707 r
F P
0 g
s
.83762 .58681 m .82521 .63955 L .81318 .62668 L p .707 .577 .707 r
F P
0 g
s
.81318 .62668 m .8256 .57394 L .83762 .58681 L p .707 .577 .707 r
F P
0 g
s
.82605 .68442 m .83184 .70257 L .82967 .69863 L p .707 .577 .707 r
F P
0 g
s
.82967 .69863 m .82388 .68048 L .82605 .68442 L p .707 .577 .707 r
F P
0 g
s
.37766 .62561 m .39007 .57287 L .3597 .564 L p .707 .577 .707 r
F P
0 g
s
.39007 .57287 m .37766 .62561 L .40878 .63111 L p .707 .577 .707 r
F P
0 g
s
.40878 .63111 m .42119 .57837 L .39007 .57287 L p .707 .577 .707 r
F P
0 g
s
.34729 .61674 m .3597 .564 L .33304 .55265 L p .707 .577 .707 r
F P
0 g
s
.3597 .564 m .34729 .61674 L .37766 .62561 L p .707 .577 .707 r
F P
0 g
s
.42119 .57837 m .40878 .63111 L .43759 .63271 L p .707 .577 .707 r
F P
0 g
s
.43759 .63271 m .45 .57998 L .42119 .57837 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65652 .65816 m .66477 .623 L .68102 .61673 L p .707 .577 .707 r
F P
0 g
s
.85405 .6671 m .8458 .70227 L .83377 .68941 L p .707 .577 .707 r
F P
0 g
s
.83377 .68941 m .84202 .65424 L .85405 .6671 L p .707 .577 .707 r
F P
0 g
s
.66462 .53633 m .6522 .58906 L .63596 .59533 L p .707 .577 .707 r
F P
0 g
s
.39824 .68847 m .4065 .6533 L .37612 .64446 L p .707 .577 .707 r
F P
0 g
s
.4065 .6533 m .39824 .68847 L .42936 .69395 L p .707 .577 .707 r
F P
0 g
s
.42936 .69395 m .43762 .65879 L .4065 .6533 L p .707 .577 .707 r
F P
0 g
s
.32063 .60539 m .33304 .55265 L .3127 .53991 L p .707 .577 .707 r
F P
0 g
s
.33304 .55265 m .32063 .60539 L .34729 .61674 L p .707 .577 .707 r
F P
0 g
s
.45 .57998 m .43759 .63271 L .46127 .63027 L p .707 .577 .707 r
F P
0 g
s
.46127 .63027 m .47369 .57753 L .45 .57998 L p .707 .577 .707 r
F P
0 g
s
.6522 .58906 m .66462 .53633 L .6883 .53388 L p .707 .577 .707 r
F P
0 g
s
.36786 .67962 m .37612 .64446 L .34945 .63312 L p .707 .577 .707 r
F P
0 g
s
.37612 .64446 m .36786 .67962 L .39824 .68847 L p .707 .577 .707 r
F P
0 g
s
.63766 .76059 m .63188 .74244 L .63921 .73567 L p .707 .577 .707 r
F P
0 g
s
.43762 .65879 m .42936 .69395 L .45818 .69554 L p .707 .577 .707 r
F P
0 g
s
.45818 .69554 m .46643 .66038 L .43762 .65879 L p .707 .577 .707 r
F P
0 g
s
.8256 .57394 m .81318 .62668 L .79285 .61394 L p .707 .577 .707 r
F P
0 g
s
.79285 .61394 m .80526 .5612 L .8256 .57394 L p .707 .577 .707 r
F P
0 g
s
.68102 .61673 m .67277 .6519 L .65652 .65816 L p .707 .577 .707 r
F P
0 g
s
.63921 .73567 m .64499 .75382 L .63766 .76059 L p .707 .577 .707 r
F P
0 g
s
.82388 .68048 m .82967 .69863 L .8182 .69792 L p .707 .577 .707 r
F P
0 g
s
.8182 .69792 m .81242 .67977 L .82388 .68048 L p .707 .577 .707 r
F P
0 g
s
.34945 .63312 m .3412 .66829 L .36786 .67962 L p .707 .577 .707 r
F P
0 g
s
.3412 .66829 m .34945 .63312 L .32911 .6204 L p .707 .577 .707 r
F P
0 g
s
.46643 .66038 m .45818 .69554 L .48187 .69308 L p .707 .577 .707 r
F P
0 g
s
.48187 .69308 m .49012 .65792 L .46643 .66038 L p .707 .577 .707 r
F P
0 g
s
.67277 .6519 m .68102 .61673 L .70471 .61427 L p .707 .577 .707 r
F P
0 g
s
.84202 .65424 m .83377 .68941 L .81343 .67669 L p .707 .577 .707 r
F P
0 g
s
.81343 .67669 m .82168 .64153 L .84202 .65424 L p .707 .577 .707 r
F P
0 g
s
.3127 .53991 m .30029 .59265 L .32063 .60539 L p .707 .577 .707 r
F P
0 g
s
.38338 .71139 m .3776 .69324 L .34801 .70136 L p .707 .577 .707 r
F P
0 g
s
.3776 .69324 m .38338 .71139 L .41379 .70158 L p .707 .577 .707 r
F P
0 g
s
.41379 .70158 m .40801 .68343 L .3776 .69324 L p .707 .577 .707 r
F P
0 g
s
.30029 .59265 m .3127 .53991 L .30068 .52705 L p .707 .577 .707 r
F P
0 g
s
.40801 .68343 m .41379 .70158 L .44205 .69103 L p .707 .577 .707 r
F P
0 g
s
.44205 .69103 m .43627 .67288 L .40801 .68343 L p .707 .577 .707 r
F P
0 g
s
.6883 .53388 m .67589 .58661 L .6522 .58906 L p .707 .577 .707 r
F P
0 g
s
.47369 .57753 m .46127 .63027 L .47752 .624 L p .707 .577 .707 r
F P
0 g
s
.47752 .624 m .48993 .57126 L .47369 .57753 L p .707 .577 .707 r
F P
0 g
s
.67589 .58661 m .6883 .53388 L .71711 .53548 L p .707 .577 .707 r
F P
0 g
s
.34801 .70136 m .35379 .71951 L .38338 .71139 L p .707 .577 .707 r
F P
0 g
s
.80526 .5612 m .79285 .61394 L .76619 .60259 L p .707 .577 .707 r
F P
0 g
s
.76619 .60259 m .7786 .54985 L .80526 .5612 L p .707 .577 .707 r
F P
0 g
s
.32911 .6204 m .32086 .65557 L .3412 .66829 L p .707 .577 .707 r
F P
0 g
s
.35379 .71951 m .34801 .70136 L .32213 .70698 L p .707 .577 .707 r
F P
0 g
s
.70471 .61427 m .69645 .64944 L .67277 .6519 L p .707 .577 .707 r
F P
0 g
s
.43627 .67288 m .44205 .69103 L .46537 .68077 L p .707 .577 .707 r
F P
0 g
s
.46537 .68077 m .45959 .66262 L .43627 .67288 L p .707 .577 .707 r
F P
0 g
s
.32213 .70698 m .32791 .72513 L .35379 .71951 L p .707 .577 .707 r
F P
0 g
s
.64499 .75382 m .63921 .73567 L .65533 .72671 L p .707 .577 .707 r
F P
0 g
s
.65533 .72671 m .66111 .74486 L .64499 .75382 L p .707 .577 .707 r
F P
0 g
s
.32086 .65557 m .32911 .6204 L .31709 .60755 L p .707 .577 .707 r
F P
0 g
s
.7047 .58822 m .71711 .53548 L .74823 .54099 L p .707 .577 .707 r
F P
0 g
s
.71711 .53548 m .7047 .58822 L .67589 .58661 L p .707 .577 .707 r
F P
0 g
s
.7786 .54985 m .76619 .60259 L .73581 .59372 L p .707 .577 .707 r
F P
0 g
s
.73581 .59372 m .74823 .54099 L .7786 .54985 L p .707 .577 .707 r
F P
0 g
s
.81242 .67977 m .8182 .69792 L .79857 .7005 L p .707 .577 .707 r
F P
0 g
s
.79857 .7005 m .79279 .68235 L .81242 .67977 L p .707 .577 .707 r
F P
0 g
s
.49012 .65792 m .48187 .69308 L .49811 .68682 L p .707 .577 .707 r
F P
0 g
s
.49811 .68682 m .50636 .65165 L .49012 .65792 L p .707 .577 .707 r
F P
0 g
s
.69645 .64944 m .70471 .61427 L .73352 .61586 L p .707 .577 .707 r
F P
0 g
s
.82168 .64153 m .81343 .67669 L .78677 .66536 L p .707 .577 .707 r
F P
0 g
s
.78677 .66536 m .79502 .63019 L .82168 .64153 L p .707 .577 .707 r
F P
0 g
s
.30068 .52705 m .28827 .57978 L .30029 .59265 L p .707 .577 .707 r
F P
0 g
s
.74823 .54099 m .73581 .59372 L .7047 .58822 L p .707 .577 .707 r
F P
0 g
s
.32791 .72513 m .32213 .70698 L .3025 .70957 L p .707 .577 .707 r
F P
0 g
s
.28827 .57978 m .30068 .52705 L .29815 .5153 L p .707 .577 .707 r
F P
0 g
s
.48993 .57126 m .47752 .624 L .48473 .61453 L p .707 .577 .707 r
F P
0 g
s
.48473 .61453 m .49714 .5618 L .48993 .57126 L p .707 .577 .707 r
F P
0 g
s
.31709 .60755 m .30883 .64272 L .32086 .65557 L p .707 .577 .707 r
F P
0 g
s
.3025 .70957 m .30828 .72772 L .32791 .72513 L p .707 .577 .707 r
F P
0 g
s
.45959 .66262 m .46537 .68077 L .48149 .67182 L p .707 .577 .707 r
F P
0 g
s
.48149 .67182 m .47571 .65367 L .45959 .66262 L p .707 .577 .707 r
F P
0 g
s
.73352 .61586 m .72527 .65103 L .69645 .64944 L p .707 .577 .707 r
F P
0 g
s
.72527 .65103 m .73352 .61586 L .76464 .62135 L p .707 .577 .707 r
F P
0 g
s
.79502 .63019 m .78677 .66536 L .75639 .65652 L p .707 .577 .707 r
F P
0 g
s
.75639 .65652 m .76464 .62135 L .79502 .63019 L p .707 .577 .707 r
F P
0 g
s
.76464 .62135 m .75639 .65652 L .72527 .65103 L p .707 .577 .707 r
F P
0 g
s
.66111 .74486 m .65533 .72671 L .67866 .71646 L p .707 .577 .707 r
F P
0 g
s
.67866 .71646 m .68444 .73461 L .66111 .74486 L p .707 .577 .707 r
F P
0 g
s
.79279 .68235 m .79857 .7005 L .77269 .70613 L p .707 .577 .707 r
F P
0 g
s
.77269 .70613 m .76691 .68798 L .79279 .68235 L p .707 .577 .707 r
F P
0 g
s
.30883 .64272 m .31709 .60755 L .31455 .59582 L p .707 .577 .707 r
F P
0 g
s
.50636 .65165 m .49811 .68682 L .50532 .67735 L p .707 .577 .707 r
F P
0 g
s
.50532 .67735 m .51357 .64219 L .50636 .65165 L p .707 .577 .707 r
F P
0 g
s
.29815 .5153 m .28574 .56804 L .28827 .57978 L p .707 .577 .707 r
F P
0 g
s
.30828 .72772 m .3025 .70957 L .29104 .70885 L p .707 .577 .707 r
F P
0 g
s
.29104 .70885 m .29682 .727 L .30828 .72772 L p .707 .577 .707 r
F P
0 g
s
.31455 .59582 m .3063 .63098 L .30883 .64272 L p .707 .577 .707 r
F P
0 g
s
.28574 .56804 m .29815 .5153 L .30536 .50584 L p .707 .577 .707 r
F P
0 g
s
.47571 .65367 m .48149 .67182 L .48883 .66504 L p .707 .577 .707 r
F P
0 g
s
.48883 .66504 m .48304 .64689 L .47571 .65367 L p .707 .577 .707 r
F P
0 g
s
.68444 .73461 m .67866 .71646 L .70691 .70591 L p .707 .577 .707 r
F P
0 g
s
.49714 .5618 m .48473 .61453 L .4822 .60279 L p .707 .577 .707 r
F P
0 g
s
.4822 .60279 m .49461 .55005 L .49714 .5618 L p .707 .577 .707 r
F P
0 g
s
.76691 .68798 m .77269 .70613 L .7431 .71424 L p .707 .577 .707 r
F P
0 g
s
.7431 .71424 m .73732 .69609 L .76691 .68798 L p .707 .577 .707 r
F P
0 g
s
.70691 .70591 m .71269 .72406 L .68444 .73461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71269 .72406 m .70691 .70591 L .73732 .69609 L p .707 .577 .707 r
F P
0 g
s
.73732 .69609 m .7431 .71424 L .71269 .72406 L p .707 .577 .707 r
F P
0 g
s
.3063 .63098 m .31455 .59582 L .32176 .58635 L p .707 .577 .707 r
F P
0 g
s
.51357 .64219 m .50532 .67735 L .50279 .66562 L p .707 .577 .707 r
F P
0 g
s
.50279 .66562 m .51104 .63045 L .51357 .64219 L p .707 .577 .707 r
F P
0 g
s
.30536 .50584 m .29295 .55857 L .28574 .56804 L p .707 .577 .707 r
F P
0 g
s
.29682 .727 m .29104 .70885 L .28887 .70491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28887 .70491 m .29465 .72306 L .29682 .727 L p .707 .577 .707 r
F P
0 g
s
.32176 .58635 m .31351 .62152 L .3063 .63098 L p .707 .577 .707 r
F P
0 g
s
.29295 .55857 m .30536 .50584 L .32161 .49957 L p .707 .577 .707 r
F P
0 g
s
.48304 .64689 m .48883 .66504 L .48666 .6611 L p .707 .577 .707 r
F P
0 g
s
.48666 .6611 m .48087 .64295 L .48304 .64689 L p .707 .577 .707 r
F P
0 g
s
.49461 .55005 m .4822 .60279 L .47017 .58992 L p .707 .577 .707 r
F P
0 g
s
.47017 .58992 m .48259 .53718 L .49461 .55005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31351 .62152 m .32176 .58635 L .33801 .58008 L p .707 .577 .707 r
F P
0 g
s
.51104 .63045 m .50279 .66562 L .49076 .65276 L p .707 .577 .707 r
F P
0 g
s
.49076 .65276 m .49901 .6176 L .51104 .63045 L p .707 .577 .707 r
F P
0 g
s
.32161 .49957 m .30919 .55231 L .29295 .55857 L p .707 .577 .707 r
F P
0 g
s
.30919 .55231 m .32161 .49957 L .34529 .49712 L p .707 .577 .707 r
F P
0 g
s
.29465 .72306 m .28887 .70491 L .2962 .69814 L p .707 .577 .707 r
F P
0 g
s
.48259 .53718 m .47017 .58992 L .44984 .57719 L p .707 .577 .707 r
F P
0 g
s
.44984 .57719 m .46225 .52445 L .48259 .53718 L p .707 .577 .707 r
F P
0 g
s
.33801 .58008 m .32975 .61525 L .31351 .62152 L p .707 .577 .707 r
F P
0 g
s
.2962 .69814 m .30198 .71629 L .29465 .72306 L p .707 .577 .707 r
F P
0 g
s
.48087 .64295 m .48666 .6611 L .47519 .66039 L p .707 .577 .707 r
F P
0 g
s
.47519 .66039 m .46941 .64224 L .48087 .64295 L p .707 .577 .707 r
F P
0 g
s
.32975 .61525 m .33801 .58008 L .3617 .57762 L p .707 .577 .707 r
F P
0 g
s
.49901 .6176 m .49076 .65276 L .47042 .64005 L p .707 .577 .707 r
F P
0 g
s
.47042 .64005 m .47867 .60488 L .49901 .6176 L p .707 .577 .707 r
F P
0 g
s
.34529 .49712 m .33288 .54986 L .30919 .55231 L p .707 .577 .707 r
F P
0 g
s
.33288 .54986 m .34529 .49712 L .3741 .49873 L p .707 .577 .707 r
F P
0 g
s
.46225 .52445 m .44984 .57719 L .42318 .56583 L p .707 .577 .707 r
F P
0 g
s
.42318 .56583 m .43559 .51309 L .46225 .52445 L p .707 .577 .707 r
F P
0 g
s
.3617 .57762 m .35344 .61279 L .32975 .61525 L p .707 .577 .707 r
F P
0 g
s
.30198 .71629 m .2962 .69814 L .31232 .68918 L p .707 .577 .707 r
F P
0 g
s
.31232 .68918 m .3181 .70733 L .30198 .71629 L p .707 .577 .707 r
F P
0 g
s
.36169 .55146 m .3741 .49873 L .40522 .50423 L p .707 .577 .707 r
F P
0 g
s
.3741 .49873 m .36169 .55146 L .33288 .54986 L p .707 .577 .707 r
F P
0 g
s
.43559 .51309 m .42318 .56583 L .3928 .55697 L p .707 .577 .707 r
F P
0 g
s
.3928 .55697 m .40522 .50423 L .43559 .51309 L p .707 .577 .707 r
F P
0 g
s
.46941 .64224 m .47519 .66039 L .45556 .66297 L p .707 .577 .707 r
F P
0 g
s
.45556 .66297 m .44978 .64482 L .46941 .64224 L p .707 .577 .707 r
F P
0 g
s
.35344 .61279 m .3617 .57762 L .39051 .57922 L p .707 .577 .707 r
F P
0 g
s
.47867 .60488 m .47042 .64005 L .44376 .62871 L p .707 .577 .707 r
F P
0 g
s
.44376 .62871 m .45201 .59355 L .47867 .60488 L p .707 .577 .707 r
F P
0 g
s
.40522 .50423 m .3928 .55697 L .36169 .55146 L p .707 .577 .707 r
F P
0 g
s
.39051 .57922 m .38226 .61438 L .35344 .61279 L p .707 .577 .707 r
F P
0 g
s
.38226 .61438 m .39051 .57922 L .42163 .5847 L p .707 .577 .707 r
F P
0 g
s
.45201 .59355 m .44376 .62871 L .41338 .61987 L p .707 .577 .707 r
F P
0 g
s
.41338 .61987 m .42163 .5847 L .45201 .59355 L p .707 .577 .707 r
F P
0 g
s
.42163 .5847 m .41338 .61987 L .38226 .61438 L p .707 .577 .707 r
F P
0 g
s
.3181 .70733 m .31232 .68918 L .33564 .67893 L p .707 .577 .707 r
F P
0 g
s
.33564 .67893 m .34143 .69708 L .3181 .70733 L p .707 .577 .707 r
F P
0 g
s
.44978 .64482 m .45556 .66297 L .42968 .6686 L p .707 .577 .707 r
F P
0 g
s
.42968 .6686 m .4239 .65045 L .44978 .64482 L p .707 .577 .707 r
F P
0 g
s
.34143 .69708 m .33564 .67893 L .3639 .66838 L p .707 .577 .707 r
F P
0 g
s
.4239 .65045 m .42968 .6686 L .40009 .67671 L p .707 .577 .707 r
F P
0 g
s
.40009 .67671 m .39431 .65856 L .4239 .65045 L p .707 .577 .707 r
F P
0 g
s
.3639 .66838 m .36968 .68653 L .34143 .69708 L p .707 .577 .707 r
F P
0 g
s
.36968 .68653 m .3639 .66838 L .39431 .65856 L p .707 .577 .707 r
F P
0 g
s
.39431 .65856 m .40009 .67671 L .36968 .68653 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol005moo`h00003FUH005YF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Eoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001FOol30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`80
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`L005Ioo`00Dgoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo
10000eYF00@005YFFUIJEPT004eoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00Agoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020014Ool0059oo`03001JEP00
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH30011Ool0059oo`8000=JEP04001JEUYFFUH>0007FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`00?Woo001BOol20002FUH50003FUH20005Ool00`00FUIJEP050002
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003aoo`00DWoo00IJEP00
000005YF0006FUH01000FUH000000goo00@005YFFUH000AJEPD000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8003Yoo`00DGoo0P0015YF00<005YFFUH015YF00@005YFFUIJEP@0
009JEP03001JEUYF00AJEPL0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000hOol0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP@000EJEPD000=JEP<000MJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00DGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF00000`000UYF1@001EYF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EP00=Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70005FUH0
0`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<goo001AOol0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70003FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo031oo`00DGoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YF00004@0015YF2`001UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000aOol0059oo`05001JEUYFFUH00005FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH30004FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00
Dgoo00<005YF00001EYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@00
1EYF00<005YFFUH00P0000=JEP00FUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUIJEP0000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003Qoo`L0
01Eoo`8000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00D000EJEP8000AJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPD0009JEP<0009oo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02aoo`00<goo1@000eYF00@005YFFUIJEPT000eoo`03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
00AJEP8000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
001JEP0200000eYF001JEP05FUH01000FUH000002Goo1P001eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002ioo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P0027oo0P0000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0`000UYF00@005YF001JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000]oo`@000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002moo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000008Ool30003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP030002FUH30006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH015YF0`001goo200000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00000P0017oo1@000goo0`001eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000goo000000030006Ool20004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000Qo
o`<00003FUH005YF00EJEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUHB0006FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF1`0015YF00<005YFFUH0
0UYF20000goo0P001UYF00@005YFFUIJEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP000000
17oo10001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUH000040003FUH01000FUIJEUYF2@0015YF00@005YFFUIJEPL000AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000Ioo`@0009JEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60006FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000_Ool002aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH20004FUH40004Ool00`00FUIJEP060006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YF001JEP0000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH20005FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000
0eYF00<005YFFUH00UYF0`000eYF00<005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00`00
0Woo00@005YFFUH000EJEP@0009JEP03001JEUYF00EJEP<000MJEP03001JEUYF00=JEP04001JEUYF
FUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40006FUH01000
FUIJEUYF0P00<7oo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEQ<0
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<00004FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30004FUH20002FUH2000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP8000=JEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800004Ool000000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01P00FUH00000FUH0009JEP800003FUH007oo02moo`00:goo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00UYF00<005YFFUH015YF00H005YF000005YF0005FUH50006FUH00`00FUIJEP07FUH3
0006FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YFFUIJEP<0009JEP03001JEP00031oo`00:goo00<005YF00000UYF00@005YFFUIJEPL000AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF009JEP8000IJEP<000MJEP03001JEUYF00MJEP<000IJEP04001JEUYFFUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00Ool0
;goo000[Ool20003FUH40003FUH20002Ool90004FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH015YF10000UYF00<005YFFUH01eYF00<005YFFUH01`000UYF0`00
0eYF00<005YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1000
00=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`00<Goo000[Ool00eYF001JEP030006FUH01000FUH000002Goo1P0025YF00<0
05YFFUH015YF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH010001UYF1@000eYF00<005YF
FUH015YF00H005YF000005YF0003FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUH005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF000`Ool002Yoo`04001JEP000002FUH00`00FUIJEP04
FUH01000FUIJEUYF0`002Woo1@0015YF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<005YF
FUH015YF1P0000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF200015YF200015YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000ZOol20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH30006Ool500001Woo00000000FUH000MJEP03001JEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00800003FUH0
07oo00Eoo`8000EJEP03001JEUYF009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo02]oo`00:Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000Aoo`D000Ao
o`<000IJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP05
FUH01000FUIJEUYF100000AJEP000000009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP800003FUH0000000=JEP8000Moo`<00003FUH005YF00QJEP03001JEP00008000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8002aoo`00:Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0000=oo`0000000`001goo0P0015YF00@005YFFUIJEP80009JEP03
001JEUYF00EJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00AJEPD0009JEP03001JEP00
00800004FUH00000FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH00`00FUIJEP020008Ool60004FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEP00:goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH60009Ool200000eYF001JEP05FUH20008FUH30004FUH00`00FUIJEP07FUH00`00FUH000060005
FUH00`00FUH00003FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF00<007ooOol02goo200015YF10001eYF00<005YF
FUH00eYF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
15YF3@000UYF20000goo0P001UYF0`0015YF0`0025YF00<005YFFUH015YF10000UYF0P000eYF00<0
05YFFUH00UYF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF0P002Woo1@0017oo2P0015YF00<005YFFUH0
15YF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00001@00
0UYF00<005YFFUH01UYF00<005YF00000`000UYF00@005YFFUIJEPL000AJEP03001JEUYF00@00003
FUH005YF00QJEP03001JEUYF00@000=JEP<000EJEP03001JEUYF009JEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF
00AJEP04001JEP000008Ool5000>Ool300000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0X
Ool002]oo`04001JEUYF0005FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50005FUH00`00FUIJEP02000015YF001JEUYF0`0015YF00<005YFFUH01EYF100015YF0`0000=J
EP00FUH01UYF00H005YF000005YF0004FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Goo1@004Goo0P00
1EYF00L005YFFUIJEP00FUH0000YOol002aoo`<000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00=JEP@000MJEP03001JEUYF00=JEP@0
00=JEP<000AJEP03001JEUYF00AJEP<000=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH30003Ool3000@Ool50004FUH01`00FUIJEUYF001JEP0002Uoo`00;Woo00<005YFFUH00UYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`0000=JEP00
FUH025YF00<005YF00002@0025YF00@005YFFUIJEP<000EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF
00<005YFFUH01UYF00<005YF00000P003Goo1P000UYF00<005YFFUH00P000UYF00L005YFFUIJEP00
FUH0000YOol002moo`800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00EJEP<000=JEPH000UJEP06001JEP00001JEP00
1UYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0017oo1P000eYF00<005YF
FUH00eYF00<005YFFUH00`0015YF00<005YF0000:Goo000aOol30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP03FUH200000eYF001J
EP02FUH600000eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP80
02Yoo`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF00<005YFFUH01EYF00<005YF00000`000UYF10000UYF0`000UYF00<005YFFUH00eYF
40001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF
00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00<0009JEP03001JEP0002Yoo`00<Goo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
15YF100000=oo`0000000P000UYF00<005YFFUH01eYF00<005YF00000P002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUH000QJEP03001JEP0000800003FUH005YF00MJEP03001JEUYF00EJEP04001JEUYF
FUH700001UYF00000000FUH002Yoo`00<Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP800003FUH00000008000IJ
EP03001JEUYF00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00AJEP<000MJEP<000EJEP03
001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUIJEP000eYF00<005YF0000:Woo000aOol20003
FUH01000FUIJEUYF3P001UYF00L005YFFUIJEP00FUH00005FUH00`00FUH0000400000eYF001JEP08
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40006FUH30003FUH30008FUH00`00FUIJEP05
FUH50002FUH200000eYF001JEP04FUH20004FUH00`00FUH0000ZOol0035oo`80009JEPP000QJEP03
001JEUYF00@0009JEP05001JEUYFFUH00002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<0
05YF00000P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF1P0015YF00<005YFFUH00`0000=JEP00FUH025YF00<005YF
FUH00eYF0P000UYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0015YF0P00:goo000aOol01UYF
00000000FUH000Ioo`<000AJEP03001JEUYF00EJEPD00006FUH005YFFUH005YF0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP00
009JEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEP00008000AJEP<000IJEP03001JEUYF
00800003FUH005YF00=JEP8002]oo`00<7oo0P0015YF0`001goo0`0000=JEP00FUH01eYF00@005YF
FUIJEP<00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP<000AJEP@000MJEP03001JEUYF00EJEP@000EJEP800003FUH005YF00IJEP<000=J
EP07001JEUYFFUH005YF0000:goo000`Ool20004FUH01000FUIJEP002Goo1P0015YF00<005YFFUH0
0eYF0P0000=JEP00FUH015YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF0`002EYF00<005YFFUH020000UYF0`0015YF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<005YFFUH00UYF0P0037oo2@000UYF
0P000UYF00<005YFFUH00eYF00<005YF00000`000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1`000eYF00<005YFFUH01EYF100000=oo`0000001`001eYF00<005YFFUH0
0UYF0P001EYF00@005YFFUIJEP8002eoo`00<7oo0P000eYF00<005YFFUH015YF0P002Goo1@001Goo
3`001EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP000000
1EYF00<005YFFUH00eYF0P001Woo1`002EYF00H005YF000005YF0005FUH01000FUH00000;goo000`
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUH000001goo1@0047oo0`001UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10001eYF00<005YF00000P0017oo10000UYF
0`000UYF00<005YFFUH01EYF0`000UYF00@005YFFUIJEPD0035oo`00<7oo00<005YFFUH00UYF00<0
05YFFUH015YF00@005YFFUIJEP8000Eoo`D0011oo`<000IJEP80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP<00003FUH007oo009oo`800003FUH0
05YF00QJEP03001JEUYF00=JEP800003Ool0000000H003Ioo`00<Goo00D005YFFUIJEP0000EJEP03
001JEUYF00AJEP@0009oo`<000aoo`D0009JEP<000=JEP03001JEP00009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00005FUH01000FUIJEUYF0P0000EJEP00000007oo00<000AJEP03
001JEUYF00MJEP03001JEP000080045oo`00<Woo00<005YF00001UYF00<005YFFUH01EYF00<005YF
FUH010002Goo100000=JEP00FUH01EYF00P005YF000005YF001JEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P001EYF00@005YF0000009JEPD000MJEP03001JEUYF00EJEP@004Ao
o`00<goo0P001UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000Aoo`00000000IJEP03001JEUYF
00=JEP03001JEUYF00<00005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00
FUIJEP02FUH60003FUH00`00FUIJEP07FUH00`00FUIJEP040018Ool003Aoo`03001JEUYF00AJEP03
001JEUYF00AJEP03001JEUYF00MJEP@00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00009o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001JEUYF00EJ
EP03001JEP00009JEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4001<Ool0
03Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP04001JEUYF
FUH400000eYF000000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH9000;FUH00`00FUIJEP0:
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00D7oo000gOol01000FUIJEP001eYF00<005YFFUH00`0000=JEP00FUH0
1eYF00<005YFFUH015YF1@000UYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00=J
EP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP04
001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUH00002001BOol003Qoo`<000MJEP<000AJ
EP03001JEUYF00MJEP03001JEP0000H000EJEP03001JEP00009JEP04001JEUYF0005FUH00`00FUH0
0004000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH50003FUH00`00Oomoo`1?Ool003Yo
o`8000=JEP<000QJEP03001JEUYF00AJEP@0009JEP8000=JEP03001JEUYF009JEP<0009JEP04001J
EUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH40003FUH01@00FUIJEUYF00000UYF1`0015YF00D005YFFUIJEP00055oo`00
?7oo0`0000=JEP00FUH025YF00<005YFFUH010000eYF0`001EYF00<005YFFUH00UYF00<005YF0000
0UYF00@005YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF0000000800000eYF001JEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`1?Ool003Yoo`<000AJEP03001JEUYF00EJEP@000AJEP<00003FUH0
05YF00IJEP06001JEP00001JEP000eYF00D005YFFUH005YF008000QJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP03001oogoo00Aoo`8000EJEP07001JEUYFFUH005YF0000D7oo000gOol30007FUH00`00FUIJEP03
FUH40003FUH30004FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF00000UYF0P0000=JEP00FUH0
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF100017oo1@0015YF00L005YFFUIJEP00FUH0001@Ool003Eoo`800003FUH0
05YF00QJEP03001JEP0000T000QJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000D0009JEP03001JEUYF0080009JEP07001JEUYF
FUH005YF0000D7oo000cOol20004FUH00`00FUIJEP05FUH30003Ool60009FUH01P00FUH00000FUH0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00<005YFFUH00`0015YF00<005YF0000D7oo000aOol20006FUH00`00FUIJEP03FUH20005Ool60000
0eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01@00FUH00000Ool00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00H005YFFUH005YF0005FUH01000FUIJEUYF0P0015YF0P00DGoo000_Ool30008
FUH00`00FUH000020003Ool40002FUH30002FUH00`00FUIJEP03FUH@0003Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<0
05YF0000DGoo000]Ool20003FUH00`00FUIJEP04FUH30002Ool40002FUH00`00FUIJEP07FUH00`00
FUH00002000DOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH0
1000FUIJEUYF1`0000IJEP00000005YF001AOol002aoo`8000AJEP03001JEUYF009JEP800003Ool0
0000008000IJEP03001JEUYF00IJEP<001Moo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP800003FUH0000000D000=JEP04001JEUYF0003FUH00`00FUH0001AOol002]oo`03001JEP00
00EJEP03001JEP0000@00003FUH005YF00QJEP03001JEUYF009JEP<001]oo`80009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP800003FUH005YF00AJEP8000AJEP03001JEP00055oo`00:goo
00@005YFFUH000=JEP@000IJEP03001JEUYF00IJEP03001JEP000080021oo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH2000015YF001JEUYF0P000eYF00<005YFFUH00eYF0P0015YF0P00DWoo000[Ool01@00FUIJEP00
FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`009Goo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP<0
00IJEP03001JEUYF00800003FUH005YF00=JEP80059oo`00;7oo00@005YF000000EJEP03001JEUYF
00EJEP03001JEUYF00@002Yoo`<000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00AJEP@000=JEP800003FUH005YF00IJEP<000=JEP07001JEUYF
FUH005YF0000DWoo000/Ool200000eYF001JEP04FUH00`00FUIJEP04FUH4000aOol300000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP050003FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000/Ool20002FUH00`00FUIJ
EP03FUH00`00FUH00003000hOol40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH=0007FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P00E7oo000]Ool200000eYF001JEP02
FUH40010Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF20000goo1`002EYF
00H005YF000005YF0005FUH01000FUH00000EWoo000_Ool5001:OolO0003FUH20002Ool400000eYF
0000000300000eYF001JEP06FUH30002FUH01000FUIJEUYF1@00F7oo002?Ool20002FUH00`00FUIJ
EP05FUH00`00FUH000020002Ool200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH200000goo
00000006001MOol008ioo`03001JEUYF00=JEP03001JEUYF00=JEP<0009oo`<000AJEP03001JEUYF
00MJEP03001JEP00008006Qoo`00SGoo0P001EYF00<005YF000020001eYF00<005YFFUH01UYF0`00
Jgoo002<Ool01000FUIJEP0015YF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00KWoo002<
Ool01000FUIJEP000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEP000080075oo`00SGoo
00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH01EYF0`00M7oo002=Ool00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP04001gOol008ioo`04FUH005YF0005FUH00`00FUIJEP04
FUH4001kOol008ioo`05001JEUYFFUH00004FUH00`00FUIJEP04001oOol008ioo``008=oo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58347 .7544 m .59588 .70166 L .56551 .6928 L p .707 .577 .707 r
F P
0 g
s
.59588 .70166 m .58347 .7544 L .61458 .7599 L p .707 .577 .707 r
F P
0 g
s
.61458 .7599 m .627 .70717 L .59588 .70166 L p .707 .577 .707 r
F P
0 g
s
.55309 .74554 m .56551 .6928 L .53885 .68144 L p .707 .577 .707 r
F P
0 g
s
.56551 .6928 m .55309 .74554 L .58347 .7544 L p .707 .577 .707 r
F P
0 g
s
.627 .70717 m .61458 .7599 L .64339 .76151 L p .707 .577 .707 r
F P
0 g
s
.64339 .76151 m .65581 .70877 L .627 .70717 L p .707 .577 .707 r
F P
0 g
s
.60405 .81715 m .6123 .78198 L .58192 .77314 L p .707 .577 .707 r
F P
0 g
s
.6123 .78198 m .60405 .81715 L .63517 .82264 L p .707 .577 .707 r
F P
0 g
s
.63517 .82264 m .64342 .78747 L .6123 .78198 L p .707 .577 .707 r
F P
0 g
s
.52643 .73418 m .53885 .68144 L .51851 .66871 L p .707 .577 .707 r
F P
0 g
s
.53885 .68144 m .52643 .73418 L .55309 .74554 L p .707 .577 .707 r
F P
0 g
s
.65581 .70877 m .64339 .76151 L .66708 .75906 L p .707 .577 .707 r
F P
0 g
s
.66708 .75906 m .67949 .70632 L .65581 .70877 L p .707 .577 .707 r
F P
0 g
s
.57367 .80831 m .58192 .77314 L .55526 .76181 L p .707 .577 .707 r
F P
0 g
s
.58192 .77314 m .57367 .80831 L .60405 .81715 L p .707 .577 .707 r
F P
0 g
s
.64342 .78747 m .63517 .82264 L .66398 .82423 L p .707 .577 .707 r
F P
0 g
s
.66398 .82423 m .67223 .78906 L .64342 .78747 L p .707 .577 .707 r
F P
0 g
s
.55526 .76181 m .547 .79697 L .57367 .80831 L p .707 .577 .707 r
F P
0 g
s
.547 .79697 m .55526 .76181 L .53492 .74909 L p .707 .577 .707 r
F P
0 g
s
.67223 .78906 m .66398 .82423 L .68767 .82177 L p .707 .577 .707 r
F P
0 g
s
.68767 .82177 m .69592 .7866 L .67223 .78906 L p .707 .577 .707 r
F P
0 g
s
.51851 .66871 m .5061 .72145 L .52643 .73418 L p .707 .577 .707 r
F P
0 g
s
.58919 .84096 m .58341 .82281 L .55381 .83092 L p .707 .577 .707 r
F P
0 g
s
.58341 .82281 m .58919 .84096 L .6196 .83114 L p .707 .577 .707 r
F P
0 g
s
.6196 .83114 m .61382 .81299 L .58341 .82281 L p .707 .577 .707 r
F P
0 g
s
.5061 .72145 m .51851 .66871 L .50649 .65584 L p .707 .577 .707 r
F P
0 g
s
.61382 .81299 m .6196 .83114 L .64785 .82059 L p .707 .577 .707 r
F P
0 g
s
.64785 .82059 m .64207 .80244 L .61382 .81299 L p .707 .577 .707 r
F P
0 g
s
.67949 .70632 m .66708 .75906 L .68332 .75279 L p .707 .577 .707 r
F P
0 g
s
.68332 .75279 m .69574 .70006 L .67949 .70632 L p .707 .577 .707 r
F P
0 g
s
.55381 .83092 m .5596 .84907 L .58919 .84096 L p .707 .577 .707 r
F P
0 g
s
.53492 .74909 m .52666 .78425 L .547 .79697 L p .707 .577 .707 r
F P
0 g
s
.5596 .84907 m .55381 .83092 L .52794 .83655 L p .707 .577 .707 r
F P
0 g
s
.64207 .80244 m .64785 .82059 L .67118 .81034 L p .707 .577 .707 r
F P
0 g
s
.67118 .81034 m .6654 .79219 L .64207 .80244 L p .707 .577 .707 r
F P
0 g
s
.52794 .83655 m .53372 .8547 L .5596 .84907 L p .707 .577 .707 r
F P
0 g
s
.52666 .78425 m .53492 .74909 L .52289 .73623 L p .707 .577 .707 r
F P
0 g
s
.69592 .7866 m .68767 .82177 L .70391 .8155 L p .707 .577 .707 r
F P
0 g
s
.70391 .8155 m .71217 .78033 L .69592 .7866 L p .707 .577 .707 r
F P
0 g
s
.50649 .65584 m .49407 .70858 L .5061 .72145 L p .707 .577 .707 r
F P
0 g
s
.53372 .8547 m .52794 .83655 L .5083 .83913 L p .707 .577 .707 r
F P
0 g
s
.49407 .70858 m .50649 .65584 L .50396 .6441 L p .707 .577 .707 r
F P
0 g
s
.69574 .70006 m .68332 .75279 L .69053 .74333 L p .707 .577 .707 r
F P
0 g
s
.69053 .74333 m .70295 .69059 L .69574 .70006 L p .707 .577 .707 r
F P
0 g
s
.52289 .73623 m .51464 .7714 L .52666 .78425 L p .707 .577 .707 r
F P
0 g
s
.5083 .83913 m .51409 .85728 L .53372 .8547 L p .707 .577 .707 r
F P
0 g
s
.6654 .79219 m .67118 .81034 L .6873 .80139 L p .707 .577 .707 r
F P
0 g
s
.6873 .80139 m .68152 .78324 L .6654 .79219 L p .707 .577 .707 r
F P
0 g
s
.51464 .7714 m .52289 .73623 L .52036 .7245 L p .707 .577 .707 r
F P
0 g
s
.71217 .78033 m .70391 .8155 L .71112 .80604 L p .707 .577 .707 r
F P
0 g
s
.71112 .80604 m .71938 .77087 L .71217 .78033 L p .707 .577 .707 r
F P
0 g
s
.50396 .6441 m .49155 .69683 L .49407 .70858 L p .707 .577 .707 r
F P
0 g
s
.51409 .85728 m .5083 .83913 L .49684 .83842 L p .707 .577 .707 r
F P
0 g
s
.49684 .83842 m .50262 .85657 L .51409 .85728 L p .707 .577 .707 r
F P
0 g
s
.52036 .7245 m .51211 .75967 L .51464 .7714 L p .707 .577 .707 r
F P
0 g
s
.49155 .69683 m .50396 .6441 L .51117 .63463 L p .707 .577 .707 r
F P
0 g
s
.68152 .78324 m .6873 .80139 L .69463 .79461 L p .707 .577 .707 r
F P
0 g
s
.69463 .79461 m .68885 .77646 L .68152 .78324 L p .707 .577 .707 r
F P
0 g
s
.70295 .69059 m .69053 .74333 L .688 .73158 L p .707 .577 .707 r
F P
0 g
s
.688 .73158 m .70042 .67885 L .70295 .69059 L p .707 .577 .707 r
F P
0 g
s
.51117 .63463 m .49875 .68737 L .49155 .69683 L p .707 .577 .707 r
F P
0 g
s
.49448 .82173 m .48855 .31924 L .44455 .31708 L p .707 .577 .707 r
F P
0 g
s
.51211 .75967 m .52036 .7245 L .52757 .71504 L p .707 .577 .707 r
F P
0 g
s
.52757 .71504 m .51932 .7502 L .51211 .75967 L p .707 .577 .707 r
F P
0 g
s
.49875 .68737 m .51117 .63463 L .52741 .62836 L p .707 .577 .707 r
F P
0 g
s
.51932 .7502 m .52757 .71504 L .54381 .70877 L p .707 .577 .707 r
F P
0 g
s
.52741 .62836 m .515 .6811 L .49875 .68737 L p .707 .577 .707 r
F P
0 g
s
.515 .6811 m .52741 .62836 L .5511 .62592 L p .707 .577 .707 r
F P
0 g
s
.54381 .70877 m .53556 .74393 L .51932 .7502 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .53868 .67865 L .515 .6811 L p .707 .577 .707 r
F P
0 g
s
.50779 .84585 m .502 .8277 L .51812 .81875 L p .707 .577 .707 r
F P
0 g
s
.51812 .81875 m .52391 .8369 L .50779 .84585 L p .707 .577 .707 r
F P
0 g
s
.52391 .8369 m .51812 .81875 L .54145 .8085 L p .707 .577 .707 r
F P
0 g
s
.54145 .8085 m .54723 .82665 L .52391 .8369 L p .707 .577 .707 r
F P
0 g
s
.48855 .31924 m .49448 .82173 L .53943 .82015 L p .707 .577 .707 r
F P
0 g
s
.53556 .74393 m .54381 .70877 L .5675 .70631 L p .707 .577 .707 r
F P
0 g
s
.5675 .70631 m .55925 .74148 L .53556 .74393 L p .707 .577 .707 r
F P
0 g
s
.53943 .82015 m .53349 .31767 L .48855 .31924 L p .707 .577 .707 r
F P
0 g
s
.5511 .62592 m .57991 .62752 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.53868 .67865 m .5452 .65097 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.5452 .65097 m .5511 .62592 L p .55112 .66323 L .707 .577 .707 r
F P
0 g
s
.62971 .78001 m .63549 .79816 L .6059 .80628 L p .707 .577 .707 r
F P
0 g
s
.6059 .80628 m .60011 .78813 L .62971 .78001 L p .707 .577 .707 r
F P
0 g
s
.60011 .78813 m .6059 .80628 L .57548 .8161 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .61486 .80679 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.56749 .68026 m .57991 .62752 L .61102 .63303 L p .707 .577 .707 r
F P
0 g
s
.57991 .62752 m .56749 .68026 L .53868 .67865 L p .707 .577 .707 r
F P
0 g
s
.6414 .64189 m .62898 .69463 L .59861 .68576 L p .707 .577 .707 r
F P
0 g
s
.59861 .68576 m .61102 .63303 L .6414 .64189 L p .707 .577 .707 r
F P
0 g
s
.55925 .74148 m .5675 .70631 L .59632 .7079 L p .707 .577 .707 r
F P
0 g
s
.61102 .63303 m .59861 .68576 L .56749 .68026 L p .707 .577 .707 r
F P
0 g
s
.59632 .7079 m .58806 .74307 L .55925 .74148 L p .707 .577 .707 r
F P
0 g
s
.58806 .74307 m .59632 .7079 L .62744 .71339 L p .707 .577 .707 r
F P
0 g
s
.62744 .71339 m .61918 .74855 L .58806 .74307 L p .707 .577 .707 r
F P
0 g
s
.57497 .31252 m .57981 .72266 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.57548 .8161 m .5697 .79795 L .60011 .78813 L p .707 .577 .707 r
F P
0 g
s
.57981 .72266 m .5809 .81501 L p .61374 .79293 L .707 .577 .707 r
F P
0 g
s
.54723 .82665 m .54145 .8085 L .5697 .79795 L p .707 .577 .707 r
F P
0 g
s
.5697 .79795 m .57548 .8161 L .54723 .82665 L p .707 .577 .707 r
F P
0 g
s
.53349 .31767 m .53943 .82015 L .5809 .81501 L p .707 .577 .707 r
F P
0 g
s
.5809 .81501 m .57497 .31252 L .53349 .31767 L p .707 .577 .707 r
F P
0 g
s
.45048 .81957 m .44455 .31708 L .40579 .31141 L p .707 .577 .707 r
F P
0 g
s
.44455 .31708 m .45048 .81957 L .49448 .82173 L p .707 .577 .707 r
F P
0 g
s
.71938 .77087 m .71112 .80604 L .70859 .7943 L p .707 .577 .707 r
F P
0 g
s
.70859 .7943 m .71684 .75914 L .71938 .77087 L p .707 .577 .707 r
F P
0 g
s
.61486 .80679 m .60893 .3043 L .57497 .31252 L p .707 .577 .707 r
F P
0 g
s
.50262 .85657 m .49684 .83842 L .49467 .83448 L p .707 .577 .707 r
F P
0 g
s
.49467 .83448 m .50045 .85263 L .50262 .85657 L p .707 .577 .707 r
F P
0 g
s
.70042 .67885 m .688 .73158 L .67598 .71872 L p .707 .577 .707 r
F P
0 g
s
.67598 .71872 m .68839 .66598 L .70042 .67885 L p .707 .577 .707 r
F P
0 g
s
.68885 .77646 m .69463 .79461 L .69246 .79067 L p .707 .577 .707 r
F P
0 g
s
.69246 .79067 m .68668 .77252 L .68885 .77646 L p .707 .577 .707 r
F P
0 g
s
.41172 .8139 m .40579 .31141 L .37606 .30277 L p .707 .577 .707 r
F P
0 g
s
.40579 .31141 m .41172 .8139 L .45048 .81957 L p .707 .577 .707 r
F P
0 g
s
.24046 .71764 m .25287 .66491 L .2225 .65604 L p .707 .577 .707 r
F P
0 g
s
.25287 .66491 m .24046 .71764 L .27157 .72315 L p .707 .577 .707 r
F P
0 g
s
.27157 .72315 m .28399 .67041 L .25287 .66491 L p .707 .577 .707 r
F P
0 g
s
.21008 .70878 m .2225 .65604 L .19584 .64469 L p .707 .577 .707 r
F P
0 g
s
.2225 .65604 m .21008 .70878 L .24046 .71764 L p .707 .577 .707 r
F P
0 g
s
.28399 .67041 m .27157 .72315 L .30038 .72475 L p .707 .577 .707 r
F P
0 g
s
.30038 .72475 m .3128 .67202 L .28399 .67041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71684 .75914 m .70859 .7943 L .69657 .78145 L p .707 .577 .707 r
F P
0 g
s
.69657 .78145 m .70482 .74628 L .71684 .75914 L p .707 .577 .707 r
F P
0 g
s
.26104 .7805 m .26929 .74534 L .23891 .73649 L p .707 .577 .707 r
F P
0 g
s
.26929 .74534 m .26104 .7805 L .29216 .78599 L p .707 .577 .707 r
F P
0 g
s
.29216 .78599 m .30041 .75082 L .26929 .74534 L p .707 .577 .707 r
F P
0 g
s
.66806 .65324 m .65564 .70598 L .62898 .69463 L p .707 .577 .707 r
F P
0 g
s
.62898 .69463 m .6414 .64189 L .66806 .65324 L p .707 .577 .707 r
F P
0 g
s
.65781 .72223 m .64956 .7574 L .61918 .74855 L p .707 .577 .707 r
F P
0 g
s
.61918 .74855 m .62744 .71339 L .65781 .72223 L p .707 .577 .707 r
F P
0 g
s
.65559 .77439 m .66137 .79254 L .63549 .79816 L p .707 .577 .707 r
F P
0 g
s
.63549 .79816 m .62971 .78001 L .65559 .77439 L p .707 .577 .707 r
F P
0 g
s
.60893 .3043 m .61486 .80679 L .63797 .7963 L p .707 .577 .707 r
F P
0 g
s
.63797 .7963 m .63204 .29382 L .60893 .3043 L p .707 .577 .707 r
F P
0 g
s
.18342 .69743 m .19584 .64469 L .1755 .63195 L p .707 .577 .707 r
F P
0 g
s
.19584 .64469 m .18342 .69743 L .21008 .70878 L p .707 .577 .707 r
F P
0 g
s
.3128 .67202 m .30038 .72475 L .32407 .7223 L p .707 .577 .707 r
F P
0 g
s
.32407 .7223 m .33648 .66957 L .3128 .67202 L p .707 .577 .707 r
F P
0 g
s
.23066 .77166 m .23891 .73649 L .21225 .72516 L p .707 .577 .707 r
F P
0 g
s
.23891 .73649 m .23066 .77166 L .26104 .7805 L p .707 .577 .707 r
F P
0 g
s
.50045 .85263 m .49467 .83448 L .502 .8277 L p .707 .577 .707 r
F P
0 g
s
.30041 .75082 m .29216 .78599 L .32097 .78758 L p .707 .577 .707 r
F P
0 g
s
.32097 .78758 m .32923 .75242 L .30041 .75082 L p .707 .577 .707 r
F P
0 g
s
.68839 .66598 m .67598 .71872 L .65564 .70598 L p .707 .577 .707 r
F P
0 g
s
.65564 .70598 m .66806 .65324 L .68839 .66598 L p .707 .577 .707 r
F P
0 g
s
.502 .8277 m .50779 .84585 L .50045 .85263 L p .707 .577 .707 r
F P
0 g
s
.68668 .77252 m .69246 .79067 L .681 .78996 L p .707 .577 .707 r
F P
0 g
s
.681 .78996 m .67522 .77181 L .68668 .77252 L p .707 .577 .707 r
F P
0 g
s
.382 .80526 m .37606 .30277 L .35829 .29202 L p .707 .577 .707 r
F P
0 g
s
.37606 .30277 m .382 .80526 L .41172 .8139 L p .707 .577 .707 r
F P
0 g
s
.21225 .72516 m .204 .76033 L .23066 .77166 L p .707 .577 .707 r
F P
0 g
s
.204 .76033 m .21225 .72516 L .19191 .71244 L p .707 .577 .707 r
F P
0 g
s
.32923 .75242 m .32097 .78758 L .34466 .78512 L p .707 .577 .707 r
F P
0 g
s
.34466 .78512 m .35291 .74996 L .32923 .75242 L p .707 .577 .707 r
F P
0 g
s
.70482 .74628 m .69657 .78145 L .67623 .76873 L p .707 .577 .707 r
F P
0 g
s
.67623 .76873 m .68448 .73357 L .70482 .74628 L p .707 .577 .707 r
F P
0 g
s
.1755 .63195 m .16309 .68469 L .18342 .69743 L p .707 .577 .707 r
F P
0 g
s
.24618 .80343 m .2404 .78528 L .21081 .7934 L p .707 .577 .707 r
F P
0 g
s
.2404 .78528 m .24618 .80343 L .27659 .79362 L p .707 .577 .707 r
F P
0 g
s
.27659 .79362 m .27081 .77547 L .2404 .78528 L p .707 .577 .707 r
F P
0 g
s
.16309 .68469 m .1755 .63195 L .16348 .61908 L p .707 .577 .707 r
F P
0 g
s
.27081 .77547 m .27659 .79362 L .30484 .78307 L p .707 .577 .707 r
F P
0 g
s
.30484 .78307 m .29906 .76492 L .27081 .77547 L p .707 .577 .707 r
F P
0 g
s
.33648 .66957 m .32407 .7223 L .34031 .71604 L p .707 .577 .707 r
F P
0 g
s
.34031 .71604 m .35273 .6633 L .33648 .66957 L p .707 .577 .707 r
F P
0 g
s
.21081 .7934 m .21659 .81155 L .24618 .80343 L p .707 .577 .707 r
F P
0 g
s
.19191 .71244 m .18366 .74761 L .204 .76033 L p .707 .577 .707 r
F P
0 g
s
.21659 .81155 m .21081 .7934 L .18493 .79902 L p .707 .577 .707 r
F P
0 g
s
.29906 .76492 m .30484 .78307 L .32817 .77281 L p .707 .577 .707 r
F P
0 g
s
.32817 .77281 m .32239 .75466 L .29906 .76492 L p .707 .577 .707 r
F P
0 g
s
.18493 .79902 m .19071 .81717 L .21659 .81155 L p .707 .577 .707 r
F P
0 g
s
.63204 .29382 m .63797 .7963 L .64797 .78458 L p .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64204 .28209 L .63204 .29382 L p .707 .577 .707 r
F P
0 g
s
.18366 .74761 m .19191 .71244 L .17988 .69959 L p .707 .577 .707 r
F P
0 g
s
.67522 .77181 m .681 .78996 L .66137 .79254 L p .707 .577 .707 r
F P
0 g
s
.66137 .79254 m .65559 .77439 L .67522 .77181 L p .707 .577 .707 r
F P
0 g
s
.35291 .74996 m .34466 .78512 L .36091 .77886 L p .707 .577 .707 r
F P
0 g
s
.36091 .77886 m .36916 .74369 L .35291 .74996 L p .707 .577 .707 r
F P
0 g
s
.68448 .73357 m .67623 .76873 L .64956 .7574 L p .707 .577 .707 r
F P
0 g
s
.64956 .7574 m .65781 .72223 L .68448 .73357 L p .707 .577 .707 r
F P
0 g
s
.16348 .61908 m .15107 .67182 L .16309 .68469 L p .707 .577 .707 r
F P
0 g
s
.19071 .81717 m .18493 .79902 L .1653 .8016 L p .707 .577 .707 r
F P
0 g
s
.15107 .67182 m .16348 .61908 L .16095 .60734 L p .707 .577 .707 r
F P
0 g
s
.35273 .6633 m .34031 .71604 L .34752 .70657 L p .707 .577 .707 r
F P
0 g
s
.34752 .70657 m .35994 .65384 L .35273 .6633 L p .707 .577 .707 r
F P
0 g
s
.17988 .69959 m .17163 .73475 L .18366 .74761 L p .707 .577 .707 r
F P
0 g
s
.1653 .8016 m .17108 .81975 L .19071 .81717 L p .707 .577 .707 r
F P
0 g
s
.32239 .75466 m .32817 .77281 L .34429 .76386 L p .707 .577 .707 r
F P
0 g
s
.34429 .76386 m .33851 .74571 L .32239 .75466 L p .707 .577 .707 r
F P
0 g
s
.36916 .74369 m .36091 .77886 L .36811 .76939 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .35356 .7448 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.37383 .72249 m .3676 .74906 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.3676 .74906 m .36558 .75766 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .3542 .2802 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36181 .70964 L .36568 .71377 L p .707 .577 .707 r
F P
0 g
s
.36568 .71377 m .37383 .72249 L p .36659 .73047 L .707 .577 .707 r
F P
0 g
s
.35356 .7448 m .36568 .71377 L .36659 .73047 L .707 .577 .707 r
F
.35162 .75708 m .34584 .73893 L .33851 .74571 L p F P
0 g
s
.36181 .70964 m .35356 .7448 L .34754 .74104 L p .707 .577 .707 r
F P
0 g
s
.34584 .73893 m .35162 .75708 L .34945 .75314 L p .707 .577 .707 r
F P
0 g
s
.34945 .75314 m .34367 .73499 L .34584 .73893 L p .707 .577 .707 r
F P
0 g
s
.33851 .74571 m .34429 .76386 L .35162 .75708 L p .707 .577 .707 r
F P
0 g
s
.34367 .73499 m .34945 .75314 L .33799 .75243 L p .707 .577 .707 r
F P
0 g
s
.33799 .75243 m .33221 .73428 L .34367 .73499 L p .707 .577 .707 r
F P
0 g
s
.34754 .74104 m .33322 .73209 L p .34793 .72054 L .707 .577 .707 r
F P
0 g
s
.34793 .72054 m .36181 .70964 L .34754 .74104 L .707 .577 .707 r
F
.35994 .65384 m .34752 .70657 L .34499 .69483 L p F P
0 g
s
.33322 .73209 m .34147 .69692 L .36181 .70964 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .36422 .79451 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3542 .2802 m .35756 .56475 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.34499 .69483 m .35741 .64209 L .35994 .65384 L p .707 .577 .707 r
F P
0 g
s
.35756 .56475 m .36013 .78269 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36422 .79451 m .3626 .6573 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.3626 .6573 m .35829 .29202 L p .36096 .62719 L .707 .577 .707 r
F P
0 g
s
.36811 .76939 m .37637 .73422 L .36916 .74369 L p .707 .577 .707 r
F P
0 g
s
.37637 .73422 m .36811 .76939 L .36558 .75766 L p .707 .577 .707 r
F P
0 g
s
.36558 .75766 m .37383 .72249 L .37637 .73422 L p .707 .577 .707 r
F P
0 g
s
.35829 .29202 m .36422 .79451 L .382 .80526 L p .707 .577 .707 r
F P
0 g
s
.36013 .78269 m .35497 .34512 L p .3642 .26848 L .707 .577 .707 r
F P
0 g
s
.35497 .34512 m .3542 .2802 L .35623 .27782 L p .707 .577 .707 r
F P
0 g
s
.35623 .27782 m .3642 .26848 L p .35497 .34512 L .707 .577 .707 r
F P
0 g
s
.17163 .73475 m .17988 .69959 L .17735 .68785 L p .707 .577 .707 r
F P
0 g
s
.16095 .60734 m .14854 .66008 L .15107 .67182 L p .707 .577 .707 r
F P
0 g
s
.17108 .81975 m .1653 .8016 L .15383 .80089 L p .707 .577 .707 r
F P
0 g
s
.15383 .80089 m .15961 .81904 L .17108 .81975 L p .707 .577 .707 r
F P
0 g
s
.17735 .68785 m .1691 .72302 L .17163 .73475 L p .707 .577 .707 r
F P
0 g
s
.14854 .66008 m .16095 .60734 L .16816 .59787 L p .707 .577 .707 r
F P
0 g
s
.64204 .28209 m .64783 .77275 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64204 .28209 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64388 .77276 m .64188 .603 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.64188 .603 m .63795 .27027 L p .64326 .60779 L .707 .577 .707 r
F P
0 g
s
.63795 .27027 m .64388 .77276 L .62611 .76201 L p .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .64116 .55206 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.63128 .61654 m .6378 .58885 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .64369 .5638 L p .63631 .58371 L .707 .577 .707 r
F P
0 g
s
.64369 .5638 m .6378 .58885 L p .6433 .62941 L .707 .577 .707 r
F P
0 g
s
.6378 .58885 m .63128 .61654 L .6398 .62566 L p .707 .577 .707 r
F P
0 g
s
.6398 .62566 m .6433 .62941 L p .6378 .58885 L .707 .577 .707 r
F P
0 g
s
.64797 .78458 m .64388 .77276 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.64783 .77275 m .64797 .78458 L p .64359 .69504 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1691 .72302 m .17735 .68785 L .18456 .67839 L p .707 .577 .707 r
F P
0 g
s
.16816 .59787 m .15575 .65061 L .14854 .66008 L p .707 .577 .707 r
F P
0 g
s
.15961 .81904 m .15383 .80089 L .15166 .79695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15166 .79695 m .15744 .8151 L .15961 .81904 L p .707 .577 .707 r
F P
0 g
s
.18456 .67839 m .17631 .71356 L .1691 .72302 L p .707 .577 .707 r
F P
0 g
s
.15575 .65061 m .16816 .59787 L .1844 .59161 L p .707 .577 .707 r
F P
0 g
s
.35741 .64209 m .34499 .69483 L .33297 .68196 L p .707 .577 .707 r
F P
0 g
s
.33297 .68196 m .34539 .62922 L .35741 .64209 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62611 .76201 m .62017 .25952 L .63795 .27027 L p .707 .577 .707 r
F P
0 g
s
.17631 .71356 m .18456 .67839 L .2008 .67212 L p .707 .577 .707 r
F P
0 g
s
.1844 .59161 m .17199 .64435 L .15575 .65061 L p .707 .577 .707 r
F P
0 g
s
.17199 .64435 m .1844 .59161 L .20809 .58916 L p .707 .577 .707 r
F P
0 g
s
.15744 .8151 m .15166 .79695 L .159 .79018 L p .707 .577 .707 r
F P
0 g
s
.34539 .62922 m .33297 .68196 L .31263 .66923 L p .707 .577 .707 r
F P
0 g
s
.31263 .66923 m .32505 .61649 L .34539 .62922 L p .707 .577 .707 r
F P
0 g
s
.2008 .67212 m .19255 .70729 L .17631 .71356 L p .707 .577 .707 r
F P
0 g
s
.159 .79018 m .16478 .80833 L .15744 .8151 L p .707 .577 .707 r
F P
0 g
s
.37013 .77096 m .3642 .26848 L .38731 .25799 L p .707 .577 .707 r
F P
0 g
s
.3642 .26848 m .37013 .77096 L .36013 .78269 L p .707 .577 .707 r
F P
0 g
s
.19255 .70729 m .2008 .67212 L .22449 .66966 L p .707 .577 .707 r
F P
0 g
s
.20809 .58916 m .19567 .6419 L .17199 .64435 L p .707 .577 .707 r
F P
0 g
s
.19567 .6419 m .20809 .58916 L .2369 .59077 L p .707 .577 .707 r
F P
0 g
s
.32505 .61649 m .31263 .66923 L .28597 .65787 L p .707 .577 .707 r
F P
0 g
s
.28597 .65787 m .29839 .60513 L .32505 .61649 L p .707 .577 .707 r
F P
0 g
s
.62017 .25952 m .62611 .76201 L .59638 .75337 L p .707 .577 .707 r
F P
0 g
s
.59638 .75337 m .59045 .25088 L .62017 .25952 L p .707 .577 .707 r
F P
0 g
s
.22449 .66966 m .21624 .70483 L .19255 .70729 L p .707 .577 .707 r
F P
0 g
s
.16478 .80833 m .159 .79018 L .17511 .78122 L p .707 .577 .707 r
F P
0 g
s
.17511 .78122 m .1809 .79937 L .16478 .80833 L p .707 .577 .707 r
F P
0 g
s
.22448 .6435 m .2369 .59077 L .26802 .59627 L p .707 .577 .707 r
F P
0 g
s
.2369 .59077 m .22448 .6435 L .19567 .6419 L p .707 .577 .707 r
F P
0 g
s
.29839 .60513 m .28597 .65787 L .2556 .64901 L p .707 .577 .707 r
F P
0 g
s
.2556 .64901 m .26802 .59627 L .29839 .60513 L p .707 .577 .707 r
F P
0 g
s
.33221 .73428 m .33799 .75243 L .31836 .75501 L p .707 .577 .707 r
F P
0 g
s
.31836 .75501 m .31258 .73686 L .33221 .73428 L p .707 .577 .707 r
F P
0 g
s
.21624 .70483 m .22449 .66966 L .25331 .67126 L p .707 .577 .707 r
F P
0 g
s
.34147 .69692 m .33322 .73209 L .30655 .72075 L p .707 .577 .707 r
F P
0 g
s
.30655 .72075 m .31481 .68558 L .34147 .69692 L p .707 .577 .707 r
F P
0 g
s
.26802 .59627 m .2556 .64901 L .22448 .6435 L p .707 .577 .707 r
F P
0 g
s
.38731 .25799 m .39324 .76048 L .37013 .77096 L p .707 .577 .707 r
F P
0 g
s
.39324 .76048 m .38731 .25799 L .42127 .24977 L p .707 .577 .707 r
F P
0 g
s
.72067 .66236 m .73308 .60962 L .70271 .60076 L p .707 .577 .707 r
F P
0 g
s
.73308 .60962 m .72067 .66236 L .75179 .66786 L p .707 .577 .707 r
F P
0 g
s
.75179 .66786 m .7642 .61513 L .73308 .60962 L p .707 .577 .707 r
F P
0 g
s
.25331 .67126 m .24505 .70642 L .21624 .70483 L p .707 .577 .707 r
F P
0 g
s
.24505 .70642 m .25331 .67126 L .28443 .67674 L p .707 .577 .707 r
F P
0 g
s
.6903 .6535 m .70271 .60076 L .67605 .58941 L p .707 .577 .707 r
F P
0 g
s
.70271 .60076 m .6903 .6535 L .72067 .66236 L p .707 .577 .707 r
F P
0 g
s
.31481 .68558 m .30655 .72075 L .27617 .71191 L p .707 .577 .707 r
F P
0 g
s
.27617 .71191 m .28443 .67674 L .31481 .68558 L p .707 .577 .707 r
F P
0 g
s
.7642 .61513 m .75179 .66786 L .7806 .66947 L p .707 .577 .707 r
F P
0 g
s
.7806 .66947 m .79301 .61673 L .7642 .61513 L p .707 .577 .707 r
F P
0 g
s
.28443 .67674 m .27617 .71191 L .24505 .70642 L p .707 .577 .707 r
F P
0 g
s
.1809 .79937 m .17511 .78122 L .19844 .77097 L p .707 .577 .707 r
F P
0 g
s
.19844 .77097 m .20422 .78912 L .1809 .79937 L p .707 .577 .707 r
F P
0 g
s
.31258 .73686 m .31836 .75501 L .29248 .76064 L p .707 .577 .707 r
F P
0 g
s
.29248 .76064 m .2867 .74249 L .31258 .73686 L p .707 .577 .707 r
F P
0 g
s
.59045 .25088 m .59638 .75337 L .55762 .7477 L p .707 .577 .707 r
F P
0 g
s
.55762 .7477 m .55169 .24521 L .59045 .25088 L p .707 .577 .707 r
F P
0 g
s
.74125 .72511 m .7495 .68995 L .71913 .6811 L p .707 .577 .707 r
F P
0 g
s
.7495 .68995 m .74125 .72511 L .77237 .7306 L p .707 .577 .707 r
F P
0 g
s
.77237 .7306 m .78062 .69543 L .7495 .68995 L p .707 .577 .707 r
F P
0 g
s
.66364 .64214 m .67605 .58941 L .65571 .57667 L p .707 .577 .707 r
F P
0 g
s
.67605 .58941 m .66364 .64214 L .6903 .6535 L p .707 .577 .707 r
F P
0 g
s
.79301 .61673 m .7806 .66947 L .80428 .66702 L p .707 .577 .707 r
F P
0 g
s
.80428 .66702 m .8167 .61428 L .79301 .61673 L p .707 .577 .707 r
F P
0 g
s
.71087 .71627 m .71913 .6811 L .69246 .66977 L p .707 .577 .707 r
F P
0 g
s
.71913 .6811 m .71087 .71627 L .74125 .72511 L p .707 .577 .707 r
F P
0 g
s
.78062 .69543 m .77237 .7306 L .80119 .73219 L p .707 .577 .707 r
F P
0 g
s
.80119 .73219 m .80944 .69702 L .78062 .69543 L p .707 .577 .707 r
F P
0 g
s
.4272 .75226 m .42127 .24977 L .46274 .24463 L p .707 .577 .707 r
F P
0 g
s
.42127 .24977 m .4272 .75226 L .39324 .76048 L p .707 .577 .707 r
F P
0 g
s
.20422 .78912 m .19844 .77097 L .22669 .76042 L p .707 .577 .707 r
F P
0 g
s
.2867 .74249 m .29248 .76064 L .26289 .76875 L p .707 .577 .707 r
F P
0 g
s
.26289 .76875 m .2571 .7506 L .2867 .74249 L p .707 .577 .707 r
F P
0 g
s
.22669 .76042 m .23247 .77857 L .20422 .78912 L p .707 .577 .707 r
F P
0 g
s
.69246 .66977 m .68421 .70493 L .71087 .71627 L p .707 .577 .707 r
F P
0 g
s
.68421 .70493 m .69246 .66977 L .67212 .65705 L p .707 .577 .707 r
F P
0 g
s
.80944 .69702 m .80119 .73219 L .82488 .72973 L p .707 .577 .707 r
F P
0 g
s
.82488 .72973 m .83313 .69456 L .80944 .69702 L p .707 .577 .707 r
F P
0 g
s
.55169 .24521 m .55762 .7477 L .51362 .74554 L p .707 .577 .707 r
F P
0 g
s
.51362 .74554 m .50769 .24305 L .55169 .24521 L p .707 .577 .707 r
F P
0 g
s
.65571 .57667 m .6433 .62941 L .66364 .64214 L p .707 .577 .707 r
F P
0 g
s
.72639 .74892 m .72061 .73077 L .69102 .73889 L p .707 .577 .707 r
F P
0 g
s
.72061 .73077 m .72639 .74892 L .7568 .73911 L p .707 .577 .707 r
F P
0 g
s
.7568 .73911 m .75102 .72096 L .72061 .73077 L p .707 .577 .707 r
F P
0 g
s
.6433 .62941 m .65571 .57667 L .64369 .5638 L p .707 .577 .707 r
F P
0 g
s
.75102 .72096 m .7568 .73911 L .78506 .72856 L p .707 .577 .707 r
F P
0 g
s
.78506 .72856 m .77927 .71041 L .75102 .72096 L p .707 .577 .707 r
F P
0 g
s
.8167 .61428 m .80428 .66702 L .82053 .66076 L p .707 .577 .707 r
F P
0 g
s
.82053 .66076 m .83294 .60802 L .8167 .61428 L p .707 .577 .707 r
F P
0 g
s
.23247 .77857 m .22669 .76042 L .2571 .7506 L p .707 .577 .707 r
F P
0 g
s
.2571 .7506 m .26289 .76875 L .23247 .77857 L p .707 .577 .707 r
F P
0 g
s
.69102 .73889 m .6968 .75704 L .72639 .74892 L p .707 .577 .707 r
F P
0 g
s
.46868 .74711 m .46274 .24463 L .50769 .24305 L p .707 .577 .707 r
F P
0 g
s
.46274 .24463 m .46868 .74711 L .4272 .75226 L p .707 .577 .707 r
F P
0 g
s
.67212 .65705 m .66387 .69222 L .68421 .70493 L p .707 .577 .707 r
F P
0 g
s
.50769 .24305 m .51362 .74554 L .46868 .74711 L p .707 .577 .707 r
F P
0 g
s
.6968 .75704 m .69102 .73889 L .66514 .74451 L p .707 .577 .707 r
F P
0 g
s
.77927 .71041 m .78506 .72856 L .80838 .7183 L p .707 .577 .707 r
F P
0 g
s
.80838 .7183 m .8026 .70015 L .77927 .71041 L p .707 .577 .707 r
F P
0 g
s
.66514 .74451 m .67092 .76266 L .6968 .75704 L p .707 .577 .707 r
F P
0 g
s
.66387 .69222 m .67212 .65705 L .6601 .6442 L p .707 .577 .707 r
F P
0 g
s
.83313 .69456 m .82488 .72973 L .84112 .72346 L p .707 .577 .707 r
F P
0 g
s
.84112 .72346 m .84937 .6883 L .83313 .69456 L p .707 .577 .707 r
F P
0 g
s
.67092 .76266 m .66514 .74451 L .64551 .74709 L p .707 .577 .707 r
F P
0 g
s
.83294 .60802 m .82053 .66076 L .82774 .65129 L p .707 .577 .707 r
F P
0 g
s
.82774 .65129 m .84015 .59855 L .83294 .60802 L p .707 .577 .707 r
F P
0 g
s
.6601 .6442 m .65184 .67936 L .66387 .69222 L p .707 .577 .707 r
F P
0 g
s
.64551 .74709 m .65129 .76524 L .67092 .76266 L p .707 .577 .707 r
F P
0 g
s
.8026 .70015 m .80838 .7183 L .8245 .70935 L p .707 .577 .707 r
F P
0 g
s
.8245 .70935 m .81872 .6912 L .8026 .70015 L p .707 .577 .707 r
F P
0 g
s
.65184 .67936 m .6601 .6442 L .65756 .63246 L p .707 .577 .707 r
F P
0 g
s
.84937 .6883 m .84112 .72346 L .84833 .714 L p .707 .577 .707 r
F P
0 g
s
.84833 .714 m .85658 .67883 L .84937 .6883 L p .707 .577 .707 r
F P
0 g
s
.64116 .55206 m .62875 .6048 L .63128 .61654 L p .707 .577 .707 r
F P
0 g
s
.65129 .76524 m .64551 .74709 L .63405 .74638 L p .707 .577 .707 r
F P
0 g
s
.63405 .74638 m .63983 .76453 L .65129 .76524 L p .707 .577 .707 r
F P
0 g
s
.65756 .63246 m .64931 .66763 L .65184 .67936 L p .707 .577 .707 r
F P
0 g
s
.62875 .6048 m .64116 .55206 L .64837 .54259 L p .707 .577 .707 r
F P
0 g
s
.81872 .6912 m .8245 .70935 L .83184 .70257 L p .707 .577 .707 r
F P
0 g
s
.83184 .70257 m .82605 .68442 L .81872 .6912 L p .707 .577 .707 r
F P
0 g
s
.84015 .59855 m .82774 .65129 L .82521 .63955 L p .707 .577 .707 r
F P
0 g
s
.82521 .63955 m .83762 .58681 L .84015 .59855 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64931 .66763 m .65756 .63246 L .66477 .623 L p .707 .577 .707 r
F P
0 g
s
.85658 .67883 m .84833 .714 L .8458 .70227 L p .707 .577 .707 r
F P
0 g
s
.8458 .70227 m .85405 .6671 L .85658 .67883 L p .707 .577 .707 r
F P
0 g
s
.64837 .54259 m .63596 .59533 L .62875 .6048 L p .707 .577 .707 r
F P
0 g
s
.63983 .76453 m .63405 .74638 L .63188 .74244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63188 .74244 m .63766 .76059 L .63983 .76453 L p .707 .577 .707 r
F P
0 g
s
.66477 .623 m .65652 .65816 L .64931 .66763 L p .707 .577 .707 r
F P
0 g
s
.63596 .59533 m .64837 .54259 L .66462 .53633 L p .707 .577 .707 r
F P
0 g
s
.83762 .58681 m .82521 .63955 L .81318 .62668 L p .707 .577 .707 r
F P
0 g
s
.81318 .62668 m .8256 .57394 L .83762 .58681 L p .707 .577 .707 r
F P
0 g
s
.82605 .68442 m .83184 .70257 L .82967 .69863 L p .707 .577 .707 r
F P
0 g
s
.82967 .69863 m .82388 .68048 L .82605 .68442 L p .707 .577 .707 r
F P
0 g
s
.37766 .62561 m .39007 .57287 L .3597 .564 L p .707 .577 .707 r
F P
0 g
s
.39007 .57287 m .37766 .62561 L .40878 .63111 L p .707 .577 .707 r
F P
0 g
s
.40878 .63111 m .42119 .57837 L .39007 .57287 L p .707 .577 .707 r
F P
0 g
s
.34729 .61674 m .3597 .564 L .33304 .55265 L p .707 .577 .707 r
F P
0 g
s
.3597 .564 m .34729 .61674 L .37766 .62561 L p .707 .577 .707 r
F P
0 g
s
.42119 .57837 m .40878 .63111 L .43759 .63271 L p .707 .577 .707 r
F P
0 g
s
.43759 .63271 m .45 .57998 L .42119 .57837 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65652 .65816 m .66477 .623 L .68102 .61673 L p .707 .577 .707 r
F P
0 g
s
.85405 .6671 m .8458 .70227 L .83377 .68941 L p .707 .577 .707 r
F P
0 g
s
.83377 .68941 m .84202 .65424 L .85405 .6671 L p .707 .577 .707 r
F P
0 g
s
.66462 .53633 m .6522 .58906 L .63596 .59533 L p .707 .577 .707 r
F P
0 g
s
.39824 .68847 m .4065 .6533 L .37612 .64446 L p .707 .577 .707 r
F P
0 g
s
.4065 .6533 m .39824 .68847 L .42936 .69395 L p .707 .577 .707 r
F P
0 g
s
.42936 .69395 m .43762 .65879 L .4065 .6533 L p .707 .577 .707 r
F P
0 g
s
.32063 .60539 m .33304 .55265 L .3127 .53991 L p .707 .577 .707 r
F P
0 g
s
.33304 .55265 m .32063 .60539 L .34729 .61674 L p .707 .577 .707 r
F P
0 g
s
.45 .57998 m .43759 .63271 L .46127 .63027 L p .707 .577 .707 r
F P
0 g
s
.46127 .63027 m .47369 .57753 L .45 .57998 L p .707 .577 .707 r
F P
0 g
s
.6522 .58906 m .66462 .53633 L .6883 .53388 L p .707 .577 .707 r
F P
0 g
s
.36786 .67962 m .37612 .64446 L .34945 .63312 L p .707 .577 .707 r
F P
0 g
s
.37612 .64446 m .36786 .67962 L .39824 .68847 L p .707 .577 .707 r
F P
0 g
s
.63766 .76059 m .63188 .74244 L .63921 .73567 L p .707 .577 .707 r
F P
0 g
s
.43762 .65879 m .42936 .69395 L .45818 .69554 L p .707 .577 .707 r
F P
0 g
s
.45818 .69554 m .46643 .66038 L .43762 .65879 L p .707 .577 .707 r
F P
0 g
s
.8256 .57394 m .81318 .62668 L .79285 .61394 L p .707 .577 .707 r
F P
0 g
s
.79285 .61394 m .80526 .5612 L .8256 .57394 L p .707 .577 .707 r
F P
0 g
s
.68102 .61673 m .67277 .6519 L .65652 .65816 L p .707 .577 .707 r
F P
0 g
s
.63921 .73567 m .64499 .75382 L .63766 .76059 L p .707 .577 .707 r
F P
0 g
s
.82388 .68048 m .82967 .69863 L .8182 .69792 L p .707 .577 .707 r
F P
0 g
s
.8182 .69792 m .81242 .67977 L .82388 .68048 L p .707 .577 .707 r
F P
0 g
s
.34945 .63312 m .3412 .66829 L .36786 .67962 L p .707 .577 .707 r
F P
0 g
s
.3412 .66829 m .34945 .63312 L .32911 .6204 L p .707 .577 .707 r
F P
0 g
s
.46643 .66038 m .45818 .69554 L .48187 .69308 L p .707 .577 .707 r
F P
0 g
s
.48187 .69308 m .49012 .65792 L .46643 .66038 L p .707 .577 .707 r
F P
0 g
s
.67277 .6519 m .68102 .61673 L .70471 .61427 L p .707 .577 .707 r
F P
0 g
s
.84202 .65424 m .83377 .68941 L .81343 .67669 L p .707 .577 .707 r
F P
0 g
s
.81343 .67669 m .82168 .64153 L .84202 .65424 L p .707 .577 .707 r
F P
0 g
s
.3127 .53991 m .30029 .59265 L .32063 .60539 L p .707 .577 .707 r
F P
0 g
s
.38338 .71139 m .3776 .69324 L .34801 .70136 L p .707 .577 .707 r
F P
0 g
s
.3776 .69324 m .38338 .71139 L .41379 .70158 L p .707 .577 .707 r
F P
0 g
s
.41379 .70158 m .40801 .68343 L .3776 .69324 L p .707 .577 .707 r
F P
0 g
s
.30029 .59265 m .3127 .53991 L .30068 .52705 L p .707 .577 .707 r
F P
0 g
s
.40801 .68343 m .41379 .70158 L .44205 .69103 L p .707 .577 .707 r
F P
0 g
s
.44205 .69103 m .43627 .67288 L .40801 .68343 L p .707 .577 .707 r
F P
0 g
s
.6883 .53388 m .67589 .58661 L .6522 .58906 L p .707 .577 .707 r
F P
0 g
s
.47369 .57753 m .46127 .63027 L .47752 .624 L p .707 .577 .707 r
F P
0 g
s
.47752 .624 m .48993 .57126 L .47369 .57753 L p .707 .577 .707 r
F P
0 g
s
.67589 .58661 m .6883 .53388 L .71711 .53548 L p .707 .577 .707 r
F P
0 g
s
.34801 .70136 m .35379 .71951 L .38338 .71139 L p .707 .577 .707 r
F P
0 g
s
.80526 .5612 m .79285 .61394 L .76619 .60259 L p .707 .577 .707 r
F P
0 g
s
.76619 .60259 m .7786 .54985 L .80526 .5612 L p .707 .577 .707 r
F P
0 g
s
.32911 .6204 m .32086 .65557 L .3412 .66829 L p .707 .577 .707 r
F P
0 g
s
.35379 .71951 m .34801 .70136 L .32213 .70698 L p .707 .577 .707 r
F P
0 g
s
.70471 .61427 m .69645 .64944 L .67277 .6519 L p .707 .577 .707 r
F P
0 g
s
.43627 .67288 m .44205 .69103 L .46537 .68077 L p .707 .577 .707 r
F P
0 g
s
.46537 .68077 m .45959 .66262 L .43627 .67288 L p .707 .577 .707 r
F P
0 g
s
.32213 .70698 m .32791 .72513 L .35379 .71951 L p .707 .577 .707 r
F P
0 g
s
.64499 .75382 m .63921 .73567 L .65533 .72671 L p .707 .577 .707 r
F P
0 g
s
.65533 .72671 m .66111 .74486 L .64499 .75382 L p .707 .577 .707 r
F P
0 g
s
.32086 .65557 m .32911 .6204 L .31709 .60755 L p .707 .577 .707 r
F P
0 g
s
.7047 .58822 m .71711 .53548 L .74823 .54099 L p .707 .577 .707 r
F P
0 g
s
.71711 .53548 m .7047 .58822 L .67589 .58661 L p .707 .577 .707 r
F P
0 g
s
.7786 .54985 m .76619 .60259 L .73581 .59372 L p .707 .577 .707 r
F P
0 g
s
.73581 .59372 m .74823 .54099 L .7786 .54985 L p .707 .577 .707 r
F P
0 g
s
.81242 .67977 m .8182 .69792 L .79857 .7005 L p .707 .577 .707 r
F P
0 g
s
.79857 .7005 m .79279 .68235 L .81242 .67977 L p .707 .577 .707 r
F P
0 g
s
.49012 .65792 m .48187 .69308 L .49811 .68682 L p .707 .577 .707 r
F P
0 g
s
.49811 .68682 m .50636 .65165 L .49012 .65792 L p .707 .577 .707 r
F P
0 g
s
.69645 .64944 m .70471 .61427 L .73352 .61586 L p .707 .577 .707 r
F P
0 g
s
.82168 .64153 m .81343 .67669 L .78677 .66536 L p .707 .577 .707 r
F P
0 g
s
.78677 .66536 m .79502 .63019 L .82168 .64153 L p .707 .577 .707 r
F P
0 g
s
.30068 .52705 m .28827 .57978 L .30029 .59265 L p .707 .577 .707 r
F P
0 g
s
.74823 .54099 m .73581 .59372 L .7047 .58822 L p .707 .577 .707 r
F P
0 g
s
.32791 .72513 m .32213 .70698 L .3025 .70957 L p .707 .577 .707 r
F P
0 g
s
.28827 .57978 m .30068 .52705 L .29815 .5153 L p .707 .577 .707 r
F P
0 g
s
.48993 .57126 m .47752 .624 L .48473 .61453 L p .707 .577 .707 r
F P
0 g
s
.48473 .61453 m .49714 .5618 L .48993 .57126 L p .707 .577 .707 r
F P
0 g
s
.31709 .60755 m .30883 .64272 L .32086 .65557 L p .707 .577 .707 r
F P
0 g
s
.3025 .70957 m .30828 .72772 L .32791 .72513 L p .707 .577 .707 r
F P
0 g
s
.45959 .66262 m .46537 .68077 L .48149 .67182 L p .707 .577 .707 r
F P
0 g
s
.48149 .67182 m .47571 .65367 L .45959 .66262 L p .707 .577 .707 r
F P
0 g
s
.73352 .61586 m .72527 .65103 L .69645 .64944 L p .707 .577 .707 r
F P
0 g
s
.72527 .65103 m .73352 .61586 L .76464 .62135 L p .707 .577 .707 r
F P
0 g
s
.79502 .63019 m .78677 .66536 L .75639 .65652 L p .707 .577 .707 r
F P
0 g
s
.75639 .65652 m .76464 .62135 L .79502 .63019 L p .707 .577 .707 r
F P
0 g
s
.76464 .62135 m .75639 .65652 L .72527 .65103 L p .707 .577 .707 r
F P
0 g
s
.66111 .74486 m .65533 .72671 L .67866 .71646 L p .707 .577 .707 r
F P
0 g
s
.67866 .71646 m .68444 .73461 L .66111 .74486 L p .707 .577 .707 r
F P
0 g
s
.79279 .68235 m .79857 .7005 L .77269 .70613 L p .707 .577 .707 r
F P
0 g
s
.77269 .70613 m .76691 .68798 L .79279 .68235 L p .707 .577 .707 r
F P
0 g
s
.30883 .64272 m .31709 .60755 L .31455 .59582 L p .707 .577 .707 r
F P
0 g
s
.50636 .65165 m .49811 .68682 L .50532 .67735 L p .707 .577 .707 r
F P
0 g
s
.50532 .67735 m .51357 .64219 L .50636 .65165 L p .707 .577 .707 r
F P
0 g
s
.29815 .5153 m .28574 .56804 L .28827 .57978 L p .707 .577 .707 r
F P
0 g
s
.30828 .72772 m .3025 .70957 L .29104 .70885 L p .707 .577 .707 r
F P
0 g
s
.29104 .70885 m .29682 .727 L .30828 .72772 L p .707 .577 .707 r
F P
0 g
s
.31455 .59582 m .3063 .63098 L .30883 .64272 L p .707 .577 .707 r
F P
0 g
s
.28574 .56804 m .29815 .5153 L .30536 .50584 L p .707 .577 .707 r
F P
0 g
s
.47571 .65367 m .48149 .67182 L .48883 .66504 L p .707 .577 .707 r
F P
0 g
s
.48883 .66504 m .48304 .64689 L .47571 .65367 L p .707 .577 .707 r
F P
0 g
s
.68444 .73461 m .67866 .71646 L .70691 .70591 L p .707 .577 .707 r
F P
0 g
s
.49714 .5618 m .48473 .61453 L .4822 .60279 L p .707 .577 .707 r
F P
0 g
s
.4822 .60279 m .49461 .55005 L .49714 .5618 L p .707 .577 .707 r
F P
0 g
s
.76691 .68798 m .77269 .70613 L .7431 .71424 L p .707 .577 .707 r
F P
0 g
s
.7431 .71424 m .73732 .69609 L .76691 .68798 L p .707 .577 .707 r
F P
0 g
s
.70691 .70591 m .71269 .72406 L .68444 .73461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71269 .72406 m .70691 .70591 L .73732 .69609 L p .707 .577 .707 r
F P
0 g
s
.73732 .69609 m .7431 .71424 L .71269 .72406 L p .707 .577 .707 r
F P
0 g
s
.3063 .63098 m .31455 .59582 L .32176 .58635 L p .707 .577 .707 r
F P
0 g
s
.51357 .64219 m .50532 .67735 L .50279 .66562 L p .707 .577 .707 r
F P
0 g
s
.50279 .66562 m .51104 .63045 L .51357 .64219 L p .707 .577 .707 r
F P
0 g
s
.30536 .50584 m .29295 .55857 L .28574 .56804 L p .707 .577 .707 r
F P
0 g
s
.29682 .727 m .29104 .70885 L .28887 .70491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28887 .70491 m .29465 .72306 L .29682 .727 L p .707 .577 .707 r
F P
0 g
s
.32176 .58635 m .31351 .62152 L .3063 .63098 L p .707 .577 .707 r
F P
0 g
s
.29295 .55857 m .30536 .50584 L .32161 .49957 L p .707 .577 .707 r
F P
0 g
s
.48304 .64689 m .48883 .66504 L .48666 .6611 L p .707 .577 .707 r
F P
0 g
s
.48666 .6611 m .48087 .64295 L .48304 .64689 L p .707 .577 .707 r
F P
0 g
s
.49461 .55005 m .4822 .60279 L .47017 .58992 L p .707 .577 .707 r
F P
0 g
s
.47017 .58992 m .48259 .53718 L .49461 .55005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31351 .62152 m .32176 .58635 L .33801 .58008 L p .707 .577 .707 r
F P
0 g
s
.51104 .63045 m .50279 .66562 L .49076 .65276 L p .707 .577 .707 r
F P
0 g
s
.49076 .65276 m .49901 .6176 L .51104 .63045 L p .707 .577 .707 r
F P
0 g
s
.32161 .49957 m .30919 .55231 L .29295 .55857 L p .707 .577 .707 r
F P
0 g
s
.30919 .55231 m .32161 .49957 L .34529 .49712 L p .707 .577 .707 r
F P
0 g
s
.29465 .72306 m .28887 .70491 L .2962 .69814 L p .707 .577 .707 r
F P
0 g
s
.48259 .53718 m .47017 .58992 L .44984 .57719 L p .707 .577 .707 r
F P
0 g
s
.44984 .57719 m .46225 .52445 L .48259 .53718 L p .707 .577 .707 r
F P
0 g
s
.33801 .58008 m .32975 .61525 L .31351 .62152 L p .707 .577 .707 r
F P
0 g
s
.2962 .69814 m .30198 .71629 L .29465 .72306 L p .707 .577 .707 r
F P
0 g
s
.48087 .64295 m .48666 .6611 L .47519 .66039 L p .707 .577 .707 r
F P
0 g
s
.47519 .66039 m .46941 .64224 L .48087 .64295 L p .707 .577 .707 r
F P
0 g
s
.32975 .61525 m .33801 .58008 L .3617 .57762 L p .707 .577 .707 r
F P
0 g
s
.49901 .6176 m .49076 .65276 L .47042 .64005 L p .707 .577 .707 r
F P
0 g
s
.47042 .64005 m .47867 .60488 L .49901 .6176 L p .707 .577 .707 r
F P
0 g
s
.34529 .49712 m .33288 .54986 L .30919 .55231 L p .707 .577 .707 r
F P
0 g
s
.33288 .54986 m .34529 .49712 L .3741 .49873 L p .707 .577 .707 r
F P
0 g
s
.46225 .52445 m .44984 .57719 L .42318 .56583 L p .707 .577 .707 r
F P
0 g
s
.42318 .56583 m .43559 .51309 L .46225 .52445 L p .707 .577 .707 r
F P
0 g
s
.3617 .57762 m .35344 .61279 L .32975 .61525 L p .707 .577 .707 r
F P
0 g
s
.30198 .71629 m .2962 .69814 L .31232 .68918 L p .707 .577 .707 r
F P
0 g
s
.31232 .68918 m .3181 .70733 L .30198 .71629 L p .707 .577 .707 r
F P
0 g
s
.36169 .55146 m .3741 .49873 L .40522 .50423 L p .707 .577 .707 r
F P
0 g
s
.3741 .49873 m .36169 .55146 L .33288 .54986 L p .707 .577 .707 r
F P
0 g
s
.43559 .51309 m .42318 .56583 L .3928 .55697 L p .707 .577 .707 r
F P
0 g
s
.3928 .55697 m .40522 .50423 L .43559 .51309 L p .707 .577 .707 r
F P
0 g
s
.46941 .64224 m .47519 .66039 L .45556 .66297 L p .707 .577 .707 r
F P
0 g
s
.45556 .66297 m .44978 .64482 L .46941 .64224 L p .707 .577 .707 r
F P
0 g
s
.35344 .61279 m .3617 .57762 L .39051 .57922 L p .707 .577 .707 r
F P
0 g
s
.47867 .60488 m .47042 .64005 L .44376 .62871 L p .707 .577 .707 r
F P
0 g
s
.44376 .62871 m .45201 .59355 L .47867 .60488 L p .707 .577 .707 r
F P
0 g
s
.40522 .50423 m .3928 .55697 L .36169 .55146 L p .707 .577 .707 r
F P
0 g
s
.39051 .57922 m .38226 .61438 L .35344 .61279 L p .707 .577 .707 r
F P
0 g
s
.38226 .61438 m .39051 .57922 L .42163 .5847 L p .707 .577 .707 r
F P
0 g
s
.45201 .59355 m .44376 .62871 L .41338 .61987 L p .707 .577 .707 r
F P
0 g
s
.41338 .61987 m .42163 .5847 L .45201 .59355 L p .707 .577 .707 r
F P
0 g
s
.42163 .5847 m .41338 .61987 L .38226 .61438 L p .707 .577 .707 r
F P
0 g
s
.3181 .70733 m .31232 .68918 L .33564 .67893 L p .707 .577 .707 r
F P
0 g
s
.33564 .67893 m .34143 .69708 L .3181 .70733 L p .707 .577 .707 r
F P
0 g
s
.44978 .64482 m .45556 .66297 L .42968 .6686 L p .707 .577 .707 r
F P
0 g
s
.42968 .6686 m .4239 .65045 L .44978 .64482 L p .707 .577 .707 r
F P
0 g
s
.34143 .69708 m .33564 .67893 L .3639 .66838 L p .707 .577 .707 r
F P
0 g
s
.4239 .65045 m .42968 .6686 L .40009 .67671 L p .707 .577 .707 r
F P
0 g
s
.40009 .67671 m .39431 .65856 L .4239 .65045 L p .707 .577 .707 r
F P
0 g
s
.3639 .66838 m .36968 .68653 L .34143 .69708 L p .707 .577 .707 r
F P
0 g
s
.36968 .68653 m .3639 .66838 L .39431 .65856 L p .707 .577 .707 r
F P
0 g
s
.39431 .65856 m .40009 .67671 L .36968 .68653 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol200000eYF
001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Ao
o`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYF
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001UOol006Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol0
06Aoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol005moo`h00003FUH005YF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Eoo`00FGoo1P000eYF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IGoo001FOol30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`80
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
008000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Eoo`00Dgoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`L005Ioo`00Dgoo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo
10000eYF00@005YFFUIJEPT004eoo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P00Agoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020014Ool0059oo`03001JEP00
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH30011Ool0059oo`8000=JEP04001JEUYFFUH>0007FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`00?Woo001BOol20002FUH50003FUH20005Ool00`00FUIJEP050002
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003aoo`00DWoo00IJEP00
000005YF0006FUH01000FUH000000goo00@005YFFUH000AJEPD000IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP8003Yoo`00DGoo0P0015YF00<005YFFUH015YF00@005YFFUIJEP@0
009JEP03001JEUYF00AJEPL0009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000hOol0055oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP@000EJEPD000=JEP<000MJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00DGoo0P000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YF00000`000UYF1@001EYF0`001EYF00<005YFFUH015YF00D005YFFUIJEP0000EJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EP00=Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70005FUH0
0`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<goo001AOol0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70003FUH00`00FUIJ
EP02FUH30006FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo031oo`00DGoo00<005YFFUH0
0UYF00<005YFFUH015YF00<005YF00004@0015YF2`001UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2
000aOol0059oo`05001JEUYFFUH00005FUH300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH00`00FUIJEP05FUH30004FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000002moo`00
Dgoo00<005YF00001EYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1@00
1EYF00<005YFFUH00P0000=JEP00FUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUIJEP0000=JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool003Qoo`L0
01Eoo`8000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00D000EJEP8000AJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EP0000AJEPD0009JEP<0009oo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo02aoo`00<goo1@000eYF00@005YFFUIJEPT000eoo`03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
00AJEP8000=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00
001JEP0200000eYF001JEP05FUH01000FUH000002Goo1P001eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8002ioo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P0027oo0P0000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF0`000UYF00@005YF001JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF009JEP8000]oo`@000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002moo`80009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000008Ool30003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP030002FUH30006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH015YF00<0
05YFFUH015YF0`001goo200000=JEP00FUH01eYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`00
1Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P000UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF1000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF00000P0017oo1@000goo0`001eYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002Ool00`00FUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH300000goo000000030006Ool20004FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0002ioo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPH000Qo
o`<00003FUH005YF00EJEP04001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUHB0006FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH015YF1`0015YF00<005YFFUH0
0UYF20000goo0P001UYF00@005YFFUIJEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP000000
17oo10001UYF00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUH000040003FUH01000FUIJEUYF2@0015YF00@005YFFUIJEPL000AJEP04001JEUYF
FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000Ioo`@0009JEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH00`00FUIJEP04FUH200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60006FUH01000FUIJEP000UYF00L005YFFUIJEP00FUH0000_Ool002aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH20004FUH40004Ool00`00FUIJEP060006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YF001JEP0000aJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH20005FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000
0eYF00<005YFFUH00UYF0`000eYF00<005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00`00
0Woo00@005YFFUH000EJEP@0009JEP03001JEUYF00EJEP<000MJEP03001JEUYF00=JEP04001JEUYF
FUH2000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40006FUH01000
FUIJEUYF0P00<7oo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH00UYF0`0000Eoo`00FUIJEP0000EJEQ<0
00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<00004FUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30004FUH20002FUH2000`Ool002]oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000=J
EP03001JEUYF00AJEP<0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00EJEP8000=JEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800004Ool000000004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01P00FUH00000FUH0009JEP800003FUH007oo02moo`00:goo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00UYF00<005YFFUH015YF00H005YF000005YF0005FUH50006FUH00`00FUIJEP07FUH3
0006FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YFFUIJEP<0009JEP03001JEP00031oo`00:goo00<005YF00000UYF00@005YFFUIJEPL000AJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00=JEP03
001JEUYF009JEP8000IJEP<000MJEP03001JEUYF00MJEP<000IJEP04001JEUYFFUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000017oo001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00Ool0
;goo000[Ool20003FUH40003FUH20002Ool90004FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001EYF00<005YFFUH015YF10000UYF00<005YFFUH01eYF00<005YFFUH01`000UYF0`00
0eYF00<005YFFUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1000
00=JEP00FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF0`00<Goo000[Ool00eYF001JEP030006FUH01000FUH000002Goo1P0025YF00<0
05YFFUH015YF00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH010001UYF1@000eYF00<005YF
FUH015YF00H005YF000005YF0003FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUH005YF00000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYF000`Ool002Yoo`04001JEP000002FUH00`00FUIJEP04
FUH01000FUIJEUYF0`002Woo1@0015YF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<005YF
FUH015YF1P0000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00`000eYF0`0035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF200015YF200015YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo000ZOol20004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH30006Ool500001Woo00000000FUH000MJEP03001JEP0000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00800003FUH0
07oo00Eoo`8000EJEP03001JEUYF009JEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo02]oo`00:Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000Aoo`D000Ao
o`<000IJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP05
FUH01000FUIJEUYF100000AJEP000000009JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP800003FUH0000000=JEP8000Moo`<00003FUH005YF00QJEP03001JEP00008000AJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8002aoo`00:Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF0`0000=oo`0000000`001goo0P0015YF00@005YFFUIJEP80009JEP03
001JEUYF00EJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00AJEPD0009JEP03001JEP00
00800004FUH00000FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40003
FUH00`00FUIJEP020008Ool60004FUH00`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP03
FUH01000FUIJEP00:goo000ZOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH60009Ool200000eYF001JEP05FUH20008FUH30004FUH00`00FUIJEP07FUH00`00FUH000060005
FUH00`00FUH00003FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF00<007ooOol02goo200015YF10001eYF00<005YF
FUH00eYF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
15YF3@000UYF20000goo0P001UYF0`0015YF0`0025YF00<005YFFUH015YF10000UYF0P000eYF00<0
05YFFUH00UYF0`000eYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF0P002Woo1@0017oo2P0015YF00<005YFFUH0
15YF00D005YFFUIJEP0002Yoo`00:Woo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00001@00
0UYF00<005YFFUH01UYF00<005YF00000`000UYF00@005YFFUIJEPL000AJEP03001JEUYF00@00003
FUH005YF00QJEP03001JEUYF00@000=JEP<000EJEP03001JEUYF009JEP03001JEP0000=JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF
00AJEP04001JEP000008Ool5000>Ool300000eYF001JEP04FUH00`00FUIJEP02FUH00`00Oomoo`0X
Ool002]oo`04001JEUYF0005FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH50005FUH00`00FUIJEP02000015YF001JEUYF0`0015YF00<005YFFUH01EYF100015YF0`0000=J
EP00FUH01UYF00H005YF000005YF0004FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Goo1@004Goo0P00
1EYF00L005YFFUIJEP00FUH0000YOol002aoo`<000AJEP8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH005YF00=JEP@000MJEP03001JEUYF00=JEP@0
00=JEP<000AJEP03001JEUYF00AJEP<000=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH30003Ool3000@Ool50004FUH01`00FUIJEUYF001JEP0002Uoo`00;Woo00<005YFFUH00UYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1`0000=JEP00
FUH025YF00<005YF00002@0025YF00@005YFFUIJEP<000EJEP04001JEUYFFUH20002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001EYF001JEUYF00001EYF
00<005YFFUH01UYF00<005YF00000P003Goo1P000UYF00<005YFFUH00P000UYF00L005YFFUIJEP00
FUH0000YOol002moo`800003FUH0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000IJEP03001JEUYF00EJEP<000=JEPH000UJEP06001JEP00001JEP00
1UYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P000UYF0P001UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0017oo1P000eYF00<005YF
FUH00eYF00<005YFFUH00`0015YF00<005YF0000:Goo000aOol30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20007FUH00`00FUIJEP03FUH200000eYF001J
EP02FUH600000eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP80
02Yoo`00<Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000UYF00<005YFFUH01EYF00<005YF00000`000UYF10000UYF0`000UYF00<005YFFUH00eYF
40001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF
00@005YF000000AJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00<0009JEP03001JEP0002Yoo`00<Goo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
15YF100000=oo`0000000P000UYF00<005YFFUH01eYF00<005YF00000P002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00@005YFFUH000QJEP03001JEP0000800003FUH005YF00MJEP03001JEUYF00EJEP04001JEUYF
FUH700001UYF00000000FUH002Yoo`00<Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP800003FUH00000008000IJ
EP03001JEUYF00IJEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00AJEP<000MJEP<000EJEP03
001JEUYF00IJEP04001JEUYFFUH70003FUH01000FUIJEP000eYF00<005YF0000:Woo000aOol20003
FUH01000FUIJEUYF3P001UYF00L005YFFUIJEP00FUH00005FUH00`00FUH0000400000eYF001JEP08
FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40006FUH30003FUH30008FUH00`00FUIJEP05
FUH50002FUH200000eYF001JEP04FUH20004FUH00`00FUH0000ZOol0035oo`80009JEPP000QJEP03
001JEUYF00@0009JEP05001JEUYFFUH00002FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<0
05YF00000P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF1P0015YF00<005YFFUH00`0000=JEP00FUH025YF00<005YF
FUH00eYF0P000UYF00<005YFFUH00P000eYF00<005YFFUH00eYF0P0015YF0P00:goo000aOol01UYF
00000000FUH000Ioo`<000AJEP03001JEUYF00EJEPD00006FUH005YFFUH005YF0P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP00
009JEP03001JEP00008000AJEP03001JEUYF00MJEP03001JEP00008000AJEP<000IJEP03001JEUYF
00800003FUH005YF00=JEP8002]oo`00<7oo0P0015YF0`001goo0`0000=JEP00FUH01eYF00@005YF
FUIJEP<00003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00@000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP<000AJEP@000MJEP03001JEUYF00EJEP@000EJEP800003FUH005YF00IJEP<000=J
EP07001JEUYFFUH005YF0000:goo000`Ool20004FUH01000FUIJEP002Goo1P0015YF00<005YFFUH0
0eYF0P0000=JEP00FUH015YF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0`0015YF0`002EYF00<005YFFUH020000UYF0`0015YF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P000eYF00<005YFFUH00UYF0P0037oo2@000UYF
0P000UYF00<005YFFUH00eYF00<005YF00000`000UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF1`000eYF00<005YFFUH01EYF100000=oo`0000001`001eYF00<005YFFUH0
0UYF0P001EYF00@005YFFUIJEP8002eoo`00<7oo0P000eYF00<005YFFUH015YF0P002Goo1@001Goo
3`001EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP000000
1EYF00<005YFFUH00eYF0P001Woo1`002EYF00H005YF000005YF0005FUH01000FUH00000;goo000`
Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUH000001goo1@0047oo0`001UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10001eYF00<005YF00000P0017oo10000UYF
0`000UYF00<005YFFUH01EYF0`000UYF00@005YFFUIJEPD0035oo`00<7oo00<005YFFUH00UYF00<0
05YFFUH015YF00@005YFFUIJEP8000Eoo`D0011oo`<000IJEP80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP<00003FUH007oo009oo`800003FUH0
05YF00QJEP03001JEUYF00=JEP800003Ool0000000H003Ioo`00<Goo00D005YFFUIJEP0000EJEP03
001JEUYF00AJEP@0009oo`<000aoo`D0009JEP<000=JEP03001JEP00009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYFFUH00005FUH01000FUIJEUYF0P0000EJEP00000007oo00<000AJEP03
001JEUYF00MJEP03001JEP000080045oo`00<Woo00<005YF00001UYF00<005YFFUH01EYF00<005YF
FUH010002Goo100000=JEP00FUH01EYF00P005YF000005YF001JEP000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00P001EYF00@005YF0000009JEPD000MJEP03001JEUYF00EJEP@004Ao
o`00<goo0P001UYF00<005YFFUH01EYF00<005YFFUH015YF1@0000Aoo`00000000IJEP03001JEUYF
00=JEP03001JEUYF00<00005FUH005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00
FUIJEP02FUH60003FUH00`00FUIJEP07FUH00`00FUIJEP040018Ool003Aoo`03001JEUYF00AJEP03
001JEUYF00AJEP03001JEUYF00MJEP@00003FUH005YF00IJEP03001JEUYF00AJEP03001JEP00009o
o`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJER4000QJEP03001JEUYF00EJ
EP03001JEP00009JEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4001<Ool0
03Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP@000IJEP03001JEUYF00EJEP04001JEUYF
FUH400000eYF000000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH9000;FUH00`00FUIJEP0:
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH01000FUIJEP000UYF0`000eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00D7oo000gOol01000FUIJEP001eYF00<005YFFUH00`0000=JEP00FUH0
1eYF00<005YFFUH015YF1@000UYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00=J
EP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000<000IJEP04
001JEUYF0002FUH20005FUH00`00FUIJEP05FUH00`00FUH00002001BOol003Qoo`<000MJEP<000AJ
EP03001JEUYF00MJEP03001JEP0000H000EJEP03001JEP00009JEP04001JEUYF0005FUH00`00FUH0
0004000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH50003FUH00`00Oomoo`1?Ool003Yo
o`8000=JEP<000QJEP03001JEUYF00AJEP@0009JEP8000=JEP03001JEUYF009JEP<0009JEP04001J
EUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH40003FUH01@00FUIJEUYF00000UYF1`0015YF00D005YFFUIJEP00055oo`00
?7oo0`0000=JEP00FUH025YF00<005YFFUH010000eYF0`001EYF00<005YFFUH00UYF00<005YF0000
0UYF00@005YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF0000000800000eYF001JEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`1?Ool003Yoo`<000AJEP03001JEUYF00EJEP@000AJEP<00003FUH0
05YF00IJEP06001JEP00001JEP000eYF00D005YFFUH005YF008000QJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP03001oogoo00Aoo`8000EJEP07001JEUYFFUH005YF0000D7oo000gOol30007FUH00`00FUIJEP03
FUH40003FUH30004FUH00`00FUIJEP04FUH30003FUH01@00FUIJEUYF00000UYF0P0000=JEP00FUH0
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF100017oo1@0015YF00L005YFFUIJEP00FUH0001@Ool003Eoo`800003FUH0
05YF00QJEP03001JEP0000T000QJEP04001JEUYFFUH30005FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000D0009JEP03001JEUYF0080009JEP07001JEUYF
FUH005YF0000D7oo000cOol20004FUH00`00FUIJEP05FUH30003Ool60009FUH01P00FUH00000FUH0
00IJEP03001JEUYF00<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEP00001JEP001EYF
00<005YFFUH00`0015YF00<005YF0000D7oo000aOol20006FUH00`00FUIJEP03FUH20005Ool60000
0eYF001JEP06FUH30003FUH00`00FUIJEP03FUH01@00FUH00000Ool00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00H005YFFUH005YF0005FUH01000FUIJEUYF0P0015YF0P00DGoo000_Ool30008
FUH00`00FUH000020003Ool40002FUH30002FUH00`00FUIJEP03FUH@0003Ool20004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<0
05YF0000DGoo000]Ool20003FUH00`00FUIJEP04FUH30002Ool40002FUH00`00FUIJEP07FUH00`00
FUH00002000DOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003FUH0
1000FUIJEUYF1`0000IJEP00000005YF001AOol002aoo`8000AJEP03001JEUYF009JEP800003Ool0
0000008000IJEP03001JEUYF00IJEP<001Moo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEP800003FUH0000000D000=JEP04001JEUYF0003FUH00`00FUH0001AOol002]oo`03001JEP00
00EJEP03001JEP0000@00003FUH005YF00QJEP03001JEUYF009JEP<001]oo`80009JEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP@0009JEP800003FUH005YF00AJEP8000AJEP03001JEP00055oo`00:goo
00@005YFFUH000=JEP@000IJEP03001JEUYF00IJEP03001JEP000080021oo`<000QJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF
FUH2000015YF001JEUYF0P000eYF00<005YFFUH00eYF0P0015YF0P00DWoo000[Ool01@00FUIJEP00
FUH00P000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`009Goo0P001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000=JEP<0
00IJEP03001JEUYF00800003FUH005YF00=JEP80059oo`00;7oo00@005YF000000EJEP03001JEUYF
00EJEP03001JEUYF00@002Yoo`<000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00AJEP@000=JEP800003FUH005YF00IJEP<000=JEP07001JEUYF
FUH005YF0000DWoo000/Ool200000eYF001JEP04FUH00`00FUIJEP04FUH4000aOol300000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP050003FUH30004
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000/Ool20002FUH00`00FUIJ
EP03FUH00`00FUH00003000hOol40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH=0007FUH00`00FUIJEP02FUH20005FUH01000FUIJEUYF0P00E7oo000]Ool200000eYF001JEP02
FUH40010Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF20000goo1`002EYF
00H005YF000005YF0005FUH01000FUH00000EWoo000_Ool5001:OolO0003FUH20002Ool400000eYF
0000000300000eYF001JEP06FUH30002FUH01000FUIJEUYF1@00F7oo002?Ool20002FUH00`00FUIJ
EP05FUH00`00FUH000020002Ool200000eYF001JEP03FUH30002FUH00`00FUIJEP03FUH200000goo
00000006001MOol008ioo`03001JEUYF00=JEP03001JEUYF00=JEP<0009oo`<000AJEP03001JEUYF
00MJEP03001JEP00008006Qoo`00SGoo0P001EYF00<005YF000020001eYF00<005YFFUH01UYF0`00
Jgoo002<Ool01000FUIJEP0015YF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0`00KWoo002<
Ool01000FUIJEP000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEP000080075oo`00SGoo
00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH01EYF0`00M7oo002=Ool00`00FUIJEP02
0004FUH00`00FUIJEP06FUH00`00FUIJEP04001gOol008ioo`04FUH005YF0005FUH00`00FUIJEP04
FUH4001kOol008ioo`05001JEUYFFUH00004FUH00`00FUIJEP04001oOol008ioo``008=oo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58847 .75275 m .59618 .69857 L .56532 .69232 L p .707 .577 .707 r
F P
0 g
s
.59618 .69857 m .58847 .75275 L .62003 .75589 L p .707 .577 .707 r
F P
0 g
s
.62003 .75589 m .62774 .70172 L .59618 .69857 L p .707 .577 .707 r
F P
0 g
s
.62774 .70172 m .62003 .75589 L .64919 .75563 L p .707 .577 .707 r
F P
0 g
s
.64919 .75563 m .65691 .70145 L .62774 .70172 L p .707 .577 .707 r
F P
0 g
s
.5576 .7465 m .56532 .69232 L .53817 .68358 L p .707 .577 .707 r
F P
0 g
s
.56532 .69232 m .5576 .7465 L .58847 .75275 L p .707 .577 .707 r
F P
0 g
s
.65691 .70145 m .64919 .75563 L .6731 .75197 L p .707 .577 .707 r
F P
0 g
s
.6731 .75197 m .68082 .6978 L .65691 .70145 L p .707 .577 .707 r
F P
0 g
s
.60119 .81453 m .60632 .77841 L .57546 .77217 L p .707 .577 .707 r
F P
0 g
s
.60632 .77841 m .60119 .81453 L .63276 .81766 L p .707 .577 .707 r
F P
0 g
s
.63276 .81766 m .63789 .78154 L .60632 .77841 L p .707 .577 .707 r
F P
0 g
s
.53045 .73776 m .53817 .68358 L .51739 .67321 L p .707 .577 .707 r
F P
0 g
s
.53817 .68358 m .53045 .73776 L .5576 .7465 L p .707 .577 .707 r
F P
0 g
s
.63789 .78154 m .63276 .81766 L .66192 .81738 L p .707 .577 .707 r
F P
0 g
s
.66192 .81738 m .66705 .78126 L .63789 .78154 L p .707 .577 .707 r
F P
0 g
s
.57033 .80829 m .57546 .77217 L .5483 .76344 L p .707 .577 .707 r
F P
0 g
s
.57546 .77217 m .57033 .80829 L .60119 .81453 L p .707 .577 .707 r
F P
0 g
s
.66705 .78126 m .66192 .81738 L .68583 .81373 L p .707 .577 .707 r
F P
0 g
s
.68583 .81373 m .69096 .77761 L .66705 .78126 L p .707 .577 .707 r
F P
0 g
s
.5483 .76344 m .54317 .79956 L .57033 .80829 L p .707 .577 .707 r
F P
0 g
s
.54317 .79956 m .5483 .76344 L .52752 .75308 L p .707 .577 .707 r
F P
0 g
s
.68082 .6978 m .6731 .75197 L .68942 .7453 L p .707 .577 .707 r
F P
0 g
s
.68942 .7453 m .69714 .69112 L .68082 .6978 L p .707 .577 .707 r
F P
0 g
s
.51739 .67321 m .50967 .72738 L .53045 .73776 L p .707 .577 .707 r
F P
0 g
s
.59223 .84515 m .58862 .82662 L .55805 .83094 L p .707 .577 .707 r
F P
0 g
s
.58862 .82662 m .59223 .84515 L .62352 .83876 L p .707 .577 .707 r
F P
0 g
s
.62352 .83876 m .6199 .82023 L .58862 .82662 L p .707 .577 .707 r
F P
0 g
s
.6199 .82023 m .62352 .83876 L .65247 .83093 L p .707 .577 .707 r
F P
0 g
s
.65247 .83093 m .64885 .8124 L .6199 .82023 L p .707 .577 .707 r
F P
0 g
s
.50967 .72738 m .51739 .67321 L .50501 .66221 L p .707 .577 .707 r
F P
0 g
s
.55805 .83094 m .56166 .84947 L .59223 .84515 L p .707 .577 .707 r
F P
0 g
s
.56166 .84947 m .55805 .83094 L .5312 .83276 L p .707 .577 .707 r
F P
0 g
s
.52752 .75308 m .52239 .7892 L .54317 .79956 L p .707 .577 .707 r
F P
0 g
s
.5312 .83276 m .53481 .8513 L .56166 .84947 L p .707 .577 .707 r
F P
0 g
s
.64885 .8124 m .65247 .83093 L .67624 .82242 L p .707 .577 .707 r
F P
0 g
s
.67624 .82242 m .67263 .80389 L .64885 .8124 L p .707 .577 .707 r
F P
0 g
s
.69096 .77761 m .68583 .81373 L .70216 .80705 L p .707 .577 .707 r
F P
0 g
s
.70216 .80705 m .70728 .77093 L .69096 .77761 L p .707 .577 .707 r
F P
0 g
s
.52239 .7892 m .52752 .75308 L .51514 .74209 L p .707 .577 .707 r
F P
0 g
s
.50501 .66221 m .4973 .71638 L .50967 .72738 L p .707 .577 .707 r
F P
0 g
s
.53481 .8513 m .5312 .83276 L .51069 .83192 L p .707 .577 .707 r
F P
0 g
s
.69714 .69112 m .68942 .7453 L .69656 .73624 L p .707 .577 .707 r
F P
0 g
s
.69656 .73624 m .70427 .68207 L .69714 .69112 L p .707 .577 .707 r
F P
0 g
s
.51069 .83192 m .5143 .85045 L .53481 .8513 L p .707 .577 .707 r
F P
0 g
s
.4973 .71638 m .50501 .66221 L .50226 .65167 L p .707 .577 .707 r
F P
0 g
s
.67263 .80389 m .67624 .82242 L .69251 .81407 L p .707 .577 .707 r
F P
0 g
s
.69251 .81407 m .6889 .79553 L .67263 .80389 L p .707 .577 .707 r
F P
0 g
s
.51514 .74209 m .51002 .77821 L .52239 .7892 L p .707 .577 .707 r
F P
0 g
s
.70728 .77093 m .70216 .80705 L .70929 .79799 L p .707 .577 .707 r
F P
0 g
s
.70929 .79799 m .71442 .76187 L .70728 .77093 L p .707 .577 .707 r
F P
0 g
s
.51002 .77821 m .51514 .74209 L .51239 .73155 L p .707 .577 .707 r
F P
0 g
s
.50226 .65167 m .49454 .70584 L .4973 .71638 L p .707 .577 .707 r
F P
0 g
s
.5143 .85045 m .51069 .83192 L .49853 .82849 L p .707 .577 .707 r
F P
0 g
s
.49853 .82849 m .50215 .84702 L .5143 .85045 L p .707 .577 .707 r
F P
0 g
s
.70427 .68207 m .69656 .73624 L .6938 .7257 L p .707 .577 .707 r
F P
0 g
s
.6938 .7257 m .70152 .67153 L .70427 .68207 L p .707 .577 .707 r
F P
0 g
s
.6889 .79553 m .69251 .81407 L .69969 .80669 L p .707 .577 .707 r
F P
0 g
s
.69969 .80669 m .69608 .78815 L .6889 .79553 L p .707 .577 .707 r
F P
0 g
s
.49454 .70584 m .50226 .65167 L .50939 .64262 L p .707 .577 .707 r
F P
0 g
s
.51239 .73155 m .50726 .76767 L .51002 .77821 L p .707 .577 .707 r
F P
0 g
s
.49294 .82177 m .48927 .31951 L .44527 .31715 L p .707 .577 .707 r
F P
0 g
s
.50726 .76767 m .51239 .73155 L .51952 .7225 L p .707 .577 .707 r
F P
0 g
s
.50939 .64262 m .50167 .69679 L .49454 .70584 L p .707 .577 .707 r
F P
0 g
s
.50167 .69679 m .50939 .64262 L .52571 .63594 L p .707 .577 .707 r
F P
0 g
s
.51952 .7225 m .51439 .75862 L .50726 .76767 L p .707 .577 .707 r
F P
0 g
s
.51439 .75862 m .51952 .7225 L .53584 .71582 L p .707 .577 .707 r
F P
0 g
s
.52571 .63594 m .51799 .69011 L .50167 .69679 L p .707 .577 .707 r
F P
0 g
s
.50215 .84702 m .49853 .82849 L .49591 .82281 L p .707 .577 .707 r
F P
0 g
s
.49591 .82281 m .49953 .84134 L .50215 .84702 L p .707 .577 .707 r
F P
0 g
s
.49953 .84134 m .49591 .82281 L .50309 .81543 L p .707 .577 .707 r
F P
0 g
s
.50309 .81543 m .50671 .83396 L .49953 .84134 L p .707 .577 .707 r
F P
0 g
s
.51799 .69011 m .52571 .63594 L .54962 .63229 L p .707 .577 .707 r
F P
0 g
s
.53584 .71582 m .53071 .75194 L .51439 .75862 L p .707 .577 .707 r
F P
0 g
s
.53071 .75194 m .53584 .71582 L .55975 .71216 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .5419 .68646 L .51799 .69011 L p .707 .577 .707 r
F P
0 g
s
.50671 .83396 m .50309 .81543 L .51937 .80707 L p .707 .577 .707 r
F P
0 g
s
.51937 .80707 m .52298 .82561 L .50671 .83396 L p .707 .577 .707 r
F P
0 g
s
.55975 .71216 m .55462 .74829 L .53071 .75194 L p .707 .577 .707 r
F P
0 g
s
.52298 .82561 m .51937 .80707 L .54314 .79857 L p .707 .577 .707 r
F P
0 g
s
.54314 .79857 m .54675 .8171 L .52298 .82561 L p .707 .577 .707 r
F P
0 g
s
.48927 .31951 m .49294 .82177 L .53788 .82038 L p .707 .577 .707 r
F P
0 g
s
.53788 .82038 m .53422 .31812 L .48927 .31951 L p .707 .577 .707 r
F P
0 g
s
.54962 .63229 m .57878 .63202 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.5419 .68646 m .54455 .66786 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.54455 .66786 m .54962 .63229 L p .54756 .67811 L .707 .577 .707 r
F P
0 g
s
.64121 .64141 m .63349 .69559 L .60263 .68934 L p .707 .577 .707 r
F P
0 g
s
.60263 .68934 m .61034 .63516 L .64121 .64141 L p .707 .577 .707 r
F P
0 g
s
.57107 .68619 m .57878 .63202 L .61034 .63516 L p .707 .577 .707 r
F P
0 g
s
.57878 .63202 m .57107 .68619 L .5419 .68646 L p .707 .577 .707 r
F P
0 g
s
.61034 .63516 m .60263 .68934 L .57107 .68619 L p .707 .577 .707 r
F P
0 g
s
.55462 .74829 m .55975 .71216 L .58892 .71189 L p .707 .577 .707 r
F P
0 g
s
.58892 .71189 m .58379 .74801 L .55462 .74829 L p .707 .577 .707 r
F P
0 g
s
.58379 .74801 m .58892 .71189 L .62048 .71502 L p .707 .577 .707 r
F P
0 g
s
.62048 .71502 m .61535 .75114 L .58379 .74801 L p .707 .577 .707 r
F P
0 g
s
.63394 .78003 m .63756 .79856 L .60699 .80288 L p .707 .577 .707 r
F P
0 g
s
.60699 .80288 m .60338 .78435 L .63394 .78003 L p .707 .577 .707 r
F P
0 g
s
.5757 .80927 m .57209 .79073 L .60338 .78435 L p .707 .577 .707 r
F P
0 g
s
.60338 .78435 m .60699 .80288 L .5757 .80927 L p .707 .577 .707 r
F P
0 g
s
.5757 .31311 m .57915 .78572 L p .61332 .80725 L .707 .577 .707 r
F P
0 g
s
.57915 .78572 m .57936 .81538 L .58729 .81348 L p .707 .577 .707 r
F P
0 g
s
.58729 .81348 m .61332 .80725 L p .57915 .78572 L .707 .577 .707 r
F P
0 g
s
.54675 .8171 m .54314 .79857 L .57209 .79073 L p .707 .577 .707 r
F P
0 g
s
.57209 .79073 m .5757 .80927 L .54675 .8171 L p .707 .577 .707 r
F P
0 g
s
.53422 .31812 m .53788 .82038 L .57936 .81538 L p .707 .577 .707 r
F P
0 g
s
.57936 .81538 m .5757 .31311 L .53422 .31812 L p .707 .577 .707 r
F P
0 g
s
.44893 .81942 m .44527 .31715 L .4065 .31127 L p .707 .577 .707 r
F P
0 g
s
.44527 .31715 m .44893 .81942 L .49294 .82177 L p .707 .577 .707 r
F P
0 g
s
.71442 .76187 m .70929 .79799 L .70653 .78746 L p .707 .577 .707 r
F P
0 g
s
.70653 .78746 m .71166 .75134 L .71442 .76187 L p .707 .577 .707 r
F P
0 g
s
.61332 .80725 m .60965 .30499 L .5757 .31311 L p .707 .577 .707 r
F P
0 g
s
.70152 .67153 m .6938 .7257 L .68143 .7147 L p .707 .577 .707 r
F P
0 g
s
.68143 .7147 m .68914 .66053 L .70152 .67153 L p .707 .577 .707 r
F P
0 g
s
.69608 .78815 m .69969 .80669 L .69707 .801 L p .707 .577 .707 r
F P
0 g
s
.69707 .801 m .69346 .78247 L .69608 .78815 L p .707 .577 .707 r
F P
0 g
s
.24546 .71597 m .25318 .66179 L .22231 .65555 L p .707 .577 .707 r
F P
0 g
s
.25318 .66179 m .24546 .71597 L .27702 .71911 L p .707 .577 .707 r
F P
0 g
s
.27702 .71911 m .28473 .66494 L .25318 .66179 L p .707 .577 .707 r
F P
0 g
s
.41017 .81354 m .4065 .31127 L .37678 .30246 L p .707 .577 .707 r
F P
0 g
s
.4065 .31127 m .41017 .81354 L .44893 .81942 L p .707 .577 .707 r
F P
0 g
s
.28473 .66494 m .27702 .71911 L .30618 .71885 L p .707 .577 .707 r
F P
0 g
s
.30618 .71885 m .3139 .66467 L .28473 .66494 L p .707 .577 .707 r
F P
0 g
s
.21459 .70972 m .22231 .65555 L .19516 .6468 L p .707 .577 .707 r
F P
0 g
s
.22231 .65555 m .21459 .70972 L .24546 .71597 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71166 .75134 m .70653 .78746 L .69415 .77647 L p .707 .577 .707 r
F P
0 g
s
.69415 .77647 m .69928 .74035 L .71166 .75134 L p .707 .577 .707 r
F P
0 g
s
.3139 .66467 m .30618 .71885 L .33009 .7152 L p .707 .577 .707 r
F P
0 g
s
.33009 .7152 m .33781 .66102 L .3139 .66467 L p .707 .577 .707 r
F P
0 g
s
.65135 .72126 m .64622 .75738 L .61535 .75114 L p .707 .577 .707 r
F P
0 g
s
.61535 .75114 m .62048 .71502 L .65135 .72126 L p .707 .577 .707 r
F P
0 g
s
.63756 .79856 m .63394 .78003 L .66079 .7782 L p .707 .577 .707 r
F P
0 g
s
.60965 .30499 m .61332 .80725 L .63643 .7968 L p .707 .577 .707 r
F P
0 g
s
.66836 .65015 m .66065 .70433 L .63349 .69559 L p .707 .577 .707 r
F P
0 g
s
.63349 .69559 m .64121 .64141 L .66836 .65015 L p .707 .577 .707 r
F P
0 g
s
.63643 .7968 m .63276 .29453 L .60965 .30499 L p .707 .577 .707 r
F P
0 g
s
.25819 .77781 m .26332 .74169 L .23245 .73546 L p .707 .577 .707 r
F P
0 g
s
.26332 .74169 m .25819 .77781 L .28975 .78095 L p .707 .577 .707 r
F P
0 g
s
.28975 .78095 m .29488 .74483 L .26332 .74169 L p .707 .577 .707 r
F P
0 g
s
.68914 .66053 m .68143 .7147 L .66065 .70433 L p .707 .577 .707 r
F P
0 g
s
.66065 .70433 m .66836 .65015 L .68914 .66053 L p .707 .577 .707 r
F P
0 g
s
.18744 .70098 m .19516 .6468 L .17438 .63643 L p .707 .577 .707 r
F P
0 g
s
.19516 .6468 m .18744 .70098 L .21459 .70972 L p .707 .577 .707 r
F P
0 g
s
.29488 .74483 m .28975 .78095 L .31891 .78067 L p .707 .577 .707 r
F P
0 g
s
.31891 .78067 m .32404 .74455 L .29488 .74483 L p .707 .577 .707 r
F P
0 g
s
.22732 .77158 m .23245 .73546 L .20529 .72673 L p .707 .577 .707 r
F P
0 g
s
.23245 .73546 m .22732 .77158 L .25819 .77781 L p .707 .577 .707 r
F P
0 g
s
.69346 .78247 m .69707 .801 L .68492 .79757 L p .707 .577 .707 r
F P
0 g
s
.68492 .79757 m .6813 .77904 L .69346 .78247 L p .707 .577 .707 r
F P
0 g
s
.38044 .80472 m .37678 .30246 L .359 .29156 L p .707 .577 .707 r
F P
0 g
s
.37678 .30246 m .38044 .80472 L .41017 .81354 L p .707 .577 .707 r
F P
0 g
s
.32404 .74455 m .31891 .78067 L .34283 .77702 L p .707 .577 .707 r
F P
0 g
s
.34283 .77702 m .34795 .7409 L .32404 .74455 L p .707 .577 .707 r
F P
0 g
s
.20529 .72673 m .20016 .76285 L .22732 .77158 L p .707 .577 .707 r
F P
0 g
s
.69928 .74035 m .69415 .77647 L .67337 .76611 L p .707 .577 .707 r
F P
0 g
s
.67337 .76611 m .6785 .72999 L .69928 .74035 L p .707 .577 .707 r
F P
0 g
s
.20016 .76285 m .20529 .72673 L .18451 .71637 L p .707 .577 .707 r
F P
0 g
s
.33781 .66102 m .33009 .7152 L .34642 .70852 L p .707 .577 .707 r
F P
0 g
s
.34642 .70852 m .35413 .65434 L .33781 .66102 L p .707 .577 .707 r
F P
0 g
s
.17438 .63643 m .16666 .6906 L .18744 .70098 L p .707 .577 .707 r
F P
0 g
s
.24922 .80789 m .24561 .78936 L .21504 .79368 L p .707 .577 .707 r
F P
0 g
s
.24561 .78936 m .24922 .80789 L .28051 .8015 L p .707 .577 .707 r
F P
0 g
s
.28051 .8015 m .27689 .78297 L .24561 .78936 L p .707 .577 .707 r
F P
0 g
s
.27689 .78297 m .28051 .8015 L .30946 .79367 L p .707 .577 .707 r
F P
0 g
s
.30946 .79367 m .30584 .77514 L .27689 .78297 L p .707 .577 .707 r
F P
0 g
s
.16666 .6906 m .17438 .63643 L .162 .62543 L p .707 .577 .707 r
F P
0 g
s
.21504 .79368 m .21865 .81221 L .24922 .80789 L p .707 .577 .707 r
F P
0 g
s
.21865 .81221 m .21504 .79368 L .18819 .79551 L p .707 .577 .707 r
F P
0 g
s
.18451 .71637 m .17938 .75249 L .20016 .76285 L p .707 .577 .707 r
F P
0 g
s
.18819 .79551 m .1918 .81404 L .21865 .81221 L p .707 .577 .707 r
F P
0 g
s
.30584 .77514 m .30946 .79367 L .33323 .78516 L p .707 .577 .707 r
F P
0 g
s
.33323 .78516 m .32962 .76663 L .30584 .77514 L p .707 .577 .707 r
F P
0 g
s
.63276 .29453 m .63643 .7968 L .64643 .78504 L p .707 .577 .707 r
F P
0 g
s
.6785 .72999 m .67337 .76611 L .64622 .75738 L p .707 .577 .707 r
F P
0 g
s
.64622 .75738 m .65135 .72126 L .6785 .72999 L p .707 .577 .707 r
F P
0 g
s
.64643 .78504 m .64276 .28278 L .63276 .29453 L p .707 .577 .707 r
F P
0 g
s
.6813 .77904 m .68492 .79757 L .66441 .79673 L p .707 .577 .707 r
F P
0 g
s
.66441 .79673 m .66079 .7782 L .6813 .77904 L p .707 .577 .707 r
F P
0 g
s
.34795 .7409 m .34283 .77702 L .35915 .77034 L p .707 .577 .707 r
F P
0 g
s
.35915 .77034 m .36428 .73422 L .34795 .7409 L p .707 .577 .707 r
F P
0 g
s
.17938 .75249 m .18451 .71637 L .17214 .70538 L p .707 .577 .707 r
F P
0 g
s
.162 .62543 m .15429 .67961 L .16666 .6906 L p .707 .577 .707 r
F P
0 g
s
.1918 .81404 m .18819 .79551 L .16768 .79466 L p .707 .577 .707 r
F P
0 g
s
.35413 .65434 m .34642 .70852 L .35355 .69946 L p .707 .577 .707 r
F P
0 g
s
.35355 .69946 m .36126 .64529 L .35413 .65434 L p .707 .577 .707 r
F P
0 g
s
.16768 .79466 m .17129 .8132 L .1918 .81404 L p .707 .577 .707 r
F P
0 g
s
.15429 .67961 m .162 .62543 L .15925 .61489 L p .707 .577 .707 r
F P
0 g
s
.32962 .76663 m .33323 .78516 L .3495 .77681 L p .707 .577 .707 r
F P
0 g
s
.3495 .77681 m .34589 .75828 L .32962 .76663 L p .707 .577 .707 r
F P
0 g
s
.17214 .70538 m .16701 .7415 L .17938 .75249 L p .707 .577 .707 r
F P
0 g
s
.36428 .73422 m .35915 .77034 L .36628 .76128 L p .707 .577 .707 r
F P
0 g
s
.36126 .64529 m .35355 .69946 L .35079 .68892 L p .707 .577 .707 r
F P
0 g
s
.35079 .68892 m .35851 .63475 L .36126 .64529 L p .707 .577 .707 r
F P
0 g
s
.36628 .76128 m .37141 .72516 L .36428 .73422 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .35115 .73976 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36865 .71463 m .36618 .73199 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.36618 .73199 m .36352 .75075 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.359 .29156 m .35491 .27965 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .35627 .70364 L .36546 .71179 L p .707 .577 .707 r
F P
0 g
s
.36546 .71179 m .36865 .71463 L p .36571 .71885 L .707 .577 .707 r
F P
0 g
s
.35115 .73976 m .36546 .71179 L .36571 .71885 L .707 .577 .707 r
F
.35858 .78192 m .36267 .79383 L p .35853 .51967 L F P
0 g
s
.35491 .27965 m .35619 .45467 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.35851 .63475 m .35079 .68892 L .34296 .68197 L p .707 .577 .707 r
F P
0 g
s
.34296 .68197 m .33842 .67793 L p .34345 .6671 L .707 .577 .707 r
F P
0 g
s
.34345 .6671 m .35851 .63475 L .34296 .68197 L .707 .577 .707 r
F
.33842 .67793 m .34613 .62375 L .35851 .63475 L p F P
0 g
s
.35619 .45467 m .35858 .78192 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36267 .79383 m .36121 .59391 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.36121 .59391 m .359 .29156 L p .35853 .51967 L .707 .577 .707 r
F P
0 g
s
.37141 .72516 m .36628 .76128 L .36352 .75075 L p .707 .577 .707 r
F P
0 g
s
.36352 .75075 m .36865 .71463 L .37141 .72516 L p .707 .577 .707 r
F P
0 g
s
.359 .29156 m .36267 .79383 L .38044 .80472 L p .707 .577 .707 r
F P
0 g
s
.35858 .78192 m .35515 .31159 L p .36491 .26789 L .707 .577 .707 r
F P
0 g
s
.35515 .31159 m .35491 .27965 L .35625 .27808 L p .707 .577 .707 r
F P
0 g
s
.35625 .27808 m .36491 .26789 L p .35515 .31159 L .707 .577 .707 r
F P
0 g
s
.66079 .7782 m .66441 .79673 L .63756 .79856 L p .707 .577 .707 r
F P
0 g
s
.16701 .7415 m .17214 .70538 L .16938 .69484 L p .707 .577 .707 r
F P
0 g
s
.15925 .61489 m .15153 .66907 L .15429 .67961 L p .707 .577 .707 r
F P
0 g
s
.17129 .8132 m .16768 .79466 L .15552 .79123 L p .707 .577 .707 r
F P
0 g
s
.15552 .79123 m .15914 .80977 L .17129 .8132 L p .707 .577 .707 r
F P
0 g
s
.34589 .75828 m .3495 .77681 L .35668 .76943 L p .707 .577 .707 r
F P
0 g
s
.35668 .76943 m .35307 .7509 L .34589 .75828 L p .707 .577 .707 r
F P
0 g
s
.64276 .28278 m .64643 .78504 L .64329 .77592 L p .707 .577 .707 r
F P
0 g
s
.64236 .75002 m .64276 .28278 L .64329 .77592 L .707 .577 .707 r
F
.63867 .27087 m .64276 .28278 L p .64247 .62315 L F P
0 g
s
.64234 .77313 m .64121 .61905 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.64121 .61905 m .63867 .27087 L p .64247 .62315 L .707 .577 .707 r
F P
0 g
s
.63867 .27087 m .64234 .77313 L .62456 .76224 L p .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63946 .55963 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.6345 .62435 m .63715 .60574 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .64222 .57017 L p .63617 .60254 L .707 .577 .707 r
F P
0 g
s
.64222 .57017 m .63715 .60574 L p .64687 .63534 L .707 .577 .707 r
F P
0 g
s
.63715 .60574 m .6345 .62435 L .63793 .6274 L p .707 .577 .707 r
F P
0 g
s
.63793 .6274 m .64687 .63534 L p .63715 .60574 L .707 .577 .707 r
F P
0 g
s
.64329 .77592 m .64234 .77313 L p .64236 .75002 L .707 .577 .707 r
F P
0 g
s
.15153 .66907 m .15925 .61489 L .16638 .60584 L p .707 .577 .707 r
F P
0 g
s
.16938 .69484 m .16425 .73096 L .16701 .7415 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16425 .73096 m .16938 .69484 L .17651 .68579 L p .707 .577 .707 r
F P
0 g
s
.16638 .60584 m .15866 .66001 L .15153 .66907 L p .707 .577 .707 r
F P
0 g
s
.15914 .80977 m .15552 .79123 L .1529 .78555 L p .707 .577 .707 r
F P
0 g
s
.1529 .78555 m .15652 .80408 L .15914 .80977 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35307 .7509 m .35668 .76943 L .35406 .76375 L p .707 .577 .707 r
F P
0 g
s
.35406 .76375 m .35045 .74522 L .35307 .7509 L p .707 .577 .707 r
F P
0 g
s
.15866 .66001 m .16638 .60584 L .1827 .59916 L p .707 .577 .707 r
F P
0 g
s
.17651 .68579 m .17138 .72191 L .16425 .73096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.62456 .76224 m .6209 .25997 L .63867 .27087 L p .707 .577 .707 r
F P
0 g
s
.17138 .72191 m .17651 .68579 L .19283 .67911 L p .707 .577 .707 r
F P
0 g
s
.1827 .59916 m .17498 .65333 L .15866 .66001 L p .707 .577 .707 r
F P
0 g
s
.15652 .80408 m .1529 .78555 L .16008 .77817 L p .707 .577 .707 r
F P
0 g
s
.34613 .62375 m .33842 .67793 L .31764 .66755 L p .707 .577 .707 r
F P
0 g
s
.31764 .66755 m .32535 .61338 L .34613 .62375 L p .707 .577 .707 r
F P
0 g
s
.16008 .77817 m .1637 .7967 L .15652 .80408 L p .707 .577 .707 r
F P
0 g
s
.17498 .65333 m .1827 .59916 L .20661 .59551 L p .707 .577 .707 r
F P
0 g
s
.35045 .74522 m .35406 .76375 L .34191 .76032 L p .707 .577 .707 r
F P
0 g
s
.34191 .76032 m .33829 .74178 L .35045 .74522 L p .707 .577 .707 r
F P
0 g
s
.36858 .77016 m .36491 .26789 L .38802 .25744 L p .707 .577 .707 r
F P
0 g
s
.36491 .26789 m .36858 .77016 L .35858 .78192 L p .707 .577 .707 r
F P
0 g
s
.19283 .67911 m .1877 .71523 L .17138 .72191 L p .707 .577 .707 r
F P
0 g
s
.35627 .70364 m .35115 .73976 L .33036 .7294 L p .707 .577 .707 r
F P
0 g
s
.33036 .7294 m .33549 .69328 L .35627 .70364 L p .707 .577 .707 r
F P
0 g
s
.1877 .71523 m .19283 .67911 L .21674 .67545 L p .707 .577 .707 r
F P
0 g
s
.32535 .61338 m .31764 .66755 L .29048 .65881 L p .707 .577 .707 r
F P
0 g
s
.29048 .65881 m .2982 .60463 L .32535 .61338 L p .707 .577 .707 r
F P
0 g
s
.20661 .59551 m .19889 .64968 L .17498 .65333 L p .707 .577 .707 r
F P
0 g
s
.19889 .64968 m .20661 .59551 L .23577 .59524 L p .707 .577 .707 r
F P
0 g
s
.1637 .7967 m .16008 .77817 L .17636 .76982 L p .707 .577 .707 r
F P
0 g
s
.6209 .25997 m .62456 .76224 L .59484 .75342 L p .707 .577 .707 r
F P
0 g
s
.59484 .75342 m .59117 .25115 L .6209 .25997 L p .707 .577 .707 r
F P
0 g
s
.17636 .76982 m .17997 .78835 L .1637 .7967 L p .707 .577 .707 r
F P
0 g
s
.21674 .67545 m .21162 .71157 L .1877 .71523 L p .707 .577 .707 r
F P
0 g
s
.33829 .74178 m .34191 .76032 L .3214 .75947 L p .707 .577 .707 r
F P
0 g
s
.3214 .75947 m .31778 .74094 L .33829 .74178 L p .707 .577 .707 r
F P
0 g
s
.2982 .60463 m .29048 .65881 L .25962 .65256 L p .707 .577 .707 r
F P
0 g
s
.25962 .65256 m .26733 .59839 L .2982 .60463 L p .707 .577 .707 r
F P
0 g
s
.22806 .64942 m .23577 .59524 L .26733 .59839 L p .707 .577 .707 r
F P
0 g
s
.23577 .59524 m .22806 .64942 L .19889 .64968 L p .707 .577 .707 r
F P
0 g
s
.33549 .69328 m .33036 .7294 L .30321 .72067 L p .707 .577 .707 r
F P
0 g
s
.30321 .72067 m .30834 .68455 L .33549 .69328 L p .707 .577 .707 r
F P
0 g
s
.26733 .59839 m .25962 .65256 L .22806 .64942 L p .707 .577 .707 r
F P
0 g
s
.21162 .71157 m .21674 .67545 L .24591 .67518 L p .707 .577 .707 r
F P
0 g
s
.38802 .25744 m .39169 .75971 L .36858 .77016 L p .707 .577 .707 r
F P
0 g
s
.39169 .75971 m .38802 .25744 L .42198 .24931 L p .707 .577 .707 r
F P
0 g
s
.72567 .66071 m .73339 .60653 L .70252 .60028 L p .707 .577 .707 r
F P
0 g
s
.73339 .60653 m .72567 .66071 L .75723 .66385 L p .707 .577 .707 r
F P
0 g
s
.75723 .66385 m .76495 .60968 L .73339 .60653 L p .707 .577 .707 r
F P
0 g
s
.76495 .60968 m .75723 .66385 L .7864 .66359 L p .707 .577 .707 r
F P
0 g
s
.7864 .66359 m .79411 .60941 L .76495 .60968 L p .707 .577 .707 r
F P
0 g
s
.69481 .65446 m .70252 .60028 L .67537 .59154 L p .707 .577 .707 r
F P
0 g
s
.70252 .60028 m .69481 .65446 L .72567 .66071 L p .707 .577 .707 r
F P
0 g
s
.17997 .78835 m .17636 .76982 L .20013 .76131 L p .707 .577 .707 r
F P
0 g
s
.30834 .68455 m .30321 .72067 L .27234 .71443 L p .707 .577 .707 r
F P
0 g
s
.27234 .71443 m .27747 .67831 L .30834 .68455 L p .707 .577 .707 r
F P
0 g
s
.24591 .67518 m .24078 .7113 L .21162 .71157 L p .707 .577 .707 r
F P
0 g
s
.24078 .7113 m .24591 .67518 L .27747 .67831 L p .707 .577 .707 r
F P
0 g
s
.20013 .76131 m .20374 .77984 L .17997 .78835 L p .707 .577 .707 r
F P
0 g
s
.27747 .67831 m .27234 .71443 L .24078 .7113 L p .707 .577 .707 r
F P
0 g
s
.31778 .74094 m .3214 .75947 L .29455 .7613 L p .707 .577 .707 r
F P
0 g
s
.29455 .7613 m .29093 .74277 L .31778 .74094 L p .707 .577 .707 r
F P
0 g
s
.59117 .25115 m .59484 .75342 L .55607 .74754 L p .707 .577 .707 r
F P
0 g
s
.55607 .74754 m .55241 .24527 L .59117 .25115 L p .707 .577 .707 r
F P
0 g
s
.79411 .60941 m .7864 .66359 L .81031 .65994 L p .707 .577 .707 r
F P
0 g
s
.81031 .65994 m .81802 .60576 L .79411 .60941 L p .707 .577 .707 r
F P
0 g
s
.7384 .72249 m .74353 .68637 L .71266 .68013 L p .707 .577 .707 r
F P
0 g
s
.74353 .68637 m .7384 .72249 L .76996 .72562 L p .707 .577 .707 r
F P
0 g
s
.76996 .72562 m .77509 .6895 L .74353 .68637 L p .707 .577 .707 r
F P
0 g
s
.66765 .64572 m .67537 .59154 L .65459 .58117 L p .707 .577 .707 r
F P
0 g
s
.67537 .59154 m .66765 .64572 L .69481 .65446 L p .707 .577 .707 r
F P
0 g
s
.77509 .6895 m .76996 .72562 L .79913 .72535 L p .707 .577 .707 r
F P
0 g
s
.79913 .72535 m .80425 .68923 L .77509 .6895 L p .707 .577 .707 r
F P
0 g
s
.70753 .71625 m .71266 .68013 L .68551 .6714 L p .707 .577 .707 r
F P
0 g
s
.71266 .68013 m .70753 .71625 L .7384 .72249 L p .707 .577 .707 r
F P
0 g
s
.42564 .75158 m .42198 .24931 L .46346 .24431 L p .707 .577 .707 r
F P
0 g
s
.42198 .24931 m .42564 .75158 L .39169 .75971 L p .707 .577 .707 r
F P
0 g
s
.20374 .77984 m .20013 .76131 L .22908 .75348 L p .707 .577 .707 r
F P
0 g
s
.22908 .75348 m .23269 .77201 L .20374 .77984 L p .707 .577 .707 r
F P
0 g
s
.29093 .74277 m .29455 .7613 L .26398 .76562 L p .707 .577 .707 r
F P
0 g
s
.26398 .76562 m .26037 .74709 L .29093 .74277 L p .707 .577 .707 r
F P
0 g
s
.80425 .68923 m .79913 .72535 L .82304 .72169 L p .707 .577 .707 r
F P
0 g
s
.82304 .72169 m .82817 .68557 L .80425 .68923 L p .707 .577 .707 r
F P
0 g
s
.68551 .6714 m .68038 .70752 L .70753 .71625 L p .707 .577 .707 r
F P
0 g
s
.55241 .24527 m .55607 .74754 L .51207 .74519 L p .707 .577 .707 r
F P
0 g
s
.51207 .74519 m .5084 .24292 L .55241 .24527 L p .707 .577 .707 r
F P
0 g
s
.68038 .70752 m .68551 .6714 L .66472 .66104 L p .707 .577 .707 r
F P
0 g
s
.81802 .60576 m .81031 .65994 L .82663 .65326 L p .707 .577 .707 r
F P
0 g
s
.82663 .65326 m .83434 .59908 L .81802 .60576 L p .707 .577 .707 r
F P
0 g
s
.65459 .58117 m .64687 .63534 L .66765 .64572 L p .707 .577 .707 r
F P
0 g
s
.23269 .77201 m .22908 .75348 L .26037 .74709 L p .707 .577 .707 r
F P
0 g
s
.72943 .75311 m .72582 .73458 L .69525 .7389 L p .707 .577 .707 r
F P
0 g
s
.72582 .73458 m .72943 .75311 L .76072 .74672 L p .707 .577 .707 r
F P
0 g
s
.76072 .74672 m .75711 .72819 L .72582 .73458 L p .707 .577 .707 r
F P
0 g
s
.26037 .74709 m .26398 .76562 L .23269 .77201 L p .707 .577 .707 r
F P
0 g
s
.75711 .72819 m .76072 .74672 L .78967 .73889 L p .707 .577 .707 r
F P
0 g
s
.78967 .73889 m .78606 .72036 L .75711 .72819 L p .707 .577 .707 r
F P
0 g
s
.64687 .63534 m .65459 .58117 L .64222 .57017 L p .707 .577 .707 r
F P
0 g
s
.69525 .7389 m .69887 .75743 L .72943 .75311 L p .707 .577 .707 r
F P
0 g
s
.46712 .74658 m .46346 .24431 L .5084 .24292 L p .707 .577 .707 r
F P
0 g
s
.46346 .24431 m .46712 .74658 L .42564 .75158 L p .707 .577 .707 r
F P
0 g
s
.69887 .75743 m .69525 .7389 L .6684 .74073 L p .707 .577 .707 r
F P
0 g
s
.5084 .24292 m .51207 .74519 L .46712 .74658 L p .707 .577 .707 r
F P
0 g
s
.66472 .66104 m .6596 .69716 L .68038 .70752 L p .707 .577 .707 r
F P
0 g
s
.6684 .74073 m .67202 .75926 L .69887 .75743 L p .707 .577 .707 r
F P
0 g
s
.78606 .72036 m .78967 .73889 L .81344 .73038 L p .707 .577 .707 r
F P
0 g
s
.81344 .73038 m .80983 .71185 L .78606 .72036 L p .707 .577 .707 r
F P
0 g
s
.82817 .68557 m .82304 .72169 L .83936 .71501 L p .707 .577 .707 r
F P
0 g
s
.83936 .71501 m .84449 .67889 L .82817 .68557 L p .707 .577 .707 r
F P
0 g
s
.6596 .69716 m .66472 .66104 L .65235 .65005 L p .707 .577 .707 r
F P
0 g
s
.67202 .75926 m .6684 .74073 L .64789 .73988 L p .707 .577 .707 r
F P
0 g
s
.83434 .59908 m .82663 .65326 L .83376 .6442 L p .707 .577 .707 r
F P
0 g
s
.83376 .6442 m .84148 .59003 L .83434 .59908 L p .707 .577 .707 r
F P
0 g
s
.64789 .73988 m .65151 .75841 L .67202 .75926 L p .707 .577 .707 r
F P
0 g
s
.80983 .71185 m .81344 .73038 L .82972 .72203 L p .707 .577 .707 r
F P
0 g
s
.82972 .72203 m .8261 .7035 L .80983 .71185 L p .707 .577 .707 r
F P
0 g
s
.65235 .65005 m .64722 .68617 L .6596 .69716 L p .707 .577 .707 r
F P
0 g
s
.84449 .67889 m .83936 .71501 L .84649 .70596 L p .707 .577 .707 r
F P
0 g
s
.84649 .70596 m .85162 .66984 L .84449 .67889 L p .707 .577 .707 r
F P
0 g
s
.64722 .68617 m .65235 .65005 L .64959 .63952 L p .707 .577 .707 r
F P
0 g
s
.63946 .55963 m .63174 .6138 L .6345 .62435 L p .707 .577 .707 r
F P
0 g
s
.65151 .75841 m .64789 .73988 L .63574 .73645 L p .707 .577 .707 r
F P
0 g
s
.63574 .73645 m .63935 .75498 L .65151 .75841 L p .707 .577 .707 r
F P
0 g
s
.84148 .59003 m .83376 .6442 L .831 .63366 L p .707 .577 .707 r
F P
0 g
s
.831 .63366 m .83872 .57949 L .84148 .59003 L p .707 .577 .707 r
F P
0 g
s
.8261 .7035 m .82972 .72203 L .8369 .71465 L p .707 .577 .707 r
F P
0 g
s
.8369 .71465 m .83328 .69612 L .8261 .7035 L p .707 .577 .707 r
F P
0 g
s
.63174 .6138 m .63946 .55963 L .64659 .55058 L p .707 .577 .707 r
F P
0 g
s
.64959 .63952 m .64446 .67564 L .64722 .68617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.85162 .66984 m .84649 .70596 L .84373 .69542 L p .707 .577 .707 r
F P
0 g
s
.84373 .69542 m .84886 .6593 L .85162 .66984 L p .707 .577 .707 r
F P
0 g
s
.64446 .67564 m .64959 .63952 L .65672 .63046 L p .707 .577 .707 r
F P
0 g
s
.64659 .55058 m .63888 .60475 L .63174 .6138 L p .707 .577 .707 r
F P
0 g
s
.63935 .75498 m .63574 .73645 L .63312 .73077 L p .707 .577 .707 r
F P
0 g
s
.63312 .73077 m .63673 .7493 L .63935 .75498 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83872 .57949 m .831 .63366 L .81863 .62267 L p .707 .577 .707 r
F P
0 g
s
.81863 .62267 m .82635 .56849 L .83872 .57949 L p .707 .577 .707 r
F P
0 g
s
.83328 .69612 m .8369 .71465 L .83428 .70897 L p .707 .577 .707 r
F P
0 g
s
.83428 .70897 m .83067 .69043 L .83328 .69612 L p .707 .577 .707 r
F P
0 g
s
.63888 .60475 m .64659 .55058 L .66291 .5439 L p .707 .577 .707 r
F P
0 g
s
.65672 .63046 m .65159 .66658 L .64446 .67564 L p .707 .577 .707 r
F P
0 g
s
.38266 .62393 m .39038 .56975 L .35951 .56351 L p .707 .577 .707 r
F P
0 g
s
.39038 .56975 m .38266 .62393 L .41422 .62707 L p .707 .577 .707 r
F P
0 g
s
.41422 .62707 m .42194 .5729 L .39038 .56975 L p .707 .577 .707 r
F P
0 g
s
.42194 .5729 m .41422 .62707 L .44339 .62681 L p .707 .577 .707 r
F P
0 g
s
.44339 .62681 m .4511 .57263 L .42194 .5729 L p .707 .577 .707 r
F P
0 g
s
.3518 .61768 m .35951 .56351 L .33236 .55477 L p .707 .577 .707 r
F P
0 g
s
.35951 .56351 m .3518 .61768 L .38266 .62393 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84886 .6593 m .84373 .69542 L .83136 .68443 L p .707 .577 .707 r
F P
0 g
s
.83136 .68443 m .83649 .64831 L .84886 .6593 L p .707 .577 .707 r
F P
0 g
s
.65159 .66658 m .65672 .63046 L .67304 .62378 L p .707 .577 .707 r
F P
0 g
s
.66291 .5439 m .6552 .59807 L .63888 .60475 L p .707 .577 .707 r
F P
0 g
s
.4511 .57263 m .44339 .62681 L .4673 .62316 L p .707 .577 .707 r
F P
0 g
s
.4673 .62316 m .47501 .56898 L .4511 .57263 L p .707 .577 .707 r
F P
0 g
s
.63673 .7493 m .63312 .73077 L .6403 .72339 L p .707 .577 .707 r
F P
0 g
s
.39539 .68578 m .40052 .64966 L .36965 .64342 L p .707 .577 .707 r
F P
0 g
s
.40052 .64966 m .39539 .68578 L .42695 .68891 L p .707 .577 .707 r
F P
0 g
s
.42695 .68891 m .43208 .65279 L .40052 .64966 L p .707 .577 .707 r
F P
0 g
s
.82635 .56849 m .81863 .62267 L .79785 .61229 L p .707 .577 .707 r
F P
0 g
s
.79785 .61229 m .80557 .55811 L .82635 .56849 L p .707 .577 .707 r
F P
0 g
s
.32464 .60894 m .33236 .55477 L .31158 .54439 L p .707 .577 .707 r
F P
0 g
s
.33236 .55477 m .32464 .60894 L .3518 .61768 L p .707 .577 .707 r
F P
0 g
s
.6403 .72339 m .64391 .74192 L .63673 .7493 L p .707 .577 .707 r
F P
0 g
s
.43208 .65279 m .42695 .68891 L .45612 .68864 L p .707 .577 .707 r
F P
0 g
s
.45612 .68864 m .46124 .65251 L .43208 .65279 L p .707 .577 .707 r
F P
0 g
s
.36452 .67954 m .36965 .64342 L .3425 .63469 L p .707 .577 .707 r
F P
0 g
s
.36965 .64342 m .36452 .67954 L .39539 .68578 L p .707 .577 .707 r
F P
0 g
s
.6552 .59807 m .66291 .5439 L .68682 .54025 L p .707 .577 .707 r
F P
0 g
s
.83067 .69043 m .83428 .70897 L .82212 .70553 L p .707 .577 .707 r
F P
0 g
s
.82212 .70553 m .81851 .687 L .83067 .69043 L p .707 .577 .707 r
F P
0 g
s
.67304 .62378 m .66792 .6599 L .65159 .66658 L p .707 .577 .707 r
F P
0 g
s
.46124 .65251 m .45612 .68864 L .48003 .68498 L p .707 .577 .707 r
F P
0 g
s
.48003 .68498 m .48516 .64886 L .46124 .65251 L p .707 .577 .707 r
F P
0 g
s
.3425 .63469 m .33737 .67081 L .36452 .67954 L p .707 .577 .707 r
F P
0 g
s
.83649 .64831 m .83136 .68443 L .81058 .67407 L p .707 .577 .707 r
F P
0 g
s
.81058 .67407 m .81571 .63795 L .83649 .64831 L p .707 .577 .707 r
F P
0 g
s
.33737 .67081 m .3425 .63469 L .32171 .62433 L p .707 .577 .707 r
F P
0 g
s
.47501 .56898 m .4673 .62316 L .48362 .61648 L p .707 .577 .707 r
F P
0 g
s
.48362 .61648 m .49133 .5623 L .47501 .56898 L p .707 .577 .707 r
F P
0 g
s
.31158 .54439 m .30386 .59856 L .32464 .60894 L p .707 .577 .707 r
F P
0 g
s
.38642 .71585 m .38281 .69732 L .35224 .70164 L p .707 .577 .707 r
F P
0 g
s
.38281 .69732 m .38642 .71585 L .41771 .70947 L p .707 .577 .707 r
F P
0 g
s
.41771 .70947 m .4141 .69093 L .38281 .69732 L p .707 .577 .707 r
F P
0 g
s
.4141 .69093 m .41771 .70947 L .44666 .70163 L p .707 .577 .707 r
F P
0 g
s
.44666 .70163 m .44305 .6831 L .4141 .69093 L p .707 .577 .707 r
F P
0 g
s
.66792 .6599 m .67304 .62378 L .69696 .62013 L p .707 .577 .707 r
F P
0 g
s
.80557 .55811 m .79785 .61229 L .7707 .60355 L p .707 .577 .707 r
F P
0 g
s
.7707 .60355 m .77841 .54937 L .80557 .55811 L p .707 .577 .707 r
F P
0 g
s
.68682 .54025 m .67911 .59442 L .6552 .59807 L p .707 .577 .707 r
F P
0 g
s
.30386 .59856 m .31158 .54439 L .29921 .53339 L p .707 .577 .707 r
F P
0 g
s
.35224 .70164 m .35586 .72017 L .38642 .71585 L p .707 .577 .707 r
F P
0 g
s
.67911 .59442 m .68682 .54025 L .71599 .53998 L p .707 .577 .707 r
F P
0 g
s
.35586 .72017 m .35224 .70164 L .32539 .70347 L p .707 .577 .707 r
F P
0 g
s
.64391 .74192 m .6403 .72339 L .65657 .71504 L p .707 .577 .707 r
F P
0 g
s
.32171 .62433 m .31658 .66045 L .33737 .67081 L p .707 .577 .707 r
F P
0 g
s
.32539 .70347 m .32901 .722 L .35586 .72017 L p .707 .577 .707 r
F P
0 g
s
.44305 .6831 m .44666 .70163 L .47043 .69312 L p .707 .577 .707 r
F P
0 g
s
.47043 .69312 m .46682 .67459 L .44305 .6831 L p .707 .577 .707 r
F P
0 g
s
.65657 .71504 m .66018 .73357 L .64391 .74192 L p .707 .577 .707 r
F P
0 g
s
.69696 .62013 m .69183 .65625 L .66792 .6599 L p .707 .577 .707 r
F P
0 g
s
.81851 .687 m .82212 .70553 L .80161 .70469 L p .707 .577 .707 r
F P
0 g
s
.80161 .70469 m .798 .68616 L .81851 .687 L p .707 .577 .707 r
F P
0 g
s
.48516 .64886 m .48003 .68498 L .49635 .6783 L p .707 .577 .707 r
F P
0 g
s
.49635 .6783 m .50148 .64218 L .48516 .64886 L p .707 .577 .707 r
F P
0 g
s
.77841 .54937 m .7707 .60355 L .73983 .5973 L p .707 .577 .707 r
F P
0 g
s
.73983 .5973 m .74755 .54313 L .77841 .54937 L p .707 .577 .707 r
F P
0 g
s
.70827 .59416 m .71599 .53998 L .74755 .54313 L p .707 .577 .707 r
F P
0 g
s
.71599 .53998 m .70827 .59416 L .67911 .59442 L p .707 .577 .707 r
F P
0 g
s
.81571 .63795 m .81058 .67407 L .78342 .66534 L p .707 .577 .707 r
F P
0 g
s
.78342 .66534 m .78855 .62922 L .81571 .63795 L p .707 .577 .707 r
F P
0 g
s
.31658 .66045 m .32171 .62433 L .30934 .61334 L p .707 .577 .707 r
F P
0 g
s
.29921 .53339 m .29149 .58757 L .30386 .59856 L p .707 .577 .707 r
F P
0 g
s
.74755 .54313 m .73983 .5973 L .70827 .59416 L p .707 .577 .707 r
F P
0 g
s
.69183 .65625 m .69696 .62013 L .72612 .61985 L p .707 .577 .707 r
F P
0 g
s
.32901 .722 m .32539 .70347 L .30488 .70263 L p .707 .577 .707 r
F P
0 g
s
.49133 .5623 m .48362 .61648 L .49075 .60743 L p .707 .577 .707 r
F P
0 g
s
.49075 .60743 m .49847 .55325 L .49133 .5623 L p .707 .577 .707 r
F P
0 g
s
.30488 .70263 m .3085 .72116 L .32901 .722 L p .707 .577 .707 r
F P
0 g
s
.29149 .58757 m .29921 .53339 L .29645 .52285 L p .707 .577 .707 r
F P
0 g
s
.46682 .67459 m .47043 .69312 L .48671 .68477 L p .707 .577 .707 r
F P
0 g
s
.48671 .68477 m .48309 .66624 L .46682 .67459 L p .707 .577 .707 r
F P
0 g
s
.30934 .61334 m .30421 .64946 L .31658 .66045 L p .707 .577 .707 r
F P
0 g
s
.66018 .73357 m .65657 .71504 L .68034 .70653 L p .707 .577 .707 r
F P
0 g
s
.78855 .62922 m .78342 .66534 L .75256 .65911 L p .707 .577 .707 r
F P
0 g
s
.75256 .65911 m .75768 .62299 L .78855 .62922 L p .707 .577 .707 r
F P
0 g
s
.72612 .61985 m .72099 .65597 L .69183 .65625 L p .707 .577 .707 r
F P
0 g
s
.72099 .65597 m .72612 .61985 L .75768 .62299 L p .707 .577 .707 r
F P
0 g
s
.68034 .70653 m .68396 .72506 L .66018 .73357 L p .707 .577 .707 r
F P
0 g
s
.75768 .62299 m .75256 .65911 L .72099 .65597 L p .707 .577 .707 r
F P
0 g
s
.798 .68616 m .80161 .70469 L .77476 .70652 L p .707 .577 .707 r
F P
0 g
s
.77476 .70652 m .77115 .68799 L .798 .68616 L p .707 .577 .707 r
F P
0 g
s
.50148 .64218 m .49635 .6783 L .50348 .66925 L p .707 .577 .707 r
F P
0 g
s
.50348 .66925 m .50861 .63313 L .50148 .64218 L p .707 .577 .707 r
F P
0 g
s
.30421 .64946 m .30934 .61334 L .30658 .6028 L p .707 .577 .707 r
F P
0 g
s
.29645 .52285 m .28873 .57703 L .29149 .58757 L p .707 .577 .707 r
F P
0 g
s
.3085 .72116 m .30488 .70263 L .29273 .6992 L p .707 .577 .707 r
F P
0 g
s
.29273 .6992 m .29634 .71773 L .3085 .72116 L p .707 .577 .707 r
F P
0 g
s
.68396 .72506 m .68034 .70653 L .70929 .6987 L p .707 .577 .707 r
F P
0 g
s
.49847 .55325 m .49075 .60743 L .48799 .59688 L p .707 .577 .707 r
F P
0 g
s
.48799 .59688 m .49571 .54271 L .49847 .55325 L p .707 .577 .707 r
F P
0 g
s
.48309 .66624 m .48671 .68477 L .49389 .67739 L p .707 .577 .707 r
F P
0 g
s
.49389 .67739 m .49027 .65886 L .48309 .66624 L p .707 .577 .707 r
F P
0 g
s
.70929 .6987 m .71291 .71723 L .68396 .72506 L p .707 .577 .707 r
F P
0 g
s
.77115 .68799 m .77476 .70652 L .74419 .71084 L p .707 .577 .707 r
F P
0 g
s
.74419 .71084 m .74058 .69231 L .77115 .68799 L p .707 .577 .707 r
F P
0 g
s
.28873 .57703 m .29645 .52285 L .30358 .5138 L p .707 .577 .707 r
F P
0 g
s
.30658 .6028 m .30145 .63893 L .30421 .64946 L p .707 .577 .707 r
F P
0 g
s
.71291 .71723 m .70929 .6987 L .74058 .69231 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.74058 .69231 m .74419 .71084 L .71291 .71723 L p .707 .577 .707 r
F P
0 g
s
.50861 .63313 m .50348 .66925 L .50072 .65871 L p .707 .577 .707 r
F P
0 g
s
.50072 .65871 m .50585 .62259 L .50861 .63313 L p .707 .577 .707 r
F P
0 g
s
.30145 .63893 m .30658 .6028 L .31371 .59375 L p .707 .577 .707 r
F P
0 g
s
.30358 .5138 m .29586 .56797 L .28873 .57703 L p .707 .577 .707 r
F P
0 g
s
.29634 .71773 m .29273 .6992 L .29011 .69351 L p .707 .577 .707 r
F P
0 g
s
.29011 .69351 m .29372 .71204 L .29634 .71773 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49571 .54271 m .48799 .59688 L .47562 .58589 L p .707 .577 .707 r
F P
0 g
s
.47562 .58589 m .48334 .53171 L .49571 .54271 L p .707 .577 .707 r
F P
0 g
s
.49027 .65886 m .49389 .67739 L .49127 .67171 L p .707 .577 .707 r
F P
0 g
s
.49127 .67171 m .48765 .65318 L .49027 .65886 L p .707 .577 .707 r
F P
0 g
s
.29586 .56797 m .30358 .5138 L .3199 .50712 L p .707 .577 .707 r
F P
0 g
s
.31371 .59375 m .30858 .62987 L .30145 .63893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50585 .62259 m .50072 .65871 L .48835 .64772 L p .707 .577 .707 r
F P
0 g
s
.48835 .64772 m .49348 .6116 L .50585 .62259 L p .707 .577 .707 r
F P
0 g
s
.30858 .62987 m .31371 .59375 L .33003 .58707 L p .707 .577 .707 r
F P
0 g
s
.3199 .50712 m .31219 .56129 L .29586 .56797 L p .707 .577 .707 r
F P
0 g
s
.29372 .71204 m .29011 .69351 L .29729 .68613 L p .707 .577 .707 r
F P
0 g
s
.48334 .53171 m .47562 .58589 L .45484 .57551 L p .707 .577 .707 r
F P
0 g
s
.45484 .57551 m .46256 .52134 L .48334 .53171 L p .707 .577 .707 r
F P
0 g
s
.29729 .68613 m .3009 .70467 L .29372 .71204 L p .707 .577 .707 r
F P
0 g
s
.31219 .56129 m .3199 .50712 L .34381 .50347 L p .707 .577 .707 r
F P
0 g
s
.48765 .65318 m .49127 .67171 L .47911 .66828 L p .707 .577 .707 r
F P
0 g
s
.47911 .66828 m .4755 .64975 L .48765 .65318 L p .707 .577 .707 r
F P
0 g
s
.33003 .58707 m .32491 .62319 L .30858 .62987 L p .707 .577 .707 r
F P
0 g
s
.49348 .6116 m .48835 .64772 L .46757 .63736 L p .707 .577 .707 r
F P
0 g
s
.46757 .63736 m .4727 .60124 L .49348 .6116 L p .707 .577 .707 r
F P
0 g
s
.32491 .62319 m .33003 .58707 L .35395 .58342 L p .707 .577 .707 r
F P
0 g
s
.46256 .52134 m .45484 .57551 L .42769 .56677 L p .707 .577 .707 r
F P
0 g
s
.42769 .56677 m .4354 .5126 L .46256 .52134 L p .707 .577 .707 r
F P
0 g
s
.34381 .50347 m .3361 .55764 L .31219 .56129 L p .707 .577 .707 r
F P
0 g
s
.3361 .55764 m .34381 .50347 L .37298 .5032 L p .707 .577 .707 r
F P
0 g
s
.3009 .70467 m .29729 .68613 L .31356 .67778 L p .707 .577 .707 r
F P
0 g
s
.31356 .67778 m .31717 .69631 L .3009 .70467 L p .707 .577 .707 r
F P
0 g
s
.35395 .58342 m .34882 .61954 L .32491 .62319 L p .707 .577 .707 r
F P
0 g
s
.4755 .64975 m .47911 .66828 L .4586 .66744 L p .707 .577 .707 r
F P
0 g
s
.4586 .66744 m .45499 .6489 L .4755 .64975 L p .707 .577 .707 r
F P
0 g
s
.4354 .5126 m .42769 .56677 L .39682 .56052 L p .707 .577 .707 r
F P
0 g
s
.39682 .56052 m .40454 .50635 L .4354 .5126 L p .707 .577 .707 r
F P
0 g
s
.36526 .55738 m .37298 .5032 L .40454 .50635 L p .707 .577 .707 r
F P
0 g
s
.37298 .5032 m .36526 .55738 L .3361 .55764 L p .707 .577 .707 r
F P
0 g
s
.4727 .60124 m .46757 .63736 L .44041 .62863 L p .707 .577 .707 r
F P
0 g
s
.44041 .62863 m .44554 .59251 L .4727 .60124 L p .707 .577 .707 r
F P
0 g
s
.40454 .50635 m .39682 .56052 L .36526 .55738 L p .707 .577 .707 r
F P
0 g
s
.34882 .61954 m .35395 .58342 L .38311 .58314 L p .707 .577 .707 r
F P
0 g
s
.31717 .69631 m .31356 .67778 L .33733 .66927 L p .707 .577 .707 r
F P
0 g
s
.44554 .59251 m .44041 .62863 L .40954 .62239 L p .707 .577 .707 r
F P
0 g
s
.40954 .62239 m .41467 .58627 L .44554 .59251 L p .707 .577 .707 r
F P
0 g
s
.38311 .58314 m .37798 .61926 L .34882 .61954 L p .707 .577 .707 r
F P
0 g
s
.37798 .61926 m .38311 .58314 L .41467 .58627 L p .707 .577 .707 r
F P
0 g
s
.33733 .66927 m .34095 .6878 L .31717 .69631 L p .707 .577 .707 r
F P
0 g
s
.41467 .58627 m .40954 .62239 L .37798 .61926 L p .707 .577 .707 r
F P
0 g
s
.45499 .6489 m .4586 .66744 L .43175 .66926 L p .707 .577 .707 r
F P
0 g
s
.43175 .66926 m .42814 .65073 L .45499 .6489 L p .707 .577 .707 r
F P
0 g
s
.34095 .6878 m .33733 .66927 L .36628 .66144 L p .707 .577 .707 r
F P
0 g
s
.36628 .66144 m .3699 .67997 L .34095 .6878 L p .707 .577 .707 r
F P
0 g
s
.42814 .65073 m .43175 .66926 L .40118 .67358 L p .707 .577 .707 r
F P
0 g
s
.40118 .67358 m .39757 .65505 L .42814 .65073 L p .707 .577 .707 r
F P
0 g
s
.3699 .67997 m .36628 .66144 L .39757 .65505 L p .707 .577 .707 r
F P
0 g
s
.39757 .65505 m .40118 .67358 L .3699 .67997 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8P00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001YOol2
0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00GWoo4@002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001JOol4
0003FUH00`00FUIJEP06FUH01000FUIJEUYF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001HOol30006FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60007FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001VOol005Ioo`80009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
IWoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`0035YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0
0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008Ool@
001=Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool50003FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH70016Ool005=oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001Goo0000
05YF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000@Woo001COol00`00FUH0
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH015YF1000?Woo001COol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00
>Woo001COol20003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF00H005YFFUH005YF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH2000hOol005=oo`8000=JEP@0009JEP04001JEUYFFUH40002FUH01000
FUIJEUYF1`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<003Ioo`00DWoo
00@005YF001JEP8000IJEP03001JEUYF00AJEP@000EJEPT0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF008003Aoo`00DWoo00H005YF000005YF0005FUH00`00FUIJEP06
FUH00`00FUH000030002FUH50004FUH40006FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00<Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUHC0002FUH0
0`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH015YF0P00<Goo001BOol20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF0P00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH01000FUH00000;goo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00@005YFFUIJEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00<005YFFUH00UYF00<005YFFUH00eYF00@005YFFUIJ
EQ0000IJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH20004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02aoo`00DWoo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03
001JEUYF009JEPL000MJEP03001JEUYF00AJEP80009JEP03001JEP0000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0UYF0P00;Goo001BOol01@00FUIJEUYF000015YF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH010000eYF00<005YFFUH015YF00L005YF001JEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
009JEP8002eoo`00Dgoo00@005YFFUH0009JEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000IJEP03001JEUYF00800003FUH005YF00=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF0000;Goo000gOolA000<Ool300000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP03FUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF200027oo
1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool003=oo`@000=J
EP03001JEUYF00IJEP03001JEUYF009JEPP000Ioo`04001JEP000003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH20005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF1P0000=JEP00FUH0
15YF1@001Woo2@000UYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUIJEP00FUH^Ool0035o
o`<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH600000goo00000004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0`00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH010000Woo1@0017oo10001EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH^Ool002moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00<000EJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00008000=JEP03001JEUYF009JEP03001JEUYF
00IJEP03001JEUYF00AJEPL000Qoo`8000=JEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002io
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH400000eYF
0000000:00000eYF001JEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20005FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YF000000=JEP03001JEUYF009JEP03001oogoo02eoo`00;Goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF
400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH@0006FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00UYF0P00;goo000]
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP020003FUH500000eYF00000002Ool01@00FUIJEP00FUH03`0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP000eYF00<005YFFUH00eYF1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH015YF0P000eYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEPD000AJEP800005Ool005YFFUH00006
FUH@0006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF000015YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P001EYF00<005YF00000UYF0P00;goo000/Ool00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
00<005YFFUH00P000UYF00@005YF0000009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH01000FUH000000eYF00<005YFFUH01000;goo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YF
FUH00eYF0`000UYF00@005YFFUH000EJEPD000EJEP03001JEUYF00IJEP800003FUH005YF00EJEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH00UYF0`00;goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUH0
000300000eYF001JEP04FUH50005FUH00`00FUIJEP08FUH20006FUH01000FUIJEUYF0`0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000eYF0P00<7oo
000/Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH40004FUH30006FUH00`00FUIJ
EP09FUH30003FUH01P00FUIJEUYF001JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP<00003FUH00000031oo`00;7oo00<005YF00000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000@000QJEP03001JEUYF00UJEP03001JEUYF0080
0003FUH005YF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH300000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03000`Ool002aoo`8000=JEP04001JEUYFFUH@0004FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
0eYF1`000UYF00<005YFFUH00eYF3@000eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002moo`00;7oo0P000eYF10000UYF00@0
05YFFUIJEP<000Moo`L000IJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEP000080009JEP800003FUH0
05YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP8002ioo`00:goo00@005YF001JEP8000IJEP03001JEUYF00AJEP<000Ioo`T0009JEP03001JEUYF
00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00AJEPL000=JEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYF001JEP0400000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40003FUH01000FUIJEUYF400015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH015YF00@005YF000002aoo`00:goo00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUH0
00030002Ool50004Ool40005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP0200001UYF00000000FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP@00003
FUH0000000Ioo`h000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000[Ool002]o
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00=JEPL000Qoo`@0009JEP8000=J
EP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EP00001JEP0300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP040004FUH2000>Ool90002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000:goo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40000
0eYF0000000=00001EYF000005YF00000UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P000eYF00X005YFFUH005YF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800005FUH00000FUH00002FUH20002FUH01000FUH000002Woo0`0027oo
10001UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00:Woo000[Ool20003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH00000FUH0
10001UYF00<005YFFUH01eYF00<005YFFUH00UYF20000eYF00<005YFFUH01@0000QJEP00000005YF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH0
0UYF0`000eYF00<007ooOol01Woo1@002goo10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000ZOol002]oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00AJEPL0
009JEP03001JEUYF00IJEP@000=JEPH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP06001JEP00001JEP0027oo1@003goo0`00
1EYF00L005YFFUIJEP00FUH0000ZOol002]oo`05001JEUYFFUH00006FUH01000FUIJEUYF5`0025YF
0P0015YF00<005YFFUH01eYF00<005YFFUH01@0025YF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00=JEP04001JEUYFFUH30007Ool5000BOol20003FUH01`00FUIJEUYF001J
EP0002Yoo`00:goo00D005YFFUIJEP0000IJEP@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00@0009JEP<000IJEP03001JEUYF00AJEPD000=JEP<000MJEP03001JEUYF00=JEP8000=J
EP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP@000Aoo`<001Eoo`800003FUH005YF
009JEP8002]oo`00;7oo00@005YFFUH000AJEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEP80009JEP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00T000IJEP03001J
EUYF00<000EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00@001Uoo`<000=JEP8002]oo`00;Goo0`000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF1P000UYF00<005YF
FUH00eYF3P0000=JEP00FUH01UYF00<005YFFUH00P001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH015YF6@0000QJEP00FUH005YF001JEP00:goo000_Ool01000FUH000000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@005YFFUIJEP8000=JEP<0
009JEP03001JEUYF00=JEPX000EJEP03001JEUYF00EJEP<000UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00=JEPL000AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000800005FUH00000
FUH0000[Ool0031oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP07001JEUYFFUH005YF00001EYF00<005YF00000`000eYF0`000UYF00<005YFFUH015YF10000UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00IJEP03001JEP0000<0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUH0
000[Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF0003FUH30003FUH400000eYF00000002FUH70006FUH00`00FUIJEP06FUH00`00
FUH00004000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF0P00;7oo000`Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00P001UYF00<005YF00001`00
0eYF00<005YFFUH01eYF00<005YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000AJEP00000000=JEP03001JEUYF00@0
0003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P00;7oo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUH000000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P000UYF0P000UYF1P001EYF00<005YFFUH01eYF00<005YFFUH015YF4@000UYF
00@005YF000002aoo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH015YF1@002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YF00000`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH0100000=JEP00FUH01UYF00<005YFFUH00UYF2000;Goo000_Ool00`00FUH00003FUH01000
FUIJEUYF400015YF00<005YFFUH00eYF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH0100015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00@005YF000000=JEP03001JEUYF00IJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00EJEP03001JEP000080009JEP03001JEUYF00<002eo
o`00;goo0P000eYF1@002Woo3`0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEPH0009J
EP<000MJEP03001JEUYF00=JEP@00003FUH005YF00=JEP04001JEP00000^Ool002moo`03FUH005YF
00D001=oo``00003FUH005YF00AJEP03001JEUYF009JEPP000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH005YF00IJEP03001JEUYF009JEP80009oo`@00003FUH0000000<000EJEP04001J
EUYFFUH30005FUH00`00FUIJEP02FUH2000`Ool002ioo`04001JEP000002FUH00`00FUIJEP02000?
Ool3000;Ool<0002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF
00<005YFFUH01EYF00<005YF00000P0027oo1`0015YF00H005YF000005YF0007FUH01@00FUIJEUYF
0000<Goo000^Ool20004FUH00`00FUIJEP02FUH3000;Ool5000>Ool200000eYF001JEP05FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020005FUH00`00FUIJEP03FUH60009Ool5
00000goo000000040003FUH00`00FUIJEP05FUH01000FUH00000<Woo000^Ool00`00FUIJEP03FUH0
0`00FUIJEP03FUH01000FUH000002Goo1@0047oo0P001UYF0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YF00000UYF00<005YFFUH00UYF00<005YF00000`000eYF0P002goo20001UYF00<0
05YFFUH015YF0`00=7oo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0`001Woo
1@004Woo0P000eYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH00UYF0P000eYF0`0000=JEP0000001Woo1`0015YF00<005YFFUH01UYF00@005YFFUIJ
EP8003Moo`00;goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEPD0009oo`<001Eoo`800004FUH0
05YF0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00003FUH01000FUH000001EYF00<0
05YFFUH00`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Uoo`00;goo
00D005YFFUIJEP0000EJEP03001JEUYF00IJEP04001JEUYFFUH90008Ool=00001EYF001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YF00000eYF4@001UYF00<005YFFUH01eYF00<005YFFUH015YF0`00
>goo000`Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF2000
0eYF00<005YFFUH00eYF00<005YF00000`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUH005YF
001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?Woo
000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEP`0
0003FUH005YF00YJEPT000QJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0049oo`00<goo00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH010000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH00`000UYF00<005YFFUH015YF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF00<0
05YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01000Agoo000dOol20002FUH00`00FUIJEP04FUH50006
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP040006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH00UYF1`00Bgoo000fOol30002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH60003FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUH00003000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUHE
001AOol003Moo`@000IJEP03001JEUYF00MJEP03001JEUYF009JEPP000=JEP03001JEUYF00D00003
FUH00000009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP@000EJEP03001oo`0000<0009JEP03001JEUYF00=J
EP07001JEUYFFUH005YF0000DGoo000dOol300000eYF001JEP08FUH00`00FUIJEP04FUH70002FUH0
0`00FUIJEP06FUH40003FUH40002FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000=JEP03001o
ogoo00=oo`<000EJEP07001JEUYFFUH005YF0000DGoo000bOol20004FUH00`00FUIJEP07FUH00`00
FUIJEP050008FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH00002FUH00`00FUH00002
0007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH200000eYF001oo`07Ool20003FUH01`00FUIJEUYF001JEP00055oo`00
<7oo0`001UYF00<005YFFUH015YF1@000eYF0`001eYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0eYF0`000UYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000Yoo`800003FUH0
05YF009JEP80059oo`00;Woo0P000UYF00<005YFFUH015YF00<005YFFUH010000goo2@001UYF00<0
05YFFUH00`001EYF00<005YFFUH00eYF00D007oo001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP04001JEP00000<Ool20003FUH2001BOol002eoo`03001JEUYF009JEP03001JEUYF00AJEP<0
00]oo`L000=JEP@00003FUH005YF00IJEP03001JEUYF0080009oo`<000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0001000004FUH005YF001BOol002aoo`8000EJEP04001JEUYFFUH2000>
Ool:0005FUH00`00FUIJEP05FUH30004Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YF00000P0000EJEP00001JEP00059oo`00:goo
00<005YF00001EYF00@005YF0000015oo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP8000Mo
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YF0000DWoo000[Ool01000FUIJEP000eYF0`003Goo1P001UYF00<005YF
FUH01UYF00<005YF00000`002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP8005=oo`00:goo00D005YFFUH005YF008000Qoo`P0
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP<000ioo`03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P00Dgoo000/Ool01000FUH0
00000UYF20000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010004Woo0P000UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P000eYF2`000UYF00@005YF000005=oo`00;7oo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0067oo0`001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF
FUIJEPL000=JEP03001JEUYF009JEPP005Aoo`00;7oo0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH010007goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00EJEP03
001JEP000080009JEP03001JEUYF00<005Aoo`00;7oo0P000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH00UYF1P009Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0015YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00@005YF000005Eoo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH00UYF2000;Goo0`0000=JEP00
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00UYF10001UYF
00<005YFFUH015YF0P000eYF00<005YFFUH00UYF0P00Egoo000_Ool<000hOol70005FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH=0004FUH01000FUIJEUYF0`001UYF00D005YFFUIJ
EP0005Qoo`00NWoo30001UYF00<005YFFUH02EYF00@005YFFUIJEPH000Moo`D00003Ool0000000H0
0003FUH005YF00IJEP04001JEP00001IOol008IooaH000eoo`X000EJEP03001JEUYF00AJEP<005]o
o`00S7oo00@005YFFUH000AJEP8001Aoo`@0009JEP03001JEUYF00IJEP04001JEUYFFUH2001NOol0
08aoo`05001JEUYFFUH00002FUH00`00Oomoo`0=Ool70006FUH00`00FUIJEP06FUH01000FUH00000
H7oo002<Ool01000FUIJEUYF4`0015YF00<005YFFUH01eYF00<005YFFUH015YF0`00HWoo002=Ool0
0`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
001UOol008eoo`<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJ
EPD006Uoo`00SGoo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01000KWoo002>Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7001b
Ool0091oo`D000=JEP04001JEUYFFUH8001iOol009Eoo`L0085oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]65\[InvisibleSpace]"     "\
\[InvisibleSpace]15.278382473820768`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 65, "     ", 15.278382473820768, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60336 .75501 m .59539 .70097 L .56453 .70271 L p .707 .577 .707 r
F P
0 g
s
.59539 .70097 m .60336 .75501 L .63489 .74994 L p .707 .577 .707 r
F P
0 g
s
.63489 .74994 m .62693 .69589 L .59539 .70097 L p .707 .577 .707 r
F P
0 g
s
.62693 .69589 m .63489 .74994 L .66403 .74203 L p .707 .577 .707 r
F P
0 g
s
.66403 .74203 m .65606 .68799 L .62693 .69589 L p .707 .577 .707 r
F P
0 g
s
.5725 .75675 m .56453 .70271 L .53738 .70094 L p .707 .577 .707 r
F P
0 g
s
.56453 .70271 m .5725 .75675 L .60336 .75501 L p .707 .577 .707 r
F P
0 g
s
.65606 .68799 m .66403 .74203 L .68791 .73206 L p .707 .577 .707 r
F P
0 g
s
.68791 .73206 m .67994 .67802 L .65606 .68799 L p .707 .577 .707 r
F P
0 g
s
.59063 .81642 m .58576 .78027 L .55485 .78173 L p .707 .577 .707 r
F P
0 g
s
.58576 .78027 m .59063 .81642 L .62221 .81169 L p .707 .577 .707 r
F P
0 g
s
.62221 .81169 m .61735 .77554 L .58576 .78027 L p .707 .577 .707 r
F P
0 g
s
.61735 .77554 m .62221 .81169 L .65136 .80415 L p .707 .577 .707 r
F P
0 g
s
.65136 .80415 m .6465 .768 L .61735 .77554 L p .707 .577 .707 r
F P
0 g
s
.54535 .75499 m .53738 .70094 L .5166 .69585 L p .707 .577 .707 r
F P
0 g
s
.53738 .70094 m .54535 .75499 L .5725 .75675 L p .707 .577 .707 r
F P
0 g
s
.55971 .81788 m .55485 .78173 L .52762 .77976 L p .707 .577 .707 r
F P
0 g
s
.55485 .78173 m .55971 .81788 L .59063 .81642 L p .707 .577 .707 r
F P
0 g
s
.6465 .768 m .65136 .80415 L .67524 .79453 L p .707 .577 .707 r
F P
0 g
s
.67524 .79453 m .67038 .75838 L .6465 .768 L p .707 .577 .707 r
F P
0 g
s
.67994 .67802 m .68791 .73206 L .7042 .72101 L p .707 .577 .707 r
F P
0 g
s
.7042 .72101 m .69623 .66696 L .67994 .67802 L p .707 .577 .707 r
F P
0 g
s
.59936 .84191 m .60293 .82336 L .57231 .81632 L p .707 .577 .707 r
F P
0 g
s
.60293 .82336 m .59936 .84191 L .63064 .84718 L p .707 .577 .707 r
F P
0 g
s
.63064 .84718 m .63422 .82863 L .60293 .82336 L p .707 .577 .707 r
F P
0 g
s
.52762 .77976 m .53248 .81591 L .55971 .81788 L p .707 .577 .707 r
F P
0 g
s
.57231 .81632 m .56874 .83487 L .59936 .84191 L p .707 .577 .707 r
F P
0 g
s
.63422 .82863 m .63064 .84718 L .65953 .85015 L p .707 .577 .707 r
F P
0 g
s
.65953 .85015 m .6631 .8316 L .63422 .82863 L p .707 .577 .707 r
F P
0 g
s
.53248 .81591 m .52762 .77976 L .50676 .77458 L p .707 .577 .707 r
F P
0 g
s
.56874 .83487 m .57231 .81632 L .54535 .80819 L p .707 .577 .707 r
F P
0 g
s
.5166 .69585 m .52457 .7499 L .54535 .75499 L p .707 .577 .707 r
F P
0 g
s
.54535 .80819 m .54178 .82675 L .56874 .83487 L p .707 .577 .707 r
F P
0 g
s
.52457 .7499 m .5166 .69585 L .50421 .68793 L p .707 .577 .707 r
F P
0 g
s
.67038 .75838 m .67524 .79453 L .6915 .78378 L p .707 .577 .707 r
F P
0 g
s
.6915 .78378 m .68664 .74763 L .67038 .75838 L p .707 .577 .707 r
F P
0 g
s
.50676 .77458 m .51162 .81072 L .53248 .81591 L p .707 .577 .707 r
F P
0 g
s
.6631 .8316 m .65953 .85015 L .68319 .85055 L p .707 .577 .707 r
F P
0 g
s
.68319 .85055 m .68676 .83199 L .6631 .8316 L p .707 .577 .707 r
F P
0 g
s
.69623 .66696 m .7042 .72101 L .7113 .70995 L p .707 .577 .707 r
F P
0 g
s
.7113 .70995 m .70333 .65591 L .69623 .66696 L p .707 .577 .707 r
F P
0 g
s
.54178 .82675 m .54535 .80819 L .52469 .79977 L p .707 .577 .707 r
F P
0 g
s
.52469 .79977 m .52112 .81833 L .54178 .82675 L p .707 .577 .707 r
F P
0 g
s
.51162 .81072 m .50676 .77458 L .49429 .76667 L p .707 .577 .707 r
F P
0 g
s
.50421 .68793 m .51218 .74197 L .52457 .7499 L p .707 .577 .707 r
F P
0 g
s
.68664 .74763 m .6915 .78378 L .69856 .77295 L p .707 .577 .707 r
F P
0 g
s
.69856 .77295 m .6937 .7368 L .68664 .74763 L p .707 .577 .707 r
F P
0 g
s
.68676 .83199 m .68319 .85055 L .6993 .84832 L p .707 .577 .707 r
F P
0 g
s
.6993 .84832 m .70288 .82976 L .68676 .83199 L p .707 .577 .707 r
F P
0 g
s
.51218 .74197 m .50421 .68793 L .50143 .67795 L p .707 .577 .707 r
F P
0 g
s
.49429 .76667 m .49915 .80282 L .51162 .81072 L p .707 .577 .707 r
F P
0 g
s
.52112 .81833 m .52469 .79977 L .51235 .79189 L p .707 .577 .707 r
F P
0 g
s
.70333 .65591 m .7113 .70995 L .70852 .69997 L p .707 .577 .707 r
F P
0 g
s
.70852 .69997 m .70055 .64593 L .70333 .65591 L p .707 .577 .707 r
F P
0 g
s
.51235 .79189 m .50878 .81044 L .52112 .81833 L p .707 .577 .707 r
F P
0 g
s
.49915 .80282 m .49429 .76667 L .49144 .75682 L p .707 .577 .707 r
F P
0 g
s
.50143 .67795 m .5094 .732 L .51218 .74197 L p .707 .577 .707 r
F P
0 g
s
.48863 .8218 m .48863 .31991 L .44475 .31708 L p .707 .577 .707 r
F P
0 g
s
.49144 .75682 m .4963 .79296 L .49915 .80282 L p .707 .577 .707 r
F P
0 g
s
.5094 .732 m .50143 .67795 L .50853 .66689 L p .707 .577 .707 r
F P
0 g
s
.50878 .81044 m .51235 .79189 L .50954 .78531 L p .707 .577 .707 r
F P
0 g
s
.50954 .78531 m .50597 .80386 L .50878 .81044 L p .707 .577 .707 r
F P
0 g
s
.4963 .79296 m .49144 .75682 L .4985 .74599 L p .707 .577 .707 r
F P
0 g
s
.50853 .66689 m .5165 .72094 L .5094 .732 L p .707 .577 .707 r
F P
0 g
s
.5165 .72094 m .50853 .66689 L .52482 .65584 L p .707 .577 .707 r
F P
0 g
s
.4985 .74599 m .50336 .78213 L .4963 .79296 L p .707 .577 .707 r
F P
0 g
s
.50597 .80386 m .50954 .78531 L .51654 .78068 L p .707 .577 .707 r
F P
0 g
s
.51654 .78068 m .51296 .79923 L .50597 .80386 L p .707 .577 .707 r
F P
0 g
s
.50336 .78213 m .4985 .74599 L .51476 .73524 L p .707 .577 .707 r
F P
0 g
s
.52482 .65584 m .53279 .70988 L .5165 .72094 L p .707 .577 .707 r
F P
0 g
s
.51476 .73524 m .51962 .77138 L .50336 .78213 L p .707 .577 .707 r
F P
0 g
s
.51296 .79923 m .51654 .78068 L .53265 .77845 L p .707 .577 .707 r
F P
0 g
s
.53265 .77845 m .52908 .797 L .51296 .79923 L p .707 .577 .707 r
F P
0 g
s
.51962 .77138 m .51476 .73524 L .53863 .72562 L p .707 .577 .707 r
F P
0 g
s
.53863 .72562 m .54349 .76177 L .51962 .77138 L p .707 .577 .707 r
F P
0 g
s
.52908 .797 m .53265 .77845 L .55631 .77884 L p .707 .577 .707 r
F P
0 g
s
.55631 .77884 m .55273 .79739 L .52908 .797 L p .707 .577 .707 r
F P
0 g
s
.48863 .31991 m .48863 .8218 L .53362 .82086 L p .707 .577 .707 r
F P
0 g
s
.53279 .70988 m .52482 .65584 L .5487 .64587 L p .707 .577 .707 r
F P
0 g
s
.5487 .64587 m .55667 .69991 L .53279 .70988 L p .707 .577 .707 r
F P
0 g
s
.53362 .82086 m .53362 .31897 L .48863 .31991 L p .707 .577 .707 r
F P
0 g
s
.55667 .69991 m .5487 .64587 L .57783 .63796 L p .707 .577 .707 r
F P
0 g
s
.57783 .63796 m .5858 .69201 L .55667 .69991 L p .707 .577 .707 r
F P
0 g
s
.54349 .76177 m .53863 .72562 L .56779 .71808 L p .707 .577 .707 r
F P
0 g
s
.56779 .71808 m .57265 .75422 L .54349 .76177 L p .707 .577 .707 r
F P
0 g
s
.55273 .79739 m .55631 .77884 L .58519 .78181 L p .707 .577 .707 r
F P
0 g
s
.58519 .78181 m .58162 .80037 L .55273 .79739 L p .707 .577 .707 r
F P
0 g
s
.53362 .31897 m .53362 .82086 L .57532 .81623 L p .707 .577 .707 r
F P
0 g
s
.57265 .75422 m .56779 .71808 L .59937 .71335 L p .707 .577 .707 r
F P
0 g
s
.59937 .71335 m .60423 .74949 L .57265 .75422 L p .707 .577 .707 r
F P
0 g
s
.57532 .81623 m .57532 .31434 L .53362 .31897 L p .707 .577 .707 r
F P
0 g
s
.6937 .7368 m .69856 .77295 L .69571 .7631 L p .707 .577 .707 r
F P
0 g
s
.69571 .7631 m .69085 .72695 L .6937 .7368 L p .707 .577 .707 r
F P
0 g
s
.70288 .82976 m .6993 .84832 L .7063 .84369 L p .707 .577 .707 r
F P
0 g
s
.7063 .84369 m .70987 .82513 L .70288 .82976 L p .707 .577 .707 r
F P
0 g
s
.44475 .81897 m .44475 .31708 L .40628 .31075 L p .707 .577 .707 r
F P
0 g
s
.44475 .31708 m .44475 .81897 L .48863 .8218 L p .707 .577 .707 r
F P
0 g
s
.70055 .64593 m .70852 .69997 L .69613 .69205 L p .707 .577 .707 r
F P
0 g
s
.69613 .69205 m .68816 .638 L .70055 .64593 L p .707 .577 .707 r
F P
0 g
s
.5858 .69201 m .57783 .63796 L .60937 .63289 L p .707 .577 .707 r
F P
0 g
s
.60937 .63289 m .61734 .68694 L .5858 .69201 L p .707 .577 .707 r
F P
0 g
s
.63029 .71189 m .63515 .74804 L .60423 .74949 L p .707 .577 .707 r
F P
0 g
s
.60423 .74949 m .59937 .71335 L .63029 .71189 L p .707 .577 .707 r
F P
0 g
s
.58162 .80037 m .58519 .78181 L .61648 .78708 L p .707 .577 .707 r
F P
0 g
s
.61648 .78708 m .6129 .80563 L .58162 .80037 L p .707 .577 .707 r
F P
0 g
s
.57532 .31434 m .57532 .81623 L .60965 .80837 L p .707 .577 .707 r
F P
0 g
s
.61734 .68694 m .60937 .63289 L .64023 .63115 L p .707 .577 .707 r
F P
0 g
s
.60965 .80837 m .60965 .30648 L .57532 .31434 L p .707 .577 .707 r
F P
0 g
s
.25637 .70092 m .25293 .64384 L .22181 .64474 L p .707 .577 .707 r
F P
0 g
s
.25293 .64384 m .25637 .70092 L .28814 .69866 L p .707 .577 .707 r
F P
0 g
s
.28814 .69866 m .28471 .64157 L .25293 .64384 L p .707 .577 .707 r
F P
0 g
s
.28471 .64157 m .28814 .69866 L .31747 .69526 L p .707 .577 .707 r
F P
0 g
s
.31747 .69526 m .31404 .63817 L .28471 .64157 L p .707 .577 .707 r
F P
0 g
s
.40628 .81264 m .40628 .31075 L .37698 .30154 L p .707 .577 .707 r
F P
0 g
s
.40628 .31075 m .40628 .81264 L .44475 .81897 L p .707 .577 .707 r
F P
0 g
s
.69085 .72695 m .69571 .7631 L .68324 .75519 L p .707 .577 .707 r
F P
0 g
s
.68324 .75519 m .67838 .71904 L .69085 .72695 L p .707 .577 .707 r
F P
0 g
s
.70987 .82513 m .7063 .84369 L .70349 .8371 L p .707 .577 .707 r
F P
0 g
s
.70349 .8371 m .70706 .81855 L .70987 .82513 L p .707 .577 .707 r
F P
0 g
s
.22525 .70182 m .22181 .64474 L .1944 .64419 L p .707 .577 .707 r
F P
0 g
s
.22181 .64474 m .22525 .70182 L .25637 .70092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31404 .63817 m .31747 .69526 L .34147 .69105 L p .707 .577 .707 r
F P
0 g
s
.34147 .69105 m .33804 .63396 L .31404 .63817 L p .707 .577 .707 r
F P
0 g
s
.1944 .64419 m .19783 .70127 L .22525 .70182 L p .707 .577 .707 r
F P
0 g
s
.68816 .638 m .69613 .69205 L .67534 .68696 L p .707 .577 .707 r
F P
0 g
s
.67534 .68696 m .66738 .63291 L .68816 .638 L p .707 .577 .707 r
F P
0 g
s
.64023 .63115 m .6482 .6852 L .61734 .68694 L p .707 .577 .707 r
F P
0 g
s
.6471 .79412 m .64352 .81267 L .6129 .80563 L p .707 .577 .707 r
F P
0 g
s
.6129 .80563 m .61648 .78708 L .6471 .79412 L p .707 .577 .707 r
F P
0 g
s
.60965 .30648 m .60965 .80837 L .63324 .79804 L p .707 .577 .707 r
F P
0 g
s
.63515 .74804 m .63029 .71189 L .65751 .71385 L p .707 .577 .707 r
F P
0 g
s
.63324 .79804 m .63324 .29615 L .60965 .30648 L p .707 .577 .707 r
F P
0 g
s
.19783 .70127 m .1944 .64419 L .17337 .64224 L p .707 .577 .707 r
F P
0 g
s
.17337 .64224 m .1768 .69933 L .19783 .70127 L p .707 .577 .707 r
F P
0 g
s
.25097 .75914 m .24888 .72113 L .21774 .7218 L p .707 .577 .707 r
F P
0 g
s
.24888 .72113 m .25097 .75914 L .28275 .757 L p .707 .577 .707 r
F P
0 g
s
.28275 .757 m .28066 .71899 L .24888 .72113 L p .707 .577 .707 r
F P
0 g
s
.67838 .71904 m .68324 .75519 L .66238 .75 L p .707 .577 .707 r
F P
0 g
s
.66238 .75 m .65751 .71385 L .67838 .71904 L p .707 .577 .707 r
F P
0 g
s
.28066 .71899 m .28275 .757 L .31207 .75359 L p .707 .577 .707 r
F P
0 g
s
.31207 .75359 m .30998 .71558 L .28066 .71899 L p .707 .577 .707 r
F P
0 g
s
.33804 .63396 m .34147 .69105 L .3578 .68644 L p .707 .577 .707 r
F P
0 g
s
.3578 .68644 m .35437 .62935 L .33804 .63396 L p .707 .577 .707 r
F P
0 g
s
.21774 .7218 m .21983 .7598 L .25097 .75914 L p .707 .577 .707 r
F P
0 g
s
.37698 .80343 m .37698 .30154 L .35973 .29035 L p .707 .577 .707 r
F P
0 g
s
.37698 .30154 m .37698 .80343 L .40628 .81264 L p .707 .577 .707 r
F P
0 g
s
.70706 .81855 m .70349 .8371 L .69115 .82922 L p .707 .577 .707 r
F P
0 g
s
.69115 .82922 m .69472 .81067 L .70706 .81855 L p .707 .577 .707 r
F P
0 g
s
.21983 .7598 m .21774 .7218 L .19029 .72092 L p .707 .577 .707 r
F P
0 g
s
.66738 .63291 m .67534 .68696 L .6482 .6852 L p .707 .577 .707 r
F P
0 g
s
.6482 .6852 m .64023 .63115 L .66738 .63291 L p .707 .577 .707 r
F P
0 g
s
.25498 .83284 m .25653 .81565 L .22542 .81033 L p .707 .577 .707 r
F P
0 g
s
.25653 .81565 m .25498 .83284 L .2867 .83379 L p .707 .577 .707 r
F P
0 g
s
.2867 .83379 m .28825 .8166 L .25653 .81565 L p .707 .577 .707 r
F P
0 g
s
.19029 .72092 m .19238 .75892 L .21983 .7598 L p .707 .577 .707 r
F P
0 g
s
.28825 .8166 m .2867 .83379 L .31593 .83028 L p .707 .577 .707 r
F P
0 g
s
.31593 .83028 m .31748 .81309 L .28825 .8166 L p .707 .577 .707 r
F P
0 g
s
.22388 .82752 m .22542 .81033 L .19798 .80115 L p .707 .577 .707 r
F P
0 g
s
.22542 .81033 m .22388 .82752 L .25498 .83284 L p .707 .577 .707 r
F P
0 g
s
.30998 .71558 m .31207 .75359 L .33605 .74925 L p .707 .577 .707 r
F P
0 g
s
.33605 .74925 m .33396 .71124 L .30998 .71558 L p .707 .577 .707 r
F P
0 g
s
.1768 .69933 m .17337 .64224 L .16079 .63909 L p .707 .577 .707 r
F P
0 g
s
.19798 .80115 m .19643 .81835 L .22388 .82752 L p .707 .577 .707 r
F P
0 g
s
.19238 .75892 m .19029 .72092 L .16922 .71858 L p .707 .577 .707 r
F P
0 g
s
.16079 .63909 m .16422 .69617 L .1768 .69933 L p .707 .577 .707 r
F P
0 g
s
.65751 .71385 m .66238 .75 L .63515 .74804 L p .707 .577 .707 r
F P
0 g
s
.63324 .29615 m .63324 .79804 L .6438 .78627 L p .707 .577 .707 r
F P
0 g
s
.6438 .78627 m .6438 .28438 L .63324 .29615 L p .707 .577 .707 r
F P
0 g
s
.31748 .81309 m .31593 .83028 L .33981 .82265 L p .707 .577 .707 r
F P
0 g
s
.33981 .82265 m .34135 .80546 L .31748 .81309 L p .707 .577 .707 r
F P
0 g
s
.19643 .81835 m .19798 .80115 L .17688 .78903 L p .707 .577 .707 r
F P
0 g
s
.16922 .71858 m .17132 .75659 L .19238 .75892 L p .707 .577 .707 r
F P
0 g
s
.35437 .62935 m .3578 .68644 L .36486 .68189 L p .707 .577 .707 r
F P
0 g
s
.36486 .68189 m .36143 .6248 L .35437 .62935 L p .707 .577 .707 r
F P
0 g
s
.69472 .81067 m .69115 .82922 L .67048 .8208 L p .707 .577 .707 r
F P
0 g
s
.67048 .8208 m .67406 .80225 L .69472 .81067 L p .707 .577 .707 r
F P
0 g
s
.33396 .71124 m .33605 .74925 L .35234 .74439 L p .707 .577 .707 r
F P
0 g
s
.35234 .74439 m .35025 .70639 L .33396 .71124 L p .707 .577 .707 r
F P
0 g
s
.17688 .78903 m .17534 .80623 L .19643 .81835 L p .707 .577 .707 r
F P
0 g
s
.16422 .69617 m .16079 .63909 L .15789 .63504 L p .707 .577 .707 r
F P
0 g
s
.34135 .80546 m .33981 .82265 L .356 .81165 L p .707 .577 .707 r
F P
0 g
s
.356 .81165 m .35755 .79446 L .34135 .80546 L p .707 .577 .707 r
F P
0 g
s
.36196 .67784 m .35853 .62075 L .36143 .6248 L p .707 .577 .707 r
F P
0 g
s
.36292 .79835 m .36446 .78116 L .35755 .79446 L p .707 .577 .707 r
F P
0 g
s
.35853 .62075 m .36196 .67784 L .34938 .67469 L p .707 .577 .707 r
F P
0 g
s
.36143 .76687 m .35988 .78406 L .3472 .77018 L p .707 .577 .707 r
F P
0 g
s
.3472 .77018 m .34875 .75298 L .36143 .76687 L p .707 .577 .707 r
F P
0 g
s
.35973 .79224 m .35973 .29035 L .3562 .27828 L p .707 .577 .707 r
F P
0 g
s
.36143 .6248 m .36486 .68189 L .36196 .67784 L p .707 .577 .707 r
F P
0 g
s
.36446 .78116 m .36292 .79835 L .35988 .78406 L p .707 .577 .707 r
F P
0 g
s
.35988 .78406 m .36143 .76687 L .36446 .78116 L p .707 .577 .707 r
F P
0 g
s
.35973 .29035 m .35973 .79224 L .37698 .80343 L p .707 .577 .707 r
F P
0 g
s
.17132 .75659 m .16922 .71858 L .1566 .71502 L p .707 .577 .707 r
F P
0 g
s
.17534 .80623 m .17688 .78903 L .1642 .77515 L p .707 .577 .707 r
F P
0 g
s
.15789 .63504 m .16132 .69212 L .16422 .69617 L p .707 .577 .707 r
F P
0 g
s
.1566 .71502 m .15869 .75302 L .17132 .75659 L p .707 .577 .707 r
F P
0 g
s
.1642 .77515 m .16265 .79234 L .17534 .80623 L p .707 .577 .707 r
F P
0 g
s
.67406 .80225 m .67048 .8208 L .64352 .81267 L p .707 .577 .707 r
F P
0 g
s
.64352 .81267 m .6471 .79412 L .67406 .80225 L p .707 .577 .707 r
F P
0 g
s
.35025 .70639 m .35234 .74439 L .35936 .73951 L p .707 .577 .707 r
F P
0 g
s
.35936 .73951 m .35727 .7015 L .35025 .70639 L p .707 .577 .707 r
F P
0 g
s
.6438 .28438 m .6438 .78627 L .64027 .7742 L p .707 .577 .707 r
F P
0 g
s
.64027 .7742 m .64027 .27231 L .6438 .28438 L p .707 .577 .707 r
F P
0 g
s
.35755 .79446 m .356 .81165 L .36292 .79835 L p .707 .577 .707 r
F P
0 g
s
.16265 .79234 m .1642 .77515 L .16117 .76085 L p .707 .577 .707 r
F P
0 g
s
.15869 .75302 m .1566 .71502 L .15365 .71057 L p .707 .577 .707 r
F P
0 g
s
.16132 .69212 m .15789 .63504 L .16495 .63049 L p .707 .577 .707 r
F P
0 g
s
.15365 .71057 m .15574 .74858 L .15869 .75302 L p .707 .577 .707 r
F P
0 g
s
.16117 .76085 m .15962 .77805 L .16265 .79234 L p .707 .577 .707 r
F P
0 g
s
.16495 .63049 m .16838 .68757 L .16132 .69212 L p .707 .577 .707 r
F P
0 g
s
.35727 .7015 m .35936 .73951 L .35641 .73506 L p .707 .577 .707 r
F P
0 g
s
.35641 .73506 m .35432 .69706 L .35727 .7015 L p .707 .577 .707 r
F P
0 g
s
.34938 .67469 m .34595 .6176 L .35853 .62075 L p .707 .577 .707 r
F P
0 g
s
.35432 .69706 m .35641 .73506 L .34379 .7315 L p .707 .577 .707 r
F P
0 g
s
.3562 .27828 m .3562 .78017 L .35973 .79224 L p .707 .577 .707 r
F P
0 g
s
.3562 .78017 m .3562 .27828 L .36675 .2665 L p .707 .577 .707 r
F P
0 g
s
.15962 .77805 m .16117 .76085 L .16809 .74756 L p .707 .577 .707 r
F P
0 g
s
.16838 .68757 m .16495 .63049 L .18128 .62588 L p .707 .577 .707 r
F P
0 g
s
.15574 .74858 m .15365 .71057 L .16067 .70569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64027 .27231 m .64027 .7742 L .62301 .76301 L p .707 .577 .707 r
F P
0 g
s
.62301 .76301 m .62301 .26112 L .64027 .27231 L p .707 .577 .707 r
F P
0 g
s
.16809 .74756 m .16654 .76475 L .15962 .77805 L p .707 .577 .707 r
F P
0 g
s
.16067 .70569 m .16276 .74369 L .15574 .74858 L p .707 .577 .707 r
F P
0 g
s
.18128 .62588 m .18471 .68297 L .16838 .68757 L p .707 .577 .707 r
F P
0 g
s
.34595 .6176 m .34938 .67469 L .32835 .67274 L p .707 .577 .707 r
F P
0 g
s
.32835 .67274 m .32492 .61565 L .34595 .6176 L p .707 .577 .707 r
F P
0 g
s
.34379 .7315 m .34169 .69349 L .35432 .69706 L p .707 .577 .707 r
F P
0 g
s
.16654 .76475 m .16809 .74756 L .18428 .73656 L p .707 .577 .707 r
F P
0 g
s
.36675 .76839 m .36675 .2665 L .39035 .25618 L p .707 .577 .707 r
F P
0 g
s
.36675 .2665 m .36675 .76839 L .3562 .78017 L p .707 .577 .707 r
F P
0 g
s
.18471 .68297 m .18128 .62588 L .20528 .62167 L p .707 .577 .707 r
F P
0 g
s
.16276 .74369 m .16067 .70569 L .17696 .70083 L p .707 .577 .707 r
F P
0 g
s
.18428 .73656 m .18273 .75375 L .16654 .76475 L p .707 .577 .707 r
F P
0 g
s
.20528 .62167 m .20872 .67876 L .18471 .68297 L p .707 .577 .707 r
F P
0 g
s
.17696 .70083 m .17906 .73884 L .16276 .74369 L p .707 .577 .707 r
F P
0 g
s
.32492 .61565 m .32835 .67274 L .30094 .67219 L p .707 .577 .707 r
F P
0 g
s
.30094 .67219 m .29751 .6151 L .32492 .61565 L p .707 .577 .707 r
F P
0 g
s
.62301 .26112 m .62301 .76301 L .59372 .7538 L p .707 .577 .707 r
F P
0 g
s
.59372 .7538 m .59372 .25191 L .62301 .26112 L p .707 .577 .707 r
F P
0 g
s
.34875 .75298 m .3472 .77018 L .3261 .75805 L p .707 .577 .707 r
F P
0 g
s
.3261 .75805 m .32765 .74086 L .34875 .75298 L p .707 .577 .707 r
F P
0 g
s
.34169 .69349 m .34379 .7315 L .32272 .72916 L p .707 .577 .707 r
F P
0 g
s
.32272 .72916 m .32063 .69116 L .34169 .69349 L p .707 .577 .707 r
F P
0 g
s
.20872 .67876 m .20528 .62167 L .23461 .61826 L p .707 .577 .707 r
F P
0 g
s
.18273 .75375 m .18428 .73656 L .20816 .72893 L p .707 .577 .707 r
F P
0 g
s
.29751 .6151 m .30094 .67219 L .26982 .67309 L p .707 .577 .707 r
F P
0 g
s
.26982 .67309 m .26639 .616 L .29751 .6151 L p .707 .577 .707 r
F P
0 g
s
.23461 .61826 m .23804 .67535 L .20872 .67876 L p .707 .577 .707 r
F P
0 g
s
.20816 .72893 m .20661 .74612 L .18273 .75375 L p .707 .577 .707 r
F P
0 g
s
.17906 .73884 m .17696 .70083 L .20094 .69649 L p .707 .577 .707 r
F P
0 g
s
.23804 .67535 m .23461 .61826 L .26639 .616 L p .707 .577 .707 r
F P
0 g
s
.39035 .25618 m .39035 .75807 L .36675 .76839 L p .707 .577 .707 r
F P
0 g
s
.39035 .75807 m .39035 .25618 L .42467 .24832 L p .707 .577 .707 r
F P
0 g
s
.26639 .616 m .26982 .67309 L .23804 .67535 L p .707 .577 .707 r
F P
0 g
s
.20094 .69649 m .20303 .7345 L .17906 .73884 L p .707 .577 .707 r
F P
0 g
s
.73018 .66809 m .73361 .61527 L .70249 .61075 L p .707 .577 .707 r
F P
0 g
s
.73361 .61527 m .73018 .66809 L .76196 .66867 L p .707 .577 .707 r
F P
0 g
s
.76196 .66867 m .76539 .61585 L .73361 .61527 L p .707 .577 .707 r
F P
0 g
s
.32765 .74086 m .3261 .75805 L .29866 .74888 L p .707 .577 .707 r
F P
0 g
s
.29866 .74888 m .30021 .73169 L .32765 .74086 L p .707 .577 .707 r
F P
0 g
s
.76539 .61585 m .76196 .66867 L .79128 .66524 L p .707 .577 .707 r
F P
0 g
s
.79128 .66524 m .79471 .61243 L .76539 .61585 L p .707 .577 .707 r
F P
0 g
s
.20661 .74612 m .20816 .72893 L .23739 .72541 L p .707 .577 .707 r
F P
0 g
s
.32063 .69116 m .32272 .72916 L .29527 .72828 L p .707 .577 .707 r
F P
0 g
s
.29527 .72828 m .29318 .69028 L .32063 .69116 L p .707 .577 .707 r
F P
0 g
s
.69906 .66357 m .70249 .61075 L .67508 .60273 L p .707 .577 .707 r
F P
0 g
s
.70249 .61075 m .69906 .66357 L .73018 .66809 L p .707 .577 .707 r
F P
0 g
s
.59372 .25191 m .59372 .7538 L .55525 .74746 L p .707 .577 .707 r
F P
0 g
s
.55525 .74746 m .55525 .24558 L .59372 .25191 L p .707 .577 .707 r
F P
0 g
s
.23739 .72541 m .23584 .74261 L .20661 .74612 L p .707 .577 .707 r
F P
0 g
s
.73586 .73097 m .73796 .69556 L .70682 .69127 L p .707 .577 .707 r
F P
0 g
s
.73796 .69556 m .73586 .73097 L .76765 .73142 L p .707 .577 .707 r
F P
0 g
s
.76765 .73142 m .76974 .69601 L .73796 .69556 L p .707 .577 .707 r
F P
0 g
s
.20303 .7345 m .20094 .69649 L .23026 .69308 L p .707 .577 .707 r
F P
0 g
s
.30021 .73169 m .29866 .74888 L .26756 .74356 L p .707 .577 .707 r
F P
0 g
s
.26756 .74356 m .26911 .72637 L .30021 .73169 L p .707 .577 .707 r
F P
0 g
s
.76974 .69601 m .76765 .73142 L .79696 .72799 L p .707 .577 .707 r
F P
0 g
s
.79696 .72799 m .79906 .69258 L .76974 .69601 L p .707 .577 .707 r
F P
0 g
s
.79471 .61243 m .79128 .66524 L .81529 .65815 L p .707 .577 .707 r
F P
0 g
s
.81529 .65815 m .81872 .60534 L .79471 .61243 L p .707 .577 .707 r
F P
0 g
s
.23584 .74261 m .23739 .72541 L .26911 .72637 L p .707 .577 .707 r
F P
0 g
s
.70472 .72668 m .70682 .69127 L .67937 .68357 L p .707 .577 .707 r
F P
0 g
s
.70682 .69127 m .70472 .72668 L .73586 .73097 L p .707 .577 .707 r
F P
0 g
s
.23026 .69308 m .23235 .73109 L .20303 .7345 L p .707 .577 .707 r
F P
0 g
s
.26911 .72637 m .26756 .74356 L .23584 .74261 L p .707 .577 .707 r
F P
0 g
s
.67164 .65554 m .67508 .60273 L .65405 .59199 L p .707 .577 .707 r
F P
0 g
s
.67508 .60273 m .67164 .65554 L .69906 .66357 L p .707 .577 .707 r
F P
0 g
s
.29318 .69028 m .29527 .72828 L .26413 .72895 L p .707 .577 .707 r
F P
0 g
s
.26413 .72895 m .26204 .69094 L .29318 .69028 L p .707 .577 .707 r
F P
0 g
s
.42467 .75021 m .42467 .24832 L .46637 .24369 L p .707 .577 .707 r
F P
0 g
s
.42467 .24832 m .42467 .75021 L .39035 .75807 L p .707 .577 .707 r
F P
0 g
s
.23235 .73109 m .23026 .69308 L .26204 .69094 L p .707 .577 .707 r
F P
0 g
s
.79906 .69258 m .79696 .72799 L .82094 .72101 L p .707 .577 .707 r
F P
0 g
s
.82094 .72101 m .82304 .68561 L .79906 .69258 L p .707 .577 .707 r
F P
0 g
s
.26204 .69094 m .26413 .72895 L .23235 .73109 L p .707 .577 .707 r
F P
0 g
s
.67728 .71897 m .67937 .68357 L .6583 .6732 L p .707 .577 .707 r
F P
0 g
s
.67937 .68357 m .67728 .71897 L .70472 .72668 L p .707 .577 .707 r
F P
0 g
s
.55525 .24558 m .55525 .74746 L .51137 .74463 L p .707 .577 .707 r
F P
0 g
s
.51137 .74463 m .51137 .24274 L .55525 .24558 L p .707 .577 .707 r
F P
0 g
s
.81872 .60534 m .81529 .65815 L .83162 .64809 L p .707 .577 .707 r
F P
0 g
s
.83162 .64809 m .83505 .59527 L .81872 .60534 L p .707 .577 .707 r
F P
0 g
s
.73244 .74043 m .73089 .72133 L .69979 .72324 L p .707 .577 .707 r
F P
0 g
s
.73089 .72133 m .73244 .74043 L .76416 .73762 L p .707 .577 .707 r
F P
0 g
s
.76416 .73762 m .76261 .71852 L .73089 .72133 L p .707 .577 .707 r
F P
0 g
s
.69979 .72324 m .70134 .74234 L .73244 .74043 L p .707 .577 .707 r
F P
0 g
s
.76261 .71852 m .76416 .73762 L .79339 .73418 L p .707 .577 .707 r
F P
0 g
s
.79339 .73418 m .79184 .71508 L .76261 .71852 L p .707 .577 .707 r
F P
0 g
s
.46637 .74558 m .46637 .24369 L .51137 .24274 L p .707 .577 .707 r
F P
0 g
s
.46637 .24369 m .46637 .74558 L .42467 .75021 L p .707 .577 .707 r
F P
0 g
s
.65062 .6448 m .65405 .59199 L .64147 .57958 L p .707 .577 .707 r
F P
0 g
s
.65405 .59199 m .65062 .6448 L .67164 .65554 L p .707 .577 .707 r
F P
0 g
s
.51137 .24274 m .51137 .74463 L .46637 .74558 L p .707 .577 .707 r
F P
0 g
s
.70134 .74234 m .69979 .72324 L .67235 .72406 L p .707 .577 .707 r
F P
0 g
s
.67235 .72406 m .67389 .74317 L .70134 .74234 L p .707 .577 .707 r
F P
0 g
s
.6583 .6732 m .65621 .7086 L .67728 .71897 L p .707 .577 .707 r
F P
0 g
s
.82304 .68561 m .82094 .72101 L .83724 .71117 L p .707 .577 .707 r
F P
0 g
s
.83724 .71117 m .83933 .67577 L .82304 .68561 L p .707 .577 .707 r
F P
0 g
s
.79184 .71508 m .79339 .73418 L .81727 .73046 L p .707 .577 .707 r
F P
0 g
s
.81727 .73046 m .81572 .71136 L .79184 .71508 L p .707 .577 .707 r
F P
0 g
s
.65621 .7086 m .6583 .6732 L .64568 .66118 L p .707 .577 .707 r
F P
0 g
s
.83505 .59527 m .83162 .64809 L .83868 .63604 L p .707 .577 .707 r
F P
0 g
s
.83868 .63604 m .84211 .58322 L .83505 .59527 L p .707 .577 .707 r
F P
0 g
s
.67389 .74317 m .67235 .72406 L .65125 .72372 L p .707 .577 .707 r
F P
0 g
s
.65125 .72372 m .6528 .74282 L .67389 .74317 L p .707 .577 .707 r
F P
0 g
s
.64147 .57958 m .63804 .6324 L .65062 .6448 L p .707 .577 .707 r
F P
0 g
s
.63804 .6324 m .64147 .57958 L .63857 .56672 L p .707 .577 .707 r
F P
0 g
s
.64568 .66118 m .64358 .69658 L .65621 .7086 L p .707 .577 .707 r
F P
0 g
s
.83933 .67577 m .83724 .71117 L .84426 .69943 L p .707 .577 .707 r
F P
0 g
s
.84426 .69943 m .84635 .66403 L .83933 .67577 L p .707 .577 .707 r
F P
0 g
s
.81572 .71136 m .81727 .73046 L .83346 .72681 L p .707 .577 .707 r
F P
0 g
s
.83346 .72681 m .83191 .70771 L .81572 .71136 L p .707 .577 .707 r
F P
0 g
s
.64358 .69658 m .64568 .66118 L .64273 .64869 L p .707 .577 .707 r
F P
0 g
s
.6528 .74282 m .65125 .72372 L .63857 .72225 L p .707 .577 .707 r
F P
0 g
s
.63857 .72225 m .64011 .74135 L .6528 .74282 L p .707 .577 .707 r
F P
0 g
s
.84211 .58322 m .83868 .63604 L .83577 .62318 L p .707 .577 .707 r
F P
0 g
s
.83577 .62318 m .83921 .57037 L .84211 .58322 L p .707 .577 .707 r
F P
0 g
s
.63857 .56672 m .63513 .61954 L .63804 .6324 L p .707 .577 .707 r
F P
0 g
s
.64273 .64869 m .64064 .68409 L .64358 .69658 L p .707 .577 .707 r
F P
0 g
s
.63513 .61954 m .63857 .56672 L .64563 .55467 L p .707 .577 .707 r
F P
0 g
s
.83191 .70771 m .83346 .72681 L .84038 .7236 L p .707 .577 .707 r
F P
0 g
s
.84038 .7236 m .83883 .7045 L .83191 .70771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84635 .66403 m .84426 .69943 L .84131 .68694 L p .707 .577 .707 r
F P
0 g
s
.84131 .68694 m .8434 .65153 L .84635 .66403 L p .707 .577 .707 r
F P
0 g
s
.64064 .68409 m .64273 .64869 L .64975 .63695 L p .707 .577 .707 r
F P
0 g
s
.64011 .74135 m .63857 .72225 L .63553 .71978 L p .707 .577 .707 r
F P
0 g
s
.63553 .71978 m .63708 .73888 L .64011 .74135 L p .707 .577 .707 r
F P
0 g
s
.83921 .57037 m .83577 .62318 L .82319 .61078 L p .707 .577 .707 r
F P
0 g
s
.82319 .61078 m .82663 .55796 L .83921 .57037 L p .707 .577 .707 r
F P
0 g
s
.64563 .55467 m .64219 .60749 L .63513 .61954 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64975 .63695 m .64765 .67235 L .64064 .68409 L p .707 .577 .707 r
F P
0 g
s
.64219 .60749 m .64563 .55467 L .66196 .54461 L p .707 .577 .707 r
F P
0 g
s
.38266 .61436 m .39062 .5585 L .35977 .55278 L p .707 .577 .707 r
F P
0 g
s
.39062 .5585 m .38266 .61436 L .41419 .61807 L p .707 .577 .707 r
F P
0 g
s
.41419 .61807 m .42216 .56221 L .39062 .5585 L p .707 .577 .707 r
F P
0 g
s
.42216 .56221 m .41419 .61807 L .44333 .6194 L p .707 .577 .707 r
F P
0 g
s
.44333 .6194 m .4513 .56354 L .42216 .56221 L p .707 .577 .707 r
F P
0 g
s
.8434 .65153 m .84131 .68694 L .82868 .67492 L p .707 .577 .707 r
F P
0 g
s
.82868 .67492 m .83077 .63951 L .8434 .65153 L p .707 .577 .707 r
F P
0 g
s
.83883 .7045 m .84038 .7236 L .83735 .72113 L p .707 .577 .707 r
F P
0 g
s
.83735 .72113 m .8358 .70203 L .83883 .7045 L p .707 .577 .707 r
F P
0 g
s
.3518 .60864 m .35977 .55278 L .33262 .54561 L p .707 .577 .707 r
F P
0 g
s
.35977 .55278 m .3518 .60864 L .38266 .61436 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64765 .67235 m .64975 .63695 L .66604 .6271 L p .707 .577 .707 r
F P
0 g
s
.4513 .56354 m .44333 .6194 L .46721 .61823 L p .707 .577 .707 r
F P
0 g
s
.46721 .61823 m .47518 .56237 L .4513 .56354 L p .707 .577 .707 r
F P
0 g
s
.33262 .54561 m .32465 .60147 L .3518 .60864 L p .707 .577 .707 r
F P
0 g
s
.82663 .55796 m .82319 .61078 L .80217 .60004 L p .707 .577 .707 r
F P
0 g
s
.80217 .60004 m .8056 .54722 L .82663 .55796 L p .707 .577 .707 r
F P
0 g
s
.63708 .73888 m .63553 .71978 L .64245 .71657 L p .707 .577 .707 r
F P
0 g
s
.32465 .60147 m .33262 .54561 L .31183 .5377 L p .707 .577 .707 r
F P
0 g
s
.64245 .71657 m .644 .73567 L .63708 .73888 L p .707 .577 .707 r
F P
0 g
s
.66196 .54461 m .65853 .59743 L .64219 .60749 L p .707 .577 .707 r
F P
0 g
s
.65853 .59743 m .66196 .54461 L .68596 .53752 L p .707 .577 .707 r
F P
0 g
s
.39576 .67398 m .40062 .63672 L .36971 .63134 L p .707 .577 .707 r
F P
0 g
s
.40062 .63672 m .39576 .67398 L .42735 .67729 L p .707 .577 .707 r
F P
0 g
s
.42735 .67729 m .43221 .64003 L .40062 .63672 L p .707 .577 .707 r
F P
0 g
s
.66604 .6271 m .66395 .66251 L .64765 .67235 L p .707 .577 .707 r
F P
0 g
s
.43221 .64003 m .42735 .67729 L .4565 .67821 L p .707 .577 .707 r
F P
0 g
s
.4565 .67821 m .46136 .64095 L .43221 .64003 L p .707 .577 .707 r
F P
0 g
s
.83077 .63951 m .82868 .67492 L .80761 .66455 L p .707 .577 .707 r
F P
0 g
s
.80761 .66455 m .80971 .62914 L .83077 .63951 L p .707 .577 .707 r
F P
0 g
s
.36485 .6686 m .36971 .63134 L .34248 .62442 L p .707 .577 .707 r
F P
0 g
s
.36971 .63134 m .36485 .6686 L .39576 .67398 L p .707 .577 .707 r
F P
0 g
s
.31183 .5377 m .30387 .59356 L .32465 .60147 L p .707 .577 .707 r
F P
0 g
s
.8358 .70203 m .83735 .72113 L .82466 .71966 L p .707 .577 .707 r
F P
0 g
s
.82466 .71966 m .82311 .70056 L .8358 .70203 L p .707 .577 .707 r
F P
0 g
s
.66395 .66251 m .66604 .6271 L .69002 .62013 L p .707 .577 .707 r
F P
0 g
s
.47518 .56237 m .46721 .61823 L .4835 .61467 L p .707 .577 .707 r
F P
0 g
s
.4835 .61467 m .49147 .55881 L .47518 .56237 L p .707 .577 .707 r
F P
0 g
s
.38709 .732 m .38352 .71426 L .3529 .71725 L p .707 .577 .707 r
F P
0 g
s
.38352 .71426 m .38709 .732 L .41838 .72546 L p .707 .577 .707 r
F P
0 g
s
.41838 .72546 m .4148 .70772 L .38352 .71426 L p .707 .577 .707 r
F P
0 g
s
.34248 .62442 m .33762 .66168 L .36485 .6686 L p .707 .577 .707 r
F P
0 g
s
.8056 .54722 m .80217 .60004 L .77475 .59201 L p .707 .577 .707 r
F P
0 g
s
.77475 .59201 m .77818 .5392 L .8056 .54722 L p .707 .577 .707 r
F P
0 g
s
.4148 .70772 m .41838 .72546 L .44726 .716 L p .707 .577 .707 r
F P
0 g
s
.44726 .716 m .44369 .69826 L .4148 .70772 L p .707 .577 .707 r
F P
0 g
s
.46136 .64095 m .4565 .67821 L .48038 .67664 L p .707 .577 .707 r
F P
0 g
s
.48038 .67664 m .48524 .63938 L .46136 .64095 L p .707 .577 .707 r
F P
0 g
s
.30387 .59356 m .31183 .5377 L .29944 .5298 L p .707 .577 .707 r
F P
0 g
s
.68253 .59034 m .68596 .53752 L .71529 .5341 L p .707 .577 .707 r
F P
0 g
s
.68596 .53752 m .68253 .59034 L .65853 .59743 L p .707 .577 .707 r
F P
0 g
s
.3529 .71725 m .35647 .73498 L .38709 .732 L p .707 .577 .707 r
F P
0 g
s
.33762 .66168 m .34248 .62442 L .32162 .61663 L p .707 .577 .707 r
F P
0 g
s
.35647 .73498 m .3529 .71725 L .32594 .71638 L p .707 .577 .707 r
F P
0 g
s
.644 .73567 m .64245 .71657 L .65864 .71292 L p .707 .577 .707 r
F P
0 g
s
.44369 .69826 m .44726 .716 L .47092 .70456 L p .707 .577 .707 r
F P
0 g
s
.47092 .70456 m .46735 .68682 L .44369 .69826 L p .707 .577 .707 r
F P
0 g
s
.65864 .71292 m .66019 .73202 L .644 .73567 L p .707 .577 .707 r
F P
0 g
s
.69002 .62013 m .68793 .65553 L .66395 .66251 L p .707 .577 .707 r
F P
0 g
s
.80971 .62914 m .80761 .66455 L .78017 .65684 L p .707 .577 .707 r
F P
0 g
s
.78017 .65684 m .78226 .62144 L .80971 .62914 L p .707 .577 .707 r
F P
0 g
s
.77818 .5392 m .77475 .59201 L .74363 .58749 L p .707 .577 .707 r
F P
0 g
s
.74363 .58749 m .74706 .53467 L .77818 .5392 L p .707 .577 .707 r
F P
0 g
s
.32594 .71638 m .32951 .73412 L .35647 .73498 L p .707 .577 .707 r
F P
0 g
s
.32162 .61663 m .31675 .65389 L .33762 .66168 L p .707 .577 .707 r
F P
0 g
s
.29944 .5298 m .29148 .58566 L .30387 .59356 L p .707 .577 .707 r
F P
0 g
s
.71185 .58691 m .71529 .5341 L .74706 .53467 L p .707 .577 .707 r
F P
0 g
s
.71529 .5341 m .71185 .58691 L .68253 .59034 L p .707 .577 .707 r
F P
0 g
s
.68793 .65553 m .69002 .62013 L .71934 .6167 L p .707 .577 .707 r
F P
0 g
s
.74706 .53467 m .74363 .58749 L .71185 .58691 L p .707 .577 .707 r
F P
0 g
s
.48524 .63938 m .48038 .67664 L .49664 .67274 L p .707 .577 .707 r
F P
0 g
s
.49664 .67274 m .5015 .63548 L .48524 .63938 L p .707 .577 .707 r
F P
0 g
s
.49147 .55881 m .4835 .61467 L .4906 .60908 L p .707 .577 .707 r
F P
0 g
s
.4906 .60908 m .49857 .55321 L .49147 .55881 L p .707 .577 .707 r
F P
0 g
s
.32951 .73412 m .32594 .71638 L .30528 .71175 L p .707 .577 .707 r
F P
0 g
s
.82311 .70056 m .82466 .71966 L .80357 .71931 L p .707 .577 .707 r
F P
0 g
s
.80357 .71931 m .80202 .70021 L .82311 .70056 L p .707 .577 .707 r
F P
0 g
s
.78226 .62144 m .78017 .65684 L .74903 .65255 L p .707 .577 .707 r
F P
0 g
s
.74903 .65255 m .75112 .61715 L .78226 .62144 L p .707 .577 .707 r
F P
0 g
s
.46735 .68682 m .47092 .70456 L .48704 .69224 L p .707 .577 .707 r
F P
0 g
s
.48704 .69224 m .48346 .6745 L .46735 .68682 L p .707 .577 .707 r
F P
0 g
s
.71725 .6521 m .71934 .6167 L .75112 .61715 L p .707 .577 .707 r
F P
0 g
s
.71934 .6167 m .71725 .6521 L .68793 .65553 L p .707 .577 .707 r
F P
0 g
s
.31675 .65389 m .32162 .61663 L .30915 .60875 L p .707 .577 .707 r
F P
0 g
s
.30528 .71175 m .30885 .72949 L .32951 .73412 L p .707 .577 .707 r
F P
0 g
s
.29148 .58566 m .29944 .5298 L .29666 .52271 L p .707 .577 .707 r
F P
0 g
s
.75112 .61715 m .74903 .65255 L .71725 .6521 L p .707 .577 .707 r
F P
0 g
s
.66019 .73202 m .65864 .71292 L .68252 .7092 L p .707 .577 .707 r
F P
0 g
s
.30915 .60875 m .30429 .646 L .31675 .65389 L p .707 .577 .707 r
F P
0 g
s
.68252 .7092 m .68407 .7283 L .66019 .73202 L p .707 .577 .707 r
F P
0 g
s
.29666 .52271 m .28869 .57857 L .29148 .58566 L p .707 .577 .707 r
F P
0 g
s
.30885 .72949 m .30528 .71175 L .29294 .70381 L p .707 .577 .707 r
F P
0 g
s
.80202 .70021 m .80357 .71931 L .77612 .72014 L p .707 .577 .707 r
F P
0 g
s
.77612 .72014 m .77458 .70104 L .80202 .70021 L p .707 .577 .707 r
F P
0 g
s
.5015 .63548 m .49664 .67274 L .50369 .6669 L p .707 .577 .707 r
F P
0 g
s
.50369 .6669 m .50855 .62964 L .5015 .63548 L p .707 .577 .707 r
F P
0 g
s
.48346 .6745 m .48704 .69224 L .49403 .68026 L p .707 .577 .707 r
F P
0 g
s
.49403 .68026 m .49046 .66252 L .48346 .6745 L p .707 .577 .707 r
F P
0 g
s
.49857 .55321 m .4906 .60908 L .48782 .60198 L p .707 .577 .707 r
F P
0 g
s
.48782 .60198 m .49579 .54612 L .49857 .55321 L p .707 .577 .707 r
F P
0 g
s
.29294 .70381 m .29651 .72155 L .30885 .72949 L p .707 .577 .707 r
F P
0 g
s
.30429 .646 m .30915 .60875 L .3063 .60153 L p .707 .577 .707 r
F P
0 g
s
.68407 .7283 m .68252 .7092 L .71175 .70576 L p .707 .577 .707 r
F P
0 g
s
.71175 .70576 m .7133 .72486 L .68407 .7283 L p .707 .577 .707 r
F P
0 g
s
.28869 .57857 m .29666 .52271 L .30377 .51711 L p .707 .577 .707 r
F P
0 g
s
.3063 .60153 m .30144 .63878 L .30429 .646 L p .707 .577 .707 r
F P
0 g
s
.77458 .70104 m .77612 .72014 L .74502 .72205 L p .707 .577 .707 r
F P
0 g
s
.74502 .72205 m .74347 .70295 L .77458 .70104 L p .707 .577 .707 r
F P
0 g
s
.7133 .72486 m .71175 .70576 L .74347 .70295 L p .707 .577 .707 r
F P
0 g
s
.74347 .70295 m .74502 .72205 L .7133 .72486 L p .707 .577 .707 r
F P
0 g
s
.30377 .51711 m .2958 .57297 L .28869 .57857 L p .707 .577 .707 r
F P
0 g
s
.29651 .72155 m .29294 .70381 L .29013 .69334 L p .707 .578 .707 r
F P
0 g
s
.50855 .62964 m .50369 .6669 L .50085 .65968 L p .707 .577 .707 r
F P
0 g
s
.50085 .65968 m .50571 .62242 L .50855 .62964 L p .707 .577 .707 r
F P
0 g
s
.49046 .66252 m .49403 .68026 L .49122 .66978 L p .707 .578 .707 r
F P
0 g
s
.49122 .66978 m .48765 .65204 L .49046 .66252 L p .707 .578 .707 r
F P
0 g
s
.29013 .69334 m .2937 .71108 L .29651 .72155 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .54612 m .48782 .60198 L .47543 .59409 L p .707 .577 .707 r
F P
0 g
s
.47543 .59409 m .4834 .53823 L .49579 .54612 L p .707 .577 .707 r
F P
0 g
s
.30144 .63878 m .3063 .60153 L .31335 .59568 L p .707 .577 .707 r
F P
0 g
s
.2958 .57297 m .30377 .51711 L .32005 .51355 L p .707 .577 .707 r
F P
0 g
s
.31335 .59568 m .30849 .63294 L .30144 .63878 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32005 .51355 m .31209 .56941 L .2958 .57297 L p .707 .577 .707 r
F P
0 g
s
.2937 .71108 m .29013 .69334 L .29712 .68136 L p .707 .577 .707 r
F P
0 g
s
.48765 .65204 m .49122 .66978 L .47888 .66184 L p .707 .577 .707 r
F P
0 g
s
.47888 .66184 m .47531 .6441 L .48765 .65204 L p .707 .577 .707 r
F P
0 g
s
.50571 .62242 m .50085 .65968 L .48838 .65179 L p .707 .577 .707 r
F P
0 g
s
.48838 .65179 m .49324 .61453 L .50571 .62242 L p .707 .577 .707 r
F P
0 g
s
.29712 .68136 m .3007 .6991 L .2937 .71108 L p .707 .577 .707 r
F P
0 g
s
.4834 .53823 m .47543 .59409 L .45464 .58617 L p .707 .577 .707 r
F P
0 g
s
.45464 .58617 m .46261 .53031 L .4834 .53823 L p .707 .577 .707 r
F P
0 g
s
.30849 .63294 m .31335 .59568 L .32961 .59179 L p .707 .577 .707 r
F P
0 g
s
.31209 .56941 m .32005 .51355 L .34394 .51238 L p .707 .577 .707 r
F P
0 g
s
.32961 .59179 m .32475 .62904 L .30849 .63294 L p .707 .577 .707 r
F P
0 g
s
.34394 .51238 m .33597 .56824 L .31209 .56941 L p .707 .577 .707 r
F P
0 g
s
.3007 .6991 m .29712 .68136 L .31324 .66904 L p .707 .577 .707 r
F P
0 g
s
.46261 .53031 m .45464 .58617 L .42749 .57901 L p .707 .577 .707 r
F P
0 g
s
.42749 .57901 m .43546 .52314 L .46261 .53031 L p .707 .577 .707 r
F P
0 g
s
.47531 .6441 m .47888 .66184 L .45822 .65721 L p .707 .577 .707 r
F P
0 g
s
.45822 .65721 m .45465 .63947 L .47531 .6441 L p .707 .577 .707 r
F P
0 g
s
.49324 .61453 m .48838 .65179 L .46751 .644 L p .707 .577 .707 r
F P
0 g
s
.46751 .644 m .47237 .60674 L .49324 .61453 L p .707 .577 .707 r
F P
0 g
s
.33597 .56824 m .34394 .51238 L .37307 .51372 L p .707 .577 .707 r
F P
0 g
s
.31324 .66904 m .31681 .68678 L .3007 .6991 L p .707 .577 .707 r
F P
0 g
s
.32475 .62904 m .32961 .59179 L .35349 .59022 L p .707 .577 .707 r
F P
0 g
s
.43546 .52314 m .42749 .57901 L .39664 .57329 L p .707 .577 .707 r
F P
0 g
s
.39664 .57329 m .40461 .51743 L .43546 .52314 L p .707 .577 .707 r
F P
0 g
s
.37307 .51372 m .3651 .56958 L .33597 .56824 L p .707 .577 .707 r
F P
0 g
s
.35349 .59022 m .34863 .62748 L .32475 .62904 L p .707 .577 .707 r
F P
0 g
s
.3651 .56958 m .37307 .51372 L .40461 .51743 L p .707 .577 .707 r
F P
0 g
s
.40461 .51743 m .39664 .57329 L .3651 .56958 L p .707 .577 .707 r
F P
0 g
s
.31681 .68678 m .31324 .66904 L .33689 .65759 L p .707 .577 .707 r
F P
0 g
s
.45465 .63947 m .45822 .65721 L .43126 .65635 L p .707 .577 .707 r
F P
0 g
s
.43126 .65635 m .42768 .63861 L .45465 .63947 L p .707 .577 .707 r
F P
0 g
s
.47237 .60674 m .46751 .644 L .44029 .63708 L p .707 .577 .707 r
F P
0 g
s
.44029 .63708 m .44515 .59982 L .47237 .60674 L p .707 .577 .707 r
F P
0 g
s
.33689 .65759 m .34047 .67533 L .31681 .68678 L p .707 .577 .707 r
F P
0 g
s
.34863 .62748 m .35349 .59022 L .38265 .59114 L p .707 .577 .707 r
F P
0 g
s
.38265 .59114 m .37779 .62839 L .34863 .62748 L p .707 .577 .707 r
F P
0 g
s
.44515 .59982 m .44029 .63708 L .40937 .6317 L p .707 .577 .707 r
F P
0 g
s
.40937 .6317 m .41423 .59444 L .44515 .59982 L p .707 .577 .707 r
F P
0 g
s
.34047 .67533 m .33689 .65759 L .36578 .64813 L p .707 .577 .707 r
F P
0 g
s
.37779 .62839 m .38265 .59114 L .41423 .59444 L p .707 .577 .707 r
F P
0 g
s
.42768 .63861 m .43126 .65635 L .40064 .65933 L p .707 .577 .707 r
F P
0 g
s
.40064 .65933 m .39706 .64159 L .42768 .63861 L p .707 .577 .707 r
F P
0 g
s
.41423 .59444 m .40937 .6317 L .37779 .62839 L p .707 .577 .707 r
F P
0 g
s
.36578 .64813 m .36935 .66587 L .34047 .67533 L p .707 .577 .707 r
F P
0 g
s
.36935 .66587 m .36578 .64813 L .39706 .64159 L p .707 .577 .707 r
F P
0 g
s
.39706 .64159 m .40064 .65933 L .36935 .66587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001NOol80002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00IWoo001IOol50003FUH00`00FUIJEP02FUH90009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol30000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol3
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80011oo`T004eoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000Yoo`H000AJEP03001JEUYF009JEPT004Aoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000Moo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPH003ioo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003Ool30005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000hOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00=Woo001COol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF008003Aoo`00Dgoo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00031oo`00DWoo00<005YF00000UYF4`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
DWoo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
059oo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60006
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF100015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000]Ool005=oo`800003FUH005YF00AJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300001eYF
001JEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH60008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Eoo`8000EJEPD000=JEP04001JEUYFFUH90005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YF00000`005goo1P001UYF00<005YFFUH00UYF00<005YF
FUH00UYF0P00;Goo001GOol500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90005
FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH2000DOol3000:Ool40002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Qoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000EJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP800003FUH00000019oo`D000eoo`<000AJEP07001J
EUYFFUH005YF0000;Goo001GOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP02FUH30005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0100015YF0`003goo1@0047oo0P00
0UYF00L005YFFUIJEP00FUH0000]Ool005Moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH000000005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001J
EP0000<000]oo`D0019oo`<000=JEP03001JEP0002eoo`00Egoo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH00eYF1`001Goo0`003goo100000=JEP0000000eYF0P00;Woo001@Ool700000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009Ool5
0005FUH00`00FUH00002FUH2000^Ool003mooa4000AJEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH0000D0003FUH00`00FUIJEP04FUH01@00FUIJEP00
FUH00P00;Woo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUH3000^Ool0039oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF
00AJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04
001JEUYFFUH3000^Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0003FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP02FUH3000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00<000EJEP03001JEUYF00=J
EP@000=JEPT000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YF0000;Woo000/Ool3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001EYF
000005YF00001EYF00<005YFFUH01UYF00<005YF00001`0015YF10000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
000015YF000000000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00P0000AJEP00FUH002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH00UYF4@001EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH3000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPL000AJ
EP03001JEUYF00=JEP@00003FUH005YF00EJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00;goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH01P00FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH01000FUIJEUYF
0P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH000020003FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH>0004FUH00`00FUH0000200001EYF000005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEPH000MJEP03
001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP@000MJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEP0000800003FUH005YF0080
0006FUH00000001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF009JEP03001JEP0000D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
009JEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30008FUH00`00
FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH0
0UYF0`001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF100000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00002Ool90004FUH00`00FUIJEP02FUH50004Ool20003FUH01000FUIJEUYF0P00;7oo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001EYF00<005YFFUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Moo`d0
00]oo`800003FUH005YF009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF4P001UYF00<005YF00000`000UYF00@005YFFUIJEPT000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP800004FUH000000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00007Ool5000EOol20003FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH20003FUH01000FUIJEP001EYF
00<005YFFUH015YF5@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000=JEP<00003FUH005YF00=JEP05001JEUYFFUH00007Ool5000GOol0
0`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP06FUH0
1000FUIJEP001EYF00@005YFFUIJEP800003FUH005YF009JEP04001JEUYF0005FUH40006FUH00`00
FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP020005FUH01000FUIJEP0027oo0`00
5goo0`0000=JEP00Ool0;7oo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUH000001EYF00@005YF000000=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH20004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P007Woo0`000eYF
0P00;Goo000]Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01000FUH000001EYF0P001EYF00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH02EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEP0000<00003FUH0000001]oo`<00003FUH0
05YF00=JEP8002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF
3@000UYF00<005YFFUH0300000Eoo`00FUIJEP0000EJEPD000EJEP03001JEUYF00MJEP<000EJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000BOol60004FUH00`00FUIJEP02FUH2000]Ool002io
o`80009JEP03001JEUYF00=JEP03001JEUYF00=JEPP000AJEP03001JEUYF00EJEP03001JEUYF00<0
00=JEP03001JEUYF00D0009oo`04001JEUYF0005FUH40006FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00L005YFFUIJEP00FUH0000]Ool0031oo`D00003FUH0000000H000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30005FUH01000FUH0000025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000;Goo000`Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUH0000200000eYF001JEP05FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF
8000;Woo000]Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00=JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000QJEP04001JEUYFFUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH00eYF00<005YF00000`0000=JEP00FUH025YF00H005YF000005YF000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2P000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000015YF001JEUYF5`001EYF00<005YFFUH01UYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEQ@0009JEP03001oogoo02aoo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000[Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH015YF10002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHL0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00D005YFFUIJEP0000=JEPP000QJEP03001JEP00008000EJEP03001JEUYF00EJEP04001J
EUYFFUH6000bOol002aoo`03001JEP0000=JEP03001JEUYF00=JEPH000EJEP03001JEUYF00IJEP03
001JEUYF00AJEP@00003FUH005YF00L000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/Ool0
0`00FUH00003FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000030004FUH00`00FUH000080004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT003moo`00;7oo00<005YF0000
0UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
00=JEP00FUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT004Qoo`00;7oo00<005YF00000`000UYF
00<005YFFUH00eYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF0`000eYF0`000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEQL0055oo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1P001eYF00<005YFFUH00`000Woo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00AJEP`000aJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00
FUIJEP03FUH01000FUIJEP00Egoo000/Ool40003FUH00`00FUH000030005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF
00<005YFFUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP800003Ool0000000D000=JEP04001JEUYF001GOol002eoo`<000=JEP800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00EJEP03
001oo`00009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00D000IJEP04001JEUYFFUH20008Ool40002FUH00`00Oomoo`1E
Ool002eoo`03001JEP00009JEPP000AJEP03001JEUYF009JEQ8000Ioo`8000IJEP<0009JEP03001J
EUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP@0009JEP04001JEUYFFUH20006Ool20004FUH4001FOol002eoo`03001JEP00
008000Qoo`T001Yoo`8000AJEP<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20004
Ool200000eYF001JEP03FUH01000FUH00000EWoo000]Ool00`00FUH0000_Ool01000FUIJEP000UYF
00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF0080009oo`8000=JEP03001JEUYF
009JEP04001JEP00001FOol002eoo`80035oo`<0009JEP03001JEUYF00800003FUH005YF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF00=JEP03001JEP0005Ioo`00;Goo0P006Goo
0`005goo00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50006FUH00`00FUIJ
EP03FUH00`00FUH0001FOol002eoo`8001Qoo`D001Moo`04001JEP000004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP03FUH2001GOol002eoo`<001Moo`D001Qo
o`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH00UYF
0P00Egoo000]Ool200000eYF001oo`0EOol5000IOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000IJEP03001JEUYF009JEP03001oogoo05Ioo`00;Goo0P000UYF00<007oo
Ool057oo0`006Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0006FUH0
0`00FUIJEP02001IOol002ioo`05001JEUYFFUH0000cOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP04FUH3001KOol002ioo`04001JEUYFFUH3000`
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60006FUH00`00Oomoo`1KOol002moo`04001J
EUYF0002FUH2000]Ool200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJ
EUYF001JEP80009JEP8005ioo`00;goo00<005YF00001EYF0`00:Goo00H005YF001JEP00Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP<005moo`00<7oo0P001UYF00@005YF000002Ioo`03
001JEUYF008000Aoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP05FUH3001LOol0035oo`03001J
EUYF00AJEP04001JEUYFFUH3000QOol20003FUH20006Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP06FUH0
0`00FUH00002001IOol0039oo`8000=JEP03001JEUYF00EJEPD001Qoo`@00003FUH005YF009JEP03
001oogoo00Moo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@00003FUH0000000@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8005Mo
o`00=7oo0P0000=JEP00FUH01eYF00@005YFFUIJEPT000Uoo`H000AJEP03001JEUYF008000eoo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000P000Ioo`@000IJ
EP03001JEUYF00AJEP<005Eoo`00=Woo0`001eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH00eYF0`005Woo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF40002Woo10000UYF
00<005YFFUH015YF00@005YFFUH005Aoo`00>Goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P008goo6P0015YF00<005YFFUH02@003Woo100015YF00D0
05YFFUIJEP0005Aoo`00>goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Qoo`800003FUH005YF00IJEP03001JEUYF00AJEPL0011oo`<00003FUH005YF009J
EP8005=oo`00?Woo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003aoo`<000EJ
EP03001JEUYF00MJEP03001JEUYF009JEPP000]oo`80009JEP03001JEP0005=oo`00A7oo2@0015YF
00<005YFFUH00UYF1@00@Goo100000=JEP00FUH025YF00<005YFFUH01UYF00@005YFFUIJEPh00004
FUH005YF001COol004eoo`T004Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00<005Aoo`00Y7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00E7oo002XOol70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Aoo`00[goo200015YF00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00]goo
4000EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63875 .7505 m .62593 .698 L .59488 .70557 L p .707 .577 .707 r
F P
0 g
s
.62593 .698 m .63875 .7505 L .66747 .73994 L p .707 .577 .707 r
F P
0 g
s
.66747 .73994 m .65466 .68743 L .62593 .698 L p .707 .577 .707 r
F P
0 g
s
.60769 .75808 m .59488 .70557 L .56453 .70941 L p .707 .577 .707 r
F P
0 g
s
.59488 .70557 m .60769 .75808 L .63875 .7505 L p .707 .577 .707 r
F P
0 g
s
.65466 .68743 m .66747 .73994 L .69105 .72742 L p .707 .577 .707 r
F P
0 g
s
.69105 .72742 m .67823 .67491 L .65466 .68743 L p .707 .577 .707 r
F P
0 g
s
.57734 .76192 m .56453 .70941 L .53785 .70915 L p .707 .577 .707 r
F P
0 g
s
.56453 .70941 m .57734 .76192 L .60769 .75808 L p .707 .577 .707 r
F P
0 g
s
.58713 .82027 m .5793 .78501 L .5488 .78843 L p .707 .577 .707 r
F P
0 g
s
.5793 .78501 m .58713 .82027 L .61831 .81321 L p .707 .577 .707 r
F P
0 g
s
.61831 .81321 m .61048 .77796 L .5793 .78501 L p .707 .577 .707 r
F P
0 g
s
.61048 .77796 m .61831 .81321 L .64711 .80321 L p .707 .577 .707 r
F P
0 g
s
.64711 .80321 m .63928 .76795 L .61048 .77796 L p .707 .577 .707 r
F P
0 g
s
.55663 .82368 m .5488 .78843 L .52196 .78786 L p .707 .577 .707 r
F P
0 g
s
.5488 .78843 m .55663 .82368 L .58713 .82027 L p .707 .577 .707 r
F P
0 g
s
.63928 .76795 m .64711 .80321 L .67071 .79123 L p .707 .577 .707 r
F P
0 g
s
.67071 .79123 m .66288 .75598 L .63928 .76795 L p .707 .577 .707 r
F P
0 g
s
.67823 .67491 m .69105 .72742 L .70718 .71417 L p .707 .577 .707 r
F P
0 g
s
.70718 .71417 m .69436 .66166 L .67823 .67491 L p .707 .577 .707 r
F P
0 g
s
.55067 .76165 m .53785 .70915 L .51747 .7048 L p .707 .577 .707 r
F P
0 g
s
.53785 .70915 m .55067 .76165 L .57734 .76192 L p .707 .577 .707 r
F P
0 g
s
.60122 .83553 m .60695 .81735 L .57722 .80715 L p .707 .577 .707 r
F P
0 g
s
.60695 .81735 m .60122 .83553 L .63162 .84452 L p .707 .577 .707 r
F P
0 g
s
.63162 .84452 m .63735 .82635 L .60695 .81735 L p .707 .577 .707 r
F P
0 g
s
.52196 .78786 m .52979 .82312 L .55663 .82368 L p .707 .577 .707 r
F P
0 g
s
.57722 .80715 m .57149 .82532 L .60122 .83553 L p .707 .577 .707 r
F P
0 g
s
.63735 .82635 m .63162 .84452 L .65973 .85144 L p .707 .577 .707 r
F P
0 g
s
.65973 .85144 m .66546 .83326 L .63735 .82635 L p .707 .577 .707 r
F P
0 g
s
.52979 .82312 m .52196 .78786 L .50141 .78338 L p .707 .577 .707 r
F P
0 g
s
.57149 .82532 m .57722 .80715 L .55108 .79674 L p .707 .577 .707 r
F P
0 g
s
.66288 .75598 m .67071 .79123 L .68681 .77846 L p .707 .577 .707 r
F P
0 g
s
.68681 .77846 m .67898 .7432 L .66288 .75598 L p .707 .577 .707 r
F P
0 g
s
.55108 .79674 m .54536 .81492 L .57149 .82532 L p .707 .577 .707 r
F P
0 g
s
.51747 .7048 m .53029 .75731 L .55067 .76165 L p .707 .577 .707 r
F P
0 g
s
.69436 .66166 m .70718 .71417 L .71427 .70148 L p .707 .577 .707 r
F P
0 g
s
.71427 .70148 m .70145 .64898 L .69436 .66166 L p .707 .577 .707 r
F P
0 g
s
.53029 .75731 m .51747 .7048 L .50537 .6968 L p .707 .577 .707 r
F P
0 g
s
.66546 .83326 m .65973 .85144 L .68279 .85559 L p .707 .577 .707 r
F P
0 g
s
.68279 .85559 m .68852 .83741 L .66546 .83326 L p .707 .577 .707 r
F P
0 g
s
.50141 .78338 m .50924 .81864 L .52979 .82312 L p .707 .577 .707 r
F P
0 g
s
.54536 .81492 m .55108 .79674 L .53109 .78715 L p .707 .577 .707 r
F P
0 g
s
.53109 .78715 m .52537 .80532 L .54536 .81492 L p .707 .577 .707 r
F P
0 g
s
.50924 .81864 m .50141 .78338 L .48916 .77542 L p .707 .577 .707 r
F P
0 g
s
.67898 .7432 m .68681 .77846 L .69383 .76613 L p .707 .577 .707 r
F P
0 g
s
.69383 .76613 m .686 .73088 L .67898 .7432 L p .707 .577 .707 r
F P
0 g
s
.50537 .6968 m .51819 .74931 L .53029 .75731 L p .707 .577 .707 r
F P
0 g
s
.68852 .83741 m .68279 .85559 L .69854 .85657 L p .707 .577 .707 r
F P
0 g
s
.69854 .85657 m .70427 .8384 L .68852 .83741 L p .707 .577 .707 r
F P
0 g
s
.48916 .77542 m .49698 .81067 L .50924 .81864 L p .707 .577 .707 r
F P
0 g
s
.70145 .64898 m .71427 .70148 L .71164 .69061 L p .698 .572 .709 r
F P
0 g
s
.71164 .69061 m .69882 .6381 L .70145 .64898 L p .698 .572 .709 r
F P
0 g
s
.51819 .74931 m .50537 .6968 L .50274 .68593 L p .698 .572 .709 r
F P
0 g
s
.52537 .80532 m .53109 .78715 L .51921 .77931 L p .707 .577 .707 r
F P
0 g
s
.51921 .77931 m .51348 .79748 L .52537 .80532 L p .707 .577 .707 r
F P
0 g
s
.49698 .81067 m .48916 .77542 L .4864 .76476 L p .708 .578 .707 r
F P
0 g
s
.686 .73088 m .69383 .76613 L .69108 .75547 L p .708 .578 .707 r
F P
0 g
s
.69108 .75547 m .68325 .72022 L .686 .73088 L p .708 .578 .707 r
F P
0 g
s
.4864 .76476 m .49423 .80001 L .49698 .81067 L p .708 .578 .707 r
F P
0 g
s
.49423 .80001 m .4864 .76476 L .49342 .75243 L p .707 .577 .707 r
F P
0 g
s
.48752 .82178 m .48752 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.50274 .68593 m .51556 .73843 L .51819 .74931 L p .698 .572 .709 r
F P
0 g
s
.51348 .79748 m .51921 .77931 L .51659 .77399 L p .707 .577 .707 r
F P
0 g
s
.51556 .73843 m .50274 .68593 L .50983 .67324 L p .707 .577 .707 r
F P
0 g
s
.51659 .77399 m .51086 .79216 L .51348 .79748 L p .707 .577 .707 r
F P
0 g
s
.50983 .67324 m .52265 .72575 L .51556 .73843 L p .707 .577 .707 r
F P
0 g
s
.49342 .75243 m .50125 .78769 L .49423 .80001 L p .707 .577 .707 r
F P
0 g
s
.52265 .72575 m .50983 .67324 L .52596 .65999 L p .707 .577 .707 r
F P
0 g
s
.51086 .79216 m .51659 .77399 L .52349 .77171 L p .707 .577 .707 r
F P
0 g
s
.52349 .77171 m .51777 .78988 L .51086 .79216 L p .707 .577 .707 r
F P
0 g
s
.50125 .78769 m .49342 .75243 L .50952 .73966 L p .707 .577 .707 r
F P
0 g
s
.52596 .65999 m .53878 .7125 L .52265 .72575 L p .707 .577 .707 r
F P
0 g
s
.50952 .73966 m .51735 .77491 L .50125 .78769 L p .707 .577 .707 r
F P
0 g
s
.51777 .78988 m .52349 .77171 L .53925 .77269 L p .707 .577 .707 r
F P
0 g
s
.53925 .77269 m .53352 .79087 L .51777 .78988 L p .707 .577 .707 r
F P
0 g
s
.51735 .77491 m .50952 .73966 L .53313 .72768 L p .707 .577 .707 r
F P
0 g
s
.53313 .72768 m .54095 .76294 L .51735 .77491 L p .707 .577 .707 r
F P
0 g
s
.48752 .31989 m .48752 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53878 .7125 m .52596 .65999 L .54954 .64747 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48752 .31989 L p .707 .577 .707 r
F P
0 g
s
.56235 .69998 m .54954 .64747 L .57826 .63691 L p .707 .577 .707 r
F P
0 g
s
.54954 .64747 m .56235 .69998 L .53878 .7125 L p .707 .577 .707 r
F P
0 g
s
.57826 .63691 m .59108 .68941 L .56235 .69998 L p .707 .577 .707 r
F P
0 g
s
.54095 .76294 m .53313 .72768 L .56193 .71768 L p .707 .577 .707 r
F P
0 g
s
.53352 .79087 m .53925 .77269 L .56231 .77684 L p .707 .577 .707 r
F P
0 g
s
.56231 .77684 m .55658 .79502 L .53352 .79087 L p .707 .577 .707 r
F P
0 g
s
.56975 .75293 m .56193 .71768 L .5931 .71062 L p .707 .577 .707 r
F P
0 g
s
.56193 .71768 m .56975 .75293 L .54095 .76294 L p .707 .577 .707 r
F P
0 g
s
.55658 .79502 m .56231 .77684 L .59041 .78376 L p .707 .577 .707 r
F P
0 g
s
.59041 .78376 m .58469 .80193 L .55658 .79502 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57437 .81638 L p .707 .577 .707 r
F P
0 g
s
.5931 .71062 m .60093 .74588 L .56975 .75293 L p .707 .577 .707 r
F P
0 g
s
.57437 .81638 m .57437 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70427 .8384 m .69854 .85657 L .70545 .85429 L p .707 .577 .707 r
F P
0 g
s
.70545 .85429 m .71118 .83612 L .70427 .8384 L p .707 .577 .707 r
F P
0 g
s
.44372 .81886 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44372 .81886 L .48752 .82178 L p .707 .577 .707 r
F P
0 g
s
.69882 .6381 m .71164 .69061 L .69954 .68261 L p .707 .577 .707 r
F P
0 g
s
.69954 .68261 m .68672 .6301 L .69882 .6381 L p .707 .577 .707 r
F P
0 g
s
.60932 .62933 m .62213 .68184 L .59108 .68941 L p .707 .577 .707 r
F P
0 g
s
.59108 .68941 m .57826 .63691 L .60932 .62933 L p .707 .577 .707 r
F P
0 g
s
.6236 .70721 m .63143 .74247 L .60093 .74588 L p .707 .577 .707 r
F P
0 g
s
.60093 .74588 m .5931 .71062 L .6236 .70721 L p .707 .577 .707 r
F P
0 g
s
.58469 .80193 m .59041 .78376 L .62082 .79275 L p .707 .577 .707 r
F P
0 g
s
.62082 .79275 m .61509 .81093 L .58469 .80193 L p .707 .577 .707 r
F P
0 g
s
.57437 .31449 m .57437 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .3067 L .57437 .31449 L p .707 .577 .707 r
F P
0 g
s
.25855 .6932 m .25298 .63584 L .22194 .63851 L p .707 .577 .707 r
F P
0 g
s
.25298 .63584 m .25855 .6932 L .29023 .68999 L p .707 .577 .707 r
F P
0 g
s
.29023 .68999 m .28466 .63263 L .25298 .63584 L p .707 .577 .707 r
F P
0 g
s
.68325 .72022 m .69108 .75547 L .67882 .74751 L p .707 .577 .707 r
F P
0 g
s
.67882 .74751 m .671 .71225 L .68325 .72022 L p .707 .577 .707 r
F P
0 g
s
.22194 .63851 m .22751 .69587 L .25855 .6932 L p .707 .577 .707 r
F P
0 g
s
.28466 .63263 m .29023 .68999 L .31945 .68656 L p .707 .577 .707 r
F P
0 g
s
.31945 .68656 m .31388 .62919 L .28466 .63263 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44372 .81886 L p .707 .577 .707 r
F P
0 g
s
.22751 .69587 m .22194 .63851 L .19458 .64038 L p .707 .577 .707 r
F P
0 g
s
.71118 .83612 m .70545 .85429 L .70283 .84897 L p .707 .577 .707 r
F P
0 g
s
.70283 .84897 m .70856 .8308 L .71118 .83612 L p .707 .577 .707 r
F P
0 g
s
.19458 .64038 m .20014 .69775 L .22751 .69587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68672 .6301 m .69954 .68261 L .67916 .67826 L p .707 .577 .707 r
F P
0 g
s
.67916 .67826 m .66634 .62576 L .68672 .6301 L p .707 .577 .707 r
F P
0 g
s
.31388 .62919 m .31945 .68656 L .34335 .68324 L p .707 .577 .707 r
F P
0 g
s
.34335 .68324 m .33778 .62588 L .31388 .62919 L p .707 .577 .707 r
F P
0 g
s
.63143 .74247 m .6236 .70721 L .65044 .70777 L p .707 .577 .707 r
F P
0 g
s
.63967 .62549 m .65248 .678 L .62213 .68184 L p .707 .577 .707 r
F P
0 g
s
.62213 .68184 m .60932 .62933 L .63967 .62549 L p .707 .577 .707 r
F P
0 g
s
.61509 .81093 m .62082 .79275 L .65054 .80296 L p .707 .577 .707 r
F P
0 g
s
.60892 .3067 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.65044 .70777 m .65827 .74303 L .63143 .74247 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .3067 L p .707 .577 .707 r
F P
0 g
s
.20014 .69775 m .19458 .64038 L .17357 .64128 L p .707 .577 .707 r
F P
0 g
s
.17357 .64128 m .17914 .69864 L .20014 .69775 L p .707 .577 .707 r
F P
0 g
s
.671 .71225 m .67882 .74751 L .65827 .74303 L p .707 .577 .707 r
F P
0 g
s
.65827 .74303 m .65044 .70777 L .671 .71225 L p .707 .577 .707 r
F P
0 g
s
.66634 .62576 m .67916 .67826 L .65248 .678 L p .707 .577 .707 r
F P
0 g
s
.65248 .678 m .63967 .62549 L .66634 .62576 L p .707 .577 .707 r
F P
0 g
s
.33778 .62588 m .34335 .68324 L .35958 .68036 L p .707 .577 .707 r
F P
0 g
s
.35958 .68036 m .35401 .623 L .33778 .62588 L p .707 .577 .707 r
F P
0 g
s
.24979 .75025 m .24639 .71202 L .21531 .7143 L p .707 .577 .707 r
F P
0 g
s
.24639 .71202 m .24979 .75025 L .28149 .74724 L p .707 .577 .707 r
F P
0 g
s
.28149 .74724 m .27809 .70901 L .24639 .71202 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.21531 .7143 m .21871 .75253 L .24979 .75025 L p .707 .577 .707 r
F P
0 g
s
.27809 .70901 m .28149 .74724 L .3107 .74381 L p .707 .577 .707 r
F P
0 g
s
.3107 .74381 m .30731 .70558 L .27809 .70901 L p .707 .577 .707 r
F P
0 g
s
.70856 .8308 m .70283 .84897 L .69095 .84113 L p .707 .577 .707 r
F P
0 g
s
.69095 .84113 m .69667 .82296 L .70856 .8308 L p .707 .577 .707 r
F P
0 g
s
.25642 .84305 m .25894 .82702 L .22797 .81992 L p .707 .577 .707 r
F P
0 g
s
.25894 .82702 m .25642 .84305 L .28795 .84481 L p .707 .577 .707 r
F P
0 g
s
.28795 .84481 m .29047 .82878 L .25894 .82702 L p .707 .577 .707 r
F P
0 g
s
.21871 .75253 m .21531 .7143 L .18789 .71563 L p .707 .577 .707 r
F P
0 g
s
.22545 .83595 m .22797 .81992 L .20058 .80816 L p .707 .577 .707 r
F P
0 g
s
.22797 .81992 m .22545 .83595 L .25642 .84305 L p .707 .577 .707 r
F P
0 g
s
.18789 .71563 m .19129 .75386 L .21871 .75253 L p .707 .577 .707 r
F P
0 g
s
.17914 .69864 m .17357 .64128 L .16097 .6411 L p .707 .577 .707 r
F P
0 g
s
.29047 .82878 m .28795 .84481 L .31695 .84106 L p .707 .577 .707 r
F P
0 g
s
.31695 .84106 m .31947 .82503 L .29047 .82878 L p .707 .577 .707 r
F P
0 g
s
.16097 .6411 m .16654 .69846 L .17914 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .70558 m .3107 .74381 L .33457 .74027 L p .707 .577 .707 r
F P
0 g
s
.33457 .74027 m .33118 .70205 L .30731 .70558 L p .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .79832 L .6437 .78657 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.20058 .80816 m .19806 .82419 L .22545 .83595 L p .707 .577 .707 r
F P
0 g
s
.19806 .82419 m .20058 .80816 L .17947 .79291 L p .707 .577 .707 r
F P
0 g
s
.19129 .75386 m .18789 .71563 L .16682 .71589 L p .707 .577 .707 r
F P
0 g
s
.31947 .82503 m .31695 .84106 L .34059 .83215 L p .707 .577 .707 r
F P
0 g
s
.34059 .83215 m .34311 .81612 L .31947 .82503 L p .707 .577 .707 r
F P
0 g
s
.16682 .71589 m .17022 .75412 L .19129 .75386 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35629 .27798 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35401 .623 m .35958 .68036 L .36581 .67844 L p .707 .577 .707 r
F P
0 g
s
.36567 .67426 m .35401 .623 L .36581 .67844 L .707 .577 .707 r
F
.36656 .6782 m .361 .62084 L .35401 .623 L p F P
0 g
s
.35805 .61961 m .361 .62084 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36361 .67698 m .36335 .67425 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36335 .67425 m .35805 .61961 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.34737 .69877 m .35076 .737 L .35769 .73429 L p .707 .577 .707 r
F P
0 g
s
.35769 .73429 m .35429 .69606 L .34737 .69877 L p .707 .577 .707 r
F P
0 g
s
.35429 .69606 m .35769 .73429 L .35467 .73242 L p .707 .577 .707 r
F P
0 g
s
.36257 .76919 m .36005 .78522 L .34727 .76796 L p .707 .577 .707 r
F P
0 g
s
.34727 .76796 m .34979 .75193 L .36257 .76919 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35947 .79195 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35805 .61961 m .36361 .67698 L .35102 .6768 L p .707 .577 .707 r
F P
0 g
s
.35102 .6768 m .34545 .61944 L .35805 .61961 L p .707 .577 .707 r
F P
0 g
s
.35629 .27798 m .35629 .70254 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35629 .70254 m .35629 .77987 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .49323 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35947 .49323 m .35947 .29006 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.36581 .67844 m .36656 .6782 L p .36567 .67426 L .707 .577 .707 r
F P
0 g
s
.17947 .79291 m .17695 .80894 L .19806 .82419 L p .707 .577 .707 r
F P
0 g
s
.69667 .82296 m .69095 .84113 L .67096 .83154 L p .707 .577 .707 r
F P
0 g
s
.67096 .83154 m .67668 .81336 L .69667 .82296 L p .707 .577 .707 r
F P
0 g
s
.33118 .70205 m .33457 .74027 L .35076 .737 L p .707 .577 .707 r
F P
0 g
s
.35076 .737 m .34737 .69877 L .33118 .70205 L p .707 .577 .707 r
F P
0 g
s
.17695 .80894 m .17947 .79291 L .16669 .77565 L p .707 .577 .707 r
F P
0 g
s
.16654 .69846 m .16097 .6411 L .15802 .63987 L p .707 .577 .707 r
F P
0 g
s
.361 .62084 m .36656 .6782 L .36361 .67698 L p .707 .577 .707 r
F P
0 g
s
.36324 .8028 m .36576 .78677 L .35906 .80294 L p .707 .577 .707 r
F P
0 g
s
.36576 .78677 m .36324 .8028 L .36005 .78522 L p .707 .577 .707 r
F P
0 g
s
.36005 .78522 m .36257 .76919 L .36576 .78677 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.15802 .63987 m .16359 .69724 L .16654 .69846 L p .707 .577 .707 r
F P
0 g
s
.34311 .81612 m .34059 .83215 L .35654 .81897 L p .707 .577 .707 r
F P
0 g
s
.35654 .81897 m .35906 .80294 L .34311 .81612 L p .707 .577 .707 r
F P
0 g
s
.17022 .75412 m .16682 .71589 L .15415 .71504 L p .707 .577 .707 r
F P
0 g
s
.16669 .77565 m .16417 .79168 L .17695 .80894 L p .707 .577 .707 r
F P
0 g
s
.15415 .71504 m .15755 .75327 L .17022 .75412 L p .707 .577 .707 r
F P
0 g
s
.67668 .81336 m .67096 .83154 L .64482 .82113 L p .707 .577 .707 r
F P
0 g
s
.64482 .82113 m .65054 .80296 L .67668 .81336 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .70924 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .62359 .76326 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .639 .56377 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63638 .62968 m .63665 .62728 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63665 .62728 m .64195 .57917 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .64053 .77449 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.6437 .70924 m .6437 .78657 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.16417 .79168 m .16669 .77565 L .1635 .75808 L p .707 .577 .707 r
F P
0 g
s
.35906 .80294 m .35654 .81897 L .36324 .8028 L p .707 .577 .707 r
F P
0 g
s
.65054 .80296 m .64482 .82113 L .61509 .81093 L p .707 .577 .707 r
F P
0 g
s
.16359 .69724 m .15802 .63987 L .16501 .63771 L p .707 .577 .707 r
F P
0 g
s
.1635 .75808 m .16098 .77411 L .16417 .79168 L p .707 .577 .707 r
F P
0 g
s
.16501 .63771 m .17057 .69508 L .16359 .69724 L p .707 .577 .707 r
F P
0 g
s
.15755 .75327 m .15415 .71504 L .15114 .71317 L p .707 .577 .707 r
F P
0 g
s
.15114 .71317 m .15453 .7514 L .15755 .75327 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35629 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16098 .77411 m .1635 .75808 L .17021 .74191 L p .707 .577 .707 r
F P
0 g
s
.35467 .73242 m .35128 .69419 L .35429 .69606 L p .707 .577 .707 r
F P
0 g
s
.17021 .74191 m .16769 .75794 L .16098 .77411 L p .707 .577 .707 r
F P
0 g
s
.17057 .69508 m .16501 .63771 L .18124 .63483 L p .707 .577 .707 r
F P
0 g
s
.62359 .76326 m .62359 .26137 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18124 .63483 m .18681 .6922 L .17057 .69508 L p .707 .577 .707 r
F P
0 g
s
.15453 .7514 m .15114 .71317 L .15806 .71046 L p .707 .577 .707 r
F P
0 g
s
.15806 .71046 m .16146 .74869 L .15453 .7514 L p .707 .577 .707 r
F P
0 g
s
.16769 .75794 m .17021 .74191 L .18616 .72872 L p .707 .577 .707 r
F P
0 g
s
.34545 .61944 m .35102 .6768 L .33001 .67769 L p .707 .577 .707 r
F P
0 g
s
.33001 .67769 m .32444 .62033 L .34545 .61944 L p .707 .577 .707 r
F P
0 g
s
.35128 .69419 m .35467 .73242 L .34201 .73157 L p .707 .577 .707 r
F P
0 g
s
.34201 .73157 m .33861 .69334 L .35128 .69419 L p .707 .577 .707 r
F P
0 g
s
.18616 .72872 m .18364 .74475 L .16769 .75794 L p .707 .577 .707 r
F P
0 g
s
.36718 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36718 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18681 .6922 m .18124 .63483 L .20514 .63152 L p .707 .577 .707 r
F P
0 g
s
.20514 .63152 m .21071 .68888 L .18681 .6922 L p .707 .577 .707 r
F P
0 g
s
.16146 .74869 m .15806 .71046 L .17425 .70718 L p .707 .577 .707 r
F P
0 g
s
.18364 .74475 m .18616 .72872 L .20979 .71982 L p .707 .577 .707 r
F P
0 g
s
.17425 .70718 m .17765 .74541 L .16146 .74869 L p .707 .577 .707 r
F P
0 g
s
.32444 .62033 m .33001 .67769 L .30265 .67957 L p .707 .577 .707 r
F P
0 g
s
.30265 .67957 m .29708 .6222 L .32444 .62033 L p .707 .577 .707 r
F P
0 g
s
.34979 .75193 m .34727 .76796 L .32616 .75271 L p .707 .577 .707 r
F P
0 g
s
.32616 .75271 m .32868 .73668 L .34979 .75193 L p .707 .577 .707 r
F P
0 g
s
.62359 .26137 m .62359 .76326 L .59456 .75399 L p .707 .577 .707 r
F P
0 g
s
.59456 .75399 m .59456 .2521 L .62359 .26137 L p .707 .577 .707 r
F P
0 g
s
.20979 .71982 m .20727 .73585 L .18364 .74475 L p .707 .577 .707 r
F P
0 g
s
.21071 .68888 m .20514 .63152 L .23436 .62808 L p .707 .577 .707 r
F P
0 g
s
.23436 .62808 m .23992 .68545 L .21071 .68888 L p .707 .577 .707 r
F P
0 g
s
.33861 .69334 m .34201 .73157 L .32093 .73182 L p .707 .577 .707 r
F P
0 g
s
.32093 .73182 m .31754 .6936 L .33861 .69334 L p .707 .577 .707 r
F P
0 g
s
.29708 .6222 m .30265 .67957 L .27161 .68224 L p .707 .577 .707 r
F P
0 g
s
.27161 .68224 m .26604 .62488 L .29708 .6222 L p .707 .577 .707 r
F P
0 g
s
.20727 .73585 m .20979 .71982 L .23879 .71606 L p .707 .577 .707 r
F P
0 g
s
.32868 .73668 m .32616 .75271 L .29877 .74095 L p .707 .577 .707 r
F P
0 g
s
.29877 .74095 m .30129 .72492 L .32868 .73668 L p .707 .577 .707 r
F P
0 g
s
.23992 .68545 m .23436 .62808 L .26604 .62488 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36718 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42563 .24816 L p .707 .577 .707 r
F P
0 g
s
.26604 .62488 m .27161 .68224 L .23992 .68545 L p .707 .577 .707 r
F P
0 g
s
.17765 .74541 m .17425 .70718 L .19812 .70365 L p .707 .577 .707 r
F P
0 g
s
.19812 .70365 m .20152 .74188 L .17765 .74541 L p .707 .577 .707 r
F P
0 g
s
.23879 .71606 m .23627 .73209 L .20727 .73585 L p .707 .577 .707 r
F P
0 g
s
.72839 .67401 m .73396 .6235 L .70292 .61751 L p .707 .577 .707 r
F P
0 g
s
.73396 .6235 m .72839 .67401 L .76007 .6753 L p .707 .577 .707 r
F P
0 g
s
.76007 .6753 m .76564 .62479 L .73396 .6235 L p .707 .577 .707 r
F P
0 g
s
.23627 .73209 m .23879 .71606 L .27032 .71782 L p .707 .577 .707 r
F P
0 g
s
.30129 .72492 m .29877 .74095 L .2678 .73385 L p .707 .577 .707 r
F P
0 g
s
.2678 .73385 m .27032 .71782 L .30129 .72492 L p .707 .577 .707 r
F P
0 g
s
.76564 .62479 m .76007 .6753 L .78929 .67178 L p .707 .577 .707 r
F P
0 g
s
.78929 .67178 m .79486 .62126 L .76564 .62479 L p .707 .577 .707 r
F P
0 g
s
.69735 .66803 m .70292 .61751 L .67555 .60742 L p .707 .577 .707 r
F P
0 g
s
.70292 .61751 m .69735 .66803 L .72839 .67401 L p .707 .577 .707 r
F P
0 g
s
.73756 .73864 m .74096 .70458 L .70988 .69895 L p .707 .577 .707 r
F P
0 g
s
.74096 .70458 m .73756 .73864 L .76926 .73974 L p .707 .577 .707 r
F P
0 g
s
.76926 .73974 m .77266 .70569 L .74096 .70458 L p .707 .577 .707 r
F P
0 g
s
.27032 .71782 m .2678 .73385 L .23627 .73209 L p .707 .577 .707 r
F P
0 g
s
.59456 .2521 m .59456 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59456 .2521 L p .707 .577 .707 r
F P
0 g
s
.31754 .6936 m .32093 .73182 L .29351 .73316 L p .707 .577 .707 r
F P
0 g
s
.29351 .73316 m .29012 .69493 L .31754 .6936 L p .707 .577 .707 r
F P
0 g
s
.77266 .70569 m .76926 .73974 L .79848 .73622 L p .707 .577 .707 r
F P
0 g
s
.79848 .73622 m .80187 .70216 L .77266 .70569 L p .707 .577 .707 r
F P
0 g
s
.70648 .733 m .70988 .69895 L .68246 .68934 L p .707 .577 .707 r
F P
0 g
s
.70988 .69895 m .70648 .733 L .73756 .73864 L p .707 .577 .707 r
F P
0 g
s
.79486 .62126 m .78929 .67178 L .81319 .66377 L p .707 .577 .707 r
F P
0 g
s
.81319 .66377 m .81876 .61326 L .79486 .62126 L p .707 .577 .707 r
F P
0 g
s
.20152 .74188 m .19812 .70365 L .22734 .70022 L p .707 .577 .707 r
F P
0 g
s
.66999 .65793 m .67555 .60742 L .65455 .59421 L p .707 .577 .707 r
F P
0 g
s
.67555 .60742 m .66999 .65793 L .69735 .66803 L p .707 .577 .707 r
F P
0 g
s
.22734 .70022 m .23073 .73844 L .20152 .74188 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42563 .24816 L .46746 .24362 L p .707 .577 .707 r
F P
0 g
s
.42563 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.80187 .70216 m .79848 .73622 L .82235 .7284 L p .707 .577 .707 r
F P
0 g
s
.82235 .7284 m .82575 .69435 L .80187 .70216 L p .707 .577 .707 r
F P
0 g
s
.67907 .72339 m .68246 .68934 L .66139 .67669 L p .707 .577 .707 r
F P
0 g
s
.68246 .68934 m .67907 .72339 L .70648 .733 L p .707 .577 .707 r
F P
0 g
s
.29012 .69493 m .29351 .73316 L .26243 .73544 L p .707 .577 .707 r
F P
0 g
s
.26243 .73544 m .25904 .69721 L .29012 .69493 L p .707 .577 .707 r
F P
0 g
s
.23073 .73844 m .22734 .70022 L .25904 .69721 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51248 .74466 L p .707 .577 .707 r
F P
0 g
s
.51248 .74466 m .51248 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.25904 .69721 m .26243 .73544 L .23073 .73844 L p .707 .577 .707 r
F P
0 g
s
.81876 .61326 m .81319 .66377 L .82942 .65208 L p .707 .577 .707 r
F P
0 g
s
.82942 .65208 m .83499 .60156 L .81876 .61326 L p .707 .577 .707 r
F P
0 g
s
.46746 .74551 m .46746 .24362 L .51248 .24277 L p .707 .577 .707 r
F P
0 g
s
.46746 .24362 m .46746 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.6987 .71342 m .70122 .73248 L .7322 .7282 L p .707 .577 .707 r
F P
0 g
s
.7322 .7282 m .72968 .70914 L .6987 .71342 L p .707 .577 .707 r
F P
0 g
s
.72968 .70914 m .7322 .7282 L .76373 .72412 L p .707 .577 .707 r
F P
0 g
s
.64898 .64472 m .65455 .59421 L .64195 .57917 L p .707 .577 .707 r
F P
0 g
s
.65455 .59421 m .64898 .64472 L .66999 .65793 L p .707 .577 .707 r
F P
0 g
s
.76373 .72412 m .76121 .70506 L .72968 .70914 L p .707 .577 .707 r
F P
0 g
s
.51248 .24277 m .51248 .74466 L .46746 .74551 L p .707 .577 .707 r
F P
0 g
s
.76121 .70506 m .76373 .72412 L .79273 .72066 L p .707 .577 .707 r
F P
0 g
s
.79273 .72066 m .79021 .70161 L .76121 .70506 L p .707 .577 .707 r
F P
0 g
s
.66139 .67669 m .65799 .71075 L .67907 .72339 L p .707 .577 .707 r
F P
0 g
s
.82575 .69435 m .82235 .7284 L .83854 .71706 L p .707 .577 .707 r
F P
0 g
s
.83854 .71706 m .84194 .68301 L .82575 .69435 L p .707 .577 .707 r
F P
0 g
s
.67132 .71751 m .67384 .73656 L .70122 .73248 L p .707 .577 .707 r
F P
0 g
s
.70122 .73248 m .6987 .71342 L .67132 .71751 L p .707 .577 .707 r
F P
0 g
s
.65799 .71075 m .66139 .67669 L .64872 .66225 L p .707 .577 .707 r
F P
0 g
s
.79021 .70161 m .79273 .72066 L .81636 .71816 L p .707 .577 .707 r
F P
0 g
s
.81636 .71816 m .81384 .6991 L .79021 .70161 L p .707 .577 .707 r
F P
0 g
s
.6502 .72098 m .65272 .74004 L .67384 .73656 L p .707 .577 .707 r
F P
0 g
s
.67384 .73656 m .67132 .71751 L .6502 .72098 L p .707 .577 .707 r
F P
0 g
s
.83499 .60156 m .82942 .65208 L .83641 .63784 L p .707 .577 .707 r
F P
0 g
s
.83641 .63784 m .84198 .58732 L .83499 .60156 L p .707 .577 .707 r
F P
0 g
s
.64872 .66225 m .64533 .69631 L .65799 .71075 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .63638 .62968 L .64898 .64472 L p .707 .577 .707 r
F P
0 g
s
.84194 .68301 m .83854 .71706 L .84547 .7033 L p .707 .577 .707 r
F P
0 g
s
.84547 .7033 m .84886 .66925 L .84194 .68301 L p .707 .577 .707 r
F P
0 g
s
.64533 .69631 m .64872 .66225 L .6457 .64743 L p .707 .577 .707 r
F P
0 g
s
.81384 .6991 m .81636 .71816 L .83231 .71685 L p .707 .577 .707 r
F P
0 g
s
.83231 .71685 m .82979 .69779 L .81384 .6991 L p .707 .577 .707 r
F P
0 g
s
.63743 .72351 m .63995 .74257 L .65272 .74004 L p .707 .577 .707 r
F P
0 g
s
.65272 .74004 m .6502 .72098 L .63743 .72351 L p .707 .577 .707 r
F P
0 g
s
.6457 .64743 m .64231 .68148 L .64533 .69631 L p .707 .577 .707 r
F P
0 g
s
.84198 .58732 m .83641 .63784 L .83346 .62245 L p .707 .577 .707 r
F P
0 g
s
.83346 .62245 m .83903 .57193 L .84198 .58732 L p .707 .577 .707 r
F P
0 g
s
.639 .56377 m .63343 .61429 L .63638 .62968 L p .707 .577 .707 r
F P
0 g
s
.63343 .61429 m .639 .56377 L .64599 .54953 L p .707 .577 .707 r
F P
0 g
s
.84886 .66925 m .84547 .7033 L .84245 .68848 L p .707 .577 .707 r
F P
0 g
s
.84245 .68848 m .84584 .65443 L .84886 .66925 L p .707 .577 .707 r
F P
0 g
s
.64231 .68148 m .6457 .64743 L .65263 .63368 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.82979 .69779 m .83231 .71685 L .83902 .71686 L p .707 .577 .707 r
F P
0 g
s
.83902 .71686 m .8365 .6978 L .82979 .69779 L p .707 .577 .707 r
F P
0 g
s
.63423 .72485 m .63675 .74391 L .63995 .74257 L p .707 .577 .707 r
F P
0 g
s
.63995 .74257 m .63743 .72351 L .63423 .72485 L p .707 .577 .707 r
F P
0 g
s
.65263 .63368 m .64923 .66773 L .64231 .68148 L p .707 .577 .707 r
F P
0 g
s
.83903 .57193 m .83346 .62245 L .82086 .60741 L p .707 .577 .707 r
F P
0 g
s
.82086 .60741 m .82643 .55689 L .83903 .57193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64599 .54953 m .64042 .60005 L .63343 .61429 L p .707 .577 .707 r
F P
0 g
s
.64042 .60005 m .64599 .54953 L .66222 .53784 L p .707 .577 .707 r
F P
0 g
s
.37786 .61007 m .39068 .55468 L .36033 .5466 L p .707 .577 .707 r
F P
0 g
s
.39068 .55468 m .37786 .61007 L .40892 .61656 L p .707 .577 .707 r
F P
0 g
s
.40892 .61656 m .42174 .56118 L .39068 .55468 L p .707 .577 .707 r
F P
0 g
s
.84584 .65443 m .84245 .68848 L .82978 .67404 L p .707 .577 .707 r
F P
0 g
s
.82978 .67404 m .83318 .63999 L .84584 .65443 L p .707 .577 .707 r
F P
0 g
s
.64923 .66773 m .65263 .63368 L .66882 .62233 L p .707 .577 .707 r
F P
0 g
s
.42174 .56118 m .40892 .61656 L .43764 .62083 L p .707 .577 .707 r
F P
0 g
s
.43764 .62083 m .45046 .56545 L .42174 .56118 L p .707 .577 .707 r
F P
0 g
s
.34751 .60198 m .36033 .5466 L .33366 .53772 L p .707 .577 .707 r
F P
0 g
s
.36033 .5466 m .34751 .60198 L .37786 .61007 L p .707 .577 .707 r
F P
0 g
s
.8365 .6978 m .83902 .71686 L .83583 .7182 L p .707 .577 .707 r
F P
0 g
s
.83583 .7182 m .83331 .69914 L .8365 .6978 L p .707 .577 .707 r
F P
0 g
s
.33366 .53772 m .32084 .5931 L .34751 .60198 L p .707 .577 .707 r
F P
0 g
s
.45046 .56545 m .43764 .62083 L .46122 .62246 L p .707 .577 .707 r
F P
0 g
s
.46122 .62246 m .47404 .56707 L .45046 .56545 L p .707 .577 .707 r
F P
0 g
s
.82643 .55689 m .82086 .60741 L .79985 .5942 L p .707 .577 .707 r
F P
0 g
s
.79985 .5942 m .80542 .54368 L .82643 .55689 L p .707 .577 .707 r
F P
0 g
s
.66882 .62233 m .66543 .65639 L .64923 .66773 L p .707 .577 .707 r
F P
0 g
s
.32084 .5931 m .33366 .53772 L .31328 .52891 L p .707 .577 .707 r
F P
0 g
s
.66222 .53784 m .65665 .58836 L .64042 .60005 L p .707 .577 .707 r
F P
0 g
s
.65665 .58836 m .66222 .53784 L .68612 .52984 L p .707 .577 .707 r
F P
0 g
s
.64094 .72487 m .64346 .74393 L .63675 .74391 L p .707 .577 .707 r
F P
0 g
s
.63675 .74391 m .63423 .72485 L .64094 .72487 L p .707 .577 .707 r
F P
0 g
s
.83318 .63999 m .82978 .67404 L .80871 .6614 L p .707 .577 .707 r
F P
0 g
s
.80871 .6614 m .8121 .62734 L .83318 .63999 L p .707 .577 .707 r
F P
0 g
s
.39907 .66939 m .40689 .63237 L .37639 .62482 L p .707 .577 .707 r
F P
0 g
s
.40689 .63237 m .39907 .66939 L .43024 .67525 L p .707 .577 .707 r
F P
0 g
s
.43024 .67525 m .43807 .63822 L .40689 .63237 L p .707 .577 .707 r
F P
0 g
s
.66543 .65639 m .66882 .62233 L .69269 .61452 L p .707 .577 .707 r
F P
0 g
s
.31328 .52891 m .30046 .58429 L .32084 .5931 L p .707 .577 .707 r
F P
0 g
s
.43807 .63822 m .43024 .67525 L .45904 .67885 L p .707 .577 .707 r
F P
0 g
s
.45904 .67885 m .46687 .64182 L .43807 .63822 L p .707 .577 .707 r
F P
0 g
s
.36856 .66185 m .37639 .62482 L .34955 .61633 L p .707 .577 .707 r
F P
0 g
s
.37639 .62482 m .36856 .66185 L .39907 .66939 L p .707 .577 .707 r
F P
0 g
s
.47404 .56707 m .46122 .62246 L .47735 .62128 L p .707 .577 .707 r
F P
0 g
s
.47735 .62128 m .49017 .5659 L .47404 .56707 L p .707 .577 .707 r
F P
0 g
s
.80542 .54368 m .79985 .5942 L .77249 .5841 L p .707 .577 .707 r
F P
0 g
s
.77249 .5841 m .77806 .53359 L .80542 .54368 L p .707 .577 .707 r
F P
0 g
s
.41531 .72759 m .40958 .71069 L .37918 .72049 L p .707 .577 .707 r
F P
0 g
s
.40958 .71069 m .41531 .72759 L .44342 .71466 L p .707 .577 .707 r
F P
0 g
s
.44342 .71466 m .43769 .69776 L .40958 .71069 L p .707 .577 .707 r
F P
0 g
s
.68055 .58035 m .68612 .52984 L .71534 .52631 L p .707 .577 .707 r
F P
0 g
s
.68612 .52984 m .68055 .58035 L .65665 .58836 L p .707 .577 .707 r
F P
0 g
s
.34955 .61633 m .34172 .65336 L .36856 .66185 L p .707 .577 .707 r
F P
0 g
s
.38491 .73739 m .37918 .72049 L .34945 .7262 L p .707 .577 .707 r
F P
0 g
s
.37918 .72049 m .38491 .73739 L .41531 .72759 L p .707 .577 .707 r
F P
0 g
s
.83331 .69914 m .83583 .7182 L .82305 .72073 L p .707 .577 .707 r
F P
0 g
s
.82305 .72073 m .82053 .70167 L .83331 .69914 L p .707 .577 .707 r
F P
0 g
s
.30046 .58429 m .31328 .52891 L .30118 .52103 L p .707 .577 .707 r
F P
0 g
s
.46687 .64182 m .45904 .67885 L .48265 .67983 L p .707 .577 .707 r
F P
0 g
s
.48265 .67983 m .49048 .64281 L .46687 .64182 L p .707 .577 .707 r
F P
0 g
s
.69269 .61452 m .6893 .64857 L .66543 .65639 L p .707 .577 .707 r
F P
0 g
s
.8121 .62734 m .80871 .6614 L .78129 .65179 L p .707 .577 .707 r
F P
0 g
s
.78129 .65179 m .78469 .61773 L .8121 .62734 L p .707 .577 .707 r
F P
0 g
s
.6893 .64857 m .69269 .61452 L .72191 .61099 L p .707 .577 .707 r
F P
0 g
s
.43769 .69776 m .44342 .71466 L .46648 .69986 L p .707 .577 .707 r
F P
0 g
s
.46648 .69986 m .46075 .68296 L .43769 .69776 L p .707 .577 .707 r
F P
0 g
s
.34945 .7262 m .35518 .7431 L .38491 .73739 L p .707 .577 .707 r
F P
0 g
s
.34172 .65336 m .34955 .61633 L .329 .60772 L p .707 .577 .707 r
F P
0 g
s
.35518 .7431 m .34945 .7262 L .32332 .72726 L p .707 .577 .707 r
F P
0 g
s
.77806 .53359 m .77249 .5841 L .74145 .57812 L p .707 .577 .707 r
F P
0 g
s
.74145 .57812 m .74702 .5276 L .77806 .53359 L p .707 .577 .707 r
F P
0 g
s
.70977 .57683 m .71534 .52631 L .74702 .5276 L p .707 .577 .707 r
F P
0 g
s
.71534 .52631 m .70977 .57683 L .68055 .58035 L p .707 .577 .707 r
F P
0 g
s
.65689 .72356 m .65941 .74262 L .64346 .74393 L p .707 .577 .707 r
F P
0 g
s
.64346 .74393 m .64094 .72487 L .65689 .72356 L p .707 .577 .707 r
F P
0 g
s
.30118 .52103 m .28836 .57642 L .30046 .58429 L p .707 .577 .707 r
F P
0 g
s
.329 .60772 m .32117 .64475 L .34172 .65336 L p .707 .577 .707 r
F P
0 g
s
.74702 .5276 m .74145 .57812 L .70977 .57683 L p .707 .577 .707 r
F P
0 g
s
.32332 .72726 m .32904 .74416 L .35518 .7431 L p .707 .577 .707 r
F P
0 g
s
.78469 .61773 m .78129 .65179 L .75021 .64615 L p .707 .577 .707 r
F P
0 g
s
.75021 .64615 m .75361 .6121 L .78469 .61773 L p .707 .577 .707 r
F P
0 g
s
.71851 .64504 m .72191 .61099 L .75361 .6121 L p .707 .577 .707 r
F P
0 g
s
.72191 .61099 m .71851 .64504 L .6893 .64857 L p .707 .577 .707 r
F P
0 g
s
.75361 .6121 m .75021 .64615 L .71851 .64504 L p .707 .577 .707 r
F P
0 g
s
.46075 .68296 m .46648 .69986 L .48223 .68465 L p .707 .577 .707 r
F P
0 g
s
.48223 .68465 m .4765 .66775 L .46075 .68296 L p .707 .577 .707 r
F P
0 g
s
.49017 .5659 m .47735 .62128 L .48444 .61742 L p .707 .577 .707 r
F P
0 g
s
.48444 .61742 m .49726 .56203 L .49017 .5659 L p .707 .577 .707 r
F P
0 g
s
.49048 .64281 m .48265 .67983 L .49875 .67811 L p .707 .577 .707 r
F P
0 g
s
.49875 .67811 m .50658 .64108 L .49048 .64281 L p .707 .577 .707 r
F P
0 g
s
.32904 .74416 m .32332 .72726 L .30333 .72357 L p .707 .577 .707 r
F P
0 g
s
.82053 .70167 m .82305 .72073 L .80193 .72421 L p .707 .577 .707 r
F P
0 g
s
.32117 .64475 m .329 .60772 L .31675 .59984 L p .707 .577 .707 r
F P
0 g
s
.28836 .57642 m .30118 .52103 L .29854 .51486 L p .707 .577 .707 r
F P
0 g
s
.80193 .72421 m .79941 .70515 L .82053 .70167 L p .707 .577 .707 r
F P
0 g
s
.30333 .72357 m .30905 .74047 L .32904 .74416 L p .707 .577 .707 r
F P
0 g
s
.31675 .59984 m .30892 .63687 L .32117 .64475 L p .707 .577 .707 r
F P
0 g
s
.68052 .72105 m .68304 .74011 L .65941 .74262 L p .707 .577 .707 r
F P
0 g
s
.65941 .74262 m .65689 .72356 L .68052 .72105 L p .707 .577 .707 r
F P
0 g
s
.29854 .51486 m .28572 .57024 L .28836 .57642 L p .707 .577 .707 r
F P
0 g
s
.4765 .66775 m .48223 .68465 L .48914 .67051 L p .707 .577 .707 r
F P
0 g
s
.48914 .67051 m .48341 .65361 L .4765 .66775 L p .707 .577 .707 r
F P
0 g
s
.30905 .74047 m .30333 .72357 L .29144 .71548 L p .707 .577 .707 r
F P
0 g
s
.50658 .64108 m .49875 .67811 L .50577 .67385 L p .707 .577 .707 r
F P
0 g
s
.50577 .67385 m .51359 .63682 L .50658 .64108 L p .707 .577 .707 r
F P
0 g
s
.79941 .70515 m .80193 .72421 L .77455 .72829 L p .707 .577 .707 r
F P
0 g
s
.77455 .72829 m .77203 .70923 L .79941 .70515 L p .707 .577 .707 r
F P
0 g
s
.49726 .56203 m .48444 .61742 L .48181 .61125 L p .707 .577 .707 r
F P
0 g
s
.48181 .61125 m .49463 .55586 L .49726 .56203 L p .707 .577 .707 r
F P
0 g
s
.30892 .63687 m .31675 .59984 L .314 .59346 L p .707 .577 .707 r
F P
0 g
s
.29144 .71548 m .29717 .73239 L .30905 .74047 L p .707 .577 .707 r
F P
0 g
s
.70953 .71759 m .71205 .73665 L .68304 .74011 L p .707 .577 .707 r
F P
0 g
s
.68304 .74011 m .68052 .72105 L .70953 .71759 L p .707 .577 .707 r
F P
0 g
s
.28572 .57024 m .29854 .51486 L .30564 .511 L p .707 .577 .707 r
F P
0 g
s
.314 .59346 m .30617 .63048 L .30892 .63687 L p .707 .577 .707 r
F P
0 g
s
.77203 .70923 m .77455 .72829 L .74358 .73258 L p .707 .577 .707 r
F P
0 g
s
.74358 .73258 m .74106 .71352 L .77203 .70923 L p .707 .577 .707 r
F P
0 g
s
.30564 .511 m .29282 .56638 L .28572 .57024 L p .707 .577 .707 r
F P
0 g
s
.74106 .71352 m .74358 .73258 L .71205 .73665 L p .707 .577 .707 r
F P
0 g
s
.71205 .73665 m .70953 .71759 L .74106 .71352 L p .707 .577 .707 r
F P
0 g
s
.48341 .65361 m .48914 .67051 L .48652 .65882 L p .707 .577 .707 r
F P
0 g
s
.48652 .65882 m .48079 .64192 L .48341 .65361 L p .707 .577 .707 r
F P
0 g
s
.29717 .73239 m .29144 .71548 L .28882 .7038 L p .707 .577 .707 r
F P
0 g
s
.51359 .63682 m .50577 .67385 L .50301 .66746 L p .707 .577 .707 r
F P
0 g
s
.50301 .66746 m .51084 .63043 L .51359 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49463 .55586 m .48181 .61125 L .46971 .60337 L p .707 .577 .707 r
F P
0 g
s
.46971 .60337 m .48253 .54799 L .49463 .55586 L p .707 .577 .707 r
F P
0 g
s
.28882 .7038 m .29455 .7207 L .29717 .73239 L p .707 .577 .707 r
F P
0 g
s
.30617 .63048 m .314 .59346 L .32101 .58919 L p .707 .577 .707 r
F P
0 g
s
.29282 .56638 m .30564 .511 L .32176 .50982 L p .707 .577 .707 r
F P
0 g
s
.32101 .58919 m .31319 .62622 L .30617 .63048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32176 .50982 m .30894 .56521 L .29282 .56638 L p .707 .577 .707 r
F P
0 g
s
.48079 .64192 m .48652 .65882 L .47463 .65074 L p .707 .577 .707 r
F P
0 g
s
.47463 .65074 m .4689 .63384 L .48079 .64192 L p .707 .577 .707 r
F P
0 g
s
.29455 .7207 m .28882 .7038 L .29573 .68966 L p .707 .577 .707 r
F P
0 g
s
.48253 .54799 m .46971 .60337 L .44932 .59456 L p .707 .577 .707 r
F P
0 g
s
.44932 .59456 m .46214 .53918 L .48253 .54799 L p .707 .577 .707 r
F P
0 g
s
.51084 .63043 m .50301 .66746 L .49076 .65958 L p .707 .577 .707 r
F P
0 g
s
.49076 .65958 m .49859 .62255 L .51084 .63043 L p .707 .577 .707 r
F P
0 g
s
.29573 .68966 m .30145 .70656 L .29455 .7207 L p .707 .577 .707 r
F P
0 g
s
.30894 .56521 m .32176 .50982 L .34534 .51145 L p .707 .577 .707 r
F P
0 g
s
.31319 .62622 m .32101 .58919 L .33711 .58747 L p .707 .577 .707 r
F P
0 g
s
.33711 .58747 m .32929 .6245 L .31319 .62622 L p .707 .577 .707 r
F P
0 g
s
.34534 .51145 m .33252 .56683 L .30894 .56521 L p .707 .577 .707 r
F P
0 g
s
.4689 .63384 m .47463 .65074 L .45464 .64705 L p .707 .577 .707 r
F P
0 g
s
.45464 .64705 m .44891 .63014 L .4689 .63384 L p .707 .577 .707 r
F P
0 g
s
.46214 .53918 m .44932 .59456 L .42265 .58568 L p .707 .577 .707 r
F P
0 g
s
.42265 .58568 m .43547 .53029 L .46214 .53918 L p .707 .577 .707 r
F P
0 g
s
.30145 .70656 m .29573 .68966 L .31148 .67444 L p .707 .577 .707 r
F P
0 g
s
.33252 .56683 m .34534 .51145 L .37406 .51572 L p .707 .577 .707 r
F P
0 g
s
.49859 .62255 m .49076 .65958 L .47021 .65097 L p .707 .577 .707 r
F P
0 g
s
.47021 .65097 m .47804 .61394 L .49859 .62255 L p .707 .577 .707 r
F P
0 g
s
.31148 .67444 m .31721 .69135 L .30145 .70656 L p .707 .577 .707 r
F P
0 g
s
.32929 .6245 m .33711 .58747 L .36072 .58845 L p .707 .577 .707 r
F P
0 g
s
.37406 .51572 m .36125 .5711 L .33252 .56683 L p .707 .577 .707 r
F P
0 g
s
.43547 .53029 m .42265 .58568 L .3923 .5776 L p .707 .577 .707 r
F P
0 g
s
.3923 .5776 m .40512 .52221 L .43547 .53029 L p .707 .577 .707 r
F P
0 g
s
.36125 .5711 m .37406 .51572 L .40512 .52221 L p .707 .577 .707 r
F P
0 g
s
.36072 .58845 m .35289 .62548 L .32929 .6245 L p .707 .577 .707 r
F P
0 g
s
.44891 .63014 m .45464 .64705 L .4285 .64811 L p .707 .577 .707 r
F P
0 g
s
.4285 .64811 m .42278 .6312 L .44891 .63014 L p .707 .577 .707 r
F P
0 g
s
.40512 .52221 m .3923 .5776 L .36125 .5711 L p .707 .577 .707 r
F P
0 g
s
.31721 .69135 m .31148 .67444 L .33454 .65965 L p .707 .577 .707 r
F P
0 g
s
.47804 .61394 m .47021 .65097 L .44337 .64248 L p .707 .577 .707 r
F P
0 g
s
.44337 .64248 m .4512 .60545 L .47804 .61394 L p .707 .577 .707 r
F P
0 g
s
.33454 .65965 m .34026 .67655 L .31721 .69135 L p .707 .577 .707 r
F P
0 g
s
.35289 .62548 m .36072 .58845 L .38952 .59205 L p .707 .577 .707 r
F P
0 g
s
.42278 .6312 m .4285 .64811 L .39878 .65382 L p .707 .577 .707 r
F P
0 g
s
.39878 .65382 m .39305 .63691 L .42278 .6312 L p .707 .577 .707 r
F P
0 g
s
.38952 .59205 m .38169 .62908 L .35289 .62548 L p .707 .577 .707 r
F P
0 g
s
.34026 .67655 m .33454 .65965 L .36265 .64671 L p .707 .577 .707 r
F P
0 g
s
.4512 .60545 m .44337 .64248 L .41287 .63493 L p .707 .577 .707 r
F P
0 g
s
.41287 .63493 m .4207 .59791 L .4512 .60545 L p .707 .577 .707 r
F P
0 g
s
.38169 .62908 m .38952 .59205 L .4207 .59791 L p .707 .577 .707 r
F P
0 g
s
.39305 .63691 m .39878 .65382 L .36837 .66362 L p .707 .577 .707 r
F P
0 g
s
.36837 .66362 m .36265 .64671 L .39305 .63691 L p .707 .577 .707 r
F P
0 g
s
.36265 .64671 m .36837 .66362 L .34026 .67655 L p .707 .577 .707 r
F P
0 g
s
.4207 .59791 m .41287 .63493 L .38169 .62908 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Iooa00009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00E7oo0`0015YF00<005YFFUH015YF00@005YFFUIJEPL0
009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00moo`P004eoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool02Goo1P000eYF00<005YFFUH00UYF2@00A7oo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01Goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol00goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003aoo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol00Woo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH01UYF00@005YFFUIJEP8003Yoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF
0P00>7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool00003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF000eOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00<goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<007ooOol0<7oo001BOol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000aOol0055oo`03001JEP00009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0000`Ool0055oo`03001JEP0000<000AJEPL000AJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000_Ool0055oo`8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP05001J
EUYFFUH0000^Ool0055oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPl000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool005=oo`<0
00IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF1P003goo10000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Goo001EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000<001Uoo`@000IJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001GOol300000eYF0000000=0002FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH2000QOol40002FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00FGoo0`000eYF00<005YFFUH015YF00@005YFFUIJ
EPL000AJEP03001JEUYF00AJEP800003FUH005YF00EJEP06001JEUYF001JEP001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0002FUH2000VOol30005FUH01`00
FUIJEUYF001JEP0002eoo`00FGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01@0025YF0`0015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYF001JEP03000015YF0000000057oo0`0047oo0P000eYF00L005YFFUIJ
EP00FUH0000]Ool005Uoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00=JEP04001JEUYFFUH300000eYF001JEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP04001JEUYF000BOol5000AOol01000FUIJEP000eYF
00<005YF0000;Goo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040006FUH20003FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF0P0047oo1@004Woo0`000eYF0P00;Woo001H
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40002FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH2000>Ool5000DOol01000FUIJEUYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01000FUH000001Goo2`005Goo0P000UYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP060004FUH00`00FUIJEP02FUH9000<
Ool200001UYF001JEP00FUH002ioo`00F7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000Woo100000AJEP00FUIJEP800003FUH007oo02eo
o`00D7oo200000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH00`00FUIJEP0200000eYF001oo`0]Ool004Mo
o`T000AJEP06001JEUYF001JEP000UYF300015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00L005YFFUIJEP00FUH0000^Ool003moo`P000AJEP03001JEUYF
00IJEP05001JEUYF001JEP040005FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEP0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH5
0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P000eYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P00;goo000aOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00UYF2P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0002FUH2000_Ool002aoo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000IJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH015YF1@0000=JEP00
FUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo02ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF
0P000eYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF009JEQ0000IJEP03001J
EUYF00AJEP03001JEUYF00AJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH00UYF0`00
25YF00<005YFFUH00eYF3P0000=JEP00FUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF1P001eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF0000;Woo000/Ool00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH60005FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YF
00000P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF0P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00D005YFFUIJEP0002aoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00008000EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP@000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<0009JEP800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP06001JEP00001JEP001EYF00<005YFFUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30008FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF
10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP03001oogoo02Yoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF0`00
0UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF0080
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000006
FUH01000FUIJEUYF1@001UYF00<005YF00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@000=J
EP03001JEUYF009JEP8002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P001EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEP0000800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP03
001JEUYF00D0009JEPH000=JEP03001JEUYF00EJEP04001JEP000004Ool200000eYF001JEP03FUH2
000[Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000MJEP06001JEP00001JEP000UYF00<005YFFUH015YF00<005YFFUH0
0UYF10000UYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP00009JEP05001JEP00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF00000eYF00@007ooOomoo`P000=JEP03001JEUYF009JEPD000Qoo`8000=JEP03001JEP0002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001eYF1P000UYF00<005YFFUH015YF00<005YFFUH01UYF1P0015YF00<005YF00000eYF
00@005YF001JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEPP000=JEP04001JEUYF0006Ool=000?Ool01P00FUIJEP00FUH002]oo`00
;Goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@000UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP80009JEP03001JEUYF00AJEP<000IJEP03
001JEUYF00=JEPH000EJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP<000=JEP06001JEP00001JEP000UYF00<007ooOol01Goo0`006Goo00D0
05YF001JEP0002]oo`00;Woo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF4`00
0eYF00@005YFFUH000=JEPL00005Ool005YFFUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP000UYF00@005YFFUIJEP80009JEP8002=oo`800003FUH007oo02Yo
o`00;Woo0UYF00<005YFFUH00UYF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04001JEUYF0004
FUH40007Ool01000FUIJEP001EYF1@001EYF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUIJ
EP<000EJEP800003FUH007oo025oo`@002aoo`00;Woo0UYF00<005YFFUH01P001eYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`001EYF00<007ooOol027oo00@005YFFUH000EJEPD000EJEP03001JEUYF
00AJEP05001JEUYFFUH00003FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF0P0015YF00@005YF0000021oo`80009J
EP8002aoo`00;Woo0UYF0`001EYF00<005YFFUH00UYF600015YF3@000UYF00<005YFFUH015YF0`00
1UYF00<005YFFUH00UYF0P0015YF00@005YFFUH000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUH000040002FUH00`00Oomo
o`0LOol20004FUH2000/Ool002ioo`l000Qoo`T000AJEP<0009JEP800003FUH005YF00AJEP03001J
EUYF00<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP05001JEUYFFUH00007FUH2000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF
00<005YFFUH00eYF1@0067oo2P0000=JEP000000;7oo000mOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUH000020007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH010003Goo1`00
0eYF100000IJEP00000005YF000/Ool003Eoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH=0003FUH70002
FUH00`00FUIJEP04000]Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00AJEP03001J
EUYF00AJEP8000EJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUH000080003
FUH90003FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00;Goo000ZOol50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH30003FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP03FUH01000FUIJEUYF1P0015YF200015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH00eYF10000UYF00<005YFFUH01UYF0P001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0009JEP8000=JEP@00003FUH005YF
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEP0000<000MJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0002FUH50005FUH60006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF1`00;goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06
00000eYF001JEP08FUH00`00FUIJEP030009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF1@000UYF00@005YF0000031oo`00:Woo00<005YF000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEPd000IJEP03001JEUYF
00IJEP@000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEP0000@000IJEP80039oo`00:Woo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH2000cOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@000UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHD
0002FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPP0009JEP03001JEUYF00IJEP03001JEUYF009JEPD003Uoo`00
:goo00<005YF000015YF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEP000080009JEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF
00@005YFFUIJEPP000Qooa0003ioo`00:goo00<005YF00000UYF1`001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF3@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF5P001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02`0000EJEP00FUIJEP00
05Uoo`00:goo00<005YF00000`000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF009J
EPT0009oo`8000=JEP03001JEUYF009JEP80009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<005YFFUH00UYF100017oo
0`000eYF00<007ooOol0EWoo000[Ool20002FUH01000FUH000000eYF00<005YFFUH00UYF4@003Goo
0P0000=JEP00FUH01EYF00<007oo00000UYF00<005YFFUH015YF00<005YFFUH015YF1P000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1P000UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol017oo0P000UYF0P0000=JEP00Ool0Egoo000/Ool?000POol20006FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUH00003FUH40006FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUIJEP02FUH01000
FUH00000F7oo000^Ool2000]Ool20004FUH00`00FUH00002FUH00`00FUIJEP03FUH400000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH01000Oomoogoo0`0015YF00@005YFFUH005Qoo`00;Woo0P00;goo00@005YFFUH0
009JEP04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH300000eYF001JEP03FUH01000Ool000000UYF00<005YFFUH0
0UYF00D005YFFUIJEP0005Moo`00;Woo00<007ooOol0;goo0`000UYF00D005YFFUH005YF008000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF008000AJEP8000EJEP03001JEUYF009JEP04001JEUYF001GOol002eoo`<0039oo`04
001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0001HOol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP02FUH00`00FUH0001HOol002eoo`03
001JEP0001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH0
0`00FUIJEP03FUH00`00Oomoo`1GOol002eoo`04001JEP00000FOol5000HOol30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH00eYF00<007ooOol0Egoo000]Ool0
1@00FUH005YF00005Goo1@006Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00MJEP03001JEUYF008005Yoo`00;Woo00@005YFFUH001Ioo`<001Yoo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0007FUH3001LOol002ioo`05001JEUYFFUH0000cOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<007ooOol0G7oo000^Ool0
0`00FUIJEP02FUH00`00Oomoo`0`Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF001JEP04FUH2001OOol002moo`04001JEUYFFUH3000`Ool30002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP02001QOol0031oo`04001JEUYF0002FUH00`00Oomoo`0]
Ool2000017oo000000001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF2000Hgoo000`Ool00`00FUH00004FUH2000]Ool2
0003Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUH000020005FUH3001SOol0035oo`8000IJEP03001oogoo02Uoo`8000Io
o`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP<000UJEP04001JEP00001QOol0039oo`03001JEUYF00AJEP<002Moo`@000Qoo`<00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0
00QJEP04001JEUYFFUH3001NOol003=oo`8000AJEP03001JEUYF008002Aoo`04001JEUYF000<Ool7
0005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0000=0004FUH00`00
FUIJEP05FUH2001LOol003Eoo`04001JEUYF0005FUH2000POol20003FUH00`00Oomoo`0AOol;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004FUH60004Ool300000eYF001JEP07FUH3001JOol0
03Ioo`<000MJEP<001Uoo`@00005FUH005YFFUH0000OOolM00000eYF001JEP05FUH500000eYF0000
00020003Ool30006FUH01000FUIJEUYF0P00F7oo000hOol20006FUH00`00FUIJEP04000@Ool50004
FUH01000FUH00000<Goo3`001UYF0`001UYF10000Woo0P0015YF00<005YFFUH00eYF0P00EWoo000j
Ool20004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH20012Ool20005FUH00`00FUIJEP07
FUH00`00FUH0000500000eYF001JEP06FUH3001DOol003aoo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo04=oo`<00003FUH005YF00QJEP03001J
EUYF00AJEP@000IJEP05001JEUYFFUH0001COol003moo`<000IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH20019Ool30008FUH00`00FUIJEP06FUH01000FUH0000015YF00@005YFFUIJ
EP80059oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000004ioo`<000EJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEP00059oo`00AWoo1`00
15YF00<005YFFUH00UYF1P00Dgoo0`0000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF0P00Dgoo
001=Ool9001LOol30007FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001oo`1BOol00;Eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00^Goo1P000eYF00L005YFFUIJEP00FUH0
001DOol00;moo`T005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63875 .7505 m .62593 .698 L .59488 .70557 L p .707 .577 .707 r
F P
0 g
s
.62593 .698 m .63875 .7505 L .66747 .73994 L p .707 .577 .707 r
F P
0 g
s
.66747 .73994 m .65466 .68743 L .62593 .698 L p .707 .577 .707 r
F P
0 g
s
.60769 .75808 m .59488 .70557 L .56453 .70941 L p .707 .577 .707 r
F P
0 g
s
.59488 .70557 m .60769 .75808 L .63875 .7505 L p .707 .577 .707 r
F P
0 g
s
.65466 .68743 m .66747 .73994 L .69105 .72742 L p .707 .577 .707 r
F P
0 g
s
.69105 .72742 m .67823 .67491 L .65466 .68743 L p .707 .577 .707 r
F P
0 g
s
.57734 .76192 m .56453 .70941 L .53785 .70915 L p .707 .577 .707 r
F P
0 g
s
.56453 .70941 m .57734 .76192 L .60769 .75808 L p .707 .577 .707 r
F P
0 g
s
.58713 .82027 m .5793 .78501 L .5488 .78843 L p .707 .577 .707 r
F P
0 g
s
.5793 .78501 m .58713 .82027 L .61831 .81321 L p .707 .577 .707 r
F P
0 g
s
.61831 .81321 m .61048 .77796 L .5793 .78501 L p .707 .577 .707 r
F P
0 g
s
.61048 .77796 m .61831 .81321 L .64711 .80321 L p .707 .577 .707 r
F P
0 g
s
.64711 .80321 m .63928 .76795 L .61048 .77796 L p .707 .577 .707 r
F P
0 g
s
.55663 .82368 m .5488 .78843 L .52196 .78786 L p .707 .577 .707 r
F P
0 g
s
.5488 .78843 m .55663 .82368 L .58713 .82027 L p .707 .577 .707 r
F P
0 g
s
.63928 .76795 m .64711 .80321 L .67071 .79123 L p .707 .577 .707 r
F P
0 g
s
.67071 .79123 m .66288 .75598 L .63928 .76795 L p .707 .577 .707 r
F P
0 g
s
.67823 .67491 m .69105 .72742 L .70718 .71417 L p .707 .577 .707 r
F P
0 g
s
.70718 .71417 m .69436 .66166 L .67823 .67491 L p .707 .577 .707 r
F P
0 g
s
.55067 .76165 m .53785 .70915 L .51747 .7048 L p .707 .577 .707 r
F P
0 g
s
.53785 .70915 m .55067 .76165 L .57734 .76192 L p .707 .577 .707 r
F P
0 g
s
.60122 .83553 m .60695 .81735 L .57722 .80715 L p .707 .577 .707 r
F P
0 g
s
.60695 .81735 m .60122 .83553 L .63162 .84452 L p .707 .577 .707 r
F P
0 g
s
.63162 .84452 m .63735 .82635 L .60695 .81735 L p .707 .577 .707 r
F P
0 g
s
.52196 .78786 m .52979 .82312 L .55663 .82368 L p .707 .577 .707 r
F P
0 g
s
.57722 .80715 m .57149 .82532 L .60122 .83553 L p .707 .577 .707 r
F P
0 g
s
.63735 .82635 m .63162 .84452 L .65973 .85144 L p .707 .577 .707 r
F P
0 g
s
.65973 .85144 m .66546 .83326 L .63735 .82635 L p .707 .577 .707 r
F P
0 g
s
.52979 .82312 m .52196 .78786 L .50141 .78338 L p .707 .577 .707 r
F P
0 g
s
.57149 .82532 m .57722 .80715 L .55108 .79674 L p .707 .577 .707 r
F P
0 g
s
.66288 .75598 m .67071 .79123 L .68681 .77846 L p .707 .577 .707 r
F P
0 g
s
.68681 .77846 m .67898 .7432 L .66288 .75598 L p .707 .577 .707 r
F P
0 g
s
.55108 .79674 m .54536 .81492 L .57149 .82532 L p .707 .577 .707 r
F P
0 g
s
.51747 .7048 m .53029 .75731 L .55067 .76165 L p .707 .577 .707 r
F P
0 g
s
.69436 .66166 m .70718 .71417 L .71427 .70148 L p .707 .577 .707 r
F P
0 g
s
.71427 .70148 m .70145 .64898 L .69436 .66166 L p .707 .577 .707 r
F P
0 g
s
.53029 .75731 m .51747 .7048 L .50537 .6968 L p .707 .577 .707 r
F P
0 g
s
.66546 .83326 m .65973 .85144 L .68279 .85559 L p .707 .577 .707 r
F P
0 g
s
.68279 .85559 m .68852 .83741 L .66546 .83326 L p .707 .577 .707 r
F P
0 g
s
.50141 .78338 m .50924 .81864 L .52979 .82312 L p .707 .577 .707 r
F P
0 g
s
.54536 .81492 m .55108 .79674 L .53109 .78715 L p .707 .577 .707 r
F P
0 g
s
.53109 .78715 m .52537 .80532 L .54536 .81492 L p .707 .577 .707 r
F P
0 g
s
.50924 .81864 m .50141 .78338 L .48916 .77542 L p .707 .577 .707 r
F P
0 g
s
.67898 .7432 m .68681 .77846 L .69383 .76613 L p .707 .577 .707 r
F P
0 g
s
.69383 .76613 m .686 .73088 L .67898 .7432 L p .707 .577 .707 r
F P
0 g
s
.50537 .6968 m .51819 .74931 L .53029 .75731 L p .707 .577 .707 r
F P
0 g
s
.68852 .83741 m .68279 .85559 L .69854 .85657 L p .707 .577 .707 r
F P
0 g
s
.69854 .85657 m .70427 .8384 L .68852 .83741 L p .707 .577 .707 r
F P
0 g
s
.48916 .77542 m .49698 .81067 L .50924 .81864 L p .707 .577 .707 r
F P
0 g
s
.70145 .64898 m .71427 .70148 L .71164 .69061 L p .698 .572 .709 r
F P
0 g
s
.71164 .69061 m .69882 .6381 L .70145 .64898 L p .698 .572 .709 r
F P
0 g
s
.51819 .74931 m .50537 .6968 L .50274 .68593 L p .698 .572 .709 r
F P
0 g
s
.52537 .80532 m .53109 .78715 L .51921 .77931 L p .707 .577 .707 r
F P
0 g
s
.51921 .77931 m .51348 .79748 L .52537 .80532 L p .707 .577 .707 r
F P
0 g
s
.49698 .81067 m .48916 .77542 L .4864 .76476 L p .708 .578 .707 r
F P
0 g
s
.686 .73088 m .69383 .76613 L .69108 .75547 L p .708 .578 .707 r
F P
0 g
s
.69108 .75547 m .68325 .72022 L .686 .73088 L p .708 .578 .707 r
F P
0 g
s
.4864 .76476 m .49423 .80001 L .49698 .81067 L p .708 .578 .707 r
F P
0 g
s
.49423 .80001 m .4864 .76476 L .49342 .75243 L p .707 .577 .707 r
F P
0 g
s
.48752 .82178 m .48752 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.50274 .68593 m .51556 .73843 L .51819 .74931 L p .698 .572 .709 r
F P
0 g
s
.51348 .79748 m .51921 .77931 L .51659 .77399 L p .707 .577 .707 r
F P
0 g
s
.51556 .73843 m .50274 .68593 L .50983 .67324 L p .707 .577 .707 r
F P
0 g
s
.51659 .77399 m .51086 .79216 L .51348 .79748 L p .707 .577 .707 r
F P
0 g
s
.50983 .67324 m .52265 .72575 L .51556 .73843 L p .707 .577 .707 r
F P
0 g
s
.49342 .75243 m .50125 .78769 L .49423 .80001 L p .707 .577 .707 r
F P
0 g
s
.52265 .72575 m .50983 .67324 L .52596 .65999 L p .707 .577 .707 r
F P
0 g
s
.51086 .79216 m .51659 .77399 L .52349 .77171 L p .707 .577 .707 r
F P
0 g
s
.52349 .77171 m .51777 .78988 L .51086 .79216 L p .707 .577 .707 r
F P
0 g
s
.50125 .78769 m .49342 .75243 L .50952 .73966 L p .707 .577 .707 r
F P
0 g
s
.52596 .65999 m .53878 .7125 L .52265 .72575 L p .707 .577 .707 r
F P
0 g
s
.50952 .73966 m .51735 .77491 L .50125 .78769 L p .707 .577 .707 r
F P
0 g
s
.51777 .78988 m .52349 .77171 L .53925 .77269 L p .707 .577 .707 r
F P
0 g
s
.53925 .77269 m .53352 .79087 L .51777 .78988 L p .707 .577 .707 r
F P
0 g
s
.51735 .77491 m .50952 .73966 L .53313 .72768 L p .707 .577 .707 r
F P
0 g
s
.53313 .72768 m .54095 .76294 L .51735 .77491 L p .707 .577 .707 r
F P
0 g
s
.48752 .31989 m .48752 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53878 .7125 m .52596 .65999 L .54954 .64747 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48752 .31989 L p .707 .577 .707 r
F P
0 g
s
.56235 .69998 m .54954 .64747 L .57826 .63691 L p .707 .577 .707 r
F P
0 g
s
.54954 .64747 m .56235 .69998 L .53878 .7125 L p .707 .577 .707 r
F P
0 g
s
.57826 .63691 m .59108 .68941 L .56235 .69998 L p .707 .577 .707 r
F P
0 g
s
.54095 .76294 m .53313 .72768 L .56193 .71768 L p .707 .577 .707 r
F P
0 g
s
.53352 .79087 m .53925 .77269 L .56231 .77684 L p .707 .577 .707 r
F P
0 g
s
.56231 .77684 m .55658 .79502 L .53352 .79087 L p .707 .577 .707 r
F P
0 g
s
.56975 .75293 m .56193 .71768 L .5931 .71062 L p .707 .577 .707 r
F P
0 g
s
.56193 .71768 m .56975 .75293 L .54095 .76294 L p .707 .577 .707 r
F P
0 g
s
.55658 .79502 m .56231 .77684 L .59041 .78376 L p .707 .577 .707 r
F P
0 g
s
.59041 .78376 m .58469 .80193 L .55658 .79502 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57437 .81638 L p .707 .577 .707 r
F P
0 g
s
.5931 .71062 m .60093 .74588 L .56975 .75293 L p .707 .577 .707 r
F P
0 g
s
.57437 .81638 m .57437 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70427 .8384 m .69854 .85657 L .70545 .85429 L p .707 .577 .707 r
F P
0 g
s
.70545 .85429 m .71118 .83612 L .70427 .8384 L p .707 .577 .707 r
F P
0 g
s
.44372 .81886 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44372 .81886 L .48752 .82178 L p .707 .577 .707 r
F P
0 g
s
.69882 .6381 m .71164 .69061 L .69954 .68261 L p .707 .577 .707 r
F P
0 g
s
.69954 .68261 m .68672 .6301 L .69882 .6381 L p .707 .577 .707 r
F P
0 g
s
.60932 .62933 m .62213 .68184 L .59108 .68941 L p .707 .577 .707 r
F P
0 g
s
.59108 .68941 m .57826 .63691 L .60932 .62933 L p .707 .577 .707 r
F P
0 g
s
.6236 .70721 m .63143 .74247 L .60093 .74588 L p .707 .577 .707 r
F P
0 g
s
.60093 .74588 m .5931 .71062 L .6236 .70721 L p .707 .577 .707 r
F P
0 g
s
.58469 .80193 m .59041 .78376 L .62082 .79275 L p .707 .577 .707 r
F P
0 g
s
.62082 .79275 m .61509 .81093 L .58469 .80193 L p .707 .577 .707 r
F P
0 g
s
.57437 .31449 m .57437 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .3067 L .57437 .31449 L p .707 .577 .707 r
F P
0 g
s
.25855 .6932 m .25298 .63584 L .22194 .63851 L p .707 .577 .707 r
F P
0 g
s
.25298 .63584 m .25855 .6932 L .29023 .68999 L p .707 .577 .707 r
F P
0 g
s
.29023 .68999 m .28466 .63263 L .25298 .63584 L p .707 .577 .707 r
F P
0 g
s
.68325 .72022 m .69108 .75547 L .67882 .74751 L p .707 .577 .707 r
F P
0 g
s
.67882 .74751 m .671 .71225 L .68325 .72022 L p .707 .577 .707 r
F P
0 g
s
.22194 .63851 m .22751 .69587 L .25855 .6932 L p .707 .577 .707 r
F P
0 g
s
.28466 .63263 m .29023 .68999 L .31945 .68656 L p .707 .577 .707 r
F P
0 g
s
.31945 .68656 m .31388 .62919 L .28466 .63263 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44372 .81886 L p .707 .577 .707 r
F P
0 g
s
.22751 .69587 m .22194 .63851 L .19458 .64038 L p .707 .577 .707 r
F P
0 g
s
.71118 .83612 m .70545 .85429 L .70283 .84897 L p .707 .577 .707 r
F P
0 g
s
.70283 .84897 m .70856 .8308 L .71118 .83612 L p .707 .577 .707 r
F P
0 g
s
.19458 .64038 m .20014 .69775 L .22751 .69587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68672 .6301 m .69954 .68261 L .67916 .67826 L p .707 .577 .707 r
F P
0 g
s
.67916 .67826 m .66634 .62576 L .68672 .6301 L p .707 .577 .707 r
F P
0 g
s
.31388 .62919 m .31945 .68656 L .34335 .68324 L p .707 .577 .707 r
F P
0 g
s
.34335 .68324 m .33778 .62588 L .31388 .62919 L p .707 .577 .707 r
F P
0 g
s
.63143 .74247 m .6236 .70721 L .65044 .70777 L p .707 .577 .707 r
F P
0 g
s
.63967 .62549 m .65248 .678 L .62213 .68184 L p .707 .577 .707 r
F P
0 g
s
.62213 .68184 m .60932 .62933 L .63967 .62549 L p .707 .577 .707 r
F P
0 g
s
.61509 .81093 m .62082 .79275 L .65054 .80296 L p .707 .577 .707 r
F P
0 g
s
.60892 .3067 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.65044 .70777 m .65827 .74303 L .63143 .74247 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .3067 L p .707 .577 .707 r
F P
0 g
s
.20014 .69775 m .19458 .64038 L .17357 .64128 L p .707 .577 .707 r
F P
0 g
s
.17357 .64128 m .17914 .69864 L .20014 .69775 L p .707 .577 .707 r
F P
0 g
s
.671 .71225 m .67882 .74751 L .65827 .74303 L p .707 .577 .707 r
F P
0 g
s
.65827 .74303 m .65044 .70777 L .671 .71225 L p .707 .577 .707 r
F P
0 g
s
.66634 .62576 m .67916 .67826 L .65248 .678 L p .707 .577 .707 r
F P
0 g
s
.65248 .678 m .63967 .62549 L .66634 .62576 L p .707 .577 .707 r
F P
0 g
s
.33778 .62588 m .34335 .68324 L .35958 .68036 L p .707 .577 .707 r
F P
0 g
s
.35958 .68036 m .35401 .623 L .33778 .62588 L p .707 .577 .707 r
F P
0 g
s
.24979 .75025 m .24639 .71202 L .21531 .7143 L p .707 .577 .707 r
F P
0 g
s
.24639 .71202 m .24979 .75025 L .28149 .74724 L p .707 .577 .707 r
F P
0 g
s
.28149 .74724 m .27809 .70901 L .24639 .71202 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.21531 .7143 m .21871 .75253 L .24979 .75025 L p .707 .577 .707 r
F P
0 g
s
.27809 .70901 m .28149 .74724 L .3107 .74381 L p .707 .577 .707 r
F P
0 g
s
.3107 .74381 m .30731 .70558 L .27809 .70901 L p .707 .577 .707 r
F P
0 g
s
.70856 .8308 m .70283 .84897 L .69095 .84113 L p .707 .577 .707 r
F P
0 g
s
.69095 .84113 m .69667 .82296 L .70856 .8308 L p .707 .577 .707 r
F P
0 g
s
.25642 .84305 m .25894 .82702 L .22797 .81992 L p .707 .577 .707 r
F P
0 g
s
.25894 .82702 m .25642 .84305 L .28795 .84481 L p .707 .577 .707 r
F P
0 g
s
.28795 .84481 m .29047 .82878 L .25894 .82702 L p .707 .577 .707 r
F P
0 g
s
.21871 .75253 m .21531 .7143 L .18789 .71563 L p .707 .577 .707 r
F P
0 g
s
.22545 .83595 m .22797 .81992 L .20058 .80816 L p .707 .577 .707 r
F P
0 g
s
.22797 .81992 m .22545 .83595 L .25642 .84305 L p .707 .577 .707 r
F P
0 g
s
.18789 .71563 m .19129 .75386 L .21871 .75253 L p .707 .577 .707 r
F P
0 g
s
.17914 .69864 m .17357 .64128 L .16097 .6411 L p .707 .577 .707 r
F P
0 g
s
.29047 .82878 m .28795 .84481 L .31695 .84106 L p .707 .577 .707 r
F P
0 g
s
.31695 .84106 m .31947 .82503 L .29047 .82878 L p .707 .577 .707 r
F P
0 g
s
.16097 .6411 m .16654 .69846 L .17914 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .70558 m .3107 .74381 L .33457 .74027 L p .707 .577 .707 r
F P
0 g
s
.33457 .74027 m .33118 .70205 L .30731 .70558 L p .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .79832 L .6437 .78657 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.20058 .80816 m .19806 .82419 L .22545 .83595 L p .707 .577 .707 r
F P
0 g
s
.19806 .82419 m .20058 .80816 L .17947 .79291 L p .707 .577 .707 r
F P
0 g
s
.19129 .75386 m .18789 .71563 L .16682 .71589 L p .707 .577 .707 r
F P
0 g
s
.31947 .82503 m .31695 .84106 L .34059 .83215 L p .707 .577 .707 r
F P
0 g
s
.34059 .83215 m .34311 .81612 L .31947 .82503 L p .707 .577 .707 r
F P
0 g
s
.16682 .71589 m .17022 .75412 L .19129 .75386 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35629 .27798 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35401 .623 m .35958 .68036 L .36581 .67844 L p .707 .577 .707 r
F P
0 g
s
.36567 .67426 m .35401 .623 L .36581 .67844 L .707 .577 .707 r
F
.36656 .6782 m .361 .62084 L .35401 .623 L p F P
0 g
s
.35805 .61961 m .361 .62084 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36361 .67698 m .36335 .67425 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36335 .67425 m .35805 .61961 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.34737 .69877 m .35076 .737 L .35769 .73429 L p .707 .577 .707 r
F P
0 g
s
.35769 .73429 m .35429 .69606 L .34737 .69877 L p .707 .577 .707 r
F P
0 g
s
.35429 .69606 m .35769 .73429 L .35467 .73242 L p .707 .577 .707 r
F P
0 g
s
.36257 .76919 m .36005 .78522 L .34727 .76796 L p .707 .577 .707 r
F P
0 g
s
.34727 .76796 m .34979 .75193 L .36257 .76919 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35947 .79195 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35805 .61961 m .36361 .67698 L .35102 .6768 L p .707 .577 .707 r
F P
0 g
s
.35102 .6768 m .34545 .61944 L .35805 .61961 L p .707 .577 .707 r
F P
0 g
s
.35629 .27798 m .35629 .70254 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35629 .70254 m .35629 .77987 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .49323 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35947 .49323 m .35947 .29006 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.36581 .67844 m .36656 .6782 L p .36567 .67426 L .707 .577 .707 r
F P
0 g
s
.17947 .79291 m .17695 .80894 L .19806 .82419 L p .707 .577 .707 r
F P
0 g
s
.69667 .82296 m .69095 .84113 L .67096 .83154 L p .707 .577 .707 r
F P
0 g
s
.67096 .83154 m .67668 .81336 L .69667 .82296 L p .707 .577 .707 r
F P
0 g
s
.33118 .70205 m .33457 .74027 L .35076 .737 L p .707 .577 .707 r
F P
0 g
s
.35076 .737 m .34737 .69877 L .33118 .70205 L p .707 .577 .707 r
F P
0 g
s
.17695 .80894 m .17947 .79291 L .16669 .77565 L p .707 .577 .707 r
F P
0 g
s
.16654 .69846 m .16097 .6411 L .15802 .63987 L p .707 .577 .707 r
F P
0 g
s
.361 .62084 m .36656 .6782 L .36361 .67698 L p .707 .577 .707 r
F P
0 g
s
.36324 .8028 m .36576 .78677 L .35906 .80294 L p .707 .577 .707 r
F P
0 g
s
.36576 .78677 m .36324 .8028 L .36005 .78522 L p .707 .577 .707 r
F P
0 g
s
.36005 .78522 m .36257 .76919 L .36576 .78677 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.15802 .63987 m .16359 .69724 L .16654 .69846 L p .707 .577 .707 r
F P
0 g
s
.34311 .81612 m .34059 .83215 L .35654 .81897 L p .707 .577 .707 r
F P
0 g
s
.35654 .81897 m .35906 .80294 L .34311 .81612 L p .707 .577 .707 r
F P
0 g
s
.17022 .75412 m .16682 .71589 L .15415 .71504 L p .707 .577 .707 r
F P
0 g
s
.16669 .77565 m .16417 .79168 L .17695 .80894 L p .707 .577 .707 r
F P
0 g
s
.15415 .71504 m .15755 .75327 L .17022 .75412 L p .707 .577 .707 r
F P
0 g
s
.67668 .81336 m .67096 .83154 L .64482 .82113 L p .707 .577 .707 r
F P
0 g
s
.64482 .82113 m .65054 .80296 L .67668 .81336 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .70924 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .62359 .76326 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .639 .56377 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63638 .62968 m .63665 .62728 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63665 .62728 m .64195 .57917 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .64053 .77449 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.6437 .70924 m .6437 .78657 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.16417 .79168 m .16669 .77565 L .1635 .75808 L p .707 .577 .707 r
F P
0 g
s
.35906 .80294 m .35654 .81897 L .36324 .8028 L p .707 .577 .707 r
F P
0 g
s
.65054 .80296 m .64482 .82113 L .61509 .81093 L p .707 .577 .707 r
F P
0 g
s
.16359 .69724 m .15802 .63987 L .16501 .63771 L p .707 .577 .707 r
F P
0 g
s
.1635 .75808 m .16098 .77411 L .16417 .79168 L p .707 .577 .707 r
F P
0 g
s
.16501 .63771 m .17057 .69508 L .16359 .69724 L p .707 .577 .707 r
F P
0 g
s
.15755 .75327 m .15415 .71504 L .15114 .71317 L p .707 .577 .707 r
F P
0 g
s
.15114 .71317 m .15453 .7514 L .15755 .75327 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35629 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16098 .77411 m .1635 .75808 L .17021 .74191 L p .707 .577 .707 r
F P
0 g
s
.35467 .73242 m .35128 .69419 L .35429 .69606 L p .707 .577 .707 r
F P
0 g
s
.17021 .74191 m .16769 .75794 L .16098 .77411 L p .707 .577 .707 r
F P
0 g
s
.17057 .69508 m .16501 .63771 L .18124 .63483 L p .707 .577 .707 r
F P
0 g
s
.62359 .76326 m .62359 .26137 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18124 .63483 m .18681 .6922 L .17057 .69508 L p .707 .577 .707 r
F P
0 g
s
.15453 .7514 m .15114 .71317 L .15806 .71046 L p .707 .577 .707 r
F P
0 g
s
.15806 .71046 m .16146 .74869 L .15453 .7514 L p .707 .577 .707 r
F P
0 g
s
.16769 .75794 m .17021 .74191 L .18616 .72872 L p .707 .577 .707 r
F P
0 g
s
.34545 .61944 m .35102 .6768 L .33001 .67769 L p .707 .577 .707 r
F P
0 g
s
.33001 .67769 m .32444 .62033 L .34545 .61944 L p .707 .577 .707 r
F P
0 g
s
.35128 .69419 m .35467 .73242 L .34201 .73157 L p .707 .577 .707 r
F P
0 g
s
.34201 .73157 m .33861 .69334 L .35128 .69419 L p .707 .577 .707 r
F P
0 g
s
.18616 .72872 m .18364 .74475 L .16769 .75794 L p .707 .577 .707 r
F P
0 g
s
.36718 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36718 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18681 .6922 m .18124 .63483 L .20514 .63152 L p .707 .577 .707 r
F P
0 g
s
.20514 .63152 m .21071 .68888 L .18681 .6922 L p .707 .577 .707 r
F P
0 g
s
.16146 .74869 m .15806 .71046 L .17425 .70718 L p .707 .577 .707 r
F P
0 g
s
.18364 .74475 m .18616 .72872 L .20979 .71982 L p .707 .577 .707 r
F P
0 g
s
.17425 .70718 m .17765 .74541 L .16146 .74869 L p .707 .577 .707 r
F P
0 g
s
.32444 .62033 m .33001 .67769 L .30265 .67957 L p .707 .577 .707 r
F P
0 g
s
.30265 .67957 m .29708 .6222 L .32444 .62033 L p .707 .577 .707 r
F P
0 g
s
.34979 .75193 m .34727 .76796 L .32616 .75271 L p .707 .577 .707 r
F P
0 g
s
.32616 .75271 m .32868 .73668 L .34979 .75193 L p .707 .577 .707 r
F P
0 g
s
.62359 .26137 m .62359 .76326 L .59456 .75399 L p .707 .577 .707 r
F P
0 g
s
.59456 .75399 m .59456 .2521 L .62359 .26137 L p .707 .577 .707 r
F P
0 g
s
.20979 .71982 m .20727 .73585 L .18364 .74475 L p .707 .577 .707 r
F P
0 g
s
.21071 .68888 m .20514 .63152 L .23436 .62808 L p .707 .577 .707 r
F P
0 g
s
.23436 .62808 m .23992 .68545 L .21071 .68888 L p .707 .577 .707 r
F P
0 g
s
.33861 .69334 m .34201 .73157 L .32093 .73182 L p .707 .577 .707 r
F P
0 g
s
.32093 .73182 m .31754 .6936 L .33861 .69334 L p .707 .577 .707 r
F P
0 g
s
.29708 .6222 m .30265 .67957 L .27161 .68224 L p .707 .577 .707 r
F P
0 g
s
.27161 .68224 m .26604 .62488 L .29708 .6222 L p .707 .577 .707 r
F P
0 g
s
.20727 .73585 m .20979 .71982 L .23879 .71606 L p .707 .577 .707 r
F P
0 g
s
.32868 .73668 m .32616 .75271 L .29877 .74095 L p .707 .577 .707 r
F P
0 g
s
.29877 .74095 m .30129 .72492 L .32868 .73668 L p .707 .577 .707 r
F P
0 g
s
.23992 .68545 m .23436 .62808 L .26604 .62488 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36718 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42563 .24816 L p .707 .577 .707 r
F P
0 g
s
.26604 .62488 m .27161 .68224 L .23992 .68545 L p .707 .577 .707 r
F P
0 g
s
.17765 .74541 m .17425 .70718 L .19812 .70365 L p .707 .577 .707 r
F P
0 g
s
.19812 .70365 m .20152 .74188 L .17765 .74541 L p .707 .577 .707 r
F P
0 g
s
.23879 .71606 m .23627 .73209 L .20727 .73585 L p .707 .577 .707 r
F P
0 g
s
.72839 .67401 m .73396 .6235 L .70292 .61751 L p .707 .577 .707 r
F P
0 g
s
.73396 .6235 m .72839 .67401 L .76007 .6753 L p .707 .577 .707 r
F P
0 g
s
.76007 .6753 m .76564 .62479 L .73396 .6235 L p .707 .577 .707 r
F P
0 g
s
.23627 .73209 m .23879 .71606 L .27032 .71782 L p .707 .577 .707 r
F P
0 g
s
.30129 .72492 m .29877 .74095 L .2678 .73385 L p .707 .577 .707 r
F P
0 g
s
.2678 .73385 m .27032 .71782 L .30129 .72492 L p .707 .577 .707 r
F P
0 g
s
.76564 .62479 m .76007 .6753 L .78929 .67178 L p .707 .577 .707 r
F P
0 g
s
.78929 .67178 m .79486 .62126 L .76564 .62479 L p .707 .577 .707 r
F P
0 g
s
.69735 .66803 m .70292 .61751 L .67555 .60742 L p .707 .577 .707 r
F P
0 g
s
.70292 .61751 m .69735 .66803 L .72839 .67401 L p .707 .577 .707 r
F P
0 g
s
.73756 .73864 m .74096 .70458 L .70988 .69895 L p .707 .577 .707 r
F P
0 g
s
.74096 .70458 m .73756 .73864 L .76926 .73974 L p .707 .577 .707 r
F P
0 g
s
.76926 .73974 m .77266 .70569 L .74096 .70458 L p .707 .577 .707 r
F P
0 g
s
.27032 .71782 m .2678 .73385 L .23627 .73209 L p .707 .577 .707 r
F P
0 g
s
.59456 .2521 m .59456 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59456 .2521 L p .707 .577 .707 r
F P
0 g
s
.31754 .6936 m .32093 .73182 L .29351 .73316 L p .707 .577 .707 r
F P
0 g
s
.29351 .73316 m .29012 .69493 L .31754 .6936 L p .707 .577 .707 r
F P
0 g
s
.77266 .70569 m .76926 .73974 L .79848 .73622 L p .707 .577 .707 r
F P
0 g
s
.79848 .73622 m .80187 .70216 L .77266 .70569 L p .707 .577 .707 r
F P
0 g
s
.70648 .733 m .70988 .69895 L .68246 .68934 L p .707 .577 .707 r
F P
0 g
s
.70988 .69895 m .70648 .733 L .73756 .73864 L p .707 .577 .707 r
F P
0 g
s
.79486 .62126 m .78929 .67178 L .81319 .66377 L p .707 .577 .707 r
F P
0 g
s
.81319 .66377 m .81876 .61326 L .79486 .62126 L p .707 .577 .707 r
F P
0 g
s
.20152 .74188 m .19812 .70365 L .22734 .70022 L p .707 .577 .707 r
F P
0 g
s
.66999 .65793 m .67555 .60742 L .65455 .59421 L p .707 .577 .707 r
F P
0 g
s
.67555 .60742 m .66999 .65793 L .69735 .66803 L p .707 .577 .707 r
F P
0 g
s
.22734 .70022 m .23073 .73844 L .20152 .74188 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42563 .24816 L .46746 .24362 L p .707 .577 .707 r
F P
0 g
s
.42563 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.80187 .70216 m .79848 .73622 L .82235 .7284 L p .707 .577 .707 r
F P
0 g
s
.82235 .7284 m .82575 .69435 L .80187 .70216 L p .707 .577 .707 r
F P
0 g
s
.67907 .72339 m .68246 .68934 L .66139 .67669 L p .707 .577 .707 r
F P
0 g
s
.68246 .68934 m .67907 .72339 L .70648 .733 L p .707 .577 .707 r
F P
0 g
s
.29012 .69493 m .29351 .73316 L .26243 .73544 L p .707 .577 .707 r
F P
0 g
s
.26243 .73544 m .25904 .69721 L .29012 .69493 L p .707 .577 .707 r
F P
0 g
s
.23073 .73844 m .22734 .70022 L .25904 .69721 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51248 .74466 L p .707 .577 .707 r
F P
0 g
s
.51248 .74466 m .51248 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.25904 .69721 m .26243 .73544 L .23073 .73844 L p .707 .577 .707 r
F P
0 g
s
.81876 .61326 m .81319 .66377 L .82942 .65208 L p .707 .577 .707 r
F P
0 g
s
.82942 .65208 m .83499 .60156 L .81876 .61326 L p .707 .577 .707 r
F P
0 g
s
.46746 .74551 m .46746 .24362 L .51248 .24277 L p .707 .577 .707 r
F P
0 g
s
.46746 .24362 m .46746 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.6987 .71342 m .70122 .73248 L .7322 .7282 L p .707 .577 .707 r
F P
0 g
s
.7322 .7282 m .72968 .70914 L .6987 .71342 L p .707 .577 .707 r
F P
0 g
s
.72968 .70914 m .7322 .7282 L .76373 .72412 L p .707 .577 .707 r
F P
0 g
s
.64898 .64472 m .65455 .59421 L .64195 .57917 L p .707 .577 .707 r
F P
0 g
s
.65455 .59421 m .64898 .64472 L .66999 .65793 L p .707 .577 .707 r
F P
0 g
s
.76373 .72412 m .76121 .70506 L .72968 .70914 L p .707 .577 .707 r
F P
0 g
s
.51248 .24277 m .51248 .74466 L .46746 .74551 L p .707 .577 .707 r
F P
0 g
s
.76121 .70506 m .76373 .72412 L .79273 .72066 L p .707 .577 .707 r
F P
0 g
s
.79273 .72066 m .79021 .70161 L .76121 .70506 L p .707 .577 .707 r
F P
0 g
s
.66139 .67669 m .65799 .71075 L .67907 .72339 L p .707 .577 .707 r
F P
0 g
s
.82575 .69435 m .82235 .7284 L .83854 .71706 L p .707 .577 .707 r
F P
0 g
s
.83854 .71706 m .84194 .68301 L .82575 .69435 L p .707 .577 .707 r
F P
0 g
s
.67132 .71751 m .67384 .73656 L .70122 .73248 L p .707 .577 .707 r
F P
0 g
s
.70122 .73248 m .6987 .71342 L .67132 .71751 L p .707 .577 .707 r
F P
0 g
s
.65799 .71075 m .66139 .67669 L .64872 .66225 L p .707 .577 .707 r
F P
0 g
s
.79021 .70161 m .79273 .72066 L .81636 .71816 L p .707 .577 .707 r
F P
0 g
s
.81636 .71816 m .81384 .6991 L .79021 .70161 L p .707 .577 .707 r
F P
0 g
s
.6502 .72098 m .65272 .74004 L .67384 .73656 L p .707 .577 .707 r
F P
0 g
s
.67384 .73656 m .67132 .71751 L .6502 .72098 L p .707 .577 .707 r
F P
0 g
s
.83499 .60156 m .82942 .65208 L .83641 .63784 L p .707 .577 .707 r
F P
0 g
s
.83641 .63784 m .84198 .58732 L .83499 .60156 L p .707 .577 .707 r
F P
0 g
s
.64872 .66225 m .64533 .69631 L .65799 .71075 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .63638 .62968 L .64898 .64472 L p .707 .577 .707 r
F P
0 g
s
.84194 .68301 m .83854 .71706 L .84547 .7033 L p .707 .577 .707 r
F P
0 g
s
.84547 .7033 m .84886 .66925 L .84194 .68301 L p .707 .577 .707 r
F P
0 g
s
.64533 .69631 m .64872 .66225 L .6457 .64743 L p .707 .577 .707 r
F P
0 g
s
.81384 .6991 m .81636 .71816 L .83231 .71685 L p .707 .577 .707 r
F P
0 g
s
.83231 .71685 m .82979 .69779 L .81384 .6991 L p .707 .577 .707 r
F P
0 g
s
.63743 .72351 m .63995 .74257 L .65272 .74004 L p .707 .577 .707 r
F P
0 g
s
.65272 .74004 m .6502 .72098 L .63743 .72351 L p .707 .577 .707 r
F P
0 g
s
.6457 .64743 m .64231 .68148 L .64533 .69631 L p .707 .577 .707 r
F P
0 g
s
.84198 .58732 m .83641 .63784 L .83346 .62245 L p .707 .577 .707 r
F P
0 g
s
.83346 .62245 m .83903 .57193 L .84198 .58732 L p .707 .577 .707 r
F P
0 g
s
.639 .56377 m .63343 .61429 L .63638 .62968 L p .707 .577 .707 r
F P
0 g
s
.63343 .61429 m .639 .56377 L .64599 .54953 L p .707 .577 .707 r
F P
0 g
s
.84886 .66925 m .84547 .7033 L .84245 .68848 L p .707 .577 .707 r
F P
0 g
s
.84245 .68848 m .84584 .65443 L .84886 .66925 L p .707 .577 .707 r
F P
0 g
s
.64231 .68148 m .6457 .64743 L .65263 .63368 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.82979 .69779 m .83231 .71685 L .83902 .71686 L p .707 .577 .707 r
F P
0 g
s
.83902 .71686 m .8365 .6978 L .82979 .69779 L p .707 .577 .707 r
F P
0 g
s
.63423 .72485 m .63675 .74391 L .63995 .74257 L p .707 .577 .707 r
F P
0 g
s
.63995 .74257 m .63743 .72351 L .63423 .72485 L p .707 .577 .707 r
F P
0 g
s
.65263 .63368 m .64923 .66773 L .64231 .68148 L p .707 .577 .707 r
F P
0 g
s
.83903 .57193 m .83346 .62245 L .82086 .60741 L p .707 .577 .707 r
F P
0 g
s
.82086 .60741 m .82643 .55689 L .83903 .57193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64599 .54953 m .64042 .60005 L .63343 .61429 L p .707 .577 .707 r
F P
0 g
s
.64042 .60005 m .64599 .54953 L .66222 .53784 L p .707 .577 .707 r
F P
0 g
s
.37786 .61007 m .39068 .55468 L .36033 .5466 L p .707 .577 .707 r
F P
0 g
s
.39068 .55468 m .37786 .61007 L .40892 .61656 L p .707 .577 .707 r
F P
0 g
s
.40892 .61656 m .42174 .56118 L .39068 .55468 L p .707 .577 .707 r
F P
0 g
s
.84584 .65443 m .84245 .68848 L .82978 .67404 L p .707 .577 .707 r
F P
0 g
s
.82978 .67404 m .83318 .63999 L .84584 .65443 L p .707 .577 .707 r
F P
0 g
s
.64923 .66773 m .65263 .63368 L .66882 .62233 L p .707 .577 .707 r
F P
0 g
s
.42174 .56118 m .40892 .61656 L .43764 .62083 L p .707 .577 .707 r
F P
0 g
s
.43764 .62083 m .45046 .56545 L .42174 .56118 L p .707 .577 .707 r
F P
0 g
s
.34751 .60198 m .36033 .5466 L .33366 .53772 L p .707 .577 .707 r
F P
0 g
s
.36033 .5466 m .34751 .60198 L .37786 .61007 L p .707 .577 .707 r
F P
0 g
s
.8365 .6978 m .83902 .71686 L .83583 .7182 L p .707 .577 .707 r
F P
0 g
s
.83583 .7182 m .83331 .69914 L .8365 .6978 L p .707 .577 .707 r
F P
0 g
s
.33366 .53772 m .32084 .5931 L .34751 .60198 L p .707 .577 .707 r
F P
0 g
s
.45046 .56545 m .43764 .62083 L .46122 .62246 L p .707 .577 .707 r
F P
0 g
s
.46122 .62246 m .47404 .56707 L .45046 .56545 L p .707 .577 .707 r
F P
0 g
s
.82643 .55689 m .82086 .60741 L .79985 .5942 L p .707 .577 .707 r
F P
0 g
s
.79985 .5942 m .80542 .54368 L .82643 .55689 L p .707 .577 .707 r
F P
0 g
s
.66882 .62233 m .66543 .65639 L .64923 .66773 L p .707 .577 .707 r
F P
0 g
s
.32084 .5931 m .33366 .53772 L .31328 .52891 L p .707 .577 .707 r
F P
0 g
s
.66222 .53784 m .65665 .58836 L .64042 .60005 L p .707 .577 .707 r
F P
0 g
s
.65665 .58836 m .66222 .53784 L .68612 .52984 L p .707 .577 .707 r
F P
0 g
s
.64094 .72487 m .64346 .74393 L .63675 .74391 L p .707 .577 .707 r
F P
0 g
s
.63675 .74391 m .63423 .72485 L .64094 .72487 L p .707 .577 .707 r
F P
0 g
s
.83318 .63999 m .82978 .67404 L .80871 .6614 L p .707 .577 .707 r
F P
0 g
s
.80871 .6614 m .8121 .62734 L .83318 .63999 L p .707 .577 .707 r
F P
0 g
s
.39907 .66939 m .40689 .63237 L .37639 .62482 L p .707 .577 .707 r
F P
0 g
s
.40689 .63237 m .39907 .66939 L .43024 .67525 L p .707 .577 .707 r
F P
0 g
s
.43024 .67525 m .43807 .63822 L .40689 .63237 L p .707 .577 .707 r
F P
0 g
s
.66543 .65639 m .66882 .62233 L .69269 .61452 L p .707 .577 .707 r
F P
0 g
s
.31328 .52891 m .30046 .58429 L .32084 .5931 L p .707 .577 .707 r
F P
0 g
s
.43807 .63822 m .43024 .67525 L .45904 .67885 L p .707 .577 .707 r
F P
0 g
s
.45904 .67885 m .46687 .64182 L .43807 .63822 L p .707 .577 .707 r
F P
0 g
s
.36856 .66185 m .37639 .62482 L .34955 .61633 L p .707 .577 .707 r
F P
0 g
s
.37639 .62482 m .36856 .66185 L .39907 .66939 L p .707 .577 .707 r
F P
0 g
s
.47404 .56707 m .46122 .62246 L .47735 .62128 L p .707 .577 .707 r
F P
0 g
s
.47735 .62128 m .49017 .5659 L .47404 .56707 L p .707 .577 .707 r
F P
0 g
s
.80542 .54368 m .79985 .5942 L .77249 .5841 L p .707 .577 .707 r
F P
0 g
s
.77249 .5841 m .77806 .53359 L .80542 .54368 L p .707 .577 .707 r
F P
0 g
s
.41531 .72759 m .40958 .71069 L .37918 .72049 L p .707 .577 .707 r
F P
0 g
s
.40958 .71069 m .41531 .72759 L .44342 .71466 L p .707 .577 .707 r
F P
0 g
s
.44342 .71466 m .43769 .69776 L .40958 .71069 L p .707 .577 .707 r
F P
0 g
s
.68055 .58035 m .68612 .52984 L .71534 .52631 L p .707 .577 .707 r
F P
0 g
s
.68612 .52984 m .68055 .58035 L .65665 .58836 L p .707 .577 .707 r
F P
0 g
s
.34955 .61633 m .34172 .65336 L .36856 .66185 L p .707 .577 .707 r
F P
0 g
s
.38491 .73739 m .37918 .72049 L .34945 .7262 L p .707 .577 .707 r
F P
0 g
s
.37918 .72049 m .38491 .73739 L .41531 .72759 L p .707 .577 .707 r
F P
0 g
s
.83331 .69914 m .83583 .7182 L .82305 .72073 L p .707 .577 .707 r
F P
0 g
s
.82305 .72073 m .82053 .70167 L .83331 .69914 L p .707 .577 .707 r
F P
0 g
s
.30046 .58429 m .31328 .52891 L .30118 .52103 L p .707 .577 .707 r
F P
0 g
s
.46687 .64182 m .45904 .67885 L .48265 .67983 L p .707 .577 .707 r
F P
0 g
s
.48265 .67983 m .49048 .64281 L .46687 .64182 L p .707 .577 .707 r
F P
0 g
s
.69269 .61452 m .6893 .64857 L .66543 .65639 L p .707 .577 .707 r
F P
0 g
s
.8121 .62734 m .80871 .6614 L .78129 .65179 L p .707 .577 .707 r
F P
0 g
s
.78129 .65179 m .78469 .61773 L .8121 .62734 L p .707 .577 .707 r
F P
0 g
s
.6893 .64857 m .69269 .61452 L .72191 .61099 L p .707 .577 .707 r
F P
0 g
s
.43769 .69776 m .44342 .71466 L .46648 .69986 L p .707 .577 .707 r
F P
0 g
s
.46648 .69986 m .46075 .68296 L .43769 .69776 L p .707 .577 .707 r
F P
0 g
s
.34945 .7262 m .35518 .7431 L .38491 .73739 L p .707 .577 .707 r
F P
0 g
s
.34172 .65336 m .34955 .61633 L .329 .60772 L p .707 .577 .707 r
F P
0 g
s
.35518 .7431 m .34945 .7262 L .32332 .72726 L p .707 .577 .707 r
F P
0 g
s
.77806 .53359 m .77249 .5841 L .74145 .57812 L p .707 .577 .707 r
F P
0 g
s
.74145 .57812 m .74702 .5276 L .77806 .53359 L p .707 .577 .707 r
F P
0 g
s
.70977 .57683 m .71534 .52631 L .74702 .5276 L p .707 .577 .707 r
F P
0 g
s
.71534 .52631 m .70977 .57683 L .68055 .58035 L p .707 .577 .707 r
F P
0 g
s
.65689 .72356 m .65941 .74262 L .64346 .74393 L p .707 .577 .707 r
F P
0 g
s
.64346 .74393 m .64094 .72487 L .65689 .72356 L p .707 .577 .707 r
F P
0 g
s
.30118 .52103 m .28836 .57642 L .30046 .58429 L p .707 .577 .707 r
F P
0 g
s
.329 .60772 m .32117 .64475 L .34172 .65336 L p .707 .577 .707 r
F P
0 g
s
.74702 .5276 m .74145 .57812 L .70977 .57683 L p .707 .577 .707 r
F P
0 g
s
.32332 .72726 m .32904 .74416 L .35518 .7431 L p .707 .577 .707 r
F P
0 g
s
.78469 .61773 m .78129 .65179 L .75021 .64615 L p .707 .577 .707 r
F P
0 g
s
.75021 .64615 m .75361 .6121 L .78469 .61773 L p .707 .577 .707 r
F P
0 g
s
.71851 .64504 m .72191 .61099 L .75361 .6121 L p .707 .577 .707 r
F P
0 g
s
.72191 .61099 m .71851 .64504 L .6893 .64857 L p .707 .577 .707 r
F P
0 g
s
.75361 .6121 m .75021 .64615 L .71851 .64504 L p .707 .577 .707 r
F P
0 g
s
.46075 .68296 m .46648 .69986 L .48223 .68465 L p .707 .577 .707 r
F P
0 g
s
.48223 .68465 m .4765 .66775 L .46075 .68296 L p .707 .577 .707 r
F P
0 g
s
.49017 .5659 m .47735 .62128 L .48444 .61742 L p .707 .577 .707 r
F P
0 g
s
.48444 .61742 m .49726 .56203 L .49017 .5659 L p .707 .577 .707 r
F P
0 g
s
.49048 .64281 m .48265 .67983 L .49875 .67811 L p .707 .577 .707 r
F P
0 g
s
.49875 .67811 m .50658 .64108 L .49048 .64281 L p .707 .577 .707 r
F P
0 g
s
.32904 .74416 m .32332 .72726 L .30333 .72357 L p .707 .577 .707 r
F P
0 g
s
.82053 .70167 m .82305 .72073 L .80193 .72421 L p .707 .577 .707 r
F P
0 g
s
.32117 .64475 m .329 .60772 L .31675 .59984 L p .707 .577 .707 r
F P
0 g
s
.28836 .57642 m .30118 .52103 L .29854 .51486 L p .707 .577 .707 r
F P
0 g
s
.80193 .72421 m .79941 .70515 L .82053 .70167 L p .707 .577 .707 r
F P
0 g
s
.30333 .72357 m .30905 .74047 L .32904 .74416 L p .707 .577 .707 r
F P
0 g
s
.31675 .59984 m .30892 .63687 L .32117 .64475 L p .707 .577 .707 r
F P
0 g
s
.68052 .72105 m .68304 .74011 L .65941 .74262 L p .707 .577 .707 r
F P
0 g
s
.65941 .74262 m .65689 .72356 L .68052 .72105 L p .707 .577 .707 r
F P
0 g
s
.29854 .51486 m .28572 .57024 L .28836 .57642 L p .707 .577 .707 r
F P
0 g
s
.4765 .66775 m .48223 .68465 L .48914 .67051 L p .707 .577 .707 r
F P
0 g
s
.48914 .67051 m .48341 .65361 L .4765 .66775 L p .707 .577 .707 r
F P
0 g
s
.30905 .74047 m .30333 .72357 L .29144 .71548 L p .707 .577 .707 r
F P
0 g
s
.50658 .64108 m .49875 .67811 L .50577 .67385 L p .707 .577 .707 r
F P
0 g
s
.50577 .67385 m .51359 .63682 L .50658 .64108 L p .707 .577 .707 r
F P
0 g
s
.79941 .70515 m .80193 .72421 L .77455 .72829 L p .707 .577 .707 r
F P
0 g
s
.77455 .72829 m .77203 .70923 L .79941 .70515 L p .707 .577 .707 r
F P
0 g
s
.49726 .56203 m .48444 .61742 L .48181 .61125 L p .707 .577 .707 r
F P
0 g
s
.48181 .61125 m .49463 .55586 L .49726 .56203 L p .707 .577 .707 r
F P
0 g
s
.30892 .63687 m .31675 .59984 L .314 .59346 L p .707 .577 .707 r
F P
0 g
s
.29144 .71548 m .29717 .73239 L .30905 .74047 L p .707 .577 .707 r
F P
0 g
s
.70953 .71759 m .71205 .73665 L .68304 .74011 L p .707 .577 .707 r
F P
0 g
s
.68304 .74011 m .68052 .72105 L .70953 .71759 L p .707 .577 .707 r
F P
0 g
s
.28572 .57024 m .29854 .51486 L .30564 .511 L p .707 .577 .707 r
F P
0 g
s
.314 .59346 m .30617 .63048 L .30892 .63687 L p .707 .577 .707 r
F P
0 g
s
.77203 .70923 m .77455 .72829 L .74358 .73258 L p .707 .577 .707 r
F P
0 g
s
.74358 .73258 m .74106 .71352 L .77203 .70923 L p .707 .577 .707 r
F P
0 g
s
.30564 .511 m .29282 .56638 L .28572 .57024 L p .707 .577 .707 r
F P
0 g
s
.74106 .71352 m .74358 .73258 L .71205 .73665 L p .707 .577 .707 r
F P
0 g
s
.71205 .73665 m .70953 .71759 L .74106 .71352 L p .707 .577 .707 r
F P
0 g
s
.48341 .65361 m .48914 .67051 L .48652 .65882 L p .707 .577 .707 r
F P
0 g
s
.48652 .65882 m .48079 .64192 L .48341 .65361 L p .707 .577 .707 r
F P
0 g
s
.29717 .73239 m .29144 .71548 L .28882 .7038 L p .707 .577 .707 r
F P
0 g
s
.51359 .63682 m .50577 .67385 L .50301 .66746 L p .707 .577 .707 r
F P
0 g
s
.50301 .66746 m .51084 .63043 L .51359 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49463 .55586 m .48181 .61125 L .46971 .60337 L p .707 .577 .707 r
F P
0 g
s
.46971 .60337 m .48253 .54799 L .49463 .55586 L p .707 .577 .707 r
F P
0 g
s
.28882 .7038 m .29455 .7207 L .29717 .73239 L p .707 .577 .707 r
F P
0 g
s
.30617 .63048 m .314 .59346 L .32101 .58919 L p .707 .577 .707 r
F P
0 g
s
.29282 .56638 m .30564 .511 L .32176 .50982 L p .707 .577 .707 r
F P
0 g
s
.32101 .58919 m .31319 .62622 L .30617 .63048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32176 .50982 m .30894 .56521 L .29282 .56638 L p .707 .577 .707 r
F P
0 g
s
.48079 .64192 m .48652 .65882 L .47463 .65074 L p .707 .577 .707 r
F P
0 g
s
.47463 .65074 m .4689 .63384 L .48079 .64192 L p .707 .577 .707 r
F P
0 g
s
.29455 .7207 m .28882 .7038 L .29573 .68966 L p .707 .577 .707 r
F P
0 g
s
.48253 .54799 m .46971 .60337 L .44932 .59456 L p .707 .577 .707 r
F P
0 g
s
.44932 .59456 m .46214 .53918 L .48253 .54799 L p .707 .577 .707 r
F P
0 g
s
.51084 .63043 m .50301 .66746 L .49076 .65958 L p .707 .577 .707 r
F P
0 g
s
.49076 .65958 m .49859 .62255 L .51084 .63043 L p .707 .577 .707 r
F P
0 g
s
.29573 .68966 m .30145 .70656 L .29455 .7207 L p .707 .577 .707 r
F P
0 g
s
.30894 .56521 m .32176 .50982 L .34534 .51145 L p .707 .577 .707 r
F P
0 g
s
.31319 .62622 m .32101 .58919 L .33711 .58747 L p .707 .577 .707 r
F P
0 g
s
.33711 .58747 m .32929 .6245 L .31319 .62622 L p .707 .577 .707 r
F P
0 g
s
.34534 .51145 m .33252 .56683 L .30894 .56521 L p .707 .577 .707 r
F P
0 g
s
.4689 .63384 m .47463 .65074 L .45464 .64705 L p .707 .577 .707 r
F P
0 g
s
.45464 .64705 m .44891 .63014 L .4689 .63384 L p .707 .577 .707 r
F P
0 g
s
.46214 .53918 m .44932 .59456 L .42265 .58568 L p .707 .577 .707 r
F P
0 g
s
.42265 .58568 m .43547 .53029 L .46214 .53918 L p .707 .577 .707 r
F P
0 g
s
.30145 .70656 m .29573 .68966 L .31148 .67444 L p .707 .577 .707 r
F P
0 g
s
.33252 .56683 m .34534 .51145 L .37406 .51572 L p .707 .577 .707 r
F P
0 g
s
.49859 .62255 m .49076 .65958 L .47021 .65097 L p .707 .577 .707 r
F P
0 g
s
.47021 .65097 m .47804 .61394 L .49859 .62255 L p .707 .577 .707 r
F P
0 g
s
.31148 .67444 m .31721 .69135 L .30145 .70656 L p .707 .577 .707 r
F P
0 g
s
.32929 .6245 m .33711 .58747 L .36072 .58845 L p .707 .577 .707 r
F P
0 g
s
.37406 .51572 m .36125 .5711 L .33252 .56683 L p .707 .577 .707 r
F P
0 g
s
.43547 .53029 m .42265 .58568 L .3923 .5776 L p .707 .577 .707 r
F P
0 g
s
.3923 .5776 m .40512 .52221 L .43547 .53029 L p .707 .577 .707 r
F P
0 g
s
.36125 .5711 m .37406 .51572 L .40512 .52221 L p .707 .577 .707 r
F P
0 g
s
.36072 .58845 m .35289 .62548 L .32929 .6245 L p .707 .577 .707 r
F P
0 g
s
.44891 .63014 m .45464 .64705 L .4285 .64811 L p .707 .577 .707 r
F P
0 g
s
.4285 .64811 m .42278 .6312 L .44891 .63014 L p .707 .577 .707 r
F P
0 g
s
.40512 .52221 m .3923 .5776 L .36125 .5711 L p .707 .577 .707 r
F P
0 g
s
.31721 .69135 m .31148 .67444 L .33454 .65965 L p .707 .577 .707 r
F P
0 g
s
.47804 .61394 m .47021 .65097 L .44337 .64248 L p .707 .577 .707 r
F P
0 g
s
.44337 .64248 m .4512 .60545 L .47804 .61394 L p .707 .577 .707 r
F P
0 g
s
.33454 .65965 m .34026 .67655 L .31721 .69135 L p .707 .577 .707 r
F P
0 g
s
.35289 .62548 m .36072 .58845 L .38952 .59205 L p .707 .577 .707 r
F P
0 g
s
.42278 .6312 m .4285 .64811 L .39878 .65382 L p .707 .577 .707 r
F P
0 g
s
.39878 .65382 m .39305 .63691 L .42278 .6312 L p .707 .577 .707 r
F P
0 g
s
.38952 .59205 m .38169 .62908 L .35289 .62548 L p .707 .577 .707 r
F P
0 g
s
.34026 .67655 m .33454 .65965 L .36265 .64671 L p .707 .577 .707 r
F P
0 g
s
.4512 .60545 m .44337 .64248 L .41287 .63493 L p .707 .577 .707 r
F P
0 g
s
.41287 .63493 m .4207 .59791 L .4512 .60545 L p .707 .577 .707 r
F P
0 g
s
.38169 .62908 m .38952 .59205 L .4207 .59791 L p .707 .577 .707 r
F P
0 g
s
.39305 .63691 m .39878 .65382 L .36837 .66362 L p .707 .577 .707 r
F P
0 g
s
.36837 .66362 m .36265 .64671 L .39305 .63691 L p .707 .577 .707 r
F P
0 g
s
.36265 .64671 m .36837 .66362 L .34026 .67655 L p .707 .577 .707 r
F P
0 g
s
.4207 .59791 m .41287 .63493 L .38169 .62908 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Iooa00009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00E7oo0`0015YF00<005YFFUH015YF00@005YFFUIJEPL0
009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00moo`P004eoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool02Goo1P000eYF00<005YFFUH00UYF2@00A7oo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01Goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol00goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003aoo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol00Woo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH01UYF00@005YFFUIJEP8003Yoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF
0P00>7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool00003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF000eOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00<goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<007ooOol0<7oo001BOol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000aOol0055oo`03001JEP00009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0000`Ool0055oo`03001JEP0000<000AJEPL000AJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000_Ool0055oo`8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP05001J
EUYFFUH0000^Ool0055oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPl000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool005=oo`<0
00IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF1P003goo10000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Goo001EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000<001Uoo`@000IJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001GOol300000eYF0000000=0002FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH2000QOol40002FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00FGoo0`000eYF00<005YFFUH015YF00@005YFFUIJ
EPL000AJEP03001JEUYF00AJEP800003FUH005YF00EJEP06001JEUYF001JEP001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0002FUH2000VOol30005FUH01`00
FUIJEUYF001JEP0002eoo`00FGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01@0025YF0`0015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYF001JEP03000015YF0000000057oo0`0047oo0P000eYF00L005YFFUIJ
EP00FUH0000]Ool005Uoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00=JEP04001JEUYFFUH300000eYF001JEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP04001JEUYF000BOol5000AOol01000FUIJEP000eYF
00<005YF0000;Goo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040006FUH20003FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF0P0047oo1@004Woo0`000eYF0P00;Woo001H
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40002FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH2000>Ool5000DOol01000FUIJEUYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01000FUH000001Goo2`005Goo0P000UYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP060004FUH00`00FUIJEP02FUH9000<
Ool200001UYF001JEP00FUH002ioo`00F7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000Woo100000AJEP00FUIJEP800003FUH007oo02eo
o`00D7oo200000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH00`00FUIJEP0200000eYF001oo`0]Ool004Mo
o`T000AJEP06001JEUYF001JEP000UYF300015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00L005YFFUIJEP00FUH0000^Ool003moo`P000AJEP03001JEUYF
00IJEP05001JEUYF001JEP040005FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEP0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH5
0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P000eYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P00;goo000aOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00UYF2P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0002FUH2000_Ool002aoo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000IJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH015YF1@0000=JEP00
FUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo02ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF
0P000eYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF009JEQ0000IJEP03001J
EUYF00AJEP03001JEUYF00AJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH00UYF0`00
25YF00<005YFFUH00eYF3P0000=JEP00FUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF1P001eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF0000;Woo000/Ool00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH60005FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YF
00000P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF0P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00D005YFFUIJEP0002aoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00008000EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP@000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<0009JEP800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP06001JEP00001JEP001EYF00<005YFFUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30008FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF
10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP03001oogoo02Yoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF0`00
0UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF0080
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000006
FUH01000FUIJEUYF1@001UYF00<005YF00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@000=J
EP03001JEUYF009JEP8002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P001EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEP0000800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP03
001JEUYF00D0009JEPH000=JEP03001JEUYF00EJEP04001JEP000004Ool200000eYF001JEP03FUH2
000[Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000MJEP06001JEP00001JEP000UYF00<005YFFUH015YF00<005YFFUH0
0UYF10000UYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP00009JEP05001JEP00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF00000eYF00@007ooOomoo`P000=JEP03001JEUYF009JEPD000Qoo`8000=JEP03001JEP0002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001eYF1P000UYF00<005YFFUH015YF00<005YFFUH01UYF1P0015YF00<005YF00000eYF
00@005YF001JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEPP000=JEP04001JEUYF0006Ool=000?Ool01P00FUIJEP00FUH002]oo`00
;Goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@000UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP80009JEP03001JEUYF00AJEP<000IJEP03
001JEUYF00=JEPH000EJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP<000=JEP06001JEP00001JEP000UYF00<007ooOol01Goo0`006Goo00D0
05YF001JEP0002]oo`00;Woo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF4`00
0eYF00@005YFFUH000=JEPL00005Ool005YFFUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP000UYF00@005YFFUIJEP80009JEP8002=oo`800003FUH007oo02Yo
o`00;Woo0UYF00<005YFFUH00UYF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04001JEUYF0004
FUH40007Ool01000FUIJEP001EYF1@001EYF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUIJ
EP<000EJEP800003FUH007oo025oo`@002aoo`00;Woo0UYF00<005YFFUH01P001eYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`001EYF00<007ooOol027oo00@005YFFUH000EJEPD000EJEP03001JEUYF
00AJEP05001JEUYFFUH00003FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF0P0015YF00@005YF0000021oo`80009J
EP8002aoo`00;Woo0UYF0`001EYF00<005YFFUH00UYF600015YF3@000UYF00<005YFFUH015YF0`00
1UYF00<005YFFUH00UYF0P0015YF00@005YFFUH000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUH000040002FUH00`00Oomo
o`0LOol20004FUH2000/Ool002ioo`l000Qoo`T000AJEP<0009JEP800003FUH005YF00AJEP03001J
EUYF00<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP05001JEUYFFUH00007FUH2000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF
00<005YFFUH00eYF1@0067oo2P0000=JEP000000;7oo000mOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUH000020007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH010003Goo1`00
0eYF100000IJEP00000005YF000/Ool003Eoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH=0003FUH70002
FUH00`00FUIJEP04000]Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00AJEP03001J
EUYF00AJEP8000EJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUH000080003
FUH90003FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00;Goo000ZOol50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH30003FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP03FUH01000FUIJEUYF1P0015YF200015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH00eYF10000UYF00<005YFFUH01UYF0P001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0009JEP8000=JEP@00003FUH005YF
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEP0000<000MJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0002FUH50005FUH60006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF1`00;goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06
00000eYF001JEP08FUH00`00FUIJEP030009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF1@000UYF00@005YF0000031oo`00:Woo00<005YF000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEPd000IJEP03001JEUYF
00IJEP@000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEP0000@000IJEP80039oo`00:Woo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH2000cOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@000UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHD
0002FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPP0009JEP03001JEUYF00IJEP03001JEUYF009JEPD003Uoo`00
:goo00<005YF000015YF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEP000080009JEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF
00@005YFFUIJEPP000Qooa0003ioo`00:goo00<005YF00000UYF1`001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF3@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF5P001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02`0000EJEP00FUIJEP00
05Uoo`00:goo00<005YF00000`000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF009J
EPT0009oo`8000=JEP03001JEUYF009JEP80009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<005YFFUH00UYF100017oo
0`000eYF00<007ooOol0EWoo000[Ool20002FUH01000FUH000000eYF00<005YFFUH00UYF4@003Goo
0P0000=JEP00FUH01EYF00<007oo00000UYF00<005YFFUH015YF00<005YFFUH015YF1P000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1P000UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol017oo0P000UYF0P0000=JEP00Ool0Egoo000/Ool?000POol20006FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUH00003FUH40006FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUIJEP02FUH01000
FUH00000F7oo000^Ool2000]Ool20004FUH00`00FUH00002FUH00`00FUIJEP03FUH400000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH01000Oomoogoo0`0015YF00@005YFFUH005Qoo`00;Woo0P00;goo00@005YFFUH0
009JEP04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH300000eYF001JEP03FUH01000Ool000000UYF00<005YFFUH0
0UYF00D005YFFUIJEP0005Moo`00;Woo00<007ooOol0;goo0`000UYF00D005YFFUH005YF008000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF008000AJEP8000EJEP03001JEUYF009JEP04001JEUYF001GOol002eoo`<0039oo`04
001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0001HOol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP02FUH00`00FUH0001HOol002eoo`03
001JEP0001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH0
0`00FUIJEP03FUH00`00Oomoo`1GOol002eoo`04001JEP00000FOol5000HOol30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH00eYF00<007ooOol0Egoo000]Ool0
1@00FUH005YF00005Goo1@006Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00MJEP03001JEUYF008005Yoo`00;Woo00@005YFFUH001Ioo`<001Yoo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0007FUH3001LOol002ioo`05001JEUYFFUH0000cOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<007ooOol0G7oo000^Ool0
0`00FUIJEP02FUH00`00Oomoo`0`Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF001JEP04FUH2001OOol002moo`04001JEUYFFUH3000`Ool30002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP02001QOol0031oo`04001JEUYF0002FUH00`00Oomoo`0]
Ool2000017oo000000001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF2000Hgoo000`Ool00`00FUH00004FUH2000]Ool2
0003Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUH000020005FUH3001SOol0035oo`8000IJEP03001oogoo02Uoo`8000Io
o`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP<000UJEP04001JEP00001QOol0039oo`03001JEUYF00AJEP<002Moo`@000Qoo`<00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0
00QJEP04001JEUYFFUH3001NOol003=oo`8000AJEP03001JEUYF008002Aoo`04001JEUYF000<Ool7
0005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0000=0004FUH00`00
FUIJEP05FUH2001LOol003Eoo`04001JEUYF0005FUH2000POol20003FUH00`00Oomoo`0AOol;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004FUH60004Ool300000eYF001JEP07FUH3001JOol0
03Ioo`<000MJEP<001Uoo`@00005FUH005YFFUH0000OOolM00000eYF001JEP05FUH500000eYF0000
00020003Ool30006FUH01000FUIJEUYF0P00F7oo000hOol20006FUH00`00FUIJEP04000@Ool50004
FUH01000FUH00000<Goo3`001UYF0`001UYF10000Woo0P0015YF00<005YFFUH00eYF0P00EWoo000j
Ool20004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH20012Ool20005FUH00`00FUIJEP07
FUH00`00FUH0000500000eYF001JEP06FUH3001DOol003aoo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo04=oo`<00003FUH005YF00QJEP03001J
EUYF00AJEP@000IJEP05001JEUYFFUH0001COol003moo`<000IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH20019Ool30008FUH00`00FUIJEP06FUH01000FUH0000015YF00@005YFFUIJ
EP80059oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000004ioo`<000EJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEP00059oo`00AWoo1`00
15YF00<005YFFUH00UYF1P00Dgoo0`0000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF0P00Dgoo
001=Ool9001LOol30007FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001oo`1BOol00;Eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00^Goo1P000eYF00L005YFFUIJEP00FUH0
001DOol00;moo`T005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60336 .75501 m .59539 .70097 L .56453 .70271 L p .707 .577 .707 r
F P
0 g
s
.59539 .70097 m .60336 .75501 L .63489 .74994 L p .707 .577 .707 r
F P
0 g
s
.63489 .74994 m .62693 .69589 L .59539 .70097 L p .707 .577 .707 r
F P
0 g
s
.62693 .69589 m .63489 .74994 L .66403 .74203 L p .707 .577 .707 r
F P
0 g
s
.66403 .74203 m .65606 .68799 L .62693 .69589 L p .707 .577 .707 r
F P
0 g
s
.5725 .75675 m .56453 .70271 L .53738 .70094 L p .707 .577 .707 r
F P
0 g
s
.56453 .70271 m .5725 .75675 L .60336 .75501 L p .707 .577 .707 r
F P
0 g
s
.65606 .68799 m .66403 .74203 L .68791 .73206 L p .707 .577 .707 r
F P
0 g
s
.68791 .73206 m .67994 .67802 L .65606 .68799 L p .707 .577 .707 r
F P
0 g
s
.59063 .81642 m .58576 .78027 L .55485 .78173 L p .707 .577 .707 r
F P
0 g
s
.58576 .78027 m .59063 .81642 L .62221 .81169 L p .707 .577 .707 r
F P
0 g
s
.62221 .81169 m .61735 .77554 L .58576 .78027 L p .707 .577 .707 r
F P
0 g
s
.61735 .77554 m .62221 .81169 L .65136 .80415 L p .707 .577 .707 r
F P
0 g
s
.65136 .80415 m .6465 .768 L .61735 .77554 L p .707 .577 .707 r
F P
0 g
s
.54535 .75499 m .53738 .70094 L .5166 .69585 L p .707 .577 .707 r
F P
0 g
s
.53738 .70094 m .54535 .75499 L .5725 .75675 L p .707 .577 .707 r
F P
0 g
s
.55971 .81788 m .55485 .78173 L .52762 .77976 L p .707 .577 .707 r
F P
0 g
s
.55485 .78173 m .55971 .81788 L .59063 .81642 L p .707 .577 .707 r
F P
0 g
s
.6465 .768 m .65136 .80415 L .67524 .79453 L p .707 .577 .707 r
F P
0 g
s
.67524 .79453 m .67038 .75838 L .6465 .768 L p .707 .577 .707 r
F P
0 g
s
.67994 .67802 m .68791 .73206 L .7042 .72101 L p .707 .577 .707 r
F P
0 g
s
.7042 .72101 m .69623 .66696 L .67994 .67802 L p .707 .577 .707 r
F P
0 g
s
.59936 .84191 m .60293 .82336 L .57231 .81632 L p .707 .577 .707 r
F P
0 g
s
.60293 .82336 m .59936 .84191 L .63064 .84718 L p .707 .577 .707 r
F P
0 g
s
.63064 .84718 m .63422 .82863 L .60293 .82336 L p .707 .577 .707 r
F P
0 g
s
.52762 .77976 m .53248 .81591 L .55971 .81788 L p .707 .577 .707 r
F P
0 g
s
.57231 .81632 m .56874 .83487 L .59936 .84191 L p .707 .577 .707 r
F P
0 g
s
.63422 .82863 m .63064 .84718 L .65953 .85015 L p .707 .577 .707 r
F P
0 g
s
.65953 .85015 m .6631 .8316 L .63422 .82863 L p .707 .577 .707 r
F P
0 g
s
.53248 .81591 m .52762 .77976 L .50676 .77458 L p .707 .577 .707 r
F P
0 g
s
.56874 .83487 m .57231 .81632 L .54535 .80819 L p .707 .577 .707 r
F P
0 g
s
.5166 .69585 m .52457 .7499 L .54535 .75499 L p .707 .577 .707 r
F P
0 g
s
.54535 .80819 m .54178 .82675 L .56874 .83487 L p .707 .577 .707 r
F P
0 g
s
.52457 .7499 m .5166 .69585 L .50421 .68793 L p .707 .577 .707 r
F P
0 g
s
.67038 .75838 m .67524 .79453 L .6915 .78378 L p .707 .577 .707 r
F P
0 g
s
.6915 .78378 m .68664 .74763 L .67038 .75838 L p .707 .577 .707 r
F P
0 g
s
.50676 .77458 m .51162 .81072 L .53248 .81591 L p .707 .577 .707 r
F P
0 g
s
.6631 .8316 m .65953 .85015 L .68319 .85055 L p .707 .577 .707 r
F P
0 g
s
.68319 .85055 m .68676 .83199 L .6631 .8316 L p .707 .577 .707 r
F P
0 g
s
.69623 .66696 m .7042 .72101 L .7113 .70995 L p .707 .577 .707 r
F P
0 g
s
.7113 .70995 m .70333 .65591 L .69623 .66696 L p .707 .577 .707 r
F P
0 g
s
.54178 .82675 m .54535 .80819 L .52469 .79977 L p .707 .577 .707 r
F P
0 g
s
.52469 .79977 m .52112 .81833 L .54178 .82675 L p .707 .577 .707 r
F P
0 g
s
.51162 .81072 m .50676 .77458 L .49429 .76667 L p .707 .577 .707 r
F P
0 g
s
.50421 .68793 m .51218 .74197 L .52457 .7499 L p .707 .577 .707 r
F P
0 g
s
.68664 .74763 m .6915 .78378 L .69856 .77295 L p .707 .577 .707 r
F P
0 g
s
.69856 .77295 m .6937 .7368 L .68664 .74763 L p .707 .577 .707 r
F P
0 g
s
.68676 .83199 m .68319 .85055 L .6993 .84832 L p .707 .577 .707 r
F P
0 g
s
.6993 .84832 m .70288 .82976 L .68676 .83199 L p .707 .577 .707 r
F P
0 g
s
.51218 .74197 m .50421 .68793 L .50143 .67795 L p .707 .577 .707 r
F P
0 g
s
.49429 .76667 m .49915 .80282 L .51162 .81072 L p .707 .577 .707 r
F P
0 g
s
.52112 .81833 m .52469 .79977 L .51235 .79189 L p .707 .577 .707 r
F P
0 g
s
.70333 .65591 m .7113 .70995 L .70852 .69997 L p .707 .577 .707 r
F P
0 g
s
.70852 .69997 m .70055 .64593 L .70333 .65591 L p .707 .577 .707 r
F P
0 g
s
.51235 .79189 m .50878 .81044 L .52112 .81833 L p .707 .577 .707 r
F P
0 g
s
.49915 .80282 m .49429 .76667 L .49144 .75682 L p .707 .577 .707 r
F P
0 g
s
.50143 .67795 m .5094 .732 L .51218 .74197 L p .707 .577 .707 r
F P
0 g
s
.48863 .8218 m .48863 .31991 L .44475 .31708 L p .707 .577 .707 r
F P
0 g
s
.49144 .75682 m .4963 .79296 L .49915 .80282 L p .707 .577 .707 r
F P
0 g
s
.5094 .732 m .50143 .67795 L .50853 .66689 L p .707 .577 .707 r
F P
0 g
s
.50878 .81044 m .51235 .79189 L .50954 .78531 L p .707 .577 .707 r
F P
0 g
s
.50954 .78531 m .50597 .80386 L .50878 .81044 L p .707 .577 .707 r
F P
0 g
s
.4963 .79296 m .49144 .75682 L .4985 .74599 L p .707 .577 .707 r
F P
0 g
s
.50853 .66689 m .5165 .72094 L .5094 .732 L p .707 .577 .707 r
F P
0 g
s
.5165 .72094 m .50853 .66689 L .52482 .65584 L p .707 .577 .707 r
F P
0 g
s
.4985 .74599 m .50336 .78213 L .4963 .79296 L p .707 .577 .707 r
F P
0 g
s
.50597 .80386 m .50954 .78531 L .51654 .78068 L p .707 .577 .707 r
F P
0 g
s
.51654 .78068 m .51296 .79923 L .50597 .80386 L p .707 .577 .707 r
F P
0 g
s
.50336 .78213 m .4985 .74599 L .51476 .73524 L p .707 .577 .707 r
F P
0 g
s
.52482 .65584 m .53279 .70988 L .5165 .72094 L p .707 .577 .707 r
F P
0 g
s
.51476 .73524 m .51962 .77138 L .50336 .78213 L p .707 .577 .707 r
F P
0 g
s
.51296 .79923 m .51654 .78068 L .53265 .77845 L p .707 .577 .707 r
F P
0 g
s
.53265 .77845 m .52908 .797 L .51296 .79923 L p .707 .577 .707 r
F P
0 g
s
.51962 .77138 m .51476 .73524 L .53863 .72562 L p .707 .577 .707 r
F P
0 g
s
.53863 .72562 m .54349 .76177 L .51962 .77138 L p .707 .577 .707 r
F P
0 g
s
.52908 .797 m .53265 .77845 L .55631 .77884 L p .707 .577 .707 r
F P
0 g
s
.55631 .77884 m .55273 .79739 L .52908 .797 L p .707 .577 .707 r
F P
0 g
s
.48863 .31991 m .48863 .8218 L .53362 .82086 L p .707 .577 .707 r
F P
0 g
s
.53279 .70988 m .52482 .65584 L .5487 .64587 L p .707 .577 .707 r
F P
0 g
s
.5487 .64587 m .55667 .69991 L .53279 .70988 L p .707 .577 .707 r
F P
0 g
s
.53362 .82086 m .53362 .31897 L .48863 .31991 L p .707 .577 .707 r
F P
0 g
s
.55667 .69991 m .5487 .64587 L .57783 .63796 L p .707 .577 .707 r
F P
0 g
s
.57783 .63796 m .5858 .69201 L .55667 .69991 L p .707 .577 .707 r
F P
0 g
s
.54349 .76177 m .53863 .72562 L .56779 .71808 L p .707 .577 .707 r
F P
0 g
s
.56779 .71808 m .57265 .75422 L .54349 .76177 L p .707 .577 .707 r
F P
0 g
s
.55273 .79739 m .55631 .77884 L .58519 .78181 L p .707 .577 .707 r
F P
0 g
s
.58519 .78181 m .58162 .80037 L .55273 .79739 L p .707 .577 .707 r
F P
0 g
s
.53362 .31897 m .53362 .82086 L .57532 .81623 L p .707 .577 .707 r
F P
0 g
s
.57265 .75422 m .56779 .71808 L .59937 .71335 L p .707 .577 .707 r
F P
0 g
s
.59937 .71335 m .60423 .74949 L .57265 .75422 L p .707 .577 .707 r
F P
0 g
s
.57532 .81623 m .57532 .31434 L .53362 .31897 L p .707 .577 .707 r
F P
0 g
s
.6937 .7368 m .69856 .77295 L .69571 .7631 L p .707 .577 .707 r
F P
0 g
s
.69571 .7631 m .69085 .72695 L .6937 .7368 L p .707 .577 .707 r
F P
0 g
s
.70288 .82976 m .6993 .84832 L .7063 .84369 L p .707 .577 .707 r
F P
0 g
s
.7063 .84369 m .70987 .82513 L .70288 .82976 L p .707 .577 .707 r
F P
0 g
s
.44475 .81897 m .44475 .31708 L .40628 .31075 L p .707 .577 .707 r
F P
0 g
s
.44475 .31708 m .44475 .81897 L .48863 .8218 L p .707 .577 .707 r
F P
0 g
s
.70055 .64593 m .70852 .69997 L .69613 .69205 L p .707 .577 .707 r
F P
0 g
s
.69613 .69205 m .68816 .638 L .70055 .64593 L p .707 .577 .707 r
F P
0 g
s
.5858 .69201 m .57783 .63796 L .60937 .63289 L p .707 .577 .707 r
F P
0 g
s
.60937 .63289 m .61734 .68694 L .5858 .69201 L p .707 .577 .707 r
F P
0 g
s
.63029 .71189 m .63515 .74804 L .60423 .74949 L p .707 .577 .707 r
F P
0 g
s
.60423 .74949 m .59937 .71335 L .63029 .71189 L p .707 .577 .707 r
F P
0 g
s
.58162 .80037 m .58519 .78181 L .61648 .78708 L p .707 .577 .707 r
F P
0 g
s
.61648 .78708 m .6129 .80563 L .58162 .80037 L p .707 .577 .707 r
F P
0 g
s
.57532 .31434 m .57532 .81623 L .60965 .80837 L p .707 .577 .707 r
F P
0 g
s
.61734 .68694 m .60937 .63289 L .64023 .63115 L p .707 .577 .707 r
F P
0 g
s
.60965 .80837 m .60965 .30648 L .57532 .31434 L p .707 .577 .707 r
F P
0 g
s
.25637 .70092 m .25293 .64384 L .22181 .64474 L p .707 .577 .707 r
F P
0 g
s
.25293 .64384 m .25637 .70092 L .28814 .69866 L p .707 .577 .707 r
F P
0 g
s
.28814 .69866 m .28471 .64157 L .25293 .64384 L p .707 .577 .707 r
F P
0 g
s
.28471 .64157 m .28814 .69866 L .31747 .69526 L p .707 .577 .707 r
F P
0 g
s
.31747 .69526 m .31404 .63817 L .28471 .64157 L p .707 .577 .707 r
F P
0 g
s
.40628 .81264 m .40628 .31075 L .37698 .30154 L p .707 .577 .707 r
F P
0 g
s
.40628 .31075 m .40628 .81264 L .44475 .81897 L p .707 .577 .707 r
F P
0 g
s
.69085 .72695 m .69571 .7631 L .68324 .75519 L p .707 .577 .707 r
F P
0 g
s
.68324 .75519 m .67838 .71904 L .69085 .72695 L p .707 .577 .707 r
F P
0 g
s
.70987 .82513 m .7063 .84369 L .70349 .8371 L p .707 .577 .707 r
F P
0 g
s
.70349 .8371 m .70706 .81855 L .70987 .82513 L p .707 .577 .707 r
F P
0 g
s
.22525 .70182 m .22181 .64474 L .1944 .64419 L p .707 .577 .707 r
F P
0 g
s
.22181 .64474 m .22525 .70182 L .25637 .70092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31404 .63817 m .31747 .69526 L .34147 .69105 L p .707 .577 .707 r
F P
0 g
s
.34147 .69105 m .33804 .63396 L .31404 .63817 L p .707 .577 .707 r
F P
0 g
s
.1944 .64419 m .19783 .70127 L .22525 .70182 L p .707 .577 .707 r
F P
0 g
s
.68816 .638 m .69613 .69205 L .67534 .68696 L p .707 .577 .707 r
F P
0 g
s
.67534 .68696 m .66738 .63291 L .68816 .638 L p .707 .577 .707 r
F P
0 g
s
.64023 .63115 m .6482 .6852 L .61734 .68694 L p .707 .577 .707 r
F P
0 g
s
.6471 .79412 m .64352 .81267 L .6129 .80563 L p .707 .577 .707 r
F P
0 g
s
.6129 .80563 m .61648 .78708 L .6471 .79412 L p .707 .577 .707 r
F P
0 g
s
.60965 .30648 m .60965 .80837 L .63324 .79804 L p .707 .577 .707 r
F P
0 g
s
.63515 .74804 m .63029 .71189 L .65751 .71385 L p .707 .577 .707 r
F P
0 g
s
.63324 .79804 m .63324 .29615 L .60965 .30648 L p .707 .577 .707 r
F P
0 g
s
.19783 .70127 m .1944 .64419 L .17337 .64224 L p .707 .577 .707 r
F P
0 g
s
.17337 .64224 m .1768 .69933 L .19783 .70127 L p .707 .577 .707 r
F P
0 g
s
.25097 .75914 m .24888 .72113 L .21774 .7218 L p .707 .577 .707 r
F P
0 g
s
.24888 .72113 m .25097 .75914 L .28275 .757 L p .707 .577 .707 r
F P
0 g
s
.28275 .757 m .28066 .71899 L .24888 .72113 L p .707 .577 .707 r
F P
0 g
s
.67838 .71904 m .68324 .75519 L .66238 .75 L p .707 .577 .707 r
F P
0 g
s
.66238 .75 m .65751 .71385 L .67838 .71904 L p .707 .577 .707 r
F P
0 g
s
.28066 .71899 m .28275 .757 L .31207 .75359 L p .707 .577 .707 r
F P
0 g
s
.31207 .75359 m .30998 .71558 L .28066 .71899 L p .707 .577 .707 r
F P
0 g
s
.33804 .63396 m .34147 .69105 L .3578 .68644 L p .707 .577 .707 r
F P
0 g
s
.3578 .68644 m .35437 .62935 L .33804 .63396 L p .707 .577 .707 r
F P
0 g
s
.21774 .7218 m .21983 .7598 L .25097 .75914 L p .707 .577 .707 r
F P
0 g
s
.37698 .80343 m .37698 .30154 L .35973 .29035 L p .707 .577 .707 r
F P
0 g
s
.37698 .30154 m .37698 .80343 L .40628 .81264 L p .707 .577 .707 r
F P
0 g
s
.70706 .81855 m .70349 .8371 L .69115 .82922 L p .707 .577 .707 r
F P
0 g
s
.69115 .82922 m .69472 .81067 L .70706 .81855 L p .707 .577 .707 r
F P
0 g
s
.21983 .7598 m .21774 .7218 L .19029 .72092 L p .707 .577 .707 r
F P
0 g
s
.66738 .63291 m .67534 .68696 L .6482 .6852 L p .707 .577 .707 r
F P
0 g
s
.6482 .6852 m .64023 .63115 L .66738 .63291 L p .707 .577 .707 r
F P
0 g
s
.25498 .83284 m .25653 .81565 L .22542 .81033 L p .707 .577 .707 r
F P
0 g
s
.25653 .81565 m .25498 .83284 L .2867 .83379 L p .707 .577 .707 r
F P
0 g
s
.2867 .83379 m .28825 .8166 L .25653 .81565 L p .707 .577 .707 r
F P
0 g
s
.19029 .72092 m .19238 .75892 L .21983 .7598 L p .707 .577 .707 r
F P
0 g
s
.28825 .8166 m .2867 .83379 L .31593 .83028 L p .707 .577 .707 r
F P
0 g
s
.31593 .83028 m .31748 .81309 L .28825 .8166 L p .707 .577 .707 r
F P
0 g
s
.22388 .82752 m .22542 .81033 L .19798 .80115 L p .707 .577 .707 r
F P
0 g
s
.22542 .81033 m .22388 .82752 L .25498 .83284 L p .707 .577 .707 r
F P
0 g
s
.30998 .71558 m .31207 .75359 L .33605 .74925 L p .707 .577 .707 r
F P
0 g
s
.33605 .74925 m .33396 .71124 L .30998 .71558 L p .707 .577 .707 r
F P
0 g
s
.1768 .69933 m .17337 .64224 L .16079 .63909 L p .707 .577 .707 r
F P
0 g
s
.19798 .80115 m .19643 .81835 L .22388 .82752 L p .707 .577 .707 r
F P
0 g
s
.19238 .75892 m .19029 .72092 L .16922 .71858 L p .707 .577 .707 r
F P
0 g
s
.16079 .63909 m .16422 .69617 L .1768 .69933 L p .707 .577 .707 r
F P
0 g
s
.65751 .71385 m .66238 .75 L .63515 .74804 L p .707 .577 .707 r
F P
0 g
s
.63324 .29615 m .63324 .79804 L .6438 .78627 L p .707 .577 .707 r
F P
0 g
s
.6438 .78627 m .6438 .28438 L .63324 .29615 L p .707 .577 .707 r
F P
0 g
s
.31748 .81309 m .31593 .83028 L .33981 .82265 L p .707 .577 .707 r
F P
0 g
s
.33981 .82265 m .34135 .80546 L .31748 .81309 L p .707 .577 .707 r
F P
0 g
s
.19643 .81835 m .19798 .80115 L .17688 .78903 L p .707 .577 .707 r
F P
0 g
s
.16922 .71858 m .17132 .75659 L .19238 .75892 L p .707 .577 .707 r
F P
0 g
s
.35437 .62935 m .3578 .68644 L .36486 .68189 L p .707 .577 .707 r
F P
0 g
s
.36486 .68189 m .36143 .6248 L .35437 .62935 L p .707 .577 .707 r
F P
0 g
s
.69472 .81067 m .69115 .82922 L .67048 .8208 L p .707 .577 .707 r
F P
0 g
s
.67048 .8208 m .67406 .80225 L .69472 .81067 L p .707 .577 .707 r
F P
0 g
s
.33396 .71124 m .33605 .74925 L .35234 .74439 L p .707 .577 .707 r
F P
0 g
s
.35234 .74439 m .35025 .70639 L .33396 .71124 L p .707 .577 .707 r
F P
0 g
s
.17688 .78903 m .17534 .80623 L .19643 .81835 L p .707 .577 .707 r
F P
0 g
s
.16422 .69617 m .16079 .63909 L .15789 .63504 L p .707 .577 .707 r
F P
0 g
s
.34135 .80546 m .33981 .82265 L .356 .81165 L p .707 .577 .707 r
F P
0 g
s
.356 .81165 m .35755 .79446 L .34135 .80546 L p .707 .577 .707 r
F P
0 g
s
.36196 .67784 m .35853 .62075 L .36143 .6248 L p .707 .577 .707 r
F P
0 g
s
.36292 .79835 m .36446 .78116 L .35755 .79446 L p .707 .577 .707 r
F P
0 g
s
.35853 .62075 m .36196 .67784 L .34938 .67469 L p .707 .577 .707 r
F P
0 g
s
.36143 .76687 m .35988 .78406 L .3472 .77018 L p .707 .577 .707 r
F P
0 g
s
.3472 .77018 m .34875 .75298 L .36143 .76687 L p .707 .577 .707 r
F P
0 g
s
.35973 .79224 m .35973 .29035 L .3562 .27828 L p .707 .577 .707 r
F P
0 g
s
.36143 .6248 m .36486 .68189 L .36196 .67784 L p .707 .577 .707 r
F P
0 g
s
.36446 .78116 m .36292 .79835 L .35988 .78406 L p .707 .577 .707 r
F P
0 g
s
.35988 .78406 m .36143 .76687 L .36446 .78116 L p .707 .577 .707 r
F P
0 g
s
.35973 .29035 m .35973 .79224 L .37698 .80343 L p .707 .577 .707 r
F P
0 g
s
.17132 .75659 m .16922 .71858 L .1566 .71502 L p .707 .577 .707 r
F P
0 g
s
.17534 .80623 m .17688 .78903 L .1642 .77515 L p .707 .577 .707 r
F P
0 g
s
.15789 .63504 m .16132 .69212 L .16422 .69617 L p .707 .577 .707 r
F P
0 g
s
.1566 .71502 m .15869 .75302 L .17132 .75659 L p .707 .577 .707 r
F P
0 g
s
.1642 .77515 m .16265 .79234 L .17534 .80623 L p .707 .577 .707 r
F P
0 g
s
.67406 .80225 m .67048 .8208 L .64352 .81267 L p .707 .577 .707 r
F P
0 g
s
.64352 .81267 m .6471 .79412 L .67406 .80225 L p .707 .577 .707 r
F P
0 g
s
.35025 .70639 m .35234 .74439 L .35936 .73951 L p .707 .577 .707 r
F P
0 g
s
.35936 .73951 m .35727 .7015 L .35025 .70639 L p .707 .577 .707 r
F P
0 g
s
.6438 .28438 m .6438 .78627 L .64027 .7742 L p .707 .577 .707 r
F P
0 g
s
.64027 .7742 m .64027 .27231 L .6438 .28438 L p .707 .577 .707 r
F P
0 g
s
.35755 .79446 m .356 .81165 L .36292 .79835 L p .707 .577 .707 r
F P
0 g
s
.16265 .79234 m .1642 .77515 L .16117 .76085 L p .707 .577 .707 r
F P
0 g
s
.15869 .75302 m .1566 .71502 L .15365 .71057 L p .707 .577 .707 r
F P
0 g
s
.16132 .69212 m .15789 .63504 L .16495 .63049 L p .707 .577 .707 r
F P
0 g
s
.15365 .71057 m .15574 .74858 L .15869 .75302 L p .707 .577 .707 r
F P
0 g
s
.16117 .76085 m .15962 .77805 L .16265 .79234 L p .707 .577 .707 r
F P
0 g
s
.16495 .63049 m .16838 .68757 L .16132 .69212 L p .707 .577 .707 r
F P
0 g
s
.35727 .7015 m .35936 .73951 L .35641 .73506 L p .707 .577 .707 r
F P
0 g
s
.35641 .73506 m .35432 .69706 L .35727 .7015 L p .707 .577 .707 r
F P
0 g
s
.34938 .67469 m .34595 .6176 L .35853 .62075 L p .707 .577 .707 r
F P
0 g
s
.35432 .69706 m .35641 .73506 L .34379 .7315 L p .707 .577 .707 r
F P
0 g
s
.3562 .27828 m .3562 .78017 L .35973 .79224 L p .707 .577 .707 r
F P
0 g
s
.3562 .78017 m .3562 .27828 L .36675 .2665 L p .707 .577 .707 r
F P
0 g
s
.15962 .77805 m .16117 .76085 L .16809 .74756 L p .707 .577 .707 r
F P
0 g
s
.16838 .68757 m .16495 .63049 L .18128 .62588 L p .707 .577 .707 r
F P
0 g
s
.15574 .74858 m .15365 .71057 L .16067 .70569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64027 .27231 m .64027 .7742 L .62301 .76301 L p .707 .577 .707 r
F P
0 g
s
.62301 .76301 m .62301 .26112 L .64027 .27231 L p .707 .577 .707 r
F P
0 g
s
.16809 .74756 m .16654 .76475 L .15962 .77805 L p .707 .577 .707 r
F P
0 g
s
.16067 .70569 m .16276 .74369 L .15574 .74858 L p .707 .577 .707 r
F P
0 g
s
.18128 .62588 m .18471 .68297 L .16838 .68757 L p .707 .577 .707 r
F P
0 g
s
.34595 .6176 m .34938 .67469 L .32835 .67274 L p .707 .577 .707 r
F P
0 g
s
.32835 .67274 m .32492 .61565 L .34595 .6176 L p .707 .577 .707 r
F P
0 g
s
.34379 .7315 m .34169 .69349 L .35432 .69706 L p .707 .577 .707 r
F P
0 g
s
.16654 .76475 m .16809 .74756 L .18428 .73656 L p .707 .577 .707 r
F P
0 g
s
.36675 .76839 m .36675 .2665 L .39035 .25618 L p .707 .577 .707 r
F P
0 g
s
.36675 .2665 m .36675 .76839 L .3562 .78017 L p .707 .577 .707 r
F P
0 g
s
.18471 .68297 m .18128 .62588 L .20528 .62167 L p .707 .577 .707 r
F P
0 g
s
.16276 .74369 m .16067 .70569 L .17696 .70083 L p .707 .577 .707 r
F P
0 g
s
.18428 .73656 m .18273 .75375 L .16654 .76475 L p .707 .577 .707 r
F P
0 g
s
.20528 .62167 m .20872 .67876 L .18471 .68297 L p .707 .577 .707 r
F P
0 g
s
.17696 .70083 m .17906 .73884 L .16276 .74369 L p .707 .577 .707 r
F P
0 g
s
.32492 .61565 m .32835 .67274 L .30094 .67219 L p .707 .577 .707 r
F P
0 g
s
.30094 .67219 m .29751 .6151 L .32492 .61565 L p .707 .577 .707 r
F P
0 g
s
.62301 .26112 m .62301 .76301 L .59372 .7538 L p .707 .577 .707 r
F P
0 g
s
.59372 .7538 m .59372 .25191 L .62301 .26112 L p .707 .577 .707 r
F P
0 g
s
.34875 .75298 m .3472 .77018 L .3261 .75805 L p .707 .577 .707 r
F P
0 g
s
.3261 .75805 m .32765 .74086 L .34875 .75298 L p .707 .577 .707 r
F P
0 g
s
.34169 .69349 m .34379 .7315 L .32272 .72916 L p .707 .577 .707 r
F P
0 g
s
.32272 .72916 m .32063 .69116 L .34169 .69349 L p .707 .577 .707 r
F P
0 g
s
.20872 .67876 m .20528 .62167 L .23461 .61826 L p .707 .577 .707 r
F P
0 g
s
.18273 .75375 m .18428 .73656 L .20816 .72893 L p .707 .577 .707 r
F P
0 g
s
.29751 .6151 m .30094 .67219 L .26982 .67309 L p .707 .577 .707 r
F P
0 g
s
.26982 .67309 m .26639 .616 L .29751 .6151 L p .707 .577 .707 r
F P
0 g
s
.23461 .61826 m .23804 .67535 L .20872 .67876 L p .707 .577 .707 r
F P
0 g
s
.20816 .72893 m .20661 .74612 L .18273 .75375 L p .707 .577 .707 r
F P
0 g
s
.17906 .73884 m .17696 .70083 L .20094 .69649 L p .707 .577 .707 r
F P
0 g
s
.23804 .67535 m .23461 .61826 L .26639 .616 L p .707 .577 .707 r
F P
0 g
s
.39035 .25618 m .39035 .75807 L .36675 .76839 L p .707 .577 .707 r
F P
0 g
s
.39035 .75807 m .39035 .25618 L .42467 .24832 L p .707 .577 .707 r
F P
0 g
s
.26639 .616 m .26982 .67309 L .23804 .67535 L p .707 .577 .707 r
F P
0 g
s
.20094 .69649 m .20303 .7345 L .17906 .73884 L p .707 .577 .707 r
F P
0 g
s
.73018 .66809 m .73361 .61527 L .70249 .61075 L p .707 .577 .707 r
F P
0 g
s
.73361 .61527 m .73018 .66809 L .76196 .66867 L p .707 .577 .707 r
F P
0 g
s
.76196 .66867 m .76539 .61585 L .73361 .61527 L p .707 .577 .707 r
F P
0 g
s
.32765 .74086 m .3261 .75805 L .29866 .74888 L p .707 .577 .707 r
F P
0 g
s
.29866 .74888 m .30021 .73169 L .32765 .74086 L p .707 .577 .707 r
F P
0 g
s
.76539 .61585 m .76196 .66867 L .79128 .66524 L p .707 .577 .707 r
F P
0 g
s
.79128 .66524 m .79471 .61243 L .76539 .61585 L p .707 .577 .707 r
F P
0 g
s
.20661 .74612 m .20816 .72893 L .23739 .72541 L p .707 .577 .707 r
F P
0 g
s
.32063 .69116 m .32272 .72916 L .29527 .72828 L p .707 .577 .707 r
F P
0 g
s
.29527 .72828 m .29318 .69028 L .32063 .69116 L p .707 .577 .707 r
F P
0 g
s
.69906 .66357 m .70249 .61075 L .67508 .60273 L p .707 .577 .707 r
F P
0 g
s
.70249 .61075 m .69906 .66357 L .73018 .66809 L p .707 .577 .707 r
F P
0 g
s
.59372 .25191 m .59372 .7538 L .55525 .74746 L p .707 .577 .707 r
F P
0 g
s
.55525 .74746 m .55525 .24558 L .59372 .25191 L p .707 .577 .707 r
F P
0 g
s
.23739 .72541 m .23584 .74261 L .20661 .74612 L p .707 .577 .707 r
F P
0 g
s
.73586 .73097 m .73796 .69556 L .70682 .69127 L p .707 .577 .707 r
F P
0 g
s
.73796 .69556 m .73586 .73097 L .76765 .73142 L p .707 .577 .707 r
F P
0 g
s
.76765 .73142 m .76974 .69601 L .73796 .69556 L p .707 .577 .707 r
F P
0 g
s
.20303 .7345 m .20094 .69649 L .23026 .69308 L p .707 .577 .707 r
F P
0 g
s
.30021 .73169 m .29866 .74888 L .26756 .74356 L p .707 .577 .707 r
F P
0 g
s
.26756 .74356 m .26911 .72637 L .30021 .73169 L p .707 .577 .707 r
F P
0 g
s
.76974 .69601 m .76765 .73142 L .79696 .72799 L p .707 .577 .707 r
F P
0 g
s
.79696 .72799 m .79906 .69258 L .76974 .69601 L p .707 .577 .707 r
F P
0 g
s
.79471 .61243 m .79128 .66524 L .81529 .65815 L p .707 .577 .707 r
F P
0 g
s
.81529 .65815 m .81872 .60534 L .79471 .61243 L p .707 .577 .707 r
F P
0 g
s
.23584 .74261 m .23739 .72541 L .26911 .72637 L p .707 .577 .707 r
F P
0 g
s
.70472 .72668 m .70682 .69127 L .67937 .68357 L p .707 .577 .707 r
F P
0 g
s
.70682 .69127 m .70472 .72668 L .73586 .73097 L p .707 .577 .707 r
F P
0 g
s
.23026 .69308 m .23235 .73109 L .20303 .7345 L p .707 .577 .707 r
F P
0 g
s
.26911 .72637 m .26756 .74356 L .23584 .74261 L p .707 .577 .707 r
F P
0 g
s
.67164 .65554 m .67508 .60273 L .65405 .59199 L p .707 .577 .707 r
F P
0 g
s
.67508 .60273 m .67164 .65554 L .69906 .66357 L p .707 .577 .707 r
F P
0 g
s
.29318 .69028 m .29527 .72828 L .26413 .72895 L p .707 .577 .707 r
F P
0 g
s
.26413 .72895 m .26204 .69094 L .29318 .69028 L p .707 .577 .707 r
F P
0 g
s
.42467 .75021 m .42467 .24832 L .46637 .24369 L p .707 .577 .707 r
F P
0 g
s
.42467 .24832 m .42467 .75021 L .39035 .75807 L p .707 .577 .707 r
F P
0 g
s
.23235 .73109 m .23026 .69308 L .26204 .69094 L p .707 .577 .707 r
F P
0 g
s
.79906 .69258 m .79696 .72799 L .82094 .72101 L p .707 .577 .707 r
F P
0 g
s
.82094 .72101 m .82304 .68561 L .79906 .69258 L p .707 .577 .707 r
F P
0 g
s
.26204 .69094 m .26413 .72895 L .23235 .73109 L p .707 .577 .707 r
F P
0 g
s
.67728 .71897 m .67937 .68357 L .6583 .6732 L p .707 .577 .707 r
F P
0 g
s
.67937 .68357 m .67728 .71897 L .70472 .72668 L p .707 .577 .707 r
F P
0 g
s
.55525 .24558 m .55525 .74746 L .51137 .74463 L p .707 .577 .707 r
F P
0 g
s
.51137 .74463 m .51137 .24274 L .55525 .24558 L p .707 .577 .707 r
F P
0 g
s
.81872 .60534 m .81529 .65815 L .83162 .64809 L p .707 .577 .707 r
F P
0 g
s
.83162 .64809 m .83505 .59527 L .81872 .60534 L p .707 .577 .707 r
F P
0 g
s
.73244 .74043 m .73089 .72133 L .69979 .72324 L p .707 .577 .707 r
F P
0 g
s
.73089 .72133 m .73244 .74043 L .76416 .73762 L p .707 .577 .707 r
F P
0 g
s
.76416 .73762 m .76261 .71852 L .73089 .72133 L p .707 .577 .707 r
F P
0 g
s
.69979 .72324 m .70134 .74234 L .73244 .74043 L p .707 .577 .707 r
F P
0 g
s
.76261 .71852 m .76416 .73762 L .79339 .73418 L p .707 .577 .707 r
F P
0 g
s
.79339 .73418 m .79184 .71508 L .76261 .71852 L p .707 .577 .707 r
F P
0 g
s
.46637 .74558 m .46637 .24369 L .51137 .24274 L p .707 .577 .707 r
F P
0 g
s
.46637 .24369 m .46637 .74558 L .42467 .75021 L p .707 .577 .707 r
F P
0 g
s
.65062 .6448 m .65405 .59199 L .64147 .57958 L p .707 .577 .707 r
F P
0 g
s
.65405 .59199 m .65062 .6448 L .67164 .65554 L p .707 .577 .707 r
F P
0 g
s
.51137 .24274 m .51137 .74463 L .46637 .74558 L p .707 .577 .707 r
F P
0 g
s
.70134 .74234 m .69979 .72324 L .67235 .72406 L p .707 .577 .707 r
F P
0 g
s
.67235 .72406 m .67389 .74317 L .70134 .74234 L p .707 .577 .707 r
F P
0 g
s
.6583 .6732 m .65621 .7086 L .67728 .71897 L p .707 .577 .707 r
F P
0 g
s
.82304 .68561 m .82094 .72101 L .83724 .71117 L p .707 .577 .707 r
F P
0 g
s
.83724 .71117 m .83933 .67577 L .82304 .68561 L p .707 .577 .707 r
F P
0 g
s
.79184 .71508 m .79339 .73418 L .81727 .73046 L p .707 .577 .707 r
F P
0 g
s
.81727 .73046 m .81572 .71136 L .79184 .71508 L p .707 .577 .707 r
F P
0 g
s
.65621 .7086 m .6583 .6732 L .64568 .66118 L p .707 .577 .707 r
F P
0 g
s
.83505 .59527 m .83162 .64809 L .83868 .63604 L p .707 .577 .707 r
F P
0 g
s
.83868 .63604 m .84211 .58322 L .83505 .59527 L p .707 .577 .707 r
F P
0 g
s
.67389 .74317 m .67235 .72406 L .65125 .72372 L p .707 .577 .707 r
F P
0 g
s
.65125 .72372 m .6528 .74282 L .67389 .74317 L p .707 .577 .707 r
F P
0 g
s
.64147 .57958 m .63804 .6324 L .65062 .6448 L p .707 .577 .707 r
F P
0 g
s
.63804 .6324 m .64147 .57958 L .63857 .56672 L p .707 .577 .707 r
F P
0 g
s
.64568 .66118 m .64358 .69658 L .65621 .7086 L p .707 .577 .707 r
F P
0 g
s
.83933 .67577 m .83724 .71117 L .84426 .69943 L p .707 .577 .707 r
F P
0 g
s
.84426 .69943 m .84635 .66403 L .83933 .67577 L p .707 .577 .707 r
F P
0 g
s
.81572 .71136 m .81727 .73046 L .83346 .72681 L p .707 .577 .707 r
F P
0 g
s
.83346 .72681 m .83191 .70771 L .81572 .71136 L p .707 .577 .707 r
F P
0 g
s
.64358 .69658 m .64568 .66118 L .64273 .64869 L p .707 .577 .707 r
F P
0 g
s
.6528 .74282 m .65125 .72372 L .63857 .72225 L p .707 .577 .707 r
F P
0 g
s
.63857 .72225 m .64011 .74135 L .6528 .74282 L p .707 .577 .707 r
F P
0 g
s
.84211 .58322 m .83868 .63604 L .83577 .62318 L p .707 .577 .707 r
F P
0 g
s
.83577 .62318 m .83921 .57037 L .84211 .58322 L p .707 .577 .707 r
F P
0 g
s
.63857 .56672 m .63513 .61954 L .63804 .6324 L p .707 .577 .707 r
F P
0 g
s
.64273 .64869 m .64064 .68409 L .64358 .69658 L p .707 .577 .707 r
F P
0 g
s
.63513 .61954 m .63857 .56672 L .64563 .55467 L p .707 .577 .707 r
F P
0 g
s
.83191 .70771 m .83346 .72681 L .84038 .7236 L p .707 .577 .707 r
F P
0 g
s
.84038 .7236 m .83883 .7045 L .83191 .70771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84635 .66403 m .84426 .69943 L .84131 .68694 L p .707 .577 .707 r
F P
0 g
s
.84131 .68694 m .8434 .65153 L .84635 .66403 L p .707 .577 .707 r
F P
0 g
s
.64064 .68409 m .64273 .64869 L .64975 .63695 L p .707 .577 .707 r
F P
0 g
s
.64011 .74135 m .63857 .72225 L .63553 .71978 L p .707 .577 .707 r
F P
0 g
s
.63553 .71978 m .63708 .73888 L .64011 .74135 L p .707 .577 .707 r
F P
0 g
s
.83921 .57037 m .83577 .62318 L .82319 .61078 L p .707 .577 .707 r
F P
0 g
s
.82319 .61078 m .82663 .55796 L .83921 .57037 L p .707 .577 .707 r
F P
0 g
s
.64563 .55467 m .64219 .60749 L .63513 .61954 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64975 .63695 m .64765 .67235 L .64064 .68409 L p .707 .577 .707 r
F P
0 g
s
.64219 .60749 m .64563 .55467 L .66196 .54461 L p .707 .577 .707 r
F P
0 g
s
.38266 .61436 m .39062 .5585 L .35977 .55278 L p .707 .577 .707 r
F P
0 g
s
.39062 .5585 m .38266 .61436 L .41419 .61807 L p .707 .577 .707 r
F P
0 g
s
.41419 .61807 m .42216 .56221 L .39062 .5585 L p .707 .577 .707 r
F P
0 g
s
.42216 .56221 m .41419 .61807 L .44333 .6194 L p .707 .577 .707 r
F P
0 g
s
.44333 .6194 m .4513 .56354 L .42216 .56221 L p .707 .577 .707 r
F P
0 g
s
.8434 .65153 m .84131 .68694 L .82868 .67492 L p .707 .577 .707 r
F P
0 g
s
.82868 .67492 m .83077 .63951 L .8434 .65153 L p .707 .577 .707 r
F P
0 g
s
.83883 .7045 m .84038 .7236 L .83735 .72113 L p .707 .577 .707 r
F P
0 g
s
.83735 .72113 m .8358 .70203 L .83883 .7045 L p .707 .577 .707 r
F P
0 g
s
.3518 .60864 m .35977 .55278 L .33262 .54561 L p .707 .577 .707 r
F P
0 g
s
.35977 .55278 m .3518 .60864 L .38266 .61436 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64765 .67235 m .64975 .63695 L .66604 .6271 L p .707 .577 .707 r
F P
0 g
s
.4513 .56354 m .44333 .6194 L .46721 .61823 L p .707 .577 .707 r
F P
0 g
s
.46721 .61823 m .47518 .56237 L .4513 .56354 L p .707 .577 .707 r
F P
0 g
s
.33262 .54561 m .32465 .60147 L .3518 .60864 L p .707 .577 .707 r
F P
0 g
s
.82663 .55796 m .82319 .61078 L .80217 .60004 L p .707 .577 .707 r
F P
0 g
s
.80217 .60004 m .8056 .54722 L .82663 .55796 L p .707 .577 .707 r
F P
0 g
s
.63708 .73888 m .63553 .71978 L .64245 .71657 L p .707 .577 .707 r
F P
0 g
s
.32465 .60147 m .33262 .54561 L .31183 .5377 L p .707 .577 .707 r
F P
0 g
s
.64245 .71657 m .644 .73567 L .63708 .73888 L p .707 .577 .707 r
F P
0 g
s
.66196 .54461 m .65853 .59743 L .64219 .60749 L p .707 .577 .707 r
F P
0 g
s
.65853 .59743 m .66196 .54461 L .68596 .53752 L p .707 .577 .707 r
F P
0 g
s
.39576 .67398 m .40062 .63672 L .36971 .63134 L p .707 .577 .707 r
F P
0 g
s
.40062 .63672 m .39576 .67398 L .42735 .67729 L p .707 .577 .707 r
F P
0 g
s
.42735 .67729 m .43221 .64003 L .40062 .63672 L p .707 .577 .707 r
F P
0 g
s
.66604 .6271 m .66395 .66251 L .64765 .67235 L p .707 .577 .707 r
F P
0 g
s
.43221 .64003 m .42735 .67729 L .4565 .67821 L p .707 .577 .707 r
F P
0 g
s
.4565 .67821 m .46136 .64095 L .43221 .64003 L p .707 .577 .707 r
F P
0 g
s
.83077 .63951 m .82868 .67492 L .80761 .66455 L p .707 .577 .707 r
F P
0 g
s
.80761 .66455 m .80971 .62914 L .83077 .63951 L p .707 .577 .707 r
F P
0 g
s
.36485 .6686 m .36971 .63134 L .34248 .62442 L p .707 .577 .707 r
F P
0 g
s
.36971 .63134 m .36485 .6686 L .39576 .67398 L p .707 .577 .707 r
F P
0 g
s
.31183 .5377 m .30387 .59356 L .32465 .60147 L p .707 .577 .707 r
F P
0 g
s
.8358 .70203 m .83735 .72113 L .82466 .71966 L p .707 .577 .707 r
F P
0 g
s
.82466 .71966 m .82311 .70056 L .8358 .70203 L p .707 .577 .707 r
F P
0 g
s
.66395 .66251 m .66604 .6271 L .69002 .62013 L p .707 .577 .707 r
F P
0 g
s
.47518 .56237 m .46721 .61823 L .4835 .61467 L p .707 .577 .707 r
F P
0 g
s
.4835 .61467 m .49147 .55881 L .47518 .56237 L p .707 .577 .707 r
F P
0 g
s
.38709 .732 m .38352 .71426 L .3529 .71725 L p .707 .577 .707 r
F P
0 g
s
.38352 .71426 m .38709 .732 L .41838 .72546 L p .707 .577 .707 r
F P
0 g
s
.41838 .72546 m .4148 .70772 L .38352 .71426 L p .707 .577 .707 r
F P
0 g
s
.34248 .62442 m .33762 .66168 L .36485 .6686 L p .707 .577 .707 r
F P
0 g
s
.8056 .54722 m .80217 .60004 L .77475 .59201 L p .707 .577 .707 r
F P
0 g
s
.77475 .59201 m .77818 .5392 L .8056 .54722 L p .707 .577 .707 r
F P
0 g
s
.4148 .70772 m .41838 .72546 L .44726 .716 L p .707 .577 .707 r
F P
0 g
s
.44726 .716 m .44369 .69826 L .4148 .70772 L p .707 .577 .707 r
F P
0 g
s
.46136 .64095 m .4565 .67821 L .48038 .67664 L p .707 .577 .707 r
F P
0 g
s
.48038 .67664 m .48524 .63938 L .46136 .64095 L p .707 .577 .707 r
F P
0 g
s
.30387 .59356 m .31183 .5377 L .29944 .5298 L p .707 .577 .707 r
F P
0 g
s
.68253 .59034 m .68596 .53752 L .71529 .5341 L p .707 .577 .707 r
F P
0 g
s
.68596 .53752 m .68253 .59034 L .65853 .59743 L p .707 .577 .707 r
F P
0 g
s
.3529 .71725 m .35647 .73498 L .38709 .732 L p .707 .577 .707 r
F P
0 g
s
.33762 .66168 m .34248 .62442 L .32162 .61663 L p .707 .577 .707 r
F P
0 g
s
.35647 .73498 m .3529 .71725 L .32594 .71638 L p .707 .577 .707 r
F P
0 g
s
.644 .73567 m .64245 .71657 L .65864 .71292 L p .707 .577 .707 r
F P
0 g
s
.44369 .69826 m .44726 .716 L .47092 .70456 L p .707 .577 .707 r
F P
0 g
s
.47092 .70456 m .46735 .68682 L .44369 .69826 L p .707 .577 .707 r
F P
0 g
s
.65864 .71292 m .66019 .73202 L .644 .73567 L p .707 .577 .707 r
F P
0 g
s
.69002 .62013 m .68793 .65553 L .66395 .66251 L p .707 .577 .707 r
F P
0 g
s
.80971 .62914 m .80761 .66455 L .78017 .65684 L p .707 .577 .707 r
F P
0 g
s
.78017 .65684 m .78226 .62144 L .80971 .62914 L p .707 .577 .707 r
F P
0 g
s
.77818 .5392 m .77475 .59201 L .74363 .58749 L p .707 .577 .707 r
F P
0 g
s
.74363 .58749 m .74706 .53467 L .77818 .5392 L p .707 .577 .707 r
F P
0 g
s
.32594 .71638 m .32951 .73412 L .35647 .73498 L p .707 .577 .707 r
F P
0 g
s
.32162 .61663 m .31675 .65389 L .33762 .66168 L p .707 .577 .707 r
F P
0 g
s
.29944 .5298 m .29148 .58566 L .30387 .59356 L p .707 .577 .707 r
F P
0 g
s
.71185 .58691 m .71529 .5341 L .74706 .53467 L p .707 .577 .707 r
F P
0 g
s
.71529 .5341 m .71185 .58691 L .68253 .59034 L p .707 .577 .707 r
F P
0 g
s
.68793 .65553 m .69002 .62013 L .71934 .6167 L p .707 .577 .707 r
F P
0 g
s
.74706 .53467 m .74363 .58749 L .71185 .58691 L p .707 .577 .707 r
F P
0 g
s
.48524 .63938 m .48038 .67664 L .49664 .67274 L p .707 .577 .707 r
F P
0 g
s
.49664 .67274 m .5015 .63548 L .48524 .63938 L p .707 .577 .707 r
F P
0 g
s
.49147 .55881 m .4835 .61467 L .4906 .60908 L p .707 .577 .707 r
F P
0 g
s
.4906 .60908 m .49857 .55321 L .49147 .55881 L p .707 .577 .707 r
F P
0 g
s
.32951 .73412 m .32594 .71638 L .30528 .71175 L p .707 .577 .707 r
F P
0 g
s
.82311 .70056 m .82466 .71966 L .80357 .71931 L p .707 .577 .707 r
F P
0 g
s
.80357 .71931 m .80202 .70021 L .82311 .70056 L p .707 .577 .707 r
F P
0 g
s
.78226 .62144 m .78017 .65684 L .74903 .65255 L p .707 .577 .707 r
F P
0 g
s
.74903 .65255 m .75112 .61715 L .78226 .62144 L p .707 .577 .707 r
F P
0 g
s
.46735 .68682 m .47092 .70456 L .48704 .69224 L p .707 .577 .707 r
F P
0 g
s
.48704 .69224 m .48346 .6745 L .46735 .68682 L p .707 .577 .707 r
F P
0 g
s
.71725 .6521 m .71934 .6167 L .75112 .61715 L p .707 .577 .707 r
F P
0 g
s
.71934 .6167 m .71725 .6521 L .68793 .65553 L p .707 .577 .707 r
F P
0 g
s
.31675 .65389 m .32162 .61663 L .30915 .60875 L p .707 .577 .707 r
F P
0 g
s
.30528 .71175 m .30885 .72949 L .32951 .73412 L p .707 .577 .707 r
F P
0 g
s
.29148 .58566 m .29944 .5298 L .29666 .52271 L p .707 .577 .707 r
F P
0 g
s
.75112 .61715 m .74903 .65255 L .71725 .6521 L p .707 .577 .707 r
F P
0 g
s
.66019 .73202 m .65864 .71292 L .68252 .7092 L p .707 .577 .707 r
F P
0 g
s
.30915 .60875 m .30429 .646 L .31675 .65389 L p .707 .577 .707 r
F P
0 g
s
.68252 .7092 m .68407 .7283 L .66019 .73202 L p .707 .577 .707 r
F P
0 g
s
.29666 .52271 m .28869 .57857 L .29148 .58566 L p .707 .577 .707 r
F P
0 g
s
.30885 .72949 m .30528 .71175 L .29294 .70381 L p .707 .577 .707 r
F P
0 g
s
.80202 .70021 m .80357 .71931 L .77612 .72014 L p .707 .577 .707 r
F P
0 g
s
.77612 .72014 m .77458 .70104 L .80202 .70021 L p .707 .577 .707 r
F P
0 g
s
.5015 .63548 m .49664 .67274 L .50369 .6669 L p .707 .577 .707 r
F P
0 g
s
.50369 .6669 m .50855 .62964 L .5015 .63548 L p .707 .577 .707 r
F P
0 g
s
.48346 .6745 m .48704 .69224 L .49403 .68026 L p .707 .577 .707 r
F P
0 g
s
.49403 .68026 m .49046 .66252 L .48346 .6745 L p .707 .577 .707 r
F P
0 g
s
.49857 .55321 m .4906 .60908 L .48782 .60198 L p .707 .577 .707 r
F P
0 g
s
.48782 .60198 m .49579 .54612 L .49857 .55321 L p .707 .577 .707 r
F P
0 g
s
.29294 .70381 m .29651 .72155 L .30885 .72949 L p .707 .577 .707 r
F P
0 g
s
.30429 .646 m .30915 .60875 L .3063 .60153 L p .707 .577 .707 r
F P
0 g
s
.68407 .7283 m .68252 .7092 L .71175 .70576 L p .707 .577 .707 r
F P
0 g
s
.71175 .70576 m .7133 .72486 L .68407 .7283 L p .707 .577 .707 r
F P
0 g
s
.28869 .57857 m .29666 .52271 L .30377 .51711 L p .707 .577 .707 r
F P
0 g
s
.3063 .60153 m .30144 .63878 L .30429 .646 L p .707 .577 .707 r
F P
0 g
s
.77458 .70104 m .77612 .72014 L .74502 .72205 L p .707 .577 .707 r
F P
0 g
s
.74502 .72205 m .74347 .70295 L .77458 .70104 L p .707 .577 .707 r
F P
0 g
s
.7133 .72486 m .71175 .70576 L .74347 .70295 L p .707 .577 .707 r
F P
0 g
s
.74347 .70295 m .74502 .72205 L .7133 .72486 L p .707 .577 .707 r
F P
0 g
s
.30377 .51711 m .2958 .57297 L .28869 .57857 L p .707 .577 .707 r
F P
0 g
s
.29651 .72155 m .29294 .70381 L .29013 .69334 L p .707 .578 .707 r
F P
0 g
s
.50855 .62964 m .50369 .6669 L .50085 .65968 L p .707 .577 .707 r
F P
0 g
s
.50085 .65968 m .50571 .62242 L .50855 .62964 L p .707 .577 .707 r
F P
0 g
s
.49046 .66252 m .49403 .68026 L .49122 .66978 L p .707 .578 .707 r
F P
0 g
s
.49122 .66978 m .48765 .65204 L .49046 .66252 L p .707 .578 .707 r
F P
0 g
s
.29013 .69334 m .2937 .71108 L .29651 .72155 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .54612 m .48782 .60198 L .47543 .59409 L p .707 .577 .707 r
F P
0 g
s
.47543 .59409 m .4834 .53823 L .49579 .54612 L p .707 .577 .707 r
F P
0 g
s
.30144 .63878 m .3063 .60153 L .31335 .59568 L p .707 .577 .707 r
F P
0 g
s
.2958 .57297 m .30377 .51711 L .32005 .51355 L p .707 .577 .707 r
F P
0 g
s
.31335 .59568 m .30849 .63294 L .30144 .63878 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32005 .51355 m .31209 .56941 L .2958 .57297 L p .707 .577 .707 r
F P
0 g
s
.2937 .71108 m .29013 .69334 L .29712 .68136 L p .707 .577 .707 r
F P
0 g
s
.48765 .65204 m .49122 .66978 L .47888 .66184 L p .707 .577 .707 r
F P
0 g
s
.47888 .66184 m .47531 .6441 L .48765 .65204 L p .707 .577 .707 r
F P
0 g
s
.50571 .62242 m .50085 .65968 L .48838 .65179 L p .707 .577 .707 r
F P
0 g
s
.48838 .65179 m .49324 .61453 L .50571 .62242 L p .707 .577 .707 r
F P
0 g
s
.29712 .68136 m .3007 .6991 L .2937 .71108 L p .707 .577 .707 r
F P
0 g
s
.4834 .53823 m .47543 .59409 L .45464 .58617 L p .707 .577 .707 r
F P
0 g
s
.45464 .58617 m .46261 .53031 L .4834 .53823 L p .707 .577 .707 r
F P
0 g
s
.30849 .63294 m .31335 .59568 L .32961 .59179 L p .707 .577 .707 r
F P
0 g
s
.31209 .56941 m .32005 .51355 L .34394 .51238 L p .707 .577 .707 r
F P
0 g
s
.32961 .59179 m .32475 .62904 L .30849 .63294 L p .707 .577 .707 r
F P
0 g
s
.34394 .51238 m .33597 .56824 L .31209 .56941 L p .707 .577 .707 r
F P
0 g
s
.3007 .6991 m .29712 .68136 L .31324 .66904 L p .707 .577 .707 r
F P
0 g
s
.46261 .53031 m .45464 .58617 L .42749 .57901 L p .707 .577 .707 r
F P
0 g
s
.42749 .57901 m .43546 .52314 L .46261 .53031 L p .707 .577 .707 r
F P
0 g
s
.47531 .6441 m .47888 .66184 L .45822 .65721 L p .707 .577 .707 r
F P
0 g
s
.45822 .65721 m .45465 .63947 L .47531 .6441 L p .707 .577 .707 r
F P
0 g
s
.49324 .61453 m .48838 .65179 L .46751 .644 L p .707 .577 .707 r
F P
0 g
s
.46751 .644 m .47237 .60674 L .49324 .61453 L p .707 .577 .707 r
F P
0 g
s
.33597 .56824 m .34394 .51238 L .37307 .51372 L p .707 .577 .707 r
F P
0 g
s
.31324 .66904 m .31681 .68678 L .3007 .6991 L p .707 .577 .707 r
F P
0 g
s
.32475 .62904 m .32961 .59179 L .35349 .59022 L p .707 .577 .707 r
F P
0 g
s
.43546 .52314 m .42749 .57901 L .39664 .57329 L p .707 .577 .707 r
F P
0 g
s
.39664 .57329 m .40461 .51743 L .43546 .52314 L p .707 .577 .707 r
F P
0 g
s
.37307 .51372 m .3651 .56958 L .33597 .56824 L p .707 .577 .707 r
F P
0 g
s
.35349 .59022 m .34863 .62748 L .32475 .62904 L p .707 .577 .707 r
F P
0 g
s
.3651 .56958 m .37307 .51372 L .40461 .51743 L p .707 .577 .707 r
F P
0 g
s
.40461 .51743 m .39664 .57329 L .3651 .56958 L p .707 .577 .707 r
F P
0 g
s
.31681 .68678 m .31324 .66904 L .33689 .65759 L p .707 .577 .707 r
F P
0 g
s
.45465 .63947 m .45822 .65721 L .43126 .65635 L p .707 .577 .707 r
F P
0 g
s
.43126 .65635 m .42768 .63861 L .45465 .63947 L p .707 .577 .707 r
F P
0 g
s
.47237 .60674 m .46751 .644 L .44029 .63708 L p .707 .577 .707 r
F P
0 g
s
.44029 .63708 m .44515 .59982 L .47237 .60674 L p .707 .577 .707 r
F P
0 g
s
.33689 .65759 m .34047 .67533 L .31681 .68678 L p .707 .577 .707 r
F P
0 g
s
.34863 .62748 m .35349 .59022 L .38265 .59114 L p .707 .577 .707 r
F P
0 g
s
.38265 .59114 m .37779 .62839 L .34863 .62748 L p .707 .577 .707 r
F P
0 g
s
.44515 .59982 m .44029 .63708 L .40937 .6317 L p .707 .577 .707 r
F P
0 g
s
.40937 .6317 m .41423 .59444 L .44515 .59982 L p .707 .577 .707 r
F P
0 g
s
.34047 .67533 m .33689 .65759 L .36578 .64813 L p .707 .577 .707 r
F P
0 g
s
.37779 .62839 m .38265 .59114 L .41423 .59444 L p .707 .577 .707 r
F P
0 g
s
.42768 .63861 m .43126 .65635 L .40064 .65933 L p .707 .577 .707 r
F P
0 g
s
.40064 .65933 m .39706 .64159 L .42768 .63861 L p .707 .577 .707 r
F P
0 g
s
.41423 .59444 m .40937 .6317 L .37779 .62839 L p .707 .577 .707 r
F P
0 g
s
.36578 .64813 m .36935 .66587 L .34047 .67533 L p .707 .577 .707 r
F P
0 g
s
.36935 .66587 m .36578 .64813 L .39706 .64159 L p .707 .577 .707 r
F P
0 g
s
.39706 .64159 m .40064 .65933 L .36935 .66587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001NOol80002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00IWoo001IOol50003FUH00`00FUIJEP02FUH90009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol30000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol3
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80011oo`T004eoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000Yoo`H000AJEP03001JEUYF009JEPT004Aoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000Moo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPH003ioo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003Ool30005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000hOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00=Woo001COol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF008003Aoo`00Dgoo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00031oo`00DWoo00<005YF00000UYF4`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
DWoo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
059oo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60006
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF100015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000]Ool005=oo`800003FUH005YF00AJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300001eYF
001JEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH60008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Eoo`8000EJEPD000=JEP04001JEUYFFUH90005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YF00000`005goo1P001UYF00<005YFFUH00UYF00<005YF
FUH00UYF0P00;Goo001GOol500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90005
FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH2000DOol3000:Ool40002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Qoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000EJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP800003FUH00000019oo`D000eoo`<000AJEP07001J
EUYFFUH005YF0000;Goo001GOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP02FUH30005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0100015YF0`003goo1@0047oo0P00
0UYF00L005YFFUIJEP00FUH0000]Ool005Moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH000000005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001J
EP0000<000]oo`D0019oo`<000=JEP03001JEP0002eoo`00Egoo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH00eYF1`001Goo0`003goo100000=JEP0000000eYF0P00;Woo001@Ool700000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009Ool5
0005FUH00`00FUH00002FUH2000^Ool003mooa4000AJEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH0000D0003FUH00`00FUIJEP04FUH01@00FUIJEP00
FUH00P00;Woo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUH3000^Ool0039oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF
00AJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04
001JEUYFFUH3000^Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0003FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP02FUH3000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00<000EJEP03001JEUYF00=J
EP@000=JEPT000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YF0000;Woo000/Ool3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001EYF
000005YF00001EYF00<005YFFUH01UYF00<005YF00001`0015YF10000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
000015YF000000000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00P0000AJEP00FUH002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH00UYF4@001EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH3000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPL000AJ
EP03001JEUYF00=JEP@00003FUH005YF00EJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00;goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH01P00FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH01000FUIJEUYF
0P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH000020003FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH>0004FUH00`00FUH0000200001EYF000005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEPH000MJEP03
001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP@000MJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEP0000800003FUH005YF0080
0006FUH00000001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF009JEP03001JEP0000D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
009JEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30008FUH00`00
FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH0
0UYF0`001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF100000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00002Ool90004FUH00`00FUIJEP02FUH50004Ool20003FUH01000FUIJEUYF0P00;7oo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001EYF00<005YFFUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Moo`d0
00]oo`800003FUH005YF009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF4P001UYF00<005YF00000`000UYF00@005YFFUIJEPT000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP800004FUH000000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00007Ool5000EOol20003FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH20003FUH01000FUIJEP001EYF
00<005YFFUH015YF5@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000=JEP<00003FUH005YF00=JEP05001JEUYFFUH00007Ool5000GOol0
0`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP06FUH0
1000FUIJEP001EYF00@005YFFUIJEP800003FUH005YF009JEP04001JEUYF0005FUH40006FUH00`00
FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP020005FUH01000FUIJEP0027oo0`00
5goo0`0000=JEP00Ool0;7oo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUH000001EYF00@005YF000000=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH20004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P007Woo0`000eYF
0P00;Goo000]Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01000FUH000001EYF0P001EYF00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH02EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEP0000<00003FUH0000001]oo`<00003FUH0
05YF00=JEP8002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF
3@000UYF00<005YFFUH0300000Eoo`00FUIJEP0000EJEPD000EJEP03001JEUYF00MJEP<000EJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000BOol60004FUH00`00FUIJEP02FUH2000]Ool002io
o`80009JEP03001JEUYF00=JEP03001JEUYF00=JEPP000AJEP03001JEUYF00EJEP03001JEUYF00<0
00=JEP03001JEUYF00D0009oo`04001JEUYF0005FUH40006FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00L005YFFUIJEP00FUH0000]Ool0031oo`D00003FUH0000000H000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30005FUH01000FUH0000025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000;Goo000`Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUH0000200000eYF001JEP05FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF
8000;Woo000]Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00=JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000QJEP04001JEUYFFUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH00eYF00<005YF00000`0000=JEP00FUH025YF00H005YF000005YF000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2P000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000015YF001JEUYF5`001EYF00<005YFFUH01UYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEQ@0009JEP03001oogoo02aoo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000[Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH015YF10002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHL0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00D005YFFUIJEP0000=JEPP000QJEP03001JEP00008000EJEP03001JEUYF00EJEP04001J
EUYFFUH6000bOol002aoo`03001JEP0000=JEP03001JEUYF00=JEPH000EJEP03001JEUYF00IJEP03
001JEUYF00AJEP@00003FUH005YF00L000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/Ool0
0`00FUH00003FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000030004FUH00`00FUH000080004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT003moo`00;7oo00<005YF0000
0UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
00=JEP00FUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT004Qoo`00;7oo00<005YF00000`000UYF
00<005YFFUH00eYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF0`000eYF0`000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEQL0055oo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1P001eYF00<005YFFUH00`000Woo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00AJEP`000aJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00
FUIJEP03FUH01000FUIJEP00Egoo000/Ool40003FUH00`00FUH000030005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF
00<005YFFUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP800003Ool0000000D000=JEP04001JEUYF001GOol002eoo`<000=JEP800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00EJEP03
001oo`00009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00D000IJEP04001JEUYFFUH20008Ool40002FUH00`00Oomoo`1E
Ool002eoo`03001JEP00009JEPP000AJEP03001JEUYF009JEQ8000Ioo`8000IJEP<0009JEP03001J
EUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP@0009JEP04001JEUYFFUH20006Ool20004FUH4001FOol002eoo`03001JEP00
008000Qoo`T001Yoo`8000AJEP<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20004
Ool200000eYF001JEP03FUH01000FUH00000EWoo000]Ool00`00FUH0000_Ool01000FUIJEP000UYF
00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF0080009oo`8000=JEP03001JEUYF
009JEP04001JEP00001FOol002eoo`80035oo`<0009JEP03001JEUYF00800003FUH005YF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF00=JEP03001JEP0005Ioo`00;Goo0P006Goo
0`005goo00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50006FUH00`00FUIJ
EP03FUH00`00FUH0001FOol002eoo`8001Qoo`D001Moo`04001JEP000004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP03FUH2001GOol002eoo`<001Moo`D001Qo
o`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH00UYF
0P00Egoo000]Ool200000eYF001oo`0EOol5000IOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000IJEP03001JEUYF009JEP03001oogoo05Ioo`00;Goo0P000UYF00<007oo
Ool057oo0`006Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0006FUH0
0`00FUIJEP02001IOol002ioo`05001JEUYFFUH0000cOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP04FUH3001KOol002ioo`04001JEUYFFUH3000`
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60006FUH00`00Oomoo`1KOol002moo`04001J
EUYF0002FUH2000]Ool200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJ
EUYF001JEP80009JEP8005ioo`00;goo00<005YF00001EYF0`00:Goo00H005YF001JEP00Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP<005moo`00<7oo0P001UYF00@005YF000002Ioo`03
001JEUYF008000Aoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP05FUH3001LOol0035oo`03001J
EUYF00AJEP04001JEUYFFUH3000QOol20003FUH20006Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP06FUH0
0`00FUH00002001IOol0039oo`8000=JEP03001JEUYF00EJEPD001Qoo`@00003FUH005YF009JEP03
001oogoo00Moo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@00003FUH0000000@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8005Mo
o`00=7oo0P0000=JEP00FUH01eYF00@005YFFUIJEPT000Uoo`H000AJEP03001JEUYF008000eoo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000P000Ioo`@000IJ
EP03001JEUYF00AJEP<005Eoo`00=Woo0`001eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH00eYF0`005Woo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF40002Woo10000UYF
00<005YFFUH015YF00@005YFFUH005Aoo`00>Goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P008goo6P0015YF00<005YFFUH02@003Woo100015YF00D0
05YFFUIJEP0005Aoo`00>goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Qoo`800003FUH005YF00IJEP03001JEUYF00AJEPL0011oo`<00003FUH005YF009J
EP8005=oo`00?Woo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003aoo`<000EJ
EP03001JEUYF00MJEP03001JEUYF009JEPP000]oo`80009JEP03001JEP0005=oo`00A7oo2@0015YF
00<005YFFUH00UYF1@00@Goo100000=JEP00FUH025YF00<005YFFUH01UYF00@005YFFUIJEPh00004
FUH005YF001COol004eoo`T004Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00<005Aoo`00Y7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00E7oo002XOol70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Aoo`00[goo200015YF00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00]goo
4000EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58871 .74323 m .59668 .68736 L .56581 .68166 L p .707 .577 .707 r
F P
0 g
s
.59668 .68736 m .58871 .74323 L .62024 .74692 L p .707 .577 .707 r
F P
0 g
s
.62024 .74692 m .62821 .69106 L .59668 .68736 L p .707 .577 .707 r
F P
0 g
s
.62821 .69106 m .62024 .74692 L .64934 .74824 L p .707 .577 .707 r
F P
0 g
s
.64934 .74824 m .65732 .69238 L .62821 .69106 L p .707 .577 .707 r
F P
0 g
s
.55784 .73752 m .56581 .68166 L .53862 .6745 L p .707 .577 .707 r
F P
0 g
s
.56581 .68166 m .55784 .73752 L .58871 .74323 L p .707 .577 .707 r
F P
0 g
s
.65732 .69238 m .64934 .74824 L .67317 .74706 L p .707 .577 .707 r
F P
0 g
s
.67317 .74706 m .68115 .6912 L .65732 .69238 L p .707 .577 .707 r
F P
0 g
s
.53862 .6745 m .53065 .73036 L .55784 .73752 L p .707 .577 .707 r
F P
0 g
s
.53065 .73036 m .53862 .6745 L .51778 .66659 L p .707 .577 .707 r
F P
0 g
s
.60147 .80283 m .60633 .76557 L .57542 .76019 L p .707 .577 .707 r
F P
0 g
s
.60633 .76557 m .60147 .80283 L .63306 .80614 L p .707 .577 .707 r
F P
0 g
s
.63306 .80614 m .63792 .76889 L .60633 .76557 L p .707 .577 .707 r
F P
0 g
s
.63792 .76889 m .63306 .80614 L .66223 .80707 L p .707 .577 .707 r
F P
0 g
s
.66223 .80707 m .66709 .76981 L .63792 .76889 L p .707 .577 .707 r
F P
0 g
s
.57056 .79745 m .57542 .76019 L .54821 .75326 L p .707 .577 .707 r
F P
0 g
s
.57542 .76019 m .57056 .79745 L .60147 .80283 L p .707 .577 .707 r
F P
0 g
s
.51778 .66659 m .5098 .72245 L .53065 .73036 L p .707 .577 .707 r
F P
0 g
s
.68115 .6912 m .67317 .74706 L .68939 .74349 L p .707 .577 .707 r
F P
0 g
s
.68939 .74349 m .69737 .68763 L .68115 .6912 L p .707 .577 .707 r
F P
0 g
s
.59255 .86086 m .58898 .84312 L .55838 .84606 L p .707 .577 .707 r
F P
0 g
s
.58898 .84312 m .59255 .86086 L .62385 .85437 L p .707 .577 .707 r
F P
0 g
s
.62385 .85437 m .62028 .83662 L .58898 .84312 L p .707 .577 .707 r
F P
0 g
s
.54821 .75326 m .54335 .79052 L .57056 .79745 L p .707 .577 .707 r
F P
0 g
s
.62028 .83662 m .62385 .85437 L .65277 .84495 L p .707 .577 .707 r
F P
0 g
s
.65277 .84495 m .6492 .8272 L .62028 .83662 L p .707 .577 .707 r
F P
0 g
s
.66709 .76981 m .66223 .80707 L .68612 .8055 L p .707 .577 .707 r
F P
0 g
s
.68612 .8055 m .69098 .76825 L .66709 .76981 L p .707 .577 .707 r
F P
0 g
s
.5098 .72245 m .51778 .66659 L .50532 .6587 L p .707 .577 .707 r
F P
0 g
s
.55838 .84606 m .56195 .86381 L .59255 .86086 L p .707 .577 .707 r
F P
0 g
s
.54335 .79052 m .54821 .75326 L .52737 .74547 L p .707 .577 .707 r
F P
0 g
s
.56195 .86381 m .55838 .84606 L .53148 .84516 L p .707 .577 .707 r
F P
0 g
s
.6492 .8272 m .65277 .84495 L .6765 .83353 L p .707 .577 .707 r
F P
0 g
s
.6765 .83353 m .67293 .81578 L .6492 .8272 L p .707 .577 .707 r
F P
0 g
s
.53148 .84516 m .53505 .8629 L .56195 .86381 L p .707 .577 .707 r
F P
0 g
s
.52737 .74547 m .52251 .78273 L .54335 .79052 L p .707 .577 .707 r
F P
0 g
s
.50532 .6587 m .49734 .71456 L .5098 .72245 L p .707 .577 .707 r
F P
0 g
s
.69098 .76825 m .68612 .8055 L .70241 .80161 L p .707 .577 .707 r
F P
0 g
s
.70241 .80161 m .70727 .76435 L .69098 .76825 L p .707 .577 .707 r
F P
0 g
s
.69737 .68763 m .68939 .74349 L .69642 .73789 L p .707 .577 .707 r
F P
0 g
s
.69642 .73789 m .70439 .68203 L .69737 .68763 L p .707 .577 .707 r
F P
0 g
s
.53505 .8629 m .53148 .84516 L .5109 .8405 L p .707 .577 .707 r
F P
0 g
s
.67293 .81578 m .6765 .83353 L .69271 .82123 L p .707 .577 .707 r
F P
0 g
s
.69271 .82123 m .68914 .80348 L .67293 .81578 L p .707 .577 .707 r
F P
0 g
s
.52251 .78273 m .52737 .74547 L .51493 .73758 L p .707 .577 .707 r
F P
0 g
s
.49734 .71456 m .50532 .6587 L .50246 .65161 L p .707 .577 .707 r
F P
0 g
s
.5109 .8405 m .51447 .85824 L .53505 .8629 L p .707 .577 .707 r
F P
0 g
s
.51493 .73758 m .51007 .77484 L .52251 .78273 L p .707 .577 .707 r
F P
0 g
s
.50246 .65161 m .49448 .70747 L .49734 .71456 L p .707 .577 .707 r
F P
0 g
s
.51447 .85824 m .5109 .8405 L .49866 .83254 L p .707 .577 .707 r
F P
0 g
s
.70727 .76435 m .70241 .80161 L .70949 .79577 L p .707 .577 .707 r
F P
0 g
s
.70949 .79577 m .71435 .75851 L .70727 .76435 L p .707 .577 .707 r
F P
0 g
s
.68914 .80348 m .69271 .82123 L .69981 .80925 L p .707 .577 .707 r
F P
0 g
s
.69981 .80925 m .69624 .7915 L .68914 .80348 L p .707 .577 .707 r
F P
0 g
s
.70439 .68203 m .69642 .73789 L .69356 .73079 L p .707 .577 .707 r
F P
0 g
s
.69356 .73079 m .70154 .67493 L .70439 .68203 L p .707 .577 .707 r
F P
0 g
s
.49866 .83254 m .50223 .85028 L .51447 .85824 L p .707 .577 .707 r
F P
0 g
s
.51007 .77484 m .51493 .73758 L .51211 .73036 L p .707 .577 .707 r
F P
0 g
s
.49224 .82187 m .49224 .31998 L .44811 .31744 L p .707 .577 .707 r
F P
0 g
s
.49448 .70747 m .50246 .65161 L .50948 .646 L p .707 .577 .707 r
F P
0 g
s
.51211 .73036 m .50725 .76762 L .51007 .77484 L p .707 .577 .707 r
F P
0 g
s
.50948 .646 m .50151 .70186 L .49448 .70747 L p .707 .577 .707 r
F P
0 g
s
.50725 .76762 m .51211 .73036 L .51919 .72452 L p .707 .577 .707 r
F P
0 g
s
.50151 .70186 m .50948 .646 L .52571 .64243 L p .707 .577 .707 r
F P
0 g
s
.51919 .72452 m .51434 .76178 L .50725 .76762 L p .707 .577 .707 r
F P
0 g
s
.52571 .64243 m .51773 .6983 L .50151 .70186 L p .707 .577 .707 r
F P
0 g
s
.50223 .85028 m .49866 .83254 L .49595 .82205 L p .707 .578 .707 r
F P
0 g
s
.49595 .82205 m .49953 .8398 L .50223 .85028 L p .707 .578 .707 r
F P
0 g
s
.49953 .8398 m .49595 .82205 L .50306 .81008 L p .707 .577 .707 r
F P
0 g
s
.50306 .81008 m .50663 .82782 L .49953 .8398 L p .707 .577 .707 r
F P
0 g
s
.51434 .76178 m .51919 .72452 L .53548 .72063 L p .707 .577 .707 r
F P
0 g
s
.51773 .6983 m .52571 .64243 L .54953 .64125 L p .707 .577 .707 r
F P
0 g
s
.53548 .72063 m .53062 .75789 L .51434 .76178 L p .707 .577 .707 r
F P
0 g
s
.54953 .64125 m .54156 .69711 L .51773 .6983 L p .707 .577 .707 r
F P
0 g
s
.50663 .82782 m .50306 .81008 L .51926 .79778 L p .707 .577 .707 r
F P
0 g
s
.51926 .79778 m .52284 .81552 L .50663 .82782 L p .707 .577 .707 r
F P
0 g
s
.53062 .75789 m .53548 .72063 L .55938 .71907 L p .707 .577 .707 r
F P
0 g
s
.55938 .71907 m .55452 .75633 L .53062 .75789 L p .707 .577 .707 r
F P
0 g
s
.52284 .81552 m .51926 .79778 L .54299 .78636 L p .707 .577 .707 r
F P
0 g
s
.54299 .78636 m .54657 .8041 L .52284 .81552 L p .707 .577 .707 r
F P
0 g
s
.49224 .31998 m .49224 .82187 L .53713 .82062 L p .707 .577 .707 r
F P
0 g
s
.53713 .82062 m .53713 .31873 L .49224 .31998 L p .707 .577 .707 r
F P
0 g
s
.54156 .69711 m .54953 .64125 L .57864 .64257 L p .707 .577 .707 r
F P
0 g
s
.57864 .64257 m .57066 .69844 L .54156 .69711 L p .707 .577 .707 r
F P
0 g
s
.55452 .75633 m .55938 .71907 L .58855 .71999 L p .707 .577 .707 r
F P
0 g
s
.58855 .71999 m .58369 .75725 L .55452 .75633 L p .707 .577 .707 r
F P
0 g
s
.54657 .8041 m .54299 .78636 L .57192 .77694 L p .707 .577 .707 r
F P
0 g
s
.57192 .77694 m .57549 .79468 L .54657 .8041 L p .707 .577 .707 r
F P
0 g
s
.57549 .79468 m .57192 .77694 L .60322 .77044 L p .707 .577 .707 r
F P
0 g
s
.60322 .77044 m .60679 .78818 L .57549 .79468 L p .707 .577 .707 r
F P
0 g
s
.53713 .31873 m .53713 .82062 L .57839 .81571 L p .707 .577 .707 r
F P
0 g
s
.57066 .69844 m .57864 .64257 L .61017 .64627 L p .707 .577 .707 r
F P
0 g
s
.61017 .64627 m .60219 .70213 L .57066 .69844 L p .707 .577 .707 r
F P
0 g
s
.57839 .81571 m .57839 .31382 L .53713 .31873 L p .707 .577 .707 r
F P
0 g
s
.44811 .81933 m .44811 .31744 L .40906 .31137 L p .707 .577 .707 r
F P
0 g
s
.44811 .31744 m .44811 .81933 L .49224 .82187 L p .707 .577 .707 r
F P
0 g
s
.71435 .75851 m .70949 .79577 L .70668 .78855 L p .707 .577 .707 r
F P
0 g
s
.70668 .78855 m .71154 .75129 L .71435 .75851 L p .707 .577 .707 r
F P
0 g
s
.69624 .7915 m .69981 .80925 L .69711 .79877 L p .707 .578 .707 r
F P
0 g
s
.69711 .79877 m .69354 .78102 L .69624 .7915 L p .707 .578 .707 r
F P
0 g
s
.64104 .65197 m .63307 .70784 L .60219 .70213 L p .707 .577 .707 r
F P
0 g
s
.60219 .70213 m .61017 .64627 L .64104 .65197 L p .707 .577 .707 r
F P
0 g
s
.58369 .75725 m .58855 .71999 L .62013 .7233 L p .707 .577 .707 r
F P
0 g
s
.63382 .7675 m .63739 .78524 L .60679 .78818 L p .707 .577 .707 r
F P
0 g
s
.60679 .78818 m .60322 .77044 L .63382 .7675 L p .707 .577 .707 r
F P
0 g
s
.62013 .7233 m .61528 .76056 L .58369 .75725 L p .707 .577 .707 r
F P
0 g
s
.57839 .31382 m .57839 .81571 L .61197 .80762 L p .707 .577 .707 r
F P
0 g
s
.61197 .80762 m .61197 .30573 L .57839 .31382 L p .707 .577 .707 r
F P
0 g
s
.70154 .67493 m .69356 .73079 L .6811 .72291 L p .707 .577 .707 r
F P
0 g
s
.6811 .72291 m .68907 .66704 L .70154 .67493 L p .707 .577 .707 r
F P
0 g
s
.40906 .81326 m .40906 .31137 L .37891 .30236 L p .707 .577 .707 r
F P
0 g
s
.40906 .31137 m .40906 .81326 L .44811 .81933 L p .707 .577 .707 r
F P
0 g
s
.25021 .72331 m .25365 .67049 L .22251 .666 L p .707 .577 .707 r
F P
0 g
s
.25365 .67049 m .25021 .72331 L .28198 .72386 L p .707 .577 .707 r
F P
0 g
s
.28198 .72386 m .28542 .67104 L .25365 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28542 .67104 m .28198 .72386 L .31128 .72041 L p .707 .577 .707 r
F P
0 g
s
.31128 .72041 m .31471 .66759 L .28542 .67104 L p .707 .577 .707 r
F P
0 g
s
.21907 .71882 m .22251 .666 L .19506 .658 L p .707 .577 .707 r
F P
0 g
s
.22251 .666 m .21907 .71882 L .25021 .72331 L p .707 .577 .707 r
F P
0 g
s
.25555 .78619 m .25765 .75079 L .22651 .74649 L p .707 .577 .707 r
F P
0 g
s
.25765 .75079 m .25555 .78619 L .28734 .78665 L p .707 .577 .707 r
F P
0 g
s
.28734 .78665 m .28943 .75125 L .25765 .75079 L p .707 .577 .707 r
F P
0 g
s
.69354 .78102 m .69711 .79877 L .68487 .7908 L p .707 .577 .707 r
F P
0 g
s
.68487 .7908 m .6813 .77306 L .69354 .78102 L p .707 .577 .707 r
F P
0 g
s
.71154 .75129 m .70668 .78855 L .69424 .78066 L p .707 .577 .707 r
F P
0 g
s
.69424 .78066 m .6991 .7434 L .71154 .75129 L p .707 .577 .707 r
F P
0 g
s
.28943 .75125 m .28734 .78665 L .31667 .78323 L p .707 .577 .707 r
F P
0 g
s
.31667 .78323 m .31876 .74783 L .28943 .75125 L p .707 .577 .707 r
F P
0 g
s
.31471 .66759 m .31128 .72041 L .33523 .7133 L p .707 .577 .707 r
F P
0 g
s
.33523 .7133 m .33867 .66048 L .31471 .66759 L p .707 .577 .707 r
F P
0 g
s
.65104 .72869 m .64619 .76595 L .61528 .76056 L p .707 .577 .707 r
F P
0 g
s
.61528 .76056 m .62013 .7233 L .65104 .72869 L p .707 .577 .707 r
F P
0 g
s
.61197 .30573 m .61197 .80762 L .63459 .79714 L p .707 .577 .707 r
F P
0 g
s
.66823 .65913 m .66025 .71499 L .63307 .70784 L p .707 .577 .707 r
F P
0 g
s
.63307 .70784 m .64104 .65197 L .66823 .65913 L p .707 .577 .707 r
F P
0 g
s
.63739 .78524 m .63382 .7675 L .66072 .7684 L p .707 .577 .707 r
F P
0 g
s
.63459 .79714 m .63459 .29525 L .61197 .30573 L p .707 .577 .707 r
F P
0 g
s
.22442 .78189 m .22651 .74649 L .19908 .73877 L p .707 .577 .707 r
F P
0 g
s
.22651 .74649 m .22442 .78189 L .25555 .78619 L p .707 .577 .707 r
F P
0 g
s
.68907 .66704 m .6811 .72291 L .66025 .71499 L p .707 .577 .707 r
F P
0 g
s
.66025 .71499 m .66823 .65913 L .68907 .66704 L p .707 .577 .707 r
F P
0 g
s
.19162 .71082 m .19506 .658 L .17397 .64728 L p .707 .577 .707 r
F P
0 g
s
.19506 .658 m .19162 .71082 L .21907 .71882 L p .707 .577 .707 r
F P
0 g
s
.31876 .74783 m .31667 .78323 L .34067 .77626 L p .707 .577 .707 r
F P
0 g
s
.34067 .77626 m .34276 .74086 L .31876 .74783 L p .707 .577 .707 r
F P
0 g
s
.37891 .80425 m .37891 .30236 L .36061 .29129 L p .707 .577 .707 r
F P
0 g
s
.37891 .30236 m .37891 .80425 L .40906 .81326 L p .707 .577 .707 r
F P
0 g
s
.19699 .77417 m .19908 .73877 L .17804 .72839 L p .707 .577 .707 r
F P
0 g
s
.19908 .73877 m .19699 .77417 L .22442 .78189 L p .707 .577 .707 r
F P
0 g
s
.33867 .66048 m .33523 .7133 L .35149 .70323 L p .707 .577 .707 r
F P
0 g
s
.35149 .70323 m .35493 .65041 L .33867 .66048 L p .707 .577 .707 r
F P
0 g
s
.25188 .79563 m .25033 .77653 L .21925 .77843 L p .707 .577 .707 r
F P
0 g
s
.25033 .77653 m .25188 .79563 L .28361 .79284 L p .707 .577 .707 r
F P
0 g
s
.28361 .79284 m .28206 .77373 L .25033 .77653 L p .707 .577 .707 r
F P
0 g
s
.21925 .77843 m .2208 .79753 L .25188 .79563 L p .707 .577 .707 r
F P
0 g
s
.28206 .77373 m .28361 .79284 L .31288 .78942 L p .707 .577 .707 r
F P
0 g
s
.31288 .78942 m .31134 .77031 L .28206 .77373 L p .707 .577 .707 r
F P
0 g
s
.17053 .7001 m .17397 .64728 L .16132 .63489 L p .707 .577 .707 r
F P
0 g
s
.17397 .64728 m .17053 .7001 L .19162 .71082 L p .707 .577 .707 r
F P
0 g
s
.6813 .77306 m .68487 .7908 L .66429 .78614 L p .707 .577 .707 r
F P
0 g
s
.66429 .78614 m .66072 .7684 L .6813 .77306 L p .707 .577 .707 r
F P
0 g
s
.6991 .7434 m .69424 .78066 L .67339 .77287 L p .707 .577 .707 r
F P
0 g
s
.67339 .77287 m .67825 .73561 L .6991 .7434 L p .707 .577 .707 r
F P
0 g
s
.2208 .79753 m .21925 .77843 L .19187 .77924 L p .707 .577 .707 r
F P
0 g
s
.19187 .77924 m .19341 .79834 L .2208 .79753 L p .707 .577 .707 r
F P
0 g
s
.17804 .72839 m .17595 .76379 L .19699 .77417 L p .707 .577 .707 r
F P
0 g
s
.34276 .74086 m .34067 .77626 L .35699 .76642 L p .707 .577 .707 r
F P
0 g
s
.35699 .76642 m .35908 .73102 L .34276 .74086 L p .707 .577 .707 r
F P
0 g
s
.31134 .77031 m .31288 .78942 L .33683 .78571 L p .707 .577 .707 r
F P
0 g
s
.33683 .78571 m .33529 .76661 L .31134 .77031 L p .707 .577 .707 r
F P
0 g
s
.66072 .7684 m .66429 .78614 L .63739 .78524 L p .707 .577 .707 r
F P
0 g
s
.63459 .29525 m .63459 .79714 L .64404 .7853 L p .707 .577 .707 r
F P
0 g
s
.64404 .7853 m .64404 .28341 L .63459 .29525 L p .707 .577 .707 r
F P
0 g
s
.17595 .76379 m .17804 .72839 L .16544 .71637 L p .707 .577 .707 r
F P
0 g
s
.35493 .65041 m .35149 .70323 L .35848 .69117 L p .707 .577 .707 r
F P
0 g
s
.35848 .69117 m .36191 .63835 L .35493 .65041 L p .707 .577 .707 r
F P
0 g
s
.19341 .79834 m .19187 .77924 L .17085 .77889 L p .707 .577 .707 r
F P
0 g
s
.17085 .77889 m .1724 .798 L .19341 .79834 L p .707 .577 .707 r
F P
0 g
s
.16132 .63489 m .15788 .68771 L .17053 .7001 L p .707 .577 .707 r
F P
0 g
s
.67825 .73561 m .67339 .77287 L .64619 .76595 L p .707 .577 .707 r
F P
0 g
s
.64619 .76595 m .65104 .72869 L .67825 .73561 L p .707 .577 .707 r
F P
0 g
s
.35908 .73102 m .35699 .76642 L .36404 .75469 L p .707 .577 .707 r
F P
0 g
s
.36404 .75469 m .36613 .71928 L .35908 .73102 L p .707 .577 .707 r
F P
0 g
s
.36191 .63835 m .35848 .69117 L .3555 .67832 L p .707 .577 .707 r
F P
0 g
s
.3555 .67832 m .35893 .6255 L .36191 .63835 L p .707 .577 .707 r
F P
0 g
s
.36321 .70679 m .36112 .74219 L .34852 .73017 L p .707 .577 .707 r
F P
0 g
s
.34852 .73017 m .35061 .69477 L .36321 .70679 L p .707 .577 .707 r
F P
0 g
s
.36061 .79318 m .36061 .29129 L .35596 .27925 L p .707 .577 .707 r
F P
0 g
s
.36613 .71928 m .36404 .75469 L .36112 .74219 L p .707 .577 .707 r
F P
0 g
s
.36112 .74219 m .36321 .70679 L .36613 .71928 L p .707 .577 .707 r
F P
0 g
s
.36061 .29129 m .36061 .79318 L .37891 .80425 L p .707 .577 .707 r
F P
0 g
s
.15788 .68771 m .16132 .63489 L .15834 .62203 L p .707 .577 .707 r
F P
0 g
s
.16544 .71637 m .16335 .75177 L .17595 .76379 L p .707 .577 .707 r
F P
0 g
s
.33529 .76661 m .33683 .78571 L .35312 .78207 L p .707 .577 .707 r
F P
0 g
s
.35312 .78207 m .35157 .76297 L .33529 .76661 L p .707 .577 .707 r
F P
0 g
s
.16335 .75177 m .16544 .71637 L .16252 .70388 L p .707 .577 .707 r
F P
0 g
s
.1724 .798 m .17085 .77889 L .15827 .77742 L p .707 .577 .707 r
F P
0 g
s
.15827 .77742 m .15981 .79652 L .1724 .798 L p .707 .577 .707 r
F P
0 g
s
.15834 .62203 m .1549 .67486 L .15788 .68771 L p .707 .577 .707 r
F P
0 g
s
.16252 .70388 m .16043 .73928 L .16335 .75177 L p .707 .577 .707 r
F P
0 g
s
.64404 .28341 m .64404 .7853 L .63938 .77325 L p .707 .577 .707 r
F P
0 g
s
.63938 .77325 m .63938 .27137 L .64404 .28341 L p .707 .577 .707 r
F P
0 g
s
.1549 .67486 m .15834 .62203 L .16532 .60998 L p .707 .577 .707 r
F P
0 g
s
.35157 .76297 m .35312 .78207 L .36014 .77887 L p .707 .577 .707 r
F P
0 g
s
.36014 .77887 m .3586 .75977 L .35157 .76297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16043 .73928 m .16252 .70388 L .16957 .69214 L p .707 .577 .707 r
F P
0 g
s
.35893 .6255 m .3555 .67832 L .34284 .66593 L p .707 .577 .707 r
F P
0 g
s
.34284 .66593 m .34628 .61311 L .35893 .6255 L p .707 .577 .707 r
F P
0 g
s
.3586 .75977 m .36014 .77887 L .35722 .77641 L p .707 .577 .707 r
F P
0 g
s
.35722 .77641 m .35567 .75731 L .3586 .75977 L p .707 .577 .707 r
F P
0 g
s
.35567 .75731 m .35722 .77641 L .34463 .77493 L p .707 .577 .707 r
F P
0 g
s
.35596 .27925 m .35596 .78114 L .36061 .79318 L p .707 .577 .707 r
F P
0 g
s
.35596 .78114 m .35596 .27925 L .36541 .26741 L p .707 .577 .707 r
F P
0 g
s
.15981 .79652 m .15827 .77742 L .15534 .77496 L p .707 .577 .707 r
F P
0 g
s
.15534 .77496 m .15689 .79406 L .15981 .79652 L p .707 .577 .707 r
F P
0 g
s
.16532 .60998 m .16189 .6628 L .1549 .67486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16957 .69214 m .16748 .72754 L .16043 .73928 L p .707 .577 .707 r
F P
0 g
s
.16189 .6628 m .16532 .60998 L .18159 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16748 .72754 m .16957 .69214 L .18589 .6823 L p .707 .577 .707 r
F P
0 g
s
.63938 .27137 m .63938 .77325 L .62109 .76219 L p .707 .577 .707 r
F P
0 g
s
.62109 .76219 m .62109 .2603 L .63938 .27137 L p .707 .577 .707 r
F P
0 g
s
.34628 .61311 m .34284 .66593 L .32176 .65521 L p .707 .577 .707 r
F P
0 g
s
.32176 .65521 m .3252 .60239 L .34628 .61311 L p .707 .577 .707 r
F P
0 g
s
.15689 .79406 m .15534 .77496 L .16237 .77175 L p .707 .577 .707 r
F P
0 g
s
.16237 .77175 m .16391 .79085 L .15689 .79406 L p .707 .577 .707 r
F P
0 g
s
.18159 .59991 m .17815 .65273 L .16189 .6628 L p .707 .577 .707 r
F P
0 g
s
.17815 .65273 m .18159 .59991 L .20554 .5928 L p .707 .577 .707 r
F P
0 g
s
.36541 .7693 m .36541 .26741 L .38803 .25693 L p .707 .577 .707 r
F P
0 g
s
.36541 .26741 m .36541 .7693 L .35596 .78114 L p .707 .577 .707 r
F P
0 g
s
.18589 .6823 m .1838 .7177 L .16748 .72754 L p .707 .577 .707 r
F P
0 g
s
.35061 .69477 m .34852 .73017 L .32748 .71979 L p .707 .577 .707 r
F P
0 g
s
.32748 .71979 m .32957 .68439 L .35061 .69477 L p .707 .577 .707 r
F P
0 g
s
.34463 .77493 m .34309 .75583 L .35567 .75731 L p .707 .577 .707 r
F P
0 g
s
.1838 .7177 m .18589 .6823 L .20989 .67533 L p .707 .577 .707 r
F P
0 g
s
.3252 .60239 m .32176 .65521 L .2943 .64721 L p .707 .577 .707 r
F P
0 g
s
.2943 .64721 m .29774 .59439 L .3252 .60239 L p .707 .577 .707 r
F P
0 g
s
.2021 .64562 m .20554 .5928 L .23483 .58935 L p .707 .577 .707 r
F P
0 g
s
.20554 .5928 m .2021 .64562 L .17815 .65273 L p .707 .577 .707 r
F P
0 g
s
.16391 .79085 m .16237 .77175 L .17865 .76812 L p .707 .577 .707 r
F P
0 g
s
.62109 .2603 m .62109 .76219 L .59094 .75317 L p .707 .577 .707 r
F P
0 g
s
.59094 .75317 m .59094 .25128 L .62109 .2603 L p .707 .577 .707 r
F P
0 g
s
.17865 .76812 m .1802 .78722 L .16391 .79085 L p .707 .577 .707 r
F P
0 g
s
.20989 .67533 m .2078 .71073 L .1838 .7177 L p .707 .577 .707 r
F P
0 g
s
.32957 .68439 m .32748 .71979 L .30004 .71207 L p .707 .577 .707 r
F P
0 g
s
.30004 .71207 m .30214 .67667 L .32957 .68439 L p .707 .577 .707 r
F P
0 g
s
.29774 .59439 m .2943 .64721 L .26317 .64272 L p .707 .577 .707 r
F P
0 g
s
.26317 .64272 m .26661 .5899 L .29774 .59439 L p .707 .577 .707 r
F P
0 g
s
.2314 .64217 m .23483 .58935 L .26661 .5899 L p .707 .577 .707 r
F P
0 g
s
.23483 .58935 m .2314 .64217 L .2021 .64562 L p .707 .577 .707 r
F P
0 g
s
.2078 .71073 m .20989 .67533 L .23922 .67191 L p .707 .577 .707 r
F P
0 g
s
.26661 .5899 m .26317 .64272 L .2314 .64217 L p .707 .577 .707 r
F P
0 g
s
.38803 .25693 m .38803 .75882 L .36541 .7693 L p .707 .577 .707 r
F P
0 g
s
.38803 .75882 m .38803 .25693 L .42161 .24884 L p .707 .577 .707 r
F P
0 g
s
.73683 .64571 m .73339 .58863 L .70226 .58954 L p .707 .577 .707 r
F P
0 g
s
.73339 .58863 m .73683 .64571 L .7686 .64344 L p .707 .577 .707 r
F P
0 g
s
.7686 .64344 m .76516 .58635 L .73339 .58863 L p .707 .577 .707 r
F P
0 g
s
.34309 .75583 m .34463 .77493 L .32362 .77458 L p .707 .577 .707 r
F P
0 g
s
.32362 .77458 m .32207 .75548 L .34309 .75583 L p .707 .577 .707 r
F P
0 g
s
.30214 .67667 m .30004 .71207 L .26891 .70777 L p .707 .577 .707 r
F P
0 g
s
.26891 .70777 m .271 .67237 L .30214 .67667 L p .707 .577 .707 r
F P
0 g
s
.76516 .58635 m .7686 .64344 L .7979 .64002 L p .707 .577 .707 r
F P
0 g
s
.7979 .64002 m .79446 .58293 L .76516 .58635 L p .707 .577 .707 r
F P
0 g
s
.23713 .70731 m .23922 .67191 L .271 .67237 L p .707 .577 .707 r
F P
0 g
s
.23922 .67191 m .23713 .70731 L .2078 .71073 L p .707 .577 .707 r
F P
0 g
s
.70569 .64663 m .70226 .58954 L .6748 .589 L p .707 .577 .707 r
F P
0 g
s
.70226 .58954 m .70569 .64663 L .73683 .64571 L p .707 .577 .707 r
F P
0 g
s
.271 .67237 m .26891 .70777 L .23713 .70731 L p .707 .577 .707 r
F P
0 g
s
.1802 .78722 m .17865 .76812 L .2026 .76441 L p .707 .577 .707 r
F P
0 g
s
.2026 .76441 m .20415 .78351 L .1802 .78722 L p .707 .577 .707 r
F P
0 g
s
.6748 .589 m .67824 .64609 L .70569 .64663 L p .707 .577 .707 r
F P
0 g
s
.79446 .58293 m .7979 .64002 L .82185 .6358 L p .707 .577 .707 r
F P
0 g
s
.82185 .6358 m .81841 .57871 L .79446 .58293 L p .707 .577 .707 r
F P
0 g
s
.59094 .25128 m .59094 .75317 L .55189 .7471 L p .707 .577 .707 r
F P
0 g
s
.55189 .7471 m .55189 .24521 L .59094 .25128 L p .707 .577 .707 r
F P
0 g
s
.67824 .64609 m .6748 .589 L .65372 .58706 L p .707 .577 .707 r
F P
0 g
s
.32207 .75548 m .32362 .77458 L .29623 .7754 L p .707 .577 .707 r
F P
0 g
s
.29623 .7754 m .29469 .7563 L .32207 .75548 L p .707 .577 .707 r
F P
0 g
s
.42161 .75073 m .42161 .24884 L .46287 .24393 L p .707 .577 .707 r
F P
0 g
s
.42161 .24884 m .42161 .75073 L .38803 .75882 L p .707 .577 .707 r
F P
0 g
s
.65372 .58706 m .65715 .64414 L .67824 .64609 L p .707 .577 .707 r
F P
0 g
s
.73109 .70391 m .72899 .66591 L .69786 .66656 L p .707 .577 .707 r
F P
0 g
s
.72899 .66591 m .73109 .70391 L .76287 .70178 L p .707 .577 .707 r
F P
0 g
s
.76287 .70178 m .76078 .66377 L .72899 .66591 L p .707 .577 .707 r
F P
0 g
s
.20415 .78351 m .2026 .76441 L .23188 .76099 L p .707 .577 .707 r
F P
0 g
s
.76078 .66377 m .76287 .70178 L .7922 .69837 L p .707 .577 .707 r
F P
0 g
s
.7922 .69837 m .79011 .66037 L .76078 .66377 L p .707 .577 .707 r
F P
0 g
s
.23188 .76099 m .23342 .78009 L .20415 .78351 L p .707 .577 .707 r
F P
0 g
s
.81841 .57871 m .82185 .6358 L .83811 .63118 L p .707 .577 .707 r
F P
0 g
s
.83811 .63118 m .83467 .57409 L .81841 .57871 L p .707 .577 .707 r
F P
0 g
s
.69786 .66656 m .69995 .70457 L .73109 .70391 L p .707 .577 .707 r
F P
0 g
s
.69995 .70457 m .69786 .66656 L .67043 .66568 L p .707 .577 .707 r
F P
0 g
s
.73485 .77762 m .73639 .76043 L .70531 .75507 L p .707 .577 .707 r
F P
0 g
s
.73639 .76043 m .73485 .77762 L .76658 .77862 L p .707 .577 .707 r
F P
0 g
s
.76658 .77862 m .76812 .76143 L .73639 .76043 L p .707 .577 .707 r
F P
0 g
s
.55189 .24521 m .55189 .7471 L .50776 .74457 L p .707 .577 .707 r
F P
0 g
s
.50776 .74457 m .50776 .24268 L .55189 .24521 L p .707 .577 .707 r
F P
0 g
s
.29469 .7563 m .29623 .7754 L .26515 .7773 L p .707 .577 .707 r
F P
0 g
s
.26515 .7773 m .26361 .75819 L .29469 .7563 L p .707 .577 .707 r
F P
0 g
s
.67043 .66568 m .67252 .70369 L .69995 .70457 L p .707 .577 .707 r
F P
0 g
s
.76812 .76143 m .76658 .77862 L .79585 .77515 L p .707 .577 .707 r
F P
0 g
s
.79585 .77515 m .79739 .75796 L .76812 .76143 L p .707 .577 .707 r
F P
0 g
s
.46287 .74582 m .46287 .24393 L .50776 .24268 L p .707 .577 .707 r
F P
0 g
s
.46287 .24393 m .46287 .74582 L .42161 .75073 L p .707 .577 .707 r
F P
0 g
s
.70377 .77226 m .70531 .75507 L .67792 .74586 L p .707 .577 .707 r
F P
0 g
s
.70531 .75507 m .70377 .77226 L .73485 .77762 L p .707 .577 .707 r
F P
0 g
s
.23342 .78009 m .23188 .76099 L .26361 .75819 L p .707 .577 .707 r
F P
0 g
s
.79011 .66037 m .7922 .69837 L .8162 .69403 L p .707 .577 .707 r
F P
0 g
s
.8162 .69403 m .81411 .65603 L .79011 .66037 L p .707 .577 .707 r
F P
0 g
s
.65715 .64414 m .65372 .58706 L .64106 .58391 L p .707 .577 .707 r
F P
0 g
s
.26361 .75819 m .26515 .7773 L .23342 .78009 L p .707 .577 .707 r
F P
0 g
s
.50776 .24268 m .50776 .74457 L .46287 .74582 L p .707 .577 .707 r
F P
0 g
s
.67792 .74586 m .67638 .76305 L .70377 .77226 L p .707 .577 .707 r
F P
0 g
s
.64106 .58391 m .6445 .64099 L .65715 .64414 L p .707 .577 .707 r
F P
0 g
s
.67252 .70369 m .67043 .66568 L .64939 .66334 L p .707 .577 .707 r
F P
0 g
s
.79739 .75796 m .79585 .77515 L .8198 .76754 L p .707 .577 .707 r
F P
0 g
s
.8198 .76754 m .82135 .75035 L .79739 .75796 L p .707 .577 .707 r
F P
0 g
s
.67638 .76305 m .67792 .74586 L .65691 .73371 L p .707 .577 .707 r
F P
0 g
s
.64939 .66334 m .65148 .70135 L .67252 .70369 L p .707 .577 .707 r
F P
0 g
s
.83467 .57409 m .83811 .63118 L .8451 .62662 L p .707 .577 .707 r
F P
0 g
s
.8451 .62662 m .84166 .56954 L .83467 .57409 L p .707 .577 .707 r
F P
0 g
s
.81411 .65603 m .8162 .69403 L .83252 .68919 L p .707 .577 .707 r
F P
0 g
s
.83252 .68919 m .83043 .65118 L .81411 .65603 L p .707 .577 .707 r
F P
0 g
s
.65691 .73371 m .65536 .7509 L .67638 .76305 L p .707 .577 .707 r
F P
0 g
s
.6445 .64099 m .64106 .58391 L .63808 .57986 L p .707 .577 .707 r
F P
0 g
s
.82135 .75035 m .8198 .76754 L .83609 .75656 L p .707 .577 .707 r
F P
0 g
s
.83609 .75656 m .83763 .73937 L .82135 .75035 L p .707 .577 .707 r
F P
0 g
s
.65148 .70135 m .64939 .66334 L .63679 .65978 L p .707 .577 .707 r
F P
0 g
s
.65536 .7509 m .65691 .73371 L .64432 .7198 L p .707 .577 .707 r
F P
0 g
s
.63808 .57986 m .64152 .63694 L .6445 .64099 L p .707 .577 .707 r
F P
0 g
s
.63679 .65978 m .63888 .69778 L .65148 .70135 L p .707 .577 .707 r
F P
0 g
s
.64432 .7198 m .64278 .73699 L .65536 .7509 L p .707 .577 .707 r
F P
0 g
s
.84166 .56954 m .8451 .62662 L .84212 .62257 L p .707 .577 .707 r
F P
0 g
s
.84212 .62257 m .83868 .56549 L .84166 .56954 L p .707 .577 .707 r
F P
0 g
s
.83043 .65118 m .83252 .68919 L .83957 .6843 L p .707 .577 .707 r
F P
0 g
s
.83957 .6843 m .83748 .64629 L .83043 .65118 L p .707 .577 .707 r
F P
0 g
s
.83763 .73937 m .83609 .75656 L .84311 .74327 L p .707 .577 .707 r
F P
0 g
s
.84311 .74327 m .84466 .72608 L .83763 .73937 L p .707 .577 .707 r
F P
0 g
s
.64278 .73699 m .64432 .7198 L .6414 .7055 L p .707 .577 .707 r
F P
0 g
s
.64152 .63694 m .63808 .57986 L .64507 .5753 L p .707 .577 .707 r
F P
0 g
s
.63888 .69778 m .63679 .65978 L .63387 .65533 L p .707 .577 .707 r
F P
0 g
s
.63387 .65533 m .63596 .69334 L .63888 .69778 L p .707 .577 .707 r
F P
0 g
s
.6414 .7055 m .63986 .72269 L .64278 .73699 L p .707 .577 .707 r
F P
0 g
s
.64507 .5753 m .64851 .63239 L .64152 .63694 L p .707 .577 .707 r
F P
0 g
s
.83748 .64629 m .83957 .6843 L .83665 .67986 L p .707 .577 .707 r
F P
0 g
s
.83665 .67986 m .83456 .64185 L .83748 .64629 L p .707 .577 .707 r
F P
0 g
s
.83868 .56549 m .84212 .62257 L .82946 .61942 L p .707 .577 .707 r
F P
0 g
s
.82946 .61942 m .82603 .56233 L .83868 .56549 L p .707 .577 .707 r
F P
0 g
s
.84466 .72608 m .84311 .74327 L .84019 .72897 L p .707 .577 .707 r
F P
0 g
s
.84019 .72897 m .84173 .71178 L .84466 .72608 L p .707 .577 .707 r
F P
0 g
s
.63986 .72269 m .6414 .7055 L .64843 .6922 L p .707 .577 .707 r
F P
0 g
s
.3978 .62615 m .38983 .57211 L .35896 .57388 L p .707 .577 .707 r
F P
0 g
s
.38983 .57211 m .3978 .62615 L .42933 .62105 L p .707 .577 .707 r
F P
0 g
s
.42933 .62105 m .42136 .56701 L .38983 .57211 L p .707 .577 .707 r
F P
0 g
s
.42136 .56701 m .42933 .62105 L .45844 .61312 L p .707 .577 .707 r
F P
0 g
s
.45844 .61312 m .45046 .55908 L .42136 .56701 L p .707 .577 .707 r
F P
0 g
s
.64851 .63239 m .64507 .5753 L .66133 .57068 L p .707 .577 .707 r
F P
0 g
s
.63596 .69334 m .63387 .65533 L .64092 .65045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64843 .6922 m .64688 .70939 L .63986 .72269 L p .707 .577 .707 r
F P
0 g
s
.36693 .62792 m .35896 .57388 L .33177 .57214 L p .707 .577 .707 r
F P
0 g
s
.35896 .57388 m .36693 .62792 L .3978 .62615 L p .707 .577 .707 r
F P
0 g
s
.64092 .65045 m .64301 .68845 L .63596 .69334 L p .707 .577 .707 r
F P
0 g
s
.66133 .57068 m .66477 .62777 L .64851 .63239 L p .707 .577 .707 r
F P
0 g
s
.45046 .55908 m .45844 .61312 L .48227 .60313 L p .707 .577 .707 r
F P
0 g
s
.48227 .60313 m .47429 .54909 L .45046 .55908 L p .707 .577 .707 r
F P
0 g
s
.38472 .68757 m .37986 .65142 L .34895 .65286 L p .707 .577 .707 r
F P
0 g
s
.37986 .65142 m .38472 .68757 L .41631 .68285 L p .707 .577 .707 r
F P
0 g
s
.41631 .68285 m .41145 .6467 L .37986 .65142 L p .707 .577 .707 r
F P
0 g
s
.82603 .56233 m .82946 .61942 L .80838 .61748 L p .707 .577 .707 r
F P
0 g
s
.80838 .61748 m .80494 .56039 L .82603 .56233 L p .707 .577 .707 r
F P
0 g
s
.41145 .6467 m .41631 .68285 L .44548 .67532 L p .707 .577 .707 r
F P
0 g
s
.44548 .67532 m .44062 .63917 L .41145 .6467 L p .707 .577 .707 r
F P
0 g
s
.83456 .64185 m .83665 .67986 L .82405 .67629 L p .707 .577 .707 r
F P
0 g
s
.82405 .67629 m .82196 .63829 L .83456 .64185 L p .707 .577 .707 r
F P
0 g
s
.84173 .71178 m .84019 .72897 L .8276 .71506 L p .707 .577 .707 r
F P
0 g
s
.8276 .71506 m .82915 .69787 L .84173 .71178 L p .707 .577 .707 r
F P
0 g
s
.33974 .62618 m .33177 .57214 L .31092 .56707 L p .707 .577 .707 r
F P
0 g
s
.33177 .57214 m .33974 .62618 L .36693 .62792 L p .707 .577 .707 r
F P
0 g
s
.35381 .68901 m .34895 .65286 L .32174 .65089 L p .707 .577 .707 r
F P
0 g
s
.34895 .65286 m .35381 .68901 L .38472 .68757 L p .707 .577 .707 r
F P
0 g
s
.64688 .70939 m .64843 .6922 L .66471 .68122 L p .707 .577 .707 r
F P
0 g
s
.44062 .63917 m .44548 .67532 L .46937 .66571 L p .707 .577 .707 r
F P
0 g
s
.46937 .66571 m .46452 .62956 L .44062 .63917 L p .707 .577 .707 r
F P
0 g
s
.66477 .62777 m .66133 .57068 L .68528 .56646 L p .707 .577 .707 r
F P
0 g
s
.47429 .54909 m .48227 .60313 L .49849 .59207 L p .707 .577 .707 r
F P
0 g
s
.49849 .59207 m .49051 .53803 L .47429 .54909 L p .707 .577 .707 r
F P
0 g
s
.64301 .68845 m .64092 .65045 L .65724 .6456 L p .707 .577 .707 r
F P
0 g
s
.66471 .68122 m .66317 .69841 L .64688 .70939 L p .707 .577 .707 r
F P
0 g
s
.68528 .56646 m .68872 .62355 L .66477 .62777 L p .707 .577 .707 r
F P
0 g
s
.39321 .71304 m .39678 .69449 L .36618 .68743 L p .707 .577 .707 r
F P
0 g
s
.39678 .69449 m .39321 .71304 L .4245 .71832 L p .707 .577 .707 r
F P
0 g
s
.4245 .71832 m .42807 .69977 L .39678 .69449 L p .707 .577 .707 r
F P
0 g
s
.32174 .65089 m .3266 .68704 L .35381 .68901 L p .707 .577 .707 r
F P
0 g
s
.65724 .6456 m .65933 .6836 L .64301 .68845 L p .707 .577 .707 r
F P
0 g
s
.36618 .68743 m .36261 .70599 L .39321 .71304 L p .707 .577 .707 r
F P
0 g
s
.42807 .69977 m .4245 .71832 L .45343 .72131 L p .707 .577 .707 r
F P
0 g
s
.45343 .72131 m .457 .70276 L .42807 .69977 L p .707 .577 .707 r
F P
0 g
s
.80494 .56039 m .80838 .61748 L .78092 .61694 L p .707 .577 .707 r
F P
0 g
s
.78092 .61694 m .77749 .55985 L .80494 .56039 L p .707 .577 .707 r
F P
0 g
s
.3266 .68704 m .32174 .65089 L .3009 .64569 L p .707 .577 .707 r
F P
0 g
s
.31092 .56707 m .3189 .62111 L .33974 .62618 L p .707 .577 .707 r
F P
0 g
s
.36261 .70599 m .36618 .68743 L .33928 .6793 L p .707 .577 .707 r
F P
0 g
s
.33928 .6793 m .3357 .69785 L .36261 .70599 L p .707 .577 .707 r
F P
0 g
s
.82915 .69787 m .8276 .71506 L .80659 .7029 L p .707 .577 .707 r
F P
0 g
s
.80659 .7029 m .80813 .68571 L .82915 .69787 L p .707 .577 .707 r
F P
0 g
s
.3189 .62111 m .31092 .56707 L .29846 .55916 L p .707 .577 .707 r
F P
0 g
s
.46452 .62956 m .46937 .66571 L .48566 .65496 L p .707 .577 .707 r
F P
0 g
s
.48566 .65496 m .4808 .61881 L .46452 .62956 L p .707 .577 .707 r
F P
0 g
s
.82196 .63829 m .82405 .67629 L .80301 .67395 L p .707 .577 .707 r
F P
0 g
s
.80301 .67395 m .80092 .63595 L .82196 .63829 L p .707 .577 .707 r
F P
0 g
s
.68872 .62355 m .68528 .56646 L .71458 .56304 L p .707 .577 .707 r
F P
0 g
s
.66317 .69841 m .66471 .68122 L .68866 .67362 L p .707 .577 .707 r
F P
0 g
s
.3009 .64569 m .30576 .68184 L .3266 .68704 L p .707 .577 .707 r
F P
0 g
s
.457 .70276 m .45343 .72131 L .47716 .72172 L p .707 .577 .707 r
F P
0 g
s
.47716 .72172 m .48073 .70317 L .457 .70276 L p .707 .577 .707 r
F P
0 g
s
.49051 .53803 m .49849 .59207 L .50551 .581 L p .707 .577 .707 r
F P
0 g
s
.50551 .581 m .49754 .52696 L .49051 .53803 L p .707 .577 .707 r
F P
0 g
s
.71458 .56304 m .71802 .62013 L .68872 .62355 L p .707 .577 .707 r
F P
0 g
s
.77749 .55985 m .78092 .61694 L .74979 .61785 L p .707 .577 .707 r
F P
0 g
s
.74979 .61785 m .74635 .56077 L .77749 .55985 L p .707 .577 .707 r
F P
0 g
s
.3357 .69785 m .33928 .6793 L .3187 .67087 L p .707 .577 .707 r
F P
0 g
s
.68866 .67362 m .68712 .69081 L .66317 .69841 L p .707 .577 .707 r
F P
0 g
s
.65933 .6836 m .65724 .6456 L .68124 .64126 L p .707 .577 .707 r
F P
0 g
s
.3187 .67087 m .31512 .68942 L .3357 .69785 L p .707 .577 .707 r
F P
0 g
s
.71802 .62013 m .71458 .56304 L .74635 .56077 L p .707 .577 .707 r
F P
0 g
s
.74635 .56077 m .74979 .61785 L .71802 .62013 L p .707 .577 .707 r
F P
0 g
s
.30576 .68184 m .3009 .64569 L .28846 .63778 L p .707 .577 .707 r
F P
0 g
s
.68124 .64126 m .68333 .67927 L .65933 .6836 L p .707 .577 .707 r
F P
0 g
s
.29846 .55916 m .30644 .6132 L .3189 .62111 L p .707 .577 .707 r
F P
0 g
s
.80813 .68571 m .80659 .7029 L .7792 .69369 L p .707 .577 .707 r
F P
0 g
s
.7792 .69369 m .78074 .6765 L .80813 .68571 L p .707 .577 .707 r
F P
0 g
s
.68712 .69081 m .68866 .67362 L .71794 .67014 L p .707 .577 .707 r
F P
0 g
s
.80092 .63595 m .80301 .67395 L .77558 .67307 L p .707 .577 .707 r
F P
0 g
s
.77558 .67307 m .77349 .63506 L .80092 .63595 L p .707 .577 .707 r
F P
0 g
s
.4808 .61881 m .48566 .65496 L .49274 .64413 L p .707 .577 .707 r
F P
0 g
s
.49274 .64413 m .48788 .60798 L .4808 .61881 L p .707 .577 .707 r
F P
0 g
s
.48073 .70317 m .47716 .72172 L .49337 .7195 L p .707 .577 .707 r
F P
0 g
s
.49337 .7195 m .49694 .70095 L .48073 .70317 L p .707 .577 .707 r
F P
0 g
s
.30644 .6132 m .29846 .55916 L .2956 .54919 L p .707 .577 .707 r
F P
0 g
s
.28846 .63778 m .29332 .67393 L .30576 .68184 L p .707 .577 .707 r
F P
0 g
s
.71794 .67014 m .71639 .68733 L .68712 .69081 L p .707 .577 .707 r
F P
0 g
s
.31512 .68942 m .3187 .67087 L .30646 .66299 L p .707 .577 .707 r
F P
0 g
s
.68333 .67927 m .68124 .64126 L .71057 .63786 L p .707 .577 .707 r
F P
0 g
s
.78074 .6765 m .7792 .69369 L .74812 .68833 L p .707 .577 .707 r
F P
0 g
s
.74812 .68833 m .74966 .67114 L .78074 .6765 L p .707 .577 .707 r
F P
0 g
s
.71639 .68733 m .71794 .67014 L .74966 .67114 L p .707 .577 .707 r
F P
0 g
s
.49754 .52696 m .50551 .581 L .50266 .57103 L p .707 .577 .707 r
F P
0 g
s
.50266 .57103 m .49468 .51699 L .49754 .52696 L p .707 .577 .707 r
F P
0 g
s
.30646 .66299 m .30288 .68154 L .31512 .68942 L p .707 .577 .707 r
F P
0 g
s
.71057 .63786 m .71266 .67586 L .68333 .67927 L p .707 .577 .707 r
F P
0 g
s
.74966 .67114 m .74812 .68833 L .71639 .68733 L p .707 .577 .707 r
F P
0 g
s
.77349 .63506 m .77558 .67307 L .74444 .67373 L p .707 .577 .707 r
F P
0 g
s
.74444 .67373 m .74235 .63572 L .77349 .63506 L p .707 .577 .707 r
F P
0 g
s
.71266 .67586 m .71057 .63786 L .74235 .63572 L p .707 .577 .707 r
F P
0 g
s
.29332 .67393 m .28846 .63778 L .28564 .62793 L p .707 .577 .707 r
F P
0 g
s
.2956 .54919 m .30358 .60323 L .30644 .6132 L p .707 .577 .707 r
F P
0 g
s
.74235 .63572 m .74444 .67373 L .71266 .67586 L p .707 .577 .707 r
F P
0 g
s
.48788 .60798 m .49274 .64413 L .48993 .63428 L p .707 .577 .707 r
F P
0 g
s
.48993 .63428 m .48507 .59813 L .48788 .60798 L p .707 .577 .707 r
F P
0 g
s
.49694 .70095 m .49337 .7195 L .50047 .71488 L p .707 .577 .707 r
F P
0 g
s
.50047 .71488 m .50404 .69633 L .49694 .70095 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28564 .62793 m .2905 .66408 L .29332 .67393 L p .707 .577 .707 r
F P
0 g
s
.30358 .60323 m .2956 .54919 L .30263 .53813 L p .707 .577 .707 r
F P
0 g
s
.30288 .68154 m .30646 .66299 L .30375 .65641 L p .707 .577 .707 r
F P
0 g
s
.30375 .65641 m .30018 .67496 L .30288 .68154 L p .707 .577 .707 r
F P
0 g
s
.49468 .51699 m .50266 .57103 L .4902 .56312 L p .707 .577 .707 r
F P
0 g
s
.4902 .56312 m .48222 .50908 L .49468 .51699 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2905 .66408 m .28564 .62793 L .29273 .6171 L p .707 .577 .707 r
F P
0 g
s
.30263 .53813 m .3106 .59217 L .30358 .60323 L p .707 .577 .707 r
F P
0 g
s
.48507 .59813 m .48993 .63428 L .47749 .62637 L p .707 .577 .707 r
F P
0 g
s
.47749 .62637 m .47263 .59022 L .48507 .59813 L p .707 .577 .707 r
F P
0 g
s
.50404 .69633 m .50047 .71488 L .49777 .7083 L p .707 .577 .707 r
F P
0 g
s
.49777 .7083 m .50134 .68975 L .50404 .69633 L p .707 .577 .707 r
F P
0 g
s
.3106 .59217 m .30263 .53813 L .31885 .52706 L p .707 .577 .707 r
F P
0 g
s
.29273 .6171 m .29758 .65325 L .2905 .66408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30018 .67496 m .30375 .65641 L .31085 .65179 L p .707 .577 .707 r
F P
0 g
s
.48222 .50908 m .4902 .56312 L .46935 .55805 L p .707 .577 .707 r
F P
0 g
s
.46935 .55805 m .46137 .50401 L .48222 .50908 L p .707 .577 .707 r
F P
0 g
s
.31085 .65179 m .30728 .67034 L .30018 .67496 L p .707 .577 .707 r
F P
0 g
s
.29758 .65325 m .29273 .6171 L .30901 .60635 L p .707 .577 .707 r
F P
0 g
s
.31885 .52706 m .32683 .5811 L .3106 .59217 L p .707 .577 .707 r
F P
0 g
s
.32683 .5811 m .31885 .52706 L .34268 .51707 L p .707 .577 .707 r
F P
0 g
s
.47263 .59022 m .47749 .62637 L .45664 .62117 L p .707 .577 .707 r
F P
0 g
s
.45664 .62117 m .45178 .58502 L .47263 .59022 L p .707 .577 .707 r
F P
0 g
s
.50134 .68975 m .49777 .7083 L .48553 .70041 L p .707 .577 .707 r
F P
0 g
s
.48553 .70041 m .4891 .68186 L .50134 .68975 L p .707 .577 .707 r
F P
0 g
s
.30901 .60635 m .31387 .6425 L .29758 .65325 L p .707 .577 .707 r
F P
0 g
s
.46137 .50401 m .46935 .55805 L .44216 .55631 L p .707 .577 .707 r
F P
0 g
s
.44216 .55631 m .43419 .50227 L .46137 .50401 L p .707 .577 .707 r
F P
0 g
s
.30728 .67034 m .31085 .65179 L .32706 .64957 L p .707 .577 .707 r
F P
0 g
s
.32706 .64957 m .32349 .66812 L .30728 .67034 L p .707 .577 .707 r
F P
0 g
s
.31387 .6425 m .30901 .60635 L .33291 .59674 L p .707 .577 .707 r
F P
0 g
s
.34268 .51707 m .35065 .57111 L .32683 .5811 L p .707 .577 .707 r
F P
0 g
s
.35065 .57111 m .34268 .51707 L .37178 .50914 L p .707 .577 .707 r
F P
0 g
s
.43419 .50227 m .44216 .55631 L .41129 .55808 L p .707 .577 .707 r
F P
0 g
s
.41129 .55808 m .40332 .50404 L .43419 .50227 L p .707 .577 .707 r
F P
0 g
s
.45178 .58502 m .45664 .62117 L .42943 .6192 L p .707 .577 .707 r
F P
0 g
s
.42943 .6192 m .42458 .58305 L .45178 .58502 L p .707 .577 .707 r
F P
0 g
s
.37976 .56318 m .37178 .50914 L .40332 .50404 L p .707 .577 .707 r
F P
0 g
s
.37178 .50914 m .37976 .56318 L .35065 .57111 L p .707 .577 .707 r
F P
0 g
s
.33291 .59674 m .33777 .63289 L .31387 .6425 L p .707 .577 .707 r
F P
0 g
s
.40332 .50404 m .41129 .55808 L .37976 .56318 L p .707 .577 .707 r
F P
0 g
s
.4891 .68186 m .48553 .70041 L .46495 .69199 L p .707 .577 .707 r
F P
0 g
s
.46495 .69199 m .46852 .67344 L .4891 .68186 L p .707 .577 .707 r
F P
0 g
s
.33777 .63289 m .33291 .59674 L .36208 .58921 L p .707 .577 .707 r
F P
0 g
s
.32349 .66812 m .32706 .64957 L .35079 .64998 L p .707 .577 .707 r
F P
0 g
s
.42458 .58305 m .42943 .6192 L .39852 .62064 L p .707 .577 .707 r
F P
0 g
s
.39852 .62064 m .39367 .58449 L .42458 .58305 L p .707 .577 .707 r
F P
0 g
s
.35079 .64998 m .34722 .66853 L .32349 .66812 L p .707 .577 .707 r
F P
0 g
s
.36694 .62536 m .36208 .58921 L .39367 .58449 L p .707 .577 .707 r
F P
0 g
s
.36208 .58921 m .36694 .62536 L .33777 .63289 L p .707 .577 .707 r
F P
0 g
s
.39367 .58449 m .39852 .62064 L .36694 .62536 L p .707 .577 .707 r
F P
0 g
s
.46852 .67344 m .46495 .69199 L .43804 .68385 L p .707 .577 .707 r
F P
0 g
s
.43804 .68385 m .44161 .6653 L .46852 .67344 L p .707 .577 .707 r
F P
0 g
s
.34722 .66853 m .35079 .64998 L .37972 .65297 L p .707 .577 .707 r
F P
0 g
s
.37972 .65297 m .37615 .67152 L .34722 .66853 L p .707 .577 .707 r
F P
0 g
s
.44161 .6653 m .43804 .68385 L .40744 .6768 L p .707 .577 .707 r
F P
0 g
s
.40744 .6768 m .41102 .65825 L .44161 .6653 L p .707 .577 .707 r
F P
0 g
s
.37615 .67152 m .37972 .65297 L .41102 .65825 L p .707 .577 .707 r
F P
0 g
s
.41102 .65825 m .40744 .6768 L .37615 .67152 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000H000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001SOol30003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`<000IJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005ao
o`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00F7oo00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo00@005YFFUH000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Ioo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00@000EJEP03001JEUYF00AJEP@000EJEP<00007FUH005YFFUH005YF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000067oo7000<Goo001DOol200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
0`00FUIJEP020002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000?Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH00002000^Ool005Aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000AJEP`0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000Moo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP03
001JEUYF00=JEP@00003FUH005YF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP00008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00009oo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP04001JEUYFFUH;
0003FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00002000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001EOol00`00FUH00004FUH01000FUH000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005Eoo`04001JEUYF0003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo
00@005YFFUH0009JEP04001JEUYF0007FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF1`001EYF
00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo3`001goo00<005YF
FUH00`0015YF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
100000=JEP00FUH00eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<0
05YFFUH01UYF00<005YFFUH0100017oo0UYF0P001EYF00<005YF00000`0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00@005YFFUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUH000=JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP000002FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<goo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUH005YF001JEP0200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF0004FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00@000]J
EP<00004FUH005YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH01000FUIJEUYF2@0025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH04@000eYF00<005YFFUH02EYF00<005YF00000P000eYF00<005YFFUH00UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF10000UYF00<005YF00001UYF
1@0015YF00<005YFFUH02EYF0P000eYF0P0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00
;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00001EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP001UYF1@0015YF00<005YF
FUH01EYF100000=JEP00FUH00eYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF5`00
0UYF1000<Goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP0015YF00@005YF000000EJEP06001JEUYF001JEP001UYF1@0015YF00@0
05YFFUIJEP@000EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000bOol002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF009JEPl000AJEP04001JEUYF0004FUH30005FUH01`00FUIJEUYF001JEP0000IJ
EP@000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPP000=J
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080
02moo`00;Goo0P000eYF00<005YFFUH00eYF1P003goo1@000UYF00<005YFFUH00P000UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00006FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP00Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUH00003000IOol200000eYF0000000400000eYF0000000;0006FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0003FUH2000DOol30007Ool01000FUH000000UYF0`0000=JEP00FUH01EYF00@005YFFUIJEPL000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002aoo`03001JEP00009JEP03001JEUYF0080015oo`D000Ioo`800003FUH00000008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<0
05YF00000`0015YF0`003Woo1@001Woo0P0000EJEP00001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000/Ool00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5
0006Ool2000015YF000000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010000eYF00<005YFFUH015YF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000Aoo`<000Moo`800004FUH005YF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH2000:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH00UYF400000=JEP00FUH05P001UYF00<005YFFUH01eYF00<005YF0000100035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEQ<00003
FUH005YF008000=JEP<000MJEP03001JEUYF00EJEPD0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP@000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YFFUH00P00;Woo
000/Ool01@00FUIJEUYF00001UYF00<005YFFUH01P0015YF00<005YFFUH01UYF00@005YFFUIJEPH0
00=JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00IJ
EP03001JEP00008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF20001UYF00<005YFFUH00eYF100000=J
EP00FUH01EYF1@0000=JEP000000;Woo000/Ool01@00FUIJEUYF00001EYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF
00<005YF00000P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF2000
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00UYF0`00;Woo
000/Ool01@00FUIJEUYF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YF001JEP0000IJEP03001JEP0000<000MJEP`00003FUH00000008000IJEP03001JEUYF
00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH00eYF00<005YF0000;Woo000/Ool01P00FUIJEUYF001JEP<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000IJEP03001JEUYF00=JEPd000AJ
EP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF1@0000=JEP00FUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH01EYF0`000eYF0`00;goo000]Ool00`00FUIJEP020002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH025YF0`001EYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00D005YFFUIJEP0000EJEPH000MJ
EP03001JEUYF00EJEP@0009JEP03001JEUYF00EJEP03001JEUYF00<0039oo`00;Woo0`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00@005YF000000=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000
00=JEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP04
001JEUYFFUH2000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEPP000IJ
EP04001JEUYFFUH200000eYF001JEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP03FUH00`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3P000UYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000Ioo`<000EJEP80031oo`00;Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00`0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0000=JEP0000005`004Woo0P000eYF00<005YF0000;goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH005YF001JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP03001JEUYF009JEP03001oogoo01moo`04001JEUYF0002FUH00`00Oomoo`0/Ool002ioo`8000AJ
EP03001JEUYF00=JEPH000MJEP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEP00FUH0
0005FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0POol30003FUH00`00Oomoo`0[Ool002ioo`8000AJEP03001JEP0000D0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05
001JEP00FUH00006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH00000008000AJEP04001JEUYFFUH2000:Ool3000GOol01@00FUIJEUYF0000;Goo000^Ool2
0003FUH30006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000017oo000000001EYF00D0
05YF001JEP0000IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00AJEP03001JEUYF00@0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003
FUH300000eYF001JEP02FUH20009Ool5000GOol01000FUIJEP00;Goo000]Ool01000FUH005YF0P00
47oo4P002Goo0P000eYF00D005YF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080
00IJEP8000=JEP8000Uoo`D001Moo`05001JEP00FUH0000/Ool002eoo`03001JEP00008001Eoo`D0
01Aoo`800006FUH005YF001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P00
1UYF00D005YF000005YF008000Uoo`D001Qoo`800003FUH007oo02]oo`00;Goo0`000UYF00<007oo
Ool04Woo1@005Woo0P0000AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80
00EJEP04001JEUYFFUH2000;Ool3000JOol00`00FUH0000/Ool002eoo`8000=JEP<0019oo`D001Qo
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPH000AJEP8002Qoo`03
001JEP0002aoo`00;Goo0P000eYF00<005YFFUH00P004Goo0`005goo100000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF0`0000AJEP00FUH002Qoo`8002eoo`00;Goo
0P000eYF00<005YFFUH00UYF0`009Woo0P000eYF00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEP00008002Uoo`8002eoo`00;Goo0P00
0eYF00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00FUH00UYF00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0003FUH30004FUH2000UOol4000]Ool002ioo`05001J
EUYFFUH00005FUH00`00FUIJEP03FUH7000BOol50005FUH01`00FUIJEUYF001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000EJEP8000AJEP<0025oo`80009JEP03001oogoo02aoo`00;Woo00D005YF
FUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP07001JEUYF
FUH005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUH00004
0002FUH2000MOol20003FUH2000^Ool002moo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0002FUH00`00FUH00006FUH00`00FUIJEP04000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH60006FUH00`00FUIJEP02FUH01000
FUH000000UYF0P000eYF00<005YFFUH00eYF1@006Goo100000=JEP00FUH00UYF00<007ooOol0;Goo
000`Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0003FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP04FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUH00005FUH2
00000eYF001JEP06FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000;goo000aOol20005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000MJEP<000IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00AJEP04001JEUYF000`Ool0039oo`04001JEUYFFUH80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH02000FUIJEUYF001JEP00FUH30008
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000UYF00@005YF000000IJEP03001JEUYF008000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0035oo`00<Goo1@000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUIJ
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000040002FUH00`00FUIJ
EP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000c
Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF001JEP02FUH00`00FUH000030004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000eOol002aoo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEQL000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003
FUH005YF009JEP03001JEUYF00=JEP<00003FUH005YF009JEPD0009JEP03001JEUYF00IJEP03001J
EUYF009JEPH003Uoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4P001eYF
00<005YFFUH015YF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEUYF009JEP03001JEP00008000=JEP8000=ooa0003moo`00;7oo00<005YF0000
15YF00@005YFFUIJEPP000QJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00D0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJ
EP02000015YF001JEP00DWoo000/Ool00`00FUH00002FUH60007FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH01000FUIJEUYF1P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH020000eYF00D005YFFUH005YF00800003FUH007oo055oo`00;7oo00<005YF00000`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Woo00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH010000UYF00<0
05YFFUH00P00Dgoo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH9000AOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH0
0`00FUIJEP04FUH00`00FUIJEP04001COol002eoo`L0009JEP03001JEUYF009JEQ4001]oo`80009J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00AJEPD00003FUH007oo059oo`00
=7oo1`00;Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP<000QJEP03001JEUYF00AJEPH005Aoo`00Jgoo0P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF001FOol006eoo`<000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EQT0009JEP03001oogoo05Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01P004goo0P0000EJEP00FUIJEP0005Ioo`00Lgoo1`001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@000Woo1@004Goo00<005YFFUH00UYF
0P00Egoo001jOol;0006FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001goo1@003goo0`0015YF0P00
Egoo0025OolG000=Ool5000=Ool20002FUH00`00FUIJEP02FUH00`00Oomoo`1FOol008aoo`04001J
EUYFFUH2000HOol3000<Ool20004FUH01@00FUIJEUYF0000FGoo002<Ool01@00FUIJEUYF00009Woo
0P001eYF00<005YF0000FWoo002=Ool00`00FUH0000SOol400000eYF001JEP06FUH2001KOol008eo
o`<001ioo`D000EJEP03001JEUYF00AJEP8005aoo`00SGoo00<005YFFUH00`005goo10000UYF00<0
05YFFUH01UYF00@005YFFUIJEP8005ioo`00SGoo0P000UYF00<005YF00000P003Goo1`001UYF00<0
05YFFUH01UYF00@005YF0000061oo`00SWoo00@005YFFUH000AJEPd000AJEP03001JEUYF00MJEP03
001JEUYF00AJEP<0069oo`00SWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00@006Eoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEPD006Uoo`00T7oo0`001EYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01000KWoo002BOol30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH7001bOol009Eo
o`l007Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58406 .73895 m .5969 .68356 L .56652 .67549 L p .707 .577 .707 r
F P
0 g
s
.5969 .68356 m .58406 .73895 L .61511 .74543 L p .707 .577 .707 r
F P
0 g
s
.61511 .74543 m .62794 .69004 L .5969 .68356 L p .707 .577 .707 r
F P
0 g
s
.62794 .69004 m .61511 .74543 L .64378 .74969 L p .707 .577 .707 r
F P
0 g
s
.64378 .74969 m .65661 .6943 L .62794 .69004 L p .707 .577 .707 r
F P
0 g
s
.55369 .73088 m .56652 .67549 L .53978 .66662 L p .707 .577 .707 r
F P
0 g
s
.56652 .67549 m .55369 .73088 L .58406 .73895 L p .707 .577 .707 r
F P
0 g
s
.53978 .66662 m .52695 .72201 L .55369 .73088 L p .707 .577 .707 r
F P
0 g
s
.65661 .6943 m .64378 .74969 L .66727 .7513 L p .707 .577 .707 r
F P
0 g
s
.66727 .7513 m .68011 .69591 L .65661 .6943 L p .707 .577 .707 r
F P
0 g
s
.52695 .72201 m .53978 .66662 L .51931 .65781 L p .707 .577 .707 r
F P
0 g
s
.60472 .79824 m .61254 .76121 L .58205 .75366 L p .707 .577 .707 r
F P
0 g
s
.61254 .76121 m .60472 .79824 L .6359 .8041 L p .707 .577 .707 r
F P
0 g
s
.6359 .8041 m .64372 .76707 L .61254 .76121 L p .707 .577 .707 r
F P
0 g
s
.51931 .65781 m .50647 .7132 L .52695 .72201 L p .707 .577 .707 r
F P
0 g
s
.64372 .76707 m .6359 .8041 L .66472 .8077 L p .707 .577 .707 r
F P
0 g
s
.66472 .8077 m .67254 .77068 L .64372 .76707 L p .707 .577 .707 r
F P
0 g
s
.57423 .79069 m .58205 .75366 L .55524 .74517 L p .707 .577 .707 r
F P
0 g
s
.58205 .75366 m .57423 .79069 L .60472 .79824 L p .707 .577 .707 r
F P
0 g
s
.68011 .69591 m .66727 .7513 L .68329 .75011 L p .707 .577 .707 r
F P
0 g
s
.68329 .75011 m .69612 .69472 L .68011 .69591 L p .707 .577 .707 r
F P
0 g
s
.62057 .85656 m .61486 .83964 L .58443 .84936 L p .707 .577 .707 r
F P
0 g
s
.61486 .83964 m .62057 .85656 L .64875 .84369 L p .707 .577 .707 r
F P
0 g
s
.64875 .84369 m .64303 .82678 L .61486 .83964 L p .707 .577 .707 r
F P
0 g
s
.55524 .74517 m .54741 .78219 L .57423 .79069 L p .707 .577 .707 r
F P
0 g
s
.59015 .86628 m .58443 .84936 L .55474 .85499 L p .707 .577 .707 r
F P
0 g
s
.58443 .84936 m .59015 .86628 L .62057 .85656 L p .707 .577 .707 r
F P
0 g
s
.50647 .7132 m .51931 .65781 L .50709 .64993 L p .707 .577 .707 r
F P
0 g
s
.67254 .77068 m .66472 .8077 L .68836 .80869 L p .707 .577 .707 r
F P
0 g
s
.68836 .80869 m .69618 .77167 L .67254 .77068 L p .707 .577 .707 r
F P
0 g
s
.64303 .82678 m .64875 .84369 L .67193 .82895 L p .707 .577 .707 r
F P
0 g
s
.67193 .82895 m .66621 .81203 L .64303 .82678 L p .707 .577 .707 r
F P
0 g
s
.55474 .85499 m .56046 .87191 L .59015 .86628 L p .707 .577 .707 r
F P
0 g
s
.54741 .78219 m .55524 .74517 L .53472 .73656 L p .707 .577 .707 r
F P
0 g
s
.56046 .87191 m .55474 .85499 L .52869 .85598 L p .707 .577 .707 r
F P
0 g
s
.50709 .64993 m .49426 .70532 L .50647 .7132 L p .707 .577 .707 r
F P
0 g
s
.53472 .73656 m .5269 .77358 L .54741 .78219 L p .707 .577 .707 r
F P
0 g
s
.52869 .85598 m .53441 .87289 L .56046 .87191 L p .707 .577 .707 r
F P
0 g
s
.66621 .81203 m .67193 .82895 L .68783 .81376 L p .707 .577 .707 r
F P
0 g
s
.68783 .81376 m .68212 .79685 L .66621 .81203 L p .707 .577 .707 r
F P
0 g
s
.69612 .69472 m .68329 .75011 L .69026 .74623 L p .707 .577 .707 r
F P
0 g
s
.69026 .74623 m .7031 .69084 L .69612 .69472 L p .707 .577 .707 r
F P
0 g
s
.69618 .77167 m .68836 .80869 L .7045 .80698 L p .707 .577 .707 r
F P
0 g
s
.7045 .80698 m .71232 .76995 L .69618 .77167 L p .707 .577 .707 r
F P
0 g
s
.53441 .87289 m .52869 .85598 L .50883 .85222 L p .707 .577 .707 r
F P
0 g
s
.49426 .70532 m .50709 .64993 L .50433 .64375 L p .707 .577 .707 r
F P
0 g
s
.5269 .77358 m .53472 .73656 L .52251 .72868 L p .707 .577 .707 r
F P
0 g
s
.50883 .85222 m .51455 .86913 L .53441 .87289 L p .707 .577 .707 r
F P
0 g
s
.52251 .72868 m .51469 .7657 L .5269 .77358 L p .707 .577 .707 r
F P
0 g
s
.50433 .64375 m .4915 .69914 L .49426 .70532 L p .707 .577 .707 r
F P
0 g
s
.68212 .79685 m .68783 .81376 L .69491 .79963 L p .707 .577 .707 r
F P
0 g
s
.69491 .79963 m .68919 .78271 L .68212 .79685 L p .707 .577 .707 r
F P
0 g
s
.71232 .76995 m .7045 .80698 L .71156 .80272 L p .707 .577 .707 r
F P
0 g
s
.71156 .80272 m .71939 .76569 L .71232 .76995 L p .707 .577 .707 r
F P
0 g
s
.51455 .86913 m .50883 .85222 L .4971 .84409 L p .707 .577 .707 r
F P
0 g
s
.7031 .69084 m .69026 .74623 L .6875 .74006 L p .707 .577 .707 r
F P
0 g
s
.6875 .74006 m .70034 .68467 L .7031 .69084 L p .707 .577 .707 r
F P
0 g
s
.51469 .7657 m .52251 .72868 L .51981 .72229 L p .707 .577 .707 r
F P
0 g
s
.4971 .84409 m .50282 .86101 L .51455 .86913 L p .707 .577 .707 r
F P
0 g
s
.4915 .69914 m .50433 .64375 L .51131 .63988 L p .707 .577 .707 r
F P
0 g
s
.51131 .63988 m .49847 .69527 L .4915 .69914 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.51981 .72229 m .51199 .75932 L .51469 .7657 L p .707 .577 .707 r
F P
0 g
s
.51199 .75932 m .51981 .72229 L .52688 .71803 L p .707 .577 .707 r
F P
0 g
s
.49847 .69527 m .51131 .63988 L .52732 .63869 L p .707 .577 .707 r
F P
0 g
s
.52688 .71803 m .51905 .75506 L .51199 .75932 L p .707 .577 .707 r
F P
0 g
s
.52732 .63869 m .51449 .69408 L .49847 .69527 L p .707 .577 .707 r
F P
0 g
s
.50038 .8493 m .49466 .83239 L .50174 .81825 L p .707 .577 .707 r
F P
0 g
s
.50174 .81825 m .50745 .83516 L .50038 .8493 L p .707 .577 .707 r
F P
0 g
s
.51449 .69408 m .52732 .63869 L .55082 .6403 L p .707 .577 .707 r
F P
0 g
s
.51905 .75506 m .52688 .71803 L .54302 .71632 L p .707 .577 .707 r
F P
0 g
s
.54302 .71632 m .53519 .75334 L .51905 .75506 L p .707 .577 .707 r
F P
0 g
s
.55082 .6403 m .53798 .69569 L .51449 .69408 L p .707 .577 .707 r
F P
0 g
s
.50745 .83516 m .50174 .81825 L .51764 .80307 L p .707 .577 .707 r
F P
0 g
s
.51764 .80307 m .52336 .81998 L .50745 .83516 L p .707 .577 .707 r
F P
0 g
s
.52336 .81998 m .51764 .80307 L .54082 .78832 L p .707 .577 .707 r
F P
0 g
s
.54082 .78832 m .54653 .80524 L .52336 .81998 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53821 .82054 L p .707 .577 .707 r
F P
0 g
s
.53798 .69569 m .55082 .6403 L .57949 .64456 L p .707 .577 .707 r
F P
0 g
s
.53519 .75334 m .54302 .71632 L .56665 .71731 L p .707 .577 .707 r
F P
0 g
s
.57949 .64456 m .56666 .69994 L .53798 .69569 L p .707 .577 .707 r
F P
0 g
s
.56665 .71731 m .55883 .75433 L .53519 .75334 L p .707 .577 .707 r
F P
0 g
s
.53821 .82054 m .53821 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.56666 .69994 m .57949 .64456 L .61053 .65103 L p .707 .577 .707 r
F P
0 g
s
.61053 .65103 m .5977 .70642 L .56666 .69994 L p .707 .577 .707 r
F P
0 g
s
.55883 .75433 m .56665 .71731 L .59547 .72091 L p .707 .577 .707 r
F P
0 g
s
.59547 .72091 m .58765 .75793 L .55883 .75433 L p .707 .577 .707 r
F P
0 g
s
.54653 .80524 m .54082 .78832 L .569 .77546 L p .707 .577 .707 r
F P
0 g
s
.59942 .76574 m .60514 .78265 L .57471 .79237 L p .707 .577 .707 r
F P
0 g
s
.57471 .79237 m .569 .77546 L .59942 .76574 L p .707 .577 .707 r
F P
0 g
s
.569 .77546 m .57471 .79237 L .54653 .80524 L p .707 .577 .707 r
F P
0 g
s
.53821 .31865 m .53821 .82054 L .57932 .81555 L p .707 .577 .707 r
F P
0 g
s
.57932 .81555 m .57932 .31366 L .53821 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40993 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.68919 .78271 m .69491 .79963 L .69246 .78792 L p .707 .577 .707 r
F P
0 g
s
.69246 .78792 m .68675 .77101 L .68919 .78271 L p .707 .577 .707 r
F P
0 g
s
.50282 .86101 m .4971 .84409 L .49466 .83239 L p .707 .577 .707 r
F P
0 g
s
.71939 .76569 m .71156 .80272 L .70886 .79633 L p .707 .577 .707 r
F P
0 g
s
.70886 .79633 m .71668 .75931 L .71939 .76569 L p .707 .577 .707 r
F P
0 g
s
.64091 .65911 m .62808 .7145 L .5977 .70642 L p .707 .577 .707 r
F P
0 g
s
.5977 .70642 m .61053 .65103 L .64091 .65911 L p .707 .577 .707 r
F P
0 g
s
.62911 .76011 m .63483 .77702 L .60514 .78265 L p .707 .577 .707 r
F P
0 g
s
.60514 .78265 m .59942 .76574 L .62911 .76011 L p .707 .577 .707 r
F P
0 g
s
.58765 .75793 m .59547 .72091 L .62666 .72677 L p .707 .577 .707 r
F P
0 g
s
.62666 .72677 m .61883 .7638 L .58765 .75793 L p .707 .577 .707 r
F P
0 g
s
.57932 .31366 m .57932 .81555 L .61267 .80739 L p .707 .577 .707 r
F P
0 g
s
.61267 .80739 m .61267 .3055 L .57932 .31366 L p .707 .577 .707 r
F P
0 g
s
.70034 .68467 m .6875 .74006 L .67529 .73218 L p .707 .577 .707 r
F P
0 g
s
.67529 .73218 m .68812 .67679 L .70034 .68467 L p .707 .577 .707 r
F P
0 g
s
.49466 .83239 m .50038 .8493 L .50282 .86101 L p .707 .577 .707 r
F P
0 g
s
.40993 .81345 m .40993 .31156 L .37952 .30261 L p .707 .577 .707 r
F P
0 g
s
.40993 .31156 m .40993 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24857 .72923 m .25416 .6787 L .22309 .67277 L p .707 .577 .707 r
F P
0 g
s
.25416 .6787 m .24857 .72923 L .28024 .73047 L p .707 .577 .707 r
F P
0 g
s
.28024 .73047 m .28582 .67994 L .25416 .6787 L p .707 .577 .707 r
F P
0 g
s
.68675 .77101 m .69246 .78792 L .68074 .77979 L p .707 .577 .707 r
F P
0 g
s
.68074 .77979 m .67502 .76288 L .68675 .77101 L p .707 .577 .707 r
F P
0 g
s
.28582 .67994 m .28024 .73047 L .30941 .7269 L p .707 .577 .707 r
F P
0 g
s
.30941 .7269 m .31499 .67637 L .28582 .67994 L p .707 .577 .707 r
F P
0 g
s
.2175 .7233 m .22309 .67277 L .19566 .66272 L p .707 .577 .707 r
F P
0 g
s
.22309 .67277 m .2175 .7233 L .24857 .72923 L p .707 .577 .707 r
F P
0 g
s
.2572 .79386 m .26059 .75981 L .22952 .75416 L p .707 .577 .707 r
F P
0 g
s
.26059 .75981 m .2572 .79386 L .2889 .79499 L p .707 .577 .707 r
F P
0 g
s
.2889 .79499 m .29229 .76094 L .26059 .75981 L p .707 .577 .707 r
F P
0 g
s
.29229 .76094 m .2889 .79499 L .31814 .79148 L p .707 .577 .707 r
F P
0 g
s
.31814 .79148 m .32153 .75743 L .29229 .76094 L p .707 .577 .707 r
F P
0 g
s
.22613 .78821 m .22952 .75416 L .20213 .74453 L p .707 .577 .707 r
F P
0 g
s
.22952 .75416 m .22613 .78821 L .2572 .79386 L p .707 .577 .707 r
F P
0 g
s
.66765 .66798 m .65481 .72337 L .62808 .7145 L p .707 .577 .707 r
F P
0 g
s
.62808 .7145 m .64091 .65911 L .66765 .66798 L p .707 .577 .707 r
F P
0 g
s
.63483 .77702 m .62911 .76011 L .65516 .75912 L p .707 .577 .707 r
F P
0 g
s
.65516 .75912 m .66088 .77604 L .63483 .77702 L p .707 .577 .707 r
F P
0 g
s
.65715 .73432 m .64932 .77135 L .61883 .7638 L p .707 .577 .707 r
F P
0 g
s
.61883 .7638 m .62666 .72677 L .65715 .73432 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80739 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.71668 .75931 m .70886 .79633 L .69665 .78845 L p .707 .577 .707 r
F P
0 g
s
.69665 .78845 m .70448 .75143 L .71668 .75931 L p .707 .577 .707 r
F P
0 g
s
.68812 .67679 m .67529 .73218 L .65481 .72337 L p .707 .577 .707 r
F P
0 g
s
.65481 .72337 m .66765 .66798 L .68812 .67679 L p .707 .577 .707 r
F P
0 g
s
.31499 .67637 m .30941 .7269 L .33322 .71886 L p .707 .577 .707 r
F P
0 g
s
.33322 .71886 m .3388 .66833 L .31499 .67637 L p .707 .577 .707 r
F P
0 g
s
.19008 .71325 m .19566 .66272 L .17456 .64955 L p .707 .577 .707 r
F P
0 g
s
.19566 .66272 m .19008 .71325 L .2175 .7233 L p .707 .577 .707 r
F P
0 g
s
.32153 .75743 m .31814 .79148 L .34204 .78368 L p .707 .577 .707 r
F P
0 g
s
.34204 .78368 m .34543 .74963 L .32153 .75743 L p .707 .577 .707 r
F P
0 g
s
.37952 .8045 m .37952 .30261 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37952 .30261 m .37952 .8045 L .40993 .81345 L p .707 .577 .707 r
F P
0 g
s
.19873 .77858 m .20213 .74453 L .18109 .73187 L p .707 .577 .707 r
F P
0 g
s
.20213 .74453 m .19873 .77858 L .22613 .78821 L p .707 .577 .707 r
F P
0 g
s
.67502 .76288 m .68074 .77979 L .66088 .77604 L p .707 .577 .707 r
F P
0 g
s
.66088 .77604 m .65516 .75912 L .67502 .76288 L p .707 .577 .707 r
F P
0 g
s
.3388 .66833 m .33322 .71886 L .34935 .70715 L p .707 .577 .707 r
F P
0 g
s
.34935 .70715 m .35493 .65662 L .3388 .66833 L p .707 .577 .707 r
F P
0 g
s
.21797 .76859 m .22048 .78765 L .25142 .78337 L p .707 .577 .707 r
F P
0 g
s
.25142 .78337 m .24891 .76431 L .21797 .76859 L p .707 .577 .707 r
F P
0 g
s
.24891 .76431 m .25142 .78337 L .28297 .77931 L p .707 .577 .707 r
F P
0 g
s
.16898 .70008 m .17456 .64955 L .16185 .63454 L p .707 .577 .707 r
F P
0 g
s
.17456 .64955 m .16898 .70008 L .19008 .71325 L p .707 .577 .707 r
F P
0 g
s
.28297 .77931 m .28046 .76025 L .24891 .76431 L p .707 .577 .707 r
F P
0 g
s
.28046 .76025 m .28297 .77931 L .31204 .77586 L p .707 .577 .707 r
F P
0 g
s
.31204 .77586 m .30953 .7568 L .28046 .76025 L p .707 .577 .707 r
F P
0 g
s
.18109 .73187 m .1777 .76592 L .19873 .77858 L p .707 .577 .707 r
F P
0 g
s
.34543 .74963 m .34204 .78368 L .35827 .77234 L p .707 .577 .707 r
F P
0 g
s
.35827 .77234 m .36166 .73829 L .34543 .74963 L p .707 .577 .707 r
F P
0 g
s
.70448 .75143 m .69665 .78845 L .67614 .77984 L p .707 .577 .707 r
F P
0 g
s
.67614 .77984 m .68396 .74282 L .70448 .75143 L p .707 .577 .707 r
F P
0 g
s
.19068 .77267 m .19319 .79173 L .22048 .78765 L p .707 .577 .707 r
F P
0 g
s
.22048 .78765 m .21797 .76859 L .19068 .77267 L p .707 .577 .707 r
F P
0 g
s
.1777 .76592 m .18109 .73187 L .16847 .71742 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.30953 .7568 m .31204 .77586 L .33579 .77337 L p .707 .577 .707 r
F P
0 g
s
.33579 .77337 m .33328 .75431 L .30953 .7568 L p .707 .577 .707 r
F P
0 g
s
.16969 .77615 m .1722 .79521 L .19319 .79173 L p .707 .577 .707 r
F P
0 g
s
.19319 .79173 m .19068 .77267 L .16969 .77615 L p .707 .577 .707 r
F P
0 g
s
.35493 .65662 m .34935 .70715 L .35621 .6929 L p .707 .577 .707 r
F P
0 g
s
.35621 .6929 m .36179 .64237 L .35493 .65662 L p .707 .577 .707 r
F P
0 g
s
.16847 .71742 m .16508 .75147 L .1777 .76592 L p .707 .577 .707 r
F P
0 g
s
.15627 .68507 m .16185 .63454 L .15877 .61916 L p .707 .577 .707 r
F P
0 g
s
.16185 .63454 m .15627 .68507 L .16898 .70008 L p .707 .577 .707 r
F P
0 g
s
.36166 .73829 m .35827 .77234 L .36525 .75859 L p .707 .577 .707 r
F P
0 g
s
.36179 .64237 m .35621 .6929 L .35313 .67752 L p .707 .577 .707 r
F P
0 g
s
.35313 .67752 m .35872 .62699 L .36179 .64237 L p .707 .577 .707 r
F P
0 g
s
.36525 .75859 m .36864 .72454 L .36166 .73829 L p .707 .577 .707 r
F P
0 g
s
.36567 .70971 m .36228 .74376 L .34965 .72931 L p .707 .577 .707 r
F P
0 g
s
.34965 .72931 m .35305 .69526 L .36567 .70971 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36864 .72454 m .36525 .75859 L .36228 .74376 L p .707 .577 .707 r
F P
0 g
s
.36228 .74376 m .36567 .70971 L .36864 .72454 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37952 .8045 L p .707 .577 .707 r
F P
0 g
s
.68396 .74282 m .67614 .77984 L .64932 .77135 L p .707 .577 .707 r
F P
0 g
s
.64932 .77135 m .65715 .73432 L .68396 .74282 L p .707 .577 .707 r
F P
0 g
s
.16508 .75147 m .16847 .71742 L .1655 .70259 L p .707 .577 .707 r
F P
0 g
s
.33328 .75431 m .33579 .77337 L .3519 .77208 L p .707 .577 .707 r
F P
0 g
s
.3519 .77208 m .34939 .75302 L .33328 .75431 L p .707 .577 .707 r
F P
0 g
s
.15707 .7787 m .15958 .79775 L .1722 .79521 L p .707 .577 .707 r
F P
0 g
s
.1722 .79521 m .16969 .77615 L .15707 .7787 L p .707 .577 .707 r
F P
0 g
s
.1655 .70259 m .16211 .73664 L .16508 .75147 L p .707 .577 .707 r
F P
0 g
s
.15877 .61916 m .15319 .66969 L .15627 .68507 L p .707 .577 .707 r
F P
0 g
s
.15319 .66969 m .15877 .61916 L .16563 .60491 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77297 L p .707 .577 .707 r
F P
0 g
s
.63909 .77297 m .63909 .27108 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.16211 .73664 m .1655 .70259 L .17247 .68884 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34939 .75302 m .3519 .77208 L .35878 .77211 L p .707 .577 .707 r
F P
0 g
s
.35878 .77211 m .35626 .75305 L .34939 .75302 L p .707 .577 .707 r
F P
0 g
s
.35872 .62699 m .35313 .67752 L .34042 .66251 L p .707 .577 .707 r
F P
0 g
s
.34042 .66251 m .34601 .61198 L .35872 .62699 L p .707 .577 .707 r
F P
0 g
s
.35626 .75305 m .35878 .77211 L .35576 .77347 L p .707 .577 .707 r
F P
0 g
s
.35576 .77347 m .35325 .75441 L .35626 .75305 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.15405 .78005 m .15656 .79911 L .15958 .79775 L p .707 .577 .707 r
F P
0 g
s
.15958 .79775 m .15707 .7787 L .15405 .78005 L p .707 .577 .707 r
F P
0 g
s
.17247 .68884 m .16908 .72289 L .16211 .73664 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16563 .60491 m .16005 .65544 L .15319 .66969 L p .707 .577 .707 r
F P
0 g
s
.16005 .65544 m .16563 .60491 L .18176 .5932 L p .707 .577 .707 r
F P
0 g
s
.16908 .72289 m .17247 .68884 L .1887 .67751 L p .707 .577 .707 r
F P
0 g
s
.63909 .27108 m .63909 .77297 L .62048 .76193 L p .707 .577 .707 r
F P
0 g
s
.62048 .76193 m .62048 .26004 L .63909 .27108 L p .707 .577 .707 r
F P
0 g
s
.34601 .61198 m .34042 .66251 L .31932 .64934 L p .707 .577 .707 r
F P
0 g
s
.31932 .64934 m .3249 .59881 L .34601 .61198 L p .707 .577 .707 r
F P
0 g
s
.18176 .5932 m .17618 .64373 L .16005 .65544 L p .707 .577 .707 r
F P
0 g
s
.17618 .64373 m .18176 .5932 L .20557 .58516 L p .707 .577 .707 r
F P
0 g
s
.1887 .67751 m .18531 .71156 L .16908 .72289 L p .707 .577 .707 r
F P
0 g
s
.16093 .78008 m .16344 .79914 L .15656 .79911 L p .707 .577 .707 r
F P
0 g
s
.15656 .79911 m .15405 .78005 L .16093 .78008 L p .707 .577 .707 r
F P
0 g
s
.35305 .69526 m .34965 .72931 L .32862 .71665 L p .707 .577 .707 r
F P
0 g
s
.32862 .71665 m .33201 .6826 L .35305 .69526 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38733 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.18531 .71156 m .1887 .67751 L .21261 .6697 L p .707 .577 .707 r
F P
0 g
s
.3249 .59881 m .31932 .64934 L .29189 .63929 L p .707 .577 .707 r
F P
0 g
s
.29189 .63929 m .29748 .58876 L .3249 .59881 L p .707 .577 .707 r
F P
0 g
s
.19999 .63569 m .20557 .58516 L .23474 .58159 L p .707 .577 .707 r
F P
0 g
s
.20557 .58516 m .19999 .63569 L .17618 .64373 L p .707 .577 .707 r
F P
0 g
s
.35325 .75441 m .35576 .77347 L .34314 .77601 L p .707 .577 .707 r
F P
0 g
s
.34314 .77601 m .34063 .75695 L .35325 .75441 L p .707 .577 .707 r
F P
0 g
s
.21261 .6697 m .20922 .70375 L .18531 .71156 L p .707 .577 .707 r
F P
0 g
s
.33201 .6826 m .32862 .71665 L .30122 .70702 L p .707 .577 .707 r
F P
0 g
s
.30122 .70702 m .30462 .67297 L .33201 .6826 L p .707 .577 .707 r
F P
0 g
s
.20922 .70375 m .21261 .6697 L .24184 .66619 L p .707 .577 .707 r
F P
0 g
s
.29748 .58876 m .29189 .63929 L .26083 .63336 L p .707 .577 .707 r
F P
0 g
s
.26083 .63336 m .26641 .58283 L .29748 .58876 L p .707 .577 .707 r
F P
0 g
s
.22916 .63212 m .23474 .58159 L .26641 .58283 L p .707 .577 .707 r
F P
0 g
s
.23474 .58159 m .22916 .63212 L .19999 .63569 L p .707 .577 .707 r
F P
0 g
s
.17703 .77879 m .17954 .79785 L .16344 .79914 L p .707 .577 .707 r
F P
0 g
s
.16344 .79914 m .16093 .78008 L .17703 .77879 L p .707 .577 .707 r
F P
0 g
s
.62048 .26004 m .62048 .76193 L .59007 .75299 L p .707 .577 .707 r
F P
0 g
s
.59007 .75299 m .59007 .2511 L .62048 .26004 L p .707 .577 .707 r
F P
0 g
s
.26641 .58283 m .26083 .63336 L .22916 .63212 L p .707 .577 .707 r
F P
0 g
s
.30462 .67297 m .30122 .70702 L .27015 .70137 L p .707 .577 .707 r
F P
0 g
s
.27015 .70137 m .27355 .66732 L .30462 .67297 L p .707 .577 .707 r
F P
0 g
s
.23845 .70024 m .24184 .66619 L .27355 .66732 L p .707 .577 .707 r
F P
0 g
s
.24184 .66619 m .23845 .70024 L .20922 .70375 L p .707 .577 .707 r
F P
0 g
s
.38733 .25716 m .38733 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38733 .75905 m .38733 .25716 L .42068 .249 L p .707 .577 .707 r
F P
0 g
s
.27355 .66732 m .27015 .70137 L .23845 .70024 L p .707 .577 .707 r
F P
0 g
s
.73917 .638 m .73359 .58064 L .70252 .58333 L p .707 .577 .707 r
F P
0 g
s
.73359 .58064 m .73917 .638 L .77084 .63478 L p .707 .577 .707 r
F P
0 g
s
.77084 .63478 m .76526 .57742 L .73359 .58064 L p .707 .577 .707 r
F P
0 g
s
.70252 .58333 m .7081 .64069 L .73917 .638 L p .707 .577 .707 r
F P
0 g
s
.76526 .57742 m .77084 .63478 L .80001 .63133 L p .707 .577 .707 r
F P
0 g
s
.80001 .63133 m .79443 .57397 L .76526 .57742 L p .707 .577 .707 r
F P
0 g
s
.34063 .75695 m .34314 .77601 L .32215 .77949 L p .707 .577 .707 r
F P
0 g
s
.7081 .64069 m .70252 .58333 L .67509 .58521 L p .707 .577 .707 r
F P
0 g
s
.32215 .77949 m .31964 .76043 L .34063 .75695 L p .707 .577 .707 r
F P
0 g
s
.67509 .58521 m .68068 .64257 L .7081 .64069 L p .707 .577 .707 r
F P
0 g
s
.79443 .57397 m .80001 .63133 L .82382 .628 L p .707 .577 .707 r
F P
0 g
s
.82382 .628 m .81824 .57064 L .79443 .57397 L p .707 .577 .707 r
F P
0 g
s
.20078 .7763 m .20329 .79536 L .17954 .79785 L p .707 .577 .707 r
F P
0 g
s
.17954 .79785 m .17703 .77879 L .20078 .7763 L p .707 .577 .707 r
F P
0 g
s
.59007 .2511 m .59007 .75299 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59007 .2511 L p .707 .577 .707 r
F P
0 g
s
.68068 .64257 m .67509 .58521 L .65399 .58611 L p .707 .577 .707 r
F P
0 g
s
.65399 .58611 m .65957 .64347 L .68068 .64257 L p .707 .577 .707 r
F P
0 g
s
.42068 .75089 m .42068 .249 L .46179 .24401 L p .707 .577 .707 r
F P
0 g
s
.42068 .249 m .42068 .75089 L .38733 .75905 L p .707 .577 .707 r
F P
0 g
s
.31964 .76043 m .32215 .77949 L .29485 .78357 L p .707 .577 .707 r
F P
0 g
s
.29485 .78357 m .29234 .76451 L .31964 .76043 L p .707 .577 .707 r
F P
0 g
s
.81824 .57064 m .82382 .628 L .83995 .62511 L p .707 .577 .707 r
F P
0 g
s
.83995 .62511 m .83436 .56774 L .81824 .57064 L p .707 .577 .707 r
F P
0 g
s
.72984 .69502 m .72645 .65679 L .69538 .65906 L p .707 .577 .707 r
F P
0 g
s
.72645 .65679 m .72984 .69502 L .76155 .69202 L p .707 .577 .707 r
F P
0 g
s
.76155 .69202 m .75816 .65379 L .72645 .65679 L p .707 .577 .707 r
F P
0 g
s
.22985 .77285 m .23237 .79191 L .20329 .79536 L p .707 .577 .707 r
F P
0 g
s
.20329 .79536 m .20078 .7763 L .22985 .77285 L p .707 .577 .707 r
F P
0 g
s
.69538 .65906 m .69877 .69729 L .72984 .69502 L p .707 .577 .707 r
F P
0 g
s
.75816 .65379 m .76155 .69202 L .79078 .68859 L p .707 .577 .707 r
F P
0 g
s
.79078 .68859 m .78739 .65036 L .75816 .65379 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50664 .74455 L p .707 .577 .707 r
F P
0 g
s
.50664 .74455 m .50664 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.73608 .78785 m .73859 .77183 L .70766 .76465 L p .707 .577 .707 r
F P
0 g
s
.73859 .77183 m .73608 .78785 L .76763 .78969 L p .707 .577 .707 r
F P
0 g
s
.76763 .78969 m .77014 .77367 L .73859 .77183 L p .707 .577 .707 r
F P
0 g
s
.69877 .69729 m .69538 .65906 L .66799 .66039 L p .707 .577 .707 r
F P
0 g
s
.46179 .7459 m .46179 .24401 L .50664 .24266 L p .707 .577 .707 r
F P
0 g
s
.46179 .24401 m .46179 .7459 L .42068 .75089 L p .707 .577 .707 r
F P
0 g
s
.29234 .76451 m .29485 .78357 L .26392 .78785 L p .707 .577 .707 r
F P
0 g
s
.70514 .78066 m .70766 .76465 L .68036 .75282 L p .707 .577 .707 r
F P
0 g
s
.70766 .76465 m .70514 .78066 L .73608 .78785 L p .707 .577 .707 r
F P
0 g
s
.66799 .66039 m .67138 .69862 L .69877 .69729 L p .707 .577 .707 r
F P
0 g
s
.26392 .78785 m .2614 .76879 L .29234 .76451 L p .707 .577 .707 r
F P
0 g
s
.65957 .64347 m .65399 .58611 L .64128 .58593 L p .707 .577 .707 r
F P
0 g
s
.77014 .77367 m .76763 .78969 L .7967 .786 L p .707 .577 .707 r
F P
0 g
s
.7967 .786 m .79922 .76998 L .77014 .77367 L p .707 .577 .707 r
F P
0 g
s
.64128 .58593 m .64686 .64329 L .65957 .64347 L p .707 .577 .707 r
F P
0 g
s
.2614 .76879 m .26392 .78785 L .23237 .79191 L p .707 .577 .707 r
F P
0 g
s
.23237 .79191 m .22985 .77285 L .2614 .76879 L p .707 .577 .707 r
F P
0 g
s
.50664 .24266 m .50664 .74455 L .46179 .7459 L p .707 .577 .707 r
F P
0 g
s
.78739 .65036 m .79078 .68859 L .81469 .68506 L p .707 .577 .707 r
F P
0 g
s
.81469 .68506 m .81129 .64683 L .78739 .65036 L p .707 .577 .707 r
F P
0 g
s
.68036 .75282 m .67785 .76883 L .70514 .78066 L p .707 .577 .707 r
F P
0 g
s
.67785 .76883 m .68036 .75282 L .65937 .7375 L p .707 .577 .707 r
F P
0 g
s
.79922 .76998 m .7967 .786 L .82045 .77715 L p .707 .577 .707 r
F P
0 g
s
.82045 .77715 m .82297 .76113 L .79922 .76998 L p .707 .577 .707 r
F P
0 g
s
.67138 .69862 m .66799 .66039 L .64695 .66064 L p .707 .577 .707 r
F P
0 g
s
.64695 .66064 m .65034 .69887 L .67138 .69862 L p .707 .577 .707 r
F P
0 g
s
.83436 .56774 m .83995 .62511 L .84681 .62294 L p .707 .577 .707 r
F P
0 g
s
.84681 .62294 m .84123 .56557 L .83436 .56774 L p .707 .577 .707 r
F P
0 g
s
.65937 .7375 m .65686 .75352 L .67785 .76883 L p .707 .577 .707 r
F P
0 g
s
.81129 .64683 m .81469 .68506 L .83092 .68179 L p .707 .577 .707 r
F P
0 g
s
.83092 .68179 m .82753 .64356 L .81129 .64683 L p .707 .577 .707 r
F P
0 g
s
.64686 .64329 m .64128 .58593 L .63821 .58469 L p .707 .577 .707 r
F P
0 g
s
.65686 .75352 m .65937 .7375 L .64675 .7202 L p .707 .577 .707 r
F P
0 g
s
.63821 .58469 m .64379 .64205 L .64686 .64329 L p .707 .577 .707 r
F P
0 g
s
.82297 .76113 m .82045 .77715 L .83656 .76399 L p .707 .577 .707 r
F P
0 g
s
.83656 .76399 m .83907 .74797 L .82297 .76113 L p .707 .577 .707 r
F P
0 g
s
.65034 .69887 m .64695 .66064 L .63433 .6598 L p .707 .577 .707 r
F P
0 g
s
.64675 .7202 m .64424 .73622 L .65686 .75352 L p .707 .577 .707 r
F P
0 g
s
.63433 .6598 m .63772 .69802 L .65034 .69887 L p .707 .577 .707 r
F P
0 g
s
.84123 .56557 m .84681 .62294 L .84373 .6217 L p .707 .577 .707 r
F P
0 g
s
.84373 .6217 m .83815 .56434 L .84123 .56557 L p .707 .577 .707 r
F P
0 g
s
.64424 .73622 m .64675 .7202 L .64373 .7026 L p .707 .577 .707 r
F P
0 g
s
.82753 .64356 m .83092 .68179 L .83789 .67908 L p .707 .577 .707 r
F P
0 g
s
.83789 .67908 m .8345 .64085 L .82753 .64356 L p .707 .577 .707 r
F P
0 g
s
.83907 .74797 m .83656 .76399 L .84344 .74783 L p .707 .577 .707 r
F P
0 g
s
.84344 .74783 m .84595 .73181 L .83907 .74797 L p .707 .577 .707 r
F P
0 g
s
.64379 .64205 m .63821 .58469 L .64507 .58252 L p .707 .577 .707 r
F P
0 g
s
.64373 .7026 m .64122 .71862 L .64424 .73622 L p .707 .577 .707 r
F P
0 g
s
.64507 .58252 m .65065 .63988 L .64379 .64205 L p .707 .577 .707 r
F P
0 g
s
.63772 .69802 m .63433 .6598 L .63136 .65793 L p .707 .577 .707 r
F P
0 g
s
.63136 .65793 m .63475 .69616 L .63772 .69802 L p .707 .577 .707 r
F P
0 g
s
.83815 .56434 m .84373 .6217 L .83102 .62152 L p .707 .577 .707 r
F P
0 g
s
.83102 .62152 m .82544 .56416 L .83815 .56434 L p .707 .577 .707 r
F P
0 g
s
.64122 .71862 m .64373 .7026 L .65061 .68643 L p .707 .577 .707 r
F P
0 g
s
.84595 .73181 m .84344 .74783 L .84042 .73023 L p .707 .577 .707 r
F P
0 g
s
.84042 .73023 m .84293 .71421 L .84595 .73181 L p .707 .577 .707 r
F P
0 g
s
.8345 .64085 m .83789 .67908 L .83492 .67722 L p .707 .577 .707 r
F P
0 g
s
.83492 .67722 m .83153 .63899 L .8345 .64085 L p .707 .577 .707 r
F P
0 g
s
.65061 .68643 m .6481 .70245 L .64122 .71862 L p .707 .577 .707 r
F P
0 g
s
.4023 .6292 m .38946 .57671 L .35909 .58061 L p .707 .577 .707 r
F P
0 g
s
.38946 .57671 m .4023 .6292 L .43334 .62158 L p .707 .577 .707 r
F P
0 g
s
.43334 .62158 m .42051 .56909 L .38946 .57671 L p .707 .577 .707 r
F P
0 g
s
.42051 .56909 m .43334 .62158 L .46201 .61097 L p .707 .577 .707 r
F P
0 g
s
.46201 .61097 m .44918 .55848 L .42051 .56909 L p .707 .577 .707 r
F P
0 g
s
.65065 .63988 m .64507 .58252 L .66119 .57963 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66119 .57963 m .66678 .63699 L .65065 .63988 L p .707 .577 .707 r
F P
0 g
s
.63475 .69616 m .63136 .65793 L .63833 .65522 L p .707 .577 .707 r
F P
0 g
s
.37192 .6331 m .35909 .58061 L .33235 .58039 L p .707 .577 .707 r
F P
0 g
s
.35909 .58061 m .37192 .6331 L .4023 .6292 L p .707 .577 .707 r
F P
0 g
s
.44918 .55848 m .46201 .61097 L .48551 .59841 L p .707 .577 .707 r
F P
0 g
s
.48551 .59841 m .47268 .54592 L .44918 .55848 L p .707 .577 .707 r
F P
0 g
s
.63833 .65522 m .64173 .69345 L .63475 .69616 L p .707 .577 .707 r
F P
0 g
s
.38117 .69142 m .37334 .65616 L .34285 .65955 L p .707 .577 .707 r
F P
0 g
s
.37334 .65616 m .38117 .69142 L .41235 .68438 L p .707 .577 .707 r
F P
0 g
s
.41235 .68438 m .40452 .64913 L .37334 .65616 L p .707 .577 .707 r
F P
0 g
s
.40452 .64913 m .41235 .68438 L .44117 .6744 L p .707 .577 .707 r
F P
0 g
s
.44117 .6744 m .43334 .63914 L .40452 .64913 L p .707 .577 .707 r
F P
0 g
s
.6481 .70245 m .65061 .68643 L .66672 .67328 L p .707 .577 .707 r
F P
0 g
s
.82544 .56416 m .83102 .62152 L .80992 .62242 L p .707 .577 .707 r
F P
0 g
s
.80992 .62242 m .80434 .56506 L .82544 .56416 L p .707 .577 .707 r
F P
0 g
s
.84293 .71421 m .84042 .73023 L .8278 .71293 L p .707 .577 .707 r
F P
0 g
s
.8278 .71293 m .83031 .69691 L .84293 .71421 L p .707 .577 .707 r
F P
0 g
s
.35067 .69481 m .34285 .65955 L .31603 .65898 L p .707 .577 .707 r
F P
0 g
s
.34285 .65955 m .35067 .69481 L .38117 .69142 L p .707 .577 .707 r
F P
0 g
s
.43334 .63914 m .44117 .6744 L .4648 .66243 L p .707 .577 .707 r
F P
0 g
s
.4648 .66243 m .45698 .62717 L .43334 .63914 L p .707 .577 .707 r
F P
0 g
s
.83153 .63899 m .83492 .67722 L .8223 .67637 L p .707 .577 .707 r
F P
0 g
s
.8223 .67637 m .81891 .63814 L .83153 .63899 L p .707 .577 .707 r
F P
0 g
s
.66672 .67328 m .6642 .6893 L .6481 .70245 L p .707 .577 .707 r
F P
0 g
s
.34518 .63288 m .33235 .58039 L .31187 .57608 L p .707 .577 .707 r
F P
0 g
s
.33235 .58039 m .34518 .63288 L .37192 .6331 L p .707 .577 .707 r
F P
0 g
s
.47268 .54592 m .48551 .59841 L .50153 .58514 L p .707 .577 .707 r
F P
0 g
s
.50153 .58514 m .48869 .53265 L .47268 .54592 L p .707 .577 .707 r
F P
0 g
s
.66678 .63699 m .66119 .57963 L .68501 .5763 L p .707 .577 .707 r
F P
0 g
s
.68501 .5763 m .69059 .63366 L .66678 .63699 L p .707 .577 .707 r
F P
0 g
s
.39486 .70662 m .40058 .68845 L .37089 .67824 L p .707 .577 .707 r
F P
0 g
s
.40058 .68845 m .39486 .70662 L .42528 .71563 L p .707 .577 .707 r
F P
0 g
s
.42528 .71563 m .431 .69746 L .40058 .68845 L p .707 .577 .707 r
F P
0 g
s
.31603 .65898 m .32386 .69423 L .35067 .69481 L p .707 .577 .707 r
F P
0 g
s
.64173 .69345 m .63833 .65522 L .65457 .65195 L p .707 .577 .707 r
F P
0 g
s
.37089 .67824 m .36517 .69641 L .39486 .70662 L p .707 .577 .707 r
F P
0 g
s
.6642 .6893 m .66672 .67328 L .69047 .66443 L p .707 .577 .707 r
F P
0 g
s
.431 .69746 m .42528 .71563 L .45346 .72256 L p .707 .577 .707 r
F P
0 g
s
.45346 .72256 m .45918 .70438 L .431 .69746 L p .707 .577 .707 r
F P
0 g
s
.32386 .69423 m .31603 .65898 L .29552 .65448 L p .707 .577 .707 r
F P
0 g
s
.65457 .65195 m .65796 .69018 L .64173 .69345 L p .707 .577 .707 r
F P
0 g
s
.80434 .56506 m .80992 .62242 L .78249 .6243 L p .707 .577 .707 r
F P
0 g
s
.78249 .6243 m .77691 .56694 L .80434 .56506 L p .707 .577 .707 r
F P
0 g
s
.45698 .62717 m .4648 .66243 L .48095 .64967 L p .707 .577 .707 r
F P
0 g
s
.48095 .64967 m .47312 .61441 L .45698 .62717 L p .707 .577 .707 r
F P
0 g
s
.36517 .69641 m .37089 .67824 L .34484 .66783 L p .707 .577 .707 r
F P
0 g
s
.83031 .69691 m .8278 .71293 L .80681 .69761 L p .707 .577 .707 r
F P
0 g
s
.80681 .69761 m .80932 .68159 L .83031 .69691 L p .707 .577 .707 r
F P
0 g
s
.34484 .66783 m .33912 .68601 L .36517 .69641 L p .707 .577 .707 r
F P
0 g
s
.31187 .57608 m .32471 .62858 L .34518 .63288 L p .707 .577 .707 r
F P
0 g
s
.69059 .63366 m .68501 .5763 L .71418 .57285 L p .707 .577 .707 r
F P
0 g
s
.69047 .66443 m .68795 .68044 L .6642 .6893 L p .707 .577 .707 r
F P
0 g
s
.32471 .62858 m .31187 .57608 L .29966 .56811 L p .707 .577 .707 r
F P
0 g
s
.48869 .53265 m .50153 .58514 L .5085 .57245 L p .707 .577 .707 r
F P
0 g
s
.5085 .57245 m .49566 .51996 L .48869 .53265 L p .707 .577 .707 r
F P
0 g
s
.71418 .57285 m .71976 .63021 L .69059 .63366 L p .707 .577 .707 r
F P
0 g
s
.45918 .70438 m .45346 .72256 L .47664 .72673 L p .707 .577 .707 r
F P
0 g
s
.47664 .72673 m .48236 .70855 L .45918 .70438 L p .707 .577 .707 r
F P
0 g
s
.29552 .65448 m .30334 .68974 L .32386 .69423 L p .707 .577 .707 r
F P
0 g
s
.81891 .63814 m .8223 .67637 L .80126 .67662 L p .707 .577 .707 r
F P
0 g
s
.80126 .67662 m .79787 .63839 L .81891 .63814 L p .707 .577 .707 r
F P
0 g
s
.33912 .68601 m .34484 .66783 L .32498 .65824 L p .707 .577 .707 r
F P
0 g
s
.77691 .56694 m .78249 .6243 L .75143 .62699 L p .707 .577 .707 r
F P
0 g
s
.75143 .62699 m .74584 .56963 L .77691 .56694 L p .707 .577 .707 r
F P
0 g
s
.68795 .68044 m .69047 .66443 L .71954 .66074 L p .707 .577 .707 r
F P
0 g
s
.32498 .65824 m .31926 .67642 L .33912 .68601 L p .707 .577 .707 r
F P
0 g
s
.80932 .68159 m .80681 .69761 L .77951 .68578 L p .707 .577 .707 r
F P
0 g
s
.77951 .68578 m .78203 .66976 L .80932 .68159 L p .707 .577 .707 r
F P
0 g
s
.71976 .63021 m .71418 .57285 L .74584 .56963 L p .707 .577 .707 r
F P
0 g
s
.74584 .56963 m .75143 .62699 L .71976 .63021 L p .707 .577 .707 r
F P
0 g
s
.30334 .68974 m .29552 .65448 L .28331 .64651 L p .707 .577 .707 r
F P
0 g
s
.65796 .69018 m .65457 .65195 L .67847 .64843 L p .707 .577 .707 r
F P
0 g
s
.47312 .61441 m .48095 .64967 L .48801 .63735 L p .707 .577 .707 r
F P
0 g
s
.48801 .63735 m .48019 .60209 L .47312 .61441 L p .707 .577 .707 r
F P
0 g
s
.67847 .64843 m .68186 .68666 L .65796 .69018 L p .707 .577 .707 r
F P
0 g
s
.71954 .66074 m .71703 .67676 L .68795 .68044 L p .707 .577 .707 r
F P
0 g
s
.29966 .56811 m .31249 .6206 L .32471 .62858 L p .707 .577 .707 r
F P
0 g
s
.71703 .67676 m .71954 .66074 L .75109 .66258 L p .707 .577 .707 r
F P
0 g
s
.78203 .66976 m .77951 .68578 L .74858 .6786 L p .707 .577 .707 r
F P
0 g
s
.74858 .6786 m .75109 .66258 L .78203 .66976 L p .707 .577 .707 r
F P
0 g
s
.48236 .70855 m .47664 .72673 L .49255 .72773 L p .707 .577 .707 r
F P
0 g
s
.49255 .72773 m .49826 .70955 L .48236 .70855 L p .707 .577 .707 r
F P
0 g
s
.75109 .66258 m .74858 .6786 L .71703 .67676 L p .707 .577 .707 r
F P
0 g
s
.28331 .64651 m .29114 .68176 L .30334 .68974 L p .707 .577 .707 r
F P
0 g
s
.79787 .63839 m .80126 .67662 L .77387 .67795 L p .707 .577 .707 r
F P
0 g
s
.77387 .67795 m .77048 .63972 L .79787 .63839 L p .707 .577 .707 r
F P
0 g
s
.31249 .6206 m .29966 .56811 L .2969 .55725 L p .709 .579 .707 r
F P
0 g
s
.49566 .51996 m .5085 .57245 L .50574 .56159 L p .709 .579 .707 r
F P
0 g
s
.50574 .56159 m .49291 .5091 L .49566 .51996 L p .709 .579 .707 r
F P
0 g
s
.31926 .67642 m .32498 .65824 L .31325 .65041 L p .707 .577 .707 r
F P
0 g
s
.31325 .65041 m .30753 .66859 L .31926 .67642 L p .707 .577 .707 r
F P
0 g
s
.68186 .68666 m .67847 .64843 L .70771 .645 L p .707 .577 .707 r
F P
0 g
s
.70771 .645 m .7111 .68323 L .68186 .68666 L p .707 .577 .707 r
F P
0 g
s
.29114 .68176 m .28331 .64651 L .28061 .63584 L p .708 .578 .707 r
F P
0 g
s
.77048 .63972 m .77387 .67795 L .7428 .68023 L p .707 .577 .707 r
F P
0 g
s
.7428 .68023 m .73941 .642 L .77048 .63972 L p .707 .577 .707 r
F P
0 g
s
.48019 .60209 m .48801 .63735 L .48531 .62668 L p .708 .578 .707 r
F P
0 g
s
.48531 .62668 m .47748 .59142 L .48019 .60209 L p .708 .578 .707 r
F P
0 g
s
.2969 .55725 m .30973 .60974 L .31249 .6206 L p .709 .579 .707 r
F P
0 g
s
.7111 .68323 m .70771 .645 L .73941 .642 L p .707 .577 .707 r
F P
0 g
s
.73941 .642 m .7428 .68023 L .7111 .68323 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49826 .70955 m .49255 .72773 L .49962 .72547 L p .707 .577 .707 r
F P
0 g
s
.49962 .72547 m .50534 .70729 L .49826 .70955 L p .707 .577 .707 r
F P
0 g
s
.28061 .63584 m .28843 .6711 L .29114 .68176 L p .708 .578 .707 r
F P
0 g
s
.30973 .60974 m .2969 .55725 L .30387 .54456 L p .707 .577 .707 r
F P
0 g
s
.49291 .5091 m .50574 .56159 L .49352 .55362 L p .707 .577 .707 r
F P
0 g
s
.49352 .55362 m .48069 .50113 L .49291 .5091 L p .707 .577 .707 r
F P
0 g
s
.30753 .66859 m .31325 .65041 L .3108 .64511 L p .707 .577 .707 r
F P
0 g
s
.3108 .64511 m .30509 .66328 L .30753 .66859 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28843 .6711 m .28061 .63584 L .28767 .62352 L p .707 .577 .707 r
F P
0 g
s
.47748 .59142 m .48531 .62668 L .4731 .6187 L p .707 .577 .707 r
F P
0 g
s
.4731 .6187 m .46528 .58345 L .47748 .59142 L p .707 .577 .707 r
F P
0 g
s
.30387 .54456 m .31671 .59705 L .30973 .60974 L p .707 .577 .707 r
F P
0 g
s
.50534 .70729 m .49962 .72547 L .49718 .72016 L p .707 .577 .707 r
F P
0 g
s
.49718 .72016 m .50289 .70199 L .50534 .70729 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28767 .62352 m .2955 .65877 L .28843 .6711 L p .707 .577 .707 r
F P
0 g
s
.31671 .59705 m .30387 .54456 L .31989 .53129 L p .707 .577 .707 r
F P
0 g
s
.48069 .50113 m .49352 .55362 L .47305 .54931 L p .707 .577 .707 r
F P
0 g
s
.47305 .54931 m .46021 .49682 L .48069 .50113 L p .707 .577 .707 r
F P
0 g
s
.30509 .66328 m .3108 .64511 L .31788 .64284 L p .707 .577 .707 r
F P
0 g
s
.31788 .64284 m .31216 .66102 L .30509 .66328 L p .707 .577 .707 r
F P
0 g
s
.2955 .65877 m .28767 .62352 L .30381 .61075 L p .707 .577 .707 r
F P
0 g
s
.46528 .58345 m .4731 .6187 L .45259 .61421 L p .707 .577 .707 r
F P
0 g
s
.45259 .61421 m .44476 .57895 L .46528 .58345 L p .707 .577 .707 r
F P
0 g
s
.31989 .53129 m .33272 .58378 L .31671 .59705 L p .707 .577 .707 r
F P
0 g
s
.33272 .58378 m .31989 .53129 L .34338 .51873 L p .707 .577 .707 r
F P
0 g
s
.46021 .49682 m .47305 .54931 L .44631 .54909 L p .707 .577 .707 r
F P
0 g
s
.44631 .54909 m .43348 .4966 L .46021 .49682 L p .707 .577 .707 r
F P
0 g
s
.30381 .61075 m .31164 .64601 L .2955 .65877 L p .707 .577 .707 r
F P
0 g
s
.50289 .70199 m .49718 .72016 L .48545 .71233 L p .707 .577 .707 r
F P
0 g
s
.48545 .71233 m .49117 .69415 L .50289 .70199 L p .707 .577 .707 r
F P
0 g
s
.31216 .66102 m .31788 .64284 L .33379 .64385 L p .707 .577 .707 r
F P
0 g
s
.33379 .64385 m .32807 .66202 L .31216 .66102 L p .707 .577 .707 r
F P
0 g
s
.31164 .64601 m .30381 .61075 L .32745 .59879 L p .707 .577 .707 r
F P
0 g
s
.44476 .57895 m .45259 .61421 L .42577 .61363 L p .707 .577 .707 r
F P
0 g
s
.42577 .61363 m .41795 .57837 L .44476 .57895 L p .707 .577 .707 r
F P
0 g
s
.35622 .57122 m .34338 .51873 L .37206 .50812 L p .707 .577 .707 r
F P
0 g
s
.34338 .51873 m .35622 .57122 L .33272 .58378 L p .707 .577 .707 r
F P
0 g
s
.43348 .4966 m .44631 .54909 L .41593 .55299 L p .707 .577 .707 r
F P
0 g
s
.41593 .55299 m .4031 .5005 L .43348 .4966 L p .707 .577 .707 r
F P
0 g
s
.38489 .56062 m .37206 .50812 L .4031 .5005 L p .707 .577 .707 r
F P
0 g
s
.37206 .50812 m .38489 .56062 L .35622 .57122 L p .707 .577 .707 r
F P
0 g
s
.4031 .5005 m .41593 .55299 L .38489 .56062 L p .707 .577 .707 r
F P
0 g
s
.32745 .59879 m .33528 .63405 L .31164 .64601 L p .707 .577 .707 r
F P
0 g
s
.49117 .69415 m .48545 .71233 L .46559 .70274 L p .707 .577 .707 r
F P
0 g
s
.46559 .70274 m .47131 .68457 L .49117 .69415 L p .707 .577 .707 r
F P
0 g
s
.33528 .63405 m .32745 .59879 L .35627 .5888 L p .707 .577 .707 r
F P
0 g
s
.41795 .57837 m .42577 .61363 L .39528 .61702 L p .707 .577 .707 r
F P
0 g
s
.39528 .61702 m .38745 .58176 L .41795 .57837 L p .707 .577 .707 r
F P
0 g
s
.32807 .66202 m .33379 .64385 L .35696 .64801 L p .707 .577 .707 r
F P
0 g
s
.35696 .64801 m .35125 .66619 L .32807 .66202 L p .707 .577 .707 r
F P
0 g
s
.3641 .62406 m .35627 .5888 L .38745 .58176 L p .707 .577 .707 r
F P
0 g
s
.35627 .5888 m .3641 .62406 L .33528 .63405 L p .707 .577 .707 r
F P
0 g
s
.38745 .58176 m .39528 .61702 L .3641 .62406 L p .707 .577 .707 r
F P
0 g
s
.47131 .68457 m .46559 .70274 L .43954 .69233 L p .707 .577 .707 r
F P
0 g
s
.43954 .69233 m .44526 .67416 L .47131 .68457 L p .707 .577 .707 r
F P
0 g
s
.35125 .66619 m .35696 .64801 L .38514 .65494 L p .707 .577 .707 r
F P
0 g
s
.38514 .65494 m .37942 .67312 L .35125 .66619 L p .707 .577 .707 r
F P
0 g
s
.44526 .67416 m .43954 .69233 L .40985 .68213 L p .707 .577 .707 r
F P
0 g
s
.40985 .68213 m .41557 .66395 L .44526 .67416 L p .707 .577 .707 r
F P
0 g
s
.37942 .67312 m .38514 .65494 L .41557 .66395 L p .707 .577 .707 r
F P
0 g
s
.41557 .66395 m .40985 .68213 L .37942 .67312 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF3P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF000010001eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00HGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo0`0025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00GGoo0P000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FWoo00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00FGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001FOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`03
001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPh0
00=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH70006FUH20004FUH00`00FUH000030002FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP02FUH5000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60005FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002
FUH50004FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000YOol?000]Ool005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020004FUH50003FUH30007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000087oo2@000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo00@0
05YFFUH000AJEP03001JEUYF00EJEP<000IJEPP00003FUH005YF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0000?OolA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol0
1000FUIJEP0015YF00<005YFFUH00eYF0`0000=JEP00FUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`04001JEUYF0003FUH01000FUIJEUYF
0P000Woo00<005YF00000eYF1@000eYF3`001UYF00<005YFFUH00UYF00@005YF000000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003moo`l000Qoo`04001JEUYF0004FUH=00000eYF000000050003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00@000Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD0009JEP07001JEUYFFUH005YF000015YF10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002eoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP80009JEP03001JEUYF00800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
<Goo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800004FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000`Ool01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;goo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF3P000eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001J
EP00008000=JEP@00003FUH0000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YFFUH01EYF1000
1UYF0P0000EJEP00001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000/Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP@000QJEP03001JEUYF00@000UJEP03001JEUYF009JEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ40009JEP@002aoo`00
;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF1P000UYF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH01UYF00@005YFFUIJEPH0031oo`00;Goo0P000eYF00<005YFFUH00eYF
00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH01EYF00<005YF
000010000eYF00<005YFFUH01`0015YF00<005YFFUH01EYF0`001EYF00@005YF000000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPP00003FUH005YF00MJEP03001JEUYF009JEPL003Ioo`00;7oo
00<005YF00000eYF00<005YFFUH00eYF1@002Goo200000EJEP00FUIJEP0000AJEP03001JEUYF00AJ
EP@000=JEPL0009JEPD000AJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP03FUH01000FUIJEUYF2@0025YF00<005YFFUH00UYF2@00?Goo000/Ool00`00FUH00003FUH01000
FUIJEUYF0P005Woo0P000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP07001JEUYFFUH005YF
00001UYF1@0015YF00<005YFFUH00`001EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000P000MJEP03
001JEUYF009JEQl0031oo`00;7oo00<005YF00000eYF00@005YF000001Uoo`04001JEUYF0005FUH0
1000FUH000001EYF00L005YFFUIJEP00FUH00006FUH40005FUH300000eYF001JEP05FUH00`00FUIJ
EP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUHR
0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool20004FUH2000L
Ool01000FUIJEP0015YF0`0000=JEP00000010000eYF00<005YF00001UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00003Goo2@0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo0P000UYF0P007Woo00@005YFFUH000=J
EP<000AJEP04001JEUYFFUH60006FUH00`00FUIJEP030008FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool4000015YF0000000057oo0`001Goo00@005YFFUH0
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEP0000<0009JEP@00003FUH005YF00QJ
EP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH000060002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool00eYF001J
EP02FUH01000FUIJEP004Woo1@0017oo00@005YFFUIJEPD000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0009FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool30003FUH01000FUIJEUYF0P0047oo1@0017oo00P005YFFUIJEP00FUH005YF
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100025YF00<005YFFUH01EYF0P00
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00:goo0`000eYF00<005YFFUH00eYF0P003Woo1@001Goo0UYF
0P0000AJEP000000009JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF
00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00:goo00<005YF00000eYF00<005YFFUH00eYF
00@005YF000000Ioo`l00003OomJEP00009JEP8000AJEP03001JEUYF009JEPD000MJEP03001JEUYF
00MJEP04001JEP000003FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF00<005YF00000eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF100000=JEP0000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00`001UYF00<005YFFUH00UYF0P0000=JEP0000000`001eYF00<005YF
FUH01EYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool00`00FUIJEP02
FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF10000UYF10000UYF00<005YFFUH01eYF00H0
05YF000005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF5`00;Woo000/Ool01@00FUIJEUYF00000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF00@005YFFUH000EJEP8000AJEP03001JEUYF00EJEP04001JEP000002FUH70007
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPX000AJEP03
001JEUYF00EJEP<0009JEPD002ioo`00;7oo00H005YFFUIJEP00FUH200000eYF001JEP05FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF00H005YF000005YF0007
FUH00`00FUIJEP02FUH;0005FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPX0
00QJEP@00003FUH005YF00MJEP@003=oo`00;Goo00<005YFFUH00P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00@005YFFUIJEP<000IJEP03001J
EUYF00=JEPD000AJEP@00003FUH005YF00MJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04
001JEUYFFUH30007FUH00`00FUH0000dOol002ioo`04001JEP000003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH20004FUH00`00
FUIJEP03FUH800000eYF001JEP02FUH30007FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEP03
001JEUYF009JEPT0009oo`8000AJEP05001JEUYFFUH0000cOol002ioo`04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@0000=J
EP00FUH01UYF0`0015YF0`001EYF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP04001JEUYF0007FUH00`00FUIJEP02
FUH9000=Ool300000eYF001JEP03FUH00`00Oomoo`0`Ool002moo`03001JEP00009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPH000IJEP03001JEUYF00IJEP<000AJEP<00003FUH005YF00EJEP<0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH00000014001Uoo`8000EJ
EP03001oogoo02moo`00;goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00MJEP03001J
EP0000<000=JEP8000EJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP03001JEUYF009JEP03001oogoo01eoo`8000=J
EP80031oo`00;goo0P000eYF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF10000UYF00<005YF
FUH01EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF10001eYF00<005YFFUH015YF1`000eYF00L0
05YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001EYF
001JEUYF00001EYF00@005YFFUIJEP80025oo`06001JEUYF001JEP00;goo000_Ool20003FUH00`00
FUH000030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH200000eYF001JEP05FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEP@000AJ
EP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol300000eYF001oo`0^Ool002moo`8000=JEP@000EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF009JEP03001JEUYF
009JEP8002Aoo`04001JEUYF000^Ool002moo`80009JEP03001oogoo009oo`8000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH01@00FUH005YF00001UYF
00<005YFFUH01UYF0`001eYF00<005YFFUH015YF00L005YF000005YF001JEP02000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000:Ool3000HOol01000FUIJEP00;Goo000^Ool00`00FUH000020007Ool200000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH01@00FUH005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000:Ool5000GOol01000FUIJEP00;Goo000^Ool00`00FUH0000;Ool40006FUH00`00FUH0
00020004FUH00`00FUIJEP05FUH00`00FUH000030003Ool02000FUIJEP00FUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P002Woo1@0067oo0`00
;Goo000^Ool200000eYF001oo`0=Ool40002FUH60003FUH00`00FUIJEP02FUH50008Ool3000015YF
001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF300000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P000UYF00<005YFFUH00UYF0P002Woo
1@0067oo0P0000=JEP00Ool0:goo000^Ool20002FUH00`00Oomoo`0?Ool@000?Ool01@00FUH005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP8000]oo`<0
01Yoo`03001JEP0002aoo`00;Woo0P000eYF00<007ooOol04Goo1@0067oo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000eYF00<005YF0000:7oo
00<005YF0000;7oo000^Ool00`00FUIJEP02FUH3000BOol3000IOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH400001eYF000005YF001JEP0002Qoo`03001J
EP0002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH00P00;Goo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00@005YF0000009JEP800005FUH00000001JEP03000ZOol00`00Oomoo`0[
Ool002ioo`03001JEUYF009JEP03001JEUYF009JEP<002Uoo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP000002FUH00`00FUH00003FUH4000YOol2000]Ool002ioo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEP00000VOol01@00FUH005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH015YF30000UYF00<005YFFUH01eYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEP8000=JEP80009JEP03001JEP00008002Moo`8002eoo`00;Woo00D005YFFUIJEP0000IJ
EP04001JEUYFFUH3000QOol20002FUH00`00FUH00006FUH00`00FUIJEP04FUH900000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH005YF0P001EYF00<005YF000015YF0P0097oo0`00;Goo000_Ool01000FUIJEP001UYF00<005YF
FUH015YF10005goo2`0000=JEP00FUH01EYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF00@005YF001JEP8000IJEP8000EJEP<0
021oo`800003FUH007oo02eoo`00<7oo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01000
37oo1`000eYF1@0000EJEP00001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP06001JEP00
FUH005YF0P0015YF00@005YF000000=JEP04001JEUYF000NOol00`00FUIJEP02000^Ool0035oo`80
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`000=JEPL0009JEP04001JEUYFFUH200000eYF001J
EP02FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH30004FUH01@00FUH005YF00000eYF00@005YFFUH000AJEP<000=JEP03001oogoo
01Yoo`8000=JEP03001oogoo02eoo`00<Woo00<005YFFUH00eYF00<005YFFUH01UYF2P0015YF2000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001JEP<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04
001JEP000005FUH30007FUH5000HOol300000eYF001JEP02FUH00`00Oomoo`0]Ool003=oo`8000=J
EP03001JEP0000L000AJEPT000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF0P001eYF00<005YF0000
0`0047oo1P0015YF00@005YFFUH0031oo`00=7oo1P000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP04001JEP000004FUH00`00FUIJEP04FUH@0004FUH00`00FUIJEP03FUH3000a
Ool002moo`D0009JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000050002FUH01000FUIJ
EUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00<goo
000[Ool;0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
0002FUH300000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001UYF0`00
1UYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8003Eoo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P000UYF
00<005YFFUH00eYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000IJ
EP03001JEUYF008000=JEP04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH00000=goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP050007FUH01000FUIJEUYF0P001Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH000IJEP04001JEUYFFUH300000eYF001JEP02FUH200001Woo00000000FUH000QJ
EP03001JEUYF009JEPD003Uoo`00:goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH00UYF1`0015YF00<005YFFUH01EYF00@005YF000000Qoo`03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEP0000Aoo`l003ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4000
15YF00<005YFFUH00UYF1@002Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
1eYF00D005YFFUIJEP00009JEP03001JEUYF00<00003FUH007oo051oo`00;7oo00<005YF00000UYF
3@0047oo2@0047oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH01UYF00D005YF
FUIJEP0000=JEP04001JEUYFFUH2001BOol002aoo`D003Qoo`<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH0
0`00FUIJEP020003FUH00`00FUIJEP03001BOol006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000L000AJEP04001J
EUYF0002FUH00`00FUH00003FUH00`00FUH0001BOol006eoo`<000AJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000Qoo`L000=JEP03001J
EP0000D005=oo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01P0047oo00<005YFFUH00eYF00<007ooOol0Egoo001cOol40008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH50002Ool5000=Ool30005FUH00`00Oomoo`1G
Ool007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH60007Ool5000<Ool0
1000FUIJEP0015YF00<007ooOol0F7oo001mOolO000=Ool5000;Ool00`00FUIJEP02FUH01000FUH0
0000Fgoo002=Ool00`00FUH00003FUH00`00Oomoo`0DOol3000:Ool20005FUH2001MOol008aoo`04
001JEUYF0002FUH00`00Oomoo`0POol20007FUH00`00Oomoo`1LOol008aoo`04001JEUYFFUH2000Q
Ool200000eYF001JEP04FUH2001OOol008aoo`05001JEUYFFUH0000OOol30004FUH01@00FUIJEUYF
0000HGoo002<Ool200000eYF001oo`0LOol30007FUH01000FUH00000HWoo002=Ool00`00FUH0000K
Ool200000eYF001JEP08FUH00`00Oomoo`1ROol008eoo`03FUH007oo01Qoo`<000AJEP03001JEUYF
00AJEP8006Eoo`00SGoo0`0057oo10001eYF00<005YFFUH00UYF0P00Igoo002=Ool2000015YF0000
00003Goo10000UYF00<005YFFUH01eYF00@005YF000006Uoo`00SWoo00<005YF00000UYF3@001UYF
00<005YFFUH01UYF0`00Jgoo002>Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH00UYF0`00KWoo002?Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH00002001aOol0091oo`<000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD007Aoo`00TWoo
0`000UYF00<005YFFUH00UYF2000NGoo002EOol70021Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58406 .73895 m .5969 .68356 L .56652 .67549 L p .707 .577 .707 r
F P
0 g
s
.5969 .68356 m .58406 .73895 L .61511 .74543 L p .707 .577 .707 r
F P
0 g
s
.61511 .74543 m .62794 .69004 L .5969 .68356 L p .707 .577 .707 r
F P
0 g
s
.62794 .69004 m .61511 .74543 L .64378 .74969 L p .707 .577 .707 r
F P
0 g
s
.64378 .74969 m .65661 .6943 L .62794 .69004 L p .707 .577 .707 r
F P
0 g
s
.55369 .73088 m .56652 .67549 L .53978 .66662 L p .707 .577 .707 r
F P
0 g
s
.56652 .67549 m .55369 .73088 L .58406 .73895 L p .707 .577 .707 r
F P
0 g
s
.53978 .66662 m .52695 .72201 L .55369 .73088 L p .707 .577 .707 r
F P
0 g
s
.65661 .6943 m .64378 .74969 L .66727 .7513 L p .707 .577 .707 r
F P
0 g
s
.66727 .7513 m .68011 .69591 L .65661 .6943 L p .707 .577 .707 r
F P
0 g
s
.52695 .72201 m .53978 .66662 L .51931 .65781 L p .707 .577 .707 r
F P
0 g
s
.60472 .79824 m .61254 .76121 L .58205 .75366 L p .707 .577 .707 r
F P
0 g
s
.61254 .76121 m .60472 .79824 L .6359 .8041 L p .707 .577 .707 r
F P
0 g
s
.6359 .8041 m .64372 .76707 L .61254 .76121 L p .707 .577 .707 r
F P
0 g
s
.51931 .65781 m .50647 .7132 L .52695 .72201 L p .707 .577 .707 r
F P
0 g
s
.64372 .76707 m .6359 .8041 L .66472 .8077 L p .707 .577 .707 r
F P
0 g
s
.66472 .8077 m .67254 .77068 L .64372 .76707 L p .707 .577 .707 r
F P
0 g
s
.57423 .79069 m .58205 .75366 L .55524 .74517 L p .707 .577 .707 r
F P
0 g
s
.58205 .75366 m .57423 .79069 L .60472 .79824 L p .707 .577 .707 r
F P
0 g
s
.68011 .69591 m .66727 .7513 L .68329 .75011 L p .707 .577 .707 r
F P
0 g
s
.68329 .75011 m .69612 .69472 L .68011 .69591 L p .707 .577 .707 r
F P
0 g
s
.62057 .85656 m .61486 .83964 L .58443 .84936 L p .707 .577 .707 r
F P
0 g
s
.61486 .83964 m .62057 .85656 L .64875 .84369 L p .707 .577 .707 r
F P
0 g
s
.64875 .84369 m .64303 .82678 L .61486 .83964 L p .707 .577 .707 r
F P
0 g
s
.55524 .74517 m .54741 .78219 L .57423 .79069 L p .707 .577 .707 r
F P
0 g
s
.59015 .86628 m .58443 .84936 L .55474 .85499 L p .707 .577 .707 r
F P
0 g
s
.58443 .84936 m .59015 .86628 L .62057 .85656 L p .707 .577 .707 r
F P
0 g
s
.50647 .7132 m .51931 .65781 L .50709 .64993 L p .707 .577 .707 r
F P
0 g
s
.67254 .77068 m .66472 .8077 L .68836 .80869 L p .707 .577 .707 r
F P
0 g
s
.68836 .80869 m .69618 .77167 L .67254 .77068 L p .707 .577 .707 r
F P
0 g
s
.64303 .82678 m .64875 .84369 L .67193 .82895 L p .707 .577 .707 r
F P
0 g
s
.67193 .82895 m .66621 .81203 L .64303 .82678 L p .707 .577 .707 r
F P
0 g
s
.55474 .85499 m .56046 .87191 L .59015 .86628 L p .707 .577 .707 r
F P
0 g
s
.54741 .78219 m .55524 .74517 L .53472 .73656 L p .707 .577 .707 r
F P
0 g
s
.56046 .87191 m .55474 .85499 L .52869 .85598 L p .707 .577 .707 r
F P
0 g
s
.50709 .64993 m .49426 .70532 L .50647 .7132 L p .707 .577 .707 r
F P
0 g
s
.53472 .73656 m .5269 .77358 L .54741 .78219 L p .707 .577 .707 r
F P
0 g
s
.52869 .85598 m .53441 .87289 L .56046 .87191 L p .707 .577 .707 r
F P
0 g
s
.66621 .81203 m .67193 .82895 L .68783 .81376 L p .707 .577 .707 r
F P
0 g
s
.68783 .81376 m .68212 .79685 L .66621 .81203 L p .707 .577 .707 r
F P
0 g
s
.69612 .69472 m .68329 .75011 L .69026 .74623 L p .707 .577 .707 r
F P
0 g
s
.69026 .74623 m .7031 .69084 L .69612 .69472 L p .707 .577 .707 r
F P
0 g
s
.69618 .77167 m .68836 .80869 L .7045 .80698 L p .707 .577 .707 r
F P
0 g
s
.7045 .80698 m .71232 .76995 L .69618 .77167 L p .707 .577 .707 r
F P
0 g
s
.53441 .87289 m .52869 .85598 L .50883 .85222 L p .707 .577 .707 r
F P
0 g
s
.49426 .70532 m .50709 .64993 L .50433 .64375 L p .707 .577 .707 r
F P
0 g
s
.5269 .77358 m .53472 .73656 L .52251 .72868 L p .707 .577 .707 r
F P
0 g
s
.50883 .85222 m .51455 .86913 L .53441 .87289 L p .707 .577 .707 r
F P
0 g
s
.52251 .72868 m .51469 .7657 L .5269 .77358 L p .707 .577 .707 r
F P
0 g
s
.50433 .64375 m .4915 .69914 L .49426 .70532 L p .707 .577 .707 r
F P
0 g
s
.68212 .79685 m .68783 .81376 L .69491 .79963 L p .707 .577 .707 r
F P
0 g
s
.69491 .79963 m .68919 .78271 L .68212 .79685 L p .707 .577 .707 r
F P
0 g
s
.71232 .76995 m .7045 .80698 L .71156 .80272 L p .707 .577 .707 r
F P
0 g
s
.71156 .80272 m .71939 .76569 L .71232 .76995 L p .707 .577 .707 r
F P
0 g
s
.51455 .86913 m .50883 .85222 L .4971 .84409 L p .707 .577 .707 r
F P
0 g
s
.7031 .69084 m .69026 .74623 L .6875 .74006 L p .707 .577 .707 r
F P
0 g
s
.6875 .74006 m .70034 .68467 L .7031 .69084 L p .707 .577 .707 r
F P
0 g
s
.51469 .7657 m .52251 .72868 L .51981 .72229 L p .707 .577 .707 r
F P
0 g
s
.4971 .84409 m .50282 .86101 L .51455 .86913 L p .707 .577 .707 r
F P
0 g
s
.4915 .69914 m .50433 .64375 L .51131 .63988 L p .707 .577 .707 r
F P
0 g
s
.51131 .63988 m .49847 .69527 L .4915 .69914 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.51981 .72229 m .51199 .75932 L .51469 .7657 L p .707 .577 .707 r
F P
0 g
s
.51199 .75932 m .51981 .72229 L .52688 .71803 L p .707 .577 .707 r
F P
0 g
s
.49847 .69527 m .51131 .63988 L .52732 .63869 L p .707 .577 .707 r
F P
0 g
s
.52688 .71803 m .51905 .75506 L .51199 .75932 L p .707 .577 .707 r
F P
0 g
s
.52732 .63869 m .51449 .69408 L .49847 .69527 L p .707 .577 .707 r
F P
0 g
s
.50038 .8493 m .49466 .83239 L .50174 .81825 L p .707 .577 .707 r
F P
0 g
s
.50174 .81825 m .50745 .83516 L .50038 .8493 L p .707 .577 .707 r
F P
0 g
s
.51449 .69408 m .52732 .63869 L .55082 .6403 L p .707 .577 .707 r
F P
0 g
s
.51905 .75506 m .52688 .71803 L .54302 .71632 L p .707 .577 .707 r
F P
0 g
s
.54302 .71632 m .53519 .75334 L .51905 .75506 L p .707 .577 .707 r
F P
0 g
s
.55082 .6403 m .53798 .69569 L .51449 .69408 L p .707 .577 .707 r
F P
0 g
s
.50745 .83516 m .50174 .81825 L .51764 .80307 L p .707 .577 .707 r
F P
0 g
s
.51764 .80307 m .52336 .81998 L .50745 .83516 L p .707 .577 .707 r
F P
0 g
s
.52336 .81998 m .51764 .80307 L .54082 .78832 L p .707 .577 .707 r
F P
0 g
s
.54082 .78832 m .54653 .80524 L .52336 .81998 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53821 .82054 L p .707 .577 .707 r
F P
0 g
s
.53798 .69569 m .55082 .6403 L .57949 .64456 L p .707 .577 .707 r
F P
0 g
s
.53519 .75334 m .54302 .71632 L .56665 .71731 L p .707 .577 .707 r
F P
0 g
s
.57949 .64456 m .56666 .69994 L .53798 .69569 L p .707 .577 .707 r
F P
0 g
s
.56665 .71731 m .55883 .75433 L .53519 .75334 L p .707 .577 .707 r
F P
0 g
s
.53821 .82054 m .53821 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.56666 .69994 m .57949 .64456 L .61053 .65103 L p .707 .577 .707 r
F P
0 g
s
.61053 .65103 m .5977 .70642 L .56666 .69994 L p .707 .577 .707 r
F P
0 g
s
.55883 .75433 m .56665 .71731 L .59547 .72091 L p .707 .577 .707 r
F P
0 g
s
.59547 .72091 m .58765 .75793 L .55883 .75433 L p .707 .577 .707 r
F P
0 g
s
.54653 .80524 m .54082 .78832 L .569 .77546 L p .707 .577 .707 r
F P
0 g
s
.59942 .76574 m .60514 .78265 L .57471 .79237 L p .707 .577 .707 r
F P
0 g
s
.57471 .79237 m .569 .77546 L .59942 .76574 L p .707 .577 .707 r
F P
0 g
s
.569 .77546 m .57471 .79237 L .54653 .80524 L p .707 .577 .707 r
F P
0 g
s
.53821 .31865 m .53821 .82054 L .57932 .81555 L p .707 .577 .707 r
F P
0 g
s
.57932 .81555 m .57932 .31366 L .53821 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40993 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.68919 .78271 m .69491 .79963 L .69246 .78792 L p .707 .577 .707 r
F P
0 g
s
.69246 .78792 m .68675 .77101 L .68919 .78271 L p .707 .577 .707 r
F P
0 g
s
.50282 .86101 m .4971 .84409 L .49466 .83239 L p .707 .577 .707 r
F P
0 g
s
.71939 .76569 m .71156 .80272 L .70886 .79633 L p .707 .577 .707 r
F P
0 g
s
.70886 .79633 m .71668 .75931 L .71939 .76569 L p .707 .577 .707 r
F P
0 g
s
.64091 .65911 m .62808 .7145 L .5977 .70642 L p .707 .577 .707 r
F P
0 g
s
.5977 .70642 m .61053 .65103 L .64091 .65911 L p .707 .577 .707 r
F P
0 g
s
.62911 .76011 m .63483 .77702 L .60514 .78265 L p .707 .577 .707 r
F P
0 g
s
.60514 .78265 m .59942 .76574 L .62911 .76011 L p .707 .577 .707 r
F P
0 g
s
.58765 .75793 m .59547 .72091 L .62666 .72677 L p .707 .577 .707 r
F P
0 g
s
.62666 .72677 m .61883 .7638 L .58765 .75793 L p .707 .577 .707 r
F P
0 g
s
.57932 .31366 m .57932 .81555 L .61267 .80739 L p .707 .577 .707 r
F P
0 g
s
.61267 .80739 m .61267 .3055 L .57932 .31366 L p .707 .577 .707 r
F P
0 g
s
.70034 .68467 m .6875 .74006 L .67529 .73218 L p .707 .577 .707 r
F P
0 g
s
.67529 .73218 m .68812 .67679 L .70034 .68467 L p .707 .577 .707 r
F P
0 g
s
.49466 .83239 m .50038 .8493 L .50282 .86101 L p .707 .577 .707 r
F P
0 g
s
.40993 .81345 m .40993 .31156 L .37952 .30261 L p .707 .577 .707 r
F P
0 g
s
.40993 .31156 m .40993 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24857 .72923 m .25416 .6787 L .22309 .67277 L p .707 .577 .707 r
F P
0 g
s
.25416 .6787 m .24857 .72923 L .28024 .73047 L p .707 .577 .707 r
F P
0 g
s
.28024 .73047 m .28582 .67994 L .25416 .6787 L p .707 .577 .707 r
F P
0 g
s
.68675 .77101 m .69246 .78792 L .68074 .77979 L p .707 .577 .707 r
F P
0 g
s
.68074 .77979 m .67502 .76288 L .68675 .77101 L p .707 .577 .707 r
F P
0 g
s
.28582 .67994 m .28024 .73047 L .30941 .7269 L p .707 .577 .707 r
F P
0 g
s
.30941 .7269 m .31499 .67637 L .28582 .67994 L p .707 .577 .707 r
F P
0 g
s
.2175 .7233 m .22309 .67277 L .19566 .66272 L p .707 .577 .707 r
F P
0 g
s
.22309 .67277 m .2175 .7233 L .24857 .72923 L p .707 .577 .707 r
F P
0 g
s
.2572 .79386 m .26059 .75981 L .22952 .75416 L p .707 .577 .707 r
F P
0 g
s
.26059 .75981 m .2572 .79386 L .2889 .79499 L p .707 .577 .707 r
F P
0 g
s
.2889 .79499 m .29229 .76094 L .26059 .75981 L p .707 .577 .707 r
F P
0 g
s
.29229 .76094 m .2889 .79499 L .31814 .79148 L p .707 .577 .707 r
F P
0 g
s
.31814 .79148 m .32153 .75743 L .29229 .76094 L p .707 .577 .707 r
F P
0 g
s
.22613 .78821 m .22952 .75416 L .20213 .74453 L p .707 .577 .707 r
F P
0 g
s
.22952 .75416 m .22613 .78821 L .2572 .79386 L p .707 .577 .707 r
F P
0 g
s
.66765 .66798 m .65481 .72337 L .62808 .7145 L p .707 .577 .707 r
F P
0 g
s
.62808 .7145 m .64091 .65911 L .66765 .66798 L p .707 .577 .707 r
F P
0 g
s
.63483 .77702 m .62911 .76011 L .65516 .75912 L p .707 .577 .707 r
F P
0 g
s
.65516 .75912 m .66088 .77604 L .63483 .77702 L p .707 .577 .707 r
F P
0 g
s
.65715 .73432 m .64932 .77135 L .61883 .7638 L p .707 .577 .707 r
F P
0 g
s
.61883 .7638 m .62666 .72677 L .65715 .73432 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80739 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.71668 .75931 m .70886 .79633 L .69665 .78845 L p .707 .577 .707 r
F P
0 g
s
.69665 .78845 m .70448 .75143 L .71668 .75931 L p .707 .577 .707 r
F P
0 g
s
.68812 .67679 m .67529 .73218 L .65481 .72337 L p .707 .577 .707 r
F P
0 g
s
.65481 .72337 m .66765 .66798 L .68812 .67679 L p .707 .577 .707 r
F P
0 g
s
.31499 .67637 m .30941 .7269 L .33322 .71886 L p .707 .577 .707 r
F P
0 g
s
.33322 .71886 m .3388 .66833 L .31499 .67637 L p .707 .577 .707 r
F P
0 g
s
.19008 .71325 m .19566 .66272 L .17456 .64955 L p .707 .577 .707 r
F P
0 g
s
.19566 .66272 m .19008 .71325 L .2175 .7233 L p .707 .577 .707 r
F P
0 g
s
.32153 .75743 m .31814 .79148 L .34204 .78368 L p .707 .577 .707 r
F P
0 g
s
.34204 .78368 m .34543 .74963 L .32153 .75743 L p .707 .577 .707 r
F P
0 g
s
.37952 .8045 m .37952 .30261 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37952 .30261 m .37952 .8045 L .40993 .81345 L p .707 .577 .707 r
F P
0 g
s
.19873 .77858 m .20213 .74453 L .18109 .73187 L p .707 .577 .707 r
F P
0 g
s
.20213 .74453 m .19873 .77858 L .22613 .78821 L p .707 .577 .707 r
F P
0 g
s
.67502 .76288 m .68074 .77979 L .66088 .77604 L p .707 .577 .707 r
F P
0 g
s
.66088 .77604 m .65516 .75912 L .67502 .76288 L p .707 .577 .707 r
F P
0 g
s
.3388 .66833 m .33322 .71886 L .34935 .70715 L p .707 .577 .707 r
F P
0 g
s
.34935 .70715 m .35493 .65662 L .3388 .66833 L p .707 .577 .707 r
F P
0 g
s
.21797 .76859 m .22048 .78765 L .25142 .78337 L p .707 .577 .707 r
F P
0 g
s
.25142 .78337 m .24891 .76431 L .21797 .76859 L p .707 .577 .707 r
F P
0 g
s
.24891 .76431 m .25142 .78337 L .28297 .77931 L p .707 .577 .707 r
F P
0 g
s
.16898 .70008 m .17456 .64955 L .16185 .63454 L p .707 .577 .707 r
F P
0 g
s
.17456 .64955 m .16898 .70008 L .19008 .71325 L p .707 .577 .707 r
F P
0 g
s
.28297 .77931 m .28046 .76025 L .24891 .76431 L p .707 .577 .707 r
F P
0 g
s
.28046 .76025 m .28297 .77931 L .31204 .77586 L p .707 .577 .707 r
F P
0 g
s
.31204 .77586 m .30953 .7568 L .28046 .76025 L p .707 .577 .707 r
F P
0 g
s
.18109 .73187 m .1777 .76592 L .19873 .77858 L p .707 .577 .707 r
F P
0 g
s
.34543 .74963 m .34204 .78368 L .35827 .77234 L p .707 .577 .707 r
F P
0 g
s
.35827 .77234 m .36166 .73829 L .34543 .74963 L p .707 .577 .707 r
F P
0 g
s
.70448 .75143 m .69665 .78845 L .67614 .77984 L p .707 .577 .707 r
F P
0 g
s
.67614 .77984 m .68396 .74282 L .70448 .75143 L p .707 .577 .707 r
F P
0 g
s
.19068 .77267 m .19319 .79173 L .22048 .78765 L p .707 .577 .707 r
F P
0 g
s
.22048 .78765 m .21797 .76859 L .19068 .77267 L p .707 .577 .707 r
F P
0 g
s
.1777 .76592 m .18109 .73187 L .16847 .71742 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.30953 .7568 m .31204 .77586 L .33579 .77337 L p .707 .577 .707 r
F P
0 g
s
.33579 .77337 m .33328 .75431 L .30953 .7568 L p .707 .577 .707 r
F P
0 g
s
.16969 .77615 m .1722 .79521 L .19319 .79173 L p .707 .577 .707 r
F P
0 g
s
.19319 .79173 m .19068 .77267 L .16969 .77615 L p .707 .577 .707 r
F P
0 g
s
.35493 .65662 m .34935 .70715 L .35621 .6929 L p .707 .577 .707 r
F P
0 g
s
.35621 .6929 m .36179 .64237 L .35493 .65662 L p .707 .577 .707 r
F P
0 g
s
.16847 .71742 m .16508 .75147 L .1777 .76592 L p .707 .577 .707 r
F P
0 g
s
.15627 .68507 m .16185 .63454 L .15877 .61916 L p .707 .577 .707 r
F P
0 g
s
.16185 .63454 m .15627 .68507 L .16898 .70008 L p .707 .577 .707 r
F P
0 g
s
.36166 .73829 m .35827 .77234 L .36525 .75859 L p .707 .577 .707 r
F P
0 g
s
.36179 .64237 m .35621 .6929 L .35313 .67752 L p .707 .577 .707 r
F P
0 g
s
.35313 .67752 m .35872 .62699 L .36179 .64237 L p .707 .577 .707 r
F P
0 g
s
.36525 .75859 m .36864 .72454 L .36166 .73829 L p .707 .577 .707 r
F P
0 g
s
.36567 .70971 m .36228 .74376 L .34965 .72931 L p .707 .577 .707 r
F P
0 g
s
.34965 .72931 m .35305 .69526 L .36567 .70971 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36864 .72454 m .36525 .75859 L .36228 .74376 L p .707 .577 .707 r
F P
0 g
s
.36228 .74376 m .36567 .70971 L .36864 .72454 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37952 .8045 L p .707 .577 .707 r
F P
0 g
s
.68396 .74282 m .67614 .77984 L .64932 .77135 L p .707 .577 .707 r
F P
0 g
s
.64932 .77135 m .65715 .73432 L .68396 .74282 L p .707 .577 .707 r
F P
0 g
s
.16508 .75147 m .16847 .71742 L .1655 .70259 L p .707 .577 .707 r
F P
0 g
s
.33328 .75431 m .33579 .77337 L .3519 .77208 L p .707 .577 .707 r
F P
0 g
s
.3519 .77208 m .34939 .75302 L .33328 .75431 L p .707 .577 .707 r
F P
0 g
s
.15707 .7787 m .15958 .79775 L .1722 .79521 L p .707 .577 .707 r
F P
0 g
s
.1722 .79521 m .16969 .77615 L .15707 .7787 L p .707 .577 .707 r
F P
0 g
s
.1655 .70259 m .16211 .73664 L .16508 .75147 L p .707 .577 .707 r
F P
0 g
s
.15877 .61916 m .15319 .66969 L .15627 .68507 L p .707 .577 .707 r
F P
0 g
s
.15319 .66969 m .15877 .61916 L .16563 .60491 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77297 L p .707 .577 .707 r
F P
0 g
s
.63909 .77297 m .63909 .27108 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.16211 .73664 m .1655 .70259 L .17247 .68884 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34939 .75302 m .3519 .77208 L .35878 .77211 L p .707 .577 .707 r
F P
0 g
s
.35878 .77211 m .35626 .75305 L .34939 .75302 L p .707 .577 .707 r
F P
0 g
s
.35872 .62699 m .35313 .67752 L .34042 .66251 L p .707 .577 .707 r
F P
0 g
s
.34042 .66251 m .34601 .61198 L .35872 .62699 L p .707 .577 .707 r
F P
0 g
s
.35626 .75305 m .35878 .77211 L .35576 .77347 L p .707 .577 .707 r
F P
0 g
s
.35576 .77347 m .35325 .75441 L .35626 .75305 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.15405 .78005 m .15656 .79911 L .15958 .79775 L p .707 .577 .707 r
F P
0 g
s
.15958 .79775 m .15707 .7787 L .15405 .78005 L p .707 .577 .707 r
F P
0 g
s
.17247 .68884 m .16908 .72289 L .16211 .73664 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16563 .60491 m .16005 .65544 L .15319 .66969 L p .707 .577 .707 r
F P
0 g
s
.16005 .65544 m .16563 .60491 L .18176 .5932 L p .707 .577 .707 r
F P
0 g
s
.16908 .72289 m .17247 .68884 L .1887 .67751 L p .707 .577 .707 r
F P
0 g
s
.63909 .27108 m .63909 .77297 L .62048 .76193 L p .707 .577 .707 r
F P
0 g
s
.62048 .76193 m .62048 .26004 L .63909 .27108 L p .707 .577 .707 r
F P
0 g
s
.34601 .61198 m .34042 .66251 L .31932 .64934 L p .707 .577 .707 r
F P
0 g
s
.31932 .64934 m .3249 .59881 L .34601 .61198 L p .707 .577 .707 r
F P
0 g
s
.18176 .5932 m .17618 .64373 L .16005 .65544 L p .707 .577 .707 r
F P
0 g
s
.17618 .64373 m .18176 .5932 L .20557 .58516 L p .707 .577 .707 r
F P
0 g
s
.1887 .67751 m .18531 .71156 L .16908 .72289 L p .707 .577 .707 r
F P
0 g
s
.16093 .78008 m .16344 .79914 L .15656 .79911 L p .707 .577 .707 r
F P
0 g
s
.15656 .79911 m .15405 .78005 L .16093 .78008 L p .707 .577 .707 r
F P
0 g
s
.35305 .69526 m .34965 .72931 L .32862 .71665 L p .707 .577 .707 r
F P
0 g
s
.32862 .71665 m .33201 .6826 L .35305 .69526 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38733 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.18531 .71156 m .1887 .67751 L .21261 .6697 L p .707 .577 .707 r
F P
0 g
s
.3249 .59881 m .31932 .64934 L .29189 .63929 L p .707 .577 .707 r
F P
0 g
s
.29189 .63929 m .29748 .58876 L .3249 .59881 L p .707 .577 .707 r
F P
0 g
s
.19999 .63569 m .20557 .58516 L .23474 .58159 L p .707 .577 .707 r
F P
0 g
s
.20557 .58516 m .19999 .63569 L .17618 .64373 L p .707 .577 .707 r
F P
0 g
s
.35325 .75441 m .35576 .77347 L .34314 .77601 L p .707 .577 .707 r
F P
0 g
s
.34314 .77601 m .34063 .75695 L .35325 .75441 L p .707 .577 .707 r
F P
0 g
s
.21261 .6697 m .20922 .70375 L .18531 .71156 L p .707 .577 .707 r
F P
0 g
s
.33201 .6826 m .32862 .71665 L .30122 .70702 L p .707 .577 .707 r
F P
0 g
s
.30122 .70702 m .30462 .67297 L .33201 .6826 L p .707 .577 .707 r
F P
0 g
s
.20922 .70375 m .21261 .6697 L .24184 .66619 L p .707 .577 .707 r
F P
0 g
s
.29748 .58876 m .29189 .63929 L .26083 .63336 L p .707 .577 .707 r
F P
0 g
s
.26083 .63336 m .26641 .58283 L .29748 .58876 L p .707 .577 .707 r
F P
0 g
s
.22916 .63212 m .23474 .58159 L .26641 .58283 L p .707 .577 .707 r
F P
0 g
s
.23474 .58159 m .22916 .63212 L .19999 .63569 L p .707 .577 .707 r
F P
0 g
s
.17703 .77879 m .17954 .79785 L .16344 .79914 L p .707 .577 .707 r
F P
0 g
s
.16344 .79914 m .16093 .78008 L .17703 .77879 L p .707 .577 .707 r
F P
0 g
s
.62048 .26004 m .62048 .76193 L .59007 .75299 L p .707 .577 .707 r
F P
0 g
s
.59007 .75299 m .59007 .2511 L .62048 .26004 L p .707 .577 .707 r
F P
0 g
s
.26641 .58283 m .26083 .63336 L .22916 .63212 L p .707 .577 .707 r
F P
0 g
s
.30462 .67297 m .30122 .70702 L .27015 .70137 L p .707 .577 .707 r
F P
0 g
s
.27015 .70137 m .27355 .66732 L .30462 .67297 L p .707 .577 .707 r
F P
0 g
s
.23845 .70024 m .24184 .66619 L .27355 .66732 L p .707 .577 .707 r
F P
0 g
s
.24184 .66619 m .23845 .70024 L .20922 .70375 L p .707 .577 .707 r
F P
0 g
s
.38733 .25716 m .38733 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38733 .75905 m .38733 .25716 L .42068 .249 L p .707 .577 .707 r
F P
0 g
s
.27355 .66732 m .27015 .70137 L .23845 .70024 L p .707 .577 .707 r
F P
0 g
s
.73917 .638 m .73359 .58064 L .70252 .58333 L p .707 .577 .707 r
F P
0 g
s
.73359 .58064 m .73917 .638 L .77084 .63478 L p .707 .577 .707 r
F P
0 g
s
.77084 .63478 m .76526 .57742 L .73359 .58064 L p .707 .577 .707 r
F P
0 g
s
.70252 .58333 m .7081 .64069 L .73917 .638 L p .707 .577 .707 r
F P
0 g
s
.76526 .57742 m .77084 .63478 L .80001 .63133 L p .707 .577 .707 r
F P
0 g
s
.80001 .63133 m .79443 .57397 L .76526 .57742 L p .707 .577 .707 r
F P
0 g
s
.34063 .75695 m .34314 .77601 L .32215 .77949 L p .707 .577 .707 r
F P
0 g
s
.7081 .64069 m .70252 .58333 L .67509 .58521 L p .707 .577 .707 r
F P
0 g
s
.32215 .77949 m .31964 .76043 L .34063 .75695 L p .707 .577 .707 r
F P
0 g
s
.67509 .58521 m .68068 .64257 L .7081 .64069 L p .707 .577 .707 r
F P
0 g
s
.79443 .57397 m .80001 .63133 L .82382 .628 L p .707 .577 .707 r
F P
0 g
s
.82382 .628 m .81824 .57064 L .79443 .57397 L p .707 .577 .707 r
F P
0 g
s
.20078 .7763 m .20329 .79536 L .17954 .79785 L p .707 .577 .707 r
F P
0 g
s
.17954 .79785 m .17703 .77879 L .20078 .7763 L p .707 .577 .707 r
F P
0 g
s
.59007 .2511 m .59007 .75299 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59007 .2511 L p .707 .577 .707 r
F P
0 g
s
.68068 .64257 m .67509 .58521 L .65399 .58611 L p .707 .577 .707 r
F P
0 g
s
.65399 .58611 m .65957 .64347 L .68068 .64257 L p .707 .577 .707 r
F P
0 g
s
.42068 .75089 m .42068 .249 L .46179 .24401 L p .707 .577 .707 r
F P
0 g
s
.42068 .249 m .42068 .75089 L .38733 .75905 L p .707 .577 .707 r
F P
0 g
s
.31964 .76043 m .32215 .77949 L .29485 .78357 L p .707 .577 .707 r
F P
0 g
s
.29485 .78357 m .29234 .76451 L .31964 .76043 L p .707 .577 .707 r
F P
0 g
s
.81824 .57064 m .82382 .628 L .83995 .62511 L p .707 .577 .707 r
F P
0 g
s
.83995 .62511 m .83436 .56774 L .81824 .57064 L p .707 .577 .707 r
F P
0 g
s
.72984 .69502 m .72645 .65679 L .69538 .65906 L p .707 .577 .707 r
F P
0 g
s
.72645 .65679 m .72984 .69502 L .76155 .69202 L p .707 .577 .707 r
F P
0 g
s
.76155 .69202 m .75816 .65379 L .72645 .65679 L p .707 .577 .707 r
F P
0 g
s
.22985 .77285 m .23237 .79191 L .20329 .79536 L p .707 .577 .707 r
F P
0 g
s
.20329 .79536 m .20078 .7763 L .22985 .77285 L p .707 .577 .707 r
F P
0 g
s
.69538 .65906 m .69877 .69729 L .72984 .69502 L p .707 .577 .707 r
F P
0 g
s
.75816 .65379 m .76155 .69202 L .79078 .68859 L p .707 .577 .707 r
F P
0 g
s
.79078 .68859 m .78739 .65036 L .75816 .65379 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50664 .74455 L p .707 .577 .707 r
F P
0 g
s
.50664 .74455 m .50664 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.73608 .78785 m .73859 .77183 L .70766 .76465 L p .707 .577 .707 r
F P
0 g
s
.73859 .77183 m .73608 .78785 L .76763 .78969 L p .707 .577 .707 r
F P
0 g
s
.76763 .78969 m .77014 .77367 L .73859 .77183 L p .707 .577 .707 r
F P
0 g
s
.69877 .69729 m .69538 .65906 L .66799 .66039 L p .707 .577 .707 r
F P
0 g
s
.46179 .7459 m .46179 .24401 L .50664 .24266 L p .707 .577 .707 r
F P
0 g
s
.46179 .24401 m .46179 .7459 L .42068 .75089 L p .707 .577 .707 r
F P
0 g
s
.29234 .76451 m .29485 .78357 L .26392 .78785 L p .707 .577 .707 r
F P
0 g
s
.70514 .78066 m .70766 .76465 L .68036 .75282 L p .707 .577 .707 r
F P
0 g
s
.70766 .76465 m .70514 .78066 L .73608 .78785 L p .707 .577 .707 r
F P
0 g
s
.66799 .66039 m .67138 .69862 L .69877 .69729 L p .707 .577 .707 r
F P
0 g
s
.26392 .78785 m .2614 .76879 L .29234 .76451 L p .707 .577 .707 r
F P
0 g
s
.65957 .64347 m .65399 .58611 L .64128 .58593 L p .707 .577 .707 r
F P
0 g
s
.77014 .77367 m .76763 .78969 L .7967 .786 L p .707 .577 .707 r
F P
0 g
s
.7967 .786 m .79922 .76998 L .77014 .77367 L p .707 .577 .707 r
F P
0 g
s
.64128 .58593 m .64686 .64329 L .65957 .64347 L p .707 .577 .707 r
F P
0 g
s
.2614 .76879 m .26392 .78785 L .23237 .79191 L p .707 .577 .707 r
F P
0 g
s
.23237 .79191 m .22985 .77285 L .2614 .76879 L p .707 .577 .707 r
F P
0 g
s
.50664 .24266 m .50664 .74455 L .46179 .7459 L p .707 .577 .707 r
F P
0 g
s
.78739 .65036 m .79078 .68859 L .81469 .68506 L p .707 .577 .707 r
F P
0 g
s
.81469 .68506 m .81129 .64683 L .78739 .65036 L p .707 .577 .707 r
F P
0 g
s
.68036 .75282 m .67785 .76883 L .70514 .78066 L p .707 .577 .707 r
F P
0 g
s
.67785 .76883 m .68036 .75282 L .65937 .7375 L p .707 .577 .707 r
F P
0 g
s
.79922 .76998 m .7967 .786 L .82045 .77715 L p .707 .577 .707 r
F P
0 g
s
.82045 .77715 m .82297 .76113 L .79922 .76998 L p .707 .577 .707 r
F P
0 g
s
.67138 .69862 m .66799 .66039 L .64695 .66064 L p .707 .577 .707 r
F P
0 g
s
.64695 .66064 m .65034 .69887 L .67138 .69862 L p .707 .577 .707 r
F P
0 g
s
.83436 .56774 m .83995 .62511 L .84681 .62294 L p .707 .577 .707 r
F P
0 g
s
.84681 .62294 m .84123 .56557 L .83436 .56774 L p .707 .577 .707 r
F P
0 g
s
.65937 .7375 m .65686 .75352 L .67785 .76883 L p .707 .577 .707 r
F P
0 g
s
.81129 .64683 m .81469 .68506 L .83092 .68179 L p .707 .577 .707 r
F P
0 g
s
.83092 .68179 m .82753 .64356 L .81129 .64683 L p .707 .577 .707 r
F P
0 g
s
.64686 .64329 m .64128 .58593 L .63821 .58469 L p .707 .577 .707 r
F P
0 g
s
.65686 .75352 m .65937 .7375 L .64675 .7202 L p .707 .577 .707 r
F P
0 g
s
.63821 .58469 m .64379 .64205 L .64686 .64329 L p .707 .577 .707 r
F P
0 g
s
.82297 .76113 m .82045 .77715 L .83656 .76399 L p .707 .577 .707 r
F P
0 g
s
.83656 .76399 m .83907 .74797 L .82297 .76113 L p .707 .577 .707 r
F P
0 g
s
.65034 .69887 m .64695 .66064 L .63433 .6598 L p .707 .577 .707 r
F P
0 g
s
.64675 .7202 m .64424 .73622 L .65686 .75352 L p .707 .577 .707 r
F P
0 g
s
.63433 .6598 m .63772 .69802 L .65034 .69887 L p .707 .577 .707 r
F P
0 g
s
.84123 .56557 m .84681 .62294 L .84373 .6217 L p .707 .577 .707 r
F P
0 g
s
.84373 .6217 m .83815 .56434 L .84123 .56557 L p .707 .577 .707 r
F P
0 g
s
.64424 .73622 m .64675 .7202 L .64373 .7026 L p .707 .577 .707 r
F P
0 g
s
.82753 .64356 m .83092 .68179 L .83789 .67908 L p .707 .577 .707 r
F P
0 g
s
.83789 .67908 m .8345 .64085 L .82753 .64356 L p .707 .577 .707 r
F P
0 g
s
.83907 .74797 m .83656 .76399 L .84344 .74783 L p .707 .577 .707 r
F P
0 g
s
.84344 .74783 m .84595 .73181 L .83907 .74797 L p .707 .577 .707 r
F P
0 g
s
.64379 .64205 m .63821 .58469 L .64507 .58252 L p .707 .577 .707 r
F P
0 g
s
.64373 .7026 m .64122 .71862 L .64424 .73622 L p .707 .577 .707 r
F P
0 g
s
.64507 .58252 m .65065 .63988 L .64379 .64205 L p .707 .577 .707 r
F P
0 g
s
.63772 .69802 m .63433 .6598 L .63136 .65793 L p .707 .577 .707 r
F P
0 g
s
.63136 .65793 m .63475 .69616 L .63772 .69802 L p .707 .577 .707 r
F P
0 g
s
.83815 .56434 m .84373 .6217 L .83102 .62152 L p .707 .577 .707 r
F P
0 g
s
.83102 .62152 m .82544 .56416 L .83815 .56434 L p .707 .577 .707 r
F P
0 g
s
.64122 .71862 m .64373 .7026 L .65061 .68643 L p .707 .577 .707 r
F P
0 g
s
.84595 .73181 m .84344 .74783 L .84042 .73023 L p .707 .577 .707 r
F P
0 g
s
.84042 .73023 m .84293 .71421 L .84595 .73181 L p .707 .577 .707 r
F P
0 g
s
.8345 .64085 m .83789 .67908 L .83492 .67722 L p .707 .577 .707 r
F P
0 g
s
.83492 .67722 m .83153 .63899 L .8345 .64085 L p .707 .577 .707 r
F P
0 g
s
.65061 .68643 m .6481 .70245 L .64122 .71862 L p .707 .577 .707 r
F P
0 g
s
.4023 .6292 m .38946 .57671 L .35909 .58061 L p .707 .577 .707 r
F P
0 g
s
.38946 .57671 m .4023 .6292 L .43334 .62158 L p .707 .577 .707 r
F P
0 g
s
.43334 .62158 m .42051 .56909 L .38946 .57671 L p .707 .577 .707 r
F P
0 g
s
.42051 .56909 m .43334 .62158 L .46201 .61097 L p .707 .577 .707 r
F P
0 g
s
.46201 .61097 m .44918 .55848 L .42051 .56909 L p .707 .577 .707 r
F P
0 g
s
.65065 .63988 m .64507 .58252 L .66119 .57963 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66119 .57963 m .66678 .63699 L .65065 .63988 L p .707 .577 .707 r
F P
0 g
s
.63475 .69616 m .63136 .65793 L .63833 .65522 L p .707 .577 .707 r
F P
0 g
s
.37192 .6331 m .35909 .58061 L .33235 .58039 L p .707 .577 .707 r
F P
0 g
s
.35909 .58061 m .37192 .6331 L .4023 .6292 L p .707 .577 .707 r
F P
0 g
s
.44918 .55848 m .46201 .61097 L .48551 .59841 L p .707 .577 .707 r
F P
0 g
s
.48551 .59841 m .47268 .54592 L .44918 .55848 L p .707 .577 .707 r
F P
0 g
s
.63833 .65522 m .64173 .69345 L .63475 .69616 L p .707 .577 .707 r
F P
0 g
s
.38117 .69142 m .37334 .65616 L .34285 .65955 L p .707 .577 .707 r
F P
0 g
s
.37334 .65616 m .38117 .69142 L .41235 .68438 L p .707 .577 .707 r
F P
0 g
s
.41235 .68438 m .40452 .64913 L .37334 .65616 L p .707 .577 .707 r
F P
0 g
s
.40452 .64913 m .41235 .68438 L .44117 .6744 L p .707 .577 .707 r
F P
0 g
s
.44117 .6744 m .43334 .63914 L .40452 .64913 L p .707 .577 .707 r
F P
0 g
s
.6481 .70245 m .65061 .68643 L .66672 .67328 L p .707 .577 .707 r
F P
0 g
s
.82544 .56416 m .83102 .62152 L .80992 .62242 L p .707 .577 .707 r
F P
0 g
s
.80992 .62242 m .80434 .56506 L .82544 .56416 L p .707 .577 .707 r
F P
0 g
s
.84293 .71421 m .84042 .73023 L .8278 .71293 L p .707 .577 .707 r
F P
0 g
s
.8278 .71293 m .83031 .69691 L .84293 .71421 L p .707 .577 .707 r
F P
0 g
s
.35067 .69481 m .34285 .65955 L .31603 .65898 L p .707 .577 .707 r
F P
0 g
s
.34285 .65955 m .35067 .69481 L .38117 .69142 L p .707 .577 .707 r
F P
0 g
s
.43334 .63914 m .44117 .6744 L .4648 .66243 L p .707 .577 .707 r
F P
0 g
s
.4648 .66243 m .45698 .62717 L .43334 .63914 L p .707 .577 .707 r
F P
0 g
s
.83153 .63899 m .83492 .67722 L .8223 .67637 L p .707 .577 .707 r
F P
0 g
s
.8223 .67637 m .81891 .63814 L .83153 .63899 L p .707 .577 .707 r
F P
0 g
s
.66672 .67328 m .6642 .6893 L .6481 .70245 L p .707 .577 .707 r
F P
0 g
s
.34518 .63288 m .33235 .58039 L .31187 .57608 L p .707 .577 .707 r
F P
0 g
s
.33235 .58039 m .34518 .63288 L .37192 .6331 L p .707 .577 .707 r
F P
0 g
s
.47268 .54592 m .48551 .59841 L .50153 .58514 L p .707 .577 .707 r
F P
0 g
s
.50153 .58514 m .48869 .53265 L .47268 .54592 L p .707 .577 .707 r
F P
0 g
s
.66678 .63699 m .66119 .57963 L .68501 .5763 L p .707 .577 .707 r
F P
0 g
s
.68501 .5763 m .69059 .63366 L .66678 .63699 L p .707 .577 .707 r
F P
0 g
s
.39486 .70662 m .40058 .68845 L .37089 .67824 L p .707 .577 .707 r
F P
0 g
s
.40058 .68845 m .39486 .70662 L .42528 .71563 L p .707 .577 .707 r
F P
0 g
s
.42528 .71563 m .431 .69746 L .40058 .68845 L p .707 .577 .707 r
F P
0 g
s
.31603 .65898 m .32386 .69423 L .35067 .69481 L p .707 .577 .707 r
F P
0 g
s
.64173 .69345 m .63833 .65522 L .65457 .65195 L p .707 .577 .707 r
F P
0 g
s
.37089 .67824 m .36517 .69641 L .39486 .70662 L p .707 .577 .707 r
F P
0 g
s
.6642 .6893 m .66672 .67328 L .69047 .66443 L p .707 .577 .707 r
F P
0 g
s
.431 .69746 m .42528 .71563 L .45346 .72256 L p .707 .577 .707 r
F P
0 g
s
.45346 .72256 m .45918 .70438 L .431 .69746 L p .707 .577 .707 r
F P
0 g
s
.32386 .69423 m .31603 .65898 L .29552 .65448 L p .707 .577 .707 r
F P
0 g
s
.65457 .65195 m .65796 .69018 L .64173 .69345 L p .707 .577 .707 r
F P
0 g
s
.80434 .56506 m .80992 .62242 L .78249 .6243 L p .707 .577 .707 r
F P
0 g
s
.78249 .6243 m .77691 .56694 L .80434 .56506 L p .707 .577 .707 r
F P
0 g
s
.45698 .62717 m .4648 .66243 L .48095 .64967 L p .707 .577 .707 r
F P
0 g
s
.48095 .64967 m .47312 .61441 L .45698 .62717 L p .707 .577 .707 r
F P
0 g
s
.36517 .69641 m .37089 .67824 L .34484 .66783 L p .707 .577 .707 r
F P
0 g
s
.83031 .69691 m .8278 .71293 L .80681 .69761 L p .707 .577 .707 r
F P
0 g
s
.80681 .69761 m .80932 .68159 L .83031 .69691 L p .707 .577 .707 r
F P
0 g
s
.34484 .66783 m .33912 .68601 L .36517 .69641 L p .707 .577 .707 r
F P
0 g
s
.31187 .57608 m .32471 .62858 L .34518 .63288 L p .707 .577 .707 r
F P
0 g
s
.69059 .63366 m .68501 .5763 L .71418 .57285 L p .707 .577 .707 r
F P
0 g
s
.69047 .66443 m .68795 .68044 L .6642 .6893 L p .707 .577 .707 r
F P
0 g
s
.32471 .62858 m .31187 .57608 L .29966 .56811 L p .707 .577 .707 r
F P
0 g
s
.48869 .53265 m .50153 .58514 L .5085 .57245 L p .707 .577 .707 r
F P
0 g
s
.5085 .57245 m .49566 .51996 L .48869 .53265 L p .707 .577 .707 r
F P
0 g
s
.71418 .57285 m .71976 .63021 L .69059 .63366 L p .707 .577 .707 r
F P
0 g
s
.45918 .70438 m .45346 .72256 L .47664 .72673 L p .707 .577 .707 r
F P
0 g
s
.47664 .72673 m .48236 .70855 L .45918 .70438 L p .707 .577 .707 r
F P
0 g
s
.29552 .65448 m .30334 .68974 L .32386 .69423 L p .707 .577 .707 r
F P
0 g
s
.81891 .63814 m .8223 .67637 L .80126 .67662 L p .707 .577 .707 r
F P
0 g
s
.80126 .67662 m .79787 .63839 L .81891 .63814 L p .707 .577 .707 r
F P
0 g
s
.33912 .68601 m .34484 .66783 L .32498 .65824 L p .707 .577 .707 r
F P
0 g
s
.77691 .56694 m .78249 .6243 L .75143 .62699 L p .707 .577 .707 r
F P
0 g
s
.75143 .62699 m .74584 .56963 L .77691 .56694 L p .707 .577 .707 r
F P
0 g
s
.68795 .68044 m .69047 .66443 L .71954 .66074 L p .707 .577 .707 r
F P
0 g
s
.32498 .65824 m .31926 .67642 L .33912 .68601 L p .707 .577 .707 r
F P
0 g
s
.80932 .68159 m .80681 .69761 L .77951 .68578 L p .707 .577 .707 r
F P
0 g
s
.77951 .68578 m .78203 .66976 L .80932 .68159 L p .707 .577 .707 r
F P
0 g
s
.71976 .63021 m .71418 .57285 L .74584 .56963 L p .707 .577 .707 r
F P
0 g
s
.74584 .56963 m .75143 .62699 L .71976 .63021 L p .707 .577 .707 r
F P
0 g
s
.30334 .68974 m .29552 .65448 L .28331 .64651 L p .707 .577 .707 r
F P
0 g
s
.65796 .69018 m .65457 .65195 L .67847 .64843 L p .707 .577 .707 r
F P
0 g
s
.47312 .61441 m .48095 .64967 L .48801 .63735 L p .707 .577 .707 r
F P
0 g
s
.48801 .63735 m .48019 .60209 L .47312 .61441 L p .707 .577 .707 r
F P
0 g
s
.67847 .64843 m .68186 .68666 L .65796 .69018 L p .707 .577 .707 r
F P
0 g
s
.71954 .66074 m .71703 .67676 L .68795 .68044 L p .707 .577 .707 r
F P
0 g
s
.29966 .56811 m .31249 .6206 L .32471 .62858 L p .707 .577 .707 r
F P
0 g
s
.71703 .67676 m .71954 .66074 L .75109 .66258 L p .707 .577 .707 r
F P
0 g
s
.78203 .66976 m .77951 .68578 L .74858 .6786 L p .707 .577 .707 r
F P
0 g
s
.74858 .6786 m .75109 .66258 L .78203 .66976 L p .707 .577 .707 r
F P
0 g
s
.48236 .70855 m .47664 .72673 L .49255 .72773 L p .707 .577 .707 r
F P
0 g
s
.49255 .72773 m .49826 .70955 L .48236 .70855 L p .707 .577 .707 r
F P
0 g
s
.75109 .66258 m .74858 .6786 L .71703 .67676 L p .707 .577 .707 r
F P
0 g
s
.28331 .64651 m .29114 .68176 L .30334 .68974 L p .707 .577 .707 r
F P
0 g
s
.79787 .63839 m .80126 .67662 L .77387 .67795 L p .707 .577 .707 r
F P
0 g
s
.77387 .67795 m .77048 .63972 L .79787 .63839 L p .707 .577 .707 r
F P
0 g
s
.31249 .6206 m .29966 .56811 L .2969 .55725 L p .709 .579 .707 r
F P
0 g
s
.49566 .51996 m .5085 .57245 L .50574 .56159 L p .709 .579 .707 r
F P
0 g
s
.50574 .56159 m .49291 .5091 L .49566 .51996 L p .709 .579 .707 r
F P
0 g
s
.31926 .67642 m .32498 .65824 L .31325 .65041 L p .707 .577 .707 r
F P
0 g
s
.31325 .65041 m .30753 .66859 L .31926 .67642 L p .707 .577 .707 r
F P
0 g
s
.68186 .68666 m .67847 .64843 L .70771 .645 L p .707 .577 .707 r
F P
0 g
s
.70771 .645 m .7111 .68323 L .68186 .68666 L p .707 .577 .707 r
F P
0 g
s
.29114 .68176 m .28331 .64651 L .28061 .63584 L p .708 .578 .707 r
F P
0 g
s
.77048 .63972 m .77387 .67795 L .7428 .68023 L p .707 .577 .707 r
F P
0 g
s
.7428 .68023 m .73941 .642 L .77048 .63972 L p .707 .577 .707 r
F P
0 g
s
.48019 .60209 m .48801 .63735 L .48531 .62668 L p .708 .578 .707 r
F P
0 g
s
.48531 .62668 m .47748 .59142 L .48019 .60209 L p .708 .578 .707 r
F P
0 g
s
.2969 .55725 m .30973 .60974 L .31249 .6206 L p .709 .579 .707 r
F P
0 g
s
.7111 .68323 m .70771 .645 L .73941 .642 L p .707 .577 .707 r
F P
0 g
s
.73941 .642 m .7428 .68023 L .7111 .68323 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49826 .70955 m .49255 .72773 L .49962 .72547 L p .707 .577 .707 r
F P
0 g
s
.49962 .72547 m .50534 .70729 L .49826 .70955 L p .707 .577 .707 r
F P
0 g
s
.28061 .63584 m .28843 .6711 L .29114 .68176 L p .708 .578 .707 r
F P
0 g
s
.30973 .60974 m .2969 .55725 L .30387 .54456 L p .707 .577 .707 r
F P
0 g
s
.49291 .5091 m .50574 .56159 L .49352 .55362 L p .707 .577 .707 r
F P
0 g
s
.49352 .55362 m .48069 .50113 L .49291 .5091 L p .707 .577 .707 r
F P
0 g
s
.30753 .66859 m .31325 .65041 L .3108 .64511 L p .707 .577 .707 r
F P
0 g
s
.3108 .64511 m .30509 .66328 L .30753 .66859 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28843 .6711 m .28061 .63584 L .28767 .62352 L p .707 .577 .707 r
F P
0 g
s
.47748 .59142 m .48531 .62668 L .4731 .6187 L p .707 .577 .707 r
F P
0 g
s
.4731 .6187 m .46528 .58345 L .47748 .59142 L p .707 .577 .707 r
F P
0 g
s
.30387 .54456 m .31671 .59705 L .30973 .60974 L p .707 .577 .707 r
F P
0 g
s
.50534 .70729 m .49962 .72547 L .49718 .72016 L p .707 .577 .707 r
F P
0 g
s
.49718 .72016 m .50289 .70199 L .50534 .70729 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28767 .62352 m .2955 .65877 L .28843 .6711 L p .707 .577 .707 r
F P
0 g
s
.31671 .59705 m .30387 .54456 L .31989 .53129 L p .707 .577 .707 r
F P
0 g
s
.48069 .50113 m .49352 .55362 L .47305 .54931 L p .707 .577 .707 r
F P
0 g
s
.47305 .54931 m .46021 .49682 L .48069 .50113 L p .707 .577 .707 r
F P
0 g
s
.30509 .66328 m .3108 .64511 L .31788 .64284 L p .707 .577 .707 r
F P
0 g
s
.31788 .64284 m .31216 .66102 L .30509 .66328 L p .707 .577 .707 r
F P
0 g
s
.2955 .65877 m .28767 .62352 L .30381 .61075 L p .707 .577 .707 r
F P
0 g
s
.46528 .58345 m .4731 .6187 L .45259 .61421 L p .707 .577 .707 r
F P
0 g
s
.45259 .61421 m .44476 .57895 L .46528 .58345 L p .707 .577 .707 r
F P
0 g
s
.31989 .53129 m .33272 .58378 L .31671 .59705 L p .707 .577 .707 r
F P
0 g
s
.33272 .58378 m .31989 .53129 L .34338 .51873 L p .707 .577 .707 r
F P
0 g
s
.46021 .49682 m .47305 .54931 L .44631 .54909 L p .707 .577 .707 r
F P
0 g
s
.44631 .54909 m .43348 .4966 L .46021 .49682 L p .707 .577 .707 r
F P
0 g
s
.30381 .61075 m .31164 .64601 L .2955 .65877 L p .707 .577 .707 r
F P
0 g
s
.50289 .70199 m .49718 .72016 L .48545 .71233 L p .707 .577 .707 r
F P
0 g
s
.48545 .71233 m .49117 .69415 L .50289 .70199 L p .707 .577 .707 r
F P
0 g
s
.31216 .66102 m .31788 .64284 L .33379 .64385 L p .707 .577 .707 r
F P
0 g
s
.33379 .64385 m .32807 .66202 L .31216 .66102 L p .707 .577 .707 r
F P
0 g
s
.31164 .64601 m .30381 .61075 L .32745 .59879 L p .707 .577 .707 r
F P
0 g
s
.44476 .57895 m .45259 .61421 L .42577 .61363 L p .707 .577 .707 r
F P
0 g
s
.42577 .61363 m .41795 .57837 L .44476 .57895 L p .707 .577 .707 r
F P
0 g
s
.35622 .57122 m .34338 .51873 L .37206 .50812 L p .707 .577 .707 r
F P
0 g
s
.34338 .51873 m .35622 .57122 L .33272 .58378 L p .707 .577 .707 r
F P
0 g
s
.43348 .4966 m .44631 .54909 L .41593 .55299 L p .707 .577 .707 r
F P
0 g
s
.41593 .55299 m .4031 .5005 L .43348 .4966 L p .707 .577 .707 r
F P
0 g
s
.38489 .56062 m .37206 .50812 L .4031 .5005 L p .707 .577 .707 r
F P
0 g
s
.37206 .50812 m .38489 .56062 L .35622 .57122 L p .707 .577 .707 r
F P
0 g
s
.4031 .5005 m .41593 .55299 L .38489 .56062 L p .707 .577 .707 r
F P
0 g
s
.32745 .59879 m .33528 .63405 L .31164 .64601 L p .707 .577 .707 r
F P
0 g
s
.49117 .69415 m .48545 .71233 L .46559 .70274 L p .707 .577 .707 r
F P
0 g
s
.46559 .70274 m .47131 .68457 L .49117 .69415 L p .707 .577 .707 r
F P
0 g
s
.33528 .63405 m .32745 .59879 L .35627 .5888 L p .707 .577 .707 r
F P
0 g
s
.41795 .57837 m .42577 .61363 L .39528 .61702 L p .707 .577 .707 r
F P
0 g
s
.39528 .61702 m .38745 .58176 L .41795 .57837 L p .707 .577 .707 r
F P
0 g
s
.32807 .66202 m .33379 .64385 L .35696 .64801 L p .707 .577 .707 r
F P
0 g
s
.35696 .64801 m .35125 .66619 L .32807 .66202 L p .707 .577 .707 r
F P
0 g
s
.3641 .62406 m .35627 .5888 L .38745 .58176 L p .707 .577 .707 r
F P
0 g
s
.35627 .5888 m .3641 .62406 L .33528 .63405 L p .707 .577 .707 r
F P
0 g
s
.38745 .58176 m .39528 .61702 L .3641 .62406 L p .707 .577 .707 r
F P
0 g
s
.47131 .68457 m .46559 .70274 L .43954 .69233 L p .707 .577 .707 r
F P
0 g
s
.43954 .69233 m .44526 .67416 L .47131 .68457 L p .707 .577 .707 r
F P
0 g
s
.35125 .66619 m .35696 .64801 L .38514 .65494 L p .707 .577 .707 r
F P
0 g
s
.38514 .65494 m .37942 .67312 L .35125 .66619 L p .707 .577 .707 r
F P
0 g
s
.44526 .67416 m .43954 .69233 L .40985 .68213 L p .707 .577 .707 r
F P
0 g
s
.40985 .68213 m .41557 .66395 L .44526 .67416 L p .707 .577 .707 r
F P
0 g
s
.37942 .67312 m .38514 .65494 L .41557 .66395 L p .707 .577 .707 r
F P
0 g
s
.41557 .66395 m .40985 .68213 L .37942 .67312 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF3P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF000010001eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00HGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo0`0025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00GGoo0P000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FWoo00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00FGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001FOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`03
001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPh0
00=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH70006FUH20004FUH00`00FUH000030002FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP02FUH5000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60005FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002
FUH50004FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000YOol?000]Ool005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020004FUH50003FUH30007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000087oo2@000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo00@0
05YFFUH000AJEP03001JEUYF00EJEP<000IJEPP00003FUH005YF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0000?OolA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol0
1000FUIJEP0015YF00<005YFFUH00eYF0`0000=JEP00FUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`04001JEUYF0003FUH01000FUIJEUYF
0P000Woo00<005YF00000eYF1@000eYF3`001UYF00<005YFFUH00UYF00@005YF000000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003moo`l000Qoo`04001JEUYF0004FUH=00000eYF000000050003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00@000Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD0009JEP07001JEUYFFUH005YF000015YF10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002eoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP80009JEP03001JEUYF00800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
<Goo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800004FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000`Ool01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;goo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF3P000eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001J
EP00008000=JEP@00003FUH0000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YFFUH01EYF1000
1UYF0P0000EJEP00001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000/Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP@000QJEP03001JEUYF00@000UJEP03001JEUYF009JEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ40009JEP@002aoo`00
;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF1P000UYF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH01UYF00@005YFFUIJEPH0031oo`00;Goo0P000eYF00<005YFFUH00eYF
00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH01EYF00<005YF
000010000eYF00<005YFFUH01`0015YF00<005YFFUH01EYF0`001EYF00@005YF000000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPP00003FUH005YF00MJEP03001JEUYF009JEPL003Ioo`00;7oo
00<005YF00000eYF00<005YFFUH00eYF1@002Goo200000EJEP00FUIJEP0000AJEP03001JEUYF00AJ
EP@000=JEPL0009JEPD000AJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP03FUH01000FUIJEUYF2@0025YF00<005YFFUH00UYF2@00?Goo000/Ool00`00FUH00003FUH01000
FUIJEUYF0P005Woo0P000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP07001JEUYFFUH005YF
00001UYF1@0015YF00<005YFFUH00`001EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000P000MJEP03
001JEUYF009JEQl0031oo`00;7oo00<005YF00000eYF00@005YF000001Uoo`04001JEUYF0005FUH0
1000FUH000001EYF00L005YFFUIJEP00FUH00006FUH40005FUH300000eYF001JEP05FUH00`00FUIJ
EP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUHR
0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool20004FUH2000L
Ool01000FUIJEP0015YF0`0000=JEP00000010000eYF00<005YF00001UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00003Goo2@0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo0P000UYF0P007Woo00@005YFFUH000=J
EP<000AJEP04001JEUYFFUH60006FUH00`00FUIJEP030008FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool4000015YF0000000057oo0`001Goo00@005YFFUH0
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEP0000<0009JEP@00003FUH005YF00QJ
EP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH000060002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool00eYF001J
EP02FUH01000FUIJEP004Woo1@0017oo00@005YFFUIJEPD000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0009FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool30003FUH01000FUIJEUYF0P0047oo1@0017oo00P005YFFUIJEP00FUH005YF
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100025YF00<005YFFUH01EYF0P00
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00:goo0`000eYF00<005YFFUH00eYF0P003Woo1@001Goo0UYF
0P0000AJEP000000009JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF
00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00:goo00<005YF00000eYF00<005YFFUH00eYF
00@005YF000000Ioo`l00003OomJEP00009JEP8000AJEP03001JEUYF009JEPD000MJEP03001JEUYF
00MJEP04001JEP000003FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF00<005YF00000eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF100000=JEP0000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00`001UYF00<005YFFUH00UYF0P0000=JEP0000000`001eYF00<005YF
FUH01EYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool00`00FUIJEP02
FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF10000UYF10000UYF00<005YFFUH01eYF00H0
05YF000005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF5`00;Woo000/Ool01@00FUIJEUYF00000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF00@005YFFUH000EJEP8000AJEP03001JEUYF00EJEP04001JEP000002FUH70007
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPX000AJEP03
001JEUYF00EJEP<0009JEPD002ioo`00;7oo00H005YFFUIJEP00FUH200000eYF001JEP05FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF00H005YF000005YF0007
FUH00`00FUIJEP02FUH;0005FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPX0
00QJEP@00003FUH005YF00MJEP@003=oo`00;Goo00<005YFFUH00P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00@005YFFUIJEP<000IJEP03001J
EUYF00=JEPD000AJEP@00003FUH005YF00MJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04
001JEUYFFUH30007FUH00`00FUH0000dOol002ioo`04001JEP000003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH20004FUH00`00
FUIJEP03FUH800000eYF001JEP02FUH30007FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEP03
001JEUYF009JEPT0009oo`8000AJEP05001JEUYFFUH0000cOol002ioo`04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@0000=J
EP00FUH01UYF0`0015YF0`001EYF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP04001JEUYF0007FUH00`00FUIJEP02
FUH9000=Ool300000eYF001JEP03FUH00`00Oomoo`0`Ool002moo`03001JEP00009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPH000IJEP03001JEUYF00IJEP<000AJEP<00003FUH005YF00EJEP<0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH00000014001Uoo`8000EJ
EP03001oogoo02moo`00;goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00MJEP03001J
EP0000<000=JEP8000EJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP03001JEUYF009JEP03001oogoo01eoo`8000=J
EP80031oo`00;goo0P000eYF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF10000UYF00<005YF
FUH01EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF10001eYF00<005YFFUH015YF1`000eYF00L0
05YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001EYF
001JEUYF00001EYF00@005YFFUIJEP80025oo`06001JEUYF001JEP00;goo000_Ool20003FUH00`00
FUH000030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH200000eYF001JEP05FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEP@000AJ
EP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol300000eYF001oo`0^Ool002moo`8000=JEP@000EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF009JEP03001JEUYF
009JEP8002Aoo`04001JEUYF000^Ool002moo`80009JEP03001oogoo009oo`8000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH01@00FUH005YF00001UYF
00<005YFFUH01UYF0`001eYF00<005YFFUH015YF00L005YF000005YF001JEP02000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000:Ool3000HOol01000FUIJEP00;Goo000^Ool00`00FUH000020007Ool200000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH01@00FUH005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000:Ool5000GOol01000FUIJEP00;Goo000^Ool00`00FUH0000;Ool40006FUH00`00FUH0
00020004FUH00`00FUIJEP05FUH00`00FUH000030003Ool02000FUIJEP00FUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P002Woo1@0067oo0`00
;Goo000^Ool200000eYF001oo`0=Ool40002FUH60003FUH00`00FUIJEP02FUH50008Ool3000015YF
001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF300000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P000UYF00<005YFFUH00UYF0P002Woo
1@0067oo0P0000=JEP00Ool0:goo000^Ool20002FUH00`00Oomoo`0?Ool@000?Ool01@00FUH005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP8000]oo`<0
01Yoo`03001JEP0002aoo`00;Woo0P000eYF00<007ooOol04Goo1@0067oo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000eYF00<005YF0000:7oo
00<005YF0000;7oo000^Ool00`00FUIJEP02FUH3000BOol3000IOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH400001eYF000005YF001JEP0002Qoo`03001J
EP0002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH00P00;Goo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00@005YF0000009JEP800005FUH00000001JEP03000ZOol00`00Oomoo`0[
Ool002ioo`03001JEUYF009JEP03001JEUYF009JEP<002Uoo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP000002FUH00`00FUH00003FUH4000YOol2000]Ool002ioo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEP00000VOol01@00FUH005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH015YF30000UYF00<005YFFUH01eYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEP8000=JEP80009JEP03001JEP00008002Moo`8002eoo`00;Woo00D005YFFUIJEP0000IJ
EP04001JEUYFFUH3000QOol20002FUH00`00FUH00006FUH00`00FUIJEP04FUH900000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH005YF0P001EYF00<005YF000015YF0P0097oo0`00;Goo000_Ool01000FUIJEP001UYF00<005YF
FUH015YF10005goo2`0000=JEP00FUH01EYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF00@005YF001JEP8000IJEP8000EJEP<0
021oo`800003FUH007oo02eoo`00<7oo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01000
37oo1`000eYF1@0000EJEP00001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP06001JEP00
FUH005YF0P0015YF00@005YF000000=JEP04001JEUYF000NOol00`00FUIJEP02000^Ool0035oo`80
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`000=JEPL0009JEP04001JEUYFFUH200000eYF001J
EP02FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH30004FUH01@00FUH005YF00000eYF00@005YFFUH000AJEP<000=JEP03001oogoo
01Yoo`8000=JEP03001oogoo02eoo`00<Woo00<005YFFUH00eYF00<005YFFUH01UYF2P0015YF2000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001JEP<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04
001JEP000005FUH30007FUH5000HOol300000eYF001JEP02FUH00`00Oomoo`0]Ool003=oo`8000=J
EP03001JEP0000L000AJEPT000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF0P001eYF00<005YF0000
0`0047oo1P0015YF00@005YFFUH0031oo`00=7oo1P000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP04001JEP000004FUH00`00FUIJEP04FUH@0004FUH00`00FUIJEP03FUH3000a
Ool002moo`D0009JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000050002FUH01000FUIJ
EUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00<goo
000[Ool;0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
0002FUH300000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001UYF0`00
1UYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8003Eoo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P000UYF
00<005YFFUH00eYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000IJ
EP03001JEUYF008000=JEP04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH00000=goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP050007FUH01000FUIJEUYF0P001Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH000IJEP04001JEUYFFUH300000eYF001JEP02FUH200001Woo00000000FUH000QJ
EP03001JEUYF009JEPD003Uoo`00:goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH00UYF1`0015YF00<005YFFUH01EYF00@005YF000000Qoo`03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEP0000Aoo`l003ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4000
15YF00<005YFFUH00UYF1@002Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
1eYF00D005YFFUIJEP00009JEP03001JEUYF00<00003FUH007oo051oo`00;7oo00<005YF00000UYF
3@0047oo2@0047oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH01UYF00D005YF
FUIJEP0000=JEP04001JEUYFFUH2001BOol002aoo`D003Qoo`<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH0
0`00FUIJEP020003FUH00`00FUIJEP03001BOol006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000L000AJEP04001J
EUYF0002FUH00`00FUH00003FUH00`00FUH0001BOol006eoo`<000AJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000Qoo`L000=JEP03001J
EP0000D005=oo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01P0047oo00<005YFFUH00eYF00<007ooOol0Egoo001cOol40008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH50002Ool5000=Ool30005FUH00`00Oomoo`1G
Ool007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH60007Ool5000<Ool0
1000FUIJEP0015YF00<007ooOol0F7oo001mOolO000=Ool5000;Ool00`00FUIJEP02FUH01000FUH0
0000Fgoo002=Ool00`00FUH00003FUH00`00Oomoo`0DOol3000:Ool20005FUH2001MOol008aoo`04
001JEUYF0002FUH00`00Oomoo`0POol20007FUH00`00Oomoo`1LOol008aoo`04001JEUYFFUH2000Q
Ool200000eYF001JEP04FUH2001OOol008aoo`05001JEUYFFUH0000OOol30004FUH01@00FUIJEUYF
0000HGoo002<Ool200000eYF001oo`0LOol30007FUH01000FUH00000HWoo002=Ool00`00FUH0000K
Ool200000eYF001JEP08FUH00`00Oomoo`1ROol008eoo`03FUH007oo01Qoo`<000AJEP03001JEUYF
00AJEP8006Eoo`00SGoo0`0057oo10001eYF00<005YFFUH00UYF0P00Igoo002=Ool2000015YF0000
00003Goo10000UYF00<005YFFUH01eYF00@005YF000006Uoo`00SWoo00<005YF00000UYF3@001UYF
00<005YFFUH01UYF0`00Jgoo002>Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH00UYF0`00KWoo002?Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH00002001aOol0091oo`<000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD007Aoo`00TWoo
0`000UYF00<005YFFUH00UYF2000NGoo002EOol70021Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58871 .74323 m .59668 .68736 L .56581 .68166 L p .707 .577 .707 r
F P
0 g
s
.59668 .68736 m .58871 .74323 L .62024 .74692 L p .707 .577 .707 r
F P
0 g
s
.62024 .74692 m .62821 .69106 L .59668 .68736 L p .707 .577 .707 r
F P
0 g
s
.62821 .69106 m .62024 .74692 L .64934 .74824 L p .707 .577 .707 r
F P
0 g
s
.64934 .74824 m .65732 .69238 L .62821 .69106 L p .707 .577 .707 r
F P
0 g
s
.55784 .73752 m .56581 .68166 L .53862 .6745 L p .707 .577 .707 r
F P
0 g
s
.56581 .68166 m .55784 .73752 L .58871 .74323 L p .707 .577 .707 r
F P
0 g
s
.65732 .69238 m .64934 .74824 L .67317 .74706 L p .707 .577 .707 r
F P
0 g
s
.67317 .74706 m .68115 .6912 L .65732 .69238 L p .707 .577 .707 r
F P
0 g
s
.53862 .6745 m .53065 .73036 L .55784 .73752 L p .707 .577 .707 r
F P
0 g
s
.53065 .73036 m .53862 .6745 L .51778 .66659 L p .707 .577 .707 r
F P
0 g
s
.60147 .80283 m .60633 .76557 L .57542 .76019 L p .707 .577 .707 r
F P
0 g
s
.60633 .76557 m .60147 .80283 L .63306 .80614 L p .707 .577 .707 r
F P
0 g
s
.63306 .80614 m .63792 .76889 L .60633 .76557 L p .707 .577 .707 r
F P
0 g
s
.63792 .76889 m .63306 .80614 L .66223 .80707 L p .707 .577 .707 r
F P
0 g
s
.66223 .80707 m .66709 .76981 L .63792 .76889 L p .707 .577 .707 r
F P
0 g
s
.57056 .79745 m .57542 .76019 L .54821 .75326 L p .707 .577 .707 r
F P
0 g
s
.57542 .76019 m .57056 .79745 L .60147 .80283 L p .707 .577 .707 r
F P
0 g
s
.51778 .66659 m .5098 .72245 L .53065 .73036 L p .707 .577 .707 r
F P
0 g
s
.68115 .6912 m .67317 .74706 L .68939 .74349 L p .707 .577 .707 r
F P
0 g
s
.68939 .74349 m .69737 .68763 L .68115 .6912 L p .707 .577 .707 r
F P
0 g
s
.59255 .86086 m .58898 .84312 L .55838 .84606 L p .707 .577 .707 r
F P
0 g
s
.58898 .84312 m .59255 .86086 L .62385 .85437 L p .707 .577 .707 r
F P
0 g
s
.62385 .85437 m .62028 .83662 L .58898 .84312 L p .707 .577 .707 r
F P
0 g
s
.54821 .75326 m .54335 .79052 L .57056 .79745 L p .707 .577 .707 r
F P
0 g
s
.62028 .83662 m .62385 .85437 L .65277 .84495 L p .707 .577 .707 r
F P
0 g
s
.65277 .84495 m .6492 .8272 L .62028 .83662 L p .707 .577 .707 r
F P
0 g
s
.66709 .76981 m .66223 .80707 L .68612 .8055 L p .707 .577 .707 r
F P
0 g
s
.68612 .8055 m .69098 .76825 L .66709 .76981 L p .707 .577 .707 r
F P
0 g
s
.5098 .72245 m .51778 .66659 L .50532 .6587 L p .707 .577 .707 r
F P
0 g
s
.55838 .84606 m .56195 .86381 L .59255 .86086 L p .707 .577 .707 r
F P
0 g
s
.54335 .79052 m .54821 .75326 L .52737 .74547 L p .707 .577 .707 r
F P
0 g
s
.56195 .86381 m .55838 .84606 L .53148 .84516 L p .707 .577 .707 r
F P
0 g
s
.6492 .8272 m .65277 .84495 L .6765 .83353 L p .707 .577 .707 r
F P
0 g
s
.6765 .83353 m .67293 .81578 L .6492 .8272 L p .707 .577 .707 r
F P
0 g
s
.53148 .84516 m .53505 .8629 L .56195 .86381 L p .707 .577 .707 r
F P
0 g
s
.52737 .74547 m .52251 .78273 L .54335 .79052 L p .707 .577 .707 r
F P
0 g
s
.50532 .6587 m .49734 .71456 L .5098 .72245 L p .707 .577 .707 r
F P
0 g
s
.69098 .76825 m .68612 .8055 L .70241 .80161 L p .707 .577 .707 r
F P
0 g
s
.70241 .80161 m .70727 .76435 L .69098 .76825 L p .707 .577 .707 r
F P
0 g
s
.69737 .68763 m .68939 .74349 L .69642 .73789 L p .707 .577 .707 r
F P
0 g
s
.69642 .73789 m .70439 .68203 L .69737 .68763 L p .707 .577 .707 r
F P
0 g
s
.53505 .8629 m .53148 .84516 L .5109 .8405 L p .707 .577 .707 r
F P
0 g
s
.67293 .81578 m .6765 .83353 L .69271 .82123 L p .707 .577 .707 r
F P
0 g
s
.69271 .82123 m .68914 .80348 L .67293 .81578 L p .707 .577 .707 r
F P
0 g
s
.52251 .78273 m .52737 .74547 L .51493 .73758 L p .707 .577 .707 r
F P
0 g
s
.49734 .71456 m .50532 .6587 L .50246 .65161 L p .707 .577 .707 r
F P
0 g
s
.5109 .8405 m .51447 .85824 L .53505 .8629 L p .707 .577 .707 r
F P
0 g
s
.51493 .73758 m .51007 .77484 L .52251 .78273 L p .707 .577 .707 r
F P
0 g
s
.50246 .65161 m .49448 .70747 L .49734 .71456 L p .707 .577 .707 r
F P
0 g
s
.51447 .85824 m .5109 .8405 L .49866 .83254 L p .707 .577 .707 r
F P
0 g
s
.70727 .76435 m .70241 .80161 L .70949 .79577 L p .707 .577 .707 r
F P
0 g
s
.70949 .79577 m .71435 .75851 L .70727 .76435 L p .707 .577 .707 r
F P
0 g
s
.68914 .80348 m .69271 .82123 L .69981 .80925 L p .707 .577 .707 r
F P
0 g
s
.69981 .80925 m .69624 .7915 L .68914 .80348 L p .707 .577 .707 r
F P
0 g
s
.70439 .68203 m .69642 .73789 L .69356 .73079 L p .707 .577 .707 r
F P
0 g
s
.69356 .73079 m .70154 .67493 L .70439 .68203 L p .707 .577 .707 r
F P
0 g
s
.49866 .83254 m .50223 .85028 L .51447 .85824 L p .707 .577 .707 r
F P
0 g
s
.51007 .77484 m .51493 .73758 L .51211 .73036 L p .707 .577 .707 r
F P
0 g
s
.49224 .82187 m .49224 .31998 L .44811 .31744 L p .707 .577 .707 r
F P
0 g
s
.49448 .70747 m .50246 .65161 L .50948 .646 L p .707 .577 .707 r
F P
0 g
s
.51211 .73036 m .50725 .76762 L .51007 .77484 L p .707 .577 .707 r
F P
0 g
s
.50948 .646 m .50151 .70186 L .49448 .70747 L p .707 .577 .707 r
F P
0 g
s
.50725 .76762 m .51211 .73036 L .51919 .72452 L p .707 .577 .707 r
F P
0 g
s
.50151 .70186 m .50948 .646 L .52571 .64243 L p .707 .577 .707 r
F P
0 g
s
.51919 .72452 m .51434 .76178 L .50725 .76762 L p .707 .577 .707 r
F P
0 g
s
.52571 .64243 m .51773 .6983 L .50151 .70186 L p .707 .577 .707 r
F P
0 g
s
.50223 .85028 m .49866 .83254 L .49595 .82205 L p .707 .578 .707 r
F P
0 g
s
.49595 .82205 m .49953 .8398 L .50223 .85028 L p .707 .578 .707 r
F P
0 g
s
.49953 .8398 m .49595 .82205 L .50306 .81008 L p .707 .577 .707 r
F P
0 g
s
.50306 .81008 m .50663 .82782 L .49953 .8398 L p .707 .577 .707 r
F P
0 g
s
.51434 .76178 m .51919 .72452 L .53548 .72063 L p .707 .577 .707 r
F P
0 g
s
.51773 .6983 m .52571 .64243 L .54953 .64125 L p .707 .577 .707 r
F P
0 g
s
.53548 .72063 m .53062 .75789 L .51434 .76178 L p .707 .577 .707 r
F P
0 g
s
.54953 .64125 m .54156 .69711 L .51773 .6983 L p .707 .577 .707 r
F P
0 g
s
.50663 .82782 m .50306 .81008 L .51926 .79778 L p .707 .577 .707 r
F P
0 g
s
.51926 .79778 m .52284 .81552 L .50663 .82782 L p .707 .577 .707 r
F P
0 g
s
.53062 .75789 m .53548 .72063 L .55938 .71907 L p .707 .577 .707 r
F P
0 g
s
.55938 .71907 m .55452 .75633 L .53062 .75789 L p .707 .577 .707 r
F P
0 g
s
.52284 .81552 m .51926 .79778 L .54299 .78636 L p .707 .577 .707 r
F P
0 g
s
.54299 .78636 m .54657 .8041 L .52284 .81552 L p .707 .577 .707 r
F P
0 g
s
.49224 .31998 m .49224 .82187 L .53713 .82062 L p .707 .577 .707 r
F P
0 g
s
.53713 .82062 m .53713 .31873 L .49224 .31998 L p .707 .577 .707 r
F P
0 g
s
.54156 .69711 m .54953 .64125 L .57864 .64257 L p .707 .577 .707 r
F P
0 g
s
.57864 .64257 m .57066 .69844 L .54156 .69711 L p .707 .577 .707 r
F P
0 g
s
.55452 .75633 m .55938 .71907 L .58855 .71999 L p .707 .577 .707 r
F P
0 g
s
.58855 .71999 m .58369 .75725 L .55452 .75633 L p .707 .577 .707 r
F P
0 g
s
.54657 .8041 m .54299 .78636 L .57192 .77694 L p .707 .577 .707 r
F P
0 g
s
.57192 .77694 m .57549 .79468 L .54657 .8041 L p .707 .577 .707 r
F P
0 g
s
.57549 .79468 m .57192 .77694 L .60322 .77044 L p .707 .577 .707 r
F P
0 g
s
.60322 .77044 m .60679 .78818 L .57549 .79468 L p .707 .577 .707 r
F P
0 g
s
.53713 .31873 m .53713 .82062 L .57839 .81571 L p .707 .577 .707 r
F P
0 g
s
.57066 .69844 m .57864 .64257 L .61017 .64627 L p .707 .577 .707 r
F P
0 g
s
.61017 .64627 m .60219 .70213 L .57066 .69844 L p .707 .577 .707 r
F P
0 g
s
.57839 .81571 m .57839 .31382 L .53713 .31873 L p .707 .577 .707 r
F P
0 g
s
.44811 .81933 m .44811 .31744 L .40906 .31137 L p .707 .577 .707 r
F P
0 g
s
.44811 .31744 m .44811 .81933 L .49224 .82187 L p .707 .577 .707 r
F P
0 g
s
.71435 .75851 m .70949 .79577 L .70668 .78855 L p .707 .577 .707 r
F P
0 g
s
.70668 .78855 m .71154 .75129 L .71435 .75851 L p .707 .577 .707 r
F P
0 g
s
.69624 .7915 m .69981 .80925 L .69711 .79877 L p .707 .578 .707 r
F P
0 g
s
.69711 .79877 m .69354 .78102 L .69624 .7915 L p .707 .578 .707 r
F P
0 g
s
.64104 .65197 m .63307 .70784 L .60219 .70213 L p .707 .577 .707 r
F P
0 g
s
.60219 .70213 m .61017 .64627 L .64104 .65197 L p .707 .577 .707 r
F P
0 g
s
.58369 .75725 m .58855 .71999 L .62013 .7233 L p .707 .577 .707 r
F P
0 g
s
.63382 .7675 m .63739 .78524 L .60679 .78818 L p .707 .577 .707 r
F P
0 g
s
.60679 .78818 m .60322 .77044 L .63382 .7675 L p .707 .577 .707 r
F P
0 g
s
.62013 .7233 m .61528 .76056 L .58369 .75725 L p .707 .577 .707 r
F P
0 g
s
.57839 .31382 m .57839 .81571 L .61197 .80762 L p .707 .577 .707 r
F P
0 g
s
.61197 .80762 m .61197 .30573 L .57839 .31382 L p .707 .577 .707 r
F P
0 g
s
.70154 .67493 m .69356 .73079 L .6811 .72291 L p .707 .577 .707 r
F P
0 g
s
.6811 .72291 m .68907 .66704 L .70154 .67493 L p .707 .577 .707 r
F P
0 g
s
.40906 .81326 m .40906 .31137 L .37891 .30236 L p .707 .577 .707 r
F P
0 g
s
.40906 .31137 m .40906 .81326 L .44811 .81933 L p .707 .577 .707 r
F P
0 g
s
.25021 .72331 m .25365 .67049 L .22251 .666 L p .707 .577 .707 r
F P
0 g
s
.25365 .67049 m .25021 .72331 L .28198 .72386 L p .707 .577 .707 r
F P
0 g
s
.28198 .72386 m .28542 .67104 L .25365 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28542 .67104 m .28198 .72386 L .31128 .72041 L p .707 .577 .707 r
F P
0 g
s
.31128 .72041 m .31471 .66759 L .28542 .67104 L p .707 .577 .707 r
F P
0 g
s
.21907 .71882 m .22251 .666 L .19506 .658 L p .707 .577 .707 r
F P
0 g
s
.22251 .666 m .21907 .71882 L .25021 .72331 L p .707 .577 .707 r
F P
0 g
s
.25555 .78619 m .25765 .75079 L .22651 .74649 L p .707 .577 .707 r
F P
0 g
s
.25765 .75079 m .25555 .78619 L .28734 .78665 L p .707 .577 .707 r
F P
0 g
s
.28734 .78665 m .28943 .75125 L .25765 .75079 L p .707 .577 .707 r
F P
0 g
s
.69354 .78102 m .69711 .79877 L .68487 .7908 L p .707 .577 .707 r
F P
0 g
s
.68487 .7908 m .6813 .77306 L .69354 .78102 L p .707 .577 .707 r
F P
0 g
s
.71154 .75129 m .70668 .78855 L .69424 .78066 L p .707 .577 .707 r
F P
0 g
s
.69424 .78066 m .6991 .7434 L .71154 .75129 L p .707 .577 .707 r
F P
0 g
s
.28943 .75125 m .28734 .78665 L .31667 .78323 L p .707 .577 .707 r
F P
0 g
s
.31667 .78323 m .31876 .74783 L .28943 .75125 L p .707 .577 .707 r
F P
0 g
s
.31471 .66759 m .31128 .72041 L .33523 .7133 L p .707 .577 .707 r
F P
0 g
s
.33523 .7133 m .33867 .66048 L .31471 .66759 L p .707 .577 .707 r
F P
0 g
s
.65104 .72869 m .64619 .76595 L .61528 .76056 L p .707 .577 .707 r
F P
0 g
s
.61528 .76056 m .62013 .7233 L .65104 .72869 L p .707 .577 .707 r
F P
0 g
s
.61197 .30573 m .61197 .80762 L .63459 .79714 L p .707 .577 .707 r
F P
0 g
s
.66823 .65913 m .66025 .71499 L .63307 .70784 L p .707 .577 .707 r
F P
0 g
s
.63307 .70784 m .64104 .65197 L .66823 .65913 L p .707 .577 .707 r
F P
0 g
s
.63739 .78524 m .63382 .7675 L .66072 .7684 L p .707 .577 .707 r
F P
0 g
s
.63459 .79714 m .63459 .29525 L .61197 .30573 L p .707 .577 .707 r
F P
0 g
s
.22442 .78189 m .22651 .74649 L .19908 .73877 L p .707 .577 .707 r
F P
0 g
s
.22651 .74649 m .22442 .78189 L .25555 .78619 L p .707 .577 .707 r
F P
0 g
s
.68907 .66704 m .6811 .72291 L .66025 .71499 L p .707 .577 .707 r
F P
0 g
s
.66025 .71499 m .66823 .65913 L .68907 .66704 L p .707 .577 .707 r
F P
0 g
s
.19162 .71082 m .19506 .658 L .17397 .64728 L p .707 .577 .707 r
F P
0 g
s
.19506 .658 m .19162 .71082 L .21907 .71882 L p .707 .577 .707 r
F P
0 g
s
.31876 .74783 m .31667 .78323 L .34067 .77626 L p .707 .577 .707 r
F P
0 g
s
.34067 .77626 m .34276 .74086 L .31876 .74783 L p .707 .577 .707 r
F P
0 g
s
.37891 .80425 m .37891 .30236 L .36061 .29129 L p .707 .577 .707 r
F P
0 g
s
.37891 .30236 m .37891 .80425 L .40906 .81326 L p .707 .577 .707 r
F P
0 g
s
.19699 .77417 m .19908 .73877 L .17804 .72839 L p .707 .577 .707 r
F P
0 g
s
.19908 .73877 m .19699 .77417 L .22442 .78189 L p .707 .577 .707 r
F P
0 g
s
.33867 .66048 m .33523 .7133 L .35149 .70323 L p .707 .577 .707 r
F P
0 g
s
.35149 .70323 m .35493 .65041 L .33867 .66048 L p .707 .577 .707 r
F P
0 g
s
.25188 .79563 m .25033 .77653 L .21925 .77843 L p .707 .577 .707 r
F P
0 g
s
.25033 .77653 m .25188 .79563 L .28361 .79284 L p .707 .577 .707 r
F P
0 g
s
.28361 .79284 m .28206 .77373 L .25033 .77653 L p .707 .577 .707 r
F P
0 g
s
.21925 .77843 m .2208 .79753 L .25188 .79563 L p .707 .577 .707 r
F P
0 g
s
.28206 .77373 m .28361 .79284 L .31288 .78942 L p .707 .577 .707 r
F P
0 g
s
.31288 .78942 m .31134 .77031 L .28206 .77373 L p .707 .577 .707 r
F P
0 g
s
.17053 .7001 m .17397 .64728 L .16132 .63489 L p .707 .577 .707 r
F P
0 g
s
.17397 .64728 m .17053 .7001 L .19162 .71082 L p .707 .577 .707 r
F P
0 g
s
.6813 .77306 m .68487 .7908 L .66429 .78614 L p .707 .577 .707 r
F P
0 g
s
.66429 .78614 m .66072 .7684 L .6813 .77306 L p .707 .577 .707 r
F P
0 g
s
.6991 .7434 m .69424 .78066 L .67339 .77287 L p .707 .577 .707 r
F P
0 g
s
.67339 .77287 m .67825 .73561 L .6991 .7434 L p .707 .577 .707 r
F P
0 g
s
.2208 .79753 m .21925 .77843 L .19187 .77924 L p .707 .577 .707 r
F P
0 g
s
.19187 .77924 m .19341 .79834 L .2208 .79753 L p .707 .577 .707 r
F P
0 g
s
.17804 .72839 m .17595 .76379 L .19699 .77417 L p .707 .577 .707 r
F P
0 g
s
.34276 .74086 m .34067 .77626 L .35699 .76642 L p .707 .577 .707 r
F P
0 g
s
.35699 .76642 m .35908 .73102 L .34276 .74086 L p .707 .577 .707 r
F P
0 g
s
.31134 .77031 m .31288 .78942 L .33683 .78571 L p .707 .577 .707 r
F P
0 g
s
.33683 .78571 m .33529 .76661 L .31134 .77031 L p .707 .577 .707 r
F P
0 g
s
.66072 .7684 m .66429 .78614 L .63739 .78524 L p .707 .577 .707 r
F P
0 g
s
.63459 .29525 m .63459 .79714 L .64404 .7853 L p .707 .577 .707 r
F P
0 g
s
.64404 .7853 m .64404 .28341 L .63459 .29525 L p .707 .577 .707 r
F P
0 g
s
.17595 .76379 m .17804 .72839 L .16544 .71637 L p .707 .577 .707 r
F P
0 g
s
.35493 .65041 m .35149 .70323 L .35848 .69117 L p .707 .577 .707 r
F P
0 g
s
.35848 .69117 m .36191 .63835 L .35493 .65041 L p .707 .577 .707 r
F P
0 g
s
.19341 .79834 m .19187 .77924 L .17085 .77889 L p .707 .577 .707 r
F P
0 g
s
.17085 .77889 m .1724 .798 L .19341 .79834 L p .707 .577 .707 r
F P
0 g
s
.16132 .63489 m .15788 .68771 L .17053 .7001 L p .707 .577 .707 r
F P
0 g
s
.67825 .73561 m .67339 .77287 L .64619 .76595 L p .707 .577 .707 r
F P
0 g
s
.64619 .76595 m .65104 .72869 L .67825 .73561 L p .707 .577 .707 r
F P
0 g
s
.35908 .73102 m .35699 .76642 L .36404 .75469 L p .707 .577 .707 r
F P
0 g
s
.36404 .75469 m .36613 .71928 L .35908 .73102 L p .707 .577 .707 r
F P
0 g
s
.36191 .63835 m .35848 .69117 L .3555 .67832 L p .707 .577 .707 r
F P
0 g
s
.3555 .67832 m .35893 .6255 L .36191 .63835 L p .707 .577 .707 r
F P
0 g
s
.36321 .70679 m .36112 .74219 L .34852 .73017 L p .707 .577 .707 r
F P
0 g
s
.34852 .73017 m .35061 .69477 L .36321 .70679 L p .707 .577 .707 r
F P
0 g
s
.36061 .79318 m .36061 .29129 L .35596 .27925 L p .707 .577 .707 r
F P
0 g
s
.36613 .71928 m .36404 .75469 L .36112 .74219 L p .707 .577 .707 r
F P
0 g
s
.36112 .74219 m .36321 .70679 L .36613 .71928 L p .707 .577 .707 r
F P
0 g
s
.36061 .29129 m .36061 .79318 L .37891 .80425 L p .707 .577 .707 r
F P
0 g
s
.15788 .68771 m .16132 .63489 L .15834 .62203 L p .707 .577 .707 r
F P
0 g
s
.16544 .71637 m .16335 .75177 L .17595 .76379 L p .707 .577 .707 r
F P
0 g
s
.33529 .76661 m .33683 .78571 L .35312 .78207 L p .707 .577 .707 r
F P
0 g
s
.35312 .78207 m .35157 .76297 L .33529 .76661 L p .707 .577 .707 r
F P
0 g
s
.16335 .75177 m .16544 .71637 L .16252 .70388 L p .707 .577 .707 r
F P
0 g
s
.1724 .798 m .17085 .77889 L .15827 .77742 L p .707 .577 .707 r
F P
0 g
s
.15827 .77742 m .15981 .79652 L .1724 .798 L p .707 .577 .707 r
F P
0 g
s
.15834 .62203 m .1549 .67486 L .15788 .68771 L p .707 .577 .707 r
F P
0 g
s
.16252 .70388 m .16043 .73928 L .16335 .75177 L p .707 .577 .707 r
F P
0 g
s
.64404 .28341 m .64404 .7853 L .63938 .77325 L p .707 .577 .707 r
F P
0 g
s
.63938 .77325 m .63938 .27137 L .64404 .28341 L p .707 .577 .707 r
F P
0 g
s
.1549 .67486 m .15834 .62203 L .16532 .60998 L p .707 .577 .707 r
F P
0 g
s
.35157 .76297 m .35312 .78207 L .36014 .77887 L p .707 .577 .707 r
F P
0 g
s
.36014 .77887 m .3586 .75977 L .35157 .76297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16043 .73928 m .16252 .70388 L .16957 .69214 L p .707 .577 .707 r
F P
0 g
s
.35893 .6255 m .3555 .67832 L .34284 .66593 L p .707 .577 .707 r
F P
0 g
s
.34284 .66593 m .34628 .61311 L .35893 .6255 L p .707 .577 .707 r
F P
0 g
s
.3586 .75977 m .36014 .77887 L .35722 .77641 L p .707 .577 .707 r
F P
0 g
s
.35722 .77641 m .35567 .75731 L .3586 .75977 L p .707 .577 .707 r
F P
0 g
s
.35567 .75731 m .35722 .77641 L .34463 .77493 L p .707 .577 .707 r
F P
0 g
s
.35596 .27925 m .35596 .78114 L .36061 .79318 L p .707 .577 .707 r
F P
0 g
s
.35596 .78114 m .35596 .27925 L .36541 .26741 L p .707 .577 .707 r
F P
0 g
s
.15981 .79652 m .15827 .77742 L .15534 .77496 L p .707 .577 .707 r
F P
0 g
s
.15534 .77496 m .15689 .79406 L .15981 .79652 L p .707 .577 .707 r
F P
0 g
s
.16532 .60998 m .16189 .6628 L .1549 .67486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16957 .69214 m .16748 .72754 L .16043 .73928 L p .707 .577 .707 r
F P
0 g
s
.16189 .6628 m .16532 .60998 L .18159 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16748 .72754 m .16957 .69214 L .18589 .6823 L p .707 .577 .707 r
F P
0 g
s
.63938 .27137 m .63938 .77325 L .62109 .76219 L p .707 .577 .707 r
F P
0 g
s
.62109 .76219 m .62109 .2603 L .63938 .27137 L p .707 .577 .707 r
F P
0 g
s
.34628 .61311 m .34284 .66593 L .32176 .65521 L p .707 .577 .707 r
F P
0 g
s
.32176 .65521 m .3252 .60239 L .34628 .61311 L p .707 .577 .707 r
F P
0 g
s
.15689 .79406 m .15534 .77496 L .16237 .77175 L p .707 .577 .707 r
F P
0 g
s
.16237 .77175 m .16391 .79085 L .15689 .79406 L p .707 .577 .707 r
F P
0 g
s
.18159 .59991 m .17815 .65273 L .16189 .6628 L p .707 .577 .707 r
F P
0 g
s
.17815 .65273 m .18159 .59991 L .20554 .5928 L p .707 .577 .707 r
F P
0 g
s
.36541 .7693 m .36541 .26741 L .38803 .25693 L p .707 .577 .707 r
F P
0 g
s
.36541 .26741 m .36541 .7693 L .35596 .78114 L p .707 .577 .707 r
F P
0 g
s
.18589 .6823 m .1838 .7177 L .16748 .72754 L p .707 .577 .707 r
F P
0 g
s
.35061 .69477 m .34852 .73017 L .32748 .71979 L p .707 .577 .707 r
F P
0 g
s
.32748 .71979 m .32957 .68439 L .35061 .69477 L p .707 .577 .707 r
F P
0 g
s
.34463 .77493 m .34309 .75583 L .35567 .75731 L p .707 .577 .707 r
F P
0 g
s
.1838 .7177 m .18589 .6823 L .20989 .67533 L p .707 .577 .707 r
F P
0 g
s
.3252 .60239 m .32176 .65521 L .2943 .64721 L p .707 .577 .707 r
F P
0 g
s
.2943 .64721 m .29774 .59439 L .3252 .60239 L p .707 .577 .707 r
F P
0 g
s
.2021 .64562 m .20554 .5928 L .23483 .58935 L p .707 .577 .707 r
F P
0 g
s
.20554 .5928 m .2021 .64562 L .17815 .65273 L p .707 .577 .707 r
F P
0 g
s
.16391 .79085 m .16237 .77175 L .17865 .76812 L p .707 .577 .707 r
F P
0 g
s
.62109 .2603 m .62109 .76219 L .59094 .75317 L p .707 .577 .707 r
F P
0 g
s
.59094 .75317 m .59094 .25128 L .62109 .2603 L p .707 .577 .707 r
F P
0 g
s
.17865 .76812 m .1802 .78722 L .16391 .79085 L p .707 .577 .707 r
F P
0 g
s
.20989 .67533 m .2078 .71073 L .1838 .7177 L p .707 .577 .707 r
F P
0 g
s
.32957 .68439 m .32748 .71979 L .30004 .71207 L p .707 .577 .707 r
F P
0 g
s
.30004 .71207 m .30214 .67667 L .32957 .68439 L p .707 .577 .707 r
F P
0 g
s
.29774 .59439 m .2943 .64721 L .26317 .64272 L p .707 .577 .707 r
F P
0 g
s
.26317 .64272 m .26661 .5899 L .29774 .59439 L p .707 .577 .707 r
F P
0 g
s
.2314 .64217 m .23483 .58935 L .26661 .5899 L p .707 .577 .707 r
F P
0 g
s
.23483 .58935 m .2314 .64217 L .2021 .64562 L p .707 .577 .707 r
F P
0 g
s
.2078 .71073 m .20989 .67533 L .23922 .67191 L p .707 .577 .707 r
F P
0 g
s
.26661 .5899 m .26317 .64272 L .2314 .64217 L p .707 .577 .707 r
F P
0 g
s
.38803 .25693 m .38803 .75882 L .36541 .7693 L p .707 .577 .707 r
F P
0 g
s
.38803 .75882 m .38803 .25693 L .42161 .24884 L p .707 .577 .707 r
F P
0 g
s
.73683 .64571 m .73339 .58863 L .70226 .58954 L p .707 .577 .707 r
F P
0 g
s
.73339 .58863 m .73683 .64571 L .7686 .64344 L p .707 .577 .707 r
F P
0 g
s
.7686 .64344 m .76516 .58635 L .73339 .58863 L p .707 .577 .707 r
F P
0 g
s
.34309 .75583 m .34463 .77493 L .32362 .77458 L p .707 .577 .707 r
F P
0 g
s
.32362 .77458 m .32207 .75548 L .34309 .75583 L p .707 .577 .707 r
F P
0 g
s
.30214 .67667 m .30004 .71207 L .26891 .70777 L p .707 .577 .707 r
F P
0 g
s
.26891 .70777 m .271 .67237 L .30214 .67667 L p .707 .577 .707 r
F P
0 g
s
.76516 .58635 m .7686 .64344 L .7979 .64002 L p .707 .577 .707 r
F P
0 g
s
.7979 .64002 m .79446 .58293 L .76516 .58635 L p .707 .577 .707 r
F P
0 g
s
.23713 .70731 m .23922 .67191 L .271 .67237 L p .707 .577 .707 r
F P
0 g
s
.23922 .67191 m .23713 .70731 L .2078 .71073 L p .707 .577 .707 r
F P
0 g
s
.70569 .64663 m .70226 .58954 L .6748 .589 L p .707 .577 .707 r
F P
0 g
s
.70226 .58954 m .70569 .64663 L .73683 .64571 L p .707 .577 .707 r
F P
0 g
s
.271 .67237 m .26891 .70777 L .23713 .70731 L p .707 .577 .707 r
F P
0 g
s
.1802 .78722 m .17865 .76812 L .2026 .76441 L p .707 .577 .707 r
F P
0 g
s
.2026 .76441 m .20415 .78351 L .1802 .78722 L p .707 .577 .707 r
F P
0 g
s
.6748 .589 m .67824 .64609 L .70569 .64663 L p .707 .577 .707 r
F P
0 g
s
.79446 .58293 m .7979 .64002 L .82185 .6358 L p .707 .577 .707 r
F P
0 g
s
.82185 .6358 m .81841 .57871 L .79446 .58293 L p .707 .577 .707 r
F P
0 g
s
.59094 .25128 m .59094 .75317 L .55189 .7471 L p .707 .577 .707 r
F P
0 g
s
.55189 .7471 m .55189 .24521 L .59094 .25128 L p .707 .577 .707 r
F P
0 g
s
.67824 .64609 m .6748 .589 L .65372 .58706 L p .707 .577 .707 r
F P
0 g
s
.32207 .75548 m .32362 .77458 L .29623 .7754 L p .707 .577 .707 r
F P
0 g
s
.29623 .7754 m .29469 .7563 L .32207 .75548 L p .707 .577 .707 r
F P
0 g
s
.42161 .75073 m .42161 .24884 L .46287 .24393 L p .707 .577 .707 r
F P
0 g
s
.42161 .24884 m .42161 .75073 L .38803 .75882 L p .707 .577 .707 r
F P
0 g
s
.65372 .58706 m .65715 .64414 L .67824 .64609 L p .707 .577 .707 r
F P
0 g
s
.73109 .70391 m .72899 .66591 L .69786 .66656 L p .707 .577 .707 r
F P
0 g
s
.72899 .66591 m .73109 .70391 L .76287 .70178 L p .707 .577 .707 r
F P
0 g
s
.76287 .70178 m .76078 .66377 L .72899 .66591 L p .707 .577 .707 r
F P
0 g
s
.20415 .78351 m .2026 .76441 L .23188 .76099 L p .707 .577 .707 r
F P
0 g
s
.76078 .66377 m .76287 .70178 L .7922 .69837 L p .707 .577 .707 r
F P
0 g
s
.7922 .69837 m .79011 .66037 L .76078 .66377 L p .707 .577 .707 r
F P
0 g
s
.23188 .76099 m .23342 .78009 L .20415 .78351 L p .707 .577 .707 r
F P
0 g
s
.81841 .57871 m .82185 .6358 L .83811 .63118 L p .707 .577 .707 r
F P
0 g
s
.83811 .63118 m .83467 .57409 L .81841 .57871 L p .707 .577 .707 r
F P
0 g
s
.69786 .66656 m .69995 .70457 L .73109 .70391 L p .707 .577 .707 r
F P
0 g
s
.69995 .70457 m .69786 .66656 L .67043 .66568 L p .707 .577 .707 r
F P
0 g
s
.73485 .77762 m .73639 .76043 L .70531 .75507 L p .707 .577 .707 r
F P
0 g
s
.73639 .76043 m .73485 .77762 L .76658 .77862 L p .707 .577 .707 r
F P
0 g
s
.76658 .77862 m .76812 .76143 L .73639 .76043 L p .707 .577 .707 r
F P
0 g
s
.55189 .24521 m .55189 .7471 L .50776 .74457 L p .707 .577 .707 r
F P
0 g
s
.50776 .74457 m .50776 .24268 L .55189 .24521 L p .707 .577 .707 r
F P
0 g
s
.29469 .7563 m .29623 .7754 L .26515 .7773 L p .707 .577 .707 r
F P
0 g
s
.26515 .7773 m .26361 .75819 L .29469 .7563 L p .707 .577 .707 r
F P
0 g
s
.67043 .66568 m .67252 .70369 L .69995 .70457 L p .707 .577 .707 r
F P
0 g
s
.76812 .76143 m .76658 .77862 L .79585 .77515 L p .707 .577 .707 r
F P
0 g
s
.79585 .77515 m .79739 .75796 L .76812 .76143 L p .707 .577 .707 r
F P
0 g
s
.46287 .74582 m .46287 .24393 L .50776 .24268 L p .707 .577 .707 r
F P
0 g
s
.46287 .24393 m .46287 .74582 L .42161 .75073 L p .707 .577 .707 r
F P
0 g
s
.70377 .77226 m .70531 .75507 L .67792 .74586 L p .707 .577 .707 r
F P
0 g
s
.70531 .75507 m .70377 .77226 L .73485 .77762 L p .707 .577 .707 r
F P
0 g
s
.23342 .78009 m .23188 .76099 L .26361 .75819 L p .707 .577 .707 r
F P
0 g
s
.79011 .66037 m .7922 .69837 L .8162 .69403 L p .707 .577 .707 r
F P
0 g
s
.8162 .69403 m .81411 .65603 L .79011 .66037 L p .707 .577 .707 r
F P
0 g
s
.65715 .64414 m .65372 .58706 L .64106 .58391 L p .707 .577 .707 r
F P
0 g
s
.26361 .75819 m .26515 .7773 L .23342 .78009 L p .707 .577 .707 r
F P
0 g
s
.50776 .24268 m .50776 .74457 L .46287 .74582 L p .707 .577 .707 r
F P
0 g
s
.67792 .74586 m .67638 .76305 L .70377 .77226 L p .707 .577 .707 r
F P
0 g
s
.64106 .58391 m .6445 .64099 L .65715 .64414 L p .707 .577 .707 r
F P
0 g
s
.67252 .70369 m .67043 .66568 L .64939 .66334 L p .707 .577 .707 r
F P
0 g
s
.79739 .75796 m .79585 .77515 L .8198 .76754 L p .707 .577 .707 r
F P
0 g
s
.8198 .76754 m .82135 .75035 L .79739 .75796 L p .707 .577 .707 r
F P
0 g
s
.67638 .76305 m .67792 .74586 L .65691 .73371 L p .707 .577 .707 r
F P
0 g
s
.64939 .66334 m .65148 .70135 L .67252 .70369 L p .707 .577 .707 r
F P
0 g
s
.83467 .57409 m .83811 .63118 L .8451 .62662 L p .707 .577 .707 r
F P
0 g
s
.8451 .62662 m .84166 .56954 L .83467 .57409 L p .707 .577 .707 r
F P
0 g
s
.81411 .65603 m .8162 .69403 L .83252 .68919 L p .707 .577 .707 r
F P
0 g
s
.83252 .68919 m .83043 .65118 L .81411 .65603 L p .707 .577 .707 r
F P
0 g
s
.65691 .73371 m .65536 .7509 L .67638 .76305 L p .707 .577 .707 r
F P
0 g
s
.6445 .64099 m .64106 .58391 L .63808 .57986 L p .707 .577 .707 r
F P
0 g
s
.82135 .75035 m .8198 .76754 L .83609 .75656 L p .707 .577 .707 r
F P
0 g
s
.83609 .75656 m .83763 .73937 L .82135 .75035 L p .707 .577 .707 r
F P
0 g
s
.65148 .70135 m .64939 .66334 L .63679 .65978 L p .707 .577 .707 r
F P
0 g
s
.65536 .7509 m .65691 .73371 L .64432 .7198 L p .707 .577 .707 r
F P
0 g
s
.63808 .57986 m .64152 .63694 L .6445 .64099 L p .707 .577 .707 r
F P
0 g
s
.63679 .65978 m .63888 .69778 L .65148 .70135 L p .707 .577 .707 r
F P
0 g
s
.64432 .7198 m .64278 .73699 L .65536 .7509 L p .707 .577 .707 r
F P
0 g
s
.84166 .56954 m .8451 .62662 L .84212 .62257 L p .707 .577 .707 r
F P
0 g
s
.84212 .62257 m .83868 .56549 L .84166 .56954 L p .707 .577 .707 r
F P
0 g
s
.83043 .65118 m .83252 .68919 L .83957 .6843 L p .707 .577 .707 r
F P
0 g
s
.83957 .6843 m .83748 .64629 L .83043 .65118 L p .707 .577 .707 r
F P
0 g
s
.83763 .73937 m .83609 .75656 L .84311 .74327 L p .707 .577 .707 r
F P
0 g
s
.84311 .74327 m .84466 .72608 L .83763 .73937 L p .707 .577 .707 r
F P
0 g
s
.64278 .73699 m .64432 .7198 L .6414 .7055 L p .707 .577 .707 r
F P
0 g
s
.64152 .63694 m .63808 .57986 L .64507 .5753 L p .707 .577 .707 r
F P
0 g
s
.63888 .69778 m .63679 .65978 L .63387 .65533 L p .707 .577 .707 r
F P
0 g
s
.63387 .65533 m .63596 .69334 L .63888 .69778 L p .707 .577 .707 r
F P
0 g
s
.6414 .7055 m .63986 .72269 L .64278 .73699 L p .707 .577 .707 r
F P
0 g
s
.64507 .5753 m .64851 .63239 L .64152 .63694 L p .707 .577 .707 r
F P
0 g
s
.83748 .64629 m .83957 .6843 L .83665 .67986 L p .707 .577 .707 r
F P
0 g
s
.83665 .67986 m .83456 .64185 L .83748 .64629 L p .707 .577 .707 r
F P
0 g
s
.83868 .56549 m .84212 .62257 L .82946 .61942 L p .707 .577 .707 r
F P
0 g
s
.82946 .61942 m .82603 .56233 L .83868 .56549 L p .707 .577 .707 r
F P
0 g
s
.84466 .72608 m .84311 .74327 L .84019 .72897 L p .707 .577 .707 r
F P
0 g
s
.84019 .72897 m .84173 .71178 L .84466 .72608 L p .707 .577 .707 r
F P
0 g
s
.63986 .72269 m .6414 .7055 L .64843 .6922 L p .707 .577 .707 r
F P
0 g
s
.3978 .62615 m .38983 .57211 L .35896 .57388 L p .707 .577 .707 r
F P
0 g
s
.38983 .57211 m .3978 .62615 L .42933 .62105 L p .707 .577 .707 r
F P
0 g
s
.42933 .62105 m .42136 .56701 L .38983 .57211 L p .707 .577 .707 r
F P
0 g
s
.42136 .56701 m .42933 .62105 L .45844 .61312 L p .707 .577 .707 r
F P
0 g
s
.45844 .61312 m .45046 .55908 L .42136 .56701 L p .707 .577 .707 r
F P
0 g
s
.64851 .63239 m .64507 .5753 L .66133 .57068 L p .707 .577 .707 r
F P
0 g
s
.63596 .69334 m .63387 .65533 L .64092 .65045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64843 .6922 m .64688 .70939 L .63986 .72269 L p .707 .577 .707 r
F P
0 g
s
.36693 .62792 m .35896 .57388 L .33177 .57214 L p .707 .577 .707 r
F P
0 g
s
.35896 .57388 m .36693 .62792 L .3978 .62615 L p .707 .577 .707 r
F P
0 g
s
.64092 .65045 m .64301 .68845 L .63596 .69334 L p .707 .577 .707 r
F P
0 g
s
.66133 .57068 m .66477 .62777 L .64851 .63239 L p .707 .577 .707 r
F P
0 g
s
.45046 .55908 m .45844 .61312 L .48227 .60313 L p .707 .577 .707 r
F P
0 g
s
.48227 .60313 m .47429 .54909 L .45046 .55908 L p .707 .577 .707 r
F P
0 g
s
.38472 .68757 m .37986 .65142 L .34895 .65286 L p .707 .577 .707 r
F P
0 g
s
.37986 .65142 m .38472 .68757 L .41631 .68285 L p .707 .577 .707 r
F P
0 g
s
.41631 .68285 m .41145 .6467 L .37986 .65142 L p .707 .577 .707 r
F P
0 g
s
.82603 .56233 m .82946 .61942 L .80838 .61748 L p .707 .577 .707 r
F P
0 g
s
.80838 .61748 m .80494 .56039 L .82603 .56233 L p .707 .577 .707 r
F P
0 g
s
.41145 .6467 m .41631 .68285 L .44548 .67532 L p .707 .577 .707 r
F P
0 g
s
.44548 .67532 m .44062 .63917 L .41145 .6467 L p .707 .577 .707 r
F P
0 g
s
.83456 .64185 m .83665 .67986 L .82405 .67629 L p .707 .577 .707 r
F P
0 g
s
.82405 .67629 m .82196 .63829 L .83456 .64185 L p .707 .577 .707 r
F P
0 g
s
.84173 .71178 m .84019 .72897 L .8276 .71506 L p .707 .577 .707 r
F P
0 g
s
.8276 .71506 m .82915 .69787 L .84173 .71178 L p .707 .577 .707 r
F P
0 g
s
.33974 .62618 m .33177 .57214 L .31092 .56707 L p .707 .577 .707 r
F P
0 g
s
.33177 .57214 m .33974 .62618 L .36693 .62792 L p .707 .577 .707 r
F P
0 g
s
.35381 .68901 m .34895 .65286 L .32174 .65089 L p .707 .577 .707 r
F P
0 g
s
.34895 .65286 m .35381 .68901 L .38472 .68757 L p .707 .577 .707 r
F P
0 g
s
.64688 .70939 m .64843 .6922 L .66471 .68122 L p .707 .577 .707 r
F P
0 g
s
.44062 .63917 m .44548 .67532 L .46937 .66571 L p .707 .577 .707 r
F P
0 g
s
.46937 .66571 m .46452 .62956 L .44062 .63917 L p .707 .577 .707 r
F P
0 g
s
.66477 .62777 m .66133 .57068 L .68528 .56646 L p .707 .577 .707 r
F P
0 g
s
.47429 .54909 m .48227 .60313 L .49849 .59207 L p .707 .577 .707 r
F P
0 g
s
.49849 .59207 m .49051 .53803 L .47429 .54909 L p .707 .577 .707 r
F P
0 g
s
.64301 .68845 m .64092 .65045 L .65724 .6456 L p .707 .577 .707 r
F P
0 g
s
.66471 .68122 m .66317 .69841 L .64688 .70939 L p .707 .577 .707 r
F P
0 g
s
.68528 .56646 m .68872 .62355 L .66477 .62777 L p .707 .577 .707 r
F P
0 g
s
.39321 .71304 m .39678 .69449 L .36618 .68743 L p .707 .577 .707 r
F P
0 g
s
.39678 .69449 m .39321 .71304 L .4245 .71832 L p .707 .577 .707 r
F P
0 g
s
.4245 .71832 m .42807 .69977 L .39678 .69449 L p .707 .577 .707 r
F P
0 g
s
.32174 .65089 m .3266 .68704 L .35381 .68901 L p .707 .577 .707 r
F P
0 g
s
.65724 .6456 m .65933 .6836 L .64301 .68845 L p .707 .577 .707 r
F P
0 g
s
.36618 .68743 m .36261 .70599 L .39321 .71304 L p .707 .577 .707 r
F P
0 g
s
.42807 .69977 m .4245 .71832 L .45343 .72131 L p .707 .577 .707 r
F P
0 g
s
.45343 .72131 m .457 .70276 L .42807 .69977 L p .707 .577 .707 r
F P
0 g
s
.80494 .56039 m .80838 .61748 L .78092 .61694 L p .707 .577 .707 r
F P
0 g
s
.78092 .61694 m .77749 .55985 L .80494 .56039 L p .707 .577 .707 r
F P
0 g
s
.3266 .68704 m .32174 .65089 L .3009 .64569 L p .707 .577 .707 r
F P
0 g
s
.31092 .56707 m .3189 .62111 L .33974 .62618 L p .707 .577 .707 r
F P
0 g
s
.36261 .70599 m .36618 .68743 L .33928 .6793 L p .707 .577 .707 r
F P
0 g
s
.33928 .6793 m .3357 .69785 L .36261 .70599 L p .707 .577 .707 r
F P
0 g
s
.82915 .69787 m .8276 .71506 L .80659 .7029 L p .707 .577 .707 r
F P
0 g
s
.80659 .7029 m .80813 .68571 L .82915 .69787 L p .707 .577 .707 r
F P
0 g
s
.3189 .62111 m .31092 .56707 L .29846 .55916 L p .707 .577 .707 r
F P
0 g
s
.46452 .62956 m .46937 .66571 L .48566 .65496 L p .707 .577 .707 r
F P
0 g
s
.48566 .65496 m .4808 .61881 L .46452 .62956 L p .707 .577 .707 r
F P
0 g
s
.82196 .63829 m .82405 .67629 L .80301 .67395 L p .707 .577 .707 r
F P
0 g
s
.80301 .67395 m .80092 .63595 L .82196 .63829 L p .707 .577 .707 r
F P
0 g
s
.68872 .62355 m .68528 .56646 L .71458 .56304 L p .707 .577 .707 r
F P
0 g
s
.66317 .69841 m .66471 .68122 L .68866 .67362 L p .707 .577 .707 r
F P
0 g
s
.3009 .64569 m .30576 .68184 L .3266 .68704 L p .707 .577 .707 r
F P
0 g
s
.457 .70276 m .45343 .72131 L .47716 .72172 L p .707 .577 .707 r
F P
0 g
s
.47716 .72172 m .48073 .70317 L .457 .70276 L p .707 .577 .707 r
F P
0 g
s
.49051 .53803 m .49849 .59207 L .50551 .581 L p .707 .577 .707 r
F P
0 g
s
.50551 .581 m .49754 .52696 L .49051 .53803 L p .707 .577 .707 r
F P
0 g
s
.71458 .56304 m .71802 .62013 L .68872 .62355 L p .707 .577 .707 r
F P
0 g
s
.77749 .55985 m .78092 .61694 L .74979 .61785 L p .707 .577 .707 r
F P
0 g
s
.74979 .61785 m .74635 .56077 L .77749 .55985 L p .707 .577 .707 r
F P
0 g
s
.3357 .69785 m .33928 .6793 L .3187 .67087 L p .707 .577 .707 r
F P
0 g
s
.68866 .67362 m .68712 .69081 L .66317 .69841 L p .707 .577 .707 r
F P
0 g
s
.65933 .6836 m .65724 .6456 L .68124 .64126 L p .707 .577 .707 r
F P
0 g
s
.3187 .67087 m .31512 .68942 L .3357 .69785 L p .707 .577 .707 r
F P
0 g
s
.71802 .62013 m .71458 .56304 L .74635 .56077 L p .707 .577 .707 r
F P
0 g
s
.74635 .56077 m .74979 .61785 L .71802 .62013 L p .707 .577 .707 r
F P
0 g
s
.30576 .68184 m .3009 .64569 L .28846 .63778 L p .707 .577 .707 r
F P
0 g
s
.68124 .64126 m .68333 .67927 L .65933 .6836 L p .707 .577 .707 r
F P
0 g
s
.29846 .55916 m .30644 .6132 L .3189 .62111 L p .707 .577 .707 r
F P
0 g
s
.80813 .68571 m .80659 .7029 L .7792 .69369 L p .707 .577 .707 r
F P
0 g
s
.7792 .69369 m .78074 .6765 L .80813 .68571 L p .707 .577 .707 r
F P
0 g
s
.68712 .69081 m .68866 .67362 L .71794 .67014 L p .707 .577 .707 r
F P
0 g
s
.80092 .63595 m .80301 .67395 L .77558 .67307 L p .707 .577 .707 r
F P
0 g
s
.77558 .67307 m .77349 .63506 L .80092 .63595 L p .707 .577 .707 r
F P
0 g
s
.4808 .61881 m .48566 .65496 L .49274 .64413 L p .707 .577 .707 r
F P
0 g
s
.49274 .64413 m .48788 .60798 L .4808 .61881 L p .707 .577 .707 r
F P
0 g
s
.48073 .70317 m .47716 .72172 L .49337 .7195 L p .707 .577 .707 r
F P
0 g
s
.49337 .7195 m .49694 .70095 L .48073 .70317 L p .707 .577 .707 r
F P
0 g
s
.30644 .6132 m .29846 .55916 L .2956 .54919 L p .707 .577 .707 r
F P
0 g
s
.28846 .63778 m .29332 .67393 L .30576 .68184 L p .707 .577 .707 r
F P
0 g
s
.71794 .67014 m .71639 .68733 L .68712 .69081 L p .707 .577 .707 r
F P
0 g
s
.31512 .68942 m .3187 .67087 L .30646 .66299 L p .707 .577 .707 r
F P
0 g
s
.68333 .67927 m .68124 .64126 L .71057 .63786 L p .707 .577 .707 r
F P
0 g
s
.78074 .6765 m .7792 .69369 L .74812 .68833 L p .707 .577 .707 r
F P
0 g
s
.74812 .68833 m .74966 .67114 L .78074 .6765 L p .707 .577 .707 r
F P
0 g
s
.71639 .68733 m .71794 .67014 L .74966 .67114 L p .707 .577 .707 r
F P
0 g
s
.49754 .52696 m .50551 .581 L .50266 .57103 L p .707 .577 .707 r
F P
0 g
s
.50266 .57103 m .49468 .51699 L .49754 .52696 L p .707 .577 .707 r
F P
0 g
s
.30646 .66299 m .30288 .68154 L .31512 .68942 L p .707 .577 .707 r
F P
0 g
s
.71057 .63786 m .71266 .67586 L .68333 .67927 L p .707 .577 .707 r
F P
0 g
s
.74966 .67114 m .74812 .68833 L .71639 .68733 L p .707 .577 .707 r
F P
0 g
s
.77349 .63506 m .77558 .67307 L .74444 .67373 L p .707 .577 .707 r
F P
0 g
s
.74444 .67373 m .74235 .63572 L .77349 .63506 L p .707 .577 .707 r
F P
0 g
s
.71266 .67586 m .71057 .63786 L .74235 .63572 L p .707 .577 .707 r
F P
0 g
s
.29332 .67393 m .28846 .63778 L .28564 .62793 L p .707 .577 .707 r
F P
0 g
s
.2956 .54919 m .30358 .60323 L .30644 .6132 L p .707 .577 .707 r
F P
0 g
s
.74235 .63572 m .74444 .67373 L .71266 .67586 L p .707 .577 .707 r
F P
0 g
s
.48788 .60798 m .49274 .64413 L .48993 .63428 L p .707 .577 .707 r
F P
0 g
s
.48993 .63428 m .48507 .59813 L .48788 .60798 L p .707 .577 .707 r
F P
0 g
s
.49694 .70095 m .49337 .7195 L .50047 .71488 L p .707 .577 .707 r
F P
0 g
s
.50047 .71488 m .50404 .69633 L .49694 .70095 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28564 .62793 m .2905 .66408 L .29332 .67393 L p .707 .577 .707 r
F P
0 g
s
.30358 .60323 m .2956 .54919 L .30263 .53813 L p .707 .577 .707 r
F P
0 g
s
.30288 .68154 m .30646 .66299 L .30375 .65641 L p .707 .577 .707 r
F P
0 g
s
.30375 .65641 m .30018 .67496 L .30288 .68154 L p .707 .577 .707 r
F P
0 g
s
.49468 .51699 m .50266 .57103 L .4902 .56312 L p .707 .577 .707 r
F P
0 g
s
.4902 .56312 m .48222 .50908 L .49468 .51699 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2905 .66408 m .28564 .62793 L .29273 .6171 L p .707 .577 .707 r
F P
0 g
s
.30263 .53813 m .3106 .59217 L .30358 .60323 L p .707 .577 .707 r
F P
0 g
s
.48507 .59813 m .48993 .63428 L .47749 .62637 L p .707 .577 .707 r
F P
0 g
s
.47749 .62637 m .47263 .59022 L .48507 .59813 L p .707 .577 .707 r
F P
0 g
s
.50404 .69633 m .50047 .71488 L .49777 .7083 L p .707 .577 .707 r
F P
0 g
s
.49777 .7083 m .50134 .68975 L .50404 .69633 L p .707 .577 .707 r
F P
0 g
s
.3106 .59217 m .30263 .53813 L .31885 .52706 L p .707 .577 .707 r
F P
0 g
s
.29273 .6171 m .29758 .65325 L .2905 .66408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30018 .67496 m .30375 .65641 L .31085 .65179 L p .707 .577 .707 r
F P
0 g
s
.48222 .50908 m .4902 .56312 L .46935 .55805 L p .707 .577 .707 r
F P
0 g
s
.46935 .55805 m .46137 .50401 L .48222 .50908 L p .707 .577 .707 r
F P
0 g
s
.31085 .65179 m .30728 .67034 L .30018 .67496 L p .707 .577 .707 r
F P
0 g
s
.29758 .65325 m .29273 .6171 L .30901 .60635 L p .707 .577 .707 r
F P
0 g
s
.31885 .52706 m .32683 .5811 L .3106 .59217 L p .707 .577 .707 r
F P
0 g
s
.32683 .5811 m .31885 .52706 L .34268 .51707 L p .707 .577 .707 r
F P
0 g
s
.47263 .59022 m .47749 .62637 L .45664 .62117 L p .707 .577 .707 r
F P
0 g
s
.45664 .62117 m .45178 .58502 L .47263 .59022 L p .707 .577 .707 r
F P
0 g
s
.50134 .68975 m .49777 .7083 L .48553 .70041 L p .707 .577 .707 r
F P
0 g
s
.48553 .70041 m .4891 .68186 L .50134 .68975 L p .707 .577 .707 r
F P
0 g
s
.30901 .60635 m .31387 .6425 L .29758 .65325 L p .707 .577 .707 r
F P
0 g
s
.46137 .50401 m .46935 .55805 L .44216 .55631 L p .707 .577 .707 r
F P
0 g
s
.44216 .55631 m .43419 .50227 L .46137 .50401 L p .707 .577 .707 r
F P
0 g
s
.30728 .67034 m .31085 .65179 L .32706 .64957 L p .707 .577 .707 r
F P
0 g
s
.32706 .64957 m .32349 .66812 L .30728 .67034 L p .707 .577 .707 r
F P
0 g
s
.31387 .6425 m .30901 .60635 L .33291 .59674 L p .707 .577 .707 r
F P
0 g
s
.34268 .51707 m .35065 .57111 L .32683 .5811 L p .707 .577 .707 r
F P
0 g
s
.35065 .57111 m .34268 .51707 L .37178 .50914 L p .707 .577 .707 r
F P
0 g
s
.43419 .50227 m .44216 .55631 L .41129 .55808 L p .707 .577 .707 r
F P
0 g
s
.41129 .55808 m .40332 .50404 L .43419 .50227 L p .707 .577 .707 r
F P
0 g
s
.45178 .58502 m .45664 .62117 L .42943 .6192 L p .707 .577 .707 r
F P
0 g
s
.42943 .6192 m .42458 .58305 L .45178 .58502 L p .707 .577 .707 r
F P
0 g
s
.37976 .56318 m .37178 .50914 L .40332 .50404 L p .707 .577 .707 r
F P
0 g
s
.37178 .50914 m .37976 .56318 L .35065 .57111 L p .707 .577 .707 r
F P
0 g
s
.33291 .59674 m .33777 .63289 L .31387 .6425 L p .707 .577 .707 r
F P
0 g
s
.40332 .50404 m .41129 .55808 L .37976 .56318 L p .707 .577 .707 r
F P
0 g
s
.4891 .68186 m .48553 .70041 L .46495 .69199 L p .707 .577 .707 r
F P
0 g
s
.46495 .69199 m .46852 .67344 L .4891 .68186 L p .707 .577 .707 r
F P
0 g
s
.33777 .63289 m .33291 .59674 L .36208 .58921 L p .707 .577 .707 r
F P
0 g
s
.32349 .66812 m .32706 .64957 L .35079 .64998 L p .707 .577 .707 r
F P
0 g
s
.42458 .58305 m .42943 .6192 L .39852 .62064 L p .707 .577 .707 r
F P
0 g
s
.39852 .62064 m .39367 .58449 L .42458 .58305 L p .707 .577 .707 r
F P
0 g
s
.35079 .64998 m .34722 .66853 L .32349 .66812 L p .707 .577 .707 r
F P
0 g
s
.36694 .62536 m .36208 .58921 L .39367 .58449 L p .707 .577 .707 r
F P
0 g
s
.36208 .58921 m .36694 .62536 L .33777 .63289 L p .707 .577 .707 r
F P
0 g
s
.39367 .58449 m .39852 .62064 L .36694 .62536 L p .707 .577 .707 r
F P
0 g
s
.46852 .67344 m .46495 .69199 L .43804 .68385 L p .707 .577 .707 r
F P
0 g
s
.43804 .68385 m .44161 .6653 L .46852 .67344 L p .707 .577 .707 r
F P
0 g
s
.34722 .66853 m .35079 .64998 L .37972 .65297 L p .707 .577 .707 r
F P
0 g
s
.37972 .65297 m .37615 .67152 L .34722 .66853 L p .707 .577 .707 r
F P
0 g
s
.44161 .6653 m .43804 .68385 L .40744 .6768 L p .707 .577 .707 r
F P
0 g
s
.40744 .6768 m .41102 .65825 L .44161 .6653 L p .707 .577 .707 r
F P
0 g
s
.37615 .67152 m .37972 .65297 L .41102 .65825 L p .707 .577 .707 r
F P
0 g
s
.41102 .65825 m .40744 .6768 L .37615 .67152 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000H000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001SOol30003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`<000IJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005ao
o`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00F7oo00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo00@005YFFUH000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Ioo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00@000EJEP03001JEUYF00AJEP@000EJEP<00007FUH005YFFUH005YF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000067oo7000<Goo001DOol200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
0`00FUIJEP020002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000?Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH00002000^Ool005Aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000AJEP`0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000Moo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP03
001JEUYF00=JEP@00003FUH005YF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP00008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00009oo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP04001JEUYFFUH;
0003FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00002000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001EOol00`00FUH00004FUH01000FUH000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005Eoo`04001JEUYF0003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo
00@005YFFUH0009JEP04001JEUYF0007FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF1`001EYF
00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo3`001goo00<005YF
FUH00`0015YF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
100000=JEP00FUH00eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<0
05YFFUH01UYF00<005YFFUH0100017oo0UYF0P001EYF00<005YF00000`0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00@005YFFUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUH000=JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP000002FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<goo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUH005YF001JEP0200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF0004FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00@000]J
EP<00004FUH005YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH01000FUIJEUYF2@0025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH04@000eYF00<005YFFUH02EYF00<005YF00000P000eYF00<005YFFUH00UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF10000UYF00<005YF00001UYF
1@0015YF00<005YFFUH02EYF0P000eYF0P0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00
;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00001EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP001UYF1@0015YF00<005YF
FUH01EYF100000=JEP00FUH00eYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF5`00
0UYF1000<Goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP0015YF00@005YF000000EJEP06001JEUYF001JEP001UYF1@0015YF00@0
05YFFUIJEP@000EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000bOol002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF009JEPl000AJEP04001JEUYF0004FUH30005FUH01`00FUIJEUYF001JEP0000IJ
EP@000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPP000=J
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080
02moo`00;Goo0P000eYF00<005YFFUH00eYF1P003goo1@000UYF00<005YFFUH00P000UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00006FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP00Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUH00003000IOol200000eYF0000000400000eYF0000000;0006FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0003FUH2000DOol30007Ool01000FUH000000UYF0`0000=JEP00FUH01EYF00@005YFFUIJEPL000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002aoo`03001JEP00009JEP03001JEUYF0080015oo`D000Ioo`800003FUH00000008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<0
05YF00000`0015YF0`003Woo1@001Woo0P0000EJEP00001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000/Ool00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5
0006Ool2000015YF000000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010000eYF00<005YFFUH015YF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000Aoo`<000Moo`800004FUH005YF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH2000:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH00UYF400000=JEP00FUH05P001UYF00<005YFFUH01eYF00<005YF0000100035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEQ<00003
FUH005YF008000=JEP<000MJEP03001JEUYF00EJEPD0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP@000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YFFUH00P00;Woo
000/Ool01@00FUIJEUYF00001UYF00<005YFFUH01P0015YF00<005YFFUH01UYF00@005YFFUIJEPH0
00=JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00IJ
EP03001JEP00008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF20001UYF00<005YFFUH00eYF100000=J
EP00FUH01EYF1@0000=JEP000000;Woo000/Ool01@00FUIJEUYF00001EYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF
00<005YF00000P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF2000
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00UYF0`00;Woo
000/Ool01@00FUIJEUYF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YF001JEP0000IJEP03001JEP0000<000MJEP`00003FUH00000008000IJEP03001JEUYF
00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH00eYF00<005YF0000;Woo000/Ool01P00FUIJEUYF001JEP<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000IJEP03001JEUYF00=JEPd000AJ
EP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF1@0000=JEP00FUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH01EYF0`000eYF0`00;goo000]Ool00`00FUIJEP020002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH025YF0`001EYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00D005YFFUIJEP0000EJEPH000MJ
EP03001JEUYF00EJEP@0009JEP03001JEUYF00EJEP03001JEUYF00<0039oo`00;Woo0`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00@005YF000000=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000
00=JEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP04
001JEUYFFUH2000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEPP000IJ
EP04001JEUYFFUH200000eYF001JEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP03FUH00`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3P000UYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000Ioo`<000EJEP80031oo`00;Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00`0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0000=JEP0000005`004Woo0P000eYF00<005YF0000;goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH005YF001JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP03001JEUYF009JEP03001oogoo01moo`04001JEUYF0002FUH00`00Oomoo`0/Ool002ioo`8000AJ
EP03001JEUYF00=JEPH000MJEP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEP00FUH0
0005FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0POol30003FUH00`00Oomoo`0[Ool002ioo`8000AJEP03001JEP0000D0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05
001JEP00FUH00006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH00000008000AJEP04001JEUYFFUH2000:Ool3000GOol01@00FUIJEUYF0000;Goo000^Ool2
0003FUH30006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000017oo000000001EYF00D0
05YF001JEP0000IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00AJEP03001JEUYF00@0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003
FUH300000eYF001JEP02FUH20009Ool5000GOol01000FUIJEP00;Goo000]Ool01000FUH005YF0P00
47oo4P002Goo0P000eYF00D005YF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080
00IJEP8000=JEP8000Uoo`D001Moo`05001JEP00FUH0000/Ool002eoo`03001JEP00008001Eoo`D0
01Aoo`800006FUH005YF001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P00
1UYF00D005YF000005YF008000Uoo`D001Qoo`800003FUH007oo02]oo`00;Goo0`000UYF00<007oo
Ool04Woo1@005Woo0P0000AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80
00EJEP04001JEUYFFUH2000;Ool3000JOol00`00FUH0000/Ool002eoo`8000=JEP<0019oo`D001Qo
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPH000AJEP8002Qoo`03
001JEP0002aoo`00;Goo0P000eYF00<005YFFUH00P004Goo0`005goo100000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF0`0000AJEP00FUH002Qoo`8002eoo`00;Goo
0P000eYF00<005YFFUH00UYF0`009Woo0P000eYF00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEP00008002Uoo`8002eoo`00;Goo0P00
0eYF00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00FUH00UYF00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0003FUH30004FUH2000UOol4000]Ool002ioo`05001J
EUYFFUH00005FUH00`00FUIJEP03FUH7000BOol50005FUH01`00FUIJEUYF001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000EJEP8000AJEP<0025oo`80009JEP03001oogoo02aoo`00;Woo00D005YF
FUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP07001JEUYF
FUH005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUH00004
0002FUH2000MOol20003FUH2000^Ool002moo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0002FUH00`00FUH00006FUH00`00FUIJEP04000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH60006FUH00`00FUIJEP02FUH01000
FUH000000UYF0P000eYF00<005YFFUH00eYF1@006Goo100000=JEP00FUH00UYF00<007ooOol0;Goo
000`Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0003FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP04FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUH00005FUH2
00000eYF001JEP06FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000;goo000aOol20005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000MJEP<000IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00AJEP04001JEUYF000`Ool0039oo`04001JEUYFFUH80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH02000FUIJEUYF001JEP00FUH30008
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000UYF00@005YF000000IJEP03001JEUYF008000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0035oo`00<Goo1@000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUIJ
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000040002FUH00`00FUIJ
EP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000c
Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF001JEP02FUH00`00FUH000030004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000eOol002aoo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEQL000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003
FUH005YF009JEP03001JEUYF00=JEP<00003FUH005YF009JEPD0009JEP03001JEUYF00IJEP03001J
EUYF009JEPH003Uoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4P001eYF
00<005YFFUH015YF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEUYF009JEP03001JEP00008000=JEP8000=ooa0003moo`00;7oo00<005YF0000
15YF00@005YFFUIJEPP000QJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00D0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJ
EP02000015YF001JEP00DWoo000/Ool00`00FUH00002FUH60007FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH01000FUIJEUYF1P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH020000eYF00D005YFFUH005YF00800003FUH007oo055oo`00;7oo00<005YF00000`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Woo00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH010000UYF00<0
05YFFUH00P00Dgoo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH9000AOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH0
0`00FUIJEP04FUH00`00FUIJEP04001COol002eoo`L0009JEP03001JEUYF009JEQ4001]oo`80009J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00AJEPD00003FUH007oo059oo`00
=7oo1`00;Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP<000QJEP03001JEUYF00AJEPH005Aoo`00Jgoo0P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF001FOol006eoo`<000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EQT0009JEP03001oogoo05Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01P004goo0P0000EJEP00FUIJEP0005Ioo`00Lgoo1`001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@000Woo1@004Goo00<005YFFUH00UYF
0P00Egoo001jOol;0006FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001goo1@003goo0`0015YF0P00
Egoo0025OolG000=Ool5000=Ool20002FUH00`00FUIJEP02FUH00`00Oomoo`1FOol008aoo`04001J
EUYFFUH2000HOol3000<Ool20004FUH01@00FUIJEUYF0000FGoo002<Ool01@00FUIJEUYF00009Woo
0P001eYF00<005YF0000FWoo002=Ool00`00FUH0000SOol400000eYF001JEP06FUH2001KOol008eo
o`<001ioo`D000EJEP03001JEUYF00AJEP8005aoo`00SGoo00<005YFFUH00`005goo10000UYF00<0
05YFFUH01UYF00@005YFFUIJEP8005ioo`00SGoo0P000UYF00<005YF00000P003Goo1`001UYF00<0
05YFFUH01UYF00@005YF0000061oo`00SWoo00@005YFFUH000AJEPd000AJEP03001JEUYF00MJEP03
001JEUYF00AJEP<0069oo`00SWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00@006Eoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEPD006Uoo`00T7oo0`001EYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01000KWoo002BOol30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH7001bOol009Eo
o`l007Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60336 .75501 m .59539 .70097 L .56453 .70271 L p .707 .577 .707 r
F P
0 g
s
.59539 .70097 m .60336 .75501 L .63489 .74994 L p .707 .577 .707 r
F P
0 g
s
.63489 .74994 m .62693 .69589 L .59539 .70097 L p .707 .577 .707 r
F P
0 g
s
.62693 .69589 m .63489 .74994 L .66403 .74203 L p .707 .577 .707 r
F P
0 g
s
.66403 .74203 m .65606 .68799 L .62693 .69589 L p .707 .577 .707 r
F P
0 g
s
.5725 .75675 m .56453 .70271 L .53738 .70094 L p .707 .577 .707 r
F P
0 g
s
.56453 .70271 m .5725 .75675 L .60336 .75501 L p .707 .577 .707 r
F P
0 g
s
.65606 .68799 m .66403 .74203 L .68791 .73206 L p .707 .577 .707 r
F P
0 g
s
.68791 .73206 m .67994 .67802 L .65606 .68799 L p .707 .577 .707 r
F P
0 g
s
.59063 .81642 m .58576 .78027 L .55485 .78173 L p .707 .577 .707 r
F P
0 g
s
.58576 .78027 m .59063 .81642 L .62221 .81169 L p .707 .577 .707 r
F P
0 g
s
.62221 .81169 m .61735 .77554 L .58576 .78027 L p .707 .577 .707 r
F P
0 g
s
.61735 .77554 m .62221 .81169 L .65136 .80415 L p .707 .577 .707 r
F P
0 g
s
.65136 .80415 m .6465 .768 L .61735 .77554 L p .707 .577 .707 r
F P
0 g
s
.54535 .75499 m .53738 .70094 L .5166 .69585 L p .707 .577 .707 r
F P
0 g
s
.53738 .70094 m .54535 .75499 L .5725 .75675 L p .707 .577 .707 r
F P
0 g
s
.55971 .81788 m .55485 .78173 L .52762 .77976 L p .707 .577 .707 r
F P
0 g
s
.55485 .78173 m .55971 .81788 L .59063 .81642 L p .707 .577 .707 r
F P
0 g
s
.6465 .768 m .65136 .80415 L .67524 .79453 L p .707 .577 .707 r
F P
0 g
s
.67524 .79453 m .67038 .75838 L .6465 .768 L p .707 .577 .707 r
F P
0 g
s
.67994 .67802 m .68791 .73206 L .7042 .72101 L p .707 .577 .707 r
F P
0 g
s
.7042 .72101 m .69623 .66696 L .67994 .67802 L p .707 .577 .707 r
F P
0 g
s
.59936 .84191 m .60293 .82336 L .57231 .81632 L p .707 .577 .707 r
F P
0 g
s
.60293 .82336 m .59936 .84191 L .63064 .84718 L p .707 .577 .707 r
F P
0 g
s
.63064 .84718 m .63422 .82863 L .60293 .82336 L p .707 .577 .707 r
F P
0 g
s
.52762 .77976 m .53248 .81591 L .55971 .81788 L p .707 .577 .707 r
F P
0 g
s
.57231 .81632 m .56874 .83487 L .59936 .84191 L p .707 .577 .707 r
F P
0 g
s
.63422 .82863 m .63064 .84718 L .65953 .85015 L p .707 .577 .707 r
F P
0 g
s
.65953 .85015 m .6631 .8316 L .63422 .82863 L p .707 .577 .707 r
F P
0 g
s
.53248 .81591 m .52762 .77976 L .50676 .77458 L p .707 .577 .707 r
F P
0 g
s
.56874 .83487 m .57231 .81632 L .54535 .80819 L p .707 .577 .707 r
F P
0 g
s
.5166 .69585 m .52457 .7499 L .54535 .75499 L p .707 .577 .707 r
F P
0 g
s
.54535 .80819 m .54178 .82675 L .56874 .83487 L p .707 .577 .707 r
F P
0 g
s
.52457 .7499 m .5166 .69585 L .50421 .68793 L p .707 .577 .707 r
F P
0 g
s
.67038 .75838 m .67524 .79453 L .6915 .78378 L p .707 .577 .707 r
F P
0 g
s
.6915 .78378 m .68664 .74763 L .67038 .75838 L p .707 .577 .707 r
F P
0 g
s
.50676 .77458 m .51162 .81072 L .53248 .81591 L p .707 .577 .707 r
F P
0 g
s
.6631 .8316 m .65953 .85015 L .68319 .85055 L p .707 .577 .707 r
F P
0 g
s
.68319 .85055 m .68676 .83199 L .6631 .8316 L p .707 .577 .707 r
F P
0 g
s
.69623 .66696 m .7042 .72101 L .7113 .70995 L p .707 .577 .707 r
F P
0 g
s
.7113 .70995 m .70333 .65591 L .69623 .66696 L p .707 .577 .707 r
F P
0 g
s
.54178 .82675 m .54535 .80819 L .52469 .79977 L p .707 .577 .707 r
F P
0 g
s
.52469 .79977 m .52112 .81833 L .54178 .82675 L p .707 .577 .707 r
F P
0 g
s
.51162 .81072 m .50676 .77458 L .49429 .76667 L p .707 .577 .707 r
F P
0 g
s
.50421 .68793 m .51218 .74197 L .52457 .7499 L p .707 .577 .707 r
F P
0 g
s
.68664 .74763 m .6915 .78378 L .69856 .77295 L p .707 .577 .707 r
F P
0 g
s
.69856 .77295 m .6937 .7368 L .68664 .74763 L p .707 .577 .707 r
F P
0 g
s
.68676 .83199 m .68319 .85055 L .6993 .84832 L p .707 .577 .707 r
F P
0 g
s
.6993 .84832 m .70288 .82976 L .68676 .83199 L p .707 .577 .707 r
F P
0 g
s
.51218 .74197 m .50421 .68793 L .50143 .67795 L p .707 .577 .707 r
F P
0 g
s
.49429 .76667 m .49915 .80282 L .51162 .81072 L p .707 .577 .707 r
F P
0 g
s
.52112 .81833 m .52469 .79977 L .51235 .79189 L p .707 .577 .707 r
F P
0 g
s
.70333 .65591 m .7113 .70995 L .70852 .69997 L p .707 .577 .707 r
F P
0 g
s
.70852 .69997 m .70055 .64593 L .70333 .65591 L p .707 .577 .707 r
F P
0 g
s
.51235 .79189 m .50878 .81044 L .52112 .81833 L p .707 .577 .707 r
F P
0 g
s
.49915 .80282 m .49429 .76667 L .49144 .75682 L p .707 .577 .707 r
F P
0 g
s
.50143 .67795 m .5094 .732 L .51218 .74197 L p .707 .577 .707 r
F P
0 g
s
.48863 .8218 m .48863 .31991 L .44475 .31708 L p .707 .577 .707 r
F P
0 g
s
.49144 .75682 m .4963 .79296 L .49915 .80282 L p .707 .577 .707 r
F P
0 g
s
.5094 .732 m .50143 .67795 L .50853 .66689 L p .707 .577 .707 r
F P
0 g
s
.50878 .81044 m .51235 .79189 L .50954 .78531 L p .707 .577 .707 r
F P
0 g
s
.50954 .78531 m .50597 .80386 L .50878 .81044 L p .707 .577 .707 r
F P
0 g
s
.4963 .79296 m .49144 .75682 L .4985 .74599 L p .707 .577 .707 r
F P
0 g
s
.50853 .66689 m .5165 .72094 L .5094 .732 L p .707 .577 .707 r
F P
0 g
s
.5165 .72094 m .50853 .66689 L .52482 .65584 L p .707 .577 .707 r
F P
0 g
s
.4985 .74599 m .50336 .78213 L .4963 .79296 L p .707 .577 .707 r
F P
0 g
s
.50597 .80386 m .50954 .78531 L .51654 .78068 L p .707 .577 .707 r
F P
0 g
s
.51654 .78068 m .51296 .79923 L .50597 .80386 L p .707 .577 .707 r
F P
0 g
s
.50336 .78213 m .4985 .74599 L .51476 .73524 L p .707 .577 .707 r
F P
0 g
s
.52482 .65584 m .53279 .70988 L .5165 .72094 L p .707 .577 .707 r
F P
0 g
s
.51476 .73524 m .51962 .77138 L .50336 .78213 L p .707 .577 .707 r
F P
0 g
s
.51296 .79923 m .51654 .78068 L .53265 .77845 L p .707 .577 .707 r
F P
0 g
s
.53265 .77845 m .52908 .797 L .51296 .79923 L p .707 .577 .707 r
F P
0 g
s
.51962 .77138 m .51476 .73524 L .53863 .72562 L p .707 .577 .707 r
F P
0 g
s
.53863 .72562 m .54349 .76177 L .51962 .77138 L p .707 .577 .707 r
F P
0 g
s
.52908 .797 m .53265 .77845 L .55631 .77884 L p .707 .577 .707 r
F P
0 g
s
.55631 .77884 m .55273 .79739 L .52908 .797 L p .707 .577 .707 r
F P
0 g
s
.48863 .31991 m .48863 .8218 L .53362 .82086 L p .707 .577 .707 r
F P
0 g
s
.53279 .70988 m .52482 .65584 L .5487 .64587 L p .707 .577 .707 r
F P
0 g
s
.5487 .64587 m .55667 .69991 L .53279 .70988 L p .707 .577 .707 r
F P
0 g
s
.53362 .82086 m .53362 .31897 L .48863 .31991 L p .707 .577 .707 r
F P
0 g
s
.55667 .69991 m .5487 .64587 L .57783 .63796 L p .707 .577 .707 r
F P
0 g
s
.57783 .63796 m .5858 .69201 L .55667 .69991 L p .707 .577 .707 r
F P
0 g
s
.54349 .76177 m .53863 .72562 L .56779 .71808 L p .707 .577 .707 r
F P
0 g
s
.56779 .71808 m .57265 .75422 L .54349 .76177 L p .707 .577 .707 r
F P
0 g
s
.55273 .79739 m .55631 .77884 L .58519 .78181 L p .707 .577 .707 r
F P
0 g
s
.58519 .78181 m .58162 .80037 L .55273 .79739 L p .707 .577 .707 r
F P
0 g
s
.53362 .31897 m .53362 .82086 L .57532 .81623 L p .707 .577 .707 r
F P
0 g
s
.57265 .75422 m .56779 .71808 L .59937 .71335 L p .707 .577 .707 r
F P
0 g
s
.59937 .71335 m .60423 .74949 L .57265 .75422 L p .707 .577 .707 r
F P
0 g
s
.57532 .81623 m .57532 .31434 L .53362 .31897 L p .707 .577 .707 r
F P
0 g
s
.6937 .7368 m .69856 .77295 L .69571 .7631 L p .707 .577 .707 r
F P
0 g
s
.69571 .7631 m .69085 .72695 L .6937 .7368 L p .707 .577 .707 r
F P
0 g
s
.70288 .82976 m .6993 .84832 L .7063 .84369 L p .707 .577 .707 r
F P
0 g
s
.7063 .84369 m .70987 .82513 L .70288 .82976 L p .707 .577 .707 r
F P
0 g
s
.44475 .81897 m .44475 .31708 L .40628 .31075 L p .707 .577 .707 r
F P
0 g
s
.44475 .31708 m .44475 .81897 L .48863 .8218 L p .707 .577 .707 r
F P
0 g
s
.70055 .64593 m .70852 .69997 L .69613 .69205 L p .707 .577 .707 r
F P
0 g
s
.69613 .69205 m .68816 .638 L .70055 .64593 L p .707 .577 .707 r
F P
0 g
s
.5858 .69201 m .57783 .63796 L .60937 .63289 L p .707 .577 .707 r
F P
0 g
s
.60937 .63289 m .61734 .68694 L .5858 .69201 L p .707 .577 .707 r
F P
0 g
s
.63029 .71189 m .63515 .74804 L .60423 .74949 L p .707 .577 .707 r
F P
0 g
s
.60423 .74949 m .59937 .71335 L .63029 .71189 L p .707 .577 .707 r
F P
0 g
s
.58162 .80037 m .58519 .78181 L .61648 .78708 L p .707 .577 .707 r
F P
0 g
s
.61648 .78708 m .6129 .80563 L .58162 .80037 L p .707 .577 .707 r
F P
0 g
s
.57532 .31434 m .57532 .81623 L .60965 .80837 L p .707 .577 .707 r
F P
0 g
s
.61734 .68694 m .60937 .63289 L .64023 .63115 L p .707 .577 .707 r
F P
0 g
s
.60965 .80837 m .60965 .30648 L .57532 .31434 L p .707 .577 .707 r
F P
0 g
s
.25637 .70092 m .25293 .64384 L .22181 .64474 L p .707 .577 .707 r
F P
0 g
s
.25293 .64384 m .25637 .70092 L .28814 .69866 L p .707 .577 .707 r
F P
0 g
s
.28814 .69866 m .28471 .64157 L .25293 .64384 L p .707 .577 .707 r
F P
0 g
s
.28471 .64157 m .28814 .69866 L .31747 .69526 L p .707 .577 .707 r
F P
0 g
s
.31747 .69526 m .31404 .63817 L .28471 .64157 L p .707 .577 .707 r
F P
0 g
s
.40628 .81264 m .40628 .31075 L .37698 .30154 L p .707 .577 .707 r
F P
0 g
s
.40628 .31075 m .40628 .81264 L .44475 .81897 L p .707 .577 .707 r
F P
0 g
s
.69085 .72695 m .69571 .7631 L .68324 .75519 L p .707 .577 .707 r
F P
0 g
s
.68324 .75519 m .67838 .71904 L .69085 .72695 L p .707 .577 .707 r
F P
0 g
s
.70987 .82513 m .7063 .84369 L .70349 .8371 L p .707 .577 .707 r
F P
0 g
s
.70349 .8371 m .70706 .81855 L .70987 .82513 L p .707 .577 .707 r
F P
0 g
s
.22525 .70182 m .22181 .64474 L .1944 .64419 L p .707 .577 .707 r
F P
0 g
s
.22181 .64474 m .22525 .70182 L .25637 .70092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31404 .63817 m .31747 .69526 L .34147 .69105 L p .707 .577 .707 r
F P
0 g
s
.34147 .69105 m .33804 .63396 L .31404 .63817 L p .707 .577 .707 r
F P
0 g
s
.1944 .64419 m .19783 .70127 L .22525 .70182 L p .707 .577 .707 r
F P
0 g
s
.68816 .638 m .69613 .69205 L .67534 .68696 L p .707 .577 .707 r
F P
0 g
s
.67534 .68696 m .66738 .63291 L .68816 .638 L p .707 .577 .707 r
F P
0 g
s
.64023 .63115 m .6482 .6852 L .61734 .68694 L p .707 .577 .707 r
F P
0 g
s
.6471 .79412 m .64352 .81267 L .6129 .80563 L p .707 .577 .707 r
F P
0 g
s
.6129 .80563 m .61648 .78708 L .6471 .79412 L p .707 .577 .707 r
F P
0 g
s
.60965 .30648 m .60965 .80837 L .63324 .79804 L p .707 .577 .707 r
F P
0 g
s
.63515 .74804 m .63029 .71189 L .65751 .71385 L p .707 .577 .707 r
F P
0 g
s
.63324 .79804 m .63324 .29615 L .60965 .30648 L p .707 .577 .707 r
F P
0 g
s
.19783 .70127 m .1944 .64419 L .17337 .64224 L p .707 .577 .707 r
F P
0 g
s
.17337 .64224 m .1768 .69933 L .19783 .70127 L p .707 .577 .707 r
F P
0 g
s
.25097 .75914 m .24888 .72113 L .21774 .7218 L p .707 .577 .707 r
F P
0 g
s
.24888 .72113 m .25097 .75914 L .28275 .757 L p .707 .577 .707 r
F P
0 g
s
.28275 .757 m .28066 .71899 L .24888 .72113 L p .707 .577 .707 r
F P
0 g
s
.67838 .71904 m .68324 .75519 L .66238 .75 L p .707 .577 .707 r
F P
0 g
s
.66238 .75 m .65751 .71385 L .67838 .71904 L p .707 .577 .707 r
F P
0 g
s
.28066 .71899 m .28275 .757 L .31207 .75359 L p .707 .577 .707 r
F P
0 g
s
.31207 .75359 m .30998 .71558 L .28066 .71899 L p .707 .577 .707 r
F P
0 g
s
.33804 .63396 m .34147 .69105 L .3578 .68644 L p .707 .577 .707 r
F P
0 g
s
.3578 .68644 m .35437 .62935 L .33804 .63396 L p .707 .577 .707 r
F P
0 g
s
.21774 .7218 m .21983 .7598 L .25097 .75914 L p .707 .577 .707 r
F P
0 g
s
.37698 .80343 m .37698 .30154 L .35973 .29035 L p .707 .577 .707 r
F P
0 g
s
.37698 .30154 m .37698 .80343 L .40628 .81264 L p .707 .577 .707 r
F P
0 g
s
.70706 .81855 m .70349 .8371 L .69115 .82922 L p .707 .577 .707 r
F P
0 g
s
.69115 .82922 m .69472 .81067 L .70706 .81855 L p .707 .577 .707 r
F P
0 g
s
.21983 .7598 m .21774 .7218 L .19029 .72092 L p .707 .577 .707 r
F P
0 g
s
.66738 .63291 m .67534 .68696 L .6482 .6852 L p .707 .577 .707 r
F P
0 g
s
.6482 .6852 m .64023 .63115 L .66738 .63291 L p .707 .577 .707 r
F P
0 g
s
.25498 .83284 m .25653 .81565 L .22542 .81033 L p .707 .577 .707 r
F P
0 g
s
.25653 .81565 m .25498 .83284 L .2867 .83379 L p .707 .577 .707 r
F P
0 g
s
.2867 .83379 m .28825 .8166 L .25653 .81565 L p .707 .577 .707 r
F P
0 g
s
.19029 .72092 m .19238 .75892 L .21983 .7598 L p .707 .577 .707 r
F P
0 g
s
.28825 .8166 m .2867 .83379 L .31593 .83028 L p .707 .577 .707 r
F P
0 g
s
.31593 .83028 m .31748 .81309 L .28825 .8166 L p .707 .577 .707 r
F P
0 g
s
.22388 .82752 m .22542 .81033 L .19798 .80115 L p .707 .577 .707 r
F P
0 g
s
.22542 .81033 m .22388 .82752 L .25498 .83284 L p .707 .577 .707 r
F P
0 g
s
.30998 .71558 m .31207 .75359 L .33605 .74925 L p .707 .577 .707 r
F P
0 g
s
.33605 .74925 m .33396 .71124 L .30998 .71558 L p .707 .577 .707 r
F P
0 g
s
.1768 .69933 m .17337 .64224 L .16079 .63909 L p .707 .577 .707 r
F P
0 g
s
.19798 .80115 m .19643 .81835 L .22388 .82752 L p .707 .577 .707 r
F P
0 g
s
.19238 .75892 m .19029 .72092 L .16922 .71858 L p .707 .577 .707 r
F P
0 g
s
.16079 .63909 m .16422 .69617 L .1768 .69933 L p .707 .577 .707 r
F P
0 g
s
.65751 .71385 m .66238 .75 L .63515 .74804 L p .707 .577 .707 r
F P
0 g
s
.63324 .29615 m .63324 .79804 L .6438 .78627 L p .707 .577 .707 r
F P
0 g
s
.6438 .78627 m .6438 .28438 L .63324 .29615 L p .707 .577 .707 r
F P
0 g
s
.31748 .81309 m .31593 .83028 L .33981 .82265 L p .707 .577 .707 r
F P
0 g
s
.33981 .82265 m .34135 .80546 L .31748 .81309 L p .707 .577 .707 r
F P
0 g
s
.19643 .81835 m .19798 .80115 L .17688 .78903 L p .707 .577 .707 r
F P
0 g
s
.16922 .71858 m .17132 .75659 L .19238 .75892 L p .707 .577 .707 r
F P
0 g
s
.35437 .62935 m .3578 .68644 L .36486 .68189 L p .707 .577 .707 r
F P
0 g
s
.36486 .68189 m .36143 .6248 L .35437 .62935 L p .707 .577 .707 r
F P
0 g
s
.69472 .81067 m .69115 .82922 L .67048 .8208 L p .707 .577 .707 r
F P
0 g
s
.67048 .8208 m .67406 .80225 L .69472 .81067 L p .707 .577 .707 r
F P
0 g
s
.33396 .71124 m .33605 .74925 L .35234 .74439 L p .707 .577 .707 r
F P
0 g
s
.35234 .74439 m .35025 .70639 L .33396 .71124 L p .707 .577 .707 r
F P
0 g
s
.17688 .78903 m .17534 .80623 L .19643 .81835 L p .707 .577 .707 r
F P
0 g
s
.16422 .69617 m .16079 .63909 L .15789 .63504 L p .707 .577 .707 r
F P
0 g
s
.34135 .80546 m .33981 .82265 L .356 .81165 L p .707 .577 .707 r
F P
0 g
s
.356 .81165 m .35755 .79446 L .34135 .80546 L p .707 .577 .707 r
F P
0 g
s
.36196 .67784 m .35853 .62075 L .36143 .6248 L p .707 .577 .707 r
F P
0 g
s
.36292 .79835 m .36446 .78116 L .35755 .79446 L p .707 .577 .707 r
F P
0 g
s
.35853 .62075 m .36196 .67784 L .34938 .67469 L p .707 .577 .707 r
F P
0 g
s
.36143 .76687 m .35988 .78406 L .3472 .77018 L p .707 .577 .707 r
F P
0 g
s
.3472 .77018 m .34875 .75298 L .36143 .76687 L p .707 .577 .707 r
F P
0 g
s
.35973 .79224 m .35973 .29035 L .3562 .27828 L p .707 .577 .707 r
F P
0 g
s
.36143 .6248 m .36486 .68189 L .36196 .67784 L p .707 .577 .707 r
F P
0 g
s
.36446 .78116 m .36292 .79835 L .35988 .78406 L p .707 .577 .707 r
F P
0 g
s
.35988 .78406 m .36143 .76687 L .36446 .78116 L p .707 .577 .707 r
F P
0 g
s
.35973 .29035 m .35973 .79224 L .37698 .80343 L p .707 .577 .707 r
F P
0 g
s
.17132 .75659 m .16922 .71858 L .1566 .71502 L p .707 .577 .707 r
F P
0 g
s
.17534 .80623 m .17688 .78903 L .1642 .77515 L p .707 .577 .707 r
F P
0 g
s
.15789 .63504 m .16132 .69212 L .16422 .69617 L p .707 .577 .707 r
F P
0 g
s
.1566 .71502 m .15869 .75302 L .17132 .75659 L p .707 .577 .707 r
F P
0 g
s
.1642 .77515 m .16265 .79234 L .17534 .80623 L p .707 .577 .707 r
F P
0 g
s
.67406 .80225 m .67048 .8208 L .64352 .81267 L p .707 .577 .707 r
F P
0 g
s
.64352 .81267 m .6471 .79412 L .67406 .80225 L p .707 .577 .707 r
F P
0 g
s
.35025 .70639 m .35234 .74439 L .35936 .73951 L p .707 .577 .707 r
F P
0 g
s
.35936 .73951 m .35727 .7015 L .35025 .70639 L p .707 .577 .707 r
F P
0 g
s
.6438 .28438 m .6438 .78627 L .64027 .7742 L p .707 .577 .707 r
F P
0 g
s
.64027 .7742 m .64027 .27231 L .6438 .28438 L p .707 .577 .707 r
F P
0 g
s
.35755 .79446 m .356 .81165 L .36292 .79835 L p .707 .577 .707 r
F P
0 g
s
.16265 .79234 m .1642 .77515 L .16117 .76085 L p .707 .577 .707 r
F P
0 g
s
.15869 .75302 m .1566 .71502 L .15365 .71057 L p .707 .577 .707 r
F P
0 g
s
.16132 .69212 m .15789 .63504 L .16495 .63049 L p .707 .577 .707 r
F P
0 g
s
.15365 .71057 m .15574 .74858 L .15869 .75302 L p .707 .577 .707 r
F P
0 g
s
.16117 .76085 m .15962 .77805 L .16265 .79234 L p .707 .577 .707 r
F P
0 g
s
.16495 .63049 m .16838 .68757 L .16132 .69212 L p .707 .577 .707 r
F P
0 g
s
.35727 .7015 m .35936 .73951 L .35641 .73506 L p .707 .577 .707 r
F P
0 g
s
.35641 .73506 m .35432 .69706 L .35727 .7015 L p .707 .577 .707 r
F P
0 g
s
.34938 .67469 m .34595 .6176 L .35853 .62075 L p .707 .577 .707 r
F P
0 g
s
.35432 .69706 m .35641 .73506 L .34379 .7315 L p .707 .577 .707 r
F P
0 g
s
.3562 .27828 m .3562 .78017 L .35973 .79224 L p .707 .577 .707 r
F P
0 g
s
.3562 .78017 m .3562 .27828 L .36675 .2665 L p .707 .577 .707 r
F P
0 g
s
.15962 .77805 m .16117 .76085 L .16809 .74756 L p .707 .577 .707 r
F P
0 g
s
.16838 .68757 m .16495 .63049 L .18128 .62588 L p .707 .577 .707 r
F P
0 g
s
.15574 .74858 m .15365 .71057 L .16067 .70569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64027 .27231 m .64027 .7742 L .62301 .76301 L p .707 .577 .707 r
F P
0 g
s
.62301 .76301 m .62301 .26112 L .64027 .27231 L p .707 .577 .707 r
F P
0 g
s
.16809 .74756 m .16654 .76475 L .15962 .77805 L p .707 .577 .707 r
F P
0 g
s
.16067 .70569 m .16276 .74369 L .15574 .74858 L p .707 .577 .707 r
F P
0 g
s
.18128 .62588 m .18471 .68297 L .16838 .68757 L p .707 .577 .707 r
F P
0 g
s
.34595 .6176 m .34938 .67469 L .32835 .67274 L p .707 .577 .707 r
F P
0 g
s
.32835 .67274 m .32492 .61565 L .34595 .6176 L p .707 .577 .707 r
F P
0 g
s
.34379 .7315 m .34169 .69349 L .35432 .69706 L p .707 .577 .707 r
F P
0 g
s
.16654 .76475 m .16809 .74756 L .18428 .73656 L p .707 .577 .707 r
F P
0 g
s
.36675 .76839 m .36675 .2665 L .39035 .25618 L p .707 .577 .707 r
F P
0 g
s
.36675 .2665 m .36675 .76839 L .3562 .78017 L p .707 .577 .707 r
F P
0 g
s
.18471 .68297 m .18128 .62588 L .20528 .62167 L p .707 .577 .707 r
F P
0 g
s
.16276 .74369 m .16067 .70569 L .17696 .70083 L p .707 .577 .707 r
F P
0 g
s
.18428 .73656 m .18273 .75375 L .16654 .76475 L p .707 .577 .707 r
F P
0 g
s
.20528 .62167 m .20872 .67876 L .18471 .68297 L p .707 .577 .707 r
F P
0 g
s
.17696 .70083 m .17906 .73884 L .16276 .74369 L p .707 .577 .707 r
F P
0 g
s
.32492 .61565 m .32835 .67274 L .30094 .67219 L p .707 .577 .707 r
F P
0 g
s
.30094 .67219 m .29751 .6151 L .32492 .61565 L p .707 .577 .707 r
F P
0 g
s
.62301 .26112 m .62301 .76301 L .59372 .7538 L p .707 .577 .707 r
F P
0 g
s
.59372 .7538 m .59372 .25191 L .62301 .26112 L p .707 .577 .707 r
F P
0 g
s
.34875 .75298 m .3472 .77018 L .3261 .75805 L p .707 .577 .707 r
F P
0 g
s
.3261 .75805 m .32765 .74086 L .34875 .75298 L p .707 .577 .707 r
F P
0 g
s
.34169 .69349 m .34379 .7315 L .32272 .72916 L p .707 .577 .707 r
F P
0 g
s
.32272 .72916 m .32063 .69116 L .34169 .69349 L p .707 .577 .707 r
F P
0 g
s
.20872 .67876 m .20528 .62167 L .23461 .61826 L p .707 .577 .707 r
F P
0 g
s
.18273 .75375 m .18428 .73656 L .20816 .72893 L p .707 .577 .707 r
F P
0 g
s
.29751 .6151 m .30094 .67219 L .26982 .67309 L p .707 .577 .707 r
F P
0 g
s
.26982 .67309 m .26639 .616 L .29751 .6151 L p .707 .577 .707 r
F P
0 g
s
.23461 .61826 m .23804 .67535 L .20872 .67876 L p .707 .577 .707 r
F P
0 g
s
.20816 .72893 m .20661 .74612 L .18273 .75375 L p .707 .577 .707 r
F P
0 g
s
.17906 .73884 m .17696 .70083 L .20094 .69649 L p .707 .577 .707 r
F P
0 g
s
.23804 .67535 m .23461 .61826 L .26639 .616 L p .707 .577 .707 r
F P
0 g
s
.39035 .25618 m .39035 .75807 L .36675 .76839 L p .707 .577 .707 r
F P
0 g
s
.39035 .75807 m .39035 .25618 L .42467 .24832 L p .707 .577 .707 r
F P
0 g
s
.26639 .616 m .26982 .67309 L .23804 .67535 L p .707 .577 .707 r
F P
0 g
s
.20094 .69649 m .20303 .7345 L .17906 .73884 L p .707 .577 .707 r
F P
0 g
s
.73018 .66809 m .73361 .61527 L .70249 .61075 L p .707 .577 .707 r
F P
0 g
s
.73361 .61527 m .73018 .66809 L .76196 .66867 L p .707 .577 .707 r
F P
0 g
s
.76196 .66867 m .76539 .61585 L .73361 .61527 L p .707 .577 .707 r
F P
0 g
s
.32765 .74086 m .3261 .75805 L .29866 .74888 L p .707 .577 .707 r
F P
0 g
s
.29866 .74888 m .30021 .73169 L .32765 .74086 L p .707 .577 .707 r
F P
0 g
s
.76539 .61585 m .76196 .66867 L .79128 .66524 L p .707 .577 .707 r
F P
0 g
s
.79128 .66524 m .79471 .61243 L .76539 .61585 L p .707 .577 .707 r
F P
0 g
s
.20661 .74612 m .20816 .72893 L .23739 .72541 L p .707 .577 .707 r
F P
0 g
s
.32063 .69116 m .32272 .72916 L .29527 .72828 L p .707 .577 .707 r
F P
0 g
s
.29527 .72828 m .29318 .69028 L .32063 .69116 L p .707 .577 .707 r
F P
0 g
s
.69906 .66357 m .70249 .61075 L .67508 .60273 L p .707 .577 .707 r
F P
0 g
s
.70249 .61075 m .69906 .66357 L .73018 .66809 L p .707 .577 .707 r
F P
0 g
s
.59372 .25191 m .59372 .7538 L .55525 .74746 L p .707 .577 .707 r
F P
0 g
s
.55525 .74746 m .55525 .24558 L .59372 .25191 L p .707 .577 .707 r
F P
0 g
s
.23739 .72541 m .23584 .74261 L .20661 .74612 L p .707 .577 .707 r
F P
0 g
s
.73586 .73097 m .73796 .69556 L .70682 .69127 L p .707 .577 .707 r
F P
0 g
s
.73796 .69556 m .73586 .73097 L .76765 .73142 L p .707 .577 .707 r
F P
0 g
s
.76765 .73142 m .76974 .69601 L .73796 .69556 L p .707 .577 .707 r
F P
0 g
s
.20303 .7345 m .20094 .69649 L .23026 .69308 L p .707 .577 .707 r
F P
0 g
s
.30021 .73169 m .29866 .74888 L .26756 .74356 L p .707 .577 .707 r
F P
0 g
s
.26756 .74356 m .26911 .72637 L .30021 .73169 L p .707 .577 .707 r
F P
0 g
s
.76974 .69601 m .76765 .73142 L .79696 .72799 L p .707 .577 .707 r
F P
0 g
s
.79696 .72799 m .79906 .69258 L .76974 .69601 L p .707 .577 .707 r
F P
0 g
s
.79471 .61243 m .79128 .66524 L .81529 .65815 L p .707 .577 .707 r
F P
0 g
s
.81529 .65815 m .81872 .60534 L .79471 .61243 L p .707 .577 .707 r
F P
0 g
s
.23584 .74261 m .23739 .72541 L .26911 .72637 L p .707 .577 .707 r
F P
0 g
s
.70472 .72668 m .70682 .69127 L .67937 .68357 L p .707 .577 .707 r
F P
0 g
s
.70682 .69127 m .70472 .72668 L .73586 .73097 L p .707 .577 .707 r
F P
0 g
s
.23026 .69308 m .23235 .73109 L .20303 .7345 L p .707 .577 .707 r
F P
0 g
s
.26911 .72637 m .26756 .74356 L .23584 .74261 L p .707 .577 .707 r
F P
0 g
s
.67164 .65554 m .67508 .60273 L .65405 .59199 L p .707 .577 .707 r
F P
0 g
s
.67508 .60273 m .67164 .65554 L .69906 .66357 L p .707 .577 .707 r
F P
0 g
s
.29318 .69028 m .29527 .72828 L .26413 .72895 L p .707 .577 .707 r
F P
0 g
s
.26413 .72895 m .26204 .69094 L .29318 .69028 L p .707 .577 .707 r
F P
0 g
s
.42467 .75021 m .42467 .24832 L .46637 .24369 L p .707 .577 .707 r
F P
0 g
s
.42467 .24832 m .42467 .75021 L .39035 .75807 L p .707 .577 .707 r
F P
0 g
s
.23235 .73109 m .23026 .69308 L .26204 .69094 L p .707 .577 .707 r
F P
0 g
s
.79906 .69258 m .79696 .72799 L .82094 .72101 L p .707 .577 .707 r
F P
0 g
s
.82094 .72101 m .82304 .68561 L .79906 .69258 L p .707 .577 .707 r
F P
0 g
s
.26204 .69094 m .26413 .72895 L .23235 .73109 L p .707 .577 .707 r
F P
0 g
s
.67728 .71897 m .67937 .68357 L .6583 .6732 L p .707 .577 .707 r
F P
0 g
s
.67937 .68357 m .67728 .71897 L .70472 .72668 L p .707 .577 .707 r
F P
0 g
s
.55525 .24558 m .55525 .74746 L .51137 .74463 L p .707 .577 .707 r
F P
0 g
s
.51137 .74463 m .51137 .24274 L .55525 .24558 L p .707 .577 .707 r
F P
0 g
s
.81872 .60534 m .81529 .65815 L .83162 .64809 L p .707 .577 .707 r
F P
0 g
s
.83162 .64809 m .83505 .59527 L .81872 .60534 L p .707 .577 .707 r
F P
0 g
s
.73244 .74043 m .73089 .72133 L .69979 .72324 L p .707 .577 .707 r
F P
0 g
s
.73089 .72133 m .73244 .74043 L .76416 .73762 L p .707 .577 .707 r
F P
0 g
s
.76416 .73762 m .76261 .71852 L .73089 .72133 L p .707 .577 .707 r
F P
0 g
s
.69979 .72324 m .70134 .74234 L .73244 .74043 L p .707 .577 .707 r
F P
0 g
s
.76261 .71852 m .76416 .73762 L .79339 .73418 L p .707 .577 .707 r
F P
0 g
s
.79339 .73418 m .79184 .71508 L .76261 .71852 L p .707 .577 .707 r
F P
0 g
s
.46637 .74558 m .46637 .24369 L .51137 .24274 L p .707 .577 .707 r
F P
0 g
s
.46637 .24369 m .46637 .74558 L .42467 .75021 L p .707 .577 .707 r
F P
0 g
s
.65062 .6448 m .65405 .59199 L .64147 .57958 L p .707 .577 .707 r
F P
0 g
s
.65405 .59199 m .65062 .6448 L .67164 .65554 L p .707 .577 .707 r
F P
0 g
s
.51137 .24274 m .51137 .74463 L .46637 .74558 L p .707 .577 .707 r
F P
0 g
s
.70134 .74234 m .69979 .72324 L .67235 .72406 L p .707 .577 .707 r
F P
0 g
s
.67235 .72406 m .67389 .74317 L .70134 .74234 L p .707 .577 .707 r
F P
0 g
s
.6583 .6732 m .65621 .7086 L .67728 .71897 L p .707 .577 .707 r
F P
0 g
s
.82304 .68561 m .82094 .72101 L .83724 .71117 L p .707 .577 .707 r
F P
0 g
s
.83724 .71117 m .83933 .67577 L .82304 .68561 L p .707 .577 .707 r
F P
0 g
s
.79184 .71508 m .79339 .73418 L .81727 .73046 L p .707 .577 .707 r
F P
0 g
s
.81727 .73046 m .81572 .71136 L .79184 .71508 L p .707 .577 .707 r
F P
0 g
s
.65621 .7086 m .6583 .6732 L .64568 .66118 L p .707 .577 .707 r
F P
0 g
s
.83505 .59527 m .83162 .64809 L .83868 .63604 L p .707 .577 .707 r
F P
0 g
s
.83868 .63604 m .84211 .58322 L .83505 .59527 L p .707 .577 .707 r
F P
0 g
s
.67389 .74317 m .67235 .72406 L .65125 .72372 L p .707 .577 .707 r
F P
0 g
s
.65125 .72372 m .6528 .74282 L .67389 .74317 L p .707 .577 .707 r
F P
0 g
s
.64147 .57958 m .63804 .6324 L .65062 .6448 L p .707 .577 .707 r
F P
0 g
s
.63804 .6324 m .64147 .57958 L .63857 .56672 L p .707 .577 .707 r
F P
0 g
s
.64568 .66118 m .64358 .69658 L .65621 .7086 L p .707 .577 .707 r
F P
0 g
s
.83933 .67577 m .83724 .71117 L .84426 .69943 L p .707 .577 .707 r
F P
0 g
s
.84426 .69943 m .84635 .66403 L .83933 .67577 L p .707 .577 .707 r
F P
0 g
s
.81572 .71136 m .81727 .73046 L .83346 .72681 L p .707 .577 .707 r
F P
0 g
s
.83346 .72681 m .83191 .70771 L .81572 .71136 L p .707 .577 .707 r
F P
0 g
s
.64358 .69658 m .64568 .66118 L .64273 .64869 L p .707 .577 .707 r
F P
0 g
s
.6528 .74282 m .65125 .72372 L .63857 .72225 L p .707 .577 .707 r
F P
0 g
s
.63857 .72225 m .64011 .74135 L .6528 .74282 L p .707 .577 .707 r
F P
0 g
s
.84211 .58322 m .83868 .63604 L .83577 .62318 L p .707 .577 .707 r
F P
0 g
s
.83577 .62318 m .83921 .57037 L .84211 .58322 L p .707 .577 .707 r
F P
0 g
s
.63857 .56672 m .63513 .61954 L .63804 .6324 L p .707 .577 .707 r
F P
0 g
s
.64273 .64869 m .64064 .68409 L .64358 .69658 L p .707 .577 .707 r
F P
0 g
s
.63513 .61954 m .63857 .56672 L .64563 .55467 L p .707 .577 .707 r
F P
0 g
s
.83191 .70771 m .83346 .72681 L .84038 .7236 L p .707 .577 .707 r
F P
0 g
s
.84038 .7236 m .83883 .7045 L .83191 .70771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84635 .66403 m .84426 .69943 L .84131 .68694 L p .707 .577 .707 r
F P
0 g
s
.84131 .68694 m .8434 .65153 L .84635 .66403 L p .707 .577 .707 r
F P
0 g
s
.64064 .68409 m .64273 .64869 L .64975 .63695 L p .707 .577 .707 r
F P
0 g
s
.64011 .74135 m .63857 .72225 L .63553 .71978 L p .707 .577 .707 r
F P
0 g
s
.63553 .71978 m .63708 .73888 L .64011 .74135 L p .707 .577 .707 r
F P
0 g
s
.83921 .57037 m .83577 .62318 L .82319 .61078 L p .707 .577 .707 r
F P
0 g
s
.82319 .61078 m .82663 .55796 L .83921 .57037 L p .707 .577 .707 r
F P
0 g
s
.64563 .55467 m .64219 .60749 L .63513 .61954 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64975 .63695 m .64765 .67235 L .64064 .68409 L p .707 .577 .707 r
F P
0 g
s
.64219 .60749 m .64563 .55467 L .66196 .54461 L p .707 .577 .707 r
F P
0 g
s
.38266 .61436 m .39062 .5585 L .35977 .55278 L p .707 .577 .707 r
F P
0 g
s
.39062 .5585 m .38266 .61436 L .41419 .61807 L p .707 .577 .707 r
F P
0 g
s
.41419 .61807 m .42216 .56221 L .39062 .5585 L p .707 .577 .707 r
F P
0 g
s
.42216 .56221 m .41419 .61807 L .44333 .6194 L p .707 .577 .707 r
F P
0 g
s
.44333 .6194 m .4513 .56354 L .42216 .56221 L p .707 .577 .707 r
F P
0 g
s
.8434 .65153 m .84131 .68694 L .82868 .67492 L p .707 .577 .707 r
F P
0 g
s
.82868 .67492 m .83077 .63951 L .8434 .65153 L p .707 .577 .707 r
F P
0 g
s
.83883 .7045 m .84038 .7236 L .83735 .72113 L p .707 .577 .707 r
F P
0 g
s
.83735 .72113 m .8358 .70203 L .83883 .7045 L p .707 .577 .707 r
F P
0 g
s
.3518 .60864 m .35977 .55278 L .33262 .54561 L p .707 .577 .707 r
F P
0 g
s
.35977 .55278 m .3518 .60864 L .38266 .61436 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64765 .67235 m .64975 .63695 L .66604 .6271 L p .707 .577 .707 r
F P
0 g
s
.4513 .56354 m .44333 .6194 L .46721 .61823 L p .707 .577 .707 r
F P
0 g
s
.46721 .61823 m .47518 .56237 L .4513 .56354 L p .707 .577 .707 r
F P
0 g
s
.33262 .54561 m .32465 .60147 L .3518 .60864 L p .707 .577 .707 r
F P
0 g
s
.82663 .55796 m .82319 .61078 L .80217 .60004 L p .707 .577 .707 r
F P
0 g
s
.80217 .60004 m .8056 .54722 L .82663 .55796 L p .707 .577 .707 r
F P
0 g
s
.63708 .73888 m .63553 .71978 L .64245 .71657 L p .707 .577 .707 r
F P
0 g
s
.32465 .60147 m .33262 .54561 L .31183 .5377 L p .707 .577 .707 r
F P
0 g
s
.64245 .71657 m .644 .73567 L .63708 .73888 L p .707 .577 .707 r
F P
0 g
s
.66196 .54461 m .65853 .59743 L .64219 .60749 L p .707 .577 .707 r
F P
0 g
s
.65853 .59743 m .66196 .54461 L .68596 .53752 L p .707 .577 .707 r
F P
0 g
s
.39576 .67398 m .40062 .63672 L .36971 .63134 L p .707 .577 .707 r
F P
0 g
s
.40062 .63672 m .39576 .67398 L .42735 .67729 L p .707 .577 .707 r
F P
0 g
s
.42735 .67729 m .43221 .64003 L .40062 .63672 L p .707 .577 .707 r
F P
0 g
s
.66604 .6271 m .66395 .66251 L .64765 .67235 L p .707 .577 .707 r
F P
0 g
s
.43221 .64003 m .42735 .67729 L .4565 .67821 L p .707 .577 .707 r
F P
0 g
s
.4565 .67821 m .46136 .64095 L .43221 .64003 L p .707 .577 .707 r
F P
0 g
s
.83077 .63951 m .82868 .67492 L .80761 .66455 L p .707 .577 .707 r
F P
0 g
s
.80761 .66455 m .80971 .62914 L .83077 .63951 L p .707 .577 .707 r
F P
0 g
s
.36485 .6686 m .36971 .63134 L .34248 .62442 L p .707 .577 .707 r
F P
0 g
s
.36971 .63134 m .36485 .6686 L .39576 .67398 L p .707 .577 .707 r
F P
0 g
s
.31183 .5377 m .30387 .59356 L .32465 .60147 L p .707 .577 .707 r
F P
0 g
s
.8358 .70203 m .83735 .72113 L .82466 .71966 L p .707 .577 .707 r
F P
0 g
s
.82466 .71966 m .82311 .70056 L .8358 .70203 L p .707 .577 .707 r
F P
0 g
s
.66395 .66251 m .66604 .6271 L .69002 .62013 L p .707 .577 .707 r
F P
0 g
s
.47518 .56237 m .46721 .61823 L .4835 .61467 L p .707 .577 .707 r
F P
0 g
s
.4835 .61467 m .49147 .55881 L .47518 .56237 L p .707 .577 .707 r
F P
0 g
s
.38709 .732 m .38352 .71426 L .3529 .71725 L p .707 .577 .707 r
F P
0 g
s
.38352 .71426 m .38709 .732 L .41838 .72546 L p .707 .577 .707 r
F P
0 g
s
.41838 .72546 m .4148 .70772 L .38352 .71426 L p .707 .577 .707 r
F P
0 g
s
.34248 .62442 m .33762 .66168 L .36485 .6686 L p .707 .577 .707 r
F P
0 g
s
.8056 .54722 m .80217 .60004 L .77475 .59201 L p .707 .577 .707 r
F P
0 g
s
.77475 .59201 m .77818 .5392 L .8056 .54722 L p .707 .577 .707 r
F P
0 g
s
.4148 .70772 m .41838 .72546 L .44726 .716 L p .707 .577 .707 r
F P
0 g
s
.44726 .716 m .44369 .69826 L .4148 .70772 L p .707 .577 .707 r
F P
0 g
s
.46136 .64095 m .4565 .67821 L .48038 .67664 L p .707 .577 .707 r
F P
0 g
s
.48038 .67664 m .48524 .63938 L .46136 .64095 L p .707 .577 .707 r
F P
0 g
s
.30387 .59356 m .31183 .5377 L .29944 .5298 L p .707 .577 .707 r
F P
0 g
s
.68253 .59034 m .68596 .53752 L .71529 .5341 L p .707 .577 .707 r
F P
0 g
s
.68596 .53752 m .68253 .59034 L .65853 .59743 L p .707 .577 .707 r
F P
0 g
s
.3529 .71725 m .35647 .73498 L .38709 .732 L p .707 .577 .707 r
F P
0 g
s
.33762 .66168 m .34248 .62442 L .32162 .61663 L p .707 .577 .707 r
F P
0 g
s
.35647 .73498 m .3529 .71725 L .32594 .71638 L p .707 .577 .707 r
F P
0 g
s
.644 .73567 m .64245 .71657 L .65864 .71292 L p .707 .577 .707 r
F P
0 g
s
.44369 .69826 m .44726 .716 L .47092 .70456 L p .707 .577 .707 r
F P
0 g
s
.47092 .70456 m .46735 .68682 L .44369 .69826 L p .707 .577 .707 r
F P
0 g
s
.65864 .71292 m .66019 .73202 L .644 .73567 L p .707 .577 .707 r
F P
0 g
s
.69002 .62013 m .68793 .65553 L .66395 .66251 L p .707 .577 .707 r
F P
0 g
s
.80971 .62914 m .80761 .66455 L .78017 .65684 L p .707 .577 .707 r
F P
0 g
s
.78017 .65684 m .78226 .62144 L .80971 .62914 L p .707 .577 .707 r
F P
0 g
s
.77818 .5392 m .77475 .59201 L .74363 .58749 L p .707 .577 .707 r
F P
0 g
s
.74363 .58749 m .74706 .53467 L .77818 .5392 L p .707 .577 .707 r
F P
0 g
s
.32594 .71638 m .32951 .73412 L .35647 .73498 L p .707 .577 .707 r
F P
0 g
s
.32162 .61663 m .31675 .65389 L .33762 .66168 L p .707 .577 .707 r
F P
0 g
s
.29944 .5298 m .29148 .58566 L .30387 .59356 L p .707 .577 .707 r
F P
0 g
s
.71185 .58691 m .71529 .5341 L .74706 .53467 L p .707 .577 .707 r
F P
0 g
s
.71529 .5341 m .71185 .58691 L .68253 .59034 L p .707 .577 .707 r
F P
0 g
s
.68793 .65553 m .69002 .62013 L .71934 .6167 L p .707 .577 .707 r
F P
0 g
s
.74706 .53467 m .74363 .58749 L .71185 .58691 L p .707 .577 .707 r
F P
0 g
s
.48524 .63938 m .48038 .67664 L .49664 .67274 L p .707 .577 .707 r
F P
0 g
s
.49664 .67274 m .5015 .63548 L .48524 .63938 L p .707 .577 .707 r
F P
0 g
s
.49147 .55881 m .4835 .61467 L .4906 .60908 L p .707 .577 .707 r
F P
0 g
s
.4906 .60908 m .49857 .55321 L .49147 .55881 L p .707 .577 .707 r
F P
0 g
s
.32951 .73412 m .32594 .71638 L .30528 .71175 L p .707 .577 .707 r
F P
0 g
s
.82311 .70056 m .82466 .71966 L .80357 .71931 L p .707 .577 .707 r
F P
0 g
s
.80357 .71931 m .80202 .70021 L .82311 .70056 L p .707 .577 .707 r
F P
0 g
s
.78226 .62144 m .78017 .65684 L .74903 .65255 L p .707 .577 .707 r
F P
0 g
s
.74903 .65255 m .75112 .61715 L .78226 .62144 L p .707 .577 .707 r
F P
0 g
s
.46735 .68682 m .47092 .70456 L .48704 .69224 L p .707 .577 .707 r
F P
0 g
s
.48704 .69224 m .48346 .6745 L .46735 .68682 L p .707 .577 .707 r
F P
0 g
s
.71725 .6521 m .71934 .6167 L .75112 .61715 L p .707 .577 .707 r
F P
0 g
s
.71934 .6167 m .71725 .6521 L .68793 .65553 L p .707 .577 .707 r
F P
0 g
s
.31675 .65389 m .32162 .61663 L .30915 .60875 L p .707 .577 .707 r
F P
0 g
s
.30528 .71175 m .30885 .72949 L .32951 .73412 L p .707 .577 .707 r
F P
0 g
s
.29148 .58566 m .29944 .5298 L .29666 .52271 L p .707 .577 .707 r
F P
0 g
s
.75112 .61715 m .74903 .65255 L .71725 .6521 L p .707 .577 .707 r
F P
0 g
s
.66019 .73202 m .65864 .71292 L .68252 .7092 L p .707 .577 .707 r
F P
0 g
s
.30915 .60875 m .30429 .646 L .31675 .65389 L p .707 .577 .707 r
F P
0 g
s
.68252 .7092 m .68407 .7283 L .66019 .73202 L p .707 .577 .707 r
F P
0 g
s
.29666 .52271 m .28869 .57857 L .29148 .58566 L p .707 .577 .707 r
F P
0 g
s
.30885 .72949 m .30528 .71175 L .29294 .70381 L p .707 .577 .707 r
F P
0 g
s
.80202 .70021 m .80357 .71931 L .77612 .72014 L p .707 .577 .707 r
F P
0 g
s
.77612 .72014 m .77458 .70104 L .80202 .70021 L p .707 .577 .707 r
F P
0 g
s
.5015 .63548 m .49664 .67274 L .50369 .6669 L p .707 .577 .707 r
F P
0 g
s
.50369 .6669 m .50855 .62964 L .5015 .63548 L p .707 .577 .707 r
F P
0 g
s
.48346 .6745 m .48704 .69224 L .49403 .68026 L p .707 .577 .707 r
F P
0 g
s
.49403 .68026 m .49046 .66252 L .48346 .6745 L p .707 .577 .707 r
F P
0 g
s
.49857 .55321 m .4906 .60908 L .48782 .60198 L p .707 .577 .707 r
F P
0 g
s
.48782 .60198 m .49579 .54612 L .49857 .55321 L p .707 .577 .707 r
F P
0 g
s
.29294 .70381 m .29651 .72155 L .30885 .72949 L p .707 .577 .707 r
F P
0 g
s
.30429 .646 m .30915 .60875 L .3063 .60153 L p .707 .577 .707 r
F P
0 g
s
.68407 .7283 m .68252 .7092 L .71175 .70576 L p .707 .577 .707 r
F P
0 g
s
.71175 .70576 m .7133 .72486 L .68407 .7283 L p .707 .577 .707 r
F P
0 g
s
.28869 .57857 m .29666 .52271 L .30377 .51711 L p .707 .577 .707 r
F P
0 g
s
.3063 .60153 m .30144 .63878 L .30429 .646 L p .707 .577 .707 r
F P
0 g
s
.77458 .70104 m .77612 .72014 L .74502 .72205 L p .707 .577 .707 r
F P
0 g
s
.74502 .72205 m .74347 .70295 L .77458 .70104 L p .707 .577 .707 r
F P
0 g
s
.7133 .72486 m .71175 .70576 L .74347 .70295 L p .707 .577 .707 r
F P
0 g
s
.74347 .70295 m .74502 .72205 L .7133 .72486 L p .707 .577 .707 r
F P
0 g
s
.30377 .51711 m .2958 .57297 L .28869 .57857 L p .707 .577 .707 r
F P
0 g
s
.29651 .72155 m .29294 .70381 L .29013 .69334 L p .707 .578 .707 r
F P
0 g
s
.50855 .62964 m .50369 .6669 L .50085 .65968 L p .707 .577 .707 r
F P
0 g
s
.50085 .65968 m .50571 .62242 L .50855 .62964 L p .707 .577 .707 r
F P
0 g
s
.49046 .66252 m .49403 .68026 L .49122 .66978 L p .707 .578 .707 r
F P
0 g
s
.49122 .66978 m .48765 .65204 L .49046 .66252 L p .707 .578 .707 r
F P
0 g
s
.29013 .69334 m .2937 .71108 L .29651 .72155 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .54612 m .48782 .60198 L .47543 .59409 L p .707 .577 .707 r
F P
0 g
s
.47543 .59409 m .4834 .53823 L .49579 .54612 L p .707 .577 .707 r
F P
0 g
s
.30144 .63878 m .3063 .60153 L .31335 .59568 L p .707 .577 .707 r
F P
0 g
s
.2958 .57297 m .30377 .51711 L .32005 .51355 L p .707 .577 .707 r
F P
0 g
s
.31335 .59568 m .30849 .63294 L .30144 .63878 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32005 .51355 m .31209 .56941 L .2958 .57297 L p .707 .577 .707 r
F P
0 g
s
.2937 .71108 m .29013 .69334 L .29712 .68136 L p .707 .577 .707 r
F P
0 g
s
.48765 .65204 m .49122 .66978 L .47888 .66184 L p .707 .577 .707 r
F P
0 g
s
.47888 .66184 m .47531 .6441 L .48765 .65204 L p .707 .577 .707 r
F P
0 g
s
.50571 .62242 m .50085 .65968 L .48838 .65179 L p .707 .577 .707 r
F P
0 g
s
.48838 .65179 m .49324 .61453 L .50571 .62242 L p .707 .577 .707 r
F P
0 g
s
.29712 .68136 m .3007 .6991 L .2937 .71108 L p .707 .577 .707 r
F P
0 g
s
.4834 .53823 m .47543 .59409 L .45464 .58617 L p .707 .577 .707 r
F P
0 g
s
.45464 .58617 m .46261 .53031 L .4834 .53823 L p .707 .577 .707 r
F P
0 g
s
.30849 .63294 m .31335 .59568 L .32961 .59179 L p .707 .577 .707 r
F P
0 g
s
.31209 .56941 m .32005 .51355 L .34394 .51238 L p .707 .577 .707 r
F P
0 g
s
.32961 .59179 m .32475 .62904 L .30849 .63294 L p .707 .577 .707 r
F P
0 g
s
.34394 .51238 m .33597 .56824 L .31209 .56941 L p .707 .577 .707 r
F P
0 g
s
.3007 .6991 m .29712 .68136 L .31324 .66904 L p .707 .577 .707 r
F P
0 g
s
.46261 .53031 m .45464 .58617 L .42749 .57901 L p .707 .577 .707 r
F P
0 g
s
.42749 .57901 m .43546 .52314 L .46261 .53031 L p .707 .577 .707 r
F P
0 g
s
.47531 .6441 m .47888 .66184 L .45822 .65721 L p .707 .577 .707 r
F P
0 g
s
.45822 .65721 m .45465 .63947 L .47531 .6441 L p .707 .577 .707 r
F P
0 g
s
.49324 .61453 m .48838 .65179 L .46751 .644 L p .707 .577 .707 r
F P
0 g
s
.46751 .644 m .47237 .60674 L .49324 .61453 L p .707 .577 .707 r
F P
0 g
s
.33597 .56824 m .34394 .51238 L .37307 .51372 L p .707 .577 .707 r
F P
0 g
s
.31324 .66904 m .31681 .68678 L .3007 .6991 L p .707 .577 .707 r
F P
0 g
s
.32475 .62904 m .32961 .59179 L .35349 .59022 L p .707 .577 .707 r
F P
0 g
s
.43546 .52314 m .42749 .57901 L .39664 .57329 L p .707 .577 .707 r
F P
0 g
s
.39664 .57329 m .40461 .51743 L .43546 .52314 L p .707 .577 .707 r
F P
0 g
s
.37307 .51372 m .3651 .56958 L .33597 .56824 L p .707 .577 .707 r
F P
0 g
s
.35349 .59022 m .34863 .62748 L .32475 .62904 L p .707 .577 .707 r
F P
0 g
s
.3651 .56958 m .37307 .51372 L .40461 .51743 L p .707 .577 .707 r
F P
0 g
s
.40461 .51743 m .39664 .57329 L .3651 .56958 L p .707 .577 .707 r
F P
0 g
s
.31681 .68678 m .31324 .66904 L .33689 .65759 L p .707 .577 .707 r
F P
0 g
s
.45465 .63947 m .45822 .65721 L .43126 .65635 L p .707 .577 .707 r
F P
0 g
s
.43126 .65635 m .42768 .63861 L .45465 .63947 L p .707 .577 .707 r
F P
0 g
s
.47237 .60674 m .46751 .644 L .44029 .63708 L p .707 .577 .707 r
F P
0 g
s
.44029 .63708 m .44515 .59982 L .47237 .60674 L p .707 .577 .707 r
F P
0 g
s
.33689 .65759 m .34047 .67533 L .31681 .68678 L p .707 .577 .707 r
F P
0 g
s
.34863 .62748 m .35349 .59022 L .38265 .59114 L p .707 .577 .707 r
F P
0 g
s
.38265 .59114 m .37779 .62839 L .34863 .62748 L p .707 .577 .707 r
F P
0 g
s
.44515 .59982 m .44029 .63708 L .40937 .6317 L p .707 .577 .707 r
F P
0 g
s
.40937 .6317 m .41423 .59444 L .44515 .59982 L p .707 .577 .707 r
F P
0 g
s
.34047 .67533 m .33689 .65759 L .36578 .64813 L p .707 .577 .707 r
F P
0 g
s
.37779 .62839 m .38265 .59114 L .41423 .59444 L p .707 .577 .707 r
F P
0 g
s
.42768 .63861 m .43126 .65635 L .40064 .65933 L p .707 .577 .707 r
F P
0 g
s
.40064 .65933 m .39706 .64159 L .42768 .63861 L p .707 .577 .707 r
F P
0 g
s
.41423 .59444 m .40937 .6317 L .37779 .62839 L p .707 .577 .707 r
F P
0 g
s
.36578 .64813 m .36935 .66587 L .34047 .67533 L p .707 .577 .707 r
F P
0 g
s
.36935 .66587 m .36578 .64813 L .39706 .64159 L p .707 .577 .707 r
F P
0 g
s
.39706 .64159 m .40064 .65933 L .36935 .66587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001NOol80002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00IWoo001IOol50003FUH00`00FUIJEP02FUH90009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol30000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol3
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80011oo`T004eoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000Yoo`H000AJEP03001JEUYF009JEPT004Aoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000Moo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPH003ioo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003Ool30005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000hOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00=Woo001COol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF008003Aoo`00Dgoo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00031oo`00DWoo00<005YF00000UYF4`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
DWoo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
059oo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60006
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF100015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000]Ool005=oo`800003FUH005YF00AJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300001eYF
001JEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH60008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Eoo`8000EJEPD000=JEP04001JEUYFFUH90005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YF00000`005goo1P001UYF00<005YFFUH00UYF00<005YF
FUH00UYF0P00;Goo001GOol500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90005
FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH2000DOol3000:Ool40002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Qoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000EJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP800003FUH00000019oo`D000eoo`<000AJEP07001J
EUYFFUH005YF0000;Goo001GOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP02FUH30005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0100015YF0`003goo1@0047oo0P00
0UYF00L005YFFUIJEP00FUH0000]Ool005Moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH000000005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001J
EP0000<000]oo`D0019oo`<000=JEP03001JEP0002eoo`00Egoo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH00eYF1`001Goo0`003goo100000=JEP0000000eYF0P00;Woo001@Ool700000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009Ool5
0005FUH00`00FUH00002FUH2000^Ool003mooa4000AJEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH0000D0003FUH00`00FUIJEP04FUH01@00FUIJEP00
FUH00P00;Woo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUH3000^Ool0039oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF
00AJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04
001JEUYFFUH3000^Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0003FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP02FUH3000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00<000EJEP03001JEUYF00=J
EP@000=JEPT000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YF0000;Woo000/Ool3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001EYF
000005YF00001EYF00<005YFFUH01UYF00<005YF00001`0015YF10000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
000015YF000000000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00P0000AJEP00FUH002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH00UYF4@001EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH3000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPL000AJ
EP03001JEUYF00=JEP@00003FUH005YF00EJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00;goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH01P00FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH01000FUIJEUYF
0P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH000020003FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH>0004FUH00`00FUH0000200001EYF000005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEPH000MJEP03
001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP@000MJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEP0000800003FUH005YF0080
0006FUH00000001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF009JEP03001JEP0000D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
009JEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30008FUH00`00
FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH0
0UYF0`001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF100000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00002Ool90004FUH00`00FUIJEP02FUH50004Ool20003FUH01000FUIJEUYF0P00;7oo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001EYF00<005YFFUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Moo`d0
00]oo`800003FUH005YF009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF4P001UYF00<005YF00000`000UYF00@005YFFUIJEPT000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP800004FUH000000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00007Ool5000EOol20003FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH20003FUH01000FUIJEP001EYF
00<005YFFUH015YF5@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000=JEP<00003FUH005YF00=JEP05001JEUYFFUH00007Ool5000GOol0
0`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP06FUH0
1000FUIJEP001EYF00@005YFFUIJEP800003FUH005YF009JEP04001JEUYF0005FUH40006FUH00`00
FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP020005FUH01000FUIJEP0027oo0`00
5goo0`0000=JEP00Ool0;7oo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUH000001EYF00@005YF000000=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH20004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P007Woo0`000eYF
0P00;Goo000]Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01000FUH000001EYF0P001EYF00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH02EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEP0000<00003FUH0000001]oo`<00003FUH0
05YF00=JEP8002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF
3@000UYF00<005YFFUH0300000Eoo`00FUIJEP0000EJEPD000EJEP03001JEUYF00MJEP<000EJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000BOol60004FUH00`00FUIJEP02FUH2000]Ool002io
o`80009JEP03001JEUYF00=JEP03001JEUYF00=JEPP000AJEP03001JEUYF00EJEP03001JEUYF00<0
00=JEP03001JEUYF00D0009oo`04001JEUYF0005FUH40006FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00L005YFFUIJEP00FUH0000]Ool0031oo`D00003FUH0000000H000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30005FUH01000FUH0000025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000;Goo000`Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUH0000200000eYF001JEP05FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF
8000;Woo000]Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00=JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000QJEP04001JEUYFFUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH00eYF00<005YF00000`0000=JEP00FUH025YF00H005YF000005YF000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2P000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000015YF001JEUYF5`001EYF00<005YFFUH01UYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEQ@0009JEP03001oogoo02aoo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000[Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH015YF10002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHL0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00D005YFFUIJEP0000=JEPP000QJEP03001JEP00008000EJEP03001JEUYF00EJEP04001J
EUYFFUH6000bOol002aoo`03001JEP0000=JEP03001JEUYF00=JEPH000EJEP03001JEUYF00IJEP03
001JEUYF00AJEP@00003FUH005YF00L000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/Ool0
0`00FUH00003FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000030004FUH00`00FUH000080004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT003moo`00;7oo00<005YF0000
0UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
00=JEP00FUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT004Qoo`00;7oo00<005YF00000`000UYF
00<005YFFUH00eYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF0`000eYF0`000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEQL0055oo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1P001eYF00<005YFFUH00`000Woo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00AJEP`000aJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00
FUIJEP03FUH01000FUIJEP00Egoo000/Ool40003FUH00`00FUH000030005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF
00<005YFFUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP800003Ool0000000D000=JEP04001JEUYF001GOol002eoo`<000=JEP800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00EJEP03
001oo`00009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00D000IJEP04001JEUYFFUH20008Ool40002FUH00`00Oomoo`1E
Ool002eoo`03001JEP00009JEPP000AJEP03001JEUYF009JEQ8000Ioo`8000IJEP<0009JEP03001J
EUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP@0009JEP04001JEUYFFUH20006Ool20004FUH4001FOol002eoo`03001JEP00
008000Qoo`T001Yoo`8000AJEP<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20004
Ool200000eYF001JEP03FUH01000FUH00000EWoo000]Ool00`00FUH0000_Ool01000FUIJEP000UYF
00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF0080009oo`8000=JEP03001JEUYF
009JEP04001JEP00001FOol002eoo`80035oo`<0009JEP03001JEUYF00800003FUH005YF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF00=JEP03001JEP0005Ioo`00;Goo0P006Goo
0`005goo00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50006FUH00`00FUIJ
EP03FUH00`00FUH0001FOol002eoo`8001Qoo`D001Moo`04001JEP000004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP03FUH2001GOol002eoo`<001Moo`D001Qo
o`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH00UYF
0P00Egoo000]Ool200000eYF001oo`0EOol5000IOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000IJEP03001JEUYF009JEP03001oogoo05Ioo`00;Goo0P000UYF00<007oo
Ool057oo0`006Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0006FUH0
0`00FUIJEP02001IOol002ioo`05001JEUYFFUH0000cOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP04FUH3001KOol002ioo`04001JEUYFFUH3000`
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60006FUH00`00Oomoo`1KOol002moo`04001J
EUYF0002FUH2000]Ool200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJ
EUYF001JEP80009JEP8005ioo`00;goo00<005YF00001EYF0`00:Goo00H005YF001JEP00Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP<005moo`00<7oo0P001UYF00@005YF000002Ioo`03
001JEUYF008000Aoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP05FUH3001LOol0035oo`03001J
EUYF00AJEP04001JEUYFFUH3000QOol20003FUH20006Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP06FUH0
0`00FUH00002001IOol0039oo`8000=JEP03001JEUYF00EJEPD001Qoo`@00003FUH005YF009JEP03
001oogoo00Moo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@00003FUH0000000@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8005Mo
o`00=7oo0P0000=JEP00FUH01eYF00@005YFFUIJEPT000Uoo`H000AJEP03001JEUYF008000eoo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000P000Ioo`@000IJ
EP03001JEUYF00AJEP<005Eoo`00=Woo0`001eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH00eYF0`005Woo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF40002Woo10000UYF
00<005YFFUH015YF00@005YFFUH005Aoo`00>Goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P008goo6P0015YF00<005YFFUH02@003Woo100015YF00D0
05YFFUIJEP0005Aoo`00>goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Qoo`800003FUH005YF00IJEP03001JEUYF00AJEPL0011oo`<00003FUH005YF009J
EP8005=oo`00?Woo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003aoo`<000EJ
EP03001JEUYF00MJEP03001JEUYF009JEPP000]oo`80009JEP03001JEP0005=oo`00A7oo2@0015YF
00<005YFFUH00UYF1@00@Goo100000=JEP00FUH025YF00<005YFFUH01UYF00@005YFFUIJEPh00004
FUH005YF001COol004eoo`T004Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00<005Aoo`00Y7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00E7oo002XOol70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Aoo`00[goo200015YF00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00]goo
4000EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63875 .7505 m .62593 .698 L .59488 .70557 L p .707 .577 .707 r
F P
0 g
s
.62593 .698 m .63875 .7505 L .66747 .73994 L p .707 .577 .707 r
F P
0 g
s
.66747 .73994 m .65466 .68743 L .62593 .698 L p .707 .577 .707 r
F P
0 g
s
.60769 .75808 m .59488 .70557 L .56453 .70941 L p .707 .577 .707 r
F P
0 g
s
.59488 .70557 m .60769 .75808 L .63875 .7505 L p .707 .577 .707 r
F P
0 g
s
.65466 .68743 m .66747 .73994 L .69105 .72742 L p .707 .577 .707 r
F P
0 g
s
.69105 .72742 m .67823 .67491 L .65466 .68743 L p .707 .577 .707 r
F P
0 g
s
.57734 .76192 m .56453 .70941 L .53785 .70915 L p .707 .577 .707 r
F P
0 g
s
.56453 .70941 m .57734 .76192 L .60769 .75808 L p .707 .577 .707 r
F P
0 g
s
.58713 .82027 m .5793 .78501 L .5488 .78843 L p .707 .577 .707 r
F P
0 g
s
.5793 .78501 m .58713 .82027 L .61831 .81321 L p .707 .577 .707 r
F P
0 g
s
.61831 .81321 m .61048 .77796 L .5793 .78501 L p .707 .577 .707 r
F P
0 g
s
.61048 .77796 m .61831 .81321 L .64711 .80321 L p .707 .577 .707 r
F P
0 g
s
.64711 .80321 m .63928 .76795 L .61048 .77796 L p .707 .577 .707 r
F P
0 g
s
.55663 .82368 m .5488 .78843 L .52196 .78786 L p .707 .577 .707 r
F P
0 g
s
.5488 .78843 m .55663 .82368 L .58713 .82027 L p .707 .577 .707 r
F P
0 g
s
.63928 .76795 m .64711 .80321 L .67071 .79123 L p .707 .577 .707 r
F P
0 g
s
.67071 .79123 m .66288 .75598 L .63928 .76795 L p .707 .577 .707 r
F P
0 g
s
.67823 .67491 m .69105 .72742 L .70718 .71417 L p .707 .577 .707 r
F P
0 g
s
.70718 .71417 m .69436 .66166 L .67823 .67491 L p .707 .577 .707 r
F P
0 g
s
.55067 .76165 m .53785 .70915 L .51747 .7048 L p .707 .577 .707 r
F P
0 g
s
.53785 .70915 m .55067 .76165 L .57734 .76192 L p .707 .577 .707 r
F P
0 g
s
.60122 .83553 m .60695 .81735 L .57722 .80715 L p .707 .577 .707 r
F P
0 g
s
.60695 .81735 m .60122 .83553 L .63162 .84452 L p .707 .577 .707 r
F P
0 g
s
.63162 .84452 m .63735 .82635 L .60695 .81735 L p .707 .577 .707 r
F P
0 g
s
.52196 .78786 m .52979 .82312 L .55663 .82368 L p .707 .577 .707 r
F P
0 g
s
.57722 .80715 m .57149 .82532 L .60122 .83553 L p .707 .577 .707 r
F P
0 g
s
.63735 .82635 m .63162 .84452 L .65973 .85144 L p .707 .577 .707 r
F P
0 g
s
.65973 .85144 m .66546 .83326 L .63735 .82635 L p .707 .577 .707 r
F P
0 g
s
.52979 .82312 m .52196 .78786 L .50141 .78338 L p .707 .577 .707 r
F P
0 g
s
.57149 .82532 m .57722 .80715 L .55108 .79674 L p .707 .577 .707 r
F P
0 g
s
.66288 .75598 m .67071 .79123 L .68681 .77846 L p .707 .577 .707 r
F P
0 g
s
.68681 .77846 m .67898 .7432 L .66288 .75598 L p .707 .577 .707 r
F P
0 g
s
.55108 .79674 m .54536 .81492 L .57149 .82532 L p .707 .577 .707 r
F P
0 g
s
.51747 .7048 m .53029 .75731 L .55067 .76165 L p .707 .577 .707 r
F P
0 g
s
.69436 .66166 m .70718 .71417 L .71427 .70148 L p .707 .577 .707 r
F P
0 g
s
.71427 .70148 m .70145 .64898 L .69436 .66166 L p .707 .577 .707 r
F P
0 g
s
.53029 .75731 m .51747 .7048 L .50537 .6968 L p .707 .577 .707 r
F P
0 g
s
.66546 .83326 m .65973 .85144 L .68279 .85559 L p .707 .577 .707 r
F P
0 g
s
.68279 .85559 m .68852 .83741 L .66546 .83326 L p .707 .577 .707 r
F P
0 g
s
.50141 .78338 m .50924 .81864 L .52979 .82312 L p .707 .577 .707 r
F P
0 g
s
.54536 .81492 m .55108 .79674 L .53109 .78715 L p .707 .577 .707 r
F P
0 g
s
.53109 .78715 m .52537 .80532 L .54536 .81492 L p .707 .577 .707 r
F P
0 g
s
.50924 .81864 m .50141 .78338 L .48916 .77542 L p .707 .577 .707 r
F P
0 g
s
.67898 .7432 m .68681 .77846 L .69383 .76613 L p .707 .577 .707 r
F P
0 g
s
.69383 .76613 m .686 .73088 L .67898 .7432 L p .707 .577 .707 r
F P
0 g
s
.50537 .6968 m .51819 .74931 L .53029 .75731 L p .707 .577 .707 r
F P
0 g
s
.68852 .83741 m .68279 .85559 L .69854 .85657 L p .707 .577 .707 r
F P
0 g
s
.69854 .85657 m .70427 .8384 L .68852 .83741 L p .707 .577 .707 r
F P
0 g
s
.48916 .77542 m .49698 .81067 L .50924 .81864 L p .707 .577 .707 r
F P
0 g
s
.70145 .64898 m .71427 .70148 L .71164 .69061 L p .698 .572 .709 r
F P
0 g
s
.71164 .69061 m .69882 .6381 L .70145 .64898 L p .698 .572 .709 r
F P
0 g
s
.51819 .74931 m .50537 .6968 L .50274 .68593 L p .698 .572 .709 r
F P
0 g
s
.52537 .80532 m .53109 .78715 L .51921 .77931 L p .707 .577 .707 r
F P
0 g
s
.51921 .77931 m .51348 .79748 L .52537 .80532 L p .707 .577 .707 r
F P
0 g
s
.49698 .81067 m .48916 .77542 L .4864 .76476 L p .708 .578 .707 r
F P
0 g
s
.686 .73088 m .69383 .76613 L .69108 .75547 L p .708 .578 .707 r
F P
0 g
s
.69108 .75547 m .68325 .72022 L .686 .73088 L p .708 .578 .707 r
F P
0 g
s
.4864 .76476 m .49423 .80001 L .49698 .81067 L p .708 .578 .707 r
F P
0 g
s
.49423 .80001 m .4864 .76476 L .49342 .75243 L p .707 .577 .707 r
F P
0 g
s
.48752 .82178 m .48752 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.50274 .68593 m .51556 .73843 L .51819 .74931 L p .698 .572 .709 r
F P
0 g
s
.51348 .79748 m .51921 .77931 L .51659 .77399 L p .707 .577 .707 r
F P
0 g
s
.51556 .73843 m .50274 .68593 L .50983 .67324 L p .707 .577 .707 r
F P
0 g
s
.51659 .77399 m .51086 .79216 L .51348 .79748 L p .707 .577 .707 r
F P
0 g
s
.50983 .67324 m .52265 .72575 L .51556 .73843 L p .707 .577 .707 r
F P
0 g
s
.49342 .75243 m .50125 .78769 L .49423 .80001 L p .707 .577 .707 r
F P
0 g
s
.52265 .72575 m .50983 .67324 L .52596 .65999 L p .707 .577 .707 r
F P
0 g
s
.51086 .79216 m .51659 .77399 L .52349 .77171 L p .707 .577 .707 r
F P
0 g
s
.52349 .77171 m .51777 .78988 L .51086 .79216 L p .707 .577 .707 r
F P
0 g
s
.50125 .78769 m .49342 .75243 L .50952 .73966 L p .707 .577 .707 r
F P
0 g
s
.52596 .65999 m .53878 .7125 L .52265 .72575 L p .707 .577 .707 r
F P
0 g
s
.50952 .73966 m .51735 .77491 L .50125 .78769 L p .707 .577 .707 r
F P
0 g
s
.51777 .78988 m .52349 .77171 L .53925 .77269 L p .707 .577 .707 r
F P
0 g
s
.53925 .77269 m .53352 .79087 L .51777 .78988 L p .707 .577 .707 r
F P
0 g
s
.51735 .77491 m .50952 .73966 L .53313 .72768 L p .707 .577 .707 r
F P
0 g
s
.53313 .72768 m .54095 .76294 L .51735 .77491 L p .707 .577 .707 r
F P
0 g
s
.48752 .31989 m .48752 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53878 .7125 m .52596 .65999 L .54954 .64747 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48752 .31989 L p .707 .577 .707 r
F P
0 g
s
.56235 .69998 m .54954 .64747 L .57826 .63691 L p .707 .577 .707 r
F P
0 g
s
.54954 .64747 m .56235 .69998 L .53878 .7125 L p .707 .577 .707 r
F P
0 g
s
.57826 .63691 m .59108 .68941 L .56235 .69998 L p .707 .577 .707 r
F P
0 g
s
.54095 .76294 m .53313 .72768 L .56193 .71768 L p .707 .577 .707 r
F P
0 g
s
.53352 .79087 m .53925 .77269 L .56231 .77684 L p .707 .577 .707 r
F P
0 g
s
.56231 .77684 m .55658 .79502 L .53352 .79087 L p .707 .577 .707 r
F P
0 g
s
.56975 .75293 m .56193 .71768 L .5931 .71062 L p .707 .577 .707 r
F P
0 g
s
.56193 .71768 m .56975 .75293 L .54095 .76294 L p .707 .577 .707 r
F P
0 g
s
.55658 .79502 m .56231 .77684 L .59041 .78376 L p .707 .577 .707 r
F P
0 g
s
.59041 .78376 m .58469 .80193 L .55658 .79502 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57437 .81638 L p .707 .577 .707 r
F P
0 g
s
.5931 .71062 m .60093 .74588 L .56975 .75293 L p .707 .577 .707 r
F P
0 g
s
.57437 .81638 m .57437 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70427 .8384 m .69854 .85657 L .70545 .85429 L p .707 .577 .707 r
F P
0 g
s
.70545 .85429 m .71118 .83612 L .70427 .8384 L p .707 .577 .707 r
F P
0 g
s
.44372 .81886 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44372 .81886 L .48752 .82178 L p .707 .577 .707 r
F P
0 g
s
.69882 .6381 m .71164 .69061 L .69954 .68261 L p .707 .577 .707 r
F P
0 g
s
.69954 .68261 m .68672 .6301 L .69882 .6381 L p .707 .577 .707 r
F P
0 g
s
.60932 .62933 m .62213 .68184 L .59108 .68941 L p .707 .577 .707 r
F P
0 g
s
.59108 .68941 m .57826 .63691 L .60932 .62933 L p .707 .577 .707 r
F P
0 g
s
.6236 .70721 m .63143 .74247 L .60093 .74588 L p .707 .577 .707 r
F P
0 g
s
.60093 .74588 m .5931 .71062 L .6236 .70721 L p .707 .577 .707 r
F P
0 g
s
.58469 .80193 m .59041 .78376 L .62082 .79275 L p .707 .577 .707 r
F P
0 g
s
.62082 .79275 m .61509 .81093 L .58469 .80193 L p .707 .577 .707 r
F P
0 g
s
.57437 .31449 m .57437 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .3067 L .57437 .31449 L p .707 .577 .707 r
F P
0 g
s
.25855 .6932 m .25298 .63584 L .22194 .63851 L p .707 .577 .707 r
F P
0 g
s
.25298 .63584 m .25855 .6932 L .29023 .68999 L p .707 .577 .707 r
F P
0 g
s
.29023 .68999 m .28466 .63263 L .25298 .63584 L p .707 .577 .707 r
F P
0 g
s
.68325 .72022 m .69108 .75547 L .67882 .74751 L p .707 .577 .707 r
F P
0 g
s
.67882 .74751 m .671 .71225 L .68325 .72022 L p .707 .577 .707 r
F P
0 g
s
.22194 .63851 m .22751 .69587 L .25855 .6932 L p .707 .577 .707 r
F P
0 g
s
.28466 .63263 m .29023 .68999 L .31945 .68656 L p .707 .577 .707 r
F P
0 g
s
.31945 .68656 m .31388 .62919 L .28466 .63263 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44372 .81886 L p .707 .577 .707 r
F P
0 g
s
.22751 .69587 m .22194 .63851 L .19458 .64038 L p .707 .577 .707 r
F P
0 g
s
.71118 .83612 m .70545 .85429 L .70283 .84897 L p .707 .577 .707 r
F P
0 g
s
.70283 .84897 m .70856 .8308 L .71118 .83612 L p .707 .577 .707 r
F P
0 g
s
.19458 .64038 m .20014 .69775 L .22751 .69587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68672 .6301 m .69954 .68261 L .67916 .67826 L p .707 .577 .707 r
F P
0 g
s
.67916 .67826 m .66634 .62576 L .68672 .6301 L p .707 .577 .707 r
F P
0 g
s
.31388 .62919 m .31945 .68656 L .34335 .68324 L p .707 .577 .707 r
F P
0 g
s
.34335 .68324 m .33778 .62588 L .31388 .62919 L p .707 .577 .707 r
F P
0 g
s
.63143 .74247 m .6236 .70721 L .65044 .70777 L p .707 .577 .707 r
F P
0 g
s
.63967 .62549 m .65248 .678 L .62213 .68184 L p .707 .577 .707 r
F P
0 g
s
.62213 .68184 m .60932 .62933 L .63967 .62549 L p .707 .577 .707 r
F P
0 g
s
.61509 .81093 m .62082 .79275 L .65054 .80296 L p .707 .577 .707 r
F P
0 g
s
.60892 .3067 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.65044 .70777 m .65827 .74303 L .63143 .74247 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .3067 L p .707 .577 .707 r
F P
0 g
s
.20014 .69775 m .19458 .64038 L .17357 .64128 L p .707 .577 .707 r
F P
0 g
s
.17357 .64128 m .17914 .69864 L .20014 .69775 L p .707 .577 .707 r
F P
0 g
s
.671 .71225 m .67882 .74751 L .65827 .74303 L p .707 .577 .707 r
F P
0 g
s
.65827 .74303 m .65044 .70777 L .671 .71225 L p .707 .577 .707 r
F P
0 g
s
.66634 .62576 m .67916 .67826 L .65248 .678 L p .707 .577 .707 r
F P
0 g
s
.65248 .678 m .63967 .62549 L .66634 .62576 L p .707 .577 .707 r
F P
0 g
s
.33778 .62588 m .34335 .68324 L .35958 .68036 L p .707 .577 .707 r
F P
0 g
s
.35958 .68036 m .35401 .623 L .33778 .62588 L p .707 .577 .707 r
F P
0 g
s
.24979 .75025 m .24639 .71202 L .21531 .7143 L p .707 .577 .707 r
F P
0 g
s
.24639 .71202 m .24979 .75025 L .28149 .74724 L p .707 .577 .707 r
F P
0 g
s
.28149 .74724 m .27809 .70901 L .24639 .71202 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.21531 .7143 m .21871 .75253 L .24979 .75025 L p .707 .577 .707 r
F P
0 g
s
.27809 .70901 m .28149 .74724 L .3107 .74381 L p .707 .577 .707 r
F P
0 g
s
.3107 .74381 m .30731 .70558 L .27809 .70901 L p .707 .577 .707 r
F P
0 g
s
.70856 .8308 m .70283 .84897 L .69095 .84113 L p .707 .577 .707 r
F P
0 g
s
.69095 .84113 m .69667 .82296 L .70856 .8308 L p .707 .577 .707 r
F P
0 g
s
.25642 .84305 m .25894 .82702 L .22797 .81992 L p .707 .577 .707 r
F P
0 g
s
.25894 .82702 m .25642 .84305 L .28795 .84481 L p .707 .577 .707 r
F P
0 g
s
.28795 .84481 m .29047 .82878 L .25894 .82702 L p .707 .577 .707 r
F P
0 g
s
.21871 .75253 m .21531 .7143 L .18789 .71563 L p .707 .577 .707 r
F P
0 g
s
.22545 .83595 m .22797 .81992 L .20058 .80816 L p .707 .577 .707 r
F P
0 g
s
.22797 .81992 m .22545 .83595 L .25642 .84305 L p .707 .577 .707 r
F P
0 g
s
.18789 .71563 m .19129 .75386 L .21871 .75253 L p .707 .577 .707 r
F P
0 g
s
.17914 .69864 m .17357 .64128 L .16097 .6411 L p .707 .577 .707 r
F P
0 g
s
.29047 .82878 m .28795 .84481 L .31695 .84106 L p .707 .577 .707 r
F P
0 g
s
.31695 .84106 m .31947 .82503 L .29047 .82878 L p .707 .577 .707 r
F P
0 g
s
.16097 .6411 m .16654 .69846 L .17914 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .70558 m .3107 .74381 L .33457 .74027 L p .707 .577 .707 r
F P
0 g
s
.33457 .74027 m .33118 .70205 L .30731 .70558 L p .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .79832 L .6437 .78657 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.20058 .80816 m .19806 .82419 L .22545 .83595 L p .707 .577 .707 r
F P
0 g
s
.19806 .82419 m .20058 .80816 L .17947 .79291 L p .707 .577 .707 r
F P
0 g
s
.19129 .75386 m .18789 .71563 L .16682 .71589 L p .707 .577 .707 r
F P
0 g
s
.31947 .82503 m .31695 .84106 L .34059 .83215 L p .707 .577 .707 r
F P
0 g
s
.34059 .83215 m .34311 .81612 L .31947 .82503 L p .707 .577 .707 r
F P
0 g
s
.16682 .71589 m .17022 .75412 L .19129 .75386 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35629 .27798 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35401 .623 m .35958 .68036 L .36581 .67844 L p .707 .577 .707 r
F P
0 g
s
.36567 .67426 m .35401 .623 L .36581 .67844 L .707 .577 .707 r
F
.36656 .6782 m .361 .62084 L .35401 .623 L p F P
0 g
s
.35805 .61961 m .361 .62084 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36361 .67698 m .36335 .67425 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36335 .67425 m .35805 .61961 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.34737 .69877 m .35076 .737 L .35769 .73429 L p .707 .577 .707 r
F P
0 g
s
.35769 .73429 m .35429 .69606 L .34737 .69877 L p .707 .577 .707 r
F P
0 g
s
.35429 .69606 m .35769 .73429 L .35467 .73242 L p .707 .577 .707 r
F P
0 g
s
.36257 .76919 m .36005 .78522 L .34727 .76796 L p .707 .577 .707 r
F P
0 g
s
.34727 .76796 m .34979 .75193 L .36257 .76919 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35947 .79195 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35805 .61961 m .36361 .67698 L .35102 .6768 L p .707 .577 .707 r
F P
0 g
s
.35102 .6768 m .34545 .61944 L .35805 .61961 L p .707 .577 .707 r
F P
0 g
s
.35629 .27798 m .35629 .70254 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35629 .70254 m .35629 .77987 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .49323 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35947 .49323 m .35947 .29006 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.36581 .67844 m .36656 .6782 L p .36567 .67426 L .707 .577 .707 r
F P
0 g
s
.17947 .79291 m .17695 .80894 L .19806 .82419 L p .707 .577 .707 r
F P
0 g
s
.69667 .82296 m .69095 .84113 L .67096 .83154 L p .707 .577 .707 r
F P
0 g
s
.67096 .83154 m .67668 .81336 L .69667 .82296 L p .707 .577 .707 r
F P
0 g
s
.33118 .70205 m .33457 .74027 L .35076 .737 L p .707 .577 .707 r
F P
0 g
s
.35076 .737 m .34737 .69877 L .33118 .70205 L p .707 .577 .707 r
F P
0 g
s
.17695 .80894 m .17947 .79291 L .16669 .77565 L p .707 .577 .707 r
F P
0 g
s
.16654 .69846 m .16097 .6411 L .15802 .63987 L p .707 .577 .707 r
F P
0 g
s
.361 .62084 m .36656 .6782 L .36361 .67698 L p .707 .577 .707 r
F P
0 g
s
.36324 .8028 m .36576 .78677 L .35906 .80294 L p .707 .577 .707 r
F P
0 g
s
.36576 .78677 m .36324 .8028 L .36005 .78522 L p .707 .577 .707 r
F P
0 g
s
.36005 .78522 m .36257 .76919 L .36576 .78677 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.15802 .63987 m .16359 .69724 L .16654 .69846 L p .707 .577 .707 r
F P
0 g
s
.34311 .81612 m .34059 .83215 L .35654 .81897 L p .707 .577 .707 r
F P
0 g
s
.35654 .81897 m .35906 .80294 L .34311 .81612 L p .707 .577 .707 r
F P
0 g
s
.17022 .75412 m .16682 .71589 L .15415 .71504 L p .707 .577 .707 r
F P
0 g
s
.16669 .77565 m .16417 .79168 L .17695 .80894 L p .707 .577 .707 r
F P
0 g
s
.15415 .71504 m .15755 .75327 L .17022 .75412 L p .707 .577 .707 r
F P
0 g
s
.67668 .81336 m .67096 .83154 L .64482 .82113 L p .707 .577 .707 r
F P
0 g
s
.64482 .82113 m .65054 .80296 L .67668 .81336 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .70924 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .62359 .76326 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .639 .56377 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63638 .62968 m .63665 .62728 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63665 .62728 m .64195 .57917 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .64053 .77449 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.6437 .70924 m .6437 .78657 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.16417 .79168 m .16669 .77565 L .1635 .75808 L p .707 .577 .707 r
F P
0 g
s
.35906 .80294 m .35654 .81897 L .36324 .8028 L p .707 .577 .707 r
F P
0 g
s
.65054 .80296 m .64482 .82113 L .61509 .81093 L p .707 .577 .707 r
F P
0 g
s
.16359 .69724 m .15802 .63987 L .16501 .63771 L p .707 .577 .707 r
F P
0 g
s
.1635 .75808 m .16098 .77411 L .16417 .79168 L p .707 .577 .707 r
F P
0 g
s
.16501 .63771 m .17057 .69508 L .16359 .69724 L p .707 .577 .707 r
F P
0 g
s
.15755 .75327 m .15415 .71504 L .15114 .71317 L p .707 .577 .707 r
F P
0 g
s
.15114 .71317 m .15453 .7514 L .15755 .75327 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35629 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16098 .77411 m .1635 .75808 L .17021 .74191 L p .707 .577 .707 r
F P
0 g
s
.35467 .73242 m .35128 .69419 L .35429 .69606 L p .707 .577 .707 r
F P
0 g
s
.17021 .74191 m .16769 .75794 L .16098 .77411 L p .707 .577 .707 r
F P
0 g
s
.17057 .69508 m .16501 .63771 L .18124 .63483 L p .707 .577 .707 r
F P
0 g
s
.62359 .76326 m .62359 .26137 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18124 .63483 m .18681 .6922 L .17057 .69508 L p .707 .577 .707 r
F P
0 g
s
.15453 .7514 m .15114 .71317 L .15806 .71046 L p .707 .577 .707 r
F P
0 g
s
.15806 .71046 m .16146 .74869 L .15453 .7514 L p .707 .577 .707 r
F P
0 g
s
.16769 .75794 m .17021 .74191 L .18616 .72872 L p .707 .577 .707 r
F P
0 g
s
.34545 .61944 m .35102 .6768 L .33001 .67769 L p .707 .577 .707 r
F P
0 g
s
.33001 .67769 m .32444 .62033 L .34545 .61944 L p .707 .577 .707 r
F P
0 g
s
.35128 .69419 m .35467 .73242 L .34201 .73157 L p .707 .577 .707 r
F P
0 g
s
.34201 .73157 m .33861 .69334 L .35128 .69419 L p .707 .577 .707 r
F P
0 g
s
.18616 .72872 m .18364 .74475 L .16769 .75794 L p .707 .577 .707 r
F P
0 g
s
.36718 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36718 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18681 .6922 m .18124 .63483 L .20514 .63152 L p .707 .577 .707 r
F P
0 g
s
.20514 .63152 m .21071 .68888 L .18681 .6922 L p .707 .577 .707 r
F P
0 g
s
.16146 .74869 m .15806 .71046 L .17425 .70718 L p .707 .577 .707 r
F P
0 g
s
.18364 .74475 m .18616 .72872 L .20979 .71982 L p .707 .577 .707 r
F P
0 g
s
.17425 .70718 m .17765 .74541 L .16146 .74869 L p .707 .577 .707 r
F P
0 g
s
.32444 .62033 m .33001 .67769 L .30265 .67957 L p .707 .577 .707 r
F P
0 g
s
.30265 .67957 m .29708 .6222 L .32444 .62033 L p .707 .577 .707 r
F P
0 g
s
.34979 .75193 m .34727 .76796 L .32616 .75271 L p .707 .577 .707 r
F P
0 g
s
.32616 .75271 m .32868 .73668 L .34979 .75193 L p .707 .577 .707 r
F P
0 g
s
.62359 .26137 m .62359 .76326 L .59456 .75399 L p .707 .577 .707 r
F P
0 g
s
.59456 .75399 m .59456 .2521 L .62359 .26137 L p .707 .577 .707 r
F P
0 g
s
.20979 .71982 m .20727 .73585 L .18364 .74475 L p .707 .577 .707 r
F P
0 g
s
.21071 .68888 m .20514 .63152 L .23436 .62808 L p .707 .577 .707 r
F P
0 g
s
.23436 .62808 m .23992 .68545 L .21071 .68888 L p .707 .577 .707 r
F P
0 g
s
.33861 .69334 m .34201 .73157 L .32093 .73182 L p .707 .577 .707 r
F P
0 g
s
.32093 .73182 m .31754 .6936 L .33861 .69334 L p .707 .577 .707 r
F P
0 g
s
.29708 .6222 m .30265 .67957 L .27161 .68224 L p .707 .577 .707 r
F P
0 g
s
.27161 .68224 m .26604 .62488 L .29708 .6222 L p .707 .577 .707 r
F P
0 g
s
.20727 .73585 m .20979 .71982 L .23879 .71606 L p .707 .577 .707 r
F P
0 g
s
.32868 .73668 m .32616 .75271 L .29877 .74095 L p .707 .577 .707 r
F P
0 g
s
.29877 .74095 m .30129 .72492 L .32868 .73668 L p .707 .577 .707 r
F P
0 g
s
.23992 .68545 m .23436 .62808 L .26604 .62488 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36718 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42563 .24816 L p .707 .577 .707 r
F P
0 g
s
.26604 .62488 m .27161 .68224 L .23992 .68545 L p .707 .577 .707 r
F P
0 g
s
.17765 .74541 m .17425 .70718 L .19812 .70365 L p .707 .577 .707 r
F P
0 g
s
.19812 .70365 m .20152 .74188 L .17765 .74541 L p .707 .577 .707 r
F P
0 g
s
.23879 .71606 m .23627 .73209 L .20727 .73585 L p .707 .577 .707 r
F P
0 g
s
.72839 .67401 m .73396 .6235 L .70292 .61751 L p .707 .577 .707 r
F P
0 g
s
.73396 .6235 m .72839 .67401 L .76007 .6753 L p .707 .577 .707 r
F P
0 g
s
.76007 .6753 m .76564 .62479 L .73396 .6235 L p .707 .577 .707 r
F P
0 g
s
.23627 .73209 m .23879 .71606 L .27032 .71782 L p .707 .577 .707 r
F P
0 g
s
.30129 .72492 m .29877 .74095 L .2678 .73385 L p .707 .577 .707 r
F P
0 g
s
.2678 .73385 m .27032 .71782 L .30129 .72492 L p .707 .577 .707 r
F P
0 g
s
.76564 .62479 m .76007 .6753 L .78929 .67178 L p .707 .577 .707 r
F P
0 g
s
.78929 .67178 m .79486 .62126 L .76564 .62479 L p .707 .577 .707 r
F P
0 g
s
.69735 .66803 m .70292 .61751 L .67555 .60742 L p .707 .577 .707 r
F P
0 g
s
.70292 .61751 m .69735 .66803 L .72839 .67401 L p .707 .577 .707 r
F P
0 g
s
.73756 .73864 m .74096 .70458 L .70988 .69895 L p .707 .577 .707 r
F P
0 g
s
.74096 .70458 m .73756 .73864 L .76926 .73974 L p .707 .577 .707 r
F P
0 g
s
.76926 .73974 m .77266 .70569 L .74096 .70458 L p .707 .577 .707 r
F P
0 g
s
.27032 .71782 m .2678 .73385 L .23627 .73209 L p .707 .577 .707 r
F P
0 g
s
.59456 .2521 m .59456 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59456 .2521 L p .707 .577 .707 r
F P
0 g
s
.31754 .6936 m .32093 .73182 L .29351 .73316 L p .707 .577 .707 r
F P
0 g
s
.29351 .73316 m .29012 .69493 L .31754 .6936 L p .707 .577 .707 r
F P
0 g
s
.77266 .70569 m .76926 .73974 L .79848 .73622 L p .707 .577 .707 r
F P
0 g
s
.79848 .73622 m .80187 .70216 L .77266 .70569 L p .707 .577 .707 r
F P
0 g
s
.70648 .733 m .70988 .69895 L .68246 .68934 L p .707 .577 .707 r
F P
0 g
s
.70988 .69895 m .70648 .733 L .73756 .73864 L p .707 .577 .707 r
F P
0 g
s
.79486 .62126 m .78929 .67178 L .81319 .66377 L p .707 .577 .707 r
F P
0 g
s
.81319 .66377 m .81876 .61326 L .79486 .62126 L p .707 .577 .707 r
F P
0 g
s
.20152 .74188 m .19812 .70365 L .22734 .70022 L p .707 .577 .707 r
F P
0 g
s
.66999 .65793 m .67555 .60742 L .65455 .59421 L p .707 .577 .707 r
F P
0 g
s
.67555 .60742 m .66999 .65793 L .69735 .66803 L p .707 .577 .707 r
F P
0 g
s
.22734 .70022 m .23073 .73844 L .20152 .74188 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42563 .24816 L .46746 .24362 L p .707 .577 .707 r
F P
0 g
s
.42563 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.80187 .70216 m .79848 .73622 L .82235 .7284 L p .707 .577 .707 r
F P
0 g
s
.82235 .7284 m .82575 .69435 L .80187 .70216 L p .707 .577 .707 r
F P
0 g
s
.67907 .72339 m .68246 .68934 L .66139 .67669 L p .707 .577 .707 r
F P
0 g
s
.68246 .68934 m .67907 .72339 L .70648 .733 L p .707 .577 .707 r
F P
0 g
s
.29012 .69493 m .29351 .73316 L .26243 .73544 L p .707 .577 .707 r
F P
0 g
s
.26243 .73544 m .25904 .69721 L .29012 .69493 L p .707 .577 .707 r
F P
0 g
s
.23073 .73844 m .22734 .70022 L .25904 .69721 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51248 .74466 L p .707 .577 .707 r
F P
0 g
s
.51248 .74466 m .51248 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.25904 .69721 m .26243 .73544 L .23073 .73844 L p .707 .577 .707 r
F P
0 g
s
.81876 .61326 m .81319 .66377 L .82942 .65208 L p .707 .577 .707 r
F P
0 g
s
.82942 .65208 m .83499 .60156 L .81876 .61326 L p .707 .577 .707 r
F P
0 g
s
.46746 .74551 m .46746 .24362 L .51248 .24277 L p .707 .577 .707 r
F P
0 g
s
.46746 .24362 m .46746 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.6987 .71342 m .70122 .73248 L .7322 .7282 L p .707 .577 .707 r
F P
0 g
s
.7322 .7282 m .72968 .70914 L .6987 .71342 L p .707 .577 .707 r
F P
0 g
s
.72968 .70914 m .7322 .7282 L .76373 .72412 L p .707 .577 .707 r
F P
0 g
s
.64898 .64472 m .65455 .59421 L .64195 .57917 L p .707 .577 .707 r
F P
0 g
s
.65455 .59421 m .64898 .64472 L .66999 .65793 L p .707 .577 .707 r
F P
0 g
s
.76373 .72412 m .76121 .70506 L .72968 .70914 L p .707 .577 .707 r
F P
0 g
s
.51248 .24277 m .51248 .74466 L .46746 .74551 L p .707 .577 .707 r
F P
0 g
s
.76121 .70506 m .76373 .72412 L .79273 .72066 L p .707 .577 .707 r
F P
0 g
s
.79273 .72066 m .79021 .70161 L .76121 .70506 L p .707 .577 .707 r
F P
0 g
s
.66139 .67669 m .65799 .71075 L .67907 .72339 L p .707 .577 .707 r
F P
0 g
s
.82575 .69435 m .82235 .7284 L .83854 .71706 L p .707 .577 .707 r
F P
0 g
s
.83854 .71706 m .84194 .68301 L .82575 .69435 L p .707 .577 .707 r
F P
0 g
s
.67132 .71751 m .67384 .73656 L .70122 .73248 L p .707 .577 .707 r
F P
0 g
s
.70122 .73248 m .6987 .71342 L .67132 .71751 L p .707 .577 .707 r
F P
0 g
s
.65799 .71075 m .66139 .67669 L .64872 .66225 L p .707 .577 .707 r
F P
0 g
s
.79021 .70161 m .79273 .72066 L .81636 .71816 L p .707 .577 .707 r
F P
0 g
s
.81636 .71816 m .81384 .6991 L .79021 .70161 L p .707 .577 .707 r
F P
0 g
s
.6502 .72098 m .65272 .74004 L .67384 .73656 L p .707 .577 .707 r
F P
0 g
s
.67384 .73656 m .67132 .71751 L .6502 .72098 L p .707 .577 .707 r
F P
0 g
s
.83499 .60156 m .82942 .65208 L .83641 .63784 L p .707 .577 .707 r
F P
0 g
s
.83641 .63784 m .84198 .58732 L .83499 .60156 L p .707 .577 .707 r
F P
0 g
s
.64872 .66225 m .64533 .69631 L .65799 .71075 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .63638 .62968 L .64898 .64472 L p .707 .577 .707 r
F P
0 g
s
.84194 .68301 m .83854 .71706 L .84547 .7033 L p .707 .577 .707 r
F P
0 g
s
.84547 .7033 m .84886 .66925 L .84194 .68301 L p .707 .577 .707 r
F P
0 g
s
.64533 .69631 m .64872 .66225 L .6457 .64743 L p .707 .577 .707 r
F P
0 g
s
.81384 .6991 m .81636 .71816 L .83231 .71685 L p .707 .577 .707 r
F P
0 g
s
.83231 .71685 m .82979 .69779 L .81384 .6991 L p .707 .577 .707 r
F P
0 g
s
.63743 .72351 m .63995 .74257 L .65272 .74004 L p .707 .577 .707 r
F P
0 g
s
.65272 .74004 m .6502 .72098 L .63743 .72351 L p .707 .577 .707 r
F P
0 g
s
.6457 .64743 m .64231 .68148 L .64533 .69631 L p .707 .577 .707 r
F P
0 g
s
.84198 .58732 m .83641 .63784 L .83346 .62245 L p .707 .577 .707 r
F P
0 g
s
.83346 .62245 m .83903 .57193 L .84198 .58732 L p .707 .577 .707 r
F P
0 g
s
.639 .56377 m .63343 .61429 L .63638 .62968 L p .707 .577 .707 r
F P
0 g
s
.63343 .61429 m .639 .56377 L .64599 .54953 L p .707 .577 .707 r
F P
0 g
s
.84886 .66925 m .84547 .7033 L .84245 .68848 L p .707 .577 .707 r
F P
0 g
s
.84245 .68848 m .84584 .65443 L .84886 .66925 L p .707 .577 .707 r
F P
0 g
s
.64231 .68148 m .6457 .64743 L .65263 .63368 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.82979 .69779 m .83231 .71685 L .83902 .71686 L p .707 .577 .707 r
F P
0 g
s
.83902 .71686 m .8365 .6978 L .82979 .69779 L p .707 .577 .707 r
F P
0 g
s
.63423 .72485 m .63675 .74391 L .63995 .74257 L p .707 .577 .707 r
F P
0 g
s
.63995 .74257 m .63743 .72351 L .63423 .72485 L p .707 .577 .707 r
F P
0 g
s
.65263 .63368 m .64923 .66773 L .64231 .68148 L p .707 .577 .707 r
F P
0 g
s
.83903 .57193 m .83346 .62245 L .82086 .60741 L p .707 .577 .707 r
F P
0 g
s
.82086 .60741 m .82643 .55689 L .83903 .57193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64599 .54953 m .64042 .60005 L .63343 .61429 L p .707 .577 .707 r
F P
0 g
s
.64042 .60005 m .64599 .54953 L .66222 .53784 L p .707 .577 .707 r
F P
0 g
s
.37786 .61007 m .39068 .55468 L .36033 .5466 L p .707 .577 .707 r
F P
0 g
s
.39068 .55468 m .37786 .61007 L .40892 .61656 L p .707 .577 .707 r
F P
0 g
s
.40892 .61656 m .42174 .56118 L .39068 .55468 L p .707 .577 .707 r
F P
0 g
s
.84584 .65443 m .84245 .68848 L .82978 .67404 L p .707 .577 .707 r
F P
0 g
s
.82978 .67404 m .83318 .63999 L .84584 .65443 L p .707 .577 .707 r
F P
0 g
s
.64923 .66773 m .65263 .63368 L .66882 .62233 L p .707 .577 .707 r
F P
0 g
s
.42174 .56118 m .40892 .61656 L .43764 .62083 L p .707 .577 .707 r
F P
0 g
s
.43764 .62083 m .45046 .56545 L .42174 .56118 L p .707 .577 .707 r
F P
0 g
s
.34751 .60198 m .36033 .5466 L .33366 .53772 L p .707 .577 .707 r
F P
0 g
s
.36033 .5466 m .34751 .60198 L .37786 .61007 L p .707 .577 .707 r
F P
0 g
s
.8365 .6978 m .83902 .71686 L .83583 .7182 L p .707 .577 .707 r
F P
0 g
s
.83583 .7182 m .83331 .69914 L .8365 .6978 L p .707 .577 .707 r
F P
0 g
s
.33366 .53772 m .32084 .5931 L .34751 .60198 L p .707 .577 .707 r
F P
0 g
s
.45046 .56545 m .43764 .62083 L .46122 .62246 L p .707 .577 .707 r
F P
0 g
s
.46122 .62246 m .47404 .56707 L .45046 .56545 L p .707 .577 .707 r
F P
0 g
s
.82643 .55689 m .82086 .60741 L .79985 .5942 L p .707 .577 .707 r
F P
0 g
s
.79985 .5942 m .80542 .54368 L .82643 .55689 L p .707 .577 .707 r
F P
0 g
s
.66882 .62233 m .66543 .65639 L .64923 .66773 L p .707 .577 .707 r
F P
0 g
s
.32084 .5931 m .33366 .53772 L .31328 .52891 L p .707 .577 .707 r
F P
0 g
s
.66222 .53784 m .65665 .58836 L .64042 .60005 L p .707 .577 .707 r
F P
0 g
s
.65665 .58836 m .66222 .53784 L .68612 .52984 L p .707 .577 .707 r
F P
0 g
s
.64094 .72487 m .64346 .74393 L .63675 .74391 L p .707 .577 .707 r
F P
0 g
s
.63675 .74391 m .63423 .72485 L .64094 .72487 L p .707 .577 .707 r
F P
0 g
s
.83318 .63999 m .82978 .67404 L .80871 .6614 L p .707 .577 .707 r
F P
0 g
s
.80871 .6614 m .8121 .62734 L .83318 .63999 L p .707 .577 .707 r
F P
0 g
s
.39907 .66939 m .40689 .63237 L .37639 .62482 L p .707 .577 .707 r
F P
0 g
s
.40689 .63237 m .39907 .66939 L .43024 .67525 L p .707 .577 .707 r
F P
0 g
s
.43024 .67525 m .43807 .63822 L .40689 .63237 L p .707 .577 .707 r
F P
0 g
s
.66543 .65639 m .66882 .62233 L .69269 .61452 L p .707 .577 .707 r
F P
0 g
s
.31328 .52891 m .30046 .58429 L .32084 .5931 L p .707 .577 .707 r
F P
0 g
s
.43807 .63822 m .43024 .67525 L .45904 .67885 L p .707 .577 .707 r
F P
0 g
s
.45904 .67885 m .46687 .64182 L .43807 .63822 L p .707 .577 .707 r
F P
0 g
s
.36856 .66185 m .37639 .62482 L .34955 .61633 L p .707 .577 .707 r
F P
0 g
s
.37639 .62482 m .36856 .66185 L .39907 .66939 L p .707 .577 .707 r
F P
0 g
s
.47404 .56707 m .46122 .62246 L .47735 .62128 L p .707 .577 .707 r
F P
0 g
s
.47735 .62128 m .49017 .5659 L .47404 .56707 L p .707 .577 .707 r
F P
0 g
s
.80542 .54368 m .79985 .5942 L .77249 .5841 L p .707 .577 .707 r
F P
0 g
s
.77249 .5841 m .77806 .53359 L .80542 .54368 L p .707 .577 .707 r
F P
0 g
s
.41531 .72759 m .40958 .71069 L .37918 .72049 L p .707 .577 .707 r
F P
0 g
s
.40958 .71069 m .41531 .72759 L .44342 .71466 L p .707 .577 .707 r
F P
0 g
s
.44342 .71466 m .43769 .69776 L .40958 .71069 L p .707 .577 .707 r
F P
0 g
s
.68055 .58035 m .68612 .52984 L .71534 .52631 L p .707 .577 .707 r
F P
0 g
s
.68612 .52984 m .68055 .58035 L .65665 .58836 L p .707 .577 .707 r
F P
0 g
s
.34955 .61633 m .34172 .65336 L .36856 .66185 L p .707 .577 .707 r
F P
0 g
s
.38491 .73739 m .37918 .72049 L .34945 .7262 L p .707 .577 .707 r
F P
0 g
s
.37918 .72049 m .38491 .73739 L .41531 .72759 L p .707 .577 .707 r
F P
0 g
s
.83331 .69914 m .83583 .7182 L .82305 .72073 L p .707 .577 .707 r
F P
0 g
s
.82305 .72073 m .82053 .70167 L .83331 .69914 L p .707 .577 .707 r
F P
0 g
s
.30046 .58429 m .31328 .52891 L .30118 .52103 L p .707 .577 .707 r
F P
0 g
s
.46687 .64182 m .45904 .67885 L .48265 .67983 L p .707 .577 .707 r
F P
0 g
s
.48265 .67983 m .49048 .64281 L .46687 .64182 L p .707 .577 .707 r
F P
0 g
s
.69269 .61452 m .6893 .64857 L .66543 .65639 L p .707 .577 .707 r
F P
0 g
s
.8121 .62734 m .80871 .6614 L .78129 .65179 L p .707 .577 .707 r
F P
0 g
s
.78129 .65179 m .78469 .61773 L .8121 .62734 L p .707 .577 .707 r
F P
0 g
s
.6893 .64857 m .69269 .61452 L .72191 .61099 L p .707 .577 .707 r
F P
0 g
s
.43769 .69776 m .44342 .71466 L .46648 .69986 L p .707 .577 .707 r
F P
0 g
s
.46648 .69986 m .46075 .68296 L .43769 .69776 L p .707 .577 .707 r
F P
0 g
s
.34945 .7262 m .35518 .7431 L .38491 .73739 L p .707 .577 .707 r
F P
0 g
s
.34172 .65336 m .34955 .61633 L .329 .60772 L p .707 .577 .707 r
F P
0 g
s
.35518 .7431 m .34945 .7262 L .32332 .72726 L p .707 .577 .707 r
F P
0 g
s
.77806 .53359 m .77249 .5841 L .74145 .57812 L p .707 .577 .707 r
F P
0 g
s
.74145 .57812 m .74702 .5276 L .77806 .53359 L p .707 .577 .707 r
F P
0 g
s
.70977 .57683 m .71534 .52631 L .74702 .5276 L p .707 .577 .707 r
F P
0 g
s
.71534 .52631 m .70977 .57683 L .68055 .58035 L p .707 .577 .707 r
F P
0 g
s
.65689 .72356 m .65941 .74262 L .64346 .74393 L p .707 .577 .707 r
F P
0 g
s
.64346 .74393 m .64094 .72487 L .65689 .72356 L p .707 .577 .707 r
F P
0 g
s
.30118 .52103 m .28836 .57642 L .30046 .58429 L p .707 .577 .707 r
F P
0 g
s
.329 .60772 m .32117 .64475 L .34172 .65336 L p .707 .577 .707 r
F P
0 g
s
.74702 .5276 m .74145 .57812 L .70977 .57683 L p .707 .577 .707 r
F P
0 g
s
.32332 .72726 m .32904 .74416 L .35518 .7431 L p .707 .577 .707 r
F P
0 g
s
.78469 .61773 m .78129 .65179 L .75021 .64615 L p .707 .577 .707 r
F P
0 g
s
.75021 .64615 m .75361 .6121 L .78469 .61773 L p .707 .577 .707 r
F P
0 g
s
.71851 .64504 m .72191 .61099 L .75361 .6121 L p .707 .577 .707 r
F P
0 g
s
.72191 .61099 m .71851 .64504 L .6893 .64857 L p .707 .577 .707 r
F P
0 g
s
.75361 .6121 m .75021 .64615 L .71851 .64504 L p .707 .577 .707 r
F P
0 g
s
.46075 .68296 m .46648 .69986 L .48223 .68465 L p .707 .577 .707 r
F P
0 g
s
.48223 .68465 m .4765 .66775 L .46075 .68296 L p .707 .577 .707 r
F P
0 g
s
.49017 .5659 m .47735 .62128 L .48444 .61742 L p .707 .577 .707 r
F P
0 g
s
.48444 .61742 m .49726 .56203 L .49017 .5659 L p .707 .577 .707 r
F P
0 g
s
.49048 .64281 m .48265 .67983 L .49875 .67811 L p .707 .577 .707 r
F P
0 g
s
.49875 .67811 m .50658 .64108 L .49048 .64281 L p .707 .577 .707 r
F P
0 g
s
.32904 .74416 m .32332 .72726 L .30333 .72357 L p .707 .577 .707 r
F P
0 g
s
.82053 .70167 m .82305 .72073 L .80193 .72421 L p .707 .577 .707 r
F P
0 g
s
.32117 .64475 m .329 .60772 L .31675 .59984 L p .707 .577 .707 r
F P
0 g
s
.28836 .57642 m .30118 .52103 L .29854 .51486 L p .707 .577 .707 r
F P
0 g
s
.80193 .72421 m .79941 .70515 L .82053 .70167 L p .707 .577 .707 r
F P
0 g
s
.30333 .72357 m .30905 .74047 L .32904 .74416 L p .707 .577 .707 r
F P
0 g
s
.31675 .59984 m .30892 .63687 L .32117 .64475 L p .707 .577 .707 r
F P
0 g
s
.68052 .72105 m .68304 .74011 L .65941 .74262 L p .707 .577 .707 r
F P
0 g
s
.65941 .74262 m .65689 .72356 L .68052 .72105 L p .707 .577 .707 r
F P
0 g
s
.29854 .51486 m .28572 .57024 L .28836 .57642 L p .707 .577 .707 r
F P
0 g
s
.4765 .66775 m .48223 .68465 L .48914 .67051 L p .707 .577 .707 r
F P
0 g
s
.48914 .67051 m .48341 .65361 L .4765 .66775 L p .707 .577 .707 r
F P
0 g
s
.30905 .74047 m .30333 .72357 L .29144 .71548 L p .707 .577 .707 r
F P
0 g
s
.50658 .64108 m .49875 .67811 L .50577 .67385 L p .707 .577 .707 r
F P
0 g
s
.50577 .67385 m .51359 .63682 L .50658 .64108 L p .707 .577 .707 r
F P
0 g
s
.79941 .70515 m .80193 .72421 L .77455 .72829 L p .707 .577 .707 r
F P
0 g
s
.77455 .72829 m .77203 .70923 L .79941 .70515 L p .707 .577 .707 r
F P
0 g
s
.49726 .56203 m .48444 .61742 L .48181 .61125 L p .707 .577 .707 r
F P
0 g
s
.48181 .61125 m .49463 .55586 L .49726 .56203 L p .707 .577 .707 r
F P
0 g
s
.30892 .63687 m .31675 .59984 L .314 .59346 L p .707 .577 .707 r
F P
0 g
s
.29144 .71548 m .29717 .73239 L .30905 .74047 L p .707 .577 .707 r
F P
0 g
s
.70953 .71759 m .71205 .73665 L .68304 .74011 L p .707 .577 .707 r
F P
0 g
s
.68304 .74011 m .68052 .72105 L .70953 .71759 L p .707 .577 .707 r
F P
0 g
s
.28572 .57024 m .29854 .51486 L .30564 .511 L p .707 .577 .707 r
F P
0 g
s
.314 .59346 m .30617 .63048 L .30892 .63687 L p .707 .577 .707 r
F P
0 g
s
.77203 .70923 m .77455 .72829 L .74358 .73258 L p .707 .577 .707 r
F P
0 g
s
.74358 .73258 m .74106 .71352 L .77203 .70923 L p .707 .577 .707 r
F P
0 g
s
.30564 .511 m .29282 .56638 L .28572 .57024 L p .707 .577 .707 r
F P
0 g
s
.74106 .71352 m .74358 .73258 L .71205 .73665 L p .707 .577 .707 r
F P
0 g
s
.71205 .73665 m .70953 .71759 L .74106 .71352 L p .707 .577 .707 r
F P
0 g
s
.48341 .65361 m .48914 .67051 L .48652 .65882 L p .707 .577 .707 r
F P
0 g
s
.48652 .65882 m .48079 .64192 L .48341 .65361 L p .707 .577 .707 r
F P
0 g
s
.29717 .73239 m .29144 .71548 L .28882 .7038 L p .707 .577 .707 r
F P
0 g
s
.51359 .63682 m .50577 .67385 L .50301 .66746 L p .707 .577 .707 r
F P
0 g
s
.50301 .66746 m .51084 .63043 L .51359 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49463 .55586 m .48181 .61125 L .46971 .60337 L p .707 .577 .707 r
F P
0 g
s
.46971 .60337 m .48253 .54799 L .49463 .55586 L p .707 .577 .707 r
F P
0 g
s
.28882 .7038 m .29455 .7207 L .29717 .73239 L p .707 .577 .707 r
F P
0 g
s
.30617 .63048 m .314 .59346 L .32101 .58919 L p .707 .577 .707 r
F P
0 g
s
.29282 .56638 m .30564 .511 L .32176 .50982 L p .707 .577 .707 r
F P
0 g
s
.32101 .58919 m .31319 .62622 L .30617 .63048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32176 .50982 m .30894 .56521 L .29282 .56638 L p .707 .577 .707 r
F P
0 g
s
.48079 .64192 m .48652 .65882 L .47463 .65074 L p .707 .577 .707 r
F P
0 g
s
.47463 .65074 m .4689 .63384 L .48079 .64192 L p .707 .577 .707 r
F P
0 g
s
.29455 .7207 m .28882 .7038 L .29573 .68966 L p .707 .577 .707 r
F P
0 g
s
.48253 .54799 m .46971 .60337 L .44932 .59456 L p .707 .577 .707 r
F P
0 g
s
.44932 .59456 m .46214 .53918 L .48253 .54799 L p .707 .577 .707 r
F P
0 g
s
.51084 .63043 m .50301 .66746 L .49076 .65958 L p .707 .577 .707 r
F P
0 g
s
.49076 .65958 m .49859 .62255 L .51084 .63043 L p .707 .577 .707 r
F P
0 g
s
.29573 .68966 m .30145 .70656 L .29455 .7207 L p .707 .577 .707 r
F P
0 g
s
.30894 .56521 m .32176 .50982 L .34534 .51145 L p .707 .577 .707 r
F P
0 g
s
.31319 .62622 m .32101 .58919 L .33711 .58747 L p .707 .577 .707 r
F P
0 g
s
.33711 .58747 m .32929 .6245 L .31319 .62622 L p .707 .577 .707 r
F P
0 g
s
.34534 .51145 m .33252 .56683 L .30894 .56521 L p .707 .577 .707 r
F P
0 g
s
.4689 .63384 m .47463 .65074 L .45464 .64705 L p .707 .577 .707 r
F P
0 g
s
.45464 .64705 m .44891 .63014 L .4689 .63384 L p .707 .577 .707 r
F P
0 g
s
.46214 .53918 m .44932 .59456 L .42265 .58568 L p .707 .577 .707 r
F P
0 g
s
.42265 .58568 m .43547 .53029 L .46214 .53918 L p .707 .577 .707 r
F P
0 g
s
.30145 .70656 m .29573 .68966 L .31148 .67444 L p .707 .577 .707 r
F P
0 g
s
.33252 .56683 m .34534 .51145 L .37406 .51572 L p .707 .577 .707 r
F P
0 g
s
.49859 .62255 m .49076 .65958 L .47021 .65097 L p .707 .577 .707 r
F P
0 g
s
.47021 .65097 m .47804 .61394 L .49859 .62255 L p .707 .577 .707 r
F P
0 g
s
.31148 .67444 m .31721 .69135 L .30145 .70656 L p .707 .577 .707 r
F P
0 g
s
.32929 .6245 m .33711 .58747 L .36072 .58845 L p .707 .577 .707 r
F P
0 g
s
.37406 .51572 m .36125 .5711 L .33252 .56683 L p .707 .577 .707 r
F P
0 g
s
.43547 .53029 m .42265 .58568 L .3923 .5776 L p .707 .577 .707 r
F P
0 g
s
.3923 .5776 m .40512 .52221 L .43547 .53029 L p .707 .577 .707 r
F P
0 g
s
.36125 .5711 m .37406 .51572 L .40512 .52221 L p .707 .577 .707 r
F P
0 g
s
.36072 .58845 m .35289 .62548 L .32929 .6245 L p .707 .577 .707 r
F P
0 g
s
.44891 .63014 m .45464 .64705 L .4285 .64811 L p .707 .577 .707 r
F P
0 g
s
.4285 .64811 m .42278 .6312 L .44891 .63014 L p .707 .577 .707 r
F P
0 g
s
.40512 .52221 m .3923 .5776 L .36125 .5711 L p .707 .577 .707 r
F P
0 g
s
.31721 .69135 m .31148 .67444 L .33454 .65965 L p .707 .577 .707 r
F P
0 g
s
.47804 .61394 m .47021 .65097 L .44337 .64248 L p .707 .577 .707 r
F P
0 g
s
.44337 .64248 m .4512 .60545 L .47804 .61394 L p .707 .577 .707 r
F P
0 g
s
.33454 .65965 m .34026 .67655 L .31721 .69135 L p .707 .577 .707 r
F P
0 g
s
.35289 .62548 m .36072 .58845 L .38952 .59205 L p .707 .577 .707 r
F P
0 g
s
.42278 .6312 m .4285 .64811 L .39878 .65382 L p .707 .577 .707 r
F P
0 g
s
.39878 .65382 m .39305 .63691 L .42278 .6312 L p .707 .577 .707 r
F P
0 g
s
.38952 .59205 m .38169 .62908 L .35289 .62548 L p .707 .577 .707 r
F P
0 g
s
.34026 .67655 m .33454 .65965 L .36265 .64671 L p .707 .577 .707 r
F P
0 g
s
.4512 .60545 m .44337 .64248 L .41287 .63493 L p .707 .577 .707 r
F P
0 g
s
.41287 .63493 m .4207 .59791 L .4512 .60545 L p .707 .577 .707 r
F P
0 g
s
.38169 .62908 m .38952 .59205 L .4207 .59791 L p .707 .577 .707 r
F P
0 g
s
.39305 .63691 m .39878 .65382 L .36837 .66362 L p .707 .577 .707 r
F P
0 g
s
.36837 .66362 m .36265 .64671 L .39305 .63691 L p .707 .577 .707 r
F P
0 g
s
.36265 .64671 m .36837 .66362 L .34026 .67655 L p .707 .577 .707 r
F P
0 g
s
.4207 .59791 m .41287 .63493 L .38169 .62908 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Iooa00009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00E7oo0`0015YF00<005YFFUH015YF00@005YFFUIJEPL0
009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00moo`P004eoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool02Goo1P000eYF00<005YFFUH00UYF2@00A7oo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01Goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol00goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003aoo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol00Woo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH01UYF00@005YFFUIJEP8003Yoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF
0P00>7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool00003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF000eOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00<goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<007ooOol0<7oo001BOol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000aOol0055oo`03001JEP00009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0000`Ool0055oo`03001JEP0000<000AJEPL000AJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000_Ool0055oo`8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP05001J
EUYFFUH0000^Ool0055oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPl000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool005=oo`<0
00IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF1P003goo10000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Goo001EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000<001Uoo`@000IJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001GOol300000eYF0000000=0002FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH2000QOol40002FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00FGoo0`000eYF00<005YFFUH015YF00@005YFFUIJ
EPL000AJEP03001JEUYF00AJEP800003FUH005YF00EJEP06001JEUYF001JEP001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0002FUH2000VOol30005FUH01`00
FUIJEUYF001JEP0002eoo`00FGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01@0025YF0`0015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYF001JEP03000015YF0000000057oo0`0047oo0P000eYF00L005YFFUIJ
EP00FUH0000]Ool005Uoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00=JEP04001JEUYFFUH300000eYF001JEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP04001JEUYF000BOol5000AOol01000FUIJEP000eYF
00<005YF0000;Goo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040006FUH20003FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF0P0047oo1@004Woo0`000eYF0P00;Woo001H
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40002FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH2000>Ool5000DOol01000FUIJEUYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01000FUH000001Goo2`005Goo0P000UYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP060004FUH00`00FUIJEP02FUH9000<
Ool200001UYF001JEP00FUH002ioo`00F7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000Woo100000AJEP00FUIJEP800003FUH007oo02eo
o`00D7oo200000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH00`00FUIJEP0200000eYF001oo`0]Ool004Mo
o`T000AJEP06001JEUYF001JEP000UYF300015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00L005YFFUIJEP00FUH0000^Ool003moo`P000AJEP03001JEUYF
00IJEP05001JEUYF001JEP040005FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEP0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH5
0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P000eYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P00;goo000aOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00UYF2P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0002FUH2000_Ool002aoo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000IJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH015YF1@0000=JEP00
FUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo02ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF
0P000eYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF009JEQ0000IJEP03001J
EUYF00AJEP03001JEUYF00AJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH00UYF0`00
25YF00<005YFFUH00eYF3P0000=JEP00FUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF1P001eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF0000;Woo000/Ool00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH60005FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YF
00000P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF0P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00D005YFFUIJEP0002aoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00008000EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP@000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<0009JEP800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP06001JEP00001JEP001EYF00<005YFFUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30008FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF
10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP03001oogoo02Yoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF0`00
0UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF0080
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000006
FUH01000FUIJEUYF1@001UYF00<005YF00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@000=J
EP03001JEUYF009JEP8002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P001EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEP0000800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP03
001JEUYF00D0009JEPH000=JEP03001JEUYF00EJEP04001JEP000004Ool200000eYF001JEP03FUH2
000[Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000MJEP06001JEP00001JEP000UYF00<005YFFUH015YF00<005YFFUH0
0UYF10000UYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP00009JEP05001JEP00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF00000eYF00@007ooOomoo`P000=JEP03001JEUYF009JEPD000Qoo`8000=JEP03001JEP0002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001eYF1P000UYF00<005YFFUH015YF00<005YFFUH01UYF1P0015YF00<005YF00000eYF
00@005YF001JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEPP000=JEP04001JEUYF0006Ool=000?Ool01P00FUIJEP00FUH002]oo`00
;Goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@000UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP80009JEP03001JEUYF00AJEP<000IJEP03
001JEUYF00=JEPH000EJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP<000=JEP06001JEP00001JEP000UYF00<007ooOol01Goo0`006Goo00D0
05YF001JEP0002]oo`00;Woo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF4`00
0eYF00@005YFFUH000=JEPL00005Ool005YFFUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP000UYF00@005YFFUIJEP80009JEP8002=oo`800003FUH007oo02Yo
o`00;Woo0UYF00<005YFFUH00UYF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04001JEUYF0004
FUH40007Ool01000FUIJEP001EYF1@001EYF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUIJ
EP<000EJEP800003FUH007oo025oo`@002aoo`00;Woo0UYF00<005YFFUH01P001eYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`001EYF00<007ooOol027oo00@005YFFUH000EJEPD000EJEP03001JEUYF
00AJEP05001JEUYFFUH00003FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF0P0015YF00@005YF0000021oo`80009J
EP8002aoo`00;Woo0UYF0`001EYF00<005YFFUH00UYF600015YF3@000UYF00<005YFFUH015YF0`00
1UYF00<005YFFUH00UYF0P0015YF00@005YFFUH000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUH000040002FUH00`00Oomo
o`0LOol20004FUH2000/Ool002ioo`l000Qoo`T000AJEP<0009JEP800003FUH005YF00AJEP03001J
EUYF00<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP05001JEUYFFUH00007FUH2000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF
00<005YFFUH00eYF1@0067oo2P0000=JEP000000;7oo000mOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUH000020007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH010003Goo1`00
0eYF100000IJEP00000005YF000/Ool003Eoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH=0003FUH70002
FUH00`00FUIJEP04000]Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00AJEP03001J
EUYF00AJEP8000EJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUH000080003
FUH90003FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00;Goo000ZOol50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH30003FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP03FUH01000FUIJEUYF1P0015YF200015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH00eYF10000UYF00<005YFFUH01UYF0P001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0009JEP8000=JEP@00003FUH005YF
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEP0000<000MJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0002FUH50005FUH60006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF1`00;goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06
00000eYF001JEP08FUH00`00FUIJEP030009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF1@000UYF00@005YF0000031oo`00:Woo00<005YF000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEPd000IJEP03001JEUYF
00IJEP@000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEP0000@000IJEP80039oo`00:Woo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH2000cOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@000UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHD
0002FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPP0009JEP03001JEUYF00IJEP03001JEUYF009JEPD003Uoo`00
:goo00<005YF000015YF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEP000080009JEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF
00@005YFFUIJEPP000Qooa0003ioo`00:goo00<005YF00000UYF1`001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF3@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF5P001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02`0000EJEP00FUIJEP00
05Uoo`00:goo00<005YF00000`000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF009J
EPT0009oo`8000=JEP03001JEUYF009JEP80009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<005YFFUH00UYF100017oo
0`000eYF00<007ooOol0EWoo000[Ool20002FUH01000FUH000000eYF00<005YFFUH00UYF4@003Goo
0P0000=JEP00FUH01EYF00<007oo00000UYF00<005YFFUH015YF00<005YFFUH015YF1P000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1P000UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol017oo0P000UYF0P0000=JEP00Ool0Egoo000/Ool?000POol20006FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUH00003FUH40006FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUIJEP02FUH01000
FUH00000F7oo000^Ool2000]Ool20004FUH00`00FUH00002FUH00`00FUIJEP03FUH400000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH01000Oomoogoo0`0015YF00@005YFFUH005Qoo`00;Woo0P00;goo00@005YFFUH0
009JEP04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH300000eYF001JEP03FUH01000Ool000000UYF00<005YFFUH0
0UYF00D005YFFUIJEP0005Moo`00;Woo00<007ooOol0;goo0`000UYF00D005YFFUH005YF008000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF008000AJEP8000EJEP03001JEUYF009JEP04001JEUYF001GOol002eoo`<0039oo`04
001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0001HOol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP02FUH00`00FUH0001HOol002eoo`03
001JEP0001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH0
0`00FUIJEP03FUH00`00Oomoo`1GOol002eoo`04001JEP00000FOol5000HOol30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH00eYF00<007ooOol0Egoo000]Ool0
1@00FUH005YF00005Goo1@006Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00MJEP03001JEUYF008005Yoo`00;Woo00@005YFFUH001Ioo`<001Yoo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0007FUH3001LOol002ioo`05001JEUYFFUH0000cOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<007ooOol0G7oo000^Ool0
0`00FUIJEP02FUH00`00Oomoo`0`Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF001JEP04FUH2001OOol002moo`04001JEUYFFUH3000`Ool30002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP02001QOol0031oo`04001JEUYF0002FUH00`00Oomoo`0]
Ool2000017oo000000001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF2000Hgoo000`Ool00`00FUH00004FUH2000]Ool2
0003Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUH000020005FUH3001SOol0035oo`8000IJEP03001oogoo02Uoo`8000Io
o`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP<000UJEP04001JEP00001QOol0039oo`03001JEUYF00AJEP<002Moo`@000Qoo`<00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0
00QJEP04001JEUYFFUH3001NOol003=oo`8000AJEP03001JEUYF008002Aoo`04001JEUYF000<Ool7
0005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0000=0004FUH00`00
FUIJEP05FUH2001LOol003Eoo`04001JEUYF0005FUH2000POol20003FUH00`00Oomoo`0AOol;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004FUH60004Ool300000eYF001JEP07FUH3001JOol0
03Ioo`<000MJEP<001Uoo`@00005FUH005YFFUH0000OOolM00000eYF001JEP05FUH500000eYF0000
00020003Ool30006FUH01000FUIJEUYF0P00F7oo000hOol20006FUH00`00FUIJEP04000@Ool50004
FUH01000FUH00000<Goo3`001UYF0`001UYF10000Woo0P0015YF00<005YFFUH00eYF0P00EWoo000j
Ool20004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH20012Ool20005FUH00`00FUIJEP07
FUH00`00FUH0000500000eYF001JEP06FUH3001DOol003aoo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo04=oo`<00003FUH005YF00QJEP03001J
EUYF00AJEP@000IJEP05001JEUYFFUH0001COol003moo`<000IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH20019Ool30008FUH00`00FUIJEP06FUH01000FUH0000015YF00@005YFFUIJ
EP80059oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000004ioo`<000EJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEP00059oo`00AWoo1`00
15YF00<005YFFUH00UYF1P00Dgoo0`0000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF0P00Dgoo
001=Ool9001LOol30007FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001oo`1BOol00;Eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00^Goo1P000eYF00L005YFFUIJEP00FUH0
001DOol00;moo`T005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63875 .7505 m .62593 .698 L .59488 .70557 L p .707 .577 .707 r
F P
0 g
s
.62593 .698 m .63875 .7505 L .66747 .73994 L p .707 .577 .707 r
F P
0 g
s
.66747 .73994 m .65466 .68743 L .62593 .698 L p .707 .577 .707 r
F P
0 g
s
.60769 .75808 m .59488 .70557 L .56453 .70941 L p .707 .577 .707 r
F P
0 g
s
.59488 .70557 m .60769 .75808 L .63875 .7505 L p .707 .577 .707 r
F P
0 g
s
.65466 .68743 m .66747 .73994 L .69105 .72742 L p .707 .577 .707 r
F P
0 g
s
.69105 .72742 m .67823 .67491 L .65466 .68743 L p .707 .577 .707 r
F P
0 g
s
.57734 .76192 m .56453 .70941 L .53785 .70915 L p .707 .577 .707 r
F P
0 g
s
.56453 .70941 m .57734 .76192 L .60769 .75808 L p .707 .577 .707 r
F P
0 g
s
.58713 .82027 m .5793 .78501 L .5488 .78843 L p .707 .577 .707 r
F P
0 g
s
.5793 .78501 m .58713 .82027 L .61831 .81321 L p .707 .577 .707 r
F P
0 g
s
.61831 .81321 m .61048 .77796 L .5793 .78501 L p .707 .577 .707 r
F P
0 g
s
.61048 .77796 m .61831 .81321 L .64711 .80321 L p .707 .577 .707 r
F P
0 g
s
.64711 .80321 m .63928 .76795 L .61048 .77796 L p .707 .577 .707 r
F P
0 g
s
.55663 .82368 m .5488 .78843 L .52196 .78786 L p .707 .577 .707 r
F P
0 g
s
.5488 .78843 m .55663 .82368 L .58713 .82027 L p .707 .577 .707 r
F P
0 g
s
.63928 .76795 m .64711 .80321 L .67071 .79123 L p .707 .577 .707 r
F P
0 g
s
.67071 .79123 m .66288 .75598 L .63928 .76795 L p .707 .577 .707 r
F P
0 g
s
.67823 .67491 m .69105 .72742 L .70718 .71417 L p .707 .577 .707 r
F P
0 g
s
.70718 .71417 m .69436 .66166 L .67823 .67491 L p .707 .577 .707 r
F P
0 g
s
.55067 .76165 m .53785 .70915 L .51747 .7048 L p .707 .577 .707 r
F P
0 g
s
.53785 .70915 m .55067 .76165 L .57734 .76192 L p .707 .577 .707 r
F P
0 g
s
.60122 .83553 m .60695 .81735 L .57722 .80715 L p .707 .577 .707 r
F P
0 g
s
.60695 .81735 m .60122 .83553 L .63162 .84452 L p .707 .577 .707 r
F P
0 g
s
.63162 .84452 m .63735 .82635 L .60695 .81735 L p .707 .577 .707 r
F P
0 g
s
.52196 .78786 m .52979 .82312 L .55663 .82368 L p .707 .577 .707 r
F P
0 g
s
.57722 .80715 m .57149 .82532 L .60122 .83553 L p .707 .577 .707 r
F P
0 g
s
.63735 .82635 m .63162 .84452 L .65973 .85144 L p .707 .577 .707 r
F P
0 g
s
.65973 .85144 m .66546 .83326 L .63735 .82635 L p .707 .577 .707 r
F P
0 g
s
.52979 .82312 m .52196 .78786 L .50141 .78338 L p .707 .577 .707 r
F P
0 g
s
.57149 .82532 m .57722 .80715 L .55108 .79674 L p .707 .577 .707 r
F P
0 g
s
.66288 .75598 m .67071 .79123 L .68681 .77846 L p .707 .577 .707 r
F P
0 g
s
.68681 .77846 m .67898 .7432 L .66288 .75598 L p .707 .577 .707 r
F P
0 g
s
.55108 .79674 m .54536 .81492 L .57149 .82532 L p .707 .577 .707 r
F P
0 g
s
.51747 .7048 m .53029 .75731 L .55067 .76165 L p .707 .577 .707 r
F P
0 g
s
.69436 .66166 m .70718 .71417 L .71427 .70148 L p .707 .577 .707 r
F P
0 g
s
.71427 .70148 m .70145 .64898 L .69436 .66166 L p .707 .577 .707 r
F P
0 g
s
.53029 .75731 m .51747 .7048 L .50537 .6968 L p .707 .577 .707 r
F P
0 g
s
.66546 .83326 m .65973 .85144 L .68279 .85559 L p .707 .577 .707 r
F P
0 g
s
.68279 .85559 m .68852 .83741 L .66546 .83326 L p .707 .577 .707 r
F P
0 g
s
.50141 .78338 m .50924 .81864 L .52979 .82312 L p .707 .577 .707 r
F P
0 g
s
.54536 .81492 m .55108 .79674 L .53109 .78715 L p .707 .577 .707 r
F P
0 g
s
.53109 .78715 m .52537 .80532 L .54536 .81492 L p .707 .577 .707 r
F P
0 g
s
.50924 .81864 m .50141 .78338 L .48916 .77542 L p .707 .577 .707 r
F P
0 g
s
.67898 .7432 m .68681 .77846 L .69383 .76613 L p .707 .577 .707 r
F P
0 g
s
.69383 .76613 m .686 .73088 L .67898 .7432 L p .707 .577 .707 r
F P
0 g
s
.50537 .6968 m .51819 .74931 L .53029 .75731 L p .707 .577 .707 r
F P
0 g
s
.68852 .83741 m .68279 .85559 L .69854 .85657 L p .707 .577 .707 r
F P
0 g
s
.69854 .85657 m .70427 .8384 L .68852 .83741 L p .707 .577 .707 r
F P
0 g
s
.48916 .77542 m .49698 .81067 L .50924 .81864 L p .707 .577 .707 r
F P
0 g
s
.70145 .64898 m .71427 .70148 L .71164 .69061 L p .698 .572 .709 r
F P
0 g
s
.71164 .69061 m .69882 .6381 L .70145 .64898 L p .698 .572 .709 r
F P
0 g
s
.51819 .74931 m .50537 .6968 L .50274 .68593 L p .698 .572 .709 r
F P
0 g
s
.52537 .80532 m .53109 .78715 L .51921 .77931 L p .707 .577 .707 r
F P
0 g
s
.51921 .77931 m .51348 .79748 L .52537 .80532 L p .707 .577 .707 r
F P
0 g
s
.49698 .81067 m .48916 .77542 L .4864 .76476 L p .708 .578 .707 r
F P
0 g
s
.686 .73088 m .69383 .76613 L .69108 .75547 L p .708 .578 .707 r
F P
0 g
s
.69108 .75547 m .68325 .72022 L .686 .73088 L p .708 .578 .707 r
F P
0 g
s
.4864 .76476 m .49423 .80001 L .49698 .81067 L p .708 .578 .707 r
F P
0 g
s
.49423 .80001 m .4864 .76476 L .49342 .75243 L p .707 .577 .707 r
F P
0 g
s
.48752 .82178 m .48752 .31989 L .44372 .31697 L p .707 .577 .707 r
F P
0 g
s
.50274 .68593 m .51556 .73843 L .51819 .74931 L p .698 .572 .709 r
F P
0 g
s
.51348 .79748 m .51921 .77931 L .51659 .77399 L p .707 .577 .707 r
F P
0 g
s
.51556 .73843 m .50274 .68593 L .50983 .67324 L p .707 .577 .707 r
F P
0 g
s
.51659 .77399 m .51086 .79216 L .51348 .79748 L p .707 .577 .707 r
F P
0 g
s
.50983 .67324 m .52265 .72575 L .51556 .73843 L p .707 .577 .707 r
F P
0 g
s
.49342 .75243 m .50125 .78769 L .49423 .80001 L p .707 .577 .707 r
F P
0 g
s
.52265 .72575 m .50983 .67324 L .52596 .65999 L p .707 .577 .707 r
F P
0 g
s
.51086 .79216 m .51659 .77399 L .52349 .77171 L p .707 .577 .707 r
F P
0 g
s
.52349 .77171 m .51777 .78988 L .51086 .79216 L p .707 .577 .707 r
F P
0 g
s
.50125 .78769 m .49342 .75243 L .50952 .73966 L p .707 .577 .707 r
F P
0 g
s
.52596 .65999 m .53878 .7125 L .52265 .72575 L p .707 .577 .707 r
F P
0 g
s
.50952 .73966 m .51735 .77491 L .50125 .78769 L p .707 .577 .707 r
F P
0 g
s
.51777 .78988 m .52349 .77171 L .53925 .77269 L p .707 .577 .707 r
F P
0 g
s
.53925 .77269 m .53352 .79087 L .51777 .78988 L p .707 .577 .707 r
F P
0 g
s
.51735 .77491 m .50952 .73966 L .53313 .72768 L p .707 .577 .707 r
F P
0 g
s
.53313 .72768 m .54095 .76294 L .51735 .77491 L p .707 .577 .707 r
F P
0 g
s
.48752 .31989 m .48752 .82178 L .53253 .82093 L p .707 .577 .707 r
F P
0 g
s
.53878 .7125 m .52596 .65999 L .54954 .64747 L p .707 .577 .707 r
F P
0 g
s
.53253 .82093 m .53253 .31904 L .48752 .31989 L p .707 .577 .707 r
F P
0 g
s
.56235 .69998 m .54954 .64747 L .57826 .63691 L p .707 .577 .707 r
F P
0 g
s
.54954 .64747 m .56235 .69998 L .53878 .7125 L p .707 .577 .707 r
F P
0 g
s
.57826 .63691 m .59108 .68941 L .56235 .69998 L p .707 .577 .707 r
F P
0 g
s
.54095 .76294 m .53313 .72768 L .56193 .71768 L p .707 .577 .707 r
F P
0 g
s
.53352 .79087 m .53925 .77269 L .56231 .77684 L p .707 .577 .707 r
F P
0 g
s
.56231 .77684 m .55658 .79502 L .53352 .79087 L p .707 .577 .707 r
F P
0 g
s
.56975 .75293 m .56193 .71768 L .5931 .71062 L p .707 .577 .707 r
F P
0 g
s
.56193 .71768 m .56975 .75293 L .54095 .76294 L p .707 .577 .707 r
F P
0 g
s
.55658 .79502 m .56231 .77684 L .59041 .78376 L p .707 .577 .707 r
F P
0 g
s
.59041 .78376 m .58469 .80193 L .55658 .79502 L p .707 .577 .707 r
F P
0 g
s
.53253 .31904 m .53253 .82093 L .57437 .81638 L p .707 .577 .707 r
F P
0 g
s
.5931 .71062 m .60093 .74588 L .56975 .75293 L p .707 .577 .707 r
F P
0 g
s
.57437 .81638 m .57437 .31449 L .53253 .31904 L p .707 .577 .707 r
F P
0 g
s
.70427 .8384 m .69854 .85657 L .70545 .85429 L p .707 .577 .707 r
F P
0 g
s
.70545 .85429 m .71118 .83612 L .70427 .8384 L p .707 .577 .707 r
F P
0 g
s
.44372 .81886 m .44372 .31697 L .40543 .31056 L p .707 .577 .707 r
F P
0 g
s
.44372 .31697 m .44372 .81886 L .48752 .82178 L p .707 .577 .707 r
F P
0 g
s
.69882 .6381 m .71164 .69061 L .69954 .68261 L p .707 .577 .707 r
F P
0 g
s
.69954 .68261 m .68672 .6301 L .69882 .6381 L p .707 .577 .707 r
F P
0 g
s
.60932 .62933 m .62213 .68184 L .59108 .68941 L p .707 .577 .707 r
F P
0 g
s
.59108 .68941 m .57826 .63691 L .60932 .62933 L p .707 .577 .707 r
F P
0 g
s
.6236 .70721 m .63143 .74247 L .60093 .74588 L p .707 .577 .707 r
F P
0 g
s
.60093 .74588 m .5931 .71062 L .6236 .70721 L p .707 .577 .707 r
F P
0 g
s
.58469 .80193 m .59041 .78376 L .62082 .79275 L p .707 .577 .707 r
F P
0 g
s
.62082 .79275 m .61509 .81093 L .58469 .80193 L p .707 .577 .707 r
F P
0 g
s
.57437 .31449 m .57437 .81638 L .60892 .80859 L p .707 .577 .707 r
F P
0 g
s
.60892 .80859 m .60892 .3067 L .57437 .31449 L p .707 .577 .707 r
F P
0 g
s
.25855 .6932 m .25298 .63584 L .22194 .63851 L p .707 .577 .707 r
F P
0 g
s
.25298 .63584 m .25855 .6932 L .29023 .68999 L p .707 .577 .707 r
F P
0 g
s
.29023 .68999 m .28466 .63263 L .25298 .63584 L p .707 .577 .707 r
F P
0 g
s
.68325 .72022 m .69108 .75547 L .67882 .74751 L p .707 .577 .707 r
F P
0 g
s
.67882 .74751 m .671 .71225 L .68325 .72022 L p .707 .577 .707 r
F P
0 g
s
.22194 .63851 m .22751 .69587 L .25855 .6932 L p .707 .577 .707 r
F P
0 g
s
.28466 .63263 m .29023 .68999 L .31945 .68656 L p .707 .577 .707 r
F P
0 g
s
.31945 .68656 m .31388 .62919 L .28466 .63263 L p .707 .577 .707 r
F P
0 g
s
.40543 .81244 m .40543 .31056 L .3764 .30128 L p .707 .577 .707 r
F P
0 g
s
.40543 .31056 m .40543 .81244 L .44372 .81886 L p .707 .577 .707 r
F P
0 g
s
.22751 .69587 m .22194 .63851 L .19458 .64038 L p .707 .577 .707 r
F P
0 g
s
.71118 .83612 m .70545 .85429 L .70283 .84897 L p .707 .577 .707 r
F P
0 g
s
.70283 .84897 m .70856 .8308 L .71118 .83612 L p .707 .577 .707 r
F P
0 g
s
.19458 .64038 m .20014 .69775 L .22751 .69587 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68672 .6301 m .69954 .68261 L .67916 .67826 L p .707 .577 .707 r
F P
0 g
s
.67916 .67826 m .66634 .62576 L .68672 .6301 L p .707 .577 .707 r
F P
0 g
s
.31388 .62919 m .31945 .68656 L .34335 .68324 L p .707 .577 .707 r
F P
0 g
s
.34335 .68324 m .33778 .62588 L .31388 .62919 L p .707 .577 .707 r
F P
0 g
s
.63143 .74247 m .6236 .70721 L .65044 .70777 L p .707 .577 .707 r
F P
0 g
s
.63967 .62549 m .65248 .678 L .62213 .68184 L p .707 .577 .707 r
F P
0 g
s
.62213 .68184 m .60932 .62933 L .63967 .62549 L p .707 .577 .707 r
F P
0 g
s
.61509 .81093 m .62082 .79275 L .65054 .80296 L p .707 .577 .707 r
F P
0 g
s
.60892 .3067 m .60892 .80859 L .63281 .79832 L p .707 .577 .707 r
F P
0 g
s
.65044 .70777 m .65827 .74303 L .63143 .74247 L p .707 .577 .707 r
F P
0 g
s
.63281 .79832 m .63281 .29643 L .60892 .3067 L p .707 .577 .707 r
F P
0 g
s
.20014 .69775 m .19458 .64038 L .17357 .64128 L p .707 .577 .707 r
F P
0 g
s
.17357 .64128 m .17914 .69864 L .20014 .69775 L p .707 .577 .707 r
F P
0 g
s
.671 .71225 m .67882 .74751 L .65827 .74303 L p .707 .577 .707 r
F P
0 g
s
.65827 .74303 m .65044 .70777 L .671 .71225 L p .707 .577 .707 r
F P
0 g
s
.66634 .62576 m .67916 .67826 L .65248 .678 L p .707 .577 .707 r
F P
0 g
s
.65248 .678 m .63967 .62549 L .66634 .62576 L p .707 .577 .707 r
F P
0 g
s
.33778 .62588 m .34335 .68324 L .35958 .68036 L p .707 .577 .707 r
F P
0 g
s
.35958 .68036 m .35401 .623 L .33778 .62588 L p .707 .577 .707 r
F P
0 g
s
.24979 .75025 m .24639 .71202 L .21531 .7143 L p .707 .577 .707 r
F P
0 g
s
.24639 .71202 m .24979 .75025 L .28149 .74724 L p .707 .577 .707 r
F P
0 g
s
.28149 .74724 m .27809 .70901 L .24639 .71202 L p .707 .577 .707 r
F P
0 g
s
.3764 .80317 m .3764 .30128 L .35947 .29006 L p .707 .577 .707 r
F P
0 g
s
.3764 .30128 m .3764 .80317 L .40543 .81244 L p .707 .577 .707 r
F P
0 g
s
.21531 .7143 m .21871 .75253 L .24979 .75025 L p .707 .577 .707 r
F P
0 g
s
.27809 .70901 m .28149 .74724 L .3107 .74381 L p .707 .577 .707 r
F P
0 g
s
.3107 .74381 m .30731 .70558 L .27809 .70901 L p .707 .577 .707 r
F P
0 g
s
.70856 .8308 m .70283 .84897 L .69095 .84113 L p .707 .577 .707 r
F P
0 g
s
.69095 .84113 m .69667 .82296 L .70856 .8308 L p .707 .577 .707 r
F P
0 g
s
.25642 .84305 m .25894 .82702 L .22797 .81992 L p .707 .577 .707 r
F P
0 g
s
.25894 .82702 m .25642 .84305 L .28795 .84481 L p .707 .577 .707 r
F P
0 g
s
.28795 .84481 m .29047 .82878 L .25894 .82702 L p .707 .577 .707 r
F P
0 g
s
.21871 .75253 m .21531 .7143 L .18789 .71563 L p .707 .577 .707 r
F P
0 g
s
.22545 .83595 m .22797 .81992 L .20058 .80816 L p .707 .577 .707 r
F P
0 g
s
.22797 .81992 m .22545 .83595 L .25642 .84305 L p .707 .577 .707 r
F P
0 g
s
.18789 .71563 m .19129 .75386 L .21871 .75253 L p .707 .577 .707 r
F P
0 g
s
.17914 .69864 m .17357 .64128 L .16097 .6411 L p .707 .577 .707 r
F P
0 g
s
.29047 .82878 m .28795 .84481 L .31695 .84106 L p .707 .577 .707 r
F P
0 g
s
.31695 .84106 m .31947 .82503 L .29047 .82878 L p .707 .577 .707 r
F P
0 g
s
.16097 .6411 m .16654 .69846 L .17914 .69864 L p .707 .577 .707 r
F P
0 g
s
.30731 .70558 m .3107 .74381 L .33457 .74027 L p .707 .577 .707 r
F P
0 g
s
.33457 .74027 m .33118 .70205 L .30731 .70558 L p .707 .577 .707 r
F P
0 g
s
.63281 .29643 m .63281 .79832 L .6437 .78657 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63281 .29643 L p .707 .577 .707 r
F P
0 g
s
.20058 .80816 m .19806 .82419 L .22545 .83595 L p .707 .577 .707 r
F P
0 g
s
.19806 .82419 m .20058 .80816 L .17947 .79291 L p .707 .577 .707 r
F P
0 g
s
.19129 .75386 m .18789 .71563 L .16682 .71589 L p .707 .577 .707 r
F P
0 g
s
.31947 .82503 m .31695 .84106 L .34059 .83215 L p .707 .577 .707 r
F P
0 g
s
.34059 .83215 m .34311 .81612 L .31947 .82503 L p .707 .577 .707 r
F P
0 g
s
.16682 .71589 m .17022 .75412 L .19129 .75386 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35629 .27798 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35401 .623 m .35958 .68036 L .36581 .67844 L p .707 .577 .707 r
F P
0 g
s
.36567 .67426 m .35401 .623 L .36581 .67844 L .707 .577 .707 r
F
.36656 .6782 m .361 .62084 L .35401 .623 L p F P
0 g
s
.35805 .61961 m .361 .62084 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36361 .67698 m .36335 .67425 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.36335 .67425 m .35805 .61961 L p .36347 .67378 L .707 .577 .707 r
F P
0 g
s
.34737 .69877 m .35076 .737 L .35769 .73429 L p .707 .577 .707 r
F P
0 g
s
.35769 .73429 m .35429 .69606 L .34737 .69877 L p .707 .577 .707 r
F P
0 g
s
.35429 .69606 m .35769 .73429 L .35467 .73242 L p .707 .577 .707 r
F P
0 g
s
.36257 .76919 m .36005 .78522 L .34727 .76796 L p .707 .577 .707 r
F P
0 g
s
.34727 .76796 m .34979 .75193 L .36257 .76919 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35947 .79195 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35805 .61961 m .36361 .67698 L .35102 .6768 L p .707 .577 .707 r
F P
0 g
s
.35102 .6768 m .34545 .61944 L .35805 .61961 L p .707 .577 .707 r
F P
0 g
s
.35629 .27798 m .35629 .70254 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35629 .70254 m .35629 .77987 L p .35885 .69228 L .707 .577 .707 r
F P
0 g
s
.35947 .79195 m .35947 .49323 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.35947 .49323 m .35947 .29006 L p .35722 .42742 L .707 .577 .707 r
F P
0 g
s
.36581 .67844 m .36656 .6782 L p .36567 .67426 L .707 .577 .707 r
F P
0 g
s
.17947 .79291 m .17695 .80894 L .19806 .82419 L p .707 .577 .707 r
F P
0 g
s
.69667 .82296 m .69095 .84113 L .67096 .83154 L p .707 .577 .707 r
F P
0 g
s
.67096 .83154 m .67668 .81336 L .69667 .82296 L p .707 .577 .707 r
F P
0 g
s
.33118 .70205 m .33457 .74027 L .35076 .737 L p .707 .577 .707 r
F P
0 g
s
.35076 .737 m .34737 .69877 L .33118 .70205 L p .707 .577 .707 r
F P
0 g
s
.17695 .80894 m .17947 .79291 L .16669 .77565 L p .707 .577 .707 r
F P
0 g
s
.16654 .69846 m .16097 .6411 L .15802 .63987 L p .707 .577 .707 r
F P
0 g
s
.361 .62084 m .36656 .6782 L .36361 .67698 L p .707 .577 .707 r
F P
0 g
s
.36324 .8028 m .36576 .78677 L .35906 .80294 L p .707 .577 .707 r
F P
0 g
s
.36576 .78677 m .36324 .8028 L .36005 .78522 L p .707 .577 .707 r
F P
0 g
s
.36005 .78522 m .36257 .76919 L .36576 .78677 L p .707 .577 .707 r
F P
0 g
s
.35947 .29006 m .35947 .79195 L .3764 .80317 L p .707 .577 .707 r
F P
0 g
s
.15802 .63987 m .16359 .69724 L .16654 .69846 L p .707 .577 .707 r
F P
0 g
s
.34311 .81612 m .34059 .83215 L .35654 .81897 L p .707 .577 .707 r
F P
0 g
s
.35654 .81897 m .35906 .80294 L .34311 .81612 L p .707 .577 .707 r
F P
0 g
s
.17022 .75412 m .16682 .71589 L .15415 .71504 L p .707 .577 .707 r
F P
0 g
s
.16669 .77565 m .16417 .79168 L .17695 .80894 L p .707 .577 .707 r
F P
0 g
s
.15415 .71504 m .15755 .75327 L .17022 .75412 L p .707 .577 .707 r
F P
0 g
s
.67668 .81336 m .67096 .83154 L .64482 .82113 L p .707 .577 .707 r
F P
0 g
s
.64482 .82113 m .65054 .80296 L .67668 .81336 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .70924 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .62359 .76326 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .639 .56377 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63638 .62968 m .63665 .62728 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.63665 .62728 m .64195 .57917 L p .63653 .62593 L .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .64053 .77449 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.6437 .70924 m .6437 .78657 L p .64114 .6795 L .707 .577 .707 r
F P
0 g
s
.16417 .79168 m .16669 .77565 L .1635 .75808 L p .707 .577 .707 r
F P
0 g
s
.35906 .80294 m .35654 .81897 L .36324 .8028 L p .707 .577 .707 r
F P
0 g
s
.65054 .80296 m .64482 .82113 L .61509 .81093 L p .707 .577 .707 r
F P
0 g
s
.16359 .69724 m .15802 .63987 L .16501 .63771 L p .707 .577 .707 r
F P
0 g
s
.1635 .75808 m .16098 .77411 L .16417 .79168 L p .707 .577 .707 r
F P
0 g
s
.16501 .63771 m .17057 .69508 L .16359 .69724 L p .707 .577 .707 r
F P
0 g
s
.15755 .75327 m .15415 .71504 L .15114 .71317 L p .707 .577 .707 r
F P
0 g
s
.15114 .71317 m .15453 .7514 L .15755 .75327 L p .707 .577 .707 r
F P
0 g
s
.35629 .77987 m .35629 .27798 L .36719 .26623 L p .707 .577 .707 r
F P
0 g
s
.16098 .77411 m .1635 .75808 L .17021 .74191 L p .707 .577 .707 r
F P
0 g
s
.35467 .73242 m .35128 .69419 L .35429 .69606 L p .707 .577 .707 r
F P
0 g
s
.17021 .74191 m .16769 .75794 L .16098 .77411 L p .707 .577 .707 r
F P
0 g
s
.17057 .69508 m .16501 .63771 L .18124 .63483 L p .707 .577 .707 r
F P
0 g
s
.62359 .76326 m .62359 .26137 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18124 .63483 m .18681 .6922 L .17057 .69508 L p .707 .577 .707 r
F P
0 g
s
.15453 .7514 m .15114 .71317 L .15806 .71046 L p .707 .577 .707 r
F P
0 g
s
.15806 .71046 m .16146 .74869 L .15453 .7514 L p .707 .577 .707 r
F P
0 g
s
.16769 .75794 m .17021 .74191 L .18616 .72872 L p .707 .577 .707 r
F P
0 g
s
.34545 .61944 m .35102 .6768 L .33001 .67769 L p .707 .577 .707 r
F P
0 g
s
.33001 .67769 m .32444 .62033 L .34545 .61944 L p .707 .577 .707 r
F P
0 g
s
.35128 .69419 m .35467 .73242 L .34201 .73157 L p .707 .577 .707 r
F P
0 g
s
.34201 .73157 m .33861 .69334 L .35128 .69419 L p .707 .577 .707 r
F P
0 g
s
.18616 .72872 m .18364 .74475 L .16769 .75794 L p .707 .577 .707 r
F P
0 g
s
.36718 .76812 m .36719 .26623 L .39108 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26623 m .36718 .76812 L .35629 .77987 L p .707 .577 .707 r
F P
0 g
s
.18681 .6922 m .18124 .63483 L .20514 .63152 L p .707 .577 .707 r
F P
0 g
s
.20514 .63152 m .21071 .68888 L .18681 .6922 L p .707 .577 .707 r
F P
0 g
s
.16146 .74869 m .15806 .71046 L .17425 .70718 L p .707 .577 .707 r
F P
0 g
s
.18364 .74475 m .18616 .72872 L .20979 .71982 L p .707 .577 .707 r
F P
0 g
s
.17425 .70718 m .17765 .74541 L .16146 .74869 L p .707 .577 .707 r
F P
0 g
s
.32444 .62033 m .33001 .67769 L .30265 .67957 L p .707 .577 .707 r
F P
0 g
s
.30265 .67957 m .29708 .6222 L .32444 .62033 L p .707 .577 .707 r
F P
0 g
s
.34979 .75193 m .34727 .76796 L .32616 .75271 L p .707 .577 .707 r
F P
0 g
s
.32616 .75271 m .32868 .73668 L .34979 .75193 L p .707 .577 .707 r
F P
0 g
s
.62359 .26137 m .62359 .76326 L .59456 .75399 L p .707 .577 .707 r
F P
0 g
s
.59456 .75399 m .59456 .2521 L .62359 .26137 L p .707 .577 .707 r
F P
0 g
s
.20979 .71982 m .20727 .73585 L .18364 .74475 L p .707 .577 .707 r
F P
0 g
s
.21071 .68888 m .20514 .63152 L .23436 .62808 L p .707 .577 .707 r
F P
0 g
s
.23436 .62808 m .23992 .68545 L .21071 .68888 L p .707 .577 .707 r
F P
0 g
s
.33861 .69334 m .34201 .73157 L .32093 .73182 L p .707 .577 .707 r
F P
0 g
s
.32093 .73182 m .31754 .6936 L .33861 .69334 L p .707 .577 .707 r
F P
0 g
s
.29708 .6222 m .30265 .67957 L .27161 .68224 L p .707 .577 .707 r
F P
0 g
s
.27161 .68224 m .26604 .62488 L .29708 .6222 L p .707 .577 .707 r
F P
0 g
s
.20727 .73585 m .20979 .71982 L .23879 .71606 L p .707 .577 .707 r
F P
0 g
s
.32868 .73668 m .32616 .75271 L .29877 .74095 L p .707 .577 .707 r
F P
0 g
s
.29877 .74095 m .30129 .72492 L .32868 .73668 L p .707 .577 .707 r
F P
0 g
s
.23992 .68545 m .23436 .62808 L .26604 .62488 L p .707 .577 .707 r
F P
0 g
s
.39108 .25595 m .39108 .75784 L .36718 .76812 L p .707 .577 .707 r
F P
0 g
s
.39108 .75784 m .39108 .25595 L .42563 .24816 L p .707 .577 .707 r
F P
0 g
s
.26604 .62488 m .27161 .68224 L .23992 .68545 L p .707 .577 .707 r
F P
0 g
s
.17765 .74541 m .17425 .70718 L .19812 .70365 L p .707 .577 .707 r
F P
0 g
s
.19812 .70365 m .20152 .74188 L .17765 .74541 L p .707 .577 .707 r
F P
0 g
s
.23879 .71606 m .23627 .73209 L .20727 .73585 L p .707 .577 .707 r
F P
0 g
s
.72839 .67401 m .73396 .6235 L .70292 .61751 L p .707 .577 .707 r
F P
0 g
s
.73396 .6235 m .72839 .67401 L .76007 .6753 L p .707 .577 .707 r
F P
0 g
s
.76007 .6753 m .76564 .62479 L .73396 .6235 L p .707 .577 .707 r
F P
0 g
s
.23627 .73209 m .23879 .71606 L .27032 .71782 L p .707 .577 .707 r
F P
0 g
s
.30129 .72492 m .29877 .74095 L .2678 .73385 L p .707 .577 .707 r
F P
0 g
s
.2678 .73385 m .27032 .71782 L .30129 .72492 L p .707 .577 .707 r
F P
0 g
s
.76564 .62479 m .76007 .6753 L .78929 .67178 L p .707 .577 .707 r
F P
0 g
s
.78929 .67178 m .79486 .62126 L .76564 .62479 L p .707 .577 .707 r
F P
0 g
s
.69735 .66803 m .70292 .61751 L .67555 .60742 L p .707 .577 .707 r
F P
0 g
s
.70292 .61751 m .69735 .66803 L .72839 .67401 L p .707 .577 .707 r
F P
0 g
s
.73756 .73864 m .74096 .70458 L .70988 .69895 L p .707 .577 .707 r
F P
0 g
s
.74096 .70458 m .73756 .73864 L .76926 .73974 L p .707 .577 .707 r
F P
0 g
s
.76926 .73974 m .77266 .70569 L .74096 .70458 L p .707 .577 .707 r
F P
0 g
s
.27032 .71782 m .2678 .73385 L .23627 .73209 L p .707 .577 .707 r
F P
0 g
s
.59456 .2521 m .59456 .75399 L .55628 .74758 L p .707 .577 .707 r
F P
0 g
s
.55628 .74758 m .55628 .24569 L .59456 .2521 L p .707 .577 .707 r
F P
0 g
s
.31754 .6936 m .32093 .73182 L .29351 .73316 L p .707 .577 .707 r
F P
0 g
s
.29351 .73316 m .29012 .69493 L .31754 .6936 L p .707 .577 .707 r
F P
0 g
s
.77266 .70569 m .76926 .73974 L .79848 .73622 L p .707 .577 .707 r
F P
0 g
s
.79848 .73622 m .80187 .70216 L .77266 .70569 L p .707 .577 .707 r
F P
0 g
s
.70648 .733 m .70988 .69895 L .68246 .68934 L p .707 .577 .707 r
F P
0 g
s
.70988 .69895 m .70648 .733 L .73756 .73864 L p .707 .577 .707 r
F P
0 g
s
.79486 .62126 m .78929 .67178 L .81319 .66377 L p .707 .577 .707 r
F P
0 g
s
.81319 .66377 m .81876 .61326 L .79486 .62126 L p .707 .577 .707 r
F P
0 g
s
.20152 .74188 m .19812 .70365 L .22734 .70022 L p .707 .577 .707 r
F P
0 g
s
.66999 .65793 m .67555 .60742 L .65455 .59421 L p .707 .577 .707 r
F P
0 g
s
.67555 .60742 m .66999 .65793 L .69735 .66803 L p .707 .577 .707 r
F P
0 g
s
.22734 .70022 m .23073 .73844 L .20152 .74188 L p .707 .577 .707 r
F P
0 g
s
.42563 .75005 m .42563 .24816 L .46746 .24362 L p .707 .577 .707 r
F P
0 g
s
.42563 .24816 m .42563 .75005 L .39108 .75784 L p .707 .577 .707 r
F P
0 g
s
.80187 .70216 m .79848 .73622 L .82235 .7284 L p .707 .577 .707 r
F P
0 g
s
.82235 .7284 m .82575 .69435 L .80187 .70216 L p .707 .577 .707 r
F P
0 g
s
.67907 .72339 m .68246 .68934 L .66139 .67669 L p .707 .577 .707 r
F P
0 g
s
.68246 .68934 m .67907 .72339 L .70648 .733 L p .707 .577 .707 r
F P
0 g
s
.29012 .69493 m .29351 .73316 L .26243 .73544 L p .707 .577 .707 r
F P
0 g
s
.26243 .73544 m .25904 .69721 L .29012 .69493 L p .707 .577 .707 r
F P
0 g
s
.23073 .73844 m .22734 .70022 L .25904 .69721 L p .707 .577 .707 r
F P
0 g
s
.55628 .24569 m .55628 .74758 L .51248 .74466 L p .707 .577 .707 r
F P
0 g
s
.51248 .74466 m .51248 .24277 L .55628 .24569 L p .707 .577 .707 r
F P
0 g
s
.25904 .69721 m .26243 .73544 L .23073 .73844 L p .707 .577 .707 r
F P
0 g
s
.81876 .61326 m .81319 .66377 L .82942 .65208 L p .707 .577 .707 r
F P
0 g
s
.82942 .65208 m .83499 .60156 L .81876 .61326 L p .707 .577 .707 r
F P
0 g
s
.46746 .74551 m .46746 .24362 L .51248 .24277 L p .707 .577 .707 r
F P
0 g
s
.46746 .24362 m .46746 .74551 L .42563 .75005 L p .707 .577 .707 r
F P
0 g
s
.6987 .71342 m .70122 .73248 L .7322 .7282 L p .707 .577 .707 r
F P
0 g
s
.7322 .7282 m .72968 .70914 L .6987 .71342 L p .707 .577 .707 r
F P
0 g
s
.72968 .70914 m .7322 .7282 L .76373 .72412 L p .707 .577 .707 r
F P
0 g
s
.64898 .64472 m .65455 .59421 L .64195 .57917 L p .707 .577 .707 r
F P
0 g
s
.65455 .59421 m .64898 .64472 L .66999 .65793 L p .707 .577 .707 r
F P
0 g
s
.76373 .72412 m .76121 .70506 L .72968 .70914 L p .707 .577 .707 r
F P
0 g
s
.51248 .24277 m .51248 .74466 L .46746 .74551 L p .707 .577 .707 r
F P
0 g
s
.76121 .70506 m .76373 .72412 L .79273 .72066 L p .707 .577 .707 r
F P
0 g
s
.79273 .72066 m .79021 .70161 L .76121 .70506 L p .707 .577 .707 r
F P
0 g
s
.66139 .67669 m .65799 .71075 L .67907 .72339 L p .707 .577 .707 r
F P
0 g
s
.82575 .69435 m .82235 .7284 L .83854 .71706 L p .707 .577 .707 r
F P
0 g
s
.83854 .71706 m .84194 .68301 L .82575 .69435 L p .707 .577 .707 r
F P
0 g
s
.67132 .71751 m .67384 .73656 L .70122 .73248 L p .707 .577 .707 r
F P
0 g
s
.70122 .73248 m .6987 .71342 L .67132 .71751 L p .707 .577 .707 r
F P
0 g
s
.65799 .71075 m .66139 .67669 L .64872 .66225 L p .707 .577 .707 r
F P
0 g
s
.79021 .70161 m .79273 .72066 L .81636 .71816 L p .707 .577 .707 r
F P
0 g
s
.81636 .71816 m .81384 .6991 L .79021 .70161 L p .707 .577 .707 r
F P
0 g
s
.6502 .72098 m .65272 .74004 L .67384 .73656 L p .707 .577 .707 r
F P
0 g
s
.67384 .73656 m .67132 .71751 L .6502 .72098 L p .707 .577 .707 r
F P
0 g
s
.83499 .60156 m .82942 .65208 L .83641 .63784 L p .707 .577 .707 r
F P
0 g
s
.83641 .63784 m .84198 .58732 L .83499 .60156 L p .707 .577 .707 r
F P
0 g
s
.64872 .66225 m .64533 .69631 L .65799 .71075 L p .707 .577 .707 r
F P
0 g
s
.64195 .57917 m .63638 .62968 L .64898 .64472 L p .707 .577 .707 r
F P
0 g
s
.84194 .68301 m .83854 .71706 L .84547 .7033 L p .707 .577 .707 r
F P
0 g
s
.84547 .7033 m .84886 .66925 L .84194 .68301 L p .707 .577 .707 r
F P
0 g
s
.64533 .69631 m .64872 .66225 L .6457 .64743 L p .707 .577 .707 r
F P
0 g
s
.81384 .6991 m .81636 .71816 L .83231 .71685 L p .707 .577 .707 r
F P
0 g
s
.83231 .71685 m .82979 .69779 L .81384 .6991 L p .707 .577 .707 r
F P
0 g
s
.63743 .72351 m .63995 .74257 L .65272 .74004 L p .707 .577 .707 r
F P
0 g
s
.65272 .74004 m .6502 .72098 L .63743 .72351 L p .707 .577 .707 r
F P
0 g
s
.6457 .64743 m .64231 .68148 L .64533 .69631 L p .707 .577 .707 r
F P
0 g
s
.84198 .58732 m .83641 .63784 L .83346 .62245 L p .707 .577 .707 r
F P
0 g
s
.83346 .62245 m .83903 .57193 L .84198 .58732 L p .707 .577 .707 r
F P
0 g
s
.639 .56377 m .63343 .61429 L .63638 .62968 L p .707 .577 .707 r
F P
0 g
s
.63343 .61429 m .639 .56377 L .64599 .54953 L p .707 .577 .707 r
F P
0 g
s
.84886 .66925 m .84547 .7033 L .84245 .68848 L p .707 .577 .707 r
F P
0 g
s
.84245 .68848 m .84584 .65443 L .84886 .66925 L p .707 .577 .707 r
F P
0 g
s
.64231 .68148 m .6457 .64743 L .65263 .63368 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.82979 .69779 m .83231 .71685 L .83902 .71686 L p .707 .577 .707 r
F P
0 g
s
.83902 .71686 m .8365 .6978 L .82979 .69779 L p .707 .577 .707 r
F P
0 g
s
.63423 .72485 m .63675 .74391 L .63995 .74257 L p .707 .577 .707 r
F P
0 g
s
.63995 .74257 m .63743 .72351 L .63423 .72485 L p .707 .577 .707 r
F P
0 g
s
.65263 .63368 m .64923 .66773 L .64231 .68148 L p .707 .577 .707 r
F P
0 g
s
.83903 .57193 m .83346 .62245 L .82086 .60741 L p .707 .577 .707 r
F P
0 g
s
.82086 .60741 m .82643 .55689 L .83903 .57193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64599 .54953 m .64042 .60005 L .63343 .61429 L p .707 .577 .707 r
F P
0 g
s
.64042 .60005 m .64599 .54953 L .66222 .53784 L p .707 .577 .707 r
F P
0 g
s
.37786 .61007 m .39068 .55468 L .36033 .5466 L p .707 .577 .707 r
F P
0 g
s
.39068 .55468 m .37786 .61007 L .40892 .61656 L p .707 .577 .707 r
F P
0 g
s
.40892 .61656 m .42174 .56118 L .39068 .55468 L p .707 .577 .707 r
F P
0 g
s
.84584 .65443 m .84245 .68848 L .82978 .67404 L p .707 .577 .707 r
F P
0 g
s
.82978 .67404 m .83318 .63999 L .84584 .65443 L p .707 .577 .707 r
F P
0 g
s
.64923 .66773 m .65263 .63368 L .66882 .62233 L p .707 .577 .707 r
F P
0 g
s
.42174 .56118 m .40892 .61656 L .43764 .62083 L p .707 .577 .707 r
F P
0 g
s
.43764 .62083 m .45046 .56545 L .42174 .56118 L p .707 .577 .707 r
F P
0 g
s
.34751 .60198 m .36033 .5466 L .33366 .53772 L p .707 .577 .707 r
F P
0 g
s
.36033 .5466 m .34751 .60198 L .37786 .61007 L p .707 .577 .707 r
F P
0 g
s
.8365 .6978 m .83902 .71686 L .83583 .7182 L p .707 .577 .707 r
F P
0 g
s
.83583 .7182 m .83331 .69914 L .8365 .6978 L p .707 .577 .707 r
F P
0 g
s
.33366 .53772 m .32084 .5931 L .34751 .60198 L p .707 .577 .707 r
F P
0 g
s
.45046 .56545 m .43764 .62083 L .46122 .62246 L p .707 .577 .707 r
F P
0 g
s
.46122 .62246 m .47404 .56707 L .45046 .56545 L p .707 .577 .707 r
F P
0 g
s
.82643 .55689 m .82086 .60741 L .79985 .5942 L p .707 .577 .707 r
F P
0 g
s
.79985 .5942 m .80542 .54368 L .82643 .55689 L p .707 .577 .707 r
F P
0 g
s
.66882 .62233 m .66543 .65639 L .64923 .66773 L p .707 .577 .707 r
F P
0 g
s
.32084 .5931 m .33366 .53772 L .31328 .52891 L p .707 .577 .707 r
F P
0 g
s
.66222 .53784 m .65665 .58836 L .64042 .60005 L p .707 .577 .707 r
F P
0 g
s
.65665 .58836 m .66222 .53784 L .68612 .52984 L p .707 .577 .707 r
F P
0 g
s
.64094 .72487 m .64346 .74393 L .63675 .74391 L p .707 .577 .707 r
F P
0 g
s
.63675 .74391 m .63423 .72485 L .64094 .72487 L p .707 .577 .707 r
F P
0 g
s
.83318 .63999 m .82978 .67404 L .80871 .6614 L p .707 .577 .707 r
F P
0 g
s
.80871 .6614 m .8121 .62734 L .83318 .63999 L p .707 .577 .707 r
F P
0 g
s
.39907 .66939 m .40689 .63237 L .37639 .62482 L p .707 .577 .707 r
F P
0 g
s
.40689 .63237 m .39907 .66939 L .43024 .67525 L p .707 .577 .707 r
F P
0 g
s
.43024 .67525 m .43807 .63822 L .40689 .63237 L p .707 .577 .707 r
F P
0 g
s
.66543 .65639 m .66882 .62233 L .69269 .61452 L p .707 .577 .707 r
F P
0 g
s
.31328 .52891 m .30046 .58429 L .32084 .5931 L p .707 .577 .707 r
F P
0 g
s
.43807 .63822 m .43024 .67525 L .45904 .67885 L p .707 .577 .707 r
F P
0 g
s
.45904 .67885 m .46687 .64182 L .43807 .63822 L p .707 .577 .707 r
F P
0 g
s
.36856 .66185 m .37639 .62482 L .34955 .61633 L p .707 .577 .707 r
F P
0 g
s
.37639 .62482 m .36856 .66185 L .39907 .66939 L p .707 .577 .707 r
F P
0 g
s
.47404 .56707 m .46122 .62246 L .47735 .62128 L p .707 .577 .707 r
F P
0 g
s
.47735 .62128 m .49017 .5659 L .47404 .56707 L p .707 .577 .707 r
F P
0 g
s
.80542 .54368 m .79985 .5942 L .77249 .5841 L p .707 .577 .707 r
F P
0 g
s
.77249 .5841 m .77806 .53359 L .80542 .54368 L p .707 .577 .707 r
F P
0 g
s
.41531 .72759 m .40958 .71069 L .37918 .72049 L p .707 .577 .707 r
F P
0 g
s
.40958 .71069 m .41531 .72759 L .44342 .71466 L p .707 .577 .707 r
F P
0 g
s
.44342 .71466 m .43769 .69776 L .40958 .71069 L p .707 .577 .707 r
F P
0 g
s
.68055 .58035 m .68612 .52984 L .71534 .52631 L p .707 .577 .707 r
F P
0 g
s
.68612 .52984 m .68055 .58035 L .65665 .58836 L p .707 .577 .707 r
F P
0 g
s
.34955 .61633 m .34172 .65336 L .36856 .66185 L p .707 .577 .707 r
F P
0 g
s
.38491 .73739 m .37918 .72049 L .34945 .7262 L p .707 .577 .707 r
F P
0 g
s
.37918 .72049 m .38491 .73739 L .41531 .72759 L p .707 .577 .707 r
F P
0 g
s
.83331 .69914 m .83583 .7182 L .82305 .72073 L p .707 .577 .707 r
F P
0 g
s
.82305 .72073 m .82053 .70167 L .83331 .69914 L p .707 .577 .707 r
F P
0 g
s
.30046 .58429 m .31328 .52891 L .30118 .52103 L p .707 .577 .707 r
F P
0 g
s
.46687 .64182 m .45904 .67885 L .48265 .67983 L p .707 .577 .707 r
F P
0 g
s
.48265 .67983 m .49048 .64281 L .46687 .64182 L p .707 .577 .707 r
F P
0 g
s
.69269 .61452 m .6893 .64857 L .66543 .65639 L p .707 .577 .707 r
F P
0 g
s
.8121 .62734 m .80871 .6614 L .78129 .65179 L p .707 .577 .707 r
F P
0 g
s
.78129 .65179 m .78469 .61773 L .8121 .62734 L p .707 .577 .707 r
F P
0 g
s
.6893 .64857 m .69269 .61452 L .72191 .61099 L p .707 .577 .707 r
F P
0 g
s
.43769 .69776 m .44342 .71466 L .46648 .69986 L p .707 .577 .707 r
F P
0 g
s
.46648 .69986 m .46075 .68296 L .43769 .69776 L p .707 .577 .707 r
F P
0 g
s
.34945 .7262 m .35518 .7431 L .38491 .73739 L p .707 .577 .707 r
F P
0 g
s
.34172 .65336 m .34955 .61633 L .329 .60772 L p .707 .577 .707 r
F P
0 g
s
.35518 .7431 m .34945 .7262 L .32332 .72726 L p .707 .577 .707 r
F P
0 g
s
.77806 .53359 m .77249 .5841 L .74145 .57812 L p .707 .577 .707 r
F P
0 g
s
.74145 .57812 m .74702 .5276 L .77806 .53359 L p .707 .577 .707 r
F P
0 g
s
.70977 .57683 m .71534 .52631 L .74702 .5276 L p .707 .577 .707 r
F P
0 g
s
.71534 .52631 m .70977 .57683 L .68055 .58035 L p .707 .577 .707 r
F P
0 g
s
.65689 .72356 m .65941 .74262 L .64346 .74393 L p .707 .577 .707 r
F P
0 g
s
.64346 .74393 m .64094 .72487 L .65689 .72356 L p .707 .577 .707 r
F P
0 g
s
.30118 .52103 m .28836 .57642 L .30046 .58429 L p .707 .577 .707 r
F P
0 g
s
.329 .60772 m .32117 .64475 L .34172 .65336 L p .707 .577 .707 r
F P
0 g
s
.74702 .5276 m .74145 .57812 L .70977 .57683 L p .707 .577 .707 r
F P
0 g
s
.32332 .72726 m .32904 .74416 L .35518 .7431 L p .707 .577 .707 r
F P
0 g
s
.78469 .61773 m .78129 .65179 L .75021 .64615 L p .707 .577 .707 r
F P
0 g
s
.75021 .64615 m .75361 .6121 L .78469 .61773 L p .707 .577 .707 r
F P
0 g
s
.71851 .64504 m .72191 .61099 L .75361 .6121 L p .707 .577 .707 r
F P
0 g
s
.72191 .61099 m .71851 .64504 L .6893 .64857 L p .707 .577 .707 r
F P
0 g
s
.75361 .6121 m .75021 .64615 L .71851 .64504 L p .707 .577 .707 r
F P
0 g
s
.46075 .68296 m .46648 .69986 L .48223 .68465 L p .707 .577 .707 r
F P
0 g
s
.48223 .68465 m .4765 .66775 L .46075 .68296 L p .707 .577 .707 r
F P
0 g
s
.49017 .5659 m .47735 .62128 L .48444 .61742 L p .707 .577 .707 r
F P
0 g
s
.48444 .61742 m .49726 .56203 L .49017 .5659 L p .707 .577 .707 r
F P
0 g
s
.49048 .64281 m .48265 .67983 L .49875 .67811 L p .707 .577 .707 r
F P
0 g
s
.49875 .67811 m .50658 .64108 L .49048 .64281 L p .707 .577 .707 r
F P
0 g
s
.32904 .74416 m .32332 .72726 L .30333 .72357 L p .707 .577 .707 r
F P
0 g
s
.82053 .70167 m .82305 .72073 L .80193 .72421 L p .707 .577 .707 r
F P
0 g
s
.32117 .64475 m .329 .60772 L .31675 .59984 L p .707 .577 .707 r
F P
0 g
s
.28836 .57642 m .30118 .52103 L .29854 .51486 L p .707 .577 .707 r
F P
0 g
s
.80193 .72421 m .79941 .70515 L .82053 .70167 L p .707 .577 .707 r
F P
0 g
s
.30333 .72357 m .30905 .74047 L .32904 .74416 L p .707 .577 .707 r
F P
0 g
s
.31675 .59984 m .30892 .63687 L .32117 .64475 L p .707 .577 .707 r
F P
0 g
s
.68052 .72105 m .68304 .74011 L .65941 .74262 L p .707 .577 .707 r
F P
0 g
s
.65941 .74262 m .65689 .72356 L .68052 .72105 L p .707 .577 .707 r
F P
0 g
s
.29854 .51486 m .28572 .57024 L .28836 .57642 L p .707 .577 .707 r
F P
0 g
s
.4765 .66775 m .48223 .68465 L .48914 .67051 L p .707 .577 .707 r
F P
0 g
s
.48914 .67051 m .48341 .65361 L .4765 .66775 L p .707 .577 .707 r
F P
0 g
s
.30905 .74047 m .30333 .72357 L .29144 .71548 L p .707 .577 .707 r
F P
0 g
s
.50658 .64108 m .49875 .67811 L .50577 .67385 L p .707 .577 .707 r
F P
0 g
s
.50577 .67385 m .51359 .63682 L .50658 .64108 L p .707 .577 .707 r
F P
0 g
s
.79941 .70515 m .80193 .72421 L .77455 .72829 L p .707 .577 .707 r
F P
0 g
s
.77455 .72829 m .77203 .70923 L .79941 .70515 L p .707 .577 .707 r
F P
0 g
s
.49726 .56203 m .48444 .61742 L .48181 .61125 L p .707 .577 .707 r
F P
0 g
s
.48181 .61125 m .49463 .55586 L .49726 .56203 L p .707 .577 .707 r
F P
0 g
s
.30892 .63687 m .31675 .59984 L .314 .59346 L p .707 .577 .707 r
F P
0 g
s
.29144 .71548 m .29717 .73239 L .30905 .74047 L p .707 .577 .707 r
F P
0 g
s
.70953 .71759 m .71205 .73665 L .68304 .74011 L p .707 .577 .707 r
F P
0 g
s
.68304 .74011 m .68052 .72105 L .70953 .71759 L p .707 .577 .707 r
F P
0 g
s
.28572 .57024 m .29854 .51486 L .30564 .511 L p .707 .577 .707 r
F P
0 g
s
.314 .59346 m .30617 .63048 L .30892 .63687 L p .707 .577 .707 r
F P
0 g
s
.77203 .70923 m .77455 .72829 L .74358 .73258 L p .707 .577 .707 r
F P
0 g
s
.74358 .73258 m .74106 .71352 L .77203 .70923 L p .707 .577 .707 r
F P
0 g
s
.30564 .511 m .29282 .56638 L .28572 .57024 L p .707 .577 .707 r
F P
0 g
s
.74106 .71352 m .74358 .73258 L .71205 .73665 L p .707 .577 .707 r
F P
0 g
s
.71205 .73665 m .70953 .71759 L .74106 .71352 L p .707 .577 .707 r
F P
0 g
s
.48341 .65361 m .48914 .67051 L .48652 .65882 L p .707 .577 .707 r
F P
0 g
s
.48652 .65882 m .48079 .64192 L .48341 .65361 L p .707 .577 .707 r
F P
0 g
s
.29717 .73239 m .29144 .71548 L .28882 .7038 L p .707 .577 .707 r
F P
0 g
s
.51359 .63682 m .50577 .67385 L .50301 .66746 L p .707 .577 .707 r
F P
0 g
s
.50301 .66746 m .51084 .63043 L .51359 .63682 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49463 .55586 m .48181 .61125 L .46971 .60337 L p .707 .577 .707 r
F P
0 g
s
.46971 .60337 m .48253 .54799 L .49463 .55586 L p .707 .577 .707 r
F P
0 g
s
.28882 .7038 m .29455 .7207 L .29717 .73239 L p .707 .577 .707 r
F P
0 g
s
.30617 .63048 m .314 .59346 L .32101 .58919 L p .707 .577 .707 r
F P
0 g
s
.29282 .56638 m .30564 .511 L .32176 .50982 L p .707 .577 .707 r
F P
0 g
s
.32101 .58919 m .31319 .62622 L .30617 .63048 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32176 .50982 m .30894 .56521 L .29282 .56638 L p .707 .577 .707 r
F P
0 g
s
.48079 .64192 m .48652 .65882 L .47463 .65074 L p .707 .577 .707 r
F P
0 g
s
.47463 .65074 m .4689 .63384 L .48079 .64192 L p .707 .577 .707 r
F P
0 g
s
.29455 .7207 m .28882 .7038 L .29573 .68966 L p .707 .577 .707 r
F P
0 g
s
.48253 .54799 m .46971 .60337 L .44932 .59456 L p .707 .577 .707 r
F P
0 g
s
.44932 .59456 m .46214 .53918 L .48253 .54799 L p .707 .577 .707 r
F P
0 g
s
.51084 .63043 m .50301 .66746 L .49076 .65958 L p .707 .577 .707 r
F P
0 g
s
.49076 .65958 m .49859 .62255 L .51084 .63043 L p .707 .577 .707 r
F P
0 g
s
.29573 .68966 m .30145 .70656 L .29455 .7207 L p .707 .577 .707 r
F P
0 g
s
.30894 .56521 m .32176 .50982 L .34534 .51145 L p .707 .577 .707 r
F P
0 g
s
.31319 .62622 m .32101 .58919 L .33711 .58747 L p .707 .577 .707 r
F P
0 g
s
.33711 .58747 m .32929 .6245 L .31319 .62622 L p .707 .577 .707 r
F P
0 g
s
.34534 .51145 m .33252 .56683 L .30894 .56521 L p .707 .577 .707 r
F P
0 g
s
.4689 .63384 m .47463 .65074 L .45464 .64705 L p .707 .577 .707 r
F P
0 g
s
.45464 .64705 m .44891 .63014 L .4689 .63384 L p .707 .577 .707 r
F P
0 g
s
.46214 .53918 m .44932 .59456 L .42265 .58568 L p .707 .577 .707 r
F P
0 g
s
.42265 .58568 m .43547 .53029 L .46214 .53918 L p .707 .577 .707 r
F P
0 g
s
.30145 .70656 m .29573 .68966 L .31148 .67444 L p .707 .577 .707 r
F P
0 g
s
.33252 .56683 m .34534 .51145 L .37406 .51572 L p .707 .577 .707 r
F P
0 g
s
.49859 .62255 m .49076 .65958 L .47021 .65097 L p .707 .577 .707 r
F P
0 g
s
.47021 .65097 m .47804 .61394 L .49859 .62255 L p .707 .577 .707 r
F P
0 g
s
.31148 .67444 m .31721 .69135 L .30145 .70656 L p .707 .577 .707 r
F P
0 g
s
.32929 .6245 m .33711 .58747 L .36072 .58845 L p .707 .577 .707 r
F P
0 g
s
.37406 .51572 m .36125 .5711 L .33252 .56683 L p .707 .577 .707 r
F P
0 g
s
.43547 .53029 m .42265 .58568 L .3923 .5776 L p .707 .577 .707 r
F P
0 g
s
.3923 .5776 m .40512 .52221 L .43547 .53029 L p .707 .577 .707 r
F P
0 g
s
.36125 .5711 m .37406 .51572 L .40512 .52221 L p .707 .577 .707 r
F P
0 g
s
.36072 .58845 m .35289 .62548 L .32929 .6245 L p .707 .577 .707 r
F P
0 g
s
.44891 .63014 m .45464 .64705 L .4285 .64811 L p .707 .577 .707 r
F P
0 g
s
.4285 .64811 m .42278 .6312 L .44891 .63014 L p .707 .577 .707 r
F P
0 g
s
.40512 .52221 m .3923 .5776 L .36125 .5711 L p .707 .577 .707 r
F P
0 g
s
.31721 .69135 m .31148 .67444 L .33454 .65965 L p .707 .577 .707 r
F P
0 g
s
.47804 .61394 m .47021 .65097 L .44337 .64248 L p .707 .577 .707 r
F P
0 g
s
.44337 .64248 m .4512 .60545 L .47804 .61394 L p .707 .577 .707 r
F P
0 g
s
.33454 .65965 m .34026 .67655 L .31721 .69135 L p .707 .577 .707 r
F P
0 g
s
.35289 .62548 m .36072 .58845 L .38952 .59205 L p .707 .577 .707 r
F P
0 g
s
.42278 .6312 m .4285 .64811 L .39878 .65382 L p .707 .577 .707 r
F P
0 g
s
.39878 .65382 m .39305 .63691 L .42278 .6312 L p .707 .577 .707 r
F P
0 g
s
.38952 .59205 m .38169 .62908 L .35289 .62548 L p .707 .577 .707 r
F P
0 g
s
.34026 .67655 m .33454 .65965 L .36265 .64671 L p .707 .577 .707 r
F P
0 g
s
.4512 .60545 m .44337 .64248 L .41287 .63493 L p .707 .577 .707 r
F P
0 g
s
.41287 .63493 m .4207 .59791 L .4512 .60545 L p .707 .577 .707 r
F P
0 g
s
.38169 .62908 m .38952 .59205 L .4207 .59791 L p .707 .577 .707 r
F P
0 g
s
.39305 .63691 m .39878 .65382 L .36837 .66362 L p .707 .577 .707 r
F P
0 g
s
.36837 .66362 m .36265 .64671 L .39305 .63691 L p .707 .577 .707 r
F P
0 g
s
.36265 .64671 m .36837 .66362 L .34026 .67655 L p .707 .577 .707 r
F P
0 g
s
.4207 .59791 m .41287 .63493 L .38169 .62908 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Iooa00009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Aoo`00E7oo0`0015YF00<005YFFUH015YF00@005YFFUIJEPL0
009JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00E7oo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1TOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00moo`P004eoo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF10001eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool02Goo1P000eYF00<005YFFUH00UYF2@00A7oo001COol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01Goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001COol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol00goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000003aoo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol00Woo0P001UYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH01UYF00@005YFFUIJEP8003Yoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF
0P00>7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Ool00003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0059oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYF000eOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00<goo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<007ooOol0<7oo001BOol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2000aOol0055oo`03001JEP00009JEPD000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP00
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0000`Ool0055oo`03001JEP0000<000AJEPL000AJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP04001JEUYF000_Ool0055oo`8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP05001J
EUYFFUH0000^Ool0055oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00D005YFFUIJEP0002ioo`00DWoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF
00IJEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001J
EUYF009JEPl000IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool005=oo`<0
00IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF1P003goo10000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00UYF0P00;Goo001EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEP0000<001Uoo`@000IJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;Goo001GOol300000eYF0000000=0002FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH2000QOol40002FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002eoo`00FGoo0`000eYF00<005YFFUH015YF00@005YFFUIJ
EPL000AJEP03001JEUYF00AJEP800003FUH005YF00EJEP06001JEUYF001JEP001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0002FUH2000VOol30005FUH01`00
FUIJEUYF001JEP0002eoo`00FGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01@0025YF0`0015YF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP05001JEUYF001JEP03000015YF0000000057oo0`0047oo0P000eYF00L005YFFUIJ
EP00FUH0000]Ool005Uoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPD0
00=JEP04001JEUYFFUH300000eYF001JEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP04001JEUYF000BOol5000AOol01000FUIJEP000eYF
00<005YF0000;Goo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP040006FUH20003FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020004FUH01000FUIJEUYF0P0047oo1@004Woo0`000eYF0P00;Woo001H
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH40002FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH2000>Ool5000DOol01000FUIJEUYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUH000030002FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01000FUH000001Goo2`005Goo0P000UYF0P00
;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP060004FUH00`00FUIJEP02FUH9000<
Ool200001UYF001JEP00FUH002ioo`00F7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF0`0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000Woo100000AJEP00FUIJEP800003FUH007oo02eo
o`00D7oo200000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEP000005FUH00`00FUIJEP0200000eYF001oo`0]Ool004Mo
o`T000AJEP06001JEUYF001JEP000UYF300015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00L005YFFUIJEP00FUH0000^Ool003moo`P000AJEP03001JEUYF
00IJEP05001JEUYF001JEP040005FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEP0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH5
0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P000eYF00<005YFFUH00UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0`000eYF0P00;goo000aOol60003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00UYF2P001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009J
EP8000AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0002FUH2000_Ool002aoo`D0009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00AJ
EP03001JEUYF009JEP@000IJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEP@002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF00<005YFFUH015YF1@0000=JEP00
FUH025YF00<005YFFUH010001UYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo02ioo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0`001UYF00<005YFFUH01UYF00<005YFFUH015YF
0P000eYF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF009JEQ0000IJEP03001J
EUYF00AJEP03001JEUYF00AJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH00UYF0`00
25YF00<005YFFUH00eYF3P0000=JEP00FUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF1P001eYF00<005YF
FUH01UYF10000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF0000;Woo000/Ool00`00FUH0
0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP050002FUH00`00FUIJEP06FUH60005FUH00`00FUIJEP05FUH40004FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YF
00000P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000EJEP03001JEUYF00AJ
EP04001JEUYF000]Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH3
0002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0`0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF0P001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH015YF00D005YFFUIJEP0002aoo`00
;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000000MJEP03001JEP00008000EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP@000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<0009JEP800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP06001JEP00001JEP001EYF00<005YFFUH00UYF00<007ooOol0:Woo000]Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH30008FUH30006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@001EYF
10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000EJEP03
001JEUYF009JEP03001oogoo02Yoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF0`00
0UYF10000UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF0080
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000006
FUH01000FUIJEUYF1@001UYF00<005YF00000P0015YF00<005YFFUH01EYF00@005YFFUIJEP@000=J
EP03001JEUYF009JEP8002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P001EYF00@005YFFUIJEP80009JEP03001J
EUYF00AJEPD000IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEP0000800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000IJEP03001JEUYF009JEP03
001JEUYF00D0009JEPH000=JEP03001JEUYF00EJEP04001JEP000004Ool200000eYF001JEP03FUH2
000[Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000MJEP06001JEP00001JEP000UYF00<005YFFUH015YF00<005YFFUH0
0UYF10000UYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP00009JEP05001JEP00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP05FUH01@00FUIJ
EUYF00000eYF00@007ooOomoo`P000=JEP03001JEUYF009JEPD000Qoo`8000=JEP03001JEP0002]o
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001eYF1P000UYF00<005YFFUH015YF00<005YFFUH01UYF1P0015YF00<005YF00000eYF
00@005YF001JEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEPP000=JEP04001JEUYF0006Ool=000?Ool01P00FUIJEP00FUH002]oo`00
;Goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1@000UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP80009JEP03001JEUYF00AJEP<000IJEP03
001JEUYF00=JEPH000EJEP<000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000=JEP<000=JEP06001JEP00001JEP000UYF00<007ooOol01Goo0`006Goo00D0
05YF001JEP0002]oo`00;Woo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH00UYF4`00
0eYF00@005YFFUH000=JEPL00005Ool005YFFUH00005FUH50005FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20003FUH01000FUIJEP000UYF00@005YFFUIJEP80009JEP8002=oo`800003FUH007oo02Yo
o`00;Woo0UYF00<005YFFUH00UYF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04001JEUYF0004
FUH40007Ool01000FUIJEP001EYF1@001EYF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUIJ
EP<000EJEP800003FUH007oo025oo`@002aoo`00;Woo0UYF00<005YFFUH01P001eYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`001EYF00<007ooOol027oo00@005YFFUH000EJEPD000EJEP03001JEUYF
00AJEP05001JEUYFFUH00003FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF0P0015YF00@005YF0000021oo`80009J
EP8002aoo`00;Woo0UYF0`001EYF00<005YFFUH00UYF600015YF3@000UYF00<005YFFUH015YF0`00
1UYF00<005YFFUH00UYF0P0015YF00@005YFFUH000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUH000040002FUH00`00Oomo
o`0LOol20004FUH2000/Ool002ioo`l000Qoo`T000AJEP<0009JEP800003FUH005YF00AJEP03001J
EUYF00<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP05001JEUYFFUH00007FUH2000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF
00<005YFFUH00eYF1@0067oo2P0000=JEP000000;7oo000mOol80004FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUH000020007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH010003Goo1`00
0eYF100000IJEP00000005YF000/Ool003Eoo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH=0003FUH70002
FUH00`00FUIJEP04000]Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00AJEP03001J
EUYF00AJEP8000EJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60005FUH00`00FUIJEP05FUH00`00FUH000080003
FUH90003FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P00;Goo000ZOol50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH00`00FUIJEP03
FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH30003FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP03FUH01000FUIJEUYF1P0015YF200015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH00eYF10000UYF00<005YFFUH01UYF0P001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0009JEP8000=JEP@00003FUH005YF
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^
Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<000IJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEP0000<000MJEP03001J
EUYF00=JEP8000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0002FUH50005FUH60006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF1`00;goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP06
00000eYF001JEP08FUH00`00FUIJEP030009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF4@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00eYF1@000UYF00@005YF0000031oo`00:Woo00<005YF000015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEPd000IJEP03001JEUYF
00IJEP@000]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEP0000@000IJEP80039oo`00:Woo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP03FUH2000cOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH0009J
EP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@000UYF00<005YFFUH0
1EYF00<005YF00000`00=Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHD
0002FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03
001JEUYF00AJEP03001JEUYF009JEPP0009JEP03001JEUYF00IJEP03001JEUYF009JEPD003Uoo`00
:goo00<005YF000015YF00@005YFFUIJEPT000QJEP03001JEUYF00IJEP03001JEP000080009JEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF
00@005YFFUIJEPP000Qooa0003ioo`00:goo00<005YF00000UYF1`001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF3@0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF5P001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH02`0000EJEP00FUIJEP00
05Uoo`00:goo00<005YF00000`000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF009J
EPT0009oo`8000=JEP03001JEUYF009JEP80009oo`04001JEUYF0006FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0025YF00<005YFFUH02UYF2P0025YF00<005YFFUH01EYF00<005YFFUH00UYF100017oo
0`000eYF00<007ooOol0EWoo000[Ool20002FUH01000FUH000000eYF00<005YFFUH00UYF4@003Goo
0P0000=JEP00FUH01EYF00<007oo00000UYF00<005YFFUH015YF00<005YFFUH015YF1P000UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1P000UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol017oo0P000UYF0P0000=JEP00Ool0Egoo000/Ool?000POol20006FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUH00003FUH40006FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUIJEP02FUH01000
FUH00000F7oo000^Ool2000]Ool20004FUH00`00FUH00002FUH00`00FUIJEP03FUH400000eYF001J
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH01000Oomoogoo0`0015YF00@005YFFUH005Qoo`00;Woo0P00;goo00@005YFFUH0
009JEP04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH300000eYF001JEP03FUH01000Ool000000UYF00<005YFFUH0
0UYF00D005YFFUIJEP0005Moo`00;Woo00<007ooOol0;goo0`000UYF00D005YFFUH005YF008000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF008000AJEP8000EJEP03001JEUYF009JEP04001JEUYF001GOol002eoo`<0039oo`04
001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0001HOol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP02FUH00`00FUH0001HOol002eoo`03
001JEP0001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0006FUH0
0`00FUIJEP03FUH00`00Oomoo`1GOol002eoo`04001JEP00000FOol5000HOol30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH00eYF00<007ooOol0Egoo000]Ool0
1@00FUH005YF00005Goo1@006Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
00MJEP03001JEUYF008005Yoo`00;Woo00@005YFFUH001Ioo`<001Yoo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0007FUH3001LOol002ioo`05001JEUYFFUH0000cOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<007ooOol0G7oo000^Ool0
0`00FUIJEP02FUH00`00Oomoo`0`Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
00000eYF001JEP04FUH2001OOol002moo`04001JEUYFFUH3000`Ool30002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH20002FUH00`00FUIJEP02001QOol0031oo`04001JEUYF0002FUH00`00Oomoo`0]
Ool2000017oo000000001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF2000Hgoo000`Ool00`00FUH00004FUH2000]Ool2
0003Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUH000020005FUH3001SOol0035oo`8000IJEP03001oogoo02Uoo`8000Io
o`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP<000UJEP04001JEP00001QOol0039oo`03001JEUYF00AJEP<002Moo`@000Qoo`<00003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0
00QJEP04001JEUYFFUH3001NOol003=oo`8000AJEP03001JEUYF008002Aoo`04001JEUYF000<Ool7
0005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0000=0004FUH00`00
FUIJEP05FUH2001LOol003Eoo`04001JEUYF0005FUH2000POol20003FUH00`00Oomoo`0AOol;0006
FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004FUH60004Ool300000eYF001JEP07FUH3001JOol0
03Ioo`<000MJEP<001Uoo`@00005FUH005YFFUH0000OOolM00000eYF001JEP05FUH500000eYF0000
00020003Ool30006FUH01000FUIJEUYF0P00F7oo000hOol20006FUH00`00FUIJEP04000@Ool50004
FUH01000FUH00000<Goo3`001UYF0`001UYF10000Woo0P0015YF00<005YFFUH00eYF0P00EWoo000j
Ool20004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH20012Ool20005FUH00`00FUIJEP07
FUH00`00FUH0000500000eYF001JEP06FUH3001DOol003aoo`<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo04=oo`<00003FUH005YF00QJEP03001J
EUYF00AJEP@000IJEP05001JEUYFFUH0001COol003moo`<000IJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH20019Ool30008FUH00`00FUIJEP06FUH01000FUH0000015YF00@005YFFUIJ
EP80059oo`00@Woo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000004ioo`<000EJ
EP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEP00059oo`00AWoo1`00
15YF00<005YFFUH00UYF1P00Dgoo0`0000=JEP00FUH01eYF00<005YFFUH015YF0P000eYF0P00Dgoo
001=Ool9001LOol30007FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001oo`1BOol00;Eoo`@0
009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Aoo`00^Goo1P000eYF00L005YFFUIJEP00FUH0
001DOol00;moo`T005Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60336 .75501 m .59539 .70097 L .56453 .70271 L p .707 .577 .707 r
F P
0 g
s
.59539 .70097 m .60336 .75501 L .63489 .74994 L p .707 .577 .707 r
F P
0 g
s
.63489 .74994 m .62693 .69589 L .59539 .70097 L p .707 .577 .707 r
F P
0 g
s
.62693 .69589 m .63489 .74994 L .66403 .74203 L p .707 .577 .707 r
F P
0 g
s
.66403 .74203 m .65606 .68799 L .62693 .69589 L p .707 .577 .707 r
F P
0 g
s
.5725 .75675 m .56453 .70271 L .53738 .70094 L p .707 .577 .707 r
F P
0 g
s
.56453 .70271 m .5725 .75675 L .60336 .75501 L p .707 .577 .707 r
F P
0 g
s
.65606 .68799 m .66403 .74203 L .68791 .73206 L p .707 .577 .707 r
F P
0 g
s
.68791 .73206 m .67994 .67802 L .65606 .68799 L p .707 .577 .707 r
F P
0 g
s
.59063 .81642 m .58576 .78027 L .55485 .78173 L p .707 .577 .707 r
F P
0 g
s
.58576 .78027 m .59063 .81642 L .62221 .81169 L p .707 .577 .707 r
F P
0 g
s
.62221 .81169 m .61735 .77554 L .58576 .78027 L p .707 .577 .707 r
F P
0 g
s
.61735 .77554 m .62221 .81169 L .65136 .80415 L p .707 .577 .707 r
F P
0 g
s
.65136 .80415 m .6465 .768 L .61735 .77554 L p .707 .577 .707 r
F P
0 g
s
.54535 .75499 m .53738 .70094 L .5166 .69585 L p .707 .577 .707 r
F P
0 g
s
.53738 .70094 m .54535 .75499 L .5725 .75675 L p .707 .577 .707 r
F P
0 g
s
.55971 .81788 m .55485 .78173 L .52762 .77976 L p .707 .577 .707 r
F P
0 g
s
.55485 .78173 m .55971 .81788 L .59063 .81642 L p .707 .577 .707 r
F P
0 g
s
.6465 .768 m .65136 .80415 L .67524 .79453 L p .707 .577 .707 r
F P
0 g
s
.67524 .79453 m .67038 .75838 L .6465 .768 L p .707 .577 .707 r
F P
0 g
s
.67994 .67802 m .68791 .73206 L .7042 .72101 L p .707 .577 .707 r
F P
0 g
s
.7042 .72101 m .69623 .66696 L .67994 .67802 L p .707 .577 .707 r
F P
0 g
s
.59936 .84191 m .60293 .82336 L .57231 .81632 L p .707 .577 .707 r
F P
0 g
s
.60293 .82336 m .59936 .84191 L .63064 .84718 L p .707 .577 .707 r
F P
0 g
s
.63064 .84718 m .63422 .82863 L .60293 .82336 L p .707 .577 .707 r
F P
0 g
s
.52762 .77976 m .53248 .81591 L .55971 .81788 L p .707 .577 .707 r
F P
0 g
s
.57231 .81632 m .56874 .83487 L .59936 .84191 L p .707 .577 .707 r
F P
0 g
s
.63422 .82863 m .63064 .84718 L .65953 .85015 L p .707 .577 .707 r
F P
0 g
s
.65953 .85015 m .6631 .8316 L .63422 .82863 L p .707 .577 .707 r
F P
0 g
s
.53248 .81591 m .52762 .77976 L .50676 .77458 L p .707 .577 .707 r
F P
0 g
s
.56874 .83487 m .57231 .81632 L .54535 .80819 L p .707 .577 .707 r
F P
0 g
s
.5166 .69585 m .52457 .7499 L .54535 .75499 L p .707 .577 .707 r
F P
0 g
s
.54535 .80819 m .54178 .82675 L .56874 .83487 L p .707 .577 .707 r
F P
0 g
s
.52457 .7499 m .5166 .69585 L .50421 .68793 L p .707 .577 .707 r
F P
0 g
s
.67038 .75838 m .67524 .79453 L .6915 .78378 L p .707 .577 .707 r
F P
0 g
s
.6915 .78378 m .68664 .74763 L .67038 .75838 L p .707 .577 .707 r
F P
0 g
s
.50676 .77458 m .51162 .81072 L .53248 .81591 L p .707 .577 .707 r
F P
0 g
s
.6631 .8316 m .65953 .85015 L .68319 .85055 L p .707 .577 .707 r
F P
0 g
s
.68319 .85055 m .68676 .83199 L .6631 .8316 L p .707 .577 .707 r
F P
0 g
s
.69623 .66696 m .7042 .72101 L .7113 .70995 L p .707 .577 .707 r
F P
0 g
s
.7113 .70995 m .70333 .65591 L .69623 .66696 L p .707 .577 .707 r
F P
0 g
s
.54178 .82675 m .54535 .80819 L .52469 .79977 L p .707 .577 .707 r
F P
0 g
s
.52469 .79977 m .52112 .81833 L .54178 .82675 L p .707 .577 .707 r
F P
0 g
s
.51162 .81072 m .50676 .77458 L .49429 .76667 L p .707 .577 .707 r
F P
0 g
s
.50421 .68793 m .51218 .74197 L .52457 .7499 L p .707 .577 .707 r
F P
0 g
s
.68664 .74763 m .6915 .78378 L .69856 .77295 L p .707 .577 .707 r
F P
0 g
s
.69856 .77295 m .6937 .7368 L .68664 .74763 L p .707 .577 .707 r
F P
0 g
s
.68676 .83199 m .68319 .85055 L .6993 .84832 L p .707 .577 .707 r
F P
0 g
s
.6993 .84832 m .70288 .82976 L .68676 .83199 L p .707 .577 .707 r
F P
0 g
s
.51218 .74197 m .50421 .68793 L .50143 .67795 L p .707 .577 .707 r
F P
0 g
s
.49429 .76667 m .49915 .80282 L .51162 .81072 L p .707 .577 .707 r
F P
0 g
s
.52112 .81833 m .52469 .79977 L .51235 .79189 L p .707 .577 .707 r
F P
0 g
s
.70333 .65591 m .7113 .70995 L .70852 .69997 L p .707 .577 .707 r
F P
0 g
s
.70852 .69997 m .70055 .64593 L .70333 .65591 L p .707 .577 .707 r
F P
0 g
s
.51235 .79189 m .50878 .81044 L .52112 .81833 L p .707 .577 .707 r
F P
0 g
s
.49915 .80282 m .49429 .76667 L .49144 .75682 L p .707 .577 .707 r
F P
0 g
s
.50143 .67795 m .5094 .732 L .51218 .74197 L p .707 .577 .707 r
F P
0 g
s
.48863 .8218 m .48863 .31991 L .44475 .31708 L p .707 .577 .707 r
F P
0 g
s
.49144 .75682 m .4963 .79296 L .49915 .80282 L p .707 .577 .707 r
F P
0 g
s
.5094 .732 m .50143 .67795 L .50853 .66689 L p .707 .577 .707 r
F P
0 g
s
.50878 .81044 m .51235 .79189 L .50954 .78531 L p .707 .577 .707 r
F P
0 g
s
.50954 .78531 m .50597 .80386 L .50878 .81044 L p .707 .577 .707 r
F P
0 g
s
.4963 .79296 m .49144 .75682 L .4985 .74599 L p .707 .577 .707 r
F P
0 g
s
.50853 .66689 m .5165 .72094 L .5094 .732 L p .707 .577 .707 r
F P
0 g
s
.5165 .72094 m .50853 .66689 L .52482 .65584 L p .707 .577 .707 r
F P
0 g
s
.4985 .74599 m .50336 .78213 L .4963 .79296 L p .707 .577 .707 r
F P
0 g
s
.50597 .80386 m .50954 .78531 L .51654 .78068 L p .707 .577 .707 r
F P
0 g
s
.51654 .78068 m .51296 .79923 L .50597 .80386 L p .707 .577 .707 r
F P
0 g
s
.50336 .78213 m .4985 .74599 L .51476 .73524 L p .707 .577 .707 r
F P
0 g
s
.52482 .65584 m .53279 .70988 L .5165 .72094 L p .707 .577 .707 r
F P
0 g
s
.51476 .73524 m .51962 .77138 L .50336 .78213 L p .707 .577 .707 r
F P
0 g
s
.51296 .79923 m .51654 .78068 L .53265 .77845 L p .707 .577 .707 r
F P
0 g
s
.53265 .77845 m .52908 .797 L .51296 .79923 L p .707 .577 .707 r
F P
0 g
s
.51962 .77138 m .51476 .73524 L .53863 .72562 L p .707 .577 .707 r
F P
0 g
s
.53863 .72562 m .54349 .76177 L .51962 .77138 L p .707 .577 .707 r
F P
0 g
s
.52908 .797 m .53265 .77845 L .55631 .77884 L p .707 .577 .707 r
F P
0 g
s
.55631 .77884 m .55273 .79739 L .52908 .797 L p .707 .577 .707 r
F P
0 g
s
.48863 .31991 m .48863 .8218 L .53362 .82086 L p .707 .577 .707 r
F P
0 g
s
.53279 .70988 m .52482 .65584 L .5487 .64587 L p .707 .577 .707 r
F P
0 g
s
.5487 .64587 m .55667 .69991 L .53279 .70988 L p .707 .577 .707 r
F P
0 g
s
.53362 .82086 m .53362 .31897 L .48863 .31991 L p .707 .577 .707 r
F P
0 g
s
.55667 .69991 m .5487 .64587 L .57783 .63796 L p .707 .577 .707 r
F P
0 g
s
.57783 .63796 m .5858 .69201 L .55667 .69991 L p .707 .577 .707 r
F P
0 g
s
.54349 .76177 m .53863 .72562 L .56779 .71808 L p .707 .577 .707 r
F P
0 g
s
.56779 .71808 m .57265 .75422 L .54349 .76177 L p .707 .577 .707 r
F P
0 g
s
.55273 .79739 m .55631 .77884 L .58519 .78181 L p .707 .577 .707 r
F P
0 g
s
.58519 .78181 m .58162 .80037 L .55273 .79739 L p .707 .577 .707 r
F P
0 g
s
.53362 .31897 m .53362 .82086 L .57532 .81623 L p .707 .577 .707 r
F P
0 g
s
.57265 .75422 m .56779 .71808 L .59937 .71335 L p .707 .577 .707 r
F P
0 g
s
.59937 .71335 m .60423 .74949 L .57265 .75422 L p .707 .577 .707 r
F P
0 g
s
.57532 .81623 m .57532 .31434 L .53362 .31897 L p .707 .577 .707 r
F P
0 g
s
.6937 .7368 m .69856 .77295 L .69571 .7631 L p .707 .577 .707 r
F P
0 g
s
.69571 .7631 m .69085 .72695 L .6937 .7368 L p .707 .577 .707 r
F P
0 g
s
.70288 .82976 m .6993 .84832 L .7063 .84369 L p .707 .577 .707 r
F P
0 g
s
.7063 .84369 m .70987 .82513 L .70288 .82976 L p .707 .577 .707 r
F P
0 g
s
.44475 .81897 m .44475 .31708 L .40628 .31075 L p .707 .577 .707 r
F P
0 g
s
.44475 .31708 m .44475 .81897 L .48863 .8218 L p .707 .577 .707 r
F P
0 g
s
.70055 .64593 m .70852 .69997 L .69613 .69205 L p .707 .577 .707 r
F P
0 g
s
.69613 .69205 m .68816 .638 L .70055 .64593 L p .707 .577 .707 r
F P
0 g
s
.5858 .69201 m .57783 .63796 L .60937 .63289 L p .707 .577 .707 r
F P
0 g
s
.60937 .63289 m .61734 .68694 L .5858 .69201 L p .707 .577 .707 r
F P
0 g
s
.63029 .71189 m .63515 .74804 L .60423 .74949 L p .707 .577 .707 r
F P
0 g
s
.60423 .74949 m .59937 .71335 L .63029 .71189 L p .707 .577 .707 r
F P
0 g
s
.58162 .80037 m .58519 .78181 L .61648 .78708 L p .707 .577 .707 r
F P
0 g
s
.61648 .78708 m .6129 .80563 L .58162 .80037 L p .707 .577 .707 r
F P
0 g
s
.57532 .31434 m .57532 .81623 L .60965 .80837 L p .707 .577 .707 r
F P
0 g
s
.61734 .68694 m .60937 .63289 L .64023 .63115 L p .707 .577 .707 r
F P
0 g
s
.60965 .80837 m .60965 .30648 L .57532 .31434 L p .707 .577 .707 r
F P
0 g
s
.25637 .70092 m .25293 .64384 L .22181 .64474 L p .707 .577 .707 r
F P
0 g
s
.25293 .64384 m .25637 .70092 L .28814 .69866 L p .707 .577 .707 r
F P
0 g
s
.28814 .69866 m .28471 .64157 L .25293 .64384 L p .707 .577 .707 r
F P
0 g
s
.28471 .64157 m .28814 .69866 L .31747 .69526 L p .707 .577 .707 r
F P
0 g
s
.31747 .69526 m .31404 .63817 L .28471 .64157 L p .707 .577 .707 r
F P
0 g
s
.40628 .81264 m .40628 .31075 L .37698 .30154 L p .707 .577 .707 r
F P
0 g
s
.40628 .31075 m .40628 .81264 L .44475 .81897 L p .707 .577 .707 r
F P
0 g
s
.69085 .72695 m .69571 .7631 L .68324 .75519 L p .707 .577 .707 r
F P
0 g
s
.68324 .75519 m .67838 .71904 L .69085 .72695 L p .707 .577 .707 r
F P
0 g
s
.70987 .82513 m .7063 .84369 L .70349 .8371 L p .707 .577 .707 r
F P
0 g
s
.70349 .8371 m .70706 .81855 L .70987 .82513 L p .707 .577 .707 r
F P
0 g
s
.22525 .70182 m .22181 .64474 L .1944 .64419 L p .707 .577 .707 r
F P
0 g
s
.22181 .64474 m .22525 .70182 L .25637 .70092 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31404 .63817 m .31747 .69526 L .34147 .69105 L p .707 .577 .707 r
F P
0 g
s
.34147 .69105 m .33804 .63396 L .31404 .63817 L p .707 .577 .707 r
F P
0 g
s
.1944 .64419 m .19783 .70127 L .22525 .70182 L p .707 .577 .707 r
F P
0 g
s
.68816 .638 m .69613 .69205 L .67534 .68696 L p .707 .577 .707 r
F P
0 g
s
.67534 .68696 m .66738 .63291 L .68816 .638 L p .707 .577 .707 r
F P
0 g
s
.64023 .63115 m .6482 .6852 L .61734 .68694 L p .707 .577 .707 r
F P
0 g
s
.6471 .79412 m .64352 .81267 L .6129 .80563 L p .707 .577 .707 r
F P
0 g
s
.6129 .80563 m .61648 .78708 L .6471 .79412 L p .707 .577 .707 r
F P
0 g
s
.60965 .30648 m .60965 .80837 L .63324 .79804 L p .707 .577 .707 r
F P
0 g
s
.63515 .74804 m .63029 .71189 L .65751 .71385 L p .707 .577 .707 r
F P
0 g
s
.63324 .79804 m .63324 .29615 L .60965 .30648 L p .707 .577 .707 r
F P
0 g
s
.19783 .70127 m .1944 .64419 L .17337 .64224 L p .707 .577 .707 r
F P
0 g
s
.17337 .64224 m .1768 .69933 L .19783 .70127 L p .707 .577 .707 r
F P
0 g
s
.25097 .75914 m .24888 .72113 L .21774 .7218 L p .707 .577 .707 r
F P
0 g
s
.24888 .72113 m .25097 .75914 L .28275 .757 L p .707 .577 .707 r
F P
0 g
s
.28275 .757 m .28066 .71899 L .24888 .72113 L p .707 .577 .707 r
F P
0 g
s
.67838 .71904 m .68324 .75519 L .66238 .75 L p .707 .577 .707 r
F P
0 g
s
.66238 .75 m .65751 .71385 L .67838 .71904 L p .707 .577 .707 r
F P
0 g
s
.28066 .71899 m .28275 .757 L .31207 .75359 L p .707 .577 .707 r
F P
0 g
s
.31207 .75359 m .30998 .71558 L .28066 .71899 L p .707 .577 .707 r
F P
0 g
s
.33804 .63396 m .34147 .69105 L .3578 .68644 L p .707 .577 .707 r
F P
0 g
s
.3578 .68644 m .35437 .62935 L .33804 .63396 L p .707 .577 .707 r
F P
0 g
s
.21774 .7218 m .21983 .7598 L .25097 .75914 L p .707 .577 .707 r
F P
0 g
s
.37698 .80343 m .37698 .30154 L .35973 .29035 L p .707 .577 .707 r
F P
0 g
s
.37698 .30154 m .37698 .80343 L .40628 .81264 L p .707 .577 .707 r
F P
0 g
s
.70706 .81855 m .70349 .8371 L .69115 .82922 L p .707 .577 .707 r
F P
0 g
s
.69115 .82922 m .69472 .81067 L .70706 .81855 L p .707 .577 .707 r
F P
0 g
s
.21983 .7598 m .21774 .7218 L .19029 .72092 L p .707 .577 .707 r
F P
0 g
s
.66738 .63291 m .67534 .68696 L .6482 .6852 L p .707 .577 .707 r
F P
0 g
s
.6482 .6852 m .64023 .63115 L .66738 .63291 L p .707 .577 .707 r
F P
0 g
s
.25498 .83284 m .25653 .81565 L .22542 .81033 L p .707 .577 .707 r
F P
0 g
s
.25653 .81565 m .25498 .83284 L .2867 .83379 L p .707 .577 .707 r
F P
0 g
s
.2867 .83379 m .28825 .8166 L .25653 .81565 L p .707 .577 .707 r
F P
0 g
s
.19029 .72092 m .19238 .75892 L .21983 .7598 L p .707 .577 .707 r
F P
0 g
s
.28825 .8166 m .2867 .83379 L .31593 .83028 L p .707 .577 .707 r
F P
0 g
s
.31593 .83028 m .31748 .81309 L .28825 .8166 L p .707 .577 .707 r
F P
0 g
s
.22388 .82752 m .22542 .81033 L .19798 .80115 L p .707 .577 .707 r
F P
0 g
s
.22542 .81033 m .22388 .82752 L .25498 .83284 L p .707 .577 .707 r
F P
0 g
s
.30998 .71558 m .31207 .75359 L .33605 .74925 L p .707 .577 .707 r
F P
0 g
s
.33605 .74925 m .33396 .71124 L .30998 .71558 L p .707 .577 .707 r
F P
0 g
s
.1768 .69933 m .17337 .64224 L .16079 .63909 L p .707 .577 .707 r
F P
0 g
s
.19798 .80115 m .19643 .81835 L .22388 .82752 L p .707 .577 .707 r
F P
0 g
s
.19238 .75892 m .19029 .72092 L .16922 .71858 L p .707 .577 .707 r
F P
0 g
s
.16079 .63909 m .16422 .69617 L .1768 .69933 L p .707 .577 .707 r
F P
0 g
s
.65751 .71385 m .66238 .75 L .63515 .74804 L p .707 .577 .707 r
F P
0 g
s
.63324 .29615 m .63324 .79804 L .6438 .78627 L p .707 .577 .707 r
F P
0 g
s
.6438 .78627 m .6438 .28438 L .63324 .29615 L p .707 .577 .707 r
F P
0 g
s
.31748 .81309 m .31593 .83028 L .33981 .82265 L p .707 .577 .707 r
F P
0 g
s
.33981 .82265 m .34135 .80546 L .31748 .81309 L p .707 .577 .707 r
F P
0 g
s
.19643 .81835 m .19798 .80115 L .17688 .78903 L p .707 .577 .707 r
F P
0 g
s
.16922 .71858 m .17132 .75659 L .19238 .75892 L p .707 .577 .707 r
F P
0 g
s
.35437 .62935 m .3578 .68644 L .36486 .68189 L p .707 .577 .707 r
F P
0 g
s
.36486 .68189 m .36143 .6248 L .35437 .62935 L p .707 .577 .707 r
F P
0 g
s
.69472 .81067 m .69115 .82922 L .67048 .8208 L p .707 .577 .707 r
F P
0 g
s
.67048 .8208 m .67406 .80225 L .69472 .81067 L p .707 .577 .707 r
F P
0 g
s
.33396 .71124 m .33605 .74925 L .35234 .74439 L p .707 .577 .707 r
F P
0 g
s
.35234 .74439 m .35025 .70639 L .33396 .71124 L p .707 .577 .707 r
F P
0 g
s
.17688 .78903 m .17534 .80623 L .19643 .81835 L p .707 .577 .707 r
F P
0 g
s
.16422 .69617 m .16079 .63909 L .15789 .63504 L p .707 .577 .707 r
F P
0 g
s
.34135 .80546 m .33981 .82265 L .356 .81165 L p .707 .577 .707 r
F P
0 g
s
.356 .81165 m .35755 .79446 L .34135 .80546 L p .707 .577 .707 r
F P
0 g
s
.36196 .67784 m .35853 .62075 L .36143 .6248 L p .707 .577 .707 r
F P
0 g
s
.36292 .79835 m .36446 .78116 L .35755 .79446 L p .707 .577 .707 r
F P
0 g
s
.35853 .62075 m .36196 .67784 L .34938 .67469 L p .707 .577 .707 r
F P
0 g
s
.36143 .76687 m .35988 .78406 L .3472 .77018 L p .707 .577 .707 r
F P
0 g
s
.3472 .77018 m .34875 .75298 L .36143 .76687 L p .707 .577 .707 r
F P
0 g
s
.35973 .79224 m .35973 .29035 L .3562 .27828 L p .707 .577 .707 r
F P
0 g
s
.36143 .6248 m .36486 .68189 L .36196 .67784 L p .707 .577 .707 r
F P
0 g
s
.36446 .78116 m .36292 .79835 L .35988 .78406 L p .707 .577 .707 r
F P
0 g
s
.35988 .78406 m .36143 .76687 L .36446 .78116 L p .707 .577 .707 r
F P
0 g
s
.35973 .29035 m .35973 .79224 L .37698 .80343 L p .707 .577 .707 r
F P
0 g
s
.17132 .75659 m .16922 .71858 L .1566 .71502 L p .707 .577 .707 r
F P
0 g
s
.17534 .80623 m .17688 .78903 L .1642 .77515 L p .707 .577 .707 r
F P
0 g
s
.15789 .63504 m .16132 .69212 L .16422 .69617 L p .707 .577 .707 r
F P
0 g
s
.1566 .71502 m .15869 .75302 L .17132 .75659 L p .707 .577 .707 r
F P
0 g
s
.1642 .77515 m .16265 .79234 L .17534 .80623 L p .707 .577 .707 r
F P
0 g
s
.67406 .80225 m .67048 .8208 L .64352 .81267 L p .707 .577 .707 r
F P
0 g
s
.64352 .81267 m .6471 .79412 L .67406 .80225 L p .707 .577 .707 r
F P
0 g
s
.35025 .70639 m .35234 .74439 L .35936 .73951 L p .707 .577 .707 r
F P
0 g
s
.35936 .73951 m .35727 .7015 L .35025 .70639 L p .707 .577 .707 r
F P
0 g
s
.6438 .28438 m .6438 .78627 L .64027 .7742 L p .707 .577 .707 r
F P
0 g
s
.64027 .7742 m .64027 .27231 L .6438 .28438 L p .707 .577 .707 r
F P
0 g
s
.35755 .79446 m .356 .81165 L .36292 .79835 L p .707 .577 .707 r
F P
0 g
s
.16265 .79234 m .1642 .77515 L .16117 .76085 L p .707 .577 .707 r
F P
0 g
s
.15869 .75302 m .1566 .71502 L .15365 .71057 L p .707 .577 .707 r
F P
0 g
s
.16132 .69212 m .15789 .63504 L .16495 .63049 L p .707 .577 .707 r
F P
0 g
s
.15365 .71057 m .15574 .74858 L .15869 .75302 L p .707 .577 .707 r
F P
0 g
s
.16117 .76085 m .15962 .77805 L .16265 .79234 L p .707 .577 .707 r
F P
0 g
s
.16495 .63049 m .16838 .68757 L .16132 .69212 L p .707 .577 .707 r
F P
0 g
s
.35727 .7015 m .35936 .73951 L .35641 .73506 L p .707 .577 .707 r
F P
0 g
s
.35641 .73506 m .35432 .69706 L .35727 .7015 L p .707 .577 .707 r
F P
0 g
s
.34938 .67469 m .34595 .6176 L .35853 .62075 L p .707 .577 .707 r
F P
0 g
s
.35432 .69706 m .35641 .73506 L .34379 .7315 L p .707 .577 .707 r
F P
0 g
s
.3562 .27828 m .3562 .78017 L .35973 .79224 L p .707 .577 .707 r
F P
0 g
s
.3562 .78017 m .3562 .27828 L .36675 .2665 L p .707 .577 .707 r
F P
0 g
s
.15962 .77805 m .16117 .76085 L .16809 .74756 L p .707 .577 .707 r
F P
0 g
s
.16838 .68757 m .16495 .63049 L .18128 .62588 L p .707 .577 .707 r
F P
0 g
s
.15574 .74858 m .15365 .71057 L .16067 .70569 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64027 .27231 m .64027 .7742 L .62301 .76301 L p .707 .577 .707 r
F P
0 g
s
.62301 .76301 m .62301 .26112 L .64027 .27231 L p .707 .577 .707 r
F P
0 g
s
.16809 .74756 m .16654 .76475 L .15962 .77805 L p .707 .577 .707 r
F P
0 g
s
.16067 .70569 m .16276 .74369 L .15574 .74858 L p .707 .577 .707 r
F P
0 g
s
.18128 .62588 m .18471 .68297 L .16838 .68757 L p .707 .577 .707 r
F P
0 g
s
.34595 .6176 m .34938 .67469 L .32835 .67274 L p .707 .577 .707 r
F P
0 g
s
.32835 .67274 m .32492 .61565 L .34595 .6176 L p .707 .577 .707 r
F P
0 g
s
.34379 .7315 m .34169 .69349 L .35432 .69706 L p .707 .577 .707 r
F P
0 g
s
.16654 .76475 m .16809 .74756 L .18428 .73656 L p .707 .577 .707 r
F P
0 g
s
.36675 .76839 m .36675 .2665 L .39035 .25618 L p .707 .577 .707 r
F P
0 g
s
.36675 .2665 m .36675 .76839 L .3562 .78017 L p .707 .577 .707 r
F P
0 g
s
.18471 .68297 m .18128 .62588 L .20528 .62167 L p .707 .577 .707 r
F P
0 g
s
.16276 .74369 m .16067 .70569 L .17696 .70083 L p .707 .577 .707 r
F P
0 g
s
.18428 .73656 m .18273 .75375 L .16654 .76475 L p .707 .577 .707 r
F P
0 g
s
.20528 .62167 m .20872 .67876 L .18471 .68297 L p .707 .577 .707 r
F P
0 g
s
.17696 .70083 m .17906 .73884 L .16276 .74369 L p .707 .577 .707 r
F P
0 g
s
.32492 .61565 m .32835 .67274 L .30094 .67219 L p .707 .577 .707 r
F P
0 g
s
.30094 .67219 m .29751 .6151 L .32492 .61565 L p .707 .577 .707 r
F P
0 g
s
.62301 .26112 m .62301 .76301 L .59372 .7538 L p .707 .577 .707 r
F P
0 g
s
.59372 .7538 m .59372 .25191 L .62301 .26112 L p .707 .577 .707 r
F P
0 g
s
.34875 .75298 m .3472 .77018 L .3261 .75805 L p .707 .577 .707 r
F P
0 g
s
.3261 .75805 m .32765 .74086 L .34875 .75298 L p .707 .577 .707 r
F P
0 g
s
.34169 .69349 m .34379 .7315 L .32272 .72916 L p .707 .577 .707 r
F P
0 g
s
.32272 .72916 m .32063 .69116 L .34169 .69349 L p .707 .577 .707 r
F P
0 g
s
.20872 .67876 m .20528 .62167 L .23461 .61826 L p .707 .577 .707 r
F P
0 g
s
.18273 .75375 m .18428 .73656 L .20816 .72893 L p .707 .577 .707 r
F P
0 g
s
.29751 .6151 m .30094 .67219 L .26982 .67309 L p .707 .577 .707 r
F P
0 g
s
.26982 .67309 m .26639 .616 L .29751 .6151 L p .707 .577 .707 r
F P
0 g
s
.23461 .61826 m .23804 .67535 L .20872 .67876 L p .707 .577 .707 r
F P
0 g
s
.20816 .72893 m .20661 .74612 L .18273 .75375 L p .707 .577 .707 r
F P
0 g
s
.17906 .73884 m .17696 .70083 L .20094 .69649 L p .707 .577 .707 r
F P
0 g
s
.23804 .67535 m .23461 .61826 L .26639 .616 L p .707 .577 .707 r
F P
0 g
s
.39035 .25618 m .39035 .75807 L .36675 .76839 L p .707 .577 .707 r
F P
0 g
s
.39035 .75807 m .39035 .25618 L .42467 .24832 L p .707 .577 .707 r
F P
0 g
s
.26639 .616 m .26982 .67309 L .23804 .67535 L p .707 .577 .707 r
F P
0 g
s
.20094 .69649 m .20303 .7345 L .17906 .73884 L p .707 .577 .707 r
F P
0 g
s
.73018 .66809 m .73361 .61527 L .70249 .61075 L p .707 .577 .707 r
F P
0 g
s
.73361 .61527 m .73018 .66809 L .76196 .66867 L p .707 .577 .707 r
F P
0 g
s
.76196 .66867 m .76539 .61585 L .73361 .61527 L p .707 .577 .707 r
F P
0 g
s
.32765 .74086 m .3261 .75805 L .29866 .74888 L p .707 .577 .707 r
F P
0 g
s
.29866 .74888 m .30021 .73169 L .32765 .74086 L p .707 .577 .707 r
F P
0 g
s
.76539 .61585 m .76196 .66867 L .79128 .66524 L p .707 .577 .707 r
F P
0 g
s
.79128 .66524 m .79471 .61243 L .76539 .61585 L p .707 .577 .707 r
F P
0 g
s
.20661 .74612 m .20816 .72893 L .23739 .72541 L p .707 .577 .707 r
F P
0 g
s
.32063 .69116 m .32272 .72916 L .29527 .72828 L p .707 .577 .707 r
F P
0 g
s
.29527 .72828 m .29318 .69028 L .32063 .69116 L p .707 .577 .707 r
F P
0 g
s
.69906 .66357 m .70249 .61075 L .67508 .60273 L p .707 .577 .707 r
F P
0 g
s
.70249 .61075 m .69906 .66357 L .73018 .66809 L p .707 .577 .707 r
F P
0 g
s
.59372 .25191 m .59372 .7538 L .55525 .74746 L p .707 .577 .707 r
F P
0 g
s
.55525 .74746 m .55525 .24558 L .59372 .25191 L p .707 .577 .707 r
F P
0 g
s
.23739 .72541 m .23584 .74261 L .20661 .74612 L p .707 .577 .707 r
F P
0 g
s
.73586 .73097 m .73796 .69556 L .70682 .69127 L p .707 .577 .707 r
F P
0 g
s
.73796 .69556 m .73586 .73097 L .76765 .73142 L p .707 .577 .707 r
F P
0 g
s
.76765 .73142 m .76974 .69601 L .73796 .69556 L p .707 .577 .707 r
F P
0 g
s
.20303 .7345 m .20094 .69649 L .23026 .69308 L p .707 .577 .707 r
F P
0 g
s
.30021 .73169 m .29866 .74888 L .26756 .74356 L p .707 .577 .707 r
F P
0 g
s
.26756 .74356 m .26911 .72637 L .30021 .73169 L p .707 .577 .707 r
F P
0 g
s
.76974 .69601 m .76765 .73142 L .79696 .72799 L p .707 .577 .707 r
F P
0 g
s
.79696 .72799 m .79906 .69258 L .76974 .69601 L p .707 .577 .707 r
F P
0 g
s
.79471 .61243 m .79128 .66524 L .81529 .65815 L p .707 .577 .707 r
F P
0 g
s
.81529 .65815 m .81872 .60534 L .79471 .61243 L p .707 .577 .707 r
F P
0 g
s
.23584 .74261 m .23739 .72541 L .26911 .72637 L p .707 .577 .707 r
F P
0 g
s
.70472 .72668 m .70682 .69127 L .67937 .68357 L p .707 .577 .707 r
F P
0 g
s
.70682 .69127 m .70472 .72668 L .73586 .73097 L p .707 .577 .707 r
F P
0 g
s
.23026 .69308 m .23235 .73109 L .20303 .7345 L p .707 .577 .707 r
F P
0 g
s
.26911 .72637 m .26756 .74356 L .23584 .74261 L p .707 .577 .707 r
F P
0 g
s
.67164 .65554 m .67508 .60273 L .65405 .59199 L p .707 .577 .707 r
F P
0 g
s
.67508 .60273 m .67164 .65554 L .69906 .66357 L p .707 .577 .707 r
F P
0 g
s
.29318 .69028 m .29527 .72828 L .26413 .72895 L p .707 .577 .707 r
F P
0 g
s
.26413 .72895 m .26204 .69094 L .29318 .69028 L p .707 .577 .707 r
F P
0 g
s
.42467 .75021 m .42467 .24832 L .46637 .24369 L p .707 .577 .707 r
F P
0 g
s
.42467 .24832 m .42467 .75021 L .39035 .75807 L p .707 .577 .707 r
F P
0 g
s
.23235 .73109 m .23026 .69308 L .26204 .69094 L p .707 .577 .707 r
F P
0 g
s
.79906 .69258 m .79696 .72799 L .82094 .72101 L p .707 .577 .707 r
F P
0 g
s
.82094 .72101 m .82304 .68561 L .79906 .69258 L p .707 .577 .707 r
F P
0 g
s
.26204 .69094 m .26413 .72895 L .23235 .73109 L p .707 .577 .707 r
F P
0 g
s
.67728 .71897 m .67937 .68357 L .6583 .6732 L p .707 .577 .707 r
F P
0 g
s
.67937 .68357 m .67728 .71897 L .70472 .72668 L p .707 .577 .707 r
F P
0 g
s
.55525 .24558 m .55525 .74746 L .51137 .74463 L p .707 .577 .707 r
F P
0 g
s
.51137 .74463 m .51137 .24274 L .55525 .24558 L p .707 .577 .707 r
F P
0 g
s
.81872 .60534 m .81529 .65815 L .83162 .64809 L p .707 .577 .707 r
F P
0 g
s
.83162 .64809 m .83505 .59527 L .81872 .60534 L p .707 .577 .707 r
F P
0 g
s
.73244 .74043 m .73089 .72133 L .69979 .72324 L p .707 .577 .707 r
F P
0 g
s
.73089 .72133 m .73244 .74043 L .76416 .73762 L p .707 .577 .707 r
F P
0 g
s
.76416 .73762 m .76261 .71852 L .73089 .72133 L p .707 .577 .707 r
F P
0 g
s
.69979 .72324 m .70134 .74234 L .73244 .74043 L p .707 .577 .707 r
F P
0 g
s
.76261 .71852 m .76416 .73762 L .79339 .73418 L p .707 .577 .707 r
F P
0 g
s
.79339 .73418 m .79184 .71508 L .76261 .71852 L p .707 .577 .707 r
F P
0 g
s
.46637 .74558 m .46637 .24369 L .51137 .24274 L p .707 .577 .707 r
F P
0 g
s
.46637 .24369 m .46637 .74558 L .42467 .75021 L p .707 .577 .707 r
F P
0 g
s
.65062 .6448 m .65405 .59199 L .64147 .57958 L p .707 .577 .707 r
F P
0 g
s
.65405 .59199 m .65062 .6448 L .67164 .65554 L p .707 .577 .707 r
F P
0 g
s
.51137 .24274 m .51137 .74463 L .46637 .74558 L p .707 .577 .707 r
F P
0 g
s
.70134 .74234 m .69979 .72324 L .67235 .72406 L p .707 .577 .707 r
F P
0 g
s
.67235 .72406 m .67389 .74317 L .70134 .74234 L p .707 .577 .707 r
F P
0 g
s
.6583 .6732 m .65621 .7086 L .67728 .71897 L p .707 .577 .707 r
F P
0 g
s
.82304 .68561 m .82094 .72101 L .83724 .71117 L p .707 .577 .707 r
F P
0 g
s
.83724 .71117 m .83933 .67577 L .82304 .68561 L p .707 .577 .707 r
F P
0 g
s
.79184 .71508 m .79339 .73418 L .81727 .73046 L p .707 .577 .707 r
F P
0 g
s
.81727 .73046 m .81572 .71136 L .79184 .71508 L p .707 .577 .707 r
F P
0 g
s
.65621 .7086 m .6583 .6732 L .64568 .66118 L p .707 .577 .707 r
F P
0 g
s
.83505 .59527 m .83162 .64809 L .83868 .63604 L p .707 .577 .707 r
F P
0 g
s
.83868 .63604 m .84211 .58322 L .83505 .59527 L p .707 .577 .707 r
F P
0 g
s
.67389 .74317 m .67235 .72406 L .65125 .72372 L p .707 .577 .707 r
F P
0 g
s
.65125 .72372 m .6528 .74282 L .67389 .74317 L p .707 .577 .707 r
F P
0 g
s
.64147 .57958 m .63804 .6324 L .65062 .6448 L p .707 .577 .707 r
F P
0 g
s
.63804 .6324 m .64147 .57958 L .63857 .56672 L p .707 .577 .707 r
F P
0 g
s
.64568 .66118 m .64358 .69658 L .65621 .7086 L p .707 .577 .707 r
F P
0 g
s
.83933 .67577 m .83724 .71117 L .84426 .69943 L p .707 .577 .707 r
F P
0 g
s
.84426 .69943 m .84635 .66403 L .83933 .67577 L p .707 .577 .707 r
F P
0 g
s
.81572 .71136 m .81727 .73046 L .83346 .72681 L p .707 .577 .707 r
F P
0 g
s
.83346 .72681 m .83191 .70771 L .81572 .71136 L p .707 .577 .707 r
F P
0 g
s
.64358 .69658 m .64568 .66118 L .64273 .64869 L p .707 .577 .707 r
F P
0 g
s
.6528 .74282 m .65125 .72372 L .63857 .72225 L p .707 .577 .707 r
F P
0 g
s
.63857 .72225 m .64011 .74135 L .6528 .74282 L p .707 .577 .707 r
F P
0 g
s
.84211 .58322 m .83868 .63604 L .83577 .62318 L p .707 .577 .707 r
F P
0 g
s
.83577 .62318 m .83921 .57037 L .84211 .58322 L p .707 .577 .707 r
F P
0 g
s
.63857 .56672 m .63513 .61954 L .63804 .6324 L p .707 .577 .707 r
F P
0 g
s
.64273 .64869 m .64064 .68409 L .64358 .69658 L p .707 .577 .707 r
F P
0 g
s
.63513 .61954 m .63857 .56672 L .64563 .55467 L p .707 .577 .707 r
F P
0 g
s
.83191 .70771 m .83346 .72681 L .84038 .7236 L p .707 .577 .707 r
F P
0 g
s
.84038 .7236 m .83883 .7045 L .83191 .70771 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84635 .66403 m .84426 .69943 L .84131 .68694 L p .707 .577 .707 r
F P
0 g
s
.84131 .68694 m .8434 .65153 L .84635 .66403 L p .707 .577 .707 r
F P
0 g
s
.64064 .68409 m .64273 .64869 L .64975 .63695 L p .707 .577 .707 r
F P
0 g
s
.64011 .74135 m .63857 .72225 L .63553 .71978 L p .707 .577 .707 r
F P
0 g
s
.63553 .71978 m .63708 .73888 L .64011 .74135 L p .707 .577 .707 r
F P
0 g
s
.83921 .57037 m .83577 .62318 L .82319 .61078 L p .707 .577 .707 r
F P
0 g
s
.82319 .61078 m .82663 .55796 L .83921 .57037 L p .707 .577 .707 r
F P
0 g
s
.64563 .55467 m .64219 .60749 L .63513 .61954 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64975 .63695 m .64765 .67235 L .64064 .68409 L p .707 .577 .707 r
F P
0 g
s
.64219 .60749 m .64563 .55467 L .66196 .54461 L p .707 .577 .707 r
F P
0 g
s
.38266 .61436 m .39062 .5585 L .35977 .55278 L p .707 .577 .707 r
F P
0 g
s
.39062 .5585 m .38266 .61436 L .41419 .61807 L p .707 .577 .707 r
F P
0 g
s
.41419 .61807 m .42216 .56221 L .39062 .5585 L p .707 .577 .707 r
F P
0 g
s
.42216 .56221 m .41419 .61807 L .44333 .6194 L p .707 .577 .707 r
F P
0 g
s
.44333 .6194 m .4513 .56354 L .42216 .56221 L p .707 .577 .707 r
F P
0 g
s
.8434 .65153 m .84131 .68694 L .82868 .67492 L p .707 .577 .707 r
F P
0 g
s
.82868 .67492 m .83077 .63951 L .8434 .65153 L p .707 .577 .707 r
F P
0 g
s
.83883 .7045 m .84038 .7236 L .83735 .72113 L p .707 .577 .707 r
F P
0 g
s
.83735 .72113 m .8358 .70203 L .83883 .7045 L p .707 .577 .707 r
F P
0 g
s
.3518 .60864 m .35977 .55278 L .33262 .54561 L p .707 .577 .707 r
F P
0 g
s
.35977 .55278 m .3518 .60864 L .38266 .61436 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64765 .67235 m .64975 .63695 L .66604 .6271 L p .707 .577 .707 r
F P
0 g
s
.4513 .56354 m .44333 .6194 L .46721 .61823 L p .707 .577 .707 r
F P
0 g
s
.46721 .61823 m .47518 .56237 L .4513 .56354 L p .707 .577 .707 r
F P
0 g
s
.33262 .54561 m .32465 .60147 L .3518 .60864 L p .707 .577 .707 r
F P
0 g
s
.82663 .55796 m .82319 .61078 L .80217 .60004 L p .707 .577 .707 r
F P
0 g
s
.80217 .60004 m .8056 .54722 L .82663 .55796 L p .707 .577 .707 r
F P
0 g
s
.63708 .73888 m .63553 .71978 L .64245 .71657 L p .707 .577 .707 r
F P
0 g
s
.32465 .60147 m .33262 .54561 L .31183 .5377 L p .707 .577 .707 r
F P
0 g
s
.64245 .71657 m .644 .73567 L .63708 .73888 L p .707 .577 .707 r
F P
0 g
s
.66196 .54461 m .65853 .59743 L .64219 .60749 L p .707 .577 .707 r
F P
0 g
s
.65853 .59743 m .66196 .54461 L .68596 .53752 L p .707 .577 .707 r
F P
0 g
s
.39576 .67398 m .40062 .63672 L .36971 .63134 L p .707 .577 .707 r
F P
0 g
s
.40062 .63672 m .39576 .67398 L .42735 .67729 L p .707 .577 .707 r
F P
0 g
s
.42735 .67729 m .43221 .64003 L .40062 .63672 L p .707 .577 .707 r
F P
0 g
s
.66604 .6271 m .66395 .66251 L .64765 .67235 L p .707 .577 .707 r
F P
0 g
s
.43221 .64003 m .42735 .67729 L .4565 .67821 L p .707 .577 .707 r
F P
0 g
s
.4565 .67821 m .46136 .64095 L .43221 .64003 L p .707 .577 .707 r
F P
0 g
s
.83077 .63951 m .82868 .67492 L .80761 .66455 L p .707 .577 .707 r
F P
0 g
s
.80761 .66455 m .80971 .62914 L .83077 .63951 L p .707 .577 .707 r
F P
0 g
s
.36485 .6686 m .36971 .63134 L .34248 .62442 L p .707 .577 .707 r
F P
0 g
s
.36971 .63134 m .36485 .6686 L .39576 .67398 L p .707 .577 .707 r
F P
0 g
s
.31183 .5377 m .30387 .59356 L .32465 .60147 L p .707 .577 .707 r
F P
0 g
s
.8358 .70203 m .83735 .72113 L .82466 .71966 L p .707 .577 .707 r
F P
0 g
s
.82466 .71966 m .82311 .70056 L .8358 .70203 L p .707 .577 .707 r
F P
0 g
s
.66395 .66251 m .66604 .6271 L .69002 .62013 L p .707 .577 .707 r
F P
0 g
s
.47518 .56237 m .46721 .61823 L .4835 .61467 L p .707 .577 .707 r
F P
0 g
s
.4835 .61467 m .49147 .55881 L .47518 .56237 L p .707 .577 .707 r
F P
0 g
s
.38709 .732 m .38352 .71426 L .3529 .71725 L p .707 .577 .707 r
F P
0 g
s
.38352 .71426 m .38709 .732 L .41838 .72546 L p .707 .577 .707 r
F P
0 g
s
.41838 .72546 m .4148 .70772 L .38352 .71426 L p .707 .577 .707 r
F P
0 g
s
.34248 .62442 m .33762 .66168 L .36485 .6686 L p .707 .577 .707 r
F P
0 g
s
.8056 .54722 m .80217 .60004 L .77475 .59201 L p .707 .577 .707 r
F P
0 g
s
.77475 .59201 m .77818 .5392 L .8056 .54722 L p .707 .577 .707 r
F P
0 g
s
.4148 .70772 m .41838 .72546 L .44726 .716 L p .707 .577 .707 r
F P
0 g
s
.44726 .716 m .44369 .69826 L .4148 .70772 L p .707 .577 .707 r
F P
0 g
s
.46136 .64095 m .4565 .67821 L .48038 .67664 L p .707 .577 .707 r
F P
0 g
s
.48038 .67664 m .48524 .63938 L .46136 .64095 L p .707 .577 .707 r
F P
0 g
s
.30387 .59356 m .31183 .5377 L .29944 .5298 L p .707 .577 .707 r
F P
0 g
s
.68253 .59034 m .68596 .53752 L .71529 .5341 L p .707 .577 .707 r
F P
0 g
s
.68596 .53752 m .68253 .59034 L .65853 .59743 L p .707 .577 .707 r
F P
0 g
s
.3529 .71725 m .35647 .73498 L .38709 .732 L p .707 .577 .707 r
F P
0 g
s
.33762 .66168 m .34248 .62442 L .32162 .61663 L p .707 .577 .707 r
F P
0 g
s
.35647 .73498 m .3529 .71725 L .32594 .71638 L p .707 .577 .707 r
F P
0 g
s
.644 .73567 m .64245 .71657 L .65864 .71292 L p .707 .577 .707 r
F P
0 g
s
.44369 .69826 m .44726 .716 L .47092 .70456 L p .707 .577 .707 r
F P
0 g
s
.47092 .70456 m .46735 .68682 L .44369 .69826 L p .707 .577 .707 r
F P
0 g
s
.65864 .71292 m .66019 .73202 L .644 .73567 L p .707 .577 .707 r
F P
0 g
s
.69002 .62013 m .68793 .65553 L .66395 .66251 L p .707 .577 .707 r
F P
0 g
s
.80971 .62914 m .80761 .66455 L .78017 .65684 L p .707 .577 .707 r
F P
0 g
s
.78017 .65684 m .78226 .62144 L .80971 .62914 L p .707 .577 .707 r
F P
0 g
s
.77818 .5392 m .77475 .59201 L .74363 .58749 L p .707 .577 .707 r
F P
0 g
s
.74363 .58749 m .74706 .53467 L .77818 .5392 L p .707 .577 .707 r
F P
0 g
s
.32594 .71638 m .32951 .73412 L .35647 .73498 L p .707 .577 .707 r
F P
0 g
s
.32162 .61663 m .31675 .65389 L .33762 .66168 L p .707 .577 .707 r
F P
0 g
s
.29944 .5298 m .29148 .58566 L .30387 .59356 L p .707 .577 .707 r
F P
0 g
s
.71185 .58691 m .71529 .5341 L .74706 .53467 L p .707 .577 .707 r
F P
0 g
s
.71529 .5341 m .71185 .58691 L .68253 .59034 L p .707 .577 .707 r
F P
0 g
s
.68793 .65553 m .69002 .62013 L .71934 .6167 L p .707 .577 .707 r
F P
0 g
s
.74706 .53467 m .74363 .58749 L .71185 .58691 L p .707 .577 .707 r
F P
0 g
s
.48524 .63938 m .48038 .67664 L .49664 .67274 L p .707 .577 .707 r
F P
0 g
s
.49664 .67274 m .5015 .63548 L .48524 .63938 L p .707 .577 .707 r
F P
0 g
s
.49147 .55881 m .4835 .61467 L .4906 .60908 L p .707 .577 .707 r
F P
0 g
s
.4906 .60908 m .49857 .55321 L .49147 .55881 L p .707 .577 .707 r
F P
0 g
s
.32951 .73412 m .32594 .71638 L .30528 .71175 L p .707 .577 .707 r
F P
0 g
s
.82311 .70056 m .82466 .71966 L .80357 .71931 L p .707 .577 .707 r
F P
0 g
s
.80357 .71931 m .80202 .70021 L .82311 .70056 L p .707 .577 .707 r
F P
0 g
s
.78226 .62144 m .78017 .65684 L .74903 .65255 L p .707 .577 .707 r
F P
0 g
s
.74903 .65255 m .75112 .61715 L .78226 .62144 L p .707 .577 .707 r
F P
0 g
s
.46735 .68682 m .47092 .70456 L .48704 .69224 L p .707 .577 .707 r
F P
0 g
s
.48704 .69224 m .48346 .6745 L .46735 .68682 L p .707 .577 .707 r
F P
0 g
s
.71725 .6521 m .71934 .6167 L .75112 .61715 L p .707 .577 .707 r
F P
0 g
s
.71934 .6167 m .71725 .6521 L .68793 .65553 L p .707 .577 .707 r
F P
0 g
s
.31675 .65389 m .32162 .61663 L .30915 .60875 L p .707 .577 .707 r
F P
0 g
s
.30528 .71175 m .30885 .72949 L .32951 .73412 L p .707 .577 .707 r
F P
0 g
s
.29148 .58566 m .29944 .5298 L .29666 .52271 L p .707 .577 .707 r
F P
0 g
s
.75112 .61715 m .74903 .65255 L .71725 .6521 L p .707 .577 .707 r
F P
0 g
s
.66019 .73202 m .65864 .71292 L .68252 .7092 L p .707 .577 .707 r
F P
0 g
s
.30915 .60875 m .30429 .646 L .31675 .65389 L p .707 .577 .707 r
F P
0 g
s
.68252 .7092 m .68407 .7283 L .66019 .73202 L p .707 .577 .707 r
F P
0 g
s
.29666 .52271 m .28869 .57857 L .29148 .58566 L p .707 .577 .707 r
F P
0 g
s
.30885 .72949 m .30528 .71175 L .29294 .70381 L p .707 .577 .707 r
F P
0 g
s
.80202 .70021 m .80357 .71931 L .77612 .72014 L p .707 .577 .707 r
F P
0 g
s
.77612 .72014 m .77458 .70104 L .80202 .70021 L p .707 .577 .707 r
F P
0 g
s
.5015 .63548 m .49664 .67274 L .50369 .6669 L p .707 .577 .707 r
F P
0 g
s
.50369 .6669 m .50855 .62964 L .5015 .63548 L p .707 .577 .707 r
F P
0 g
s
.48346 .6745 m .48704 .69224 L .49403 .68026 L p .707 .577 .707 r
F P
0 g
s
.49403 .68026 m .49046 .66252 L .48346 .6745 L p .707 .577 .707 r
F P
0 g
s
.49857 .55321 m .4906 .60908 L .48782 .60198 L p .707 .577 .707 r
F P
0 g
s
.48782 .60198 m .49579 .54612 L .49857 .55321 L p .707 .577 .707 r
F P
0 g
s
.29294 .70381 m .29651 .72155 L .30885 .72949 L p .707 .577 .707 r
F P
0 g
s
.30429 .646 m .30915 .60875 L .3063 .60153 L p .707 .577 .707 r
F P
0 g
s
.68407 .7283 m .68252 .7092 L .71175 .70576 L p .707 .577 .707 r
F P
0 g
s
.71175 .70576 m .7133 .72486 L .68407 .7283 L p .707 .577 .707 r
F P
0 g
s
.28869 .57857 m .29666 .52271 L .30377 .51711 L p .707 .577 .707 r
F P
0 g
s
.3063 .60153 m .30144 .63878 L .30429 .646 L p .707 .577 .707 r
F P
0 g
s
.77458 .70104 m .77612 .72014 L .74502 .72205 L p .707 .577 .707 r
F P
0 g
s
.74502 .72205 m .74347 .70295 L .77458 .70104 L p .707 .577 .707 r
F P
0 g
s
.7133 .72486 m .71175 .70576 L .74347 .70295 L p .707 .577 .707 r
F P
0 g
s
.74347 .70295 m .74502 .72205 L .7133 .72486 L p .707 .577 .707 r
F P
0 g
s
.30377 .51711 m .2958 .57297 L .28869 .57857 L p .707 .577 .707 r
F P
0 g
s
.29651 .72155 m .29294 .70381 L .29013 .69334 L p .707 .578 .707 r
F P
0 g
s
.50855 .62964 m .50369 .6669 L .50085 .65968 L p .707 .577 .707 r
F P
0 g
s
.50085 .65968 m .50571 .62242 L .50855 .62964 L p .707 .577 .707 r
F P
0 g
s
.49046 .66252 m .49403 .68026 L .49122 .66978 L p .707 .578 .707 r
F P
0 g
s
.49122 .66978 m .48765 .65204 L .49046 .66252 L p .707 .578 .707 r
F P
0 g
s
.29013 .69334 m .2937 .71108 L .29651 .72155 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .54612 m .48782 .60198 L .47543 .59409 L p .707 .577 .707 r
F P
0 g
s
.47543 .59409 m .4834 .53823 L .49579 .54612 L p .707 .577 .707 r
F P
0 g
s
.30144 .63878 m .3063 .60153 L .31335 .59568 L p .707 .577 .707 r
F P
0 g
s
.2958 .57297 m .30377 .51711 L .32005 .51355 L p .707 .577 .707 r
F P
0 g
s
.31335 .59568 m .30849 .63294 L .30144 .63878 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32005 .51355 m .31209 .56941 L .2958 .57297 L p .707 .577 .707 r
F P
0 g
s
.2937 .71108 m .29013 .69334 L .29712 .68136 L p .707 .577 .707 r
F P
0 g
s
.48765 .65204 m .49122 .66978 L .47888 .66184 L p .707 .577 .707 r
F P
0 g
s
.47888 .66184 m .47531 .6441 L .48765 .65204 L p .707 .577 .707 r
F P
0 g
s
.50571 .62242 m .50085 .65968 L .48838 .65179 L p .707 .577 .707 r
F P
0 g
s
.48838 .65179 m .49324 .61453 L .50571 .62242 L p .707 .577 .707 r
F P
0 g
s
.29712 .68136 m .3007 .6991 L .2937 .71108 L p .707 .577 .707 r
F P
0 g
s
.4834 .53823 m .47543 .59409 L .45464 .58617 L p .707 .577 .707 r
F P
0 g
s
.45464 .58617 m .46261 .53031 L .4834 .53823 L p .707 .577 .707 r
F P
0 g
s
.30849 .63294 m .31335 .59568 L .32961 .59179 L p .707 .577 .707 r
F P
0 g
s
.31209 .56941 m .32005 .51355 L .34394 .51238 L p .707 .577 .707 r
F P
0 g
s
.32961 .59179 m .32475 .62904 L .30849 .63294 L p .707 .577 .707 r
F P
0 g
s
.34394 .51238 m .33597 .56824 L .31209 .56941 L p .707 .577 .707 r
F P
0 g
s
.3007 .6991 m .29712 .68136 L .31324 .66904 L p .707 .577 .707 r
F P
0 g
s
.46261 .53031 m .45464 .58617 L .42749 .57901 L p .707 .577 .707 r
F P
0 g
s
.42749 .57901 m .43546 .52314 L .46261 .53031 L p .707 .577 .707 r
F P
0 g
s
.47531 .6441 m .47888 .66184 L .45822 .65721 L p .707 .577 .707 r
F P
0 g
s
.45822 .65721 m .45465 .63947 L .47531 .6441 L p .707 .577 .707 r
F P
0 g
s
.49324 .61453 m .48838 .65179 L .46751 .644 L p .707 .577 .707 r
F P
0 g
s
.46751 .644 m .47237 .60674 L .49324 .61453 L p .707 .577 .707 r
F P
0 g
s
.33597 .56824 m .34394 .51238 L .37307 .51372 L p .707 .577 .707 r
F P
0 g
s
.31324 .66904 m .31681 .68678 L .3007 .6991 L p .707 .577 .707 r
F P
0 g
s
.32475 .62904 m .32961 .59179 L .35349 .59022 L p .707 .577 .707 r
F P
0 g
s
.43546 .52314 m .42749 .57901 L .39664 .57329 L p .707 .577 .707 r
F P
0 g
s
.39664 .57329 m .40461 .51743 L .43546 .52314 L p .707 .577 .707 r
F P
0 g
s
.37307 .51372 m .3651 .56958 L .33597 .56824 L p .707 .577 .707 r
F P
0 g
s
.35349 .59022 m .34863 .62748 L .32475 .62904 L p .707 .577 .707 r
F P
0 g
s
.3651 .56958 m .37307 .51372 L .40461 .51743 L p .707 .577 .707 r
F P
0 g
s
.40461 .51743 m .39664 .57329 L .3651 .56958 L p .707 .577 .707 r
F P
0 g
s
.31681 .68678 m .31324 .66904 L .33689 .65759 L p .707 .577 .707 r
F P
0 g
s
.45465 .63947 m .45822 .65721 L .43126 .65635 L p .707 .577 .707 r
F P
0 g
s
.43126 .65635 m .42768 .63861 L .45465 .63947 L p .707 .577 .707 r
F P
0 g
s
.47237 .60674 m .46751 .644 L .44029 .63708 L p .707 .577 .707 r
F P
0 g
s
.44029 .63708 m .44515 .59982 L .47237 .60674 L p .707 .577 .707 r
F P
0 g
s
.33689 .65759 m .34047 .67533 L .31681 .68678 L p .707 .577 .707 r
F P
0 g
s
.34863 .62748 m .35349 .59022 L .38265 .59114 L p .707 .577 .707 r
F P
0 g
s
.38265 .59114 m .37779 .62839 L .34863 .62748 L p .707 .577 .707 r
F P
0 g
s
.44515 .59982 m .44029 .63708 L .40937 .6317 L p .707 .577 .707 r
F P
0 g
s
.40937 .6317 m .41423 .59444 L .44515 .59982 L p .707 .577 .707 r
F P
0 g
s
.34047 .67533 m .33689 .65759 L .36578 .64813 L p .707 .577 .707 r
F P
0 g
s
.37779 .62839 m .38265 .59114 L .41423 .59444 L p .707 .577 .707 r
F P
0 g
s
.42768 .63861 m .43126 .65635 L .40064 .65933 L p .707 .577 .707 r
F P
0 g
s
.40064 .65933 m .39706 .64159 L .42768 .63861 L p .707 .577 .707 r
F P
0 g
s
.41423 .59444 m .40937 .6317 L .37779 .62839 L p .707 .577 .707 r
F P
0 g
s
.36578 .64813 m .36935 .66587 L .34047 .67533 L p .707 .577 .707 r
F P
0 g
s
.36935 .66587 m .36578 .64813 L .39706 .64159 L p .707 .577 .707 r
F P
0 g
s
.39706 .64159 m .40064 .65933 L .36935 .66587 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001NOol80002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00IWoo001IOol50003FUH00`00FUIJEP02FUH90009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol30000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol3
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00E7oo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo00<005YF00000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00E7oo0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80011oo`T004eoo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8000Yoo`H000AJEP03001JEUYF009JEPT004Aoo`00Dgoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP8000Moo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPH003ioo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH015YF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000<003Yoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003Ool30005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000hOol005=oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000=oo`0000000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00=Woo001COol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF008003Aoo`00Dgoo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF
001JEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00H005YFFUH005YF
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEP00031oo`00DWoo00<005YF00000UYF4`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00
DWoo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo001BOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH70004FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
059oo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60006
FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`05
001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
10000UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001BOol0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF100015YF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000]Ool005=oo`800003FUH005YF00AJ
EP03001JEUYF009JEPL000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300001eYF
001JEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20004FUH00`00FUIJEP03FUH60008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Eoo`8000EJEPD000=JEP04001JEUYFFUH90005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YF00000`005goo1P001UYF00<005YFFUH00UYF00<005YF
FUH00UYF0P00;Goo001GOol500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90005
FUH00`00FUIJEP03FUH01@00FUIJEP00FUH00P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH2000DOol3000:Ool40002FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH2000]Ool005Qoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPH000EJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP800003FUH00000019oo`D000eoo`<000AJEP07001J
EUYFFUH005YF0000;Goo001GOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP02FUH30005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0100015YF0`003goo1@0047oo0P00
0UYF00L005YFFUIJEP00FUH0000]Ool005Moo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00004FUH000000005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP03001J
EP0000<000]oo`D0019oo`<000=JEP03001JEP0002eoo`00Egoo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH0
0eYF00<005YFFUH00eYF1`001Goo0`003goo100000=JEP0000000eYF0P00;Woo001@Ool700000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009Ool5
0005FUH00`00FUH00002FUH2000^Ool003mooa4000AJEP05001JEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUH0000D0003FUH00`00FUIJEP04FUH01@00FUIJEP00
FUH00P00;Woo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00P000UYF00<005YFFUH015YF00@005YFFUIJEPH000=JEP03001JEUYF00IJEP03001J
EUYF009JEPH00003FUH005YF00EJEP04001JEUYFFUH3000^Ool0039oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF
00AJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000AJEP04
001JEUYFFUH3000^Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0003FUHE0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH300000eYF001JEP02FUH3000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00<000EJEP03001JEUYF00=J
EP@000=JEPT000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YF0000;Woo000/Ool3
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200001EYF
000005YF00001EYF00<005YFFUH01UYF00<005YF00001`0015YF10000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
000015YF000000000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00P0000AJEP00FUH002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH00UYF4@001EYF00<005YFFUH015YF00@005YFFUIJEP<000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH3000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPL000AJ
EP03001JEUYF00=JEP@00003FUH005YF00EJEP05001JEUYF001JEP02000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF100015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00;goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020004FUH01P00FUIJEUYF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YF
FUH00eYF10001UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF009J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH01000FUIJEUYF
0P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEP00;Goo000/Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH000020003FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH>0004FUH00`00FUH0000200001EYF000005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEPH000MJEP03
001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP0000EJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP@000MJEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001JEP0000800003FUH005YF0080
0006FUH00000001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0
05YF009JEP03001JEP0000D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
009JEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30008FUH00`00
FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00002
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000=JEP00FUH0
0UYF0`001EYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`001EYF00@005YF
FUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF10001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF100000IJEP00FUH005YF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00002Ool90004FUH00`00FUIJEP02FUH50004Ool20003FUH01000FUIJEUYF0P00;7oo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P001EYF00<005YFFUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00D005YF000005YF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH2000015YF000000000eYF00<005YFFUH00eYF00D005YFFUIJEP0000Moo`d0
00]oo`800003FUH005YF009JEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF4P001UYF00<005YF00000`000UYF00@005YFFUIJEPT000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP800004FUH000000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP05001JEUYF
FUH00007Ool5000EOol20003FUH2000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPT000QJEP04001JEUYFFUH20002FUH00`00FUIJEP04FUH20003FUH01000FUIJEP001EYF
00<005YFFUH015YF5@000UYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000=JEP<00003FUH005YF00=JEP05001JEUYFFUH00007Ool5000GOol0
0`00FUIJEP02000/Ool002eoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP06FUH0
1000FUIJEP001EYF00@005YFFUIJEP800003FUH005YF009JEP04001JEUYF0005FUH40006FUH00`00
FUIJEP09FUH01P00FUH00000FUH0009JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP020005FUH01000FUIJEP0027oo0`00
5goo0`0000=JEP00Ool0;7oo000]Ool00`00FUH00002FUH70007FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUH000001EYF00@005YF000000=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH20004FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00P007Woo0`000eYF
0P00;Goo000]Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH01000FUH000001EYF0P001EYF00<005YFFUH00P000UYF00<005YFFUH00eYF1@001EYF00<005YF
FUH02EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8000AJEP03001JEUYF00=JEP03001JEP0000<00003FUH0000001]oo`<00003FUH0
05YF00=JEP8002eoo`00;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF
3@000UYF00<005YFFUH0300000Eoo`00FUIJEP0000EJEPD000EJEP03001JEUYF00MJEP<000EJEP03
001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH6000BOol60004FUH00`00FUIJEP02FUH2000]Ool002io
o`80009JEP03001JEUYF00=JEP03001JEUYF00=JEPP000AJEP03001JEUYF00EJEP03001JEUYF00<0
00=JEP03001JEUYF00D0009oo`04001JEUYF0005FUH40006FUH00`00FUIJEP05FUH20002FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH00eYF00L005YFFUIJEP00FUH0000]Ool0031oo`D00003FUH0000000H000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30005FUH01000FUH0000025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000;Goo000`Ool60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUH0000200000eYF001JEP05FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF
8000;Woo000]Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0000AJEP00000000EJEP03001JEUYF00=JEPT000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00=JEP<000QJEP04001JEUYFFUH2000<
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF
FUH00UYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH00P00
0UYF00<005YFFUH00eYF00<005YF00000`0000=JEP00FUH025YF00H005YF000005YF000<FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF2P000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000015YF001JEUYF5`001EYF00<005YFFUH01UYF0`000eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH0000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEQ@0009JEP03001oogoo02aoo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH0
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000[Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH015YF10002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03000_Ool002]oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHL0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00D005YFFUIJEP0000=JEPP000QJEP03001JEP00008000EJEP03001JEUYF00EJEP04001J
EUYFFUH6000bOol002aoo`03001JEP0000=JEP03001JEUYF00=JEPH000EJEP03001JEUYF00IJEP03
001JEUYF00AJEP@00003FUH005YF00L000AJEP03001JEUYF009JEPL000MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/Ool0
0`00FUH00003FUH00`00FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH000030004FUH00`00FUH000080004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP<0
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT003moo`00;7oo00<005YF0000
0UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
00=JEP00FUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPT004Qoo`00;7oo00<005YF00000`000UYF
00<005YFFUH00eYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF0`000eYF0`000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEQL0055oo`00;7oo0P0000=JEP00FUH00UYF00<005YFFUH00eYF
1P0025YF00<005YFFUH01UYF1P001eYF00<005YFFUH00`000Woo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00AJEP`000aJEPT000QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00
FUIJEP03FUH01000FUIJEP00Egoo000/Ool40003FUH00`00FUH000030005FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF
00<005YFFUH01EYF2@002eYF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP800003Ool0000000D000=JEP04001JEUYF001GOol002eoo`<000=JEP800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH00003FUH005YF00EJEP03
001oo`00009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00D000IJEP04001JEUYFFUH20008Ool40002FUH00`00Oomoo`1E
Ool002eoo`03001JEP00009JEPP000AJEP03001JEUYF009JEQ8000Ioo`8000IJEP<0009JEP03001J
EUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP@0009JEP04001JEUYFFUH20006Ool20004FUH4001FOol002eoo`03001JEP00
008000Qoo`T001Yoo`8000AJEP<0009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20004
Ool200000eYF001JEP03FUH01000FUH00000EWoo000]Ool00`00FUH0000_Ool01000FUIJEP000UYF
00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF0080009oo`8000=JEP03001JEUYF
009JEP04001JEP00001FOol002eoo`80035oo`<0009JEP03001JEUYF00800003FUH005YF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000<000EJEP03001JEUYF00=JEP03001JEP0005Ioo`00;Goo0P006Goo
0`005goo00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50006FUH00`00FUIJ
EP03FUH00`00FUH0001FOol002eoo`8001Qoo`D001Moo`04001JEP000004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH000020006FUH00`00FUIJEP03FUH2001GOol002eoo`<001Moo`D001Qo
o`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEP00001JEP001UYF00<005YFFUH00UYF
0P00Egoo000]Ool200000eYF001oo`0EOol5000IOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000IJEP03001JEUYF009JEP03001oogoo05Ioo`00;Goo0P000UYF00<007oo
Ool057oo0`006Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0006FUH0
0`00FUIJEP02001IOol002ioo`05001JEUYFFUH0000cOol00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP04FUH3001KOol002ioo`04001JEUYFFUH3000`
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH60006FUH00`00Oomoo`1KOol002moo`04001J
EUYF0002FUH2000]Ool200000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJ
EUYF001JEP80009JEP8005ioo`00;goo00<005YF00001EYF0`00:Goo00H005YF001JEP00Ool30007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP<005moo`00<7oo0P001UYF00@005YF000002Ioo`03
001JEUYF008000Aoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP05FUH3001LOol0035oo`03001J
EUYF00AJEP04001JEUYFFUH3000QOol20003FUH20006Ool20004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP06FUH0
0`00FUH00002001IOol0039oo`8000=JEP03001JEUYF00EJEPD001Qoo`@00003FUH005YF009JEP03
001oogoo00Moo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@00003FUH0000000@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8005Mo
o`00=7oo0P0000=JEP00FUH01eYF00@005YFFUIJEPT000Uoo`H000AJEP03001JEUYF008000eoo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000P000Ioo`@000IJ
EP03001JEUYF00AJEP<005Eoo`00=Woo0`001eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH00eYF0`005Woo2`001UYF00<005YFFUH02UYF00<005YFFUH015YF40002Woo10000UYF
00<005YFFUH015YF00@005YFFUH005Aoo`00>Goo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P008goo6P0015YF00<005YFFUH02@003Woo100015YF00D0
05YFFUIJEP0005Aoo`00>goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUIJEP8003Qoo`800003FUH005YF00IJEP03001JEUYF00AJEPL0011oo`<00003FUH005YF009J
EP8005=oo`00?Woo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003aoo`<000EJ
EP03001JEUYF00MJEP03001JEUYF009JEPP000]oo`80009JEP03001JEP0005=oo`00A7oo2@0015YF
00<005YFFUH00UYF1@00@Goo100000=JEP00FUH025YF00<005YFFUH01UYF00@005YFFUIJEPh00004
FUH005YF001COol004eoo`T004Yoo`@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00<005Aoo`00Y7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00`00E7oo002XOol70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0005Aoo`00[goo200015YF00<005YFFUH015YF00@005YFFUIJEP8005Eoo`00]goo
4000EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58871 .74323 m .59668 .68736 L .56581 .68166 L p .707 .577 .707 r
F P
0 g
s
.59668 .68736 m .58871 .74323 L .62024 .74692 L p .707 .577 .707 r
F P
0 g
s
.62024 .74692 m .62821 .69106 L .59668 .68736 L p .707 .577 .707 r
F P
0 g
s
.62821 .69106 m .62024 .74692 L .64934 .74824 L p .707 .577 .707 r
F P
0 g
s
.64934 .74824 m .65732 .69238 L .62821 .69106 L p .707 .577 .707 r
F P
0 g
s
.55784 .73752 m .56581 .68166 L .53862 .6745 L p .707 .577 .707 r
F P
0 g
s
.56581 .68166 m .55784 .73752 L .58871 .74323 L p .707 .577 .707 r
F P
0 g
s
.65732 .69238 m .64934 .74824 L .67317 .74706 L p .707 .577 .707 r
F P
0 g
s
.67317 .74706 m .68115 .6912 L .65732 .69238 L p .707 .577 .707 r
F P
0 g
s
.53862 .6745 m .53065 .73036 L .55784 .73752 L p .707 .577 .707 r
F P
0 g
s
.53065 .73036 m .53862 .6745 L .51778 .66659 L p .707 .577 .707 r
F P
0 g
s
.60147 .80283 m .60633 .76557 L .57542 .76019 L p .707 .577 .707 r
F P
0 g
s
.60633 .76557 m .60147 .80283 L .63306 .80614 L p .707 .577 .707 r
F P
0 g
s
.63306 .80614 m .63792 .76889 L .60633 .76557 L p .707 .577 .707 r
F P
0 g
s
.63792 .76889 m .63306 .80614 L .66223 .80707 L p .707 .577 .707 r
F P
0 g
s
.66223 .80707 m .66709 .76981 L .63792 .76889 L p .707 .577 .707 r
F P
0 g
s
.57056 .79745 m .57542 .76019 L .54821 .75326 L p .707 .577 .707 r
F P
0 g
s
.57542 .76019 m .57056 .79745 L .60147 .80283 L p .707 .577 .707 r
F P
0 g
s
.51778 .66659 m .5098 .72245 L .53065 .73036 L p .707 .577 .707 r
F P
0 g
s
.68115 .6912 m .67317 .74706 L .68939 .74349 L p .707 .577 .707 r
F P
0 g
s
.68939 .74349 m .69737 .68763 L .68115 .6912 L p .707 .577 .707 r
F P
0 g
s
.59255 .86086 m .58898 .84312 L .55838 .84606 L p .707 .577 .707 r
F P
0 g
s
.58898 .84312 m .59255 .86086 L .62385 .85437 L p .707 .577 .707 r
F P
0 g
s
.62385 .85437 m .62028 .83662 L .58898 .84312 L p .707 .577 .707 r
F P
0 g
s
.54821 .75326 m .54335 .79052 L .57056 .79745 L p .707 .577 .707 r
F P
0 g
s
.62028 .83662 m .62385 .85437 L .65277 .84495 L p .707 .577 .707 r
F P
0 g
s
.65277 .84495 m .6492 .8272 L .62028 .83662 L p .707 .577 .707 r
F P
0 g
s
.66709 .76981 m .66223 .80707 L .68612 .8055 L p .707 .577 .707 r
F P
0 g
s
.68612 .8055 m .69098 .76825 L .66709 .76981 L p .707 .577 .707 r
F P
0 g
s
.5098 .72245 m .51778 .66659 L .50532 .6587 L p .707 .577 .707 r
F P
0 g
s
.55838 .84606 m .56195 .86381 L .59255 .86086 L p .707 .577 .707 r
F P
0 g
s
.54335 .79052 m .54821 .75326 L .52737 .74547 L p .707 .577 .707 r
F P
0 g
s
.56195 .86381 m .55838 .84606 L .53148 .84516 L p .707 .577 .707 r
F P
0 g
s
.6492 .8272 m .65277 .84495 L .6765 .83353 L p .707 .577 .707 r
F P
0 g
s
.6765 .83353 m .67293 .81578 L .6492 .8272 L p .707 .577 .707 r
F P
0 g
s
.53148 .84516 m .53505 .8629 L .56195 .86381 L p .707 .577 .707 r
F P
0 g
s
.52737 .74547 m .52251 .78273 L .54335 .79052 L p .707 .577 .707 r
F P
0 g
s
.50532 .6587 m .49734 .71456 L .5098 .72245 L p .707 .577 .707 r
F P
0 g
s
.69098 .76825 m .68612 .8055 L .70241 .80161 L p .707 .577 .707 r
F P
0 g
s
.70241 .80161 m .70727 .76435 L .69098 .76825 L p .707 .577 .707 r
F P
0 g
s
.69737 .68763 m .68939 .74349 L .69642 .73789 L p .707 .577 .707 r
F P
0 g
s
.69642 .73789 m .70439 .68203 L .69737 .68763 L p .707 .577 .707 r
F P
0 g
s
.53505 .8629 m .53148 .84516 L .5109 .8405 L p .707 .577 .707 r
F P
0 g
s
.67293 .81578 m .6765 .83353 L .69271 .82123 L p .707 .577 .707 r
F P
0 g
s
.69271 .82123 m .68914 .80348 L .67293 .81578 L p .707 .577 .707 r
F P
0 g
s
.52251 .78273 m .52737 .74547 L .51493 .73758 L p .707 .577 .707 r
F P
0 g
s
.49734 .71456 m .50532 .6587 L .50246 .65161 L p .707 .577 .707 r
F P
0 g
s
.5109 .8405 m .51447 .85824 L .53505 .8629 L p .707 .577 .707 r
F P
0 g
s
.51493 .73758 m .51007 .77484 L .52251 .78273 L p .707 .577 .707 r
F P
0 g
s
.50246 .65161 m .49448 .70747 L .49734 .71456 L p .707 .577 .707 r
F P
0 g
s
.51447 .85824 m .5109 .8405 L .49866 .83254 L p .707 .577 .707 r
F P
0 g
s
.70727 .76435 m .70241 .80161 L .70949 .79577 L p .707 .577 .707 r
F P
0 g
s
.70949 .79577 m .71435 .75851 L .70727 .76435 L p .707 .577 .707 r
F P
0 g
s
.68914 .80348 m .69271 .82123 L .69981 .80925 L p .707 .577 .707 r
F P
0 g
s
.69981 .80925 m .69624 .7915 L .68914 .80348 L p .707 .577 .707 r
F P
0 g
s
.70439 .68203 m .69642 .73789 L .69356 .73079 L p .707 .577 .707 r
F P
0 g
s
.69356 .73079 m .70154 .67493 L .70439 .68203 L p .707 .577 .707 r
F P
0 g
s
.49866 .83254 m .50223 .85028 L .51447 .85824 L p .707 .577 .707 r
F P
0 g
s
.51007 .77484 m .51493 .73758 L .51211 .73036 L p .707 .577 .707 r
F P
0 g
s
.49224 .82187 m .49224 .31998 L .44811 .31744 L p .707 .577 .707 r
F P
0 g
s
.49448 .70747 m .50246 .65161 L .50948 .646 L p .707 .577 .707 r
F P
0 g
s
.51211 .73036 m .50725 .76762 L .51007 .77484 L p .707 .577 .707 r
F P
0 g
s
.50948 .646 m .50151 .70186 L .49448 .70747 L p .707 .577 .707 r
F P
0 g
s
.50725 .76762 m .51211 .73036 L .51919 .72452 L p .707 .577 .707 r
F P
0 g
s
.50151 .70186 m .50948 .646 L .52571 .64243 L p .707 .577 .707 r
F P
0 g
s
.51919 .72452 m .51434 .76178 L .50725 .76762 L p .707 .577 .707 r
F P
0 g
s
.52571 .64243 m .51773 .6983 L .50151 .70186 L p .707 .577 .707 r
F P
0 g
s
.50223 .85028 m .49866 .83254 L .49595 .82205 L p .707 .578 .707 r
F P
0 g
s
.49595 .82205 m .49953 .8398 L .50223 .85028 L p .707 .578 .707 r
F P
0 g
s
.49953 .8398 m .49595 .82205 L .50306 .81008 L p .707 .577 .707 r
F P
0 g
s
.50306 .81008 m .50663 .82782 L .49953 .8398 L p .707 .577 .707 r
F P
0 g
s
.51434 .76178 m .51919 .72452 L .53548 .72063 L p .707 .577 .707 r
F P
0 g
s
.51773 .6983 m .52571 .64243 L .54953 .64125 L p .707 .577 .707 r
F P
0 g
s
.53548 .72063 m .53062 .75789 L .51434 .76178 L p .707 .577 .707 r
F P
0 g
s
.54953 .64125 m .54156 .69711 L .51773 .6983 L p .707 .577 .707 r
F P
0 g
s
.50663 .82782 m .50306 .81008 L .51926 .79778 L p .707 .577 .707 r
F P
0 g
s
.51926 .79778 m .52284 .81552 L .50663 .82782 L p .707 .577 .707 r
F P
0 g
s
.53062 .75789 m .53548 .72063 L .55938 .71907 L p .707 .577 .707 r
F P
0 g
s
.55938 .71907 m .55452 .75633 L .53062 .75789 L p .707 .577 .707 r
F P
0 g
s
.52284 .81552 m .51926 .79778 L .54299 .78636 L p .707 .577 .707 r
F P
0 g
s
.54299 .78636 m .54657 .8041 L .52284 .81552 L p .707 .577 .707 r
F P
0 g
s
.49224 .31998 m .49224 .82187 L .53713 .82062 L p .707 .577 .707 r
F P
0 g
s
.53713 .82062 m .53713 .31873 L .49224 .31998 L p .707 .577 .707 r
F P
0 g
s
.54156 .69711 m .54953 .64125 L .57864 .64257 L p .707 .577 .707 r
F P
0 g
s
.57864 .64257 m .57066 .69844 L .54156 .69711 L p .707 .577 .707 r
F P
0 g
s
.55452 .75633 m .55938 .71907 L .58855 .71999 L p .707 .577 .707 r
F P
0 g
s
.58855 .71999 m .58369 .75725 L .55452 .75633 L p .707 .577 .707 r
F P
0 g
s
.54657 .8041 m .54299 .78636 L .57192 .77694 L p .707 .577 .707 r
F P
0 g
s
.57192 .77694 m .57549 .79468 L .54657 .8041 L p .707 .577 .707 r
F P
0 g
s
.57549 .79468 m .57192 .77694 L .60322 .77044 L p .707 .577 .707 r
F P
0 g
s
.60322 .77044 m .60679 .78818 L .57549 .79468 L p .707 .577 .707 r
F P
0 g
s
.53713 .31873 m .53713 .82062 L .57839 .81571 L p .707 .577 .707 r
F P
0 g
s
.57066 .69844 m .57864 .64257 L .61017 .64627 L p .707 .577 .707 r
F P
0 g
s
.61017 .64627 m .60219 .70213 L .57066 .69844 L p .707 .577 .707 r
F P
0 g
s
.57839 .81571 m .57839 .31382 L .53713 .31873 L p .707 .577 .707 r
F P
0 g
s
.44811 .81933 m .44811 .31744 L .40906 .31137 L p .707 .577 .707 r
F P
0 g
s
.44811 .31744 m .44811 .81933 L .49224 .82187 L p .707 .577 .707 r
F P
0 g
s
.71435 .75851 m .70949 .79577 L .70668 .78855 L p .707 .577 .707 r
F P
0 g
s
.70668 .78855 m .71154 .75129 L .71435 .75851 L p .707 .577 .707 r
F P
0 g
s
.69624 .7915 m .69981 .80925 L .69711 .79877 L p .707 .578 .707 r
F P
0 g
s
.69711 .79877 m .69354 .78102 L .69624 .7915 L p .707 .578 .707 r
F P
0 g
s
.64104 .65197 m .63307 .70784 L .60219 .70213 L p .707 .577 .707 r
F P
0 g
s
.60219 .70213 m .61017 .64627 L .64104 .65197 L p .707 .577 .707 r
F P
0 g
s
.58369 .75725 m .58855 .71999 L .62013 .7233 L p .707 .577 .707 r
F P
0 g
s
.63382 .7675 m .63739 .78524 L .60679 .78818 L p .707 .577 .707 r
F P
0 g
s
.60679 .78818 m .60322 .77044 L .63382 .7675 L p .707 .577 .707 r
F P
0 g
s
.62013 .7233 m .61528 .76056 L .58369 .75725 L p .707 .577 .707 r
F P
0 g
s
.57839 .31382 m .57839 .81571 L .61197 .80762 L p .707 .577 .707 r
F P
0 g
s
.61197 .80762 m .61197 .30573 L .57839 .31382 L p .707 .577 .707 r
F P
0 g
s
.70154 .67493 m .69356 .73079 L .6811 .72291 L p .707 .577 .707 r
F P
0 g
s
.6811 .72291 m .68907 .66704 L .70154 .67493 L p .707 .577 .707 r
F P
0 g
s
.40906 .81326 m .40906 .31137 L .37891 .30236 L p .707 .577 .707 r
F P
0 g
s
.40906 .31137 m .40906 .81326 L .44811 .81933 L p .707 .577 .707 r
F P
0 g
s
.25021 .72331 m .25365 .67049 L .22251 .666 L p .707 .577 .707 r
F P
0 g
s
.25365 .67049 m .25021 .72331 L .28198 .72386 L p .707 .577 .707 r
F P
0 g
s
.28198 .72386 m .28542 .67104 L .25365 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28542 .67104 m .28198 .72386 L .31128 .72041 L p .707 .577 .707 r
F P
0 g
s
.31128 .72041 m .31471 .66759 L .28542 .67104 L p .707 .577 .707 r
F P
0 g
s
.21907 .71882 m .22251 .666 L .19506 .658 L p .707 .577 .707 r
F P
0 g
s
.22251 .666 m .21907 .71882 L .25021 .72331 L p .707 .577 .707 r
F P
0 g
s
.25555 .78619 m .25765 .75079 L .22651 .74649 L p .707 .577 .707 r
F P
0 g
s
.25765 .75079 m .25555 .78619 L .28734 .78665 L p .707 .577 .707 r
F P
0 g
s
.28734 .78665 m .28943 .75125 L .25765 .75079 L p .707 .577 .707 r
F P
0 g
s
.69354 .78102 m .69711 .79877 L .68487 .7908 L p .707 .577 .707 r
F P
0 g
s
.68487 .7908 m .6813 .77306 L .69354 .78102 L p .707 .577 .707 r
F P
0 g
s
.71154 .75129 m .70668 .78855 L .69424 .78066 L p .707 .577 .707 r
F P
0 g
s
.69424 .78066 m .6991 .7434 L .71154 .75129 L p .707 .577 .707 r
F P
0 g
s
.28943 .75125 m .28734 .78665 L .31667 .78323 L p .707 .577 .707 r
F P
0 g
s
.31667 .78323 m .31876 .74783 L .28943 .75125 L p .707 .577 .707 r
F P
0 g
s
.31471 .66759 m .31128 .72041 L .33523 .7133 L p .707 .577 .707 r
F P
0 g
s
.33523 .7133 m .33867 .66048 L .31471 .66759 L p .707 .577 .707 r
F P
0 g
s
.65104 .72869 m .64619 .76595 L .61528 .76056 L p .707 .577 .707 r
F P
0 g
s
.61528 .76056 m .62013 .7233 L .65104 .72869 L p .707 .577 .707 r
F P
0 g
s
.61197 .30573 m .61197 .80762 L .63459 .79714 L p .707 .577 .707 r
F P
0 g
s
.66823 .65913 m .66025 .71499 L .63307 .70784 L p .707 .577 .707 r
F P
0 g
s
.63307 .70784 m .64104 .65197 L .66823 .65913 L p .707 .577 .707 r
F P
0 g
s
.63739 .78524 m .63382 .7675 L .66072 .7684 L p .707 .577 .707 r
F P
0 g
s
.63459 .79714 m .63459 .29525 L .61197 .30573 L p .707 .577 .707 r
F P
0 g
s
.22442 .78189 m .22651 .74649 L .19908 .73877 L p .707 .577 .707 r
F P
0 g
s
.22651 .74649 m .22442 .78189 L .25555 .78619 L p .707 .577 .707 r
F P
0 g
s
.68907 .66704 m .6811 .72291 L .66025 .71499 L p .707 .577 .707 r
F P
0 g
s
.66025 .71499 m .66823 .65913 L .68907 .66704 L p .707 .577 .707 r
F P
0 g
s
.19162 .71082 m .19506 .658 L .17397 .64728 L p .707 .577 .707 r
F P
0 g
s
.19506 .658 m .19162 .71082 L .21907 .71882 L p .707 .577 .707 r
F P
0 g
s
.31876 .74783 m .31667 .78323 L .34067 .77626 L p .707 .577 .707 r
F P
0 g
s
.34067 .77626 m .34276 .74086 L .31876 .74783 L p .707 .577 .707 r
F P
0 g
s
.37891 .80425 m .37891 .30236 L .36061 .29129 L p .707 .577 .707 r
F P
0 g
s
.37891 .30236 m .37891 .80425 L .40906 .81326 L p .707 .577 .707 r
F P
0 g
s
.19699 .77417 m .19908 .73877 L .17804 .72839 L p .707 .577 .707 r
F P
0 g
s
.19908 .73877 m .19699 .77417 L .22442 .78189 L p .707 .577 .707 r
F P
0 g
s
.33867 .66048 m .33523 .7133 L .35149 .70323 L p .707 .577 .707 r
F P
0 g
s
.35149 .70323 m .35493 .65041 L .33867 .66048 L p .707 .577 .707 r
F P
0 g
s
.25188 .79563 m .25033 .77653 L .21925 .77843 L p .707 .577 .707 r
F P
0 g
s
.25033 .77653 m .25188 .79563 L .28361 .79284 L p .707 .577 .707 r
F P
0 g
s
.28361 .79284 m .28206 .77373 L .25033 .77653 L p .707 .577 .707 r
F P
0 g
s
.21925 .77843 m .2208 .79753 L .25188 .79563 L p .707 .577 .707 r
F P
0 g
s
.28206 .77373 m .28361 .79284 L .31288 .78942 L p .707 .577 .707 r
F P
0 g
s
.31288 .78942 m .31134 .77031 L .28206 .77373 L p .707 .577 .707 r
F P
0 g
s
.17053 .7001 m .17397 .64728 L .16132 .63489 L p .707 .577 .707 r
F P
0 g
s
.17397 .64728 m .17053 .7001 L .19162 .71082 L p .707 .577 .707 r
F P
0 g
s
.6813 .77306 m .68487 .7908 L .66429 .78614 L p .707 .577 .707 r
F P
0 g
s
.66429 .78614 m .66072 .7684 L .6813 .77306 L p .707 .577 .707 r
F P
0 g
s
.6991 .7434 m .69424 .78066 L .67339 .77287 L p .707 .577 .707 r
F P
0 g
s
.67339 .77287 m .67825 .73561 L .6991 .7434 L p .707 .577 .707 r
F P
0 g
s
.2208 .79753 m .21925 .77843 L .19187 .77924 L p .707 .577 .707 r
F P
0 g
s
.19187 .77924 m .19341 .79834 L .2208 .79753 L p .707 .577 .707 r
F P
0 g
s
.17804 .72839 m .17595 .76379 L .19699 .77417 L p .707 .577 .707 r
F P
0 g
s
.34276 .74086 m .34067 .77626 L .35699 .76642 L p .707 .577 .707 r
F P
0 g
s
.35699 .76642 m .35908 .73102 L .34276 .74086 L p .707 .577 .707 r
F P
0 g
s
.31134 .77031 m .31288 .78942 L .33683 .78571 L p .707 .577 .707 r
F P
0 g
s
.33683 .78571 m .33529 .76661 L .31134 .77031 L p .707 .577 .707 r
F P
0 g
s
.66072 .7684 m .66429 .78614 L .63739 .78524 L p .707 .577 .707 r
F P
0 g
s
.63459 .29525 m .63459 .79714 L .64404 .7853 L p .707 .577 .707 r
F P
0 g
s
.64404 .7853 m .64404 .28341 L .63459 .29525 L p .707 .577 .707 r
F P
0 g
s
.17595 .76379 m .17804 .72839 L .16544 .71637 L p .707 .577 .707 r
F P
0 g
s
.35493 .65041 m .35149 .70323 L .35848 .69117 L p .707 .577 .707 r
F P
0 g
s
.35848 .69117 m .36191 .63835 L .35493 .65041 L p .707 .577 .707 r
F P
0 g
s
.19341 .79834 m .19187 .77924 L .17085 .77889 L p .707 .577 .707 r
F P
0 g
s
.17085 .77889 m .1724 .798 L .19341 .79834 L p .707 .577 .707 r
F P
0 g
s
.16132 .63489 m .15788 .68771 L .17053 .7001 L p .707 .577 .707 r
F P
0 g
s
.67825 .73561 m .67339 .77287 L .64619 .76595 L p .707 .577 .707 r
F P
0 g
s
.64619 .76595 m .65104 .72869 L .67825 .73561 L p .707 .577 .707 r
F P
0 g
s
.35908 .73102 m .35699 .76642 L .36404 .75469 L p .707 .577 .707 r
F P
0 g
s
.36404 .75469 m .36613 .71928 L .35908 .73102 L p .707 .577 .707 r
F P
0 g
s
.36191 .63835 m .35848 .69117 L .3555 .67832 L p .707 .577 .707 r
F P
0 g
s
.3555 .67832 m .35893 .6255 L .36191 .63835 L p .707 .577 .707 r
F P
0 g
s
.36321 .70679 m .36112 .74219 L .34852 .73017 L p .707 .577 .707 r
F P
0 g
s
.34852 .73017 m .35061 .69477 L .36321 .70679 L p .707 .577 .707 r
F P
0 g
s
.36061 .79318 m .36061 .29129 L .35596 .27925 L p .707 .577 .707 r
F P
0 g
s
.36613 .71928 m .36404 .75469 L .36112 .74219 L p .707 .577 .707 r
F P
0 g
s
.36112 .74219 m .36321 .70679 L .36613 .71928 L p .707 .577 .707 r
F P
0 g
s
.36061 .29129 m .36061 .79318 L .37891 .80425 L p .707 .577 .707 r
F P
0 g
s
.15788 .68771 m .16132 .63489 L .15834 .62203 L p .707 .577 .707 r
F P
0 g
s
.16544 .71637 m .16335 .75177 L .17595 .76379 L p .707 .577 .707 r
F P
0 g
s
.33529 .76661 m .33683 .78571 L .35312 .78207 L p .707 .577 .707 r
F P
0 g
s
.35312 .78207 m .35157 .76297 L .33529 .76661 L p .707 .577 .707 r
F P
0 g
s
.16335 .75177 m .16544 .71637 L .16252 .70388 L p .707 .577 .707 r
F P
0 g
s
.1724 .798 m .17085 .77889 L .15827 .77742 L p .707 .577 .707 r
F P
0 g
s
.15827 .77742 m .15981 .79652 L .1724 .798 L p .707 .577 .707 r
F P
0 g
s
.15834 .62203 m .1549 .67486 L .15788 .68771 L p .707 .577 .707 r
F P
0 g
s
.16252 .70388 m .16043 .73928 L .16335 .75177 L p .707 .577 .707 r
F P
0 g
s
.64404 .28341 m .64404 .7853 L .63938 .77325 L p .707 .577 .707 r
F P
0 g
s
.63938 .77325 m .63938 .27137 L .64404 .28341 L p .707 .577 .707 r
F P
0 g
s
.1549 .67486 m .15834 .62203 L .16532 .60998 L p .707 .577 .707 r
F P
0 g
s
.35157 .76297 m .35312 .78207 L .36014 .77887 L p .707 .577 .707 r
F P
0 g
s
.36014 .77887 m .3586 .75977 L .35157 .76297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16043 .73928 m .16252 .70388 L .16957 .69214 L p .707 .577 .707 r
F P
0 g
s
.35893 .6255 m .3555 .67832 L .34284 .66593 L p .707 .577 .707 r
F P
0 g
s
.34284 .66593 m .34628 .61311 L .35893 .6255 L p .707 .577 .707 r
F P
0 g
s
.3586 .75977 m .36014 .77887 L .35722 .77641 L p .707 .577 .707 r
F P
0 g
s
.35722 .77641 m .35567 .75731 L .3586 .75977 L p .707 .577 .707 r
F P
0 g
s
.35567 .75731 m .35722 .77641 L .34463 .77493 L p .707 .577 .707 r
F P
0 g
s
.35596 .27925 m .35596 .78114 L .36061 .79318 L p .707 .577 .707 r
F P
0 g
s
.35596 .78114 m .35596 .27925 L .36541 .26741 L p .707 .577 .707 r
F P
0 g
s
.15981 .79652 m .15827 .77742 L .15534 .77496 L p .707 .577 .707 r
F P
0 g
s
.15534 .77496 m .15689 .79406 L .15981 .79652 L p .707 .577 .707 r
F P
0 g
s
.16532 .60998 m .16189 .6628 L .1549 .67486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16957 .69214 m .16748 .72754 L .16043 .73928 L p .707 .577 .707 r
F P
0 g
s
.16189 .6628 m .16532 .60998 L .18159 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16748 .72754 m .16957 .69214 L .18589 .6823 L p .707 .577 .707 r
F P
0 g
s
.63938 .27137 m .63938 .77325 L .62109 .76219 L p .707 .577 .707 r
F P
0 g
s
.62109 .76219 m .62109 .2603 L .63938 .27137 L p .707 .577 .707 r
F P
0 g
s
.34628 .61311 m .34284 .66593 L .32176 .65521 L p .707 .577 .707 r
F P
0 g
s
.32176 .65521 m .3252 .60239 L .34628 .61311 L p .707 .577 .707 r
F P
0 g
s
.15689 .79406 m .15534 .77496 L .16237 .77175 L p .707 .577 .707 r
F P
0 g
s
.16237 .77175 m .16391 .79085 L .15689 .79406 L p .707 .577 .707 r
F P
0 g
s
.18159 .59991 m .17815 .65273 L .16189 .6628 L p .707 .577 .707 r
F P
0 g
s
.17815 .65273 m .18159 .59991 L .20554 .5928 L p .707 .577 .707 r
F P
0 g
s
.36541 .7693 m .36541 .26741 L .38803 .25693 L p .707 .577 .707 r
F P
0 g
s
.36541 .26741 m .36541 .7693 L .35596 .78114 L p .707 .577 .707 r
F P
0 g
s
.18589 .6823 m .1838 .7177 L .16748 .72754 L p .707 .577 .707 r
F P
0 g
s
.35061 .69477 m .34852 .73017 L .32748 .71979 L p .707 .577 .707 r
F P
0 g
s
.32748 .71979 m .32957 .68439 L .35061 .69477 L p .707 .577 .707 r
F P
0 g
s
.34463 .77493 m .34309 .75583 L .35567 .75731 L p .707 .577 .707 r
F P
0 g
s
.1838 .7177 m .18589 .6823 L .20989 .67533 L p .707 .577 .707 r
F P
0 g
s
.3252 .60239 m .32176 .65521 L .2943 .64721 L p .707 .577 .707 r
F P
0 g
s
.2943 .64721 m .29774 .59439 L .3252 .60239 L p .707 .577 .707 r
F P
0 g
s
.2021 .64562 m .20554 .5928 L .23483 .58935 L p .707 .577 .707 r
F P
0 g
s
.20554 .5928 m .2021 .64562 L .17815 .65273 L p .707 .577 .707 r
F P
0 g
s
.16391 .79085 m .16237 .77175 L .17865 .76812 L p .707 .577 .707 r
F P
0 g
s
.62109 .2603 m .62109 .76219 L .59094 .75317 L p .707 .577 .707 r
F P
0 g
s
.59094 .75317 m .59094 .25128 L .62109 .2603 L p .707 .577 .707 r
F P
0 g
s
.17865 .76812 m .1802 .78722 L .16391 .79085 L p .707 .577 .707 r
F P
0 g
s
.20989 .67533 m .2078 .71073 L .1838 .7177 L p .707 .577 .707 r
F P
0 g
s
.32957 .68439 m .32748 .71979 L .30004 .71207 L p .707 .577 .707 r
F P
0 g
s
.30004 .71207 m .30214 .67667 L .32957 .68439 L p .707 .577 .707 r
F P
0 g
s
.29774 .59439 m .2943 .64721 L .26317 .64272 L p .707 .577 .707 r
F P
0 g
s
.26317 .64272 m .26661 .5899 L .29774 .59439 L p .707 .577 .707 r
F P
0 g
s
.2314 .64217 m .23483 .58935 L .26661 .5899 L p .707 .577 .707 r
F P
0 g
s
.23483 .58935 m .2314 .64217 L .2021 .64562 L p .707 .577 .707 r
F P
0 g
s
.2078 .71073 m .20989 .67533 L .23922 .67191 L p .707 .577 .707 r
F P
0 g
s
.26661 .5899 m .26317 .64272 L .2314 .64217 L p .707 .577 .707 r
F P
0 g
s
.38803 .25693 m .38803 .75882 L .36541 .7693 L p .707 .577 .707 r
F P
0 g
s
.38803 .75882 m .38803 .25693 L .42161 .24884 L p .707 .577 .707 r
F P
0 g
s
.73683 .64571 m .73339 .58863 L .70226 .58954 L p .707 .577 .707 r
F P
0 g
s
.73339 .58863 m .73683 .64571 L .7686 .64344 L p .707 .577 .707 r
F P
0 g
s
.7686 .64344 m .76516 .58635 L .73339 .58863 L p .707 .577 .707 r
F P
0 g
s
.34309 .75583 m .34463 .77493 L .32362 .77458 L p .707 .577 .707 r
F P
0 g
s
.32362 .77458 m .32207 .75548 L .34309 .75583 L p .707 .577 .707 r
F P
0 g
s
.30214 .67667 m .30004 .71207 L .26891 .70777 L p .707 .577 .707 r
F P
0 g
s
.26891 .70777 m .271 .67237 L .30214 .67667 L p .707 .577 .707 r
F P
0 g
s
.76516 .58635 m .7686 .64344 L .7979 .64002 L p .707 .577 .707 r
F P
0 g
s
.7979 .64002 m .79446 .58293 L .76516 .58635 L p .707 .577 .707 r
F P
0 g
s
.23713 .70731 m .23922 .67191 L .271 .67237 L p .707 .577 .707 r
F P
0 g
s
.23922 .67191 m .23713 .70731 L .2078 .71073 L p .707 .577 .707 r
F P
0 g
s
.70569 .64663 m .70226 .58954 L .6748 .589 L p .707 .577 .707 r
F P
0 g
s
.70226 .58954 m .70569 .64663 L .73683 .64571 L p .707 .577 .707 r
F P
0 g
s
.271 .67237 m .26891 .70777 L .23713 .70731 L p .707 .577 .707 r
F P
0 g
s
.1802 .78722 m .17865 .76812 L .2026 .76441 L p .707 .577 .707 r
F P
0 g
s
.2026 .76441 m .20415 .78351 L .1802 .78722 L p .707 .577 .707 r
F P
0 g
s
.6748 .589 m .67824 .64609 L .70569 .64663 L p .707 .577 .707 r
F P
0 g
s
.79446 .58293 m .7979 .64002 L .82185 .6358 L p .707 .577 .707 r
F P
0 g
s
.82185 .6358 m .81841 .57871 L .79446 .58293 L p .707 .577 .707 r
F P
0 g
s
.59094 .25128 m .59094 .75317 L .55189 .7471 L p .707 .577 .707 r
F P
0 g
s
.55189 .7471 m .55189 .24521 L .59094 .25128 L p .707 .577 .707 r
F P
0 g
s
.67824 .64609 m .6748 .589 L .65372 .58706 L p .707 .577 .707 r
F P
0 g
s
.32207 .75548 m .32362 .77458 L .29623 .7754 L p .707 .577 .707 r
F P
0 g
s
.29623 .7754 m .29469 .7563 L .32207 .75548 L p .707 .577 .707 r
F P
0 g
s
.42161 .75073 m .42161 .24884 L .46287 .24393 L p .707 .577 .707 r
F P
0 g
s
.42161 .24884 m .42161 .75073 L .38803 .75882 L p .707 .577 .707 r
F P
0 g
s
.65372 .58706 m .65715 .64414 L .67824 .64609 L p .707 .577 .707 r
F P
0 g
s
.73109 .70391 m .72899 .66591 L .69786 .66656 L p .707 .577 .707 r
F P
0 g
s
.72899 .66591 m .73109 .70391 L .76287 .70178 L p .707 .577 .707 r
F P
0 g
s
.76287 .70178 m .76078 .66377 L .72899 .66591 L p .707 .577 .707 r
F P
0 g
s
.20415 .78351 m .2026 .76441 L .23188 .76099 L p .707 .577 .707 r
F P
0 g
s
.76078 .66377 m .76287 .70178 L .7922 .69837 L p .707 .577 .707 r
F P
0 g
s
.7922 .69837 m .79011 .66037 L .76078 .66377 L p .707 .577 .707 r
F P
0 g
s
.23188 .76099 m .23342 .78009 L .20415 .78351 L p .707 .577 .707 r
F P
0 g
s
.81841 .57871 m .82185 .6358 L .83811 .63118 L p .707 .577 .707 r
F P
0 g
s
.83811 .63118 m .83467 .57409 L .81841 .57871 L p .707 .577 .707 r
F P
0 g
s
.69786 .66656 m .69995 .70457 L .73109 .70391 L p .707 .577 .707 r
F P
0 g
s
.69995 .70457 m .69786 .66656 L .67043 .66568 L p .707 .577 .707 r
F P
0 g
s
.73485 .77762 m .73639 .76043 L .70531 .75507 L p .707 .577 .707 r
F P
0 g
s
.73639 .76043 m .73485 .77762 L .76658 .77862 L p .707 .577 .707 r
F P
0 g
s
.76658 .77862 m .76812 .76143 L .73639 .76043 L p .707 .577 .707 r
F P
0 g
s
.55189 .24521 m .55189 .7471 L .50776 .74457 L p .707 .577 .707 r
F P
0 g
s
.50776 .74457 m .50776 .24268 L .55189 .24521 L p .707 .577 .707 r
F P
0 g
s
.29469 .7563 m .29623 .7754 L .26515 .7773 L p .707 .577 .707 r
F P
0 g
s
.26515 .7773 m .26361 .75819 L .29469 .7563 L p .707 .577 .707 r
F P
0 g
s
.67043 .66568 m .67252 .70369 L .69995 .70457 L p .707 .577 .707 r
F P
0 g
s
.76812 .76143 m .76658 .77862 L .79585 .77515 L p .707 .577 .707 r
F P
0 g
s
.79585 .77515 m .79739 .75796 L .76812 .76143 L p .707 .577 .707 r
F P
0 g
s
.46287 .74582 m .46287 .24393 L .50776 .24268 L p .707 .577 .707 r
F P
0 g
s
.46287 .24393 m .46287 .74582 L .42161 .75073 L p .707 .577 .707 r
F P
0 g
s
.70377 .77226 m .70531 .75507 L .67792 .74586 L p .707 .577 .707 r
F P
0 g
s
.70531 .75507 m .70377 .77226 L .73485 .77762 L p .707 .577 .707 r
F P
0 g
s
.23342 .78009 m .23188 .76099 L .26361 .75819 L p .707 .577 .707 r
F P
0 g
s
.79011 .66037 m .7922 .69837 L .8162 .69403 L p .707 .577 .707 r
F P
0 g
s
.8162 .69403 m .81411 .65603 L .79011 .66037 L p .707 .577 .707 r
F P
0 g
s
.65715 .64414 m .65372 .58706 L .64106 .58391 L p .707 .577 .707 r
F P
0 g
s
.26361 .75819 m .26515 .7773 L .23342 .78009 L p .707 .577 .707 r
F P
0 g
s
.50776 .24268 m .50776 .74457 L .46287 .74582 L p .707 .577 .707 r
F P
0 g
s
.67792 .74586 m .67638 .76305 L .70377 .77226 L p .707 .577 .707 r
F P
0 g
s
.64106 .58391 m .6445 .64099 L .65715 .64414 L p .707 .577 .707 r
F P
0 g
s
.67252 .70369 m .67043 .66568 L .64939 .66334 L p .707 .577 .707 r
F P
0 g
s
.79739 .75796 m .79585 .77515 L .8198 .76754 L p .707 .577 .707 r
F P
0 g
s
.8198 .76754 m .82135 .75035 L .79739 .75796 L p .707 .577 .707 r
F P
0 g
s
.67638 .76305 m .67792 .74586 L .65691 .73371 L p .707 .577 .707 r
F P
0 g
s
.64939 .66334 m .65148 .70135 L .67252 .70369 L p .707 .577 .707 r
F P
0 g
s
.83467 .57409 m .83811 .63118 L .8451 .62662 L p .707 .577 .707 r
F P
0 g
s
.8451 .62662 m .84166 .56954 L .83467 .57409 L p .707 .577 .707 r
F P
0 g
s
.81411 .65603 m .8162 .69403 L .83252 .68919 L p .707 .577 .707 r
F P
0 g
s
.83252 .68919 m .83043 .65118 L .81411 .65603 L p .707 .577 .707 r
F P
0 g
s
.65691 .73371 m .65536 .7509 L .67638 .76305 L p .707 .577 .707 r
F P
0 g
s
.6445 .64099 m .64106 .58391 L .63808 .57986 L p .707 .577 .707 r
F P
0 g
s
.82135 .75035 m .8198 .76754 L .83609 .75656 L p .707 .577 .707 r
F P
0 g
s
.83609 .75656 m .83763 .73937 L .82135 .75035 L p .707 .577 .707 r
F P
0 g
s
.65148 .70135 m .64939 .66334 L .63679 .65978 L p .707 .577 .707 r
F P
0 g
s
.65536 .7509 m .65691 .73371 L .64432 .7198 L p .707 .577 .707 r
F P
0 g
s
.63808 .57986 m .64152 .63694 L .6445 .64099 L p .707 .577 .707 r
F P
0 g
s
.63679 .65978 m .63888 .69778 L .65148 .70135 L p .707 .577 .707 r
F P
0 g
s
.64432 .7198 m .64278 .73699 L .65536 .7509 L p .707 .577 .707 r
F P
0 g
s
.84166 .56954 m .8451 .62662 L .84212 .62257 L p .707 .577 .707 r
F P
0 g
s
.84212 .62257 m .83868 .56549 L .84166 .56954 L p .707 .577 .707 r
F P
0 g
s
.83043 .65118 m .83252 .68919 L .83957 .6843 L p .707 .577 .707 r
F P
0 g
s
.83957 .6843 m .83748 .64629 L .83043 .65118 L p .707 .577 .707 r
F P
0 g
s
.83763 .73937 m .83609 .75656 L .84311 .74327 L p .707 .577 .707 r
F P
0 g
s
.84311 .74327 m .84466 .72608 L .83763 .73937 L p .707 .577 .707 r
F P
0 g
s
.64278 .73699 m .64432 .7198 L .6414 .7055 L p .707 .577 .707 r
F P
0 g
s
.64152 .63694 m .63808 .57986 L .64507 .5753 L p .707 .577 .707 r
F P
0 g
s
.63888 .69778 m .63679 .65978 L .63387 .65533 L p .707 .577 .707 r
F P
0 g
s
.63387 .65533 m .63596 .69334 L .63888 .69778 L p .707 .577 .707 r
F P
0 g
s
.6414 .7055 m .63986 .72269 L .64278 .73699 L p .707 .577 .707 r
F P
0 g
s
.64507 .5753 m .64851 .63239 L .64152 .63694 L p .707 .577 .707 r
F P
0 g
s
.83748 .64629 m .83957 .6843 L .83665 .67986 L p .707 .577 .707 r
F P
0 g
s
.83665 .67986 m .83456 .64185 L .83748 .64629 L p .707 .577 .707 r
F P
0 g
s
.83868 .56549 m .84212 .62257 L .82946 .61942 L p .707 .577 .707 r
F P
0 g
s
.82946 .61942 m .82603 .56233 L .83868 .56549 L p .707 .577 .707 r
F P
0 g
s
.84466 .72608 m .84311 .74327 L .84019 .72897 L p .707 .577 .707 r
F P
0 g
s
.84019 .72897 m .84173 .71178 L .84466 .72608 L p .707 .577 .707 r
F P
0 g
s
.63986 .72269 m .6414 .7055 L .64843 .6922 L p .707 .577 .707 r
F P
0 g
s
.3978 .62615 m .38983 .57211 L .35896 .57388 L p .707 .577 .707 r
F P
0 g
s
.38983 .57211 m .3978 .62615 L .42933 .62105 L p .707 .577 .707 r
F P
0 g
s
.42933 .62105 m .42136 .56701 L .38983 .57211 L p .707 .577 .707 r
F P
0 g
s
.42136 .56701 m .42933 .62105 L .45844 .61312 L p .707 .577 .707 r
F P
0 g
s
.45844 .61312 m .45046 .55908 L .42136 .56701 L p .707 .577 .707 r
F P
0 g
s
.64851 .63239 m .64507 .5753 L .66133 .57068 L p .707 .577 .707 r
F P
0 g
s
.63596 .69334 m .63387 .65533 L .64092 .65045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64843 .6922 m .64688 .70939 L .63986 .72269 L p .707 .577 .707 r
F P
0 g
s
.36693 .62792 m .35896 .57388 L .33177 .57214 L p .707 .577 .707 r
F P
0 g
s
.35896 .57388 m .36693 .62792 L .3978 .62615 L p .707 .577 .707 r
F P
0 g
s
.64092 .65045 m .64301 .68845 L .63596 .69334 L p .707 .577 .707 r
F P
0 g
s
.66133 .57068 m .66477 .62777 L .64851 .63239 L p .707 .577 .707 r
F P
0 g
s
.45046 .55908 m .45844 .61312 L .48227 .60313 L p .707 .577 .707 r
F P
0 g
s
.48227 .60313 m .47429 .54909 L .45046 .55908 L p .707 .577 .707 r
F P
0 g
s
.38472 .68757 m .37986 .65142 L .34895 .65286 L p .707 .577 .707 r
F P
0 g
s
.37986 .65142 m .38472 .68757 L .41631 .68285 L p .707 .577 .707 r
F P
0 g
s
.41631 .68285 m .41145 .6467 L .37986 .65142 L p .707 .577 .707 r
F P
0 g
s
.82603 .56233 m .82946 .61942 L .80838 .61748 L p .707 .577 .707 r
F P
0 g
s
.80838 .61748 m .80494 .56039 L .82603 .56233 L p .707 .577 .707 r
F P
0 g
s
.41145 .6467 m .41631 .68285 L .44548 .67532 L p .707 .577 .707 r
F P
0 g
s
.44548 .67532 m .44062 .63917 L .41145 .6467 L p .707 .577 .707 r
F P
0 g
s
.83456 .64185 m .83665 .67986 L .82405 .67629 L p .707 .577 .707 r
F P
0 g
s
.82405 .67629 m .82196 .63829 L .83456 .64185 L p .707 .577 .707 r
F P
0 g
s
.84173 .71178 m .84019 .72897 L .8276 .71506 L p .707 .577 .707 r
F P
0 g
s
.8276 .71506 m .82915 .69787 L .84173 .71178 L p .707 .577 .707 r
F P
0 g
s
.33974 .62618 m .33177 .57214 L .31092 .56707 L p .707 .577 .707 r
F P
0 g
s
.33177 .57214 m .33974 .62618 L .36693 .62792 L p .707 .577 .707 r
F P
0 g
s
.35381 .68901 m .34895 .65286 L .32174 .65089 L p .707 .577 .707 r
F P
0 g
s
.34895 .65286 m .35381 .68901 L .38472 .68757 L p .707 .577 .707 r
F P
0 g
s
.64688 .70939 m .64843 .6922 L .66471 .68122 L p .707 .577 .707 r
F P
0 g
s
.44062 .63917 m .44548 .67532 L .46937 .66571 L p .707 .577 .707 r
F P
0 g
s
.46937 .66571 m .46452 .62956 L .44062 .63917 L p .707 .577 .707 r
F P
0 g
s
.66477 .62777 m .66133 .57068 L .68528 .56646 L p .707 .577 .707 r
F P
0 g
s
.47429 .54909 m .48227 .60313 L .49849 .59207 L p .707 .577 .707 r
F P
0 g
s
.49849 .59207 m .49051 .53803 L .47429 .54909 L p .707 .577 .707 r
F P
0 g
s
.64301 .68845 m .64092 .65045 L .65724 .6456 L p .707 .577 .707 r
F P
0 g
s
.66471 .68122 m .66317 .69841 L .64688 .70939 L p .707 .577 .707 r
F P
0 g
s
.68528 .56646 m .68872 .62355 L .66477 .62777 L p .707 .577 .707 r
F P
0 g
s
.39321 .71304 m .39678 .69449 L .36618 .68743 L p .707 .577 .707 r
F P
0 g
s
.39678 .69449 m .39321 .71304 L .4245 .71832 L p .707 .577 .707 r
F P
0 g
s
.4245 .71832 m .42807 .69977 L .39678 .69449 L p .707 .577 .707 r
F P
0 g
s
.32174 .65089 m .3266 .68704 L .35381 .68901 L p .707 .577 .707 r
F P
0 g
s
.65724 .6456 m .65933 .6836 L .64301 .68845 L p .707 .577 .707 r
F P
0 g
s
.36618 .68743 m .36261 .70599 L .39321 .71304 L p .707 .577 .707 r
F P
0 g
s
.42807 .69977 m .4245 .71832 L .45343 .72131 L p .707 .577 .707 r
F P
0 g
s
.45343 .72131 m .457 .70276 L .42807 .69977 L p .707 .577 .707 r
F P
0 g
s
.80494 .56039 m .80838 .61748 L .78092 .61694 L p .707 .577 .707 r
F P
0 g
s
.78092 .61694 m .77749 .55985 L .80494 .56039 L p .707 .577 .707 r
F P
0 g
s
.3266 .68704 m .32174 .65089 L .3009 .64569 L p .707 .577 .707 r
F P
0 g
s
.31092 .56707 m .3189 .62111 L .33974 .62618 L p .707 .577 .707 r
F P
0 g
s
.36261 .70599 m .36618 .68743 L .33928 .6793 L p .707 .577 .707 r
F P
0 g
s
.33928 .6793 m .3357 .69785 L .36261 .70599 L p .707 .577 .707 r
F P
0 g
s
.82915 .69787 m .8276 .71506 L .80659 .7029 L p .707 .577 .707 r
F P
0 g
s
.80659 .7029 m .80813 .68571 L .82915 .69787 L p .707 .577 .707 r
F P
0 g
s
.3189 .62111 m .31092 .56707 L .29846 .55916 L p .707 .577 .707 r
F P
0 g
s
.46452 .62956 m .46937 .66571 L .48566 .65496 L p .707 .577 .707 r
F P
0 g
s
.48566 .65496 m .4808 .61881 L .46452 .62956 L p .707 .577 .707 r
F P
0 g
s
.82196 .63829 m .82405 .67629 L .80301 .67395 L p .707 .577 .707 r
F P
0 g
s
.80301 .67395 m .80092 .63595 L .82196 .63829 L p .707 .577 .707 r
F P
0 g
s
.68872 .62355 m .68528 .56646 L .71458 .56304 L p .707 .577 .707 r
F P
0 g
s
.66317 .69841 m .66471 .68122 L .68866 .67362 L p .707 .577 .707 r
F P
0 g
s
.3009 .64569 m .30576 .68184 L .3266 .68704 L p .707 .577 .707 r
F P
0 g
s
.457 .70276 m .45343 .72131 L .47716 .72172 L p .707 .577 .707 r
F P
0 g
s
.47716 .72172 m .48073 .70317 L .457 .70276 L p .707 .577 .707 r
F P
0 g
s
.49051 .53803 m .49849 .59207 L .50551 .581 L p .707 .577 .707 r
F P
0 g
s
.50551 .581 m .49754 .52696 L .49051 .53803 L p .707 .577 .707 r
F P
0 g
s
.71458 .56304 m .71802 .62013 L .68872 .62355 L p .707 .577 .707 r
F P
0 g
s
.77749 .55985 m .78092 .61694 L .74979 .61785 L p .707 .577 .707 r
F P
0 g
s
.74979 .61785 m .74635 .56077 L .77749 .55985 L p .707 .577 .707 r
F P
0 g
s
.3357 .69785 m .33928 .6793 L .3187 .67087 L p .707 .577 .707 r
F P
0 g
s
.68866 .67362 m .68712 .69081 L .66317 .69841 L p .707 .577 .707 r
F P
0 g
s
.65933 .6836 m .65724 .6456 L .68124 .64126 L p .707 .577 .707 r
F P
0 g
s
.3187 .67087 m .31512 .68942 L .3357 .69785 L p .707 .577 .707 r
F P
0 g
s
.71802 .62013 m .71458 .56304 L .74635 .56077 L p .707 .577 .707 r
F P
0 g
s
.74635 .56077 m .74979 .61785 L .71802 .62013 L p .707 .577 .707 r
F P
0 g
s
.30576 .68184 m .3009 .64569 L .28846 .63778 L p .707 .577 .707 r
F P
0 g
s
.68124 .64126 m .68333 .67927 L .65933 .6836 L p .707 .577 .707 r
F P
0 g
s
.29846 .55916 m .30644 .6132 L .3189 .62111 L p .707 .577 .707 r
F P
0 g
s
.80813 .68571 m .80659 .7029 L .7792 .69369 L p .707 .577 .707 r
F P
0 g
s
.7792 .69369 m .78074 .6765 L .80813 .68571 L p .707 .577 .707 r
F P
0 g
s
.68712 .69081 m .68866 .67362 L .71794 .67014 L p .707 .577 .707 r
F P
0 g
s
.80092 .63595 m .80301 .67395 L .77558 .67307 L p .707 .577 .707 r
F P
0 g
s
.77558 .67307 m .77349 .63506 L .80092 .63595 L p .707 .577 .707 r
F P
0 g
s
.4808 .61881 m .48566 .65496 L .49274 .64413 L p .707 .577 .707 r
F P
0 g
s
.49274 .64413 m .48788 .60798 L .4808 .61881 L p .707 .577 .707 r
F P
0 g
s
.48073 .70317 m .47716 .72172 L .49337 .7195 L p .707 .577 .707 r
F P
0 g
s
.49337 .7195 m .49694 .70095 L .48073 .70317 L p .707 .577 .707 r
F P
0 g
s
.30644 .6132 m .29846 .55916 L .2956 .54919 L p .707 .577 .707 r
F P
0 g
s
.28846 .63778 m .29332 .67393 L .30576 .68184 L p .707 .577 .707 r
F P
0 g
s
.71794 .67014 m .71639 .68733 L .68712 .69081 L p .707 .577 .707 r
F P
0 g
s
.31512 .68942 m .3187 .67087 L .30646 .66299 L p .707 .577 .707 r
F P
0 g
s
.68333 .67927 m .68124 .64126 L .71057 .63786 L p .707 .577 .707 r
F P
0 g
s
.78074 .6765 m .7792 .69369 L .74812 .68833 L p .707 .577 .707 r
F P
0 g
s
.74812 .68833 m .74966 .67114 L .78074 .6765 L p .707 .577 .707 r
F P
0 g
s
.71639 .68733 m .71794 .67014 L .74966 .67114 L p .707 .577 .707 r
F P
0 g
s
.49754 .52696 m .50551 .581 L .50266 .57103 L p .707 .577 .707 r
F P
0 g
s
.50266 .57103 m .49468 .51699 L .49754 .52696 L p .707 .577 .707 r
F P
0 g
s
.30646 .66299 m .30288 .68154 L .31512 .68942 L p .707 .577 .707 r
F P
0 g
s
.71057 .63786 m .71266 .67586 L .68333 .67927 L p .707 .577 .707 r
F P
0 g
s
.74966 .67114 m .74812 .68833 L .71639 .68733 L p .707 .577 .707 r
F P
0 g
s
.77349 .63506 m .77558 .67307 L .74444 .67373 L p .707 .577 .707 r
F P
0 g
s
.74444 .67373 m .74235 .63572 L .77349 .63506 L p .707 .577 .707 r
F P
0 g
s
.71266 .67586 m .71057 .63786 L .74235 .63572 L p .707 .577 .707 r
F P
0 g
s
.29332 .67393 m .28846 .63778 L .28564 .62793 L p .707 .577 .707 r
F P
0 g
s
.2956 .54919 m .30358 .60323 L .30644 .6132 L p .707 .577 .707 r
F P
0 g
s
.74235 .63572 m .74444 .67373 L .71266 .67586 L p .707 .577 .707 r
F P
0 g
s
.48788 .60798 m .49274 .64413 L .48993 .63428 L p .707 .577 .707 r
F P
0 g
s
.48993 .63428 m .48507 .59813 L .48788 .60798 L p .707 .577 .707 r
F P
0 g
s
.49694 .70095 m .49337 .7195 L .50047 .71488 L p .707 .577 .707 r
F P
0 g
s
.50047 .71488 m .50404 .69633 L .49694 .70095 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28564 .62793 m .2905 .66408 L .29332 .67393 L p .707 .577 .707 r
F P
0 g
s
.30358 .60323 m .2956 .54919 L .30263 .53813 L p .707 .577 .707 r
F P
0 g
s
.30288 .68154 m .30646 .66299 L .30375 .65641 L p .707 .577 .707 r
F P
0 g
s
.30375 .65641 m .30018 .67496 L .30288 .68154 L p .707 .577 .707 r
F P
0 g
s
.49468 .51699 m .50266 .57103 L .4902 .56312 L p .707 .577 .707 r
F P
0 g
s
.4902 .56312 m .48222 .50908 L .49468 .51699 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2905 .66408 m .28564 .62793 L .29273 .6171 L p .707 .577 .707 r
F P
0 g
s
.30263 .53813 m .3106 .59217 L .30358 .60323 L p .707 .577 .707 r
F P
0 g
s
.48507 .59813 m .48993 .63428 L .47749 .62637 L p .707 .577 .707 r
F P
0 g
s
.47749 .62637 m .47263 .59022 L .48507 .59813 L p .707 .577 .707 r
F P
0 g
s
.50404 .69633 m .50047 .71488 L .49777 .7083 L p .707 .577 .707 r
F P
0 g
s
.49777 .7083 m .50134 .68975 L .50404 .69633 L p .707 .577 .707 r
F P
0 g
s
.3106 .59217 m .30263 .53813 L .31885 .52706 L p .707 .577 .707 r
F P
0 g
s
.29273 .6171 m .29758 .65325 L .2905 .66408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30018 .67496 m .30375 .65641 L .31085 .65179 L p .707 .577 .707 r
F P
0 g
s
.48222 .50908 m .4902 .56312 L .46935 .55805 L p .707 .577 .707 r
F P
0 g
s
.46935 .55805 m .46137 .50401 L .48222 .50908 L p .707 .577 .707 r
F P
0 g
s
.31085 .65179 m .30728 .67034 L .30018 .67496 L p .707 .577 .707 r
F P
0 g
s
.29758 .65325 m .29273 .6171 L .30901 .60635 L p .707 .577 .707 r
F P
0 g
s
.31885 .52706 m .32683 .5811 L .3106 .59217 L p .707 .577 .707 r
F P
0 g
s
.32683 .5811 m .31885 .52706 L .34268 .51707 L p .707 .577 .707 r
F P
0 g
s
.47263 .59022 m .47749 .62637 L .45664 .62117 L p .707 .577 .707 r
F P
0 g
s
.45664 .62117 m .45178 .58502 L .47263 .59022 L p .707 .577 .707 r
F P
0 g
s
.50134 .68975 m .49777 .7083 L .48553 .70041 L p .707 .577 .707 r
F P
0 g
s
.48553 .70041 m .4891 .68186 L .50134 .68975 L p .707 .577 .707 r
F P
0 g
s
.30901 .60635 m .31387 .6425 L .29758 .65325 L p .707 .577 .707 r
F P
0 g
s
.46137 .50401 m .46935 .55805 L .44216 .55631 L p .707 .577 .707 r
F P
0 g
s
.44216 .55631 m .43419 .50227 L .46137 .50401 L p .707 .577 .707 r
F P
0 g
s
.30728 .67034 m .31085 .65179 L .32706 .64957 L p .707 .577 .707 r
F P
0 g
s
.32706 .64957 m .32349 .66812 L .30728 .67034 L p .707 .577 .707 r
F P
0 g
s
.31387 .6425 m .30901 .60635 L .33291 .59674 L p .707 .577 .707 r
F P
0 g
s
.34268 .51707 m .35065 .57111 L .32683 .5811 L p .707 .577 .707 r
F P
0 g
s
.35065 .57111 m .34268 .51707 L .37178 .50914 L p .707 .577 .707 r
F P
0 g
s
.43419 .50227 m .44216 .55631 L .41129 .55808 L p .707 .577 .707 r
F P
0 g
s
.41129 .55808 m .40332 .50404 L .43419 .50227 L p .707 .577 .707 r
F P
0 g
s
.45178 .58502 m .45664 .62117 L .42943 .6192 L p .707 .577 .707 r
F P
0 g
s
.42943 .6192 m .42458 .58305 L .45178 .58502 L p .707 .577 .707 r
F P
0 g
s
.37976 .56318 m .37178 .50914 L .40332 .50404 L p .707 .577 .707 r
F P
0 g
s
.37178 .50914 m .37976 .56318 L .35065 .57111 L p .707 .577 .707 r
F P
0 g
s
.33291 .59674 m .33777 .63289 L .31387 .6425 L p .707 .577 .707 r
F P
0 g
s
.40332 .50404 m .41129 .55808 L .37976 .56318 L p .707 .577 .707 r
F P
0 g
s
.4891 .68186 m .48553 .70041 L .46495 .69199 L p .707 .577 .707 r
F P
0 g
s
.46495 .69199 m .46852 .67344 L .4891 .68186 L p .707 .577 .707 r
F P
0 g
s
.33777 .63289 m .33291 .59674 L .36208 .58921 L p .707 .577 .707 r
F P
0 g
s
.32349 .66812 m .32706 .64957 L .35079 .64998 L p .707 .577 .707 r
F P
0 g
s
.42458 .58305 m .42943 .6192 L .39852 .62064 L p .707 .577 .707 r
F P
0 g
s
.39852 .62064 m .39367 .58449 L .42458 .58305 L p .707 .577 .707 r
F P
0 g
s
.35079 .64998 m .34722 .66853 L .32349 .66812 L p .707 .577 .707 r
F P
0 g
s
.36694 .62536 m .36208 .58921 L .39367 .58449 L p .707 .577 .707 r
F P
0 g
s
.36208 .58921 m .36694 .62536 L .33777 .63289 L p .707 .577 .707 r
F P
0 g
s
.39367 .58449 m .39852 .62064 L .36694 .62536 L p .707 .577 .707 r
F P
0 g
s
.46852 .67344 m .46495 .69199 L .43804 .68385 L p .707 .577 .707 r
F P
0 g
s
.43804 .68385 m .44161 .6653 L .46852 .67344 L p .707 .577 .707 r
F P
0 g
s
.34722 .66853 m .35079 .64998 L .37972 .65297 L p .707 .577 .707 r
F P
0 g
s
.37972 .65297 m .37615 .67152 L .34722 .66853 L p .707 .577 .707 r
F P
0 g
s
.44161 .6653 m .43804 .68385 L .40744 .6768 L p .707 .577 .707 r
F P
0 g
s
.40744 .6768 m .41102 .65825 L .44161 .6653 L p .707 .577 .707 r
F P
0 g
s
.37615 .67152 m .37972 .65297 L .41102 .65825 L p .707 .577 .707 r
F P
0 g
s
.41102 .65825 m .40744 .6768 L .37615 .67152 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000H000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001SOol30003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`<000IJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005ao
o`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00F7oo00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo00@005YFFUH000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Ioo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00@000EJEP03001JEUYF00AJEP@000EJEP<00007FUH005YFFUH005YF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000067oo7000<Goo001DOol200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
0`00FUIJEP020002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000?Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH00002000^Ool005Aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000AJEP`0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000Moo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP03
001JEUYF00=JEP@00003FUH005YF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP00008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00009oo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP04001JEUYFFUH;
0003FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00002000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001EOol00`00FUH00004FUH01000FUH000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005Eoo`04001JEUYF0003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo
00@005YFFUH0009JEP04001JEUYF0007FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF1`001EYF
00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo3`001goo00<005YF
FUH00`0015YF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
100000=JEP00FUH00eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<0
05YFFUH01UYF00<005YFFUH0100017oo0UYF0P001EYF00<005YF00000`0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00@005YFFUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUH000=JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP000002FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<goo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUH005YF001JEP0200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF0004FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00@000]J
EP<00004FUH005YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH01000FUIJEUYF2@0025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH04@000eYF00<005YFFUH02EYF00<005YF00000P000eYF00<005YFFUH00UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF10000UYF00<005YF00001UYF
1@0015YF00<005YFFUH02EYF0P000eYF0P0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00
;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00001EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP001UYF1@0015YF00<005YF
FUH01EYF100000=JEP00FUH00eYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF5`00
0UYF1000<Goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP0015YF00@005YF000000EJEP06001JEUYF001JEP001UYF1@0015YF00@0
05YFFUIJEP@000EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000bOol002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF009JEPl000AJEP04001JEUYF0004FUH30005FUH01`00FUIJEUYF001JEP0000IJ
EP@000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPP000=J
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080
02moo`00;Goo0P000eYF00<005YFFUH00eYF1P003goo1@000UYF00<005YFFUH00P000UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00006FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP00Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUH00003000IOol200000eYF0000000400000eYF0000000;0006FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0003FUH2000DOol30007Ool01000FUH000000UYF0`0000=JEP00FUH01EYF00@005YFFUIJEPL000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002aoo`03001JEP00009JEP03001JEUYF0080015oo`D000Ioo`800003FUH00000008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<0
05YF00000`0015YF0`003Woo1@001Woo0P0000EJEP00001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000/Ool00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5
0006Ool2000015YF000000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010000eYF00<005YFFUH015YF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000Aoo`<000Moo`800004FUH005YF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH2000:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH00UYF400000=JEP00FUH05P001UYF00<005YFFUH01eYF00<005YF0000100035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEQ<00003
FUH005YF008000=JEP<000MJEP03001JEUYF00EJEPD0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP@000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YFFUH00P00;Woo
000/Ool01@00FUIJEUYF00001UYF00<005YFFUH01P0015YF00<005YFFUH01UYF00@005YFFUIJEPH0
00=JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00IJ
EP03001JEP00008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF20001UYF00<005YFFUH00eYF100000=J
EP00FUH01EYF1@0000=JEP000000;Woo000/Ool01@00FUIJEUYF00001EYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF
00<005YF00000P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF2000
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00UYF0`00;Woo
000/Ool01@00FUIJEUYF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YF001JEP0000IJEP03001JEP0000<000MJEP`00003FUH00000008000IJEP03001JEUYF
00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH00eYF00<005YF0000;Woo000/Ool01P00FUIJEUYF001JEP<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000IJEP03001JEUYF00=JEPd000AJ
EP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF1@0000=JEP00FUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH01EYF0`000eYF0`00;goo000]Ool00`00FUIJEP020002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH025YF0`001EYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00D005YFFUIJEP0000EJEPH000MJ
EP03001JEUYF00EJEP@0009JEP03001JEUYF00EJEP03001JEUYF00<0039oo`00;Woo0`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00@005YF000000=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000
00=JEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP04
001JEUYFFUH2000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEPP000IJ
EP04001JEUYFFUH200000eYF001JEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP03FUH00`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3P000UYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000Ioo`<000EJEP80031oo`00;Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00`0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0000=JEP0000005`004Woo0P000eYF00<005YF0000;goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH005YF001JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP03001JEUYF009JEP03001oogoo01moo`04001JEUYF0002FUH00`00Oomoo`0/Ool002ioo`8000AJ
EP03001JEUYF00=JEPH000MJEP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEP00FUH0
0005FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0POol30003FUH00`00Oomoo`0[Ool002ioo`8000AJEP03001JEP0000D0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05
001JEP00FUH00006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH00000008000AJEP04001JEUYFFUH2000:Ool3000GOol01@00FUIJEUYF0000;Goo000^Ool2
0003FUH30006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000017oo000000001EYF00D0
05YF001JEP0000IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00AJEP03001JEUYF00@0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003
FUH300000eYF001JEP02FUH20009Ool5000GOol01000FUIJEP00;Goo000]Ool01000FUH005YF0P00
47oo4P002Goo0P000eYF00D005YF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080
00IJEP8000=JEP8000Uoo`D001Moo`05001JEP00FUH0000/Ool002eoo`03001JEP00008001Eoo`D0
01Aoo`800006FUH005YF001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P00
1UYF00D005YF000005YF008000Uoo`D001Qoo`800003FUH007oo02]oo`00;Goo0`000UYF00<007oo
Ool04Woo1@005Woo0P0000AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80
00EJEP04001JEUYFFUH2000;Ool3000JOol00`00FUH0000/Ool002eoo`8000=JEP<0019oo`D001Qo
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPH000AJEP8002Qoo`03
001JEP0002aoo`00;Goo0P000eYF00<005YFFUH00P004Goo0`005goo100000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF0`0000AJEP00FUH002Qoo`8002eoo`00;Goo
0P000eYF00<005YFFUH00UYF0`009Woo0P000eYF00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEP00008002Uoo`8002eoo`00;Goo0P00
0eYF00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00FUH00UYF00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0003FUH30004FUH2000UOol4000]Ool002ioo`05001J
EUYFFUH00005FUH00`00FUIJEP03FUH7000BOol50005FUH01`00FUIJEUYF001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000EJEP8000AJEP<0025oo`80009JEP03001oogoo02aoo`00;Woo00D005YF
FUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP07001JEUYF
FUH005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUH00004
0002FUH2000MOol20003FUH2000^Ool002moo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0002FUH00`00FUH00006FUH00`00FUIJEP04000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH60006FUH00`00FUIJEP02FUH01000
FUH000000UYF0P000eYF00<005YFFUH00eYF1@006Goo100000=JEP00FUH00UYF00<007ooOol0;Goo
000`Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0003FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP04FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUH00005FUH2
00000eYF001JEP06FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000;goo000aOol20005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000MJEP<000IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00AJEP04001JEUYF000`Ool0039oo`04001JEUYFFUH80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH02000FUIJEUYF001JEP00FUH30008
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000UYF00@005YF000000IJEP03001JEUYF008000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0035oo`00<Goo1@000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUIJ
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000040002FUH00`00FUIJ
EP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000c
Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF001JEP02FUH00`00FUH000030004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000eOol002aoo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEQL000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003
FUH005YF009JEP03001JEUYF00=JEP<00003FUH005YF009JEPD0009JEP03001JEUYF00IJEP03001J
EUYF009JEPH003Uoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4P001eYF
00<005YFFUH015YF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEUYF009JEP03001JEP00008000=JEP8000=ooa0003moo`00;7oo00<005YF0000
15YF00@005YFFUIJEPP000QJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00D0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJ
EP02000015YF001JEP00DWoo000/Ool00`00FUH00002FUH60007FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH01000FUIJEUYF1P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH020000eYF00D005YFFUH005YF00800003FUH007oo055oo`00;7oo00<005YF00000`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Woo00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH010000UYF00<0
05YFFUH00P00Dgoo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH9000AOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH0
0`00FUIJEP04FUH00`00FUIJEP04001COol002eoo`L0009JEP03001JEUYF009JEQ4001]oo`80009J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00AJEPD00003FUH007oo059oo`00
=7oo1`00;Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP<000QJEP03001JEUYF00AJEPH005Aoo`00Jgoo0P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF001FOol006eoo`<000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EQT0009JEP03001oogoo05Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01P004goo0P0000EJEP00FUIJEP0005Ioo`00Lgoo1`001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@000Woo1@004Goo00<005YFFUH00UYF
0P00Egoo001jOol;0006FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001goo1@003goo0`0015YF0P00
Egoo0025OolG000=Ool5000=Ool20002FUH00`00FUIJEP02FUH00`00Oomoo`1FOol008aoo`04001J
EUYFFUH2000HOol3000<Ool20004FUH01@00FUIJEUYF0000FGoo002<Ool01@00FUIJEUYF00009Woo
0P001eYF00<005YF0000FWoo002=Ool00`00FUH0000SOol400000eYF001JEP06FUH2001KOol008eo
o`<001ioo`D000EJEP03001JEUYF00AJEP8005aoo`00SGoo00<005YFFUH00`005goo10000UYF00<0
05YFFUH01UYF00@005YFFUIJEP8005ioo`00SGoo0P000UYF00<005YF00000P003Goo1`001UYF00<0
05YFFUH01UYF00@005YF0000061oo`00SWoo00@005YFFUH000AJEPd000AJEP03001JEUYF00MJEP03
001JEUYF00AJEP<0069oo`00SWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00@006Eoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEPD006Uoo`00T7oo0`001EYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01000KWoo002BOol30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH7001bOol009Eo
o`l007Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58406 .73895 m .5969 .68356 L .56652 .67549 L p .707 .577 .707 r
F P
0 g
s
.5969 .68356 m .58406 .73895 L .61511 .74543 L p .707 .577 .707 r
F P
0 g
s
.61511 .74543 m .62794 .69004 L .5969 .68356 L p .707 .577 .707 r
F P
0 g
s
.62794 .69004 m .61511 .74543 L .64378 .74969 L p .707 .577 .707 r
F P
0 g
s
.64378 .74969 m .65661 .6943 L .62794 .69004 L p .707 .577 .707 r
F P
0 g
s
.55369 .73088 m .56652 .67549 L .53978 .66662 L p .707 .577 .707 r
F P
0 g
s
.56652 .67549 m .55369 .73088 L .58406 .73895 L p .707 .577 .707 r
F P
0 g
s
.53978 .66662 m .52695 .72201 L .55369 .73088 L p .707 .577 .707 r
F P
0 g
s
.65661 .6943 m .64378 .74969 L .66727 .7513 L p .707 .577 .707 r
F P
0 g
s
.66727 .7513 m .68011 .69591 L .65661 .6943 L p .707 .577 .707 r
F P
0 g
s
.52695 .72201 m .53978 .66662 L .51931 .65781 L p .707 .577 .707 r
F P
0 g
s
.60472 .79824 m .61254 .76121 L .58205 .75366 L p .707 .577 .707 r
F P
0 g
s
.61254 .76121 m .60472 .79824 L .6359 .8041 L p .707 .577 .707 r
F P
0 g
s
.6359 .8041 m .64372 .76707 L .61254 .76121 L p .707 .577 .707 r
F P
0 g
s
.51931 .65781 m .50647 .7132 L .52695 .72201 L p .707 .577 .707 r
F P
0 g
s
.64372 .76707 m .6359 .8041 L .66472 .8077 L p .707 .577 .707 r
F P
0 g
s
.66472 .8077 m .67254 .77068 L .64372 .76707 L p .707 .577 .707 r
F P
0 g
s
.57423 .79069 m .58205 .75366 L .55524 .74517 L p .707 .577 .707 r
F P
0 g
s
.58205 .75366 m .57423 .79069 L .60472 .79824 L p .707 .577 .707 r
F P
0 g
s
.68011 .69591 m .66727 .7513 L .68329 .75011 L p .707 .577 .707 r
F P
0 g
s
.68329 .75011 m .69612 .69472 L .68011 .69591 L p .707 .577 .707 r
F P
0 g
s
.62057 .85656 m .61486 .83964 L .58443 .84936 L p .707 .577 .707 r
F P
0 g
s
.61486 .83964 m .62057 .85656 L .64875 .84369 L p .707 .577 .707 r
F P
0 g
s
.64875 .84369 m .64303 .82678 L .61486 .83964 L p .707 .577 .707 r
F P
0 g
s
.55524 .74517 m .54741 .78219 L .57423 .79069 L p .707 .577 .707 r
F P
0 g
s
.59015 .86628 m .58443 .84936 L .55474 .85499 L p .707 .577 .707 r
F P
0 g
s
.58443 .84936 m .59015 .86628 L .62057 .85656 L p .707 .577 .707 r
F P
0 g
s
.50647 .7132 m .51931 .65781 L .50709 .64993 L p .707 .577 .707 r
F P
0 g
s
.67254 .77068 m .66472 .8077 L .68836 .80869 L p .707 .577 .707 r
F P
0 g
s
.68836 .80869 m .69618 .77167 L .67254 .77068 L p .707 .577 .707 r
F P
0 g
s
.64303 .82678 m .64875 .84369 L .67193 .82895 L p .707 .577 .707 r
F P
0 g
s
.67193 .82895 m .66621 .81203 L .64303 .82678 L p .707 .577 .707 r
F P
0 g
s
.55474 .85499 m .56046 .87191 L .59015 .86628 L p .707 .577 .707 r
F P
0 g
s
.54741 .78219 m .55524 .74517 L .53472 .73656 L p .707 .577 .707 r
F P
0 g
s
.56046 .87191 m .55474 .85499 L .52869 .85598 L p .707 .577 .707 r
F P
0 g
s
.50709 .64993 m .49426 .70532 L .50647 .7132 L p .707 .577 .707 r
F P
0 g
s
.53472 .73656 m .5269 .77358 L .54741 .78219 L p .707 .577 .707 r
F P
0 g
s
.52869 .85598 m .53441 .87289 L .56046 .87191 L p .707 .577 .707 r
F P
0 g
s
.66621 .81203 m .67193 .82895 L .68783 .81376 L p .707 .577 .707 r
F P
0 g
s
.68783 .81376 m .68212 .79685 L .66621 .81203 L p .707 .577 .707 r
F P
0 g
s
.69612 .69472 m .68329 .75011 L .69026 .74623 L p .707 .577 .707 r
F P
0 g
s
.69026 .74623 m .7031 .69084 L .69612 .69472 L p .707 .577 .707 r
F P
0 g
s
.69618 .77167 m .68836 .80869 L .7045 .80698 L p .707 .577 .707 r
F P
0 g
s
.7045 .80698 m .71232 .76995 L .69618 .77167 L p .707 .577 .707 r
F P
0 g
s
.53441 .87289 m .52869 .85598 L .50883 .85222 L p .707 .577 .707 r
F P
0 g
s
.49426 .70532 m .50709 .64993 L .50433 .64375 L p .707 .577 .707 r
F P
0 g
s
.5269 .77358 m .53472 .73656 L .52251 .72868 L p .707 .577 .707 r
F P
0 g
s
.50883 .85222 m .51455 .86913 L .53441 .87289 L p .707 .577 .707 r
F P
0 g
s
.52251 .72868 m .51469 .7657 L .5269 .77358 L p .707 .577 .707 r
F P
0 g
s
.50433 .64375 m .4915 .69914 L .49426 .70532 L p .707 .577 .707 r
F P
0 g
s
.68212 .79685 m .68783 .81376 L .69491 .79963 L p .707 .577 .707 r
F P
0 g
s
.69491 .79963 m .68919 .78271 L .68212 .79685 L p .707 .577 .707 r
F P
0 g
s
.71232 .76995 m .7045 .80698 L .71156 .80272 L p .707 .577 .707 r
F P
0 g
s
.71156 .80272 m .71939 .76569 L .71232 .76995 L p .707 .577 .707 r
F P
0 g
s
.51455 .86913 m .50883 .85222 L .4971 .84409 L p .707 .577 .707 r
F P
0 g
s
.7031 .69084 m .69026 .74623 L .6875 .74006 L p .707 .577 .707 r
F P
0 g
s
.6875 .74006 m .70034 .68467 L .7031 .69084 L p .707 .577 .707 r
F P
0 g
s
.51469 .7657 m .52251 .72868 L .51981 .72229 L p .707 .577 .707 r
F P
0 g
s
.4971 .84409 m .50282 .86101 L .51455 .86913 L p .707 .577 .707 r
F P
0 g
s
.4915 .69914 m .50433 .64375 L .51131 .63988 L p .707 .577 .707 r
F P
0 g
s
.51131 .63988 m .49847 .69527 L .4915 .69914 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.51981 .72229 m .51199 .75932 L .51469 .7657 L p .707 .577 .707 r
F P
0 g
s
.51199 .75932 m .51981 .72229 L .52688 .71803 L p .707 .577 .707 r
F P
0 g
s
.49847 .69527 m .51131 .63988 L .52732 .63869 L p .707 .577 .707 r
F P
0 g
s
.52688 .71803 m .51905 .75506 L .51199 .75932 L p .707 .577 .707 r
F P
0 g
s
.52732 .63869 m .51449 .69408 L .49847 .69527 L p .707 .577 .707 r
F P
0 g
s
.50038 .8493 m .49466 .83239 L .50174 .81825 L p .707 .577 .707 r
F P
0 g
s
.50174 .81825 m .50745 .83516 L .50038 .8493 L p .707 .577 .707 r
F P
0 g
s
.51449 .69408 m .52732 .63869 L .55082 .6403 L p .707 .577 .707 r
F P
0 g
s
.51905 .75506 m .52688 .71803 L .54302 .71632 L p .707 .577 .707 r
F P
0 g
s
.54302 .71632 m .53519 .75334 L .51905 .75506 L p .707 .577 .707 r
F P
0 g
s
.55082 .6403 m .53798 .69569 L .51449 .69408 L p .707 .577 .707 r
F P
0 g
s
.50745 .83516 m .50174 .81825 L .51764 .80307 L p .707 .577 .707 r
F P
0 g
s
.51764 .80307 m .52336 .81998 L .50745 .83516 L p .707 .577 .707 r
F P
0 g
s
.52336 .81998 m .51764 .80307 L .54082 .78832 L p .707 .577 .707 r
F P
0 g
s
.54082 .78832 m .54653 .80524 L .52336 .81998 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53821 .82054 L p .707 .577 .707 r
F P
0 g
s
.53798 .69569 m .55082 .6403 L .57949 .64456 L p .707 .577 .707 r
F P
0 g
s
.53519 .75334 m .54302 .71632 L .56665 .71731 L p .707 .577 .707 r
F P
0 g
s
.57949 .64456 m .56666 .69994 L .53798 .69569 L p .707 .577 .707 r
F P
0 g
s
.56665 .71731 m .55883 .75433 L .53519 .75334 L p .707 .577 .707 r
F P
0 g
s
.53821 .82054 m .53821 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.56666 .69994 m .57949 .64456 L .61053 .65103 L p .707 .577 .707 r
F P
0 g
s
.61053 .65103 m .5977 .70642 L .56666 .69994 L p .707 .577 .707 r
F P
0 g
s
.55883 .75433 m .56665 .71731 L .59547 .72091 L p .707 .577 .707 r
F P
0 g
s
.59547 .72091 m .58765 .75793 L .55883 .75433 L p .707 .577 .707 r
F P
0 g
s
.54653 .80524 m .54082 .78832 L .569 .77546 L p .707 .577 .707 r
F P
0 g
s
.59942 .76574 m .60514 .78265 L .57471 .79237 L p .707 .577 .707 r
F P
0 g
s
.57471 .79237 m .569 .77546 L .59942 .76574 L p .707 .577 .707 r
F P
0 g
s
.569 .77546 m .57471 .79237 L .54653 .80524 L p .707 .577 .707 r
F P
0 g
s
.53821 .31865 m .53821 .82054 L .57932 .81555 L p .707 .577 .707 r
F P
0 g
s
.57932 .81555 m .57932 .31366 L .53821 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40993 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.68919 .78271 m .69491 .79963 L .69246 .78792 L p .707 .577 .707 r
F P
0 g
s
.69246 .78792 m .68675 .77101 L .68919 .78271 L p .707 .577 .707 r
F P
0 g
s
.50282 .86101 m .4971 .84409 L .49466 .83239 L p .707 .577 .707 r
F P
0 g
s
.71939 .76569 m .71156 .80272 L .70886 .79633 L p .707 .577 .707 r
F P
0 g
s
.70886 .79633 m .71668 .75931 L .71939 .76569 L p .707 .577 .707 r
F P
0 g
s
.64091 .65911 m .62808 .7145 L .5977 .70642 L p .707 .577 .707 r
F P
0 g
s
.5977 .70642 m .61053 .65103 L .64091 .65911 L p .707 .577 .707 r
F P
0 g
s
.62911 .76011 m .63483 .77702 L .60514 .78265 L p .707 .577 .707 r
F P
0 g
s
.60514 .78265 m .59942 .76574 L .62911 .76011 L p .707 .577 .707 r
F P
0 g
s
.58765 .75793 m .59547 .72091 L .62666 .72677 L p .707 .577 .707 r
F P
0 g
s
.62666 .72677 m .61883 .7638 L .58765 .75793 L p .707 .577 .707 r
F P
0 g
s
.57932 .31366 m .57932 .81555 L .61267 .80739 L p .707 .577 .707 r
F P
0 g
s
.61267 .80739 m .61267 .3055 L .57932 .31366 L p .707 .577 .707 r
F P
0 g
s
.70034 .68467 m .6875 .74006 L .67529 .73218 L p .707 .577 .707 r
F P
0 g
s
.67529 .73218 m .68812 .67679 L .70034 .68467 L p .707 .577 .707 r
F P
0 g
s
.49466 .83239 m .50038 .8493 L .50282 .86101 L p .707 .577 .707 r
F P
0 g
s
.40993 .81345 m .40993 .31156 L .37952 .30261 L p .707 .577 .707 r
F P
0 g
s
.40993 .31156 m .40993 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24857 .72923 m .25416 .6787 L .22309 .67277 L p .707 .577 .707 r
F P
0 g
s
.25416 .6787 m .24857 .72923 L .28024 .73047 L p .707 .577 .707 r
F P
0 g
s
.28024 .73047 m .28582 .67994 L .25416 .6787 L p .707 .577 .707 r
F P
0 g
s
.68675 .77101 m .69246 .78792 L .68074 .77979 L p .707 .577 .707 r
F P
0 g
s
.68074 .77979 m .67502 .76288 L .68675 .77101 L p .707 .577 .707 r
F P
0 g
s
.28582 .67994 m .28024 .73047 L .30941 .7269 L p .707 .577 .707 r
F P
0 g
s
.30941 .7269 m .31499 .67637 L .28582 .67994 L p .707 .577 .707 r
F P
0 g
s
.2175 .7233 m .22309 .67277 L .19566 .66272 L p .707 .577 .707 r
F P
0 g
s
.22309 .67277 m .2175 .7233 L .24857 .72923 L p .707 .577 .707 r
F P
0 g
s
.2572 .79386 m .26059 .75981 L .22952 .75416 L p .707 .577 .707 r
F P
0 g
s
.26059 .75981 m .2572 .79386 L .2889 .79499 L p .707 .577 .707 r
F P
0 g
s
.2889 .79499 m .29229 .76094 L .26059 .75981 L p .707 .577 .707 r
F P
0 g
s
.29229 .76094 m .2889 .79499 L .31814 .79148 L p .707 .577 .707 r
F P
0 g
s
.31814 .79148 m .32153 .75743 L .29229 .76094 L p .707 .577 .707 r
F P
0 g
s
.22613 .78821 m .22952 .75416 L .20213 .74453 L p .707 .577 .707 r
F P
0 g
s
.22952 .75416 m .22613 .78821 L .2572 .79386 L p .707 .577 .707 r
F P
0 g
s
.66765 .66798 m .65481 .72337 L .62808 .7145 L p .707 .577 .707 r
F P
0 g
s
.62808 .7145 m .64091 .65911 L .66765 .66798 L p .707 .577 .707 r
F P
0 g
s
.63483 .77702 m .62911 .76011 L .65516 .75912 L p .707 .577 .707 r
F P
0 g
s
.65516 .75912 m .66088 .77604 L .63483 .77702 L p .707 .577 .707 r
F P
0 g
s
.65715 .73432 m .64932 .77135 L .61883 .7638 L p .707 .577 .707 r
F P
0 g
s
.61883 .7638 m .62666 .72677 L .65715 .73432 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80739 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.71668 .75931 m .70886 .79633 L .69665 .78845 L p .707 .577 .707 r
F P
0 g
s
.69665 .78845 m .70448 .75143 L .71668 .75931 L p .707 .577 .707 r
F P
0 g
s
.68812 .67679 m .67529 .73218 L .65481 .72337 L p .707 .577 .707 r
F P
0 g
s
.65481 .72337 m .66765 .66798 L .68812 .67679 L p .707 .577 .707 r
F P
0 g
s
.31499 .67637 m .30941 .7269 L .33322 .71886 L p .707 .577 .707 r
F P
0 g
s
.33322 .71886 m .3388 .66833 L .31499 .67637 L p .707 .577 .707 r
F P
0 g
s
.19008 .71325 m .19566 .66272 L .17456 .64955 L p .707 .577 .707 r
F P
0 g
s
.19566 .66272 m .19008 .71325 L .2175 .7233 L p .707 .577 .707 r
F P
0 g
s
.32153 .75743 m .31814 .79148 L .34204 .78368 L p .707 .577 .707 r
F P
0 g
s
.34204 .78368 m .34543 .74963 L .32153 .75743 L p .707 .577 .707 r
F P
0 g
s
.37952 .8045 m .37952 .30261 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37952 .30261 m .37952 .8045 L .40993 .81345 L p .707 .577 .707 r
F P
0 g
s
.19873 .77858 m .20213 .74453 L .18109 .73187 L p .707 .577 .707 r
F P
0 g
s
.20213 .74453 m .19873 .77858 L .22613 .78821 L p .707 .577 .707 r
F P
0 g
s
.67502 .76288 m .68074 .77979 L .66088 .77604 L p .707 .577 .707 r
F P
0 g
s
.66088 .77604 m .65516 .75912 L .67502 .76288 L p .707 .577 .707 r
F P
0 g
s
.3388 .66833 m .33322 .71886 L .34935 .70715 L p .707 .577 .707 r
F P
0 g
s
.34935 .70715 m .35493 .65662 L .3388 .66833 L p .707 .577 .707 r
F P
0 g
s
.21797 .76859 m .22048 .78765 L .25142 .78337 L p .707 .577 .707 r
F P
0 g
s
.25142 .78337 m .24891 .76431 L .21797 .76859 L p .707 .577 .707 r
F P
0 g
s
.24891 .76431 m .25142 .78337 L .28297 .77931 L p .707 .577 .707 r
F P
0 g
s
.16898 .70008 m .17456 .64955 L .16185 .63454 L p .707 .577 .707 r
F P
0 g
s
.17456 .64955 m .16898 .70008 L .19008 .71325 L p .707 .577 .707 r
F P
0 g
s
.28297 .77931 m .28046 .76025 L .24891 .76431 L p .707 .577 .707 r
F P
0 g
s
.28046 .76025 m .28297 .77931 L .31204 .77586 L p .707 .577 .707 r
F P
0 g
s
.31204 .77586 m .30953 .7568 L .28046 .76025 L p .707 .577 .707 r
F P
0 g
s
.18109 .73187 m .1777 .76592 L .19873 .77858 L p .707 .577 .707 r
F P
0 g
s
.34543 .74963 m .34204 .78368 L .35827 .77234 L p .707 .577 .707 r
F P
0 g
s
.35827 .77234 m .36166 .73829 L .34543 .74963 L p .707 .577 .707 r
F P
0 g
s
.70448 .75143 m .69665 .78845 L .67614 .77984 L p .707 .577 .707 r
F P
0 g
s
.67614 .77984 m .68396 .74282 L .70448 .75143 L p .707 .577 .707 r
F P
0 g
s
.19068 .77267 m .19319 .79173 L .22048 .78765 L p .707 .577 .707 r
F P
0 g
s
.22048 .78765 m .21797 .76859 L .19068 .77267 L p .707 .577 .707 r
F P
0 g
s
.1777 .76592 m .18109 .73187 L .16847 .71742 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.30953 .7568 m .31204 .77586 L .33579 .77337 L p .707 .577 .707 r
F P
0 g
s
.33579 .77337 m .33328 .75431 L .30953 .7568 L p .707 .577 .707 r
F P
0 g
s
.16969 .77615 m .1722 .79521 L .19319 .79173 L p .707 .577 .707 r
F P
0 g
s
.19319 .79173 m .19068 .77267 L .16969 .77615 L p .707 .577 .707 r
F P
0 g
s
.35493 .65662 m .34935 .70715 L .35621 .6929 L p .707 .577 .707 r
F P
0 g
s
.35621 .6929 m .36179 .64237 L .35493 .65662 L p .707 .577 .707 r
F P
0 g
s
.16847 .71742 m .16508 .75147 L .1777 .76592 L p .707 .577 .707 r
F P
0 g
s
.15627 .68507 m .16185 .63454 L .15877 .61916 L p .707 .577 .707 r
F P
0 g
s
.16185 .63454 m .15627 .68507 L .16898 .70008 L p .707 .577 .707 r
F P
0 g
s
.36166 .73829 m .35827 .77234 L .36525 .75859 L p .707 .577 .707 r
F P
0 g
s
.36179 .64237 m .35621 .6929 L .35313 .67752 L p .707 .577 .707 r
F P
0 g
s
.35313 .67752 m .35872 .62699 L .36179 .64237 L p .707 .577 .707 r
F P
0 g
s
.36525 .75859 m .36864 .72454 L .36166 .73829 L p .707 .577 .707 r
F P
0 g
s
.36567 .70971 m .36228 .74376 L .34965 .72931 L p .707 .577 .707 r
F P
0 g
s
.34965 .72931 m .35305 .69526 L .36567 .70971 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36864 .72454 m .36525 .75859 L .36228 .74376 L p .707 .577 .707 r
F P
0 g
s
.36228 .74376 m .36567 .70971 L .36864 .72454 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37952 .8045 L p .707 .577 .707 r
F P
0 g
s
.68396 .74282 m .67614 .77984 L .64932 .77135 L p .707 .577 .707 r
F P
0 g
s
.64932 .77135 m .65715 .73432 L .68396 .74282 L p .707 .577 .707 r
F P
0 g
s
.16508 .75147 m .16847 .71742 L .1655 .70259 L p .707 .577 .707 r
F P
0 g
s
.33328 .75431 m .33579 .77337 L .3519 .77208 L p .707 .577 .707 r
F P
0 g
s
.3519 .77208 m .34939 .75302 L .33328 .75431 L p .707 .577 .707 r
F P
0 g
s
.15707 .7787 m .15958 .79775 L .1722 .79521 L p .707 .577 .707 r
F P
0 g
s
.1722 .79521 m .16969 .77615 L .15707 .7787 L p .707 .577 .707 r
F P
0 g
s
.1655 .70259 m .16211 .73664 L .16508 .75147 L p .707 .577 .707 r
F P
0 g
s
.15877 .61916 m .15319 .66969 L .15627 .68507 L p .707 .577 .707 r
F P
0 g
s
.15319 .66969 m .15877 .61916 L .16563 .60491 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77297 L p .707 .577 .707 r
F P
0 g
s
.63909 .77297 m .63909 .27108 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.16211 .73664 m .1655 .70259 L .17247 .68884 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34939 .75302 m .3519 .77208 L .35878 .77211 L p .707 .577 .707 r
F P
0 g
s
.35878 .77211 m .35626 .75305 L .34939 .75302 L p .707 .577 .707 r
F P
0 g
s
.35872 .62699 m .35313 .67752 L .34042 .66251 L p .707 .577 .707 r
F P
0 g
s
.34042 .66251 m .34601 .61198 L .35872 .62699 L p .707 .577 .707 r
F P
0 g
s
.35626 .75305 m .35878 .77211 L .35576 .77347 L p .707 .577 .707 r
F P
0 g
s
.35576 .77347 m .35325 .75441 L .35626 .75305 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.15405 .78005 m .15656 .79911 L .15958 .79775 L p .707 .577 .707 r
F P
0 g
s
.15958 .79775 m .15707 .7787 L .15405 .78005 L p .707 .577 .707 r
F P
0 g
s
.17247 .68884 m .16908 .72289 L .16211 .73664 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16563 .60491 m .16005 .65544 L .15319 .66969 L p .707 .577 .707 r
F P
0 g
s
.16005 .65544 m .16563 .60491 L .18176 .5932 L p .707 .577 .707 r
F P
0 g
s
.16908 .72289 m .17247 .68884 L .1887 .67751 L p .707 .577 .707 r
F P
0 g
s
.63909 .27108 m .63909 .77297 L .62048 .76193 L p .707 .577 .707 r
F P
0 g
s
.62048 .76193 m .62048 .26004 L .63909 .27108 L p .707 .577 .707 r
F P
0 g
s
.34601 .61198 m .34042 .66251 L .31932 .64934 L p .707 .577 .707 r
F P
0 g
s
.31932 .64934 m .3249 .59881 L .34601 .61198 L p .707 .577 .707 r
F P
0 g
s
.18176 .5932 m .17618 .64373 L .16005 .65544 L p .707 .577 .707 r
F P
0 g
s
.17618 .64373 m .18176 .5932 L .20557 .58516 L p .707 .577 .707 r
F P
0 g
s
.1887 .67751 m .18531 .71156 L .16908 .72289 L p .707 .577 .707 r
F P
0 g
s
.16093 .78008 m .16344 .79914 L .15656 .79911 L p .707 .577 .707 r
F P
0 g
s
.15656 .79911 m .15405 .78005 L .16093 .78008 L p .707 .577 .707 r
F P
0 g
s
.35305 .69526 m .34965 .72931 L .32862 .71665 L p .707 .577 .707 r
F P
0 g
s
.32862 .71665 m .33201 .6826 L .35305 .69526 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38733 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.18531 .71156 m .1887 .67751 L .21261 .6697 L p .707 .577 .707 r
F P
0 g
s
.3249 .59881 m .31932 .64934 L .29189 .63929 L p .707 .577 .707 r
F P
0 g
s
.29189 .63929 m .29748 .58876 L .3249 .59881 L p .707 .577 .707 r
F P
0 g
s
.19999 .63569 m .20557 .58516 L .23474 .58159 L p .707 .577 .707 r
F P
0 g
s
.20557 .58516 m .19999 .63569 L .17618 .64373 L p .707 .577 .707 r
F P
0 g
s
.35325 .75441 m .35576 .77347 L .34314 .77601 L p .707 .577 .707 r
F P
0 g
s
.34314 .77601 m .34063 .75695 L .35325 .75441 L p .707 .577 .707 r
F P
0 g
s
.21261 .6697 m .20922 .70375 L .18531 .71156 L p .707 .577 .707 r
F P
0 g
s
.33201 .6826 m .32862 .71665 L .30122 .70702 L p .707 .577 .707 r
F P
0 g
s
.30122 .70702 m .30462 .67297 L .33201 .6826 L p .707 .577 .707 r
F P
0 g
s
.20922 .70375 m .21261 .6697 L .24184 .66619 L p .707 .577 .707 r
F P
0 g
s
.29748 .58876 m .29189 .63929 L .26083 .63336 L p .707 .577 .707 r
F P
0 g
s
.26083 .63336 m .26641 .58283 L .29748 .58876 L p .707 .577 .707 r
F P
0 g
s
.22916 .63212 m .23474 .58159 L .26641 .58283 L p .707 .577 .707 r
F P
0 g
s
.23474 .58159 m .22916 .63212 L .19999 .63569 L p .707 .577 .707 r
F P
0 g
s
.17703 .77879 m .17954 .79785 L .16344 .79914 L p .707 .577 .707 r
F P
0 g
s
.16344 .79914 m .16093 .78008 L .17703 .77879 L p .707 .577 .707 r
F P
0 g
s
.62048 .26004 m .62048 .76193 L .59007 .75299 L p .707 .577 .707 r
F P
0 g
s
.59007 .75299 m .59007 .2511 L .62048 .26004 L p .707 .577 .707 r
F P
0 g
s
.26641 .58283 m .26083 .63336 L .22916 .63212 L p .707 .577 .707 r
F P
0 g
s
.30462 .67297 m .30122 .70702 L .27015 .70137 L p .707 .577 .707 r
F P
0 g
s
.27015 .70137 m .27355 .66732 L .30462 .67297 L p .707 .577 .707 r
F P
0 g
s
.23845 .70024 m .24184 .66619 L .27355 .66732 L p .707 .577 .707 r
F P
0 g
s
.24184 .66619 m .23845 .70024 L .20922 .70375 L p .707 .577 .707 r
F P
0 g
s
.38733 .25716 m .38733 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38733 .75905 m .38733 .25716 L .42068 .249 L p .707 .577 .707 r
F P
0 g
s
.27355 .66732 m .27015 .70137 L .23845 .70024 L p .707 .577 .707 r
F P
0 g
s
.73917 .638 m .73359 .58064 L .70252 .58333 L p .707 .577 .707 r
F P
0 g
s
.73359 .58064 m .73917 .638 L .77084 .63478 L p .707 .577 .707 r
F P
0 g
s
.77084 .63478 m .76526 .57742 L .73359 .58064 L p .707 .577 .707 r
F P
0 g
s
.70252 .58333 m .7081 .64069 L .73917 .638 L p .707 .577 .707 r
F P
0 g
s
.76526 .57742 m .77084 .63478 L .80001 .63133 L p .707 .577 .707 r
F P
0 g
s
.80001 .63133 m .79443 .57397 L .76526 .57742 L p .707 .577 .707 r
F P
0 g
s
.34063 .75695 m .34314 .77601 L .32215 .77949 L p .707 .577 .707 r
F P
0 g
s
.7081 .64069 m .70252 .58333 L .67509 .58521 L p .707 .577 .707 r
F P
0 g
s
.32215 .77949 m .31964 .76043 L .34063 .75695 L p .707 .577 .707 r
F P
0 g
s
.67509 .58521 m .68068 .64257 L .7081 .64069 L p .707 .577 .707 r
F P
0 g
s
.79443 .57397 m .80001 .63133 L .82382 .628 L p .707 .577 .707 r
F P
0 g
s
.82382 .628 m .81824 .57064 L .79443 .57397 L p .707 .577 .707 r
F P
0 g
s
.20078 .7763 m .20329 .79536 L .17954 .79785 L p .707 .577 .707 r
F P
0 g
s
.17954 .79785 m .17703 .77879 L .20078 .7763 L p .707 .577 .707 r
F P
0 g
s
.59007 .2511 m .59007 .75299 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59007 .2511 L p .707 .577 .707 r
F P
0 g
s
.68068 .64257 m .67509 .58521 L .65399 .58611 L p .707 .577 .707 r
F P
0 g
s
.65399 .58611 m .65957 .64347 L .68068 .64257 L p .707 .577 .707 r
F P
0 g
s
.42068 .75089 m .42068 .249 L .46179 .24401 L p .707 .577 .707 r
F P
0 g
s
.42068 .249 m .42068 .75089 L .38733 .75905 L p .707 .577 .707 r
F P
0 g
s
.31964 .76043 m .32215 .77949 L .29485 .78357 L p .707 .577 .707 r
F P
0 g
s
.29485 .78357 m .29234 .76451 L .31964 .76043 L p .707 .577 .707 r
F P
0 g
s
.81824 .57064 m .82382 .628 L .83995 .62511 L p .707 .577 .707 r
F P
0 g
s
.83995 .62511 m .83436 .56774 L .81824 .57064 L p .707 .577 .707 r
F P
0 g
s
.72984 .69502 m .72645 .65679 L .69538 .65906 L p .707 .577 .707 r
F P
0 g
s
.72645 .65679 m .72984 .69502 L .76155 .69202 L p .707 .577 .707 r
F P
0 g
s
.76155 .69202 m .75816 .65379 L .72645 .65679 L p .707 .577 .707 r
F P
0 g
s
.22985 .77285 m .23237 .79191 L .20329 .79536 L p .707 .577 .707 r
F P
0 g
s
.20329 .79536 m .20078 .7763 L .22985 .77285 L p .707 .577 .707 r
F P
0 g
s
.69538 .65906 m .69877 .69729 L .72984 .69502 L p .707 .577 .707 r
F P
0 g
s
.75816 .65379 m .76155 .69202 L .79078 .68859 L p .707 .577 .707 r
F P
0 g
s
.79078 .68859 m .78739 .65036 L .75816 .65379 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50664 .74455 L p .707 .577 .707 r
F P
0 g
s
.50664 .74455 m .50664 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.73608 .78785 m .73859 .77183 L .70766 .76465 L p .707 .577 .707 r
F P
0 g
s
.73859 .77183 m .73608 .78785 L .76763 .78969 L p .707 .577 .707 r
F P
0 g
s
.76763 .78969 m .77014 .77367 L .73859 .77183 L p .707 .577 .707 r
F P
0 g
s
.69877 .69729 m .69538 .65906 L .66799 .66039 L p .707 .577 .707 r
F P
0 g
s
.46179 .7459 m .46179 .24401 L .50664 .24266 L p .707 .577 .707 r
F P
0 g
s
.46179 .24401 m .46179 .7459 L .42068 .75089 L p .707 .577 .707 r
F P
0 g
s
.29234 .76451 m .29485 .78357 L .26392 .78785 L p .707 .577 .707 r
F P
0 g
s
.70514 .78066 m .70766 .76465 L .68036 .75282 L p .707 .577 .707 r
F P
0 g
s
.70766 .76465 m .70514 .78066 L .73608 .78785 L p .707 .577 .707 r
F P
0 g
s
.66799 .66039 m .67138 .69862 L .69877 .69729 L p .707 .577 .707 r
F P
0 g
s
.26392 .78785 m .2614 .76879 L .29234 .76451 L p .707 .577 .707 r
F P
0 g
s
.65957 .64347 m .65399 .58611 L .64128 .58593 L p .707 .577 .707 r
F P
0 g
s
.77014 .77367 m .76763 .78969 L .7967 .786 L p .707 .577 .707 r
F P
0 g
s
.7967 .786 m .79922 .76998 L .77014 .77367 L p .707 .577 .707 r
F P
0 g
s
.64128 .58593 m .64686 .64329 L .65957 .64347 L p .707 .577 .707 r
F P
0 g
s
.2614 .76879 m .26392 .78785 L .23237 .79191 L p .707 .577 .707 r
F P
0 g
s
.23237 .79191 m .22985 .77285 L .2614 .76879 L p .707 .577 .707 r
F P
0 g
s
.50664 .24266 m .50664 .74455 L .46179 .7459 L p .707 .577 .707 r
F P
0 g
s
.78739 .65036 m .79078 .68859 L .81469 .68506 L p .707 .577 .707 r
F P
0 g
s
.81469 .68506 m .81129 .64683 L .78739 .65036 L p .707 .577 .707 r
F P
0 g
s
.68036 .75282 m .67785 .76883 L .70514 .78066 L p .707 .577 .707 r
F P
0 g
s
.67785 .76883 m .68036 .75282 L .65937 .7375 L p .707 .577 .707 r
F P
0 g
s
.79922 .76998 m .7967 .786 L .82045 .77715 L p .707 .577 .707 r
F P
0 g
s
.82045 .77715 m .82297 .76113 L .79922 .76998 L p .707 .577 .707 r
F P
0 g
s
.67138 .69862 m .66799 .66039 L .64695 .66064 L p .707 .577 .707 r
F P
0 g
s
.64695 .66064 m .65034 .69887 L .67138 .69862 L p .707 .577 .707 r
F P
0 g
s
.83436 .56774 m .83995 .62511 L .84681 .62294 L p .707 .577 .707 r
F P
0 g
s
.84681 .62294 m .84123 .56557 L .83436 .56774 L p .707 .577 .707 r
F P
0 g
s
.65937 .7375 m .65686 .75352 L .67785 .76883 L p .707 .577 .707 r
F P
0 g
s
.81129 .64683 m .81469 .68506 L .83092 .68179 L p .707 .577 .707 r
F P
0 g
s
.83092 .68179 m .82753 .64356 L .81129 .64683 L p .707 .577 .707 r
F P
0 g
s
.64686 .64329 m .64128 .58593 L .63821 .58469 L p .707 .577 .707 r
F P
0 g
s
.65686 .75352 m .65937 .7375 L .64675 .7202 L p .707 .577 .707 r
F P
0 g
s
.63821 .58469 m .64379 .64205 L .64686 .64329 L p .707 .577 .707 r
F P
0 g
s
.82297 .76113 m .82045 .77715 L .83656 .76399 L p .707 .577 .707 r
F P
0 g
s
.83656 .76399 m .83907 .74797 L .82297 .76113 L p .707 .577 .707 r
F P
0 g
s
.65034 .69887 m .64695 .66064 L .63433 .6598 L p .707 .577 .707 r
F P
0 g
s
.64675 .7202 m .64424 .73622 L .65686 .75352 L p .707 .577 .707 r
F P
0 g
s
.63433 .6598 m .63772 .69802 L .65034 .69887 L p .707 .577 .707 r
F P
0 g
s
.84123 .56557 m .84681 .62294 L .84373 .6217 L p .707 .577 .707 r
F P
0 g
s
.84373 .6217 m .83815 .56434 L .84123 .56557 L p .707 .577 .707 r
F P
0 g
s
.64424 .73622 m .64675 .7202 L .64373 .7026 L p .707 .577 .707 r
F P
0 g
s
.82753 .64356 m .83092 .68179 L .83789 .67908 L p .707 .577 .707 r
F P
0 g
s
.83789 .67908 m .8345 .64085 L .82753 .64356 L p .707 .577 .707 r
F P
0 g
s
.83907 .74797 m .83656 .76399 L .84344 .74783 L p .707 .577 .707 r
F P
0 g
s
.84344 .74783 m .84595 .73181 L .83907 .74797 L p .707 .577 .707 r
F P
0 g
s
.64379 .64205 m .63821 .58469 L .64507 .58252 L p .707 .577 .707 r
F P
0 g
s
.64373 .7026 m .64122 .71862 L .64424 .73622 L p .707 .577 .707 r
F P
0 g
s
.64507 .58252 m .65065 .63988 L .64379 .64205 L p .707 .577 .707 r
F P
0 g
s
.63772 .69802 m .63433 .6598 L .63136 .65793 L p .707 .577 .707 r
F P
0 g
s
.63136 .65793 m .63475 .69616 L .63772 .69802 L p .707 .577 .707 r
F P
0 g
s
.83815 .56434 m .84373 .6217 L .83102 .62152 L p .707 .577 .707 r
F P
0 g
s
.83102 .62152 m .82544 .56416 L .83815 .56434 L p .707 .577 .707 r
F P
0 g
s
.64122 .71862 m .64373 .7026 L .65061 .68643 L p .707 .577 .707 r
F P
0 g
s
.84595 .73181 m .84344 .74783 L .84042 .73023 L p .707 .577 .707 r
F P
0 g
s
.84042 .73023 m .84293 .71421 L .84595 .73181 L p .707 .577 .707 r
F P
0 g
s
.8345 .64085 m .83789 .67908 L .83492 .67722 L p .707 .577 .707 r
F P
0 g
s
.83492 .67722 m .83153 .63899 L .8345 .64085 L p .707 .577 .707 r
F P
0 g
s
.65061 .68643 m .6481 .70245 L .64122 .71862 L p .707 .577 .707 r
F P
0 g
s
.4023 .6292 m .38946 .57671 L .35909 .58061 L p .707 .577 .707 r
F P
0 g
s
.38946 .57671 m .4023 .6292 L .43334 .62158 L p .707 .577 .707 r
F P
0 g
s
.43334 .62158 m .42051 .56909 L .38946 .57671 L p .707 .577 .707 r
F P
0 g
s
.42051 .56909 m .43334 .62158 L .46201 .61097 L p .707 .577 .707 r
F P
0 g
s
.46201 .61097 m .44918 .55848 L .42051 .56909 L p .707 .577 .707 r
F P
0 g
s
.65065 .63988 m .64507 .58252 L .66119 .57963 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66119 .57963 m .66678 .63699 L .65065 .63988 L p .707 .577 .707 r
F P
0 g
s
.63475 .69616 m .63136 .65793 L .63833 .65522 L p .707 .577 .707 r
F P
0 g
s
.37192 .6331 m .35909 .58061 L .33235 .58039 L p .707 .577 .707 r
F P
0 g
s
.35909 .58061 m .37192 .6331 L .4023 .6292 L p .707 .577 .707 r
F P
0 g
s
.44918 .55848 m .46201 .61097 L .48551 .59841 L p .707 .577 .707 r
F P
0 g
s
.48551 .59841 m .47268 .54592 L .44918 .55848 L p .707 .577 .707 r
F P
0 g
s
.63833 .65522 m .64173 .69345 L .63475 .69616 L p .707 .577 .707 r
F P
0 g
s
.38117 .69142 m .37334 .65616 L .34285 .65955 L p .707 .577 .707 r
F P
0 g
s
.37334 .65616 m .38117 .69142 L .41235 .68438 L p .707 .577 .707 r
F P
0 g
s
.41235 .68438 m .40452 .64913 L .37334 .65616 L p .707 .577 .707 r
F P
0 g
s
.40452 .64913 m .41235 .68438 L .44117 .6744 L p .707 .577 .707 r
F P
0 g
s
.44117 .6744 m .43334 .63914 L .40452 .64913 L p .707 .577 .707 r
F P
0 g
s
.6481 .70245 m .65061 .68643 L .66672 .67328 L p .707 .577 .707 r
F P
0 g
s
.82544 .56416 m .83102 .62152 L .80992 .62242 L p .707 .577 .707 r
F P
0 g
s
.80992 .62242 m .80434 .56506 L .82544 .56416 L p .707 .577 .707 r
F P
0 g
s
.84293 .71421 m .84042 .73023 L .8278 .71293 L p .707 .577 .707 r
F P
0 g
s
.8278 .71293 m .83031 .69691 L .84293 .71421 L p .707 .577 .707 r
F P
0 g
s
.35067 .69481 m .34285 .65955 L .31603 .65898 L p .707 .577 .707 r
F P
0 g
s
.34285 .65955 m .35067 .69481 L .38117 .69142 L p .707 .577 .707 r
F P
0 g
s
.43334 .63914 m .44117 .6744 L .4648 .66243 L p .707 .577 .707 r
F P
0 g
s
.4648 .66243 m .45698 .62717 L .43334 .63914 L p .707 .577 .707 r
F P
0 g
s
.83153 .63899 m .83492 .67722 L .8223 .67637 L p .707 .577 .707 r
F P
0 g
s
.8223 .67637 m .81891 .63814 L .83153 .63899 L p .707 .577 .707 r
F P
0 g
s
.66672 .67328 m .6642 .6893 L .6481 .70245 L p .707 .577 .707 r
F P
0 g
s
.34518 .63288 m .33235 .58039 L .31187 .57608 L p .707 .577 .707 r
F P
0 g
s
.33235 .58039 m .34518 .63288 L .37192 .6331 L p .707 .577 .707 r
F P
0 g
s
.47268 .54592 m .48551 .59841 L .50153 .58514 L p .707 .577 .707 r
F P
0 g
s
.50153 .58514 m .48869 .53265 L .47268 .54592 L p .707 .577 .707 r
F P
0 g
s
.66678 .63699 m .66119 .57963 L .68501 .5763 L p .707 .577 .707 r
F P
0 g
s
.68501 .5763 m .69059 .63366 L .66678 .63699 L p .707 .577 .707 r
F P
0 g
s
.39486 .70662 m .40058 .68845 L .37089 .67824 L p .707 .577 .707 r
F P
0 g
s
.40058 .68845 m .39486 .70662 L .42528 .71563 L p .707 .577 .707 r
F P
0 g
s
.42528 .71563 m .431 .69746 L .40058 .68845 L p .707 .577 .707 r
F P
0 g
s
.31603 .65898 m .32386 .69423 L .35067 .69481 L p .707 .577 .707 r
F P
0 g
s
.64173 .69345 m .63833 .65522 L .65457 .65195 L p .707 .577 .707 r
F P
0 g
s
.37089 .67824 m .36517 .69641 L .39486 .70662 L p .707 .577 .707 r
F P
0 g
s
.6642 .6893 m .66672 .67328 L .69047 .66443 L p .707 .577 .707 r
F P
0 g
s
.431 .69746 m .42528 .71563 L .45346 .72256 L p .707 .577 .707 r
F P
0 g
s
.45346 .72256 m .45918 .70438 L .431 .69746 L p .707 .577 .707 r
F P
0 g
s
.32386 .69423 m .31603 .65898 L .29552 .65448 L p .707 .577 .707 r
F P
0 g
s
.65457 .65195 m .65796 .69018 L .64173 .69345 L p .707 .577 .707 r
F P
0 g
s
.80434 .56506 m .80992 .62242 L .78249 .6243 L p .707 .577 .707 r
F P
0 g
s
.78249 .6243 m .77691 .56694 L .80434 .56506 L p .707 .577 .707 r
F P
0 g
s
.45698 .62717 m .4648 .66243 L .48095 .64967 L p .707 .577 .707 r
F P
0 g
s
.48095 .64967 m .47312 .61441 L .45698 .62717 L p .707 .577 .707 r
F P
0 g
s
.36517 .69641 m .37089 .67824 L .34484 .66783 L p .707 .577 .707 r
F P
0 g
s
.83031 .69691 m .8278 .71293 L .80681 .69761 L p .707 .577 .707 r
F P
0 g
s
.80681 .69761 m .80932 .68159 L .83031 .69691 L p .707 .577 .707 r
F P
0 g
s
.34484 .66783 m .33912 .68601 L .36517 .69641 L p .707 .577 .707 r
F P
0 g
s
.31187 .57608 m .32471 .62858 L .34518 .63288 L p .707 .577 .707 r
F P
0 g
s
.69059 .63366 m .68501 .5763 L .71418 .57285 L p .707 .577 .707 r
F P
0 g
s
.69047 .66443 m .68795 .68044 L .6642 .6893 L p .707 .577 .707 r
F P
0 g
s
.32471 .62858 m .31187 .57608 L .29966 .56811 L p .707 .577 .707 r
F P
0 g
s
.48869 .53265 m .50153 .58514 L .5085 .57245 L p .707 .577 .707 r
F P
0 g
s
.5085 .57245 m .49566 .51996 L .48869 .53265 L p .707 .577 .707 r
F P
0 g
s
.71418 .57285 m .71976 .63021 L .69059 .63366 L p .707 .577 .707 r
F P
0 g
s
.45918 .70438 m .45346 .72256 L .47664 .72673 L p .707 .577 .707 r
F P
0 g
s
.47664 .72673 m .48236 .70855 L .45918 .70438 L p .707 .577 .707 r
F P
0 g
s
.29552 .65448 m .30334 .68974 L .32386 .69423 L p .707 .577 .707 r
F P
0 g
s
.81891 .63814 m .8223 .67637 L .80126 .67662 L p .707 .577 .707 r
F P
0 g
s
.80126 .67662 m .79787 .63839 L .81891 .63814 L p .707 .577 .707 r
F P
0 g
s
.33912 .68601 m .34484 .66783 L .32498 .65824 L p .707 .577 .707 r
F P
0 g
s
.77691 .56694 m .78249 .6243 L .75143 .62699 L p .707 .577 .707 r
F P
0 g
s
.75143 .62699 m .74584 .56963 L .77691 .56694 L p .707 .577 .707 r
F P
0 g
s
.68795 .68044 m .69047 .66443 L .71954 .66074 L p .707 .577 .707 r
F P
0 g
s
.32498 .65824 m .31926 .67642 L .33912 .68601 L p .707 .577 .707 r
F P
0 g
s
.80932 .68159 m .80681 .69761 L .77951 .68578 L p .707 .577 .707 r
F P
0 g
s
.77951 .68578 m .78203 .66976 L .80932 .68159 L p .707 .577 .707 r
F P
0 g
s
.71976 .63021 m .71418 .57285 L .74584 .56963 L p .707 .577 .707 r
F P
0 g
s
.74584 .56963 m .75143 .62699 L .71976 .63021 L p .707 .577 .707 r
F P
0 g
s
.30334 .68974 m .29552 .65448 L .28331 .64651 L p .707 .577 .707 r
F P
0 g
s
.65796 .69018 m .65457 .65195 L .67847 .64843 L p .707 .577 .707 r
F P
0 g
s
.47312 .61441 m .48095 .64967 L .48801 .63735 L p .707 .577 .707 r
F P
0 g
s
.48801 .63735 m .48019 .60209 L .47312 .61441 L p .707 .577 .707 r
F P
0 g
s
.67847 .64843 m .68186 .68666 L .65796 .69018 L p .707 .577 .707 r
F P
0 g
s
.71954 .66074 m .71703 .67676 L .68795 .68044 L p .707 .577 .707 r
F P
0 g
s
.29966 .56811 m .31249 .6206 L .32471 .62858 L p .707 .577 .707 r
F P
0 g
s
.71703 .67676 m .71954 .66074 L .75109 .66258 L p .707 .577 .707 r
F P
0 g
s
.78203 .66976 m .77951 .68578 L .74858 .6786 L p .707 .577 .707 r
F P
0 g
s
.74858 .6786 m .75109 .66258 L .78203 .66976 L p .707 .577 .707 r
F P
0 g
s
.48236 .70855 m .47664 .72673 L .49255 .72773 L p .707 .577 .707 r
F P
0 g
s
.49255 .72773 m .49826 .70955 L .48236 .70855 L p .707 .577 .707 r
F P
0 g
s
.75109 .66258 m .74858 .6786 L .71703 .67676 L p .707 .577 .707 r
F P
0 g
s
.28331 .64651 m .29114 .68176 L .30334 .68974 L p .707 .577 .707 r
F P
0 g
s
.79787 .63839 m .80126 .67662 L .77387 .67795 L p .707 .577 .707 r
F P
0 g
s
.77387 .67795 m .77048 .63972 L .79787 .63839 L p .707 .577 .707 r
F P
0 g
s
.31249 .6206 m .29966 .56811 L .2969 .55725 L p .709 .579 .707 r
F P
0 g
s
.49566 .51996 m .5085 .57245 L .50574 .56159 L p .709 .579 .707 r
F P
0 g
s
.50574 .56159 m .49291 .5091 L .49566 .51996 L p .709 .579 .707 r
F P
0 g
s
.31926 .67642 m .32498 .65824 L .31325 .65041 L p .707 .577 .707 r
F P
0 g
s
.31325 .65041 m .30753 .66859 L .31926 .67642 L p .707 .577 .707 r
F P
0 g
s
.68186 .68666 m .67847 .64843 L .70771 .645 L p .707 .577 .707 r
F P
0 g
s
.70771 .645 m .7111 .68323 L .68186 .68666 L p .707 .577 .707 r
F P
0 g
s
.29114 .68176 m .28331 .64651 L .28061 .63584 L p .708 .578 .707 r
F P
0 g
s
.77048 .63972 m .77387 .67795 L .7428 .68023 L p .707 .577 .707 r
F P
0 g
s
.7428 .68023 m .73941 .642 L .77048 .63972 L p .707 .577 .707 r
F P
0 g
s
.48019 .60209 m .48801 .63735 L .48531 .62668 L p .708 .578 .707 r
F P
0 g
s
.48531 .62668 m .47748 .59142 L .48019 .60209 L p .708 .578 .707 r
F P
0 g
s
.2969 .55725 m .30973 .60974 L .31249 .6206 L p .709 .579 .707 r
F P
0 g
s
.7111 .68323 m .70771 .645 L .73941 .642 L p .707 .577 .707 r
F P
0 g
s
.73941 .642 m .7428 .68023 L .7111 .68323 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49826 .70955 m .49255 .72773 L .49962 .72547 L p .707 .577 .707 r
F P
0 g
s
.49962 .72547 m .50534 .70729 L .49826 .70955 L p .707 .577 .707 r
F P
0 g
s
.28061 .63584 m .28843 .6711 L .29114 .68176 L p .708 .578 .707 r
F P
0 g
s
.30973 .60974 m .2969 .55725 L .30387 .54456 L p .707 .577 .707 r
F P
0 g
s
.49291 .5091 m .50574 .56159 L .49352 .55362 L p .707 .577 .707 r
F P
0 g
s
.49352 .55362 m .48069 .50113 L .49291 .5091 L p .707 .577 .707 r
F P
0 g
s
.30753 .66859 m .31325 .65041 L .3108 .64511 L p .707 .577 .707 r
F P
0 g
s
.3108 .64511 m .30509 .66328 L .30753 .66859 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28843 .6711 m .28061 .63584 L .28767 .62352 L p .707 .577 .707 r
F P
0 g
s
.47748 .59142 m .48531 .62668 L .4731 .6187 L p .707 .577 .707 r
F P
0 g
s
.4731 .6187 m .46528 .58345 L .47748 .59142 L p .707 .577 .707 r
F P
0 g
s
.30387 .54456 m .31671 .59705 L .30973 .60974 L p .707 .577 .707 r
F P
0 g
s
.50534 .70729 m .49962 .72547 L .49718 .72016 L p .707 .577 .707 r
F P
0 g
s
.49718 .72016 m .50289 .70199 L .50534 .70729 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28767 .62352 m .2955 .65877 L .28843 .6711 L p .707 .577 .707 r
F P
0 g
s
.31671 .59705 m .30387 .54456 L .31989 .53129 L p .707 .577 .707 r
F P
0 g
s
.48069 .50113 m .49352 .55362 L .47305 .54931 L p .707 .577 .707 r
F P
0 g
s
.47305 .54931 m .46021 .49682 L .48069 .50113 L p .707 .577 .707 r
F P
0 g
s
.30509 .66328 m .3108 .64511 L .31788 .64284 L p .707 .577 .707 r
F P
0 g
s
.31788 .64284 m .31216 .66102 L .30509 .66328 L p .707 .577 .707 r
F P
0 g
s
.2955 .65877 m .28767 .62352 L .30381 .61075 L p .707 .577 .707 r
F P
0 g
s
.46528 .58345 m .4731 .6187 L .45259 .61421 L p .707 .577 .707 r
F P
0 g
s
.45259 .61421 m .44476 .57895 L .46528 .58345 L p .707 .577 .707 r
F P
0 g
s
.31989 .53129 m .33272 .58378 L .31671 .59705 L p .707 .577 .707 r
F P
0 g
s
.33272 .58378 m .31989 .53129 L .34338 .51873 L p .707 .577 .707 r
F P
0 g
s
.46021 .49682 m .47305 .54931 L .44631 .54909 L p .707 .577 .707 r
F P
0 g
s
.44631 .54909 m .43348 .4966 L .46021 .49682 L p .707 .577 .707 r
F P
0 g
s
.30381 .61075 m .31164 .64601 L .2955 .65877 L p .707 .577 .707 r
F P
0 g
s
.50289 .70199 m .49718 .72016 L .48545 .71233 L p .707 .577 .707 r
F P
0 g
s
.48545 .71233 m .49117 .69415 L .50289 .70199 L p .707 .577 .707 r
F P
0 g
s
.31216 .66102 m .31788 .64284 L .33379 .64385 L p .707 .577 .707 r
F P
0 g
s
.33379 .64385 m .32807 .66202 L .31216 .66102 L p .707 .577 .707 r
F P
0 g
s
.31164 .64601 m .30381 .61075 L .32745 .59879 L p .707 .577 .707 r
F P
0 g
s
.44476 .57895 m .45259 .61421 L .42577 .61363 L p .707 .577 .707 r
F P
0 g
s
.42577 .61363 m .41795 .57837 L .44476 .57895 L p .707 .577 .707 r
F P
0 g
s
.35622 .57122 m .34338 .51873 L .37206 .50812 L p .707 .577 .707 r
F P
0 g
s
.34338 .51873 m .35622 .57122 L .33272 .58378 L p .707 .577 .707 r
F P
0 g
s
.43348 .4966 m .44631 .54909 L .41593 .55299 L p .707 .577 .707 r
F P
0 g
s
.41593 .55299 m .4031 .5005 L .43348 .4966 L p .707 .577 .707 r
F P
0 g
s
.38489 .56062 m .37206 .50812 L .4031 .5005 L p .707 .577 .707 r
F P
0 g
s
.37206 .50812 m .38489 .56062 L .35622 .57122 L p .707 .577 .707 r
F P
0 g
s
.4031 .5005 m .41593 .55299 L .38489 .56062 L p .707 .577 .707 r
F P
0 g
s
.32745 .59879 m .33528 .63405 L .31164 .64601 L p .707 .577 .707 r
F P
0 g
s
.49117 .69415 m .48545 .71233 L .46559 .70274 L p .707 .577 .707 r
F P
0 g
s
.46559 .70274 m .47131 .68457 L .49117 .69415 L p .707 .577 .707 r
F P
0 g
s
.33528 .63405 m .32745 .59879 L .35627 .5888 L p .707 .577 .707 r
F P
0 g
s
.41795 .57837 m .42577 .61363 L .39528 .61702 L p .707 .577 .707 r
F P
0 g
s
.39528 .61702 m .38745 .58176 L .41795 .57837 L p .707 .577 .707 r
F P
0 g
s
.32807 .66202 m .33379 .64385 L .35696 .64801 L p .707 .577 .707 r
F P
0 g
s
.35696 .64801 m .35125 .66619 L .32807 .66202 L p .707 .577 .707 r
F P
0 g
s
.3641 .62406 m .35627 .5888 L .38745 .58176 L p .707 .577 .707 r
F P
0 g
s
.35627 .5888 m .3641 .62406 L .33528 .63405 L p .707 .577 .707 r
F P
0 g
s
.38745 .58176 m .39528 .61702 L .3641 .62406 L p .707 .577 .707 r
F P
0 g
s
.47131 .68457 m .46559 .70274 L .43954 .69233 L p .707 .577 .707 r
F P
0 g
s
.43954 .69233 m .44526 .67416 L .47131 .68457 L p .707 .577 .707 r
F P
0 g
s
.35125 .66619 m .35696 .64801 L .38514 .65494 L p .707 .577 .707 r
F P
0 g
s
.38514 .65494 m .37942 .67312 L .35125 .66619 L p .707 .577 .707 r
F P
0 g
s
.44526 .67416 m .43954 .69233 L .40985 .68213 L p .707 .577 .707 r
F P
0 g
s
.40985 .68213 m .41557 .66395 L .44526 .67416 L p .707 .577 .707 r
F P
0 g
s
.37942 .67312 m .38514 .65494 L .41557 .66395 L p .707 .577 .707 r
F P
0 g
s
.41557 .66395 m .40985 .68213 L .37942 .67312 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF3P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF000010001eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00HGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo0`0025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00GGoo0P000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FWoo00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00FGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001FOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`03
001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPh0
00=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH70006FUH20004FUH00`00FUH000030002FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP02FUH5000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60005FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002
FUH50004FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000YOol?000]Ool005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020004FUH50003FUH30007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000087oo2@000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo00@0
05YFFUH000AJEP03001JEUYF00EJEP<000IJEPP00003FUH005YF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0000?OolA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol0
1000FUIJEP0015YF00<005YFFUH00eYF0`0000=JEP00FUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`04001JEUYF0003FUH01000FUIJEUYF
0P000Woo00<005YF00000eYF1@000eYF3`001UYF00<005YFFUH00UYF00@005YF000000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003moo`l000Qoo`04001JEUYF0004FUH=00000eYF000000050003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00@000Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD0009JEP07001JEUYFFUH005YF000015YF10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002eoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP80009JEP03001JEUYF00800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
<Goo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800004FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000`Ool01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;goo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF3P000eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001J
EP00008000=JEP@00003FUH0000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YFFUH01EYF1000
1UYF0P0000EJEP00001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000/Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP@000QJEP03001JEUYF00@000UJEP03001JEUYF009JEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ40009JEP@002aoo`00
;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF1P000UYF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH01UYF00@005YFFUIJEPH0031oo`00;Goo0P000eYF00<005YFFUH00eYF
00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH01EYF00<005YF
000010000eYF00<005YFFUH01`0015YF00<005YFFUH01EYF0`001EYF00@005YF000000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPP00003FUH005YF00MJEP03001JEUYF009JEPL003Ioo`00;7oo
00<005YF00000eYF00<005YFFUH00eYF1@002Goo200000EJEP00FUIJEP0000AJEP03001JEUYF00AJ
EP@000=JEPL0009JEPD000AJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP03FUH01000FUIJEUYF2@0025YF00<005YFFUH00UYF2@00?Goo000/Ool00`00FUH00003FUH01000
FUIJEUYF0P005Woo0P000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP07001JEUYFFUH005YF
00001UYF1@0015YF00<005YFFUH00`001EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000P000MJEP03
001JEUYF009JEQl0031oo`00;7oo00<005YF00000eYF00@005YF000001Uoo`04001JEUYF0005FUH0
1000FUH000001EYF00L005YFFUIJEP00FUH00006FUH40005FUH300000eYF001JEP05FUH00`00FUIJ
EP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUHR
0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool20004FUH2000L
Ool01000FUIJEP0015YF0`0000=JEP00000010000eYF00<005YF00001UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00003Goo2@0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo0P000UYF0P007Woo00@005YFFUH000=J
EP<000AJEP04001JEUYFFUH60006FUH00`00FUIJEP030008FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool4000015YF0000000057oo0`001Goo00@005YFFUH0
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEP0000<0009JEP@00003FUH005YF00QJ
EP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH000060002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool00eYF001J
EP02FUH01000FUIJEP004Woo1@0017oo00@005YFFUIJEPD000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0009FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool30003FUH01000FUIJEUYF0P0047oo1@0017oo00P005YFFUIJEP00FUH005YF
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100025YF00<005YFFUH01EYF0P00
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00:goo0`000eYF00<005YFFUH00eYF0P003Woo1@001Goo0UYF
0P0000AJEP000000009JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF
00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00:goo00<005YF00000eYF00<005YFFUH00eYF
00@005YF000000Ioo`l00003OomJEP00009JEP8000AJEP03001JEUYF009JEPD000MJEP03001JEUYF
00MJEP04001JEP000003FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF00<005YF00000eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF100000=JEP0000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00`001UYF00<005YFFUH00UYF0P0000=JEP0000000`001eYF00<005YF
FUH01EYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool00`00FUIJEP02
FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF10000UYF10000UYF00<005YFFUH01eYF00H0
05YF000005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF5`00;Woo000/Ool01@00FUIJEUYF00000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF00@005YFFUH000EJEP8000AJEP03001JEUYF00EJEP04001JEP000002FUH70007
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPX000AJEP03
001JEUYF00EJEP<0009JEPD002ioo`00;7oo00H005YFFUIJEP00FUH200000eYF001JEP05FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF00H005YF000005YF0007
FUH00`00FUIJEP02FUH;0005FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPX0
00QJEP@00003FUH005YF00MJEP@003=oo`00;Goo00<005YFFUH00P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00@005YFFUIJEP<000IJEP03001J
EUYF00=JEPD000AJEP@00003FUH005YF00MJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04
001JEUYFFUH30007FUH00`00FUH0000dOol002ioo`04001JEP000003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH20004FUH00`00
FUIJEP03FUH800000eYF001JEP02FUH30007FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEP03
001JEUYF009JEPT0009oo`8000AJEP05001JEUYFFUH0000cOol002ioo`04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@0000=J
EP00FUH01UYF0`0015YF0`001EYF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP04001JEUYF0007FUH00`00FUIJEP02
FUH9000=Ool300000eYF001JEP03FUH00`00Oomoo`0`Ool002moo`03001JEP00009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPH000IJEP03001JEUYF00IJEP<000AJEP<00003FUH005YF00EJEP<0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH00000014001Uoo`8000EJ
EP03001oogoo02moo`00;goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00MJEP03001J
EP0000<000=JEP8000EJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP03001JEUYF009JEP03001oogoo01eoo`8000=J
EP80031oo`00;goo0P000eYF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF10000UYF00<005YF
FUH01EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF10001eYF00<005YFFUH015YF1`000eYF00L0
05YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001EYF
001JEUYF00001EYF00@005YFFUIJEP80025oo`06001JEUYF001JEP00;goo000_Ool20003FUH00`00
FUH000030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH200000eYF001JEP05FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEP@000AJ
EP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol300000eYF001oo`0^Ool002moo`8000=JEP@000EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF009JEP03001JEUYF
009JEP8002Aoo`04001JEUYF000^Ool002moo`80009JEP03001oogoo009oo`8000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH01@00FUH005YF00001UYF
00<005YFFUH01UYF0`001eYF00<005YFFUH015YF00L005YF000005YF001JEP02000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000:Ool3000HOol01000FUIJEP00;Goo000^Ool00`00FUH000020007Ool200000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH01@00FUH005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000:Ool5000GOol01000FUIJEP00;Goo000^Ool00`00FUH0000;Ool40006FUH00`00FUH0
00020004FUH00`00FUIJEP05FUH00`00FUH000030003Ool02000FUIJEP00FUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P002Woo1@0067oo0`00
;Goo000^Ool200000eYF001oo`0=Ool40002FUH60003FUH00`00FUIJEP02FUH50008Ool3000015YF
001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF300000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P000UYF00<005YFFUH00UYF0P002Woo
1@0067oo0P0000=JEP00Ool0:goo000^Ool20002FUH00`00Oomoo`0?Ool@000?Ool01@00FUH005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP8000]oo`<0
01Yoo`03001JEP0002aoo`00;Woo0P000eYF00<007ooOol04Goo1@0067oo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000eYF00<005YF0000:7oo
00<005YF0000;7oo000^Ool00`00FUIJEP02FUH3000BOol3000IOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH400001eYF000005YF001JEP0002Qoo`03001J
EP0002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH00P00;Goo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00@005YF0000009JEP800005FUH00000001JEP03000ZOol00`00Oomoo`0[
Ool002ioo`03001JEUYF009JEP03001JEUYF009JEP<002Uoo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP000002FUH00`00FUH00003FUH4000YOol2000]Ool002ioo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEP00000VOol01@00FUH005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH015YF30000UYF00<005YFFUH01eYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEP8000=JEP80009JEP03001JEP00008002Moo`8002eoo`00;Woo00D005YFFUIJEP0000IJ
EP04001JEUYFFUH3000QOol20002FUH00`00FUH00006FUH00`00FUIJEP04FUH900000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH005YF0P001EYF00<005YF000015YF0P0097oo0`00;Goo000_Ool01000FUIJEP001UYF00<005YF
FUH015YF10005goo2`0000=JEP00FUH01EYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF00@005YF001JEP8000IJEP8000EJEP<0
021oo`800003FUH007oo02eoo`00<7oo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01000
37oo1`000eYF1@0000EJEP00001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP06001JEP00
FUH005YF0P0015YF00@005YF000000=JEP04001JEUYF000NOol00`00FUIJEP02000^Ool0035oo`80
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`000=JEPL0009JEP04001JEUYFFUH200000eYF001J
EP02FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH30004FUH01@00FUH005YF00000eYF00@005YFFUH000AJEP<000=JEP03001oogoo
01Yoo`8000=JEP03001oogoo02eoo`00<Woo00<005YFFUH00eYF00<005YFFUH01UYF2P0015YF2000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001JEP<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04
001JEP000005FUH30007FUH5000HOol300000eYF001JEP02FUH00`00Oomoo`0]Ool003=oo`8000=J
EP03001JEP0000L000AJEPT000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF0P001eYF00<005YF0000
0`0047oo1P0015YF00@005YFFUH0031oo`00=7oo1P000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP04001JEP000004FUH00`00FUIJEP04FUH@0004FUH00`00FUIJEP03FUH3000a
Ool002moo`D0009JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000050002FUH01000FUIJ
EUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00<goo
000[Ool;0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
0002FUH300000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001UYF0`00
1UYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8003Eoo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P000UYF
00<005YFFUH00eYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000IJ
EP03001JEUYF008000=JEP04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH00000=goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP050007FUH01000FUIJEUYF0P001Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH000IJEP04001JEUYFFUH300000eYF001JEP02FUH200001Woo00000000FUH000QJ
EP03001JEUYF009JEPD003Uoo`00:goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH00UYF1`0015YF00<005YFFUH01EYF00@005YF000000Qoo`03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEP0000Aoo`l003ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4000
15YF00<005YFFUH00UYF1@002Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
1eYF00D005YFFUIJEP00009JEP03001JEUYF00<00003FUH007oo051oo`00;7oo00<005YF00000UYF
3@0047oo2@0047oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH01UYF00D005YF
FUIJEP0000=JEP04001JEUYFFUH2001BOol002aoo`D003Qoo`<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH0
0`00FUIJEP020003FUH00`00FUIJEP03001BOol006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000L000AJEP04001J
EUYF0002FUH00`00FUH00003FUH00`00FUH0001BOol006eoo`<000AJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000Qoo`L000=JEP03001J
EP0000D005=oo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01P0047oo00<005YFFUH00eYF00<007ooOol0Egoo001cOol40008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH50002Ool5000=Ool30005FUH00`00Oomoo`1G
Ool007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH60007Ool5000<Ool0
1000FUIJEP0015YF00<007ooOol0F7oo001mOolO000=Ool5000;Ool00`00FUIJEP02FUH01000FUH0
0000Fgoo002=Ool00`00FUH00003FUH00`00Oomoo`0DOol3000:Ool20005FUH2001MOol008aoo`04
001JEUYF0002FUH00`00Oomoo`0POol20007FUH00`00Oomoo`1LOol008aoo`04001JEUYFFUH2000Q
Ool200000eYF001JEP04FUH2001OOol008aoo`05001JEUYFFUH0000OOol30004FUH01@00FUIJEUYF
0000HGoo002<Ool200000eYF001oo`0LOol30007FUH01000FUH00000HWoo002=Ool00`00FUH0000K
Ool200000eYF001JEP08FUH00`00Oomoo`1ROol008eoo`03FUH007oo01Qoo`<000AJEP03001JEUYF
00AJEP8006Eoo`00SGoo0`0057oo10001eYF00<005YFFUH00UYF0P00Igoo002=Ool2000015YF0000
00003Goo10000UYF00<005YFFUH01eYF00@005YF000006Uoo`00SWoo00<005YF00000UYF3@001UYF
00<005YFFUH01UYF0`00Jgoo002>Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH00UYF0`00KWoo002?Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH00002001aOol0091oo`<000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD007Aoo`00TWoo
0`000UYF00<005YFFUH00UYF2000NGoo002EOol70021Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58406 .73895 m .5969 .68356 L .56652 .67549 L p .707 .577 .707 r
F P
0 g
s
.5969 .68356 m .58406 .73895 L .61511 .74543 L p .707 .577 .707 r
F P
0 g
s
.61511 .74543 m .62794 .69004 L .5969 .68356 L p .707 .577 .707 r
F P
0 g
s
.62794 .69004 m .61511 .74543 L .64378 .74969 L p .707 .577 .707 r
F P
0 g
s
.64378 .74969 m .65661 .6943 L .62794 .69004 L p .707 .577 .707 r
F P
0 g
s
.55369 .73088 m .56652 .67549 L .53978 .66662 L p .707 .577 .707 r
F P
0 g
s
.56652 .67549 m .55369 .73088 L .58406 .73895 L p .707 .577 .707 r
F P
0 g
s
.53978 .66662 m .52695 .72201 L .55369 .73088 L p .707 .577 .707 r
F P
0 g
s
.65661 .6943 m .64378 .74969 L .66727 .7513 L p .707 .577 .707 r
F P
0 g
s
.66727 .7513 m .68011 .69591 L .65661 .6943 L p .707 .577 .707 r
F P
0 g
s
.52695 .72201 m .53978 .66662 L .51931 .65781 L p .707 .577 .707 r
F P
0 g
s
.60472 .79824 m .61254 .76121 L .58205 .75366 L p .707 .577 .707 r
F P
0 g
s
.61254 .76121 m .60472 .79824 L .6359 .8041 L p .707 .577 .707 r
F P
0 g
s
.6359 .8041 m .64372 .76707 L .61254 .76121 L p .707 .577 .707 r
F P
0 g
s
.51931 .65781 m .50647 .7132 L .52695 .72201 L p .707 .577 .707 r
F P
0 g
s
.64372 .76707 m .6359 .8041 L .66472 .8077 L p .707 .577 .707 r
F P
0 g
s
.66472 .8077 m .67254 .77068 L .64372 .76707 L p .707 .577 .707 r
F P
0 g
s
.57423 .79069 m .58205 .75366 L .55524 .74517 L p .707 .577 .707 r
F P
0 g
s
.58205 .75366 m .57423 .79069 L .60472 .79824 L p .707 .577 .707 r
F P
0 g
s
.68011 .69591 m .66727 .7513 L .68329 .75011 L p .707 .577 .707 r
F P
0 g
s
.68329 .75011 m .69612 .69472 L .68011 .69591 L p .707 .577 .707 r
F P
0 g
s
.62057 .85656 m .61486 .83964 L .58443 .84936 L p .707 .577 .707 r
F P
0 g
s
.61486 .83964 m .62057 .85656 L .64875 .84369 L p .707 .577 .707 r
F P
0 g
s
.64875 .84369 m .64303 .82678 L .61486 .83964 L p .707 .577 .707 r
F P
0 g
s
.55524 .74517 m .54741 .78219 L .57423 .79069 L p .707 .577 .707 r
F P
0 g
s
.59015 .86628 m .58443 .84936 L .55474 .85499 L p .707 .577 .707 r
F P
0 g
s
.58443 .84936 m .59015 .86628 L .62057 .85656 L p .707 .577 .707 r
F P
0 g
s
.50647 .7132 m .51931 .65781 L .50709 .64993 L p .707 .577 .707 r
F P
0 g
s
.67254 .77068 m .66472 .8077 L .68836 .80869 L p .707 .577 .707 r
F P
0 g
s
.68836 .80869 m .69618 .77167 L .67254 .77068 L p .707 .577 .707 r
F P
0 g
s
.64303 .82678 m .64875 .84369 L .67193 .82895 L p .707 .577 .707 r
F P
0 g
s
.67193 .82895 m .66621 .81203 L .64303 .82678 L p .707 .577 .707 r
F P
0 g
s
.55474 .85499 m .56046 .87191 L .59015 .86628 L p .707 .577 .707 r
F P
0 g
s
.54741 .78219 m .55524 .74517 L .53472 .73656 L p .707 .577 .707 r
F P
0 g
s
.56046 .87191 m .55474 .85499 L .52869 .85598 L p .707 .577 .707 r
F P
0 g
s
.50709 .64993 m .49426 .70532 L .50647 .7132 L p .707 .577 .707 r
F P
0 g
s
.53472 .73656 m .5269 .77358 L .54741 .78219 L p .707 .577 .707 r
F P
0 g
s
.52869 .85598 m .53441 .87289 L .56046 .87191 L p .707 .577 .707 r
F P
0 g
s
.66621 .81203 m .67193 .82895 L .68783 .81376 L p .707 .577 .707 r
F P
0 g
s
.68783 .81376 m .68212 .79685 L .66621 .81203 L p .707 .577 .707 r
F P
0 g
s
.69612 .69472 m .68329 .75011 L .69026 .74623 L p .707 .577 .707 r
F P
0 g
s
.69026 .74623 m .7031 .69084 L .69612 .69472 L p .707 .577 .707 r
F P
0 g
s
.69618 .77167 m .68836 .80869 L .7045 .80698 L p .707 .577 .707 r
F P
0 g
s
.7045 .80698 m .71232 .76995 L .69618 .77167 L p .707 .577 .707 r
F P
0 g
s
.53441 .87289 m .52869 .85598 L .50883 .85222 L p .707 .577 .707 r
F P
0 g
s
.49426 .70532 m .50709 .64993 L .50433 .64375 L p .707 .577 .707 r
F P
0 g
s
.5269 .77358 m .53472 .73656 L .52251 .72868 L p .707 .577 .707 r
F P
0 g
s
.50883 .85222 m .51455 .86913 L .53441 .87289 L p .707 .577 .707 r
F P
0 g
s
.52251 .72868 m .51469 .7657 L .5269 .77358 L p .707 .577 .707 r
F P
0 g
s
.50433 .64375 m .4915 .69914 L .49426 .70532 L p .707 .577 .707 r
F P
0 g
s
.68212 .79685 m .68783 .81376 L .69491 .79963 L p .707 .577 .707 r
F P
0 g
s
.69491 .79963 m .68919 .78271 L .68212 .79685 L p .707 .577 .707 r
F P
0 g
s
.71232 .76995 m .7045 .80698 L .71156 .80272 L p .707 .577 .707 r
F P
0 g
s
.71156 .80272 m .71939 .76569 L .71232 .76995 L p .707 .577 .707 r
F P
0 g
s
.51455 .86913 m .50883 .85222 L .4971 .84409 L p .707 .577 .707 r
F P
0 g
s
.7031 .69084 m .69026 .74623 L .6875 .74006 L p .707 .577 .707 r
F P
0 g
s
.6875 .74006 m .70034 .68467 L .7031 .69084 L p .707 .577 .707 r
F P
0 g
s
.51469 .7657 m .52251 .72868 L .51981 .72229 L p .707 .577 .707 r
F P
0 g
s
.4971 .84409 m .50282 .86101 L .51455 .86913 L p .707 .577 .707 r
F P
0 g
s
.4915 .69914 m .50433 .64375 L .51131 .63988 L p .707 .577 .707 r
F P
0 g
s
.51131 .63988 m .49847 .69527 L .4915 .69914 L p .707 .577 .707 r
F P
0 g
s
.49336 .82188 m .49336 .31999 L .44916 .31755 L p .707 .577 .707 r
F P
0 g
s
.51981 .72229 m .51199 .75932 L .51469 .7657 L p .707 .577 .707 r
F P
0 g
s
.51199 .75932 m .51981 .72229 L .52688 .71803 L p .707 .577 .707 r
F P
0 g
s
.49847 .69527 m .51131 .63988 L .52732 .63869 L p .707 .577 .707 r
F P
0 g
s
.52688 .71803 m .51905 .75506 L .51199 .75932 L p .707 .577 .707 r
F P
0 g
s
.52732 .63869 m .51449 .69408 L .49847 .69527 L p .707 .577 .707 r
F P
0 g
s
.50038 .8493 m .49466 .83239 L .50174 .81825 L p .707 .577 .707 r
F P
0 g
s
.50174 .81825 m .50745 .83516 L .50038 .8493 L p .707 .577 .707 r
F P
0 g
s
.51449 .69408 m .52732 .63869 L .55082 .6403 L p .707 .577 .707 r
F P
0 g
s
.51905 .75506 m .52688 .71803 L .54302 .71632 L p .707 .577 .707 r
F P
0 g
s
.54302 .71632 m .53519 .75334 L .51905 .75506 L p .707 .577 .707 r
F P
0 g
s
.55082 .6403 m .53798 .69569 L .51449 .69408 L p .707 .577 .707 r
F P
0 g
s
.50745 .83516 m .50174 .81825 L .51764 .80307 L p .707 .577 .707 r
F P
0 g
s
.51764 .80307 m .52336 .81998 L .50745 .83516 L p .707 .577 .707 r
F P
0 g
s
.52336 .81998 m .51764 .80307 L .54082 .78832 L p .707 .577 .707 r
F P
0 g
s
.54082 .78832 m .54653 .80524 L .52336 .81998 L p .707 .577 .707 r
F P
0 g
s
.49336 .31999 m .49336 .82188 L .53821 .82054 L p .707 .577 .707 r
F P
0 g
s
.53798 .69569 m .55082 .6403 L .57949 .64456 L p .707 .577 .707 r
F P
0 g
s
.53519 .75334 m .54302 .71632 L .56665 .71731 L p .707 .577 .707 r
F P
0 g
s
.57949 .64456 m .56666 .69994 L .53798 .69569 L p .707 .577 .707 r
F P
0 g
s
.56665 .71731 m .55883 .75433 L .53519 .75334 L p .707 .577 .707 r
F P
0 g
s
.53821 .82054 m .53821 .31865 L .49336 .31999 L p .707 .577 .707 r
F P
0 g
s
.56666 .69994 m .57949 .64456 L .61053 .65103 L p .707 .577 .707 r
F P
0 g
s
.61053 .65103 m .5977 .70642 L .56666 .69994 L p .707 .577 .707 r
F P
0 g
s
.55883 .75433 m .56665 .71731 L .59547 .72091 L p .707 .577 .707 r
F P
0 g
s
.59547 .72091 m .58765 .75793 L .55883 .75433 L p .707 .577 .707 r
F P
0 g
s
.54653 .80524 m .54082 .78832 L .569 .77546 L p .707 .577 .707 r
F P
0 g
s
.59942 .76574 m .60514 .78265 L .57471 .79237 L p .707 .577 .707 r
F P
0 g
s
.57471 .79237 m .569 .77546 L .59942 .76574 L p .707 .577 .707 r
F P
0 g
s
.569 .77546 m .57471 .79237 L .54653 .80524 L p .707 .577 .707 r
F P
0 g
s
.53821 .31865 m .53821 .82054 L .57932 .81555 L p .707 .577 .707 r
F P
0 g
s
.57932 .81555 m .57932 .31366 L .53821 .31865 L p .707 .577 .707 r
F P
0 g
s
.44916 .81944 m .44916 .31755 L .40993 .31156 L p .707 .577 .707 r
F P
0 g
s
.44916 .31755 m .44916 .81944 L .49336 .82188 L p .707 .577 .707 r
F P
0 g
s
.68919 .78271 m .69491 .79963 L .69246 .78792 L p .707 .577 .707 r
F P
0 g
s
.69246 .78792 m .68675 .77101 L .68919 .78271 L p .707 .577 .707 r
F P
0 g
s
.50282 .86101 m .4971 .84409 L .49466 .83239 L p .707 .577 .707 r
F P
0 g
s
.71939 .76569 m .71156 .80272 L .70886 .79633 L p .707 .577 .707 r
F P
0 g
s
.70886 .79633 m .71668 .75931 L .71939 .76569 L p .707 .577 .707 r
F P
0 g
s
.64091 .65911 m .62808 .7145 L .5977 .70642 L p .707 .577 .707 r
F P
0 g
s
.5977 .70642 m .61053 .65103 L .64091 .65911 L p .707 .577 .707 r
F P
0 g
s
.62911 .76011 m .63483 .77702 L .60514 .78265 L p .707 .577 .707 r
F P
0 g
s
.60514 .78265 m .59942 .76574 L .62911 .76011 L p .707 .577 .707 r
F P
0 g
s
.58765 .75793 m .59547 .72091 L .62666 .72677 L p .707 .577 .707 r
F P
0 g
s
.62666 .72677 m .61883 .7638 L .58765 .75793 L p .707 .577 .707 r
F P
0 g
s
.57932 .31366 m .57932 .81555 L .61267 .80739 L p .707 .577 .707 r
F P
0 g
s
.61267 .80739 m .61267 .3055 L .57932 .31366 L p .707 .577 .707 r
F P
0 g
s
.70034 .68467 m .6875 .74006 L .67529 .73218 L p .707 .577 .707 r
F P
0 g
s
.67529 .73218 m .68812 .67679 L .70034 .68467 L p .707 .577 .707 r
F P
0 g
s
.49466 .83239 m .50038 .8493 L .50282 .86101 L p .707 .577 .707 r
F P
0 g
s
.40993 .81345 m .40993 .31156 L .37952 .30261 L p .707 .577 .707 r
F P
0 g
s
.40993 .31156 m .40993 .81345 L .44916 .81944 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24857 .72923 m .25416 .6787 L .22309 .67277 L p .707 .577 .707 r
F P
0 g
s
.25416 .6787 m .24857 .72923 L .28024 .73047 L p .707 .577 .707 r
F P
0 g
s
.28024 .73047 m .28582 .67994 L .25416 .6787 L p .707 .577 .707 r
F P
0 g
s
.68675 .77101 m .69246 .78792 L .68074 .77979 L p .707 .577 .707 r
F P
0 g
s
.68074 .77979 m .67502 .76288 L .68675 .77101 L p .707 .577 .707 r
F P
0 g
s
.28582 .67994 m .28024 .73047 L .30941 .7269 L p .707 .577 .707 r
F P
0 g
s
.30941 .7269 m .31499 .67637 L .28582 .67994 L p .707 .577 .707 r
F P
0 g
s
.2175 .7233 m .22309 .67277 L .19566 .66272 L p .707 .577 .707 r
F P
0 g
s
.22309 .67277 m .2175 .7233 L .24857 .72923 L p .707 .577 .707 r
F P
0 g
s
.2572 .79386 m .26059 .75981 L .22952 .75416 L p .707 .577 .707 r
F P
0 g
s
.26059 .75981 m .2572 .79386 L .2889 .79499 L p .707 .577 .707 r
F P
0 g
s
.2889 .79499 m .29229 .76094 L .26059 .75981 L p .707 .577 .707 r
F P
0 g
s
.29229 .76094 m .2889 .79499 L .31814 .79148 L p .707 .577 .707 r
F P
0 g
s
.31814 .79148 m .32153 .75743 L .29229 .76094 L p .707 .577 .707 r
F P
0 g
s
.22613 .78821 m .22952 .75416 L .20213 .74453 L p .707 .577 .707 r
F P
0 g
s
.22952 .75416 m .22613 .78821 L .2572 .79386 L p .707 .577 .707 r
F P
0 g
s
.66765 .66798 m .65481 .72337 L .62808 .7145 L p .707 .577 .707 r
F P
0 g
s
.62808 .7145 m .64091 .65911 L .66765 .66798 L p .707 .577 .707 r
F P
0 g
s
.63483 .77702 m .62911 .76011 L .65516 .75912 L p .707 .577 .707 r
F P
0 g
s
.65516 .75912 m .66088 .77604 L .63483 .77702 L p .707 .577 .707 r
F P
0 g
s
.65715 .73432 m .64932 .77135 L .61883 .7638 L p .707 .577 .707 r
F P
0 g
s
.61883 .7638 m .62666 .72677 L .65715 .73432 L p .707 .577 .707 r
F P
0 g
s
.61267 .3055 m .61267 .80739 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61267 .3055 L p .707 .577 .707 r
F P
0 g
s
.71668 .75931 m .70886 .79633 L .69665 .78845 L p .707 .577 .707 r
F P
0 g
s
.69665 .78845 m .70448 .75143 L .71668 .75931 L p .707 .577 .707 r
F P
0 g
s
.68812 .67679 m .67529 .73218 L .65481 .72337 L p .707 .577 .707 r
F P
0 g
s
.65481 .72337 m .66765 .66798 L .68812 .67679 L p .707 .577 .707 r
F P
0 g
s
.31499 .67637 m .30941 .7269 L .33322 .71886 L p .707 .577 .707 r
F P
0 g
s
.33322 .71886 m .3388 .66833 L .31499 .67637 L p .707 .577 .707 r
F P
0 g
s
.19008 .71325 m .19566 .66272 L .17456 .64955 L p .707 .577 .707 r
F P
0 g
s
.19566 .66272 m .19008 .71325 L .2175 .7233 L p .707 .577 .707 r
F P
0 g
s
.32153 .75743 m .31814 .79148 L .34204 .78368 L p .707 .577 .707 r
F P
0 g
s
.34204 .78368 m .34543 .74963 L .32153 .75743 L p .707 .577 .707 r
F P
0 g
s
.37952 .8045 m .37952 .30261 L .36091 .29158 L p .707 .577 .707 r
F P
0 g
s
.37952 .30261 m .37952 .8045 L .40993 .81345 L p .707 .577 .707 r
F P
0 g
s
.19873 .77858 m .20213 .74453 L .18109 .73187 L p .707 .577 .707 r
F P
0 g
s
.20213 .74453 m .19873 .77858 L .22613 .78821 L p .707 .577 .707 r
F P
0 g
s
.67502 .76288 m .68074 .77979 L .66088 .77604 L p .707 .577 .707 r
F P
0 g
s
.66088 .77604 m .65516 .75912 L .67502 .76288 L p .707 .577 .707 r
F P
0 g
s
.3388 .66833 m .33322 .71886 L .34935 .70715 L p .707 .577 .707 r
F P
0 g
s
.34935 .70715 m .35493 .65662 L .3388 .66833 L p .707 .577 .707 r
F P
0 g
s
.21797 .76859 m .22048 .78765 L .25142 .78337 L p .707 .577 .707 r
F P
0 g
s
.25142 .78337 m .24891 .76431 L .21797 .76859 L p .707 .577 .707 r
F P
0 g
s
.24891 .76431 m .25142 .78337 L .28297 .77931 L p .707 .577 .707 r
F P
0 g
s
.16898 .70008 m .17456 .64955 L .16185 .63454 L p .707 .577 .707 r
F P
0 g
s
.17456 .64955 m .16898 .70008 L .19008 .71325 L p .707 .577 .707 r
F P
0 g
s
.28297 .77931 m .28046 .76025 L .24891 .76431 L p .707 .577 .707 r
F P
0 g
s
.28046 .76025 m .28297 .77931 L .31204 .77586 L p .707 .577 .707 r
F P
0 g
s
.31204 .77586 m .30953 .7568 L .28046 .76025 L p .707 .577 .707 r
F P
0 g
s
.18109 .73187 m .1777 .76592 L .19873 .77858 L p .707 .577 .707 r
F P
0 g
s
.34543 .74963 m .34204 .78368 L .35827 .77234 L p .707 .577 .707 r
F P
0 g
s
.35827 .77234 m .36166 .73829 L .34543 .74963 L p .707 .577 .707 r
F P
0 g
s
.70448 .75143 m .69665 .78845 L .67614 .77984 L p .707 .577 .707 r
F P
0 g
s
.67614 .77984 m .68396 .74282 L .70448 .75143 L p .707 .577 .707 r
F P
0 g
s
.19068 .77267 m .19319 .79173 L .22048 .78765 L p .707 .577 .707 r
F P
0 g
s
.22048 .78765 m .21797 .76859 L .19068 .77267 L p .707 .577 .707 r
F P
0 g
s
.1777 .76592 m .18109 .73187 L .16847 .71742 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .785 L p .707 .577 .707 r
F P
0 g
s
.64409 .785 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.30953 .7568 m .31204 .77586 L .33579 .77337 L p .707 .577 .707 r
F P
0 g
s
.33579 .77337 m .33328 .75431 L .30953 .7568 L p .707 .577 .707 r
F P
0 g
s
.16969 .77615 m .1722 .79521 L .19319 .79173 L p .707 .577 .707 r
F P
0 g
s
.19319 .79173 m .19068 .77267 L .16969 .77615 L p .707 .577 .707 r
F P
0 g
s
.35493 .65662 m .34935 .70715 L .35621 .6929 L p .707 .577 .707 r
F P
0 g
s
.35621 .6929 m .36179 .64237 L .35493 .65662 L p .707 .577 .707 r
F P
0 g
s
.16847 .71742 m .16508 .75147 L .1777 .76592 L p .707 .577 .707 r
F P
0 g
s
.15627 .68507 m .16185 .63454 L .15877 .61916 L p .707 .577 .707 r
F P
0 g
s
.16185 .63454 m .15627 .68507 L .16898 .70008 L p .707 .577 .707 r
F P
0 g
s
.36166 .73829 m .35827 .77234 L .36525 .75859 L p .707 .577 .707 r
F P
0 g
s
.36179 .64237 m .35621 .6929 L .35313 .67752 L p .707 .577 .707 r
F P
0 g
s
.35313 .67752 m .35872 .62699 L .36179 .64237 L p .707 .577 .707 r
F P
0 g
s
.36525 .75859 m .36864 .72454 L .36166 .73829 L p .707 .577 .707 r
F P
0 g
s
.36567 .70971 m .36228 .74376 L .34965 .72931 L p .707 .577 .707 r
F P
0 g
s
.34965 .72931 m .35305 .69526 L .36567 .70971 L p .707 .577 .707 r
F P
0 g
s
.36091 .79347 m .36091 .29158 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36864 .72454 m .36525 .75859 L .36228 .74376 L p .707 .577 .707 r
F P
0 g
s
.36228 .74376 m .36567 .70971 L .36864 .72454 L p .707 .577 .707 r
F P
0 g
s
.36091 .29158 m .36091 .79347 L .37952 .8045 L p .707 .577 .707 r
F P
0 g
s
.68396 .74282 m .67614 .77984 L .64932 .77135 L p .707 .577 .707 r
F P
0 g
s
.64932 .77135 m .65715 .73432 L .68396 .74282 L p .707 .577 .707 r
F P
0 g
s
.16508 .75147 m .16847 .71742 L .1655 .70259 L p .707 .577 .707 r
F P
0 g
s
.33328 .75431 m .33579 .77337 L .3519 .77208 L p .707 .577 .707 r
F P
0 g
s
.3519 .77208 m .34939 .75302 L .33328 .75431 L p .707 .577 .707 r
F P
0 g
s
.15707 .7787 m .15958 .79775 L .1722 .79521 L p .707 .577 .707 r
F P
0 g
s
.1722 .79521 m .16969 .77615 L .15707 .7787 L p .707 .577 .707 r
F P
0 g
s
.1655 .70259 m .16211 .73664 L .16508 .75147 L p .707 .577 .707 r
F P
0 g
s
.15877 .61916 m .15319 .66969 L .15627 .68507 L p .707 .577 .707 r
F P
0 g
s
.15319 .66969 m .15877 .61916 L .16563 .60491 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .785 L .63909 .77297 L p .707 .577 .707 r
F P
0 g
s
.63909 .77297 m .63909 .27108 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.16211 .73664 m .1655 .70259 L .17247 .68884 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34939 .75302 m .3519 .77208 L .35878 .77211 L p .707 .577 .707 r
F P
0 g
s
.35878 .77211 m .35626 .75305 L .34939 .75302 L p .707 .577 .707 r
F P
0 g
s
.35872 .62699 m .35313 .67752 L .34042 .66251 L p .707 .577 .707 r
F P
0 g
s
.34042 .66251 m .34601 .61198 L .35872 .62699 L p .707 .577 .707 r
F P
0 g
s
.35626 .75305 m .35878 .77211 L .35576 .77347 L p .707 .577 .707 r
F P
0 g
s
.35576 .77347 m .35325 .75441 L .35626 .75305 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79347 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .36501 .26769 L p .707 .577 .707 r
F P
0 g
s
.15405 .78005 m .15656 .79911 L .15958 .79775 L p .707 .577 .707 r
F P
0 g
s
.15958 .79775 m .15707 .7787 L .15405 .78005 L p .707 .577 .707 r
F P
0 g
s
.17247 .68884 m .16908 .72289 L .16211 .73664 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16563 .60491 m .16005 .65544 L .15319 .66969 L p .707 .577 .707 r
F P
0 g
s
.16005 .65544 m .16563 .60491 L .18176 .5932 L p .707 .577 .707 r
F P
0 g
s
.16908 .72289 m .17247 .68884 L .1887 .67751 L p .707 .577 .707 r
F P
0 g
s
.63909 .27108 m .63909 .77297 L .62048 .76193 L p .707 .577 .707 r
F P
0 g
s
.62048 .76193 m .62048 .26004 L .63909 .27108 L p .707 .577 .707 r
F P
0 g
s
.34601 .61198 m .34042 .66251 L .31932 .64934 L p .707 .577 .707 r
F P
0 g
s
.31932 .64934 m .3249 .59881 L .34601 .61198 L p .707 .577 .707 r
F P
0 g
s
.18176 .5932 m .17618 .64373 L .16005 .65544 L p .707 .577 .707 r
F P
0 g
s
.17618 .64373 m .18176 .5932 L .20557 .58516 L p .707 .577 .707 r
F P
0 g
s
.1887 .67751 m .18531 .71156 L .16908 .72289 L p .707 .577 .707 r
F P
0 g
s
.16093 .78008 m .16344 .79914 L .15656 .79911 L p .707 .577 .707 r
F P
0 g
s
.15656 .79911 m .15405 .78005 L .16093 .78008 L p .707 .577 .707 r
F P
0 g
s
.35305 .69526 m .34965 .72931 L .32862 .71665 L p .707 .577 .707 r
F P
0 g
s
.32862 .71665 m .33201 .6826 L .35305 .69526 L p .707 .577 .707 r
F P
0 g
s
.36501 .76958 m .36501 .26769 L .38733 .25716 L p .707 .577 .707 r
F P
0 g
s
.36501 .26769 m .36501 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.18531 .71156 m .1887 .67751 L .21261 .6697 L p .707 .577 .707 r
F P
0 g
s
.3249 .59881 m .31932 .64934 L .29189 .63929 L p .707 .577 .707 r
F P
0 g
s
.29189 .63929 m .29748 .58876 L .3249 .59881 L p .707 .577 .707 r
F P
0 g
s
.19999 .63569 m .20557 .58516 L .23474 .58159 L p .707 .577 .707 r
F P
0 g
s
.20557 .58516 m .19999 .63569 L .17618 .64373 L p .707 .577 .707 r
F P
0 g
s
.35325 .75441 m .35576 .77347 L .34314 .77601 L p .707 .577 .707 r
F P
0 g
s
.34314 .77601 m .34063 .75695 L .35325 .75441 L p .707 .577 .707 r
F P
0 g
s
.21261 .6697 m .20922 .70375 L .18531 .71156 L p .707 .577 .707 r
F P
0 g
s
.33201 .6826 m .32862 .71665 L .30122 .70702 L p .707 .577 .707 r
F P
0 g
s
.30122 .70702 m .30462 .67297 L .33201 .6826 L p .707 .577 .707 r
F P
0 g
s
.20922 .70375 m .21261 .6697 L .24184 .66619 L p .707 .577 .707 r
F P
0 g
s
.29748 .58876 m .29189 .63929 L .26083 .63336 L p .707 .577 .707 r
F P
0 g
s
.26083 .63336 m .26641 .58283 L .29748 .58876 L p .707 .577 .707 r
F P
0 g
s
.22916 .63212 m .23474 .58159 L .26641 .58283 L p .707 .577 .707 r
F P
0 g
s
.23474 .58159 m .22916 .63212 L .19999 .63569 L p .707 .577 .707 r
F P
0 g
s
.17703 .77879 m .17954 .79785 L .16344 .79914 L p .707 .577 .707 r
F P
0 g
s
.16344 .79914 m .16093 .78008 L .17703 .77879 L p .707 .577 .707 r
F P
0 g
s
.62048 .26004 m .62048 .76193 L .59007 .75299 L p .707 .577 .707 r
F P
0 g
s
.59007 .75299 m .59007 .2511 L .62048 .26004 L p .707 .577 .707 r
F P
0 g
s
.26641 .58283 m .26083 .63336 L .22916 .63212 L p .707 .577 .707 r
F P
0 g
s
.30462 .67297 m .30122 .70702 L .27015 .70137 L p .707 .577 .707 r
F P
0 g
s
.27015 .70137 m .27355 .66732 L .30462 .67297 L p .707 .577 .707 r
F P
0 g
s
.23845 .70024 m .24184 .66619 L .27355 .66732 L p .707 .577 .707 r
F P
0 g
s
.24184 .66619 m .23845 .70024 L .20922 .70375 L p .707 .577 .707 r
F P
0 g
s
.38733 .25716 m .38733 .75905 L .36501 .76958 L p .707 .577 .707 r
F P
0 g
s
.38733 .75905 m .38733 .25716 L .42068 .249 L p .707 .577 .707 r
F P
0 g
s
.27355 .66732 m .27015 .70137 L .23845 .70024 L p .707 .577 .707 r
F P
0 g
s
.73917 .638 m .73359 .58064 L .70252 .58333 L p .707 .577 .707 r
F P
0 g
s
.73359 .58064 m .73917 .638 L .77084 .63478 L p .707 .577 .707 r
F P
0 g
s
.77084 .63478 m .76526 .57742 L .73359 .58064 L p .707 .577 .707 r
F P
0 g
s
.70252 .58333 m .7081 .64069 L .73917 .638 L p .707 .577 .707 r
F P
0 g
s
.76526 .57742 m .77084 .63478 L .80001 .63133 L p .707 .577 .707 r
F P
0 g
s
.80001 .63133 m .79443 .57397 L .76526 .57742 L p .707 .577 .707 r
F P
0 g
s
.34063 .75695 m .34314 .77601 L .32215 .77949 L p .707 .577 .707 r
F P
0 g
s
.7081 .64069 m .70252 .58333 L .67509 .58521 L p .707 .577 .707 r
F P
0 g
s
.32215 .77949 m .31964 .76043 L .34063 .75695 L p .707 .577 .707 r
F P
0 g
s
.67509 .58521 m .68068 .64257 L .7081 .64069 L p .707 .577 .707 r
F P
0 g
s
.79443 .57397 m .80001 .63133 L .82382 .628 L p .707 .577 .707 r
F P
0 g
s
.82382 .628 m .81824 .57064 L .79443 .57397 L p .707 .577 .707 r
F P
0 g
s
.20078 .7763 m .20329 .79536 L .17954 .79785 L p .707 .577 .707 r
F P
0 g
s
.17954 .79785 m .17703 .77879 L .20078 .7763 L p .707 .577 .707 r
F P
0 g
s
.59007 .2511 m .59007 .75299 L .55084 .747 L p .707 .577 .707 r
F P
0 g
s
.55084 .747 m .55084 .24511 L .59007 .2511 L p .707 .577 .707 r
F P
0 g
s
.68068 .64257 m .67509 .58521 L .65399 .58611 L p .707 .577 .707 r
F P
0 g
s
.65399 .58611 m .65957 .64347 L .68068 .64257 L p .707 .577 .707 r
F P
0 g
s
.42068 .75089 m .42068 .249 L .46179 .24401 L p .707 .577 .707 r
F P
0 g
s
.42068 .249 m .42068 .75089 L .38733 .75905 L p .707 .577 .707 r
F P
0 g
s
.31964 .76043 m .32215 .77949 L .29485 .78357 L p .707 .577 .707 r
F P
0 g
s
.29485 .78357 m .29234 .76451 L .31964 .76043 L p .707 .577 .707 r
F P
0 g
s
.81824 .57064 m .82382 .628 L .83995 .62511 L p .707 .577 .707 r
F P
0 g
s
.83995 .62511 m .83436 .56774 L .81824 .57064 L p .707 .577 .707 r
F P
0 g
s
.72984 .69502 m .72645 .65679 L .69538 .65906 L p .707 .577 .707 r
F P
0 g
s
.72645 .65679 m .72984 .69502 L .76155 .69202 L p .707 .577 .707 r
F P
0 g
s
.76155 .69202 m .75816 .65379 L .72645 .65679 L p .707 .577 .707 r
F P
0 g
s
.22985 .77285 m .23237 .79191 L .20329 .79536 L p .707 .577 .707 r
F P
0 g
s
.20329 .79536 m .20078 .7763 L .22985 .77285 L p .707 .577 .707 r
F P
0 g
s
.69538 .65906 m .69877 .69729 L .72984 .69502 L p .707 .577 .707 r
F P
0 g
s
.75816 .65379 m .76155 .69202 L .79078 .68859 L p .707 .577 .707 r
F P
0 g
s
.79078 .68859 m .78739 .65036 L .75816 .65379 L p .707 .577 .707 r
F P
0 g
s
.55084 .24511 m .55084 .747 L .50664 .74455 L p .707 .577 .707 r
F P
0 g
s
.50664 .74455 m .50664 .24266 L .55084 .24511 L p .707 .577 .707 r
F P
0 g
s
.73608 .78785 m .73859 .77183 L .70766 .76465 L p .707 .577 .707 r
F P
0 g
s
.73859 .77183 m .73608 .78785 L .76763 .78969 L p .707 .577 .707 r
F P
0 g
s
.76763 .78969 m .77014 .77367 L .73859 .77183 L p .707 .577 .707 r
F P
0 g
s
.69877 .69729 m .69538 .65906 L .66799 .66039 L p .707 .577 .707 r
F P
0 g
s
.46179 .7459 m .46179 .24401 L .50664 .24266 L p .707 .577 .707 r
F P
0 g
s
.46179 .24401 m .46179 .7459 L .42068 .75089 L p .707 .577 .707 r
F P
0 g
s
.29234 .76451 m .29485 .78357 L .26392 .78785 L p .707 .577 .707 r
F P
0 g
s
.70514 .78066 m .70766 .76465 L .68036 .75282 L p .707 .577 .707 r
F P
0 g
s
.70766 .76465 m .70514 .78066 L .73608 .78785 L p .707 .577 .707 r
F P
0 g
s
.66799 .66039 m .67138 .69862 L .69877 .69729 L p .707 .577 .707 r
F P
0 g
s
.26392 .78785 m .2614 .76879 L .29234 .76451 L p .707 .577 .707 r
F P
0 g
s
.65957 .64347 m .65399 .58611 L .64128 .58593 L p .707 .577 .707 r
F P
0 g
s
.77014 .77367 m .76763 .78969 L .7967 .786 L p .707 .577 .707 r
F P
0 g
s
.7967 .786 m .79922 .76998 L .77014 .77367 L p .707 .577 .707 r
F P
0 g
s
.64128 .58593 m .64686 .64329 L .65957 .64347 L p .707 .577 .707 r
F P
0 g
s
.2614 .76879 m .26392 .78785 L .23237 .79191 L p .707 .577 .707 r
F P
0 g
s
.23237 .79191 m .22985 .77285 L .2614 .76879 L p .707 .577 .707 r
F P
0 g
s
.50664 .24266 m .50664 .74455 L .46179 .7459 L p .707 .577 .707 r
F P
0 g
s
.78739 .65036 m .79078 .68859 L .81469 .68506 L p .707 .577 .707 r
F P
0 g
s
.81469 .68506 m .81129 .64683 L .78739 .65036 L p .707 .577 .707 r
F P
0 g
s
.68036 .75282 m .67785 .76883 L .70514 .78066 L p .707 .577 .707 r
F P
0 g
s
.67785 .76883 m .68036 .75282 L .65937 .7375 L p .707 .577 .707 r
F P
0 g
s
.79922 .76998 m .7967 .786 L .82045 .77715 L p .707 .577 .707 r
F P
0 g
s
.82045 .77715 m .82297 .76113 L .79922 .76998 L p .707 .577 .707 r
F P
0 g
s
.67138 .69862 m .66799 .66039 L .64695 .66064 L p .707 .577 .707 r
F P
0 g
s
.64695 .66064 m .65034 .69887 L .67138 .69862 L p .707 .577 .707 r
F P
0 g
s
.83436 .56774 m .83995 .62511 L .84681 .62294 L p .707 .577 .707 r
F P
0 g
s
.84681 .62294 m .84123 .56557 L .83436 .56774 L p .707 .577 .707 r
F P
0 g
s
.65937 .7375 m .65686 .75352 L .67785 .76883 L p .707 .577 .707 r
F P
0 g
s
.81129 .64683 m .81469 .68506 L .83092 .68179 L p .707 .577 .707 r
F P
0 g
s
.83092 .68179 m .82753 .64356 L .81129 .64683 L p .707 .577 .707 r
F P
0 g
s
.64686 .64329 m .64128 .58593 L .63821 .58469 L p .707 .577 .707 r
F P
0 g
s
.65686 .75352 m .65937 .7375 L .64675 .7202 L p .707 .577 .707 r
F P
0 g
s
.63821 .58469 m .64379 .64205 L .64686 .64329 L p .707 .577 .707 r
F P
0 g
s
.82297 .76113 m .82045 .77715 L .83656 .76399 L p .707 .577 .707 r
F P
0 g
s
.83656 .76399 m .83907 .74797 L .82297 .76113 L p .707 .577 .707 r
F P
0 g
s
.65034 .69887 m .64695 .66064 L .63433 .6598 L p .707 .577 .707 r
F P
0 g
s
.64675 .7202 m .64424 .73622 L .65686 .75352 L p .707 .577 .707 r
F P
0 g
s
.63433 .6598 m .63772 .69802 L .65034 .69887 L p .707 .577 .707 r
F P
0 g
s
.84123 .56557 m .84681 .62294 L .84373 .6217 L p .707 .577 .707 r
F P
0 g
s
.84373 .6217 m .83815 .56434 L .84123 .56557 L p .707 .577 .707 r
F P
0 g
s
.64424 .73622 m .64675 .7202 L .64373 .7026 L p .707 .577 .707 r
F P
0 g
s
.82753 .64356 m .83092 .68179 L .83789 .67908 L p .707 .577 .707 r
F P
0 g
s
.83789 .67908 m .8345 .64085 L .82753 .64356 L p .707 .577 .707 r
F P
0 g
s
.83907 .74797 m .83656 .76399 L .84344 .74783 L p .707 .577 .707 r
F P
0 g
s
.84344 .74783 m .84595 .73181 L .83907 .74797 L p .707 .577 .707 r
F P
0 g
s
.64379 .64205 m .63821 .58469 L .64507 .58252 L p .707 .577 .707 r
F P
0 g
s
.64373 .7026 m .64122 .71862 L .64424 .73622 L p .707 .577 .707 r
F P
0 g
s
.64507 .58252 m .65065 .63988 L .64379 .64205 L p .707 .577 .707 r
F P
0 g
s
.63772 .69802 m .63433 .6598 L .63136 .65793 L p .707 .577 .707 r
F P
0 g
s
.63136 .65793 m .63475 .69616 L .63772 .69802 L p .707 .577 .707 r
F P
0 g
s
.83815 .56434 m .84373 .6217 L .83102 .62152 L p .707 .577 .707 r
F P
0 g
s
.83102 .62152 m .82544 .56416 L .83815 .56434 L p .707 .577 .707 r
F P
0 g
s
.64122 .71862 m .64373 .7026 L .65061 .68643 L p .707 .577 .707 r
F P
0 g
s
.84595 .73181 m .84344 .74783 L .84042 .73023 L p .707 .577 .707 r
F P
0 g
s
.84042 .73023 m .84293 .71421 L .84595 .73181 L p .707 .577 .707 r
F P
0 g
s
.8345 .64085 m .83789 .67908 L .83492 .67722 L p .707 .577 .707 r
F P
0 g
s
.83492 .67722 m .83153 .63899 L .8345 .64085 L p .707 .577 .707 r
F P
0 g
s
.65061 .68643 m .6481 .70245 L .64122 .71862 L p .707 .577 .707 r
F P
0 g
s
.4023 .6292 m .38946 .57671 L .35909 .58061 L p .707 .577 .707 r
F P
0 g
s
.38946 .57671 m .4023 .6292 L .43334 .62158 L p .707 .577 .707 r
F P
0 g
s
.43334 .62158 m .42051 .56909 L .38946 .57671 L p .707 .577 .707 r
F P
0 g
s
.42051 .56909 m .43334 .62158 L .46201 .61097 L p .707 .577 .707 r
F P
0 g
s
.46201 .61097 m .44918 .55848 L .42051 .56909 L p .707 .577 .707 r
F P
0 g
s
.65065 .63988 m .64507 .58252 L .66119 .57963 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66119 .57963 m .66678 .63699 L .65065 .63988 L p .707 .577 .707 r
F P
0 g
s
.63475 .69616 m .63136 .65793 L .63833 .65522 L p .707 .577 .707 r
F P
0 g
s
.37192 .6331 m .35909 .58061 L .33235 .58039 L p .707 .577 .707 r
F P
0 g
s
.35909 .58061 m .37192 .6331 L .4023 .6292 L p .707 .577 .707 r
F P
0 g
s
.44918 .55848 m .46201 .61097 L .48551 .59841 L p .707 .577 .707 r
F P
0 g
s
.48551 .59841 m .47268 .54592 L .44918 .55848 L p .707 .577 .707 r
F P
0 g
s
.63833 .65522 m .64173 .69345 L .63475 .69616 L p .707 .577 .707 r
F P
0 g
s
.38117 .69142 m .37334 .65616 L .34285 .65955 L p .707 .577 .707 r
F P
0 g
s
.37334 .65616 m .38117 .69142 L .41235 .68438 L p .707 .577 .707 r
F P
0 g
s
.41235 .68438 m .40452 .64913 L .37334 .65616 L p .707 .577 .707 r
F P
0 g
s
.40452 .64913 m .41235 .68438 L .44117 .6744 L p .707 .577 .707 r
F P
0 g
s
.44117 .6744 m .43334 .63914 L .40452 .64913 L p .707 .577 .707 r
F P
0 g
s
.6481 .70245 m .65061 .68643 L .66672 .67328 L p .707 .577 .707 r
F P
0 g
s
.82544 .56416 m .83102 .62152 L .80992 .62242 L p .707 .577 .707 r
F P
0 g
s
.80992 .62242 m .80434 .56506 L .82544 .56416 L p .707 .577 .707 r
F P
0 g
s
.84293 .71421 m .84042 .73023 L .8278 .71293 L p .707 .577 .707 r
F P
0 g
s
.8278 .71293 m .83031 .69691 L .84293 .71421 L p .707 .577 .707 r
F P
0 g
s
.35067 .69481 m .34285 .65955 L .31603 .65898 L p .707 .577 .707 r
F P
0 g
s
.34285 .65955 m .35067 .69481 L .38117 .69142 L p .707 .577 .707 r
F P
0 g
s
.43334 .63914 m .44117 .6744 L .4648 .66243 L p .707 .577 .707 r
F P
0 g
s
.4648 .66243 m .45698 .62717 L .43334 .63914 L p .707 .577 .707 r
F P
0 g
s
.83153 .63899 m .83492 .67722 L .8223 .67637 L p .707 .577 .707 r
F P
0 g
s
.8223 .67637 m .81891 .63814 L .83153 .63899 L p .707 .577 .707 r
F P
0 g
s
.66672 .67328 m .6642 .6893 L .6481 .70245 L p .707 .577 .707 r
F P
0 g
s
.34518 .63288 m .33235 .58039 L .31187 .57608 L p .707 .577 .707 r
F P
0 g
s
.33235 .58039 m .34518 .63288 L .37192 .6331 L p .707 .577 .707 r
F P
0 g
s
.47268 .54592 m .48551 .59841 L .50153 .58514 L p .707 .577 .707 r
F P
0 g
s
.50153 .58514 m .48869 .53265 L .47268 .54592 L p .707 .577 .707 r
F P
0 g
s
.66678 .63699 m .66119 .57963 L .68501 .5763 L p .707 .577 .707 r
F P
0 g
s
.68501 .5763 m .69059 .63366 L .66678 .63699 L p .707 .577 .707 r
F P
0 g
s
.39486 .70662 m .40058 .68845 L .37089 .67824 L p .707 .577 .707 r
F P
0 g
s
.40058 .68845 m .39486 .70662 L .42528 .71563 L p .707 .577 .707 r
F P
0 g
s
.42528 .71563 m .431 .69746 L .40058 .68845 L p .707 .577 .707 r
F P
0 g
s
.31603 .65898 m .32386 .69423 L .35067 .69481 L p .707 .577 .707 r
F P
0 g
s
.64173 .69345 m .63833 .65522 L .65457 .65195 L p .707 .577 .707 r
F P
0 g
s
.37089 .67824 m .36517 .69641 L .39486 .70662 L p .707 .577 .707 r
F P
0 g
s
.6642 .6893 m .66672 .67328 L .69047 .66443 L p .707 .577 .707 r
F P
0 g
s
.431 .69746 m .42528 .71563 L .45346 .72256 L p .707 .577 .707 r
F P
0 g
s
.45346 .72256 m .45918 .70438 L .431 .69746 L p .707 .577 .707 r
F P
0 g
s
.32386 .69423 m .31603 .65898 L .29552 .65448 L p .707 .577 .707 r
F P
0 g
s
.65457 .65195 m .65796 .69018 L .64173 .69345 L p .707 .577 .707 r
F P
0 g
s
.80434 .56506 m .80992 .62242 L .78249 .6243 L p .707 .577 .707 r
F P
0 g
s
.78249 .6243 m .77691 .56694 L .80434 .56506 L p .707 .577 .707 r
F P
0 g
s
.45698 .62717 m .4648 .66243 L .48095 .64967 L p .707 .577 .707 r
F P
0 g
s
.48095 .64967 m .47312 .61441 L .45698 .62717 L p .707 .577 .707 r
F P
0 g
s
.36517 .69641 m .37089 .67824 L .34484 .66783 L p .707 .577 .707 r
F P
0 g
s
.83031 .69691 m .8278 .71293 L .80681 .69761 L p .707 .577 .707 r
F P
0 g
s
.80681 .69761 m .80932 .68159 L .83031 .69691 L p .707 .577 .707 r
F P
0 g
s
.34484 .66783 m .33912 .68601 L .36517 .69641 L p .707 .577 .707 r
F P
0 g
s
.31187 .57608 m .32471 .62858 L .34518 .63288 L p .707 .577 .707 r
F P
0 g
s
.69059 .63366 m .68501 .5763 L .71418 .57285 L p .707 .577 .707 r
F P
0 g
s
.69047 .66443 m .68795 .68044 L .6642 .6893 L p .707 .577 .707 r
F P
0 g
s
.32471 .62858 m .31187 .57608 L .29966 .56811 L p .707 .577 .707 r
F P
0 g
s
.48869 .53265 m .50153 .58514 L .5085 .57245 L p .707 .577 .707 r
F P
0 g
s
.5085 .57245 m .49566 .51996 L .48869 .53265 L p .707 .577 .707 r
F P
0 g
s
.71418 .57285 m .71976 .63021 L .69059 .63366 L p .707 .577 .707 r
F P
0 g
s
.45918 .70438 m .45346 .72256 L .47664 .72673 L p .707 .577 .707 r
F P
0 g
s
.47664 .72673 m .48236 .70855 L .45918 .70438 L p .707 .577 .707 r
F P
0 g
s
.29552 .65448 m .30334 .68974 L .32386 .69423 L p .707 .577 .707 r
F P
0 g
s
.81891 .63814 m .8223 .67637 L .80126 .67662 L p .707 .577 .707 r
F P
0 g
s
.80126 .67662 m .79787 .63839 L .81891 .63814 L p .707 .577 .707 r
F P
0 g
s
.33912 .68601 m .34484 .66783 L .32498 .65824 L p .707 .577 .707 r
F P
0 g
s
.77691 .56694 m .78249 .6243 L .75143 .62699 L p .707 .577 .707 r
F P
0 g
s
.75143 .62699 m .74584 .56963 L .77691 .56694 L p .707 .577 .707 r
F P
0 g
s
.68795 .68044 m .69047 .66443 L .71954 .66074 L p .707 .577 .707 r
F P
0 g
s
.32498 .65824 m .31926 .67642 L .33912 .68601 L p .707 .577 .707 r
F P
0 g
s
.80932 .68159 m .80681 .69761 L .77951 .68578 L p .707 .577 .707 r
F P
0 g
s
.77951 .68578 m .78203 .66976 L .80932 .68159 L p .707 .577 .707 r
F P
0 g
s
.71976 .63021 m .71418 .57285 L .74584 .56963 L p .707 .577 .707 r
F P
0 g
s
.74584 .56963 m .75143 .62699 L .71976 .63021 L p .707 .577 .707 r
F P
0 g
s
.30334 .68974 m .29552 .65448 L .28331 .64651 L p .707 .577 .707 r
F P
0 g
s
.65796 .69018 m .65457 .65195 L .67847 .64843 L p .707 .577 .707 r
F P
0 g
s
.47312 .61441 m .48095 .64967 L .48801 .63735 L p .707 .577 .707 r
F P
0 g
s
.48801 .63735 m .48019 .60209 L .47312 .61441 L p .707 .577 .707 r
F P
0 g
s
.67847 .64843 m .68186 .68666 L .65796 .69018 L p .707 .577 .707 r
F P
0 g
s
.71954 .66074 m .71703 .67676 L .68795 .68044 L p .707 .577 .707 r
F P
0 g
s
.29966 .56811 m .31249 .6206 L .32471 .62858 L p .707 .577 .707 r
F P
0 g
s
.71703 .67676 m .71954 .66074 L .75109 .66258 L p .707 .577 .707 r
F P
0 g
s
.78203 .66976 m .77951 .68578 L .74858 .6786 L p .707 .577 .707 r
F P
0 g
s
.74858 .6786 m .75109 .66258 L .78203 .66976 L p .707 .577 .707 r
F P
0 g
s
.48236 .70855 m .47664 .72673 L .49255 .72773 L p .707 .577 .707 r
F P
0 g
s
.49255 .72773 m .49826 .70955 L .48236 .70855 L p .707 .577 .707 r
F P
0 g
s
.75109 .66258 m .74858 .6786 L .71703 .67676 L p .707 .577 .707 r
F P
0 g
s
.28331 .64651 m .29114 .68176 L .30334 .68974 L p .707 .577 .707 r
F P
0 g
s
.79787 .63839 m .80126 .67662 L .77387 .67795 L p .707 .577 .707 r
F P
0 g
s
.77387 .67795 m .77048 .63972 L .79787 .63839 L p .707 .577 .707 r
F P
0 g
s
.31249 .6206 m .29966 .56811 L .2969 .55725 L p .709 .579 .707 r
F P
0 g
s
.49566 .51996 m .5085 .57245 L .50574 .56159 L p .709 .579 .707 r
F P
0 g
s
.50574 .56159 m .49291 .5091 L .49566 .51996 L p .709 .579 .707 r
F P
0 g
s
.31926 .67642 m .32498 .65824 L .31325 .65041 L p .707 .577 .707 r
F P
0 g
s
.31325 .65041 m .30753 .66859 L .31926 .67642 L p .707 .577 .707 r
F P
0 g
s
.68186 .68666 m .67847 .64843 L .70771 .645 L p .707 .577 .707 r
F P
0 g
s
.70771 .645 m .7111 .68323 L .68186 .68666 L p .707 .577 .707 r
F P
0 g
s
.29114 .68176 m .28331 .64651 L .28061 .63584 L p .708 .578 .707 r
F P
0 g
s
.77048 .63972 m .77387 .67795 L .7428 .68023 L p .707 .577 .707 r
F P
0 g
s
.7428 .68023 m .73941 .642 L .77048 .63972 L p .707 .577 .707 r
F P
0 g
s
.48019 .60209 m .48801 .63735 L .48531 .62668 L p .708 .578 .707 r
F P
0 g
s
.48531 .62668 m .47748 .59142 L .48019 .60209 L p .708 .578 .707 r
F P
0 g
s
.2969 .55725 m .30973 .60974 L .31249 .6206 L p .709 .579 .707 r
F P
0 g
s
.7111 .68323 m .70771 .645 L .73941 .642 L p .707 .577 .707 r
F P
0 g
s
.73941 .642 m .7428 .68023 L .7111 .68323 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49826 .70955 m .49255 .72773 L .49962 .72547 L p .707 .577 .707 r
F P
0 g
s
.49962 .72547 m .50534 .70729 L .49826 .70955 L p .707 .577 .707 r
F P
0 g
s
.28061 .63584 m .28843 .6711 L .29114 .68176 L p .708 .578 .707 r
F P
0 g
s
.30973 .60974 m .2969 .55725 L .30387 .54456 L p .707 .577 .707 r
F P
0 g
s
.49291 .5091 m .50574 .56159 L .49352 .55362 L p .707 .577 .707 r
F P
0 g
s
.49352 .55362 m .48069 .50113 L .49291 .5091 L p .707 .577 .707 r
F P
0 g
s
.30753 .66859 m .31325 .65041 L .3108 .64511 L p .707 .577 .707 r
F P
0 g
s
.3108 .64511 m .30509 .66328 L .30753 .66859 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28843 .6711 m .28061 .63584 L .28767 .62352 L p .707 .577 .707 r
F P
0 g
s
.47748 .59142 m .48531 .62668 L .4731 .6187 L p .707 .577 .707 r
F P
0 g
s
.4731 .6187 m .46528 .58345 L .47748 .59142 L p .707 .577 .707 r
F P
0 g
s
.30387 .54456 m .31671 .59705 L .30973 .60974 L p .707 .577 .707 r
F P
0 g
s
.50534 .70729 m .49962 .72547 L .49718 .72016 L p .707 .577 .707 r
F P
0 g
s
.49718 .72016 m .50289 .70199 L .50534 .70729 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28767 .62352 m .2955 .65877 L .28843 .6711 L p .707 .577 .707 r
F P
0 g
s
.31671 .59705 m .30387 .54456 L .31989 .53129 L p .707 .577 .707 r
F P
0 g
s
.48069 .50113 m .49352 .55362 L .47305 .54931 L p .707 .577 .707 r
F P
0 g
s
.47305 .54931 m .46021 .49682 L .48069 .50113 L p .707 .577 .707 r
F P
0 g
s
.30509 .66328 m .3108 .64511 L .31788 .64284 L p .707 .577 .707 r
F P
0 g
s
.31788 .64284 m .31216 .66102 L .30509 .66328 L p .707 .577 .707 r
F P
0 g
s
.2955 .65877 m .28767 .62352 L .30381 .61075 L p .707 .577 .707 r
F P
0 g
s
.46528 .58345 m .4731 .6187 L .45259 .61421 L p .707 .577 .707 r
F P
0 g
s
.45259 .61421 m .44476 .57895 L .46528 .58345 L p .707 .577 .707 r
F P
0 g
s
.31989 .53129 m .33272 .58378 L .31671 .59705 L p .707 .577 .707 r
F P
0 g
s
.33272 .58378 m .31989 .53129 L .34338 .51873 L p .707 .577 .707 r
F P
0 g
s
.46021 .49682 m .47305 .54931 L .44631 .54909 L p .707 .577 .707 r
F P
0 g
s
.44631 .54909 m .43348 .4966 L .46021 .49682 L p .707 .577 .707 r
F P
0 g
s
.30381 .61075 m .31164 .64601 L .2955 .65877 L p .707 .577 .707 r
F P
0 g
s
.50289 .70199 m .49718 .72016 L .48545 .71233 L p .707 .577 .707 r
F P
0 g
s
.48545 .71233 m .49117 .69415 L .50289 .70199 L p .707 .577 .707 r
F P
0 g
s
.31216 .66102 m .31788 .64284 L .33379 .64385 L p .707 .577 .707 r
F P
0 g
s
.33379 .64385 m .32807 .66202 L .31216 .66102 L p .707 .577 .707 r
F P
0 g
s
.31164 .64601 m .30381 .61075 L .32745 .59879 L p .707 .577 .707 r
F P
0 g
s
.44476 .57895 m .45259 .61421 L .42577 .61363 L p .707 .577 .707 r
F P
0 g
s
.42577 .61363 m .41795 .57837 L .44476 .57895 L p .707 .577 .707 r
F P
0 g
s
.35622 .57122 m .34338 .51873 L .37206 .50812 L p .707 .577 .707 r
F P
0 g
s
.34338 .51873 m .35622 .57122 L .33272 .58378 L p .707 .577 .707 r
F P
0 g
s
.43348 .4966 m .44631 .54909 L .41593 .55299 L p .707 .577 .707 r
F P
0 g
s
.41593 .55299 m .4031 .5005 L .43348 .4966 L p .707 .577 .707 r
F P
0 g
s
.38489 .56062 m .37206 .50812 L .4031 .5005 L p .707 .577 .707 r
F P
0 g
s
.37206 .50812 m .38489 .56062 L .35622 .57122 L p .707 .577 .707 r
F P
0 g
s
.4031 .5005 m .41593 .55299 L .38489 .56062 L p .707 .577 .707 r
F P
0 g
s
.32745 .59879 m .33528 .63405 L .31164 .64601 L p .707 .577 .707 r
F P
0 g
s
.49117 .69415 m .48545 .71233 L .46559 .70274 L p .707 .577 .707 r
F P
0 g
s
.46559 .70274 m .47131 .68457 L .49117 .69415 L p .707 .577 .707 r
F P
0 g
s
.33528 .63405 m .32745 .59879 L .35627 .5888 L p .707 .577 .707 r
F P
0 g
s
.41795 .57837 m .42577 .61363 L .39528 .61702 L p .707 .577 .707 r
F P
0 g
s
.39528 .61702 m .38745 .58176 L .41795 .57837 L p .707 .577 .707 r
F P
0 g
s
.32807 .66202 m .33379 .64385 L .35696 .64801 L p .707 .577 .707 r
F P
0 g
s
.35696 .64801 m .35125 .66619 L .32807 .66202 L p .707 .577 .707 r
F P
0 g
s
.3641 .62406 m .35627 .5888 L .38745 .58176 L p .707 .577 .707 r
F P
0 g
s
.35627 .5888 m .3641 .62406 L .33528 .63405 L p .707 .577 .707 r
F P
0 g
s
.38745 .58176 m .39528 .61702 L .3641 .62406 L p .707 .577 .707 r
F P
0 g
s
.47131 .68457 m .46559 .70274 L .43954 .69233 L p .707 .577 .707 r
F P
0 g
s
.43954 .69233 m .44526 .67416 L .47131 .68457 L p .707 .577 .707 r
F P
0 g
s
.35125 .66619 m .35696 .64801 L .38514 .65494 L p .707 .577 .707 r
F P
0 g
s
.38514 .65494 m .37942 .67312 L .35125 .66619 L p .707 .577 .707 r
F P
0 g
s
.44526 .67416 m .43954 .69233 L .40985 .68213 L p .707 .577 .707 r
F P
0 g
s
.40985 .68213 m .41557 .66395 L .44526 .67416 L p .707 .577 .707 r
F P
0 g
s
.37942 .67312 m .38514 .65494 L .41557 .66395 L p .707 .577 .707 r
F P
0 g
s
.41557 .66395 m .40985 .68213 L .37942 .67312 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF3P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP040007FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF000010001eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF000000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00HGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo0`0025YF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00GGoo0P000eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FWoo00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00FGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Moo`80009JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001FOol00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUH005YF
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`03
001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPh0
00=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH70006FUH20004FUH00`00FUH000030002FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040003FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP02FUH5000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`04001JEUYF0004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60005FUH00`00FUIJEP02FUH200000eYF001JEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002
FUH50004FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000YOol?000]Ool005Eo
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUH000020004FUH50003FUH30007FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF000087oo2@000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo00@0
05YFFUH000AJEP03001JEUYF00EJEP<000IJEPP00003FUH005YF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0000?OolA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol0
1000FUIJEP0015YF00<005YFFUH00eYF0`0000=JEP00FUH01EYF1@001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`04001JEUYF0003FUH01000FUIJEUYF
0P000Woo00<005YF00000eYF1@000eYF3`001UYF00<005YFFUH00UYF00@005YF000000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009oo`D000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool003moo`l000Qoo`04001JEUYF0004FUH=00000eYF000000050003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00@000Aoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJ
EP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD0009JEP07001JEUYFFUH005YF000015YF10001UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002eoo`00<goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YF000000=JEP80009JEP03001JEUYF00800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00002FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000UYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00
<Goo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUH0
05YF00800004FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000`Ool01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YFFUIJEP00FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;goo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUIJEP001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
1eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH00UYF3P000eYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001J
EP00008000=JEP@00003FUH0000000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YFFUH01EYF1000
1UYF0P0000EJEP00001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7000/Ool002eoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP@000QJEP03001JEUYF00@000UJEP03001JEUYF009JEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ40009JEP@002aoo`00
;Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
1EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF1P000UYF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0000=JEP00FUH01UYF00@005YFFUIJEPH0031oo`00;Goo0P000eYF00<005YFFUH00eYF
00<005YFFUH00UYF2@0015YF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH01EYF00<005YF
000010000eYF00<005YFFUH01`0015YF00<005YFFUH01EYF0`001EYF00@005YF000000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPP00003FUH005YF00MJEP03001JEUYF009JEPL003Ioo`00;7oo
00<005YF00000eYF00<005YFFUH00eYF1@002Goo200000EJEP00FUIJEP0000AJEP03001JEUYF00AJ
EP@000=JEPL0009JEPD000AJEP03001JEUYF00=JEP8000=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP03FUH01000FUIJEUYF2@0025YF00<005YFFUH00UYF2@00?Goo000/Ool00`00FUH00003FUH01000
FUIJEUYF0P005Woo0P000UYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP07001JEUYFFUH005YF
00001UYF1@0015YF00<005YFFUH00`001EYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000P000MJEP03
001JEUYF009JEQl0031oo`00;7oo00<005YF00000eYF00@005YF000001Uoo`04001JEUYF0005FUH0
1000FUH000001EYF00L005YFFUIJEP00FUH00006FUH40005FUH300000eYF001JEP05FUH00`00FUIJ
EP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUHR
0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool20004FUH2000L
Ool01000FUIJEP0015YF0`0000=JEP00000010000eYF00<005YF00001UYF00<005YFFUH00eYF0`00
15YF00<005YFFUH015YF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00003Goo2@0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;7oo0P000UYF0P007Woo00@005YFFUH000=J
EP<000AJEP04001JEUYFFUH60006FUH00`00FUIJEP030008FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool4000015YF0000000057oo0`001Goo00@005YFFUH0
009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEP0000<0009JEP@00003FUH005YF00QJ
EP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH000060002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000/Ool00eYF001J
EP02FUH01000FUIJEP004Woo1@0017oo00@005YFFUIJEPD000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPD000=JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0009FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;goo000[Ool30003FUH01000FUIJEUYF0P0047oo1@0017oo00P005YFFUIJEP00FUH005YF
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100025YF00<005YFFUH01EYF0P00
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00:goo0`000eYF00<005YFFUH00eYF0P003Woo1@001Goo0UYF
0P0000AJEP000000009JEPD000=JEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF
00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00:goo00<005YF00000eYF00<005YFFUH00eYF
00@005YF000000Ioo`l00003OomJEP00009JEP8000AJEP03001JEUYF009JEPD000MJEP03001JEUYF
00MJEP04001JEP000003FUH01000FUIJEUYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool0
0`00FUH00003FUH00`00FUIJEP03FUH01000FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH0
0P000eYF00<005YF00000eYF00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH01eYF00<0
05YFFUH00UYF100000=JEP0000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH400000eYF001JEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00`001UYF00<005YFFUH00UYF0P0000=JEP0000000`001eYF00<005YF
FUH01EYF0`000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000[Ool00`00FUIJEP02
FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP0015YF00<005YFFUH015YF00<005YFFUH015YF10000UYF10000UYF00<005YFFUH01eYF00H0
05YF000005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP00
0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF5`00;Woo000/Ool01@00FUIJEUYF00000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF00@005YFFUH000EJEP8000AJEP03001JEUYF00EJEP04001JEP000002FUH70007
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPX000AJEP03
001JEUYF00EJEP<0009JEPD002ioo`00;7oo00H005YFFUIJEP00FUH200000eYF001JEP05FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF00H005YF000005YF0007
FUH00`00FUIJEP02FUH;0005FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEPX0
00QJEP@00003FUH005YF00MJEP@003=oo`00;Goo00<005YFFUH00P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00@005YFFUIJEP<000IJEP03001J
EUYF00=JEPD000AJEP@00003FUH005YF00MJEP<000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP04
001JEUYFFUH30007FUH00`00FUH0000dOol002ioo`04001JEP000003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP03FUH20004FUH00`00
FUIJEP03FUH800000eYF001JEP02FUH30007FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEPH000MJEP03001JEUYF00IJEP03
001JEUYF009JEPT0009oo`8000AJEP05001JEUYFFUH0000cOol002ioo`04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3@0000=J
EP00FUH01UYF0`0015YF0`001EYF0P0015YF00<005YFFUH00eYF0P0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP04001JEUYF0007FUH00`00FUIJEP02
FUH9000=Ool300000eYF001JEP03FUH00`00Oomoo`0`Ool002moo`03001JEP00009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEPH000IJEP03001JEUYF00IJEP<000AJEP<00003FUH005YF00EJEP<0009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH00000014001Uoo`8000EJ
EP03001oogoo02moo`00;goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF
00<005YFFUH01EYF00<005YFFUH015YF0P0000AJEP00FUIJEP@0009JEP03001JEUYF00MJEP03001J
EP0000<000=JEP8000EJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000EJEP00FUIJEP0000EJEP03001JEUYF009JEP03001oogoo01eoo`8000=J
EP80031oo`00;goo0P000eYF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF10000UYF00<005YF
FUH01EYF00<005YFFUH015YF0P0000=JEP00FUH01EYF10001eYF00<005YFFUH015YF1`000eYF00L0
05YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001EYF
001JEUYF00001EYF00@005YFFUIJEP80025oo`06001JEUYF001JEP00;goo000_Ool20003FUH00`00
FUH000030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04
FUH200000eYF001JEP05FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00@005YFFUIJEP@000AJ
EP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP04001JEUYFFUH2000ROol300000eYF001oo`0^Ool002moo`8000=JEP@000EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05001JEP00FUH00006FUH0
0`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF009JEP03001JEUYF
009JEP8002Aoo`04001JEUYF000^Ool002moo`80009JEP03001oogoo009oo`8000=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH30005FUH01@00FUH005YF00001UYF
00<005YFFUH01UYF0`001eYF00<005YFFUH015YF00L005YF000005YF001JEP02000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000:Ool3000HOol01000FUIJEP00;Goo000^Ool00`00FUH000020007Ool200000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH01@00FUH005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP04001J
EUYFFUH2000:Ool5000GOol01000FUIJEP00;Goo000^Ool00`00FUH0000;Ool40006FUH00`00FUH0
00020004FUH00`00FUIJEP05FUH00`00FUH000030003Ool02000FUIJEP00FUH005YF0006FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH01000FUIJEUYF0P002Woo1@0067oo0`00
;Goo000^Ool200000eYF001oo`0=Ool40002FUH60003FUH00`00FUIJEP02FUH50008Ool3000015YF
001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF300000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00P000UYF00<005YFFUH00UYF0P002Woo
1@0067oo0P0000=JEP00Ool0:goo000^Ool20002FUH00`00Oomoo`0?Ool@000?Ool01@00FUH005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP<000AJEP8000]oo`<0
01Yoo`03001JEP0002aoo`00;Woo0P000eYF00<007ooOol04Goo1@0067oo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF0P000UYF0P000eYF00<005YF0000:7oo
00<005YF0000;7oo000^Ool00`00FUIJEP02FUH3000BOol3000IOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH400001eYF000005YF001JEP0002Qoo`03001J
EP0002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH00P00;Goo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00@005YF0000009JEP800005FUH00000001JEP03000ZOol00`00Oomoo`0[
Ool002ioo`03001JEUYF009JEP03001JEUYF009JEP<002Uoo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP04001JEP000002FUH00`00FUH00003FUH4000YOol2000]Ool002ioo`03001JEUYF
009JEP03001JEUYF00=JEP04001JEP00000VOol01@00FUH005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH015YF30000UYF00<005YFFUH01eYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEP8000=JEP80009JEP03001JEP00008002Moo`8002eoo`00;Woo00D005YFFUIJEP0000IJ
EP04001JEUYFFUH3000QOol20002FUH00`00FUH00006FUH00`00FUIJEP04FUH900000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH005YF0P001EYF00<005YF000015YF0P0097oo0`00;Goo000_Ool01000FUIJEP001UYF00<005YF
FUH015YF10005goo2`0000=JEP00FUH01EYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF1P001UYF00<005YFFUH00UYF00@005YF001JEP8000IJEP8000EJEP<0
021oo`800003FUH007oo02eoo`00<7oo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH01000
37oo1`000eYF1@0000EJEP00001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP06001JEP00
FUH005YF0P0015YF00@005YF000000=JEP04001JEUYF000NOol00`00FUIJEP02000^Ool0035oo`80
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`000=JEPL0009JEP04001JEUYFFUH200000eYF001J
EP02FUH20007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH30004FUH01@00FUH005YF00000eYF00@005YFFUH000AJEP<000=JEP03001oogoo
01Yoo`8000=JEP03001oogoo02eoo`00<Woo00<005YFFUH00eYF00<005YFFUH01UYF2P0015YF2000
0eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001JEP<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF0080009JEP04
001JEP000005FUH30007FUH5000HOol300000eYF001JEP02FUH00`00Oomoo`0]Ool003=oo`8000=J
EP03001JEP0000L000AJEPT000AJEP03001JEUYF00AJEP03001JEUYF00AJEP06001JEUYFFUH005YF
0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF0P001eYF00<005YF0000
0`0047oo1P0015YF00@005YFFUH0031oo`00=7oo1P000eYF2@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
00AJEP00000000IJEP04001JEP000004FUH00`00FUIJEP04FUH@0004FUH00`00FUIJEP03FUH3000a
Ool002moo`D0009JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EUYFFUH80004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF000000050002FUH01000FUIJ
EUYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00<goo
000[Ool;0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
0002FUH300000goo00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001UYF0`00
1UYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8003Eoo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P000UYF
00<005YFFUH00eYF0P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000IJ
EP03001JEUYF008000=JEP04001JEUYFFUH30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUH00000=goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP050007FUH01000FUIJEUYF0P001Goo0P0015YF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH000IJEP04001JEUYFFUH300000eYF001JEP02FUH200001Woo00000000FUH000QJ
EP03001JEUYF009JEPD003Uoo`00:goo00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH00UYF1`0015YF00<005YFFUH01EYF00@005YF000000Qoo`03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0000IJEP03001JEUYF009JEP03001JEP000080009JEP03
001JEP0000Aoo`l003ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF4000
15YF00<005YFFUH00UYF1@002Woo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
1eYF00D005YFFUIJEP00009JEP03001JEUYF00<00003FUH007oo051oo`00;7oo00<005YF00000UYF
3@0047oo2@0047oo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH01UYF00D005YF
FUIJEP0000=JEP04001JEUYFFUH2001BOol002aoo`D003Qoo`<000QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH30008FUH0
0`00FUIJEP020003FUH00`00FUIJEP03001BOol006]oo`8000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP0000L000AJEP04001J
EUYF0002FUH00`00FUH00003FUH00`00FUH0001BOol006eoo`<000AJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000Qoo`L000=JEP03001J
EP0000D005=oo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01P0047oo00<005YFFUH00eYF00<007ooOol0Egoo001cOol40008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH50002Ool5000=Ool30005FUH00`00Oomoo`1G
Ool007Moo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH60007Ool5000<Ool0
1000FUIJEP0015YF00<007ooOol0F7oo001mOolO000=Ool5000;Ool00`00FUIJEP02FUH01000FUH0
0000Fgoo002=Ool00`00FUH00003FUH00`00Oomoo`0DOol3000:Ool20005FUH2001MOol008aoo`04
001JEUYF0002FUH00`00Oomoo`0POol20007FUH00`00Oomoo`1LOol008aoo`04001JEUYFFUH2000Q
Ool200000eYF001JEP04FUH2001OOol008aoo`05001JEUYFFUH0000OOol30004FUH01@00FUIJEUYF
0000HGoo002<Ool200000eYF001oo`0LOol30007FUH01000FUH00000HWoo002=Ool00`00FUH0000K
Ool200000eYF001JEP08FUH00`00Oomoo`1ROol008eoo`03FUH007oo01Qoo`<000AJEP03001JEUYF
00AJEP8006Eoo`00SGoo0`0057oo10001eYF00<005YFFUH00UYF0P00Igoo002=Ool2000015YF0000
00003Goo10000UYF00<005YFFUH01eYF00@005YF000006Uoo`00SWoo00<005YF00000UYF3@001UYF
00<005YFFUH01UYF0`00Jgoo002>Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH00UYF0`00KWoo002?Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUH00002001aOol0091oo`<000AJEP03001JEUYF00AJEP03001JEUYF00=JEPD007Aoo`00TWoo
0`000UYF00<005YFFUH00UYF2000NGoo002EOol70021Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58871 .74323 m .59668 .68736 L .56581 .68166 L p .707 .577 .707 r
F P
0 g
s
.59668 .68736 m .58871 .74323 L .62024 .74692 L p .707 .577 .707 r
F P
0 g
s
.62024 .74692 m .62821 .69106 L .59668 .68736 L p .707 .577 .707 r
F P
0 g
s
.62821 .69106 m .62024 .74692 L .64934 .74824 L p .707 .577 .707 r
F P
0 g
s
.64934 .74824 m .65732 .69238 L .62821 .69106 L p .707 .577 .707 r
F P
0 g
s
.55784 .73752 m .56581 .68166 L .53862 .6745 L p .707 .577 .707 r
F P
0 g
s
.56581 .68166 m .55784 .73752 L .58871 .74323 L p .707 .577 .707 r
F P
0 g
s
.65732 .69238 m .64934 .74824 L .67317 .74706 L p .707 .577 .707 r
F P
0 g
s
.67317 .74706 m .68115 .6912 L .65732 .69238 L p .707 .577 .707 r
F P
0 g
s
.53862 .6745 m .53065 .73036 L .55784 .73752 L p .707 .577 .707 r
F P
0 g
s
.53065 .73036 m .53862 .6745 L .51778 .66659 L p .707 .577 .707 r
F P
0 g
s
.60147 .80283 m .60633 .76557 L .57542 .76019 L p .707 .577 .707 r
F P
0 g
s
.60633 .76557 m .60147 .80283 L .63306 .80614 L p .707 .577 .707 r
F P
0 g
s
.63306 .80614 m .63792 .76889 L .60633 .76557 L p .707 .577 .707 r
F P
0 g
s
.63792 .76889 m .63306 .80614 L .66223 .80707 L p .707 .577 .707 r
F P
0 g
s
.66223 .80707 m .66709 .76981 L .63792 .76889 L p .707 .577 .707 r
F P
0 g
s
.57056 .79745 m .57542 .76019 L .54821 .75326 L p .707 .577 .707 r
F P
0 g
s
.57542 .76019 m .57056 .79745 L .60147 .80283 L p .707 .577 .707 r
F P
0 g
s
.51778 .66659 m .5098 .72245 L .53065 .73036 L p .707 .577 .707 r
F P
0 g
s
.68115 .6912 m .67317 .74706 L .68939 .74349 L p .707 .577 .707 r
F P
0 g
s
.68939 .74349 m .69737 .68763 L .68115 .6912 L p .707 .577 .707 r
F P
0 g
s
.59255 .86086 m .58898 .84312 L .55838 .84606 L p .707 .577 .707 r
F P
0 g
s
.58898 .84312 m .59255 .86086 L .62385 .85437 L p .707 .577 .707 r
F P
0 g
s
.62385 .85437 m .62028 .83662 L .58898 .84312 L p .707 .577 .707 r
F P
0 g
s
.54821 .75326 m .54335 .79052 L .57056 .79745 L p .707 .577 .707 r
F P
0 g
s
.62028 .83662 m .62385 .85437 L .65277 .84495 L p .707 .577 .707 r
F P
0 g
s
.65277 .84495 m .6492 .8272 L .62028 .83662 L p .707 .577 .707 r
F P
0 g
s
.66709 .76981 m .66223 .80707 L .68612 .8055 L p .707 .577 .707 r
F P
0 g
s
.68612 .8055 m .69098 .76825 L .66709 .76981 L p .707 .577 .707 r
F P
0 g
s
.5098 .72245 m .51778 .66659 L .50532 .6587 L p .707 .577 .707 r
F P
0 g
s
.55838 .84606 m .56195 .86381 L .59255 .86086 L p .707 .577 .707 r
F P
0 g
s
.54335 .79052 m .54821 .75326 L .52737 .74547 L p .707 .577 .707 r
F P
0 g
s
.56195 .86381 m .55838 .84606 L .53148 .84516 L p .707 .577 .707 r
F P
0 g
s
.6492 .8272 m .65277 .84495 L .6765 .83353 L p .707 .577 .707 r
F P
0 g
s
.6765 .83353 m .67293 .81578 L .6492 .8272 L p .707 .577 .707 r
F P
0 g
s
.53148 .84516 m .53505 .8629 L .56195 .86381 L p .707 .577 .707 r
F P
0 g
s
.52737 .74547 m .52251 .78273 L .54335 .79052 L p .707 .577 .707 r
F P
0 g
s
.50532 .6587 m .49734 .71456 L .5098 .72245 L p .707 .577 .707 r
F P
0 g
s
.69098 .76825 m .68612 .8055 L .70241 .80161 L p .707 .577 .707 r
F P
0 g
s
.70241 .80161 m .70727 .76435 L .69098 .76825 L p .707 .577 .707 r
F P
0 g
s
.69737 .68763 m .68939 .74349 L .69642 .73789 L p .707 .577 .707 r
F P
0 g
s
.69642 .73789 m .70439 .68203 L .69737 .68763 L p .707 .577 .707 r
F P
0 g
s
.53505 .8629 m .53148 .84516 L .5109 .8405 L p .707 .577 .707 r
F P
0 g
s
.67293 .81578 m .6765 .83353 L .69271 .82123 L p .707 .577 .707 r
F P
0 g
s
.69271 .82123 m .68914 .80348 L .67293 .81578 L p .707 .577 .707 r
F P
0 g
s
.52251 .78273 m .52737 .74547 L .51493 .73758 L p .707 .577 .707 r
F P
0 g
s
.49734 .71456 m .50532 .6587 L .50246 .65161 L p .707 .577 .707 r
F P
0 g
s
.5109 .8405 m .51447 .85824 L .53505 .8629 L p .707 .577 .707 r
F P
0 g
s
.51493 .73758 m .51007 .77484 L .52251 .78273 L p .707 .577 .707 r
F P
0 g
s
.50246 .65161 m .49448 .70747 L .49734 .71456 L p .707 .577 .707 r
F P
0 g
s
.51447 .85824 m .5109 .8405 L .49866 .83254 L p .707 .577 .707 r
F P
0 g
s
.70727 .76435 m .70241 .80161 L .70949 .79577 L p .707 .577 .707 r
F P
0 g
s
.70949 .79577 m .71435 .75851 L .70727 .76435 L p .707 .577 .707 r
F P
0 g
s
.68914 .80348 m .69271 .82123 L .69981 .80925 L p .707 .577 .707 r
F P
0 g
s
.69981 .80925 m .69624 .7915 L .68914 .80348 L p .707 .577 .707 r
F P
0 g
s
.70439 .68203 m .69642 .73789 L .69356 .73079 L p .707 .577 .707 r
F P
0 g
s
.69356 .73079 m .70154 .67493 L .70439 .68203 L p .707 .577 .707 r
F P
0 g
s
.49866 .83254 m .50223 .85028 L .51447 .85824 L p .707 .577 .707 r
F P
0 g
s
.51007 .77484 m .51493 .73758 L .51211 .73036 L p .707 .577 .707 r
F P
0 g
s
.49224 .82187 m .49224 .31998 L .44811 .31744 L p .707 .577 .707 r
F P
0 g
s
.49448 .70747 m .50246 .65161 L .50948 .646 L p .707 .577 .707 r
F P
0 g
s
.51211 .73036 m .50725 .76762 L .51007 .77484 L p .707 .577 .707 r
F P
0 g
s
.50948 .646 m .50151 .70186 L .49448 .70747 L p .707 .577 .707 r
F P
0 g
s
.50725 .76762 m .51211 .73036 L .51919 .72452 L p .707 .577 .707 r
F P
0 g
s
.50151 .70186 m .50948 .646 L .52571 .64243 L p .707 .577 .707 r
F P
0 g
s
.51919 .72452 m .51434 .76178 L .50725 .76762 L p .707 .577 .707 r
F P
0 g
s
.52571 .64243 m .51773 .6983 L .50151 .70186 L p .707 .577 .707 r
F P
0 g
s
.50223 .85028 m .49866 .83254 L .49595 .82205 L p .707 .578 .707 r
F P
0 g
s
.49595 .82205 m .49953 .8398 L .50223 .85028 L p .707 .578 .707 r
F P
0 g
s
.49953 .8398 m .49595 .82205 L .50306 .81008 L p .707 .577 .707 r
F P
0 g
s
.50306 .81008 m .50663 .82782 L .49953 .8398 L p .707 .577 .707 r
F P
0 g
s
.51434 .76178 m .51919 .72452 L .53548 .72063 L p .707 .577 .707 r
F P
0 g
s
.51773 .6983 m .52571 .64243 L .54953 .64125 L p .707 .577 .707 r
F P
0 g
s
.53548 .72063 m .53062 .75789 L .51434 .76178 L p .707 .577 .707 r
F P
0 g
s
.54953 .64125 m .54156 .69711 L .51773 .6983 L p .707 .577 .707 r
F P
0 g
s
.50663 .82782 m .50306 .81008 L .51926 .79778 L p .707 .577 .707 r
F P
0 g
s
.51926 .79778 m .52284 .81552 L .50663 .82782 L p .707 .577 .707 r
F P
0 g
s
.53062 .75789 m .53548 .72063 L .55938 .71907 L p .707 .577 .707 r
F P
0 g
s
.55938 .71907 m .55452 .75633 L .53062 .75789 L p .707 .577 .707 r
F P
0 g
s
.52284 .81552 m .51926 .79778 L .54299 .78636 L p .707 .577 .707 r
F P
0 g
s
.54299 .78636 m .54657 .8041 L .52284 .81552 L p .707 .577 .707 r
F P
0 g
s
.49224 .31998 m .49224 .82187 L .53713 .82062 L p .707 .577 .707 r
F P
0 g
s
.53713 .82062 m .53713 .31873 L .49224 .31998 L p .707 .577 .707 r
F P
0 g
s
.54156 .69711 m .54953 .64125 L .57864 .64257 L p .707 .577 .707 r
F P
0 g
s
.57864 .64257 m .57066 .69844 L .54156 .69711 L p .707 .577 .707 r
F P
0 g
s
.55452 .75633 m .55938 .71907 L .58855 .71999 L p .707 .577 .707 r
F P
0 g
s
.58855 .71999 m .58369 .75725 L .55452 .75633 L p .707 .577 .707 r
F P
0 g
s
.54657 .8041 m .54299 .78636 L .57192 .77694 L p .707 .577 .707 r
F P
0 g
s
.57192 .77694 m .57549 .79468 L .54657 .8041 L p .707 .577 .707 r
F P
0 g
s
.57549 .79468 m .57192 .77694 L .60322 .77044 L p .707 .577 .707 r
F P
0 g
s
.60322 .77044 m .60679 .78818 L .57549 .79468 L p .707 .577 .707 r
F P
0 g
s
.53713 .31873 m .53713 .82062 L .57839 .81571 L p .707 .577 .707 r
F P
0 g
s
.57066 .69844 m .57864 .64257 L .61017 .64627 L p .707 .577 .707 r
F P
0 g
s
.61017 .64627 m .60219 .70213 L .57066 .69844 L p .707 .577 .707 r
F P
0 g
s
.57839 .81571 m .57839 .31382 L .53713 .31873 L p .707 .577 .707 r
F P
0 g
s
.44811 .81933 m .44811 .31744 L .40906 .31137 L p .707 .577 .707 r
F P
0 g
s
.44811 .31744 m .44811 .81933 L .49224 .82187 L p .707 .577 .707 r
F P
0 g
s
.71435 .75851 m .70949 .79577 L .70668 .78855 L p .707 .577 .707 r
F P
0 g
s
.70668 .78855 m .71154 .75129 L .71435 .75851 L p .707 .577 .707 r
F P
0 g
s
.69624 .7915 m .69981 .80925 L .69711 .79877 L p .707 .578 .707 r
F P
0 g
s
.69711 .79877 m .69354 .78102 L .69624 .7915 L p .707 .578 .707 r
F P
0 g
s
.64104 .65197 m .63307 .70784 L .60219 .70213 L p .707 .577 .707 r
F P
0 g
s
.60219 .70213 m .61017 .64627 L .64104 .65197 L p .707 .577 .707 r
F P
0 g
s
.58369 .75725 m .58855 .71999 L .62013 .7233 L p .707 .577 .707 r
F P
0 g
s
.63382 .7675 m .63739 .78524 L .60679 .78818 L p .707 .577 .707 r
F P
0 g
s
.60679 .78818 m .60322 .77044 L .63382 .7675 L p .707 .577 .707 r
F P
0 g
s
.62013 .7233 m .61528 .76056 L .58369 .75725 L p .707 .577 .707 r
F P
0 g
s
.57839 .31382 m .57839 .81571 L .61197 .80762 L p .707 .577 .707 r
F P
0 g
s
.61197 .80762 m .61197 .30573 L .57839 .31382 L p .707 .577 .707 r
F P
0 g
s
.70154 .67493 m .69356 .73079 L .6811 .72291 L p .707 .577 .707 r
F P
0 g
s
.6811 .72291 m .68907 .66704 L .70154 .67493 L p .707 .577 .707 r
F P
0 g
s
.40906 .81326 m .40906 .31137 L .37891 .30236 L p .707 .577 .707 r
F P
0 g
s
.40906 .31137 m .40906 .81326 L .44811 .81933 L p .707 .577 .707 r
F P
0 g
s
.25021 .72331 m .25365 .67049 L .22251 .666 L p .707 .577 .707 r
F P
0 g
s
.25365 .67049 m .25021 .72331 L .28198 .72386 L p .707 .577 .707 r
F P
0 g
s
.28198 .72386 m .28542 .67104 L .25365 .67049 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28542 .67104 m .28198 .72386 L .31128 .72041 L p .707 .577 .707 r
F P
0 g
s
.31128 .72041 m .31471 .66759 L .28542 .67104 L p .707 .577 .707 r
F P
0 g
s
.21907 .71882 m .22251 .666 L .19506 .658 L p .707 .577 .707 r
F P
0 g
s
.22251 .666 m .21907 .71882 L .25021 .72331 L p .707 .577 .707 r
F P
0 g
s
.25555 .78619 m .25765 .75079 L .22651 .74649 L p .707 .577 .707 r
F P
0 g
s
.25765 .75079 m .25555 .78619 L .28734 .78665 L p .707 .577 .707 r
F P
0 g
s
.28734 .78665 m .28943 .75125 L .25765 .75079 L p .707 .577 .707 r
F P
0 g
s
.69354 .78102 m .69711 .79877 L .68487 .7908 L p .707 .577 .707 r
F P
0 g
s
.68487 .7908 m .6813 .77306 L .69354 .78102 L p .707 .577 .707 r
F P
0 g
s
.71154 .75129 m .70668 .78855 L .69424 .78066 L p .707 .577 .707 r
F P
0 g
s
.69424 .78066 m .6991 .7434 L .71154 .75129 L p .707 .577 .707 r
F P
0 g
s
.28943 .75125 m .28734 .78665 L .31667 .78323 L p .707 .577 .707 r
F P
0 g
s
.31667 .78323 m .31876 .74783 L .28943 .75125 L p .707 .577 .707 r
F P
0 g
s
.31471 .66759 m .31128 .72041 L .33523 .7133 L p .707 .577 .707 r
F P
0 g
s
.33523 .7133 m .33867 .66048 L .31471 .66759 L p .707 .577 .707 r
F P
0 g
s
.65104 .72869 m .64619 .76595 L .61528 .76056 L p .707 .577 .707 r
F P
0 g
s
.61528 .76056 m .62013 .7233 L .65104 .72869 L p .707 .577 .707 r
F P
0 g
s
.61197 .30573 m .61197 .80762 L .63459 .79714 L p .707 .577 .707 r
F P
0 g
s
.66823 .65913 m .66025 .71499 L .63307 .70784 L p .707 .577 .707 r
F P
0 g
s
.63307 .70784 m .64104 .65197 L .66823 .65913 L p .707 .577 .707 r
F P
0 g
s
.63739 .78524 m .63382 .7675 L .66072 .7684 L p .707 .577 .707 r
F P
0 g
s
.63459 .79714 m .63459 .29525 L .61197 .30573 L p .707 .577 .707 r
F P
0 g
s
.22442 .78189 m .22651 .74649 L .19908 .73877 L p .707 .577 .707 r
F P
0 g
s
.22651 .74649 m .22442 .78189 L .25555 .78619 L p .707 .577 .707 r
F P
0 g
s
.68907 .66704 m .6811 .72291 L .66025 .71499 L p .707 .577 .707 r
F P
0 g
s
.66025 .71499 m .66823 .65913 L .68907 .66704 L p .707 .577 .707 r
F P
0 g
s
.19162 .71082 m .19506 .658 L .17397 .64728 L p .707 .577 .707 r
F P
0 g
s
.19506 .658 m .19162 .71082 L .21907 .71882 L p .707 .577 .707 r
F P
0 g
s
.31876 .74783 m .31667 .78323 L .34067 .77626 L p .707 .577 .707 r
F P
0 g
s
.34067 .77626 m .34276 .74086 L .31876 .74783 L p .707 .577 .707 r
F P
0 g
s
.37891 .80425 m .37891 .30236 L .36061 .29129 L p .707 .577 .707 r
F P
0 g
s
.37891 .30236 m .37891 .80425 L .40906 .81326 L p .707 .577 .707 r
F P
0 g
s
.19699 .77417 m .19908 .73877 L .17804 .72839 L p .707 .577 .707 r
F P
0 g
s
.19908 .73877 m .19699 .77417 L .22442 .78189 L p .707 .577 .707 r
F P
0 g
s
.33867 .66048 m .33523 .7133 L .35149 .70323 L p .707 .577 .707 r
F P
0 g
s
.35149 .70323 m .35493 .65041 L .33867 .66048 L p .707 .577 .707 r
F P
0 g
s
.25188 .79563 m .25033 .77653 L .21925 .77843 L p .707 .577 .707 r
F P
0 g
s
.25033 .77653 m .25188 .79563 L .28361 .79284 L p .707 .577 .707 r
F P
0 g
s
.28361 .79284 m .28206 .77373 L .25033 .77653 L p .707 .577 .707 r
F P
0 g
s
.21925 .77843 m .2208 .79753 L .25188 .79563 L p .707 .577 .707 r
F P
0 g
s
.28206 .77373 m .28361 .79284 L .31288 .78942 L p .707 .577 .707 r
F P
0 g
s
.31288 .78942 m .31134 .77031 L .28206 .77373 L p .707 .577 .707 r
F P
0 g
s
.17053 .7001 m .17397 .64728 L .16132 .63489 L p .707 .577 .707 r
F P
0 g
s
.17397 .64728 m .17053 .7001 L .19162 .71082 L p .707 .577 .707 r
F P
0 g
s
.6813 .77306 m .68487 .7908 L .66429 .78614 L p .707 .577 .707 r
F P
0 g
s
.66429 .78614 m .66072 .7684 L .6813 .77306 L p .707 .577 .707 r
F P
0 g
s
.6991 .7434 m .69424 .78066 L .67339 .77287 L p .707 .577 .707 r
F P
0 g
s
.67339 .77287 m .67825 .73561 L .6991 .7434 L p .707 .577 .707 r
F P
0 g
s
.2208 .79753 m .21925 .77843 L .19187 .77924 L p .707 .577 .707 r
F P
0 g
s
.19187 .77924 m .19341 .79834 L .2208 .79753 L p .707 .577 .707 r
F P
0 g
s
.17804 .72839 m .17595 .76379 L .19699 .77417 L p .707 .577 .707 r
F P
0 g
s
.34276 .74086 m .34067 .77626 L .35699 .76642 L p .707 .577 .707 r
F P
0 g
s
.35699 .76642 m .35908 .73102 L .34276 .74086 L p .707 .577 .707 r
F P
0 g
s
.31134 .77031 m .31288 .78942 L .33683 .78571 L p .707 .577 .707 r
F P
0 g
s
.33683 .78571 m .33529 .76661 L .31134 .77031 L p .707 .577 .707 r
F P
0 g
s
.66072 .7684 m .66429 .78614 L .63739 .78524 L p .707 .577 .707 r
F P
0 g
s
.63459 .29525 m .63459 .79714 L .64404 .7853 L p .707 .577 .707 r
F P
0 g
s
.64404 .7853 m .64404 .28341 L .63459 .29525 L p .707 .577 .707 r
F P
0 g
s
.17595 .76379 m .17804 .72839 L .16544 .71637 L p .707 .577 .707 r
F P
0 g
s
.35493 .65041 m .35149 .70323 L .35848 .69117 L p .707 .577 .707 r
F P
0 g
s
.35848 .69117 m .36191 .63835 L .35493 .65041 L p .707 .577 .707 r
F P
0 g
s
.19341 .79834 m .19187 .77924 L .17085 .77889 L p .707 .577 .707 r
F P
0 g
s
.17085 .77889 m .1724 .798 L .19341 .79834 L p .707 .577 .707 r
F P
0 g
s
.16132 .63489 m .15788 .68771 L .17053 .7001 L p .707 .577 .707 r
F P
0 g
s
.67825 .73561 m .67339 .77287 L .64619 .76595 L p .707 .577 .707 r
F P
0 g
s
.64619 .76595 m .65104 .72869 L .67825 .73561 L p .707 .577 .707 r
F P
0 g
s
.35908 .73102 m .35699 .76642 L .36404 .75469 L p .707 .577 .707 r
F P
0 g
s
.36404 .75469 m .36613 .71928 L .35908 .73102 L p .707 .577 .707 r
F P
0 g
s
.36191 .63835 m .35848 .69117 L .3555 .67832 L p .707 .577 .707 r
F P
0 g
s
.3555 .67832 m .35893 .6255 L .36191 .63835 L p .707 .577 .707 r
F P
0 g
s
.36321 .70679 m .36112 .74219 L .34852 .73017 L p .707 .577 .707 r
F P
0 g
s
.34852 .73017 m .35061 .69477 L .36321 .70679 L p .707 .577 .707 r
F P
0 g
s
.36061 .79318 m .36061 .29129 L .35596 .27925 L p .707 .577 .707 r
F P
0 g
s
.36613 .71928 m .36404 .75469 L .36112 .74219 L p .707 .577 .707 r
F P
0 g
s
.36112 .74219 m .36321 .70679 L .36613 .71928 L p .707 .577 .707 r
F P
0 g
s
.36061 .29129 m .36061 .79318 L .37891 .80425 L p .707 .577 .707 r
F P
0 g
s
.15788 .68771 m .16132 .63489 L .15834 .62203 L p .707 .577 .707 r
F P
0 g
s
.16544 .71637 m .16335 .75177 L .17595 .76379 L p .707 .577 .707 r
F P
0 g
s
.33529 .76661 m .33683 .78571 L .35312 .78207 L p .707 .577 .707 r
F P
0 g
s
.35312 .78207 m .35157 .76297 L .33529 .76661 L p .707 .577 .707 r
F P
0 g
s
.16335 .75177 m .16544 .71637 L .16252 .70388 L p .707 .577 .707 r
F P
0 g
s
.1724 .798 m .17085 .77889 L .15827 .77742 L p .707 .577 .707 r
F P
0 g
s
.15827 .77742 m .15981 .79652 L .1724 .798 L p .707 .577 .707 r
F P
0 g
s
.15834 .62203 m .1549 .67486 L .15788 .68771 L p .707 .577 .707 r
F P
0 g
s
.16252 .70388 m .16043 .73928 L .16335 .75177 L p .707 .577 .707 r
F P
0 g
s
.64404 .28341 m .64404 .7853 L .63938 .77325 L p .707 .577 .707 r
F P
0 g
s
.63938 .77325 m .63938 .27137 L .64404 .28341 L p .707 .577 .707 r
F P
0 g
s
.1549 .67486 m .15834 .62203 L .16532 .60998 L p .707 .577 .707 r
F P
0 g
s
.35157 .76297 m .35312 .78207 L .36014 .77887 L p .707 .577 .707 r
F P
0 g
s
.36014 .77887 m .3586 .75977 L .35157 .76297 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16043 .73928 m .16252 .70388 L .16957 .69214 L p .707 .577 .707 r
F P
0 g
s
.35893 .6255 m .3555 .67832 L .34284 .66593 L p .707 .577 .707 r
F P
0 g
s
.34284 .66593 m .34628 .61311 L .35893 .6255 L p .707 .577 .707 r
F P
0 g
s
.3586 .75977 m .36014 .77887 L .35722 .77641 L p .707 .577 .707 r
F P
0 g
s
.35722 .77641 m .35567 .75731 L .3586 .75977 L p .707 .577 .707 r
F P
0 g
s
.35567 .75731 m .35722 .77641 L .34463 .77493 L p .707 .577 .707 r
F P
0 g
s
.35596 .27925 m .35596 .78114 L .36061 .79318 L p .707 .577 .707 r
F P
0 g
s
.35596 .78114 m .35596 .27925 L .36541 .26741 L p .707 .577 .707 r
F P
0 g
s
.15981 .79652 m .15827 .77742 L .15534 .77496 L p .707 .577 .707 r
F P
0 g
s
.15534 .77496 m .15689 .79406 L .15981 .79652 L p .707 .577 .707 r
F P
0 g
s
.16532 .60998 m .16189 .6628 L .1549 .67486 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16957 .69214 m .16748 .72754 L .16043 .73928 L p .707 .577 .707 r
F P
0 g
s
.16189 .6628 m .16532 .60998 L .18159 .59991 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16748 .72754 m .16957 .69214 L .18589 .6823 L p .707 .577 .707 r
F P
0 g
s
.63938 .27137 m .63938 .77325 L .62109 .76219 L p .707 .577 .707 r
F P
0 g
s
.62109 .76219 m .62109 .2603 L .63938 .27137 L p .707 .577 .707 r
F P
0 g
s
.34628 .61311 m .34284 .66593 L .32176 .65521 L p .707 .577 .707 r
F P
0 g
s
.32176 .65521 m .3252 .60239 L .34628 .61311 L p .707 .577 .707 r
F P
0 g
s
.15689 .79406 m .15534 .77496 L .16237 .77175 L p .707 .577 .707 r
F P
0 g
s
.16237 .77175 m .16391 .79085 L .15689 .79406 L p .707 .577 .707 r
F P
0 g
s
.18159 .59991 m .17815 .65273 L .16189 .6628 L p .707 .577 .707 r
F P
0 g
s
.17815 .65273 m .18159 .59991 L .20554 .5928 L p .707 .577 .707 r
F P
0 g
s
.36541 .7693 m .36541 .26741 L .38803 .25693 L p .707 .577 .707 r
F P
0 g
s
.36541 .26741 m .36541 .7693 L .35596 .78114 L p .707 .577 .707 r
F P
0 g
s
.18589 .6823 m .1838 .7177 L .16748 .72754 L p .707 .577 .707 r
F P
0 g
s
.35061 .69477 m .34852 .73017 L .32748 .71979 L p .707 .577 .707 r
F P
0 g
s
.32748 .71979 m .32957 .68439 L .35061 .69477 L p .707 .577 .707 r
F P
0 g
s
.34463 .77493 m .34309 .75583 L .35567 .75731 L p .707 .577 .707 r
F P
0 g
s
.1838 .7177 m .18589 .6823 L .20989 .67533 L p .707 .577 .707 r
F P
0 g
s
.3252 .60239 m .32176 .65521 L .2943 .64721 L p .707 .577 .707 r
F P
0 g
s
.2943 .64721 m .29774 .59439 L .3252 .60239 L p .707 .577 .707 r
F P
0 g
s
.2021 .64562 m .20554 .5928 L .23483 .58935 L p .707 .577 .707 r
F P
0 g
s
.20554 .5928 m .2021 .64562 L .17815 .65273 L p .707 .577 .707 r
F P
0 g
s
.16391 .79085 m .16237 .77175 L .17865 .76812 L p .707 .577 .707 r
F P
0 g
s
.62109 .2603 m .62109 .76219 L .59094 .75317 L p .707 .577 .707 r
F P
0 g
s
.59094 .75317 m .59094 .25128 L .62109 .2603 L p .707 .577 .707 r
F P
0 g
s
.17865 .76812 m .1802 .78722 L .16391 .79085 L p .707 .577 .707 r
F P
0 g
s
.20989 .67533 m .2078 .71073 L .1838 .7177 L p .707 .577 .707 r
F P
0 g
s
.32957 .68439 m .32748 .71979 L .30004 .71207 L p .707 .577 .707 r
F P
0 g
s
.30004 .71207 m .30214 .67667 L .32957 .68439 L p .707 .577 .707 r
F P
0 g
s
.29774 .59439 m .2943 .64721 L .26317 .64272 L p .707 .577 .707 r
F P
0 g
s
.26317 .64272 m .26661 .5899 L .29774 .59439 L p .707 .577 .707 r
F P
0 g
s
.2314 .64217 m .23483 .58935 L .26661 .5899 L p .707 .577 .707 r
F P
0 g
s
.23483 .58935 m .2314 .64217 L .2021 .64562 L p .707 .577 .707 r
F P
0 g
s
.2078 .71073 m .20989 .67533 L .23922 .67191 L p .707 .577 .707 r
F P
0 g
s
.26661 .5899 m .26317 .64272 L .2314 .64217 L p .707 .577 .707 r
F P
0 g
s
.38803 .25693 m .38803 .75882 L .36541 .7693 L p .707 .577 .707 r
F P
0 g
s
.38803 .75882 m .38803 .25693 L .42161 .24884 L p .707 .577 .707 r
F P
0 g
s
.73683 .64571 m .73339 .58863 L .70226 .58954 L p .707 .577 .707 r
F P
0 g
s
.73339 .58863 m .73683 .64571 L .7686 .64344 L p .707 .577 .707 r
F P
0 g
s
.7686 .64344 m .76516 .58635 L .73339 .58863 L p .707 .577 .707 r
F P
0 g
s
.34309 .75583 m .34463 .77493 L .32362 .77458 L p .707 .577 .707 r
F P
0 g
s
.32362 .77458 m .32207 .75548 L .34309 .75583 L p .707 .577 .707 r
F P
0 g
s
.30214 .67667 m .30004 .71207 L .26891 .70777 L p .707 .577 .707 r
F P
0 g
s
.26891 .70777 m .271 .67237 L .30214 .67667 L p .707 .577 .707 r
F P
0 g
s
.76516 .58635 m .7686 .64344 L .7979 .64002 L p .707 .577 .707 r
F P
0 g
s
.7979 .64002 m .79446 .58293 L .76516 .58635 L p .707 .577 .707 r
F P
0 g
s
.23713 .70731 m .23922 .67191 L .271 .67237 L p .707 .577 .707 r
F P
0 g
s
.23922 .67191 m .23713 .70731 L .2078 .71073 L p .707 .577 .707 r
F P
0 g
s
.70569 .64663 m .70226 .58954 L .6748 .589 L p .707 .577 .707 r
F P
0 g
s
.70226 .58954 m .70569 .64663 L .73683 .64571 L p .707 .577 .707 r
F P
0 g
s
.271 .67237 m .26891 .70777 L .23713 .70731 L p .707 .577 .707 r
F P
0 g
s
.1802 .78722 m .17865 .76812 L .2026 .76441 L p .707 .577 .707 r
F P
0 g
s
.2026 .76441 m .20415 .78351 L .1802 .78722 L p .707 .577 .707 r
F P
0 g
s
.6748 .589 m .67824 .64609 L .70569 .64663 L p .707 .577 .707 r
F P
0 g
s
.79446 .58293 m .7979 .64002 L .82185 .6358 L p .707 .577 .707 r
F P
0 g
s
.82185 .6358 m .81841 .57871 L .79446 .58293 L p .707 .577 .707 r
F P
0 g
s
.59094 .25128 m .59094 .75317 L .55189 .7471 L p .707 .577 .707 r
F P
0 g
s
.55189 .7471 m .55189 .24521 L .59094 .25128 L p .707 .577 .707 r
F P
0 g
s
.67824 .64609 m .6748 .589 L .65372 .58706 L p .707 .577 .707 r
F P
0 g
s
.32207 .75548 m .32362 .77458 L .29623 .7754 L p .707 .577 .707 r
F P
0 g
s
.29623 .7754 m .29469 .7563 L .32207 .75548 L p .707 .577 .707 r
F P
0 g
s
.42161 .75073 m .42161 .24884 L .46287 .24393 L p .707 .577 .707 r
F P
0 g
s
.42161 .24884 m .42161 .75073 L .38803 .75882 L p .707 .577 .707 r
F P
0 g
s
.65372 .58706 m .65715 .64414 L .67824 .64609 L p .707 .577 .707 r
F P
0 g
s
.73109 .70391 m .72899 .66591 L .69786 .66656 L p .707 .577 .707 r
F P
0 g
s
.72899 .66591 m .73109 .70391 L .76287 .70178 L p .707 .577 .707 r
F P
0 g
s
.76287 .70178 m .76078 .66377 L .72899 .66591 L p .707 .577 .707 r
F P
0 g
s
.20415 .78351 m .2026 .76441 L .23188 .76099 L p .707 .577 .707 r
F P
0 g
s
.76078 .66377 m .76287 .70178 L .7922 .69837 L p .707 .577 .707 r
F P
0 g
s
.7922 .69837 m .79011 .66037 L .76078 .66377 L p .707 .577 .707 r
F P
0 g
s
.23188 .76099 m .23342 .78009 L .20415 .78351 L p .707 .577 .707 r
F P
0 g
s
.81841 .57871 m .82185 .6358 L .83811 .63118 L p .707 .577 .707 r
F P
0 g
s
.83811 .63118 m .83467 .57409 L .81841 .57871 L p .707 .577 .707 r
F P
0 g
s
.69786 .66656 m .69995 .70457 L .73109 .70391 L p .707 .577 .707 r
F P
0 g
s
.69995 .70457 m .69786 .66656 L .67043 .66568 L p .707 .577 .707 r
F P
0 g
s
.73485 .77762 m .73639 .76043 L .70531 .75507 L p .707 .577 .707 r
F P
0 g
s
.73639 .76043 m .73485 .77762 L .76658 .77862 L p .707 .577 .707 r
F P
0 g
s
.76658 .77862 m .76812 .76143 L .73639 .76043 L p .707 .577 .707 r
F P
0 g
s
.55189 .24521 m .55189 .7471 L .50776 .74457 L p .707 .577 .707 r
F P
0 g
s
.50776 .74457 m .50776 .24268 L .55189 .24521 L p .707 .577 .707 r
F P
0 g
s
.29469 .7563 m .29623 .7754 L .26515 .7773 L p .707 .577 .707 r
F P
0 g
s
.26515 .7773 m .26361 .75819 L .29469 .7563 L p .707 .577 .707 r
F P
0 g
s
.67043 .66568 m .67252 .70369 L .69995 .70457 L p .707 .577 .707 r
F P
0 g
s
.76812 .76143 m .76658 .77862 L .79585 .77515 L p .707 .577 .707 r
F P
0 g
s
.79585 .77515 m .79739 .75796 L .76812 .76143 L p .707 .577 .707 r
F P
0 g
s
.46287 .74582 m .46287 .24393 L .50776 .24268 L p .707 .577 .707 r
F P
0 g
s
.46287 .24393 m .46287 .74582 L .42161 .75073 L p .707 .577 .707 r
F P
0 g
s
.70377 .77226 m .70531 .75507 L .67792 .74586 L p .707 .577 .707 r
F P
0 g
s
.70531 .75507 m .70377 .77226 L .73485 .77762 L p .707 .577 .707 r
F P
0 g
s
.23342 .78009 m .23188 .76099 L .26361 .75819 L p .707 .577 .707 r
F P
0 g
s
.79011 .66037 m .7922 .69837 L .8162 .69403 L p .707 .577 .707 r
F P
0 g
s
.8162 .69403 m .81411 .65603 L .79011 .66037 L p .707 .577 .707 r
F P
0 g
s
.65715 .64414 m .65372 .58706 L .64106 .58391 L p .707 .577 .707 r
F P
0 g
s
.26361 .75819 m .26515 .7773 L .23342 .78009 L p .707 .577 .707 r
F P
0 g
s
.50776 .24268 m .50776 .74457 L .46287 .74582 L p .707 .577 .707 r
F P
0 g
s
.67792 .74586 m .67638 .76305 L .70377 .77226 L p .707 .577 .707 r
F P
0 g
s
.64106 .58391 m .6445 .64099 L .65715 .64414 L p .707 .577 .707 r
F P
0 g
s
.67252 .70369 m .67043 .66568 L .64939 .66334 L p .707 .577 .707 r
F P
0 g
s
.79739 .75796 m .79585 .77515 L .8198 .76754 L p .707 .577 .707 r
F P
0 g
s
.8198 .76754 m .82135 .75035 L .79739 .75796 L p .707 .577 .707 r
F P
0 g
s
.67638 .76305 m .67792 .74586 L .65691 .73371 L p .707 .577 .707 r
F P
0 g
s
.64939 .66334 m .65148 .70135 L .67252 .70369 L p .707 .577 .707 r
F P
0 g
s
.83467 .57409 m .83811 .63118 L .8451 .62662 L p .707 .577 .707 r
F P
0 g
s
.8451 .62662 m .84166 .56954 L .83467 .57409 L p .707 .577 .707 r
F P
0 g
s
.81411 .65603 m .8162 .69403 L .83252 .68919 L p .707 .577 .707 r
F P
0 g
s
.83252 .68919 m .83043 .65118 L .81411 .65603 L p .707 .577 .707 r
F P
0 g
s
.65691 .73371 m .65536 .7509 L .67638 .76305 L p .707 .577 .707 r
F P
0 g
s
.6445 .64099 m .64106 .58391 L .63808 .57986 L p .707 .577 .707 r
F P
0 g
s
.82135 .75035 m .8198 .76754 L .83609 .75656 L p .707 .577 .707 r
F P
0 g
s
.83609 .75656 m .83763 .73937 L .82135 .75035 L p .707 .577 .707 r
F P
0 g
s
.65148 .70135 m .64939 .66334 L .63679 .65978 L p .707 .577 .707 r
F P
0 g
s
.65536 .7509 m .65691 .73371 L .64432 .7198 L p .707 .577 .707 r
F P
0 g
s
.63808 .57986 m .64152 .63694 L .6445 .64099 L p .707 .577 .707 r
F P
0 g
s
.63679 .65978 m .63888 .69778 L .65148 .70135 L p .707 .577 .707 r
F P
0 g
s
.64432 .7198 m .64278 .73699 L .65536 .7509 L p .707 .577 .707 r
F P
0 g
s
.84166 .56954 m .8451 .62662 L .84212 .62257 L p .707 .577 .707 r
F P
0 g
s
.84212 .62257 m .83868 .56549 L .84166 .56954 L p .707 .577 .707 r
F P
0 g
s
.83043 .65118 m .83252 .68919 L .83957 .6843 L p .707 .577 .707 r
F P
0 g
s
.83957 .6843 m .83748 .64629 L .83043 .65118 L p .707 .577 .707 r
F P
0 g
s
.83763 .73937 m .83609 .75656 L .84311 .74327 L p .707 .577 .707 r
F P
0 g
s
.84311 .74327 m .84466 .72608 L .83763 .73937 L p .707 .577 .707 r
F P
0 g
s
.64278 .73699 m .64432 .7198 L .6414 .7055 L p .707 .577 .707 r
F P
0 g
s
.64152 .63694 m .63808 .57986 L .64507 .5753 L p .707 .577 .707 r
F P
0 g
s
.63888 .69778 m .63679 .65978 L .63387 .65533 L p .707 .577 .707 r
F P
0 g
s
.63387 .65533 m .63596 .69334 L .63888 .69778 L p .707 .577 .707 r
F P
0 g
s
.6414 .7055 m .63986 .72269 L .64278 .73699 L p .707 .577 .707 r
F P
0 g
s
.64507 .5753 m .64851 .63239 L .64152 .63694 L p .707 .577 .707 r
F P
0 g
s
.83748 .64629 m .83957 .6843 L .83665 .67986 L p .707 .577 .707 r
F P
0 g
s
.83665 .67986 m .83456 .64185 L .83748 .64629 L p .707 .577 .707 r
F P
0 g
s
.83868 .56549 m .84212 .62257 L .82946 .61942 L p .707 .577 .707 r
F P
0 g
s
.82946 .61942 m .82603 .56233 L .83868 .56549 L p .707 .577 .707 r
F P
0 g
s
.84466 .72608 m .84311 .74327 L .84019 .72897 L p .707 .577 .707 r
F P
0 g
s
.84019 .72897 m .84173 .71178 L .84466 .72608 L p .707 .577 .707 r
F P
0 g
s
.63986 .72269 m .6414 .7055 L .64843 .6922 L p .707 .577 .707 r
F P
0 g
s
.3978 .62615 m .38983 .57211 L .35896 .57388 L p .707 .577 .707 r
F P
0 g
s
.38983 .57211 m .3978 .62615 L .42933 .62105 L p .707 .577 .707 r
F P
0 g
s
.42933 .62105 m .42136 .56701 L .38983 .57211 L p .707 .577 .707 r
F P
0 g
s
.42136 .56701 m .42933 .62105 L .45844 .61312 L p .707 .577 .707 r
F P
0 g
s
.45844 .61312 m .45046 .55908 L .42136 .56701 L p .707 .577 .707 r
F P
0 g
s
.64851 .63239 m .64507 .5753 L .66133 .57068 L p .707 .577 .707 r
F P
0 g
s
.63596 .69334 m .63387 .65533 L .64092 .65045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64843 .6922 m .64688 .70939 L .63986 .72269 L p .707 .577 .707 r
F P
0 g
s
.36693 .62792 m .35896 .57388 L .33177 .57214 L p .707 .577 .707 r
F P
0 g
s
.35896 .57388 m .36693 .62792 L .3978 .62615 L p .707 .577 .707 r
F P
0 g
s
.64092 .65045 m .64301 .68845 L .63596 .69334 L p .707 .577 .707 r
F P
0 g
s
.66133 .57068 m .66477 .62777 L .64851 .63239 L p .707 .577 .707 r
F P
0 g
s
.45046 .55908 m .45844 .61312 L .48227 .60313 L p .707 .577 .707 r
F P
0 g
s
.48227 .60313 m .47429 .54909 L .45046 .55908 L p .707 .577 .707 r
F P
0 g
s
.38472 .68757 m .37986 .65142 L .34895 .65286 L p .707 .577 .707 r
F P
0 g
s
.37986 .65142 m .38472 .68757 L .41631 .68285 L p .707 .577 .707 r
F P
0 g
s
.41631 .68285 m .41145 .6467 L .37986 .65142 L p .707 .577 .707 r
F P
0 g
s
.82603 .56233 m .82946 .61942 L .80838 .61748 L p .707 .577 .707 r
F P
0 g
s
.80838 .61748 m .80494 .56039 L .82603 .56233 L p .707 .577 .707 r
F P
0 g
s
.41145 .6467 m .41631 .68285 L .44548 .67532 L p .707 .577 .707 r
F P
0 g
s
.44548 .67532 m .44062 .63917 L .41145 .6467 L p .707 .577 .707 r
F P
0 g
s
.83456 .64185 m .83665 .67986 L .82405 .67629 L p .707 .577 .707 r
F P
0 g
s
.82405 .67629 m .82196 .63829 L .83456 .64185 L p .707 .577 .707 r
F P
0 g
s
.84173 .71178 m .84019 .72897 L .8276 .71506 L p .707 .577 .707 r
F P
0 g
s
.8276 .71506 m .82915 .69787 L .84173 .71178 L p .707 .577 .707 r
F P
0 g
s
.33974 .62618 m .33177 .57214 L .31092 .56707 L p .707 .577 .707 r
F P
0 g
s
.33177 .57214 m .33974 .62618 L .36693 .62792 L p .707 .577 .707 r
F P
0 g
s
.35381 .68901 m .34895 .65286 L .32174 .65089 L p .707 .577 .707 r
F P
0 g
s
.34895 .65286 m .35381 .68901 L .38472 .68757 L p .707 .577 .707 r
F P
0 g
s
.64688 .70939 m .64843 .6922 L .66471 .68122 L p .707 .577 .707 r
F P
0 g
s
.44062 .63917 m .44548 .67532 L .46937 .66571 L p .707 .577 .707 r
F P
0 g
s
.46937 .66571 m .46452 .62956 L .44062 .63917 L p .707 .577 .707 r
F P
0 g
s
.66477 .62777 m .66133 .57068 L .68528 .56646 L p .707 .577 .707 r
F P
0 g
s
.47429 .54909 m .48227 .60313 L .49849 .59207 L p .707 .577 .707 r
F P
0 g
s
.49849 .59207 m .49051 .53803 L .47429 .54909 L p .707 .577 .707 r
F P
0 g
s
.64301 .68845 m .64092 .65045 L .65724 .6456 L p .707 .577 .707 r
F P
0 g
s
.66471 .68122 m .66317 .69841 L .64688 .70939 L p .707 .577 .707 r
F P
0 g
s
.68528 .56646 m .68872 .62355 L .66477 .62777 L p .707 .577 .707 r
F P
0 g
s
.39321 .71304 m .39678 .69449 L .36618 .68743 L p .707 .577 .707 r
F P
0 g
s
.39678 .69449 m .39321 .71304 L .4245 .71832 L p .707 .577 .707 r
F P
0 g
s
.4245 .71832 m .42807 .69977 L .39678 .69449 L p .707 .577 .707 r
F P
0 g
s
.32174 .65089 m .3266 .68704 L .35381 .68901 L p .707 .577 .707 r
F P
0 g
s
.65724 .6456 m .65933 .6836 L .64301 .68845 L p .707 .577 .707 r
F P
0 g
s
.36618 .68743 m .36261 .70599 L .39321 .71304 L p .707 .577 .707 r
F P
0 g
s
.42807 .69977 m .4245 .71832 L .45343 .72131 L p .707 .577 .707 r
F P
0 g
s
.45343 .72131 m .457 .70276 L .42807 .69977 L p .707 .577 .707 r
F P
0 g
s
.80494 .56039 m .80838 .61748 L .78092 .61694 L p .707 .577 .707 r
F P
0 g
s
.78092 .61694 m .77749 .55985 L .80494 .56039 L p .707 .577 .707 r
F P
0 g
s
.3266 .68704 m .32174 .65089 L .3009 .64569 L p .707 .577 .707 r
F P
0 g
s
.31092 .56707 m .3189 .62111 L .33974 .62618 L p .707 .577 .707 r
F P
0 g
s
.36261 .70599 m .36618 .68743 L .33928 .6793 L p .707 .577 .707 r
F P
0 g
s
.33928 .6793 m .3357 .69785 L .36261 .70599 L p .707 .577 .707 r
F P
0 g
s
.82915 .69787 m .8276 .71506 L .80659 .7029 L p .707 .577 .707 r
F P
0 g
s
.80659 .7029 m .80813 .68571 L .82915 .69787 L p .707 .577 .707 r
F P
0 g
s
.3189 .62111 m .31092 .56707 L .29846 .55916 L p .707 .577 .707 r
F P
0 g
s
.46452 .62956 m .46937 .66571 L .48566 .65496 L p .707 .577 .707 r
F P
0 g
s
.48566 .65496 m .4808 .61881 L .46452 .62956 L p .707 .577 .707 r
F P
0 g
s
.82196 .63829 m .82405 .67629 L .80301 .67395 L p .707 .577 .707 r
F P
0 g
s
.80301 .67395 m .80092 .63595 L .82196 .63829 L p .707 .577 .707 r
F P
0 g
s
.68872 .62355 m .68528 .56646 L .71458 .56304 L p .707 .577 .707 r
F P
0 g
s
.66317 .69841 m .66471 .68122 L .68866 .67362 L p .707 .577 .707 r
F P
0 g
s
.3009 .64569 m .30576 .68184 L .3266 .68704 L p .707 .577 .707 r
F P
0 g
s
.457 .70276 m .45343 .72131 L .47716 .72172 L p .707 .577 .707 r
F P
0 g
s
.47716 .72172 m .48073 .70317 L .457 .70276 L p .707 .577 .707 r
F P
0 g
s
.49051 .53803 m .49849 .59207 L .50551 .581 L p .707 .577 .707 r
F P
0 g
s
.50551 .581 m .49754 .52696 L .49051 .53803 L p .707 .577 .707 r
F P
0 g
s
.71458 .56304 m .71802 .62013 L .68872 .62355 L p .707 .577 .707 r
F P
0 g
s
.77749 .55985 m .78092 .61694 L .74979 .61785 L p .707 .577 .707 r
F P
0 g
s
.74979 .61785 m .74635 .56077 L .77749 .55985 L p .707 .577 .707 r
F P
0 g
s
.3357 .69785 m .33928 .6793 L .3187 .67087 L p .707 .577 .707 r
F P
0 g
s
.68866 .67362 m .68712 .69081 L .66317 .69841 L p .707 .577 .707 r
F P
0 g
s
.65933 .6836 m .65724 .6456 L .68124 .64126 L p .707 .577 .707 r
F P
0 g
s
.3187 .67087 m .31512 .68942 L .3357 .69785 L p .707 .577 .707 r
F P
0 g
s
.71802 .62013 m .71458 .56304 L .74635 .56077 L p .707 .577 .707 r
F P
0 g
s
.74635 .56077 m .74979 .61785 L .71802 .62013 L p .707 .577 .707 r
F P
0 g
s
.30576 .68184 m .3009 .64569 L .28846 .63778 L p .707 .577 .707 r
F P
0 g
s
.68124 .64126 m .68333 .67927 L .65933 .6836 L p .707 .577 .707 r
F P
0 g
s
.29846 .55916 m .30644 .6132 L .3189 .62111 L p .707 .577 .707 r
F P
0 g
s
.80813 .68571 m .80659 .7029 L .7792 .69369 L p .707 .577 .707 r
F P
0 g
s
.7792 .69369 m .78074 .6765 L .80813 .68571 L p .707 .577 .707 r
F P
0 g
s
.68712 .69081 m .68866 .67362 L .71794 .67014 L p .707 .577 .707 r
F P
0 g
s
.80092 .63595 m .80301 .67395 L .77558 .67307 L p .707 .577 .707 r
F P
0 g
s
.77558 .67307 m .77349 .63506 L .80092 .63595 L p .707 .577 .707 r
F P
0 g
s
.4808 .61881 m .48566 .65496 L .49274 .64413 L p .707 .577 .707 r
F P
0 g
s
.49274 .64413 m .48788 .60798 L .4808 .61881 L p .707 .577 .707 r
F P
0 g
s
.48073 .70317 m .47716 .72172 L .49337 .7195 L p .707 .577 .707 r
F P
0 g
s
.49337 .7195 m .49694 .70095 L .48073 .70317 L p .707 .577 .707 r
F P
0 g
s
.30644 .6132 m .29846 .55916 L .2956 .54919 L p .707 .577 .707 r
F P
0 g
s
.28846 .63778 m .29332 .67393 L .30576 .68184 L p .707 .577 .707 r
F P
0 g
s
.71794 .67014 m .71639 .68733 L .68712 .69081 L p .707 .577 .707 r
F P
0 g
s
.31512 .68942 m .3187 .67087 L .30646 .66299 L p .707 .577 .707 r
F P
0 g
s
.68333 .67927 m .68124 .64126 L .71057 .63786 L p .707 .577 .707 r
F P
0 g
s
.78074 .6765 m .7792 .69369 L .74812 .68833 L p .707 .577 .707 r
F P
0 g
s
.74812 .68833 m .74966 .67114 L .78074 .6765 L p .707 .577 .707 r
F P
0 g
s
.71639 .68733 m .71794 .67014 L .74966 .67114 L p .707 .577 .707 r
F P
0 g
s
.49754 .52696 m .50551 .581 L .50266 .57103 L p .707 .577 .707 r
F P
0 g
s
.50266 .57103 m .49468 .51699 L .49754 .52696 L p .707 .577 .707 r
F P
0 g
s
.30646 .66299 m .30288 .68154 L .31512 .68942 L p .707 .577 .707 r
F P
0 g
s
.71057 .63786 m .71266 .67586 L .68333 .67927 L p .707 .577 .707 r
F P
0 g
s
.74966 .67114 m .74812 .68833 L .71639 .68733 L p .707 .577 .707 r
F P
0 g
s
.77349 .63506 m .77558 .67307 L .74444 .67373 L p .707 .577 .707 r
F P
0 g
s
.74444 .67373 m .74235 .63572 L .77349 .63506 L p .707 .577 .707 r
F P
0 g
s
.71266 .67586 m .71057 .63786 L .74235 .63572 L p .707 .577 .707 r
F P
0 g
s
.29332 .67393 m .28846 .63778 L .28564 .62793 L p .707 .577 .707 r
F P
0 g
s
.2956 .54919 m .30358 .60323 L .30644 .6132 L p .707 .577 .707 r
F P
0 g
s
.74235 .63572 m .74444 .67373 L .71266 .67586 L p .707 .577 .707 r
F P
0 g
s
.48788 .60798 m .49274 .64413 L .48993 .63428 L p .707 .577 .707 r
F P
0 g
s
.48993 .63428 m .48507 .59813 L .48788 .60798 L p .707 .577 .707 r
F P
0 g
s
.49694 .70095 m .49337 .7195 L .50047 .71488 L p .707 .577 .707 r
F P
0 g
s
.50047 .71488 m .50404 .69633 L .49694 .70095 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28564 .62793 m .2905 .66408 L .29332 .67393 L p .707 .577 .707 r
F P
0 g
s
.30358 .60323 m .2956 .54919 L .30263 .53813 L p .707 .577 .707 r
F P
0 g
s
.30288 .68154 m .30646 .66299 L .30375 .65641 L p .707 .577 .707 r
F P
0 g
s
.30375 .65641 m .30018 .67496 L .30288 .68154 L p .707 .577 .707 r
F P
0 g
s
.49468 .51699 m .50266 .57103 L .4902 .56312 L p .707 .577 .707 r
F P
0 g
s
.4902 .56312 m .48222 .50908 L .49468 .51699 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2905 .66408 m .28564 .62793 L .29273 .6171 L p .707 .577 .707 r
F P
0 g
s
.30263 .53813 m .3106 .59217 L .30358 .60323 L p .707 .577 .707 r
F P
0 g
s
.48507 .59813 m .48993 .63428 L .47749 .62637 L p .707 .577 .707 r
F P
0 g
s
.47749 .62637 m .47263 .59022 L .48507 .59813 L p .707 .577 .707 r
F P
0 g
s
.50404 .69633 m .50047 .71488 L .49777 .7083 L p .707 .577 .707 r
F P
0 g
s
.49777 .7083 m .50134 .68975 L .50404 .69633 L p .707 .577 .707 r
F P
0 g
s
.3106 .59217 m .30263 .53813 L .31885 .52706 L p .707 .577 .707 r
F P
0 g
s
.29273 .6171 m .29758 .65325 L .2905 .66408 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30018 .67496 m .30375 .65641 L .31085 .65179 L p .707 .577 .707 r
F P
0 g
s
.48222 .50908 m .4902 .56312 L .46935 .55805 L p .707 .577 .707 r
F P
0 g
s
.46935 .55805 m .46137 .50401 L .48222 .50908 L p .707 .577 .707 r
F P
0 g
s
.31085 .65179 m .30728 .67034 L .30018 .67496 L p .707 .577 .707 r
F P
0 g
s
.29758 .65325 m .29273 .6171 L .30901 .60635 L p .707 .577 .707 r
F P
0 g
s
.31885 .52706 m .32683 .5811 L .3106 .59217 L p .707 .577 .707 r
F P
0 g
s
.32683 .5811 m .31885 .52706 L .34268 .51707 L p .707 .577 .707 r
F P
0 g
s
.47263 .59022 m .47749 .62637 L .45664 .62117 L p .707 .577 .707 r
F P
0 g
s
.45664 .62117 m .45178 .58502 L .47263 .59022 L p .707 .577 .707 r
F P
0 g
s
.50134 .68975 m .49777 .7083 L .48553 .70041 L p .707 .577 .707 r
F P
0 g
s
.48553 .70041 m .4891 .68186 L .50134 .68975 L p .707 .577 .707 r
F P
0 g
s
.30901 .60635 m .31387 .6425 L .29758 .65325 L p .707 .577 .707 r
F P
0 g
s
.46137 .50401 m .46935 .55805 L .44216 .55631 L p .707 .577 .707 r
F P
0 g
s
.44216 .55631 m .43419 .50227 L .46137 .50401 L p .707 .577 .707 r
F P
0 g
s
.30728 .67034 m .31085 .65179 L .32706 .64957 L p .707 .577 .707 r
F P
0 g
s
.32706 .64957 m .32349 .66812 L .30728 .67034 L p .707 .577 .707 r
F P
0 g
s
.31387 .6425 m .30901 .60635 L .33291 .59674 L p .707 .577 .707 r
F P
0 g
s
.34268 .51707 m .35065 .57111 L .32683 .5811 L p .707 .577 .707 r
F P
0 g
s
.35065 .57111 m .34268 .51707 L .37178 .50914 L p .707 .577 .707 r
F P
0 g
s
.43419 .50227 m .44216 .55631 L .41129 .55808 L p .707 .577 .707 r
F P
0 g
s
.41129 .55808 m .40332 .50404 L .43419 .50227 L p .707 .577 .707 r
F P
0 g
s
.45178 .58502 m .45664 .62117 L .42943 .6192 L p .707 .577 .707 r
F P
0 g
s
.42943 .6192 m .42458 .58305 L .45178 .58502 L p .707 .577 .707 r
F P
0 g
s
.37976 .56318 m .37178 .50914 L .40332 .50404 L p .707 .577 .707 r
F P
0 g
s
.37178 .50914 m .37976 .56318 L .35065 .57111 L p .707 .577 .707 r
F P
0 g
s
.33291 .59674 m .33777 .63289 L .31387 .6425 L p .707 .577 .707 r
F P
0 g
s
.40332 .50404 m .41129 .55808 L .37976 .56318 L p .707 .577 .707 r
F P
0 g
s
.4891 .68186 m .48553 .70041 L .46495 .69199 L p .707 .577 .707 r
F P
0 g
s
.46495 .69199 m .46852 .67344 L .4891 .68186 L p .707 .577 .707 r
F P
0 g
s
.33777 .63289 m .33291 .59674 L .36208 .58921 L p .707 .577 .707 r
F P
0 g
s
.32349 .66812 m .32706 .64957 L .35079 .64998 L p .707 .577 .707 r
F P
0 g
s
.42458 .58305 m .42943 .6192 L .39852 .62064 L p .707 .577 .707 r
F P
0 g
s
.39852 .62064 m .39367 .58449 L .42458 .58305 L p .707 .577 .707 r
F P
0 g
s
.35079 .64998 m .34722 .66853 L .32349 .66812 L p .707 .577 .707 r
F P
0 g
s
.36694 .62536 m .36208 .58921 L .39367 .58449 L p .707 .577 .707 r
F P
0 g
s
.36208 .58921 m .36694 .62536 L .33777 .63289 L p .707 .577 .707 r
F P
0 g
s
.39367 .58449 m .39852 .62064 L .36694 .62536 L p .707 .577 .707 r
F P
0 g
s
.46852 .67344 m .46495 .69199 L .43804 .68385 L p .707 .577 .707 r
F P
0 g
s
.43804 .68385 m .44161 .6653 L .46852 .67344 L p .707 .577 .707 r
F P
0 g
s
.34722 .66853 m .35079 .64998 L .37972 .65297 L p .707 .577 .707 r
F P
0 g
s
.37972 .65297 m .37615 .67152 L .34722 .66853 L p .707 .577 .707 r
F P
0 g
s
.44161 .6653 m .43804 .68385 L .40744 .6768 L p .707 .577 .707 r
F P
0 g
s
.40744 .6768 m .41102 .65825 L .44161 .6653 L p .707 .577 .707 r
F P
0 g
s
.37615 .67152 m .37972 .65297 L .41102 .65825 L p .707 .577 .707 r
F P
0 g
s
.41102 .65825 m .40744 .6768 L .37615 .67152 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEPT000AJEP04001JEUYFFUH7000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000H000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo0`0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001SOol30003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0061oo`<000IJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005ao
o`@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Yoo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00F7oo00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo00@005YFFUH000MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Ioo`05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YF000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUHE
0004FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00E7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00@000EJEP03001JEUYF00AJEP@000EJEP<00007FUH005YFFUH005YF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000067oo7000<Goo001DOol200000eYF001JEP02
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH90004FUH00`00FUIJEP040002FUH00`00FUIJEP04FUH0
0`00FUIJEP020002FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000?Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH00002000^Ool005Aoo`800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00@000AJEP`0
00IJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000Moo`P000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP03
001JEUYF00=JEP@00003FUH005YF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP00008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP00009oo`D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEP0000AJEP04001JEUYFFUH;
0003FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH00002000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001EOol00`00FUH00004FUH01000FUH000001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP8000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005Eoo`04001JEUYF0003FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80005
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EGoo
00@005YFFUH0009JEP04001JEUYF0007FUH00`00FUIJEP02FUH90004FUH01000FUIJEUYF1`001EYF
00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00?goo3`001goo00<005YF
FUH00`0015YF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
100000=JEP00FUH00eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<0
05YFFUH01UYF00<005YFFUH0100017oo0UYF0P001EYF00<005YF00000`0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00@005YFFUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUH000=JEP@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEP000002FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<goo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUH005YF001JEP0200000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJ
EP030004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000bOol20006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH20003FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000/Ool002moo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH000001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000/Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;7oo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF0004FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH2
000/Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP8000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000AJEP03001JEUYF00@000]J
EP<00004FUH005YFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH01000FUIJEUYF2@0025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP@002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH04@000eYF00<005YFFUH02EYF00<005YF00000P000eYF00<005YFFUH00UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0002aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF10000UYF00<005YF00001UYF
1@0015YF00<005YFFUH02EYF0P000eYF0P0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002eoo`00
;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00001EYF00@005YFFUIJEP8000=JEP06001JEUYF001JEP001UYF1@0015YF00<005YF
FUH01EYF100000=JEP00FUH00eYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF5`00
0UYF1000<Goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEP0015YF00@005YF000000EJEP06001JEUYF001JEP001UYF1@0015YF00@0
05YFFUIJEP@000EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000bOol002eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF009JEPl000AJEP04001JEUYF0004FUH30005FUH01`00FUIJEUYF001JEP0000IJ
EP@000EJEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEPP000=J
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080
02moo`00;Goo0P000eYF00<005YFFUH00eYF1P003goo1@000UYF00<005YFFUH00P000UYF00<005YF
FUH00eYF00L005YFFUIJEP00FUH00006FUH01000FUIJEUYF1@001UYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP04001JEP00Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00
FUH00003000IOol200000eYF0000000400000eYF0000000;0006FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH0
0003FUH2000DOol30007Ool01000FUH000000UYF0`0000=JEP00FUH01EYF00@005YFFUIJEPL000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000^Ool002aoo`03001JEP00009JEP03001JEUYF0080015oo`D000Ioo`800003FUH00000008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00;7oo00<0
05YF00000`0015YF0`003Woo1@001Woo0P0000EJEP00001JEP00009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00AJEPD000MJEP03001JEUYF00AJEP03001JEUYF008000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Woo000/Ool00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00003000:Ool5
0006Ool2000015YF000000000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH010000eYF00<005YFFUH015YF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000Aoo`<000Moo`800004FUH005YF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH2000:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH00UYF400000=JEP00FUH05P001UYF00<005YFFUH01eYF00<005YF0000100035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool002aoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEQ<00003
FUH005YF008000=JEP<000MJEP03001JEUYF00EJEPD0009JEP03001JEUYF00MJEP03001JEUYF00=J
EP@000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF60000eYF00<005YFFUH00P00;Woo
000/Ool01@00FUIJEUYF00001UYF00<005YFFUH01P0015YF00<005YFFUH01UYF00@005YFFUIJEPH0
00=JEP03001JEUYF008000EJEP03001JEUYF00EJEP03001JEUYF009JEPD000IJEP03001JEUYF00IJ
EP03001JEP00008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF20001UYF00<005YFFUH00eYF100000=J
EP00FUH01EYF1@0000=JEP000000;Woo000/Ool01@00FUIJEUYF00001EYF100000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF
00<005YF00000P0015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF2000
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH00UYF0`00;Woo
000/Ool01@00FUIJEUYF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YF001JEP0000IJEP03001JEP0000<000MJEP`00003FUH00000008000IJEP03001JEUYF
00AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000UYF1P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`0000=JEP00FUH00eYF00<005YF0000;Woo000/Ool01P00FUIJEUYF001JEP<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000IJEP03001JEUYF00=JEPd000AJ
EP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEP00009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF1@0000=JEP00FUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH01EYF0`000eYF0`00;goo000]Ool00`00FUIJEP020002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YF
FUH01UYF00<005YF0000200015YF00<005YFFUH025YF0`001EYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00D005YFFUIJEP0000EJEPH000MJ
EP03001JEUYF00EJEP@0009JEP03001JEUYF00EJEP03001JEUYF00<0039oo`00;Woo0`000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01eYF00<005YFFUH00eYF1`000UYF00<005YFFUH02EYF00@005YF000000=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH00000
00=JEP03001JEP0000<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP04
001JEUYFFUH2000bOol002moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00IJEP03001JEUYF009JEPP000IJ
EP04001JEUYFFUH200000eYF001JEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH40003FUH200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH60002FUH00`00FUIJEP03FUH00`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF3P000UYF00@005YF000000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP8000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF009JEPT000Ioo`<000EJEP80031oo`00;Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00`0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF1@0000=JEP0000005`004Woo0P000eYF00<005YF0000;goo000^Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH005YF001JEP@0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00=J
EP03001JEUYF009JEP03001oogoo01moo`04001JEUYF0002FUH00`00Oomoo`0/Ool002ioo`8000AJ
EP03001JEUYF00=JEPH000MJEP03001JEUYF00IJEPL000IJEP03001JEUYF00=JEP05001JEP00FUH0
0005FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00Oomoo`0POol30003FUH00`00Oomoo`0[Ool002ioo`8000AJEP03001JEP0000D0
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP05
001JEP00FUH00006FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH00000008000AJEP04001JEUYFFUH2000:Ool3000GOol01@00FUIJEUYF0000;Goo000^Ool2
0003FUH30006Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000017oo000000001EYF00D0
05YF001JEP0000IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00AJEP03001JEUYF00@0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003
FUH300000eYF001JEP02FUH20009Ool5000GOol01000FUIJEP00;Goo000]Ool01000FUH005YF0P00
47oo4P002Goo0P000eYF00D005YF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPh000IJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP000080
00IJEP8000=JEP8000Uoo`D001Moo`05001JEP00FUH0000/Ool002eoo`03001JEP00008001Eoo`D0
01Aoo`800006FUH005YF001JEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P00
1UYF00D005YF000005YF008000Uoo`D001Qoo`800003FUH007oo02]oo`00;Goo0`000UYF00<007oo
Ool04Woo1@005Woo0P0000AJEP00FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP80
00EJEP04001JEUYFFUH2000;Ool3000JOol00`00FUH0000/Ool002eoo`8000=JEP<0019oo`D001Qo
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPH000AJEP8002Qoo`03
001JEP0002aoo`00;Goo0P000eYF00<005YFFUH00P004Goo0`005goo100000=JEP00FUH01EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000eYF0`000UYF0`0000AJEP00FUH002Qoo`8002eoo`00;Goo
0P000eYF00<005YFFUH00UYF0`009Woo0P000eYF00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000UYF00@005YFFUH0009JEP03001JEP00008002Uoo`8002eoo`00;Goo0P00
0eYF00<005YFFUH00eYF00<005YF00000`007Woo100000=JEP00FUH00UYF00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00H005YF000005YF0003FUH30004FUH2000UOol4000]Ool002ioo`05001J
EUYFFUH00005FUH00`00FUIJEP03FUH7000BOol50005FUH01`00FUIJEUYF001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000<000EJEP8000AJEP<0025oo`80009JEP03001oogoo02aoo`00;Woo00D005YF
FUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP07001JEUYF
FUH005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH0
15YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0005FUH00`00FUH00004
0002FUH2000MOol20003FUH2000^Ool002moo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0002FUH00`00FUH00006FUH00`00FUIJEP04000:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH60006FUH00`00FUIJEP02FUH01000
FUH000000UYF0P000eYF00<005YFFUH00eYF1@006Goo100000=JEP00FUH00UYF00<007ooOol0;Goo
000`Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHB0003FUH00`00FUIJEP03FUH0
0`00FUH0000200000eYF001JEP04FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUH00005FUH2
00000eYF001JEP06FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000;goo000aOol20005
FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000MJEP<000IJEP03001JEUYF00AJEQ00
00=JEP03001JEUYF00AJEP04001JEUYF000`Ool0039oo`04001JEUYFFUH80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH02000FUIJEUYF001JEP00FUH30008
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH01000FUIJEUYF0P000UYF00@005YF000000IJEP03001JEUYF008000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0035oo`00<Goo1@000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YFFUIJ
EP00FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF000000040002FUH00`00FUIJ
EP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000c
Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF001JEP02FUH00`00FUH000030004FUH00`00FUH000020006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUH00003000eOol002aoo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEQL000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003
FUH005YF009JEP03001JEUYF00=JEP<00003FUH005YF009JEPD0009JEP03001JEUYF00IJEP03001J
EUYF009JEPH003Uoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4P001eYF
00<005YFFUH015YF00<005YFFUH00UYF0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEUYF009JEP03001JEP00008000=JEP8000=ooa0003moo`00;7oo00<005YF0000
15YF00@005YFFUIJEPP000QJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00D0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP03FUH00`00FUIJ
EP02000015YF001JEP00DWoo000/Ool00`00FUH00002FUH60007FUH00`00FUIJEP06FUH40005FUH0
0`00FUIJEP05FUH01000FUIJEUYF1P000goo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH020000eYF00D005YFFUH005YF00800003FUH007oo055oo`00;7oo00<005YF00000`0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`002Woo00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00001EYF00<005YFFUH010000UYF00<0
05YFFUH00P00Dgoo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH9000AOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH0
0`00FUIJEP04FUH00`00FUIJEP04001COol002eoo`L0009JEP03001JEUYF009JEQ4001]oo`80009J
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00=JEP8000MJEP03001JEUYF00AJEPD00003FUH007oo059oo`00
=7oo1`00;Woo0`0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00@005YFFUIJEP<000QJEP03001JEUYF00AJEPH005Aoo`00Jgoo0P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF001FOol006eoo`<000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EQT0009JEP03001oogoo05Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01P004goo0P0000EJEP00FUIJEP0005Ioo`00Lgoo1`001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@000Woo1@004Goo00<005YFFUH00UYF
0P00Egoo001jOol;0006FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001goo1@003goo0`0015YF0P00
Egoo0025OolG000=Ool5000=Ool20002FUH00`00FUIJEP02FUH00`00Oomoo`1FOol008aoo`04001J
EUYFFUH2000HOol3000<Ool20004FUH01@00FUIJEUYF0000FGoo002<Ool01@00FUIJEUYF00009Woo
0P001eYF00<005YF0000FWoo002=Ool00`00FUH0000SOol400000eYF001JEP06FUH2001KOol008eo
o`<001ioo`D000EJEP03001JEUYF00AJEP8005aoo`00SGoo00<005YFFUH00`005goo10000UYF00<0
05YFFUH01UYF00@005YFFUIJEP8005ioo`00SGoo0P000UYF00<005YF00000P003Goo1`001UYF00<0
05YFFUH01UYF00@005YF0000061oo`00SWoo00@005YFFUH000AJEPd000AJEP03001JEUYF00MJEP03
001JEUYF00AJEP<0069oo`00SWoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00@006Eoo`00Sgoo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00AJEPD006Uoo`00T7oo0`001EYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01000KWoo002BOol30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH7001bOol009Eo
o`l007Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]66\[InvisibleSpace]"     "\
\[InvisibleSpace]15.278805936283119`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 66, "     ", 15.278805936283119, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59556 .70474 m .5644 .70337 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59556 .70474 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59449 .78841 m .62618 .79101 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59449 .78841 L p .59916 .75385 L .707 .577 .707 r
F P
0 g
s
.59936 .75234 m .59764 .75234 L .59916 .75385 L .707 .577 .707 r
F
.59449 .78841 m .59764 .75234 L p .56889 .75032 L F P
0 g
s
.56337 .78535 m .59449 .78841 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56337 .78535 L p .56855 .75246 L .707 .577 .707 r
F P
0 g
s
.56889 .75032 m .56645 .75015 L .56855 .75246 L .707 .577 .707 r
F
.5644 .70337 m .53693 .69845 L p .55916 .74213 L F P
0 g
s
.56298 .74963 m .56645 .75015 L .55916 .74213 L .707 .577 .707 r
F
.56645 .75015 m .5644 .70337 L p .55916 .74213 L F P
0 g
s
.58885 .74353 m .58222 .73689 L .56675 .75703 L .707 .577 .707 r
F
.56512 .71976 m .56645 .75015 L p .58222 .73689 L F P
0 g
s
.56645 .75015 m .56675 .75703 L p .58222 .73689 L .707 .577 .707 r
F P
0 g
s
.56337 .78535 m .56645 .75015 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .56337 .78535 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53586 .78212 L p .54038 .74808 L .707 .577 .707 r
F P
0 g
s
.54062 .74629 m .53901 .74605 L .54038 .74808 L .707 .577 .707 r
F
.53693 .69845 m .51584 .69048 L p .53431 .73904 L F P
0 g
s
.51584 .69048 m .5032 .68024 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.52079 .74118 m .518 .74077 L p .53901 .74605 L .707 .577 .707 r
F P
0 g
s
.518 .74077 m .51466 .77904 L .53348 .78178 L p .707 .577 .707 r
F P
0 g
s
.53348 .78178 m .53586 .78212 L p .51914 .74341 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .518 .74077 L .53348 .78178 L .707 .577 .707 r
F
.51466 .77904 m .518 .74077 L .50518 .73814 L p F P
0 g
s
.50555 .73391 m .51819 .74415 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.5032 .68024 m .50422 .70349 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.50422 .70349 m .50555 .73391 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51819 .74415 m .51803 .74044 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51803 .74044 m .51584 .69048 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .53901 .74605 L p .51817 .74081 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .51817 .74081 L .518 .74077 L .707 .577 .707 r
F
.53586 .78212 m .51817 .74081 L .51914 .74341 L F
.53674 .74544 m .53901 .74605 L .53431 .73904 L F
.53901 .74605 m .53693 .69845 L p .53431 .73904 L F P
0 g
s
.53693 .69845 m .53901 .74605 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.51584 .69048 m .51819 .74415 L .53928 .75212 L p .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53921 .74385 L .52079 .74118 L p .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .53901 .74605 L p .53674 .74544 L .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .56675 .75703 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53928 .75212 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53921 .74385 m .53901 .74605 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .53921 .74385 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56672 .74708 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .56645 .75015 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .56645 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .59791 .75841 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59406 .75209 m .58885 .74353 L .57683 .75088 L .707 .577 .707 r
F
.59406 .75209 m .57683 .75088 L .56675 .75703 L F
.5644 .70337 m .56512 .71976 L p .58885 .74353 L F P
0 g
s
.59556 .70474 m .59764 .75234 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62952 .75274 L .62535 .7524 L p .707 .577 .707 r
F P
0 g
s
.62535 .7524 m .59784 .75015 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62535 .7524 L .59936 .75234 L .707 .577 .707 r
F
.62736 .70245 m .59556 .70474 L p .62724 .7524 L F P
0 g
s
.62952 .75274 m .62618 .79101 L .65533 .79288 L p .707 .577 .707 r
F P
0 g
s
.65533 .79288 m .65867 .75461 L .62952 .75274 L p .707 .577 .707 r
F P
0 g
s
.62971 .75612 m .62955 .75241 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62955 .75241 m .62736 .70245 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .62971 .75612 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59791 .75841 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .59764 .75234 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .56672 .74708 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59784 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .59764 .75234 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.62736 .70245 m .62971 .75612 L .65905 .75039 L p .707 .577 .707 r
F P
0 g
s
.65905 .75039 m .65669 .69672 L .62736 .70245 L p .707 .577 .707 r
F P
0 g
s
.65669 .69672 m .65905 .75039 L .68303 .74176 L p .707 .577 .707 r
F P
0 g
s
.68303 .74176 m .68068 .6881 L .65669 .69672 L p .707 .577 .707 r
F P
0 g
s
.68068 .6881 m .68303 .74176 L .69933 .7311 L p .707 .577 .707 r
F P
0 g
s
.69933 .7311 m .69698 .67744 L .68068 .6881 L p .707 .577 .707 r
F P
0 g
s
.65867 .75461 m .65533 .79288 L .67909 .79385 L p .707 .577 .707 r
F P
0 g
s
.67909 .79385 m .68243 .75558 L .65867 .75461 L p .707 .577 .707 r
F P
0 g
s
.5988 .86257 m .59786 .84483 L .5667 .84355 L p .707 .577 .707 r
F P
0 g
s
.59786 .84483 m .5988 .86257 L .63059 .85999 L p .707 .577 .707 r
F P
0 g
s
.63059 .85999 m .62965 .84225 L .59786 .84483 L p .707 .577 .707 r
F P
0 g
s
.62965 .84225 m .63059 .85999 L .6599 .8538 L p .707 .577 .707 r
F P
0 g
s
.6599 .8538 m .65896 .83606 L .62965 .84225 L p .707 .577 .707 r
F P
0 g
s
.56764 .86129 m .5667 .84355 L .53923 .83854 L p .707 .577 .707 r
F P
0 g
s
.5667 .84355 m .56764 .86129 L .5988 .86257 L p .707 .577 .707 r
F P
0 g
s
.68243 .75558 m .67909 .79385 L .69513 .79382 L p .707 .577 .707 r
F P
0 g
s
.69513 .79382 m .69847 .75555 L .68243 .75558 L p .707 .577 .707 r
F P
0 g
s
.69698 .67744 m .69933 .7311 L .70634 .71945 L p .707 .577 .707 r
F P
0 g
s
.70634 .71945 m .70399 .66578 L .69698 .67744 L p .707 .577 .707 r
F P
0 g
s
.65896 .83606 m .6599 .8538 L .68386 .84461 L p .707 .577 .707 r
F P
0 g
s
.68386 .84461 m .68292 .82687 L .65896 .83606 L p .707 .577 .707 r
F P
0 g
s
.53923 .83854 m .54017 .85627 L .56764 .86129 L p .707 .577 .707 r
F P
0 g
s
.50518 .73814 m .50183 .77641 L .51466 .77904 L p .707 .577 .707 r
F P
0 g
s
.54017 .85627 m .53923 .83854 L .51813 .83028 L p .707 .577 .707 r
F P
0 g
s
.50555 .73391 m .5032 .68024 L .50024 .66873 L p .707 .577 .707 r
F P
0 g
s
.51813 .83028 m .51906 .84802 L .54017 .85627 L p .707 .577 .707 r
F P
0 g
s
.68292 .82687 m .68386 .84461 L .70012 .83331 L p .707 .577 .707 r
F P
0 g
s
.70012 .83331 m .69919 .81558 L .68292 .82687 L p .707 .577 .707 r
F P
0 g
s
.69847 .75555 m .69513 .79382 L .70189 .79279 L p .707 .577 .707 r
F P
0 g
s
.70189 .79279 m .70523 .75452 L .69847 .75555 L p .707 .577 .707 r
F P
0 g
s
.70399 .66578 m .70634 .71945 L .70338 .70793 L p .707 .577 .707 r
F P
0 g
s
.70338 .70793 m .70103 .65427 L .70399 .66578 L p .707 .577 .707 r
F P
0 g
s
.51906 .84802 m .51813 .83028 L .50546 .81958 L p .707 .577 .707 r
F P
0 g
s
.50024 .66873 m .50259 .7224 L .50555 .73391 L p .707 .577 .707 r
F P
0 g
s
.50183 .77641 m .50518 .73814 L .50199 .73622 L p .707 .577 .707 r
F P
0 g
s
.50199 .73622 m .49864 .77448 L .50183 .77641 L p .707 .577 .707 r
F P
0 g
s
.50546 .81958 m .5064 .83732 L .51906 .84802 L p .707 .577 .707 r
F P
0 g
s
.48829 .82105 m .49149 .31708 L .44749 .31429 L p .707 .577 .707 r
F P
0 g
s
.50259 .7224 m .50024 .66873 L .50725 .65707 L p .707 .577 .707 r
F P
0 g
s
.5064 .83732 m .50546 .81958 L .50247 .8075 L p .707 .577 .707 r
F P
0 g
s
.50725 .65707 m .5096 .71074 L .50259 .7224 L p .707 .577 .707 r
F P
0 g
s
.50247 .8075 m .50341 .82524 L .5064 .83732 L p .707 .577 .707 r
F P
0 g
s
.49864 .77448 m .50199 .73622 L .50874 .73519 L p .707 .577 .707 r
F P
0 g
s
.50874 .73519 m .5054 .77346 L .49864 .77448 L p .707 .577 .707 r
F P
0 g
s
.5096 .71074 m .50725 .65707 L .52355 .64641 L p .707 .577 .707 r
F P
0 g
s
.50341 .82524 m .50247 .8075 L .50946 .79521 L p .707 .577 .707 r
F P
0 g
s
.52355 .64641 m .5259 .70008 L .5096 .71074 L p .707 .577 .707 r
F P
0 g
s
.50946 .79521 m .51039 .81295 L .50341 .82524 L p .707 .577 .707 r
F P
0 g
s
.5054 .77346 m .50874 .73519 L .52479 .73516 L p .707 .577 .707 r
F P
0 g
s
.52479 .73516 m .52144 .77342 L .5054 .77346 L p .707 .577 .707 r
F P
0 g
s
.51039 .81295 m .50946 .79521 L .52572 .78392 L p .707 .577 .707 r
F P
0 g
s
.52572 .78392 m .52666 .80166 L .51039 .81295 L p .707 .577 .707 r
F P
0 g
s
.52144 .77342 m .52479 .73516 L .54855 .73612 L p .707 .577 .707 r
F P
0 g
s
.54855 .73612 m .5452 .77439 L .52144 .77342 L p .707 .577 .707 r
F P
0 g
s
.52666 .80166 m .52572 .78392 L .54968 .77473 L p .707 .577 .707 r
F P
0 g
s
.54968 .77473 m .55062 .79247 L .52666 .80166 L p .707 .577 .707 r
F P
0 g
s
.49149 .31708 m .48829 .82105 L .53323 .82028 L p .707 .577 .707 r
F P
0 g
s
.5259 .70008 m .52355 .64641 L .54753 .63779 L p .707 .577 .707 r
F P
0 g
s
.54753 .63779 m .54989 .69146 L .5259 .70008 L p .707 .577 .707 r
F P
0 g
s
.53323 .82028 m .53644 .31631 L .49149 .31708 L p .707 .577 .707 r
F P
0 g
s
.69919 .81558 m .70012 .83331 L .70711 .82102 L p .707 .577 .707 r
F P
0 g
s
.70711 .82102 m .70617 .80329 L .69919 .81558 L p .707 .577 .707 r
F P
0 g
s
.54989 .69146 m .54753 .63779 L .57687 .63206 L p .707 .577 .707 r
F P
0 g
s
.57687 .63206 m .57922 .68572 L .54989 .69146 L p .707 .577 .707 r
F P
0 g
s
.5452 .77439 m .54855 .73612 L .57769 .738 L p .707 .577 .707 r
F P
0 g
s
.57769 .738 m .57435 .77627 L .5452 .77439 L p .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .57769 .738 L .58259 .7384 L p .707 .577 .707 r
F P
0 g
s
.58259 .7384 m .60938 .74059 L p .57818 .77236 L .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .58259 .7384 L .57818 .77236 L .707 .577 .707 r
F
.63983 .63114 m .64218 .68481 L .61102 .68343 L p F P
0 g
s
.61102 .68343 m .60867 .62977 L .63983 .63114 L p .707 .577 .707 r
F P
0 g
s
.6405 .74365 m .63716 .78192 L .61154 .7794 L p .707 .577 .707 r
F P
0 g
s
.61154 .7794 m .60604 .77886 L p .61189 .77288 L .707 .577 .707 r
F P
0 g
s
.61189 .77288 m .6405 .74365 L .61154 .7794 L .707 .577 .707 r
F
.66801 .74689 m .66467 .78515 L .63716 .78192 L p F P
0 g
s
.63716 .78192 m .6405 .74365 L .66801 .74689 L p .707 .577 .707 r
F P
0 g
s
.60604 .77886 m .60938 .74059 L .6405 .74365 L p .707 .577 .707 r
F P
0 g
s
.64194 .76724 m .64288 .78497 L .61172 .7837 L p .707 .577 .707 r
F P
0 g
s
.61172 .7837 m .61078 .76596 L .64194 .76724 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .64177 .78791 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63498 .29503 m .63463 .35034 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63463 .35034 m .63177 .799 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.60938 .74059 m .60604 .77886 L .57435 .77627 L p .707 .577 .707 r
F P
0 g
s
.57993 .78628 m .57899 .76854 L .61078 .76596 L p .707 .577 .707 r
F P
0 g
s
.61078 .76596 m .61172 .7837 L .57993 .78628 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .63177 .799 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.61187 .30472 m .61048 .52333 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.60867 .62977 m .61102 .68343 L .57922 .68572 L p .707 .577 .707 r
F P
0 g
s
.61048 .52333 m .60867 .80869 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.55062 .79247 m .54968 .77473 L .57899 .76854 L p .707 .577 .707 r
F P
0 g
s
.57899 .76854 m .57993 .78628 L .55062 .79247 L p .707 .577 .707 r
F P
0 g
s
.53644 .31631 m .53323 .82028 L .57471 .81602 L p .707 .577 .707 r
F P
0 g
s
.57471 .81602 m .57792 .31205 L .53644 .31631 L p .707 .577 .707 r
F P
0 g
s
.44428 .81826 m .44749 .31429 L .40872 .3082 L p .707 .577 .707 r
F P
0 g
s
.44749 .31429 m .44428 .81826 L .48829 .82105 L p .707 .577 .707 r
F P
0 g
s
.70523 .75452 m .70189 .79279 L .6987 .79087 L p .707 .577 .707 r
F P
0 g
s
.6987 .79087 m .70204 .7526 L .70523 .75452 L p .707 .577 .707 r
F P
0 g
s
.70103 .65427 m .70338 .70793 L .69074 .69769 L p .707 .577 .707 r
F P
0 g
s
.69074 .69769 m .68839 .64403 L .70103 .65427 L p .707 .577 .707 r
F P
0 g
s
.57922 .68572 m .57687 .63206 L .60867 .62977 L p .707 .577 .707 r
F P
0 g
s
.57792 .31205 m .57471 .81602 L .60867 .80869 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .61187 .30472 L .57792 .31205 L p .707 .577 .707 r
F P
0 g
s
.70617 .80329 m .70711 .82102 L .70412 .80894 L p .707 .577 .707 r
F P
0 g
s
.70412 .80894 m .70318 .7912 L .70617 .80329 L p .707 .577 .707 r
F P
0 g
s
.25255 .66793 m .22139 .66655 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25255 .66793 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25148 .7516 m .28317 .75419 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25148 .7516 L p .25615 .71704 L .707 .577 .707 r
F P
0 g
s
.25635 .71553 m .25464 .71552 L .25615 .71704 L .707 .577 .707 r
F
.25148 .7516 m .25464 .71552 L p .22588 .7135 L F P
0 g
s
.22036 .74854 m .25148 .7516 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22036 .74854 L p .22554 .71565 L .707 .577 .707 r
F P
0 g
s
.22588 .7135 m .22344 .71333 L .22554 .71565 L .707 .577 .707 r
F
.22139 .66655 m .19392 .66164 L p .21615 .70531 L F P
0 g
s
.21997 .71281 m .22344 .71333 L .21615 .70531 L .707 .577 .707 r
F
.22344 .71333 m .22139 .66655 L p .21615 .70531 L F P
0 g
s
.24584 .70672 m .23921 .70007 L .22374 .72022 L .707 .577 .707 r
F
.22211 .68295 m .22344 .71333 L p .23921 .70007 L F P
0 g
s
.22344 .71333 m .22374 .72022 L p .23921 .70007 L .707 .577 .707 r
F P
0 g
s
.22036 .74854 m .22344 .71333 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .22036 .74854 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19285 .74531 L p .19738 .71127 L .707 .577 .707 r
F P
0 g
s
.19761 .70947 m .19601 .70923 L .19738 .71127 L .707 .577 .707 r
F
.19392 .66164 m .17283 .65367 L p .1913 .70222 L F P
0 g
s
.17283 .65367 m .16019 .64343 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17778 .70436 m .17499 .70396 L p .19601 .70923 L .707 .577 .707 r
F P
0 g
s
.17499 .70396 m .17165 .74222 L .19048 .74496 L p .707 .577 .707 r
F P
0 g
s
.19048 .74496 m .19285 .74531 L p .17613 .70659 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17499 .70396 L .19048 .74496 L .707 .577 .707 r
F
.17165 .74222 m .17499 .70396 L .16217 .70132 L p F P
0 g
s
.16254 .6971 m .17518 .70734 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16019 .64343 m .16121 .66667 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16121 .66667 m .16254 .6971 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17518 .70734 m .17502 .70362 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17502 .70362 m .17283 .65367 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .19601 .70923 L p .17516 .704 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17516 .704 L .17499 .70396 L .707 .577 .707 r
F
.19285 .74531 m .17516 .704 L .17613 .70659 L F
.19373 .70862 m .19601 .70923 L .1913 .70222 L F
.19601 .70923 m .19392 .66164 L p .1913 .70222 L F P
0 g
s
.19392 .66164 m .19601 .70923 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.17283 .65367 m .17518 .70734 L .19627 .7153 L p .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .1962 .70704 L .17778 .70436 L p .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .19601 .70923 L p .19373 .70862 L .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .22374 .72022 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19627 .7153 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.1962 .70704 m .19601 .70923 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .1962 .70704 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22371 .71027 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .22344 .71333 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .22344 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .2549 .7216 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25105 .71527 m .24584 .70672 L .23382 .71406 L .707 .577 .707 r
F
.25105 .71527 m .23382 .71406 L .22374 .72022 L F
.22139 .66655 m .22211 .68295 L p .24584 .70672 L F P
0 g
s
.25255 .66793 m .25464 .71552 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28651 .71593 L .28235 .71558 L p .707 .577 .707 r
F P
0 g
s
.28235 .71558 m .25483 .71333 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28235 .71558 L .25635 .71553 L .707 .577 .707 r
F
.28435 .66564 m .25255 .66793 L p .28423 .71559 L F P
0 g
s
.28651 .71593 m .28317 .75419 L .31232 .75607 L p .707 .577 .707 r
F P
0 g
s
.31232 .75607 m .31566 .7178 L .28651 .71593 L p .707 .577 .707 r
F P
0 g
s
.28671 .71931 m .28654 .71559 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28654 .71559 m .28435 .66564 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .28671 .71931 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .2549 .7216 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .25464 .71552 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .22371 .71027 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25483 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .25464 .71552 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.40552 .81217 m .40872 .3082 L .379 .29941 L p .707 .577 .707 r
F P
0 g
s
.40872 .3082 m .40552 .81217 L .44428 .81826 L p .707 .577 .707 r
F P
0 g
s
.28435 .66564 m .28671 .71931 L .31604 .71357 L p .707 .577 .707 r
F P
0 g
s
.31604 .71357 m .31368 .6599 L .28435 .66564 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68839 .64403 m .69074 .69769 L .66965 .68973 L p .707 .577 .707 r
F P
0 g
s
.66965 .68973 m .6673 .63606 L .68839 .64403 L p .707 .577 .707 r
F P
0 g
s
.31368 .6599 m .31604 .71357 L .34003 .70495 L p .707 .577 .707 r
F P
0 g
s
.34003 .70495 m .33767 .65128 L .31368 .6599 L p .707 .577 .707 r
F P
0 g
s
.70204 .7526 m .6987 .79087 L .68587 .78824 L p .707 .577 .707 r
F P
0 g
s
.68587 .78824 m .68922 .74997 L .70204 .7526 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .63498 .29503 L .61187 .30472 L p .707 .577 .707 r
F P
0 g
s
.70318 .7912 m .70412 .80894 L .69145 .79825 L p .707 .577 .707 r
F P
0 g
s
.69145 .79825 m .69052 .78051 L .70318 .7912 L p .707 .577 .707 r
F P
0 g
s
.33767 .65128 m .34003 .70495 L .35632 .69429 L p .707 .577 .707 r
F P
0 g
s
.35632 .69429 m .35397 .64062 L .33767 .65128 L p .707 .577 .707 r
F P
0 g
s
.37579 .80339 m .379 .29941 L .36122 .2888 L p .707 .577 .707 r
F P
0 g
s
.379 .29941 m .37579 .80339 L .40552 .81217 L p .707 .577 .707 r
F P
0 g
s
.6673 .63606 m .66965 .68973 L .64218 .68481 L p .707 .577 .707 r
F P
0 g
s
.64218 .68481 m .63983 .63114 L .6673 .63606 L p .707 .577 .707 r
F P
0 g
s
.31566 .7178 m .31232 .75607 L .33608 .75704 L p .707 .577 .707 r
F P
0 g
s
.33608 .75704 m .33942 .71877 L .31566 .7178 L p .707 .577 .707 r
F P
0 g
s
.68922 .74997 m .68587 .78824 L .66467 .78515 L p .707 .577 .707 r
F P
0 g
s
.66467 .78515 m .66801 .74689 L .68922 .74997 L p .707 .577 .707 r
F P
0 g
s
.25579 .82575 m .25485 .80801 L .22369 .80674 L p .707 .577 .707 r
F P
0 g
s
.25485 .80801 m .25579 .82575 L .28758 .82317 L p .707 .577 .707 r
F P
0 g
s
.28758 .82317 m .28664 .80543 L .25485 .80801 L p .707 .577 .707 r
F P
0 g
s
.28664 .80543 m .28758 .82317 L .31689 .81698 L p .707 .577 .707 r
F P
0 g
s
.31689 .81698 m .31595 .79924 L .28664 .80543 L p .707 .577 .707 r
F P
0 g
s
.22463 .82447 m .22369 .80674 L .19622 .80172 L p .707 .577 .707 r
F P
0 g
s
.22369 .80674 m .22463 .82447 L .25579 .82575 L p .707 .577 .707 r
F P
0 g
s
.69052 .78051 m .69145 .79825 L .67035 .78999 L p .707 .577 .707 r
F P
0 g
s
.67035 .78999 m .66941 .77225 L .69052 .78051 L p .707 .577 .707 r
F P
0 g
s
.33942 .71877 m .33608 .75704 L .35212 .757 L p .707 .577 .707 r
F P
0 g
s
.35212 .757 m .35547 .71874 L .33942 .71877 L p .707 .577 .707 r
F P
0 g
s
.64177 .78791 m .64498 .28394 L .63498 .29503 L p .707 .577 .707 r
F P
0 g
s
.35397 .64062 m .35632 .69429 L .36334 .68263 L p .707 .577 .707 r
F P
0 g
s
.36334 .68263 m .36098 .62896 L .35397 .64062 L p .707 .577 .707 r
F P
0 g
s
.31595 .79924 m .31689 .81698 L .34085 .80779 L p .707 .577 .707 r
F P
0 g
s
.34085 .80779 m .33991 .79005 L .31595 .79924 L p .707 .577 .707 r
F P
0 g
s
.19622 .80172 m .19716 .81946 L .22463 .82447 L p .707 .577 .707 r
F P
0 g
s
.16217 .70132 m .15882 .73959 L .17165 .74222 L p .707 .577 .707 r
F P
0 g
s
.19716 .81946 m .19622 .80172 L .17512 .79346 L p .707 .577 .707 r
F P
0 g
s
.16254 .6971 m .16019 .64343 L .15723 .63192 L p .707 .577 .707 r
F P
0 g
s
.35547 .71874 m .35212 .757 L .35888 .75598 L p .707 .577 .707 r
F P
0 g
s
.35888 .75598 m .36222 .71771 L .35547 .71874 L p .707 .577 .707 r
F P
0 g
s
.36038 .67112 m .35802 .61745 L .36098 .62896 L p .707 .577 .707 r
F P
0 g
s
.35618 .77876 m .35712 .7965 L .3641 .78421 L p .707 .577 .707 r
F P
0 g
s
.3641 .78421 m .36316 .76647 L .35618 .77876 L p .707 .577 .707 r
F P
0 g
s
.36222 .71771 m .35888 .75598 L .35569 .75405 L p .707 .577 .707 r
F P
0 g
s
.35569 .75405 m .35903 .71578 L .36222 .71771 L p .707 .577 .707 r
F P
0 g
s
.35802 .61745 m .36038 .67112 L .34773 .66088 L p .707 .577 .707 r
F P
0 g
s
.34773 .66088 m .34538 .60721 L .35802 .61745 L p .707 .577 .707 r
F P
0 g
s
.35903 .71578 m .35569 .75405 L .34286 .75142 L p .707 .577 .707 r
F P
0 g
s
.34286 .75142 m .34621 .71315 L .35903 .71578 L p .707 .577 .707 r
F P
0 g
s
.36017 .75439 m .36111 .77213 L .34844 .76143 L p .707 .577 .707 r
F P
0 g
s
.34844 .76143 m .34751 .74369 L .36017 .75439 L p .707 .577 .707 r
F P
0 g
s
.35801 .79277 m .36122 .2888 L .35713 .27738 L p .707 .577 .707 r
F P
0 g
s
.36098 .62896 m .36334 .68263 L .36038 .67112 L p .707 .577 .707 r
F P
0 g
s
.36316 .76647 m .3641 .78421 L .36111 .77213 L p .707 .577 .707 r
F P
0 g
s
.36111 .77213 m .36017 .75439 L .36316 .76647 L p .707 .577 .707 r
F P
0 g
s
.36122 .2888 m .35801 .79277 L .37579 .80339 L p .707 .577 .707 r
F P
0 g
s
.17512 .79346 m .17606 .8112 L .19716 .81946 L p .707 .577 .707 r
F P
0 g
s
.33991 .79005 m .34085 .80779 L .35712 .7965 L p .707 .577 .707 r
F P
0 g
s
.35712 .7965 m .35618 .77876 L .33991 .79005 L p .707 .577 .707 r
F P
0 g
s
.66941 .77225 m .67035 .78999 L .64288 .78497 L p .707 .577 .707 r
F P
0 g
s
.64288 .78497 m .64194 .76724 L .66941 .77225 L p .707 .577 .707 r
F P
0 g
s
.17606 .8112 m .17512 .79346 L .16245 .78277 L p .707 .577 .707 r
F P
0 g
s
.15723 .63192 m .15958 .68558 L .16254 .6971 L p .707 .577 .707 r
F P
0 g
s
.15882 .73959 m .16217 .70132 L .15898 .6994 L p .707 .577 .707 r
F P
0 g
s
.15898 .6994 m .15563 .73767 L .15882 .73959 L p .707 .577 .707 r
F P
0 g
s
.16245 .78277 m .16339 .80051 L .17606 .8112 L p .707 .577 .707 r
F P
0 g
s
.64498 .28394 m .64177 .78791 L .63768 .77649 L p .707 .577 .707 r
F P
0 g
s
.63768 .77649 m .64089 .27252 L .64498 .28394 L p .707 .577 .707 r
F P
0 g
s
.15958 .68558 m .15723 .63192 L .16424 .62026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16339 .80051 m .16245 .78277 L .15946 .77069 L p .707 .577 .707 r
F P
0 g
s
.35713 .27738 m .35392 .78135 L .35801 .79277 L p .707 .577 .707 r
F P
0 g
s
.35392 .78135 m .35713 .27738 L .36712 .26628 L p .707 .577 .707 r
F P
0 g
s
.16424 .62026 m .16659 .67393 L .15958 .68558 L p .707 .577 .707 r
F P
0 g
s
.15946 .77069 m .1604 .78842 L .16339 .80051 L p .707 .577 .707 r
F P
0 g
s
.15563 .73767 m .15898 .6994 L .16573 .69837 L p .707 .577 .707 r
F P
0 g
s
.16573 .69837 m .16239 .73664 L .15563 .73767 L p .707 .577 .707 r
F P
0 g
s
.16659 .67393 m .16424 .62026 L .18054 .6096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64089 .27252 m .63768 .77649 L .6199 .76587 L p .707 .577 .707 r
F P
0 g
s
.6199 .76587 m .62311 .2619 L .64089 .27252 L p .707 .577 .707 r
F P
0 g
s
.34538 .60721 m .34773 .66088 L .32664 .65291 L p .707 .577 .707 r
F P
0 g
s
.32664 .65291 m .32429 .59924 L .34538 .60721 L p .707 .577 .707 r
F P
0 g
s
.1604 .78842 m .15946 .77069 L .16645 .7584 L p .707 .577 .707 r
F P
0 g
s
.18054 .6096 m .18289 .66326 L .16659 .67393 L p .707 .577 .707 r
F P
0 g
s
.16645 .7584 m .16738 .77613 L .1604 .78842 L p .707 .577 .707 r
F P
0 g
s
.18289 .66326 m .18054 .6096 L .20453 .60098 L p .707 .577 .707 r
F P
0 g
s
.16239 .73664 m .16573 .69837 L .18178 .69834 L p .707 .577 .707 r
F P
0 g
s
.18178 .69834 m .17843 .73661 L .16239 .73664 L p .707 .577 .707 r
F P
0 g
s
.36392 .77025 m .36712 .26628 L .39023 .25659 L p .707 .577 .707 r
F P
0 g
s
.36712 .26628 m .36392 .77025 L .35392 .78135 L p .707 .577 .707 r
F P
0 g
s
.32429 .59924 m .32664 .65291 L .29917 .648 L p .707 .577 .707 r
F P
0 g
s
.29917 .648 m .29682 .59433 L .32429 .59924 L p .707 .577 .707 r
F P
0 g
s
.16738 .77613 m .16645 .7584 L .18271 .7471 L p .707 .577 .707 r
F P
0 g
s
.20688 .65464 m .20453 .60098 L .23386 .59524 L p .707 .577 .707 r
F P
0 g
s
.20453 .60098 m .20688 .65464 L .18289 .66326 L p .707 .577 .707 r
F P
0 g
s
.34621 .71315 m .34286 .75142 L .32166 .74834 L p .707 .577 .707 r
F P
0 g
s
.32166 .74834 m .325 .71007 L .34621 .71315 L p .707 .577 .707 r
F P
0 g
s
.29682 .59433 m .29917 .648 L .26801 .64662 L p .707 .577 .707 r
F P
0 g
s
.26801 .64662 m .26566 .59295 L .29682 .59433 L p .707 .577 .707 r
F P
0 g
s
.18271 .7471 m .18365 .76484 L .16738 .77613 L p .707 .577 .707 r
F P
0 g
s
.62311 .2619 m .6199 .76587 L .59017 .75709 L p .707 .577 .707 r
F P
0 g
s
.59017 .75709 m .59338 .25312 L .62311 .2619 L p .707 .577 .707 r
F P
0 g
s
.17843 .73661 m .18178 .69834 L .20554 .69931 L p .707 .577 .707 r
F P
0 g
s
.20554 .69931 m .20219 .73758 L .17843 .73661 L p .707 .577 .707 r
F P
0 g
s
.23621 .64891 m .23386 .59524 L .26566 .59295 L p .707 .577 .707 r
F P
0 g
s
.23386 .59524 m .23621 .64891 L .20688 .65464 L p .707 .577 .707 r
F P
0 g
s
.34751 .74369 m .34844 .76143 L .32734 .75317 L p .707 .577 .707 r
F P
0 g
s
.32734 .75317 m .3264 .73544 L .34751 .74369 L p .707 .577 .707 r
F P
0 g
s
.26566 .59295 m .26801 .64662 L .23621 .64891 L p .707 .577 .707 r
F P
0 g
s
.39023 .25659 m .38702 .76057 L .36392 .77025 L p .707 .577 .707 r
F P
0 g
s
.38702 .76057 m .39023 .25659 L .42418 .24926 L p .707 .577 .707 r
F P
0 g
s
.73276 .61271 m .7016 .61133 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73276 .61271 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.7317 .69661 m .76338 .69921 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .7317 .69661 L p .73631 .66192 L .707 .577 .707 r
F P
0 g
s
.73651 .66046 m .73486 .66046 L .73631 .66192 L .707 .577 .707 r
F
.7317 .69661 m .73486 .66046 L p .70604 .65843 L F P
0 g
s
.70058 .69355 m .7317 .69661 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70058 .69355 L p .70571 .66052 L .707 .577 .707 r
F P
0 g
s
.70604 .65843 m .70366 .65827 L .70571 .66052 L .707 .577 .707 r
F
.7016 .61133 m .67413 .60641 L p .69654 .65043 L F P
0 g
s
.70027 .65776 m .70366 .65827 L .69654 .65043 L .707 .577 .707 r
F
.70366 .65827 m .7016 .61133 L p .69654 .65043 L F P
0 g
s
.72629 .65188 m .71943 .64501 L .70395 .66499 L .707 .577 .707 r
F
.70233 .62788 m .70366 .65827 L p .71943 .64501 L F P
0 g
s
.70366 .65827 m .70395 .66499 L p .71943 .64501 L .707 .577 .707 r
F P
0 g
s
.70058 .69355 m .70366 .65827 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .70058 .69355 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67307 .69032 L p .67755 .65613 L .707 .577 .707 r
F P
0 g
s
.67778 .6544 m .67623 .65417 L .67755 .65613 L .707 .577 .707 r
F
.67413 .60641 m .65304 .59844 L p .67164 .64734 L F P
0 g
s
.65304 .59844 m .6404 .5882 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65866 .64947 m .6552 .64897 L p .67623 .65417 L .707 .577 .707 r
F P
0 g
s
.6552 .64897 m .65186 .68724 L .67073 .68998 L p .707 .577 .707 r
F P
0 g
s
.67073 .68998 m .67307 .69032 L p .65662 .65224 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .6552 .64897 L .67073 .68998 L .707 .577 .707 r
F
.65186 .68724 m .6552 .64897 L .64238 .64634 L p F P
0 g
s
.64275 .64187 m .6554 .65211 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6404 .5882 m .64143 .61161 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.64143 .61161 m .64275 .64187 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6554 .65211 m .65524 .64856 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65524 .64856 m .65304 .59844 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .67623 .65417 L p .65541 .64902 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .65541 .64902 L .6552 .64897 L .707 .577 .707 r
F
.67307 .69032 m .65541 .64902 L .65662 .65224 L F
.67401 .65357 m .67623 .65417 L .67164 .64734 L F
.67623 .65417 m .67413 .60641 L p .67164 .64734 L F P
0 g
s
.67413 .60641 m .67623 .65417 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.65304 .59844 m .6554 .65211 L .67648 .66008 L p .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67641 .65205 L .65866 .64947 L p .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .67623 .65417 L p .67401 .65357 L .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .70395 .66499 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67648 .66008 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67641 .65205 m .67623 .65417 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .67641 .65205 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70392 .65528 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .70366 .65827 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .70366 .65827 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .73512 .66637 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73137 .66021 m .72629 .65188 L .71416 .659 L .707 .577 .707 r
F
.73137 .66021 m .71416 .659 L .70395 .66499 L F
.7016 .61133 m .70233 .62788 L p .72629 .65188 L F P
0 g
s
.73276 .61271 m .73486 .66046 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76673 .66094 L .76156 .66052 L p .707 .577 .707 r
F P
0 g
s
.76156 .66052 m .73504 .65835 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76156 .66052 L .73651 .66046 L .707 .577 .707 r
F
.76456 .61041 m .73276 .61271 L p .76455 .66052 L F P
0 g
s
.76673 .66094 m .76338 .69921 L .79253 .70108 L p .707 .577 .707 r
F P
0 g
s
.79253 .70108 m .79588 .66281 L .76673 .66094 L p .707 .577 .707 r
F P
0 g
s
.76692 .66408 m .76676 .66053 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76676 .66053 m .76456 .61041 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .76692 .66408 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73512 .66637 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .73486 .66046 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .70392 .65528 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73504 .65835 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .73486 .66046 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.325 .71007 m .32166 .74834 L .29415 .74511 L p .707 .577 .707 r
F P
0 g
s
.29415 .74511 m .29749 .70684 L .325 .71007 L p .707 .577 .707 r
F P
0 g
s
.76456 .61041 m .76692 .66408 L .79625 .65835 L p .707 .577 .707 r
F P
0 g
s
.79625 .65835 m .7939 .60468 L .76456 .61041 L p .707 .577 .707 r
F P
0 g
s
.18365 .76484 m .18271 .7471 L .20667 .73791 L p .707 .577 .707 r
F P
0 g
s
.20219 .73758 m .20554 .69931 L .23468 .70118 L p .707 .577 .707 r
F P
0 g
s
.23468 .70118 m .23134 .73945 L .20219 .73758 L p .707 .577 .707 r
F P
0 g
s
.20667 .73791 m .20761 .75565 L .18365 .76484 L p .707 .577 .707 r
F P
0 g
s
.3264 .73544 m .32734 .75317 L .29987 .74816 L p .707 .577 .707 r
F P
0 g
s
.29987 .74816 m .29893 .73042 L .3264 .73544 L p .707 .577 .707 r
F P
0 g
s
.7939 .60468 m .79625 .65835 L .82024 .64973 L p .707 .577 .707 r
F P
0 g
s
.82024 .64973 m .81789 .59606 L .7939 .60468 L p .707 .577 .707 r
F P
0 g
s
.29749 .70684 m .29415 .74511 L .26303 .74205 L p .707 .577 .707 r
F P
0 g
s
.26303 .74205 m .26637 .70378 L .29749 .70684 L p .707 .577 .707 r
F P
0 g
s
.59338 .25312 m .59017 .75709 L .55141 .751 L p .707 .577 .707 r
F P
0 g
s
.55141 .751 m .55462 .24703 L .59338 .25312 L p .707 .577 .707 r
F P
0 g
s
.23134 .73945 m .23468 .70118 L .26637 .70378 L p .707 .577 .707 r
F P
0 g
s
.20761 .75565 m .20667 .73791 L .23598 .73172 L p .707 .577 .707 r
F P
0 g
s
.26637 .70378 m .26303 .74205 L .23134 .73945 L p .707 .577 .707 r
F P
0 g
s
.29893 .73042 m .29987 .74816 L .26871 .74688 L p .707 .577 .707 r
F P
0 g
s
.26871 .74688 m .26777 .72914 L .29893 .73042 L p .707 .577 .707 r
F P
0 g
s
.42098 .75323 m .42418 .24926 L .46566 .245 L p .707 .577 .707 r
F P
0 g
s
.42418 .24926 m .42098 .75323 L .38702 .76057 L p .707 .577 .707 r
F P
0 g
s
.23598 .73172 m .23692 .74946 L .20761 .75565 L p .707 .577 .707 r
F P
0 g
s
.23692 .74946 m .23598 .73172 L .26777 .72914 L p .707 .577 .707 r
F P
0 g
s
.81789 .59606 m .82024 .64973 L .83654 .63907 L p .707 .577 .707 r
F P
0 g
s
.83654 .63907 m .83418 .5854 L .81789 .59606 L p .707 .577 .707 r
F P
0 g
s
.26777 .72914 m .26871 .74688 L .23692 .74946 L p .707 .577 .707 r
F P
0 g
s
.79588 .66281 m .79253 .70108 L .81629 .70205 L p .707 .577 .707 r
F P
0 g
s
.81629 .70205 m .81964 .66378 L .79588 .66281 L p .707 .577 .707 r
F P
0 g
s
.55462 .24703 m .55141 .751 L .5074 .7482 L p .707 .577 .707 r
F P
0 g
s
.5074 .7482 m .51061 .24423 L .55462 .24703 L p .707 .577 .707 r
F P
0 g
s
.736 .76962 m .73506 .75188 L .70391 .7506 L p .707 .577 .707 r
F P
0 g
s
.73506 .75188 m .736 .76962 L .76779 .76704 L p .707 .577 .707 r
F P
0 g
s
.76779 .76704 m .76685 .7493 L .73506 .75188 L p .707 .577 .707 r
F P
0 g
s
.46246 .74897 m .46566 .245 L .51061 .24423 L p .707 .577 .707 r
F P
0 g
s
.46566 .245 m .46246 .74897 L .42098 .75323 L p .707 .577 .707 r
F P
0 g
s
.76685 .7493 m .76779 .76704 L .7971 .76085 L p .707 .577 .707 r
F P
0 g
s
.7971 .76085 m .79616 .74311 L .76685 .7493 L p .707 .577 .707 r
F P
0 g
s
.51061 .24423 m .5074 .7482 L .46246 .74897 L p .707 .577 .707 r
F P
0 g
s
.70485 .76834 m .70391 .7506 L .67643 .74559 L p .707 .577 .707 r
F P
0 g
s
.70391 .7506 m .70485 .76834 L .736 .76962 L p .707 .577 .707 r
F P
0 g
s
.81964 .66378 m .81629 .70205 L .83234 .70202 L p .707 .577 .707 r
F P
0 g
s
.83234 .70202 m .83568 .66375 L .81964 .66378 L p .707 .577 .707 r
F P
0 g
s
.79616 .74311 m .7971 .76085 L .82106 .75166 L p .707 .577 .707 r
F P
0 g
s
.82106 .75166 m .82012 .73392 L .79616 .74311 L p .707 .577 .707 r
F P
0 g
s
.83418 .5854 m .83654 .63907 L .84355 .62741 L p .707 .577 .707 r
F P
0 g
s
.84355 .62741 m .8412 .57374 L .83418 .5854 L p .707 .577 .707 r
F P
0 g
s
.67643 .74559 m .67737 .76332 L .70485 .76834 L p .707 .577 .707 r
F P
0 g
s
.64238 .64634 m .63904 .68461 L .65186 .68724 L p .707 .577 .707 r
F P
0 g
s
.67737 .76332 m .67643 .74559 L .65533 .73733 L p .707 .577 .707 r
F P
0 g
s
.64275 .64187 m .6404 .5882 L .63744 .57669 L p .707 .577 .707 r
F P
0 g
s
.65533 .73733 m .65627 .75507 L .67737 .76332 L p .707 .577 .707 r
F P
0 g
s
.82012 .73392 m .82106 .75166 L .83733 .74036 L p .707 .577 .707 r
F P
0 g
s
.83733 .74036 m .83639 .72263 L .82012 .73392 L p .707 .577 .707 r
F P
0 g
s
.83568 .66375 m .83234 .70202 L .83909 .70099 L p .707 .577 .707 r
F P
0 g
s
.83909 .70099 m .84244 .66272 L .83568 .66375 L p .707 .577 .707 r
F P
0 g
s
.8412 .57374 m .84355 .62741 L .84059 .6159 L p .707 .577 .707 r
F P
0 g
s
.84059 .6159 m .83824 .56223 L .8412 .57374 L p .707 .577 .707 r
F P
0 g
s
.65627 .75507 m .65533 .73733 L .64267 .72663 L p .707 .577 .707 r
F P
0 g
s
.63744 .57669 m .63979 .63036 L .64275 .64187 L p .707 .577 .707 r
F P
0 g
s
.63904 .68461 m .64238 .64634 L .63919 .64441 L p .707 .577 .707 r
F P
0 g
s
.63919 .64441 m .63585 .68268 L .63904 .68461 L p .707 .577 .707 r
F P
0 g
s
.64267 .72663 m .6436 .74437 L .65627 .75507 L p .707 .577 .707 r
F P
0 g
s
.83639 .72263 m .83733 .74036 L .84431 .72807 L p .707 .577 .707 r
F P
0 g
s
.84431 .72807 m .84337 .71034 L .83639 .72263 L p .707 .577 .707 r
F P
0 g
s
.63979 .63036 m .63744 .57669 L .64445 .56503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84244 .66272 m .83909 .70099 L .8359 .69907 L p .707 .577 .707 r
F P
0 g
s
.8359 .69907 m .83925 .6608 L .84244 .66272 L p .707 .577 .707 r
F P
0 g
s
.83824 .56223 m .84059 .6159 L .82795 .60565 L p .707 .577 .707 r
F P
0 g
s
.82795 .60565 m .82559 .55199 L .83824 .56223 L p .707 .577 .707 r
F P
0 g
s
.6436 .74437 m .64267 .72663 L .63968 .71455 L p .707 .577 .707 r
F P
0 g
s
.64445 .56503 m .64681 .6187 L .63979 .63036 L p .707 .577 .707 r
F P
0 g
s
.63968 .71455 m .64062 .73229 L .6436 .74437 L p .707 .577 .707 r
F P
0 g
s
.63585 .68268 m .63919 .64441 L .64595 .64339 L p .707 .577 .707 r
F P
0 g
s
.64595 .64339 m .6426 .68166 L .63585 .68268 L p .707 .577 .707 r
F P
0 g
s
.84337 .71034 m .84431 .72807 L .84132 .71599 L p .707 .577 .707 r
F P
0 g
s
.84132 .71599 m .84039 .69825 L .84337 .71034 L p .707 .577 .707 r
F P
0 g
s
.64681 .6187 m .64445 .56503 L .66075 .55437 L p .707 .577 .707 r
F P
0 g
s
.38975 .57589 m .35859 .57451 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38975 .57589 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38869 .6598 m .42037 .66239 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38869 .6598 L p .3933 .6251 L .707 .577 .707 r
F P
0 g
s
.3935 .62365 m .39185 .62364 L .3933 .6251 L .707 .577 .707 r
F
.38869 .6598 m .39185 .62364 L p .36303 .62162 L F P
0 g
s
.35757 .65674 m .38869 .6598 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .35757 .65674 L p .3627 .62371 L .707 .577 .707 r
F P
0 g
s
.36303 .62162 m .36065 .62145 L .3627 .62371 L .707 .577 .707 r
F
.35859 .57451 m .33112 .5696 L p .35353 .61362 L F P
0 g
s
.35726 .62094 m .36065 .62145 L .35353 .61362 L .707 .577 .707 r
F
.36065 .62145 m .35859 .57451 L p .35353 .61362 L F P
0 g
s
.38328 .61507 m .37642 .60819 L .36094 .62818 L .707 .577 .707 r
F
.35932 .59106 m .36065 .62145 L p .37642 .60819 L F P
0 g
s
.36065 .62145 m .36094 .62818 L p .37642 .60819 L .707 .577 .707 r
F P
0 g
s
.35757 .65674 m .36065 .62145 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .35757 .65674 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33006 .65351 L p .33454 .61932 L .707 .577 .707 r
F P
0 g
s
.33477 .61758 m .33322 .61735 L .33454 .61932 L .707 .577 .707 r
F
.33112 .5696 m .31003 .56163 L p .32863 .61053 L F P
0 g
s
.31003 .56163 m .29739 .55139 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31565 .61266 m .31219 .61216 L p .33322 .61735 L .707 .577 .707 r
F P
0 g
s
.31219 .61216 m .30885 .65042 L .32772 .65317 L p .707 .577 .707 r
F P
0 g
s
.32772 .65317 m .33006 .65351 L p .31361 .61542 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .31219 .61216 L .32772 .65317 L .707 .577 .707 r
F
.30885 .65042 m .31219 .61216 L .29937 .60952 L p F P
0 g
s
.29974 .60506 m .31239 .6153 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29739 .55139 m .29842 .57479 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29842 .57479 m .29974 .60506 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31239 .6153 m .31223 .61174 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31223 .61174 m .31003 .56163 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .33322 .61735 L p .3124 .61221 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .3124 .61221 L .31219 .61216 L .707 .577 .707 r
F
.33006 .65351 m .3124 .61221 L .31361 .61542 L F
.331 .61676 m .33322 .61735 L .32863 .61053 L F
.33322 .61735 m .33112 .5696 L p .32863 .61053 L F P
0 g
s
.33112 .5696 m .33322 .61735 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.31003 .56163 m .31239 .6153 L .33347 .62326 L p .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .3334 .61524 L .31565 .61266 L p .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .33322 .61735 L p .331 .61676 L .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .36094 .62818 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33347 .62326 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.3334 .61524 m .33322 .61735 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .3334 .61524 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .36091 .61847 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .36065 .62145 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .36065 .62145 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .39211 .62956 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38836 .6234 m .38328 .61507 L .37115 .62219 L .707 .577 .707 r
F
.38836 .6234 m .37115 .62219 L .36094 .62818 L F
.35859 .57451 m .35932 .59106 L p .38328 .61507 L F P
0 g
s
.38975 .57589 m .39185 .62364 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .42372 .62412 L .41855 .6237 L p .707 .577 .707 r
F P
0 g
s
.41855 .6237 m .39203 .62153 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .41855 .6237 L .3935 .62365 L .707 .577 .707 r
F
.42156 .5736 m .38975 .57589 L p .42154 .62371 L F P
0 g
s
.42372 .62412 m .42037 .66239 L .44952 .66427 L p .707 .577 .707 r
F P
0 g
s
.44952 .66427 m .45287 .626 L .42372 .62412 L p .707 .577 .707 r
F P
0 g
s
.42391 .62727 m .42375 .62371 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42375 .62371 m .42156 .5736 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .42391 .62727 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39211 .62956 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .39185 .62364 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .36091 .61847 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39203 .62153 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .39185 .62364 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.42156 .5736 m .42391 .62727 L .45324 .62153 L p .707 .577 .707 r
F P
0 g
s
.45324 .62153 m .45089 .56786 L .42156 .5736 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82559 .55199 m .82795 .60565 L .80686 .59769 L p .707 .577 .707 r
F P
0 g
s
.80686 .59769 m .8045 .54402 L .82559 .55199 L p .707 .577 .707 r
F P
0 g
s
.45089 .56786 m .45324 .62153 L .47723 .61291 L p .707 .577 .707 r
F P
0 g
s
.47723 .61291 m .47488 .55924 L .45089 .56786 L p .707 .577 .707 r
F P
0 g
s
.64062 .73229 m .63968 .71455 L .64666 .70226 L p .707 .577 .707 r
F P
0 g
s
.83925 .6608 m .8359 .69907 L .82308 .69644 L p .707 .577 .707 r
F P
0 g
s
.82308 .69644 m .82642 .65817 L .83925 .6608 L p .707 .577 .707 r
F P
0 g
s
.66075 .55437 m .6631 .60804 L .64681 .6187 L p .707 .577 .707 r
F P
0 g
s
.64666 .70226 m .6476 .72 L .64062 .73229 L p .707 .577 .707 r
F P
0 g
s
.6631 .60804 m .66075 .55437 L .68474 .54575 L p .707 .577 .707 r
F P
0 g
s
.6426 .68166 m .64595 .64339 L .66199 .64336 L p .707 .577 .707 r
F P
0 g
s
.66199 .64336 m .65865 .68162 L .6426 .68166 L p .707 .577 .707 r
F P
0 g
s
.84039 .69825 m .84132 .71599 L .82866 .7053 L p .707 .577 .707 r
F P
0 g
s
.82866 .7053 m .82772 .68756 L .84039 .69825 L p .707 .577 .707 r
F P
0 g
s
.47488 .55924 m .47723 .61291 L .49353 .60225 L p .707 .577 .707 r
F P
0 g
s
.49353 .60225 m .49117 .54858 L .47488 .55924 L p .707 .577 .707 r
F P
0 g
s
.8045 .54402 m .80686 .59769 L .77939 .59277 L p .707 .577 .707 r
F P
0 g
s
.77939 .59277 m .77704 .53911 L .8045 .54402 L p .707 .577 .707 r
F P
0 g
s
.45287 .626 m .44952 .66427 L .47328 .66524 L p .707 .577 .707 r
F P
0 g
s
.47328 .66524 m .47663 .62697 L .45287 .626 L p .707 .577 .707 r
F P
0 g
s
.6476 .72 m .64666 .70226 L .66293 .69097 L p .707 .577 .707 r
F P
0 g
s
.68709 .59942 m .68474 .54575 L .71407 .54002 L p .707 .577 .707 r
F P
0 g
s
.68474 .54575 m .68709 .59942 L .6631 .60804 L p .707 .577 .707 r
F P
0 g
s
.82642 .65817 m .82308 .69644 L .80187 .69335 L p .707 .577 .707 r
F P
0 g
s
.80187 .69335 m .80522 .65508 L .82642 .65817 L p .707 .577 .707 r
F P
0 g
s
.39299 .7328 m .39205 .71506 L .3609 .71379 L p .707 .577 .707 r
F P
0 g
s
.39205 .71506 m .39299 .7328 L .42478 .73022 L p .707 .577 .707 r
F P
0 g
s
.42478 .73022 m .42384 .71248 L .39205 .71506 L p .707 .577 .707 r
F P
0 g
s
.42384 .71248 m .42478 .73022 L .45409 .72403 L p .707 .577 .707 r
F P
0 g
s
.45409 .72403 m .45315 .70629 L .42384 .71248 L p .707 .577 .707 r
F P
0 g
s
.77704 .53911 m .77939 .59277 L .74823 .59139 L p .707 .577 .707 r
F P
0 g
s
.74823 .59139 m .74587 .53773 L .77704 .53911 L p .707 .577 .707 r
F P
0 g
s
.66293 .69097 m .66386 .70871 L .6476 .72 L p .707 .577 .707 r
F P
0 g
s
.36183 .73152 m .3609 .71379 L .33342 .70877 L p .707 .577 .707 r
F P
0 g
s
.3609 .71379 m .36183 .73152 L .39299 .7328 L p .707 .577 .707 r
F P
0 g
s
.65865 .68162 m .66199 .64336 L .68575 .64432 L p .707 .577 .707 r
F P
0 g
s
.68575 .64432 m .68241 .68259 L .65865 .68162 L p .707 .577 .707 r
F P
0 g
s
.71642 .59368 m .71407 .54002 L .74587 .53773 L p .707 .577 .707 r
F P
0 g
s
.71407 .54002 m .71642 .59368 L .68709 .59942 L p .707 .577 .707 r
F P
0 g
s
.82772 .68756 m .82866 .7053 L .80756 .69704 L p .707 .577 .707 r
F P
0 g
s
.80756 .69704 m .80662 .6793 L .82772 .68756 L p .707 .577 .707 r
F P
0 g
s
.47663 .62697 m .47328 .66524 L .48933 .6652 L p .707 .577 .707 r
F P
0 g
s
.48933 .6652 m .49267 .62694 L .47663 .62697 L p .707 .577 .707 r
F P
0 g
s
.74587 .53773 m .74823 .59139 L .71642 .59368 L p .707 .577 .707 r
F P
0 g
s
.45315 .70629 m .45409 .72403 L .47805 .71484 L p .707 .577 .707 r
F P
0 g
s
.47805 .71484 m .47711 .6971 L .45315 .70629 L p .707 .577 .707 r
F P
0 g
s
.49117 .54858 m .49353 .60225 L .50054 .59059 L p .707 .577 .707 r
F P
0 g
s
.50054 .59059 m .49819 .53692 L .49117 .54858 L p .707 .577 .707 r
F P
0 g
s
.33342 .70877 m .33436 .72651 L .36183 .73152 L p .707 .577 .707 r
F P
0 g
s
.29937 .60952 m .29603 .64779 L .30885 .65042 L p .707 .577 .707 r
F P
0 g
s
.33436 .72651 m .33342 .70877 L .31232 .70051 L p .707 .577 .707 r
F P
0 g
s
.80522 .65508 m .80187 .69335 L .77436 .69012 L p .707 .577 .707 r
F P
0 g
s
.77436 .69012 m .77771 .65185 L .80522 .65508 L p .707 .577 .707 r
F P
0 g
s
.7149 .6462 m .71156 .68447 L .68241 .68259 L p .707 .577 .707 r
F P
0 g
s
.66386 .70871 m .66293 .69097 L .68689 .68178 L p .707 .577 .707 r
F P
0 g
s
.29974 .60506 m .29739 .55139 L .29443 .53988 L p .707 .577 .707 r
F P
0 g
s
.68241 .68259 m .68575 .64432 L .7149 .6462 L p .707 .577 .707 r
F P
0 g
s
.31232 .70051 m .31326 .71825 L .33436 .72651 L p .707 .577 .707 r
F P
0 g
s
.68689 .68178 m .68783 .69952 L .66386 .70871 L p .707 .577 .707 r
F P
0 g
s
.47711 .6971 m .47805 .71484 L .49432 .70355 L p .707 .577 .707 r
F P
0 g
s
.49432 .70355 m .49338 .68581 L .47711 .6971 L p .707 .577 .707 r
F P
0 g
s
.80662 .6793 m .80756 .69704 L .78008 .69202 L p .707 .577 .707 r
F P
0 g
s
.78008 .69202 m .77914 .67429 L .80662 .6793 L p .707 .577 .707 r
F P
0 g
s
.77771 .65185 m .77436 .69012 L .74324 .68706 L p .707 .577 .707 r
F P
0 g
s
.74324 .68706 m .74658 .64879 L .77771 .65185 L p .707 .577 .707 r
F P
0 g
s
.49267 .62694 m .48933 .6652 L .49608 .66418 L p .707 .577 .707 r
F P
0 g
s
.49608 .66418 m .49943 .62591 L .49267 .62694 L p .707 .577 .707 r
F P
0 g
s
.71156 .68447 m .7149 .6462 L .74658 .64879 L p .707 .577 .707 r
F P
0 g
s
.49819 .53692 m .50054 .59059 L .49758 .57908 L p .707 .577 .707 r
F P
0 g
s
.49758 .57908 m .49523 .52541 L .49819 .53692 L p .707 .577 .707 r
F P
0 g
s
.68783 .69952 m .68689 .68178 L .7162 .67559 L p .707 .577 .707 r
F P
0 g
s
.74658 .64879 m .74324 .68706 L .71156 .68447 L p .707 .577 .707 r
F P
0 g
s
.31326 .71825 m .31232 .70051 L .29966 .68982 L p .707 .577 .707 r
F P
0 g
s
.77914 .67429 m .78008 .69202 L .74893 .69075 L p .707 .577 .707 r
F P
0 g
s
.74893 .69075 m .74799 .67301 L .77914 .67429 L p .707 .577 .707 r
F P
0 g
s
.29443 .53988 m .29678 .59354 L .29974 .60506 L p .707 .577 .707 r
F P
0 g
s
.29603 .64779 m .29937 .60952 L .29618 .6076 L p .707 .577 .707 r
F P
0 g
s
.7162 .67559 m .71714 .69333 L .68783 .69952 L p .707 .577 .707 r
F P
0 g
s
.29618 .6076 m .29284 .64587 L .29603 .64779 L p .707 .577 .707 r
F P
0 g
s
.29966 .68982 m .30059 .70756 L .31326 .71825 L p .707 .577 .707 r
F P
0 g
s
.71714 .69333 m .7162 .67559 L .74799 .67301 L p .707 .577 .707 r
F P
0 g
s
.74799 .67301 m .74893 .69075 L .71714 .69333 L p .707 .577 .707 r
F P
0 g
s
.49338 .68581 m .49432 .70355 L .5013 .69126 L p .707 .577 .707 r
F P
0 g
s
.5013 .69126 m .50036 .67352 L .49338 .68581 L p .707 .577 .707 r
F P
0 g
s
.29678 .59354 m .29443 .53988 L .30144 .52822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49943 .62591 m .49608 .66418 L .49289 .66225 L p .707 .577 .707 r
F P
0 g
s
.49289 .66225 m .49624 .62398 L .49943 .62591 L p .707 .577 .707 r
F P
0 g
s
.49523 .52541 m .49758 .57908 L .48494 .56884 L p .707 .577 .707 r
F P
0 g
s
.48494 .56884 m .48258 .51517 L .49523 .52541 L p .707 .577 .707 r
F P
0 g
s
.30059 .70756 m .29966 .68982 L .29667 .67774 L p .707 .577 .707 r
F P
0 g
s
.30144 .52822 m .30379 .58189 L .29678 .59354 L p .707 .577 .707 r
F P
0 g
s
.29667 .67774 m .29761 .69547 L .30059 .70756 L p .707 .577 .707 r
F P
0 g
s
.29284 .64587 m .29618 .6076 L .30294 .60657 L p .707 .577 .707 r
F P
0 g
s
.30294 .60657 m .29959 .64484 L .29284 .64587 L p .707 .577 .707 r
F P
0 g
s
.50036 .67352 m .5013 .69126 L .49831 .67918 L p .707 .577 .707 r
F P
0 g
s
.49831 .67918 m .49737 .66144 L .50036 .67352 L p .707 .577 .707 r
F P
0 g
s
.30379 .58189 m .30144 .52822 L .31774 .51756 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48258 .51517 m .48494 .56884 L .46385 .56087 L p .707 .577 .707 r
F P
0 g
s
.46385 .56087 m .46149 .5072 L .48258 .51517 L p .707 .577 .707 r
F P
0 g
s
.29761 .69547 m .29667 .67774 L .30365 .66545 L p .707 .577 .707 r
F P
0 g
s
.49624 .62398 m .49289 .66225 L .48007 .65962 L p .707 .577 .707 r
F P
0 g
s
.48007 .65962 m .48341 .62135 L .49624 .62398 L p .707 .577 .707 r
F P
0 g
s
.31774 .51756 m .32009 .57123 L .30379 .58189 L p .707 .577 .707 r
F P
0 g
s
.30365 .66545 m .30459 .68318 L .29761 .69547 L p .707 .577 .707 r
F P
0 g
s
.32009 .57123 m .31774 .51756 L .34173 .50894 L p .707 .577 .707 r
F P
0 g
s
.29959 .64484 m .30294 .60657 L .31898 .60654 L p .707 .577 .707 r
F P
0 g
s
.31898 .60654 m .31564 .64481 L .29959 .64484 L p .707 .577 .707 r
F P
0 g
s
.49737 .66144 m .49831 .67918 L .48565 .66848 L p .707 .577 .707 r
F P
0 g
s
.48565 .66848 m .48471 .65074 L .49737 .66144 L p .707 .577 .707 r
F P
0 g
s
.46149 .5072 m .46385 .56087 L .43638 .55596 L p .707 .577 .707 r
F P
0 g
s
.43638 .55596 m .43402 .50229 L .46149 .5072 L p .707 .577 .707 r
F P
0 g
s
.30459 .68318 m .30365 .66545 L .31992 .65415 L p .707 .577 .707 r
F P
0 g
s
.34408 .5626 m .34173 .50894 L .37106 .5032 L p .707 .577 .707 r
F P
0 g
s
.34173 .50894 m .34408 .5626 L .32009 .57123 L p .707 .577 .707 r
F P
0 g
s
.48341 .62135 m .48007 .65962 L .45886 .65654 L p .707 .577 .707 r
F P
0 g
s
.45886 .65654 m .4622 .61827 L .48341 .62135 L p .707 .577 .707 r
F P
0 g
s
.43402 .50229 m .43638 .55596 L .40522 .55458 L p .707 .577 .707 r
F P
0 g
s
.40522 .55458 m .40286 .50091 L .43402 .50229 L p .707 .577 .707 r
F P
0 g
s
.31992 .65415 m .32085 .67189 L .30459 .68318 L p .707 .577 .707 r
F P
0 g
s
.31564 .64481 m .31898 .60654 L .34274 .60751 L p .707 .577 .707 r
F P
0 g
s
.34274 .60751 m .3394 .64578 L .31564 .64481 L p .707 .577 .707 r
F P
0 g
s
.37341 .55687 m .37106 .5032 L .40286 .50091 L p .707 .577 .707 r
F P
0 g
s
.37106 .5032 m .37341 .55687 L .34408 .5626 L p .707 .577 .707 r
F P
0 g
s
.48471 .65074 m .48565 .66848 L .46455 .66022 L p .707 .577 .707 r
F P
0 g
s
.46455 .66022 m .46361 .64248 L .48471 .65074 L p .707 .577 .707 r
F P
0 g
s
.40286 .50091 m .40522 .55458 L .37341 .55687 L p .707 .577 .707 r
F P
0 g
s
.4622 .61827 m .45886 .65654 L .43135 .65331 L p .707 .577 .707 r
F P
0 g
s
.43135 .65331 m .4347 .61504 L .4622 .61827 L p .707 .577 .707 r
F P
0 g
s
.37189 .60938 m .36855 .64765 L .3394 .64578 L p .707 .577 .707 r
F P
0 g
s
.32085 .67189 m .31992 .65415 L .34388 .64496 L p .707 .577 .707 r
F P
0 g
s
.3394 .64578 m .34274 .60751 L .37189 .60938 L p .707 .577 .707 r
F P
0 g
s
.34388 .64496 m .34482 .6627 L .32085 .67189 L p .707 .577 .707 r
F P
0 g
s
.46361 .64248 m .46455 .66022 L .43707 .65521 L p .707 .577 .707 r
F P
0 g
s
.43707 .65521 m .43613 .63747 L .46361 .64248 L p .707 .577 .707 r
F P
0 g
s
.4347 .61504 m .43135 .65331 L .40023 .65024 L p .707 .577 .707 r
F P
0 g
s
.40023 .65024 m .40357 .61198 L .4347 .61504 L p .707 .577 .707 r
F P
0 g
s
.36855 .64765 m .37189 .60938 L .40357 .61198 L p .707 .577 .707 r
F P
0 g
s
.34482 .6627 m .34388 .64496 L .37319 .63877 L p .707 .577 .707 r
F P
0 g
s
.40357 .61198 m .40023 .65024 L .36855 .64765 L p .707 .577 .707 r
F P
0 g
s
.43613 .63747 m .43707 .65521 L .40591 .65393 L p .707 .577 .707 r
F P
0 g
s
.40591 .65393 m .40498 .63619 L .43613 .63747 L p .707 .577 .707 r
F P
0 g
s
.37319 .63877 m .37413 .65651 L .34482 .6627 L p .707 .577 .707 r
F P
0 g
s
.37413 .65651 m .37319 .63877 L .40498 .63619 L p .707 .577 .707 r
F P
0 g
s
.40498 .63619 m .40591 .65393 L .37413 .65651 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo6000QWoo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Aoo`<00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00L7oo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool3
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00
JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEPl000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo2@0015YF00<005YFFUH01UYF00<005YF00000`000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000;FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001UOol005ioo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00
G7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00IGoo001JOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00EWoo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000IOol80015Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`L000AJEP04001J
EUYFFUH8000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF
00QJEP03001JEUYF00EJEP04001JEUYFFUH6000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000Yoo`@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo100000=JEP00FUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH015YF1`0025YF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000_Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH4
0005FUH00`00FUIJEP06FUH50004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool005=oo`04001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP04FUH50004FUH00`00
FUIJEP08FUH600000eYF001JEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH0
0003FUH00`00FUH000030004Ool01000FUIJEP001UYF1@0015YF00<005YFFUH015YF100015YF00@0
05YF000000=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000=JEP800003FUH0
000000<0009oo`04001JEUYF0006FUH50004FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF00<005YF
FUH00UYF00@005YFFUIJEQP000IJEP03001JEUYF00=JEP03001JEUYF009JEP@00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<00003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`07001JEP00FUH005YFOol00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF0`00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo0017Ool90004Ool20002FUH01000FUIJEWoo0UYF00<0
05YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF5`0015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000oOol80004FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040007Ool3000=Ool50005FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH4000:Ool5000>Ool50003FUH00`00FUIJEP02000]Ool003Moo`800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEP0000<000ioo`D000]oo`<000EJEP800004FUH005YFFUH2000]Ool003Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ400003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEPL000eoo`D000Moo`@00003FUH0
05YF00EJEP04001JEP000002FUH2000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH900000eYF001JEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH01000FUIJEUYF2@001Goo0`0000=o
o`0000001@001EYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000]Ool0035oo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEQ400003FUH005YF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;goo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPL000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00L005YFFUIJEP00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00005
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70004FUH01000FUIJEUYF20000eYF00<005YFFUH015YF
00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000EJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001J
EUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00
15YF00<005YFFUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEPX00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP04001JEUYF000`Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT0009JEQ4000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<0009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP0B0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000a
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH70009Ool90003FUH30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030003
FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP03
FUH2000cOol002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP040007Ool3000>Ool5
0003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH00UYF0P00=Goo000/Ool01000FUIJEP0015YF00<005YFFUH00UYF10002Woo1@003Woo
0P001UYF00<005YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF0P0000=JEP0000000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Io
o`00;Goo00<005YF000015YF00<005YF00000P003Woo1@002goo10001eYF00<005YFFUH0100000=J
EP0000001`0015YF00<005YFFUH01EYF1P0015YF00<005YF00000P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Woo
000]Ool00`00FUH00004FUH7000<Ool50007Ool600000eYF001JEP05FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH@0002FUH20003FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Goo00<005YF00000UYF0P000eYF00@005YFFUIJEQP000=JEP03001JEUYF009JEP04001JEUYF
FUH20003FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF1P0000EJEP00FUIJEP00
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF00000P0015YF00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00=JEP80009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;Goo00L005YF001JEP00FUIoo`03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20002FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF00H005YF000005YF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00=JEPl000EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00000UYF0P0015YF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<0
05YF000010001UYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF0P001eYF00<005YFFUH01UYF00H005YFFUIJEP00FUH40006FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH80003FUH70003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH01`00FUIJEUYF001JEP0002eoo`00;Goo0P000UYF00@0
05YFFUIoo`9JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00AJEPD000AJEP03001JEUYF00UJEP03
001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH2000^Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP8000MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF
00000UYF00<005YFFUH015YF1@0015YF00<005YFFUH02EYF00<005YFFUH01UYF00D005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP8000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0
000002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH50004FUH00`00FUIJEP09FUH00`00FUIJEP04FUH3000015YF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH00eYF1000;Woo000^Ool01000FUIJEP000eYF00=ooeYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH015YF00D005YFFUIJEP00009J
EP03001JEUYF00AJEP@000EJEP03001JEUYF00UJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`<000IJEP03001J
EUYF009JEPP000QJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEP00000^Ool002eo
oa400003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0006FUH00`00FUIJ
EP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP020004FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP03FUH70002OolB0004FUH00`00FUH000030004FUH01000FUIJEP00;Woo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH01eYF00<005YFFUH00P000UYF
0P001UYF0`0000Eoo`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@00003FUH005YF
00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH01000FUIJEUYF0P000eYF00@005YF000001Aoo`d00005FUH005YFFUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH005YF009JEP05
001JEUYF001JEP030002FUH20003Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP06001JEP00001JEP0015YF0`008Goo0P000UYF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP02FUH50002Ool01000FUIJEP001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP8000=JEP03001JEUYF009JEP<002=oo`04001JEUYF000]Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP04001JEUYFFUH90003FUH00`00FUIJEP03FUH70005FUH0
0`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00UYF0`0097oo0`00;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030007FUH01`00FUIJEUYF001JEP0000Qoo`<001Yoo`8002eoo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0007FUH01`00FUIJEUYF001JEP0000Moo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH01EYF00@005YFFUIJEP8000Qoo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH015YF00@005YFFUIJEP8000Qoo`D001Moo`800003FUH007oo
02aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF3P00
1EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH00UYF1`0025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YF
FUH015YF00D005YFFUIJEP0000Yoo`<001Ioo`800004FUH005YF000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEP0000<00003FUH0
05YF00AJEP03001JEUYF010000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH00000FUH00006FUH01000FUIJ
EP008Woo0P000eYF0P00;Woo000/OolC0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P001UYF0`008Goo0P0000=JEP00FUH00UYF0P00;Woo000]Ool200000eYF001JEP04FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
0002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0`0015YF0P008Goo
0P000eYF00D005YFFUIJEP0002moo`00;goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00@001moo`@000EJEP04001JEUYF000`Ool003=o
o`8000IJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF009JEP<0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF009JEPD001Qoo`@0009JEP03001JEUYF00AJEP<0035o
o`00<Woo0P001eYF00<005YFFUH00UYF300015YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJEP03001JEUYF
00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH01000FUIJEUYF
60001UYF00<005YFFUH00eYF0P00<goo000`Ool200000eYF001JEP05FUH6000<OolC0004FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000_Ool00`00FUIJEP02FUH01000FUIJEUYF0P008Woo1P0000=JEP0000000UYF00<005YFFUH015YF
00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
10001UYF00<005YFFUH00UYF0P0015YF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;Woo0P0015YF00@005YF000002Yoo`<0009J
EP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP8000IJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<003Uoo`00;Woo0P0015YF0P00;Woo00@0
05YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP@000AJEP8000IJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@003aoo`00;Goo00<005YF00000UYF0P00<7oo00D005YFFUH005YF0080
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYFFUH20002FUH50002FUH00`00FUIJEP04FUHJ0010Ool002eoo`03001JEP000080
01Ioo`<001Uoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEPH0009JEP07
001JEUYFFUH005YF0000E7oo000]Ool00`00FUH0000GOol5000HOol00`00FUH00003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YF00000P000eYF0P00EGoo000]Ool2000H
Ool5000HOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH0
0UYF0P0000=JEP000000EGoo000]Ool2000HOol5000GOol30004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH000001eYF00<005YFFUH00eYF1000EGoo000]Ool3000HOol3000FOol200000eYF
00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP040004FUH00`00FUIJEP03FUH0
1000FUH00000EGoo000]Ool200000eYF001oo`0]Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP000eYF1P0015YF00@005YFFUH005Eoo`00;Goo0P000UYF0P00
:Woo0P0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00003@0000EJEP00FUIJEP0005Eoo`00;Woo00D005YFFUH005YF00<002Eoo`8000=JEP03001JEUYF
009JEP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000ioo`80009JEP03001oogoo05=oo`00
;Woo00@005YFFUH000AJEP<001moo`<000EJEP03001JEUYF008000=oo`<000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP80015oo`04001JEP00001DOol002moo`04001JEUYF0004FUH00`00FUH00003000GOol400000eYF
001JEP05FUH30007Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUH00002000DOol00`00FUH0001DOol0031oo`<000AJEP03
001JEUYF00=JEQL000EJEP03001JEUYF00AJEP03001oogoo00Yoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<001Qoo`8005Aoo`00
<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEP80015oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@001Yoo`8005Aoo`00<goo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000001Qoo`H0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000P001Qoo`03001JEP0005Aoo`00=Goo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100087oo20001UYF00<005YF
FUH02UYF00<005YFFUH015YF1`0017oo1@005goo0P0000=JEP00Ool0Dgoo000gOol50003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000/OolJ000;Ool5000FOol01@00FUH005YF0000
E7oo000lOolH000kOol2000IOol3000FOol01000FUIJEUYF0P00E7oo002?Ool01000FUH00000;Woo
0P0015YF00<007ooOol0Dgoo002?Ool01000FUIJEUYF0P00:7oo100000=JEP00FUH00eYF00<007oo
Ool0Dgoo002?Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP05001JEUYFFUH0001FOol008moo`05
001JEUYFFUH00004FUH5000HOol40002FUH00`00FUIJEP04FUH01000FUH00000Egoo002@Ool01000
FUIJEP001EYF00@005YFFUIJEPP000Uoo`L000IJEP03001JEUYF00AJEP8005Uoo`00TGoo0`001EYF
00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Yoo`00
Tgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000`00G7oo002EOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3001POol009Qoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06=oo`00WGoo2@0015YF00<005YFFUH00UYF1`00Igoo002VOol9001^Ool00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59543 .7114 m .56429 .71033 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59543 .7114 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59451 .7745 m .62595 .7792 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59451 .7745 L p .60514 .75319 L .707 .577 .707 r
F P
0 g
s
.60733 .7488 m .59814 .74863 L .60514 .75319 L .707 .577 .707 r
F
.59451 .7745 m .59814 .74863 L p .57761 .74707 L F P
0 g
s
.56347 .77072 m .59451 .7745 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .56347 .77072 L p .57469 .75196 L .707 .577 .707 r
F P
0 g
s
.57761 .74707 m .5669 .74626 L .57469 .75196 L .707 .577 .707 r
F
.56429 .71033 m .5368 .70511 L p .55415 .73694 L F P
0 g
s
.55858 .74507 m .5669 .74626 L .55415 .73694 L .707 .577 .707 r
F
.5669 .74626 m .56429 .71033 L p .55415 .73694 L F P
0 g
s
.58292 .73873 m .58267 .73856 L .56808 .76249 L .707 .577 .707 r
F
.56553 .7274 m .5669 .74626 L p .58267 .73856 L F P
0 g
s
.5669 .74626 m .56808 .76249 L p .58267 .73856 L .707 .577 .707 r
F P
0 g
s
.56347 .77072 m .5669 .74626 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .56347 .77072 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .53588 .76821 L p .54592 .74875 L .707 .577 .707 r
F P
0 g
s
.54857 .74364 m .53951 .74234 L .54592 .74875 L .707 .577 .707 r
F
.5368 .70511 m .51566 .69624 L p .53103 .73386 L F P
0 g
s
.53394 .74098 m .53951 .74234 L .53103 .73386 L .707 .577 .707 r
F
.53951 .74234 m .5368 .70511 L p .53103 .73386 L F P
0 g
s
.5368 .70511 m .53951 .74234 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .53951 .74234 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .53588 .76821 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51443 .76723 L p .52201 .74331 L .707 .577 .707 r
F P
0 g
s
.52355 .73844 m .51864 .73724 L .52201 .74331 L .707 .577 .707 r
F
.51566 .69624 m .50293 .68458 L p .51475 .73023 L F P
0 g
s
.51628 .73613 m .51864 .73724 L .51475 .73023 L .707 .577 .707 r
F
.51864 .73724 m .51566 .69624 L p .51475 .73023 L F P
0 g
s
.51566 .69624 m .51864 .73724 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .51864 .73724 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .50695 .73175 L .50665 .73361 L .707 .577 .707 r
F
.50123 .76788 m .5115 .76738 L p .50665 .73361 L F P
0 g
s
.5115 .76738 m .51443 .76723 L p .50665 .73361 L .707 .577 .707 r
F P
0 g
s
.50293 .68458 m .49987 .67129 L p .50572 .7271 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50123 .76788 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.50123 .76788 m .50634 .73147 L p .5029 .73212 L .707 .577 .707 r
F P
0 g
s
.50612 .73094 m .50634 .73147 L .50572 .7271 L .707 .577 .707 r
F
.50634 .73147 m .50293 .68458 L p .50572 .7271 L F P
0 g
s
.50293 .68458 m .50634 .73147 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50586 .73034 m .5029 .73212 L p .50634 .73147 L .707 .577 .707 r
F P
0 g
s
.49987 .67129 m .50366 .72345 L .50372 .7237 L p .707 .577 .707 r
F P
0 g
s
.50372 .7237 m .50673 .73674 L p .5021 .69257 L .707 .577 .707 r
F P
0 g
s
.5021 .69257 m .49987 .67129 L .50372 .7237 L .707 .577 .707 r
F
.5029 .73212 m .49757 .77008 L .50123 .76788 L p F P
0 g
s
.49757 .77008 m .5029 .73212 L .5042 .73286 L p .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .50634 .73147 L p .50612 .73094 L .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .51945 .74839 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50673 .73674 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.5042 .73286 m .50914 .73567 L p .50499 .74802 L .707 .577 .707 r
F P
0 g
s
.49757 .77008 m .5042 .73286 L .50499 .74802 L .707 .577 .707 r
F
.50634 .73147 m .50656 .72992 L .50586 .73034 L p F P
0 g
s
.50656 .72992 m .50634 .73147 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .50656 .72992 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51976 .72928 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .51864 .73724 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .54059 .75727 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51945 .74839 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .51864 .73724 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .51976 .72928 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .5412 .73026 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .53951 .74234 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .56808 .76249 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .54059 .75727 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .53951 .74234 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5412 .73026 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .5688 .73276 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .5669 .74626 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5669 .74626 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .59922 .76356 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.58897 .74794 m .58292 .73873 L .57771 .74708 L .707 .577 .707 r
F
.58897 .74794 m .57771 .74708 L .56808 .76249 L F
.56429 .71033 m .56553 .7274 L p .58292 .73873 L F P
0 g
s
.59543 .7114 m .59814 .74863 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .59543 .7114 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62718 .70821 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .65473 .78435 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62595 .7792 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .63016 .74921 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .62718 .70821 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65643 .70106 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .65984 .74794 L p .68411 .74282 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .67802 .78945 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65473 .78435 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.67724 .74581 m .68411 .74282 L p .65984 .74794 L .707 .577 .707 r
F P
0 g
s
.67802 .78945 m .68335 .75149 L .66006 .74639 L p .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66022 .75322 L .67724 .74581 L p .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .65984 .74794 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .63128 .74125 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .65984 .74794 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66006 .74639 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.66022 .75322 m .65984 .74794 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .66022 .75322 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63097 .76036 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .63016 .74921 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .59983 .73655 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .63016 .74921 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63128 .74125 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .63016 .74921 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .63097 .76036 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59922 .76356 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .59814 .74863 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .5688 .73276 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59983 .73655 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .59814 .74863 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.68411 .74282 m .68031 .69066 L .65643 .70106 L p .707 .577 .707 r
F P
0 g
s
.68031 .69066 m .68411 .74282 L .70029 .73019 L p .707 .577 .707 r
F P
0 g
s
.70029 .73019 m .6965 .67803 L .68031 .69066 L p .707 .577 .707 r
F P
0 g
s
.60075 .86891 m .59924 .85181 L .56811 .8509 L p .707 .577 .707 r
F P
0 g
s
.59924 .85181 m .60075 .86891 L .63247 .86526 L p .707 .577 .707 r
F P
0 g
s
.63247 .86526 m .63096 .84816 L .59924 .85181 L p .707 .577 .707 r
F P
0 g
s
.63096 .84816 m .63247 .86526 L .66166 .8574 L p .707 .577 .707 r
F P
0 g
s
.66166 .8574 m .66015 .84031 L .63096 .84816 L p .707 .577 .707 r
F P
0 g
s
.68335 .75149 m .67802 .78945 L .69354 .79399 L p .707 .577 .707 r
F P
0 g
s
.6965 .67803 m .70029 .73019 L .70719 .71656 L p .707 .577 .707 r
F P
0 g
s
.70719 .71656 m .7034 .6644 L .6965 .67803 L p .707 .577 .707 r
F P
0 g
s
.69354 .79399 m .69887 .75603 L .68335 .75149 L p .707 .577 .707 r
F P
0 g
s
.56962 .868 m .56811 .8509 L .54061 .84552 L p .707 .577 .707 r
F P
0 g
s
.56811 .8509 m .56962 .868 L .60075 .86891 L p .707 .577 .707 r
F P
0 g
s
.66015 .84031 m .66166 .8574 L .68547 .84611 L p .707 .577 .707 r
F P
0 g
s
.68547 .84611 m .68396 .82902 L .66015 .84031 L p .707 .577 .707 r
F P
0 g
s
.54061 .84552 m .54212 .86262 L .56962 .868 L p .707 .577 .707 r
F P
0 g
s
.54212 .86262 m .54061 .84552 L .51944 .83619 L p .707 .577 .707 r
F P
0 g
s
.68396 .82902 m .68547 .84611 L .70158 .83249 L p .707 .577 .707 r
F P
0 g
s
.70158 .83249 m .70007 .8154 L .68396 .82902 L p .707 .577 .707 r
F P
0 g
s
.51944 .83619 m .52095 .85329 L .54212 .86262 L p .707 .577 .707 r
F P
0 g
s
.69887 .75603 m .69354 .79399 L .69978 .79754 L p .707 .577 .707 r
F P
0 g
s
.69978 .79754 m .70511 .75958 L .69887 .75603 L p .707 .577 .707 r
F P
0 g
s
.7034 .6644 m .70719 .71656 L .70413 .70327 L p .707 .577 .707 r
F P
0 g
s
.70413 .70327 m .70033 .65111 L .7034 .6644 L p .707 .577 .707 r
F P
0 g
s
.52095 .85329 m .51944 .83619 L .50665 .82383 L p .707 .577 .707 r
F P
0 g
s
.50366 .72345 m .49987 .67129 L .50677 .65767 L p .707 .577 .707 r
F P
0 g
s
.48697 .82053 m .49216 .31534 L .44815 .31248 L p .707 .577 .707 r
F P
0 g
s
.50816 .84093 m .50665 .82383 L .50352 .80965 L p .707 .577 .707 r
F P
0 g
s
.50914 .73567 m .50381 .77363 L .49757 .77008 L p .707 .577 .707 r
F P
0 g
s
.50677 .65767 m .51056 .70982 L .50366 .72345 L p .707 .577 .707 r
F P
0 g
s
.51056 .70982 m .50677 .65767 L .52295 .64504 L p .707 .577 .707 r
F P
0 g
s
.50352 .80965 m .50503 .82675 L .50816 .84093 L p .707 .577 .707 r
F P
0 g
s
.50503 .82675 m .50352 .80965 L .51034 .79503 L p .707 .577 .707 r
F P
0 g
s
.52295 .64504 m .52675 .69719 L .51056 .70982 L p .707 .577 .707 r
F P
0 g
s
.52466 .74021 m .51933 .77817 L .50381 .77363 L p .707 .577 .707 r
F P
0 g
s
.50381 .77363 m .50914 .73567 L .52466 .74021 L p .707 .577 .707 r
F P
0 g
s
.51034 .79503 m .51185 .81213 L .50503 .82675 L p .707 .577 .707 r
F P
0 g
s
.51185 .81213 m .51034 .79503 L .52644 .78141 L p .707 .577 .707 r
F P
0 g
s
.54795 .74531 m .54262 .78326 L .51933 .77817 L p .707 .577 .707 r
F P
0 g
s
.51933 .77817 m .52466 .74021 L .54795 .74531 L p .707 .577 .707 r
F P
0 g
s
.52644 .78141 m .52795 .79851 L .51185 .81213 L p .707 .577 .707 r
F P
0 g
s
.54262 .78326 m .54795 .74531 L .57673 .75046 L p .707 .577 .707 r
F P
0 g
s
.52795 .79851 m .52644 .78141 L .55025 .77012 L p .707 .577 .707 r
F P
0 g
s
.57673 .75046 m .5714 .78841 L .54262 .78326 L p .707 .577 .707 r
F P
0 g
s
.55025 .77012 m .55176 .78722 L .52795 .79851 L p .707 .577 .707 r
F P
0 g
s
.49216 .31534 m .48697 .82053 L .53191 .81996 L p .707 .577 .707 r
F P
0 g
s
.52675 .69719 m .52295 .64504 L .54684 .63464 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .55063 .6868 L .52675 .69719 L p .707 .577 .707 r
F P
0 g
s
.53191 .81996 m .5371 .31478 L .49216 .31534 L p .707 .577 .707 r
F P
0 g
s
.50665 .82383 m .50816 .84093 L .52095 .85329 L p .707 .577 .707 r
F P
0 g
s
.70007 .8154 m .70158 .83249 L .7084 .81787 L p .707 .577 .707 r
F P
0 g
s
.7084 .81787 m .70689 .80078 L .70007 .8154 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .57609 .62749 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55063 .6868 m .55052 .68524 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55052 .68524 m .54684 .63464 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.57988 .67965 m .57609 .62749 L .60784 .6243 L p .707 .577 .707 r
F P
0 g
s
.57609 .62749 m .57988 .67965 L .55063 .6868 L p .707 .577 .707 r
F P
0 g
s
.60784 .6243 m .61163 .67645 L .57988 .67965 L p .707 .577 .707 r
F P
0 g
s
.63921 .75894 m .63388 .7969 L .60912 .79388 L p .707 .577 .707 r
F P
0 g
s
.60912 .79388 m .60285 .79311 L p .60974 .78663 L .707 .577 .707 r
F P
0 g
s
.60974 .78663 m .63921 .75894 L .60912 .79388 L .707 .577 .707 r
F
.63898 .62536 m .64277 .67752 L .61163 .67645 L p F P
0 g
s
.61163 .67645 m .60784 .6243 L .63898 .62536 L p .707 .577 .707 r
F P
0 g
s
.63388 .7969 m .63921 .75894 L .6668 .76145 L p .707 .577 .707 r
F P
0 g
s
.60285 .79311 m .60817 .75516 L .63921 .75894 L p .707 .577 .707 r
F P
0 g
s
.64229 .75952 m .6438 .77662 L .61267 .77571 L p .707 .577 .707 r
F P
0 g
s
.61267 .77571 m .61116 .75861 L .64229 .75952 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .64043 .78919 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.63563 .29465 m .6334 .51211 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.6334 .51211 m .63044 .79984 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.60817 .75516 m .60285 .79311 L .5738 .78877 L p .707 .577 .707 r
F P
0 g
s
.5738 .78877 m .5714 .78841 L p .57445 .78566 L .707 .577 .707 r
F P
0 g
s
.57445 .78566 m .60817 .75516 L .5738 .78877 L .707 .577 .707 r
F
.5714 .78841 m .57673 .75046 L .60817 .75516 L p F P
0 g
s
.58096 .77936 m .57945 .76226 L .61116 .75861 L p .707 .577 .707 r
F P
0 g
s
.61116 .75861 m .61267 .77571 L .58096 .77936 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .63044 .79984 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.61253 .3039 m .60929 .61908 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.60929 .61908 m .60734 .80909 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.57857 .31083 m .57412 .74459 L p .60734 .80909 L .707 .577 .707 r
F P
0 g
s
.55176 .78722 m .55025 .77012 L .57945 .76226 L p .707 .577 .707 r
F P
0 g
s
.57945 .76226 m .58096 .77936 L .55986 .78504 L p .707 .577 .707 r
F P
0 g
s
.55986 .78504 m .55176 .78722 L p .55814 .78147 L .707 .577 .707 r
F P
0 g
s
.55814 .78147 m .57945 .76226 L .55986 .78504 L .707 .577 .707 r
F
.57412 .74459 m .57341 .81317 L p .60033 .81052 L F P
0 g
s
.57341 .81317 m .57339 .81602 L .57466 .81576 L p .707 .577 .707 r
F P
0 g
s
.57466 .81576 m .60033 .81052 L p .57341 .81317 L .707 .577 .707 r
F P
0 g
s
.60033 .81052 m .60734 .80909 L p .57412 .74459 L .707 .577 .707 r
F P
0 g
s
.5371 .31478 m .53191 .81996 L .57339 .81602 L p .707 .577 .707 r
F P
0 g
s
.57339 .81602 m .57857 .31083 L .5371 .31478 L p .707 .577 .707 r
F P
0 g
s
.44296 .81766 m .44815 .31248 L .40938 .30646 L p .707 .577 .707 r
F P
0 g
s
.44815 .31248 m .44296 .81766 L .48697 .82053 L p .707 .577 .707 r
F P
0 g
s
.70511 .75958 m .69978 .79754 L .69612 .79974 L p .707 .577 .707 r
F P
0 g
s
.70033 .65111 m .70413 .70327 L .6914 .69162 L p .707 .577 .707 r
F P
0 g
s
.6914 .69162 m .68761 .63946 L .70033 .65111 L p .707 .577 .707 r
F P
0 g
s
.69612 .79974 m .70145 .76178 L .70511 .75958 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .61253 .3039 L .57857 .31083 L p .707 .577 .707 r
F P
0 g
s
.70689 .80078 m .7084 .81787 L .70526 .80369 L p .707 .577 .707 r
F P
0 g
s
.70526 .80369 m .70375 .7866 L .70689 .80078 L p .707 .577 .707 r
F P
0 g
s
.25242 .67459 m .22128 .67352 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25242 .67459 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.2515 .73769 m .28294 .74239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .2515 .73769 L p .26213 .71637 L .707 .577 .707 r
F P
0 g
s
.26433 .71198 m .25513 .71182 L .26213 .71637 L .707 .577 .707 r
F
.2515 .73769 m .25513 .71182 L p .2346 .71026 L F P
0 g
s
.22046 .7339 m .2515 .73769 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22046 .7339 L p .23168 .71514 L .707 .577 .707 r
F P
0 g
s
.2346 .71026 m .22389 .70945 L .23168 .71514 L .707 .577 .707 r
F
.22128 .67352 m .19379 .66829 L p .21114 .70012 L F P
0 g
s
.21558 .70826 m .22389 .70945 L .21114 .70012 L .707 .577 .707 r
F
.22389 .70945 m .22128 .67352 L p .21114 .70012 L F P
0 g
s
.23991 .70191 m .23966 .70175 L .22507 .72568 L .707 .577 .707 r
F
.22252 .69059 m .22389 .70945 L p .23966 .70175 L F P
0 g
s
.22389 .70945 m .22507 .72568 L p .23966 .70175 L .707 .577 .707 r
F P
0 g
s
.22046 .7339 m .22389 .70945 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .22046 .7339 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19287 .7314 L p .20291 .71194 L .707 .577 .707 r
F P
0 g
s
.20556 .70682 m .1965 .70552 L .20291 .71194 L .707 .577 .707 r
F
.19379 .66829 m .17265 .65942 L p .18802 .69704 L F P
0 g
s
.19093 .70416 m .1965 .70552 L .18802 .69704 L .707 .577 .707 r
F
.1965 .70552 m .19379 .66829 L p .18802 .69704 L F P
0 g
s
.19379 .66829 m .1965 .70552 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .1965 .70552 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .19287 .7314 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17142 .73042 L p .179 .70649 L .707 .577 .707 r
F P
0 g
s
.18054 .70162 m .17563 .70042 L .179 .70649 L .707 .577 .707 r
F
.17265 .65942 m .15992 .64777 L p .17174 .69341 L F P
0 g
s
.17327 .69931 m .17563 .70042 L .17174 .69341 L .707 .577 .707 r
F
.17563 .70042 m .17265 .65942 L p .17174 .69341 L F P
0 g
s
.17265 .65942 m .17563 .70042 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .17563 .70042 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .16394 .69493 L .16364 .6968 L .707 .577 .707 r
F
.15822 .73106 m .16849 .73056 L p .16364 .6968 L F P
0 g
s
.16849 .73056 m .17142 .73042 L p .16364 .6968 L .707 .577 .707 r
F P
0 g
s
.15992 .64777 m .15686 .63448 L p .16271 .69028 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .15822 .73106 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.15822 .73106 m .16334 .69465 L p .15989 .69531 L .707 .577 .707 r
F P
0 g
s
.16311 .69413 m .16334 .69465 L .16271 .69028 L .707 .577 .707 r
F
.16334 .69465 m .15992 .64777 L p .16271 .69028 L F P
0 g
s
.15992 .64777 m .16334 .69465 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16285 .69353 m .15989 .69531 L p .16334 .69465 L .707 .577 .707 r
F P
0 g
s
.15686 .63448 m .16066 .68664 L .16071 .68688 L p .707 .577 .707 r
F P
0 g
s
.16071 .68688 m .16372 .69993 L p .15909 .65576 L .707 .577 .707 r
F P
0 g
s
.15909 .65576 m .15686 .63448 L .16071 .68688 L .707 .577 .707 r
F
.15989 .69531 m .15456 .73326 L .15822 .73106 L p F P
0 g
s
.15456 .73326 m .15989 .69531 L .16119 .69605 L p .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .16334 .69465 L p .16311 .69413 L .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .17644 .71158 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .16372 .69993 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16119 .69605 m .16613 .69885 L p .16198 .7112 L .707 .577 .707 r
F P
0 g
s
.15456 .73326 m .16119 .69605 L .16198 .7112 L .707 .577 .707 r
F
.16334 .69465 m .16355 .6931 L .16285 .69353 L p F P
0 g
s
.16355 .6931 m .16334 .69465 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .16355 .6931 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17675 .69246 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .17563 .70042 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .19759 .72045 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17644 .71158 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .17563 .70042 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .17675 .69246 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .1982 .69344 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .1965 .70552 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .22507 .72568 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19759 .72045 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .1965 .70552 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .1982 .69344 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22579 .69595 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .22389 .70945 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .22389 .70945 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .25622 .72674 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.24596 .71112 m .23991 .70191 L .2347 .71027 L .707 .577 .707 r
F
.24596 .71112 m .2347 .71027 L .22507 .72568 L F
.22128 .67352 m .22252 .69059 L p .23991 .70191 L F P
0 g
s
.25242 .67459 m .25513 .71182 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .25242 .67459 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28417 .67139 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .31172 .74754 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28294 .74239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .28715 .71239 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .28417 .67139 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31342 .66424 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .31683 .71113 L p .3411 .706 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .33501 .75263 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31172 .74754 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.33423 .709 m .3411 .706 L p .31683 .71113 L .707 .577 .707 r
F P
0 g
s
.33501 .75263 m .34034 .71468 L .31705 .70958 L p .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31722 .7164 L .33423 .709 L p .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .31683 .71113 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .28827 .70443 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .31683 .71113 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31705 .70958 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31722 .7164 m .31683 .71113 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .31722 .7164 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28797 .72355 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .28715 .71239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .25683 .69973 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .28715 .71239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28827 .70443 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .28715 .71239 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .28797 .72355 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25622 .72674 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .25513 .71182 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .22579 .69595 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25683 .69973 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .25513 .71182 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.4042 .81165 m .40938 .30646 L .37966 .29788 L p .707 .577 .707 r
F P
0 g
s
.40938 .30646 m .4042 .81165 L .44296 .81766 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68761 .63946 m .6914 .69162 L .67026 .68275 L p .707 .577 .707 r
F P
0 g
s
.67026 .68275 m .66647 .63059 L .68761 .63946 L p .707 .577 .707 r
F P
0 g
s
.70145 .76178 m .69612 .79974 L .68292 .80038 L p .707 .577 .707 r
F P
0 g
s
.3411 .706 m .33731 .65385 L .31342 .66424 L p .707 .577 .707 r
F P
0 g
s
.68292 .80038 m .68825 .76243 L .70145 .76178 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .63563 .29465 L .61253 .3039 L p .707 .577 .707 r
F P
0 g
s
.70375 .7866 m .70526 .80369 L .69248 .79133 L p .707 .577 .707 r
F P
0 g
s
.69248 .79133 m .69097 .77423 L .70375 .7866 L p .707 .577 .707 r
F P
0 g
s
.66647 .63059 m .67026 .68275 L .64277 .67752 L p .707 .577 .707 r
F P
0 g
s
.64277 .67752 m .63898 .62536 L .66647 .63059 L p .707 .577 .707 r
F P
0 g
s
.33731 .65385 m .3411 .706 L .35728 .69337 L p .707 .577 .707 r
F P
0 g
s
.35728 .69337 m .35349 .64122 L .33731 .65385 L p .707 .577 .707 r
F P
0 g
s
.37447 .80307 m .37966 .29788 L .36187 .28757 L p .707 .577 .707 r
F P
0 g
s
.37966 .29788 m .37447 .80307 L .4042 .81165 L p .707 .577 .707 r
F P
0 g
s
.68825 .76243 m .68292 .80038 L .66148 .7994 L p .707 .577 .707 r
F P
0 g
s
.66148 .7994 m .6668 .76145 L .68825 .76243 L p .707 .577 .707 r
F P
0 g
s
.25775 .8321 m .25623 .815 L .2251 .81409 L p .707 .577 .707 r
F P
0 g
s
.25623 .815 m .25775 .8321 L .28946 .82844 L p .707 .577 .707 r
F P
0 g
s
.28946 .82844 m .28795 .81135 L .25623 .815 L p .707 .577 .707 r
F P
0 g
s
.28795 .81135 m .28946 .82844 L .31865 .82059 L p .707 .577 .707 r
F P
0 g
s
.31865 .82059 m .31714 .80349 L .28795 .81135 L p .707 .577 .707 r
F P
0 g
s
.34034 .71468 m .33501 .75263 L .35053 .75717 L p .707 .577 .707 r
F P
0 g
s
.69097 .77423 m .69248 .79133 L .6713 .782 L p .707 .577 .707 r
F P
0 g
s
.6713 .782 m .66979 .76491 L .69097 .77423 L p .707 .577 .707 r
F P
0 g
s
.35349 .64122 m .35728 .69337 L .36418 .67975 L p .707 .577 .707 r
F P
0 g
s
.36418 .67975 m .36039 .62759 L .35349 .64122 L p .707 .577 .707 r
F P
0 g
s
.35053 .75717 m .35586 .71922 L .34034 .71468 L p .707 .577 .707 r
F P
0 g
s
.22661 .83119 m .2251 .81409 L .1976 .80871 L p .707 .577 .707 r
F P
0 g
s
.2251 .81409 m .22661 .83119 L .25775 .8321 L p .707 .577 .707 r
F P
0 g
s
.64043 .78919 m .64562 .284 L .63563 .29465 L p .707 .577 .707 r
F P
0 g
s
.31714 .80349 m .31865 .82059 L .34246 .8093 L p .707 .577 .707 r
F P
0 g
s
.34246 .8093 m .34095 .7922 L .31714 .80349 L p .707 .577 .707 r
F P
0 g
s
.6668 .76145 m .66148 .7994 L .63388 .7969 L p .707 .577 .707 r
F P
0 g
s
.1976 .80871 m .19911 .8258 L .22661 .83119 L p .707 .577 .707 r
F P
0 g
s
.19911 .8258 m .1976 .80871 L .17643 .79938 L p .707 .577 .707 r
F P
0 g
s
.35857 .79568 m .35706 .77858 L .34095 .7922 L p .707 .577 .707 r
F P
0 g
s
.35586 .71922 m .35053 .75717 L .35677 .76072 L p .707 .577 .707 r
F P
0 g
s
.35677 .76072 m .3621 .72277 L .35586 .71922 L p .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36039 .62759 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36112 .66646 m .36101 .6649 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .35732 .6143 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36101 .6649 L p .34839 .6548 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .36112 .66646 L .36092 .66627 L p .707 .577 .707 r
F P
0 g
s
.36092 .66627 m .34839 .6548 L p .36101 .6649 L .707 .577 .707 r
F P
0 g
s
.3621 .72277 m .35677 .76072 L .35311 .76292 L p .707 .577 .707 r
F P
0 g
s
.34839 .6548 m .3446 .60265 L .35732 .6143 L p .707 .577 .707 r
F P
0 g
s
.35311 .76292 m .35844 .72497 L .3621 .72277 L p .707 .577 .707 r
F P
0 g
s
.35844 .72497 m .35311 .76292 L .33991 .76357 L p .707 .577 .707 r
F P
0 g
s
.33991 .76357 m .34524 .72561 L .35844 .72497 L p .707 .577 .707 r
F P
0 g
s
.36074 .74978 m .36225 .76688 L .35871 .76345 L p .707 .577 .707 r
F P
0 g
s
.35871 .76345 m .34947 .75451 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.3597 .75022 m .36074 .74978 L .35871 .76345 L .707 .577 .707 r
F
.34947 .75451 m .34796 .73742 L .3598 .74887 L p F P
0 g
s
.3598 .74887 m .36074 .74978 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.34947 .75451 m .3598 .74887 L .3597 .75022 L .707 .577 .707 r
F
.35669 .79023 m .35811 .65416 L .35699 .65 L F
.35668 .79276 m .35671 .78991 L p .35669 .79023 L F P
0 g
s
.35671 .78991 m .35811 .65416 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35343 .78402 m .35653 .79235 L p .35682 .73081 L .707 .577 .707 r
F P
0 g
s
.35653 .79235 m .35668 .79276 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35669 .79023 m .35682 .73081 L .35653 .79235 L .707 .577 .707 r
F
.35778 .27656 m .35259 .78175 L .35343 .78402 L p F P
0 g
s
.35682 .73081 m .35778 .27656 L .35343 .78402 L .707 .577 .707 r
F
.36187 .28757 m .35778 .27656 L p .35699 .65 L F P
0 g
s
.35811 .65416 m .36187 .28757 L p .35699 .65 L .707 .577 .707 r
F P
0 g
s
.36039 .62759 m .36418 .67975 L .36112 .66646 L p .707 .577 .707 r
F P
0 g
s
.35706 .77858 m .35857 .79568 L .36539 .78106 L p .707 .577 .707 r
F P
0 g
s
.36539 .78106 m .36388 .76396 L .35706 .77858 L p .707 .577 .707 r
F P
0 g
s
.36388 .76396 m .36539 .78106 L .36225 .76688 L p .707 .577 .707 r
F P
0 g
s
.36225 .76688 m .36074 .74978 L .36388 .76396 L p .707 .577 .707 r
F P
0 g
s
.36187 .28757 m .35668 .79276 L .37447 .80307 L p .707 .577 .707 r
F P
0 g
s
.66979 .76491 m .6713 .782 L .6438 .77662 L p .707 .577 .707 r
F P
0 g
s
.6438 .77662 m .64229 .75952 L .66979 .76491 L p .707 .577 .707 r
F P
0 g
s
.34095 .7922 m .34246 .8093 L .35857 .79568 L p .707 .577 .707 r
F P
0 g
s
.17643 .79938 m .17794 .81647 L .19911 .8258 L p .707 .577 .707 r
F P
0 g
s
.17794 .81647 m .17643 .79938 L .16364 .78702 L p .707 .577 .707 r
F P
0 g
s
.64562 .284 m .64043 .78919 L .63634 .77817 L p .707 .577 .707 r
F P
0 g
s
.63634 .77817 m .64153 .27298 L .64562 .284 L p .707 .577 .707 r
F P
0 g
s
.16066 .68664 m .15686 .63448 L .16376 .62085 L p .707 .577 .707 r
F P
0 g
s
.16364 .78702 m .16515 .80411 L .17794 .81647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35259 .78175 m .35778 .27656 L .36777 .2659 L p .707 .577 .707 r
F P
0 g
s
.16515 .80411 m .16364 .78702 L .16051 .77283 L p .707 .577 .707 r
F P
0 g
s
.16613 .69885 m .1608 .73681 L .15456 .73326 L p .707 .577 .707 r
F P
0 g
s
.16376 .62085 m .16755 .67301 L .16066 .68664 L p .707 .577 .707 r
F P
0 g
s
.16755 .67301 m .16376 .62085 L .17994 .60822 L p .707 .577 .707 r
F P
0 g
s
.16051 .77283 m .16202 .78993 L .16515 .80411 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3446 .60265 m .34839 .6548 L .32725 .64593 L p .707 .577 .707 r
F P
0 g
s
.32725 .64593 m .32346 .59377 L .3446 .60265 L p .707 .577 .707 r
F P
0 g
s
.64153 .27298 m .63634 .77817 L .61856 .76787 L p .707 .577 .707 r
F P
0 g
s
.61856 .76787 m .62375 .26268 L .64153 .27298 L p .707 .577 .707 r
F P
0 g
s
.16202 .78993 m .16051 .77283 L .16733 .75822 L p .707 .577 .707 r
F P
0 g
s
.17994 .60822 m .18374 .66038 L .16755 .67301 L p .707 .577 .707 r
F P
0 g
s
.18374 .66038 m .17994 .60822 L .20383 .59782 L p .707 .577 .707 r
F P
0 g
s
.18165 .7034 m .17632 .74135 L .1608 .73681 L p .707 .577 .707 r
F P
0 g
s
.1608 .73681 m .16613 .69885 L .18165 .7034 L p .707 .577 .707 r
F P
0 g
s
.16733 .75822 m .16884 .77531 L .16202 .78993 L p .707 .577 .707 r
F P
0 g
s
.36258 .77109 m .36777 .2659 L .39088 .25666 L p .707 .577 .707 r
F P
0 g
s
.36777 .2659 m .36258 .77109 L .35259 .78175 L p .707 .577 .707 r
F P
0 g
s
.32346 .59377 m .32725 .64593 L .29977 .64071 L p .707 .577 .707 r
F P
0 g
s
.29977 .64071 m .29597 .58855 L .32346 .59377 L p .707 .577 .707 r
F P
0 g
s
.20762 .64998 m .20383 .59782 L .23308 .59068 L p .707 .577 .707 r
F P
0 g
s
.20383 .59782 m .20762 .64998 L .18374 .66038 L p .707 .577 .707 r
F P
0 g
s
.34524 .72561 m .33991 .76357 L .31847 .76259 L p .707 .577 .707 r
F P
0 g
s
.31847 .76259 m .3238 .72463 L .34524 .72561 L p .707 .577 .707 r
F P
0 g
s
.16884 .77531 m .16733 .75822 L .18343 .7446 L p .707 .577 .707 r
F P
0 g
s
.29597 .58855 m .29977 .64071 L .26862 .63964 L p .707 .577 .707 r
F P
0 g
s
.26862 .63964 m .26483 .58748 L .29597 .58855 L p .707 .577 .707 r
F P
0 g
s
.20494 .70849 m .19961 .74645 L .17632 .74135 L p .707 .577 .707 r
F P
0 g
s
.17632 .74135 m .18165 .7034 L .20494 .70849 L p .707 .577 .707 r
F P
0 g
s
.23687 .64284 m .23308 .59068 L .26483 .58748 L p .707 .577 .707 r
F P
0 g
s
.23308 .59068 m .23687 .64284 L .20762 .64998 L p .707 .577 .707 r
F P
0 g
s
.62375 .26268 m .61856 .76787 L .58883 .75929 L p .707 .577 .707 r
F P
0 g
s
.58883 .75929 m .59402 .2541 L .62375 .26268 L p .707 .577 .707 r
F P
0 g
s
.26483 .58748 m .26862 .63964 L .23687 .64284 L p .707 .577 .707 r
F P
0 g
s
.18343 .7446 m .18494 .76169 L .16884 .77531 L p .707 .577 .707 r
F P
0 g
s
.34796 .73742 m .34947 .75451 L .32829 .74519 L p .707 .577 .707 r
F P
0 g
s
.32829 .74519 m .32678 .72809 L .34796 .73742 L p .707 .577 .707 r
F P
0 g
s
.3238 .72463 m .31847 .76259 L .29088 .76008 L p .707 .577 .707 r
F P
0 g
s
.73263 .61936 m .70149 .61829 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73263 .61936 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73171 .68285 m .76316 .68755 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73171 .68285 L p .74231 .66137 L .707 .577 .707 r
F P
0 g
s
.74446 .65701 m .73536 .65685 L .74231 .66137 L .707 .577 .707 r
F
.73171 .68285 m .73536 .65685 L p .71473 .65528 L F P
0 g
s
.70067 .67906 m .73171 .68285 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .70067 .67906 L p .71186 .66014 L .707 .577 .707 r
F P
0 g
s
.71473 .65528 m .70412 .65448 L .71186 .66014 L .707 .577 .707 r
F
.70149 .61829 m .674 .61307 L p .69157 .6453 L F P
0 g
s
.69594 .6533 m .70412 .65448 L .69157 .6453 L .707 .577 .707 r
F
.70412 .65448 m .70149 .61829 L p .69157 .6453 L F P
0 g
s
.72041 .64711 m .7199 .64678 L .70529 .67045 L .707 .577 .707 r
F
.70275 .63562 m .70412 .65448 L p .7199 .64678 L F P
0 g
s
.70412 .65448 m .70529 .67045 L p .7199 .64678 L .707 .577 .707 r
F P
0 g
s
.70067 .67906 m .70412 .65448 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .70067 .67906 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67308 .67656 L p .6831 .65692 L .707 .577 .707 r
F P
0 g
s
.68569 .65184 m .67673 .65055 L .6831 .65692 L .707 .577 .707 r
F
.674 .61307 m .65286 .6042 L p .6684 .64221 L F P
0 g
s
.67126 .64921 m .67673 .65055 L .6684 .64221 L .707 .577 .707 r
F
.67673 .65055 m .674 .61307 L p .6684 .64221 L F P
0 g
s
.674 .61307 m .67673 .65055 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .67673 .65055 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .67308 .67656 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65164 .67558 L p .65919 .65144 L .707 .577 .707 r
F P
0 g
s
.66069 .64663 m .65586 .64545 L .65919 .65144 L .707 .577 .707 r
F
.65286 .6042 m .64014 .59254 L p .65206 .6386 L F P
0 g
s
.65586 .64545 m .65286 .6042 L p .65206 .6386 L .707 .577 .707 r
F P
0 g
s
.65286 .6042 m .65586 .64545 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .65586 .64545 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .64412 .63994 L .64385 .64165 L .707 .577 .707 r
F
.63844 .67622 m .64874 .67572 L p .64385 .64165 L F P
0 g
s
.64874 .67572 m .65164 .67558 L p .64385 .64165 L .707 .577 .707 r
F P
0 g
s
.64014 .59254 m .63707 .57925 L p .64297 .63552 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .63844 .67622 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.63844 .67622 m .64357 .63968 L p .64011 .64047 L .707 .577 .707 r
F P
0 g
s
.64335 .63918 m .64357 .63968 L .64297 .63552 L .707 .577 .707 r
F
.64357 .63968 m .64014 .59254 L p .64297 .63552 L F P
0 g
s
.64014 .59254 m .64357 .63968 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64313 .63865 m .64011 .64047 L p .64357 .63968 L .707 .577 .707 r
F P
0 g
s
.63707 .57925 m .64087 .63141 L .64093 .63169 L p .707 .577 .707 r
F P
0 g
s
.64093 .63169 m .64393 .6447 L p .63931 .60063 L .707 .577 .707 r
F P
0 g
s
.63931 .60063 m .63707 .57925 L .64093 .63169 L .707 .577 .707 r
F
.64011 .64047 m .63478 .67843 L .63844 .67622 L p F P
0 g
s
.63478 .67843 m .64011 .64047 L .64143 .64122 L p .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .64357 .63968 L p .64335 .63918 L .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .65666 .65635 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .64393 .6447 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64143 .64122 m .64634 .64402 L p .64222 .6563 L .707 .577 .707 r
F P
0 g
s
.63478 .67843 m .64143 .64122 L .64222 .6563 L .707 .577 .707 r
F
.64357 .63968 m .64377 .63827 L .64313 .63865 L p F P
0 g
s
.64377 .63827 m .64357 .63968 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .64377 .63827 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65355 .64437 m .65586 .64545 L .65206 .6386 L .707 .577 .707 r
F
.65586 .64545 m .65696 .63762 L p .64412 .63994 L F P
0 g
s
.65666 .65635 m .65586 .64545 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.65666 .65635 m .6778 .66523 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65666 .65635 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .65586 .64545 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .65696 .63762 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67841 .6386 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .67673 .65055 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .70529 .67045 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .6778 .66523 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .67673 .65055 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .67841 .6386 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .706 .64111 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .70412 .65448 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .70412 .65448 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .73643 .67152 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.72635 .65616 m .72041 .64711 L .71509 .65531 L .707 .577 .707 r
F
.72635 .65616 m .71509 .65531 L .70529 .67045 L F
.70149 .61829 m .70275 .63562 L p .72041 .64711 L F P
0 g
s
.73263 .61936 m .73536 .65685 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .73263 .61936 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76438 .61617 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .79193 .6927 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76316 .68755 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .76739 .65742 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .76438 .61617 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79363 .60902 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .79706 .65616 L p .82131 .65078 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .81522 .69779 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79193 .6927 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.81362 .65413 m .82131 .65078 L p .79706 .65616 L .707 .577 .707 r
F P
0 g
s
.81522 .69779 m .82055 .65984 L .79726 .65474 L p .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79743 .66118 L .81362 .65413 L p .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .79706 .65616 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .76849 .64959 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .79706 .65616 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79726 .65474 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79743 .66118 m .79706 .65616 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .79743 .66118 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76818 .66832 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .76739 .65742 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .73704 .6449 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .76739 .65742 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76849 .64959 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .76739 .65742 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .76818 .66832 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73643 .67152 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .73536 .65685 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .706 .64111 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73704 .6449 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .73536 .65685 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.39088 .25666 m .38569 .76185 L .36258 .77109 L p .707 .577 .707 r
F P
0 g
s
.38569 .76185 m .39088 .25666 L .42483 .24972 L p .707 .577 .707 r
F P
0 g
s
.29088 .76008 m .2962 .72213 L .3238 .72463 L p .707 .577 .707 r
F P
0 g
s
.19961 .74645 m .20494 .70849 L .23372 .71364 L p .707 .577 .707 r
F P
0 g
s
.18494 .76169 m .18343 .7446 L .20724 .73331 L p .707 .577 .707 r
F P
0 g
s
.23372 .71364 m .22839 .7516 L .19961 .74645 L p .707 .577 .707 r
F P
0 g
s
.32678 .72809 m .32829 .74519 L .30079 .7398 L p .707 .577 .707 r
F P
0 g
s
.30079 .7398 m .29928 .72271 L .32678 .72809 L p .707 .577 .707 r
F P
0 g
s
.20724 .73331 m .20875 .7504 L .18494 .76169 L p .707 .577 .707 r
F P
0 g
s
.82131 .65078 m .81752 .59862 L .79363 .60902 L p .707 .577 .707 r
F P
0 g
s
.2962 .72213 m .29088 .76008 L .25984 .7563 L p .707 .577 .707 r
F P
0 g
s
.25984 .7563 m .26517 .71834 L .2962 .72213 L p .707 .577 .707 r
F P
0 g
s
.26517 .71834 m .25984 .7563 L .22839 .7516 L p .707 .577 .707 r
F P
0 g
s
.22839 .7516 m .23372 .71364 L .26517 .71834 L p .707 .577 .707 r
F P
0 g
s
.59402 .2541 m .58883 .75929 L .55006 .75327 L p .707 .577 .707 r
F P
0 g
s
.55006 .75327 m .55525 .24808 L .59402 .2541 L p .707 .577 .707 r
F P
0 g
s
.20875 .7504 m .20724 .73331 L .23644 .72545 L p .707 .577 .707 r
F P
0 g
s
.29928 .72271 m .30079 .7398 L .26966 .73889 L p .707 .577 .707 r
F P
0 g
s
.26966 .73889 m .26815 .7218 L .29928 .72271 L p .707 .577 .707 r
F P
0 g
s
.23644 .72545 m .23795 .74254 L .20875 .7504 L p .707 .577 .707 r
F P
0 g
s
.41964 .75491 m .42483 .24972 L .4663 .24578 L p .707 .577 .707 r
F P
0 g
s
.42483 .24972 m .41964 .75491 L .38569 .76185 L p .707 .577 .707 r
F P
0 g
s
.23795 .74254 m .23644 .72545 L .26815 .7218 L p .707 .577 .707 r
F P
0 g
s
.81752 .59862 m .82131 .65078 L .8375 .63815 L p .707 .577 .707 r
F P
0 g
s
.8375 .63815 m .8337 .58599 L .81752 .59862 L p .707 .577 .707 r
F P
0 g
s
.26815 .7218 m .26966 .73889 L .23795 .74254 L p .707 .577 .707 r
F P
0 g
s
.55525 .24808 m .55006 .75327 L .50606 .7504 L p .707 .577 .707 r
F P
0 g
s
.50606 .7504 m .51125 .24521 L .55525 .24808 L p .707 .577 .707 r
F P
0 g
s
.46112 .75097 m .4663 .24578 L .51125 .24521 L p .707 .577 .707 r
F P
0 g
s
.4663 .24578 m .46112 .75097 L .41964 .75491 L p .707 .577 .707 r
F P
0 g
s
.73796 .7754 m .73645 .7583 L .70532 .75739 L p .707 .577 .707 r
F P
0 g
s
.73645 .7583 m .73796 .7754 L .76967 .77175 L p .707 .577 .707 r
F P
0 g
s
.76967 .77175 m .76816 .75465 L .73645 .7583 L p .707 .577 .707 r
F P
0 g
s
.76816 .75465 m .76967 .77175 L .79886 .76389 L p .707 .577 .707 r
F P
0 g
s
.79886 .76389 m .79735 .74679 L .76816 .75465 L p .707 .577 .707 r
F P
0 g
s
.51125 .24521 m .50606 .7504 L .46112 .75097 L p .707 .577 .707 r
F P
0 g
s
.82055 .65984 m .81522 .69779 L .83075 .70234 L p .707 .577 .707 r
F P
0 g
s
.8337 .58599 m .8375 .63815 L .8444 .62452 L p .707 .577 .707 r
F P
0 g
s
.8444 .62452 m .8406 .57236 L .8337 .58599 L p .707 .577 .707 r
F P
0 g
s
.70683 .77449 m .70532 .75739 L .67782 .75201 L p .707 .577 .707 r
F P
0 g
s
.70532 .75739 m .70683 .77449 L .73796 .7754 L p .707 .577 .707 r
F P
0 g
s
.83075 .70234 m .83607 .66438 L .82055 .65984 L p .707 .577 .707 r
F P
0 g
s
.79735 .74679 m .79886 .76389 L .82268 .7526 L p .707 .577 .707 r
F P
0 g
s
.82268 .7526 m .82117 .7355 L .79735 .74679 L p .707 .577 .707 r
F P
0 g
s
.67782 .75201 m .67933 .7691 L .70683 .77449 L p .707 .577 .707 r
F P
0 g
s
.67933 .7691 m .67782 .75201 L .65664 .74268 L p .707 .577 .707 r
F P
0 g
s
.82117 .7355 m .82268 .7526 L .83878 .73898 L p .707 .577 .707 r
F P
0 g
s
.83878 .73898 m .83727 .72188 L .82117 .7355 L p .707 .577 .707 r
F P
0 g
s
.65664 .74268 m .65815 .75978 L .67933 .7691 L p .707 .577 .707 r
F P
0 g
s
.83607 .66438 m .83075 .70234 L .83698 .70588 L p .707 .577 .707 r
F P
0 g
s
.83698 .70588 m .84231 .66793 L .83607 .66438 L p .707 .577 .707 r
F P
0 g
s
.8406 .57236 m .8444 .62452 L .84133 .61123 L p .707 .577 .707 r
F P
0 g
s
.84133 .61123 m .83754 .55907 L .8406 .57236 L p .707 .577 .707 r
F P
0 g
s
.65815 .75978 m .65664 .74268 L .64386 .73032 L p .707 .577 .707 r
F P
0 g
s
.64087 .63141 m .63707 .57925 L .64397 .56563 L p .707 .577 .707 r
F P
0 g
s
.64386 .73032 m .64537 .74741 L .65815 .75978 L p .707 .577 .707 r
F P
0 g
s
.83727 .72188 m .83878 .73898 L .8456 .72436 L p .707 .577 .707 r
F P
0 g
s
.8456 .72436 m .84409 .70726 L .83727 .72188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84231 .66793 m .83698 .70588 L .83332 .70809 L p .707 .577 .707 r
F P
0 g
s
.83754 .55907 m .84133 .61123 L .82861 .59958 L p .707 .577 .707 r
F P
0 g
s
.82861 .59958 m .82481 .54742 L .83754 .55907 L p .707 .577 .707 r
F P
0 g
s
.83332 .70809 m .83865 .67013 L .84231 .66793 L p .707 .577 .707 r
F P
0 g
s
.64537 .74741 m .64386 .73032 L .64072 .71614 L p .707 .577 .707 r
F P
0 g
s
.64634 .64402 m .64101 .68197 L .63478 .67843 L p .707 .577 .707 r
F P
0 g
s
.64397 .56563 m .64777 .61778 L .64087 .63141 L p .707 .577 .707 r
F P
0 g
s
.64072 .71614 m .64223 .73323 L .64537 .74741 L p .707 .577 .707 r
F P
0 g
s
.64777 .61778 m .64397 .56563 L .66015 .553 L p .707 .577 .707 r
F P
0 g
s
.84409 .70726 m .8456 .72436 L .84247 .71018 L p .707 .577 .707 r
F P
0 g
s
.84247 .71018 m .84095 .69308 L .84409 .70726 L p .707 .577 .707 r
F P
0 g
s
.38962 .58255 m .35848 .58148 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .38962 .58255 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.3887 .64603 m .42015 .65073 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .3887 .64603 L p .3993 .62455 L .707 .577 .707 r
F P
0 g
s
.40145 .62019 m .39235 .62003 L .3993 .62455 L .707 .577 .707 r
F
.3887 .64603 m .39235 .62003 L p .37172 .61847 L F P
0 g
s
.35766 .64225 m .3887 .64603 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .35766 .64225 L p .36885 .62332 L .707 .577 .707 r
F P
0 g
s
.37172 .61847 m .36111 .61766 L .36885 .62332 L .707 .577 .707 r
F
.35848 .58148 m .33099 .57625 L p .34856 .60848 L F P
0 g
s
.35293 .61649 m .36111 .61766 L .34856 .60848 L .707 .577 .707 r
F
.36111 .61766 m .35848 .58148 L p .34856 .60848 L F P
0 g
s
.3774 .61029 m .37689 .60996 L .36228 .63364 L .707 .577 .707 r
F
.35974 .5988 m .36111 .61766 L p .37689 .60996 L F P
0 g
s
.36111 .61766 m .36228 .63364 L p .37689 .60996 L .707 .577 .707 r
F P
0 g
s
.35766 .64225 m .36111 .61766 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .35766 .64225 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33007 .63974 L p .34009 .62011 L .707 .577 .707 r
F P
0 g
s
.34268 .61502 m .33372 .61374 L .34009 .62011 L .707 .577 .707 r
F
.33099 .57625 m .30985 .56738 L p .32539 .6054 L F P
0 g
s
.32825 .6124 m .33372 .61374 L .32539 .6054 L .707 .577 .707 r
F
.33372 .61374 m .33099 .57625 L p .32539 .6054 L F P
0 g
s
.33099 .57625 m .33372 .61374 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .33372 .61374 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .33007 .63974 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .30863 .63876 L p .31618 .61463 L .707 .577 .707 r
F P
0 g
s
.31768 .60982 m .31285 .60864 L .31618 .61463 L .707 .577 .707 r
F
.30985 .56738 m .29713 .55573 L p .30905 .60178 L F P
0 g
s
.31285 .60864 m .30985 .56738 L p .30905 .60178 L .707 .577 .707 r
F P
0 g
s
.30985 .56738 m .31285 .60864 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .31285 .60864 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .30111 .60312 L .30084 .60484 L .707 .577 .707 r
F
.29543 .63941 m .30573 .6389 L p .30084 .60484 L F P
0 g
s
.30573 .6389 m .30863 .63876 L p .30084 .60484 L .707 .577 .707 r
F P
0 g
s
.29713 .55573 m .29406 .54244 L p .29996 .59871 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .29543 .63941 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.29543 .63941 m .30056 .60286 L p .2971 .60365 L .707 .577 .707 r
F P
0 g
s
.30034 .60237 m .30056 .60286 L .29996 .59871 L .707 .577 .707 r
F
.30056 .60286 m .29713 .55573 L p .29996 .59871 L F P
0 g
s
.29713 .55573 m .30056 .60286 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30012 .60184 m .2971 .60365 L p .30056 .60286 L .707 .577 .707 r
F P
0 g
s
.29406 .54244 m .29786 .5946 L .29792 .59487 L p .707 .577 .707 r
F P
0 g
s
.29792 .59487 m .30092 .60789 L p .2963 .56382 L .707 .577 .707 r
F P
0 g
s
.2963 .56382 m .29406 .54244 L .29792 .59487 L .707 .577 .707 r
F
.2971 .60365 m .29177 .64161 L .29543 .63941 L p F P
0 g
s
.29177 .64161 m .2971 .60365 L .29842 .60441 L p .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .30056 .60286 L p .30034 .60237 L .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .31365 .61954 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .30092 .60789 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.29842 .60441 m .30333 .6072 L p .2992 .61948 L .707 .577 .707 r
F P
0 g
s
.29177 .64161 m .29842 .60441 L .2992 .61948 L .707 .577 .707 r
F
.30056 .60286 m .30076 .60145 L .30012 .60184 L p F P
0 g
s
.30076 .60145 m .30056 .60286 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .30076 .60145 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31054 .60755 m .31285 .60864 L .30905 .60178 L .707 .577 .707 r
F
.31285 .60864 m .31395 .60081 L p .30111 .60312 L F P
0 g
s
.31365 .61954 m .31285 .60864 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.31365 .61954 m .33479 .62841 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .31365 .61954 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .31285 .60864 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .31395 .60081 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .3354 .60179 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .33372 .61374 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .36228 .63364 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33479 .62841 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .33372 .61374 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .3354 .60179 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .36299 .60429 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .36111 .61766 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .36111 .61766 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .39342 .6347 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.38334 .61935 m .3774 .61029 L .37208 .61849 L .707 .577 .707 r
F
.38334 .61935 m .37208 .61849 L .36228 .63364 L F
.35848 .58148 m .35974 .5988 L p .3774 .61029 L F P
0 g
s
.38962 .58255 m .39235 .62003 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .38962 .58255 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42137 .57935 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .44892 .65588 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42015 .65073 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .42438 .62061 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .42137 .57935 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45062 .5722 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .45405 .61934 L p .4783 .61396 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .47221 .66098 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .44892 .65588 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.47061 .61731 m .4783 .61396 L p .45405 .61934 L .707 .577 .707 r
F P
0 g
s
.47221 .66098 m .47754 .62302 L .45425 .61793 L p .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45442 .62436 L .47061 .61731 L p .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .45405 .61934 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .42548 .61278 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .45405 .61934 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45425 .61793 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45442 .62436 m .45405 .61934 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .45442 .62436 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42517 .63151 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .42438 .62061 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .39403 .60808 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .42438 .62061 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42548 .61278 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .42438 .62061 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .42517 .63151 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39342 .6347 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .39235 .62003 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .36299 .60429 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39403 .60808 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .39235 .62003 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82481 .54742 m .82861 .59958 L .80747 .59071 L p .707 .577 .707 r
F P
0 g
s
.80747 .59071 m .80367 .53855 L .82481 .54742 L p .707 .577 .707 r
F P
0 g
s
.83865 .67013 m .83332 .70809 L .82013 .70873 L p .707 .577 .707 r
F P
0 g
s
.4783 .61396 m .47451 .56181 L .45062 .5722 L p .707 .577 .707 r
F P
0 g
s
.82013 .70873 m .82545 .67077 L .83865 .67013 L p .707 .577 .707 r
F P
0 g
s
.64223 .73323 m .64072 .71614 L .64754 .70152 L p .707 .577 .707 r
F P
0 g
s
.66015 .553 m .66395 .60515 L .64777 .61778 L p .707 .577 .707 r
F P
0 g
s
.66395 .60515 m .66015 .553 L .68404 .5426 L p .707 .577 .707 r
F P
0 g
s
.66187 .64856 m .65654 .68652 L .64101 .68197 L p .707 .577 .707 r
F P
0 g
s
.64101 .68197 m .64634 .64402 L .66187 .64856 L p .707 .577 .707 r
F P
0 g
s
.64754 .70152 m .64905 .71861 L .64223 .73323 L p .707 .577 .707 r
F P
0 g
s
.84095 .69308 m .84247 .71018 L .82968 .69782 L p .707 .577 .707 r
F P
0 g
s
.82968 .69782 m .82817 .68072 L .84095 .69308 L p .707 .577 .707 r
F P
0 g
s
.80367 .53855 m .80747 .59071 L .77998 .58548 L p .707 .577 .707 r
F P
0 g
s
.77998 .58548 m .77618 .53332 L .80367 .53855 L p .707 .577 .707 r
F P
0 g
s
.47451 .56181 m .4783 .61396 L .49449 .60133 L p .707 .577 .707 r
F P
0 g
s
.49449 .60133 m .49069 .54918 L .47451 .56181 L p .707 .577 .707 r
F P
0 g
s
.68784 .59476 m .68404 .5426 L .71329 .53545 L p .707 .577 .707 r
F P
0 g
s
.68404 .5426 m .68784 .59476 L .66395 .60515 L p .707 .577 .707 r
F P
0 g
s
.82545 .67077 m .82013 .70873 L .79868 .70775 L p .707 .577 .707 r
F P
0 g
s
.79868 .70775 m .80401 .6698 L .82545 .67077 L p .707 .577 .707 r
F P
0 g
s
.68516 .65366 m .67983 .69161 L .65654 .68652 L p .707 .577 .707 r
F P
0 g
s
.64905 .71861 m .64754 .70152 L .66364 .6879 L p .707 .577 .707 r
F P
0 g
s
.77618 .53332 m .77998 .58548 L .74884 .58441 L p .707 .577 .707 r
F P
0 g
s
.74884 .58441 m .74504 .53226 L .77618 .53332 L p .707 .577 .707 r
F P
0 g
s
.39495 .73858 m .39344 .72149 L .36231 .72058 L p .707 .577 .707 r
F P
0 g
s
.39344 .72149 m .39495 .73858 L .42666 .73493 L p .707 .577 .707 r
F P
0 g
s
.42666 .73493 m .42515 .71783 L .39344 .72149 L p .707 .577 .707 r
F P
0 g
s
.65654 .68652 m .66187 .64856 L .68516 .65366 L p .707 .577 .707 r
F P
0 g
s
.42515 .71783 m .42666 .73493 L .45585 .72707 L p .707 .577 .707 r
F P
0 g
s
.45585 .72707 m .45434 .70998 L .42515 .71783 L p .707 .577 .707 r
F P
0 g
s
.71709 .58761 m .71329 .53545 L .74504 .53226 L p .707 .577 .707 r
F P
0 g
s
.71329 .53545 m .71709 .58761 L .68784 .59476 L p .707 .577 .707 r
F P
0 g
s
.74504 .53226 m .74884 .58441 L .71709 .58761 L p .707 .577 .707 r
F P
0 g
s
.66364 .6879 m .66515 .70499 L .64905 .71861 L p .707 .577 .707 r
F P
0 g
s
.47754 .62302 m .47221 .66098 L .48774 .66552 L p .707 .577 .707 r
F P
0 g
s
.82817 .68072 m .82968 .69782 L .80851 .68849 L p .707 .577 .707 r
F P
0 g
s
.80851 .68849 m .807 .67139 L .82817 .68072 L p .707 .577 .707 r
F P
0 g
s
.49069 .54918 m .49449 .60133 L .50139 .58771 L p .707 .577 .707 r
F P
0 g
s
.50139 .58771 m .49759 .53555 L .49069 .54918 L p .707 .577 .707 r
F P
0 g
s
.36382 .73767 m .36231 .72058 L .33481 .71519 L p .707 .577 .707 r
F P
0 g
s
.36231 .72058 m .36382 .73767 L .39495 .73858 L p .707 .577 .707 r
F P
0 g
s
.48774 .66552 m .49306 .62757 L .47754 .62302 L p .707 .577 .707 r
F P
0 g
s
.45434 .70998 m .45585 .72707 L .47967 .71578 L p .707 .577 .707 r
F P
0 g
s
.47967 .71578 m .47816 .69869 L .45434 .70998 L p .707 .577 .707 r
F P
0 g
s
.80401 .6698 m .79868 .70775 L .77109 .70524 L p .707 .577 .707 r
F P
0 g
s
.33481 .71519 m .33632 .73229 L .36382 .73767 L p .707 .577 .707 r
F P
0 g
s
.77109 .70524 m .77642 .66729 L .80401 .6698 L p .707 .577 .707 r
F P
0 g
s
.67983 .69161 m .68516 .65366 L .71393 .6588 L p .707 .577 .707 r
F P
0 g
s
.66515 .70499 m .66364 .6879 L .68746 .67661 L p .707 .577 .707 r
F P
0 g
s
.71393 .6588 m .7086 .69676 L .67983 .69161 L p .707 .577 .707 r
F P
0 g
s
.33632 .73229 m .33481 .71519 L .31363 .70586 L p .707 .577 .707 r
F P
0 g
s
.807 .67139 m .80851 .68849 L .78101 .6831 L p .707 .577 .707 r
F P
0 g
s
.78101 .6831 m .7795 .66601 L .807 .67139 L p .707 .577 .707 r
F P
0 g
s
.68746 .67661 m .68897 .6937 L .66515 .70499 L p .707 .577 .707 r
F P
0 g
s
.47816 .69869 m .47967 .71578 L .49577 .70216 L p .707 .577 .707 r
F P
0 g
s
.49577 .70216 m .49426 .68507 L .47816 .69869 L p .707 .577 .707 r
F P
0 g
s
.77642 .66729 m .77109 .70524 L .74005 .70146 L p .707 .577 .707 r
F P
0 g
s
.31363 .70586 m .31514 .72296 L .33632 .73229 L p .707 .577 .707 r
F P
0 g
s
.49306 .62757 m .48774 .66552 L .49397 .66907 L p .707 .577 .707 r
F P
0 g
s
.74005 .70146 m .74538 .6635 L .77642 .66729 L p .707 .577 .707 r
F P
0 g
s
.74538 .6635 m .74005 .70146 L .7086 .69676 L p .707 .577 .707 r
F P
0 g
s
.7086 .69676 m .71393 .6588 L .74538 .6635 L p .707 .577 .707 r
F P
0 g
s
.49397 .66907 m .4993 .63111 L .49306 .62757 L p .707 .577 .707 r
F P
0 g
s
.49759 .53555 m .50139 .58771 L .49832 .57442 L p .707 .577 .707 r
F P
0 g
s
.49832 .57442 m .49453 .52226 L .49759 .53555 L p .707 .577 .707 r
F P
0 g
s
.68897 .6937 m .68746 .67661 L .71665 .66875 L p .707 .577 .707 r
F P
0 g
s
.7795 .66601 m .78101 .6831 L .74987 .68219 L p .707 .577 .707 r
F P
0 g
s
.74987 .68219 m .74836 .6651 L .7795 .66601 L p .707 .577 .707 r
F P
0 g
s
.31514 .72296 m .31363 .70586 L .30085 .6935 L p .707 .577 .707 r
F P
0 g
s
.71665 .66875 m .71816 .68585 L .68897 .6937 L p .707 .577 .707 r
F P
0 g
s
.71816 .68585 m .71665 .66875 L .74836 .6651 L p .707 .577 .707 r
F P
0 g
s
.74836 .6651 m .74987 .68219 L .71816 .68585 L p .707 .577 .707 r
F P
0 g
s
.29786 .5946 m .29406 .54244 L .30096 .52881 L p .707 .577 .707 r
F P
0 g
s
.30085 .6935 m .30236 .7106 L .31514 .72296 L p .707 .577 .707 r
F P
0 g
s
.49426 .68507 m .49577 .70216 L .50259 .68754 L p .707 .577 .707 r
F P
0 g
s
.50259 .68754 m .50108 .67045 L .49426 .68507 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4993 .63111 m .49397 .66907 L .49031 .67127 L p .707 .577 .707 r
F P
0 g
s
.49453 .52226 m .49832 .57442 L .4856 .56276 L p .707 .577 .707 r
F P
0 g
s
.4856 .56276 m .4818 .51061 L .49453 .52226 L p .707 .577 .707 r
F P
0 g
s
.49031 .67127 m .49564 .63332 L .4993 .63111 L p .707 .577 .707 r
F P
0 g
s
.30236 .7106 m .30085 .6935 L .29771 .67932 L p .707 .577 .707 r
F P
0 g
s
.30333 .6072 m .298 .64516 L .29177 .64161 L p .707 .577 .707 r
F P
0 g
s
.30096 .52881 m .30476 .58097 L .29786 .5946 L p .707 .577 .707 r
F P
0 g
s
.29771 .67932 m .29922 .69642 L .30236 .7106 L p .707 .577 .707 r
F P
0 g
s
.30476 .58097 m .30096 .52881 L .31714 .51618 L p .707 .577 .707 r
F P
0 g
s
.50108 .67045 m .50259 .68754 L .49945 .67336 L p .707 .577 .707 r
F P
0 g
s
.49945 .67336 m .49794 .65627 L .50108 .67045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4818 .51061 m .4856 .56276 L .46446 .55389 L p .707 .577 .707 r
F P
0 g
s
.46446 .55389 m .46066 .50173 L .4818 .51061 L p .707 .577 .707 r
F P
0 g
s
.49564 .63332 m .49031 .67127 L .47712 .67191 L p .707 .577 .707 r
F P
0 g
s
.47712 .67191 m .48244 .63396 L .49564 .63332 L p .707 .577 .707 r
F P
0 g
s
.29922 .69642 m .29771 .67932 L .30453 .6647 L p .707 .577 .707 r
F P
0 g
s
.31714 .51618 m .32094 .56834 L .30476 .58097 L p .707 .577 .707 r
F P
0 g
s
.32094 .56834 m .31714 .51618 L .34103 .50578 L p .707 .577 .707 r
F P
0 g
s
.31886 .61174 m .31353 .6497 L .298 .64516 L p .707 .577 .707 r
F P
0 g
s
.298 .64516 m .30333 .6072 L .31886 .61174 L p .707 .577 .707 r
F P
0 g
s
.30453 .6647 m .30604 .6818 L .29922 .69642 L p .707 .577 .707 r
F P
0 g
s
.49794 .65627 m .49945 .67336 L .48667 .661 L p .707 .577 .707 r
F P
0 g
s
.48667 .661 m .48516 .6439 L .49794 .65627 L p .707 .577 .707 r
F P
0 g
s
.46066 .50173 m .46446 .55389 L .43697 .54867 L p .707 .577 .707 r
F P
0 g
s
.43697 .54867 m .43317 .49651 L .46066 .50173 L p .707 .577 .707 r
F P
0 g
s
.34483 .55794 m .34103 .50578 L .37028 .49864 L p .707 .577 .707 r
F P
0 g
s
.34103 .50578 m .34483 .55794 L .32094 .56834 L p .707 .577 .707 r
F P
0 g
s
.48244 .63396 m .47712 .67191 L .45567 .67094 L p .707 .577 .707 r
F P
0 g
s
.45567 .67094 m .461 .63298 L .48244 .63396 L p .707 .577 .707 r
F P
0 g
s
.34215 .61684 m .33682 .6548 L .31353 .6497 L p .707 .577 .707 r
F P
0 g
s
.30604 .6818 m .30453 .6647 L .32063 .65108 L p .707 .577 .707 r
F P
0 g
s
.43317 .49651 m .43697 .54867 L .40583 .5476 L p .707 .577 .707 r
F P
0 g
s
.40583 .5476 m .40203 .49544 L .43317 .49651 L p .707 .577 .707 r
F P
0 g
s
.31353 .6497 m .31886 .61174 L .34215 .61684 L p .707 .577 .707 r
F P
0 g
s
.37408 .55079 m .37028 .49864 L .40203 .49544 L p .707 .577 .707 r
F P
0 g
s
.37028 .49864 m .37408 .55079 L .34483 .55794 L p .707 .577 .707 r
F P
0 g
s
.40203 .49544 m .40583 .5476 L .37408 .55079 L p .707 .577 .707 r
F P
0 g
s
.32063 .65108 m .32214 .66818 L .30604 .6818 L p .707 .577 .707 r
F P
0 g
s
.48516 .6439 m .48667 .661 L .46549 .65167 L p .707 .577 .707 r
F P
0 g
s
.46549 .65167 m .46398 .63458 L .48516 .6439 L p .707 .577 .707 r
F P
0 g
s
.461 .63298 m .45567 .67094 L .42808 .66843 L p .707 .577 .707 r
F P
0 g
s
.42808 .66843 m .43341 .63047 L .461 .63298 L p .707 .577 .707 r
F P
0 g
s
.33682 .6548 m .34215 .61684 L .37092 .62199 L p .707 .577 .707 r
F P
0 g
s
.32214 .66818 m .32063 .65108 L .34445 .63979 L p .707 .577 .707 r
F P
0 g
s
.37092 .62199 m .36559 .65994 L .33682 .6548 L p .707 .577 .707 r
F P
0 g
s
.46398 .63458 m .46549 .65167 L .43799 .64629 L p .707 .577 .707 r
F P
0 g
s
.43799 .64629 m .43648 .62919 L .46398 .63458 L p .707 .577 .707 r
F P
0 g
s
.34445 .63979 m .34596 .65689 L .32214 .66818 L p .707 .577 .707 r
F P
0 g
s
.43341 .63047 m .42808 .66843 L .39704 .66464 L p .707 .577 .707 r
F P
0 g
s
.39704 .66464 m .40237 .62669 L .43341 .63047 L p .707 .577 .707 r
F P
0 g
s
.40237 .62669 m .39704 .66464 L .36559 .65994 L p .707 .577 .707 r
F P
0 g
s
.36559 .65994 m .37092 .62199 L .40237 .62669 L p .707 .577 .707 r
F P
0 g
s
.34596 .65689 m .34445 .63979 L .37364 .63194 L p .707 .577 .707 r
F P
0 g
s
.43648 .62919 m .43799 .64629 L .40686 .64538 L p .707 .577 .707 r
F P
0 g
s
.40686 .64538 m .40535 .62828 L .43648 .62919 L p .707 .577 .707 r
F P
0 g
s
.37364 .63194 m .37515 .64903 L .34596 .65689 L p .707 .577 .707 r
F P
0 g
s
.37515 .64903 m .37364 .63194 L .40535 .62828 L p .707 .577 .707 r
F P
0 g
s
.40535 .62828 m .40686 .64538 L .37515 .64903 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00LWoo10000UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001^Ool40006FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool0
06Yoo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001P0015YF00<005YF
FUH00UYF200015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001POol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000GOol?000oOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Qoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF1@001EYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00Dgoo00@005YFFUH000AJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEP000003FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00@005YFFUH000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00`0000EJEP00FUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005Ool00000FUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00@005YF000000Eoo`04001JEUYF
0006FUH50004FUH00`00FUIJEP09FUH40002FUH20002FUH200000eYF001JEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
001COol01000FUIJEP0015YF0P001goo00@005YFFUH000IJEPD000AJEP03001JEUYF00QJEP80009J
EP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF0`00
1goo00@005YFFUH000IJEPD000AJEP03001JEUYF00AJEP@000AJEP03001JEUYF009JEP@00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH20003FUH30004Ool01000FUIJEP001UYF1000
1EYF00<005YFFUH010000UYF00<005YFFUH00eYF00<005YFFUH00UYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP00;Woo001DOol00`00FUH000020005FUH00`00FUH000040002FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH70006FUH00`00FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo001DOol01@00FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00@Goo5@000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000moo`@0009JEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool003ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000IOol40004FUH0
1@00FUIJEUYF0000;Goo000kOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF10002goo0`004goo0`0000=JEP00FUH00UYF
00<007ooOol0:goo000hOol30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH40002FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000=JEP04001JEUYFFUH2000>Ool5000BOol200000eYF00000003FUH00`00Oomoo`0[Ool0
03Eoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EUYF010000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00@005YF0000011oo`D0011oo`800003FUH005YF009JEP04001JEUYF000]Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP@000IJEP03001JEUYF00EJEP03001J
EUYF009JEPH000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP80019o
o`D000ioo`8000=JEP03001JEUYF009JEP<002eoo`00<Woo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP<001=oo`<000aoo`<000EJ
EP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPL000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH5000IOol400000eYF
001JEP05FUH00`00FUIJEP02FUH01000FUH00000;7oo000_Ool01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000UYF0P002EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEPT0
00Uoo`L000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP04FUH40003FUH40005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH@0002FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00000`00
1EYF00<005YFFUH00eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00005FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP`00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFOol5FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00004FUH005YF0004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP0200000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/
Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`800003FUH005YF
00=JEP03001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00800004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH010004Goo10000UYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF
009JEPl000IJEP04001JEUYFFUH20002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo000/Ool01000FUIJEP0015YF00<0
05YFFUH00eYF10006Goo100000=JEP00000015YF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH2000bOol002aoo`04001JEUYF0004FUH01000
FUIJEUYF0P003Woo0`0047oo00<005YFFUH015YF00<005YFFUH0100025YF00<005YFFUH01UYF00<0
05YFFUH01EYF10000eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001oogoo035oo`00;7oo00@005YF
FUH000AJEP04001JEP00000?Ool5000>Ool20006FUH30002FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUH00004
0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH7000dOol002aoo`04001JEUYF0004FUH2000AOol5
000<Ool200000eYF001JEP03FUH200000eYF000000050006FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00eYF1`000UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00001P00<Woo000]Ool00`00FUH00003FUH00`00Oomoo`0AOol5
000;Ool01@00FUIJEUYF00000UYF0P0015YF00@005YFFUH0009JEP@0009JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPT0009JEP03001JEUYF00AJEP<000EJEP03001JEP00008002moo`00;Goo00@005YF001J
EP800003FUH00000019oo`<000Qoo`@000AJEP<00003FUH005YF00=JEP04001JEUYF0005FUH80004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00=JEQ400003FUH005YF00EJEP03001JEUYF009JEP8002eoo`00;Goo00<005YF00000P00
15YF1@004Goo1`000UYF0P0015YF00D005YFFUIJEP0000AJEP04001JEUYF0005FUH00`00FUIJEP05
FUH?0003FUH00`00FUIJEP06000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP06FUH01000FUIJ
EUYF3`00;Goo000]Ool01@00FUH005YF00001EYF00@005YFFUIJEQ4000AJEP03001JEUYF009JEP80
00=JEP03001JEUYF009JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH70003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH30002FUH01000FUIJEUYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`001EYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP<000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001o
ogoo02aoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP00009JEP03001JEP0000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00
FUIJEP04FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000000^Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH00`00FUH00006FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000800003FUH005YF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00@000IJEPP0
00AJEP03001JEUYF00=JEP@002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000Woo1@001EYF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00@005YF000002ioo`00;Goo
0P000UYF10000UYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004Ool20006FUH00`00FUIJEP040008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH01000FUIJEP00;Woo000]Ool00`00FUIJEP02FUH00`00FUIJEP0@0003
FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00UJEP03001JEUYF009JEP04001JEUYFFUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool00`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0[Ool002eoo`05FUH00000FUH00006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH60006FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP0000AJ
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
Ool01@00FUIJEUYF00000eYF0P000eYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`000eYF00<007ooOol0:goo000]Ool2FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000030002FUH01P00FUIJEUYF001JEP800003FUH005YF00AJEP<00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020004FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001JEP000080
00AJEP03001JEP0000Eoo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00Oomoo`0[Ool002aoo`04001JEUYF0002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7
0003FUH20005FUH01@00Oomoogoo00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF0P000UYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00008000AJEP80009JEP03001JEUYF009JEP04001JEP00000=Ool8
0004FUH00`00FUIJEP03FUH00`00FUIJEP04000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0`000UYF0P0017oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF
009JEP03001JEUYF009JEP04001JEP00000EOol>0002Ool00`00Oomoo`0[Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH00`001Goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP06001JEP00FUH005YF0P001EYF00<005YFFUH00UYF00@005YFFUH002Aoo`8002eoo`00;7oo0UYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100025YF00<005YFFUH0
0UYF00@005YFFUH000AJEPD00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP030004
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0`001UYF00<005YFFUH00UYF00@005YFFUH000Moo`<001Yoo`8002eo
o`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1`00
00AJEP00FUIJEPH000EJEP04001JEUYFFUH80002FUH00`00FUIJEP04FUH60007FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF
001JEP00FUH00007FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000/Ool2FUH0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000[Ool01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo00Ioo`D001Moo`80009JEP03001oogoo02Yoo`00:goo00<005YF
000015YF00<005YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`07Ool3000GOol0
1@00FUH005YF0000;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00008goo00@005YF
FUIJEP8002eoo`00;7oo10000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF2`0015YF00<005YFFUH01@002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00
0UYF00<005YFFUH015YF00@005YF0000029oo`8000AJEP03001oogoo02aoo`00<7oo10000UYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001UYF0P008Woo0P0000=JEP00FUH0
0eYF00<007ooOol0;7oo000dOol20005FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH50004FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH000000UYF0P001UYF00<007ooOol07goo0P000eYF00D005YFFUIJEP0002moo`00<goo
0P001UYF00<005YFFUH0100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EP0000D001moo`<000EJEP04001JEP00000`Ool0035oo`800003FUH005YF00AJEPT000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEP00FUH005YF000015YF1@006Goo100000=JEP00FUH01EYF0P00<Woo000`Ool01@00
FUIJEUYF00000eYF0P002Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF000015YF00<005YF000010003goo1`00
1EYF00<005YFFUH015YF00<007ooOol0<Goo000_Ool00`00FUIJEP02FUH01000FUH000003goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF
009JEP03001JEP0000D000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2
000dOol002ioo`8000AJEP8001Qoo`l000=JEP03001JEUYF0080009JEP03001JEUYF00=JEP<0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000EJEP8000AJ
EP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH00000=Woo000^Ool20003FUH00`00Oomoo`0WOol600001Goo
001JEUYF00000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF0P001eYF0`0000=JEP00FUH00eYF00<005YF00001EYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>7oo000]Ool01P00FUIJEP00FUH0035oo`05
001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH20008FUH01000FUH0000015YF00<005YF00001eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000?7oo000]Ool00`00FUIJEP02000FOol3000IOol00`00FUIJEP020000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH2
0008FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01P0000=JEP00FUH01eYF00<0
05YFFUH00UYF1`00@7oo000]Ool01000FUIJEP005Woo1@0067oo00<005YF00000eYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF0P0025YF00<0
05YFFUH00eYF0`0000=JEP0000001UYF00<005YFFUH00UYF0P0000=JEP0000003P00Agoo000]Ool0
0`00FUH0000GOol5000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04
0002FUH00`00FUIJEP03FUH4001EOol002ioo`8001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000005FUH30005FUH01000FUH00000EGoo000^Ool00`00Oomoo`0GOol3
000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00P00
0eYF00D005YFFUIJEP0005Aoo`00;Woo0P00<Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`1B
Ool002ioo`03001JEP0002moo`03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001oogoo059oo`00;Woo00@005YF
FUH002aoo`<000AJEP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD000AJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00Oomoo`1BOol002ioo`04001JEUYFFUH2000XOol20002FUH01@00FUIJ
EUYF00000goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo4@00E7oo000^Ool01P00FUIJEUYF001JEP<0
025oo`@000EJEP03001JEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2000EOol2001DOol002moo`04001J
EUYF0004FUH3000JOol40002FUH00`00FUIJEP04FUH20009Ool40002FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000005goo0P00
E7oo000`Ool00`00FUH00005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000>Ool5
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH7000HOol0
1000FUH00000Dgoo000aOol20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P005Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1@000Woo1@00
67oo00@005YFFUH005=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000001eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPH0
00Ioo`D001Moo`80009JEP03001oogoo055oo`00=7oo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH015YF0`00:7oo6@0037oo1@005Woo00D005YF001JEP0005Aoo`00
=goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P006Goo0`005Woo
00@005YFFUIJEP8005Aoo`00>Woo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00
;goo0P0015YF00<007ooOol0Dgoo000nOol@0011Ool200000eYF001oo`0[Ool200000eYF001JEP03
FUH00`00Oomoo`1COol008moo`80009JEP03001oogoo02Moo`8000=JEP05001JEUYFFUH0001FOol0
091oo`03001JEUYF00<002Aoo`<000EJEP04001JEP00001GOol0091oo`04001JEUYF0002FUH2000P
Ool200000eYF001JEP05FUH2001IOol0095oo`04001JEUYF0003FUH5000HOol30003FUH00`00FUIJ
EP04FUH00`00Oomoo`1HOol0099oo`<000AJEP04001JEUYFFUH90009Ool60007FUH01000FUIJEUYF
0P00Fgoo002DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP06FUH01000FUH00000GGoo002EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3001OOol009Moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<0069oo`00VGoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P00IGoo002NOol80004FUH00`00FUIJEP02FUH6001XOol00:Ioo`T006ioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59543 .7114 m .56429 .71033 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59543 .7114 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59451 .7745 m .62595 .7792 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59451 .7745 L p .60514 .75319 L .707 .577 .707 r
F P
0 g
s
.60733 .7488 m .59814 .74863 L .60514 .75319 L .707 .577 .707 r
F
.59451 .7745 m .59814 .74863 L p .57761 .74707 L F P
0 g
s
.56347 .77072 m .59451 .7745 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .56347 .77072 L p .57469 .75196 L .707 .577 .707 r
F P
0 g
s
.57761 .74707 m .5669 .74626 L .57469 .75196 L .707 .577 .707 r
F
.56429 .71033 m .5368 .70511 L p .55415 .73694 L F P
0 g
s
.55858 .74507 m .5669 .74626 L .55415 .73694 L .707 .577 .707 r
F
.5669 .74626 m .56429 .71033 L p .55415 .73694 L F P
0 g
s
.58292 .73873 m .58267 .73856 L .56808 .76249 L .707 .577 .707 r
F
.56553 .7274 m .5669 .74626 L p .58267 .73856 L F P
0 g
s
.5669 .74626 m .56808 .76249 L p .58267 .73856 L .707 .577 .707 r
F P
0 g
s
.56347 .77072 m .5669 .74626 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .56347 .77072 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .53588 .76821 L p .54592 .74875 L .707 .577 .707 r
F P
0 g
s
.54857 .74364 m .53951 .74234 L .54592 .74875 L .707 .577 .707 r
F
.5368 .70511 m .51566 .69624 L p .53103 .73386 L F P
0 g
s
.53394 .74098 m .53951 .74234 L .53103 .73386 L .707 .577 .707 r
F
.53951 .74234 m .5368 .70511 L p .53103 .73386 L F P
0 g
s
.5368 .70511 m .53951 .74234 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .53951 .74234 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .53588 .76821 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51443 .76723 L p .52201 .74331 L .707 .577 .707 r
F P
0 g
s
.52355 .73844 m .51864 .73724 L .52201 .74331 L .707 .577 .707 r
F
.51566 .69624 m .50293 .68458 L p .51475 .73023 L F P
0 g
s
.51628 .73613 m .51864 .73724 L .51475 .73023 L .707 .577 .707 r
F
.51864 .73724 m .51566 .69624 L p .51475 .73023 L F P
0 g
s
.51566 .69624 m .51864 .73724 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .51864 .73724 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .50695 .73175 L .50665 .73361 L .707 .577 .707 r
F
.50123 .76788 m .5115 .76738 L p .50665 .73361 L F P
0 g
s
.5115 .76738 m .51443 .76723 L p .50665 .73361 L .707 .577 .707 r
F P
0 g
s
.50293 .68458 m .49987 .67129 L p .50572 .7271 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50123 .76788 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.50123 .76788 m .50634 .73147 L p .5029 .73212 L .707 .577 .707 r
F P
0 g
s
.50612 .73094 m .50634 .73147 L .50572 .7271 L .707 .577 .707 r
F
.50634 .73147 m .50293 .68458 L p .50572 .7271 L F P
0 g
s
.50293 .68458 m .50634 .73147 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50586 .73034 m .5029 .73212 L p .50634 .73147 L .707 .577 .707 r
F P
0 g
s
.49987 .67129 m .50366 .72345 L .50372 .7237 L p .707 .577 .707 r
F P
0 g
s
.50372 .7237 m .50673 .73674 L p .5021 .69257 L .707 .577 .707 r
F P
0 g
s
.5021 .69257 m .49987 .67129 L .50372 .7237 L .707 .577 .707 r
F
.5029 .73212 m .49757 .77008 L .50123 .76788 L p F P
0 g
s
.49757 .77008 m .5029 .73212 L .5042 .73286 L p .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .50634 .73147 L p .50612 .73094 L .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .51945 .74839 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50673 .73674 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.5042 .73286 m .50914 .73567 L p .50499 .74802 L .707 .577 .707 r
F P
0 g
s
.49757 .77008 m .5042 .73286 L .50499 .74802 L .707 .577 .707 r
F
.50634 .73147 m .50656 .72992 L .50586 .73034 L p F P
0 g
s
.50656 .72992 m .50634 .73147 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .50656 .72992 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51976 .72928 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .51864 .73724 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .54059 .75727 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51945 .74839 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .51864 .73724 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .51976 .72928 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .5412 .73026 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .53951 .74234 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .56808 .76249 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .54059 .75727 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .53951 .74234 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5412 .73026 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .5688 .73276 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .5669 .74626 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5669 .74626 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .59922 .76356 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.58897 .74794 m .58292 .73873 L .57771 .74708 L .707 .577 .707 r
F
.58897 .74794 m .57771 .74708 L .56808 .76249 L F
.56429 .71033 m .56553 .7274 L p .58292 .73873 L F P
0 g
s
.59543 .7114 m .59814 .74863 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .59543 .7114 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62718 .70821 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .65473 .78435 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62595 .7792 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .63016 .74921 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .62718 .70821 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65643 .70106 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .65984 .74794 L p .68411 .74282 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .67802 .78945 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65473 .78435 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.67724 .74581 m .68411 .74282 L p .65984 .74794 L .707 .577 .707 r
F P
0 g
s
.67802 .78945 m .68335 .75149 L .66006 .74639 L p .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66022 .75322 L .67724 .74581 L p .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .65984 .74794 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .63128 .74125 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .65984 .74794 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66006 .74639 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.66022 .75322 m .65984 .74794 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .66022 .75322 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63097 .76036 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .63016 .74921 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .59983 .73655 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .63016 .74921 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63128 .74125 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .63016 .74921 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .63097 .76036 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59922 .76356 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .59814 .74863 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .5688 .73276 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59983 .73655 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .59814 .74863 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.68411 .74282 m .68031 .69066 L .65643 .70106 L p .707 .577 .707 r
F P
0 g
s
.68031 .69066 m .68411 .74282 L .70029 .73019 L p .707 .577 .707 r
F P
0 g
s
.70029 .73019 m .6965 .67803 L .68031 .69066 L p .707 .577 .707 r
F P
0 g
s
.60075 .86891 m .59924 .85181 L .56811 .8509 L p .707 .577 .707 r
F P
0 g
s
.59924 .85181 m .60075 .86891 L .63247 .86526 L p .707 .577 .707 r
F P
0 g
s
.63247 .86526 m .63096 .84816 L .59924 .85181 L p .707 .577 .707 r
F P
0 g
s
.63096 .84816 m .63247 .86526 L .66166 .8574 L p .707 .577 .707 r
F P
0 g
s
.66166 .8574 m .66015 .84031 L .63096 .84816 L p .707 .577 .707 r
F P
0 g
s
.68335 .75149 m .67802 .78945 L .69354 .79399 L p .707 .577 .707 r
F P
0 g
s
.6965 .67803 m .70029 .73019 L .70719 .71656 L p .707 .577 .707 r
F P
0 g
s
.70719 .71656 m .7034 .6644 L .6965 .67803 L p .707 .577 .707 r
F P
0 g
s
.69354 .79399 m .69887 .75603 L .68335 .75149 L p .707 .577 .707 r
F P
0 g
s
.56962 .868 m .56811 .8509 L .54061 .84552 L p .707 .577 .707 r
F P
0 g
s
.56811 .8509 m .56962 .868 L .60075 .86891 L p .707 .577 .707 r
F P
0 g
s
.66015 .84031 m .66166 .8574 L .68547 .84611 L p .707 .577 .707 r
F P
0 g
s
.68547 .84611 m .68396 .82902 L .66015 .84031 L p .707 .577 .707 r
F P
0 g
s
.54061 .84552 m .54212 .86262 L .56962 .868 L p .707 .577 .707 r
F P
0 g
s
.54212 .86262 m .54061 .84552 L .51944 .83619 L p .707 .577 .707 r
F P
0 g
s
.68396 .82902 m .68547 .84611 L .70158 .83249 L p .707 .577 .707 r
F P
0 g
s
.70158 .83249 m .70007 .8154 L .68396 .82902 L p .707 .577 .707 r
F P
0 g
s
.51944 .83619 m .52095 .85329 L .54212 .86262 L p .707 .577 .707 r
F P
0 g
s
.69887 .75603 m .69354 .79399 L .69978 .79754 L p .707 .577 .707 r
F P
0 g
s
.69978 .79754 m .70511 .75958 L .69887 .75603 L p .707 .577 .707 r
F P
0 g
s
.7034 .6644 m .70719 .71656 L .70413 .70327 L p .707 .577 .707 r
F P
0 g
s
.70413 .70327 m .70033 .65111 L .7034 .6644 L p .707 .577 .707 r
F P
0 g
s
.52095 .85329 m .51944 .83619 L .50665 .82383 L p .707 .577 .707 r
F P
0 g
s
.50366 .72345 m .49987 .67129 L .50677 .65767 L p .707 .577 .707 r
F P
0 g
s
.48697 .82053 m .49216 .31534 L .44815 .31248 L p .707 .577 .707 r
F P
0 g
s
.50816 .84093 m .50665 .82383 L .50352 .80965 L p .707 .577 .707 r
F P
0 g
s
.50914 .73567 m .50381 .77363 L .49757 .77008 L p .707 .577 .707 r
F P
0 g
s
.50677 .65767 m .51056 .70982 L .50366 .72345 L p .707 .577 .707 r
F P
0 g
s
.51056 .70982 m .50677 .65767 L .52295 .64504 L p .707 .577 .707 r
F P
0 g
s
.50352 .80965 m .50503 .82675 L .50816 .84093 L p .707 .577 .707 r
F P
0 g
s
.50503 .82675 m .50352 .80965 L .51034 .79503 L p .707 .577 .707 r
F P
0 g
s
.52295 .64504 m .52675 .69719 L .51056 .70982 L p .707 .577 .707 r
F P
0 g
s
.52466 .74021 m .51933 .77817 L .50381 .77363 L p .707 .577 .707 r
F P
0 g
s
.50381 .77363 m .50914 .73567 L .52466 .74021 L p .707 .577 .707 r
F P
0 g
s
.51034 .79503 m .51185 .81213 L .50503 .82675 L p .707 .577 .707 r
F P
0 g
s
.51185 .81213 m .51034 .79503 L .52644 .78141 L p .707 .577 .707 r
F P
0 g
s
.54795 .74531 m .54262 .78326 L .51933 .77817 L p .707 .577 .707 r
F P
0 g
s
.51933 .77817 m .52466 .74021 L .54795 .74531 L p .707 .577 .707 r
F P
0 g
s
.52644 .78141 m .52795 .79851 L .51185 .81213 L p .707 .577 .707 r
F P
0 g
s
.54262 .78326 m .54795 .74531 L .57673 .75046 L p .707 .577 .707 r
F P
0 g
s
.52795 .79851 m .52644 .78141 L .55025 .77012 L p .707 .577 .707 r
F P
0 g
s
.57673 .75046 m .5714 .78841 L .54262 .78326 L p .707 .577 .707 r
F P
0 g
s
.55025 .77012 m .55176 .78722 L .52795 .79851 L p .707 .577 .707 r
F P
0 g
s
.49216 .31534 m .48697 .82053 L .53191 .81996 L p .707 .577 .707 r
F P
0 g
s
.52675 .69719 m .52295 .64504 L .54684 .63464 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .55063 .6868 L .52675 .69719 L p .707 .577 .707 r
F P
0 g
s
.53191 .81996 m .5371 .31478 L .49216 .31534 L p .707 .577 .707 r
F P
0 g
s
.50665 .82383 m .50816 .84093 L .52095 .85329 L p .707 .577 .707 r
F P
0 g
s
.70007 .8154 m .70158 .83249 L .7084 .81787 L p .707 .577 .707 r
F P
0 g
s
.7084 .81787 m .70689 .80078 L .70007 .8154 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .57609 .62749 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55063 .6868 m .55052 .68524 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55052 .68524 m .54684 .63464 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.57988 .67965 m .57609 .62749 L .60784 .6243 L p .707 .577 .707 r
F P
0 g
s
.57609 .62749 m .57988 .67965 L .55063 .6868 L p .707 .577 .707 r
F P
0 g
s
.60784 .6243 m .61163 .67645 L .57988 .67965 L p .707 .577 .707 r
F P
0 g
s
.63921 .75894 m .63388 .7969 L .60912 .79388 L p .707 .577 .707 r
F P
0 g
s
.60912 .79388 m .60285 .79311 L p .60974 .78663 L .707 .577 .707 r
F P
0 g
s
.60974 .78663 m .63921 .75894 L .60912 .79388 L .707 .577 .707 r
F
.63898 .62536 m .64277 .67752 L .61163 .67645 L p F P
0 g
s
.61163 .67645 m .60784 .6243 L .63898 .62536 L p .707 .577 .707 r
F P
0 g
s
.63388 .7969 m .63921 .75894 L .6668 .76145 L p .707 .577 .707 r
F P
0 g
s
.60285 .79311 m .60817 .75516 L .63921 .75894 L p .707 .577 .707 r
F P
0 g
s
.64229 .75952 m .6438 .77662 L .61267 .77571 L p .707 .577 .707 r
F P
0 g
s
.61267 .77571 m .61116 .75861 L .64229 .75952 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .64043 .78919 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.63563 .29465 m .6334 .51211 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.6334 .51211 m .63044 .79984 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.60817 .75516 m .60285 .79311 L .5738 .78877 L p .707 .577 .707 r
F P
0 g
s
.5738 .78877 m .5714 .78841 L p .57445 .78566 L .707 .577 .707 r
F P
0 g
s
.57445 .78566 m .60817 .75516 L .5738 .78877 L .707 .577 .707 r
F
.5714 .78841 m .57673 .75046 L .60817 .75516 L p F P
0 g
s
.58096 .77936 m .57945 .76226 L .61116 .75861 L p .707 .577 .707 r
F P
0 g
s
.61116 .75861 m .61267 .77571 L .58096 .77936 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .63044 .79984 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.61253 .3039 m .60929 .61908 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.60929 .61908 m .60734 .80909 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.57857 .31083 m .57412 .74459 L p .60734 .80909 L .707 .577 .707 r
F P
0 g
s
.55176 .78722 m .55025 .77012 L .57945 .76226 L p .707 .577 .707 r
F P
0 g
s
.57945 .76226 m .58096 .77936 L .55986 .78504 L p .707 .577 .707 r
F P
0 g
s
.55986 .78504 m .55176 .78722 L p .55814 .78147 L .707 .577 .707 r
F P
0 g
s
.55814 .78147 m .57945 .76226 L .55986 .78504 L .707 .577 .707 r
F
.57412 .74459 m .57341 .81317 L p .60033 .81052 L F P
0 g
s
.57341 .81317 m .57339 .81602 L .57466 .81576 L p .707 .577 .707 r
F P
0 g
s
.57466 .81576 m .60033 .81052 L p .57341 .81317 L .707 .577 .707 r
F P
0 g
s
.60033 .81052 m .60734 .80909 L p .57412 .74459 L .707 .577 .707 r
F P
0 g
s
.5371 .31478 m .53191 .81996 L .57339 .81602 L p .707 .577 .707 r
F P
0 g
s
.57339 .81602 m .57857 .31083 L .5371 .31478 L p .707 .577 .707 r
F P
0 g
s
.44296 .81766 m .44815 .31248 L .40938 .30646 L p .707 .577 .707 r
F P
0 g
s
.44815 .31248 m .44296 .81766 L .48697 .82053 L p .707 .577 .707 r
F P
0 g
s
.70511 .75958 m .69978 .79754 L .69612 .79974 L p .707 .577 .707 r
F P
0 g
s
.70033 .65111 m .70413 .70327 L .6914 .69162 L p .707 .577 .707 r
F P
0 g
s
.6914 .69162 m .68761 .63946 L .70033 .65111 L p .707 .577 .707 r
F P
0 g
s
.69612 .79974 m .70145 .76178 L .70511 .75958 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .61253 .3039 L .57857 .31083 L p .707 .577 .707 r
F P
0 g
s
.70689 .80078 m .7084 .81787 L .70526 .80369 L p .707 .577 .707 r
F P
0 g
s
.70526 .80369 m .70375 .7866 L .70689 .80078 L p .707 .577 .707 r
F P
0 g
s
.25242 .67459 m .22128 .67352 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25242 .67459 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.2515 .73769 m .28294 .74239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .2515 .73769 L p .26213 .71637 L .707 .577 .707 r
F P
0 g
s
.26433 .71198 m .25513 .71182 L .26213 .71637 L .707 .577 .707 r
F
.2515 .73769 m .25513 .71182 L p .2346 .71026 L F P
0 g
s
.22046 .7339 m .2515 .73769 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22046 .7339 L p .23168 .71514 L .707 .577 .707 r
F P
0 g
s
.2346 .71026 m .22389 .70945 L .23168 .71514 L .707 .577 .707 r
F
.22128 .67352 m .19379 .66829 L p .21114 .70012 L F P
0 g
s
.21558 .70826 m .22389 .70945 L .21114 .70012 L .707 .577 .707 r
F
.22389 .70945 m .22128 .67352 L p .21114 .70012 L F P
0 g
s
.23991 .70191 m .23966 .70175 L .22507 .72568 L .707 .577 .707 r
F
.22252 .69059 m .22389 .70945 L p .23966 .70175 L F P
0 g
s
.22389 .70945 m .22507 .72568 L p .23966 .70175 L .707 .577 .707 r
F P
0 g
s
.22046 .7339 m .22389 .70945 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .22046 .7339 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19287 .7314 L p .20291 .71194 L .707 .577 .707 r
F P
0 g
s
.20556 .70682 m .1965 .70552 L .20291 .71194 L .707 .577 .707 r
F
.19379 .66829 m .17265 .65942 L p .18802 .69704 L F P
0 g
s
.19093 .70416 m .1965 .70552 L .18802 .69704 L .707 .577 .707 r
F
.1965 .70552 m .19379 .66829 L p .18802 .69704 L F P
0 g
s
.19379 .66829 m .1965 .70552 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .1965 .70552 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .19287 .7314 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17142 .73042 L p .179 .70649 L .707 .577 .707 r
F P
0 g
s
.18054 .70162 m .17563 .70042 L .179 .70649 L .707 .577 .707 r
F
.17265 .65942 m .15992 .64777 L p .17174 .69341 L F P
0 g
s
.17327 .69931 m .17563 .70042 L .17174 .69341 L .707 .577 .707 r
F
.17563 .70042 m .17265 .65942 L p .17174 .69341 L F P
0 g
s
.17265 .65942 m .17563 .70042 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .17563 .70042 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .16394 .69493 L .16364 .6968 L .707 .577 .707 r
F
.15822 .73106 m .16849 .73056 L p .16364 .6968 L F P
0 g
s
.16849 .73056 m .17142 .73042 L p .16364 .6968 L .707 .577 .707 r
F P
0 g
s
.15992 .64777 m .15686 .63448 L p .16271 .69028 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .15822 .73106 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.15822 .73106 m .16334 .69465 L p .15989 .69531 L .707 .577 .707 r
F P
0 g
s
.16311 .69413 m .16334 .69465 L .16271 .69028 L .707 .577 .707 r
F
.16334 .69465 m .15992 .64777 L p .16271 .69028 L F P
0 g
s
.15992 .64777 m .16334 .69465 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16285 .69353 m .15989 .69531 L p .16334 .69465 L .707 .577 .707 r
F P
0 g
s
.15686 .63448 m .16066 .68664 L .16071 .68688 L p .707 .577 .707 r
F P
0 g
s
.16071 .68688 m .16372 .69993 L p .15909 .65576 L .707 .577 .707 r
F P
0 g
s
.15909 .65576 m .15686 .63448 L .16071 .68688 L .707 .577 .707 r
F
.15989 .69531 m .15456 .73326 L .15822 .73106 L p F P
0 g
s
.15456 .73326 m .15989 .69531 L .16119 .69605 L p .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .16334 .69465 L p .16311 .69413 L .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .17644 .71158 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .16372 .69993 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16119 .69605 m .16613 .69885 L p .16198 .7112 L .707 .577 .707 r
F P
0 g
s
.15456 .73326 m .16119 .69605 L .16198 .7112 L .707 .577 .707 r
F
.16334 .69465 m .16355 .6931 L .16285 .69353 L p F P
0 g
s
.16355 .6931 m .16334 .69465 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .16355 .6931 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17675 .69246 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .17563 .70042 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .19759 .72045 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17644 .71158 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .17563 .70042 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .17675 .69246 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .1982 .69344 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .1965 .70552 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .22507 .72568 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19759 .72045 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .1965 .70552 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .1982 .69344 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22579 .69595 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .22389 .70945 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .22389 .70945 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .25622 .72674 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.24596 .71112 m .23991 .70191 L .2347 .71027 L .707 .577 .707 r
F
.24596 .71112 m .2347 .71027 L .22507 .72568 L F
.22128 .67352 m .22252 .69059 L p .23991 .70191 L F P
0 g
s
.25242 .67459 m .25513 .71182 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .25242 .67459 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28417 .67139 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .31172 .74754 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28294 .74239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .28715 .71239 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .28417 .67139 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31342 .66424 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .31683 .71113 L p .3411 .706 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .33501 .75263 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31172 .74754 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.33423 .709 m .3411 .706 L p .31683 .71113 L .707 .577 .707 r
F P
0 g
s
.33501 .75263 m .34034 .71468 L .31705 .70958 L p .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31722 .7164 L .33423 .709 L p .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .31683 .71113 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .28827 .70443 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .31683 .71113 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31705 .70958 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31722 .7164 m .31683 .71113 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .31722 .7164 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28797 .72355 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .28715 .71239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .25683 .69973 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .28715 .71239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28827 .70443 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .28715 .71239 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .28797 .72355 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25622 .72674 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .25513 .71182 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .22579 .69595 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25683 .69973 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .25513 .71182 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.4042 .81165 m .40938 .30646 L .37966 .29788 L p .707 .577 .707 r
F P
0 g
s
.40938 .30646 m .4042 .81165 L .44296 .81766 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68761 .63946 m .6914 .69162 L .67026 .68275 L p .707 .577 .707 r
F P
0 g
s
.67026 .68275 m .66647 .63059 L .68761 .63946 L p .707 .577 .707 r
F P
0 g
s
.70145 .76178 m .69612 .79974 L .68292 .80038 L p .707 .577 .707 r
F P
0 g
s
.3411 .706 m .33731 .65385 L .31342 .66424 L p .707 .577 .707 r
F P
0 g
s
.68292 .80038 m .68825 .76243 L .70145 .76178 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .63563 .29465 L .61253 .3039 L p .707 .577 .707 r
F P
0 g
s
.70375 .7866 m .70526 .80369 L .69248 .79133 L p .707 .577 .707 r
F P
0 g
s
.69248 .79133 m .69097 .77423 L .70375 .7866 L p .707 .577 .707 r
F P
0 g
s
.66647 .63059 m .67026 .68275 L .64277 .67752 L p .707 .577 .707 r
F P
0 g
s
.64277 .67752 m .63898 .62536 L .66647 .63059 L p .707 .577 .707 r
F P
0 g
s
.33731 .65385 m .3411 .706 L .35728 .69337 L p .707 .577 .707 r
F P
0 g
s
.35728 .69337 m .35349 .64122 L .33731 .65385 L p .707 .577 .707 r
F P
0 g
s
.37447 .80307 m .37966 .29788 L .36187 .28757 L p .707 .577 .707 r
F P
0 g
s
.37966 .29788 m .37447 .80307 L .4042 .81165 L p .707 .577 .707 r
F P
0 g
s
.68825 .76243 m .68292 .80038 L .66148 .7994 L p .707 .577 .707 r
F P
0 g
s
.66148 .7994 m .6668 .76145 L .68825 .76243 L p .707 .577 .707 r
F P
0 g
s
.25775 .8321 m .25623 .815 L .2251 .81409 L p .707 .577 .707 r
F P
0 g
s
.25623 .815 m .25775 .8321 L .28946 .82844 L p .707 .577 .707 r
F P
0 g
s
.28946 .82844 m .28795 .81135 L .25623 .815 L p .707 .577 .707 r
F P
0 g
s
.28795 .81135 m .28946 .82844 L .31865 .82059 L p .707 .577 .707 r
F P
0 g
s
.31865 .82059 m .31714 .80349 L .28795 .81135 L p .707 .577 .707 r
F P
0 g
s
.34034 .71468 m .33501 .75263 L .35053 .75717 L p .707 .577 .707 r
F P
0 g
s
.69097 .77423 m .69248 .79133 L .6713 .782 L p .707 .577 .707 r
F P
0 g
s
.6713 .782 m .66979 .76491 L .69097 .77423 L p .707 .577 .707 r
F P
0 g
s
.35349 .64122 m .35728 .69337 L .36418 .67975 L p .707 .577 .707 r
F P
0 g
s
.36418 .67975 m .36039 .62759 L .35349 .64122 L p .707 .577 .707 r
F P
0 g
s
.35053 .75717 m .35586 .71922 L .34034 .71468 L p .707 .577 .707 r
F P
0 g
s
.22661 .83119 m .2251 .81409 L .1976 .80871 L p .707 .577 .707 r
F P
0 g
s
.2251 .81409 m .22661 .83119 L .25775 .8321 L p .707 .577 .707 r
F P
0 g
s
.64043 .78919 m .64562 .284 L .63563 .29465 L p .707 .577 .707 r
F P
0 g
s
.31714 .80349 m .31865 .82059 L .34246 .8093 L p .707 .577 .707 r
F P
0 g
s
.34246 .8093 m .34095 .7922 L .31714 .80349 L p .707 .577 .707 r
F P
0 g
s
.6668 .76145 m .66148 .7994 L .63388 .7969 L p .707 .577 .707 r
F P
0 g
s
.1976 .80871 m .19911 .8258 L .22661 .83119 L p .707 .577 .707 r
F P
0 g
s
.19911 .8258 m .1976 .80871 L .17643 .79938 L p .707 .577 .707 r
F P
0 g
s
.35857 .79568 m .35706 .77858 L .34095 .7922 L p .707 .577 .707 r
F P
0 g
s
.35586 .71922 m .35053 .75717 L .35677 .76072 L p .707 .577 .707 r
F P
0 g
s
.35677 .76072 m .3621 .72277 L .35586 .71922 L p .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36039 .62759 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36112 .66646 m .36101 .6649 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .35732 .6143 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36101 .6649 L p .34839 .6548 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .36112 .66646 L .36092 .66627 L p .707 .577 .707 r
F P
0 g
s
.36092 .66627 m .34839 .6548 L p .36101 .6649 L .707 .577 .707 r
F P
0 g
s
.3621 .72277 m .35677 .76072 L .35311 .76292 L p .707 .577 .707 r
F P
0 g
s
.34839 .6548 m .3446 .60265 L .35732 .6143 L p .707 .577 .707 r
F P
0 g
s
.35311 .76292 m .35844 .72497 L .3621 .72277 L p .707 .577 .707 r
F P
0 g
s
.35844 .72497 m .35311 .76292 L .33991 .76357 L p .707 .577 .707 r
F P
0 g
s
.33991 .76357 m .34524 .72561 L .35844 .72497 L p .707 .577 .707 r
F P
0 g
s
.36074 .74978 m .36225 .76688 L .35871 .76345 L p .707 .577 .707 r
F P
0 g
s
.35871 .76345 m .34947 .75451 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.3597 .75022 m .36074 .74978 L .35871 .76345 L .707 .577 .707 r
F
.34947 .75451 m .34796 .73742 L .3598 .74887 L p F P
0 g
s
.3598 .74887 m .36074 .74978 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.34947 .75451 m .3598 .74887 L .3597 .75022 L .707 .577 .707 r
F
.35669 .79023 m .35811 .65416 L .35699 .65 L F
.35668 .79276 m .35671 .78991 L p .35669 .79023 L F P
0 g
s
.35671 .78991 m .35811 .65416 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35343 .78402 m .35653 .79235 L p .35682 .73081 L .707 .577 .707 r
F P
0 g
s
.35653 .79235 m .35668 .79276 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35669 .79023 m .35682 .73081 L .35653 .79235 L .707 .577 .707 r
F
.35778 .27656 m .35259 .78175 L .35343 .78402 L p F P
0 g
s
.35682 .73081 m .35778 .27656 L .35343 .78402 L .707 .577 .707 r
F
.36187 .28757 m .35778 .27656 L p .35699 .65 L F P
0 g
s
.35811 .65416 m .36187 .28757 L p .35699 .65 L .707 .577 .707 r
F P
0 g
s
.36039 .62759 m .36418 .67975 L .36112 .66646 L p .707 .577 .707 r
F P
0 g
s
.35706 .77858 m .35857 .79568 L .36539 .78106 L p .707 .577 .707 r
F P
0 g
s
.36539 .78106 m .36388 .76396 L .35706 .77858 L p .707 .577 .707 r
F P
0 g
s
.36388 .76396 m .36539 .78106 L .36225 .76688 L p .707 .577 .707 r
F P
0 g
s
.36225 .76688 m .36074 .74978 L .36388 .76396 L p .707 .577 .707 r
F P
0 g
s
.36187 .28757 m .35668 .79276 L .37447 .80307 L p .707 .577 .707 r
F P
0 g
s
.66979 .76491 m .6713 .782 L .6438 .77662 L p .707 .577 .707 r
F P
0 g
s
.6438 .77662 m .64229 .75952 L .66979 .76491 L p .707 .577 .707 r
F P
0 g
s
.34095 .7922 m .34246 .8093 L .35857 .79568 L p .707 .577 .707 r
F P
0 g
s
.17643 .79938 m .17794 .81647 L .19911 .8258 L p .707 .577 .707 r
F P
0 g
s
.17794 .81647 m .17643 .79938 L .16364 .78702 L p .707 .577 .707 r
F P
0 g
s
.64562 .284 m .64043 .78919 L .63634 .77817 L p .707 .577 .707 r
F P
0 g
s
.63634 .77817 m .64153 .27298 L .64562 .284 L p .707 .577 .707 r
F P
0 g
s
.16066 .68664 m .15686 .63448 L .16376 .62085 L p .707 .577 .707 r
F P
0 g
s
.16364 .78702 m .16515 .80411 L .17794 .81647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35259 .78175 m .35778 .27656 L .36777 .2659 L p .707 .577 .707 r
F P
0 g
s
.16515 .80411 m .16364 .78702 L .16051 .77283 L p .707 .577 .707 r
F P
0 g
s
.16613 .69885 m .1608 .73681 L .15456 .73326 L p .707 .577 .707 r
F P
0 g
s
.16376 .62085 m .16755 .67301 L .16066 .68664 L p .707 .577 .707 r
F P
0 g
s
.16755 .67301 m .16376 .62085 L .17994 .60822 L p .707 .577 .707 r
F P
0 g
s
.16051 .77283 m .16202 .78993 L .16515 .80411 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3446 .60265 m .34839 .6548 L .32725 .64593 L p .707 .577 .707 r
F P
0 g
s
.32725 .64593 m .32346 .59377 L .3446 .60265 L p .707 .577 .707 r
F P
0 g
s
.64153 .27298 m .63634 .77817 L .61856 .76787 L p .707 .577 .707 r
F P
0 g
s
.61856 .76787 m .62375 .26268 L .64153 .27298 L p .707 .577 .707 r
F P
0 g
s
.16202 .78993 m .16051 .77283 L .16733 .75822 L p .707 .577 .707 r
F P
0 g
s
.17994 .60822 m .18374 .66038 L .16755 .67301 L p .707 .577 .707 r
F P
0 g
s
.18374 .66038 m .17994 .60822 L .20383 .59782 L p .707 .577 .707 r
F P
0 g
s
.18165 .7034 m .17632 .74135 L .1608 .73681 L p .707 .577 .707 r
F P
0 g
s
.1608 .73681 m .16613 .69885 L .18165 .7034 L p .707 .577 .707 r
F P
0 g
s
.16733 .75822 m .16884 .77531 L .16202 .78993 L p .707 .577 .707 r
F P
0 g
s
.36258 .77109 m .36777 .2659 L .39088 .25666 L p .707 .577 .707 r
F P
0 g
s
.36777 .2659 m .36258 .77109 L .35259 .78175 L p .707 .577 .707 r
F P
0 g
s
.32346 .59377 m .32725 .64593 L .29977 .64071 L p .707 .577 .707 r
F P
0 g
s
.29977 .64071 m .29597 .58855 L .32346 .59377 L p .707 .577 .707 r
F P
0 g
s
.20762 .64998 m .20383 .59782 L .23308 .59068 L p .707 .577 .707 r
F P
0 g
s
.20383 .59782 m .20762 .64998 L .18374 .66038 L p .707 .577 .707 r
F P
0 g
s
.34524 .72561 m .33991 .76357 L .31847 .76259 L p .707 .577 .707 r
F P
0 g
s
.31847 .76259 m .3238 .72463 L .34524 .72561 L p .707 .577 .707 r
F P
0 g
s
.16884 .77531 m .16733 .75822 L .18343 .7446 L p .707 .577 .707 r
F P
0 g
s
.29597 .58855 m .29977 .64071 L .26862 .63964 L p .707 .577 .707 r
F P
0 g
s
.26862 .63964 m .26483 .58748 L .29597 .58855 L p .707 .577 .707 r
F P
0 g
s
.20494 .70849 m .19961 .74645 L .17632 .74135 L p .707 .577 .707 r
F P
0 g
s
.17632 .74135 m .18165 .7034 L .20494 .70849 L p .707 .577 .707 r
F P
0 g
s
.23687 .64284 m .23308 .59068 L .26483 .58748 L p .707 .577 .707 r
F P
0 g
s
.23308 .59068 m .23687 .64284 L .20762 .64998 L p .707 .577 .707 r
F P
0 g
s
.62375 .26268 m .61856 .76787 L .58883 .75929 L p .707 .577 .707 r
F P
0 g
s
.58883 .75929 m .59402 .2541 L .62375 .26268 L p .707 .577 .707 r
F P
0 g
s
.26483 .58748 m .26862 .63964 L .23687 .64284 L p .707 .577 .707 r
F P
0 g
s
.18343 .7446 m .18494 .76169 L .16884 .77531 L p .707 .577 .707 r
F P
0 g
s
.34796 .73742 m .34947 .75451 L .32829 .74519 L p .707 .577 .707 r
F P
0 g
s
.32829 .74519 m .32678 .72809 L .34796 .73742 L p .707 .577 .707 r
F P
0 g
s
.3238 .72463 m .31847 .76259 L .29088 .76008 L p .707 .577 .707 r
F P
0 g
s
.73263 .61936 m .70149 .61829 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73263 .61936 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73171 .68285 m .76316 .68755 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73171 .68285 L p .74231 .66137 L .707 .577 .707 r
F P
0 g
s
.74446 .65701 m .73536 .65685 L .74231 .66137 L .707 .577 .707 r
F
.73171 .68285 m .73536 .65685 L p .71473 .65528 L F P
0 g
s
.70067 .67906 m .73171 .68285 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .70067 .67906 L p .71186 .66014 L .707 .577 .707 r
F P
0 g
s
.71473 .65528 m .70412 .65448 L .71186 .66014 L .707 .577 .707 r
F
.70149 .61829 m .674 .61307 L p .69157 .6453 L F P
0 g
s
.69594 .6533 m .70412 .65448 L .69157 .6453 L .707 .577 .707 r
F
.70412 .65448 m .70149 .61829 L p .69157 .6453 L F P
0 g
s
.72041 .64711 m .7199 .64678 L .70529 .67045 L .707 .577 .707 r
F
.70275 .63562 m .70412 .65448 L p .7199 .64678 L F P
0 g
s
.70412 .65448 m .70529 .67045 L p .7199 .64678 L .707 .577 .707 r
F P
0 g
s
.70067 .67906 m .70412 .65448 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .70067 .67906 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67308 .67656 L p .6831 .65692 L .707 .577 .707 r
F P
0 g
s
.68569 .65184 m .67673 .65055 L .6831 .65692 L .707 .577 .707 r
F
.674 .61307 m .65286 .6042 L p .6684 .64221 L F P
0 g
s
.67126 .64921 m .67673 .65055 L .6684 .64221 L .707 .577 .707 r
F
.67673 .65055 m .674 .61307 L p .6684 .64221 L F P
0 g
s
.674 .61307 m .67673 .65055 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .67673 .65055 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .67308 .67656 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65164 .67558 L p .65919 .65144 L .707 .577 .707 r
F P
0 g
s
.66069 .64663 m .65586 .64545 L .65919 .65144 L .707 .577 .707 r
F
.65286 .6042 m .64014 .59254 L p .65206 .6386 L F P
0 g
s
.65586 .64545 m .65286 .6042 L p .65206 .6386 L .707 .577 .707 r
F P
0 g
s
.65286 .6042 m .65586 .64545 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .65586 .64545 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .64412 .63994 L .64385 .64165 L .707 .577 .707 r
F
.63844 .67622 m .64874 .67572 L p .64385 .64165 L F P
0 g
s
.64874 .67572 m .65164 .67558 L p .64385 .64165 L .707 .577 .707 r
F P
0 g
s
.64014 .59254 m .63707 .57925 L p .64297 .63552 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .63844 .67622 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.63844 .67622 m .64357 .63968 L p .64011 .64047 L .707 .577 .707 r
F P
0 g
s
.64335 .63918 m .64357 .63968 L .64297 .63552 L .707 .577 .707 r
F
.64357 .63968 m .64014 .59254 L p .64297 .63552 L F P
0 g
s
.64014 .59254 m .64357 .63968 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64313 .63865 m .64011 .64047 L p .64357 .63968 L .707 .577 .707 r
F P
0 g
s
.63707 .57925 m .64087 .63141 L .64093 .63169 L p .707 .577 .707 r
F P
0 g
s
.64093 .63169 m .64393 .6447 L p .63931 .60063 L .707 .577 .707 r
F P
0 g
s
.63931 .60063 m .63707 .57925 L .64093 .63169 L .707 .577 .707 r
F
.64011 .64047 m .63478 .67843 L .63844 .67622 L p F P
0 g
s
.63478 .67843 m .64011 .64047 L .64143 .64122 L p .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .64357 .63968 L p .64335 .63918 L .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .65666 .65635 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .64393 .6447 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64143 .64122 m .64634 .64402 L p .64222 .6563 L .707 .577 .707 r
F P
0 g
s
.63478 .67843 m .64143 .64122 L .64222 .6563 L .707 .577 .707 r
F
.64357 .63968 m .64377 .63827 L .64313 .63865 L p F P
0 g
s
.64377 .63827 m .64357 .63968 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .64377 .63827 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65355 .64437 m .65586 .64545 L .65206 .6386 L .707 .577 .707 r
F
.65586 .64545 m .65696 .63762 L p .64412 .63994 L F P
0 g
s
.65666 .65635 m .65586 .64545 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.65666 .65635 m .6778 .66523 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65666 .65635 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .65586 .64545 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .65696 .63762 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67841 .6386 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .67673 .65055 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .70529 .67045 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .6778 .66523 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .67673 .65055 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .67841 .6386 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .706 .64111 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .70412 .65448 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .70412 .65448 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .73643 .67152 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.72635 .65616 m .72041 .64711 L .71509 .65531 L .707 .577 .707 r
F
.72635 .65616 m .71509 .65531 L .70529 .67045 L F
.70149 .61829 m .70275 .63562 L p .72041 .64711 L F P
0 g
s
.73263 .61936 m .73536 .65685 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .73263 .61936 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76438 .61617 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .79193 .6927 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76316 .68755 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .76739 .65742 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .76438 .61617 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79363 .60902 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .79706 .65616 L p .82131 .65078 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .81522 .69779 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79193 .6927 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.81362 .65413 m .82131 .65078 L p .79706 .65616 L .707 .577 .707 r
F P
0 g
s
.81522 .69779 m .82055 .65984 L .79726 .65474 L p .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79743 .66118 L .81362 .65413 L p .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .79706 .65616 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .76849 .64959 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .79706 .65616 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79726 .65474 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79743 .66118 m .79706 .65616 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .79743 .66118 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76818 .66832 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .76739 .65742 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .73704 .6449 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .76739 .65742 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76849 .64959 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .76739 .65742 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .76818 .66832 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73643 .67152 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .73536 .65685 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .706 .64111 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73704 .6449 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .73536 .65685 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.39088 .25666 m .38569 .76185 L .36258 .77109 L p .707 .577 .707 r
F P
0 g
s
.38569 .76185 m .39088 .25666 L .42483 .24972 L p .707 .577 .707 r
F P
0 g
s
.29088 .76008 m .2962 .72213 L .3238 .72463 L p .707 .577 .707 r
F P
0 g
s
.19961 .74645 m .20494 .70849 L .23372 .71364 L p .707 .577 .707 r
F P
0 g
s
.18494 .76169 m .18343 .7446 L .20724 .73331 L p .707 .577 .707 r
F P
0 g
s
.23372 .71364 m .22839 .7516 L .19961 .74645 L p .707 .577 .707 r
F P
0 g
s
.32678 .72809 m .32829 .74519 L .30079 .7398 L p .707 .577 .707 r
F P
0 g
s
.30079 .7398 m .29928 .72271 L .32678 .72809 L p .707 .577 .707 r
F P
0 g
s
.20724 .73331 m .20875 .7504 L .18494 .76169 L p .707 .577 .707 r
F P
0 g
s
.82131 .65078 m .81752 .59862 L .79363 .60902 L p .707 .577 .707 r
F P
0 g
s
.2962 .72213 m .29088 .76008 L .25984 .7563 L p .707 .577 .707 r
F P
0 g
s
.25984 .7563 m .26517 .71834 L .2962 .72213 L p .707 .577 .707 r
F P
0 g
s
.26517 .71834 m .25984 .7563 L .22839 .7516 L p .707 .577 .707 r
F P
0 g
s
.22839 .7516 m .23372 .71364 L .26517 .71834 L p .707 .577 .707 r
F P
0 g
s
.59402 .2541 m .58883 .75929 L .55006 .75327 L p .707 .577 .707 r
F P
0 g
s
.55006 .75327 m .55525 .24808 L .59402 .2541 L p .707 .577 .707 r
F P
0 g
s
.20875 .7504 m .20724 .73331 L .23644 .72545 L p .707 .577 .707 r
F P
0 g
s
.29928 .72271 m .30079 .7398 L .26966 .73889 L p .707 .577 .707 r
F P
0 g
s
.26966 .73889 m .26815 .7218 L .29928 .72271 L p .707 .577 .707 r
F P
0 g
s
.23644 .72545 m .23795 .74254 L .20875 .7504 L p .707 .577 .707 r
F P
0 g
s
.41964 .75491 m .42483 .24972 L .4663 .24578 L p .707 .577 .707 r
F P
0 g
s
.42483 .24972 m .41964 .75491 L .38569 .76185 L p .707 .577 .707 r
F P
0 g
s
.23795 .74254 m .23644 .72545 L .26815 .7218 L p .707 .577 .707 r
F P
0 g
s
.81752 .59862 m .82131 .65078 L .8375 .63815 L p .707 .577 .707 r
F P
0 g
s
.8375 .63815 m .8337 .58599 L .81752 .59862 L p .707 .577 .707 r
F P
0 g
s
.26815 .7218 m .26966 .73889 L .23795 .74254 L p .707 .577 .707 r
F P
0 g
s
.55525 .24808 m .55006 .75327 L .50606 .7504 L p .707 .577 .707 r
F P
0 g
s
.50606 .7504 m .51125 .24521 L .55525 .24808 L p .707 .577 .707 r
F P
0 g
s
.46112 .75097 m .4663 .24578 L .51125 .24521 L p .707 .577 .707 r
F P
0 g
s
.4663 .24578 m .46112 .75097 L .41964 .75491 L p .707 .577 .707 r
F P
0 g
s
.73796 .7754 m .73645 .7583 L .70532 .75739 L p .707 .577 .707 r
F P
0 g
s
.73645 .7583 m .73796 .7754 L .76967 .77175 L p .707 .577 .707 r
F P
0 g
s
.76967 .77175 m .76816 .75465 L .73645 .7583 L p .707 .577 .707 r
F P
0 g
s
.76816 .75465 m .76967 .77175 L .79886 .76389 L p .707 .577 .707 r
F P
0 g
s
.79886 .76389 m .79735 .74679 L .76816 .75465 L p .707 .577 .707 r
F P
0 g
s
.51125 .24521 m .50606 .7504 L .46112 .75097 L p .707 .577 .707 r
F P
0 g
s
.82055 .65984 m .81522 .69779 L .83075 .70234 L p .707 .577 .707 r
F P
0 g
s
.8337 .58599 m .8375 .63815 L .8444 .62452 L p .707 .577 .707 r
F P
0 g
s
.8444 .62452 m .8406 .57236 L .8337 .58599 L p .707 .577 .707 r
F P
0 g
s
.70683 .77449 m .70532 .75739 L .67782 .75201 L p .707 .577 .707 r
F P
0 g
s
.70532 .75739 m .70683 .77449 L .73796 .7754 L p .707 .577 .707 r
F P
0 g
s
.83075 .70234 m .83607 .66438 L .82055 .65984 L p .707 .577 .707 r
F P
0 g
s
.79735 .74679 m .79886 .76389 L .82268 .7526 L p .707 .577 .707 r
F P
0 g
s
.82268 .7526 m .82117 .7355 L .79735 .74679 L p .707 .577 .707 r
F P
0 g
s
.67782 .75201 m .67933 .7691 L .70683 .77449 L p .707 .577 .707 r
F P
0 g
s
.67933 .7691 m .67782 .75201 L .65664 .74268 L p .707 .577 .707 r
F P
0 g
s
.82117 .7355 m .82268 .7526 L .83878 .73898 L p .707 .577 .707 r
F P
0 g
s
.83878 .73898 m .83727 .72188 L .82117 .7355 L p .707 .577 .707 r
F P
0 g
s
.65664 .74268 m .65815 .75978 L .67933 .7691 L p .707 .577 .707 r
F P
0 g
s
.83607 .66438 m .83075 .70234 L .83698 .70588 L p .707 .577 .707 r
F P
0 g
s
.83698 .70588 m .84231 .66793 L .83607 .66438 L p .707 .577 .707 r
F P
0 g
s
.8406 .57236 m .8444 .62452 L .84133 .61123 L p .707 .577 .707 r
F P
0 g
s
.84133 .61123 m .83754 .55907 L .8406 .57236 L p .707 .577 .707 r
F P
0 g
s
.65815 .75978 m .65664 .74268 L .64386 .73032 L p .707 .577 .707 r
F P
0 g
s
.64087 .63141 m .63707 .57925 L .64397 .56563 L p .707 .577 .707 r
F P
0 g
s
.64386 .73032 m .64537 .74741 L .65815 .75978 L p .707 .577 .707 r
F P
0 g
s
.83727 .72188 m .83878 .73898 L .8456 .72436 L p .707 .577 .707 r
F P
0 g
s
.8456 .72436 m .84409 .70726 L .83727 .72188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84231 .66793 m .83698 .70588 L .83332 .70809 L p .707 .577 .707 r
F P
0 g
s
.83754 .55907 m .84133 .61123 L .82861 .59958 L p .707 .577 .707 r
F P
0 g
s
.82861 .59958 m .82481 .54742 L .83754 .55907 L p .707 .577 .707 r
F P
0 g
s
.83332 .70809 m .83865 .67013 L .84231 .66793 L p .707 .577 .707 r
F P
0 g
s
.64537 .74741 m .64386 .73032 L .64072 .71614 L p .707 .577 .707 r
F P
0 g
s
.64634 .64402 m .64101 .68197 L .63478 .67843 L p .707 .577 .707 r
F P
0 g
s
.64397 .56563 m .64777 .61778 L .64087 .63141 L p .707 .577 .707 r
F P
0 g
s
.64072 .71614 m .64223 .73323 L .64537 .74741 L p .707 .577 .707 r
F P
0 g
s
.64777 .61778 m .64397 .56563 L .66015 .553 L p .707 .577 .707 r
F P
0 g
s
.84409 .70726 m .8456 .72436 L .84247 .71018 L p .707 .577 .707 r
F P
0 g
s
.84247 .71018 m .84095 .69308 L .84409 .70726 L p .707 .577 .707 r
F P
0 g
s
.38962 .58255 m .35848 .58148 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .38962 .58255 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.3887 .64603 m .42015 .65073 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .3887 .64603 L p .3993 .62455 L .707 .577 .707 r
F P
0 g
s
.40145 .62019 m .39235 .62003 L .3993 .62455 L .707 .577 .707 r
F
.3887 .64603 m .39235 .62003 L p .37172 .61847 L F P
0 g
s
.35766 .64225 m .3887 .64603 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .35766 .64225 L p .36885 .62332 L .707 .577 .707 r
F P
0 g
s
.37172 .61847 m .36111 .61766 L .36885 .62332 L .707 .577 .707 r
F
.35848 .58148 m .33099 .57625 L p .34856 .60848 L F P
0 g
s
.35293 .61649 m .36111 .61766 L .34856 .60848 L .707 .577 .707 r
F
.36111 .61766 m .35848 .58148 L p .34856 .60848 L F P
0 g
s
.3774 .61029 m .37689 .60996 L .36228 .63364 L .707 .577 .707 r
F
.35974 .5988 m .36111 .61766 L p .37689 .60996 L F P
0 g
s
.36111 .61766 m .36228 .63364 L p .37689 .60996 L .707 .577 .707 r
F P
0 g
s
.35766 .64225 m .36111 .61766 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .35766 .64225 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33007 .63974 L p .34009 .62011 L .707 .577 .707 r
F P
0 g
s
.34268 .61502 m .33372 .61374 L .34009 .62011 L .707 .577 .707 r
F
.33099 .57625 m .30985 .56738 L p .32539 .6054 L F P
0 g
s
.32825 .6124 m .33372 .61374 L .32539 .6054 L .707 .577 .707 r
F
.33372 .61374 m .33099 .57625 L p .32539 .6054 L F P
0 g
s
.33099 .57625 m .33372 .61374 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .33372 .61374 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .33007 .63974 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .30863 .63876 L p .31618 .61463 L .707 .577 .707 r
F P
0 g
s
.31768 .60982 m .31285 .60864 L .31618 .61463 L .707 .577 .707 r
F
.30985 .56738 m .29713 .55573 L p .30905 .60178 L F P
0 g
s
.31285 .60864 m .30985 .56738 L p .30905 .60178 L .707 .577 .707 r
F P
0 g
s
.30985 .56738 m .31285 .60864 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .31285 .60864 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .30111 .60312 L .30084 .60484 L .707 .577 .707 r
F
.29543 .63941 m .30573 .6389 L p .30084 .60484 L F P
0 g
s
.30573 .6389 m .30863 .63876 L p .30084 .60484 L .707 .577 .707 r
F P
0 g
s
.29713 .55573 m .29406 .54244 L p .29996 .59871 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .29543 .63941 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.29543 .63941 m .30056 .60286 L p .2971 .60365 L .707 .577 .707 r
F P
0 g
s
.30034 .60237 m .30056 .60286 L .29996 .59871 L .707 .577 .707 r
F
.30056 .60286 m .29713 .55573 L p .29996 .59871 L F P
0 g
s
.29713 .55573 m .30056 .60286 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30012 .60184 m .2971 .60365 L p .30056 .60286 L .707 .577 .707 r
F P
0 g
s
.29406 .54244 m .29786 .5946 L .29792 .59487 L p .707 .577 .707 r
F P
0 g
s
.29792 .59487 m .30092 .60789 L p .2963 .56382 L .707 .577 .707 r
F P
0 g
s
.2963 .56382 m .29406 .54244 L .29792 .59487 L .707 .577 .707 r
F
.2971 .60365 m .29177 .64161 L .29543 .63941 L p F P
0 g
s
.29177 .64161 m .2971 .60365 L .29842 .60441 L p .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .30056 .60286 L p .30034 .60237 L .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .31365 .61954 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .30092 .60789 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.29842 .60441 m .30333 .6072 L p .2992 .61948 L .707 .577 .707 r
F P
0 g
s
.29177 .64161 m .29842 .60441 L .2992 .61948 L .707 .577 .707 r
F
.30056 .60286 m .30076 .60145 L .30012 .60184 L p F P
0 g
s
.30076 .60145 m .30056 .60286 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .30076 .60145 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31054 .60755 m .31285 .60864 L .30905 .60178 L .707 .577 .707 r
F
.31285 .60864 m .31395 .60081 L p .30111 .60312 L F P
0 g
s
.31365 .61954 m .31285 .60864 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.31365 .61954 m .33479 .62841 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .31365 .61954 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .31285 .60864 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .31395 .60081 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .3354 .60179 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .33372 .61374 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .36228 .63364 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33479 .62841 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .33372 .61374 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .3354 .60179 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .36299 .60429 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .36111 .61766 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .36111 .61766 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .39342 .6347 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.38334 .61935 m .3774 .61029 L .37208 .61849 L .707 .577 .707 r
F
.38334 .61935 m .37208 .61849 L .36228 .63364 L F
.35848 .58148 m .35974 .5988 L p .3774 .61029 L F P
0 g
s
.38962 .58255 m .39235 .62003 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .38962 .58255 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42137 .57935 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .44892 .65588 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42015 .65073 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .42438 .62061 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .42137 .57935 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45062 .5722 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .45405 .61934 L p .4783 .61396 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .47221 .66098 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .44892 .65588 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.47061 .61731 m .4783 .61396 L p .45405 .61934 L .707 .577 .707 r
F P
0 g
s
.47221 .66098 m .47754 .62302 L .45425 .61793 L p .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45442 .62436 L .47061 .61731 L p .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .45405 .61934 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .42548 .61278 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .45405 .61934 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45425 .61793 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45442 .62436 m .45405 .61934 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .45442 .62436 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42517 .63151 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .42438 .62061 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .39403 .60808 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .42438 .62061 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42548 .61278 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .42438 .62061 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .42517 .63151 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39342 .6347 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .39235 .62003 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .36299 .60429 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39403 .60808 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .39235 .62003 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82481 .54742 m .82861 .59958 L .80747 .59071 L p .707 .577 .707 r
F P
0 g
s
.80747 .59071 m .80367 .53855 L .82481 .54742 L p .707 .577 .707 r
F P
0 g
s
.83865 .67013 m .83332 .70809 L .82013 .70873 L p .707 .577 .707 r
F P
0 g
s
.4783 .61396 m .47451 .56181 L .45062 .5722 L p .707 .577 .707 r
F P
0 g
s
.82013 .70873 m .82545 .67077 L .83865 .67013 L p .707 .577 .707 r
F P
0 g
s
.64223 .73323 m .64072 .71614 L .64754 .70152 L p .707 .577 .707 r
F P
0 g
s
.66015 .553 m .66395 .60515 L .64777 .61778 L p .707 .577 .707 r
F P
0 g
s
.66395 .60515 m .66015 .553 L .68404 .5426 L p .707 .577 .707 r
F P
0 g
s
.66187 .64856 m .65654 .68652 L .64101 .68197 L p .707 .577 .707 r
F P
0 g
s
.64101 .68197 m .64634 .64402 L .66187 .64856 L p .707 .577 .707 r
F P
0 g
s
.64754 .70152 m .64905 .71861 L .64223 .73323 L p .707 .577 .707 r
F P
0 g
s
.84095 .69308 m .84247 .71018 L .82968 .69782 L p .707 .577 .707 r
F P
0 g
s
.82968 .69782 m .82817 .68072 L .84095 .69308 L p .707 .577 .707 r
F P
0 g
s
.80367 .53855 m .80747 .59071 L .77998 .58548 L p .707 .577 .707 r
F P
0 g
s
.77998 .58548 m .77618 .53332 L .80367 .53855 L p .707 .577 .707 r
F P
0 g
s
.47451 .56181 m .4783 .61396 L .49449 .60133 L p .707 .577 .707 r
F P
0 g
s
.49449 .60133 m .49069 .54918 L .47451 .56181 L p .707 .577 .707 r
F P
0 g
s
.68784 .59476 m .68404 .5426 L .71329 .53545 L p .707 .577 .707 r
F P
0 g
s
.68404 .5426 m .68784 .59476 L .66395 .60515 L p .707 .577 .707 r
F P
0 g
s
.82545 .67077 m .82013 .70873 L .79868 .70775 L p .707 .577 .707 r
F P
0 g
s
.79868 .70775 m .80401 .6698 L .82545 .67077 L p .707 .577 .707 r
F P
0 g
s
.68516 .65366 m .67983 .69161 L .65654 .68652 L p .707 .577 .707 r
F P
0 g
s
.64905 .71861 m .64754 .70152 L .66364 .6879 L p .707 .577 .707 r
F P
0 g
s
.77618 .53332 m .77998 .58548 L .74884 .58441 L p .707 .577 .707 r
F P
0 g
s
.74884 .58441 m .74504 .53226 L .77618 .53332 L p .707 .577 .707 r
F P
0 g
s
.39495 .73858 m .39344 .72149 L .36231 .72058 L p .707 .577 .707 r
F P
0 g
s
.39344 .72149 m .39495 .73858 L .42666 .73493 L p .707 .577 .707 r
F P
0 g
s
.42666 .73493 m .42515 .71783 L .39344 .72149 L p .707 .577 .707 r
F P
0 g
s
.65654 .68652 m .66187 .64856 L .68516 .65366 L p .707 .577 .707 r
F P
0 g
s
.42515 .71783 m .42666 .73493 L .45585 .72707 L p .707 .577 .707 r
F P
0 g
s
.45585 .72707 m .45434 .70998 L .42515 .71783 L p .707 .577 .707 r
F P
0 g
s
.71709 .58761 m .71329 .53545 L .74504 .53226 L p .707 .577 .707 r
F P
0 g
s
.71329 .53545 m .71709 .58761 L .68784 .59476 L p .707 .577 .707 r
F P
0 g
s
.74504 .53226 m .74884 .58441 L .71709 .58761 L p .707 .577 .707 r
F P
0 g
s
.66364 .6879 m .66515 .70499 L .64905 .71861 L p .707 .577 .707 r
F P
0 g
s
.47754 .62302 m .47221 .66098 L .48774 .66552 L p .707 .577 .707 r
F P
0 g
s
.82817 .68072 m .82968 .69782 L .80851 .68849 L p .707 .577 .707 r
F P
0 g
s
.80851 .68849 m .807 .67139 L .82817 .68072 L p .707 .577 .707 r
F P
0 g
s
.49069 .54918 m .49449 .60133 L .50139 .58771 L p .707 .577 .707 r
F P
0 g
s
.50139 .58771 m .49759 .53555 L .49069 .54918 L p .707 .577 .707 r
F P
0 g
s
.36382 .73767 m .36231 .72058 L .33481 .71519 L p .707 .577 .707 r
F P
0 g
s
.36231 .72058 m .36382 .73767 L .39495 .73858 L p .707 .577 .707 r
F P
0 g
s
.48774 .66552 m .49306 .62757 L .47754 .62302 L p .707 .577 .707 r
F P
0 g
s
.45434 .70998 m .45585 .72707 L .47967 .71578 L p .707 .577 .707 r
F P
0 g
s
.47967 .71578 m .47816 .69869 L .45434 .70998 L p .707 .577 .707 r
F P
0 g
s
.80401 .6698 m .79868 .70775 L .77109 .70524 L p .707 .577 .707 r
F P
0 g
s
.33481 .71519 m .33632 .73229 L .36382 .73767 L p .707 .577 .707 r
F P
0 g
s
.77109 .70524 m .77642 .66729 L .80401 .6698 L p .707 .577 .707 r
F P
0 g
s
.67983 .69161 m .68516 .65366 L .71393 .6588 L p .707 .577 .707 r
F P
0 g
s
.66515 .70499 m .66364 .6879 L .68746 .67661 L p .707 .577 .707 r
F P
0 g
s
.71393 .6588 m .7086 .69676 L .67983 .69161 L p .707 .577 .707 r
F P
0 g
s
.33632 .73229 m .33481 .71519 L .31363 .70586 L p .707 .577 .707 r
F P
0 g
s
.807 .67139 m .80851 .68849 L .78101 .6831 L p .707 .577 .707 r
F P
0 g
s
.78101 .6831 m .7795 .66601 L .807 .67139 L p .707 .577 .707 r
F P
0 g
s
.68746 .67661 m .68897 .6937 L .66515 .70499 L p .707 .577 .707 r
F P
0 g
s
.47816 .69869 m .47967 .71578 L .49577 .70216 L p .707 .577 .707 r
F P
0 g
s
.49577 .70216 m .49426 .68507 L .47816 .69869 L p .707 .577 .707 r
F P
0 g
s
.77642 .66729 m .77109 .70524 L .74005 .70146 L p .707 .577 .707 r
F P
0 g
s
.31363 .70586 m .31514 .72296 L .33632 .73229 L p .707 .577 .707 r
F P
0 g
s
.49306 .62757 m .48774 .66552 L .49397 .66907 L p .707 .577 .707 r
F P
0 g
s
.74005 .70146 m .74538 .6635 L .77642 .66729 L p .707 .577 .707 r
F P
0 g
s
.74538 .6635 m .74005 .70146 L .7086 .69676 L p .707 .577 .707 r
F P
0 g
s
.7086 .69676 m .71393 .6588 L .74538 .6635 L p .707 .577 .707 r
F P
0 g
s
.49397 .66907 m .4993 .63111 L .49306 .62757 L p .707 .577 .707 r
F P
0 g
s
.49759 .53555 m .50139 .58771 L .49832 .57442 L p .707 .577 .707 r
F P
0 g
s
.49832 .57442 m .49453 .52226 L .49759 .53555 L p .707 .577 .707 r
F P
0 g
s
.68897 .6937 m .68746 .67661 L .71665 .66875 L p .707 .577 .707 r
F P
0 g
s
.7795 .66601 m .78101 .6831 L .74987 .68219 L p .707 .577 .707 r
F P
0 g
s
.74987 .68219 m .74836 .6651 L .7795 .66601 L p .707 .577 .707 r
F P
0 g
s
.31514 .72296 m .31363 .70586 L .30085 .6935 L p .707 .577 .707 r
F P
0 g
s
.71665 .66875 m .71816 .68585 L .68897 .6937 L p .707 .577 .707 r
F P
0 g
s
.71816 .68585 m .71665 .66875 L .74836 .6651 L p .707 .577 .707 r
F P
0 g
s
.74836 .6651 m .74987 .68219 L .71816 .68585 L p .707 .577 .707 r
F P
0 g
s
.29786 .5946 m .29406 .54244 L .30096 .52881 L p .707 .577 .707 r
F P
0 g
s
.30085 .6935 m .30236 .7106 L .31514 .72296 L p .707 .577 .707 r
F P
0 g
s
.49426 .68507 m .49577 .70216 L .50259 .68754 L p .707 .577 .707 r
F P
0 g
s
.50259 .68754 m .50108 .67045 L .49426 .68507 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4993 .63111 m .49397 .66907 L .49031 .67127 L p .707 .577 .707 r
F P
0 g
s
.49453 .52226 m .49832 .57442 L .4856 .56276 L p .707 .577 .707 r
F P
0 g
s
.4856 .56276 m .4818 .51061 L .49453 .52226 L p .707 .577 .707 r
F P
0 g
s
.49031 .67127 m .49564 .63332 L .4993 .63111 L p .707 .577 .707 r
F P
0 g
s
.30236 .7106 m .30085 .6935 L .29771 .67932 L p .707 .577 .707 r
F P
0 g
s
.30333 .6072 m .298 .64516 L .29177 .64161 L p .707 .577 .707 r
F P
0 g
s
.30096 .52881 m .30476 .58097 L .29786 .5946 L p .707 .577 .707 r
F P
0 g
s
.29771 .67932 m .29922 .69642 L .30236 .7106 L p .707 .577 .707 r
F P
0 g
s
.30476 .58097 m .30096 .52881 L .31714 .51618 L p .707 .577 .707 r
F P
0 g
s
.50108 .67045 m .50259 .68754 L .49945 .67336 L p .707 .577 .707 r
F P
0 g
s
.49945 .67336 m .49794 .65627 L .50108 .67045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4818 .51061 m .4856 .56276 L .46446 .55389 L p .707 .577 .707 r
F P
0 g
s
.46446 .55389 m .46066 .50173 L .4818 .51061 L p .707 .577 .707 r
F P
0 g
s
.49564 .63332 m .49031 .67127 L .47712 .67191 L p .707 .577 .707 r
F P
0 g
s
.47712 .67191 m .48244 .63396 L .49564 .63332 L p .707 .577 .707 r
F P
0 g
s
.29922 .69642 m .29771 .67932 L .30453 .6647 L p .707 .577 .707 r
F P
0 g
s
.31714 .51618 m .32094 .56834 L .30476 .58097 L p .707 .577 .707 r
F P
0 g
s
.32094 .56834 m .31714 .51618 L .34103 .50578 L p .707 .577 .707 r
F P
0 g
s
.31886 .61174 m .31353 .6497 L .298 .64516 L p .707 .577 .707 r
F P
0 g
s
.298 .64516 m .30333 .6072 L .31886 .61174 L p .707 .577 .707 r
F P
0 g
s
.30453 .6647 m .30604 .6818 L .29922 .69642 L p .707 .577 .707 r
F P
0 g
s
.49794 .65627 m .49945 .67336 L .48667 .661 L p .707 .577 .707 r
F P
0 g
s
.48667 .661 m .48516 .6439 L .49794 .65627 L p .707 .577 .707 r
F P
0 g
s
.46066 .50173 m .46446 .55389 L .43697 .54867 L p .707 .577 .707 r
F P
0 g
s
.43697 .54867 m .43317 .49651 L .46066 .50173 L p .707 .577 .707 r
F P
0 g
s
.34483 .55794 m .34103 .50578 L .37028 .49864 L p .707 .577 .707 r
F P
0 g
s
.34103 .50578 m .34483 .55794 L .32094 .56834 L p .707 .577 .707 r
F P
0 g
s
.48244 .63396 m .47712 .67191 L .45567 .67094 L p .707 .577 .707 r
F P
0 g
s
.45567 .67094 m .461 .63298 L .48244 .63396 L p .707 .577 .707 r
F P
0 g
s
.34215 .61684 m .33682 .6548 L .31353 .6497 L p .707 .577 .707 r
F P
0 g
s
.30604 .6818 m .30453 .6647 L .32063 .65108 L p .707 .577 .707 r
F P
0 g
s
.43317 .49651 m .43697 .54867 L .40583 .5476 L p .707 .577 .707 r
F P
0 g
s
.40583 .5476 m .40203 .49544 L .43317 .49651 L p .707 .577 .707 r
F P
0 g
s
.31353 .6497 m .31886 .61174 L .34215 .61684 L p .707 .577 .707 r
F P
0 g
s
.37408 .55079 m .37028 .49864 L .40203 .49544 L p .707 .577 .707 r
F P
0 g
s
.37028 .49864 m .37408 .55079 L .34483 .55794 L p .707 .577 .707 r
F P
0 g
s
.40203 .49544 m .40583 .5476 L .37408 .55079 L p .707 .577 .707 r
F P
0 g
s
.32063 .65108 m .32214 .66818 L .30604 .6818 L p .707 .577 .707 r
F P
0 g
s
.48516 .6439 m .48667 .661 L .46549 .65167 L p .707 .577 .707 r
F P
0 g
s
.46549 .65167 m .46398 .63458 L .48516 .6439 L p .707 .577 .707 r
F P
0 g
s
.461 .63298 m .45567 .67094 L .42808 .66843 L p .707 .577 .707 r
F P
0 g
s
.42808 .66843 m .43341 .63047 L .461 .63298 L p .707 .577 .707 r
F P
0 g
s
.33682 .6548 m .34215 .61684 L .37092 .62199 L p .707 .577 .707 r
F P
0 g
s
.32214 .66818 m .32063 .65108 L .34445 .63979 L p .707 .577 .707 r
F P
0 g
s
.37092 .62199 m .36559 .65994 L .33682 .6548 L p .707 .577 .707 r
F P
0 g
s
.46398 .63458 m .46549 .65167 L .43799 .64629 L p .707 .577 .707 r
F P
0 g
s
.43799 .64629 m .43648 .62919 L .46398 .63458 L p .707 .577 .707 r
F P
0 g
s
.34445 .63979 m .34596 .65689 L .32214 .66818 L p .707 .577 .707 r
F P
0 g
s
.43341 .63047 m .42808 .66843 L .39704 .66464 L p .707 .577 .707 r
F P
0 g
s
.39704 .66464 m .40237 .62669 L .43341 .63047 L p .707 .577 .707 r
F P
0 g
s
.40237 .62669 m .39704 .66464 L .36559 .65994 L p .707 .577 .707 r
F P
0 g
s
.36559 .65994 m .37092 .62199 L .40237 .62669 L p .707 .577 .707 r
F P
0 g
s
.34596 .65689 m .34445 .63979 L .37364 .63194 L p .707 .577 .707 r
F P
0 g
s
.43648 .62919 m .43799 .64629 L .40686 .64538 L p .707 .577 .707 r
F P
0 g
s
.40686 .64538 m .40535 .62828 L .43648 .62919 L p .707 .577 .707 r
F P
0 g
s
.37364 .63194 m .37515 .64903 L .34596 .65689 L p .707 .577 .707 r
F P
0 g
s
.37515 .64903 m .37364 .63194 L .40535 .62828 L p .707 .577 .707 r
F P
0 g
s
.40535 .62828 m .40686 .64538 L .37515 .64903 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00LWoo10000UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001^Ool40006FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool0
06Yoo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001P0015YF00<005YF
FUH00UYF200015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001POol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000GOol?000oOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Qoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF1@001EYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00Dgoo00@005YFFUH000AJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEP000003FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00@005YFFUH000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00`0000EJEP00FUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005Ool00000FUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00@005YF000000Eoo`04001JEUYF
0006FUH50004FUH00`00FUIJEP09FUH40002FUH20002FUH200000eYF001JEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
001COol01000FUIJEP0015YF0P001goo00@005YFFUH000IJEPD000AJEP03001JEUYF00QJEP80009J
EP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF0`00
1goo00@005YFFUH000IJEPD000AJEP03001JEUYF00AJEP@000AJEP03001JEUYF009JEP@00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH20003FUH30004Ool01000FUIJEP001UYF1000
1EYF00<005YFFUH010000UYF00<005YFFUH00eYF00<005YFFUH00UYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP00;Woo001DOol00`00FUH000020005FUH00`00FUH000040002FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH70006FUH00`00FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo001DOol01@00FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00@Goo5@000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000moo`@0009JEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool003ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000IOol40004FUH0
1@00FUIJEUYF0000;Goo000kOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF10002goo0`004goo0`0000=JEP00FUH00UYF
00<007ooOol0:goo000hOol30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH40002FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000=JEP04001JEUYFFUH2000>Ool5000BOol200000eYF00000003FUH00`00Oomoo`0[Ool0
03Eoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EUYF010000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00@005YF0000011oo`D0011oo`800003FUH005YF009JEP04001JEUYF000]Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP@000IJEP03001JEUYF00EJEP03001J
EUYF009JEPH000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP80019o
o`D000ioo`8000=JEP03001JEUYF009JEP<002eoo`00<Woo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP<001=oo`<000aoo`<000EJ
EP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPL000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH5000IOol400000eYF
001JEP05FUH00`00FUIJEP02FUH01000FUH00000;7oo000_Ool01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000UYF0P002EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEPT0
00Uoo`L000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP04FUH40003FUH40005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH@0002FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00000`00
1EYF00<005YFFUH00eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00005FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP`00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFOol5FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00004FUH005YF0004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP0200000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/
Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`800003FUH005YF
00=JEP03001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00800004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH010004Goo10000UYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF
009JEPl000IJEP04001JEUYFFUH20002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo000/Ool01000FUIJEP0015YF00<0
05YFFUH00eYF10006Goo100000=JEP00000015YF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH2000bOol002aoo`04001JEUYF0004FUH01000
FUIJEUYF0P003Woo0`0047oo00<005YFFUH015YF00<005YFFUH0100025YF00<005YFFUH01UYF00<0
05YFFUH01EYF10000eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001oogoo035oo`00;7oo00@005YF
FUH000AJEP04001JEP00000?Ool5000>Ool20006FUH30002FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUH00004
0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH7000dOol002aoo`04001JEUYF0004FUH2000AOol5
000<Ool200000eYF001JEP03FUH200000eYF000000050006FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00eYF1`000UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00001P00<Woo000]Ool00`00FUH00003FUH00`00Oomoo`0AOol5
000;Ool01@00FUIJEUYF00000UYF0P0015YF00@005YFFUH0009JEP@0009JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPT0009JEP03001JEUYF00AJEP<000EJEP03001JEP00008002moo`00;Goo00@005YF001J
EP800003FUH00000019oo`<000Qoo`@000AJEP<00003FUH005YF00=JEP04001JEUYF0005FUH80004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00=JEQ400003FUH005YF00EJEP03001JEUYF009JEP8002eoo`00;Goo00<005YF00000P00
15YF1@004Goo1`000UYF0P0015YF00D005YFFUIJEP0000AJEP04001JEUYF0005FUH00`00FUIJEP05
FUH?0003FUH00`00FUIJEP06000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP06FUH01000FUIJ
EUYF3`00;Goo000]Ool01@00FUH005YF00001EYF00@005YFFUIJEQ4000AJEP03001JEUYF009JEP80
00=JEP03001JEUYF009JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH70003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH30002FUH01000FUIJEUYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`001EYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP<000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001o
ogoo02aoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP00009JEP03001JEP0000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00
FUIJEP04FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000000^Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH00`00FUH00006FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000800003FUH005YF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00@000IJEPP0
00AJEP03001JEUYF00=JEP@002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000Woo1@001EYF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00@005YF000002ioo`00;Goo
0P000UYF10000UYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004Ool20006FUH00`00FUIJEP040008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH01000FUIJEP00;Woo000]Ool00`00FUIJEP02FUH00`00FUIJEP0@0003
FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00UJEP03001JEUYF009JEP04001JEUYFFUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool00`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0[Ool002eoo`05FUH00000FUH00006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH60006FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP0000AJ
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
Ool01@00FUIJEUYF00000eYF0P000eYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`000eYF00<007ooOol0:goo000]Ool2FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000030002FUH01P00FUIJEUYF001JEP800003FUH005YF00AJEP<00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020004FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001JEP000080
00AJEP03001JEP0000Eoo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00Oomoo`0[Ool002aoo`04001JEUYF0002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7
0003FUH20005FUH01@00Oomoogoo00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF0P000UYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00008000AJEP80009JEP03001JEUYF009JEP04001JEP00000=Ool8
0004FUH00`00FUIJEP03FUH00`00FUIJEP04000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0`000UYF0P0017oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF
009JEP03001JEUYF009JEP04001JEP00000EOol>0002Ool00`00Oomoo`0[Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH00`001Goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP06001JEP00FUH005YF0P001EYF00<005YFFUH00UYF00@005YFFUH002Aoo`8002eoo`00;7oo0UYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100025YF00<005YFFUH0
0UYF00@005YFFUH000AJEPD00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP030004
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0`001UYF00<005YFFUH00UYF00@005YFFUH000Moo`<001Yoo`8002eo
o`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1`00
00AJEP00FUIJEPH000EJEP04001JEUYFFUH80002FUH00`00FUIJEP04FUH60007FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF
001JEP00FUH00007FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000/Ool2FUH0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000[Ool01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo00Ioo`D001Moo`80009JEP03001oogoo02Yoo`00:goo00<005YF
000015YF00<005YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`07Ool3000GOol0
1@00FUH005YF0000;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00008goo00@005YF
FUIJEP8002eoo`00;7oo10000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF2`0015YF00<005YFFUH01@002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00
0UYF00<005YFFUH015YF00@005YF0000029oo`8000AJEP03001oogoo02aoo`00<7oo10000UYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001UYF0P008Woo0P0000=JEP00FUH0
0eYF00<007ooOol0;7oo000dOol20005FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH50004FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH000000UYF0P001UYF00<007ooOol07goo0P000eYF00D005YFFUIJEP0002moo`00<goo
0P001UYF00<005YFFUH0100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EP0000D001moo`<000EJEP04001JEP00000`Ool0035oo`800003FUH005YF00AJEPT000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEP00FUH005YF000015YF1@006Goo100000=JEP00FUH01EYF0P00<Woo000`Ool01@00
FUIJEUYF00000eYF0P002Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF000015YF00<005YF000010003goo1`00
1EYF00<005YFFUH015YF00<007ooOol0<Goo000_Ool00`00FUIJEP02FUH01000FUH000003goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF
009JEP03001JEP0000D000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2
000dOol002ioo`8000AJEP8001Qoo`l000=JEP03001JEUYF0080009JEP03001JEUYF00=JEP<0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000EJEP8000AJ
EP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH00000=Woo000^Ool20003FUH00`00Oomoo`0WOol600001Goo
001JEUYF00000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF0P001eYF0`0000=JEP00FUH00eYF00<005YF00001EYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>7oo000]Ool01P00FUIJEP00FUH0035oo`05
001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH20008FUH01000FUH0000015YF00<005YF00001eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000?7oo000]Ool00`00FUIJEP02000FOol3000IOol00`00FUIJEP020000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH2
0008FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01P0000=JEP00FUH01eYF00<0
05YFFUH00UYF1`00@7oo000]Ool01000FUIJEP005Woo1@0067oo00<005YF00000eYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF0P0025YF00<0
05YFFUH00eYF0`0000=JEP0000001UYF00<005YFFUH00UYF0P0000=JEP0000003P00Agoo000]Ool0
0`00FUH0000GOol5000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04
0002FUH00`00FUIJEP03FUH4001EOol002ioo`8001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000005FUH30005FUH01000FUH00000EGoo000^Ool00`00Oomoo`0GOol3
000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00P00
0eYF00D005YFFUIJEP0005Aoo`00;Woo0P00<Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`1B
Ool002ioo`03001JEP0002moo`03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001oogoo059oo`00;Woo00@005YF
FUH002aoo`<000AJEP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD000AJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00Oomoo`1BOol002ioo`04001JEUYFFUH2000XOol20002FUH01@00FUIJ
EUYF00000goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo4@00E7oo000^Ool01P00FUIJEUYF001JEP<0
025oo`@000EJEP03001JEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2000EOol2001DOol002moo`04001J
EUYF0004FUH3000JOol40002FUH00`00FUIJEP04FUH20009Ool40002FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000005goo0P00
E7oo000`Ool00`00FUH00005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000>Ool5
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH7000HOol0
1000FUH00000Dgoo000aOol20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P005Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1@000Woo1@00
67oo00@005YFFUH005=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000001eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPH0
00Ioo`D001Moo`80009JEP03001oogoo055oo`00=7oo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH015YF0`00:7oo6@0037oo1@005Woo00D005YF001JEP0005Aoo`00
=goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P006Goo0`005Woo
00@005YFFUIJEP8005Aoo`00>Woo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00
;goo0P0015YF00<007ooOol0Dgoo000nOol@0011Ool200000eYF001oo`0[Ool200000eYF001JEP03
FUH00`00Oomoo`1COol008moo`80009JEP03001oogoo02Moo`8000=JEP05001JEUYFFUH0001FOol0
091oo`03001JEUYF00<002Aoo`<000EJEP04001JEP00001GOol0091oo`04001JEUYF0002FUH2000P
Ool200000eYF001JEP05FUH2001IOol0095oo`04001JEUYF0003FUH5000HOol30003FUH00`00FUIJ
EP04FUH00`00Oomoo`1HOol0099oo`<000AJEP04001JEUYFFUH90009Ool60007FUH01000FUIJEUYF
0P00Fgoo002DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP06FUH01000FUH00000GGoo002EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3001OOol009Moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<0069oo`00VGoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P00IGoo002NOol80004FUH00`00FUIJEP02FUH6001XOol00:Ioo`T006ioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59556 .70474 m .5644 .70337 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59556 .70474 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59449 .78841 m .62618 .79101 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59449 .78841 L p .59916 .75385 L .707 .577 .707 r
F P
0 g
s
.59936 .75234 m .59764 .75234 L .59916 .75385 L .707 .577 .707 r
F
.59449 .78841 m .59764 .75234 L p .56889 .75032 L F P
0 g
s
.56337 .78535 m .59449 .78841 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56337 .78535 L p .56855 .75246 L .707 .577 .707 r
F P
0 g
s
.56889 .75032 m .56645 .75015 L .56855 .75246 L .707 .577 .707 r
F
.5644 .70337 m .53693 .69845 L p .55916 .74213 L F P
0 g
s
.56298 .74963 m .56645 .75015 L .55916 .74213 L .707 .577 .707 r
F
.56645 .75015 m .5644 .70337 L p .55916 .74213 L F P
0 g
s
.58885 .74353 m .58222 .73689 L .56675 .75703 L .707 .577 .707 r
F
.56512 .71976 m .56645 .75015 L p .58222 .73689 L F P
0 g
s
.56645 .75015 m .56675 .75703 L p .58222 .73689 L .707 .577 .707 r
F P
0 g
s
.56337 .78535 m .56645 .75015 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .56337 .78535 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53586 .78212 L p .54038 .74808 L .707 .577 .707 r
F P
0 g
s
.54062 .74629 m .53901 .74605 L .54038 .74808 L .707 .577 .707 r
F
.53693 .69845 m .51584 .69048 L p .53431 .73904 L F P
0 g
s
.51584 .69048 m .5032 .68024 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.52079 .74118 m .518 .74077 L p .53901 .74605 L .707 .577 .707 r
F P
0 g
s
.518 .74077 m .51466 .77904 L .53348 .78178 L p .707 .577 .707 r
F P
0 g
s
.53348 .78178 m .53586 .78212 L p .51914 .74341 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .518 .74077 L .53348 .78178 L .707 .577 .707 r
F
.51466 .77904 m .518 .74077 L .50518 .73814 L p F P
0 g
s
.50555 .73391 m .51819 .74415 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.5032 .68024 m .50422 .70349 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.50422 .70349 m .50555 .73391 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51819 .74415 m .51803 .74044 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51803 .74044 m .51584 .69048 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .53901 .74605 L p .51817 .74081 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .51817 .74081 L .518 .74077 L .707 .577 .707 r
F
.53586 .78212 m .51817 .74081 L .51914 .74341 L F
.53674 .74544 m .53901 .74605 L .53431 .73904 L F
.53901 .74605 m .53693 .69845 L p .53431 .73904 L F P
0 g
s
.53693 .69845 m .53901 .74605 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.51584 .69048 m .51819 .74415 L .53928 .75212 L p .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53921 .74385 L .52079 .74118 L p .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .53901 .74605 L p .53674 .74544 L .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .56675 .75703 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53928 .75212 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53921 .74385 m .53901 .74605 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .53921 .74385 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56672 .74708 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .56645 .75015 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .56645 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .59791 .75841 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59406 .75209 m .58885 .74353 L .57683 .75088 L .707 .577 .707 r
F
.59406 .75209 m .57683 .75088 L .56675 .75703 L F
.5644 .70337 m .56512 .71976 L p .58885 .74353 L F P
0 g
s
.59556 .70474 m .59764 .75234 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62952 .75274 L .62535 .7524 L p .707 .577 .707 r
F P
0 g
s
.62535 .7524 m .59784 .75015 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62535 .7524 L .59936 .75234 L .707 .577 .707 r
F
.62736 .70245 m .59556 .70474 L p .62724 .7524 L F P
0 g
s
.62952 .75274 m .62618 .79101 L .65533 .79288 L p .707 .577 .707 r
F P
0 g
s
.65533 .79288 m .65867 .75461 L .62952 .75274 L p .707 .577 .707 r
F P
0 g
s
.62971 .75612 m .62955 .75241 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62955 .75241 m .62736 .70245 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .62971 .75612 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59791 .75841 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .59764 .75234 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .56672 .74708 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59784 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .59764 .75234 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.62736 .70245 m .62971 .75612 L .65905 .75039 L p .707 .577 .707 r
F P
0 g
s
.65905 .75039 m .65669 .69672 L .62736 .70245 L p .707 .577 .707 r
F P
0 g
s
.65669 .69672 m .65905 .75039 L .68303 .74176 L p .707 .577 .707 r
F P
0 g
s
.68303 .74176 m .68068 .6881 L .65669 .69672 L p .707 .577 .707 r
F P
0 g
s
.68068 .6881 m .68303 .74176 L .69933 .7311 L p .707 .577 .707 r
F P
0 g
s
.69933 .7311 m .69698 .67744 L .68068 .6881 L p .707 .577 .707 r
F P
0 g
s
.65867 .75461 m .65533 .79288 L .67909 .79385 L p .707 .577 .707 r
F P
0 g
s
.67909 .79385 m .68243 .75558 L .65867 .75461 L p .707 .577 .707 r
F P
0 g
s
.5988 .86257 m .59786 .84483 L .5667 .84355 L p .707 .577 .707 r
F P
0 g
s
.59786 .84483 m .5988 .86257 L .63059 .85999 L p .707 .577 .707 r
F P
0 g
s
.63059 .85999 m .62965 .84225 L .59786 .84483 L p .707 .577 .707 r
F P
0 g
s
.62965 .84225 m .63059 .85999 L .6599 .8538 L p .707 .577 .707 r
F P
0 g
s
.6599 .8538 m .65896 .83606 L .62965 .84225 L p .707 .577 .707 r
F P
0 g
s
.56764 .86129 m .5667 .84355 L .53923 .83854 L p .707 .577 .707 r
F P
0 g
s
.5667 .84355 m .56764 .86129 L .5988 .86257 L p .707 .577 .707 r
F P
0 g
s
.68243 .75558 m .67909 .79385 L .69513 .79382 L p .707 .577 .707 r
F P
0 g
s
.69513 .79382 m .69847 .75555 L .68243 .75558 L p .707 .577 .707 r
F P
0 g
s
.69698 .67744 m .69933 .7311 L .70634 .71945 L p .707 .577 .707 r
F P
0 g
s
.70634 .71945 m .70399 .66578 L .69698 .67744 L p .707 .577 .707 r
F P
0 g
s
.65896 .83606 m .6599 .8538 L .68386 .84461 L p .707 .577 .707 r
F P
0 g
s
.68386 .84461 m .68292 .82687 L .65896 .83606 L p .707 .577 .707 r
F P
0 g
s
.53923 .83854 m .54017 .85627 L .56764 .86129 L p .707 .577 .707 r
F P
0 g
s
.50518 .73814 m .50183 .77641 L .51466 .77904 L p .707 .577 .707 r
F P
0 g
s
.54017 .85627 m .53923 .83854 L .51813 .83028 L p .707 .577 .707 r
F P
0 g
s
.50555 .73391 m .5032 .68024 L .50024 .66873 L p .707 .577 .707 r
F P
0 g
s
.51813 .83028 m .51906 .84802 L .54017 .85627 L p .707 .577 .707 r
F P
0 g
s
.68292 .82687 m .68386 .84461 L .70012 .83331 L p .707 .577 .707 r
F P
0 g
s
.70012 .83331 m .69919 .81558 L .68292 .82687 L p .707 .577 .707 r
F P
0 g
s
.69847 .75555 m .69513 .79382 L .70189 .79279 L p .707 .577 .707 r
F P
0 g
s
.70189 .79279 m .70523 .75452 L .69847 .75555 L p .707 .577 .707 r
F P
0 g
s
.70399 .66578 m .70634 .71945 L .70338 .70793 L p .707 .577 .707 r
F P
0 g
s
.70338 .70793 m .70103 .65427 L .70399 .66578 L p .707 .577 .707 r
F P
0 g
s
.51906 .84802 m .51813 .83028 L .50546 .81958 L p .707 .577 .707 r
F P
0 g
s
.50024 .66873 m .50259 .7224 L .50555 .73391 L p .707 .577 .707 r
F P
0 g
s
.50183 .77641 m .50518 .73814 L .50199 .73622 L p .707 .577 .707 r
F P
0 g
s
.50199 .73622 m .49864 .77448 L .50183 .77641 L p .707 .577 .707 r
F P
0 g
s
.50546 .81958 m .5064 .83732 L .51906 .84802 L p .707 .577 .707 r
F P
0 g
s
.48829 .82105 m .49149 .31708 L .44749 .31429 L p .707 .577 .707 r
F P
0 g
s
.50259 .7224 m .50024 .66873 L .50725 .65707 L p .707 .577 .707 r
F P
0 g
s
.5064 .83732 m .50546 .81958 L .50247 .8075 L p .707 .577 .707 r
F P
0 g
s
.50725 .65707 m .5096 .71074 L .50259 .7224 L p .707 .577 .707 r
F P
0 g
s
.50247 .8075 m .50341 .82524 L .5064 .83732 L p .707 .577 .707 r
F P
0 g
s
.49864 .77448 m .50199 .73622 L .50874 .73519 L p .707 .577 .707 r
F P
0 g
s
.50874 .73519 m .5054 .77346 L .49864 .77448 L p .707 .577 .707 r
F P
0 g
s
.5096 .71074 m .50725 .65707 L .52355 .64641 L p .707 .577 .707 r
F P
0 g
s
.50341 .82524 m .50247 .8075 L .50946 .79521 L p .707 .577 .707 r
F P
0 g
s
.52355 .64641 m .5259 .70008 L .5096 .71074 L p .707 .577 .707 r
F P
0 g
s
.50946 .79521 m .51039 .81295 L .50341 .82524 L p .707 .577 .707 r
F P
0 g
s
.5054 .77346 m .50874 .73519 L .52479 .73516 L p .707 .577 .707 r
F P
0 g
s
.52479 .73516 m .52144 .77342 L .5054 .77346 L p .707 .577 .707 r
F P
0 g
s
.51039 .81295 m .50946 .79521 L .52572 .78392 L p .707 .577 .707 r
F P
0 g
s
.52572 .78392 m .52666 .80166 L .51039 .81295 L p .707 .577 .707 r
F P
0 g
s
.52144 .77342 m .52479 .73516 L .54855 .73612 L p .707 .577 .707 r
F P
0 g
s
.54855 .73612 m .5452 .77439 L .52144 .77342 L p .707 .577 .707 r
F P
0 g
s
.52666 .80166 m .52572 .78392 L .54968 .77473 L p .707 .577 .707 r
F P
0 g
s
.54968 .77473 m .55062 .79247 L .52666 .80166 L p .707 .577 .707 r
F P
0 g
s
.49149 .31708 m .48829 .82105 L .53323 .82028 L p .707 .577 .707 r
F P
0 g
s
.5259 .70008 m .52355 .64641 L .54753 .63779 L p .707 .577 .707 r
F P
0 g
s
.54753 .63779 m .54989 .69146 L .5259 .70008 L p .707 .577 .707 r
F P
0 g
s
.53323 .82028 m .53644 .31631 L .49149 .31708 L p .707 .577 .707 r
F P
0 g
s
.69919 .81558 m .70012 .83331 L .70711 .82102 L p .707 .577 .707 r
F P
0 g
s
.70711 .82102 m .70617 .80329 L .69919 .81558 L p .707 .577 .707 r
F P
0 g
s
.54989 .69146 m .54753 .63779 L .57687 .63206 L p .707 .577 .707 r
F P
0 g
s
.57687 .63206 m .57922 .68572 L .54989 .69146 L p .707 .577 .707 r
F P
0 g
s
.5452 .77439 m .54855 .73612 L .57769 .738 L p .707 .577 .707 r
F P
0 g
s
.57769 .738 m .57435 .77627 L .5452 .77439 L p .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .57769 .738 L .58259 .7384 L p .707 .577 .707 r
F P
0 g
s
.58259 .7384 m .60938 .74059 L p .57818 .77236 L .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .58259 .7384 L .57818 .77236 L .707 .577 .707 r
F
.63983 .63114 m .64218 .68481 L .61102 .68343 L p F P
0 g
s
.61102 .68343 m .60867 .62977 L .63983 .63114 L p .707 .577 .707 r
F P
0 g
s
.6405 .74365 m .63716 .78192 L .61154 .7794 L p .707 .577 .707 r
F P
0 g
s
.61154 .7794 m .60604 .77886 L p .61189 .77288 L .707 .577 .707 r
F P
0 g
s
.61189 .77288 m .6405 .74365 L .61154 .7794 L .707 .577 .707 r
F
.66801 .74689 m .66467 .78515 L .63716 .78192 L p F P
0 g
s
.63716 .78192 m .6405 .74365 L .66801 .74689 L p .707 .577 .707 r
F P
0 g
s
.60604 .77886 m .60938 .74059 L .6405 .74365 L p .707 .577 .707 r
F P
0 g
s
.64194 .76724 m .64288 .78497 L .61172 .7837 L p .707 .577 .707 r
F P
0 g
s
.61172 .7837 m .61078 .76596 L .64194 .76724 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .64177 .78791 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63498 .29503 m .63463 .35034 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63463 .35034 m .63177 .799 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.60938 .74059 m .60604 .77886 L .57435 .77627 L p .707 .577 .707 r
F P
0 g
s
.57993 .78628 m .57899 .76854 L .61078 .76596 L p .707 .577 .707 r
F P
0 g
s
.61078 .76596 m .61172 .7837 L .57993 .78628 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .63177 .799 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.61187 .30472 m .61048 .52333 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.60867 .62977 m .61102 .68343 L .57922 .68572 L p .707 .577 .707 r
F P
0 g
s
.61048 .52333 m .60867 .80869 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.55062 .79247 m .54968 .77473 L .57899 .76854 L p .707 .577 .707 r
F P
0 g
s
.57899 .76854 m .57993 .78628 L .55062 .79247 L p .707 .577 .707 r
F P
0 g
s
.53644 .31631 m .53323 .82028 L .57471 .81602 L p .707 .577 .707 r
F P
0 g
s
.57471 .81602 m .57792 .31205 L .53644 .31631 L p .707 .577 .707 r
F P
0 g
s
.44428 .81826 m .44749 .31429 L .40872 .3082 L p .707 .577 .707 r
F P
0 g
s
.44749 .31429 m .44428 .81826 L .48829 .82105 L p .707 .577 .707 r
F P
0 g
s
.70523 .75452 m .70189 .79279 L .6987 .79087 L p .707 .577 .707 r
F P
0 g
s
.6987 .79087 m .70204 .7526 L .70523 .75452 L p .707 .577 .707 r
F P
0 g
s
.70103 .65427 m .70338 .70793 L .69074 .69769 L p .707 .577 .707 r
F P
0 g
s
.69074 .69769 m .68839 .64403 L .70103 .65427 L p .707 .577 .707 r
F P
0 g
s
.57922 .68572 m .57687 .63206 L .60867 .62977 L p .707 .577 .707 r
F P
0 g
s
.57792 .31205 m .57471 .81602 L .60867 .80869 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .61187 .30472 L .57792 .31205 L p .707 .577 .707 r
F P
0 g
s
.70617 .80329 m .70711 .82102 L .70412 .80894 L p .707 .577 .707 r
F P
0 g
s
.70412 .80894 m .70318 .7912 L .70617 .80329 L p .707 .577 .707 r
F P
0 g
s
.25255 .66793 m .22139 .66655 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25255 .66793 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25148 .7516 m .28317 .75419 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25148 .7516 L p .25615 .71704 L .707 .577 .707 r
F P
0 g
s
.25635 .71553 m .25464 .71552 L .25615 .71704 L .707 .577 .707 r
F
.25148 .7516 m .25464 .71552 L p .22588 .7135 L F P
0 g
s
.22036 .74854 m .25148 .7516 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22036 .74854 L p .22554 .71565 L .707 .577 .707 r
F P
0 g
s
.22588 .7135 m .22344 .71333 L .22554 .71565 L .707 .577 .707 r
F
.22139 .66655 m .19392 .66164 L p .21615 .70531 L F P
0 g
s
.21997 .71281 m .22344 .71333 L .21615 .70531 L .707 .577 .707 r
F
.22344 .71333 m .22139 .66655 L p .21615 .70531 L F P
0 g
s
.24584 .70672 m .23921 .70007 L .22374 .72022 L .707 .577 .707 r
F
.22211 .68295 m .22344 .71333 L p .23921 .70007 L F P
0 g
s
.22344 .71333 m .22374 .72022 L p .23921 .70007 L .707 .577 .707 r
F P
0 g
s
.22036 .74854 m .22344 .71333 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .22036 .74854 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19285 .74531 L p .19738 .71127 L .707 .577 .707 r
F P
0 g
s
.19761 .70947 m .19601 .70923 L .19738 .71127 L .707 .577 .707 r
F
.19392 .66164 m .17283 .65367 L p .1913 .70222 L F P
0 g
s
.17283 .65367 m .16019 .64343 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17778 .70436 m .17499 .70396 L p .19601 .70923 L .707 .577 .707 r
F P
0 g
s
.17499 .70396 m .17165 .74222 L .19048 .74496 L p .707 .577 .707 r
F P
0 g
s
.19048 .74496 m .19285 .74531 L p .17613 .70659 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17499 .70396 L .19048 .74496 L .707 .577 .707 r
F
.17165 .74222 m .17499 .70396 L .16217 .70132 L p F P
0 g
s
.16254 .6971 m .17518 .70734 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16019 .64343 m .16121 .66667 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16121 .66667 m .16254 .6971 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17518 .70734 m .17502 .70362 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17502 .70362 m .17283 .65367 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .19601 .70923 L p .17516 .704 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17516 .704 L .17499 .70396 L .707 .577 .707 r
F
.19285 .74531 m .17516 .704 L .17613 .70659 L F
.19373 .70862 m .19601 .70923 L .1913 .70222 L F
.19601 .70923 m .19392 .66164 L p .1913 .70222 L F P
0 g
s
.19392 .66164 m .19601 .70923 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.17283 .65367 m .17518 .70734 L .19627 .7153 L p .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .1962 .70704 L .17778 .70436 L p .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .19601 .70923 L p .19373 .70862 L .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .22374 .72022 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19627 .7153 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.1962 .70704 m .19601 .70923 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .1962 .70704 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22371 .71027 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .22344 .71333 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .22344 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .2549 .7216 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25105 .71527 m .24584 .70672 L .23382 .71406 L .707 .577 .707 r
F
.25105 .71527 m .23382 .71406 L .22374 .72022 L F
.22139 .66655 m .22211 .68295 L p .24584 .70672 L F P
0 g
s
.25255 .66793 m .25464 .71552 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28651 .71593 L .28235 .71558 L p .707 .577 .707 r
F P
0 g
s
.28235 .71558 m .25483 .71333 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28235 .71558 L .25635 .71553 L .707 .577 .707 r
F
.28435 .66564 m .25255 .66793 L p .28423 .71559 L F P
0 g
s
.28651 .71593 m .28317 .75419 L .31232 .75607 L p .707 .577 .707 r
F P
0 g
s
.31232 .75607 m .31566 .7178 L .28651 .71593 L p .707 .577 .707 r
F P
0 g
s
.28671 .71931 m .28654 .71559 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28654 .71559 m .28435 .66564 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .28671 .71931 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .2549 .7216 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .25464 .71552 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .22371 .71027 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25483 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .25464 .71552 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.40552 .81217 m .40872 .3082 L .379 .29941 L p .707 .577 .707 r
F P
0 g
s
.40872 .3082 m .40552 .81217 L .44428 .81826 L p .707 .577 .707 r
F P
0 g
s
.28435 .66564 m .28671 .71931 L .31604 .71357 L p .707 .577 .707 r
F P
0 g
s
.31604 .71357 m .31368 .6599 L .28435 .66564 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68839 .64403 m .69074 .69769 L .66965 .68973 L p .707 .577 .707 r
F P
0 g
s
.66965 .68973 m .6673 .63606 L .68839 .64403 L p .707 .577 .707 r
F P
0 g
s
.31368 .6599 m .31604 .71357 L .34003 .70495 L p .707 .577 .707 r
F P
0 g
s
.34003 .70495 m .33767 .65128 L .31368 .6599 L p .707 .577 .707 r
F P
0 g
s
.70204 .7526 m .6987 .79087 L .68587 .78824 L p .707 .577 .707 r
F P
0 g
s
.68587 .78824 m .68922 .74997 L .70204 .7526 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .63498 .29503 L .61187 .30472 L p .707 .577 .707 r
F P
0 g
s
.70318 .7912 m .70412 .80894 L .69145 .79825 L p .707 .577 .707 r
F P
0 g
s
.69145 .79825 m .69052 .78051 L .70318 .7912 L p .707 .577 .707 r
F P
0 g
s
.33767 .65128 m .34003 .70495 L .35632 .69429 L p .707 .577 .707 r
F P
0 g
s
.35632 .69429 m .35397 .64062 L .33767 .65128 L p .707 .577 .707 r
F P
0 g
s
.37579 .80339 m .379 .29941 L .36122 .2888 L p .707 .577 .707 r
F P
0 g
s
.379 .29941 m .37579 .80339 L .40552 .81217 L p .707 .577 .707 r
F P
0 g
s
.6673 .63606 m .66965 .68973 L .64218 .68481 L p .707 .577 .707 r
F P
0 g
s
.64218 .68481 m .63983 .63114 L .6673 .63606 L p .707 .577 .707 r
F P
0 g
s
.31566 .7178 m .31232 .75607 L .33608 .75704 L p .707 .577 .707 r
F P
0 g
s
.33608 .75704 m .33942 .71877 L .31566 .7178 L p .707 .577 .707 r
F P
0 g
s
.68922 .74997 m .68587 .78824 L .66467 .78515 L p .707 .577 .707 r
F P
0 g
s
.66467 .78515 m .66801 .74689 L .68922 .74997 L p .707 .577 .707 r
F P
0 g
s
.25579 .82575 m .25485 .80801 L .22369 .80674 L p .707 .577 .707 r
F P
0 g
s
.25485 .80801 m .25579 .82575 L .28758 .82317 L p .707 .577 .707 r
F P
0 g
s
.28758 .82317 m .28664 .80543 L .25485 .80801 L p .707 .577 .707 r
F P
0 g
s
.28664 .80543 m .28758 .82317 L .31689 .81698 L p .707 .577 .707 r
F P
0 g
s
.31689 .81698 m .31595 .79924 L .28664 .80543 L p .707 .577 .707 r
F P
0 g
s
.22463 .82447 m .22369 .80674 L .19622 .80172 L p .707 .577 .707 r
F P
0 g
s
.22369 .80674 m .22463 .82447 L .25579 .82575 L p .707 .577 .707 r
F P
0 g
s
.69052 .78051 m .69145 .79825 L .67035 .78999 L p .707 .577 .707 r
F P
0 g
s
.67035 .78999 m .66941 .77225 L .69052 .78051 L p .707 .577 .707 r
F P
0 g
s
.33942 .71877 m .33608 .75704 L .35212 .757 L p .707 .577 .707 r
F P
0 g
s
.35212 .757 m .35547 .71874 L .33942 .71877 L p .707 .577 .707 r
F P
0 g
s
.64177 .78791 m .64498 .28394 L .63498 .29503 L p .707 .577 .707 r
F P
0 g
s
.35397 .64062 m .35632 .69429 L .36334 .68263 L p .707 .577 .707 r
F P
0 g
s
.36334 .68263 m .36098 .62896 L .35397 .64062 L p .707 .577 .707 r
F P
0 g
s
.31595 .79924 m .31689 .81698 L .34085 .80779 L p .707 .577 .707 r
F P
0 g
s
.34085 .80779 m .33991 .79005 L .31595 .79924 L p .707 .577 .707 r
F P
0 g
s
.19622 .80172 m .19716 .81946 L .22463 .82447 L p .707 .577 .707 r
F P
0 g
s
.16217 .70132 m .15882 .73959 L .17165 .74222 L p .707 .577 .707 r
F P
0 g
s
.19716 .81946 m .19622 .80172 L .17512 .79346 L p .707 .577 .707 r
F P
0 g
s
.16254 .6971 m .16019 .64343 L .15723 .63192 L p .707 .577 .707 r
F P
0 g
s
.35547 .71874 m .35212 .757 L .35888 .75598 L p .707 .577 .707 r
F P
0 g
s
.35888 .75598 m .36222 .71771 L .35547 .71874 L p .707 .577 .707 r
F P
0 g
s
.36038 .67112 m .35802 .61745 L .36098 .62896 L p .707 .577 .707 r
F P
0 g
s
.35618 .77876 m .35712 .7965 L .3641 .78421 L p .707 .577 .707 r
F P
0 g
s
.3641 .78421 m .36316 .76647 L .35618 .77876 L p .707 .577 .707 r
F P
0 g
s
.36222 .71771 m .35888 .75598 L .35569 .75405 L p .707 .577 .707 r
F P
0 g
s
.35569 .75405 m .35903 .71578 L .36222 .71771 L p .707 .577 .707 r
F P
0 g
s
.35802 .61745 m .36038 .67112 L .34773 .66088 L p .707 .577 .707 r
F P
0 g
s
.34773 .66088 m .34538 .60721 L .35802 .61745 L p .707 .577 .707 r
F P
0 g
s
.35903 .71578 m .35569 .75405 L .34286 .75142 L p .707 .577 .707 r
F P
0 g
s
.34286 .75142 m .34621 .71315 L .35903 .71578 L p .707 .577 .707 r
F P
0 g
s
.36017 .75439 m .36111 .77213 L .34844 .76143 L p .707 .577 .707 r
F P
0 g
s
.34844 .76143 m .34751 .74369 L .36017 .75439 L p .707 .577 .707 r
F P
0 g
s
.35801 .79277 m .36122 .2888 L .35713 .27738 L p .707 .577 .707 r
F P
0 g
s
.36098 .62896 m .36334 .68263 L .36038 .67112 L p .707 .577 .707 r
F P
0 g
s
.36316 .76647 m .3641 .78421 L .36111 .77213 L p .707 .577 .707 r
F P
0 g
s
.36111 .77213 m .36017 .75439 L .36316 .76647 L p .707 .577 .707 r
F P
0 g
s
.36122 .2888 m .35801 .79277 L .37579 .80339 L p .707 .577 .707 r
F P
0 g
s
.17512 .79346 m .17606 .8112 L .19716 .81946 L p .707 .577 .707 r
F P
0 g
s
.33991 .79005 m .34085 .80779 L .35712 .7965 L p .707 .577 .707 r
F P
0 g
s
.35712 .7965 m .35618 .77876 L .33991 .79005 L p .707 .577 .707 r
F P
0 g
s
.66941 .77225 m .67035 .78999 L .64288 .78497 L p .707 .577 .707 r
F P
0 g
s
.64288 .78497 m .64194 .76724 L .66941 .77225 L p .707 .577 .707 r
F P
0 g
s
.17606 .8112 m .17512 .79346 L .16245 .78277 L p .707 .577 .707 r
F P
0 g
s
.15723 .63192 m .15958 .68558 L .16254 .6971 L p .707 .577 .707 r
F P
0 g
s
.15882 .73959 m .16217 .70132 L .15898 .6994 L p .707 .577 .707 r
F P
0 g
s
.15898 .6994 m .15563 .73767 L .15882 .73959 L p .707 .577 .707 r
F P
0 g
s
.16245 .78277 m .16339 .80051 L .17606 .8112 L p .707 .577 .707 r
F P
0 g
s
.64498 .28394 m .64177 .78791 L .63768 .77649 L p .707 .577 .707 r
F P
0 g
s
.63768 .77649 m .64089 .27252 L .64498 .28394 L p .707 .577 .707 r
F P
0 g
s
.15958 .68558 m .15723 .63192 L .16424 .62026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16339 .80051 m .16245 .78277 L .15946 .77069 L p .707 .577 .707 r
F P
0 g
s
.35713 .27738 m .35392 .78135 L .35801 .79277 L p .707 .577 .707 r
F P
0 g
s
.35392 .78135 m .35713 .27738 L .36712 .26628 L p .707 .577 .707 r
F P
0 g
s
.16424 .62026 m .16659 .67393 L .15958 .68558 L p .707 .577 .707 r
F P
0 g
s
.15946 .77069 m .1604 .78842 L .16339 .80051 L p .707 .577 .707 r
F P
0 g
s
.15563 .73767 m .15898 .6994 L .16573 .69837 L p .707 .577 .707 r
F P
0 g
s
.16573 .69837 m .16239 .73664 L .15563 .73767 L p .707 .577 .707 r
F P
0 g
s
.16659 .67393 m .16424 .62026 L .18054 .6096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64089 .27252 m .63768 .77649 L .6199 .76587 L p .707 .577 .707 r
F P
0 g
s
.6199 .76587 m .62311 .2619 L .64089 .27252 L p .707 .577 .707 r
F P
0 g
s
.34538 .60721 m .34773 .66088 L .32664 .65291 L p .707 .577 .707 r
F P
0 g
s
.32664 .65291 m .32429 .59924 L .34538 .60721 L p .707 .577 .707 r
F P
0 g
s
.1604 .78842 m .15946 .77069 L .16645 .7584 L p .707 .577 .707 r
F P
0 g
s
.18054 .6096 m .18289 .66326 L .16659 .67393 L p .707 .577 .707 r
F P
0 g
s
.16645 .7584 m .16738 .77613 L .1604 .78842 L p .707 .577 .707 r
F P
0 g
s
.18289 .66326 m .18054 .6096 L .20453 .60098 L p .707 .577 .707 r
F P
0 g
s
.16239 .73664 m .16573 .69837 L .18178 .69834 L p .707 .577 .707 r
F P
0 g
s
.18178 .69834 m .17843 .73661 L .16239 .73664 L p .707 .577 .707 r
F P
0 g
s
.36392 .77025 m .36712 .26628 L .39023 .25659 L p .707 .577 .707 r
F P
0 g
s
.36712 .26628 m .36392 .77025 L .35392 .78135 L p .707 .577 .707 r
F P
0 g
s
.32429 .59924 m .32664 .65291 L .29917 .648 L p .707 .577 .707 r
F P
0 g
s
.29917 .648 m .29682 .59433 L .32429 .59924 L p .707 .577 .707 r
F P
0 g
s
.16738 .77613 m .16645 .7584 L .18271 .7471 L p .707 .577 .707 r
F P
0 g
s
.20688 .65464 m .20453 .60098 L .23386 .59524 L p .707 .577 .707 r
F P
0 g
s
.20453 .60098 m .20688 .65464 L .18289 .66326 L p .707 .577 .707 r
F P
0 g
s
.34621 .71315 m .34286 .75142 L .32166 .74834 L p .707 .577 .707 r
F P
0 g
s
.32166 .74834 m .325 .71007 L .34621 .71315 L p .707 .577 .707 r
F P
0 g
s
.29682 .59433 m .29917 .648 L .26801 .64662 L p .707 .577 .707 r
F P
0 g
s
.26801 .64662 m .26566 .59295 L .29682 .59433 L p .707 .577 .707 r
F P
0 g
s
.18271 .7471 m .18365 .76484 L .16738 .77613 L p .707 .577 .707 r
F P
0 g
s
.62311 .2619 m .6199 .76587 L .59017 .75709 L p .707 .577 .707 r
F P
0 g
s
.59017 .75709 m .59338 .25312 L .62311 .2619 L p .707 .577 .707 r
F P
0 g
s
.17843 .73661 m .18178 .69834 L .20554 .69931 L p .707 .577 .707 r
F P
0 g
s
.20554 .69931 m .20219 .73758 L .17843 .73661 L p .707 .577 .707 r
F P
0 g
s
.23621 .64891 m .23386 .59524 L .26566 .59295 L p .707 .577 .707 r
F P
0 g
s
.23386 .59524 m .23621 .64891 L .20688 .65464 L p .707 .577 .707 r
F P
0 g
s
.34751 .74369 m .34844 .76143 L .32734 .75317 L p .707 .577 .707 r
F P
0 g
s
.32734 .75317 m .3264 .73544 L .34751 .74369 L p .707 .577 .707 r
F P
0 g
s
.26566 .59295 m .26801 .64662 L .23621 .64891 L p .707 .577 .707 r
F P
0 g
s
.39023 .25659 m .38702 .76057 L .36392 .77025 L p .707 .577 .707 r
F P
0 g
s
.38702 .76057 m .39023 .25659 L .42418 .24926 L p .707 .577 .707 r
F P
0 g
s
.73276 .61271 m .7016 .61133 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73276 .61271 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.7317 .69661 m .76338 .69921 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .7317 .69661 L p .73631 .66192 L .707 .577 .707 r
F P
0 g
s
.73651 .66046 m .73486 .66046 L .73631 .66192 L .707 .577 .707 r
F
.7317 .69661 m .73486 .66046 L p .70604 .65843 L F P
0 g
s
.70058 .69355 m .7317 .69661 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70058 .69355 L p .70571 .66052 L .707 .577 .707 r
F P
0 g
s
.70604 .65843 m .70366 .65827 L .70571 .66052 L .707 .577 .707 r
F
.7016 .61133 m .67413 .60641 L p .69654 .65043 L F P
0 g
s
.70027 .65776 m .70366 .65827 L .69654 .65043 L .707 .577 .707 r
F
.70366 .65827 m .7016 .61133 L p .69654 .65043 L F P
0 g
s
.72629 .65188 m .71943 .64501 L .70395 .66499 L .707 .577 .707 r
F
.70233 .62788 m .70366 .65827 L p .71943 .64501 L F P
0 g
s
.70366 .65827 m .70395 .66499 L p .71943 .64501 L .707 .577 .707 r
F P
0 g
s
.70058 .69355 m .70366 .65827 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .70058 .69355 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67307 .69032 L p .67755 .65613 L .707 .577 .707 r
F P
0 g
s
.67778 .6544 m .67623 .65417 L .67755 .65613 L .707 .577 .707 r
F
.67413 .60641 m .65304 .59844 L p .67164 .64734 L F P
0 g
s
.65304 .59844 m .6404 .5882 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65866 .64947 m .6552 .64897 L p .67623 .65417 L .707 .577 .707 r
F P
0 g
s
.6552 .64897 m .65186 .68724 L .67073 .68998 L p .707 .577 .707 r
F P
0 g
s
.67073 .68998 m .67307 .69032 L p .65662 .65224 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .6552 .64897 L .67073 .68998 L .707 .577 .707 r
F
.65186 .68724 m .6552 .64897 L .64238 .64634 L p F P
0 g
s
.64275 .64187 m .6554 .65211 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6404 .5882 m .64143 .61161 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.64143 .61161 m .64275 .64187 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6554 .65211 m .65524 .64856 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65524 .64856 m .65304 .59844 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .67623 .65417 L p .65541 .64902 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .65541 .64902 L .6552 .64897 L .707 .577 .707 r
F
.67307 .69032 m .65541 .64902 L .65662 .65224 L F
.67401 .65357 m .67623 .65417 L .67164 .64734 L F
.67623 .65417 m .67413 .60641 L p .67164 .64734 L F P
0 g
s
.67413 .60641 m .67623 .65417 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.65304 .59844 m .6554 .65211 L .67648 .66008 L p .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67641 .65205 L .65866 .64947 L p .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .67623 .65417 L p .67401 .65357 L .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .70395 .66499 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67648 .66008 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67641 .65205 m .67623 .65417 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .67641 .65205 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70392 .65528 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .70366 .65827 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .70366 .65827 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .73512 .66637 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73137 .66021 m .72629 .65188 L .71416 .659 L .707 .577 .707 r
F
.73137 .66021 m .71416 .659 L .70395 .66499 L F
.7016 .61133 m .70233 .62788 L p .72629 .65188 L F P
0 g
s
.73276 .61271 m .73486 .66046 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76673 .66094 L .76156 .66052 L p .707 .577 .707 r
F P
0 g
s
.76156 .66052 m .73504 .65835 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76156 .66052 L .73651 .66046 L .707 .577 .707 r
F
.76456 .61041 m .73276 .61271 L p .76455 .66052 L F P
0 g
s
.76673 .66094 m .76338 .69921 L .79253 .70108 L p .707 .577 .707 r
F P
0 g
s
.79253 .70108 m .79588 .66281 L .76673 .66094 L p .707 .577 .707 r
F P
0 g
s
.76692 .66408 m .76676 .66053 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76676 .66053 m .76456 .61041 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .76692 .66408 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73512 .66637 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .73486 .66046 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .70392 .65528 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73504 .65835 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .73486 .66046 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.325 .71007 m .32166 .74834 L .29415 .74511 L p .707 .577 .707 r
F P
0 g
s
.29415 .74511 m .29749 .70684 L .325 .71007 L p .707 .577 .707 r
F P
0 g
s
.76456 .61041 m .76692 .66408 L .79625 .65835 L p .707 .577 .707 r
F P
0 g
s
.79625 .65835 m .7939 .60468 L .76456 .61041 L p .707 .577 .707 r
F P
0 g
s
.18365 .76484 m .18271 .7471 L .20667 .73791 L p .707 .577 .707 r
F P
0 g
s
.20219 .73758 m .20554 .69931 L .23468 .70118 L p .707 .577 .707 r
F P
0 g
s
.23468 .70118 m .23134 .73945 L .20219 .73758 L p .707 .577 .707 r
F P
0 g
s
.20667 .73791 m .20761 .75565 L .18365 .76484 L p .707 .577 .707 r
F P
0 g
s
.3264 .73544 m .32734 .75317 L .29987 .74816 L p .707 .577 .707 r
F P
0 g
s
.29987 .74816 m .29893 .73042 L .3264 .73544 L p .707 .577 .707 r
F P
0 g
s
.7939 .60468 m .79625 .65835 L .82024 .64973 L p .707 .577 .707 r
F P
0 g
s
.82024 .64973 m .81789 .59606 L .7939 .60468 L p .707 .577 .707 r
F P
0 g
s
.29749 .70684 m .29415 .74511 L .26303 .74205 L p .707 .577 .707 r
F P
0 g
s
.26303 .74205 m .26637 .70378 L .29749 .70684 L p .707 .577 .707 r
F P
0 g
s
.59338 .25312 m .59017 .75709 L .55141 .751 L p .707 .577 .707 r
F P
0 g
s
.55141 .751 m .55462 .24703 L .59338 .25312 L p .707 .577 .707 r
F P
0 g
s
.23134 .73945 m .23468 .70118 L .26637 .70378 L p .707 .577 .707 r
F P
0 g
s
.20761 .75565 m .20667 .73791 L .23598 .73172 L p .707 .577 .707 r
F P
0 g
s
.26637 .70378 m .26303 .74205 L .23134 .73945 L p .707 .577 .707 r
F P
0 g
s
.29893 .73042 m .29987 .74816 L .26871 .74688 L p .707 .577 .707 r
F P
0 g
s
.26871 .74688 m .26777 .72914 L .29893 .73042 L p .707 .577 .707 r
F P
0 g
s
.42098 .75323 m .42418 .24926 L .46566 .245 L p .707 .577 .707 r
F P
0 g
s
.42418 .24926 m .42098 .75323 L .38702 .76057 L p .707 .577 .707 r
F P
0 g
s
.23598 .73172 m .23692 .74946 L .20761 .75565 L p .707 .577 .707 r
F P
0 g
s
.23692 .74946 m .23598 .73172 L .26777 .72914 L p .707 .577 .707 r
F P
0 g
s
.81789 .59606 m .82024 .64973 L .83654 .63907 L p .707 .577 .707 r
F P
0 g
s
.83654 .63907 m .83418 .5854 L .81789 .59606 L p .707 .577 .707 r
F P
0 g
s
.26777 .72914 m .26871 .74688 L .23692 .74946 L p .707 .577 .707 r
F P
0 g
s
.79588 .66281 m .79253 .70108 L .81629 .70205 L p .707 .577 .707 r
F P
0 g
s
.81629 .70205 m .81964 .66378 L .79588 .66281 L p .707 .577 .707 r
F P
0 g
s
.55462 .24703 m .55141 .751 L .5074 .7482 L p .707 .577 .707 r
F P
0 g
s
.5074 .7482 m .51061 .24423 L .55462 .24703 L p .707 .577 .707 r
F P
0 g
s
.736 .76962 m .73506 .75188 L .70391 .7506 L p .707 .577 .707 r
F P
0 g
s
.73506 .75188 m .736 .76962 L .76779 .76704 L p .707 .577 .707 r
F P
0 g
s
.76779 .76704 m .76685 .7493 L .73506 .75188 L p .707 .577 .707 r
F P
0 g
s
.46246 .74897 m .46566 .245 L .51061 .24423 L p .707 .577 .707 r
F P
0 g
s
.46566 .245 m .46246 .74897 L .42098 .75323 L p .707 .577 .707 r
F P
0 g
s
.76685 .7493 m .76779 .76704 L .7971 .76085 L p .707 .577 .707 r
F P
0 g
s
.7971 .76085 m .79616 .74311 L .76685 .7493 L p .707 .577 .707 r
F P
0 g
s
.51061 .24423 m .5074 .7482 L .46246 .74897 L p .707 .577 .707 r
F P
0 g
s
.70485 .76834 m .70391 .7506 L .67643 .74559 L p .707 .577 .707 r
F P
0 g
s
.70391 .7506 m .70485 .76834 L .736 .76962 L p .707 .577 .707 r
F P
0 g
s
.81964 .66378 m .81629 .70205 L .83234 .70202 L p .707 .577 .707 r
F P
0 g
s
.83234 .70202 m .83568 .66375 L .81964 .66378 L p .707 .577 .707 r
F P
0 g
s
.79616 .74311 m .7971 .76085 L .82106 .75166 L p .707 .577 .707 r
F P
0 g
s
.82106 .75166 m .82012 .73392 L .79616 .74311 L p .707 .577 .707 r
F P
0 g
s
.83418 .5854 m .83654 .63907 L .84355 .62741 L p .707 .577 .707 r
F P
0 g
s
.84355 .62741 m .8412 .57374 L .83418 .5854 L p .707 .577 .707 r
F P
0 g
s
.67643 .74559 m .67737 .76332 L .70485 .76834 L p .707 .577 .707 r
F P
0 g
s
.64238 .64634 m .63904 .68461 L .65186 .68724 L p .707 .577 .707 r
F P
0 g
s
.67737 .76332 m .67643 .74559 L .65533 .73733 L p .707 .577 .707 r
F P
0 g
s
.64275 .64187 m .6404 .5882 L .63744 .57669 L p .707 .577 .707 r
F P
0 g
s
.65533 .73733 m .65627 .75507 L .67737 .76332 L p .707 .577 .707 r
F P
0 g
s
.82012 .73392 m .82106 .75166 L .83733 .74036 L p .707 .577 .707 r
F P
0 g
s
.83733 .74036 m .83639 .72263 L .82012 .73392 L p .707 .577 .707 r
F P
0 g
s
.83568 .66375 m .83234 .70202 L .83909 .70099 L p .707 .577 .707 r
F P
0 g
s
.83909 .70099 m .84244 .66272 L .83568 .66375 L p .707 .577 .707 r
F P
0 g
s
.8412 .57374 m .84355 .62741 L .84059 .6159 L p .707 .577 .707 r
F P
0 g
s
.84059 .6159 m .83824 .56223 L .8412 .57374 L p .707 .577 .707 r
F P
0 g
s
.65627 .75507 m .65533 .73733 L .64267 .72663 L p .707 .577 .707 r
F P
0 g
s
.63744 .57669 m .63979 .63036 L .64275 .64187 L p .707 .577 .707 r
F P
0 g
s
.63904 .68461 m .64238 .64634 L .63919 .64441 L p .707 .577 .707 r
F P
0 g
s
.63919 .64441 m .63585 .68268 L .63904 .68461 L p .707 .577 .707 r
F P
0 g
s
.64267 .72663 m .6436 .74437 L .65627 .75507 L p .707 .577 .707 r
F P
0 g
s
.83639 .72263 m .83733 .74036 L .84431 .72807 L p .707 .577 .707 r
F P
0 g
s
.84431 .72807 m .84337 .71034 L .83639 .72263 L p .707 .577 .707 r
F P
0 g
s
.63979 .63036 m .63744 .57669 L .64445 .56503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84244 .66272 m .83909 .70099 L .8359 .69907 L p .707 .577 .707 r
F P
0 g
s
.8359 .69907 m .83925 .6608 L .84244 .66272 L p .707 .577 .707 r
F P
0 g
s
.83824 .56223 m .84059 .6159 L .82795 .60565 L p .707 .577 .707 r
F P
0 g
s
.82795 .60565 m .82559 .55199 L .83824 .56223 L p .707 .577 .707 r
F P
0 g
s
.6436 .74437 m .64267 .72663 L .63968 .71455 L p .707 .577 .707 r
F P
0 g
s
.64445 .56503 m .64681 .6187 L .63979 .63036 L p .707 .577 .707 r
F P
0 g
s
.63968 .71455 m .64062 .73229 L .6436 .74437 L p .707 .577 .707 r
F P
0 g
s
.63585 .68268 m .63919 .64441 L .64595 .64339 L p .707 .577 .707 r
F P
0 g
s
.64595 .64339 m .6426 .68166 L .63585 .68268 L p .707 .577 .707 r
F P
0 g
s
.84337 .71034 m .84431 .72807 L .84132 .71599 L p .707 .577 .707 r
F P
0 g
s
.84132 .71599 m .84039 .69825 L .84337 .71034 L p .707 .577 .707 r
F P
0 g
s
.64681 .6187 m .64445 .56503 L .66075 .55437 L p .707 .577 .707 r
F P
0 g
s
.38975 .57589 m .35859 .57451 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38975 .57589 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38869 .6598 m .42037 .66239 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38869 .6598 L p .3933 .6251 L .707 .577 .707 r
F P
0 g
s
.3935 .62365 m .39185 .62364 L .3933 .6251 L .707 .577 .707 r
F
.38869 .6598 m .39185 .62364 L p .36303 .62162 L F P
0 g
s
.35757 .65674 m .38869 .6598 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .35757 .65674 L p .3627 .62371 L .707 .577 .707 r
F P
0 g
s
.36303 .62162 m .36065 .62145 L .3627 .62371 L .707 .577 .707 r
F
.35859 .57451 m .33112 .5696 L p .35353 .61362 L F P
0 g
s
.35726 .62094 m .36065 .62145 L .35353 .61362 L .707 .577 .707 r
F
.36065 .62145 m .35859 .57451 L p .35353 .61362 L F P
0 g
s
.38328 .61507 m .37642 .60819 L .36094 .62818 L .707 .577 .707 r
F
.35932 .59106 m .36065 .62145 L p .37642 .60819 L F P
0 g
s
.36065 .62145 m .36094 .62818 L p .37642 .60819 L .707 .577 .707 r
F P
0 g
s
.35757 .65674 m .36065 .62145 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .35757 .65674 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33006 .65351 L p .33454 .61932 L .707 .577 .707 r
F P
0 g
s
.33477 .61758 m .33322 .61735 L .33454 .61932 L .707 .577 .707 r
F
.33112 .5696 m .31003 .56163 L p .32863 .61053 L F P
0 g
s
.31003 .56163 m .29739 .55139 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31565 .61266 m .31219 .61216 L p .33322 .61735 L .707 .577 .707 r
F P
0 g
s
.31219 .61216 m .30885 .65042 L .32772 .65317 L p .707 .577 .707 r
F P
0 g
s
.32772 .65317 m .33006 .65351 L p .31361 .61542 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .31219 .61216 L .32772 .65317 L .707 .577 .707 r
F
.30885 .65042 m .31219 .61216 L .29937 .60952 L p F P
0 g
s
.29974 .60506 m .31239 .6153 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29739 .55139 m .29842 .57479 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29842 .57479 m .29974 .60506 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31239 .6153 m .31223 .61174 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31223 .61174 m .31003 .56163 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .33322 .61735 L p .3124 .61221 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .3124 .61221 L .31219 .61216 L .707 .577 .707 r
F
.33006 .65351 m .3124 .61221 L .31361 .61542 L F
.331 .61676 m .33322 .61735 L .32863 .61053 L F
.33322 .61735 m .33112 .5696 L p .32863 .61053 L F P
0 g
s
.33112 .5696 m .33322 .61735 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.31003 .56163 m .31239 .6153 L .33347 .62326 L p .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .3334 .61524 L .31565 .61266 L p .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .33322 .61735 L p .331 .61676 L .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .36094 .62818 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33347 .62326 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.3334 .61524 m .33322 .61735 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .3334 .61524 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .36091 .61847 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .36065 .62145 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .36065 .62145 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .39211 .62956 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38836 .6234 m .38328 .61507 L .37115 .62219 L .707 .577 .707 r
F
.38836 .6234 m .37115 .62219 L .36094 .62818 L F
.35859 .57451 m .35932 .59106 L p .38328 .61507 L F P
0 g
s
.38975 .57589 m .39185 .62364 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .42372 .62412 L .41855 .6237 L p .707 .577 .707 r
F P
0 g
s
.41855 .6237 m .39203 .62153 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .41855 .6237 L .3935 .62365 L .707 .577 .707 r
F
.42156 .5736 m .38975 .57589 L p .42154 .62371 L F P
0 g
s
.42372 .62412 m .42037 .66239 L .44952 .66427 L p .707 .577 .707 r
F P
0 g
s
.44952 .66427 m .45287 .626 L .42372 .62412 L p .707 .577 .707 r
F P
0 g
s
.42391 .62727 m .42375 .62371 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42375 .62371 m .42156 .5736 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .42391 .62727 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39211 .62956 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .39185 .62364 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .36091 .61847 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39203 .62153 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .39185 .62364 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.42156 .5736 m .42391 .62727 L .45324 .62153 L p .707 .577 .707 r
F P
0 g
s
.45324 .62153 m .45089 .56786 L .42156 .5736 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82559 .55199 m .82795 .60565 L .80686 .59769 L p .707 .577 .707 r
F P
0 g
s
.80686 .59769 m .8045 .54402 L .82559 .55199 L p .707 .577 .707 r
F P
0 g
s
.45089 .56786 m .45324 .62153 L .47723 .61291 L p .707 .577 .707 r
F P
0 g
s
.47723 .61291 m .47488 .55924 L .45089 .56786 L p .707 .577 .707 r
F P
0 g
s
.64062 .73229 m .63968 .71455 L .64666 .70226 L p .707 .577 .707 r
F P
0 g
s
.83925 .6608 m .8359 .69907 L .82308 .69644 L p .707 .577 .707 r
F P
0 g
s
.82308 .69644 m .82642 .65817 L .83925 .6608 L p .707 .577 .707 r
F P
0 g
s
.66075 .55437 m .6631 .60804 L .64681 .6187 L p .707 .577 .707 r
F P
0 g
s
.64666 .70226 m .6476 .72 L .64062 .73229 L p .707 .577 .707 r
F P
0 g
s
.6631 .60804 m .66075 .55437 L .68474 .54575 L p .707 .577 .707 r
F P
0 g
s
.6426 .68166 m .64595 .64339 L .66199 .64336 L p .707 .577 .707 r
F P
0 g
s
.66199 .64336 m .65865 .68162 L .6426 .68166 L p .707 .577 .707 r
F P
0 g
s
.84039 .69825 m .84132 .71599 L .82866 .7053 L p .707 .577 .707 r
F P
0 g
s
.82866 .7053 m .82772 .68756 L .84039 .69825 L p .707 .577 .707 r
F P
0 g
s
.47488 .55924 m .47723 .61291 L .49353 .60225 L p .707 .577 .707 r
F P
0 g
s
.49353 .60225 m .49117 .54858 L .47488 .55924 L p .707 .577 .707 r
F P
0 g
s
.8045 .54402 m .80686 .59769 L .77939 .59277 L p .707 .577 .707 r
F P
0 g
s
.77939 .59277 m .77704 .53911 L .8045 .54402 L p .707 .577 .707 r
F P
0 g
s
.45287 .626 m .44952 .66427 L .47328 .66524 L p .707 .577 .707 r
F P
0 g
s
.47328 .66524 m .47663 .62697 L .45287 .626 L p .707 .577 .707 r
F P
0 g
s
.6476 .72 m .64666 .70226 L .66293 .69097 L p .707 .577 .707 r
F P
0 g
s
.68709 .59942 m .68474 .54575 L .71407 .54002 L p .707 .577 .707 r
F P
0 g
s
.68474 .54575 m .68709 .59942 L .6631 .60804 L p .707 .577 .707 r
F P
0 g
s
.82642 .65817 m .82308 .69644 L .80187 .69335 L p .707 .577 .707 r
F P
0 g
s
.80187 .69335 m .80522 .65508 L .82642 .65817 L p .707 .577 .707 r
F P
0 g
s
.39299 .7328 m .39205 .71506 L .3609 .71379 L p .707 .577 .707 r
F P
0 g
s
.39205 .71506 m .39299 .7328 L .42478 .73022 L p .707 .577 .707 r
F P
0 g
s
.42478 .73022 m .42384 .71248 L .39205 .71506 L p .707 .577 .707 r
F P
0 g
s
.42384 .71248 m .42478 .73022 L .45409 .72403 L p .707 .577 .707 r
F P
0 g
s
.45409 .72403 m .45315 .70629 L .42384 .71248 L p .707 .577 .707 r
F P
0 g
s
.77704 .53911 m .77939 .59277 L .74823 .59139 L p .707 .577 .707 r
F P
0 g
s
.74823 .59139 m .74587 .53773 L .77704 .53911 L p .707 .577 .707 r
F P
0 g
s
.66293 .69097 m .66386 .70871 L .6476 .72 L p .707 .577 .707 r
F P
0 g
s
.36183 .73152 m .3609 .71379 L .33342 .70877 L p .707 .577 .707 r
F P
0 g
s
.3609 .71379 m .36183 .73152 L .39299 .7328 L p .707 .577 .707 r
F P
0 g
s
.65865 .68162 m .66199 .64336 L .68575 .64432 L p .707 .577 .707 r
F P
0 g
s
.68575 .64432 m .68241 .68259 L .65865 .68162 L p .707 .577 .707 r
F P
0 g
s
.71642 .59368 m .71407 .54002 L .74587 .53773 L p .707 .577 .707 r
F P
0 g
s
.71407 .54002 m .71642 .59368 L .68709 .59942 L p .707 .577 .707 r
F P
0 g
s
.82772 .68756 m .82866 .7053 L .80756 .69704 L p .707 .577 .707 r
F P
0 g
s
.80756 .69704 m .80662 .6793 L .82772 .68756 L p .707 .577 .707 r
F P
0 g
s
.47663 .62697 m .47328 .66524 L .48933 .6652 L p .707 .577 .707 r
F P
0 g
s
.48933 .6652 m .49267 .62694 L .47663 .62697 L p .707 .577 .707 r
F P
0 g
s
.74587 .53773 m .74823 .59139 L .71642 .59368 L p .707 .577 .707 r
F P
0 g
s
.45315 .70629 m .45409 .72403 L .47805 .71484 L p .707 .577 .707 r
F P
0 g
s
.47805 .71484 m .47711 .6971 L .45315 .70629 L p .707 .577 .707 r
F P
0 g
s
.49117 .54858 m .49353 .60225 L .50054 .59059 L p .707 .577 .707 r
F P
0 g
s
.50054 .59059 m .49819 .53692 L .49117 .54858 L p .707 .577 .707 r
F P
0 g
s
.33342 .70877 m .33436 .72651 L .36183 .73152 L p .707 .577 .707 r
F P
0 g
s
.29937 .60952 m .29603 .64779 L .30885 .65042 L p .707 .577 .707 r
F P
0 g
s
.33436 .72651 m .33342 .70877 L .31232 .70051 L p .707 .577 .707 r
F P
0 g
s
.80522 .65508 m .80187 .69335 L .77436 .69012 L p .707 .577 .707 r
F P
0 g
s
.77436 .69012 m .77771 .65185 L .80522 .65508 L p .707 .577 .707 r
F P
0 g
s
.7149 .6462 m .71156 .68447 L .68241 .68259 L p .707 .577 .707 r
F P
0 g
s
.66386 .70871 m .66293 .69097 L .68689 .68178 L p .707 .577 .707 r
F P
0 g
s
.29974 .60506 m .29739 .55139 L .29443 .53988 L p .707 .577 .707 r
F P
0 g
s
.68241 .68259 m .68575 .64432 L .7149 .6462 L p .707 .577 .707 r
F P
0 g
s
.31232 .70051 m .31326 .71825 L .33436 .72651 L p .707 .577 .707 r
F P
0 g
s
.68689 .68178 m .68783 .69952 L .66386 .70871 L p .707 .577 .707 r
F P
0 g
s
.47711 .6971 m .47805 .71484 L .49432 .70355 L p .707 .577 .707 r
F P
0 g
s
.49432 .70355 m .49338 .68581 L .47711 .6971 L p .707 .577 .707 r
F P
0 g
s
.80662 .6793 m .80756 .69704 L .78008 .69202 L p .707 .577 .707 r
F P
0 g
s
.78008 .69202 m .77914 .67429 L .80662 .6793 L p .707 .577 .707 r
F P
0 g
s
.77771 .65185 m .77436 .69012 L .74324 .68706 L p .707 .577 .707 r
F P
0 g
s
.74324 .68706 m .74658 .64879 L .77771 .65185 L p .707 .577 .707 r
F P
0 g
s
.49267 .62694 m .48933 .6652 L .49608 .66418 L p .707 .577 .707 r
F P
0 g
s
.49608 .66418 m .49943 .62591 L .49267 .62694 L p .707 .577 .707 r
F P
0 g
s
.71156 .68447 m .7149 .6462 L .74658 .64879 L p .707 .577 .707 r
F P
0 g
s
.49819 .53692 m .50054 .59059 L .49758 .57908 L p .707 .577 .707 r
F P
0 g
s
.49758 .57908 m .49523 .52541 L .49819 .53692 L p .707 .577 .707 r
F P
0 g
s
.68783 .69952 m .68689 .68178 L .7162 .67559 L p .707 .577 .707 r
F P
0 g
s
.74658 .64879 m .74324 .68706 L .71156 .68447 L p .707 .577 .707 r
F P
0 g
s
.31326 .71825 m .31232 .70051 L .29966 .68982 L p .707 .577 .707 r
F P
0 g
s
.77914 .67429 m .78008 .69202 L .74893 .69075 L p .707 .577 .707 r
F P
0 g
s
.74893 .69075 m .74799 .67301 L .77914 .67429 L p .707 .577 .707 r
F P
0 g
s
.29443 .53988 m .29678 .59354 L .29974 .60506 L p .707 .577 .707 r
F P
0 g
s
.29603 .64779 m .29937 .60952 L .29618 .6076 L p .707 .577 .707 r
F P
0 g
s
.7162 .67559 m .71714 .69333 L .68783 .69952 L p .707 .577 .707 r
F P
0 g
s
.29618 .6076 m .29284 .64587 L .29603 .64779 L p .707 .577 .707 r
F P
0 g
s
.29966 .68982 m .30059 .70756 L .31326 .71825 L p .707 .577 .707 r
F P
0 g
s
.71714 .69333 m .7162 .67559 L .74799 .67301 L p .707 .577 .707 r
F P
0 g
s
.74799 .67301 m .74893 .69075 L .71714 .69333 L p .707 .577 .707 r
F P
0 g
s
.49338 .68581 m .49432 .70355 L .5013 .69126 L p .707 .577 .707 r
F P
0 g
s
.5013 .69126 m .50036 .67352 L .49338 .68581 L p .707 .577 .707 r
F P
0 g
s
.29678 .59354 m .29443 .53988 L .30144 .52822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49943 .62591 m .49608 .66418 L .49289 .66225 L p .707 .577 .707 r
F P
0 g
s
.49289 .66225 m .49624 .62398 L .49943 .62591 L p .707 .577 .707 r
F P
0 g
s
.49523 .52541 m .49758 .57908 L .48494 .56884 L p .707 .577 .707 r
F P
0 g
s
.48494 .56884 m .48258 .51517 L .49523 .52541 L p .707 .577 .707 r
F P
0 g
s
.30059 .70756 m .29966 .68982 L .29667 .67774 L p .707 .577 .707 r
F P
0 g
s
.30144 .52822 m .30379 .58189 L .29678 .59354 L p .707 .577 .707 r
F P
0 g
s
.29667 .67774 m .29761 .69547 L .30059 .70756 L p .707 .577 .707 r
F P
0 g
s
.29284 .64587 m .29618 .6076 L .30294 .60657 L p .707 .577 .707 r
F P
0 g
s
.30294 .60657 m .29959 .64484 L .29284 .64587 L p .707 .577 .707 r
F P
0 g
s
.50036 .67352 m .5013 .69126 L .49831 .67918 L p .707 .577 .707 r
F P
0 g
s
.49831 .67918 m .49737 .66144 L .50036 .67352 L p .707 .577 .707 r
F P
0 g
s
.30379 .58189 m .30144 .52822 L .31774 .51756 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48258 .51517 m .48494 .56884 L .46385 .56087 L p .707 .577 .707 r
F P
0 g
s
.46385 .56087 m .46149 .5072 L .48258 .51517 L p .707 .577 .707 r
F P
0 g
s
.29761 .69547 m .29667 .67774 L .30365 .66545 L p .707 .577 .707 r
F P
0 g
s
.49624 .62398 m .49289 .66225 L .48007 .65962 L p .707 .577 .707 r
F P
0 g
s
.48007 .65962 m .48341 .62135 L .49624 .62398 L p .707 .577 .707 r
F P
0 g
s
.31774 .51756 m .32009 .57123 L .30379 .58189 L p .707 .577 .707 r
F P
0 g
s
.30365 .66545 m .30459 .68318 L .29761 .69547 L p .707 .577 .707 r
F P
0 g
s
.32009 .57123 m .31774 .51756 L .34173 .50894 L p .707 .577 .707 r
F P
0 g
s
.29959 .64484 m .30294 .60657 L .31898 .60654 L p .707 .577 .707 r
F P
0 g
s
.31898 .60654 m .31564 .64481 L .29959 .64484 L p .707 .577 .707 r
F P
0 g
s
.49737 .66144 m .49831 .67918 L .48565 .66848 L p .707 .577 .707 r
F P
0 g
s
.48565 .66848 m .48471 .65074 L .49737 .66144 L p .707 .577 .707 r
F P
0 g
s
.46149 .5072 m .46385 .56087 L .43638 .55596 L p .707 .577 .707 r
F P
0 g
s
.43638 .55596 m .43402 .50229 L .46149 .5072 L p .707 .577 .707 r
F P
0 g
s
.30459 .68318 m .30365 .66545 L .31992 .65415 L p .707 .577 .707 r
F P
0 g
s
.34408 .5626 m .34173 .50894 L .37106 .5032 L p .707 .577 .707 r
F P
0 g
s
.34173 .50894 m .34408 .5626 L .32009 .57123 L p .707 .577 .707 r
F P
0 g
s
.48341 .62135 m .48007 .65962 L .45886 .65654 L p .707 .577 .707 r
F P
0 g
s
.45886 .65654 m .4622 .61827 L .48341 .62135 L p .707 .577 .707 r
F P
0 g
s
.43402 .50229 m .43638 .55596 L .40522 .55458 L p .707 .577 .707 r
F P
0 g
s
.40522 .55458 m .40286 .50091 L .43402 .50229 L p .707 .577 .707 r
F P
0 g
s
.31992 .65415 m .32085 .67189 L .30459 .68318 L p .707 .577 .707 r
F P
0 g
s
.31564 .64481 m .31898 .60654 L .34274 .60751 L p .707 .577 .707 r
F P
0 g
s
.34274 .60751 m .3394 .64578 L .31564 .64481 L p .707 .577 .707 r
F P
0 g
s
.37341 .55687 m .37106 .5032 L .40286 .50091 L p .707 .577 .707 r
F P
0 g
s
.37106 .5032 m .37341 .55687 L .34408 .5626 L p .707 .577 .707 r
F P
0 g
s
.48471 .65074 m .48565 .66848 L .46455 .66022 L p .707 .577 .707 r
F P
0 g
s
.46455 .66022 m .46361 .64248 L .48471 .65074 L p .707 .577 .707 r
F P
0 g
s
.40286 .50091 m .40522 .55458 L .37341 .55687 L p .707 .577 .707 r
F P
0 g
s
.4622 .61827 m .45886 .65654 L .43135 .65331 L p .707 .577 .707 r
F P
0 g
s
.43135 .65331 m .4347 .61504 L .4622 .61827 L p .707 .577 .707 r
F P
0 g
s
.37189 .60938 m .36855 .64765 L .3394 .64578 L p .707 .577 .707 r
F P
0 g
s
.32085 .67189 m .31992 .65415 L .34388 .64496 L p .707 .577 .707 r
F P
0 g
s
.3394 .64578 m .34274 .60751 L .37189 .60938 L p .707 .577 .707 r
F P
0 g
s
.34388 .64496 m .34482 .6627 L .32085 .67189 L p .707 .577 .707 r
F P
0 g
s
.46361 .64248 m .46455 .66022 L .43707 .65521 L p .707 .577 .707 r
F P
0 g
s
.43707 .65521 m .43613 .63747 L .46361 .64248 L p .707 .577 .707 r
F P
0 g
s
.4347 .61504 m .43135 .65331 L .40023 .65024 L p .707 .577 .707 r
F P
0 g
s
.40023 .65024 m .40357 .61198 L .4347 .61504 L p .707 .577 .707 r
F P
0 g
s
.36855 .64765 m .37189 .60938 L .40357 .61198 L p .707 .577 .707 r
F P
0 g
s
.34482 .6627 m .34388 .64496 L .37319 .63877 L p .707 .577 .707 r
F P
0 g
s
.40357 .61198 m .40023 .65024 L .36855 .64765 L p .707 .577 .707 r
F P
0 g
s
.43613 .63747 m .43707 .65521 L .40591 .65393 L p .707 .577 .707 r
F P
0 g
s
.40591 .65393 m .40498 .63619 L .43613 .63747 L p .707 .577 .707 r
F P
0 g
s
.37319 .63877 m .37413 .65651 L .34482 .6627 L p .707 .577 .707 r
F P
0 g
s
.37413 .65651 m .37319 .63877 L .40498 .63619 L p .707 .577 .707 r
F P
0 g
s
.40498 .63619 m .40591 .65393 L .37413 .65651 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo6000QWoo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Aoo`<00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00L7oo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool3
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00
JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEPl000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo2@0015YF00<005YFFUH01UYF00<005YF00000`000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000;FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001UOol005ioo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00
G7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00IGoo001JOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00EWoo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000IOol80015Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`L000AJEP04001J
EUYFFUH8000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF
00QJEP03001JEUYF00EJEP04001JEUYFFUH6000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000Yoo`@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo100000=JEP00FUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH015YF1`0025YF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000_Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH4
0005FUH00`00FUIJEP06FUH50004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool005=oo`04001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP04FUH50004FUH00`00
FUIJEP08FUH600000eYF001JEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH0
0003FUH00`00FUH000030004Ool01000FUIJEP001UYF1@0015YF00<005YFFUH015YF100015YF00@0
05YF000000=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000=JEP800003FUH0
000000<0009oo`04001JEUYF0006FUH50004FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF00<005YF
FUH00UYF00@005YFFUIJEQP000IJEP03001JEUYF00=JEP03001JEUYF009JEP@00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<00003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`07001JEP00FUH005YFOol00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF0`00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo0017Ool90004Ool20002FUH01000FUIJEWoo0UYF00<0
05YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF5`0015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000oOol80004FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040007Ool3000=Ool50005FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH4000:Ool5000>Ool50003FUH00`00FUIJEP02000]Ool003Moo`800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEP0000<000ioo`D000]oo`<000EJEP800004FUH005YFFUH2000]Ool003Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ400003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEPL000eoo`D000Moo`@00003FUH0
05YF00EJEP04001JEP000002FUH2000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH900000eYF001JEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH01000FUIJEUYF2@001Goo0`0000=o
o`0000001@001EYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000]Ool0035oo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEQ400003FUH005YF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;goo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPL000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00L005YFFUIJEP00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00005
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70004FUH01000FUIJEUYF20000eYF00<005YFFUH015YF
00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000EJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001J
EUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00
15YF00<005YFFUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEPX00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP04001JEUYF000`Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT0009JEQ4000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<0009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP0B0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000a
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH70009Ool90003FUH30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030003
FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP03
FUH2000cOol002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP040007Ool3000>Ool5
0003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH00UYF0P00=Goo000/Ool01000FUIJEP0015YF00<005YFFUH00UYF10002Woo1@003Woo
0P001UYF00<005YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF0P0000=JEP0000000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Io
o`00;Goo00<005YF000015YF00<005YF00000P003Woo1@002goo10001eYF00<005YFFUH0100000=J
EP0000001`0015YF00<005YFFUH01EYF1P0015YF00<005YF00000P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Woo
000]Ool00`00FUH00004FUH7000<Ool50007Ool600000eYF001JEP05FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH@0002FUH20003FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Goo00<005YF00000UYF0P000eYF00@005YFFUIJEQP000=JEP03001JEUYF009JEP04001JEUYF
FUH20003FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF1P0000EJEP00FUIJEP00
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF00000P0015YF00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00=JEP80009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;Goo00L005YF001JEP00FUIoo`03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20002FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF00H005YF000005YF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00=JEPl000EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00000UYF0P0015YF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<0
05YF000010001UYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF0P001eYF00<005YFFUH01UYF00H005YFFUIJEP00FUH40006FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH80003FUH70003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH01`00FUIJEUYF001JEP0002eoo`00;Goo0P000UYF00@0
05YFFUIoo`9JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00AJEPD000AJEP03001JEUYF00UJEP03
001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH2000^Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP8000MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF
00000UYF00<005YFFUH015YF1@0015YF00<005YFFUH02EYF00<005YFFUH01UYF00D005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP8000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0
000002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH50004FUH00`00FUIJEP09FUH00`00FUIJEP04FUH3000015YF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH00eYF1000;Woo000^Ool01000FUIJEP000eYF00=ooeYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH015YF00D005YFFUIJEP00009J
EP03001JEUYF00AJEP@000EJEP03001JEUYF00UJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`<000IJEP03001J
EUYF009JEPP000QJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEP00000^Ool002eo
oa400003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0006FUH00`00FUIJ
EP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP020004FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP03FUH70002OolB0004FUH00`00FUH000030004FUH01000FUIJEP00;Woo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH01eYF00<005YFFUH00P000UYF
0P001UYF0`0000Eoo`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@00003FUH005YF
00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH01000FUIJEUYF0P000eYF00@005YF000001Aoo`d00005FUH005YFFUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH005YF009JEP05
001JEUYF001JEP030002FUH20003Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP06001JEP00001JEP0015YF0`008Goo0P000UYF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP02FUH50002Ool01000FUIJEP001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP8000=JEP03001JEUYF009JEP<002=oo`04001JEUYF000]Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP04001JEUYFFUH90003FUH00`00FUIJEP03FUH70005FUH0
0`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00UYF0`0097oo0`00;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030007FUH01`00FUIJEUYF001JEP0000Qoo`<001Yoo`8002eoo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0007FUH01`00FUIJEUYF001JEP0000Moo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH01EYF00@005YFFUIJEP8000Qoo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH015YF00@005YFFUIJEP8000Qoo`D001Moo`800003FUH007oo
02aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF3P00
1EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH00UYF1`0025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YF
FUH015YF00D005YFFUIJEP0000Yoo`<001Ioo`800004FUH005YF000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEP0000<00003FUH0
05YF00AJEP03001JEUYF010000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH00000FUH00006FUH01000FUIJ
EP008Woo0P000eYF0P00;Woo000/OolC0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P001UYF0`008Goo0P0000=JEP00FUH00UYF0P00;Woo000]Ool200000eYF001JEP04FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
0002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0`0015YF0P008Goo
0P000eYF00D005YFFUIJEP0002moo`00;goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00@001moo`@000EJEP04001JEUYF000`Ool003=o
o`8000IJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF009JEP<0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF009JEPD001Qoo`@0009JEP03001JEUYF00AJEP<0035o
o`00<Woo0P001eYF00<005YFFUH00UYF300015YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJEP03001JEUYF
00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH01000FUIJEUYF
60001UYF00<005YFFUH00eYF0P00<goo000`Ool200000eYF001JEP05FUH6000<OolC0004FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000_Ool00`00FUIJEP02FUH01000FUIJEUYF0P008Woo1P0000=JEP0000000UYF00<005YFFUH015YF
00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
10001UYF00<005YFFUH00UYF0P0015YF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;Woo0P0015YF00@005YF000002Yoo`<0009J
EP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP8000IJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<003Uoo`00;Woo0P0015YF0P00;Woo00@0
05YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP@000AJEP8000IJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@003aoo`00;Goo00<005YF00000UYF0P00<7oo00D005YFFUH005YF0080
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYFFUH20002FUH50002FUH00`00FUIJEP04FUHJ0010Ool002eoo`03001JEP000080
01Ioo`<001Uoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEPH0009JEP07
001JEUYFFUH005YF0000E7oo000]Ool00`00FUH0000GOol5000HOol00`00FUH00003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YF00000P000eYF0P00EGoo000]Ool2000H
Ool5000HOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH0
0UYF0P0000=JEP000000EGoo000]Ool2000HOol5000GOol30004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH000001eYF00<005YFFUH00eYF1000EGoo000]Ool3000HOol3000FOol200000eYF
00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP040004FUH00`00FUIJEP03FUH0
1000FUH00000EGoo000]Ool200000eYF001oo`0]Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP000eYF1P0015YF00@005YFFUH005Eoo`00;Goo0P000UYF0P00
:Woo0P0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00003@0000EJEP00FUIJEP0005Eoo`00;Woo00D005YFFUH005YF00<002Eoo`8000=JEP03001JEUYF
009JEP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000ioo`80009JEP03001oogoo05=oo`00
;Woo00@005YFFUH000AJEP<001moo`<000EJEP03001JEUYF008000=oo`<000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP80015oo`04001JEP00001DOol002moo`04001JEUYF0004FUH00`00FUH00003000GOol400000eYF
001JEP05FUH30007Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUH00002000DOol00`00FUH0001DOol0031oo`<000AJEP03
001JEUYF00=JEQL000EJEP03001JEUYF00AJEP03001oogoo00Yoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<001Qoo`8005Aoo`00
<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEP80015oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@001Yoo`8005Aoo`00<goo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000001Qoo`H0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000P001Qoo`03001JEP0005Aoo`00=Goo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100087oo20001UYF00<005YF
FUH02UYF00<005YFFUH015YF1`0017oo1@005goo0P0000=JEP00Ool0Dgoo000gOol50003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000/OolJ000;Ool5000FOol01@00FUH005YF0000
E7oo000lOolH000kOol2000IOol3000FOol01000FUIJEUYF0P00E7oo002?Ool01000FUH00000;Woo
0P0015YF00<007ooOol0Dgoo002?Ool01000FUIJEUYF0P00:7oo100000=JEP00FUH00eYF00<007oo
Ool0Dgoo002?Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP05001JEUYFFUH0001FOol008moo`05
001JEUYFFUH00004FUH5000HOol40002FUH00`00FUIJEP04FUH01000FUH00000Egoo002@Ool01000
FUIJEP001EYF00@005YFFUIJEPP000Uoo`L000IJEP03001JEUYF00AJEP8005Uoo`00TGoo0`001EYF
00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Yoo`00
Tgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000`00G7oo002EOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3001POol009Qoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06=oo`00WGoo2@0015YF00<005YFFUH00UYF1`00Igoo002VOol9001^Ool00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59478 .73995 m .59713 .68313 L .56597 .68069 L p .707 .577 .707 r
F P
0 g
s
.59713 .68313 m .59478 .73995 L .62658 .74073 L p .707 .577 .707 r
F P
0 g
s
.62658 .74073 m .62894 .68391 L .59713 .68313 L p .707 .577 .707 r
F P
0 g
s
.62894 .68391 m .62658 .74073 L .65591 .73978 L p .707 .577 .707 r
F P
0 g
s
.65591 .73978 m .65827 .68295 L .62894 .68391 L p .707 .577 .707 r
F P
0 g
s
.56362 .73751 m .56597 .68069 L .5385 .67683 L p .707 .577 .707 r
F P
0 g
s
.56597 .68069 m .56362 .73751 L .59478 .73995 L p .707 .577 .707 r
F P
0 g
s
.65827 .68295 m .65591 .73978 L .6799 .73718 L p .707 .577 .707 r
F P
0 g
s
.6799 .73718 m .68226 .68036 L .65827 .68295 L p .707 .577 .707 r
F P
0 g
s
.5385 .67683 m .53615 .73366 L .56362 .73751 L p .707 .577 .707 r
F P
0 g
s
.53615 .73366 m .5385 .67683 L .51742 .67194 L p .707 .577 .707 r
F P
0 g
s
.59408 .84024 m .59502 .82124 L .56386 .8187 L p .707 .577 .707 r
F P
0 g
s
.59502 .82124 m .59408 .84024 L .62587 .84133 L p .707 .577 .707 r
F P
0 g
s
.62587 .84133 m .62681 .82233 L .59502 .82124 L p .707 .577 .707 r
F P
0 g
s
.59977 .82893 m .59642 .79514 L .5653 .79434 L p .707 .577 .707 r
F P
0 g
s
.62681 .82233 m .62587 .84133 L .65518 .84086 L p .707 .577 .707 r
F P
0 g
s
.65518 .84086 m .65612 .82186 L .62681 .82233 L p .707 .577 .707 r
F P
0 g
s
.59642 .79514 m .59977 .82893 L .63145 .82498 L p .707 .577 .707 r
F P
0 g
s
.63145 .82498 m .62811 .7912 L .59642 .79514 L p .707 .577 .707 r
F P
0 g
s
.62811 .7912 m .63145 .82498 L .6606 .81666 L p .707 .577 .707 r
F P
0 g
s
.6606 .81666 m .65726 .78288 L .62811 .7912 L p .707 .577 .707 r
F P
0 g
s
.51742 .67194 m .51506 .72876 L .53615 .73366 L p .707 .577 .707 r
F P
0 g
s
.56386 .8187 m .56293 .83769 L .59408 .84024 L p .707 .577 .707 r
F P
0 g
s
.56293 .83769 m .56386 .8187 L .53639 .81495 L p .707 .577 .707 r
F P
0 g
s
.56865 .82812 m .5653 .79434 L .53779 .78885 L p .707 .577 .707 r
F P
0 g
s
.5653 .79434 m .56865 .82812 L .59977 .82893 L p .707 .577 .707 r
F P
0 g
s
.68226 .68036 m .6799 .73718 L .6962 .7332 L p .707 .577 .707 r
F P
0 g
s
.6962 .7332 m .69855 .67638 L .68226 .68036 L p .707 .577 .707 r
F P
0 g
s
.65726 .78288 m .6606 .81666 L .68436 .80479 L p .707 .577 .707 r
F P
0 g
s
.68436 .80479 m .68102 .771 L .65726 .78288 L p .707 .577 .707 r
F P
0 g
s
.53639 .81495 m .53545 .83395 L .56293 .83769 L p .707 .577 .707 r
F P
0 g
s
.51506 .72876 m .51742 .67194 L .50477 .66648 L p .707 .577 .707 r
F P
0 g
s
.65612 .82186 m .65518 .84086 L .67914 .83887 L p .707 .577 .707 r
F P
0 g
s
.67914 .83887 m .68008 .81987 L .65612 .82186 L p .707 .577 .707 r
F P
0 g
s
.54114 .82264 m .53779 .78885 L .51659 .77923 L p .707 .577 .707 r
F P
0 g
s
.53779 .78885 m .54114 .82264 L .56865 .82812 L p .707 .577 .707 r
F P
0 g
s
.53048 .81366 m .51529 .81036 L p .53582 .82645 L .707 .577 .707 r
F P
0 g
s
.51993 .81301 m .51675 .78083 L p .50376 .7664 L .707 .577 .707 r
F P
0 g
s
.51675 .78083 m .51659 .77923 L .51571 .77835 L p .707 .577 .707 r
F P
0 g
s
.51571 .77835 m .50376 .7664 L p .51675 .78083 L .707 .577 .707 r
F P
0 g
s
.53545 .83395 m .53582 .82645 L p .51529 .81036 L .707 .577 .707 r
F P
0 g
s
.53582 .82645 m .53639 .81495 L .53048 .81366 L p .707 .577 .707 r
F P
0 g
s
.50477 .66648 m .50242 .7233 L .51506 .72876 L p .707 .577 .707 r
F P
0 g
s
.51529 .81036 m .51435 .82936 L .53545 .83395 L p .707 .577 .707 r
F P
0 g
s
.68102 .771 m .68436 .80479 L .7004 .79052 L p .707 .577 .707 r
F P
0 g
s
.7004 .79052 m .69706 .75674 L .68102 .771 L p .707 .577 .707 r
F P
0 g
s
.69855 .67638 m .6962 .7332 L .70321 .72823 L p .707 .577 .707 r
F P
0 g
s
.70321 .72823 m .70557 .6714 L .69855 .67638 L p .707 .577 .707 r
F P
0 g
s
.68008 .81987 m .67914 .83887 L .69541 .83556 L p .707 .577 .707 r
F P
0 g
s
.69541 .83556 m .69635 .81657 L .68008 .81987 L p .707 .577 .707 r
F P
0 g
s
.51659 .77923 m .51993 .81301 L .54114 .82264 L p .707 .577 .707 r
F P
0 g
s
.50242 .7233 m .50477 .66648 L .50181 .66099 L p .707 .577 .707 r
F P
0 g
s
.51435 .82936 m .51529 .81036 L .50262 .80539 L p .707 .577 .707 r
F P
0 g
s
.50262 .80539 m .50168 .82438 L .51435 .82936 L p .707 .577 .707 r
F P
0 g
s
.69706 .75674 m .7004 .79052 L .70716 .77526 L p .707 .577 .707 r
F P
0 g
s
.70716 .77526 m .70382 .74147 L .69706 .75674 L p .707 .577 .707 r
F P
0 g
s
.50181 .66099 m .49946 .71782 L .50242 .7233 L p .707 .577 .707 r
F P
0 g
s
.50376 .7664 m .5071 .80019 L .51993 .81301 L p .707 .577 .707 r
F P
0 g
s
.70557 .6714 m .70321 .72823 L .70025 .72274 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .70261 .66592 L .70557 .6714 L p .707 .577 .707 r
F P
0 g
s
.69635 .81657 m .69541 .83556 L .70239 .83126 L p .707 .577 .707 r
F P
0 g
s
.70239 .83126 m .70333 .81227 L .69635 .81657 L p .707 .577 .707 r
F P
0 g
s
.4926 .82254 m .48939 .32288 L .44538 .32031 L p .707 .577 .707 r
F P
0 g
s
.5071 .80019 m .50376 .7664 L .50057 .75164 L p .707 .577 .707 r
F P
0 g
s
.49946 .71782 m .50181 .66099 L .50882 .65602 L p .707 .577 .707 r
F P
0 g
s
.50168 .82438 m .50262 .80539 L .49963 .80051 L p .707 .577 .707 r
F P
0 g
s
.49963 .80051 m .4987 .8195 L .50168 .82438 L p .707 .577 .707 r
F P
0 g
s
.50882 .65602 m .50647 .71284 L .49946 .71782 L p .707 .577 .707 r
F P
0 g
s
.50391 .78542 m .5071 .80019 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50057 .75164 m .50156 .76159 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50156 .76159 m .50391 .78542 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .49963 .80051 L .50467 .7974 L p .707 .577 .707 r
F P
0 g
s
.50467 .7974 m .50662 .7962 L p .50498 .80101 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .50467 .7974 L .50498 .80101 L .707 .577 .707 r
F
.50391 .78542 m .50057 .75164 L .50733 .73637 L p F P
0 g
s
.50647 .71284 m .50882 .65602 L .52512 .65204 L p .707 .577 .707 r
F P
0 g
s
.50662 .7962 m .50568 .8152 L .4987 .8195 L p .707 .577 .707 r
F P
0 g
s
.50733 .73637 m .51067 .77016 L .50391 .78542 L p .707 .577 .707 r
F P
0 g
s
.52512 .65204 m .52277 .70886 L .50647 .71284 L p .707 .577 .707 r
F P
0 g
s
.51067 .77016 m .50733 .73637 L .52337 .72211 L p .707 .577 .707 r
F P
0 g
s
.52277 .70886 m .52512 .65204 L .54911 .64944 L p .707 .577 .707 r
F P
0 g
s
.50568 .8152 m .50662 .7962 L .52288 .7929 L p .707 .577 .707 r
F P
0 g
s
.52288 .7929 m .52195 .81189 L .50568 .8152 L p .707 .577 .707 r
F P
0 g
s
.52337 .72211 m .52672 .75589 L .51067 .77016 L p .707 .577 .707 r
F P
0 g
s
.54911 .64944 m .54676 .70627 L .52277 .70886 L p .707 .577 .707 r
F P
0 g
s
.52672 .75589 m .52337 .72211 L .54713 .71023 L p .707 .577 .707 r
F P
0 g
s
.54713 .71023 m .55047 .74402 L .52672 .75589 L p .707 .577 .707 r
F P
0 g
s
.52195 .81189 m .52288 .7929 L .54685 .79091 L p .707 .577 .707 r
F P
0 g
s
.54685 .79091 m .54591 .80991 L .52195 .81189 L p .707 .577 .707 r
F P
0 g
s
.48939 .32288 m .4926 .82254 L .53754 .82112 L p .707 .577 .707 r
F P
0 g
s
.53754 .82112 m .53433 .32145 L .48939 .32288 L p .707 .577 .707 r
F P
0 g
s
.54676 .70627 m .54911 .64944 L .57844 .64849 L p .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .57609 .70531 L .54676 .70627 L p .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .57624 .70155 L .58541 .69001 L .707 .577 .707 r
F
.57609 .70531 m .57624 .70155 L p .57845 .70143 L F P
0 g
s
.58145 .70127 m .60797 .69797 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .57609 .70531 L p .57845 .70143 L .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .60307 .7001 L .60789 .70609 L .707 .577 .707 r
F
.60797 .69797 m .60815 .69983 L p .6065 .69992 L F P
0 g
s
.60815 .69983 m .60789 .70609 L p .58952 .68327 L .707 .577 .707 r
F P
0 g
s
.61131 .73175 m .57962 .7357 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60797 .69797 m .63909 .69877 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .60789 .70609 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.61164 .70001 m .62885 .70088 L .63905 .70853 L .707 .577 .707 r
F
.60995 .69992 m .60797 .69797 L .63697 .70129 L F
.62885 .70088 m .63413 .70114 L .63905 .70853 L F
.63909 .69877 m .63935 .70141 L p .63697 .70129 L F P
0 g
s
.63935 .70141 m .63905 .70853 L p .62358 .68532 L .707 .577 .707 r
F P
0 g
s
.64243 .73256 m .61131 .73175 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63909 .69877 m .6666 .70426 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .63905 .70853 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.64274 .70199 m .6572 .70448 L .66652 .71239 L .707 .577 .707 r
F
.64169 .70181 m .63909 .69877 L .66523 .70586 L F
.6572 .70448 m .663 .70547 L .66652 .71239 L F
.6666 .70426 m .66678 .70612 L p .66523 .70586 L F P
0 g
s
.66678 .70612 m .66652 .71239 L p .6544 .68863 L .707 .577 .707 r
F P
0 g
s
.66994 .73804 m .64243 .73256 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .66652 .71239 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.669 .7069 m .68135 .71126 L .68761 .71728 L .707 .577 .707 r
F
.6666 .70426 m .68434 .71231 L p .66812 .7066 L F P
0 g
s
.68897 .6845 m .68761 .71728 L p .67137 .70165 L .707 .577 .707 r
F P
0 g
s
.68996 .66046 m .70261 .66592 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .68777 .71352 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68777 .71352 m .68996 .66046 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.66888 .65556 m .68996 .66046 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .66678 .70612 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .6666 .70426 L p .66812 .7066 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66888 .65556 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66812 .7066 L .67987 .72462 L .707 .577 .707 r
F
.67987 .72462 m .66812 .7066 L .68759 .71381 L F
.68639 .71579 m .68759 .71381 L .6878 .71388 L F
.67987 .72462 m .68759 .71381 L .68639 .71579 L F
.68434 .71231 m .6878 .71388 L p .66812 .7066 L F P
0 g
s
.669 .7069 m .67137 .70165 L .68135 .71126 L .707 .577 .707 r
F
.68996 .66046 m .68897 .6845 L p .67137 .70165 L F P
0 g
s
.66678 .70612 m .66994 .73804 L p .66546 .70741 L .707 .577 .707 r
F P
0 g
s
.66523 .70586 m .66678 .70612 L .66546 .70741 L .707 .577 .707 r
F
.64646 .69537 m .6544 .68863 L .663 .70547 L F
.64646 .69537 m .663 .70547 L .6572 .70448 L F
.66798 .6771 m .66678 .70612 L p .6544 .68863 L F P
0 g
s
.66994 .73804 m .66678 .70612 L p .67987 .72462 L .707 .577 .707 r
F P
0 g
s
.64141 .65171 m .66888 .65556 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .63935 .70141 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .63909 .69877 L p .64169 .70181 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64141 .65171 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64169 .70181 L .65521 .71759 L .707 .577 .707 r
F
.65521 .71759 m .64169 .70181 L .66523 .70586 L F
.64274 .70199 m .64646 .69537 L .6572 .70448 L F
.66888 .65556 m .66798 .6771 L p .64646 .69537 L F P
0 g
s
.63935 .70141 m .64243 .73256 L p .6373 .70315 L .707 .577 .707 r
F P
0 g
s
.63697 .70129 m .63935 .70141 L .6373 .70315 L .707 .577 .707 r
F
.61671 .69178 m .62358 .68532 L .63413 .70114 L F
.61671 .69178 m .63413 .70114 L .62885 .70088 L F
.64068 .66923 m .63935 .70141 L p .62358 .68532 L F P
0 g
s
.64243 .73256 m .63935 .70141 L p .65521 .71759 L .707 .577 .707 r
F P
0 g
s
.61025 .64927 m .64141 .65171 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .60815 .69983 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60797 .69797 L p .60995 .69992 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .61025 .64927 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60995 .69992 L .62533 .71511 L .707 .577 .707 r
F
.62533 .71511 m .60995 .69992 L .63697 .70129 L F
.61164 .70001 m .61671 .69178 L .62885 .70088 L F
.64141 .65171 m .64068 .66923 L p .61671 .69178 L F P
0 g
s
.60815 .69983 m .61131 .73175 L p .60669 .7012 L .707 .577 .707 r
F P
0 g
s
.6065 .69992 m .60815 .69983 L .60669 .7012 L .707 .577 .707 r
F
.57845 .70143 m .58952 .68327 L .60307 .7001 L F
.61025 .64927 m .60815 .69983 L p .58952 .68327 L F P
0 g
s
.61131 .73175 m .60815 .69983 L p .62533 .71511 L .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .57628 .70191 L .58145 .70127 L p .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .58145 .70127 L .6065 .69992 L .707 .577 .707 r
F
.55047 .74402 m .54959 .73509 L p .57628 .70191 L F P
0 g
s
.54959 .73509 m .54713 .71023 L .57586 .70203 L p .707 .577 .707 r
F P
0 g
s
.57586 .70203 m .57628 .70191 L p .54959 .73509 L .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .61025 .64927 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57624 .70155 m .57844 .64849 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57628 .70191 m .57962 .7357 L .55047 .74402 L p .707 .577 .707 r
F P
0 g
s
.54591 .80991 m .54685 .79091 L .57615 .79044 L p .707 .577 .707 r
F P
0 g
s
.57615 .79044 m .57522 .80944 L .54591 .80991 L p .707 .577 .707 r
F P
0 g
s
.57522 .80944 m .57615 .79044 L .60794 .79153 L p .707 .577 .707 r
F P
0 g
s
.60794 .79153 m .60701 .81053 L .57522 .80944 L p .707 .577 .707 r
F P
0 g
s
.53433 .32145 m .53754 .82112 L .57902 .81584 L p .707 .577 .707 r
F P
0 g
s
.57902 .81584 m .57581 .31617 L .53433 .32145 L p .707 .577 .707 r
F P
0 g
s
.44859 .81997 m .44538 .32031 L .40662 .31399 L p .707 .577 .707 r
F P
0 g
s
.44538 .32031 m .44859 .81997 L .4926 .82254 L p .707 .577 .707 r
F P
0 g
s
.70382 .74147 m .70716 .77526 L .70397 .76049 L p .707 .577 .707 r
F P
0 g
s
.70397 .76049 m .70063 .72671 L .70382 .74147 L p .707 .577 .707 r
F P
0 g
s
.60701 .81053 m .60794 .79153 L .6391 .79407 L p .707 .577 .707 r
F P
0 g
s
.57581 .31617 m .57902 .81584 L .61297 .80722 L p .707 .577 .707 r
F P
0 g
s
.61297 .80722 m .60977 .30756 L .57581 .31617 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .68761 .71728 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.6878 .71388 m .69115 .74767 L .67228 .7391 L p .707 .577 .707 r
F P
0 g
s
.67228 .7391 m .66994 .73804 L p .68639 .71579 L .707 .577 .707 r
F P
0 g
s
.68639 .71579 m .6878 .71388 L .67228 .7391 L .707 .577 .707 r
F
.70261 .66592 m .70158 .6907 L p .68959 .71051 L F P
0 g
s
.70158 .6907 m .70025 .72274 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.70333 .81227 m .70239 .83126 L .6994 .82638 L p .707 .577 .707 r
F P
0 g
s
.6994 .82638 m .70034 .80739 L .70333 .81227 L p .707 .577 .707 r
F P
0 g
s
.40983 .81366 m .40662 .31399 L .37689 .30455 L p .707 .577 .707 r
F P
0 g
s
.40662 .31399 m .40983 .81366 L .44859 .81997 L p .707 .577 .707 r
F P
0 g
s
.25177 .70314 m .25412 .64631 L .22296 .64387 L p .707 .577 .707 r
F P
0 g
s
.25412 .64631 m .25177 .70314 L .28357 .70392 L p .707 .577 .707 r
F P
0 g
s
.28357 .70392 m .28593 .64709 L .25412 .64631 L p .707 .577 .707 r
F P
0 g
s
.28593 .64709 m .28357 .70392 L .31291 .70296 L p .707 .577 .707 r
F P
0 g
s
.31291 .70296 m .31526 .64614 L .28593 .64709 L p .707 .577 .707 r
F P
0 g
s
.70063 .72671 m .70397 .76049 L .69115 .74767 L p .707 .577 .707 r
F P
0 g
s
.69115 .74767 m .6878 .71388 L .70063 .72671 L p .707 .577 .707 r
F P
0 g
s
.22061 .7007 m .22296 .64387 L .19549 .64002 L p .707 .577 .707 r
F P
0 g
s
.22296 .64387 m .22061 .7007 L .25177 .70314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31526 .64614 m .31291 .70296 L .33689 .70037 L p .707 .577 .707 r
F P
0 g
s
.33689 .70037 m .33925 .64354 L .31526 .64614 L p .707 .577 .707 r
F P
0 g
s
.19549 .64002 m .19314 .69684 L .22061 .7007 L p .707 .577 .707 r
F P
0 g
s
.6391 .79407 m .63816 .81307 L .60701 .81053 L p .707 .577 .707 r
F P
0 g
s
.60977 .30756 m .61297 .80722 L .63608 .79611 L p .707 .577 .707 r
F P
0 g
s
.63608 .79611 m .63287 .29644 L .60977 .30756 L p .707 .577 .707 r
F P
0 g
s
.19314 .69684 m .19549 .64002 L .17441 .63512 L p .707 .577 .707 r
F P
0 g
s
.70034 .80739 m .6994 .82638 L .68674 .82141 L p .707 .577 .707 r
F P
0 g
s
.68674 .82141 m .68768 .80241 L .70034 .80739 L p .707 .577 .707 r
F P
0 g
s
.25107 .80342 m .25201 .78443 L .22086 .78188 L p .707 .577 .707 r
F P
0 g
s
.25201 .78443 m .25107 .80342 L .28286 .80451 L p .707 .577 .707 r
F P
0 g
s
.28286 .80451 m .2838 .78552 L .25201 .78443 L p .707 .577 .707 r
F P
0 g
s
.25676 .79211 m .25341 .75833 L .22229 .75752 L p .707 .577 .707 r
F P
0 g
s
.2838 .78552 m .28286 .80451 L .31217 .80404 L p .707 .577 .707 r
F P
0 g
s
.31217 .80404 m .31311 .78505 L .2838 .78552 L p .707 .577 .707 r
F P
0 g
s
.25341 .75833 m .25676 .79211 L .28844 .78816 L p .707 .577 .707 r
F P
0 g
s
.28844 .78816 m .2851 .75438 L .25341 .75833 L p .707 .577 .707 r
F P
0 g
s
.2851 .75438 m .28844 .78816 L .31759 .77985 L p .707 .577 .707 r
F P
0 g
s
.31759 .77985 m .31425 .74606 L .2851 .75438 L p .707 .577 .707 r
F P
0 g
s
.17441 .63512 m .17205 .69195 L .19314 .69684 L p .707 .577 .707 r
F P
0 g
s
.3801 .80422 m .37689 .30455 L .35911 .29291 L p .707 .577 .707 r
F P
0 g
s
.37689 .30455 m .3801 .80422 L .40983 .81366 L p .707 .577 .707 r
F P
0 g
s
.22086 .78188 m .21992 .80088 L .25107 .80342 L p .707 .577 .707 r
F P
0 g
s
.21992 .80088 m .22086 .78188 L .19338 .77813 L p .707 .577 .707 r
F P
0 g
s
.22564 .79131 m .22229 .75752 L .19478 .75204 L p .707 .577 .707 r
F P
0 g
s
.22229 .75752 m .22564 .79131 L .25676 .79211 L p .707 .577 .707 r
F P
0 g
s
.33925 .64354 m .33689 .70037 L .35319 .69639 L p .707 .577 .707 r
F P
0 g
s
.35319 .69639 m .35555 .63956 L .33925 .64354 L p .707 .577 .707 r
F P
0 g
s
.31425 .74606 m .31759 .77985 L .34135 .76797 L p .707 .577 .707 r
F P
0 g
s
.34135 .76797 m .33801 .73419 L .31425 .74606 L p .707 .577 .707 r
F P
0 g
s
.19338 .77813 m .19244 .79713 L .21992 .80088 L p .707 .577 .707 r
F P
0 g
s
.17205 .69195 m .17441 .63512 L .16176 .62966 L p .707 .577 .707 r
F P
0 g
s
.31311 .78505 m .31217 .80404 L .33613 .80206 L p .707 .577 .707 r
F P
0 g
s
.33613 .80206 m .33707 .78306 L .31311 .78505 L p .707 .577 .707 r
F P
0 g
s
.19813 .78582 m .19478 .75204 L .17358 .74241 L p .707 .577 .707 r
F P
0 g
s
.19478 .75204 m .19813 .78582 L .22564 .79131 L p .707 .577 .707 r
F P
0 g
s
.63287 .29644 m .63608 .79611 L .64608 .78359 L p .707 .577 .707 r
F P
0 g
s
.64608 .78359 m .64287 .28393 L .63287 .29644 L p .707 .577 .707 r
F P
0 g
s
.18747 .77685 m .17228 .77355 L p .19281 .78963 L .707 .577 .707 r
F P
0 g
s
.17692 .77619 m .17374 .74401 L p .16075 .72959 L .707 .577 .707 r
F P
0 g
s
.17374 .74401 m .17358 .74241 L .1727 .74153 L p .707 .577 .707 r
F P
0 g
s
.1727 .74153 m .16075 .72959 L p .17374 .74401 L .707 .577 .707 r
F P
0 g
s
.19244 .79713 m .19281 .78963 L p .17228 .77355 L .707 .577 .707 r
F P
0 g
s
.19281 .78963 m .19338 .77813 L .18747 .77685 L p .707 .577 .707 r
F P
0 g
s
.16176 .62966 m .15941 .68649 L .17205 .69195 L p .707 .577 .707 r
F P
0 g
s
.68768 .80241 m .68674 .82141 L .66564 .81682 L p .707 .577 .707 r
F P
0 g
s
.66564 .81682 m .66657 .79782 L .68768 .80241 L p .707 .577 .707 r
F P
0 g
s
.17228 .77355 m .17134 .79254 L .19244 .79713 L p .707 .577 .707 r
F P
0 g
s
.33801 .73419 m .34135 .76797 L .35739 .75371 L p .707 .577 .707 r
F P
0 g
s
.35739 .75371 m .35405 .71992 L .33801 .73419 L p .707 .577 .707 r
F P
0 g
s
.35555 .63956 m .35319 .69639 L .3602 .69141 L p .707 .577 .707 r
F P
0 g
s
.3602 .69141 m .36256 .63459 L .35555 .63956 L p .707 .577 .707 r
F P
0 g
s
.33707 .78306 m .33613 .80206 L .3524 .79875 L p .707 .577 .707 r
F P
0 g
s
.3524 .79875 m .35334 .77975 L .33707 .78306 L p .707 .577 .707 r
F P
0 g
s
.17358 .74241 m .17692 .77619 L .19813 .78582 L p .707 .577 .707 r
F P
0 g
s
.35405 .71992 m .35739 .75371 L .36415 .73844 L p .707 .577 .707 r
F P
0 g
s
.36415 .73844 m .36081 .70466 L .35405 .71992 L p .707 .577 .707 r
F P
0 g
s
.36256 .63459 m .3602 .69141 L .35724 .68593 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3596 .6291 L .36256 .63459 L p .707 .577 .707 r
F P
0 g
s
.36081 .70466 m .36415 .73844 L .36096 .72368 L p .707 .577 .707 r
F P
0 g
s
.36232 .79258 m .35911 .29291 L .35502 .28021 L p .707 .577 .707 r
F P
0 g
s
.35911 .29291 m .36232 .79258 L .3801 .80422 L p .707 .577 .707 r
F P
0 g
s
.15941 .68649 m .16176 .62966 L .1588 .62418 L p .707 .577 .707 r
F P
0 g
s
.17134 .79254 m .17228 .77355 L .15961 .76857 L p .707 .577 .707 r
F P
0 g
s
.66657 .79782 m .66564 .81682 L .63816 .81307 L p .707 .577 .707 r
F P
0 g
s
.63816 .81307 m .6391 .79407 L .66657 .79782 L p .707 .577 .707 r
F P
0 g
s
.15961 .76857 m .15868 .78757 L .17134 .79254 L p .707 .577 .707 r
F P
0 g
s
.1588 .62418 m .15645 .681 L .15941 .68649 L p .707 .577 .707 r
F P
0 g
s
.16075 .72959 m .1641 .76337 L .17692 .77619 L p .707 .577 .707 r
F P
0 g
s
.64287 .28393 m .64608 .78359 L .64199 .77089 L p .707 .577 .707 r
F P
0 g
s
.64199 .77089 m .63878 .27123 L .64287 .28393 L p .707 .577 .707 r
F P
0 g
s
.35334 .77975 m .3524 .79875 L .35938 .79445 L p .707 .577 .707 r
F P
0 g
s
.35938 .79445 m .36032 .77545 L .35334 .77975 L p .707 .577 .707 r
F P
0 g
s
.1641 .76337 m .16075 .72959 L .15756 .71482 L p .707 .577 .707 r
F P
0 g
s
.15645 .681 m .1588 .62418 L .16581 .6192 L p .707 .577 .707 r
F P
0 g
s
.15868 .78757 m .15961 .76857 L .15663 .76369 L p .707 .577 .707 r
F P
0 g
s
.36096 .72368 m .35762 .68989 L .36081 .70466 L p .707 .577 .707 r
F P
0 g
s
.15663 .76369 m .15569 .78269 L .15868 .78757 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3446 .68047 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3596 .6291 m .35857 .65388 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.35857 .65388 m .35724 .68593 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .3596 .6291 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .34476 .6767 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .34695 .62364 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .32351 .67557 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32359 .66744 L .34133 .6755 L p .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .34476 .6767 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .3446 .68047 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .34695 .62364 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .32377 .66931 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32587 .61875 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .29942 .69574 L p .31316 .67965 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .29604 .67171 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32359 .66744 m .32377 .66931 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32351 .67557 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .32359 .66744 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .29634 .66459 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .29634 .66459 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29608 .66196 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .32587 .61875 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .2984 .61489 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .32377 .66931 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.31316 .67965 m .32222 .66904 L .32377 .66931 L .707 .577 .707 r
F
.32377 .66931 m .32693 .70123 L p .31316 .67965 L F P
0 g
s
.32693 .70123 m .32377 .66931 L p .34459 .67698 L .707 .577 .707 r
F P
0 g
s
.34133 .6755 m .34459 .67698 L p .32377 .66931 L .707 .577 .707 r
F P
0 g
s
.34459 .67698 m .34479 .67707 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .34459 .67698 L .34338 .67898 L .707 .577 .707 r
F
.34479 .67707 m .34814 .71085 L .32927 .70229 L p F P
0 g
s
.32927 .70229 m .32693 .70123 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.34338 .67898 m .34479 .67707 L .32927 .70229 L .707 .577 .707 r
F
.36032 .77545 m .35938 .79445 L .35639 .78957 L p F P
0 g
s
.35639 .78957 m .35733 .77057 L .36032 .77545 L p .707 .577 .707 r
F P
0 g
s
.35762 .68989 m .36096 .72368 L .34814 .71085 L p .707 .577 .707 r
F P
0 g
s
.35502 .28021 m .35823 .77988 L .36232 .79258 L p .707 .577 .707 r
F P
0 g
s
.35823 .77988 m .35502 .28021 L .36502 .2677 L p .707 .577 .707 r
F P
0 g
s
.16581 .6192 m .16346 .67602 L .15645 .681 L p .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .15663 .76369 L .16166 .76059 L p .707 .577 .707 r
F P
0 g
s
.16091 .7486 m .1641 .76337 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.16166 .76059 m .16361 .75939 L p .16197 .76419 L .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .16166 .76059 L .16197 .76419 L .707 .577 .707 r
F
.15756 .71482 m .15855 .72477 L p .1579 .71733 L F P
0 g
s
.15855 .72477 m .16091 .7486 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16091 .7486 m .15756 .71482 L .16432 .69956 L p .707 .577 .707 r
F P
0 g
s
.16346 .67602 m .16581 .6192 L .18211 .61522 L p .707 .577 .707 r
F P
0 g
s
.34814 .71085 m .34479 .67707 L .35762 .68989 L p .707 .577 .707 r
F P
0 g
s
.63878 .27123 m .64199 .77089 L .62421 .75925 L p .707 .577 .707 r
F P
0 g
s
.62421 .75925 m .621 .25959 L .63878 .27123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16361 .75939 m .16267 .77839 L .15569 .78269 L p .707 .577 .707 r
F P
0 g
s
.16432 .69956 m .16766 .73334 L .16091 .7486 L p .707 .577 .707 r
F P
0 g
s
.18211 .61522 m .17976 .67204 L .16346 .67602 L p .707 .577 .707 r
F P
0 g
s
.16766 .73334 m .16432 .69956 L .18036 .68529 L p .707 .577 .707 r
F P
0 g
s
.36822 .76736 m .36502 .2677 L .38813 .25658 L p .707 .577 .707 r
F P
0 g
s
.36502 .2677 m .36822 .76736 L .35823 .77988 L p .707 .577 .707 r
F P
0 g
s
.35733 .77057 m .35639 .78957 L .34373 .78459 L p .707 .577 .707 r
F P
0 g
s
.34373 .78459 m .34467 .7656 L .35733 .77057 L p .707 .577 .707 r
F P
0 g
s
.17976 .67204 m .18211 .61522 L .2061 .61263 L p .707 .577 .707 r
F P
0 g
s
.16267 .77839 m .16361 .75939 L .17987 .75608 L p .707 .577 .707 r
F P
0 g
s
.17987 .75608 m .17894 .77508 L .16267 .77839 L p .707 .577 .707 r
F P
0 g
s
.18036 .68529 m .18371 .71907 L .16766 .73334 L p .707 .577 .707 r
F P
0 g
s
.2061 .61263 m .20375 .66945 L .17976 .67204 L p .707 .577 .707 r
F P
0 g
s
.18371 .71907 m .18036 .68529 L .20412 .67342 L p .707 .577 .707 r
F P
0 g
s
.621 .25959 m .62421 .75925 L .59448 .74982 L p .707 .577 .707 r
F P
0 g
s
.59448 .74982 m .59127 .25015 L .621 .25959 L p .707 .577 .707 r
F P
0 g
s
.20375 .66945 m .2061 .61263 L .23543 .61167 L p .707 .577 .707 r
F P
0 g
s
.34467 .7656 m .34373 .78459 L .32263 .78 L p .707 .577 .707 r
F P
0 g
s
.32263 .78 m .32356 .76101 L .34467 .7656 L p .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .26488 .66928 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29604 .67171 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .2683 .69493 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .29634 .66459 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29942 .69574 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .29608 .66196 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .26514 .66302 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .26514 .66302 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26496 .66115 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .2984 .61489 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26724 .61245 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .29634 .66459 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.38813 .25658 m .39133 .75625 L .36822 .76736 L p .707 .577 .707 r
F P
0 g
s
.39133 .75625 m .38813 .25658 L .42208 .24797 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .23308 .6685 L .20375 .66945 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .26724 .61245 L p .2424 .6532 L .707 .577 .707 r
F P
0 g
s
.23308 .6685 m .23324 .66474 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.23844 .66445 m .26496 .66115 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .23308 .6685 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .26514 .66302 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .26514 .66302 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26488 .66928 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .23661 .69888 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .2683 .69493 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23327 .6651 L .23844 .66445 L p .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23844 .66445 L .26349 .6631 L .707 .577 .707 r
F
.23545 .66462 m .23324 .66474 L .2424 .6532 L F
.23324 .66474 m .23543 .61167 L p .2424 .6532 L F P
0 g
s
.20747 .7072 m .20658 .69827 L p .23327 .6651 L .707 .577 .707 r
F P
0 g
s
.20658 .69827 m .20412 .67342 L .23285 .66522 L p .707 .577 .707 r
F P
0 g
s
.23285 .66522 m .23327 .6651 L p .20658 .69827 L .707 .577 .707 r
F P
0 g
s
.20412 .67342 m .20747 .7072 L .18371 .71907 L p .707 .577 .707 r
F P
0 g
s
.17894 .77508 m .17987 .75608 L .20384 .7541 L p .707 .577 .707 r
F P
0 g
s
.73198 .64791 m .73434 .59109 L .70318 .58865 L p .707 .577 .707 r
F P
0 g
s
.73434 .59109 m .73198 .64791 L .76379 .64869 L p .707 .577 .707 r
F P
0 g
s
.76379 .64869 m .76614 .59187 L .73434 .59109 L p .707 .577 .707 r
F P
0 g
s
.20384 .7541 m .2029 .77309 L .17894 .77508 L p .707 .577 .707 r
F P
0 g
s
.76614 .59187 m .76379 .64869 L .79312 .64774 L p .707 .577 .707 r
F P
0 g
s
.79312 .64774 m .79547 .59092 L .76614 .59187 L p .707 .577 .707 r
F P
0 g
s
.70082 .64548 m .70318 .58865 L .67571 .5848 L p .707 .577 .707 r
F P
0 g
s
.70318 .58865 m .70082 .64548 L .73198 .64791 L p .707 .577 .707 r
F P
0 g
s
.23327 .6651 m .23661 .69888 L .20747 .7072 L p .707 .577 .707 r
F P
0 g
s
.59127 .25015 m .59448 .74982 L .55572 .7435 L p .707 .577 .707 r
F P
0 g
s
.55572 .7435 m .55251 .24383 L .59127 .25015 L p .707 .577 .707 r
F P
0 g
s
.32356 .76101 m .32263 .78 L .29515 .77626 L p .707 .577 .707 r
F P
0 g
s
.29515 .77626 m .29609 .75726 L .32356 .76101 L p .707 .577 .707 r
F P
0 g
s
.79547 .59092 m .79312 .64774 L .81711 .64515 L p .707 .577 .707 r
F P
0 g
s
.81711 .64515 m .81946 .58832 L .79547 .59092 L p .707 .577 .707 r
F P
0 g
s
.67571 .5848 m .67335 .64162 L .70082 .64548 L p .707 .577 .707 r
F P
0 g
s
.2029 .77309 m .20384 .7541 L .23315 .75363 L p .707 .577 .707 r
F P
0 g
s
.67335 .64162 m .67571 .5848 L .65462 .5799 L p .707 .577 .707 r
F P
0 g
s
.23315 .75363 m .23221 .77262 L .2029 .77309 L p .707 .577 .707 r
F P
0 g
s
.42529 .74764 m .42208 .24797 L .46356 .24269 L p .707 .577 .707 r
F P
0 g
s
.42208 .24797 m .42529 .74764 L .39133 .75625 L p .707 .577 .707 r
F P
0 g
s
.73129 .74911 m .73222 .73012 L .70107 .72757 L p .707 .577 .707 r
F P
0 g
s
.73222 .73012 m .73129 .74911 L .76308 .7502 L p .707 .577 .707 r
F P
0 g
s
.76308 .7502 m .76401 .73121 L .73222 .73012 L p .707 .577 .707 r
F P
0 g
s
.73697 .73665 m .73363 .70287 L .70251 .70206 L p .707 .577 .707 r
F P
0 g
s
.76401 .73121 m .76308 .7502 L .79239 .74973 L p .707 .577 .707 r
F P
0 g
s
.79239 .74973 m .79332 .73073 L .76401 .73121 L p .707 .577 .707 r
F P
0 g
s
.73363 .70287 m .73697 .73665 L .76866 .7327 L p .707 .577 .707 r
F P
0 g
s
.76866 .7327 m .76531 .69892 L .73363 .70287 L p .707 .577 .707 r
F P
0 g
s
.29609 .75726 m .29515 .77626 L .264 .77371 L p .707 .577 .707 r
F P
0 g
s
.264 .77371 m .26493 .75472 L .29609 .75726 L p .707 .577 .707 r
F P
0 g
s
.76531 .69892 m .76866 .7327 L .79781 .72439 L p .707 .577 .707 r
F P
0 g
s
.79781 .72439 m .79446 .6906 L .76531 .69892 L p .707 .577 .707 r
F P
0 g
s
.65462 .5799 m .65227 .63672 L .67335 .64162 L p .707 .577 .707 r
F P
0 g
s
.23221 .77262 m .23315 .75363 L .26493 .75472 L p .707 .577 .707 r
F P
0 g
s
.55251 .24383 m .55572 .7435 L .51171 .74093 L p .707 .577 .707 r
F P
0 g
s
.51171 .74093 m .5085 .24126 L .55251 .24383 L p .707 .577 .707 r
F P
0 g
s
.70107 .72757 m .70013 .74657 L .73129 .74911 L p .707 .577 .707 r
F P
0 g
s
.26493 .75472 m .264 .77371 L .23221 .77262 L p .707 .577 .707 r
F P
0 g
s
.70013 .74657 m .70107 .72757 L .67359 .72382 L p .707 .577 .707 r
F P
0 g
s
.70585 .73584 m .70251 .70206 L .675 .69658 L p .707 .577 .707 r
F P
0 g
s
.70251 .70206 m .70585 .73584 L .73697 .73665 L p .707 .577 .707 r
F P
0 g
s
.81946 .58832 m .81711 .64515 L .83341 .64117 L p .707 .577 .707 r
F P
0 g
s
.83341 .64117 m .83576 .58434 L .81946 .58832 L p .707 .577 .707 r
F P
0 g
s
.79446 .6906 m .79781 .72439 L .82156 .71251 L p .707 .577 .707 r
F P
0 g
s
.82156 .71251 m .81822 .67873 L .79446 .6906 L p .707 .577 .707 r
F P
0 g
s
.46677 .74236 m .46356 .24269 L .5085 .24126 L p .707 .577 .707 r
F P
0 g
s
.46356 .24269 m .46677 .74236 L .42529 .74764 L p .707 .577 .707 r
F P
0 g
s
.67359 .72382 m .67266 .74282 L .70013 .74657 L p .707 .577 .707 r
F P
0 g
s
.5085 .24126 m .51171 .74093 L .46677 .74236 L p .707 .577 .707 r
F P
0 g
s
.65227 .63672 m .65462 .5799 L .64198 .57444 L p .707 .577 .707 r
F P
0 g
s
.79332 .73073 m .79239 .74973 L .81635 .74774 L p .707 .577 .707 r
F P
0 g
s
.81635 .74774 m .81728 .72875 L .79332 .73073 L p .707 .577 .707 r
F P
0 g
s
.67834 .73036 m .675 .69658 L .65379 .68695 L p .707 .577 .707 r
F P
0 g
s
.675 .69658 m .67834 .73036 L .70585 .73584 L p .707 .577 .707 r
F P
0 g
s
.66807 .72262 m .65249 .71924 L p .67306 .73456 L .707 .577 .707 r
F P
0 g
s
.65713 .72073 m .65399 .68894 L p .64097 .67413 L .707 .577 .707 r
F P
0 g
s
.65399 .68894 m .65379 .68695 L .6527 .68586 L p .707 .577 .707 r
F P
0 g
s
.6527 .68586 m .64097 .67413 L p .65399 .68894 L .707 .577 .707 r
F P
0 g
s
.67266 .74282 m .67306 .73456 L p .65249 .71924 L .707 .577 .707 r
F P
0 g
s
.67306 .73456 m .67359 .72382 L .66807 .72262 L p .707 .577 .707 r
F P
0 g
s
.64198 .57444 m .63962 .63126 L .65227 .63672 L p .707 .577 .707 r
F P
0 g
s
.65249 .71924 m .65155 .73823 L .67266 .74282 L p .707 .577 .707 r
F P
0 g
s
.81822 .67873 m .82156 .71251 L .83761 .69824 L p .707 .577 .707 r
F P
0 g
s
.83761 .69824 m .83427 .66446 L .81822 .67873 L p .707 .577 .707 r
F P
0 g
s
.83576 .58434 m .83341 .64117 L .84042 .63619 L p .707 .577 .707 r
F P
0 g
s
.84042 .63619 m .84277 .57937 L .83576 .58434 L p .707 .577 .707 r
F P
0 g
s
.65379 .68695 m .65713 .72073 L .67834 .73036 L p .707 .577 .707 r
F P
0 g
s
.81728 .72875 m .81635 .74774 L .83261 .74444 L p .707 .577 .707 r
F P
0 g
s
.83261 .74444 m .83355 .72544 L .81728 .72875 L p .707 .577 .707 r
F P
0 g
s
.63962 .63126 m .64198 .57444 L .63902 .56895 L p .707 .577 .707 r
F P
0 g
s
.65155 .73823 m .65249 .71924 L .63983 .71426 L p .707 .577 .707 r
F P
0 g
s
.63983 .71426 m .63889 .73326 L .65155 .73823 L p .707 .577 .707 r
F P
0 g
s
.83427 .66446 m .83761 .69824 L .84437 .68298 L p .707 .577 .707 r
F P
0 g
s
.84437 .68298 m .84102 .6492 L .83427 .66446 L p .707 .577 .707 r
F P
0 g
s
.63902 .56895 m .63666 .62578 L .63962 .63126 L p .707 .577 .707 r
F P
0 g
s
.64097 .67413 m .64431 .70791 L .65713 .72073 L p .707 .577 .707 r
F P
0 g
s
.84277 .57937 m .84042 .63619 L .83746 .6307 L p .707 .577 .707 r
F P
0 g
s
.83746 .6307 m .83981 .57388 L .84277 .57937 L p .707 .577 .707 r
F P
0 g
s
.83355 .72544 m .83261 .74444 L .8396 .74014 L p .707 .577 .707 r
F P
0 g
s
.8396 .74014 m .84053 .72114 L .83355 .72544 L p .707 .577 .707 r
F P
0 g
s
.64431 .70791 m .64097 .67413 L .63778 .65936 L p .707 .577 .707 r
F P
0 g
s
.63666 .62578 m .63902 .56895 L .64603 .56398 L p .707 .577 .707 r
F P
0 g
s
.63889 .73326 m .63983 .71426 L .63684 .70938 L p .707 .577 .707 r
F P
0 g
s
.84102 .6492 m .84437 .68298 L .84118 .66821 L p .707 .577 .707 r
F P
0 g
s
.84118 .66821 m .83783 .63443 L .84102 .6492 L p .707 .577 .707 r
F P
0 g
s
.63684 .70938 m .6359 .72838 L .63889 .73326 L p .707 .577 .707 r
F P
0 g
s
.64603 .56398 m .64367 .6208 L .63666 .62578 L p .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .63684 .70938 L .64197 .70622 L p .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .64431 .70791 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.64197 .70622 m .64382 .70508 L p .64227 .70964 L .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .64197 .70622 L .64227 .70964 L .707 .577 .707 r
F
.63778 .65936 m .6388 .66969 L p .63813 .66196 L F P
0 g
s
.6388 .66969 m .64112 .69314 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83746 .6307 m .82482 .62525 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .83981 .57388 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .82498 .62131 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82717 .56842 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .80373 .62035 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .8038 .61198 L .82222 .62034 L p .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .82498 .62131 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82482 .62525 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .82717 .56842 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .80399 .61392 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80608 .56352 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .77964 .64028 L p .79298 .62465 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .77626 .61649 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.8038 .61198 m .80399 .61392 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80373 .62035 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .8038 .61198 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .77656 .6092 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .77656 .6092 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77629 .6065 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .80608 .56352 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77861 .55967 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .80399 .61392 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.79298 .62465 m .80238 .61364 L .80399 .61392 L .707 .577 .707 r
F
.80399 .61392 m .80714 .64577 L p .79298 .62465 L F P
0 g
s
.80714 .64577 m .80399 .61392 L p .82485 .62153 L .707 .577 .707 r
F P
0 g
s
.82222 .62034 m .82485 .62153 L p .80399 .61392 L .707 .577 .707 r
F P
0 g
s
.82485 .62153 m .82501 .62161 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .82485 .62153 L .82387 .62315 L .707 .577 .707 r
F
.82501 .62161 m .82835 .65539 L .80952 .64685 L p F P
0 g
s
.80952 .64685 m .80714 .64577 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.82387 .62315 m .82501 .62161 L .80952 .64685 L .707 .577 .707 r
F
.83981 .57388 m .83879 .59849 L p .82688 .61817 L F P
0 g
s
.83879 .59849 m .83746 .6307 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .63778 .65936 L .64453 .6441 L p .707 .577 .707 r
F P
0 g
s
.84053 .72114 m .8396 .74014 L .83661 .73526 L p .707 .577 .707 r
F P
0 g
s
.83661 .73526 m .83755 .71626 L .84053 .72114 L p .707 .577 .707 r
F P
0 g
s
.38897 .6111 m .39133 .55427 L .36017 .55184 L p .707 .577 .707 r
F P
0 g
s
.39133 .55427 m .38897 .6111 L .42078 .61188 L p .707 .577 .707 r
F P
0 g
s
.42078 .61188 m .42313 .55505 L .39133 .55427 L p .707 .577 .707 r
F P
0 g
s
.42313 .55505 m .42078 .61188 L .45011 .61092 L p .707 .577 .707 r
F P
0 g
s
.45011 .61092 m .45246 .5541 L .42313 .55505 L p .707 .577 .707 r
F P
0 g
s
.64367 .6208 m .64603 .56398 L .66233 .56 L p .707 .577 .707 r
F P
0 g
s
.83783 .63443 m .84118 .66821 L .82835 .65539 L p .707 .577 .707 r
F P
0 g
s
.82835 .65539 m .82501 .62161 L .83783 .63443 L p .707 .577 .707 r
F P
0 g
s
.35781 .60866 m .36017 .55184 L .3327 .54798 L p .707 .577 .707 r
F P
0 g
s
.36017 .55184 m .35781 .60866 L .38897 .6111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64382 .70508 m .64288 .72407 L .6359 .72838 L p .707 .577 .707 r
F P
0 g
s
.64453 .6441 m .64788 .67788 L .64112 .69314 L p .707 .577 .707 r
F P
0 g
s
.66233 .56 m .65997 .61682 L .64367 .6208 L p .707 .577 .707 r
F P
0 g
s
.45246 .5541 m .45011 .61092 L .4741 .60833 L p .707 .577 .707 r
F P
0 g
s
.4741 .60833 m .47645 .55151 L .45246 .5541 L p .707 .577 .707 r
F P
0 g
s
.3327 .54798 m .33034 .6048 L .35781 .60866 L p .707 .577 .707 r
F P
0 g
s
.33034 .6048 m .3327 .54798 L .31161 .54308 L p .707 .577 .707 r
F P
0 g
s
.64788 .67788 m .64453 .6441 L .66058 .62983 L p .707 .577 .707 r
F P
0 g
s
.83755 .71626 m .83661 .73526 L .82394 .73028 L p .707 .577 .707 r
F P
0 g
s
.82394 .73028 m .82488 .71128 L .83755 .71626 L p .707 .577 .707 r
F P
0 g
s
.38828 .7123 m .38921 .6933 L .35806 .69076 L p .707 .577 .707 r
F P
0 g
s
.38921 .6933 m .38828 .7123 L .42007 .71339 L p .707 .577 .707 r
F P
0 g
s
.42007 .71339 m .421 .69439 L .38921 .6933 L p .707 .577 .707 r
F P
0 g
s
.39396 .69984 m .39062 .66605 L .3595 .66525 L p .707 .577 .707 r
F P
0 g
s
.421 .69439 m .42007 .71339 L .44938 .71292 L p .707 .577 .707 r
F P
0 g
s
.44938 .71292 m .45031 .69392 L .421 .69439 L p .707 .577 .707 r
F P
0 g
s
.39062 .66605 m .39396 .69984 L .42565 .69589 L p .707 .577 .707 r
F P
0 g
s
.42565 .69589 m .4223 .6621 L .39062 .66605 L p .707 .577 .707 r
F P
0 g
s
.4223 .6621 m .42565 .69589 L .4548 .68757 L p .707 .577 .707 r
F P
0 g
s
.4548 .68757 m .45145 .65379 L .4223 .6621 L p .707 .577 .707 r
F P
0 g
s
.65997 .61682 m .66233 .56 L .68632 .5574 L p .707 .577 .707 r
F P
0 g
s
.31161 .54308 m .30926 .59991 L .33034 .6048 L p .707 .577 .707 r
F P
0 g
s
.35806 .69076 m .35712 .70975 L .38828 .7123 L p .707 .577 .707 r
F P
0 g
s
.35712 .70975 m .35806 .69076 L .33058 .68701 L p .707 .577 .707 r
F P
0 g
s
.36284 .69903 m .3595 .66525 L .33199 .65976 L p .707 .577 .707 r
F P
0 g
s
.3595 .66525 m .36284 .69903 L .39396 .69984 L p .707 .577 .707 r
F P
0 g
s
.47645 .55151 m .4741 .60833 L .4904 .60435 L p .707 .577 .707 r
F P
0 g
s
.4904 .60435 m .49275 .54753 L .47645 .55151 L p .707 .577 .707 r
F P
0 g
s
.64288 .72407 m .64382 .70508 L .66009 .70177 L p .707 .577 .707 r
F P
0 g
s
.45145 .65379 m .4548 .68757 L .47855 .6757 L p .707 .577 .707 r
F P
0 g
s
.47855 .6757 m .47521 .64191 L .45145 .65379 L p .707 .577 .707 r
F P
0 g
s
.66009 .70177 m .65915 .72077 L .64288 .72407 L p .707 .577 .707 r
F P
0 g
s
.66058 .62983 m .66392 .66361 L .64788 .67788 L p .707 .577 .707 r
F P
0 g
s
.68632 .5574 m .68396 .61423 L .65997 .61682 L p .707 .577 .707 r
F P
0 g
s
.33058 .68701 m .32965 .706 L .35712 .70975 L p .707 .577 .707 r
F P
0 g
s
.30926 .59991 m .31161 .54308 L .29897 .53762 L p .707 .577 .707 r
F P
0 g
s
.66392 .66361 m .66058 .62983 L .68434 .61796 L p .707 .577 .707 r
F P
0 g
s
.45031 .69392 m .44938 .71292 L .47334 .71093 L p .707 .577 .707 r
F P
0 g
s
.47334 .71093 m .47427 .69193 L .45031 .69392 L p .707 .577 .707 r
F P
0 g
s
.33533 .69354 m .33199 .65976 L .31078 .65014 L p .707 .577 .707 r
F P
0 g
s
.33199 .65976 m .33533 .69354 L .36284 .69903 L p .707 .577 .707 r
F P
0 g
s
.68396 .61423 m .68632 .5574 L .71565 .55645 L p .707 .577 .707 r
F P
0 g
s
.32506 .68581 m .30948 .68242 L p .33005 .69774 L .707 .577 .707 r
F P
0 g
s
.31412 .68392 m .31098 .65212 L p .29796 .63731 L .707 .577 .707 r
F P
0 g
s
.31098 .65212 m .31078 .65014 L .30969 .64905 L p .707 .577 .707 r
F P
0 g
s
.30969 .64905 m .29796 .63731 L p .31098 .65212 L .707 .577 .707 r
F P
0 g
s
.32965 .706 m .33005 .69774 L p .30948 .68242 L .707 .577 .707 r
F P
0 g
s
.33005 .69774 m .33058 .68701 L .32506 .68581 L p .707 .577 .707 r
F P
0 g
s
.29897 .53762 m .29661 .59445 L .30926 .59991 L p .707 .577 .707 r
F P
0 g
s
.82488 .71128 m .82394 .73028 L .80284 .72569 L p .707 .577 .707 r
F P
0 g
s
.80284 .72569 m .80378 .7067 L .82488 .71128 L p .707 .577 .707 r
F P
0 g
s
.30948 .68242 m .30854 .70142 L .32965 .706 L p .707 .577 .707 r
F P
0 g
s
.47521 .64191 m .47855 .6757 L .4946 .66143 L p .707 .577 .707 r
F P
0 g
s
.4946 .66143 m .49126 .62765 L .47521 .64191 L p .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .7451 .61406 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77626 .61649 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .74851 .63947 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .77656 .6092 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77964 .64028 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .77629 .6065 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .74536 .60762 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .74536 .60762 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74517 .60569 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .77861 .55967 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74745 .55723 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .77656 .6092 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .71329 .61328 L .68396 .61423 L p .707 .577 .707 r
F P
0 g
s
.49275 .54753 m .4904 .60435 L .49741 .59937 L p .707 .577 .707 r
F P
0 g
s
.49741 .59937 m .49976 .54255 L .49275 .54753 L p .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .74745 .55723 L p .72303 .59729 L .707 .577 .707 r
F P
0 g
s
.71329 .61328 m .71346 .60934 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.71765 .60912 m .74517 .60569 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .71329 .61328 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .74536 .60762 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .74536 .60762 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .7451 .61406 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .71683 .64342 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74851 .63947 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71349 .60964 L .71765 .60912 L p .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71765 .60912 L .74365 .60772 L .707 .577 .707 r
F
.71576 .60922 m .71346 .60934 L .72303 .59729 L F
.71346 .60934 m .71565 .55645 L p .72303 .59729 L F P
0 g
s
.68768 .65174 m .6868 .64288 L p .71349 .60964 L .707 .577 .707 r
F P
0 g
s
.6868 .64288 m .68434 .61796 L .71315 .60973 L p .707 .577 .707 r
F P
0 g
s
.71315 .60973 m .71349 .60964 L p .6868 .64288 L .707 .577 .707 r
F P
0 g
s
.68434 .61796 m .68768 .65174 L .66392 .66361 L p .707 .577 .707 r
F P
0 g
s
.65915 .72077 m .66009 .70177 L .68405 .69979 L p .707 .577 .707 r
F P
0 g
s
.68405 .69979 m .68311 .71878 L .65915 .72077 L p .707 .577 .707 r
F P
0 g
s
.31078 .65014 m .31412 .68392 L .33533 .69354 L p .707 .577 .707 r
F P
0 g
s
.47427 .69193 m .47334 .71093 L .4896 .70762 L p .707 .577 .707 r
F P
0 g
s
.4896 .70762 m .49054 .68863 L .47427 .69193 L p .707 .577 .707 r
F P
0 g
s
.29661 .59445 m .29897 .53762 L .29601 .53214 L p .707 .577 .707 r
F P
0 g
s
.71349 .60964 m .71683 .64342 L .68768 .65174 L p .707 .577 .707 r
F P
0 g
s
.30854 .70142 m .30948 .68242 L .29682 .67744 L p .707 .577 .707 r
F P
0 g
s
.80378 .7067 m .80284 .72569 L .77537 .72194 L p .707 .577 .707 r
F P
0 g
s
.77537 .72194 m .7763 .70295 L .80378 .7067 L p .707 .577 .707 r
F P
0 g
s
.29682 .67744 m .29588 .69644 L .30854 .70142 L p .707 .577 .707 r
F P
0 g
s
.49126 .62765 m .4946 .66143 L .50136 .64617 L p .707 .577 .707 r
F P
0 g
s
.50136 .64617 m .49801 .61238 L .49126 .62765 L p .707 .577 .707 r
F P
0 g
s
.29601 .53214 m .29365 .58896 L .29661 .59445 L p .707 .577 .707 r
F P
0 g
s
.68311 .71878 m .68405 .69979 L .71336 .69931 L p .707 .577 .707 r
F P
0 g
s
.71336 .69931 m .71242 .71831 L .68311 .71878 L p .707 .577 .707 r
F P
0 g
s
.29796 .63731 m .3013 .6711 L .31412 .68392 L p .707 .577 .707 r
F P
0 g
s
.49976 .54255 m .49741 .59937 L .49445 .59389 L p .707 .577 .707 r
F P
0 g
s
.49445 .59389 m .4968 .53706 L .49976 .54255 L p .707 .577 .707 r
F P
0 g
s
.7763 .70295 m .77537 .72194 L .74421 .7194 L p .707 .577 .707 r
F P
0 g
s
.74421 .7194 m .74515 .7004 L .7763 .70295 L p .707 .577 .707 r
F P
0 g
s
.49054 .68863 m .4896 .70762 L .49659 .70332 L p .707 .577 .707 r
F P
0 g
s
.49659 .70332 m .49752 .68432 L .49054 .68863 L p .707 .577 .707 r
F P
0 g
s
.71242 .71831 m .71336 .69931 L .74515 .7004 L p .707 .577 .707 r
F P
0 g
s
.3013 .6711 m .29796 .63731 L .29477 .62255 L p .707 .577 .707 r
F P
0 g
s
.74515 .7004 m .74421 .7194 L .71242 .71831 L p .707 .577 .707 r
F P
0 g
s
.29365 .58896 m .29601 .53214 L .30302 .52716 L p .707 .577 .707 r
F P
0 g
s
.29588 .69644 m .29682 .67744 L .29383 .67257 L p .707 .577 .707 r
F P
0 g
s
.49801 .61238 m .50136 .64617 L .49817 .6314 L p .707 .577 .707 r
F P
0 g
s
.49817 .6314 m .49482 .59762 L .49801 .61238 L p .707 .577 .707 r
F P
0 g
s
.29383 .67257 m .29289 .69156 L .29588 .69644 L p .707 .577 .707 r
F P
0 g
s
.30302 .52716 m .30066 .58399 L .29365 .58896 L p .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29383 .67257 L .29896 .6694 L p .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .3013 .6711 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.29896 .6694 m .30081 .66826 L p .29926 .67282 L .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29896 .6694 L .29926 .67282 L .707 .577 .707 r
F
.29477 .62255 m .29579 .63288 L p .29512 .62515 L F P
0 g
s
.29579 .63288 m .29811 .65633 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49445 .59389 m .4818 .58843 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .4968 .53706 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .48197 .5845 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .48416 .5316 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .46072 .58353 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46079 .57517 L .47921 .58353 L p .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .48197 .5845 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .4818 .58843 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .48416 .5316 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .46098 .5771 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46307 .52671 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .43662 .60346 L p .44997 .58784 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .43325 .57968 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46079 .57517 m .46098 .5771 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46072 .58353 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .46079 .57517 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .43355 .57239 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .43355 .57239 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43328 .56968 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .46307 .52671 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .4356 .52285 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .46098 .5771 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.44997 .58784 m .45937 .57683 L .46098 .5771 L .707 .577 .707 r
F
.46098 .5771 m .46413 .60895 L p .44997 .58784 L F P
0 g
s
.46413 .60895 m .46098 .5771 L p .48183 .58472 L .707 .577 .707 r
F P
0 g
s
.47921 .58353 m .48183 .58472 L p .46098 .5771 L .707 .577 .707 r
F P
0 g
s
.48183 .58472 m .482 .58479 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .48183 .58472 L .48086 .58633 L .707 .577 .707 r
F
.482 .58479 m .48534 .61858 L .46651 .61003 L p F P
0 g
s
.46651 .61003 m .46413 .60895 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.48086 .58633 m .482 .58479 L .46651 .61003 L .707 .577 .707 r
F
.4968 .53706 m .49578 .56168 L p .48387 .58136 L F P
0 g
s
.49578 .56168 m .49445 .59389 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .29477 .62255 L .30152 .60728 L p .707 .577 .707 r
F P
0 g
s
.49752 .68432 m .49659 .70332 L .4936 .69844 L p .707 .577 .707 r
F P
0 g
s
.4936 .69844 m .49454 .67945 L .49752 .68432 L p .707 .577 .707 r
F P
0 g
s
.30066 .58399 m .30302 .52716 L .31932 .52318 L p .707 .577 .707 r
F P
0 g
s
.49482 .59762 m .49817 .6314 L .48534 .61858 L p .707 .577 .707 r
F P
0 g
s
.48534 .61858 m .482 .58479 L .49482 .59762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30081 .66826 m .29987 .68726 L .29289 .69156 L p .707 .577 .707 r
F P
0 g
s
.30152 .60728 m .30487 .64106 L .29811 .65633 L p .707 .577 .707 r
F P
0 g
s
.31932 .52318 m .31696 .58001 L .30066 .58399 L p .707 .577 .707 r
F P
0 g
s
.30487 .64106 m .30152 .60728 L .31757 .59301 L p .707 .577 .707 r
F P
0 g
s
.49454 .67945 m .4936 .69844 L .48093 .69347 L p .707 .577 .707 r
F P
0 g
s
.48093 .69347 m .48187 .67447 L .49454 .67945 L p .707 .577 .707 r
F P
0 g
s
.31696 .58001 m .31932 .52318 L .3433 .52059 L p .707 .577 .707 r
F P
0 g
s
.29987 .68726 m .30081 .66826 L .31708 .66496 L p .707 .577 .707 r
F P
0 g
s
.31708 .66496 m .31614 .68395 L .29987 .68726 L p .707 .577 .707 r
F P
0 g
s
.31757 .59301 m .32091 .6268 L .30487 .64106 L p .707 .577 .707 r
F P
0 g
s
.3433 .52059 m .34095 .57741 L .31696 .58001 L p .707 .577 .707 r
F P
0 g
s
.32091 .6268 m .31757 .59301 L .34133 .58114 L p .707 .577 .707 r
F P
0 g
s
.34095 .57741 m .3433 .52059 L .37264 .51963 L p .707 .577 .707 r
F P
0 g
s
.48187 .67447 m .48093 .69347 L .45983 .68888 L p .707 .577 .707 r
F P
0 g
s
.45983 .68888 m .46077 .66988 L .48187 .67447 L p .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .40209 .57724 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43325 .57968 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .4055 .60266 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .43355 .57239 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43662 .60346 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .43328 .56968 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .40235 .57081 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .40235 .57081 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40216 .56887 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .4356 .52285 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40444 .52041 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .43355 .57239 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .37028 .57646 L .34095 .57741 L p .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .40444 .52041 L p .38002 .56048 L .707 .577 .707 r
F P
0 g
s
.37028 .57646 m .37045 .57253 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.37464 .5723 m .40216 .56887 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .37028 .57646 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .40235 .57081 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .40235 .57081 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40209 .57724 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .37382 .60661 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .4055 .60266 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37047 .57282 L .37464 .5723 L p .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37464 .5723 L .40064 .5709 L .707 .577 .707 r
F
.37275 .5724 m .37045 .57253 L .38002 .56048 L F
.37045 .57253 m .37264 .51963 L p .38002 .56048 L F P
0 g
s
.34467 .61492 m .34379 .60607 L p .37047 .57282 L .707 .577 .707 r
F P
0 g
s
.34379 .60607 m .34133 .58114 L .37014 .57292 L p .707 .577 .707 r
F P
0 g
s
.37014 .57292 m .37047 .57282 L p .34379 .60607 L .707 .577 .707 r
F P
0 g
s
.34133 .58114 m .34467 .61492 L .32091 .6268 L p .707 .577 .707 r
F P
0 g
s
.31614 .68395 m .31708 .66496 L .34104 .66297 L p .707 .577 .707 r
F P
0 g
s
.34104 .66297 m .3401 .68197 L .31614 .68395 L p .707 .577 .707 r
F P
0 g
s
.37047 .57282 m .37382 .60661 L .34467 .61492 L p .707 .577 .707 r
F P
0 g
s
.46077 .66988 m .45983 .68888 L .43236 .68513 L p .707 .577 .707 r
F P
0 g
s
.43236 .68513 m .43329 .66613 L .46077 .66988 L p .707 .577 .707 r
F P
0 g
s
.3401 .68197 m .34104 .66297 L .37035 .6625 L p .707 .577 .707 r
F P
0 g
s
.37035 .6625 m .36941 .6815 L .3401 .68197 L p .707 .577 .707 r
F P
0 g
s
.43329 .66613 m .43236 .68513 L .4012 .68258 L p .707 .577 .707 r
F P
0 g
s
.4012 .68258 m .40214 .66359 L .43329 .66613 L p .707 .577 .707 r
F P
0 g
s
.36941 .6815 m .37035 .6625 L .40214 .66359 L p .707 .577 .707 r
F P
0 g
s
.40214 .66359 m .4012 .68258 L .36941 .6815 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Yoo`d008Io
o`00OWoo30001UYF00<005YFFUH015YF2@00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol007=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@007=oo`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001]Ool30007FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006]oo`80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8006]oo`00JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uoo`00Igoo
0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00<005YF00001`0000=JEP00FUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00FGoo3@000eYF00<005YFFUH00UYF4@001EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000QooaT004Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000eOol005=oo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP05Ool005YFFUH0000^Ool005=oo`03001JEP0000=J
EPd000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol01000FUH005YF0P0015YF00<005YF
FUH00`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00L005YFFUIJEWooFUH00002FUH2000]Ool005=oo`03001JEP00008000EJEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF00EooeYFFUIJEP0000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P000UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP0000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P00;Goo001COol20002FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001DOol200000eYF
001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`<00003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06
001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EWoo00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000EJEP03001JEUYF00=JEP04001JEUYF0004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000QJEP03001JEUYF00AJEP@00003FUH005YF00AJEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00?goo20003Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH03`0015YF
00<005YFFUH00UYF2P000eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000cOol<0003FUH0
0`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH300001Goo001JEUYF00001UYF00@005YFFUIJEPT0
00QJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`000UYF0`001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
1EYF00<005YFFUH00`0017oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH010001EYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0;7oo000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30003FUH300001Goo001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF0P000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P000UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P001EYF00@005YF0000009JEP03001J
EUYF00AJEP<000IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF008000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEP00FUH0
000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYF0003FUH00`00FUH00005FUH01000FUIJEP000UYF00<005YFFUH00eYF
1@001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0000=JEP0000000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH00`00FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50005
FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF00@005YF0000009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002eo
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP05001JEUYFFUIoo`04FUH00`00FUIJ
EP06FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF0`001UYF
00<005YFFUH02EYF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70008
FUH80004FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF0P0000=JEP00FUH00UYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EPH000AJEP03001JEUYF008002eoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000UYF00D005YFFUIJEP0000EJEP04001JEUYF0002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH00`00FUH000020004OolI0002Ool20002FUH00`00FUIJEP02000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0`0097oo0`000UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP020005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF0P00:Goo00D0
05YFFUIJEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF0`000UYF00@005YFFUH0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00D005YF000005YF00@002Moo`04001JEUYF000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP8000MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEQ`000IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000EJEP<002Ioo`03001JEP0002eoo`00;7oo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF0P0025YF00<005YFFUH01UYF0P000UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH01@00FUIJEP00FUH00P001EYF00@005YFFUH000Uoo`<001Qoo`@002eoo`00;7oo00<005YF0000
15YF00@005YFFUIJEPX00003FUH005YF00MJEP03001JEUYF00IJEP@0009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
00000UYF0P001EYF00<005YFFUH00P001goo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YF
00000UYF1P000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP8000=JEP8000AJEP80009JEP8000Moo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00FUH0
00020005FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF0P0015YF0P000UYF0P001goo1@0057oo00L005YFFUIJEP00FUH0
000]Ool002aoo`80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0P000UYF0P0027oo0`004goo
0P0015YF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH@0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0P000UYF0P0077oo0P0000=J
EP00FUH015YF0P00;Goo000]Ool200000eYF001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH000020002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5
0005FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00@005YF
FUIJEP8001Yoo`8000=JEP03001JEUYF00=JEP8002eoo`00;goo0`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH015YF1@001EYF00<005YFFUH010001EYF0`0000=JEP00FUH00UYF0P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`0000=J
EP00FUH015YF00@005YFFUIJEP8001Moo`<000EJEP03001JEUYF00=JEP03001oogoo02aoo`00;goo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPd0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00EJEP<000AJEPh0009JEP@0009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH20005FUH01000FUIJEUYF0P00
4goo100000=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH60008FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YF
FUH00eYF200015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP@0
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEPH000=JEPP000Ioo`L000EJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo02ao
o`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF3@0015YF00<005YFFUH00UYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`001EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00000030000eYF00<005YFFUH00UYF4@0000=JEP00FUH01UYF00D005YFFUIJ
EP0002moo`00;Goo0P001EYF00<005YFFUH00eYF00<005YF00000P003Goo2@001Goo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000=JEP04001JEP00000`Ool002eoo`8000EJEP03001JEUYF00=JEP8002Aoo`X000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004000bOol002aoo`03
001JEP0000EJEP04001JEUYFFUH2000XOol01000FUIJEP000UYF00<005YF00007P0025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
035oo`00;7oo00<005YF00001EYF00@005YF000002]oo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`04
001JEUYF0004FUH2000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04001J
EUYF0003FUH00`00Oomoo`0BOol3000HOol30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH0100000=JEP0000000UYF0P001eYF00<005YFFUH01EYF1@000eYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00D005YFFUH005YF008001Aoo`D001Ioo`04001JEP00
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF20000eYF00<005YFFUH00P00;Woo
000/Ool00`00FUIJEP02000FOol5000EOol00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH30006FUH00`00
FUH0000>0002FUH2000^Ool002eoo`03001JEP0001Moo`D001Aoo`04001JEUYFFUH20002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool4000GOol3000COol30003FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH50004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000]Ool20002FUH00`00Oomoo`0XOol20002FUH00`00FUIJEP02FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`04001JEUYFFUH2
000WOol20004FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH015YF
300000=JEP00FUH02EYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo1@0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00;goo
000]Ool01P00FUIJEUYF001JEP<0029oo`8000IJEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000;Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Woo
000]Ool20002FUH00`00FUIJEP02FUH3000KOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YF000010001UYF00<005YFFUH00UYF0P003Goo00@005YFFUH0009ooaX003Qoo`00;Goo
0P000UYF8`001EYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP00
00<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP8000ioo`03001JEP0005Aoo`00;Woo0`000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH00P000UYF
00<005YFFUH00eYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF100015YF0P003Woo0`00E7oo000]Ool20004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF001o
o`00009JEP04001JEUYFFUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF0P003Goo0P0000=JEP000000Dgoo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP050002Ool01@00FUIJEP00FUH00`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000002goo0P0000=JEP00FUH00P00Dgoo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH3000017oo001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10002Woo00H005YF
FUIJEP00FUH2001COol002aoo`03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01000FUH0000027oo0P0015YF00@005YFFUH005=oo`00;7oo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH01EYF400015YF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000006Ool200000eYF001JEP04FUH00`00
FUH0001COol002aoo`03001JEP000080009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP0017oo0P000eYF00<005YFFUH00eYF0P00E7oo000/Ool20002FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP02FUH20004Ool300000eYF
001JEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00Ool00`001EYF00<0
05YFFUH00eYF0P00E7oo000]Ool01000FUIJEP001EYF10001UYF00<005YFFUH01EYF0`001eYF00<0
05YF000020000UYF10000UYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0Dgoo000^Ool30005FUH01000FUIJEUYF1000
0UYF00<005YFFUH01EYF00<005YFFUH00eYF1P001EYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo05=oo`00<7oo0`000eYF00<005YFFUH01EYF40000UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@0000=JEP00FUH0
1UYF00D005YFFUIJEP0005Ioo`00<goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000eYF1P000eYF00@005YF000005Moo`00>Woo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0017oo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP800003FUH005YF00IJEP03001JEP0000@005Uoo`00@goo7`002Goo0`001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF009JEP<005Qoo`00KWoo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P00EGoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000EGoo001cOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH50002FUH50003FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001gOol60002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001eYF1@001EYF00<005YFFUH00eYF
1`000eYF00<005YFFUH00P00EGoo001mOolO0005FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP0?
00000eYF0000001EOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF
00IJEP<0009JEPL000AJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol0091oo`@000AJEP03001J
EUYF00AJEQ0000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol009Aoo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000EGoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03001FOol009aooa4000AJEP03001JEUYF00IJEP04
001JEUYFFUH6001IOol00:eooa4005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59417 .73379 m .59797 .67654 L .56682 .67377 L p .707 .577 .707 r
F P
0 g
s
.59797 .67654 m .59417 .73379 L .62592 .73554 L p .707 .577 .707 r
F P
0 g
s
.62592 .73554 m .62972 .67829 L .59797 .67654 L p .707 .577 .707 r
F P
0 g
s
.62972 .67829 m .62592 .73554 L .65517 .73611 L p .707 .577 .707 r
F P
0 g
s
.65517 .73611 m .65897 .67886 L .62972 .67829 L p .707 .577 .707 r
F P
0 g
s
.56682 .67377 m .56303 .73101 L .59417 .73379 L p .707 .577 .707 r
F P
0 g
s
.56303 .73101 m .56682 .67377 L .53934 .67025 L p .707 .577 .707 r
F P
0 g
s
.53934 .67025 m .53554 .7275 L .56303 .73101 L p .707 .577 .707 r
F P
0 g
s
.65897 .67886 m .65517 .73611 L .67906 .73543 L p .707 .577 .707 r
F P
0 g
s
.67906 .73543 m .68285 .67818 L .65897 .67886 L p .707 .577 .707 r
F P
0 g
s
.53554 .7275 m .53934 .67025 L .5182 .66633 L p .707 .577 .707 r
F P
0 g
s
.5182 .66633 m .5144 .72357 L .53554 .7275 L p .707 .577 .707 r
F P
0 g
s
.59313 .83296 m .59464 .81384 L .56351 .81089 L p .707 .577 .707 r
F P
0 g
s
.59464 .81384 m .59313 .83296 L .62485 .83522 L p .707 .577 .707 r
F P
0 g
s
.62485 .83522 m .62636 .8161 L .59464 .81384 L p .707 .577 .707 r
F P
0 g
s
.56351 .81089 m .562 .83001 L .59313 .83296 L p .707 .577 .707 r
F P
0 g
s
.62636 .8161 m .62485 .83522 L .65404 .83657 L p .707 .577 .707 r
F P
0 g
s
.65404 .83657 m .65555 .81745 L .62636 .8161 L p .707 .577 .707 r
F P
0 g
s
.60296 .83904 m .59763 .80824 L .56659 .80804 L p .707 .577 .707 r
F P
0 g
s
.59763 .80824 m .60296 .83904 L .6344 .83331 L p .707 .577 .707 r
F P
0 g
s
.6344 .83331 m .62907 .80251 L .59763 .80824 L p .707 .577 .707 r
F P
0 g
s
.65555 .81745 m .65404 .83657 L .67785 .83689 L p .707 .577 .707 r
F P
0 g
s
.67785 .83689 m .67936 .81777 L .65555 .81745 L p .707 .577 .707 r
F P
0 g
s
.62907 .80251 m .6344 .83331 L .66318 .82222 L p .707 .577 .707 r
F P
0 g
s
.66318 .82222 m .65785 .79141 L .62907 .80251 L p .707 .577 .707 r
F P
0 g
s
.562 .83001 m .56351 .81089 L .53601 .80755 L p .707 .577 .707 r
F P
0 g
s
.68285 .67818 m .67906 .73543 L .69524 .73358 L p .707 .577 .707 r
F P
0 g
s
.69524 .73358 m .69904 .67633 L .68285 .67818 L p .707 .577 .707 r
F P
0 g
s
.53601 .80755 m .5345 .82667 L .562 .83001 L p .707 .577 .707 r
F P
0 g
s
.57192 .83885 m .56659 .80804 L .539 .80195 L p .707 .577 .707 r
F P
0 g
s
.56659 .80804 m .57192 .83885 L .60296 .83904 L p .707 .577 .707 r
F P
0 g
s
.65785 .79141 m .66318 .82222 L .68647 .80685 L p .707 .577 .707 r
F P
0 g
s
.68647 .80685 m .68114 .77604 L .65785 .79141 L p .707 .577 .707 r
F P
0 g
s
.5144 .72357 m .5182 .66633 L .50547 .66239 L p .707 .577 .707 r
F P
0 g
s
.5345 .82667 m .53601 .80755 L .51484 .80413 L p .707 .577 .707 r
F P
0 g
s
.50547 .66239 m .50168 .71964 L .5144 .72357 L p .707 .577 .707 r
F P
0 g
s
.51484 .80413 m .51332 .82325 L .5345 .82667 L p .707 .577 .707 r
F P
0 g
s
.54433 .83275 m .539 .80195 L .51755 .79054 L p .707 .577 .707 r
F P
0 g
s
.539 .80195 m .54433 .83275 L .57192 .83885 L p .707 .577 .707 r
F P
0 g
s
.68114 .77604 m .68647 .80685 L .70199 .78871 L p .707 .577 .707 r
F P
0 g
s
.70199 .78871 m .69666 .7579 L .68114 .77604 L p .707 .577 .707 r
F P
0 g
s
.69904 .67633 m .69524 .73358 L .70214 .73072 L p .707 .577 .707 r
F P
0 g
s
.70214 .73072 m .70593 .67347 L .69904 .67633 L p .707 .577 .707 r
F P
0 g
s
.67936 .81777 m .67785 .83689 L .69396 .83613 L p .707 .577 .707 r
F P
0 g
s
.69396 .83613 m .69547 .81701 L .67936 .81777 L p .707 .577 .707 r
F P
0 g
s
.50168 .71964 m .50547 .66239 L .50241 .65882 L p .707 .577 .707 r
F P
0 g
s
.51332 .82325 m .51484 .80413 L .50205 .80098 L p .707 .577 .707 r
F P
0 g
s
.50205 .80098 m .50054 .8201 L .51332 .82325 L p .707 .577 .707 r
F P
0 g
s
.52288 .82134 m .51755 .79054 L .50436 .77494 L p .707 .577 .707 r
F P
0 g
s
.51755 .79054 m .52288 .82134 L .54433 .83275 L p .707 .577 .707 r
F P
0 g
s
.50241 .65882 m .49861 .71607 L .50168 .71964 L p .707 .577 .707 r
F P
0 g
s
.69666 .7579 m .70199 .78871 L .70823 .76957 L p .707 .577 .707 r
F P
0 g
s
.70823 .76957 m .7029 .73876 L .69666 .7579 L p .707 .577 .707 r
F P
0 g
s
.69547 .81701 m .69396 .83613 L .70077 .83437 L p .707 .577 .707 r
F P
0 g
s
.70077 .83437 m .70228 .81525 L .69547 .81701 L p .707 .577 .707 r
F P
0 g
s
.70115 .72957 m .69907 .72715 L p .69965 .72263 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69924 .72049 L .69988 .72369 L p .708 .578 .707 r
F P
0 g
s
.70287 .6699 m .70593 .67347 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .69944 .72164 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .70287 .6699 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .68635 .72322 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69924 .72049 m .69944 .72164 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69907 .72715 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69924 .72049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68635 .72322 m .68714 .71125 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .68714 .71125 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .68604 .7049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .70287 .6699 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .69014 .66597 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.70287 .6699 m .69944 .72164 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .69889 .72118 L .69944 .72164 L .707 .577 .707 r
F
.69944 .72164 m .70457 .7513 L .69427 .73913 L p F P
0 g
s
.69427 .73913 m .69137 .7357 L p .69944 .72164 L .707 .577 .707 r
F P
0 g
s
.70457 .7513 m .69944 .72164 L p .7029 .73876 L .708 .578 .707 r
F P
0 g
s
.69988 .72369 m .7029 .73876 L p .69944 .72164 L .708 .578 .707 r
F P
0 g
s
.70593 .67347 m .70214 .73072 L .70115 .72957 L p .707 .577 .707 r
F P
0 g
s
.69965 .72263 m .70593 .67347 L .70115 .72957 L .707 .577 .707 r
F
.49394 .82294 m .48875 .32471 L .44474 .32221 L p F P
0 g
s
.50436 .77494 m .50968 .80575 L .52288 .82134 L p .707 .577 .707 r
F P
0 g
s
.50968 .80575 m .50436 .77494 L .5007 .75668 L p .708 .578 .707 r
F P
0 g
s
.50054 .8201 m .50205 .80098 L .49892 .7984 L p .707 .577 .707 r
F P
0 g
s
.49892 .7984 m .49741 .81752 L .50054 .8201 L p .707 .577 .707 r
F P
0 g
s
.49861 .71607 m .50241 .65882 L .5093 .65596 L p .707 .577 .707 r
F P
0 g
s
.5093 .65596 m .50551 .71321 L .49861 .71607 L p .707 .577 .707 r
F P
0 g
s
.5007 .75668 m .50602 .78748 L .50968 .80575 L p .708 .578 .707 r
F P
0 g
s
.50602 .78748 m .5007 .75668 L .50693 .73753 L p .707 .577 .707 r
F P
0 g
s
.49741 .81752 m .49892 .7984 L .50574 .79664 L p .707 .577 .707 r
F P
0 g
s
.50551 .71321 m .5093 .65596 L .52549 .65411 L p .707 .577 .707 r
F P
0 g
s
.50574 .79664 m .50423 .81576 L .49741 .81752 L p .707 .577 .707 r
F P
0 g
s
.52549 .65411 m .52169 .71136 L .50551 .71321 L p .707 .577 .707 r
F P
0 g
s
.50693 .73753 m .51226 .76834 L .50602 .78748 L p .707 .577 .707 r
F P
0 g
s
.51226 .76834 m .50693 .73753 L .52246 .71939 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .52549 .65411 L .54937 .65343 L p .707 .577 .707 r
F P
0 g
s
.50423 .81576 m .50574 .79664 L .52184 .79588 L p .707 .577 .707 r
F P
0 g
s
.52184 .79588 m .52033 .81501 L .50423 .81576 L p .707 .577 .707 r
F P
0 g
s
.54167 .70671 m .54575 .70402 L p .54519 .70544 L .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .57452 .69293 L p .57038 .70032 L .707 .577 .707 r
F P
0 g
s
.5469 .70498 m .54575 .70402 L .57038 .70032 L .707 .577 .707 r
F
.54937 .65343 m .57862 .654 L p .54916 .70453 L F P
0 g
s
.54558 .71068 m .54594 .70517 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .54575 .70402 L p .5469 .70498 L .707 .577 .707 r
F P
0 g
s
.57483 .71125 m .54558 .71068 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .5469 .70498 L .56118 .71677 L .707 .577 .707 r
F
.57452 .69293 m .60597 .6872 L p .59855 .69757 L F P
0 g
s
.58137 .69885 m .57452 .69293 L .59855 .69757 L .707 .577 .707 r
F
.57862 .654 m .61037 .65575 L p .58284 .69874 L F P
0 g
s
.57483 .71125 m .57562 .69928 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .57452 .69293 L p .58137 .69885 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .57483 .71125 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .58137 .69885 L .59142 .70755 L .707 .577 .707 r
F
.63772 .71578 m .60658 .713 L p .61666 .69728 L F P
0 g
s
.60597 .6872 m .63701 .68739 L p .62828 .69778 L .707 .577 .707 r
F P
0 g
s
.6154 .69723 m .60597 .6872 L .62828 .69778 L .707 .577 .707 r
F
.66521 .71929 m .63772 .71578 L p .64707 .69972 L F P
0 g
s
.63701 .68739 m .6646 .69349 L p .65732 .70157 L .707 .577 .707 r
F P
0 g
s
.64643 .6996 m .63701 .68739 L .65732 .70157 L .707 .577 .707 r
F
.68635 .72322 m .66521 .71929 L p .67175 .7053 L F P
0 g
s
.6646 .69349 m .68604 .7049 L p .68231 .70939 L .707 .577 .707 r
F P
0 g
s
.67212 .70545 m .6646 .69349 L .68231 .70939 L .707 .577 .707 r
F
.68714 .71125 m .68635 .72322 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .6646 .69349 L p .67212 .70545 L .707 .577 .707 r
F P
0 g
s
.66521 .71929 m .66628 .70319 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.66628 .70319 m .67212 .70545 L .67792 .71467 L .707 .577 .707 r
F
.669 .66205 m .69014 .66597 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .669 .66205 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69137 .7357 L .66993 .7243 L p .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .68714 .71125 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.67792 .71467 m .67212 .70545 L .68231 .70939 L .707 .577 .707 r
F
.66993 .7243 m .66628 .70319 L p .67792 .71467 L F P
0 g
s
.66628 .70319 m .66521 .71929 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.6646 .69349 m .66993 .7243 L .64233 .7182 L p .707 .577 .707 r
F P
0 g
s
.64707 .69972 m .65279 .68989 L .66628 .70319 L .707 .577 .707 r
F
.669 .66205 m .66628 .70319 L p .65279 .68989 L F P
0 g
s
.64152 .65853 m .669 .66205 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63772 .71578 m .63888 .69824 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .63701 .68739 L p .64643 .6996 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64152 .65853 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64643 .6996 L .65227 .70717 L .707 .577 .707 r
F
.65227 .70717 m .64643 .6996 L .65732 .70157 L F
.64233 .7182 m .63888 .69824 L p .65227 .70717 L F P
0 g
s
.63888 .69824 m .63772 .71578 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.63701 .68739 m .64233 .7182 L .6113 .718 L p .707 .577 .707 r
F P
0 g
s
.61666 .69728 m .62289 .68757 L .63888 .69824 L .707 .577 .707 r
F
.64152 .65853 m .63888 .69824 L p .62289 .68757 L F P
0 g
s
.61037 .65575 m .64152 .65853 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .60765 .6969 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .60597 .6872 L p .6154 .69723 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .61037 .65575 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .6154 .69723 L .62245 .70473 L .707 .577 .707 r
F
.62245 .70473 m .6154 .69723 L .62828 .69778 L F
.6113 .718 m .60765 .6969 L p .62245 .70473 L F P
0 g
s
.60765 .6969 m .60658 .713 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.60597 .6872 m .6113 .718 L .57985 .72373 L p .707 .577 .707 r
F P
0 g
s
.58284 .69874 m .59 .68756 L .60765 .6969 L .707 .577 .707 r
F
.61037 .65575 m .60765 .6969 L p .59 .68756 L F P
0 g
s
.57562 .69928 m .57862 .654 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.59142 .70755 m .58137 .69885 L .59855 .69757 L .707 .577 .707 r
F
.57985 .72373 m .57562 .69928 L p .59142 .70755 L F P
0 g
s
.57562 .69928 m .57483 .71125 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.57452 .69293 m .57985 .72373 L .55107 .73483 L p .707 .577 .707 r
F P
0 g
s
.54916 .70453 m .55769 .6899 L .57562 .69928 L .707 .577 .707 r
F
.57862 .654 m .57562 .69928 L p .55769 .6899 L F P
0 g
s
.54594 .70517 m .54937 .65343 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.56118 .71677 m .5469 .70498 L .57038 .70032 L .707 .577 .707 r
F
.55107 .73483 m .54594 .70517 L p .56118 .71677 L F P
0 g
s
.54594 .70517 m .54558 .71068 L .52939 .71114 L p .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .55107 .73483 L .52778 .7502 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .53033 .69328 L .54594 .70517 L .707 .577 .707 r
F
.54937 .65343 m .54594 .70517 L p .53033 .69328 L F P
0 g
s
.52939 .71114 m .52169 .71136 L p .54594 .70517 L .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .52246 .71939 L .54167 .70671 L p .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .54167 .70671 L .54519 .70544 L .707 .577 .707 r
F
.52246 .71939 m .52778 .7502 L .51226 .76834 L p F P
0 g
s
.52033 .81501 m .52184 .79588 L .54565 .7962 L p .707 .577 .707 r
F P
0 g
s
.54565 .7962 m .54414 .81532 L .52033 .81501 L p .707 .577 .707 r
F P
0 g
s
.48875 .32471 m .49394 .82294 L .53888 .82132 L p .707 .577 .707 r
F P
0 g
s
.53888 .82132 m .53369 .32309 L .48875 .32471 L p .707 .577 .707 r
F P
0 g
s
.54414 .81532 m .54565 .7962 L .57485 .79755 L p .707 .577 .707 r
F P
0 g
s
.57485 .79755 m .57334 .81667 L .54414 .81532 L p .707 .577 .707 r
F P
0 g
s
.57334 .81667 m .57485 .79755 L .60656 .79981 L p .707 .577 .707 r
F P
0 g
s
.60656 .79981 m .60505 .81893 L .57334 .81667 L p .707 .577 .707 r
F P
0 g
s
.53369 .32309 m .53888 .82132 L .58036 .81572 L p .707 .577 .707 r
F P
0 g
s
.58036 .81572 m .57517 .3175 L .53369 .32309 L p .707 .577 .707 r
F P
0 g
s
.7029 .73876 m .70823 .76957 L .70457 .7513 L p .708 .578 .707 r
F P
0 g
s
.44993 .82044 m .44474 .32221 L .40598 .31583 L p .707 .577 .707 r
F P
0 g
s
.44474 .32221 m .44993 .82044 L .49394 .82294 L p .707 .577 .707 r
F P
0 g
s
.60505 .81893 m .60656 .79981 L .63769 .80276 L p .707 .577 .707 r
F P
0 g
s
.57517 .3175 m .58036 .81572 L .61431 .80671 L p .707 .577 .707 r
F P
0 g
s
.61431 .80671 m .60912 .30849 L .57517 .3175 L p .707 .577 .707 r
F P
0 g
s
.70228 .81525 m .70077 .83437 L .69764 .83179 L p .707 .577 .707 r
F P
0 g
s
.69764 .83179 m .69915 .81267 L .70228 .81525 L p .707 .577 .707 r
F P
0 g
s
.41117 .81406 m .40598 .31583 L .37625 .30619 L p .707 .577 .707 r
F P
0 g
s
.40598 .31583 m .41117 .81406 L .44993 .82044 L p .707 .577 .707 r
F P
0 g
s
.25116 .69697 m .25496 .63972 L .22381 .63695 L p .707 .577 .707 r
F P
0 g
s
.25496 .63972 m .25116 .69697 L .28291 .69873 L p .707 .577 .707 r
F P
0 g
s
.28291 .69873 m .28671 .64148 L .25496 .63972 L p .707 .577 .707 r
F P
0 g
s
.28671 .64148 m .28291 .69873 L .31216 .6993 L p .707 .577 .707 r
F P
0 g
s
.31216 .6993 m .31596 .64205 L .28671 .64148 L p .707 .577 .707 r
F P
0 g
s
.22381 .63695 m .22002 .6942 L .25116 .69697 L p .707 .577 .707 r
F P
0 g
s
.22002 .6942 m .22381 .63695 L .19633 .63343 L p .707 .577 .707 r
F P
0 g
s
.19633 .63343 m .19253 .69068 L .22002 .6942 L p .707 .577 .707 r
F P
0 g
s
.60912 .30849 m .61431 .80671 L .63741 .79516 L p .707 .577 .707 r
F P
0 g
s
.63741 .79516 m .63222 .29694 L .60912 .30849 L p .707 .577 .707 r
F P
0 g
s
.31596 .64205 m .31216 .6993 L .33605 .69862 L p .707 .577 .707 r
F P
0 g
s
.33605 .69862 m .33984 .64137 L .31596 .64205 L p .707 .577 .707 r
F P
0 g
s
.19253 .69068 m .19633 .63343 L .17519 .62951 L p .707 .577 .707 r
F P
0 g
s
.69915 .81267 m .69764 .83179 L .68486 .82864 L p .707 .577 .707 r
F P
0 g
s
.68486 .82864 m .68637 .80952 L .69915 .81267 L p .707 .577 .707 r
F P
0 g
s
.17519 .62951 m .17139 .68676 L .19253 .69068 L p .707 .577 .707 r
F P
0 g
s
.25012 .79615 m .25163 .77702 L .2205 .77408 L p .707 .577 .707 r
F P
0 g
s
.25163 .77702 m .25012 .79615 L .28184 .79841 L p .707 .577 .707 r
F P
0 g
s
.28184 .79841 m .28335 .77929 L .25163 .77702 L p .707 .577 .707 r
F P
0 g
s
.38144 .80442 m .37625 .30619 L .35847 .29424 L p .707 .577 .707 r
F P
0 g
s
.37625 .30619 m .38144 .80442 L .41117 .81406 L p .707 .577 .707 r
F P
0 g
s
.2205 .77408 m .21899 .7932 L .25012 .79615 L p .707 .577 .707 r
F P
0 g
s
.28335 .77929 m .28184 .79841 L .31103 .79976 L p .707 .577 .707 r
F P
0 g
s
.31103 .79976 m .31254 .78064 L .28335 .77929 L p .707 .577 .707 r
F P
0 g
s
.25995 .80223 m .25462 .77142 L .22358 .77123 L p .707 .577 .707 r
F P
0 g
s
.25462 .77142 m .25995 .80223 L .29139 .7965 L p .707 .577 .707 r
F P
0 g
s
.29139 .7965 m .28607 .76569 L .25462 .77142 L p .707 .577 .707 r
F P
0 g
s
.31254 .78064 m .31103 .79976 L .33484 .80007 L p .707 .577 .707 r
F P
0 g
s
.33484 .80007 m .33635 .78095 L .31254 .78064 L p .707 .577 .707 r
F P
0 g
s
.28607 .76569 m .29139 .7965 L .32017 .78541 L p .707 .577 .707 r
F P
0 g
s
.32017 .78541 m .31484 .7546 L .28607 .76569 L p .707 .577 .707 r
F P
0 g
s
.21899 .7932 m .2205 .77408 L .193 .77073 L p .707 .577 .707 r
F P
0 g
s
.33984 .64137 m .33605 .69862 L .35223 .69676 L p .707 .577 .707 r
F P
0 g
s
.35223 .69676 m .35603 .63951 L .33984 .64137 L p .707 .577 .707 r
F P
0 g
s
.193 .77073 m .19149 .78985 L .21899 .7932 L p .707 .577 .707 r
F P
0 g
s
.22891 .80204 m .22358 .77123 L .19599 .76513 L p .707 .577 .707 r
F P
0 g
s
.22358 .77123 m .22891 .80204 L .25995 .80223 L p .707 .577 .707 r
F P
0 g
s
.31484 .7546 m .32017 .78541 L .34346 .77003 L p .707 .577 .707 r
F P
0 g
s
.34346 .77003 m .33813 .73923 L .31484 .7546 L p .707 .577 .707 r
F P
0 g
s
.17139 .68676 m .17519 .62951 L .16246 .62557 L p .707 .577 .707 r
F P
0 g
s
.19149 .78985 m .193 .77073 L .17183 .76732 L p .707 .577 .707 r
F P
0 g
s
.16246 .62557 m .15867 .68282 L .17139 .68676 L p .707 .577 .707 r
F P
0 g
s
.63222 .29694 m .63741 .79516 L .64741 .78221 L p .707 .577 .707 r
F P
0 g
s
.64741 .78221 m .64222 .28398 L .63222 .29694 L p .707 .577 .707 r
F P
0 g
s
.17183 .76732 m .17032 .78644 L .19149 .78985 L p .707 .577 .707 r
F P
0 g
s
.68637 .80952 m .68486 .82864 L .66368 .82522 L p .707 .577 .707 r
F P
0 g
s
.66368 .82522 m .66519 .8061 L .68637 .80952 L p .707 .577 .707 r
F P
0 g
s
.20132 .79594 m .19599 .76513 L .17454 .75372 L p .707 .577 .707 r
F P
0 g
s
.19599 .76513 m .20132 .79594 L .22891 .80204 L p .707 .577 .707 r
F P
0 g
s
.33813 .73923 m .34346 .77003 L .35898 .75189 L p .707 .577 .707 r
F P
0 g
s
.35898 .75189 m .35366 .72108 L .33813 .73923 L p .707 .577 .707 r
F P
0 g
s
.35603 .63951 m .35223 .69676 L .35913 .69391 L p .707 .577 .707 r
F P
0 g
s
.35913 .69391 m .36292 .63666 L .35603 .63951 L p .707 .577 .707 r
F P
0 g
s
.33635 .78095 m .33484 .80007 L .35095 .79931 L p .707 .577 .707 r
F P
0 g
s
.35095 .79931 m .35246 .78019 L .33635 .78095 L p .707 .577 .707 r
F P
0 g
s
.35366 .72108 m .35898 .75189 L .36522 .73275 L p .707 .577 .707 r
F P
0 g
s
.36522 .73275 m .35989 .70194 L .35366 .72108 L p .707 .577 .707 r
F P
0 g
s
.36292 .63666 m .35913 .69391 L .35814 .69276 L p .707 .577 .707 r
F P
0 g
s
.35814 .69276 m .35607 .69034 L p .35664 .68581 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35623 .68368 L .35687 .68687 L p .708 .578 .707 r
F P
0 g
s
.35664 .68581 m .36292 .63666 L .35814 .69276 L .707 .577 .707 r
F
.35986 .63309 m .36292 .63666 L p .35703 .68281 L F P
0 g
s
.35607 .69034 m .35643 .68483 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35986 .63309 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35607 .69034 m .34334 .6864 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35623 .68368 m .35643 .68483 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35607 .69034 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .35623 .68368 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .34413 .67444 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .34413 .67444 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34303 .66808 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .35986 .63309 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34714 .62915 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35986 .63309 m .35643 .68483 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .35588 .68436 L .35643 .68483 L .707 .577 .707 r
F
.35643 .68483 m .36156 .71449 L .35126 .70231 L p F P
0 g
s
.35126 .70231 m .34836 .69889 L p .35643 .68483 L .707 .577 .707 r
F P
0 g
s
.36156 .71449 m .35643 .68483 L p .35989 .70194 L .708 .578 .707 r
F P
0 g
s
.35687 .68687 m .35989 .70194 L p .35643 .68483 L .708 .578 .707 r
F P
0 g
s
.35989 .70194 m .36522 .73275 L .36156 .71449 L p .708 .578 .707 r
F P
0 g
s
.36366 .79247 m .35847 .29424 L .35437 .28114 L p .707 .577 .707 r
F P
0 g
s
.35847 .29424 m .36366 .79247 L .38144 .80442 L p .707 .577 .707 r
F P
0 g
s
.15867 .68282 m .16246 .62557 L .1594 .622 L p .707 .577 .707 r
F P
0 g
s
.17032 .78644 m .17183 .76732 L .15904 .76416 L p .707 .577 .707 r
F P
0 g
s
.15904 .76416 m .15753 .78328 L .17032 .78644 L p .707 .577 .707 r
F P
0 g
s
.66519 .8061 m .66368 .82522 L .63618 .82188 L p .707 .577 .707 r
F P
0 g
s
.63618 .82188 m .63769 .80276 L .66519 .8061 L p .707 .577 .707 r
F P
0 g
s
.17987 .78453 m .17454 .75372 L .16135 .73812 L p .707 .577 .707 r
F P
0 g
s
.17454 .75372 m .17987 .78453 L .20132 .79594 L p .707 .577 .707 r
F P
0 g
s
.1594 .622 m .1556 .67925 L .15867 .68282 L p .707 .577 .707 r
F P
0 g
s
.63769 .80276 m .63618 .82188 L .60505 .81893 L p .707 .577 .707 r
F P
0 g
s
.64222 .28398 m .64741 .78221 L .64656 .77951 L p .707 .577 .707 r
F P
0 g
s
.64318 .71089 m .64222 .28398 L .64656 .77951 L .707 .577 .707 r
F
.63812 .27089 m .64222 .28398 L p .64301 .63495 L F P
0 g
s
.64331 .76673 m .64189 .63242 L .64301 .63495 L .707 .577 .707 r
F
.64328 .7663 m .64189 .63242 L p .64331 .76673 L F P
0 g
s
.64656 .77951 m .64347 .76961 L p .64318 .71089 L .707 .577 .707 r
F P
0 g
s
.64347 .76961 m .64331 .76911 L p .64331 .76673 L .707 .577 .707 r
F P
0 g
s
.64331 .76673 m .64318 .71089 L .64347 .76961 L .707 .577 .707 r
F
.63812 .27089 m .64331 .76911 L .62553 .75716 L p F P
0 g
s
.63926 .71042 m .63775 .72954 L .64129 .73041 L p .707 .577 .707 r
F P
0 g
s
.64129 .73041 m .65053 .73269 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.6403 .71247 m .63926 .71042 L .64129 .73041 L .707 .577 .707 r
F
.65053 .73269 m .65204 .71357 L .6402 .71065 L p F P
0 g
s
.6402 .71065 m .63926 .71042 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.65053 .73269 m .6402 .71065 L .6403 .71247 L .707 .577 .707 r
F
.64331 .76911 m .64328 .7663 L p .64331 .76673 L F P
0 g
s
.64189 .63242 m .63812 .27089 L p .64301 .63495 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63961 .56678 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63888 .6276 m .63899 .62589 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .64267 .57035 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63899 .62589 L p .6516 .63154 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .63888 .6276 L .63908 .62766 L p .707 .577 .707 r
F P
0 g
s
.63908 .62766 m .6516 .63154 L p .63899 .62589 L .707 .577 .707 r
F P
0 g
s
.35246 .78019 m .35095 .79931 L .35777 .79756 L p .707 .577 .707 r
F P
0 g
s
.35777 .79756 m .35928 .77844 L .35246 .78019 L p .707 .577 .707 r
F P
0 g
s
.16135 .73812 m .16667 .76893 L .17987 .78453 L p .707 .577 .707 r
F P
0 g
s
.16667 .76893 m .16135 .73812 L .15769 .71986 L p .708 .578 .707 r
F P
0 g
s
.15753 .78328 m .15904 .76416 L .15591 .76158 L p .707 .577 .707 r
F P
0 g
s
.15591 .76158 m .1544 .7807 L .15753 .78328 L p .707 .577 .707 r
F P
0 g
s
.1556 .67925 m .1594 .622 L .16629 .61915 L p .707 .577 .707 r
F P
0 g
s
.16629 .61915 m .1625 .6764 L .1556 .67925 L p .707 .577 .707 r
F P
0 g
s
.35437 .28114 m .35956 .77937 L .36366 .79247 L p .707 .577 .707 r
F P
0 g
s
.35956 .77937 m .35437 .28114 L .36437 .26819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35928 .77844 m .35777 .79756 L .35463 .79498 L p .707 .577 .707 r
F P
0 g
s
.35463 .79498 m .35614 .77586 L .35928 .77844 L p .707 .577 .707 r
F P
0 g
s
.15769 .71986 m .16301 .75067 L .16667 .76893 L p .708 .578 .707 r
F P
0 g
s
.16301 .75067 m .15769 .71986 L .16392 .70072 L p .707 .577 .707 r
F P
0 g
s
.1544 .7807 m .15591 .76158 L .16273 .75983 L p .707 .577 .707 r
F P
0 g
s
.62553 .75716 m .62034 .25893 L .63812 .27089 L p .707 .577 .707 r
F P
0 g
s
.1625 .6764 m .16629 .61915 L .18248 .61729 L p .707 .577 .707 r
F P
0 g
s
.16273 .75983 m .16122 .77895 L .1544 .7807 L p .707 .577 .707 r
F P
0 g
s
.18248 .61729 m .17868 .67454 L .1625 .6764 L p .707 .577 .707 r
F P
0 g
s
.16392 .70072 m .16925 .73153 L .16301 .75067 L p .707 .577 .707 r
F P
0 g
s
.16925 .73153 m .16392 .70072 L .17945 .68258 L p .707 .577 .707 r
F P
0 g
s
.36956 .76641 m .36437 .26819 L .38747 .25664 L p .707 .577 .707 r
F P
0 g
s
.36437 .26819 m .36956 .76641 L .35956 .77937 L p .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .3222 .68248 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34334 .6864 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .32692 .68748 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .34413 .67444 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34836 .69889 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32159 .65667 m .34303 .66808 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.3222 .68248 m .32327 .66637 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32692 .68748 m .32327 .66637 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32159 .65667 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .34714 .62915 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32599 .62523 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .34413 .67444 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.35614 .77586 m .35463 .79498 L .34185 .79182 L p .707 .577 .707 r
F P
0 g
s
.34185 .79182 m .34336 .7727 L .35614 .77586 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18248 .61729 L .20636 .61661 L p .707 .577 .707 r
F P
0 g
s
.16122 .77895 m .16273 .75983 L .17883 .75907 L p .707 .577 .707 r
F P
0 g
s
.17883 .75907 m .17732 .77819 L .16122 .77895 L p .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20257 .67386 L .18638 .67432 L p .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .17945 .68258 L .19866 .66989 L p .707 .577 .707 r
F P
0 g
s
.19866 .66989 m .20274 .6672 L p .20218 .66862 L .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .19866 .66989 L .20218 .66862 L .707 .577 .707 r
F
.20274 .6672 m .23151 .65611 L p .22737 .6635 L F P
0 g
s
.20389 .66816 m .20274 .6672 L .22737 .6635 L .707 .577 .707 r
F
.20636 .61661 m .23561 .61718 L p .20615 .66771 L F P
0 g
s
.20257 .67386 m .20293 .66835 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20274 .6672 L p .20389 .66816 L .707 .577 .707 r
F P
0 g
s
.23182 .67443 m .20257 .67386 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20389 .66816 L .21817 .67995 L .707 .577 .707 r
F
.23151 .65611 m .26296 .65038 L p .25554 .66076 L F P
0 g
s
.23836 .66204 m .23151 .65611 L .25554 .66076 L .707 .577 .707 r
F
.23561 .61718 m .26736 .61894 L p .23983 .66193 L F P
0 g
s
.23182 .67443 m .23261 .66247 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23151 .65611 L p .23836 .66204 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .23182 .67443 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23836 .66204 L .24841 .67073 L .707 .577 .707 r
F
.29471 .67896 m .26357 .67619 L p .27365 .66047 L F P
0 g
s
.26296 .65038 m .294 .65057 L p .28527 .66097 L .707 .577 .707 r
F P
0 g
s
.27239 .66041 m .26296 .65038 L .28527 .66097 L .707 .577 .707 r
F
.3222 .68248 m .29471 .67896 L p .30406 .6629 L F P
0 g
s
.294 .65057 m .32159 .65667 L p .31431 .66475 L .707 .577 .707 r
F P
0 g
s
.30342 .66279 m .294 .65057 L .31431 .66475 L .707 .577 .707 r
F
.32327 .66637 m .3222 .68248 L p .30406 .6629 L F P
0 g
s
.32159 .65667 m .32692 .68748 L .29933 .68138 L p .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .32327 .66637 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29851 .62171 m .32599 .62523 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29471 .67896 m .29587 .66143 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .294 .65057 L p .30342 .66279 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .29851 .62171 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .30342 .66279 L .30926 .67036 L .707 .577 .707 r
F
.30926 .67036 m .30342 .66279 L .31431 .66475 L F
.29933 .68138 m .29587 .66143 L p .30926 .67036 L F P
0 g
s
.29587 .66143 m .29471 .67896 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.294 .65057 m .29933 .68138 L .26829 .68119 L p .707 .577 .707 r
F P
0 g
s
.27365 .66047 m .27988 .65075 L .29587 .66143 L .707 .577 .707 r
F
.29851 .62171 m .29587 .66143 L p .27988 .65075 L F P
0 g
s
.26736 .61894 m .29851 .62171 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .26464 .66008 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26296 .65038 L p .27239 .66041 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26736 .61894 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .27239 .66041 L .27944 .66791 L .707 .577 .707 r
F
.27944 .66791 m .27239 .66041 L .28527 .66097 L F
.26829 .68119 m .26464 .66008 L p .27944 .66791 L F P
0 g
s
.26464 .66008 m .26357 .67619 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.26296 .65038 m .26829 .68119 L .23684 .68692 L p .707 .577 .707 r
F P
0 g
s
.23983 .66193 m .24699 .65074 L .26464 .66008 L .707 .577 .707 r
F
.26736 .61894 m .26464 .66008 L p .24699 .65074 L F P
0 g
s
.23261 .66247 m .23561 .61718 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.24841 .67073 m .23836 .66204 L .25554 .66076 L .707 .577 .707 r
F
.23684 .68692 m .23261 .66247 L p .24841 .67073 L F P
0 g
s
.23261 .66247 m .23182 .67443 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.23151 .65611 m .23684 .68692 L .20806 .69801 L p .707 .577 .707 r
F P
0 g
s
.20615 .66771 m .21468 .65308 L .23261 .66247 L .707 .577 .707 r
F
.23561 .61718 m .23261 .66247 L p .21468 .65308 L F P
0 g
s
.20293 .66835 m .20636 .61661 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.21817 .67995 m .20389 .66816 L .22737 .6635 L .707 .577 .707 r
F
.20806 .69801 m .20293 .66835 L p .21817 .67995 L F P
0 g
s
.20274 .6672 m .20806 .69801 L .18477 .71338 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18732 .65647 L .20293 .66835 L .707 .577 .707 r
F
.20636 .61661 m .20293 .66835 L p .18732 .65647 L F P
0 g
s
.18638 .67432 m .17868 .67454 L p .20293 .66835 L .707 .577 .707 r
F P
0 g
s
.17945 .68258 m .18477 .71338 L .16925 .73153 L p .707 .577 .707 r
F P
0 g
s
.62034 .25893 m .62553 .75716 L .5958 .74752 L p .707 .577 .707 r
F P
0 g
s
.5958 .74752 m .59061 .24929 L .62034 .25893 L p .707 .577 .707 r
F P
0 g
s
.34336 .7727 m .34185 .79182 L .32067 .78841 L p .707 .577 .707 r
F P
0 g
s
.32067 .78841 m .32218 .76929 L .34336 .7727 L p .707 .577 .707 r
F P
0 g
s
.38747 .25664 m .39266 .75487 L .36956 .76641 L p .707 .577 .707 r
F P
0 g
s
.39266 .75487 m .38747 .25664 L .42142 .24763 L p .707 .577 .707 r
F P
0 g
s
.17732 .77819 m .17883 .75907 L .20264 .75938 L p .707 .577 .707 r
F P
0 g
s
.20264 .75938 m .20113 .7785 L .17732 .77819 L p .707 .577 .707 r
F P
0 g
s
.73138 .64175 m .73517 .5845 L .70403 .58173 L p .707 .577 .707 r
F P
0 g
s
.73517 .5845 m .73138 .64175 L .76313 .64351 L p .707 .577 .707 r
F P
0 g
s
.76313 .64351 m .76692 .58626 L .73517 .5845 L p .707 .577 .707 r
F P
0 g
s
.76692 .58626 m .76313 .64351 L .79238 .64407 L p .707 .577 .707 r
F P
0 g
s
.79238 .64407 m .79617 .58682 L .76692 .58626 L p .707 .577 .707 r
F P
0 g
s
.70403 .58173 m .70023 .63898 L .73138 .64175 L p .707 .577 .707 r
F P
0 g
s
.70023 .63898 m .70403 .58173 L .67654 .57821 L p .707 .577 .707 r
F P
0 g
s
.59061 .24929 m .5958 .74752 L .55704 .74114 L p .707 .577 .707 r
F P
0 g
s
.55704 .74114 m .55185 .24291 L .59061 .24929 L p .707 .577 .707 r
F P
0 g
s
.32218 .76929 m .32067 .78841 L .29317 .78506 L p .707 .577 .707 r
F P
0 g
s
.29317 .78506 m .29468 .76594 L .32218 .76929 L p .707 .577 .707 r
F P
0 g
s
.67654 .57821 m .67275 .63546 L .70023 .63898 L p .707 .577 .707 r
F P
0 g
s
.79617 .58682 m .79238 .64407 L .81626 .6434 L p .707 .577 .707 r
F P
0 g
s
.81626 .6434 m .82006 .58615 L .79617 .58682 L p .707 .577 .707 r
F P
0 g
s
.20113 .7785 m .20264 .75938 L .23184 .76073 L p .707 .577 .707 r
F P
0 g
s
.23184 .76073 m .23033 .77986 L .20113 .7785 L p .707 .577 .707 r
F P
0 g
s
.67275 .63546 m .67654 .57821 L .6554 .57429 L p .707 .577 .707 r
F P
0 g
s
.42661 .74585 m .42142 .24763 L .4629 .24203 L p .707 .577 .707 r
F P
0 g
s
.42142 .24763 m .42588 .67541 L p .39266 .75487 L .707 .577 .707 r
F P
0 g
s
.4629 .24203 m .46809 .74026 L .42661 .74585 L p .707 .577 .707 r
F P
0 g
s
.42391 .54944 m .42012 .60669 L .4489 .60725 L p .707 .577 .707 r
F P
0 g
s
.4489 .60725 m .44937 .60726 L p .4491 .60666 L .707 .577 .707 r
F P
0 g
s
.4491 .60666 m .42391 .54944 L .4489 .60725 L .707 .577 .707 r
F
.42588 .67541 m .42658 .74304 L p .39966 .75301 L F P
0 g
s
.39966 .75301 m .39266 .75487 L p .42588 .67541 L .707 .577 .707 r
F P
0 g
s
.42055 .68872 m .41904 .70784 L .44014 .70882 L p .707 .577 .707 r
F P
0 g
s
.44014 .70882 m .44823 .7092 L p .44185 .70448 L .707 .577 .707 r
F P
0 g
s
.44185 .70448 m .42055 .68872 L .44014 .70882 L .707 .577 .707 r
F
.42658 .74304 m .42661 .74585 L .42533 .74619 L p F P
0 g
s
.42533 .74619 m .39966 .75301 L p .42658 .74304 L .707 .577 .707 r
F P
0 g
s
.29468 .76594 m .29317 .78506 L .26204 .78212 L p .707 .577 .707 r
F P
0 g
s
.26204 .78212 m .26355 .76299 L .29468 .76594 L p .707 .577 .707 r
F P
0 g
s
.6554 .57429 m .6516 .63154 L .67275 .63546 L p .707 .577 .707 r
F P
0 g
s
.73034 .7424 m .73185 .72328 L .70072 .72033 L p .707 .577 .707 r
F P
0 g
s
.73185 .72328 m .73034 .7424 L .76205 .74466 L p .707 .577 .707 r
F P
0 g
s
.76205 .74466 m .76356 .72554 L .73185 .72328 L p .707 .577 .707 r
F P
0 g
s
.70072 .72033 m .69921 .73945 L .73034 .7424 L p .707 .577 .707 r
F P
0 g
s
.23033 .77986 m .23184 .76073 L .26355 .76299 L p .707 .577 .707 r
F P
0 g
s
.26355 .76299 m .26204 .78212 L .23033 .77986 L p .707 .577 .707 r
F P
0 g
s
.76356 .72554 m .76205 .74466 L .79124 .74601 L p .707 .577 .707 r
F P
0 g
s
.79124 .74601 m .79275 .72689 L .76356 .72554 L p .707 .577 .707 r
F P
0 g
s
.55185 .24291 m .55704 .74114 L .51303 .73864 L p .707 .577 .707 r
F P
0 g
s
.51303 .73864 m .50784 .24041 L .55185 .24291 L p .707 .577 .707 r
F P
0 g
s
.74016 .74662 m .73483 .71581 L .70379 .71562 L p .707 .577 .707 r
F P
0 g
s
.73483 .71581 m .74016 .74662 L .77161 .74089 L p .707 .577 .707 r
F P
0 g
s
.77161 .74089 m .76628 .71008 L .73483 .71581 L p .707 .577 .707 r
F P
0 g
s
.79275 .72689 m .79124 .74601 L .81506 .74632 L p .707 .577 .707 r
F P
0 g
s
.81506 .74632 m .81657 .7272 L .79275 .72689 L p .707 .577 .707 r
F P
0 g
s
.76628 .71008 m .77161 .74089 L .80038 .7298 L p .707 .577 .707 r
F P
0 g
s
.80038 .7298 m .79506 .69899 L .76628 .71008 L p .707 .577 .707 r
F P
0 g
s
.69921 .73945 m .70072 .72033 L .67322 .71698 L p .707 .577 .707 r
F P
0 g
s
.82006 .58615 m .81626 .6434 L .83245 .64154 L p .707 .577 .707 r
F P
0 g
s
.83245 .64154 m .83624 .58429 L .82006 .58615 L p .707 .577 .707 r
F P
0 g
s
.67322 .71698 m .67171 .73611 L .69921 .73945 L p .707 .577 .707 r
F P
0 g
s
.46809 .74026 m .4629 .24203 L .50784 .24041 L p .707 .577 .707 r
F P
0 g
s
.50784 .24041 m .51303 .73864 L .46809 .74026 L p .707 .577 .707 r
F P
0 g
s
.70912 .74643 m .70379 .71562 L .6762 .70952 L p .707 .577 .707 r
F P
0 g
s
.70379 .71562 m .70912 .74643 L .74016 .74662 L p .707 .577 .707 r
F P
0 g
s
.79506 .69899 m .80038 .7298 L .82367 .71443 L p .707 .577 .707 r
F P
0 g
s
.82367 .71443 m .81835 .68362 L .79506 .69899 L p .707 .577 .707 r
F P
0 g
s
.6516 .63154 m .6554 .57429 L .64267 .57035 L p .707 .577 .707 r
F P
0 g
s
.67171 .73611 m .67322 .71698 L .65204 .71357 L p .707 .577 .707 r
F P
0 g
s
.65204 .71357 m .65053 .73269 L .67171 .73611 L p .707 .577 .707 r
F P
0 g
s
.68153 .74033 m .6762 .70952 L .65476 .69811 L p .707 .577 .707 r
F P
0 g
s
.6762 .70952 m .68153 .74033 L .70912 .74643 L p .707 .577 .707 r
F P
0 g
s
.81835 .68362 m .82367 .71443 L .8392 .69628 L p .707 .577 .707 r
F P
0 g
s
.8392 .69628 m .83387 .66548 L .81835 .68362 L p .707 .577 .707 r
F P
0 g
s
.83624 .58429 m .83245 .64154 L .83934 .63869 L p .707 .577 .707 r
F P
0 g
s
.83934 .63869 m .84314 .58144 L .83624 .58429 L p .707 .577 .707 r
F P
0 g
s
.81657 .7272 m .81506 .74632 L .83116 .74557 L p .707 .577 .707 r
F P
0 g
s
.83116 .74557 m .83267 .72644 L .81657 .7272 L p .707 .577 .707 r
F P
0 g
s
.66009 .72892 m .65476 .69811 L .64156 .68252 L p .707 .577 .707 r
F P
0 g
s
.65476 .69811 m .66009 .72892 L .68153 .74033 L p .707 .577 .707 r
F P
0 g
s
.83387 .66548 m .8392 .69628 L .84543 .67714 L p .707 .577 .707 r
F P
0 g
s
.84543 .67714 m .84011 .64634 L .83387 .66548 L p .707 .577 .707 r
F P
0 g
s
.63961 .56678 m .63582 .62403 L .63888 .6276 L p .707 .577 .707 r
F P
0 g
s
.83267 .72644 m .83116 .74557 L .83798 .74381 L p .707 .577 .707 r
F P
0 g
s
.83798 .74381 m .83949 .72469 L .83267 .72644 L p .707 .577 .707 r
F P
0 g
s
.83846 .63766 m .83628 .63512 L p .83689 .63036 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83645 .62807 L .83715 .63156 L p .708 .578 .707 r
F P
0 g
s
.84007 .57787 m .84314 .58144 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .83666 .62933 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .84007 .57787 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .82355 .63118 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.83645 .62807 m .83666 .62933 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83628 .63512 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .83645 .62807 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .82437 .61893 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .82437 .61893 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82325 .61247 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .84007 .57787 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82735 .57393 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.84007 .57787 m .83666 .62933 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .83606 .62882 L .83666 .62933 L .707 .577 .707 r
F
.83666 .62933 m .84177 .65888 L .83151 .64675 L p F P
0 g
s
.83151 .64675 m .82858 .64328 L p .83666 .62933 L .707 .577 .707 r
F P
0 g
s
.84177 .65888 m .83666 .62933 L p .84011 .64634 L .708 .578 .707 r
F P
0 g
s
.83715 .63156 m .84011 .64634 L p .83666 .62933 L .708 .578 .707 r
F P
0 g
s
.84314 .58144 m .83934 .63869 L .83846 .63766 L p .707 .577 .707 r
F P
0 g
s
.83689 .63036 m .84314 .58144 L .83846 .63766 L .707 .577 .707 r
F
.64156 .68252 m .64689 .71332 L .66009 .72892 L p F P
0 g
s
.64689 .71332 m .64156 .68252 L .6379 .66425 L p .708 .578 .707 r
F P
0 g
s
.63775 .72954 m .63926 .71042 L .63612 .70784 L p .707 .577 .707 r
F P
0 g
s
.84011 .64634 m .84543 .67714 L .84177 .65888 L p .708 .578 .707 r
F P
0 g
s
.63612 .70784 m .63461 .72696 L .63775 .72954 L p .707 .577 .707 r
F P
0 g
s
.63582 .62403 m .63961 .56678 L .64651 .56393 L p .707 .577 .707 r
F P
0 g
s
.64651 .56393 m .64271 .62118 L .63582 .62403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6379 .66425 m .64323 .69506 L .64689 .71332 L p .708 .578 .707 r
F P
0 g
s
.83949 .72469 m .83798 .74381 L .83484 .74123 L p .707 .577 .707 r
F P
0 g
s
.83484 .74123 m .83635 .72211 L .83949 .72469 L p .707 .577 .707 r
F P
0 g
s
.64323 .69506 m .6379 .66425 L .64414 .64511 L p .707 .577 .707 r
F P
0 g
s
.38837 .60494 m .39216 .54769 L .36102 .54491 L p .707 .577 .707 r
F P
0 g
s
.39216 .54769 m .38837 .60494 L .42012 .60669 L p .707 .577 .707 r
F P
0 g
s
.42012 .60669 m .42391 .54944 L .39216 .54769 L p .707 .577 .707 r
F P
0 g
s
.44937 .60726 m .45316 .55001 L .42391 .54944 L p .707 .577 .707 r
F P
0 g
s
.63461 .72696 m .63612 .70784 L .64294 .70608 L p .707 .577 .707 r
F P
0 g
s
.64271 .62118 m .64651 .56393 L .66269 .56207 L p .707 .577 .707 r
F P
0 g
s
.36102 .54491 m .35722 .60216 L .38837 .60494 L p .707 .577 .707 r
F P
0 g
s
.64294 .70608 m .64143 .7252 L .63461 .72696 L p .707 .577 .707 r
F P
0 g
s
.35722 .60216 m .36102 .54491 L .33353 .54139 L p .707 .577 .707 r
F P
0 g
s
.66269 .56207 m .6589 .61932 L .64271 .62118 L p .707 .577 .707 r
F P
0 g
s
.33353 .54139 m .32974 .59864 L .35722 .60216 L p .707 .577 .707 r
F P
0 g
s
.45316 .55001 m .44937 .60726 L .47325 .60658 L p .707 .577 .707 r
F P
0 g
s
.47325 .60658 m .47705 .54933 L .45316 .55001 L p .707 .577 .707 r
F P
0 g
s
.64414 .64511 m .64946 .67592 L .64323 .69506 L p .707 .577 .707 r
F P
0 g
s
.64946 .67592 m .64414 .64511 L .65966 .62697 L p .707 .577 .707 r
F P
0 g
s
.32974 .59864 m .33353 .54139 L .31239 .53747 L p .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .80241 .62726 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82355 .63118 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .80713 .63187 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .82437 .61893 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82858 .64328 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8018 .60106 m .82325 .61247 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80241 .62726 m .8035 .61087 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.80713 .63187 m .8035 .61087 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .8018 .60106 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .82735 .57393 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .80621 .57001 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .82437 .61893 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.83635 .72211 m .83484 .74123 L .82206 .73808 L p .707 .577 .707 r
F P
0 g
s
.82206 .73808 m .82357 .71896 L .83635 .72211 L p .707 .577 .707 r
F P
0 g
s
.31239 .53747 m .30859 .59472 L .32974 .59864 L p .707 .577 .707 r
F P
0 g
s
.38733 .70558 m .38884 .68646 L .35771 .68351 L p .707 .577 .707 r
F P
0 g
s
.38884 .68646 m .38733 .70558 L .41904 .70784 L p .707 .577 .707 r
F P
0 g
s
.41904 .70784 m .42055 .68872 L .38884 .68646 L p .707 .577 .707 r
F P
0 g
s
.35771 .68351 m .3562 .70264 L .38733 .70558 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66269 .56207 L .68658 .56139 L p .707 .577 .707 r
F P
0 g
s
.44823 .7092 m .44974 .69008 L .42055 .68872 L p .707 .577 .707 r
F P
0 g
s
.39715 .70981 m .39182 .679 L .36078 .67881 L p .707 .577 .707 r
F P
0 g
s
.39182 .679 m .39715 .70981 L .4286 .70408 L p .707 .577 .707 r
F P
0 g
s
.4286 .70408 m .42327 .67327 L .39182 .679 L p .707 .577 .707 r
F P
0 g
s
.44974 .69008 m .44823 .7092 L .47205 .70951 L p .707 .577 .707 r
F P
0 g
s
.47205 .70951 m .47356 .69039 L .44974 .69008 L p .707 .577 .707 r
F P
0 g
s
.42327 .67327 m .4286 .70408 L .45737 .69298 L p .707 .577 .707 r
F P
0 g
s
.45737 .69298 m .45205 .66218 L .42327 .67327 L p .707 .577 .707 r
F P
0 g
s
.64143 .7252 m .64294 .70608 L .65904 .70532 L p .707 .577 .707 r
F P
0 g
s
.3562 .70264 m .35771 .68351 L .33021 .68017 L p .707 .577 .707 r
F P
0 g
s
.47705 .54933 m .47325 .60658 L .48944 .60472 L p .707 .577 .707 r
F P
0 g
s
.48944 .60472 m .49323 .54748 L .47705 .54933 L p .707 .577 .707 r
F P
0 g
s
.65904 .70532 m .65753 .72444 L .64143 .7252 L p .707 .577 .707 r
F P
0 g
s
.33021 .68017 m .3287 .69929 L .3562 .70264 L p .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68278 .61864 L .66577 .61912 L p .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .65966 .62697 L .6785 .61453 L p .707 .577 .707 r
F P
0 g
s
.6785 .61453 m .68295 .6116 L p .68235 .61315 L .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .6785 .61453 L .68235 .61315 L .707 .577 .707 r
F
.68295 .6116 m .71173 .6005 L p .70752 .60802 L F P
0 g
s
.68421 .61264 m .68295 .6116 L .70752 .60802 L .707 .577 .707 r
F
.68658 .56139 m .71583 .56196 L p .68655 .61218 L F P
0 g
s
.68278 .61864 m .68317 .61285 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68295 .6116 L p .68421 .61264 L .707 .577 .707 r
F P
0 g
s
.71203 .61921 m .68278 .61864 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68421 .61264 L .69835 .62441 L .707 .577 .707 r
F
.71173 .6005 m .74317 .59477 L p .73567 .60526 L F P
0 g
s
.71864 .60653 m .71173 .6005 L .73567 .60526 L .707 .577 .707 r
F
.71583 .56196 m .74758 .56372 L p .72023 .60642 L F P
0 g
s
.71203 .61921 m .71284 .60697 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71173 .6005 L p .71864 .60653 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .71203 .61921 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71864 .60653 L .72857 .6152 L .707 .577 .707 r
F
.77493 .62374 m .74378 .62096 L p .75404 .60497 L F P
0 g
s
.74317 .59477 m .77421 .59497 L p .7654 .60546 L .707 .577 .707 r
F P
0 g
s
.75264 .60491 m .74317 .59477 L .7654 .60546 L .707 .577 .707 r
F
.80241 .62726 m .77493 .62374 L p .78442 .60743 L F P
0 g
s
.77421 .59497 m .8018 .60106 L p .79444 .60924 L .707 .577 .707 r
F P
0 g
s
.78366 .60729 m .77421 .59497 L .79444 .60924 L .707 .577 .707 r
F
.8035 .61087 m .80241 .62726 L p .78442 .60743 L F P
0 g
s
.8018 .60106 m .80713 .63187 L .77954 .62577 L p .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .8035 .61087 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77872 .56649 m .80621 .57001 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77493 .62374 m .77611 .60592 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77421 .59497 L p .78366 .60729 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77872 .56649 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .78366 .60729 L .78942 .61481 L .707 .577 .707 r
F
.78942 .61481 m .78366 .60729 L .79444 .60924 L F
.77954 .62577 m .77611 .60592 L p .78942 .61481 L F P
0 g
s
.77611 .60592 m .77493 .62374 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.77421 .59497 m .77954 .62577 L .7485 .62558 L p .707 .577 .707 r
F P
0 g
s
.75404 .60497 m .76023 .59533 L .77611 .60592 L .707 .577 .707 r
F
.77872 .56649 m .77611 .60592 L p .76023 .59533 L F P
0 g
s
.74758 .56372 m .77872 .56649 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .74487 .60458 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74317 .59477 L p .75264 .60491 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74758 .56372 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .75264 .60491 L .7596 .61237 L .707 .577 .707 r
F
.7596 .61237 m .75264 .60491 L .7654 .60546 L F
.7485 .62558 m .74487 .60458 L p .7596 .61237 L F P
0 g
s
.74487 .60458 m .74378 .62096 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.74317 .59477 m .7485 .62558 L .71705 .63131 L p .707 .577 .707 r
F P
0 g
s
.72023 .60642 m .72734 .59531 L .74487 .60458 L .707 .577 .707 r
F
.74758 .56372 m .74487 .60458 L p .72734 .59531 L F P
0 g
s
.71284 .60697 m .71583 .56196 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.72857 .6152 m .71864 .60653 L .73567 .60526 L .707 .577 .707 r
F
.71705 .63131 m .71284 .60697 L p .72857 .6152 L F P
0 g
s
.71284 .60697 m .71203 .61921 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.71173 .6005 m .71705 .63131 L .68828 .6424 L p .707 .577 .707 r
F P
0 g
s
.68655 .61218 m .69503 .59764 L .71284 .60697 L .707 .577 .707 r
F
.71583 .56196 m .71284 .60697 L p .69503 .59764 L F P
0 g
s
.68317 .61285 m .68658 .56139 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.69835 .62441 m .68421 .61264 L .70752 .60802 L .707 .577 .707 r
F
.68828 .6424 m .68317 .61285 L p .69835 .62441 L F P
0 g
s
.68295 .6116 m .68828 .6424 L .66499 .65777 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66764 .60103 L .68317 .61285 L .707 .577 .707 r
F
.68658 .56139 m .68317 .61285 L p .66764 .60103 L F P
0 g
s
.66577 .61912 m .6589 .61932 L p .68317 .61285 L .707 .577 .707 r
F P
0 g
s
.36611 .70961 m .36078 .67881 L .33319 .67271 L p .707 .577 .707 r
F P
0 g
s
.36078 .67881 m .36611 .70961 L .39715 .70981 L p .707 .577 .707 r
F P
0 g
s
.65966 .62697 m .66499 .65777 L .64946 .67592 L p .707 .577 .707 r
F P
0 g
s
.45205 .66218 m .45737 .69298 L .48066 .67761 L p .707 .577 .707 r
F P
0 g
s
.48066 .67761 m .47534 .6468 L .45205 .66218 L p .707 .577 .707 r
F P
0 g
s
.30859 .59472 m .31239 .53747 L .29966 .53353 L p .707 .577 .707 r
F P
0 g
s
.29966 .53353 m .29587 .59078 L .30859 .59472 L p .707 .577 .707 r
F P
0 g
s
.3287 .69929 m .33021 .68017 L .30903 .67675 L p .707 .577 .707 r
F P
0 g
s
.30903 .67675 m .30752 .69587 L .3287 .69929 L p .707 .577 .707 r
F P
0 g
s
.82357 .71896 m .82206 .73808 L .80088 .73466 L p .707 .577 .707 r
F P
0 g
s
.80088 .73466 m .80239 .71554 L .82357 .71896 L p .707 .577 .707 r
F P
0 g
s
.33852 .70351 m .33319 .67271 L .31175 .6613 L p .707 .577 .707 r
F P
0 g
s
.33319 .67271 m .33852 .70351 L .36611 .70961 L p .707 .577 .707 r
F P
0 g
s
.47534 .6468 m .48066 .67761 L .49619 .65947 L p .707 .577 .707 r
F P
0 g
s
.49619 .65947 m .49086 .62866 L .47534 .6468 L p .707 .577 .707 r
F P
0 g
s
.65753 .72444 m .65904 .70532 L .68286 .70563 L p .707 .577 .707 r
F P
0 g
s
.49323 .54748 m .48944 .60472 L .49633 .60187 L p .707 .577 .707 r
F P
0 g
s
.49633 .60187 m .50013 .54462 L .49323 .54748 L p .707 .577 .707 r
F P
0 g
s
.68286 .70563 m .68135 .72476 L .65753 .72444 L p .707 .577 .707 r
F P
0 g
s
.47356 .69039 m .47205 .70951 L .48815 .70875 L p .707 .577 .707 r
F P
0 g
s
.48815 .70875 m .48966 .68963 L .47356 .69039 L p .707 .577 .707 r
F P
0 g
s
.29587 .59078 m .29966 .53353 L .2966 .52996 L p .707 .577 .707 r
F P
0 g
s
.30752 .69587 m .30903 .67675 L .29625 .6736 L p .707 .577 .707 r
F P
0 g
s
.29625 .6736 m .29474 .69272 L .30752 .69587 L p .707 .577 .707 r
F P
0 g
s
.80239 .71554 m .80088 .73466 L .77338 .73132 L p .707 .577 .707 r
F P
0 g
s
.77338 .73132 m .77489 .71219 L .80239 .71554 L p .707 .577 .707 r
F P
0 g
s
.31708 .69211 m .31175 .6613 L .29855 .6457 L p .707 .577 .707 r
F P
0 g
s
.31175 .6613 m .31708 .69211 L .33852 .70351 L p .707 .577 .707 r
F P
0 g
s
.49086 .62866 m .49619 .65947 L .50242 .64033 L p .707 .577 .707 r
F P
0 g
s
.50242 .64033 m .4971 .60952 L .49086 .62866 L p .707 .577 .707 r
F P
0 g
s
.2966 .52996 m .29281 .58721 L .29587 .59078 L p .707 .577 .707 r
F P
0 g
s
.68135 .72476 m .68286 .70563 L .71205 .70699 L p .707 .577 .707 r
F P
0 g
s
.71205 .70699 m .71054 .72611 L .68135 .72476 L p .707 .577 .707 r
F P
0 g
s
.77489 .71219 m .77338 .73132 L .74225 .72837 L p .707 .577 .707 r
F P
0 g
s
.74225 .72837 m .74376 .70925 L .77489 .71219 L p .707 .577 .707 r
F P
0 g
s
.48966 .68963 m .48815 .70875 L .49497 .707 L p .707 .577 .707 r
F P
0 g
s
.49497 .707 m .49648 .68787 L .48966 .68963 L p .707 .577 .707 r
F P
0 g
s
.49545 .60084 m .49327 .5983 L p .49388 .59355 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49344 .59126 L .49414 .59475 L p .708 .578 .707 r
F P
0 g
s
.49706 .54105 m .50013 .54462 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .49365 .59251 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49706 .54105 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .48054 .59436 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49344 .59126 m .49365 .59251 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49327 .5983 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .49344 .59126 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .48136 .58212 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .48136 .58212 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48024 .57566 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .49706 .54105 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48434 .53711 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49706 .54105 m .49365 .59251 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .49305 .592 L .49365 .59251 L .707 .577 .707 r
F
.49365 .59251 m .49876 .62206 L .4885 .60993 L p F P
0 g
s
.4885 .60993 m .48557 .60646 L p .49365 .59251 L .707 .577 .707 r
F P
0 g
s
.49876 .62206 m .49365 .59251 L p .4971 .60952 L .708 .578 .707 r
F P
0 g
s
.49414 .59475 m .4971 .60952 L p .49365 .59251 L .708 .578 .707 r
F P
0 g
s
.50013 .54462 m .49633 .60187 L .49545 .60084 L p .707 .577 .707 r
F P
0 g
s
.49388 .59355 m .50013 .54462 L .49545 .60084 L .707 .577 .707 r
F
.71054 .72611 m .71205 .70699 L .74376 .70925 L p F P
0 g
s
.74376 .70925 m .74225 .72837 L .71054 .72611 L p .707 .577 .707 r
F P
0 g
s
.29855 .6457 m .30388 .67651 L .31708 .69211 L p .707 .577 .707 r
F P
0 g
s
.30388 .67651 m .29855 .6457 L .29489 .62744 L p .708 .578 .707 r
F P
0 g
s
.29474 .69272 m .29625 .6736 L .29311 .67102 L p .707 .577 .707 r
F P
0 g
s
.4971 .60952 m .50242 .64033 L .49876 .62206 L p .708 .578 .707 r
F P
0 g
s
.29311 .67102 m .2916 .69014 L .29474 .69272 L p .707 .577 .707 r
F P
0 g
s
.29281 .58721 m .2966 .52996 L .3035 .52711 L p .707 .577 .707 r
F P
0 g
s
.3035 .52711 m .2997 .58436 L .29281 .58721 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29489 .62744 m .30022 .65824 L .30388 .67651 L p .708 .578 .707 r
F P
0 g
s
.49648 .68787 m .49497 .707 L .49183 .70441 L p .707 .577 .707 r
F P
0 g
s
.49183 .70441 m .49334 .68529 L .49648 .68787 L p .707 .577 .707 r
F P
0 g
s
.30022 .65824 m .29489 .62744 L .30113 .6083 L p .707 .577 .707 r
F P
0 g
s
.2916 .69014 m .29311 .67102 L .29993 .66926 L p .707 .577 .707 r
F P
0 g
s
.2997 .58436 m .3035 .52711 L .31968 .52525 L p .707 .577 .707 r
F P
0 g
s
.29993 .66926 m .29842 .68839 L .2916 .69014 L p .707 .577 .707 r
F P
0 g
s
.31968 .52525 m .31589 .5825 L .2997 .58436 L p .707 .577 .707 r
F P
0 g
s
.30113 .6083 m .30645 .6391 L .30022 .65824 L p .707 .577 .707 r
F P
0 g
s
.30645 .6391 m .30113 .6083 L .31665 .59015 L p .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .4594 .59044 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48054 .59436 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .46412 .59506 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .48136 .58212 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48557 .60646 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.45879 .56425 m .48024 .57566 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4594 .59044 m .46049 .57406 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46412 .59506 m .46049 .57406 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .45879 .56425 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .48434 .53711 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .4632 .53319 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .48136 .58212 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.49334 .68529 m .49183 .70441 L .47905 .70126 L p .707 .577 .707 r
F P
0 g
s
.47905 .70126 m .48056 .68214 L .49334 .68529 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .31968 .52525 L .34357 .52458 L p .707 .577 .707 r
F P
0 g
s
.29842 .68839 m .29993 .66926 L .31603 .66851 L p .707 .577 .707 r
F P
0 g
s
.31603 .66851 m .31452 .68763 L .29842 .68839 L p .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33977 .58183 L .32276 .58231 L p .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .31665 .59015 L .33549 .57772 L p .707 .577 .707 r
F P
0 g
s
.33549 .57772 m .33994 .57478 L p .33934 .57633 L .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .33549 .57772 L .33934 .57633 L .707 .577 .707 r
F
.33994 .57478 m .36872 .56369 L p .36451 .57121 L F P
0 g
s
.3412 .57583 m .33994 .57478 L .36451 .57121 L .707 .577 .707 r
F
.34357 .52458 m .37282 .52514 L p .34354 .57536 L F P
0 g
s
.33977 .58183 m .34016 .57604 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33994 .57478 L p .3412 .57583 L .707 .577 .707 r
F P
0 g
s
.36902 .58239 m .33977 .58183 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .3412 .57583 L .35534 .58759 L .707 .577 .707 r
F
.36872 .56369 m .40016 .55796 L p .39266 .56845 L F P
0 g
s
.37563 .56972 m .36872 .56369 L .39266 .56845 L .707 .577 .707 r
F
.37282 .52514 m .40457 .5269 L p .37722 .5696 L F P
0 g
s
.36902 .58239 m .36983 .57015 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .36872 .56369 L p .37563 .56972 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .36902 .58239 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .37563 .56972 L .38556 .57838 L .707 .577 .707 r
F
.43192 .58692 m .40077 .58415 L p .41103 .56816 L F P
0 g
s
.40016 .55796 m .4312 .55815 L p .42239 .56865 L .707 .577 .707 r
F P
0 g
s
.40963 .5681 m .40016 .55796 L .42239 .56865 L .707 .577 .707 r
F
.4594 .59044 m .43192 .58692 L p .44141 .57061 L F P
0 g
s
.4312 .55815 m .45879 .56425 L p .45143 .57242 L .707 .577 .707 r
F P
0 g
s
.44064 .57047 m .4312 .55815 L .45143 .57242 L .707 .577 .707 r
F
.46049 .57406 m .4594 .59044 L p .44141 .57061 L F P
0 g
s
.45879 .56425 m .46412 .59506 L .43653 .58896 L p .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .46049 .57406 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43571 .52967 m .4632 .53319 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43192 .58692 m .4331 .56911 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .4312 .55815 L p .44064 .57047 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .43571 .52967 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .44064 .57047 L .44641 .57799 L .707 .577 .707 r
F
.44641 .57799 m .44064 .57047 L .45143 .57242 L F
.43653 .58896 m .4331 .56911 L p .44641 .57799 L F P
0 g
s
.4331 .56911 m .43192 .58692 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.4312 .55815 m .43653 .58896 L .40549 .58876 L p .707 .577 .707 r
F P
0 g
s
.41103 .56816 m .41722 .55851 L .4331 .56911 L .707 .577 .707 r
F
.43571 .52967 m .4331 .56911 L p .41722 .55851 L F P
0 g
s
.40457 .5269 m .43571 .52967 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .40186 .56776 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40016 .55796 L p .40963 .5681 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40457 .5269 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40963 .5681 L .41658 .57555 L .707 .577 .707 r
F
.41658 .57555 m .40963 .5681 L .42239 .56865 L F
.40549 .58876 m .40186 .56776 L p .41658 .57555 L F P
0 g
s
.40186 .56776 m .40077 .58415 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.40016 .55796 m .40549 .58876 L .37404 .59449 L p .707 .577 .707 r
F P
0 g
s
.37722 .5696 m .38433 .55849 L .40186 .56776 L .707 .577 .707 r
F
.40457 .5269 m .40186 .56776 L p .38433 .55849 L F P
0 g
s
.36983 .57015 m .37282 .52514 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.38556 .57838 m .37563 .56972 L .39266 .56845 L .707 .577 .707 r
F
.37404 .59449 m .36983 .57015 L p .38556 .57838 L F P
0 g
s
.36983 .57015 m .36902 .58239 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.36872 .56369 m .37404 .59449 L .34527 .60559 L p .707 .577 .707 r
F P
0 g
s
.34354 .57536 m .35202 .56082 L .36983 .57015 L .707 .577 .707 r
F
.37282 .52514 m .36983 .57015 L p .35202 .56082 L F P
0 g
s
.34016 .57604 m .34357 .52458 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.35534 .58759 m .3412 .57583 L .36451 .57121 L .707 .577 .707 r
F
.34527 .60559 m .34016 .57604 L p .35534 .58759 L F P
0 g
s
.33994 .57478 m .34527 .60559 L .32198 .62096 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .32463 .56421 L .34016 .57604 L .707 .577 .707 r
F
.34357 .52458 m .34016 .57604 L p .32463 .56421 L F P
0 g
s
.32276 .58231 m .31589 .5825 L p .34016 .57604 L .707 .577 .707 r
F P
0 g
s
.31665 .59015 m .32198 .62096 L .30645 .6391 L p .707 .577 .707 r
F P
0 g
s
.48056 .68214 m .47905 .70126 L .45787 .69785 L p .707 .577 .707 r
F P
0 g
s
.45787 .69785 m .45938 .67872 L .48056 .68214 L p .707 .577 .707 r
F P
0 g
s
.31452 .68763 m .31603 .66851 L .33985 .66882 L p .707 .577 .707 r
F P
0 g
s
.33985 .66882 m .33834 .68794 L .31452 .68763 L p .707 .577 .707 r
F P
0 g
s
.45938 .67872 m .45787 .69785 L .43037 .6945 L p .707 .577 .707 r
F P
0 g
s
.43037 .6945 m .43188 .67538 L .45938 .67872 L p .707 .577 .707 r
F P
0 g
s
.33834 .68794 m .33985 .66882 L .36904 .67017 L p .707 .577 .707 r
F P
0 g
s
.36904 .67017 m .36753 .68929 L .33834 .68794 L p .707 .577 .707 r
F P
0 g
s
.43188 .67538 m .43037 .6945 L .39924 .69155 L p .707 .577 .707 r
F P
0 g
s
.39924 .69155 m .40075 .67243 L .43188 .67538 L p .707 .577 .707 r
F P
0 g
s
.36753 .68929 m .36904 .67017 L .40075 .67243 L p .707 .577 .707 r
F P
0 g
s
.40075 .67243 m .39924 .69155 L .36753 .68929 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00L7oo0`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo8@0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2000
1EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00goo001JEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF1`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP050006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00E7oo00<005YF00000eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009ooaH004eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@00A7oo001COol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH8000lOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP00000^Ool005=oo`03001JEP00009JEPL00003FUH005YF00MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00Dgoo00<005YF00000P000eYF0P0015YF00<005YFFUH01EYF0P0025YF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001COol20002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
15YF3@001EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`800003FUH005YF008000IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001FOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005Moo`04001JEUYF0007FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Moo`04001JEUYF0007FUH00`00FUH0
00050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF001JEP020003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP00;Goo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH200001Woo
001JEUYF001JER400003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool005Eoo`03001JEUYF
00=JEP03001JEUYF009JEP8000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001EOol00`00FUIJEP03
FUH00`00FUIJEP020005Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo000bOolE000=Ool20005FUH30007
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03
FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEP00FUH0;Woo000]Ool500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0000
0eYF001JEP03FUH00`00Oomoo`07Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF0P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF
FUH005YF00T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYF001JEP0^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
Ool005YF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH50006Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00AJEPd000IJEP03001JEUYF009JEP05001JEUYF001JEP0^Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01000FUIJEP000UYF10000Woo00@005YFFUH000IJEP<000MJEP03001JEUYF
00UJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH010001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF00D005YFFUH005YF02ioo`00;Goo00<005YF0000
0eYF00<005YFFUH00UYF00=ooeYF00001eYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
009JEP04001JEUYF0005FUH40002FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH200000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH60007FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH0
00020004FUH00`00FUIJEP02FUH^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00002FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0
00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP04001JEP00FUH^Ool002eoo`03001JEP0000=JEP05001JEUYFFUH00002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH017ooFUIJEP000UYF00<005YFFUH00UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001Goo001JEUYF00000UYF00IooeYFFUIJEP00FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH000=J
EP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP8000Ioo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH70002FUH0
0`00Oomoo`0/Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH00004FUH00`00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH0
0`00Oomoo`0?OolA0007Ool00`00FUH0000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIo
o`02FUH00`00Oomoo`0YOol2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP05001JEUYF
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEP001EYF00D0
05YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP04001J
EP00000/Ool3000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP8002ioo`<002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH00UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001oogoo02eoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00@005YFFUH000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH20007FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP04001JEUYFFUH5000/Ool00`00FUH0000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP80009JEP@000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH01UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP000UYF00<005YFFUH01@002goo0`006Goo00<0
05YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUHJ0002FUH00`00FUIJEP07FUH40003FUH00`00FUIJEP05FUH00`00FUH00006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000eYF00<005YFFUH00eYF00@005YF000000Qoo`D001Moo`80009JEP03001oogoo02Yoo`00;7oo
00<005YF00000UYF1`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP80009J
EP03OomJEP0000EJEP03001JEUYF008000Moo`D001Ioo`03001JEP00009JEP03001oogoo02Yoo`00
;7oo00<005YF00000P0015YF0P000eYF00<005YFFUH01EYF0P0025YF00<005YFFUH015YF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF008000Moo`D001Eo
o`04001JEUYF0002FUH00`00Oomoo`0ZOol002aoo`80009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH900000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P00
27oo0`005Goo00D005YFFUIJEP00009JEP03001oogoo02Yoo`00;Goo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00@000IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02000OOol00`00FUIJEP03FUH2000]Ool002moo`D000IJ
EP03001JEUYF00EJEP@00003FUH005YF00MJEP04001JEP00FUH@0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YF
FUH00P007Goo0`001EYF0P00;Goo000aOol00`00FUH00007FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP06FUH00`00FUH000020002FUH01000FUIJEP0015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000K
Ool20002FUH00`00FUIJEP03FUH2000]Ool0031oo`04001JEUYF0007FUH00`00FUH000050004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P006Goo0P001EYF00<005YFFUH00UYF00<007ooOol0;7oo000_Ool01@00FUIJ
EUYF00001eYF0P001Woo6`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP06001JEUYF001JEP00
5goo0P001eYF00<005YFFUH00UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02
FUH2000SOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500000eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH40005FUH01@00FUIJEP00FUH05Woo0P0000=JEP00FUH01UYF00D005YFFUIJEP00
02moo`00;Woo00<005YFFUH00eYF00<005YFFUH00P009goo100015YF00<005YFFUH01EYF00<005YF
FUH00UYF1P0015YF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEQ400003FUIoogoo015oo`<000=JEP03001JEUYF00EJ
EP04001JEUYF000`Ool002eoo`8000EJEP<002eoobT000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP04001JEUYFFUHE0007FUH00`00
FUIJEP05FUH00`00FUH0000`Ool002eoo`03001JEP0000AJEP03001oogoo02ioo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH01EYF0P00<Goo000/Ool01000FUIJ
EP000eYF00<007ooOol0;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`000eYF00<007ooOol0<7oo000/Ool01000FUIJEP000eYF00<007ooOol0;Woo00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol0
02aoo`04001JEUYF0002FUH00`00Oomoo`0COol3000IOol00`00FUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`04
001JEUYFFUH2000EOol5000GOol200001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
6P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]
Ool00`00FUIJEP02000EOol5000FOol01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800005FUH005YFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP03FUHA0004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP005Woo1@005Woo00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP0000000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPL000=JEP04001JEUYF
FUH2000^Ool002eoo`04001JEUYF000GOol3000FOol01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YF00000`001EYF1@000UYF0P00;Woo000]Ool00`00FUH0000`Ool00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHN0008FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000]Ool00`00FUH0000^Ool30004FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Woo10000UYF00<0
05YFFUH01UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Woo
000^Ool2000/Ool20002FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH01EYF1P000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH0
0UYF00<005YF00003Woo3P001goo4P00;goo000^Ool00`00FUH0000YOol20004FUH00`00FUIJEP03
FUH01000FUIJEP001EYF00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000eoo`03001JEP0005Ao
o`00;Woo00@005YFFUH002Ioo`8000IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
0003FUH005YF00=JEP03001JEP0000eoo`03001JEP0005Aoo`00;Woo00<005YFFUH030006Goo0P00
00=JEP00FUH01UYF00H005YFFUH007oo0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03
001JEP0000eoo`03001JEP0005Aoo`00;7oo1@0000=JEP00FUH01EYF00@005YFFUIJEQ8000Aoo`<0
00=JEP03001JEUYF00EJEP03001JEP00009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
0UYF00<005YF000037oo0P0000=JEP000000Dgoo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP04FUH20003Ool0
0`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0:Ool00`00FUH00002
FUH00`00Oomoo`1AOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00Oomoo`02Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`09Ool01000FUIJEP000UYF00<007ooOol0
DGoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP050003Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001oo`08Ool01@00FUIJEUYF00000UYF00<007ooOol0DGoo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH0000027oo00<005YFFUH00eYF0P00E7oo000[OolK0004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
000000Ioo`<000EJEP8005Aoo`00;7oo0P000UYF00@005YF000000AJEP03001JEUYF00EJEP03001J
EUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP001Goo00@005YFFUH000EJEP8005Aoo`00;Woo1P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF200015YF00<005YFFUH00eYF00D005YF
FUH005YF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000Eoo`03001JEUYF009J
EP03001JEUYF009JEP03001oogoo05=oo`00<goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P0000=oo`00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0017oo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000fOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500001EYF000007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P000Woo0P001eYF00D0
05YFFUIJEP0005Ioo`00>7oo0`001UYF00<005YFFUH01EYF00<005YFFUH015YF100015YF00<005YF
FUH015YF00@005YFFUIJEP<0009oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800005Ool0
0000FUH00007FUH01000FUIJEP00Egoo000kOol40002FUH00`00FUIJEP05FUH00`00FUIJEP0I0005
Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YF0000Egoo000oOol=000POol2
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000080002FUH00`00FUIJEP05FUH2001HOol006ioo`8000AJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000EJEP04001J
EUYFFUH70003FUH00`00Oomoo`1GOol0071oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000UJEP03001JEUYF00EJEP03001JEUYF00D005Qo
o`00Lgoo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P00EGoo001gOol60002FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0D0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02001EOol007eooal000EJEP03001JEUYF00IJEP03001JEUYF00=JEPP000AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol0091oo`@00003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP04001JEUYFFUH2001EOol009Aoo`D0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJEPD0009JEP80
05Eoo`00VGoo0`001UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00@0
05YFFUIJEP@005Eoo`00W7oo10000UYF00<005YFFUH01UYF00<005YFFUH06P00EGoo002POol>001_
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59417 .73379 m .59797 .67654 L .56682 .67377 L p .707 .577 .707 r
F P
0 g
s
.59797 .67654 m .59417 .73379 L .62592 .73554 L p .707 .577 .707 r
F P
0 g
s
.62592 .73554 m .62972 .67829 L .59797 .67654 L p .707 .577 .707 r
F P
0 g
s
.62972 .67829 m .62592 .73554 L .65517 .73611 L p .707 .577 .707 r
F P
0 g
s
.65517 .73611 m .65897 .67886 L .62972 .67829 L p .707 .577 .707 r
F P
0 g
s
.56682 .67377 m .56303 .73101 L .59417 .73379 L p .707 .577 .707 r
F P
0 g
s
.56303 .73101 m .56682 .67377 L .53934 .67025 L p .707 .577 .707 r
F P
0 g
s
.53934 .67025 m .53554 .7275 L .56303 .73101 L p .707 .577 .707 r
F P
0 g
s
.65897 .67886 m .65517 .73611 L .67906 .73543 L p .707 .577 .707 r
F P
0 g
s
.67906 .73543 m .68285 .67818 L .65897 .67886 L p .707 .577 .707 r
F P
0 g
s
.53554 .7275 m .53934 .67025 L .5182 .66633 L p .707 .577 .707 r
F P
0 g
s
.5182 .66633 m .5144 .72357 L .53554 .7275 L p .707 .577 .707 r
F P
0 g
s
.59313 .83296 m .59464 .81384 L .56351 .81089 L p .707 .577 .707 r
F P
0 g
s
.59464 .81384 m .59313 .83296 L .62485 .83522 L p .707 .577 .707 r
F P
0 g
s
.62485 .83522 m .62636 .8161 L .59464 .81384 L p .707 .577 .707 r
F P
0 g
s
.56351 .81089 m .562 .83001 L .59313 .83296 L p .707 .577 .707 r
F P
0 g
s
.62636 .8161 m .62485 .83522 L .65404 .83657 L p .707 .577 .707 r
F P
0 g
s
.65404 .83657 m .65555 .81745 L .62636 .8161 L p .707 .577 .707 r
F P
0 g
s
.60296 .83904 m .59763 .80824 L .56659 .80804 L p .707 .577 .707 r
F P
0 g
s
.59763 .80824 m .60296 .83904 L .6344 .83331 L p .707 .577 .707 r
F P
0 g
s
.6344 .83331 m .62907 .80251 L .59763 .80824 L p .707 .577 .707 r
F P
0 g
s
.65555 .81745 m .65404 .83657 L .67785 .83689 L p .707 .577 .707 r
F P
0 g
s
.67785 .83689 m .67936 .81777 L .65555 .81745 L p .707 .577 .707 r
F P
0 g
s
.62907 .80251 m .6344 .83331 L .66318 .82222 L p .707 .577 .707 r
F P
0 g
s
.66318 .82222 m .65785 .79141 L .62907 .80251 L p .707 .577 .707 r
F P
0 g
s
.562 .83001 m .56351 .81089 L .53601 .80755 L p .707 .577 .707 r
F P
0 g
s
.68285 .67818 m .67906 .73543 L .69524 .73358 L p .707 .577 .707 r
F P
0 g
s
.69524 .73358 m .69904 .67633 L .68285 .67818 L p .707 .577 .707 r
F P
0 g
s
.53601 .80755 m .5345 .82667 L .562 .83001 L p .707 .577 .707 r
F P
0 g
s
.57192 .83885 m .56659 .80804 L .539 .80195 L p .707 .577 .707 r
F P
0 g
s
.56659 .80804 m .57192 .83885 L .60296 .83904 L p .707 .577 .707 r
F P
0 g
s
.65785 .79141 m .66318 .82222 L .68647 .80685 L p .707 .577 .707 r
F P
0 g
s
.68647 .80685 m .68114 .77604 L .65785 .79141 L p .707 .577 .707 r
F P
0 g
s
.5144 .72357 m .5182 .66633 L .50547 .66239 L p .707 .577 .707 r
F P
0 g
s
.5345 .82667 m .53601 .80755 L .51484 .80413 L p .707 .577 .707 r
F P
0 g
s
.50547 .66239 m .50168 .71964 L .5144 .72357 L p .707 .577 .707 r
F P
0 g
s
.51484 .80413 m .51332 .82325 L .5345 .82667 L p .707 .577 .707 r
F P
0 g
s
.54433 .83275 m .539 .80195 L .51755 .79054 L p .707 .577 .707 r
F P
0 g
s
.539 .80195 m .54433 .83275 L .57192 .83885 L p .707 .577 .707 r
F P
0 g
s
.68114 .77604 m .68647 .80685 L .70199 .78871 L p .707 .577 .707 r
F P
0 g
s
.70199 .78871 m .69666 .7579 L .68114 .77604 L p .707 .577 .707 r
F P
0 g
s
.69904 .67633 m .69524 .73358 L .70214 .73072 L p .707 .577 .707 r
F P
0 g
s
.70214 .73072 m .70593 .67347 L .69904 .67633 L p .707 .577 .707 r
F P
0 g
s
.67936 .81777 m .67785 .83689 L .69396 .83613 L p .707 .577 .707 r
F P
0 g
s
.69396 .83613 m .69547 .81701 L .67936 .81777 L p .707 .577 .707 r
F P
0 g
s
.50168 .71964 m .50547 .66239 L .50241 .65882 L p .707 .577 .707 r
F P
0 g
s
.51332 .82325 m .51484 .80413 L .50205 .80098 L p .707 .577 .707 r
F P
0 g
s
.50205 .80098 m .50054 .8201 L .51332 .82325 L p .707 .577 .707 r
F P
0 g
s
.52288 .82134 m .51755 .79054 L .50436 .77494 L p .707 .577 .707 r
F P
0 g
s
.51755 .79054 m .52288 .82134 L .54433 .83275 L p .707 .577 .707 r
F P
0 g
s
.50241 .65882 m .49861 .71607 L .50168 .71964 L p .707 .577 .707 r
F P
0 g
s
.69666 .7579 m .70199 .78871 L .70823 .76957 L p .707 .577 .707 r
F P
0 g
s
.70823 .76957 m .7029 .73876 L .69666 .7579 L p .707 .577 .707 r
F P
0 g
s
.69547 .81701 m .69396 .83613 L .70077 .83437 L p .707 .577 .707 r
F P
0 g
s
.70077 .83437 m .70228 .81525 L .69547 .81701 L p .707 .577 .707 r
F P
0 g
s
.70115 .72957 m .69907 .72715 L p .69965 .72263 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69924 .72049 L .69988 .72369 L p .708 .578 .707 r
F P
0 g
s
.70287 .6699 m .70593 .67347 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .69944 .72164 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .70287 .6699 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .68635 .72322 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69924 .72049 m .69944 .72164 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69907 .72715 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69924 .72049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68635 .72322 m .68714 .71125 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .68714 .71125 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .68604 .7049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .70287 .6699 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .69014 .66597 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.70287 .6699 m .69944 .72164 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .69889 .72118 L .69944 .72164 L .707 .577 .707 r
F
.69944 .72164 m .70457 .7513 L .69427 .73913 L p F P
0 g
s
.69427 .73913 m .69137 .7357 L p .69944 .72164 L .707 .577 .707 r
F P
0 g
s
.70457 .7513 m .69944 .72164 L p .7029 .73876 L .708 .578 .707 r
F P
0 g
s
.69988 .72369 m .7029 .73876 L p .69944 .72164 L .708 .578 .707 r
F P
0 g
s
.70593 .67347 m .70214 .73072 L .70115 .72957 L p .707 .577 .707 r
F P
0 g
s
.69965 .72263 m .70593 .67347 L .70115 .72957 L .707 .577 .707 r
F
.49394 .82294 m .48875 .32471 L .44474 .32221 L p F P
0 g
s
.50436 .77494 m .50968 .80575 L .52288 .82134 L p .707 .577 .707 r
F P
0 g
s
.50968 .80575 m .50436 .77494 L .5007 .75668 L p .708 .578 .707 r
F P
0 g
s
.50054 .8201 m .50205 .80098 L .49892 .7984 L p .707 .577 .707 r
F P
0 g
s
.49892 .7984 m .49741 .81752 L .50054 .8201 L p .707 .577 .707 r
F P
0 g
s
.49861 .71607 m .50241 .65882 L .5093 .65596 L p .707 .577 .707 r
F P
0 g
s
.5093 .65596 m .50551 .71321 L .49861 .71607 L p .707 .577 .707 r
F P
0 g
s
.5007 .75668 m .50602 .78748 L .50968 .80575 L p .708 .578 .707 r
F P
0 g
s
.50602 .78748 m .5007 .75668 L .50693 .73753 L p .707 .577 .707 r
F P
0 g
s
.49741 .81752 m .49892 .7984 L .50574 .79664 L p .707 .577 .707 r
F P
0 g
s
.50551 .71321 m .5093 .65596 L .52549 .65411 L p .707 .577 .707 r
F P
0 g
s
.50574 .79664 m .50423 .81576 L .49741 .81752 L p .707 .577 .707 r
F P
0 g
s
.52549 .65411 m .52169 .71136 L .50551 .71321 L p .707 .577 .707 r
F P
0 g
s
.50693 .73753 m .51226 .76834 L .50602 .78748 L p .707 .577 .707 r
F P
0 g
s
.51226 .76834 m .50693 .73753 L .52246 .71939 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .52549 .65411 L .54937 .65343 L p .707 .577 .707 r
F P
0 g
s
.50423 .81576 m .50574 .79664 L .52184 .79588 L p .707 .577 .707 r
F P
0 g
s
.52184 .79588 m .52033 .81501 L .50423 .81576 L p .707 .577 .707 r
F P
0 g
s
.54167 .70671 m .54575 .70402 L p .54519 .70544 L .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .57452 .69293 L p .57038 .70032 L .707 .577 .707 r
F P
0 g
s
.5469 .70498 m .54575 .70402 L .57038 .70032 L .707 .577 .707 r
F
.54937 .65343 m .57862 .654 L p .54916 .70453 L F P
0 g
s
.54558 .71068 m .54594 .70517 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .54575 .70402 L p .5469 .70498 L .707 .577 .707 r
F P
0 g
s
.57483 .71125 m .54558 .71068 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .5469 .70498 L .56118 .71677 L .707 .577 .707 r
F
.57452 .69293 m .60597 .6872 L p .59855 .69757 L F P
0 g
s
.58137 .69885 m .57452 .69293 L .59855 .69757 L .707 .577 .707 r
F
.57862 .654 m .61037 .65575 L p .58284 .69874 L F P
0 g
s
.57483 .71125 m .57562 .69928 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .57452 .69293 L p .58137 .69885 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .57483 .71125 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .58137 .69885 L .59142 .70755 L .707 .577 .707 r
F
.63772 .71578 m .60658 .713 L p .61666 .69728 L F P
0 g
s
.60597 .6872 m .63701 .68739 L p .62828 .69778 L .707 .577 .707 r
F P
0 g
s
.6154 .69723 m .60597 .6872 L .62828 .69778 L .707 .577 .707 r
F
.66521 .71929 m .63772 .71578 L p .64707 .69972 L F P
0 g
s
.63701 .68739 m .6646 .69349 L p .65732 .70157 L .707 .577 .707 r
F P
0 g
s
.64643 .6996 m .63701 .68739 L .65732 .70157 L .707 .577 .707 r
F
.68635 .72322 m .66521 .71929 L p .67175 .7053 L F P
0 g
s
.6646 .69349 m .68604 .7049 L p .68231 .70939 L .707 .577 .707 r
F P
0 g
s
.67212 .70545 m .6646 .69349 L .68231 .70939 L .707 .577 .707 r
F
.68714 .71125 m .68635 .72322 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .6646 .69349 L p .67212 .70545 L .707 .577 .707 r
F P
0 g
s
.66521 .71929 m .66628 .70319 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.66628 .70319 m .67212 .70545 L .67792 .71467 L .707 .577 .707 r
F
.669 .66205 m .69014 .66597 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .669 .66205 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69137 .7357 L .66993 .7243 L p .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .68714 .71125 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.67792 .71467 m .67212 .70545 L .68231 .70939 L .707 .577 .707 r
F
.66993 .7243 m .66628 .70319 L p .67792 .71467 L F P
0 g
s
.66628 .70319 m .66521 .71929 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.6646 .69349 m .66993 .7243 L .64233 .7182 L p .707 .577 .707 r
F P
0 g
s
.64707 .69972 m .65279 .68989 L .66628 .70319 L .707 .577 .707 r
F
.669 .66205 m .66628 .70319 L p .65279 .68989 L F P
0 g
s
.64152 .65853 m .669 .66205 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63772 .71578 m .63888 .69824 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .63701 .68739 L p .64643 .6996 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64152 .65853 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64643 .6996 L .65227 .70717 L .707 .577 .707 r
F
.65227 .70717 m .64643 .6996 L .65732 .70157 L F
.64233 .7182 m .63888 .69824 L p .65227 .70717 L F P
0 g
s
.63888 .69824 m .63772 .71578 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.63701 .68739 m .64233 .7182 L .6113 .718 L p .707 .577 .707 r
F P
0 g
s
.61666 .69728 m .62289 .68757 L .63888 .69824 L .707 .577 .707 r
F
.64152 .65853 m .63888 .69824 L p .62289 .68757 L F P
0 g
s
.61037 .65575 m .64152 .65853 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .60765 .6969 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .60597 .6872 L p .6154 .69723 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .61037 .65575 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .6154 .69723 L .62245 .70473 L .707 .577 .707 r
F
.62245 .70473 m .6154 .69723 L .62828 .69778 L F
.6113 .718 m .60765 .6969 L p .62245 .70473 L F P
0 g
s
.60765 .6969 m .60658 .713 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.60597 .6872 m .6113 .718 L .57985 .72373 L p .707 .577 .707 r
F P
0 g
s
.58284 .69874 m .59 .68756 L .60765 .6969 L .707 .577 .707 r
F
.61037 .65575 m .60765 .6969 L p .59 .68756 L F P
0 g
s
.57562 .69928 m .57862 .654 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.59142 .70755 m .58137 .69885 L .59855 .69757 L .707 .577 .707 r
F
.57985 .72373 m .57562 .69928 L p .59142 .70755 L F P
0 g
s
.57562 .69928 m .57483 .71125 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.57452 .69293 m .57985 .72373 L .55107 .73483 L p .707 .577 .707 r
F P
0 g
s
.54916 .70453 m .55769 .6899 L .57562 .69928 L .707 .577 .707 r
F
.57862 .654 m .57562 .69928 L p .55769 .6899 L F P
0 g
s
.54594 .70517 m .54937 .65343 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.56118 .71677 m .5469 .70498 L .57038 .70032 L .707 .577 .707 r
F
.55107 .73483 m .54594 .70517 L p .56118 .71677 L F P
0 g
s
.54594 .70517 m .54558 .71068 L .52939 .71114 L p .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .55107 .73483 L .52778 .7502 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .53033 .69328 L .54594 .70517 L .707 .577 .707 r
F
.54937 .65343 m .54594 .70517 L p .53033 .69328 L F P
0 g
s
.52939 .71114 m .52169 .71136 L p .54594 .70517 L .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .52246 .71939 L .54167 .70671 L p .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .54167 .70671 L .54519 .70544 L .707 .577 .707 r
F
.52246 .71939 m .52778 .7502 L .51226 .76834 L p F P
0 g
s
.52033 .81501 m .52184 .79588 L .54565 .7962 L p .707 .577 .707 r
F P
0 g
s
.54565 .7962 m .54414 .81532 L .52033 .81501 L p .707 .577 .707 r
F P
0 g
s
.48875 .32471 m .49394 .82294 L .53888 .82132 L p .707 .577 .707 r
F P
0 g
s
.53888 .82132 m .53369 .32309 L .48875 .32471 L p .707 .577 .707 r
F P
0 g
s
.54414 .81532 m .54565 .7962 L .57485 .79755 L p .707 .577 .707 r
F P
0 g
s
.57485 .79755 m .57334 .81667 L .54414 .81532 L p .707 .577 .707 r
F P
0 g
s
.57334 .81667 m .57485 .79755 L .60656 .79981 L p .707 .577 .707 r
F P
0 g
s
.60656 .79981 m .60505 .81893 L .57334 .81667 L p .707 .577 .707 r
F P
0 g
s
.53369 .32309 m .53888 .82132 L .58036 .81572 L p .707 .577 .707 r
F P
0 g
s
.58036 .81572 m .57517 .3175 L .53369 .32309 L p .707 .577 .707 r
F P
0 g
s
.7029 .73876 m .70823 .76957 L .70457 .7513 L p .708 .578 .707 r
F P
0 g
s
.44993 .82044 m .44474 .32221 L .40598 .31583 L p .707 .577 .707 r
F P
0 g
s
.44474 .32221 m .44993 .82044 L .49394 .82294 L p .707 .577 .707 r
F P
0 g
s
.60505 .81893 m .60656 .79981 L .63769 .80276 L p .707 .577 .707 r
F P
0 g
s
.57517 .3175 m .58036 .81572 L .61431 .80671 L p .707 .577 .707 r
F P
0 g
s
.61431 .80671 m .60912 .30849 L .57517 .3175 L p .707 .577 .707 r
F P
0 g
s
.70228 .81525 m .70077 .83437 L .69764 .83179 L p .707 .577 .707 r
F P
0 g
s
.69764 .83179 m .69915 .81267 L .70228 .81525 L p .707 .577 .707 r
F P
0 g
s
.41117 .81406 m .40598 .31583 L .37625 .30619 L p .707 .577 .707 r
F P
0 g
s
.40598 .31583 m .41117 .81406 L .44993 .82044 L p .707 .577 .707 r
F P
0 g
s
.25116 .69697 m .25496 .63972 L .22381 .63695 L p .707 .577 .707 r
F P
0 g
s
.25496 .63972 m .25116 .69697 L .28291 .69873 L p .707 .577 .707 r
F P
0 g
s
.28291 .69873 m .28671 .64148 L .25496 .63972 L p .707 .577 .707 r
F P
0 g
s
.28671 .64148 m .28291 .69873 L .31216 .6993 L p .707 .577 .707 r
F P
0 g
s
.31216 .6993 m .31596 .64205 L .28671 .64148 L p .707 .577 .707 r
F P
0 g
s
.22381 .63695 m .22002 .6942 L .25116 .69697 L p .707 .577 .707 r
F P
0 g
s
.22002 .6942 m .22381 .63695 L .19633 .63343 L p .707 .577 .707 r
F P
0 g
s
.19633 .63343 m .19253 .69068 L .22002 .6942 L p .707 .577 .707 r
F P
0 g
s
.60912 .30849 m .61431 .80671 L .63741 .79516 L p .707 .577 .707 r
F P
0 g
s
.63741 .79516 m .63222 .29694 L .60912 .30849 L p .707 .577 .707 r
F P
0 g
s
.31596 .64205 m .31216 .6993 L .33605 .69862 L p .707 .577 .707 r
F P
0 g
s
.33605 .69862 m .33984 .64137 L .31596 .64205 L p .707 .577 .707 r
F P
0 g
s
.19253 .69068 m .19633 .63343 L .17519 .62951 L p .707 .577 .707 r
F P
0 g
s
.69915 .81267 m .69764 .83179 L .68486 .82864 L p .707 .577 .707 r
F P
0 g
s
.68486 .82864 m .68637 .80952 L .69915 .81267 L p .707 .577 .707 r
F P
0 g
s
.17519 .62951 m .17139 .68676 L .19253 .69068 L p .707 .577 .707 r
F P
0 g
s
.25012 .79615 m .25163 .77702 L .2205 .77408 L p .707 .577 .707 r
F P
0 g
s
.25163 .77702 m .25012 .79615 L .28184 .79841 L p .707 .577 .707 r
F P
0 g
s
.28184 .79841 m .28335 .77929 L .25163 .77702 L p .707 .577 .707 r
F P
0 g
s
.38144 .80442 m .37625 .30619 L .35847 .29424 L p .707 .577 .707 r
F P
0 g
s
.37625 .30619 m .38144 .80442 L .41117 .81406 L p .707 .577 .707 r
F P
0 g
s
.2205 .77408 m .21899 .7932 L .25012 .79615 L p .707 .577 .707 r
F P
0 g
s
.28335 .77929 m .28184 .79841 L .31103 .79976 L p .707 .577 .707 r
F P
0 g
s
.31103 .79976 m .31254 .78064 L .28335 .77929 L p .707 .577 .707 r
F P
0 g
s
.25995 .80223 m .25462 .77142 L .22358 .77123 L p .707 .577 .707 r
F P
0 g
s
.25462 .77142 m .25995 .80223 L .29139 .7965 L p .707 .577 .707 r
F P
0 g
s
.29139 .7965 m .28607 .76569 L .25462 .77142 L p .707 .577 .707 r
F P
0 g
s
.31254 .78064 m .31103 .79976 L .33484 .80007 L p .707 .577 .707 r
F P
0 g
s
.33484 .80007 m .33635 .78095 L .31254 .78064 L p .707 .577 .707 r
F P
0 g
s
.28607 .76569 m .29139 .7965 L .32017 .78541 L p .707 .577 .707 r
F P
0 g
s
.32017 .78541 m .31484 .7546 L .28607 .76569 L p .707 .577 .707 r
F P
0 g
s
.21899 .7932 m .2205 .77408 L .193 .77073 L p .707 .577 .707 r
F P
0 g
s
.33984 .64137 m .33605 .69862 L .35223 .69676 L p .707 .577 .707 r
F P
0 g
s
.35223 .69676 m .35603 .63951 L .33984 .64137 L p .707 .577 .707 r
F P
0 g
s
.193 .77073 m .19149 .78985 L .21899 .7932 L p .707 .577 .707 r
F P
0 g
s
.22891 .80204 m .22358 .77123 L .19599 .76513 L p .707 .577 .707 r
F P
0 g
s
.22358 .77123 m .22891 .80204 L .25995 .80223 L p .707 .577 .707 r
F P
0 g
s
.31484 .7546 m .32017 .78541 L .34346 .77003 L p .707 .577 .707 r
F P
0 g
s
.34346 .77003 m .33813 .73923 L .31484 .7546 L p .707 .577 .707 r
F P
0 g
s
.17139 .68676 m .17519 .62951 L .16246 .62557 L p .707 .577 .707 r
F P
0 g
s
.19149 .78985 m .193 .77073 L .17183 .76732 L p .707 .577 .707 r
F P
0 g
s
.16246 .62557 m .15867 .68282 L .17139 .68676 L p .707 .577 .707 r
F P
0 g
s
.63222 .29694 m .63741 .79516 L .64741 .78221 L p .707 .577 .707 r
F P
0 g
s
.64741 .78221 m .64222 .28398 L .63222 .29694 L p .707 .577 .707 r
F P
0 g
s
.17183 .76732 m .17032 .78644 L .19149 .78985 L p .707 .577 .707 r
F P
0 g
s
.68637 .80952 m .68486 .82864 L .66368 .82522 L p .707 .577 .707 r
F P
0 g
s
.66368 .82522 m .66519 .8061 L .68637 .80952 L p .707 .577 .707 r
F P
0 g
s
.20132 .79594 m .19599 .76513 L .17454 .75372 L p .707 .577 .707 r
F P
0 g
s
.19599 .76513 m .20132 .79594 L .22891 .80204 L p .707 .577 .707 r
F P
0 g
s
.33813 .73923 m .34346 .77003 L .35898 .75189 L p .707 .577 .707 r
F P
0 g
s
.35898 .75189 m .35366 .72108 L .33813 .73923 L p .707 .577 .707 r
F P
0 g
s
.35603 .63951 m .35223 .69676 L .35913 .69391 L p .707 .577 .707 r
F P
0 g
s
.35913 .69391 m .36292 .63666 L .35603 .63951 L p .707 .577 .707 r
F P
0 g
s
.33635 .78095 m .33484 .80007 L .35095 .79931 L p .707 .577 .707 r
F P
0 g
s
.35095 .79931 m .35246 .78019 L .33635 .78095 L p .707 .577 .707 r
F P
0 g
s
.35366 .72108 m .35898 .75189 L .36522 .73275 L p .707 .577 .707 r
F P
0 g
s
.36522 .73275 m .35989 .70194 L .35366 .72108 L p .707 .577 .707 r
F P
0 g
s
.36292 .63666 m .35913 .69391 L .35814 .69276 L p .707 .577 .707 r
F P
0 g
s
.35814 .69276 m .35607 .69034 L p .35664 .68581 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35623 .68368 L .35687 .68687 L p .708 .578 .707 r
F P
0 g
s
.35664 .68581 m .36292 .63666 L .35814 .69276 L .707 .577 .707 r
F
.35986 .63309 m .36292 .63666 L p .35703 .68281 L F P
0 g
s
.35607 .69034 m .35643 .68483 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35986 .63309 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35607 .69034 m .34334 .6864 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35623 .68368 m .35643 .68483 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35607 .69034 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .35623 .68368 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .34413 .67444 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .34413 .67444 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34303 .66808 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .35986 .63309 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34714 .62915 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35986 .63309 m .35643 .68483 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .35588 .68436 L .35643 .68483 L .707 .577 .707 r
F
.35643 .68483 m .36156 .71449 L .35126 .70231 L p F P
0 g
s
.35126 .70231 m .34836 .69889 L p .35643 .68483 L .707 .577 .707 r
F P
0 g
s
.36156 .71449 m .35643 .68483 L p .35989 .70194 L .708 .578 .707 r
F P
0 g
s
.35687 .68687 m .35989 .70194 L p .35643 .68483 L .708 .578 .707 r
F P
0 g
s
.35989 .70194 m .36522 .73275 L .36156 .71449 L p .708 .578 .707 r
F P
0 g
s
.36366 .79247 m .35847 .29424 L .35437 .28114 L p .707 .577 .707 r
F P
0 g
s
.35847 .29424 m .36366 .79247 L .38144 .80442 L p .707 .577 .707 r
F P
0 g
s
.15867 .68282 m .16246 .62557 L .1594 .622 L p .707 .577 .707 r
F P
0 g
s
.17032 .78644 m .17183 .76732 L .15904 .76416 L p .707 .577 .707 r
F P
0 g
s
.15904 .76416 m .15753 .78328 L .17032 .78644 L p .707 .577 .707 r
F P
0 g
s
.66519 .8061 m .66368 .82522 L .63618 .82188 L p .707 .577 .707 r
F P
0 g
s
.63618 .82188 m .63769 .80276 L .66519 .8061 L p .707 .577 .707 r
F P
0 g
s
.17987 .78453 m .17454 .75372 L .16135 .73812 L p .707 .577 .707 r
F P
0 g
s
.17454 .75372 m .17987 .78453 L .20132 .79594 L p .707 .577 .707 r
F P
0 g
s
.1594 .622 m .1556 .67925 L .15867 .68282 L p .707 .577 .707 r
F P
0 g
s
.63769 .80276 m .63618 .82188 L .60505 .81893 L p .707 .577 .707 r
F P
0 g
s
.64222 .28398 m .64741 .78221 L .64656 .77951 L p .707 .577 .707 r
F P
0 g
s
.64318 .71089 m .64222 .28398 L .64656 .77951 L .707 .577 .707 r
F
.63812 .27089 m .64222 .28398 L p .64301 .63495 L F P
0 g
s
.64331 .76673 m .64189 .63242 L .64301 .63495 L .707 .577 .707 r
F
.64328 .7663 m .64189 .63242 L p .64331 .76673 L F P
0 g
s
.64656 .77951 m .64347 .76961 L p .64318 .71089 L .707 .577 .707 r
F P
0 g
s
.64347 .76961 m .64331 .76911 L p .64331 .76673 L .707 .577 .707 r
F P
0 g
s
.64331 .76673 m .64318 .71089 L .64347 .76961 L .707 .577 .707 r
F
.63812 .27089 m .64331 .76911 L .62553 .75716 L p F P
0 g
s
.63926 .71042 m .63775 .72954 L .64129 .73041 L p .707 .577 .707 r
F P
0 g
s
.64129 .73041 m .65053 .73269 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.6403 .71247 m .63926 .71042 L .64129 .73041 L .707 .577 .707 r
F
.65053 .73269 m .65204 .71357 L .6402 .71065 L p F P
0 g
s
.6402 .71065 m .63926 .71042 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.65053 .73269 m .6402 .71065 L .6403 .71247 L .707 .577 .707 r
F
.64331 .76911 m .64328 .7663 L p .64331 .76673 L F P
0 g
s
.64189 .63242 m .63812 .27089 L p .64301 .63495 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63961 .56678 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63888 .6276 m .63899 .62589 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .64267 .57035 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63899 .62589 L p .6516 .63154 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .63888 .6276 L .63908 .62766 L p .707 .577 .707 r
F P
0 g
s
.63908 .62766 m .6516 .63154 L p .63899 .62589 L .707 .577 .707 r
F P
0 g
s
.35246 .78019 m .35095 .79931 L .35777 .79756 L p .707 .577 .707 r
F P
0 g
s
.35777 .79756 m .35928 .77844 L .35246 .78019 L p .707 .577 .707 r
F P
0 g
s
.16135 .73812 m .16667 .76893 L .17987 .78453 L p .707 .577 .707 r
F P
0 g
s
.16667 .76893 m .16135 .73812 L .15769 .71986 L p .708 .578 .707 r
F P
0 g
s
.15753 .78328 m .15904 .76416 L .15591 .76158 L p .707 .577 .707 r
F P
0 g
s
.15591 .76158 m .1544 .7807 L .15753 .78328 L p .707 .577 .707 r
F P
0 g
s
.1556 .67925 m .1594 .622 L .16629 .61915 L p .707 .577 .707 r
F P
0 g
s
.16629 .61915 m .1625 .6764 L .1556 .67925 L p .707 .577 .707 r
F P
0 g
s
.35437 .28114 m .35956 .77937 L .36366 .79247 L p .707 .577 .707 r
F P
0 g
s
.35956 .77937 m .35437 .28114 L .36437 .26819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35928 .77844 m .35777 .79756 L .35463 .79498 L p .707 .577 .707 r
F P
0 g
s
.35463 .79498 m .35614 .77586 L .35928 .77844 L p .707 .577 .707 r
F P
0 g
s
.15769 .71986 m .16301 .75067 L .16667 .76893 L p .708 .578 .707 r
F P
0 g
s
.16301 .75067 m .15769 .71986 L .16392 .70072 L p .707 .577 .707 r
F P
0 g
s
.1544 .7807 m .15591 .76158 L .16273 .75983 L p .707 .577 .707 r
F P
0 g
s
.62553 .75716 m .62034 .25893 L .63812 .27089 L p .707 .577 .707 r
F P
0 g
s
.1625 .6764 m .16629 .61915 L .18248 .61729 L p .707 .577 .707 r
F P
0 g
s
.16273 .75983 m .16122 .77895 L .1544 .7807 L p .707 .577 .707 r
F P
0 g
s
.18248 .61729 m .17868 .67454 L .1625 .6764 L p .707 .577 .707 r
F P
0 g
s
.16392 .70072 m .16925 .73153 L .16301 .75067 L p .707 .577 .707 r
F P
0 g
s
.16925 .73153 m .16392 .70072 L .17945 .68258 L p .707 .577 .707 r
F P
0 g
s
.36956 .76641 m .36437 .26819 L .38747 .25664 L p .707 .577 .707 r
F P
0 g
s
.36437 .26819 m .36956 .76641 L .35956 .77937 L p .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .3222 .68248 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34334 .6864 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .32692 .68748 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .34413 .67444 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34836 .69889 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32159 .65667 m .34303 .66808 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.3222 .68248 m .32327 .66637 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32692 .68748 m .32327 .66637 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32159 .65667 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .34714 .62915 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32599 .62523 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .34413 .67444 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.35614 .77586 m .35463 .79498 L .34185 .79182 L p .707 .577 .707 r
F P
0 g
s
.34185 .79182 m .34336 .7727 L .35614 .77586 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18248 .61729 L .20636 .61661 L p .707 .577 .707 r
F P
0 g
s
.16122 .77895 m .16273 .75983 L .17883 .75907 L p .707 .577 .707 r
F P
0 g
s
.17883 .75907 m .17732 .77819 L .16122 .77895 L p .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20257 .67386 L .18638 .67432 L p .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .17945 .68258 L .19866 .66989 L p .707 .577 .707 r
F P
0 g
s
.19866 .66989 m .20274 .6672 L p .20218 .66862 L .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .19866 .66989 L .20218 .66862 L .707 .577 .707 r
F
.20274 .6672 m .23151 .65611 L p .22737 .6635 L F P
0 g
s
.20389 .66816 m .20274 .6672 L .22737 .6635 L .707 .577 .707 r
F
.20636 .61661 m .23561 .61718 L p .20615 .66771 L F P
0 g
s
.20257 .67386 m .20293 .66835 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20274 .6672 L p .20389 .66816 L .707 .577 .707 r
F P
0 g
s
.23182 .67443 m .20257 .67386 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20389 .66816 L .21817 .67995 L .707 .577 .707 r
F
.23151 .65611 m .26296 .65038 L p .25554 .66076 L F P
0 g
s
.23836 .66204 m .23151 .65611 L .25554 .66076 L .707 .577 .707 r
F
.23561 .61718 m .26736 .61894 L p .23983 .66193 L F P
0 g
s
.23182 .67443 m .23261 .66247 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23151 .65611 L p .23836 .66204 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .23182 .67443 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23836 .66204 L .24841 .67073 L .707 .577 .707 r
F
.29471 .67896 m .26357 .67619 L p .27365 .66047 L F P
0 g
s
.26296 .65038 m .294 .65057 L p .28527 .66097 L .707 .577 .707 r
F P
0 g
s
.27239 .66041 m .26296 .65038 L .28527 .66097 L .707 .577 .707 r
F
.3222 .68248 m .29471 .67896 L p .30406 .6629 L F P
0 g
s
.294 .65057 m .32159 .65667 L p .31431 .66475 L .707 .577 .707 r
F P
0 g
s
.30342 .66279 m .294 .65057 L .31431 .66475 L .707 .577 .707 r
F
.32327 .66637 m .3222 .68248 L p .30406 .6629 L F P
0 g
s
.32159 .65667 m .32692 .68748 L .29933 .68138 L p .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .32327 .66637 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29851 .62171 m .32599 .62523 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29471 .67896 m .29587 .66143 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .294 .65057 L p .30342 .66279 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .29851 .62171 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .30342 .66279 L .30926 .67036 L .707 .577 .707 r
F
.30926 .67036 m .30342 .66279 L .31431 .66475 L F
.29933 .68138 m .29587 .66143 L p .30926 .67036 L F P
0 g
s
.29587 .66143 m .29471 .67896 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.294 .65057 m .29933 .68138 L .26829 .68119 L p .707 .577 .707 r
F P
0 g
s
.27365 .66047 m .27988 .65075 L .29587 .66143 L .707 .577 .707 r
F
.29851 .62171 m .29587 .66143 L p .27988 .65075 L F P
0 g
s
.26736 .61894 m .29851 .62171 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .26464 .66008 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26296 .65038 L p .27239 .66041 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26736 .61894 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .27239 .66041 L .27944 .66791 L .707 .577 .707 r
F
.27944 .66791 m .27239 .66041 L .28527 .66097 L F
.26829 .68119 m .26464 .66008 L p .27944 .66791 L F P
0 g
s
.26464 .66008 m .26357 .67619 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.26296 .65038 m .26829 .68119 L .23684 .68692 L p .707 .577 .707 r
F P
0 g
s
.23983 .66193 m .24699 .65074 L .26464 .66008 L .707 .577 .707 r
F
.26736 .61894 m .26464 .66008 L p .24699 .65074 L F P
0 g
s
.23261 .66247 m .23561 .61718 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.24841 .67073 m .23836 .66204 L .25554 .66076 L .707 .577 .707 r
F
.23684 .68692 m .23261 .66247 L p .24841 .67073 L F P
0 g
s
.23261 .66247 m .23182 .67443 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.23151 .65611 m .23684 .68692 L .20806 .69801 L p .707 .577 .707 r
F P
0 g
s
.20615 .66771 m .21468 .65308 L .23261 .66247 L .707 .577 .707 r
F
.23561 .61718 m .23261 .66247 L p .21468 .65308 L F P
0 g
s
.20293 .66835 m .20636 .61661 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.21817 .67995 m .20389 .66816 L .22737 .6635 L .707 .577 .707 r
F
.20806 .69801 m .20293 .66835 L p .21817 .67995 L F P
0 g
s
.20274 .6672 m .20806 .69801 L .18477 .71338 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18732 .65647 L .20293 .66835 L .707 .577 .707 r
F
.20636 .61661 m .20293 .66835 L p .18732 .65647 L F P
0 g
s
.18638 .67432 m .17868 .67454 L p .20293 .66835 L .707 .577 .707 r
F P
0 g
s
.17945 .68258 m .18477 .71338 L .16925 .73153 L p .707 .577 .707 r
F P
0 g
s
.62034 .25893 m .62553 .75716 L .5958 .74752 L p .707 .577 .707 r
F P
0 g
s
.5958 .74752 m .59061 .24929 L .62034 .25893 L p .707 .577 .707 r
F P
0 g
s
.34336 .7727 m .34185 .79182 L .32067 .78841 L p .707 .577 .707 r
F P
0 g
s
.32067 .78841 m .32218 .76929 L .34336 .7727 L p .707 .577 .707 r
F P
0 g
s
.38747 .25664 m .39266 .75487 L .36956 .76641 L p .707 .577 .707 r
F P
0 g
s
.39266 .75487 m .38747 .25664 L .42142 .24763 L p .707 .577 .707 r
F P
0 g
s
.17732 .77819 m .17883 .75907 L .20264 .75938 L p .707 .577 .707 r
F P
0 g
s
.20264 .75938 m .20113 .7785 L .17732 .77819 L p .707 .577 .707 r
F P
0 g
s
.73138 .64175 m .73517 .5845 L .70403 .58173 L p .707 .577 .707 r
F P
0 g
s
.73517 .5845 m .73138 .64175 L .76313 .64351 L p .707 .577 .707 r
F P
0 g
s
.76313 .64351 m .76692 .58626 L .73517 .5845 L p .707 .577 .707 r
F P
0 g
s
.76692 .58626 m .76313 .64351 L .79238 .64407 L p .707 .577 .707 r
F P
0 g
s
.79238 .64407 m .79617 .58682 L .76692 .58626 L p .707 .577 .707 r
F P
0 g
s
.70403 .58173 m .70023 .63898 L .73138 .64175 L p .707 .577 .707 r
F P
0 g
s
.70023 .63898 m .70403 .58173 L .67654 .57821 L p .707 .577 .707 r
F P
0 g
s
.59061 .24929 m .5958 .74752 L .55704 .74114 L p .707 .577 .707 r
F P
0 g
s
.55704 .74114 m .55185 .24291 L .59061 .24929 L p .707 .577 .707 r
F P
0 g
s
.32218 .76929 m .32067 .78841 L .29317 .78506 L p .707 .577 .707 r
F P
0 g
s
.29317 .78506 m .29468 .76594 L .32218 .76929 L p .707 .577 .707 r
F P
0 g
s
.67654 .57821 m .67275 .63546 L .70023 .63898 L p .707 .577 .707 r
F P
0 g
s
.79617 .58682 m .79238 .64407 L .81626 .6434 L p .707 .577 .707 r
F P
0 g
s
.81626 .6434 m .82006 .58615 L .79617 .58682 L p .707 .577 .707 r
F P
0 g
s
.20113 .7785 m .20264 .75938 L .23184 .76073 L p .707 .577 .707 r
F P
0 g
s
.23184 .76073 m .23033 .77986 L .20113 .7785 L p .707 .577 .707 r
F P
0 g
s
.67275 .63546 m .67654 .57821 L .6554 .57429 L p .707 .577 .707 r
F P
0 g
s
.42661 .74585 m .42142 .24763 L .4629 .24203 L p .707 .577 .707 r
F P
0 g
s
.42142 .24763 m .42588 .67541 L p .39266 .75487 L .707 .577 .707 r
F P
0 g
s
.4629 .24203 m .46809 .74026 L .42661 .74585 L p .707 .577 .707 r
F P
0 g
s
.42391 .54944 m .42012 .60669 L .4489 .60725 L p .707 .577 .707 r
F P
0 g
s
.4489 .60725 m .44937 .60726 L p .4491 .60666 L .707 .577 .707 r
F P
0 g
s
.4491 .60666 m .42391 .54944 L .4489 .60725 L .707 .577 .707 r
F
.42588 .67541 m .42658 .74304 L p .39966 .75301 L F P
0 g
s
.39966 .75301 m .39266 .75487 L p .42588 .67541 L .707 .577 .707 r
F P
0 g
s
.42055 .68872 m .41904 .70784 L .44014 .70882 L p .707 .577 .707 r
F P
0 g
s
.44014 .70882 m .44823 .7092 L p .44185 .70448 L .707 .577 .707 r
F P
0 g
s
.44185 .70448 m .42055 .68872 L .44014 .70882 L .707 .577 .707 r
F
.42658 .74304 m .42661 .74585 L .42533 .74619 L p F P
0 g
s
.42533 .74619 m .39966 .75301 L p .42658 .74304 L .707 .577 .707 r
F P
0 g
s
.29468 .76594 m .29317 .78506 L .26204 .78212 L p .707 .577 .707 r
F P
0 g
s
.26204 .78212 m .26355 .76299 L .29468 .76594 L p .707 .577 .707 r
F P
0 g
s
.6554 .57429 m .6516 .63154 L .67275 .63546 L p .707 .577 .707 r
F P
0 g
s
.73034 .7424 m .73185 .72328 L .70072 .72033 L p .707 .577 .707 r
F P
0 g
s
.73185 .72328 m .73034 .7424 L .76205 .74466 L p .707 .577 .707 r
F P
0 g
s
.76205 .74466 m .76356 .72554 L .73185 .72328 L p .707 .577 .707 r
F P
0 g
s
.70072 .72033 m .69921 .73945 L .73034 .7424 L p .707 .577 .707 r
F P
0 g
s
.23033 .77986 m .23184 .76073 L .26355 .76299 L p .707 .577 .707 r
F P
0 g
s
.26355 .76299 m .26204 .78212 L .23033 .77986 L p .707 .577 .707 r
F P
0 g
s
.76356 .72554 m .76205 .74466 L .79124 .74601 L p .707 .577 .707 r
F P
0 g
s
.79124 .74601 m .79275 .72689 L .76356 .72554 L p .707 .577 .707 r
F P
0 g
s
.55185 .24291 m .55704 .74114 L .51303 .73864 L p .707 .577 .707 r
F P
0 g
s
.51303 .73864 m .50784 .24041 L .55185 .24291 L p .707 .577 .707 r
F P
0 g
s
.74016 .74662 m .73483 .71581 L .70379 .71562 L p .707 .577 .707 r
F P
0 g
s
.73483 .71581 m .74016 .74662 L .77161 .74089 L p .707 .577 .707 r
F P
0 g
s
.77161 .74089 m .76628 .71008 L .73483 .71581 L p .707 .577 .707 r
F P
0 g
s
.79275 .72689 m .79124 .74601 L .81506 .74632 L p .707 .577 .707 r
F P
0 g
s
.81506 .74632 m .81657 .7272 L .79275 .72689 L p .707 .577 .707 r
F P
0 g
s
.76628 .71008 m .77161 .74089 L .80038 .7298 L p .707 .577 .707 r
F P
0 g
s
.80038 .7298 m .79506 .69899 L .76628 .71008 L p .707 .577 .707 r
F P
0 g
s
.69921 .73945 m .70072 .72033 L .67322 .71698 L p .707 .577 .707 r
F P
0 g
s
.82006 .58615 m .81626 .6434 L .83245 .64154 L p .707 .577 .707 r
F P
0 g
s
.83245 .64154 m .83624 .58429 L .82006 .58615 L p .707 .577 .707 r
F P
0 g
s
.67322 .71698 m .67171 .73611 L .69921 .73945 L p .707 .577 .707 r
F P
0 g
s
.46809 .74026 m .4629 .24203 L .50784 .24041 L p .707 .577 .707 r
F P
0 g
s
.50784 .24041 m .51303 .73864 L .46809 .74026 L p .707 .577 .707 r
F P
0 g
s
.70912 .74643 m .70379 .71562 L .6762 .70952 L p .707 .577 .707 r
F P
0 g
s
.70379 .71562 m .70912 .74643 L .74016 .74662 L p .707 .577 .707 r
F P
0 g
s
.79506 .69899 m .80038 .7298 L .82367 .71443 L p .707 .577 .707 r
F P
0 g
s
.82367 .71443 m .81835 .68362 L .79506 .69899 L p .707 .577 .707 r
F P
0 g
s
.6516 .63154 m .6554 .57429 L .64267 .57035 L p .707 .577 .707 r
F P
0 g
s
.67171 .73611 m .67322 .71698 L .65204 .71357 L p .707 .577 .707 r
F P
0 g
s
.65204 .71357 m .65053 .73269 L .67171 .73611 L p .707 .577 .707 r
F P
0 g
s
.68153 .74033 m .6762 .70952 L .65476 .69811 L p .707 .577 .707 r
F P
0 g
s
.6762 .70952 m .68153 .74033 L .70912 .74643 L p .707 .577 .707 r
F P
0 g
s
.81835 .68362 m .82367 .71443 L .8392 .69628 L p .707 .577 .707 r
F P
0 g
s
.8392 .69628 m .83387 .66548 L .81835 .68362 L p .707 .577 .707 r
F P
0 g
s
.83624 .58429 m .83245 .64154 L .83934 .63869 L p .707 .577 .707 r
F P
0 g
s
.83934 .63869 m .84314 .58144 L .83624 .58429 L p .707 .577 .707 r
F P
0 g
s
.81657 .7272 m .81506 .74632 L .83116 .74557 L p .707 .577 .707 r
F P
0 g
s
.83116 .74557 m .83267 .72644 L .81657 .7272 L p .707 .577 .707 r
F P
0 g
s
.66009 .72892 m .65476 .69811 L .64156 .68252 L p .707 .577 .707 r
F P
0 g
s
.65476 .69811 m .66009 .72892 L .68153 .74033 L p .707 .577 .707 r
F P
0 g
s
.83387 .66548 m .8392 .69628 L .84543 .67714 L p .707 .577 .707 r
F P
0 g
s
.84543 .67714 m .84011 .64634 L .83387 .66548 L p .707 .577 .707 r
F P
0 g
s
.63961 .56678 m .63582 .62403 L .63888 .6276 L p .707 .577 .707 r
F P
0 g
s
.83267 .72644 m .83116 .74557 L .83798 .74381 L p .707 .577 .707 r
F P
0 g
s
.83798 .74381 m .83949 .72469 L .83267 .72644 L p .707 .577 .707 r
F P
0 g
s
.83846 .63766 m .83628 .63512 L p .83689 .63036 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83645 .62807 L .83715 .63156 L p .708 .578 .707 r
F P
0 g
s
.84007 .57787 m .84314 .58144 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .83666 .62933 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .84007 .57787 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .82355 .63118 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.83645 .62807 m .83666 .62933 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83628 .63512 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .83645 .62807 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .82437 .61893 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .82437 .61893 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82325 .61247 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .84007 .57787 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82735 .57393 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.84007 .57787 m .83666 .62933 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .83606 .62882 L .83666 .62933 L .707 .577 .707 r
F
.83666 .62933 m .84177 .65888 L .83151 .64675 L p F P
0 g
s
.83151 .64675 m .82858 .64328 L p .83666 .62933 L .707 .577 .707 r
F P
0 g
s
.84177 .65888 m .83666 .62933 L p .84011 .64634 L .708 .578 .707 r
F P
0 g
s
.83715 .63156 m .84011 .64634 L p .83666 .62933 L .708 .578 .707 r
F P
0 g
s
.84314 .58144 m .83934 .63869 L .83846 .63766 L p .707 .577 .707 r
F P
0 g
s
.83689 .63036 m .84314 .58144 L .83846 .63766 L .707 .577 .707 r
F
.64156 .68252 m .64689 .71332 L .66009 .72892 L p F P
0 g
s
.64689 .71332 m .64156 .68252 L .6379 .66425 L p .708 .578 .707 r
F P
0 g
s
.63775 .72954 m .63926 .71042 L .63612 .70784 L p .707 .577 .707 r
F P
0 g
s
.84011 .64634 m .84543 .67714 L .84177 .65888 L p .708 .578 .707 r
F P
0 g
s
.63612 .70784 m .63461 .72696 L .63775 .72954 L p .707 .577 .707 r
F P
0 g
s
.63582 .62403 m .63961 .56678 L .64651 .56393 L p .707 .577 .707 r
F P
0 g
s
.64651 .56393 m .64271 .62118 L .63582 .62403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6379 .66425 m .64323 .69506 L .64689 .71332 L p .708 .578 .707 r
F P
0 g
s
.83949 .72469 m .83798 .74381 L .83484 .74123 L p .707 .577 .707 r
F P
0 g
s
.83484 .74123 m .83635 .72211 L .83949 .72469 L p .707 .577 .707 r
F P
0 g
s
.64323 .69506 m .6379 .66425 L .64414 .64511 L p .707 .577 .707 r
F P
0 g
s
.38837 .60494 m .39216 .54769 L .36102 .54491 L p .707 .577 .707 r
F P
0 g
s
.39216 .54769 m .38837 .60494 L .42012 .60669 L p .707 .577 .707 r
F P
0 g
s
.42012 .60669 m .42391 .54944 L .39216 .54769 L p .707 .577 .707 r
F P
0 g
s
.44937 .60726 m .45316 .55001 L .42391 .54944 L p .707 .577 .707 r
F P
0 g
s
.63461 .72696 m .63612 .70784 L .64294 .70608 L p .707 .577 .707 r
F P
0 g
s
.64271 .62118 m .64651 .56393 L .66269 .56207 L p .707 .577 .707 r
F P
0 g
s
.36102 .54491 m .35722 .60216 L .38837 .60494 L p .707 .577 .707 r
F P
0 g
s
.64294 .70608 m .64143 .7252 L .63461 .72696 L p .707 .577 .707 r
F P
0 g
s
.35722 .60216 m .36102 .54491 L .33353 .54139 L p .707 .577 .707 r
F P
0 g
s
.66269 .56207 m .6589 .61932 L .64271 .62118 L p .707 .577 .707 r
F P
0 g
s
.33353 .54139 m .32974 .59864 L .35722 .60216 L p .707 .577 .707 r
F P
0 g
s
.45316 .55001 m .44937 .60726 L .47325 .60658 L p .707 .577 .707 r
F P
0 g
s
.47325 .60658 m .47705 .54933 L .45316 .55001 L p .707 .577 .707 r
F P
0 g
s
.64414 .64511 m .64946 .67592 L .64323 .69506 L p .707 .577 .707 r
F P
0 g
s
.64946 .67592 m .64414 .64511 L .65966 .62697 L p .707 .577 .707 r
F P
0 g
s
.32974 .59864 m .33353 .54139 L .31239 .53747 L p .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .80241 .62726 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82355 .63118 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .80713 .63187 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .82437 .61893 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82858 .64328 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8018 .60106 m .82325 .61247 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80241 .62726 m .8035 .61087 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.80713 .63187 m .8035 .61087 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .8018 .60106 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .82735 .57393 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .80621 .57001 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .82437 .61893 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.83635 .72211 m .83484 .74123 L .82206 .73808 L p .707 .577 .707 r
F P
0 g
s
.82206 .73808 m .82357 .71896 L .83635 .72211 L p .707 .577 .707 r
F P
0 g
s
.31239 .53747 m .30859 .59472 L .32974 .59864 L p .707 .577 .707 r
F P
0 g
s
.38733 .70558 m .38884 .68646 L .35771 .68351 L p .707 .577 .707 r
F P
0 g
s
.38884 .68646 m .38733 .70558 L .41904 .70784 L p .707 .577 .707 r
F P
0 g
s
.41904 .70784 m .42055 .68872 L .38884 .68646 L p .707 .577 .707 r
F P
0 g
s
.35771 .68351 m .3562 .70264 L .38733 .70558 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66269 .56207 L .68658 .56139 L p .707 .577 .707 r
F P
0 g
s
.44823 .7092 m .44974 .69008 L .42055 .68872 L p .707 .577 .707 r
F P
0 g
s
.39715 .70981 m .39182 .679 L .36078 .67881 L p .707 .577 .707 r
F P
0 g
s
.39182 .679 m .39715 .70981 L .4286 .70408 L p .707 .577 .707 r
F P
0 g
s
.4286 .70408 m .42327 .67327 L .39182 .679 L p .707 .577 .707 r
F P
0 g
s
.44974 .69008 m .44823 .7092 L .47205 .70951 L p .707 .577 .707 r
F P
0 g
s
.47205 .70951 m .47356 .69039 L .44974 .69008 L p .707 .577 .707 r
F P
0 g
s
.42327 .67327 m .4286 .70408 L .45737 .69298 L p .707 .577 .707 r
F P
0 g
s
.45737 .69298 m .45205 .66218 L .42327 .67327 L p .707 .577 .707 r
F P
0 g
s
.64143 .7252 m .64294 .70608 L .65904 .70532 L p .707 .577 .707 r
F P
0 g
s
.3562 .70264 m .35771 .68351 L .33021 .68017 L p .707 .577 .707 r
F P
0 g
s
.47705 .54933 m .47325 .60658 L .48944 .60472 L p .707 .577 .707 r
F P
0 g
s
.48944 .60472 m .49323 .54748 L .47705 .54933 L p .707 .577 .707 r
F P
0 g
s
.65904 .70532 m .65753 .72444 L .64143 .7252 L p .707 .577 .707 r
F P
0 g
s
.33021 .68017 m .3287 .69929 L .3562 .70264 L p .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68278 .61864 L .66577 .61912 L p .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .65966 .62697 L .6785 .61453 L p .707 .577 .707 r
F P
0 g
s
.6785 .61453 m .68295 .6116 L p .68235 .61315 L .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .6785 .61453 L .68235 .61315 L .707 .577 .707 r
F
.68295 .6116 m .71173 .6005 L p .70752 .60802 L F P
0 g
s
.68421 .61264 m .68295 .6116 L .70752 .60802 L .707 .577 .707 r
F
.68658 .56139 m .71583 .56196 L p .68655 .61218 L F P
0 g
s
.68278 .61864 m .68317 .61285 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68295 .6116 L p .68421 .61264 L .707 .577 .707 r
F P
0 g
s
.71203 .61921 m .68278 .61864 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68421 .61264 L .69835 .62441 L .707 .577 .707 r
F
.71173 .6005 m .74317 .59477 L p .73567 .60526 L F P
0 g
s
.71864 .60653 m .71173 .6005 L .73567 .60526 L .707 .577 .707 r
F
.71583 .56196 m .74758 .56372 L p .72023 .60642 L F P
0 g
s
.71203 .61921 m .71284 .60697 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71173 .6005 L p .71864 .60653 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .71203 .61921 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71864 .60653 L .72857 .6152 L .707 .577 .707 r
F
.77493 .62374 m .74378 .62096 L p .75404 .60497 L F P
0 g
s
.74317 .59477 m .77421 .59497 L p .7654 .60546 L .707 .577 .707 r
F P
0 g
s
.75264 .60491 m .74317 .59477 L .7654 .60546 L .707 .577 .707 r
F
.80241 .62726 m .77493 .62374 L p .78442 .60743 L F P
0 g
s
.77421 .59497 m .8018 .60106 L p .79444 .60924 L .707 .577 .707 r
F P
0 g
s
.78366 .60729 m .77421 .59497 L .79444 .60924 L .707 .577 .707 r
F
.8035 .61087 m .80241 .62726 L p .78442 .60743 L F P
0 g
s
.8018 .60106 m .80713 .63187 L .77954 .62577 L p .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .8035 .61087 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77872 .56649 m .80621 .57001 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77493 .62374 m .77611 .60592 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77421 .59497 L p .78366 .60729 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77872 .56649 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .78366 .60729 L .78942 .61481 L .707 .577 .707 r
F
.78942 .61481 m .78366 .60729 L .79444 .60924 L F
.77954 .62577 m .77611 .60592 L p .78942 .61481 L F P
0 g
s
.77611 .60592 m .77493 .62374 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.77421 .59497 m .77954 .62577 L .7485 .62558 L p .707 .577 .707 r
F P
0 g
s
.75404 .60497 m .76023 .59533 L .77611 .60592 L .707 .577 .707 r
F
.77872 .56649 m .77611 .60592 L p .76023 .59533 L F P
0 g
s
.74758 .56372 m .77872 .56649 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .74487 .60458 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74317 .59477 L p .75264 .60491 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74758 .56372 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .75264 .60491 L .7596 .61237 L .707 .577 .707 r
F
.7596 .61237 m .75264 .60491 L .7654 .60546 L F
.7485 .62558 m .74487 .60458 L p .7596 .61237 L F P
0 g
s
.74487 .60458 m .74378 .62096 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.74317 .59477 m .7485 .62558 L .71705 .63131 L p .707 .577 .707 r
F P
0 g
s
.72023 .60642 m .72734 .59531 L .74487 .60458 L .707 .577 .707 r
F
.74758 .56372 m .74487 .60458 L p .72734 .59531 L F P
0 g
s
.71284 .60697 m .71583 .56196 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.72857 .6152 m .71864 .60653 L .73567 .60526 L .707 .577 .707 r
F
.71705 .63131 m .71284 .60697 L p .72857 .6152 L F P
0 g
s
.71284 .60697 m .71203 .61921 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.71173 .6005 m .71705 .63131 L .68828 .6424 L p .707 .577 .707 r
F P
0 g
s
.68655 .61218 m .69503 .59764 L .71284 .60697 L .707 .577 .707 r
F
.71583 .56196 m .71284 .60697 L p .69503 .59764 L F P
0 g
s
.68317 .61285 m .68658 .56139 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.69835 .62441 m .68421 .61264 L .70752 .60802 L .707 .577 .707 r
F
.68828 .6424 m .68317 .61285 L p .69835 .62441 L F P
0 g
s
.68295 .6116 m .68828 .6424 L .66499 .65777 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66764 .60103 L .68317 .61285 L .707 .577 .707 r
F
.68658 .56139 m .68317 .61285 L p .66764 .60103 L F P
0 g
s
.66577 .61912 m .6589 .61932 L p .68317 .61285 L .707 .577 .707 r
F P
0 g
s
.36611 .70961 m .36078 .67881 L .33319 .67271 L p .707 .577 .707 r
F P
0 g
s
.36078 .67881 m .36611 .70961 L .39715 .70981 L p .707 .577 .707 r
F P
0 g
s
.65966 .62697 m .66499 .65777 L .64946 .67592 L p .707 .577 .707 r
F P
0 g
s
.45205 .66218 m .45737 .69298 L .48066 .67761 L p .707 .577 .707 r
F P
0 g
s
.48066 .67761 m .47534 .6468 L .45205 .66218 L p .707 .577 .707 r
F P
0 g
s
.30859 .59472 m .31239 .53747 L .29966 .53353 L p .707 .577 .707 r
F P
0 g
s
.29966 .53353 m .29587 .59078 L .30859 .59472 L p .707 .577 .707 r
F P
0 g
s
.3287 .69929 m .33021 .68017 L .30903 .67675 L p .707 .577 .707 r
F P
0 g
s
.30903 .67675 m .30752 .69587 L .3287 .69929 L p .707 .577 .707 r
F P
0 g
s
.82357 .71896 m .82206 .73808 L .80088 .73466 L p .707 .577 .707 r
F P
0 g
s
.80088 .73466 m .80239 .71554 L .82357 .71896 L p .707 .577 .707 r
F P
0 g
s
.33852 .70351 m .33319 .67271 L .31175 .6613 L p .707 .577 .707 r
F P
0 g
s
.33319 .67271 m .33852 .70351 L .36611 .70961 L p .707 .577 .707 r
F P
0 g
s
.47534 .6468 m .48066 .67761 L .49619 .65947 L p .707 .577 .707 r
F P
0 g
s
.49619 .65947 m .49086 .62866 L .47534 .6468 L p .707 .577 .707 r
F P
0 g
s
.65753 .72444 m .65904 .70532 L .68286 .70563 L p .707 .577 .707 r
F P
0 g
s
.49323 .54748 m .48944 .60472 L .49633 .60187 L p .707 .577 .707 r
F P
0 g
s
.49633 .60187 m .50013 .54462 L .49323 .54748 L p .707 .577 .707 r
F P
0 g
s
.68286 .70563 m .68135 .72476 L .65753 .72444 L p .707 .577 .707 r
F P
0 g
s
.47356 .69039 m .47205 .70951 L .48815 .70875 L p .707 .577 .707 r
F P
0 g
s
.48815 .70875 m .48966 .68963 L .47356 .69039 L p .707 .577 .707 r
F P
0 g
s
.29587 .59078 m .29966 .53353 L .2966 .52996 L p .707 .577 .707 r
F P
0 g
s
.30752 .69587 m .30903 .67675 L .29625 .6736 L p .707 .577 .707 r
F P
0 g
s
.29625 .6736 m .29474 .69272 L .30752 .69587 L p .707 .577 .707 r
F P
0 g
s
.80239 .71554 m .80088 .73466 L .77338 .73132 L p .707 .577 .707 r
F P
0 g
s
.77338 .73132 m .77489 .71219 L .80239 .71554 L p .707 .577 .707 r
F P
0 g
s
.31708 .69211 m .31175 .6613 L .29855 .6457 L p .707 .577 .707 r
F P
0 g
s
.31175 .6613 m .31708 .69211 L .33852 .70351 L p .707 .577 .707 r
F P
0 g
s
.49086 .62866 m .49619 .65947 L .50242 .64033 L p .707 .577 .707 r
F P
0 g
s
.50242 .64033 m .4971 .60952 L .49086 .62866 L p .707 .577 .707 r
F P
0 g
s
.2966 .52996 m .29281 .58721 L .29587 .59078 L p .707 .577 .707 r
F P
0 g
s
.68135 .72476 m .68286 .70563 L .71205 .70699 L p .707 .577 .707 r
F P
0 g
s
.71205 .70699 m .71054 .72611 L .68135 .72476 L p .707 .577 .707 r
F P
0 g
s
.77489 .71219 m .77338 .73132 L .74225 .72837 L p .707 .577 .707 r
F P
0 g
s
.74225 .72837 m .74376 .70925 L .77489 .71219 L p .707 .577 .707 r
F P
0 g
s
.48966 .68963 m .48815 .70875 L .49497 .707 L p .707 .577 .707 r
F P
0 g
s
.49497 .707 m .49648 .68787 L .48966 .68963 L p .707 .577 .707 r
F P
0 g
s
.49545 .60084 m .49327 .5983 L p .49388 .59355 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49344 .59126 L .49414 .59475 L p .708 .578 .707 r
F P
0 g
s
.49706 .54105 m .50013 .54462 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .49365 .59251 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49706 .54105 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .48054 .59436 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49344 .59126 m .49365 .59251 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49327 .5983 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .49344 .59126 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .48136 .58212 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .48136 .58212 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48024 .57566 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .49706 .54105 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48434 .53711 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49706 .54105 m .49365 .59251 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .49305 .592 L .49365 .59251 L .707 .577 .707 r
F
.49365 .59251 m .49876 .62206 L .4885 .60993 L p F P
0 g
s
.4885 .60993 m .48557 .60646 L p .49365 .59251 L .707 .577 .707 r
F P
0 g
s
.49876 .62206 m .49365 .59251 L p .4971 .60952 L .708 .578 .707 r
F P
0 g
s
.49414 .59475 m .4971 .60952 L p .49365 .59251 L .708 .578 .707 r
F P
0 g
s
.50013 .54462 m .49633 .60187 L .49545 .60084 L p .707 .577 .707 r
F P
0 g
s
.49388 .59355 m .50013 .54462 L .49545 .60084 L .707 .577 .707 r
F
.71054 .72611 m .71205 .70699 L .74376 .70925 L p F P
0 g
s
.74376 .70925 m .74225 .72837 L .71054 .72611 L p .707 .577 .707 r
F P
0 g
s
.29855 .6457 m .30388 .67651 L .31708 .69211 L p .707 .577 .707 r
F P
0 g
s
.30388 .67651 m .29855 .6457 L .29489 .62744 L p .708 .578 .707 r
F P
0 g
s
.29474 .69272 m .29625 .6736 L .29311 .67102 L p .707 .577 .707 r
F P
0 g
s
.4971 .60952 m .50242 .64033 L .49876 .62206 L p .708 .578 .707 r
F P
0 g
s
.29311 .67102 m .2916 .69014 L .29474 .69272 L p .707 .577 .707 r
F P
0 g
s
.29281 .58721 m .2966 .52996 L .3035 .52711 L p .707 .577 .707 r
F P
0 g
s
.3035 .52711 m .2997 .58436 L .29281 .58721 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29489 .62744 m .30022 .65824 L .30388 .67651 L p .708 .578 .707 r
F P
0 g
s
.49648 .68787 m .49497 .707 L .49183 .70441 L p .707 .577 .707 r
F P
0 g
s
.49183 .70441 m .49334 .68529 L .49648 .68787 L p .707 .577 .707 r
F P
0 g
s
.30022 .65824 m .29489 .62744 L .30113 .6083 L p .707 .577 .707 r
F P
0 g
s
.2916 .69014 m .29311 .67102 L .29993 .66926 L p .707 .577 .707 r
F P
0 g
s
.2997 .58436 m .3035 .52711 L .31968 .52525 L p .707 .577 .707 r
F P
0 g
s
.29993 .66926 m .29842 .68839 L .2916 .69014 L p .707 .577 .707 r
F P
0 g
s
.31968 .52525 m .31589 .5825 L .2997 .58436 L p .707 .577 .707 r
F P
0 g
s
.30113 .6083 m .30645 .6391 L .30022 .65824 L p .707 .577 .707 r
F P
0 g
s
.30645 .6391 m .30113 .6083 L .31665 .59015 L p .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .4594 .59044 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48054 .59436 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .46412 .59506 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .48136 .58212 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48557 .60646 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.45879 .56425 m .48024 .57566 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4594 .59044 m .46049 .57406 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46412 .59506 m .46049 .57406 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .45879 .56425 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .48434 .53711 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .4632 .53319 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .48136 .58212 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.49334 .68529 m .49183 .70441 L .47905 .70126 L p .707 .577 .707 r
F P
0 g
s
.47905 .70126 m .48056 .68214 L .49334 .68529 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .31968 .52525 L .34357 .52458 L p .707 .577 .707 r
F P
0 g
s
.29842 .68839 m .29993 .66926 L .31603 .66851 L p .707 .577 .707 r
F P
0 g
s
.31603 .66851 m .31452 .68763 L .29842 .68839 L p .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33977 .58183 L .32276 .58231 L p .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .31665 .59015 L .33549 .57772 L p .707 .577 .707 r
F P
0 g
s
.33549 .57772 m .33994 .57478 L p .33934 .57633 L .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .33549 .57772 L .33934 .57633 L .707 .577 .707 r
F
.33994 .57478 m .36872 .56369 L p .36451 .57121 L F P
0 g
s
.3412 .57583 m .33994 .57478 L .36451 .57121 L .707 .577 .707 r
F
.34357 .52458 m .37282 .52514 L p .34354 .57536 L F P
0 g
s
.33977 .58183 m .34016 .57604 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33994 .57478 L p .3412 .57583 L .707 .577 .707 r
F P
0 g
s
.36902 .58239 m .33977 .58183 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .3412 .57583 L .35534 .58759 L .707 .577 .707 r
F
.36872 .56369 m .40016 .55796 L p .39266 .56845 L F P
0 g
s
.37563 .56972 m .36872 .56369 L .39266 .56845 L .707 .577 .707 r
F
.37282 .52514 m .40457 .5269 L p .37722 .5696 L F P
0 g
s
.36902 .58239 m .36983 .57015 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .36872 .56369 L p .37563 .56972 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .36902 .58239 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .37563 .56972 L .38556 .57838 L .707 .577 .707 r
F
.43192 .58692 m .40077 .58415 L p .41103 .56816 L F P
0 g
s
.40016 .55796 m .4312 .55815 L p .42239 .56865 L .707 .577 .707 r
F P
0 g
s
.40963 .5681 m .40016 .55796 L .42239 .56865 L .707 .577 .707 r
F
.4594 .59044 m .43192 .58692 L p .44141 .57061 L F P
0 g
s
.4312 .55815 m .45879 .56425 L p .45143 .57242 L .707 .577 .707 r
F P
0 g
s
.44064 .57047 m .4312 .55815 L .45143 .57242 L .707 .577 .707 r
F
.46049 .57406 m .4594 .59044 L p .44141 .57061 L F P
0 g
s
.45879 .56425 m .46412 .59506 L .43653 .58896 L p .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .46049 .57406 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43571 .52967 m .4632 .53319 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43192 .58692 m .4331 .56911 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .4312 .55815 L p .44064 .57047 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .43571 .52967 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .44064 .57047 L .44641 .57799 L .707 .577 .707 r
F
.44641 .57799 m .44064 .57047 L .45143 .57242 L F
.43653 .58896 m .4331 .56911 L p .44641 .57799 L F P
0 g
s
.4331 .56911 m .43192 .58692 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.4312 .55815 m .43653 .58896 L .40549 .58876 L p .707 .577 .707 r
F P
0 g
s
.41103 .56816 m .41722 .55851 L .4331 .56911 L .707 .577 .707 r
F
.43571 .52967 m .4331 .56911 L p .41722 .55851 L F P
0 g
s
.40457 .5269 m .43571 .52967 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .40186 .56776 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40016 .55796 L p .40963 .5681 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40457 .5269 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40963 .5681 L .41658 .57555 L .707 .577 .707 r
F
.41658 .57555 m .40963 .5681 L .42239 .56865 L F
.40549 .58876 m .40186 .56776 L p .41658 .57555 L F P
0 g
s
.40186 .56776 m .40077 .58415 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.40016 .55796 m .40549 .58876 L .37404 .59449 L p .707 .577 .707 r
F P
0 g
s
.37722 .5696 m .38433 .55849 L .40186 .56776 L .707 .577 .707 r
F
.40457 .5269 m .40186 .56776 L p .38433 .55849 L F P
0 g
s
.36983 .57015 m .37282 .52514 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.38556 .57838 m .37563 .56972 L .39266 .56845 L .707 .577 .707 r
F
.37404 .59449 m .36983 .57015 L p .38556 .57838 L F P
0 g
s
.36983 .57015 m .36902 .58239 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.36872 .56369 m .37404 .59449 L .34527 .60559 L p .707 .577 .707 r
F P
0 g
s
.34354 .57536 m .35202 .56082 L .36983 .57015 L .707 .577 .707 r
F
.37282 .52514 m .36983 .57015 L p .35202 .56082 L F P
0 g
s
.34016 .57604 m .34357 .52458 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.35534 .58759 m .3412 .57583 L .36451 .57121 L .707 .577 .707 r
F
.34527 .60559 m .34016 .57604 L p .35534 .58759 L F P
0 g
s
.33994 .57478 m .34527 .60559 L .32198 .62096 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .32463 .56421 L .34016 .57604 L .707 .577 .707 r
F
.34357 .52458 m .34016 .57604 L p .32463 .56421 L F P
0 g
s
.32276 .58231 m .31589 .5825 L p .34016 .57604 L .707 .577 .707 r
F P
0 g
s
.31665 .59015 m .32198 .62096 L .30645 .6391 L p .707 .577 .707 r
F P
0 g
s
.48056 .68214 m .47905 .70126 L .45787 .69785 L p .707 .577 .707 r
F P
0 g
s
.45787 .69785 m .45938 .67872 L .48056 .68214 L p .707 .577 .707 r
F P
0 g
s
.31452 .68763 m .31603 .66851 L .33985 .66882 L p .707 .577 .707 r
F P
0 g
s
.33985 .66882 m .33834 .68794 L .31452 .68763 L p .707 .577 .707 r
F P
0 g
s
.45938 .67872 m .45787 .69785 L .43037 .6945 L p .707 .577 .707 r
F P
0 g
s
.43037 .6945 m .43188 .67538 L .45938 .67872 L p .707 .577 .707 r
F P
0 g
s
.33834 .68794 m .33985 .66882 L .36904 .67017 L p .707 .577 .707 r
F P
0 g
s
.36904 .67017 m .36753 .68929 L .33834 .68794 L p .707 .577 .707 r
F P
0 g
s
.43188 .67538 m .43037 .6945 L .39924 .69155 L p .707 .577 .707 r
F P
0 g
s
.39924 .69155 m .40075 .67243 L .43188 .67538 L p .707 .577 .707 r
F P
0 g
s
.36753 .68929 m .36904 .67017 L .40075 .67243 L p .707 .577 .707 r
F P
0 g
s
.40075 .67243 m .39924 .69155 L .36753 .68929 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00L7oo0`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo8@0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2000
1EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00goo001JEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF1`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP050006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00E7oo00<005YF00000eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009ooaH004eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@00A7oo001COol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH8000lOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP00000^Ool005=oo`03001JEP00009JEPL00003FUH005YF00MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00Dgoo00<005YF00000P000eYF0P0015YF00<005YFFUH01EYF0P0025YF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001COol20002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
15YF3@001EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`800003FUH005YF008000IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001FOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005Moo`04001JEUYF0007FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Moo`04001JEUYF0007FUH00`00FUH0
00050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF001JEP020003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP00;Goo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH200001Woo
001JEUYF001JER400003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool005Eoo`03001JEUYF
00=JEP03001JEUYF009JEP8000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001EOol00`00FUIJEP03
FUH00`00FUIJEP020005Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo000bOolE000=Ool20005FUH30007
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03
FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEP00FUH0;Woo000]Ool500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0000
0eYF001JEP03FUH00`00Oomoo`07Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF0P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF
FUH005YF00T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYF001JEP0^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
Ool005YF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH50006Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00AJEPd000IJEP03001JEUYF009JEP05001JEUYF001JEP0^Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01000FUIJEP000UYF10000Woo00@005YFFUH000IJEP<000MJEP03001JEUYF
00UJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH010001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF00D005YFFUH005YF02ioo`00;Goo00<005YF0000
0eYF00<005YFFUH00UYF00=ooeYF00001eYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
009JEP04001JEUYF0005FUH40002FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH200000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH60007FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH0
00020004FUH00`00FUIJEP02FUH^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00002FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0
00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP04001JEP00FUH^Ool002eoo`03001JEP0000=JEP05001JEUYFFUH00002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH017ooFUIJEP000UYF00<005YFFUH00UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001Goo001JEUYF00000UYF00IooeYFFUIJEP00FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH000=J
EP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP8000Ioo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH70002FUH0
0`00Oomoo`0/Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH00004FUH00`00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH0
0`00Oomoo`0?OolA0007Ool00`00FUH0000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIo
o`02FUH00`00Oomoo`0YOol2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP05001JEUYF
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEP001EYF00D0
05YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP04001J
EP00000/Ool3000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP8002ioo`<002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH00UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001oogoo02eoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00@005YFFUH000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH20007FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP04001JEUYFFUH5000/Ool00`00FUH0000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP80009JEP@000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH01UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP000UYF00<005YFFUH01@002goo0`006Goo00<0
05YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUHJ0002FUH00`00FUIJEP07FUH40003FUH00`00FUIJEP05FUH00`00FUH00006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000eYF00<005YFFUH00eYF00@005YF000000Qoo`D001Moo`80009JEP03001oogoo02Yoo`00;7oo
00<005YF00000UYF1`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP80009J
EP03OomJEP0000EJEP03001JEUYF008000Moo`D001Ioo`03001JEP00009JEP03001oogoo02Yoo`00
;7oo00<005YF00000P0015YF0P000eYF00<005YFFUH01EYF0P0025YF00<005YFFUH015YF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF008000Moo`D001Eo
o`04001JEUYF0002FUH00`00Oomoo`0ZOol002aoo`80009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH900000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P00
27oo0`005Goo00D005YFFUIJEP00009JEP03001oogoo02Yoo`00;Goo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00@000IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02000OOol00`00FUIJEP03FUH2000]Ool002moo`D000IJ
EP03001JEUYF00EJEP@00003FUH005YF00MJEP04001JEP00FUH@0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YF
FUH00P007Goo0`001EYF0P00;Goo000aOol00`00FUH00007FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP06FUH00`00FUH000020002FUH01000FUIJEP0015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000K
Ool20002FUH00`00FUIJEP03FUH2000]Ool0031oo`04001JEUYF0007FUH00`00FUH000050004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P006Goo0P001EYF00<005YFFUH00UYF00<007ooOol0;7oo000_Ool01@00FUIJ
EUYF00001eYF0P001Woo6`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP06001JEUYF001JEP00
5goo0P001eYF00<005YFFUH00UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02
FUH2000SOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500000eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH40005FUH01@00FUIJEP00FUH05Woo0P0000=JEP00FUH01UYF00D005YFFUIJEP00
02moo`00;Woo00<005YFFUH00eYF00<005YFFUH00P009goo100015YF00<005YFFUH01EYF00<005YF
FUH00UYF1P0015YF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEQ400003FUIoogoo015oo`<000=JEP03001JEUYF00EJ
EP04001JEUYF000`Ool002eoo`8000EJEP<002eoobT000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP04001JEUYFFUHE0007FUH00`00
FUIJEP05FUH00`00FUH0000`Ool002eoo`03001JEP0000AJEP03001oogoo02ioo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH01EYF0P00<Goo000/Ool01000FUIJ
EP000eYF00<007ooOol0;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`000eYF00<007ooOol0<7oo000/Ool01000FUIJEP000eYF00<007ooOol0;Woo00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol0
02aoo`04001JEUYF0002FUH00`00Oomoo`0COol3000IOol00`00FUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`04
001JEUYFFUH2000EOol5000GOol200001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
6P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]
Ool00`00FUIJEP02000EOol5000FOol01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800005FUH005YFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP03FUHA0004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP005Woo1@005Woo00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP0000000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPL000=JEP04001JEUYF
FUH2000^Ool002eoo`04001JEUYF000GOol3000FOol01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YF00000`001EYF1@000UYF0P00;Woo000]Ool00`00FUH0000`Ool00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHN0008FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000]Ool00`00FUH0000^Ool30004FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Woo10000UYF00<0
05YFFUH01UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Woo
000^Ool2000/Ool20002FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH01EYF1P000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH0
0UYF00<005YF00003Woo3P001goo4P00;goo000^Ool00`00FUH0000YOol20004FUH00`00FUIJEP03
FUH01000FUIJEP001EYF00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000eoo`03001JEP0005Ao
o`00;Woo00@005YFFUH002Ioo`8000IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
0003FUH005YF00=JEP03001JEP0000eoo`03001JEP0005Aoo`00;Woo00<005YFFUH030006Goo0P00
00=JEP00FUH01UYF00H005YFFUH007oo0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03
001JEP0000eoo`03001JEP0005Aoo`00;7oo1@0000=JEP00FUH01EYF00@005YFFUIJEQ8000Aoo`<0
00=JEP03001JEUYF00EJEP03001JEP00009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
0UYF00<005YF000037oo0P0000=JEP000000Dgoo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP04FUH20003Ool0
0`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0:Ool00`00FUH00002
FUH00`00Oomoo`1AOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00Oomoo`02Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`09Ool01000FUIJEP000UYF00<007ooOol0
DGoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP050003Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001oo`08Ool01@00FUIJEUYF00000UYF00<007ooOol0DGoo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH0000027oo00<005YFFUH00eYF0P00E7oo000[OolK0004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
000000Ioo`<000EJEP8005Aoo`00;7oo0P000UYF00@005YF000000AJEP03001JEUYF00EJEP03001J
EUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP001Goo00@005YFFUH000EJEP8005Aoo`00;Woo1P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF200015YF00<005YFFUH00eYF00D005YF
FUH005YF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000Eoo`03001JEUYF009J
EP03001JEUYF009JEP03001oogoo05=oo`00<goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P0000=oo`00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0017oo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000fOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500001EYF000007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P000Woo0P001eYF00D0
05YFFUIJEP0005Ioo`00>7oo0`001UYF00<005YFFUH01EYF00<005YFFUH015YF100015YF00<005YF
FUH015YF00@005YFFUIJEP<0009oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800005Ool0
0000FUH00007FUH01000FUIJEP00Egoo000kOol40002FUH00`00FUIJEP05FUH00`00FUIJEP0I0005
Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YF0000Egoo000oOol=000POol2
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000080002FUH00`00FUIJEP05FUH2001HOol006ioo`8000AJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000EJEP04001J
EUYFFUH70003FUH00`00Oomoo`1GOol0071oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000UJEP03001JEUYF00EJEP03001JEUYF00D005Qo
o`00Lgoo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P00EGoo001gOol60002FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0D0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02001EOol007eooal000EJEP03001JEUYF00IJEP03001JEUYF00=JEPP000AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol0091oo`@00003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP04001JEUYFFUH2001EOol009Aoo`D0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJEPD0009JEP80
05Eoo`00VGoo0`001UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00@0
05YFFUIJEP@005Eoo`00W7oo10000UYF00<005YFFUH01UYF00<005YFFUH06P00EGoo002POol>001_
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59478 .73995 m .59713 .68313 L .56597 .68069 L p .707 .577 .707 r
F P
0 g
s
.59713 .68313 m .59478 .73995 L .62658 .74073 L p .707 .577 .707 r
F P
0 g
s
.62658 .74073 m .62894 .68391 L .59713 .68313 L p .707 .577 .707 r
F P
0 g
s
.62894 .68391 m .62658 .74073 L .65591 .73978 L p .707 .577 .707 r
F P
0 g
s
.65591 .73978 m .65827 .68295 L .62894 .68391 L p .707 .577 .707 r
F P
0 g
s
.56362 .73751 m .56597 .68069 L .5385 .67683 L p .707 .577 .707 r
F P
0 g
s
.56597 .68069 m .56362 .73751 L .59478 .73995 L p .707 .577 .707 r
F P
0 g
s
.65827 .68295 m .65591 .73978 L .6799 .73718 L p .707 .577 .707 r
F P
0 g
s
.6799 .73718 m .68226 .68036 L .65827 .68295 L p .707 .577 .707 r
F P
0 g
s
.5385 .67683 m .53615 .73366 L .56362 .73751 L p .707 .577 .707 r
F P
0 g
s
.53615 .73366 m .5385 .67683 L .51742 .67194 L p .707 .577 .707 r
F P
0 g
s
.59408 .84024 m .59502 .82124 L .56386 .8187 L p .707 .577 .707 r
F P
0 g
s
.59502 .82124 m .59408 .84024 L .62587 .84133 L p .707 .577 .707 r
F P
0 g
s
.62587 .84133 m .62681 .82233 L .59502 .82124 L p .707 .577 .707 r
F P
0 g
s
.59977 .82893 m .59642 .79514 L .5653 .79434 L p .707 .577 .707 r
F P
0 g
s
.62681 .82233 m .62587 .84133 L .65518 .84086 L p .707 .577 .707 r
F P
0 g
s
.65518 .84086 m .65612 .82186 L .62681 .82233 L p .707 .577 .707 r
F P
0 g
s
.59642 .79514 m .59977 .82893 L .63145 .82498 L p .707 .577 .707 r
F P
0 g
s
.63145 .82498 m .62811 .7912 L .59642 .79514 L p .707 .577 .707 r
F P
0 g
s
.62811 .7912 m .63145 .82498 L .6606 .81666 L p .707 .577 .707 r
F P
0 g
s
.6606 .81666 m .65726 .78288 L .62811 .7912 L p .707 .577 .707 r
F P
0 g
s
.51742 .67194 m .51506 .72876 L .53615 .73366 L p .707 .577 .707 r
F P
0 g
s
.56386 .8187 m .56293 .83769 L .59408 .84024 L p .707 .577 .707 r
F P
0 g
s
.56293 .83769 m .56386 .8187 L .53639 .81495 L p .707 .577 .707 r
F P
0 g
s
.56865 .82812 m .5653 .79434 L .53779 .78885 L p .707 .577 .707 r
F P
0 g
s
.5653 .79434 m .56865 .82812 L .59977 .82893 L p .707 .577 .707 r
F P
0 g
s
.68226 .68036 m .6799 .73718 L .6962 .7332 L p .707 .577 .707 r
F P
0 g
s
.6962 .7332 m .69855 .67638 L .68226 .68036 L p .707 .577 .707 r
F P
0 g
s
.65726 .78288 m .6606 .81666 L .68436 .80479 L p .707 .577 .707 r
F P
0 g
s
.68436 .80479 m .68102 .771 L .65726 .78288 L p .707 .577 .707 r
F P
0 g
s
.53639 .81495 m .53545 .83395 L .56293 .83769 L p .707 .577 .707 r
F P
0 g
s
.51506 .72876 m .51742 .67194 L .50477 .66648 L p .707 .577 .707 r
F P
0 g
s
.65612 .82186 m .65518 .84086 L .67914 .83887 L p .707 .577 .707 r
F P
0 g
s
.67914 .83887 m .68008 .81987 L .65612 .82186 L p .707 .577 .707 r
F P
0 g
s
.54114 .82264 m .53779 .78885 L .51659 .77923 L p .707 .577 .707 r
F P
0 g
s
.53779 .78885 m .54114 .82264 L .56865 .82812 L p .707 .577 .707 r
F P
0 g
s
.53048 .81366 m .51529 .81036 L p .53582 .82645 L .707 .577 .707 r
F P
0 g
s
.51993 .81301 m .51675 .78083 L p .50376 .7664 L .707 .577 .707 r
F P
0 g
s
.51675 .78083 m .51659 .77923 L .51571 .77835 L p .707 .577 .707 r
F P
0 g
s
.51571 .77835 m .50376 .7664 L p .51675 .78083 L .707 .577 .707 r
F P
0 g
s
.53545 .83395 m .53582 .82645 L p .51529 .81036 L .707 .577 .707 r
F P
0 g
s
.53582 .82645 m .53639 .81495 L .53048 .81366 L p .707 .577 .707 r
F P
0 g
s
.50477 .66648 m .50242 .7233 L .51506 .72876 L p .707 .577 .707 r
F P
0 g
s
.51529 .81036 m .51435 .82936 L .53545 .83395 L p .707 .577 .707 r
F P
0 g
s
.68102 .771 m .68436 .80479 L .7004 .79052 L p .707 .577 .707 r
F P
0 g
s
.7004 .79052 m .69706 .75674 L .68102 .771 L p .707 .577 .707 r
F P
0 g
s
.69855 .67638 m .6962 .7332 L .70321 .72823 L p .707 .577 .707 r
F P
0 g
s
.70321 .72823 m .70557 .6714 L .69855 .67638 L p .707 .577 .707 r
F P
0 g
s
.68008 .81987 m .67914 .83887 L .69541 .83556 L p .707 .577 .707 r
F P
0 g
s
.69541 .83556 m .69635 .81657 L .68008 .81987 L p .707 .577 .707 r
F P
0 g
s
.51659 .77923 m .51993 .81301 L .54114 .82264 L p .707 .577 .707 r
F P
0 g
s
.50242 .7233 m .50477 .66648 L .50181 .66099 L p .707 .577 .707 r
F P
0 g
s
.51435 .82936 m .51529 .81036 L .50262 .80539 L p .707 .577 .707 r
F P
0 g
s
.50262 .80539 m .50168 .82438 L .51435 .82936 L p .707 .577 .707 r
F P
0 g
s
.69706 .75674 m .7004 .79052 L .70716 .77526 L p .707 .577 .707 r
F P
0 g
s
.70716 .77526 m .70382 .74147 L .69706 .75674 L p .707 .577 .707 r
F P
0 g
s
.50181 .66099 m .49946 .71782 L .50242 .7233 L p .707 .577 .707 r
F P
0 g
s
.50376 .7664 m .5071 .80019 L .51993 .81301 L p .707 .577 .707 r
F P
0 g
s
.70557 .6714 m .70321 .72823 L .70025 .72274 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .70261 .66592 L .70557 .6714 L p .707 .577 .707 r
F P
0 g
s
.69635 .81657 m .69541 .83556 L .70239 .83126 L p .707 .577 .707 r
F P
0 g
s
.70239 .83126 m .70333 .81227 L .69635 .81657 L p .707 .577 .707 r
F P
0 g
s
.4926 .82254 m .48939 .32288 L .44538 .32031 L p .707 .577 .707 r
F P
0 g
s
.5071 .80019 m .50376 .7664 L .50057 .75164 L p .707 .577 .707 r
F P
0 g
s
.49946 .71782 m .50181 .66099 L .50882 .65602 L p .707 .577 .707 r
F P
0 g
s
.50168 .82438 m .50262 .80539 L .49963 .80051 L p .707 .577 .707 r
F P
0 g
s
.49963 .80051 m .4987 .8195 L .50168 .82438 L p .707 .577 .707 r
F P
0 g
s
.50882 .65602 m .50647 .71284 L .49946 .71782 L p .707 .577 .707 r
F P
0 g
s
.50391 .78542 m .5071 .80019 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50057 .75164 m .50156 .76159 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50156 .76159 m .50391 .78542 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .49963 .80051 L .50467 .7974 L p .707 .577 .707 r
F P
0 g
s
.50467 .7974 m .50662 .7962 L p .50498 .80101 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .50467 .7974 L .50498 .80101 L .707 .577 .707 r
F
.50391 .78542 m .50057 .75164 L .50733 .73637 L p F P
0 g
s
.50647 .71284 m .50882 .65602 L .52512 .65204 L p .707 .577 .707 r
F P
0 g
s
.50662 .7962 m .50568 .8152 L .4987 .8195 L p .707 .577 .707 r
F P
0 g
s
.50733 .73637 m .51067 .77016 L .50391 .78542 L p .707 .577 .707 r
F P
0 g
s
.52512 .65204 m .52277 .70886 L .50647 .71284 L p .707 .577 .707 r
F P
0 g
s
.51067 .77016 m .50733 .73637 L .52337 .72211 L p .707 .577 .707 r
F P
0 g
s
.52277 .70886 m .52512 .65204 L .54911 .64944 L p .707 .577 .707 r
F P
0 g
s
.50568 .8152 m .50662 .7962 L .52288 .7929 L p .707 .577 .707 r
F P
0 g
s
.52288 .7929 m .52195 .81189 L .50568 .8152 L p .707 .577 .707 r
F P
0 g
s
.52337 .72211 m .52672 .75589 L .51067 .77016 L p .707 .577 .707 r
F P
0 g
s
.54911 .64944 m .54676 .70627 L .52277 .70886 L p .707 .577 .707 r
F P
0 g
s
.52672 .75589 m .52337 .72211 L .54713 .71023 L p .707 .577 .707 r
F P
0 g
s
.54713 .71023 m .55047 .74402 L .52672 .75589 L p .707 .577 .707 r
F P
0 g
s
.52195 .81189 m .52288 .7929 L .54685 .79091 L p .707 .577 .707 r
F P
0 g
s
.54685 .79091 m .54591 .80991 L .52195 .81189 L p .707 .577 .707 r
F P
0 g
s
.48939 .32288 m .4926 .82254 L .53754 .82112 L p .707 .577 .707 r
F P
0 g
s
.53754 .82112 m .53433 .32145 L .48939 .32288 L p .707 .577 .707 r
F P
0 g
s
.54676 .70627 m .54911 .64944 L .57844 .64849 L p .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .57609 .70531 L .54676 .70627 L p .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .57624 .70155 L .58541 .69001 L .707 .577 .707 r
F
.57609 .70531 m .57624 .70155 L p .57845 .70143 L F P
0 g
s
.58145 .70127 m .60797 .69797 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .57609 .70531 L p .57845 .70143 L .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .60307 .7001 L .60789 .70609 L .707 .577 .707 r
F
.60797 .69797 m .60815 .69983 L p .6065 .69992 L F P
0 g
s
.60815 .69983 m .60789 .70609 L p .58952 .68327 L .707 .577 .707 r
F P
0 g
s
.61131 .73175 m .57962 .7357 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60797 .69797 m .63909 .69877 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .60789 .70609 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.61164 .70001 m .62885 .70088 L .63905 .70853 L .707 .577 .707 r
F
.60995 .69992 m .60797 .69797 L .63697 .70129 L F
.62885 .70088 m .63413 .70114 L .63905 .70853 L F
.63909 .69877 m .63935 .70141 L p .63697 .70129 L F P
0 g
s
.63935 .70141 m .63905 .70853 L p .62358 .68532 L .707 .577 .707 r
F P
0 g
s
.64243 .73256 m .61131 .73175 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63909 .69877 m .6666 .70426 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .63905 .70853 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.64274 .70199 m .6572 .70448 L .66652 .71239 L .707 .577 .707 r
F
.64169 .70181 m .63909 .69877 L .66523 .70586 L F
.6572 .70448 m .663 .70547 L .66652 .71239 L F
.6666 .70426 m .66678 .70612 L p .66523 .70586 L F P
0 g
s
.66678 .70612 m .66652 .71239 L p .6544 .68863 L .707 .577 .707 r
F P
0 g
s
.66994 .73804 m .64243 .73256 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .66652 .71239 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.669 .7069 m .68135 .71126 L .68761 .71728 L .707 .577 .707 r
F
.6666 .70426 m .68434 .71231 L p .66812 .7066 L F P
0 g
s
.68897 .6845 m .68761 .71728 L p .67137 .70165 L .707 .577 .707 r
F P
0 g
s
.68996 .66046 m .70261 .66592 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .68777 .71352 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68777 .71352 m .68996 .66046 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.66888 .65556 m .68996 .66046 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .66678 .70612 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .6666 .70426 L p .66812 .7066 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66888 .65556 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66812 .7066 L .67987 .72462 L .707 .577 .707 r
F
.67987 .72462 m .66812 .7066 L .68759 .71381 L F
.68639 .71579 m .68759 .71381 L .6878 .71388 L F
.67987 .72462 m .68759 .71381 L .68639 .71579 L F
.68434 .71231 m .6878 .71388 L p .66812 .7066 L F P
0 g
s
.669 .7069 m .67137 .70165 L .68135 .71126 L .707 .577 .707 r
F
.68996 .66046 m .68897 .6845 L p .67137 .70165 L F P
0 g
s
.66678 .70612 m .66994 .73804 L p .66546 .70741 L .707 .577 .707 r
F P
0 g
s
.66523 .70586 m .66678 .70612 L .66546 .70741 L .707 .577 .707 r
F
.64646 .69537 m .6544 .68863 L .663 .70547 L F
.64646 .69537 m .663 .70547 L .6572 .70448 L F
.66798 .6771 m .66678 .70612 L p .6544 .68863 L F P
0 g
s
.66994 .73804 m .66678 .70612 L p .67987 .72462 L .707 .577 .707 r
F P
0 g
s
.64141 .65171 m .66888 .65556 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .63935 .70141 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .63909 .69877 L p .64169 .70181 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64141 .65171 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64169 .70181 L .65521 .71759 L .707 .577 .707 r
F
.65521 .71759 m .64169 .70181 L .66523 .70586 L F
.64274 .70199 m .64646 .69537 L .6572 .70448 L F
.66888 .65556 m .66798 .6771 L p .64646 .69537 L F P
0 g
s
.63935 .70141 m .64243 .73256 L p .6373 .70315 L .707 .577 .707 r
F P
0 g
s
.63697 .70129 m .63935 .70141 L .6373 .70315 L .707 .577 .707 r
F
.61671 .69178 m .62358 .68532 L .63413 .70114 L F
.61671 .69178 m .63413 .70114 L .62885 .70088 L F
.64068 .66923 m .63935 .70141 L p .62358 .68532 L F P
0 g
s
.64243 .73256 m .63935 .70141 L p .65521 .71759 L .707 .577 .707 r
F P
0 g
s
.61025 .64927 m .64141 .65171 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .60815 .69983 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60797 .69797 L p .60995 .69992 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .61025 .64927 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60995 .69992 L .62533 .71511 L .707 .577 .707 r
F
.62533 .71511 m .60995 .69992 L .63697 .70129 L F
.61164 .70001 m .61671 .69178 L .62885 .70088 L F
.64141 .65171 m .64068 .66923 L p .61671 .69178 L F P
0 g
s
.60815 .69983 m .61131 .73175 L p .60669 .7012 L .707 .577 .707 r
F P
0 g
s
.6065 .69992 m .60815 .69983 L .60669 .7012 L .707 .577 .707 r
F
.57845 .70143 m .58952 .68327 L .60307 .7001 L F
.61025 .64927 m .60815 .69983 L p .58952 .68327 L F P
0 g
s
.61131 .73175 m .60815 .69983 L p .62533 .71511 L .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .57628 .70191 L .58145 .70127 L p .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .58145 .70127 L .6065 .69992 L .707 .577 .707 r
F
.55047 .74402 m .54959 .73509 L p .57628 .70191 L F P
0 g
s
.54959 .73509 m .54713 .71023 L .57586 .70203 L p .707 .577 .707 r
F P
0 g
s
.57586 .70203 m .57628 .70191 L p .54959 .73509 L .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .61025 .64927 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57624 .70155 m .57844 .64849 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57628 .70191 m .57962 .7357 L .55047 .74402 L p .707 .577 .707 r
F P
0 g
s
.54591 .80991 m .54685 .79091 L .57615 .79044 L p .707 .577 .707 r
F P
0 g
s
.57615 .79044 m .57522 .80944 L .54591 .80991 L p .707 .577 .707 r
F P
0 g
s
.57522 .80944 m .57615 .79044 L .60794 .79153 L p .707 .577 .707 r
F P
0 g
s
.60794 .79153 m .60701 .81053 L .57522 .80944 L p .707 .577 .707 r
F P
0 g
s
.53433 .32145 m .53754 .82112 L .57902 .81584 L p .707 .577 .707 r
F P
0 g
s
.57902 .81584 m .57581 .31617 L .53433 .32145 L p .707 .577 .707 r
F P
0 g
s
.44859 .81997 m .44538 .32031 L .40662 .31399 L p .707 .577 .707 r
F P
0 g
s
.44538 .32031 m .44859 .81997 L .4926 .82254 L p .707 .577 .707 r
F P
0 g
s
.70382 .74147 m .70716 .77526 L .70397 .76049 L p .707 .577 .707 r
F P
0 g
s
.70397 .76049 m .70063 .72671 L .70382 .74147 L p .707 .577 .707 r
F P
0 g
s
.60701 .81053 m .60794 .79153 L .6391 .79407 L p .707 .577 .707 r
F P
0 g
s
.57581 .31617 m .57902 .81584 L .61297 .80722 L p .707 .577 .707 r
F P
0 g
s
.61297 .80722 m .60977 .30756 L .57581 .31617 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .68761 .71728 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.6878 .71388 m .69115 .74767 L .67228 .7391 L p .707 .577 .707 r
F P
0 g
s
.67228 .7391 m .66994 .73804 L p .68639 .71579 L .707 .577 .707 r
F P
0 g
s
.68639 .71579 m .6878 .71388 L .67228 .7391 L .707 .577 .707 r
F
.70261 .66592 m .70158 .6907 L p .68959 .71051 L F P
0 g
s
.70158 .6907 m .70025 .72274 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.70333 .81227 m .70239 .83126 L .6994 .82638 L p .707 .577 .707 r
F P
0 g
s
.6994 .82638 m .70034 .80739 L .70333 .81227 L p .707 .577 .707 r
F P
0 g
s
.40983 .81366 m .40662 .31399 L .37689 .30455 L p .707 .577 .707 r
F P
0 g
s
.40662 .31399 m .40983 .81366 L .44859 .81997 L p .707 .577 .707 r
F P
0 g
s
.25177 .70314 m .25412 .64631 L .22296 .64387 L p .707 .577 .707 r
F P
0 g
s
.25412 .64631 m .25177 .70314 L .28357 .70392 L p .707 .577 .707 r
F P
0 g
s
.28357 .70392 m .28593 .64709 L .25412 .64631 L p .707 .577 .707 r
F P
0 g
s
.28593 .64709 m .28357 .70392 L .31291 .70296 L p .707 .577 .707 r
F P
0 g
s
.31291 .70296 m .31526 .64614 L .28593 .64709 L p .707 .577 .707 r
F P
0 g
s
.70063 .72671 m .70397 .76049 L .69115 .74767 L p .707 .577 .707 r
F P
0 g
s
.69115 .74767 m .6878 .71388 L .70063 .72671 L p .707 .577 .707 r
F P
0 g
s
.22061 .7007 m .22296 .64387 L .19549 .64002 L p .707 .577 .707 r
F P
0 g
s
.22296 .64387 m .22061 .7007 L .25177 .70314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31526 .64614 m .31291 .70296 L .33689 .70037 L p .707 .577 .707 r
F P
0 g
s
.33689 .70037 m .33925 .64354 L .31526 .64614 L p .707 .577 .707 r
F P
0 g
s
.19549 .64002 m .19314 .69684 L .22061 .7007 L p .707 .577 .707 r
F P
0 g
s
.6391 .79407 m .63816 .81307 L .60701 .81053 L p .707 .577 .707 r
F P
0 g
s
.60977 .30756 m .61297 .80722 L .63608 .79611 L p .707 .577 .707 r
F P
0 g
s
.63608 .79611 m .63287 .29644 L .60977 .30756 L p .707 .577 .707 r
F P
0 g
s
.19314 .69684 m .19549 .64002 L .17441 .63512 L p .707 .577 .707 r
F P
0 g
s
.70034 .80739 m .6994 .82638 L .68674 .82141 L p .707 .577 .707 r
F P
0 g
s
.68674 .82141 m .68768 .80241 L .70034 .80739 L p .707 .577 .707 r
F P
0 g
s
.25107 .80342 m .25201 .78443 L .22086 .78188 L p .707 .577 .707 r
F P
0 g
s
.25201 .78443 m .25107 .80342 L .28286 .80451 L p .707 .577 .707 r
F P
0 g
s
.28286 .80451 m .2838 .78552 L .25201 .78443 L p .707 .577 .707 r
F P
0 g
s
.25676 .79211 m .25341 .75833 L .22229 .75752 L p .707 .577 .707 r
F P
0 g
s
.2838 .78552 m .28286 .80451 L .31217 .80404 L p .707 .577 .707 r
F P
0 g
s
.31217 .80404 m .31311 .78505 L .2838 .78552 L p .707 .577 .707 r
F P
0 g
s
.25341 .75833 m .25676 .79211 L .28844 .78816 L p .707 .577 .707 r
F P
0 g
s
.28844 .78816 m .2851 .75438 L .25341 .75833 L p .707 .577 .707 r
F P
0 g
s
.2851 .75438 m .28844 .78816 L .31759 .77985 L p .707 .577 .707 r
F P
0 g
s
.31759 .77985 m .31425 .74606 L .2851 .75438 L p .707 .577 .707 r
F P
0 g
s
.17441 .63512 m .17205 .69195 L .19314 .69684 L p .707 .577 .707 r
F P
0 g
s
.3801 .80422 m .37689 .30455 L .35911 .29291 L p .707 .577 .707 r
F P
0 g
s
.37689 .30455 m .3801 .80422 L .40983 .81366 L p .707 .577 .707 r
F P
0 g
s
.22086 .78188 m .21992 .80088 L .25107 .80342 L p .707 .577 .707 r
F P
0 g
s
.21992 .80088 m .22086 .78188 L .19338 .77813 L p .707 .577 .707 r
F P
0 g
s
.22564 .79131 m .22229 .75752 L .19478 .75204 L p .707 .577 .707 r
F P
0 g
s
.22229 .75752 m .22564 .79131 L .25676 .79211 L p .707 .577 .707 r
F P
0 g
s
.33925 .64354 m .33689 .70037 L .35319 .69639 L p .707 .577 .707 r
F P
0 g
s
.35319 .69639 m .35555 .63956 L .33925 .64354 L p .707 .577 .707 r
F P
0 g
s
.31425 .74606 m .31759 .77985 L .34135 .76797 L p .707 .577 .707 r
F P
0 g
s
.34135 .76797 m .33801 .73419 L .31425 .74606 L p .707 .577 .707 r
F P
0 g
s
.19338 .77813 m .19244 .79713 L .21992 .80088 L p .707 .577 .707 r
F P
0 g
s
.17205 .69195 m .17441 .63512 L .16176 .62966 L p .707 .577 .707 r
F P
0 g
s
.31311 .78505 m .31217 .80404 L .33613 .80206 L p .707 .577 .707 r
F P
0 g
s
.33613 .80206 m .33707 .78306 L .31311 .78505 L p .707 .577 .707 r
F P
0 g
s
.19813 .78582 m .19478 .75204 L .17358 .74241 L p .707 .577 .707 r
F P
0 g
s
.19478 .75204 m .19813 .78582 L .22564 .79131 L p .707 .577 .707 r
F P
0 g
s
.63287 .29644 m .63608 .79611 L .64608 .78359 L p .707 .577 .707 r
F P
0 g
s
.64608 .78359 m .64287 .28393 L .63287 .29644 L p .707 .577 .707 r
F P
0 g
s
.18747 .77685 m .17228 .77355 L p .19281 .78963 L .707 .577 .707 r
F P
0 g
s
.17692 .77619 m .17374 .74401 L p .16075 .72959 L .707 .577 .707 r
F P
0 g
s
.17374 .74401 m .17358 .74241 L .1727 .74153 L p .707 .577 .707 r
F P
0 g
s
.1727 .74153 m .16075 .72959 L p .17374 .74401 L .707 .577 .707 r
F P
0 g
s
.19244 .79713 m .19281 .78963 L p .17228 .77355 L .707 .577 .707 r
F P
0 g
s
.19281 .78963 m .19338 .77813 L .18747 .77685 L p .707 .577 .707 r
F P
0 g
s
.16176 .62966 m .15941 .68649 L .17205 .69195 L p .707 .577 .707 r
F P
0 g
s
.68768 .80241 m .68674 .82141 L .66564 .81682 L p .707 .577 .707 r
F P
0 g
s
.66564 .81682 m .66657 .79782 L .68768 .80241 L p .707 .577 .707 r
F P
0 g
s
.17228 .77355 m .17134 .79254 L .19244 .79713 L p .707 .577 .707 r
F P
0 g
s
.33801 .73419 m .34135 .76797 L .35739 .75371 L p .707 .577 .707 r
F P
0 g
s
.35739 .75371 m .35405 .71992 L .33801 .73419 L p .707 .577 .707 r
F P
0 g
s
.35555 .63956 m .35319 .69639 L .3602 .69141 L p .707 .577 .707 r
F P
0 g
s
.3602 .69141 m .36256 .63459 L .35555 .63956 L p .707 .577 .707 r
F P
0 g
s
.33707 .78306 m .33613 .80206 L .3524 .79875 L p .707 .577 .707 r
F P
0 g
s
.3524 .79875 m .35334 .77975 L .33707 .78306 L p .707 .577 .707 r
F P
0 g
s
.17358 .74241 m .17692 .77619 L .19813 .78582 L p .707 .577 .707 r
F P
0 g
s
.35405 .71992 m .35739 .75371 L .36415 .73844 L p .707 .577 .707 r
F P
0 g
s
.36415 .73844 m .36081 .70466 L .35405 .71992 L p .707 .577 .707 r
F P
0 g
s
.36256 .63459 m .3602 .69141 L .35724 .68593 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3596 .6291 L .36256 .63459 L p .707 .577 .707 r
F P
0 g
s
.36081 .70466 m .36415 .73844 L .36096 .72368 L p .707 .577 .707 r
F P
0 g
s
.36232 .79258 m .35911 .29291 L .35502 .28021 L p .707 .577 .707 r
F P
0 g
s
.35911 .29291 m .36232 .79258 L .3801 .80422 L p .707 .577 .707 r
F P
0 g
s
.15941 .68649 m .16176 .62966 L .1588 .62418 L p .707 .577 .707 r
F P
0 g
s
.17134 .79254 m .17228 .77355 L .15961 .76857 L p .707 .577 .707 r
F P
0 g
s
.66657 .79782 m .66564 .81682 L .63816 .81307 L p .707 .577 .707 r
F P
0 g
s
.63816 .81307 m .6391 .79407 L .66657 .79782 L p .707 .577 .707 r
F P
0 g
s
.15961 .76857 m .15868 .78757 L .17134 .79254 L p .707 .577 .707 r
F P
0 g
s
.1588 .62418 m .15645 .681 L .15941 .68649 L p .707 .577 .707 r
F P
0 g
s
.16075 .72959 m .1641 .76337 L .17692 .77619 L p .707 .577 .707 r
F P
0 g
s
.64287 .28393 m .64608 .78359 L .64199 .77089 L p .707 .577 .707 r
F P
0 g
s
.64199 .77089 m .63878 .27123 L .64287 .28393 L p .707 .577 .707 r
F P
0 g
s
.35334 .77975 m .3524 .79875 L .35938 .79445 L p .707 .577 .707 r
F P
0 g
s
.35938 .79445 m .36032 .77545 L .35334 .77975 L p .707 .577 .707 r
F P
0 g
s
.1641 .76337 m .16075 .72959 L .15756 .71482 L p .707 .577 .707 r
F P
0 g
s
.15645 .681 m .1588 .62418 L .16581 .6192 L p .707 .577 .707 r
F P
0 g
s
.15868 .78757 m .15961 .76857 L .15663 .76369 L p .707 .577 .707 r
F P
0 g
s
.36096 .72368 m .35762 .68989 L .36081 .70466 L p .707 .577 .707 r
F P
0 g
s
.15663 .76369 m .15569 .78269 L .15868 .78757 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3446 .68047 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3596 .6291 m .35857 .65388 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.35857 .65388 m .35724 .68593 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .3596 .6291 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .34476 .6767 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .34695 .62364 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .32351 .67557 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32359 .66744 L .34133 .6755 L p .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .34476 .6767 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .3446 .68047 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .34695 .62364 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .32377 .66931 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32587 .61875 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .29942 .69574 L p .31316 .67965 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .29604 .67171 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32359 .66744 m .32377 .66931 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32351 .67557 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .32359 .66744 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .29634 .66459 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .29634 .66459 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29608 .66196 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .32587 .61875 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .2984 .61489 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .32377 .66931 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.31316 .67965 m .32222 .66904 L .32377 .66931 L .707 .577 .707 r
F
.32377 .66931 m .32693 .70123 L p .31316 .67965 L F P
0 g
s
.32693 .70123 m .32377 .66931 L p .34459 .67698 L .707 .577 .707 r
F P
0 g
s
.34133 .6755 m .34459 .67698 L p .32377 .66931 L .707 .577 .707 r
F P
0 g
s
.34459 .67698 m .34479 .67707 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .34459 .67698 L .34338 .67898 L .707 .577 .707 r
F
.34479 .67707 m .34814 .71085 L .32927 .70229 L p F P
0 g
s
.32927 .70229 m .32693 .70123 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.34338 .67898 m .34479 .67707 L .32927 .70229 L .707 .577 .707 r
F
.36032 .77545 m .35938 .79445 L .35639 .78957 L p F P
0 g
s
.35639 .78957 m .35733 .77057 L .36032 .77545 L p .707 .577 .707 r
F P
0 g
s
.35762 .68989 m .36096 .72368 L .34814 .71085 L p .707 .577 .707 r
F P
0 g
s
.35502 .28021 m .35823 .77988 L .36232 .79258 L p .707 .577 .707 r
F P
0 g
s
.35823 .77988 m .35502 .28021 L .36502 .2677 L p .707 .577 .707 r
F P
0 g
s
.16581 .6192 m .16346 .67602 L .15645 .681 L p .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .15663 .76369 L .16166 .76059 L p .707 .577 .707 r
F P
0 g
s
.16091 .7486 m .1641 .76337 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.16166 .76059 m .16361 .75939 L p .16197 .76419 L .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .16166 .76059 L .16197 .76419 L .707 .577 .707 r
F
.15756 .71482 m .15855 .72477 L p .1579 .71733 L F P
0 g
s
.15855 .72477 m .16091 .7486 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16091 .7486 m .15756 .71482 L .16432 .69956 L p .707 .577 .707 r
F P
0 g
s
.16346 .67602 m .16581 .6192 L .18211 .61522 L p .707 .577 .707 r
F P
0 g
s
.34814 .71085 m .34479 .67707 L .35762 .68989 L p .707 .577 .707 r
F P
0 g
s
.63878 .27123 m .64199 .77089 L .62421 .75925 L p .707 .577 .707 r
F P
0 g
s
.62421 .75925 m .621 .25959 L .63878 .27123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16361 .75939 m .16267 .77839 L .15569 .78269 L p .707 .577 .707 r
F P
0 g
s
.16432 .69956 m .16766 .73334 L .16091 .7486 L p .707 .577 .707 r
F P
0 g
s
.18211 .61522 m .17976 .67204 L .16346 .67602 L p .707 .577 .707 r
F P
0 g
s
.16766 .73334 m .16432 .69956 L .18036 .68529 L p .707 .577 .707 r
F P
0 g
s
.36822 .76736 m .36502 .2677 L .38813 .25658 L p .707 .577 .707 r
F P
0 g
s
.36502 .2677 m .36822 .76736 L .35823 .77988 L p .707 .577 .707 r
F P
0 g
s
.35733 .77057 m .35639 .78957 L .34373 .78459 L p .707 .577 .707 r
F P
0 g
s
.34373 .78459 m .34467 .7656 L .35733 .77057 L p .707 .577 .707 r
F P
0 g
s
.17976 .67204 m .18211 .61522 L .2061 .61263 L p .707 .577 .707 r
F P
0 g
s
.16267 .77839 m .16361 .75939 L .17987 .75608 L p .707 .577 .707 r
F P
0 g
s
.17987 .75608 m .17894 .77508 L .16267 .77839 L p .707 .577 .707 r
F P
0 g
s
.18036 .68529 m .18371 .71907 L .16766 .73334 L p .707 .577 .707 r
F P
0 g
s
.2061 .61263 m .20375 .66945 L .17976 .67204 L p .707 .577 .707 r
F P
0 g
s
.18371 .71907 m .18036 .68529 L .20412 .67342 L p .707 .577 .707 r
F P
0 g
s
.621 .25959 m .62421 .75925 L .59448 .74982 L p .707 .577 .707 r
F P
0 g
s
.59448 .74982 m .59127 .25015 L .621 .25959 L p .707 .577 .707 r
F P
0 g
s
.20375 .66945 m .2061 .61263 L .23543 .61167 L p .707 .577 .707 r
F P
0 g
s
.34467 .7656 m .34373 .78459 L .32263 .78 L p .707 .577 .707 r
F P
0 g
s
.32263 .78 m .32356 .76101 L .34467 .7656 L p .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .26488 .66928 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29604 .67171 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .2683 .69493 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .29634 .66459 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29942 .69574 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .29608 .66196 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .26514 .66302 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .26514 .66302 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26496 .66115 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .2984 .61489 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26724 .61245 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .29634 .66459 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.38813 .25658 m .39133 .75625 L .36822 .76736 L p .707 .577 .707 r
F P
0 g
s
.39133 .75625 m .38813 .25658 L .42208 .24797 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .23308 .6685 L .20375 .66945 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .26724 .61245 L p .2424 .6532 L .707 .577 .707 r
F P
0 g
s
.23308 .6685 m .23324 .66474 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.23844 .66445 m .26496 .66115 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .23308 .6685 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .26514 .66302 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .26514 .66302 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26488 .66928 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .23661 .69888 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .2683 .69493 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23327 .6651 L .23844 .66445 L p .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23844 .66445 L .26349 .6631 L .707 .577 .707 r
F
.23545 .66462 m .23324 .66474 L .2424 .6532 L F
.23324 .66474 m .23543 .61167 L p .2424 .6532 L F P
0 g
s
.20747 .7072 m .20658 .69827 L p .23327 .6651 L .707 .577 .707 r
F P
0 g
s
.20658 .69827 m .20412 .67342 L .23285 .66522 L p .707 .577 .707 r
F P
0 g
s
.23285 .66522 m .23327 .6651 L p .20658 .69827 L .707 .577 .707 r
F P
0 g
s
.20412 .67342 m .20747 .7072 L .18371 .71907 L p .707 .577 .707 r
F P
0 g
s
.17894 .77508 m .17987 .75608 L .20384 .7541 L p .707 .577 .707 r
F P
0 g
s
.73198 .64791 m .73434 .59109 L .70318 .58865 L p .707 .577 .707 r
F P
0 g
s
.73434 .59109 m .73198 .64791 L .76379 .64869 L p .707 .577 .707 r
F P
0 g
s
.76379 .64869 m .76614 .59187 L .73434 .59109 L p .707 .577 .707 r
F P
0 g
s
.20384 .7541 m .2029 .77309 L .17894 .77508 L p .707 .577 .707 r
F P
0 g
s
.76614 .59187 m .76379 .64869 L .79312 .64774 L p .707 .577 .707 r
F P
0 g
s
.79312 .64774 m .79547 .59092 L .76614 .59187 L p .707 .577 .707 r
F P
0 g
s
.70082 .64548 m .70318 .58865 L .67571 .5848 L p .707 .577 .707 r
F P
0 g
s
.70318 .58865 m .70082 .64548 L .73198 .64791 L p .707 .577 .707 r
F P
0 g
s
.23327 .6651 m .23661 .69888 L .20747 .7072 L p .707 .577 .707 r
F P
0 g
s
.59127 .25015 m .59448 .74982 L .55572 .7435 L p .707 .577 .707 r
F P
0 g
s
.55572 .7435 m .55251 .24383 L .59127 .25015 L p .707 .577 .707 r
F P
0 g
s
.32356 .76101 m .32263 .78 L .29515 .77626 L p .707 .577 .707 r
F P
0 g
s
.29515 .77626 m .29609 .75726 L .32356 .76101 L p .707 .577 .707 r
F P
0 g
s
.79547 .59092 m .79312 .64774 L .81711 .64515 L p .707 .577 .707 r
F P
0 g
s
.81711 .64515 m .81946 .58832 L .79547 .59092 L p .707 .577 .707 r
F P
0 g
s
.67571 .5848 m .67335 .64162 L .70082 .64548 L p .707 .577 .707 r
F P
0 g
s
.2029 .77309 m .20384 .7541 L .23315 .75363 L p .707 .577 .707 r
F P
0 g
s
.67335 .64162 m .67571 .5848 L .65462 .5799 L p .707 .577 .707 r
F P
0 g
s
.23315 .75363 m .23221 .77262 L .2029 .77309 L p .707 .577 .707 r
F P
0 g
s
.42529 .74764 m .42208 .24797 L .46356 .24269 L p .707 .577 .707 r
F P
0 g
s
.42208 .24797 m .42529 .74764 L .39133 .75625 L p .707 .577 .707 r
F P
0 g
s
.73129 .74911 m .73222 .73012 L .70107 .72757 L p .707 .577 .707 r
F P
0 g
s
.73222 .73012 m .73129 .74911 L .76308 .7502 L p .707 .577 .707 r
F P
0 g
s
.76308 .7502 m .76401 .73121 L .73222 .73012 L p .707 .577 .707 r
F P
0 g
s
.73697 .73665 m .73363 .70287 L .70251 .70206 L p .707 .577 .707 r
F P
0 g
s
.76401 .73121 m .76308 .7502 L .79239 .74973 L p .707 .577 .707 r
F P
0 g
s
.79239 .74973 m .79332 .73073 L .76401 .73121 L p .707 .577 .707 r
F P
0 g
s
.73363 .70287 m .73697 .73665 L .76866 .7327 L p .707 .577 .707 r
F P
0 g
s
.76866 .7327 m .76531 .69892 L .73363 .70287 L p .707 .577 .707 r
F P
0 g
s
.29609 .75726 m .29515 .77626 L .264 .77371 L p .707 .577 .707 r
F P
0 g
s
.264 .77371 m .26493 .75472 L .29609 .75726 L p .707 .577 .707 r
F P
0 g
s
.76531 .69892 m .76866 .7327 L .79781 .72439 L p .707 .577 .707 r
F P
0 g
s
.79781 .72439 m .79446 .6906 L .76531 .69892 L p .707 .577 .707 r
F P
0 g
s
.65462 .5799 m .65227 .63672 L .67335 .64162 L p .707 .577 .707 r
F P
0 g
s
.23221 .77262 m .23315 .75363 L .26493 .75472 L p .707 .577 .707 r
F P
0 g
s
.55251 .24383 m .55572 .7435 L .51171 .74093 L p .707 .577 .707 r
F P
0 g
s
.51171 .74093 m .5085 .24126 L .55251 .24383 L p .707 .577 .707 r
F P
0 g
s
.70107 .72757 m .70013 .74657 L .73129 .74911 L p .707 .577 .707 r
F P
0 g
s
.26493 .75472 m .264 .77371 L .23221 .77262 L p .707 .577 .707 r
F P
0 g
s
.70013 .74657 m .70107 .72757 L .67359 .72382 L p .707 .577 .707 r
F P
0 g
s
.70585 .73584 m .70251 .70206 L .675 .69658 L p .707 .577 .707 r
F P
0 g
s
.70251 .70206 m .70585 .73584 L .73697 .73665 L p .707 .577 .707 r
F P
0 g
s
.81946 .58832 m .81711 .64515 L .83341 .64117 L p .707 .577 .707 r
F P
0 g
s
.83341 .64117 m .83576 .58434 L .81946 .58832 L p .707 .577 .707 r
F P
0 g
s
.79446 .6906 m .79781 .72439 L .82156 .71251 L p .707 .577 .707 r
F P
0 g
s
.82156 .71251 m .81822 .67873 L .79446 .6906 L p .707 .577 .707 r
F P
0 g
s
.46677 .74236 m .46356 .24269 L .5085 .24126 L p .707 .577 .707 r
F P
0 g
s
.46356 .24269 m .46677 .74236 L .42529 .74764 L p .707 .577 .707 r
F P
0 g
s
.67359 .72382 m .67266 .74282 L .70013 .74657 L p .707 .577 .707 r
F P
0 g
s
.5085 .24126 m .51171 .74093 L .46677 .74236 L p .707 .577 .707 r
F P
0 g
s
.65227 .63672 m .65462 .5799 L .64198 .57444 L p .707 .577 .707 r
F P
0 g
s
.79332 .73073 m .79239 .74973 L .81635 .74774 L p .707 .577 .707 r
F P
0 g
s
.81635 .74774 m .81728 .72875 L .79332 .73073 L p .707 .577 .707 r
F P
0 g
s
.67834 .73036 m .675 .69658 L .65379 .68695 L p .707 .577 .707 r
F P
0 g
s
.675 .69658 m .67834 .73036 L .70585 .73584 L p .707 .577 .707 r
F P
0 g
s
.66807 .72262 m .65249 .71924 L p .67306 .73456 L .707 .577 .707 r
F P
0 g
s
.65713 .72073 m .65399 .68894 L p .64097 .67413 L .707 .577 .707 r
F P
0 g
s
.65399 .68894 m .65379 .68695 L .6527 .68586 L p .707 .577 .707 r
F P
0 g
s
.6527 .68586 m .64097 .67413 L p .65399 .68894 L .707 .577 .707 r
F P
0 g
s
.67266 .74282 m .67306 .73456 L p .65249 .71924 L .707 .577 .707 r
F P
0 g
s
.67306 .73456 m .67359 .72382 L .66807 .72262 L p .707 .577 .707 r
F P
0 g
s
.64198 .57444 m .63962 .63126 L .65227 .63672 L p .707 .577 .707 r
F P
0 g
s
.65249 .71924 m .65155 .73823 L .67266 .74282 L p .707 .577 .707 r
F P
0 g
s
.81822 .67873 m .82156 .71251 L .83761 .69824 L p .707 .577 .707 r
F P
0 g
s
.83761 .69824 m .83427 .66446 L .81822 .67873 L p .707 .577 .707 r
F P
0 g
s
.83576 .58434 m .83341 .64117 L .84042 .63619 L p .707 .577 .707 r
F P
0 g
s
.84042 .63619 m .84277 .57937 L .83576 .58434 L p .707 .577 .707 r
F P
0 g
s
.65379 .68695 m .65713 .72073 L .67834 .73036 L p .707 .577 .707 r
F P
0 g
s
.81728 .72875 m .81635 .74774 L .83261 .74444 L p .707 .577 .707 r
F P
0 g
s
.83261 .74444 m .83355 .72544 L .81728 .72875 L p .707 .577 .707 r
F P
0 g
s
.63962 .63126 m .64198 .57444 L .63902 .56895 L p .707 .577 .707 r
F P
0 g
s
.65155 .73823 m .65249 .71924 L .63983 .71426 L p .707 .577 .707 r
F P
0 g
s
.63983 .71426 m .63889 .73326 L .65155 .73823 L p .707 .577 .707 r
F P
0 g
s
.83427 .66446 m .83761 .69824 L .84437 .68298 L p .707 .577 .707 r
F P
0 g
s
.84437 .68298 m .84102 .6492 L .83427 .66446 L p .707 .577 .707 r
F P
0 g
s
.63902 .56895 m .63666 .62578 L .63962 .63126 L p .707 .577 .707 r
F P
0 g
s
.64097 .67413 m .64431 .70791 L .65713 .72073 L p .707 .577 .707 r
F P
0 g
s
.84277 .57937 m .84042 .63619 L .83746 .6307 L p .707 .577 .707 r
F P
0 g
s
.83746 .6307 m .83981 .57388 L .84277 .57937 L p .707 .577 .707 r
F P
0 g
s
.83355 .72544 m .83261 .74444 L .8396 .74014 L p .707 .577 .707 r
F P
0 g
s
.8396 .74014 m .84053 .72114 L .83355 .72544 L p .707 .577 .707 r
F P
0 g
s
.64431 .70791 m .64097 .67413 L .63778 .65936 L p .707 .577 .707 r
F P
0 g
s
.63666 .62578 m .63902 .56895 L .64603 .56398 L p .707 .577 .707 r
F P
0 g
s
.63889 .73326 m .63983 .71426 L .63684 .70938 L p .707 .577 .707 r
F P
0 g
s
.84102 .6492 m .84437 .68298 L .84118 .66821 L p .707 .577 .707 r
F P
0 g
s
.84118 .66821 m .83783 .63443 L .84102 .6492 L p .707 .577 .707 r
F P
0 g
s
.63684 .70938 m .6359 .72838 L .63889 .73326 L p .707 .577 .707 r
F P
0 g
s
.64603 .56398 m .64367 .6208 L .63666 .62578 L p .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .63684 .70938 L .64197 .70622 L p .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .64431 .70791 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.64197 .70622 m .64382 .70508 L p .64227 .70964 L .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .64197 .70622 L .64227 .70964 L .707 .577 .707 r
F
.63778 .65936 m .6388 .66969 L p .63813 .66196 L F P
0 g
s
.6388 .66969 m .64112 .69314 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83746 .6307 m .82482 .62525 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .83981 .57388 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .82498 .62131 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82717 .56842 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .80373 .62035 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .8038 .61198 L .82222 .62034 L p .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .82498 .62131 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82482 .62525 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .82717 .56842 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .80399 .61392 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80608 .56352 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .77964 .64028 L p .79298 .62465 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .77626 .61649 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.8038 .61198 m .80399 .61392 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80373 .62035 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .8038 .61198 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .77656 .6092 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .77656 .6092 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77629 .6065 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .80608 .56352 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77861 .55967 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .80399 .61392 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.79298 .62465 m .80238 .61364 L .80399 .61392 L .707 .577 .707 r
F
.80399 .61392 m .80714 .64577 L p .79298 .62465 L F P
0 g
s
.80714 .64577 m .80399 .61392 L p .82485 .62153 L .707 .577 .707 r
F P
0 g
s
.82222 .62034 m .82485 .62153 L p .80399 .61392 L .707 .577 .707 r
F P
0 g
s
.82485 .62153 m .82501 .62161 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .82485 .62153 L .82387 .62315 L .707 .577 .707 r
F
.82501 .62161 m .82835 .65539 L .80952 .64685 L p F P
0 g
s
.80952 .64685 m .80714 .64577 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.82387 .62315 m .82501 .62161 L .80952 .64685 L .707 .577 .707 r
F
.83981 .57388 m .83879 .59849 L p .82688 .61817 L F P
0 g
s
.83879 .59849 m .83746 .6307 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .63778 .65936 L .64453 .6441 L p .707 .577 .707 r
F P
0 g
s
.84053 .72114 m .8396 .74014 L .83661 .73526 L p .707 .577 .707 r
F P
0 g
s
.83661 .73526 m .83755 .71626 L .84053 .72114 L p .707 .577 .707 r
F P
0 g
s
.38897 .6111 m .39133 .55427 L .36017 .55184 L p .707 .577 .707 r
F P
0 g
s
.39133 .55427 m .38897 .6111 L .42078 .61188 L p .707 .577 .707 r
F P
0 g
s
.42078 .61188 m .42313 .55505 L .39133 .55427 L p .707 .577 .707 r
F P
0 g
s
.42313 .55505 m .42078 .61188 L .45011 .61092 L p .707 .577 .707 r
F P
0 g
s
.45011 .61092 m .45246 .5541 L .42313 .55505 L p .707 .577 .707 r
F P
0 g
s
.64367 .6208 m .64603 .56398 L .66233 .56 L p .707 .577 .707 r
F P
0 g
s
.83783 .63443 m .84118 .66821 L .82835 .65539 L p .707 .577 .707 r
F P
0 g
s
.82835 .65539 m .82501 .62161 L .83783 .63443 L p .707 .577 .707 r
F P
0 g
s
.35781 .60866 m .36017 .55184 L .3327 .54798 L p .707 .577 .707 r
F P
0 g
s
.36017 .55184 m .35781 .60866 L .38897 .6111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64382 .70508 m .64288 .72407 L .6359 .72838 L p .707 .577 .707 r
F P
0 g
s
.64453 .6441 m .64788 .67788 L .64112 .69314 L p .707 .577 .707 r
F P
0 g
s
.66233 .56 m .65997 .61682 L .64367 .6208 L p .707 .577 .707 r
F P
0 g
s
.45246 .5541 m .45011 .61092 L .4741 .60833 L p .707 .577 .707 r
F P
0 g
s
.4741 .60833 m .47645 .55151 L .45246 .5541 L p .707 .577 .707 r
F P
0 g
s
.3327 .54798 m .33034 .6048 L .35781 .60866 L p .707 .577 .707 r
F P
0 g
s
.33034 .6048 m .3327 .54798 L .31161 .54308 L p .707 .577 .707 r
F P
0 g
s
.64788 .67788 m .64453 .6441 L .66058 .62983 L p .707 .577 .707 r
F P
0 g
s
.83755 .71626 m .83661 .73526 L .82394 .73028 L p .707 .577 .707 r
F P
0 g
s
.82394 .73028 m .82488 .71128 L .83755 .71626 L p .707 .577 .707 r
F P
0 g
s
.38828 .7123 m .38921 .6933 L .35806 .69076 L p .707 .577 .707 r
F P
0 g
s
.38921 .6933 m .38828 .7123 L .42007 .71339 L p .707 .577 .707 r
F P
0 g
s
.42007 .71339 m .421 .69439 L .38921 .6933 L p .707 .577 .707 r
F P
0 g
s
.39396 .69984 m .39062 .66605 L .3595 .66525 L p .707 .577 .707 r
F P
0 g
s
.421 .69439 m .42007 .71339 L .44938 .71292 L p .707 .577 .707 r
F P
0 g
s
.44938 .71292 m .45031 .69392 L .421 .69439 L p .707 .577 .707 r
F P
0 g
s
.39062 .66605 m .39396 .69984 L .42565 .69589 L p .707 .577 .707 r
F P
0 g
s
.42565 .69589 m .4223 .6621 L .39062 .66605 L p .707 .577 .707 r
F P
0 g
s
.4223 .6621 m .42565 .69589 L .4548 .68757 L p .707 .577 .707 r
F P
0 g
s
.4548 .68757 m .45145 .65379 L .4223 .6621 L p .707 .577 .707 r
F P
0 g
s
.65997 .61682 m .66233 .56 L .68632 .5574 L p .707 .577 .707 r
F P
0 g
s
.31161 .54308 m .30926 .59991 L .33034 .6048 L p .707 .577 .707 r
F P
0 g
s
.35806 .69076 m .35712 .70975 L .38828 .7123 L p .707 .577 .707 r
F P
0 g
s
.35712 .70975 m .35806 .69076 L .33058 .68701 L p .707 .577 .707 r
F P
0 g
s
.36284 .69903 m .3595 .66525 L .33199 .65976 L p .707 .577 .707 r
F P
0 g
s
.3595 .66525 m .36284 .69903 L .39396 .69984 L p .707 .577 .707 r
F P
0 g
s
.47645 .55151 m .4741 .60833 L .4904 .60435 L p .707 .577 .707 r
F P
0 g
s
.4904 .60435 m .49275 .54753 L .47645 .55151 L p .707 .577 .707 r
F P
0 g
s
.64288 .72407 m .64382 .70508 L .66009 .70177 L p .707 .577 .707 r
F P
0 g
s
.45145 .65379 m .4548 .68757 L .47855 .6757 L p .707 .577 .707 r
F P
0 g
s
.47855 .6757 m .47521 .64191 L .45145 .65379 L p .707 .577 .707 r
F P
0 g
s
.66009 .70177 m .65915 .72077 L .64288 .72407 L p .707 .577 .707 r
F P
0 g
s
.66058 .62983 m .66392 .66361 L .64788 .67788 L p .707 .577 .707 r
F P
0 g
s
.68632 .5574 m .68396 .61423 L .65997 .61682 L p .707 .577 .707 r
F P
0 g
s
.33058 .68701 m .32965 .706 L .35712 .70975 L p .707 .577 .707 r
F P
0 g
s
.30926 .59991 m .31161 .54308 L .29897 .53762 L p .707 .577 .707 r
F P
0 g
s
.66392 .66361 m .66058 .62983 L .68434 .61796 L p .707 .577 .707 r
F P
0 g
s
.45031 .69392 m .44938 .71292 L .47334 .71093 L p .707 .577 .707 r
F P
0 g
s
.47334 .71093 m .47427 .69193 L .45031 .69392 L p .707 .577 .707 r
F P
0 g
s
.33533 .69354 m .33199 .65976 L .31078 .65014 L p .707 .577 .707 r
F P
0 g
s
.33199 .65976 m .33533 .69354 L .36284 .69903 L p .707 .577 .707 r
F P
0 g
s
.68396 .61423 m .68632 .5574 L .71565 .55645 L p .707 .577 .707 r
F P
0 g
s
.32506 .68581 m .30948 .68242 L p .33005 .69774 L .707 .577 .707 r
F P
0 g
s
.31412 .68392 m .31098 .65212 L p .29796 .63731 L .707 .577 .707 r
F P
0 g
s
.31098 .65212 m .31078 .65014 L .30969 .64905 L p .707 .577 .707 r
F P
0 g
s
.30969 .64905 m .29796 .63731 L p .31098 .65212 L .707 .577 .707 r
F P
0 g
s
.32965 .706 m .33005 .69774 L p .30948 .68242 L .707 .577 .707 r
F P
0 g
s
.33005 .69774 m .33058 .68701 L .32506 .68581 L p .707 .577 .707 r
F P
0 g
s
.29897 .53762 m .29661 .59445 L .30926 .59991 L p .707 .577 .707 r
F P
0 g
s
.82488 .71128 m .82394 .73028 L .80284 .72569 L p .707 .577 .707 r
F P
0 g
s
.80284 .72569 m .80378 .7067 L .82488 .71128 L p .707 .577 .707 r
F P
0 g
s
.30948 .68242 m .30854 .70142 L .32965 .706 L p .707 .577 .707 r
F P
0 g
s
.47521 .64191 m .47855 .6757 L .4946 .66143 L p .707 .577 .707 r
F P
0 g
s
.4946 .66143 m .49126 .62765 L .47521 .64191 L p .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .7451 .61406 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77626 .61649 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .74851 .63947 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .77656 .6092 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77964 .64028 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .77629 .6065 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .74536 .60762 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .74536 .60762 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74517 .60569 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .77861 .55967 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74745 .55723 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .77656 .6092 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .71329 .61328 L .68396 .61423 L p .707 .577 .707 r
F P
0 g
s
.49275 .54753 m .4904 .60435 L .49741 .59937 L p .707 .577 .707 r
F P
0 g
s
.49741 .59937 m .49976 .54255 L .49275 .54753 L p .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .74745 .55723 L p .72303 .59729 L .707 .577 .707 r
F P
0 g
s
.71329 .61328 m .71346 .60934 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.71765 .60912 m .74517 .60569 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .71329 .61328 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .74536 .60762 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .74536 .60762 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .7451 .61406 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .71683 .64342 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74851 .63947 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71349 .60964 L .71765 .60912 L p .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71765 .60912 L .74365 .60772 L .707 .577 .707 r
F
.71576 .60922 m .71346 .60934 L .72303 .59729 L F
.71346 .60934 m .71565 .55645 L p .72303 .59729 L F P
0 g
s
.68768 .65174 m .6868 .64288 L p .71349 .60964 L .707 .577 .707 r
F P
0 g
s
.6868 .64288 m .68434 .61796 L .71315 .60973 L p .707 .577 .707 r
F P
0 g
s
.71315 .60973 m .71349 .60964 L p .6868 .64288 L .707 .577 .707 r
F P
0 g
s
.68434 .61796 m .68768 .65174 L .66392 .66361 L p .707 .577 .707 r
F P
0 g
s
.65915 .72077 m .66009 .70177 L .68405 .69979 L p .707 .577 .707 r
F P
0 g
s
.68405 .69979 m .68311 .71878 L .65915 .72077 L p .707 .577 .707 r
F P
0 g
s
.31078 .65014 m .31412 .68392 L .33533 .69354 L p .707 .577 .707 r
F P
0 g
s
.47427 .69193 m .47334 .71093 L .4896 .70762 L p .707 .577 .707 r
F P
0 g
s
.4896 .70762 m .49054 .68863 L .47427 .69193 L p .707 .577 .707 r
F P
0 g
s
.29661 .59445 m .29897 .53762 L .29601 .53214 L p .707 .577 .707 r
F P
0 g
s
.71349 .60964 m .71683 .64342 L .68768 .65174 L p .707 .577 .707 r
F P
0 g
s
.30854 .70142 m .30948 .68242 L .29682 .67744 L p .707 .577 .707 r
F P
0 g
s
.80378 .7067 m .80284 .72569 L .77537 .72194 L p .707 .577 .707 r
F P
0 g
s
.77537 .72194 m .7763 .70295 L .80378 .7067 L p .707 .577 .707 r
F P
0 g
s
.29682 .67744 m .29588 .69644 L .30854 .70142 L p .707 .577 .707 r
F P
0 g
s
.49126 .62765 m .4946 .66143 L .50136 .64617 L p .707 .577 .707 r
F P
0 g
s
.50136 .64617 m .49801 .61238 L .49126 .62765 L p .707 .577 .707 r
F P
0 g
s
.29601 .53214 m .29365 .58896 L .29661 .59445 L p .707 .577 .707 r
F P
0 g
s
.68311 .71878 m .68405 .69979 L .71336 .69931 L p .707 .577 .707 r
F P
0 g
s
.71336 .69931 m .71242 .71831 L .68311 .71878 L p .707 .577 .707 r
F P
0 g
s
.29796 .63731 m .3013 .6711 L .31412 .68392 L p .707 .577 .707 r
F P
0 g
s
.49976 .54255 m .49741 .59937 L .49445 .59389 L p .707 .577 .707 r
F P
0 g
s
.49445 .59389 m .4968 .53706 L .49976 .54255 L p .707 .577 .707 r
F P
0 g
s
.7763 .70295 m .77537 .72194 L .74421 .7194 L p .707 .577 .707 r
F P
0 g
s
.74421 .7194 m .74515 .7004 L .7763 .70295 L p .707 .577 .707 r
F P
0 g
s
.49054 .68863 m .4896 .70762 L .49659 .70332 L p .707 .577 .707 r
F P
0 g
s
.49659 .70332 m .49752 .68432 L .49054 .68863 L p .707 .577 .707 r
F P
0 g
s
.71242 .71831 m .71336 .69931 L .74515 .7004 L p .707 .577 .707 r
F P
0 g
s
.3013 .6711 m .29796 .63731 L .29477 .62255 L p .707 .577 .707 r
F P
0 g
s
.74515 .7004 m .74421 .7194 L .71242 .71831 L p .707 .577 .707 r
F P
0 g
s
.29365 .58896 m .29601 .53214 L .30302 .52716 L p .707 .577 .707 r
F P
0 g
s
.29588 .69644 m .29682 .67744 L .29383 .67257 L p .707 .577 .707 r
F P
0 g
s
.49801 .61238 m .50136 .64617 L .49817 .6314 L p .707 .577 .707 r
F P
0 g
s
.49817 .6314 m .49482 .59762 L .49801 .61238 L p .707 .577 .707 r
F P
0 g
s
.29383 .67257 m .29289 .69156 L .29588 .69644 L p .707 .577 .707 r
F P
0 g
s
.30302 .52716 m .30066 .58399 L .29365 .58896 L p .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29383 .67257 L .29896 .6694 L p .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .3013 .6711 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.29896 .6694 m .30081 .66826 L p .29926 .67282 L .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29896 .6694 L .29926 .67282 L .707 .577 .707 r
F
.29477 .62255 m .29579 .63288 L p .29512 .62515 L F P
0 g
s
.29579 .63288 m .29811 .65633 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49445 .59389 m .4818 .58843 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .4968 .53706 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .48197 .5845 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .48416 .5316 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .46072 .58353 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46079 .57517 L .47921 .58353 L p .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .48197 .5845 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .4818 .58843 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .48416 .5316 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .46098 .5771 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46307 .52671 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .43662 .60346 L p .44997 .58784 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .43325 .57968 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46079 .57517 m .46098 .5771 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46072 .58353 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .46079 .57517 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .43355 .57239 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .43355 .57239 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43328 .56968 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .46307 .52671 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .4356 .52285 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .46098 .5771 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.44997 .58784 m .45937 .57683 L .46098 .5771 L .707 .577 .707 r
F
.46098 .5771 m .46413 .60895 L p .44997 .58784 L F P
0 g
s
.46413 .60895 m .46098 .5771 L p .48183 .58472 L .707 .577 .707 r
F P
0 g
s
.47921 .58353 m .48183 .58472 L p .46098 .5771 L .707 .577 .707 r
F P
0 g
s
.48183 .58472 m .482 .58479 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .48183 .58472 L .48086 .58633 L .707 .577 .707 r
F
.482 .58479 m .48534 .61858 L .46651 .61003 L p F P
0 g
s
.46651 .61003 m .46413 .60895 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.48086 .58633 m .482 .58479 L .46651 .61003 L .707 .577 .707 r
F
.4968 .53706 m .49578 .56168 L p .48387 .58136 L F P
0 g
s
.49578 .56168 m .49445 .59389 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .29477 .62255 L .30152 .60728 L p .707 .577 .707 r
F P
0 g
s
.49752 .68432 m .49659 .70332 L .4936 .69844 L p .707 .577 .707 r
F P
0 g
s
.4936 .69844 m .49454 .67945 L .49752 .68432 L p .707 .577 .707 r
F P
0 g
s
.30066 .58399 m .30302 .52716 L .31932 .52318 L p .707 .577 .707 r
F P
0 g
s
.49482 .59762 m .49817 .6314 L .48534 .61858 L p .707 .577 .707 r
F P
0 g
s
.48534 .61858 m .482 .58479 L .49482 .59762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30081 .66826 m .29987 .68726 L .29289 .69156 L p .707 .577 .707 r
F P
0 g
s
.30152 .60728 m .30487 .64106 L .29811 .65633 L p .707 .577 .707 r
F P
0 g
s
.31932 .52318 m .31696 .58001 L .30066 .58399 L p .707 .577 .707 r
F P
0 g
s
.30487 .64106 m .30152 .60728 L .31757 .59301 L p .707 .577 .707 r
F P
0 g
s
.49454 .67945 m .4936 .69844 L .48093 .69347 L p .707 .577 .707 r
F P
0 g
s
.48093 .69347 m .48187 .67447 L .49454 .67945 L p .707 .577 .707 r
F P
0 g
s
.31696 .58001 m .31932 .52318 L .3433 .52059 L p .707 .577 .707 r
F P
0 g
s
.29987 .68726 m .30081 .66826 L .31708 .66496 L p .707 .577 .707 r
F P
0 g
s
.31708 .66496 m .31614 .68395 L .29987 .68726 L p .707 .577 .707 r
F P
0 g
s
.31757 .59301 m .32091 .6268 L .30487 .64106 L p .707 .577 .707 r
F P
0 g
s
.3433 .52059 m .34095 .57741 L .31696 .58001 L p .707 .577 .707 r
F P
0 g
s
.32091 .6268 m .31757 .59301 L .34133 .58114 L p .707 .577 .707 r
F P
0 g
s
.34095 .57741 m .3433 .52059 L .37264 .51963 L p .707 .577 .707 r
F P
0 g
s
.48187 .67447 m .48093 .69347 L .45983 .68888 L p .707 .577 .707 r
F P
0 g
s
.45983 .68888 m .46077 .66988 L .48187 .67447 L p .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .40209 .57724 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43325 .57968 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .4055 .60266 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .43355 .57239 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43662 .60346 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .43328 .56968 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .40235 .57081 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .40235 .57081 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40216 .56887 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .4356 .52285 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40444 .52041 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .43355 .57239 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .37028 .57646 L .34095 .57741 L p .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .40444 .52041 L p .38002 .56048 L .707 .577 .707 r
F P
0 g
s
.37028 .57646 m .37045 .57253 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.37464 .5723 m .40216 .56887 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .37028 .57646 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .40235 .57081 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .40235 .57081 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40209 .57724 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .37382 .60661 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .4055 .60266 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37047 .57282 L .37464 .5723 L p .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37464 .5723 L .40064 .5709 L .707 .577 .707 r
F
.37275 .5724 m .37045 .57253 L .38002 .56048 L F
.37045 .57253 m .37264 .51963 L p .38002 .56048 L F P
0 g
s
.34467 .61492 m .34379 .60607 L p .37047 .57282 L .707 .577 .707 r
F P
0 g
s
.34379 .60607 m .34133 .58114 L .37014 .57292 L p .707 .577 .707 r
F P
0 g
s
.37014 .57292 m .37047 .57282 L p .34379 .60607 L .707 .577 .707 r
F P
0 g
s
.34133 .58114 m .34467 .61492 L .32091 .6268 L p .707 .577 .707 r
F P
0 g
s
.31614 .68395 m .31708 .66496 L .34104 .66297 L p .707 .577 .707 r
F P
0 g
s
.34104 .66297 m .3401 .68197 L .31614 .68395 L p .707 .577 .707 r
F P
0 g
s
.37047 .57282 m .37382 .60661 L .34467 .61492 L p .707 .577 .707 r
F P
0 g
s
.46077 .66988 m .45983 .68888 L .43236 .68513 L p .707 .577 .707 r
F P
0 g
s
.43236 .68513 m .43329 .66613 L .46077 .66988 L p .707 .577 .707 r
F P
0 g
s
.3401 .68197 m .34104 .66297 L .37035 .6625 L p .707 .577 .707 r
F P
0 g
s
.37035 .6625 m .36941 .6815 L .3401 .68197 L p .707 .577 .707 r
F P
0 g
s
.43329 .66613 m .43236 .68513 L .4012 .68258 L p .707 .577 .707 r
F P
0 g
s
.4012 .68258 m .40214 .66359 L .43329 .66613 L p .707 .577 .707 r
F P
0 g
s
.36941 .6815 m .37035 .6625 L .40214 .66359 L p .707 .577 .707 r
F P
0 g
s
.40214 .66359 m .4012 .68258 L .36941 .6815 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Yoo`d008Io
o`00OWoo30001UYF00<005YFFUH015YF2@00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol007=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@007=oo`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001]Ool30007FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006]oo`80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8006]oo`00JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uoo`00Igoo
0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00<005YF00001`0000=JEP00FUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00FGoo3@000eYF00<005YFFUH00UYF4@001EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000QooaT004Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000eOol005=oo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP05Ool005YFFUH0000^Ool005=oo`03001JEP0000=J
EPd000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol01000FUH005YF0P0015YF00<005YF
FUH00`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00L005YFFUIJEWooFUH00002FUH2000]Ool005=oo`03001JEP00008000EJEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF00EooeYFFUIJEP0000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P000UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP0000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P00;Goo001COol20002FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001DOol200000eYF
001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`<00003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06
001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EWoo00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000EJEP03001JEUYF00=JEP04001JEUYF0004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000QJEP03001JEUYF00AJEP@00003FUH005YF00AJEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00?goo20003Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH03`0015YF
00<005YFFUH00UYF2P000eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000cOol<0003FUH0
0`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH300001Goo001JEUYF00001UYF00@005YFFUIJEPT0
00QJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`000UYF0`001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
1EYF00<005YFFUH00`0017oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH010001EYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0;7oo000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30003FUH300001Goo001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF0P000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P000UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P001EYF00@005YF0000009JEP03001J
EUYF00AJEP<000IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF008000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEP00FUH0
000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYF0003FUH00`00FUH00005FUH01000FUIJEP000UYF00<005YFFUH00eYF
1@001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0000=JEP0000000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH00`00FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50005
FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF00@005YF0000009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002eo
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP05001JEUYFFUIoo`04FUH00`00FUIJ
EP06FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF0`001UYF
00<005YFFUH02EYF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70008
FUH80004FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF0P0000=JEP00FUH00UYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EPH000AJEP03001JEUYF008002eoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000UYF00D005YFFUIJEP0000EJEP04001JEUYF0002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH00`00FUH000020004OolI0002Ool20002FUH00`00FUIJEP02000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0`0097oo0`000UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP020005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF0P00:Goo00D0
05YFFUIJEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF0`000UYF00@005YFFUH0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00D005YF000005YF00@002Moo`04001JEUYF000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP8000MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEQ`000IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000EJEP<002Ioo`03001JEP0002eoo`00;7oo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF0P0025YF00<005YFFUH01UYF0P000UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH01@00FUIJEP00FUH00P001EYF00@005YFFUH000Uoo`<001Qoo`@002eoo`00;7oo00<005YF0000
15YF00@005YFFUIJEPX00003FUH005YF00MJEP03001JEUYF00IJEP@0009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
00000UYF0P001EYF00<005YFFUH00P001goo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YF
00000UYF1P000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP8000=JEP8000AJEP80009JEP8000Moo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00FUH0
00020005FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF0P0015YF0P000UYF0P001goo1@0057oo00L005YFFUIJEP00FUH0
000]Ool002aoo`80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0P000UYF0P0027oo0`004goo
0P0015YF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH@0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0P000UYF0P0077oo0P0000=J
EP00FUH015YF0P00;Goo000]Ool200000eYF001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH000020002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5
0005FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00@005YF
FUIJEP8001Yoo`8000=JEP03001JEUYF00=JEP8002eoo`00;goo0`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH015YF1@001EYF00<005YFFUH010001EYF0`0000=JEP00FUH00UYF0P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`0000=J
EP00FUH015YF00@005YFFUIJEP8001Moo`<000EJEP03001JEUYF00=JEP03001oogoo02aoo`00;goo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPd0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00EJEP<000AJEPh0009JEP@0009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH20005FUH01000FUIJEUYF0P00
4goo100000=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH60008FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YF
FUH00eYF200015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP@0
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEPH000=JEPP000Ioo`L000EJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo02ao
o`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF3@0015YF00<005YFFUH00UYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`001EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00000030000eYF00<005YFFUH00UYF4@0000=JEP00FUH01UYF00D005YFFUIJ
EP0002moo`00;Goo0P001EYF00<005YFFUH00eYF00<005YF00000P003Goo2@001Goo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000=JEP04001JEP00000`Ool002eoo`8000EJEP03001JEUYF00=JEP8002Aoo`X000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004000bOol002aoo`03
001JEP0000EJEP04001JEUYFFUH2000XOol01000FUIJEP000UYF00<005YF00007P0025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
035oo`00;7oo00<005YF00001EYF00@005YF000002]oo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`04
001JEUYF0004FUH2000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04001J
EUYF0003FUH00`00Oomoo`0BOol3000HOol30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH0100000=JEP0000000UYF0P001eYF00<005YFFUH01EYF1@000eYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00D005YFFUH005YF008001Aoo`D001Ioo`04001JEP00
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF20000eYF00<005YFFUH00P00;Woo
000/Ool00`00FUIJEP02000FOol5000EOol00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH30006FUH00`00
FUH0000>0002FUH2000^Ool002eoo`03001JEP0001Moo`D001Aoo`04001JEUYFFUH20002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool4000GOol3000COol30003FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH50004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000]Ool20002FUH00`00Oomoo`0XOol20002FUH00`00FUIJEP02FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`04001JEUYFFUH2
000WOol20004FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH015YF
300000=JEP00FUH02EYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo1@0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00;goo
000]Ool01P00FUIJEUYF001JEP<0029oo`8000IJEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000;Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Woo
000]Ool20002FUH00`00FUIJEP02FUH3000KOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YF000010001UYF00<005YFFUH00UYF0P003Goo00@005YFFUH0009ooaX003Qoo`00;Goo
0P000UYF8`001EYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP00
00<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP8000ioo`03001JEP0005Aoo`00;Woo0`000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH00P000UYF
00<005YFFUH00eYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF100015YF0P003Woo0`00E7oo000]Ool20004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF001o
o`00009JEP04001JEUYFFUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF0P003Goo0P0000=JEP000000Dgoo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP050002Ool01@00FUIJEP00FUH00`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000002goo0P0000=JEP00FUH00P00Dgoo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH3000017oo001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10002Woo00H005YF
FUIJEP00FUH2001COol002aoo`03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01000FUH0000027oo0P0015YF00@005YFFUH005=oo`00;7oo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH01EYF400015YF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000006Ool200000eYF001JEP04FUH00`00
FUH0001COol002aoo`03001JEP000080009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP0017oo0P000eYF00<005YFFUH00eYF0P00E7oo000/Ool20002FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP02FUH20004Ool300000eYF
001JEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00Ool00`001EYF00<0
05YFFUH00eYF0P00E7oo000]Ool01000FUIJEP001EYF10001UYF00<005YFFUH01EYF0`001eYF00<0
05YF000020000UYF10000UYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0Dgoo000^Ool30005FUH01000FUIJEUYF1000
0UYF00<005YFFUH01EYF00<005YFFUH00eYF1P001EYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo05=oo`00<7oo0`000eYF00<005YFFUH01EYF40000UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@0000=JEP00FUH0
1UYF00D005YFFUIJEP0005Ioo`00<goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000eYF1P000eYF00@005YF000005Moo`00>Woo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0017oo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP800003FUH005YF00IJEP03001JEP0000@005Uoo`00@goo7`002Goo0`001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF009JEP<005Qoo`00KWoo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P00EGoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000EGoo001cOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH50002FUH50003FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001gOol60002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001eYF1@001EYF00<005YFFUH00eYF
1`000eYF00<005YFFUH00P00EGoo001mOolO0005FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP0?
00000eYF0000001EOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF
00IJEP<0009JEPL000AJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol0091oo`@000AJEP03001J
EUYF00AJEQ0000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol009Aoo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000EGoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03001FOol009aooa4000AJEP03001JEUYF00IJEP04
001JEUYFFUH6001IOol00:eooa4005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59556 .70474 m .5644 .70337 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59556 .70474 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59449 .78841 m .62618 .79101 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59449 .78841 L p .59916 .75385 L .707 .577 .707 r
F P
0 g
s
.59936 .75234 m .59764 .75234 L .59916 .75385 L .707 .577 .707 r
F
.59449 .78841 m .59764 .75234 L p .56889 .75032 L F P
0 g
s
.56337 .78535 m .59449 .78841 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56337 .78535 L p .56855 .75246 L .707 .577 .707 r
F P
0 g
s
.56889 .75032 m .56645 .75015 L .56855 .75246 L .707 .577 .707 r
F
.5644 .70337 m .53693 .69845 L p .55916 .74213 L F P
0 g
s
.56298 .74963 m .56645 .75015 L .55916 .74213 L .707 .577 .707 r
F
.56645 .75015 m .5644 .70337 L p .55916 .74213 L F P
0 g
s
.58885 .74353 m .58222 .73689 L .56675 .75703 L .707 .577 .707 r
F
.56512 .71976 m .56645 .75015 L p .58222 .73689 L F P
0 g
s
.56645 .75015 m .56675 .75703 L p .58222 .73689 L .707 .577 .707 r
F P
0 g
s
.56337 .78535 m .56645 .75015 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .56337 .78535 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53586 .78212 L p .54038 .74808 L .707 .577 .707 r
F P
0 g
s
.54062 .74629 m .53901 .74605 L .54038 .74808 L .707 .577 .707 r
F
.53693 .69845 m .51584 .69048 L p .53431 .73904 L F P
0 g
s
.51584 .69048 m .5032 .68024 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.52079 .74118 m .518 .74077 L p .53901 .74605 L .707 .577 .707 r
F P
0 g
s
.518 .74077 m .51466 .77904 L .53348 .78178 L p .707 .577 .707 r
F P
0 g
s
.53348 .78178 m .53586 .78212 L p .51914 .74341 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .518 .74077 L .53348 .78178 L .707 .577 .707 r
F
.51466 .77904 m .518 .74077 L .50518 .73814 L p F P
0 g
s
.50555 .73391 m .51819 .74415 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.5032 .68024 m .50422 .70349 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.50422 .70349 m .50555 .73391 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51819 .74415 m .51803 .74044 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51803 .74044 m .51584 .69048 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .53901 .74605 L p .51817 .74081 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .51817 .74081 L .518 .74077 L .707 .577 .707 r
F
.53586 .78212 m .51817 .74081 L .51914 .74341 L F
.53674 .74544 m .53901 .74605 L .53431 .73904 L F
.53901 .74605 m .53693 .69845 L p .53431 .73904 L F P
0 g
s
.53693 .69845 m .53901 .74605 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.51584 .69048 m .51819 .74415 L .53928 .75212 L p .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53921 .74385 L .52079 .74118 L p .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .53901 .74605 L p .53674 .74544 L .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .56675 .75703 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53928 .75212 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53921 .74385 m .53901 .74605 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .53921 .74385 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56672 .74708 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .56645 .75015 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .56645 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .59791 .75841 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59406 .75209 m .58885 .74353 L .57683 .75088 L .707 .577 .707 r
F
.59406 .75209 m .57683 .75088 L .56675 .75703 L F
.5644 .70337 m .56512 .71976 L p .58885 .74353 L F P
0 g
s
.59556 .70474 m .59764 .75234 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62952 .75274 L .62535 .7524 L p .707 .577 .707 r
F P
0 g
s
.62535 .7524 m .59784 .75015 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62535 .7524 L .59936 .75234 L .707 .577 .707 r
F
.62736 .70245 m .59556 .70474 L p .62724 .7524 L F P
0 g
s
.62952 .75274 m .62618 .79101 L .65533 .79288 L p .707 .577 .707 r
F P
0 g
s
.65533 .79288 m .65867 .75461 L .62952 .75274 L p .707 .577 .707 r
F P
0 g
s
.62971 .75612 m .62955 .75241 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62955 .75241 m .62736 .70245 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .62971 .75612 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59791 .75841 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .59764 .75234 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .56672 .74708 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59784 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .59764 .75234 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.62736 .70245 m .62971 .75612 L .65905 .75039 L p .707 .577 .707 r
F P
0 g
s
.65905 .75039 m .65669 .69672 L .62736 .70245 L p .707 .577 .707 r
F P
0 g
s
.65669 .69672 m .65905 .75039 L .68303 .74176 L p .707 .577 .707 r
F P
0 g
s
.68303 .74176 m .68068 .6881 L .65669 .69672 L p .707 .577 .707 r
F P
0 g
s
.68068 .6881 m .68303 .74176 L .69933 .7311 L p .707 .577 .707 r
F P
0 g
s
.69933 .7311 m .69698 .67744 L .68068 .6881 L p .707 .577 .707 r
F P
0 g
s
.65867 .75461 m .65533 .79288 L .67909 .79385 L p .707 .577 .707 r
F P
0 g
s
.67909 .79385 m .68243 .75558 L .65867 .75461 L p .707 .577 .707 r
F P
0 g
s
.5988 .86257 m .59786 .84483 L .5667 .84355 L p .707 .577 .707 r
F P
0 g
s
.59786 .84483 m .5988 .86257 L .63059 .85999 L p .707 .577 .707 r
F P
0 g
s
.63059 .85999 m .62965 .84225 L .59786 .84483 L p .707 .577 .707 r
F P
0 g
s
.62965 .84225 m .63059 .85999 L .6599 .8538 L p .707 .577 .707 r
F P
0 g
s
.6599 .8538 m .65896 .83606 L .62965 .84225 L p .707 .577 .707 r
F P
0 g
s
.56764 .86129 m .5667 .84355 L .53923 .83854 L p .707 .577 .707 r
F P
0 g
s
.5667 .84355 m .56764 .86129 L .5988 .86257 L p .707 .577 .707 r
F P
0 g
s
.68243 .75558 m .67909 .79385 L .69513 .79382 L p .707 .577 .707 r
F P
0 g
s
.69513 .79382 m .69847 .75555 L .68243 .75558 L p .707 .577 .707 r
F P
0 g
s
.69698 .67744 m .69933 .7311 L .70634 .71945 L p .707 .577 .707 r
F P
0 g
s
.70634 .71945 m .70399 .66578 L .69698 .67744 L p .707 .577 .707 r
F P
0 g
s
.65896 .83606 m .6599 .8538 L .68386 .84461 L p .707 .577 .707 r
F P
0 g
s
.68386 .84461 m .68292 .82687 L .65896 .83606 L p .707 .577 .707 r
F P
0 g
s
.53923 .83854 m .54017 .85627 L .56764 .86129 L p .707 .577 .707 r
F P
0 g
s
.50518 .73814 m .50183 .77641 L .51466 .77904 L p .707 .577 .707 r
F P
0 g
s
.54017 .85627 m .53923 .83854 L .51813 .83028 L p .707 .577 .707 r
F P
0 g
s
.50555 .73391 m .5032 .68024 L .50024 .66873 L p .707 .577 .707 r
F P
0 g
s
.51813 .83028 m .51906 .84802 L .54017 .85627 L p .707 .577 .707 r
F P
0 g
s
.68292 .82687 m .68386 .84461 L .70012 .83331 L p .707 .577 .707 r
F P
0 g
s
.70012 .83331 m .69919 .81558 L .68292 .82687 L p .707 .577 .707 r
F P
0 g
s
.69847 .75555 m .69513 .79382 L .70189 .79279 L p .707 .577 .707 r
F P
0 g
s
.70189 .79279 m .70523 .75452 L .69847 .75555 L p .707 .577 .707 r
F P
0 g
s
.70399 .66578 m .70634 .71945 L .70338 .70793 L p .707 .577 .707 r
F P
0 g
s
.70338 .70793 m .70103 .65427 L .70399 .66578 L p .707 .577 .707 r
F P
0 g
s
.51906 .84802 m .51813 .83028 L .50546 .81958 L p .707 .577 .707 r
F P
0 g
s
.50024 .66873 m .50259 .7224 L .50555 .73391 L p .707 .577 .707 r
F P
0 g
s
.50183 .77641 m .50518 .73814 L .50199 .73622 L p .707 .577 .707 r
F P
0 g
s
.50199 .73622 m .49864 .77448 L .50183 .77641 L p .707 .577 .707 r
F P
0 g
s
.50546 .81958 m .5064 .83732 L .51906 .84802 L p .707 .577 .707 r
F P
0 g
s
.48829 .82105 m .49149 .31708 L .44749 .31429 L p .707 .577 .707 r
F P
0 g
s
.50259 .7224 m .50024 .66873 L .50725 .65707 L p .707 .577 .707 r
F P
0 g
s
.5064 .83732 m .50546 .81958 L .50247 .8075 L p .707 .577 .707 r
F P
0 g
s
.50725 .65707 m .5096 .71074 L .50259 .7224 L p .707 .577 .707 r
F P
0 g
s
.50247 .8075 m .50341 .82524 L .5064 .83732 L p .707 .577 .707 r
F P
0 g
s
.49864 .77448 m .50199 .73622 L .50874 .73519 L p .707 .577 .707 r
F P
0 g
s
.50874 .73519 m .5054 .77346 L .49864 .77448 L p .707 .577 .707 r
F P
0 g
s
.5096 .71074 m .50725 .65707 L .52355 .64641 L p .707 .577 .707 r
F P
0 g
s
.50341 .82524 m .50247 .8075 L .50946 .79521 L p .707 .577 .707 r
F P
0 g
s
.52355 .64641 m .5259 .70008 L .5096 .71074 L p .707 .577 .707 r
F P
0 g
s
.50946 .79521 m .51039 .81295 L .50341 .82524 L p .707 .577 .707 r
F P
0 g
s
.5054 .77346 m .50874 .73519 L .52479 .73516 L p .707 .577 .707 r
F P
0 g
s
.52479 .73516 m .52144 .77342 L .5054 .77346 L p .707 .577 .707 r
F P
0 g
s
.51039 .81295 m .50946 .79521 L .52572 .78392 L p .707 .577 .707 r
F P
0 g
s
.52572 .78392 m .52666 .80166 L .51039 .81295 L p .707 .577 .707 r
F P
0 g
s
.52144 .77342 m .52479 .73516 L .54855 .73612 L p .707 .577 .707 r
F P
0 g
s
.54855 .73612 m .5452 .77439 L .52144 .77342 L p .707 .577 .707 r
F P
0 g
s
.52666 .80166 m .52572 .78392 L .54968 .77473 L p .707 .577 .707 r
F P
0 g
s
.54968 .77473 m .55062 .79247 L .52666 .80166 L p .707 .577 .707 r
F P
0 g
s
.49149 .31708 m .48829 .82105 L .53323 .82028 L p .707 .577 .707 r
F P
0 g
s
.5259 .70008 m .52355 .64641 L .54753 .63779 L p .707 .577 .707 r
F P
0 g
s
.54753 .63779 m .54989 .69146 L .5259 .70008 L p .707 .577 .707 r
F P
0 g
s
.53323 .82028 m .53644 .31631 L .49149 .31708 L p .707 .577 .707 r
F P
0 g
s
.69919 .81558 m .70012 .83331 L .70711 .82102 L p .707 .577 .707 r
F P
0 g
s
.70711 .82102 m .70617 .80329 L .69919 .81558 L p .707 .577 .707 r
F P
0 g
s
.54989 .69146 m .54753 .63779 L .57687 .63206 L p .707 .577 .707 r
F P
0 g
s
.57687 .63206 m .57922 .68572 L .54989 .69146 L p .707 .577 .707 r
F P
0 g
s
.5452 .77439 m .54855 .73612 L .57769 .738 L p .707 .577 .707 r
F P
0 g
s
.57769 .738 m .57435 .77627 L .5452 .77439 L p .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .57769 .738 L .58259 .7384 L p .707 .577 .707 r
F P
0 g
s
.58259 .7384 m .60938 .74059 L p .57818 .77236 L .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .58259 .7384 L .57818 .77236 L .707 .577 .707 r
F
.63983 .63114 m .64218 .68481 L .61102 .68343 L p F P
0 g
s
.61102 .68343 m .60867 .62977 L .63983 .63114 L p .707 .577 .707 r
F P
0 g
s
.6405 .74365 m .63716 .78192 L .61154 .7794 L p .707 .577 .707 r
F P
0 g
s
.61154 .7794 m .60604 .77886 L p .61189 .77288 L .707 .577 .707 r
F P
0 g
s
.61189 .77288 m .6405 .74365 L .61154 .7794 L .707 .577 .707 r
F
.66801 .74689 m .66467 .78515 L .63716 .78192 L p F P
0 g
s
.63716 .78192 m .6405 .74365 L .66801 .74689 L p .707 .577 .707 r
F P
0 g
s
.60604 .77886 m .60938 .74059 L .6405 .74365 L p .707 .577 .707 r
F P
0 g
s
.64194 .76724 m .64288 .78497 L .61172 .7837 L p .707 .577 .707 r
F P
0 g
s
.61172 .7837 m .61078 .76596 L .64194 .76724 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .64177 .78791 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63498 .29503 m .63463 .35034 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63463 .35034 m .63177 .799 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.60938 .74059 m .60604 .77886 L .57435 .77627 L p .707 .577 .707 r
F P
0 g
s
.57993 .78628 m .57899 .76854 L .61078 .76596 L p .707 .577 .707 r
F P
0 g
s
.61078 .76596 m .61172 .7837 L .57993 .78628 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .63177 .799 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.61187 .30472 m .61048 .52333 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.60867 .62977 m .61102 .68343 L .57922 .68572 L p .707 .577 .707 r
F P
0 g
s
.61048 .52333 m .60867 .80869 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.55062 .79247 m .54968 .77473 L .57899 .76854 L p .707 .577 .707 r
F P
0 g
s
.57899 .76854 m .57993 .78628 L .55062 .79247 L p .707 .577 .707 r
F P
0 g
s
.53644 .31631 m .53323 .82028 L .57471 .81602 L p .707 .577 .707 r
F P
0 g
s
.57471 .81602 m .57792 .31205 L .53644 .31631 L p .707 .577 .707 r
F P
0 g
s
.44428 .81826 m .44749 .31429 L .40872 .3082 L p .707 .577 .707 r
F P
0 g
s
.44749 .31429 m .44428 .81826 L .48829 .82105 L p .707 .577 .707 r
F P
0 g
s
.70523 .75452 m .70189 .79279 L .6987 .79087 L p .707 .577 .707 r
F P
0 g
s
.6987 .79087 m .70204 .7526 L .70523 .75452 L p .707 .577 .707 r
F P
0 g
s
.70103 .65427 m .70338 .70793 L .69074 .69769 L p .707 .577 .707 r
F P
0 g
s
.69074 .69769 m .68839 .64403 L .70103 .65427 L p .707 .577 .707 r
F P
0 g
s
.57922 .68572 m .57687 .63206 L .60867 .62977 L p .707 .577 .707 r
F P
0 g
s
.57792 .31205 m .57471 .81602 L .60867 .80869 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .61187 .30472 L .57792 .31205 L p .707 .577 .707 r
F P
0 g
s
.70617 .80329 m .70711 .82102 L .70412 .80894 L p .707 .577 .707 r
F P
0 g
s
.70412 .80894 m .70318 .7912 L .70617 .80329 L p .707 .577 .707 r
F P
0 g
s
.25255 .66793 m .22139 .66655 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25255 .66793 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25148 .7516 m .28317 .75419 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25148 .7516 L p .25615 .71704 L .707 .577 .707 r
F P
0 g
s
.25635 .71553 m .25464 .71552 L .25615 .71704 L .707 .577 .707 r
F
.25148 .7516 m .25464 .71552 L p .22588 .7135 L F P
0 g
s
.22036 .74854 m .25148 .7516 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22036 .74854 L p .22554 .71565 L .707 .577 .707 r
F P
0 g
s
.22588 .7135 m .22344 .71333 L .22554 .71565 L .707 .577 .707 r
F
.22139 .66655 m .19392 .66164 L p .21615 .70531 L F P
0 g
s
.21997 .71281 m .22344 .71333 L .21615 .70531 L .707 .577 .707 r
F
.22344 .71333 m .22139 .66655 L p .21615 .70531 L F P
0 g
s
.24584 .70672 m .23921 .70007 L .22374 .72022 L .707 .577 .707 r
F
.22211 .68295 m .22344 .71333 L p .23921 .70007 L F P
0 g
s
.22344 .71333 m .22374 .72022 L p .23921 .70007 L .707 .577 .707 r
F P
0 g
s
.22036 .74854 m .22344 .71333 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .22036 .74854 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19285 .74531 L p .19738 .71127 L .707 .577 .707 r
F P
0 g
s
.19761 .70947 m .19601 .70923 L .19738 .71127 L .707 .577 .707 r
F
.19392 .66164 m .17283 .65367 L p .1913 .70222 L F P
0 g
s
.17283 .65367 m .16019 .64343 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17778 .70436 m .17499 .70396 L p .19601 .70923 L .707 .577 .707 r
F P
0 g
s
.17499 .70396 m .17165 .74222 L .19048 .74496 L p .707 .577 .707 r
F P
0 g
s
.19048 .74496 m .19285 .74531 L p .17613 .70659 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17499 .70396 L .19048 .74496 L .707 .577 .707 r
F
.17165 .74222 m .17499 .70396 L .16217 .70132 L p F P
0 g
s
.16254 .6971 m .17518 .70734 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16019 .64343 m .16121 .66667 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16121 .66667 m .16254 .6971 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17518 .70734 m .17502 .70362 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17502 .70362 m .17283 .65367 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .19601 .70923 L p .17516 .704 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17516 .704 L .17499 .70396 L .707 .577 .707 r
F
.19285 .74531 m .17516 .704 L .17613 .70659 L F
.19373 .70862 m .19601 .70923 L .1913 .70222 L F
.19601 .70923 m .19392 .66164 L p .1913 .70222 L F P
0 g
s
.19392 .66164 m .19601 .70923 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.17283 .65367 m .17518 .70734 L .19627 .7153 L p .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .1962 .70704 L .17778 .70436 L p .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .19601 .70923 L p .19373 .70862 L .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .22374 .72022 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19627 .7153 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.1962 .70704 m .19601 .70923 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .1962 .70704 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22371 .71027 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .22344 .71333 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .22344 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .2549 .7216 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25105 .71527 m .24584 .70672 L .23382 .71406 L .707 .577 .707 r
F
.25105 .71527 m .23382 .71406 L .22374 .72022 L F
.22139 .66655 m .22211 .68295 L p .24584 .70672 L F P
0 g
s
.25255 .66793 m .25464 .71552 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28651 .71593 L .28235 .71558 L p .707 .577 .707 r
F P
0 g
s
.28235 .71558 m .25483 .71333 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28235 .71558 L .25635 .71553 L .707 .577 .707 r
F
.28435 .66564 m .25255 .66793 L p .28423 .71559 L F P
0 g
s
.28651 .71593 m .28317 .75419 L .31232 .75607 L p .707 .577 .707 r
F P
0 g
s
.31232 .75607 m .31566 .7178 L .28651 .71593 L p .707 .577 .707 r
F P
0 g
s
.28671 .71931 m .28654 .71559 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28654 .71559 m .28435 .66564 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .28671 .71931 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .2549 .7216 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .25464 .71552 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .22371 .71027 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25483 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .25464 .71552 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.40552 .81217 m .40872 .3082 L .379 .29941 L p .707 .577 .707 r
F P
0 g
s
.40872 .3082 m .40552 .81217 L .44428 .81826 L p .707 .577 .707 r
F P
0 g
s
.28435 .66564 m .28671 .71931 L .31604 .71357 L p .707 .577 .707 r
F P
0 g
s
.31604 .71357 m .31368 .6599 L .28435 .66564 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68839 .64403 m .69074 .69769 L .66965 .68973 L p .707 .577 .707 r
F P
0 g
s
.66965 .68973 m .6673 .63606 L .68839 .64403 L p .707 .577 .707 r
F P
0 g
s
.31368 .6599 m .31604 .71357 L .34003 .70495 L p .707 .577 .707 r
F P
0 g
s
.34003 .70495 m .33767 .65128 L .31368 .6599 L p .707 .577 .707 r
F P
0 g
s
.70204 .7526 m .6987 .79087 L .68587 .78824 L p .707 .577 .707 r
F P
0 g
s
.68587 .78824 m .68922 .74997 L .70204 .7526 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .63498 .29503 L .61187 .30472 L p .707 .577 .707 r
F P
0 g
s
.70318 .7912 m .70412 .80894 L .69145 .79825 L p .707 .577 .707 r
F P
0 g
s
.69145 .79825 m .69052 .78051 L .70318 .7912 L p .707 .577 .707 r
F P
0 g
s
.33767 .65128 m .34003 .70495 L .35632 .69429 L p .707 .577 .707 r
F P
0 g
s
.35632 .69429 m .35397 .64062 L .33767 .65128 L p .707 .577 .707 r
F P
0 g
s
.37579 .80339 m .379 .29941 L .36122 .2888 L p .707 .577 .707 r
F P
0 g
s
.379 .29941 m .37579 .80339 L .40552 .81217 L p .707 .577 .707 r
F P
0 g
s
.6673 .63606 m .66965 .68973 L .64218 .68481 L p .707 .577 .707 r
F P
0 g
s
.64218 .68481 m .63983 .63114 L .6673 .63606 L p .707 .577 .707 r
F P
0 g
s
.31566 .7178 m .31232 .75607 L .33608 .75704 L p .707 .577 .707 r
F P
0 g
s
.33608 .75704 m .33942 .71877 L .31566 .7178 L p .707 .577 .707 r
F P
0 g
s
.68922 .74997 m .68587 .78824 L .66467 .78515 L p .707 .577 .707 r
F P
0 g
s
.66467 .78515 m .66801 .74689 L .68922 .74997 L p .707 .577 .707 r
F P
0 g
s
.25579 .82575 m .25485 .80801 L .22369 .80674 L p .707 .577 .707 r
F P
0 g
s
.25485 .80801 m .25579 .82575 L .28758 .82317 L p .707 .577 .707 r
F P
0 g
s
.28758 .82317 m .28664 .80543 L .25485 .80801 L p .707 .577 .707 r
F P
0 g
s
.28664 .80543 m .28758 .82317 L .31689 .81698 L p .707 .577 .707 r
F P
0 g
s
.31689 .81698 m .31595 .79924 L .28664 .80543 L p .707 .577 .707 r
F P
0 g
s
.22463 .82447 m .22369 .80674 L .19622 .80172 L p .707 .577 .707 r
F P
0 g
s
.22369 .80674 m .22463 .82447 L .25579 .82575 L p .707 .577 .707 r
F P
0 g
s
.69052 .78051 m .69145 .79825 L .67035 .78999 L p .707 .577 .707 r
F P
0 g
s
.67035 .78999 m .66941 .77225 L .69052 .78051 L p .707 .577 .707 r
F P
0 g
s
.33942 .71877 m .33608 .75704 L .35212 .757 L p .707 .577 .707 r
F P
0 g
s
.35212 .757 m .35547 .71874 L .33942 .71877 L p .707 .577 .707 r
F P
0 g
s
.64177 .78791 m .64498 .28394 L .63498 .29503 L p .707 .577 .707 r
F P
0 g
s
.35397 .64062 m .35632 .69429 L .36334 .68263 L p .707 .577 .707 r
F P
0 g
s
.36334 .68263 m .36098 .62896 L .35397 .64062 L p .707 .577 .707 r
F P
0 g
s
.31595 .79924 m .31689 .81698 L .34085 .80779 L p .707 .577 .707 r
F P
0 g
s
.34085 .80779 m .33991 .79005 L .31595 .79924 L p .707 .577 .707 r
F P
0 g
s
.19622 .80172 m .19716 .81946 L .22463 .82447 L p .707 .577 .707 r
F P
0 g
s
.16217 .70132 m .15882 .73959 L .17165 .74222 L p .707 .577 .707 r
F P
0 g
s
.19716 .81946 m .19622 .80172 L .17512 .79346 L p .707 .577 .707 r
F P
0 g
s
.16254 .6971 m .16019 .64343 L .15723 .63192 L p .707 .577 .707 r
F P
0 g
s
.35547 .71874 m .35212 .757 L .35888 .75598 L p .707 .577 .707 r
F P
0 g
s
.35888 .75598 m .36222 .71771 L .35547 .71874 L p .707 .577 .707 r
F P
0 g
s
.36038 .67112 m .35802 .61745 L .36098 .62896 L p .707 .577 .707 r
F P
0 g
s
.35618 .77876 m .35712 .7965 L .3641 .78421 L p .707 .577 .707 r
F P
0 g
s
.3641 .78421 m .36316 .76647 L .35618 .77876 L p .707 .577 .707 r
F P
0 g
s
.36222 .71771 m .35888 .75598 L .35569 .75405 L p .707 .577 .707 r
F P
0 g
s
.35569 .75405 m .35903 .71578 L .36222 .71771 L p .707 .577 .707 r
F P
0 g
s
.35802 .61745 m .36038 .67112 L .34773 .66088 L p .707 .577 .707 r
F P
0 g
s
.34773 .66088 m .34538 .60721 L .35802 .61745 L p .707 .577 .707 r
F P
0 g
s
.35903 .71578 m .35569 .75405 L .34286 .75142 L p .707 .577 .707 r
F P
0 g
s
.34286 .75142 m .34621 .71315 L .35903 .71578 L p .707 .577 .707 r
F P
0 g
s
.36017 .75439 m .36111 .77213 L .34844 .76143 L p .707 .577 .707 r
F P
0 g
s
.34844 .76143 m .34751 .74369 L .36017 .75439 L p .707 .577 .707 r
F P
0 g
s
.35801 .79277 m .36122 .2888 L .35713 .27738 L p .707 .577 .707 r
F P
0 g
s
.36098 .62896 m .36334 .68263 L .36038 .67112 L p .707 .577 .707 r
F P
0 g
s
.36316 .76647 m .3641 .78421 L .36111 .77213 L p .707 .577 .707 r
F P
0 g
s
.36111 .77213 m .36017 .75439 L .36316 .76647 L p .707 .577 .707 r
F P
0 g
s
.36122 .2888 m .35801 .79277 L .37579 .80339 L p .707 .577 .707 r
F P
0 g
s
.17512 .79346 m .17606 .8112 L .19716 .81946 L p .707 .577 .707 r
F P
0 g
s
.33991 .79005 m .34085 .80779 L .35712 .7965 L p .707 .577 .707 r
F P
0 g
s
.35712 .7965 m .35618 .77876 L .33991 .79005 L p .707 .577 .707 r
F P
0 g
s
.66941 .77225 m .67035 .78999 L .64288 .78497 L p .707 .577 .707 r
F P
0 g
s
.64288 .78497 m .64194 .76724 L .66941 .77225 L p .707 .577 .707 r
F P
0 g
s
.17606 .8112 m .17512 .79346 L .16245 .78277 L p .707 .577 .707 r
F P
0 g
s
.15723 .63192 m .15958 .68558 L .16254 .6971 L p .707 .577 .707 r
F P
0 g
s
.15882 .73959 m .16217 .70132 L .15898 .6994 L p .707 .577 .707 r
F P
0 g
s
.15898 .6994 m .15563 .73767 L .15882 .73959 L p .707 .577 .707 r
F P
0 g
s
.16245 .78277 m .16339 .80051 L .17606 .8112 L p .707 .577 .707 r
F P
0 g
s
.64498 .28394 m .64177 .78791 L .63768 .77649 L p .707 .577 .707 r
F P
0 g
s
.63768 .77649 m .64089 .27252 L .64498 .28394 L p .707 .577 .707 r
F P
0 g
s
.15958 .68558 m .15723 .63192 L .16424 .62026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16339 .80051 m .16245 .78277 L .15946 .77069 L p .707 .577 .707 r
F P
0 g
s
.35713 .27738 m .35392 .78135 L .35801 .79277 L p .707 .577 .707 r
F P
0 g
s
.35392 .78135 m .35713 .27738 L .36712 .26628 L p .707 .577 .707 r
F P
0 g
s
.16424 .62026 m .16659 .67393 L .15958 .68558 L p .707 .577 .707 r
F P
0 g
s
.15946 .77069 m .1604 .78842 L .16339 .80051 L p .707 .577 .707 r
F P
0 g
s
.15563 .73767 m .15898 .6994 L .16573 .69837 L p .707 .577 .707 r
F P
0 g
s
.16573 .69837 m .16239 .73664 L .15563 .73767 L p .707 .577 .707 r
F P
0 g
s
.16659 .67393 m .16424 .62026 L .18054 .6096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64089 .27252 m .63768 .77649 L .6199 .76587 L p .707 .577 .707 r
F P
0 g
s
.6199 .76587 m .62311 .2619 L .64089 .27252 L p .707 .577 .707 r
F P
0 g
s
.34538 .60721 m .34773 .66088 L .32664 .65291 L p .707 .577 .707 r
F P
0 g
s
.32664 .65291 m .32429 .59924 L .34538 .60721 L p .707 .577 .707 r
F P
0 g
s
.1604 .78842 m .15946 .77069 L .16645 .7584 L p .707 .577 .707 r
F P
0 g
s
.18054 .6096 m .18289 .66326 L .16659 .67393 L p .707 .577 .707 r
F P
0 g
s
.16645 .7584 m .16738 .77613 L .1604 .78842 L p .707 .577 .707 r
F P
0 g
s
.18289 .66326 m .18054 .6096 L .20453 .60098 L p .707 .577 .707 r
F P
0 g
s
.16239 .73664 m .16573 .69837 L .18178 .69834 L p .707 .577 .707 r
F P
0 g
s
.18178 .69834 m .17843 .73661 L .16239 .73664 L p .707 .577 .707 r
F P
0 g
s
.36392 .77025 m .36712 .26628 L .39023 .25659 L p .707 .577 .707 r
F P
0 g
s
.36712 .26628 m .36392 .77025 L .35392 .78135 L p .707 .577 .707 r
F P
0 g
s
.32429 .59924 m .32664 .65291 L .29917 .648 L p .707 .577 .707 r
F P
0 g
s
.29917 .648 m .29682 .59433 L .32429 .59924 L p .707 .577 .707 r
F P
0 g
s
.16738 .77613 m .16645 .7584 L .18271 .7471 L p .707 .577 .707 r
F P
0 g
s
.20688 .65464 m .20453 .60098 L .23386 .59524 L p .707 .577 .707 r
F P
0 g
s
.20453 .60098 m .20688 .65464 L .18289 .66326 L p .707 .577 .707 r
F P
0 g
s
.34621 .71315 m .34286 .75142 L .32166 .74834 L p .707 .577 .707 r
F P
0 g
s
.32166 .74834 m .325 .71007 L .34621 .71315 L p .707 .577 .707 r
F P
0 g
s
.29682 .59433 m .29917 .648 L .26801 .64662 L p .707 .577 .707 r
F P
0 g
s
.26801 .64662 m .26566 .59295 L .29682 .59433 L p .707 .577 .707 r
F P
0 g
s
.18271 .7471 m .18365 .76484 L .16738 .77613 L p .707 .577 .707 r
F P
0 g
s
.62311 .2619 m .6199 .76587 L .59017 .75709 L p .707 .577 .707 r
F P
0 g
s
.59017 .75709 m .59338 .25312 L .62311 .2619 L p .707 .577 .707 r
F P
0 g
s
.17843 .73661 m .18178 .69834 L .20554 .69931 L p .707 .577 .707 r
F P
0 g
s
.20554 .69931 m .20219 .73758 L .17843 .73661 L p .707 .577 .707 r
F P
0 g
s
.23621 .64891 m .23386 .59524 L .26566 .59295 L p .707 .577 .707 r
F P
0 g
s
.23386 .59524 m .23621 .64891 L .20688 .65464 L p .707 .577 .707 r
F P
0 g
s
.34751 .74369 m .34844 .76143 L .32734 .75317 L p .707 .577 .707 r
F P
0 g
s
.32734 .75317 m .3264 .73544 L .34751 .74369 L p .707 .577 .707 r
F P
0 g
s
.26566 .59295 m .26801 .64662 L .23621 .64891 L p .707 .577 .707 r
F P
0 g
s
.39023 .25659 m .38702 .76057 L .36392 .77025 L p .707 .577 .707 r
F P
0 g
s
.38702 .76057 m .39023 .25659 L .42418 .24926 L p .707 .577 .707 r
F P
0 g
s
.73276 .61271 m .7016 .61133 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73276 .61271 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.7317 .69661 m .76338 .69921 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .7317 .69661 L p .73631 .66192 L .707 .577 .707 r
F P
0 g
s
.73651 .66046 m .73486 .66046 L .73631 .66192 L .707 .577 .707 r
F
.7317 .69661 m .73486 .66046 L p .70604 .65843 L F P
0 g
s
.70058 .69355 m .7317 .69661 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70058 .69355 L p .70571 .66052 L .707 .577 .707 r
F P
0 g
s
.70604 .65843 m .70366 .65827 L .70571 .66052 L .707 .577 .707 r
F
.7016 .61133 m .67413 .60641 L p .69654 .65043 L F P
0 g
s
.70027 .65776 m .70366 .65827 L .69654 .65043 L .707 .577 .707 r
F
.70366 .65827 m .7016 .61133 L p .69654 .65043 L F P
0 g
s
.72629 .65188 m .71943 .64501 L .70395 .66499 L .707 .577 .707 r
F
.70233 .62788 m .70366 .65827 L p .71943 .64501 L F P
0 g
s
.70366 .65827 m .70395 .66499 L p .71943 .64501 L .707 .577 .707 r
F P
0 g
s
.70058 .69355 m .70366 .65827 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .70058 .69355 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67307 .69032 L p .67755 .65613 L .707 .577 .707 r
F P
0 g
s
.67778 .6544 m .67623 .65417 L .67755 .65613 L .707 .577 .707 r
F
.67413 .60641 m .65304 .59844 L p .67164 .64734 L F P
0 g
s
.65304 .59844 m .6404 .5882 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65866 .64947 m .6552 .64897 L p .67623 .65417 L .707 .577 .707 r
F P
0 g
s
.6552 .64897 m .65186 .68724 L .67073 .68998 L p .707 .577 .707 r
F P
0 g
s
.67073 .68998 m .67307 .69032 L p .65662 .65224 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .6552 .64897 L .67073 .68998 L .707 .577 .707 r
F
.65186 .68724 m .6552 .64897 L .64238 .64634 L p F P
0 g
s
.64275 .64187 m .6554 .65211 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6404 .5882 m .64143 .61161 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.64143 .61161 m .64275 .64187 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6554 .65211 m .65524 .64856 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65524 .64856 m .65304 .59844 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .67623 .65417 L p .65541 .64902 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .65541 .64902 L .6552 .64897 L .707 .577 .707 r
F
.67307 .69032 m .65541 .64902 L .65662 .65224 L F
.67401 .65357 m .67623 .65417 L .67164 .64734 L F
.67623 .65417 m .67413 .60641 L p .67164 .64734 L F P
0 g
s
.67413 .60641 m .67623 .65417 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.65304 .59844 m .6554 .65211 L .67648 .66008 L p .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67641 .65205 L .65866 .64947 L p .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .67623 .65417 L p .67401 .65357 L .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .70395 .66499 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67648 .66008 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67641 .65205 m .67623 .65417 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .67641 .65205 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70392 .65528 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .70366 .65827 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .70366 .65827 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .73512 .66637 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73137 .66021 m .72629 .65188 L .71416 .659 L .707 .577 .707 r
F
.73137 .66021 m .71416 .659 L .70395 .66499 L F
.7016 .61133 m .70233 .62788 L p .72629 .65188 L F P
0 g
s
.73276 .61271 m .73486 .66046 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76673 .66094 L .76156 .66052 L p .707 .577 .707 r
F P
0 g
s
.76156 .66052 m .73504 .65835 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76156 .66052 L .73651 .66046 L .707 .577 .707 r
F
.76456 .61041 m .73276 .61271 L p .76455 .66052 L F P
0 g
s
.76673 .66094 m .76338 .69921 L .79253 .70108 L p .707 .577 .707 r
F P
0 g
s
.79253 .70108 m .79588 .66281 L .76673 .66094 L p .707 .577 .707 r
F P
0 g
s
.76692 .66408 m .76676 .66053 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76676 .66053 m .76456 .61041 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .76692 .66408 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73512 .66637 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .73486 .66046 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .70392 .65528 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73504 .65835 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .73486 .66046 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.325 .71007 m .32166 .74834 L .29415 .74511 L p .707 .577 .707 r
F P
0 g
s
.29415 .74511 m .29749 .70684 L .325 .71007 L p .707 .577 .707 r
F P
0 g
s
.76456 .61041 m .76692 .66408 L .79625 .65835 L p .707 .577 .707 r
F P
0 g
s
.79625 .65835 m .7939 .60468 L .76456 .61041 L p .707 .577 .707 r
F P
0 g
s
.18365 .76484 m .18271 .7471 L .20667 .73791 L p .707 .577 .707 r
F P
0 g
s
.20219 .73758 m .20554 .69931 L .23468 .70118 L p .707 .577 .707 r
F P
0 g
s
.23468 .70118 m .23134 .73945 L .20219 .73758 L p .707 .577 .707 r
F P
0 g
s
.20667 .73791 m .20761 .75565 L .18365 .76484 L p .707 .577 .707 r
F P
0 g
s
.3264 .73544 m .32734 .75317 L .29987 .74816 L p .707 .577 .707 r
F P
0 g
s
.29987 .74816 m .29893 .73042 L .3264 .73544 L p .707 .577 .707 r
F P
0 g
s
.7939 .60468 m .79625 .65835 L .82024 .64973 L p .707 .577 .707 r
F P
0 g
s
.82024 .64973 m .81789 .59606 L .7939 .60468 L p .707 .577 .707 r
F P
0 g
s
.29749 .70684 m .29415 .74511 L .26303 .74205 L p .707 .577 .707 r
F P
0 g
s
.26303 .74205 m .26637 .70378 L .29749 .70684 L p .707 .577 .707 r
F P
0 g
s
.59338 .25312 m .59017 .75709 L .55141 .751 L p .707 .577 .707 r
F P
0 g
s
.55141 .751 m .55462 .24703 L .59338 .25312 L p .707 .577 .707 r
F P
0 g
s
.23134 .73945 m .23468 .70118 L .26637 .70378 L p .707 .577 .707 r
F P
0 g
s
.20761 .75565 m .20667 .73791 L .23598 .73172 L p .707 .577 .707 r
F P
0 g
s
.26637 .70378 m .26303 .74205 L .23134 .73945 L p .707 .577 .707 r
F P
0 g
s
.29893 .73042 m .29987 .74816 L .26871 .74688 L p .707 .577 .707 r
F P
0 g
s
.26871 .74688 m .26777 .72914 L .29893 .73042 L p .707 .577 .707 r
F P
0 g
s
.42098 .75323 m .42418 .24926 L .46566 .245 L p .707 .577 .707 r
F P
0 g
s
.42418 .24926 m .42098 .75323 L .38702 .76057 L p .707 .577 .707 r
F P
0 g
s
.23598 .73172 m .23692 .74946 L .20761 .75565 L p .707 .577 .707 r
F P
0 g
s
.23692 .74946 m .23598 .73172 L .26777 .72914 L p .707 .577 .707 r
F P
0 g
s
.81789 .59606 m .82024 .64973 L .83654 .63907 L p .707 .577 .707 r
F P
0 g
s
.83654 .63907 m .83418 .5854 L .81789 .59606 L p .707 .577 .707 r
F P
0 g
s
.26777 .72914 m .26871 .74688 L .23692 .74946 L p .707 .577 .707 r
F P
0 g
s
.79588 .66281 m .79253 .70108 L .81629 .70205 L p .707 .577 .707 r
F P
0 g
s
.81629 .70205 m .81964 .66378 L .79588 .66281 L p .707 .577 .707 r
F P
0 g
s
.55462 .24703 m .55141 .751 L .5074 .7482 L p .707 .577 .707 r
F P
0 g
s
.5074 .7482 m .51061 .24423 L .55462 .24703 L p .707 .577 .707 r
F P
0 g
s
.736 .76962 m .73506 .75188 L .70391 .7506 L p .707 .577 .707 r
F P
0 g
s
.73506 .75188 m .736 .76962 L .76779 .76704 L p .707 .577 .707 r
F P
0 g
s
.76779 .76704 m .76685 .7493 L .73506 .75188 L p .707 .577 .707 r
F P
0 g
s
.46246 .74897 m .46566 .245 L .51061 .24423 L p .707 .577 .707 r
F P
0 g
s
.46566 .245 m .46246 .74897 L .42098 .75323 L p .707 .577 .707 r
F P
0 g
s
.76685 .7493 m .76779 .76704 L .7971 .76085 L p .707 .577 .707 r
F P
0 g
s
.7971 .76085 m .79616 .74311 L .76685 .7493 L p .707 .577 .707 r
F P
0 g
s
.51061 .24423 m .5074 .7482 L .46246 .74897 L p .707 .577 .707 r
F P
0 g
s
.70485 .76834 m .70391 .7506 L .67643 .74559 L p .707 .577 .707 r
F P
0 g
s
.70391 .7506 m .70485 .76834 L .736 .76962 L p .707 .577 .707 r
F P
0 g
s
.81964 .66378 m .81629 .70205 L .83234 .70202 L p .707 .577 .707 r
F P
0 g
s
.83234 .70202 m .83568 .66375 L .81964 .66378 L p .707 .577 .707 r
F P
0 g
s
.79616 .74311 m .7971 .76085 L .82106 .75166 L p .707 .577 .707 r
F P
0 g
s
.82106 .75166 m .82012 .73392 L .79616 .74311 L p .707 .577 .707 r
F P
0 g
s
.83418 .5854 m .83654 .63907 L .84355 .62741 L p .707 .577 .707 r
F P
0 g
s
.84355 .62741 m .8412 .57374 L .83418 .5854 L p .707 .577 .707 r
F P
0 g
s
.67643 .74559 m .67737 .76332 L .70485 .76834 L p .707 .577 .707 r
F P
0 g
s
.64238 .64634 m .63904 .68461 L .65186 .68724 L p .707 .577 .707 r
F P
0 g
s
.67737 .76332 m .67643 .74559 L .65533 .73733 L p .707 .577 .707 r
F P
0 g
s
.64275 .64187 m .6404 .5882 L .63744 .57669 L p .707 .577 .707 r
F P
0 g
s
.65533 .73733 m .65627 .75507 L .67737 .76332 L p .707 .577 .707 r
F P
0 g
s
.82012 .73392 m .82106 .75166 L .83733 .74036 L p .707 .577 .707 r
F P
0 g
s
.83733 .74036 m .83639 .72263 L .82012 .73392 L p .707 .577 .707 r
F P
0 g
s
.83568 .66375 m .83234 .70202 L .83909 .70099 L p .707 .577 .707 r
F P
0 g
s
.83909 .70099 m .84244 .66272 L .83568 .66375 L p .707 .577 .707 r
F P
0 g
s
.8412 .57374 m .84355 .62741 L .84059 .6159 L p .707 .577 .707 r
F P
0 g
s
.84059 .6159 m .83824 .56223 L .8412 .57374 L p .707 .577 .707 r
F P
0 g
s
.65627 .75507 m .65533 .73733 L .64267 .72663 L p .707 .577 .707 r
F P
0 g
s
.63744 .57669 m .63979 .63036 L .64275 .64187 L p .707 .577 .707 r
F P
0 g
s
.63904 .68461 m .64238 .64634 L .63919 .64441 L p .707 .577 .707 r
F P
0 g
s
.63919 .64441 m .63585 .68268 L .63904 .68461 L p .707 .577 .707 r
F P
0 g
s
.64267 .72663 m .6436 .74437 L .65627 .75507 L p .707 .577 .707 r
F P
0 g
s
.83639 .72263 m .83733 .74036 L .84431 .72807 L p .707 .577 .707 r
F P
0 g
s
.84431 .72807 m .84337 .71034 L .83639 .72263 L p .707 .577 .707 r
F P
0 g
s
.63979 .63036 m .63744 .57669 L .64445 .56503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84244 .66272 m .83909 .70099 L .8359 .69907 L p .707 .577 .707 r
F P
0 g
s
.8359 .69907 m .83925 .6608 L .84244 .66272 L p .707 .577 .707 r
F P
0 g
s
.83824 .56223 m .84059 .6159 L .82795 .60565 L p .707 .577 .707 r
F P
0 g
s
.82795 .60565 m .82559 .55199 L .83824 .56223 L p .707 .577 .707 r
F P
0 g
s
.6436 .74437 m .64267 .72663 L .63968 .71455 L p .707 .577 .707 r
F P
0 g
s
.64445 .56503 m .64681 .6187 L .63979 .63036 L p .707 .577 .707 r
F P
0 g
s
.63968 .71455 m .64062 .73229 L .6436 .74437 L p .707 .577 .707 r
F P
0 g
s
.63585 .68268 m .63919 .64441 L .64595 .64339 L p .707 .577 .707 r
F P
0 g
s
.64595 .64339 m .6426 .68166 L .63585 .68268 L p .707 .577 .707 r
F P
0 g
s
.84337 .71034 m .84431 .72807 L .84132 .71599 L p .707 .577 .707 r
F P
0 g
s
.84132 .71599 m .84039 .69825 L .84337 .71034 L p .707 .577 .707 r
F P
0 g
s
.64681 .6187 m .64445 .56503 L .66075 .55437 L p .707 .577 .707 r
F P
0 g
s
.38975 .57589 m .35859 .57451 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38975 .57589 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38869 .6598 m .42037 .66239 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38869 .6598 L p .3933 .6251 L .707 .577 .707 r
F P
0 g
s
.3935 .62365 m .39185 .62364 L .3933 .6251 L .707 .577 .707 r
F
.38869 .6598 m .39185 .62364 L p .36303 .62162 L F P
0 g
s
.35757 .65674 m .38869 .6598 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .35757 .65674 L p .3627 .62371 L .707 .577 .707 r
F P
0 g
s
.36303 .62162 m .36065 .62145 L .3627 .62371 L .707 .577 .707 r
F
.35859 .57451 m .33112 .5696 L p .35353 .61362 L F P
0 g
s
.35726 .62094 m .36065 .62145 L .35353 .61362 L .707 .577 .707 r
F
.36065 .62145 m .35859 .57451 L p .35353 .61362 L F P
0 g
s
.38328 .61507 m .37642 .60819 L .36094 .62818 L .707 .577 .707 r
F
.35932 .59106 m .36065 .62145 L p .37642 .60819 L F P
0 g
s
.36065 .62145 m .36094 .62818 L p .37642 .60819 L .707 .577 .707 r
F P
0 g
s
.35757 .65674 m .36065 .62145 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .35757 .65674 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33006 .65351 L p .33454 .61932 L .707 .577 .707 r
F P
0 g
s
.33477 .61758 m .33322 .61735 L .33454 .61932 L .707 .577 .707 r
F
.33112 .5696 m .31003 .56163 L p .32863 .61053 L F P
0 g
s
.31003 .56163 m .29739 .55139 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31565 .61266 m .31219 .61216 L p .33322 .61735 L .707 .577 .707 r
F P
0 g
s
.31219 .61216 m .30885 .65042 L .32772 .65317 L p .707 .577 .707 r
F P
0 g
s
.32772 .65317 m .33006 .65351 L p .31361 .61542 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .31219 .61216 L .32772 .65317 L .707 .577 .707 r
F
.30885 .65042 m .31219 .61216 L .29937 .60952 L p F P
0 g
s
.29974 .60506 m .31239 .6153 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29739 .55139 m .29842 .57479 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29842 .57479 m .29974 .60506 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31239 .6153 m .31223 .61174 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31223 .61174 m .31003 .56163 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .33322 .61735 L p .3124 .61221 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .3124 .61221 L .31219 .61216 L .707 .577 .707 r
F
.33006 .65351 m .3124 .61221 L .31361 .61542 L F
.331 .61676 m .33322 .61735 L .32863 .61053 L F
.33322 .61735 m .33112 .5696 L p .32863 .61053 L F P
0 g
s
.33112 .5696 m .33322 .61735 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.31003 .56163 m .31239 .6153 L .33347 .62326 L p .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .3334 .61524 L .31565 .61266 L p .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .33322 .61735 L p .331 .61676 L .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .36094 .62818 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33347 .62326 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.3334 .61524 m .33322 .61735 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .3334 .61524 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .36091 .61847 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .36065 .62145 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .36065 .62145 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .39211 .62956 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38836 .6234 m .38328 .61507 L .37115 .62219 L .707 .577 .707 r
F
.38836 .6234 m .37115 .62219 L .36094 .62818 L F
.35859 .57451 m .35932 .59106 L p .38328 .61507 L F P
0 g
s
.38975 .57589 m .39185 .62364 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .42372 .62412 L .41855 .6237 L p .707 .577 .707 r
F P
0 g
s
.41855 .6237 m .39203 .62153 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .41855 .6237 L .3935 .62365 L .707 .577 .707 r
F
.42156 .5736 m .38975 .57589 L p .42154 .62371 L F P
0 g
s
.42372 .62412 m .42037 .66239 L .44952 .66427 L p .707 .577 .707 r
F P
0 g
s
.44952 .66427 m .45287 .626 L .42372 .62412 L p .707 .577 .707 r
F P
0 g
s
.42391 .62727 m .42375 .62371 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42375 .62371 m .42156 .5736 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .42391 .62727 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39211 .62956 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .39185 .62364 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .36091 .61847 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39203 .62153 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .39185 .62364 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.42156 .5736 m .42391 .62727 L .45324 .62153 L p .707 .577 .707 r
F P
0 g
s
.45324 .62153 m .45089 .56786 L .42156 .5736 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82559 .55199 m .82795 .60565 L .80686 .59769 L p .707 .577 .707 r
F P
0 g
s
.80686 .59769 m .8045 .54402 L .82559 .55199 L p .707 .577 .707 r
F P
0 g
s
.45089 .56786 m .45324 .62153 L .47723 .61291 L p .707 .577 .707 r
F P
0 g
s
.47723 .61291 m .47488 .55924 L .45089 .56786 L p .707 .577 .707 r
F P
0 g
s
.64062 .73229 m .63968 .71455 L .64666 .70226 L p .707 .577 .707 r
F P
0 g
s
.83925 .6608 m .8359 .69907 L .82308 .69644 L p .707 .577 .707 r
F P
0 g
s
.82308 .69644 m .82642 .65817 L .83925 .6608 L p .707 .577 .707 r
F P
0 g
s
.66075 .55437 m .6631 .60804 L .64681 .6187 L p .707 .577 .707 r
F P
0 g
s
.64666 .70226 m .6476 .72 L .64062 .73229 L p .707 .577 .707 r
F P
0 g
s
.6631 .60804 m .66075 .55437 L .68474 .54575 L p .707 .577 .707 r
F P
0 g
s
.6426 .68166 m .64595 .64339 L .66199 .64336 L p .707 .577 .707 r
F P
0 g
s
.66199 .64336 m .65865 .68162 L .6426 .68166 L p .707 .577 .707 r
F P
0 g
s
.84039 .69825 m .84132 .71599 L .82866 .7053 L p .707 .577 .707 r
F P
0 g
s
.82866 .7053 m .82772 .68756 L .84039 .69825 L p .707 .577 .707 r
F P
0 g
s
.47488 .55924 m .47723 .61291 L .49353 .60225 L p .707 .577 .707 r
F P
0 g
s
.49353 .60225 m .49117 .54858 L .47488 .55924 L p .707 .577 .707 r
F P
0 g
s
.8045 .54402 m .80686 .59769 L .77939 .59277 L p .707 .577 .707 r
F P
0 g
s
.77939 .59277 m .77704 .53911 L .8045 .54402 L p .707 .577 .707 r
F P
0 g
s
.45287 .626 m .44952 .66427 L .47328 .66524 L p .707 .577 .707 r
F P
0 g
s
.47328 .66524 m .47663 .62697 L .45287 .626 L p .707 .577 .707 r
F P
0 g
s
.6476 .72 m .64666 .70226 L .66293 .69097 L p .707 .577 .707 r
F P
0 g
s
.68709 .59942 m .68474 .54575 L .71407 .54002 L p .707 .577 .707 r
F P
0 g
s
.68474 .54575 m .68709 .59942 L .6631 .60804 L p .707 .577 .707 r
F P
0 g
s
.82642 .65817 m .82308 .69644 L .80187 .69335 L p .707 .577 .707 r
F P
0 g
s
.80187 .69335 m .80522 .65508 L .82642 .65817 L p .707 .577 .707 r
F P
0 g
s
.39299 .7328 m .39205 .71506 L .3609 .71379 L p .707 .577 .707 r
F P
0 g
s
.39205 .71506 m .39299 .7328 L .42478 .73022 L p .707 .577 .707 r
F P
0 g
s
.42478 .73022 m .42384 .71248 L .39205 .71506 L p .707 .577 .707 r
F P
0 g
s
.42384 .71248 m .42478 .73022 L .45409 .72403 L p .707 .577 .707 r
F P
0 g
s
.45409 .72403 m .45315 .70629 L .42384 .71248 L p .707 .577 .707 r
F P
0 g
s
.77704 .53911 m .77939 .59277 L .74823 .59139 L p .707 .577 .707 r
F P
0 g
s
.74823 .59139 m .74587 .53773 L .77704 .53911 L p .707 .577 .707 r
F P
0 g
s
.66293 .69097 m .66386 .70871 L .6476 .72 L p .707 .577 .707 r
F P
0 g
s
.36183 .73152 m .3609 .71379 L .33342 .70877 L p .707 .577 .707 r
F P
0 g
s
.3609 .71379 m .36183 .73152 L .39299 .7328 L p .707 .577 .707 r
F P
0 g
s
.65865 .68162 m .66199 .64336 L .68575 .64432 L p .707 .577 .707 r
F P
0 g
s
.68575 .64432 m .68241 .68259 L .65865 .68162 L p .707 .577 .707 r
F P
0 g
s
.71642 .59368 m .71407 .54002 L .74587 .53773 L p .707 .577 .707 r
F P
0 g
s
.71407 .54002 m .71642 .59368 L .68709 .59942 L p .707 .577 .707 r
F P
0 g
s
.82772 .68756 m .82866 .7053 L .80756 .69704 L p .707 .577 .707 r
F P
0 g
s
.80756 .69704 m .80662 .6793 L .82772 .68756 L p .707 .577 .707 r
F P
0 g
s
.47663 .62697 m .47328 .66524 L .48933 .6652 L p .707 .577 .707 r
F P
0 g
s
.48933 .6652 m .49267 .62694 L .47663 .62697 L p .707 .577 .707 r
F P
0 g
s
.74587 .53773 m .74823 .59139 L .71642 .59368 L p .707 .577 .707 r
F P
0 g
s
.45315 .70629 m .45409 .72403 L .47805 .71484 L p .707 .577 .707 r
F P
0 g
s
.47805 .71484 m .47711 .6971 L .45315 .70629 L p .707 .577 .707 r
F P
0 g
s
.49117 .54858 m .49353 .60225 L .50054 .59059 L p .707 .577 .707 r
F P
0 g
s
.50054 .59059 m .49819 .53692 L .49117 .54858 L p .707 .577 .707 r
F P
0 g
s
.33342 .70877 m .33436 .72651 L .36183 .73152 L p .707 .577 .707 r
F P
0 g
s
.29937 .60952 m .29603 .64779 L .30885 .65042 L p .707 .577 .707 r
F P
0 g
s
.33436 .72651 m .33342 .70877 L .31232 .70051 L p .707 .577 .707 r
F P
0 g
s
.80522 .65508 m .80187 .69335 L .77436 .69012 L p .707 .577 .707 r
F P
0 g
s
.77436 .69012 m .77771 .65185 L .80522 .65508 L p .707 .577 .707 r
F P
0 g
s
.7149 .6462 m .71156 .68447 L .68241 .68259 L p .707 .577 .707 r
F P
0 g
s
.66386 .70871 m .66293 .69097 L .68689 .68178 L p .707 .577 .707 r
F P
0 g
s
.29974 .60506 m .29739 .55139 L .29443 .53988 L p .707 .577 .707 r
F P
0 g
s
.68241 .68259 m .68575 .64432 L .7149 .6462 L p .707 .577 .707 r
F P
0 g
s
.31232 .70051 m .31326 .71825 L .33436 .72651 L p .707 .577 .707 r
F P
0 g
s
.68689 .68178 m .68783 .69952 L .66386 .70871 L p .707 .577 .707 r
F P
0 g
s
.47711 .6971 m .47805 .71484 L .49432 .70355 L p .707 .577 .707 r
F P
0 g
s
.49432 .70355 m .49338 .68581 L .47711 .6971 L p .707 .577 .707 r
F P
0 g
s
.80662 .6793 m .80756 .69704 L .78008 .69202 L p .707 .577 .707 r
F P
0 g
s
.78008 .69202 m .77914 .67429 L .80662 .6793 L p .707 .577 .707 r
F P
0 g
s
.77771 .65185 m .77436 .69012 L .74324 .68706 L p .707 .577 .707 r
F P
0 g
s
.74324 .68706 m .74658 .64879 L .77771 .65185 L p .707 .577 .707 r
F P
0 g
s
.49267 .62694 m .48933 .6652 L .49608 .66418 L p .707 .577 .707 r
F P
0 g
s
.49608 .66418 m .49943 .62591 L .49267 .62694 L p .707 .577 .707 r
F P
0 g
s
.71156 .68447 m .7149 .6462 L .74658 .64879 L p .707 .577 .707 r
F P
0 g
s
.49819 .53692 m .50054 .59059 L .49758 .57908 L p .707 .577 .707 r
F P
0 g
s
.49758 .57908 m .49523 .52541 L .49819 .53692 L p .707 .577 .707 r
F P
0 g
s
.68783 .69952 m .68689 .68178 L .7162 .67559 L p .707 .577 .707 r
F P
0 g
s
.74658 .64879 m .74324 .68706 L .71156 .68447 L p .707 .577 .707 r
F P
0 g
s
.31326 .71825 m .31232 .70051 L .29966 .68982 L p .707 .577 .707 r
F P
0 g
s
.77914 .67429 m .78008 .69202 L .74893 .69075 L p .707 .577 .707 r
F P
0 g
s
.74893 .69075 m .74799 .67301 L .77914 .67429 L p .707 .577 .707 r
F P
0 g
s
.29443 .53988 m .29678 .59354 L .29974 .60506 L p .707 .577 .707 r
F P
0 g
s
.29603 .64779 m .29937 .60952 L .29618 .6076 L p .707 .577 .707 r
F P
0 g
s
.7162 .67559 m .71714 .69333 L .68783 .69952 L p .707 .577 .707 r
F P
0 g
s
.29618 .6076 m .29284 .64587 L .29603 .64779 L p .707 .577 .707 r
F P
0 g
s
.29966 .68982 m .30059 .70756 L .31326 .71825 L p .707 .577 .707 r
F P
0 g
s
.71714 .69333 m .7162 .67559 L .74799 .67301 L p .707 .577 .707 r
F P
0 g
s
.74799 .67301 m .74893 .69075 L .71714 .69333 L p .707 .577 .707 r
F P
0 g
s
.49338 .68581 m .49432 .70355 L .5013 .69126 L p .707 .577 .707 r
F P
0 g
s
.5013 .69126 m .50036 .67352 L .49338 .68581 L p .707 .577 .707 r
F P
0 g
s
.29678 .59354 m .29443 .53988 L .30144 .52822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49943 .62591 m .49608 .66418 L .49289 .66225 L p .707 .577 .707 r
F P
0 g
s
.49289 .66225 m .49624 .62398 L .49943 .62591 L p .707 .577 .707 r
F P
0 g
s
.49523 .52541 m .49758 .57908 L .48494 .56884 L p .707 .577 .707 r
F P
0 g
s
.48494 .56884 m .48258 .51517 L .49523 .52541 L p .707 .577 .707 r
F P
0 g
s
.30059 .70756 m .29966 .68982 L .29667 .67774 L p .707 .577 .707 r
F P
0 g
s
.30144 .52822 m .30379 .58189 L .29678 .59354 L p .707 .577 .707 r
F P
0 g
s
.29667 .67774 m .29761 .69547 L .30059 .70756 L p .707 .577 .707 r
F P
0 g
s
.29284 .64587 m .29618 .6076 L .30294 .60657 L p .707 .577 .707 r
F P
0 g
s
.30294 .60657 m .29959 .64484 L .29284 .64587 L p .707 .577 .707 r
F P
0 g
s
.50036 .67352 m .5013 .69126 L .49831 .67918 L p .707 .577 .707 r
F P
0 g
s
.49831 .67918 m .49737 .66144 L .50036 .67352 L p .707 .577 .707 r
F P
0 g
s
.30379 .58189 m .30144 .52822 L .31774 .51756 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48258 .51517 m .48494 .56884 L .46385 .56087 L p .707 .577 .707 r
F P
0 g
s
.46385 .56087 m .46149 .5072 L .48258 .51517 L p .707 .577 .707 r
F P
0 g
s
.29761 .69547 m .29667 .67774 L .30365 .66545 L p .707 .577 .707 r
F P
0 g
s
.49624 .62398 m .49289 .66225 L .48007 .65962 L p .707 .577 .707 r
F P
0 g
s
.48007 .65962 m .48341 .62135 L .49624 .62398 L p .707 .577 .707 r
F P
0 g
s
.31774 .51756 m .32009 .57123 L .30379 .58189 L p .707 .577 .707 r
F P
0 g
s
.30365 .66545 m .30459 .68318 L .29761 .69547 L p .707 .577 .707 r
F P
0 g
s
.32009 .57123 m .31774 .51756 L .34173 .50894 L p .707 .577 .707 r
F P
0 g
s
.29959 .64484 m .30294 .60657 L .31898 .60654 L p .707 .577 .707 r
F P
0 g
s
.31898 .60654 m .31564 .64481 L .29959 .64484 L p .707 .577 .707 r
F P
0 g
s
.49737 .66144 m .49831 .67918 L .48565 .66848 L p .707 .577 .707 r
F P
0 g
s
.48565 .66848 m .48471 .65074 L .49737 .66144 L p .707 .577 .707 r
F P
0 g
s
.46149 .5072 m .46385 .56087 L .43638 .55596 L p .707 .577 .707 r
F P
0 g
s
.43638 .55596 m .43402 .50229 L .46149 .5072 L p .707 .577 .707 r
F P
0 g
s
.30459 .68318 m .30365 .66545 L .31992 .65415 L p .707 .577 .707 r
F P
0 g
s
.34408 .5626 m .34173 .50894 L .37106 .5032 L p .707 .577 .707 r
F P
0 g
s
.34173 .50894 m .34408 .5626 L .32009 .57123 L p .707 .577 .707 r
F P
0 g
s
.48341 .62135 m .48007 .65962 L .45886 .65654 L p .707 .577 .707 r
F P
0 g
s
.45886 .65654 m .4622 .61827 L .48341 .62135 L p .707 .577 .707 r
F P
0 g
s
.43402 .50229 m .43638 .55596 L .40522 .55458 L p .707 .577 .707 r
F P
0 g
s
.40522 .55458 m .40286 .50091 L .43402 .50229 L p .707 .577 .707 r
F P
0 g
s
.31992 .65415 m .32085 .67189 L .30459 .68318 L p .707 .577 .707 r
F P
0 g
s
.31564 .64481 m .31898 .60654 L .34274 .60751 L p .707 .577 .707 r
F P
0 g
s
.34274 .60751 m .3394 .64578 L .31564 .64481 L p .707 .577 .707 r
F P
0 g
s
.37341 .55687 m .37106 .5032 L .40286 .50091 L p .707 .577 .707 r
F P
0 g
s
.37106 .5032 m .37341 .55687 L .34408 .5626 L p .707 .577 .707 r
F P
0 g
s
.48471 .65074 m .48565 .66848 L .46455 .66022 L p .707 .577 .707 r
F P
0 g
s
.46455 .66022 m .46361 .64248 L .48471 .65074 L p .707 .577 .707 r
F P
0 g
s
.40286 .50091 m .40522 .55458 L .37341 .55687 L p .707 .577 .707 r
F P
0 g
s
.4622 .61827 m .45886 .65654 L .43135 .65331 L p .707 .577 .707 r
F P
0 g
s
.43135 .65331 m .4347 .61504 L .4622 .61827 L p .707 .577 .707 r
F P
0 g
s
.37189 .60938 m .36855 .64765 L .3394 .64578 L p .707 .577 .707 r
F P
0 g
s
.32085 .67189 m .31992 .65415 L .34388 .64496 L p .707 .577 .707 r
F P
0 g
s
.3394 .64578 m .34274 .60751 L .37189 .60938 L p .707 .577 .707 r
F P
0 g
s
.34388 .64496 m .34482 .6627 L .32085 .67189 L p .707 .577 .707 r
F P
0 g
s
.46361 .64248 m .46455 .66022 L .43707 .65521 L p .707 .577 .707 r
F P
0 g
s
.43707 .65521 m .43613 .63747 L .46361 .64248 L p .707 .577 .707 r
F P
0 g
s
.4347 .61504 m .43135 .65331 L .40023 .65024 L p .707 .577 .707 r
F P
0 g
s
.40023 .65024 m .40357 .61198 L .4347 .61504 L p .707 .577 .707 r
F P
0 g
s
.36855 .64765 m .37189 .60938 L .40357 .61198 L p .707 .577 .707 r
F P
0 g
s
.34482 .6627 m .34388 .64496 L .37319 .63877 L p .707 .577 .707 r
F P
0 g
s
.40357 .61198 m .40023 .65024 L .36855 .64765 L p .707 .577 .707 r
F P
0 g
s
.43613 .63747 m .43707 .65521 L .40591 .65393 L p .707 .577 .707 r
F P
0 g
s
.40591 .65393 m .40498 .63619 L .43613 .63747 L p .707 .577 .707 r
F P
0 g
s
.37319 .63877 m .37413 .65651 L .34482 .6627 L p .707 .577 .707 r
F P
0 g
s
.37413 .65651 m .37319 .63877 L .40498 .63619 L p .707 .577 .707 r
F P
0 g
s
.40498 .63619 m .40591 .65393 L .37413 .65651 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo6000QWoo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Aoo`<00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00L7oo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool3
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00
JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEPl000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo2@0015YF00<005YFFUH01UYF00<005YF00000`000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000;FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001UOol005ioo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00
G7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00IGoo001JOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00EWoo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000IOol80015Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`L000AJEP04001J
EUYFFUH8000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF
00QJEP03001JEUYF00EJEP04001JEUYFFUH6000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000Yoo`@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo100000=JEP00FUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH015YF1`0025YF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000_Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH4
0005FUH00`00FUIJEP06FUH50004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool005=oo`04001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP04FUH50004FUH00`00
FUIJEP08FUH600000eYF001JEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH0
0003FUH00`00FUH000030004Ool01000FUIJEP001UYF1@0015YF00<005YFFUH015YF100015YF00@0
05YF000000=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000=JEP800003FUH0
000000<0009oo`04001JEUYF0006FUH50004FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF00<005YF
FUH00UYF00@005YFFUIJEQP000IJEP03001JEUYF00=JEP03001JEUYF009JEP@00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<00003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`07001JEP00FUH005YFOol00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF0`00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo0017Ool90004Ool20002FUH01000FUIJEWoo0UYF00<0
05YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF5`0015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000oOol80004FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040007Ool3000=Ool50005FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH4000:Ool5000>Ool50003FUH00`00FUIJEP02000]Ool003Moo`800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEP0000<000ioo`D000]oo`<000EJEP800004FUH005YFFUH2000]Ool003Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ400003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEPL000eoo`D000Moo`@00003FUH0
05YF00EJEP04001JEP000002FUH2000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH900000eYF001JEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH01000FUIJEUYF2@001Goo0`0000=o
o`0000001@001EYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000]Ool0035oo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEQ400003FUH005YF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;goo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPL000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00L005YFFUIJEP00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00005
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70004FUH01000FUIJEUYF20000eYF00<005YFFUH015YF
00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000EJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001J
EUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00
15YF00<005YFFUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEPX00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP04001JEUYF000`Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT0009JEQ4000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<0009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP0B0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000a
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH70009Ool90003FUH30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030003
FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP03
FUH2000cOol002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP040007Ool3000>Ool5
0003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH00UYF0P00=Goo000/Ool01000FUIJEP0015YF00<005YFFUH00UYF10002Woo1@003Woo
0P001UYF00<005YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF0P0000=JEP0000000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Io
o`00;Goo00<005YF000015YF00<005YF00000P003Woo1@002goo10001eYF00<005YFFUH0100000=J
EP0000001`0015YF00<005YFFUH01EYF1P0015YF00<005YF00000P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Woo
000]Ool00`00FUH00004FUH7000<Ool50007Ool600000eYF001JEP05FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH@0002FUH20003FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Goo00<005YF00000UYF0P000eYF00@005YFFUIJEQP000=JEP03001JEUYF009JEP04001JEUYF
FUH20003FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF1P0000EJEP00FUIJEP00
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF00000P0015YF00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00=JEP80009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;Goo00L005YF001JEP00FUIoo`03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20002FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF00H005YF000005YF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00=JEPl000EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00000UYF0P0015YF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<0
05YF000010001UYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF0P001eYF00<005YFFUH01UYF00H005YFFUIJEP00FUH40006FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH80003FUH70003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH01`00FUIJEUYF001JEP0002eoo`00;Goo0P000UYF00@0
05YFFUIoo`9JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00AJEPD000AJEP03001JEUYF00UJEP03
001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH2000^Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP8000MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF
00000UYF00<005YFFUH015YF1@0015YF00<005YFFUH02EYF00<005YFFUH01UYF00D005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP8000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0
000002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH50004FUH00`00FUIJEP09FUH00`00FUIJEP04FUH3000015YF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH00eYF1000;Woo000^Ool01000FUIJEP000eYF00=ooeYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH015YF00D005YFFUIJEP00009J
EP03001JEUYF00AJEP@000EJEP03001JEUYF00UJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`<000IJEP03001J
EUYF009JEPP000QJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEP00000^Ool002eo
oa400003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0006FUH00`00FUIJ
EP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP020004FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP03FUH70002OolB0004FUH00`00FUH000030004FUH01000FUIJEP00;Woo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH01eYF00<005YFFUH00P000UYF
0P001UYF0`0000Eoo`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@00003FUH005YF
00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH01000FUIJEUYF0P000eYF00@005YF000001Aoo`d00005FUH005YFFUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH005YF009JEP05
001JEUYF001JEP030002FUH20003Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP06001JEP00001JEP0015YF0`008Goo0P000UYF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP02FUH50002Ool01000FUIJEP001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP8000=JEP03001JEUYF009JEP<002=oo`04001JEUYF000]Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP04001JEUYFFUH90003FUH00`00FUIJEP03FUH70005FUH0
0`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00UYF0`0097oo0`00;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030007FUH01`00FUIJEUYF001JEP0000Qoo`<001Yoo`8002eoo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0007FUH01`00FUIJEUYF001JEP0000Moo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH01EYF00@005YFFUIJEP8000Qoo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH015YF00@005YFFUIJEP8000Qoo`D001Moo`800003FUH007oo
02aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF3P00
1EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH00UYF1`0025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YF
FUH015YF00D005YFFUIJEP0000Yoo`<001Ioo`800004FUH005YF000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEP0000<00003FUH0
05YF00AJEP03001JEUYF010000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH00000FUH00006FUH01000FUIJ
EP008Woo0P000eYF0P00;Woo000/OolC0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P001UYF0`008Goo0P0000=JEP00FUH00UYF0P00;Woo000]Ool200000eYF001JEP04FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
0002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0`0015YF0P008Goo
0P000eYF00D005YFFUIJEP0002moo`00;goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00@001moo`@000EJEP04001JEUYF000`Ool003=o
o`8000IJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF009JEP<0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF009JEPD001Qoo`@0009JEP03001JEUYF00AJEP<0035o
o`00<Woo0P001eYF00<005YFFUH00UYF300015YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJEP03001JEUYF
00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH01000FUIJEUYF
60001UYF00<005YFFUH00eYF0P00<goo000`Ool200000eYF001JEP05FUH6000<OolC0004FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000_Ool00`00FUIJEP02FUH01000FUIJEUYF0P008Woo1P0000=JEP0000000UYF00<005YFFUH015YF
00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
10001UYF00<005YFFUH00UYF0P0015YF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;Woo0P0015YF00@005YF000002Yoo`<0009J
EP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP8000IJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<003Uoo`00;Woo0P0015YF0P00;Woo00@0
05YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP@000AJEP8000IJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@003aoo`00;Goo00<005YF00000UYF0P00<7oo00D005YFFUH005YF0080
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYFFUH20002FUH50002FUH00`00FUIJEP04FUHJ0010Ool002eoo`03001JEP000080
01Ioo`<001Uoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEPH0009JEP07
001JEUYFFUH005YF0000E7oo000]Ool00`00FUH0000GOol5000HOol00`00FUH00003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YF00000P000eYF0P00EGoo000]Ool2000H
Ool5000HOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH0
0UYF0P0000=JEP000000EGoo000]Ool2000HOol5000GOol30004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH000001eYF00<005YFFUH00eYF1000EGoo000]Ool3000HOol3000FOol200000eYF
00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP040004FUH00`00FUIJEP03FUH0
1000FUH00000EGoo000]Ool200000eYF001oo`0]Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP000eYF1P0015YF00@005YFFUH005Eoo`00;Goo0P000UYF0P00
:Woo0P0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00003@0000EJEP00FUIJEP0005Eoo`00;Woo00D005YFFUH005YF00<002Eoo`8000=JEP03001JEUYF
009JEP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000ioo`80009JEP03001oogoo05=oo`00
;Woo00@005YFFUH000AJEP<001moo`<000EJEP03001JEUYF008000=oo`<000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP80015oo`04001JEP00001DOol002moo`04001JEUYF0004FUH00`00FUH00003000GOol400000eYF
001JEP05FUH30007Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUH00002000DOol00`00FUH0001DOol0031oo`<000AJEP03
001JEUYF00=JEQL000EJEP03001JEUYF00AJEP03001oogoo00Yoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<001Qoo`8005Aoo`00
<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEP80015oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@001Yoo`8005Aoo`00<goo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000001Qoo`H0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000P001Qoo`03001JEP0005Aoo`00=Goo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100087oo20001UYF00<005YF
FUH02UYF00<005YFFUH015YF1`0017oo1@005goo0P0000=JEP00Ool0Dgoo000gOol50003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000/OolJ000;Ool5000FOol01@00FUH005YF0000
E7oo000lOolH000kOol2000IOol3000FOol01000FUIJEUYF0P00E7oo002?Ool01000FUH00000;Woo
0P0015YF00<007ooOol0Dgoo002?Ool01000FUIJEUYF0P00:7oo100000=JEP00FUH00eYF00<007oo
Ool0Dgoo002?Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP05001JEUYFFUH0001FOol008moo`05
001JEUYFFUH00004FUH5000HOol40002FUH00`00FUIJEP04FUH01000FUH00000Egoo002@Ool01000
FUIJEP001EYF00@005YFFUIJEPP000Uoo`L000IJEP03001JEUYF00AJEP8005Uoo`00TGoo0`001EYF
00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Yoo`00
Tgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000`00G7oo002EOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3001POol009Qoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06=oo`00WGoo2@0015YF00<005YFFUH00UYF1`00Igoo002VOol9001^Ool00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59543 .7114 m .56429 .71033 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59543 .7114 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59451 .7745 m .62595 .7792 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59451 .7745 L p .60514 .75319 L .707 .577 .707 r
F P
0 g
s
.60733 .7488 m .59814 .74863 L .60514 .75319 L .707 .577 .707 r
F
.59451 .7745 m .59814 .74863 L p .57761 .74707 L F P
0 g
s
.56347 .77072 m .59451 .7745 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .56347 .77072 L p .57469 .75196 L .707 .577 .707 r
F P
0 g
s
.57761 .74707 m .5669 .74626 L .57469 .75196 L .707 .577 .707 r
F
.56429 .71033 m .5368 .70511 L p .55415 .73694 L F P
0 g
s
.55858 .74507 m .5669 .74626 L .55415 .73694 L .707 .577 .707 r
F
.5669 .74626 m .56429 .71033 L p .55415 .73694 L F P
0 g
s
.58292 .73873 m .58267 .73856 L .56808 .76249 L .707 .577 .707 r
F
.56553 .7274 m .5669 .74626 L p .58267 .73856 L F P
0 g
s
.5669 .74626 m .56808 .76249 L p .58267 .73856 L .707 .577 .707 r
F P
0 g
s
.56347 .77072 m .5669 .74626 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .56347 .77072 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .53588 .76821 L p .54592 .74875 L .707 .577 .707 r
F P
0 g
s
.54857 .74364 m .53951 .74234 L .54592 .74875 L .707 .577 .707 r
F
.5368 .70511 m .51566 .69624 L p .53103 .73386 L F P
0 g
s
.53394 .74098 m .53951 .74234 L .53103 .73386 L .707 .577 .707 r
F
.53951 .74234 m .5368 .70511 L p .53103 .73386 L F P
0 g
s
.5368 .70511 m .53951 .74234 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .53951 .74234 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .53588 .76821 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51443 .76723 L p .52201 .74331 L .707 .577 .707 r
F P
0 g
s
.52355 .73844 m .51864 .73724 L .52201 .74331 L .707 .577 .707 r
F
.51566 .69624 m .50293 .68458 L p .51475 .73023 L F P
0 g
s
.51628 .73613 m .51864 .73724 L .51475 .73023 L .707 .577 .707 r
F
.51864 .73724 m .51566 .69624 L p .51475 .73023 L F P
0 g
s
.51566 .69624 m .51864 .73724 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .51864 .73724 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .50695 .73175 L .50665 .73361 L .707 .577 .707 r
F
.50123 .76788 m .5115 .76738 L p .50665 .73361 L F P
0 g
s
.5115 .76738 m .51443 .76723 L p .50665 .73361 L .707 .577 .707 r
F P
0 g
s
.50293 .68458 m .49987 .67129 L p .50572 .7271 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50123 .76788 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.50123 .76788 m .50634 .73147 L p .5029 .73212 L .707 .577 .707 r
F P
0 g
s
.50612 .73094 m .50634 .73147 L .50572 .7271 L .707 .577 .707 r
F
.50634 .73147 m .50293 .68458 L p .50572 .7271 L F P
0 g
s
.50293 .68458 m .50634 .73147 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50586 .73034 m .5029 .73212 L p .50634 .73147 L .707 .577 .707 r
F P
0 g
s
.49987 .67129 m .50366 .72345 L .50372 .7237 L p .707 .577 .707 r
F P
0 g
s
.50372 .7237 m .50673 .73674 L p .5021 .69257 L .707 .577 .707 r
F P
0 g
s
.5021 .69257 m .49987 .67129 L .50372 .7237 L .707 .577 .707 r
F
.5029 .73212 m .49757 .77008 L .50123 .76788 L p F P
0 g
s
.49757 .77008 m .5029 .73212 L .5042 .73286 L p .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .50634 .73147 L p .50612 .73094 L .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .51945 .74839 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50673 .73674 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.5042 .73286 m .50914 .73567 L p .50499 .74802 L .707 .577 .707 r
F P
0 g
s
.49757 .77008 m .5042 .73286 L .50499 .74802 L .707 .577 .707 r
F
.50634 .73147 m .50656 .72992 L .50586 .73034 L p F P
0 g
s
.50656 .72992 m .50634 .73147 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .50656 .72992 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51976 .72928 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .51864 .73724 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .54059 .75727 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51945 .74839 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .51864 .73724 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .51976 .72928 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .5412 .73026 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .53951 .74234 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .56808 .76249 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .54059 .75727 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .53951 .74234 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5412 .73026 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .5688 .73276 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .5669 .74626 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5669 .74626 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .59922 .76356 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.58897 .74794 m .58292 .73873 L .57771 .74708 L .707 .577 .707 r
F
.58897 .74794 m .57771 .74708 L .56808 .76249 L F
.56429 .71033 m .56553 .7274 L p .58292 .73873 L F P
0 g
s
.59543 .7114 m .59814 .74863 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .59543 .7114 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62718 .70821 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .65473 .78435 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62595 .7792 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .63016 .74921 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .62718 .70821 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65643 .70106 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .65984 .74794 L p .68411 .74282 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .67802 .78945 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65473 .78435 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.67724 .74581 m .68411 .74282 L p .65984 .74794 L .707 .577 .707 r
F P
0 g
s
.67802 .78945 m .68335 .75149 L .66006 .74639 L p .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66022 .75322 L .67724 .74581 L p .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .65984 .74794 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .63128 .74125 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .65984 .74794 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66006 .74639 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.66022 .75322 m .65984 .74794 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .66022 .75322 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63097 .76036 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .63016 .74921 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .59983 .73655 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .63016 .74921 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63128 .74125 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .63016 .74921 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .63097 .76036 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59922 .76356 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .59814 .74863 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .5688 .73276 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59983 .73655 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .59814 .74863 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.68411 .74282 m .68031 .69066 L .65643 .70106 L p .707 .577 .707 r
F P
0 g
s
.68031 .69066 m .68411 .74282 L .70029 .73019 L p .707 .577 .707 r
F P
0 g
s
.70029 .73019 m .6965 .67803 L .68031 .69066 L p .707 .577 .707 r
F P
0 g
s
.60075 .86891 m .59924 .85181 L .56811 .8509 L p .707 .577 .707 r
F P
0 g
s
.59924 .85181 m .60075 .86891 L .63247 .86526 L p .707 .577 .707 r
F P
0 g
s
.63247 .86526 m .63096 .84816 L .59924 .85181 L p .707 .577 .707 r
F P
0 g
s
.63096 .84816 m .63247 .86526 L .66166 .8574 L p .707 .577 .707 r
F P
0 g
s
.66166 .8574 m .66015 .84031 L .63096 .84816 L p .707 .577 .707 r
F P
0 g
s
.68335 .75149 m .67802 .78945 L .69354 .79399 L p .707 .577 .707 r
F P
0 g
s
.6965 .67803 m .70029 .73019 L .70719 .71656 L p .707 .577 .707 r
F P
0 g
s
.70719 .71656 m .7034 .6644 L .6965 .67803 L p .707 .577 .707 r
F P
0 g
s
.69354 .79399 m .69887 .75603 L .68335 .75149 L p .707 .577 .707 r
F P
0 g
s
.56962 .868 m .56811 .8509 L .54061 .84552 L p .707 .577 .707 r
F P
0 g
s
.56811 .8509 m .56962 .868 L .60075 .86891 L p .707 .577 .707 r
F P
0 g
s
.66015 .84031 m .66166 .8574 L .68547 .84611 L p .707 .577 .707 r
F P
0 g
s
.68547 .84611 m .68396 .82902 L .66015 .84031 L p .707 .577 .707 r
F P
0 g
s
.54061 .84552 m .54212 .86262 L .56962 .868 L p .707 .577 .707 r
F P
0 g
s
.54212 .86262 m .54061 .84552 L .51944 .83619 L p .707 .577 .707 r
F P
0 g
s
.68396 .82902 m .68547 .84611 L .70158 .83249 L p .707 .577 .707 r
F P
0 g
s
.70158 .83249 m .70007 .8154 L .68396 .82902 L p .707 .577 .707 r
F P
0 g
s
.51944 .83619 m .52095 .85329 L .54212 .86262 L p .707 .577 .707 r
F P
0 g
s
.69887 .75603 m .69354 .79399 L .69978 .79754 L p .707 .577 .707 r
F P
0 g
s
.69978 .79754 m .70511 .75958 L .69887 .75603 L p .707 .577 .707 r
F P
0 g
s
.7034 .6644 m .70719 .71656 L .70413 .70327 L p .707 .577 .707 r
F P
0 g
s
.70413 .70327 m .70033 .65111 L .7034 .6644 L p .707 .577 .707 r
F P
0 g
s
.52095 .85329 m .51944 .83619 L .50665 .82383 L p .707 .577 .707 r
F P
0 g
s
.50366 .72345 m .49987 .67129 L .50677 .65767 L p .707 .577 .707 r
F P
0 g
s
.48697 .82053 m .49216 .31534 L .44815 .31248 L p .707 .577 .707 r
F P
0 g
s
.50816 .84093 m .50665 .82383 L .50352 .80965 L p .707 .577 .707 r
F P
0 g
s
.50914 .73567 m .50381 .77363 L .49757 .77008 L p .707 .577 .707 r
F P
0 g
s
.50677 .65767 m .51056 .70982 L .50366 .72345 L p .707 .577 .707 r
F P
0 g
s
.51056 .70982 m .50677 .65767 L .52295 .64504 L p .707 .577 .707 r
F P
0 g
s
.50352 .80965 m .50503 .82675 L .50816 .84093 L p .707 .577 .707 r
F P
0 g
s
.50503 .82675 m .50352 .80965 L .51034 .79503 L p .707 .577 .707 r
F P
0 g
s
.52295 .64504 m .52675 .69719 L .51056 .70982 L p .707 .577 .707 r
F P
0 g
s
.52466 .74021 m .51933 .77817 L .50381 .77363 L p .707 .577 .707 r
F P
0 g
s
.50381 .77363 m .50914 .73567 L .52466 .74021 L p .707 .577 .707 r
F P
0 g
s
.51034 .79503 m .51185 .81213 L .50503 .82675 L p .707 .577 .707 r
F P
0 g
s
.51185 .81213 m .51034 .79503 L .52644 .78141 L p .707 .577 .707 r
F P
0 g
s
.54795 .74531 m .54262 .78326 L .51933 .77817 L p .707 .577 .707 r
F P
0 g
s
.51933 .77817 m .52466 .74021 L .54795 .74531 L p .707 .577 .707 r
F P
0 g
s
.52644 .78141 m .52795 .79851 L .51185 .81213 L p .707 .577 .707 r
F P
0 g
s
.54262 .78326 m .54795 .74531 L .57673 .75046 L p .707 .577 .707 r
F P
0 g
s
.52795 .79851 m .52644 .78141 L .55025 .77012 L p .707 .577 .707 r
F P
0 g
s
.57673 .75046 m .5714 .78841 L .54262 .78326 L p .707 .577 .707 r
F P
0 g
s
.55025 .77012 m .55176 .78722 L .52795 .79851 L p .707 .577 .707 r
F P
0 g
s
.49216 .31534 m .48697 .82053 L .53191 .81996 L p .707 .577 .707 r
F P
0 g
s
.52675 .69719 m .52295 .64504 L .54684 .63464 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .55063 .6868 L .52675 .69719 L p .707 .577 .707 r
F P
0 g
s
.53191 .81996 m .5371 .31478 L .49216 .31534 L p .707 .577 .707 r
F P
0 g
s
.50665 .82383 m .50816 .84093 L .52095 .85329 L p .707 .577 .707 r
F P
0 g
s
.70007 .8154 m .70158 .83249 L .7084 .81787 L p .707 .577 .707 r
F P
0 g
s
.7084 .81787 m .70689 .80078 L .70007 .8154 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .57609 .62749 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55063 .6868 m .55052 .68524 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55052 .68524 m .54684 .63464 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.57988 .67965 m .57609 .62749 L .60784 .6243 L p .707 .577 .707 r
F P
0 g
s
.57609 .62749 m .57988 .67965 L .55063 .6868 L p .707 .577 .707 r
F P
0 g
s
.60784 .6243 m .61163 .67645 L .57988 .67965 L p .707 .577 .707 r
F P
0 g
s
.63921 .75894 m .63388 .7969 L .60912 .79388 L p .707 .577 .707 r
F P
0 g
s
.60912 .79388 m .60285 .79311 L p .60974 .78663 L .707 .577 .707 r
F P
0 g
s
.60974 .78663 m .63921 .75894 L .60912 .79388 L .707 .577 .707 r
F
.63898 .62536 m .64277 .67752 L .61163 .67645 L p F P
0 g
s
.61163 .67645 m .60784 .6243 L .63898 .62536 L p .707 .577 .707 r
F P
0 g
s
.63388 .7969 m .63921 .75894 L .6668 .76145 L p .707 .577 .707 r
F P
0 g
s
.60285 .79311 m .60817 .75516 L .63921 .75894 L p .707 .577 .707 r
F P
0 g
s
.64229 .75952 m .6438 .77662 L .61267 .77571 L p .707 .577 .707 r
F P
0 g
s
.61267 .77571 m .61116 .75861 L .64229 .75952 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .64043 .78919 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.63563 .29465 m .6334 .51211 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.6334 .51211 m .63044 .79984 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.60817 .75516 m .60285 .79311 L .5738 .78877 L p .707 .577 .707 r
F P
0 g
s
.5738 .78877 m .5714 .78841 L p .57445 .78566 L .707 .577 .707 r
F P
0 g
s
.57445 .78566 m .60817 .75516 L .5738 .78877 L .707 .577 .707 r
F
.5714 .78841 m .57673 .75046 L .60817 .75516 L p F P
0 g
s
.58096 .77936 m .57945 .76226 L .61116 .75861 L p .707 .577 .707 r
F P
0 g
s
.61116 .75861 m .61267 .77571 L .58096 .77936 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .63044 .79984 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.61253 .3039 m .60929 .61908 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.60929 .61908 m .60734 .80909 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.57857 .31083 m .57412 .74459 L p .60734 .80909 L .707 .577 .707 r
F P
0 g
s
.55176 .78722 m .55025 .77012 L .57945 .76226 L p .707 .577 .707 r
F P
0 g
s
.57945 .76226 m .58096 .77936 L .55986 .78504 L p .707 .577 .707 r
F P
0 g
s
.55986 .78504 m .55176 .78722 L p .55814 .78147 L .707 .577 .707 r
F P
0 g
s
.55814 .78147 m .57945 .76226 L .55986 .78504 L .707 .577 .707 r
F
.57412 .74459 m .57341 .81317 L p .60033 .81052 L F P
0 g
s
.57341 .81317 m .57339 .81602 L .57466 .81576 L p .707 .577 .707 r
F P
0 g
s
.57466 .81576 m .60033 .81052 L p .57341 .81317 L .707 .577 .707 r
F P
0 g
s
.60033 .81052 m .60734 .80909 L p .57412 .74459 L .707 .577 .707 r
F P
0 g
s
.5371 .31478 m .53191 .81996 L .57339 .81602 L p .707 .577 .707 r
F P
0 g
s
.57339 .81602 m .57857 .31083 L .5371 .31478 L p .707 .577 .707 r
F P
0 g
s
.44296 .81766 m .44815 .31248 L .40938 .30646 L p .707 .577 .707 r
F P
0 g
s
.44815 .31248 m .44296 .81766 L .48697 .82053 L p .707 .577 .707 r
F P
0 g
s
.70511 .75958 m .69978 .79754 L .69612 .79974 L p .707 .577 .707 r
F P
0 g
s
.70033 .65111 m .70413 .70327 L .6914 .69162 L p .707 .577 .707 r
F P
0 g
s
.6914 .69162 m .68761 .63946 L .70033 .65111 L p .707 .577 .707 r
F P
0 g
s
.69612 .79974 m .70145 .76178 L .70511 .75958 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .61253 .3039 L .57857 .31083 L p .707 .577 .707 r
F P
0 g
s
.70689 .80078 m .7084 .81787 L .70526 .80369 L p .707 .577 .707 r
F P
0 g
s
.70526 .80369 m .70375 .7866 L .70689 .80078 L p .707 .577 .707 r
F P
0 g
s
.25242 .67459 m .22128 .67352 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25242 .67459 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.2515 .73769 m .28294 .74239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .2515 .73769 L p .26213 .71637 L .707 .577 .707 r
F P
0 g
s
.26433 .71198 m .25513 .71182 L .26213 .71637 L .707 .577 .707 r
F
.2515 .73769 m .25513 .71182 L p .2346 .71026 L F P
0 g
s
.22046 .7339 m .2515 .73769 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22046 .7339 L p .23168 .71514 L .707 .577 .707 r
F P
0 g
s
.2346 .71026 m .22389 .70945 L .23168 .71514 L .707 .577 .707 r
F
.22128 .67352 m .19379 .66829 L p .21114 .70012 L F P
0 g
s
.21558 .70826 m .22389 .70945 L .21114 .70012 L .707 .577 .707 r
F
.22389 .70945 m .22128 .67352 L p .21114 .70012 L F P
0 g
s
.23991 .70191 m .23966 .70175 L .22507 .72568 L .707 .577 .707 r
F
.22252 .69059 m .22389 .70945 L p .23966 .70175 L F P
0 g
s
.22389 .70945 m .22507 .72568 L p .23966 .70175 L .707 .577 .707 r
F P
0 g
s
.22046 .7339 m .22389 .70945 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .22046 .7339 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19287 .7314 L p .20291 .71194 L .707 .577 .707 r
F P
0 g
s
.20556 .70682 m .1965 .70552 L .20291 .71194 L .707 .577 .707 r
F
.19379 .66829 m .17265 .65942 L p .18802 .69704 L F P
0 g
s
.19093 .70416 m .1965 .70552 L .18802 .69704 L .707 .577 .707 r
F
.1965 .70552 m .19379 .66829 L p .18802 .69704 L F P
0 g
s
.19379 .66829 m .1965 .70552 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .1965 .70552 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .19287 .7314 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17142 .73042 L p .179 .70649 L .707 .577 .707 r
F P
0 g
s
.18054 .70162 m .17563 .70042 L .179 .70649 L .707 .577 .707 r
F
.17265 .65942 m .15992 .64777 L p .17174 .69341 L F P
0 g
s
.17327 .69931 m .17563 .70042 L .17174 .69341 L .707 .577 .707 r
F
.17563 .70042 m .17265 .65942 L p .17174 .69341 L F P
0 g
s
.17265 .65942 m .17563 .70042 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .17563 .70042 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .16394 .69493 L .16364 .6968 L .707 .577 .707 r
F
.15822 .73106 m .16849 .73056 L p .16364 .6968 L F P
0 g
s
.16849 .73056 m .17142 .73042 L p .16364 .6968 L .707 .577 .707 r
F P
0 g
s
.15992 .64777 m .15686 .63448 L p .16271 .69028 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .15822 .73106 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.15822 .73106 m .16334 .69465 L p .15989 .69531 L .707 .577 .707 r
F P
0 g
s
.16311 .69413 m .16334 .69465 L .16271 .69028 L .707 .577 .707 r
F
.16334 .69465 m .15992 .64777 L p .16271 .69028 L F P
0 g
s
.15992 .64777 m .16334 .69465 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16285 .69353 m .15989 .69531 L p .16334 .69465 L .707 .577 .707 r
F P
0 g
s
.15686 .63448 m .16066 .68664 L .16071 .68688 L p .707 .577 .707 r
F P
0 g
s
.16071 .68688 m .16372 .69993 L p .15909 .65576 L .707 .577 .707 r
F P
0 g
s
.15909 .65576 m .15686 .63448 L .16071 .68688 L .707 .577 .707 r
F
.15989 .69531 m .15456 .73326 L .15822 .73106 L p F P
0 g
s
.15456 .73326 m .15989 .69531 L .16119 .69605 L p .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .16334 .69465 L p .16311 .69413 L .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .17644 .71158 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .16372 .69993 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16119 .69605 m .16613 .69885 L p .16198 .7112 L .707 .577 .707 r
F P
0 g
s
.15456 .73326 m .16119 .69605 L .16198 .7112 L .707 .577 .707 r
F
.16334 .69465 m .16355 .6931 L .16285 .69353 L p F P
0 g
s
.16355 .6931 m .16334 .69465 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .16355 .6931 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17675 .69246 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .17563 .70042 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .19759 .72045 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17644 .71158 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .17563 .70042 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .17675 .69246 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .1982 .69344 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .1965 .70552 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .22507 .72568 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19759 .72045 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .1965 .70552 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .1982 .69344 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22579 .69595 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .22389 .70945 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .22389 .70945 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .25622 .72674 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.24596 .71112 m .23991 .70191 L .2347 .71027 L .707 .577 .707 r
F
.24596 .71112 m .2347 .71027 L .22507 .72568 L F
.22128 .67352 m .22252 .69059 L p .23991 .70191 L F P
0 g
s
.25242 .67459 m .25513 .71182 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .25242 .67459 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28417 .67139 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .31172 .74754 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28294 .74239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .28715 .71239 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .28417 .67139 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31342 .66424 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .31683 .71113 L p .3411 .706 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .33501 .75263 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31172 .74754 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.33423 .709 m .3411 .706 L p .31683 .71113 L .707 .577 .707 r
F P
0 g
s
.33501 .75263 m .34034 .71468 L .31705 .70958 L p .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31722 .7164 L .33423 .709 L p .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .31683 .71113 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .28827 .70443 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .31683 .71113 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31705 .70958 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31722 .7164 m .31683 .71113 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .31722 .7164 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28797 .72355 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .28715 .71239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .25683 .69973 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .28715 .71239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28827 .70443 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .28715 .71239 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .28797 .72355 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25622 .72674 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .25513 .71182 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .22579 .69595 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25683 .69973 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .25513 .71182 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.4042 .81165 m .40938 .30646 L .37966 .29788 L p .707 .577 .707 r
F P
0 g
s
.40938 .30646 m .4042 .81165 L .44296 .81766 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68761 .63946 m .6914 .69162 L .67026 .68275 L p .707 .577 .707 r
F P
0 g
s
.67026 .68275 m .66647 .63059 L .68761 .63946 L p .707 .577 .707 r
F P
0 g
s
.70145 .76178 m .69612 .79974 L .68292 .80038 L p .707 .577 .707 r
F P
0 g
s
.3411 .706 m .33731 .65385 L .31342 .66424 L p .707 .577 .707 r
F P
0 g
s
.68292 .80038 m .68825 .76243 L .70145 .76178 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .63563 .29465 L .61253 .3039 L p .707 .577 .707 r
F P
0 g
s
.70375 .7866 m .70526 .80369 L .69248 .79133 L p .707 .577 .707 r
F P
0 g
s
.69248 .79133 m .69097 .77423 L .70375 .7866 L p .707 .577 .707 r
F P
0 g
s
.66647 .63059 m .67026 .68275 L .64277 .67752 L p .707 .577 .707 r
F P
0 g
s
.64277 .67752 m .63898 .62536 L .66647 .63059 L p .707 .577 .707 r
F P
0 g
s
.33731 .65385 m .3411 .706 L .35728 .69337 L p .707 .577 .707 r
F P
0 g
s
.35728 .69337 m .35349 .64122 L .33731 .65385 L p .707 .577 .707 r
F P
0 g
s
.37447 .80307 m .37966 .29788 L .36187 .28757 L p .707 .577 .707 r
F P
0 g
s
.37966 .29788 m .37447 .80307 L .4042 .81165 L p .707 .577 .707 r
F P
0 g
s
.68825 .76243 m .68292 .80038 L .66148 .7994 L p .707 .577 .707 r
F P
0 g
s
.66148 .7994 m .6668 .76145 L .68825 .76243 L p .707 .577 .707 r
F P
0 g
s
.25775 .8321 m .25623 .815 L .2251 .81409 L p .707 .577 .707 r
F P
0 g
s
.25623 .815 m .25775 .8321 L .28946 .82844 L p .707 .577 .707 r
F P
0 g
s
.28946 .82844 m .28795 .81135 L .25623 .815 L p .707 .577 .707 r
F P
0 g
s
.28795 .81135 m .28946 .82844 L .31865 .82059 L p .707 .577 .707 r
F P
0 g
s
.31865 .82059 m .31714 .80349 L .28795 .81135 L p .707 .577 .707 r
F P
0 g
s
.34034 .71468 m .33501 .75263 L .35053 .75717 L p .707 .577 .707 r
F P
0 g
s
.69097 .77423 m .69248 .79133 L .6713 .782 L p .707 .577 .707 r
F P
0 g
s
.6713 .782 m .66979 .76491 L .69097 .77423 L p .707 .577 .707 r
F P
0 g
s
.35349 .64122 m .35728 .69337 L .36418 .67975 L p .707 .577 .707 r
F P
0 g
s
.36418 .67975 m .36039 .62759 L .35349 .64122 L p .707 .577 .707 r
F P
0 g
s
.35053 .75717 m .35586 .71922 L .34034 .71468 L p .707 .577 .707 r
F P
0 g
s
.22661 .83119 m .2251 .81409 L .1976 .80871 L p .707 .577 .707 r
F P
0 g
s
.2251 .81409 m .22661 .83119 L .25775 .8321 L p .707 .577 .707 r
F P
0 g
s
.64043 .78919 m .64562 .284 L .63563 .29465 L p .707 .577 .707 r
F P
0 g
s
.31714 .80349 m .31865 .82059 L .34246 .8093 L p .707 .577 .707 r
F P
0 g
s
.34246 .8093 m .34095 .7922 L .31714 .80349 L p .707 .577 .707 r
F P
0 g
s
.6668 .76145 m .66148 .7994 L .63388 .7969 L p .707 .577 .707 r
F P
0 g
s
.1976 .80871 m .19911 .8258 L .22661 .83119 L p .707 .577 .707 r
F P
0 g
s
.19911 .8258 m .1976 .80871 L .17643 .79938 L p .707 .577 .707 r
F P
0 g
s
.35857 .79568 m .35706 .77858 L .34095 .7922 L p .707 .577 .707 r
F P
0 g
s
.35586 .71922 m .35053 .75717 L .35677 .76072 L p .707 .577 .707 r
F P
0 g
s
.35677 .76072 m .3621 .72277 L .35586 .71922 L p .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36039 .62759 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36112 .66646 m .36101 .6649 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .35732 .6143 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36101 .6649 L p .34839 .6548 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .36112 .66646 L .36092 .66627 L p .707 .577 .707 r
F P
0 g
s
.36092 .66627 m .34839 .6548 L p .36101 .6649 L .707 .577 .707 r
F P
0 g
s
.3621 .72277 m .35677 .76072 L .35311 .76292 L p .707 .577 .707 r
F P
0 g
s
.34839 .6548 m .3446 .60265 L .35732 .6143 L p .707 .577 .707 r
F P
0 g
s
.35311 .76292 m .35844 .72497 L .3621 .72277 L p .707 .577 .707 r
F P
0 g
s
.35844 .72497 m .35311 .76292 L .33991 .76357 L p .707 .577 .707 r
F P
0 g
s
.33991 .76357 m .34524 .72561 L .35844 .72497 L p .707 .577 .707 r
F P
0 g
s
.36074 .74978 m .36225 .76688 L .35871 .76345 L p .707 .577 .707 r
F P
0 g
s
.35871 .76345 m .34947 .75451 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.3597 .75022 m .36074 .74978 L .35871 .76345 L .707 .577 .707 r
F
.34947 .75451 m .34796 .73742 L .3598 .74887 L p F P
0 g
s
.3598 .74887 m .36074 .74978 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.34947 .75451 m .3598 .74887 L .3597 .75022 L .707 .577 .707 r
F
.35669 .79023 m .35811 .65416 L .35699 .65 L F
.35668 .79276 m .35671 .78991 L p .35669 .79023 L F P
0 g
s
.35671 .78991 m .35811 .65416 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35343 .78402 m .35653 .79235 L p .35682 .73081 L .707 .577 .707 r
F P
0 g
s
.35653 .79235 m .35668 .79276 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35669 .79023 m .35682 .73081 L .35653 .79235 L .707 .577 .707 r
F
.35778 .27656 m .35259 .78175 L .35343 .78402 L p F P
0 g
s
.35682 .73081 m .35778 .27656 L .35343 .78402 L .707 .577 .707 r
F
.36187 .28757 m .35778 .27656 L p .35699 .65 L F P
0 g
s
.35811 .65416 m .36187 .28757 L p .35699 .65 L .707 .577 .707 r
F P
0 g
s
.36039 .62759 m .36418 .67975 L .36112 .66646 L p .707 .577 .707 r
F P
0 g
s
.35706 .77858 m .35857 .79568 L .36539 .78106 L p .707 .577 .707 r
F P
0 g
s
.36539 .78106 m .36388 .76396 L .35706 .77858 L p .707 .577 .707 r
F P
0 g
s
.36388 .76396 m .36539 .78106 L .36225 .76688 L p .707 .577 .707 r
F P
0 g
s
.36225 .76688 m .36074 .74978 L .36388 .76396 L p .707 .577 .707 r
F P
0 g
s
.36187 .28757 m .35668 .79276 L .37447 .80307 L p .707 .577 .707 r
F P
0 g
s
.66979 .76491 m .6713 .782 L .6438 .77662 L p .707 .577 .707 r
F P
0 g
s
.6438 .77662 m .64229 .75952 L .66979 .76491 L p .707 .577 .707 r
F P
0 g
s
.34095 .7922 m .34246 .8093 L .35857 .79568 L p .707 .577 .707 r
F P
0 g
s
.17643 .79938 m .17794 .81647 L .19911 .8258 L p .707 .577 .707 r
F P
0 g
s
.17794 .81647 m .17643 .79938 L .16364 .78702 L p .707 .577 .707 r
F P
0 g
s
.64562 .284 m .64043 .78919 L .63634 .77817 L p .707 .577 .707 r
F P
0 g
s
.63634 .77817 m .64153 .27298 L .64562 .284 L p .707 .577 .707 r
F P
0 g
s
.16066 .68664 m .15686 .63448 L .16376 .62085 L p .707 .577 .707 r
F P
0 g
s
.16364 .78702 m .16515 .80411 L .17794 .81647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35259 .78175 m .35778 .27656 L .36777 .2659 L p .707 .577 .707 r
F P
0 g
s
.16515 .80411 m .16364 .78702 L .16051 .77283 L p .707 .577 .707 r
F P
0 g
s
.16613 .69885 m .1608 .73681 L .15456 .73326 L p .707 .577 .707 r
F P
0 g
s
.16376 .62085 m .16755 .67301 L .16066 .68664 L p .707 .577 .707 r
F P
0 g
s
.16755 .67301 m .16376 .62085 L .17994 .60822 L p .707 .577 .707 r
F P
0 g
s
.16051 .77283 m .16202 .78993 L .16515 .80411 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3446 .60265 m .34839 .6548 L .32725 .64593 L p .707 .577 .707 r
F P
0 g
s
.32725 .64593 m .32346 .59377 L .3446 .60265 L p .707 .577 .707 r
F P
0 g
s
.64153 .27298 m .63634 .77817 L .61856 .76787 L p .707 .577 .707 r
F P
0 g
s
.61856 .76787 m .62375 .26268 L .64153 .27298 L p .707 .577 .707 r
F P
0 g
s
.16202 .78993 m .16051 .77283 L .16733 .75822 L p .707 .577 .707 r
F P
0 g
s
.17994 .60822 m .18374 .66038 L .16755 .67301 L p .707 .577 .707 r
F P
0 g
s
.18374 .66038 m .17994 .60822 L .20383 .59782 L p .707 .577 .707 r
F P
0 g
s
.18165 .7034 m .17632 .74135 L .1608 .73681 L p .707 .577 .707 r
F P
0 g
s
.1608 .73681 m .16613 .69885 L .18165 .7034 L p .707 .577 .707 r
F P
0 g
s
.16733 .75822 m .16884 .77531 L .16202 .78993 L p .707 .577 .707 r
F P
0 g
s
.36258 .77109 m .36777 .2659 L .39088 .25666 L p .707 .577 .707 r
F P
0 g
s
.36777 .2659 m .36258 .77109 L .35259 .78175 L p .707 .577 .707 r
F P
0 g
s
.32346 .59377 m .32725 .64593 L .29977 .64071 L p .707 .577 .707 r
F P
0 g
s
.29977 .64071 m .29597 .58855 L .32346 .59377 L p .707 .577 .707 r
F P
0 g
s
.20762 .64998 m .20383 .59782 L .23308 .59068 L p .707 .577 .707 r
F P
0 g
s
.20383 .59782 m .20762 .64998 L .18374 .66038 L p .707 .577 .707 r
F P
0 g
s
.34524 .72561 m .33991 .76357 L .31847 .76259 L p .707 .577 .707 r
F P
0 g
s
.31847 .76259 m .3238 .72463 L .34524 .72561 L p .707 .577 .707 r
F P
0 g
s
.16884 .77531 m .16733 .75822 L .18343 .7446 L p .707 .577 .707 r
F P
0 g
s
.29597 .58855 m .29977 .64071 L .26862 .63964 L p .707 .577 .707 r
F P
0 g
s
.26862 .63964 m .26483 .58748 L .29597 .58855 L p .707 .577 .707 r
F P
0 g
s
.20494 .70849 m .19961 .74645 L .17632 .74135 L p .707 .577 .707 r
F P
0 g
s
.17632 .74135 m .18165 .7034 L .20494 .70849 L p .707 .577 .707 r
F P
0 g
s
.23687 .64284 m .23308 .59068 L .26483 .58748 L p .707 .577 .707 r
F P
0 g
s
.23308 .59068 m .23687 .64284 L .20762 .64998 L p .707 .577 .707 r
F P
0 g
s
.62375 .26268 m .61856 .76787 L .58883 .75929 L p .707 .577 .707 r
F P
0 g
s
.58883 .75929 m .59402 .2541 L .62375 .26268 L p .707 .577 .707 r
F P
0 g
s
.26483 .58748 m .26862 .63964 L .23687 .64284 L p .707 .577 .707 r
F P
0 g
s
.18343 .7446 m .18494 .76169 L .16884 .77531 L p .707 .577 .707 r
F P
0 g
s
.34796 .73742 m .34947 .75451 L .32829 .74519 L p .707 .577 .707 r
F P
0 g
s
.32829 .74519 m .32678 .72809 L .34796 .73742 L p .707 .577 .707 r
F P
0 g
s
.3238 .72463 m .31847 .76259 L .29088 .76008 L p .707 .577 .707 r
F P
0 g
s
.73263 .61936 m .70149 .61829 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73263 .61936 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73171 .68285 m .76316 .68755 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73171 .68285 L p .74231 .66137 L .707 .577 .707 r
F P
0 g
s
.74446 .65701 m .73536 .65685 L .74231 .66137 L .707 .577 .707 r
F
.73171 .68285 m .73536 .65685 L p .71473 .65528 L F P
0 g
s
.70067 .67906 m .73171 .68285 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .70067 .67906 L p .71186 .66014 L .707 .577 .707 r
F P
0 g
s
.71473 .65528 m .70412 .65448 L .71186 .66014 L .707 .577 .707 r
F
.70149 .61829 m .674 .61307 L p .69157 .6453 L F P
0 g
s
.69594 .6533 m .70412 .65448 L .69157 .6453 L .707 .577 .707 r
F
.70412 .65448 m .70149 .61829 L p .69157 .6453 L F P
0 g
s
.72041 .64711 m .7199 .64678 L .70529 .67045 L .707 .577 .707 r
F
.70275 .63562 m .70412 .65448 L p .7199 .64678 L F P
0 g
s
.70412 .65448 m .70529 .67045 L p .7199 .64678 L .707 .577 .707 r
F P
0 g
s
.70067 .67906 m .70412 .65448 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .70067 .67906 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67308 .67656 L p .6831 .65692 L .707 .577 .707 r
F P
0 g
s
.68569 .65184 m .67673 .65055 L .6831 .65692 L .707 .577 .707 r
F
.674 .61307 m .65286 .6042 L p .6684 .64221 L F P
0 g
s
.67126 .64921 m .67673 .65055 L .6684 .64221 L .707 .577 .707 r
F
.67673 .65055 m .674 .61307 L p .6684 .64221 L F P
0 g
s
.674 .61307 m .67673 .65055 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .67673 .65055 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .67308 .67656 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65164 .67558 L p .65919 .65144 L .707 .577 .707 r
F P
0 g
s
.66069 .64663 m .65586 .64545 L .65919 .65144 L .707 .577 .707 r
F
.65286 .6042 m .64014 .59254 L p .65206 .6386 L F P
0 g
s
.65586 .64545 m .65286 .6042 L p .65206 .6386 L .707 .577 .707 r
F P
0 g
s
.65286 .6042 m .65586 .64545 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .65586 .64545 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .64412 .63994 L .64385 .64165 L .707 .577 .707 r
F
.63844 .67622 m .64874 .67572 L p .64385 .64165 L F P
0 g
s
.64874 .67572 m .65164 .67558 L p .64385 .64165 L .707 .577 .707 r
F P
0 g
s
.64014 .59254 m .63707 .57925 L p .64297 .63552 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .63844 .67622 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.63844 .67622 m .64357 .63968 L p .64011 .64047 L .707 .577 .707 r
F P
0 g
s
.64335 .63918 m .64357 .63968 L .64297 .63552 L .707 .577 .707 r
F
.64357 .63968 m .64014 .59254 L p .64297 .63552 L F P
0 g
s
.64014 .59254 m .64357 .63968 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64313 .63865 m .64011 .64047 L p .64357 .63968 L .707 .577 .707 r
F P
0 g
s
.63707 .57925 m .64087 .63141 L .64093 .63169 L p .707 .577 .707 r
F P
0 g
s
.64093 .63169 m .64393 .6447 L p .63931 .60063 L .707 .577 .707 r
F P
0 g
s
.63931 .60063 m .63707 .57925 L .64093 .63169 L .707 .577 .707 r
F
.64011 .64047 m .63478 .67843 L .63844 .67622 L p F P
0 g
s
.63478 .67843 m .64011 .64047 L .64143 .64122 L p .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .64357 .63968 L p .64335 .63918 L .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .65666 .65635 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .64393 .6447 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64143 .64122 m .64634 .64402 L p .64222 .6563 L .707 .577 .707 r
F P
0 g
s
.63478 .67843 m .64143 .64122 L .64222 .6563 L .707 .577 .707 r
F
.64357 .63968 m .64377 .63827 L .64313 .63865 L p F P
0 g
s
.64377 .63827 m .64357 .63968 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .64377 .63827 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65355 .64437 m .65586 .64545 L .65206 .6386 L .707 .577 .707 r
F
.65586 .64545 m .65696 .63762 L p .64412 .63994 L F P
0 g
s
.65666 .65635 m .65586 .64545 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.65666 .65635 m .6778 .66523 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65666 .65635 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .65586 .64545 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .65696 .63762 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67841 .6386 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .67673 .65055 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .70529 .67045 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .6778 .66523 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .67673 .65055 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .67841 .6386 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .706 .64111 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .70412 .65448 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .70412 .65448 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .73643 .67152 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.72635 .65616 m .72041 .64711 L .71509 .65531 L .707 .577 .707 r
F
.72635 .65616 m .71509 .65531 L .70529 .67045 L F
.70149 .61829 m .70275 .63562 L p .72041 .64711 L F P
0 g
s
.73263 .61936 m .73536 .65685 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .73263 .61936 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76438 .61617 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .79193 .6927 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76316 .68755 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .76739 .65742 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .76438 .61617 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79363 .60902 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .79706 .65616 L p .82131 .65078 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .81522 .69779 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79193 .6927 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.81362 .65413 m .82131 .65078 L p .79706 .65616 L .707 .577 .707 r
F P
0 g
s
.81522 .69779 m .82055 .65984 L .79726 .65474 L p .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79743 .66118 L .81362 .65413 L p .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .79706 .65616 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .76849 .64959 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .79706 .65616 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79726 .65474 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79743 .66118 m .79706 .65616 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .79743 .66118 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76818 .66832 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .76739 .65742 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .73704 .6449 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .76739 .65742 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76849 .64959 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .76739 .65742 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .76818 .66832 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73643 .67152 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .73536 .65685 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .706 .64111 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73704 .6449 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .73536 .65685 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.39088 .25666 m .38569 .76185 L .36258 .77109 L p .707 .577 .707 r
F P
0 g
s
.38569 .76185 m .39088 .25666 L .42483 .24972 L p .707 .577 .707 r
F P
0 g
s
.29088 .76008 m .2962 .72213 L .3238 .72463 L p .707 .577 .707 r
F P
0 g
s
.19961 .74645 m .20494 .70849 L .23372 .71364 L p .707 .577 .707 r
F P
0 g
s
.18494 .76169 m .18343 .7446 L .20724 .73331 L p .707 .577 .707 r
F P
0 g
s
.23372 .71364 m .22839 .7516 L .19961 .74645 L p .707 .577 .707 r
F P
0 g
s
.32678 .72809 m .32829 .74519 L .30079 .7398 L p .707 .577 .707 r
F P
0 g
s
.30079 .7398 m .29928 .72271 L .32678 .72809 L p .707 .577 .707 r
F P
0 g
s
.20724 .73331 m .20875 .7504 L .18494 .76169 L p .707 .577 .707 r
F P
0 g
s
.82131 .65078 m .81752 .59862 L .79363 .60902 L p .707 .577 .707 r
F P
0 g
s
.2962 .72213 m .29088 .76008 L .25984 .7563 L p .707 .577 .707 r
F P
0 g
s
.25984 .7563 m .26517 .71834 L .2962 .72213 L p .707 .577 .707 r
F P
0 g
s
.26517 .71834 m .25984 .7563 L .22839 .7516 L p .707 .577 .707 r
F P
0 g
s
.22839 .7516 m .23372 .71364 L .26517 .71834 L p .707 .577 .707 r
F P
0 g
s
.59402 .2541 m .58883 .75929 L .55006 .75327 L p .707 .577 .707 r
F P
0 g
s
.55006 .75327 m .55525 .24808 L .59402 .2541 L p .707 .577 .707 r
F P
0 g
s
.20875 .7504 m .20724 .73331 L .23644 .72545 L p .707 .577 .707 r
F P
0 g
s
.29928 .72271 m .30079 .7398 L .26966 .73889 L p .707 .577 .707 r
F P
0 g
s
.26966 .73889 m .26815 .7218 L .29928 .72271 L p .707 .577 .707 r
F P
0 g
s
.23644 .72545 m .23795 .74254 L .20875 .7504 L p .707 .577 .707 r
F P
0 g
s
.41964 .75491 m .42483 .24972 L .4663 .24578 L p .707 .577 .707 r
F P
0 g
s
.42483 .24972 m .41964 .75491 L .38569 .76185 L p .707 .577 .707 r
F P
0 g
s
.23795 .74254 m .23644 .72545 L .26815 .7218 L p .707 .577 .707 r
F P
0 g
s
.81752 .59862 m .82131 .65078 L .8375 .63815 L p .707 .577 .707 r
F P
0 g
s
.8375 .63815 m .8337 .58599 L .81752 .59862 L p .707 .577 .707 r
F P
0 g
s
.26815 .7218 m .26966 .73889 L .23795 .74254 L p .707 .577 .707 r
F P
0 g
s
.55525 .24808 m .55006 .75327 L .50606 .7504 L p .707 .577 .707 r
F P
0 g
s
.50606 .7504 m .51125 .24521 L .55525 .24808 L p .707 .577 .707 r
F P
0 g
s
.46112 .75097 m .4663 .24578 L .51125 .24521 L p .707 .577 .707 r
F P
0 g
s
.4663 .24578 m .46112 .75097 L .41964 .75491 L p .707 .577 .707 r
F P
0 g
s
.73796 .7754 m .73645 .7583 L .70532 .75739 L p .707 .577 .707 r
F P
0 g
s
.73645 .7583 m .73796 .7754 L .76967 .77175 L p .707 .577 .707 r
F P
0 g
s
.76967 .77175 m .76816 .75465 L .73645 .7583 L p .707 .577 .707 r
F P
0 g
s
.76816 .75465 m .76967 .77175 L .79886 .76389 L p .707 .577 .707 r
F P
0 g
s
.79886 .76389 m .79735 .74679 L .76816 .75465 L p .707 .577 .707 r
F P
0 g
s
.51125 .24521 m .50606 .7504 L .46112 .75097 L p .707 .577 .707 r
F P
0 g
s
.82055 .65984 m .81522 .69779 L .83075 .70234 L p .707 .577 .707 r
F P
0 g
s
.8337 .58599 m .8375 .63815 L .8444 .62452 L p .707 .577 .707 r
F P
0 g
s
.8444 .62452 m .8406 .57236 L .8337 .58599 L p .707 .577 .707 r
F P
0 g
s
.70683 .77449 m .70532 .75739 L .67782 .75201 L p .707 .577 .707 r
F P
0 g
s
.70532 .75739 m .70683 .77449 L .73796 .7754 L p .707 .577 .707 r
F P
0 g
s
.83075 .70234 m .83607 .66438 L .82055 .65984 L p .707 .577 .707 r
F P
0 g
s
.79735 .74679 m .79886 .76389 L .82268 .7526 L p .707 .577 .707 r
F P
0 g
s
.82268 .7526 m .82117 .7355 L .79735 .74679 L p .707 .577 .707 r
F P
0 g
s
.67782 .75201 m .67933 .7691 L .70683 .77449 L p .707 .577 .707 r
F P
0 g
s
.67933 .7691 m .67782 .75201 L .65664 .74268 L p .707 .577 .707 r
F P
0 g
s
.82117 .7355 m .82268 .7526 L .83878 .73898 L p .707 .577 .707 r
F P
0 g
s
.83878 .73898 m .83727 .72188 L .82117 .7355 L p .707 .577 .707 r
F P
0 g
s
.65664 .74268 m .65815 .75978 L .67933 .7691 L p .707 .577 .707 r
F P
0 g
s
.83607 .66438 m .83075 .70234 L .83698 .70588 L p .707 .577 .707 r
F P
0 g
s
.83698 .70588 m .84231 .66793 L .83607 .66438 L p .707 .577 .707 r
F P
0 g
s
.8406 .57236 m .8444 .62452 L .84133 .61123 L p .707 .577 .707 r
F P
0 g
s
.84133 .61123 m .83754 .55907 L .8406 .57236 L p .707 .577 .707 r
F P
0 g
s
.65815 .75978 m .65664 .74268 L .64386 .73032 L p .707 .577 .707 r
F P
0 g
s
.64087 .63141 m .63707 .57925 L .64397 .56563 L p .707 .577 .707 r
F P
0 g
s
.64386 .73032 m .64537 .74741 L .65815 .75978 L p .707 .577 .707 r
F P
0 g
s
.83727 .72188 m .83878 .73898 L .8456 .72436 L p .707 .577 .707 r
F P
0 g
s
.8456 .72436 m .84409 .70726 L .83727 .72188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84231 .66793 m .83698 .70588 L .83332 .70809 L p .707 .577 .707 r
F P
0 g
s
.83754 .55907 m .84133 .61123 L .82861 .59958 L p .707 .577 .707 r
F P
0 g
s
.82861 .59958 m .82481 .54742 L .83754 .55907 L p .707 .577 .707 r
F P
0 g
s
.83332 .70809 m .83865 .67013 L .84231 .66793 L p .707 .577 .707 r
F P
0 g
s
.64537 .74741 m .64386 .73032 L .64072 .71614 L p .707 .577 .707 r
F P
0 g
s
.64634 .64402 m .64101 .68197 L .63478 .67843 L p .707 .577 .707 r
F P
0 g
s
.64397 .56563 m .64777 .61778 L .64087 .63141 L p .707 .577 .707 r
F P
0 g
s
.64072 .71614 m .64223 .73323 L .64537 .74741 L p .707 .577 .707 r
F P
0 g
s
.64777 .61778 m .64397 .56563 L .66015 .553 L p .707 .577 .707 r
F P
0 g
s
.84409 .70726 m .8456 .72436 L .84247 .71018 L p .707 .577 .707 r
F P
0 g
s
.84247 .71018 m .84095 .69308 L .84409 .70726 L p .707 .577 .707 r
F P
0 g
s
.38962 .58255 m .35848 .58148 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .38962 .58255 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.3887 .64603 m .42015 .65073 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .3887 .64603 L p .3993 .62455 L .707 .577 .707 r
F P
0 g
s
.40145 .62019 m .39235 .62003 L .3993 .62455 L .707 .577 .707 r
F
.3887 .64603 m .39235 .62003 L p .37172 .61847 L F P
0 g
s
.35766 .64225 m .3887 .64603 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .35766 .64225 L p .36885 .62332 L .707 .577 .707 r
F P
0 g
s
.37172 .61847 m .36111 .61766 L .36885 .62332 L .707 .577 .707 r
F
.35848 .58148 m .33099 .57625 L p .34856 .60848 L F P
0 g
s
.35293 .61649 m .36111 .61766 L .34856 .60848 L .707 .577 .707 r
F
.36111 .61766 m .35848 .58148 L p .34856 .60848 L F P
0 g
s
.3774 .61029 m .37689 .60996 L .36228 .63364 L .707 .577 .707 r
F
.35974 .5988 m .36111 .61766 L p .37689 .60996 L F P
0 g
s
.36111 .61766 m .36228 .63364 L p .37689 .60996 L .707 .577 .707 r
F P
0 g
s
.35766 .64225 m .36111 .61766 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .35766 .64225 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33007 .63974 L p .34009 .62011 L .707 .577 .707 r
F P
0 g
s
.34268 .61502 m .33372 .61374 L .34009 .62011 L .707 .577 .707 r
F
.33099 .57625 m .30985 .56738 L p .32539 .6054 L F P
0 g
s
.32825 .6124 m .33372 .61374 L .32539 .6054 L .707 .577 .707 r
F
.33372 .61374 m .33099 .57625 L p .32539 .6054 L F P
0 g
s
.33099 .57625 m .33372 .61374 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .33372 .61374 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .33007 .63974 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .30863 .63876 L p .31618 .61463 L .707 .577 .707 r
F P
0 g
s
.31768 .60982 m .31285 .60864 L .31618 .61463 L .707 .577 .707 r
F
.30985 .56738 m .29713 .55573 L p .30905 .60178 L F P
0 g
s
.31285 .60864 m .30985 .56738 L p .30905 .60178 L .707 .577 .707 r
F P
0 g
s
.30985 .56738 m .31285 .60864 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .31285 .60864 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .30111 .60312 L .30084 .60484 L .707 .577 .707 r
F
.29543 .63941 m .30573 .6389 L p .30084 .60484 L F P
0 g
s
.30573 .6389 m .30863 .63876 L p .30084 .60484 L .707 .577 .707 r
F P
0 g
s
.29713 .55573 m .29406 .54244 L p .29996 .59871 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .29543 .63941 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.29543 .63941 m .30056 .60286 L p .2971 .60365 L .707 .577 .707 r
F P
0 g
s
.30034 .60237 m .30056 .60286 L .29996 .59871 L .707 .577 .707 r
F
.30056 .60286 m .29713 .55573 L p .29996 .59871 L F P
0 g
s
.29713 .55573 m .30056 .60286 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30012 .60184 m .2971 .60365 L p .30056 .60286 L .707 .577 .707 r
F P
0 g
s
.29406 .54244 m .29786 .5946 L .29792 .59487 L p .707 .577 .707 r
F P
0 g
s
.29792 .59487 m .30092 .60789 L p .2963 .56382 L .707 .577 .707 r
F P
0 g
s
.2963 .56382 m .29406 .54244 L .29792 .59487 L .707 .577 .707 r
F
.2971 .60365 m .29177 .64161 L .29543 .63941 L p F P
0 g
s
.29177 .64161 m .2971 .60365 L .29842 .60441 L p .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .30056 .60286 L p .30034 .60237 L .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .31365 .61954 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .30092 .60789 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.29842 .60441 m .30333 .6072 L p .2992 .61948 L .707 .577 .707 r
F P
0 g
s
.29177 .64161 m .29842 .60441 L .2992 .61948 L .707 .577 .707 r
F
.30056 .60286 m .30076 .60145 L .30012 .60184 L p F P
0 g
s
.30076 .60145 m .30056 .60286 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .30076 .60145 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31054 .60755 m .31285 .60864 L .30905 .60178 L .707 .577 .707 r
F
.31285 .60864 m .31395 .60081 L p .30111 .60312 L F P
0 g
s
.31365 .61954 m .31285 .60864 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.31365 .61954 m .33479 .62841 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .31365 .61954 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .31285 .60864 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .31395 .60081 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .3354 .60179 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .33372 .61374 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .36228 .63364 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33479 .62841 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .33372 .61374 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .3354 .60179 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .36299 .60429 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .36111 .61766 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .36111 .61766 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .39342 .6347 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.38334 .61935 m .3774 .61029 L .37208 .61849 L .707 .577 .707 r
F
.38334 .61935 m .37208 .61849 L .36228 .63364 L F
.35848 .58148 m .35974 .5988 L p .3774 .61029 L F P
0 g
s
.38962 .58255 m .39235 .62003 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .38962 .58255 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42137 .57935 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .44892 .65588 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42015 .65073 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .42438 .62061 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .42137 .57935 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45062 .5722 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .45405 .61934 L p .4783 .61396 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .47221 .66098 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .44892 .65588 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.47061 .61731 m .4783 .61396 L p .45405 .61934 L .707 .577 .707 r
F P
0 g
s
.47221 .66098 m .47754 .62302 L .45425 .61793 L p .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45442 .62436 L .47061 .61731 L p .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .45405 .61934 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .42548 .61278 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .45405 .61934 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45425 .61793 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45442 .62436 m .45405 .61934 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .45442 .62436 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42517 .63151 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .42438 .62061 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .39403 .60808 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .42438 .62061 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42548 .61278 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .42438 .62061 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .42517 .63151 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39342 .6347 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .39235 .62003 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .36299 .60429 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39403 .60808 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .39235 .62003 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82481 .54742 m .82861 .59958 L .80747 .59071 L p .707 .577 .707 r
F P
0 g
s
.80747 .59071 m .80367 .53855 L .82481 .54742 L p .707 .577 .707 r
F P
0 g
s
.83865 .67013 m .83332 .70809 L .82013 .70873 L p .707 .577 .707 r
F P
0 g
s
.4783 .61396 m .47451 .56181 L .45062 .5722 L p .707 .577 .707 r
F P
0 g
s
.82013 .70873 m .82545 .67077 L .83865 .67013 L p .707 .577 .707 r
F P
0 g
s
.64223 .73323 m .64072 .71614 L .64754 .70152 L p .707 .577 .707 r
F P
0 g
s
.66015 .553 m .66395 .60515 L .64777 .61778 L p .707 .577 .707 r
F P
0 g
s
.66395 .60515 m .66015 .553 L .68404 .5426 L p .707 .577 .707 r
F P
0 g
s
.66187 .64856 m .65654 .68652 L .64101 .68197 L p .707 .577 .707 r
F P
0 g
s
.64101 .68197 m .64634 .64402 L .66187 .64856 L p .707 .577 .707 r
F P
0 g
s
.64754 .70152 m .64905 .71861 L .64223 .73323 L p .707 .577 .707 r
F P
0 g
s
.84095 .69308 m .84247 .71018 L .82968 .69782 L p .707 .577 .707 r
F P
0 g
s
.82968 .69782 m .82817 .68072 L .84095 .69308 L p .707 .577 .707 r
F P
0 g
s
.80367 .53855 m .80747 .59071 L .77998 .58548 L p .707 .577 .707 r
F P
0 g
s
.77998 .58548 m .77618 .53332 L .80367 .53855 L p .707 .577 .707 r
F P
0 g
s
.47451 .56181 m .4783 .61396 L .49449 .60133 L p .707 .577 .707 r
F P
0 g
s
.49449 .60133 m .49069 .54918 L .47451 .56181 L p .707 .577 .707 r
F P
0 g
s
.68784 .59476 m .68404 .5426 L .71329 .53545 L p .707 .577 .707 r
F P
0 g
s
.68404 .5426 m .68784 .59476 L .66395 .60515 L p .707 .577 .707 r
F P
0 g
s
.82545 .67077 m .82013 .70873 L .79868 .70775 L p .707 .577 .707 r
F P
0 g
s
.79868 .70775 m .80401 .6698 L .82545 .67077 L p .707 .577 .707 r
F P
0 g
s
.68516 .65366 m .67983 .69161 L .65654 .68652 L p .707 .577 .707 r
F P
0 g
s
.64905 .71861 m .64754 .70152 L .66364 .6879 L p .707 .577 .707 r
F P
0 g
s
.77618 .53332 m .77998 .58548 L .74884 .58441 L p .707 .577 .707 r
F P
0 g
s
.74884 .58441 m .74504 .53226 L .77618 .53332 L p .707 .577 .707 r
F P
0 g
s
.39495 .73858 m .39344 .72149 L .36231 .72058 L p .707 .577 .707 r
F P
0 g
s
.39344 .72149 m .39495 .73858 L .42666 .73493 L p .707 .577 .707 r
F P
0 g
s
.42666 .73493 m .42515 .71783 L .39344 .72149 L p .707 .577 .707 r
F P
0 g
s
.65654 .68652 m .66187 .64856 L .68516 .65366 L p .707 .577 .707 r
F P
0 g
s
.42515 .71783 m .42666 .73493 L .45585 .72707 L p .707 .577 .707 r
F P
0 g
s
.45585 .72707 m .45434 .70998 L .42515 .71783 L p .707 .577 .707 r
F P
0 g
s
.71709 .58761 m .71329 .53545 L .74504 .53226 L p .707 .577 .707 r
F P
0 g
s
.71329 .53545 m .71709 .58761 L .68784 .59476 L p .707 .577 .707 r
F P
0 g
s
.74504 .53226 m .74884 .58441 L .71709 .58761 L p .707 .577 .707 r
F P
0 g
s
.66364 .6879 m .66515 .70499 L .64905 .71861 L p .707 .577 .707 r
F P
0 g
s
.47754 .62302 m .47221 .66098 L .48774 .66552 L p .707 .577 .707 r
F P
0 g
s
.82817 .68072 m .82968 .69782 L .80851 .68849 L p .707 .577 .707 r
F P
0 g
s
.80851 .68849 m .807 .67139 L .82817 .68072 L p .707 .577 .707 r
F P
0 g
s
.49069 .54918 m .49449 .60133 L .50139 .58771 L p .707 .577 .707 r
F P
0 g
s
.50139 .58771 m .49759 .53555 L .49069 .54918 L p .707 .577 .707 r
F P
0 g
s
.36382 .73767 m .36231 .72058 L .33481 .71519 L p .707 .577 .707 r
F P
0 g
s
.36231 .72058 m .36382 .73767 L .39495 .73858 L p .707 .577 .707 r
F P
0 g
s
.48774 .66552 m .49306 .62757 L .47754 .62302 L p .707 .577 .707 r
F P
0 g
s
.45434 .70998 m .45585 .72707 L .47967 .71578 L p .707 .577 .707 r
F P
0 g
s
.47967 .71578 m .47816 .69869 L .45434 .70998 L p .707 .577 .707 r
F P
0 g
s
.80401 .6698 m .79868 .70775 L .77109 .70524 L p .707 .577 .707 r
F P
0 g
s
.33481 .71519 m .33632 .73229 L .36382 .73767 L p .707 .577 .707 r
F P
0 g
s
.77109 .70524 m .77642 .66729 L .80401 .6698 L p .707 .577 .707 r
F P
0 g
s
.67983 .69161 m .68516 .65366 L .71393 .6588 L p .707 .577 .707 r
F P
0 g
s
.66515 .70499 m .66364 .6879 L .68746 .67661 L p .707 .577 .707 r
F P
0 g
s
.71393 .6588 m .7086 .69676 L .67983 .69161 L p .707 .577 .707 r
F P
0 g
s
.33632 .73229 m .33481 .71519 L .31363 .70586 L p .707 .577 .707 r
F P
0 g
s
.807 .67139 m .80851 .68849 L .78101 .6831 L p .707 .577 .707 r
F P
0 g
s
.78101 .6831 m .7795 .66601 L .807 .67139 L p .707 .577 .707 r
F P
0 g
s
.68746 .67661 m .68897 .6937 L .66515 .70499 L p .707 .577 .707 r
F P
0 g
s
.47816 .69869 m .47967 .71578 L .49577 .70216 L p .707 .577 .707 r
F P
0 g
s
.49577 .70216 m .49426 .68507 L .47816 .69869 L p .707 .577 .707 r
F P
0 g
s
.77642 .66729 m .77109 .70524 L .74005 .70146 L p .707 .577 .707 r
F P
0 g
s
.31363 .70586 m .31514 .72296 L .33632 .73229 L p .707 .577 .707 r
F P
0 g
s
.49306 .62757 m .48774 .66552 L .49397 .66907 L p .707 .577 .707 r
F P
0 g
s
.74005 .70146 m .74538 .6635 L .77642 .66729 L p .707 .577 .707 r
F P
0 g
s
.74538 .6635 m .74005 .70146 L .7086 .69676 L p .707 .577 .707 r
F P
0 g
s
.7086 .69676 m .71393 .6588 L .74538 .6635 L p .707 .577 .707 r
F P
0 g
s
.49397 .66907 m .4993 .63111 L .49306 .62757 L p .707 .577 .707 r
F P
0 g
s
.49759 .53555 m .50139 .58771 L .49832 .57442 L p .707 .577 .707 r
F P
0 g
s
.49832 .57442 m .49453 .52226 L .49759 .53555 L p .707 .577 .707 r
F P
0 g
s
.68897 .6937 m .68746 .67661 L .71665 .66875 L p .707 .577 .707 r
F P
0 g
s
.7795 .66601 m .78101 .6831 L .74987 .68219 L p .707 .577 .707 r
F P
0 g
s
.74987 .68219 m .74836 .6651 L .7795 .66601 L p .707 .577 .707 r
F P
0 g
s
.31514 .72296 m .31363 .70586 L .30085 .6935 L p .707 .577 .707 r
F P
0 g
s
.71665 .66875 m .71816 .68585 L .68897 .6937 L p .707 .577 .707 r
F P
0 g
s
.71816 .68585 m .71665 .66875 L .74836 .6651 L p .707 .577 .707 r
F P
0 g
s
.74836 .6651 m .74987 .68219 L .71816 .68585 L p .707 .577 .707 r
F P
0 g
s
.29786 .5946 m .29406 .54244 L .30096 .52881 L p .707 .577 .707 r
F P
0 g
s
.30085 .6935 m .30236 .7106 L .31514 .72296 L p .707 .577 .707 r
F P
0 g
s
.49426 .68507 m .49577 .70216 L .50259 .68754 L p .707 .577 .707 r
F P
0 g
s
.50259 .68754 m .50108 .67045 L .49426 .68507 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4993 .63111 m .49397 .66907 L .49031 .67127 L p .707 .577 .707 r
F P
0 g
s
.49453 .52226 m .49832 .57442 L .4856 .56276 L p .707 .577 .707 r
F P
0 g
s
.4856 .56276 m .4818 .51061 L .49453 .52226 L p .707 .577 .707 r
F P
0 g
s
.49031 .67127 m .49564 .63332 L .4993 .63111 L p .707 .577 .707 r
F P
0 g
s
.30236 .7106 m .30085 .6935 L .29771 .67932 L p .707 .577 .707 r
F P
0 g
s
.30333 .6072 m .298 .64516 L .29177 .64161 L p .707 .577 .707 r
F P
0 g
s
.30096 .52881 m .30476 .58097 L .29786 .5946 L p .707 .577 .707 r
F P
0 g
s
.29771 .67932 m .29922 .69642 L .30236 .7106 L p .707 .577 .707 r
F P
0 g
s
.30476 .58097 m .30096 .52881 L .31714 .51618 L p .707 .577 .707 r
F P
0 g
s
.50108 .67045 m .50259 .68754 L .49945 .67336 L p .707 .577 .707 r
F P
0 g
s
.49945 .67336 m .49794 .65627 L .50108 .67045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4818 .51061 m .4856 .56276 L .46446 .55389 L p .707 .577 .707 r
F P
0 g
s
.46446 .55389 m .46066 .50173 L .4818 .51061 L p .707 .577 .707 r
F P
0 g
s
.49564 .63332 m .49031 .67127 L .47712 .67191 L p .707 .577 .707 r
F P
0 g
s
.47712 .67191 m .48244 .63396 L .49564 .63332 L p .707 .577 .707 r
F P
0 g
s
.29922 .69642 m .29771 .67932 L .30453 .6647 L p .707 .577 .707 r
F P
0 g
s
.31714 .51618 m .32094 .56834 L .30476 .58097 L p .707 .577 .707 r
F P
0 g
s
.32094 .56834 m .31714 .51618 L .34103 .50578 L p .707 .577 .707 r
F P
0 g
s
.31886 .61174 m .31353 .6497 L .298 .64516 L p .707 .577 .707 r
F P
0 g
s
.298 .64516 m .30333 .6072 L .31886 .61174 L p .707 .577 .707 r
F P
0 g
s
.30453 .6647 m .30604 .6818 L .29922 .69642 L p .707 .577 .707 r
F P
0 g
s
.49794 .65627 m .49945 .67336 L .48667 .661 L p .707 .577 .707 r
F P
0 g
s
.48667 .661 m .48516 .6439 L .49794 .65627 L p .707 .577 .707 r
F P
0 g
s
.46066 .50173 m .46446 .55389 L .43697 .54867 L p .707 .577 .707 r
F P
0 g
s
.43697 .54867 m .43317 .49651 L .46066 .50173 L p .707 .577 .707 r
F P
0 g
s
.34483 .55794 m .34103 .50578 L .37028 .49864 L p .707 .577 .707 r
F P
0 g
s
.34103 .50578 m .34483 .55794 L .32094 .56834 L p .707 .577 .707 r
F P
0 g
s
.48244 .63396 m .47712 .67191 L .45567 .67094 L p .707 .577 .707 r
F P
0 g
s
.45567 .67094 m .461 .63298 L .48244 .63396 L p .707 .577 .707 r
F P
0 g
s
.34215 .61684 m .33682 .6548 L .31353 .6497 L p .707 .577 .707 r
F P
0 g
s
.30604 .6818 m .30453 .6647 L .32063 .65108 L p .707 .577 .707 r
F P
0 g
s
.43317 .49651 m .43697 .54867 L .40583 .5476 L p .707 .577 .707 r
F P
0 g
s
.40583 .5476 m .40203 .49544 L .43317 .49651 L p .707 .577 .707 r
F P
0 g
s
.31353 .6497 m .31886 .61174 L .34215 .61684 L p .707 .577 .707 r
F P
0 g
s
.37408 .55079 m .37028 .49864 L .40203 .49544 L p .707 .577 .707 r
F P
0 g
s
.37028 .49864 m .37408 .55079 L .34483 .55794 L p .707 .577 .707 r
F P
0 g
s
.40203 .49544 m .40583 .5476 L .37408 .55079 L p .707 .577 .707 r
F P
0 g
s
.32063 .65108 m .32214 .66818 L .30604 .6818 L p .707 .577 .707 r
F P
0 g
s
.48516 .6439 m .48667 .661 L .46549 .65167 L p .707 .577 .707 r
F P
0 g
s
.46549 .65167 m .46398 .63458 L .48516 .6439 L p .707 .577 .707 r
F P
0 g
s
.461 .63298 m .45567 .67094 L .42808 .66843 L p .707 .577 .707 r
F P
0 g
s
.42808 .66843 m .43341 .63047 L .461 .63298 L p .707 .577 .707 r
F P
0 g
s
.33682 .6548 m .34215 .61684 L .37092 .62199 L p .707 .577 .707 r
F P
0 g
s
.32214 .66818 m .32063 .65108 L .34445 .63979 L p .707 .577 .707 r
F P
0 g
s
.37092 .62199 m .36559 .65994 L .33682 .6548 L p .707 .577 .707 r
F P
0 g
s
.46398 .63458 m .46549 .65167 L .43799 .64629 L p .707 .577 .707 r
F P
0 g
s
.43799 .64629 m .43648 .62919 L .46398 .63458 L p .707 .577 .707 r
F P
0 g
s
.34445 .63979 m .34596 .65689 L .32214 .66818 L p .707 .577 .707 r
F P
0 g
s
.43341 .63047 m .42808 .66843 L .39704 .66464 L p .707 .577 .707 r
F P
0 g
s
.39704 .66464 m .40237 .62669 L .43341 .63047 L p .707 .577 .707 r
F P
0 g
s
.40237 .62669 m .39704 .66464 L .36559 .65994 L p .707 .577 .707 r
F P
0 g
s
.36559 .65994 m .37092 .62199 L .40237 .62669 L p .707 .577 .707 r
F P
0 g
s
.34596 .65689 m .34445 .63979 L .37364 .63194 L p .707 .577 .707 r
F P
0 g
s
.43648 .62919 m .43799 .64629 L .40686 .64538 L p .707 .577 .707 r
F P
0 g
s
.40686 .64538 m .40535 .62828 L .43648 .62919 L p .707 .577 .707 r
F P
0 g
s
.37364 .63194 m .37515 .64903 L .34596 .65689 L p .707 .577 .707 r
F P
0 g
s
.37515 .64903 m .37364 .63194 L .40535 .62828 L p .707 .577 .707 r
F P
0 g
s
.40535 .62828 m .40686 .64538 L .37515 .64903 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00LWoo10000UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001^Ool40006FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool0
06Yoo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001P0015YF00<005YF
FUH00UYF200015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001POol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000GOol?000oOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Qoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF1@001EYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00Dgoo00@005YFFUH000AJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEP000003FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00@005YFFUH000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00`0000EJEP00FUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005Ool00000FUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00@005YF000000Eoo`04001JEUYF
0006FUH50004FUH00`00FUIJEP09FUH40002FUH20002FUH200000eYF001JEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
001COol01000FUIJEP0015YF0P001goo00@005YFFUH000IJEPD000AJEP03001JEUYF00QJEP80009J
EP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF0`00
1goo00@005YFFUH000IJEPD000AJEP03001JEUYF00AJEP@000AJEP03001JEUYF009JEP@00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH20003FUH30004Ool01000FUIJEP001UYF1000
1EYF00<005YFFUH010000UYF00<005YFFUH00eYF00<005YFFUH00UYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP00;Woo001DOol00`00FUH000020005FUH00`00FUH000040002FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH70006FUH00`00FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo001DOol01@00FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00@Goo5@000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000moo`@0009JEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool003ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000IOol40004FUH0
1@00FUIJEUYF0000;Goo000kOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF10002goo0`004goo0`0000=JEP00FUH00UYF
00<007ooOol0:goo000hOol30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH40002FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000=JEP04001JEUYFFUH2000>Ool5000BOol200000eYF00000003FUH00`00Oomoo`0[Ool0
03Eoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EUYF010000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00@005YF0000011oo`D0011oo`800003FUH005YF009JEP04001JEUYF000]Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP@000IJEP03001JEUYF00EJEP03001J
EUYF009JEPH000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP80019o
o`D000ioo`8000=JEP03001JEUYF009JEP<002eoo`00<Woo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP<001=oo`<000aoo`<000EJ
EP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPL000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH5000IOol400000eYF
001JEP05FUH00`00FUIJEP02FUH01000FUH00000;7oo000_Ool01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000UYF0P002EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEPT0
00Uoo`L000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP04FUH40003FUH40005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH@0002FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00000`00
1EYF00<005YFFUH00eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00005FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP`00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFOol5FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00004FUH005YF0004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP0200000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/
Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`800003FUH005YF
00=JEP03001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00800004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH010004Goo10000UYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF
009JEPl000IJEP04001JEUYFFUH20002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo000/Ool01000FUIJEP0015YF00<0
05YFFUH00eYF10006Goo100000=JEP00000015YF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH2000bOol002aoo`04001JEUYF0004FUH01000
FUIJEUYF0P003Woo0`0047oo00<005YFFUH015YF00<005YFFUH0100025YF00<005YFFUH01UYF00<0
05YFFUH01EYF10000eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001oogoo035oo`00;7oo00@005YF
FUH000AJEP04001JEP00000?Ool5000>Ool20006FUH30002FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUH00004
0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH7000dOol002aoo`04001JEUYF0004FUH2000AOol5
000<Ool200000eYF001JEP03FUH200000eYF000000050006FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00eYF1`000UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00001P00<Woo000]Ool00`00FUH00003FUH00`00Oomoo`0AOol5
000;Ool01@00FUIJEUYF00000UYF0P0015YF00@005YFFUH0009JEP@0009JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPT0009JEP03001JEUYF00AJEP<000EJEP03001JEP00008002moo`00;Goo00@005YF001J
EP800003FUH00000019oo`<000Qoo`@000AJEP<00003FUH005YF00=JEP04001JEUYF0005FUH80004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00=JEQ400003FUH005YF00EJEP03001JEUYF009JEP8002eoo`00;Goo00<005YF00000P00
15YF1@004Goo1`000UYF0P0015YF00D005YFFUIJEP0000AJEP04001JEUYF0005FUH00`00FUIJEP05
FUH?0003FUH00`00FUIJEP06000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP06FUH01000FUIJ
EUYF3`00;Goo000]Ool01@00FUH005YF00001EYF00@005YFFUIJEQ4000AJEP03001JEUYF009JEP80
00=JEP03001JEUYF009JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH70003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH30002FUH01000FUIJEUYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`001EYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP<000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001o
ogoo02aoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP00009JEP03001JEP0000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00
FUIJEP04FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000000^Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH00`00FUH00006FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000800003FUH005YF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00@000IJEPP0
00AJEP03001JEUYF00=JEP@002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000Woo1@001EYF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00@005YF000002ioo`00;Goo
0P000UYF10000UYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004Ool20006FUH00`00FUIJEP040008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH01000FUIJEP00;Woo000]Ool00`00FUIJEP02FUH00`00FUIJEP0@0003
FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00UJEP03001JEUYF009JEP04001JEUYFFUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool00`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0[Ool002eoo`05FUH00000FUH00006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH60006FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP0000AJ
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
Ool01@00FUIJEUYF00000eYF0P000eYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`000eYF00<007ooOol0:goo000]Ool2FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000030002FUH01P00FUIJEUYF001JEP800003FUH005YF00AJEP<00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020004FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001JEP000080
00AJEP03001JEP0000Eoo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00Oomoo`0[Ool002aoo`04001JEUYF0002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7
0003FUH20005FUH01@00Oomoogoo00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF0P000UYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00008000AJEP80009JEP03001JEUYF009JEP04001JEP00000=Ool8
0004FUH00`00FUIJEP03FUH00`00FUIJEP04000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0`000UYF0P0017oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF
009JEP03001JEUYF009JEP04001JEP00000EOol>0002Ool00`00Oomoo`0[Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH00`001Goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP06001JEP00FUH005YF0P001EYF00<005YFFUH00UYF00@005YFFUH002Aoo`8002eoo`00;7oo0UYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100025YF00<005YFFUH0
0UYF00@005YFFUH000AJEPD00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP030004
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0`001UYF00<005YFFUH00UYF00@005YFFUH000Moo`<001Yoo`8002eo
o`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1`00
00AJEP00FUIJEPH000EJEP04001JEUYFFUH80002FUH00`00FUIJEP04FUH60007FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF
001JEP00FUH00007FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000/Ool2FUH0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000[Ool01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo00Ioo`D001Moo`80009JEP03001oogoo02Yoo`00:goo00<005YF
000015YF00<005YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`07Ool3000GOol0
1@00FUH005YF0000;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00008goo00@005YF
FUIJEP8002eoo`00;7oo10000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF2`0015YF00<005YFFUH01@002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00
0UYF00<005YFFUH015YF00@005YF0000029oo`8000AJEP03001oogoo02aoo`00<7oo10000UYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001UYF0P008Woo0P0000=JEP00FUH0
0eYF00<007ooOol0;7oo000dOol20005FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH50004FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH000000UYF0P001UYF00<007ooOol07goo0P000eYF00D005YFFUIJEP0002moo`00<goo
0P001UYF00<005YFFUH0100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EP0000D001moo`<000EJEP04001JEP00000`Ool0035oo`800003FUH005YF00AJEPT000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEP00FUH005YF000015YF1@006Goo100000=JEP00FUH01EYF0P00<Woo000`Ool01@00
FUIJEUYF00000eYF0P002Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF000015YF00<005YF000010003goo1`00
1EYF00<005YFFUH015YF00<007ooOol0<Goo000_Ool00`00FUIJEP02FUH01000FUH000003goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF
009JEP03001JEP0000D000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2
000dOol002ioo`8000AJEP8001Qoo`l000=JEP03001JEUYF0080009JEP03001JEUYF00=JEP<0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000EJEP8000AJ
EP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH00000=Woo000^Ool20003FUH00`00Oomoo`0WOol600001Goo
001JEUYF00000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF0P001eYF0`0000=JEP00FUH00eYF00<005YF00001EYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>7oo000]Ool01P00FUIJEP00FUH0035oo`05
001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH20008FUH01000FUH0000015YF00<005YF00001eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000?7oo000]Ool00`00FUIJEP02000FOol3000IOol00`00FUIJEP020000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH2
0008FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01P0000=JEP00FUH01eYF00<0
05YFFUH00UYF1`00@7oo000]Ool01000FUIJEP005Woo1@0067oo00<005YF00000eYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF0P0025YF00<0
05YFFUH00eYF0`0000=JEP0000001UYF00<005YFFUH00UYF0P0000=JEP0000003P00Agoo000]Ool0
0`00FUH0000GOol5000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04
0002FUH00`00FUIJEP03FUH4001EOol002ioo`8001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000005FUH30005FUH01000FUH00000EGoo000^Ool00`00Oomoo`0GOol3
000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00P00
0eYF00D005YFFUIJEP0005Aoo`00;Woo0P00<Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`1B
Ool002ioo`03001JEP0002moo`03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001oogoo059oo`00;Woo00@005YF
FUH002aoo`<000AJEP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD000AJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00Oomoo`1BOol002ioo`04001JEUYFFUH2000XOol20002FUH01@00FUIJ
EUYF00000goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo4@00E7oo000^Ool01P00FUIJEUYF001JEP<0
025oo`@000EJEP03001JEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2000EOol2001DOol002moo`04001J
EUYF0004FUH3000JOol40002FUH00`00FUIJEP04FUH20009Ool40002FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000005goo0P00
E7oo000`Ool00`00FUH00005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000>Ool5
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH7000HOol0
1000FUH00000Dgoo000aOol20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P005Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1@000Woo1@00
67oo00@005YFFUH005=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000001eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPH0
00Ioo`D001Moo`80009JEP03001oogoo055oo`00=7oo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH015YF0`00:7oo6@0037oo1@005Woo00D005YF001JEP0005Aoo`00
=goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P006Goo0`005Woo
00@005YFFUIJEP8005Aoo`00>Woo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00
;goo0P0015YF00<007ooOol0Dgoo000nOol@0011Ool200000eYF001oo`0[Ool200000eYF001JEP03
FUH00`00Oomoo`1COol008moo`80009JEP03001oogoo02Moo`8000=JEP05001JEUYFFUH0001FOol0
091oo`03001JEUYF00<002Aoo`<000EJEP04001JEP00001GOol0091oo`04001JEUYF0002FUH2000P
Ool200000eYF001JEP05FUH2001IOol0095oo`04001JEUYF0003FUH5000HOol30003FUH00`00FUIJ
EP04FUH00`00Oomoo`1HOol0099oo`<000AJEP04001JEUYFFUH90009Ool60007FUH01000FUIJEUYF
0P00Fgoo002DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP06FUH01000FUH00000GGoo002EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3001OOol009Moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<0069oo`00VGoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P00IGoo002NOol80004FUH00`00FUIJEP02FUH6001XOol00:Ioo`T006ioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59543 .7114 m .56429 .71033 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59543 .7114 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.59451 .7745 m .62595 .7792 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59451 .7745 L p .60514 .75319 L .707 .577 .707 r
F P
0 g
s
.60733 .7488 m .59814 .74863 L .60514 .75319 L .707 .577 .707 r
F
.59451 .7745 m .59814 .74863 L p .57761 .74707 L F P
0 g
s
.56347 .77072 m .59451 .7745 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .56347 .77072 L p .57469 .75196 L .707 .577 .707 r
F P
0 g
s
.57761 .74707 m .5669 .74626 L .57469 .75196 L .707 .577 .707 r
F
.56429 .71033 m .5368 .70511 L p .55415 .73694 L F P
0 g
s
.55858 .74507 m .5669 .74626 L .55415 .73694 L .707 .577 .707 r
F
.5669 .74626 m .56429 .71033 L p .55415 .73694 L F P
0 g
s
.58292 .73873 m .58267 .73856 L .56808 .76249 L .707 .577 .707 r
F
.56553 .7274 m .5669 .74626 L p .58267 .73856 L F P
0 g
s
.5669 .74626 m .56808 .76249 L p .58267 .73856 L .707 .577 .707 r
F P
0 g
s
.56347 .77072 m .5669 .74626 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .56347 .77072 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .53588 .76821 L p .54592 .74875 L .707 .577 .707 r
F P
0 g
s
.54857 .74364 m .53951 .74234 L .54592 .74875 L .707 .577 .707 r
F
.5368 .70511 m .51566 .69624 L p .53103 .73386 L F P
0 g
s
.53394 .74098 m .53951 .74234 L .53103 .73386 L .707 .577 .707 r
F
.53951 .74234 m .5368 .70511 L p .53103 .73386 L F P
0 g
s
.5368 .70511 m .53951 .74234 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53588 .76821 m .53951 .74234 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .53588 .76821 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51443 .76723 L p .52201 .74331 L .707 .577 .707 r
F P
0 g
s
.52355 .73844 m .51864 .73724 L .52201 .74331 L .707 .577 .707 r
F
.51566 .69624 m .50293 .68458 L p .51475 .73023 L F P
0 g
s
.51628 .73613 m .51864 .73724 L .51475 .73023 L .707 .577 .707 r
F
.51864 .73724 m .51566 .69624 L p .51475 .73023 L F P
0 g
s
.51566 .69624 m .51864 .73724 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .51864 .73724 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51443 .76723 m .50695 .73175 L .50665 .73361 L .707 .577 .707 r
F
.50123 .76788 m .5115 .76738 L p .50665 .73361 L F P
0 g
s
.5115 .76738 m .51443 .76723 L p .50665 .73361 L .707 .577 .707 r
F P
0 g
s
.50293 .68458 m .49987 .67129 L p .50572 .7271 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50123 .76788 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.50123 .76788 m .50634 .73147 L p .5029 .73212 L .707 .577 .707 r
F P
0 g
s
.50612 .73094 m .50634 .73147 L .50572 .7271 L .707 .577 .707 r
F
.50634 .73147 m .50293 .68458 L p .50572 .7271 L F P
0 g
s
.50293 .68458 m .50634 .73147 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50586 .73034 m .5029 .73212 L p .50634 .73147 L .707 .577 .707 r
F P
0 g
s
.49987 .67129 m .50366 .72345 L .50372 .7237 L p .707 .577 .707 r
F P
0 g
s
.50372 .7237 m .50673 .73674 L p .5021 .69257 L .707 .577 .707 r
F P
0 g
s
.5021 .69257 m .49987 .67129 L .50372 .7237 L .707 .577 .707 r
F
.5029 .73212 m .49757 .77008 L .50123 .76788 L p F P
0 g
s
.49757 .77008 m .5029 .73212 L .5042 .73286 L p .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .50634 .73147 L p .50612 .73094 L .707 .577 .707 r
F P
0 g
s
.50673 .73674 m .51945 .74839 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.50634 .73147 m .50673 .73674 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.5042 .73286 m .50914 .73567 L p .50499 .74802 L .707 .577 .707 r
F P
0 g
s
.49757 .77008 m .5042 .73286 L .50499 .74802 L .707 .577 .707 r
F
.50634 .73147 m .50656 .72992 L .50586 .73034 L p F P
0 g
s
.50656 .72992 m .50634 .73147 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .50656 .72992 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51976 .72928 L p .50695 .73175 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .51864 .73724 L p .51628 .73613 L .707 .577 .707 r
F P
0 g
s
.51945 .74839 m .54059 .75727 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51864 .73724 m .51945 .74839 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.51976 .72928 m .51864 .73724 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .51976 .72928 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .5412 .73026 L p .52355 .73844 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .53951 .74234 L p .53394 .74098 L .707 .577 .707 r
F P
0 g
s
.54059 .75727 m .56808 .76249 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.53951 .74234 m .54059 .75727 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5412 .73026 m .53951 .74234 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5412 .73026 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.5669 .74626 m .5688 .73276 L p .54857 .74364 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .5669 .74626 L p .55858 .74507 L .707 .577 .707 r
F P
0 g
s
.5688 .73276 m .5669 .74626 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.56808 .76249 m .59922 .76356 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.58897 .74794 m .58292 .73873 L .57771 .74708 L .707 .577 .707 r
F
.58897 .74794 m .57771 .74708 L .56808 .76249 L F
.56429 .71033 m .56553 .7274 L p .58292 .73873 L F P
0 g
s
.59543 .7114 m .59814 .74863 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .59543 .7114 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62718 .70821 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .65473 .78435 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .62595 .7792 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.62718 .70821 m .63016 .74921 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .62718 .70821 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65643 .70106 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.65643 .70106 m .65984 .74794 L p .68411 .74282 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .67802 .78945 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .65473 .78435 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.67724 .74581 m .68411 .74282 L p .65984 .74794 L .707 .577 .707 r
F P
0 g
s
.67802 .78945 m .68335 .75149 L .66006 .74639 L p .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66022 .75322 L .67724 .74581 L p .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .65984 .74794 L p .66066 .74784 L .707 .577 .707 r
F P
0 g
s
.66006 .74639 m .63128 .74125 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65473 .78435 m .65984 .74794 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.65984 .74794 m .66006 .74639 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.66022 .75322 m .65984 .74794 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .66022 .75322 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63097 .76036 L p .65646 .74808 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .63016 .74921 L p .63549 .74898 L .707 .577 .707 r
F P
0 g
s
.63128 .74125 m .59983 .73655 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.62595 .7792 m .63016 .74921 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63016 .74921 m .63128 .74125 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.63097 .76036 m .63016 .74921 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .63097 .76036 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59922 .76356 L p .62278 .74908 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .59814 .74863 L p .60733 .7488 L .707 .577 .707 r
F P
0 g
s
.59983 .73655 m .5688 .73276 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59814 .74863 m .59983 .73655 L p .57761 .74707 L .707 .577 .707 r
F P
0 g
s
.59922 .76356 m .59814 .74863 L p .58897 .74794 L .707 .577 .707 r
F P
0 g
s
.68411 .74282 m .68031 .69066 L .65643 .70106 L p .707 .577 .707 r
F P
0 g
s
.68031 .69066 m .68411 .74282 L .70029 .73019 L p .707 .577 .707 r
F P
0 g
s
.70029 .73019 m .6965 .67803 L .68031 .69066 L p .707 .577 .707 r
F P
0 g
s
.60075 .86891 m .59924 .85181 L .56811 .8509 L p .707 .577 .707 r
F P
0 g
s
.59924 .85181 m .60075 .86891 L .63247 .86526 L p .707 .577 .707 r
F P
0 g
s
.63247 .86526 m .63096 .84816 L .59924 .85181 L p .707 .577 .707 r
F P
0 g
s
.63096 .84816 m .63247 .86526 L .66166 .8574 L p .707 .577 .707 r
F P
0 g
s
.66166 .8574 m .66015 .84031 L .63096 .84816 L p .707 .577 .707 r
F P
0 g
s
.68335 .75149 m .67802 .78945 L .69354 .79399 L p .707 .577 .707 r
F P
0 g
s
.6965 .67803 m .70029 .73019 L .70719 .71656 L p .707 .577 .707 r
F P
0 g
s
.70719 .71656 m .7034 .6644 L .6965 .67803 L p .707 .577 .707 r
F P
0 g
s
.69354 .79399 m .69887 .75603 L .68335 .75149 L p .707 .577 .707 r
F P
0 g
s
.56962 .868 m .56811 .8509 L .54061 .84552 L p .707 .577 .707 r
F P
0 g
s
.56811 .8509 m .56962 .868 L .60075 .86891 L p .707 .577 .707 r
F P
0 g
s
.66015 .84031 m .66166 .8574 L .68547 .84611 L p .707 .577 .707 r
F P
0 g
s
.68547 .84611 m .68396 .82902 L .66015 .84031 L p .707 .577 .707 r
F P
0 g
s
.54061 .84552 m .54212 .86262 L .56962 .868 L p .707 .577 .707 r
F P
0 g
s
.54212 .86262 m .54061 .84552 L .51944 .83619 L p .707 .577 .707 r
F P
0 g
s
.68396 .82902 m .68547 .84611 L .70158 .83249 L p .707 .577 .707 r
F P
0 g
s
.70158 .83249 m .70007 .8154 L .68396 .82902 L p .707 .577 .707 r
F P
0 g
s
.51944 .83619 m .52095 .85329 L .54212 .86262 L p .707 .577 .707 r
F P
0 g
s
.69887 .75603 m .69354 .79399 L .69978 .79754 L p .707 .577 .707 r
F P
0 g
s
.69978 .79754 m .70511 .75958 L .69887 .75603 L p .707 .577 .707 r
F P
0 g
s
.7034 .6644 m .70719 .71656 L .70413 .70327 L p .707 .577 .707 r
F P
0 g
s
.70413 .70327 m .70033 .65111 L .7034 .6644 L p .707 .577 .707 r
F P
0 g
s
.52095 .85329 m .51944 .83619 L .50665 .82383 L p .707 .577 .707 r
F P
0 g
s
.50366 .72345 m .49987 .67129 L .50677 .65767 L p .707 .577 .707 r
F P
0 g
s
.48697 .82053 m .49216 .31534 L .44815 .31248 L p .707 .577 .707 r
F P
0 g
s
.50816 .84093 m .50665 .82383 L .50352 .80965 L p .707 .577 .707 r
F P
0 g
s
.50914 .73567 m .50381 .77363 L .49757 .77008 L p .707 .577 .707 r
F P
0 g
s
.50677 .65767 m .51056 .70982 L .50366 .72345 L p .707 .577 .707 r
F P
0 g
s
.51056 .70982 m .50677 .65767 L .52295 .64504 L p .707 .577 .707 r
F P
0 g
s
.50352 .80965 m .50503 .82675 L .50816 .84093 L p .707 .577 .707 r
F P
0 g
s
.50503 .82675 m .50352 .80965 L .51034 .79503 L p .707 .577 .707 r
F P
0 g
s
.52295 .64504 m .52675 .69719 L .51056 .70982 L p .707 .577 .707 r
F P
0 g
s
.52466 .74021 m .51933 .77817 L .50381 .77363 L p .707 .577 .707 r
F P
0 g
s
.50381 .77363 m .50914 .73567 L .52466 .74021 L p .707 .577 .707 r
F P
0 g
s
.51034 .79503 m .51185 .81213 L .50503 .82675 L p .707 .577 .707 r
F P
0 g
s
.51185 .81213 m .51034 .79503 L .52644 .78141 L p .707 .577 .707 r
F P
0 g
s
.54795 .74531 m .54262 .78326 L .51933 .77817 L p .707 .577 .707 r
F P
0 g
s
.51933 .77817 m .52466 .74021 L .54795 .74531 L p .707 .577 .707 r
F P
0 g
s
.52644 .78141 m .52795 .79851 L .51185 .81213 L p .707 .577 .707 r
F P
0 g
s
.54262 .78326 m .54795 .74531 L .57673 .75046 L p .707 .577 .707 r
F P
0 g
s
.52795 .79851 m .52644 .78141 L .55025 .77012 L p .707 .577 .707 r
F P
0 g
s
.57673 .75046 m .5714 .78841 L .54262 .78326 L p .707 .577 .707 r
F P
0 g
s
.55025 .77012 m .55176 .78722 L .52795 .79851 L p .707 .577 .707 r
F P
0 g
s
.49216 .31534 m .48697 .82053 L .53191 .81996 L p .707 .577 .707 r
F P
0 g
s
.52675 .69719 m .52295 .64504 L .54684 .63464 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .55063 .6868 L .52675 .69719 L p .707 .577 .707 r
F P
0 g
s
.53191 .81996 m .5371 .31478 L .49216 .31534 L p .707 .577 .707 r
F P
0 g
s
.50665 .82383 m .50816 .84093 L .52095 .85329 L p .707 .577 .707 r
F P
0 g
s
.70007 .8154 m .70158 .83249 L .7084 .81787 L p .707 .577 .707 r
F P
0 g
s
.7084 .81787 m .70689 .80078 L .70007 .8154 L p .707 .577 .707 r
F P
0 g
s
.54684 .63464 m .57609 .62749 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55063 .6868 m .55052 .68524 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.55052 .68524 m .54684 .63464 L p .55089 .68618 L .707 .577 .707 r
F P
0 g
s
.57988 .67965 m .57609 .62749 L .60784 .6243 L p .707 .577 .707 r
F P
0 g
s
.57609 .62749 m .57988 .67965 L .55063 .6868 L p .707 .577 .707 r
F P
0 g
s
.60784 .6243 m .61163 .67645 L .57988 .67965 L p .707 .577 .707 r
F P
0 g
s
.63921 .75894 m .63388 .7969 L .60912 .79388 L p .707 .577 .707 r
F P
0 g
s
.60912 .79388 m .60285 .79311 L p .60974 .78663 L .707 .577 .707 r
F P
0 g
s
.60974 .78663 m .63921 .75894 L .60912 .79388 L .707 .577 .707 r
F
.63898 .62536 m .64277 .67752 L .61163 .67645 L p F P
0 g
s
.61163 .67645 m .60784 .6243 L .63898 .62536 L p .707 .577 .707 r
F P
0 g
s
.63388 .7969 m .63921 .75894 L .6668 .76145 L p .707 .577 .707 r
F P
0 g
s
.60285 .79311 m .60817 .75516 L .63921 .75894 L p .707 .577 .707 r
F P
0 g
s
.64229 .75952 m .6438 .77662 L .61267 .77571 L p .707 .577 .707 r
F P
0 g
s
.61267 .77571 m .61116 .75861 L .64229 .75952 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .64043 .78919 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.63563 .29465 m .6334 .51211 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.6334 .51211 m .63044 .79984 L p .6373 .46678 L .707 .577 .707 r
F P
0 g
s
.60817 .75516 m .60285 .79311 L .5738 .78877 L p .707 .577 .707 r
F P
0 g
s
.5738 .78877 m .5714 .78841 L p .57445 .78566 L .707 .577 .707 r
F P
0 g
s
.57445 .78566 m .60817 .75516 L .5738 .78877 L .707 .577 .707 r
F
.5714 .78841 m .57673 .75046 L .60817 .75516 L p F P
0 g
s
.58096 .77936 m .57945 .76226 L .61116 .75861 L p .707 .577 .707 r
F P
0 g
s
.61116 .75861 m .61267 .77571 L .58096 .77936 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .63044 .79984 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.61253 .3039 m .60929 .61908 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.60929 .61908 m .60734 .80909 L p .62176 .55947 L .707 .577 .707 r
F P
0 g
s
.57857 .31083 m .57412 .74459 L p .60734 .80909 L .707 .577 .707 r
F P
0 g
s
.55176 .78722 m .55025 .77012 L .57945 .76226 L p .707 .577 .707 r
F P
0 g
s
.57945 .76226 m .58096 .77936 L .55986 .78504 L p .707 .577 .707 r
F P
0 g
s
.55986 .78504 m .55176 .78722 L p .55814 .78147 L .707 .577 .707 r
F P
0 g
s
.55814 .78147 m .57945 .76226 L .55986 .78504 L .707 .577 .707 r
F
.57412 .74459 m .57341 .81317 L p .60033 .81052 L F P
0 g
s
.57341 .81317 m .57339 .81602 L .57466 .81576 L p .707 .577 .707 r
F P
0 g
s
.57466 .81576 m .60033 .81052 L p .57341 .81317 L .707 .577 .707 r
F P
0 g
s
.60033 .81052 m .60734 .80909 L p .57412 .74459 L .707 .577 .707 r
F P
0 g
s
.5371 .31478 m .53191 .81996 L .57339 .81602 L p .707 .577 .707 r
F P
0 g
s
.57339 .81602 m .57857 .31083 L .5371 .31478 L p .707 .577 .707 r
F P
0 g
s
.44296 .81766 m .44815 .31248 L .40938 .30646 L p .707 .577 .707 r
F P
0 g
s
.44815 .31248 m .44296 .81766 L .48697 .82053 L p .707 .577 .707 r
F P
0 g
s
.70511 .75958 m .69978 .79754 L .69612 .79974 L p .707 .577 .707 r
F P
0 g
s
.70033 .65111 m .70413 .70327 L .6914 .69162 L p .707 .577 .707 r
F P
0 g
s
.6914 .69162 m .68761 .63946 L .70033 .65111 L p .707 .577 .707 r
F P
0 g
s
.69612 .79974 m .70145 .76178 L .70511 .75958 L p .707 .577 .707 r
F P
0 g
s
.60734 .80909 m .61253 .3039 L .57857 .31083 L p .707 .577 .707 r
F P
0 g
s
.70689 .80078 m .7084 .81787 L .70526 .80369 L p .707 .577 .707 r
F P
0 g
s
.70526 .80369 m .70375 .7866 L .70689 .80078 L p .707 .577 .707 r
F P
0 g
s
.25242 .67459 m .22128 .67352 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25242 .67459 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.2515 .73769 m .28294 .74239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .2515 .73769 L p .26213 .71637 L .707 .577 .707 r
F P
0 g
s
.26433 .71198 m .25513 .71182 L .26213 .71637 L .707 .577 .707 r
F
.2515 .73769 m .25513 .71182 L p .2346 .71026 L F P
0 g
s
.22046 .7339 m .2515 .73769 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22046 .7339 L p .23168 .71514 L .707 .577 .707 r
F P
0 g
s
.2346 .71026 m .22389 .70945 L .23168 .71514 L .707 .577 .707 r
F
.22128 .67352 m .19379 .66829 L p .21114 .70012 L F P
0 g
s
.21558 .70826 m .22389 .70945 L .21114 .70012 L .707 .577 .707 r
F
.22389 .70945 m .22128 .67352 L p .21114 .70012 L F P
0 g
s
.23991 .70191 m .23966 .70175 L .22507 .72568 L .707 .577 .707 r
F
.22252 .69059 m .22389 .70945 L p .23966 .70175 L F P
0 g
s
.22389 .70945 m .22507 .72568 L p .23966 .70175 L .707 .577 .707 r
F P
0 g
s
.22046 .7339 m .22389 .70945 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .22046 .7339 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19287 .7314 L p .20291 .71194 L .707 .577 .707 r
F P
0 g
s
.20556 .70682 m .1965 .70552 L .20291 .71194 L .707 .577 .707 r
F
.19379 .66829 m .17265 .65942 L p .18802 .69704 L F P
0 g
s
.19093 .70416 m .1965 .70552 L .18802 .69704 L .707 .577 .707 r
F
.1965 .70552 m .19379 .66829 L p .18802 .69704 L F P
0 g
s
.19379 .66829 m .1965 .70552 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.19287 .7314 m .1965 .70552 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .19287 .7314 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17142 .73042 L p .179 .70649 L .707 .577 .707 r
F P
0 g
s
.18054 .70162 m .17563 .70042 L .179 .70649 L .707 .577 .707 r
F
.17265 .65942 m .15992 .64777 L p .17174 .69341 L F P
0 g
s
.17327 .69931 m .17563 .70042 L .17174 .69341 L .707 .577 .707 r
F
.17563 .70042 m .17265 .65942 L p .17174 .69341 L F P
0 g
s
.17265 .65942 m .17563 .70042 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .17563 .70042 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17142 .73042 m .16394 .69493 L .16364 .6968 L .707 .577 .707 r
F
.15822 .73106 m .16849 .73056 L p .16364 .6968 L F P
0 g
s
.16849 .73056 m .17142 .73042 L p .16364 .6968 L .707 .577 .707 r
F P
0 g
s
.15992 .64777 m .15686 .63448 L p .16271 .69028 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .15822 .73106 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.15822 .73106 m .16334 .69465 L p .15989 .69531 L .707 .577 .707 r
F P
0 g
s
.16311 .69413 m .16334 .69465 L .16271 .69028 L .707 .577 .707 r
F
.16334 .69465 m .15992 .64777 L p .16271 .69028 L F P
0 g
s
.15992 .64777 m .16334 .69465 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16285 .69353 m .15989 .69531 L p .16334 .69465 L .707 .577 .707 r
F P
0 g
s
.15686 .63448 m .16066 .68664 L .16071 .68688 L p .707 .577 .707 r
F P
0 g
s
.16071 .68688 m .16372 .69993 L p .15909 .65576 L .707 .577 .707 r
F P
0 g
s
.15909 .65576 m .15686 .63448 L .16071 .68688 L .707 .577 .707 r
F
.15989 .69531 m .15456 .73326 L .15822 .73106 L p F P
0 g
s
.15456 .73326 m .15989 .69531 L .16119 .69605 L p .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .16334 .69465 L p .16311 .69413 L .707 .577 .707 r
F P
0 g
s
.16372 .69993 m .17644 .71158 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16334 .69465 m .16372 .69993 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.16119 .69605 m .16613 .69885 L p .16198 .7112 L .707 .577 .707 r
F P
0 g
s
.15456 .73326 m .16119 .69605 L .16198 .7112 L .707 .577 .707 r
F
.16334 .69465 m .16355 .6931 L .16285 .69353 L p F P
0 g
s
.16355 .6931 m .16334 .69465 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .16355 .6931 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17675 .69246 L p .16394 .69493 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .17563 .70042 L p .17327 .69931 L .707 .577 .707 r
F P
0 g
s
.17644 .71158 m .19759 .72045 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17563 .70042 m .17644 .71158 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.17675 .69246 m .17563 .70042 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .17675 .69246 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .1982 .69344 L p .18054 .70162 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .1965 .70552 L p .19093 .70416 L .707 .577 .707 r
F P
0 g
s
.19759 .72045 m .22507 .72568 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1965 .70552 m .19759 .72045 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.1982 .69344 m .1965 .70552 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .1982 .69344 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22389 .70945 m .22579 .69595 L p .20556 .70682 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .22389 .70945 L p .21558 .70826 L .707 .577 .707 r
F P
0 g
s
.22579 .69595 m .22389 .70945 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.22507 .72568 m .25622 .72674 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.24596 .71112 m .23991 .70191 L .2347 .71027 L .707 .577 .707 r
F
.24596 .71112 m .2347 .71027 L .22507 .72568 L F
.22128 .67352 m .22252 .69059 L p .23991 .70191 L F P
0 g
s
.25242 .67459 m .25513 .71182 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .25242 .67459 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28417 .67139 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .31172 .74754 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28294 .74239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28417 .67139 m .28715 .71239 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .28417 .67139 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31342 .66424 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.31342 .66424 m .31683 .71113 L p .3411 .706 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .33501 .75263 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31172 .74754 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.33423 .709 m .3411 .706 L p .31683 .71113 L .707 .577 .707 r
F P
0 g
s
.33501 .75263 m .34034 .71468 L .31705 .70958 L p .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31722 .7164 L .33423 .709 L p .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .31683 .71113 L p .31765 .71102 L .707 .577 .707 r
F P
0 g
s
.31705 .70958 m .28827 .70443 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31172 .74754 m .31683 .71113 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31683 .71113 m .31705 .70958 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.31722 .7164 m .31683 .71113 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .31722 .7164 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28797 .72355 L p .31345 .71127 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .28715 .71239 L p .29248 .71217 L .707 .577 .707 r
F P
0 g
s
.28827 .70443 m .25683 .69973 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28294 .74239 m .28715 .71239 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28715 .71239 m .28827 .70443 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.28797 .72355 m .28715 .71239 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .28797 .72355 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25622 .72674 L p .27977 .71226 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .25513 .71182 L p .26433 .71198 L .707 .577 .707 r
F P
0 g
s
.25683 .69973 m .22579 .69595 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25513 .71182 m .25683 .69973 L p .2346 .71026 L .707 .577 .707 r
F P
0 g
s
.25622 .72674 m .25513 .71182 L p .24596 .71112 L .707 .577 .707 r
F P
0 g
s
.4042 .81165 m .40938 .30646 L .37966 .29788 L p .707 .577 .707 r
F P
0 g
s
.40938 .30646 m .4042 .81165 L .44296 .81766 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68761 .63946 m .6914 .69162 L .67026 .68275 L p .707 .577 .707 r
F P
0 g
s
.67026 .68275 m .66647 .63059 L .68761 .63946 L p .707 .577 .707 r
F P
0 g
s
.70145 .76178 m .69612 .79974 L .68292 .80038 L p .707 .577 .707 r
F P
0 g
s
.3411 .706 m .33731 .65385 L .31342 .66424 L p .707 .577 .707 r
F P
0 g
s
.68292 .80038 m .68825 .76243 L .70145 .76178 L p .707 .577 .707 r
F P
0 g
s
.63044 .79984 m .63563 .29465 L .61253 .3039 L p .707 .577 .707 r
F P
0 g
s
.70375 .7866 m .70526 .80369 L .69248 .79133 L p .707 .577 .707 r
F P
0 g
s
.69248 .79133 m .69097 .77423 L .70375 .7866 L p .707 .577 .707 r
F P
0 g
s
.66647 .63059 m .67026 .68275 L .64277 .67752 L p .707 .577 .707 r
F P
0 g
s
.64277 .67752 m .63898 .62536 L .66647 .63059 L p .707 .577 .707 r
F P
0 g
s
.33731 .65385 m .3411 .706 L .35728 .69337 L p .707 .577 .707 r
F P
0 g
s
.35728 .69337 m .35349 .64122 L .33731 .65385 L p .707 .577 .707 r
F P
0 g
s
.37447 .80307 m .37966 .29788 L .36187 .28757 L p .707 .577 .707 r
F P
0 g
s
.37966 .29788 m .37447 .80307 L .4042 .81165 L p .707 .577 .707 r
F P
0 g
s
.68825 .76243 m .68292 .80038 L .66148 .7994 L p .707 .577 .707 r
F P
0 g
s
.66148 .7994 m .6668 .76145 L .68825 .76243 L p .707 .577 .707 r
F P
0 g
s
.25775 .8321 m .25623 .815 L .2251 .81409 L p .707 .577 .707 r
F P
0 g
s
.25623 .815 m .25775 .8321 L .28946 .82844 L p .707 .577 .707 r
F P
0 g
s
.28946 .82844 m .28795 .81135 L .25623 .815 L p .707 .577 .707 r
F P
0 g
s
.28795 .81135 m .28946 .82844 L .31865 .82059 L p .707 .577 .707 r
F P
0 g
s
.31865 .82059 m .31714 .80349 L .28795 .81135 L p .707 .577 .707 r
F P
0 g
s
.34034 .71468 m .33501 .75263 L .35053 .75717 L p .707 .577 .707 r
F P
0 g
s
.69097 .77423 m .69248 .79133 L .6713 .782 L p .707 .577 .707 r
F P
0 g
s
.6713 .782 m .66979 .76491 L .69097 .77423 L p .707 .577 .707 r
F P
0 g
s
.35349 .64122 m .35728 .69337 L .36418 .67975 L p .707 .577 .707 r
F P
0 g
s
.36418 .67975 m .36039 .62759 L .35349 .64122 L p .707 .577 .707 r
F P
0 g
s
.35053 .75717 m .35586 .71922 L .34034 .71468 L p .707 .577 .707 r
F P
0 g
s
.22661 .83119 m .2251 .81409 L .1976 .80871 L p .707 .577 .707 r
F P
0 g
s
.2251 .81409 m .22661 .83119 L .25775 .8321 L p .707 .577 .707 r
F P
0 g
s
.64043 .78919 m .64562 .284 L .63563 .29465 L p .707 .577 .707 r
F P
0 g
s
.31714 .80349 m .31865 .82059 L .34246 .8093 L p .707 .577 .707 r
F P
0 g
s
.34246 .8093 m .34095 .7922 L .31714 .80349 L p .707 .577 .707 r
F P
0 g
s
.6668 .76145 m .66148 .7994 L .63388 .7969 L p .707 .577 .707 r
F P
0 g
s
.1976 .80871 m .19911 .8258 L .22661 .83119 L p .707 .577 .707 r
F P
0 g
s
.19911 .8258 m .1976 .80871 L .17643 .79938 L p .707 .577 .707 r
F P
0 g
s
.35857 .79568 m .35706 .77858 L .34095 .7922 L p .707 .577 .707 r
F P
0 g
s
.35586 .71922 m .35053 .75717 L .35677 .76072 L p .707 .577 .707 r
F P
0 g
s
.35677 .76072 m .3621 .72277 L .35586 .71922 L p .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36039 .62759 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36112 .66646 m .36101 .6649 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .35732 .6143 L p .3611 .66523 L .707 .577 .707 r
F P
0 g
s
.35732 .6143 m .36101 .6649 L p .34839 .6548 L .707 .577 .707 r
F P
0 g
s
.36101 .6649 m .36112 .66646 L .36092 .66627 L p .707 .577 .707 r
F P
0 g
s
.36092 .66627 m .34839 .6548 L p .36101 .6649 L .707 .577 .707 r
F P
0 g
s
.3621 .72277 m .35677 .76072 L .35311 .76292 L p .707 .577 .707 r
F P
0 g
s
.34839 .6548 m .3446 .60265 L .35732 .6143 L p .707 .577 .707 r
F P
0 g
s
.35311 .76292 m .35844 .72497 L .3621 .72277 L p .707 .577 .707 r
F P
0 g
s
.35844 .72497 m .35311 .76292 L .33991 .76357 L p .707 .577 .707 r
F P
0 g
s
.33991 .76357 m .34524 .72561 L .35844 .72497 L p .707 .577 .707 r
F P
0 g
s
.36074 .74978 m .36225 .76688 L .35871 .76345 L p .707 .577 .707 r
F P
0 g
s
.35871 .76345 m .34947 .75451 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.3597 .75022 m .36074 .74978 L .35871 .76345 L .707 .577 .707 r
F
.34947 .75451 m .34796 .73742 L .3598 .74887 L p F P
0 g
s
.3598 .74887 m .36074 .74978 L p .3597 .75022 L .707 .577 .707 r
F P
0 g
s
.34947 .75451 m .3598 .74887 L .3597 .75022 L .707 .577 .707 r
F
.35669 .79023 m .35811 .65416 L .35699 .65 L F
.35668 .79276 m .35671 .78991 L p .35669 .79023 L F P
0 g
s
.35671 .78991 m .35811 .65416 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35343 .78402 m .35653 .79235 L p .35682 .73081 L .707 .577 .707 r
F P
0 g
s
.35653 .79235 m .35668 .79276 L p .35669 .79023 L .707 .577 .707 r
F P
0 g
s
.35669 .79023 m .35682 .73081 L .35653 .79235 L .707 .577 .707 r
F
.35778 .27656 m .35259 .78175 L .35343 .78402 L p F P
0 g
s
.35682 .73081 m .35778 .27656 L .35343 .78402 L .707 .577 .707 r
F
.36187 .28757 m .35778 .27656 L p .35699 .65 L F P
0 g
s
.35811 .65416 m .36187 .28757 L p .35699 .65 L .707 .577 .707 r
F P
0 g
s
.36039 .62759 m .36418 .67975 L .36112 .66646 L p .707 .577 .707 r
F P
0 g
s
.35706 .77858 m .35857 .79568 L .36539 .78106 L p .707 .577 .707 r
F P
0 g
s
.36539 .78106 m .36388 .76396 L .35706 .77858 L p .707 .577 .707 r
F P
0 g
s
.36388 .76396 m .36539 .78106 L .36225 .76688 L p .707 .577 .707 r
F P
0 g
s
.36225 .76688 m .36074 .74978 L .36388 .76396 L p .707 .577 .707 r
F P
0 g
s
.36187 .28757 m .35668 .79276 L .37447 .80307 L p .707 .577 .707 r
F P
0 g
s
.66979 .76491 m .6713 .782 L .6438 .77662 L p .707 .577 .707 r
F P
0 g
s
.6438 .77662 m .64229 .75952 L .66979 .76491 L p .707 .577 .707 r
F P
0 g
s
.34095 .7922 m .34246 .8093 L .35857 .79568 L p .707 .577 .707 r
F P
0 g
s
.17643 .79938 m .17794 .81647 L .19911 .8258 L p .707 .577 .707 r
F P
0 g
s
.17794 .81647 m .17643 .79938 L .16364 .78702 L p .707 .577 .707 r
F P
0 g
s
.64562 .284 m .64043 .78919 L .63634 .77817 L p .707 .577 .707 r
F P
0 g
s
.63634 .77817 m .64153 .27298 L .64562 .284 L p .707 .577 .707 r
F P
0 g
s
.16066 .68664 m .15686 .63448 L .16376 .62085 L p .707 .577 .707 r
F P
0 g
s
.16364 .78702 m .16515 .80411 L .17794 .81647 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35259 .78175 m .35778 .27656 L .36777 .2659 L p .707 .577 .707 r
F P
0 g
s
.16515 .80411 m .16364 .78702 L .16051 .77283 L p .707 .577 .707 r
F P
0 g
s
.16613 .69885 m .1608 .73681 L .15456 .73326 L p .707 .577 .707 r
F P
0 g
s
.16376 .62085 m .16755 .67301 L .16066 .68664 L p .707 .577 .707 r
F P
0 g
s
.16755 .67301 m .16376 .62085 L .17994 .60822 L p .707 .577 .707 r
F P
0 g
s
.16051 .77283 m .16202 .78993 L .16515 .80411 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.3446 .60265 m .34839 .6548 L .32725 .64593 L p .707 .577 .707 r
F P
0 g
s
.32725 .64593 m .32346 .59377 L .3446 .60265 L p .707 .577 .707 r
F P
0 g
s
.64153 .27298 m .63634 .77817 L .61856 .76787 L p .707 .577 .707 r
F P
0 g
s
.61856 .76787 m .62375 .26268 L .64153 .27298 L p .707 .577 .707 r
F P
0 g
s
.16202 .78993 m .16051 .77283 L .16733 .75822 L p .707 .577 .707 r
F P
0 g
s
.17994 .60822 m .18374 .66038 L .16755 .67301 L p .707 .577 .707 r
F P
0 g
s
.18374 .66038 m .17994 .60822 L .20383 .59782 L p .707 .577 .707 r
F P
0 g
s
.18165 .7034 m .17632 .74135 L .1608 .73681 L p .707 .577 .707 r
F P
0 g
s
.1608 .73681 m .16613 .69885 L .18165 .7034 L p .707 .577 .707 r
F P
0 g
s
.16733 .75822 m .16884 .77531 L .16202 .78993 L p .707 .577 .707 r
F P
0 g
s
.36258 .77109 m .36777 .2659 L .39088 .25666 L p .707 .577 .707 r
F P
0 g
s
.36777 .2659 m .36258 .77109 L .35259 .78175 L p .707 .577 .707 r
F P
0 g
s
.32346 .59377 m .32725 .64593 L .29977 .64071 L p .707 .577 .707 r
F P
0 g
s
.29977 .64071 m .29597 .58855 L .32346 .59377 L p .707 .577 .707 r
F P
0 g
s
.20762 .64998 m .20383 .59782 L .23308 .59068 L p .707 .577 .707 r
F P
0 g
s
.20383 .59782 m .20762 .64998 L .18374 .66038 L p .707 .577 .707 r
F P
0 g
s
.34524 .72561 m .33991 .76357 L .31847 .76259 L p .707 .577 .707 r
F P
0 g
s
.31847 .76259 m .3238 .72463 L .34524 .72561 L p .707 .577 .707 r
F P
0 g
s
.16884 .77531 m .16733 .75822 L .18343 .7446 L p .707 .577 .707 r
F P
0 g
s
.29597 .58855 m .29977 .64071 L .26862 .63964 L p .707 .577 .707 r
F P
0 g
s
.26862 .63964 m .26483 .58748 L .29597 .58855 L p .707 .577 .707 r
F P
0 g
s
.20494 .70849 m .19961 .74645 L .17632 .74135 L p .707 .577 .707 r
F P
0 g
s
.17632 .74135 m .18165 .7034 L .20494 .70849 L p .707 .577 .707 r
F P
0 g
s
.23687 .64284 m .23308 .59068 L .26483 .58748 L p .707 .577 .707 r
F P
0 g
s
.23308 .59068 m .23687 .64284 L .20762 .64998 L p .707 .577 .707 r
F P
0 g
s
.62375 .26268 m .61856 .76787 L .58883 .75929 L p .707 .577 .707 r
F P
0 g
s
.58883 .75929 m .59402 .2541 L .62375 .26268 L p .707 .577 .707 r
F P
0 g
s
.26483 .58748 m .26862 .63964 L .23687 .64284 L p .707 .577 .707 r
F P
0 g
s
.18343 .7446 m .18494 .76169 L .16884 .77531 L p .707 .577 .707 r
F P
0 g
s
.34796 .73742 m .34947 .75451 L .32829 .74519 L p .707 .577 .707 r
F P
0 g
s
.32829 .74519 m .32678 .72809 L .34796 .73742 L p .707 .577 .707 r
F P
0 g
s
.3238 .72463 m .31847 .76259 L .29088 .76008 L p .707 .577 .707 r
F P
0 g
s
.73263 .61936 m .70149 .61829 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73263 .61936 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.73171 .68285 m .76316 .68755 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73171 .68285 L p .74231 .66137 L .707 .577 .707 r
F P
0 g
s
.74446 .65701 m .73536 .65685 L .74231 .66137 L .707 .577 .707 r
F
.73171 .68285 m .73536 .65685 L p .71473 .65528 L F P
0 g
s
.70067 .67906 m .73171 .68285 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .70067 .67906 L p .71186 .66014 L .707 .577 .707 r
F P
0 g
s
.71473 .65528 m .70412 .65448 L .71186 .66014 L .707 .577 .707 r
F
.70149 .61829 m .674 .61307 L p .69157 .6453 L F P
0 g
s
.69594 .6533 m .70412 .65448 L .69157 .6453 L .707 .577 .707 r
F
.70412 .65448 m .70149 .61829 L p .69157 .6453 L F P
0 g
s
.72041 .64711 m .7199 .64678 L .70529 .67045 L .707 .577 .707 r
F
.70275 .63562 m .70412 .65448 L p .7199 .64678 L F P
0 g
s
.70412 .65448 m .70529 .67045 L p .7199 .64678 L .707 .577 .707 r
F P
0 g
s
.70067 .67906 m .70412 .65448 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .70067 .67906 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67308 .67656 L p .6831 .65692 L .707 .577 .707 r
F P
0 g
s
.68569 .65184 m .67673 .65055 L .6831 .65692 L .707 .577 .707 r
F
.674 .61307 m .65286 .6042 L p .6684 .64221 L F P
0 g
s
.67126 .64921 m .67673 .65055 L .6684 .64221 L .707 .577 .707 r
F
.67673 .65055 m .674 .61307 L p .6684 .64221 L F P
0 g
s
.674 .61307 m .67673 .65055 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67308 .67656 m .67673 .65055 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .67308 .67656 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65164 .67558 L p .65919 .65144 L .707 .577 .707 r
F P
0 g
s
.66069 .64663 m .65586 .64545 L .65919 .65144 L .707 .577 .707 r
F
.65286 .6042 m .64014 .59254 L p .65206 .6386 L F P
0 g
s
.65586 .64545 m .65286 .6042 L p .65206 .6386 L .707 .577 .707 r
F P
0 g
s
.65286 .6042 m .65586 .64545 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .65586 .64545 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65164 .67558 m .64412 .63994 L .64385 .64165 L .707 .577 .707 r
F
.63844 .67622 m .64874 .67572 L p .64385 .64165 L F P
0 g
s
.64874 .67572 m .65164 .67558 L p .64385 .64165 L .707 .577 .707 r
F P
0 g
s
.64014 .59254 m .63707 .57925 L p .64297 .63552 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .63844 .67622 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.63844 .67622 m .64357 .63968 L p .64011 .64047 L .707 .577 .707 r
F P
0 g
s
.64335 .63918 m .64357 .63968 L .64297 .63552 L .707 .577 .707 r
F
.64357 .63968 m .64014 .59254 L p .64297 .63552 L F P
0 g
s
.64014 .59254 m .64357 .63968 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64313 .63865 m .64011 .64047 L p .64357 .63968 L .707 .577 .707 r
F P
0 g
s
.63707 .57925 m .64087 .63141 L .64093 .63169 L p .707 .577 .707 r
F P
0 g
s
.64093 .63169 m .64393 .6447 L p .63931 .60063 L .707 .577 .707 r
F P
0 g
s
.63931 .60063 m .63707 .57925 L .64093 .63169 L .707 .577 .707 r
F
.64011 .64047 m .63478 .67843 L .63844 .67622 L p F P
0 g
s
.63478 .67843 m .64011 .64047 L .64143 .64122 L p .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .64357 .63968 L p .64335 .63918 L .707 .577 .707 r
F P
0 g
s
.64393 .6447 m .65666 .65635 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64357 .63968 m .64393 .6447 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.64143 .64122 m .64634 .64402 L p .64222 .6563 L .707 .577 .707 r
F P
0 g
s
.63478 .67843 m .64143 .64122 L .64222 .6563 L .707 .577 .707 r
F
.64357 .63968 m .64377 .63827 L .64313 .63865 L p F P
0 g
s
.64377 .63827 m .64357 .63968 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .64377 .63827 L p .64412 .63994 L .707 .577 .707 r
F P
0 g
s
.65355 .64437 m .65586 .64545 L .65206 .6386 L .707 .577 .707 r
F
.65586 .64545 m .65696 .63762 L p .64412 .63994 L F P
0 g
s
.65666 .65635 m .65586 .64545 L p .65355 .64437 L .707 .577 .707 r
F P
0 g
s
.65666 .65635 m .6778 .66523 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65586 .64545 m .65666 .65635 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.65696 .63762 m .65586 .64545 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .65696 .63762 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .67841 .6386 L p .66069 .64663 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .67673 .65055 L p .67126 .64921 L .707 .577 .707 r
F P
0 g
s
.6778 .66523 m .70529 .67045 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67673 .65055 m .6778 .66523 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.67841 .6386 m .67673 .65055 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .67841 .6386 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70412 .65448 m .706 .64111 L p .68569 .65184 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .70412 .65448 L p .69594 .6533 L .707 .577 .707 r
F P
0 g
s
.706 .64111 m .70412 .65448 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.70529 .67045 m .73643 .67152 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.72635 .65616 m .72041 .64711 L .71509 .65531 L .707 .577 .707 r
F
.72635 .65616 m .71509 .65531 L .70529 .67045 L F
.70149 .61829 m .70275 .63562 L p .72041 .64711 L F P
0 g
s
.73263 .61936 m .73536 .65685 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .73263 .61936 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76438 .61617 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .79193 .6927 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76316 .68755 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76438 .61617 m .76739 .65742 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .76438 .61617 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79363 .60902 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.79363 .60902 m .79706 .65616 L p .82131 .65078 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .81522 .69779 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79193 .6927 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.81362 .65413 m .82131 .65078 L p .79706 .65616 L .707 .577 .707 r
F P
0 g
s
.81522 .69779 m .82055 .65984 L .79726 .65474 L p .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79743 .66118 L .81362 .65413 L p .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .79706 .65616 L p .79781 .65606 L .707 .577 .707 r
F P
0 g
s
.79726 .65474 m .76849 .64959 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79193 .6927 m .79706 .65616 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79706 .65616 m .79726 .65474 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.79743 .66118 m .79706 .65616 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .79743 .66118 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76818 .66832 L p .79384 .65629 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .76739 .65742 L p .77262 .6572 L .707 .577 .707 r
F P
0 g
s
.76849 .64959 m .73704 .6449 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76316 .68755 m .76739 .65742 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76739 .65742 m .76849 .64959 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.76818 .66832 m .76739 .65742 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .76818 .66832 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73643 .67152 L p .76017 .65729 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .73536 .65685 L p .74446 .65701 L .707 .577 .707 r
F P
0 g
s
.73704 .6449 m .706 .64111 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73536 .65685 m .73704 .6449 L p .71473 .65528 L .707 .577 .707 r
F P
0 g
s
.73643 .67152 m .73536 .65685 L p .72635 .65616 L .707 .577 .707 r
F P
0 g
s
.39088 .25666 m .38569 .76185 L .36258 .77109 L p .707 .577 .707 r
F P
0 g
s
.38569 .76185 m .39088 .25666 L .42483 .24972 L p .707 .577 .707 r
F P
0 g
s
.29088 .76008 m .2962 .72213 L .3238 .72463 L p .707 .577 .707 r
F P
0 g
s
.19961 .74645 m .20494 .70849 L .23372 .71364 L p .707 .577 .707 r
F P
0 g
s
.18494 .76169 m .18343 .7446 L .20724 .73331 L p .707 .577 .707 r
F P
0 g
s
.23372 .71364 m .22839 .7516 L .19961 .74645 L p .707 .577 .707 r
F P
0 g
s
.32678 .72809 m .32829 .74519 L .30079 .7398 L p .707 .577 .707 r
F P
0 g
s
.30079 .7398 m .29928 .72271 L .32678 .72809 L p .707 .577 .707 r
F P
0 g
s
.20724 .73331 m .20875 .7504 L .18494 .76169 L p .707 .577 .707 r
F P
0 g
s
.82131 .65078 m .81752 .59862 L .79363 .60902 L p .707 .577 .707 r
F P
0 g
s
.2962 .72213 m .29088 .76008 L .25984 .7563 L p .707 .577 .707 r
F P
0 g
s
.25984 .7563 m .26517 .71834 L .2962 .72213 L p .707 .577 .707 r
F P
0 g
s
.26517 .71834 m .25984 .7563 L .22839 .7516 L p .707 .577 .707 r
F P
0 g
s
.22839 .7516 m .23372 .71364 L .26517 .71834 L p .707 .577 .707 r
F P
0 g
s
.59402 .2541 m .58883 .75929 L .55006 .75327 L p .707 .577 .707 r
F P
0 g
s
.55006 .75327 m .55525 .24808 L .59402 .2541 L p .707 .577 .707 r
F P
0 g
s
.20875 .7504 m .20724 .73331 L .23644 .72545 L p .707 .577 .707 r
F P
0 g
s
.29928 .72271 m .30079 .7398 L .26966 .73889 L p .707 .577 .707 r
F P
0 g
s
.26966 .73889 m .26815 .7218 L .29928 .72271 L p .707 .577 .707 r
F P
0 g
s
.23644 .72545 m .23795 .74254 L .20875 .7504 L p .707 .577 .707 r
F P
0 g
s
.41964 .75491 m .42483 .24972 L .4663 .24578 L p .707 .577 .707 r
F P
0 g
s
.42483 .24972 m .41964 .75491 L .38569 .76185 L p .707 .577 .707 r
F P
0 g
s
.23795 .74254 m .23644 .72545 L .26815 .7218 L p .707 .577 .707 r
F P
0 g
s
.81752 .59862 m .82131 .65078 L .8375 .63815 L p .707 .577 .707 r
F P
0 g
s
.8375 .63815 m .8337 .58599 L .81752 .59862 L p .707 .577 .707 r
F P
0 g
s
.26815 .7218 m .26966 .73889 L .23795 .74254 L p .707 .577 .707 r
F P
0 g
s
.55525 .24808 m .55006 .75327 L .50606 .7504 L p .707 .577 .707 r
F P
0 g
s
.50606 .7504 m .51125 .24521 L .55525 .24808 L p .707 .577 .707 r
F P
0 g
s
.46112 .75097 m .4663 .24578 L .51125 .24521 L p .707 .577 .707 r
F P
0 g
s
.4663 .24578 m .46112 .75097 L .41964 .75491 L p .707 .577 .707 r
F P
0 g
s
.73796 .7754 m .73645 .7583 L .70532 .75739 L p .707 .577 .707 r
F P
0 g
s
.73645 .7583 m .73796 .7754 L .76967 .77175 L p .707 .577 .707 r
F P
0 g
s
.76967 .77175 m .76816 .75465 L .73645 .7583 L p .707 .577 .707 r
F P
0 g
s
.76816 .75465 m .76967 .77175 L .79886 .76389 L p .707 .577 .707 r
F P
0 g
s
.79886 .76389 m .79735 .74679 L .76816 .75465 L p .707 .577 .707 r
F P
0 g
s
.51125 .24521 m .50606 .7504 L .46112 .75097 L p .707 .577 .707 r
F P
0 g
s
.82055 .65984 m .81522 .69779 L .83075 .70234 L p .707 .577 .707 r
F P
0 g
s
.8337 .58599 m .8375 .63815 L .8444 .62452 L p .707 .577 .707 r
F P
0 g
s
.8444 .62452 m .8406 .57236 L .8337 .58599 L p .707 .577 .707 r
F P
0 g
s
.70683 .77449 m .70532 .75739 L .67782 .75201 L p .707 .577 .707 r
F P
0 g
s
.70532 .75739 m .70683 .77449 L .73796 .7754 L p .707 .577 .707 r
F P
0 g
s
.83075 .70234 m .83607 .66438 L .82055 .65984 L p .707 .577 .707 r
F P
0 g
s
.79735 .74679 m .79886 .76389 L .82268 .7526 L p .707 .577 .707 r
F P
0 g
s
.82268 .7526 m .82117 .7355 L .79735 .74679 L p .707 .577 .707 r
F P
0 g
s
.67782 .75201 m .67933 .7691 L .70683 .77449 L p .707 .577 .707 r
F P
0 g
s
.67933 .7691 m .67782 .75201 L .65664 .74268 L p .707 .577 .707 r
F P
0 g
s
.82117 .7355 m .82268 .7526 L .83878 .73898 L p .707 .577 .707 r
F P
0 g
s
.83878 .73898 m .83727 .72188 L .82117 .7355 L p .707 .577 .707 r
F P
0 g
s
.65664 .74268 m .65815 .75978 L .67933 .7691 L p .707 .577 .707 r
F P
0 g
s
.83607 .66438 m .83075 .70234 L .83698 .70588 L p .707 .577 .707 r
F P
0 g
s
.83698 .70588 m .84231 .66793 L .83607 .66438 L p .707 .577 .707 r
F P
0 g
s
.8406 .57236 m .8444 .62452 L .84133 .61123 L p .707 .577 .707 r
F P
0 g
s
.84133 .61123 m .83754 .55907 L .8406 .57236 L p .707 .577 .707 r
F P
0 g
s
.65815 .75978 m .65664 .74268 L .64386 .73032 L p .707 .577 .707 r
F P
0 g
s
.64087 .63141 m .63707 .57925 L .64397 .56563 L p .707 .577 .707 r
F P
0 g
s
.64386 .73032 m .64537 .74741 L .65815 .75978 L p .707 .577 .707 r
F P
0 g
s
.83727 .72188 m .83878 .73898 L .8456 .72436 L p .707 .577 .707 r
F P
0 g
s
.8456 .72436 m .84409 .70726 L .83727 .72188 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84231 .66793 m .83698 .70588 L .83332 .70809 L p .707 .577 .707 r
F P
0 g
s
.83754 .55907 m .84133 .61123 L .82861 .59958 L p .707 .577 .707 r
F P
0 g
s
.82861 .59958 m .82481 .54742 L .83754 .55907 L p .707 .577 .707 r
F P
0 g
s
.83332 .70809 m .83865 .67013 L .84231 .66793 L p .707 .577 .707 r
F P
0 g
s
.64537 .74741 m .64386 .73032 L .64072 .71614 L p .707 .577 .707 r
F P
0 g
s
.64634 .64402 m .64101 .68197 L .63478 .67843 L p .707 .577 .707 r
F P
0 g
s
.64397 .56563 m .64777 .61778 L .64087 .63141 L p .707 .577 .707 r
F P
0 g
s
.64072 .71614 m .64223 .73323 L .64537 .74741 L p .707 .577 .707 r
F P
0 g
s
.64777 .61778 m .64397 .56563 L .66015 .553 L p .707 .577 .707 r
F P
0 g
s
.84409 .70726 m .8456 .72436 L .84247 .71018 L p .707 .577 .707 r
F P
0 g
s
.84247 .71018 m .84095 .69308 L .84409 .70726 L p .707 .577 .707 r
F P
0 g
s
.38962 .58255 m .35848 .58148 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .38962 .58255 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.3887 .64603 m .42015 .65073 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .3887 .64603 L p .3993 .62455 L .707 .577 .707 r
F P
0 g
s
.40145 .62019 m .39235 .62003 L .3993 .62455 L .707 .577 .707 r
F
.3887 .64603 m .39235 .62003 L p .37172 .61847 L F P
0 g
s
.35766 .64225 m .3887 .64603 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .35766 .64225 L p .36885 .62332 L .707 .577 .707 r
F P
0 g
s
.37172 .61847 m .36111 .61766 L .36885 .62332 L .707 .577 .707 r
F
.35848 .58148 m .33099 .57625 L p .34856 .60848 L F P
0 g
s
.35293 .61649 m .36111 .61766 L .34856 .60848 L .707 .577 .707 r
F
.36111 .61766 m .35848 .58148 L p .34856 .60848 L F P
0 g
s
.3774 .61029 m .37689 .60996 L .36228 .63364 L .707 .577 .707 r
F
.35974 .5988 m .36111 .61766 L p .37689 .60996 L F P
0 g
s
.36111 .61766 m .36228 .63364 L p .37689 .60996 L .707 .577 .707 r
F P
0 g
s
.35766 .64225 m .36111 .61766 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .35766 .64225 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33007 .63974 L p .34009 .62011 L .707 .577 .707 r
F P
0 g
s
.34268 .61502 m .33372 .61374 L .34009 .62011 L .707 .577 .707 r
F
.33099 .57625 m .30985 .56738 L p .32539 .6054 L F P
0 g
s
.32825 .6124 m .33372 .61374 L .32539 .6054 L .707 .577 .707 r
F
.33372 .61374 m .33099 .57625 L p .32539 .6054 L F P
0 g
s
.33099 .57625 m .33372 .61374 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33007 .63974 m .33372 .61374 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .33007 .63974 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .30863 .63876 L p .31618 .61463 L .707 .577 .707 r
F P
0 g
s
.31768 .60982 m .31285 .60864 L .31618 .61463 L .707 .577 .707 r
F
.30985 .56738 m .29713 .55573 L p .30905 .60178 L F P
0 g
s
.31285 .60864 m .30985 .56738 L p .30905 .60178 L .707 .577 .707 r
F P
0 g
s
.30985 .56738 m .31285 .60864 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .31285 .60864 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.30863 .63876 m .30111 .60312 L .30084 .60484 L .707 .577 .707 r
F
.29543 .63941 m .30573 .6389 L p .30084 .60484 L F P
0 g
s
.30573 .6389 m .30863 .63876 L p .30084 .60484 L .707 .577 .707 r
F P
0 g
s
.29713 .55573 m .29406 .54244 L p .29996 .59871 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .29543 .63941 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.29543 .63941 m .30056 .60286 L p .2971 .60365 L .707 .577 .707 r
F P
0 g
s
.30034 .60237 m .30056 .60286 L .29996 .59871 L .707 .577 .707 r
F
.30056 .60286 m .29713 .55573 L p .29996 .59871 L F P
0 g
s
.29713 .55573 m .30056 .60286 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30012 .60184 m .2971 .60365 L p .30056 .60286 L .707 .577 .707 r
F P
0 g
s
.29406 .54244 m .29786 .5946 L .29792 .59487 L p .707 .577 .707 r
F P
0 g
s
.29792 .59487 m .30092 .60789 L p .2963 .56382 L .707 .577 .707 r
F P
0 g
s
.2963 .56382 m .29406 .54244 L .29792 .59487 L .707 .577 .707 r
F
.2971 .60365 m .29177 .64161 L .29543 .63941 L p F P
0 g
s
.29177 .64161 m .2971 .60365 L .29842 .60441 L p .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .30056 .60286 L p .30034 .60237 L .707 .577 .707 r
F P
0 g
s
.30092 .60789 m .31365 .61954 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.30056 .60286 m .30092 .60789 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.29842 .60441 m .30333 .6072 L p .2992 .61948 L .707 .577 .707 r
F P
0 g
s
.29177 .64161 m .29842 .60441 L .2992 .61948 L .707 .577 .707 r
F
.30056 .60286 m .30076 .60145 L .30012 .60184 L p F P
0 g
s
.30076 .60145 m .30056 .60286 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .30076 .60145 L p .30111 .60312 L .707 .577 .707 r
F P
0 g
s
.31054 .60755 m .31285 .60864 L .30905 .60178 L .707 .577 .707 r
F
.31285 .60864 m .31395 .60081 L p .30111 .60312 L F P
0 g
s
.31365 .61954 m .31285 .60864 L p .31054 .60755 L .707 .577 .707 r
F P
0 g
s
.31365 .61954 m .33479 .62841 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31285 .60864 m .31365 .61954 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.31395 .60081 m .31285 .60864 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .31395 .60081 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .3354 .60179 L p .31768 .60982 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .33372 .61374 L p .32825 .6124 L .707 .577 .707 r
F P
0 g
s
.33479 .62841 m .36228 .63364 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.33372 .61374 m .33479 .62841 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.3354 .60179 m .33372 .61374 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .3354 .60179 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36111 .61766 m .36299 .60429 L p .34268 .61502 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .36111 .61766 L p .35293 .61649 L .707 .577 .707 r
F P
0 g
s
.36299 .60429 m .36111 .61766 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.36228 .63364 m .39342 .6347 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.38334 .61935 m .3774 .61029 L .37208 .61849 L .707 .577 .707 r
F
.38334 .61935 m .37208 .61849 L .36228 .63364 L F
.35848 .58148 m .35974 .5988 L p .3774 .61029 L F P
0 g
s
.38962 .58255 m .39235 .62003 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .38962 .58255 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42137 .57935 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .44892 .65588 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42015 .65073 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42137 .57935 m .42438 .62061 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .42137 .57935 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45062 .5722 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.45062 .5722 m .45405 .61934 L p .4783 .61396 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .47221 .66098 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .44892 .65588 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.47061 .61731 m .4783 .61396 L p .45405 .61934 L .707 .577 .707 r
F P
0 g
s
.47221 .66098 m .47754 .62302 L .45425 .61793 L p .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45442 .62436 L .47061 .61731 L p .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .45405 .61934 L p .4548 .61925 L .707 .577 .707 r
F P
0 g
s
.45425 .61793 m .42548 .61278 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.44892 .65588 m .45405 .61934 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45405 .61934 m .45425 .61793 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.45442 .62436 m .45405 .61934 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .45442 .62436 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42517 .63151 L p .45083 .61948 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .42438 .62061 L p .42961 .62038 L .707 .577 .707 r
F P
0 g
s
.42548 .61278 m .39403 .60808 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42015 .65073 m .42438 .62061 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42438 .62061 m .42548 .61278 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.42517 .63151 m .42438 .62061 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .42517 .63151 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39342 .6347 L p .41716 .62048 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .39235 .62003 L p .40145 .62019 L .707 .577 .707 r
F P
0 g
s
.39403 .60808 m .36299 .60429 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39235 .62003 m .39403 .60808 L p .37172 .61847 L .707 .577 .707 r
F P
0 g
s
.39342 .6347 m .39235 .62003 L p .38334 .61935 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82481 .54742 m .82861 .59958 L .80747 .59071 L p .707 .577 .707 r
F P
0 g
s
.80747 .59071 m .80367 .53855 L .82481 .54742 L p .707 .577 .707 r
F P
0 g
s
.83865 .67013 m .83332 .70809 L .82013 .70873 L p .707 .577 .707 r
F P
0 g
s
.4783 .61396 m .47451 .56181 L .45062 .5722 L p .707 .577 .707 r
F P
0 g
s
.82013 .70873 m .82545 .67077 L .83865 .67013 L p .707 .577 .707 r
F P
0 g
s
.64223 .73323 m .64072 .71614 L .64754 .70152 L p .707 .577 .707 r
F P
0 g
s
.66015 .553 m .66395 .60515 L .64777 .61778 L p .707 .577 .707 r
F P
0 g
s
.66395 .60515 m .66015 .553 L .68404 .5426 L p .707 .577 .707 r
F P
0 g
s
.66187 .64856 m .65654 .68652 L .64101 .68197 L p .707 .577 .707 r
F P
0 g
s
.64101 .68197 m .64634 .64402 L .66187 .64856 L p .707 .577 .707 r
F P
0 g
s
.64754 .70152 m .64905 .71861 L .64223 .73323 L p .707 .577 .707 r
F P
0 g
s
.84095 .69308 m .84247 .71018 L .82968 .69782 L p .707 .577 .707 r
F P
0 g
s
.82968 .69782 m .82817 .68072 L .84095 .69308 L p .707 .577 .707 r
F P
0 g
s
.80367 .53855 m .80747 .59071 L .77998 .58548 L p .707 .577 .707 r
F P
0 g
s
.77998 .58548 m .77618 .53332 L .80367 .53855 L p .707 .577 .707 r
F P
0 g
s
.47451 .56181 m .4783 .61396 L .49449 .60133 L p .707 .577 .707 r
F P
0 g
s
.49449 .60133 m .49069 .54918 L .47451 .56181 L p .707 .577 .707 r
F P
0 g
s
.68784 .59476 m .68404 .5426 L .71329 .53545 L p .707 .577 .707 r
F P
0 g
s
.68404 .5426 m .68784 .59476 L .66395 .60515 L p .707 .577 .707 r
F P
0 g
s
.82545 .67077 m .82013 .70873 L .79868 .70775 L p .707 .577 .707 r
F P
0 g
s
.79868 .70775 m .80401 .6698 L .82545 .67077 L p .707 .577 .707 r
F P
0 g
s
.68516 .65366 m .67983 .69161 L .65654 .68652 L p .707 .577 .707 r
F P
0 g
s
.64905 .71861 m .64754 .70152 L .66364 .6879 L p .707 .577 .707 r
F P
0 g
s
.77618 .53332 m .77998 .58548 L .74884 .58441 L p .707 .577 .707 r
F P
0 g
s
.74884 .58441 m .74504 .53226 L .77618 .53332 L p .707 .577 .707 r
F P
0 g
s
.39495 .73858 m .39344 .72149 L .36231 .72058 L p .707 .577 .707 r
F P
0 g
s
.39344 .72149 m .39495 .73858 L .42666 .73493 L p .707 .577 .707 r
F P
0 g
s
.42666 .73493 m .42515 .71783 L .39344 .72149 L p .707 .577 .707 r
F P
0 g
s
.65654 .68652 m .66187 .64856 L .68516 .65366 L p .707 .577 .707 r
F P
0 g
s
.42515 .71783 m .42666 .73493 L .45585 .72707 L p .707 .577 .707 r
F P
0 g
s
.45585 .72707 m .45434 .70998 L .42515 .71783 L p .707 .577 .707 r
F P
0 g
s
.71709 .58761 m .71329 .53545 L .74504 .53226 L p .707 .577 .707 r
F P
0 g
s
.71329 .53545 m .71709 .58761 L .68784 .59476 L p .707 .577 .707 r
F P
0 g
s
.74504 .53226 m .74884 .58441 L .71709 .58761 L p .707 .577 .707 r
F P
0 g
s
.66364 .6879 m .66515 .70499 L .64905 .71861 L p .707 .577 .707 r
F P
0 g
s
.47754 .62302 m .47221 .66098 L .48774 .66552 L p .707 .577 .707 r
F P
0 g
s
.82817 .68072 m .82968 .69782 L .80851 .68849 L p .707 .577 .707 r
F P
0 g
s
.80851 .68849 m .807 .67139 L .82817 .68072 L p .707 .577 .707 r
F P
0 g
s
.49069 .54918 m .49449 .60133 L .50139 .58771 L p .707 .577 .707 r
F P
0 g
s
.50139 .58771 m .49759 .53555 L .49069 .54918 L p .707 .577 .707 r
F P
0 g
s
.36382 .73767 m .36231 .72058 L .33481 .71519 L p .707 .577 .707 r
F P
0 g
s
.36231 .72058 m .36382 .73767 L .39495 .73858 L p .707 .577 .707 r
F P
0 g
s
.48774 .66552 m .49306 .62757 L .47754 .62302 L p .707 .577 .707 r
F P
0 g
s
.45434 .70998 m .45585 .72707 L .47967 .71578 L p .707 .577 .707 r
F P
0 g
s
.47967 .71578 m .47816 .69869 L .45434 .70998 L p .707 .577 .707 r
F P
0 g
s
.80401 .6698 m .79868 .70775 L .77109 .70524 L p .707 .577 .707 r
F P
0 g
s
.33481 .71519 m .33632 .73229 L .36382 .73767 L p .707 .577 .707 r
F P
0 g
s
.77109 .70524 m .77642 .66729 L .80401 .6698 L p .707 .577 .707 r
F P
0 g
s
.67983 .69161 m .68516 .65366 L .71393 .6588 L p .707 .577 .707 r
F P
0 g
s
.66515 .70499 m .66364 .6879 L .68746 .67661 L p .707 .577 .707 r
F P
0 g
s
.71393 .6588 m .7086 .69676 L .67983 .69161 L p .707 .577 .707 r
F P
0 g
s
.33632 .73229 m .33481 .71519 L .31363 .70586 L p .707 .577 .707 r
F P
0 g
s
.807 .67139 m .80851 .68849 L .78101 .6831 L p .707 .577 .707 r
F P
0 g
s
.78101 .6831 m .7795 .66601 L .807 .67139 L p .707 .577 .707 r
F P
0 g
s
.68746 .67661 m .68897 .6937 L .66515 .70499 L p .707 .577 .707 r
F P
0 g
s
.47816 .69869 m .47967 .71578 L .49577 .70216 L p .707 .577 .707 r
F P
0 g
s
.49577 .70216 m .49426 .68507 L .47816 .69869 L p .707 .577 .707 r
F P
0 g
s
.77642 .66729 m .77109 .70524 L .74005 .70146 L p .707 .577 .707 r
F P
0 g
s
.31363 .70586 m .31514 .72296 L .33632 .73229 L p .707 .577 .707 r
F P
0 g
s
.49306 .62757 m .48774 .66552 L .49397 .66907 L p .707 .577 .707 r
F P
0 g
s
.74005 .70146 m .74538 .6635 L .77642 .66729 L p .707 .577 .707 r
F P
0 g
s
.74538 .6635 m .74005 .70146 L .7086 .69676 L p .707 .577 .707 r
F P
0 g
s
.7086 .69676 m .71393 .6588 L .74538 .6635 L p .707 .577 .707 r
F P
0 g
s
.49397 .66907 m .4993 .63111 L .49306 .62757 L p .707 .577 .707 r
F P
0 g
s
.49759 .53555 m .50139 .58771 L .49832 .57442 L p .707 .577 .707 r
F P
0 g
s
.49832 .57442 m .49453 .52226 L .49759 .53555 L p .707 .577 .707 r
F P
0 g
s
.68897 .6937 m .68746 .67661 L .71665 .66875 L p .707 .577 .707 r
F P
0 g
s
.7795 .66601 m .78101 .6831 L .74987 .68219 L p .707 .577 .707 r
F P
0 g
s
.74987 .68219 m .74836 .6651 L .7795 .66601 L p .707 .577 .707 r
F P
0 g
s
.31514 .72296 m .31363 .70586 L .30085 .6935 L p .707 .577 .707 r
F P
0 g
s
.71665 .66875 m .71816 .68585 L .68897 .6937 L p .707 .577 .707 r
F P
0 g
s
.71816 .68585 m .71665 .66875 L .74836 .6651 L p .707 .577 .707 r
F P
0 g
s
.74836 .6651 m .74987 .68219 L .71816 .68585 L p .707 .577 .707 r
F P
0 g
s
.29786 .5946 m .29406 .54244 L .30096 .52881 L p .707 .577 .707 r
F P
0 g
s
.30085 .6935 m .30236 .7106 L .31514 .72296 L p .707 .577 .707 r
F P
0 g
s
.49426 .68507 m .49577 .70216 L .50259 .68754 L p .707 .577 .707 r
F P
0 g
s
.50259 .68754 m .50108 .67045 L .49426 .68507 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4993 .63111 m .49397 .66907 L .49031 .67127 L p .707 .577 .707 r
F P
0 g
s
.49453 .52226 m .49832 .57442 L .4856 .56276 L p .707 .577 .707 r
F P
0 g
s
.4856 .56276 m .4818 .51061 L .49453 .52226 L p .707 .577 .707 r
F P
0 g
s
.49031 .67127 m .49564 .63332 L .4993 .63111 L p .707 .577 .707 r
F P
0 g
s
.30236 .7106 m .30085 .6935 L .29771 .67932 L p .707 .577 .707 r
F P
0 g
s
.30333 .6072 m .298 .64516 L .29177 .64161 L p .707 .577 .707 r
F P
0 g
s
.30096 .52881 m .30476 .58097 L .29786 .5946 L p .707 .577 .707 r
F P
0 g
s
.29771 .67932 m .29922 .69642 L .30236 .7106 L p .707 .577 .707 r
F P
0 g
s
.30476 .58097 m .30096 .52881 L .31714 .51618 L p .707 .577 .707 r
F P
0 g
s
.50108 .67045 m .50259 .68754 L .49945 .67336 L p .707 .577 .707 r
F P
0 g
s
.49945 .67336 m .49794 .65627 L .50108 .67045 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.4818 .51061 m .4856 .56276 L .46446 .55389 L p .707 .577 .707 r
F P
0 g
s
.46446 .55389 m .46066 .50173 L .4818 .51061 L p .707 .577 .707 r
F P
0 g
s
.49564 .63332 m .49031 .67127 L .47712 .67191 L p .707 .577 .707 r
F P
0 g
s
.47712 .67191 m .48244 .63396 L .49564 .63332 L p .707 .577 .707 r
F P
0 g
s
.29922 .69642 m .29771 .67932 L .30453 .6647 L p .707 .577 .707 r
F P
0 g
s
.31714 .51618 m .32094 .56834 L .30476 .58097 L p .707 .577 .707 r
F P
0 g
s
.32094 .56834 m .31714 .51618 L .34103 .50578 L p .707 .577 .707 r
F P
0 g
s
.31886 .61174 m .31353 .6497 L .298 .64516 L p .707 .577 .707 r
F P
0 g
s
.298 .64516 m .30333 .6072 L .31886 .61174 L p .707 .577 .707 r
F P
0 g
s
.30453 .6647 m .30604 .6818 L .29922 .69642 L p .707 .577 .707 r
F P
0 g
s
.49794 .65627 m .49945 .67336 L .48667 .661 L p .707 .577 .707 r
F P
0 g
s
.48667 .661 m .48516 .6439 L .49794 .65627 L p .707 .577 .707 r
F P
0 g
s
.46066 .50173 m .46446 .55389 L .43697 .54867 L p .707 .577 .707 r
F P
0 g
s
.43697 .54867 m .43317 .49651 L .46066 .50173 L p .707 .577 .707 r
F P
0 g
s
.34483 .55794 m .34103 .50578 L .37028 .49864 L p .707 .577 .707 r
F P
0 g
s
.34103 .50578 m .34483 .55794 L .32094 .56834 L p .707 .577 .707 r
F P
0 g
s
.48244 .63396 m .47712 .67191 L .45567 .67094 L p .707 .577 .707 r
F P
0 g
s
.45567 .67094 m .461 .63298 L .48244 .63396 L p .707 .577 .707 r
F P
0 g
s
.34215 .61684 m .33682 .6548 L .31353 .6497 L p .707 .577 .707 r
F P
0 g
s
.30604 .6818 m .30453 .6647 L .32063 .65108 L p .707 .577 .707 r
F P
0 g
s
.43317 .49651 m .43697 .54867 L .40583 .5476 L p .707 .577 .707 r
F P
0 g
s
.40583 .5476 m .40203 .49544 L .43317 .49651 L p .707 .577 .707 r
F P
0 g
s
.31353 .6497 m .31886 .61174 L .34215 .61684 L p .707 .577 .707 r
F P
0 g
s
.37408 .55079 m .37028 .49864 L .40203 .49544 L p .707 .577 .707 r
F P
0 g
s
.37028 .49864 m .37408 .55079 L .34483 .55794 L p .707 .577 .707 r
F P
0 g
s
.40203 .49544 m .40583 .5476 L .37408 .55079 L p .707 .577 .707 r
F P
0 g
s
.32063 .65108 m .32214 .66818 L .30604 .6818 L p .707 .577 .707 r
F P
0 g
s
.48516 .6439 m .48667 .661 L .46549 .65167 L p .707 .577 .707 r
F P
0 g
s
.46549 .65167 m .46398 .63458 L .48516 .6439 L p .707 .577 .707 r
F P
0 g
s
.461 .63298 m .45567 .67094 L .42808 .66843 L p .707 .577 .707 r
F P
0 g
s
.42808 .66843 m .43341 .63047 L .461 .63298 L p .707 .577 .707 r
F P
0 g
s
.33682 .6548 m .34215 .61684 L .37092 .62199 L p .707 .577 .707 r
F P
0 g
s
.32214 .66818 m .32063 .65108 L .34445 .63979 L p .707 .577 .707 r
F P
0 g
s
.37092 .62199 m .36559 .65994 L .33682 .6548 L p .707 .577 .707 r
F P
0 g
s
.46398 .63458 m .46549 .65167 L .43799 .64629 L p .707 .577 .707 r
F P
0 g
s
.43799 .64629 m .43648 .62919 L .46398 .63458 L p .707 .577 .707 r
F P
0 g
s
.34445 .63979 m .34596 .65689 L .32214 .66818 L p .707 .577 .707 r
F P
0 g
s
.43341 .63047 m .42808 .66843 L .39704 .66464 L p .707 .577 .707 r
F P
0 g
s
.39704 .66464 m .40237 .62669 L .43341 .63047 L p .707 .577 .707 r
F P
0 g
s
.40237 .62669 m .39704 .66464 L .36559 .65994 L p .707 .577 .707 r
F P
0 g
s
.36559 .65994 m .37092 .62199 L .40237 .62669 L p .707 .577 .707 r
F P
0 g
s
.34596 .65689 m .34445 .63979 L .37364 .63194 L p .707 .577 .707 r
F P
0 g
s
.43648 .62919 m .43799 .64629 L .40686 .64538 L p .707 .577 .707 r
F P
0 g
s
.40686 .64538 m .40535 .62828 L .43648 .62919 L p .707 .577 .707 r
F P
0 g
s
.37364 .63194 m .37515 .64903 L .34596 .65689 L p .707 .577 .707 r
F P
0 g
s
.37515 .64903 m .37364 .63194 L .40535 .62828 L p .707 .577 .707 r
F P
0 g
s
.40535 .62828 m .40686 .64538 L .37515 .64903 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo5@00QWoo001lOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Ioo`H000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00LWoo10000UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001^Ool40006FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool0
06Yoo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol2
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEPT00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001P0015YF00<005YF
FUH00UYF200015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001SOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001POol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00G7oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP000004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol005Moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001EOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000GOol?000oOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP03001JEP0000<003]oo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH00eYF1000=goo001COol00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000dOol005=oo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Qoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80035oo`00Dgoo
00<005YF00001EYF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF1@001EYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000Aoo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00Dgoo00@005YFFUH000AJEP03001JEUYF
00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEP000003FUH0
1000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000goo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00@005YFFUH000AJEP04001JEUYFFUH20003Ool0
1000FUIJEP001UYF10001EYF00<005YFFUH02EYF00<005YFFUH00`0000EJEP00FUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005Ool00000FUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00@005YF000000Eoo`04001JEUYF
0006FUH50004FUH00`00FUIJEP09FUH40002FUH20002FUH200000eYF001JEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo
001COol01000FUIJEP0015YF0P001goo00@005YFFUH000IJEPD000AJEP03001JEUYF00QJEP80009J
EP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF0`00
1goo00@005YFFUH000IJEPD000AJEP03001JEUYF00AJEP@000AJEP03001JEUYF009JEP@00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool005Aoo`04001JEP00FUH20003FUH30004Ool01000FUIJEP001UYF1000
1EYF00<005YFFUH010000UYF00<005YFFUH00eYF00<005YFFUH00UYF00H005YF000005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP00;Woo001DOol00`00FUH000020005FUH00`00FUH000040002FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH70006FUH00`00FUIJEP03FUH00`00FUIJEP03FUH300000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Woo001DOol01@00FUH005YF00001EYF00<005YFFUH00eYF3`0015YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH00eYF0`0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo0P00
0UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YFFUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPl000IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00@Goo5@000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000moo`@0009JEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool003ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP80009J
EP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP04000IOol40004FUH0
1@00FUIJEUYF0000;Goo000kOol30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF10002goo0`004goo0`0000=JEP00FUH00UYF
00<007ooOol0:goo000hOol30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH40002FUH0
0`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000=JEP04001JEUYFFUH2000>Ool5000BOol200000eYF00000003FUH00`00Oomoo`0[Ool0
03Eoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EUYF010000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
0eYF00@005YF0000011oo`D0011oo`800003FUH005YF009JEP04001JEUYF000]Ool003=oo`8000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP@000IJEP03001JEUYF00EJEP03001J
EUYF009JEPH000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP80019o
o`D000ioo`8000=JEP03001JEUYF009JEP<002eoo`00<Woo0P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEP<001=oo`<000aoo`<000EJ
EP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0000<000IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPL000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH5000IOol400000eYF
001JEP05FUH00`00FUIJEP02FUH01000FUH00000;7oo000_Ool01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF1P000UYF0P002EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP0000001EYF00@005YFFUIJEPT0
00Uoo`L000EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEP00000/Ool002ioo`03001JEUYF
009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP040008FUH00`00FUIJEP04FUH40003FUH40005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP00;7oo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH@0002FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF00000`00
1EYF00<005YFFUH00eYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo000/Ool00`00FUH00005FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<0
05YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP`00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP04001JEUYFOol5FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00004FUH005YF0004FUH00`00FUIJEP04FUH40006
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP0200000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/
Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Uoo`800003FUH005YF
00=JEP03001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00800004FUH005YFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH010004Goo10000UYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF
009JEPl000IJEP04001JEUYFFUH20002FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<7oo000/Ool01000FUIJEP0015YF00<0
05YFFUH00eYF10006Goo100000=JEP00000015YF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF
00@005YFFUIJEP@0009JEP03001JEUYF009JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH500000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP04FUH2000bOol002aoo`04001JEUYF0004FUH01000
FUIJEUYF0P003Woo0`0047oo00<005YFFUH015YF00<005YFFUH0100025YF00<005YFFUH01UYF00<0
05YFFUH01EYF10000eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00D000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001oogoo035oo`00;7oo00@005YF
FUH000AJEP04001JEP00000?Ool5000>Ool20006FUH30002FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000MJEP00FUIJEP00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUH00004
0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH7000dOol002aoo`04001JEUYF0004FUH2000AOol5
000<Ool200000eYF001JEP03FUH200000eYF000000050006FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30002FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH00eYF1`000UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00001P00<Woo000]Ool00`00FUH00003FUH00`00Oomoo`0AOol5
000;Ool01@00FUIJEUYF00000UYF0P0015YF00@005YFFUH0009JEP@0009JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEPT0009JEP03001JEUYF00AJEP<000EJEP03001JEP00008002moo`00;Goo00@005YF001J
EP800003FUH00000019oo`<000Qoo`@000AJEP<00003FUH005YF00=JEP04001JEUYF0005FUH80004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00=JEQ400003FUH005YF00EJEP03001JEUYF009JEP8002eoo`00;Goo00<005YF00000P00
15YF1@004Goo1`000UYF0P0015YF00D005YFFUIJEP0000AJEP04001JEUYF0005FUH00`00FUIJEP05
FUH?0003FUH00`00FUIJEP06000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP06FUH01000FUIJ
EUYF3`00;Goo000]Ool01@00FUH005YF00001EYF00@005YFFUIJEQ4000AJEP03001JEUYF009JEP80
00=JEP03001JEUYF009JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH70003FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH30002FUH01000FUIJEUYF0P00;Goo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0`001EYF00<005YFFUH0
0UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP<000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEPD0
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001o
ogoo02aoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP00009JEP03001JEP0000IJEP05001JEUYFFUH00002FUH00`00FUIJEP03
FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP06FUH4000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00
FUIJEP04FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000000^Ool002eoo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH00`00FUH00006FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000800003FUH005YF009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00@000IJEPP0
00AJEP03001JEUYF00=JEP@002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
0UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH01EYF0P0000=JEP00000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000Woo1@001EYF00<005YF
FUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH00eYF1@001EYF00@005YF000002ioo`00;Goo
0P000UYF10000UYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEPH000AJEP03001JEUYF00UJEP03
001JEUYF00=JEP800005FUH00000FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004Ool20006FUH00`00FUIJEP040008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH01000FUIJEP00;Woo000]Ool00`00FUIJEP02FUH00`00FUIJEP0@0003
FUH00`00FUIJEP06FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00UJEP03001JEUYF009JEP04001JEUYFFUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
Ool00`00FUH00006FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`0[Ool002eoo`05FUH00000FUH00006FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH60006FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP0000AJ
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
Ool01@00FUIJEUYF00000eYF0P000eYF200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`000eYF00<007ooOol0:goo000]Ool2FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH000030002FUH01P00FUIJEUYF001JEP800003FUH005YF00AJEP<00005Ool005YFFUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH000020004FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001oo`0000AJEP03001JEP000080
00AJEP03001JEP0000Eoo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00Oomoo`0[Ool002aoo`04001JEUYF0002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7
0003FUH20005FUH01@00Oomoogoo00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF0P000UYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP00008000AJEP80009JEP03001JEUYF009JEP04001JEP00000=Ool8
0004FUH00`00FUIJEP03FUH00`00FUIJEP04000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH7
00000eYF001JEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF0`000UYF0P0017oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP03001JEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000=JEP03001JEUYF
009JEP03001JEUYF009JEP04001JEP00000EOol>0002Ool00`00Oomoo`0[Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH00`001Goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH0
05YF00EJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP06001JEP00FUH005YF0P001EYF00<005YFFUH00UYF00@005YFFUH002Aoo`8002eoo`00;7oo0UYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100025YF00<005YFFUH0
0UYF00@005YFFUH000AJEPD00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP030004
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0`001UYF00<005YFFUH00UYF00@005YFFUH000Moo`<001Yoo`8002eo
o`00;7oo0UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1`00
00AJEP00FUIJEPH000EJEP04001JEUYFFUH80002FUH00`00FUIJEP04FUH60007FUH01000FUIJEUYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF
001JEP00FUH00007FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000/Ool2FUH0
1@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH015YF400000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20007Ool5000HOol01000FUIJEP00;7oo000[Ool01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF1`0015YF00<005YFFUH01UYF00<005YF000010000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10002eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00AJ
EP03001JEUYF009JEP03001oogoo00Ioo`D001Moo`80009JEP03001oogoo02Yoo`00:goo00<005YF
000015YF00<005YFFUH015YF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`07Ool3000GOol0
1@00FUH005YF0000;Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000040004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP04FUH01@00FUIJEUYF00008goo00@005YF
FUIJEP8002eoo`00;7oo10000UYF00<005YFFUH00eYF0`0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF2`0015YF00<005YFFUH01@002eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P00
0UYF00<005YFFUH015YF00@005YF0000029oo`8000AJEP03001oogoo02aoo`00<7oo10000UYF0P00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF4@0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH0
0UYF1`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00P005YF000005YF001JEP001UYF0P008Woo0P0000=JEP00FUH0
0eYF00<007ooOol0;7oo000dOol20005FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH50004FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUH000000UYF0P001UYF00<007ooOol07goo0P000eYF00D005YFFUIJEP0002moo`00<goo
0P001UYF00<005YFFUH0100025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001J
EP0000D001moo`<000EJEP04001JEP00000`Ool0035oo`800003FUH005YF00AJEPT000IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP07001JEP00FUH005YF000015YF1@006Goo100000=JEP00FUH01EYF0P00<Woo000`Ool01@00
FUIJEUYF00000eYF0P002Goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
10000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@0035YF00<005YFFUH02EYF30001EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF000015YF00<005YF000010003goo1`00
1EYF00<005YFFUH015YF00<007ooOol0<Goo000_Ool00`00FUIJEP02FUH01000FUH000003goo1`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF
009JEP03001JEP0000D000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2
000dOol002ioo`8000AJEP8001Qoo`l000=JEP03001JEUYF0080009JEP03001JEUYF00=JEP<0009J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000EJEP8000AJ
EP03001JEUYF009JEP04001JEP00FUH50004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUH00000=Woo000^Ool20003FUH00`00Oomoo`0WOol600001Goo
001JEUYF00000eYF0P001EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF0P001eYF0`0000=JEP00FUH00eYF00<005YF00001EYF100000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000>7oo000]Ool01P00FUIJEP00FUH0035oo`05
001JEUYF001JEP020007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH20008FUH01000FUH0000015YF00<005YF00001eYF1@001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01000?7oo000]Ool00`00FUIJEP02000FOol3000IOol00`00FUIJEP020000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH2
0008FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01P0000=JEP00FUH01eYF00<0
05YFFUH00UYF1`00@7oo000]Ool01000FUIJEP005Woo1@0067oo00<005YF00000eYF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF0P0025YF00<0
05YFFUH00eYF0`0000=JEP0000001UYF00<005YFFUH00UYF0P0000=JEP0000003P00Agoo000]Ool0
0`00FUH0000GOol5000HOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP04
0002FUH00`00FUIJEP03FUH4001EOol002ioo`8001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000005FUH30005FUH01000FUH00000EGoo000^Ool00`00Oomoo`0GOol3
000GOol40004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH00P00
0eYF00D005YFFUIJEP0005Aoo`00;Woo0P00<Goo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomoo`1B
Ool002ioo`03001JEP0002moo`03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000=JEP03001oogoo059oo`00;Woo00@005YF
FUH002aoo`<000AJEP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD000AJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00Oomoo`1BOol002ioo`04001JEUYFFUH2000XOol20002FUH01@00FUIJ
EUYF00000goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0P0017oo4@00E7oo000^Ool01P00FUIJEUYF001JEP<0
025oo`@000EJEP03001JEP0000Ioo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2000EOol2001DOol002moo`04001J
EUYF0004FUH3000JOol40002FUH00`00FUIJEP04FUH20009Ool40002FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000005goo0P00
E7oo000`Ool00`00FUH00005FUH00`00FUH00003000?Ool70006FUH00`00FUIJEP03FUH2000>Ool5
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH7000HOol0
1000FUH00000Dgoo000aOol20005FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P005Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1@000Woo1@00
67oo00@005YFFUH005=oo`00<Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF000001eoo`T000IJEP03001JEUYF00YJEP03001JEUYF00=JEPH0
00Ioo`D001Moo`80009JEP03001oogoo055oo`00=7oo0`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH015YF0`00:7oo6@0037oo1@005Woo00D005YF001JEP0005Aoo`00
=goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000=Woo0P006Goo0`005Woo
00@005YFFUIJEP8005Aoo`00>Woo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>Woo0`00
;goo0P0015YF00<007ooOol0Dgoo000nOol@0011Ool200000eYF001oo`0[Ool200000eYF001JEP03
FUH00`00Oomoo`1COol008moo`80009JEP03001oogoo02Moo`8000=JEP05001JEUYFFUH0001FOol0
091oo`03001JEUYF00<002Aoo`<000EJEP04001JEP00001GOol0091oo`04001JEUYF0002FUH2000P
Ool200000eYF001JEP05FUH2001IOol0095oo`04001JEUYF0003FUH5000HOol30003FUH00`00FUIJ
EP04FUH00`00Oomoo`1HOol0099oo`<000AJEP04001JEUYFFUH90009Ool60007FUH01000FUIJEUYF
0P00Fgoo002DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP06FUH01000FUH00000GGoo002EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH3001OOol009Moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<0069oo`00VGoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P00IGoo002NOol80004FUH00`00FUIJEP02FUH6001XOol00:Ioo`T006ioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59556 .70474 m .5644 .70337 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59556 .70474 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59449 .78841 m .62618 .79101 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59449 .78841 L p .59916 .75385 L .707 .577 .707 r
F P
0 g
s
.59936 .75234 m .59764 .75234 L .59916 .75385 L .707 .577 .707 r
F
.59449 .78841 m .59764 .75234 L p .56889 .75032 L F P
0 g
s
.56337 .78535 m .59449 .78841 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56337 .78535 L p .56855 .75246 L .707 .577 .707 r
F P
0 g
s
.56889 .75032 m .56645 .75015 L .56855 .75246 L .707 .577 .707 r
F
.5644 .70337 m .53693 .69845 L p .55916 .74213 L F P
0 g
s
.56298 .74963 m .56645 .75015 L .55916 .74213 L .707 .577 .707 r
F
.56645 .75015 m .5644 .70337 L p .55916 .74213 L F P
0 g
s
.58885 .74353 m .58222 .73689 L .56675 .75703 L .707 .577 .707 r
F
.56512 .71976 m .56645 .75015 L p .58222 .73689 L F P
0 g
s
.56645 .75015 m .56675 .75703 L p .58222 .73689 L .707 .577 .707 r
F P
0 g
s
.56337 .78535 m .56645 .75015 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .56337 .78535 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53586 .78212 L p .54038 .74808 L .707 .577 .707 r
F P
0 g
s
.54062 .74629 m .53901 .74605 L .54038 .74808 L .707 .577 .707 r
F
.53693 .69845 m .51584 .69048 L p .53431 .73904 L F P
0 g
s
.51584 .69048 m .5032 .68024 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.52079 .74118 m .518 .74077 L p .53901 .74605 L .707 .577 .707 r
F P
0 g
s
.518 .74077 m .51466 .77904 L .53348 .78178 L p .707 .577 .707 r
F P
0 g
s
.53348 .78178 m .53586 .78212 L p .51914 .74341 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .518 .74077 L .53348 .78178 L .707 .577 .707 r
F
.51466 .77904 m .518 .74077 L .50518 .73814 L p F P
0 g
s
.50555 .73391 m .51819 .74415 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.5032 .68024 m .50422 .70349 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.50422 .70349 m .50555 .73391 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51819 .74415 m .51803 .74044 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.51803 .74044 m .51584 .69048 L p .51613 .73535 L .707 .577 .707 r
F P
0 g
s
.53586 .78212 m .53901 .74605 L p .51817 .74081 L .707 .577 .707 r
F P
0 g
s
.51914 .74341 m .51817 .74081 L .518 .74077 L .707 .577 .707 r
F
.53586 .78212 m .51817 .74081 L .51914 .74341 L F
.53674 .74544 m .53901 .74605 L .53431 .73904 L F
.53901 .74605 m .53693 .69845 L p .53431 .73904 L F P
0 g
s
.53693 .69845 m .53901 .74605 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.51584 .69048 m .51819 .74415 L .53928 .75212 L p .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53921 .74385 L .52079 .74118 L p .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .53901 .74605 L p .53674 .74544 L .707 .577 .707 r
F P
0 g
s
.53928 .75212 m .56675 .75703 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53901 .74605 m .53928 .75212 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.53921 .74385 m .53901 .74605 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .53921 .74385 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56645 .75015 m .56672 .74708 L p .54062 .74629 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .56645 .75015 L p .56298 .74963 L .707 .577 .707 r
F P
0 g
s
.56672 .74708 m .56645 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.56675 .75703 m .59791 .75841 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.59406 .75209 m .58885 .74353 L .57683 .75088 L .707 .577 .707 r
F
.59406 .75209 m .57683 .75088 L .56675 .75703 L F
.5644 .70337 m .56512 .71976 L p .58885 .74353 L F P
0 g
s
.59556 .70474 m .59764 .75234 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62952 .75274 L .62535 .7524 L p .707 .577 .707 r
F P
0 g
s
.62535 .7524 m .59784 .75015 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.62618 .79101 m .62535 .7524 L .59936 .75234 L .707 .577 .707 r
F
.62736 .70245 m .59556 .70474 L p .62724 .7524 L F P
0 g
s
.62952 .75274 m .62618 .79101 L .65533 .79288 L p .707 .577 .707 r
F P
0 g
s
.65533 .79288 m .65867 .75461 L .62952 .75274 L p .707 .577 .707 r
F P
0 g
s
.62971 .75612 m .62955 .75241 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.62955 .75241 m .62736 .70245 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .62971 .75612 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59791 .75841 L p .62724 .7524 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .59764 .75234 L p .59936 .75234 L .707 .577 .707 r
F P
0 g
s
.59784 .75015 m .56672 .74708 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59764 .75234 m .59784 .75015 L p .56889 .75032 L .707 .577 .707 r
F P
0 g
s
.59791 .75841 m .59764 .75234 L p .59406 .75209 L .707 .577 .707 r
F P
0 g
s
.62736 .70245 m .62971 .75612 L .65905 .75039 L p .707 .577 .707 r
F P
0 g
s
.65905 .75039 m .65669 .69672 L .62736 .70245 L p .707 .577 .707 r
F P
0 g
s
.65669 .69672 m .65905 .75039 L .68303 .74176 L p .707 .577 .707 r
F P
0 g
s
.68303 .74176 m .68068 .6881 L .65669 .69672 L p .707 .577 .707 r
F P
0 g
s
.68068 .6881 m .68303 .74176 L .69933 .7311 L p .707 .577 .707 r
F P
0 g
s
.69933 .7311 m .69698 .67744 L .68068 .6881 L p .707 .577 .707 r
F P
0 g
s
.65867 .75461 m .65533 .79288 L .67909 .79385 L p .707 .577 .707 r
F P
0 g
s
.67909 .79385 m .68243 .75558 L .65867 .75461 L p .707 .577 .707 r
F P
0 g
s
.5988 .86257 m .59786 .84483 L .5667 .84355 L p .707 .577 .707 r
F P
0 g
s
.59786 .84483 m .5988 .86257 L .63059 .85999 L p .707 .577 .707 r
F P
0 g
s
.63059 .85999 m .62965 .84225 L .59786 .84483 L p .707 .577 .707 r
F P
0 g
s
.62965 .84225 m .63059 .85999 L .6599 .8538 L p .707 .577 .707 r
F P
0 g
s
.6599 .8538 m .65896 .83606 L .62965 .84225 L p .707 .577 .707 r
F P
0 g
s
.56764 .86129 m .5667 .84355 L .53923 .83854 L p .707 .577 .707 r
F P
0 g
s
.5667 .84355 m .56764 .86129 L .5988 .86257 L p .707 .577 .707 r
F P
0 g
s
.68243 .75558 m .67909 .79385 L .69513 .79382 L p .707 .577 .707 r
F P
0 g
s
.69513 .79382 m .69847 .75555 L .68243 .75558 L p .707 .577 .707 r
F P
0 g
s
.69698 .67744 m .69933 .7311 L .70634 .71945 L p .707 .577 .707 r
F P
0 g
s
.70634 .71945 m .70399 .66578 L .69698 .67744 L p .707 .577 .707 r
F P
0 g
s
.65896 .83606 m .6599 .8538 L .68386 .84461 L p .707 .577 .707 r
F P
0 g
s
.68386 .84461 m .68292 .82687 L .65896 .83606 L p .707 .577 .707 r
F P
0 g
s
.53923 .83854 m .54017 .85627 L .56764 .86129 L p .707 .577 .707 r
F P
0 g
s
.50518 .73814 m .50183 .77641 L .51466 .77904 L p .707 .577 .707 r
F P
0 g
s
.54017 .85627 m .53923 .83854 L .51813 .83028 L p .707 .577 .707 r
F P
0 g
s
.50555 .73391 m .5032 .68024 L .50024 .66873 L p .707 .577 .707 r
F P
0 g
s
.51813 .83028 m .51906 .84802 L .54017 .85627 L p .707 .577 .707 r
F P
0 g
s
.68292 .82687 m .68386 .84461 L .70012 .83331 L p .707 .577 .707 r
F P
0 g
s
.70012 .83331 m .69919 .81558 L .68292 .82687 L p .707 .577 .707 r
F P
0 g
s
.69847 .75555 m .69513 .79382 L .70189 .79279 L p .707 .577 .707 r
F P
0 g
s
.70189 .79279 m .70523 .75452 L .69847 .75555 L p .707 .577 .707 r
F P
0 g
s
.70399 .66578 m .70634 .71945 L .70338 .70793 L p .707 .577 .707 r
F P
0 g
s
.70338 .70793 m .70103 .65427 L .70399 .66578 L p .707 .577 .707 r
F P
0 g
s
.51906 .84802 m .51813 .83028 L .50546 .81958 L p .707 .577 .707 r
F P
0 g
s
.50024 .66873 m .50259 .7224 L .50555 .73391 L p .707 .577 .707 r
F P
0 g
s
.50183 .77641 m .50518 .73814 L .50199 .73622 L p .707 .577 .707 r
F P
0 g
s
.50199 .73622 m .49864 .77448 L .50183 .77641 L p .707 .577 .707 r
F P
0 g
s
.50546 .81958 m .5064 .83732 L .51906 .84802 L p .707 .577 .707 r
F P
0 g
s
.48829 .82105 m .49149 .31708 L .44749 .31429 L p .707 .577 .707 r
F P
0 g
s
.50259 .7224 m .50024 .66873 L .50725 .65707 L p .707 .577 .707 r
F P
0 g
s
.5064 .83732 m .50546 .81958 L .50247 .8075 L p .707 .577 .707 r
F P
0 g
s
.50725 .65707 m .5096 .71074 L .50259 .7224 L p .707 .577 .707 r
F P
0 g
s
.50247 .8075 m .50341 .82524 L .5064 .83732 L p .707 .577 .707 r
F P
0 g
s
.49864 .77448 m .50199 .73622 L .50874 .73519 L p .707 .577 .707 r
F P
0 g
s
.50874 .73519 m .5054 .77346 L .49864 .77448 L p .707 .577 .707 r
F P
0 g
s
.5096 .71074 m .50725 .65707 L .52355 .64641 L p .707 .577 .707 r
F P
0 g
s
.50341 .82524 m .50247 .8075 L .50946 .79521 L p .707 .577 .707 r
F P
0 g
s
.52355 .64641 m .5259 .70008 L .5096 .71074 L p .707 .577 .707 r
F P
0 g
s
.50946 .79521 m .51039 .81295 L .50341 .82524 L p .707 .577 .707 r
F P
0 g
s
.5054 .77346 m .50874 .73519 L .52479 .73516 L p .707 .577 .707 r
F P
0 g
s
.52479 .73516 m .52144 .77342 L .5054 .77346 L p .707 .577 .707 r
F P
0 g
s
.51039 .81295 m .50946 .79521 L .52572 .78392 L p .707 .577 .707 r
F P
0 g
s
.52572 .78392 m .52666 .80166 L .51039 .81295 L p .707 .577 .707 r
F P
0 g
s
.52144 .77342 m .52479 .73516 L .54855 .73612 L p .707 .577 .707 r
F P
0 g
s
.54855 .73612 m .5452 .77439 L .52144 .77342 L p .707 .577 .707 r
F P
0 g
s
.52666 .80166 m .52572 .78392 L .54968 .77473 L p .707 .577 .707 r
F P
0 g
s
.54968 .77473 m .55062 .79247 L .52666 .80166 L p .707 .577 .707 r
F P
0 g
s
.49149 .31708 m .48829 .82105 L .53323 .82028 L p .707 .577 .707 r
F P
0 g
s
.5259 .70008 m .52355 .64641 L .54753 .63779 L p .707 .577 .707 r
F P
0 g
s
.54753 .63779 m .54989 .69146 L .5259 .70008 L p .707 .577 .707 r
F P
0 g
s
.53323 .82028 m .53644 .31631 L .49149 .31708 L p .707 .577 .707 r
F P
0 g
s
.69919 .81558 m .70012 .83331 L .70711 .82102 L p .707 .577 .707 r
F P
0 g
s
.70711 .82102 m .70617 .80329 L .69919 .81558 L p .707 .577 .707 r
F P
0 g
s
.54989 .69146 m .54753 .63779 L .57687 .63206 L p .707 .577 .707 r
F P
0 g
s
.57687 .63206 m .57922 .68572 L .54989 .69146 L p .707 .577 .707 r
F P
0 g
s
.5452 .77439 m .54855 .73612 L .57769 .738 L p .707 .577 .707 r
F P
0 g
s
.57769 .738 m .57435 .77627 L .5452 .77439 L p .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .57769 .738 L .58259 .7384 L p .707 .577 .707 r
F P
0 g
s
.58259 .7384 m .60938 .74059 L p .57818 .77236 L .707 .577 .707 r
F P
0 g
s
.57435 .77627 m .58259 .7384 L .57818 .77236 L .707 .577 .707 r
F
.63983 .63114 m .64218 .68481 L .61102 .68343 L p F P
0 g
s
.61102 .68343 m .60867 .62977 L .63983 .63114 L p .707 .577 .707 r
F P
0 g
s
.6405 .74365 m .63716 .78192 L .61154 .7794 L p .707 .577 .707 r
F P
0 g
s
.61154 .7794 m .60604 .77886 L p .61189 .77288 L .707 .577 .707 r
F P
0 g
s
.61189 .77288 m .6405 .74365 L .61154 .7794 L .707 .577 .707 r
F
.66801 .74689 m .66467 .78515 L .63716 .78192 L p F P
0 g
s
.63716 .78192 m .6405 .74365 L .66801 .74689 L p .707 .577 .707 r
F P
0 g
s
.60604 .77886 m .60938 .74059 L .6405 .74365 L p .707 .577 .707 r
F P
0 g
s
.64194 .76724 m .64288 .78497 L .61172 .7837 L p .707 .577 .707 r
F P
0 g
s
.61172 .7837 m .61078 .76596 L .64194 .76724 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .64177 .78791 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63498 .29503 m .63463 .35034 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.63463 .35034 m .63177 .799 L p .63551 .33386 L .707 .577 .707 r
F P
0 g
s
.60938 .74059 m .60604 .77886 L .57435 .77627 L p .707 .577 .707 r
F P
0 g
s
.57993 .78628 m .57899 .76854 L .61078 .76596 L p .707 .577 .707 r
F P
0 g
s
.61078 .76596 m .61172 .7837 L .57993 .78628 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .63177 .799 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.61187 .30472 m .61048 .52333 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.60867 .62977 m .61102 .68343 L .57922 .68572 L p .707 .577 .707 r
F P
0 g
s
.61048 .52333 m .60867 .80869 L p .61826 .46336 L .707 .577 .707 r
F P
0 g
s
.55062 .79247 m .54968 .77473 L .57899 .76854 L p .707 .577 .707 r
F P
0 g
s
.57899 .76854 m .57993 .78628 L .55062 .79247 L p .707 .577 .707 r
F P
0 g
s
.53644 .31631 m .53323 .82028 L .57471 .81602 L p .707 .577 .707 r
F P
0 g
s
.57471 .81602 m .57792 .31205 L .53644 .31631 L p .707 .577 .707 r
F P
0 g
s
.44428 .81826 m .44749 .31429 L .40872 .3082 L p .707 .577 .707 r
F P
0 g
s
.44749 .31429 m .44428 .81826 L .48829 .82105 L p .707 .577 .707 r
F P
0 g
s
.70523 .75452 m .70189 .79279 L .6987 .79087 L p .707 .577 .707 r
F P
0 g
s
.6987 .79087 m .70204 .7526 L .70523 .75452 L p .707 .577 .707 r
F P
0 g
s
.70103 .65427 m .70338 .70793 L .69074 .69769 L p .707 .577 .707 r
F P
0 g
s
.69074 .69769 m .68839 .64403 L .70103 .65427 L p .707 .577 .707 r
F P
0 g
s
.57922 .68572 m .57687 .63206 L .60867 .62977 L p .707 .577 .707 r
F P
0 g
s
.57792 .31205 m .57471 .81602 L .60867 .80869 L p .707 .577 .707 r
F P
0 g
s
.60867 .80869 m .61187 .30472 L .57792 .31205 L p .707 .577 .707 r
F P
0 g
s
.70617 .80329 m .70711 .82102 L .70412 .80894 L p .707 .577 .707 r
F P
0 g
s
.70412 .80894 m .70318 .7912 L .70617 .80329 L p .707 .577 .707 r
F P
0 g
s
.25255 .66793 m .22139 .66655 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25255 .66793 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25148 .7516 m .28317 .75419 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25148 .7516 L p .25615 .71704 L .707 .577 .707 r
F P
0 g
s
.25635 .71553 m .25464 .71552 L .25615 .71704 L .707 .577 .707 r
F
.25148 .7516 m .25464 .71552 L p .22588 .7135 L F P
0 g
s
.22036 .74854 m .25148 .7516 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22036 .74854 L p .22554 .71565 L .707 .577 .707 r
F P
0 g
s
.22588 .7135 m .22344 .71333 L .22554 .71565 L .707 .577 .707 r
F
.22139 .66655 m .19392 .66164 L p .21615 .70531 L F P
0 g
s
.21997 .71281 m .22344 .71333 L .21615 .70531 L .707 .577 .707 r
F
.22344 .71333 m .22139 .66655 L p .21615 .70531 L F P
0 g
s
.24584 .70672 m .23921 .70007 L .22374 .72022 L .707 .577 .707 r
F
.22211 .68295 m .22344 .71333 L p .23921 .70007 L F P
0 g
s
.22344 .71333 m .22374 .72022 L p .23921 .70007 L .707 .577 .707 r
F P
0 g
s
.22036 .74854 m .22344 .71333 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .22036 .74854 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19285 .74531 L p .19738 .71127 L .707 .577 .707 r
F P
0 g
s
.19761 .70947 m .19601 .70923 L .19738 .71127 L .707 .577 .707 r
F
.19392 .66164 m .17283 .65367 L p .1913 .70222 L F P
0 g
s
.17283 .65367 m .16019 .64343 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17778 .70436 m .17499 .70396 L p .19601 .70923 L .707 .577 .707 r
F P
0 g
s
.17499 .70396 m .17165 .74222 L .19048 .74496 L p .707 .577 .707 r
F P
0 g
s
.19048 .74496 m .19285 .74531 L p .17613 .70659 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17499 .70396 L .19048 .74496 L .707 .577 .707 r
F
.17165 .74222 m .17499 .70396 L .16217 .70132 L p F P
0 g
s
.16254 .6971 m .17518 .70734 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16019 .64343 m .16121 .66667 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.16121 .66667 m .16254 .6971 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17518 .70734 m .17502 .70362 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.17502 .70362 m .17283 .65367 L p .17312 .69854 L .707 .577 .707 r
F P
0 g
s
.19285 .74531 m .19601 .70923 L p .17516 .704 L .707 .577 .707 r
F P
0 g
s
.17613 .70659 m .17516 .704 L .17499 .70396 L .707 .577 .707 r
F
.19285 .74531 m .17516 .704 L .17613 .70659 L F
.19373 .70862 m .19601 .70923 L .1913 .70222 L F
.19601 .70923 m .19392 .66164 L p .1913 .70222 L F P
0 g
s
.19392 .66164 m .19601 .70923 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.17283 .65367 m .17518 .70734 L .19627 .7153 L p .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .1962 .70704 L .17778 .70436 L p .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .19601 .70923 L p .19373 .70862 L .707 .577 .707 r
F P
0 g
s
.19627 .7153 m .22374 .72022 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.19601 .70923 m .19627 .7153 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.1962 .70704 m .19601 .70923 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .1962 .70704 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22344 .71333 m .22371 .71027 L p .19761 .70947 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .22344 .71333 L p .21997 .71281 L .707 .577 .707 r
F P
0 g
s
.22371 .71027 m .22344 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.22374 .72022 m .2549 .7216 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.25105 .71527 m .24584 .70672 L .23382 .71406 L .707 .577 .707 r
F
.25105 .71527 m .23382 .71406 L .22374 .72022 L F
.22139 .66655 m .22211 .68295 L p .24584 .70672 L F P
0 g
s
.25255 .66793 m .25464 .71552 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28651 .71593 L .28235 .71558 L p .707 .577 .707 r
F P
0 g
s
.28235 .71558 m .25483 .71333 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.28317 .75419 m .28235 .71558 L .25635 .71553 L .707 .577 .707 r
F
.28435 .66564 m .25255 .66793 L p .28423 .71559 L F P
0 g
s
.28651 .71593 m .28317 .75419 L .31232 .75607 L p .707 .577 .707 r
F P
0 g
s
.31232 .75607 m .31566 .7178 L .28651 .71593 L p .707 .577 .707 r
F P
0 g
s
.28671 .71931 m .28654 .71559 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.28654 .71559 m .28435 .66564 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .28671 .71931 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .2549 .7216 L p .28423 .71559 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .25464 .71552 L p .25635 .71553 L .707 .577 .707 r
F P
0 g
s
.25483 .71333 m .22371 .71027 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.25464 .71552 m .25483 .71333 L p .22588 .7135 L .707 .577 .707 r
F P
0 g
s
.2549 .7216 m .25464 .71552 L p .25105 .71527 L .707 .577 .707 r
F P
0 g
s
.40552 .81217 m .40872 .3082 L .379 .29941 L p .707 .577 .707 r
F P
0 g
s
.40872 .3082 m .40552 .81217 L .44428 .81826 L p .707 .577 .707 r
F P
0 g
s
.28435 .66564 m .28671 .71931 L .31604 .71357 L p .707 .577 .707 r
F P
0 g
s
.31604 .71357 m .31368 .6599 L .28435 .66564 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68839 .64403 m .69074 .69769 L .66965 .68973 L p .707 .577 .707 r
F P
0 g
s
.66965 .68973 m .6673 .63606 L .68839 .64403 L p .707 .577 .707 r
F P
0 g
s
.31368 .6599 m .31604 .71357 L .34003 .70495 L p .707 .577 .707 r
F P
0 g
s
.34003 .70495 m .33767 .65128 L .31368 .6599 L p .707 .577 .707 r
F P
0 g
s
.70204 .7526 m .6987 .79087 L .68587 .78824 L p .707 .577 .707 r
F P
0 g
s
.68587 .78824 m .68922 .74997 L .70204 .7526 L p .707 .577 .707 r
F P
0 g
s
.63177 .799 m .63498 .29503 L .61187 .30472 L p .707 .577 .707 r
F P
0 g
s
.70318 .7912 m .70412 .80894 L .69145 .79825 L p .707 .577 .707 r
F P
0 g
s
.69145 .79825 m .69052 .78051 L .70318 .7912 L p .707 .577 .707 r
F P
0 g
s
.33767 .65128 m .34003 .70495 L .35632 .69429 L p .707 .577 .707 r
F P
0 g
s
.35632 .69429 m .35397 .64062 L .33767 .65128 L p .707 .577 .707 r
F P
0 g
s
.37579 .80339 m .379 .29941 L .36122 .2888 L p .707 .577 .707 r
F P
0 g
s
.379 .29941 m .37579 .80339 L .40552 .81217 L p .707 .577 .707 r
F P
0 g
s
.6673 .63606 m .66965 .68973 L .64218 .68481 L p .707 .577 .707 r
F P
0 g
s
.64218 .68481 m .63983 .63114 L .6673 .63606 L p .707 .577 .707 r
F P
0 g
s
.31566 .7178 m .31232 .75607 L .33608 .75704 L p .707 .577 .707 r
F P
0 g
s
.33608 .75704 m .33942 .71877 L .31566 .7178 L p .707 .577 .707 r
F P
0 g
s
.68922 .74997 m .68587 .78824 L .66467 .78515 L p .707 .577 .707 r
F P
0 g
s
.66467 .78515 m .66801 .74689 L .68922 .74997 L p .707 .577 .707 r
F P
0 g
s
.25579 .82575 m .25485 .80801 L .22369 .80674 L p .707 .577 .707 r
F P
0 g
s
.25485 .80801 m .25579 .82575 L .28758 .82317 L p .707 .577 .707 r
F P
0 g
s
.28758 .82317 m .28664 .80543 L .25485 .80801 L p .707 .577 .707 r
F P
0 g
s
.28664 .80543 m .28758 .82317 L .31689 .81698 L p .707 .577 .707 r
F P
0 g
s
.31689 .81698 m .31595 .79924 L .28664 .80543 L p .707 .577 .707 r
F P
0 g
s
.22463 .82447 m .22369 .80674 L .19622 .80172 L p .707 .577 .707 r
F P
0 g
s
.22369 .80674 m .22463 .82447 L .25579 .82575 L p .707 .577 .707 r
F P
0 g
s
.69052 .78051 m .69145 .79825 L .67035 .78999 L p .707 .577 .707 r
F P
0 g
s
.67035 .78999 m .66941 .77225 L .69052 .78051 L p .707 .577 .707 r
F P
0 g
s
.33942 .71877 m .33608 .75704 L .35212 .757 L p .707 .577 .707 r
F P
0 g
s
.35212 .757 m .35547 .71874 L .33942 .71877 L p .707 .577 .707 r
F P
0 g
s
.64177 .78791 m .64498 .28394 L .63498 .29503 L p .707 .577 .707 r
F P
0 g
s
.35397 .64062 m .35632 .69429 L .36334 .68263 L p .707 .577 .707 r
F P
0 g
s
.36334 .68263 m .36098 .62896 L .35397 .64062 L p .707 .577 .707 r
F P
0 g
s
.31595 .79924 m .31689 .81698 L .34085 .80779 L p .707 .577 .707 r
F P
0 g
s
.34085 .80779 m .33991 .79005 L .31595 .79924 L p .707 .577 .707 r
F P
0 g
s
.19622 .80172 m .19716 .81946 L .22463 .82447 L p .707 .577 .707 r
F P
0 g
s
.16217 .70132 m .15882 .73959 L .17165 .74222 L p .707 .577 .707 r
F P
0 g
s
.19716 .81946 m .19622 .80172 L .17512 .79346 L p .707 .577 .707 r
F P
0 g
s
.16254 .6971 m .16019 .64343 L .15723 .63192 L p .707 .577 .707 r
F P
0 g
s
.35547 .71874 m .35212 .757 L .35888 .75598 L p .707 .577 .707 r
F P
0 g
s
.35888 .75598 m .36222 .71771 L .35547 .71874 L p .707 .577 .707 r
F P
0 g
s
.36038 .67112 m .35802 .61745 L .36098 .62896 L p .707 .577 .707 r
F P
0 g
s
.35618 .77876 m .35712 .7965 L .3641 .78421 L p .707 .577 .707 r
F P
0 g
s
.3641 .78421 m .36316 .76647 L .35618 .77876 L p .707 .577 .707 r
F P
0 g
s
.36222 .71771 m .35888 .75598 L .35569 .75405 L p .707 .577 .707 r
F P
0 g
s
.35569 .75405 m .35903 .71578 L .36222 .71771 L p .707 .577 .707 r
F P
0 g
s
.35802 .61745 m .36038 .67112 L .34773 .66088 L p .707 .577 .707 r
F P
0 g
s
.34773 .66088 m .34538 .60721 L .35802 .61745 L p .707 .577 .707 r
F P
0 g
s
.35903 .71578 m .35569 .75405 L .34286 .75142 L p .707 .577 .707 r
F P
0 g
s
.34286 .75142 m .34621 .71315 L .35903 .71578 L p .707 .577 .707 r
F P
0 g
s
.36017 .75439 m .36111 .77213 L .34844 .76143 L p .707 .577 .707 r
F P
0 g
s
.34844 .76143 m .34751 .74369 L .36017 .75439 L p .707 .577 .707 r
F P
0 g
s
.35801 .79277 m .36122 .2888 L .35713 .27738 L p .707 .577 .707 r
F P
0 g
s
.36098 .62896 m .36334 .68263 L .36038 .67112 L p .707 .577 .707 r
F P
0 g
s
.36316 .76647 m .3641 .78421 L .36111 .77213 L p .707 .577 .707 r
F P
0 g
s
.36111 .77213 m .36017 .75439 L .36316 .76647 L p .707 .577 .707 r
F P
0 g
s
.36122 .2888 m .35801 .79277 L .37579 .80339 L p .707 .577 .707 r
F P
0 g
s
.17512 .79346 m .17606 .8112 L .19716 .81946 L p .707 .577 .707 r
F P
0 g
s
.33991 .79005 m .34085 .80779 L .35712 .7965 L p .707 .577 .707 r
F P
0 g
s
.35712 .7965 m .35618 .77876 L .33991 .79005 L p .707 .577 .707 r
F P
0 g
s
.66941 .77225 m .67035 .78999 L .64288 .78497 L p .707 .577 .707 r
F P
0 g
s
.64288 .78497 m .64194 .76724 L .66941 .77225 L p .707 .577 .707 r
F P
0 g
s
.17606 .8112 m .17512 .79346 L .16245 .78277 L p .707 .577 .707 r
F P
0 g
s
.15723 .63192 m .15958 .68558 L .16254 .6971 L p .707 .577 .707 r
F P
0 g
s
.15882 .73959 m .16217 .70132 L .15898 .6994 L p .707 .577 .707 r
F P
0 g
s
.15898 .6994 m .15563 .73767 L .15882 .73959 L p .707 .577 .707 r
F P
0 g
s
.16245 .78277 m .16339 .80051 L .17606 .8112 L p .707 .577 .707 r
F P
0 g
s
.64498 .28394 m .64177 .78791 L .63768 .77649 L p .707 .577 .707 r
F P
0 g
s
.63768 .77649 m .64089 .27252 L .64498 .28394 L p .707 .577 .707 r
F P
0 g
s
.15958 .68558 m .15723 .63192 L .16424 .62026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16339 .80051 m .16245 .78277 L .15946 .77069 L p .707 .577 .707 r
F P
0 g
s
.35713 .27738 m .35392 .78135 L .35801 .79277 L p .707 .577 .707 r
F P
0 g
s
.35392 .78135 m .35713 .27738 L .36712 .26628 L p .707 .577 .707 r
F P
0 g
s
.16424 .62026 m .16659 .67393 L .15958 .68558 L p .707 .577 .707 r
F P
0 g
s
.15946 .77069 m .1604 .78842 L .16339 .80051 L p .707 .577 .707 r
F P
0 g
s
.15563 .73767 m .15898 .6994 L .16573 .69837 L p .707 .577 .707 r
F P
0 g
s
.16573 .69837 m .16239 .73664 L .15563 .73767 L p .707 .577 .707 r
F P
0 g
s
.16659 .67393 m .16424 .62026 L .18054 .6096 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64089 .27252 m .63768 .77649 L .6199 .76587 L p .707 .577 .707 r
F P
0 g
s
.6199 .76587 m .62311 .2619 L .64089 .27252 L p .707 .577 .707 r
F P
0 g
s
.34538 .60721 m .34773 .66088 L .32664 .65291 L p .707 .577 .707 r
F P
0 g
s
.32664 .65291 m .32429 .59924 L .34538 .60721 L p .707 .577 .707 r
F P
0 g
s
.1604 .78842 m .15946 .77069 L .16645 .7584 L p .707 .577 .707 r
F P
0 g
s
.18054 .6096 m .18289 .66326 L .16659 .67393 L p .707 .577 .707 r
F P
0 g
s
.16645 .7584 m .16738 .77613 L .1604 .78842 L p .707 .577 .707 r
F P
0 g
s
.18289 .66326 m .18054 .6096 L .20453 .60098 L p .707 .577 .707 r
F P
0 g
s
.16239 .73664 m .16573 .69837 L .18178 .69834 L p .707 .577 .707 r
F P
0 g
s
.18178 .69834 m .17843 .73661 L .16239 .73664 L p .707 .577 .707 r
F P
0 g
s
.36392 .77025 m .36712 .26628 L .39023 .25659 L p .707 .577 .707 r
F P
0 g
s
.36712 .26628 m .36392 .77025 L .35392 .78135 L p .707 .577 .707 r
F P
0 g
s
.32429 .59924 m .32664 .65291 L .29917 .648 L p .707 .577 .707 r
F P
0 g
s
.29917 .648 m .29682 .59433 L .32429 .59924 L p .707 .577 .707 r
F P
0 g
s
.16738 .77613 m .16645 .7584 L .18271 .7471 L p .707 .577 .707 r
F P
0 g
s
.20688 .65464 m .20453 .60098 L .23386 .59524 L p .707 .577 .707 r
F P
0 g
s
.20453 .60098 m .20688 .65464 L .18289 .66326 L p .707 .577 .707 r
F P
0 g
s
.34621 .71315 m .34286 .75142 L .32166 .74834 L p .707 .577 .707 r
F P
0 g
s
.32166 .74834 m .325 .71007 L .34621 .71315 L p .707 .577 .707 r
F P
0 g
s
.29682 .59433 m .29917 .648 L .26801 .64662 L p .707 .577 .707 r
F P
0 g
s
.26801 .64662 m .26566 .59295 L .29682 .59433 L p .707 .577 .707 r
F P
0 g
s
.18271 .7471 m .18365 .76484 L .16738 .77613 L p .707 .577 .707 r
F P
0 g
s
.62311 .2619 m .6199 .76587 L .59017 .75709 L p .707 .577 .707 r
F P
0 g
s
.59017 .75709 m .59338 .25312 L .62311 .2619 L p .707 .577 .707 r
F P
0 g
s
.17843 .73661 m .18178 .69834 L .20554 .69931 L p .707 .577 .707 r
F P
0 g
s
.20554 .69931 m .20219 .73758 L .17843 .73661 L p .707 .577 .707 r
F P
0 g
s
.23621 .64891 m .23386 .59524 L .26566 .59295 L p .707 .577 .707 r
F P
0 g
s
.23386 .59524 m .23621 .64891 L .20688 .65464 L p .707 .577 .707 r
F P
0 g
s
.34751 .74369 m .34844 .76143 L .32734 .75317 L p .707 .577 .707 r
F P
0 g
s
.32734 .75317 m .3264 .73544 L .34751 .74369 L p .707 .577 .707 r
F P
0 g
s
.26566 .59295 m .26801 .64662 L .23621 .64891 L p .707 .577 .707 r
F P
0 g
s
.39023 .25659 m .38702 .76057 L .36392 .77025 L p .707 .577 .707 r
F P
0 g
s
.38702 .76057 m .39023 .25659 L .42418 .24926 L p .707 .577 .707 r
F P
0 g
s
.73276 .61271 m .7016 .61133 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73276 .61271 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.7317 .69661 m .76338 .69921 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .7317 .69661 L p .73631 .66192 L .707 .577 .707 r
F P
0 g
s
.73651 .66046 m .73486 .66046 L .73631 .66192 L .707 .577 .707 r
F
.7317 .69661 m .73486 .66046 L p .70604 .65843 L F P
0 g
s
.70058 .69355 m .7317 .69661 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70058 .69355 L p .70571 .66052 L .707 .577 .707 r
F P
0 g
s
.70604 .65843 m .70366 .65827 L .70571 .66052 L .707 .577 .707 r
F
.7016 .61133 m .67413 .60641 L p .69654 .65043 L F P
0 g
s
.70027 .65776 m .70366 .65827 L .69654 .65043 L .707 .577 .707 r
F
.70366 .65827 m .7016 .61133 L p .69654 .65043 L F P
0 g
s
.72629 .65188 m .71943 .64501 L .70395 .66499 L .707 .577 .707 r
F
.70233 .62788 m .70366 .65827 L p .71943 .64501 L F P
0 g
s
.70366 .65827 m .70395 .66499 L p .71943 .64501 L .707 .577 .707 r
F P
0 g
s
.70058 .69355 m .70366 .65827 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .70058 .69355 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67307 .69032 L p .67755 .65613 L .707 .577 .707 r
F P
0 g
s
.67778 .6544 m .67623 .65417 L .67755 .65613 L .707 .577 .707 r
F
.67413 .60641 m .65304 .59844 L p .67164 .64734 L F P
0 g
s
.65304 .59844 m .6404 .5882 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65866 .64947 m .6552 .64897 L p .67623 .65417 L .707 .577 .707 r
F P
0 g
s
.6552 .64897 m .65186 .68724 L .67073 .68998 L p .707 .577 .707 r
F P
0 g
s
.67073 .68998 m .67307 .69032 L p .65662 .65224 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .6552 .64897 L .67073 .68998 L .707 .577 .707 r
F
.65186 .68724 m .6552 .64897 L .64238 .64634 L p F P
0 g
s
.64275 .64187 m .6554 .65211 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6404 .5882 m .64143 .61161 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.64143 .61161 m .64275 .64187 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.6554 .65211 m .65524 .64856 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.65524 .64856 m .65304 .59844 L p .65342 .64369 L .707 .577 .707 r
F P
0 g
s
.67307 .69032 m .67623 .65417 L p .65541 .64902 L .707 .577 .707 r
F P
0 g
s
.65662 .65224 m .65541 .64902 L .6552 .64897 L .707 .577 .707 r
F
.67307 .69032 m .65541 .64902 L .65662 .65224 L F
.67401 .65357 m .67623 .65417 L .67164 .64734 L F
.67623 .65417 m .67413 .60641 L p .67164 .64734 L F P
0 g
s
.67413 .60641 m .67623 .65417 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.65304 .59844 m .6554 .65211 L .67648 .66008 L p .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67641 .65205 L .65866 .64947 L p .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .67623 .65417 L p .67401 .65357 L .707 .577 .707 r
F P
0 g
s
.67648 .66008 m .70395 .66499 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67623 .65417 m .67648 .66008 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.67641 .65205 m .67623 .65417 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .67641 .65205 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70366 .65827 m .70392 .65528 L p .67778 .6544 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .70366 .65827 L p .70027 .65776 L .707 .577 .707 r
F P
0 g
s
.70392 .65528 m .70366 .65827 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.70395 .66499 m .73512 .66637 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.73137 .66021 m .72629 .65188 L .71416 .659 L .707 .577 .707 r
F
.73137 .66021 m .71416 .659 L .70395 .66499 L F
.7016 .61133 m .70233 .62788 L p .72629 .65188 L F P
0 g
s
.73276 .61271 m .73486 .66046 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76673 .66094 L .76156 .66052 L p .707 .577 .707 r
F P
0 g
s
.76156 .66052 m .73504 .65835 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.76338 .69921 m .76156 .66052 L .73651 .66046 L .707 .577 .707 r
F
.76456 .61041 m .73276 .61271 L p .76455 .66052 L F P
0 g
s
.76673 .66094 m .76338 .69921 L .79253 .70108 L p .707 .577 .707 r
F P
0 g
s
.79253 .70108 m .79588 .66281 L .76673 .66094 L p .707 .577 .707 r
F P
0 g
s
.76692 .66408 m .76676 .66053 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.76676 .66053 m .76456 .61041 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .76692 .66408 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73512 .66637 L p .76455 .66052 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .73486 .66046 L p .73651 .66046 L .707 .577 .707 r
F P
0 g
s
.73504 .65835 m .70392 .65528 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73486 .66046 m .73504 .65835 L p .70604 .65843 L .707 .577 .707 r
F P
0 g
s
.73512 .66637 m .73486 .66046 L p .73137 .66021 L .707 .577 .707 r
F P
0 g
s
.325 .71007 m .32166 .74834 L .29415 .74511 L p .707 .577 .707 r
F P
0 g
s
.29415 .74511 m .29749 .70684 L .325 .71007 L p .707 .577 .707 r
F P
0 g
s
.76456 .61041 m .76692 .66408 L .79625 .65835 L p .707 .577 .707 r
F P
0 g
s
.79625 .65835 m .7939 .60468 L .76456 .61041 L p .707 .577 .707 r
F P
0 g
s
.18365 .76484 m .18271 .7471 L .20667 .73791 L p .707 .577 .707 r
F P
0 g
s
.20219 .73758 m .20554 .69931 L .23468 .70118 L p .707 .577 .707 r
F P
0 g
s
.23468 .70118 m .23134 .73945 L .20219 .73758 L p .707 .577 .707 r
F P
0 g
s
.20667 .73791 m .20761 .75565 L .18365 .76484 L p .707 .577 .707 r
F P
0 g
s
.3264 .73544 m .32734 .75317 L .29987 .74816 L p .707 .577 .707 r
F P
0 g
s
.29987 .74816 m .29893 .73042 L .3264 .73544 L p .707 .577 .707 r
F P
0 g
s
.7939 .60468 m .79625 .65835 L .82024 .64973 L p .707 .577 .707 r
F P
0 g
s
.82024 .64973 m .81789 .59606 L .7939 .60468 L p .707 .577 .707 r
F P
0 g
s
.29749 .70684 m .29415 .74511 L .26303 .74205 L p .707 .577 .707 r
F P
0 g
s
.26303 .74205 m .26637 .70378 L .29749 .70684 L p .707 .577 .707 r
F P
0 g
s
.59338 .25312 m .59017 .75709 L .55141 .751 L p .707 .577 .707 r
F P
0 g
s
.55141 .751 m .55462 .24703 L .59338 .25312 L p .707 .577 .707 r
F P
0 g
s
.23134 .73945 m .23468 .70118 L .26637 .70378 L p .707 .577 .707 r
F P
0 g
s
.20761 .75565 m .20667 .73791 L .23598 .73172 L p .707 .577 .707 r
F P
0 g
s
.26637 .70378 m .26303 .74205 L .23134 .73945 L p .707 .577 .707 r
F P
0 g
s
.29893 .73042 m .29987 .74816 L .26871 .74688 L p .707 .577 .707 r
F P
0 g
s
.26871 .74688 m .26777 .72914 L .29893 .73042 L p .707 .577 .707 r
F P
0 g
s
.42098 .75323 m .42418 .24926 L .46566 .245 L p .707 .577 .707 r
F P
0 g
s
.42418 .24926 m .42098 .75323 L .38702 .76057 L p .707 .577 .707 r
F P
0 g
s
.23598 .73172 m .23692 .74946 L .20761 .75565 L p .707 .577 .707 r
F P
0 g
s
.23692 .74946 m .23598 .73172 L .26777 .72914 L p .707 .577 .707 r
F P
0 g
s
.81789 .59606 m .82024 .64973 L .83654 .63907 L p .707 .577 .707 r
F P
0 g
s
.83654 .63907 m .83418 .5854 L .81789 .59606 L p .707 .577 .707 r
F P
0 g
s
.26777 .72914 m .26871 .74688 L .23692 .74946 L p .707 .577 .707 r
F P
0 g
s
.79588 .66281 m .79253 .70108 L .81629 .70205 L p .707 .577 .707 r
F P
0 g
s
.81629 .70205 m .81964 .66378 L .79588 .66281 L p .707 .577 .707 r
F P
0 g
s
.55462 .24703 m .55141 .751 L .5074 .7482 L p .707 .577 .707 r
F P
0 g
s
.5074 .7482 m .51061 .24423 L .55462 .24703 L p .707 .577 .707 r
F P
0 g
s
.736 .76962 m .73506 .75188 L .70391 .7506 L p .707 .577 .707 r
F P
0 g
s
.73506 .75188 m .736 .76962 L .76779 .76704 L p .707 .577 .707 r
F P
0 g
s
.76779 .76704 m .76685 .7493 L .73506 .75188 L p .707 .577 .707 r
F P
0 g
s
.46246 .74897 m .46566 .245 L .51061 .24423 L p .707 .577 .707 r
F P
0 g
s
.46566 .245 m .46246 .74897 L .42098 .75323 L p .707 .577 .707 r
F P
0 g
s
.76685 .7493 m .76779 .76704 L .7971 .76085 L p .707 .577 .707 r
F P
0 g
s
.7971 .76085 m .79616 .74311 L .76685 .7493 L p .707 .577 .707 r
F P
0 g
s
.51061 .24423 m .5074 .7482 L .46246 .74897 L p .707 .577 .707 r
F P
0 g
s
.70485 .76834 m .70391 .7506 L .67643 .74559 L p .707 .577 .707 r
F P
0 g
s
.70391 .7506 m .70485 .76834 L .736 .76962 L p .707 .577 .707 r
F P
0 g
s
.81964 .66378 m .81629 .70205 L .83234 .70202 L p .707 .577 .707 r
F P
0 g
s
.83234 .70202 m .83568 .66375 L .81964 .66378 L p .707 .577 .707 r
F P
0 g
s
.79616 .74311 m .7971 .76085 L .82106 .75166 L p .707 .577 .707 r
F P
0 g
s
.82106 .75166 m .82012 .73392 L .79616 .74311 L p .707 .577 .707 r
F P
0 g
s
.83418 .5854 m .83654 .63907 L .84355 .62741 L p .707 .577 .707 r
F P
0 g
s
.84355 .62741 m .8412 .57374 L .83418 .5854 L p .707 .577 .707 r
F P
0 g
s
.67643 .74559 m .67737 .76332 L .70485 .76834 L p .707 .577 .707 r
F P
0 g
s
.64238 .64634 m .63904 .68461 L .65186 .68724 L p .707 .577 .707 r
F P
0 g
s
.67737 .76332 m .67643 .74559 L .65533 .73733 L p .707 .577 .707 r
F P
0 g
s
.64275 .64187 m .6404 .5882 L .63744 .57669 L p .707 .577 .707 r
F P
0 g
s
.65533 .73733 m .65627 .75507 L .67737 .76332 L p .707 .577 .707 r
F P
0 g
s
.82012 .73392 m .82106 .75166 L .83733 .74036 L p .707 .577 .707 r
F P
0 g
s
.83733 .74036 m .83639 .72263 L .82012 .73392 L p .707 .577 .707 r
F P
0 g
s
.83568 .66375 m .83234 .70202 L .83909 .70099 L p .707 .577 .707 r
F P
0 g
s
.83909 .70099 m .84244 .66272 L .83568 .66375 L p .707 .577 .707 r
F P
0 g
s
.8412 .57374 m .84355 .62741 L .84059 .6159 L p .707 .577 .707 r
F P
0 g
s
.84059 .6159 m .83824 .56223 L .8412 .57374 L p .707 .577 .707 r
F P
0 g
s
.65627 .75507 m .65533 .73733 L .64267 .72663 L p .707 .577 .707 r
F P
0 g
s
.63744 .57669 m .63979 .63036 L .64275 .64187 L p .707 .577 .707 r
F P
0 g
s
.63904 .68461 m .64238 .64634 L .63919 .64441 L p .707 .577 .707 r
F P
0 g
s
.63919 .64441 m .63585 .68268 L .63904 .68461 L p .707 .577 .707 r
F P
0 g
s
.64267 .72663 m .6436 .74437 L .65627 .75507 L p .707 .577 .707 r
F P
0 g
s
.83639 .72263 m .83733 .74036 L .84431 .72807 L p .707 .577 .707 r
F P
0 g
s
.84431 .72807 m .84337 .71034 L .83639 .72263 L p .707 .577 .707 r
F P
0 g
s
.63979 .63036 m .63744 .57669 L .64445 .56503 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84244 .66272 m .83909 .70099 L .8359 .69907 L p .707 .577 .707 r
F P
0 g
s
.8359 .69907 m .83925 .6608 L .84244 .66272 L p .707 .577 .707 r
F P
0 g
s
.83824 .56223 m .84059 .6159 L .82795 .60565 L p .707 .577 .707 r
F P
0 g
s
.82795 .60565 m .82559 .55199 L .83824 .56223 L p .707 .577 .707 r
F P
0 g
s
.6436 .74437 m .64267 .72663 L .63968 .71455 L p .707 .577 .707 r
F P
0 g
s
.64445 .56503 m .64681 .6187 L .63979 .63036 L p .707 .577 .707 r
F P
0 g
s
.63968 .71455 m .64062 .73229 L .6436 .74437 L p .707 .577 .707 r
F P
0 g
s
.63585 .68268 m .63919 .64441 L .64595 .64339 L p .707 .577 .707 r
F P
0 g
s
.64595 .64339 m .6426 .68166 L .63585 .68268 L p .707 .577 .707 r
F P
0 g
s
.84337 .71034 m .84431 .72807 L .84132 .71599 L p .707 .577 .707 r
F P
0 g
s
.84132 .71599 m .84039 .69825 L .84337 .71034 L p .707 .577 .707 r
F P
0 g
s
.64681 .6187 m .64445 .56503 L .66075 .55437 L p .707 .577 .707 r
F P
0 g
s
.38975 .57589 m .35859 .57451 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38975 .57589 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38869 .6598 m .42037 .66239 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .38869 .6598 L p .3933 .6251 L .707 .577 .707 r
F P
0 g
s
.3935 .62365 m .39185 .62364 L .3933 .6251 L .707 .577 .707 r
F
.38869 .6598 m .39185 .62364 L p .36303 .62162 L F P
0 g
s
.35757 .65674 m .38869 .6598 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .35757 .65674 L p .3627 .62371 L .707 .577 .707 r
F P
0 g
s
.36303 .62162 m .36065 .62145 L .3627 .62371 L .707 .577 .707 r
F
.35859 .57451 m .33112 .5696 L p .35353 .61362 L F P
0 g
s
.35726 .62094 m .36065 .62145 L .35353 .61362 L .707 .577 .707 r
F
.36065 .62145 m .35859 .57451 L p .35353 .61362 L F P
0 g
s
.38328 .61507 m .37642 .60819 L .36094 .62818 L .707 .577 .707 r
F
.35932 .59106 m .36065 .62145 L p .37642 .60819 L F P
0 g
s
.36065 .62145 m .36094 .62818 L p .37642 .60819 L .707 .577 .707 r
F P
0 g
s
.35757 .65674 m .36065 .62145 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .35757 .65674 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33006 .65351 L p .33454 .61932 L .707 .577 .707 r
F P
0 g
s
.33477 .61758 m .33322 .61735 L .33454 .61932 L .707 .577 .707 r
F
.33112 .5696 m .31003 .56163 L p .32863 .61053 L F P
0 g
s
.31003 .56163 m .29739 .55139 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31565 .61266 m .31219 .61216 L p .33322 .61735 L .707 .577 .707 r
F P
0 g
s
.31219 .61216 m .30885 .65042 L .32772 .65317 L p .707 .577 .707 r
F P
0 g
s
.32772 .65317 m .33006 .65351 L p .31361 .61542 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .31219 .61216 L .32772 .65317 L .707 .577 .707 r
F
.30885 .65042 m .31219 .61216 L .29937 .60952 L p F P
0 g
s
.29974 .60506 m .31239 .6153 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29739 .55139 m .29842 .57479 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.29842 .57479 m .29974 .60506 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31239 .6153 m .31223 .61174 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.31223 .61174 m .31003 .56163 L p .31041 .60687 L .707 .577 .707 r
F P
0 g
s
.33006 .65351 m .33322 .61735 L p .3124 .61221 L .707 .577 .707 r
F P
0 g
s
.31361 .61542 m .3124 .61221 L .31219 .61216 L .707 .577 .707 r
F
.33006 .65351 m .3124 .61221 L .31361 .61542 L F
.331 .61676 m .33322 .61735 L .32863 .61053 L F
.33322 .61735 m .33112 .5696 L p .32863 .61053 L F P
0 g
s
.33112 .5696 m .33322 .61735 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.31003 .56163 m .31239 .6153 L .33347 .62326 L p .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .3334 .61524 L .31565 .61266 L p .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .33322 .61735 L p .331 .61676 L .707 .577 .707 r
F P
0 g
s
.33347 .62326 m .36094 .62818 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.33322 .61735 m .33347 .62326 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.3334 .61524 m .33322 .61735 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .3334 .61524 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36065 .62145 m .36091 .61847 L p .33477 .61758 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .36065 .62145 L p .35726 .62094 L .707 .577 .707 r
F P
0 g
s
.36091 .61847 m .36065 .62145 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.36094 .62818 m .39211 .62956 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.38836 .6234 m .38328 .61507 L .37115 .62219 L .707 .577 .707 r
F
.38836 .6234 m .37115 .62219 L .36094 .62818 L F
.35859 .57451 m .35932 .59106 L p .38328 .61507 L F P
0 g
s
.38975 .57589 m .39185 .62364 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .42372 .62412 L .41855 .6237 L p .707 .577 .707 r
F P
0 g
s
.41855 .6237 m .39203 .62153 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.42037 .66239 m .41855 .6237 L .3935 .62365 L .707 .577 .707 r
F
.42156 .5736 m .38975 .57589 L p .42154 .62371 L F P
0 g
s
.42372 .62412 m .42037 .66239 L .44952 .66427 L p .707 .577 .707 r
F P
0 g
s
.44952 .66427 m .45287 .626 L .42372 .62412 L p .707 .577 .707 r
F P
0 g
s
.42391 .62727 m .42375 .62371 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.42375 .62371 m .42156 .5736 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .42391 .62727 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39211 .62956 L p .42154 .62371 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .39185 .62364 L p .3935 .62365 L .707 .577 .707 r
F P
0 g
s
.39203 .62153 m .36091 .61847 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39185 .62364 m .39203 .62153 L p .36303 .62162 L .707 .577 .707 r
F P
0 g
s
.39211 .62956 m .39185 .62364 L p .38836 .6234 L .707 .577 .707 r
F P
0 g
s
.42156 .5736 m .42391 .62727 L .45324 .62153 L p .707 .577 .707 r
F P
0 g
s
.45324 .62153 m .45089 .56786 L .42156 .5736 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.82559 .55199 m .82795 .60565 L .80686 .59769 L p .707 .577 .707 r
F P
0 g
s
.80686 .59769 m .8045 .54402 L .82559 .55199 L p .707 .577 .707 r
F P
0 g
s
.45089 .56786 m .45324 .62153 L .47723 .61291 L p .707 .577 .707 r
F P
0 g
s
.47723 .61291 m .47488 .55924 L .45089 .56786 L p .707 .577 .707 r
F P
0 g
s
.64062 .73229 m .63968 .71455 L .64666 .70226 L p .707 .577 .707 r
F P
0 g
s
.83925 .6608 m .8359 .69907 L .82308 .69644 L p .707 .577 .707 r
F P
0 g
s
.82308 .69644 m .82642 .65817 L .83925 .6608 L p .707 .577 .707 r
F P
0 g
s
.66075 .55437 m .6631 .60804 L .64681 .6187 L p .707 .577 .707 r
F P
0 g
s
.64666 .70226 m .6476 .72 L .64062 .73229 L p .707 .577 .707 r
F P
0 g
s
.6631 .60804 m .66075 .55437 L .68474 .54575 L p .707 .577 .707 r
F P
0 g
s
.6426 .68166 m .64595 .64339 L .66199 .64336 L p .707 .577 .707 r
F P
0 g
s
.66199 .64336 m .65865 .68162 L .6426 .68166 L p .707 .577 .707 r
F P
0 g
s
.84039 .69825 m .84132 .71599 L .82866 .7053 L p .707 .577 .707 r
F P
0 g
s
.82866 .7053 m .82772 .68756 L .84039 .69825 L p .707 .577 .707 r
F P
0 g
s
.47488 .55924 m .47723 .61291 L .49353 .60225 L p .707 .577 .707 r
F P
0 g
s
.49353 .60225 m .49117 .54858 L .47488 .55924 L p .707 .577 .707 r
F P
0 g
s
.8045 .54402 m .80686 .59769 L .77939 .59277 L p .707 .577 .707 r
F P
0 g
s
.77939 .59277 m .77704 .53911 L .8045 .54402 L p .707 .577 .707 r
F P
0 g
s
.45287 .626 m .44952 .66427 L .47328 .66524 L p .707 .577 .707 r
F P
0 g
s
.47328 .66524 m .47663 .62697 L .45287 .626 L p .707 .577 .707 r
F P
0 g
s
.6476 .72 m .64666 .70226 L .66293 .69097 L p .707 .577 .707 r
F P
0 g
s
.68709 .59942 m .68474 .54575 L .71407 .54002 L p .707 .577 .707 r
F P
0 g
s
.68474 .54575 m .68709 .59942 L .6631 .60804 L p .707 .577 .707 r
F P
0 g
s
.82642 .65817 m .82308 .69644 L .80187 .69335 L p .707 .577 .707 r
F P
0 g
s
.80187 .69335 m .80522 .65508 L .82642 .65817 L p .707 .577 .707 r
F P
0 g
s
.39299 .7328 m .39205 .71506 L .3609 .71379 L p .707 .577 .707 r
F P
0 g
s
.39205 .71506 m .39299 .7328 L .42478 .73022 L p .707 .577 .707 r
F P
0 g
s
.42478 .73022 m .42384 .71248 L .39205 .71506 L p .707 .577 .707 r
F P
0 g
s
.42384 .71248 m .42478 .73022 L .45409 .72403 L p .707 .577 .707 r
F P
0 g
s
.45409 .72403 m .45315 .70629 L .42384 .71248 L p .707 .577 .707 r
F P
0 g
s
.77704 .53911 m .77939 .59277 L .74823 .59139 L p .707 .577 .707 r
F P
0 g
s
.74823 .59139 m .74587 .53773 L .77704 .53911 L p .707 .577 .707 r
F P
0 g
s
.66293 .69097 m .66386 .70871 L .6476 .72 L p .707 .577 .707 r
F P
0 g
s
.36183 .73152 m .3609 .71379 L .33342 .70877 L p .707 .577 .707 r
F P
0 g
s
.3609 .71379 m .36183 .73152 L .39299 .7328 L p .707 .577 .707 r
F P
0 g
s
.65865 .68162 m .66199 .64336 L .68575 .64432 L p .707 .577 .707 r
F P
0 g
s
.68575 .64432 m .68241 .68259 L .65865 .68162 L p .707 .577 .707 r
F P
0 g
s
.71642 .59368 m .71407 .54002 L .74587 .53773 L p .707 .577 .707 r
F P
0 g
s
.71407 .54002 m .71642 .59368 L .68709 .59942 L p .707 .577 .707 r
F P
0 g
s
.82772 .68756 m .82866 .7053 L .80756 .69704 L p .707 .577 .707 r
F P
0 g
s
.80756 .69704 m .80662 .6793 L .82772 .68756 L p .707 .577 .707 r
F P
0 g
s
.47663 .62697 m .47328 .66524 L .48933 .6652 L p .707 .577 .707 r
F P
0 g
s
.48933 .6652 m .49267 .62694 L .47663 .62697 L p .707 .577 .707 r
F P
0 g
s
.74587 .53773 m .74823 .59139 L .71642 .59368 L p .707 .577 .707 r
F P
0 g
s
.45315 .70629 m .45409 .72403 L .47805 .71484 L p .707 .577 .707 r
F P
0 g
s
.47805 .71484 m .47711 .6971 L .45315 .70629 L p .707 .577 .707 r
F P
0 g
s
.49117 .54858 m .49353 .60225 L .50054 .59059 L p .707 .577 .707 r
F P
0 g
s
.50054 .59059 m .49819 .53692 L .49117 .54858 L p .707 .577 .707 r
F P
0 g
s
.33342 .70877 m .33436 .72651 L .36183 .73152 L p .707 .577 .707 r
F P
0 g
s
.29937 .60952 m .29603 .64779 L .30885 .65042 L p .707 .577 .707 r
F P
0 g
s
.33436 .72651 m .33342 .70877 L .31232 .70051 L p .707 .577 .707 r
F P
0 g
s
.80522 .65508 m .80187 .69335 L .77436 .69012 L p .707 .577 .707 r
F P
0 g
s
.77436 .69012 m .77771 .65185 L .80522 .65508 L p .707 .577 .707 r
F P
0 g
s
.7149 .6462 m .71156 .68447 L .68241 .68259 L p .707 .577 .707 r
F P
0 g
s
.66386 .70871 m .66293 .69097 L .68689 .68178 L p .707 .577 .707 r
F P
0 g
s
.29974 .60506 m .29739 .55139 L .29443 .53988 L p .707 .577 .707 r
F P
0 g
s
.68241 .68259 m .68575 .64432 L .7149 .6462 L p .707 .577 .707 r
F P
0 g
s
.31232 .70051 m .31326 .71825 L .33436 .72651 L p .707 .577 .707 r
F P
0 g
s
.68689 .68178 m .68783 .69952 L .66386 .70871 L p .707 .577 .707 r
F P
0 g
s
.47711 .6971 m .47805 .71484 L .49432 .70355 L p .707 .577 .707 r
F P
0 g
s
.49432 .70355 m .49338 .68581 L .47711 .6971 L p .707 .577 .707 r
F P
0 g
s
.80662 .6793 m .80756 .69704 L .78008 .69202 L p .707 .577 .707 r
F P
0 g
s
.78008 .69202 m .77914 .67429 L .80662 .6793 L p .707 .577 .707 r
F P
0 g
s
.77771 .65185 m .77436 .69012 L .74324 .68706 L p .707 .577 .707 r
F P
0 g
s
.74324 .68706 m .74658 .64879 L .77771 .65185 L p .707 .577 .707 r
F P
0 g
s
.49267 .62694 m .48933 .6652 L .49608 .66418 L p .707 .577 .707 r
F P
0 g
s
.49608 .66418 m .49943 .62591 L .49267 .62694 L p .707 .577 .707 r
F P
0 g
s
.71156 .68447 m .7149 .6462 L .74658 .64879 L p .707 .577 .707 r
F P
0 g
s
.49819 .53692 m .50054 .59059 L .49758 .57908 L p .707 .577 .707 r
F P
0 g
s
.49758 .57908 m .49523 .52541 L .49819 .53692 L p .707 .577 .707 r
F P
0 g
s
.68783 .69952 m .68689 .68178 L .7162 .67559 L p .707 .577 .707 r
F P
0 g
s
.74658 .64879 m .74324 .68706 L .71156 .68447 L p .707 .577 .707 r
F P
0 g
s
.31326 .71825 m .31232 .70051 L .29966 .68982 L p .707 .577 .707 r
F P
0 g
s
.77914 .67429 m .78008 .69202 L .74893 .69075 L p .707 .577 .707 r
F P
0 g
s
.74893 .69075 m .74799 .67301 L .77914 .67429 L p .707 .577 .707 r
F P
0 g
s
.29443 .53988 m .29678 .59354 L .29974 .60506 L p .707 .577 .707 r
F P
0 g
s
.29603 .64779 m .29937 .60952 L .29618 .6076 L p .707 .577 .707 r
F P
0 g
s
.7162 .67559 m .71714 .69333 L .68783 .69952 L p .707 .577 .707 r
F P
0 g
s
.29618 .6076 m .29284 .64587 L .29603 .64779 L p .707 .577 .707 r
F P
0 g
s
.29966 .68982 m .30059 .70756 L .31326 .71825 L p .707 .577 .707 r
F P
0 g
s
.71714 .69333 m .7162 .67559 L .74799 .67301 L p .707 .577 .707 r
F P
0 g
s
.74799 .67301 m .74893 .69075 L .71714 .69333 L p .707 .577 .707 r
F P
0 g
s
.49338 .68581 m .49432 .70355 L .5013 .69126 L p .707 .577 .707 r
F P
0 g
s
.5013 .69126 m .50036 .67352 L .49338 .68581 L p .707 .577 .707 r
F P
0 g
s
.29678 .59354 m .29443 .53988 L .30144 .52822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49943 .62591 m .49608 .66418 L .49289 .66225 L p .707 .577 .707 r
F P
0 g
s
.49289 .66225 m .49624 .62398 L .49943 .62591 L p .707 .577 .707 r
F P
0 g
s
.49523 .52541 m .49758 .57908 L .48494 .56884 L p .707 .577 .707 r
F P
0 g
s
.48494 .56884 m .48258 .51517 L .49523 .52541 L p .707 .577 .707 r
F P
0 g
s
.30059 .70756 m .29966 .68982 L .29667 .67774 L p .707 .577 .707 r
F P
0 g
s
.30144 .52822 m .30379 .58189 L .29678 .59354 L p .707 .577 .707 r
F P
0 g
s
.29667 .67774 m .29761 .69547 L .30059 .70756 L p .707 .577 .707 r
F P
0 g
s
.29284 .64587 m .29618 .6076 L .30294 .60657 L p .707 .577 .707 r
F P
0 g
s
.30294 .60657 m .29959 .64484 L .29284 .64587 L p .707 .577 .707 r
F P
0 g
s
.50036 .67352 m .5013 .69126 L .49831 .67918 L p .707 .577 .707 r
F P
0 g
s
.49831 .67918 m .49737 .66144 L .50036 .67352 L p .707 .577 .707 r
F P
0 g
s
.30379 .58189 m .30144 .52822 L .31774 .51756 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48258 .51517 m .48494 .56884 L .46385 .56087 L p .707 .577 .707 r
F P
0 g
s
.46385 .56087 m .46149 .5072 L .48258 .51517 L p .707 .577 .707 r
F P
0 g
s
.29761 .69547 m .29667 .67774 L .30365 .66545 L p .707 .577 .707 r
F P
0 g
s
.49624 .62398 m .49289 .66225 L .48007 .65962 L p .707 .577 .707 r
F P
0 g
s
.48007 .65962 m .48341 .62135 L .49624 .62398 L p .707 .577 .707 r
F P
0 g
s
.31774 .51756 m .32009 .57123 L .30379 .58189 L p .707 .577 .707 r
F P
0 g
s
.30365 .66545 m .30459 .68318 L .29761 .69547 L p .707 .577 .707 r
F P
0 g
s
.32009 .57123 m .31774 .51756 L .34173 .50894 L p .707 .577 .707 r
F P
0 g
s
.29959 .64484 m .30294 .60657 L .31898 .60654 L p .707 .577 .707 r
F P
0 g
s
.31898 .60654 m .31564 .64481 L .29959 .64484 L p .707 .577 .707 r
F P
0 g
s
.49737 .66144 m .49831 .67918 L .48565 .66848 L p .707 .577 .707 r
F P
0 g
s
.48565 .66848 m .48471 .65074 L .49737 .66144 L p .707 .577 .707 r
F P
0 g
s
.46149 .5072 m .46385 .56087 L .43638 .55596 L p .707 .577 .707 r
F P
0 g
s
.43638 .55596 m .43402 .50229 L .46149 .5072 L p .707 .577 .707 r
F P
0 g
s
.30459 .68318 m .30365 .66545 L .31992 .65415 L p .707 .577 .707 r
F P
0 g
s
.34408 .5626 m .34173 .50894 L .37106 .5032 L p .707 .577 .707 r
F P
0 g
s
.34173 .50894 m .34408 .5626 L .32009 .57123 L p .707 .577 .707 r
F P
0 g
s
.48341 .62135 m .48007 .65962 L .45886 .65654 L p .707 .577 .707 r
F P
0 g
s
.45886 .65654 m .4622 .61827 L .48341 .62135 L p .707 .577 .707 r
F P
0 g
s
.43402 .50229 m .43638 .55596 L .40522 .55458 L p .707 .577 .707 r
F P
0 g
s
.40522 .55458 m .40286 .50091 L .43402 .50229 L p .707 .577 .707 r
F P
0 g
s
.31992 .65415 m .32085 .67189 L .30459 .68318 L p .707 .577 .707 r
F P
0 g
s
.31564 .64481 m .31898 .60654 L .34274 .60751 L p .707 .577 .707 r
F P
0 g
s
.34274 .60751 m .3394 .64578 L .31564 .64481 L p .707 .577 .707 r
F P
0 g
s
.37341 .55687 m .37106 .5032 L .40286 .50091 L p .707 .577 .707 r
F P
0 g
s
.37106 .5032 m .37341 .55687 L .34408 .5626 L p .707 .577 .707 r
F P
0 g
s
.48471 .65074 m .48565 .66848 L .46455 .66022 L p .707 .577 .707 r
F P
0 g
s
.46455 .66022 m .46361 .64248 L .48471 .65074 L p .707 .577 .707 r
F P
0 g
s
.40286 .50091 m .40522 .55458 L .37341 .55687 L p .707 .577 .707 r
F P
0 g
s
.4622 .61827 m .45886 .65654 L .43135 .65331 L p .707 .577 .707 r
F P
0 g
s
.43135 .65331 m .4347 .61504 L .4622 .61827 L p .707 .577 .707 r
F P
0 g
s
.37189 .60938 m .36855 .64765 L .3394 .64578 L p .707 .577 .707 r
F P
0 g
s
.32085 .67189 m .31992 .65415 L .34388 .64496 L p .707 .577 .707 r
F P
0 g
s
.3394 .64578 m .34274 .60751 L .37189 .60938 L p .707 .577 .707 r
F P
0 g
s
.34388 .64496 m .34482 .6627 L .32085 .67189 L p .707 .577 .707 r
F P
0 g
s
.46361 .64248 m .46455 .66022 L .43707 .65521 L p .707 .577 .707 r
F P
0 g
s
.43707 .65521 m .43613 .63747 L .46361 .64248 L p .707 .577 .707 r
F P
0 g
s
.4347 .61504 m .43135 .65331 L .40023 .65024 L p .707 .577 .707 r
F P
0 g
s
.40023 .65024 m .40357 .61198 L .4347 .61504 L p .707 .577 .707 r
F P
0 g
s
.36855 .64765 m .37189 .60938 L .40357 .61198 L p .707 .577 .707 r
F P
0 g
s
.34482 .6627 m .34388 .64496 L .37319 .63877 L p .707 .577 .707 r
F P
0 g
s
.40357 .61198 m .40023 .65024 L .36855 .64765 L p .707 .577 .707 r
F P
0 g
s
.43613 .63747 m .43707 .65521 L .40591 .65393 L p .707 .577 .707 r
F P
0 g
s
.40591 .65393 m .40498 .63619 L .43613 .63747 L p .707 .577 .707 r
F P
0 g
s
.37319 .63877 m .37413 .65651 L .34482 .6627 L p .707 .577 .707 r
F P
0 g
s
.37413 .65651 m .37319 .63877 L .40498 .63619 L p .707 .577 .707 r
F P
0 g
s
.40498 .63619 m .40591 .65393 L .37413 .65651 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo6000QWoo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001mOol007Aoo`<00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00H007Moo`00L7oo100015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001]Ool3
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP04001^Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00AJEP<006]oo`00J7oo0P0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00
JGoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEPl000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00IGoo2@0015YF00<005YFFUH01UYF00<005YF00000`000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000;FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001UOol005ioo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP000080
00QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00
G7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00IGoo001JOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol005Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00EWoo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000IOol80015Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`L000AJEP04001J
EUYFFUH8000mOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF
00QJEP03001JEUYF00EJEP04001JEUYFFUH6000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000Yoo`@000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo100000=JEP00FUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Woo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0017oo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<Goo001COol01000FUIJEP000eYF00<0
05YFFUH015YF00<005YFFUH015YF1`0025YF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00000_Ool005=oo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH4
0005FUH00`00FUIJEP06FUH50004FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool005=oo`04001JEUYF0003FUH00`00FUIJEP03FUH50002FUH00`00FUIJEP04FUH50004FUH00`00
FUIJEP08FUH600000eYF001JEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH0
0003FUH00`00FUH000030004Ool01000FUIJEP001UYF1@0015YF00<005YFFUH015YF100015YF00@0
05YF000000=JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`03001JEP0000=JEP800003FUH0
000000<0009oo`04001JEUYF0006FUH50004FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000UYF00<005YF
FUH00UYF00@005YFFUIJEQP000IJEP03001JEUYF00=JEP03001JEUYF009JEP@00003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP<00003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000]Ool005Aoo`07001JEP00FUH005YFOol00eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF0`00
00=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00
FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo0017Ool90004Ool20002FUH01000FUIJEWoo0UYF00<0
05YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH015YF5`0015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Goo000oOol80004FUH00`00FUIJEP02FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH2
0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP040007Ool3000=Ool50005FUH00`00FUIJEP02000]Ool003Uoo`H0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH4000:Ool5000>Ool50003FUH00`00FUIJEP02000]Ool003Moo`800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP07001JEUYFFUH005YF00001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEP0000<000ioo`D000]oo`<000EJEP800004FUH005YFFUH2000]Ool003Eoo`8000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEQ400003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEPL000eoo`D000Moo`@00003FUH0
05YF00EJEP04001JEP000002FUH2000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH900000eYF001JEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH20003FUH01000FUIJEUYF2@001Goo0`0000=o
o`0000001@001EYF00<005YFFUH015YF00H005YFFUIJEP00FUH2000]Ool0035oo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEQ400003FUH005YF00AJEP8000QJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001J
EUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;goo
0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPL000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00L005YFFUIJEP00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH2000^Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPP000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00005
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70004FUH01000FUIJEUYF20000eYF00<005YFFUH015YF
00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000EJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001J
EUYF00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00
15YF00<005YFFUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEPX00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP04001JEUYF000`Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPT0009JEQ4000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<0009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH30004FUH00`00FUIJEP0B0008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000a
Ool002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH70009Ool90003FUH30000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030003
FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0008FUH00`00FUIJEP03
FUH2000cOol002aoo`04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP040007Ool3000>Ool5
0003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH00UYF0P00=Goo000/Ool01000FUIJEP0015YF00<005YFFUH00UYF10002Woo1@003Woo
0P001UYF00<005YFFUH015YF1P0025YF2@0015YF00<005YFFUH00UYF0P0000=JEP0000000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Io
o`00;Goo00<005YF000015YF00<005YF00000P003Woo1@002goo10001eYF00<005YFFUH0100000=J
EP0000001`0015YF00<005YFFUH01EYF1P0015YF00<005YF00000P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02000;Woo
000]Ool00`00FUH00004FUH7000<Ool50007Ool600000eYF001JEP05FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH@0002FUH20003FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Goo00<005YF00000UYF0P000eYF00@005YFFUIJEQP000=JEP03001JEUYF009JEP04001JEUYF
FUH20003FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF1P0000EJEP00FUIJEP00
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YF00000P0015YF00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00=JEP80009JEP800003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;Goo00L005YF001JEP00FUIoo`03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH20002FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01EYF00H005YF000005YF000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00=JEPl000EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eo
o`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF00000UYF0P0015YF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH015YF200015YF00<005YFFUH01UYF00<0
05YF000010001UYF00@005YFFUIJEP8002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF0P001eYF00<005YFFUH01UYF00H005YFFUIJEP00FUH40006FUH01@00FUIJEUYF00000UYF00<0
05YFFUH015YF10001EYF00<005YFFUH02EYF00<005YFFUH01eYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH80003FUH70003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40002FUH01`00FUIJEUYF001JEP0002eoo`00;Goo0P000UYF00@0
05YFFUIoo`9JEP03001JEUYF00AJEP8000MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00AJEPD000AJEP03001JEUYF00UJEP03
001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3
0002FUH00`00FUIJEP02FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH000020003FUH2000^Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF
00AJEP8000MJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH01@00FUIJEUYF
00000UYF00<005YFFUH015YF1@0015YF00<005YFFUH02EYF00<005YFFUH01UYF00D005YF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL0009JEP8000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0
000002ioo`00;Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH50004FUH00`00FUIJEP09FUH00`00FUIJEP04FUH3000015YF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH00UYF
3`001UYF00<005YFFUH00eYF1000;Woo000^Ool01000FUIJEP000eYF00=ooeYF00001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH015YF00D005YFFUIJEP00009J
EP03001JEUYF00AJEP@000EJEP03001JEUYF00UJEP03001JEUYF009JEP80009JEP80009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`<000IJEP03001J
EUYF009JEPP000QJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEP00000^Ool002eo
oa400003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00800004FUH005YF0006FUH00`00FUIJ
EP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP020004FUH2
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP03FUH70002OolB0004FUH00`00FUH000030004FUH01000FUIJEP00;Woo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH01eYF00<005YFFUH00P000UYF
0P001UYF0`0000Eoo`00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP@00003FUH005YF
00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004
FUH01000FUIJEUYF0P000eYF00@005YF000001Aoo`d00005FUH005YFFUH0000^Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH005YF009JEP05
001JEUYF001JEP030002FUH20003Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`001EYF00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP06001JEP00001JEP0015YF0`008Goo0P000UYF0P00;Goo000]Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60002
FUH00`00FUIJEP02FUH50002Ool01000FUIJEP001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP8000=JEP03001JEUYF009JEP<002=oo`04001JEUYF000]Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP04001JEUYFFUH90003FUH00`00FUIJEP03FUH70005FUH0
0`00FUIJEP04FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00UYF0`0097oo0`00;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP030007FUH01`00FUIJEUYF001JEP0000Qoo`<001Yoo`8002eoo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00H005YFFUH005YF0007FUH01`00FUIJEUYF001JEP0000Moo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF1@0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH01EYF00@005YFFUIJEP8000Qoo`D001Qoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH015YF00@005YFFUIJEP8000Qoo`D001Moo`800003FUH007oo
02aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF3P00
1EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH00UYF1`0025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YF
FUH015YF00D005YFFUIJEP0000Yoo`<001Ioo`800004FUH005YF000]Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEP0000<00003FUH0
05YF00AJEP03001JEUYF010000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH00000FUH00006FUH01000FUIJ
EP008Woo0P000eYF0P00;Woo000/OolC0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH40003FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000eYF0P001UYF0`008Goo0P0000=JEP00FUH00UYF0P00;Woo000]Ool200000eYF001JEP04FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00003
0002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0`0015YF0P008Goo
0P000eYF00D005YFFUIJEP0002moo`00;goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00@001moo`@000EJEP04001JEUYF000`Ool003=o
o`8000IJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF009JEP<0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP03001JEUYF009JEPD001Qoo`@0009JEP03001JEUYF00AJEP<0035o
o`00<Woo0P001eYF00<005YFFUH00UYF300015YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YFFUIJEPH000UJEP03001JEUYF
00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH01000FUIJEUYF
60001UYF00<005YFFUH00eYF0P00<goo000`Ool200000eYF001JEP05FUH6000<OolC0004FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P00=Goo
000_Ool00`00FUIJEP02FUH01000FUIJEUYF0P008Woo1P0000=JEP0000000UYF00<005YFFUH015YF
00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF0000
10001UYF00<005YFFUH00UYF0P0015YF0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YF000003Moo`00;Woo0P0015YF00@005YF000002Yoo`<0009J
EP03001JEUYF00=JEP@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP8000IJEP800003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<003Uoo`00;Woo0P0015YF0P00;Woo00@0
05YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP@000AJEP8000IJEP03001JEP0000@000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00@003aoo`00;Goo00<005YF00000UYF0P00<7oo00D005YFFUH005YF0080
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP04001JEUYFFUH20002FUH50002FUH00`00FUIJEP04FUHJ0010Ool002eoo`03001JEP000080
01Ioo`<001Uoo`03001JEUYF00800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEPH0009JEP07
001JEUYFFUH005YF0000E7oo000]Ool00`00FUH0000GOol5000HOol00`00FUH00003FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YF00000P000eYF0P00EGoo000]Ool2000H
Ool5000HOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH0
0UYF0P0000=JEP000000EGoo000]Ool2000HOol5000GOol30004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUH000001eYF00<005YFFUH00eYF1000EGoo000]Ool3000HOol3000FOol200000eYF
00000004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP040004FUH00`00FUIJEP03FUH0
1000FUH00000EGoo000]Ool200000eYF001oo`0]Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP000eYF1P0015YF00@005YFFUH005Eoo`00;Goo0P000UYF0P00
:Woo0P0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00003@0000EJEP00FUIJEP0005Eoo`00;Woo00D005YFFUH005YF00<002Eoo`8000=JEP03001JEUYF
009JEP<0009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000ioo`80009JEP03001oogoo05=oo`00
;Woo00@005YFFUH000AJEP<001moo`<000EJEP03001JEUYF008000=oo`<000QJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009J
EP80015oo`04001JEP00001DOol002moo`04001JEUYF0004FUH00`00FUH00003000GOol400000eYF
001JEP05FUH30007Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUH00002000DOol00`00FUH0001DOol0031oo`<000AJEP03
001JEUYF00=JEQL000EJEP03001JEUYF00AJEP03001oogoo00Yoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<001Qoo`8005Aoo`00
<Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEP80015oo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00=JEP@001Yoo`8005Aoo`00<goo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000001Qoo`H0009JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEP0000P001Qoo`03001JEP0005Aoo`00=Goo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100087oo20001UYF00<005YF
FUH02UYF00<005YFFUH015YF1`0017oo1@005goo0P0000=JEP00Ool0Dgoo000gOol50003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000/OolJ000;Ool5000FOol01@00FUH005YF0000
E7oo000lOolH000kOol2000IOol3000FOol01000FUIJEUYF0P00E7oo002?Ool01000FUH00000;Woo
0P0015YF00<007ooOol0Dgoo002?Ool01000FUIJEUYF0P00:7oo100000=JEP00FUH00eYF00<007oo
Ool0Dgoo002?Ool01P00FUIJEUYF001JEP<0025oo`@000EJEP05001JEUYFFUH0001FOol008moo`05
001JEUYFFUH00004FUH5000HOol40002FUH00`00FUIJEP04FUH01000FUH00000Egoo002@Ool01000
FUIJEP001EYF00@005YFFUIJEPP000Uoo`L000IJEP03001JEUYF00AJEP8005Uoo`00TGoo0`001EYF
00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJEP03001JEUYF00=JEP8005Yoo`00
Tgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000`00G7oo002EOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH3001POol009Qoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0
06=oo`00WGoo2@0015YF00<005YFFUH00UYF1`00Igoo002VOol9001^Ool00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59478 .73995 m .59713 .68313 L .56597 .68069 L p .707 .577 .707 r
F P
0 g
s
.59713 .68313 m .59478 .73995 L .62658 .74073 L p .707 .577 .707 r
F P
0 g
s
.62658 .74073 m .62894 .68391 L .59713 .68313 L p .707 .577 .707 r
F P
0 g
s
.62894 .68391 m .62658 .74073 L .65591 .73978 L p .707 .577 .707 r
F P
0 g
s
.65591 .73978 m .65827 .68295 L .62894 .68391 L p .707 .577 .707 r
F P
0 g
s
.56362 .73751 m .56597 .68069 L .5385 .67683 L p .707 .577 .707 r
F P
0 g
s
.56597 .68069 m .56362 .73751 L .59478 .73995 L p .707 .577 .707 r
F P
0 g
s
.65827 .68295 m .65591 .73978 L .6799 .73718 L p .707 .577 .707 r
F P
0 g
s
.6799 .73718 m .68226 .68036 L .65827 .68295 L p .707 .577 .707 r
F P
0 g
s
.5385 .67683 m .53615 .73366 L .56362 .73751 L p .707 .577 .707 r
F P
0 g
s
.53615 .73366 m .5385 .67683 L .51742 .67194 L p .707 .577 .707 r
F P
0 g
s
.59408 .84024 m .59502 .82124 L .56386 .8187 L p .707 .577 .707 r
F P
0 g
s
.59502 .82124 m .59408 .84024 L .62587 .84133 L p .707 .577 .707 r
F P
0 g
s
.62587 .84133 m .62681 .82233 L .59502 .82124 L p .707 .577 .707 r
F P
0 g
s
.59977 .82893 m .59642 .79514 L .5653 .79434 L p .707 .577 .707 r
F P
0 g
s
.62681 .82233 m .62587 .84133 L .65518 .84086 L p .707 .577 .707 r
F P
0 g
s
.65518 .84086 m .65612 .82186 L .62681 .82233 L p .707 .577 .707 r
F P
0 g
s
.59642 .79514 m .59977 .82893 L .63145 .82498 L p .707 .577 .707 r
F P
0 g
s
.63145 .82498 m .62811 .7912 L .59642 .79514 L p .707 .577 .707 r
F P
0 g
s
.62811 .7912 m .63145 .82498 L .6606 .81666 L p .707 .577 .707 r
F P
0 g
s
.6606 .81666 m .65726 .78288 L .62811 .7912 L p .707 .577 .707 r
F P
0 g
s
.51742 .67194 m .51506 .72876 L .53615 .73366 L p .707 .577 .707 r
F P
0 g
s
.56386 .8187 m .56293 .83769 L .59408 .84024 L p .707 .577 .707 r
F P
0 g
s
.56293 .83769 m .56386 .8187 L .53639 .81495 L p .707 .577 .707 r
F P
0 g
s
.56865 .82812 m .5653 .79434 L .53779 .78885 L p .707 .577 .707 r
F P
0 g
s
.5653 .79434 m .56865 .82812 L .59977 .82893 L p .707 .577 .707 r
F P
0 g
s
.68226 .68036 m .6799 .73718 L .6962 .7332 L p .707 .577 .707 r
F P
0 g
s
.6962 .7332 m .69855 .67638 L .68226 .68036 L p .707 .577 .707 r
F P
0 g
s
.65726 .78288 m .6606 .81666 L .68436 .80479 L p .707 .577 .707 r
F P
0 g
s
.68436 .80479 m .68102 .771 L .65726 .78288 L p .707 .577 .707 r
F P
0 g
s
.53639 .81495 m .53545 .83395 L .56293 .83769 L p .707 .577 .707 r
F P
0 g
s
.51506 .72876 m .51742 .67194 L .50477 .66648 L p .707 .577 .707 r
F P
0 g
s
.65612 .82186 m .65518 .84086 L .67914 .83887 L p .707 .577 .707 r
F P
0 g
s
.67914 .83887 m .68008 .81987 L .65612 .82186 L p .707 .577 .707 r
F P
0 g
s
.54114 .82264 m .53779 .78885 L .51659 .77923 L p .707 .577 .707 r
F P
0 g
s
.53779 .78885 m .54114 .82264 L .56865 .82812 L p .707 .577 .707 r
F P
0 g
s
.53048 .81366 m .51529 .81036 L p .53582 .82645 L .707 .577 .707 r
F P
0 g
s
.51993 .81301 m .51675 .78083 L p .50376 .7664 L .707 .577 .707 r
F P
0 g
s
.51675 .78083 m .51659 .77923 L .51571 .77835 L p .707 .577 .707 r
F P
0 g
s
.51571 .77835 m .50376 .7664 L p .51675 .78083 L .707 .577 .707 r
F P
0 g
s
.53545 .83395 m .53582 .82645 L p .51529 .81036 L .707 .577 .707 r
F P
0 g
s
.53582 .82645 m .53639 .81495 L .53048 .81366 L p .707 .577 .707 r
F P
0 g
s
.50477 .66648 m .50242 .7233 L .51506 .72876 L p .707 .577 .707 r
F P
0 g
s
.51529 .81036 m .51435 .82936 L .53545 .83395 L p .707 .577 .707 r
F P
0 g
s
.68102 .771 m .68436 .80479 L .7004 .79052 L p .707 .577 .707 r
F P
0 g
s
.7004 .79052 m .69706 .75674 L .68102 .771 L p .707 .577 .707 r
F P
0 g
s
.69855 .67638 m .6962 .7332 L .70321 .72823 L p .707 .577 .707 r
F P
0 g
s
.70321 .72823 m .70557 .6714 L .69855 .67638 L p .707 .577 .707 r
F P
0 g
s
.68008 .81987 m .67914 .83887 L .69541 .83556 L p .707 .577 .707 r
F P
0 g
s
.69541 .83556 m .69635 .81657 L .68008 .81987 L p .707 .577 .707 r
F P
0 g
s
.51659 .77923 m .51993 .81301 L .54114 .82264 L p .707 .577 .707 r
F P
0 g
s
.50242 .7233 m .50477 .66648 L .50181 .66099 L p .707 .577 .707 r
F P
0 g
s
.51435 .82936 m .51529 .81036 L .50262 .80539 L p .707 .577 .707 r
F P
0 g
s
.50262 .80539 m .50168 .82438 L .51435 .82936 L p .707 .577 .707 r
F P
0 g
s
.69706 .75674 m .7004 .79052 L .70716 .77526 L p .707 .577 .707 r
F P
0 g
s
.70716 .77526 m .70382 .74147 L .69706 .75674 L p .707 .577 .707 r
F P
0 g
s
.50181 .66099 m .49946 .71782 L .50242 .7233 L p .707 .577 .707 r
F P
0 g
s
.50376 .7664 m .5071 .80019 L .51993 .81301 L p .707 .577 .707 r
F P
0 g
s
.70557 .6714 m .70321 .72823 L .70025 .72274 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .70261 .66592 L .70557 .6714 L p .707 .577 .707 r
F P
0 g
s
.69635 .81657 m .69541 .83556 L .70239 .83126 L p .707 .577 .707 r
F P
0 g
s
.70239 .83126 m .70333 .81227 L .69635 .81657 L p .707 .577 .707 r
F P
0 g
s
.4926 .82254 m .48939 .32288 L .44538 .32031 L p .707 .577 .707 r
F P
0 g
s
.5071 .80019 m .50376 .7664 L .50057 .75164 L p .707 .577 .707 r
F P
0 g
s
.49946 .71782 m .50181 .66099 L .50882 .65602 L p .707 .577 .707 r
F P
0 g
s
.50168 .82438 m .50262 .80539 L .49963 .80051 L p .707 .577 .707 r
F P
0 g
s
.49963 .80051 m .4987 .8195 L .50168 .82438 L p .707 .577 .707 r
F P
0 g
s
.50882 .65602 m .50647 .71284 L .49946 .71782 L p .707 .577 .707 r
F P
0 g
s
.50391 .78542 m .5071 .80019 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50057 .75164 m .50156 .76159 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50156 .76159 m .50391 .78542 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .49963 .80051 L .50467 .7974 L p .707 .577 .707 r
F P
0 g
s
.50467 .7974 m .50662 .7962 L p .50498 .80101 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .50467 .7974 L .50498 .80101 L .707 .577 .707 r
F
.50391 .78542 m .50057 .75164 L .50733 .73637 L p F P
0 g
s
.50647 .71284 m .50882 .65602 L .52512 .65204 L p .707 .577 .707 r
F P
0 g
s
.50662 .7962 m .50568 .8152 L .4987 .8195 L p .707 .577 .707 r
F P
0 g
s
.50733 .73637 m .51067 .77016 L .50391 .78542 L p .707 .577 .707 r
F P
0 g
s
.52512 .65204 m .52277 .70886 L .50647 .71284 L p .707 .577 .707 r
F P
0 g
s
.51067 .77016 m .50733 .73637 L .52337 .72211 L p .707 .577 .707 r
F P
0 g
s
.52277 .70886 m .52512 .65204 L .54911 .64944 L p .707 .577 .707 r
F P
0 g
s
.50568 .8152 m .50662 .7962 L .52288 .7929 L p .707 .577 .707 r
F P
0 g
s
.52288 .7929 m .52195 .81189 L .50568 .8152 L p .707 .577 .707 r
F P
0 g
s
.52337 .72211 m .52672 .75589 L .51067 .77016 L p .707 .577 .707 r
F P
0 g
s
.54911 .64944 m .54676 .70627 L .52277 .70886 L p .707 .577 .707 r
F P
0 g
s
.52672 .75589 m .52337 .72211 L .54713 .71023 L p .707 .577 .707 r
F P
0 g
s
.54713 .71023 m .55047 .74402 L .52672 .75589 L p .707 .577 .707 r
F P
0 g
s
.52195 .81189 m .52288 .7929 L .54685 .79091 L p .707 .577 .707 r
F P
0 g
s
.54685 .79091 m .54591 .80991 L .52195 .81189 L p .707 .577 .707 r
F P
0 g
s
.48939 .32288 m .4926 .82254 L .53754 .82112 L p .707 .577 .707 r
F P
0 g
s
.53754 .82112 m .53433 .32145 L .48939 .32288 L p .707 .577 .707 r
F P
0 g
s
.54676 .70627 m .54911 .64944 L .57844 .64849 L p .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .57609 .70531 L .54676 .70627 L p .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .57624 .70155 L .58541 .69001 L .707 .577 .707 r
F
.57609 .70531 m .57624 .70155 L p .57845 .70143 L F P
0 g
s
.58145 .70127 m .60797 .69797 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .57609 .70531 L p .57845 .70143 L .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .60307 .7001 L .60789 .70609 L .707 .577 .707 r
F
.60797 .69797 m .60815 .69983 L p .6065 .69992 L F P
0 g
s
.60815 .69983 m .60789 .70609 L p .58952 .68327 L .707 .577 .707 r
F P
0 g
s
.61131 .73175 m .57962 .7357 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60797 .69797 m .63909 .69877 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .60789 .70609 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.61164 .70001 m .62885 .70088 L .63905 .70853 L .707 .577 .707 r
F
.60995 .69992 m .60797 .69797 L .63697 .70129 L F
.62885 .70088 m .63413 .70114 L .63905 .70853 L F
.63909 .69877 m .63935 .70141 L p .63697 .70129 L F P
0 g
s
.63935 .70141 m .63905 .70853 L p .62358 .68532 L .707 .577 .707 r
F P
0 g
s
.64243 .73256 m .61131 .73175 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63909 .69877 m .6666 .70426 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .63905 .70853 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.64274 .70199 m .6572 .70448 L .66652 .71239 L .707 .577 .707 r
F
.64169 .70181 m .63909 .69877 L .66523 .70586 L F
.6572 .70448 m .663 .70547 L .66652 .71239 L F
.6666 .70426 m .66678 .70612 L p .66523 .70586 L F P
0 g
s
.66678 .70612 m .66652 .71239 L p .6544 .68863 L .707 .577 .707 r
F P
0 g
s
.66994 .73804 m .64243 .73256 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .66652 .71239 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.669 .7069 m .68135 .71126 L .68761 .71728 L .707 .577 .707 r
F
.6666 .70426 m .68434 .71231 L p .66812 .7066 L F P
0 g
s
.68897 .6845 m .68761 .71728 L p .67137 .70165 L .707 .577 .707 r
F P
0 g
s
.68996 .66046 m .70261 .66592 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .68777 .71352 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68777 .71352 m .68996 .66046 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.66888 .65556 m .68996 .66046 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .66678 .70612 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .6666 .70426 L p .66812 .7066 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66888 .65556 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66812 .7066 L .67987 .72462 L .707 .577 .707 r
F
.67987 .72462 m .66812 .7066 L .68759 .71381 L F
.68639 .71579 m .68759 .71381 L .6878 .71388 L F
.67987 .72462 m .68759 .71381 L .68639 .71579 L F
.68434 .71231 m .6878 .71388 L p .66812 .7066 L F P
0 g
s
.669 .7069 m .67137 .70165 L .68135 .71126 L .707 .577 .707 r
F
.68996 .66046 m .68897 .6845 L p .67137 .70165 L F P
0 g
s
.66678 .70612 m .66994 .73804 L p .66546 .70741 L .707 .577 .707 r
F P
0 g
s
.66523 .70586 m .66678 .70612 L .66546 .70741 L .707 .577 .707 r
F
.64646 .69537 m .6544 .68863 L .663 .70547 L F
.64646 .69537 m .663 .70547 L .6572 .70448 L F
.66798 .6771 m .66678 .70612 L p .6544 .68863 L F P
0 g
s
.66994 .73804 m .66678 .70612 L p .67987 .72462 L .707 .577 .707 r
F P
0 g
s
.64141 .65171 m .66888 .65556 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .63935 .70141 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .63909 .69877 L p .64169 .70181 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64141 .65171 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64169 .70181 L .65521 .71759 L .707 .577 .707 r
F
.65521 .71759 m .64169 .70181 L .66523 .70586 L F
.64274 .70199 m .64646 .69537 L .6572 .70448 L F
.66888 .65556 m .66798 .6771 L p .64646 .69537 L F P
0 g
s
.63935 .70141 m .64243 .73256 L p .6373 .70315 L .707 .577 .707 r
F P
0 g
s
.63697 .70129 m .63935 .70141 L .6373 .70315 L .707 .577 .707 r
F
.61671 .69178 m .62358 .68532 L .63413 .70114 L F
.61671 .69178 m .63413 .70114 L .62885 .70088 L F
.64068 .66923 m .63935 .70141 L p .62358 .68532 L F P
0 g
s
.64243 .73256 m .63935 .70141 L p .65521 .71759 L .707 .577 .707 r
F P
0 g
s
.61025 .64927 m .64141 .65171 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .60815 .69983 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60797 .69797 L p .60995 .69992 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .61025 .64927 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60995 .69992 L .62533 .71511 L .707 .577 .707 r
F
.62533 .71511 m .60995 .69992 L .63697 .70129 L F
.61164 .70001 m .61671 .69178 L .62885 .70088 L F
.64141 .65171 m .64068 .66923 L p .61671 .69178 L F P
0 g
s
.60815 .69983 m .61131 .73175 L p .60669 .7012 L .707 .577 .707 r
F P
0 g
s
.6065 .69992 m .60815 .69983 L .60669 .7012 L .707 .577 .707 r
F
.57845 .70143 m .58952 .68327 L .60307 .7001 L F
.61025 .64927 m .60815 .69983 L p .58952 .68327 L F P
0 g
s
.61131 .73175 m .60815 .69983 L p .62533 .71511 L .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .57628 .70191 L .58145 .70127 L p .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .58145 .70127 L .6065 .69992 L .707 .577 .707 r
F
.55047 .74402 m .54959 .73509 L p .57628 .70191 L F P
0 g
s
.54959 .73509 m .54713 .71023 L .57586 .70203 L p .707 .577 .707 r
F P
0 g
s
.57586 .70203 m .57628 .70191 L p .54959 .73509 L .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .61025 .64927 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57624 .70155 m .57844 .64849 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57628 .70191 m .57962 .7357 L .55047 .74402 L p .707 .577 .707 r
F P
0 g
s
.54591 .80991 m .54685 .79091 L .57615 .79044 L p .707 .577 .707 r
F P
0 g
s
.57615 .79044 m .57522 .80944 L .54591 .80991 L p .707 .577 .707 r
F P
0 g
s
.57522 .80944 m .57615 .79044 L .60794 .79153 L p .707 .577 .707 r
F P
0 g
s
.60794 .79153 m .60701 .81053 L .57522 .80944 L p .707 .577 .707 r
F P
0 g
s
.53433 .32145 m .53754 .82112 L .57902 .81584 L p .707 .577 .707 r
F P
0 g
s
.57902 .81584 m .57581 .31617 L .53433 .32145 L p .707 .577 .707 r
F P
0 g
s
.44859 .81997 m .44538 .32031 L .40662 .31399 L p .707 .577 .707 r
F P
0 g
s
.44538 .32031 m .44859 .81997 L .4926 .82254 L p .707 .577 .707 r
F P
0 g
s
.70382 .74147 m .70716 .77526 L .70397 .76049 L p .707 .577 .707 r
F P
0 g
s
.70397 .76049 m .70063 .72671 L .70382 .74147 L p .707 .577 .707 r
F P
0 g
s
.60701 .81053 m .60794 .79153 L .6391 .79407 L p .707 .577 .707 r
F P
0 g
s
.57581 .31617 m .57902 .81584 L .61297 .80722 L p .707 .577 .707 r
F P
0 g
s
.61297 .80722 m .60977 .30756 L .57581 .31617 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .68761 .71728 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.6878 .71388 m .69115 .74767 L .67228 .7391 L p .707 .577 .707 r
F P
0 g
s
.67228 .7391 m .66994 .73804 L p .68639 .71579 L .707 .577 .707 r
F P
0 g
s
.68639 .71579 m .6878 .71388 L .67228 .7391 L .707 .577 .707 r
F
.70261 .66592 m .70158 .6907 L p .68959 .71051 L F P
0 g
s
.70158 .6907 m .70025 .72274 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.70333 .81227 m .70239 .83126 L .6994 .82638 L p .707 .577 .707 r
F P
0 g
s
.6994 .82638 m .70034 .80739 L .70333 .81227 L p .707 .577 .707 r
F P
0 g
s
.40983 .81366 m .40662 .31399 L .37689 .30455 L p .707 .577 .707 r
F P
0 g
s
.40662 .31399 m .40983 .81366 L .44859 .81997 L p .707 .577 .707 r
F P
0 g
s
.25177 .70314 m .25412 .64631 L .22296 .64387 L p .707 .577 .707 r
F P
0 g
s
.25412 .64631 m .25177 .70314 L .28357 .70392 L p .707 .577 .707 r
F P
0 g
s
.28357 .70392 m .28593 .64709 L .25412 .64631 L p .707 .577 .707 r
F P
0 g
s
.28593 .64709 m .28357 .70392 L .31291 .70296 L p .707 .577 .707 r
F P
0 g
s
.31291 .70296 m .31526 .64614 L .28593 .64709 L p .707 .577 .707 r
F P
0 g
s
.70063 .72671 m .70397 .76049 L .69115 .74767 L p .707 .577 .707 r
F P
0 g
s
.69115 .74767 m .6878 .71388 L .70063 .72671 L p .707 .577 .707 r
F P
0 g
s
.22061 .7007 m .22296 .64387 L .19549 .64002 L p .707 .577 .707 r
F P
0 g
s
.22296 .64387 m .22061 .7007 L .25177 .70314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31526 .64614 m .31291 .70296 L .33689 .70037 L p .707 .577 .707 r
F P
0 g
s
.33689 .70037 m .33925 .64354 L .31526 .64614 L p .707 .577 .707 r
F P
0 g
s
.19549 .64002 m .19314 .69684 L .22061 .7007 L p .707 .577 .707 r
F P
0 g
s
.6391 .79407 m .63816 .81307 L .60701 .81053 L p .707 .577 .707 r
F P
0 g
s
.60977 .30756 m .61297 .80722 L .63608 .79611 L p .707 .577 .707 r
F P
0 g
s
.63608 .79611 m .63287 .29644 L .60977 .30756 L p .707 .577 .707 r
F P
0 g
s
.19314 .69684 m .19549 .64002 L .17441 .63512 L p .707 .577 .707 r
F P
0 g
s
.70034 .80739 m .6994 .82638 L .68674 .82141 L p .707 .577 .707 r
F P
0 g
s
.68674 .82141 m .68768 .80241 L .70034 .80739 L p .707 .577 .707 r
F P
0 g
s
.25107 .80342 m .25201 .78443 L .22086 .78188 L p .707 .577 .707 r
F P
0 g
s
.25201 .78443 m .25107 .80342 L .28286 .80451 L p .707 .577 .707 r
F P
0 g
s
.28286 .80451 m .2838 .78552 L .25201 .78443 L p .707 .577 .707 r
F P
0 g
s
.25676 .79211 m .25341 .75833 L .22229 .75752 L p .707 .577 .707 r
F P
0 g
s
.2838 .78552 m .28286 .80451 L .31217 .80404 L p .707 .577 .707 r
F P
0 g
s
.31217 .80404 m .31311 .78505 L .2838 .78552 L p .707 .577 .707 r
F P
0 g
s
.25341 .75833 m .25676 .79211 L .28844 .78816 L p .707 .577 .707 r
F P
0 g
s
.28844 .78816 m .2851 .75438 L .25341 .75833 L p .707 .577 .707 r
F P
0 g
s
.2851 .75438 m .28844 .78816 L .31759 .77985 L p .707 .577 .707 r
F P
0 g
s
.31759 .77985 m .31425 .74606 L .2851 .75438 L p .707 .577 .707 r
F P
0 g
s
.17441 .63512 m .17205 .69195 L .19314 .69684 L p .707 .577 .707 r
F P
0 g
s
.3801 .80422 m .37689 .30455 L .35911 .29291 L p .707 .577 .707 r
F P
0 g
s
.37689 .30455 m .3801 .80422 L .40983 .81366 L p .707 .577 .707 r
F P
0 g
s
.22086 .78188 m .21992 .80088 L .25107 .80342 L p .707 .577 .707 r
F P
0 g
s
.21992 .80088 m .22086 .78188 L .19338 .77813 L p .707 .577 .707 r
F P
0 g
s
.22564 .79131 m .22229 .75752 L .19478 .75204 L p .707 .577 .707 r
F P
0 g
s
.22229 .75752 m .22564 .79131 L .25676 .79211 L p .707 .577 .707 r
F P
0 g
s
.33925 .64354 m .33689 .70037 L .35319 .69639 L p .707 .577 .707 r
F P
0 g
s
.35319 .69639 m .35555 .63956 L .33925 .64354 L p .707 .577 .707 r
F P
0 g
s
.31425 .74606 m .31759 .77985 L .34135 .76797 L p .707 .577 .707 r
F P
0 g
s
.34135 .76797 m .33801 .73419 L .31425 .74606 L p .707 .577 .707 r
F P
0 g
s
.19338 .77813 m .19244 .79713 L .21992 .80088 L p .707 .577 .707 r
F P
0 g
s
.17205 .69195 m .17441 .63512 L .16176 .62966 L p .707 .577 .707 r
F P
0 g
s
.31311 .78505 m .31217 .80404 L .33613 .80206 L p .707 .577 .707 r
F P
0 g
s
.33613 .80206 m .33707 .78306 L .31311 .78505 L p .707 .577 .707 r
F P
0 g
s
.19813 .78582 m .19478 .75204 L .17358 .74241 L p .707 .577 .707 r
F P
0 g
s
.19478 .75204 m .19813 .78582 L .22564 .79131 L p .707 .577 .707 r
F P
0 g
s
.63287 .29644 m .63608 .79611 L .64608 .78359 L p .707 .577 .707 r
F P
0 g
s
.64608 .78359 m .64287 .28393 L .63287 .29644 L p .707 .577 .707 r
F P
0 g
s
.18747 .77685 m .17228 .77355 L p .19281 .78963 L .707 .577 .707 r
F P
0 g
s
.17692 .77619 m .17374 .74401 L p .16075 .72959 L .707 .577 .707 r
F P
0 g
s
.17374 .74401 m .17358 .74241 L .1727 .74153 L p .707 .577 .707 r
F P
0 g
s
.1727 .74153 m .16075 .72959 L p .17374 .74401 L .707 .577 .707 r
F P
0 g
s
.19244 .79713 m .19281 .78963 L p .17228 .77355 L .707 .577 .707 r
F P
0 g
s
.19281 .78963 m .19338 .77813 L .18747 .77685 L p .707 .577 .707 r
F P
0 g
s
.16176 .62966 m .15941 .68649 L .17205 .69195 L p .707 .577 .707 r
F P
0 g
s
.68768 .80241 m .68674 .82141 L .66564 .81682 L p .707 .577 .707 r
F P
0 g
s
.66564 .81682 m .66657 .79782 L .68768 .80241 L p .707 .577 .707 r
F P
0 g
s
.17228 .77355 m .17134 .79254 L .19244 .79713 L p .707 .577 .707 r
F P
0 g
s
.33801 .73419 m .34135 .76797 L .35739 .75371 L p .707 .577 .707 r
F P
0 g
s
.35739 .75371 m .35405 .71992 L .33801 .73419 L p .707 .577 .707 r
F P
0 g
s
.35555 .63956 m .35319 .69639 L .3602 .69141 L p .707 .577 .707 r
F P
0 g
s
.3602 .69141 m .36256 .63459 L .35555 .63956 L p .707 .577 .707 r
F P
0 g
s
.33707 .78306 m .33613 .80206 L .3524 .79875 L p .707 .577 .707 r
F P
0 g
s
.3524 .79875 m .35334 .77975 L .33707 .78306 L p .707 .577 .707 r
F P
0 g
s
.17358 .74241 m .17692 .77619 L .19813 .78582 L p .707 .577 .707 r
F P
0 g
s
.35405 .71992 m .35739 .75371 L .36415 .73844 L p .707 .577 .707 r
F P
0 g
s
.36415 .73844 m .36081 .70466 L .35405 .71992 L p .707 .577 .707 r
F P
0 g
s
.36256 .63459 m .3602 .69141 L .35724 .68593 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3596 .6291 L .36256 .63459 L p .707 .577 .707 r
F P
0 g
s
.36081 .70466 m .36415 .73844 L .36096 .72368 L p .707 .577 .707 r
F P
0 g
s
.36232 .79258 m .35911 .29291 L .35502 .28021 L p .707 .577 .707 r
F P
0 g
s
.35911 .29291 m .36232 .79258 L .3801 .80422 L p .707 .577 .707 r
F P
0 g
s
.15941 .68649 m .16176 .62966 L .1588 .62418 L p .707 .577 .707 r
F P
0 g
s
.17134 .79254 m .17228 .77355 L .15961 .76857 L p .707 .577 .707 r
F P
0 g
s
.66657 .79782 m .66564 .81682 L .63816 .81307 L p .707 .577 .707 r
F P
0 g
s
.63816 .81307 m .6391 .79407 L .66657 .79782 L p .707 .577 .707 r
F P
0 g
s
.15961 .76857 m .15868 .78757 L .17134 .79254 L p .707 .577 .707 r
F P
0 g
s
.1588 .62418 m .15645 .681 L .15941 .68649 L p .707 .577 .707 r
F P
0 g
s
.16075 .72959 m .1641 .76337 L .17692 .77619 L p .707 .577 .707 r
F P
0 g
s
.64287 .28393 m .64608 .78359 L .64199 .77089 L p .707 .577 .707 r
F P
0 g
s
.64199 .77089 m .63878 .27123 L .64287 .28393 L p .707 .577 .707 r
F P
0 g
s
.35334 .77975 m .3524 .79875 L .35938 .79445 L p .707 .577 .707 r
F P
0 g
s
.35938 .79445 m .36032 .77545 L .35334 .77975 L p .707 .577 .707 r
F P
0 g
s
.1641 .76337 m .16075 .72959 L .15756 .71482 L p .707 .577 .707 r
F P
0 g
s
.15645 .681 m .1588 .62418 L .16581 .6192 L p .707 .577 .707 r
F P
0 g
s
.15868 .78757 m .15961 .76857 L .15663 .76369 L p .707 .577 .707 r
F P
0 g
s
.36096 .72368 m .35762 .68989 L .36081 .70466 L p .707 .577 .707 r
F P
0 g
s
.15663 .76369 m .15569 .78269 L .15868 .78757 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3446 .68047 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3596 .6291 m .35857 .65388 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.35857 .65388 m .35724 .68593 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .3596 .6291 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .34476 .6767 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .34695 .62364 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .32351 .67557 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32359 .66744 L .34133 .6755 L p .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .34476 .6767 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .3446 .68047 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .34695 .62364 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .32377 .66931 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32587 .61875 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .29942 .69574 L p .31316 .67965 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .29604 .67171 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32359 .66744 m .32377 .66931 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32351 .67557 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .32359 .66744 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .29634 .66459 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .29634 .66459 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29608 .66196 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .32587 .61875 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .2984 .61489 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .32377 .66931 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.31316 .67965 m .32222 .66904 L .32377 .66931 L .707 .577 .707 r
F
.32377 .66931 m .32693 .70123 L p .31316 .67965 L F P
0 g
s
.32693 .70123 m .32377 .66931 L p .34459 .67698 L .707 .577 .707 r
F P
0 g
s
.34133 .6755 m .34459 .67698 L p .32377 .66931 L .707 .577 .707 r
F P
0 g
s
.34459 .67698 m .34479 .67707 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .34459 .67698 L .34338 .67898 L .707 .577 .707 r
F
.34479 .67707 m .34814 .71085 L .32927 .70229 L p F P
0 g
s
.32927 .70229 m .32693 .70123 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.34338 .67898 m .34479 .67707 L .32927 .70229 L .707 .577 .707 r
F
.36032 .77545 m .35938 .79445 L .35639 .78957 L p F P
0 g
s
.35639 .78957 m .35733 .77057 L .36032 .77545 L p .707 .577 .707 r
F P
0 g
s
.35762 .68989 m .36096 .72368 L .34814 .71085 L p .707 .577 .707 r
F P
0 g
s
.35502 .28021 m .35823 .77988 L .36232 .79258 L p .707 .577 .707 r
F P
0 g
s
.35823 .77988 m .35502 .28021 L .36502 .2677 L p .707 .577 .707 r
F P
0 g
s
.16581 .6192 m .16346 .67602 L .15645 .681 L p .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .15663 .76369 L .16166 .76059 L p .707 .577 .707 r
F P
0 g
s
.16091 .7486 m .1641 .76337 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.16166 .76059 m .16361 .75939 L p .16197 .76419 L .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .16166 .76059 L .16197 .76419 L .707 .577 .707 r
F
.15756 .71482 m .15855 .72477 L p .1579 .71733 L F P
0 g
s
.15855 .72477 m .16091 .7486 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16091 .7486 m .15756 .71482 L .16432 .69956 L p .707 .577 .707 r
F P
0 g
s
.16346 .67602 m .16581 .6192 L .18211 .61522 L p .707 .577 .707 r
F P
0 g
s
.34814 .71085 m .34479 .67707 L .35762 .68989 L p .707 .577 .707 r
F P
0 g
s
.63878 .27123 m .64199 .77089 L .62421 .75925 L p .707 .577 .707 r
F P
0 g
s
.62421 .75925 m .621 .25959 L .63878 .27123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16361 .75939 m .16267 .77839 L .15569 .78269 L p .707 .577 .707 r
F P
0 g
s
.16432 .69956 m .16766 .73334 L .16091 .7486 L p .707 .577 .707 r
F P
0 g
s
.18211 .61522 m .17976 .67204 L .16346 .67602 L p .707 .577 .707 r
F P
0 g
s
.16766 .73334 m .16432 .69956 L .18036 .68529 L p .707 .577 .707 r
F P
0 g
s
.36822 .76736 m .36502 .2677 L .38813 .25658 L p .707 .577 .707 r
F P
0 g
s
.36502 .2677 m .36822 .76736 L .35823 .77988 L p .707 .577 .707 r
F P
0 g
s
.35733 .77057 m .35639 .78957 L .34373 .78459 L p .707 .577 .707 r
F P
0 g
s
.34373 .78459 m .34467 .7656 L .35733 .77057 L p .707 .577 .707 r
F P
0 g
s
.17976 .67204 m .18211 .61522 L .2061 .61263 L p .707 .577 .707 r
F P
0 g
s
.16267 .77839 m .16361 .75939 L .17987 .75608 L p .707 .577 .707 r
F P
0 g
s
.17987 .75608 m .17894 .77508 L .16267 .77839 L p .707 .577 .707 r
F P
0 g
s
.18036 .68529 m .18371 .71907 L .16766 .73334 L p .707 .577 .707 r
F P
0 g
s
.2061 .61263 m .20375 .66945 L .17976 .67204 L p .707 .577 .707 r
F P
0 g
s
.18371 .71907 m .18036 .68529 L .20412 .67342 L p .707 .577 .707 r
F P
0 g
s
.621 .25959 m .62421 .75925 L .59448 .74982 L p .707 .577 .707 r
F P
0 g
s
.59448 .74982 m .59127 .25015 L .621 .25959 L p .707 .577 .707 r
F P
0 g
s
.20375 .66945 m .2061 .61263 L .23543 .61167 L p .707 .577 .707 r
F P
0 g
s
.34467 .7656 m .34373 .78459 L .32263 .78 L p .707 .577 .707 r
F P
0 g
s
.32263 .78 m .32356 .76101 L .34467 .7656 L p .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .26488 .66928 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29604 .67171 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .2683 .69493 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .29634 .66459 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29942 .69574 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .29608 .66196 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .26514 .66302 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .26514 .66302 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26496 .66115 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .2984 .61489 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26724 .61245 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .29634 .66459 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.38813 .25658 m .39133 .75625 L .36822 .76736 L p .707 .577 .707 r
F P
0 g
s
.39133 .75625 m .38813 .25658 L .42208 .24797 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .23308 .6685 L .20375 .66945 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .26724 .61245 L p .2424 .6532 L .707 .577 .707 r
F P
0 g
s
.23308 .6685 m .23324 .66474 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.23844 .66445 m .26496 .66115 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .23308 .6685 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .26514 .66302 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .26514 .66302 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26488 .66928 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .23661 .69888 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .2683 .69493 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23327 .6651 L .23844 .66445 L p .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23844 .66445 L .26349 .6631 L .707 .577 .707 r
F
.23545 .66462 m .23324 .66474 L .2424 .6532 L F
.23324 .66474 m .23543 .61167 L p .2424 .6532 L F P
0 g
s
.20747 .7072 m .20658 .69827 L p .23327 .6651 L .707 .577 .707 r
F P
0 g
s
.20658 .69827 m .20412 .67342 L .23285 .66522 L p .707 .577 .707 r
F P
0 g
s
.23285 .66522 m .23327 .6651 L p .20658 .69827 L .707 .577 .707 r
F P
0 g
s
.20412 .67342 m .20747 .7072 L .18371 .71907 L p .707 .577 .707 r
F P
0 g
s
.17894 .77508 m .17987 .75608 L .20384 .7541 L p .707 .577 .707 r
F P
0 g
s
.73198 .64791 m .73434 .59109 L .70318 .58865 L p .707 .577 .707 r
F P
0 g
s
.73434 .59109 m .73198 .64791 L .76379 .64869 L p .707 .577 .707 r
F P
0 g
s
.76379 .64869 m .76614 .59187 L .73434 .59109 L p .707 .577 .707 r
F P
0 g
s
.20384 .7541 m .2029 .77309 L .17894 .77508 L p .707 .577 .707 r
F P
0 g
s
.76614 .59187 m .76379 .64869 L .79312 .64774 L p .707 .577 .707 r
F P
0 g
s
.79312 .64774 m .79547 .59092 L .76614 .59187 L p .707 .577 .707 r
F P
0 g
s
.70082 .64548 m .70318 .58865 L .67571 .5848 L p .707 .577 .707 r
F P
0 g
s
.70318 .58865 m .70082 .64548 L .73198 .64791 L p .707 .577 .707 r
F P
0 g
s
.23327 .6651 m .23661 .69888 L .20747 .7072 L p .707 .577 .707 r
F P
0 g
s
.59127 .25015 m .59448 .74982 L .55572 .7435 L p .707 .577 .707 r
F P
0 g
s
.55572 .7435 m .55251 .24383 L .59127 .25015 L p .707 .577 .707 r
F P
0 g
s
.32356 .76101 m .32263 .78 L .29515 .77626 L p .707 .577 .707 r
F P
0 g
s
.29515 .77626 m .29609 .75726 L .32356 .76101 L p .707 .577 .707 r
F P
0 g
s
.79547 .59092 m .79312 .64774 L .81711 .64515 L p .707 .577 .707 r
F P
0 g
s
.81711 .64515 m .81946 .58832 L .79547 .59092 L p .707 .577 .707 r
F P
0 g
s
.67571 .5848 m .67335 .64162 L .70082 .64548 L p .707 .577 .707 r
F P
0 g
s
.2029 .77309 m .20384 .7541 L .23315 .75363 L p .707 .577 .707 r
F P
0 g
s
.67335 .64162 m .67571 .5848 L .65462 .5799 L p .707 .577 .707 r
F P
0 g
s
.23315 .75363 m .23221 .77262 L .2029 .77309 L p .707 .577 .707 r
F P
0 g
s
.42529 .74764 m .42208 .24797 L .46356 .24269 L p .707 .577 .707 r
F P
0 g
s
.42208 .24797 m .42529 .74764 L .39133 .75625 L p .707 .577 .707 r
F P
0 g
s
.73129 .74911 m .73222 .73012 L .70107 .72757 L p .707 .577 .707 r
F P
0 g
s
.73222 .73012 m .73129 .74911 L .76308 .7502 L p .707 .577 .707 r
F P
0 g
s
.76308 .7502 m .76401 .73121 L .73222 .73012 L p .707 .577 .707 r
F P
0 g
s
.73697 .73665 m .73363 .70287 L .70251 .70206 L p .707 .577 .707 r
F P
0 g
s
.76401 .73121 m .76308 .7502 L .79239 .74973 L p .707 .577 .707 r
F P
0 g
s
.79239 .74973 m .79332 .73073 L .76401 .73121 L p .707 .577 .707 r
F P
0 g
s
.73363 .70287 m .73697 .73665 L .76866 .7327 L p .707 .577 .707 r
F P
0 g
s
.76866 .7327 m .76531 .69892 L .73363 .70287 L p .707 .577 .707 r
F P
0 g
s
.29609 .75726 m .29515 .77626 L .264 .77371 L p .707 .577 .707 r
F P
0 g
s
.264 .77371 m .26493 .75472 L .29609 .75726 L p .707 .577 .707 r
F P
0 g
s
.76531 .69892 m .76866 .7327 L .79781 .72439 L p .707 .577 .707 r
F P
0 g
s
.79781 .72439 m .79446 .6906 L .76531 .69892 L p .707 .577 .707 r
F P
0 g
s
.65462 .5799 m .65227 .63672 L .67335 .64162 L p .707 .577 .707 r
F P
0 g
s
.23221 .77262 m .23315 .75363 L .26493 .75472 L p .707 .577 .707 r
F P
0 g
s
.55251 .24383 m .55572 .7435 L .51171 .74093 L p .707 .577 .707 r
F P
0 g
s
.51171 .74093 m .5085 .24126 L .55251 .24383 L p .707 .577 .707 r
F P
0 g
s
.70107 .72757 m .70013 .74657 L .73129 .74911 L p .707 .577 .707 r
F P
0 g
s
.26493 .75472 m .264 .77371 L .23221 .77262 L p .707 .577 .707 r
F P
0 g
s
.70013 .74657 m .70107 .72757 L .67359 .72382 L p .707 .577 .707 r
F P
0 g
s
.70585 .73584 m .70251 .70206 L .675 .69658 L p .707 .577 .707 r
F P
0 g
s
.70251 .70206 m .70585 .73584 L .73697 .73665 L p .707 .577 .707 r
F P
0 g
s
.81946 .58832 m .81711 .64515 L .83341 .64117 L p .707 .577 .707 r
F P
0 g
s
.83341 .64117 m .83576 .58434 L .81946 .58832 L p .707 .577 .707 r
F P
0 g
s
.79446 .6906 m .79781 .72439 L .82156 .71251 L p .707 .577 .707 r
F P
0 g
s
.82156 .71251 m .81822 .67873 L .79446 .6906 L p .707 .577 .707 r
F P
0 g
s
.46677 .74236 m .46356 .24269 L .5085 .24126 L p .707 .577 .707 r
F P
0 g
s
.46356 .24269 m .46677 .74236 L .42529 .74764 L p .707 .577 .707 r
F P
0 g
s
.67359 .72382 m .67266 .74282 L .70013 .74657 L p .707 .577 .707 r
F P
0 g
s
.5085 .24126 m .51171 .74093 L .46677 .74236 L p .707 .577 .707 r
F P
0 g
s
.65227 .63672 m .65462 .5799 L .64198 .57444 L p .707 .577 .707 r
F P
0 g
s
.79332 .73073 m .79239 .74973 L .81635 .74774 L p .707 .577 .707 r
F P
0 g
s
.81635 .74774 m .81728 .72875 L .79332 .73073 L p .707 .577 .707 r
F P
0 g
s
.67834 .73036 m .675 .69658 L .65379 .68695 L p .707 .577 .707 r
F P
0 g
s
.675 .69658 m .67834 .73036 L .70585 .73584 L p .707 .577 .707 r
F P
0 g
s
.66807 .72262 m .65249 .71924 L p .67306 .73456 L .707 .577 .707 r
F P
0 g
s
.65713 .72073 m .65399 .68894 L p .64097 .67413 L .707 .577 .707 r
F P
0 g
s
.65399 .68894 m .65379 .68695 L .6527 .68586 L p .707 .577 .707 r
F P
0 g
s
.6527 .68586 m .64097 .67413 L p .65399 .68894 L .707 .577 .707 r
F P
0 g
s
.67266 .74282 m .67306 .73456 L p .65249 .71924 L .707 .577 .707 r
F P
0 g
s
.67306 .73456 m .67359 .72382 L .66807 .72262 L p .707 .577 .707 r
F P
0 g
s
.64198 .57444 m .63962 .63126 L .65227 .63672 L p .707 .577 .707 r
F P
0 g
s
.65249 .71924 m .65155 .73823 L .67266 .74282 L p .707 .577 .707 r
F P
0 g
s
.81822 .67873 m .82156 .71251 L .83761 .69824 L p .707 .577 .707 r
F P
0 g
s
.83761 .69824 m .83427 .66446 L .81822 .67873 L p .707 .577 .707 r
F P
0 g
s
.83576 .58434 m .83341 .64117 L .84042 .63619 L p .707 .577 .707 r
F P
0 g
s
.84042 .63619 m .84277 .57937 L .83576 .58434 L p .707 .577 .707 r
F P
0 g
s
.65379 .68695 m .65713 .72073 L .67834 .73036 L p .707 .577 .707 r
F P
0 g
s
.81728 .72875 m .81635 .74774 L .83261 .74444 L p .707 .577 .707 r
F P
0 g
s
.83261 .74444 m .83355 .72544 L .81728 .72875 L p .707 .577 .707 r
F P
0 g
s
.63962 .63126 m .64198 .57444 L .63902 .56895 L p .707 .577 .707 r
F P
0 g
s
.65155 .73823 m .65249 .71924 L .63983 .71426 L p .707 .577 .707 r
F P
0 g
s
.63983 .71426 m .63889 .73326 L .65155 .73823 L p .707 .577 .707 r
F P
0 g
s
.83427 .66446 m .83761 .69824 L .84437 .68298 L p .707 .577 .707 r
F P
0 g
s
.84437 .68298 m .84102 .6492 L .83427 .66446 L p .707 .577 .707 r
F P
0 g
s
.63902 .56895 m .63666 .62578 L .63962 .63126 L p .707 .577 .707 r
F P
0 g
s
.64097 .67413 m .64431 .70791 L .65713 .72073 L p .707 .577 .707 r
F P
0 g
s
.84277 .57937 m .84042 .63619 L .83746 .6307 L p .707 .577 .707 r
F P
0 g
s
.83746 .6307 m .83981 .57388 L .84277 .57937 L p .707 .577 .707 r
F P
0 g
s
.83355 .72544 m .83261 .74444 L .8396 .74014 L p .707 .577 .707 r
F P
0 g
s
.8396 .74014 m .84053 .72114 L .83355 .72544 L p .707 .577 .707 r
F P
0 g
s
.64431 .70791 m .64097 .67413 L .63778 .65936 L p .707 .577 .707 r
F P
0 g
s
.63666 .62578 m .63902 .56895 L .64603 .56398 L p .707 .577 .707 r
F P
0 g
s
.63889 .73326 m .63983 .71426 L .63684 .70938 L p .707 .577 .707 r
F P
0 g
s
.84102 .6492 m .84437 .68298 L .84118 .66821 L p .707 .577 .707 r
F P
0 g
s
.84118 .66821 m .83783 .63443 L .84102 .6492 L p .707 .577 .707 r
F P
0 g
s
.63684 .70938 m .6359 .72838 L .63889 .73326 L p .707 .577 .707 r
F P
0 g
s
.64603 .56398 m .64367 .6208 L .63666 .62578 L p .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .63684 .70938 L .64197 .70622 L p .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .64431 .70791 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.64197 .70622 m .64382 .70508 L p .64227 .70964 L .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .64197 .70622 L .64227 .70964 L .707 .577 .707 r
F
.63778 .65936 m .6388 .66969 L p .63813 .66196 L F P
0 g
s
.6388 .66969 m .64112 .69314 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83746 .6307 m .82482 .62525 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .83981 .57388 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .82498 .62131 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82717 .56842 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .80373 .62035 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .8038 .61198 L .82222 .62034 L p .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .82498 .62131 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82482 .62525 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .82717 .56842 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .80399 .61392 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80608 .56352 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .77964 .64028 L p .79298 .62465 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .77626 .61649 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.8038 .61198 m .80399 .61392 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80373 .62035 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .8038 .61198 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .77656 .6092 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .77656 .6092 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77629 .6065 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .80608 .56352 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77861 .55967 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .80399 .61392 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.79298 .62465 m .80238 .61364 L .80399 .61392 L .707 .577 .707 r
F
.80399 .61392 m .80714 .64577 L p .79298 .62465 L F P
0 g
s
.80714 .64577 m .80399 .61392 L p .82485 .62153 L .707 .577 .707 r
F P
0 g
s
.82222 .62034 m .82485 .62153 L p .80399 .61392 L .707 .577 .707 r
F P
0 g
s
.82485 .62153 m .82501 .62161 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .82485 .62153 L .82387 .62315 L .707 .577 .707 r
F
.82501 .62161 m .82835 .65539 L .80952 .64685 L p F P
0 g
s
.80952 .64685 m .80714 .64577 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.82387 .62315 m .82501 .62161 L .80952 .64685 L .707 .577 .707 r
F
.83981 .57388 m .83879 .59849 L p .82688 .61817 L F P
0 g
s
.83879 .59849 m .83746 .6307 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .63778 .65936 L .64453 .6441 L p .707 .577 .707 r
F P
0 g
s
.84053 .72114 m .8396 .74014 L .83661 .73526 L p .707 .577 .707 r
F P
0 g
s
.83661 .73526 m .83755 .71626 L .84053 .72114 L p .707 .577 .707 r
F P
0 g
s
.38897 .6111 m .39133 .55427 L .36017 .55184 L p .707 .577 .707 r
F P
0 g
s
.39133 .55427 m .38897 .6111 L .42078 .61188 L p .707 .577 .707 r
F P
0 g
s
.42078 .61188 m .42313 .55505 L .39133 .55427 L p .707 .577 .707 r
F P
0 g
s
.42313 .55505 m .42078 .61188 L .45011 .61092 L p .707 .577 .707 r
F P
0 g
s
.45011 .61092 m .45246 .5541 L .42313 .55505 L p .707 .577 .707 r
F P
0 g
s
.64367 .6208 m .64603 .56398 L .66233 .56 L p .707 .577 .707 r
F P
0 g
s
.83783 .63443 m .84118 .66821 L .82835 .65539 L p .707 .577 .707 r
F P
0 g
s
.82835 .65539 m .82501 .62161 L .83783 .63443 L p .707 .577 .707 r
F P
0 g
s
.35781 .60866 m .36017 .55184 L .3327 .54798 L p .707 .577 .707 r
F P
0 g
s
.36017 .55184 m .35781 .60866 L .38897 .6111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64382 .70508 m .64288 .72407 L .6359 .72838 L p .707 .577 .707 r
F P
0 g
s
.64453 .6441 m .64788 .67788 L .64112 .69314 L p .707 .577 .707 r
F P
0 g
s
.66233 .56 m .65997 .61682 L .64367 .6208 L p .707 .577 .707 r
F P
0 g
s
.45246 .5541 m .45011 .61092 L .4741 .60833 L p .707 .577 .707 r
F P
0 g
s
.4741 .60833 m .47645 .55151 L .45246 .5541 L p .707 .577 .707 r
F P
0 g
s
.3327 .54798 m .33034 .6048 L .35781 .60866 L p .707 .577 .707 r
F P
0 g
s
.33034 .6048 m .3327 .54798 L .31161 .54308 L p .707 .577 .707 r
F P
0 g
s
.64788 .67788 m .64453 .6441 L .66058 .62983 L p .707 .577 .707 r
F P
0 g
s
.83755 .71626 m .83661 .73526 L .82394 .73028 L p .707 .577 .707 r
F P
0 g
s
.82394 .73028 m .82488 .71128 L .83755 .71626 L p .707 .577 .707 r
F P
0 g
s
.38828 .7123 m .38921 .6933 L .35806 .69076 L p .707 .577 .707 r
F P
0 g
s
.38921 .6933 m .38828 .7123 L .42007 .71339 L p .707 .577 .707 r
F P
0 g
s
.42007 .71339 m .421 .69439 L .38921 .6933 L p .707 .577 .707 r
F P
0 g
s
.39396 .69984 m .39062 .66605 L .3595 .66525 L p .707 .577 .707 r
F P
0 g
s
.421 .69439 m .42007 .71339 L .44938 .71292 L p .707 .577 .707 r
F P
0 g
s
.44938 .71292 m .45031 .69392 L .421 .69439 L p .707 .577 .707 r
F P
0 g
s
.39062 .66605 m .39396 .69984 L .42565 .69589 L p .707 .577 .707 r
F P
0 g
s
.42565 .69589 m .4223 .6621 L .39062 .66605 L p .707 .577 .707 r
F P
0 g
s
.4223 .6621 m .42565 .69589 L .4548 .68757 L p .707 .577 .707 r
F P
0 g
s
.4548 .68757 m .45145 .65379 L .4223 .6621 L p .707 .577 .707 r
F P
0 g
s
.65997 .61682 m .66233 .56 L .68632 .5574 L p .707 .577 .707 r
F P
0 g
s
.31161 .54308 m .30926 .59991 L .33034 .6048 L p .707 .577 .707 r
F P
0 g
s
.35806 .69076 m .35712 .70975 L .38828 .7123 L p .707 .577 .707 r
F P
0 g
s
.35712 .70975 m .35806 .69076 L .33058 .68701 L p .707 .577 .707 r
F P
0 g
s
.36284 .69903 m .3595 .66525 L .33199 .65976 L p .707 .577 .707 r
F P
0 g
s
.3595 .66525 m .36284 .69903 L .39396 .69984 L p .707 .577 .707 r
F P
0 g
s
.47645 .55151 m .4741 .60833 L .4904 .60435 L p .707 .577 .707 r
F P
0 g
s
.4904 .60435 m .49275 .54753 L .47645 .55151 L p .707 .577 .707 r
F P
0 g
s
.64288 .72407 m .64382 .70508 L .66009 .70177 L p .707 .577 .707 r
F P
0 g
s
.45145 .65379 m .4548 .68757 L .47855 .6757 L p .707 .577 .707 r
F P
0 g
s
.47855 .6757 m .47521 .64191 L .45145 .65379 L p .707 .577 .707 r
F P
0 g
s
.66009 .70177 m .65915 .72077 L .64288 .72407 L p .707 .577 .707 r
F P
0 g
s
.66058 .62983 m .66392 .66361 L .64788 .67788 L p .707 .577 .707 r
F P
0 g
s
.68632 .5574 m .68396 .61423 L .65997 .61682 L p .707 .577 .707 r
F P
0 g
s
.33058 .68701 m .32965 .706 L .35712 .70975 L p .707 .577 .707 r
F P
0 g
s
.30926 .59991 m .31161 .54308 L .29897 .53762 L p .707 .577 .707 r
F P
0 g
s
.66392 .66361 m .66058 .62983 L .68434 .61796 L p .707 .577 .707 r
F P
0 g
s
.45031 .69392 m .44938 .71292 L .47334 .71093 L p .707 .577 .707 r
F P
0 g
s
.47334 .71093 m .47427 .69193 L .45031 .69392 L p .707 .577 .707 r
F P
0 g
s
.33533 .69354 m .33199 .65976 L .31078 .65014 L p .707 .577 .707 r
F P
0 g
s
.33199 .65976 m .33533 .69354 L .36284 .69903 L p .707 .577 .707 r
F P
0 g
s
.68396 .61423 m .68632 .5574 L .71565 .55645 L p .707 .577 .707 r
F P
0 g
s
.32506 .68581 m .30948 .68242 L p .33005 .69774 L .707 .577 .707 r
F P
0 g
s
.31412 .68392 m .31098 .65212 L p .29796 .63731 L .707 .577 .707 r
F P
0 g
s
.31098 .65212 m .31078 .65014 L .30969 .64905 L p .707 .577 .707 r
F P
0 g
s
.30969 .64905 m .29796 .63731 L p .31098 .65212 L .707 .577 .707 r
F P
0 g
s
.32965 .706 m .33005 .69774 L p .30948 .68242 L .707 .577 .707 r
F P
0 g
s
.33005 .69774 m .33058 .68701 L .32506 .68581 L p .707 .577 .707 r
F P
0 g
s
.29897 .53762 m .29661 .59445 L .30926 .59991 L p .707 .577 .707 r
F P
0 g
s
.82488 .71128 m .82394 .73028 L .80284 .72569 L p .707 .577 .707 r
F P
0 g
s
.80284 .72569 m .80378 .7067 L .82488 .71128 L p .707 .577 .707 r
F P
0 g
s
.30948 .68242 m .30854 .70142 L .32965 .706 L p .707 .577 .707 r
F P
0 g
s
.47521 .64191 m .47855 .6757 L .4946 .66143 L p .707 .577 .707 r
F P
0 g
s
.4946 .66143 m .49126 .62765 L .47521 .64191 L p .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .7451 .61406 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77626 .61649 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .74851 .63947 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .77656 .6092 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77964 .64028 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .77629 .6065 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .74536 .60762 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .74536 .60762 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74517 .60569 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .77861 .55967 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74745 .55723 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .77656 .6092 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .71329 .61328 L .68396 .61423 L p .707 .577 .707 r
F P
0 g
s
.49275 .54753 m .4904 .60435 L .49741 .59937 L p .707 .577 .707 r
F P
0 g
s
.49741 .59937 m .49976 .54255 L .49275 .54753 L p .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .74745 .55723 L p .72303 .59729 L .707 .577 .707 r
F P
0 g
s
.71329 .61328 m .71346 .60934 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.71765 .60912 m .74517 .60569 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .71329 .61328 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .74536 .60762 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .74536 .60762 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .7451 .61406 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .71683 .64342 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74851 .63947 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71349 .60964 L .71765 .60912 L p .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71765 .60912 L .74365 .60772 L .707 .577 .707 r
F
.71576 .60922 m .71346 .60934 L .72303 .59729 L F
.71346 .60934 m .71565 .55645 L p .72303 .59729 L F P
0 g
s
.68768 .65174 m .6868 .64288 L p .71349 .60964 L .707 .577 .707 r
F P
0 g
s
.6868 .64288 m .68434 .61796 L .71315 .60973 L p .707 .577 .707 r
F P
0 g
s
.71315 .60973 m .71349 .60964 L p .6868 .64288 L .707 .577 .707 r
F P
0 g
s
.68434 .61796 m .68768 .65174 L .66392 .66361 L p .707 .577 .707 r
F P
0 g
s
.65915 .72077 m .66009 .70177 L .68405 .69979 L p .707 .577 .707 r
F P
0 g
s
.68405 .69979 m .68311 .71878 L .65915 .72077 L p .707 .577 .707 r
F P
0 g
s
.31078 .65014 m .31412 .68392 L .33533 .69354 L p .707 .577 .707 r
F P
0 g
s
.47427 .69193 m .47334 .71093 L .4896 .70762 L p .707 .577 .707 r
F P
0 g
s
.4896 .70762 m .49054 .68863 L .47427 .69193 L p .707 .577 .707 r
F P
0 g
s
.29661 .59445 m .29897 .53762 L .29601 .53214 L p .707 .577 .707 r
F P
0 g
s
.71349 .60964 m .71683 .64342 L .68768 .65174 L p .707 .577 .707 r
F P
0 g
s
.30854 .70142 m .30948 .68242 L .29682 .67744 L p .707 .577 .707 r
F P
0 g
s
.80378 .7067 m .80284 .72569 L .77537 .72194 L p .707 .577 .707 r
F P
0 g
s
.77537 .72194 m .7763 .70295 L .80378 .7067 L p .707 .577 .707 r
F P
0 g
s
.29682 .67744 m .29588 .69644 L .30854 .70142 L p .707 .577 .707 r
F P
0 g
s
.49126 .62765 m .4946 .66143 L .50136 .64617 L p .707 .577 .707 r
F P
0 g
s
.50136 .64617 m .49801 .61238 L .49126 .62765 L p .707 .577 .707 r
F P
0 g
s
.29601 .53214 m .29365 .58896 L .29661 .59445 L p .707 .577 .707 r
F P
0 g
s
.68311 .71878 m .68405 .69979 L .71336 .69931 L p .707 .577 .707 r
F P
0 g
s
.71336 .69931 m .71242 .71831 L .68311 .71878 L p .707 .577 .707 r
F P
0 g
s
.29796 .63731 m .3013 .6711 L .31412 .68392 L p .707 .577 .707 r
F P
0 g
s
.49976 .54255 m .49741 .59937 L .49445 .59389 L p .707 .577 .707 r
F P
0 g
s
.49445 .59389 m .4968 .53706 L .49976 .54255 L p .707 .577 .707 r
F P
0 g
s
.7763 .70295 m .77537 .72194 L .74421 .7194 L p .707 .577 .707 r
F P
0 g
s
.74421 .7194 m .74515 .7004 L .7763 .70295 L p .707 .577 .707 r
F P
0 g
s
.49054 .68863 m .4896 .70762 L .49659 .70332 L p .707 .577 .707 r
F P
0 g
s
.49659 .70332 m .49752 .68432 L .49054 .68863 L p .707 .577 .707 r
F P
0 g
s
.71242 .71831 m .71336 .69931 L .74515 .7004 L p .707 .577 .707 r
F P
0 g
s
.3013 .6711 m .29796 .63731 L .29477 .62255 L p .707 .577 .707 r
F P
0 g
s
.74515 .7004 m .74421 .7194 L .71242 .71831 L p .707 .577 .707 r
F P
0 g
s
.29365 .58896 m .29601 .53214 L .30302 .52716 L p .707 .577 .707 r
F P
0 g
s
.29588 .69644 m .29682 .67744 L .29383 .67257 L p .707 .577 .707 r
F P
0 g
s
.49801 .61238 m .50136 .64617 L .49817 .6314 L p .707 .577 .707 r
F P
0 g
s
.49817 .6314 m .49482 .59762 L .49801 .61238 L p .707 .577 .707 r
F P
0 g
s
.29383 .67257 m .29289 .69156 L .29588 .69644 L p .707 .577 .707 r
F P
0 g
s
.30302 .52716 m .30066 .58399 L .29365 .58896 L p .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29383 .67257 L .29896 .6694 L p .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .3013 .6711 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.29896 .6694 m .30081 .66826 L p .29926 .67282 L .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29896 .6694 L .29926 .67282 L .707 .577 .707 r
F
.29477 .62255 m .29579 .63288 L p .29512 .62515 L F P
0 g
s
.29579 .63288 m .29811 .65633 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49445 .59389 m .4818 .58843 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .4968 .53706 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .48197 .5845 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .48416 .5316 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .46072 .58353 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46079 .57517 L .47921 .58353 L p .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .48197 .5845 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .4818 .58843 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .48416 .5316 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .46098 .5771 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46307 .52671 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .43662 .60346 L p .44997 .58784 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .43325 .57968 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46079 .57517 m .46098 .5771 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46072 .58353 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .46079 .57517 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .43355 .57239 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .43355 .57239 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43328 .56968 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .46307 .52671 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .4356 .52285 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .46098 .5771 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.44997 .58784 m .45937 .57683 L .46098 .5771 L .707 .577 .707 r
F
.46098 .5771 m .46413 .60895 L p .44997 .58784 L F P
0 g
s
.46413 .60895 m .46098 .5771 L p .48183 .58472 L .707 .577 .707 r
F P
0 g
s
.47921 .58353 m .48183 .58472 L p .46098 .5771 L .707 .577 .707 r
F P
0 g
s
.48183 .58472 m .482 .58479 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .48183 .58472 L .48086 .58633 L .707 .577 .707 r
F
.482 .58479 m .48534 .61858 L .46651 .61003 L p F P
0 g
s
.46651 .61003 m .46413 .60895 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.48086 .58633 m .482 .58479 L .46651 .61003 L .707 .577 .707 r
F
.4968 .53706 m .49578 .56168 L p .48387 .58136 L F P
0 g
s
.49578 .56168 m .49445 .59389 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .29477 .62255 L .30152 .60728 L p .707 .577 .707 r
F P
0 g
s
.49752 .68432 m .49659 .70332 L .4936 .69844 L p .707 .577 .707 r
F P
0 g
s
.4936 .69844 m .49454 .67945 L .49752 .68432 L p .707 .577 .707 r
F P
0 g
s
.30066 .58399 m .30302 .52716 L .31932 .52318 L p .707 .577 .707 r
F P
0 g
s
.49482 .59762 m .49817 .6314 L .48534 .61858 L p .707 .577 .707 r
F P
0 g
s
.48534 .61858 m .482 .58479 L .49482 .59762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30081 .66826 m .29987 .68726 L .29289 .69156 L p .707 .577 .707 r
F P
0 g
s
.30152 .60728 m .30487 .64106 L .29811 .65633 L p .707 .577 .707 r
F P
0 g
s
.31932 .52318 m .31696 .58001 L .30066 .58399 L p .707 .577 .707 r
F P
0 g
s
.30487 .64106 m .30152 .60728 L .31757 .59301 L p .707 .577 .707 r
F P
0 g
s
.49454 .67945 m .4936 .69844 L .48093 .69347 L p .707 .577 .707 r
F P
0 g
s
.48093 .69347 m .48187 .67447 L .49454 .67945 L p .707 .577 .707 r
F P
0 g
s
.31696 .58001 m .31932 .52318 L .3433 .52059 L p .707 .577 .707 r
F P
0 g
s
.29987 .68726 m .30081 .66826 L .31708 .66496 L p .707 .577 .707 r
F P
0 g
s
.31708 .66496 m .31614 .68395 L .29987 .68726 L p .707 .577 .707 r
F P
0 g
s
.31757 .59301 m .32091 .6268 L .30487 .64106 L p .707 .577 .707 r
F P
0 g
s
.3433 .52059 m .34095 .57741 L .31696 .58001 L p .707 .577 .707 r
F P
0 g
s
.32091 .6268 m .31757 .59301 L .34133 .58114 L p .707 .577 .707 r
F P
0 g
s
.34095 .57741 m .3433 .52059 L .37264 .51963 L p .707 .577 .707 r
F P
0 g
s
.48187 .67447 m .48093 .69347 L .45983 .68888 L p .707 .577 .707 r
F P
0 g
s
.45983 .68888 m .46077 .66988 L .48187 .67447 L p .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .40209 .57724 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43325 .57968 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .4055 .60266 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .43355 .57239 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43662 .60346 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .43328 .56968 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .40235 .57081 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .40235 .57081 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40216 .56887 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .4356 .52285 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40444 .52041 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .43355 .57239 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .37028 .57646 L .34095 .57741 L p .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .40444 .52041 L p .38002 .56048 L .707 .577 .707 r
F P
0 g
s
.37028 .57646 m .37045 .57253 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.37464 .5723 m .40216 .56887 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .37028 .57646 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .40235 .57081 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .40235 .57081 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40209 .57724 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .37382 .60661 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .4055 .60266 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37047 .57282 L .37464 .5723 L p .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37464 .5723 L .40064 .5709 L .707 .577 .707 r
F
.37275 .5724 m .37045 .57253 L .38002 .56048 L F
.37045 .57253 m .37264 .51963 L p .38002 .56048 L F P
0 g
s
.34467 .61492 m .34379 .60607 L p .37047 .57282 L .707 .577 .707 r
F P
0 g
s
.34379 .60607 m .34133 .58114 L .37014 .57292 L p .707 .577 .707 r
F P
0 g
s
.37014 .57292 m .37047 .57282 L p .34379 .60607 L .707 .577 .707 r
F P
0 g
s
.34133 .58114 m .34467 .61492 L .32091 .6268 L p .707 .577 .707 r
F P
0 g
s
.31614 .68395 m .31708 .66496 L .34104 .66297 L p .707 .577 .707 r
F P
0 g
s
.34104 .66297 m .3401 .68197 L .31614 .68395 L p .707 .577 .707 r
F P
0 g
s
.37047 .57282 m .37382 .60661 L .34467 .61492 L p .707 .577 .707 r
F P
0 g
s
.46077 .66988 m .45983 .68888 L .43236 .68513 L p .707 .577 .707 r
F P
0 g
s
.43236 .68513 m .43329 .66613 L .46077 .66988 L p .707 .577 .707 r
F P
0 g
s
.3401 .68197 m .34104 .66297 L .37035 .6625 L p .707 .577 .707 r
F P
0 g
s
.37035 .6625 m .36941 .6815 L .3401 .68197 L p .707 .577 .707 r
F P
0 g
s
.43329 .66613 m .43236 .68513 L .4012 .68258 L p .707 .577 .707 r
F P
0 g
s
.4012 .68258 m .40214 .66359 L .43329 .66613 L p .707 .577 .707 r
F P
0 g
s
.36941 .6815 m .37035 .6625 L .40214 .66359 L p .707 .577 .707 r
F P
0 g
s
.40214 .66359 m .4012 .68258 L .36941 .6815 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Yoo`d008Io
o`00OWoo30001UYF00<005YFFUH015YF2@00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol007=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@007=oo`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001]Ool30007FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006]oo`80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8006]oo`00JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uoo`00Igoo
0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00<005YF00001`0000=JEP00FUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00FGoo3@000eYF00<005YFFUH00UYF4@001EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000QooaT004Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000eOol005=oo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP05Ool005YFFUH0000^Ool005=oo`03001JEP0000=J
EPd000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol01000FUH005YF0P0015YF00<005YF
FUH00`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00L005YFFUIJEWooFUH00002FUH2000]Ool005=oo`03001JEP00008000EJEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF00EooeYFFUIJEP0000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P000UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP0000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P00;Goo001COol20002FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001DOol200000eYF
001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`<00003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06
001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EWoo00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000EJEP03001JEUYF00=JEP04001JEUYF0004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000QJEP03001JEUYF00AJEP@00003FUH005YF00AJEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00?goo20003Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH03`0015YF
00<005YFFUH00UYF2P000eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000cOol<0003FUH0
0`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH300001Goo001JEUYF00001UYF00@005YFFUIJEPT0
00QJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`000UYF0`001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
1EYF00<005YFFUH00`0017oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH010001EYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0;7oo000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30003FUH300001Goo001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF0P000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P000UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P001EYF00@005YF0000009JEP03001J
EUYF00AJEP<000IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF008000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEP00FUH0
000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYF0003FUH00`00FUH00005FUH01000FUIJEP000UYF00<005YFFUH00eYF
1@001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0000=JEP0000000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH00`00FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50005
FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF00@005YF0000009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002eo
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP05001JEUYFFUIoo`04FUH00`00FUIJ
EP06FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF0`001UYF
00<005YFFUH02EYF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70008
FUH80004FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF0P0000=JEP00FUH00UYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EPH000AJEP03001JEUYF008002eoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000UYF00D005YFFUIJEP0000EJEP04001JEUYF0002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH00`00FUH000020004OolI0002Ool20002FUH00`00FUIJEP02000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0`0097oo0`000UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP020005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF0P00:Goo00D0
05YFFUIJEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF0`000UYF00@005YFFUH0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00D005YF000005YF00@002Moo`04001JEUYF000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP8000MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEQ`000IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000EJEP<002Ioo`03001JEP0002eoo`00;7oo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF0P0025YF00<005YFFUH01UYF0P000UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH01@00FUIJEP00FUH00P001EYF00@005YFFUH000Uoo`<001Qoo`@002eoo`00;7oo00<005YF0000
15YF00@005YFFUIJEPX00003FUH005YF00MJEP03001JEUYF00IJEP@0009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
00000UYF0P001EYF00<005YFFUH00P001goo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YF
00000UYF1P000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP8000=JEP8000AJEP80009JEP8000Moo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00FUH0
00020005FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF0P0015YF0P000UYF0P001goo1@0057oo00L005YFFUIJEP00FUH0
000]Ool002aoo`80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0P000UYF0P0027oo0`004goo
0P0015YF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH@0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0P000UYF0P0077oo0P0000=J
EP00FUH015YF0P00;Goo000]Ool200000eYF001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH000020002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5
0005FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00@005YF
FUIJEP8001Yoo`8000=JEP03001JEUYF00=JEP8002eoo`00;goo0`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH015YF1@001EYF00<005YFFUH010001EYF0`0000=JEP00FUH00UYF0P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`0000=J
EP00FUH015YF00@005YFFUIJEP8001Moo`<000EJEP03001JEUYF00=JEP03001oogoo02aoo`00;goo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPd0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00EJEP<000AJEPh0009JEP@0009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH20005FUH01000FUIJEUYF0P00
4goo100000=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH60008FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YF
FUH00eYF200015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP@0
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEPH000=JEPP000Ioo`L000EJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo02ao
o`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF3@0015YF00<005YFFUH00UYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`001EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00000030000eYF00<005YFFUH00UYF4@0000=JEP00FUH01UYF00D005YFFUIJ
EP0002moo`00;Goo0P001EYF00<005YFFUH00eYF00<005YF00000P003Goo2@001Goo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000=JEP04001JEP00000`Ool002eoo`8000EJEP03001JEUYF00=JEP8002Aoo`X000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004000bOol002aoo`03
001JEP0000EJEP04001JEUYFFUH2000XOol01000FUIJEP000UYF00<005YF00007P0025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
035oo`00;7oo00<005YF00001EYF00@005YF000002]oo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`04
001JEUYF0004FUH2000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04001J
EUYF0003FUH00`00Oomoo`0BOol3000HOol30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH0100000=JEP0000000UYF0P001eYF00<005YFFUH01EYF1@000eYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00D005YFFUH005YF008001Aoo`D001Ioo`04001JEP00
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF20000eYF00<005YFFUH00P00;Woo
000/Ool00`00FUIJEP02000FOol5000EOol00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH30006FUH00`00
FUH0000>0002FUH2000^Ool002eoo`03001JEP0001Moo`D001Aoo`04001JEUYFFUH20002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool4000GOol3000COol30003FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH50004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000]Ool20002FUH00`00Oomoo`0XOol20002FUH00`00FUIJEP02FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`04001JEUYFFUH2
000WOol20004FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH015YF
300000=JEP00FUH02EYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo1@0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00;goo
000]Ool01P00FUIJEUYF001JEP<0029oo`8000IJEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000;Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Woo
000]Ool20002FUH00`00FUIJEP02FUH3000KOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YF000010001UYF00<005YFFUH00UYF0P003Goo00@005YFFUH0009ooaX003Qoo`00;Goo
0P000UYF8`001EYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP00
00<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP8000ioo`03001JEP0005Aoo`00;Woo0`000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH00P000UYF
00<005YFFUH00eYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF100015YF0P003Woo0`00E7oo000]Ool20004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF001o
o`00009JEP04001JEUYFFUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF0P003Goo0P0000=JEP000000Dgoo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP050002Ool01@00FUIJEP00FUH00`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000002goo0P0000=JEP00FUH00P00Dgoo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH3000017oo001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10002Woo00H005YF
FUIJEP00FUH2001COol002aoo`03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01000FUH0000027oo0P0015YF00@005YFFUH005=oo`00;7oo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH01EYF400015YF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000006Ool200000eYF001JEP04FUH00`00
FUH0001COol002aoo`03001JEP000080009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP0017oo0P000eYF00<005YFFUH00eYF0P00E7oo000/Ool20002FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP02FUH20004Ool300000eYF
001JEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00Ool00`001EYF00<0
05YFFUH00eYF0P00E7oo000]Ool01000FUIJEP001EYF10001UYF00<005YFFUH01EYF0`001eYF00<0
05YF000020000UYF10000UYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0Dgoo000^Ool30005FUH01000FUIJEUYF1000
0UYF00<005YFFUH01EYF00<005YFFUH00eYF1P001EYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo05=oo`00<7oo0`000eYF00<005YFFUH01EYF40000UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@0000=JEP00FUH0
1UYF00D005YFFUIJEP0005Ioo`00<goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000eYF1P000eYF00@005YF000005Moo`00>Woo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0017oo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP800003FUH005YF00IJEP03001JEP0000@005Uoo`00@goo7`002Goo0`001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF009JEP<005Qoo`00KWoo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P00EGoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000EGoo001cOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH50002FUH50003FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001gOol60002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001eYF1@001EYF00<005YFFUH00eYF
1`000eYF00<005YFFUH00P00EGoo001mOolO0005FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP0?
00000eYF0000001EOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF
00IJEP<0009JEPL000AJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol0091oo`@000AJEP03001J
EUYF00AJEQ0000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol009Aoo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000EGoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03001FOol009aooa4000AJEP03001JEUYF00IJEP04
001JEUYFFUH6001IOol00:eooa4005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59417 .73379 m .59797 .67654 L .56682 .67377 L p .707 .577 .707 r
F P
0 g
s
.59797 .67654 m .59417 .73379 L .62592 .73554 L p .707 .577 .707 r
F P
0 g
s
.62592 .73554 m .62972 .67829 L .59797 .67654 L p .707 .577 .707 r
F P
0 g
s
.62972 .67829 m .62592 .73554 L .65517 .73611 L p .707 .577 .707 r
F P
0 g
s
.65517 .73611 m .65897 .67886 L .62972 .67829 L p .707 .577 .707 r
F P
0 g
s
.56682 .67377 m .56303 .73101 L .59417 .73379 L p .707 .577 .707 r
F P
0 g
s
.56303 .73101 m .56682 .67377 L .53934 .67025 L p .707 .577 .707 r
F P
0 g
s
.53934 .67025 m .53554 .7275 L .56303 .73101 L p .707 .577 .707 r
F P
0 g
s
.65897 .67886 m .65517 .73611 L .67906 .73543 L p .707 .577 .707 r
F P
0 g
s
.67906 .73543 m .68285 .67818 L .65897 .67886 L p .707 .577 .707 r
F P
0 g
s
.53554 .7275 m .53934 .67025 L .5182 .66633 L p .707 .577 .707 r
F P
0 g
s
.5182 .66633 m .5144 .72357 L .53554 .7275 L p .707 .577 .707 r
F P
0 g
s
.59313 .83296 m .59464 .81384 L .56351 .81089 L p .707 .577 .707 r
F P
0 g
s
.59464 .81384 m .59313 .83296 L .62485 .83522 L p .707 .577 .707 r
F P
0 g
s
.62485 .83522 m .62636 .8161 L .59464 .81384 L p .707 .577 .707 r
F P
0 g
s
.56351 .81089 m .562 .83001 L .59313 .83296 L p .707 .577 .707 r
F P
0 g
s
.62636 .8161 m .62485 .83522 L .65404 .83657 L p .707 .577 .707 r
F P
0 g
s
.65404 .83657 m .65555 .81745 L .62636 .8161 L p .707 .577 .707 r
F P
0 g
s
.60296 .83904 m .59763 .80824 L .56659 .80804 L p .707 .577 .707 r
F P
0 g
s
.59763 .80824 m .60296 .83904 L .6344 .83331 L p .707 .577 .707 r
F P
0 g
s
.6344 .83331 m .62907 .80251 L .59763 .80824 L p .707 .577 .707 r
F P
0 g
s
.65555 .81745 m .65404 .83657 L .67785 .83689 L p .707 .577 .707 r
F P
0 g
s
.67785 .83689 m .67936 .81777 L .65555 .81745 L p .707 .577 .707 r
F P
0 g
s
.62907 .80251 m .6344 .83331 L .66318 .82222 L p .707 .577 .707 r
F P
0 g
s
.66318 .82222 m .65785 .79141 L .62907 .80251 L p .707 .577 .707 r
F P
0 g
s
.562 .83001 m .56351 .81089 L .53601 .80755 L p .707 .577 .707 r
F P
0 g
s
.68285 .67818 m .67906 .73543 L .69524 .73358 L p .707 .577 .707 r
F P
0 g
s
.69524 .73358 m .69904 .67633 L .68285 .67818 L p .707 .577 .707 r
F P
0 g
s
.53601 .80755 m .5345 .82667 L .562 .83001 L p .707 .577 .707 r
F P
0 g
s
.57192 .83885 m .56659 .80804 L .539 .80195 L p .707 .577 .707 r
F P
0 g
s
.56659 .80804 m .57192 .83885 L .60296 .83904 L p .707 .577 .707 r
F P
0 g
s
.65785 .79141 m .66318 .82222 L .68647 .80685 L p .707 .577 .707 r
F P
0 g
s
.68647 .80685 m .68114 .77604 L .65785 .79141 L p .707 .577 .707 r
F P
0 g
s
.5144 .72357 m .5182 .66633 L .50547 .66239 L p .707 .577 .707 r
F P
0 g
s
.5345 .82667 m .53601 .80755 L .51484 .80413 L p .707 .577 .707 r
F P
0 g
s
.50547 .66239 m .50168 .71964 L .5144 .72357 L p .707 .577 .707 r
F P
0 g
s
.51484 .80413 m .51332 .82325 L .5345 .82667 L p .707 .577 .707 r
F P
0 g
s
.54433 .83275 m .539 .80195 L .51755 .79054 L p .707 .577 .707 r
F P
0 g
s
.539 .80195 m .54433 .83275 L .57192 .83885 L p .707 .577 .707 r
F P
0 g
s
.68114 .77604 m .68647 .80685 L .70199 .78871 L p .707 .577 .707 r
F P
0 g
s
.70199 .78871 m .69666 .7579 L .68114 .77604 L p .707 .577 .707 r
F P
0 g
s
.69904 .67633 m .69524 .73358 L .70214 .73072 L p .707 .577 .707 r
F P
0 g
s
.70214 .73072 m .70593 .67347 L .69904 .67633 L p .707 .577 .707 r
F P
0 g
s
.67936 .81777 m .67785 .83689 L .69396 .83613 L p .707 .577 .707 r
F P
0 g
s
.69396 .83613 m .69547 .81701 L .67936 .81777 L p .707 .577 .707 r
F P
0 g
s
.50168 .71964 m .50547 .66239 L .50241 .65882 L p .707 .577 .707 r
F P
0 g
s
.51332 .82325 m .51484 .80413 L .50205 .80098 L p .707 .577 .707 r
F P
0 g
s
.50205 .80098 m .50054 .8201 L .51332 .82325 L p .707 .577 .707 r
F P
0 g
s
.52288 .82134 m .51755 .79054 L .50436 .77494 L p .707 .577 .707 r
F P
0 g
s
.51755 .79054 m .52288 .82134 L .54433 .83275 L p .707 .577 .707 r
F P
0 g
s
.50241 .65882 m .49861 .71607 L .50168 .71964 L p .707 .577 .707 r
F P
0 g
s
.69666 .7579 m .70199 .78871 L .70823 .76957 L p .707 .577 .707 r
F P
0 g
s
.70823 .76957 m .7029 .73876 L .69666 .7579 L p .707 .577 .707 r
F P
0 g
s
.69547 .81701 m .69396 .83613 L .70077 .83437 L p .707 .577 .707 r
F P
0 g
s
.70077 .83437 m .70228 .81525 L .69547 .81701 L p .707 .577 .707 r
F P
0 g
s
.70115 .72957 m .69907 .72715 L p .69965 .72263 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69924 .72049 L .69988 .72369 L p .708 .578 .707 r
F P
0 g
s
.70287 .6699 m .70593 .67347 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .69944 .72164 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .70287 .6699 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .68635 .72322 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69924 .72049 m .69944 .72164 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69907 .72715 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69924 .72049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68635 .72322 m .68714 .71125 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .68714 .71125 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .68604 .7049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .70287 .6699 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .69014 .66597 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.70287 .6699 m .69944 .72164 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .69889 .72118 L .69944 .72164 L .707 .577 .707 r
F
.69944 .72164 m .70457 .7513 L .69427 .73913 L p F P
0 g
s
.69427 .73913 m .69137 .7357 L p .69944 .72164 L .707 .577 .707 r
F P
0 g
s
.70457 .7513 m .69944 .72164 L p .7029 .73876 L .708 .578 .707 r
F P
0 g
s
.69988 .72369 m .7029 .73876 L p .69944 .72164 L .708 .578 .707 r
F P
0 g
s
.70593 .67347 m .70214 .73072 L .70115 .72957 L p .707 .577 .707 r
F P
0 g
s
.69965 .72263 m .70593 .67347 L .70115 .72957 L .707 .577 .707 r
F
.49394 .82294 m .48875 .32471 L .44474 .32221 L p F P
0 g
s
.50436 .77494 m .50968 .80575 L .52288 .82134 L p .707 .577 .707 r
F P
0 g
s
.50968 .80575 m .50436 .77494 L .5007 .75668 L p .708 .578 .707 r
F P
0 g
s
.50054 .8201 m .50205 .80098 L .49892 .7984 L p .707 .577 .707 r
F P
0 g
s
.49892 .7984 m .49741 .81752 L .50054 .8201 L p .707 .577 .707 r
F P
0 g
s
.49861 .71607 m .50241 .65882 L .5093 .65596 L p .707 .577 .707 r
F P
0 g
s
.5093 .65596 m .50551 .71321 L .49861 .71607 L p .707 .577 .707 r
F P
0 g
s
.5007 .75668 m .50602 .78748 L .50968 .80575 L p .708 .578 .707 r
F P
0 g
s
.50602 .78748 m .5007 .75668 L .50693 .73753 L p .707 .577 .707 r
F P
0 g
s
.49741 .81752 m .49892 .7984 L .50574 .79664 L p .707 .577 .707 r
F P
0 g
s
.50551 .71321 m .5093 .65596 L .52549 .65411 L p .707 .577 .707 r
F P
0 g
s
.50574 .79664 m .50423 .81576 L .49741 .81752 L p .707 .577 .707 r
F P
0 g
s
.52549 .65411 m .52169 .71136 L .50551 .71321 L p .707 .577 .707 r
F P
0 g
s
.50693 .73753 m .51226 .76834 L .50602 .78748 L p .707 .577 .707 r
F P
0 g
s
.51226 .76834 m .50693 .73753 L .52246 .71939 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .52549 .65411 L .54937 .65343 L p .707 .577 .707 r
F P
0 g
s
.50423 .81576 m .50574 .79664 L .52184 .79588 L p .707 .577 .707 r
F P
0 g
s
.52184 .79588 m .52033 .81501 L .50423 .81576 L p .707 .577 .707 r
F P
0 g
s
.54167 .70671 m .54575 .70402 L p .54519 .70544 L .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .57452 .69293 L p .57038 .70032 L .707 .577 .707 r
F P
0 g
s
.5469 .70498 m .54575 .70402 L .57038 .70032 L .707 .577 .707 r
F
.54937 .65343 m .57862 .654 L p .54916 .70453 L F P
0 g
s
.54558 .71068 m .54594 .70517 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .54575 .70402 L p .5469 .70498 L .707 .577 .707 r
F P
0 g
s
.57483 .71125 m .54558 .71068 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .5469 .70498 L .56118 .71677 L .707 .577 .707 r
F
.57452 .69293 m .60597 .6872 L p .59855 .69757 L F P
0 g
s
.58137 .69885 m .57452 .69293 L .59855 .69757 L .707 .577 .707 r
F
.57862 .654 m .61037 .65575 L p .58284 .69874 L F P
0 g
s
.57483 .71125 m .57562 .69928 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .57452 .69293 L p .58137 .69885 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .57483 .71125 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .58137 .69885 L .59142 .70755 L .707 .577 .707 r
F
.63772 .71578 m .60658 .713 L p .61666 .69728 L F P
0 g
s
.60597 .6872 m .63701 .68739 L p .62828 .69778 L .707 .577 .707 r
F P
0 g
s
.6154 .69723 m .60597 .6872 L .62828 .69778 L .707 .577 .707 r
F
.66521 .71929 m .63772 .71578 L p .64707 .69972 L F P
0 g
s
.63701 .68739 m .6646 .69349 L p .65732 .70157 L .707 .577 .707 r
F P
0 g
s
.64643 .6996 m .63701 .68739 L .65732 .70157 L .707 .577 .707 r
F
.68635 .72322 m .66521 .71929 L p .67175 .7053 L F P
0 g
s
.6646 .69349 m .68604 .7049 L p .68231 .70939 L .707 .577 .707 r
F P
0 g
s
.67212 .70545 m .6646 .69349 L .68231 .70939 L .707 .577 .707 r
F
.68714 .71125 m .68635 .72322 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .6646 .69349 L p .67212 .70545 L .707 .577 .707 r
F P
0 g
s
.66521 .71929 m .66628 .70319 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.66628 .70319 m .67212 .70545 L .67792 .71467 L .707 .577 .707 r
F
.669 .66205 m .69014 .66597 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .669 .66205 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69137 .7357 L .66993 .7243 L p .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .68714 .71125 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.67792 .71467 m .67212 .70545 L .68231 .70939 L .707 .577 .707 r
F
.66993 .7243 m .66628 .70319 L p .67792 .71467 L F P
0 g
s
.66628 .70319 m .66521 .71929 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.6646 .69349 m .66993 .7243 L .64233 .7182 L p .707 .577 .707 r
F P
0 g
s
.64707 .69972 m .65279 .68989 L .66628 .70319 L .707 .577 .707 r
F
.669 .66205 m .66628 .70319 L p .65279 .68989 L F P
0 g
s
.64152 .65853 m .669 .66205 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63772 .71578 m .63888 .69824 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .63701 .68739 L p .64643 .6996 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64152 .65853 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64643 .6996 L .65227 .70717 L .707 .577 .707 r
F
.65227 .70717 m .64643 .6996 L .65732 .70157 L F
.64233 .7182 m .63888 .69824 L p .65227 .70717 L F P
0 g
s
.63888 .69824 m .63772 .71578 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.63701 .68739 m .64233 .7182 L .6113 .718 L p .707 .577 .707 r
F P
0 g
s
.61666 .69728 m .62289 .68757 L .63888 .69824 L .707 .577 .707 r
F
.64152 .65853 m .63888 .69824 L p .62289 .68757 L F P
0 g
s
.61037 .65575 m .64152 .65853 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .60765 .6969 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .60597 .6872 L p .6154 .69723 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .61037 .65575 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .6154 .69723 L .62245 .70473 L .707 .577 .707 r
F
.62245 .70473 m .6154 .69723 L .62828 .69778 L F
.6113 .718 m .60765 .6969 L p .62245 .70473 L F P
0 g
s
.60765 .6969 m .60658 .713 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.60597 .6872 m .6113 .718 L .57985 .72373 L p .707 .577 .707 r
F P
0 g
s
.58284 .69874 m .59 .68756 L .60765 .6969 L .707 .577 .707 r
F
.61037 .65575 m .60765 .6969 L p .59 .68756 L F P
0 g
s
.57562 .69928 m .57862 .654 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.59142 .70755 m .58137 .69885 L .59855 .69757 L .707 .577 .707 r
F
.57985 .72373 m .57562 .69928 L p .59142 .70755 L F P
0 g
s
.57562 .69928 m .57483 .71125 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.57452 .69293 m .57985 .72373 L .55107 .73483 L p .707 .577 .707 r
F P
0 g
s
.54916 .70453 m .55769 .6899 L .57562 .69928 L .707 .577 .707 r
F
.57862 .654 m .57562 .69928 L p .55769 .6899 L F P
0 g
s
.54594 .70517 m .54937 .65343 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.56118 .71677 m .5469 .70498 L .57038 .70032 L .707 .577 .707 r
F
.55107 .73483 m .54594 .70517 L p .56118 .71677 L F P
0 g
s
.54594 .70517 m .54558 .71068 L .52939 .71114 L p .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .55107 .73483 L .52778 .7502 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .53033 .69328 L .54594 .70517 L .707 .577 .707 r
F
.54937 .65343 m .54594 .70517 L p .53033 .69328 L F P
0 g
s
.52939 .71114 m .52169 .71136 L p .54594 .70517 L .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .52246 .71939 L .54167 .70671 L p .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .54167 .70671 L .54519 .70544 L .707 .577 .707 r
F
.52246 .71939 m .52778 .7502 L .51226 .76834 L p F P
0 g
s
.52033 .81501 m .52184 .79588 L .54565 .7962 L p .707 .577 .707 r
F P
0 g
s
.54565 .7962 m .54414 .81532 L .52033 .81501 L p .707 .577 .707 r
F P
0 g
s
.48875 .32471 m .49394 .82294 L .53888 .82132 L p .707 .577 .707 r
F P
0 g
s
.53888 .82132 m .53369 .32309 L .48875 .32471 L p .707 .577 .707 r
F P
0 g
s
.54414 .81532 m .54565 .7962 L .57485 .79755 L p .707 .577 .707 r
F P
0 g
s
.57485 .79755 m .57334 .81667 L .54414 .81532 L p .707 .577 .707 r
F P
0 g
s
.57334 .81667 m .57485 .79755 L .60656 .79981 L p .707 .577 .707 r
F P
0 g
s
.60656 .79981 m .60505 .81893 L .57334 .81667 L p .707 .577 .707 r
F P
0 g
s
.53369 .32309 m .53888 .82132 L .58036 .81572 L p .707 .577 .707 r
F P
0 g
s
.58036 .81572 m .57517 .3175 L .53369 .32309 L p .707 .577 .707 r
F P
0 g
s
.7029 .73876 m .70823 .76957 L .70457 .7513 L p .708 .578 .707 r
F P
0 g
s
.44993 .82044 m .44474 .32221 L .40598 .31583 L p .707 .577 .707 r
F P
0 g
s
.44474 .32221 m .44993 .82044 L .49394 .82294 L p .707 .577 .707 r
F P
0 g
s
.60505 .81893 m .60656 .79981 L .63769 .80276 L p .707 .577 .707 r
F P
0 g
s
.57517 .3175 m .58036 .81572 L .61431 .80671 L p .707 .577 .707 r
F P
0 g
s
.61431 .80671 m .60912 .30849 L .57517 .3175 L p .707 .577 .707 r
F P
0 g
s
.70228 .81525 m .70077 .83437 L .69764 .83179 L p .707 .577 .707 r
F P
0 g
s
.69764 .83179 m .69915 .81267 L .70228 .81525 L p .707 .577 .707 r
F P
0 g
s
.41117 .81406 m .40598 .31583 L .37625 .30619 L p .707 .577 .707 r
F P
0 g
s
.40598 .31583 m .41117 .81406 L .44993 .82044 L p .707 .577 .707 r
F P
0 g
s
.25116 .69697 m .25496 .63972 L .22381 .63695 L p .707 .577 .707 r
F P
0 g
s
.25496 .63972 m .25116 .69697 L .28291 .69873 L p .707 .577 .707 r
F P
0 g
s
.28291 .69873 m .28671 .64148 L .25496 .63972 L p .707 .577 .707 r
F P
0 g
s
.28671 .64148 m .28291 .69873 L .31216 .6993 L p .707 .577 .707 r
F P
0 g
s
.31216 .6993 m .31596 .64205 L .28671 .64148 L p .707 .577 .707 r
F P
0 g
s
.22381 .63695 m .22002 .6942 L .25116 .69697 L p .707 .577 .707 r
F P
0 g
s
.22002 .6942 m .22381 .63695 L .19633 .63343 L p .707 .577 .707 r
F P
0 g
s
.19633 .63343 m .19253 .69068 L .22002 .6942 L p .707 .577 .707 r
F P
0 g
s
.60912 .30849 m .61431 .80671 L .63741 .79516 L p .707 .577 .707 r
F P
0 g
s
.63741 .79516 m .63222 .29694 L .60912 .30849 L p .707 .577 .707 r
F P
0 g
s
.31596 .64205 m .31216 .6993 L .33605 .69862 L p .707 .577 .707 r
F P
0 g
s
.33605 .69862 m .33984 .64137 L .31596 .64205 L p .707 .577 .707 r
F P
0 g
s
.19253 .69068 m .19633 .63343 L .17519 .62951 L p .707 .577 .707 r
F P
0 g
s
.69915 .81267 m .69764 .83179 L .68486 .82864 L p .707 .577 .707 r
F P
0 g
s
.68486 .82864 m .68637 .80952 L .69915 .81267 L p .707 .577 .707 r
F P
0 g
s
.17519 .62951 m .17139 .68676 L .19253 .69068 L p .707 .577 .707 r
F P
0 g
s
.25012 .79615 m .25163 .77702 L .2205 .77408 L p .707 .577 .707 r
F P
0 g
s
.25163 .77702 m .25012 .79615 L .28184 .79841 L p .707 .577 .707 r
F P
0 g
s
.28184 .79841 m .28335 .77929 L .25163 .77702 L p .707 .577 .707 r
F P
0 g
s
.38144 .80442 m .37625 .30619 L .35847 .29424 L p .707 .577 .707 r
F P
0 g
s
.37625 .30619 m .38144 .80442 L .41117 .81406 L p .707 .577 .707 r
F P
0 g
s
.2205 .77408 m .21899 .7932 L .25012 .79615 L p .707 .577 .707 r
F P
0 g
s
.28335 .77929 m .28184 .79841 L .31103 .79976 L p .707 .577 .707 r
F P
0 g
s
.31103 .79976 m .31254 .78064 L .28335 .77929 L p .707 .577 .707 r
F P
0 g
s
.25995 .80223 m .25462 .77142 L .22358 .77123 L p .707 .577 .707 r
F P
0 g
s
.25462 .77142 m .25995 .80223 L .29139 .7965 L p .707 .577 .707 r
F P
0 g
s
.29139 .7965 m .28607 .76569 L .25462 .77142 L p .707 .577 .707 r
F P
0 g
s
.31254 .78064 m .31103 .79976 L .33484 .80007 L p .707 .577 .707 r
F P
0 g
s
.33484 .80007 m .33635 .78095 L .31254 .78064 L p .707 .577 .707 r
F P
0 g
s
.28607 .76569 m .29139 .7965 L .32017 .78541 L p .707 .577 .707 r
F P
0 g
s
.32017 .78541 m .31484 .7546 L .28607 .76569 L p .707 .577 .707 r
F P
0 g
s
.21899 .7932 m .2205 .77408 L .193 .77073 L p .707 .577 .707 r
F P
0 g
s
.33984 .64137 m .33605 .69862 L .35223 .69676 L p .707 .577 .707 r
F P
0 g
s
.35223 .69676 m .35603 .63951 L .33984 .64137 L p .707 .577 .707 r
F P
0 g
s
.193 .77073 m .19149 .78985 L .21899 .7932 L p .707 .577 .707 r
F P
0 g
s
.22891 .80204 m .22358 .77123 L .19599 .76513 L p .707 .577 .707 r
F P
0 g
s
.22358 .77123 m .22891 .80204 L .25995 .80223 L p .707 .577 .707 r
F P
0 g
s
.31484 .7546 m .32017 .78541 L .34346 .77003 L p .707 .577 .707 r
F P
0 g
s
.34346 .77003 m .33813 .73923 L .31484 .7546 L p .707 .577 .707 r
F P
0 g
s
.17139 .68676 m .17519 .62951 L .16246 .62557 L p .707 .577 .707 r
F P
0 g
s
.19149 .78985 m .193 .77073 L .17183 .76732 L p .707 .577 .707 r
F P
0 g
s
.16246 .62557 m .15867 .68282 L .17139 .68676 L p .707 .577 .707 r
F P
0 g
s
.63222 .29694 m .63741 .79516 L .64741 .78221 L p .707 .577 .707 r
F P
0 g
s
.64741 .78221 m .64222 .28398 L .63222 .29694 L p .707 .577 .707 r
F P
0 g
s
.17183 .76732 m .17032 .78644 L .19149 .78985 L p .707 .577 .707 r
F P
0 g
s
.68637 .80952 m .68486 .82864 L .66368 .82522 L p .707 .577 .707 r
F P
0 g
s
.66368 .82522 m .66519 .8061 L .68637 .80952 L p .707 .577 .707 r
F P
0 g
s
.20132 .79594 m .19599 .76513 L .17454 .75372 L p .707 .577 .707 r
F P
0 g
s
.19599 .76513 m .20132 .79594 L .22891 .80204 L p .707 .577 .707 r
F P
0 g
s
.33813 .73923 m .34346 .77003 L .35898 .75189 L p .707 .577 .707 r
F P
0 g
s
.35898 .75189 m .35366 .72108 L .33813 .73923 L p .707 .577 .707 r
F P
0 g
s
.35603 .63951 m .35223 .69676 L .35913 .69391 L p .707 .577 .707 r
F P
0 g
s
.35913 .69391 m .36292 .63666 L .35603 .63951 L p .707 .577 .707 r
F P
0 g
s
.33635 .78095 m .33484 .80007 L .35095 .79931 L p .707 .577 .707 r
F P
0 g
s
.35095 .79931 m .35246 .78019 L .33635 .78095 L p .707 .577 .707 r
F P
0 g
s
.35366 .72108 m .35898 .75189 L .36522 .73275 L p .707 .577 .707 r
F P
0 g
s
.36522 .73275 m .35989 .70194 L .35366 .72108 L p .707 .577 .707 r
F P
0 g
s
.36292 .63666 m .35913 .69391 L .35814 .69276 L p .707 .577 .707 r
F P
0 g
s
.35814 .69276 m .35607 .69034 L p .35664 .68581 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35623 .68368 L .35687 .68687 L p .708 .578 .707 r
F P
0 g
s
.35664 .68581 m .36292 .63666 L .35814 .69276 L .707 .577 .707 r
F
.35986 .63309 m .36292 .63666 L p .35703 .68281 L F P
0 g
s
.35607 .69034 m .35643 .68483 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35986 .63309 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35607 .69034 m .34334 .6864 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35623 .68368 m .35643 .68483 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35607 .69034 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .35623 .68368 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .34413 .67444 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .34413 .67444 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34303 .66808 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .35986 .63309 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34714 .62915 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35986 .63309 m .35643 .68483 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .35588 .68436 L .35643 .68483 L .707 .577 .707 r
F
.35643 .68483 m .36156 .71449 L .35126 .70231 L p F P
0 g
s
.35126 .70231 m .34836 .69889 L p .35643 .68483 L .707 .577 .707 r
F P
0 g
s
.36156 .71449 m .35643 .68483 L p .35989 .70194 L .708 .578 .707 r
F P
0 g
s
.35687 .68687 m .35989 .70194 L p .35643 .68483 L .708 .578 .707 r
F P
0 g
s
.35989 .70194 m .36522 .73275 L .36156 .71449 L p .708 .578 .707 r
F P
0 g
s
.36366 .79247 m .35847 .29424 L .35437 .28114 L p .707 .577 .707 r
F P
0 g
s
.35847 .29424 m .36366 .79247 L .38144 .80442 L p .707 .577 .707 r
F P
0 g
s
.15867 .68282 m .16246 .62557 L .1594 .622 L p .707 .577 .707 r
F P
0 g
s
.17032 .78644 m .17183 .76732 L .15904 .76416 L p .707 .577 .707 r
F P
0 g
s
.15904 .76416 m .15753 .78328 L .17032 .78644 L p .707 .577 .707 r
F P
0 g
s
.66519 .8061 m .66368 .82522 L .63618 .82188 L p .707 .577 .707 r
F P
0 g
s
.63618 .82188 m .63769 .80276 L .66519 .8061 L p .707 .577 .707 r
F P
0 g
s
.17987 .78453 m .17454 .75372 L .16135 .73812 L p .707 .577 .707 r
F P
0 g
s
.17454 .75372 m .17987 .78453 L .20132 .79594 L p .707 .577 .707 r
F P
0 g
s
.1594 .622 m .1556 .67925 L .15867 .68282 L p .707 .577 .707 r
F P
0 g
s
.63769 .80276 m .63618 .82188 L .60505 .81893 L p .707 .577 .707 r
F P
0 g
s
.64222 .28398 m .64741 .78221 L .64656 .77951 L p .707 .577 .707 r
F P
0 g
s
.64318 .71089 m .64222 .28398 L .64656 .77951 L .707 .577 .707 r
F
.63812 .27089 m .64222 .28398 L p .64301 .63495 L F P
0 g
s
.64331 .76673 m .64189 .63242 L .64301 .63495 L .707 .577 .707 r
F
.64328 .7663 m .64189 .63242 L p .64331 .76673 L F P
0 g
s
.64656 .77951 m .64347 .76961 L p .64318 .71089 L .707 .577 .707 r
F P
0 g
s
.64347 .76961 m .64331 .76911 L p .64331 .76673 L .707 .577 .707 r
F P
0 g
s
.64331 .76673 m .64318 .71089 L .64347 .76961 L .707 .577 .707 r
F
.63812 .27089 m .64331 .76911 L .62553 .75716 L p F P
0 g
s
.63926 .71042 m .63775 .72954 L .64129 .73041 L p .707 .577 .707 r
F P
0 g
s
.64129 .73041 m .65053 .73269 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.6403 .71247 m .63926 .71042 L .64129 .73041 L .707 .577 .707 r
F
.65053 .73269 m .65204 .71357 L .6402 .71065 L p F P
0 g
s
.6402 .71065 m .63926 .71042 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.65053 .73269 m .6402 .71065 L .6403 .71247 L .707 .577 .707 r
F
.64331 .76911 m .64328 .7663 L p .64331 .76673 L F P
0 g
s
.64189 .63242 m .63812 .27089 L p .64301 .63495 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63961 .56678 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63888 .6276 m .63899 .62589 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .64267 .57035 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63899 .62589 L p .6516 .63154 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .63888 .6276 L .63908 .62766 L p .707 .577 .707 r
F P
0 g
s
.63908 .62766 m .6516 .63154 L p .63899 .62589 L .707 .577 .707 r
F P
0 g
s
.35246 .78019 m .35095 .79931 L .35777 .79756 L p .707 .577 .707 r
F P
0 g
s
.35777 .79756 m .35928 .77844 L .35246 .78019 L p .707 .577 .707 r
F P
0 g
s
.16135 .73812 m .16667 .76893 L .17987 .78453 L p .707 .577 .707 r
F P
0 g
s
.16667 .76893 m .16135 .73812 L .15769 .71986 L p .708 .578 .707 r
F P
0 g
s
.15753 .78328 m .15904 .76416 L .15591 .76158 L p .707 .577 .707 r
F P
0 g
s
.15591 .76158 m .1544 .7807 L .15753 .78328 L p .707 .577 .707 r
F P
0 g
s
.1556 .67925 m .1594 .622 L .16629 .61915 L p .707 .577 .707 r
F P
0 g
s
.16629 .61915 m .1625 .6764 L .1556 .67925 L p .707 .577 .707 r
F P
0 g
s
.35437 .28114 m .35956 .77937 L .36366 .79247 L p .707 .577 .707 r
F P
0 g
s
.35956 .77937 m .35437 .28114 L .36437 .26819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35928 .77844 m .35777 .79756 L .35463 .79498 L p .707 .577 .707 r
F P
0 g
s
.35463 .79498 m .35614 .77586 L .35928 .77844 L p .707 .577 .707 r
F P
0 g
s
.15769 .71986 m .16301 .75067 L .16667 .76893 L p .708 .578 .707 r
F P
0 g
s
.16301 .75067 m .15769 .71986 L .16392 .70072 L p .707 .577 .707 r
F P
0 g
s
.1544 .7807 m .15591 .76158 L .16273 .75983 L p .707 .577 .707 r
F P
0 g
s
.62553 .75716 m .62034 .25893 L .63812 .27089 L p .707 .577 .707 r
F P
0 g
s
.1625 .6764 m .16629 .61915 L .18248 .61729 L p .707 .577 .707 r
F P
0 g
s
.16273 .75983 m .16122 .77895 L .1544 .7807 L p .707 .577 .707 r
F P
0 g
s
.18248 .61729 m .17868 .67454 L .1625 .6764 L p .707 .577 .707 r
F P
0 g
s
.16392 .70072 m .16925 .73153 L .16301 .75067 L p .707 .577 .707 r
F P
0 g
s
.16925 .73153 m .16392 .70072 L .17945 .68258 L p .707 .577 .707 r
F P
0 g
s
.36956 .76641 m .36437 .26819 L .38747 .25664 L p .707 .577 .707 r
F P
0 g
s
.36437 .26819 m .36956 .76641 L .35956 .77937 L p .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .3222 .68248 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34334 .6864 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .32692 .68748 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .34413 .67444 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34836 .69889 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32159 .65667 m .34303 .66808 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.3222 .68248 m .32327 .66637 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32692 .68748 m .32327 .66637 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32159 .65667 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .34714 .62915 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32599 .62523 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .34413 .67444 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.35614 .77586 m .35463 .79498 L .34185 .79182 L p .707 .577 .707 r
F P
0 g
s
.34185 .79182 m .34336 .7727 L .35614 .77586 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18248 .61729 L .20636 .61661 L p .707 .577 .707 r
F P
0 g
s
.16122 .77895 m .16273 .75983 L .17883 .75907 L p .707 .577 .707 r
F P
0 g
s
.17883 .75907 m .17732 .77819 L .16122 .77895 L p .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20257 .67386 L .18638 .67432 L p .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .17945 .68258 L .19866 .66989 L p .707 .577 .707 r
F P
0 g
s
.19866 .66989 m .20274 .6672 L p .20218 .66862 L .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .19866 .66989 L .20218 .66862 L .707 .577 .707 r
F
.20274 .6672 m .23151 .65611 L p .22737 .6635 L F P
0 g
s
.20389 .66816 m .20274 .6672 L .22737 .6635 L .707 .577 .707 r
F
.20636 .61661 m .23561 .61718 L p .20615 .66771 L F P
0 g
s
.20257 .67386 m .20293 .66835 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20274 .6672 L p .20389 .66816 L .707 .577 .707 r
F P
0 g
s
.23182 .67443 m .20257 .67386 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20389 .66816 L .21817 .67995 L .707 .577 .707 r
F
.23151 .65611 m .26296 .65038 L p .25554 .66076 L F P
0 g
s
.23836 .66204 m .23151 .65611 L .25554 .66076 L .707 .577 .707 r
F
.23561 .61718 m .26736 .61894 L p .23983 .66193 L F P
0 g
s
.23182 .67443 m .23261 .66247 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23151 .65611 L p .23836 .66204 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .23182 .67443 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23836 .66204 L .24841 .67073 L .707 .577 .707 r
F
.29471 .67896 m .26357 .67619 L p .27365 .66047 L F P
0 g
s
.26296 .65038 m .294 .65057 L p .28527 .66097 L .707 .577 .707 r
F P
0 g
s
.27239 .66041 m .26296 .65038 L .28527 .66097 L .707 .577 .707 r
F
.3222 .68248 m .29471 .67896 L p .30406 .6629 L F P
0 g
s
.294 .65057 m .32159 .65667 L p .31431 .66475 L .707 .577 .707 r
F P
0 g
s
.30342 .66279 m .294 .65057 L .31431 .66475 L .707 .577 .707 r
F
.32327 .66637 m .3222 .68248 L p .30406 .6629 L F P
0 g
s
.32159 .65667 m .32692 .68748 L .29933 .68138 L p .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .32327 .66637 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29851 .62171 m .32599 .62523 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29471 .67896 m .29587 .66143 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .294 .65057 L p .30342 .66279 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .29851 .62171 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .30342 .66279 L .30926 .67036 L .707 .577 .707 r
F
.30926 .67036 m .30342 .66279 L .31431 .66475 L F
.29933 .68138 m .29587 .66143 L p .30926 .67036 L F P
0 g
s
.29587 .66143 m .29471 .67896 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.294 .65057 m .29933 .68138 L .26829 .68119 L p .707 .577 .707 r
F P
0 g
s
.27365 .66047 m .27988 .65075 L .29587 .66143 L .707 .577 .707 r
F
.29851 .62171 m .29587 .66143 L p .27988 .65075 L F P
0 g
s
.26736 .61894 m .29851 .62171 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .26464 .66008 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26296 .65038 L p .27239 .66041 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26736 .61894 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .27239 .66041 L .27944 .66791 L .707 .577 .707 r
F
.27944 .66791 m .27239 .66041 L .28527 .66097 L F
.26829 .68119 m .26464 .66008 L p .27944 .66791 L F P
0 g
s
.26464 .66008 m .26357 .67619 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.26296 .65038 m .26829 .68119 L .23684 .68692 L p .707 .577 .707 r
F P
0 g
s
.23983 .66193 m .24699 .65074 L .26464 .66008 L .707 .577 .707 r
F
.26736 .61894 m .26464 .66008 L p .24699 .65074 L F P
0 g
s
.23261 .66247 m .23561 .61718 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.24841 .67073 m .23836 .66204 L .25554 .66076 L .707 .577 .707 r
F
.23684 .68692 m .23261 .66247 L p .24841 .67073 L F P
0 g
s
.23261 .66247 m .23182 .67443 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.23151 .65611 m .23684 .68692 L .20806 .69801 L p .707 .577 .707 r
F P
0 g
s
.20615 .66771 m .21468 .65308 L .23261 .66247 L .707 .577 .707 r
F
.23561 .61718 m .23261 .66247 L p .21468 .65308 L F P
0 g
s
.20293 .66835 m .20636 .61661 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.21817 .67995 m .20389 .66816 L .22737 .6635 L .707 .577 .707 r
F
.20806 .69801 m .20293 .66835 L p .21817 .67995 L F P
0 g
s
.20274 .6672 m .20806 .69801 L .18477 .71338 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18732 .65647 L .20293 .66835 L .707 .577 .707 r
F
.20636 .61661 m .20293 .66835 L p .18732 .65647 L F P
0 g
s
.18638 .67432 m .17868 .67454 L p .20293 .66835 L .707 .577 .707 r
F P
0 g
s
.17945 .68258 m .18477 .71338 L .16925 .73153 L p .707 .577 .707 r
F P
0 g
s
.62034 .25893 m .62553 .75716 L .5958 .74752 L p .707 .577 .707 r
F P
0 g
s
.5958 .74752 m .59061 .24929 L .62034 .25893 L p .707 .577 .707 r
F P
0 g
s
.34336 .7727 m .34185 .79182 L .32067 .78841 L p .707 .577 .707 r
F P
0 g
s
.32067 .78841 m .32218 .76929 L .34336 .7727 L p .707 .577 .707 r
F P
0 g
s
.38747 .25664 m .39266 .75487 L .36956 .76641 L p .707 .577 .707 r
F P
0 g
s
.39266 .75487 m .38747 .25664 L .42142 .24763 L p .707 .577 .707 r
F P
0 g
s
.17732 .77819 m .17883 .75907 L .20264 .75938 L p .707 .577 .707 r
F P
0 g
s
.20264 .75938 m .20113 .7785 L .17732 .77819 L p .707 .577 .707 r
F P
0 g
s
.73138 .64175 m .73517 .5845 L .70403 .58173 L p .707 .577 .707 r
F P
0 g
s
.73517 .5845 m .73138 .64175 L .76313 .64351 L p .707 .577 .707 r
F P
0 g
s
.76313 .64351 m .76692 .58626 L .73517 .5845 L p .707 .577 .707 r
F P
0 g
s
.76692 .58626 m .76313 .64351 L .79238 .64407 L p .707 .577 .707 r
F P
0 g
s
.79238 .64407 m .79617 .58682 L .76692 .58626 L p .707 .577 .707 r
F P
0 g
s
.70403 .58173 m .70023 .63898 L .73138 .64175 L p .707 .577 .707 r
F P
0 g
s
.70023 .63898 m .70403 .58173 L .67654 .57821 L p .707 .577 .707 r
F P
0 g
s
.59061 .24929 m .5958 .74752 L .55704 .74114 L p .707 .577 .707 r
F P
0 g
s
.55704 .74114 m .55185 .24291 L .59061 .24929 L p .707 .577 .707 r
F P
0 g
s
.32218 .76929 m .32067 .78841 L .29317 .78506 L p .707 .577 .707 r
F P
0 g
s
.29317 .78506 m .29468 .76594 L .32218 .76929 L p .707 .577 .707 r
F P
0 g
s
.67654 .57821 m .67275 .63546 L .70023 .63898 L p .707 .577 .707 r
F P
0 g
s
.79617 .58682 m .79238 .64407 L .81626 .6434 L p .707 .577 .707 r
F P
0 g
s
.81626 .6434 m .82006 .58615 L .79617 .58682 L p .707 .577 .707 r
F P
0 g
s
.20113 .7785 m .20264 .75938 L .23184 .76073 L p .707 .577 .707 r
F P
0 g
s
.23184 .76073 m .23033 .77986 L .20113 .7785 L p .707 .577 .707 r
F P
0 g
s
.67275 .63546 m .67654 .57821 L .6554 .57429 L p .707 .577 .707 r
F P
0 g
s
.42661 .74585 m .42142 .24763 L .4629 .24203 L p .707 .577 .707 r
F P
0 g
s
.42142 .24763 m .42588 .67541 L p .39266 .75487 L .707 .577 .707 r
F P
0 g
s
.4629 .24203 m .46809 .74026 L .42661 .74585 L p .707 .577 .707 r
F P
0 g
s
.42391 .54944 m .42012 .60669 L .4489 .60725 L p .707 .577 .707 r
F P
0 g
s
.4489 .60725 m .44937 .60726 L p .4491 .60666 L .707 .577 .707 r
F P
0 g
s
.4491 .60666 m .42391 .54944 L .4489 .60725 L .707 .577 .707 r
F
.42588 .67541 m .42658 .74304 L p .39966 .75301 L F P
0 g
s
.39966 .75301 m .39266 .75487 L p .42588 .67541 L .707 .577 .707 r
F P
0 g
s
.42055 .68872 m .41904 .70784 L .44014 .70882 L p .707 .577 .707 r
F P
0 g
s
.44014 .70882 m .44823 .7092 L p .44185 .70448 L .707 .577 .707 r
F P
0 g
s
.44185 .70448 m .42055 .68872 L .44014 .70882 L .707 .577 .707 r
F
.42658 .74304 m .42661 .74585 L .42533 .74619 L p F P
0 g
s
.42533 .74619 m .39966 .75301 L p .42658 .74304 L .707 .577 .707 r
F P
0 g
s
.29468 .76594 m .29317 .78506 L .26204 .78212 L p .707 .577 .707 r
F P
0 g
s
.26204 .78212 m .26355 .76299 L .29468 .76594 L p .707 .577 .707 r
F P
0 g
s
.6554 .57429 m .6516 .63154 L .67275 .63546 L p .707 .577 .707 r
F P
0 g
s
.73034 .7424 m .73185 .72328 L .70072 .72033 L p .707 .577 .707 r
F P
0 g
s
.73185 .72328 m .73034 .7424 L .76205 .74466 L p .707 .577 .707 r
F P
0 g
s
.76205 .74466 m .76356 .72554 L .73185 .72328 L p .707 .577 .707 r
F P
0 g
s
.70072 .72033 m .69921 .73945 L .73034 .7424 L p .707 .577 .707 r
F P
0 g
s
.23033 .77986 m .23184 .76073 L .26355 .76299 L p .707 .577 .707 r
F P
0 g
s
.26355 .76299 m .26204 .78212 L .23033 .77986 L p .707 .577 .707 r
F P
0 g
s
.76356 .72554 m .76205 .74466 L .79124 .74601 L p .707 .577 .707 r
F P
0 g
s
.79124 .74601 m .79275 .72689 L .76356 .72554 L p .707 .577 .707 r
F P
0 g
s
.55185 .24291 m .55704 .74114 L .51303 .73864 L p .707 .577 .707 r
F P
0 g
s
.51303 .73864 m .50784 .24041 L .55185 .24291 L p .707 .577 .707 r
F P
0 g
s
.74016 .74662 m .73483 .71581 L .70379 .71562 L p .707 .577 .707 r
F P
0 g
s
.73483 .71581 m .74016 .74662 L .77161 .74089 L p .707 .577 .707 r
F P
0 g
s
.77161 .74089 m .76628 .71008 L .73483 .71581 L p .707 .577 .707 r
F P
0 g
s
.79275 .72689 m .79124 .74601 L .81506 .74632 L p .707 .577 .707 r
F P
0 g
s
.81506 .74632 m .81657 .7272 L .79275 .72689 L p .707 .577 .707 r
F P
0 g
s
.76628 .71008 m .77161 .74089 L .80038 .7298 L p .707 .577 .707 r
F P
0 g
s
.80038 .7298 m .79506 .69899 L .76628 .71008 L p .707 .577 .707 r
F P
0 g
s
.69921 .73945 m .70072 .72033 L .67322 .71698 L p .707 .577 .707 r
F P
0 g
s
.82006 .58615 m .81626 .6434 L .83245 .64154 L p .707 .577 .707 r
F P
0 g
s
.83245 .64154 m .83624 .58429 L .82006 .58615 L p .707 .577 .707 r
F P
0 g
s
.67322 .71698 m .67171 .73611 L .69921 .73945 L p .707 .577 .707 r
F P
0 g
s
.46809 .74026 m .4629 .24203 L .50784 .24041 L p .707 .577 .707 r
F P
0 g
s
.50784 .24041 m .51303 .73864 L .46809 .74026 L p .707 .577 .707 r
F P
0 g
s
.70912 .74643 m .70379 .71562 L .6762 .70952 L p .707 .577 .707 r
F P
0 g
s
.70379 .71562 m .70912 .74643 L .74016 .74662 L p .707 .577 .707 r
F P
0 g
s
.79506 .69899 m .80038 .7298 L .82367 .71443 L p .707 .577 .707 r
F P
0 g
s
.82367 .71443 m .81835 .68362 L .79506 .69899 L p .707 .577 .707 r
F P
0 g
s
.6516 .63154 m .6554 .57429 L .64267 .57035 L p .707 .577 .707 r
F P
0 g
s
.67171 .73611 m .67322 .71698 L .65204 .71357 L p .707 .577 .707 r
F P
0 g
s
.65204 .71357 m .65053 .73269 L .67171 .73611 L p .707 .577 .707 r
F P
0 g
s
.68153 .74033 m .6762 .70952 L .65476 .69811 L p .707 .577 .707 r
F P
0 g
s
.6762 .70952 m .68153 .74033 L .70912 .74643 L p .707 .577 .707 r
F P
0 g
s
.81835 .68362 m .82367 .71443 L .8392 .69628 L p .707 .577 .707 r
F P
0 g
s
.8392 .69628 m .83387 .66548 L .81835 .68362 L p .707 .577 .707 r
F P
0 g
s
.83624 .58429 m .83245 .64154 L .83934 .63869 L p .707 .577 .707 r
F P
0 g
s
.83934 .63869 m .84314 .58144 L .83624 .58429 L p .707 .577 .707 r
F P
0 g
s
.81657 .7272 m .81506 .74632 L .83116 .74557 L p .707 .577 .707 r
F P
0 g
s
.83116 .74557 m .83267 .72644 L .81657 .7272 L p .707 .577 .707 r
F P
0 g
s
.66009 .72892 m .65476 .69811 L .64156 .68252 L p .707 .577 .707 r
F P
0 g
s
.65476 .69811 m .66009 .72892 L .68153 .74033 L p .707 .577 .707 r
F P
0 g
s
.83387 .66548 m .8392 .69628 L .84543 .67714 L p .707 .577 .707 r
F P
0 g
s
.84543 .67714 m .84011 .64634 L .83387 .66548 L p .707 .577 .707 r
F P
0 g
s
.63961 .56678 m .63582 .62403 L .63888 .6276 L p .707 .577 .707 r
F P
0 g
s
.83267 .72644 m .83116 .74557 L .83798 .74381 L p .707 .577 .707 r
F P
0 g
s
.83798 .74381 m .83949 .72469 L .83267 .72644 L p .707 .577 .707 r
F P
0 g
s
.83846 .63766 m .83628 .63512 L p .83689 .63036 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83645 .62807 L .83715 .63156 L p .708 .578 .707 r
F P
0 g
s
.84007 .57787 m .84314 .58144 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .83666 .62933 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .84007 .57787 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .82355 .63118 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.83645 .62807 m .83666 .62933 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83628 .63512 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .83645 .62807 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .82437 .61893 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .82437 .61893 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82325 .61247 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .84007 .57787 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82735 .57393 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.84007 .57787 m .83666 .62933 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .83606 .62882 L .83666 .62933 L .707 .577 .707 r
F
.83666 .62933 m .84177 .65888 L .83151 .64675 L p F P
0 g
s
.83151 .64675 m .82858 .64328 L p .83666 .62933 L .707 .577 .707 r
F P
0 g
s
.84177 .65888 m .83666 .62933 L p .84011 .64634 L .708 .578 .707 r
F P
0 g
s
.83715 .63156 m .84011 .64634 L p .83666 .62933 L .708 .578 .707 r
F P
0 g
s
.84314 .58144 m .83934 .63869 L .83846 .63766 L p .707 .577 .707 r
F P
0 g
s
.83689 .63036 m .84314 .58144 L .83846 .63766 L .707 .577 .707 r
F
.64156 .68252 m .64689 .71332 L .66009 .72892 L p F P
0 g
s
.64689 .71332 m .64156 .68252 L .6379 .66425 L p .708 .578 .707 r
F P
0 g
s
.63775 .72954 m .63926 .71042 L .63612 .70784 L p .707 .577 .707 r
F P
0 g
s
.84011 .64634 m .84543 .67714 L .84177 .65888 L p .708 .578 .707 r
F P
0 g
s
.63612 .70784 m .63461 .72696 L .63775 .72954 L p .707 .577 .707 r
F P
0 g
s
.63582 .62403 m .63961 .56678 L .64651 .56393 L p .707 .577 .707 r
F P
0 g
s
.64651 .56393 m .64271 .62118 L .63582 .62403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6379 .66425 m .64323 .69506 L .64689 .71332 L p .708 .578 .707 r
F P
0 g
s
.83949 .72469 m .83798 .74381 L .83484 .74123 L p .707 .577 .707 r
F P
0 g
s
.83484 .74123 m .83635 .72211 L .83949 .72469 L p .707 .577 .707 r
F P
0 g
s
.64323 .69506 m .6379 .66425 L .64414 .64511 L p .707 .577 .707 r
F P
0 g
s
.38837 .60494 m .39216 .54769 L .36102 .54491 L p .707 .577 .707 r
F P
0 g
s
.39216 .54769 m .38837 .60494 L .42012 .60669 L p .707 .577 .707 r
F P
0 g
s
.42012 .60669 m .42391 .54944 L .39216 .54769 L p .707 .577 .707 r
F P
0 g
s
.44937 .60726 m .45316 .55001 L .42391 .54944 L p .707 .577 .707 r
F P
0 g
s
.63461 .72696 m .63612 .70784 L .64294 .70608 L p .707 .577 .707 r
F P
0 g
s
.64271 .62118 m .64651 .56393 L .66269 .56207 L p .707 .577 .707 r
F P
0 g
s
.36102 .54491 m .35722 .60216 L .38837 .60494 L p .707 .577 .707 r
F P
0 g
s
.64294 .70608 m .64143 .7252 L .63461 .72696 L p .707 .577 .707 r
F P
0 g
s
.35722 .60216 m .36102 .54491 L .33353 .54139 L p .707 .577 .707 r
F P
0 g
s
.66269 .56207 m .6589 .61932 L .64271 .62118 L p .707 .577 .707 r
F P
0 g
s
.33353 .54139 m .32974 .59864 L .35722 .60216 L p .707 .577 .707 r
F P
0 g
s
.45316 .55001 m .44937 .60726 L .47325 .60658 L p .707 .577 .707 r
F P
0 g
s
.47325 .60658 m .47705 .54933 L .45316 .55001 L p .707 .577 .707 r
F P
0 g
s
.64414 .64511 m .64946 .67592 L .64323 .69506 L p .707 .577 .707 r
F P
0 g
s
.64946 .67592 m .64414 .64511 L .65966 .62697 L p .707 .577 .707 r
F P
0 g
s
.32974 .59864 m .33353 .54139 L .31239 .53747 L p .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .80241 .62726 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82355 .63118 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .80713 .63187 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .82437 .61893 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82858 .64328 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8018 .60106 m .82325 .61247 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80241 .62726 m .8035 .61087 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.80713 .63187 m .8035 .61087 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .8018 .60106 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .82735 .57393 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .80621 .57001 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .82437 .61893 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.83635 .72211 m .83484 .74123 L .82206 .73808 L p .707 .577 .707 r
F P
0 g
s
.82206 .73808 m .82357 .71896 L .83635 .72211 L p .707 .577 .707 r
F P
0 g
s
.31239 .53747 m .30859 .59472 L .32974 .59864 L p .707 .577 .707 r
F P
0 g
s
.38733 .70558 m .38884 .68646 L .35771 .68351 L p .707 .577 .707 r
F P
0 g
s
.38884 .68646 m .38733 .70558 L .41904 .70784 L p .707 .577 .707 r
F P
0 g
s
.41904 .70784 m .42055 .68872 L .38884 .68646 L p .707 .577 .707 r
F P
0 g
s
.35771 .68351 m .3562 .70264 L .38733 .70558 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66269 .56207 L .68658 .56139 L p .707 .577 .707 r
F P
0 g
s
.44823 .7092 m .44974 .69008 L .42055 .68872 L p .707 .577 .707 r
F P
0 g
s
.39715 .70981 m .39182 .679 L .36078 .67881 L p .707 .577 .707 r
F P
0 g
s
.39182 .679 m .39715 .70981 L .4286 .70408 L p .707 .577 .707 r
F P
0 g
s
.4286 .70408 m .42327 .67327 L .39182 .679 L p .707 .577 .707 r
F P
0 g
s
.44974 .69008 m .44823 .7092 L .47205 .70951 L p .707 .577 .707 r
F P
0 g
s
.47205 .70951 m .47356 .69039 L .44974 .69008 L p .707 .577 .707 r
F P
0 g
s
.42327 .67327 m .4286 .70408 L .45737 .69298 L p .707 .577 .707 r
F P
0 g
s
.45737 .69298 m .45205 .66218 L .42327 .67327 L p .707 .577 .707 r
F P
0 g
s
.64143 .7252 m .64294 .70608 L .65904 .70532 L p .707 .577 .707 r
F P
0 g
s
.3562 .70264 m .35771 .68351 L .33021 .68017 L p .707 .577 .707 r
F P
0 g
s
.47705 .54933 m .47325 .60658 L .48944 .60472 L p .707 .577 .707 r
F P
0 g
s
.48944 .60472 m .49323 .54748 L .47705 .54933 L p .707 .577 .707 r
F P
0 g
s
.65904 .70532 m .65753 .72444 L .64143 .7252 L p .707 .577 .707 r
F P
0 g
s
.33021 .68017 m .3287 .69929 L .3562 .70264 L p .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68278 .61864 L .66577 .61912 L p .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .65966 .62697 L .6785 .61453 L p .707 .577 .707 r
F P
0 g
s
.6785 .61453 m .68295 .6116 L p .68235 .61315 L .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .6785 .61453 L .68235 .61315 L .707 .577 .707 r
F
.68295 .6116 m .71173 .6005 L p .70752 .60802 L F P
0 g
s
.68421 .61264 m .68295 .6116 L .70752 .60802 L .707 .577 .707 r
F
.68658 .56139 m .71583 .56196 L p .68655 .61218 L F P
0 g
s
.68278 .61864 m .68317 .61285 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68295 .6116 L p .68421 .61264 L .707 .577 .707 r
F P
0 g
s
.71203 .61921 m .68278 .61864 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68421 .61264 L .69835 .62441 L .707 .577 .707 r
F
.71173 .6005 m .74317 .59477 L p .73567 .60526 L F P
0 g
s
.71864 .60653 m .71173 .6005 L .73567 .60526 L .707 .577 .707 r
F
.71583 .56196 m .74758 .56372 L p .72023 .60642 L F P
0 g
s
.71203 .61921 m .71284 .60697 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71173 .6005 L p .71864 .60653 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .71203 .61921 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71864 .60653 L .72857 .6152 L .707 .577 .707 r
F
.77493 .62374 m .74378 .62096 L p .75404 .60497 L F P
0 g
s
.74317 .59477 m .77421 .59497 L p .7654 .60546 L .707 .577 .707 r
F P
0 g
s
.75264 .60491 m .74317 .59477 L .7654 .60546 L .707 .577 .707 r
F
.80241 .62726 m .77493 .62374 L p .78442 .60743 L F P
0 g
s
.77421 .59497 m .8018 .60106 L p .79444 .60924 L .707 .577 .707 r
F P
0 g
s
.78366 .60729 m .77421 .59497 L .79444 .60924 L .707 .577 .707 r
F
.8035 .61087 m .80241 .62726 L p .78442 .60743 L F P
0 g
s
.8018 .60106 m .80713 .63187 L .77954 .62577 L p .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .8035 .61087 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77872 .56649 m .80621 .57001 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77493 .62374 m .77611 .60592 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77421 .59497 L p .78366 .60729 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77872 .56649 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .78366 .60729 L .78942 .61481 L .707 .577 .707 r
F
.78942 .61481 m .78366 .60729 L .79444 .60924 L F
.77954 .62577 m .77611 .60592 L p .78942 .61481 L F P
0 g
s
.77611 .60592 m .77493 .62374 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.77421 .59497 m .77954 .62577 L .7485 .62558 L p .707 .577 .707 r
F P
0 g
s
.75404 .60497 m .76023 .59533 L .77611 .60592 L .707 .577 .707 r
F
.77872 .56649 m .77611 .60592 L p .76023 .59533 L F P
0 g
s
.74758 .56372 m .77872 .56649 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .74487 .60458 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74317 .59477 L p .75264 .60491 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74758 .56372 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .75264 .60491 L .7596 .61237 L .707 .577 .707 r
F
.7596 .61237 m .75264 .60491 L .7654 .60546 L F
.7485 .62558 m .74487 .60458 L p .7596 .61237 L F P
0 g
s
.74487 .60458 m .74378 .62096 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.74317 .59477 m .7485 .62558 L .71705 .63131 L p .707 .577 .707 r
F P
0 g
s
.72023 .60642 m .72734 .59531 L .74487 .60458 L .707 .577 .707 r
F
.74758 .56372 m .74487 .60458 L p .72734 .59531 L F P
0 g
s
.71284 .60697 m .71583 .56196 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.72857 .6152 m .71864 .60653 L .73567 .60526 L .707 .577 .707 r
F
.71705 .63131 m .71284 .60697 L p .72857 .6152 L F P
0 g
s
.71284 .60697 m .71203 .61921 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.71173 .6005 m .71705 .63131 L .68828 .6424 L p .707 .577 .707 r
F P
0 g
s
.68655 .61218 m .69503 .59764 L .71284 .60697 L .707 .577 .707 r
F
.71583 .56196 m .71284 .60697 L p .69503 .59764 L F P
0 g
s
.68317 .61285 m .68658 .56139 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.69835 .62441 m .68421 .61264 L .70752 .60802 L .707 .577 .707 r
F
.68828 .6424 m .68317 .61285 L p .69835 .62441 L F P
0 g
s
.68295 .6116 m .68828 .6424 L .66499 .65777 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66764 .60103 L .68317 .61285 L .707 .577 .707 r
F
.68658 .56139 m .68317 .61285 L p .66764 .60103 L F P
0 g
s
.66577 .61912 m .6589 .61932 L p .68317 .61285 L .707 .577 .707 r
F P
0 g
s
.36611 .70961 m .36078 .67881 L .33319 .67271 L p .707 .577 .707 r
F P
0 g
s
.36078 .67881 m .36611 .70961 L .39715 .70981 L p .707 .577 .707 r
F P
0 g
s
.65966 .62697 m .66499 .65777 L .64946 .67592 L p .707 .577 .707 r
F P
0 g
s
.45205 .66218 m .45737 .69298 L .48066 .67761 L p .707 .577 .707 r
F P
0 g
s
.48066 .67761 m .47534 .6468 L .45205 .66218 L p .707 .577 .707 r
F P
0 g
s
.30859 .59472 m .31239 .53747 L .29966 .53353 L p .707 .577 .707 r
F P
0 g
s
.29966 .53353 m .29587 .59078 L .30859 .59472 L p .707 .577 .707 r
F P
0 g
s
.3287 .69929 m .33021 .68017 L .30903 .67675 L p .707 .577 .707 r
F P
0 g
s
.30903 .67675 m .30752 .69587 L .3287 .69929 L p .707 .577 .707 r
F P
0 g
s
.82357 .71896 m .82206 .73808 L .80088 .73466 L p .707 .577 .707 r
F P
0 g
s
.80088 .73466 m .80239 .71554 L .82357 .71896 L p .707 .577 .707 r
F P
0 g
s
.33852 .70351 m .33319 .67271 L .31175 .6613 L p .707 .577 .707 r
F P
0 g
s
.33319 .67271 m .33852 .70351 L .36611 .70961 L p .707 .577 .707 r
F P
0 g
s
.47534 .6468 m .48066 .67761 L .49619 .65947 L p .707 .577 .707 r
F P
0 g
s
.49619 .65947 m .49086 .62866 L .47534 .6468 L p .707 .577 .707 r
F P
0 g
s
.65753 .72444 m .65904 .70532 L .68286 .70563 L p .707 .577 .707 r
F P
0 g
s
.49323 .54748 m .48944 .60472 L .49633 .60187 L p .707 .577 .707 r
F P
0 g
s
.49633 .60187 m .50013 .54462 L .49323 .54748 L p .707 .577 .707 r
F P
0 g
s
.68286 .70563 m .68135 .72476 L .65753 .72444 L p .707 .577 .707 r
F P
0 g
s
.47356 .69039 m .47205 .70951 L .48815 .70875 L p .707 .577 .707 r
F P
0 g
s
.48815 .70875 m .48966 .68963 L .47356 .69039 L p .707 .577 .707 r
F P
0 g
s
.29587 .59078 m .29966 .53353 L .2966 .52996 L p .707 .577 .707 r
F P
0 g
s
.30752 .69587 m .30903 .67675 L .29625 .6736 L p .707 .577 .707 r
F P
0 g
s
.29625 .6736 m .29474 .69272 L .30752 .69587 L p .707 .577 .707 r
F P
0 g
s
.80239 .71554 m .80088 .73466 L .77338 .73132 L p .707 .577 .707 r
F P
0 g
s
.77338 .73132 m .77489 .71219 L .80239 .71554 L p .707 .577 .707 r
F P
0 g
s
.31708 .69211 m .31175 .6613 L .29855 .6457 L p .707 .577 .707 r
F P
0 g
s
.31175 .6613 m .31708 .69211 L .33852 .70351 L p .707 .577 .707 r
F P
0 g
s
.49086 .62866 m .49619 .65947 L .50242 .64033 L p .707 .577 .707 r
F P
0 g
s
.50242 .64033 m .4971 .60952 L .49086 .62866 L p .707 .577 .707 r
F P
0 g
s
.2966 .52996 m .29281 .58721 L .29587 .59078 L p .707 .577 .707 r
F P
0 g
s
.68135 .72476 m .68286 .70563 L .71205 .70699 L p .707 .577 .707 r
F P
0 g
s
.71205 .70699 m .71054 .72611 L .68135 .72476 L p .707 .577 .707 r
F P
0 g
s
.77489 .71219 m .77338 .73132 L .74225 .72837 L p .707 .577 .707 r
F P
0 g
s
.74225 .72837 m .74376 .70925 L .77489 .71219 L p .707 .577 .707 r
F P
0 g
s
.48966 .68963 m .48815 .70875 L .49497 .707 L p .707 .577 .707 r
F P
0 g
s
.49497 .707 m .49648 .68787 L .48966 .68963 L p .707 .577 .707 r
F P
0 g
s
.49545 .60084 m .49327 .5983 L p .49388 .59355 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49344 .59126 L .49414 .59475 L p .708 .578 .707 r
F P
0 g
s
.49706 .54105 m .50013 .54462 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .49365 .59251 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49706 .54105 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .48054 .59436 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49344 .59126 m .49365 .59251 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49327 .5983 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .49344 .59126 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .48136 .58212 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .48136 .58212 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48024 .57566 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .49706 .54105 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48434 .53711 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49706 .54105 m .49365 .59251 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .49305 .592 L .49365 .59251 L .707 .577 .707 r
F
.49365 .59251 m .49876 .62206 L .4885 .60993 L p F P
0 g
s
.4885 .60993 m .48557 .60646 L p .49365 .59251 L .707 .577 .707 r
F P
0 g
s
.49876 .62206 m .49365 .59251 L p .4971 .60952 L .708 .578 .707 r
F P
0 g
s
.49414 .59475 m .4971 .60952 L p .49365 .59251 L .708 .578 .707 r
F P
0 g
s
.50013 .54462 m .49633 .60187 L .49545 .60084 L p .707 .577 .707 r
F P
0 g
s
.49388 .59355 m .50013 .54462 L .49545 .60084 L .707 .577 .707 r
F
.71054 .72611 m .71205 .70699 L .74376 .70925 L p F P
0 g
s
.74376 .70925 m .74225 .72837 L .71054 .72611 L p .707 .577 .707 r
F P
0 g
s
.29855 .6457 m .30388 .67651 L .31708 .69211 L p .707 .577 .707 r
F P
0 g
s
.30388 .67651 m .29855 .6457 L .29489 .62744 L p .708 .578 .707 r
F P
0 g
s
.29474 .69272 m .29625 .6736 L .29311 .67102 L p .707 .577 .707 r
F P
0 g
s
.4971 .60952 m .50242 .64033 L .49876 .62206 L p .708 .578 .707 r
F P
0 g
s
.29311 .67102 m .2916 .69014 L .29474 .69272 L p .707 .577 .707 r
F P
0 g
s
.29281 .58721 m .2966 .52996 L .3035 .52711 L p .707 .577 .707 r
F P
0 g
s
.3035 .52711 m .2997 .58436 L .29281 .58721 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29489 .62744 m .30022 .65824 L .30388 .67651 L p .708 .578 .707 r
F P
0 g
s
.49648 .68787 m .49497 .707 L .49183 .70441 L p .707 .577 .707 r
F P
0 g
s
.49183 .70441 m .49334 .68529 L .49648 .68787 L p .707 .577 .707 r
F P
0 g
s
.30022 .65824 m .29489 .62744 L .30113 .6083 L p .707 .577 .707 r
F P
0 g
s
.2916 .69014 m .29311 .67102 L .29993 .66926 L p .707 .577 .707 r
F P
0 g
s
.2997 .58436 m .3035 .52711 L .31968 .52525 L p .707 .577 .707 r
F P
0 g
s
.29993 .66926 m .29842 .68839 L .2916 .69014 L p .707 .577 .707 r
F P
0 g
s
.31968 .52525 m .31589 .5825 L .2997 .58436 L p .707 .577 .707 r
F P
0 g
s
.30113 .6083 m .30645 .6391 L .30022 .65824 L p .707 .577 .707 r
F P
0 g
s
.30645 .6391 m .30113 .6083 L .31665 .59015 L p .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .4594 .59044 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48054 .59436 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .46412 .59506 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .48136 .58212 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48557 .60646 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.45879 .56425 m .48024 .57566 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4594 .59044 m .46049 .57406 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46412 .59506 m .46049 .57406 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .45879 .56425 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .48434 .53711 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .4632 .53319 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .48136 .58212 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.49334 .68529 m .49183 .70441 L .47905 .70126 L p .707 .577 .707 r
F P
0 g
s
.47905 .70126 m .48056 .68214 L .49334 .68529 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .31968 .52525 L .34357 .52458 L p .707 .577 .707 r
F P
0 g
s
.29842 .68839 m .29993 .66926 L .31603 .66851 L p .707 .577 .707 r
F P
0 g
s
.31603 .66851 m .31452 .68763 L .29842 .68839 L p .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33977 .58183 L .32276 .58231 L p .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .31665 .59015 L .33549 .57772 L p .707 .577 .707 r
F P
0 g
s
.33549 .57772 m .33994 .57478 L p .33934 .57633 L .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .33549 .57772 L .33934 .57633 L .707 .577 .707 r
F
.33994 .57478 m .36872 .56369 L p .36451 .57121 L F P
0 g
s
.3412 .57583 m .33994 .57478 L .36451 .57121 L .707 .577 .707 r
F
.34357 .52458 m .37282 .52514 L p .34354 .57536 L F P
0 g
s
.33977 .58183 m .34016 .57604 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33994 .57478 L p .3412 .57583 L .707 .577 .707 r
F P
0 g
s
.36902 .58239 m .33977 .58183 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .3412 .57583 L .35534 .58759 L .707 .577 .707 r
F
.36872 .56369 m .40016 .55796 L p .39266 .56845 L F P
0 g
s
.37563 .56972 m .36872 .56369 L .39266 .56845 L .707 .577 .707 r
F
.37282 .52514 m .40457 .5269 L p .37722 .5696 L F P
0 g
s
.36902 .58239 m .36983 .57015 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .36872 .56369 L p .37563 .56972 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .36902 .58239 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .37563 .56972 L .38556 .57838 L .707 .577 .707 r
F
.43192 .58692 m .40077 .58415 L p .41103 .56816 L F P
0 g
s
.40016 .55796 m .4312 .55815 L p .42239 .56865 L .707 .577 .707 r
F P
0 g
s
.40963 .5681 m .40016 .55796 L .42239 .56865 L .707 .577 .707 r
F
.4594 .59044 m .43192 .58692 L p .44141 .57061 L F P
0 g
s
.4312 .55815 m .45879 .56425 L p .45143 .57242 L .707 .577 .707 r
F P
0 g
s
.44064 .57047 m .4312 .55815 L .45143 .57242 L .707 .577 .707 r
F
.46049 .57406 m .4594 .59044 L p .44141 .57061 L F P
0 g
s
.45879 .56425 m .46412 .59506 L .43653 .58896 L p .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .46049 .57406 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43571 .52967 m .4632 .53319 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43192 .58692 m .4331 .56911 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .4312 .55815 L p .44064 .57047 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .43571 .52967 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .44064 .57047 L .44641 .57799 L .707 .577 .707 r
F
.44641 .57799 m .44064 .57047 L .45143 .57242 L F
.43653 .58896 m .4331 .56911 L p .44641 .57799 L F P
0 g
s
.4331 .56911 m .43192 .58692 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.4312 .55815 m .43653 .58896 L .40549 .58876 L p .707 .577 .707 r
F P
0 g
s
.41103 .56816 m .41722 .55851 L .4331 .56911 L .707 .577 .707 r
F
.43571 .52967 m .4331 .56911 L p .41722 .55851 L F P
0 g
s
.40457 .5269 m .43571 .52967 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .40186 .56776 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40016 .55796 L p .40963 .5681 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40457 .5269 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40963 .5681 L .41658 .57555 L .707 .577 .707 r
F
.41658 .57555 m .40963 .5681 L .42239 .56865 L F
.40549 .58876 m .40186 .56776 L p .41658 .57555 L F P
0 g
s
.40186 .56776 m .40077 .58415 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.40016 .55796 m .40549 .58876 L .37404 .59449 L p .707 .577 .707 r
F P
0 g
s
.37722 .5696 m .38433 .55849 L .40186 .56776 L .707 .577 .707 r
F
.40457 .5269 m .40186 .56776 L p .38433 .55849 L F P
0 g
s
.36983 .57015 m .37282 .52514 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.38556 .57838 m .37563 .56972 L .39266 .56845 L .707 .577 .707 r
F
.37404 .59449 m .36983 .57015 L p .38556 .57838 L F P
0 g
s
.36983 .57015 m .36902 .58239 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.36872 .56369 m .37404 .59449 L .34527 .60559 L p .707 .577 .707 r
F P
0 g
s
.34354 .57536 m .35202 .56082 L .36983 .57015 L .707 .577 .707 r
F
.37282 .52514 m .36983 .57015 L p .35202 .56082 L F P
0 g
s
.34016 .57604 m .34357 .52458 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.35534 .58759 m .3412 .57583 L .36451 .57121 L .707 .577 .707 r
F
.34527 .60559 m .34016 .57604 L p .35534 .58759 L F P
0 g
s
.33994 .57478 m .34527 .60559 L .32198 .62096 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .32463 .56421 L .34016 .57604 L .707 .577 .707 r
F
.34357 .52458 m .34016 .57604 L p .32463 .56421 L F P
0 g
s
.32276 .58231 m .31589 .5825 L p .34016 .57604 L .707 .577 .707 r
F P
0 g
s
.31665 .59015 m .32198 .62096 L .30645 .6391 L p .707 .577 .707 r
F P
0 g
s
.48056 .68214 m .47905 .70126 L .45787 .69785 L p .707 .577 .707 r
F P
0 g
s
.45787 .69785 m .45938 .67872 L .48056 .68214 L p .707 .577 .707 r
F P
0 g
s
.31452 .68763 m .31603 .66851 L .33985 .66882 L p .707 .577 .707 r
F P
0 g
s
.33985 .66882 m .33834 .68794 L .31452 .68763 L p .707 .577 .707 r
F P
0 g
s
.45938 .67872 m .45787 .69785 L .43037 .6945 L p .707 .577 .707 r
F P
0 g
s
.43037 .6945 m .43188 .67538 L .45938 .67872 L p .707 .577 .707 r
F P
0 g
s
.33834 .68794 m .33985 .66882 L .36904 .67017 L p .707 .577 .707 r
F P
0 g
s
.36904 .67017 m .36753 .68929 L .33834 .68794 L p .707 .577 .707 r
F P
0 g
s
.43188 .67538 m .43037 .6945 L .39924 .69155 L p .707 .577 .707 r
F P
0 g
s
.39924 .69155 m .40075 .67243 L .43188 .67538 L p .707 .577 .707 r
F P
0 g
s
.36753 .68929 m .36904 .67017 L .40075 .67243 L p .707 .577 .707 r
F P
0 g
s
.40075 .67243 m .39924 .69155 L .36753 .68929 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00L7oo0`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo8@0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2000
1EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00goo001JEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF1`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP050006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00E7oo00<005YF00000eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009ooaH004eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@00A7oo001COol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH8000lOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP00000^Ool005=oo`03001JEP00009JEPL00003FUH005YF00MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00Dgoo00<005YF00000P000eYF0P0015YF00<005YFFUH01EYF0P0025YF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001COol20002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
15YF3@001EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`800003FUH005YF008000IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001FOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005Moo`04001JEUYF0007FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Moo`04001JEUYF0007FUH00`00FUH0
00050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF001JEP020003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP00;Goo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH200001Woo
001JEUYF001JER400003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool005Eoo`03001JEUYF
00=JEP03001JEUYF009JEP8000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001EOol00`00FUIJEP03
FUH00`00FUIJEP020005Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo000bOolE000=Ool20005FUH30007
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03
FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEP00FUH0;Woo000]Ool500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0000
0eYF001JEP03FUH00`00Oomoo`07Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF0P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF
FUH005YF00T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYF001JEP0^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
Ool005YF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH50006Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00AJEPd000IJEP03001JEUYF009JEP05001JEUYF001JEP0^Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01000FUIJEP000UYF10000Woo00@005YFFUH000IJEP<000MJEP03001JEUYF
00UJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH010001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF00D005YFFUH005YF02ioo`00;Goo00<005YF0000
0eYF00<005YFFUH00UYF00=ooeYF00001eYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
009JEP04001JEUYF0005FUH40002FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH200000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH60007FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH0
00020004FUH00`00FUIJEP02FUH^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00002FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0
00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP04001JEP00FUH^Ool002eoo`03001JEP0000=JEP05001JEUYFFUH00002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH017ooFUIJEP000UYF00<005YFFUH00UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001Goo001JEUYF00000UYF00IooeYFFUIJEP00FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH000=J
EP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP8000Ioo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH70002FUH0
0`00Oomoo`0/Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH00004FUH00`00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH0
0`00Oomoo`0?OolA0007Ool00`00FUH0000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIo
o`02FUH00`00Oomoo`0YOol2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP05001JEUYF
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEP001EYF00D0
05YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP04001J
EP00000/Ool3000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP8002ioo`<002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH00UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001oogoo02eoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00@005YFFUH000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH20007FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP04001JEUYFFUH5000/Ool00`00FUH0000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP80009JEP@000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH01UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP000UYF00<005YFFUH01@002goo0`006Goo00<0
05YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUHJ0002FUH00`00FUIJEP07FUH40003FUH00`00FUIJEP05FUH00`00FUH00006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000eYF00<005YFFUH00eYF00@005YF000000Qoo`D001Moo`80009JEP03001oogoo02Yoo`00;7oo
00<005YF00000UYF1`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP80009J
EP03OomJEP0000EJEP03001JEUYF008000Moo`D001Ioo`03001JEP00009JEP03001oogoo02Yoo`00
;7oo00<005YF00000P0015YF0P000eYF00<005YFFUH01EYF0P0025YF00<005YFFUH015YF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF008000Moo`D001Eo
o`04001JEUYF0002FUH00`00Oomoo`0ZOol002aoo`80009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH900000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P00
27oo0`005Goo00D005YFFUIJEP00009JEP03001oogoo02Yoo`00;Goo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00@000IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02000OOol00`00FUIJEP03FUH2000]Ool002moo`D000IJ
EP03001JEUYF00EJEP@00003FUH005YF00MJEP04001JEP00FUH@0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YF
FUH00P007Goo0`001EYF0P00;Goo000aOol00`00FUH00007FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP06FUH00`00FUH000020002FUH01000FUIJEP0015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000K
Ool20002FUH00`00FUIJEP03FUH2000]Ool0031oo`04001JEUYF0007FUH00`00FUH000050004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P006Goo0P001EYF00<005YFFUH00UYF00<007ooOol0;7oo000_Ool01@00FUIJ
EUYF00001eYF0P001Woo6`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP06001JEUYF001JEP00
5goo0P001eYF00<005YFFUH00UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02
FUH2000SOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500000eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH40005FUH01@00FUIJEP00FUH05Woo0P0000=JEP00FUH01UYF00D005YFFUIJEP00
02moo`00;Woo00<005YFFUH00eYF00<005YFFUH00P009goo100015YF00<005YFFUH01EYF00<005YF
FUH00UYF1P0015YF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEQ400003FUIoogoo015oo`<000=JEP03001JEUYF00EJ
EP04001JEUYF000`Ool002eoo`8000EJEP<002eoobT000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP04001JEUYFFUHE0007FUH00`00
FUIJEP05FUH00`00FUH0000`Ool002eoo`03001JEP0000AJEP03001oogoo02ioo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH01EYF0P00<Goo000/Ool01000FUIJ
EP000eYF00<007ooOol0;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`000eYF00<007ooOol0<7oo000/Ool01000FUIJEP000eYF00<007ooOol0;Woo00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol0
02aoo`04001JEUYF0002FUH00`00Oomoo`0COol3000IOol00`00FUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`04
001JEUYFFUH2000EOol5000GOol200001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
6P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]
Ool00`00FUIJEP02000EOol5000FOol01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800005FUH005YFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP03FUHA0004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP005Woo1@005Woo00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP0000000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPL000=JEP04001JEUYF
FUH2000^Ool002eoo`04001JEUYF000GOol3000FOol01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YF00000`001EYF1@000UYF0P00;Woo000]Ool00`00FUH0000`Ool00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHN0008FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000]Ool00`00FUH0000^Ool30004FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Woo10000UYF00<0
05YFFUH01UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Woo
000^Ool2000/Ool20002FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH01EYF1P000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH0
0UYF00<005YF00003Woo3P001goo4P00;goo000^Ool00`00FUH0000YOol20004FUH00`00FUIJEP03
FUH01000FUIJEP001EYF00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000eoo`03001JEP0005Ao
o`00;Woo00@005YFFUH002Ioo`8000IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
0003FUH005YF00=JEP03001JEP0000eoo`03001JEP0005Aoo`00;Woo00<005YFFUH030006Goo0P00
00=JEP00FUH01UYF00H005YFFUH007oo0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03
001JEP0000eoo`03001JEP0005Aoo`00;7oo1@0000=JEP00FUH01EYF00@005YFFUIJEQ8000Aoo`<0
00=JEP03001JEUYF00EJEP03001JEP00009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
0UYF00<005YF000037oo0P0000=JEP000000Dgoo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP04FUH20003Ool0
0`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0:Ool00`00FUH00002
FUH00`00Oomoo`1AOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00Oomoo`02Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`09Ool01000FUIJEP000UYF00<007ooOol0
DGoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP050003Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001oo`08Ool01@00FUIJEUYF00000UYF00<007ooOol0DGoo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH0000027oo00<005YFFUH00eYF0P00E7oo000[OolK0004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
000000Ioo`<000EJEP8005Aoo`00;7oo0P000UYF00@005YF000000AJEP03001JEUYF00EJEP03001J
EUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP001Goo00@005YFFUH000EJEP8005Aoo`00;Woo1P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF200015YF00<005YFFUH00eYF00D005YF
FUH005YF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000Eoo`03001JEUYF009J
EP03001JEUYF009JEP03001oogoo05=oo`00<goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P0000=oo`00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0017oo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000fOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500001EYF000007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P000Woo0P001eYF00D0
05YFFUIJEP0005Ioo`00>7oo0`001UYF00<005YFFUH01EYF00<005YFFUH015YF100015YF00<005YF
FUH015YF00@005YFFUIJEP<0009oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800005Ool0
0000FUH00007FUH01000FUIJEP00Egoo000kOol40002FUH00`00FUIJEP05FUH00`00FUIJEP0I0005
Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YF0000Egoo000oOol=000POol2
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000080002FUH00`00FUIJEP05FUH2001HOol006ioo`8000AJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000EJEP04001J
EUYFFUH70003FUH00`00Oomoo`1GOol0071oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000UJEP03001JEUYF00EJEP03001JEUYF00D005Qo
o`00Lgoo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P00EGoo001gOol60002FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0D0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02001EOol007eooal000EJEP03001JEUYF00IJEP03001JEUYF00=JEPP000AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol0091oo`@00003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP04001JEUYFFUH2001EOol009Aoo`D0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJEPD0009JEP80
05Eoo`00VGoo0`001UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00@0
05YFFUIJEP@005Eoo`00W7oo10000UYF00<005YFFUH01UYF00<005YFFUH06P00EGoo002POol>001_
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59417 .73379 m .59797 .67654 L .56682 .67377 L p .707 .577 .707 r
F P
0 g
s
.59797 .67654 m .59417 .73379 L .62592 .73554 L p .707 .577 .707 r
F P
0 g
s
.62592 .73554 m .62972 .67829 L .59797 .67654 L p .707 .577 .707 r
F P
0 g
s
.62972 .67829 m .62592 .73554 L .65517 .73611 L p .707 .577 .707 r
F P
0 g
s
.65517 .73611 m .65897 .67886 L .62972 .67829 L p .707 .577 .707 r
F P
0 g
s
.56682 .67377 m .56303 .73101 L .59417 .73379 L p .707 .577 .707 r
F P
0 g
s
.56303 .73101 m .56682 .67377 L .53934 .67025 L p .707 .577 .707 r
F P
0 g
s
.53934 .67025 m .53554 .7275 L .56303 .73101 L p .707 .577 .707 r
F P
0 g
s
.65897 .67886 m .65517 .73611 L .67906 .73543 L p .707 .577 .707 r
F P
0 g
s
.67906 .73543 m .68285 .67818 L .65897 .67886 L p .707 .577 .707 r
F P
0 g
s
.53554 .7275 m .53934 .67025 L .5182 .66633 L p .707 .577 .707 r
F P
0 g
s
.5182 .66633 m .5144 .72357 L .53554 .7275 L p .707 .577 .707 r
F P
0 g
s
.59313 .83296 m .59464 .81384 L .56351 .81089 L p .707 .577 .707 r
F P
0 g
s
.59464 .81384 m .59313 .83296 L .62485 .83522 L p .707 .577 .707 r
F P
0 g
s
.62485 .83522 m .62636 .8161 L .59464 .81384 L p .707 .577 .707 r
F P
0 g
s
.56351 .81089 m .562 .83001 L .59313 .83296 L p .707 .577 .707 r
F P
0 g
s
.62636 .8161 m .62485 .83522 L .65404 .83657 L p .707 .577 .707 r
F P
0 g
s
.65404 .83657 m .65555 .81745 L .62636 .8161 L p .707 .577 .707 r
F P
0 g
s
.60296 .83904 m .59763 .80824 L .56659 .80804 L p .707 .577 .707 r
F P
0 g
s
.59763 .80824 m .60296 .83904 L .6344 .83331 L p .707 .577 .707 r
F P
0 g
s
.6344 .83331 m .62907 .80251 L .59763 .80824 L p .707 .577 .707 r
F P
0 g
s
.65555 .81745 m .65404 .83657 L .67785 .83689 L p .707 .577 .707 r
F P
0 g
s
.67785 .83689 m .67936 .81777 L .65555 .81745 L p .707 .577 .707 r
F P
0 g
s
.62907 .80251 m .6344 .83331 L .66318 .82222 L p .707 .577 .707 r
F P
0 g
s
.66318 .82222 m .65785 .79141 L .62907 .80251 L p .707 .577 .707 r
F P
0 g
s
.562 .83001 m .56351 .81089 L .53601 .80755 L p .707 .577 .707 r
F P
0 g
s
.68285 .67818 m .67906 .73543 L .69524 .73358 L p .707 .577 .707 r
F P
0 g
s
.69524 .73358 m .69904 .67633 L .68285 .67818 L p .707 .577 .707 r
F P
0 g
s
.53601 .80755 m .5345 .82667 L .562 .83001 L p .707 .577 .707 r
F P
0 g
s
.57192 .83885 m .56659 .80804 L .539 .80195 L p .707 .577 .707 r
F P
0 g
s
.56659 .80804 m .57192 .83885 L .60296 .83904 L p .707 .577 .707 r
F P
0 g
s
.65785 .79141 m .66318 .82222 L .68647 .80685 L p .707 .577 .707 r
F P
0 g
s
.68647 .80685 m .68114 .77604 L .65785 .79141 L p .707 .577 .707 r
F P
0 g
s
.5144 .72357 m .5182 .66633 L .50547 .66239 L p .707 .577 .707 r
F P
0 g
s
.5345 .82667 m .53601 .80755 L .51484 .80413 L p .707 .577 .707 r
F P
0 g
s
.50547 .66239 m .50168 .71964 L .5144 .72357 L p .707 .577 .707 r
F P
0 g
s
.51484 .80413 m .51332 .82325 L .5345 .82667 L p .707 .577 .707 r
F P
0 g
s
.54433 .83275 m .539 .80195 L .51755 .79054 L p .707 .577 .707 r
F P
0 g
s
.539 .80195 m .54433 .83275 L .57192 .83885 L p .707 .577 .707 r
F P
0 g
s
.68114 .77604 m .68647 .80685 L .70199 .78871 L p .707 .577 .707 r
F P
0 g
s
.70199 .78871 m .69666 .7579 L .68114 .77604 L p .707 .577 .707 r
F P
0 g
s
.69904 .67633 m .69524 .73358 L .70214 .73072 L p .707 .577 .707 r
F P
0 g
s
.70214 .73072 m .70593 .67347 L .69904 .67633 L p .707 .577 .707 r
F P
0 g
s
.67936 .81777 m .67785 .83689 L .69396 .83613 L p .707 .577 .707 r
F P
0 g
s
.69396 .83613 m .69547 .81701 L .67936 .81777 L p .707 .577 .707 r
F P
0 g
s
.50168 .71964 m .50547 .66239 L .50241 .65882 L p .707 .577 .707 r
F P
0 g
s
.51332 .82325 m .51484 .80413 L .50205 .80098 L p .707 .577 .707 r
F P
0 g
s
.50205 .80098 m .50054 .8201 L .51332 .82325 L p .707 .577 .707 r
F P
0 g
s
.52288 .82134 m .51755 .79054 L .50436 .77494 L p .707 .577 .707 r
F P
0 g
s
.51755 .79054 m .52288 .82134 L .54433 .83275 L p .707 .577 .707 r
F P
0 g
s
.50241 .65882 m .49861 .71607 L .50168 .71964 L p .707 .577 .707 r
F P
0 g
s
.69666 .7579 m .70199 .78871 L .70823 .76957 L p .707 .577 .707 r
F P
0 g
s
.70823 .76957 m .7029 .73876 L .69666 .7579 L p .707 .577 .707 r
F P
0 g
s
.69547 .81701 m .69396 .83613 L .70077 .83437 L p .707 .577 .707 r
F P
0 g
s
.70077 .83437 m .70228 .81525 L .69547 .81701 L p .707 .577 .707 r
F P
0 g
s
.70115 .72957 m .69907 .72715 L p .69965 .72263 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69924 .72049 L .69988 .72369 L p .708 .578 .707 r
F P
0 g
s
.70287 .6699 m .70593 .67347 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .69944 .72164 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .70287 .6699 L p .70004 .71962 L .707 .577 .707 r
F P
0 g
s
.69907 .72715 m .68635 .72322 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69924 .72049 m .69944 .72164 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69944 .72164 m .69907 .72715 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69924 .72049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68635 .72322 m .68714 .71125 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .68714 .71125 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .68604 .7049 L p .69889 .72118 L .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .70287 .6699 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.68714 .71125 m .69014 .66597 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.70287 .6699 m .69944 .72164 L p .68945 .7132 L .707 .577 .707 r
F P
0 g
s
.69137 .7357 m .69889 .72118 L .69944 .72164 L .707 .577 .707 r
F
.69944 .72164 m .70457 .7513 L .69427 .73913 L p F P
0 g
s
.69427 .73913 m .69137 .7357 L p .69944 .72164 L .707 .577 .707 r
F P
0 g
s
.70457 .7513 m .69944 .72164 L p .7029 .73876 L .708 .578 .707 r
F P
0 g
s
.69988 .72369 m .7029 .73876 L p .69944 .72164 L .708 .578 .707 r
F P
0 g
s
.70593 .67347 m .70214 .73072 L .70115 .72957 L p .707 .577 .707 r
F P
0 g
s
.69965 .72263 m .70593 .67347 L .70115 .72957 L .707 .577 .707 r
F
.49394 .82294 m .48875 .32471 L .44474 .32221 L p F P
0 g
s
.50436 .77494 m .50968 .80575 L .52288 .82134 L p .707 .577 .707 r
F P
0 g
s
.50968 .80575 m .50436 .77494 L .5007 .75668 L p .708 .578 .707 r
F P
0 g
s
.50054 .8201 m .50205 .80098 L .49892 .7984 L p .707 .577 .707 r
F P
0 g
s
.49892 .7984 m .49741 .81752 L .50054 .8201 L p .707 .577 .707 r
F P
0 g
s
.49861 .71607 m .50241 .65882 L .5093 .65596 L p .707 .577 .707 r
F P
0 g
s
.5093 .65596 m .50551 .71321 L .49861 .71607 L p .707 .577 .707 r
F P
0 g
s
.5007 .75668 m .50602 .78748 L .50968 .80575 L p .708 .578 .707 r
F P
0 g
s
.50602 .78748 m .5007 .75668 L .50693 .73753 L p .707 .577 .707 r
F P
0 g
s
.49741 .81752 m .49892 .7984 L .50574 .79664 L p .707 .577 .707 r
F P
0 g
s
.50551 .71321 m .5093 .65596 L .52549 .65411 L p .707 .577 .707 r
F P
0 g
s
.50574 .79664 m .50423 .81576 L .49741 .81752 L p .707 .577 .707 r
F P
0 g
s
.52549 .65411 m .52169 .71136 L .50551 .71321 L p .707 .577 .707 r
F P
0 g
s
.50693 .73753 m .51226 .76834 L .50602 .78748 L p .707 .577 .707 r
F P
0 g
s
.51226 .76834 m .50693 .73753 L .52246 .71939 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .52549 .65411 L .54937 .65343 L p .707 .577 .707 r
F P
0 g
s
.50423 .81576 m .50574 .79664 L .52184 .79588 L p .707 .577 .707 r
F P
0 g
s
.52184 .79588 m .52033 .81501 L .50423 .81576 L p .707 .577 .707 r
F P
0 g
s
.54167 .70671 m .54575 .70402 L p .54519 .70544 L .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .57452 .69293 L p .57038 .70032 L .707 .577 .707 r
F P
0 g
s
.5469 .70498 m .54575 .70402 L .57038 .70032 L .707 .577 .707 r
F
.54937 .65343 m .57862 .654 L p .54916 .70453 L F P
0 g
s
.54558 .71068 m .54594 .70517 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .54575 .70402 L p .5469 .70498 L .707 .577 .707 r
F P
0 g
s
.57483 .71125 m .54558 .71068 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.54594 .70517 m .5469 .70498 L .56118 .71677 L .707 .577 .707 r
F
.57452 .69293 m .60597 .6872 L p .59855 .69757 L F P
0 g
s
.58137 .69885 m .57452 .69293 L .59855 .69757 L .707 .577 .707 r
F
.57862 .654 m .61037 .65575 L p .58284 .69874 L F P
0 g
s
.57483 .71125 m .57562 .69928 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .57452 .69293 L p .58137 .69885 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .57483 .71125 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.57562 .69928 m .58137 .69885 L .59142 .70755 L .707 .577 .707 r
F
.63772 .71578 m .60658 .713 L p .61666 .69728 L F P
0 g
s
.60597 .6872 m .63701 .68739 L p .62828 .69778 L .707 .577 .707 r
F P
0 g
s
.6154 .69723 m .60597 .6872 L .62828 .69778 L .707 .577 .707 r
F
.66521 .71929 m .63772 .71578 L p .64707 .69972 L F P
0 g
s
.63701 .68739 m .6646 .69349 L p .65732 .70157 L .707 .577 .707 r
F P
0 g
s
.64643 .6996 m .63701 .68739 L .65732 .70157 L .707 .577 .707 r
F
.68635 .72322 m .66521 .71929 L p .67175 .7053 L F P
0 g
s
.6646 .69349 m .68604 .7049 L p .68231 .70939 L .707 .577 .707 r
F P
0 g
s
.67212 .70545 m .6646 .69349 L .68231 .70939 L .707 .577 .707 r
F
.68714 .71125 m .68635 .72322 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .6646 .69349 L p .67212 .70545 L .707 .577 .707 r
F P
0 g
s
.66521 .71929 m .66628 .70319 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.66628 .70319 m .67212 .70545 L .67792 .71467 L .707 .577 .707 r
F
.669 .66205 m .69014 .66597 L p .67175 .7053 L F P
0 g
s
.66628 .70319 m .669 .66205 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.68604 .7049 m .69137 .7357 L .66993 .7243 L p .707 .577 .707 r
F P
0 g
s
.69014 .66597 m .68714 .71125 L p .67175 .7053 L .707 .577 .707 r
F P
0 g
s
.67792 .71467 m .67212 .70545 L .68231 .70939 L .707 .577 .707 r
F
.66993 .7243 m .66628 .70319 L p .67792 .71467 L F P
0 g
s
.66628 .70319 m .66521 .71929 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.6646 .69349 m .66993 .7243 L .64233 .7182 L p .707 .577 .707 r
F P
0 g
s
.64707 .69972 m .65279 .68989 L .66628 .70319 L .707 .577 .707 r
F
.669 .66205 m .66628 .70319 L p .65279 .68989 L F P
0 g
s
.64152 .65853 m .669 .66205 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63772 .71578 m .63888 .69824 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .63701 .68739 L p .64643 .6996 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64152 .65853 L p .64707 .69972 L .707 .577 .707 r
F P
0 g
s
.63888 .69824 m .64643 .6996 L .65227 .70717 L .707 .577 .707 r
F
.65227 .70717 m .64643 .6996 L .65732 .70157 L F
.64233 .7182 m .63888 .69824 L p .65227 .70717 L F P
0 g
s
.63888 .69824 m .63772 .71578 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.63701 .68739 m .64233 .7182 L .6113 .718 L p .707 .577 .707 r
F P
0 g
s
.61666 .69728 m .62289 .68757 L .63888 .69824 L .707 .577 .707 r
F
.64152 .65853 m .63888 .69824 L p .62289 .68757 L F P
0 g
s
.61037 .65575 m .64152 .65853 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60658 .713 m .60765 .6969 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .60597 .6872 L p .6154 .69723 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .61037 .65575 L p .61666 .69728 L .707 .577 .707 r
F P
0 g
s
.60765 .6969 m .6154 .69723 L .62245 .70473 L .707 .577 .707 r
F
.62245 .70473 m .6154 .69723 L .62828 .69778 L F
.6113 .718 m .60765 .6969 L p .62245 .70473 L F P
0 g
s
.60765 .6969 m .60658 .713 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.60597 .6872 m .6113 .718 L .57985 .72373 L p .707 .577 .707 r
F P
0 g
s
.58284 .69874 m .59 .68756 L .60765 .6969 L .707 .577 .707 r
F
.61037 .65575 m .60765 .6969 L p .59 .68756 L F P
0 g
s
.57562 .69928 m .57862 .654 L p .58284 .69874 L .707 .577 .707 r
F P
0 g
s
.59142 .70755 m .58137 .69885 L .59855 .69757 L .707 .577 .707 r
F
.57985 .72373 m .57562 .69928 L p .59142 .70755 L F P
0 g
s
.57562 .69928 m .57483 .71125 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.57452 .69293 m .57985 .72373 L .55107 .73483 L p .707 .577 .707 r
F P
0 g
s
.54916 .70453 m .55769 .6899 L .57562 .69928 L .707 .577 .707 r
F
.57862 .654 m .57562 .69928 L p .55769 .6899 L F P
0 g
s
.54594 .70517 m .54937 .65343 L p .54916 .70453 L .707 .577 .707 r
F P
0 g
s
.56118 .71677 m .5469 .70498 L .57038 .70032 L .707 .577 .707 r
F
.55107 .73483 m .54594 .70517 L p .56118 .71677 L F P
0 g
s
.54594 .70517 m .54558 .71068 L .52939 .71114 L p .707 .577 .707 r
F P
0 g
s
.54575 .70402 m .55107 .73483 L .52778 .7502 L p .707 .577 .707 r
F P
0 g
s
.52169 .71136 m .53033 .69328 L .54594 .70517 L .707 .577 .707 r
F
.54937 .65343 m .54594 .70517 L p .53033 .69328 L F P
0 g
s
.52939 .71114 m .52169 .71136 L p .54594 .70517 L .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .52246 .71939 L .54167 .70671 L p .707 .577 .707 r
F P
0 g
s
.52778 .7502 m .54167 .70671 L .54519 .70544 L .707 .577 .707 r
F
.52246 .71939 m .52778 .7502 L .51226 .76834 L p F P
0 g
s
.52033 .81501 m .52184 .79588 L .54565 .7962 L p .707 .577 .707 r
F P
0 g
s
.54565 .7962 m .54414 .81532 L .52033 .81501 L p .707 .577 .707 r
F P
0 g
s
.48875 .32471 m .49394 .82294 L .53888 .82132 L p .707 .577 .707 r
F P
0 g
s
.53888 .82132 m .53369 .32309 L .48875 .32471 L p .707 .577 .707 r
F P
0 g
s
.54414 .81532 m .54565 .7962 L .57485 .79755 L p .707 .577 .707 r
F P
0 g
s
.57485 .79755 m .57334 .81667 L .54414 .81532 L p .707 .577 .707 r
F P
0 g
s
.57334 .81667 m .57485 .79755 L .60656 .79981 L p .707 .577 .707 r
F P
0 g
s
.60656 .79981 m .60505 .81893 L .57334 .81667 L p .707 .577 .707 r
F P
0 g
s
.53369 .32309 m .53888 .82132 L .58036 .81572 L p .707 .577 .707 r
F P
0 g
s
.58036 .81572 m .57517 .3175 L .53369 .32309 L p .707 .577 .707 r
F P
0 g
s
.7029 .73876 m .70823 .76957 L .70457 .7513 L p .708 .578 .707 r
F P
0 g
s
.44993 .82044 m .44474 .32221 L .40598 .31583 L p .707 .577 .707 r
F P
0 g
s
.44474 .32221 m .44993 .82044 L .49394 .82294 L p .707 .577 .707 r
F P
0 g
s
.60505 .81893 m .60656 .79981 L .63769 .80276 L p .707 .577 .707 r
F P
0 g
s
.57517 .3175 m .58036 .81572 L .61431 .80671 L p .707 .577 .707 r
F P
0 g
s
.61431 .80671 m .60912 .30849 L .57517 .3175 L p .707 .577 .707 r
F P
0 g
s
.70228 .81525 m .70077 .83437 L .69764 .83179 L p .707 .577 .707 r
F P
0 g
s
.69764 .83179 m .69915 .81267 L .70228 .81525 L p .707 .577 .707 r
F P
0 g
s
.41117 .81406 m .40598 .31583 L .37625 .30619 L p .707 .577 .707 r
F P
0 g
s
.40598 .31583 m .41117 .81406 L .44993 .82044 L p .707 .577 .707 r
F P
0 g
s
.25116 .69697 m .25496 .63972 L .22381 .63695 L p .707 .577 .707 r
F P
0 g
s
.25496 .63972 m .25116 .69697 L .28291 .69873 L p .707 .577 .707 r
F P
0 g
s
.28291 .69873 m .28671 .64148 L .25496 .63972 L p .707 .577 .707 r
F P
0 g
s
.28671 .64148 m .28291 .69873 L .31216 .6993 L p .707 .577 .707 r
F P
0 g
s
.31216 .6993 m .31596 .64205 L .28671 .64148 L p .707 .577 .707 r
F P
0 g
s
.22381 .63695 m .22002 .6942 L .25116 .69697 L p .707 .577 .707 r
F P
0 g
s
.22002 .6942 m .22381 .63695 L .19633 .63343 L p .707 .577 .707 r
F P
0 g
s
.19633 .63343 m .19253 .69068 L .22002 .6942 L p .707 .577 .707 r
F P
0 g
s
.60912 .30849 m .61431 .80671 L .63741 .79516 L p .707 .577 .707 r
F P
0 g
s
.63741 .79516 m .63222 .29694 L .60912 .30849 L p .707 .577 .707 r
F P
0 g
s
.31596 .64205 m .31216 .6993 L .33605 .69862 L p .707 .577 .707 r
F P
0 g
s
.33605 .69862 m .33984 .64137 L .31596 .64205 L p .707 .577 .707 r
F P
0 g
s
.19253 .69068 m .19633 .63343 L .17519 .62951 L p .707 .577 .707 r
F P
0 g
s
.69915 .81267 m .69764 .83179 L .68486 .82864 L p .707 .577 .707 r
F P
0 g
s
.68486 .82864 m .68637 .80952 L .69915 .81267 L p .707 .577 .707 r
F P
0 g
s
.17519 .62951 m .17139 .68676 L .19253 .69068 L p .707 .577 .707 r
F P
0 g
s
.25012 .79615 m .25163 .77702 L .2205 .77408 L p .707 .577 .707 r
F P
0 g
s
.25163 .77702 m .25012 .79615 L .28184 .79841 L p .707 .577 .707 r
F P
0 g
s
.28184 .79841 m .28335 .77929 L .25163 .77702 L p .707 .577 .707 r
F P
0 g
s
.38144 .80442 m .37625 .30619 L .35847 .29424 L p .707 .577 .707 r
F P
0 g
s
.37625 .30619 m .38144 .80442 L .41117 .81406 L p .707 .577 .707 r
F P
0 g
s
.2205 .77408 m .21899 .7932 L .25012 .79615 L p .707 .577 .707 r
F P
0 g
s
.28335 .77929 m .28184 .79841 L .31103 .79976 L p .707 .577 .707 r
F P
0 g
s
.31103 .79976 m .31254 .78064 L .28335 .77929 L p .707 .577 .707 r
F P
0 g
s
.25995 .80223 m .25462 .77142 L .22358 .77123 L p .707 .577 .707 r
F P
0 g
s
.25462 .77142 m .25995 .80223 L .29139 .7965 L p .707 .577 .707 r
F P
0 g
s
.29139 .7965 m .28607 .76569 L .25462 .77142 L p .707 .577 .707 r
F P
0 g
s
.31254 .78064 m .31103 .79976 L .33484 .80007 L p .707 .577 .707 r
F P
0 g
s
.33484 .80007 m .33635 .78095 L .31254 .78064 L p .707 .577 .707 r
F P
0 g
s
.28607 .76569 m .29139 .7965 L .32017 .78541 L p .707 .577 .707 r
F P
0 g
s
.32017 .78541 m .31484 .7546 L .28607 .76569 L p .707 .577 .707 r
F P
0 g
s
.21899 .7932 m .2205 .77408 L .193 .77073 L p .707 .577 .707 r
F P
0 g
s
.33984 .64137 m .33605 .69862 L .35223 .69676 L p .707 .577 .707 r
F P
0 g
s
.35223 .69676 m .35603 .63951 L .33984 .64137 L p .707 .577 .707 r
F P
0 g
s
.193 .77073 m .19149 .78985 L .21899 .7932 L p .707 .577 .707 r
F P
0 g
s
.22891 .80204 m .22358 .77123 L .19599 .76513 L p .707 .577 .707 r
F P
0 g
s
.22358 .77123 m .22891 .80204 L .25995 .80223 L p .707 .577 .707 r
F P
0 g
s
.31484 .7546 m .32017 .78541 L .34346 .77003 L p .707 .577 .707 r
F P
0 g
s
.34346 .77003 m .33813 .73923 L .31484 .7546 L p .707 .577 .707 r
F P
0 g
s
.17139 .68676 m .17519 .62951 L .16246 .62557 L p .707 .577 .707 r
F P
0 g
s
.19149 .78985 m .193 .77073 L .17183 .76732 L p .707 .577 .707 r
F P
0 g
s
.16246 .62557 m .15867 .68282 L .17139 .68676 L p .707 .577 .707 r
F P
0 g
s
.63222 .29694 m .63741 .79516 L .64741 .78221 L p .707 .577 .707 r
F P
0 g
s
.64741 .78221 m .64222 .28398 L .63222 .29694 L p .707 .577 .707 r
F P
0 g
s
.17183 .76732 m .17032 .78644 L .19149 .78985 L p .707 .577 .707 r
F P
0 g
s
.68637 .80952 m .68486 .82864 L .66368 .82522 L p .707 .577 .707 r
F P
0 g
s
.66368 .82522 m .66519 .8061 L .68637 .80952 L p .707 .577 .707 r
F P
0 g
s
.20132 .79594 m .19599 .76513 L .17454 .75372 L p .707 .577 .707 r
F P
0 g
s
.19599 .76513 m .20132 .79594 L .22891 .80204 L p .707 .577 .707 r
F P
0 g
s
.33813 .73923 m .34346 .77003 L .35898 .75189 L p .707 .577 .707 r
F P
0 g
s
.35898 .75189 m .35366 .72108 L .33813 .73923 L p .707 .577 .707 r
F P
0 g
s
.35603 .63951 m .35223 .69676 L .35913 .69391 L p .707 .577 .707 r
F P
0 g
s
.35913 .69391 m .36292 .63666 L .35603 .63951 L p .707 .577 .707 r
F P
0 g
s
.33635 .78095 m .33484 .80007 L .35095 .79931 L p .707 .577 .707 r
F P
0 g
s
.35095 .79931 m .35246 .78019 L .33635 .78095 L p .707 .577 .707 r
F P
0 g
s
.35366 .72108 m .35898 .75189 L .36522 .73275 L p .707 .577 .707 r
F P
0 g
s
.36522 .73275 m .35989 .70194 L .35366 .72108 L p .707 .577 .707 r
F P
0 g
s
.36292 .63666 m .35913 .69391 L .35814 .69276 L p .707 .577 .707 r
F P
0 g
s
.35814 .69276 m .35607 .69034 L p .35664 .68581 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35623 .68368 L .35687 .68687 L p .708 .578 .707 r
F P
0 g
s
.35664 .68581 m .36292 .63666 L .35814 .69276 L .707 .577 .707 r
F
.35986 .63309 m .36292 .63666 L p .35703 .68281 L F P
0 g
s
.35607 .69034 m .35643 .68483 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35986 .63309 L p .35703 .68281 L .707 .577 .707 r
F P
0 g
s
.35607 .69034 m .34334 .6864 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35623 .68368 m .35643 .68483 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.35643 .68483 m .35607 .69034 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .35623 .68368 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .34413 .67444 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .34413 .67444 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34303 .66808 L p .35588 .68436 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .35986 .63309 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34714 .62915 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.35986 .63309 m .35643 .68483 L p .34644 .67639 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .35588 .68436 L .35643 .68483 L .707 .577 .707 r
F
.35643 .68483 m .36156 .71449 L .35126 .70231 L p F P
0 g
s
.35126 .70231 m .34836 .69889 L p .35643 .68483 L .707 .577 .707 r
F P
0 g
s
.36156 .71449 m .35643 .68483 L p .35989 .70194 L .708 .578 .707 r
F P
0 g
s
.35687 .68687 m .35989 .70194 L p .35643 .68483 L .708 .578 .707 r
F P
0 g
s
.35989 .70194 m .36522 .73275 L .36156 .71449 L p .708 .578 .707 r
F P
0 g
s
.36366 .79247 m .35847 .29424 L .35437 .28114 L p .707 .577 .707 r
F P
0 g
s
.35847 .29424 m .36366 .79247 L .38144 .80442 L p .707 .577 .707 r
F P
0 g
s
.15867 .68282 m .16246 .62557 L .1594 .622 L p .707 .577 .707 r
F P
0 g
s
.17032 .78644 m .17183 .76732 L .15904 .76416 L p .707 .577 .707 r
F P
0 g
s
.15904 .76416 m .15753 .78328 L .17032 .78644 L p .707 .577 .707 r
F P
0 g
s
.66519 .8061 m .66368 .82522 L .63618 .82188 L p .707 .577 .707 r
F P
0 g
s
.63618 .82188 m .63769 .80276 L .66519 .8061 L p .707 .577 .707 r
F P
0 g
s
.17987 .78453 m .17454 .75372 L .16135 .73812 L p .707 .577 .707 r
F P
0 g
s
.17454 .75372 m .17987 .78453 L .20132 .79594 L p .707 .577 .707 r
F P
0 g
s
.1594 .622 m .1556 .67925 L .15867 .68282 L p .707 .577 .707 r
F P
0 g
s
.63769 .80276 m .63618 .82188 L .60505 .81893 L p .707 .577 .707 r
F P
0 g
s
.64222 .28398 m .64741 .78221 L .64656 .77951 L p .707 .577 .707 r
F P
0 g
s
.64318 .71089 m .64222 .28398 L .64656 .77951 L .707 .577 .707 r
F
.63812 .27089 m .64222 .28398 L p .64301 .63495 L F P
0 g
s
.64331 .76673 m .64189 .63242 L .64301 .63495 L .707 .577 .707 r
F
.64328 .7663 m .64189 .63242 L p .64331 .76673 L F P
0 g
s
.64656 .77951 m .64347 .76961 L p .64318 .71089 L .707 .577 .707 r
F P
0 g
s
.64347 .76961 m .64331 .76911 L p .64331 .76673 L .707 .577 .707 r
F P
0 g
s
.64331 .76673 m .64318 .71089 L .64347 .76961 L .707 .577 .707 r
F
.63812 .27089 m .64331 .76911 L .62553 .75716 L p F P
0 g
s
.63926 .71042 m .63775 .72954 L .64129 .73041 L p .707 .577 .707 r
F P
0 g
s
.64129 .73041 m .65053 .73269 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.6403 .71247 m .63926 .71042 L .64129 .73041 L .707 .577 .707 r
F
.65053 .73269 m .65204 .71357 L .6402 .71065 L p F P
0 g
s
.6402 .71065 m .63926 .71042 L p .6403 .71247 L .707 .577 .707 r
F P
0 g
s
.65053 .73269 m .6402 .71065 L .6403 .71247 L .707 .577 .707 r
F
.64331 .76911 m .64328 .7663 L p .64331 .76673 L F P
0 g
s
.64189 .63242 m .63812 .27089 L p .64301 .63495 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63961 .56678 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63888 .6276 m .63899 .62589 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .64267 .57035 L p .6389 .62568 L .707 .577 .707 r
F P
0 g
s
.64267 .57035 m .63899 .62589 L p .6516 .63154 L .707 .577 .707 r
F P
0 g
s
.63899 .62589 m .63888 .6276 L .63908 .62766 L p .707 .577 .707 r
F P
0 g
s
.63908 .62766 m .6516 .63154 L p .63899 .62589 L .707 .577 .707 r
F P
0 g
s
.35246 .78019 m .35095 .79931 L .35777 .79756 L p .707 .577 .707 r
F P
0 g
s
.35777 .79756 m .35928 .77844 L .35246 .78019 L p .707 .577 .707 r
F P
0 g
s
.16135 .73812 m .16667 .76893 L .17987 .78453 L p .707 .577 .707 r
F P
0 g
s
.16667 .76893 m .16135 .73812 L .15769 .71986 L p .708 .578 .707 r
F P
0 g
s
.15753 .78328 m .15904 .76416 L .15591 .76158 L p .707 .577 .707 r
F P
0 g
s
.15591 .76158 m .1544 .7807 L .15753 .78328 L p .707 .577 .707 r
F P
0 g
s
.1556 .67925 m .1594 .622 L .16629 .61915 L p .707 .577 .707 r
F P
0 g
s
.16629 .61915 m .1625 .6764 L .1556 .67925 L p .707 .577 .707 r
F P
0 g
s
.35437 .28114 m .35956 .77937 L .36366 .79247 L p .707 .577 .707 r
F P
0 g
s
.35956 .77937 m .35437 .28114 L .36437 .26819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35928 .77844 m .35777 .79756 L .35463 .79498 L p .707 .577 .707 r
F P
0 g
s
.35463 .79498 m .35614 .77586 L .35928 .77844 L p .707 .577 .707 r
F P
0 g
s
.15769 .71986 m .16301 .75067 L .16667 .76893 L p .708 .578 .707 r
F P
0 g
s
.16301 .75067 m .15769 .71986 L .16392 .70072 L p .707 .577 .707 r
F P
0 g
s
.1544 .7807 m .15591 .76158 L .16273 .75983 L p .707 .577 .707 r
F P
0 g
s
.62553 .75716 m .62034 .25893 L .63812 .27089 L p .707 .577 .707 r
F P
0 g
s
.1625 .6764 m .16629 .61915 L .18248 .61729 L p .707 .577 .707 r
F P
0 g
s
.16273 .75983 m .16122 .77895 L .1544 .7807 L p .707 .577 .707 r
F P
0 g
s
.18248 .61729 m .17868 .67454 L .1625 .6764 L p .707 .577 .707 r
F P
0 g
s
.16392 .70072 m .16925 .73153 L .16301 .75067 L p .707 .577 .707 r
F P
0 g
s
.16925 .73153 m .16392 .70072 L .17945 .68258 L p .707 .577 .707 r
F P
0 g
s
.36956 .76641 m .36437 .26819 L .38747 .25664 L p .707 .577 .707 r
F P
0 g
s
.36437 .26819 m .36956 .76641 L .35956 .77937 L p .707 .577 .707 r
F P
0 g
s
.34334 .6864 m .3222 .68248 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34334 .6864 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34836 .69889 m .32692 .68748 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34303 .66808 m .34413 .67444 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.34413 .67444 m .34836 .69889 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32159 .65667 m .34303 .66808 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.3222 .68248 m .32327 .66637 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32692 .68748 m .32327 .66637 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32159 .65667 L p .3393 .67257 L .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .34714 .62915 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.32327 .66637 m .32599 .62523 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.34714 .62915 m .34413 .67444 L p .32874 .66849 L .707 .577 .707 r
F P
0 g
s
.35614 .77586 m .35463 .79498 L .34185 .79182 L p .707 .577 .707 r
F P
0 g
s
.34185 .79182 m .34336 .7727 L .35614 .77586 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18248 .61729 L .20636 .61661 L p .707 .577 .707 r
F P
0 g
s
.16122 .77895 m .16273 .75983 L .17883 .75907 L p .707 .577 .707 r
F P
0 g
s
.17883 .75907 m .17732 .77819 L .16122 .77895 L p .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20257 .67386 L .18638 .67432 L p .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .17945 .68258 L .19866 .66989 L p .707 .577 .707 r
F P
0 g
s
.19866 .66989 m .20274 .6672 L p .20218 .66862 L .707 .577 .707 r
F P
0 g
s
.18477 .71338 m .19866 .66989 L .20218 .66862 L .707 .577 .707 r
F
.20274 .6672 m .23151 .65611 L p .22737 .6635 L F P
0 g
s
.20389 .66816 m .20274 .6672 L .22737 .6635 L .707 .577 .707 r
F
.20636 .61661 m .23561 .61718 L p .20615 .66771 L F P
0 g
s
.20257 .67386 m .20293 .66835 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20274 .6672 L p .20389 .66816 L .707 .577 .707 r
F P
0 g
s
.23182 .67443 m .20257 .67386 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.20293 .66835 m .20389 .66816 L .21817 .67995 L .707 .577 .707 r
F
.23151 .65611 m .26296 .65038 L p .25554 .66076 L F P
0 g
s
.23836 .66204 m .23151 .65611 L .25554 .66076 L .707 .577 .707 r
F
.23561 .61718 m .26736 .61894 L p .23983 .66193 L F P
0 g
s
.23182 .67443 m .23261 .66247 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23151 .65611 L p .23836 .66204 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .23182 .67443 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.23261 .66247 m .23836 .66204 L .24841 .67073 L .707 .577 .707 r
F
.29471 .67896 m .26357 .67619 L p .27365 .66047 L F P
0 g
s
.26296 .65038 m .294 .65057 L p .28527 .66097 L .707 .577 .707 r
F P
0 g
s
.27239 .66041 m .26296 .65038 L .28527 .66097 L .707 .577 .707 r
F
.3222 .68248 m .29471 .67896 L p .30406 .6629 L F P
0 g
s
.294 .65057 m .32159 .65667 L p .31431 .66475 L .707 .577 .707 r
F P
0 g
s
.30342 .66279 m .294 .65057 L .31431 .66475 L .707 .577 .707 r
F
.32327 .66637 m .3222 .68248 L p .30406 .6629 L F P
0 g
s
.32159 .65667 m .32692 .68748 L .29933 .68138 L p .707 .577 .707 r
F P
0 g
s
.32599 .62523 m .32327 .66637 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29851 .62171 m .32599 .62523 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29471 .67896 m .29587 .66143 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .294 .65057 L p .30342 .66279 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .29851 .62171 L p .30406 .6629 L .707 .577 .707 r
F P
0 g
s
.29587 .66143 m .30342 .66279 L .30926 .67036 L .707 .577 .707 r
F
.30926 .67036 m .30342 .66279 L .31431 .66475 L F
.29933 .68138 m .29587 .66143 L p .30926 .67036 L F P
0 g
s
.29587 .66143 m .29471 .67896 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.294 .65057 m .29933 .68138 L .26829 .68119 L p .707 .577 .707 r
F P
0 g
s
.27365 .66047 m .27988 .65075 L .29587 .66143 L .707 .577 .707 r
F
.29851 .62171 m .29587 .66143 L p .27988 .65075 L F P
0 g
s
.26736 .61894 m .29851 .62171 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26357 .67619 m .26464 .66008 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26296 .65038 L p .27239 .66041 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .26736 .61894 L p .27365 .66047 L .707 .577 .707 r
F P
0 g
s
.26464 .66008 m .27239 .66041 L .27944 .66791 L .707 .577 .707 r
F
.27944 .66791 m .27239 .66041 L .28527 .66097 L F
.26829 .68119 m .26464 .66008 L p .27944 .66791 L F P
0 g
s
.26464 .66008 m .26357 .67619 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.26296 .65038 m .26829 .68119 L .23684 .68692 L p .707 .577 .707 r
F P
0 g
s
.23983 .66193 m .24699 .65074 L .26464 .66008 L .707 .577 .707 r
F
.26736 .61894 m .26464 .66008 L p .24699 .65074 L F P
0 g
s
.23261 .66247 m .23561 .61718 L p .23983 .66193 L .707 .577 .707 r
F P
0 g
s
.24841 .67073 m .23836 .66204 L .25554 .66076 L .707 .577 .707 r
F
.23684 .68692 m .23261 .66247 L p .24841 .67073 L F P
0 g
s
.23261 .66247 m .23182 .67443 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.23151 .65611 m .23684 .68692 L .20806 .69801 L p .707 .577 .707 r
F P
0 g
s
.20615 .66771 m .21468 .65308 L .23261 .66247 L .707 .577 .707 r
F
.23561 .61718 m .23261 .66247 L p .21468 .65308 L F P
0 g
s
.20293 .66835 m .20636 .61661 L p .20615 .66771 L .707 .577 .707 r
F P
0 g
s
.21817 .67995 m .20389 .66816 L .22737 .6635 L .707 .577 .707 r
F
.20806 .69801 m .20293 .66835 L p .21817 .67995 L F P
0 g
s
.20274 .6672 m .20806 .69801 L .18477 .71338 L p .707 .577 .707 r
F P
0 g
s
.17868 .67454 m .18732 .65647 L .20293 .66835 L .707 .577 .707 r
F
.20636 .61661 m .20293 .66835 L p .18732 .65647 L F P
0 g
s
.18638 .67432 m .17868 .67454 L p .20293 .66835 L .707 .577 .707 r
F P
0 g
s
.17945 .68258 m .18477 .71338 L .16925 .73153 L p .707 .577 .707 r
F P
0 g
s
.62034 .25893 m .62553 .75716 L .5958 .74752 L p .707 .577 .707 r
F P
0 g
s
.5958 .74752 m .59061 .24929 L .62034 .25893 L p .707 .577 .707 r
F P
0 g
s
.34336 .7727 m .34185 .79182 L .32067 .78841 L p .707 .577 .707 r
F P
0 g
s
.32067 .78841 m .32218 .76929 L .34336 .7727 L p .707 .577 .707 r
F P
0 g
s
.38747 .25664 m .39266 .75487 L .36956 .76641 L p .707 .577 .707 r
F P
0 g
s
.39266 .75487 m .38747 .25664 L .42142 .24763 L p .707 .577 .707 r
F P
0 g
s
.17732 .77819 m .17883 .75907 L .20264 .75938 L p .707 .577 .707 r
F P
0 g
s
.20264 .75938 m .20113 .7785 L .17732 .77819 L p .707 .577 .707 r
F P
0 g
s
.73138 .64175 m .73517 .5845 L .70403 .58173 L p .707 .577 .707 r
F P
0 g
s
.73517 .5845 m .73138 .64175 L .76313 .64351 L p .707 .577 .707 r
F P
0 g
s
.76313 .64351 m .76692 .58626 L .73517 .5845 L p .707 .577 .707 r
F P
0 g
s
.76692 .58626 m .76313 .64351 L .79238 .64407 L p .707 .577 .707 r
F P
0 g
s
.79238 .64407 m .79617 .58682 L .76692 .58626 L p .707 .577 .707 r
F P
0 g
s
.70403 .58173 m .70023 .63898 L .73138 .64175 L p .707 .577 .707 r
F P
0 g
s
.70023 .63898 m .70403 .58173 L .67654 .57821 L p .707 .577 .707 r
F P
0 g
s
.59061 .24929 m .5958 .74752 L .55704 .74114 L p .707 .577 .707 r
F P
0 g
s
.55704 .74114 m .55185 .24291 L .59061 .24929 L p .707 .577 .707 r
F P
0 g
s
.32218 .76929 m .32067 .78841 L .29317 .78506 L p .707 .577 .707 r
F P
0 g
s
.29317 .78506 m .29468 .76594 L .32218 .76929 L p .707 .577 .707 r
F P
0 g
s
.67654 .57821 m .67275 .63546 L .70023 .63898 L p .707 .577 .707 r
F P
0 g
s
.79617 .58682 m .79238 .64407 L .81626 .6434 L p .707 .577 .707 r
F P
0 g
s
.81626 .6434 m .82006 .58615 L .79617 .58682 L p .707 .577 .707 r
F P
0 g
s
.20113 .7785 m .20264 .75938 L .23184 .76073 L p .707 .577 .707 r
F P
0 g
s
.23184 .76073 m .23033 .77986 L .20113 .7785 L p .707 .577 .707 r
F P
0 g
s
.67275 .63546 m .67654 .57821 L .6554 .57429 L p .707 .577 .707 r
F P
0 g
s
.42661 .74585 m .42142 .24763 L .4629 .24203 L p .707 .577 .707 r
F P
0 g
s
.42142 .24763 m .42588 .67541 L p .39266 .75487 L .707 .577 .707 r
F P
0 g
s
.4629 .24203 m .46809 .74026 L .42661 .74585 L p .707 .577 .707 r
F P
0 g
s
.42391 .54944 m .42012 .60669 L .4489 .60725 L p .707 .577 .707 r
F P
0 g
s
.4489 .60725 m .44937 .60726 L p .4491 .60666 L .707 .577 .707 r
F P
0 g
s
.4491 .60666 m .42391 .54944 L .4489 .60725 L .707 .577 .707 r
F
.42588 .67541 m .42658 .74304 L p .39966 .75301 L F P
0 g
s
.39966 .75301 m .39266 .75487 L p .42588 .67541 L .707 .577 .707 r
F P
0 g
s
.42055 .68872 m .41904 .70784 L .44014 .70882 L p .707 .577 .707 r
F P
0 g
s
.44014 .70882 m .44823 .7092 L p .44185 .70448 L .707 .577 .707 r
F P
0 g
s
.44185 .70448 m .42055 .68872 L .44014 .70882 L .707 .577 .707 r
F
.42658 .74304 m .42661 .74585 L .42533 .74619 L p F P
0 g
s
.42533 .74619 m .39966 .75301 L p .42658 .74304 L .707 .577 .707 r
F P
0 g
s
.29468 .76594 m .29317 .78506 L .26204 .78212 L p .707 .577 .707 r
F P
0 g
s
.26204 .78212 m .26355 .76299 L .29468 .76594 L p .707 .577 .707 r
F P
0 g
s
.6554 .57429 m .6516 .63154 L .67275 .63546 L p .707 .577 .707 r
F P
0 g
s
.73034 .7424 m .73185 .72328 L .70072 .72033 L p .707 .577 .707 r
F P
0 g
s
.73185 .72328 m .73034 .7424 L .76205 .74466 L p .707 .577 .707 r
F P
0 g
s
.76205 .74466 m .76356 .72554 L .73185 .72328 L p .707 .577 .707 r
F P
0 g
s
.70072 .72033 m .69921 .73945 L .73034 .7424 L p .707 .577 .707 r
F P
0 g
s
.23033 .77986 m .23184 .76073 L .26355 .76299 L p .707 .577 .707 r
F P
0 g
s
.26355 .76299 m .26204 .78212 L .23033 .77986 L p .707 .577 .707 r
F P
0 g
s
.76356 .72554 m .76205 .74466 L .79124 .74601 L p .707 .577 .707 r
F P
0 g
s
.79124 .74601 m .79275 .72689 L .76356 .72554 L p .707 .577 .707 r
F P
0 g
s
.55185 .24291 m .55704 .74114 L .51303 .73864 L p .707 .577 .707 r
F P
0 g
s
.51303 .73864 m .50784 .24041 L .55185 .24291 L p .707 .577 .707 r
F P
0 g
s
.74016 .74662 m .73483 .71581 L .70379 .71562 L p .707 .577 .707 r
F P
0 g
s
.73483 .71581 m .74016 .74662 L .77161 .74089 L p .707 .577 .707 r
F P
0 g
s
.77161 .74089 m .76628 .71008 L .73483 .71581 L p .707 .577 .707 r
F P
0 g
s
.79275 .72689 m .79124 .74601 L .81506 .74632 L p .707 .577 .707 r
F P
0 g
s
.81506 .74632 m .81657 .7272 L .79275 .72689 L p .707 .577 .707 r
F P
0 g
s
.76628 .71008 m .77161 .74089 L .80038 .7298 L p .707 .577 .707 r
F P
0 g
s
.80038 .7298 m .79506 .69899 L .76628 .71008 L p .707 .577 .707 r
F P
0 g
s
.69921 .73945 m .70072 .72033 L .67322 .71698 L p .707 .577 .707 r
F P
0 g
s
.82006 .58615 m .81626 .6434 L .83245 .64154 L p .707 .577 .707 r
F P
0 g
s
.83245 .64154 m .83624 .58429 L .82006 .58615 L p .707 .577 .707 r
F P
0 g
s
.67322 .71698 m .67171 .73611 L .69921 .73945 L p .707 .577 .707 r
F P
0 g
s
.46809 .74026 m .4629 .24203 L .50784 .24041 L p .707 .577 .707 r
F P
0 g
s
.50784 .24041 m .51303 .73864 L .46809 .74026 L p .707 .577 .707 r
F P
0 g
s
.70912 .74643 m .70379 .71562 L .6762 .70952 L p .707 .577 .707 r
F P
0 g
s
.70379 .71562 m .70912 .74643 L .74016 .74662 L p .707 .577 .707 r
F P
0 g
s
.79506 .69899 m .80038 .7298 L .82367 .71443 L p .707 .577 .707 r
F P
0 g
s
.82367 .71443 m .81835 .68362 L .79506 .69899 L p .707 .577 .707 r
F P
0 g
s
.6516 .63154 m .6554 .57429 L .64267 .57035 L p .707 .577 .707 r
F P
0 g
s
.67171 .73611 m .67322 .71698 L .65204 .71357 L p .707 .577 .707 r
F P
0 g
s
.65204 .71357 m .65053 .73269 L .67171 .73611 L p .707 .577 .707 r
F P
0 g
s
.68153 .74033 m .6762 .70952 L .65476 .69811 L p .707 .577 .707 r
F P
0 g
s
.6762 .70952 m .68153 .74033 L .70912 .74643 L p .707 .577 .707 r
F P
0 g
s
.81835 .68362 m .82367 .71443 L .8392 .69628 L p .707 .577 .707 r
F P
0 g
s
.8392 .69628 m .83387 .66548 L .81835 .68362 L p .707 .577 .707 r
F P
0 g
s
.83624 .58429 m .83245 .64154 L .83934 .63869 L p .707 .577 .707 r
F P
0 g
s
.83934 .63869 m .84314 .58144 L .83624 .58429 L p .707 .577 .707 r
F P
0 g
s
.81657 .7272 m .81506 .74632 L .83116 .74557 L p .707 .577 .707 r
F P
0 g
s
.83116 .74557 m .83267 .72644 L .81657 .7272 L p .707 .577 .707 r
F P
0 g
s
.66009 .72892 m .65476 .69811 L .64156 .68252 L p .707 .577 .707 r
F P
0 g
s
.65476 .69811 m .66009 .72892 L .68153 .74033 L p .707 .577 .707 r
F P
0 g
s
.83387 .66548 m .8392 .69628 L .84543 .67714 L p .707 .577 .707 r
F P
0 g
s
.84543 .67714 m .84011 .64634 L .83387 .66548 L p .707 .577 .707 r
F P
0 g
s
.63961 .56678 m .63582 .62403 L .63888 .6276 L p .707 .577 .707 r
F P
0 g
s
.83267 .72644 m .83116 .74557 L .83798 .74381 L p .707 .577 .707 r
F P
0 g
s
.83798 .74381 m .83949 .72469 L .83267 .72644 L p .707 .577 .707 r
F P
0 g
s
.83846 .63766 m .83628 .63512 L p .83689 .63036 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83645 .62807 L .83715 .63156 L p .708 .578 .707 r
F P
0 g
s
.84007 .57787 m .84314 .58144 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .83666 .62933 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .84007 .57787 L p .83729 .62721 L .707 .577 .707 r
F P
0 g
s
.83628 .63512 m .82355 .63118 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.83645 .62807 m .83666 .62933 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.83666 .62933 m .83628 .63512 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .83645 .62807 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .82437 .61893 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .82437 .61893 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82325 .61247 L p .83606 .62882 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .84007 .57787 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82735 .57393 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.84007 .57787 m .83666 .62933 L p .82673 .62093 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .83606 .62882 L .83666 .62933 L .707 .577 .707 r
F
.83666 .62933 m .84177 .65888 L .83151 .64675 L p F P
0 g
s
.83151 .64675 m .82858 .64328 L p .83666 .62933 L .707 .577 .707 r
F P
0 g
s
.84177 .65888 m .83666 .62933 L p .84011 .64634 L .708 .578 .707 r
F P
0 g
s
.83715 .63156 m .84011 .64634 L p .83666 .62933 L .708 .578 .707 r
F P
0 g
s
.84314 .58144 m .83934 .63869 L .83846 .63766 L p .707 .577 .707 r
F P
0 g
s
.83689 .63036 m .84314 .58144 L .83846 .63766 L .707 .577 .707 r
F
.64156 .68252 m .64689 .71332 L .66009 .72892 L p F P
0 g
s
.64689 .71332 m .64156 .68252 L .6379 .66425 L p .708 .578 .707 r
F P
0 g
s
.63775 .72954 m .63926 .71042 L .63612 .70784 L p .707 .577 .707 r
F P
0 g
s
.84011 .64634 m .84543 .67714 L .84177 .65888 L p .708 .578 .707 r
F P
0 g
s
.63612 .70784 m .63461 .72696 L .63775 .72954 L p .707 .577 .707 r
F P
0 g
s
.63582 .62403 m .63961 .56678 L .64651 .56393 L p .707 .577 .707 r
F P
0 g
s
.64651 .56393 m .64271 .62118 L .63582 .62403 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.6379 .66425 m .64323 .69506 L .64689 .71332 L p .708 .578 .707 r
F P
0 g
s
.83949 .72469 m .83798 .74381 L .83484 .74123 L p .707 .577 .707 r
F P
0 g
s
.83484 .74123 m .83635 .72211 L .83949 .72469 L p .707 .577 .707 r
F P
0 g
s
.64323 .69506 m .6379 .66425 L .64414 .64511 L p .707 .577 .707 r
F P
0 g
s
.38837 .60494 m .39216 .54769 L .36102 .54491 L p .707 .577 .707 r
F P
0 g
s
.39216 .54769 m .38837 .60494 L .42012 .60669 L p .707 .577 .707 r
F P
0 g
s
.42012 .60669 m .42391 .54944 L .39216 .54769 L p .707 .577 .707 r
F P
0 g
s
.44937 .60726 m .45316 .55001 L .42391 .54944 L p .707 .577 .707 r
F P
0 g
s
.63461 .72696 m .63612 .70784 L .64294 .70608 L p .707 .577 .707 r
F P
0 g
s
.64271 .62118 m .64651 .56393 L .66269 .56207 L p .707 .577 .707 r
F P
0 g
s
.36102 .54491 m .35722 .60216 L .38837 .60494 L p .707 .577 .707 r
F P
0 g
s
.64294 .70608 m .64143 .7252 L .63461 .72696 L p .707 .577 .707 r
F P
0 g
s
.35722 .60216 m .36102 .54491 L .33353 .54139 L p .707 .577 .707 r
F P
0 g
s
.66269 .56207 m .6589 .61932 L .64271 .62118 L p .707 .577 .707 r
F P
0 g
s
.33353 .54139 m .32974 .59864 L .35722 .60216 L p .707 .577 .707 r
F P
0 g
s
.45316 .55001 m .44937 .60726 L .47325 .60658 L p .707 .577 .707 r
F P
0 g
s
.47325 .60658 m .47705 .54933 L .45316 .55001 L p .707 .577 .707 r
F P
0 g
s
.64414 .64511 m .64946 .67592 L .64323 .69506 L p .707 .577 .707 r
F P
0 g
s
.64946 .67592 m .64414 .64511 L .65966 .62697 L p .707 .577 .707 r
F P
0 g
s
.32974 .59864 m .33353 .54139 L .31239 .53747 L p .707 .577 .707 r
F P
0 g
s
.82355 .63118 m .80241 .62726 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82355 .63118 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82858 .64328 m .80713 .63187 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82325 .61247 m .82437 .61893 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.82437 .61893 m .82858 .64328 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8018 .60106 m .82325 .61247 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80241 .62726 m .8035 .61087 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.80713 .63187 m .8035 .61087 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .8018 .60106 L p .81946 .61704 L .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .82735 .57393 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.8035 .61087 m .80621 .57001 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.82735 .57393 m .82437 .61893 L p .80907 .61302 L .707 .577 .707 r
F P
0 g
s
.83635 .72211 m .83484 .74123 L .82206 .73808 L p .707 .577 .707 r
F P
0 g
s
.82206 .73808 m .82357 .71896 L .83635 .72211 L p .707 .577 .707 r
F P
0 g
s
.31239 .53747 m .30859 .59472 L .32974 .59864 L p .707 .577 .707 r
F P
0 g
s
.38733 .70558 m .38884 .68646 L .35771 .68351 L p .707 .577 .707 r
F P
0 g
s
.38884 .68646 m .38733 .70558 L .41904 .70784 L p .707 .577 .707 r
F P
0 g
s
.41904 .70784 m .42055 .68872 L .38884 .68646 L p .707 .577 .707 r
F P
0 g
s
.35771 .68351 m .3562 .70264 L .38733 .70558 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66269 .56207 L .68658 .56139 L p .707 .577 .707 r
F P
0 g
s
.44823 .7092 m .44974 .69008 L .42055 .68872 L p .707 .577 .707 r
F P
0 g
s
.39715 .70981 m .39182 .679 L .36078 .67881 L p .707 .577 .707 r
F P
0 g
s
.39182 .679 m .39715 .70981 L .4286 .70408 L p .707 .577 .707 r
F P
0 g
s
.4286 .70408 m .42327 .67327 L .39182 .679 L p .707 .577 .707 r
F P
0 g
s
.44974 .69008 m .44823 .7092 L .47205 .70951 L p .707 .577 .707 r
F P
0 g
s
.47205 .70951 m .47356 .69039 L .44974 .69008 L p .707 .577 .707 r
F P
0 g
s
.42327 .67327 m .4286 .70408 L .45737 .69298 L p .707 .577 .707 r
F P
0 g
s
.45737 .69298 m .45205 .66218 L .42327 .67327 L p .707 .577 .707 r
F P
0 g
s
.64143 .7252 m .64294 .70608 L .65904 .70532 L p .707 .577 .707 r
F P
0 g
s
.3562 .70264 m .35771 .68351 L .33021 .68017 L p .707 .577 .707 r
F P
0 g
s
.47705 .54933 m .47325 .60658 L .48944 .60472 L p .707 .577 .707 r
F P
0 g
s
.48944 .60472 m .49323 .54748 L .47705 .54933 L p .707 .577 .707 r
F P
0 g
s
.65904 .70532 m .65753 .72444 L .64143 .7252 L p .707 .577 .707 r
F P
0 g
s
.33021 .68017 m .3287 .69929 L .3562 .70264 L p .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68278 .61864 L .66577 .61912 L p .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .65966 .62697 L .6785 .61453 L p .707 .577 .707 r
F P
0 g
s
.6785 .61453 m .68295 .6116 L p .68235 .61315 L .707 .577 .707 r
F P
0 g
s
.66499 .65777 m .6785 .61453 L .68235 .61315 L .707 .577 .707 r
F
.68295 .6116 m .71173 .6005 L p .70752 .60802 L F P
0 g
s
.68421 .61264 m .68295 .6116 L .70752 .60802 L .707 .577 .707 r
F
.68658 .56139 m .71583 .56196 L p .68655 .61218 L F P
0 g
s
.68278 .61864 m .68317 .61285 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68295 .6116 L p .68421 .61264 L .707 .577 .707 r
F P
0 g
s
.71203 .61921 m .68278 .61864 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.68317 .61285 m .68421 .61264 L .69835 .62441 L .707 .577 .707 r
F
.71173 .6005 m .74317 .59477 L p .73567 .60526 L F P
0 g
s
.71864 .60653 m .71173 .6005 L .73567 .60526 L .707 .577 .707 r
F
.71583 .56196 m .74758 .56372 L p .72023 .60642 L F P
0 g
s
.71203 .61921 m .71284 .60697 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71173 .6005 L p .71864 .60653 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .71203 .61921 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.71284 .60697 m .71864 .60653 L .72857 .6152 L .707 .577 .707 r
F
.77493 .62374 m .74378 .62096 L p .75404 .60497 L F P
0 g
s
.74317 .59477 m .77421 .59497 L p .7654 .60546 L .707 .577 .707 r
F P
0 g
s
.75264 .60491 m .74317 .59477 L .7654 .60546 L .707 .577 .707 r
F
.80241 .62726 m .77493 .62374 L p .78442 .60743 L F P
0 g
s
.77421 .59497 m .8018 .60106 L p .79444 .60924 L .707 .577 .707 r
F P
0 g
s
.78366 .60729 m .77421 .59497 L .79444 .60924 L .707 .577 .707 r
F
.8035 .61087 m .80241 .62726 L p .78442 .60743 L F P
0 g
s
.8018 .60106 m .80713 .63187 L .77954 .62577 L p .707 .577 .707 r
F P
0 g
s
.80621 .57001 m .8035 .61087 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77872 .56649 m .80621 .57001 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77493 .62374 m .77611 .60592 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77421 .59497 L p .78366 .60729 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .77872 .56649 L p .78442 .60743 L .707 .577 .707 r
F P
0 g
s
.77611 .60592 m .78366 .60729 L .78942 .61481 L .707 .577 .707 r
F
.78942 .61481 m .78366 .60729 L .79444 .60924 L F
.77954 .62577 m .77611 .60592 L p .78942 .61481 L F P
0 g
s
.77611 .60592 m .77493 .62374 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.77421 .59497 m .77954 .62577 L .7485 .62558 L p .707 .577 .707 r
F P
0 g
s
.75404 .60497 m .76023 .59533 L .77611 .60592 L .707 .577 .707 r
F
.77872 .56649 m .77611 .60592 L p .76023 .59533 L F P
0 g
s
.74758 .56372 m .77872 .56649 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74378 .62096 m .74487 .60458 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74317 .59477 L p .75264 .60491 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .74758 .56372 L p .75404 .60497 L .707 .577 .707 r
F P
0 g
s
.74487 .60458 m .75264 .60491 L .7596 .61237 L .707 .577 .707 r
F
.7596 .61237 m .75264 .60491 L .7654 .60546 L F
.7485 .62558 m .74487 .60458 L p .7596 .61237 L F P
0 g
s
.74487 .60458 m .74378 .62096 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.74317 .59477 m .7485 .62558 L .71705 .63131 L p .707 .577 .707 r
F P
0 g
s
.72023 .60642 m .72734 .59531 L .74487 .60458 L .707 .577 .707 r
F
.74758 .56372 m .74487 .60458 L p .72734 .59531 L F P
0 g
s
.71284 .60697 m .71583 .56196 L p .72023 .60642 L .707 .577 .707 r
F P
0 g
s
.72857 .6152 m .71864 .60653 L .73567 .60526 L .707 .577 .707 r
F
.71705 .63131 m .71284 .60697 L p .72857 .6152 L F P
0 g
s
.71284 .60697 m .71203 .61921 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.71173 .6005 m .71705 .63131 L .68828 .6424 L p .707 .577 .707 r
F P
0 g
s
.68655 .61218 m .69503 .59764 L .71284 .60697 L .707 .577 .707 r
F
.71583 .56196 m .71284 .60697 L p .69503 .59764 L F P
0 g
s
.68317 .61285 m .68658 .56139 L p .68655 .61218 L .707 .577 .707 r
F P
0 g
s
.69835 .62441 m .68421 .61264 L .70752 .60802 L .707 .577 .707 r
F
.68828 .6424 m .68317 .61285 L p .69835 .62441 L F P
0 g
s
.68295 .6116 m .68828 .6424 L .66499 .65777 L p .707 .577 .707 r
F P
0 g
s
.6589 .61932 m .66764 .60103 L .68317 .61285 L .707 .577 .707 r
F
.68658 .56139 m .68317 .61285 L p .66764 .60103 L F P
0 g
s
.66577 .61912 m .6589 .61932 L p .68317 .61285 L .707 .577 .707 r
F P
0 g
s
.36611 .70961 m .36078 .67881 L .33319 .67271 L p .707 .577 .707 r
F P
0 g
s
.36078 .67881 m .36611 .70961 L .39715 .70981 L p .707 .577 .707 r
F P
0 g
s
.65966 .62697 m .66499 .65777 L .64946 .67592 L p .707 .577 .707 r
F P
0 g
s
.45205 .66218 m .45737 .69298 L .48066 .67761 L p .707 .577 .707 r
F P
0 g
s
.48066 .67761 m .47534 .6468 L .45205 .66218 L p .707 .577 .707 r
F P
0 g
s
.30859 .59472 m .31239 .53747 L .29966 .53353 L p .707 .577 .707 r
F P
0 g
s
.29966 .53353 m .29587 .59078 L .30859 .59472 L p .707 .577 .707 r
F P
0 g
s
.3287 .69929 m .33021 .68017 L .30903 .67675 L p .707 .577 .707 r
F P
0 g
s
.30903 .67675 m .30752 .69587 L .3287 .69929 L p .707 .577 .707 r
F P
0 g
s
.82357 .71896 m .82206 .73808 L .80088 .73466 L p .707 .577 .707 r
F P
0 g
s
.80088 .73466 m .80239 .71554 L .82357 .71896 L p .707 .577 .707 r
F P
0 g
s
.33852 .70351 m .33319 .67271 L .31175 .6613 L p .707 .577 .707 r
F P
0 g
s
.33319 .67271 m .33852 .70351 L .36611 .70961 L p .707 .577 .707 r
F P
0 g
s
.47534 .6468 m .48066 .67761 L .49619 .65947 L p .707 .577 .707 r
F P
0 g
s
.49619 .65947 m .49086 .62866 L .47534 .6468 L p .707 .577 .707 r
F P
0 g
s
.65753 .72444 m .65904 .70532 L .68286 .70563 L p .707 .577 .707 r
F P
0 g
s
.49323 .54748 m .48944 .60472 L .49633 .60187 L p .707 .577 .707 r
F P
0 g
s
.49633 .60187 m .50013 .54462 L .49323 .54748 L p .707 .577 .707 r
F P
0 g
s
.68286 .70563 m .68135 .72476 L .65753 .72444 L p .707 .577 .707 r
F P
0 g
s
.47356 .69039 m .47205 .70951 L .48815 .70875 L p .707 .577 .707 r
F P
0 g
s
.48815 .70875 m .48966 .68963 L .47356 .69039 L p .707 .577 .707 r
F P
0 g
s
.29587 .59078 m .29966 .53353 L .2966 .52996 L p .707 .577 .707 r
F P
0 g
s
.30752 .69587 m .30903 .67675 L .29625 .6736 L p .707 .577 .707 r
F P
0 g
s
.29625 .6736 m .29474 .69272 L .30752 .69587 L p .707 .577 .707 r
F P
0 g
s
.80239 .71554 m .80088 .73466 L .77338 .73132 L p .707 .577 .707 r
F P
0 g
s
.77338 .73132 m .77489 .71219 L .80239 .71554 L p .707 .577 .707 r
F P
0 g
s
.31708 .69211 m .31175 .6613 L .29855 .6457 L p .707 .577 .707 r
F P
0 g
s
.31175 .6613 m .31708 .69211 L .33852 .70351 L p .707 .577 .707 r
F P
0 g
s
.49086 .62866 m .49619 .65947 L .50242 .64033 L p .707 .577 .707 r
F P
0 g
s
.50242 .64033 m .4971 .60952 L .49086 .62866 L p .707 .577 .707 r
F P
0 g
s
.2966 .52996 m .29281 .58721 L .29587 .59078 L p .707 .577 .707 r
F P
0 g
s
.68135 .72476 m .68286 .70563 L .71205 .70699 L p .707 .577 .707 r
F P
0 g
s
.71205 .70699 m .71054 .72611 L .68135 .72476 L p .707 .577 .707 r
F P
0 g
s
.77489 .71219 m .77338 .73132 L .74225 .72837 L p .707 .577 .707 r
F P
0 g
s
.74225 .72837 m .74376 .70925 L .77489 .71219 L p .707 .577 .707 r
F P
0 g
s
.48966 .68963 m .48815 .70875 L .49497 .707 L p .707 .577 .707 r
F P
0 g
s
.49497 .707 m .49648 .68787 L .48966 .68963 L p .707 .577 .707 r
F P
0 g
s
.49545 .60084 m .49327 .5983 L p .49388 .59355 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49344 .59126 L .49414 .59475 L p .708 .578 .707 r
F P
0 g
s
.49706 .54105 m .50013 .54462 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .49365 .59251 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49706 .54105 L p .49428 .59039 L .707 .577 .707 r
F P
0 g
s
.49327 .5983 m .48054 .59436 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49344 .59126 m .49365 .59251 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.49365 .59251 m .49327 .5983 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .49344 .59126 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .48136 .58212 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .48136 .58212 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48024 .57566 L p .49305 .592 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .49706 .54105 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48434 .53711 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.49706 .54105 m .49365 .59251 L p .48372 .58412 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .49305 .592 L .49365 .59251 L .707 .577 .707 r
F
.49365 .59251 m .49876 .62206 L .4885 .60993 L p F P
0 g
s
.4885 .60993 m .48557 .60646 L p .49365 .59251 L .707 .577 .707 r
F P
0 g
s
.49876 .62206 m .49365 .59251 L p .4971 .60952 L .708 .578 .707 r
F P
0 g
s
.49414 .59475 m .4971 .60952 L p .49365 .59251 L .708 .578 .707 r
F P
0 g
s
.50013 .54462 m .49633 .60187 L .49545 .60084 L p .707 .577 .707 r
F P
0 g
s
.49388 .59355 m .50013 .54462 L .49545 .60084 L .707 .577 .707 r
F
.71054 .72611 m .71205 .70699 L .74376 .70925 L p F P
0 g
s
.74376 .70925 m .74225 .72837 L .71054 .72611 L p .707 .577 .707 r
F P
0 g
s
.29855 .6457 m .30388 .67651 L .31708 .69211 L p .707 .577 .707 r
F P
0 g
s
.30388 .67651 m .29855 .6457 L .29489 .62744 L p .708 .578 .707 r
F P
0 g
s
.29474 .69272 m .29625 .6736 L .29311 .67102 L p .707 .577 .707 r
F P
0 g
s
.4971 .60952 m .50242 .64033 L .49876 .62206 L p .708 .578 .707 r
F P
0 g
s
.29311 .67102 m .2916 .69014 L .29474 .69272 L p .707 .577 .707 r
F P
0 g
s
.29281 .58721 m .2966 .52996 L .3035 .52711 L p .707 .577 .707 r
F P
0 g
s
.3035 .52711 m .2997 .58436 L .29281 .58721 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29489 .62744 m .30022 .65824 L .30388 .67651 L p .708 .578 .707 r
F P
0 g
s
.49648 .68787 m .49497 .707 L .49183 .70441 L p .707 .577 .707 r
F P
0 g
s
.49183 .70441 m .49334 .68529 L .49648 .68787 L p .707 .577 .707 r
F P
0 g
s
.30022 .65824 m .29489 .62744 L .30113 .6083 L p .707 .577 .707 r
F P
0 g
s
.2916 .69014 m .29311 .67102 L .29993 .66926 L p .707 .577 .707 r
F P
0 g
s
.2997 .58436 m .3035 .52711 L .31968 .52525 L p .707 .577 .707 r
F P
0 g
s
.29993 .66926 m .29842 .68839 L .2916 .69014 L p .707 .577 .707 r
F P
0 g
s
.31968 .52525 m .31589 .5825 L .2997 .58436 L p .707 .577 .707 r
F P
0 g
s
.30113 .6083 m .30645 .6391 L .30022 .65824 L p .707 .577 .707 r
F P
0 g
s
.30645 .6391 m .30113 .6083 L .31665 .59015 L p .707 .577 .707 r
F P
0 g
s
.48054 .59436 m .4594 .59044 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48054 .59436 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48557 .60646 m .46412 .59506 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48024 .57566 m .48136 .58212 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.48136 .58212 m .48557 .60646 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.45879 .56425 m .48024 .57566 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4594 .59044 m .46049 .57406 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46412 .59506 m .46049 .57406 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .45879 .56425 L p .47645 .58022 L .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .48434 .53711 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.46049 .57406 m .4632 .53319 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.48434 .53711 m .48136 .58212 L p .46606 .57621 L .707 .577 .707 r
F P
0 g
s
.49334 .68529 m .49183 .70441 L .47905 .70126 L p .707 .577 .707 r
F P
0 g
s
.47905 .70126 m .48056 .68214 L .49334 .68529 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .31968 .52525 L .34357 .52458 L p .707 .577 .707 r
F P
0 g
s
.29842 .68839 m .29993 .66926 L .31603 .66851 L p .707 .577 .707 r
F P
0 g
s
.31603 .66851 m .31452 .68763 L .29842 .68839 L p .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33977 .58183 L .32276 .58231 L p .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .31665 .59015 L .33549 .57772 L p .707 .577 .707 r
F P
0 g
s
.33549 .57772 m .33994 .57478 L p .33934 .57633 L .707 .577 .707 r
F P
0 g
s
.32198 .62096 m .33549 .57772 L .33934 .57633 L .707 .577 .707 r
F
.33994 .57478 m .36872 .56369 L p .36451 .57121 L F P
0 g
s
.3412 .57583 m .33994 .57478 L .36451 .57121 L .707 .577 .707 r
F
.34357 .52458 m .37282 .52514 L p .34354 .57536 L F P
0 g
s
.33977 .58183 m .34016 .57604 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .33994 .57478 L p .3412 .57583 L .707 .577 .707 r
F P
0 g
s
.36902 .58239 m .33977 .58183 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.34016 .57604 m .3412 .57583 L .35534 .58759 L .707 .577 .707 r
F
.36872 .56369 m .40016 .55796 L p .39266 .56845 L F P
0 g
s
.37563 .56972 m .36872 .56369 L .39266 .56845 L .707 .577 .707 r
F
.37282 .52514 m .40457 .5269 L p .37722 .5696 L F P
0 g
s
.36902 .58239 m .36983 .57015 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .36872 .56369 L p .37563 .56972 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .36902 .58239 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.36983 .57015 m .37563 .56972 L .38556 .57838 L .707 .577 .707 r
F
.43192 .58692 m .40077 .58415 L p .41103 .56816 L F P
0 g
s
.40016 .55796 m .4312 .55815 L p .42239 .56865 L .707 .577 .707 r
F P
0 g
s
.40963 .5681 m .40016 .55796 L .42239 .56865 L .707 .577 .707 r
F
.4594 .59044 m .43192 .58692 L p .44141 .57061 L F P
0 g
s
.4312 .55815 m .45879 .56425 L p .45143 .57242 L .707 .577 .707 r
F P
0 g
s
.44064 .57047 m .4312 .55815 L .45143 .57242 L .707 .577 .707 r
F
.46049 .57406 m .4594 .59044 L p .44141 .57061 L F P
0 g
s
.45879 .56425 m .46412 .59506 L .43653 .58896 L p .707 .577 .707 r
F P
0 g
s
.4632 .53319 m .46049 .57406 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43571 .52967 m .4632 .53319 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.43192 .58692 m .4331 .56911 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .4312 .55815 L p .44064 .57047 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .43571 .52967 L p .44141 .57061 L .707 .577 .707 r
F P
0 g
s
.4331 .56911 m .44064 .57047 L .44641 .57799 L .707 .577 .707 r
F
.44641 .57799 m .44064 .57047 L .45143 .57242 L F
.43653 .58896 m .4331 .56911 L p .44641 .57799 L F P
0 g
s
.4331 .56911 m .43192 .58692 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.4312 .55815 m .43653 .58896 L .40549 .58876 L p .707 .577 .707 r
F P
0 g
s
.41103 .56816 m .41722 .55851 L .4331 .56911 L .707 .577 .707 r
F
.43571 .52967 m .4331 .56911 L p .41722 .55851 L F P
0 g
s
.40457 .5269 m .43571 .52967 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40077 .58415 m .40186 .56776 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40016 .55796 L p .40963 .5681 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40457 .5269 L p .41103 .56816 L .707 .577 .707 r
F P
0 g
s
.40186 .56776 m .40963 .5681 L .41658 .57555 L .707 .577 .707 r
F
.41658 .57555 m .40963 .5681 L .42239 .56865 L F
.40549 .58876 m .40186 .56776 L p .41658 .57555 L F P
0 g
s
.40186 .56776 m .40077 .58415 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.40016 .55796 m .40549 .58876 L .37404 .59449 L p .707 .577 .707 r
F P
0 g
s
.37722 .5696 m .38433 .55849 L .40186 .56776 L .707 .577 .707 r
F
.40457 .5269 m .40186 .56776 L p .38433 .55849 L F P
0 g
s
.36983 .57015 m .37282 .52514 L p .37722 .5696 L .707 .577 .707 r
F P
0 g
s
.38556 .57838 m .37563 .56972 L .39266 .56845 L .707 .577 .707 r
F
.37404 .59449 m .36983 .57015 L p .38556 .57838 L F P
0 g
s
.36983 .57015 m .36902 .58239 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.36872 .56369 m .37404 .59449 L .34527 .60559 L p .707 .577 .707 r
F P
0 g
s
.34354 .57536 m .35202 .56082 L .36983 .57015 L .707 .577 .707 r
F
.37282 .52514 m .36983 .57015 L p .35202 .56082 L F P
0 g
s
.34016 .57604 m .34357 .52458 L p .34354 .57536 L .707 .577 .707 r
F P
0 g
s
.35534 .58759 m .3412 .57583 L .36451 .57121 L .707 .577 .707 r
F
.34527 .60559 m .34016 .57604 L p .35534 .58759 L F P
0 g
s
.33994 .57478 m .34527 .60559 L .32198 .62096 L p .707 .577 .707 r
F P
0 g
s
.31589 .5825 m .32463 .56421 L .34016 .57604 L .707 .577 .707 r
F
.34357 .52458 m .34016 .57604 L p .32463 .56421 L F P
0 g
s
.32276 .58231 m .31589 .5825 L p .34016 .57604 L .707 .577 .707 r
F P
0 g
s
.31665 .59015 m .32198 .62096 L .30645 .6391 L p .707 .577 .707 r
F P
0 g
s
.48056 .68214 m .47905 .70126 L .45787 .69785 L p .707 .577 .707 r
F P
0 g
s
.45787 .69785 m .45938 .67872 L .48056 .68214 L p .707 .577 .707 r
F P
0 g
s
.31452 .68763 m .31603 .66851 L .33985 .66882 L p .707 .577 .707 r
F P
0 g
s
.33985 .66882 m .33834 .68794 L .31452 .68763 L p .707 .577 .707 r
F P
0 g
s
.45938 .67872 m .45787 .69785 L .43037 .6945 L p .707 .577 .707 r
F P
0 g
s
.43037 .6945 m .43188 .67538 L .45938 .67872 L p .707 .577 .707 r
F P
0 g
s
.33834 .68794 m .33985 .66882 L .36904 .67017 L p .707 .577 .707 r
F P
0 g
s
.36904 .67017 m .36753 .68929 L .33834 .68794 L p .707 .577 .707 r
F P
0 g
s
.43188 .67538 m .43037 .6945 L .39924 .69155 L p .707 .577 .707 r
F P
0 g
s
.39924 .69155 m .40075 .67243 L .43188 .67538 L p .707 .577 .707 r
F P
0 g
s
.36753 .68929 m .36904 .67017 L .40075 .67243 L p .707 .577 .707 r
F P
0 g
s
.40075 .67243 m .39924 .69155 L .36753 .68929 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00L7oo0`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo8@0000=JEP00FUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2000
1EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00goo001JEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF1`002eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP050006FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00E7oo00<005YF00000eYF00D005YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04
001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009ooaH004eoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@00A7oo001COol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH8000lOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1`00=Goo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP05000`Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP00000^Ool005=oo`03001JEP00009JEPL00003FUH005YF00MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00Dgoo00<005YF00000P000eYF0P0015YF00<005YFFUH01EYF0P0025YF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo001COol20002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
15YF3@001EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0
05Aoo`800003FUH005YF008000IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00AJ
EP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001FOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
0004FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005Moo`04001JEUYF0007FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Moo`04001JEUYF0007FUH00`00FUH0
00050004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF001JEP020003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEUYF001JEP00;Goo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH200001Woo
001JEUYF001JER400003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool005Eoo`03001JEUYF
00=JEP03001JEUYF009JEP8000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001EOol00`00FUIJEP03
FUH00`00FUIJEP020005Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH015YF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YF
FUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo000bOolE000=Ool20005FUH30007
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP03
FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEP00FUH0;Woo000]Ool500000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH>0000
0eYF001JEP03FUH00`00Oomoo`07Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH015YF0P000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YF
FUH005YF00T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYF001JEP0^Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03
Ool005YF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH50006Ool01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00AJEPd000IJEP03001JEUYF009JEP05001JEUYF001JEP0^Ool002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0002FUH01000FUIJEP000UYF10000Woo00@005YFFUH000IJEP<000MJEP03001JEUYF
00UJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P000UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH010001UYF
00<005YFFUH015YF10000UYF00<005YFFUH00UYF00D005YFFUH005YF02ioo`00;Goo00<005YF0000
0eYF00<005YFFUH00UYF00=ooeYF00001eYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0
009JEP04001JEUYF0005FUH40002FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP09FUH00`00FUIJ
EP02FUH200000eYF00000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH60007FUH00`00FUIJEP04FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH0
00020004FUH00`00FUIJEP02FUH^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF1@001UYF00<005YFFUH02EYF00L005YFFUIJEP00FUH00002FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH0
00MJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP80
00=JEP04001JEP00FUH^Ool002eoo`03001JEP0000=JEP05001JEUYFFUH00002FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH017ooFUIJEP000UYF00<005YFFUH00UYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEPD000IJEP03001JEUYF00UJEP05001JEUYFFUH00002
FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001Goo001JEUYF00000UYF00IooeYFFUIJEP00FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200000eYF001JEP02000^Ool002eoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJ
EP03FUH01000FUIJEP000eYF00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH000=J
EP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<000=JEP03001JEUYF00AJEP8000Ioo`T000AJEP03001JEUYF00IJEP04001JEUYFFUH70002FUH0
0`00Oomoo`0/Ool002eoo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH00004FUH00`00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH0
0`00Oomoo`0?OolA0007Ool00`00FUH0000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30004FUH00`00FUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIo
o`02FUH00`00Oomoo`0YOol2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00=JEP05001JEUYF
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEP001EYF00D0
05YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP04001J
EP00000/Ool3000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH01@00FUIJEUYF00001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP8002ioo`<002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH00UYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001oogoo02eoo`03001JEP0002eoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF00@005YFFUH000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH20007FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP00009JEP04001JEUYFFUH5000/Ool00`00FUH0000]Ool002ao
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP80009JEP@000EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000=JEP00FUH01UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP000UYF00<005YFFUH01@002goo0`006Goo00<0
05YF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUHJ0002FUH00`00FUIJEP07FUH40003FUH00`00FUIJEP05FUH00`00FUH00006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF
00000eYF00<005YFFUH00eYF00@005YF000000Qoo`D001Moo`80009JEP03001oogoo02Yoo`00;7oo
00<005YF00000UYF1`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF3@001eYF00<005YFFUH015YF0P00
1eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP80009J
EP03OomJEP0000EJEP03001JEUYF008000Moo`D001Ioo`03001JEP00009JEP03001oogoo02Yoo`00
;7oo00<005YF00000P0015YF0P000eYF00<005YFFUH01EYF0P0025YF00<005YFFUH015YF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF008000Moo`D001Eo
o`04001JEUYF0002FUH00`00Oomoo`0ZOol002aoo`80009JEP05001JEUYFFUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH900000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30001eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00<005YFFUH00P00
27oo0`005Goo00D005YFFUIJEP00009JEP03001oogoo02Yoo`00;Goo0P0000EJEP00FUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00@000IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH000020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0004FUH00`00FUIJEP04FUH00`00FUIJEP02000OOol00`00FUIJEP03FUH2000]Ool002moo`D000IJ
EP03001JEUYF00EJEP@00003FUH005YF00MJEP04001JEP00FUH@0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YF
FUH00P007Goo0`001EYF0P00;Goo000aOol00`00FUH00007FUH00`00FUIJEP02FUH20005FUH00`00
FUIJEP06FUH00`00FUH000020002FUH01000FUIJEP0015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000K
Ool20002FUH00`00FUIJEP03FUH2000]Ool0031oo`04001JEUYF0007FUH00`00FUH000050004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH500000eYF00000002FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P006Goo0P001EYF00<005YFFUH00UYF00<007ooOol0;7oo000_Ool01@00FUIJ
EUYF00001eYF0P001Woo6`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP06001JEUYF001JEP00
5goo0P001eYF00<005YFFUH00UYF00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP02
FUH2000SOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500000eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH40005FUH01@00FUIJEP00FUH05Woo0P0000=JEP00FUH01UYF00D005YFFUIJEP00
02moo`00;Woo00<005YFFUH00eYF00<005YFFUH00P009goo100015YF00<005YFFUH01EYF00<005YF
FUH00UYF1P0015YF00<005YFFUH015YF00@005YFFUIJEP<000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEQ400003FUIoogoo015oo`<000=JEP03001JEUYF00EJ
EP04001JEUYF000`Ool002eoo`8000EJEP<002eoobT000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP04001JEUYFFUHE0007FUH00`00
FUIJEP05FUH00`00FUH0000`Ool002eoo`03001JEP0000AJEP03001oogoo02ioo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF20000UYF00<005YFFUH01EYF0P00<Goo000/Ool01000FUIJ
EP000eYF00<007ooOol0;goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`000eYF00<007ooOol0<7oo000/Ool01000FUIJEP000eYF00<007ooOol0;Woo00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol0
02aoo`04001JEUYF0002FUH00`00Oomoo`0COol3000IOol00`00FUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000_Ool002aoo`04
001JEUYFFUH2000EOol5000GOol200001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
6P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Woo000]
Ool00`00FUIJEP02000EOol5000FOol01@00FUH005YF00000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800005FUH005YFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP03FUHA0004
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP005Woo1@005Woo00<005YF
FUH00P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP0000000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPL000=JEP04001JEUYF
FUH2000^Ool002eoo`04001JEUYF000GOol3000FOol01000FUIJEUYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001`0000=JEP00FUH01UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YF00000`001EYF1@000UYF0P00;Woo000]Ool00`00FUH0000`Ool00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHN0008FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH40003FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000]Ool00`00FUH0000^Ool30004FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<0
05YFFUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Woo10000UYF00<0
05YFFUH01UYF00<005YFFUH01`0015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Woo
000^Ool2000/Ool20002FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH01EYF1P000UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH0
0UYF00<005YF00003Woo3P001goo4P00;goo000^Ool00`00FUH0000YOol20004FUH00`00FUIJEP03
FUH01000FUIJEP001EYF00@005YFFUIJEP@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000eoo`03001JEP0005Ao
o`00;Woo00@005YFFUH002Ioo`8000IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP@00003
FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
0003FUH005YF00=JEP03001JEP0000eoo`03001JEP0005Aoo`00;Woo00<005YFFUH030006Goo0P00
00=JEP00FUH01UYF00H005YFFUH007oo0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03
001JEP0000eoo`03001JEP0005Aoo`00;7oo1@0000=JEP00FUH01EYF00@005YFFUIJEQ8000Aoo`<0
00=JEP03001JEUYF00EJEP03001JEP00009oo`05001JEUYF001JEP020007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00
0UYF00<005YF000037oo0P0000=JEP000000Dgoo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP04FUH20003Ool0
0`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001oo`0:Ool00`00FUH00002
FUH00`00Oomoo`1AOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00Oomoo`02Ool00`00FUH00003FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`09Ool01000FUIJEP000UYF00<007ooOol0
DGoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP050003Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH200000eYF001oo`08Ool01@00FUIJEUYF00000UYF00<007ooOol0DGoo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH0000027oo00<005YFFUH00eYF0P00E7oo000[OolK0004FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
000000Ioo`<000EJEP8005Aoo`00;7oo0P000UYF00@005YF000000AJEP03001JEUYF00EJEP03001J
EUYF00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP001Goo00@005YFFUH000EJEP8005Aoo`00;Woo1P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH015YF200015YF00<005YFFUH00eYF00D005YF
FUH005YF008000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000Eoo`03001JEUYF009J
EP03001JEUYF009JEP03001oogoo05=oo`00<goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1`000eYF00<005YFFUH00P0000=oo`00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0017oo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000fOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP04
FUH500001EYF000007oo000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P000Woo0P001eYF00D0
05YFFUIJEP0005Ioo`00>7oo0`001UYF00<005YFFUH01EYF00<005YFFUH015YF100015YF00<005YF
FUH015YF00@005YFFUIJEP<0009oo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800005Ool0
0000FUH00007FUH01000FUIJEP00Egoo000kOol40002FUH00`00FUIJEP05FUH00`00FUIJEP0I0005
Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YF0000Egoo000oOol=000POol2
0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUH000080002FUH00`00FUIJEP05FUH2001HOol006ioo`8000AJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000EJEP04001J
EUYFFUH70003FUH00`00Oomoo`1GOol0071oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000UJEP03001JEUYF00EJEP03001JEUYF00D005Qo
o`00Lgoo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P00EGoo001gOol60002FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0D0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02001EOol007eooal000EJEP03001JEUYF00IJEP03001JEUYF00=JEPP000AJEP03001J
EUYF00=JEP04001JEUYFFUH2001EOol0091oo`@00003FUH0000000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP04001JEUYFFUH2001EOol009Aoo`D0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<000EJEPD0009JEP80
05Eoo`00VGoo0`001UYF00<005YFFUH01UYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00@0
05YFFUIJEP@005Eoo`00W7oo10000UYF00<005YFFUH01UYF00<005YFFUH06P00EGoo002POol>001_
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59478 .73995 m .59713 .68313 L .56597 .68069 L p .707 .577 .707 r
F P
0 g
s
.59713 .68313 m .59478 .73995 L .62658 .74073 L p .707 .577 .707 r
F P
0 g
s
.62658 .74073 m .62894 .68391 L .59713 .68313 L p .707 .577 .707 r
F P
0 g
s
.62894 .68391 m .62658 .74073 L .65591 .73978 L p .707 .577 .707 r
F P
0 g
s
.65591 .73978 m .65827 .68295 L .62894 .68391 L p .707 .577 .707 r
F P
0 g
s
.56362 .73751 m .56597 .68069 L .5385 .67683 L p .707 .577 .707 r
F P
0 g
s
.56597 .68069 m .56362 .73751 L .59478 .73995 L p .707 .577 .707 r
F P
0 g
s
.65827 .68295 m .65591 .73978 L .6799 .73718 L p .707 .577 .707 r
F P
0 g
s
.6799 .73718 m .68226 .68036 L .65827 .68295 L p .707 .577 .707 r
F P
0 g
s
.5385 .67683 m .53615 .73366 L .56362 .73751 L p .707 .577 .707 r
F P
0 g
s
.53615 .73366 m .5385 .67683 L .51742 .67194 L p .707 .577 .707 r
F P
0 g
s
.59408 .84024 m .59502 .82124 L .56386 .8187 L p .707 .577 .707 r
F P
0 g
s
.59502 .82124 m .59408 .84024 L .62587 .84133 L p .707 .577 .707 r
F P
0 g
s
.62587 .84133 m .62681 .82233 L .59502 .82124 L p .707 .577 .707 r
F P
0 g
s
.59977 .82893 m .59642 .79514 L .5653 .79434 L p .707 .577 .707 r
F P
0 g
s
.62681 .82233 m .62587 .84133 L .65518 .84086 L p .707 .577 .707 r
F P
0 g
s
.65518 .84086 m .65612 .82186 L .62681 .82233 L p .707 .577 .707 r
F P
0 g
s
.59642 .79514 m .59977 .82893 L .63145 .82498 L p .707 .577 .707 r
F P
0 g
s
.63145 .82498 m .62811 .7912 L .59642 .79514 L p .707 .577 .707 r
F P
0 g
s
.62811 .7912 m .63145 .82498 L .6606 .81666 L p .707 .577 .707 r
F P
0 g
s
.6606 .81666 m .65726 .78288 L .62811 .7912 L p .707 .577 .707 r
F P
0 g
s
.51742 .67194 m .51506 .72876 L .53615 .73366 L p .707 .577 .707 r
F P
0 g
s
.56386 .8187 m .56293 .83769 L .59408 .84024 L p .707 .577 .707 r
F P
0 g
s
.56293 .83769 m .56386 .8187 L .53639 .81495 L p .707 .577 .707 r
F P
0 g
s
.56865 .82812 m .5653 .79434 L .53779 .78885 L p .707 .577 .707 r
F P
0 g
s
.5653 .79434 m .56865 .82812 L .59977 .82893 L p .707 .577 .707 r
F P
0 g
s
.68226 .68036 m .6799 .73718 L .6962 .7332 L p .707 .577 .707 r
F P
0 g
s
.6962 .7332 m .69855 .67638 L .68226 .68036 L p .707 .577 .707 r
F P
0 g
s
.65726 .78288 m .6606 .81666 L .68436 .80479 L p .707 .577 .707 r
F P
0 g
s
.68436 .80479 m .68102 .771 L .65726 .78288 L p .707 .577 .707 r
F P
0 g
s
.53639 .81495 m .53545 .83395 L .56293 .83769 L p .707 .577 .707 r
F P
0 g
s
.51506 .72876 m .51742 .67194 L .50477 .66648 L p .707 .577 .707 r
F P
0 g
s
.65612 .82186 m .65518 .84086 L .67914 .83887 L p .707 .577 .707 r
F P
0 g
s
.67914 .83887 m .68008 .81987 L .65612 .82186 L p .707 .577 .707 r
F P
0 g
s
.54114 .82264 m .53779 .78885 L .51659 .77923 L p .707 .577 .707 r
F P
0 g
s
.53779 .78885 m .54114 .82264 L .56865 .82812 L p .707 .577 .707 r
F P
0 g
s
.53048 .81366 m .51529 .81036 L p .53582 .82645 L .707 .577 .707 r
F P
0 g
s
.51993 .81301 m .51675 .78083 L p .50376 .7664 L .707 .577 .707 r
F P
0 g
s
.51675 .78083 m .51659 .77923 L .51571 .77835 L p .707 .577 .707 r
F P
0 g
s
.51571 .77835 m .50376 .7664 L p .51675 .78083 L .707 .577 .707 r
F P
0 g
s
.53545 .83395 m .53582 .82645 L p .51529 .81036 L .707 .577 .707 r
F P
0 g
s
.53582 .82645 m .53639 .81495 L .53048 .81366 L p .707 .577 .707 r
F P
0 g
s
.50477 .66648 m .50242 .7233 L .51506 .72876 L p .707 .577 .707 r
F P
0 g
s
.51529 .81036 m .51435 .82936 L .53545 .83395 L p .707 .577 .707 r
F P
0 g
s
.68102 .771 m .68436 .80479 L .7004 .79052 L p .707 .577 .707 r
F P
0 g
s
.7004 .79052 m .69706 .75674 L .68102 .771 L p .707 .577 .707 r
F P
0 g
s
.69855 .67638 m .6962 .7332 L .70321 .72823 L p .707 .577 .707 r
F P
0 g
s
.70321 .72823 m .70557 .6714 L .69855 .67638 L p .707 .577 .707 r
F P
0 g
s
.68008 .81987 m .67914 .83887 L .69541 .83556 L p .707 .577 .707 r
F P
0 g
s
.69541 .83556 m .69635 .81657 L .68008 .81987 L p .707 .577 .707 r
F P
0 g
s
.51659 .77923 m .51993 .81301 L .54114 .82264 L p .707 .577 .707 r
F P
0 g
s
.50242 .7233 m .50477 .66648 L .50181 .66099 L p .707 .577 .707 r
F P
0 g
s
.51435 .82936 m .51529 .81036 L .50262 .80539 L p .707 .577 .707 r
F P
0 g
s
.50262 .80539 m .50168 .82438 L .51435 .82936 L p .707 .577 .707 r
F P
0 g
s
.69706 .75674 m .7004 .79052 L .70716 .77526 L p .707 .577 .707 r
F P
0 g
s
.70716 .77526 m .70382 .74147 L .69706 .75674 L p .707 .577 .707 r
F P
0 g
s
.50181 .66099 m .49946 .71782 L .50242 .7233 L p .707 .577 .707 r
F P
0 g
s
.50376 .7664 m .5071 .80019 L .51993 .81301 L p .707 .577 .707 r
F P
0 g
s
.70557 .6714 m .70321 .72823 L .70025 .72274 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .70261 .66592 L .70557 .6714 L p .707 .577 .707 r
F P
0 g
s
.69635 .81657 m .69541 .83556 L .70239 .83126 L p .707 .577 .707 r
F P
0 g
s
.70239 .83126 m .70333 .81227 L .69635 .81657 L p .707 .577 .707 r
F P
0 g
s
.4926 .82254 m .48939 .32288 L .44538 .32031 L p .707 .577 .707 r
F P
0 g
s
.5071 .80019 m .50376 .7664 L .50057 .75164 L p .707 .577 .707 r
F P
0 g
s
.49946 .71782 m .50181 .66099 L .50882 .65602 L p .707 .577 .707 r
F P
0 g
s
.50168 .82438 m .50262 .80539 L .49963 .80051 L p .707 .577 .707 r
F P
0 g
s
.49963 .80051 m .4987 .8195 L .50168 .82438 L p .707 .577 .707 r
F P
0 g
s
.50882 .65602 m .50647 .71284 L .49946 .71782 L p .707 .577 .707 r
F P
0 g
s
.50391 .78542 m .5071 .80019 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50057 .75164 m .50156 .76159 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.50156 .76159 m .50391 .78542 L p .50091 .75414 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .49963 .80051 L .50467 .7974 L p .707 .577 .707 r
F P
0 g
s
.50467 .7974 m .50662 .7962 L p .50498 .80101 L .707 .577 .707 r
F P
0 g
s
.4987 .8195 m .50467 .7974 L .50498 .80101 L .707 .577 .707 r
F
.50391 .78542 m .50057 .75164 L .50733 .73637 L p F P
0 g
s
.50647 .71284 m .50882 .65602 L .52512 .65204 L p .707 .577 .707 r
F P
0 g
s
.50662 .7962 m .50568 .8152 L .4987 .8195 L p .707 .577 .707 r
F P
0 g
s
.50733 .73637 m .51067 .77016 L .50391 .78542 L p .707 .577 .707 r
F P
0 g
s
.52512 .65204 m .52277 .70886 L .50647 .71284 L p .707 .577 .707 r
F P
0 g
s
.51067 .77016 m .50733 .73637 L .52337 .72211 L p .707 .577 .707 r
F P
0 g
s
.52277 .70886 m .52512 .65204 L .54911 .64944 L p .707 .577 .707 r
F P
0 g
s
.50568 .8152 m .50662 .7962 L .52288 .7929 L p .707 .577 .707 r
F P
0 g
s
.52288 .7929 m .52195 .81189 L .50568 .8152 L p .707 .577 .707 r
F P
0 g
s
.52337 .72211 m .52672 .75589 L .51067 .77016 L p .707 .577 .707 r
F P
0 g
s
.54911 .64944 m .54676 .70627 L .52277 .70886 L p .707 .577 .707 r
F P
0 g
s
.52672 .75589 m .52337 .72211 L .54713 .71023 L p .707 .577 .707 r
F P
0 g
s
.54713 .71023 m .55047 .74402 L .52672 .75589 L p .707 .577 .707 r
F P
0 g
s
.52195 .81189 m .52288 .7929 L .54685 .79091 L p .707 .577 .707 r
F P
0 g
s
.54685 .79091 m .54591 .80991 L .52195 .81189 L p .707 .577 .707 r
F P
0 g
s
.48939 .32288 m .4926 .82254 L .53754 .82112 L p .707 .577 .707 r
F P
0 g
s
.53754 .82112 m .53433 .32145 L .48939 .32288 L p .707 .577 .707 r
F P
0 g
s
.54676 .70627 m .54911 .64944 L .57844 .64849 L p .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .57609 .70531 L .54676 .70627 L p .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .57624 .70155 L .58541 .69001 L .707 .577 .707 r
F
.57609 .70531 m .57624 .70155 L p .57845 .70143 L F P
0 g
s
.58145 .70127 m .60797 .69797 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .57609 .70531 L p .57845 .70143 L .707 .577 .707 r
F P
0 g
s
.57845 .70143 m .60307 .7001 L .60789 .70609 L .707 .577 .707 r
F
.60797 .69797 m .60815 .69983 L p .6065 .69992 L F P
0 g
s
.60815 .69983 m .60789 .70609 L p .58952 .68327 L .707 .577 .707 r
F P
0 g
s
.61131 .73175 m .57962 .7357 L p .6065 .69992 L .707 .577 .707 r
F P
0 g
s
.60797 .69797 m .63909 .69877 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .60789 .70609 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.61164 .70001 m .62885 .70088 L .63905 .70853 L .707 .577 .707 r
F
.60995 .69992 m .60797 .69797 L .63697 .70129 L F
.62885 .70088 m .63413 .70114 L .63905 .70853 L F
.63909 .69877 m .63935 .70141 L p .63697 .70129 L F P
0 g
s
.63935 .70141 m .63905 .70853 L p .62358 .68532 L .707 .577 .707 r
F P
0 g
s
.64243 .73256 m .61131 .73175 L p .63697 .70129 L .707 .577 .707 r
F P
0 g
s
.63909 .69877 m .6666 .70426 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .63905 .70853 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.64274 .70199 m .6572 .70448 L .66652 .71239 L .707 .577 .707 r
F
.64169 .70181 m .63909 .69877 L .66523 .70586 L F
.6572 .70448 m .663 .70547 L .66652 .71239 L F
.6666 .70426 m .66678 .70612 L p .66523 .70586 L F P
0 g
s
.66678 .70612 m .66652 .71239 L p .6544 .68863 L .707 .577 .707 r
F P
0 g
s
.66994 .73804 m .64243 .73256 L p .66523 .70586 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .66652 .71239 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.669 .7069 m .68135 .71126 L .68761 .71728 L .707 .577 .707 r
F
.6666 .70426 m .68434 .71231 L p .66812 .7066 L F P
0 g
s
.68897 .6845 m .68761 .71728 L p .67137 .70165 L .707 .577 .707 r
F P
0 g
s
.68996 .66046 m .70261 .66592 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68761 .71728 m .68777 .71352 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.68777 .71352 m .68996 .66046 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.66888 .65556 m .68996 .66046 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66652 .71239 m .66678 .70612 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .6666 .70426 L p .66812 .7066 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66888 .65556 L p .669 .7069 L .707 .577 .707 r
F P
0 g
s
.66678 .70612 m .66812 .7066 L .67987 .72462 L .707 .577 .707 r
F
.67987 .72462 m .66812 .7066 L .68759 .71381 L F
.68639 .71579 m .68759 .71381 L .6878 .71388 L F
.67987 .72462 m .68759 .71381 L .68639 .71579 L F
.68434 .71231 m .6878 .71388 L p .66812 .7066 L F P
0 g
s
.669 .7069 m .67137 .70165 L .68135 .71126 L .707 .577 .707 r
F
.68996 .66046 m .68897 .6845 L p .67137 .70165 L F P
0 g
s
.66678 .70612 m .66994 .73804 L p .66546 .70741 L .707 .577 .707 r
F P
0 g
s
.66523 .70586 m .66678 .70612 L .66546 .70741 L .707 .577 .707 r
F
.64646 .69537 m .6544 .68863 L .663 .70547 L F
.64646 .69537 m .663 .70547 L .6572 .70448 L F
.66798 .6771 m .66678 .70612 L p .6544 .68863 L F P
0 g
s
.66994 .73804 m .66678 .70612 L p .67987 .72462 L .707 .577 .707 r
F P
0 g
s
.64141 .65171 m .66888 .65556 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63905 .70853 m .63935 .70141 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .63909 .69877 L p .64169 .70181 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64141 .65171 L p .64274 .70199 L .707 .577 .707 r
F P
0 g
s
.63935 .70141 m .64169 .70181 L .65521 .71759 L .707 .577 .707 r
F
.65521 .71759 m .64169 .70181 L .66523 .70586 L F
.64274 .70199 m .64646 .69537 L .6572 .70448 L F
.66888 .65556 m .66798 .6771 L p .64646 .69537 L F P
0 g
s
.63935 .70141 m .64243 .73256 L p .6373 .70315 L .707 .577 .707 r
F P
0 g
s
.63697 .70129 m .63935 .70141 L .6373 .70315 L .707 .577 .707 r
F
.61671 .69178 m .62358 .68532 L .63413 .70114 L F
.61671 .69178 m .63413 .70114 L .62885 .70088 L F
.64068 .66923 m .63935 .70141 L p .62358 .68532 L F P
0 g
s
.64243 .73256 m .63935 .70141 L p .65521 .71759 L .707 .577 .707 r
F P
0 g
s
.61025 .64927 m .64141 .65171 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60789 .70609 m .60815 .69983 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60797 .69797 L p .60995 .69992 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .61025 .64927 L p .61164 .70001 L .707 .577 .707 r
F P
0 g
s
.60815 .69983 m .60995 .69992 L .62533 .71511 L .707 .577 .707 r
F
.62533 .71511 m .60995 .69992 L .63697 .70129 L F
.61164 .70001 m .61671 .69178 L .62885 .70088 L F
.64141 .65171 m .64068 .66923 L p .61671 .69178 L F P
0 g
s
.60815 .69983 m .61131 .73175 L p .60669 .7012 L .707 .577 .707 r
F P
0 g
s
.6065 .69992 m .60815 .69983 L .60669 .7012 L .707 .577 .707 r
F
.57845 .70143 m .58952 .68327 L .60307 .7001 L F
.61025 .64927 m .60815 .69983 L p .58952 .68327 L F P
0 g
s
.61131 .73175 m .60815 .69983 L p .62533 .71511 L .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .57628 .70191 L .58145 .70127 L p .707 .577 .707 r
F P
0 g
s
.57962 .7357 m .58145 .70127 L .6065 .69992 L .707 .577 .707 r
F
.55047 .74402 m .54959 .73509 L p .57628 .70191 L F P
0 g
s
.54959 .73509 m .54713 .71023 L .57586 .70203 L p .707 .577 .707 r
F P
0 g
s
.57586 .70203 m .57628 .70191 L p .54959 .73509 L .707 .577 .707 r
F P
0 g
s
.57844 .64849 m .61025 .64927 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57624 .70155 m .57844 .64849 L p .58541 .69001 L .707 .577 .707 r
F P
0 g
s
.57628 .70191 m .57962 .7357 L .55047 .74402 L p .707 .577 .707 r
F P
0 g
s
.54591 .80991 m .54685 .79091 L .57615 .79044 L p .707 .577 .707 r
F P
0 g
s
.57615 .79044 m .57522 .80944 L .54591 .80991 L p .707 .577 .707 r
F P
0 g
s
.57522 .80944 m .57615 .79044 L .60794 .79153 L p .707 .577 .707 r
F P
0 g
s
.60794 .79153 m .60701 .81053 L .57522 .80944 L p .707 .577 .707 r
F P
0 g
s
.53433 .32145 m .53754 .82112 L .57902 .81584 L p .707 .577 .707 r
F P
0 g
s
.57902 .81584 m .57581 .31617 L .53433 .32145 L p .707 .577 .707 r
F P
0 g
s
.44859 .81997 m .44538 .32031 L .40662 .31399 L p .707 .577 .707 r
F P
0 g
s
.44538 .32031 m .44859 .81997 L .4926 .82254 L p .707 .577 .707 r
F P
0 g
s
.70382 .74147 m .70716 .77526 L .70397 .76049 L p .707 .577 .707 r
F P
0 g
s
.70397 .76049 m .70063 .72671 L .70382 .74147 L p .707 .577 .707 r
F P
0 g
s
.60701 .81053 m .60794 .79153 L .6391 .79407 L p .707 .577 .707 r
F P
0 g
s
.57581 .31617 m .57902 .81584 L .61297 .80722 L p .707 .577 .707 r
F P
0 g
s
.61297 .80722 m .60977 .30756 L .57581 .31617 L p .707 .577 .707 r
F P
0 g
s
.70025 .72274 m .68761 .71728 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.6878 .71388 m .69115 .74767 L .67228 .7391 L p .707 .577 .707 r
F P
0 g
s
.67228 .7391 m .66994 .73804 L p .68639 .71579 L .707 .577 .707 r
F P
0 g
s
.68639 .71579 m .6878 .71388 L .67228 .7391 L .707 .577 .707 r
F
.70261 .66592 m .70158 .6907 L p .68959 .71051 L F P
0 g
s
.70158 .6907 m .70025 .72274 L p .68959 .71051 L .707 .577 .707 r
F P
0 g
s
.70333 .81227 m .70239 .83126 L .6994 .82638 L p .707 .577 .707 r
F P
0 g
s
.6994 .82638 m .70034 .80739 L .70333 .81227 L p .707 .577 .707 r
F P
0 g
s
.40983 .81366 m .40662 .31399 L .37689 .30455 L p .707 .577 .707 r
F P
0 g
s
.40662 .31399 m .40983 .81366 L .44859 .81997 L p .707 .577 .707 r
F P
0 g
s
.25177 .70314 m .25412 .64631 L .22296 .64387 L p .707 .577 .707 r
F P
0 g
s
.25412 .64631 m .25177 .70314 L .28357 .70392 L p .707 .577 .707 r
F P
0 g
s
.28357 .70392 m .28593 .64709 L .25412 .64631 L p .707 .577 .707 r
F P
0 g
s
.28593 .64709 m .28357 .70392 L .31291 .70296 L p .707 .577 .707 r
F P
0 g
s
.31291 .70296 m .31526 .64614 L .28593 .64709 L p .707 .577 .707 r
F P
0 g
s
.70063 .72671 m .70397 .76049 L .69115 .74767 L p .707 .577 .707 r
F P
0 g
s
.69115 .74767 m .6878 .71388 L .70063 .72671 L p .707 .577 .707 r
F P
0 g
s
.22061 .7007 m .22296 .64387 L .19549 .64002 L p .707 .577 .707 r
F P
0 g
s
.22296 .64387 m .22061 .7007 L .25177 .70314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31526 .64614 m .31291 .70296 L .33689 .70037 L p .707 .577 .707 r
F P
0 g
s
.33689 .70037 m .33925 .64354 L .31526 .64614 L p .707 .577 .707 r
F P
0 g
s
.19549 .64002 m .19314 .69684 L .22061 .7007 L p .707 .577 .707 r
F P
0 g
s
.6391 .79407 m .63816 .81307 L .60701 .81053 L p .707 .577 .707 r
F P
0 g
s
.60977 .30756 m .61297 .80722 L .63608 .79611 L p .707 .577 .707 r
F P
0 g
s
.63608 .79611 m .63287 .29644 L .60977 .30756 L p .707 .577 .707 r
F P
0 g
s
.19314 .69684 m .19549 .64002 L .17441 .63512 L p .707 .577 .707 r
F P
0 g
s
.70034 .80739 m .6994 .82638 L .68674 .82141 L p .707 .577 .707 r
F P
0 g
s
.68674 .82141 m .68768 .80241 L .70034 .80739 L p .707 .577 .707 r
F P
0 g
s
.25107 .80342 m .25201 .78443 L .22086 .78188 L p .707 .577 .707 r
F P
0 g
s
.25201 .78443 m .25107 .80342 L .28286 .80451 L p .707 .577 .707 r
F P
0 g
s
.28286 .80451 m .2838 .78552 L .25201 .78443 L p .707 .577 .707 r
F P
0 g
s
.25676 .79211 m .25341 .75833 L .22229 .75752 L p .707 .577 .707 r
F P
0 g
s
.2838 .78552 m .28286 .80451 L .31217 .80404 L p .707 .577 .707 r
F P
0 g
s
.31217 .80404 m .31311 .78505 L .2838 .78552 L p .707 .577 .707 r
F P
0 g
s
.25341 .75833 m .25676 .79211 L .28844 .78816 L p .707 .577 .707 r
F P
0 g
s
.28844 .78816 m .2851 .75438 L .25341 .75833 L p .707 .577 .707 r
F P
0 g
s
.2851 .75438 m .28844 .78816 L .31759 .77985 L p .707 .577 .707 r
F P
0 g
s
.31759 .77985 m .31425 .74606 L .2851 .75438 L p .707 .577 .707 r
F P
0 g
s
.17441 .63512 m .17205 .69195 L .19314 .69684 L p .707 .577 .707 r
F P
0 g
s
.3801 .80422 m .37689 .30455 L .35911 .29291 L p .707 .577 .707 r
F P
0 g
s
.37689 .30455 m .3801 .80422 L .40983 .81366 L p .707 .577 .707 r
F P
0 g
s
.22086 .78188 m .21992 .80088 L .25107 .80342 L p .707 .577 .707 r
F P
0 g
s
.21992 .80088 m .22086 .78188 L .19338 .77813 L p .707 .577 .707 r
F P
0 g
s
.22564 .79131 m .22229 .75752 L .19478 .75204 L p .707 .577 .707 r
F P
0 g
s
.22229 .75752 m .22564 .79131 L .25676 .79211 L p .707 .577 .707 r
F P
0 g
s
.33925 .64354 m .33689 .70037 L .35319 .69639 L p .707 .577 .707 r
F P
0 g
s
.35319 .69639 m .35555 .63956 L .33925 .64354 L p .707 .577 .707 r
F P
0 g
s
.31425 .74606 m .31759 .77985 L .34135 .76797 L p .707 .577 .707 r
F P
0 g
s
.34135 .76797 m .33801 .73419 L .31425 .74606 L p .707 .577 .707 r
F P
0 g
s
.19338 .77813 m .19244 .79713 L .21992 .80088 L p .707 .577 .707 r
F P
0 g
s
.17205 .69195 m .17441 .63512 L .16176 .62966 L p .707 .577 .707 r
F P
0 g
s
.31311 .78505 m .31217 .80404 L .33613 .80206 L p .707 .577 .707 r
F P
0 g
s
.33613 .80206 m .33707 .78306 L .31311 .78505 L p .707 .577 .707 r
F P
0 g
s
.19813 .78582 m .19478 .75204 L .17358 .74241 L p .707 .577 .707 r
F P
0 g
s
.19478 .75204 m .19813 .78582 L .22564 .79131 L p .707 .577 .707 r
F P
0 g
s
.63287 .29644 m .63608 .79611 L .64608 .78359 L p .707 .577 .707 r
F P
0 g
s
.64608 .78359 m .64287 .28393 L .63287 .29644 L p .707 .577 .707 r
F P
0 g
s
.18747 .77685 m .17228 .77355 L p .19281 .78963 L .707 .577 .707 r
F P
0 g
s
.17692 .77619 m .17374 .74401 L p .16075 .72959 L .707 .577 .707 r
F P
0 g
s
.17374 .74401 m .17358 .74241 L .1727 .74153 L p .707 .577 .707 r
F P
0 g
s
.1727 .74153 m .16075 .72959 L p .17374 .74401 L .707 .577 .707 r
F P
0 g
s
.19244 .79713 m .19281 .78963 L p .17228 .77355 L .707 .577 .707 r
F P
0 g
s
.19281 .78963 m .19338 .77813 L .18747 .77685 L p .707 .577 .707 r
F P
0 g
s
.16176 .62966 m .15941 .68649 L .17205 .69195 L p .707 .577 .707 r
F P
0 g
s
.68768 .80241 m .68674 .82141 L .66564 .81682 L p .707 .577 .707 r
F P
0 g
s
.66564 .81682 m .66657 .79782 L .68768 .80241 L p .707 .577 .707 r
F P
0 g
s
.17228 .77355 m .17134 .79254 L .19244 .79713 L p .707 .577 .707 r
F P
0 g
s
.33801 .73419 m .34135 .76797 L .35739 .75371 L p .707 .577 .707 r
F P
0 g
s
.35739 .75371 m .35405 .71992 L .33801 .73419 L p .707 .577 .707 r
F P
0 g
s
.35555 .63956 m .35319 .69639 L .3602 .69141 L p .707 .577 .707 r
F P
0 g
s
.3602 .69141 m .36256 .63459 L .35555 .63956 L p .707 .577 .707 r
F P
0 g
s
.33707 .78306 m .33613 .80206 L .3524 .79875 L p .707 .577 .707 r
F P
0 g
s
.3524 .79875 m .35334 .77975 L .33707 .78306 L p .707 .577 .707 r
F P
0 g
s
.17358 .74241 m .17692 .77619 L .19813 .78582 L p .707 .577 .707 r
F P
0 g
s
.35405 .71992 m .35739 .75371 L .36415 .73844 L p .707 .577 .707 r
F P
0 g
s
.36415 .73844 m .36081 .70466 L .35405 .71992 L p .707 .577 .707 r
F P
0 g
s
.36256 .63459 m .3602 .69141 L .35724 .68593 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3596 .6291 L .36256 .63459 L p .707 .577 .707 r
F P
0 g
s
.36081 .70466 m .36415 .73844 L .36096 .72368 L p .707 .577 .707 r
F P
0 g
s
.36232 .79258 m .35911 .29291 L .35502 .28021 L p .707 .577 .707 r
F P
0 g
s
.35911 .29291 m .36232 .79258 L .3801 .80422 L p .707 .577 .707 r
F P
0 g
s
.15941 .68649 m .16176 .62966 L .1588 .62418 L p .707 .577 .707 r
F P
0 g
s
.17134 .79254 m .17228 .77355 L .15961 .76857 L p .707 .577 .707 r
F P
0 g
s
.66657 .79782 m .66564 .81682 L .63816 .81307 L p .707 .577 .707 r
F P
0 g
s
.63816 .81307 m .6391 .79407 L .66657 .79782 L p .707 .577 .707 r
F P
0 g
s
.15961 .76857 m .15868 .78757 L .17134 .79254 L p .707 .577 .707 r
F P
0 g
s
.1588 .62418 m .15645 .681 L .15941 .68649 L p .707 .577 .707 r
F P
0 g
s
.16075 .72959 m .1641 .76337 L .17692 .77619 L p .707 .577 .707 r
F P
0 g
s
.64287 .28393 m .64608 .78359 L .64199 .77089 L p .707 .577 .707 r
F P
0 g
s
.64199 .77089 m .63878 .27123 L .64287 .28393 L p .707 .577 .707 r
F P
0 g
s
.35334 .77975 m .3524 .79875 L .35938 .79445 L p .707 .577 .707 r
F P
0 g
s
.35938 .79445 m .36032 .77545 L .35334 .77975 L p .707 .577 .707 r
F P
0 g
s
.1641 .76337 m .16075 .72959 L .15756 .71482 L p .707 .577 .707 r
F P
0 g
s
.15645 .681 m .1588 .62418 L .16581 .6192 L p .707 .577 .707 r
F P
0 g
s
.15868 .78757 m .15961 .76857 L .15663 .76369 L p .707 .577 .707 r
F P
0 g
s
.36096 .72368 m .35762 .68989 L .36081 .70466 L p .707 .577 .707 r
F P
0 g
s
.15663 .76369 m .15569 .78269 L .15868 .78757 L p .707 .577 .707 r
F P
0 g
s
.35724 .68593 m .3446 .68047 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3596 .6291 m .35857 .65388 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.35857 .65388 m .35724 .68593 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .3596 .6291 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .34476 .6767 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .34695 .62364 L p .34658 .6737 L .707 .577 .707 r
F P
0 g
s
.3446 .68047 m .32351 .67557 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32359 .66744 L .34133 .6755 L p .707 .577 .707 r
F P
0 g
s
.34695 .62364 m .34476 .6767 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.34476 .6767 m .3446 .68047 L p .32599 .67009 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .34695 .62364 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .32377 .66931 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32587 .61875 L p .32836 .66484 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .29942 .69574 L p .31316 .67965 L .707 .577 .707 r
F P
0 g
s
.32351 .67557 m .29604 .67171 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32359 .66744 m .32377 .66931 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.32377 .66931 m .32351 .67557 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .32359 .66744 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .29634 .66459 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .29634 .66459 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29608 .66196 L p .32222 .66904 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .32587 .61875 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .2984 .61489 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.32587 .61875 m .32377 .66931 L p .29973 .66517 L .707 .577 .707 r
F P
0 g
s
.31316 .67965 m .32222 .66904 L .32377 .66931 L .707 .577 .707 r
F
.32377 .66931 m .32693 .70123 L p .31316 .67965 L F P
0 g
s
.32693 .70123 m .32377 .66931 L p .34459 .67698 L .707 .577 .707 r
F P
0 g
s
.34133 .6755 m .34459 .67698 L p .32377 .66931 L .707 .577 .707 r
F P
0 g
s
.34459 .67698 m .34479 .67707 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.32693 .70123 m .34459 .67698 L .34338 .67898 L .707 .577 .707 r
F
.34479 .67707 m .34814 .71085 L .32927 .70229 L p F P
0 g
s
.32927 .70229 m .32693 .70123 L p .34338 .67898 L .707 .577 .707 r
F P
0 g
s
.34338 .67898 m .34479 .67707 L .32927 .70229 L .707 .577 .707 r
F
.36032 .77545 m .35938 .79445 L .35639 .78957 L p F P
0 g
s
.35639 .78957 m .35733 .77057 L .36032 .77545 L p .707 .577 .707 r
F P
0 g
s
.35762 .68989 m .36096 .72368 L .34814 .71085 L p .707 .577 .707 r
F P
0 g
s
.35502 .28021 m .35823 .77988 L .36232 .79258 L p .707 .577 .707 r
F P
0 g
s
.35823 .77988 m .35502 .28021 L .36502 .2677 L p .707 .577 .707 r
F P
0 g
s
.16581 .6192 m .16346 .67602 L .15645 .681 L p .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .15663 .76369 L .16166 .76059 L p .707 .577 .707 r
F P
0 g
s
.16091 .7486 m .1641 .76337 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.16166 .76059 m .16361 .75939 L p .16197 .76419 L .707 .577 .707 r
F P
0 g
s
.15569 .78269 m .16166 .76059 L .16197 .76419 L .707 .577 .707 r
F
.15756 .71482 m .15855 .72477 L p .1579 .71733 L F P
0 g
s
.15855 .72477 m .16091 .7486 L p .1579 .71733 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16091 .7486 m .15756 .71482 L .16432 .69956 L p .707 .577 .707 r
F P
0 g
s
.16346 .67602 m .16581 .6192 L .18211 .61522 L p .707 .577 .707 r
F P
0 g
s
.34814 .71085 m .34479 .67707 L .35762 .68989 L p .707 .577 .707 r
F P
0 g
s
.63878 .27123 m .64199 .77089 L .62421 .75925 L p .707 .577 .707 r
F P
0 g
s
.62421 .75925 m .621 .25959 L .63878 .27123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16361 .75939 m .16267 .77839 L .15569 .78269 L p .707 .577 .707 r
F P
0 g
s
.16432 .69956 m .16766 .73334 L .16091 .7486 L p .707 .577 .707 r
F P
0 g
s
.18211 .61522 m .17976 .67204 L .16346 .67602 L p .707 .577 .707 r
F P
0 g
s
.16766 .73334 m .16432 .69956 L .18036 .68529 L p .707 .577 .707 r
F P
0 g
s
.36822 .76736 m .36502 .2677 L .38813 .25658 L p .707 .577 .707 r
F P
0 g
s
.36502 .2677 m .36822 .76736 L .35823 .77988 L p .707 .577 .707 r
F P
0 g
s
.35733 .77057 m .35639 .78957 L .34373 .78459 L p .707 .577 .707 r
F P
0 g
s
.34373 .78459 m .34467 .7656 L .35733 .77057 L p .707 .577 .707 r
F P
0 g
s
.17976 .67204 m .18211 .61522 L .2061 .61263 L p .707 .577 .707 r
F P
0 g
s
.16267 .77839 m .16361 .75939 L .17987 .75608 L p .707 .577 .707 r
F P
0 g
s
.17987 .75608 m .17894 .77508 L .16267 .77839 L p .707 .577 .707 r
F P
0 g
s
.18036 .68529 m .18371 .71907 L .16766 .73334 L p .707 .577 .707 r
F P
0 g
s
.2061 .61263 m .20375 .66945 L .17976 .67204 L p .707 .577 .707 r
F P
0 g
s
.18371 .71907 m .18036 .68529 L .20412 .67342 L p .707 .577 .707 r
F P
0 g
s
.621 .25959 m .62421 .75925 L .59448 .74982 L p .707 .577 .707 r
F P
0 g
s
.59448 .74982 m .59127 .25015 L .621 .25959 L p .707 .577 .707 r
F P
0 g
s
.20375 .66945 m .2061 .61263 L .23543 .61167 L p .707 .577 .707 r
F P
0 g
s
.34467 .7656 m .34373 .78459 L .32263 .78 L p .707 .577 .707 r
F P
0 g
s
.32263 .78 m .32356 .76101 L .34467 .7656 L p .707 .577 .707 r
F P
0 g
s
.29604 .67171 m .26488 .66928 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29604 .67171 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.29942 .69574 m .2683 .69493 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29608 .66196 m .29634 .66459 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.29634 .66459 m .29942 .69574 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .29608 .66196 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .26514 .66302 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .26514 .66302 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26496 .66115 L p .29396 .66447 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .2984 .61489 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26724 .61245 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.2984 .61489 m .29634 .66459 L p .26863 .66319 L .707 .577 .707 r
F P
0 g
s
.38813 .25658 m .39133 .75625 L .36822 .76736 L p .707 .577 .707 r
F P
0 g
s
.39133 .75625 m .38813 .25658 L .42208 .24797 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .23308 .6685 L .20375 .66945 L p .707 .577 .707 r
F P
0 g
s
.23543 .61167 m .26724 .61245 L p .2424 .6532 L .707 .577 .707 r
F P
0 g
s
.23308 .6685 m .23324 .66474 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.23844 .66445 m .26496 .66115 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26488 .66928 m .23308 .6685 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26496 .66115 m .26514 .66302 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26724 .61245 m .26514 .66302 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .26488 .66928 L p .23545 .66462 L .707 .577 .707 r
F P
0 g
s
.2683 .69493 m .23661 .69888 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.26514 .66302 m .2683 .69493 L p .26349 .6631 L .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23327 .6651 L .23844 .66445 L p .707 .577 .707 r
F P
0 g
s
.23661 .69888 m .23844 .66445 L .26349 .6631 L .707 .577 .707 r
F
.23545 .66462 m .23324 .66474 L .2424 .6532 L F
.23324 .66474 m .23543 .61167 L p .2424 .6532 L F P
0 g
s
.20747 .7072 m .20658 .69827 L p .23327 .6651 L .707 .577 .707 r
F P
0 g
s
.20658 .69827 m .20412 .67342 L .23285 .66522 L p .707 .577 .707 r
F P
0 g
s
.23285 .66522 m .23327 .6651 L p .20658 .69827 L .707 .577 .707 r
F P
0 g
s
.20412 .67342 m .20747 .7072 L .18371 .71907 L p .707 .577 .707 r
F P
0 g
s
.17894 .77508 m .17987 .75608 L .20384 .7541 L p .707 .577 .707 r
F P
0 g
s
.73198 .64791 m .73434 .59109 L .70318 .58865 L p .707 .577 .707 r
F P
0 g
s
.73434 .59109 m .73198 .64791 L .76379 .64869 L p .707 .577 .707 r
F P
0 g
s
.76379 .64869 m .76614 .59187 L .73434 .59109 L p .707 .577 .707 r
F P
0 g
s
.20384 .7541 m .2029 .77309 L .17894 .77508 L p .707 .577 .707 r
F P
0 g
s
.76614 .59187 m .76379 .64869 L .79312 .64774 L p .707 .577 .707 r
F P
0 g
s
.79312 .64774 m .79547 .59092 L .76614 .59187 L p .707 .577 .707 r
F P
0 g
s
.70082 .64548 m .70318 .58865 L .67571 .5848 L p .707 .577 .707 r
F P
0 g
s
.70318 .58865 m .70082 .64548 L .73198 .64791 L p .707 .577 .707 r
F P
0 g
s
.23327 .6651 m .23661 .69888 L .20747 .7072 L p .707 .577 .707 r
F P
0 g
s
.59127 .25015 m .59448 .74982 L .55572 .7435 L p .707 .577 .707 r
F P
0 g
s
.55572 .7435 m .55251 .24383 L .59127 .25015 L p .707 .577 .707 r
F P
0 g
s
.32356 .76101 m .32263 .78 L .29515 .77626 L p .707 .577 .707 r
F P
0 g
s
.29515 .77626 m .29609 .75726 L .32356 .76101 L p .707 .577 .707 r
F P
0 g
s
.79547 .59092 m .79312 .64774 L .81711 .64515 L p .707 .577 .707 r
F P
0 g
s
.81711 .64515 m .81946 .58832 L .79547 .59092 L p .707 .577 .707 r
F P
0 g
s
.67571 .5848 m .67335 .64162 L .70082 .64548 L p .707 .577 .707 r
F P
0 g
s
.2029 .77309 m .20384 .7541 L .23315 .75363 L p .707 .577 .707 r
F P
0 g
s
.67335 .64162 m .67571 .5848 L .65462 .5799 L p .707 .577 .707 r
F P
0 g
s
.23315 .75363 m .23221 .77262 L .2029 .77309 L p .707 .577 .707 r
F P
0 g
s
.42529 .74764 m .42208 .24797 L .46356 .24269 L p .707 .577 .707 r
F P
0 g
s
.42208 .24797 m .42529 .74764 L .39133 .75625 L p .707 .577 .707 r
F P
0 g
s
.73129 .74911 m .73222 .73012 L .70107 .72757 L p .707 .577 .707 r
F P
0 g
s
.73222 .73012 m .73129 .74911 L .76308 .7502 L p .707 .577 .707 r
F P
0 g
s
.76308 .7502 m .76401 .73121 L .73222 .73012 L p .707 .577 .707 r
F P
0 g
s
.73697 .73665 m .73363 .70287 L .70251 .70206 L p .707 .577 .707 r
F P
0 g
s
.76401 .73121 m .76308 .7502 L .79239 .74973 L p .707 .577 .707 r
F P
0 g
s
.79239 .74973 m .79332 .73073 L .76401 .73121 L p .707 .577 .707 r
F P
0 g
s
.73363 .70287 m .73697 .73665 L .76866 .7327 L p .707 .577 .707 r
F P
0 g
s
.76866 .7327 m .76531 .69892 L .73363 .70287 L p .707 .577 .707 r
F P
0 g
s
.29609 .75726 m .29515 .77626 L .264 .77371 L p .707 .577 .707 r
F P
0 g
s
.264 .77371 m .26493 .75472 L .29609 .75726 L p .707 .577 .707 r
F P
0 g
s
.76531 .69892 m .76866 .7327 L .79781 .72439 L p .707 .577 .707 r
F P
0 g
s
.79781 .72439 m .79446 .6906 L .76531 .69892 L p .707 .577 .707 r
F P
0 g
s
.65462 .5799 m .65227 .63672 L .67335 .64162 L p .707 .577 .707 r
F P
0 g
s
.23221 .77262 m .23315 .75363 L .26493 .75472 L p .707 .577 .707 r
F P
0 g
s
.55251 .24383 m .55572 .7435 L .51171 .74093 L p .707 .577 .707 r
F P
0 g
s
.51171 .74093 m .5085 .24126 L .55251 .24383 L p .707 .577 .707 r
F P
0 g
s
.70107 .72757 m .70013 .74657 L .73129 .74911 L p .707 .577 .707 r
F P
0 g
s
.26493 .75472 m .264 .77371 L .23221 .77262 L p .707 .577 .707 r
F P
0 g
s
.70013 .74657 m .70107 .72757 L .67359 .72382 L p .707 .577 .707 r
F P
0 g
s
.70585 .73584 m .70251 .70206 L .675 .69658 L p .707 .577 .707 r
F P
0 g
s
.70251 .70206 m .70585 .73584 L .73697 .73665 L p .707 .577 .707 r
F P
0 g
s
.81946 .58832 m .81711 .64515 L .83341 .64117 L p .707 .577 .707 r
F P
0 g
s
.83341 .64117 m .83576 .58434 L .81946 .58832 L p .707 .577 .707 r
F P
0 g
s
.79446 .6906 m .79781 .72439 L .82156 .71251 L p .707 .577 .707 r
F P
0 g
s
.82156 .71251 m .81822 .67873 L .79446 .6906 L p .707 .577 .707 r
F P
0 g
s
.46677 .74236 m .46356 .24269 L .5085 .24126 L p .707 .577 .707 r
F P
0 g
s
.46356 .24269 m .46677 .74236 L .42529 .74764 L p .707 .577 .707 r
F P
0 g
s
.67359 .72382 m .67266 .74282 L .70013 .74657 L p .707 .577 .707 r
F P
0 g
s
.5085 .24126 m .51171 .74093 L .46677 .74236 L p .707 .577 .707 r
F P
0 g
s
.65227 .63672 m .65462 .5799 L .64198 .57444 L p .707 .577 .707 r
F P
0 g
s
.79332 .73073 m .79239 .74973 L .81635 .74774 L p .707 .577 .707 r
F P
0 g
s
.81635 .74774 m .81728 .72875 L .79332 .73073 L p .707 .577 .707 r
F P
0 g
s
.67834 .73036 m .675 .69658 L .65379 .68695 L p .707 .577 .707 r
F P
0 g
s
.675 .69658 m .67834 .73036 L .70585 .73584 L p .707 .577 .707 r
F P
0 g
s
.66807 .72262 m .65249 .71924 L p .67306 .73456 L .707 .577 .707 r
F P
0 g
s
.65713 .72073 m .65399 .68894 L p .64097 .67413 L .707 .577 .707 r
F P
0 g
s
.65399 .68894 m .65379 .68695 L .6527 .68586 L p .707 .577 .707 r
F P
0 g
s
.6527 .68586 m .64097 .67413 L p .65399 .68894 L .707 .577 .707 r
F P
0 g
s
.67266 .74282 m .67306 .73456 L p .65249 .71924 L .707 .577 .707 r
F P
0 g
s
.67306 .73456 m .67359 .72382 L .66807 .72262 L p .707 .577 .707 r
F P
0 g
s
.64198 .57444 m .63962 .63126 L .65227 .63672 L p .707 .577 .707 r
F P
0 g
s
.65249 .71924 m .65155 .73823 L .67266 .74282 L p .707 .577 .707 r
F P
0 g
s
.81822 .67873 m .82156 .71251 L .83761 .69824 L p .707 .577 .707 r
F P
0 g
s
.83761 .69824 m .83427 .66446 L .81822 .67873 L p .707 .577 .707 r
F P
0 g
s
.83576 .58434 m .83341 .64117 L .84042 .63619 L p .707 .577 .707 r
F P
0 g
s
.84042 .63619 m .84277 .57937 L .83576 .58434 L p .707 .577 .707 r
F P
0 g
s
.65379 .68695 m .65713 .72073 L .67834 .73036 L p .707 .577 .707 r
F P
0 g
s
.81728 .72875 m .81635 .74774 L .83261 .74444 L p .707 .577 .707 r
F P
0 g
s
.83261 .74444 m .83355 .72544 L .81728 .72875 L p .707 .577 .707 r
F P
0 g
s
.63962 .63126 m .64198 .57444 L .63902 .56895 L p .707 .577 .707 r
F P
0 g
s
.65155 .73823 m .65249 .71924 L .63983 .71426 L p .707 .577 .707 r
F P
0 g
s
.63983 .71426 m .63889 .73326 L .65155 .73823 L p .707 .577 .707 r
F P
0 g
s
.83427 .66446 m .83761 .69824 L .84437 .68298 L p .707 .577 .707 r
F P
0 g
s
.84437 .68298 m .84102 .6492 L .83427 .66446 L p .707 .577 .707 r
F P
0 g
s
.63902 .56895 m .63666 .62578 L .63962 .63126 L p .707 .577 .707 r
F P
0 g
s
.64097 .67413 m .64431 .70791 L .65713 .72073 L p .707 .577 .707 r
F P
0 g
s
.84277 .57937 m .84042 .63619 L .83746 .6307 L p .707 .577 .707 r
F P
0 g
s
.83746 .6307 m .83981 .57388 L .84277 .57937 L p .707 .577 .707 r
F P
0 g
s
.83355 .72544 m .83261 .74444 L .8396 .74014 L p .707 .577 .707 r
F P
0 g
s
.8396 .74014 m .84053 .72114 L .83355 .72544 L p .707 .577 .707 r
F P
0 g
s
.64431 .70791 m .64097 .67413 L .63778 .65936 L p .707 .577 .707 r
F P
0 g
s
.63666 .62578 m .63902 .56895 L .64603 .56398 L p .707 .577 .707 r
F P
0 g
s
.63889 .73326 m .63983 .71426 L .63684 .70938 L p .707 .577 .707 r
F P
0 g
s
.84102 .6492 m .84437 .68298 L .84118 .66821 L p .707 .577 .707 r
F P
0 g
s
.84118 .66821 m .83783 .63443 L .84102 .6492 L p .707 .577 .707 r
F P
0 g
s
.63684 .70938 m .6359 .72838 L .63889 .73326 L p .707 .577 .707 r
F P
0 g
s
.64603 .56398 m .64367 .6208 L .63666 .62578 L p .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .63684 .70938 L .64197 .70622 L p .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .64431 .70791 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.64197 .70622 m .64382 .70508 L p .64227 .70964 L .707 .577 .707 r
F P
0 g
s
.6359 .72838 m .64197 .70622 L .64227 .70964 L .707 .577 .707 r
F
.63778 .65936 m .6388 .66969 L p .63813 .66196 L F P
0 g
s
.6388 .66969 m .64112 .69314 L p .63813 .66196 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83746 .6307 m .82482 .62525 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .83981 .57388 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .82498 .62131 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82717 .56842 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.82482 .62525 m .80373 .62035 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .8038 .61198 L .82222 .62034 L p .707 .577 .707 r
F P
0 g
s
.82717 .56842 m .82498 .62131 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.82498 .62131 m .82482 .62525 L p .80627 .61472 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .82717 .56842 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .80399 .61392 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80608 .56352 L p .8087 .60933 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .77964 .64028 L p .79298 .62465 L .707 .577 .707 r
F P
0 g
s
.80373 .62035 m .77626 .61649 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.8038 .61198 m .80399 .61392 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.80399 .61392 m .80373 .62035 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .8038 .61198 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .77656 .6092 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .77656 .6092 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77629 .6065 L p .80238 .61364 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .80608 .56352 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77861 .55967 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.80608 .56352 m .80399 .61392 L p .78003 .6098 L .707 .577 .707 r
F P
0 g
s
.79298 .62465 m .80238 .61364 L .80399 .61392 L .707 .577 .707 r
F
.80399 .61392 m .80714 .64577 L p .79298 .62465 L F P
0 g
s
.80714 .64577 m .80399 .61392 L p .82485 .62153 L .707 .577 .707 r
F P
0 g
s
.82222 .62034 m .82485 .62153 L p .80399 .61392 L .707 .577 .707 r
F P
0 g
s
.82485 .62153 m .82501 .62161 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.80714 .64577 m .82485 .62153 L .82387 .62315 L .707 .577 .707 r
F
.82501 .62161 m .82835 .65539 L .80952 .64685 L p F P
0 g
s
.80952 .64685 m .80714 .64577 L p .82387 .62315 L .707 .577 .707 r
F P
0 g
s
.82387 .62315 m .82501 .62161 L .80952 .64685 L .707 .577 .707 r
F
.83981 .57388 m .83879 .59849 L p .82688 .61817 L F P
0 g
s
.83879 .59849 m .83746 .6307 L p .82688 .61817 L .707 .577 .707 r
F P
0 g
s
.64112 .69314 m .63778 .65936 L .64453 .6441 L p .707 .577 .707 r
F P
0 g
s
.84053 .72114 m .8396 .74014 L .83661 .73526 L p .707 .577 .707 r
F P
0 g
s
.83661 .73526 m .83755 .71626 L .84053 .72114 L p .707 .577 .707 r
F P
0 g
s
.38897 .6111 m .39133 .55427 L .36017 .55184 L p .707 .577 .707 r
F P
0 g
s
.39133 .55427 m .38897 .6111 L .42078 .61188 L p .707 .577 .707 r
F P
0 g
s
.42078 .61188 m .42313 .55505 L .39133 .55427 L p .707 .577 .707 r
F P
0 g
s
.42313 .55505 m .42078 .61188 L .45011 .61092 L p .707 .577 .707 r
F P
0 g
s
.45011 .61092 m .45246 .5541 L .42313 .55505 L p .707 .577 .707 r
F P
0 g
s
.64367 .6208 m .64603 .56398 L .66233 .56 L p .707 .577 .707 r
F P
0 g
s
.83783 .63443 m .84118 .66821 L .82835 .65539 L p .707 .577 .707 r
F P
0 g
s
.82835 .65539 m .82501 .62161 L .83783 .63443 L p .707 .577 .707 r
F P
0 g
s
.35781 .60866 m .36017 .55184 L .3327 .54798 L p .707 .577 .707 r
F P
0 g
s
.36017 .55184 m .35781 .60866 L .38897 .6111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64382 .70508 m .64288 .72407 L .6359 .72838 L p .707 .577 .707 r
F P
0 g
s
.64453 .6441 m .64788 .67788 L .64112 .69314 L p .707 .577 .707 r
F P
0 g
s
.66233 .56 m .65997 .61682 L .64367 .6208 L p .707 .577 .707 r
F P
0 g
s
.45246 .5541 m .45011 .61092 L .4741 .60833 L p .707 .577 .707 r
F P
0 g
s
.4741 .60833 m .47645 .55151 L .45246 .5541 L p .707 .577 .707 r
F P
0 g
s
.3327 .54798 m .33034 .6048 L .35781 .60866 L p .707 .577 .707 r
F P
0 g
s
.33034 .6048 m .3327 .54798 L .31161 .54308 L p .707 .577 .707 r
F P
0 g
s
.64788 .67788 m .64453 .6441 L .66058 .62983 L p .707 .577 .707 r
F P
0 g
s
.83755 .71626 m .83661 .73526 L .82394 .73028 L p .707 .577 .707 r
F P
0 g
s
.82394 .73028 m .82488 .71128 L .83755 .71626 L p .707 .577 .707 r
F P
0 g
s
.38828 .7123 m .38921 .6933 L .35806 .69076 L p .707 .577 .707 r
F P
0 g
s
.38921 .6933 m .38828 .7123 L .42007 .71339 L p .707 .577 .707 r
F P
0 g
s
.42007 .71339 m .421 .69439 L .38921 .6933 L p .707 .577 .707 r
F P
0 g
s
.39396 .69984 m .39062 .66605 L .3595 .66525 L p .707 .577 .707 r
F P
0 g
s
.421 .69439 m .42007 .71339 L .44938 .71292 L p .707 .577 .707 r
F P
0 g
s
.44938 .71292 m .45031 .69392 L .421 .69439 L p .707 .577 .707 r
F P
0 g
s
.39062 .66605 m .39396 .69984 L .42565 .69589 L p .707 .577 .707 r
F P
0 g
s
.42565 .69589 m .4223 .6621 L .39062 .66605 L p .707 .577 .707 r
F P
0 g
s
.4223 .6621 m .42565 .69589 L .4548 .68757 L p .707 .577 .707 r
F P
0 g
s
.4548 .68757 m .45145 .65379 L .4223 .6621 L p .707 .577 .707 r
F P
0 g
s
.65997 .61682 m .66233 .56 L .68632 .5574 L p .707 .577 .707 r
F P
0 g
s
.31161 .54308 m .30926 .59991 L .33034 .6048 L p .707 .577 .707 r
F P
0 g
s
.35806 .69076 m .35712 .70975 L .38828 .7123 L p .707 .577 .707 r
F P
0 g
s
.35712 .70975 m .35806 .69076 L .33058 .68701 L p .707 .577 .707 r
F P
0 g
s
.36284 .69903 m .3595 .66525 L .33199 .65976 L p .707 .577 .707 r
F P
0 g
s
.3595 .66525 m .36284 .69903 L .39396 .69984 L p .707 .577 .707 r
F P
0 g
s
.47645 .55151 m .4741 .60833 L .4904 .60435 L p .707 .577 .707 r
F P
0 g
s
.4904 .60435 m .49275 .54753 L .47645 .55151 L p .707 .577 .707 r
F P
0 g
s
.64288 .72407 m .64382 .70508 L .66009 .70177 L p .707 .577 .707 r
F P
0 g
s
.45145 .65379 m .4548 .68757 L .47855 .6757 L p .707 .577 .707 r
F P
0 g
s
.47855 .6757 m .47521 .64191 L .45145 .65379 L p .707 .577 .707 r
F P
0 g
s
.66009 .70177 m .65915 .72077 L .64288 .72407 L p .707 .577 .707 r
F P
0 g
s
.66058 .62983 m .66392 .66361 L .64788 .67788 L p .707 .577 .707 r
F P
0 g
s
.68632 .5574 m .68396 .61423 L .65997 .61682 L p .707 .577 .707 r
F P
0 g
s
.33058 .68701 m .32965 .706 L .35712 .70975 L p .707 .577 .707 r
F P
0 g
s
.30926 .59991 m .31161 .54308 L .29897 .53762 L p .707 .577 .707 r
F P
0 g
s
.66392 .66361 m .66058 .62983 L .68434 .61796 L p .707 .577 .707 r
F P
0 g
s
.45031 .69392 m .44938 .71292 L .47334 .71093 L p .707 .577 .707 r
F P
0 g
s
.47334 .71093 m .47427 .69193 L .45031 .69392 L p .707 .577 .707 r
F P
0 g
s
.33533 .69354 m .33199 .65976 L .31078 .65014 L p .707 .577 .707 r
F P
0 g
s
.33199 .65976 m .33533 .69354 L .36284 .69903 L p .707 .577 .707 r
F P
0 g
s
.68396 .61423 m .68632 .5574 L .71565 .55645 L p .707 .577 .707 r
F P
0 g
s
.32506 .68581 m .30948 .68242 L p .33005 .69774 L .707 .577 .707 r
F P
0 g
s
.31412 .68392 m .31098 .65212 L p .29796 .63731 L .707 .577 .707 r
F P
0 g
s
.31098 .65212 m .31078 .65014 L .30969 .64905 L p .707 .577 .707 r
F P
0 g
s
.30969 .64905 m .29796 .63731 L p .31098 .65212 L .707 .577 .707 r
F P
0 g
s
.32965 .706 m .33005 .69774 L p .30948 .68242 L .707 .577 .707 r
F P
0 g
s
.33005 .69774 m .33058 .68701 L .32506 .68581 L p .707 .577 .707 r
F P
0 g
s
.29897 .53762 m .29661 .59445 L .30926 .59991 L p .707 .577 .707 r
F P
0 g
s
.82488 .71128 m .82394 .73028 L .80284 .72569 L p .707 .577 .707 r
F P
0 g
s
.80284 .72569 m .80378 .7067 L .82488 .71128 L p .707 .577 .707 r
F P
0 g
s
.30948 .68242 m .30854 .70142 L .32965 .706 L p .707 .577 .707 r
F P
0 g
s
.47521 .64191 m .47855 .6757 L .4946 .66143 L p .707 .577 .707 r
F P
0 g
s
.4946 .66143 m .49126 .62765 L .47521 .64191 L p .707 .577 .707 r
F P
0 g
s
.77626 .61649 m .7451 .61406 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77626 .61649 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77964 .64028 m .74851 .63947 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77629 .6065 m .77656 .6092 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.77656 .6092 m .77964 .64028 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .77629 .6065 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .74536 .60762 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .74536 .60762 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74517 .60569 L p .77412 .60908 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .77861 .55967 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74745 .55723 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.77861 .55967 m .77656 .6092 L p .74895 .60781 L .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .71329 .61328 L .68396 .61423 L p .707 .577 .707 r
F P
0 g
s
.49275 .54753 m .4904 .60435 L .49741 .59937 L p .707 .577 .707 r
F P
0 g
s
.49741 .59937 m .49976 .54255 L .49275 .54753 L p .707 .577 .707 r
F P
0 g
s
.71565 .55645 m .74745 .55723 L p .72303 .59729 L .707 .577 .707 r
F P
0 g
s
.71329 .61328 m .71346 .60934 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.71765 .60912 m .74517 .60569 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.7451 .61406 m .71329 .61328 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74517 .60569 m .74536 .60762 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74745 .55723 m .74536 .60762 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .7451 .61406 L p .71576 .60922 L .707 .577 .707 r
F P
0 g
s
.74851 .63947 m .71683 .64342 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.74536 .60762 m .74851 .63947 L p .74365 .60772 L .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71349 .60964 L .71765 .60912 L p .707 .577 .707 r
F P
0 g
s
.71683 .64342 m .71765 .60912 L .74365 .60772 L .707 .577 .707 r
F
.71576 .60922 m .71346 .60934 L .72303 .59729 L F
.71346 .60934 m .71565 .55645 L p .72303 .59729 L F P
0 g
s
.68768 .65174 m .6868 .64288 L p .71349 .60964 L .707 .577 .707 r
F P
0 g
s
.6868 .64288 m .68434 .61796 L .71315 .60973 L p .707 .577 .707 r
F P
0 g
s
.71315 .60973 m .71349 .60964 L p .6868 .64288 L .707 .577 .707 r
F P
0 g
s
.68434 .61796 m .68768 .65174 L .66392 .66361 L p .707 .577 .707 r
F P
0 g
s
.65915 .72077 m .66009 .70177 L .68405 .69979 L p .707 .577 .707 r
F P
0 g
s
.68405 .69979 m .68311 .71878 L .65915 .72077 L p .707 .577 .707 r
F P
0 g
s
.31078 .65014 m .31412 .68392 L .33533 .69354 L p .707 .577 .707 r
F P
0 g
s
.47427 .69193 m .47334 .71093 L .4896 .70762 L p .707 .577 .707 r
F P
0 g
s
.4896 .70762 m .49054 .68863 L .47427 .69193 L p .707 .577 .707 r
F P
0 g
s
.29661 .59445 m .29897 .53762 L .29601 .53214 L p .707 .577 .707 r
F P
0 g
s
.71349 .60964 m .71683 .64342 L .68768 .65174 L p .707 .577 .707 r
F P
0 g
s
.30854 .70142 m .30948 .68242 L .29682 .67744 L p .707 .577 .707 r
F P
0 g
s
.80378 .7067 m .80284 .72569 L .77537 .72194 L p .707 .577 .707 r
F P
0 g
s
.77537 .72194 m .7763 .70295 L .80378 .7067 L p .707 .577 .707 r
F P
0 g
s
.29682 .67744 m .29588 .69644 L .30854 .70142 L p .707 .577 .707 r
F P
0 g
s
.49126 .62765 m .4946 .66143 L .50136 .64617 L p .707 .577 .707 r
F P
0 g
s
.50136 .64617 m .49801 .61238 L .49126 .62765 L p .707 .577 .707 r
F P
0 g
s
.29601 .53214 m .29365 .58896 L .29661 .59445 L p .707 .577 .707 r
F P
0 g
s
.68311 .71878 m .68405 .69979 L .71336 .69931 L p .707 .577 .707 r
F P
0 g
s
.71336 .69931 m .71242 .71831 L .68311 .71878 L p .707 .577 .707 r
F P
0 g
s
.29796 .63731 m .3013 .6711 L .31412 .68392 L p .707 .577 .707 r
F P
0 g
s
.49976 .54255 m .49741 .59937 L .49445 .59389 L p .707 .577 .707 r
F P
0 g
s
.49445 .59389 m .4968 .53706 L .49976 .54255 L p .707 .577 .707 r
F P
0 g
s
.7763 .70295 m .77537 .72194 L .74421 .7194 L p .707 .577 .707 r
F P
0 g
s
.74421 .7194 m .74515 .7004 L .7763 .70295 L p .707 .577 .707 r
F P
0 g
s
.49054 .68863 m .4896 .70762 L .49659 .70332 L p .707 .577 .707 r
F P
0 g
s
.49659 .70332 m .49752 .68432 L .49054 .68863 L p .707 .577 .707 r
F P
0 g
s
.71242 .71831 m .71336 .69931 L .74515 .7004 L p .707 .577 .707 r
F P
0 g
s
.3013 .6711 m .29796 .63731 L .29477 .62255 L p .707 .577 .707 r
F P
0 g
s
.74515 .7004 m .74421 .7194 L .71242 .71831 L p .707 .577 .707 r
F P
0 g
s
.29365 .58896 m .29601 .53214 L .30302 .52716 L p .707 .577 .707 r
F P
0 g
s
.29588 .69644 m .29682 .67744 L .29383 .67257 L p .707 .577 .707 r
F P
0 g
s
.49801 .61238 m .50136 .64617 L .49817 .6314 L p .707 .577 .707 r
F P
0 g
s
.49817 .6314 m .49482 .59762 L .49801 .61238 L p .707 .577 .707 r
F P
0 g
s
.29383 .67257 m .29289 .69156 L .29588 .69644 L p .707 .577 .707 r
F P
0 g
s
.30302 .52716 m .30066 .58399 L .29365 .58896 L p .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29383 .67257 L .29896 .6694 L p .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .3013 .6711 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.29896 .6694 m .30081 .66826 L p .29926 .67282 L .707 .577 .707 r
F P
0 g
s
.29289 .69156 m .29896 .6694 L .29926 .67282 L .707 .577 .707 r
F
.29477 .62255 m .29579 .63288 L p .29512 .62515 L F P
0 g
s
.29579 .63288 m .29811 .65633 L p .29512 .62515 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49445 .59389 m .4818 .58843 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .4968 .53706 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .48197 .5845 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .48416 .5316 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.4818 .58843 m .46072 .58353 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46079 .57517 L .47921 .58353 L p .707 .577 .707 r
F P
0 g
s
.48416 .5316 m .48197 .5845 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.48197 .5845 m .4818 .58843 L p .46326 .5779 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .48416 .5316 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .46098 .5771 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46307 .52671 L p .46569 .57251 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .43662 .60346 L p .44997 .58784 L .707 .577 .707 r
F P
0 g
s
.46072 .58353 m .43325 .57968 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46079 .57517 m .46098 .5771 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.46098 .5771 m .46072 .58353 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .46079 .57517 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .43355 .57239 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .43355 .57239 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43328 .56968 L p .45937 .57683 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .46307 .52671 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .4356 .52285 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.46307 .52671 m .46098 .5771 L p .43702 .57298 L .707 .577 .707 r
F P
0 g
s
.44997 .58784 m .45937 .57683 L .46098 .5771 L .707 .577 .707 r
F
.46098 .5771 m .46413 .60895 L p .44997 .58784 L F P
0 g
s
.46413 .60895 m .46098 .5771 L p .48183 .58472 L .707 .577 .707 r
F P
0 g
s
.47921 .58353 m .48183 .58472 L p .46098 .5771 L .707 .577 .707 r
F P
0 g
s
.48183 .58472 m .482 .58479 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.46413 .60895 m .48183 .58472 L .48086 .58633 L .707 .577 .707 r
F
.482 .58479 m .48534 .61858 L .46651 .61003 L p F P
0 g
s
.46651 .61003 m .46413 .60895 L p .48086 .58633 L .707 .577 .707 r
F P
0 g
s
.48086 .58633 m .482 .58479 L .46651 .61003 L .707 .577 .707 r
F
.4968 .53706 m .49578 .56168 L p .48387 .58136 L F P
0 g
s
.49578 .56168 m .49445 .59389 L p .48387 .58136 L .707 .577 .707 r
F P
0 g
s
.29811 .65633 m .29477 .62255 L .30152 .60728 L p .707 .577 .707 r
F P
0 g
s
.49752 .68432 m .49659 .70332 L .4936 .69844 L p .707 .577 .707 r
F P
0 g
s
.4936 .69844 m .49454 .67945 L .49752 .68432 L p .707 .577 .707 r
F P
0 g
s
.30066 .58399 m .30302 .52716 L .31932 .52318 L p .707 .577 .707 r
F P
0 g
s
.49482 .59762 m .49817 .6314 L .48534 .61858 L p .707 .577 .707 r
F P
0 g
s
.48534 .61858 m .482 .58479 L .49482 .59762 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30081 .66826 m .29987 .68726 L .29289 .69156 L p .707 .577 .707 r
F P
0 g
s
.30152 .60728 m .30487 .64106 L .29811 .65633 L p .707 .577 .707 r
F P
0 g
s
.31932 .52318 m .31696 .58001 L .30066 .58399 L p .707 .577 .707 r
F P
0 g
s
.30487 .64106 m .30152 .60728 L .31757 .59301 L p .707 .577 .707 r
F P
0 g
s
.49454 .67945 m .4936 .69844 L .48093 .69347 L p .707 .577 .707 r
F P
0 g
s
.48093 .69347 m .48187 .67447 L .49454 .67945 L p .707 .577 .707 r
F P
0 g
s
.31696 .58001 m .31932 .52318 L .3433 .52059 L p .707 .577 .707 r
F P
0 g
s
.29987 .68726 m .30081 .66826 L .31708 .66496 L p .707 .577 .707 r
F P
0 g
s
.31708 .66496 m .31614 .68395 L .29987 .68726 L p .707 .577 .707 r
F P
0 g
s
.31757 .59301 m .32091 .6268 L .30487 .64106 L p .707 .577 .707 r
F P
0 g
s
.3433 .52059 m .34095 .57741 L .31696 .58001 L p .707 .577 .707 r
F P
0 g
s
.32091 .6268 m .31757 .59301 L .34133 .58114 L p .707 .577 .707 r
F P
0 g
s
.34095 .57741 m .3433 .52059 L .37264 .51963 L p .707 .577 .707 r
F P
0 g
s
.48187 .67447 m .48093 .69347 L .45983 .68888 L p .707 .577 .707 r
F P
0 g
s
.45983 .68888 m .46077 .66988 L .48187 .67447 L p .707 .577 .707 r
F P
0 g
s
.43325 .57968 m .40209 .57724 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43325 .57968 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.43662 .60346 m .4055 .60266 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43328 .56968 m .43355 .57239 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.43355 .57239 m .43662 .60346 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .43328 .56968 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .40235 .57081 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .40235 .57081 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40216 .56887 L p .43111 .57226 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .4356 .52285 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40444 .52041 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.4356 .52285 m .43355 .57239 L p .40594 .57099 L .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .37028 .57646 L .34095 .57741 L p .707 .577 .707 r
F P
0 g
s
.37264 .51963 m .40444 .52041 L p .38002 .56048 L .707 .577 .707 r
F P
0 g
s
.37028 .57646 m .37045 .57253 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.37464 .5723 m .40216 .56887 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40209 .57724 m .37028 .57646 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40216 .56887 m .40235 .57081 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40444 .52041 m .40235 .57081 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .40209 .57724 L p .37275 .5724 L .707 .577 .707 r
F P
0 g
s
.4055 .60266 m .37382 .60661 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.40235 .57081 m .4055 .60266 L p .40064 .5709 L .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37047 .57282 L .37464 .5723 L p .707 .577 .707 r
F P
0 g
s
.37382 .60661 m .37464 .5723 L .40064 .5709 L .707 .577 .707 r
F
.37275 .5724 m .37045 .57253 L .38002 .56048 L F
.37045 .57253 m .37264 .51963 L p .38002 .56048 L F P
0 g
s
.34467 .61492 m .34379 .60607 L p .37047 .57282 L .707 .577 .707 r
F P
0 g
s
.34379 .60607 m .34133 .58114 L .37014 .57292 L p .707 .577 .707 r
F P
0 g
s
.37014 .57292 m .37047 .57282 L p .34379 .60607 L .707 .577 .707 r
F P
0 g
s
.34133 .58114 m .34467 .61492 L .32091 .6268 L p .707 .577 .707 r
F P
0 g
s
.31614 .68395 m .31708 .66496 L .34104 .66297 L p .707 .577 .707 r
F P
0 g
s
.34104 .66297 m .3401 .68197 L .31614 .68395 L p .707 .577 .707 r
F P
0 g
s
.37047 .57282 m .37382 .60661 L .34467 .61492 L p .707 .577 .707 r
F P
0 g
s
.46077 .66988 m .45983 .68888 L .43236 .68513 L p .707 .577 .707 r
F P
0 g
s
.43236 .68513 m .43329 .66613 L .46077 .66988 L p .707 .577 .707 r
F P
0 g
s
.3401 .68197 m .34104 .66297 L .37035 .6625 L p .707 .577 .707 r
F P
0 g
s
.37035 .6625 m .36941 .6815 L .3401 .68197 L p .707 .577 .707 r
F P
0 g
s
.43329 .66613 m .43236 .68513 L .4012 .68258 L p .707 .577 .707 r
F P
0 g
s
.4012 .68258 m .40214 .66359 L .43329 .66613 L p .707 .577 .707 r
F P
0 g
s
.36941 .6815 m .37035 .6625 L .40214 .66359 L p .707 .577 .707 r
F P
0 g
s
.40214 .66359 m .4012 .68258 L .36941 .6815 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008Yoo`d008Io
o`00OWoo30001UYF00<005YFFUH015YF2@00OGoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001gOol007=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@007=oo`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YF00000`00Kgoo001]Ool30007FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH3001/Ool006]oo`80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8006]oo`00JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000006Uoo`00Igoo
0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00D005YFFUIJEP0006Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00<005YF00001`0000=JEP00FUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00FGoo3@000eYF00<005YFFUH00UYF4@001EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00EWoo0`00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH0
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00<0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000QooaT004Aoo`00Dgoo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000Woo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo
001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000eOol005=oo`03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP06001JEUYF001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@0035oo`00Dgoo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP05Ool005YFFUH0000^Ool005=oo`03001JEP0000=J
EPd000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001COol01000FUH005YF0P0015YF00<005YF
FUH00`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00L005YFFUIJEWooFUH00002FUH2000]Ool005=oo`03001JEP00008000EJEP<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
009JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF00EooeYFFUIJEP0000QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo0P000UYF00<005YFFUH00UYF
0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P0000=JEP0000000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00P00;Goo001COol20002FUH0
0`00FUIJEP020005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001DOol200000eYF
001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Ioo`<00003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06
001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00EWoo00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000EJEP03001JEUYF00=JEP04001JEUYF0004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00AJ
EPL000QJEP03001JEUYF00AJEP@00003FUH005YF00AJEP03001JEUYF008000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00?goo20003Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH03`0015YF
00<005YFFUH00UYF2P000eYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000cOol<0003FUH0
0`00FUIJEP02FUH?0005FUH00`00FUIJEP03FUH300001Goo001JEUYF00001UYF00@005YFFUIJEPT0
00QJEP06001JEP00001JEP000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0004FUH01000FUIJEUYF2P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<Goo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF00@005YFFUIJEP8000Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00D005YFFUIJEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF1`000UYF0`001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;goo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
1EYF00<005YFFUH00`0017oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH010001EYF10001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<007ooOol0;7oo000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00005FUH30003FUH300001Goo001JEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00UYF0P000UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
0P000UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P001EYF00@005YF0000009JEP03001J
EUYF00AJEP<000IJEP03001JEUYF00UJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF008000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEP00FUH0
000^Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYF0003FUH00`00FUH00005FUH01000FUIJEP000UYF00<005YFFUH00eYF
1@001EYF00<005YFFUH02EYF00<005YFFUH00eYF0P0000=JEP0000000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH5
0005FUH00`00FUIJEP09FUH00`00FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000IJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF008000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50005
FUH00`00FUIJEP09FUH01@00FUIJEUYF00000UYF00@005YF0000009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002eo
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP05001JEUYFFUIoo`04FUH00`00FUIJ
EP06FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF0`001UYF
00<005YFFUH02EYF00@005YF000000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70008
FUH80004FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF0P0000=JEP00FUH00UYF
00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP03001JEUYF00IJEP03001JEUYF00EJ
EPH000AJEP03001JEUYF008002eoo`00;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000UYF00D005YFFUIJEP0000EJEP04001JEUYF0002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20003FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00
FUIJEP04FUH00`00FUH000020004OolI0002Ool20002FUH00`00FUIJEP02000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH300000eYF001JEP04FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF0`001EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF0`0097oo0`000UYF0P00;Goo000/
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH00`00FUIJEP020005FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH01000FUIJEUYF0P00:Goo00D0
05YFFUIJEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF0`000UYF00@005YFFUH0009JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEP00008000=JEP03001JEUYF00AJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00D005YF000005YF00@002Moo`04001JEUYF000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP8000MJEP03001JEUYF00IJEP80009JEP03001JEUYF00=JEQ`000IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP<000EJEP<002Ioo`03001JEP0002eoo`00;7oo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF0P0025YF00<005YFFUH01UYF0P000UYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00@0
05YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002
FUH01@00FUIJEP00FUH00P001EYF00@005YFFUH000Uoo`<001Qoo`@002eoo`00;7oo00<005YF0000
15YF00@005YFFUIJEPX00003FUH005YF00MJEP03001JEUYF00IJEP@0009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUH00006
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
00000UYF0P001EYF00<005YFFUH00P001goo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YF
00000UYF1P000UYF10001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009J
EP8000=JEP8000AJEP80009JEP8000Moo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00FUH0
00020005FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF0P0015YF0P000UYF0P001goo1@0057oo00L005YFFUIJEP00FUH0
000]Ool002aoo`80009JEP03001JEUYF009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF0P000UYF0P0027oo0`004goo
0P0015YF00<005YF0000;Goo000/Ool20002FUH00`00FUIJEP020005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002FUH50002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH@0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF0P000UYF0P0077oo0P0000=J
EP00FUH015YF0P00;Goo000]Ool200000eYF001JEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUH000020002FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5
0005FUH00`00FUIJEP03FUH60004FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH00eYF00@005YF
FUIJEP8001Yoo`8000=JEP03001JEUYF00=JEP8002eoo`00;goo0`0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<005YFFUH00UYF0P0000=JEP00FUH0
1UYF00<005YFFUH015YF1@001EYF00<005YFFUH010001EYF0`0000=JEP00FUH00UYF0P000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`0000=J
EP00FUH015YF00@005YFFUIJEP8001Moo`<000EJEP03001JEUYF00=JEP03001oogoo02aoo`00;goo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPd0009JEP03001JEUYF00=JEPH0
00AJEP03001JEUYF00EJEP<000AJEPh0009JEP@0009JEP8000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH005YFFUH20005FUH01000FUIJEUYF0P00
4goo100000=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0;7oo000^Ool00`00FUIJEP02FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH60008FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YF
FUH00eYF200015YF00<005YFFUH0100000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP@0
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00=JEPH000=JEPP000Ioo`L000EJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo02ao
o`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF3@0015YF00<005YFFUH00UYF
1@000eYF00<005YFFUH01EYF00<005YFFUH00eYF1`001EYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00000030000eYF00<005YFFUH00UYF4@0000=JEP00FUH01UYF00D005YFFUIJ
EP0002moo`00;Goo0P001EYF00<005YFFUH00eYF00<005YF00000P003Goo2@001Goo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH000=JEP04001JEP00000`Ool002eoo`8000EJEP03001JEUYF00=JEP8002Aoo`X000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004000bOol002aoo`03
001JEP0000EJEP04001JEUYFFUH2000XOol01000FUIJEP000UYF00<005YF00007P0025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<0
035oo`00;7oo00<005YF00001EYF00@005YF000002]oo`03001JEP00009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool002aoo`04
001JEUYF0004FUH2000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
009JEQl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`04001J
EUYF0003FUH00`00Oomoo`0BOol3000HOol30002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH0100000=JEP0000000UYF0P001eYF00<005YFFUH01EYF1@000eYF200015YF00<005YF
FUH00eYF00D005YFFUIJEP0002ioo`00;7oo00D005YFFUH005YF008001Aoo`D001Ioo`04001JEP00
0002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0000=J
EP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF20000eYF00<005YFFUH00P00;Woo
000/Ool00`00FUIJEP02000FOol5000EOol00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH30006FUH00`00
FUH0000>0002FUH2000^Ool002eoo`03001JEP0001Moo`D001Aoo`04001JEUYFFUH20002FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01000
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH01000;Woo
000]Ool4000GOol3000COol30003FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH50004FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000]Ool20002FUH00`00Oomoo`0XOol20002FUH00`00FUIJEP02FUH01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool002eoo`04001JEUYFFUH2
000WOol20004FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH015YF
300000=JEP00FUH02EYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo1@0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`00;goo
000]Ool01P00FUIJEUYF001JEP<0029oo`8000IJEP03001JEUYF009JEP04001JEUYF0006FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000;Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Woo
000]Ool20002FUH00`00FUIJEP02FUH3000KOol400000eYF001JEP05FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YF000010001UYF00<005YFFUH00UYF0P003Goo00@005YFFUH0009ooaX003Qoo`00;Goo
0P000UYF8`001EYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001JEP00
00<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009J
EP03001JEUYF009JEP8000ioo`03001JEP0005Aoo`00;Woo0`000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200000=JEP00FUH01UYF00<005YFFUH00P000UYF
00<005YFFUH00eYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF100015YF0P003Woo0`00E7oo000]Ool20004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P000eYF00D005YF001o
o`00009JEP04001JEUYFFUH20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF00000eYF0P003Goo0P0000=JEP000000Dgoo
000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP050002Ool01@00FUIJEP00FUH00`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP0000002goo0P0000=JEP00FUH00P00Dgoo000/Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH3000017oo001JEUYF0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10002Woo00H005YF
FUIJEP00FUH2001COol002aoo`03001JEP0000=JEP04001JEUYFFUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01000FUH0000027oo0P0015YF00@005YFFUH005=oo`00;7oo00<005YF00000UYF
1@000UYF00<005YFFUH015YF00<005YFFUH01EYF400015YF00<005YFFUH00eYF00@005YFFUIJEP80
00EJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000006Ool200000eYF001JEP04FUH00`00
FUH0001COol002aoo`03001JEP000080009JEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPH000AJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP0017oo0P000eYF00<005YFFUH00eYF0P00E7oo000/Ool20002FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP02FUH20004Ool300000eYF
001JEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00Ool00`001EYF00<0
05YFFUH00eYF0P00E7oo000]Ool01000FUIJEP001EYF10001UYF00<005YFFUH01EYF0`001eYF00<0
05YF000020000UYF10000UYF0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P00
00=JEP00FUH01EYF00<005YFFUH00eYF00<007ooOol0Dgoo000^Ool30005FUH01000FUIJEUYF1000
0UYF00<005YFFUH01EYF00<005YFFUH00eYF1P001EYF00<005YFFUH00eYF00@005YFFUIJEP@000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo05=oo`00<7oo0`000eYF00<005YFFUH01EYF40000UYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF1@0000=JEP00FUH0
1UYF00D005YFFUIJEP0005Ioo`00<goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF0P000eYF1P000eYF00@005YF000005Moo`00>Woo2@0015YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`0017oo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJ
EP800003FUH005YF00IJEP03001JEP0000@005Uoo`00@goo7`002Goo0`001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000=J
EP03001JEUYF00EJEP03001JEUYF009JEP<005Qoo`00KWoo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000P00EGoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:0004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000EGoo001cOol40008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH50002FUH50003FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo001gOol60002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001eYF1@001EYF00<005YFFUH00eYF
1`000eYF00<005YFFUH00P00EGoo001mOolO0005FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP0?
00000eYF0000001EOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00@0009JEP03001JEUYF
00IJEP<0009JEPL000AJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol0091oo`@000AJEP03001J
EUYF00AJEQ0000=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3001EOol009Aoo`<0
0003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000EGoo002GOol50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03001FOol009aooa4000AJEP03001JEUYF00IJEP04
001JEUYFFUH6001IOol00:eooa4005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]67\[InvisibleSpace]"     "\
\[InvisibleSpace]15.548494759603141`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 67, "     ", 15.548494759603141, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5931 .75334 m .60094 .6992 L .57009 .69288 L p .707 .577 .707 r
F P
0 g
s
.60094 .6992 m .5931 .75334 L .62465 .75656 L p .707 .577 .707 r
F P
0 g
s
.62465 .75656 m .6325 .70242 L .60094 .6992 L p .707 .577 .707 r
F P
0 g
s
.6325 .70242 m .62797 .73363 L p .6538 .75634 L .707 .577 .707 r
F P
0 g
s
.65178 .75636 m .6538 .75634 L p .62797 .73363 L .707 .577 .707 r
F P
0 g
s
.6538 .75634 m .66165 .7022 L .6325 .70242 L p .707 .577 .707 r
F P
0 g
s
.66165 .7022 m .6538 .75634 L .66979 .75392 L p .707 .577 .707 r
F P
0 g
s
.67747 .75197 m .66165 .7022 L .66979 .75392 L .707 .577 .707 r
F
.68556 .69858 m .66165 .7022 L p .67727 .75134 L F P
0 g
s
.67747 .75197 m .67753 .75158 L .67727 .75134 L .707 .577 .707 r
F
.67753 .75158 m .68556 .69858 L .67727 .75134 L F
.67783 .75188 m .68556 .69858 L p .67747 .75197 L F P
0 g
s
.69991 .77044 m .68237 .74979 L .67783 .75188 L .707 .577 .707 r
F
.67783 .75188 m .68366 .7789 L .69818 .77134 L p F P
0 g
s
.69818 .77134 m .69991 .77044 L p .67783 .75188 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .67783 .75188 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.68556 .69858 m .67783 .75188 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.70188 .69192 m .68556 .69858 L p .69353 .74324 L .707 .577 .707 r
F P
0 g
s
.69376 .74456 m .69389 .74376 L .69353 .74324 L .707 .577 .707 r
F
.69389 .74376 m .70188 .69192 L .69353 .74324 L F
.69991 .77044 m .70711 .76317 L p .70635 .76169 L F P
0 g
s
.69428 .74433 m .70188 .69192 L p .69389 .74376 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69389 .74376 L .69376 .74456 L .707 .577 .707 r
F
.70101 .75123 m .70119 .73626 L .69629 .74198 L F
.70635 .76169 m .70128 .73669 L .70101 .75123 L F
.70128 .73669 m .70119 .73626 L .70101 .75123 L F
.70117 .73627 m .70119 .73544 L .69428 .74433 L F
.70188 .69192 m .69843 .7157 L p .70119 .73544 L F P
0 g
s
.69843 .7157 m .69428 .74433 L p .70119 .73544 L .707 .577 .707 r
F P
0 g
s
.70711 .76317 m .70699 .7626 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70699 .7626 m .70129 .73614 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70901 .68285 m .70188 .69192 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70901 .68285 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .69914 .72619 L p .70119 .73626 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70119 .73626 L .70635 .76169 L .707 .577 .707 r
F
.70116 .73699 m .70129 .73614 L p .70117 .73627 L F P
0 g
s
.70711 .76317 m .70455 .75778 L p .70324 .75011 L .707 .577 .707 r
F P
0 g
s
.70635 .76169 m .69629 .74198 L .69428 .74433 L .707 .577 .707 r
F
.69194 .73347 m .69428 .74433 L p .69629 .74198 L F P
0 g
s
.69428 .74433 m .69991 .77044 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.69991 .77044 m .69428 .74433 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .70102 .73717 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70102 .73717 m .70116 .73699 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70117 .73627 L .70093 .73661 L .707 .577 .707 r
F
.70119 .73626 m .69914 .72619 L .69629 .74198 L F
.69914 .72619 m .70129 .73614 L p .7005 .73413 L F P
0 g
s
.69914 .72619 m .69194 .73347 L p .69629 .74198 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69403 .74606 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70025 .73349 L p .70119 .73589 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .69914 .72619 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.70455 .75778 m .69816 .72813 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69816 .72813 m .69659 .7208 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69194 .73347 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .69428 .74433 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .69403 .74606 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67771 .75272 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .70455 .75778 L .69249 .75481 L p .707 .577 .707 r
F P
0 g
s
.70626 .67228 m .69841 .72642 L .69755 .72565 L p .707 .577 .707 r
F P
0 g
s
.69194 .73347 m .67569 .74192 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69249 .75481 m .68452 .71783 L .69659 .7208 L p .707 .577 .707 r
F P
0 g
s
.69755 .72565 m .68605 .71537 L p .69193 .70283 L .707 .577 .707 r
F P
0 g
s
.69193 .70283 m .70626 .67228 L .69755 .72565 L .707 .577 .707 r
F
.69841 .72642 m .70171 .71285 L .70119 .73589 L F
.70025 .73349 m .69841 .72642 L p .70119 .73589 L F P
0 g
s
.70129 .73614 m .70116 .73699 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.70324 .75011 m .7005 .73413 L .70129 .73614 L .707 .577 .707 r
F
.70129 .73614 m .70711 .76317 L p .70324 .75011 L F P
0 g
s
.70901 .68285 m .70129 .73614 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .67783 .75188 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .65198 .75073 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67569 .74192 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .67783 .75188 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.66979 .75392 m .67771 .75272 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .65873 .75674 L .65356 .75806 L .707 .577 .707 r
F
.65198 .75073 m .65356 .75806 L p .65873 .75674 L F P
0 g
s
.65356 .75806 m .65994 .7877 L .6777 .78111 L p .707 .577 .707 r
F P
0 g
s
.6777 .78111 m .68366 .7789 L p .65356 .75806 L .707 .577 .707 r
F P
0 g
s
.62797 .73363 m .62465 .75656 L .65178 .75636 L p .707 .577 .707 r
F P
0 g
s
.56224 .74702 m .57009 .69288 L .54295 .68407 L p .707 .577 .707 r
F P
0 g
s
.57009 .69288 m .56224 .74702 L .5931 .75334 L p .707 .577 .707 r
F P
0 g
s
.5351 .73821 m .54295 .68407 L .52218 .67363 L p .707 .577 .707 r
F P
0 g
s
.54295 .68407 m .5351 .73821 L .56224 .74702 L p .707 .577 .707 r
F P
0 g
s
.59992 .80296 m .59195 .76599 L .56152 .77095 L p .707 .577 .707 r
F P
0 g
s
.59195 .76599 m .59992 .80296 L .63109 .796 L p .707 .577 .707 r
F P
0 g
s
.63109 .796 m .62312 .75902 L .59195 .76599 L p .707 .577 .707 r
F P
0 g
s
.62312 .75902 m .63109 .796 L .65994 .7877 L p .707 .577 .707 r
F P
0 g
s
.65994 .7877 m .65198 .75073 L .62312 .75902 L p .707 .577 .707 r
F P
0 g
s
.56152 .77095 m .56948 .80792 L .59992 .80296 L p .707 .577 .707 r
F P
0 g
s
.56948 .80792 m .56152 .77095 L .5348 .77342 L p .707 .577 .707 r
F P
0 g
s
.5348 .77342 m .54276 .81039 L .56948 .80792 L p .707 .577 .707 r
F P
0 g
s
.52218 .67363 m .51433 .72777 L .5351 .73821 L p .707 .577 .707 r
F P
0 g
s
.59252 .85502 m .59462 .83685 L .56365 .83139 L p .707 .577 .707 r
F P
0 g
s
.59462 .83685 m .59252 .85502 L .62417 .85746 L p .707 .577 .707 r
F P
0 g
s
.62417 .85746 m .62627 .83928 L .59462 .83685 L p .707 .577 .707 r
F P
0 g
s
.51433 .72777 m .52218 .67363 L .50981 .66258 L p .707 .577 .707 r
F P
0 g
s
.62627 .83928 m .62417 .85746 L .65341 .85663 L p .707 .577 .707 r
F P
0 g
s
.65341 .85663 m .65551 .83845 L .62627 .83928 L p .707 .577 .707 r
F P
0 g
s
.56155 .84956 m .56365 .83139 L .5364 .82344 L p .707 .577 .707 r
F P
0 g
s
.56365 .83139 m .56155 .84956 L .59252 .85502 L p .707 .577 .707 r
F P
0 g
s
.54276 .81039 m .5348 .77342 L .51441 .77315 L p .707 .577 .707 r
F P
0 g
s
.5364 .82344 m .5343 .84161 L .56155 .84956 L p .707 .577 .707 r
F P
0 g
s
.51441 .77315 m .52238 .81013 L .54276 .81039 L p .707 .577 .707 r
F P
0 g
s
.65551 .83845 m .65341 .85663 L .67736 .85261 L p .707 .577 .707 r
F P
0 g
s
.67736 .85261 m .67947 .83444 L .65551 .83845 L p .707 .577 .707 r
F P
0 g
s
.50981 .66258 m .50196 .71672 L .51433 .72777 L p .707 .577 .707 r
F P
0 g
s
.5343 .84161 m .5364 .82344 L .51553 .81378 L p .707 .577 .707 r
F P
0 g
s
.51553 .81378 m .51342 .83195 L .5343 .84161 L p .707 .577 .707 r
F P
0 g
s
.50196 .71672 m .50981 .66258 L .50706 .652 L p .707 .577 .707 r
F P
0 g
s
.52238 .81013 m .51441 .77315 L .50235 .77018 L p .707 .577 .707 r
F P
0 g
s
.67947 .83444 m .67736 .85261 L .6937 .84581 L p .707 .577 .707 r
F P
0 g
s
.6937 .84581 m .6958 .82763 L .67947 .83444 L p .707 .577 .707 r
F P
0 g
s
.50235 .77018 m .51031 .80716 L .52238 .81013 L p .707 .577 .707 r
F P
0 g
s
.51342 .83195 m .51553 .81378 L .50308 .80334 L p .707 .577 .707 r
F P
0 g
s
.50706 .652 m .49921 .70614 L .50196 .71672 L p .707 .577 .707 r
F P
0 g
s
.50308 .80334 m .50098 .82152 L .51342 .83195 L p .707 .577 .707 r
F P
0 g
s
.69841 .72642 m .70626 .67228 L .70901 .68285 L p .707 .577 .707 r
F P
0 g
s
.49921 .70614 m .50706 .652 L .51419 .64294 L p .707 .577 .707 r
F P
0 g
s
.51031 .80716 m .50235 .77018 L .49979 .7648 L p .707 .577 .707 r
F P
0 g
s
.49321 .82176 m .48908 .31945 L .44507 .31713 L p .707 .577 .707 r
F P
0 g
s
.49979 .7648 m .50775 .80177 L .51031 .80716 L p .707 .577 .707 r
F P
0 g
s
.50098 .82152 m .50308 .80334 L .50028 .79317 L p .707 .577 .707 r
F P
0 g
s
.50028 .79317 m .49817 .81134 L .50098 .82152 L p .707 .577 .707 r
F P
0 g
s
.51419 .64294 m .50635 .69708 L .49921 .70614 L p .707 .577 .707 r
F P
0 g
s
.50635 .69708 m .51419 .64294 L .53051 .63627 L p .707 .577 .707 r
F P
0 g
s
.50775 .80177 m .49979 .7648 L .50699 .75752 L p .707 .577 .707 r
F P
0 g
s
.50699 .75752 m .51495 .79449 L .50775 .80177 L p .707 .577 .707 r
F P
0 g
s
.49817 .81134 m .50028 .79317 L .50739 .78424 L p .707 .577 .707 r
F P
0 g
s
.50739 .78424 m .50529 .80241 L .49817 .81134 L p .707 .577 .707 r
F P
0 g
s
.53051 .63627 m .52266 .69041 L .50635 .69708 L p .707 .577 .707 r
F P
0 g
s
.52266 .69041 m .53051 .63627 L .55442 .63265 L p .707 .577 .707 r
F P
0 g
s
.51495 .79449 m .50699 .75752 L .52324 .74906 L p .707 .577 .707 r
F P
0 g
s
.52324 .74906 m .53121 .78604 L .51495 .79449 L p .707 .577 .707 r
F P
0 g
s
.50529 .80241 m .50739 .78424 L .52373 .77743 L p .707 .577 .707 r
F P
0 g
s
.55442 .63265 m .54657 .68679 L .52266 .69041 L p .707 .577 .707 r
F P
0 g
s
.52373 .77743 m .52163 .79561 L .50529 .80241 L p .707 .577 .707 r
F P
0 g
s
.53121 .78604 m .52324 .74906 L .54696 .74026 L p .707 .577 .707 r
F P
0 g
s
.54696 .74026 m .55492 .77724 L .53121 .78604 L p .707 .577 .707 r
F P
0 g
s
.52163 .79561 m .52373 .77743 L .54769 .77342 L p .707 .577 .707 r
F P
0 g
s
.54769 .77342 m .54559 .79159 L .52163 .79561 L p .707 .577 .707 r
F P
0 g
s
.48908 .31945 m .49321 .82176 L .53815 .82033 L p .707 .577 .707 r
F P
0 g
s
.53815 .82033 m .53402 .31802 L .48908 .31945 L p .707 .577 .707 r
F P
0 g
s
.6958 .82763 m .6937 .84581 L .70082 .83688 L p .707 .577 .707 r
F P
0 g
s
.70082 .83688 m .70292 .81871 L .6958 .82763 L p .707 .577 .707 r
F P
0 g
s
.54657 .68679 m .55442 .63265 L .58358 .63244 L p .707 .577 .707 r
F P
0 g
s
.58358 .63244 m .57573 .68658 L .54657 .68679 L p .707 .577 .707 r
F P
0 g
s
.55492 .77724 m .54696 .74026 L .57581 .73197 L p .707 .577 .707 r
F P
0 g
s
.57581 .73197 m .58377 .76894 L .55492 .77724 L p .707 .577 .707 r
F P
0 g
s
.54559 .79159 m .54769 .77342 L .57692 .77259 L p .707 .577 .707 r
F P
0 g
s
.57692 .77259 m .57482 .79076 L .54559 .79159 L p .707 .577 .707 r
F P
0 g
s
.57482 .79076 m .57692 .77259 L .60858 .77502 L p .707 .577 .707 r
F P
0 g
s
.60858 .77502 m .60647 .79319 L .57482 .79076 L p .707 .577 .707 r
F P
0 g
s
.53402 .31802 m .53815 .82033 L .57963 .8153 L p .707 .577 .707 r
F P
0 g
s
.57573 .68658 m .58358 .63244 L .61513 .63565 L p .707 .577 .707 r
F P
0 g
s
.61513 .63565 m .60728 .68979 L .57573 .68658 L p .707 .577 .707 r
F P
0 g
s
.58377 .76894 m .57581 .73197 L .60698 .725 L p .707 .577 .707 r
F P
0 g
s
.57963 .8153 m .5755 .31298 L .53402 .31802 L p .707 .577 .707 r
F P
0 g
s
.4492 .81944 m .44507 .31713 L .40631 .3113 L p .707 .577 .707 r
F P
0 g
s
.44507 .31713 m .4492 .81944 L .49321 .82176 L p .707 .577 .707 r
F P
0 g
s
.61494 .76198 m .60698 .725 L .63741 .72004 L p .707 .577 .707 r
F P
0 g
s
.60698 .725 m .61494 .76198 L .58377 .76894 L p .707 .577 .707 r
F P
0 g
s
.63954 .78048 m .63744 .79865 L .60647 .79319 L p .707 .577 .707 r
F P
0 g
s
.60647 .79319 m .60858 .77502 L .63954 .78048 L p .707 .577 .707 r
F P
0 g
s
.5755 .31298 m .57963 .8153 L .61359 .80715 L p .707 .577 .707 r
F P
0 g
s
.64598 .64197 m .63813 .69611 L .60728 .68979 L p .707 .577 .707 r
F P
0 g
s
.60728 .68979 m .61513 .63565 L .64598 .64197 L p .707 .577 .707 r
F P
0 g
s
.61359 .80715 m .60946 .30484 L .5755 .31298 L p .707 .577 .707 r
F P
0 g
s
.68605 .71537 m .69389 .66123 L .70626 .67228 L p .707 .577 .707 r
F P
0 g
s
.25009 .71649 m .25794 .66235 L .22708 .65603 L p .707 .577 .707 r
F P
0 g
s
.25794 .66235 m .25009 .71649 L .28164 .7197 L p .707 .577 .707 r
F P
0 g
s
.28164 .7197 m .28949 .66556 L .25794 .66235 L p .707 .577 .707 r
F P
0 g
s
.41044 .81361 m .40631 .3113 L .37659 .30252 L p .707 .577 .707 r
F P
0 g
s
.40631 .3113 m .41044 .81361 L .4492 .81944 L p .707 .577 .707 r
F P
0 g
s
.70292 .81871 m .70082 .83688 L .69801 .8267 L p .707 .577 .707 r
F P
0 g
s
.69801 .8267 m .70012 .80853 L .70292 .81871 L p .707 .577 .707 r
F P
0 g
s
.28949 .66556 m .28495 .69686 L p .31079 .71949 L .707 .577 .707 r
F P
0 g
s
.30867 .71951 m .31079 .71949 L p .28495 .69686 L .707 .577 .707 r
F P
0 g
s
.31079 .71949 m .31864 .66535 L .28949 .66556 L p .707 .577 .707 r
F P
0 g
s
.31864 .66535 m .31079 .71949 L .32757 .71695 L p .707 .577 .707 r
F P
0 g
s
.33449 .71519 m .31864 .66535 L .32757 .71695 L .707 .577 .707 r
F
.34255 .66173 m .31864 .66535 L p .3343 .71462 L F P
0 g
s
.33449 .71519 m .33454 .71485 L .3343 .71462 L .707 .577 .707 r
F
.33454 .71485 m .34255 .66173 L .3343 .71462 L F
.33481 .71511 m .34255 .66173 L p .33449 .71519 L F P
0 g
s
.3569 .73373 m .33933 .71304 L .33481 .71511 L .707 .577 .707 r
F
.33481 .71511 m .34065 .74219 L .3552 .73462 L p F P
0 g
s
.3552 .73462 m .3569 .73373 L p .33481 .71511 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .33481 .71511 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.34255 .66173 m .33481 .71511 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35887 .65507 m .34255 .66173 L p .35054 .70653 L .707 .577 .707 r
F P
0 g
s
.35077 .70778 m .35089 .70702 L .35054 .70653 L .707 .577 .707 r
F
.35089 .70702 m .35887 .65507 L .35054 .70653 L F
.3569 .73373 m .3641 .72646 L p .36327 .72484 L F P
0 g
s
.35126 .70756 m .35887 .65507 L p .35089 .70702 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35089 .70702 L .35077 .70778 L .707 .577 .707 r
F
.35799 .71449 m .35816 .6995 L .35326 .70523 L F
.36327 .72484 m .35825 .69998 L .35799 .71449 L F
.35825 .69998 m .35816 .6995 L .35799 .71449 L F
.35816 .69949 m .35818 .69874 L .35126 .70756 L F
.35887 .65507 m .35541 .67893 L p .35818 .69874 L F P
0 g
s
.35541 .67893 m .35126 .70756 L p .35818 .69874 L .707 .577 .707 r
F P
0 g
s
.36345 .7251 m .36323 .72462 L .36327 .72484 L .707 .577 .707 r
F
.36396 .72583 m .36323 .72462 L .36345 .7251 L F
.366 .646 m .35887 .65507 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .35816 .6995 L .36323 .72462 L .707 .577 .707 r
F
.35815 .70014 m .35827 .69938 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .366 .646 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.36396 .72583 m .35827 .69938 L p .36323 .72462 L .707 .577 .707 r
F P
0 g
s
.35827 .69938 m .35613 .68948 L p .35816 .6995 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36396 .72583 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36154 .72107 L p .3602 .71326 L .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .35126 .70756 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .3569 .73373 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3569 .73373 m .35126 .70756 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35799 .70035 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35799 .70035 m .35815 .70014 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35816 .69949 L .35791 .69984 L .707 .577 .707 r
F
.35816 .6995 m .35613 .68948 L .35326 .70523 L F
.35613 .68948 m .35827 .69938 L p .35749 .69737 L F P
0 g
s
.35613 .68948 m .34893 .69676 L p .35326 .70523 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35102 .70921 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35733 .69699 L p .35818 .69915 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .35613 .68948 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.36154 .72107 m .35514 .69136 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35514 .69136 m .35358 .68409 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .34893 .69676 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35126 .70756 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .35102 .70921 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .3347 .71587 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .36154 .72107 L .34948 .7181 L p .707 .577 .707 r
F P
0 g
s
.36325 .63543 m .3554 .68957 L .3545 .68876 L p .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .33268 .70521 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.34948 .7181 m .34151 .68112 L .35358 .68409 L p .707 .577 .707 r
F P
0 g
s
.3545 .68876 m .34304 .67852 L p .3489 .66602 L .707 .577 .707 r
F P
0 g
s
.3489 .66602 m .36325 .63543 L .3545 .68876 L .707 .577 .707 r
F
.3554 .68957 m .35869 .67604 L .35818 .69915 L F
.35733 .69699 m .3554 .68957 L p .35818 .69915 L F P
0 g
s
.35827 .69938 m .35815 .70014 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.3602 .71326 m .35749 .69737 L .35827 .69938 L .707 .577 .707 r
F
.35827 .69938 m .3641 .72646 L p .3602 .71326 L F P
0 g
s
.366 .646 m .35827 .69938 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .33481 .71511 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .30897 .71402 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .33268 .70521 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .33481 .71511 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.32757 .71695 m .3347 .71587 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .31567 .71998 L .31053 .72129 L .707 .577 .707 r
F
.30897 .71402 m .31053 .72129 L p .31567 .71998 L F P
0 g
s
.31053 .72129 m .31693 .75099 L .33473 .74439 L p .707 .577 .707 r
F P
0 g
s
.33473 .74439 m .34065 .74219 L p .31053 .72129 L .707 .577 .707 r
F P
0 g
s
.28495 .69686 m .28164 .7197 L .30867 .71951 L p .707 .577 .707 r
F P
0 g
s
.21923 .71017 m .22708 .65603 L .19994 .64722 L p .707 .577 .707 r
F P
0 g
s
.22708 .65603 m .21923 .71017 L .25009 .71649 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69389 .66123 m .68605 .71537 L .66528 .70493 L p .707 .577 .707 r
F P
0 g
s
.66528 .70493 m .67312 .65079 L .69389 .66123 L p .707 .577 .707 r
F P
0 g
s
.63741 .72004 m .64538 .75701 L .61494 .76198 L p .707 .577 .707 r
F P
0 g
s
.60946 .30484 m .61359 .80715 L .6367 .79669 L p .707 .577 .707 r
F P
0 g
s
.6367 .79669 m .63257 .29438 L .60946 .30484 L p .707 .577 .707 r
F P
0 g
s
.19209 .70136 m .19994 .64722 L .17917 .63677 L p .707 .577 .707 r
F P
0 g
s
.19994 .64722 m .19209 .70136 L .21923 .71017 L p .707 .577 .707 r
F P
0 g
s
.25691 .76625 m .24895 .72928 L .21851 .73424 L p .707 .577 .707 r
F P
0 g
s
.24895 .72928 m .25691 .76625 L .28808 .75928 L p .707 .577 .707 r
F P
0 g
s
.28808 .75928 m .28011 .72231 L .24895 .72928 L p .707 .577 .707 r
F P
0 g
s
.28011 .72231 m .28808 .75928 L .31693 .75099 L p .707 .577 .707 r
F P
0 g
s
.31693 .75099 m .30897 .71402 L .28011 .72231 L p .707 .577 .707 r
F P
0 g
s
.21851 .73424 m .22648 .77121 L .25691 .76625 L p .707 .577 .707 r
F P
0 g
s
.22648 .77121 m .21851 .73424 L .19179 .73671 L p .707 .577 .707 r
F P
0 g
s
.70012 .80853 m .69801 .8267 L .68557 .81627 L p .707 .577 .707 r
F P
0 g
s
.68557 .81627 m .68767 .7981 L .70012 .80853 L p .707 .577 .707 r
F P
0 g
s
.38072 .80483 m .37659 .30252 L .35881 .29165 L p .707 .577 .707 r
F P
0 g
s
.37659 .30252 m .38072 .80483 L .41044 .81361 L p .707 .577 .707 r
F P
0 g
s
.19179 .73671 m .19976 .77368 L .22648 .77121 L p .707 .577 .707 r
F P
0 g
s
.17917 .63677 m .17132 .69091 L .19209 .70136 L p .707 .577 .707 r
F P
0 g
s
.68452 .71783 m .69249 .75481 L .6721 .75454 L p .707 .577 .707 r
F P
0 g
s
.6721 .75454 m .66413 .71757 L .68452 .71783 L p .707 .577 .707 r
F P
0 g
s
.24951 .81781 m .25161 .79963 L .22064 .79417 L p .707 .577 .707 r
F P
0 g
s
.25161 .79963 m .24951 .81781 L .28116 .82024 L p .707 .577 .707 r
F P
0 g
s
.28116 .82024 m .28326 .80207 L .25161 .79963 L p .707 .577 .707 r
F P
0 g
s
.67312 .65079 m .66528 .70493 L .63813 .69611 L p .707 .577 .707 r
F P
0 g
s
.63813 .69611 m .64598 .64197 L .67312 .65079 L p .707 .577 .707 r
F P
0 g
s
.17132 .69091 m .17917 .63677 L .1668 .62572 L p .707 .577 .707 r
F P
0 g
s
.28326 .80207 m .28116 .82024 L .3104 .81941 L p .707 .577 .707 r
F P
0 g
s
.3104 .81941 m .3125 .80123 L .28326 .80207 L p .707 .577 .707 r
F P
0 g
s
.21854 .81235 m .22064 .79417 L .19339 .78622 L p .707 .577 .707 r
F P
0 g
s
.22064 .79417 m .21854 .81235 L .24951 .81781 L p .707 .577 .707 r
F P
0 g
s
.19976 .77368 m .19179 .73671 L .1714 .73644 L p .707 .577 .707 r
F P
0 g
s
.19339 .78622 m .19129 .80439 L .21854 .81235 L p .707 .577 .707 r
F P
0 g
s
.1714 .73644 m .17937 .77342 L .19976 .77368 L p .707 .577 .707 r
F P
0 g
s
.66413 .71757 m .6721 .75454 L .64538 .75701 L p .707 .577 .707 r
F P
0 g
s
.64538 .75701 m .63741 .72004 L .66413 .71757 L p .707 .577 .707 r
F P
0 g
s
.63744 .79865 m .63954 .78048 L .6668 .78843 L p .707 .577 .707 r
F P
0 g
s
.63257 .29438 m .6367 .79669 L .6467 .78494 L p .707 .577 .707 r
F P
0 g
s
.6467 .78494 m .64257 .28263 L .63257 .29438 L p .707 .577 .707 r
F P
0 g
s
.3125 .80123 m .3104 .81941 L .33436 .81539 L p .707 .577 .707 r
F P
0 g
s
.33436 .81539 m .33646 .79722 L .3125 .80123 L p .707 .577 .707 r
F P
0 g
s
.1668 .62572 m .15895 .67987 L .17132 .69091 L p .707 .577 .707 r
F P
0 g
s
.68767 .7981 m .68557 .81627 L .6647 .8066 L p .707 .577 .707 r
F P
0 g
s
.6647 .8066 m .6668 .78843 L .68767 .7981 L p .707 .577 .707 r
F P
0 g
s
.19129 .80439 m .19339 .78622 L .17252 .77656 L p .707 .577 .707 r
F P
0 g
s
.17252 .77656 m .17041 .79473 L .19129 .80439 L p .707 .577 .707 r
F P
0 g
s
.15895 .67987 m .1668 .62572 L .16405 .61515 L p .707 .577 .707 r
F P
0 g
s
.17937 .77342 m .1714 .73644 L .15934 .73347 L p .707 .577 .707 r
F P
0 g
s
.3554 .68957 m .36325 .63543 L .366 .646 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .36325 .63543 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34304 .67852 m .34488 .66583 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34488 .66583 m .35088 .62438 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.36294 .79396 m .35881 .29165 L .35472 .27976 L p .707 .577 .707 r
F P
0 g
s
.35881 .29165 m .36294 .79396 L .38072 .80483 L p .707 .577 .707 r
F P
0 g
s
.35781 .79966 m .35991 .78149 L .3528 .79042 L p .707 .577 .707 r
F P
0 g
s
.35991 .78149 m .35781 .79966 L .35501 .78948 L p .707 .577 .707 r
F P
0 g
s
.35501 .78948 m .35711 .77131 L .35991 .78149 L p .707 .577 .707 r
F P
0 g
s
.35472 .27976 m .35885 .78207 L .36294 .79396 L p .707 .577 .707 r
F P
0 g
s
.35885 .78207 m .35529 .34893 L p .36472 .26801 L .707 .577 .707 r
F P
0 g
s
.35529 .34893 m .35472 .27976 L .35768 .27628 L p .707 .577 .707 r
F P
0 g
s
.35768 .27628 m .36472 .26801 L p .35529 .34893 L .707 .577 .707 r
F P
0 g
s
.33646 .79722 m .33436 .81539 L .35069 .80859 L p .707 .577 .707 r
F P
0 g
s
.35069 .80859 m .3528 .79042 L .33646 .79722 L p .707 .577 .707 r
F P
0 g
s
.15934 .73347 m .1673 .77045 L .17937 .77342 L p .707 .577 .707 r
F P
0 g
s
.6668 .78843 m .6647 .8066 L .63744 .79865 L p .707 .577 .707 r
F P
0 g
s
.17041 .79473 m .17252 .77656 L .16007 .76613 L p .707 .577 .707 r
F P
0 g
s
.16405 .61515 m .1562 .66929 L .15895 .67987 L p .707 .577 .707 r
F P
0 g
s
.16007 .76613 m .15797 .7843 L .17041 .79473 L p .707 .577 .707 r
F P
0 g
s
.1562 .66929 m .16405 .61515 L .17118 .60609 L p .707 .577 .707 r
F P
0 g
s
.64257 .28263 m .6467 .78494 L .64261 .77305 L p .707 .577 .707 r
F P
0 g
s
.64261 .77305 m .63848 .27074 L .64257 .28263 L p .707 .577 .707 r
F P
0 g
s
.1673 .77045 m .15934 .73347 L .15678 .72808 L p .707 .577 .707 r
F P
0 g
s
.3528 .79042 m .35069 .80859 L .35781 .79966 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15678 .72808 m .16474 .76506 L .1673 .77045 L p .707 .577 .707 r
F P
0 g
s
.15797 .7843 m .16007 .76613 L .15727 .75595 L p .707 .577 .707 r
F P
0 g
s
.15727 .75595 m .15516 .77412 L .15797 .7843 L p .707 .577 .707 r
F P
0 g
s
.17118 .60609 m .16334 .66023 L .1562 .66929 L p .707 .577 .707 r
F P
0 g
s
.16334 .66023 m .17118 .60609 L .1875 .59942 L p .707 .577 .707 r
F P
0 g
s
.16474 .76506 m .15678 .72808 L .16398 .72081 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16398 .72081 m .17194 .75778 L .16474 .76506 L p .707 .577 .707 r
F P
0 g
s
.15516 .77412 m .15727 .75595 L .16438 .74702 L p .707 .577 .707 r
F P
0 g
s
.63848 .27074 m .64261 .77305 L .62483 .76219 L p .707 .577 .707 r
F P
0 g
s
.62483 .76219 m .6207 .25987 L .63848 .27074 L p .707 .577 .707 r
F P
0 g
s
.16438 .74702 m .16228 .76519 L .15516 .77412 L p .707 .577 .707 r
F P
0 g
s
.1875 .59942 m .17966 .65356 L .16334 .66023 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .34304 .67852 L .32227 .66807 L p .707 .577 .707 r
F P
0 g
s
.32227 .66807 m .33011 .61393 L .35088 .62438 L p .707 .577 .707 r
F P
0 g
s
.17966 .65356 m .1875 .59942 L .21141 .5958 L p .707 .577 .707 r
F P
0 g
s
.36885 .77032 m .36472 .26801 L .38783 .25755 L p .707 .577 .707 r
F P
0 g
s
.36472 .26801 m .36885 .77032 L .35885 .78207 L p .707 .577 .707 r
F P
0 g
s
.17194 .75778 m .16398 .72081 L .18023 .71235 L p .707 .577 .707 r
F P
0 g
s
.35711 .77131 m .35501 .78948 L .34256 .77905 L p .707 .577 .707 r
F P
0 g
s
.34256 .77905 m .34466 .76088 L .35711 .77131 L p .707 .577 .707 r
F P
0 g
s
.18023 .71235 m .1882 .74933 L .17194 .75778 L p .707 .577 .707 r
F P
0 g
s
.16228 .76519 m .16438 .74702 L .18072 .74022 L p .707 .577 .707 r
F P
0 g
s
.34151 .68112 m .34948 .7181 L .32909 .71783 L p .707 .577 .707 r
F P
0 g
s
.32909 .71783 m .32112 .68086 L .34151 .68112 L p .707 .577 .707 r
F P
0 g
s
.33011 .61393 m .32227 .66807 L .29512 .65926 L p .707 .577 .707 r
F P
0 g
s
.29512 .65926 m .30297 .60512 L .33011 .61393 L p .707 .577 .707 r
F P
0 g
s
.21141 .5958 m .20356 .64994 L .17966 .65356 L p .707 .577 .707 r
F P
0 g
s
.20356 .64994 m .21141 .5958 L .24057 .59559 L p .707 .577 .707 r
F P
0 g
s
.18072 .74022 m .17862 .75839 L .16228 .76519 L p .707 .577 .707 r
F P
0 g
s
.6207 .25987 m .62483 .76219 L .59511 .7534 L p .707 .577 .707 r
F P
0 g
s
.59511 .7534 m .59098 .25109 L .6207 .25987 L p .707 .577 .707 r
F P
0 g
s
.30297 .60512 m .29512 .65926 L .26427 .65294 L p .707 .577 .707 r
F P
0 g
s
.26427 .65294 m .27212 .5988 L .30297 .60512 L p .707 .577 .707 r
F P
0 g
s
.23272 .64973 m .24057 .59559 L .27212 .5988 L p .707 .577 .707 r
F P
0 g
s
.24057 .59559 m .23272 .64973 L .20356 .64994 L p .707 .577 .707 r
F P
0 g
s
.1882 .74933 m .18023 .71235 L .20395 .70355 L p .707 .577 .707 r
F P
0 g
s
.34466 .76088 m .34256 .77905 L .32169 .76939 L p .707 .577 .707 r
F P
0 g
s
.32169 .76939 m .32379 .75121 L .34466 .76088 L p .707 .577 .707 r
F P
0 g
s
.27212 .5988 m .26427 .65294 L .23272 .64973 L p .707 .577 .707 r
F P
0 g
s
.32112 .68086 m .32909 .71783 L .30237 .7203 L p .707 .577 .707 r
F P
0 g
s
.30237 .7203 m .2944 .68333 L .32112 .68086 L p .707 .577 .707 r
F P
0 g
s
.20395 .70355 m .21191 .74053 L .1882 .74933 L p .707 .577 .707 r
F P
0 g
s
.17862 .75839 m .18072 .74022 L .20468 .7362 L p .707 .577 .707 r
F P
0 g
s
.7303 .66131 m .73815 .60717 L .70729 .60084 L p .707 .577 .707 r
F P
0 g
s
.73815 .60717 m .7303 .66131 L .76185 .66452 L p .707 .577 .707 r
F P
0 g
s
.76185 .66452 m .7697 .61038 L .73815 .60717 L p .707 .577 .707 r
F P
0 g
s
.38783 .25755 m .39196 .75986 L .36885 .77032 L p .707 .577 .707 r
F P
0 g
s
.39196 .75986 m .38783 .25755 L .42179 .2494 L p .707 .577 .707 r
F P
0 g
s
.7697 .61038 m .76517 .64159 L p .79101 .6643 L .707 .577 .707 r
F P
0 g
s
.78898 .66432 m .79101 .6643 L p .76517 .64159 L .707 .577 .707 r
F P
0 g
s
.79101 .6643 m .79886 .61016 L .7697 .61038 L p .707 .577 .707 r
F P
0 g
s
.79886 .61016 m .79101 .6643 L .807 .66188 L p .707 .577 .707 r
F P
0 g
s
.81468 .65993 m .79886 .61016 L .807 .66188 L .707 .577 .707 r
F
.82276 .60655 m .79886 .61016 L p .81447 .6593 L F P
0 g
s
.81468 .65993 m .81473 .65955 L .81447 .6593 L .707 .577 .707 r
F
.81473 .65955 m .82276 .60655 L .81447 .6593 L F
.81504 .65984 m .82276 .60655 L p .81468 .65993 L F P
0 g
s
.83711 .67841 m .81958 .65775 L .81504 .65984 L .707 .577 .707 r
F
.81504 .65984 m .82086 .68686 L .83539 .6793 L p F P
0 g
s
.83539 .6793 m .83711 .67841 L p .81504 .65984 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .81504 .65984 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.82276 .60655 m .81504 .65984 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83908 .59988 m .82276 .60655 L p .83073 .6512 L .707 .577 .707 r
F P
0 g
s
.83097 .65253 m .83109 .65172 L .83073 .6512 L .707 .577 .707 r
F
.83109 .65172 m .83908 .59988 L .83073 .6512 L F
.83711 .67841 m .84431 .67113 L p .84356 .66966 L F P
0 g
s
.83149 .65229 m .83908 .59988 L p .83109 .65172 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83109 .65172 L .83097 .65253 L .707 .577 .707 r
F
.83821 .65919 m .83839 .64422 L .83349 .64994 L F
.84356 .66966 m .83848 .64466 L .83821 .65919 L F
.83848 .64466 m .83839 .64422 L .83821 .65919 L F
.83838 .64424 m .83839 .6434 L .83149 .65229 L F
.83908 .59988 m .83564 .62366 L p .83839 .6434 L F P
0 g
s
.83564 .62366 m .83149 .65229 L p .83839 .6434 L .707 .577 .707 r
F P
0 g
s
.84431 .67113 m .84419 .67056 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84419 .67056 m .83849 .64411 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84622 .59081 m .83908 .59988 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .84622 .59081 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83635 .63415 L p .83839 .64422 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83839 .64422 L .84356 .66966 L .707 .577 .707 r
F
.83837 .64495 m .83849 .64411 L p .83838 .64424 L F P
0 g
s
.84431 .67113 m .84176 .66574 L p .84044 .65807 L .707 .577 .707 r
F P
0 g
s
.84356 .66966 m .83349 .64994 L .83149 .65229 L .707 .577 .707 r
F
.82915 .64143 m .83149 .65229 L p .83349 .64994 L F P
0 g
s
.83149 .65229 m .83711 .67841 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.83711 .67841 m .83149 .65229 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83823 .64513 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83823 .64513 m .83837 .64495 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83838 .64424 L .83813 .64458 L .707 .577 .707 r
F
.83839 .64422 m .83635 .63415 L .83349 .64994 L F
.83635 .63415 m .83849 .64411 L p .83771 .64209 L F P
0 g
s
.83635 .63415 m .82915 .64143 L p .83349 .64994 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83124 .65402 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83746 .64145 L p .83839 .64385 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .83635 .63415 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.84176 .66574 m .83537 .63609 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83537 .63609 m .83379 .62876 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .82915 .64143 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83149 .65229 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .83124 .65402 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .81492 .66069 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .84176 .66574 L .82969 .66277 L p .707 .577 .707 r
F P
0 g
s
.84346 .58024 m .83562 .63438 L .83476 .63361 L p .707 .577 .707 r
F P
0 g
s
.82915 .64143 m .8129 .64988 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.82969 .66277 m .82173 .62579 L .83379 .62876 L p .707 .577 .707 r
F P
0 g
s
.83476 .63361 m .82325 .62333 L p .82913 .61079 L .707 .577 .707 r
F P
0 g
s
.82913 .61079 m .84346 .58024 L .83476 .63361 L .707 .577 .707 r
F
.83562 .63438 m .83892 .62081 L .83839 .64385 L F
.83746 .64145 m .83562 .63438 L p .83839 .64385 L F P
0 g
s
.83849 .64411 m .83837 .64495 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.84044 .65807 m .83771 .64209 L .83849 .64411 L .707 .577 .707 r
F
.83849 .64411 m .84431 .67113 L p .84044 .65807 L F P
0 g
s
.84622 .59081 m .83849 .64411 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .81504 .65984 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .78918 .65869 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .8129 .64988 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .81504 .65984 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.807 .66188 m .81492 .66069 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .79594 .6647 L .79076 .66602 L .707 .577 .707 r
F
.78918 .65869 m .79076 .66602 L p .79594 .6647 L F P
0 g
s
.79076 .66602 m .79715 .69567 L .81491 .68907 L p .707 .577 .707 r
F P
0 g
s
.81491 .68907 m .82086 .68686 L p .79076 .66602 L .707 .577 .707 r
F P
0 g
s
.76517 .64159 m .76185 .66452 L .78898 .66432 L p .707 .577 .707 r
F P
0 g
s
.20468 .7362 m .20258 .75437 L .17862 .75839 L p .707 .577 .707 r
F P
0 g
s
.69945 .65498 m .70729 .60084 L .68015 .59203 L p .707 .577 .707 r
F P
0 g
s
.70729 .60084 m .69945 .65498 L .7303 .66131 L p .707 .577 .707 r
F P
0 g
s
.21191 .74053 m .20395 .70355 L .2328 .69526 L p .707 .577 .707 r
F P
0 g
s
.2944 .68333 m .30237 .7203 L .27193 .72527 L p .707 .577 .707 r
F P
0 g
s
.27193 .72527 m .26397 .68829 L .2944 .68333 L p .707 .577 .707 r
F P
0 g
s
.32379 .75121 m .32169 .76939 L .29443 .76144 L p .707 .577 .707 r
F P
0 g
s
.29443 .76144 m .29653 .74326 L .32379 .75121 L p .707 .577 .707 r
F P
0 g
s
.59098 .25109 m .59511 .7534 L .55635 .74757 L p .707 .577 .707 r
F P
0 g
s
.55635 .74757 m .55221 .24526 L .59098 .25109 L p .707 .577 .707 r
F P
0 g
s
.2328 .69526 m .24076 .73223 L .21191 .74053 L p .707 .577 .707 r
F P
0 g
s
.6723 .64617 m .68015 .59203 L .65938 .58159 L p .707 .577 .707 r
F P
0 g
s
.68015 .59203 m .6723 .64617 L .69945 .65498 L p .707 .577 .707 r
F P
0 g
s
.20258 .75437 m .20468 .7362 L .23391 .73537 L p .707 .577 .707 r
F P
0 g
s
.73712 .71092 m .72916 .67395 L .69872 .67891 L p .707 .577 .707 r
F P
0 g
s
.72916 .67395 m .73712 .71092 L .76829 .70396 L p .707 .577 .707 r
F P
0 g
s
.76829 .70396 m .76033 .66698 L .72916 .67395 L p .707 .577 .707 r
F P
0 g
s
.24076 .73223 m .2328 .69526 L .26397 .68829 L p .707 .577 .707 r
F P
0 g
s
.76033 .66698 m .76829 .70396 L .79715 .69567 L p .707 .577 .707 r
F P
0 g
s
.79715 .69567 m .78918 .65869 L .76033 .66698 L p .707 .577 .707 r
F P
0 g
s
.26397 .68829 m .27193 .72527 L .24076 .73223 L p .707 .577 .707 r
F P
0 g
s
.23391 .73537 m .23181 .75354 L .20258 .75437 L p .707 .577 .707 r
F P
0 g
s
.42592 .75172 m .42179 .2494 L .46327 .24437 L p .707 .577 .707 r
F P
0 g
s
.42179 .2494 m .42592 .75172 L .39196 .75986 L p .707 .577 .707 r
F P
0 g
s
.69872 .67891 m .70669 .71589 L .73712 .71092 L p .707 .577 .707 r
F P
0 g
s
.70669 .71589 m .69872 .67891 L .672 .68138 L p .707 .577 .707 r
F P
0 g
s
.29653 .74326 m .29443 .76144 L .26346 .75598 L p .707 .577 .707 r
F P
0 g
s
.26346 .75598 m .26557 .7378 L .29653 .74326 L p .707 .577 .707 r
F P
0 g
s
.23181 .75354 m .23391 .73537 L .26557 .7378 L p .707 .577 .707 r
F P
0 g
s
.26557 .7378 m .26346 .75598 L .23181 .75354 L p .707 .577 .707 r
F P
0 g
s
.672 .68138 m .67997 .71836 L .70669 .71589 L p .707 .577 .707 r
F P
0 g
s
.65938 .58159 m .65153 .63573 L .6723 .64617 L p .707 .577 .707 r
F P
0 g
s
.55221 .24526 m .55635 .74757 L .51234 .74525 L p .707 .577 .707 r
F P
0 g
s
.51234 .74525 m .50821 .24294 L .55221 .24526 L p .707 .577 .707 r
F P
0 g
s
.72972 .76298 m .73182 .74481 L .70086 .73935 L p .707 .577 .707 r
F P
0 g
s
.73182 .74481 m .72972 .76298 L .76137 .76542 L p .707 .577 .707 r
F P
0 g
s
.76137 .76542 m .76348 .74725 L .73182 .74481 L p .707 .577 .707 r
F P
0 g
s
.65153 .63573 m .65938 .58159 L .64701 .57054 L p .707 .577 .707 r
F P
0 g
s
.76348 .74725 m .76137 .76542 L .79061 .76459 L p .707 .577 .707 r
F P
0 g
s
.79061 .76459 m .79271 .74641 L .76348 .74725 L p .707 .577 .707 r
F P
0 g
s
.4674 .74668 m .46327 .24437 L .50821 .24294 L p .707 .577 .707 r
F P
0 g
s
.46327 .24437 m .4674 .74668 L .42592 .75172 L p .707 .577 .707 r
F P
0 g
s
.69875 .75753 m .70086 .73935 L .6736 .7314 L p .707 .577 .707 r
F P
0 g
s
.70086 .73935 m .69875 .75753 L .72972 .76298 L p .707 .577 .707 r
F P
0 g
s
.67997 .71836 m .672 .68138 L .65161 .68112 L p .707 .577 .707 r
F P
0 g
s
.50821 .24294 m .51234 .74525 L .4674 .74668 L p .707 .577 .707 r
F P
0 g
s
.6736 .7314 m .6715 .74957 L .69875 .75753 L p .707 .577 .707 r
F P
0 g
s
.65161 .68112 m .65958 .71809 L .67997 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .74641 m .79061 .76459 L .81457 .76057 L p .707 .577 .707 r
F P
0 g
s
.81457 .76057 m .81667 .7424 L .79271 .74641 L p .707 .577 .707 r
F P
0 g
s
.64701 .57054 m .63917 .62468 L .65153 .63573 L p .707 .577 .707 r
F P
0 g
s
.6715 .74957 m .6736 .7314 L .65273 .72174 L p .707 .577 .707 r
F P
0 g
s
.65273 .72174 m .65063 .73991 L .6715 .74957 L p .707 .577 .707 r
F P
0 g
s
.63917 .62468 m .64701 .57054 L .64426 .55996 L p .707 .577 .707 r
F P
0 g
s
.65958 .71809 m .65161 .68112 L .63955 .67815 L p .707 .577 .707 r
F P
0 g
s
.81667 .7424 m .81457 .76057 L .83091 .75377 L p .707 .577 .707 r
F P
0 g
s
.83091 .75377 m .83301 .7356 L .81667 .7424 L p .707 .577 .707 r
F P
0 g
s
.63955 .67815 m .64752 .71512 L .65958 .71809 L p .707 .577 .707 r
F P
0 g
s
.65063 .73991 m .65273 .72174 L .64028 .71131 L p .707 .577 .707 r
F P
0 g
s
.64426 .55996 m .63642 .6141 L .63917 .62468 L p .707 .577 .707 r
F P
0 g
s
.64028 .71131 m .63818 .72948 L .65063 .73991 L p .707 .577 .707 r
F P
0 g
s
.83562 .63438 m .84346 .58024 L .84622 .59081 L p .707 .577 .707 r
F P
0 g
s
.63642 .6141 m .64426 .55996 L .6514 .5509 L p .707 .577 .707 r
F P
0 g
s
.64752 .71512 m .63955 .67815 L .63699 .67276 L p .707 .577 .707 r
F P
0 g
s
.83301 .7356 m .83091 .75377 L .83802 .74484 L p .707 .577 .707 r
F P
0 g
s
.83802 .74484 m .84012 .72667 L .83301 .7356 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63699 .67276 m .64496 .70973 L .64752 .71512 L p .707 .577 .707 r
F P
0 g
s
.63818 .72948 m .64028 .71131 L .63748 .70113 L p .707 .577 .707 r
F P
0 g
s
.63748 .70113 m .63538 .7193 L .63818 .72948 L p .707 .577 .707 r
F P
0 g
s
.6514 .5509 m .64355 .60504 L .63642 .6141 L p .707 .577 .707 r
F P
0 g
s
.82325 .62333 m .8311 .56919 L .84346 .58024 L p .707 .577 .707 r
F P
0 g
s
.64355 .60504 m .6514 .5509 L .66772 .54423 L p .707 .577 .707 r
F P
0 g
s
.38729 .62445 m .39514 .57031 L .36428 .56399 L p .707 .577 .707 r
F P
0 g
s
.39514 .57031 m .38729 .62445 L .41884 .62767 L p .707 .577 .707 r
F P
0 g
s
.41884 .62767 m .42669 .57353 L .39514 .57031 L p .707 .577 .707 r
F P
0 g
s
.64496 .70973 m .63699 .67276 L .64419 .66548 L p .707 .577 .707 r
F P
0 g
s
.84012 .72667 m .83802 .74484 L .83522 .73466 L p .707 .577 .707 r
F P
0 g
s
.83522 .73466 m .83732 .71649 L .84012 .72667 L p .707 .577 .707 r
F P
0 g
s
.42669 .57353 m .42215 .60483 L p .448 .62745 L .707 .577 .707 r
F P
0 g
s
.44587 .62747 m .448 .62745 L p .42215 .60483 L .707 .577 .707 r
F P
0 g
s
.448 .62745 m .45585 .57331 L .42669 .57353 L p .707 .577 .707 r
F P
0 g
s
.45585 .57331 m .448 .62745 L .46477 .62491 L p .707 .577 .707 r
F P
0 g
s
.47169 .62315 m .45585 .57331 L .46477 .62491 L .707 .577 .707 r
F
.47975 .56969 m .45585 .57331 L p .47151 .62258 L F P
0 g
s
.47169 .62315 m .47174 .62281 L .47151 .62258 L .707 .577 .707 r
F
.47174 .62281 m .47975 .56969 L .47151 .62258 L F
.47202 .62307 m .47975 .56969 L p .47169 .62315 L F P
0 g
s
.4941 .6417 m .47653 .621 L .47202 .62307 L .707 .577 .707 r
F
.47202 .62307 m .47785 .65015 L .49241 .64258 L p F P
0 g
s
.49241 .64258 m .4941 .6417 L p .47202 .62307 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .47202 .62307 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47975 .56969 m .47202 .62307 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49607 .56303 m .47975 .56969 L p .48775 .61449 L .707 .577 .707 r
F P
0 g
s
.48797 .61575 m .48809 .61498 L .48775 .61449 L .707 .577 .707 r
F
.48809 .61498 m .49607 .56303 L .48775 .61449 L F
.4941 .6417 m .5013 .63442 L p .50047 .6328 L F P
0 g
s
.48846 .61552 m .49607 .56303 L p .48809 .61498 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48809 .61498 L .48797 .61575 L .707 .577 .707 r
F
.49519 .62245 m .49536 .60746 L .49046 .61319 L F
.50047 .6328 m .49546 .60795 L .49519 .62245 L F
.49546 .60795 m .49536 .60746 L .49519 .62245 L F
.49537 .60746 m .49538 .6067 L .48846 .61552 L F
.49607 .56303 m .49261 .58689 L p .49538 .6067 L F P
0 g
s
.49261 .58689 m .48846 .61552 L p .49538 .6067 L .707 .577 .707 r
F P
0 g
s
.50066 .63306 m .50043 .63258 L .50047 .6328 L .707 .577 .707 r
F
.50117 .63379 m .50043 .63258 L .50066 .63306 L F
.50321 .55396 m .49607 .56303 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .49536 .60746 L .50043 .63258 L .707 .577 .707 r
F
.49536 .6081 m .49547 .60734 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .50321 .55396 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.50117 .63379 m .49547 .60734 L p .50043 .63258 L .707 .577 .707 r
F P
0 g
s
.49547 .60734 m .49334 .59744 L p .49536 .60746 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .50117 .63379 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .49874 .62903 L p .49741 .62122 L .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .48846 .61552 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .4941 .6417 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.4941 .6417 m .48846 .61552 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .4952 .60831 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.4952 .60831 m .49536 .6081 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49537 .60746 L .49511 .6078 L .707 .577 .707 r
F
.49536 .60746 m .49334 .59744 L .49046 .61319 L F
.49334 .59744 m .49547 .60734 L p .49469 .60534 L F P
0 g
s
.49334 .59744 m .48614 .60472 L p .49046 .61319 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48823 .61717 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49454 .60495 L p .49538 .60711 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49334 .59744 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49874 .62903 m .49235 .59933 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49235 .59933 m .49078 .59205 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48614 .60472 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .48846 .61552 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .48823 .61717 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .47191 .62383 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49874 .62903 L .48668 .62606 L p .707 .577 .707 r
F P
0 g
s
.50045 .54339 m .49261 .59753 L .4917 .59672 L p .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .46989 .61317 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48668 .62606 m .47872 .58908 L .49078 .59205 L p .707 .577 .707 r
F P
0 g
s
.4917 .59672 m .48024 .58648 L p .4861 .57399 L .707 .577 .707 r
F P
0 g
s
.4861 .57399 m .50045 .54339 L .4917 .59672 L .707 .577 .707 r
F
.49261 .59753 m .4959 .584 L .49538 .60711 L F
.49454 .60495 m .49261 .59753 L p .49538 .60711 L F P
0 g
s
.49547 .60734 m .49536 .6081 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.49741 .62122 m .49469 .60534 L .49547 .60734 L .707 .577 .707 r
F
.49547 .60734 m .5013 .63442 L p .49741 .62122 L F P
0 g
s
.50321 .55396 m .49547 .60734 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .47202 .62307 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .44617 .62198 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .46989 .61317 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .47202 .62307 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.46477 .62491 m .47191 .62383 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .45288 .62794 L .44774 .62925 L .707 .577 .707 r
F
.44617 .62198 m .44774 .62925 L p .45288 .62794 L F P
0 g
s
.44774 .62925 m .45414 .65895 L .47193 .65235 L p .707 .577 .707 r
F P
0 g
s
.47193 .65235 m .47785 .65015 L p .44774 .62925 L .707 .577 .707 r
F P
0 g
s
.42215 .60483 m .41884 .62767 L .44587 .62747 L p .707 .577 .707 r
F P
0 g
s
.35644 .61813 m .36428 .56399 L .33714 .55518 L p .707 .577 .707 r
F P
0 g
s
.36428 .56399 m .35644 .61813 L .38729 .62445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64419 .66548 m .65216 .70246 L .64496 .70973 L p .707 .577 .707 r
F P
0 g
s
.63538 .7193 m .63748 .70113 L .6446 .6922 L p .707 .577 .707 r
F P
0 g
s
.6446 .6922 m .64249 .71037 L .63538 .7193 L p .707 .577 .707 r
F P
0 g
s
.66772 .54423 m .65987 .59837 L .64355 .60504 L p .707 .577 .707 r
F P
0 g
s
.8311 .56919 m .82325 .62333 L .80248 .61289 L p .707 .577 .707 r
F P
0 g
s
.80248 .61289 m .81033 .55875 L .8311 .56919 L p .707 .577 .707 r
F P
0 g
s
.32929 .60932 m .33714 .55518 L .31637 .54474 L p .707 .577 .707 r
F P
0 g
s
.33714 .55518 m .32929 .60932 L .35644 .61813 L p .707 .577 .707 r
F P
0 g
s
.39411 .67421 m .38615 .63724 L .35571 .6422 L p .707 .577 .707 r
F P
0 g
s
.38615 .63724 m .39411 .67421 L .42528 .66725 L p .707 .577 .707 r
F P
0 g
s
.42528 .66725 m .41732 .63027 L .38615 .63724 L p .707 .577 .707 r
F P
0 g
s
.65987 .59837 m .66772 .54423 L .69162 .54061 L p .707 .577 .707 r
F P
0 g
s
.41732 .63027 m .42528 .66725 L .45414 .65895 L p .707 .577 .707 r
F P
0 g
s
.45414 .65895 m .44617 .62198 L .41732 .63027 L p .707 .577 .707 r
F P
0 g
s
.35571 .6422 m .36368 .67918 L .39411 .67421 L p .707 .577 .707 r
F P
0 g
s
.36368 .67918 m .35571 .6422 L .32899 .64467 L p .707 .577 .707 r
F P
0 g
s
.65216 .70246 m .64419 .66548 L .66045 .65702 L p .707 .577 .707 r
F P
0 g
s
.83732 .71649 m .83522 .73466 L .82277 .72423 L p .707 .577 .707 r
F P
0 g
s
.82277 .72423 m .82488 .70606 L .83732 .71649 L p .707 .577 .707 r
F P
0 g
s
.32899 .64467 m .33696 .68165 L .36368 .67918 L p .707 .577 .707 r
F P
0 g
s
.31637 .54474 m .30852 .59888 L .32929 .60932 L p .707 .577 .707 r
F P
0 g
s
.66045 .65702 m .66841 .694 L .65216 .70246 L p .707 .577 .707 r
F P
0 g
s
.64249 .71037 m .6446 .6922 L .66093 .68539 L p .707 .577 .707 r
F P
0 g
s
.82173 .62579 m .82969 .66277 L .8093 .66251 L p .707 .577 .707 r
F P
0 g
s
.8093 .66251 m .80134 .62553 L .82173 .62579 L p .707 .577 .707 r
F P
0 g
s
.38671 .72577 m .38881 .70759 L .35785 .70213 L p .707 .577 .707 r
F P
0 g
s
.38881 .70759 m .38671 .72577 L .41836 .7282 L p .707 .577 .707 r
F P
0 g
s
.41836 .7282 m .42047 .71003 L .38881 .70759 L p .707 .577 .707 r
F P
0 g
s
.81033 .55875 m .80248 .61289 L .77534 .60407 L p .707 .577 .707 r
F P
0 g
s
.77534 .60407 m .78319 .54993 L .81033 .55875 L p .707 .577 .707 r
F P
0 g
s
.30852 .59888 m .31637 .54474 L .304 .53369 L p .707 .577 .707 r
F P
0 g
s
.69162 .54061 m .68378 .59475 L .65987 .59837 L p .707 .577 .707 r
F P
0 g
s
.68378 .59475 m .69162 .54061 L .72078 .5404 L p .707 .577 .707 r
F P
0 g
s
.42047 .71003 m .41836 .7282 L .4476 .72737 L p .707 .577 .707 r
F P
0 g
s
.4476 .72737 m .4497 .7092 L .42047 .71003 L p .707 .577 .707 r
F P
0 g
s
.66093 .68539 m .65883 .70357 L .64249 .71037 L p .707 .577 .707 r
F P
0 g
s
.35574 .72031 m .35785 .70213 L .33059 .69418 L p .707 .577 .707 r
F P
0 g
s
.35785 .70213 m .35574 .72031 L .38671 .72577 L p .707 .577 .707 r
F P
0 g
s
.33696 .68165 m .32899 .64467 L .3086 .64441 L p .707 .577 .707 r
F P
0 g
s
.33059 .69418 m .32849 .71236 L .35574 .72031 L p .707 .577 .707 r
F P
0 g
s
.3086 .64441 m .31657 .68138 L .33696 .68165 L p .707 .577 .707 r
F P
0 g
s
.78319 .54993 m .77534 .60407 L .74448 .59775 L p .707 .577 .707 r
F P
0 g
s
.74448 .59775 m .75233 .54361 L .78319 .54993 L p .707 .577 .707 r
F P
0 g
s
.71293 .59454 m .72078 .5404 L .75233 .54361 L p .707 .577 .707 r
F P
0 g
s
.72078 .5404 m .71293 .59454 L .68378 .59475 L p .707 .577 .707 r
F P
0 g
s
.4497 .7092 m .4476 .72737 L .47156 .72336 L p .707 .577 .707 r
F P
0 g
s
.47156 .72336 m .47366 .70518 L .4497 .7092 L p .707 .577 .707 r
F P
0 g
s
.66841 .694 m .66045 .65702 L .68416 .64822 L p .707 .577 .707 r
F P
0 g
s
.304 .53369 m .29616 .58783 L .30852 .59888 L p .707 .577 .707 r
F P
0 g
s
.82488 .70606 m .82277 .72423 L .8019 .71457 L p .707 .577 .707 r
F P
0 g
s
.8019 .71457 m .804 .69639 L .82488 .70606 L p .707 .577 .707 r
F P
0 g
s
.32849 .71236 m .33059 .69418 L .30972 .68452 L p .707 .577 .707 r
F P
0 g
s
.75233 .54361 m .74448 .59775 L .71293 .59454 L p .707 .577 .707 r
F P
0 g
s
.80134 .62553 m .8093 .66251 L .78258 .66498 L p .707 .577 .707 r
F P
0 g
s
.78258 .66498 m .77462 .628 L .80134 .62553 L p .707 .577 .707 r
F P
0 g
s
.68416 .64822 m .69212 .6852 L .66841 .694 L p .707 .577 .707 r
F P
0 g
s
.65883 .70357 m .66093 .68539 L .68489 .68138 L p .707 .577 .707 r
F P
0 g
s
.30972 .68452 m .30762 .70269 L .32849 .71236 L p .707 .577 .707 r
F P
0 g
s
.29616 .58783 m .304 .53369 L .30125 .52311 L p .707 .577 .707 r
F P
0 g
s
.68489 .68138 m .68279 .69955 L .65883 .70357 L p .707 .577 .707 r
F P
0 g
s
.31657 .68138 m .3086 .64441 L .29654 .64143 L p .707 .577 .707 r
F P
0 g
s
.69212 .6852 m .68416 .64822 L .71301 .63993 L p .707 .577 .707 r
F P
0 g
s
.47366 .70518 m .47156 .72336 L .4879 .71655 L p .707 .577 .707 r
F P
0 g
s
.4879 .71655 m .49 .69838 L .47366 .70518 L p .707 .577 .707 r
F P
0 g
s
.29654 .64143 m .30451 .67841 L .31657 .68138 L p .707 .577 .707 r
F P
0 g
s
.77462 .628 m .78258 .66498 L .75215 .66994 L p .707 .577 .707 r
F P
0 g
s
.75215 .66994 m .74418 .63296 L .77462 .628 L p .707 .577 .707 r
F P
0 g
s
.804 .69639 m .8019 .71457 L .77465 .70662 L p .707 .577 .707 r
F P
0 g
s
.77465 .70662 m .77675 .68844 L .804 .69639 L p .707 .577 .707 r
F P
0 g
s
.30762 .70269 m .30972 .68452 L .29727 .67409 L p .707 .577 .707 r
F P
0 g
s
.71301 .63993 m .72098 .67691 L .69212 .6852 L p .707 .577 .707 r
F P
0 g
s
.68279 .69955 m .68489 .68138 L .71413 .68055 L p .707 .577 .707 r
F P
0 g
s
.30125 .52311 m .29341 .57725 L .29616 .58783 L p .707 .577 .707 r
F P
0 g
s
.72098 .67691 m .71301 .63993 L .74418 .63296 L p .707 .577 .707 r
F P
0 g
s
.29727 .67409 m .29517 .69226 L .30762 .70269 L p .707 .577 .707 r
F P
0 g
s
.74418 .63296 m .75215 .66994 L .72098 .67691 L p .707 .577 .707 r
F P
0 g
s
.71413 .68055 m .71203 .69872 L .68279 .69955 L p .707 .577 .707 r
F P
0 g
s
.49261 .59753 m .50045 .54339 L .50321 .55396 L p .707 .577 .707 r
F P
0 g
s
.77675 .68844 m .77465 .70662 L .74368 .70116 L p .707 .577 .707 r
F P
0 g
s
.74368 .70116 m .74578 .68298 L .77675 .68844 L p .707 .577 .707 r
F P
0 g
s
.29341 .57725 m .30125 .52311 L .30839 .51405 L p .707 .577 .707 r
F P
0 g
s
.71203 .69872 m .71413 .68055 L .74578 .68298 L p .707 .577 .707 r
F P
0 g
s
.30451 .67841 m .29654 .64143 L .29398 .63605 L p .707 .577 .707 r
F P
0 g
s
.74578 .68298 m .74368 .70116 L .71203 .69872 L p .707 .577 .707 r
F P
0 g
s
.49 .69838 m .4879 .71655 L .49501 .70762 L p .707 .577 .707 r
F P
0 g
s
.49501 .70762 m .49711 .68945 L .49 .69838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29398 .63605 m .30195 .67302 L .30451 .67841 L p .707 .577 .707 r
F P
0 g
s
.29517 .69226 m .29727 .67409 L .29447 .66391 L p .707 .577 .707 r
F P
0 g
s
.29447 .66391 m .29237 .68208 L .29517 .69226 L p .707 .577 .707 r
F P
0 g
s
.30839 .51405 m .30054 .56819 L .29341 .57725 L p .707 .577 .707 r
F P
0 g
s
.48024 .58648 m .48809 .53234 L .50045 .54339 L p .707 .577 .707 r
F P
0 g
s
.30054 .56819 m .30839 .51405 L .32471 .50738 L p .707 .577 .707 r
F P
0 g
s
.30195 .67302 m .29398 .63605 L .30118 .62877 L p .707 .577 .707 r
F P
0 g
s
.49711 .68945 m .49501 .70762 L .49221 .69745 L p .707 .577 .707 r
F P
0 g
s
.49221 .69745 m .49431 .67927 L .49711 .68945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30118 .62877 m .30915 .66575 L .30195 .67302 L p .707 .577 .707 r
F P
0 g
s
.29237 .68208 m .29447 .66391 L .30159 .65498 L p .707 .577 .707 r
F P
0 g
s
.30159 .65498 m .29948 .67315 L .29237 .68208 L p .707 .577 .707 r
F P
0 g
s
.32471 .50738 m .31686 .56152 L .30054 .56819 L p .707 .577 .707 r
F P
0 g
s
.48809 .53234 m .48024 .58648 L .45947 .57604 L p .707 .577 .707 r
F P
0 g
s
.45947 .57604 m .46732 .5219 L .48809 .53234 L p .707 .577 .707 r
F P
0 g
s
.31686 .56152 m .32471 .50738 L .34861 .50376 L p .707 .577 .707 r
F P
0 g
s
.30915 .66575 m .30118 .62877 L .31744 .62031 L p .707 .577 .707 r
F P
0 g
s
.49431 .67927 m .49221 .69745 L .47976 .68701 L p .707 .577 .707 r
F P
0 g
s
.47976 .68701 m .48186 .66884 L .49431 .67927 L p .707 .577 .707 r
F P
0 g
s
.31744 .62031 m .3254 .65729 L .30915 .66575 L p .707 .577 .707 r
F P
0 g
s
.29948 .67315 m .30159 .65498 L .31792 .64818 L p .707 .577 .707 r
F P
0 g
s
.47872 .58908 m .48668 .62606 L .46629 .6258 L p .707 .577 .707 r
F P
0 g
s
.46629 .6258 m .45833 .58882 L .47872 .58908 L p .707 .577 .707 r
F P
0 g
s
.46732 .5219 m .45947 .57604 L .43233 .56722 L p .707 .577 .707 r
F P
0 g
s
.43233 .56722 m .44018 .51308 L .46732 .5219 L p .707 .577 .707 r
F P
0 g
s
.34861 .50376 m .34077 .5579 L .31686 .56152 L p .707 .577 .707 r
F P
0 g
s
.34077 .5579 m .34861 .50376 L .37777 .50355 L p .707 .577 .707 r
F P
0 g
s
.31792 .64818 m .31582 .66635 L .29948 .67315 L p .707 .577 .707 r
F P
0 g
s
.44018 .51308 m .43233 .56722 L .40147 .5609 L p .707 .577 .707 r
F P
0 g
s
.40147 .5609 m .40932 .50676 L .44018 .51308 L p .707 .577 .707 r
F P
0 g
s
.36992 .55769 m .37777 .50355 L .40932 .50676 L p .707 .577 .707 r
F P
0 g
s
.37777 .50355 m .36992 .55769 L .34077 .5579 L p .707 .577 .707 r
F P
0 g
s
.3254 .65729 m .31744 .62031 L .34115 .61151 L p .707 .577 .707 r
F P
0 g
s
.48186 .66884 m .47976 .68701 L .45889 .67735 L p .707 .577 .707 r
F P
0 g
s
.45889 .67735 m .46099 .65918 L .48186 .66884 L p .707 .577 .707 r
F P
0 g
s
.40932 .50676 m .40147 .5609 L .36992 .55769 L p .707 .577 .707 r
F P
0 g
s
.45833 .58882 m .46629 .6258 L .43957 .62827 L p .707 .577 .707 r
F P
0 g
s
.43957 .62827 m .43161 .59129 L .45833 .58882 L p .707 .577 .707 r
F P
0 g
s
.34115 .61151 m .34911 .64849 L .3254 .65729 L p .707 .577 .707 r
F P
0 g
s
.31582 .66635 m .31792 .64818 L .34188 .64416 L p .707 .577 .707 r
F P
0 g
s
.34188 .64416 m .33978 .66234 L .31582 .66635 L p .707 .577 .707 r
F P
0 g
s
.34911 .64849 m .34115 .61151 L .37 .60322 L p .707 .577 .707 r
F P
0 g
s
.43161 .59129 m .43957 .62827 L .40914 .63323 L p .707 .577 .707 r
F P
0 g
s
.40914 .63323 m .40117 .59625 L .43161 .59129 L p .707 .577 .707 r
F P
0 g
s
.46099 .65918 m .45889 .67735 L .43164 .6694 L p .707 .577 .707 r
F P
0 g
s
.43164 .6694 m .43374 .65122 L .46099 .65918 L p .707 .577 .707 r
F P
0 g
s
.37 .60322 m .37797 .64019 L .34911 .64849 L p .707 .577 .707 r
F P
0 g
s
.33978 .66234 m .34188 .64416 L .37112 .64333 L p .707 .577 .707 r
F P
0 g
s
.37797 .64019 m .37 .60322 L .40117 .59625 L p .707 .577 .707 r
F P
0 g
s
.40117 .59625 m .40914 .63323 L .37797 .64019 L p .707 .577 .707 r
F P
0 g
s
.37112 .64333 m .36902 .6615 L .33978 .66234 L p .707 .577 .707 r
F P
0 g
s
.43374 .65122 m .43164 .6694 L .40067 .66394 L p .707 .577 .707 r
F P
0 g
s
.40067 .66394 m .40277 .64576 L .43374 .65122 L p .707 .577 .707 r
F P
0 g
s
.36902 .6615 m .37112 .64333 L .40277 .64576 L p .707 .577 .707 r
F P
0 g
s
.40277 .64576 m .40067 .66394 L .36902 .6615 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001POol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005]oo`D000=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00FGoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Ioo`00Egoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol005Ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool@001<Ool005Aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70015Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00E7oo
00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00>Goo001DOol20004FUH01000FUIJEUYF4000
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00T005YFFUIJEP00FUH005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`00=Woo001DOol20003
FUH500000eYF001JEP02FUH30002FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH3000dOol005=oo`04001JEP00FUH20006FUH00`00FUIJEP04FUH40004FUH50000
0eYF000000020002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
<Woo001COol01P00FUH00000FUH000EJEP03001JEUYF00IJEP03001JEUYF00T000EJEP@000IJEP03
001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000`Ool005=oo`<0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF0P00;goo001COol20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30003FUH>0005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo001DOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF2`000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP03
FUH01000FUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000iOol@000=Ool20005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00
FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20003FUH50002FUH00`00FUIJEP03FUH40004Ool90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00<Woo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF00<005YFFUH01UYF1P001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00EJ
EP03001JEP0000<00003Ool0000000<000=oo`H000IJEP03001JEUYF00=JEP07001JEUYFFUH005YF
0000;7oo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40002Ool200000eYF001JEP04FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00=JEPL000Qoo`8000AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002moo`8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000H00004FUH0
00000006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`000UYF3@0000=JEP00FUH015YF00@0
05YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF1@002EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8002eoo`00;Woo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF0P00;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP04001JEUYF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0P001EYF2P000eYF00<005YF0000;Goo000]
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005
FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1`000eYF00<005YFFUH0
0eYF0P000UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00Ool0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00FUH0
15YF00<005YFFUH01EYF00<005YFFUH01EYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH01UYF0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF00<0
05YF00001@0015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUIJEPP000UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003Ool200000eYF001JEP06FUH200000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJ
EP03001JEUYF00P000=JEP03001JEUYF009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF00000003Ool30003FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002eoo`8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
0007FUH00`00FUIJEP04FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH30003Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool20003FUH500000eYF001JEP040009
Ool60006FUH200001UYF00000000FUH000IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000=JEP8000=JEP8000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002aoo`04001JEP00FUH20006FUH00`00
FUIJEP03FUH50004Ool500000goo000000020002FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000400000eYF0000000<FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo000/Ool01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00T000Eoo`D000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEUYFFUH0000]Ool002aoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00AJEPL000Eoo`03001JEP0000=JEP04001JEUYFFUHG0006FUH00`00FUIJEP06FUH3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0002FUH00`00
Oomoo`0[Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP<000=J
EPH00003FUH005YF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP<002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P0000=JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP0000000P001UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1`001eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEPH00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF
00QJEP03001JEUYF00AJEP<000EJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPD000UJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@00003FUH00000018000EJ
EP<000MJEP03001JEUYF00MJEP8000=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP00009JEQ4000UJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Woo00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUH000EJEP04001J
EP00FUH200000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH300000eYF001JEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0002FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05
FUH01000FUH00000<7oo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH00`00
FUIJEP02FUH40005FUH00`00FUIJEP0300000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH00`00
FUIJEP020003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH01000FUIJEUYF1@00<Woo000`Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF
001JEP04FUH50006FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP04001JEP00000g
Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF00IJEP04001JEUYF
0005FUH20003FUH00`00FUIJEP0200000eYF001JEP05FUH30007FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1000>Goo000cOol200000eYF001JEP06FUH300000eYF001JEP08FUH00`00FUIJ
EP05FUH40005FUH00`00FUH000030002FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH3000gOol003Eoo`<000=JEP<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYF0005FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEUYF
0P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000AJEP03001JEP0000<000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00>7oo0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00MJEPD000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP02FUH2000bOol0
03Eoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH005YF00IJEP03001JEUYF00AJEQL000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040006Ool20003FUH00`00FUIJEP04FUH2000aOol0039oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`000UYF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF1`0037oo0P0000=JEP00FUH01EYF00<005YF
0000<7oo000`Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH01P0000=JEP00FUH015YF00@005YFFUIJEPP000Aoo`<000ioo`<000AJ
EP05001JEUYFFUH0000_Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEQ<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020000
0eYF0000000<000015YF001JEP001goo1@0047oo0`0000=JEP00FUH00UYF00<007ooOol0;Goo000]
Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P0000=JEP00FUH015YF00<005YFFUH00P0000=JEP00Ool01Woo1@004goo0P000eYF0P00;Woo000]
Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF1`0015YF00<005YFFUH00UYF200000=JEP00FUH0
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP00008000AJEP04001JEUYFFUH20008Ool5000EOol00`00FUIJEP02000^Ool002aoo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP090009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00P002Goo0`005goo1000;Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP<00003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEP000080009J
EP8002Eoo`8002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF01L0009JEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYF0002Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH01000FUIJEUYF1@0097oo0`00;Woo000]Ool00`00FUH00002FUH50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP04FUH30003Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH6000NOol300000eYF001oo`0]
Ool002eoo`03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@000=JEP03001JEUYF009JEP<000Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP00
02ioo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YF0000100000=JEP00000027oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
0eYF300000=JEP00FUH02UYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8002moo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0`002Goo00<005YF00001UYF00<005YFFUH01UYF200035YF00<005YFFUH02EYF00<005YF
FUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF0`001UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<0
05YF00000eYF00@005YFFUIJEQL000IJEP03001JEUYF00IJEP<000Moo`03001JEP0000IJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP8000AJEPP0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000`Ool002aoo`03001JEP0000=JEP@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF008000Eo
o`03001JEP0000IJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEPH000AJEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000/Ool01000FUH005YF
0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=oo`0000000P001UYF00<0
05YFFUH00eYF00<007ooOol00Woo00<005YF00001EYF0`000eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF100015YF0P000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF00000Woo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPD003Ao
o`00;7oo00@005YF0000009JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEPD000Uo
o`@0009JEP03001JEUYF00=JEP8000=oo`03001JEP0000=JEP8000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH2
0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;Ool@000iOol002aoo`@000=JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00@0019oo`<000EJEP09001JEP00001oo`00FUH0
05YF00<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00
;7oo0P0000=JEP0000001@000UYF00<005YFFUH00UYF1P001Goo0`004Goo0P000eYF00@005YFFUIJ
EP800003FUH00000009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1DOol002aoo`03001JEUYF009JEP03001oogoo009oo`L0
00Yoo`D0019oo`800003FUH005YF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000002FUH00`00FUIJEP05FUH01000FUH00000Egoo000/Ool00`00FUIJEP02FUH3000COol5000D
Ool20003FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH0
15YF0P00FGoo000/Ool00`00FUIJEP02FUH00`00FUIJEP02000AOol5000FOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH01000Fgoo000/
Ool01@00FUIJEUYF00001EYF0P0047oo0`0067oo0P0000=JEP00000015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00D005YFFUH005YF00D005moo`00;Goo0P0000=JEP00FUH015YF00<005YF00000`00
9goo0P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001EYF0`00GWoo
000_Ool20005FUH00`00FUIJEP03FUH5000POol200001EYF000007oo000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P001eYF00<005YF00000P00Fgoo000aOol20003FUH00`00FUIJEP05FUH00`00
FUIJEP04000GOol50003FUH20002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP02FUH2001IOol003=oo`800003FUH005YF00IJEP03001JEUYF00AJEPL000Uoo`L000=J
EP07001JEUYFFUH005YF000017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEPD000EJEP03001JEUYF00AJEP8005Qo
o`00=Goo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00@005YF
FUIJEP8000Moo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP04001JEP000005Ool400000eYF001JEP05FUH01000FUH00000EWoo000h
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00
FUIJEUYF00002Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF10002goo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000lOol4
0006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000003Goo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01P0047oo
0P000eYF00<005YFFUH00UYF00<007ooOol0Dgoo0010Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1@004Woo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF1@000Woo1@004Goo0P0000=JEP00FUH00eYF00<007ooOol0Dgoo0014Ool70004FUH00`00FUIJ
EP02FUH8000KOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001goo1@00
4goo0P000eYF0P00EGoo001;Ool9000YOolO000=Ool5000EOol00`00FUIJEP02001EOol008moo`03
001JEP0000EJEP<0011oo`<001Moo`@005Eoo`00T7oo0P001UYF00<005YF00000`009goo0`00EGoo
002AOol00`00FUIJEP04FUH00`00FUIJEP03FUH7000NOol5001EOol0099oo`8000=JEP03001JEUYF
00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP0005Eoo`00U7oo0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8005Ioo`00UWoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Io
o`00VGoo10000UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00WGoo1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Uoo`00XWoo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD005]oo`00YWoo5`00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59095 .75535 m .60357 .70269 L .57322 .69371 L p .707 .577 .707 r
F P
0 g
s
.60357 .70269 m .59095 .75535 L .6213 .76083 L p .707 .577 .707 r
F P
0 g
s
.62198 .76078 m .62195 .76067 L .6213 .76083 L .707 .577 .707 r
F
.62195 .76067 m .60357 .70269 L .62106 .76002 L F
.62195 .76067 m .62106 .76002 L .6213 .76083 L F
.60897 .77425 m .62209 .76077 L .59015 .76315 L F
.63155 .78758 m .62209 .76077 L p .60897 .77425 L F P
0 g
s
.65956 .7763 m .63155 .7593 L .62209 .76077 L .707 .577 .707 r
F
.64903 .75658 m .64367 .73859 L .62225 .76074 L F
.63466 .7083 m .62209 .76077 L p .64367 .73859 L F P
0 g
s
.62209 .76077 m .63155 .78758 L .64921 .78047 L p .707 .577 .707 r
F P
0 g
s
.64921 .78047 m .65956 .7763 L p .62209 .76077 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .62204 .76096 L p .62225 .76074 L .707 .577 .707 r
F P
0 g
s
.64367 .73859 m .62209 .76077 L .62225 .76074 L .707 .577 .707 r
F
.63466 .7083 m .60357 .70269 L p .62195 .76067 L F P
0 g
s
.62204 .76096 m .62209 .76077 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .63466 .7083 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.6423 .76582 m .65241 .75606 L .63155 .7593 L .707 .577 .707 r
F
.65956 .7763 m .65241 .75606 L p .6423 .76582 L F P
0 g
s
.65956 .7763 m .68273 .76558 L p .67083 .75719 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .66987 .73919 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .65241 .75606 L p .66987 .73919 L F P
0 g
s
.66987 .73919 m .65241 .75606 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .63466 .7083 L p .64824 .75395 L F P
0 g
s
.65083 .76265 m .65241 .75606 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .66345 .70999 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.68273 .76558 m .67707 .74955 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.68713 .70759 m .66345 .70999 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .67707 .74955 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68713 .70759 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.68862 .75322 m .68665 .74512 L .67707 .74955 L .707 .577 .707 r
F
.6988 .75646 m .69058 .74879 L .68862 .75322 L F
.69058 .74879 m .68665 .74512 L .68862 .75322 L F
.69575 .75819 m .6988 .75646 L p .67707 .74955 L F P
0 g
s
.68993 .7436 m .68924 .73466 L .68197 .74729 L .707 .577 .707 r
F
.68713 .70759 m .67707 .74955 L p .68924 .73466 L F P
0 g
s
.68924 .73466 m .67707 .74955 L .68197 .74729 L .707 .577 .707 r
F
.68608 .72047 m .67002 .72959 L p .68665 .74512 L F P
0 g
s
.6988 .75646 m .69365 .74189 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70337 .70135 m .68713 .70759 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69074 .75401 m .69365 .74189 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .70337 .70135 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.70033 .74613 m .69758 .73727 L .69365 .74189 L .707 .577 .707 r
F
.70618 .74985 m .70041 .7414 L .70033 .74613 L F
.70041 .7414 m .69758 .73727 L .70033 .74613 L F
.69365 .74189 m .6988 .75646 L .70594 .75007 L p F P
0 g
s
.70594 .75007 m .70618 .74985 L p .69365 .74189 L .707 .577 .707 r
F P
0 g
s
.69909 .7355 m .70011 .72733 L .69594 .73919 L .707 .577 .707 r
F
.70337 .70135 m .69365 .74189 L p .70011 .72733 L F P
0 g
s
.70011 .72733 m .69365 .74189 L .69594 .73919 L .707 .577 .707 r
F
.69347 .71385 m .68608 .72047 L p .69758 .73727 L F P
0 g
s
.70618 .74985 m .70052 .73382 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.71058 .69186 m .70337 .70135 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .70052 .73382 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .71058 .69186 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70618 .74985 m .70417 .74638 L p .70249 .74128 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .69347 .71385 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.69779 .73837 m .69796 .74452 L p .69909 .7355 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .69701 .7401 L .69074 .75401 L .707 .577 .707 r
F
.69909 .7355 m .69594 .73919 L .69074 .75401 L F
.68608 .72047 m .69365 .74189 L p .69758 .73727 L F P
0 g
s
.69796 .74452 m .69544 .73273 L p .6975 .72718 L .707 .577 .707 r
F P
0 g
s
.69347 .71385 m .70052 .73382 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.6975 .72718 m .69937 .7313 L .69796 .74452 L .707 .577 .707 r
F
.69146 .71038 m .69347 .71385 L p .69878 .73 L F P
0 g
s
.70052 .73382 m .69796 .74452 L p .69937 .7313 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69146 .71038 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .71058 .69186 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .69702 .72613 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .70806 .68006 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .69074 .75401 L p .69594 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .68608 .72047 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70417 .74638 m .69295 .74639 L p .69243 .73379 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .68344 .71977 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69146 .71038 m .69702 .72613 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69544 .73273 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .69146 .71038 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .68348 .71958 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68024 .7104 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .70806 .68006 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68344 .71977 m .68348 .71958 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69606 .66711 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .69702 .72613 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69243 .73379 m .69201 .72371 L .69702 .72613 L .707 .577 .707 r
F
.69702 .72613 m .70417 .74638 L p .69243 .73379 L F P
0 g
s
.70417 .74638 m .69702 .72613 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70076 .71837 m .70052 .73382 L .69937 .7313 L .707 .577 .707 r
F
.6975 .72718 m .70076 .71837 L .69937 .7313 L F
.70249 .74128 m .69878 .73 L .70052 .73382 L F
.70052 .73382 m .70618 .74985 L p .70249 .74128 L F P
0 g
s
.71058 .69186 m .70052 .73382 L p .70076 .71837 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68273 .76558 L .69575 .75819 L p .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .6745 .76025 L p .68197 .74729 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .69074 .75401 L p .68993 .7436 L .707 .577 .707 r
F P
0 g
s
.68993 .7436 m .68197 .74729 L .6745 .76025 L .707 .577 .707 r
F
.67002 .72959 m .67707 .74955 L p .68665 .74512 L F P
0 g
s
.67002 .72959 m .64685 .74031 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .67002 .72959 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65956 .7763 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65083 .76265 L p .65721 .75479 L .707 .577 .707 r
F P
0 g
s
.67083 .75719 m .66463 .75283 L .66112 .76907 L .707 .577 .707 r
F
.67083 .75719 m .66112 .76907 L .65956 .7763 L F
.64685 .74031 m .65241 .75606 L p .66463 .75283 L F P
0 g
s
.65083 .76265 m .6745 .76025 L p .67242 .75078 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .65721 .75479 L .65083 .76265 L .707 .577 .707 r
F
.64685 .74031 m .61884 .75158 L p .63155 .7593 L F P
0 g
s
.65241 .75606 m .64685 .74031 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.61884 .75158 m .62209 .76077 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.62204 .76096 m .65083 .76265 L p .64903 .75658 L .707 .577 .707 r
F P
0 g
s
.64903 .75658 m .62225 .76074 L .62204 .76096 L .707 .577 .707 r
F
.61884 .75158 m .58874 .76231 L p .59015 .76315 L F P
0 g
s
.62209 .76077 m .61884 .75158 L p .59015 .76315 L .707 .577 .707 r
F P
0 g
s
.6213 .76083 m .62204 .76096 L p .62198 .76078 L .707 .577 .707 r
F P
0 g
s
.5606 .74637 m .57322 .69371 L .54659 .68224 L p .707 .577 .707 r
F P
0 g
s
.57322 .69371 m .5606 .74637 L .59095 .75535 L p .707 .577 .707 r
F P
0 g
s
.53397 .7349 m .54659 .68224 L .52628 .6694 L p .707 .577 .707 r
F P
0 g
s
.54659 .68224 m .53397 .7349 L .5606 .74637 L p .707 .577 .707 r
F P
0 g
s
.60145 .79831 m .58874 .76231 L .55948 .77144 L p .707 .577 .707 r
F P
0 g
s
.58874 .76231 m .60145 .79831 L .63155 .78758 L p .707 .577 .707 r
F P
0 g
s
.55948 .77144 m .5722 .80744 L .60145 .79831 L p .707 .577 .707 r
F P
0 g
s
.5722 .80744 m .55948 .77144 L .53395 .77808 L p .707 .577 .707 r
F P
0 g
s
.53395 .77808 m .54666 .81408 L .5722 .80744 L p .707 .577 .707 r
F P
0 g
s
.52628 .6694 m .51366 .72206 L .53397 .7349 L p .707 .577 .707 r
F P
0 g
s
.51366 .72206 m .52628 .6694 L .51428 .65645 L p .707 .577 .707 r
F P
0 g
s
.59009 .85697 m .59348 .83915 L .56284 .83153 L p .707 .577 .707 r
F P
0 g
s
.59348 .83915 m .59009 .85697 L .62145 .86135 L p .707 .577 .707 r
F P
0 g
s
.62145 .86135 m .62483 .84353 L .59348 .83915 L p .707 .577 .707 r
F P
0 g
s
.62483 .84353 m .62145 .86135 L .65045 .86206 L p .707 .577 .707 r
F P
0 g
s
.65045 .86206 m .65384 .84424 L .62483 .84353 L p .707 .577 .707 r
F P
0 g
s
.55945 .84936 m .56284 .83153 L .53591 .82142 L p .707 .577 .707 r
F P
0 g
s
.56284 .83153 m .55945 .84936 L .59009 .85697 L p .707 .577 .707 r
F P
0 g
s
.54666 .81408 m .53395 .77808 L .51462 .78158 L p .707 .577 .707 r
F P
0 g
s
.53591 .82142 m .53253 .83925 L .55945 .84936 L p .707 .577 .707 r
F P
0 g
s
.53253 .83925 m .53591 .82145 L p .51534 .80982 L .707 .577 .707 r
F P
0 g
s
.53591 .82145 m .53591 .82142 L .53588 .82141 L p .707 .577 .707 r
F P
0 g
s
.53588 .82141 m .51534 .80982 L p .53591 .82145 L .707 .577 .707 r
F P
0 g
s
.52733 .81757 m .51858 .79278 L p .5034 .78159 L .707 .577 .707 r
F P
0 g
s
.51858 .79278 m .51462 .78158 L .51181 .78158 L p .707 .577 .707 r
F P
0 g
s
.51181 .78158 m .5034 .78159 L p .51858 .79278 L .707 .577 .707 r
F P
0 g
s
.51462 .78158 m .52733 .81757 L .54666 .81408 L p .707 .577 .707 r
F P
0 g
s
.51428 .65645 m .50166 .70911 L .51366 .72206 L p .707 .577 .707 r
F P
0 g
s
.65384 .84424 m .65045 .86206 L .67425 .85904 L p .707 .577 .707 r
F P
0 g
s
.67425 .85904 m .67764 .84121 L .65384 .84424 L p .707 .577 .707 r
F P
0 g
s
.50166 .70911 m .51428 .65645 L .51176 .64466 L p .707 .577 .707 r
F P
0 g
s
.51534 .80982 m .51195 .82764 L .53253 .83925 L p .707 .577 .707 r
F P
0 g
s
.51195 .82764 m .51487 .81229 L p .50313 .79784 L .707 .577 .707 r
F P
0 g
s
.51487 .81229 m .51534 .80982 L .51311 .80763 L p .707 .577 .707 r
F P
0 g
s
.51311 .80763 m .50313 .79784 L p .51487 .81229 L .707 .577 .707 r
F P
0 g
s
.51612 .81759 m .50523 .78677 L p .50139 .77812 L .707 .577 .707 r
F P
0 g
s
.50523 .78677 m .5034 .78159 L .50304 .78097 L p .707 .577 .707 r
F P
0 g
s
.50304 .78097 m .50139 .77812 L p .50523 .78677 L .707 .577 .707 r
F P
0 g
s
.5034 .78159 m .51612 .81759 L .52733 .81757 L p .707 .577 .707 r
F P
0 g
s
.67764 .84121 m .67425 .85904 L .69054 .85258 L p .707 .577 .707 r
F P
0 g
s
.69054 .85258 m .69393 .83475 L .67764 .84121 L p .707 .577 .707 r
F P
0 g
s
.51176 .64466 m .49914 .69732 L .50166 .70911 L p .707 .577 .707 r
F P
0 g
s
.50313 .79784 m .49974 .81567 L .51195 .82764 L p .707 .577 .707 r
F P
0 g
s
.49914 .69732 m .51176 .64466 L .51898 .63517 L p .707 .577 .707 r
F P
0 g
s
.49492 .8217 m .48824 .31914 L .44423 .31706 L p .707 .577 .707 r
F P
0 g
s
.49974 .81567 m .50313 .79784 L .50048 .78667 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .51612 .81759 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50139 .77812 m .50185 .77943 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50185 .77943 m .5141 .81412 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50048 .78667 m .49709 .8045 L .49974 .81567 L p .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50048 .78667 L .50297 .78345 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .50139 .77812 L .50878 .77151 L p .707 .577 .707 r
F P
0 g
s
.50297 .78345 m .50764 .7774 L p .50393 .78693 L .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50297 .78345 L .50393 .78693 L .707 .577 .707 r
F
.51898 .63517 m .50635 .68783 L .49914 .69732 L p F P
0 g
s
.50635 .68783 m .51898 .63517 L .53521 .62892 L p .707 .577 .707 r
F P
0 g
s
.50878 .77151 m .52149 .8075 L .5141 .81412 L p .707 .577 .707 r
F P
0 g
s
.53521 .62892 m .52259 .68159 L .50635 .68783 L p .707 .577 .707 r
F P
0 g
s
.50764 .7774 m .50426 .79523 L .49709 .8045 L p .707 .577 .707 r
F P
0 g
s
.52259 .68159 m .53521 .62892 L .55889 .62653 L p .707 .577 .707 r
F P
0 g
s
.52149 .8075 m .50878 .77151 L .52484 .76239 L p .707 .577 .707 r
F P
0 g
s
.50426 .79523 m .50764 .7774 L .52393 .77094 L p .707 .577 .707 r
F P
0 g
s
.55889 .62653 m .54627 .67919 L .52259 .68159 L p .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52149 .8075 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.52484 .76239 m .5253 .7637 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.5253 .7637 m .53755 .79838 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52484 .76239 L .54801 .75167 L p .707 .577 .707 r
F P
0 g
s
.52054 .78877 m .52393 .77094 L .53645 .76935 L p .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .53755 .79838 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54801 .75167 m .54984 .75685 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54984 .75685 m .56072 .78766 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .54801 .75167 L .57602 .74039 L p .707 .577 .707 r
F P
0 g
s
.57602 .74039 m .58873 .77639 L .56072 .78766 L p .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .54774 .76792 L .57144 .7685 L p .707 .577 .707 r
F P
0 g
s
.57144 .7685 m .57674 .76863 L p .57419 .76998 L .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .57144 .7685 L .57419 .76998 L .707 .577 .707 r
F
.53645 .76935 m .54774 .76792 L p .54212 .77222 L F P
0 g
s
.52054 .78877 m .53645 .76935 L .54212 .77222 L .707 .577 .707 r
F
.52393 .77094 m .52054 .78877 L .50426 .79523 L p F P
0 g
s
.54774 .76792 m .54435 .78574 L .52054 .78877 L p .707 .577 .707 r
F P
0 g
s
.48824 .31914 m .49492 .8217 L .53987 .82007 L p .707 .577 .707 r
F P
0 g
s
.53987 .82007 m .53318 .31751 L .48824 .31914 L p .707 .577 .707 r
F P
0 g
s
.54627 .67919 m .55889 .62653 L .58768 .62822 L p .707 .577 .707 r
F P
0 g
s
.58768 .62822 m .57506 .68088 L .54627 .67919 L p .707 .577 .707 r
F P
0 g
s
.57674 .76863 m .57335 .78646 L .54435 .78574 L p .707 .577 .707 r
F P
0 g
s
.58873 .77639 m .57602 .74039 L .60612 .72967 L p .707 .577 .707 r
F P
0 g
s
.60612 .72967 m .61884 .76566 L .58873 .77639 L p .707 .577 .707 r
F P
0 g
s
.57335 .78646 m .57674 .76863 L .60809 .77301 L p .707 .577 .707 r
F P
0 g
s
.60809 .77301 m .6047 .79083 L .57335 .78646 L p .707 .577 .707 r
F P
0 g
s
.53318 .31751 m .53987 .82007 L .58134 .81487 L p .707 .577 .707 r
F P
0 g
s
.57506 .68088 m .58768 .62822 L .61877 .63382 L p .707 .577 .707 r
F P
0 g
s
.61877 .63382 m .60615 .68649 L .57506 .68088 L p .707 .577 .707 r
F P
0 g
s
.58134 .81487 m .57466 .31232 L .53318 .31751 L p .707 .577 .707 r
F P
0 g
s
.69393 .83475 m .69054 .85258 L .69771 .84331 L p .707 .577 .707 r
F P
0 g
s
.69771 .84331 m .7011 .82548 L .69393 .83475 L p .707 .577 .707 r
F P
0 g
s
.45092 .81961 m .44423 .31706 L .40547 .31145 L p .707 .577 .707 r
F P
0 g
s
.44423 .31706 m .45092 .81961 L .49492 .8217 L p .707 .577 .707 r
F P
0 g
s
.61884 .76566 m .60612 .72967 L .63538 .72053 L p .707 .577 .707 r
F P
0 g
s
.63873 .78062 m .63534 .79845 L .6047 .79083 L p .707 .577 .707 r
F P
0 g
s
.6047 .79083 m .60809 .77301 L .63873 .78062 L p .707 .577 .707 r
F P
0 g
s
.57466 .31232 m .58134 .81487 L .6153 .80662 L p .707 .577 .707 r
F P
0 g
s
.64912 .6428 m .63649 .69546 L .60615 .68649 L p .707 .577 .707 r
F P
0 g
s
.60615 .68649 m .61877 .63382 L .64912 .6428 L p .707 .577 .707 r
F P
0 g
s
.6153 .80662 m .60861 .30407 L .57466 .31232 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .26056 .66582 L .23022 .65684 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .27882 .72405 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.26056 .66582 m .25142 .70397 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.25142 .70397 m .24794 .71848 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.27901 .72403 m .26056 .66582 L .27882 .72405 L .707 .577 .707 r
F
.26588 .73756 m .27904 .72403 L .247 .72642 L F
.28854 .75093 m .27904 .72403 L p .26588 .73756 L F P
0 g
s
.31655 .73965 m .28842 .72258 L .27904 .72403 L .707 .577 .707 r
F
.30605 .71983 m .30069 .7018 L .27909 .72403 L F
.29165 .67143 m .27904 .72403 L p .30069 .7018 L F P
0 g
s
.27904 .72403 m .28854 .75093 L .30626 .7438 L p .707 .577 .707 r
F P
0 g
s
.30626 .7438 m .31655 .73965 L p .27904 .72403 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .27903 .72409 L p .27909 .72403 L .707 .577 .707 r
F P
0 g
s
.30069 .7018 m .27904 .72403 L .27909 .72403 L .707 .577 .707 r
F
.29165 .67143 m .26056 .66582 L p .279 .724 L F P
0 g
s
.27903 .72409 m .27904 .72403 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .29165 .67143 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.29921 .72913 m .30937 .71932 L .28842 .72258 L .707 .577 .707 r
F
.31655 .73965 m .30937 .71932 L p .29921 .72913 L F P
0 g
s
.31655 .73965 m .33972 .72893 L p .32775 .7205 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .32688 .7024 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .30937 .71932 L p .32688 .7024 L F P
0 g
s
.32688 .7024 m .30937 .71932 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .29165 .67143 L p .30529 .71726 L F P
0 g
s
.30782 .72578 m .30937 .71932 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .32044 .67311 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.33972 .72893 m .33403 .71281 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.34412 .67072 m .32044 .67311 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .33403 .71281 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .34412 .67072 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.34556 .71652 m .34357 .7084 L .33403 .71281 L .707 .577 .707 r
F
.35579 .71982 m .34752 .7121 L .34556 .71652 L F
.34752 .7121 m .34357 .7084 L .34556 .71652 L F
.34693 .70685 m .34623 .69787 L .3389 .71056 L F
.34412 .67072 m .33403 .71281 L p .34623 .69787 L F P
0 g
s
.34623 .69787 m .33403 .71281 L .3389 .71056 L .707 .577 .707 r
F
.34308 .68383 m .32701 .69294 L p .34357 .7084 L F P
0 g
s
.35579 .71982 m .35061 .70515 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36036 .66447 m .34412 .67072 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.34773 .71713 m .35061 .70515 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .36036 .66447 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35729 .70943 m .35452 .70055 L .35061 .70515 L .707 .577 .707 r
F
.36317 .7132 m .35736 .70471 L .35729 .70943 L F
.35736 .70471 m .35452 .70055 L .35729 .70943 L F
.35061 .70515 m .35579 .71982 L .36297 .71338 L p F P
0 g
s
.36297 .71338 m .36317 .7132 L p .35061 .70515 L .707 .577 .707 r
F P
0 g
s
.35606 .69874 m .35709 .69054 L .3529 .70246 L .707 .577 .707 r
F
.36036 .66447 m .35061 .70515 L p .35709 .69054 L F P
0 g
s
.35709 .69054 m .35061 .70515 L .3529 .70246 L .707 .577 .707 r
F
.35046 .67721 m .34308 .68383 L p .35452 .70055 L F P
0 g
s
.36317 .7132 m .35748 .69708 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.36757 .65499 m .36036 .66447 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35748 .69708 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36757 .65499 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.36317 .7132 m .36116 .70973 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .35046 .67721 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.35477 .7016 m .35495 .70765 L p .35606 .69874 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35401 .70327 L .34773 .71713 L .707 .577 .707 r
F
.35606 .69874 m .3529 .70246 L .34773 .71713 L F
.34308 .68383 m .35061 .70515 L p .35452 .70055 L F P
0 g
s
.35495 .70765 m .35243 .69585 L p .35444 .69042 L .707 .577 .707 r
F P
0 g
s
.35046 .67721 m .35748 .69708 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35444 .69042 m .35634 .69457 L .35495 .70765 L .707 .577 .707 r
F
.34845 .67374 m .35046 .67721 L p .35575 .69328 L F P
0 g
s
.35748 .69708 m .35495 .70765 L p .35634 .69457 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .34845 .67374 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36757 .65499 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .35398 .6894 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36505 .64319 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34773 .71713 L p .3529 .70246 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34308 .68383 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .34994 .70974 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .34043 .6829 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.34845 .67374 m .35398 .6894 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.38244 .80543 m .37575 .30287 L .35798 .29217 L p .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .35243 .69585 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34845 .67374 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .34044 .68285 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .33723 .67375 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .36505 .64319 L p .34508 .67541 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36138 .65852 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.36138 .65852 m .35398 .6894 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.34459 .68485 m .36143 .65057 L .35398 .6894 L .707 .577 .707 r
F
.36466 .79473 m .36445 .7784 L p .36432 .77855 L F P
0 g
s
.34508 .67541 m .36505 .64319 L .34459 .68485 L .707 .577 .707 r
F
.36757 .65499 m .35748 .69708 L p .35772 .68158 L F P
0 g
s
.36445 .7784 m .35798 .29217 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36317 .7132 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .35389 .28038 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36116 .70973 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .35398 .6894 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .36466 .79473 L .38244 .80543 L p .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36058 .78294 L .36466 .79473 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36058 .78294 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36389 .26867 m .36429 .29882 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36429 .29882 m .37058 .77122 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34584 .66035 L .34508 .67541 L .707 .577 .707 r
F
.34584 .66035 m .35305 .63024 L .34508 .67541 L F
.34043 .6829 m .34044 .68285 L p .34046 .68285 L F P
0 g
s
.34044 .68285 m .35305 .63024 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36389 .26867 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36058 .78294 m .35624 .4567 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.35624 .4567 m .35389 .28038 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34508 .67541 L .34459 .68485 L .707 .577 .707 r
F
.34941 .697 m .349 .68699 L .35398 .6894 L F
.35772 .68158 m .35748 .69708 L .35634 .69457 L F
.35444 .69042 m .35772 .68158 L .35634 .69457 L F
.35944 .70451 m .35575 .69328 L .35748 .69708 L F
.33403 .71281 m .33972 .72893 L .35282 .7215 L p F P
0 g
s
.35282 .7215 m .35579 .71982 L p .33403 .71281 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .3315 .72338 L p .3389 .71056 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .34773 .71713 L p .34693 .70685 L .707 .577 .707 r
F P
0 g
s
.34693 .70685 m .3389 .71056 L .3315 .72338 L .707 .577 .707 r
F
.32701 .69294 m .33403 .71281 L p .34357 .7084 L F P
0 g
s
.32701 .69294 m .30384 .70366 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .32701 .69294 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .31655 .73965 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .30782 .72578 L p .31411 .71807 L .707 .577 .707 r
F P
0 g
s
.32775 .7205 m .32152 .71611 L .3181 .73231 L .707 .577 .707 r
F
.32775 .7205 m .3181 .73231 L .31655 .73965 L F
.30384 .70366 m .30937 .71932 L p .32152 .71611 L F P
0 g
s
.30782 .72578 m .3315 .72338 L p .32944 .71402 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .31411 .71807 L .30782 .72578 L .707 .577 .707 r
F
.30384 .70366 m .27583 .71494 L p .28842 .72258 L F P
0 g
s
.30937 .71932 m .30384 .70366 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27583 .71494 m .27904 .72403 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27903 .72409 m .30782 .72578 L p .30605 .71983 L .707 .577 .707 r
F P
0 g
s
.30605 .71983 m .27909 .72403 L .27903 .72409 L .707 .577 .707 r
F
.27583 .71494 m .24573 .72567 L p .247 .72642 L F P
0 g
s
.27904 .72403 m .27583 .71494 L p .247 .72642 L .707 .577 .707 r
F P
0 g
s
.27882 .72405 m .27903 .72409 L p .27901 .72403 L .707 .577 .707 r
F P
0 g
s
.41216 .81401 m .40547 .31145 L .37575 .30287 L p .707 .577 .707 r
F P
0 g
s
.40547 .31145 m .41216 .81401 L .45092 .81961 L p .707 .577 .707 r
F P
0 g
s
.21759 .7095 m .23022 .65684 L .20358 .64537 L p .707 .577 .707 r
F P
0 g
s
.23022 .65684 m .21759 .7095 L .24794 .71848 L p .707 .577 .707 r
F P
0 g
s
.7011 .82548 m .69771 .84331 L .69506 .83214 L p .707 .577 .707 r
F P
0 g
s
.69506 .83214 m .69844 .81431 L .7011 .82548 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19096 .69803 m .20358 .64537 L .18327 .63253 L p .707 .577 .707 r
F P
0 g
s
.20358 .64537 m .19096 .69803 L .21759 .7095 L p .707 .577 .707 r
F P
0 g
s
.63538 .72053 m .64809 .75653 L .61884 .76566 L p .707 .577 .707 r
F P
0 g
s
.63534 .79845 m .63873 .78062 L .66566 .79073 L p .707 .577 .707 r
F P
0 g
s
.60861 .30407 m .6153 .80662 L .63841 .79613 L p .707 .577 .707 r
F P
0 g
s
.67575 .65427 m .66313 .70694 L .63649 .69546 L p .707 .577 .707 r
F P
0 g
s
.63649 .69546 m .64912 .6428 L .67575 .65427 L p .707 .577 .707 r
F P
0 g
s
.64809 .75653 m .63538 .72053 L .66092 .71389 L p .707 .577 .707 r
F P
0 g
s
.63841 .79613 m .63172 .29357 L .60861 .30407 L p .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .67363 .74989 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .68348 .71958 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68344 .71977 L .68296 .71947 L p .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69295 .74639 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.67363 .74989 m .66092 .71389 L .68024 .7104 L p .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .68348 .71958 L p .66313 .70694 L .707 .577 .707 r
F P
0 g
s
.68296 .71947 m .66313 .70694 L p .68348 .71958 L .707 .577 .707 r
F P
0 g
s
.66313 .70694 m .67575 .65427 L .69606 .66711 L p .707 .577 .707 r
F P
0 g
s
.25844 .76166 m .24573 .72567 L .21648 .7348 L p .707 .577 .707 r
F P
0 g
s
.24573 .72567 m .25844 .76166 L .28854 .75093 L p .707 .577 .707 r
F P
0 g
s
.21648 .7348 m .22919 .77079 L .25844 .76166 L p .707 .577 .707 r
F P
0 g
s
.22919 .77079 m .21648 .7348 L .19094 .74144 L p .707 .577 .707 r
F P
0 g
s
.69844 .81431 m .69506 .83214 L .68284 .82017 L p .707 .577 .707 r
F P
0 g
s
.68284 .82017 m .68623 .80234 L .69844 .81431 L p .707 .577 .707 r
F P
0 g
s
.37575 .30287 m .38244 .80543 L .41216 .81401 L p .707 .577 .707 r
F P
0 g
s
.19094 .74144 m .20365 .77743 L .22919 .77079 L p .707 .577 .707 r
F P
0 g
s
.18327 .63253 m .17065 .68519 L .19096 .69803 L p .707 .577 .707 r
F P
0 g
s
.17065 .68519 m .18327 .63253 L .17127 .61958 L p .707 .577 .707 r
F P
0 g
s
.24708 .81951 m .25047 .80168 L .21983 .79407 L p .707 .577 .707 r
F P
0 g
s
.25047 .80168 m .24708 .81951 L .27844 .82389 L p .707 .577 .707 r
F P
0 g
s
.27844 .82389 m .28183 .80606 L .25047 .80168 L p .707 .577 .707 r
F P
0 g
s
.28183 .80606 m .27844 .82389 L .30744 .8246 L p .707 .577 .707 r
F P
0 g
s
.30744 .8246 m .31083 .80677 L .28183 .80606 L p .707 .577 .707 r
F P
0 g
s
.21644 .81189 m .21983 .79407 L .19291 .78396 L p .707 .577 .707 r
F P
0 g
s
.21983 .79407 m .21644 .81189 L .24708 .81951 L p .707 .577 .707 r
F P
0 g
s
.20365 .77743 m .19094 .74144 L .17161 .74494 L p .707 .577 .707 r
F P
0 g
s
.19291 .78396 m .18952 .80179 L .21644 .81189 L p .707 .577 .707 r
F P
0 g
s
.18952 .80179 m .1928 .78452 L p .17233 .77235 L .707 .577 .707 r
F P
0 g
s
.1928 .78452 m .19291 .78396 L .19223 .78358 L p .707 .577 .707 r
F P
0 g
s
.19223 .78358 m .17233 .77235 L p .1928 .78452 L .707 .577 .707 r
F P
0 g
s
.18432 .78093 m .17547 .75585 L p .1604 .74495 L .707 .577 .707 r
F P
0 g
s
.17547 .75585 m .17161 .74494 L .16887 .74494 L p .707 .577 .707 r
F P
0 g
s
.16887 .74494 m .1604 .74495 L p .17547 .75585 L .707 .577 .707 r
F P
0 g
s
.17161 .74494 m .18432 .78093 L .20365 .77743 L p .707 .577 .707 r
F P
0 g
s
.63172 .29357 m .63841 .79613 L .64841 .78441 L p .707 .577 .707 r
F P
0 g
s
.64841 .78441 m .64172 .28186 L .63172 .29357 L p .707 .577 .707 r
F P
0 g
s
.17127 .61958 m .15865 .67224 L .17065 .68519 L p .707 .577 .707 r
F P
0 g
s
.31083 .80677 m .30744 .8246 L .33125 .82158 L p .707 .577 .707 r
F P
0 g
s
.33125 .82158 m .33463 .80375 L .31083 .80677 L p .707 .577 .707 r
F P
0 g
s
.68623 .80234 m .68284 .82017 L .66227 .80856 L p .707 .577 .707 r
F P
0 g
s
.66227 .80856 m .66566 .79073 L .68623 .80234 L p .707 .577 .707 r
F P
0 g
s
.66092 .71389 m .67363 .74989 L .64809 .75653 L p .707 .577 .707 r
F P
0 g
s
.15865 .67224 m .17127 .61958 L .16875 .60778 L p .707 .577 .707 r
F P
0 g
s
.17233 .77235 m .16894 .79018 L .18952 .80179 L p .707 .577 .707 r
F P
0 g
s
.16894 .79018 m .17176 .77535 L p .16012 .76037 L .707 .577 .707 r
F P
0 g
s
.17176 .77535 m .17233 .77235 L .16962 .76969 L p .707 .577 .707 r
F P
0 g
s
.16962 .76969 m .16012 .76037 L p .17176 .77535 L .707 .577 .707 r
F P
0 g
s
.17311 .78094 m .16212 .74984 L p .15838 .74148 L .707 .577 .707 r
F P
0 g
s
.16212 .74984 m .1604 .74495 L .16005 .74436 L p .707 .577 .707 r
F P
0 g
s
.16005 .74436 m .15838 .74148 L p .16212 .74984 L .707 .577 .707 r
F P
0 g
s
.1604 .74495 m .17311 .78094 L .18432 .78093 L p .707 .577 .707 r
F P
0 g
s
.33463 .80375 m .33125 .82158 L .34753 .81511 L p .707 .577 .707 r
F P
0 g
s
.34753 .81511 m .35092 .79729 L .33463 .80375 L p .707 .577 .707 r
F P
0 g
s
.66566 .79073 m .66227 .80856 L .63534 .79845 L p .707 .577 .707 r
F P
0 g
s
.16875 .60778 m .15613 .66044 L .15865 .67224 L p .707 .577 .707 r
F P
0 g
s
.16012 .76037 m .15673 .7782 L .16894 .79018 L p .707 .577 .707 r
F P
0 g
s
.15613 .66044 m .16875 .60778 L .17597 .5983 L p .707 .577 .707 r
F P
0 g
s
.64172 .28186 m .64841 .78441 L .64432 .77263 L p .707 .577 .707 r
F P
0 g
s
.64432 .77263 m .63763 .27007 L .64172 .28186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35092 .79729 m .34753 .81511 L .3547 .80584 L p .707 .577 .707 r
F P
0 g
s
.3547 .80584 m .35809 .78802 L .35092 .79729 L p .707 .577 .707 r
F P
0 g
s
.15673 .7782 m .16012 .76037 L .15747 .7492 L p .707 .577 .707 r
F P
0 g
s
.15747 .7492 m .15408 .76703 L .15673 .7782 L p .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15747 .7492 L .15977 .74622 L p .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .17311 .78094 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15874 .7425 m .17109 .77747 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15838 .74148 m .15874 .7425 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .15838 .74148 L .16577 .73486 L p .707 .577 .707 r
F P
0 g
s
.15977 .74622 m .16463 .73993 L p .16078 .74983 L .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15977 .74622 L .16078 .74983 L .707 .577 .707 r
F
.17597 .5983 m .16334 .65096 L .15613 .66044 L p F P
0 g
s
.16334 .65096 m .17597 .5983 L .19221 .59205 L p .707 .577 .707 r
F P
0 g
s
.35809 .78802 m .3547 .80584 L .35205 .79467 L p .707 .577 .707 r
F P
0 g
s
.35205 .79467 m .35543 .77685 L .35809 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16577 .73486 m .17848 .77085 L .17109 .77747 L p .707 .577 .707 r
F P
0 g
s
.63763 .27007 m .64432 .77263 L .62655 .76192 L p .707 .577 .707 r
F P
0 g
s
.62655 .76192 m .61986 .25936 L .63763 .27007 L p .707 .577 .707 r
F P
0 g
s
.19221 .59205 m .17958 .64471 L .16334 .65096 L p .707 .577 .707 r
F P
0 g
s
.16463 .73993 m .16125 .75776 L .15408 .76703 L p .707 .577 .707 r
F P
0 g
s
.17958 .64471 m .19221 .59205 L .21588 .58965 L p .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .33062 .71324 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34044 .68285 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34043 .6829 L .34029 .68281 L p .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34994 .70974 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33062 .71324 m .31791 .67725 L .33723 .67375 L p .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .34044 .68285 L p .32012 .67006 L .707 .577 .707 r
F P
0 g
s
.34029 .68281 m .32012 .67006 L p .34044 .68285 L .707 .577 .707 r
F P
0 g
s
.32012 .67006 m .33274 .6174 L .35305 .63024 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36389 .26867 L .387 .25817 L p .707 .577 .707 r
F P
0 g
s
.17848 .77085 m .16577 .73486 L .18183 .72575 L p .707 .577 .707 r
F P
0 g
s
.35543 .77685 m .35205 .79467 L .33983 .7827 L p .707 .577 .707 r
F P
0 g
s
.33983 .7827 m .34322 .76487 L .35543 .77685 L p .707 .577 .707 r
F P
0 g
s
.16125 .75776 m .16463 .73993 L .18092 .73347 L p .707 .577 .707 r
F P
0 g
s
.21588 .58965 m .20326 .64232 L .17958 .64471 L p .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .17848 .77085 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.18219 .72677 m .19454 .76174 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .18183 .72575 L .205 .71502 L p .707 .577 .707 r
F P
0 g
s
.17753 .7513 m .18092 .73347 L .19251 .732 L p .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .19454 .76174 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.205 .71502 m .20673 .71991 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.20673 .71991 m .21771 .75102 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .205 .71502 L .23301 .70375 L p .707 .577 .707 r
F P
0 g
s
.23301 .70375 m .24572 .73974 L .21771 .75102 L p .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .20473 .73045 L .22729 .731 L p .707 .577 .707 r
F P
0 g
s
.22729 .731 m .23373 .73116 L p .23062 .7328 L .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .22729 .731 L .23062 .7328 L .707 .577 .707 r
F
.19251 .732 m .20473 .73045 L p .19865 .73511 L F P
0 g
s
.17753 .7513 m .19251 .732 L .19865 .73511 L .707 .577 .707 r
F
.18183 .72575 m .18219 .72677 L p .18177 .72655 L F P
0 g
s
.20326 .64232 m .21588 .58965 L .24467 .59134 L p .707 .577 .707 r
F P
0 g
s
.33274 .6174 m .32012 .67006 L .29348 .65859 L p .707 .577 .707 r
F P
0 g
s
.29348 .65859 m .30611 .60593 L .33274 .6174 L p .707 .577 .707 r
F P
0 g
s
.18092 .73347 m .17753 .7513 L .16125 .75776 L p .707 .577 .707 r
F P
0 g
s
.61986 .25936 m .62655 .76192 L .59682 .75335 L p .707 .577 .707 r
F P
0 g
s
.59682 .75335 m .59014 .25079 L .61986 .25936 L p .707 .577 .707 r
F P
0 g
s
.23205 .644 m .24467 .59134 L .27576 .59695 L p .707 .577 .707 r
F P
0 g
s
.24467 .59134 m .23205 .644 L .20326 .64232 L p .707 .577 .707 r
F P
0 g
s
.30611 .60593 m .29348 .65859 L .26314 .64961 L p .707 .577 .707 r
F P
0 g
s
.26314 .64961 m .27576 .59695 L .30611 .60593 L p .707 .577 .707 r
F P
0 g
s
.27576 .59695 m .26314 .64961 L .23205 .644 L p .707 .577 .707 r
F P
0 g
s
.34322 .76487 m .33983 .7827 L .31926 .77109 L p .707 .577 .707 r
F P
0 g
s
.31926 .77109 m .32265 .75326 L .34322 .76487 L p .707 .577 .707 r
F P
0 g
s
.31791 .67725 m .33062 .71324 L .30508 .71988 L p .707 .577 .707 r
F P
0 g
s
.30508 .71988 m .29237 .68389 L .31791 .67725 L p .707 .577 .707 r
F P
0 g
s
.72815 .66332 m .74078 .61065 L .71043 .60167 L p .707 .577 .707 r
F P
0 g
s
.74078 .61065 m .72815 .66332 L .75851 .66879 L p .707 .577 .707 r
F P
0 g
s
.75919 .66874 m .75915 .66863 L .75851 .66879 L .707 .577 .707 r
F
.75915 .66863 m .74078 .61065 L .75826 .66799 L F
.75915 .66863 m .75826 .66799 L .75851 .66879 L F
.74617 .68221 m .75929 .66873 L .72736 .67111 L F
.76876 .69554 m .75929 .66873 L p .74617 .68221 L F P
0 g
s
.79676 .68426 m .76876 .66726 L .75929 .66873 L .707 .577 .707 r
F
.78623 .66454 m .78088 .64655 L .75945 .66871 L F
.77187 .61626 m .75929 .66873 L p .78088 .64655 L F P
0 g
s
.75929 .66873 m .76876 .69554 L .78641 .68843 L p .707 .577 .707 r
F P
0 g
s
.78641 .68843 m .79676 .68426 L p .75929 .66873 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .75924 .66892 L p .75945 .66871 L .707 .577 .707 r
F P
0 g
s
.78088 .64655 m .75929 .66873 L .75945 .66871 L .707 .577 .707 r
F
.77187 .61626 m .74078 .61065 L p .75915 .66863 L F P
0 g
s
.75924 .66892 m .75929 .66873 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .77187 .61626 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.7795 .67378 m .78962 .66402 L .76876 .66726 L .707 .577 .707 r
F
.79676 .68426 m .78962 .66402 L p .7795 .67378 L F P
0 g
s
.79676 .68426 m .81994 .67354 L p .80803 .66516 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .80708 .64715 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .78962 .66402 L p .80708 .64715 L F P
0 g
s
.80708 .64715 m .78962 .66402 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .77187 .61626 L p .78545 .66191 L F P
0 g
s
.78804 .67061 m .78962 .66402 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .80066 .61795 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.81994 .67354 m .81427 .65751 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.82433 .61555 m .80066 .61795 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .81427 .65751 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .82433 .61555 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.82582 .66119 m .82386 .65308 L .81427 .65751 L .707 .577 .707 r
F
.836 .66443 m .82779 .65675 L .82582 .66119 L F
.82779 .65675 m .82386 .65308 L .82582 .66119 L F
.83296 .66615 m .836 .66443 L p .81427 .65751 L F P
0 g
s
.82714 .65157 m .82644 .64262 L .81917 .65525 L .707 .577 .707 r
F
.82433 .61555 m .81427 .65751 L p .82644 .64262 L F P
0 g
s
.82644 .64262 m .81427 .65751 L .81917 .65525 L .707 .577 .707 r
F
.82329 .62843 m .80722 .63755 L p .82386 .65308 L F P
0 g
s
.836 .66443 m .83085 .64985 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84057 .60931 m .82433 .61555 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.82795 .66197 m .83085 .64985 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .84057 .60931 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83754 .6541 m .83478 .64523 L .83085 .64985 L .707 .577 .707 r
F
.84339 .65781 m .83761 .64937 L .83754 .6541 L F
.83761 .64937 m .83478 .64523 L .83754 .6541 L F
.83085 .64985 m .836 .66443 L .84314 .65803 L p F P
0 g
s
.84314 .65803 m .84339 .65781 L p .83085 .64985 L .707 .577 .707 r
F P
0 g
s
.83629 .64347 m .83732 .63529 L .83315 .64715 L .707 .577 .707 r
F
.84057 .60931 m .83085 .64985 L p .83732 .63529 L F P
0 g
s
.83732 .63529 m .83085 .64985 L .83315 .64715 L .707 .577 .707 r
F
.83068 .62182 m .82329 .62843 L p .83478 .64523 L F P
0 g
s
.84339 .65781 m .83773 .64178 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.84778 .59982 m .84057 .60931 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83773 .64178 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .84778 .59982 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.84339 .65781 m .84137 .65434 L p .8397 .64924 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .83068 .62182 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.835 .64633 m .83516 .65248 L p .83629 .64347 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83422 .64806 L .82795 .66197 L .707 .577 .707 r
F
.83629 .64347 m .83315 .64715 L .82795 .66197 L F
.82329 .62843 m .83085 .64985 L p .83478 .64523 L F P
0 g
s
.83516 .65248 m .83264 .64069 L p .8347 .63514 L .707 .577 .707 r
F P
0 g
s
.83068 .62182 m .83773 .64178 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.8347 .63514 m .83658 .63926 L .83516 .65248 L .707 .577 .707 r
F
.82866 .61834 m .83068 .62182 L p .83599 .63796 L F P
0 g
s
.83773 .64178 m .83516 .65248 L p .83658 .63926 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .82866 .61834 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .84778 .59982 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .83422 .63409 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .84527 .58803 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82795 .66197 L p .83315 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82329 .62843 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84137 .65434 m .83016 .65435 L p .82963 .64175 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .82064 .62774 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82866 .61834 m .83422 .63409 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .83264 .64069 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82866 .61834 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .82069 .62755 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .81744 .61836 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .84527 .58803 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82064 .62774 m .82069 .62755 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83327 .57507 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .83422 .63409 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82963 .64175 m .82921 .63167 L .83422 .63409 L .707 .577 .707 r
F
.83422 .63409 m .84137 .65434 L p .82963 .64175 L F P
0 g
s
.84137 .65434 m .83422 .63409 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.83796 .62633 m .83773 .64178 L .83658 .63926 L .707 .577 .707 r
F
.8347 .63514 m .83796 .62633 L .83658 .63926 L F
.8397 .64924 m .83599 .63796 L .83773 .64178 L F
.83773 .64178 m .84339 .65781 L p .8397 .64924 L F P
0 g
s
.84778 .59982 m .83773 .64178 L p .83796 .62633 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81994 .67354 L .83296 .66615 L p .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81171 .66822 L p .81917 .65525 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .82795 .66197 L p .82714 .65157 L .707 .577 .707 r
F P
0 g
s
.82714 .65157 m .81917 .65525 L .81171 .66822 L .707 .577 .707 r
F
.80722 .63755 m .81427 .65751 L p .82386 .65308 L F P
0 g
s
.80722 .63755 m .78405 .64827 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .80722 .63755 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .79676 .68426 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .78804 .67061 L p .79442 .66275 L .707 .577 .707 r
F P
0 g
s
.80803 .66516 m .80184 .66079 L .79833 .67703 L .707 .577 .707 r
F
.80803 .66516 m .79833 .67703 L .79676 .68426 L F
.78405 .64827 m .78962 .66402 L p .80184 .66079 L F P
0 g
s
.78804 .67061 m .81171 .66822 L p .80963 .65874 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .79442 .66275 L .78804 .67061 L .707 .577 .707 r
F
.78405 .64827 m .75605 .65955 L p .76876 .66726 L F P
0 g
s
.78962 .66402 m .78405 .64827 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75605 .65955 m .75929 .66873 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75924 .66892 m .78804 .67061 L p .78623 .66454 L .707 .577 .707 r
F P
0 g
s
.78623 .66454 m .75945 .66871 L .75924 .66892 L .707 .577 .707 r
F
.75605 .65955 m .72594 .67027 L p .72736 .67111 L F P
0 g
s
.75929 .66873 m .75605 .65955 L p .72736 .67111 L .707 .577 .707 r
F P
0 g
s
.75851 .66879 m .75924 .66892 L p .75919 .66874 L .707 .577 .707 r
F P
0 g
s
.387 .25817 m .39369 .76073 L .37058 .77122 L p .707 .577 .707 r
F P
0 g
s
.39369 .76073 m .387 .25817 L .42095 .24992 L p .707 .577 .707 r
F P
0 g
s
.20473 .73045 m .20134 .74828 L .17753 .7513 L p .707 .577 .707 r
F P
0 g
s
.69781 .65434 m .71043 .60167 L .6838 .5902 L p .707 .577 .707 r
F P
0 g
s
.71043 .60167 m .69781 .65434 L .72815 .66332 L p .707 .577 .707 r
F P
0 g
s
.29237 .68389 m .30508 .71988 L .27583 .72901 L p .707 .577 .707 r
F P
0 g
s
.27583 .72901 m .26311 .69302 L .29237 .68389 L p .707 .577 .707 r
F P
0 g
s
.32265 .75326 m .31926 .77109 L .29233 .76098 L p .707 .577 .707 r
F P
0 g
s
.29233 .76098 m .29572 .74316 L .32265 .75326 L p .707 .577 .707 r
F P
0 g
s
.59014 .25079 m .59682 .75335 L .55806 .74774 L p .707 .577 .707 r
F P
0 g
s
.55806 .74774 m .55138 .24518 L .59014 .25079 L p .707 .577 .707 r
F P
0 g
s
.67117 .64287 m .6838 .5902 L .66349 .57736 L p .707 .577 .707 r
F P
0 g
s
.6838 .5902 m .67117 .64287 L .69781 .65434 L p .707 .577 .707 r
F P
0 g
s
.73865 .70627 m .72594 .67027 L .69669 .67941 L p .707 .577 .707 r
F P
0 g
s
.72594 .67027 m .73865 .70627 L .76876 .69554 L p .707 .577 .707 r
F P
0 g
s
.24572 .73974 m .23301 .70375 L .26311 .69302 L p .707 .577 .707 r
F P
0 g
s
.23373 .73116 m .23034 .74899 L .20134 .74828 L p .707 .577 .707 r
F P
0 g
s
.26311 .69302 m .27583 .72901 L .24572 .73974 L p .707 .577 .707 r
F P
0 g
s
.69669 .67941 m .7094 .7154 L .73865 .70627 L p .707 .577 .707 r
F P
0 g
s
.42764 .75248 m .42095 .24992 L .46243 .24472 L p .707 .577 .707 r
F P
0 g
s
.42095 .24992 m .42764 .75248 L .39369 .76073 L p .707 .577 .707 r
F P
0 g
s
.29572 .74316 m .29233 .76098 L .26169 .75337 L p .707 .577 .707 r
F P
0 g
s
.26169 .75337 m .26508 .73554 L .29572 .74316 L p .707 .577 .707 r
F P
0 g
s
.7094 .7154 m .69669 .67941 L .67115 .68605 L p .707 .577 .707 r
F P
0 g
s
.23034 .74899 m .23373 .73116 L .26508 .73554 L p .707 .577 .707 r
F P
0 g
s
.26508 .73554 m .26169 .75337 L .23034 .74899 L p .707 .577 .707 r
F P
0 g
s
.67115 .68605 m .68386 .72204 L .7094 .7154 L p .707 .577 .707 r
F P
0 g
s
.66349 .57736 m .65086 .63003 L .67117 .64287 L p .707 .577 .707 r
F P
0 g
s
.65086 .63003 m .66349 .57736 L .65148 .56441 L p .707 .577 .707 r
F P
0 g
s
.55138 .24518 m .55806 .74774 L .51406 .74565 L p .707 .577 .707 r
F P
0 g
s
.51406 .74565 m .50737 .24309 L .55138 .24518 L p .707 .577 .707 r
F P
0 g
s
.72729 .76494 m .73068 .74711 L .70004 .73949 L p .707 .577 .707 r
F P
0 g
s
.73068 .74711 m .72729 .76494 L .75865 .76931 L p .707 .577 .707 r
F P
0 g
s
.75865 .76931 m .76204 .75149 L .73068 .74711 L p .707 .577 .707 r
F P
0 g
s
.46912 .74728 m .46243 .24472 L .50737 .24309 L p .707 .577 .707 r
F P
0 g
s
.46243 .24472 m .46912 .74728 L .42764 .75248 L p .707 .577 .707 r
F P
0 g
s
.76204 .75149 m .75865 .76931 L .78765 .77003 L p .707 .577 .707 r
F P
0 g
s
.78765 .77003 m .79104 .7522 L .76204 .75149 L p .707 .577 .707 r
F P
0 g
s
.69666 .75732 m .70004 .73949 L .67312 .72939 L p .707 .577 .707 r
F P
0 g
s
.70004 .73949 m .69666 .75732 L .72729 .76494 L p .707 .577 .707 r
F P
0 g
s
.68386 .72204 m .67115 .68605 L .65183 .68954 L p .707 .577 .707 r
F P
0 g
s
.50737 .24309 m .51406 .74565 L .46912 .74728 L p .707 .577 .707 r
F P
0 g
s
.67312 .72939 m .66973 .74721 L .69666 .75732 L p .707 .577 .707 r
F P
0 g
s
.66973 .74721 m .67311 .72941 L p .65254 .71778 L .707 .577 .707 r
F P
0 g
s
.67311 .72941 m .67312 .72939 L .67309 .72937 L p .707 .577 .707 r
F P
0 g
s
.67309 .72937 m .65254 .71778 L p .67311 .72941 L .707 .577 .707 r
F P
0 g
s
.66454 .72554 m .65578 .70074 L p .64061 .68956 L .707 .577 .707 r
F P
0 g
s
.65578 .70074 m .65183 .68954 L .64901 .68955 L p .707 .577 .707 r
F P
0 g
s
.64901 .68955 m .64061 .68956 L p .65578 .70074 L .707 .577 .707 r
F P
0 g
s
.65183 .68954 m .66454 .72554 L .68386 .72204 L p .707 .577 .707 r
F P
0 g
s
.65148 .56441 m .63886 .61707 L .65086 .63003 L p .707 .577 .707 r
F P
0 g
s
.79104 .7522 m .78765 .77003 L .81146 .767 L p .707 .577 .707 r
F P
0 g
s
.81146 .767 m .81485 .74918 L .79104 .7522 L p .707 .577 .707 r
F P
0 g
s
.63886 .61707 m .65148 .56441 L .64897 .55262 L p .707 .577 .707 r
F P
0 g
s
.65254 .71778 m .64915 .7356 L .66973 .74721 L p .707 .577 .707 r
F P
0 g
s
.64915 .7356 m .65207 .72025 L p .64033 .7058 L .707 .577 .707 r
F P
0 g
s
.65207 .72025 m .65254 .71778 L .65031 .71559 L p .707 .577 .707 r
F P
0 g
s
.65031 .71559 m .64033 .7058 L p .65207 .72025 L .707 .577 .707 r
F P
0 g
s
.65332 .72555 m .64244 .69473 L p .63859 .68608 L .707 .577 .707 r
F P
0 g
s
.64244 .69473 m .64061 .68956 L .64024 .68893 L p .707 .577 .707 r
F P
0 g
s
.64024 .68893 m .63859 .68608 L p .64244 .69473 L .707 .577 .707 r
F P
0 g
s
.64061 .68956 m .65332 .72555 L .66454 .72554 L p .707 .577 .707 r
F P
0 g
s
.81485 .74918 m .81146 .767 L .82774 .76054 L p .707 .577 .707 r
F P
0 g
s
.82774 .76054 m .83113 .74271 L .81485 .74918 L p .707 .577 .707 r
F P
0 g
s
.64897 .55262 m .63634 .60528 L .63886 .61707 L p .707 .577 .707 r
F P
0 g
s
.64033 .7058 m .63694 .72363 L .64915 .7356 L p .707 .577 .707 r
F P
0 g
s
.63634 .60528 m .64897 .55262 L .65618 .54313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83113 .74271 m .82774 .76054 L .83491 .75127 L p .707 .577 .707 r
F P
0 g
s
.83491 .75127 m .8383 .73344 L .83113 .74271 L p .707 .577 .707 r
F P
0 g
s
.63694 .72363 m .64033 .7058 L .63768 .69463 L p .707 .577 .707 r
F P
0 g
s
.63768 .69463 m .63429 .71246 L .63694 .72363 L p .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .63768 .69463 L .64017 .69141 L p .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .65332 .72555 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63906 .68739 m .65131 .72208 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63859 .68608 m .63906 .68739 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .63859 .68608 L .64598 .67947 L p .707 .577 .707 r
F P
0 g
s
.64017 .69141 m .64485 .68536 L p .64114 .69489 L .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .64017 .69141 L .64114 .69489 L .707 .577 .707 r
F
.65618 .54313 m .64356 .59579 L .63634 .60528 L p F P
0 g
s
.64356 .59579 m .65618 .54313 L .67242 .53688 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .39777 .57378 L .36742 .5648 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .41602 .63201 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.39777 .57378 m .38862 .61193 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.38862 .61193 m .38514 .62644 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.41622 .632 m .39777 .57378 L .41602 .63201 L .707 .577 .707 r
F
.40308 .64552 m .41625 .63199 L .3842 .63438 L F
.42575 .65889 m .41625 .63199 L p .40308 .64552 L F P
0 g
s
.45375 .64762 m .42562 .63054 L .41625 .63199 L .707 .577 .707 r
F
.44326 .6278 m .43789 .60976 L .41629 .63199 L F
.42886 .57939 m .41625 .63199 L p .43789 .60976 L F P
0 g
s
.41625 .63199 m .42575 .65889 L .44346 .65176 L p .707 .577 .707 r
F P
0 g
s
.44346 .65176 m .45375 .64762 L p .41625 .63199 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .41623 .63205 L p .41629 .63199 L .707 .577 .707 r
F P
0 g
s
.43789 .60976 m .41625 .63199 L .41629 .63199 L .707 .577 .707 r
F
.42886 .57939 m .39777 .57378 L p .41621 .63196 L F P
0 g
s
.41623 .63205 m .41625 .63199 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .42886 .57939 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.43642 .63709 m .44657 .62728 L .42562 .63054 L .707 .577 .707 r
F
.45375 .64762 m .44657 .62728 L p .43642 .63709 L F P
0 g
s
.45375 .64762 m .47693 .6369 L p .46495 .62846 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .46409 .61036 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .44657 .62728 L p .46409 .61036 L F P
0 g
s
.46409 .61036 m .44657 .62728 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .42886 .57939 L p .44249 .62522 L F P
0 g
s
.44503 .63374 m .44657 .62728 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45765 .58108 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.47693 .6369 m .47123 .62077 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.48132 .57868 m .45765 .58108 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .47123 .62077 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .48132 .57868 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.48276 .62449 m .48077 .61637 L .47123 .62077 L .707 .577 .707 r
F
.49299 .62778 m .48473 .62006 L .48276 .62449 L F
.48473 .62006 m .48077 .61637 L .48276 .62449 L F
.48414 .61481 m .48344 .60583 L .47611 .61852 L F
.48132 .57868 m .47123 .62077 L p .48344 .60583 L F P
0 g
s
.48344 .60583 m .47123 .62077 L .47611 .61852 L .707 .577 .707 r
F
.48028 .59179 m .46421 .6009 L p .48077 .61637 L F P
0 g
s
.49299 .62778 m .48781 .61311 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49756 .57243 m .48132 .57868 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48494 .6251 m .48781 .61311 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .49756 .57243 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.4945 .61739 m .49172 .60852 L .48781 .61311 L .707 .577 .707 r
F
.50038 .62116 m .49457 .61267 L .4945 .61739 L F
.49457 .61267 m .49172 .60852 L .4945 .61739 L F
.48781 .61311 m .49299 .62778 L .50018 .62134 L p F P
0 g
s
.50018 .62134 m .50038 .62116 L p .48781 .61311 L .707 .577 .707 r
F P
0 g
s
.49327 .60671 m .49429 .5985 L .4901 .61042 L .707 .577 .707 r
F
.49756 .57243 m .48781 .61311 L p .49429 .5985 L F P
0 g
s
.49429 .5985 m .48781 .61311 L .4901 .61042 L .707 .577 .707 r
F
.48767 .58517 m .48028 .59179 L p .49172 .60852 L F P
0 g
s
.50038 .62116 m .49468 .60504 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.50477 .56295 m .49756 .57243 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49468 .60504 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .50477 .56295 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.50038 .62116 m .49836 .61769 L p .49664 .61247 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .48767 .58517 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.49197 .60956 m .49215 .61561 L p .49327 .60671 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49122 .61123 L .48494 .6251 L .707 .577 .707 r
F
.49327 .60671 m .4901 .61042 L .48494 .6251 L F
.48028 .59179 m .48781 .61311 L p .49172 .60852 L F P
0 g
s
.49215 .61561 m .48963 .60381 L p .49165 .59838 L .707 .577 .707 r
F P
0 g
s
.48767 .58517 m .49468 .60504 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49165 .59838 m .49354 .60253 L .49215 .61561 L .707 .577 .707 r
F
.48565 .5817 m .48767 .58517 L p .49295 .60124 L F P
0 g
s
.49468 .60504 m .49215 .61561 L p .49354 .60253 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48565 .5817 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .50477 .56295 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .49118 .59736 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .50226 .55115 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48494 .6251 L p .4901 .61042 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48028 .59179 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49836 .61769 m .48715 .61771 L p .48662 .60497 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .47763 .59086 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48565 .5817 m .49118 .59736 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48963 .60381 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .48565 .5817 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .47765 .59081 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47443 .58171 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .50226 .55115 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47763 .59086 m .47765 .59081 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .49026 .5382 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .49118 .59736 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48662 .60497 m .4862 .59495 L .49118 .59736 L .707 .577 .707 r
F
.49118 .59736 m .49836 .61769 L p .48662 .60497 L F P
0 g
s
.49836 .61769 m .49118 .59736 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49492 .58954 m .49468 .60504 L .49354 .60253 L .707 .577 .707 r
F
.49165 .59838 m .49492 .58954 L .49354 .60253 L F
.49664 .61247 m .49295 .60124 L .49468 .60504 L F
.49468 .60504 m .50038 .62116 L p .49664 .61247 L F P
0 g
s
.50477 .56295 m .49468 .60504 L p .49492 .58954 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .47693 .6369 L .49002 .62947 L p .707 .577 .707 r
F P
0 g
s
.49002 .62947 m .49299 .62778 L p .47123 .62077 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .4687 .63134 L p .47611 .61852 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .48494 .6251 L p .48414 .61481 L .707 .577 .707 r
F P
0 g
s
.48414 .61481 m .47611 .61852 L .4687 .63134 L .707 .577 .707 r
F
.46421 .6009 m .47123 .62077 L p .48077 .61637 L F P
0 g
s
.46421 .6009 m .44104 .61162 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .46421 .6009 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45375 .64762 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .44503 .63374 L p .45131 .62603 L .707 .577 .707 r
F P
0 g
s
.46495 .62846 m .45872 .62407 L .4553 .64027 L .707 .577 .707 r
F
.46495 .62846 m .4553 .64027 L .45375 .64762 L F
.44104 .61162 m .44657 .62728 L p .45872 .62407 L F P
0 g
s
.44503 .63374 m .4687 .63134 L p .46664 .62199 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .45131 .62603 L .44503 .63374 L .707 .577 .707 r
F
.44104 .61162 m .41304 .6229 L p .42562 .63054 L F P
0 g
s
.44657 .62728 m .44104 .61162 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41304 .6229 m .41625 .63199 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41623 .63205 m .44503 .63374 L p .44326 .6278 L .707 .577 .707 r
F P
0 g
s
.44326 .6278 m .41629 .63199 L .41623 .63205 L .707 .577 .707 r
F
.41304 .6229 m .38293 .63363 L p .3842 .63438 L F P
0 g
s
.41625 .63199 m .41304 .6229 L p .3842 .63438 L .707 .577 .707 r
F P
0 g
s
.41602 .63201 m .41623 .63205 L p .41622 .632 L .707 .577 .707 r
F P
0 g
s
.3548 .61746 m .36742 .5648 L .34079 .55333 L p .707 .577 .707 r
F P
0 g
s
.36742 .5648 m .3548 .61746 L .38514 .62644 L p .707 .577 .707 r
F P
0 g
s
.8383 .73344 m .83491 .75127 L .83226 .7401 L p .707 .577 .707 r
F P
0 g
s
.83226 .7401 m .83565 .72228 L .8383 .73344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64598 .67947 m .65869 .71546 L .65131 .72208 L p .707 .577 .707 r
F P
0 g
s
.67242 .53688 m .6598 .58955 L .64356 .59579 L p .707 .577 .707 r
F P
0 g
s
.64485 .68536 m .64146 .70319 L .63429 .71246 L p .707 .577 .707 r
F P
0 g
s
.32816 .60599 m .34079 .55333 L .32048 .54049 L p .707 .577 .707 r
F P
0 g
s
.34079 .55333 m .32816 .60599 L .3548 .61746 L p .707 .577 .707 r
F P
0 g
s
.6598 .58955 m .67242 .53688 L .69609 .53449 L p .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .81083 .65785 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82069 .62755 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .82064 .62774 L .82016 .62743 L p .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83016 .65435 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81083 .65785 m .79812 .62186 L .81744 .61836 L p .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .82069 .62755 L p .80033 .6149 L .707 .577 .707 r
F P
0 g
s
.82016 .62743 m .80033 .6149 L p .82069 .62755 L .707 .577 .707 r
F P
0 g
s
.80033 .6149 m .81295 .56223 L .83327 .57507 L p .707 .577 .707 r
F P
0 g
s
.39564 .66962 m .38293 .63363 L .35368 .64276 L p .707 .577 .707 r
F P
0 g
s
.38293 .63363 m .39564 .66962 L .42575 .65889 L p .707 .577 .707 r
F P
0 g
s
.35368 .64276 m .36639 .67875 L .39564 .66962 L p .707 .577 .707 r
F P
0 g
s
.36639 .67875 m .35368 .64276 L .32814 .6494 L p .707 .577 .707 r
F P
0 g
s
.65869 .71546 m .64598 .67947 L .66205 .67035 L p .707 .577 .707 r
F P
0 g
s
.83565 .72228 m .83226 .7401 L .82005 .72813 L p .707 .577 .707 r
F P
0 g
s
.82005 .72813 m .82344 .7103 L .83565 .72228 L p .707 .577 .707 r
F P
0 g
s
.32814 .6494 m .34085 .68539 L .36639 .67875 L p .707 .577 .707 r
F P
0 g
s
.64146 .70319 m .64485 .68536 L .66113 .6789 L p .707 .577 .707 r
F P
0 g
s
.32048 .54049 m .30785 .59315 L .32816 .60599 L p .707 .577 .707 r
F P
0 g
s
.30785 .59315 m .32048 .54049 L .30847 .52754 L p .707 .577 .707 r
F P
0 g
s
.69609 .53449 m .68347 .58715 L .6598 .58955 L p .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .65869 .71546 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.66251 .67166 m .67476 .70635 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .66205 .67035 L .68522 .65963 L p .707 .577 .707 r
F P
0 g
s
.65774 .69673 m .66113 .6789 L .67365 .67731 L p .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .67476 .70635 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68522 .65963 m .68705 .66481 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68705 .66481 m .69793 .69563 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .68522 .65963 L .71323 .64836 L p .707 .577 .707 r
F P
0 g
s
.71323 .64836 m .72594 .68435 L .69793 .69563 L p .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .68494 .67588 L .70865 .67646 L p .707 .577 .707 r
F P
0 g
s
.70865 .67646 m .71394 .67659 L p .71139 .67794 L .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .70865 .67646 L .71139 .67794 L .707 .577 .707 r
F
.67365 .67731 m .68494 .67588 L p .67932 .68019 L F P
0 g
s
.65774 .69673 m .67365 .67731 L .67932 .68019 L .707 .577 .707 r
F
.66205 .67035 m .66251 .67166 L p .66197 .67139 L F P
0 g
s
.68347 .58715 m .69609 .53449 L .72488 .53618 L p .707 .577 .707 r
F P
0 g
s
.81295 .56223 m .80033 .6149 L .7737 .60343 L p .707 .577 .707 r
F P
0 g
s
.7737 .60343 m .78632 .55076 L .81295 .56223 L p .707 .577 .707 r
F P
0 g
s
.38428 .72747 m .38767 .70964 L .35703 .70203 L p .707 .577 .707 r
F P
0 g
s
.38767 .70964 m .38428 .72747 L .41564 .73185 L p .707 .577 .707 r
F P
0 g
s
.41564 .73185 m .41903 .71402 L .38767 .70964 L p .707 .577 .707 r
F P
0 g
s
.66113 .6789 m .65774 .69673 L .64146 .70319 L p .707 .577 .707 r
F P
0 g
s
.41903 .71402 m .41564 .73185 L .44464 .73256 L p .707 .577 .707 r
F P
0 g
s
.44464 .73256 m .44803 .71473 L .41903 .71402 L p .707 .577 .707 r
F P
0 g
s
.35365 .71985 m .35703 .70203 L .33011 .69192 L p .707 .577 .707 r
F P
0 g
s
.35703 .70203 m .35365 .71985 L .38428 .72747 L p .707 .577 .707 r
F P
0 g
s
.34085 .68539 m .32814 .6494 L .30882 .6529 L p .707 .577 .707 r
F P
0 g
s
.33011 .69192 m .32672 .70975 L .35365 .71985 L p .707 .577 .707 r
F P
0 g
s
.32672 .70975 m .33 .69248 L p .30953 .68031 L .707 .577 .707 r
F P
0 g
s
.33 .69248 m .33011 .69192 L .32943 .69154 L p .707 .577 .707 r
F P
0 g
s
.32943 .69154 m .30953 .68031 L p .33 .69248 L .707 .577 .707 r
F P
0 g
s
.32153 .68889 m .31267 .66381 L p .2976 .65291 L .707 .577 .707 r
F P
0 g
s
.31267 .66381 m .30882 .6529 L .30608 .6529 L p .707 .577 .707 r
F P
0 g
s
.30608 .6529 m .2976 .65291 L p .31267 .66381 L .707 .577 .707 r
F P
0 g
s
.30882 .6529 m .32153 .68889 L .34085 .68539 L p .707 .577 .707 r
F P
0 g
s
.71226 .58884 m .72488 .53618 L .75598 .54178 L p .707 .577 .707 r
F P
0 g
s
.72488 .53618 m .71226 .58884 L .68347 .58715 L p .707 .577 .707 r
F P
0 g
s
.78632 .55076 m .7737 .60343 L .74335 .59445 L p .707 .577 .707 r
F P
0 g
s
.74335 .59445 m .75598 .54178 L .78632 .55076 L p .707 .577 .707 r
F P
0 g
s
.30847 .52754 m .29585 .5802 L .30785 .59315 L p .707 .577 .707 r
F P
0 g
s
.75598 .54178 m .74335 .59445 L .71226 .58884 L p .707 .577 .707 r
F P
0 g
s
.44803 .71473 m .44464 .73256 L .46845 .72954 L p .707 .577 .707 r
F P
0 g
s
.46845 .72954 m .47184 .71171 L .44803 .71473 L p .707 .577 .707 r
F P
0 g
s
.82344 .7103 m .82005 .72813 L .79947 .71652 L p .707 .577 .707 r
F P
0 g
s
.79947 .71652 m .80286 .69869 L .82344 .7103 L p .707 .577 .707 r
F P
0 g
s
.79812 .62186 m .81083 .65785 L .78529 .66449 L p .707 .577 .707 r
F P
0 g
s
.78529 .66449 m .77258 .6285 L .79812 .62186 L p .707 .577 .707 r
F P
0 g
s
.29585 .5802 m .30847 .52754 L .30596 .51574 L p .707 .577 .707 r
F P
0 g
s
.30953 .68031 m .30614 .69814 L .32672 .70975 L p .707 .577 .707 r
F P
0 g
s
.68494 .67588 m .68155 .6937 L .65774 .69673 L p .707 .577 .707 r
F P
0 g
s
.30614 .69814 m .30896 .68332 L p .29732 .66833 L .707 .577 .707 r
F P
0 g
s
.30896 .68332 m .30953 .68031 L .30682 .67765 L p .707 .577 .707 r
F P
0 g
s
.30682 .67765 m .29732 .66833 L p .30896 .68332 L .707 .577 .707 r
F P
0 g
s
.31031 .6889 m .29932 .6578 L p .29558 .64944 L .707 .577 .707 r
F P
0 g
s
.29932 .6578 m .2976 .65291 L .29725 .65232 L p .707 .577 .707 r
F P
0 g
s
.29725 .65232 m .29558 .64944 L p .29932 .6578 L .707 .577 .707 r
F P
0 g
s
.2976 .65291 m .31031 .6889 L .32153 .68889 L p .707 .577 .707 r
F P
0 g
s
.47184 .71171 m .46845 .72954 L .48473 .72307 L p .707 .577 .707 r
F P
0 g
s
.48473 .72307 m .48812 .70525 L .47184 .71171 L p .707 .577 .707 r
F P
0 g
s
.77258 .6285 m .78529 .66449 L .75604 .67362 L p .707 .577 .707 r
F P
0 g
s
.75604 .67362 m .74333 .63763 L .77258 .6285 L p .707 .577 .707 r
F P
0 g
s
.80286 .69869 m .79947 .71652 L .77255 .70641 L p .707 .577 .707 r
F P
0 g
s
.77255 .70641 m .77594 .68858 L .80286 .69869 L p .707 .577 .707 r
F P
0 g
s
.30596 .51574 m .29333 .5684 L .29585 .5802 L p .707 .577 .707 r
F P
0 g
s
.29732 .66833 m .29393 .68616 L .30614 .69814 L p .707 .577 .707 r
F P
0 g
s
.72594 .68435 m .71323 .64836 L .74333 .63763 L p .707 .577 .707 r
F P
0 g
s
.71394 .67659 m .71055 .69442 L .68155 .6937 L p .707 .577 .707 r
F P
0 g
s
.74333 .63763 m .75604 .67362 L .72594 .68435 L p .707 .577 .707 r
F P
0 g
s
.29333 .5684 m .30596 .51574 L .31317 .50626 L p .707 .577 .707 r
F P
0 g
s
.77594 .68858 m .77255 .70641 L .74191 .6988 L p .707 .577 .707 r
F P
0 g
s
.74191 .6988 m .7453 .68097 L .77594 .68858 L p .707 .577 .707 r
F P
0 g
s
.71055 .69442 m .71394 .67659 L .7453 .68097 L p .707 .577 .707 r
F P
0 g
s
.7453 .68097 m .74191 .6988 L .71055 .69442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.48812 .70525 m .48473 .72307 L .4919 .7138 L p .707 .577 .707 r
F P
0 g
s
.4919 .7138 m .49529 .69598 L .48812 .70525 L p .707 .577 .707 r
F P
0 g
s
.29393 .68616 m .29732 .66833 L .29467 .65717 L p .707 .577 .707 r
F P
0 g
s
.29467 .65717 m .29128 .67499 L .29393 .68616 L p .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29467 .65717 L .29698 .65418 L p .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .31031 .6889 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29594 .65046 m .3083 .68543 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29558 .64944 m .29594 .65046 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .29558 .64944 L .30297 .64282 L p .707 .577 .707 r
F P
0 g
s
.29698 .65418 m .30184 .6479 L p .29798 .6578 L .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29698 .65418 L .29798 .6578 L .707 .577 .707 r
F
.31317 .50626 m .30055 .55892 L .29333 .5684 L p F P
0 g
s
.30055 .55892 m .31317 .50626 L .32941 .50001 L p .707 .577 .707 r
F P
0 g
s
.49529 .69598 m .4919 .7138 L .48925 .70264 L p .707 .577 .707 r
F P
0 g
s
.48925 .70264 m .49264 .68481 L .49529 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30297 .64282 m .31568 .67881 L .3083 .68543 L p .707 .577 .707 r
F P
0 g
s
.32941 .50001 m .31679 .55267 L .30055 .55892 L p .707 .577 .707 r
F P
0 g
s
.30184 .6479 m .29845 .66572 L .29128 .67499 L p .707 .577 .707 r
F P
0 g
s
.31679 .55267 m .32941 .50001 L .35308 .49761 L p .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .46782 .6212 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .47765 .59081 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47763 .59086 L .47749 .59077 L p .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .48715 .61771 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.46782 .6212 m .45511 .58521 L .47443 .58171 L p .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .47765 .59081 L p .45732 .57802 L .707 .577 .707 r
F P
0 g
s
.47749 .59077 m .45732 .57802 L p .47765 .59081 L .707 .577 .707 r
F P
0 g
s
.45732 .57802 m .46994 .52536 L .49026 .5382 L p .707 .577 .707 r
F P
0 g
s
.31568 .67881 m .30297 .64282 L .31904 .63371 L p .707 .577 .707 r
F P
0 g
s
.49264 .68481 m .48925 .70264 L .47704 .69066 L p .707 .577 .707 r
F P
0 g
s
.47704 .69066 m .48043 .67283 L .49264 .68481 L p .707 .577 .707 r
F P
0 g
s
.29845 .66572 m .30184 .6479 L .31812 .64143 L p .707 .577 .707 r
F P
0 g
s
.35308 .49761 m .34046 .55028 L .31679 .55267 L p .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31568 .67881 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.3194 .63473 m .33175 .6697 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31904 .63371 L .34221 .62299 L p .707 .577 .707 r
F P
0 g
s
.31473 .65926 m .31812 .64143 L .32972 .63996 L p .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .33175 .6697 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34221 .62299 m .34393 .62788 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34393 .62788 m .35492 .65898 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .34221 .62299 L .37021 .61171 L p .707 .577 .707 r
F P
0 g
s
.37021 .61171 m .38293 .6477 L .35492 .65898 L p .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .34193 .63841 L .36449 .63896 L p .707 .577 .707 r
F P
0 g
s
.36449 .63896 m .37093 .63912 L p .36783 .64076 L .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .36449 .63896 L .36783 .64076 L .707 .577 .707 r
F
.32972 .63996 m .34193 .63841 L p .33585 .64307 L F P
0 g
s
.31473 .65926 m .32972 .63996 L .33585 .64307 L .707 .577 .707 r
F
.31904 .63371 m .3194 .63473 L p .31898 .63452 L F P
0 g
s
.34046 .55028 m .35308 .49761 L .38187 .4993 L p .707 .577 .707 r
F P
0 g
s
.46994 .52536 m .45732 .57802 L .43069 .56655 L p .707 .577 .707 r
F P
0 g
s
.43069 .56655 m .44331 .51389 L .46994 .52536 L p .707 .577 .707 r
F P
0 g
s
.31812 .64143 m .31473 .65926 L .29845 .66572 L p .707 .577 .707 r
F P
0 g
s
.36925 .55196 m .38187 .4993 L .41296 .50491 L p .707 .577 .707 r
F P
0 g
s
.38187 .4993 m .36925 .55196 L .34046 .55028 L p .707 .577 .707 r
F P
0 g
s
.44331 .51389 m .43069 .56655 L .40034 .55757 L p .707 .577 .707 r
F P
0 g
s
.40034 .55757 m .41296 .50491 L .44331 .51389 L p .707 .577 .707 r
F P
0 g
s
.41296 .50491 m .40034 .55757 L .36925 .55196 L p .707 .577 .707 r
F P
0 g
s
.48043 .67283 m .47704 .69066 L .45646 .67905 L p .707 .577 .707 r
F P
0 g
s
.45646 .67905 m .45985 .66122 L .48043 .67283 L p .707 .577 .707 r
F P
0 g
s
.45511 .58521 m .46782 .6212 L .44228 .62784 L p .707 .577 .707 r
F P
0 g
s
.44228 .62784 m .42957 .59185 L .45511 .58521 L p .707 .577 .707 r
F P
0 g
s
.34193 .63841 m .33854 .65624 L .31473 .65926 L p .707 .577 .707 r
F P
0 g
s
.42957 .59185 m .44228 .62784 L .41303 .63697 L p .707 .577 .707 r
F P
0 g
s
.41303 .63697 m .40032 .60098 L .42957 .59185 L p .707 .577 .707 r
F P
0 g
s
.45985 .66122 m .45646 .67905 L .42954 .66894 L p .707 .577 .707 r
F P
0 g
s
.42954 .66894 m .43293 .65112 L .45985 .66122 L p .707 .577 .707 r
F P
0 g
s
.38293 .6477 m .37021 .61171 L .40032 .60098 L p .707 .577 .707 r
F P
0 g
s
.37093 .63912 m .36754 .65695 L .33854 .65624 L p .707 .577 .707 r
F P
0 g
s
.40032 .60098 m .41303 .63697 L .38293 .6477 L p .707 .577 .707 r
F P
0 g
s
.43293 .65112 m .42954 .66894 L .3989 .66133 L p .707 .577 .707 r
F P
0 g
s
.3989 .66133 m .40229 .6435 L .43293 .65112 L p .707 .577 .707 r
F P
0 g
s
.36754 .65695 m .37093 .63912 L .40229 .6435 L p .707 .577 .707 r
F P
0 g
s
.40229 .6435 m .3989 .66133 L .36754 .65695 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0I7oo001TOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
06Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
065oo`P000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00GGoo10000eYF00@005YFFUIJ
EPT000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001IOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001FOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`04001JEUYF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001Woo4P00CGoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUH000030019Ool005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD004Aoo`00E7oo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003Ool0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@0041oo`00E7oo00<005YFFUH00eYF00@005YFFUIJEPd000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol005Aoo`80009JEPH0009JEP80
00=oo`04001JEUYF0002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF100015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000003Yoo`00E7oo10000UYF00<005YFFUH00eYF00H005YF000007oo0002FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00=goo001COol30003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01EYF0`0000AJEP00000000EJEP03001JEUYF
00AJEP03001JEUYF00AJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Eoo`00Dgoo0`000eYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF1@000eYF0`0000=JEP00FUH01UYF00<005YFFUH015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
=7oo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
000000030005FUH40006FUH00`00FUIJEP04FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000bOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000EJEP04001JEUYFFUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0;goo001COol00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP03
FUH200000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02io
o`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH90002
FUH20006FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8002moo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YF0000;Woo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH70004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000jOol7000EOol20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00UYF10000UYF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH50002FUH20003Ool7
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`0ZOol003Ioo`@000=JEP04001JEUYFFUH9000=Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF000005YF0000
1UYF0`0027oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0:Woo000dOol30005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60008Ool20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool40007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol0039oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000Moo`04001JEUYF0007FUH0
0`00FUIJEP07FUH50007FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP03001JEUYF00=JEP8000Moo`T0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000/Ool0031oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000Eoo`<000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH30004Ool50004Ool40007FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000Aoo`8000IJEP03001JEUYF00=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00T000Qoo`8000EJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00
;goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000Aoo`8000AJEP04001JEUYFFUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000:
Ool300000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`800004FUH005YFFUH30008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000Uoo`8000IJ
EP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004Ool40003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEPd000AJEP04001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<0
009oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00004FUH005YF0002
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPH0009J
EP03001JEUYF009JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF00000`000UYF00T005YFFUIJEP00FUH005YF000015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH00eYF0`00
15YF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH30006FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000=JEP8000QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH0
0`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000goo001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001J
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20006FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000001eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0300000eYF0000000>0008FUH40007FUH00`00
FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0017oo0`0025YF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000eYF00@005YFFUIJEPH000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP05001JEP00001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP040000
15YF000000000eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000Eoo`03001JEUYF00IJEP03001JEUYF00EJEP<0
0003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002eoo`03
001JEUYF009JEPD0009JEP80009oo`T000AJEP03001JEUYF00MJEPD00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00IJEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD000Aoo`8000IJEP03001JEUYF
009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^
Ool002eoo`800005FUH00000FUH00005FUH01000FUH000002Goo1P0025YF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001eYF0P000eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP80
00Aoo`8000=JEP03001JEUYF00<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool002aoo`04001JEP000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
27oo0`0000Aoo`00000000EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEPL000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP8000Aoo`800006FUH00000001JEP002EYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000AJEP00000000=JEP04001JEUYF
FUH>0006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01EYF0P000goo0`0015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01`00;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000goo000000030006Ool30003
FUH60006FUH30004FUH40002FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF
10001eYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEPH0009JEP05001JEP00FUH0000]
Ool002aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000Mo
o`800004FUH000000004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH50006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20006FUH40009FUH00`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH01000FUIJ
EUYF0P0000=JEP000000;Woo000/Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH60004Ool01000FUH000000UYF00<005YFFUH00eYF00@005YF000000EJEP03001J
EUYF00IJEP03001JEP0000D0009JEP03001JEUYF00EJEP@000aJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<00003FUH005YF00EJEP04001JEP000002FUH00`00Oomoo`0^Ool002eo
o`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2@0000=JEP00
FUH015YF0P001eYF00<005YFFUH01EYF0`001UYF10001UYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00003`0000AJEP000000035oo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF009J
EP800003FUH005YF00IJEP03001JEUYF00=JEP<000UJEP03001JEUYF008000=JEP03001JEUYF00=J
EP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP04FUH2000cOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUH0
05YF00000UYF0`000eYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01EYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF4`0015YF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
=Goo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH20005
FUH00`00FUIJEP02FUH50005FUH30007FUH00`00FUIJEP04FUH20006FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0100015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF0P00=goo000`Ool00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH20002FUH00`00FUIJ
EP0700001EYF001JEUYF000015YF1@001UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000MJEP<003Uoo`00<Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH00UYF1`00
0UYF00<005YFFUH00eYF00@005YFFUH000AJEPD000IJEP03001JEUYF00QJEP800003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL003aoo`00
<goo00@005YFFUH000MJEP03001JEUYF00MJEP04001JEUYFFUH30005FUH01000FUIJEP0015YF0`00
0UYF00<005YFFUH00UYF00@005YFFUH000AJEPD000IJEP03001JEUYF00UJEP<000AJEP03001JEUYF
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003eoo`00
=7oo0`001eYF00<005YFFUH01eYF100025YF10001EYF00<005YF00000P000UYF00<005YF00000UYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH0009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUIJEUYF400015YF00<0
05YFFUH01eYF00@005YFFUIJEP<003Yoo`00=Woo0P001UYF00<005YFFUH01UYF0P0000=JEP00FUH0
25YF00@005YFFUH000EJEP04001JEUYFFUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH60004FUH20002FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP05FUH2
000hOol003Qoo`8000AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH00`00FUIJEP05FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000D0009JEP03001JEUYF00IJEP<003Io
o`00>Woo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00<005YFFUH00UYF0`0025YF00<0
05YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH01EYF0`001Woo10001eYF00<005YFFUH00P00=7oo000lOol500000eYF001JEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09
FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00=JEP8000eoo`8000AJEP03001JEUYF
00=JEP80039oo`00?7oo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000
15YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH01eYF1@000UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP<0009JEP<000=JEP03001JEUYF
00EJEP03001JEP000080015oo`<00003FUH005YF00EJEP80035oo`00>Goo0`001eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000`000UYF00<005YF00000P0000=JEP00FUH025YF00<005YF
FUH015YF3P000eYF00<005YFFUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YF0000009JEP04001JEUYF0005FUH00`00FUIJEP04FUH30006Ool3000>Ool20006FUH2
000aOol003Moo`800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP<000IJEP05001J
EP00001JEP040006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YF
000000IJEP03001JEP0000@000Moo`D000moo`8000=JEP04001JEUYF000`Ool003Eoo`8000=JEP80
00MJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH00`00Ool00004
0002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYF0003FUH4
0002FUH20008Ool5000AOol01000FUIJEP000eYF00<007ooOol0;Goo000cOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000000Woo00D005YFFUH005YF00D0
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF1`000UYF00<005YFFUH00UYF00<007ooOol0
1Woo1@004Woo0`000eYF00<007ooOol0;Goo000aOol30005FUH<0008FUH40007FUH00`00FUIoo`04
FUH30004Ool01000FUIJEP001EYF1@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF0`000UYF00D0
05YFFUIJEP0000Uoo`<001Eoo`04001JEUYFFUH2000^Ool002moo`800003FUH0000000D00003FUH0
05YF00IJEP03001JEUYF00@00004FUH000000003FUH00`00FUIJEP03FUH00gooFUH00004FUH20007
Ool01000FUIJEP001EYF00<005YFFUH00UYF3P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YF00000P000eYF00<007oo
Ool087oo00D005YF001JEP0002ioo`00;Woo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF00@005YF000000Uoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20006FUH01000FUIJEUYF0P000UYF00<007ooOol08Goo0P0000=JEP00Ool0
;Goo000]Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
0007FUH2000;Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF10008goo00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH7000=Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH010007Woo0`00;goo000]Ool20003FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00@005YF000000ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUHQ0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH30006FUH0
0`00FUIJEP04FUH7000EOol200000eYF0000000_Ool002aoo`8000=JEPH000IJEP<000AJEP@0009J
EP03001JEUYF00MJEP04001JEUYFFUH2000<Ool01000FUIJEP001EYF00<005YFFUH01UYF2@002eYF
00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF
100015YF00<005YFFUH01UYF00<005YFFUH00UYF5@000eYF0P00;goo000/Ool2000015YF00000000
15YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF1@001UYF00<005YFFUH015YF0P002Woo00@0
05YFFUH000EJEP03001JEUYF00=JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEP0000@000IJEP03001JEUYF009JEP800003FUH00000008000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000`Ool002ao
o`03FUH00000009JEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUH00005
0002FUH00`00FUIJEP05FUH30008Ool01000FUIJEP001EYF00<005YF000010002UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00<005YFFUH00UYF0`00
1EYF00@005YF0000009JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000`Ool002]oo`D00003FUH005YF00AJEP8000MJEP03001JEUYF00EJEP<000Ioo`@0
00IJEP03001JEUYF008000Ioo`04001JEUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH;00000eYF
00000003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00<Goo000[Ool500000eYF001JEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH2000=Ool2
0003FUH00`00FUIJEP03FUH20004Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P0000=JEP00FUH01EYF0P002Goo1`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
03=oo`00:goo00D005YF001JEP00009JEP<000=JEP03001JEUYF00IJEP03001JEP000080015oo`80
0003FUH005YF00EJEP8000=oo`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF001J
EP03FUH2000BOolE000eOol002]oo`80009JEP03001JEUYF008000AJEP03001JEUYF00EJEP<000Eo
o`<000ioo`8000IJEP06001JEP00001oo`000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000000AJEP8005ioo`00;7oo00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH010001goo
1@003goo0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF000005YF00<0061oo`00;7oo00@005YFFUIJEP80009JEP03001JEUYF00D000]oo`D0
015oo`800003FUH005YF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
06=oo`00;Goo00<005YFFUH020003goo1@004goo0P0015YF0`0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH006Aoo`00;Woo0`001EYF00@005YF000000ioo`<001Ioo`03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0065oo`00<7oo00<005YFFUH00eYF
00@005YFFUIJEP<002Eoo`@00003Ool005YF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000AJEP8005moo`00<Goo0P000UYF00<005YFFUH01EYF10008goo0P0000=oo`00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P001UYF0`00GGoo000cOol30008FUH00`00FUIJEP04000NOol3
0002Ool01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YFFUH005aoo`00=Goo0P00
1eYF00<005YFFUH015YF1@005goo100017oo0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP@000IJEP03
001JEUYF009JEP8005Yoo`00=goo0P0015YF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF
0P001Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000Aoo`@0009JEP03001JEUYF00AJEP03001oogoo05Moo`00>Goo
0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0007Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH4000:
Ool30006FUH2001HOol003aoo`<000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008000]oo`@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00D0011oo`8000AJEP03001JEP0005Moo`00?goo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00011oo`D000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD00003Ool0000000<0015oo`04001JEUYF0003FUH0
0`00Oomoo`1DOol0049oo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000FOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Woo1@004Woo
0`000eYF00<007ooOol0E7oo0015Ool60004FUH00`00FUIJEP05FUH01000FUIJEUYF1@007Woo7`00
37oo1@0057oo00@005YFFUIJEP8005Eoo`00Bgoo4000=Goo0P001UYF00@005YF000000ioo`<001Io
o`05001JEP00FUH0001EOol0095oo`03001JEUYF00AJEP04001JEUYFFUH2000VOol200000eYF001o
o`1DOol0099oo`8000=JEP03001JEUYF00AJEP@002=oo`03001JEP0005Eoo`00U7oo0P0000=JEP00
FUH01UYF00<005YFFUH010007Woo0`00EWoo002FOol30006FUH00`00FUIJEP04FUH7000EOol20000
0eYF0000001FOol009Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000Qoo`D000=JEP80
05Ioo`00Vgoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYF
FUH2001GOol009ioo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001GOol00:5oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2001HOol00:Eoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001J
Ool00:aoo`P000AJEP04001JEUYFFUH5001LOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59095 .75535 m .60357 .70269 L .57322 .69371 L p .707 .577 .707 r
F P
0 g
s
.60357 .70269 m .59095 .75535 L .6213 .76083 L p .707 .577 .707 r
F P
0 g
s
.62198 .76078 m .62195 .76067 L .6213 .76083 L .707 .577 .707 r
F
.62195 .76067 m .60357 .70269 L .62106 .76002 L F
.62195 .76067 m .62106 .76002 L .6213 .76083 L F
.60897 .77425 m .62209 .76077 L .59015 .76315 L F
.63155 .78758 m .62209 .76077 L p .60897 .77425 L F P
0 g
s
.65956 .7763 m .63155 .7593 L .62209 .76077 L .707 .577 .707 r
F
.64903 .75658 m .64367 .73859 L .62225 .76074 L F
.63466 .7083 m .62209 .76077 L p .64367 .73859 L F P
0 g
s
.62209 .76077 m .63155 .78758 L .64921 .78047 L p .707 .577 .707 r
F P
0 g
s
.64921 .78047 m .65956 .7763 L p .62209 .76077 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .62204 .76096 L p .62225 .76074 L .707 .577 .707 r
F P
0 g
s
.64367 .73859 m .62209 .76077 L .62225 .76074 L .707 .577 .707 r
F
.63466 .7083 m .60357 .70269 L p .62195 .76067 L F P
0 g
s
.62204 .76096 m .62209 .76077 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .63466 .7083 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.6423 .76582 m .65241 .75606 L .63155 .7593 L .707 .577 .707 r
F
.65956 .7763 m .65241 .75606 L p .6423 .76582 L F P
0 g
s
.65956 .7763 m .68273 .76558 L p .67083 .75719 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .66987 .73919 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .65241 .75606 L p .66987 .73919 L F P
0 g
s
.66987 .73919 m .65241 .75606 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .63466 .7083 L p .64824 .75395 L F P
0 g
s
.65083 .76265 m .65241 .75606 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .66345 .70999 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.68273 .76558 m .67707 .74955 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.68713 .70759 m .66345 .70999 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .67707 .74955 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68713 .70759 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.68862 .75322 m .68665 .74512 L .67707 .74955 L .707 .577 .707 r
F
.6988 .75646 m .69058 .74879 L .68862 .75322 L F
.69058 .74879 m .68665 .74512 L .68862 .75322 L F
.69575 .75819 m .6988 .75646 L p .67707 .74955 L F P
0 g
s
.68993 .7436 m .68924 .73466 L .68197 .74729 L .707 .577 .707 r
F
.68713 .70759 m .67707 .74955 L p .68924 .73466 L F P
0 g
s
.68924 .73466 m .67707 .74955 L .68197 .74729 L .707 .577 .707 r
F
.68608 .72047 m .67002 .72959 L p .68665 .74512 L F P
0 g
s
.6988 .75646 m .69365 .74189 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70337 .70135 m .68713 .70759 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69074 .75401 m .69365 .74189 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .70337 .70135 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.70033 .74613 m .69758 .73727 L .69365 .74189 L .707 .577 .707 r
F
.70618 .74985 m .70041 .7414 L .70033 .74613 L F
.70041 .7414 m .69758 .73727 L .70033 .74613 L F
.69365 .74189 m .6988 .75646 L .70594 .75007 L p F P
0 g
s
.70594 .75007 m .70618 .74985 L p .69365 .74189 L .707 .577 .707 r
F P
0 g
s
.69909 .7355 m .70011 .72733 L .69594 .73919 L .707 .577 .707 r
F
.70337 .70135 m .69365 .74189 L p .70011 .72733 L F P
0 g
s
.70011 .72733 m .69365 .74189 L .69594 .73919 L .707 .577 .707 r
F
.69347 .71385 m .68608 .72047 L p .69758 .73727 L F P
0 g
s
.70618 .74985 m .70052 .73382 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.71058 .69186 m .70337 .70135 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .70052 .73382 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .71058 .69186 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70618 .74985 m .70417 .74638 L p .70249 .74128 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .69347 .71385 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.69779 .73837 m .69796 .74452 L p .69909 .7355 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .69701 .7401 L .69074 .75401 L .707 .577 .707 r
F
.69909 .7355 m .69594 .73919 L .69074 .75401 L F
.68608 .72047 m .69365 .74189 L p .69758 .73727 L F P
0 g
s
.69796 .74452 m .69544 .73273 L p .6975 .72718 L .707 .577 .707 r
F P
0 g
s
.69347 .71385 m .70052 .73382 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.6975 .72718 m .69937 .7313 L .69796 .74452 L .707 .577 .707 r
F
.69146 .71038 m .69347 .71385 L p .69878 .73 L F P
0 g
s
.70052 .73382 m .69796 .74452 L p .69937 .7313 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69146 .71038 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .71058 .69186 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .69702 .72613 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .70806 .68006 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .69074 .75401 L p .69594 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .68608 .72047 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70417 .74638 m .69295 .74639 L p .69243 .73379 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .68344 .71977 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69146 .71038 m .69702 .72613 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69544 .73273 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .69146 .71038 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .68348 .71958 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68024 .7104 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .70806 .68006 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68344 .71977 m .68348 .71958 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69606 .66711 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .69702 .72613 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69243 .73379 m .69201 .72371 L .69702 .72613 L .707 .577 .707 r
F
.69702 .72613 m .70417 .74638 L p .69243 .73379 L F P
0 g
s
.70417 .74638 m .69702 .72613 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70076 .71837 m .70052 .73382 L .69937 .7313 L .707 .577 .707 r
F
.6975 .72718 m .70076 .71837 L .69937 .7313 L F
.70249 .74128 m .69878 .73 L .70052 .73382 L F
.70052 .73382 m .70618 .74985 L p .70249 .74128 L F P
0 g
s
.71058 .69186 m .70052 .73382 L p .70076 .71837 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68273 .76558 L .69575 .75819 L p .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .6745 .76025 L p .68197 .74729 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .69074 .75401 L p .68993 .7436 L .707 .577 .707 r
F P
0 g
s
.68993 .7436 m .68197 .74729 L .6745 .76025 L .707 .577 .707 r
F
.67002 .72959 m .67707 .74955 L p .68665 .74512 L F P
0 g
s
.67002 .72959 m .64685 .74031 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .67002 .72959 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65956 .7763 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65083 .76265 L p .65721 .75479 L .707 .577 .707 r
F P
0 g
s
.67083 .75719 m .66463 .75283 L .66112 .76907 L .707 .577 .707 r
F
.67083 .75719 m .66112 .76907 L .65956 .7763 L F
.64685 .74031 m .65241 .75606 L p .66463 .75283 L F P
0 g
s
.65083 .76265 m .6745 .76025 L p .67242 .75078 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .65721 .75479 L .65083 .76265 L .707 .577 .707 r
F
.64685 .74031 m .61884 .75158 L p .63155 .7593 L F P
0 g
s
.65241 .75606 m .64685 .74031 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.61884 .75158 m .62209 .76077 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.62204 .76096 m .65083 .76265 L p .64903 .75658 L .707 .577 .707 r
F P
0 g
s
.64903 .75658 m .62225 .76074 L .62204 .76096 L .707 .577 .707 r
F
.61884 .75158 m .58874 .76231 L p .59015 .76315 L F P
0 g
s
.62209 .76077 m .61884 .75158 L p .59015 .76315 L .707 .577 .707 r
F P
0 g
s
.6213 .76083 m .62204 .76096 L p .62198 .76078 L .707 .577 .707 r
F P
0 g
s
.5606 .74637 m .57322 .69371 L .54659 .68224 L p .707 .577 .707 r
F P
0 g
s
.57322 .69371 m .5606 .74637 L .59095 .75535 L p .707 .577 .707 r
F P
0 g
s
.53397 .7349 m .54659 .68224 L .52628 .6694 L p .707 .577 .707 r
F P
0 g
s
.54659 .68224 m .53397 .7349 L .5606 .74637 L p .707 .577 .707 r
F P
0 g
s
.60145 .79831 m .58874 .76231 L .55948 .77144 L p .707 .577 .707 r
F P
0 g
s
.58874 .76231 m .60145 .79831 L .63155 .78758 L p .707 .577 .707 r
F P
0 g
s
.55948 .77144 m .5722 .80744 L .60145 .79831 L p .707 .577 .707 r
F P
0 g
s
.5722 .80744 m .55948 .77144 L .53395 .77808 L p .707 .577 .707 r
F P
0 g
s
.53395 .77808 m .54666 .81408 L .5722 .80744 L p .707 .577 .707 r
F P
0 g
s
.52628 .6694 m .51366 .72206 L .53397 .7349 L p .707 .577 .707 r
F P
0 g
s
.51366 .72206 m .52628 .6694 L .51428 .65645 L p .707 .577 .707 r
F P
0 g
s
.59009 .85697 m .59348 .83915 L .56284 .83153 L p .707 .577 .707 r
F P
0 g
s
.59348 .83915 m .59009 .85697 L .62145 .86135 L p .707 .577 .707 r
F P
0 g
s
.62145 .86135 m .62483 .84353 L .59348 .83915 L p .707 .577 .707 r
F P
0 g
s
.62483 .84353 m .62145 .86135 L .65045 .86206 L p .707 .577 .707 r
F P
0 g
s
.65045 .86206 m .65384 .84424 L .62483 .84353 L p .707 .577 .707 r
F P
0 g
s
.55945 .84936 m .56284 .83153 L .53591 .82142 L p .707 .577 .707 r
F P
0 g
s
.56284 .83153 m .55945 .84936 L .59009 .85697 L p .707 .577 .707 r
F P
0 g
s
.54666 .81408 m .53395 .77808 L .51462 .78158 L p .707 .577 .707 r
F P
0 g
s
.53591 .82142 m .53253 .83925 L .55945 .84936 L p .707 .577 .707 r
F P
0 g
s
.53253 .83925 m .53591 .82145 L p .51534 .80982 L .707 .577 .707 r
F P
0 g
s
.53591 .82145 m .53591 .82142 L .53588 .82141 L p .707 .577 .707 r
F P
0 g
s
.53588 .82141 m .51534 .80982 L p .53591 .82145 L .707 .577 .707 r
F P
0 g
s
.52733 .81757 m .51858 .79278 L p .5034 .78159 L .707 .577 .707 r
F P
0 g
s
.51858 .79278 m .51462 .78158 L .51181 .78158 L p .707 .577 .707 r
F P
0 g
s
.51181 .78158 m .5034 .78159 L p .51858 .79278 L .707 .577 .707 r
F P
0 g
s
.51462 .78158 m .52733 .81757 L .54666 .81408 L p .707 .577 .707 r
F P
0 g
s
.51428 .65645 m .50166 .70911 L .51366 .72206 L p .707 .577 .707 r
F P
0 g
s
.65384 .84424 m .65045 .86206 L .67425 .85904 L p .707 .577 .707 r
F P
0 g
s
.67425 .85904 m .67764 .84121 L .65384 .84424 L p .707 .577 .707 r
F P
0 g
s
.50166 .70911 m .51428 .65645 L .51176 .64466 L p .707 .577 .707 r
F P
0 g
s
.51534 .80982 m .51195 .82764 L .53253 .83925 L p .707 .577 .707 r
F P
0 g
s
.51195 .82764 m .51487 .81229 L p .50313 .79784 L .707 .577 .707 r
F P
0 g
s
.51487 .81229 m .51534 .80982 L .51311 .80763 L p .707 .577 .707 r
F P
0 g
s
.51311 .80763 m .50313 .79784 L p .51487 .81229 L .707 .577 .707 r
F P
0 g
s
.51612 .81759 m .50523 .78677 L p .50139 .77812 L .707 .577 .707 r
F P
0 g
s
.50523 .78677 m .5034 .78159 L .50304 .78097 L p .707 .577 .707 r
F P
0 g
s
.50304 .78097 m .50139 .77812 L p .50523 .78677 L .707 .577 .707 r
F P
0 g
s
.5034 .78159 m .51612 .81759 L .52733 .81757 L p .707 .577 .707 r
F P
0 g
s
.67764 .84121 m .67425 .85904 L .69054 .85258 L p .707 .577 .707 r
F P
0 g
s
.69054 .85258 m .69393 .83475 L .67764 .84121 L p .707 .577 .707 r
F P
0 g
s
.51176 .64466 m .49914 .69732 L .50166 .70911 L p .707 .577 .707 r
F P
0 g
s
.50313 .79784 m .49974 .81567 L .51195 .82764 L p .707 .577 .707 r
F P
0 g
s
.49914 .69732 m .51176 .64466 L .51898 .63517 L p .707 .577 .707 r
F P
0 g
s
.49492 .8217 m .48824 .31914 L .44423 .31706 L p .707 .577 .707 r
F P
0 g
s
.49974 .81567 m .50313 .79784 L .50048 .78667 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .51612 .81759 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50139 .77812 m .50185 .77943 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50185 .77943 m .5141 .81412 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50048 .78667 m .49709 .8045 L .49974 .81567 L p .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50048 .78667 L .50297 .78345 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .50139 .77812 L .50878 .77151 L p .707 .577 .707 r
F P
0 g
s
.50297 .78345 m .50764 .7774 L p .50393 .78693 L .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50297 .78345 L .50393 .78693 L .707 .577 .707 r
F
.51898 .63517 m .50635 .68783 L .49914 .69732 L p F P
0 g
s
.50635 .68783 m .51898 .63517 L .53521 .62892 L p .707 .577 .707 r
F P
0 g
s
.50878 .77151 m .52149 .8075 L .5141 .81412 L p .707 .577 .707 r
F P
0 g
s
.53521 .62892 m .52259 .68159 L .50635 .68783 L p .707 .577 .707 r
F P
0 g
s
.50764 .7774 m .50426 .79523 L .49709 .8045 L p .707 .577 .707 r
F P
0 g
s
.52259 .68159 m .53521 .62892 L .55889 .62653 L p .707 .577 .707 r
F P
0 g
s
.52149 .8075 m .50878 .77151 L .52484 .76239 L p .707 .577 .707 r
F P
0 g
s
.50426 .79523 m .50764 .7774 L .52393 .77094 L p .707 .577 .707 r
F P
0 g
s
.55889 .62653 m .54627 .67919 L .52259 .68159 L p .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52149 .8075 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.52484 .76239 m .5253 .7637 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.5253 .7637 m .53755 .79838 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52484 .76239 L .54801 .75167 L p .707 .577 .707 r
F P
0 g
s
.52054 .78877 m .52393 .77094 L .53645 .76935 L p .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .53755 .79838 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54801 .75167 m .54984 .75685 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54984 .75685 m .56072 .78766 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .54801 .75167 L .57602 .74039 L p .707 .577 .707 r
F P
0 g
s
.57602 .74039 m .58873 .77639 L .56072 .78766 L p .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .54774 .76792 L .57144 .7685 L p .707 .577 .707 r
F P
0 g
s
.57144 .7685 m .57674 .76863 L p .57419 .76998 L .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .57144 .7685 L .57419 .76998 L .707 .577 .707 r
F
.53645 .76935 m .54774 .76792 L p .54212 .77222 L F P
0 g
s
.52054 .78877 m .53645 .76935 L .54212 .77222 L .707 .577 .707 r
F
.52393 .77094 m .52054 .78877 L .50426 .79523 L p F P
0 g
s
.54774 .76792 m .54435 .78574 L .52054 .78877 L p .707 .577 .707 r
F P
0 g
s
.48824 .31914 m .49492 .8217 L .53987 .82007 L p .707 .577 .707 r
F P
0 g
s
.53987 .82007 m .53318 .31751 L .48824 .31914 L p .707 .577 .707 r
F P
0 g
s
.54627 .67919 m .55889 .62653 L .58768 .62822 L p .707 .577 .707 r
F P
0 g
s
.58768 .62822 m .57506 .68088 L .54627 .67919 L p .707 .577 .707 r
F P
0 g
s
.57674 .76863 m .57335 .78646 L .54435 .78574 L p .707 .577 .707 r
F P
0 g
s
.58873 .77639 m .57602 .74039 L .60612 .72967 L p .707 .577 .707 r
F P
0 g
s
.60612 .72967 m .61884 .76566 L .58873 .77639 L p .707 .577 .707 r
F P
0 g
s
.57335 .78646 m .57674 .76863 L .60809 .77301 L p .707 .577 .707 r
F P
0 g
s
.60809 .77301 m .6047 .79083 L .57335 .78646 L p .707 .577 .707 r
F P
0 g
s
.53318 .31751 m .53987 .82007 L .58134 .81487 L p .707 .577 .707 r
F P
0 g
s
.57506 .68088 m .58768 .62822 L .61877 .63382 L p .707 .577 .707 r
F P
0 g
s
.61877 .63382 m .60615 .68649 L .57506 .68088 L p .707 .577 .707 r
F P
0 g
s
.58134 .81487 m .57466 .31232 L .53318 .31751 L p .707 .577 .707 r
F P
0 g
s
.69393 .83475 m .69054 .85258 L .69771 .84331 L p .707 .577 .707 r
F P
0 g
s
.69771 .84331 m .7011 .82548 L .69393 .83475 L p .707 .577 .707 r
F P
0 g
s
.45092 .81961 m .44423 .31706 L .40547 .31145 L p .707 .577 .707 r
F P
0 g
s
.44423 .31706 m .45092 .81961 L .49492 .8217 L p .707 .577 .707 r
F P
0 g
s
.61884 .76566 m .60612 .72967 L .63538 .72053 L p .707 .577 .707 r
F P
0 g
s
.63873 .78062 m .63534 .79845 L .6047 .79083 L p .707 .577 .707 r
F P
0 g
s
.6047 .79083 m .60809 .77301 L .63873 .78062 L p .707 .577 .707 r
F P
0 g
s
.57466 .31232 m .58134 .81487 L .6153 .80662 L p .707 .577 .707 r
F P
0 g
s
.64912 .6428 m .63649 .69546 L .60615 .68649 L p .707 .577 .707 r
F P
0 g
s
.60615 .68649 m .61877 .63382 L .64912 .6428 L p .707 .577 .707 r
F P
0 g
s
.6153 .80662 m .60861 .30407 L .57466 .31232 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .26056 .66582 L .23022 .65684 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .27882 .72405 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.26056 .66582 m .25142 .70397 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.25142 .70397 m .24794 .71848 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.27901 .72403 m .26056 .66582 L .27882 .72405 L .707 .577 .707 r
F
.26588 .73756 m .27904 .72403 L .247 .72642 L F
.28854 .75093 m .27904 .72403 L p .26588 .73756 L F P
0 g
s
.31655 .73965 m .28842 .72258 L .27904 .72403 L .707 .577 .707 r
F
.30605 .71983 m .30069 .7018 L .27909 .72403 L F
.29165 .67143 m .27904 .72403 L p .30069 .7018 L F P
0 g
s
.27904 .72403 m .28854 .75093 L .30626 .7438 L p .707 .577 .707 r
F P
0 g
s
.30626 .7438 m .31655 .73965 L p .27904 .72403 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .27903 .72409 L p .27909 .72403 L .707 .577 .707 r
F P
0 g
s
.30069 .7018 m .27904 .72403 L .27909 .72403 L .707 .577 .707 r
F
.29165 .67143 m .26056 .66582 L p .279 .724 L F P
0 g
s
.27903 .72409 m .27904 .72403 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .29165 .67143 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.29921 .72913 m .30937 .71932 L .28842 .72258 L .707 .577 .707 r
F
.31655 .73965 m .30937 .71932 L p .29921 .72913 L F P
0 g
s
.31655 .73965 m .33972 .72893 L p .32775 .7205 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .32688 .7024 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .30937 .71932 L p .32688 .7024 L F P
0 g
s
.32688 .7024 m .30937 .71932 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .29165 .67143 L p .30529 .71726 L F P
0 g
s
.30782 .72578 m .30937 .71932 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .32044 .67311 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.33972 .72893 m .33403 .71281 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.34412 .67072 m .32044 .67311 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .33403 .71281 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .34412 .67072 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.34556 .71652 m .34357 .7084 L .33403 .71281 L .707 .577 .707 r
F
.35579 .71982 m .34752 .7121 L .34556 .71652 L F
.34752 .7121 m .34357 .7084 L .34556 .71652 L F
.34693 .70685 m .34623 .69787 L .3389 .71056 L F
.34412 .67072 m .33403 .71281 L p .34623 .69787 L F P
0 g
s
.34623 .69787 m .33403 .71281 L .3389 .71056 L .707 .577 .707 r
F
.34308 .68383 m .32701 .69294 L p .34357 .7084 L F P
0 g
s
.35579 .71982 m .35061 .70515 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36036 .66447 m .34412 .67072 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.34773 .71713 m .35061 .70515 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .36036 .66447 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35729 .70943 m .35452 .70055 L .35061 .70515 L .707 .577 .707 r
F
.36317 .7132 m .35736 .70471 L .35729 .70943 L F
.35736 .70471 m .35452 .70055 L .35729 .70943 L F
.35061 .70515 m .35579 .71982 L .36297 .71338 L p F P
0 g
s
.36297 .71338 m .36317 .7132 L p .35061 .70515 L .707 .577 .707 r
F P
0 g
s
.35606 .69874 m .35709 .69054 L .3529 .70246 L .707 .577 .707 r
F
.36036 .66447 m .35061 .70515 L p .35709 .69054 L F P
0 g
s
.35709 .69054 m .35061 .70515 L .3529 .70246 L .707 .577 .707 r
F
.35046 .67721 m .34308 .68383 L p .35452 .70055 L F P
0 g
s
.36317 .7132 m .35748 .69708 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.36757 .65499 m .36036 .66447 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35748 .69708 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36757 .65499 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.36317 .7132 m .36116 .70973 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .35046 .67721 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.35477 .7016 m .35495 .70765 L p .35606 .69874 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35401 .70327 L .34773 .71713 L .707 .577 .707 r
F
.35606 .69874 m .3529 .70246 L .34773 .71713 L F
.34308 .68383 m .35061 .70515 L p .35452 .70055 L F P
0 g
s
.35495 .70765 m .35243 .69585 L p .35444 .69042 L .707 .577 .707 r
F P
0 g
s
.35046 .67721 m .35748 .69708 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35444 .69042 m .35634 .69457 L .35495 .70765 L .707 .577 .707 r
F
.34845 .67374 m .35046 .67721 L p .35575 .69328 L F P
0 g
s
.35748 .69708 m .35495 .70765 L p .35634 .69457 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .34845 .67374 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36757 .65499 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .35398 .6894 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36505 .64319 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34773 .71713 L p .3529 .70246 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34308 .68383 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .34994 .70974 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .34043 .6829 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.34845 .67374 m .35398 .6894 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.38244 .80543 m .37575 .30287 L .35798 .29217 L p .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .35243 .69585 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34845 .67374 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .34044 .68285 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .33723 .67375 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .36505 .64319 L p .34508 .67541 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36138 .65852 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.36138 .65852 m .35398 .6894 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.34459 .68485 m .36143 .65057 L .35398 .6894 L .707 .577 .707 r
F
.36466 .79473 m .36445 .7784 L p .36432 .77855 L F P
0 g
s
.34508 .67541 m .36505 .64319 L .34459 .68485 L .707 .577 .707 r
F
.36757 .65499 m .35748 .69708 L p .35772 .68158 L F P
0 g
s
.36445 .7784 m .35798 .29217 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36317 .7132 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .35389 .28038 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36116 .70973 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .35398 .6894 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .36466 .79473 L .38244 .80543 L p .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36058 .78294 L .36466 .79473 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36058 .78294 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36389 .26867 m .36429 .29882 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36429 .29882 m .37058 .77122 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34584 .66035 L .34508 .67541 L .707 .577 .707 r
F
.34584 .66035 m .35305 .63024 L .34508 .67541 L F
.34043 .6829 m .34044 .68285 L p .34046 .68285 L F P
0 g
s
.34044 .68285 m .35305 .63024 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36389 .26867 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36058 .78294 m .35624 .4567 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.35624 .4567 m .35389 .28038 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34508 .67541 L .34459 .68485 L .707 .577 .707 r
F
.34941 .697 m .349 .68699 L .35398 .6894 L F
.35772 .68158 m .35748 .69708 L .35634 .69457 L F
.35444 .69042 m .35772 .68158 L .35634 .69457 L F
.35944 .70451 m .35575 .69328 L .35748 .69708 L F
.33403 .71281 m .33972 .72893 L .35282 .7215 L p F P
0 g
s
.35282 .7215 m .35579 .71982 L p .33403 .71281 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .3315 .72338 L p .3389 .71056 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .34773 .71713 L p .34693 .70685 L .707 .577 .707 r
F P
0 g
s
.34693 .70685 m .3389 .71056 L .3315 .72338 L .707 .577 .707 r
F
.32701 .69294 m .33403 .71281 L p .34357 .7084 L F P
0 g
s
.32701 .69294 m .30384 .70366 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .32701 .69294 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .31655 .73965 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .30782 .72578 L p .31411 .71807 L .707 .577 .707 r
F P
0 g
s
.32775 .7205 m .32152 .71611 L .3181 .73231 L .707 .577 .707 r
F
.32775 .7205 m .3181 .73231 L .31655 .73965 L F
.30384 .70366 m .30937 .71932 L p .32152 .71611 L F P
0 g
s
.30782 .72578 m .3315 .72338 L p .32944 .71402 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .31411 .71807 L .30782 .72578 L .707 .577 .707 r
F
.30384 .70366 m .27583 .71494 L p .28842 .72258 L F P
0 g
s
.30937 .71932 m .30384 .70366 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27583 .71494 m .27904 .72403 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27903 .72409 m .30782 .72578 L p .30605 .71983 L .707 .577 .707 r
F P
0 g
s
.30605 .71983 m .27909 .72403 L .27903 .72409 L .707 .577 .707 r
F
.27583 .71494 m .24573 .72567 L p .247 .72642 L F P
0 g
s
.27904 .72403 m .27583 .71494 L p .247 .72642 L .707 .577 .707 r
F P
0 g
s
.27882 .72405 m .27903 .72409 L p .27901 .72403 L .707 .577 .707 r
F P
0 g
s
.41216 .81401 m .40547 .31145 L .37575 .30287 L p .707 .577 .707 r
F P
0 g
s
.40547 .31145 m .41216 .81401 L .45092 .81961 L p .707 .577 .707 r
F P
0 g
s
.21759 .7095 m .23022 .65684 L .20358 .64537 L p .707 .577 .707 r
F P
0 g
s
.23022 .65684 m .21759 .7095 L .24794 .71848 L p .707 .577 .707 r
F P
0 g
s
.7011 .82548 m .69771 .84331 L .69506 .83214 L p .707 .577 .707 r
F P
0 g
s
.69506 .83214 m .69844 .81431 L .7011 .82548 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19096 .69803 m .20358 .64537 L .18327 .63253 L p .707 .577 .707 r
F P
0 g
s
.20358 .64537 m .19096 .69803 L .21759 .7095 L p .707 .577 .707 r
F P
0 g
s
.63538 .72053 m .64809 .75653 L .61884 .76566 L p .707 .577 .707 r
F P
0 g
s
.63534 .79845 m .63873 .78062 L .66566 .79073 L p .707 .577 .707 r
F P
0 g
s
.60861 .30407 m .6153 .80662 L .63841 .79613 L p .707 .577 .707 r
F P
0 g
s
.67575 .65427 m .66313 .70694 L .63649 .69546 L p .707 .577 .707 r
F P
0 g
s
.63649 .69546 m .64912 .6428 L .67575 .65427 L p .707 .577 .707 r
F P
0 g
s
.64809 .75653 m .63538 .72053 L .66092 .71389 L p .707 .577 .707 r
F P
0 g
s
.63841 .79613 m .63172 .29357 L .60861 .30407 L p .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .67363 .74989 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .68348 .71958 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68344 .71977 L .68296 .71947 L p .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69295 .74639 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.67363 .74989 m .66092 .71389 L .68024 .7104 L p .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .68348 .71958 L p .66313 .70694 L .707 .577 .707 r
F P
0 g
s
.68296 .71947 m .66313 .70694 L p .68348 .71958 L .707 .577 .707 r
F P
0 g
s
.66313 .70694 m .67575 .65427 L .69606 .66711 L p .707 .577 .707 r
F P
0 g
s
.25844 .76166 m .24573 .72567 L .21648 .7348 L p .707 .577 .707 r
F P
0 g
s
.24573 .72567 m .25844 .76166 L .28854 .75093 L p .707 .577 .707 r
F P
0 g
s
.21648 .7348 m .22919 .77079 L .25844 .76166 L p .707 .577 .707 r
F P
0 g
s
.22919 .77079 m .21648 .7348 L .19094 .74144 L p .707 .577 .707 r
F P
0 g
s
.69844 .81431 m .69506 .83214 L .68284 .82017 L p .707 .577 .707 r
F P
0 g
s
.68284 .82017 m .68623 .80234 L .69844 .81431 L p .707 .577 .707 r
F P
0 g
s
.37575 .30287 m .38244 .80543 L .41216 .81401 L p .707 .577 .707 r
F P
0 g
s
.19094 .74144 m .20365 .77743 L .22919 .77079 L p .707 .577 .707 r
F P
0 g
s
.18327 .63253 m .17065 .68519 L .19096 .69803 L p .707 .577 .707 r
F P
0 g
s
.17065 .68519 m .18327 .63253 L .17127 .61958 L p .707 .577 .707 r
F P
0 g
s
.24708 .81951 m .25047 .80168 L .21983 .79407 L p .707 .577 .707 r
F P
0 g
s
.25047 .80168 m .24708 .81951 L .27844 .82389 L p .707 .577 .707 r
F P
0 g
s
.27844 .82389 m .28183 .80606 L .25047 .80168 L p .707 .577 .707 r
F P
0 g
s
.28183 .80606 m .27844 .82389 L .30744 .8246 L p .707 .577 .707 r
F P
0 g
s
.30744 .8246 m .31083 .80677 L .28183 .80606 L p .707 .577 .707 r
F P
0 g
s
.21644 .81189 m .21983 .79407 L .19291 .78396 L p .707 .577 .707 r
F P
0 g
s
.21983 .79407 m .21644 .81189 L .24708 .81951 L p .707 .577 .707 r
F P
0 g
s
.20365 .77743 m .19094 .74144 L .17161 .74494 L p .707 .577 .707 r
F P
0 g
s
.19291 .78396 m .18952 .80179 L .21644 .81189 L p .707 .577 .707 r
F P
0 g
s
.18952 .80179 m .1928 .78452 L p .17233 .77235 L .707 .577 .707 r
F P
0 g
s
.1928 .78452 m .19291 .78396 L .19223 .78358 L p .707 .577 .707 r
F P
0 g
s
.19223 .78358 m .17233 .77235 L p .1928 .78452 L .707 .577 .707 r
F P
0 g
s
.18432 .78093 m .17547 .75585 L p .1604 .74495 L .707 .577 .707 r
F P
0 g
s
.17547 .75585 m .17161 .74494 L .16887 .74494 L p .707 .577 .707 r
F P
0 g
s
.16887 .74494 m .1604 .74495 L p .17547 .75585 L .707 .577 .707 r
F P
0 g
s
.17161 .74494 m .18432 .78093 L .20365 .77743 L p .707 .577 .707 r
F P
0 g
s
.63172 .29357 m .63841 .79613 L .64841 .78441 L p .707 .577 .707 r
F P
0 g
s
.64841 .78441 m .64172 .28186 L .63172 .29357 L p .707 .577 .707 r
F P
0 g
s
.17127 .61958 m .15865 .67224 L .17065 .68519 L p .707 .577 .707 r
F P
0 g
s
.31083 .80677 m .30744 .8246 L .33125 .82158 L p .707 .577 .707 r
F P
0 g
s
.33125 .82158 m .33463 .80375 L .31083 .80677 L p .707 .577 .707 r
F P
0 g
s
.68623 .80234 m .68284 .82017 L .66227 .80856 L p .707 .577 .707 r
F P
0 g
s
.66227 .80856 m .66566 .79073 L .68623 .80234 L p .707 .577 .707 r
F P
0 g
s
.66092 .71389 m .67363 .74989 L .64809 .75653 L p .707 .577 .707 r
F P
0 g
s
.15865 .67224 m .17127 .61958 L .16875 .60778 L p .707 .577 .707 r
F P
0 g
s
.17233 .77235 m .16894 .79018 L .18952 .80179 L p .707 .577 .707 r
F P
0 g
s
.16894 .79018 m .17176 .77535 L p .16012 .76037 L .707 .577 .707 r
F P
0 g
s
.17176 .77535 m .17233 .77235 L .16962 .76969 L p .707 .577 .707 r
F P
0 g
s
.16962 .76969 m .16012 .76037 L p .17176 .77535 L .707 .577 .707 r
F P
0 g
s
.17311 .78094 m .16212 .74984 L p .15838 .74148 L .707 .577 .707 r
F P
0 g
s
.16212 .74984 m .1604 .74495 L .16005 .74436 L p .707 .577 .707 r
F P
0 g
s
.16005 .74436 m .15838 .74148 L p .16212 .74984 L .707 .577 .707 r
F P
0 g
s
.1604 .74495 m .17311 .78094 L .18432 .78093 L p .707 .577 .707 r
F P
0 g
s
.33463 .80375 m .33125 .82158 L .34753 .81511 L p .707 .577 .707 r
F P
0 g
s
.34753 .81511 m .35092 .79729 L .33463 .80375 L p .707 .577 .707 r
F P
0 g
s
.66566 .79073 m .66227 .80856 L .63534 .79845 L p .707 .577 .707 r
F P
0 g
s
.16875 .60778 m .15613 .66044 L .15865 .67224 L p .707 .577 .707 r
F P
0 g
s
.16012 .76037 m .15673 .7782 L .16894 .79018 L p .707 .577 .707 r
F P
0 g
s
.15613 .66044 m .16875 .60778 L .17597 .5983 L p .707 .577 .707 r
F P
0 g
s
.64172 .28186 m .64841 .78441 L .64432 .77263 L p .707 .577 .707 r
F P
0 g
s
.64432 .77263 m .63763 .27007 L .64172 .28186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35092 .79729 m .34753 .81511 L .3547 .80584 L p .707 .577 .707 r
F P
0 g
s
.3547 .80584 m .35809 .78802 L .35092 .79729 L p .707 .577 .707 r
F P
0 g
s
.15673 .7782 m .16012 .76037 L .15747 .7492 L p .707 .577 .707 r
F P
0 g
s
.15747 .7492 m .15408 .76703 L .15673 .7782 L p .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15747 .7492 L .15977 .74622 L p .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .17311 .78094 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15874 .7425 m .17109 .77747 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15838 .74148 m .15874 .7425 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .15838 .74148 L .16577 .73486 L p .707 .577 .707 r
F P
0 g
s
.15977 .74622 m .16463 .73993 L p .16078 .74983 L .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15977 .74622 L .16078 .74983 L .707 .577 .707 r
F
.17597 .5983 m .16334 .65096 L .15613 .66044 L p F P
0 g
s
.16334 .65096 m .17597 .5983 L .19221 .59205 L p .707 .577 .707 r
F P
0 g
s
.35809 .78802 m .3547 .80584 L .35205 .79467 L p .707 .577 .707 r
F P
0 g
s
.35205 .79467 m .35543 .77685 L .35809 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16577 .73486 m .17848 .77085 L .17109 .77747 L p .707 .577 .707 r
F P
0 g
s
.63763 .27007 m .64432 .77263 L .62655 .76192 L p .707 .577 .707 r
F P
0 g
s
.62655 .76192 m .61986 .25936 L .63763 .27007 L p .707 .577 .707 r
F P
0 g
s
.19221 .59205 m .17958 .64471 L .16334 .65096 L p .707 .577 .707 r
F P
0 g
s
.16463 .73993 m .16125 .75776 L .15408 .76703 L p .707 .577 .707 r
F P
0 g
s
.17958 .64471 m .19221 .59205 L .21588 .58965 L p .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .33062 .71324 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34044 .68285 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34043 .6829 L .34029 .68281 L p .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34994 .70974 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33062 .71324 m .31791 .67725 L .33723 .67375 L p .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .34044 .68285 L p .32012 .67006 L .707 .577 .707 r
F P
0 g
s
.34029 .68281 m .32012 .67006 L p .34044 .68285 L .707 .577 .707 r
F P
0 g
s
.32012 .67006 m .33274 .6174 L .35305 .63024 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36389 .26867 L .387 .25817 L p .707 .577 .707 r
F P
0 g
s
.17848 .77085 m .16577 .73486 L .18183 .72575 L p .707 .577 .707 r
F P
0 g
s
.35543 .77685 m .35205 .79467 L .33983 .7827 L p .707 .577 .707 r
F P
0 g
s
.33983 .7827 m .34322 .76487 L .35543 .77685 L p .707 .577 .707 r
F P
0 g
s
.16125 .75776 m .16463 .73993 L .18092 .73347 L p .707 .577 .707 r
F P
0 g
s
.21588 .58965 m .20326 .64232 L .17958 .64471 L p .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .17848 .77085 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.18219 .72677 m .19454 .76174 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .18183 .72575 L .205 .71502 L p .707 .577 .707 r
F P
0 g
s
.17753 .7513 m .18092 .73347 L .19251 .732 L p .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .19454 .76174 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.205 .71502 m .20673 .71991 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.20673 .71991 m .21771 .75102 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .205 .71502 L .23301 .70375 L p .707 .577 .707 r
F P
0 g
s
.23301 .70375 m .24572 .73974 L .21771 .75102 L p .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .20473 .73045 L .22729 .731 L p .707 .577 .707 r
F P
0 g
s
.22729 .731 m .23373 .73116 L p .23062 .7328 L .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .22729 .731 L .23062 .7328 L .707 .577 .707 r
F
.19251 .732 m .20473 .73045 L p .19865 .73511 L F P
0 g
s
.17753 .7513 m .19251 .732 L .19865 .73511 L .707 .577 .707 r
F
.18183 .72575 m .18219 .72677 L p .18177 .72655 L F P
0 g
s
.20326 .64232 m .21588 .58965 L .24467 .59134 L p .707 .577 .707 r
F P
0 g
s
.33274 .6174 m .32012 .67006 L .29348 .65859 L p .707 .577 .707 r
F P
0 g
s
.29348 .65859 m .30611 .60593 L .33274 .6174 L p .707 .577 .707 r
F P
0 g
s
.18092 .73347 m .17753 .7513 L .16125 .75776 L p .707 .577 .707 r
F P
0 g
s
.61986 .25936 m .62655 .76192 L .59682 .75335 L p .707 .577 .707 r
F P
0 g
s
.59682 .75335 m .59014 .25079 L .61986 .25936 L p .707 .577 .707 r
F P
0 g
s
.23205 .644 m .24467 .59134 L .27576 .59695 L p .707 .577 .707 r
F P
0 g
s
.24467 .59134 m .23205 .644 L .20326 .64232 L p .707 .577 .707 r
F P
0 g
s
.30611 .60593 m .29348 .65859 L .26314 .64961 L p .707 .577 .707 r
F P
0 g
s
.26314 .64961 m .27576 .59695 L .30611 .60593 L p .707 .577 .707 r
F P
0 g
s
.27576 .59695 m .26314 .64961 L .23205 .644 L p .707 .577 .707 r
F P
0 g
s
.34322 .76487 m .33983 .7827 L .31926 .77109 L p .707 .577 .707 r
F P
0 g
s
.31926 .77109 m .32265 .75326 L .34322 .76487 L p .707 .577 .707 r
F P
0 g
s
.31791 .67725 m .33062 .71324 L .30508 .71988 L p .707 .577 .707 r
F P
0 g
s
.30508 .71988 m .29237 .68389 L .31791 .67725 L p .707 .577 .707 r
F P
0 g
s
.72815 .66332 m .74078 .61065 L .71043 .60167 L p .707 .577 .707 r
F P
0 g
s
.74078 .61065 m .72815 .66332 L .75851 .66879 L p .707 .577 .707 r
F P
0 g
s
.75919 .66874 m .75915 .66863 L .75851 .66879 L .707 .577 .707 r
F
.75915 .66863 m .74078 .61065 L .75826 .66799 L F
.75915 .66863 m .75826 .66799 L .75851 .66879 L F
.74617 .68221 m .75929 .66873 L .72736 .67111 L F
.76876 .69554 m .75929 .66873 L p .74617 .68221 L F P
0 g
s
.79676 .68426 m .76876 .66726 L .75929 .66873 L .707 .577 .707 r
F
.78623 .66454 m .78088 .64655 L .75945 .66871 L F
.77187 .61626 m .75929 .66873 L p .78088 .64655 L F P
0 g
s
.75929 .66873 m .76876 .69554 L .78641 .68843 L p .707 .577 .707 r
F P
0 g
s
.78641 .68843 m .79676 .68426 L p .75929 .66873 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .75924 .66892 L p .75945 .66871 L .707 .577 .707 r
F P
0 g
s
.78088 .64655 m .75929 .66873 L .75945 .66871 L .707 .577 .707 r
F
.77187 .61626 m .74078 .61065 L p .75915 .66863 L F P
0 g
s
.75924 .66892 m .75929 .66873 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .77187 .61626 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.7795 .67378 m .78962 .66402 L .76876 .66726 L .707 .577 .707 r
F
.79676 .68426 m .78962 .66402 L p .7795 .67378 L F P
0 g
s
.79676 .68426 m .81994 .67354 L p .80803 .66516 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .80708 .64715 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .78962 .66402 L p .80708 .64715 L F P
0 g
s
.80708 .64715 m .78962 .66402 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .77187 .61626 L p .78545 .66191 L F P
0 g
s
.78804 .67061 m .78962 .66402 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .80066 .61795 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.81994 .67354 m .81427 .65751 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.82433 .61555 m .80066 .61795 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .81427 .65751 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .82433 .61555 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.82582 .66119 m .82386 .65308 L .81427 .65751 L .707 .577 .707 r
F
.836 .66443 m .82779 .65675 L .82582 .66119 L F
.82779 .65675 m .82386 .65308 L .82582 .66119 L F
.83296 .66615 m .836 .66443 L p .81427 .65751 L F P
0 g
s
.82714 .65157 m .82644 .64262 L .81917 .65525 L .707 .577 .707 r
F
.82433 .61555 m .81427 .65751 L p .82644 .64262 L F P
0 g
s
.82644 .64262 m .81427 .65751 L .81917 .65525 L .707 .577 .707 r
F
.82329 .62843 m .80722 .63755 L p .82386 .65308 L F P
0 g
s
.836 .66443 m .83085 .64985 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84057 .60931 m .82433 .61555 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.82795 .66197 m .83085 .64985 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .84057 .60931 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83754 .6541 m .83478 .64523 L .83085 .64985 L .707 .577 .707 r
F
.84339 .65781 m .83761 .64937 L .83754 .6541 L F
.83761 .64937 m .83478 .64523 L .83754 .6541 L F
.83085 .64985 m .836 .66443 L .84314 .65803 L p F P
0 g
s
.84314 .65803 m .84339 .65781 L p .83085 .64985 L .707 .577 .707 r
F P
0 g
s
.83629 .64347 m .83732 .63529 L .83315 .64715 L .707 .577 .707 r
F
.84057 .60931 m .83085 .64985 L p .83732 .63529 L F P
0 g
s
.83732 .63529 m .83085 .64985 L .83315 .64715 L .707 .577 .707 r
F
.83068 .62182 m .82329 .62843 L p .83478 .64523 L F P
0 g
s
.84339 .65781 m .83773 .64178 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.84778 .59982 m .84057 .60931 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83773 .64178 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .84778 .59982 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.84339 .65781 m .84137 .65434 L p .8397 .64924 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .83068 .62182 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.835 .64633 m .83516 .65248 L p .83629 .64347 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83422 .64806 L .82795 .66197 L .707 .577 .707 r
F
.83629 .64347 m .83315 .64715 L .82795 .66197 L F
.82329 .62843 m .83085 .64985 L p .83478 .64523 L F P
0 g
s
.83516 .65248 m .83264 .64069 L p .8347 .63514 L .707 .577 .707 r
F P
0 g
s
.83068 .62182 m .83773 .64178 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.8347 .63514 m .83658 .63926 L .83516 .65248 L .707 .577 .707 r
F
.82866 .61834 m .83068 .62182 L p .83599 .63796 L F P
0 g
s
.83773 .64178 m .83516 .65248 L p .83658 .63926 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .82866 .61834 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .84778 .59982 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .83422 .63409 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .84527 .58803 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82795 .66197 L p .83315 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82329 .62843 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84137 .65434 m .83016 .65435 L p .82963 .64175 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .82064 .62774 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82866 .61834 m .83422 .63409 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .83264 .64069 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82866 .61834 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .82069 .62755 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .81744 .61836 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .84527 .58803 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82064 .62774 m .82069 .62755 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83327 .57507 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .83422 .63409 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82963 .64175 m .82921 .63167 L .83422 .63409 L .707 .577 .707 r
F
.83422 .63409 m .84137 .65434 L p .82963 .64175 L F P
0 g
s
.84137 .65434 m .83422 .63409 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.83796 .62633 m .83773 .64178 L .83658 .63926 L .707 .577 .707 r
F
.8347 .63514 m .83796 .62633 L .83658 .63926 L F
.8397 .64924 m .83599 .63796 L .83773 .64178 L F
.83773 .64178 m .84339 .65781 L p .8397 .64924 L F P
0 g
s
.84778 .59982 m .83773 .64178 L p .83796 .62633 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81994 .67354 L .83296 .66615 L p .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81171 .66822 L p .81917 .65525 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .82795 .66197 L p .82714 .65157 L .707 .577 .707 r
F P
0 g
s
.82714 .65157 m .81917 .65525 L .81171 .66822 L .707 .577 .707 r
F
.80722 .63755 m .81427 .65751 L p .82386 .65308 L F P
0 g
s
.80722 .63755 m .78405 .64827 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .80722 .63755 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .79676 .68426 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .78804 .67061 L p .79442 .66275 L .707 .577 .707 r
F P
0 g
s
.80803 .66516 m .80184 .66079 L .79833 .67703 L .707 .577 .707 r
F
.80803 .66516 m .79833 .67703 L .79676 .68426 L F
.78405 .64827 m .78962 .66402 L p .80184 .66079 L F P
0 g
s
.78804 .67061 m .81171 .66822 L p .80963 .65874 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .79442 .66275 L .78804 .67061 L .707 .577 .707 r
F
.78405 .64827 m .75605 .65955 L p .76876 .66726 L F P
0 g
s
.78962 .66402 m .78405 .64827 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75605 .65955 m .75929 .66873 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75924 .66892 m .78804 .67061 L p .78623 .66454 L .707 .577 .707 r
F P
0 g
s
.78623 .66454 m .75945 .66871 L .75924 .66892 L .707 .577 .707 r
F
.75605 .65955 m .72594 .67027 L p .72736 .67111 L F P
0 g
s
.75929 .66873 m .75605 .65955 L p .72736 .67111 L .707 .577 .707 r
F P
0 g
s
.75851 .66879 m .75924 .66892 L p .75919 .66874 L .707 .577 .707 r
F P
0 g
s
.387 .25817 m .39369 .76073 L .37058 .77122 L p .707 .577 .707 r
F P
0 g
s
.39369 .76073 m .387 .25817 L .42095 .24992 L p .707 .577 .707 r
F P
0 g
s
.20473 .73045 m .20134 .74828 L .17753 .7513 L p .707 .577 .707 r
F P
0 g
s
.69781 .65434 m .71043 .60167 L .6838 .5902 L p .707 .577 .707 r
F P
0 g
s
.71043 .60167 m .69781 .65434 L .72815 .66332 L p .707 .577 .707 r
F P
0 g
s
.29237 .68389 m .30508 .71988 L .27583 .72901 L p .707 .577 .707 r
F P
0 g
s
.27583 .72901 m .26311 .69302 L .29237 .68389 L p .707 .577 .707 r
F P
0 g
s
.32265 .75326 m .31926 .77109 L .29233 .76098 L p .707 .577 .707 r
F P
0 g
s
.29233 .76098 m .29572 .74316 L .32265 .75326 L p .707 .577 .707 r
F P
0 g
s
.59014 .25079 m .59682 .75335 L .55806 .74774 L p .707 .577 .707 r
F P
0 g
s
.55806 .74774 m .55138 .24518 L .59014 .25079 L p .707 .577 .707 r
F P
0 g
s
.67117 .64287 m .6838 .5902 L .66349 .57736 L p .707 .577 .707 r
F P
0 g
s
.6838 .5902 m .67117 .64287 L .69781 .65434 L p .707 .577 .707 r
F P
0 g
s
.73865 .70627 m .72594 .67027 L .69669 .67941 L p .707 .577 .707 r
F P
0 g
s
.72594 .67027 m .73865 .70627 L .76876 .69554 L p .707 .577 .707 r
F P
0 g
s
.24572 .73974 m .23301 .70375 L .26311 .69302 L p .707 .577 .707 r
F P
0 g
s
.23373 .73116 m .23034 .74899 L .20134 .74828 L p .707 .577 .707 r
F P
0 g
s
.26311 .69302 m .27583 .72901 L .24572 .73974 L p .707 .577 .707 r
F P
0 g
s
.69669 .67941 m .7094 .7154 L .73865 .70627 L p .707 .577 .707 r
F P
0 g
s
.42764 .75248 m .42095 .24992 L .46243 .24472 L p .707 .577 .707 r
F P
0 g
s
.42095 .24992 m .42764 .75248 L .39369 .76073 L p .707 .577 .707 r
F P
0 g
s
.29572 .74316 m .29233 .76098 L .26169 .75337 L p .707 .577 .707 r
F P
0 g
s
.26169 .75337 m .26508 .73554 L .29572 .74316 L p .707 .577 .707 r
F P
0 g
s
.7094 .7154 m .69669 .67941 L .67115 .68605 L p .707 .577 .707 r
F P
0 g
s
.23034 .74899 m .23373 .73116 L .26508 .73554 L p .707 .577 .707 r
F P
0 g
s
.26508 .73554 m .26169 .75337 L .23034 .74899 L p .707 .577 .707 r
F P
0 g
s
.67115 .68605 m .68386 .72204 L .7094 .7154 L p .707 .577 .707 r
F P
0 g
s
.66349 .57736 m .65086 .63003 L .67117 .64287 L p .707 .577 .707 r
F P
0 g
s
.65086 .63003 m .66349 .57736 L .65148 .56441 L p .707 .577 .707 r
F P
0 g
s
.55138 .24518 m .55806 .74774 L .51406 .74565 L p .707 .577 .707 r
F P
0 g
s
.51406 .74565 m .50737 .24309 L .55138 .24518 L p .707 .577 .707 r
F P
0 g
s
.72729 .76494 m .73068 .74711 L .70004 .73949 L p .707 .577 .707 r
F P
0 g
s
.73068 .74711 m .72729 .76494 L .75865 .76931 L p .707 .577 .707 r
F P
0 g
s
.75865 .76931 m .76204 .75149 L .73068 .74711 L p .707 .577 .707 r
F P
0 g
s
.46912 .74728 m .46243 .24472 L .50737 .24309 L p .707 .577 .707 r
F P
0 g
s
.46243 .24472 m .46912 .74728 L .42764 .75248 L p .707 .577 .707 r
F P
0 g
s
.76204 .75149 m .75865 .76931 L .78765 .77003 L p .707 .577 .707 r
F P
0 g
s
.78765 .77003 m .79104 .7522 L .76204 .75149 L p .707 .577 .707 r
F P
0 g
s
.69666 .75732 m .70004 .73949 L .67312 .72939 L p .707 .577 .707 r
F P
0 g
s
.70004 .73949 m .69666 .75732 L .72729 .76494 L p .707 .577 .707 r
F P
0 g
s
.68386 .72204 m .67115 .68605 L .65183 .68954 L p .707 .577 .707 r
F P
0 g
s
.50737 .24309 m .51406 .74565 L .46912 .74728 L p .707 .577 .707 r
F P
0 g
s
.67312 .72939 m .66973 .74721 L .69666 .75732 L p .707 .577 .707 r
F P
0 g
s
.66973 .74721 m .67311 .72941 L p .65254 .71778 L .707 .577 .707 r
F P
0 g
s
.67311 .72941 m .67312 .72939 L .67309 .72937 L p .707 .577 .707 r
F P
0 g
s
.67309 .72937 m .65254 .71778 L p .67311 .72941 L .707 .577 .707 r
F P
0 g
s
.66454 .72554 m .65578 .70074 L p .64061 .68956 L .707 .577 .707 r
F P
0 g
s
.65578 .70074 m .65183 .68954 L .64901 .68955 L p .707 .577 .707 r
F P
0 g
s
.64901 .68955 m .64061 .68956 L p .65578 .70074 L .707 .577 .707 r
F P
0 g
s
.65183 .68954 m .66454 .72554 L .68386 .72204 L p .707 .577 .707 r
F P
0 g
s
.65148 .56441 m .63886 .61707 L .65086 .63003 L p .707 .577 .707 r
F P
0 g
s
.79104 .7522 m .78765 .77003 L .81146 .767 L p .707 .577 .707 r
F P
0 g
s
.81146 .767 m .81485 .74918 L .79104 .7522 L p .707 .577 .707 r
F P
0 g
s
.63886 .61707 m .65148 .56441 L .64897 .55262 L p .707 .577 .707 r
F P
0 g
s
.65254 .71778 m .64915 .7356 L .66973 .74721 L p .707 .577 .707 r
F P
0 g
s
.64915 .7356 m .65207 .72025 L p .64033 .7058 L .707 .577 .707 r
F P
0 g
s
.65207 .72025 m .65254 .71778 L .65031 .71559 L p .707 .577 .707 r
F P
0 g
s
.65031 .71559 m .64033 .7058 L p .65207 .72025 L .707 .577 .707 r
F P
0 g
s
.65332 .72555 m .64244 .69473 L p .63859 .68608 L .707 .577 .707 r
F P
0 g
s
.64244 .69473 m .64061 .68956 L .64024 .68893 L p .707 .577 .707 r
F P
0 g
s
.64024 .68893 m .63859 .68608 L p .64244 .69473 L .707 .577 .707 r
F P
0 g
s
.64061 .68956 m .65332 .72555 L .66454 .72554 L p .707 .577 .707 r
F P
0 g
s
.81485 .74918 m .81146 .767 L .82774 .76054 L p .707 .577 .707 r
F P
0 g
s
.82774 .76054 m .83113 .74271 L .81485 .74918 L p .707 .577 .707 r
F P
0 g
s
.64897 .55262 m .63634 .60528 L .63886 .61707 L p .707 .577 .707 r
F P
0 g
s
.64033 .7058 m .63694 .72363 L .64915 .7356 L p .707 .577 .707 r
F P
0 g
s
.63634 .60528 m .64897 .55262 L .65618 .54313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83113 .74271 m .82774 .76054 L .83491 .75127 L p .707 .577 .707 r
F P
0 g
s
.83491 .75127 m .8383 .73344 L .83113 .74271 L p .707 .577 .707 r
F P
0 g
s
.63694 .72363 m .64033 .7058 L .63768 .69463 L p .707 .577 .707 r
F P
0 g
s
.63768 .69463 m .63429 .71246 L .63694 .72363 L p .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .63768 .69463 L .64017 .69141 L p .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .65332 .72555 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63906 .68739 m .65131 .72208 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63859 .68608 m .63906 .68739 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .63859 .68608 L .64598 .67947 L p .707 .577 .707 r
F P
0 g
s
.64017 .69141 m .64485 .68536 L p .64114 .69489 L .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .64017 .69141 L .64114 .69489 L .707 .577 .707 r
F
.65618 .54313 m .64356 .59579 L .63634 .60528 L p F P
0 g
s
.64356 .59579 m .65618 .54313 L .67242 .53688 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .39777 .57378 L .36742 .5648 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .41602 .63201 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.39777 .57378 m .38862 .61193 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.38862 .61193 m .38514 .62644 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.41622 .632 m .39777 .57378 L .41602 .63201 L .707 .577 .707 r
F
.40308 .64552 m .41625 .63199 L .3842 .63438 L F
.42575 .65889 m .41625 .63199 L p .40308 .64552 L F P
0 g
s
.45375 .64762 m .42562 .63054 L .41625 .63199 L .707 .577 .707 r
F
.44326 .6278 m .43789 .60976 L .41629 .63199 L F
.42886 .57939 m .41625 .63199 L p .43789 .60976 L F P
0 g
s
.41625 .63199 m .42575 .65889 L .44346 .65176 L p .707 .577 .707 r
F P
0 g
s
.44346 .65176 m .45375 .64762 L p .41625 .63199 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .41623 .63205 L p .41629 .63199 L .707 .577 .707 r
F P
0 g
s
.43789 .60976 m .41625 .63199 L .41629 .63199 L .707 .577 .707 r
F
.42886 .57939 m .39777 .57378 L p .41621 .63196 L F P
0 g
s
.41623 .63205 m .41625 .63199 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .42886 .57939 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.43642 .63709 m .44657 .62728 L .42562 .63054 L .707 .577 .707 r
F
.45375 .64762 m .44657 .62728 L p .43642 .63709 L F P
0 g
s
.45375 .64762 m .47693 .6369 L p .46495 .62846 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .46409 .61036 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .44657 .62728 L p .46409 .61036 L F P
0 g
s
.46409 .61036 m .44657 .62728 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .42886 .57939 L p .44249 .62522 L F P
0 g
s
.44503 .63374 m .44657 .62728 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45765 .58108 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.47693 .6369 m .47123 .62077 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.48132 .57868 m .45765 .58108 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .47123 .62077 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .48132 .57868 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.48276 .62449 m .48077 .61637 L .47123 .62077 L .707 .577 .707 r
F
.49299 .62778 m .48473 .62006 L .48276 .62449 L F
.48473 .62006 m .48077 .61637 L .48276 .62449 L F
.48414 .61481 m .48344 .60583 L .47611 .61852 L F
.48132 .57868 m .47123 .62077 L p .48344 .60583 L F P
0 g
s
.48344 .60583 m .47123 .62077 L .47611 .61852 L .707 .577 .707 r
F
.48028 .59179 m .46421 .6009 L p .48077 .61637 L F P
0 g
s
.49299 .62778 m .48781 .61311 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49756 .57243 m .48132 .57868 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48494 .6251 m .48781 .61311 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .49756 .57243 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.4945 .61739 m .49172 .60852 L .48781 .61311 L .707 .577 .707 r
F
.50038 .62116 m .49457 .61267 L .4945 .61739 L F
.49457 .61267 m .49172 .60852 L .4945 .61739 L F
.48781 .61311 m .49299 .62778 L .50018 .62134 L p F P
0 g
s
.50018 .62134 m .50038 .62116 L p .48781 .61311 L .707 .577 .707 r
F P
0 g
s
.49327 .60671 m .49429 .5985 L .4901 .61042 L .707 .577 .707 r
F
.49756 .57243 m .48781 .61311 L p .49429 .5985 L F P
0 g
s
.49429 .5985 m .48781 .61311 L .4901 .61042 L .707 .577 .707 r
F
.48767 .58517 m .48028 .59179 L p .49172 .60852 L F P
0 g
s
.50038 .62116 m .49468 .60504 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.50477 .56295 m .49756 .57243 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49468 .60504 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .50477 .56295 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.50038 .62116 m .49836 .61769 L p .49664 .61247 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .48767 .58517 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.49197 .60956 m .49215 .61561 L p .49327 .60671 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49122 .61123 L .48494 .6251 L .707 .577 .707 r
F
.49327 .60671 m .4901 .61042 L .48494 .6251 L F
.48028 .59179 m .48781 .61311 L p .49172 .60852 L F P
0 g
s
.49215 .61561 m .48963 .60381 L p .49165 .59838 L .707 .577 .707 r
F P
0 g
s
.48767 .58517 m .49468 .60504 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49165 .59838 m .49354 .60253 L .49215 .61561 L .707 .577 .707 r
F
.48565 .5817 m .48767 .58517 L p .49295 .60124 L F P
0 g
s
.49468 .60504 m .49215 .61561 L p .49354 .60253 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48565 .5817 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .50477 .56295 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .49118 .59736 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .50226 .55115 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48494 .6251 L p .4901 .61042 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48028 .59179 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49836 .61769 m .48715 .61771 L p .48662 .60497 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .47763 .59086 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48565 .5817 m .49118 .59736 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48963 .60381 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .48565 .5817 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .47765 .59081 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47443 .58171 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .50226 .55115 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47763 .59086 m .47765 .59081 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .49026 .5382 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .49118 .59736 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48662 .60497 m .4862 .59495 L .49118 .59736 L .707 .577 .707 r
F
.49118 .59736 m .49836 .61769 L p .48662 .60497 L F P
0 g
s
.49836 .61769 m .49118 .59736 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49492 .58954 m .49468 .60504 L .49354 .60253 L .707 .577 .707 r
F
.49165 .59838 m .49492 .58954 L .49354 .60253 L F
.49664 .61247 m .49295 .60124 L .49468 .60504 L F
.49468 .60504 m .50038 .62116 L p .49664 .61247 L F P
0 g
s
.50477 .56295 m .49468 .60504 L p .49492 .58954 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .47693 .6369 L .49002 .62947 L p .707 .577 .707 r
F P
0 g
s
.49002 .62947 m .49299 .62778 L p .47123 .62077 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .4687 .63134 L p .47611 .61852 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .48494 .6251 L p .48414 .61481 L .707 .577 .707 r
F P
0 g
s
.48414 .61481 m .47611 .61852 L .4687 .63134 L .707 .577 .707 r
F
.46421 .6009 m .47123 .62077 L p .48077 .61637 L F P
0 g
s
.46421 .6009 m .44104 .61162 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .46421 .6009 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45375 .64762 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .44503 .63374 L p .45131 .62603 L .707 .577 .707 r
F P
0 g
s
.46495 .62846 m .45872 .62407 L .4553 .64027 L .707 .577 .707 r
F
.46495 .62846 m .4553 .64027 L .45375 .64762 L F
.44104 .61162 m .44657 .62728 L p .45872 .62407 L F P
0 g
s
.44503 .63374 m .4687 .63134 L p .46664 .62199 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .45131 .62603 L .44503 .63374 L .707 .577 .707 r
F
.44104 .61162 m .41304 .6229 L p .42562 .63054 L F P
0 g
s
.44657 .62728 m .44104 .61162 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41304 .6229 m .41625 .63199 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41623 .63205 m .44503 .63374 L p .44326 .6278 L .707 .577 .707 r
F P
0 g
s
.44326 .6278 m .41629 .63199 L .41623 .63205 L .707 .577 .707 r
F
.41304 .6229 m .38293 .63363 L p .3842 .63438 L F P
0 g
s
.41625 .63199 m .41304 .6229 L p .3842 .63438 L .707 .577 .707 r
F P
0 g
s
.41602 .63201 m .41623 .63205 L p .41622 .632 L .707 .577 .707 r
F P
0 g
s
.3548 .61746 m .36742 .5648 L .34079 .55333 L p .707 .577 .707 r
F P
0 g
s
.36742 .5648 m .3548 .61746 L .38514 .62644 L p .707 .577 .707 r
F P
0 g
s
.8383 .73344 m .83491 .75127 L .83226 .7401 L p .707 .577 .707 r
F P
0 g
s
.83226 .7401 m .83565 .72228 L .8383 .73344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64598 .67947 m .65869 .71546 L .65131 .72208 L p .707 .577 .707 r
F P
0 g
s
.67242 .53688 m .6598 .58955 L .64356 .59579 L p .707 .577 .707 r
F P
0 g
s
.64485 .68536 m .64146 .70319 L .63429 .71246 L p .707 .577 .707 r
F P
0 g
s
.32816 .60599 m .34079 .55333 L .32048 .54049 L p .707 .577 .707 r
F P
0 g
s
.34079 .55333 m .32816 .60599 L .3548 .61746 L p .707 .577 .707 r
F P
0 g
s
.6598 .58955 m .67242 .53688 L .69609 .53449 L p .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .81083 .65785 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82069 .62755 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .82064 .62774 L .82016 .62743 L p .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83016 .65435 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81083 .65785 m .79812 .62186 L .81744 .61836 L p .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .82069 .62755 L p .80033 .6149 L .707 .577 .707 r
F P
0 g
s
.82016 .62743 m .80033 .6149 L p .82069 .62755 L .707 .577 .707 r
F P
0 g
s
.80033 .6149 m .81295 .56223 L .83327 .57507 L p .707 .577 .707 r
F P
0 g
s
.39564 .66962 m .38293 .63363 L .35368 .64276 L p .707 .577 .707 r
F P
0 g
s
.38293 .63363 m .39564 .66962 L .42575 .65889 L p .707 .577 .707 r
F P
0 g
s
.35368 .64276 m .36639 .67875 L .39564 .66962 L p .707 .577 .707 r
F P
0 g
s
.36639 .67875 m .35368 .64276 L .32814 .6494 L p .707 .577 .707 r
F P
0 g
s
.65869 .71546 m .64598 .67947 L .66205 .67035 L p .707 .577 .707 r
F P
0 g
s
.83565 .72228 m .83226 .7401 L .82005 .72813 L p .707 .577 .707 r
F P
0 g
s
.82005 .72813 m .82344 .7103 L .83565 .72228 L p .707 .577 .707 r
F P
0 g
s
.32814 .6494 m .34085 .68539 L .36639 .67875 L p .707 .577 .707 r
F P
0 g
s
.64146 .70319 m .64485 .68536 L .66113 .6789 L p .707 .577 .707 r
F P
0 g
s
.32048 .54049 m .30785 .59315 L .32816 .60599 L p .707 .577 .707 r
F P
0 g
s
.30785 .59315 m .32048 .54049 L .30847 .52754 L p .707 .577 .707 r
F P
0 g
s
.69609 .53449 m .68347 .58715 L .6598 .58955 L p .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .65869 .71546 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.66251 .67166 m .67476 .70635 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .66205 .67035 L .68522 .65963 L p .707 .577 .707 r
F P
0 g
s
.65774 .69673 m .66113 .6789 L .67365 .67731 L p .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .67476 .70635 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68522 .65963 m .68705 .66481 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68705 .66481 m .69793 .69563 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .68522 .65963 L .71323 .64836 L p .707 .577 .707 r
F P
0 g
s
.71323 .64836 m .72594 .68435 L .69793 .69563 L p .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .68494 .67588 L .70865 .67646 L p .707 .577 .707 r
F P
0 g
s
.70865 .67646 m .71394 .67659 L p .71139 .67794 L .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .70865 .67646 L .71139 .67794 L .707 .577 .707 r
F
.67365 .67731 m .68494 .67588 L p .67932 .68019 L F P
0 g
s
.65774 .69673 m .67365 .67731 L .67932 .68019 L .707 .577 .707 r
F
.66205 .67035 m .66251 .67166 L p .66197 .67139 L F P
0 g
s
.68347 .58715 m .69609 .53449 L .72488 .53618 L p .707 .577 .707 r
F P
0 g
s
.81295 .56223 m .80033 .6149 L .7737 .60343 L p .707 .577 .707 r
F P
0 g
s
.7737 .60343 m .78632 .55076 L .81295 .56223 L p .707 .577 .707 r
F P
0 g
s
.38428 .72747 m .38767 .70964 L .35703 .70203 L p .707 .577 .707 r
F P
0 g
s
.38767 .70964 m .38428 .72747 L .41564 .73185 L p .707 .577 .707 r
F P
0 g
s
.41564 .73185 m .41903 .71402 L .38767 .70964 L p .707 .577 .707 r
F P
0 g
s
.66113 .6789 m .65774 .69673 L .64146 .70319 L p .707 .577 .707 r
F P
0 g
s
.41903 .71402 m .41564 .73185 L .44464 .73256 L p .707 .577 .707 r
F P
0 g
s
.44464 .73256 m .44803 .71473 L .41903 .71402 L p .707 .577 .707 r
F P
0 g
s
.35365 .71985 m .35703 .70203 L .33011 .69192 L p .707 .577 .707 r
F P
0 g
s
.35703 .70203 m .35365 .71985 L .38428 .72747 L p .707 .577 .707 r
F P
0 g
s
.34085 .68539 m .32814 .6494 L .30882 .6529 L p .707 .577 .707 r
F P
0 g
s
.33011 .69192 m .32672 .70975 L .35365 .71985 L p .707 .577 .707 r
F P
0 g
s
.32672 .70975 m .33 .69248 L p .30953 .68031 L .707 .577 .707 r
F P
0 g
s
.33 .69248 m .33011 .69192 L .32943 .69154 L p .707 .577 .707 r
F P
0 g
s
.32943 .69154 m .30953 .68031 L p .33 .69248 L .707 .577 .707 r
F P
0 g
s
.32153 .68889 m .31267 .66381 L p .2976 .65291 L .707 .577 .707 r
F P
0 g
s
.31267 .66381 m .30882 .6529 L .30608 .6529 L p .707 .577 .707 r
F P
0 g
s
.30608 .6529 m .2976 .65291 L p .31267 .66381 L .707 .577 .707 r
F P
0 g
s
.30882 .6529 m .32153 .68889 L .34085 .68539 L p .707 .577 .707 r
F P
0 g
s
.71226 .58884 m .72488 .53618 L .75598 .54178 L p .707 .577 .707 r
F P
0 g
s
.72488 .53618 m .71226 .58884 L .68347 .58715 L p .707 .577 .707 r
F P
0 g
s
.78632 .55076 m .7737 .60343 L .74335 .59445 L p .707 .577 .707 r
F P
0 g
s
.74335 .59445 m .75598 .54178 L .78632 .55076 L p .707 .577 .707 r
F P
0 g
s
.30847 .52754 m .29585 .5802 L .30785 .59315 L p .707 .577 .707 r
F P
0 g
s
.75598 .54178 m .74335 .59445 L .71226 .58884 L p .707 .577 .707 r
F P
0 g
s
.44803 .71473 m .44464 .73256 L .46845 .72954 L p .707 .577 .707 r
F P
0 g
s
.46845 .72954 m .47184 .71171 L .44803 .71473 L p .707 .577 .707 r
F P
0 g
s
.82344 .7103 m .82005 .72813 L .79947 .71652 L p .707 .577 .707 r
F P
0 g
s
.79947 .71652 m .80286 .69869 L .82344 .7103 L p .707 .577 .707 r
F P
0 g
s
.79812 .62186 m .81083 .65785 L .78529 .66449 L p .707 .577 .707 r
F P
0 g
s
.78529 .66449 m .77258 .6285 L .79812 .62186 L p .707 .577 .707 r
F P
0 g
s
.29585 .5802 m .30847 .52754 L .30596 .51574 L p .707 .577 .707 r
F P
0 g
s
.30953 .68031 m .30614 .69814 L .32672 .70975 L p .707 .577 .707 r
F P
0 g
s
.68494 .67588 m .68155 .6937 L .65774 .69673 L p .707 .577 .707 r
F P
0 g
s
.30614 .69814 m .30896 .68332 L p .29732 .66833 L .707 .577 .707 r
F P
0 g
s
.30896 .68332 m .30953 .68031 L .30682 .67765 L p .707 .577 .707 r
F P
0 g
s
.30682 .67765 m .29732 .66833 L p .30896 .68332 L .707 .577 .707 r
F P
0 g
s
.31031 .6889 m .29932 .6578 L p .29558 .64944 L .707 .577 .707 r
F P
0 g
s
.29932 .6578 m .2976 .65291 L .29725 .65232 L p .707 .577 .707 r
F P
0 g
s
.29725 .65232 m .29558 .64944 L p .29932 .6578 L .707 .577 .707 r
F P
0 g
s
.2976 .65291 m .31031 .6889 L .32153 .68889 L p .707 .577 .707 r
F P
0 g
s
.47184 .71171 m .46845 .72954 L .48473 .72307 L p .707 .577 .707 r
F P
0 g
s
.48473 .72307 m .48812 .70525 L .47184 .71171 L p .707 .577 .707 r
F P
0 g
s
.77258 .6285 m .78529 .66449 L .75604 .67362 L p .707 .577 .707 r
F P
0 g
s
.75604 .67362 m .74333 .63763 L .77258 .6285 L p .707 .577 .707 r
F P
0 g
s
.80286 .69869 m .79947 .71652 L .77255 .70641 L p .707 .577 .707 r
F P
0 g
s
.77255 .70641 m .77594 .68858 L .80286 .69869 L p .707 .577 .707 r
F P
0 g
s
.30596 .51574 m .29333 .5684 L .29585 .5802 L p .707 .577 .707 r
F P
0 g
s
.29732 .66833 m .29393 .68616 L .30614 .69814 L p .707 .577 .707 r
F P
0 g
s
.72594 .68435 m .71323 .64836 L .74333 .63763 L p .707 .577 .707 r
F P
0 g
s
.71394 .67659 m .71055 .69442 L .68155 .6937 L p .707 .577 .707 r
F P
0 g
s
.74333 .63763 m .75604 .67362 L .72594 .68435 L p .707 .577 .707 r
F P
0 g
s
.29333 .5684 m .30596 .51574 L .31317 .50626 L p .707 .577 .707 r
F P
0 g
s
.77594 .68858 m .77255 .70641 L .74191 .6988 L p .707 .577 .707 r
F P
0 g
s
.74191 .6988 m .7453 .68097 L .77594 .68858 L p .707 .577 .707 r
F P
0 g
s
.71055 .69442 m .71394 .67659 L .7453 .68097 L p .707 .577 .707 r
F P
0 g
s
.7453 .68097 m .74191 .6988 L .71055 .69442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.48812 .70525 m .48473 .72307 L .4919 .7138 L p .707 .577 .707 r
F P
0 g
s
.4919 .7138 m .49529 .69598 L .48812 .70525 L p .707 .577 .707 r
F P
0 g
s
.29393 .68616 m .29732 .66833 L .29467 .65717 L p .707 .577 .707 r
F P
0 g
s
.29467 .65717 m .29128 .67499 L .29393 .68616 L p .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29467 .65717 L .29698 .65418 L p .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .31031 .6889 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29594 .65046 m .3083 .68543 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29558 .64944 m .29594 .65046 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .29558 .64944 L .30297 .64282 L p .707 .577 .707 r
F P
0 g
s
.29698 .65418 m .30184 .6479 L p .29798 .6578 L .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29698 .65418 L .29798 .6578 L .707 .577 .707 r
F
.31317 .50626 m .30055 .55892 L .29333 .5684 L p F P
0 g
s
.30055 .55892 m .31317 .50626 L .32941 .50001 L p .707 .577 .707 r
F P
0 g
s
.49529 .69598 m .4919 .7138 L .48925 .70264 L p .707 .577 .707 r
F P
0 g
s
.48925 .70264 m .49264 .68481 L .49529 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30297 .64282 m .31568 .67881 L .3083 .68543 L p .707 .577 .707 r
F P
0 g
s
.32941 .50001 m .31679 .55267 L .30055 .55892 L p .707 .577 .707 r
F P
0 g
s
.30184 .6479 m .29845 .66572 L .29128 .67499 L p .707 .577 .707 r
F P
0 g
s
.31679 .55267 m .32941 .50001 L .35308 .49761 L p .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .46782 .6212 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .47765 .59081 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47763 .59086 L .47749 .59077 L p .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .48715 .61771 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.46782 .6212 m .45511 .58521 L .47443 .58171 L p .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .47765 .59081 L p .45732 .57802 L .707 .577 .707 r
F P
0 g
s
.47749 .59077 m .45732 .57802 L p .47765 .59081 L .707 .577 .707 r
F P
0 g
s
.45732 .57802 m .46994 .52536 L .49026 .5382 L p .707 .577 .707 r
F P
0 g
s
.31568 .67881 m .30297 .64282 L .31904 .63371 L p .707 .577 .707 r
F P
0 g
s
.49264 .68481 m .48925 .70264 L .47704 .69066 L p .707 .577 .707 r
F P
0 g
s
.47704 .69066 m .48043 .67283 L .49264 .68481 L p .707 .577 .707 r
F P
0 g
s
.29845 .66572 m .30184 .6479 L .31812 .64143 L p .707 .577 .707 r
F P
0 g
s
.35308 .49761 m .34046 .55028 L .31679 .55267 L p .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31568 .67881 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.3194 .63473 m .33175 .6697 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31904 .63371 L .34221 .62299 L p .707 .577 .707 r
F P
0 g
s
.31473 .65926 m .31812 .64143 L .32972 .63996 L p .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .33175 .6697 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34221 .62299 m .34393 .62788 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34393 .62788 m .35492 .65898 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .34221 .62299 L .37021 .61171 L p .707 .577 .707 r
F P
0 g
s
.37021 .61171 m .38293 .6477 L .35492 .65898 L p .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .34193 .63841 L .36449 .63896 L p .707 .577 .707 r
F P
0 g
s
.36449 .63896 m .37093 .63912 L p .36783 .64076 L .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .36449 .63896 L .36783 .64076 L .707 .577 .707 r
F
.32972 .63996 m .34193 .63841 L p .33585 .64307 L F P
0 g
s
.31473 .65926 m .32972 .63996 L .33585 .64307 L .707 .577 .707 r
F
.31904 .63371 m .3194 .63473 L p .31898 .63452 L F P
0 g
s
.34046 .55028 m .35308 .49761 L .38187 .4993 L p .707 .577 .707 r
F P
0 g
s
.46994 .52536 m .45732 .57802 L .43069 .56655 L p .707 .577 .707 r
F P
0 g
s
.43069 .56655 m .44331 .51389 L .46994 .52536 L p .707 .577 .707 r
F P
0 g
s
.31812 .64143 m .31473 .65926 L .29845 .66572 L p .707 .577 .707 r
F P
0 g
s
.36925 .55196 m .38187 .4993 L .41296 .50491 L p .707 .577 .707 r
F P
0 g
s
.38187 .4993 m .36925 .55196 L .34046 .55028 L p .707 .577 .707 r
F P
0 g
s
.44331 .51389 m .43069 .56655 L .40034 .55757 L p .707 .577 .707 r
F P
0 g
s
.40034 .55757 m .41296 .50491 L .44331 .51389 L p .707 .577 .707 r
F P
0 g
s
.41296 .50491 m .40034 .55757 L .36925 .55196 L p .707 .577 .707 r
F P
0 g
s
.48043 .67283 m .47704 .69066 L .45646 .67905 L p .707 .577 .707 r
F P
0 g
s
.45646 .67905 m .45985 .66122 L .48043 .67283 L p .707 .577 .707 r
F P
0 g
s
.45511 .58521 m .46782 .6212 L .44228 .62784 L p .707 .577 .707 r
F P
0 g
s
.44228 .62784 m .42957 .59185 L .45511 .58521 L p .707 .577 .707 r
F P
0 g
s
.34193 .63841 m .33854 .65624 L .31473 .65926 L p .707 .577 .707 r
F P
0 g
s
.42957 .59185 m .44228 .62784 L .41303 .63697 L p .707 .577 .707 r
F P
0 g
s
.41303 .63697 m .40032 .60098 L .42957 .59185 L p .707 .577 .707 r
F P
0 g
s
.45985 .66122 m .45646 .67905 L .42954 .66894 L p .707 .577 .707 r
F P
0 g
s
.42954 .66894 m .43293 .65112 L .45985 .66122 L p .707 .577 .707 r
F P
0 g
s
.38293 .6477 m .37021 .61171 L .40032 .60098 L p .707 .577 .707 r
F P
0 g
s
.37093 .63912 m .36754 .65695 L .33854 .65624 L p .707 .577 .707 r
F P
0 g
s
.40032 .60098 m .41303 .63697 L .38293 .6477 L p .707 .577 .707 r
F P
0 g
s
.43293 .65112 m .42954 .66894 L .3989 .66133 L p .707 .577 .707 r
F P
0 g
s
.3989 .66133 m .40229 .6435 L .43293 .65112 L p .707 .577 .707 r
F P
0 g
s
.36754 .65695 m .37093 .63912 L .40229 .6435 L p .707 .577 .707 r
F P
0 g
s
.40229 .6435 m .3989 .66133 L .36754 .65695 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0I7oo001TOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
06Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
065oo`P000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00GGoo10000eYF00@005YFFUIJ
EPT000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001IOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001FOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`04001JEUYF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001Woo4P00CGoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUH000030019Ool005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD004Aoo`00E7oo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003Ool0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@0041oo`00E7oo00<005YFFUH00eYF00@005YFFUIJEPd000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol005Aoo`80009JEPH0009JEP80
00=oo`04001JEUYF0002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF100015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000003Yoo`00E7oo10000UYF00<005YFFUH00eYF00H005YF000007oo0002FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00=goo001COol30003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01EYF0`0000AJEP00000000EJEP03001JEUYF
00AJEP03001JEUYF00AJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Eoo`00Dgoo0`000eYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF1@000eYF0`0000=JEP00FUH01UYF00<005YFFUH015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
=7oo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
000000030005FUH40006FUH00`00FUIJEP04FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000bOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000EJEP04001JEUYFFUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0;goo001COol00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP03
FUH200000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02io
o`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH90002
FUH20006FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8002moo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YF0000;Woo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH70004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000jOol7000EOol20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00UYF10000UYF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH50002FUH20003Ool7
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`0ZOol003Ioo`@000=JEP04001JEUYFFUH9000=Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF000005YF0000
1UYF0`0027oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0:Woo000dOol30005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60008Ool20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool40007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol0039oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000Moo`04001JEUYF0007FUH0
0`00FUIJEP07FUH50007FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP03001JEUYF00=JEP8000Moo`T0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000/Ool0031oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000Eoo`<000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH30004Ool50004Ool40007FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000Aoo`8000IJEP03001JEUYF00=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00T000Qoo`8000EJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00
;goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000Aoo`8000AJEP04001JEUYFFUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000:
Ool300000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`800004FUH005YFFUH30008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000Uoo`8000IJ
EP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004Ool40003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEPd000AJEP04001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<0
009oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00004FUH005YF0002
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPH0009J
EP03001JEUYF009JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF00000`000UYF00T005YFFUIJEP00FUH005YF000015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH00eYF0`00
15YF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH30006FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000=JEP8000QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH0
0`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000goo001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001J
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20006FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000001eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0300000eYF0000000>0008FUH40007FUH00`00
FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0017oo0`0025YF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000eYF00@005YFFUIJEPH000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP05001JEP00001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP040000
15YF000000000eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000Eoo`03001JEUYF00IJEP03001JEUYF00EJEP<0
0003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002eoo`03
001JEUYF009JEPD0009JEP80009oo`T000AJEP03001JEUYF00MJEPD00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00IJEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD000Aoo`8000IJEP03001JEUYF
009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^
Ool002eoo`800005FUH00000FUH00005FUH01000FUH000002Goo1P0025YF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001eYF0P000eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP80
00Aoo`8000=JEP03001JEUYF00<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool002aoo`04001JEP000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
27oo0`0000Aoo`00000000EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEPL000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP8000Aoo`800006FUH00000001JEP002EYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000AJEP00000000=JEP04001JEUYF
FUH>0006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01EYF0P000goo0`0015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01`00;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000goo000000030006Ool30003
FUH60006FUH30004FUH40002FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF
10001eYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEPH0009JEP05001JEP00FUH0000]
Ool002aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000Mo
o`800004FUH000000004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH50006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20006FUH40009FUH00`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH01000FUIJ
EUYF0P0000=JEP000000;Woo000/Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH60004Ool01000FUH000000UYF00<005YFFUH00eYF00@005YF000000EJEP03001J
EUYF00IJEP03001JEP0000D0009JEP03001JEUYF00EJEP@000aJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<00003FUH005YF00EJEP04001JEP000002FUH00`00Oomoo`0^Ool002eo
o`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2@0000=JEP00
FUH015YF0P001eYF00<005YFFUH01EYF0`001UYF10001UYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00003`0000AJEP000000035oo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF009J
EP800003FUH005YF00IJEP03001JEUYF00=JEP<000UJEP03001JEUYF008000=JEP03001JEUYF00=J
EP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP04FUH2000cOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUH0
05YF00000UYF0`000eYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01EYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF4`0015YF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
=Goo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH20005
FUH00`00FUIJEP02FUH50005FUH30007FUH00`00FUIJEP04FUH20006FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0100015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF0P00=goo000`Ool00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH20002FUH00`00FUIJ
EP0700001EYF001JEUYF000015YF1@001UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000MJEP<003Uoo`00<Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH00UYF1`00
0UYF00<005YFFUH00eYF00@005YFFUH000AJEPD000IJEP03001JEUYF00QJEP800003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL003aoo`00
<goo00@005YFFUH000MJEP03001JEUYF00MJEP04001JEUYFFUH30005FUH01000FUIJEP0015YF0`00
0UYF00<005YFFUH00UYF00@005YFFUH000AJEPD000IJEP03001JEUYF00UJEP<000AJEP03001JEUYF
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003eoo`00
=7oo0`001eYF00<005YFFUH01eYF100025YF10001EYF00<005YF00000P000UYF00<005YF00000UYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH0009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUIJEUYF400015YF00<0
05YFFUH01eYF00@005YFFUIJEP<003Yoo`00=Woo0P001UYF00<005YFFUH01UYF0P0000=JEP00FUH0
25YF00@005YFFUH000EJEP04001JEUYFFUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH60004FUH20002FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP05FUH2
000hOol003Qoo`8000AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH00`00FUIJEP05FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000D0009JEP03001JEUYF00IJEP<003Io
o`00>Woo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00<005YFFUH00UYF0`0025YF00<0
05YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH01EYF0`001Woo10001eYF00<005YFFUH00P00=7oo000lOol500000eYF001JEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09
FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00=JEP8000eoo`8000AJEP03001JEUYF
00=JEP80039oo`00?7oo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000
15YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH01eYF1@000UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP<0009JEP<000=JEP03001JEUYF
00EJEP03001JEP000080015oo`<00003FUH005YF00EJEP80035oo`00>Goo0`001eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000`000UYF00<005YF00000P0000=JEP00FUH025YF00<005YF
FUH015YF3P000eYF00<005YFFUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YF0000009JEP04001JEUYF0005FUH00`00FUIJEP04FUH30006Ool3000>Ool20006FUH2
000aOol003Moo`800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP<000IJEP05001J
EP00001JEP040006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YF
000000IJEP03001JEP0000@000Moo`D000moo`8000=JEP04001JEUYF000`Ool003Eoo`8000=JEP80
00MJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH00`00Ool00004
0002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYF0003FUH4
0002FUH20008Ool5000AOol01000FUIJEP000eYF00<007ooOol0;Goo000cOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000000Woo00D005YFFUH005YF00D0
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF1`000UYF00<005YFFUH00UYF00<007ooOol0
1Woo1@004Woo0`000eYF00<007ooOol0;Goo000aOol30005FUH<0008FUH40007FUH00`00FUIoo`04
FUH30004Ool01000FUIJEP001EYF1@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF0`000UYF00D0
05YFFUIJEP0000Uoo`<001Eoo`04001JEUYFFUH2000^Ool002moo`800003FUH0000000D00003FUH0
05YF00IJEP03001JEUYF00@00004FUH000000003FUH00`00FUIJEP03FUH00gooFUH00004FUH20007
Ool01000FUIJEP001EYF00<005YFFUH00UYF3P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YF00000P000eYF00<007oo
Ool087oo00D005YF001JEP0002ioo`00;Woo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF00@005YF000000Uoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20006FUH01000FUIJEUYF0P000UYF00<007ooOol08Goo0P0000=JEP00Ool0
;Goo000]Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
0007FUH2000;Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF10008goo00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH7000=Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH010007Woo0`00;goo000]Ool20003FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00@005YF000000ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUHQ0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH30006FUH0
0`00FUIJEP04FUH7000EOol200000eYF0000000_Ool002aoo`8000=JEPH000IJEP<000AJEP@0009J
EP03001JEUYF00MJEP04001JEUYFFUH2000<Ool01000FUIJEP001EYF00<005YFFUH01UYF2@002eYF
00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF
100015YF00<005YFFUH01UYF00<005YFFUH00UYF5@000eYF0P00;goo000/Ool2000015YF00000000
15YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF1@001UYF00<005YFFUH015YF0P002Woo00@0
05YFFUH000EJEP03001JEUYF00=JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEP0000@000IJEP03001JEUYF009JEP800003FUH00000008000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000`Ool002ao
o`03FUH00000009JEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUH00005
0002FUH00`00FUIJEP05FUH30008Ool01000FUIJEP001EYF00<005YF000010002UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00<005YFFUH00UYF0`00
1EYF00@005YF0000009JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000`Ool002]oo`D00003FUH005YF00AJEP8000MJEP03001JEUYF00EJEP<000Ioo`@0
00IJEP03001JEUYF008000Ioo`04001JEUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH;00000eYF
00000003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00<Goo000[Ool500000eYF001JEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH2000=Ool2
0003FUH00`00FUIJEP03FUH20004Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P0000=JEP00FUH01EYF0P002Goo1`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
03=oo`00:goo00D005YF001JEP00009JEP<000=JEP03001JEUYF00IJEP03001JEP000080015oo`80
0003FUH005YF00EJEP8000=oo`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF001J
EP03FUH2000BOolE000eOol002]oo`80009JEP03001JEUYF008000AJEP03001JEUYF00EJEP<000Eo
o`<000ioo`8000IJEP06001JEP00001oo`000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000000AJEP8005ioo`00;7oo00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH010001goo
1@003goo0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF000005YF00<0061oo`00;7oo00@005YFFUIJEP80009JEP03001JEUYF00D000]oo`D0
015oo`800003FUH005YF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
06=oo`00;Goo00<005YFFUH020003goo1@004goo0P0015YF0`0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH006Aoo`00;Woo0`001EYF00@005YF000000ioo`<001Ioo`03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0065oo`00<7oo00<005YFFUH00eYF
00@005YFFUIJEP<002Eoo`@00003Ool005YF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000AJEP8005moo`00<Goo0P000UYF00<005YFFUH01EYF10008goo0P0000=oo`00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P001UYF0`00GGoo000cOol30008FUH00`00FUIJEP04000NOol3
0002Ool01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YFFUH005aoo`00=Goo0P00
1eYF00<005YFFUH015YF1@005goo100017oo0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP@000IJEP03
001JEUYF009JEP8005Yoo`00=goo0P0015YF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF
0P001Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000Aoo`@0009JEP03001JEUYF00AJEP03001oogoo05Moo`00>Goo
0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0007Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH4000:
Ool30006FUH2001HOol003aoo`<000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008000]oo`@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00D0011oo`8000AJEP03001JEP0005Moo`00?goo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00011oo`D000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD00003Ool0000000<0015oo`04001JEUYF0003FUH0
0`00Oomoo`1DOol0049oo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000FOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Woo1@004Woo
0`000eYF00<007ooOol0E7oo0015Ool60004FUH00`00FUIJEP05FUH01000FUIJEUYF1@007Woo7`00
37oo1@0057oo00@005YFFUIJEP8005Eoo`00Bgoo4000=Goo0P001UYF00@005YF000000ioo`<001Io
o`05001JEP00FUH0001EOol0095oo`03001JEUYF00AJEP04001JEUYFFUH2000VOol200000eYF001o
o`1DOol0099oo`8000=JEP03001JEUYF00AJEP@002=oo`03001JEP0005Eoo`00U7oo0P0000=JEP00
FUH01UYF00<005YFFUH010007Woo0`00EWoo002FOol30006FUH00`00FUIJEP04FUH7000EOol20000
0eYF0000001FOol009Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000Qoo`D000=JEP80
05Ioo`00Vgoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYF
FUH2001GOol009ioo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001GOol00:5oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2001HOol00:Eoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001J
Ool00:aoo`P000AJEP04001JEUYFFUH5001LOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5931 .75334 m .60094 .6992 L .57009 .69288 L p .707 .577 .707 r
F P
0 g
s
.60094 .6992 m .5931 .75334 L .62465 .75656 L p .707 .577 .707 r
F P
0 g
s
.62465 .75656 m .6325 .70242 L .60094 .6992 L p .707 .577 .707 r
F P
0 g
s
.6325 .70242 m .62797 .73363 L p .6538 .75634 L .707 .577 .707 r
F P
0 g
s
.65178 .75636 m .6538 .75634 L p .62797 .73363 L .707 .577 .707 r
F P
0 g
s
.6538 .75634 m .66165 .7022 L .6325 .70242 L p .707 .577 .707 r
F P
0 g
s
.66165 .7022 m .6538 .75634 L .66979 .75392 L p .707 .577 .707 r
F P
0 g
s
.67747 .75197 m .66165 .7022 L .66979 .75392 L .707 .577 .707 r
F
.68556 .69858 m .66165 .7022 L p .67727 .75134 L F P
0 g
s
.67747 .75197 m .67753 .75158 L .67727 .75134 L .707 .577 .707 r
F
.67753 .75158 m .68556 .69858 L .67727 .75134 L F
.67783 .75188 m .68556 .69858 L p .67747 .75197 L F P
0 g
s
.69991 .77044 m .68237 .74979 L .67783 .75188 L .707 .577 .707 r
F
.67783 .75188 m .68366 .7789 L .69818 .77134 L p F P
0 g
s
.69818 .77134 m .69991 .77044 L p .67783 .75188 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .67783 .75188 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.68556 .69858 m .67783 .75188 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.70188 .69192 m .68556 .69858 L p .69353 .74324 L .707 .577 .707 r
F P
0 g
s
.69376 .74456 m .69389 .74376 L .69353 .74324 L .707 .577 .707 r
F
.69389 .74376 m .70188 .69192 L .69353 .74324 L F
.69991 .77044 m .70711 .76317 L p .70635 .76169 L F P
0 g
s
.69428 .74433 m .70188 .69192 L p .69389 .74376 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69389 .74376 L .69376 .74456 L .707 .577 .707 r
F
.70101 .75123 m .70119 .73626 L .69629 .74198 L F
.70635 .76169 m .70128 .73669 L .70101 .75123 L F
.70128 .73669 m .70119 .73626 L .70101 .75123 L F
.70117 .73627 m .70119 .73544 L .69428 .74433 L F
.70188 .69192 m .69843 .7157 L p .70119 .73544 L F P
0 g
s
.69843 .7157 m .69428 .74433 L p .70119 .73544 L .707 .577 .707 r
F P
0 g
s
.70711 .76317 m .70699 .7626 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70699 .7626 m .70129 .73614 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70901 .68285 m .70188 .69192 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70901 .68285 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .69914 .72619 L p .70119 .73626 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70119 .73626 L .70635 .76169 L .707 .577 .707 r
F
.70116 .73699 m .70129 .73614 L p .70117 .73627 L F P
0 g
s
.70711 .76317 m .70455 .75778 L p .70324 .75011 L .707 .577 .707 r
F P
0 g
s
.70635 .76169 m .69629 .74198 L .69428 .74433 L .707 .577 .707 r
F
.69194 .73347 m .69428 .74433 L p .69629 .74198 L F P
0 g
s
.69428 .74433 m .69991 .77044 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.69991 .77044 m .69428 .74433 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .70102 .73717 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70102 .73717 m .70116 .73699 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70117 .73627 L .70093 .73661 L .707 .577 .707 r
F
.70119 .73626 m .69914 .72619 L .69629 .74198 L F
.69914 .72619 m .70129 .73614 L p .7005 .73413 L F P
0 g
s
.69914 .72619 m .69194 .73347 L p .69629 .74198 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69403 .74606 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70025 .73349 L p .70119 .73589 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .69914 .72619 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.70455 .75778 m .69816 .72813 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69816 .72813 m .69659 .7208 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69194 .73347 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .69428 .74433 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .69403 .74606 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67771 .75272 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .70455 .75778 L .69249 .75481 L p .707 .577 .707 r
F P
0 g
s
.70626 .67228 m .69841 .72642 L .69755 .72565 L p .707 .577 .707 r
F P
0 g
s
.69194 .73347 m .67569 .74192 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69249 .75481 m .68452 .71783 L .69659 .7208 L p .707 .577 .707 r
F P
0 g
s
.69755 .72565 m .68605 .71537 L p .69193 .70283 L .707 .577 .707 r
F P
0 g
s
.69193 .70283 m .70626 .67228 L .69755 .72565 L .707 .577 .707 r
F
.69841 .72642 m .70171 .71285 L .70119 .73589 L F
.70025 .73349 m .69841 .72642 L p .70119 .73589 L F P
0 g
s
.70129 .73614 m .70116 .73699 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.70324 .75011 m .7005 .73413 L .70129 .73614 L .707 .577 .707 r
F
.70129 .73614 m .70711 .76317 L p .70324 .75011 L F P
0 g
s
.70901 .68285 m .70129 .73614 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .67783 .75188 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .65198 .75073 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67569 .74192 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .67783 .75188 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.66979 .75392 m .67771 .75272 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .65873 .75674 L .65356 .75806 L .707 .577 .707 r
F
.65198 .75073 m .65356 .75806 L p .65873 .75674 L F P
0 g
s
.65356 .75806 m .65994 .7877 L .6777 .78111 L p .707 .577 .707 r
F P
0 g
s
.6777 .78111 m .68366 .7789 L p .65356 .75806 L .707 .577 .707 r
F P
0 g
s
.62797 .73363 m .62465 .75656 L .65178 .75636 L p .707 .577 .707 r
F P
0 g
s
.56224 .74702 m .57009 .69288 L .54295 .68407 L p .707 .577 .707 r
F P
0 g
s
.57009 .69288 m .56224 .74702 L .5931 .75334 L p .707 .577 .707 r
F P
0 g
s
.5351 .73821 m .54295 .68407 L .52218 .67363 L p .707 .577 .707 r
F P
0 g
s
.54295 .68407 m .5351 .73821 L .56224 .74702 L p .707 .577 .707 r
F P
0 g
s
.59992 .80296 m .59195 .76599 L .56152 .77095 L p .707 .577 .707 r
F P
0 g
s
.59195 .76599 m .59992 .80296 L .63109 .796 L p .707 .577 .707 r
F P
0 g
s
.63109 .796 m .62312 .75902 L .59195 .76599 L p .707 .577 .707 r
F P
0 g
s
.62312 .75902 m .63109 .796 L .65994 .7877 L p .707 .577 .707 r
F P
0 g
s
.65994 .7877 m .65198 .75073 L .62312 .75902 L p .707 .577 .707 r
F P
0 g
s
.56152 .77095 m .56948 .80792 L .59992 .80296 L p .707 .577 .707 r
F P
0 g
s
.56948 .80792 m .56152 .77095 L .5348 .77342 L p .707 .577 .707 r
F P
0 g
s
.5348 .77342 m .54276 .81039 L .56948 .80792 L p .707 .577 .707 r
F P
0 g
s
.52218 .67363 m .51433 .72777 L .5351 .73821 L p .707 .577 .707 r
F P
0 g
s
.59252 .85502 m .59462 .83685 L .56365 .83139 L p .707 .577 .707 r
F P
0 g
s
.59462 .83685 m .59252 .85502 L .62417 .85746 L p .707 .577 .707 r
F P
0 g
s
.62417 .85746 m .62627 .83928 L .59462 .83685 L p .707 .577 .707 r
F P
0 g
s
.51433 .72777 m .52218 .67363 L .50981 .66258 L p .707 .577 .707 r
F P
0 g
s
.62627 .83928 m .62417 .85746 L .65341 .85663 L p .707 .577 .707 r
F P
0 g
s
.65341 .85663 m .65551 .83845 L .62627 .83928 L p .707 .577 .707 r
F P
0 g
s
.56155 .84956 m .56365 .83139 L .5364 .82344 L p .707 .577 .707 r
F P
0 g
s
.56365 .83139 m .56155 .84956 L .59252 .85502 L p .707 .577 .707 r
F P
0 g
s
.54276 .81039 m .5348 .77342 L .51441 .77315 L p .707 .577 .707 r
F P
0 g
s
.5364 .82344 m .5343 .84161 L .56155 .84956 L p .707 .577 .707 r
F P
0 g
s
.51441 .77315 m .52238 .81013 L .54276 .81039 L p .707 .577 .707 r
F P
0 g
s
.65551 .83845 m .65341 .85663 L .67736 .85261 L p .707 .577 .707 r
F P
0 g
s
.67736 .85261 m .67947 .83444 L .65551 .83845 L p .707 .577 .707 r
F P
0 g
s
.50981 .66258 m .50196 .71672 L .51433 .72777 L p .707 .577 .707 r
F P
0 g
s
.5343 .84161 m .5364 .82344 L .51553 .81378 L p .707 .577 .707 r
F P
0 g
s
.51553 .81378 m .51342 .83195 L .5343 .84161 L p .707 .577 .707 r
F P
0 g
s
.50196 .71672 m .50981 .66258 L .50706 .652 L p .707 .577 .707 r
F P
0 g
s
.52238 .81013 m .51441 .77315 L .50235 .77018 L p .707 .577 .707 r
F P
0 g
s
.67947 .83444 m .67736 .85261 L .6937 .84581 L p .707 .577 .707 r
F P
0 g
s
.6937 .84581 m .6958 .82763 L .67947 .83444 L p .707 .577 .707 r
F P
0 g
s
.50235 .77018 m .51031 .80716 L .52238 .81013 L p .707 .577 .707 r
F P
0 g
s
.51342 .83195 m .51553 .81378 L .50308 .80334 L p .707 .577 .707 r
F P
0 g
s
.50706 .652 m .49921 .70614 L .50196 .71672 L p .707 .577 .707 r
F P
0 g
s
.50308 .80334 m .50098 .82152 L .51342 .83195 L p .707 .577 .707 r
F P
0 g
s
.69841 .72642 m .70626 .67228 L .70901 .68285 L p .707 .577 .707 r
F P
0 g
s
.49921 .70614 m .50706 .652 L .51419 .64294 L p .707 .577 .707 r
F P
0 g
s
.51031 .80716 m .50235 .77018 L .49979 .7648 L p .707 .577 .707 r
F P
0 g
s
.49321 .82176 m .48908 .31945 L .44507 .31713 L p .707 .577 .707 r
F P
0 g
s
.49979 .7648 m .50775 .80177 L .51031 .80716 L p .707 .577 .707 r
F P
0 g
s
.50098 .82152 m .50308 .80334 L .50028 .79317 L p .707 .577 .707 r
F P
0 g
s
.50028 .79317 m .49817 .81134 L .50098 .82152 L p .707 .577 .707 r
F P
0 g
s
.51419 .64294 m .50635 .69708 L .49921 .70614 L p .707 .577 .707 r
F P
0 g
s
.50635 .69708 m .51419 .64294 L .53051 .63627 L p .707 .577 .707 r
F P
0 g
s
.50775 .80177 m .49979 .7648 L .50699 .75752 L p .707 .577 .707 r
F P
0 g
s
.50699 .75752 m .51495 .79449 L .50775 .80177 L p .707 .577 .707 r
F P
0 g
s
.49817 .81134 m .50028 .79317 L .50739 .78424 L p .707 .577 .707 r
F P
0 g
s
.50739 .78424 m .50529 .80241 L .49817 .81134 L p .707 .577 .707 r
F P
0 g
s
.53051 .63627 m .52266 .69041 L .50635 .69708 L p .707 .577 .707 r
F P
0 g
s
.52266 .69041 m .53051 .63627 L .55442 .63265 L p .707 .577 .707 r
F P
0 g
s
.51495 .79449 m .50699 .75752 L .52324 .74906 L p .707 .577 .707 r
F P
0 g
s
.52324 .74906 m .53121 .78604 L .51495 .79449 L p .707 .577 .707 r
F P
0 g
s
.50529 .80241 m .50739 .78424 L .52373 .77743 L p .707 .577 .707 r
F P
0 g
s
.55442 .63265 m .54657 .68679 L .52266 .69041 L p .707 .577 .707 r
F P
0 g
s
.52373 .77743 m .52163 .79561 L .50529 .80241 L p .707 .577 .707 r
F P
0 g
s
.53121 .78604 m .52324 .74906 L .54696 .74026 L p .707 .577 .707 r
F P
0 g
s
.54696 .74026 m .55492 .77724 L .53121 .78604 L p .707 .577 .707 r
F P
0 g
s
.52163 .79561 m .52373 .77743 L .54769 .77342 L p .707 .577 .707 r
F P
0 g
s
.54769 .77342 m .54559 .79159 L .52163 .79561 L p .707 .577 .707 r
F P
0 g
s
.48908 .31945 m .49321 .82176 L .53815 .82033 L p .707 .577 .707 r
F P
0 g
s
.53815 .82033 m .53402 .31802 L .48908 .31945 L p .707 .577 .707 r
F P
0 g
s
.6958 .82763 m .6937 .84581 L .70082 .83688 L p .707 .577 .707 r
F P
0 g
s
.70082 .83688 m .70292 .81871 L .6958 .82763 L p .707 .577 .707 r
F P
0 g
s
.54657 .68679 m .55442 .63265 L .58358 .63244 L p .707 .577 .707 r
F P
0 g
s
.58358 .63244 m .57573 .68658 L .54657 .68679 L p .707 .577 .707 r
F P
0 g
s
.55492 .77724 m .54696 .74026 L .57581 .73197 L p .707 .577 .707 r
F P
0 g
s
.57581 .73197 m .58377 .76894 L .55492 .77724 L p .707 .577 .707 r
F P
0 g
s
.54559 .79159 m .54769 .77342 L .57692 .77259 L p .707 .577 .707 r
F P
0 g
s
.57692 .77259 m .57482 .79076 L .54559 .79159 L p .707 .577 .707 r
F P
0 g
s
.57482 .79076 m .57692 .77259 L .60858 .77502 L p .707 .577 .707 r
F P
0 g
s
.60858 .77502 m .60647 .79319 L .57482 .79076 L p .707 .577 .707 r
F P
0 g
s
.53402 .31802 m .53815 .82033 L .57963 .8153 L p .707 .577 .707 r
F P
0 g
s
.57573 .68658 m .58358 .63244 L .61513 .63565 L p .707 .577 .707 r
F P
0 g
s
.61513 .63565 m .60728 .68979 L .57573 .68658 L p .707 .577 .707 r
F P
0 g
s
.58377 .76894 m .57581 .73197 L .60698 .725 L p .707 .577 .707 r
F P
0 g
s
.57963 .8153 m .5755 .31298 L .53402 .31802 L p .707 .577 .707 r
F P
0 g
s
.4492 .81944 m .44507 .31713 L .40631 .3113 L p .707 .577 .707 r
F P
0 g
s
.44507 .31713 m .4492 .81944 L .49321 .82176 L p .707 .577 .707 r
F P
0 g
s
.61494 .76198 m .60698 .725 L .63741 .72004 L p .707 .577 .707 r
F P
0 g
s
.60698 .725 m .61494 .76198 L .58377 .76894 L p .707 .577 .707 r
F P
0 g
s
.63954 .78048 m .63744 .79865 L .60647 .79319 L p .707 .577 .707 r
F P
0 g
s
.60647 .79319 m .60858 .77502 L .63954 .78048 L p .707 .577 .707 r
F P
0 g
s
.5755 .31298 m .57963 .8153 L .61359 .80715 L p .707 .577 .707 r
F P
0 g
s
.64598 .64197 m .63813 .69611 L .60728 .68979 L p .707 .577 .707 r
F P
0 g
s
.60728 .68979 m .61513 .63565 L .64598 .64197 L p .707 .577 .707 r
F P
0 g
s
.61359 .80715 m .60946 .30484 L .5755 .31298 L p .707 .577 .707 r
F P
0 g
s
.68605 .71537 m .69389 .66123 L .70626 .67228 L p .707 .577 .707 r
F P
0 g
s
.25009 .71649 m .25794 .66235 L .22708 .65603 L p .707 .577 .707 r
F P
0 g
s
.25794 .66235 m .25009 .71649 L .28164 .7197 L p .707 .577 .707 r
F P
0 g
s
.28164 .7197 m .28949 .66556 L .25794 .66235 L p .707 .577 .707 r
F P
0 g
s
.41044 .81361 m .40631 .3113 L .37659 .30252 L p .707 .577 .707 r
F P
0 g
s
.40631 .3113 m .41044 .81361 L .4492 .81944 L p .707 .577 .707 r
F P
0 g
s
.70292 .81871 m .70082 .83688 L .69801 .8267 L p .707 .577 .707 r
F P
0 g
s
.69801 .8267 m .70012 .80853 L .70292 .81871 L p .707 .577 .707 r
F P
0 g
s
.28949 .66556 m .28495 .69686 L p .31079 .71949 L .707 .577 .707 r
F P
0 g
s
.30867 .71951 m .31079 .71949 L p .28495 .69686 L .707 .577 .707 r
F P
0 g
s
.31079 .71949 m .31864 .66535 L .28949 .66556 L p .707 .577 .707 r
F P
0 g
s
.31864 .66535 m .31079 .71949 L .32757 .71695 L p .707 .577 .707 r
F P
0 g
s
.33449 .71519 m .31864 .66535 L .32757 .71695 L .707 .577 .707 r
F
.34255 .66173 m .31864 .66535 L p .3343 .71462 L F P
0 g
s
.33449 .71519 m .33454 .71485 L .3343 .71462 L .707 .577 .707 r
F
.33454 .71485 m .34255 .66173 L .3343 .71462 L F
.33481 .71511 m .34255 .66173 L p .33449 .71519 L F P
0 g
s
.3569 .73373 m .33933 .71304 L .33481 .71511 L .707 .577 .707 r
F
.33481 .71511 m .34065 .74219 L .3552 .73462 L p F P
0 g
s
.3552 .73462 m .3569 .73373 L p .33481 .71511 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .33481 .71511 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.34255 .66173 m .33481 .71511 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35887 .65507 m .34255 .66173 L p .35054 .70653 L .707 .577 .707 r
F P
0 g
s
.35077 .70778 m .35089 .70702 L .35054 .70653 L .707 .577 .707 r
F
.35089 .70702 m .35887 .65507 L .35054 .70653 L F
.3569 .73373 m .3641 .72646 L p .36327 .72484 L F P
0 g
s
.35126 .70756 m .35887 .65507 L p .35089 .70702 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35089 .70702 L .35077 .70778 L .707 .577 .707 r
F
.35799 .71449 m .35816 .6995 L .35326 .70523 L F
.36327 .72484 m .35825 .69998 L .35799 .71449 L F
.35825 .69998 m .35816 .6995 L .35799 .71449 L F
.35816 .69949 m .35818 .69874 L .35126 .70756 L F
.35887 .65507 m .35541 .67893 L p .35818 .69874 L F P
0 g
s
.35541 .67893 m .35126 .70756 L p .35818 .69874 L .707 .577 .707 r
F P
0 g
s
.36345 .7251 m .36323 .72462 L .36327 .72484 L .707 .577 .707 r
F
.36396 .72583 m .36323 .72462 L .36345 .7251 L F
.366 .646 m .35887 .65507 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .35816 .6995 L .36323 .72462 L .707 .577 .707 r
F
.35815 .70014 m .35827 .69938 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .366 .646 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.36396 .72583 m .35827 .69938 L p .36323 .72462 L .707 .577 .707 r
F P
0 g
s
.35827 .69938 m .35613 .68948 L p .35816 .6995 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36396 .72583 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36154 .72107 L p .3602 .71326 L .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .35126 .70756 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .3569 .73373 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3569 .73373 m .35126 .70756 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35799 .70035 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35799 .70035 m .35815 .70014 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35816 .69949 L .35791 .69984 L .707 .577 .707 r
F
.35816 .6995 m .35613 .68948 L .35326 .70523 L F
.35613 .68948 m .35827 .69938 L p .35749 .69737 L F P
0 g
s
.35613 .68948 m .34893 .69676 L p .35326 .70523 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35102 .70921 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35733 .69699 L p .35818 .69915 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .35613 .68948 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.36154 .72107 m .35514 .69136 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35514 .69136 m .35358 .68409 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .34893 .69676 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35126 .70756 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .35102 .70921 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .3347 .71587 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .36154 .72107 L .34948 .7181 L p .707 .577 .707 r
F P
0 g
s
.36325 .63543 m .3554 .68957 L .3545 .68876 L p .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .33268 .70521 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.34948 .7181 m .34151 .68112 L .35358 .68409 L p .707 .577 .707 r
F P
0 g
s
.3545 .68876 m .34304 .67852 L p .3489 .66602 L .707 .577 .707 r
F P
0 g
s
.3489 .66602 m .36325 .63543 L .3545 .68876 L .707 .577 .707 r
F
.3554 .68957 m .35869 .67604 L .35818 .69915 L F
.35733 .69699 m .3554 .68957 L p .35818 .69915 L F P
0 g
s
.35827 .69938 m .35815 .70014 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.3602 .71326 m .35749 .69737 L .35827 .69938 L .707 .577 .707 r
F
.35827 .69938 m .3641 .72646 L p .3602 .71326 L F P
0 g
s
.366 .646 m .35827 .69938 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .33481 .71511 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .30897 .71402 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .33268 .70521 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .33481 .71511 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.32757 .71695 m .3347 .71587 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .31567 .71998 L .31053 .72129 L .707 .577 .707 r
F
.30897 .71402 m .31053 .72129 L p .31567 .71998 L F P
0 g
s
.31053 .72129 m .31693 .75099 L .33473 .74439 L p .707 .577 .707 r
F P
0 g
s
.33473 .74439 m .34065 .74219 L p .31053 .72129 L .707 .577 .707 r
F P
0 g
s
.28495 .69686 m .28164 .7197 L .30867 .71951 L p .707 .577 .707 r
F P
0 g
s
.21923 .71017 m .22708 .65603 L .19994 .64722 L p .707 .577 .707 r
F P
0 g
s
.22708 .65603 m .21923 .71017 L .25009 .71649 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69389 .66123 m .68605 .71537 L .66528 .70493 L p .707 .577 .707 r
F P
0 g
s
.66528 .70493 m .67312 .65079 L .69389 .66123 L p .707 .577 .707 r
F P
0 g
s
.63741 .72004 m .64538 .75701 L .61494 .76198 L p .707 .577 .707 r
F P
0 g
s
.60946 .30484 m .61359 .80715 L .6367 .79669 L p .707 .577 .707 r
F P
0 g
s
.6367 .79669 m .63257 .29438 L .60946 .30484 L p .707 .577 .707 r
F P
0 g
s
.19209 .70136 m .19994 .64722 L .17917 .63677 L p .707 .577 .707 r
F P
0 g
s
.19994 .64722 m .19209 .70136 L .21923 .71017 L p .707 .577 .707 r
F P
0 g
s
.25691 .76625 m .24895 .72928 L .21851 .73424 L p .707 .577 .707 r
F P
0 g
s
.24895 .72928 m .25691 .76625 L .28808 .75928 L p .707 .577 .707 r
F P
0 g
s
.28808 .75928 m .28011 .72231 L .24895 .72928 L p .707 .577 .707 r
F P
0 g
s
.28011 .72231 m .28808 .75928 L .31693 .75099 L p .707 .577 .707 r
F P
0 g
s
.31693 .75099 m .30897 .71402 L .28011 .72231 L p .707 .577 .707 r
F P
0 g
s
.21851 .73424 m .22648 .77121 L .25691 .76625 L p .707 .577 .707 r
F P
0 g
s
.22648 .77121 m .21851 .73424 L .19179 .73671 L p .707 .577 .707 r
F P
0 g
s
.70012 .80853 m .69801 .8267 L .68557 .81627 L p .707 .577 .707 r
F P
0 g
s
.68557 .81627 m .68767 .7981 L .70012 .80853 L p .707 .577 .707 r
F P
0 g
s
.38072 .80483 m .37659 .30252 L .35881 .29165 L p .707 .577 .707 r
F P
0 g
s
.37659 .30252 m .38072 .80483 L .41044 .81361 L p .707 .577 .707 r
F P
0 g
s
.19179 .73671 m .19976 .77368 L .22648 .77121 L p .707 .577 .707 r
F P
0 g
s
.17917 .63677 m .17132 .69091 L .19209 .70136 L p .707 .577 .707 r
F P
0 g
s
.68452 .71783 m .69249 .75481 L .6721 .75454 L p .707 .577 .707 r
F P
0 g
s
.6721 .75454 m .66413 .71757 L .68452 .71783 L p .707 .577 .707 r
F P
0 g
s
.24951 .81781 m .25161 .79963 L .22064 .79417 L p .707 .577 .707 r
F P
0 g
s
.25161 .79963 m .24951 .81781 L .28116 .82024 L p .707 .577 .707 r
F P
0 g
s
.28116 .82024 m .28326 .80207 L .25161 .79963 L p .707 .577 .707 r
F P
0 g
s
.67312 .65079 m .66528 .70493 L .63813 .69611 L p .707 .577 .707 r
F P
0 g
s
.63813 .69611 m .64598 .64197 L .67312 .65079 L p .707 .577 .707 r
F P
0 g
s
.17132 .69091 m .17917 .63677 L .1668 .62572 L p .707 .577 .707 r
F P
0 g
s
.28326 .80207 m .28116 .82024 L .3104 .81941 L p .707 .577 .707 r
F P
0 g
s
.3104 .81941 m .3125 .80123 L .28326 .80207 L p .707 .577 .707 r
F P
0 g
s
.21854 .81235 m .22064 .79417 L .19339 .78622 L p .707 .577 .707 r
F P
0 g
s
.22064 .79417 m .21854 .81235 L .24951 .81781 L p .707 .577 .707 r
F P
0 g
s
.19976 .77368 m .19179 .73671 L .1714 .73644 L p .707 .577 .707 r
F P
0 g
s
.19339 .78622 m .19129 .80439 L .21854 .81235 L p .707 .577 .707 r
F P
0 g
s
.1714 .73644 m .17937 .77342 L .19976 .77368 L p .707 .577 .707 r
F P
0 g
s
.66413 .71757 m .6721 .75454 L .64538 .75701 L p .707 .577 .707 r
F P
0 g
s
.64538 .75701 m .63741 .72004 L .66413 .71757 L p .707 .577 .707 r
F P
0 g
s
.63744 .79865 m .63954 .78048 L .6668 .78843 L p .707 .577 .707 r
F P
0 g
s
.63257 .29438 m .6367 .79669 L .6467 .78494 L p .707 .577 .707 r
F P
0 g
s
.6467 .78494 m .64257 .28263 L .63257 .29438 L p .707 .577 .707 r
F P
0 g
s
.3125 .80123 m .3104 .81941 L .33436 .81539 L p .707 .577 .707 r
F P
0 g
s
.33436 .81539 m .33646 .79722 L .3125 .80123 L p .707 .577 .707 r
F P
0 g
s
.1668 .62572 m .15895 .67987 L .17132 .69091 L p .707 .577 .707 r
F P
0 g
s
.68767 .7981 m .68557 .81627 L .6647 .8066 L p .707 .577 .707 r
F P
0 g
s
.6647 .8066 m .6668 .78843 L .68767 .7981 L p .707 .577 .707 r
F P
0 g
s
.19129 .80439 m .19339 .78622 L .17252 .77656 L p .707 .577 .707 r
F P
0 g
s
.17252 .77656 m .17041 .79473 L .19129 .80439 L p .707 .577 .707 r
F P
0 g
s
.15895 .67987 m .1668 .62572 L .16405 .61515 L p .707 .577 .707 r
F P
0 g
s
.17937 .77342 m .1714 .73644 L .15934 .73347 L p .707 .577 .707 r
F P
0 g
s
.3554 .68957 m .36325 .63543 L .366 .646 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .36325 .63543 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34304 .67852 m .34488 .66583 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34488 .66583 m .35088 .62438 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.36294 .79396 m .35881 .29165 L .35472 .27976 L p .707 .577 .707 r
F P
0 g
s
.35881 .29165 m .36294 .79396 L .38072 .80483 L p .707 .577 .707 r
F P
0 g
s
.35781 .79966 m .35991 .78149 L .3528 .79042 L p .707 .577 .707 r
F P
0 g
s
.35991 .78149 m .35781 .79966 L .35501 .78948 L p .707 .577 .707 r
F P
0 g
s
.35501 .78948 m .35711 .77131 L .35991 .78149 L p .707 .577 .707 r
F P
0 g
s
.35472 .27976 m .35885 .78207 L .36294 .79396 L p .707 .577 .707 r
F P
0 g
s
.35885 .78207 m .35529 .34893 L p .36472 .26801 L .707 .577 .707 r
F P
0 g
s
.35529 .34893 m .35472 .27976 L .35768 .27628 L p .707 .577 .707 r
F P
0 g
s
.35768 .27628 m .36472 .26801 L p .35529 .34893 L .707 .577 .707 r
F P
0 g
s
.33646 .79722 m .33436 .81539 L .35069 .80859 L p .707 .577 .707 r
F P
0 g
s
.35069 .80859 m .3528 .79042 L .33646 .79722 L p .707 .577 .707 r
F P
0 g
s
.15934 .73347 m .1673 .77045 L .17937 .77342 L p .707 .577 .707 r
F P
0 g
s
.6668 .78843 m .6647 .8066 L .63744 .79865 L p .707 .577 .707 r
F P
0 g
s
.17041 .79473 m .17252 .77656 L .16007 .76613 L p .707 .577 .707 r
F P
0 g
s
.16405 .61515 m .1562 .66929 L .15895 .67987 L p .707 .577 .707 r
F P
0 g
s
.16007 .76613 m .15797 .7843 L .17041 .79473 L p .707 .577 .707 r
F P
0 g
s
.1562 .66929 m .16405 .61515 L .17118 .60609 L p .707 .577 .707 r
F P
0 g
s
.64257 .28263 m .6467 .78494 L .64261 .77305 L p .707 .577 .707 r
F P
0 g
s
.64261 .77305 m .63848 .27074 L .64257 .28263 L p .707 .577 .707 r
F P
0 g
s
.1673 .77045 m .15934 .73347 L .15678 .72808 L p .707 .577 .707 r
F P
0 g
s
.3528 .79042 m .35069 .80859 L .35781 .79966 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15678 .72808 m .16474 .76506 L .1673 .77045 L p .707 .577 .707 r
F P
0 g
s
.15797 .7843 m .16007 .76613 L .15727 .75595 L p .707 .577 .707 r
F P
0 g
s
.15727 .75595 m .15516 .77412 L .15797 .7843 L p .707 .577 .707 r
F P
0 g
s
.17118 .60609 m .16334 .66023 L .1562 .66929 L p .707 .577 .707 r
F P
0 g
s
.16334 .66023 m .17118 .60609 L .1875 .59942 L p .707 .577 .707 r
F P
0 g
s
.16474 .76506 m .15678 .72808 L .16398 .72081 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16398 .72081 m .17194 .75778 L .16474 .76506 L p .707 .577 .707 r
F P
0 g
s
.15516 .77412 m .15727 .75595 L .16438 .74702 L p .707 .577 .707 r
F P
0 g
s
.63848 .27074 m .64261 .77305 L .62483 .76219 L p .707 .577 .707 r
F P
0 g
s
.62483 .76219 m .6207 .25987 L .63848 .27074 L p .707 .577 .707 r
F P
0 g
s
.16438 .74702 m .16228 .76519 L .15516 .77412 L p .707 .577 .707 r
F P
0 g
s
.1875 .59942 m .17966 .65356 L .16334 .66023 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .34304 .67852 L .32227 .66807 L p .707 .577 .707 r
F P
0 g
s
.32227 .66807 m .33011 .61393 L .35088 .62438 L p .707 .577 .707 r
F P
0 g
s
.17966 .65356 m .1875 .59942 L .21141 .5958 L p .707 .577 .707 r
F P
0 g
s
.36885 .77032 m .36472 .26801 L .38783 .25755 L p .707 .577 .707 r
F P
0 g
s
.36472 .26801 m .36885 .77032 L .35885 .78207 L p .707 .577 .707 r
F P
0 g
s
.17194 .75778 m .16398 .72081 L .18023 .71235 L p .707 .577 .707 r
F P
0 g
s
.35711 .77131 m .35501 .78948 L .34256 .77905 L p .707 .577 .707 r
F P
0 g
s
.34256 .77905 m .34466 .76088 L .35711 .77131 L p .707 .577 .707 r
F P
0 g
s
.18023 .71235 m .1882 .74933 L .17194 .75778 L p .707 .577 .707 r
F P
0 g
s
.16228 .76519 m .16438 .74702 L .18072 .74022 L p .707 .577 .707 r
F P
0 g
s
.34151 .68112 m .34948 .7181 L .32909 .71783 L p .707 .577 .707 r
F P
0 g
s
.32909 .71783 m .32112 .68086 L .34151 .68112 L p .707 .577 .707 r
F P
0 g
s
.33011 .61393 m .32227 .66807 L .29512 .65926 L p .707 .577 .707 r
F P
0 g
s
.29512 .65926 m .30297 .60512 L .33011 .61393 L p .707 .577 .707 r
F P
0 g
s
.21141 .5958 m .20356 .64994 L .17966 .65356 L p .707 .577 .707 r
F P
0 g
s
.20356 .64994 m .21141 .5958 L .24057 .59559 L p .707 .577 .707 r
F P
0 g
s
.18072 .74022 m .17862 .75839 L .16228 .76519 L p .707 .577 .707 r
F P
0 g
s
.6207 .25987 m .62483 .76219 L .59511 .7534 L p .707 .577 .707 r
F P
0 g
s
.59511 .7534 m .59098 .25109 L .6207 .25987 L p .707 .577 .707 r
F P
0 g
s
.30297 .60512 m .29512 .65926 L .26427 .65294 L p .707 .577 .707 r
F P
0 g
s
.26427 .65294 m .27212 .5988 L .30297 .60512 L p .707 .577 .707 r
F P
0 g
s
.23272 .64973 m .24057 .59559 L .27212 .5988 L p .707 .577 .707 r
F P
0 g
s
.24057 .59559 m .23272 .64973 L .20356 .64994 L p .707 .577 .707 r
F P
0 g
s
.1882 .74933 m .18023 .71235 L .20395 .70355 L p .707 .577 .707 r
F P
0 g
s
.34466 .76088 m .34256 .77905 L .32169 .76939 L p .707 .577 .707 r
F P
0 g
s
.32169 .76939 m .32379 .75121 L .34466 .76088 L p .707 .577 .707 r
F P
0 g
s
.27212 .5988 m .26427 .65294 L .23272 .64973 L p .707 .577 .707 r
F P
0 g
s
.32112 .68086 m .32909 .71783 L .30237 .7203 L p .707 .577 .707 r
F P
0 g
s
.30237 .7203 m .2944 .68333 L .32112 .68086 L p .707 .577 .707 r
F P
0 g
s
.20395 .70355 m .21191 .74053 L .1882 .74933 L p .707 .577 .707 r
F P
0 g
s
.17862 .75839 m .18072 .74022 L .20468 .7362 L p .707 .577 .707 r
F P
0 g
s
.7303 .66131 m .73815 .60717 L .70729 .60084 L p .707 .577 .707 r
F P
0 g
s
.73815 .60717 m .7303 .66131 L .76185 .66452 L p .707 .577 .707 r
F P
0 g
s
.76185 .66452 m .7697 .61038 L .73815 .60717 L p .707 .577 .707 r
F P
0 g
s
.38783 .25755 m .39196 .75986 L .36885 .77032 L p .707 .577 .707 r
F P
0 g
s
.39196 .75986 m .38783 .25755 L .42179 .2494 L p .707 .577 .707 r
F P
0 g
s
.7697 .61038 m .76517 .64159 L p .79101 .6643 L .707 .577 .707 r
F P
0 g
s
.78898 .66432 m .79101 .6643 L p .76517 .64159 L .707 .577 .707 r
F P
0 g
s
.79101 .6643 m .79886 .61016 L .7697 .61038 L p .707 .577 .707 r
F P
0 g
s
.79886 .61016 m .79101 .6643 L .807 .66188 L p .707 .577 .707 r
F P
0 g
s
.81468 .65993 m .79886 .61016 L .807 .66188 L .707 .577 .707 r
F
.82276 .60655 m .79886 .61016 L p .81447 .6593 L F P
0 g
s
.81468 .65993 m .81473 .65955 L .81447 .6593 L .707 .577 .707 r
F
.81473 .65955 m .82276 .60655 L .81447 .6593 L F
.81504 .65984 m .82276 .60655 L p .81468 .65993 L F P
0 g
s
.83711 .67841 m .81958 .65775 L .81504 .65984 L .707 .577 .707 r
F
.81504 .65984 m .82086 .68686 L .83539 .6793 L p F P
0 g
s
.83539 .6793 m .83711 .67841 L p .81504 .65984 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .81504 .65984 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.82276 .60655 m .81504 .65984 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83908 .59988 m .82276 .60655 L p .83073 .6512 L .707 .577 .707 r
F P
0 g
s
.83097 .65253 m .83109 .65172 L .83073 .6512 L .707 .577 .707 r
F
.83109 .65172 m .83908 .59988 L .83073 .6512 L F
.83711 .67841 m .84431 .67113 L p .84356 .66966 L F P
0 g
s
.83149 .65229 m .83908 .59988 L p .83109 .65172 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83109 .65172 L .83097 .65253 L .707 .577 .707 r
F
.83821 .65919 m .83839 .64422 L .83349 .64994 L F
.84356 .66966 m .83848 .64466 L .83821 .65919 L F
.83848 .64466 m .83839 .64422 L .83821 .65919 L F
.83838 .64424 m .83839 .6434 L .83149 .65229 L F
.83908 .59988 m .83564 .62366 L p .83839 .6434 L F P
0 g
s
.83564 .62366 m .83149 .65229 L p .83839 .6434 L .707 .577 .707 r
F P
0 g
s
.84431 .67113 m .84419 .67056 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84419 .67056 m .83849 .64411 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84622 .59081 m .83908 .59988 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .84622 .59081 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83635 .63415 L p .83839 .64422 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83839 .64422 L .84356 .66966 L .707 .577 .707 r
F
.83837 .64495 m .83849 .64411 L p .83838 .64424 L F P
0 g
s
.84431 .67113 m .84176 .66574 L p .84044 .65807 L .707 .577 .707 r
F P
0 g
s
.84356 .66966 m .83349 .64994 L .83149 .65229 L .707 .577 .707 r
F
.82915 .64143 m .83149 .65229 L p .83349 .64994 L F P
0 g
s
.83149 .65229 m .83711 .67841 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.83711 .67841 m .83149 .65229 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83823 .64513 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83823 .64513 m .83837 .64495 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83838 .64424 L .83813 .64458 L .707 .577 .707 r
F
.83839 .64422 m .83635 .63415 L .83349 .64994 L F
.83635 .63415 m .83849 .64411 L p .83771 .64209 L F P
0 g
s
.83635 .63415 m .82915 .64143 L p .83349 .64994 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83124 .65402 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83746 .64145 L p .83839 .64385 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .83635 .63415 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.84176 .66574 m .83537 .63609 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83537 .63609 m .83379 .62876 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .82915 .64143 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83149 .65229 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .83124 .65402 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .81492 .66069 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .84176 .66574 L .82969 .66277 L p .707 .577 .707 r
F P
0 g
s
.84346 .58024 m .83562 .63438 L .83476 .63361 L p .707 .577 .707 r
F P
0 g
s
.82915 .64143 m .8129 .64988 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.82969 .66277 m .82173 .62579 L .83379 .62876 L p .707 .577 .707 r
F P
0 g
s
.83476 .63361 m .82325 .62333 L p .82913 .61079 L .707 .577 .707 r
F P
0 g
s
.82913 .61079 m .84346 .58024 L .83476 .63361 L .707 .577 .707 r
F
.83562 .63438 m .83892 .62081 L .83839 .64385 L F
.83746 .64145 m .83562 .63438 L p .83839 .64385 L F P
0 g
s
.83849 .64411 m .83837 .64495 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.84044 .65807 m .83771 .64209 L .83849 .64411 L .707 .577 .707 r
F
.83849 .64411 m .84431 .67113 L p .84044 .65807 L F P
0 g
s
.84622 .59081 m .83849 .64411 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .81504 .65984 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .78918 .65869 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .8129 .64988 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .81504 .65984 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.807 .66188 m .81492 .66069 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .79594 .6647 L .79076 .66602 L .707 .577 .707 r
F
.78918 .65869 m .79076 .66602 L p .79594 .6647 L F P
0 g
s
.79076 .66602 m .79715 .69567 L .81491 .68907 L p .707 .577 .707 r
F P
0 g
s
.81491 .68907 m .82086 .68686 L p .79076 .66602 L .707 .577 .707 r
F P
0 g
s
.76517 .64159 m .76185 .66452 L .78898 .66432 L p .707 .577 .707 r
F P
0 g
s
.20468 .7362 m .20258 .75437 L .17862 .75839 L p .707 .577 .707 r
F P
0 g
s
.69945 .65498 m .70729 .60084 L .68015 .59203 L p .707 .577 .707 r
F P
0 g
s
.70729 .60084 m .69945 .65498 L .7303 .66131 L p .707 .577 .707 r
F P
0 g
s
.21191 .74053 m .20395 .70355 L .2328 .69526 L p .707 .577 .707 r
F P
0 g
s
.2944 .68333 m .30237 .7203 L .27193 .72527 L p .707 .577 .707 r
F P
0 g
s
.27193 .72527 m .26397 .68829 L .2944 .68333 L p .707 .577 .707 r
F P
0 g
s
.32379 .75121 m .32169 .76939 L .29443 .76144 L p .707 .577 .707 r
F P
0 g
s
.29443 .76144 m .29653 .74326 L .32379 .75121 L p .707 .577 .707 r
F P
0 g
s
.59098 .25109 m .59511 .7534 L .55635 .74757 L p .707 .577 .707 r
F P
0 g
s
.55635 .74757 m .55221 .24526 L .59098 .25109 L p .707 .577 .707 r
F P
0 g
s
.2328 .69526 m .24076 .73223 L .21191 .74053 L p .707 .577 .707 r
F P
0 g
s
.6723 .64617 m .68015 .59203 L .65938 .58159 L p .707 .577 .707 r
F P
0 g
s
.68015 .59203 m .6723 .64617 L .69945 .65498 L p .707 .577 .707 r
F P
0 g
s
.20258 .75437 m .20468 .7362 L .23391 .73537 L p .707 .577 .707 r
F P
0 g
s
.73712 .71092 m .72916 .67395 L .69872 .67891 L p .707 .577 .707 r
F P
0 g
s
.72916 .67395 m .73712 .71092 L .76829 .70396 L p .707 .577 .707 r
F P
0 g
s
.76829 .70396 m .76033 .66698 L .72916 .67395 L p .707 .577 .707 r
F P
0 g
s
.24076 .73223 m .2328 .69526 L .26397 .68829 L p .707 .577 .707 r
F P
0 g
s
.76033 .66698 m .76829 .70396 L .79715 .69567 L p .707 .577 .707 r
F P
0 g
s
.79715 .69567 m .78918 .65869 L .76033 .66698 L p .707 .577 .707 r
F P
0 g
s
.26397 .68829 m .27193 .72527 L .24076 .73223 L p .707 .577 .707 r
F P
0 g
s
.23391 .73537 m .23181 .75354 L .20258 .75437 L p .707 .577 .707 r
F P
0 g
s
.42592 .75172 m .42179 .2494 L .46327 .24437 L p .707 .577 .707 r
F P
0 g
s
.42179 .2494 m .42592 .75172 L .39196 .75986 L p .707 .577 .707 r
F P
0 g
s
.69872 .67891 m .70669 .71589 L .73712 .71092 L p .707 .577 .707 r
F P
0 g
s
.70669 .71589 m .69872 .67891 L .672 .68138 L p .707 .577 .707 r
F P
0 g
s
.29653 .74326 m .29443 .76144 L .26346 .75598 L p .707 .577 .707 r
F P
0 g
s
.26346 .75598 m .26557 .7378 L .29653 .74326 L p .707 .577 .707 r
F P
0 g
s
.23181 .75354 m .23391 .73537 L .26557 .7378 L p .707 .577 .707 r
F P
0 g
s
.26557 .7378 m .26346 .75598 L .23181 .75354 L p .707 .577 .707 r
F P
0 g
s
.672 .68138 m .67997 .71836 L .70669 .71589 L p .707 .577 .707 r
F P
0 g
s
.65938 .58159 m .65153 .63573 L .6723 .64617 L p .707 .577 .707 r
F P
0 g
s
.55221 .24526 m .55635 .74757 L .51234 .74525 L p .707 .577 .707 r
F P
0 g
s
.51234 .74525 m .50821 .24294 L .55221 .24526 L p .707 .577 .707 r
F P
0 g
s
.72972 .76298 m .73182 .74481 L .70086 .73935 L p .707 .577 .707 r
F P
0 g
s
.73182 .74481 m .72972 .76298 L .76137 .76542 L p .707 .577 .707 r
F P
0 g
s
.76137 .76542 m .76348 .74725 L .73182 .74481 L p .707 .577 .707 r
F P
0 g
s
.65153 .63573 m .65938 .58159 L .64701 .57054 L p .707 .577 .707 r
F P
0 g
s
.76348 .74725 m .76137 .76542 L .79061 .76459 L p .707 .577 .707 r
F P
0 g
s
.79061 .76459 m .79271 .74641 L .76348 .74725 L p .707 .577 .707 r
F P
0 g
s
.4674 .74668 m .46327 .24437 L .50821 .24294 L p .707 .577 .707 r
F P
0 g
s
.46327 .24437 m .4674 .74668 L .42592 .75172 L p .707 .577 .707 r
F P
0 g
s
.69875 .75753 m .70086 .73935 L .6736 .7314 L p .707 .577 .707 r
F P
0 g
s
.70086 .73935 m .69875 .75753 L .72972 .76298 L p .707 .577 .707 r
F P
0 g
s
.67997 .71836 m .672 .68138 L .65161 .68112 L p .707 .577 .707 r
F P
0 g
s
.50821 .24294 m .51234 .74525 L .4674 .74668 L p .707 .577 .707 r
F P
0 g
s
.6736 .7314 m .6715 .74957 L .69875 .75753 L p .707 .577 .707 r
F P
0 g
s
.65161 .68112 m .65958 .71809 L .67997 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .74641 m .79061 .76459 L .81457 .76057 L p .707 .577 .707 r
F P
0 g
s
.81457 .76057 m .81667 .7424 L .79271 .74641 L p .707 .577 .707 r
F P
0 g
s
.64701 .57054 m .63917 .62468 L .65153 .63573 L p .707 .577 .707 r
F P
0 g
s
.6715 .74957 m .6736 .7314 L .65273 .72174 L p .707 .577 .707 r
F P
0 g
s
.65273 .72174 m .65063 .73991 L .6715 .74957 L p .707 .577 .707 r
F P
0 g
s
.63917 .62468 m .64701 .57054 L .64426 .55996 L p .707 .577 .707 r
F P
0 g
s
.65958 .71809 m .65161 .68112 L .63955 .67815 L p .707 .577 .707 r
F P
0 g
s
.81667 .7424 m .81457 .76057 L .83091 .75377 L p .707 .577 .707 r
F P
0 g
s
.83091 .75377 m .83301 .7356 L .81667 .7424 L p .707 .577 .707 r
F P
0 g
s
.63955 .67815 m .64752 .71512 L .65958 .71809 L p .707 .577 .707 r
F P
0 g
s
.65063 .73991 m .65273 .72174 L .64028 .71131 L p .707 .577 .707 r
F P
0 g
s
.64426 .55996 m .63642 .6141 L .63917 .62468 L p .707 .577 .707 r
F P
0 g
s
.64028 .71131 m .63818 .72948 L .65063 .73991 L p .707 .577 .707 r
F P
0 g
s
.83562 .63438 m .84346 .58024 L .84622 .59081 L p .707 .577 .707 r
F P
0 g
s
.63642 .6141 m .64426 .55996 L .6514 .5509 L p .707 .577 .707 r
F P
0 g
s
.64752 .71512 m .63955 .67815 L .63699 .67276 L p .707 .577 .707 r
F P
0 g
s
.83301 .7356 m .83091 .75377 L .83802 .74484 L p .707 .577 .707 r
F P
0 g
s
.83802 .74484 m .84012 .72667 L .83301 .7356 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63699 .67276 m .64496 .70973 L .64752 .71512 L p .707 .577 .707 r
F P
0 g
s
.63818 .72948 m .64028 .71131 L .63748 .70113 L p .707 .577 .707 r
F P
0 g
s
.63748 .70113 m .63538 .7193 L .63818 .72948 L p .707 .577 .707 r
F P
0 g
s
.6514 .5509 m .64355 .60504 L .63642 .6141 L p .707 .577 .707 r
F P
0 g
s
.82325 .62333 m .8311 .56919 L .84346 .58024 L p .707 .577 .707 r
F P
0 g
s
.64355 .60504 m .6514 .5509 L .66772 .54423 L p .707 .577 .707 r
F P
0 g
s
.38729 .62445 m .39514 .57031 L .36428 .56399 L p .707 .577 .707 r
F P
0 g
s
.39514 .57031 m .38729 .62445 L .41884 .62767 L p .707 .577 .707 r
F P
0 g
s
.41884 .62767 m .42669 .57353 L .39514 .57031 L p .707 .577 .707 r
F P
0 g
s
.64496 .70973 m .63699 .67276 L .64419 .66548 L p .707 .577 .707 r
F P
0 g
s
.84012 .72667 m .83802 .74484 L .83522 .73466 L p .707 .577 .707 r
F P
0 g
s
.83522 .73466 m .83732 .71649 L .84012 .72667 L p .707 .577 .707 r
F P
0 g
s
.42669 .57353 m .42215 .60483 L p .448 .62745 L .707 .577 .707 r
F P
0 g
s
.44587 .62747 m .448 .62745 L p .42215 .60483 L .707 .577 .707 r
F P
0 g
s
.448 .62745 m .45585 .57331 L .42669 .57353 L p .707 .577 .707 r
F P
0 g
s
.45585 .57331 m .448 .62745 L .46477 .62491 L p .707 .577 .707 r
F P
0 g
s
.47169 .62315 m .45585 .57331 L .46477 .62491 L .707 .577 .707 r
F
.47975 .56969 m .45585 .57331 L p .47151 .62258 L F P
0 g
s
.47169 .62315 m .47174 .62281 L .47151 .62258 L .707 .577 .707 r
F
.47174 .62281 m .47975 .56969 L .47151 .62258 L F
.47202 .62307 m .47975 .56969 L p .47169 .62315 L F P
0 g
s
.4941 .6417 m .47653 .621 L .47202 .62307 L .707 .577 .707 r
F
.47202 .62307 m .47785 .65015 L .49241 .64258 L p F P
0 g
s
.49241 .64258 m .4941 .6417 L p .47202 .62307 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .47202 .62307 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47975 .56969 m .47202 .62307 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49607 .56303 m .47975 .56969 L p .48775 .61449 L .707 .577 .707 r
F P
0 g
s
.48797 .61575 m .48809 .61498 L .48775 .61449 L .707 .577 .707 r
F
.48809 .61498 m .49607 .56303 L .48775 .61449 L F
.4941 .6417 m .5013 .63442 L p .50047 .6328 L F P
0 g
s
.48846 .61552 m .49607 .56303 L p .48809 .61498 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48809 .61498 L .48797 .61575 L .707 .577 .707 r
F
.49519 .62245 m .49536 .60746 L .49046 .61319 L F
.50047 .6328 m .49546 .60795 L .49519 .62245 L F
.49546 .60795 m .49536 .60746 L .49519 .62245 L F
.49537 .60746 m .49538 .6067 L .48846 .61552 L F
.49607 .56303 m .49261 .58689 L p .49538 .6067 L F P
0 g
s
.49261 .58689 m .48846 .61552 L p .49538 .6067 L .707 .577 .707 r
F P
0 g
s
.50066 .63306 m .50043 .63258 L .50047 .6328 L .707 .577 .707 r
F
.50117 .63379 m .50043 .63258 L .50066 .63306 L F
.50321 .55396 m .49607 .56303 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .49536 .60746 L .50043 .63258 L .707 .577 .707 r
F
.49536 .6081 m .49547 .60734 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .50321 .55396 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.50117 .63379 m .49547 .60734 L p .50043 .63258 L .707 .577 .707 r
F P
0 g
s
.49547 .60734 m .49334 .59744 L p .49536 .60746 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .50117 .63379 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .49874 .62903 L p .49741 .62122 L .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .48846 .61552 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .4941 .6417 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.4941 .6417 m .48846 .61552 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .4952 .60831 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.4952 .60831 m .49536 .6081 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49537 .60746 L .49511 .6078 L .707 .577 .707 r
F
.49536 .60746 m .49334 .59744 L .49046 .61319 L F
.49334 .59744 m .49547 .60734 L p .49469 .60534 L F P
0 g
s
.49334 .59744 m .48614 .60472 L p .49046 .61319 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48823 .61717 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49454 .60495 L p .49538 .60711 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49334 .59744 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49874 .62903 m .49235 .59933 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49235 .59933 m .49078 .59205 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48614 .60472 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .48846 .61552 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .48823 .61717 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .47191 .62383 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49874 .62903 L .48668 .62606 L p .707 .577 .707 r
F P
0 g
s
.50045 .54339 m .49261 .59753 L .4917 .59672 L p .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .46989 .61317 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48668 .62606 m .47872 .58908 L .49078 .59205 L p .707 .577 .707 r
F P
0 g
s
.4917 .59672 m .48024 .58648 L p .4861 .57399 L .707 .577 .707 r
F P
0 g
s
.4861 .57399 m .50045 .54339 L .4917 .59672 L .707 .577 .707 r
F
.49261 .59753 m .4959 .584 L .49538 .60711 L F
.49454 .60495 m .49261 .59753 L p .49538 .60711 L F P
0 g
s
.49547 .60734 m .49536 .6081 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.49741 .62122 m .49469 .60534 L .49547 .60734 L .707 .577 .707 r
F
.49547 .60734 m .5013 .63442 L p .49741 .62122 L F P
0 g
s
.50321 .55396 m .49547 .60734 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .47202 .62307 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .44617 .62198 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .46989 .61317 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .47202 .62307 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.46477 .62491 m .47191 .62383 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .45288 .62794 L .44774 .62925 L .707 .577 .707 r
F
.44617 .62198 m .44774 .62925 L p .45288 .62794 L F P
0 g
s
.44774 .62925 m .45414 .65895 L .47193 .65235 L p .707 .577 .707 r
F P
0 g
s
.47193 .65235 m .47785 .65015 L p .44774 .62925 L .707 .577 .707 r
F P
0 g
s
.42215 .60483 m .41884 .62767 L .44587 .62747 L p .707 .577 .707 r
F P
0 g
s
.35644 .61813 m .36428 .56399 L .33714 .55518 L p .707 .577 .707 r
F P
0 g
s
.36428 .56399 m .35644 .61813 L .38729 .62445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64419 .66548 m .65216 .70246 L .64496 .70973 L p .707 .577 .707 r
F P
0 g
s
.63538 .7193 m .63748 .70113 L .6446 .6922 L p .707 .577 .707 r
F P
0 g
s
.6446 .6922 m .64249 .71037 L .63538 .7193 L p .707 .577 .707 r
F P
0 g
s
.66772 .54423 m .65987 .59837 L .64355 .60504 L p .707 .577 .707 r
F P
0 g
s
.8311 .56919 m .82325 .62333 L .80248 .61289 L p .707 .577 .707 r
F P
0 g
s
.80248 .61289 m .81033 .55875 L .8311 .56919 L p .707 .577 .707 r
F P
0 g
s
.32929 .60932 m .33714 .55518 L .31637 .54474 L p .707 .577 .707 r
F P
0 g
s
.33714 .55518 m .32929 .60932 L .35644 .61813 L p .707 .577 .707 r
F P
0 g
s
.39411 .67421 m .38615 .63724 L .35571 .6422 L p .707 .577 .707 r
F P
0 g
s
.38615 .63724 m .39411 .67421 L .42528 .66725 L p .707 .577 .707 r
F P
0 g
s
.42528 .66725 m .41732 .63027 L .38615 .63724 L p .707 .577 .707 r
F P
0 g
s
.65987 .59837 m .66772 .54423 L .69162 .54061 L p .707 .577 .707 r
F P
0 g
s
.41732 .63027 m .42528 .66725 L .45414 .65895 L p .707 .577 .707 r
F P
0 g
s
.45414 .65895 m .44617 .62198 L .41732 .63027 L p .707 .577 .707 r
F P
0 g
s
.35571 .6422 m .36368 .67918 L .39411 .67421 L p .707 .577 .707 r
F P
0 g
s
.36368 .67918 m .35571 .6422 L .32899 .64467 L p .707 .577 .707 r
F P
0 g
s
.65216 .70246 m .64419 .66548 L .66045 .65702 L p .707 .577 .707 r
F P
0 g
s
.83732 .71649 m .83522 .73466 L .82277 .72423 L p .707 .577 .707 r
F P
0 g
s
.82277 .72423 m .82488 .70606 L .83732 .71649 L p .707 .577 .707 r
F P
0 g
s
.32899 .64467 m .33696 .68165 L .36368 .67918 L p .707 .577 .707 r
F P
0 g
s
.31637 .54474 m .30852 .59888 L .32929 .60932 L p .707 .577 .707 r
F P
0 g
s
.66045 .65702 m .66841 .694 L .65216 .70246 L p .707 .577 .707 r
F P
0 g
s
.64249 .71037 m .6446 .6922 L .66093 .68539 L p .707 .577 .707 r
F P
0 g
s
.82173 .62579 m .82969 .66277 L .8093 .66251 L p .707 .577 .707 r
F P
0 g
s
.8093 .66251 m .80134 .62553 L .82173 .62579 L p .707 .577 .707 r
F P
0 g
s
.38671 .72577 m .38881 .70759 L .35785 .70213 L p .707 .577 .707 r
F P
0 g
s
.38881 .70759 m .38671 .72577 L .41836 .7282 L p .707 .577 .707 r
F P
0 g
s
.41836 .7282 m .42047 .71003 L .38881 .70759 L p .707 .577 .707 r
F P
0 g
s
.81033 .55875 m .80248 .61289 L .77534 .60407 L p .707 .577 .707 r
F P
0 g
s
.77534 .60407 m .78319 .54993 L .81033 .55875 L p .707 .577 .707 r
F P
0 g
s
.30852 .59888 m .31637 .54474 L .304 .53369 L p .707 .577 .707 r
F P
0 g
s
.69162 .54061 m .68378 .59475 L .65987 .59837 L p .707 .577 .707 r
F P
0 g
s
.68378 .59475 m .69162 .54061 L .72078 .5404 L p .707 .577 .707 r
F P
0 g
s
.42047 .71003 m .41836 .7282 L .4476 .72737 L p .707 .577 .707 r
F P
0 g
s
.4476 .72737 m .4497 .7092 L .42047 .71003 L p .707 .577 .707 r
F P
0 g
s
.66093 .68539 m .65883 .70357 L .64249 .71037 L p .707 .577 .707 r
F P
0 g
s
.35574 .72031 m .35785 .70213 L .33059 .69418 L p .707 .577 .707 r
F P
0 g
s
.35785 .70213 m .35574 .72031 L .38671 .72577 L p .707 .577 .707 r
F P
0 g
s
.33696 .68165 m .32899 .64467 L .3086 .64441 L p .707 .577 .707 r
F P
0 g
s
.33059 .69418 m .32849 .71236 L .35574 .72031 L p .707 .577 .707 r
F P
0 g
s
.3086 .64441 m .31657 .68138 L .33696 .68165 L p .707 .577 .707 r
F P
0 g
s
.78319 .54993 m .77534 .60407 L .74448 .59775 L p .707 .577 .707 r
F P
0 g
s
.74448 .59775 m .75233 .54361 L .78319 .54993 L p .707 .577 .707 r
F P
0 g
s
.71293 .59454 m .72078 .5404 L .75233 .54361 L p .707 .577 .707 r
F P
0 g
s
.72078 .5404 m .71293 .59454 L .68378 .59475 L p .707 .577 .707 r
F P
0 g
s
.4497 .7092 m .4476 .72737 L .47156 .72336 L p .707 .577 .707 r
F P
0 g
s
.47156 .72336 m .47366 .70518 L .4497 .7092 L p .707 .577 .707 r
F P
0 g
s
.66841 .694 m .66045 .65702 L .68416 .64822 L p .707 .577 .707 r
F P
0 g
s
.304 .53369 m .29616 .58783 L .30852 .59888 L p .707 .577 .707 r
F P
0 g
s
.82488 .70606 m .82277 .72423 L .8019 .71457 L p .707 .577 .707 r
F P
0 g
s
.8019 .71457 m .804 .69639 L .82488 .70606 L p .707 .577 .707 r
F P
0 g
s
.32849 .71236 m .33059 .69418 L .30972 .68452 L p .707 .577 .707 r
F P
0 g
s
.75233 .54361 m .74448 .59775 L .71293 .59454 L p .707 .577 .707 r
F P
0 g
s
.80134 .62553 m .8093 .66251 L .78258 .66498 L p .707 .577 .707 r
F P
0 g
s
.78258 .66498 m .77462 .628 L .80134 .62553 L p .707 .577 .707 r
F P
0 g
s
.68416 .64822 m .69212 .6852 L .66841 .694 L p .707 .577 .707 r
F P
0 g
s
.65883 .70357 m .66093 .68539 L .68489 .68138 L p .707 .577 .707 r
F P
0 g
s
.30972 .68452 m .30762 .70269 L .32849 .71236 L p .707 .577 .707 r
F P
0 g
s
.29616 .58783 m .304 .53369 L .30125 .52311 L p .707 .577 .707 r
F P
0 g
s
.68489 .68138 m .68279 .69955 L .65883 .70357 L p .707 .577 .707 r
F P
0 g
s
.31657 .68138 m .3086 .64441 L .29654 .64143 L p .707 .577 .707 r
F P
0 g
s
.69212 .6852 m .68416 .64822 L .71301 .63993 L p .707 .577 .707 r
F P
0 g
s
.47366 .70518 m .47156 .72336 L .4879 .71655 L p .707 .577 .707 r
F P
0 g
s
.4879 .71655 m .49 .69838 L .47366 .70518 L p .707 .577 .707 r
F P
0 g
s
.29654 .64143 m .30451 .67841 L .31657 .68138 L p .707 .577 .707 r
F P
0 g
s
.77462 .628 m .78258 .66498 L .75215 .66994 L p .707 .577 .707 r
F P
0 g
s
.75215 .66994 m .74418 .63296 L .77462 .628 L p .707 .577 .707 r
F P
0 g
s
.804 .69639 m .8019 .71457 L .77465 .70662 L p .707 .577 .707 r
F P
0 g
s
.77465 .70662 m .77675 .68844 L .804 .69639 L p .707 .577 .707 r
F P
0 g
s
.30762 .70269 m .30972 .68452 L .29727 .67409 L p .707 .577 .707 r
F P
0 g
s
.71301 .63993 m .72098 .67691 L .69212 .6852 L p .707 .577 .707 r
F P
0 g
s
.68279 .69955 m .68489 .68138 L .71413 .68055 L p .707 .577 .707 r
F P
0 g
s
.30125 .52311 m .29341 .57725 L .29616 .58783 L p .707 .577 .707 r
F P
0 g
s
.72098 .67691 m .71301 .63993 L .74418 .63296 L p .707 .577 .707 r
F P
0 g
s
.29727 .67409 m .29517 .69226 L .30762 .70269 L p .707 .577 .707 r
F P
0 g
s
.74418 .63296 m .75215 .66994 L .72098 .67691 L p .707 .577 .707 r
F P
0 g
s
.71413 .68055 m .71203 .69872 L .68279 .69955 L p .707 .577 .707 r
F P
0 g
s
.49261 .59753 m .50045 .54339 L .50321 .55396 L p .707 .577 .707 r
F P
0 g
s
.77675 .68844 m .77465 .70662 L .74368 .70116 L p .707 .577 .707 r
F P
0 g
s
.74368 .70116 m .74578 .68298 L .77675 .68844 L p .707 .577 .707 r
F P
0 g
s
.29341 .57725 m .30125 .52311 L .30839 .51405 L p .707 .577 .707 r
F P
0 g
s
.71203 .69872 m .71413 .68055 L .74578 .68298 L p .707 .577 .707 r
F P
0 g
s
.30451 .67841 m .29654 .64143 L .29398 .63605 L p .707 .577 .707 r
F P
0 g
s
.74578 .68298 m .74368 .70116 L .71203 .69872 L p .707 .577 .707 r
F P
0 g
s
.49 .69838 m .4879 .71655 L .49501 .70762 L p .707 .577 .707 r
F P
0 g
s
.49501 .70762 m .49711 .68945 L .49 .69838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29398 .63605 m .30195 .67302 L .30451 .67841 L p .707 .577 .707 r
F P
0 g
s
.29517 .69226 m .29727 .67409 L .29447 .66391 L p .707 .577 .707 r
F P
0 g
s
.29447 .66391 m .29237 .68208 L .29517 .69226 L p .707 .577 .707 r
F P
0 g
s
.30839 .51405 m .30054 .56819 L .29341 .57725 L p .707 .577 .707 r
F P
0 g
s
.48024 .58648 m .48809 .53234 L .50045 .54339 L p .707 .577 .707 r
F P
0 g
s
.30054 .56819 m .30839 .51405 L .32471 .50738 L p .707 .577 .707 r
F P
0 g
s
.30195 .67302 m .29398 .63605 L .30118 .62877 L p .707 .577 .707 r
F P
0 g
s
.49711 .68945 m .49501 .70762 L .49221 .69745 L p .707 .577 .707 r
F P
0 g
s
.49221 .69745 m .49431 .67927 L .49711 .68945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30118 .62877 m .30915 .66575 L .30195 .67302 L p .707 .577 .707 r
F P
0 g
s
.29237 .68208 m .29447 .66391 L .30159 .65498 L p .707 .577 .707 r
F P
0 g
s
.30159 .65498 m .29948 .67315 L .29237 .68208 L p .707 .577 .707 r
F P
0 g
s
.32471 .50738 m .31686 .56152 L .30054 .56819 L p .707 .577 .707 r
F P
0 g
s
.48809 .53234 m .48024 .58648 L .45947 .57604 L p .707 .577 .707 r
F P
0 g
s
.45947 .57604 m .46732 .5219 L .48809 .53234 L p .707 .577 .707 r
F P
0 g
s
.31686 .56152 m .32471 .50738 L .34861 .50376 L p .707 .577 .707 r
F P
0 g
s
.30915 .66575 m .30118 .62877 L .31744 .62031 L p .707 .577 .707 r
F P
0 g
s
.49431 .67927 m .49221 .69745 L .47976 .68701 L p .707 .577 .707 r
F P
0 g
s
.47976 .68701 m .48186 .66884 L .49431 .67927 L p .707 .577 .707 r
F P
0 g
s
.31744 .62031 m .3254 .65729 L .30915 .66575 L p .707 .577 .707 r
F P
0 g
s
.29948 .67315 m .30159 .65498 L .31792 .64818 L p .707 .577 .707 r
F P
0 g
s
.47872 .58908 m .48668 .62606 L .46629 .6258 L p .707 .577 .707 r
F P
0 g
s
.46629 .6258 m .45833 .58882 L .47872 .58908 L p .707 .577 .707 r
F P
0 g
s
.46732 .5219 m .45947 .57604 L .43233 .56722 L p .707 .577 .707 r
F P
0 g
s
.43233 .56722 m .44018 .51308 L .46732 .5219 L p .707 .577 .707 r
F P
0 g
s
.34861 .50376 m .34077 .5579 L .31686 .56152 L p .707 .577 .707 r
F P
0 g
s
.34077 .5579 m .34861 .50376 L .37777 .50355 L p .707 .577 .707 r
F P
0 g
s
.31792 .64818 m .31582 .66635 L .29948 .67315 L p .707 .577 .707 r
F P
0 g
s
.44018 .51308 m .43233 .56722 L .40147 .5609 L p .707 .577 .707 r
F P
0 g
s
.40147 .5609 m .40932 .50676 L .44018 .51308 L p .707 .577 .707 r
F P
0 g
s
.36992 .55769 m .37777 .50355 L .40932 .50676 L p .707 .577 .707 r
F P
0 g
s
.37777 .50355 m .36992 .55769 L .34077 .5579 L p .707 .577 .707 r
F P
0 g
s
.3254 .65729 m .31744 .62031 L .34115 .61151 L p .707 .577 .707 r
F P
0 g
s
.48186 .66884 m .47976 .68701 L .45889 .67735 L p .707 .577 .707 r
F P
0 g
s
.45889 .67735 m .46099 .65918 L .48186 .66884 L p .707 .577 .707 r
F P
0 g
s
.40932 .50676 m .40147 .5609 L .36992 .55769 L p .707 .577 .707 r
F P
0 g
s
.45833 .58882 m .46629 .6258 L .43957 .62827 L p .707 .577 .707 r
F P
0 g
s
.43957 .62827 m .43161 .59129 L .45833 .58882 L p .707 .577 .707 r
F P
0 g
s
.34115 .61151 m .34911 .64849 L .3254 .65729 L p .707 .577 .707 r
F P
0 g
s
.31582 .66635 m .31792 .64818 L .34188 .64416 L p .707 .577 .707 r
F P
0 g
s
.34188 .64416 m .33978 .66234 L .31582 .66635 L p .707 .577 .707 r
F P
0 g
s
.34911 .64849 m .34115 .61151 L .37 .60322 L p .707 .577 .707 r
F P
0 g
s
.43161 .59129 m .43957 .62827 L .40914 .63323 L p .707 .577 .707 r
F P
0 g
s
.40914 .63323 m .40117 .59625 L .43161 .59129 L p .707 .577 .707 r
F P
0 g
s
.46099 .65918 m .45889 .67735 L .43164 .6694 L p .707 .577 .707 r
F P
0 g
s
.43164 .6694 m .43374 .65122 L .46099 .65918 L p .707 .577 .707 r
F P
0 g
s
.37 .60322 m .37797 .64019 L .34911 .64849 L p .707 .577 .707 r
F P
0 g
s
.33978 .66234 m .34188 .64416 L .37112 .64333 L p .707 .577 .707 r
F P
0 g
s
.37797 .64019 m .37 .60322 L .40117 .59625 L p .707 .577 .707 r
F P
0 g
s
.40117 .59625 m .40914 .63323 L .37797 .64019 L p .707 .577 .707 r
F P
0 g
s
.37112 .64333 m .36902 .6615 L .33978 .66234 L p .707 .577 .707 r
F P
0 g
s
.43374 .65122 m .43164 .6694 L .40067 .66394 L p .707 .577 .707 r
F P
0 g
s
.40067 .66394 m .40277 .64576 L .43374 .65122 L p .707 .577 .707 r
F P
0 g
s
.36902 .6615 m .37112 .64333 L .40277 .64576 L p .707 .577 .707 r
F P
0 g
s
.40277 .64576 m .40067 .66394 L .36902 .6615 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001POol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005]oo`D000=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00FGoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Ioo`00Egoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol005Ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool@001<Ool005Aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70015Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00E7oo
00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00>Goo001DOol20004FUH01000FUIJEUYF4000
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00T005YFFUIJEP00FUH005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`00=Woo001DOol20003
FUH500000eYF001JEP02FUH30002FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH3000dOol005=oo`04001JEP00FUH20006FUH00`00FUIJEP04FUH40004FUH50000
0eYF000000020002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
<Woo001COol01P00FUH00000FUH000EJEP03001JEUYF00IJEP03001JEUYF00T000EJEP@000IJEP03
001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000`Ool005=oo`<0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF0P00;goo001COol20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30003FUH>0005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo001DOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF2`000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP03
FUH01000FUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000iOol@000=Ool20005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00
FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20003FUH50002FUH00`00FUIJEP03FUH40004Ool90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00<Woo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF00<005YFFUH01UYF1P001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00EJ
EP03001JEP0000<00003Ool0000000<000=oo`H000IJEP03001JEUYF00=JEP07001JEUYFFUH005YF
0000;7oo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40002Ool200000eYF001JEP04FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00=JEPL000Qoo`8000AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002moo`8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000H00004FUH0
00000006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`000UYF3@0000=JEP00FUH015YF00@0
05YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF1@002EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8002eoo`00;Woo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF0P00;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP04001JEUYF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0P001EYF2P000eYF00<005YF0000;Goo000]
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005
FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1`000eYF00<005YFFUH0
0eYF0P000UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00Ool0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00FUH0
15YF00<005YFFUH01EYF00<005YFFUH01EYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH01UYF0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF00<0
05YF00001@0015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUIJEPP000UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003Ool200000eYF001JEP06FUH200000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJ
EP03001JEUYF00P000=JEP03001JEUYF009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF00000003Ool30003FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002eoo`8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
0007FUH00`00FUIJEP04FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH30003Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool20003FUH500000eYF001JEP040009
Ool60006FUH200001UYF00000000FUH000IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000=JEP8000=JEP8000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002aoo`04001JEP00FUH20006FUH00`00
FUIJEP03FUH50004Ool500000goo000000020002FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000400000eYF0000000<FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo000/Ool01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00T000Eoo`D000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEUYFFUH0000]Ool002aoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00AJEPL000Eoo`03001JEP0000=JEP04001JEUYFFUHG0006FUH00`00FUIJEP06FUH3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0002FUH00`00
Oomoo`0[Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP<000=J
EPH00003FUH005YF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP<002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P0000=JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP0000000P001UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1`001eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEPH00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF
00QJEP03001JEUYF00AJEP<000EJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPD000UJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@00003FUH00000018000EJ
EP<000MJEP03001JEUYF00MJEP8000=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP00009JEQ4000UJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Woo00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUH000EJEP04001J
EP00FUH200000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH300000eYF001JEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0002FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05
FUH01000FUH00000<7oo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH00`00
FUIJEP02FUH40005FUH00`00FUIJEP0300000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH00`00
FUIJEP020003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH01000FUIJEUYF1@00<Woo000`Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF
001JEP04FUH50006FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP04001JEP00000g
Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF00IJEP04001JEUYF
0005FUH20003FUH00`00FUIJEP0200000eYF001JEP05FUH30007FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1000>Goo000cOol200000eYF001JEP06FUH300000eYF001JEP08FUH00`00FUIJ
EP05FUH40005FUH00`00FUH000030002FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH3000gOol003Eoo`<000=JEP<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYF0005FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEUYF
0P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000AJEP03001JEP0000<000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00>7oo0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00MJEPD000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP02FUH2000bOol0
03Eoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH005YF00IJEP03001JEUYF00AJEQL000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040006Ool20003FUH00`00FUIJEP04FUH2000aOol0039oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`000UYF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF1`0037oo0P0000=JEP00FUH01EYF00<005YF
0000<7oo000`Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH01P0000=JEP00FUH015YF00@005YFFUIJEPP000Aoo`<000ioo`<000AJ
EP05001JEUYFFUH0000_Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEQ<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020000
0eYF0000000<000015YF001JEP001goo1@0047oo0`0000=JEP00FUH00UYF00<007ooOol0;Goo000]
Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P0000=JEP00FUH015YF00<005YFFUH00P0000=JEP00Ool01Woo1@004goo0P000eYF0P00;Woo000]
Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF1`0015YF00<005YFFUH00UYF200000=JEP00FUH0
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP00008000AJEP04001JEUYFFUH20008Ool5000EOol00`00FUIJEP02000^Ool002aoo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP090009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00P002Goo0`005goo1000;Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP<00003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEP000080009J
EP8002Eoo`8002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF01L0009JEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYF0002Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH01000FUIJEUYF1@0097oo0`00;Woo000]Ool00`00FUH00002FUH50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP04FUH30003Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH6000NOol300000eYF001oo`0]
Ool002eoo`03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@000=JEP03001JEUYF009JEP<000Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP00
02ioo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YF0000100000=JEP00000027oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
0eYF300000=JEP00FUH02UYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8002moo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0`002Goo00<005YF00001UYF00<005YFFUH01UYF200035YF00<005YFFUH02EYF00<005YF
FUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF0`001UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<0
05YF00000eYF00@005YFFUIJEQL000IJEP03001JEUYF00IJEP<000Moo`03001JEP0000IJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP8000AJEPP0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000`Ool002aoo`03001JEP0000=JEP@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF008000Eo
o`03001JEP0000IJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEPH000AJEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000/Ool01000FUH005YF
0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=oo`0000000P001UYF00<0
05YFFUH00eYF00<007ooOol00Woo00<005YF00001EYF0`000eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF100015YF0P000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF00000Woo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPD003Ao
o`00;7oo00@005YF0000009JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEPD000Uo
o`@0009JEP03001JEUYF00=JEP8000=oo`03001JEP0000=JEP8000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH2
0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;Ool@000iOol002aoo`@000=JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00@0019oo`<000EJEP09001JEP00001oo`00FUH0
05YF00<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00
;7oo0P0000=JEP0000001@000UYF00<005YFFUH00UYF1P001Goo0`004Goo0P000eYF00@005YFFUIJ
EP800003FUH00000009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1DOol002aoo`03001JEUYF009JEP03001oogoo009oo`L0
00Yoo`D0019oo`800003FUH005YF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000002FUH00`00FUIJEP05FUH01000FUH00000Egoo000/Ool00`00FUIJEP02FUH3000COol5000D
Ool20003FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH0
15YF0P00FGoo000/Ool00`00FUIJEP02FUH00`00FUIJEP02000AOol5000FOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH01000Fgoo000/
Ool01@00FUIJEUYF00001EYF0P0047oo0`0067oo0P0000=JEP00000015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00D005YFFUH005YF00D005moo`00;Goo0P0000=JEP00FUH015YF00<005YF00000`00
9goo0P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001EYF0`00GWoo
000_Ool20005FUH00`00FUIJEP03FUH5000POol200001EYF000007oo000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P001eYF00<005YF00000P00Fgoo000aOol20003FUH00`00FUIJEP05FUH00`00
FUIJEP04000GOol50003FUH20002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP02FUH2001IOol003=oo`800003FUH005YF00IJEP03001JEUYF00AJEPL000Uoo`L000=J
EP07001JEUYFFUH005YF000017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEPD000EJEP03001JEUYF00AJEP8005Qo
o`00=Goo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00@005YF
FUIJEP8000Moo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP04001JEP000005Ool400000eYF001JEP05FUH01000FUH00000EWoo000h
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00
FUIJEUYF00002Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF10002goo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000lOol4
0006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000003Goo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01P0047oo
0P000eYF00<005YFFUH00UYF00<007ooOol0Dgoo0010Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1@004Woo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF1@000Woo1@004Goo0P0000=JEP00FUH00eYF00<007ooOol0Dgoo0014Ool70004FUH00`00FUIJ
EP02FUH8000KOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001goo1@00
4goo0P000eYF0P00EGoo001;Ool9000YOolO000=Ool5000EOol00`00FUIJEP02001EOol008moo`03
001JEP0000EJEP<0011oo`<001Moo`@005Eoo`00T7oo0P001UYF00<005YF00000`009goo0`00EGoo
002AOol00`00FUIJEP04FUH00`00FUIJEP03FUH7000NOol5001EOol0099oo`8000=JEP03001JEUYF
00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP0005Eoo`00U7oo0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8005Ioo`00UWoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Io
o`00VGoo10000UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00WGoo1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Uoo`00XWoo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD005]oo`00YWoo5`00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59852 .74498 m .59068 .68916 L .55982 .69174 L p .707 .577 .707 r
F P
0 g
s
.59068 .68916 m .59852 .74498 L .63007 .74015 L p .707 .577 .707 r
F P
0 g
s
.63007 .74015 m .62223 .68433 L .59068 .68916 L p .707 .577 .707 r
F P
0 g
s
.62223 .68433 m .63007 .74015 L .65923 .73356 L p .707 .577 .707 r
F P
0 g
s
.65923 .73356 m .65138 .67774 L .62223 .68433 L p .707 .577 .707 r
F P
0 g
s
.56767 .74757 m .55982 .69174 L .53268 .69184 L p .707 .577 .707 r
F P
0 g
s
.55982 .69174 m .56767 .74757 L .59852 .74498 L p .707 .577 .707 r
F P
0 g
s
.65138 .67774 m .65923 .73356 L .68314 .72585 L p .707 .577 .707 r
F P
0 g
s
.68314 .72585 m .67529 .67002 L .65138 .67774 L p .707 .577 .707 r
F P
0 g
s
.53268 .69184 m .54053 .74767 L .56767 .74757 L p .707 .577 .707 r
F P
0 g
s
.59086 .81566 m .59882 .78039 L .56839 .77179 L p .707 .577 .707 r
F P
0 g
s
.59882 .78039 m .59086 .81566 L .62203 .82093 L p .707 .577 .707 r
F P
0 g
s
.62203 .82093 m .62999 .78566 L .59882 .78039 L p .707 .577 .707 r
F P
0 g
s
.54053 .74767 m .53268 .69184 L .51191 .68944 L p .707 .577 .707 r
F P
0 g
s
.56043 .80706 m .56839 .77179 L .54167 .76069 L p .707 .577 .707 r
F P
0 g
s
.56839 .77179 m .56043 .80706 L .59086 .81566 L p .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .65811 .81958 L .63785 .82371 L p .707 .577 .707 r
F P
0 g
s
.63785 .82371 m .62888 .82554 L p .63467 .82788 L .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .63785 .82371 L .63467 .82788 L .707 .577 .707 r
F
.65811 .81958 m .66022 .8382 L .68418 .8309 L p F P
0 g
s
.68418 .8309 m .68207 .81227 L .66657 .817 L p .707 .577 .707 r
F P
0 g
s
.66657 .817 m .65811 .81958 L p .6635 .82192 L .707 .577 .707 r
F P
0 g
s
.68418 .8309 m .66657 .817 L .6635 .82192 L .707 .577 .707 r
F
.68207 .81227 m .68418 .8309 L .70051 .82296 L p F P
0 g
s
.70051 .82296 m .69841 .80434 L .68893 .80894 L p .707 .577 .707 r
F P
0 g
s
.68893 .80894 m .68207 .81227 L p .68672 .81497 L .707 .577 .707 r
F P
0 g
s
.70051 .82296 m .68893 .80894 L .68672 .81497 L .707 .577 .707 r
F
.69085 .81348 m .69805 .80405 L p .69869 .78235 L F P
0 g
s
.69881 .77821 m .69658 .78811 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.69658 .78811 m .69085 .81348 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .69085 .81348 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68256 .78452 m .68015 .79521 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68015 .79521 m .6746 .81978 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .6746 .81978 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65885 .78709 m .65591 .80008 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65591 .80008 m .65088 .82235 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.62999 .78566 m .62203 .82093 L .65088 .82235 L p .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .65885 .78709 L .62999 .78566 L p .707 .577 .707 r
F P
0 g
s
.67529 .67002 m .68314 .72585 L .69946 .71777 L p .707 .577 .707 r
F P
0 g
s
.69946 .71777 m .69161 .66194 L .67529 .67002 L p .707 .577 .707 r
F P
0 g
s
.59933 .84819 m .59723 .82957 L .56626 .83127 L p .707 .577 .707 r
F P
0 g
s
.59723 .82957 m .59933 .84819 L .63098 .84416 L p .707 .577 .707 r
F P
0 g
s
.63098 .84416 m .62888 .82554 L .59723 .82957 L p .707 .577 .707 r
F P
0 g
s
.51191 .68944 m .51976 .74526 L .54053 .74767 L p .707 .577 .707 r
F P
0 g
s
.62888 .82554 m .63098 .84416 L .66022 .8382 L p .707 .577 .707 r
F P
0 g
s
.54167 .76069 m .53371 .79596 L .56043 .80706 L p .707 .577 .707 r
F P
0 g
s
.53371 .79596 m .54167 .76069 L .52128 .74819 L p .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .68256 .78452 L .65885 .78709 L p .707 .577 .707 r
F P
0 g
s
.56626 .83127 m .56836 .84989 L .59933 .84819 L p .707 .577 .707 r
F P
0 g
s
.56836 .84989 m .56626 .83127 L .539 .83048 L p .707 .577 .707 r
F P
0 g
s
.539 .83048 m .54111 .8491 L .56836 .84989 L p .707 .577 .707 r
F P
0 g
s
.51976 .74526 m .51191 .68944 L .49954 .68477 L p .707 .577 .707 r
F P
0 g
s
.52128 .74819 m .51332 .78346 L .53371 .79596 L p .707 .577 .707 r
F P
0 g
s
.69161 .66194 m .69946 .71777 L .70659 .71011 L p .707 .577 .707 r
F P
0 g
s
.70659 .71011 m .69874 .65429 L .69161 .66194 L p .707 .577 .707 r
F P
0 g
s
.54111 .8491 m .539 .83048 L .51813 .82727 L p .707 .577 .707 r
F P
0 g
s
.49954 .68477 m .50739 .74059 L .50829 .74093 L p .707 .577 .707 r
F P
0 g
s
.5139 .72772 m .49954 .68477 L .50829 .74093 L .707 .577 .707 r
F
.50739 .74059 m .49954 .68477 L .49679 .67829 L p F P
0 g
s
.50739 .74059 m .5041 .72125 L .50453 .73332 L .707 .577 .707 r
F
.50335 .75258 m .50724 .74125 L .50531 .7356 L F
.50546 .73605 m .50739 .74059 L p .50453 .73332 L F P
0 g
s
.4987 .75915 m .50125 .77078 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50666 .72389 m .50453 .73332 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .4987 .75915 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50453 .73332 L p .5041 .72125 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50393 .67063 L p .50462 .73214 L .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50666 .72389 L p .50531 .7356 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .50666 .72389 L p .50581 .73175 L .707 .577 .707 r
F P
0 g
s
.50463 .73363 m .50464 .73411 L .50546 .73605 L p .707 .577 .707 r
F P
0 g
s
.50464 .73411 m .50453 .73332 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50724 .74125 m .50922 .73551 L .50531 .7356 L .707 .577 .707 r
F
.51177 .72646 m .50464 .73411 L p .50463 .7332 L F P
0 g
s
.50666 .72389 m .51386 .71446 L p .50954 .7272 L .707 .577 .707 r
F P
0 g
s
.50581 .73175 m .50666 .72389 L .50954 .7272 L .707 .577 .707 r
F
.51153 .72476 m .51177 .72646 L p .50463 .7332 L F P
0 g
s
.50125 .77078 m .50765 .74244 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.50765 .74244 m .50922 .73551 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .4987 .75915 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .51153 .72476 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .5059 .74973 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .53011 .70815 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51177 .72646 m .51153 .72476 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.50829 .74093 m .51976 .74526 L p .5139 .72772 L .707 .577 .707 r
F P
0 g
s
.51332 .78346 m .52128 .74819 L .50922 .73551 L p .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50125 .77078 L .51332 .78346 L p .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .51386 .71446 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .51177 .72646 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .52798 .71759 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .52798 .71759 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52809 .71838 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .5059 .74973 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52215 .74342 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .51153 .72476 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51203 .72455 m .51153 .72476 L .51225 .72285 L .707 .577 .707 r
F
.50393 .67063 m .52024 .66256 L p .51225 .72285 L F P
0 g
s
.51153 .72476 m .50393 .67063 L p .51225 .72285 L .707 .577 .707 r
F P
0 g
s
.50393 .67063 m .51153 .72476 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50481 .74114 m .50581 .73175 L .50954 .7272 L .707 .577 .707 r
F
.50453 .73332 m .50581 .73175 L .50481 .74114 L F
.50463 .7332 m .50453 .73332 L .50462 .73214 L F
.50453 .73332 m .49679 .67829 L p .50462 .73214 L F P
0 g
s
.4987 .75915 m .50453 .73332 L p .50481 .74114 L .707 .577 .707 r
F P
0 g
s
.69085 .81348 m .69881 .77821 L .68256 .78452 L p .707 .577 .707 r
F P
0 g
s
.51813 .82727 m .52023 .8459 L .54111 .8491 L p .707 .577 .707 r
F P
0 g
s
.52023 .8459 m .51813 .82727 L .50569 .82197 L p .707 .577 .707 r
F P
0 g
s
.69805 .80405 m .70601 .76879 L .69881 .77821 L p .707 .577 .707 r
F P
0 g
s
.50569 .82197 m .50779 .84059 L .52023 .8459 L p .707 .577 .707 r
F P
0 g
s
.69874 .65429 m .70659 .71011 L .70384 .70364 L p .707 .577 .707 r
F P
0 g
s
.70384 .70364 m .69599 .64781 L .69874 .65429 L p .707 .577 .707 r
F P
0 g
s
.69841 .80434 m .70051 .82296 L .70763 .81517 L p .707 .577 .707 r
F P
0 g
s
.70763 .81517 m .70553 .79654 L .69841 .80434 L p .707 .577 .707 r
F P
0 g
s
.48766 .8219 m .49179 .32047 L .44778 .31742 L p .707 .577 .707 r
F P
0 g
s
.50779 .84059 m .50569 .82197 L .50288 .81508 L p .707 .577 .707 r
F P
0 g
s
.50288 .81508 m .50499 .83371 L .50779 .84059 L p .707 .577 .707 r
F P
0 g
s
.50499 .83371 m .50288 .81508 L .51 .80729 L p .707 .577 .707 r
F P
0 g
s
.51 .80729 m .5121 .82591 L .50499 .83371 L p .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .55383 .70559 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .52798 .71759 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .53011 .70815 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.55383 .70559 m .55226 .71252 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.54415 .65484 m .552 .71067 L .53522 .71608 L p .707 .577 .707 r
F P
0 g
s
.53522 .71608 m .52809 .71838 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52831 .71752 m .54415 .65484 L .53522 .71608 L .707 .577 .707 r
F
.54586 .74085 m .52215 .74342 L p .54712 .71359 L F P
0 g
s
.55226 .71252 m .54586 .74085 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .52798 .71759 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .54415 .65484 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52024 .66256 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.5121 .82591 m .51 .80729 L .52634 .79935 L p .707 .577 .707 r
F P
0 g
s
.52634 .79935 m .52844 .81798 L .5121 .82591 L p .707 .577 .707 r
F P
0 g
s
.52844 .81798 m .52634 .79935 L .55029 .79205 L p .707 .577 .707 r
F P
0 g
s
.55029 .79205 m .5524 .81067 L .52844 .81798 L p .707 .577 .707 r
F P
0 g
s
.49179 .32047 m .48766 .8219 L .5326 .82113 L p .707 .577 .707 r
F P
0 g
s
.5326 .82113 m .53673 .3197 L .49179 .32047 L p .707 .577 .707 r
F P
0 g
s
.552 .71067 m .54415 .65484 L .57331 .64825 L p .707 .577 .707 r
F P
0 g
s
.54586 .74085 m .55383 .70559 L .58268 .70701 L p .707 .577 .707 r
F P
0 g
s
.57331 .64825 m .58115 .70407 L .552 .71067 L p .707 .577 .707 r
F P
0 g
s
.58268 .70701 m .57471 .74227 L .54586 .74085 L p .707 .577 .707 r
F P
0 g
s
.5524 .81067 m .55029 .79205 L .57953 .78609 L p .707 .577 .707 r
F P
0 g
s
.57953 .78609 m .58163 .80471 L .5524 .81067 L p .707 .577 .707 r
F P
0 g
s
.53673 .3197 m .5326 .82113 L .57408 .81662 L p .707 .577 .707 r
F P
0 g
s
.58115 .70407 m .57331 .64825 L .60486 .64342 L p .707 .577 .707 r
F P
0 g
s
.57408 .81662 m .57821 .3152 L .53673 .3197 L p .707 .577 .707 r
F P
0 g
s
.44365 .81885 m .44778 .31742 L .40902 .31085 L p .707 .577 .707 r
F P
0 g
s
.44778 .31742 m .44365 .81885 L .48766 .8219 L p .707 .577 .707 r
F P
0 g
s
.70601 .76879 m .69805 .80405 L .69549 .79243 L p .707 .577 .707 r
F P
0 g
s
.69549 .79243 m .70052 .77015 L p .70601 .76879 L .707 .577 .707 r
F P
0 g
s
.70346 .75716 m .69549 .79243 L .68343 .77974 L p .707 .577 .707 r
F P
0 g
s
.69238 .80298 m .69125 .79299 L p .70272 .78966 L .707 .577 .707 r
F P
0 g
s
.69125 .79299 m .69028 .78435 L .6941 .78598 L p .707 .577 .707 r
F P
0 g
s
.6941 .78598 m .70272 .78966 L p .69125 .79299 L .707 .577 .707 r
F P
0 g
s
.70052 .77015 m .70346 .75716 L .70428 .7609 L p .707 .577 .707 r
F P
0 g
s
.70428 .7609 m .70601 .76879 L p .70052 .77015 L .707 .577 .707 r
F P
0 g
s
.69599 .64781 m .70384 .70364 L .69147 .69897 L p .707 .577 .707 r
F P
0 g
s
.69147 .69897 m .68363 .64314 L .69599 .64781 L p .707 .577 .707 r
F P
0 g
s
.60486 .64342 m .61271 .69925 L .58115 .70407 L p .707 .577 .707 r
F P
0 g
s
.57471 .74227 m .58268 .70701 L .61385 .71228 L p .707 .577 .707 r
F P
0 g
s
.61385 .71228 m .60588 .74754 L .57471 .74227 L p .707 .577 .707 r
F P
0 g
s
.58163 .80471 m .57953 .78609 L .61118 .78206 L p .707 .577 .707 r
F P
0 g
s
.61118 .78206 m .61329 .80068 L .58163 .80471 L p .707 .577 .707 r
F P
0 g
s
.57821 .3152 m .57408 .81662 L .60804 .80882 L p .707 .577 .707 r
F P
0 g
s
.61271 .69925 m .60486 .64342 L .63571 .64083 L p .707 .577 .707 r
F P
0 g
s
.64428 .72088 m .63632 .75615 L .60588 .74754 L p .707 .577 .707 r
F P
0 g
s
.60588 .74754 m .61385 .71228 L .64428 .72088 L p .707 .577 .707 r
F P
0 g
s
.60804 .80882 m .61217 .30739 L .57821 .3152 L p .707 .577 .707 r
F P
0 g
s
.70553 .79654 m .70763 .81517 L .70483 .80828 L p .707 .577 .707 r
F P
0 g
s
.70483 .80828 m .70272 .78966 L .70553 .79654 L p .707 .577 .707 r
F P
0 g
s
.40489 .81228 m .40902 .31085 L .3793 .30141 L p .707 .577 .707 r
F P
0 g
s
.40902 .31085 m .40489 .81228 L .44365 .81885 L p .707 .577 .707 r
F P
0 g
s
.25552 .7082 m .24767 .65238 L .21681 .65496 L p .707 .577 .707 r
F P
0 g
s
.24767 .65238 m .25552 .7082 L .28707 .70337 L p .707 .577 .707 r
F P
0 g
s
.28707 .70337 m .27922 .64755 L .24767 .65238 L p .707 .577 .707 r
F P
0 g
s
.27922 .64755 m .28707 .70337 L .31622 .69678 L p .707 .577 .707 r
F P
0 g
s
.31622 .69678 m .30837 .64096 L .27922 .64755 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22466 .71079 m .21681 .65496 L .18967 .65506 L p .707 .577 .707 r
F P
0 g
s
.21681 .65496 m .22466 .71079 L .25552 .7082 L p .707 .577 .707 r
F P
0 g
s
.30837 .64096 m .31622 .69678 L .34013 .68907 L p .707 .577 .707 r
F P
0 g
s
.34013 .68907 m .33228 .63324 L .30837 .64096 L p .707 .577 .707 r
F P
0 g
s
.68343 .77974 m .69139 .74448 L .70346 .75716 L p .707 .577 .707 r
F P
0 g
s
.68363 .64314 m .69147 .69897 L .6707 .69656 L p .707 .577 .707 r
F P
0 g
s
.6707 .69656 m .66286 .64074 L .68363 .64314 L p .707 .577 .707 r
F P
0 g
s
.63571 .64083 m .64356 .69666 L .61271 .69925 L p .707 .577 .707 r
F P
0 g
s
.64215 .78036 m .64425 .79898 L .61329 .80068 L p .707 .577 .707 r
F P
0 g
s
.61329 .80068 m .61118 .78206 L .64215 .78036 L p .707 .577 .707 r
F P
0 g
s
.61217 .30739 m .60804 .80882 L .63115 .79847 L p .707 .577 .707 r
F P
0 g
s
.63115 .79847 m .63528 .29705 L .61217 .30739 L p .707 .577 .707 r
F P
0 g
s
.18967 .65506 m .19752 .71089 L .22466 .71079 L p .707 .577 .707 r
F P
0 g
s
.24785 .77874 m .25582 .74347 L .22538 .73487 L p .707 .577 .707 r
F P
0 g
s
.25582 .74347 m .24785 .77874 L .27902 .78401 L p .707 .577 .707 r
F P
0 g
s
.27902 .78401 m .28699 .74875 L .25582 .74347 L p .707 .577 .707 r
F P
0 g
s
.19752 .71089 m .18967 .65506 L .1689 .65266 L p .707 .577 .707 r
F P
0 g
s
.70272 .78966 m .70483 .80828 L .69238 .80298 L p .707 .577 .707 r
F P
0 g
s
.21742 .77014 m .22538 .73487 L .19866 .72377 L p .707 .577 .707 r
F P
0 g
s
.22538 .73487 m .21742 .77014 L .24785 .77874 L p .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .31511 .78317 L .29449 .78737 L p .707 .577 .707 r
F P
0 g
s
.29449 .78737 m .28587 .78913 L p .29143 .79137 L .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .29449 .78737 L .29143 .79137 L .707 .577 .707 r
F
.31511 .78317 m .31721 .80179 L .34117 .79449 L p F P
0 g
s
.34117 .79449 m .33907 .77586 L .32325 .78068 L p .707 .577 .707 r
F P
0 g
s
.32325 .78068 m .31511 .78317 L p .3203 .78542 L .707 .577 .707 r
F P
0 g
s
.34117 .79449 m .32325 .78068 L .3203 .78542 L .707 .577 .707 r
F
.33907 .77586 m .34117 .79449 L .3575 .78655 L p F P
0 g
s
.3575 .78655 m .3554 .76792 L .34572 .77263 L p .707 .577 .707 r
F P
0 g
s
.34572 .77263 m .33907 .77586 L p .34358 .77848 L .707 .577 .707 r
F P
0 g
s
.3575 .78655 m .34572 .77263 L .34358 .77848 L .707 .577 .707 r
F
.34784 .77656 m .35504 .76713 L p .35568 .7455 L F P
0 g
s
.3558 .74129 m .35353 .75135 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.35353 .75135 m .34784 .77656 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .34784 .77656 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.33955 .7476 m .3371 .75845 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.3371 .75845 m .33159 .78286 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .33159 .78286 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31584 .75017 m .31287 .76333 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31287 .76333 m .30787 .78543 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.28699 .74875 m .27902 .78401 L .30787 .78543 L p .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .31584 .75017 L .28699 .74875 L p .707 .577 .707 r
F P
0 g
s
.37516 .80284 m .3793 .30141 L .36152 .29002 L p .707 .577 .707 r
F P
0 g
s
.3793 .30141 m .37516 .80284 L .40489 .81228 L p .707 .577 .707 r
F P
0 g
s
.33228 .63324 m .34013 .68907 L .35645 .68099 L p .707 .577 .707 r
F P
0 g
s
.35645 .68099 m .3486 .62516 L .33228 .63324 L p .707 .577 .707 r
F P
0 g
s
.25632 .81178 m .25422 .79315 L .22325 .79486 L p .707 .577 .707 r
F P
0 g
s
.25422 .79315 m .25632 .81178 L .28797 .80775 L p .707 .577 .707 r
F P
0 g
s
.28797 .80775 m .28587 .78913 L .25422 .79315 L p .707 .577 .707 r
F P
0 g
s
.1689 .65266 m .17675 .70848 L .19752 .71089 L p .707 .577 .707 r
F P
0 g
s
.28587 .78913 m .28797 .80775 L .31721 .80179 L p .707 .577 .707 r
F P
0 g
s
.19866 .72377 m .1907 .75904 L .21742 .77014 L p .707 .577 .707 r
F P
0 g
s
.1907 .75904 m .19866 .72377 L .17827 .71127 L p .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .33955 .7476 L .31584 .75017 L p .707 .577 .707 r
F P
0 g
s
.22325 .79486 m .22535 .81348 L .25632 .81178 L p .707 .577 .707 r
F P
0 g
s
.66286 .64074 m .6707 .69656 L .64356 .69666 L p .707 .577 .707 r
F P
0 g
s
.64356 .69666 m .63571 .64083 L .66286 .64074 L p .707 .577 .707 r
F P
0 g
s
.69139 .74448 m .68343 .77974 L .66304 .76724 L p .707 .577 .707 r
F P
0 g
s
.66304 .76724 m .671 .73198 L .69139 .74448 L p .707 .577 .707 r
F P
0 g
s
.22535 .81348 m .22325 .79486 L .196 .79407 L p .707 .577 .707 r
F P
0 g
s
.196 .79407 m .1981 .81269 L .22535 .81348 L p .707 .577 .707 r
F P
0 g
s
.17675 .70848 m .1689 .65266 L .15653 .64799 L p .707 .577 .707 r
F P
0 g
s
.17827 .71127 m .17031 .74654 L .1907 .75904 L p .707 .577 .707 r
F P
0 g
s
.69028 .78435 m .69238 .80298 L .67151 .79977 L p .707 .577 .707 r
F P
0 g
s
.67151 .79977 m .66941 .78115 L .69028 .78435 L p .707 .577 .707 r
F P
0 g
s
.671 .73198 m .66304 .76724 L .63632 .75615 L p .707 .577 .707 r
F P
0 g
s
.63632 .75615 m .64428 .72088 L .671 .73198 L p .707 .577 .707 r
F P
0 g
s
.63528 .29705 m .63115 .79847 L .64115 .78661 L p .707 .577 .707 r
F P
0 g
s
.64115 .78661 m .64528 .28518 L .63528 .29705 L p .707 .577 .707 r
F P
0 g
s
.3486 .62516 m .35645 .68099 L .36358 .67334 L p .707 .577 .707 r
F P
0 g
s
.36358 .67334 m .35573 .61751 L .3486 .62516 L p .707 .577 .707 r
F P
0 g
s
.1981 .81269 m .196 .79407 L .17512 .79086 L p .707 .577 .707 r
F P
0 g
s
.15653 .64799 m .16438 .70381 L .16524 .70414 L p .707 .577 .707 r
F P
0 g
s
.17087 .69088 m .15653 .64799 L .16524 .70414 L .707 .577 .707 r
F
.16438 .70381 m .15653 .64799 L .15378 .64151 L p F P
0 g
s
.16438 .70381 m .16108 .6844 L .16151 .69646 L .707 .577 .707 r
F
.16034 .7157 m .16422 .70438 L .16229 .69875 L F
.16254 .69948 m .16438 .70381 L p .16151 .69646 L F P
0 g
s
.15569 .72223 m .15824 .73386 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16365 .68697 m .16151 .69646 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .15569 .72223 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16151 .69646 L p .16108 .6844 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16092 .63386 L p .16161 .69515 L .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .16365 .68697 L p .16229 .69875 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .16365 .68697 L p .1628 .69488 L .707 .577 .707 r
F P
0 g
s
.16162 .6968 m .16163 .69733 L .16254 .69948 L p .707 .577 .707 r
F P
0 g
s
.16163 .69733 m .16151 .69646 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16422 .70438 m .16621 .69859 L .16229 .69875 L .707 .577 .707 r
F
.16876 .68968 m .16163 .69733 L p .16162 .69632 L F P
0 g
s
.16365 .68697 m .17085 .67754 L p .1665 .69035 L .707 .577 .707 r
F P
0 g
s
.1628 .69488 m .16365 .68697 L .1665 .69035 L .707 .577 .707 r
F
.16851 .68789 m .16876 .68968 L p .16162 .69632 L F P
0 g
s
.15824 .73386 m .16463 .70558 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16463 .70558 m .16621 .69859 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .15569 .72223 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .16851 .68789 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .16289 .71281 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .1871 .67123 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16876 .68968 m .16851 .68789 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.16524 .70414 m .17675 .70848 L p .17087 .69088 L .707 .577 .707 r
F P
0 g
s
.17031 .74654 m .17827 .71127 L .16621 .69859 L p .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .15824 .73386 L .17031 .74654 L p .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .17085 .67754 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .16876 .68968 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .18496 .68073 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .18496 .68073 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .18508 .6816 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .16289 .71281 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17914 .7065 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .16851 .68789 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16903 .68767 m .16851 .68789 L .16927 .68589 L .707 .577 .707 r
F
.16092 .63386 m .17723 .62578 L p .16927 .68589 L F P
0 g
s
.16851 .68789 m .16092 .63386 L p .16927 .68589 L .707 .577 .707 r
F P
0 g
s
.16092 .63386 m .16851 .68789 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16178 .70426 m .1628 .69488 L .1665 .69035 L .707 .577 .707 r
F
.16151 .69646 m .1628 .69488 L .16178 .70426 L F
.16162 .69632 m .16151 .69646 L .16161 .69515 L F
.16151 .69646 m .15378 .64151 L p .16161 .69515 L F P
0 g
s
.15569 .72223 m .16151 .69646 L p .16178 .70426 L .707 .577 .707 r
F P
0 g
s
.34784 .77656 m .3558 .74129 L .33955 .7476 L p .707 .577 .707 r
F P
0 g
s
.17512 .79086 m .17723 .80949 L .1981 .81269 L p .707 .577 .707 r
F P
0 g
s
.35504 .76713 m .363 .73187 L .3558 .74129 L p .707 .577 .707 r
F P
0 g
s
.35573 .61751 m .36358 .67334 L .36083 .66686 L p .707 .577 .707 r
F P
0 g
s
.36083 .66686 m .35298 .61103 L .35573 .61751 L p .707 .577 .707 r
F P
0 g
s
.3554 .76792 m .3575 .78655 L .36462 .77876 L p .707 .577 .707 r
F P
0 g
s
.36462 .77876 m .36462 .77875 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .77875 m .3554 .76792 L .36462 .77876 L .707 .577 .707 r
F
.36152 .29002 m .35743 .27779 L p .35741 .51257 L F P
0 g
s
.36252 .76013 m .3554 .76792 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36462 .77875 m .36461 .7787 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .7787 m .36252 .76013 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.363 .73187 m .35504 .76713 L .35248 .75551 L p .707 .577 .707 r
F P
0 g
s
.35248 .75551 m .35747 .7334 L p .363 .73187 L .707 .577 .707 r
F P
0 g
s
.35747 .7334 m .36045 .72024 L .36128 .72403 L p .707 .577 .707 r
F P
0 g
s
.36128 .72403 m .363 .73187 L p .35747 .7334 L .707 .577 .707 r
F P
0 g
s
.36045 .72024 m .35248 .75551 L .34071 .74313 L p .707 .577 .707 r
F P
0 g
s
.34071 .74313 m .34042 .74282 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34075 .74245 m .36045 .72024 L .34071 .74313 L .707 .577 .707 r
F
.35915 .57699 m .36152 .29002 L p .35741 .51257 L F P
0 g
s
.34937 .76656 m .3482 .75624 L p .35971 .75324 L .707 .577 .707 r
F P
0 g
s
.35094 .7495 m .35971 .75324 L p .3482 .75624 L .707 .577 .707 r
F P
0 g
s
.35298 .61103 m .36083 .66686 L .34846 .66219 L p .707 .577 .707 r
F P
0 g
s
.36252 .76013 m .36462 .77875 L .36182 .77187 L p .707 .577 .707 r
F P
0 g
s
.36182 .77187 m .35971 .75324 L .36252 .76013 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .36045 .72024 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34042 .74282 m .34084 .74094 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34084 .74094 m .34838 .70756 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.35971 .75324 m .36182 .77187 L .34937 .76656 L p .707 .577 .707 r
F P
0 g
s
.36152 .29002 m .35739 .79144 L .37516 .80284 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .35753 .7742 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35739 .79144 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35739 .79144 m .35915 .57699 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35753 .7742 m .3533 .77922 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .36483 .36022 L .36465 .40786 L .707 .577 .707 r
F
.36743 .26592 m .36693 .327 L p .36483 .36022 L F P
0 g
s
.36693 .327 m .3633 .76735 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .36743 .26592 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .35594 .45834 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35594 .45834 m .3533 .77922 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35554 .5078 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35554 .5078 m .35743 .27779 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.3482 .75624 m .34727 .74794 L .35094 .7495 L p .707 .577 .707 r
F P
0 g
s
.66941 .78115 m .67151 .79977 L .64425 .79898 L p .707 .577 .707 r
F P
0 g
s
.64425 .79898 m .64215 .78036 L .66941 .78115 L p .707 .577 .707 r
F P
0 g
s
.17723 .80949 m .17512 .79086 L .16268 .78556 L p .707 .577 .707 r
F P
0 g
s
.16268 .78556 m .16478 .80418 L .17723 .80949 L p .707 .577 .707 r
F P
0 g
s
.64528 .28518 m .64115 .78661 L .63706 .77438 L p .707 .577 .707 r
F P
0 g
s
.63706 .77438 m .64119 .27295 L .64528 .28518 L p .707 .577 .707 r
F P
0 g
s
.16478 .80418 m .16268 .78556 L .15987 .77867 L p .707 .577 .707 r
F P
0 g
s
.15987 .77867 m .16198 .79729 L .16478 .80418 L p .707 .577 .707 r
F P
0 g
s
.34846 .66219 m .34062 .60636 L .35298 .61103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64119 .27295 m .63706 .77438 L .61928 .76298 L p .707 .577 .707 r
F P
0 g
s
.61928 .76298 m .62341 .26156 L .64119 .27295 L p .707 .577 .707 r
F P
0 g
s
.16198 .79729 m .15987 .77867 L .16699 .77088 L p .707 .577 .707 r
F P
0 g
s
.16699 .77088 m .16909 .7895 L .16198 .79729 L p .707 .577 .707 r
F P
0 g
s
.34062 .60636 m .34846 .66219 L .32769 .65978 L p .707 .577 .707 r
F P
0 g
s
.32769 .65978 m .31985 .60396 L .34062 .60636 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .36743 .26592 L .39054 .25558 L p .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .21082 .66867 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .18496 .68073 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .1871 .67123 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.21082 .66867 m .20924 .67565 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.20114 .61806 m .20899 .67389 L .193 .67905 L p .707 .577 .707 r
F P
0 g
s
.193 .67905 m .18508 .6816 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18532 .68065 m .20114 .61806 L .193 .67905 L .707 .577 .707 r
F
.20285 .70393 m .17914 .7065 L p .20406 .67674 L F P
0 g
s
.20924 .67565 m .20285 .70393 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .18496 .68073 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .20114 .61806 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17723 .62578 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.31985 .60396 m .32769 .65978 L .30055 .65988 L p .707 .577 .707 r
F P
0 g
s
.30055 .65988 m .2927 .60405 L .31985 .60396 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .34042 .74282 L .32003 .73032 L p .707 .577 .707 r
F P
0 g
s
.32003 .73032 m .32799 .69506 L .34838 .70756 L p .707 .577 .707 r
F P
0 g
s
.16909 .7895 m .16699 .77088 L .18333 .76294 L p .707 .577 .707 r
F P
0 g
s
.18333 .76294 m .18543 .78156 L .16909 .7895 L p .707 .577 .707 r
F P
0 g
s
.62341 .26156 m .61928 .76298 L .58956 .75354 L p .707 .577 .707 r
F P
0 g
s
.58956 .75354 m .59369 .25211 L .62341 .26156 L p .707 .577 .707 r
F P
0 g
s
.20899 .67389 m .20114 .61806 L .2303 .61147 L p .707 .577 .707 r
F P
0 g
s
.34727 .74794 m .34937 .76656 L .3285 .76336 L p .707 .577 .707 r
F P
0 g
s
.3285 .76336 m .3264 .74474 L .34727 .74794 L p .707 .577 .707 r
F P
0 g
s
.2927 .60405 m .30055 .65988 L .2697 .66247 L p .707 .577 .707 r
F P
0 g
s
.2697 .66247 m .26185 .60664 L .2927 .60405 L p .707 .577 .707 r
F P
0 g
s
.39054 .25558 m .38641 .75701 L .3633 .76735 L p .707 .577 .707 r
F P
0 g
s
.38641 .75701 m .39054 .25558 L .4245 .24777 L p .707 .577 .707 r
F P
0 g
s
.20285 .70393 m .21082 .66867 L .23967 .67009 L p .707 .577 .707 r
F P
0 g
s
.32799 .69506 m .32003 .73032 L .29331 .71923 L p .707 .577 .707 r
F P
0 g
s
.29331 .71923 m .30127 .68396 L .32799 .69506 L p .707 .577 .707 r
F P
0 g
s
.23815 .6673 m .2303 .61147 L .26185 .60664 L p .707 .577 .707 r
F P
0 g
s
.2303 .61147 m .23815 .6673 L .20899 .67389 L p .707 .577 .707 r
F P
0 g
s
.73573 .65294 m .72788 .59712 L .69703 .59971 L p .707 .577 .707 r
F P
0 g
s
.72788 .59712 m .73573 .65294 L .76728 .64811 L p .707 .577 .707 r
F P
0 g
s
.76728 .64811 m .75943 .59229 L .72788 .59712 L p .707 .577 .707 r
F P
0 g
s
.26185 .60664 m .2697 .66247 L .23815 .6673 L p .707 .577 .707 r
F P
0 g
s
.75943 .59229 m .76728 .64811 L .79644 .64152 L p .707 .577 .707 r
F P
0 g
s
.79644 .64152 m .78859 .5857 L .75943 .59229 L p .707 .577 .707 r
F P
0 g
s
.18543 .78156 m .18333 .76294 L .20729 .75563 L p .707 .577 .707 r
F P
0 g
s
.20729 .75563 m .20939 .77426 L .18543 .78156 L p .707 .577 .707 r
F P
0 g
s
.70487 .65553 m .69703 .59971 L .66988 .5998 L p .707 .577 .707 r
F P
0 g
s
.69703 .59971 m .70487 .65553 L .73573 .65294 L p .707 .577 .707 r
F P
0 g
s
.23967 .67009 m .23171 .70535 L .20285 .70393 L p .707 .577 .707 r
F P
0 g
s
.23171 .70535 m .23967 .67009 L .27084 .67536 L p .707 .577 .707 r
F P
0 g
s
.30127 .68396 m .29331 .71923 L .26287 .71062 L p .707 .577 .707 r
F P
0 g
s
.26287 .71062 m .27084 .67536 L .30127 .68396 L p .707 .577 .707 r
F P
0 g
s
.3264 .74474 m .3285 .76336 L .30124 .76257 L p .707 .577 .707 r
F P
0 g
s
.30124 .76257 m .29914 .74395 L .3264 .74474 L p .707 .577 .707 r
F P
0 g
s
.78859 .5857 m .79644 .64152 L .82034 .63381 L p .707 .577 .707 r
F P
0 g
s
.82034 .63381 m .8125 .57798 L .78859 .5857 L p .707 .577 .707 r
F P
0 g
s
.59369 .25211 m .58956 .75354 L .55079 .74697 L p .707 .577 .707 r
F P
0 g
s
.55079 .74697 m .55493 .24555 L .59369 .25211 L p .707 .577 .707 r
F P
0 g
s
.27084 .67536 m .26287 .71062 L .23171 .70535 L p .707 .577 .707 r
F P
0 g
s
.66988 .5998 m .67773 .65563 L .70487 .65553 L p .707 .577 .707 r
F P
0 g
s
.72806 .72362 m .73603 .68836 L .70559 .67975 L p .707 .577 .707 r
F P
0 g
s
.73603 .68836 m .72806 .72362 L .75923 .72889 L p .707 .577 .707 r
F P
0 g
s
.75923 .72889 m .7672 .69363 L .73603 .68836 L p .707 .577 .707 r
F P
0 g
s
.20939 .77426 m .20729 .75563 L .23652 .74967 L p .707 .577 .707 r
F P
0 g
s
.67773 .65563 m .66988 .5998 L .64911 .5974 L p .707 .577 .707 r
F P
0 g
s
.42036 .7492 m .4245 .24777 L .46598 .24326 L p .707 .577 .707 r
F P
0 g
s
.4245 .24777 m .42036 .7492 L .38641 .75701 L p .707 .577 .707 r
F P
0 g
s
.69763 .71502 m .70559 .67975 L .67887 .66866 L p .707 .577 .707 r
F P
0 g
s
.70559 .67975 m .69763 .71502 L .72806 .72362 L p .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .79532 .72754 L .77506 .73167 L p .707 .577 .707 r
F P
0 g
s
.77506 .73167 m .76608 .7335 L p .77187 .73584 L .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .77506 .73167 L .77187 .73584 L .707 .577 .707 r
F
.79532 .72754 m .79742 .74617 L .82138 .73886 L p F P
0 g
s
.82138 .73886 m .81928 .72024 L .80377 .72497 L p .707 .577 .707 r
F P
0 g
s
.80377 .72497 m .79532 .72754 L p .80071 .72988 L .707 .577 .707 r
F P
0 g
s
.82138 .73886 m .80377 .72497 L .80071 .72988 L .707 .577 .707 r
F
.81928 .72024 m .82138 .73886 L .83772 .73092 L p F P
0 g
s
.83772 .73092 m .83562 .7123 L .82613 .71691 L p .707 .577 .707 r
F P
0 g
s
.82613 .71691 m .81928 .72024 L p .82392 .72293 L .707 .577 .707 r
F P
0 g
s
.83772 .73092 m .82613 .71691 L .82392 .72293 L .707 .577 .707 r
F
.82805 .72144 m .83525 .71201 L p .8359 .69031 L F P
0 g
s
.83602 .68617 m .83378 .69607 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.83378 .69607 m .82805 .72144 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .82805 .72144 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81977 .69248 m .81735 .70317 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81735 .70317 m .8118 .72775 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .8118 .72775 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79605 .69505 m .79312 .70804 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79312 .70804 m .78809 .73031 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.7672 .69363 m .75923 .72889 L .78809 .73031 L p .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .79605 .69505 L .7672 .69363 L p .707 .577 .707 r
F P
0 g
s
.23652 .74967 m .23862 .7683 L .20939 .77426 L p .707 .577 .707 r
F P
0 g
s
.29914 .74395 m .30124 .76257 L .27028 .76427 L p .707 .577 .707 r
F P
0 g
s
.27028 .76427 m .26817 .74565 L .29914 .74395 L p .707 .577 .707 r
F P
0 g
s
.8125 .57798 m .82034 .63381 L .83666 .62573 L p .707 .577 .707 r
F P
0 g
s
.83666 .62573 m .82881 .5699 L .8125 .57798 L p .707 .577 .707 r
F P
0 g
s
.23862 .7683 m .23652 .74967 L .26817 .74565 L p .707 .577 .707 r
F P
0 g
s
.73653 .75615 m .73443 .73753 L .70346 .73923 L p .707 .577 .707 r
F P
0 g
s
.73443 .73753 m .73653 .75615 L .76819 .75212 L p .707 .577 .707 r
F P
0 g
s
.76819 .75212 m .76608 .7335 L .73443 .73753 L p .707 .577 .707 r
F P
0 g
s
.26817 .74565 m .27028 .76427 L .23862 .7683 L p .707 .577 .707 r
F P
0 g
s
.64911 .5974 m .65696 .65322 L .67773 .65563 L p .707 .577 .707 r
F P
0 g
s
.55493 .24555 m .55079 .74697 L .50679 .74392 L p .707 .577 .707 r
F P
0 g
s
.50679 .74392 m .51092 .2425 L .55493 .24555 L p .707 .577 .707 r
F P
0 g
s
.76608 .7335 m .76819 .75212 L .79742 .74617 L p .707 .577 .707 r
F P
0 g
s
.67887 .66866 m .67091 .70392 L .69763 .71502 L p .707 .577 .707 r
F P
0 g
s
.67091 .70392 m .67887 .66866 L .65849 .65615 L p .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .81977 .69248 L .79605 .69505 L p .707 .577 .707 r
F P
0 g
s
.70346 .73923 m .70556 .75785 L .73653 .75615 L p .707 .577 .707 r
F P
0 g
s
.46184 .74469 m .46598 .24326 L .51092 .2425 L p .707 .577 .707 r
F P
0 g
s
.46598 .24326 m .46184 .74469 L .42036 .7492 L p .707 .577 .707 r
F P
0 g
s
.70556 .75785 m .70346 .73923 L .67621 .73844 L p .707 .577 .707 r
F P
0 g
s
.51092 .2425 m .50679 .74392 L .46184 .74469 L p .707 .577 .707 r
F P
0 g
s
.67621 .73844 m .67831 .75706 L .70556 .75785 L p .707 .577 .707 r
F P
0 g
s
.65696 .65322 m .64911 .5974 L .63675 .59273 L p .707 .577 .707 r
F P
0 g
s
.65849 .65615 m .65052 .69142 L .67091 .70392 L p .707 .577 .707 r
F P
0 g
s
.82881 .5699 m .83666 .62573 L .8438 .61808 L p .707 .577 .707 r
F P
0 g
s
.8438 .61808 m .83595 .56225 L .82881 .5699 L p .707 .577 .707 r
F P
0 g
s
.67831 .75706 m .67621 .73844 L .65534 .73524 L p .707 .577 .707 r
F P
0 g
s
.63675 .59273 m .64459 .64855 L .6455 .64889 L p .707 .577 .707 r
F P
0 g
s
.6511 .63568 m .63675 .59273 L .6455 .64889 L .707 .577 .707 r
F
.64459 .64855 m .63675 .59273 L .634 .58625 L p F P
0 g
s
.64459 .64855 m .6413 .62921 L .64173 .64129 L .707 .577 .707 r
F
.64055 .66054 m .64445 .64922 L .64251 .64357 L F
.64266 .64401 m .64459 .64855 L p .64173 .64129 L F P
0 g
s
.6359 .66711 m .63846 .67874 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64386 .63185 m .64173 .64129 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .6359 .66711 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64173 .64129 L p .6413 .62921 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64113 .5786 L p .64182 .6401 L .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .64386 .63185 L p .64251 .64357 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .64386 .63185 L p .64302 .63971 L .707 .577 .707 r
F P
0 g
s
.64184 .64159 m .64184 .64207 L .64266 .64401 L p .707 .577 .707 r
F P
0 g
s
.64184 .64207 m .64173 .64129 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64445 .64922 m .64642 .64347 L .64251 .64357 L .707 .577 .707 r
F
.64898 .63442 m .64184 .64207 L p .64183 .64116 L F P
0 g
s
.64386 .63185 m .65106 .62242 L p .64674 .63516 L .707 .577 .707 r
F P
0 g
s
.64302 .63971 m .64386 .63185 L .64674 .63516 L .707 .577 .707 r
F
.64874 .63272 m .64898 .63442 L p .64183 .64116 L F P
0 g
s
.63846 .67874 m .64486 .65041 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.64486 .65041 m .64642 .64347 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .6359 .66711 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .64874 .63272 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .6431 .65769 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .66732 .61612 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64898 .63442 m .64874 .63272 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.6455 .64889 m .65696 .65322 L p .6511 .63568 L .707 .577 .707 r
F P
0 g
s
.65052 .69142 m .65849 .65615 L .64642 .64347 L p .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .63846 .67874 L .65052 .69142 L p .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .65106 .62242 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .64898 .63442 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .66518 .62555 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .66518 .62555 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .6653 .62634 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .6431 .65769 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65935 .65138 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .64874 .63272 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64923 .63251 m .64874 .63272 L .64945 .63082 L .707 .577 .707 r
F
.64113 .5786 m .65745 .57052 L p .64945 .63082 L F P
0 g
s
.64874 .63272 m .64113 .5786 L p .64945 .63082 L .707 .577 .707 r
F P
0 g
s
.64113 .5786 m .64874 .63272 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64201 .64911 m .64302 .63971 L .64674 .63516 L .707 .577 .707 r
F
.64173 .64129 m .64302 .63971 L .64201 .64911 L F
.64183 .64116 m .64173 .64129 L .64182 .6401 L F
.64173 .64129 m .634 .58625 L p .64182 .6401 L F P
0 g
s
.6359 .66711 m .64173 .64129 L p .64201 .64911 L .707 .577 .707 r
F P
0 g
s
.82805 .72144 m .83602 .68617 L .81977 .69248 L p .707 .577 .707 r
F P
0 g
s
.65534 .73524 m .65744 .75386 L .67831 .75706 L p .707 .577 .707 r
F P
0 g
s
.65744 .75386 m .65534 .73524 L .64289 .72993 L p .707 .577 .707 r
F P
0 g
s
.83525 .71201 m .84322 .67675 L .83602 .68617 L p .707 .577 .707 r
F P
0 g
s
.64289 .72993 m .64499 .74856 L .65744 .75386 L p .707 .577 .707 r
F P
0 g
s
.83595 .56225 m .8438 .61808 L .84104 .6116 L p .707 .577 .707 r
F P
0 g
s
.84104 .6116 m .8332 .55577 L .83595 .56225 L p .707 .577 .707 r
F P
0 g
s
.83562 .7123 m .83772 .73092 L .84483 .72313 L p .707 .577 .707 r
F P
0 g
s
.84483 .72313 m .84273 .7045 L .83562 .7123 L p .707 .577 .707 r
F P
0 g
s
.64499 .74856 m .64289 .72993 L .64009 .72304 L p .707 .577 .707 r
F P
0 g
s
.64009 .72304 m .64219 .74167 L .64499 .74856 L p .707 .577 .707 r
F P
0 g
s
.84322 .67675 m .83525 .71201 L .8327 .70039 L p .707 .577 .707 r
F P
0 g
s
.8327 .70039 m .83773 .67812 L p .84322 .67675 L .707 .577 .707 r
F P
0 g
s
.84066 .66512 m .8327 .70039 L .82063 .68771 L p .707 .577 .707 r
F P
0 g
s
.82958 .71094 m .82846 .70095 L p .83993 .69762 L .707 .577 .707 r
F P
0 g
s
.82846 .70095 m .82748 .69231 L .8313 .69394 L p .707 .577 .707 r
F P
0 g
s
.8313 .69394 m .83993 .69762 L p .82846 .70095 L .707 .577 .707 r
F P
0 g
s
.83773 .67812 m .84066 .66512 L .84148 .66886 L p .707 .577 .707 r
F P
0 g
s
.84148 .66886 m .84322 .67675 L p .83773 .67812 L .707 .577 .707 r
F P
0 g
s
.8332 .55577 m .84104 .6116 L .82868 .60693 L p .707 .577 .707 r
F P
0 g
s
.82868 .60693 m .82083 .5511 L .8332 .55577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84273 .7045 m .84483 .72313 L .84203 .71624 L p .707 .577 .707 r
F P
0 g
s
.84203 .71624 m .83993 .69762 L .84273 .7045 L p .707 .577 .707 r
F P
0 g
s
.39272 .61616 m .38487 .56034 L .35402 .56293 L p .707 .577 .707 r
F P
0 g
s
.38487 .56034 m .39272 .61616 L .42427 .61134 L p .707 .577 .707 r
F P
0 g
s
.42427 .61134 m .41642 .55551 L .38487 .56034 L p .707 .577 .707 r
F P
0 g
s
.41642 .55551 m .42427 .61134 L .45343 .60474 L p .707 .577 .707 r
F P
0 g
s
.45343 .60474 m .44558 .54892 L .41642 .55551 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36186 .61875 m .35402 .56293 L .32687 .56302 L p .707 .577 .707 r
F P
0 g
s
.35402 .56293 m .36186 .61875 L .39272 .61616 L p .707 .577 .707 r
F P
0 g
s
.64219 .74167 m .64009 .72304 L .6472 .71525 L p .707 .577 .707 r
F P
0 g
s
.44558 .54892 m .45343 .60474 L .47733 .59703 L p .707 .577 .707 r
F P
0 g
s
.47733 .59703 m .46949 .5412 L .44558 .54892 L p .707 .577 .707 r
F P
0 g
s
.82063 .68771 m .8286 .65244 L .84066 .66512 L p .707 .577 .707 r
F P
0 g
s
.6472 .71525 m .64931 .73388 L .64219 .74167 L p .707 .577 .707 r
F P
0 g
s
.82083 .5511 m .82868 .60693 L .80791 .60452 L p .707 .577 .707 r
F P
0 g
s
.80791 .60452 m .80006 .5487 L .82083 .5511 L p .707 .577 .707 r
F P
0 g
s
.32687 .56302 m .33472 .61885 L .36186 .61875 L p .707 .577 .707 r
F P
0 g
s
.38505 .6867 m .39302 .65144 L .36258 .64283 L p .707 .577 .707 r
F P
0 g
s
.39302 .65144 m .38505 .6867 L .41622 .69197 L p .707 .577 .707 r
F P
0 g
s
.41622 .69197 m .42419 .65671 L .39302 .65144 L p .707 .577 .707 r
F P
0 g
s
.33472 .61885 m .32687 .56302 L .3061 .56062 L p .707 .577 .707 r
F P
0 g
s
.83993 .69762 m .84203 .71624 L .82958 .71094 L p .707 .577 .707 r
F P
0 g
s
.35462 .6781 m .36258 .64283 L .33586 .63174 L p .707 .577 .707 r
F P
0 g
s
.36258 .64283 m .35462 .6781 L .38505 .6867 L p .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .45231 .69113 L .4317 .69533 L p .707 .577 .707 r
F P
0 g
s
.4317 .69533 m .42307 .69709 L p .42863 .69934 L .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .4317 .69533 L .42863 .69934 L .707 .577 .707 r
F
.45231 .69113 m .45441 .70975 L .47837 .70245 L p F P
0 g
s
.47837 .70245 m .47627 .68382 L .46045 .68865 L p .707 .577 .707 r
F P
0 g
s
.46045 .68865 m .45231 .69113 L p .4575 .69338 L .707 .577 .707 r
F P
0 g
s
.47837 .70245 m .46045 .68865 L .4575 .69338 L .707 .577 .707 r
F
.47627 .68382 m .47837 .70245 L .49471 .69451 L p F P
0 g
s
.49471 .69451 m .49261 .67589 L .48293 .68059 L p .707 .577 .707 r
F P
0 g
s
.48293 .68059 m .47627 .68382 L p .48078 .68644 L .707 .577 .707 r
F P
0 g
s
.49471 .69451 m .48293 .68059 L .48078 .68644 L .707 .577 .707 r
F
.48504 .68452 m .49224 .67509 L p .49288 .65346 L F P
0 g
s
.49301 .64925 m .49074 .65932 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.49074 .65932 m .48504 .68452 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .48504 .68452 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.47676 .65556 m .4743 .66642 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.4743 .66642 m .46879 .69083 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .46879 .69083 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45304 .65813 m .45007 .67129 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45007 .67129 m .44508 .69339 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.42419 .65671 m .41622 .69197 L .44508 .69339 L p .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .45304 .65813 L .42419 .65671 L p .707 .577 .707 r
F P
0 g
s
.46949 .5412 m .47733 .59703 L .49365 .58895 L p .707 .577 .707 r
F P
0 g
s
.49365 .58895 m .4858 .53313 L .46949 .5412 L p .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .69103 .61355 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .66518 .62555 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .66732 .61612 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.69103 .61355 m .68946 .62048 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.68136 .5628 m .6892 .61863 L .67243 .62404 L p .707 .577 .707 r
F P
0 g
s
.67243 .62404 m .6653 .62634 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66551 .62549 m .68136 .5628 L .67243 .62404 L .707 .577 .707 r
F
.68307 .64881 m .65935 .65138 L p .68432 .62156 L F P
0 g
s
.68946 .62048 m .68307 .64881 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .66518 .62555 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .68136 .5628 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65745 .57052 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.39352 .71974 m .39142 .70111 L .36045 .70282 L p .707 .577 .707 r
F P
0 g
s
.39142 .70111 m .39352 .71974 L .42518 .71571 L p .707 .577 .707 r
F P
0 g
s
.42518 .71571 m .42307 .69709 L .39142 .70111 L p .707 .577 .707 r
F P
0 g
s
.3061 .56062 m .31395 .61644 L .33472 .61885 L p .707 .577 .707 r
F P
0 g
s
.42307 .69709 m .42518 .71571 L .45441 .70975 L p .707 .577 .707 r
F P
0 g
s
.33586 .63174 m .3279 .667 L .35462 .6781 L p .707 .577 .707 r
F P
0 g
s
.3279 .667 m .33586 .63174 L .31547 .61923 L p .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .47676 .65556 L .45304 .65813 L p .707 .577 .707 r
F P
0 g
s
.36045 .70282 m .36255 .72144 L .39352 .71974 L p .707 .577 .707 r
F P
0 g
s
.80006 .5487 m .80791 .60452 L .78077 .60462 L p .707 .577 .707 r
F P
0 g
s
.78077 .60462 m .77292 .5488 L .80006 .5487 L p .707 .577 .707 r
F P
0 g
s
.8286 .65244 m .82063 .68771 L .80024 .6752 L p .707 .577 .707 r
F P
0 g
s
.80024 .6752 m .80821 .63994 L .8286 .65244 L p .707 .577 .707 r
F P
0 g
s
.64931 .73388 m .6472 .71525 L .66354 .70731 L p .707 .577 .707 r
F P
0 g
s
.36255 .72144 m .36045 .70282 L .3332 .70203 L p .707 .577 .707 r
F P
0 g
s
.66354 .70731 m .66564 .72594 L .64931 .73388 L p .707 .577 .707 r
F P
0 g
s
.3332 .70203 m .3353 .72065 L .36255 .72144 L p .707 .577 .707 r
F P
0 g
s
.31395 .61644 m .3061 .56062 L .29374 .55595 L p .707 .577 .707 r
F P
0 g
s
.6892 .61863 m .68136 .5628 L .71051 .55621 L p .707 .577 .707 r
F P
0 g
s
.31547 .61923 m .30751 .6545 L .3279 .667 L p .707 .577 .707 r
F P
0 g
s
.82748 .69231 m .82958 .71094 L .80871 .70773 L p .707 .577 .707 r
F P
0 g
s
.80871 .70773 m .80661 .68911 L .82748 .69231 L p .707 .577 .707 r
F P
0 g
s
.77292 .5488 m .78077 .60462 L .74991 .60721 L p .707 .577 .707 r
F P
0 g
s
.74991 .60721 m .74206 .55138 L .77292 .5488 L p .707 .577 .707 r
F P
0 g
s
.4858 .53313 m .49365 .58895 L .50079 .5813 L p .707 .577 .707 r
F P
0 g
s
.50079 .5813 m .49294 .52547 L .4858 .53313 L p .707 .577 .707 r
F P
0 g
s
.3353 .72065 m .3332 .70203 L .31233 .69882 L p .707 .577 .707 r
F P
0 g
s
.29374 .55595 m .30158 .61177 L .30244 .6121 L p .707 .577 .707 r
F P
0 g
s
.30807 .59884 m .29374 .55595 L .30244 .6121 L .707 .577 .707 r
F
.30158 .61177 m .29374 .55595 L .29099 .54947 L p F P
0 g
s
.30158 .61177 m .29828 .59237 L .29871 .60442 L .707 .577 .707 r
F
.29754 .62366 m .30142 .61234 L .29949 .60671 L F
.29974 .60744 m .30158 .61177 L p .29871 .60442 L F P
0 g
s
.29289 .63019 m .29545 .64182 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.30085 .59493 m .29871 .60442 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .29289 .63019 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29871 .60442 L p .29828 .59237 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29812 .54182 L p .29881 .60311 L .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .30085 .59493 L p .29949 .60671 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .30085 .59493 L p .3 .60284 L .707 .577 .707 r
F P
0 g
s
.29883 .60476 m .29883 .60529 L .29974 .60744 L p .707 .577 .707 r
F P
0 g
s
.29883 .60529 m .29871 .60442 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.30142 .61234 m .30341 .60655 L .29949 .60671 L .707 .577 .707 r
F
.30597 .59764 m .29883 .60529 L p .29882 .60428 L F P
0 g
s
.30085 .59493 m .30805 .5855 L p .30371 .59831 L .707 .577 .707 r
F P
0 g
s
.3 .60284 m .30085 .59493 L .30371 .59831 L .707 .577 .707 r
F
.30572 .59586 m .30597 .59764 L p .29882 .60428 L F P
0 g
s
.29545 .64182 m .30183 .61354 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30183 .61354 m .30341 .60655 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .29289 .63019 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .30572 .59586 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30009 .62077 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .32431 .57919 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30597 .59764 m .30572 .59586 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.30244 .6121 m .31395 .61644 L p .30807 .59884 L .707 .577 .707 r
F P
0 g
s
.30751 .6545 m .31547 .61923 L .30341 .60655 L p .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .29545 .64182 L .30751 .6545 L p .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30805 .5855 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .30597 .59764 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .32216 .58869 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .32216 .58869 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32229 .58956 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .30009 .62077 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31634 .61446 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .30572 .59586 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30623 .59563 m .30572 .59586 L .30647 .59385 L .707 .577 .707 r
F
.29812 .54182 m .31444 .53374 L p .30647 .59385 L F P
0 g
s
.30572 .59586 m .29812 .54182 L p .30647 .59385 L .707 .577 .707 r
F P
0 g
s
.29812 .54182 m .30572 .59586 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.29899 .61222 m .3 .60284 L .30371 .59831 L .707 .577 .707 r
F
.29871 .60442 m .3 .60284 L .29899 .61222 L F
.29882 .60428 m .29871 .60442 L .29881 .60311 L F
.29871 .60442 m .29099 .54947 L p .29881 .60311 L F P
0 g
s
.29289 .63019 m .29871 .60442 L p .29899 .61222 L .707 .577 .707 r
F P
0 g
s
.48504 .68452 m .49301 .64925 L .47676 .65556 L p .707 .577 .707 r
F P
0 g
s
.68307 .64881 m .69103 .61355 L .71988 .61497 L p .707 .577 .707 r
F P
0 g
s
.80821 .63994 m .80024 .6752 L .77352 .66411 L p .707 .577 .707 r
F P
0 g
s
.77352 .66411 m .78149 .62884 L .80821 .63994 L p .707 .577 .707 r
F P
0 g
s
.71836 .61204 m .71051 .55621 L .74206 .55138 L p .707 .577 .707 r
F P
0 g
s
.71051 .55621 m .71836 .61204 L .6892 .61863 L p .707 .577 .707 r
F P
0 g
s
.31233 .69882 m .31443 .71745 L .3353 .72065 L p .707 .577 .707 r
F P
0 g
s
.74206 .55138 m .74991 .60721 L .71836 .61204 L p .707 .577 .707 r
F P
0 g
s
.66564 .72594 m .66354 .70731 L .6875 .70001 L p .707 .577 .707 r
F P
0 g
s
.6875 .70001 m .6896 .71863 L .66564 .72594 L p .707 .577 .707 r
F P
0 g
s
.71988 .61497 m .71192 .65023 L .68307 .64881 L p .707 .577 .707 r
F P
0 g
s
.71192 .65023 m .71988 .61497 L .75105 .62024 L p .707 .577 .707 r
F P
0 g
s
.78149 .62884 m .77352 .66411 L .74309 .6555 L p .707 .577 .707 r
F P
0 g
s
.74309 .6555 m .75105 .62024 L .78149 .62884 L p .707 .577 .707 r
F P
0 g
s
.80661 .68911 m .80871 .70773 L .78146 .70694 L p .707 .577 .707 r
F P
0 g
s
.78146 .70694 m .77936 .68832 L .80661 .68911 L p .707 .577 .707 r
F P
0 g
s
.75105 .62024 m .74309 .6555 L .71192 .65023 L p .707 .577 .707 r
F P
0 g
s
.31443 .71745 m .31233 .69882 L .29988 .69352 L p .707 .577 .707 r
F P
0 g
s
.49224 .67509 m .50021 .63983 L .49301 .64925 L p .707 .577 .707 r
F P
0 g
s
.6896 .71863 m .6875 .70001 L .71674 .69405 L p .707 .577 .707 r
F P
0 g
s
.29988 .69352 m .30198 .71214 L .31443 .71745 L p .707 .577 .707 r
F P
0 g
s
.49294 .52547 m .50079 .5813 L .49803 .57482 L p .707 .577 .707 r
F P
0 g
s
.49803 .57482 m .49019 .51899 L .49294 .52547 L p .707 .577 .707 r
F P
0 g
s
.71674 .69405 m .71884 .71267 L .6896 .71863 L p .707 .577 .707 r
F P
0 g
s
.77936 .68832 m .78146 .70694 L .75049 .70865 L p .707 .577 .707 r
F P
0 g
s
.75049 .70865 m .74839 .69002 L .77936 .68832 L p .707 .577 .707 r
F P
0 g
s
.49261 .67589 m .49471 .69451 L .50182 .68672 L p .707 .577 .707 r
F P
0 g
s
.50182 .68672 m .49972 .66809 L .49261 .67589 L p .707 .577 .707 r
F P
0 g
s
.71884 .71267 m .71674 .69405 L .74839 .69002 L p .707 .577 .707 r
F P
0 g
s
.74839 .69002 m .75049 .70865 L .71884 .71267 L p .707 .577 .707 r
F P
0 g
s
.30198 .71214 m .29988 .69352 L .29708 .68663 L p .707 .577 .707 r
F P
0 g
s
.50021 .63983 m .49224 .67509 L .48969 .66347 L p .707 .577 .707 r
F P
0 g
s
.48969 .66347 m .49468 .64136 L p .50021 .63983 L .707 .577 .707 r
F P
0 g
s
.49765 .6282 m .48969 .66347 L .47762 .65079 L p .707 .577 .707 r
F P
0 g
s
.48657 .67452 m .48541 .6642 L p .49692 .66121 L .707 .577 .707 r
F P
0 g
s
.48541 .6642 m .48447 .6559 L .48814 .65747 L p .707 .577 .707 r
F P
0 g
s
.48814 .65747 m .49692 .66121 L p .48541 .6642 L .707 .577 .707 r
F P
0 g
s
.49468 .64136 m .49765 .6282 L .49848 .63199 L p .707 .577 .707 r
F P
0 g
s
.49848 .63199 m .50021 .63983 L p .49468 .64136 L .707 .577 .707 r
F P
0 g
s
.29708 .68663 m .29918 .70526 L .30198 .71214 L p .707 .577 .707 r
F P
0 g
s
.49019 .51899 m .49803 .57482 L .48567 .57015 L p .707 .577 .707 r
F P
0 g
s
.48567 .57015 m .47782 .51432 L .49019 .51899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49972 .66809 m .50182 .68672 L .49902 .67983 L p .707 .577 .707 r
F P
0 g
s
.49902 .67983 m .49692 .66121 L .49972 .66809 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29918 .70526 m .29708 .68663 L .30419 .67884 L p .707 .577 .707 r
F P
0 g
s
.47762 .65079 m .48559 .61552 L .49765 .6282 L p .707 .577 .707 r
F P
0 g
s
.30419 .67884 m .30629 .69746 L .29918 .70526 L p .707 .577 .707 r
F P
0 g
s
.47782 .51432 m .48567 .57015 L .4649 .56774 L p .707 .577 .707 r
F P
0 g
s
.4649 .56774 m .45705 .51192 L .47782 .51432 L p .707 .577 .707 r
F P
0 g
s
.49692 .66121 m .49902 .67983 L .48657 .67452 L p .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .34802 .57663 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .32216 .58869 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32431 .57919 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.34802 .57663 m .34644 .58362 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.33835 .52602 m .34619 .58185 L .3302 .58701 L p .707 .577 .707 r
F P
0 g
s
.3302 .58701 m .32229 .58956 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32253 .58861 m .33835 .52602 L .3302 .58701 L .707 .577 .707 r
F
.34005 .61189 m .31634 .61446 L p .34126 .5847 L F P
0 g
s
.34644 .58362 m .34005 .61189 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .32216 .58869 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .33835 .52602 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31444 .53374 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.45705 .51192 m .4649 .56774 L .43776 .56784 L p .707 .577 .707 r
F P
0 g
s
.43776 .56784 m .42991 .51202 L .45705 .51192 L p .707 .577 .707 r
F P
0 g
s
.48559 .61552 m .47762 .65079 L .45723 .63828 L p .707 .577 .707 r
F P
0 g
s
.45723 .63828 m .4652 .60302 L .48559 .61552 L p .707 .577 .707 r
F P
0 g
s
.30629 .69746 m .30419 .67884 L .32053 .6709 L p .707 .577 .707 r
F P
0 g
s
.32053 .6709 m .32263 .68952 L .30629 .69746 L p .707 .577 .707 r
F P
0 g
s
.34619 .58185 m .33835 .52602 L .3675 .51943 L p .707 .577 .707 r
F P
0 g
s
.48447 .6559 m .48657 .67452 L .4657 .67132 L p .707 .577 .707 r
F P
0 g
s
.4657 .67132 m .4636 .6527 L .48447 .6559 L p .707 .577 .707 r
F P
0 g
s
.42991 .51202 m .43776 .56784 L .4069 .57043 L p .707 .577 .707 r
F P
0 g
s
.4069 .57043 m .39905 .5146 L .42991 .51202 L p .707 .577 .707 r
F P
0 g
s
.34005 .61189 m .34802 .57663 L .37687 .57805 L p .707 .577 .707 r
F P
0 g
s
.4652 .60302 m .45723 .63828 L .43051 .62719 L p .707 .577 .707 r
F P
0 g
s
.43051 .62719 m .43848 .59192 L .4652 .60302 L p .707 .577 .707 r
F P
0 g
s
.37535 .57526 m .3675 .51943 L .39905 .5146 L p .707 .577 .707 r
F P
0 g
s
.3675 .51943 m .37535 .57526 L .34619 .58185 L p .707 .577 .707 r
F P
0 g
s
.39905 .5146 m .4069 .57043 L .37535 .57526 L p .707 .577 .707 r
F P
0 g
s
.32263 .68952 m .32053 .6709 L .34449 .66359 L p .707 .577 .707 r
F P
0 g
s
.34449 .66359 m .34659 .68222 L .32263 .68952 L p .707 .577 .707 r
F P
0 g
s
.37687 .57805 m .36891 .61331 L .34005 .61189 L p .707 .577 .707 r
F P
0 g
s
.36891 .61331 m .37687 .57805 L .40804 .58332 L p .707 .577 .707 r
F P
0 g
s
.43848 .59192 m .43051 .62719 L .40008 .61858 L p .707 .577 .707 r
F P
0 g
s
.40008 .61858 m .40804 .58332 L .43848 .59192 L p .707 .577 .707 r
F P
0 g
s
.4636 .6527 m .4657 .67132 L .43845 .67053 L p .707 .577 .707 r
F P
0 g
s
.43845 .67053 m .43635 .65191 L .4636 .6527 L p .707 .577 .707 r
F P
0 g
s
.40804 .58332 m .40008 .61858 L .36891 .61331 L p .707 .577 .707 r
F P
0 g
s
.34659 .68222 m .34449 .66359 L .37373 .65764 L p .707 .577 .707 r
F P
0 g
s
.37373 .65764 m .37583 .67626 L .34659 .68222 L p .707 .577 .707 r
F P
0 g
s
.43635 .65191 m .43845 .67053 L .40748 .67223 L p .707 .577 .707 r
F P
0 g
s
.40748 .67223 m .40538 .65361 L .43635 .65191 L p .707 .577 .707 r
F P
0 g
s
.37583 .67626 m .37373 .65764 L .40538 .65361 L p .707 .577 .707 r
F P
0 g
s
.40538 .65361 m .40748 .67223 L .37583 .67626 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01EYF3P0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP0015YF2@0015YF00<005YF
FUH015YF00<005YFFUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IGoo001UOol00`00FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol006=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00E7oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000IOolJ000cOol0059oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Eoo`@0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00DWoo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80015oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000=Ool400000eYF
001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH01000
FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1P0000EJEP00001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800004Ool000000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP0:0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000EJEP03001JEUYF009JEPD000IJEP04001JEUYF
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001COol01000FUIJEP0015YF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001EYF0`001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool004moo`H0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF009JEPh000=JEP05001JEUYFFUH0000]Ool004Ioo`T000AJEP800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000MJEP03001JEUYF00=JEPH0009J
EP03001oogoo02]oo`00@7oo1P0015YF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEUYFFUH4000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<000=JEQ@000AJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00>7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEQ`000QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00@000EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00=7oo100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEP0000EJEP03
001JEUYF00@000IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004
FUH01000FUIJEUYF10001eYF00<005YFFUH015YF1P0025YF00<005YFFUH015YF00<005YFFUH00UYF
0P00;Woo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20004FUH3
0005FUH00`00FUIJEP040006FUH00`00FUIJEP05FUH300000eYF001JEP06FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00<7oo0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01000
1UYF10001EYF00<005YF00000P001UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH400000eYF001JEP06FUH01000
FUIJEP00<7oo000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH40002FUH40006FUH50004FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001UYF0`00<Goo000]Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP04FUH01@00FUH00000FUH010001EYF1P0015YF00<005YFFUH015YF0P0000=JEP00FUH01EYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP8003=oo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00@005YFFUIJEPD000EJ
EPH000AJEP03001JEUYF00IJEP8000IJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@003Eoo`00:goo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF00<005YF00000P001EYF00<005YFFUH025YF0P0015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
=Goo000[Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEP00=7oo000[Ool01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YF00000P0015YF0P00
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF00@005YFFUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPD00003FUH0
05YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo02moo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00L000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUHB0004Ool40007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00EJEPP000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH30005FUH01000FUIJEP003Woo10000UYF
00<005YFFUH01UYF00<005YFFUH015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90007FUH01P00FUH00000FUH0009JEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00
15YF00@005YFFUH0019oo`<000QJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP04001JEUYFFUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
0eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001oogoo00Qoo`<000Qoo`8000IJEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00X000QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPl000=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH30003FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0027oo1@002Goo0P00
0eYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;7oo00<005YF00001EYF00<005YFFUH00eYF
10001UYF00<005YFFUH010001EYF00<005YFFUH01EYF10001EYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@001eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP04001JEP000002FUH20008Ool5000;Ool2
00000eYF001JEP05FUH01000FUIJEUYF0P00;Goo000/Ool01000FUIJEP0015YF00@005YFFUIJEP80
0003FUH005YF00IJEP03001JEUYF00EJEP@00003FUH005YF00EJEP80009JEP03001JEUYF00AJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH500000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00@0
05YFFUIJEP@000Qoo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool01000FUIJEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`000eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF10001Woo0`0047oo0P000eYF
00@005YFFUIJEP<002eoo`00;7oo00@005YFFUH0009JEP03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00=JEP@00004FUH00000FUH300000eYF
000000040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0`0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH010005goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUH000040002Ool01000FUIJEP0015YF1`000eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005OolA0003FUH2000^
Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0003FUH40005Ool01000FUIJEP001EYF3@0015YF00@005YFFUIJEPH000AJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPT000AJEP03001JEUYF00EJEP03001JEUYF
00@00003FUH0000002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00800003FUH0000000Ioo`04001JEUYF0005
FUH00`00FUH000020005FUH00`00FUIJEP080005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200000eYF000000020002FUH30004Ool01000FUIJEP001EYF00<005YFFUH015YF1@001eYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEPL0009JEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00004FUH005YFFUHI0004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUH000020003FUH40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool20003FUHB0007FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool2
00000eYF000000030003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01@00FUIJEUYF0000;Goo000/
Ool01000FUH000000UYF00<007ooOol03`0017oo1@001UYF00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P00
00=JEP00FUH01UYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
00<007ooOol0:goo000/Ool30003FUH3000HOol40002FUH00`00FUIJEP0200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF1P00;7oo000/Ool30003FUH00`00FUIJEP02000JOol40003FUH;0004FUH00`00FUIJEP02FUH8
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP03FUH400000goo000000020002FUH00`00FUH0
00040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP000000;7oo000/
Ool30002FUH00`00FUIJEP03FUH3000>Ool3000:Ool20004FUH00`00FUIJEP04FUH:00000eYF001J
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000300000eYF00000006Ool90003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUH0000/Ool002aoo`8000=J
EP03001JEUYF00AJEP04001JEP00000;Ool5000;Ool200000eYF001JEP05FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP<000ao
o`D0009JEP03001JEUYF00IJEP04001JEUYFFUH50005FUH2000]Ool002eoo`05001JEUYFFUH00006
FUH01000FUIJEUYF0`0027oo1@003Goo0P001UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYF001JEP07000@Ool300000goo0000000=0004FUH00`00
FUIJEP03FUH00`00Oomoo`0/Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH30005Ool5
000?Ool20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00000015YF00<007ooOol057oo2@0015YF00<005YFFUH015YF00<005YFFUH00P00;goo
000^Ool01000FUIJEP001EYF00<005YFFUH01UYF00@005YF000000Aoo`<0019oo`05001JEUYFFUH0
0002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000002@0027oo
2@0015YF00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000^Ool00`00FUH00006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH3000GOol30003FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8003=oo`00;goo0P001UYF00<005YFFUH01EYF00<005YFFUH01EYF1P00
17oo3P0000=oo`00FUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eoo`00
<7oo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJ
EP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000iOol0035oo`8000=JEP03
001JEUYF00EJEPX000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000nOol003=oo`800004FUH005YFFUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00
FUIJEP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUH000040006FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP040015Ool003Eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP8000IJEQL004Uoo`00=7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200015YF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP8000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJ
EP<000AJEP03001JEUYF00AJEP04001JEUYFFUH2001DOol0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEPd0009JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
00Ioo`00000005YF0006FUH01000FUIJEUYF0P00E7oo000`Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P0000=J
EP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000017oo0P001UYF00H005YFFUH005YF001DOol0
02moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP@000Ioo`8000=JEP04001JEUYFFUH3001DOol002ioo`8000AJEP03001JEUYF00=J
EP@000Aoo`<00003FUH0000000@000=JEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000Qoo`800003FUH005YF009J
EP03001JEP0005Aoo`00;Goo00<005YF000015YF00<005YF00000`002goo1`000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000Moo`8000=JEP8005Eoo`00;Goo00@005YFFUH000=JEP80015oo``000AJEP04001J
EUYFFUH60003FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000eYF1`000Woo
00<005YFFUH00P00EGoo000]Ool01@00FUIJEP00FUH00P0057oo0`0027oo20001EYF00@005YFFUIJ
EP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP07001EOol0
02ioo`03001JEP0000<001Uoo`H000IJEP03001JEUYF00AJEP06001JEP00001oo`0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000MJEP03001JEUYF00=JEP04001JEP00001EOol002io
o`800004FUH005YFFUH70009Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo000^Ool01000FUIJEP001EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00008000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000aoo`<000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEPl000=JEP05001JEUYFFUH0001DOol002ioo`05001JEUYFFUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000BOol30006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH0
00030008FUH00`00FUIJEP03FUH60002FUH00`00Oomoo`1BOol002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL001Uoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH6001COol0035oo`@000=JEP03001JEUYF00EJEP03001J
EUYF009JEPP002Aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF0000001C
Ool003Eooa00035oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EP0000P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0001C
Ool007aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP06001JEP00001JEWoo0UYF0P00E7oo0024OolJ000;OolI0005FUH2001DOol0
08ioo`03001JEUYF008001Moo`<00003Ool0000000T0009JEP03001JEUYF00AJEP04001JEUYFFUH2
001EOol008moo`800003FUH00000008000moo`T000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP00001GOol008moo`80009JEP03001JEUYF00l000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<005Uoo`00Sgoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00G7oo002?Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001P
Ool0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@006=oo`00TWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
1`00Igoo002FOolI001^Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59966 .7419 m .58703 .68652 L .55669 .69188 L p .707 .577 .707 r
F P
0 g
s
.58703 .68652 m .59966 .7419 L .63075 .73457 L p .707 .577 .707 r
F P
0 g
s
.63075 .73457 m .61812 .6792 L .58703 .68652 L p .707 .577 .707 r
F P
0 g
s
.61812 .6792 m .63075 .73457 L .65954 .726 L p .707 .577 .707 r
F P
0 g
s
.65954 .726 m .64691 .67063 L .61812 .6792 L p .707 .577 .707 r
F P
0 g
s
.56931 .74725 m .55669 .69188 L .53005 .69474 L p .707 .577 .707 r
F P
0 g
s
.55669 .69188 m .56931 .74725 L .59966 .7419 L p .707 .577 .707 r
F P
0 g
s
.64691 .67063 m .65954 .726 L .68321 .71702 L p .707 .577 .707 r
F P
0 g
s
.68321 .71702 m .67059 .66164 L .64691 .67063 L p .707 .577 .707 r
F P
0 g
s
.53005 .69474 m .54268 .75011 L .56931 .74725 L p .707 .577 .707 r
F P
0 g
s
.58697 .81857 m .59968 .78531 L .57043 .77279 L p .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .62906 .82137 L .59874 .82721 L p .707 .577 .707 r
F P
0 g
s
.59874 .82721 m .59771 .82741 L p .59827 .82761 L .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .59874 .82721 L .59827 .82761 L .707 .577 .707 r
F
.63245 .83992 m .66145 .83237 L p .63217 .82242 L F P
0 g
s
.62906 .82137 m .62964 .8245 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.62964 .8245 m .63245 .83992 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .65807 .81382 L .62906 .82137 L p .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .68526 .82404 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65807 .81382 m .65941 .82117 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65941 .82117 m .66145 .83237 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .68187 .80549 L .67028 .80954 L p .707 .577 .707 r
F P
0 g
s
.67028 .80954 m .65807 .81382 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .67028 .80954 L .66415 .8161 L .707 .577 .707 r
F
.68187 .80549 m .68526 .82404 L .70155 .81575 L p F P
0 g
s
.70155 .81575 m .69816 .7972 L .68187 .80549 L p .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .69703 .79188 L .68174 .79729 L p .707 .577 .707 r
F P
0 g
s
.68174 .79729 m .68096 .79757 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .68174 .79729 L .68102 .79806 L .707 .577 .707 r
F
.66825 .83083 m .68431 .82514 L p .68102 .79806 L F P
0 g
s
.68096 .79757 m .6806 .79851 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.6806 .79851 m .66825 .83083 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .66825 .83083 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65779 .79833 m .65606 .80285 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65606 .80285 m .64508 .8316 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .64508 .8316 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62978 .79411 m .62593 .8042 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62593 .8042 m .61707 .82737 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.59968 .78531 m .58697 .81857 L .61707 .82737 L p .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .62978 .79411 L .59968 .78531 L p .707 .577 .707 r
F P
0 g
s
.55771 .80605 m .57043 .77279 L .54489 .75778 L p .707 .577 .707 r
F P
0 g
s
.57043 .77279 m .55771 .80605 L .58697 .81857 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53005 .69474 L .50974 .69483 L p .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .65779 .79833 L .62978 .79411 L p .707 .577 .707 r
F P
0 g
s
.67059 .66164 m .68321 .71702 L .69945 .7085 L p .707 .577 .707 r
F P
0 g
s
.69945 .7085 m .68683 .65313 L .67059 .66164 L p .707 .577 .707 r
F P
0 g
s
.6011 .84596 m .59771 .82741 L .56707 .83133 L p .707 .577 .707 r
F P
0 g
s
.59771 .82741 m .6011 .84596 L .63245 .83992 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53556 .73816 L .52235 .75015 L .707 .577 .707 r
F
.50974 .69483 m .52235 .75015 L p .53556 .73816 L F P
0 g
s
.50974 .69483 m .49774 .69214 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.5225 .7502 m .54268 .75011 L p .52235 .75015 L .707 .577 .707 r
F P
0 g
s
.51285 .77501 m .53218 .79104 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52556 .74174 m .52235 .75015 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .51285 .77501 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.51336 .75831 m .52038 .74878 L .5138 .74419 L .707 .577 .707 r
F
.51285 .77501 m .52235 .75015 L p .51336 .75831 L F P
0 g
s
.52234 .75014 m .52224 .74992 L .52193 .74985 L .707 .577 .707 r
F
.49774 .69214 m .50041 .70384 L p .52224 .74992 L F P
0 g
s
.52235 .75015 m .52038 .74878 L .51336 .75831 L .707 .577 .707 r
F
.50041 .70384 m .50882 .74073 L p .51494 .73452 L F P
0 g
s
.49774 .69214 m .49522 .68694 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50163 .75952 m .50882 .74073 L p .50507 .74452 L .707 .577 .707 r
F P
0 g
s
.50882 .74073 m .49774 .69214 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50835 .73946 m .50508 .72636 L .50531 .7312 L .707 .577 .707 r
F
.49522 .68694 m .50531 .7312 L p .50508 .72636 L F P
0 g
s
.50882 .74073 m .50805 .73865 L .50507 .74452 L .707 .577 .707 r
F
.50507 .74452 m .50805 .73865 L .50704 .73591 L F
.49962 .7461 m .50163 .75952 L p .50335 .75202 L F P
0 g
s
.51233 .71283 m .50531 .7312 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .49962 .7461 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.49522 .68694 m .50244 .67972 L p .50613 .72249 L .707 .577 .707 r
F P
0 g
s
.50737 .73679 m .50785 .74231 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51435 .72626 m .51233 .71283 L p .50704 .73591 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .50974 .69483 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.51233 .71283 m .51972 .70279 L p .50827 .72745 L .707 .577 .707 r
F P
0 g
s
.50805 .73865 m .51435 .72626 L .50704 .73591 L .707 .577 .707 r
F
.50785 .74231 m .50531 .7312 L p .50673 .7294 L F P
0 g
s
.50688 .72921 m .51233 .71283 L .50827 .72745 L .707 .577 .707 r
F
.50882 .74073 m .51435 .72626 L p .50805 .73865 L F P
0 g
s
.50882 .74073 m .50163 .75952 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.50785 .74231 m .51036 .74752 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .50882 .74073 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .51494 .73452 L .50882 .74073 L .707 .577 .707 r
F
.50163 .75952 m .51285 .77501 L p .5138 .74419 L F P
0 g
s
.50882 .74073 m .51036 .74752 L p .52193 .74985 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .50882 .74073 L .52193 .74985 L .707 .577 .707 r
F
.51435 .72626 m .50882 .74073 L p .5138 .74419 L F P
0 g
s
.52556 .74174 m .51435 .72626 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .50785 .74231 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .51233 .71283 L p .50688 .72921 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51506 .73509 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .51219 .72249 L p .49962 .7461 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .50701 .73605 L .49982 .74582 L p .707 .577 .707 r
F P
0 g
s
.49982 .74582 m .49962 .7461 L p .51219 .72249 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .53578 .6971 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .51219 .72249 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51972 .70279 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .51506 .73509 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .52877 .71546 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .52877 .71546 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .5313 .72658 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .50701 .73605 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .52307 .73036 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.50701 .73605 m .51219 .72249 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51586 .72093 m .51219 .72249 L .5162 .71492 L .707 .577 .707 r
F
.50244 .67972 m .51868 .6712 L p .5162 .71492 L F P
0 g
s
.51219 .72249 m .50244 .67972 L p .5162 .71492 L .707 .577 .707 r
F P
0 g
s
.50244 .67972 m .51219 .72249 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .50688 .72921 L .50543 .73358 L .707 .577 .707 r
F
.50543 .73358 m .50688 .72921 L .50827 .72745 L F
.50673 .7294 m .50531 .7312 L .50613 .72249 L F
.50531 .7312 m .49522 .68694 L p .50613 .72249 L F P
0 g
s
.49962 .7461 m .50531 .7312 L p .50543 .73358 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52556 .74174 L p .52038 .74878 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .52237 .75021 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.52234 .75014 m .52193 .74985 L .51036 .74752 L .707 .577 .707 r
F
.52237 .75021 m .52235 .75015 L p .52234 .75014 L F P
0 g
s
.52038 .74878 m .52556 .74174 L .5138 .74419 L .707 .577 .707 r
F
.54489 .75778 m .52556 .74174 L p .52692 .75187 L F P
0 g
s
.53218 .79104 m .5446 .75854 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.5446 .75854 m .54489 .75778 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52237 .75021 L .5225 .7502 L p .707 .577 .707 r
F P
0 g
s
.54489 .75778 m .53218 .79104 L .55771 .80605 L p .707 .577 .707 r
F P
0 g
s
.56707 .83133 m .57046 .84989 L .6011 .84596 L p .707 .577 .707 r
F P
0 g
s
.57046 .84989 m .56707 .83133 L .54015 .83277 L p .707 .577 .707 r
F P
0 g
s
.66825 .83083 m .68096 .79757 L .65779 .79833 L p .707 .577 .707 r
F P
0 g
s
.54015 .83277 m .54353 .85133 L .57046 .84989 L p .707 .577 .707 r
F P
0 g
s
.68683 .65313 m .69945 .7085 L .70666 .70128 L p .707 .577 .707 r
F P
0 g
s
.70666 .70128 m .69404 .64591 L .68683 .65313 L p .707 .577 .707 r
F P
0 g
s
.54353 .85133 m .54015 .83277 L .51957 .83158 L p .707 .577 .707 r
F P
0 g
s
.51957 .83158 m .52296 .85013 L .54353 .85133 L p .707 .577 .707 r
F P
0 g
s
.52296 .85013 m .51957 .83158 L .50736 .82787 L p .707 .577 .707 r
F P
0 g
s
.69404 .64591 m .70666 .70128 L .70415 .69608 L p .707 .577 .707 r
F P
0 g
s
.70415 .69608 m .69152 .6407 L .69404 .64591 L p .707 .577 .707 r
F P
0 g
s
.50736 .82787 m .51075 .84642 L .52296 .85013 L p .707 .577 .707 r
F P
0 g
s
.69703 .79188 m .68431 .82514 L .6917 .8151 L p .707 .577 .707 r
F P
0 g
s
.70155 .81575 m .70871 .80831 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.69816 .7972 m .70084 .8119 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70084 .8119 m .70155 .81575 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70871 .80831 m .70533 .78976 L .69816 .7972 L p .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .70405 .78278 L p .69703 .79188 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .70441 .78183 L .70405 .78232 L p .707 .577 .707 r
F P
0 g
s
.70405 .78232 m .69703 .79188 L p .70405 .78278 L .707 .577 .707 r
F P
0 g
s
.70606 .80245 m .70402 .79124 L p .70533 .78976 L .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .68969 .80167 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .6917 .8151 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.68969 .80167 m .70067 .77293 L p .70441 .78183 L .707 .577 .707 r
F P
0 g
s
.70067 .77293 m .7024 .76841 L .70274 .7707 L p .707 .577 .707 r
F P
0 g
s
.70274 .7707 m .70441 .78183 L p .70067 .77293 L .707 .577 .707 r
F P
0 g
s
.7024 .76841 m .68969 .80167 L .67847 .78619 L p .707 .577 .707 r
F P
0 g
s
.69385 .79874 m .69104 .78331 L p .70267 .78389 L .707 .577 .707 r
F P
0 g
s
.69104 .78331 m .69046 .78018 L .69317 .78101 L p .707 .577 .707 r
F P
0 g
s
.69317 .78101 m .70267 .78389 L p .69104 .78331 L .707 .577 .707 r
F P
0 g
s
.70402 .79124 m .70267 .78389 L .70403 .7869 L p .707 .577 .707 r
F P
0 g
s
.70403 .7869 m .70533 .78976 L p .70402 .79124 L .707 .577 .707 r
F P
0 g
s
.70441 .78183 m .70405 .78278 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.48594 .82192 m .49262 .3208 L .44862 .31753 L p .707 .577 .707 r
F P
0 g
s
.51075 .84642 m .50736 .82787 L .50471 .822 L p .707 .577 .707 r
F P
0 g
s
.50471 .822 m .5081 .84056 L .51075 .84642 L p .707 .577 .707 r
F P
0 g
s
.5081 .84056 m .50471 .822 L .51187 .81456 L p .707 .577 .707 r
F P
0 g
s
.51187 .81456 m .51526 .83312 L .5081 .84056 L p .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .55895 .69633 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .53578 .6971 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .54235 .66222 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .52877 .71546 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .51868 .6712 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .5313 .72658 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .55342 .7108 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .55342 .7108 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55497 .71759 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .52307 .73036 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54624 .7296 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .52877 .71546 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51526 .83312 m .51187 .81456 L .52816 .80627 L p .707 .577 .707 r
F P
0 g
s
.52816 .80627 m .53155 .82482 L .51526 .83312 L p .707 .577 .707 r
F P
0 g
s
.53155 .82482 m .52816 .80627 L .55197 .79794 L p .707 .577 .707 r
F P
0 g
s
.49262 .3208 m .48594 .82192 L .53088 .82136 L p .707 .577 .707 r
F P
0 g
s
.53088 .82136 m .53757 .32024 L .49262 .3208 L p .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .58696 .70056 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55895 .69633 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .57114 .65365 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .55342 .7108 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54235 .66222 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .55497 .71759 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .58375 .70896 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .58375 .70896 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58376 .70902 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .54624 .7296 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57425 .73382 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .55342 .7108 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55197 .79794 m .55536 .8165 L .53155 .82482 L p .707 .577 .707 r
F P
0 g
s
.55536 .8165 m .55197 .79794 L .58097 .79039 L p .707 .577 .707 r
F P
0 g
s
.58097 .79039 m .58436 .80894 L .55536 .8165 L p .707 .577 .707 r
F P
0 g
s
.53757 .32024 m .53088 .82136 L .57236 .81702 L p .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58696 .70056 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .60223 .64632 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .58375 .70896 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57114 .65365 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .61707 .70936 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.60223 .64632 m .61485 .7017 L .58376 .70902 L p .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .58375 .70896 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57236 .81702 m .57904 .31589 L .53757 .32024 L p .707 .577 .707 r
F P
0 g
s
.44193 .81865 m .44862 .31753 L .40986 .31073 L p .707 .577 .707 r
F P
0 g
s
.44862 .31753 m .44193 .81865 L .48594 .82192 L p .707 .577 .707 r
F P
0 g
s
.69152 .6407 m .70415 .69608 L .69214 .69339 L p .707 .577 .707 r
F P
0 g
s
.69214 .69339 m .67952 .63801 L .69152 .6407 L p .707 .577 .707 r
F P
0 g
s
.61707 .70936 m .60435 .74262 L .57425 .73382 L p .707 .577 .707 r
F P
0 g
s
.58436 .80894 m .58097 .79039 L .61232 .78435 L p .707 .577 .707 r
F P
0 g
s
.61232 .78435 m .61571 .80291 L .58436 .80894 L p .707 .577 .707 r
F P
0 g
s
.57904 .31589 m .57236 .81702 L .60631 .80931 L p .707 .577 .707 r
F P
0 g
s
.61485 .7017 m .60223 .64632 L .63258 .64097 L p .707 .577 .707 r
F P
0 g
s
.64632 .72188 m .63361 .75514 L .60435 .74262 L p .707 .577 .707 r
F P
0 g
s
.60435 .74262 m .61707 .70936 L .64632 .72188 L p .707 .577 .707 r
F P
0 g
s
.60631 .80931 m .613 .30819 L .57904 .31589 L p .707 .577 .707 r
F P
0 g
s
.70533 .78976 m .70871 .80831 L .70606 .80245 L p .707 .577 .707 r
F P
0 g
s
.40317 .81185 m .40986 .31073 L .38014 .30108 L p .707 .577 .707 r
F P
0 g
s
.40986 .31073 m .40317 .81185 L .44193 .81865 L p .707 .577 .707 r
F P
0 g
s
.25665 .70514 m .24402 .64977 L .21368 .65512 L p .707 .577 .707 r
F P
0 g
s
.24402 .64977 m .25665 .70514 L .28774 .69782 L p .707 .577 .707 r
F P
0 g
s
.28774 .69782 m .27511 .64244 L .24402 .64977 L p .707 .577 .707 r
F P
0 g
s
.27511 .64244 m .28774 .69782 L .31653 .68924 L p .707 .577 .707 r
F P
0 g
s
.31653 .68924 m .30391 .63387 L .27511 .64244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2263 .71049 m .21368 .65512 L .18704 .65799 L p .707 .577 .707 r
F P
0 g
s
.21368 .65512 m .2263 .71049 L .25665 .70514 L p .707 .577 .707 r
F P
0 g
s
.30391 .63387 m .31653 .68924 L .3402 .68026 L p .707 .577 .707 r
F P
0 g
s
.3402 .68026 m .32758 .62489 L .30391 .63387 L p .707 .577 .707 r
F P
0 g
s
.67952 .63801 m .69214 .69339 L .67183 .69348 L p .707 .577 .707 r
F P
0 g
s
.67183 .69348 m .65921 .63811 L .67952 .63801 L p .707 .577 .707 r
F P
0 g
s
.63258 .64097 m .6452 .69634 L .61485 .7017 L p .707 .577 .707 r
F P
0 g
s
.64296 .78042 m .64635 .79898 L .61571 .80291 L p .707 .577 .707 r
F P
0 g
s
.61571 .80291 m .61232 .78435 L .64296 .78042 L p .707 .577 .707 r
F P
0 g
s
.613 .30819 m .60631 .80931 L .62942 .79901 L p .707 .577 .707 r
F P
0 g
s
.62942 .79901 m .63611 .29788 L .613 .30819 L p .707 .577 .707 r
F P
0 g
s
.67847 .78619 m .68733 .76301 L p .7024 .76841 L .707 .577 .707 r
F P
0 g
s
.69118 .75292 m .67847 .78619 L .65915 .77015 L p .707 .577 .707 r
F P
0 g
s
.67328 .79754 m .67 .77957 L p .69046 .78018 L .707 .577 .707 r
F P
0 g
s
.67 .77957 m .66989 .77899 L .67057 .77903 L p .707 .577 .707 r
F P
0 g
s
.67057 .77903 m .69046 .78018 L p .67 .77957 L .707 .577 .707 r
F P
0 g
s
.68733 .76301 m .69118 .75292 L .69392 .75671 L p .707 .577 .707 r
F P
0 g
s
.69392 .75671 m .7024 .76841 L p .68733 .76301 L .707 .577 .707 r
F P
0 g
s
.18704 .65799 m .19967 .71336 L .2263 .71049 L p .707 .577 .707 r
F P
0 g
s
.24396 .78159 m .25667 .74832 L .22742 .7358 L p .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .28606 .78521 L .25475 .79123 L p .707 .577 .707 r
F P
0 g
s
.25475 .79123 m .2547 .79124 L p .25473 .79125 L .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .25475 .79123 L .25473 .79125 L .707 .577 .707 r
F
.28944 .80376 m .31845 .79621 L p .28861 .78607 L F P
0 g
s
.28606 .78521 m .28653 .78778 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.28653 .78778 m .28944 .80376 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .31506 .77765 L .28606 .78521 L p .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .34225 .78788 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.31506 .77765 m .3163 .78445 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.3163 .78445 m .31845 .79621 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .33887 .76933 L .32635 .7737 L p .707 .577 .707 r
F P
0 g
s
.32635 .7737 m .31506 .77765 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .32635 .7737 L .32068 .77977 L .707 .577 .707 r
F
.33887 .76933 m .34225 .78788 L .35854 .77959 L p F P
0 g
s
.35854 .77959 m .35515 .76103 L .33887 .76933 L p .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .35402 .7549 L .33895 .76023 L p .707 .577 .707 r
F P
0 g
s
.33895 .76023 m .33795 .76058 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .33895 .76023 L .33803 .76121 L .707 .577 .707 r
F
.32524 .79385 m .34131 .78816 L p .33803 .76121 L F P
0 g
s
.33795 .76058 m .33749 .76179 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.33749 .76179 m .32524 .79385 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .32524 .79385 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31478 .76135 m .31295 .76613 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31295 .76613 m .30207 .79461 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .30207 .79461 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28677 .75713 m .28282 .76748 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28282 .76748 m .27406 .79039 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.25667 .74832 m .24396 .78159 L .27406 .79039 L p .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .28677 .75713 L .25667 .74832 L p .707 .577 .707 r
F P
0 g
s
.70267 .78389 m .70606 .80245 L .69385 .79874 L p .707 .577 .707 r
F P
0 g
s
.21471 .76907 m .22742 .7358 L .20188 .72079 L p .707 .577 .707 r
F P
0 g
s
.22742 .7358 m .21471 .76907 L .24396 .78159 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .18704 .65799 L .16673 .65808 L p .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .31478 .76135 L .28677 .75713 L p .707 .577 .707 r
F P
0 g
s
.37345 .80221 m .38014 .30108 L .36236 .28953 L p .707 .577 .707 r
F P
0 g
s
.38014 .30108 m .37345 .80221 L .40317 .81185 L p .707 .577 .707 r
F P
0 g
s
.32758 .62489 m .3402 .68026 L .35644 .67174 L p .707 .577 .707 r
F P
0 g
s
.35644 .67174 m .34382 .61637 L .32758 .62489 L p .707 .577 .707 r
F P
0 g
s
.25809 .8098 m .2547 .79124 L .22406 .79517 L p .707 .577 .707 r
F P
0 g
s
.2547 .79124 m .25809 .8098 L .28944 .80376 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .19248 .70129 L .17931 .71325 L .707 .577 .707 r
F
.16673 .65808 m .17931 .71325 L p .19248 .70129 L F P
0 g
s
.16673 .65808 m .15473 .65539 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17984 .71345 m .19967 .71336 L p .17931 .71325 L .707 .577 .707 r
F P
0 g
s
.16984 .73802 m .18917 .75406 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.18255 .70476 m .17931 .71325 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16984 .73802 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17035 .72138 m .17733 .71187 L .17078 .70731 L .707 .577 .707 r
F
.16984 .73802 m .17931 .71325 L p .17035 .72138 L F P
0 g
s
.17925 .71321 m .17893 .71246 L .17797 .71231 L .707 .577 .707 r
F
.15473 .65539 m .15737 .66694 L p .17893 .71246 L F P
0 g
s
.17931 .71325 m .17733 .71187 L .17035 .72138 L .707 .577 .707 r
F
.15737 .66694 m .16577 .70383 L p .1719 .69762 L F P
0 g
s
.15473 .65539 m .15221 .65018 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.15862 .72253 m .16577 .70383 L p .16205 .7076 L .707 .577 .707 r
F P
0 g
s
.16577 .70383 m .15473 .65539 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.1653 .70253 m .16204 .68948 L .16227 .6943 L .707 .577 .707 r
F
.15221 .65018 m .16227 .6943 L p .16204 .68948 L F P
0 g
s
.16577 .70383 m .16501 .70175 L .16205 .7076 L .707 .577 .707 r
F
.16205 .7076 m .16501 .70175 L .16401 .69903 L F
.15661 .70911 m .15862 .72253 L p .1603 .71522 L F P
0 g
s
.16932 .67585 m .16227 .6943 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .15661 .70911 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.15221 .65018 m .15943 .64296 L p .1631 .68548 L .707 .577 .707 r
F P
0 g
s
.16435 .69996 m .16484 .70555 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17134 .68927 m .16932 .67585 L p .16401 .69903 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16673 .65808 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.16932 .67585 m .17671 .6658 L p .16521 .69057 L .707 .577 .707 r
F P
0 g
s
.16501 .70175 m .17134 .68927 L .16401 .69903 L .707 .577 .707 r
F
.16484 .70555 m .16227 .6943 L p .16371 .69248 L F P
0 g
s
.16383 .69232 m .16932 .67585 L .16521 .69057 L .707 .577 .707 r
F
.16577 .70383 m .17134 .68927 L p .16501 .70175 L F P
0 g
s
.16577 .70383 m .15862 .72253 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.16484 .70555 m .16735 .71076 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .16577 .70383 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .1719 .69762 L .16577 .70383 L .707 .577 .707 r
F
.15862 .72253 m .16984 .73802 L p .17078 .70731 L F P
0 g
s
.16577 .70383 m .16735 .71076 L p .17797 .71231 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .16577 .70383 L .17797 .71231 L .707 .577 .707 r
F
.17134 .68927 m .16577 .70383 L p .17078 .70731 L F P
0 g
s
.18255 .70476 m .17134 .68927 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16484 .70555 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16932 .67585 L p .16383 .69232 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17205 .69834 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .16915 .68559 L p .15661 .70911 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .164 .69906 L .15686 .70878 L p .707 .577 .707 r
F P
0 g
s
.15686 .70878 m .15661 .70911 L p .16915 .68559 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .19277 .66011 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16915 .68559 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17671 .6658 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .17205 .69834 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .18572 .67857 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .18572 .67857 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18829 .68982 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .164 .69906 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18006 .69338 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.164 .69906 m .16915 .68559 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17286 .68402 m .16915 .68559 L .17321 .67793 L .707 .577 .707 r
F
.15943 .64296 m .17567 .63445 L p .17321 .67793 L F P
0 g
s
.16915 .68559 m .15943 .64296 L p .17321 .67793 L .707 .577 .707 r
F P
0 g
s
.15943 .64296 m .16915 .68559 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16383 .69232 L .16239 .69666 L .707 .577 .707 r
F
.16239 .69666 m .16383 .69232 L .16521 .69057 L F
.16371 .69248 m .16227 .6943 L .1631 .68548 L F
.16227 .6943 m .15221 .65018 L p .1631 .68548 L F P
0 g
s
.15661 .70911 m .16227 .6943 L p .16239 .69666 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .18255 .70476 L p .17733 .71187 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .17936 .71345 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17925 .71321 m .17797 .71231 L .16735 .71076 L .707 .577 .707 r
F
.17936 .71345 m .17931 .71325 L p .17925 .71321 L F P
0 g
s
.17733 .71187 m .18255 .70476 L .17078 .70731 L .707 .577 .707 r
F
.20188 .72079 m .18255 .70476 L p .18393 .71499 L F P
0 g
s
.18917 .75406 m .20155 .72164 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.20155 .72164 m .20188 .72079 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .17936 .71345 L .17984 .71345 L p .707 .577 .707 r
F P
0 g
s
.20188 .72079 m .18917 .75406 L .21471 .76907 L p .707 .577 .707 r
F P
0 g
s
.22406 .79517 m .22745 .81373 L .25809 .8098 L p .707 .577 .707 r
F P
0 g
s
.65921 .63811 m .67183 .69348 L .6452 .69634 L p .707 .577 .707 r
F P
0 g
s
.6452 .69634 m .63258 .64097 L .65921 .63811 L p .707 .577 .707 r
F P
0 g
s
.32524 .79385 m .33795 .76058 L .31478 .76135 L p .707 .577 .707 r
F P
0 g
s
.22745 .81373 m .22406 .79517 L .19714 .79661 L p .707 .577 .707 r
F P
0 g
s
.65915 .77015 m .67186 .73689 L .69118 .75292 L p .707 .577 .707 r
F P
0 g
s
.19714 .79661 m .20053 .81516 L .22745 .81373 L p .707 .577 .707 r
F P
0 g
s
.69046 .78018 m .69385 .79874 L .67328 .79754 L p .707 .577 .707 r
F P
0 g
s
.67186 .73689 m .65915 .77015 L .63361 .75514 L p .707 .577 .707 r
F P
0 g
s
.63361 .75514 m .64632 .72188 L .67186 .73689 L p .707 .577 .707 r
F P
0 g
s
.63611 .29788 m .62942 .79901 L .63942 .7871 L p .707 .577 .707 r
F P
0 g
s
.63942 .7871 m .64611 .28598 L .63611 .29788 L p .707 .577 .707 r
F P
0 g
s
.34382 .61637 m .35644 .67174 L .36365 .66453 L p .707 .577 .707 r
F P
0 g
s
.36365 .66453 m .35103 .60915 L .34382 .61637 L p .707 .577 .707 r
F P
0 g
s
.20053 .81516 m .19714 .79661 L .17656 .79541 L p .707 .577 .707 r
F P
0 g
s
.17656 .79541 m .17995 .81397 L .20053 .81516 L p .707 .577 .707 r
F P
0 g
s
.35103 .60915 m .36365 .66453 L .36114 .65932 L p .707 .577 .707 r
F P
0 g
s
.36114 .65932 m .34851 .60395 L .35103 .60915 L p .707 .577 .707 r
F P
0 g
s
.35515 .76103 m .35854 .77959 L .36395 .77397 L p .707 .577 .707 r
F P
0 g
s
.36395 .77397 m .36571 .77215 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35515 .76103 L .36395 .77397 L .707 .577 .707 r
F
.36236 .28953 m .35828 .2772 L p .35665 .59931 L F P
0 g
s
.35983 .75618 m .35515 .76103 L p .35886 .76494 L .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .36094 .74606 L p .35402 .7549 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .3614 .74485 L .36094 .74547 L p .707 .577 .707 r
F P
0 g
s
.36094 .74547 m .35402 .7549 L p .36094 .74606 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .35983 .75618 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36305 .76628 m .36091 .75453 L p .36232 .75359 L .707 .577 .707 r
F P
0 g
s
.35402 .7549 m .34131 .78816 L .34869 .77811 L p .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .34668 .76469 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .34869 .77811 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36091 .75453 m .35967 .74773 L .36092 .75051 L p .707 .577 .707 r
F P
0 g
s
.36092 .75051 m .36232 .75359 L p .36091 .75453 L .707 .577 .707 r
F P
0 g
s
.3614 .74485 m .36094 .74606 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35983 .75618 L .35886 .76494 L .707 .577 .707 r
F
.36571 .77215 m .36333 .75912 L p .36379 .77013 L F P
0 g
s
.36333 .75912 m .36232 .75359 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.34851 .60395 m .36114 .65932 L .34914 .65663 L p .707 .577 .707 r
F P
0 g
s
.34668 .76469 m .35756 .73621 L p .3614 .74485 L .707 .577 .707 r
F P
0 g
s
.35756 .73621 m .35939 .73143 L .35975 .73385 L p .707 .577 .707 r
F P
0 g
s
.35975 .73385 m .3614 .74485 L p .35756 .73621 L .707 .577 .707 r
F P
0 g
s
.35939 .73143 m .34668 .76469 L .33808 .75281 L p .707 .577 .707 r
F P
0 g
s
.33808 .75281 m .33546 .7492 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .35939 .73143 L .33808 .75281 L .707 .577 .707 r
F
.35785 .62804 m .36236 .28953 L p .35665 .59931 L F P
0 g
s
.35084 .76257 m .34792 .74659 L p .35967 .74773 L .707 .577 .707 r
F P
0 g
s
.34968 .7447 m .35967 .74773 L p .34792 .74659 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .36571 .77215 L .36305 .76628 L p .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .3453 .72525 L .35939 .73143 L .707 .577 .707 r
F
.33546 .7492 m .33943 .73883 L p .33865 .74683 L F P
0 g
s
.33943 .73883 m .34817 .71594 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .33546 .7492 L .31614 .73317 L p .707 .577 .707 r
F P
0 g
s
.33027 .76138 m .32688 .74285 L p .34745 .74402 L .707 .577 .707 r
F P
0 g
s
.32688 .74285 m .32688 .74282 L .32691 .74283 L p .707 .577 .707 r
F P
0 g
s
.32691 .74283 m .34745 .74402 L p .32688 .74285 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .35098 .71982 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35098 .71982 m .35939 .73143 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35967 .74773 m .36305 .76628 L .35084 .76257 L p .707 .577 .707 r
F P
0 g
s
.36236 .28953 m .35568 .79065 L .37345 .80221 L p .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35568 .79065 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35573 .78004 m .35785 .62804 L .35665 .59931 L .707 .577 .707 r
F
.35583 .77955 m .35785 .62804 L p .35573 .78004 L F P
0 g
s
.35591 .77318 m .35159 .77832 L p .3588 .55667 L .707 .577 .707 r
F P
0 g
s
.3588 .55667 m .35971 .52868 L .35591 .77318 L .707 .577 .707 r
F
.36159 .76642 m .35591 .77318 L p .35971 .52868 L F P
0 g
s
.36828 .26529 m .36557 .46794 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.36557 .46794 m .36159 .76642 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .36828 .26529 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .35462 .55094 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35462 .55094 m .35159 .77832 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35415 .58625 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35415 .58625 m .35828 .2772 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.34792 .74659 m .34745 .74402 L .34968 .7447 L p .707 .577 .707 r
F P
0 g
s
.35568 .79065 m .35583 .77955 L p .35573 .78004 L .707 .577 .707 r
F P
0 g
s
.66989 .77899 m .67328 .79754 L .64635 .79898 L p .707 .577 .707 r
F P
0 g
s
.64635 .79898 m .64296 .78042 L .66989 .77899 L p .707 .577 .707 r
F P
0 g
s
.17995 .81397 m .17656 .79541 L .16435 .7917 L p .707 .577 .707 r
F P
0 g
s
.16435 .7917 m .16774 .81026 L .17995 .81397 L p .707 .577 .707 r
F P
0 g
s
.64611 .28598 m .63942 .7871 L .63533 .77477 L p .707 .577 .707 r
F P
0 g
s
.63533 .77477 m .64202 .27365 L .64611 .28598 L p .707 .577 .707 r
F P
0 g
s
.16774 .81026 m .16435 .7917 L .1617 .78584 L p .707 .577 .707 r
F P
0 g
s
.1617 .78584 m .16509 .80439 L .16774 .81026 L p .707 .577 .707 r
F P
0 g
s
.34914 .65663 m .33651 .60126 L .34851 .60395 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64202 .27365 m .63533 .77477 L .61756 .76322 L p .707 .577 .707 r
F P
0 g
s
.61756 .76322 m .62425 .26209 L .64202 .27365 L p .707 .577 .707 r
F P
0 g
s
.16509 .80439 m .1617 .78584 L .16887 .7784 L p .707 .577 .707 r
F P
0 g
s
.33651 .60126 m .34914 .65663 L .32882 .65672 L p .707 .577 .707 r
F P
0 g
s
.32882 .65672 m .3162 .60135 L .33651 .60126 L p .707 .577 .707 r
F P
0 g
s
.16887 .7784 m .17225 .79695 L .16509 .80439 L p .707 .577 .707 r
F P
0 g
s
.36159 .76642 m .36828 .26529 L .39139 .25499 L p .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .21594 .65935 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .18572 .67857 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .19277 .66011 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .18829 .68982 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .21038 .6739 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .21038 .6739 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21196 .68083 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .18006 .69338 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .20323 .69261 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .18572 .67857 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .19934 .62546 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .17567 .63445 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.3162 .60135 m .32882 .65672 L .30219 .65958 L p .707 .577 .707 r
F P
0 g
s
.30219 .65958 m .28957 .60421 L .3162 .60135 L p .707 .577 .707 r
F P
0 g
s
.17225 .79695 m .16887 .7784 L .18515 .77011 L p .707 .577 .707 r
F P
0 g
s
.31614 .73317 m .32885 .6999 L .34817 .71594 L p .707 .577 .707 r
F P
0 g
s
.18515 .77011 m .18854 .78866 L .17225 .79695 L p .707 .577 .707 r
F P
0 g
s
.62425 .26209 m .61756 .76322 L .58784 .75357 L p .707 .577 .707 r
F P
0 g
s
.58784 .75357 m .59452 .25245 L .62425 .26209 L p .707 .577 .707 r
F P
0 g
s
.34745 .74402 m .35084 .76257 L .33027 .76138 L p .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .24395 .66357 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .21038 .6739 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21594 .65935 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .21196 .68083 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .24071 .67206 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .24071 .67206 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24075 .67226 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .20323 .69261 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .23124 .69683 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .21038 .6739 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .22813 .61689 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .19934 .62546 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.28957 .60421 m .30219 .65958 L .27184 .66494 L p .707 .577 .707 r
F P
0 g
s
.27184 .66494 m .25922 .60957 L .28957 .60421 L p .707 .577 .707 r
F P
0 g
s
.39139 .25499 m .3847 .75611 L .36159 .76642 L p .707 .577 .707 r
F P
0 g
s
.3847 .75611 m .39139 .25499 L .42534 .24728 L p .707 .577 .707 r
F P
0 g
s
.32885 .6999 m .31614 .73317 L .2906 .71816 L p .707 .577 .707 r
F P
0 g
s
.2906 .71816 m .30331 .68489 L .32885 .6999 L p .707 .577 .707 r
F P
0 g
s
.73686 .64986 m .72424 .59449 L .69389 .59984 L p .707 .577 .707 r
F P
0 g
s
.72424 .59449 m .73686 .64986 L .76795 .64253 L p .707 .577 .707 r
F P
0 g
s
.76795 .64253 m .75533 .58716 L .72424 .59449 L p .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .27406 .67237 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .24071 .67206 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24395 .66357 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.25922 .60957 m .27184 .66494 L .24075 .67226 L p .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .24071 .67206 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .25922 .60957 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .22813 .61689 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.75533 .58716 m .76795 .64253 L .79674 .63396 L p .707 .577 .707 r
F P
0 g
s
.79674 .63396 m .78412 .57859 L .75533 .58716 L p .707 .577 .707 r
F P
0 g
s
.18854 .78866 m .18515 .77011 L .20896 .76178 L p .707 .577 .707 r
F P
0 g
s
.20896 .76178 m .21235 .78033 L .18854 .78866 L p .707 .577 .707 r
F P
0 g
s
.70651 .65521 m .69389 .59984 L .66726 .6027 L p .707 .577 .707 r
F P
0 g
s
.69389 .59984 m .70651 .65521 L .73686 .64986 L p .707 .577 .707 r
F P
0 g
s
.30331 .68489 m .2906 .71816 L .26134 .70564 L p .707 .577 .707 r
F P
0 g
s
.26134 .70564 m .27406 .67237 L .30331 .68489 L p .707 .577 .707 r
F P
0 g
s
.32688 .74282 m .33027 .76138 L .30334 .76282 L p .707 .577 .707 r
F P
0 g
s
.30334 .76282 m .29995 .74426 L .32688 .74282 L p .707 .577 .707 r
F P
0 g
s
.78412 .57859 m .79674 .63396 L .82042 .62498 L p .707 .577 .707 r
F P
0 g
s
.82042 .62498 m .80779 .5696 L .78412 .57859 L p .707 .577 .707 r
F P
0 g
s
.27406 .67237 m .26134 .70564 L .23124 .69683 L p .707 .577 .707 r
F P
0 g
s
.59452 .25245 m .58784 .75357 L .54908 .74678 L p .707 .577 .707 r
F P
0 g
s
.54908 .74678 m .55576 .24565 L .59452 .25245 L p .707 .577 .707 r
F P
0 g
s
.66726 .6027 m .67988 .65808 L .70651 .65521 L p .707 .577 .707 r
F P
0 g
s
.72417 .72653 m .73688 .69327 L .70763 .68075 L p .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .76627 .72933 L .73595 .73517 L p .707 .577 .707 r
F P
0 g
s
.73595 .73517 m .73491 .73537 L p .73547 .73557 L .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .73595 .73517 L .73547 .73557 L .707 .577 .707 r
F
.76966 .74789 m .79866 .74033 L p .76937 .73039 L F P
0 g
s
.76627 .72933 m .76684 .73246 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.76684 .73246 m .76966 .74789 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .79527 .72178 L .76627 .72933 L p .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .82247 .73201 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79527 .72178 m .79661 .72913 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79661 .72913 m .79866 .74033 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .81908 .71345 L .80748 .71751 L p .707 .577 .707 r
F P
0 g
s
.80748 .71751 m .79527 .72178 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .80748 .71751 L .80135 .72407 L .707 .577 .707 r
F
.81908 .71345 m .82247 .73201 L .83875 .72371 L p F P
0 g
s
.83875 .72371 m .83536 .70516 L .81908 .71345 L p .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .83423 .69984 L .81895 .70525 L p .707 .577 .707 r
F P
0 g
s
.81895 .70525 m .81817 .70553 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .81895 .70525 L .81823 .70602 L .707 .577 .707 r
F
.80545 .73879 m .82152 .73311 L p .81823 .70602 L F P
0 g
s
.81817 .70553 m .8178 .70647 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.8178 .70647 m .80545 .73879 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .80545 .73879 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79499 .7063 m .79327 .71081 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79327 .71081 m .78228 .73956 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .78228 .73956 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76699 .70207 m .76313 .71216 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76313 .71216 m .75427 .73534 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.73688 .69327 m .72417 .72653 L .75427 .73534 L p .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .76699 .70207 L .73688 .69327 L p .707 .577 .707 r
F P
0 g
s
.21235 .78033 m .20896 .76178 L .23796 .75423 L p .707 .577 .707 r
F P
0 g
s
.41865 .74841 m .42534 .24728 L .46682 .24294 L p .707 .577 .707 r
F P
0 g
s
.42534 .24728 m .41865 .74841 L .3847 .75611 L p .707 .577 .707 r
F P
0 g
s
.69492 .71401 m .70763 .68075 L .68209 .66574 L p .707 .577 .707 r
F P
0 g
s
.70763 .68075 m .69492 .71401 L .72417 .72653 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .66726 .6027 L .64695 .60279 L p .707 .577 .707 r
F P
0 g
s
.23796 .75423 m .24135 .77278 L .21235 .78033 L p .707 .577 .707 r
F P
0 g
s
.29995 .74426 m .30334 .76282 L .2727 .76674 L p .707 .577 .707 r
F P
0 g
s
.2727 .76674 m .26931 .74819 L .29995 .74426 L p .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .79499 .7063 L .76699 .70207 L p .707 .577 .707 r
F P
0 g
s
.80779 .5696 m .82042 .62498 L .83665 .61646 L p .707 .577 .707 r
F P
0 g
s
.83665 .61646 m .82403 .56109 L .80779 .5696 L p .707 .577 .707 r
F P
0 g
s
.24135 .77278 m .23796 .75423 L .26931 .74819 L p .707 .577 .707 r
F P
0 g
s
.7383 .75392 m .73491 .73537 L .70427 .7393 L p .707 .577 .707 r
F P
0 g
s
.73491 .73537 m .7383 .75392 L .76966 .74789 L p .707 .577 .707 r
F P
0 g
s
.26931 .74819 m .2727 .76674 L .24135 .77278 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .67276 .64612 L .65956 .65811 L .707 .577 .707 r
F
.64695 .60279 m .65956 .65811 L p .67276 .64612 L F P
0 g
s
.64695 .60279 m .63494 .60011 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65971 .65817 m .67988 .65808 L p .65956 .65811 L .707 .577 .707 r
F P
0 g
s
.65006 .68297 m .66938 .699 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.66277 .6497 m .65956 .65811 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65006 .68297 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65057 .66627 m .65759 .65674 L .651 .65215 L .707 .577 .707 r
F
.65006 .68297 m .65956 .65811 L p .65057 .66627 L F P
0 g
s
.65954 .6581 m .65945 .65788 L .65914 .65782 L .707 .577 .707 r
F
.63494 .60011 m .63761 .6118 L p .65945 .65788 L F P
0 g
s
.65956 .65811 m .65759 .65674 L .65057 .66627 L .707 .577 .707 r
F
.63761 .6118 m .64602 .64869 L p .65215 .64248 L F P
0 g
s
.63494 .60011 m .63243 .5949 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.63884 .66748 m .64602 .64869 L p .64227 .65248 L .707 .577 .707 r
F P
0 g
s
.64602 .64869 m .63494 .60011 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64555 .64742 m .64228 .63433 L .64252 .63916 L .707 .577 .707 r
F
.63243 .5949 m .64252 .63916 L p .64228 .63433 L F P
0 g
s
.64602 .64869 m .64526 .64661 L .64227 .65248 L .707 .577 .707 r
F
.64227 .65248 m .64526 .64661 L .64425 .64387 L F
.63682 .65406 m .63884 .66748 L p .64056 .65998 L F P
0 g
s
.64954 .62079 m .64252 .63916 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .63682 .65406 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.63243 .5949 m .63964 .58768 L p .64334 .63045 L .707 .577 .707 r
F P
0 g
s
.64457 .64475 m .64505 .65027 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65155 .63422 m .64954 .62079 L p .64425 .64387 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .64695 .60279 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.64954 .62079 m .65692 .61075 L p .64548 .63541 L .707 .577 .707 r
F P
0 g
s
.64526 .64661 m .65155 .63422 L .64425 .64387 L .707 .577 .707 r
F
.64505 .65027 m .64252 .63916 L p .64394 .63736 L F P
0 g
s
.64409 .63717 m .64954 .62079 L .64548 .63541 L .707 .577 .707 r
F
.64602 .64869 m .65155 .63422 L p .64526 .64661 L F P
0 g
s
.64602 .64869 m .63884 .66748 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.64505 .65027 m .64757 .65548 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .64602 .64869 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .65215 .64248 L .64602 .64869 L .707 .577 .707 r
F
.63884 .66748 m .65006 .68297 L p .651 .65215 L F P
0 g
s
.64602 .64869 m .64757 .65548 L p .65914 .65782 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .64602 .64869 L .65914 .65782 L .707 .577 .707 r
F
.65155 .63422 m .64602 .64869 L p .651 .65215 L F P
0 g
s
.66277 .6497 m .65155 .63422 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64505 .65027 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64954 .62079 L p .64409 .63717 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65226 .64305 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .64939 .63045 L p .63682 .65406 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .64421 .64401 L .63703 .65378 L p .707 .577 .707 r
F P
0 g
s
.63703 .65378 m .63682 .65406 L p .64939 .63045 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .67299 .60506 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64939 .63045 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65692 .61075 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .65226 .64305 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .66597 .62343 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .66597 .62343 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .6685 .63454 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .64421 .64401 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .66028 .63833 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.64421 .64401 m .64939 .63045 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65307 .6289 m .64939 .63045 L .65341 .62288 L .707 .577 .707 r
F
.63964 .58768 m .65588 .57917 L p .65341 .62288 L F P
0 g
s
.64939 .63045 m .63964 .58768 L p .65341 .62288 L .707 .577 .707 r
F P
0 g
s
.63964 .58768 m .64939 .63045 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64409 .63717 L .64263 .64154 L .707 .577 .707 r
F
.64263 .64154 m .64409 .63717 L .64548 .63541 L F
.64394 .63736 m .64252 .63916 L .64334 .63045 L F
.64252 .63916 m .63243 .5949 L p .64334 .63045 L F P
0 g
s
.63682 .65406 m .64252 .63916 L p .64263 .64154 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .66277 .6497 L p .65759 .65674 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .65957 .65817 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65954 .6581 m .65914 .65782 L .64757 .65548 L .707 .577 .707 r
F
.65957 .65817 m .65956 .65811 L p .65954 .6581 L F P
0 g
s
.65759 .65674 m .66277 .6497 L .651 .65215 L .707 .577 .707 r
F
.68209 .66574 m .66277 .6497 L p .66413 .65983 L F P
0 g
s
.66938 .699 m .6818 .6665 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.6818 .6665 m .68209 .66574 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65957 .65817 L .65971 .65817 L p .707 .577 .707 r
F P
0 g
s
.55576 .24565 m .54908 .74678 L .50507 .7435 L p .707 .577 .707 r
F P
0 g
s
.50507 .7435 m .51176 .24238 L .55576 .24565 L p .707 .577 .707 r
F P
0 g
s
.68209 .66574 m .66938 .699 L .69492 .71401 L p .707 .577 .707 r
F P
0 g
s
.70427 .7393 m .70766 .75785 L .7383 .75392 L p .707 .577 .707 r
F P
0 g
s
.46013 .74406 m .46682 .24294 L .51176 .24238 L p .707 .577 .707 r
F P
0 g
s
.46682 .24294 m .46013 .74406 L .41865 .74841 L p .707 .577 .707 r
F P
0 g
s
.70766 .75785 m .70427 .7393 L .67735 .74073 L p .707 .577 .707 r
F P
0 g
s
.80545 .73879 m .81817 .70553 L .79499 .7063 L p .707 .577 .707 r
F P
0 g
s
.51176 .24238 m .50507 .7435 L .46013 .74406 L p .707 .577 .707 r
F P
0 g
s
.67735 .74073 m .68074 .75929 L .70766 .75785 L p .707 .577 .707 r
F P
0 g
s
.82403 .56109 m .83665 .61646 L .84387 .60924 L p .707 .577 .707 r
F P
0 g
s
.84387 .60924 m .83124 .55387 L .82403 .56109 L p .707 .577 .707 r
F P
0 g
s
.68074 .75929 m .67735 .74073 L .65677 .73954 L p .707 .577 .707 r
F P
0 g
s
.65677 .73954 m .66016 .75809 L .68074 .75929 L p .707 .577 .707 r
F P
0 g
s
.66016 .75809 m .65677 .73954 L .64456 .73583 L p .707 .577 .707 r
F P
0 g
s
.83124 .55387 m .84387 .60924 L .84135 .60404 L p .707 .577 .707 r
F P
0 g
s
.84135 .60404 m .82873 .54867 L .83124 .55387 L p .707 .577 .707 r
F P
0 g
s
.64456 .73583 m .64795 .75438 L .66016 .75809 L p .707 .577 .707 r
F P
0 g
s
.83423 .69984 m .82152 .73311 L .82891 .72306 L p .707 .577 .707 r
F P
0 g
s
.83875 .72371 m .84592 .71627 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83536 .70516 m .83805 .71986 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83805 .71986 m .83875 .72371 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.84592 .71627 m .84253 .69772 L .83536 .70516 L p .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .84126 .69074 L p .83423 .69984 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .84162 .6898 L .84126 .69028 L p .707 .577 .707 r
F P
0 g
s
.84126 .69028 m .83423 .69984 L p .84126 .69074 L .707 .577 .707 r
F P
0 g
s
.84327 .71041 m .84122 .69921 L p .84253 .69772 L .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .82689 .70964 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .82891 .72306 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.82689 .70964 m .83788 .68089 L p .84162 .6898 L .707 .577 .707 r
F P
0 g
s
.83788 .68089 m .8396 .67637 L .83995 .67866 L p .707 .577 .707 r
F P
0 g
s
.83995 .67866 m .84162 .6898 L p .83788 .68089 L .707 .577 .707 r
F P
0 g
s
.8396 .67637 m .82689 .70964 L .81567 .69415 L p .707 .577 .707 r
F P
0 g
s
.83106 .7067 m .82824 .69127 L p .83988 .69186 L .707 .577 .707 r
F P
0 g
s
.82824 .69127 m .82767 .68814 L .83038 .68897 L p .707 .577 .707 r
F P
0 g
s
.83038 .68897 m .83988 .69186 L p .82824 .69127 L .707 .577 .707 r
F P
0 g
s
.84122 .69921 m .83988 .69186 L .84124 .69486 L p .707 .577 .707 r
F P
0 g
s
.84124 .69486 m .84253 .69772 L p .84122 .69921 L .707 .577 .707 r
F P
0 g
s
.84162 .6898 m .84126 .69074 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.64795 .75438 m .64456 .73583 L .64191 .72996 L p .707 .577 .707 r
F P
0 g
s
.64191 .72996 m .6453 .74852 L .64795 .75438 L p .707 .577 .707 r
F P
0 g
s
.82873 .54867 m .84135 .60404 L .82935 .60135 L p .707 .577 .707 r
F P
0 g
s
.82935 .60135 m .81673 .54598 L .82873 .54867 L p .707 .577 .707 r
F P
0 g
s
.84253 .69772 m .84592 .71627 L .84327 .71041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39385 .6131 m .38123 .55773 L .35088 .56308 L p .707 .577 .707 r
F P
0 g
s
.38123 .55773 m .39385 .6131 L .42494 .60578 L p .707 .577 .707 r
F P
0 g
s
.42494 .60578 m .41232 .55041 L .38123 .55773 L p .707 .577 .707 r
F P
0 g
s
.41232 .55041 m .42494 .60578 L .45373 .5972 L p .707 .577 .707 r
F P
0 g
s
.45373 .5972 m .44111 .54183 L .41232 .55041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3635 .61846 m .35088 .56308 L .32425 .56595 L p .707 .577 .707 r
F P
0 g
s
.35088 .56308 m .3635 .61846 L .39385 .6131 L p .707 .577 .707 r
F P
0 g
s
.44111 .54183 m .45373 .5972 L .47741 .58822 L p .707 .577 .707 r
F P
0 g
s
.47741 .58822 m .46478 .53285 L .44111 .54183 L p .707 .577 .707 r
F P
0 g
s
.6453 .74852 m .64191 .72996 L .64908 .72252 L p .707 .577 .707 r
F P
0 g
s
.64908 .72252 m .65247 .74108 L .6453 .74852 L p .707 .577 .707 r
F P
0 g
s
.81673 .54598 m .82935 .60135 L .80904 .60144 L p .707 .577 .707 r
F P
0 g
s
.80904 .60144 m .79642 .54607 L .81673 .54598 L p .707 .577 .707 r
F P
0 g
s
.81567 .69415 m .82453 .67097 L p .8396 .67637 L .707 .577 .707 r
F P
0 g
s
.82839 .66089 m .81567 .69415 L .79635 .67812 L p .707 .577 .707 r
F P
0 g
s
.81048 .7055 m .8072 .68753 L p .82767 .68814 L .707 .577 .707 r
F P
0 g
s
.8072 .68753 m .80709 .68695 L .80777 .68699 L p .707 .577 .707 r
F P
0 g
s
.80777 .68699 m .82767 .68814 L p .8072 .68753 L .707 .577 .707 r
F P
0 g
s
.82453 .67097 m .82839 .66089 L .83113 .66467 L p .707 .577 .707 r
F P
0 g
s
.83113 .66467 m .8396 .67637 L p .82453 .67097 L .707 .577 .707 r
F P
0 g
s
.32425 .56595 m .33687 .62132 L .3635 .61846 L p .707 .577 .707 r
F P
0 g
s
.38116 .68955 m .39387 .65628 L .36462 .64376 L p .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .42326 .69317 L .39196 .69919 L p .707 .577 .707 r
F P
0 g
s
.39196 .69919 m .3919 .6992 L p .39193 .69921 L .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .39196 .69919 L .39193 .69921 L .707 .577 .707 r
F
.42665 .71172 m .45565 .70417 L p .42581 .69404 L F P
0 g
s
.42326 .69317 m .42373 .69574 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.42373 .69574 m .42665 .71172 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .45226 .68562 L .42326 .69317 L p .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .47946 .69584 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.45226 .68562 m .4535 .69241 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.4535 .69241 m .45565 .70417 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .47607 .67729 L .46355 .68167 L p .707 .577 .707 r
F P
0 g
s
.46355 .68167 m .45226 .68562 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .46355 .68167 L .45788 .68773 L .707 .577 .707 r
F
.47607 .67729 m .47946 .69584 L .49574 .68755 L p F P
0 g
s
.49574 .68755 m .49235 .669 L .47607 .67729 L p .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .49122 .66286 L .47616 .66819 L p .707 .577 .707 r
F P
0 g
s
.47616 .66819 m .47516 .66854 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .47616 .66819 L .47523 .66918 L .707 .577 .707 r
F
.46244 .70181 m .47851 .69612 L p .47523 .66918 L F P
0 g
s
.47516 .66854 m .47469 .66975 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47469 .66975 m .46244 .70181 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .46244 .70181 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45198 .66931 m .45016 .6741 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45016 .6741 m .43927 .70258 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .43927 .70258 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42398 .66509 m .42002 .67544 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42002 .67544 m .41127 .69835 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.39387 .65628 m .38116 .68955 L .41127 .69835 L p .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .42398 .66509 L .39387 .65628 L p .707 .577 .707 r
F P
0 g
s
.83988 .69186 m .84327 .71041 L .83106 .7067 L p .707 .577 .707 r
F P
0 g
s
.35191 .67703 m .36462 .64376 L .33908 .62875 L p .707 .577 .707 r
F P
0 g
s
.36462 .64376 m .35191 .67703 L .38116 .68955 L p .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32425 .56595 L .30394 .56604 L p .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .45198 .66931 L .42398 .66509 L p .707 .577 .707 r
F P
0 g
s
.46478 .53285 m .47741 .58822 L .49364 .5797 L p .707 .577 .707 r
F P
0 g
s
.49364 .5797 m .48102 .52433 L .46478 .53285 L p .707 .577 .707 r
F P
0 g
s
.39529 .71776 m .3919 .6992 L .36126 .70313 L p .707 .577 .707 r
F P
0 g
s
.3919 .6992 m .39529 .71776 L .42665 .71172 L p .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .69616 .60429 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .66597 .62343 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .67299 .60506 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .6685 .63454 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .69063 .61876 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .69063 .61876 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69218 .62555 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .66028 .63833 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .68345 .63756 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .66597 .62343 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .67955 .57018 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .65588 .57917 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32968 .60925 L .31651 .62121 L .707 .577 .707 r
F
.30394 .56604 m .31651 .62121 L p .32968 .60925 L F P
0 g
s
.30394 .56604 m .29193 .56335 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31704 .62141 m .33687 .62132 L p .31651 .62121 L .707 .577 .707 r
F P
0 g
s
.30705 .64598 m .32637 .66202 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31976 .61272 m .31651 .62121 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30705 .64598 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.30756 .62934 m .31454 .61983 L .30799 .61527 L .707 .577 .707 r
F
.30705 .64598 m .31651 .62121 L p .30756 .62934 L F P
0 g
s
.31646 .62117 m .31614 .62042 L .31517 .62027 L .707 .577 .707 r
F
.29193 .56335 m .29457 .5749 L p .31614 .62042 L F P
0 g
s
.31651 .62121 m .31454 .61983 L .30756 .62934 L .707 .577 .707 r
F
.29457 .5749 m .30298 .61179 L p .30911 .60558 L F P
0 g
s
.29193 .56335 m .28942 .55814 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.29583 .6305 m .30298 .61179 L p .29925 .61557 L .707 .577 .707 r
F P
0 g
s
.30298 .61179 m .29193 .56335 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.3025 .61049 m .29924 .59744 L .29947 .60226 L .707 .577 .707 r
F
.28942 .55814 m .29947 .60226 L p .29924 .59744 L F P
0 g
s
.30298 .61179 m .30221 .60971 L .29925 .61557 L .707 .577 .707 r
F
.29925 .61557 m .30221 .60971 L .30121 .60699 L F
.29381 .61707 m .29583 .6305 L p .2975 .62318 L F P
0 g
s
.30653 .58381 m .29947 .60226 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .29381 .61707 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.28942 .55814 m .29663 .55093 L p .30031 .59344 L .707 .577 .707 r
F P
0 g
s
.30156 .60792 m .30204 .61351 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30854 .59723 m .30653 .58381 L p .30121 .60699 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30394 .56604 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.30653 .58381 m .31391 .57376 L p .30242 .59853 L .707 .577 .707 r
F P
0 g
s
.30221 .60971 m .30854 .59723 L .30121 .60699 L .707 .577 .707 r
F
.30204 .61351 m .29947 .60226 L p .30091 .60044 L F P
0 g
s
.30104 .60028 m .30653 .58381 L .30242 .59853 L .707 .577 .707 r
F
.30298 .61179 m .30854 .59723 L p .30221 .60971 L F P
0 g
s
.30298 .61179 m .29583 .6305 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30204 .61351 m .30456 .61872 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .30298 .61179 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30911 .60558 L .30298 .61179 L .707 .577 .707 r
F
.29583 .6305 m .30705 .64598 L p .30799 .61527 L F P
0 g
s
.30298 .61179 m .30456 .61872 L p .31517 .62027 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30298 .61179 L .31517 .62027 L .707 .577 .707 r
F
.30854 .59723 m .30298 .61179 L p .30799 .61527 L F P
0 g
s
.31976 .61272 m .30854 .59723 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30204 .61351 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30653 .58381 L p .30104 .60028 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .30925 .6063 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .30635 .59355 L p .29381 .61707 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .3012 .60703 L .29406 .61674 L p .707 .577 .707 r
F P
0 g
s
.29406 .61674 m .29381 .61707 L p .30635 .59355 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .32998 .56808 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30635 .59355 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .31391 .57376 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .30925 .6063 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .32293 .58653 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .32293 .58653 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32549 .59778 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .3012 .60703 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31727 .60134 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.3012 .60703 m .30635 .59355 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31006 .59198 m .30635 .59355 L .31041 .5859 L .707 .577 .707 r
F
.29663 .55093 m .31287 .54241 L p .31041 .5859 L F P
0 g
s
.30635 .59355 m .29663 .55093 L p .31041 .5859 L .707 .577 .707 r
F P
0 g
s
.29663 .55093 m .30635 .59355 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30104 .60028 L .29959 .60462 L .707 .577 .707 r
F
.29959 .60462 m .30104 .60028 L .30242 .59853 L F
.30091 .60044 m .29947 .60226 L .30031 .59344 L F
.29947 .60226 m .28942 .55814 L p .30031 .59344 L F P
0 g
s
.29381 .61707 m .29947 .60226 L p .29959 .60462 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31976 .61272 L p .31454 .61983 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .31656 .62141 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31646 .62117 m .31517 .62027 L .30456 .61872 L .707 .577 .707 r
F
.31656 .62141 m .31651 .62121 L p .31646 .62117 L F P
0 g
s
.31454 .61983 m .31976 .61272 L .30799 .61527 L .707 .577 .707 r
F
.33908 .62875 m .31976 .61272 L p .32113 .62295 L F P
0 g
s
.32637 .66202 m .33876 .6296 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.33876 .6296 m .33908 .62875 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31656 .62141 L .31704 .62141 L p .707 .577 .707 r
F P
0 g
s
.33908 .62875 m .32637 .66202 L .35191 .67703 L p .707 .577 .707 r
F P
0 g
s
.36126 .70313 m .36465 .72169 L .39529 .71776 L p .707 .577 .707 r
F P
0 g
s
.79642 .54607 m .80904 .60144 L .78241 .6043 L p .707 .577 .707 r
F P
0 g
s
.78241 .6043 m .76978 .54893 L .79642 .54607 L p .707 .577 .707 r
F P
0 g
s
.46244 .70181 m .47516 .66854 L .45198 .66931 L p .707 .577 .707 r
F P
0 g
s
.36465 .72169 m .36126 .70313 L .33434 .70457 L p .707 .577 .707 r
F P
0 g
s
.65247 .74108 m .64908 .72252 L .66536 .71423 L p .707 .577 .707 r
F P
0 g
s
.79635 .67812 m .80906 .64485 L .82839 .66089 L p .707 .577 .707 r
F P
0 g
s
.33434 .70457 m .33773 .72312 L .36465 .72169 L p .707 .577 .707 r
F P
0 g
s
.66536 .71423 m .66875 .73279 L .65247 .74108 L p .707 .577 .707 r
F P
0 g
s
.82767 .68814 m .83106 .7067 L .81048 .7055 L p .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .72417 .60852 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .69063 .61876 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69616 .60429 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .69218 .62555 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .72095 .61692 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .72095 .61692 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72097 .61698 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .68345 .63756 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .71146 .64178 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .69063 .61876 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .70834 .56161 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .67955 .57018 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.48102 .52433 m .49364 .5797 L .50086 .57249 L p .707 .577 .707 r
F P
0 g
s
.50086 .57249 m .48823 .51712 L .48102 .52433 L p .707 .577 .707 r
F P
0 g
s
.76978 .54893 m .78241 .6043 L .75206 .60966 L p .707 .577 .707 r
F P
0 g
s
.75206 .60966 m .73944 .55428 L .76978 .54893 L p .707 .577 .707 r
F P
0 g
s
.33773 .72312 m .33434 .70457 L .31376 .70337 L p .707 .577 .707 r
F P
0 g
s
.80906 .64485 m .79635 .67812 L .77081 .6631 L p .707 .577 .707 r
F P
0 g
s
.77081 .6631 m .78352 .62984 L .80906 .64485 L p .707 .577 .707 r
F P
0 g
s
.31376 .70337 m .31715 .72193 L .33773 .72312 L p .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .75427 .61732 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .72095 .61692 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72417 .60852 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.73944 .55428 m .75206 .60966 L .72097 .61698 L p .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .72095 .61692 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .73944 .55428 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .70834 .56161 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.66875 .73279 m .66536 .71423 L .68917 .7059 L p .707 .577 .707 r
F P
0 g
s
.68917 .7059 m .69256 .72446 L .66875 .73279 L p .707 .577 .707 r
F P
0 g
s
.78352 .62984 m .77081 .6631 L .74156 .65058 L p .707 .577 .707 r
F P
0 g
s
.74156 .65058 m .75427 .61732 L .78352 .62984 L p .707 .577 .707 r
F P
0 g
s
.80709 .68695 m .81048 .7055 L .78356 .70694 L p .707 .577 .707 r
F P
0 g
s
.78356 .70694 m .78017 .68839 L .80709 .68695 L p .707 .577 .707 r
F P
0 g
s
.75427 .61732 m .74156 .65058 L .71146 .64178 L p .707 .577 .707 r
F P
0 g
s
.31715 .72193 m .31376 .70337 L .30155 .69966 L p .707 .577 .707 r
F P
0 g
s
.48823 .51712 m .50086 .57249 L .49834 .56728 L p .707 .577 .707 r
F P
0 g
s
.49834 .56728 m .48572 .51191 L .48823 .51712 L p .707 .577 .707 r
F P
0 g
s
.30155 .69966 m .30494 .71822 L .31715 .72193 L p .707 .577 .707 r
F P
0 g
s
.69256 .72446 m .68917 .7059 L .71817 .69835 L p .707 .577 .707 r
F P
0 g
s
.49122 .66286 m .47851 .69612 L .4859 .68607 L p .707 .577 .707 r
F P
0 g
s
.49574 .68755 m .50291 .68011 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49235 .669 m .49494 .68314 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49494 .68314 m .49574 .68755 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.50291 .68011 m .49952 .66155 L .49235 .669 L p .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .49814 .65402 L p .49122 .66286 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .49861 .65281 L .49815 .65344 L p .707 .577 .707 r
F P
0 g
s
.49815 .65344 m .49122 .66286 L p .49814 .65402 L .707 .577 .707 r
F P
0 g
s
.50026 .67425 m .49811 .66249 L p .49952 .66155 L .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .48388 .67265 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .4859 .68607 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49811 .66249 m .49687 .65569 L .49813 .65847 L p .707 .577 .707 r
F P
0 g
s
.49813 .65847 m .49952 .66155 L p .49811 .66249 L .707 .577 .707 r
F P
0 g
s
.49861 .65281 m .49814 .65402 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.71817 .69835 m .72156 .71691 L .69256 .72446 L p .707 .577 .707 r
F P
0 g
s
.78017 .68839 m .78356 .70694 L .75292 .71087 L p .707 .577 .707 r
F P
0 g
s
.75292 .71087 m .74953 .69231 L .78017 .68839 L p .707 .577 .707 r
F P
0 g
s
.72156 .71691 m .71817 .69835 L .74953 .69231 L p .707 .577 .707 r
F P
0 g
s
.74953 .69231 m .75292 .71087 L .72156 .71691 L p .707 .577 .707 r
F P
0 g
s
.30494 .71822 m .30155 .69966 L .2989 .6938 L p .707 .577 .707 r
F P
0 g
s
.2989 .6938 m .30229 .71235 L .30494 .71822 L p .707 .577 .707 r
F P
0 g
s
.48572 .51191 m .49834 .56728 L .48634 .56459 L p .707 .577 .707 r
F P
0 g
s
.48634 .56459 m .47372 .50922 L .48572 .51191 L p .707 .577 .707 r
F P
0 g
s
.48388 .67265 m .49477 .64417 L p .49861 .65281 L .707 .577 .707 r
F P
0 g
s
.49659 .63939 m .48388 .67265 L .47266 .65716 L p .707 .577 .707 r
F P
0 g
s
.48805 .67054 m .48513 .65455 L p .49687 .65569 L .707 .577 .707 r
F P
0 g
s
.48513 .65455 m .48466 .65198 L .48689 .65266 L p .707 .577 .707 r
F P
0 g
s
.48689 .65266 m .49687 .65569 L p .48513 .65455 L .707 .577 .707 r
F P
0 g
s
.49477 .64417 m .49659 .63939 L .49696 .64181 L p .707 .577 .707 r
F P
0 g
s
.49696 .64181 m .49861 .65281 L p .49477 .64417 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49952 .66155 m .50291 .68011 L .50026 .67425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30229 .71235 m .2989 .6938 L .30607 .68636 L p .707 .577 .707 r
F P
0 g
s
.47372 .50922 m .48634 .56459 L .46603 .56468 L p .707 .577 .707 r
F P
0 g
s
.46603 .56468 m .45341 .50931 L .47372 .50922 L p .707 .577 .707 r
F P
0 g
s
.30607 .68636 m .30946 .70491 L .30229 .71235 L p .707 .577 .707 r
F P
0 g
s
.47266 .65716 m .48142 .63425 L p .49659 .63939 L .707 .577 .707 r
F P
0 g
s
.48538 .6239 m .47266 .65716 L .45334 .64113 L p .707 .577 .707 r
F P
0 g
s
.46747 .66934 m .46409 .65081 L p .48466 .65198 L .707 .577 .707 r
F P
0 g
s
.46409 .65081 m .46408 .65079 L .46412 .65079 L p .707 .577 .707 r
F P
0 g
s
.46412 .65079 m .48466 .65198 L p .46409 .65081 L .707 .577 .707 r
F P
0 g
s
.48142 .63425 m .48538 .6239 L .48819 .62778 L p .707 .577 .707 r
F P
0 g
s
.48819 .62778 m .49659 .63939 L p .48142 .63425 L .707 .577 .707 r
F P
0 g
s
.49687 .65569 m .50026 .67425 L .48805 .67054 L p .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .35315 .56731 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .32293 .58653 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32998 .56808 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .32549 .59778 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .34759 .58186 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .34759 .58186 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34917 .5888 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .31727 .60134 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34044 .60057 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .32293 .58653 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .33654 .53342 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31287 .54241 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.45341 .50931 m .46603 .56468 L .4394 .56755 L p .707 .577 .707 r
F P
0 g
s
.4394 .56755 m .42677 .51217 L .45341 .50931 L p .707 .577 .707 r
F P
0 g
s
.30946 .70491 m .30607 .68636 L .32235 .67807 L p .707 .577 .707 r
F P
0 g
s
.45334 .64113 m .46605 .60787 L .48538 .6239 L p .707 .577 .707 r
F P
0 g
s
.32235 .67807 m .32574 .69662 L .30946 .70491 L p .707 .577 .707 r
F P
0 g
s
.48466 .65198 m .48805 .67054 L .46747 .66934 L p .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .38116 .57153 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .34759 .58186 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .35315 .56731 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .34917 .5888 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .37791 .58002 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .37791 .58002 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .37796 .58022 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .34044 .60057 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36844 .6048 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .34759 .58186 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .36533 .52485 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .33654 .53342 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.42677 .51217 m .4394 .56755 L .40905 .5729 L p .707 .577 .707 r
F P
0 g
s
.40905 .5729 m .39643 .51753 L .42677 .51217 L p .707 .577 .707 r
F P
0 g
s
.46605 .60787 m .45334 .64113 L .4278 .62612 L p .707 .577 .707 r
F P
0 g
s
.4278 .62612 m .44051 .59285 L .46605 .60787 L p .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .41126 .58033 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .37791 .58002 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .38116 .57153 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.39643 .51753 m .40905 .5729 L .37796 .58022 L p .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .37791 .58002 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .39643 .51753 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36533 .52485 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.32574 .69662 m .32235 .67807 L .34616 .66974 L p .707 .577 .707 r
F P
0 g
s
.34616 .66974 m .34955 .68829 L .32574 .69662 L p .707 .577 .707 r
F P
0 g
s
.44051 .59285 m .4278 .62612 L .39855 .6136 L p .707 .577 .707 r
F P
0 g
s
.39855 .6136 m .41126 .58033 L .44051 .59285 L p .707 .577 .707 r
F P
0 g
s
.46408 .65079 m .46747 .66934 L .44055 .67078 L p .707 .577 .707 r
F P
0 g
s
.44055 .67078 m .43716 .65222 L .46408 .65079 L p .707 .577 .707 r
F P
0 g
s
.41126 .58033 m .39855 .6136 L .36844 .6048 L p .707 .577 .707 r
F P
0 g
s
.34955 .68829 m .34616 .66974 L .37516 .66219 L p .707 .577 .707 r
F P
0 g
s
.37516 .66219 m .37855 .68074 L .34955 .68829 L p .707 .577 .707 r
F P
0 g
s
.43716 .65222 m .44055 .67078 L .40991 .67471 L p .707 .577 .707 r
F P
0 g
s
.40991 .67471 m .40652 .65615 L .43716 .65222 L p .707 .577 .707 r
F P
0 g
s
.37855 .68074 m .37516 .66219 L .40652 .65615 L p .707 .577 .707 r
F P
0 g
s
.40652 .65615 m .40991 .67471 L .37855 .68074 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH6
0003FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF1@001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0009JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000<000MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0069oo`@00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005ioo`@0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05aoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol005Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00F7oo0P001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05Ioo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000XOol;000cOol005Aoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000POol80003FUH0
0`00FUIJEP03FUH01000FUH00000<Goo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000IOol70003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool0059oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8001Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P004Goo10001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP/00005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000?Ool200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool0059oo`800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`<000=JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P001UYF00<005YFFUH015YF00<005YF
FUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0009Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00
0080009JEP05001JEUYFFUH00008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
02moo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005Ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
00IJEP03001JEUYF00EJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP03FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002io
o`00EGoo0P000eYF00@005YFFUIJEP@000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00D7oo1P000UYF1`00
0eYF10000UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@002eoo`00C7oo10000UYF00<0
05YF00001@0015YF00<005YFFUH01EYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<007ooOol0:goo0017Ool50006FUH01@00FUH005YF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000]Ool004=oo`@0009JEP03001JEUYF00MJEP@000=JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPH000UJEP03001JEUYF00EJEP04001JEUYF0009
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00;Woo000oOol40006FUH00`00FUIJEP07FUH00`00FUH00002
0003FUH20002FUH00`00FUIJEP02FUH80002FUH01000FUIJEUYF0P001UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH30007FUH00`00FUH00008FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003]oo`@00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEP00009JEP<0009JEPP00003FUH0000000IJEP03001JEUYF00=JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP<000QJEP03001JEUYF00EJEP04001JEP00000`Ool003Moo`@000EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF009JEP800006FUH005YFFUH005YF0P001UYF00<0
05YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP<0039o
o`00=Goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00@005YFFUH0
00AJEP80009JEP04001JEP000006FUH40005FUH30008FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH2000eOol003=oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP04001JEUYF0004FUH300000eYF001JEP020006FUH50004FUH00`00FUIJEP020005FUH00`00FUIJ
EP04FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000eYF00@005YF000003Moo`00<Goo0P001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH200000eYF00000005FUH6
0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP08FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00MJEPH003Uoo`00;goo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000EJEPH000AJ
EP03001JEUYF00AJEP<000MJEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000=JEP/000AJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2000jOol002eoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH00`00FUIJEP04FUH20006FUH00`00FUH000020005FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF00000005FUH00`00FUIJEP03FUH60007FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000hOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP07FUH00`00FUIJEP07FUH20004FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00Oomoo`0eOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01eYF00<005YFFUH025YF
0`000UYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00D005YFFUIJEP0000MJEP03001JEUYF00=JEP<00003FUH005YF00QJEP03
001JEUYF00IJEP<003Eoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30009FUHE000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH015YF00@005YFFUH000MJEP03001JEUYF00@0009oo`<000QJEP03001JEUYF00EJ
EP05001JEUYFFUH0000dOol002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH01EYF
2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJEP00001JEP00009JEP04001JEUYF0003
FUH60009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH00003FUH00000
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
0P000eYF200047oo0`0000=JEP00FUH01eYF00<005YFFUH015YF00<007ooOol0;goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00Oomoo`0AOol20007FUH00`00
FUIJEP05FUH00`00Oomoo`0_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP02FUH20006FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF0P000eYF00<007ooOol027oo0`00
27oo0P001EYF00<005YFFUH015YF00<005YF0000<7oo000/Ool01000FUIJEP000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01@000eYF00<005YFFUH01UYF00<005YFFUH015YF1P001EYF
00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0`000UYF00<007ooOol01goo1@002Goo0P000eYF
00<005YFFUH01eYF00<007ooOol0;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH30006FUH200000eYF001JEP06FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJ
EP04FUH70007FUH00`00FUIJEP04FUH01000FUH005YF1@0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF00@005YFFUIJEP<000Uoo`D000]oo`<000IJ
EP80009JEP03001oogoo02eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YF
FUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0002FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001UYF00<005YFFUH00eYF
0P0027oo1@003Goo00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;7oo000]Ool01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF
00@005YF000000MJEP03001JEUYF00AJEP@00004FUH000000004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUIJEP00FUH00P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF100025YF00<005YFFUH01EYF0P001goo0`003goo00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0;7oo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00001JEP0000MJEP03001JEUYF00@000=JEPH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200001EYF000005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01eYF0`00
67oo00D005YFFUIJEP0000AJEP8002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH0
1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YFFUH0000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH20004FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0037oo500000=JEP00Ool0;7oo000^Ool20003FUH01000FUIJEUYF10001eYF00<0
05YFFUH01UYF00<005YFFUH01eYF0`0015YF00@005YFFUIJEP800005Ool005YFFUH00004FUH80002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP0000QJEP03001JEUYF
00=JEP8000=oo`L000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002eoo`00;Woo
00<005YFFUH01`000eYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUH000AJEP04
001JEP000003Ool01000FUIJEP001UYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF100025YF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH5
0007FUH00`00FUIJEP06FUH01000FUIJEP000eYF0`001Goo00@005YFFUH000AJEPd000AJEP03001J
EUYF00AJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00002FUH01P00FUIJEUYFOol0
00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP05001JEUYF001JEP020002FUH00`00Oomo
o`03Ool80004FUH00`00FUIJEP06FUH=000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20005FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000/Ool40003FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH200000eYF0000000:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUH000020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0002FUH00`00Oomoo`0[Ool002ao
o`04001JEP000004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP040004Ool20006FUH01000FUH0
00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH010000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0015YF00<005YFFUH015YF0`002EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00D005YFFUH005YF00@002aoo`00;7oo00<005YF00000eYF0P000UYF3@002Woo0P0015YF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF009JEP80009JEP03001JEUYF00MJEP03001JEUYF009JEPT00003OomJ
EUYF009JEP8000EJEP04001JEUYFFUH300000eYF0000000/Ool002aoo`03001oo`0000=JEP03001J
EUYF009JEP8001Ioo`800004FUH005YFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUH000020004FUH00`00FUIJEP06FUH80004
FUH01000FUIJEWoo15YF0P001EYF00@005YFFUIJEP8000=JEP03001oogoo02Yoo`00;Goo00D005YF
FUIJEP00009JEP03OomJEUYF009JEP03001oogoo01Eoo`8000=JEP80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPL000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP800003FUH005YF00EJ
EP03001JEUYF009JEP<0009JEP03001JEP0000@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF008002eoo`00;Goo00D005YFFUIJEP00009JEP03OomJEUYF009JEP<0
00aoo`<000Qoo`8000=JEQ@00003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJ
EP03001JEP0000D00004FUH005YFFUH50003FUH01@00FUIJEUYFOol00UYF0P001EYF00@005YFFUIJ
EP80009JEP03001oogoo02aoo`00;Woo00@005YFFUH0009JEP05OomJEUYFFUH00003FUH00`00Oomo
o`08Ool50009Ool20003FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP02FUH30006Ool300000eYF0000
00030002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8002moo`00;Woo00@0
05YFFUH000IJEP03001JEUYF009JEP03001oogoo00Moo`D000]oo`<000MJEP03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEP000080
00aoo`D000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000aOol002moo`8000IJ
EP03001JEUYF00AJEP8000Moo`D000eoo`03001JEUYF00AJEP800005FUH005YFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH01000FUIJEUYF0`004Woo0`0000=JEP00FUH01eYF00<0
05YFFUH00eYF00<005YFFUH00P00<goo000`Ool00`00FUIJEP04FUH00`00FUIJEP06FUH20006Ool3
000?Ool00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00H005YF000005YF000>Ool700000eYF000000030004FUH00`00FUIJEP03FUH0
1000FUH00000=Goo000aOol00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000005goo00<005YF
00000UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF01@000=JEP03001JEUYF00IJEPd003Moo`00<Woo00D005YFFUIJEP0000QJEP03001JEUYF
009JEP<000Yooa<0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEQT000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol003=oo`04001JEUYF0008
FUH00`00FUIJEP05FUH:0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00
@7oo000dOol20009FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040015Ool003Eo
o`03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH00UYF1P00BGoo000fOol20006FUH400000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF0`000eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YF
FUH00UYF0`000eYF5000Cgoo000hOol60005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH@0002FUH0
0`00FUH000030006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH300000eYF001JEP03FUH200000goo00000003FUH00`00FUIJEP07FUH00`00
Oomoo`1DOol003Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP04001JEP000002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000goo0`00
1eYF00@005YFFUH005Ioo`00=7oo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF20001eYF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP8000Eoo`03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05=oo`00<goo0P001eYF00<005YF
FUH015YF200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF10001Woo00<005YFFUH00eYF00<005YFFUH00UYF00<007oo
Ool0Dgoo000aOol200000eYF001JEP06FUH00`00FUIJEP040003FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000
00Moo`05001JEUYFFUH00004FUH2001EOol0031oo`05001JEUYFFUH00006FUH40003Ool200000eYF
001JEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000400000AJEP00FUH005Aoo`00;Woo0`0015YF
00@005YFFUIJEP8000Uoo`P0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020007FUH00`00FUIJEP03
FUH5001DOol002eoo`04001JEUYF0004FUH01000FUH000003Woo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF0080
00MJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo00@005YFFUH000=JEP<000moo`/000AJ
EP03001JEUYF00AJEP03001JEUYF00<000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP05001JEP00FUH00008FUH00`00FUIJEP02FUH00`00FUIJEP02001DOol002eoo`05001JEUYF
001JEP02000>Ool40002FUH00`00FUIJEP06FUH?0006Ool01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Aoo`00;Woo00<005YF0000
4@001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002goo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH00UYF1P000eYF00@005YFFUH005Aoo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0100047oo0P001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00002@000eYF1P0000=JEP000000Dgoo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000EOol20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF100000=ooeYFFUH00eYF00<005YFFUH00eYF0P000UYF1P00Dgoo000^Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000
FUH0009JEP03OomJEUYF009JEP8000EJEP04001JEUYFFUH20003FUH00`00Oomoo`1AOol002moo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Aoo`D000QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000=JEP03001JEUYF00EJEP03
001JEUYF00=JEP8000=JEP03001JEUYF008005Aoo`00<Goo5000<7oo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02@000eYF00D005YFFUIJEWoo00=JEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00Oomoo`1COol007]oo`T000IJEP03001JEUYF00UJEP03
001JEUYF00AJEP/00003FUH0000000<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF
FUH005YF0P00EWoo0024OolI000;Ool60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`00F7oo002?Ool01000FUIJEP000eYF0`004Goo100000=JEP00FUH01eYF00<005YFFUH00eYF
00<005YFFUH00P00FWoo002?Ool01@00FUIJEP00FUH00P0047oo1`0000=JEP0000000`0015YF00<0
05YFFUH00eYF00@005YF000005aoo`00Sgoo00<005YFFUH050000eYF00<005YFFUH01UYF3@00GWoo
002@Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04001SOol0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEPD006Moo`00T7oo0P000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01000K7oo002AOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
001`Ool009=oo`@000=JEP03001JEUYF009JEPP007Ioo`00Ugoo2000OWoo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59966 .7419 m .58703 .68652 L .55669 .69188 L p .707 .577 .707 r
F P
0 g
s
.58703 .68652 m .59966 .7419 L .63075 .73457 L p .707 .577 .707 r
F P
0 g
s
.63075 .73457 m .61812 .6792 L .58703 .68652 L p .707 .577 .707 r
F P
0 g
s
.61812 .6792 m .63075 .73457 L .65954 .726 L p .707 .577 .707 r
F P
0 g
s
.65954 .726 m .64691 .67063 L .61812 .6792 L p .707 .577 .707 r
F P
0 g
s
.56931 .74725 m .55669 .69188 L .53005 .69474 L p .707 .577 .707 r
F P
0 g
s
.55669 .69188 m .56931 .74725 L .59966 .7419 L p .707 .577 .707 r
F P
0 g
s
.64691 .67063 m .65954 .726 L .68321 .71702 L p .707 .577 .707 r
F P
0 g
s
.68321 .71702 m .67059 .66164 L .64691 .67063 L p .707 .577 .707 r
F P
0 g
s
.53005 .69474 m .54268 .75011 L .56931 .74725 L p .707 .577 .707 r
F P
0 g
s
.58697 .81857 m .59968 .78531 L .57043 .77279 L p .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .62906 .82137 L .59874 .82721 L p .707 .577 .707 r
F P
0 g
s
.59874 .82721 m .59771 .82741 L p .59827 .82761 L .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .59874 .82721 L .59827 .82761 L .707 .577 .707 r
F
.63245 .83992 m .66145 .83237 L p .63217 .82242 L F P
0 g
s
.62906 .82137 m .62964 .8245 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.62964 .8245 m .63245 .83992 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .65807 .81382 L .62906 .82137 L p .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .68526 .82404 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65807 .81382 m .65941 .82117 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65941 .82117 m .66145 .83237 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .68187 .80549 L .67028 .80954 L p .707 .577 .707 r
F P
0 g
s
.67028 .80954 m .65807 .81382 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .67028 .80954 L .66415 .8161 L .707 .577 .707 r
F
.68187 .80549 m .68526 .82404 L .70155 .81575 L p F P
0 g
s
.70155 .81575 m .69816 .7972 L .68187 .80549 L p .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .69703 .79188 L .68174 .79729 L p .707 .577 .707 r
F P
0 g
s
.68174 .79729 m .68096 .79757 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .68174 .79729 L .68102 .79806 L .707 .577 .707 r
F
.66825 .83083 m .68431 .82514 L p .68102 .79806 L F P
0 g
s
.68096 .79757 m .6806 .79851 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.6806 .79851 m .66825 .83083 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .66825 .83083 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65779 .79833 m .65606 .80285 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65606 .80285 m .64508 .8316 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .64508 .8316 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62978 .79411 m .62593 .8042 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62593 .8042 m .61707 .82737 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.59968 .78531 m .58697 .81857 L .61707 .82737 L p .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .62978 .79411 L .59968 .78531 L p .707 .577 .707 r
F P
0 g
s
.55771 .80605 m .57043 .77279 L .54489 .75778 L p .707 .577 .707 r
F P
0 g
s
.57043 .77279 m .55771 .80605 L .58697 .81857 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53005 .69474 L .50974 .69483 L p .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .65779 .79833 L .62978 .79411 L p .707 .577 .707 r
F P
0 g
s
.67059 .66164 m .68321 .71702 L .69945 .7085 L p .707 .577 .707 r
F P
0 g
s
.69945 .7085 m .68683 .65313 L .67059 .66164 L p .707 .577 .707 r
F P
0 g
s
.6011 .84596 m .59771 .82741 L .56707 .83133 L p .707 .577 .707 r
F P
0 g
s
.59771 .82741 m .6011 .84596 L .63245 .83992 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53556 .73816 L .52235 .75015 L .707 .577 .707 r
F
.50974 .69483 m .52235 .75015 L p .53556 .73816 L F P
0 g
s
.50974 .69483 m .49774 .69214 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.5225 .7502 m .54268 .75011 L p .52235 .75015 L .707 .577 .707 r
F P
0 g
s
.51285 .77501 m .53218 .79104 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52556 .74174 m .52235 .75015 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .51285 .77501 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.51336 .75831 m .52038 .74878 L .5138 .74419 L .707 .577 .707 r
F
.51285 .77501 m .52235 .75015 L p .51336 .75831 L F P
0 g
s
.52234 .75014 m .52224 .74992 L .52193 .74985 L .707 .577 .707 r
F
.49774 .69214 m .50041 .70384 L p .52224 .74992 L F P
0 g
s
.52235 .75015 m .52038 .74878 L .51336 .75831 L .707 .577 .707 r
F
.50041 .70384 m .50882 .74073 L p .51494 .73452 L F P
0 g
s
.49774 .69214 m .49522 .68694 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50163 .75952 m .50882 .74073 L p .50507 .74452 L .707 .577 .707 r
F P
0 g
s
.50882 .74073 m .49774 .69214 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50835 .73946 m .50508 .72636 L .50531 .7312 L .707 .577 .707 r
F
.49522 .68694 m .50531 .7312 L p .50508 .72636 L F P
0 g
s
.50882 .74073 m .50805 .73865 L .50507 .74452 L .707 .577 .707 r
F
.50507 .74452 m .50805 .73865 L .50704 .73591 L F
.49962 .7461 m .50163 .75952 L p .50335 .75202 L F P
0 g
s
.51233 .71283 m .50531 .7312 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .49962 .7461 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.49522 .68694 m .50244 .67972 L p .50613 .72249 L .707 .577 .707 r
F P
0 g
s
.50737 .73679 m .50785 .74231 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51435 .72626 m .51233 .71283 L p .50704 .73591 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .50974 .69483 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.51233 .71283 m .51972 .70279 L p .50827 .72745 L .707 .577 .707 r
F P
0 g
s
.50805 .73865 m .51435 .72626 L .50704 .73591 L .707 .577 .707 r
F
.50785 .74231 m .50531 .7312 L p .50673 .7294 L F P
0 g
s
.50688 .72921 m .51233 .71283 L .50827 .72745 L .707 .577 .707 r
F
.50882 .74073 m .51435 .72626 L p .50805 .73865 L F P
0 g
s
.50882 .74073 m .50163 .75952 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.50785 .74231 m .51036 .74752 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .50882 .74073 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .51494 .73452 L .50882 .74073 L .707 .577 .707 r
F
.50163 .75952 m .51285 .77501 L p .5138 .74419 L F P
0 g
s
.50882 .74073 m .51036 .74752 L p .52193 .74985 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .50882 .74073 L .52193 .74985 L .707 .577 .707 r
F
.51435 .72626 m .50882 .74073 L p .5138 .74419 L F P
0 g
s
.52556 .74174 m .51435 .72626 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .50785 .74231 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .51233 .71283 L p .50688 .72921 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51506 .73509 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .51219 .72249 L p .49962 .7461 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .50701 .73605 L .49982 .74582 L p .707 .577 .707 r
F P
0 g
s
.49982 .74582 m .49962 .7461 L p .51219 .72249 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .53578 .6971 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .51219 .72249 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51972 .70279 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .51506 .73509 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .52877 .71546 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .52877 .71546 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .5313 .72658 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .50701 .73605 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .52307 .73036 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.50701 .73605 m .51219 .72249 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51586 .72093 m .51219 .72249 L .5162 .71492 L .707 .577 .707 r
F
.50244 .67972 m .51868 .6712 L p .5162 .71492 L F P
0 g
s
.51219 .72249 m .50244 .67972 L p .5162 .71492 L .707 .577 .707 r
F P
0 g
s
.50244 .67972 m .51219 .72249 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .50688 .72921 L .50543 .73358 L .707 .577 .707 r
F
.50543 .73358 m .50688 .72921 L .50827 .72745 L F
.50673 .7294 m .50531 .7312 L .50613 .72249 L F
.50531 .7312 m .49522 .68694 L p .50613 .72249 L F P
0 g
s
.49962 .7461 m .50531 .7312 L p .50543 .73358 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52556 .74174 L p .52038 .74878 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .52237 .75021 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.52234 .75014 m .52193 .74985 L .51036 .74752 L .707 .577 .707 r
F
.52237 .75021 m .52235 .75015 L p .52234 .75014 L F P
0 g
s
.52038 .74878 m .52556 .74174 L .5138 .74419 L .707 .577 .707 r
F
.54489 .75778 m .52556 .74174 L p .52692 .75187 L F P
0 g
s
.53218 .79104 m .5446 .75854 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.5446 .75854 m .54489 .75778 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52237 .75021 L .5225 .7502 L p .707 .577 .707 r
F P
0 g
s
.54489 .75778 m .53218 .79104 L .55771 .80605 L p .707 .577 .707 r
F P
0 g
s
.56707 .83133 m .57046 .84989 L .6011 .84596 L p .707 .577 .707 r
F P
0 g
s
.57046 .84989 m .56707 .83133 L .54015 .83277 L p .707 .577 .707 r
F P
0 g
s
.66825 .83083 m .68096 .79757 L .65779 .79833 L p .707 .577 .707 r
F P
0 g
s
.54015 .83277 m .54353 .85133 L .57046 .84989 L p .707 .577 .707 r
F P
0 g
s
.68683 .65313 m .69945 .7085 L .70666 .70128 L p .707 .577 .707 r
F P
0 g
s
.70666 .70128 m .69404 .64591 L .68683 .65313 L p .707 .577 .707 r
F P
0 g
s
.54353 .85133 m .54015 .83277 L .51957 .83158 L p .707 .577 .707 r
F P
0 g
s
.51957 .83158 m .52296 .85013 L .54353 .85133 L p .707 .577 .707 r
F P
0 g
s
.52296 .85013 m .51957 .83158 L .50736 .82787 L p .707 .577 .707 r
F P
0 g
s
.69404 .64591 m .70666 .70128 L .70415 .69608 L p .707 .577 .707 r
F P
0 g
s
.70415 .69608 m .69152 .6407 L .69404 .64591 L p .707 .577 .707 r
F P
0 g
s
.50736 .82787 m .51075 .84642 L .52296 .85013 L p .707 .577 .707 r
F P
0 g
s
.69703 .79188 m .68431 .82514 L .6917 .8151 L p .707 .577 .707 r
F P
0 g
s
.70155 .81575 m .70871 .80831 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.69816 .7972 m .70084 .8119 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70084 .8119 m .70155 .81575 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70871 .80831 m .70533 .78976 L .69816 .7972 L p .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .70405 .78278 L p .69703 .79188 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .70441 .78183 L .70405 .78232 L p .707 .577 .707 r
F P
0 g
s
.70405 .78232 m .69703 .79188 L p .70405 .78278 L .707 .577 .707 r
F P
0 g
s
.70606 .80245 m .70402 .79124 L p .70533 .78976 L .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .68969 .80167 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .6917 .8151 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.68969 .80167 m .70067 .77293 L p .70441 .78183 L .707 .577 .707 r
F P
0 g
s
.70067 .77293 m .7024 .76841 L .70274 .7707 L p .707 .577 .707 r
F P
0 g
s
.70274 .7707 m .70441 .78183 L p .70067 .77293 L .707 .577 .707 r
F P
0 g
s
.7024 .76841 m .68969 .80167 L .67847 .78619 L p .707 .577 .707 r
F P
0 g
s
.69385 .79874 m .69104 .78331 L p .70267 .78389 L .707 .577 .707 r
F P
0 g
s
.69104 .78331 m .69046 .78018 L .69317 .78101 L p .707 .577 .707 r
F P
0 g
s
.69317 .78101 m .70267 .78389 L p .69104 .78331 L .707 .577 .707 r
F P
0 g
s
.70402 .79124 m .70267 .78389 L .70403 .7869 L p .707 .577 .707 r
F P
0 g
s
.70403 .7869 m .70533 .78976 L p .70402 .79124 L .707 .577 .707 r
F P
0 g
s
.70441 .78183 m .70405 .78278 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.48594 .82192 m .49262 .3208 L .44862 .31753 L p .707 .577 .707 r
F P
0 g
s
.51075 .84642 m .50736 .82787 L .50471 .822 L p .707 .577 .707 r
F P
0 g
s
.50471 .822 m .5081 .84056 L .51075 .84642 L p .707 .577 .707 r
F P
0 g
s
.5081 .84056 m .50471 .822 L .51187 .81456 L p .707 .577 .707 r
F P
0 g
s
.51187 .81456 m .51526 .83312 L .5081 .84056 L p .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .55895 .69633 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .53578 .6971 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .54235 .66222 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .52877 .71546 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .51868 .6712 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .5313 .72658 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .55342 .7108 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .55342 .7108 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55497 .71759 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .52307 .73036 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54624 .7296 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .52877 .71546 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51526 .83312 m .51187 .81456 L .52816 .80627 L p .707 .577 .707 r
F P
0 g
s
.52816 .80627 m .53155 .82482 L .51526 .83312 L p .707 .577 .707 r
F P
0 g
s
.53155 .82482 m .52816 .80627 L .55197 .79794 L p .707 .577 .707 r
F P
0 g
s
.49262 .3208 m .48594 .82192 L .53088 .82136 L p .707 .577 .707 r
F P
0 g
s
.53088 .82136 m .53757 .32024 L .49262 .3208 L p .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .58696 .70056 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55895 .69633 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .57114 .65365 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .55342 .7108 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54235 .66222 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .55497 .71759 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .58375 .70896 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .58375 .70896 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58376 .70902 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .54624 .7296 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57425 .73382 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .55342 .7108 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55197 .79794 m .55536 .8165 L .53155 .82482 L p .707 .577 .707 r
F P
0 g
s
.55536 .8165 m .55197 .79794 L .58097 .79039 L p .707 .577 .707 r
F P
0 g
s
.58097 .79039 m .58436 .80894 L .55536 .8165 L p .707 .577 .707 r
F P
0 g
s
.53757 .32024 m .53088 .82136 L .57236 .81702 L p .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58696 .70056 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .60223 .64632 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .58375 .70896 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57114 .65365 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .61707 .70936 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.60223 .64632 m .61485 .7017 L .58376 .70902 L p .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .58375 .70896 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57236 .81702 m .57904 .31589 L .53757 .32024 L p .707 .577 .707 r
F P
0 g
s
.44193 .81865 m .44862 .31753 L .40986 .31073 L p .707 .577 .707 r
F P
0 g
s
.44862 .31753 m .44193 .81865 L .48594 .82192 L p .707 .577 .707 r
F P
0 g
s
.69152 .6407 m .70415 .69608 L .69214 .69339 L p .707 .577 .707 r
F P
0 g
s
.69214 .69339 m .67952 .63801 L .69152 .6407 L p .707 .577 .707 r
F P
0 g
s
.61707 .70936 m .60435 .74262 L .57425 .73382 L p .707 .577 .707 r
F P
0 g
s
.58436 .80894 m .58097 .79039 L .61232 .78435 L p .707 .577 .707 r
F P
0 g
s
.61232 .78435 m .61571 .80291 L .58436 .80894 L p .707 .577 .707 r
F P
0 g
s
.57904 .31589 m .57236 .81702 L .60631 .80931 L p .707 .577 .707 r
F P
0 g
s
.61485 .7017 m .60223 .64632 L .63258 .64097 L p .707 .577 .707 r
F P
0 g
s
.64632 .72188 m .63361 .75514 L .60435 .74262 L p .707 .577 .707 r
F P
0 g
s
.60435 .74262 m .61707 .70936 L .64632 .72188 L p .707 .577 .707 r
F P
0 g
s
.60631 .80931 m .613 .30819 L .57904 .31589 L p .707 .577 .707 r
F P
0 g
s
.70533 .78976 m .70871 .80831 L .70606 .80245 L p .707 .577 .707 r
F P
0 g
s
.40317 .81185 m .40986 .31073 L .38014 .30108 L p .707 .577 .707 r
F P
0 g
s
.40986 .31073 m .40317 .81185 L .44193 .81865 L p .707 .577 .707 r
F P
0 g
s
.25665 .70514 m .24402 .64977 L .21368 .65512 L p .707 .577 .707 r
F P
0 g
s
.24402 .64977 m .25665 .70514 L .28774 .69782 L p .707 .577 .707 r
F P
0 g
s
.28774 .69782 m .27511 .64244 L .24402 .64977 L p .707 .577 .707 r
F P
0 g
s
.27511 .64244 m .28774 .69782 L .31653 .68924 L p .707 .577 .707 r
F P
0 g
s
.31653 .68924 m .30391 .63387 L .27511 .64244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2263 .71049 m .21368 .65512 L .18704 .65799 L p .707 .577 .707 r
F P
0 g
s
.21368 .65512 m .2263 .71049 L .25665 .70514 L p .707 .577 .707 r
F P
0 g
s
.30391 .63387 m .31653 .68924 L .3402 .68026 L p .707 .577 .707 r
F P
0 g
s
.3402 .68026 m .32758 .62489 L .30391 .63387 L p .707 .577 .707 r
F P
0 g
s
.67952 .63801 m .69214 .69339 L .67183 .69348 L p .707 .577 .707 r
F P
0 g
s
.67183 .69348 m .65921 .63811 L .67952 .63801 L p .707 .577 .707 r
F P
0 g
s
.63258 .64097 m .6452 .69634 L .61485 .7017 L p .707 .577 .707 r
F P
0 g
s
.64296 .78042 m .64635 .79898 L .61571 .80291 L p .707 .577 .707 r
F P
0 g
s
.61571 .80291 m .61232 .78435 L .64296 .78042 L p .707 .577 .707 r
F P
0 g
s
.613 .30819 m .60631 .80931 L .62942 .79901 L p .707 .577 .707 r
F P
0 g
s
.62942 .79901 m .63611 .29788 L .613 .30819 L p .707 .577 .707 r
F P
0 g
s
.67847 .78619 m .68733 .76301 L p .7024 .76841 L .707 .577 .707 r
F P
0 g
s
.69118 .75292 m .67847 .78619 L .65915 .77015 L p .707 .577 .707 r
F P
0 g
s
.67328 .79754 m .67 .77957 L p .69046 .78018 L .707 .577 .707 r
F P
0 g
s
.67 .77957 m .66989 .77899 L .67057 .77903 L p .707 .577 .707 r
F P
0 g
s
.67057 .77903 m .69046 .78018 L p .67 .77957 L .707 .577 .707 r
F P
0 g
s
.68733 .76301 m .69118 .75292 L .69392 .75671 L p .707 .577 .707 r
F P
0 g
s
.69392 .75671 m .7024 .76841 L p .68733 .76301 L .707 .577 .707 r
F P
0 g
s
.18704 .65799 m .19967 .71336 L .2263 .71049 L p .707 .577 .707 r
F P
0 g
s
.24396 .78159 m .25667 .74832 L .22742 .7358 L p .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .28606 .78521 L .25475 .79123 L p .707 .577 .707 r
F P
0 g
s
.25475 .79123 m .2547 .79124 L p .25473 .79125 L .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .25475 .79123 L .25473 .79125 L .707 .577 .707 r
F
.28944 .80376 m .31845 .79621 L p .28861 .78607 L F P
0 g
s
.28606 .78521 m .28653 .78778 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.28653 .78778 m .28944 .80376 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .31506 .77765 L .28606 .78521 L p .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .34225 .78788 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.31506 .77765 m .3163 .78445 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.3163 .78445 m .31845 .79621 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .33887 .76933 L .32635 .7737 L p .707 .577 .707 r
F P
0 g
s
.32635 .7737 m .31506 .77765 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .32635 .7737 L .32068 .77977 L .707 .577 .707 r
F
.33887 .76933 m .34225 .78788 L .35854 .77959 L p F P
0 g
s
.35854 .77959 m .35515 .76103 L .33887 .76933 L p .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .35402 .7549 L .33895 .76023 L p .707 .577 .707 r
F P
0 g
s
.33895 .76023 m .33795 .76058 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .33895 .76023 L .33803 .76121 L .707 .577 .707 r
F
.32524 .79385 m .34131 .78816 L p .33803 .76121 L F P
0 g
s
.33795 .76058 m .33749 .76179 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.33749 .76179 m .32524 .79385 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .32524 .79385 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31478 .76135 m .31295 .76613 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31295 .76613 m .30207 .79461 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .30207 .79461 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28677 .75713 m .28282 .76748 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28282 .76748 m .27406 .79039 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.25667 .74832 m .24396 .78159 L .27406 .79039 L p .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .28677 .75713 L .25667 .74832 L p .707 .577 .707 r
F P
0 g
s
.70267 .78389 m .70606 .80245 L .69385 .79874 L p .707 .577 .707 r
F P
0 g
s
.21471 .76907 m .22742 .7358 L .20188 .72079 L p .707 .577 .707 r
F P
0 g
s
.22742 .7358 m .21471 .76907 L .24396 .78159 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .18704 .65799 L .16673 .65808 L p .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .31478 .76135 L .28677 .75713 L p .707 .577 .707 r
F P
0 g
s
.37345 .80221 m .38014 .30108 L .36236 .28953 L p .707 .577 .707 r
F P
0 g
s
.38014 .30108 m .37345 .80221 L .40317 .81185 L p .707 .577 .707 r
F P
0 g
s
.32758 .62489 m .3402 .68026 L .35644 .67174 L p .707 .577 .707 r
F P
0 g
s
.35644 .67174 m .34382 .61637 L .32758 .62489 L p .707 .577 .707 r
F P
0 g
s
.25809 .8098 m .2547 .79124 L .22406 .79517 L p .707 .577 .707 r
F P
0 g
s
.2547 .79124 m .25809 .8098 L .28944 .80376 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .19248 .70129 L .17931 .71325 L .707 .577 .707 r
F
.16673 .65808 m .17931 .71325 L p .19248 .70129 L F P
0 g
s
.16673 .65808 m .15473 .65539 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17984 .71345 m .19967 .71336 L p .17931 .71325 L .707 .577 .707 r
F P
0 g
s
.16984 .73802 m .18917 .75406 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.18255 .70476 m .17931 .71325 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16984 .73802 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17035 .72138 m .17733 .71187 L .17078 .70731 L .707 .577 .707 r
F
.16984 .73802 m .17931 .71325 L p .17035 .72138 L F P
0 g
s
.17925 .71321 m .17893 .71246 L .17797 .71231 L .707 .577 .707 r
F
.15473 .65539 m .15737 .66694 L p .17893 .71246 L F P
0 g
s
.17931 .71325 m .17733 .71187 L .17035 .72138 L .707 .577 .707 r
F
.15737 .66694 m .16577 .70383 L p .1719 .69762 L F P
0 g
s
.15473 .65539 m .15221 .65018 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.15862 .72253 m .16577 .70383 L p .16205 .7076 L .707 .577 .707 r
F P
0 g
s
.16577 .70383 m .15473 .65539 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.1653 .70253 m .16204 .68948 L .16227 .6943 L .707 .577 .707 r
F
.15221 .65018 m .16227 .6943 L p .16204 .68948 L F P
0 g
s
.16577 .70383 m .16501 .70175 L .16205 .7076 L .707 .577 .707 r
F
.16205 .7076 m .16501 .70175 L .16401 .69903 L F
.15661 .70911 m .15862 .72253 L p .1603 .71522 L F P
0 g
s
.16932 .67585 m .16227 .6943 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .15661 .70911 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.15221 .65018 m .15943 .64296 L p .1631 .68548 L .707 .577 .707 r
F P
0 g
s
.16435 .69996 m .16484 .70555 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17134 .68927 m .16932 .67585 L p .16401 .69903 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16673 .65808 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.16932 .67585 m .17671 .6658 L p .16521 .69057 L .707 .577 .707 r
F P
0 g
s
.16501 .70175 m .17134 .68927 L .16401 .69903 L .707 .577 .707 r
F
.16484 .70555 m .16227 .6943 L p .16371 .69248 L F P
0 g
s
.16383 .69232 m .16932 .67585 L .16521 .69057 L .707 .577 .707 r
F
.16577 .70383 m .17134 .68927 L p .16501 .70175 L F P
0 g
s
.16577 .70383 m .15862 .72253 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.16484 .70555 m .16735 .71076 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .16577 .70383 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .1719 .69762 L .16577 .70383 L .707 .577 .707 r
F
.15862 .72253 m .16984 .73802 L p .17078 .70731 L F P
0 g
s
.16577 .70383 m .16735 .71076 L p .17797 .71231 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .16577 .70383 L .17797 .71231 L .707 .577 .707 r
F
.17134 .68927 m .16577 .70383 L p .17078 .70731 L F P
0 g
s
.18255 .70476 m .17134 .68927 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16484 .70555 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16932 .67585 L p .16383 .69232 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17205 .69834 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .16915 .68559 L p .15661 .70911 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .164 .69906 L .15686 .70878 L p .707 .577 .707 r
F P
0 g
s
.15686 .70878 m .15661 .70911 L p .16915 .68559 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .19277 .66011 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16915 .68559 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17671 .6658 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .17205 .69834 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .18572 .67857 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .18572 .67857 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18829 .68982 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .164 .69906 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18006 .69338 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.164 .69906 m .16915 .68559 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17286 .68402 m .16915 .68559 L .17321 .67793 L .707 .577 .707 r
F
.15943 .64296 m .17567 .63445 L p .17321 .67793 L F P
0 g
s
.16915 .68559 m .15943 .64296 L p .17321 .67793 L .707 .577 .707 r
F P
0 g
s
.15943 .64296 m .16915 .68559 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16383 .69232 L .16239 .69666 L .707 .577 .707 r
F
.16239 .69666 m .16383 .69232 L .16521 .69057 L F
.16371 .69248 m .16227 .6943 L .1631 .68548 L F
.16227 .6943 m .15221 .65018 L p .1631 .68548 L F P
0 g
s
.15661 .70911 m .16227 .6943 L p .16239 .69666 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .18255 .70476 L p .17733 .71187 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .17936 .71345 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17925 .71321 m .17797 .71231 L .16735 .71076 L .707 .577 .707 r
F
.17936 .71345 m .17931 .71325 L p .17925 .71321 L F P
0 g
s
.17733 .71187 m .18255 .70476 L .17078 .70731 L .707 .577 .707 r
F
.20188 .72079 m .18255 .70476 L p .18393 .71499 L F P
0 g
s
.18917 .75406 m .20155 .72164 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.20155 .72164 m .20188 .72079 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .17936 .71345 L .17984 .71345 L p .707 .577 .707 r
F P
0 g
s
.20188 .72079 m .18917 .75406 L .21471 .76907 L p .707 .577 .707 r
F P
0 g
s
.22406 .79517 m .22745 .81373 L .25809 .8098 L p .707 .577 .707 r
F P
0 g
s
.65921 .63811 m .67183 .69348 L .6452 .69634 L p .707 .577 .707 r
F P
0 g
s
.6452 .69634 m .63258 .64097 L .65921 .63811 L p .707 .577 .707 r
F P
0 g
s
.32524 .79385 m .33795 .76058 L .31478 .76135 L p .707 .577 .707 r
F P
0 g
s
.22745 .81373 m .22406 .79517 L .19714 .79661 L p .707 .577 .707 r
F P
0 g
s
.65915 .77015 m .67186 .73689 L .69118 .75292 L p .707 .577 .707 r
F P
0 g
s
.19714 .79661 m .20053 .81516 L .22745 .81373 L p .707 .577 .707 r
F P
0 g
s
.69046 .78018 m .69385 .79874 L .67328 .79754 L p .707 .577 .707 r
F P
0 g
s
.67186 .73689 m .65915 .77015 L .63361 .75514 L p .707 .577 .707 r
F P
0 g
s
.63361 .75514 m .64632 .72188 L .67186 .73689 L p .707 .577 .707 r
F P
0 g
s
.63611 .29788 m .62942 .79901 L .63942 .7871 L p .707 .577 .707 r
F P
0 g
s
.63942 .7871 m .64611 .28598 L .63611 .29788 L p .707 .577 .707 r
F P
0 g
s
.34382 .61637 m .35644 .67174 L .36365 .66453 L p .707 .577 .707 r
F P
0 g
s
.36365 .66453 m .35103 .60915 L .34382 .61637 L p .707 .577 .707 r
F P
0 g
s
.20053 .81516 m .19714 .79661 L .17656 .79541 L p .707 .577 .707 r
F P
0 g
s
.17656 .79541 m .17995 .81397 L .20053 .81516 L p .707 .577 .707 r
F P
0 g
s
.35103 .60915 m .36365 .66453 L .36114 .65932 L p .707 .577 .707 r
F P
0 g
s
.36114 .65932 m .34851 .60395 L .35103 .60915 L p .707 .577 .707 r
F P
0 g
s
.35515 .76103 m .35854 .77959 L .36395 .77397 L p .707 .577 .707 r
F P
0 g
s
.36395 .77397 m .36571 .77215 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35515 .76103 L .36395 .77397 L .707 .577 .707 r
F
.36236 .28953 m .35828 .2772 L p .35665 .59931 L F P
0 g
s
.35983 .75618 m .35515 .76103 L p .35886 .76494 L .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .36094 .74606 L p .35402 .7549 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .3614 .74485 L .36094 .74547 L p .707 .577 .707 r
F P
0 g
s
.36094 .74547 m .35402 .7549 L p .36094 .74606 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .35983 .75618 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36305 .76628 m .36091 .75453 L p .36232 .75359 L .707 .577 .707 r
F P
0 g
s
.35402 .7549 m .34131 .78816 L .34869 .77811 L p .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .34668 .76469 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .34869 .77811 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36091 .75453 m .35967 .74773 L .36092 .75051 L p .707 .577 .707 r
F P
0 g
s
.36092 .75051 m .36232 .75359 L p .36091 .75453 L .707 .577 .707 r
F P
0 g
s
.3614 .74485 m .36094 .74606 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35983 .75618 L .35886 .76494 L .707 .577 .707 r
F
.36571 .77215 m .36333 .75912 L p .36379 .77013 L F P
0 g
s
.36333 .75912 m .36232 .75359 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.34851 .60395 m .36114 .65932 L .34914 .65663 L p .707 .577 .707 r
F P
0 g
s
.34668 .76469 m .35756 .73621 L p .3614 .74485 L .707 .577 .707 r
F P
0 g
s
.35756 .73621 m .35939 .73143 L .35975 .73385 L p .707 .577 .707 r
F P
0 g
s
.35975 .73385 m .3614 .74485 L p .35756 .73621 L .707 .577 .707 r
F P
0 g
s
.35939 .73143 m .34668 .76469 L .33808 .75281 L p .707 .577 .707 r
F P
0 g
s
.33808 .75281 m .33546 .7492 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .35939 .73143 L .33808 .75281 L .707 .577 .707 r
F
.35785 .62804 m .36236 .28953 L p .35665 .59931 L F P
0 g
s
.35084 .76257 m .34792 .74659 L p .35967 .74773 L .707 .577 .707 r
F P
0 g
s
.34968 .7447 m .35967 .74773 L p .34792 .74659 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .36571 .77215 L .36305 .76628 L p .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .3453 .72525 L .35939 .73143 L .707 .577 .707 r
F
.33546 .7492 m .33943 .73883 L p .33865 .74683 L F P
0 g
s
.33943 .73883 m .34817 .71594 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .33546 .7492 L .31614 .73317 L p .707 .577 .707 r
F P
0 g
s
.33027 .76138 m .32688 .74285 L p .34745 .74402 L .707 .577 .707 r
F P
0 g
s
.32688 .74285 m .32688 .74282 L .32691 .74283 L p .707 .577 .707 r
F P
0 g
s
.32691 .74283 m .34745 .74402 L p .32688 .74285 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .35098 .71982 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35098 .71982 m .35939 .73143 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35967 .74773 m .36305 .76628 L .35084 .76257 L p .707 .577 .707 r
F P
0 g
s
.36236 .28953 m .35568 .79065 L .37345 .80221 L p .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35568 .79065 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35573 .78004 m .35785 .62804 L .35665 .59931 L .707 .577 .707 r
F
.35583 .77955 m .35785 .62804 L p .35573 .78004 L F P
0 g
s
.35591 .77318 m .35159 .77832 L p .3588 .55667 L .707 .577 .707 r
F P
0 g
s
.3588 .55667 m .35971 .52868 L .35591 .77318 L .707 .577 .707 r
F
.36159 .76642 m .35591 .77318 L p .35971 .52868 L F P
0 g
s
.36828 .26529 m .36557 .46794 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.36557 .46794 m .36159 .76642 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .36828 .26529 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .35462 .55094 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35462 .55094 m .35159 .77832 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35415 .58625 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35415 .58625 m .35828 .2772 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.34792 .74659 m .34745 .74402 L .34968 .7447 L p .707 .577 .707 r
F P
0 g
s
.35568 .79065 m .35583 .77955 L p .35573 .78004 L .707 .577 .707 r
F P
0 g
s
.66989 .77899 m .67328 .79754 L .64635 .79898 L p .707 .577 .707 r
F P
0 g
s
.64635 .79898 m .64296 .78042 L .66989 .77899 L p .707 .577 .707 r
F P
0 g
s
.17995 .81397 m .17656 .79541 L .16435 .7917 L p .707 .577 .707 r
F P
0 g
s
.16435 .7917 m .16774 .81026 L .17995 .81397 L p .707 .577 .707 r
F P
0 g
s
.64611 .28598 m .63942 .7871 L .63533 .77477 L p .707 .577 .707 r
F P
0 g
s
.63533 .77477 m .64202 .27365 L .64611 .28598 L p .707 .577 .707 r
F P
0 g
s
.16774 .81026 m .16435 .7917 L .1617 .78584 L p .707 .577 .707 r
F P
0 g
s
.1617 .78584 m .16509 .80439 L .16774 .81026 L p .707 .577 .707 r
F P
0 g
s
.34914 .65663 m .33651 .60126 L .34851 .60395 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64202 .27365 m .63533 .77477 L .61756 .76322 L p .707 .577 .707 r
F P
0 g
s
.61756 .76322 m .62425 .26209 L .64202 .27365 L p .707 .577 .707 r
F P
0 g
s
.16509 .80439 m .1617 .78584 L .16887 .7784 L p .707 .577 .707 r
F P
0 g
s
.33651 .60126 m .34914 .65663 L .32882 .65672 L p .707 .577 .707 r
F P
0 g
s
.32882 .65672 m .3162 .60135 L .33651 .60126 L p .707 .577 .707 r
F P
0 g
s
.16887 .7784 m .17225 .79695 L .16509 .80439 L p .707 .577 .707 r
F P
0 g
s
.36159 .76642 m .36828 .26529 L .39139 .25499 L p .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .21594 .65935 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .18572 .67857 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .19277 .66011 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .18829 .68982 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .21038 .6739 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .21038 .6739 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21196 .68083 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .18006 .69338 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .20323 .69261 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .18572 .67857 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .19934 .62546 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .17567 .63445 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.3162 .60135 m .32882 .65672 L .30219 .65958 L p .707 .577 .707 r
F P
0 g
s
.30219 .65958 m .28957 .60421 L .3162 .60135 L p .707 .577 .707 r
F P
0 g
s
.17225 .79695 m .16887 .7784 L .18515 .77011 L p .707 .577 .707 r
F P
0 g
s
.31614 .73317 m .32885 .6999 L .34817 .71594 L p .707 .577 .707 r
F P
0 g
s
.18515 .77011 m .18854 .78866 L .17225 .79695 L p .707 .577 .707 r
F P
0 g
s
.62425 .26209 m .61756 .76322 L .58784 .75357 L p .707 .577 .707 r
F P
0 g
s
.58784 .75357 m .59452 .25245 L .62425 .26209 L p .707 .577 .707 r
F P
0 g
s
.34745 .74402 m .35084 .76257 L .33027 .76138 L p .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .24395 .66357 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .21038 .6739 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21594 .65935 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .21196 .68083 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .24071 .67206 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .24071 .67206 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24075 .67226 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .20323 .69261 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .23124 .69683 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .21038 .6739 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .22813 .61689 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .19934 .62546 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.28957 .60421 m .30219 .65958 L .27184 .66494 L p .707 .577 .707 r
F P
0 g
s
.27184 .66494 m .25922 .60957 L .28957 .60421 L p .707 .577 .707 r
F P
0 g
s
.39139 .25499 m .3847 .75611 L .36159 .76642 L p .707 .577 .707 r
F P
0 g
s
.3847 .75611 m .39139 .25499 L .42534 .24728 L p .707 .577 .707 r
F P
0 g
s
.32885 .6999 m .31614 .73317 L .2906 .71816 L p .707 .577 .707 r
F P
0 g
s
.2906 .71816 m .30331 .68489 L .32885 .6999 L p .707 .577 .707 r
F P
0 g
s
.73686 .64986 m .72424 .59449 L .69389 .59984 L p .707 .577 .707 r
F P
0 g
s
.72424 .59449 m .73686 .64986 L .76795 .64253 L p .707 .577 .707 r
F P
0 g
s
.76795 .64253 m .75533 .58716 L .72424 .59449 L p .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .27406 .67237 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .24071 .67206 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24395 .66357 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.25922 .60957 m .27184 .66494 L .24075 .67226 L p .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .24071 .67206 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .25922 .60957 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .22813 .61689 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.75533 .58716 m .76795 .64253 L .79674 .63396 L p .707 .577 .707 r
F P
0 g
s
.79674 .63396 m .78412 .57859 L .75533 .58716 L p .707 .577 .707 r
F P
0 g
s
.18854 .78866 m .18515 .77011 L .20896 .76178 L p .707 .577 .707 r
F P
0 g
s
.20896 .76178 m .21235 .78033 L .18854 .78866 L p .707 .577 .707 r
F P
0 g
s
.70651 .65521 m .69389 .59984 L .66726 .6027 L p .707 .577 .707 r
F P
0 g
s
.69389 .59984 m .70651 .65521 L .73686 .64986 L p .707 .577 .707 r
F P
0 g
s
.30331 .68489 m .2906 .71816 L .26134 .70564 L p .707 .577 .707 r
F P
0 g
s
.26134 .70564 m .27406 .67237 L .30331 .68489 L p .707 .577 .707 r
F P
0 g
s
.32688 .74282 m .33027 .76138 L .30334 .76282 L p .707 .577 .707 r
F P
0 g
s
.30334 .76282 m .29995 .74426 L .32688 .74282 L p .707 .577 .707 r
F P
0 g
s
.78412 .57859 m .79674 .63396 L .82042 .62498 L p .707 .577 .707 r
F P
0 g
s
.82042 .62498 m .80779 .5696 L .78412 .57859 L p .707 .577 .707 r
F P
0 g
s
.27406 .67237 m .26134 .70564 L .23124 .69683 L p .707 .577 .707 r
F P
0 g
s
.59452 .25245 m .58784 .75357 L .54908 .74678 L p .707 .577 .707 r
F P
0 g
s
.54908 .74678 m .55576 .24565 L .59452 .25245 L p .707 .577 .707 r
F P
0 g
s
.66726 .6027 m .67988 .65808 L .70651 .65521 L p .707 .577 .707 r
F P
0 g
s
.72417 .72653 m .73688 .69327 L .70763 .68075 L p .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .76627 .72933 L .73595 .73517 L p .707 .577 .707 r
F P
0 g
s
.73595 .73517 m .73491 .73537 L p .73547 .73557 L .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .73595 .73517 L .73547 .73557 L .707 .577 .707 r
F
.76966 .74789 m .79866 .74033 L p .76937 .73039 L F P
0 g
s
.76627 .72933 m .76684 .73246 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.76684 .73246 m .76966 .74789 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .79527 .72178 L .76627 .72933 L p .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .82247 .73201 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79527 .72178 m .79661 .72913 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79661 .72913 m .79866 .74033 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .81908 .71345 L .80748 .71751 L p .707 .577 .707 r
F P
0 g
s
.80748 .71751 m .79527 .72178 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .80748 .71751 L .80135 .72407 L .707 .577 .707 r
F
.81908 .71345 m .82247 .73201 L .83875 .72371 L p F P
0 g
s
.83875 .72371 m .83536 .70516 L .81908 .71345 L p .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .83423 .69984 L .81895 .70525 L p .707 .577 .707 r
F P
0 g
s
.81895 .70525 m .81817 .70553 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .81895 .70525 L .81823 .70602 L .707 .577 .707 r
F
.80545 .73879 m .82152 .73311 L p .81823 .70602 L F P
0 g
s
.81817 .70553 m .8178 .70647 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.8178 .70647 m .80545 .73879 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .80545 .73879 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79499 .7063 m .79327 .71081 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79327 .71081 m .78228 .73956 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .78228 .73956 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76699 .70207 m .76313 .71216 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76313 .71216 m .75427 .73534 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.73688 .69327 m .72417 .72653 L .75427 .73534 L p .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .76699 .70207 L .73688 .69327 L p .707 .577 .707 r
F P
0 g
s
.21235 .78033 m .20896 .76178 L .23796 .75423 L p .707 .577 .707 r
F P
0 g
s
.41865 .74841 m .42534 .24728 L .46682 .24294 L p .707 .577 .707 r
F P
0 g
s
.42534 .24728 m .41865 .74841 L .3847 .75611 L p .707 .577 .707 r
F P
0 g
s
.69492 .71401 m .70763 .68075 L .68209 .66574 L p .707 .577 .707 r
F P
0 g
s
.70763 .68075 m .69492 .71401 L .72417 .72653 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .66726 .6027 L .64695 .60279 L p .707 .577 .707 r
F P
0 g
s
.23796 .75423 m .24135 .77278 L .21235 .78033 L p .707 .577 .707 r
F P
0 g
s
.29995 .74426 m .30334 .76282 L .2727 .76674 L p .707 .577 .707 r
F P
0 g
s
.2727 .76674 m .26931 .74819 L .29995 .74426 L p .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .79499 .7063 L .76699 .70207 L p .707 .577 .707 r
F P
0 g
s
.80779 .5696 m .82042 .62498 L .83665 .61646 L p .707 .577 .707 r
F P
0 g
s
.83665 .61646 m .82403 .56109 L .80779 .5696 L p .707 .577 .707 r
F P
0 g
s
.24135 .77278 m .23796 .75423 L .26931 .74819 L p .707 .577 .707 r
F P
0 g
s
.7383 .75392 m .73491 .73537 L .70427 .7393 L p .707 .577 .707 r
F P
0 g
s
.73491 .73537 m .7383 .75392 L .76966 .74789 L p .707 .577 .707 r
F P
0 g
s
.26931 .74819 m .2727 .76674 L .24135 .77278 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .67276 .64612 L .65956 .65811 L .707 .577 .707 r
F
.64695 .60279 m .65956 .65811 L p .67276 .64612 L F P
0 g
s
.64695 .60279 m .63494 .60011 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65971 .65817 m .67988 .65808 L p .65956 .65811 L .707 .577 .707 r
F P
0 g
s
.65006 .68297 m .66938 .699 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.66277 .6497 m .65956 .65811 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65006 .68297 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65057 .66627 m .65759 .65674 L .651 .65215 L .707 .577 .707 r
F
.65006 .68297 m .65956 .65811 L p .65057 .66627 L F P
0 g
s
.65954 .6581 m .65945 .65788 L .65914 .65782 L .707 .577 .707 r
F
.63494 .60011 m .63761 .6118 L p .65945 .65788 L F P
0 g
s
.65956 .65811 m .65759 .65674 L .65057 .66627 L .707 .577 .707 r
F
.63761 .6118 m .64602 .64869 L p .65215 .64248 L F P
0 g
s
.63494 .60011 m .63243 .5949 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.63884 .66748 m .64602 .64869 L p .64227 .65248 L .707 .577 .707 r
F P
0 g
s
.64602 .64869 m .63494 .60011 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64555 .64742 m .64228 .63433 L .64252 .63916 L .707 .577 .707 r
F
.63243 .5949 m .64252 .63916 L p .64228 .63433 L F P
0 g
s
.64602 .64869 m .64526 .64661 L .64227 .65248 L .707 .577 .707 r
F
.64227 .65248 m .64526 .64661 L .64425 .64387 L F
.63682 .65406 m .63884 .66748 L p .64056 .65998 L F P
0 g
s
.64954 .62079 m .64252 .63916 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .63682 .65406 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.63243 .5949 m .63964 .58768 L p .64334 .63045 L .707 .577 .707 r
F P
0 g
s
.64457 .64475 m .64505 .65027 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65155 .63422 m .64954 .62079 L p .64425 .64387 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .64695 .60279 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.64954 .62079 m .65692 .61075 L p .64548 .63541 L .707 .577 .707 r
F P
0 g
s
.64526 .64661 m .65155 .63422 L .64425 .64387 L .707 .577 .707 r
F
.64505 .65027 m .64252 .63916 L p .64394 .63736 L F P
0 g
s
.64409 .63717 m .64954 .62079 L .64548 .63541 L .707 .577 .707 r
F
.64602 .64869 m .65155 .63422 L p .64526 .64661 L F P
0 g
s
.64602 .64869 m .63884 .66748 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.64505 .65027 m .64757 .65548 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .64602 .64869 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .65215 .64248 L .64602 .64869 L .707 .577 .707 r
F
.63884 .66748 m .65006 .68297 L p .651 .65215 L F P
0 g
s
.64602 .64869 m .64757 .65548 L p .65914 .65782 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .64602 .64869 L .65914 .65782 L .707 .577 .707 r
F
.65155 .63422 m .64602 .64869 L p .651 .65215 L F P
0 g
s
.66277 .6497 m .65155 .63422 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64505 .65027 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64954 .62079 L p .64409 .63717 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65226 .64305 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .64939 .63045 L p .63682 .65406 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .64421 .64401 L .63703 .65378 L p .707 .577 .707 r
F P
0 g
s
.63703 .65378 m .63682 .65406 L p .64939 .63045 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .67299 .60506 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64939 .63045 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65692 .61075 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .65226 .64305 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .66597 .62343 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .66597 .62343 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .6685 .63454 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .64421 .64401 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .66028 .63833 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.64421 .64401 m .64939 .63045 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65307 .6289 m .64939 .63045 L .65341 .62288 L .707 .577 .707 r
F
.63964 .58768 m .65588 .57917 L p .65341 .62288 L F P
0 g
s
.64939 .63045 m .63964 .58768 L p .65341 .62288 L .707 .577 .707 r
F P
0 g
s
.63964 .58768 m .64939 .63045 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64409 .63717 L .64263 .64154 L .707 .577 .707 r
F
.64263 .64154 m .64409 .63717 L .64548 .63541 L F
.64394 .63736 m .64252 .63916 L .64334 .63045 L F
.64252 .63916 m .63243 .5949 L p .64334 .63045 L F P
0 g
s
.63682 .65406 m .64252 .63916 L p .64263 .64154 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .66277 .6497 L p .65759 .65674 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .65957 .65817 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65954 .6581 m .65914 .65782 L .64757 .65548 L .707 .577 .707 r
F
.65957 .65817 m .65956 .65811 L p .65954 .6581 L F P
0 g
s
.65759 .65674 m .66277 .6497 L .651 .65215 L .707 .577 .707 r
F
.68209 .66574 m .66277 .6497 L p .66413 .65983 L F P
0 g
s
.66938 .699 m .6818 .6665 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.6818 .6665 m .68209 .66574 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65957 .65817 L .65971 .65817 L p .707 .577 .707 r
F P
0 g
s
.55576 .24565 m .54908 .74678 L .50507 .7435 L p .707 .577 .707 r
F P
0 g
s
.50507 .7435 m .51176 .24238 L .55576 .24565 L p .707 .577 .707 r
F P
0 g
s
.68209 .66574 m .66938 .699 L .69492 .71401 L p .707 .577 .707 r
F P
0 g
s
.70427 .7393 m .70766 .75785 L .7383 .75392 L p .707 .577 .707 r
F P
0 g
s
.46013 .74406 m .46682 .24294 L .51176 .24238 L p .707 .577 .707 r
F P
0 g
s
.46682 .24294 m .46013 .74406 L .41865 .74841 L p .707 .577 .707 r
F P
0 g
s
.70766 .75785 m .70427 .7393 L .67735 .74073 L p .707 .577 .707 r
F P
0 g
s
.80545 .73879 m .81817 .70553 L .79499 .7063 L p .707 .577 .707 r
F P
0 g
s
.51176 .24238 m .50507 .7435 L .46013 .74406 L p .707 .577 .707 r
F P
0 g
s
.67735 .74073 m .68074 .75929 L .70766 .75785 L p .707 .577 .707 r
F P
0 g
s
.82403 .56109 m .83665 .61646 L .84387 .60924 L p .707 .577 .707 r
F P
0 g
s
.84387 .60924 m .83124 .55387 L .82403 .56109 L p .707 .577 .707 r
F P
0 g
s
.68074 .75929 m .67735 .74073 L .65677 .73954 L p .707 .577 .707 r
F P
0 g
s
.65677 .73954 m .66016 .75809 L .68074 .75929 L p .707 .577 .707 r
F P
0 g
s
.66016 .75809 m .65677 .73954 L .64456 .73583 L p .707 .577 .707 r
F P
0 g
s
.83124 .55387 m .84387 .60924 L .84135 .60404 L p .707 .577 .707 r
F P
0 g
s
.84135 .60404 m .82873 .54867 L .83124 .55387 L p .707 .577 .707 r
F P
0 g
s
.64456 .73583 m .64795 .75438 L .66016 .75809 L p .707 .577 .707 r
F P
0 g
s
.83423 .69984 m .82152 .73311 L .82891 .72306 L p .707 .577 .707 r
F P
0 g
s
.83875 .72371 m .84592 .71627 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83536 .70516 m .83805 .71986 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83805 .71986 m .83875 .72371 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.84592 .71627 m .84253 .69772 L .83536 .70516 L p .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .84126 .69074 L p .83423 .69984 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .84162 .6898 L .84126 .69028 L p .707 .577 .707 r
F P
0 g
s
.84126 .69028 m .83423 .69984 L p .84126 .69074 L .707 .577 .707 r
F P
0 g
s
.84327 .71041 m .84122 .69921 L p .84253 .69772 L .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .82689 .70964 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .82891 .72306 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.82689 .70964 m .83788 .68089 L p .84162 .6898 L .707 .577 .707 r
F P
0 g
s
.83788 .68089 m .8396 .67637 L .83995 .67866 L p .707 .577 .707 r
F P
0 g
s
.83995 .67866 m .84162 .6898 L p .83788 .68089 L .707 .577 .707 r
F P
0 g
s
.8396 .67637 m .82689 .70964 L .81567 .69415 L p .707 .577 .707 r
F P
0 g
s
.83106 .7067 m .82824 .69127 L p .83988 .69186 L .707 .577 .707 r
F P
0 g
s
.82824 .69127 m .82767 .68814 L .83038 .68897 L p .707 .577 .707 r
F P
0 g
s
.83038 .68897 m .83988 .69186 L p .82824 .69127 L .707 .577 .707 r
F P
0 g
s
.84122 .69921 m .83988 .69186 L .84124 .69486 L p .707 .577 .707 r
F P
0 g
s
.84124 .69486 m .84253 .69772 L p .84122 .69921 L .707 .577 .707 r
F P
0 g
s
.84162 .6898 m .84126 .69074 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.64795 .75438 m .64456 .73583 L .64191 .72996 L p .707 .577 .707 r
F P
0 g
s
.64191 .72996 m .6453 .74852 L .64795 .75438 L p .707 .577 .707 r
F P
0 g
s
.82873 .54867 m .84135 .60404 L .82935 .60135 L p .707 .577 .707 r
F P
0 g
s
.82935 .60135 m .81673 .54598 L .82873 .54867 L p .707 .577 .707 r
F P
0 g
s
.84253 .69772 m .84592 .71627 L .84327 .71041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39385 .6131 m .38123 .55773 L .35088 .56308 L p .707 .577 .707 r
F P
0 g
s
.38123 .55773 m .39385 .6131 L .42494 .60578 L p .707 .577 .707 r
F P
0 g
s
.42494 .60578 m .41232 .55041 L .38123 .55773 L p .707 .577 .707 r
F P
0 g
s
.41232 .55041 m .42494 .60578 L .45373 .5972 L p .707 .577 .707 r
F P
0 g
s
.45373 .5972 m .44111 .54183 L .41232 .55041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3635 .61846 m .35088 .56308 L .32425 .56595 L p .707 .577 .707 r
F P
0 g
s
.35088 .56308 m .3635 .61846 L .39385 .6131 L p .707 .577 .707 r
F P
0 g
s
.44111 .54183 m .45373 .5972 L .47741 .58822 L p .707 .577 .707 r
F P
0 g
s
.47741 .58822 m .46478 .53285 L .44111 .54183 L p .707 .577 .707 r
F P
0 g
s
.6453 .74852 m .64191 .72996 L .64908 .72252 L p .707 .577 .707 r
F P
0 g
s
.64908 .72252 m .65247 .74108 L .6453 .74852 L p .707 .577 .707 r
F P
0 g
s
.81673 .54598 m .82935 .60135 L .80904 .60144 L p .707 .577 .707 r
F P
0 g
s
.80904 .60144 m .79642 .54607 L .81673 .54598 L p .707 .577 .707 r
F P
0 g
s
.81567 .69415 m .82453 .67097 L p .8396 .67637 L .707 .577 .707 r
F P
0 g
s
.82839 .66089 m .81567 .69415 L .79635 .67812 L p .707 .577 .707 r
F P
0 g
s
.81048 .7055 m .8072 .68753 L p .82767 .68814 L .707 .577 .707 r
F P
0 g
s
.8072 .68753 m .80709 .68695 L .80777 .68699 L p .707 .577 .707 r
F P
0 g
s
.80777 .68699 m .82767 .68814 L p .8072 .68753 L .707 .577 .707 r
F P
0 g
s
.82453 .67097 m .82839 .66089 L .83113 .66467 L p .707 .577 .707 r
F P
0 g
s
.83113 .66467 m .8396 .67637 L p .82453 .67097 L .707 .577 .707 r
F P
0 g
s
.32425 .56595 m .33687 .62132 L .3635 .61846 L p .707 .577 .707 r
F P
0 g
s
.38116 .68955 m .39387 .65628 L .36462 .64376 L p .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .42326 .69317 L .39196 .69919 L p .707 .577 .707 r
F P
0 g
s
.39196 .69919 m .3919 .6992 L p .39193 .69921 L .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .39196 .69919 L .39193 .69921 L .707 .577 .707 r
F
.42665 .71172 m .45565 .70417 L p .42581 .69404 L F P
0 g
s
.42326 .69317 m .42373 .69574 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.42373 .69574 m .42665 .71172 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .45226 .68562 L .42326 .69317 L p .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .47946 .69584 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.45226 .68562 m .4535 .69241 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.4535 .69241 m .45565 .70417 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .47607 .67729 L .46355 .68167 L p .707 .577 .707 r
F P
0 g
s
.46355 .68167 m .45226 .68562 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .46355 .68167 L .45788 .68773 L .707 .577 .707 r
F
.47607 .67729 m .47946 .69584 L .49574 .68755 L p F P
0 g
s
.49574 .68755 m .49235 .669 L .47607 .67729 L p .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .49122 .66286 L .47616 .66819 L p .707 .577 .707 r
F P
0 g
s
.47616 .66819 m .47516 .66854 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .47616 .66819 L .47523 .66918 L .707 .577 .707 r
F
.46244 .70181 m .47851 .69612 L p .47523 .66918 L F P
0 g
s
.47516 .66854 m .47469 .66975 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47469 .66975 m .46244 .70181 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .46244 .70181 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45198 .66931 m .45016 .6741 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45016 .6741 m .43927 .70258 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .43927 .70258 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42398 .66509 m .42002 .67544 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42002 .67544 m .41127 .69835 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.39387 .65628 m .38116 .68955 L .41127 .69835 L p .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .42398 .66509 L .39387 .65628 L p .707 .577 .707 r
F P
0 g
s
.83988 .69186 m .84327 .71041 L .83106 .7067 L p .707 .577 .707 r
F P
0 g
s
.35191 .67703 m .36462 .64376 L .33908 .62875 L p .707 .577 .707 r
F P
0 g
s
.36462 .64376 m .35191 .67703 L .38116 .68955 L p .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32425 .56595 L .30394 .56604 L p .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .45198 .66931 L .42398 .66509 L p .707 .577 .707 r
F P
0 g
s
.46478 .53285 m .47741 .58822 L .49364 .5797 L p .707 .577 .707 r
F P
0 g
s
.49364 .5797 m .48102 .52433 L .46478 .53285 L p .707 .577 .707 r
F P
0 g
s
.39529 .71776 m .3919 .6992 L .36126 .70313 L p .707 .577 .707 r
F P
0 g
s
.3919 .6992 m .39529 .71776 L .42665 .71172 L p .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .69616 .60429 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .66597 .62343 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .67299 .60506 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .6685 .63454 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .69063 .61876 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .69063 .61876 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69218 .62555 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .66028 .63833 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .68345 .63756 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .66597 .62343 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .67955 .57018 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .65588 .57917 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32968 .60925 L .31651 .62121 L .707 .577 .707 r
F
.30394 .56604 m .31651 .62121 L p .32968 .60925 L F P
0 g
s
.30394 .56604 m .29193 .56335 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31704 .62141 m .33687 .62132 L p .31651 .62121 L .707 .577 .707 r
F P
0 g
s
.30705 .64598 m .32637 .66202 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31976 .61272 m .31651 .62121 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30705 .64598 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.30756 .62934 m .31454 .61983 L .30799 .61527 L .707 .577 .707 r
F
.30705 .64598 m .31651 .62121 L p .30756 .62934 L F P
0 g
s
.31646 .62117 m .31614 .62042 L .31517 .62027 L .707 .577 .707 r
F
.29193 .56335 m .29457 .5749 L p .31614 .62042 L F P
0 g
s
.31651 .62121 m .31454 .61983 L .30756 .62934 L .707 .577 .707 r
F
.29457 .5749 m .30298 .61179 L p .30911 .60558 L F P
0 g
s
.29193 .56335 m .28942 .55814 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.29583 .6305 m .30298 .61179 L p .29925 .61557 L .707 .577 .707 r
F P
0 g
s
.30298 .61179 m .29193 .56335 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.3025 .61049 m .29924 .59744 L .29947 .60226 L .707 .577 .707 r
F
.28942 .55814 m .29947 .60226 L p .29924 .59744 L F P
0 g
s
.30298 .61179 m .30221 .60971 L .29925 .61557 L .707 .577 .707 r
F
.29925 .61557 m .30221 .60971 L .30121 .60699 L F
.29381 .61707 m .29583 .6305 L p .2975 .62318 L F P
0 g
s
.30653 .58381 m .29947 .60226 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .29381 .61707 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.28942 .55814 m .29663 .55093 L p .30031 .59344 L .707 .577 .707 r
F P
0 g
s
.30156 .60792 m .30204 .61351 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30854 .59723 m .30653 .58381 L p .30121 .60699 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30394 .56604 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.30653 .58381 m .31391 .57376 L p .30242 .59853 L .707 .577 .707 r
F P
0 g
s
.30221 .60971 m .30854 .59723 L .30121 .60699 L .707 .577 .707 r
F
.30204 .61351 m .29947 .60226 L p .30091 .60044 L F P
0 g
s
.30104 .60028 m .30653 .58381 L .30242 .59853 L .707 .577 .707 r
F
.30298 .61179 m .30854 .59723 L p .30221 .60971 L F P
0 g
s
.30298 .61179 m .29583 .6305 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30204 .61351 m .30456 .61872 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .30298 .61179 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30911 .60558 L .30298 .61179 L .707 .577 .707 r
F
.29583 .6305 m .30705 .64598 L p .30799 .61527 L F P
0 g
s
.30298 .61179 m .30456 .61872 L p .31517 .62027 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30298 .61179 L .31517 .62027 L .707 .577 .707 r
F
.30854 .59723 m .30298 .61179 L p .30799 .61527 L F P
0 g
s
.31976 .61272 m .30854 .59723 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30204 .61351 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30653 .58381 L p .30104 .60028 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .30925 .6063 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .30635 .59355 L p .29381 .61707 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .3012 .60703 L .29406 .61674 L p .707 .577 .707 r
F P
0 g
s
.29406 .61674 m .29381 .61707 L p .30635 .59355 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .32998 .56808 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30635 .59355 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .31391 .57376 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .30925 .6063 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .32293 .58653 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .32293 .58653 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32549 .59778 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .3012 .60703 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31727 .60134 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.3012 .60703 m .30635 .59355 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31006 .59198 m .30635 .59355 L .31041 .5859 L .707 .577 .707 r
F
.29663 .55093 m .31287 .54241 L p .31041 .5859 L F P
0 g
s
.30635 .59355 m .29663 .55093 L p .31041 .5859 L .707 .577 .707 r
F P
0 g
s
.29663 .55093 m .30635 .59355 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30104 .60028 L .29959 .60462 L .707 .577 .707 r
F
.29959 .60462 m .30104 .60028 L .30242 .59853 L F
.30091 .60044 m .29947 .60226 L .30031 .59344 L F
.29947 .60226 m .28942 .55814 L p .30031 .59344 L F P
0 g
s
.29381 .61707 m .29947 .60226 L p .29959 .60462 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31976 .61272 L p .31454 .61983 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .31656 .62141 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31646 .62117 m .31517 .62027 L .30456 .61872 L .707 .577 .707 r
F
.31656 .62141 m .31651 .62121 L p .31646 .62117 L F P
0 g
s
.31454 .61983 m .31976 .61272 L .30799 .61527 L .707 .577 .707 r
F
.33908 .62875 m .31976 .61272 L p .32113 .62295 L F P
0 g
s
.32637 .66202 m .33876 .6296 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.33876 .6296 m .33908 .62875 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31656 .62141 L .31704 .62141 L p .707 .577 .707 r
F P
0 g
s
.33908 .62875 m .32637 .66202 L .35191 .67703 L p .707 .577 .707 r
F P
0 g
s
.36126 .70313 m .36465 .72169 L .39529 .71776 L p .707 .577 .707 r
F P
0 g
s
.79642 .54607 m .80904 .60144 L .78241 .6043 L p .707 .577 .707 r
F P
0 g
s
.78241 .6043 m .76978 .54893 L .79642 .54607 L p .707 .577 .707 r
F P
0 g
s
.46244 .70181 m .47516 .66854 L .45198 .66931 L p .707 .577 .707 r
F P
0 g
s
.36465 .72169 m .36126 .70313 L .33434 .70457 L p .707 .577 .707 r
F P
0 g
s
.65247 .74108 m .64908 .72252 L .66536 .71423 L p .707 .577 .707 r
F P
0 g
s
.79635 .67812 m .80906 .64485 L .82839 .66089 L p .707 .577 .707 r
F P
0 g
s
.33434 .70457 m .33773 .72312 L .36465 .72169 L p .707 .577 .707 r
F P
0 g
s
.66536 .71423 m .66875 .73279 L .65247 .74108 L p .707 .577 .707 r
F P
0 g
s
.82767 .68814 m .83106 .7067 L .81048 .7055 L p .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .72417 .60852 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .69063 .61876 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69616 .60429 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .69218 .62555 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .72095 .61692 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .72095 .61692 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72097 .61698 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .68345 .63756 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .71146 .64178 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .69063 .61876 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .70834 .56161 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .67955 .57018 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.48102 .52433 m .49364 .5797 L .50086 .57249 L p .707 .577 .707 r
F P
0 g
s
.50086 .57249 m .48823 .51712 L .48102 .52433 L p .707 .577 .707 r
F P
0 g
s
.76978 .54893 m .78241 .6043 L .75206 .60966 L p .707 .577 .707 r
F P
0 g
s
.75206 .60966 m .73944 .55428 L .76978 .54893 L p .707 .577 .707 r
F P
0 g
s
.33773 .72312 m .33434 .70457 L .31376 .70337 L p .707 .577 .707 r
F P
0 g
s
.80906 .64485 m .79635 .67812 L .77081 .6631 L p .707 .577 .707 r
F P
0 g
s
.77081 .6631 m .78352 .62984 L .80906 .64485 L p .707 .577 .707 r
F P
0 g
s
.31376 .70337 m .31715 .72193 L .33773 .72312 L p .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .75427 .61732 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .72095 .61692 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72417 .60852 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.73944 .55428 m .75206 .60966 L .72097 .61698 L p .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .72095 .61692 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .73944 .55428 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .70834 .56161 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.66875 .73279 m .66536 .71423 L .68917 .7059 L p .707 .577 .707 r
F P
0 g
s
.68917 .7059 m .69256 .72446 L .66875 .73279 L p .707 .577 .707 r
F P
0 g
s
.78352 .62984 m .77081 .6631 L .74156 .65058 L p .707 .577 .707 r
F P
0 g
s
.74156 .65058 m .75427 .61732 L .78352 .62984 L p .707 .577 .707 r
F P
0 g
s
.80709 .68695 m .81048 .7055 L .78356 .70694 L p .707 .577 .707 r
F P
0 g
s
.78356 .70694 m .78017 .68839 L .80709 .68695 L p .707 .577 .707 r
F P
0 g
s
.75427 .61732 m .74156 .65058 L .71146 .64178 L p .707 .577 .707 r
F P
0 g
s
.31715 .72193 m .31376 .70337 L .30155 .69966 L p .707 .577 .707 r
F P
0 g
s
.48823 .51712 m .50086 .57249 L .49834 .56728 L p .707 .577 .707 r
F P
0 g
s
.49834 .56728 m .48572 .51191 L .48823 .51712 L p .707 .577 .707 r
F P
0 g
s
.30155 .69966 m .30494 .71822 L .31715 .72193 L p .707 .577 .707 r
F P
0 g
s
.69256 .72446 m .68917 .7059 L .71817 .69835 L p .707 .577 .707 r
F P
0 g
s
.49122 .66286 m .47851 .69612 L .4859 .68607 L p .707 .577 .707 r
F P
0 g
s
.49574 .68755 m .50291 .68011 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49235 .669 m .49494 .68314 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49494 .68314 m .49574 .68755 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.50291 .68011 m .49952 .66155 L .49235 .669 L p .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .49814 .65402 L p .49122 .66286 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .49861 .65281 L .49815 .65344 L p .707 .577 .707 r
F P
0 g
s
.49815 .65344 m .49122 .66286 L p .49814 .65402 L .707 .577 .707 r
F P
0 g
s
.50026 .67425 m .49811 .66249 L p .49952 .66155 L .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .48388 .67265 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .4859 .68607 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49811 .66249 m .49687 .65569 L .49813 .65847 L p .707 .577 .707 r
F P
0 g
s
.49813 .65847 m .49952 .66155 L p .49811 .66249 L .707 .577 .707 r
F P
0 g
s
.49861 .65281 m .49814 .65402 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.71817 .69835 m .72156 .71691 L .69256 .72446 L p .707 .577 .707 r
F P
0 g
s
.78017 .68839 m .78356 .70694 L .75292 .71087 L p .707 .577 .707 r
F P
0 g
s
.75292 .71087 m .74953 .69231 L .78017 .68839 L p .707 .577 .707 r
F P
0 g
s
.72156 .71691 m .71817 .69835 L .74953 .69231 L p .707 .577 .707 r
F P
0 g
s
.74953 .69231 m .75292 .71087 L .72156 .71691 L p .707 .577 .707 r
F P
0 g
s
.30494 .71822 m .30155 .69966 L .2989 .6938 L p .707 .577 .707 r
F P
0 g
s
.2989 .6938 m .30229 .71235 L .30494 .71822 L p .707 .577 .707 r
F P
0 g
s
.48572 .51191 m .49834 .56728 L .48634 .56459 L p .707 .577 .707 r
F P
0 g
s
.48634 .56459 m .47372 .50922 L .48572 .51191 L p .707 .577 .707 r
F P
0 g
s
.48388 .67265 m .49477 .64417 L p .49861 .65281 L .707 .577 .707 r
F P
0 g
s
.49659 .63939 m .48388 .67265 L .47266 .65716 L p .707 .577 .707 r
F P
0 g
s
.48805 .67054 m .48513 .65455 L p .49687 .65569 L .707 .577 .707 r
F P
0 g
s
.48513 .65455 m .48466 .65198 L .48689 .65266 L p .707 .577 .707 r
F P
0 g
s
.48689 .65266 m .49687 .65569 L p .48513 .65455 L .707 .577 .707 r
F P
0 g
s
.49477 .64417 m .49659 .63939 L .49696 .64181 L p .707 .577 .707 r
F P
0 g
s
.49696 .64181 m .49861 .65281 L p .49477 .64417 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49952 .66155 m .50291 .68011 L .50026 .67425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30229 .71235 m .2989 .6938 L .30607 .68636 L p .707 .577 .707 r
F P
0 g
s
.47372 .50922 m .48634 .56459 L .46603 .56468 L p .707 .577 .707 r
F P
0 g
s
.46603 .56468 m .45341 .50931 L .47372 .50922 L p .707 .577 .707 r
F P
0 g
s
.30607 .68636 m .30946 .70491 L .30229 .71235 L p .707 .577 .707 r
F P
0 g
s
.47266 .65716 m .48142 .63425 L p .49659 .63939 L .707 .577 .707 r
F P
0 g
s
.48538 .6239 m .47266 .65716 L .45334 .64113 L p .707 .577 .707 r
F P
0 g
s
.46747 .66934 m .46409 .65081 L p .48466 .65198 L .707 .577 .707 r
F P
0 g
s
.46409 .65081 m .46408 .65079 L .46412 .65079 L p .707 .577 .707 r
F P
0 g
s
.46412 .65079 m .48466 .65198 L p .46409 .65081 L .707 .577 .707 r
F P
0 g
s
.48142 .63425 m .48538 .6239 L .48819 .62778 L p .707 .577 .707 r
F P
0 g
s
.48819 .62778 m .49659 .63939 L p .48142 .63425 L .707 .577 .707 r
F P
0 g
s
.49687 .65569 m .50026 .67425 L .48805 .67054 L p .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .35315 .56731 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .32293 .58653 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32998 .56808 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .32549 .59778 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .34759 .58186 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .34759 .58186 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34917 .5888 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .31727 .60134 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34044 .60057 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .32293 .58653 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .33654 .53342 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31287 .54241 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.45341 .50931 m .46603 .56468 L .4394 .56755 L p .707 .577 .707 r
F P
0 g
s
.4394 .56755 m .42677 .51217 L .45341 .50931 L p .707 .577 .707 r
F P
0 g
s
.30946 .70491 m .30607 .68636 L .32235 .67807 L p .707 .577 .707 r
F P
0 g
s
.45334 .64113 m .46605 .60787 L .48538 .6239 L p .707 .577 .707 r
F P
0 g
s
.32235 .67807 m .32574 .69662 L .30946 .70491 L p .707 .577 .707 r
F P
0 g
s
.48466 .65198 m .48805 .67054 L .46747 .66934 L p .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .38116 .57153 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .34759 .58186 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .35315 .56731 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .34917 .5888 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .37791 .58002 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .37791 .58002 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .37796 .58022 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .34044 .60057 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36844 .6048 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .34759 .58186 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .36533 .52485 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .33654 .53342 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.42677 .51217 m .4394 .56755 L .40905 .5729 L p .707 .577 .707 r
F P
0 g
s
.40905 .5729 m .39643 .51753 L .42677 .51217 L p .707 .577 .707 r
F P
0 g
s
.46605 .60787 m .45334 .64113 L .4278 .62612 L p .707 .577 .707 r
F P
0 g
s
.4278 .62612 m .44051 .59285 L .46605 .60787 L p .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .41126 .58033 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .37791 .58002 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .38116 .57153 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.39643 .51753 m .40905 .5729 L .37796 .58022 L p .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .37791 .58002 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .39643 .51753 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36533 .52485 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.32574 .69662 m .32235 .67807 L .34616 .66974 L p .707 .577 .707 r
F P
0 g
s
.34616 .66974 m .34955 .68829 L .32574 .69662 L p .707 .577 .707 r
F P
0 g
s
.44051 .59285 m .4278 .62612 L .39855 .6136 L p .707 .577 .707 r
F P
0 g
s
.39855 .6136 m .41126 .58033 L .44051 .59285 L p .707 .577 .707 r
F P
0 g
s
.46408 .65079 m .46747 .66934 L .44055 .67078 L p .707 .577 .707 r
F P
0 g
s
.44055 .67078 m .43716 .65222 L .46408 .65079 L p .707 .577 .707 r
F P
0 g
s
.41126 .58033 m .39855 .6136 L .36844 .6048 L p .707 .577 .707 r
F P
0 g
s
.34955 .68829 m .34616 .66974 L .37516 .66219 L p .707 .577 .707 r
F P
0 g
s
.37516 .66219 m .37855 .68074 L .34955 .68829 L p .707 .577 .707 r
F P
0 g
s
.43716 .65222 m .44055 .67078 L .40991 .67471 L p .707 .577 .707 r
F P
0 g
s
.40991 .67471 m .40652 .65615 L .43716 .65222 L p .707 .577 .707 r
F P
0 g
s
.37855 .68074 m .37516 .66219 L .40652 .65615 L p .707 .577 .707 r
F P
0 g
s
.40652 .65615 m .40991 .67471 L .37855 .68074 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH6
0003FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF1@001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0009JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000<000MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0069oo`@00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005ioo`@0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05aoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol005Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00F7oo0P001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05Ioo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000XOol;000cOol005Aoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000POol80003FUH0
0`00FUIJEP03FUH01000FUH00000<Goo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000IOol70003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool0059oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8001Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P004Goo10001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP/00005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000?Ool200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool0059oo`800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`<000=JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P001UYF00<005YFFUH015YF00<005YF
FUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0009Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00
0080009JEP05001JEUYFFUH00008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
02moo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005Ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
00IJEP03001JEUYF00EJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP03FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002io
o`00EGoo0P000eYF00@005YFFUIJEP@000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00D7oo1P000UYF1`00
0eYF10000UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@002eoo`00C7oo10000UYF00<0
05YF00001@0015YF00<005YFFUH01EYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<007ooOol0:goo0017Ool50006FUH01@00FUH005YF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000]Ool004=oo`@0009JEP03001JEUYF00MJEP@000=JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPH000UJEP03001JEUYF00EJEP04001JEUYF0009
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00;Woo000oOol40006FUH00`00FUIJEP07FUH00`00FUH00002
0003FUH20002FUH00`00FUIJEP02FUH80002FUH01000FUIJEUYF0P001UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH30007FUH00`00FUH00008FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003]oo`@00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEP00009JEP<0009JEPP00003FUH0000000IJEP03001JEUYF00=JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP<000QJEP03001JEUYF00EJEP04001JEP00000`Ool003Moo`@000EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF009JEP800006FUH005YFFUH005YF0P001UYF00<0
05YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP<0039o
o`00=Goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00@005YFFUH0
00AJEP80009JEP04001JEP000006FUH40005FUH30008FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH2000eOol003=oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP04001JEUYF0004FUH300000eYF001JEP020006FUH50004FUH00`00FUIJEP020005FUH00`00FUIJ
EP04FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000eYF00@005YF000003Moo`00<Goo0P001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH200000eYF00000005FUH6
0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP08FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00MJEPH003Uoo`00;goo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000EJEPH000AJ
EP03001JEUYF00AJEP<000MJEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000=JEP/000AJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2000jOol002eoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH00`00FUIJEP04FUH20006FUH00`00FUH000020005FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF00000005FUH00`00FUIJEP03FUH60007FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000hOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP07FUH00`00FUIJEP07FUH20004FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00Oomoo`0eOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01eYF00<005YFFUH025YF
0`000UYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00D005YFFUIJEP0000MJEP03001JEUYF00=JEP<00003FUH005YF00QJEP03
001JEUYF00IJEP<003Eoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30009FUHE000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH015YF00@005YFFUH000MJEP03001JEUYF00@0009oo`<000QJEP03001JEUYF00EJ
EP05001JEUYFFUH0000dOol002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH01EYF
2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJEP00001JEP00009JEP04001JEUYF0003
FUH60009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH00003FUH00000
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
0P000eYF200047oo0`0000=JEP00FUH01eYF00<005YFFUH015YF00<007ooOol0;goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00Oomoo`0AOol20007FUH00`00
FUIJEP05FUH00`00Oomoo`0_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP02FUH20006FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF0P000eYF00<007ooOol027oo0`00
27oo0P001EYF00<005YFFUH015YF00<005YF0000<7oo000/Ool01000FUIJEP000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01@000eYF00<005YFFUH01UYF00<005YFFUH015YF1P001EYF
00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0`000UYF00<007ooOol01goo1@002Goo0P000eYF
00<005YFFUH01eYF00<007ooOol0;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH30006FUH200000eYF001JEP06FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJ
EP04FUH70007FUH00`00FUIJEP04FUH01000FUH005YF1@0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF00@005YFFUIJEP<000Uoo`D000]oo`<000IJ
EP80009JEP03001oogoo02eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YF
FUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0002FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001UYF00<005YFFUH00eYF
0P0027oo1@003Goo00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;7oo000]Ool01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF
00@005YF000000MJEP03001JEUYF00AJEP@00004FUH000000004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUIJEP00FUH00P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF100025YF00<005YFFUH01EYF0P001goo0`003goo00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0;7oo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00001JEP0000MJEP03001JEUYF00@000=JEPH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200001EYF000005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01eYF0`00
67oo00D005YFFUIJEP0000AJEP8002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH0
1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YFFUH0000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH20004FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0037oo500000=JEP00Ool0;7oo000^Ool20003FUH01000FUIJEUYF10001eYF00<0
05YFFUH01UYF00<005YFFUH01eYF0`0015YF00@005YFFUIJEP800005Ool005YFFUH00004FUH80002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP0000QJEP03001JEUYF
00=JEP8000=oo`L000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002eoo`00;Woo
00<005YFFUH01`000eYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUH000AJEP04
001JEP000003Ool01000FUIJEP001UYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF100025YF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH5
0007FUH00`00FUIJEP06FUH01000FUIJEP000eYF0`001Goo00@005YFFUH000AJEPd000AJEP03001J
EUYF00AJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00002FUH01P00FUIJEUYFOol0
00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP05001JEUYF001JEP020002FUH00`00Oomo
o`03Ool80004FUH00`00FUIJEP06FUH=000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20005FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000/Ool40003FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH200000eYF0000000:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUH000020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0002FUH00`00Oomoo`0[Ool002ao
o`04001JEP000004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP040004Ool20006FUH01000FUH0
00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH010000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0015YF00<005YFFUH015YF0`002EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00D005YFFUH005YF00@002aoo`00;7oo00<005YF00000eYF0P000UYF3@002Woo0P0015YF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF009JEP80009JEP03001JEUYF00MJEP03001JEUYF009JEPT00003OomJ
EUYF009JEP8000EJEP04001JEUYFFUH300000eYF0000000/Ool002aoo`03001oo`0000=JEP03001J
EUYF009JEP8001Ioo`800004FUH005YFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUH000020004FUH00`00FUIJEP06FUH80004
FUH01000FUIJEWoo15YF0P001EYF00@005YFFUIJEP8000=JEP03001oogoo02Yoo`00;Goo00D005YF
FUIJEP00009JEP03OomJEUYF009JEP03001oogoo01Eoo`8000=JEP80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPL000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP800003FUH005YF00EJ
EP03001JEUYF009JEP<0009JEP03001JEP0000@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF008002eoo`00;Goo00D005YFFUIJEP00009JEP03OomJEUYF009JEP<0
00aoo`<000Qoo`8000=JEQ@00003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJ
EP03001JEP0000D00004FUH005YFFUH50003FUH01@00FUIJEUYFOol00UYF0P001EYF00@005YFFUIJ
EP80009JEP03001oogoo02aoo`00;Woo00@005YFFUH0009JEP05OomJEUYFFUH00003FUH00`00Oomo
o`08Ool50009Ool20003FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP02FUH30006Ool300000eYF0000
00030002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8002moo`00;Woo00@0
05YFFUH000IJEP03001JEUYF009JEP03001oogoo00Moo`D000]oo`<000MJEP03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEP000080
00aoo`D000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000aOol002moo`8000IJ
EP03001JEUYF00AJEP8000Moo`D000eoo`03001JEUYF00AJEP800005FUH005YFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH01000FUIJEUYF0`004Woo0`0000=JEP00FUH01eYF00<0
05YFFUH00eYF00<005YFFUH00P00<goo000`Ool00`00FUIJEP04FUH00`00FUIJEP06FUH20006Ool3
000?Ool00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00H005YF000005YF000>Ool700000eYF000000030004FUH00`00FUIJEP03FUH0
1000FUH00000=Goo000aOol00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000005goo00<005YF
00000UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF01@000=JEP03001JEUYF00IJEPd003Moo`00<Woo00D005YFFUIJEP0000QJEP03001JEUYF
009JEP<000Yooa<0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEQT000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol003=oo`04001JEUYF0008
FUH00`00FUIJEP05FUH:0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00
@7oo000dOol20009FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040015Ool003Eo
o`03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH00UYF1P00BGoo000fOol20006FUH400000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF0`000eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YF
FUH00UYF0`000eYF5000Cgoo000hOol60005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH@0002FUH0
0`00FUH000030006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH300000eYF001JEP03FUH200000goo00000003FUH00`00FUIJEP07FUH00`00
Oomoo`1DOol003Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP04001JEP000002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000goo0`00
1eYF00@005YFFUH005Ioo`00=7oo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF20001eYF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP8000Eoo`03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05=oo`00<goo0P001eYF00<005YF
FUH015YF200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF10001Woo00<005YFFUH00eYF00<005YFFUH00UYF00<007oo
Ool0Dgoo000aOol200000eYF001JEP06FUH00`00FUIJEP040003FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000
00Moo`05001JEUYFFUH00004FUH2001EOol0031oo`05001JEUYFFUH00006FUH40003Ool200000eYF
001JEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000400000AJEP00FUH005Aoo`00;Woo0`0015YF
00@005YFFUIJEP8000Uoo`P0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020007FUH00`00FUIJEP03
FUH5001DOol002eoo`04001JEUYF0004FUH01000FUH000003Woo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF0080
00MJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo00@005YFFUH000=JEP<000moo`/000AJ
EP03001JEUYF00AJEP03001JEUYF00<000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP05001JEP00FUH00008FUH00`00FUIJEP02FUH00`00FUIJEP02001DOol002eoo`05001JEUYF
001JEP02000>Ool40002FUH00`00FUIJEP06FUH?0006Ool01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Aoo`00;Woo00<005YF0000
4@001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002goo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH00UYF1P000eYF00@005YFFUH005Aoo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0100047oo0P001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00002@000eYF1P0000=JEP000000Dgoo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000EOol20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF100000=ooeYFFUH00eYF00<005YFFUH00eYF0P000UYF1P00Dgoo000^Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000
FUH0009JEP03OomJEUYF009JEP8000EJEP04001JEUYFFUH20003FUH00`00Oomoo`1AOol002moo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Aoo`D000QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000=JEP03001JEUYF00EJEP03
001JEUYF00=JEP8000=JEP03001JEUYF008005Aoo`00<Goo5000<7oo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02@000eYF00D005YFFUIJEWoo00=JEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00Oomoo`1COol007]oo`T000IJEP03001JEUYF00UJEP03
001JEUYF00AJEP/00003FUH0000000<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF
FUH005YF0P00EWoo0024OolI000;Ool60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`00F7oo002?Ool01000FUIJEP000eYF0`004Goo100000=JEP00FUH01eYF00<005YFFUH00eYF
00<005YFFUH00P00FWoo002?Ool01@00FUIJEP00FUH00P0047oo1`0000=JEP0000000`0015YF00<0
05YFFUH00eYF00@005YF000005aoo`00Sgoo00<005YFFUH050000eYF00<005YFFUH01UYF3@00GWoo
002@Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04001SOol0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEPD006Moo`00T7oo0P000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01000K7oo002AOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
001`Ool009=oo`@000=JEP03001JEUYF009JEPP007Ioo`00Ugoo2000OWoo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59852 .74498 m .59068 .68916 L .55982 .69174 L p .707 .577 .707 r
F P
0 g
s
.59068 .68916 m .59852 .74498 L .63007 .74015 L p .707 .577 .707 r
F P
0 g
s
.63007 .74015 m .62223 .68433 L .59068 .68916 L p .707 .577 .707 r
F P
0 g
s
.62223 .68433 m .63007 .74015 L .65923 .73356 L p .707 .577 .707 r
F P
0 g
s
.65923 .73356 m .65138 .67774 L .62223 .68433 L p .707 .577 .707 r
F P
0 g
s
.56767 .74757 m .55982 .69174 L .53268 .69184 L p .707 .577 .707 r
F P
0 g
s
.55982 .69174 m .56767 .74757 L .59852 .74498 L p .707 .577 .707 r
F P
0 g
s
.65138 .67774 m .65923 .73356 L .68314 .72585 L p .707 .577 .707 r
F P
0 g
s
.68314 .72585 m .67529 .67002 L .65138 .67774 L p .707 .577 .707 r
F P
0 g
s
.53268 .69184 m .54053 .74767 L .56767 .74757 L p .707 .577 .707 r
F P
0 g
s
.59086 .81566 m .59882 .78039 L .56839 .77179 L p .707 .577 .707 r
F P
0 g
s
.59882 .78039 m .59086 .81566 L .62203 .82093 L p .707 .577 .707 r
F P
0 g
s
.62203 .82093 m .62999 .78566 L .59882 .78039 L p .707 .577 .707 r
F P
0 g
s
.54053 .74767 m .53268 .69184 L .51191 .68944 L p .707 .577 .707 r
F P
0 g
s
.56043 .80706 m .56839 .77179 L .54167 .76069 L p .707 .577 .707 r
F P
0 g
s
.56839 .77179 m .56043 .80706 L .59086 .81566 L p .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .65811 .81958 L .63785 .82371 L p .707 .577 .707 r
F P
0 g
s
.63785 .82371 m .62888 .82554 L p .63467 .82788 L .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .63785 .82371 L .63467 .82788 L .707 .577 .707 r
F
.65811 .81958 m .66022 .8382 L .68418 .8309 L p F P
0 g
s
.68418 .8309 m .68207 .81227 L .66657 .817 L p .707 .577 .707 r
F P
0 g
s
.66657 .817 m .65811 .81958 L p .6635 .82192 L .707 .577 .707 r
F P
0 g
s
.68418 .8309 m .66657 .817 L .6635 .82192 L .707 .577 .707 r
F
.68207 .81227 m .68418 .8309 L .70051 .82296 L p F P
0 g
s
.70051 .82296 m .69841 .80434 L .68893 .80894 L p .707 .577 .707 r
F P
0 g
s
.68893 .80894 m .68207 .81227 L p .68672 .81497 L .707 .577 .707 r
F P
0 g
s
.70051 .82296 m .68893 .80894 L .68672 .81497 L .707 .577 .707 r
F
.69085 .81348 m .69805 .80405 L p .69869 .78235 L F P
0 g
s
.69881 .77821 m .69658 .78811 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.69658 .78811 m .69085 .81348 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .69085 .81348 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68256 .78452 m .68015 .79521 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68015 .79521 m .6746 .81978 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .6746 .81978 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65885 .78709 m .65591 .80008 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65591 .80008 m .65088 .82235 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.62999 .78566 m .62203 .82093 L .65088 .82235 L p .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .65885 .78709 L .62999 .78566 L p .707 .577 .707 r
F P
0 g
s
.67529 .67002 m .68314 .72585 L .69946 .71777 L p .707 .577 .707 r
F P
0 g
s
.69946 .71777 m .69161 .66194 L .67529 .67002 L p .707 .577 .707 r
F P
0 g
s
.59933 .84819 m .59723 .82957 L .56626 .83127 L p .707 .577 .707 r
F P
0 g
s
.59723 .82957 m .59933 .84819 L .63098 .84416 L p .707 .577 .707 r
F P
0 g
s
.63098 .84416 m .62888 .82554 L .59723 .82957 L p .707 .577 .707 r
F P
0 g
s
.51191 .68944 m .51976 .74526 L .54053 .74767 L p .707 .577 .707 r
F P
0 g
s
.62888 .82554 m .63098 .84416 L .66022 .8382 L p .707 .577 .707 r
F P
0 g
s
.54167 .76069 m .53371 .79596 L .56043 .80706 L p .707 .577 .707 r
F P
0 g
s
.53371 .79596 m .54167 .76069 L .52128 .74819 L p .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .68256 .78452 L .65885 .78709 L p .707 .577 .707 r
F P
0 g
s
.56626 .83127 m .56836 .84989 L .59933 .84819 L p .707 .577 .707 r
F P
0 g
s
.56836 .84989 m .56626 .83127 L .539 .83048 L p .707 .577 .707 r
F P
0 g
s
.539 .83048 m .54111 .8491 L .56836 .84989 L p .707 .577 .707 r
F P
0 g
s
.51976 .74526 m .51191 .68944 L .49954 .68477 L p .707 .577 .707 r
F P
0 g
s
.52128 .74819 m .51332 .78346 L .53371 .79596 L p .707 .577 .707 r
F P
0 g
s
.69161 .66194 m .69946 .71777 L .70659 .71011 L p .707 .577 .707 r
F P
0 g
s
.70659 .71011 m .69874 .65429 L .69161 .66194 L p .707 .577 .707 r
F P
0 g
s
.54111 .8491 m .539 .83048 L .51813 .82727 L p .707 .577 .707 r
F P
0 g
s
.49954 .68477 m .50739 .74059 L .50829 .74093 L p .707 .577 .707 r
F P
0 g
s
.5139 .72772 m .49954 .68477 L .50829 .74093 L .707 .577 .707 r
F
.50739 .74059 m .49954 .68477 L .49679 .67829 L p F P
0 g
s
.50739 .74059 m .5041 .72125 L .50453 .73332 L .707 .577 .707 r
F
.50335 .75258 m .50724 .74125 L .50531 .7356 L F
.50546 .73605 m .50739 .74059 L p .50453 .73332 L F P
0 g
s
.4987 .75915 m .50125 .77078 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50666 .72389 m .50453 .73332 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .4987 .75915 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50453 .73332 L p .5041 .72125 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50393 .67063 L p .50462 .73214 L .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50666 .72389 L p .50531 .7356 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .50666 .72389 L p .50581 .73175 L .707 .577 .707 r
F P
0 g
s
.50463 .73363 m .50464 .73411 L .50546 .73605 L p .707 .577 .707 r
F P
0 g
s
.50464 .73411 m .50453 .73332 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50724 .74125 m .50922 .73551 L .50531 .7356 L .707 .577 .707 r
F
.51177 .72646 m .50464 .73411 L p .50463 .7332 L F P
0 g
s
.50666 .72389 m .51386 .71446 L p .50954 .7272 L .707 .577 .707 r
F P
0 g
s
.50581 .73175 m .50666 .72389 L .50954 .7272 L .707 .577 .707 r
F
.51153 .72476 m .51177 .72646 L p .50463 .7332 L F P
0 g
s
.50125 .77078 m .50765 .74244 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.50765 .74244 m .50922 .73551 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .4987 .75915 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .51153 .72476 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .5059 .74973 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .53011 .70815 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51177 .72646 m .51153 .72476 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.50829 .74093 m .51976 .74526 L p .5139 .72772 L .707 .577 .707 r
F P
0 g
s
.51332 .78346 m .52128 .74819 L .50922 .73551 L p .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50125 .77078 L .51332 .78346 L p .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .51386 .71446 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .51177 .72646 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .52798 .71759 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .52798 .71759 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52809 .71838 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .5059 .74973 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52215 .74342 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .51153 .72476 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51203 .72455 m .51153 .72476 L .51225 .72285 L .707 .577 .707 r
F
.50393 .67063 m .52024 .66256 L p .51225 .72285 L F P
0 g
s
.51153 .72476 m .50393 .67063 L p .51225 .72285 L .707 .577 .707 r
F P
0 g
s
.50393 .67063 m .51153 .72476 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50481 .74114 m .50581 .73175 L .50954 .7272 L .707 .577 .707 r
F
.50453 .73332 m .50581 .73175 L .50481 .74114 L F
.50463 .7332 m .50453 .73332 L .50462 .73214 L F
.50453 .73332 m .49679 .67829 L p .50462 .73214 L F P
0 g
s
.4987 .75915 m .50453 .73332 L p .50481 .74114 L .707 .577 .707 r
F P
0 g
s
.69085 .81348 m .69881 .77821 L .68256 .78452 L p .707 .577 .707 r
F P
0 g
s
.51813 .82727 m .52023 .8459 L .54111 .8491 L p .707 .577 .707 r
F P
0 g
s
.52023 .8459 m .51813 .82727 L .50569 .82197 L p .707 .577 .707 r
F P
0 g
s
.69805 .80405 m .70601 .76879 L .69881 .77821 L p .707 .577 .707 r
F P
0 g
s
.50569 .82197 m .50779 .84059 L .52023 .8459 L p .707 .577 .707 r
F P
0 g
s
.69874 .65429 m .70659 .71011 L .70384 .70364 L p .707 .577 .707 r
F P
0 g
s
.70384 .70364 m .69599 .64781 L .69874 .65429 L p .707 .577 .707 r
F P
0 g
s
.69841 .80434 m .70051 .82296 L .70763 .81517 L p .707 .577 .707 r
F P
0 g
s
.70763 .81517 m .70553 .79654 L .69841 .80434 L p .707 .577 .707 r
F P
0 g
s
.48766 .8219 m .49179 .32047 L .44778 .31742 L p .707 .577 .707 r
F P
0 g
s
.50779 .84059 m .50569 .82197 L .50288 .81508 L p .707 .577 .707 r
F P
0 g
s
.50288 .81508 m .50499 .83371 L .50779 .84059 L p .707 .577 .707 r
F P
0 g
s
.50499 .83371 m .50288 .81508 L .51 .80729 L p .707 .577 .707 r
F P
0 g
s
.51 .80729 m .5121 .82591 L .50499 .83371 L p .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .55383 .70559 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .52798 .71759 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .53011 .70815 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.55383 .70559 m .55226 .71252 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.54415 .65484 m .552 .71067 L .53522 .71608 L p .707 .577 .707 r
F P
0 g
s
.53522 .71608 m .52809 .71838 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52831 .71752 m .54415 .65484 L .53522 .71608 L .707 .577 .707 r
F
.54586 .74085 m .52215 .74342 L p .54712 .71359 L F P
0 g
s
.55226 .71252 m .54586 .74085 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .52798 .71759 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .54415 .65484 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52024 .66256 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.5121 .82591 m .51 .80729 L .52634 .79935 L p .707 .577 .707 r
F P
0 g
s
.52634 .79935 m .52844 .81798 L .5121 .82591 L p .707 .577 .707 r
F P
0 g
s
.52844 .81798 m .52634 .79935 L .55029 .79205 L p .707 .577 .707 r
F P
0 g
s
.55029 .79205 m .5524 .81067 L .52844 .81798 L p .707 .577 .707 r
F P
0 g
s
.49179 .32047 m .48766 .8219 L .5326 .82113 L p .707 .577 .707 r
F P
0 g
s
.5326 .82113 m .53673 .3197 L .49179 .32047 L p .707 .577 .707 r
F P
0 g
s
.552 .71067 m .54415 .65484 L .57331 .64825 L p .707 .577 .707 r
F P
0 g
s
.54586 .74085 m .55383 .70559 L .58268 .70701 L p .707 .577 .707 r
F P
0 g
s
.57331 .64825 m .58115 .70407 L .552 .71067 L p .707 .577 .707 r
F P
0 g
s
.58268 .70701 m .57471 .74227 L .54586 .74085 L p .707 .577 .707 r
F P
0 g
s
.5524 .81067 m .55029 .79205 L .57953 .78609 L p .707 .577 .707 r
F P
0 g
s
.57953 .78609 m .58163 .80471 L .5524 .81067 L p .707 .577 .707 r
F P
0 g
s
.53673 .3197 m .5326 .82113 L .57408 .81662 L p .707 .577 .707 r
F P
0 g
s
.58115 .70407 m .57331 .64825 L .60486 .64342 L p .707 .577 .707 r
F P
0 g
s
.57408 .81662 m .57821 .3152 L .53673 .3197 L p .707 .577 .707 r
F P
0 g
s
.44365 .81885 m .44778 .31742 L .40902 .31085 L p .707 .577 .707 r
F P
0 g
s
.44778 .31742 m .44365 .81885 L .48766 .8219 L p .707 .577 .707 r
F P
0 g
s
.70601 .76879 m .69805 .80405 L .69549 .79243 L p .707 .577 .707 r
F P
0 g
s
.69549 .79243 m .70052 .77015 L p .70601 .76879 L .707 .577 .707 r
F P
0 g
s
.70346 .75716 m .69549 .79243 L .68343 .77974 L p .707 .577 .707 r
F P
0 g
s
.69238 .80298 m .69125 .79299 L p .70272 .78966 L .707 .577 .707 r
F P
0 g
s
.69125 .79299 m .69028 .78435 L .6941 .78598 L p .707 .577 .707 r
F P
0 g
s
.6941 .78598 m .70272 .78966 L p .69125 .79299 L .707 .577 .707 r
F P
0 g
s
.70052 .77015 m .70346 .75716 L .70428 .7609 L p .707 .577 .707 r
F P
0 g
s
.70428 .7609 m .70601 .76879 L p .70052 .77015 L .707 .577 .707 r
F P
0 g
s
.69599 .64781 m .70384 .70364 L .69147 .69897 L p .707 .577 .707 r
F P
0 g
s
.69147 .69897 m .68363 .64314 L .69599 .64781 L p .707 .577 .707 r
F P
0 g
s
.60486 .64342 m .61271 .69925 L .58115 .70407 L p .707 .577 .707 r
F P
0 g
s
.57471 .74227 m .58268 .70701 L .61385 .71228 L p .707 .577 .707 r
F P
0 g
s
.61385 .71228 m .60588 .74754 L .57471 .74227 L p .707 .577 .707 r
F P
0 g
s
.58163 .80471 m .57953 .78609 L .61118 .78206 L p .707 .577 .707 r
F P
0 g
s
.61118 .78206 m .61329 .80068 L .58163 .80471 L p .707 .577 .707 r
F P
0 g
s
.57821 .3152 m .57408 .81662 L .60804 .80882 L p .707 .577 .707 r
F P
0 g
s
.61271 .69925 m .60486 .64342 L .63571 .64083 L p .707 .577 .707 r
F P
0 g
s
.64428 .72088 m .63632 .75615 L .60588 .74754 L p .707 .577 .707 r
F P
0 g
s
.60588 .74754 m .61385 .71228 L .64428 .72088 L p .707 .577 .707 r
F P
0 g
s
.60804 .80882 m .61217 .30739 L .57821 .3152 L p .707 .577 .707 r
F P
0 g
s
.70553 .79654 m .70763 .81517 L .70483 .80828 L p .707 .577 .707 r
F P
0 g
s
.70483 .80828 m .70272 .78966 L .70553 .79654 L p .707 .577 .707 r
F P
0 g
s
.40489 .81228 m .40902 .31085 L .3793 .30141 L p .707 .577 .707 r
F P
0 g
s
.40902 .31085 m .40489 .81228 L .44365 .81885 L p .707 .577 .707 r
F P
0 g
s
.25552 .7082 m .24767 .65238 L .21681 .65496 L p .707 .577 .707 r
F P
0 g
s
.24767 .65238 m .25552 .7082 L .28707 .70337 L p .707 .577 .707 r
F P
0 g
s
.28707 .70337 m .27922 .64755 L .24767 .65238 L p .707 .577 .707 r
F P
0 g
s
.27922 .64755 m .28707 .70337 L .31622 .69678 L p .707 .577 .707 r
F P
0 g
s
.31622 .69678 m .30837 .64096 L .27922 .64755 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22466 .71079 m .21681 .65496 L .18967 .65506 L p .707 .577 .707 r
F P
0 g
s
.21681 .65496 m .22466 .71079 L .25552 .7082 L p .707 .577 .707 r
F P
0 g
s
.30837 .64096 m .31622 .69678 L .34013 .68907 L p .707 .577 .707 r
F P
0 g
s
.34013 .68907 m .33228 .63324 L .30837 .64096 L p .707 .577 .707 r
F P
0 g
s
.68343 .77974 m .69139 .74448 L .70346 .75716 L p .707 .577 .707 r
F P
0 g
s
.68363 .64314 m .69147 .69897 L .6707 .69656 L p .707 .577 .707 r
F P
0 g
s
.6707 .69656 m .66286 .64074 L .68363 .64314 L p .707 .577 .707 r
F P
0 g
s
.63571 .64083 m .64356 .69666 L .61271 .69925 L p .707 .577 .707 r
F P
0 g
s
.64215 .78036 m .64425 .79898 L .61329 .80068 L p .707 .577 .707 r
F P
0 g
s
.61329 .80068 m .61118 .78206 L .64215 .78036 L p .707 .577 .707 r
F P
0 g
s
.61217 .30739 m .60804 .80882 L .63115 .79847 L p .707 .577 .707 r
F P
0 g
s
.63115 .79847 m .63528 .29705 L .61217 .30739 L p .707 .577 .707 r
F P
0 g
s
.18967 .65506 m .19752 .71089 L .22466 .71079 L p .707 .577 .707 r
F P
0 g
s
.24785 .77874 m .25582 .74347 L .22538 .73487 L p .707 .577 .707 r
F P
0 g
s
.25582 .74347 m .24785 .77874 L .27902 .78401 L p .707 .577 .707 r
F P
0 g
s
.27902 .78401 m .28699 .74875 L .25582 .74347 L p .707 .577 .707 r
F P
0 g
s
.19752 .71089 m .18967 .65506 L .1689 .65266 L p .707 .577 .707 r
F P
0 g
s
.70272 .78966 m .70483 .80828 L .69238 .80298 L p .707 .577 .707 r
F P
0 g
s
.21742 .77014 m .22538 .73487 L .19866 .72377 L p .707 .577 .707 r
F P
0 g
s
.22538 .73487 m .21742 .77014 L .24785 .77874 L p .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .31511 .78317 L .29449 .78737 L p .707 .577 .707 r
F P
0 g
s
.29449 .78737 m .28587 .78913 L p .29143 .79137 L .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .29449 .78737 L .29143 .79137 L .707 .577 .707 r
F
.31511 .78317 m .31721 .80179 L .34117 .79449 L p F P
0 g
s
.34117 .79449 m .33907 .77586 L .32325 .78068 L p .707 .577 .707 r
F P
0 g
s
.32325 .78068 m .31511 .78317 L p .3203 .78542 L .707 .577 .707 r
F P
0 g
s
.34117 .79449 m .32325 .78068 L .3203 .78542 L .707 .577 .707 r
F
.33907 .77586 m .34117 .79449 L .3575 .78655 L p F P
0 g
s
.3575 .78655 m .3554 .76792 L .34572 .77263 L p .707 .577 .707 r
F P
0 g
s
.34572 .77263 m .33907 .77586 L p .34358 .77848 L .707 .577 .707 r
F P
0 g
s
.3575 .78655 m .34572 .77263 L .34358 .77848 L .707 .577 .707 r
F
.34784 .77656 m .35504 .76713 L p .35568 .7455 L F P
0 g
s
.3558 .74129 m .35353 .75135 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.35353 .75135 m .34784 .77656 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .34784 .77656 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.33955 .7476 m .3371 .75845 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.3371 .75845 m .33159 .78286 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .33159 .78286 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31584 .75017 m .31287 .76333 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31287 .76333 m .30787 .78543 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.28699 .74875 m .27902 .78401 L .30787 .78543 L p .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .31584 .75017 L .28699 .74875 L p .707 .577 .707 r
F P
0 g
s
.37516 .80284 m .3793 .30141 L .36152 .29002 L p .707 .577 .707 r
F P
0 g
s
.3793 .30141 m .37516 .80284 L .40489 .81228 L p .707 .577 .707 r
F P
0 g
s
.33228 .63324 m .34013 .68907 L .35645 .68099 L p .707 .577 .707 r
F P
0 g
s
.35645 .68099 m .3486 .62516 L .33228 .63324 L p .707 .577 .707 r
F P
0 g
s
.25632 .81178 m .25422 .79315 L .22325 .79486 L p .707 .577 .707 r
F P
0 g
s
.25422 .79315 m .25632 .81178 L .28797 .80775 L p .707 .577 .707 r
F P
0 g
s
.28797 .80775 m .28587 .78913 L .25422 .79315 L p .707 .577 .707 r
F P
0 g
s
.1689 .65266 m .17675 .70848 L .19752 .71089 L p .707 .577 .707 r
F P
0 g
s
.28587 .78913 m .28797 .80775 L .31721 .80179 L p .707 .577 .707 r
F P
0 g
s
.19866 .72377 m .1907 .75904 L .21742 .77014 L p .707 .577 .707 r
F P
0 g
s
.1907 .75904 m .19866 .72377 L .17827 .71127 L p .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .33955 .7476 L .31584 .75017 L p .707 .577 .707 r
F P
0 g
s
.22325 .79486 m .22535 .81348 L .25632 .81178 L p .707 .577 .707 r
F P
0 g
s
.66286 .64074 m .6707 .69656 L .64356 .69666 L p .707 .577 .707 r
F P
0 g
s
.64356 .69666 m .63571 .64083 L .66286 .64074 L p .707 .577 .707 r
F P
0 g
s
.69139 .74448 m .68343 .77974 L .66304 .76724 L p .707 .577 .707 r
F P
0 g
s
.66304 .76724 m .671 .73198 L .69139 .74448 L p .707 .577 .707 r
F P
0 g
s
.22535 .81348 m .22325 .79486 L .196 .79407 L p .707 .577 .707 r
F P
0 g
s
.196 .79407 m .1981 .81269 L .22535 .81348 L p .707 .577 .707 r
F P
0 g
s
.17675 .70848 m .1689 .65266 L .15653 .64799 L p .707 .577 .707 r
F P
0 g
s
.17827 .71127 m .17031 .74654 L .1907 .75904 L p .707 .577 .707 r
F P
0 g
s
.69028 .78435 m .69238 .80298 L .67151 .79977 L p .707 .577 .707 r
F P
0 g
s
.67151 .79977 m .66941 .78115 L .69028 .78435 L p .707 .577 .707 r
F P
0 g
s
.671 .73198 m .66304 .76724 L .63632 .75615 L p .707 .577 .707 r
F P
0 g
s
.63632 .75615 m .64428 .72088 L .671 .73198 L p .707 .577 .707 r
F P
0 g
s
.63528 .29705 m .63115 .79847 L .64115 .78661 L p .707 .577 .707 r
F P
0 g
s
.64115 .78661 m .64528 .28518 L .63528 .29705 L p .707 .577 .707 r
F P
0 g
s
.3486 .62516 m .35645 .68099 L .36358 .67334 L p .707 .577 .707 r
F P
0 g
s
.36358 .67334 m .35573 .61751 L .3486 .62516 L p .707 .577 .707 r
F P
0 g
s
.1981 .81269 m .196 .79407 L .17512 .79086 L p .707 .577 .707 r
F P
0 g
s
.15653 .64799 m .16438 .70381 L .16524 .70414 L p .707 .577 .707 r
F P
0 g
s
.17087 .69088 m .15653 .64799 L .16524 .70414 L .707 .577 .707 r
F
.16438 .70381 m .15653 .64799 L .15378 .64151 L p F P
0 g
s
.16438 .70381 m .16108 .6844 L .16151 .69646 L .707 .577 .707 r
F
.16034 .7157 m .16422 .70438 L .16229 .69875 L F
.16254 .69948 m .16438 .70381 L p .16151 .69646 L F P
0 g
s
.15569 .72223 m .15824 .73386 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16365 .68697 m .16151 .69646 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .15569 .72223 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16151 .69646 L p .16108 .6844 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16092 .63386 L p .16161 .69515 L .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .16365 .68697 L p .16229 .69875 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .16365 .68697 L p .1628 .69488 L .707 .577 .707 r
F P
0 g
s
.16162 .6968 m .16163 .69733 L .16254 .69948 L p .707 .577 .707 r
F P
0 g
s
.16163 .69733 m .16151 .69646 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16422 .70438 m .16621 .69859 L .16229 .69875 L .707 .577 .707 r
F
.16876 .68968 m .16163 .69733 L p .16162 .69632 L F P
0 g
s
.16365 .68697 m .17085 .67754 L p .1665 .69035 L .707 .577 .707 r
F P
0 g
s
.1628 .69488 m .16365 .68697 L .1665 .69035 L .707 .577 .707 r
F
.16851 .68789 m .16876 .68968 L p .16162 .69632 L F P
0 g
s
.15824 .73386 m .16463 .70558 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16463 .70558 m .16621 .69859 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .15569 .72223 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .16851 .68789 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .16289 .71281 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .1871 .67123 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16876 .68968 m .16851 .68789 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.16524 .70414 m .17675 .70848 L p .17087 .69088 L .707 .577 .707 r
F P
0 g
s
.17031 .74654 m .17827 .71127 L .16621 .69859 L p .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .15824 .73386 L .17031 .74654 L p .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .17085 .67754 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .16876 .68968 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .18496 .68073 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .18496 .68073 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .18508 .6816 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .16289 .71281 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17914 .7065 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .16851 .68789 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16903 .68767 m .16851 .68789 L .16927 .68589 L .707 .577 .707 r
F
.16092 .63386 m .17723 .62578 L p .16927 .68589 L F P
0 g
s
.16851 .68789 m .16092 .63386 L p .16927 .68589 L .707 .577 .707 r
F P
0 g
s
.16092 .63386 m .16851 .68789 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16178 .70426 m .1628 .69488 L .1665 .69035 L .707 .577 .707 r
F
.16151 .69646 m .1628 .69488 L .16178 .70426 L F
.16162 .69632 m .16151 .69646 L .16161 .69515 L F
.16151 .69646 m .15378 .64151 L p .16161 .69515 L F P
0 g
s
.15569 .72223 m .16151 .69646 L p .16178 .70426 L .707 .577 .707 r
F P
0 g
s
.34784 .77656 m .3558 .74129 L .33955 .7476 L p .707 .577 .707 r
F P
0 g
s
.17512 .79086 m .17723 .80949 L .1981 .81269 L p .707 .577 .707 r
F P
0 g
s
.35504 .76713 m .363 .73187 L .3558 .74129 L p .707 .577 .707 r
F P
0 g
s
.35573 .61751 m .36358 .67334 L .36083 .66686 L p .707 .577 .707 r
F P
0 g
s
.36083 .66686 m .35298 .61103 L .35573 .61751 L p .707 .577 .707 r
F P
0 g
s
.3554 .76792 m .3575 .78655 L .36462 .77876 L p .707 .577 .707 r
F P
0 g
s
.36462 .77876 m .36462 .77875 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .77875 m .3554 .76792 L .36462 .77876 L .707 .577 .707 r
F
.36152 .29002 m .35743 .27779 L p .35741 .51257 L F P
0 g
s
.36252 .76013 m .3554 .76792 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36462 .77875 m .36461 .7787 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .7787 m .36252 .76013 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.363 .73187 m .35504 .76713 L .35248 .75551 L p .707 .577 .707 r
F P
0 g
s
.35248 .75551 m .35747 .7334 L p .363 .73187 L .707 .577 .707 r
F P
0 g
s
.35747 .7334 m .36045 .72024 L .36128 .72403 L p .707 .577 .707 r
F P
0 g
s
.36128 .72403 m .363 .73187 L p .35747 .7334 L .707 .577 .707 r
F P
0 g
s
.36045 .72024 m .35248 .75551 L .34071 .74313 L p .707 .577 .707 r
F P
0 g
s
.34071 .74313 m .34042 .74282 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34075 .74245 m .36045 .72024 L .34071 .74313 L .707 .577 .707 r
F
.35915 .57699 m .36152 .29002 L p .35741 .51257 L F P
0 g
s
.34937 .76656 m .3482 .75624 L p .35971 .75324 L .707 .577 .707 r
F P
0 g
s
.35094 .7495 m .35971 .75324 L p .3482 .75624 L .707 .577 .707 r
F P
0 g
s
.35298 .61103 m .36083 .66686 L .34846 .66219 L p .707 .577 .707 r
F P
0 g
s
.36252 .76013 m .36462 .77875 L .36182 .77187 L p .707 .577 .707 r
F P
0 g
s
.36182 .77187 m .35971 .75324 L .36252 .76013 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .36045 .72024 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34042 .74282 m .34084 .74094 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34084 .74094 m .34838 .70756 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.35971 .75324 m .36182 .77187 L .34937 .76656 L p .707 .577 .707 r
F P
0 g
s
.36152 .29002 m .35739 .79144 L .37516 .80284 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .35753 .7742 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35739 .79144 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35739 .79144 m .35915 .57699 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35753 .7742 m .3533 .77922 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .36483 .36022 L .36465 .40786 L .707 .577 .707 r
F
.36743 .26592 m .36693 .327 L p .36483 .36022 L F P
0 g
s
.36693 .327 m .3633 .76735 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .36743 .26592 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .35594 .45834 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35594 .45834 m .3533 .77922 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35554 .5078 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35554 .5078 m .35743 .27779 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.3482 .75624 m .34727 .74794 L .35094 .7495 L p .707 .577 .707 r
F P
0 g
s
.66941 .78115 m .67151 .79977 L .64425 .79898 L p .707 .577 .707 r
F P
0 g
s
.64425 .79898 m .64215 .78036 L .66941 .78115 L p .707 .577 .707 r
F P
0 g
s
.17723 .80949 m .17512 .79086 L .16268 .78556 L p .707 .577 .707 r
F P
0 g
s
.16268 .78556 m .16478 .80418 L .17723 .80949 L p .707 .577 .707 r
F P
0 g
s
.64528 .28518 m .64115 .78661 L .63706 .77438 L p .707 .577 .707 r
F P
0 g
s
.63706 .77438 m .64119 .27295 L .64528 .28518 L p .707 .577 .707 r
F P
0 g
s
.16478 .80418 m .16268 .78556 L .15987 .77867 L p .707 .577 .707 r
F P
0 g
s
.15987 .77867 m .16198 .79729 L .16478 .80418 L p .707 .577 .707 r
F P
0 g
s
.34846 .66219 m .34062 .60636 L .35298 .61103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64119 .27295 m .63706 .77438 L .61928 .76298 L p .707 .577 .707 r
F P
0 g
s
.61928 .76298 m .62341 .26156 L .64119 .27295 L p .707 .577 .707 r
F P
0 g
s
.16198 .79729 m .15987 .77867 L .16699 .77088 L p .707 .577 .707 r
F P
0 g
s
.16699 .77088 m .16909 .7895 L .16198 .79729 L p .707 .577 .707 r
F P
0 g
s
.34062 .60636 m .34846 .66219 L .32769 .65978 L p .707 .577 .707 r
F P
0 g
s
.32769 .65978 m .31985 .60396 L .34062 .60636 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .36743 .26592 L .39054 .25558 L p .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .21082 .66867 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .18496 .68073 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .1871 .67123 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.21082 .66867 m .20924 .67565 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.20114 .61806 m .20899 .67389 L .193 .67905 L p .707 .577 .707 r
F P
0 g
s
.193 .67905 m .18508 .6816 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18532 .68065 m .20114 .61806 L .193 .67905 L .707 .577 .707 r
F
.20285 .70393 m .17914 .7065 L p .20406 .67674 L F P
0 g
s
.20924 .67565 m .20285 .70393 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .18496 .68073 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .20114 .61806 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17723 .62578 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.31985 .60396 m .32769 .65978 L .30055 .65988 L p .707 .577 .707 r
F P
0 g
s
.30055 .65988 m .2927 .60405 L .31985 .60396 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .34042 .74282 L .32003 .73032 L p .707 .577 .707 r
F P
0 g
s
.32003 .73032 m .32799 .69506 L .34838 .70756 L p .707 .577 .707 r
F P
0 g
s
.16909 .7895 m .16699 .77088 L .18333 .76294 L p .707 .577 .707 r
F P
0 g
s
.18333 .76294 m .18543 .78156 L .16909 .7895 L p .707 .577 .707 r
F P
0 g
s
.62341 .26156 m .61928 .76298 L .58956 .75354 L p .707 .577 .707 r
F P
0 g
s
.58956 .75354 m .59369 .25211 L .62341 .26156 L p .707 .577 .707 r
F P
0 g
s
.20899 .67389 m .20114 .61806 L .2303 .61147 L p .707 .577 .707 r
F P
0 g
s
.34727 .74794 m .34937 .76656 L .3285 .76336 L p .707 .577 .707 r
F P
0 g
s
.3285 .76336 m .3264 .74474 L .34727 .74794 L p .707 .577 .707 r
F P
0 g
s
.2927 .60405 m .30055 .65988 L .2697 .66247 L p .707 .577 .707 r
F P
0 g
s
.2697 .66247 m .26185 .60664 L .2927 .60405 L p .707 .577 .707 r
F P
0 g
s
.39054 .25558 m .38641 .75701 L .3633 .76735 L p .707 .577 .707 r
F P
0 g
s
.38641 .75701 m .39054 .25558 L .4245 .24777 L p .707 .577 .707 r
F P
0 g
s
.20285 .70393 m .21082 .66867 L .23967 .67009 L p .707 .577 .707 r
F P
0 g
s
.32799 .69506 m .32003 .73032 L .29331 .71923 L p .707 .577 .707 r
F P
0 g
s
.29331 .71923 m .30127 .68396 L .32799 .69506 L p .707 .577 .707 r
F P
0 g
s
.23815 .6673 m .2303 .61147 L .26185 .60664 L p .707 .577 .707 r
F P
0 g
s
.2303 .61147 m .23815 .6673 L .20899 .67389 L p .707 .577 .707 r
F P
0 g
s
.73573 .65294 m .72788 .59712 L .69703 .59971 L p .707 .577 .707 r
F P
0 g
s
.72788 .59712 m .73573 .65294 L .76728 .64811 L p .707 .577 .707 r
F P
0 g
s
.76728 .64811 m .75943 .59229 L .72788 .59712 L p .707 .577 .707 r
F P
0 g
s
.26185 .60664 m .2697 .66247 L .23815 .6673 L p .707 .577 .707 r
F P
0 g
s
.75943 .59229 m .76728 .64811 L .79644 .64152 L p .707 .577 .707 r
F P
0 g
s
.79644 .64152 m .78859 .5857 L .75943 .59229 L p .707 .577 .707 r
F P
0 g
s
.18543 .78156 m .18333 .76294 L .20729 .75563 L p .707 .577 .707 r
F P
0 g
s
.20729 .75563 m .20939 .77426 L .18543 .78156 L p .707 .577 .707 r
F P
0 g
s
.70487 .65553 m .69703 .59971 L .66988 .5998 L p .707 .577 .707 r
F P
0 g
s
.69703 .59971 m .70487 .65553 L .73573 .65294 L p .707 .577 .707 r
F P
0 g
s
.23967 .67009 m .23171 .70535 L .20285 .70393 L p .707 .577 .707 r
F P
0 g
s
.23171 .70535 m .23967 .67009 L .27084 .67536 L p .707 .577 .707 r
F P
0 g
s
.30127 .68396 m .29331 .71923 L .26287 .71062 L p .707 .577 .707 r
F P
0 g
s
.26287 .71062 m .27084 .67536 L .30127 .68396 L p .707 .577 .707 r
F P
0 g
s
.3264 .74474 m .3285 .76336 L .30124 .76257 L p .707 .577 .707 r
F P
0 g
s
.30124 .76257 m .29914 .74395 L .3264 .74474 L p .707 .577 .707 r
F P
0 g
s
.78859 .5857 m .79644 .64152 L .82034 .63381 L p .707 .577 .707 r
F P
0 g
s
.82034 .63381 m .8125 .57798 L .78859 .5857 L p .707 .577 .707 r
F P
0 g
s
.59369 .25211 m .58956 .75354 L .55079 .74697 L p .707 .577 .707 r
F P
0 g
s
.55079 .74697 m .55493 .24555 L .59369 .25211 L p .707 .577 .707 r
F P
0 g
s
.27084 .67536 m .26287 .71062 L .23171 .70535 L p .707 .577 .707 r
F P
0 g
s
.66988 .5998 m .67773 .65563 L .70487 .65553 L p .707 .577 .707 r
F P
0 g
s
.72806 .72362 m .73603 .68836 L .70559 .67975 L p .707 .577 .707 r
F P
0 g
s
.73603 .68836 m .72806 .72362 L .75923 .72889 L p .707 .577 .707 r
F P
0 g
s
.75923 .72889 m .7672 .69363 L .73603 .68836 L p .707 .577 .707 r
F P
0 g
s
.20939 .77426 m .20729 .75563 L .23652 .74967 L p .707 .577 .707 r
F P
0 g
s
.67773 .65563 m .66988 .5998 L .64911 .5974 L p .707 .577 .707 r
F P
0 g
s
.42036 .7492 m .4245 .24777 L .46598 .24326 L p .707 .577 .707 r
F P
0 g
s
.4245 .24777 m .42036 .7492 L .38641 .75701 L p .707 .577 .707 r
F P
0 g
s
.69763 .71502 m .70559 .67975 L .67887 .66866 L p .707 .577 .707 r
F P
0 g
s
.70559 .67975 m .69763 .71502 L .72806 .72362 L p .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .79532 .72754 L .77506 .73167 L p .707 .577 .707 r
F P
0 g
s
.77506 .73167 m .76608 .7335 L p .77187 .73584 L .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .77506 .73167 L .77187 .73584 L .707 .577 .707 r
F
.79532 .72754 m .79742 .74617 L .82138 .73886 L p F P
0 g
s
.82138 .73886 m .81928 .72024 L .80377 .72497 L p .707 .577 .707 r
F P
0 g
s
.80377 .72497 m .79532 .72754 L p .80071 .72988 L .707 .577 .707 r
F P
0 g
s
.82138 .73886 m .80377 .72497 L .80071 .72988 L .707 .577 .707 r
F
.81928 .72024 m .82138 .73886 L .83772 .73092 L p F P
0 g
s
.83772 .73092 m .83562 .7123 L .82613 .71691 L p .707 .577 .707 r
F P
0 g
s
.82613 .71691 m .81928 .72024 L p .82392 .72293 L .707 .577 .707 r
F P
0 g
s
.83772 .73092 m .82613 .71691 L .82392 .72293 L .707 .577 .707 r
F
.82805 .72144 m .83525 .71201 L p .8359 .69031 L F P
0 g
s
.83602 .68617 m .83378 .69607 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.83378 .69607 m .82805 .72144 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .82805 .72144 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81977 .69248 m .81735 .70317 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81735 .70317 m .8118 .72775 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .8118 .72775 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79605 .69505 m .79312 .70804 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79312 .70804 m .78809 .73031 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.7672 .69363 m .75923 .72889 L .78809 .73031 L p .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .79605 .69505 L .7672 .69363 L p .707 .577 .707 r
F P
0 g
s
.23652 .74967 m .23862 .7683 L .20939 .77426 L p .707 .577 .707 r
F P
0 g
s
.29914 .74395 m .30124 .76257 L .27028 .76427 L p .707 .577 .707 r
F P
0 g
s
.27028 .76427 m .26817 .74565 L .29914 .74395 L p .707 .577 .707 r
F P
0 g
s
.8125 .57798 m .82034 .63381 L .83666 .62573 L p .707 .577 .707 r
F P
0 g
s
.83666 .62573 m .82881 .5699 L .8125 .57798 L p .707 .577 .707 r
F P
0 g
s
.23862 .7683 m .23652 .74967 L .26817 .74565 L p .707 .577 .707 r
F P
0 g
s
.73653 .75615 m .73443 .73753 L .70346 .73923 L p .707 .577 .707 r
F P
0 g
s
.73443 .73753 m .73653 .75615 L .76819 .75212 L p .707 .577 .707 r
F P
0 g
s
.76819 .75212 m .76608 .7335 L .73443 .73753 L p .707 .577 .707 r
F P
0 g
s
.26817 .74565 m .27028 .76427 L .23862 .7683 L p .707 .577 .707 r
F P
0 g
s
.64911 .5974 m .65696 .65322 L .67773 .65563 L p .707 .577 .707 r
F P
0 g
s
.55493 .24555 m .55079 .74697 L .50679 .74392 L p .707 .577 .707 r
F P
0 g
s
.50679 .74392 m .51092 .2425 L .55493 .24555 L p .707 .577 .707 r
F P
0 g
s
.76608 .7335 m .76819 .75212 L .79742 .74617 L p .707 .577 .707 r
F P
0 g
s
.67887 .66866 m .67091 .70392 L .69763 .71502 L p .707 .577 .707 r
F P
0 g
s
.67091 .70392 m .67887 .66866 L .65849 .65615 L p .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .81977 .69248 L .79605 .69505 L p .707 .577 .707 r
F P
0 g
s
.70346 .73923 m .70556 .75785 L .73653 .75615 L p .707 .577 .707 r
F P
0 g
s
.46184 .74469 m .46598 .24326 L .51092 .2425 L p .707 .577 .707 r
F P
0 g
s
.46598 .24326 m .46184 .74469 L .42036 .7492 L p .707 .577 .707 r
F P
0 g
s
.70556 .75785 m .70346 .73923 L .67621 .73844 L p .707 .577 .707 r
F P
0 g
s
.51092 .2425 m .50679 .74392 L .46184 .74469 L p .707 .577 .707 r
F P
0 g
s
.67621 .73844 m .67831 .75706 L .70556 .75785 L p .707 .577 .707 r
F P
0 g
s
.65696 .65322 m .64911 .5974 L .63675 .59273 L p .707 .577 .707 r
F P
0 g
s
.65849 .65615 m .65052 .69142 L .67091 .70392 L p .707 .577 .707 r
F P
0 g
s
.82881 .5699 m .83666 .62573 L .8438 .61808 L p .707 .577 .707 r
F P
0 g
s
.8438 .61808 m .83595 .56225 L .82881 .5699 L p .707 .577 .707 r
F P
0 g
s
.67831 .75706 m .67621 .73844 L .65534 .73524 L p .707 .577 .707 r
F P
0 g
s
.63675 .59273 m .64459 .64855 L .6455 .64889 L p .707 .577 .707 r
F P
0 g
s
.6511 .63568 m .63675 .59273 L .6455 .64889 L .707 .577 .707 r
F
.64459 .64855 m .63675 .59273 L .634 .58625 L p F P
0 g
s
.64459 .64855 m .6413 .62921 L .64173 .64129 L .707 .577 .707 r
F
.64055 .66054 m .64445 .64922 L .64251 .64357 L F
.64266 .64401 m .64459 .64855 L p .64173 .64129 L F P
0 g
s
.6359 .66711 m .63846 .67874 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64386 .63185 m .64173 .64129 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .6359 .66711 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64173 .64129 L p .6413 .62921 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64113 .5786 L p .64182 .6401 L .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .64386 .63185 L p .64251 .64357 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .64386 .63185 L p .64302 .63971 L .707 .577 .707 r
F P
0 g
s
.64184 .64159 m .64184 .64207 L .64266 .64401 L p .707 .577 .707 r
F P
0 g
s
.64184 .64207 m .64173 .64129 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64445 .64922 m .64642 .64347 L .64251 .64357 L .707 .577 .707 r
F
.64898 .63442 m .64184 .64207 L p .64183 .64116 L F P
0 g
s
.64386 .63185 m .65106 .62242 L p .64674 .63516 L .707 .577 .707 r
F P
0 g
s
.64302 .63971 m .64386 .63185 L .64674 .63516 L .707 .577 .707 r
F
.64874 .63272 m .64898 .63442 L p .64183 .64116 L F P
0 g
s
.63846 .67874 m .64486 .65041 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.64486 .65041 m .64642 .64347 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .6359 .66711 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .64874 .63272 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .6431 .65769 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .66732 .61612 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64898 .63442 m .64874 .63272 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.6455 .64889 m .65696 .65322 L p .6511 .63568 L .707 .577 .707 r
F P
0 g
s
.65052 .69142 m .65849 .65615 L .64642 .64347 L p .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .63846 .67874 L .65052 .69142 L p .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .65106 .62242 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .64898 .63442 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .66518 .62555 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .66518 .62555 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .6653 .62634 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .6431 .65769 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65935 .65138 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .64874 .63272 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64923 .63251 m .64874 .63272 L .64945 .63082 L .707 .577 .707 r
F
.64113 .5786 m .65745 .57052 L p .64945 .63082 L F P
0 g
s
.64874 .63272 m .64113 .5786 L p .64945 .63082 L .707 .577 .707 r
F P
0 g
s
.64113 .5786 m .64874 .63272 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64201 .64911 m .64302 .63971 L .64674 .63516 L .707 .577 .707 r
F
.64173 .64129 m .64302 .63971 L .64201 .64911 L F
.64183 .64116 m .64173 .64129 L .64182 .6401 L F
.64173 .64129 m .634 .58625 L p .64182 .6401 L F P
0 g
s
.6359 .66711 m .64173 .64129 L p .64201 .64911 L .707 .577 .707 r
F P
0 g
s
.82805 .72144 m .83602 .68617 L .81977 .69248 L p .707 .577 .707 r
F P
0 g
s
.65534 .73524 m .65744 .75386 L .67831 .75706 L p .707 .577 .707 r
F P
0 g
s
.65744 .75386 m .65534 .73524 L .64289 .72993 L p .707 .577 .707 r
F P
0 g
s
.83525 .71201 m .84322 .67675 L .83602 .68617 L p .707 .577 .707 r
F P
0 g
s
.64289 .72993 m .64499 .74856 L .65744 .75386 L p .707 .577 .707 r
F P
0 g
s
.83595 .56225 m .8438 .61808 L .84104 .6116 L p .707 .577 .707 r
F P
0 g
s
.84104 .6116 m .8332 .55577 L .83595 .56225 L p .707 .577 .707 r
F P
0 g
s
.83562 .7123 m .83772 .73092 L .84483 .72313 L p .707 .577 .707 r
F P
0 g
s
.84483 .72313 m .84273 .7045 L .83562 .7123 L p .707 .577 .707 r
F P
0 g
s
.64499 .74856 m .64289 .72993 L .64009 .72304 L p .707 .577 .707 r
F P
0 g
s
.64009 .72304 m .64219 .74167 L .64499 .74856 L p .707 .577 .707 r
F P
0 g
s
.84322 .67675 m .83525 .71201 L .8327 .70039 L p .707 .577 .707 r
F P
0 g
s
.8327 .70039 m .83773 .67812 L p .84322 .67675 L .707 .577 .707 r
F P
0 g
s
.84066 .66512 m .8327 .70039 L .82063 .68771 L p .707 .577 .707 r
F P
0 g
s
.82958 .71094 m .82846 .70095 L p .83993 .69762 L .707 .577 .707 r
F P
0 g
s
.82846 .70095 m .82748 .69231 L .8313 .69394 L p .707 .577 .707 r
F P
0 g
s
.8313 .69394 m .83993 .69762 L p .82846 .70095 L .707 .577 .707 r
F P
0 g
s
.83773 .67812 m .84066 .66512 L .84148 .66886 L p .707 .577 .707 r
F P
0 g
s
.84148 .66886 m .84322 .67675 L p .83773 .67812 L .707 .577 .707 r
F P
0 g
s
.8332 .55577 m .84104 .6116 L .82868 .60693 L p .707 .577 .707 r
F P
0 g
s
.82868 .60693 m .82083 .5511 L .8332 .55577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84273 .7045 m .84483 .72313 L .84203 .71624 L p .707 .577 .707 r
F P
0 g
s
.84203 .71624 m .83993 .69762 L .84273 .7045 L p .707 .577 .707 r
F P
0 g
s
.39272 .61616 m .38487 .56034 L .35402 .56293 L p .707 .577 .707 r
F P
0 g
s
.38487 .56034 m .39272 .61616 L .42427 .61134 L p .707 .577 .707 r
F P
0 g
s
.42427 .61134 m .41642 .55551 L .38487 .56034 L p .707 .577 .707 r
F P
0 g
s
.41642 .55551 m .42427 .61134 L .45343 .60474 L p .707 .577 .707 r
F P
0 g
s
.45343 .60474 m .44558 .54892 L .41642 .55551 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36186 .61875 m .35402 .56293 L .32687 .56302 L p .707 .577 .707 r
F P
0 g
s
.35402 .56293 m .36186 .61875 L .39272 .61616 L p .707 .577 .707 r
F P
0 g
s
.64219 .74167 m .64009 .72304 L .6472 .71525 L p .707 .577 .707 r
F P
0 g
s
.44558 .54892 m .45343 .60474 L .47733 .59703 L p .707 .577 .707 r
F P
0 g
s
.47733 .59703 m .46949 .5412 L .44558 .54892 L p .707 .577 .707 r
F P
0 g
s
.82063 .68771 m .8286 .65244 L .84066 .66512 L p .707 .577 .707 r
F P
0 g
s
.6472 .71525 m .64931 .73388 L .64219 .74167 L p .707 .577 .707 r
F P
0 g
s
.82083 .5511 m .82868 .60693 L .80791 .60452 L p .707 .577 .707 r
F P
0 g
s
.80791 .60452 m .80006 .5487 L .82083 .5511 L p .707 .577 .707 r
F P
0 g
s
.32687 .56302 m .33472 .61885 L .36186 .61875 L p .707 .577 .707 r
F P
0 g
s
.38505 .6867 m .39302 .65144 L .36258 .64283 L p .707 .577 .707 r
F P
0 g
s
.39302 .65144 m .38505 .6867 L .41622 .69197 L p .707 .577 .707 r
F P
0 g
s
.41622 .69197 m .42419 .65671 L .39302 .65144 L p .707 .577 .707 r
F P
0 g
s
.33472 .61885 m .32687 .56302 L .3061 .56062 L p .707 .577 .707 r
F P
0 g
s
.83993 .69762 m .84203 .71624 L .82958 .71094 L p .707 .577 .707 r
F P
0 g
s
.35462 .6781 m .36258 .64283 L .33586 .63174 L p .707 .577 .707 r
F P
0 g
s
.36258 .64283 m .35462 .6781 L .38505 .6867 L p .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .45231 .69113 L .4317 .69533 L p .707 .577 .707 r
F P
0 g
s
.4317 .69533 m .42307 .69709 L p .42863 .69934 L .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .4317 .69533 L .42863 .69934 L .707 .577 .707 r
F
.45231 .69113 m .45441 .70975 L .47837 .70245 L p F P
0 g
s
.47837 .70245 m .47627 .68382 L .46045 .68865 L p .707 .577 .707 r
F P
0 g
s
.46045 .68865 m .45231 .69113 L p .4575 .69338 L .707 .577 .707 r
F P
0 g
s
.47837 .70245 m .46045 .68865 L .4575 .69338 L .707 .577 .707 r
F
.47627 .68382 m .47837 .70245 L .49471 .69451 L p F P
0 g
s
.49471 .69451 m .49261 .67589 L .48293 .68059 L p .707 .577 .707 r
F P
0 g
s
.48293 .68059 m .47627 .68382 L p .48078 .68644 L .707 .577 .707 r
F P
0 g
s
.49471 .69451 m .48293 .68059 L .48078 .68644 L .707 .577 .707 r
F
.48504 .68452 m .49224 .67509 L p .49288 .65346 L F P
0 g
s
.49301 .64925 m .49074 .65932 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.49074 .65932 m .48504 .68452 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .48504 .68452 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.47676 .65556 m .4743 .66642 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.4743 .66642 m .46879 .69083 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .46879 .69083 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45304 .65813 m .45007 .67129 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45007 .67129 m .44508 .69339 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.42419 .65671 m .41622 .69197 L .44508 .69339 L p .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .45304 .65813 L .42419 .65671 L p .707 .577 .707 r
F P
0 g
s
.46949 .5412 m .47733 .59703 L .49365 .58895 L p .707 .577 .707 r
F P
0 g
s
.49365 .58895 m .4858 .53313 L .46949 .5412 L p .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .69103 .61355 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .66518 .62555 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .66732 .61612 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.69103 .61355 m .68946 .62048 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.68136 .5628 m .6892 .61863 L .67243 .62404 L p .707 .577 .707 r
F P
0 g
s
.67243 .62404 m .6653 .62634 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66551 .62549 m .68136 .5628 L .67243 .62404 L .707 .577 .707 r
F
.68307 .64881 m .65935 .65138 L p .68432 .62156 L F P
0 g
s
.68946 .62048 m .68307 .64881 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .66518 .62555 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .68136 .5628 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65745 .57052 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.39352 .71974 m .39142 .70111 L .36045 .70282 L p .707 .577 .707 r
F P
0 g
s
.39142 .70111 m .39352 .71974 L .42518 .71571 L p .707 .577 .707 r
F P
0 g
s
.42518 .71571 m .42307 .69709 L .39142 .70111 L p .707 .577 .707 r
F P
0 g
s
.3061 .56062 m .31395 .61644 L .33472 .61885 L p .707 .577 .707 r
F P
0 g
s
.42307 .69709 m .42518 .71571 L .45441 .70975 L p .707 .577 .707 r
F P
0 g
s
.33586 .63174 m .3279 .667 L .35462 .6781 L p .707 .577 .707 r
F P
0 g
s
.3279 .667 m .33586 .63174 L .31547 .61923 L p .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .47676 .65556 L .45304 .65813 L p .707 .577 .707 r
F P
0 g
s
.36045 .70282 m .36255 .72144 L .39352 .71974 L p .707 .577 .707 r
F P
0 g
s
.80006 .5487 m .80791 .60452 L .78077 .60462 L p .707 .577 .707 r
F P
0 g
s
.78077 .60462 m .77292 .5488 L .80006 .5487 L p .707 .577 .707 r
F P
0 g
s
.8286 .65244 m .82063 .68771 L .80024 .6752 L p .707 .577 .707 r
F P
0 g
s
.80024 .6752 m .80821 .63994 L .8286 .65244 L p .707 .577 .707 r
F P
0 g
s
.64931 .73388 m .6472 .71525 L .66354 .70731 L p .707 .577 .707 r
F P
0 g
s
.36255 .72144 m .36045 .70282 L .3332 .70203 L p .707 .577 .707 r
F P
0 g
s
.66354 .70731 m .66564 .72594 L .64931 .73388 L p .707 .577 .707 r
F P
0 g
s
.3332 .70203 m .3353 .72065 L .36255 .72144 L p .707 .577 .707 r
F P
0 g
s
.31395 .61644 m .3061 .56062 L .29374 .55595 L p .707 .577 .707 r
F P
0 g
s
.6892 .61863 m .68136 .5628 L .71051 .55621 L p .707 .577 .707 r
F P
0 g
s
.31547 .61923 m .30751 .6545 L .3279 .667 L p .707 .577 .707 r
F P
0 g
s
.82748 .69231 m .82958 .71094 L .80871 .70773 L p .707 .577 .707 r
F P
0 g
s
.80871 .70773 m .80661 .68911 L .82748 .69231 L p .707 .577 .707 r
F P
0 g
s
.77292 .5488 m .78077 .60462 L .74991 .60721 L p .707 .577 .707 r
F P
0 g
s
.74991 .60721 m .74206 .55138 L .77292 .5488 L p .707 .577 .707 r
F P
0 g
s
.4858 .53313 m .49365 .58895 L .50079 .5813 L p .707 .577 .707 r
F P
0 g
s
.50079 .5813 m .49294 .52547 L .4858 .53313 L p .707 .577 .707 r
F P
0 g
s
.3353 .72065 m .3332 .70203 L .31233 .69882 L p .707 .577 .707 r
F P
0 g
s
.29374 .55595 m .30158 .61177 L .30244 .6121 L p .707 .577 .707 r
F P
0 g
s
.30807 .59884 m .29374 .55595 L .30244 .6121 L .707 .577 .707 r
F
.30158 .61177 m .29374 .55595 L .29099 .54947 L p F P
0 g
s
.30158 .61177 m .29828 .59237 L .29871 .60442 L .707 .577 .707 r
F
.29754 .62366 m .30142 .61234 L .29949 .60671 L F
.29974 .60744 m .30158 .61177 L p .29871 .60442 L F P
0 g
s
.29289 .63019 m .29545 .64182 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.30085 .59493 m .29871 .60442 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .29289 .63019 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29871 .60442 L p .29828 .59237 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29812 .54182 L p .29881 .60311 L .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .30085 .59493 L p .29949 .60671 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .30085 .59493 L p .3 .60284 L .707 .577 .707 r
F P
0 g
s
.29883 .60476 m .29883 .60529 L .29974 .60744 L p .707 .577 .707 r
F P
0 g
s
.29883 .60529 m .29871 .60442 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.30142 .61234 m .30341 .60655 L .29949 .60671 L .707 .577 .707 r
F
.30597 .59764 m .29883 .60529 L p .29882 .60428 L F P
0 g
s
.30085 .59493 m .30805 .5855 L p .30371 .59831 L .707 .577 .707 r
F P
0 g
s
.3 .60284 m .30085 .59493 L .30371 .59831 L .707 .577 .707 r
F
.30572 .59586 m .30597 .59764 L p .29882 .60428 L F P
0 g
s
.29545 .64182 m .30183 .61354 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30183 .61354 m .30341 .60655 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .29289 .63019 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .30572 .59586 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30009 .62077 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .32431 .57919 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30597 .59764 m .30572 .59586 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.30244 .6121 m .31395 .61644 L p .30807 .59884 L .707 .577 .707 r
F P
0 g
s
.30751 .6545 m .31547 .61923 L .30341 .60655 L p .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .29545 .64182 L .30751 .6545 L p .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30805 .5855 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .30597 .59764 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .32216 .58869 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .32216 .58869 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32229 .58956 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .30009 .62077 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31634 .61446 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .30572 .59586 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30623 .59563 m .30572 .59586 L .30647 .59385 L .707 .577 .707 r
F
.29812 .54182 m .31444 .53374 L p .30647 .59385 L F P
0 g
s
.30572 .59586 m .29812 .54182 L p .30647 .59385 L .707 .577 .707 r
F P
0 g
s
.29812 .54182 m .30572 .59586 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.29899 .61222 m .3 .60284 L .30371 .59831 L .707 .577 .707 r
F
.29871 .60442 m .3 .60284 L .29899 .61222 L F
.29882 .60428 m .29871 .60442 L .29881 .60311 L F
.29871 .60442 m .29099 .54947 L p .29881 .60311 L F P
0 g
s
.29289 .63019 m .29871 .60442 L p .29899 .61222 L .707 .577 .707 r
F P
0 g
s
.48504 .68452 m .49301 .64925 L .47676 .65556 L p .707 .577 .707 r
F P
0 g
s
.68307 .64881 m .69103 .61355 L .71988 .61497 L p .707 .577 .707 r
F P
0 g
s
.80821 .63994 m .80024 .6752 L .77352 .66411 L p .707 .577 .707 r
F P
0 g
s
.77352 .66411 m .78149 .62884 L .80821 .63994 L p .707 .577 .707 r
F P
0 g
s
.71836 .61204 m .71051 .55621 L .74206 .55138 L p .707 .577 .707 r
F P
0 g
s
.71051 .55621 m .71836 .61204 L .6892 .61863 L p .707 .577 .707 r
F P
0 g
s
.31233 .69882 m .31443 .71745 L .3353 .72065 L p .707 .577 .707 r
F P
0 g
s
.74206 .55138 m .74991 .60721 L .71836 .61204 L p .707 .577 .707 r
F P
0 g
s
.66564 .72594 m .66354 .70731 L .6875 .70001 L p .707 .577 .707 r
F P
0 g
s
.6875 .70001 m .6896 .71863 L .66564 .72594 L p .707 .577 .707 r
F P
0 g
s
.71988 .61497 m .71192 .65023 L .68307 .64881 L p .707 .577 .707 r
F P
0 g
s
.71192 .65023 m .71988 .61497 L .75105 .62024 L p .707 .577 .707 r
F P
0 g
s
.78149 .62884 m .77352 .66411 L .74309 .6555 L p .707 .577 .707 r
F P
0 g
s
.74309 .6555 m .75105 .62024 L .78149 .62884 L p .707 .577 .707 r
F P
0 g
s
.80661 .68911 m .80871 .70773 L .78146 .70694 L p .707 .577 .707 r
F P
0 g
s
.78146 .70694 m .77936 .68832 L .80661 .68911 L p .707 .577 .707 r
F P
0 g
s
.75105 .62024 m .74309 .6555 L .71192 .65023 L p .707 .577 .707 r
F P
0 g
s
.31443 .71745 m .31233 .69882 L .29988 .69352 L p .707 .577 .707 r
F P
0 g
s
.49224 .67509 m .50021 .63983 L .49301 .64925 L p .707 .577 .707 r
F P
0 g
s
.6896 .71863 m .6875 .70001 L .71674 .69405 L p .707 .577 .707 r
F P
0 g
s
.29988 .69352 m .30198 .71214 L .31443 .71745 L p .707 .577 .707 r
F P
0 g
s
.49294 .52547 m .50079 .5813 L .49803 .57482 L p .707 .577 .707 r
F P
0 g
s
.49803 .57482 m .49019 .51899 L .49294 .52547 L p .707 .577 .707 r
F P
0 g
s
.71674 .69405 m .71884 .71267 L .6896 .71863 L p .707 .577 .707 r
F P
0 g
s
.77936 .68832 m .78146 .70694 L .75049 .70865 L p .707 .577 .707 r
F P
0 g
s
.75049 .70865 m .74839 .69002 L .77936 .68832 L p .707 .577 .707 r
F P
0 g
s
.49261 .67589 m .49471 .69451 L .50182 .68672 L p .707 .577 .707 r
F P
0 g
s
.50182 .68672 m .49972 .66809 L .49261 .67589 L p .707 .577 .707 r
F P
0 g
s
.71884 .71267 m .71674 .69405 L .74839 .69002 L p .707 .577 .707 r
F P
0 g
s
.74839 .69002 m .75049 .70865 L .71884 .71267 L p .707 .577 .707 r
F P
0 g
s
.30198 .71214 m .29988 .69352 L .29708 .68663 L p .707 .577 .707 r
F P
0 g
s
.50021 .63983 m .49224 .67509 L .48969 .66347 L p .707 .577 .707 r
F P
0 g
s
.48969 .66347 m .49468 .64136 L p .50021 .63983 L .707 .577 .707 r
F P
0 g
s
.49765 .6282 m .48969 .66347 L .47762 .65079 L p .707 .577 .707 r
F P
0 g
s
.48657 .67452 m .48541 .6642 L p .49692 .66121 L .707 .577 .707 r
F P
0 g
s
.48541 .6642 m .48447 .6559 L .48814 .65747 L p .707 .577 .707 r
F P
0 g
s
.48814 .65747 m .49692 .66121 L p .48541 .6642 L .707 .577 .707 r
F P
0 g
s
.49468 .64136 m .49765 .6282 L .49848 .63199 L p .707 .577 .707 r
F P
0 g
s
.49848 .63199 m .50021 .63983 L p .49468 .64136 L .707 .577 .707 r
F P
0 g
s
.29708 .68663 m .29918 .70526 L .30198 .71214 L p .707 .577 .707 r
F P
0 g
s
.49019 .51899 m .49803 .57482 L .48567 .57015 L p .707 .577 .707 r
F P
0 g
s
.48567 .57015 m .47782 .51432 L .49019 .51899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49972 .66809 m .50182 .68672 L .49902 .67983 L p .707 .577 .707 r
F P
0 g
s
.49902 .67983 m .49692 .66121 L .49972 .66809 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29918 .70526 m .29708 .68663 L .30419 .67884 L p .707 .577 .707 r
F P
0 g
s
.47762 .65079 m .48559 .61552 L .49765 .6282 L p .707 .577 .707 r
F P
0 g
s
.30419 .67884 m .30629 .69746 L .29918 .70526 L p .707 .577 .707 r
F P
0 g
s
.47782 .51432 m .48567 .57015 L .4649 .56774 L p .707 .577 .707 r
F P
0 g
s
.4649 .56774 m .45705 .51192 L .47782 .51432 L p .707 .577 .707 r
F P
0 g
s
.49692 .66121 m .49902 .67983 L .48657 .67452 L p .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .34802 .57663 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .32216 .58869 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32431 .57919 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.34802 .57663 m .34644 .58362 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.33835 .52602 m .34619 .58185 L .3302 .58701 L p .707 .577 .707 r
F P
0 g
s
.3302 .58701 m .32229 .58956 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32253 .58861 m .33835 .52602 L .3302 .58701 L .707 .577 .707 r
F
.34005 .61189 m .31634 .61446 L p .34126 .5847 L F P
0 g
s
.34644 .58362 m .34005 .61189 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .32216 .58869 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .33835 .52602 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31444 .53374 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.45705 .51192 m .4649 .56774 L .43776 .56784 L p .707 .577 .707 r
F P
0 g
s
.43776 .56784 m .42991 .51202 L .45705 .51192 L p .707 .577 .707 r
F P
0 g
s
.48559 .61552 m .47762 .65079 L .45723 .63828 L p .707 .577 .707 r
F P
0 g
s
.45723 .63828 m .4652 .60302 L .48559 .61552 L p .707 .577 .707 r
F P
0 g
s
.30629 .69746 m .30419 .67884 L .32053 .6709 L p .707 .577 .707 r
F P
0 g
s
.32053 .6709 m .32263 .68952 L .30629 .69746 L p .707 .577 .707 r
F P
0 g
s
.34619 .58185 m .33835 .52602 L .3675 .51943 L p .707 .577 .707 r
F P
0 g
s
.48447 .6559 m .48657 .67452 L .4657 .67132 L p .707 .577 .707 r
F P
0 g
s
.4657 .67132 m .4636 .6527 L .48447 .6559 L p .707 .577 .707 r
F P
0 g
s
.42991 .51202 m .43776 .56784 L .4069 .57043 L p .707 .577 .707 r
F P
0 g
s
.4069 .57043 m .39905 .5146 L .42991 .51202 L p .707 .577 .707 r
F P
0 g
s
.34005 .61189 m .34802 .57663 L .37687 .57805 L p .707 .577 .707 r
F P
0 g
s
.4652 .60302 m .45723 .63828 L .43051 .62719 L p .707 .577 .707 r
F P
0 g
s
.43051 .62719 m .43848 .59192 L .4652 .60302 L p .707 .577 .707 r
F P
0 g
s
.37535 .57526 m .3675 .51943 L .39905 .5146 L p .707 .577 .707 r
F P
0 g
s
.3675 .51943 m .37535 .57526 L .34619 .58185 L p .707 .577 .707 r
F P
0 g
s
.39905 .5146 m .4069 .57043 L .37535 .57526 L p .707 .577 .707 r
F P
0 g
s
.32263 .68952 m .32053 .6709 L .34449 .66359 L p .707 .577 .707 r
F P
0 g
s
.34449 .66359 m .34659 .68222 L .32263 .68952 L p .707 .577 .707 r
F P
0 g
s
.37687 .57805 m .36891 .61331 L .34005 .61189 L p .707 .577 .707 r
F P
0 g
s
.36891 .61331 m .37687 .57805 L .40804 .58332 L p .707 .577 .707 r
F P
0 g
s
.43848 .59192 m .43051 .62719 L .40008 .61858 L p .707 .577 .707 r
F P
0 g
s
.40008 .61858 m .40804 .58332 L .43848 .59192 L p .707 .577 .707 r
F P
0 g
s
.4636 .6527 m .4657 .67132 L .43845 .67053 L p .707 .577 .707 r
F P
0 g
s
.43845 .67053 m .43635 .65191 L .4636 .6527 L p .707 .577 .707 r
F P
0 g
s
.40804 .58332 m .40008 .61858 L .36891 .61331 L p .707 .577 .707 r
F P
0 g
s
.34659 .68222 m .34449 .66359 L .37373 .65764 L p .707 .577 .707 r
F P
0 g
s
.37373 .65764 m .37583 .67626 L .34659 .68222 L p .707 .577 .707 r
F P
0 g
s
.43635 .65191 m .43845 .67053 L .40748 .67223 L p .707 .577 .707 r
F P
0 g
s
.40748 .67223 m .40538 .65361 L .43635 .65191 L p .707 .577 .707 r
F P
0 g
s
.37583 .67626 m .37373 .65764 L .40538 .65361 L p .707 .577 .707 r
F P
0 g
s
.40538 .65361 m .40748 .67223 L .37583 .67626 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01EYF3P0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP0015YF2@0015YF00<005YF
FUH015YF00<005YFFUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IGoo001UOol00`00FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol006=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00E7oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000IOolJ000cOol0059oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Eoo`@0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00DWoo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80015oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000=Ool400000eYF
001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH01000
FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1P0000EJEP00001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800004Ool000000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP0:0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000EJEP03001JEUYF009JEPD000IJEP04001JEUYF
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001COol01000FUIJEP0015YF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001EYF0`001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool004moo`H0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF009JEPh000=JEP05001JEUYFFUH0000]Ool004Ioo`T000AJEP800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000MJEP03001JEUYF00=JEPH0009J
EP03001oogoo02]oo`00@7oo1P0015YF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEUYFFUH4000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<000=JEQ@000AJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00>7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEQ`000QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00@000EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00=7oo100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEP0000EJEP03
001JEUYF00@000IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004
FUH01000FUIJEUYF10001eYF00<005YFFUH015YF1P0025YF00<005YFFUH015YF00<005YFFUH00UYF
0P00;Woo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20004FUH3
0005FUH00`00FUIJEP040006FUH00`00FUIJEP05FUH300000eYF001JEP06FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00<7oo0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01000
1UYF10001EYF00<005YF00000P001UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH400000eYF001JEP06FUH01000
FUIJEP00<7oo000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH40002FUH40006FUH50004FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001UYF0`00<Goo000]Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP04FUH01@00FUH00000FUH010001EYF1P0015YF00<005YFFUH015YF0P0000=JEP00FUH01EYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP8003=oo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00@005YFFUIJEPD000EJ
EPH000AJEP03001JEUYF00IJEP8000IJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@003Eoo`00:goo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF00<005YF00000P001EYF00<005YFFUH025YF0P0015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
=Goo000[Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEP00=7oo000[Ool01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YF00000P0015YF0P00
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF00@005YFFUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPD00003FUH0
05YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo02moo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00L000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUHB0004Ool40007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00EJEPP000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH30005FUH01000FUIJEP003Woo10000UYF
00<005YFFUH01UYF00<005YFFUH015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90007FUH01P00FUH00000FUH0009JEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00
15YF00@005YFFUH0019oo`<000QJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP04001JEUYFFUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
0eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001oogoo00Qoo`<000Qoo`8000IJEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00X000QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPl000=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH30003FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0027oo1@002Goo0P00
0eYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;7oo00<005YF00001EYF00<005YFFUH00eYF
10001UYF00<005YFFUH010001EYF00<005YFFUH01EYF10001EYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@001eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP04001JEP000002FUH20008Ool5000;Ool2
00000eYF001JEP05FUH01000FUIJEUYF0P00;Goo000/Ool01000FUIJEP0015YF00@005YFFUIJEP80
0003FUH005YF00IJEP03001JEUYF00EJEP@00003FUH005YF00EJEP80009JEP03001JEUYF00AJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH500000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00@0
05YFFUIJEP@000Qoo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool01000FUIJEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`000eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF10001Woo0`0047oo0P000eYF
00@005YFFUIJEP<002eoo`00;7oo00@005YFFUH0009JEP03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00=JEP@00004FUH00000FUH300000eYF
000000040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0`0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH010005goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUH000040002Ool01000FUIJEP0015YF1`000eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005OolA0003FUH2000^
Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0003FUH40005Ool01000FUIJEP001EYF3@0015YF00@005YFFUIJEPH000AJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPT000AJEP03001JEUYF00EJEP03001JEUYF
00@00003FUH0000002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00800003FUH0000000Ioo`04001JEUYF0005
FUH00`00FUH000020005FUH00`00FUIJEP080005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200000eYF000000020002FUH30004Ool01000FUIJEP001EYF00<005YFFUH015YF1@001eYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEPL0009JEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00004FUH005YFFUHI0004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUH000020003FUH40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool20003FUHB0007FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool2
00000eYF000000030003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01@00FUIJEUYF0000;Goo000/
Ool01000FUH000000UYF00<007ooOol03`0017oo1@001UYF00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P00
00=JEP00FUH01UYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
00<007ooOol0:goo000/Ool30003FUH3000HOol40002FUH00`00FUIJEP0200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF1P00;7oo000/Ool30003FUH00`00FUIJEP02000JOol40003FUH;0004FUH00`00FUIJEP02FUH8
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP03FUH400000goo000000020002FUH00`00FUH0
00040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP000000;7oo000/
Ool30002FUH00`00FUIJEP03FUH3000>Ool3000:Ool20004FUH00`00FUIJEP04FUH:00000eYF001J
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000300000eYF00000006Ool90003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUH0000/Ool002aoo`8000=J
EP03001JEUYF00AJEP04001JEP00000;Ool5000;Ool200000eYF001JEP05FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP<000ao
o`D0009JEP03001JEUYF00IJEP04001JEUYFFUH50005FUH2000]Ool002eoo`05001JEUYFFUH00006
FUH01000FUIJEUYF0`0027oo1@003Goo0P001UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYF001JEP07000@Ool300000goo0000000=0004FUH00`00
FUIJEP03FUH00`00Oomoo`0/Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH30005Ool5
000?Ool20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00000015YF00<007ooOol057oo2@0015YF00<005YFFUH015YF00<005YFFUH00P00;goo
000^Ool01000FUIJEP001EYF00<005YFFUH01UYF00@005YF000000Aoo`<0019oo`05001JEUYFFUH0
0002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000002@0027oo
2@0015YF00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000^Ool00`00FUH00006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH3000GOol30003FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8003=oo`00;goo0P001UYF00<005YFFUH01EYF00<005YFFUH01EYF1P00
17oo3P0000=oo`00FUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eoo`00
<7oo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJ
EP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000iOol0035oo`8000=JEP03
001JEUYF00EJEPX000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000nOol003=oo`800004FUH005YFFUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00
FUIJEP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUH000040006FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP040015Ool003Eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP8000IJEQL004Uoo`00=7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200015YF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP8000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJ
EP<000AJEP03001JEUYF00AJEP04001JEUYFFUH2001DOol0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEPd0009JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
00Ioo`00000005YF0006FUH01000FUIJEUYF0P00E7oo000`Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P0000=J
EP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000017oo0P001UYF00H005YFFUH005YF001DOol0
02moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP@000Ioo`8000=JEP04001JEUYFFUH3001DOol002ioo`8000AJEP03001JEUYF00=J
EP@000Aoo`<00003FUH0000000@000=JEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000Qoo`800003FUH005YF009J
EP03001JEP0005Aoo`00;Goo00<005YF000015YF00<005YF00000`002goo1`000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000Moo`8000=JEP8005Eoo`00;Goo00@005YFFUH000=JEP80015oo``000AJEP04001J
EUYFFUH60003FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000eYF1`000Woo
00<005YFFUH00P00EGoo000]Ool01@00FUIJEP00FUH00P0057oo0`0027oo20001EYF00@005YFFUIJ
EP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP07001EOol0
02ioo`03001JEP0000<001Uoo`H000IJEP03001JEUYF00AJEP06001JEP00001oo`0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000MJEP03001JEUYF00=JEP04001JEP00001EOol002io
o`800004FUH005YFFUH70009Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo000^Ool01000FUIJEP001EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00008000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000aoo`<000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEPl000=JEP05001JEUYFFUH0001DOol002ioo`05001JEUYFFUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000BOol30006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH0
00030008FUH00`00FUIJEP03FUH60002FUH00`00Oomoo`1BOol002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL001Uoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH6001COol0035oo`@000=JEP03001JEUYF00EJEP03001J
EUYF009JEPP002Aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF0000001C
Ool003Eooa00035oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EP0000P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0001C
Ool007aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP06001JEP00001JEWoo0UYF0P00E7oo0024OolJ000;OolI0005FUH2001DOol0
08ioo`03001JEUYF008001Moo`<00003Ool0000000T0009JEP03001JEUYF00AJEP04001JEUYFFUH2
001EOol008moo`800003FUH00000008000moo`T000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP00001GOol008moo`80009JEP03001JEUYF00l000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<005Uoo`00Sgoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00G7oo002?Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001P
Ool0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@006=oo`00TWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
1`00Igoo002FOolI001^Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5931 .75334 m .60094 .6992 L .57009 .69288 L p .707 .577 .707 r
F P
0 g
s
.60094 .6992 m .5931 .75334 L .62465 .75656 L p .707 .577 .707 r
F P
0 g
s
.62465 .75656 m .6325 .70242 L .60094 .6992 L p .707 .577 .707 r
F P
0 g
s
.6325 .70242 m .62797 .73363 L p .6538 .75634 L .707 .577 .707 r
F P
0 g
s
.65178 .75636 m .6538 .75634 L p .62797 .73363 L .707 .577 .707 r
F P
0 g
s
.6538 .75634 m .66165 .7022 L .6325 .70242 L p .707 .577 .707 r
F P
0 g
s
.66165 .7022 m .6538 .75634 L .66979 .75392 L p .707 .577 .707 r
F P
0 g
s
.67747 .75197 m .66165 .7022 L .66979 .75392 L .707 .577 .707 r
F
.68556 .69858 m .66165 .7022 L p .67727 .75134 L F P
0 g
s
.67747 .75197 m .67753 .75158 L .67727 .75134 L .707 .577 .707 r
F
.67753 .75158 m .68556 .69858 L .67727 .75134 L F
.67783 .75188 m .68556 .69858 L p .67747 .75197 L F P
0 g
s
.69991 .77044 m .68237 .74979 L .67783 .75188 L .707 .577 .707 r
F
.67783 .75188 m .68366 .7789 L .69818 .77134 L p F P
0 g
s
.69818 .77134 m .69991 .77044 L p .67783 .75188 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .67783 .75188 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.68556 .69858 m .67783 .75188 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.70188 .69192 m .68556 .69858 L p .69353 .74324 L .707 .577 .707 r
F P
0 g
s
.69376 .74456 m .69389 .74376 L .69353 .74324 L .707 .577 .707 r
F
.69389 .74376 m .70188 .69192 L .69353 .74324 L F
.69991 .77044 m .70711 .76317 L p .70635 .76169 L F P
0 g
s
.69428 .74433 m .70188 .69192 L p .69389 .74376 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69389 .74376 L .69376 .74456 L .707 .577 .707 r
F
.70101 .75123 m .70119 .73626 L .69629 .74198 L F
.70635 .76169 m .70128 .73669 L .70101 .75123 L F
.70128 .73669 m .70119 .73626 L .70101 .75123 L F
.70117 .73627 m .70119 .73544 L .69428 .74433 L F
.70188 .69192 m .69843 .7157 L p .70119 .73544 L F P
0 g
s
.69843 .7157 m .69428 .74433 L p .70119 .73544 L .707 .577 .707 r
F P
0 g
s
.70711 .76317 m .70699 .7626 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70699 .7626 m .70129 .73614 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70901 .68285 m .70188 .69192 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70901 .68285 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .69914 .72619 L p .70119 .73626 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70119 .73626 L .70635 .76169 L .707 .577 .707 r
F
.70116 .73699 m .70129 .73614 L p .70117 .73627 L F P
0 g
s
.70711 .76317 m .70455 .75778 L p .70324 .75011 L .707 .577 .707 r
F P
0 g
s
.70635 .76169 m .69629 .74198 L .69428 .74433 L .707 .577 .707 r
F
.69194 .73347 m .69428 .74433 L p .69629 .74198 L F P
0 g
s
.69428 .74433 m .69991 .77044 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.69991 .77044 m .69428 .74433 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .70102 .73717 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70102 .73717 m .70116 .73699 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70117 .73627 L .70093 .73661 L .707 .577 .707 r
F
.70119 .73626 m .69914 .72619 L .69629 .74198 L F
.69914 .72619 m .70129 .73614 L p .7005 .73413 L F P
0 g
s
.69914 .72619 m .69194 .73347 L p .69629 .74198 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69403 .74606 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70025 .73349 L p .70119 .73589 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .69914 .72619 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.70455 .75778 m .69816 .72813 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69816 .72813 m .69659 .7208 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69194 .73347 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .69428 .74433 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .69403 .74606 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67771 .75272 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .70455 .75778 L .69249 .75481 L p .707 .577 .707 r
F P
0 g
s
.70626 .67228 m .69841 .72642 L .69755 .72565 L p .707 .577 .707 r
F P
0 g
s
.69194 .73347 m .67569 .74192 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69249 .75481 m .68452 .71783 L .69659 .7208 L p .707 .577 .707 r
F P
0 g
s
.69755 .72565 m .68605 .71537 L p .69193 .70283 L .707 .577 .707 r
F P
0 g
s
.69193 .70283 m .70626 .67228 L .69755 .72565 L .707 .577 .707 r
F
.69841 .72642 m .70171 .71285 L .70119 .73589 L F
.70025 .73349 m .69841 .72642 L p .70119 .73589 L F P
0 g
s
.70129 .73614 m .70116 .73699 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.70324 .75011 m .7005 .73413 L .70129 .73614 L .707 .577 .707 r
F
.70129 .73614 m .70711 .76317 L p .70324 .75011 L F P
0 g
s
.70901 .68285 m .70129 .73614 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .67783 .75188 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .65198 .75073 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67569 .74192 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .67783 .75188 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.66979 .75392 m .67771 .75272 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .65873 .75674 L .65356 .75806 L .707 .577 .707 r
F
.65198 .75073 m .65356 .75806 L p .65873 .75674 L F P
0 g
s
.65356 .75806 m .65994 .7877 L .6777 .78111 L p .707 .577 .707 r
F P
0 g
s
.6777 .78111 m .68366 .7789 L p .65356 .75806 L .707 .577 .707 r
F P
0 g
s
.62797 .73363 m .62465 .75656 L .65178 .75636 L p .707 .577 .707 r
F P
0 g
s
.56224 .74702 m .57009 .69288 L .54295 .68407 L p .707 .577 .707 r
F P
0 g
s
.57009 .69288 m .56224 .74702 L .5931 .75334 L p .707 .577 .707 r
F P
0 g
s
.5351 .73821 m .54295 .68407 L .52218 .67363 L p .707 .577 .707 r
F P
0 g
s
.54295 .68407 m .5351 .73821 L .56224 .74702 L p .707 .577 .707 r
F P
0 g
s
.59992 .80296 m .59195 .76599 L .56152 .77095 L p .707 .577 .707 r
F P
0 g
s
.59195 .76599 m .59992 .80296 L .63109 .796 L p .707 .577 .707 r
F P
0 g
s
.63109 .796 m .62312 .75902 L .59195 .76599 L p .707 .577 .707 r
F P
0 g
s
.62312 .75902 m .63109 .796 L .65994 .7877 L p .707 .577 .707 r
F P
0 g
s
.65994 .7877 m .65198 .75073 L .62312 .75902 L p .707 .577 .707 r
F P
0 g
s
.56152 .77095 m .56948 .80792 L .59992 .80296 L p .707 .577 .707 r
F P
0 g
s
.56948 .80792 m .56152 .77095 L .5348 .77342 L p .707 .577 .707 r
F P
0 g
s
.5348 .77342 m .54276 .81039 L .56948 .80792 L p .707 .577 .707 r
F P
0 g
s
.52218 .67363 m .51433 .72777 L .5351 .73821 L p .707 .577 .707 r
F P
0 g
s
.59252 .85502 m .59462 .83685 L .56365 .83139 L p .707 .577 .707 r
F P
0 g
s
.59462 .83685 m .59252 .85502 L .62417 .85746 L p .707 .577 .707 r
F P
0 g
s
.62417 .85746 m .62627 .83928 L .59462 .83685 L p .707 .577 .707 r
F P
0 g
s
.51433 .72777 m .52218 .67363 L .50981 .66258 L p .707 .577 .707 r
F P
0 g
s
.62627 .83928 m .62417 .85746 L .65341 .85663 L p .707 .577 .707 r
F P
0 g
s
.65341 .85663 m .65551 .83845 L .62627 .83928 L p .707 .577 .707 r
F P
0 g
s
.56155 .84956 m .56365 .83139 L .5364 .82344 L p .707 .577 .707 r
F P
0 g
s
.56365 .83139 m .56155 .84956 L .59252 .85502 L p .707 .577 .707 r
F P
0 g
s
.54276 .81039 m .5348 .77342 L .51441 .77315 L p .707 .577 .707 r
F P
0 g
s
.5364 .82344 m .5343 .84161 L .56155 .84956 L p .707 .577 .707 r
F P
0 g
s
.51441 .77315 m .52238 .81013 L .54276 .81039 L p .707 .577 .707 r
F P
0 g
s
.65551 .83845 m .65341 .85663 L .67736 .85261 L p .707 .577 .707 r
F P
0 g
s
.67736 .85261 m .67947 .83444 L .65551 .83845 L p .707 .577 .707 r
F P
0 g
s
.50981 .66258 m .50196 .71672 L .51433 .72777 L p .707 .577 .707 r
F P
0 g
s
.5343 .84161 m .5364 .82344 L .51553 .81378 L p .707 .577 .707 r
F P
0 g
s
.51553 .81378 m .51342 .83195 L .5343 .84161 L p .707 .577 .707 r
F P
0 g
s
.50196 .71672 m .50981 .66258 L .50706 .652 L p .707 .577 .707 r
F P
0 g
s
.52238 .81013 m .51441 .77315 L .50235 .77018 L p .707 .577 .707 r
F P
0 g
s
.67947 .83444 m .67736 .85261 L .6937 .84581 L p .707 .577 .707 r
F P
0 g
s
.6937 .84581 m .6958 .82763 L .67947 .83444 L p .707 .577 .707 r
F P
0 g
s
.50235 .77018 m .51031 .80716 L .52238 .81013 L p .707 .577 .707 r
F P
0 g
s
.51342 .83195 m .51553 .81378 L .50308 .80334 L p .707 .577 .707 r
F P
0 g
s
.50706 .652 m .49921 .70614 L .50196 .71672 L p .707 .577 .707 r
F P
0 g
s
.50308 .80334 m .50098 .82152 L .51342 .83195 L p .707 .577 .707 r
F P
0 g
s
.69841 .72642 m .70626 .67228 L .70901 .68285 L p .707 .577 .707 r
F P
0 g
s
.49921 .70614 m .50706 .652 L .51419 .64294 L p .707 .577 .707 r
F P
0 g
s
.51031 .80716 m .50235 .77018 L .49979 .7648 L p .707 .577 .707 r
F P
0 g
s
.49321 .82176 m .48908 .31945 L .44507 .31713 L p .707 .577 .707 r
F P
0 g
s
.49979 .7648 m .50775 .80177 L .51031 .80716 L p .707 .577 .707 r
F P
0 g
s
.50098 .82152 m .50308 .80334 L .50028 .79317 L p .707 .577 .707 r
F P
0 g
s
.50028 .79317 m .49817 .81134 L .50098 .82152 L p .707 .577 .707 r
F P
0 g
s
.51419 .64294 m .50635 .69708 L .49921 .70614 L p .707 .577 .707 r
F P
0 g
s
.50635 .69708 m .51419 .64294 L .53051 .63627 L p .707 .577 .707 r
F P
0 g
s
.50775 .80177 m .49979 .7648 L .50699 .75752 L p .707 .577 .707 r
F P
0 g
s
.50699 .75752 m .51495 .79449 L .50775 .80177 L p .707 .577 .707 r
F P
0 g
s
.49817 .81134 m .50028 .79317 L .50739 .78424 L p .707 .577 .707 r
F P
0 g
s
.50739 .78424 m .50529 .80241 L .49817 .81134 L p .707 .577 .707 r
F P
0 g
s
.53051 .63627 m .52266 .69041 L .50635 .69708 L p .707 .577 .707 r
F P
0 g
s
.52266 .69041 m .53051 .63627 L .55442 .63265 L p .707 .577 .707 r
F P
0 g
s
.51495 .79449 m .50699 .75752 L .52324 .74906 L p .707 .577 .707 r
F P
0 g
s
.52324 .74906 m .53121 .78604 L .51495 .79449 L p .707 .577 .707 r
F P
0 g
s
.50529 .80241 m .50739 .78424 L .52373 .77743 L p .707 .577 .707 r
F P
0 g
s
.55442 .63265 m .54657 .68679 L .52266 .69041 L p .707 .577 .707 r
F P
0 g
s
.52373 .77743 m .52163 .79561 L .50529 .80241 L p .707 .577 .707 r
F P
0 g
s
.53121 .78604 m .52324 .74906 L .54696 .74026 L p .707 .577 .707 r
F P
0 g
s
.54696 .74026 m .55492 .77724 L .53121 .78604 L p .707 .577 .707 r
F P
0 g
s
.52163 .79561 m .52373 .77743 L .54769 .77342 L p .707 .577 .707 r
F P
0 g
s
.54769 .77342 m .54559 .79159 L .52163 .79561 L p .707 .577 .707 r
F P
0 g
s
.48908 .31945 m .49321 .82176 L .53815 .82033 L p .707 .577 .707 r
F P
0 g
s
.53815 .82033 m .53402 .31802 L .48908 .31945 L p .707 .577 .707 r
F P
0 g
s
.6958 .82763 m .6937 .84581 L .70082 .83688 L p .707 .577 .707 r
F P
0 g
s
.70082 .83688 m .70292 .81871 L .6958 .82763 L p .707 .577 .707 r
F P
0 g
s
.54657 .68679 m .55442 .63265 L .58358 .63244 L p .707 .577 .707 r
F P
0 g
s
.58358 .63244 m .57573 .68658 L .54657 .68679 L p .707 .577 .707 r
F P
0 g
s
.55492 .77724 m .54696 .74026 L .57581 .73197 L p .707 .577 .707 r
F P
0 g
s
.57581 .73197 m .58377 .76894 L .55492 .77724 L p .707 .577 .707 r
F P
0 g
s
.54559 .79159 m .54769 .77342 L .57692 .77259 L p .707 .577 .707 r
F P
0 g
s
.57692 .77259 m .57482 .79076 L .54559 .79159 L p .707 .577 .707 r
F P
0 g
s
.57482 .79076 m .57692 .77259 L .60858 .77502 L p .707 .577 .707 r
F P
0 g
s
.60858 .77502 m .60647 .79319 L .57482 .79076 L p .707 .577 .707 r
F P
0 g
s
.53402 .31802 m .53815 .82033 L .57963 .8153 L p .707 .577 .707 r
F P
0 g
s
.57573 .68658 m .58358 .63244 L .61513 .63565 L p .707 .577 .707 r
F P
0 g
s
.61513 .63565 m .60728 .68979 L .57573 .68658 L p .707 .577 .707 r
F P
0 g
s
.58377 .76894 m .57581 .73197 L .60698 .725 L p .707 .577 .707 r
F P
0 g
s
.57963 .8153 m .5755 .31298 L .53402 .31802 L p .707 .577 .707 r
F P
0 g
s
.4492 .81944 m .44507 .31713 L .40631 .3113 L p .707 .577 .707 r
F P
0 g
s
.44507 .31713 m .4492 .81944 L .49321 .82176 L p .707 .577 .707 r
F P
0 g
s
.61494 .76198 m .60698 .725 L .63741 .72004 L p .707 .577 .707 r
F P
0 g
s
.60698 .725 m .61494 .76198 L .58377 .76894 L p .707 .577 .707 r
F P
0 g
s
.63954 .78048 m .63744 .79865 L .60647 .79319 L p .707 .577 .707 r
F P
0 g
s
.60647 .79319 m .60858 .77502 L .63954 .78048 L p .707 .577 .707 r
F P
0 g
s
.5755 .31298 m .57963 .8153 L .61359 .80715 L p .707 .577 .707 r
F P
0 g
s
.64598 .64197 m .63813 .69611 L .60728 .68979 L p .707 .577 .707 r
F P
0 g
s
.60728 .68979 m .61513 .63565 L .64598 .64197 L p .707 .577 .707 r
F P
0 g
s
.61359 .80715 m .60946 .30484 L .5755 .31298 L p .707 .577 .707 r
F P
0 g
s
.68605 .71537 m .69389 .66123 L .70626 .67228 L p .707 .577 .707 r
F P
0 g
s
.25009 .71649 m .25794 .66235 L .22708 .65603 L p .707 .577 .707 r
F P
0 g
s
.25794 .66235 m .25009 .71649 L .28164 .7197 L p .707 .577 .707 r
F P
0 g
s
.28164 .7197 m .28949 .66556 L .25794 .66235 L p .707 .577 .707 r
F P
0 g
s
.41044 .81361 m .40631 .3113 L .37659 .30252 L p .707 .577 .707 r
F P
0 g
s
.40631 .3113 m .41044 .81361 L .4492 .81944 L p .707 .577 .707 r
F P
0 g
s
.70292 .81871 m .70082 .83688 L .69801 .8267 L p .707 .577 .707 r
F P
0 g
s
.69801 .8267 m .70012 .80853 L .70292 .81871 L p .707 .577 .707 r
F P
0 g
s
.28949 .66556 m .28495 .69686 L p .31079 .71949 L .707 .577 .707 r
F P
0 g
s
.30867 .71951 m .31079 .71949 L p .28495 .69686 L .707 .577 .707 r
F P
0 g
s
.31079 .71949 m .31864 .66535 L .28949 .66556 L p .707 .577 .707 r
F P
0 g
s
.31864 .66535 m .31079 .71949 L .32757 .71695 L p .707 .577 .707 r
F P
0 g
s
.33449 .71519 m .31864 .66535 L .32757 .71695 L .707 .577 .707 r
F
.34255 .66173 m .31864 .66535 L p .3343 .71462 L F P
0 g
s
.33449 .71519 m .33454 .71485 L .3343 .71462 L .707 .577 .707 r
F
.33454 .71485 m .34255 .66173 L .3343 .71462 L F
.33481 .71511 m .34255 .66173 L p .33449 .71519 L F P
0 g
s
.3569 .73373 m .33933 .71304 L .33481 .71511 L .707 .577 .707 r
F
.33481 .71511 m .34065 .74219 L .3552 .73462 L p F P
0 g
s
.3552 .73462 m .3569 .73373 L p .33481 .71511 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .33481 .71511 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.34255 .66173 m .33481 .71511 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35887 .65507 m .34255 .66173 L p .35054 .70653 L .707 .577 .707 r
F P
0 g
s
.35077 .70778 m .35089 .70702 L .35054 .70653 L .707 .577 .707 r
F
.35089 .70702 m .35887 .65507 L .35054 .70653 L F
.3569 .73373 m .3641 .72646 L p .36327 .72484 L F P
0 g
s
.35126 .70756 m .35887 .65507 L p .35089 .70702 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35089 .70702 L .35077 .70778 L .707 .577 .707 r
F
.35799 .71449 m .35816 .6995 L .35326 .70523 L F
.36327 .72484 m .35825 .69998 L .35799 .71449 L F
.35825 .69998 m .35816 .6995 L .35799 .71449 L F
.35816 .69949 m .35818 .69874 L .35126 .70756 L F
.35887 .65507 m .35541 .67893 L p .35818 .69874 L F P
0 g
s
.35541 .67893 m .35126 .70756 L p .35818 .69874 L .707 .577 .707 r
F P
0 g
s
.36345 .7251 m .36323 .72462 L .36327 .72484 L .707 .577 .707 r
F
.36396 .72583 m .36323 .72462 L .36345 .7251 L F
.366 .646 m .35887 .65507 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .35816 .6995 L .36323 .72462 L .707 .577 .707 r
F
.35815 .70014 m .35827 .69938 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .366 .646 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.36396 .72583 m .35827 .69938 L p .36323 .72462 L .707 .577 .707 r
F P
0 g
s
.35827 .69938 m .35613 .68948 L p .35816 .6995 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36396 .72583 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36154 .72107 L p .3602 .71326 L .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .35126 .70756 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .3569 .73373 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3569 .73373 m .35126 .70756 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35799 .70035 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35799 .70035 m .35815 .70014 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35816 .69949 L .35791 .69984 L .707 .577 .707 r
F
.35816 .6995 m .35613 .68948 L .35326 .70523 L F
.35613 .68948 m .35827 .69938 L p .35749 .69737 L F P
0 g
s
.35613 .68948 m .34893 .69676 L p .35326 .70523 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35102 .70921 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35733 .69699 L p .35818 .69915 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .35613 .68948 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.36154 .72107 m .35514 .69136 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35514 .69136 m .35358 .68409 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .34893 .69676 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35126 .70756 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .35102 .70921 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .3347 .71587 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .36154 .72107 L .34948 .7181 L p .707 .577 .707 r
F P
0 g
s
.36325 .63543 m .3554 .68957 L .3545 .68876 L p .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .33268 .70521 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.34948 .7181 m .34151 .68112 L .35358 .68409 L p .707 .577 .707 r
F P
0 g
s
.3545 .68876 m .34304 .67852 L p .3489 .66602 L .707 .577 .707 r
F P
0 g
s
.3489 .66602 m .36325 .63543 L .3545 .68876 L .707 .577 .707 r
F
.3554 .68957 m .35869 .67604 L .35818 .69915 L F
.35733 .69699 m .3554 .68957 L p .35818 .69915 L F P
0 g
s
.35827 .69938 m .35815 .70014 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.3602 .71326 m .35749 .69737 L .35827 .69938 L .707 .577 .707 r
F
.35827 .69938 m .3641 .72646 L p .3602 .71326 L F P
0 g
s
.366 .646 m .35827 .69938 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .33481 .71511 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .30897 .71402 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .33268 .70521 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .33481 .71511 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.32757 .71695 m .3347 .71587 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .31567 .71998 L .31053 .72129 L .707 .577 .707 r
F
.30897 .71402 m .31053 .72129 L p .31567 .71998 L F P
0 g
s
.31053 .72129 m .31693 .75099 L .33473 .74439 L p .707 .577 .707 r
F P
0 g
s
.33473 .74439 m .34065 .74219 L p .31053 .72129 L .707 .577 .707 r
F P
0 g
s
.28495 .69686 m .28164 .7197 L .30867 .71951 L p .707 .577 .707 r
F P
0 g
s
.21923 .71017 m .22708 .65603 L .19994 .64722 L p .707 .577 .707 r
F P
0 g
s
.22708 .65603 m .21923 .71017 L .25009 .71649 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69389 .66123 m .68605 .71537 L .66528 .70493 L p .707 .577 .707 r
F P
0 g
s
.66528 .70493 m .67312 .65079 L .69389 .66123 L p .707 .577 .707 r
F P
0 g
s
.63741 .72004 m .64538 .75701 L .61494 .76198 L p .707 .577 .707 r
F P
0 g
s
.60946 .30484 m .61359 .80715 L .6367 .79669 L p .707 .577 .707 r
F P
0 g
s
.6367 .79669 m .63257 .29438 L .60946 .30484 L p .707 .577 .707 r
F P
0 g
s
.19209 .70136 m .19994 .64722 L .17917 .63677 L p .707 .577 .707 r
F P
0 g
s
.19994 .64722 m .19209 .70136 L .21923 .71017 L p .707 .577 .707 r
F P
0 g
s
.25691 .76625 m .24895 .72928 L .21851 .73424 L p .707 .577 .707 r
F P
0 g
s
.24895 .72928 m .25691 .76625 L .28808 .75928 L p .707 .577 .707 r
F P
0 g
s
.28808 .75928 m .28011 .72231 L .24895 .72928 L p .707 .577 .707 r
F P
0 g
s
.28011 .72231 m .28808 .75928 L .31693 .75099 L p .707 .577 .707 r
F P
0 g
s
.31693 .75099 m .30897 .71402 L .28011 .72231 L p .707 .577 .707 r
F P
0 g
s
.21851 .73424 m .22648 .77121 L .25691 .76625 L p .707 .577 .707 r
F P
0 g
s
.22648 .77121 m .21851 .73424 L .19179 .73671 L p .707 .577 .707 r
F P
0 g
s
.70012 .80853 m .69801 .8267 L .68557 .81627 L p .707 .577 .707 r
F P
0 g
s
.68557 .81627 m .68767 .7981 L .70012 .80853 L p .707 .577 .707 r
F P
0 g
s
.38072 .80483 m .37659 .30252 L .35881 .29165 L p .707 .577 .707 r
F P
0 g
s
.37659 .30252 m .38072 .80483 L .41044 .81361 L p .707 .577 .707 r
F P
0 g
s
.19179 .73671 m .19976 .77368 L .22648 .77121 L p .707 .577 .707 r
F P
0 g
s
.17917 .63677 m .17132 .69091 L .19209 .70136 L p .707 .577 .707 r
F P
0 g
s
.68452 .71783 m .69249 .75481 L .6721 .75454 L p .707 .577 .707 r
F P
0 g
s
.6721 .75454 m .66413 .71757 L .68452 .71783 L p .707 .577 .707 r
F P
0 g
s
.24951 .81781 m .25161 .79963 L .22064 .79417 L p .707 .577 .707 r
F P
0 g
s
.25161 .79963 m .24951 .81781 L .28116 .82024 L p .707 .577 .707 r
F P
0 g
s
.28116 .82024 m .28326 .80207 L .25161 .79963 L p .707 .577 .707 r
F P
0 g
s
.67312 .65079 m .66528 .70493 L .63813 .69611 L p .707 .577 .707 r
F P
0 g
s
.63813 .69611 m .64598 .64197 L .67312 .65079 L p .707 .577 .707 r
F P
0 g
s
.17132 .69091 m .17917 .63677 L .1668 .62572 L p .707 .577 .707 r
F P
0 g
s
.28326 .80207 m .28116 .82024 L .3104 .81941 L p .707 .577 .707 r
F P
0 g
s
.3104 .81941 m .3125 .80123 L .28326 .80207 L p .707 .577 .707 r
F P
0 g
s
.21854 .81235 m .22064 .79417 L .19339 .78622 L p .707 .577 .707 r
F P
0 g
s
.22064 .79417 m .21854 .81235 L .24951 .81781 L p .707 .577 .707 r
F P
0 g
s
.19976 .77368 m .19179 .73671 L .1714 .73644 L p .707 .577 .707 r
F P
0 g
s
.19339 .78622 m .19129 .80439 L .21854 .81235 L p .707 .577 .707 r
F P
0 g
s
.1714 .73644 m .17937 .77342 L .19976 .77368 L p .707 .577 .707 r
F P
0 g
s
.66413 .71757 m .6721 .75454 L .64538 .75701 L p .707 .577 .707 r
F P
0 g
s
.64538 .75701 m .63741 .72004 L .66413 .71757 L p .707 .577 .707 r
F P
0 g
s
.63744 .79865 m .63954 .78048 L .6668 .78843 L p .707 .577 .707 r
F P
0 g
s
.63257 .29438 m .6367 .79669 L .6467 .78494 L p .707 .577 .707 r
F P
0 g
s
.6467 .78494 m .64257 .28263 L .63257 .29438 L p .707 .577 .707 r
F P
0 g
s
.3125 .80123 m .3104 .81941 L .33436 .81539 L p .707 .577 .707 r
F P
0 g
s
.33436 .81539 m .33646 .79722 L .3125 .80123 L p .707 .577 .707 r
F P
0 g
s
.1668 .62572 m .15895 .67987 L .17132 .69091 L p .707 .577 .707 r
F P
0 g
s
.68767 .7981 m .68557 .81627 L .6647 .8066 L p .707 .577 .707 r
F P
0 g
s
.6647 .8066 m .6668 .78843 L .68767 .7981 L p .707 .577 .707 r
F P
0 g
s
.19129 .80439 m .19339 .78622 L .17252 .77656 L p .707 .577 .707 r
F P
0 g
s
.17252 .77656 m .17041 .79473 L .19129 .80439 L p .707 .577 .707 r
F P
0 g
s
.15895 .67987 m .1668 .62572 L .16405 .61515 L p .707 .577 .707 r
F P
0 g
s
.17937 .77342 m .1714 .73644 L .15934 .73347 L p .707 .577 .707 r
F P
0 g
s
.3554 .68957 m .36325 .63543 L .366 .646 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .36325 .63543 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34304 .67852 m .34488 .66583 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34488 .66583 m .35088 .62438 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.36294 .79396 m .35881 .29165 L .35472 .27976 L p .707 .577 .707 r
F P
0 g
s
.35881 .29165 m .36294 .79396 L .38072 .80483 L p .707 .577 .707 r
F P
0 g
s
.35781 .79966 m .35991 .78149 L .3528 .79042 L p .707 .577 .707 r
F P
0 g
s
.35991 .78149 m .35781 .79966 L .35501 .78948 L p .707 .577 .707 r
F P
0 g
s
.35501 .78948 m .35711 .77131 L .35991 .78149 L p .707 .577 .707 r
F P
0 g
s
.35472 .27976 m .35885 .78207 L .36294 .79396 L p .707 .577 .707 r
F P
0 g
s
.35885 .78207 m .35529 .34893 L p .36472 .26801 L .707 .577 .707 r
F P
0 g
s
.35529 .34893 m .35472 .27976 L .35768 .27628 L p .707 .577 .707 r
F P
0 g
s
.35768 .27628 m .36472 .26801 L p .35529 .34893 L .707 .577 .707 r
F P
0 g
s
.33646 .79722 m .33436 .81539 L .35069 .80859 L p .707 .577 .707 r
F P
0 g
s
.35069 .80859 m .3528 .79042 L .33646 .79722 L p .707 .577 .707 r
F P
0 g
s
.15934 .73347 m .1673 .77045 L .17937 .77342 L p .707 .577 .707 r
F P
0 g
s
.6668 .78843 m .6647 .8066 L .63744 .79865 L p .707 .577 .707 r
F P
0 g
s
.17041 .79473 m .17252 .77656 L .16007 .76613 L p .707 .577 .707 r
F P
0 g
s
.16405 .61515 m .1562 .66929 L .15895 .67987 L p .707 .577 .707 r
F P
0 g
s
.16007 .76613 m .15797 .7843 L .17041 .79473 L p .707 .577 .707 r
F P
0 g
s
.1562 .66929 m .16405 .61515 L .17118 .60609 L p .707 .577 .707 r
F P
0 g
s
.64257 .28263 m .6467 .78494 L .64261 .77305 L p .707 .577 .707 r
F P
0 g
s
.64261 .77305 m .63848 .27074 L .64257 .28263 L p .707 .577 .707 r
F P
0 g
s
.1673 .77045 m .15934 .73347 L .15678 .72808 L p .707 .577 .707 r
F P
0 g
s
.3528 .79042 m .35069 .80859 L .35781 .79966 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15678 .72808 m .16474 .76506 L .1673 .77045 L p .707 .577 .707 r
F P
0 g
s
.15797 .7843 m .16007 .76613 L .15727 .75595 L p .707 .577 .707 r
F P
0 g
s
.15727 .75595 m .15516 .77412 L .15797 .7843 L p .707 .577 .707 r
F P
0 g
s
.17118 .60609 m .16334 .66023 L .1562 .66929 L p .707 .577 .707 r
F P
0 g
s
.16334 .66023 m .17118 .60609 L .1875 .59942 L p .707 .577 .707 r
F P
0 g
s
.16474 .76506 m .15678 .72808 L .16398 .72081 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16398 .72081 m .17194 .75778 L .16474 .76506 L p .707 .577 .707 r
F P
0 g
s
.15516 .77412 m .15727 .75595 L .16438 .74702 L p .707 .577 .707 r
F P
0 g
s
.63848 .27074 m .64261 .77305 L .62483 .76219 L p .707 .577 .707 r
F P
0 g
s
.62483 .76219 m .6207 .25987 L .63848 .27074 L p .707 .577 .707 r
F P
0 g
s
.16438 .74702 m .16228 .76519 L .15516 .77412 L p .707 .577 .707 r
F P
0 g
s
.1875 .59942 m .17966 .65356 L .16334 .66023 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .34304 .67852 L .32227 .66807 L p .707 .577 .707 r
F P
0 g
s
.32227 .66807 m .33011 .61393 L .35088 .62438 L p .707 .577 .707 r
F P
0 g
s
.17966 .65356 m .1875 .59942 L .21141 .5958 L p .707 .577 .707 r
F P
0 g
s
.36885 .77032 m .36472 .26801 L .38783 .25755 L p .707 .577 .707 r
F P
0 g
s
.36472 .26801 m .36885 .77032 L .35885 .78207 L p .707 .577 .707 r
F P
0 g
s
.17194 .75778 m .16398 .72081 L .18023 .71235 L p .707 .577 .707 r
F P
0 g
s
.35711 .77131 m .35501 .78948 L .34256 .77905 L p .707 .577 .707 r
F P
0 g
s
.34256 .77905 m .34466 .76088 L .35711 .77131 L p .707 .577 .707 r
F P
0 g
s
.18023 .71235 m .1882 .74933 L .17194 .75778 L p .707 .577 .707 r
F P
0 g
s
.16228 .76519 m .16438 .74702 L .18072 .74022 L p .707 .577 .707 r
F P
0 g
s
.34151 .68112 m .34948 .7181 L .32909 .71783 L p .707 .577 .707 r
F P
0 g
s
.32909 .71783 m .32112 .68086 L .34151 .68112 L p .707 .577 .707 r
F P
0 g
s
.33011 .61393 m .32227 .66807 L .29512 .65926 L p .707 .577 .707 r
F P
0 g
s
.29512 .65926 m .30297 .60512 L .33011 .61393 L p .707 .577 .707 r
F P
0 g
s
.21141 .5958 m .20356 .64994 L .17966 .65356 L p .707 .577 .707 r
F P
0 g
s
.20356 .64994 m .21141 .5958 L .24057 .59559 L p .707 .577 .707 r
F P
0 g
s
.18072 .74022 m .17862 .75839 L .16228 .76519 L p .707 .577 .707 r
F P
0 g
s
.6207 .25987 m .62483 .76219 L .59511 .7534 L p .707 .577 .707 r
F P
0 g
s
.59511 .7534 m .59098 .25109 L .6207 .25987 L p .707 .577 .707 r
F P
0 g
s
.30297 .60512 m .29512 .65926 L .26427 .65294 L p .707 .577 .707 r
F P
0 g
s
.26427 .65294 m .27212 .5988 L .30297 .60512 L p .707 .577 .707 r
F P
0 g
s
.23272 .64973 m .24057 .59559 L .27212 .5988 L p .707 .577 .707 r
F P
0 g
s
.24057 .59559 m .23272 .64973 L .20356 .64994 L p .707 .577 .707 r
F P
0 g
s
.1882 .74933 m .18023 .71235 L .20395 .70355 L p .707 .577 .707 r
F P
0 g
s
.34466 .76088 m .34256 .77905 L .32169 .76939 L p .707 .577 .707 r
F P
0 g
s
.32169 .76939 m .32379 .75121 L .34466 .76088 L p .707 .577 .707 r
F P
0 g
s
.27212 .5988 m .26427 .65294 L .23272 .64973 L p .707 .577 .707 r
F P
0 g
s
.32112 .68086 m .32909 .71783 L .30237 .7203 L p .707 .577 .707 r
F P
0 g
s
.30237 .7203 m .2944 .68333 L .32112 .68086 L p .707 .577 .707 r
F P
0 g
s
.20395 .70355 m .21191 .74053 L .1882 .74933 L p .707 .577 .707 r
F P
0 g
s
.17862 .75839 m .18072 .74022 L .20468 .7362 L p .707 .577 .707 r
F P
0 g
s
.7303 .66131 m .73815 .60717 L .70729 .60084 L p .707 .577 .707 r
F P
0 g
s
.73815 .60717 m .7303 .66131 L .76185 .66452 L p .707 .577 .707 r
F P
0 g
s
.76185 .66452 m .7697 .61038 L .73815 .60717 L p .707 .577 .707 r
F P
0 g
s
.38783 .25755 m .39196 .75986 L .36885 .77032 L p .707 .577 .707 r
F P
0 g
s
.39196 .75986 m .38783 .25755 L .42179 .2494 L p .707 .577 .707 r
F P
0 g
s
.7697 .61038 m .76517 .64159 L p .79101 .6643 L .707 .577 .707 r
F P
0 g
s
.78898 .66432 m .79101 .6643 L p .76517 .64159 L .707 .577 .707 r
F P
0 g
s
.79101 .6643 m .79886 .61016 L .7697 .61038 L p .707 .577 .707 r
F P
0 g
s
.79886 .61016 m .79101 .6643 L .807 .66188 L p .707 .577 .707 r
F P
0 g
s
.81468 .65993 m .79886 .61016 L .807 .66188 L .707 .577 .707 r
F
.82276 .60655 m .79886 .61016 L p .81447 .6593 L F P
0 g
s
.81468 .65993 m .81473 .65955 L .81447 .6593 L .707 .577 .707 r
F
.81473 .65955 m .82276 .60655 L .81447 .6593 L F
.81504 .65984 m .82276 .60655 L p .81468 .65993 L F P
0 g
s
.83711 .67841 m .81958 .65775 L .81504 .65984 L .707 .577 .707 r
F
.81504 .65984 m .82086 .68686 L .83539 .6793 L p F P
0 g
s
.83539 .6793 m .83711 .67841 L p .81504 .65984 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .81504 .65984 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.82276 .60655 m .81504 .65984 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83908 .59988 m .82276 .60655 L p .83073 .6512 L .707 .577 .707 r
F P
0 g
s
.83097 .65253 m .83109 .65172 L .83073 .6512 L .707 .577 .707 r
F
.83109 .65172 m .83908 .59988 L .83073 .6512 L F
.83711 .67841 m .84431 .67113 L p .84356 .66966 L F P
0 g
s
.83149 .65229 m .83908 .59988 L p .83109 .65172 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83109 .65172 L .83097 .65253 L .707 .577 .707 r
F
.83821 .65919 m .83839 .64422 L .83349 .64994 L F
.84356 .66966 m .83848 .64466 L .83821 .65919 L F
.83848 .64466 m .83839 .64422 L .83821 .65919 L F
.83838 .64424 m .83839 .6434 L .83149 .65229 L F
.83908 .59988 m .83564 .62366 L p .83839 .6434 L F P
0 g
s
.83564 .62366 m .83149 .65229 L p .83839 .6434 L .707 .577 .707 r
F P
0 g
s
.84431 .67113 m .84419 .67056 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84419 .67056 m .83849 .64411 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84622 .59081 m .83908 .59988 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .84622 .59081 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83635 .63415 L p .83839 .64422 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83839 .64422 L .84356 .66966 L .707 .577 .707 r
F
.83837 .64495 m .83849 .64411 L p .83838 .64424 L F P
0 g
s
.84431 .67113 m .84176 .66574 L p .84044 .65807 L .707 .577 .707 r
F P
0 g
s
.84356 .66966 m .83349 .64994 L .83149 .65229 L .707 .577 .707 r
F
.82915 .64143 m .83149 .65229 L p .83349 .64994 L F P
0 g
s
.83149 .65229 m .83711 .67841 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.83711 .67841 m .83149 .65229 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83823 .64513 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83823 .64513 m .83837 .64495 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83838 .64424 L .83813 .64458 L .707 .577 .707 r
F
.83839 .64422 m .83635 .63415 L .83349 .64994 L F
.83635 .63415 m .83849 .64411 L p .83771 .64209 L F P
0 g
s
.83635 .63415 m .82915 .64143 L p .83349 .64994 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83124 .65402 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83746 .64145 L p .83839 .64385 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .83635 .63415 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.84176 .66574 m .83537 .63609 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83537 .63609 m .83379 .62876 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .82915 .64143 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83149 .65229 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .83124 .65402 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .81492 .66069 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .84176 .66574 L .82969 .66277 L p .707 .577 .707 r
F P
0 g
s
.84346 .58024 m .83562 .63438 L .83476 .63361 L p .707 .577 .707 r
F P
0 g
s
.82915 .64143 m .8129 .64988 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.82969 .66277 m .82173 .62579 L .83379 .62876 L p .707 .577 .707 r
F P
0 g
s
.83476 .63361 m .82325 .62333 L p .82913 .61079 L .707 .577 .707 r
F P
0 g
s
.82913 .61079 m .84346 .58024 L .83476 .63361 L .707 .577 .707 r
F
.83562 .63438 m .83892 .62081 L .83839 .64385 L F
.83746 .64145 m .83562 .63438 L p .83839 .64385 L F P
0 g
s
.83849 .64411 m .83837 .64495 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.84044 .65807 m .83771 .64209 L .83849 .64411 L .707 .577 .707 r
F
.83849 .64411 m .84431 .67113 L p .84044 .65807 L F P
0 g
s
.84622 .59081 m .83849 .64411 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .81504 .65984 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .78918 .65869 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .8129 .64988 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .81504 .65984 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.807 .66188 m .81492 .66069 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .79594 .6647 L .79076 .66602 L .707 .577 .707 r
F
.78918 .65869 m .79076 .66602 L p .79594 .6647 L F P
0 g
s
.79076 .66602 m .79715 .69567 L .81491 .68907 L p .707 .577 .707 r
F P
0 g
s
.81491 .68907 m .82086 .68686 L p .79076 .66602 L .707 .577 .707 r
F P
0 g
s
.76517 .64159 m .76185 .66452 L .78898 .66432 L p .707 .577 .707 r
F P
0 g
s
.20468 .7362 m .20258 .75437 L .17862 .75839 L p .707 .577 .707 r
F P
0 g
s
.69945 .65498 m .70729 .60084 L .68015 .59203 L p .707 .577 .707 r
F P
0 g
s
.70729 .60084 m .69945 .65498 L .7303 .66131 L p .707 .577 .707 r
F P
0 g
s
.21191 .74053 m .20395 .70355 L .2328 .69526 L p .707 .577 .707 r
F P
0 g
s
.2944 .68333 m .30237 .7203 L .27193 .72527 L p .707 .577 .707 r
F P
0 g
s
.27193 .72527 m .26397 .68829 L .2944 .68333 L p .707 .577 .707 r
F P
0 g
s
.32379 .75121 m .32169 .76939 L .29443 .76144 L p .707 .577 .707 r
F P
0 g
s
.29443 .76144 m .29653 .74326 L .32379 .75121 L p .707 .577 .707 r
F P
0 g
s
.59098 .25109 m .59511 .7534 L .55635 .74757 L p .707 .577 .707 r
F P
0 g
s
.55635 .74757 m .55221 .24526 L .59098 .25109 L p .707 .577 .707 r
F P
0 g
s
.2328 .69526 m .24076 .73223 L .21191 .74053 L p .707 .577 .707 r
F P
0 g
s
.6723 .64617 m .68015 .59203 L .65938 .58159 L p .707 .577 .707 r
F P
0 g
s
.68015 .59203 m .6723 .64617 L .69945 .65498 L p .707 .577 .707 r
F P
0 g
s
.20258 .75437 m .20468 .7362 L .23391 .73537 L p .707 .577 .707 r
F P
0 g
s
.73712 .71092 m .72916 .67395 L .69872 .67891 L p .707 .577 .707 r
F P
0 g
s
.72916 .67395 m .73712 .71092 L .76829 .70396 L p .707 .577 .707 r
F P
0 g
s
.76829 .70396 m .76033 .66698 L .72916 .67395 L p .707 .577 .707 r
F P
0 g
s
.24076 .73223 m .2328 .69526 L .26397 .68829 L p .707 .577 .707 r
F P
0 g
s
.76033 .66698 m .76829 .70396 L .79715 .69567 L p .707 .577 .707 r
F P
0 g
s
.79715 .69567 m .78918 .65869 L .76033 .66698 L p .707 .577 .707 r
F P
0 g
s
.26397 .68829 m .27193 .72527 L .24076 .73223 L p .707 .577 .707 r
F P
0 g
s
.23391 .73537 m .23181 .75354 L .20258 .75437 L p .707 .577 .707 r
F P
0 g
s
.42592 .75172 m .42179 .2494 L .46327 .24437 L p .707 .577 .707 r
F P
0 g
s
.42179 .2494 m .42592 .75172 L .39196 .75986 L p .707 .577 .707 r
F P
0 g
s
.69872 .67891 m .70669 .71589 L .73712 .71092 L p .707 .577 .707 r
F P
0 g
s
.70669 .71589 m .69872 .67891 L .672 .68138 L p .707 .577 .707 r
F P
0 g
s
.29653 .74326 m .29443 .76144 L .26346 .75598 L p .707 .577 .707 r
F P
0 g
s
.26346 .75598 m .26557 .7378 L .29653 .74326 L p .707 .577 .707 r
F P
0 g
s
.23181 .75354 m .23391 .73537 L .26557 .7378 L p .707 .577 .707 r
F P
0 g
s
.26557 .7378 m .26346 .75598 L .23181 .75354 L p .707 .577 .707 r
F P
0 g
s
.672 .68138 m .67997 .71836 L .70669 .71589 L p .707 .577 .707 r
F P
0 g
s
.65938 .58159 m .65153 .63573 L .6723 .64617 L p .707 .577 .707 r
F P
0 g
s
.55221 .24526 m .55635 .74757 L .51234 .74525 L p .707 .577 .707 r
F P
0 g
s
.51234 .74525 m .50821 .24294 L .55221 .24526 L p .707 .577 .707 r
F P
0 g
s
.72972 .76298 m .73182 .74481 L .70086 .73935 L p .707 .577 .707 r
F P
0 g
s
.73182 .74481 m .72972 .76298 L .76137 .76542 L p .707 .577 .707 r
F P
0 g
s
.76137 .76542 m .76348 .74725 L .73182 .74481 L p .707 .577 .707 r
F P
0 g
s
.65153 .63573 m .65938 .58159 L .64701 .57054 L p .707 .577 .707 r
F P
0 g
s
.76348 .74725 m .76137 .76542 L .79061 .76459 L p .707 .577 .707 r
F P
0 g
s
.79061 .76459 m .79271 .74641 L .76348 .74725 L p .707 .577 .707 r
F P
0 g
s
.4674 .74668 m .46327 .24437 L .50821 .24294 L p .707 .577 .707 r
F P
0 g
s
.46327 .24437 m .4674 .74668 L .42592 .75172 L p .707 .577 .707 r
F P
0 g
s
.69875 .75753 m .70086 .73935 L .6736 .7314 L p .707 .577 .707 r
F P
0 g
s
.70086 .73935 m .69875 .75753 L .72972 .76298 L p .707 .577 .707 r
F P
0 g
s
.67997 .71836 m .672 .68138 L .65161 .68112 L p .707 .577 .707 r
F P
0 g
s
.50821 .24294 m .51234 .74525 L .4674 .74668 L p .707 .577 .707 r
F P
0 g
s
.6736 .7314 m .6715 .74957 L .69875 .75753 L p .707 .577 .707 r
F P
0 g
s
.65161 .68112 m .65958 .71809 L .67997 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .74641 m .79061 .76459 L .81457 .76057 L p .707 .577 .707 r
F P
0 g
s
.81457 .76057 m .81667 .7424 L .79271 .74641 L p .707 .577 .707 r
F P
0 g
s
.64701 .57054 m .63917 .62468 L .65153 .63573 L p .707 .577 .707 r
F P
0 g
s
.6715 .74957 m .6736 .7314 L .65273 .72174 L p .707 .577 .707 r
F P
0 g
s
.65273 .72174 m .65063 .73991 L .6715 .74957 L p .707 .577 .707 r
F P
0 g
s
.63917 .62468 m .64701 .57054 L .64426 .55996 L p .707 .577 .707 r
F P
0 g
s
.65958 .71809 m .65161 .68112 L .63955 .67815 L p .707 .577 .707 r
F P
0 g
s
.81667 .7424 m .81457 .76057 L .83091 .75377 L p .707 .577 .707 r
F P
0 g
s
.83091 .75377 m .83301 .7356 L .81667 .7424 L p .707 .577 .707 r
F P
0 g
s
.63955 .67815 m .64752 .71512 L .65958 .71809 L p .707 .577 .707 r
F P
0 g
s
.65063 .73991 m .65273 .72174 L .64028 .71131 L p .707 .577 .707 r
F P
0 g
s
.64426 .55996 m .63642 .6141 L .63917 .62468 L p .707 .577 .707 r
F P
0 g
s
.64028 .71131 m .63818 .72948 L .65063 .73991 L p .707 .577 .707 r
F P
0 g
s
.83562 .63438 m .84346 .58024 L .84622 .59081 L p .707 .577 .707 r
F P
0 g
s
.63642 .6141 m .64426 .55996 L .6514 .5509 L p .707 .577 .707 r
F P
0 g
s
.64752 .71512 m .63955 .67815 L .63699 .67276 L p .707 .577 .707 r
F P
0 g
s
.83301 .7356 m .83091 .75377 L .83802 .74484 L p .707 .577 .707 r
F P
0 g
s
.83802 .74484 m .84012 .72667 L .83301 .7356 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63699 .67276 m .64496 .70973 L .64752 .71512 L p .707 .577 .707 r
F P
0 g
s
.63818 .72948 m .64028 .71131 L .63748 .70113 L p .707 .577 .707 r
F P
0 g
s
.63748 .70113 m .63538 .7193 L .63818 .72948 L p .707 .577 .707 r
F P
0 g
s
.6514 .5509 m .64355 .60504 L .63642 .6141 L p .707 .577 .707 r
F P
0 g
s
.82325 .62333 m .8311 .56919 L .84346 .58024 L p .707 .577 .707 r
F P
0 g
s
.64355 .60504 m .6514 .5509 L .66772 .54423 L p .707 .577 .707 r
F P
0 g
s
.38729 .62445 m .39514 .57031 L .36428 .56399 L p .707 .577 .707 r
F P
0 g
s
.39514 .57031 m .38729 .62445 L .41884 .62767 L p .707 .577 .707 r
F P
0 g
s
.41884 .62767 m .42669 .57353 L .39514 .57031 L p .707 .577 .707 r
F P
0 g
s
.64496 .70973 m .63699 .67276 L .64419 .66548 L p .707 .577 .707 r
F P
0 g
s
.84012 .72667 m .83802 .74484 L .83522 .73466 L p .707 .577 .707 r
F P
0 g
s
.83522 .73466 m .83732 .71649 L .84012 .72667 L p .707 .577 .707 r
F P
0 g
s
.42669 .57353 m .42215 .60483 L p .448 .62745 L .707 .577 .707 r
F P
0 g
s
.44587 .62747 m .448 .62745 L p .42215 .60483 L .707 .577 .707 r
F P
0 g
s
.448 .62745 m .45585 .57331 L .42669 .57353 L p .707 .577 .707 r
F P
0 g
s
.45585 .57331 m .448 .62745 L .46477 .62491 L p .707 .577 .707 r
F P
0 g
s
.47169 .62315 m .45585 .57331 L .46477 .62491 L .707 .577 .707 r
F
.47975 .56969 m .45585 .57331 L p .47151 .62258 L F P
0 g
s
.47169 .62315 m .47174 .62281 L .47151 .62258 L .707 .577 .707 r
F
.47174 .62281 m .47975 .56969 L .47151 .62258 L F
.47202 .62307 m .47975 .56969 L p .47169 .62315 L F P
0 g
s
.4941 .6417 m .47653 .621 L .47202 .62307 L .707 .577 .707 r
F
.47202 .62307 m .47785 .65015 L .49241 .64258 L p F P
0 g
s
.49241 .64258 m .4941 .6417 L p .47202 .62307 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .47202 .62307 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47975 .56969 m .47202 .62307 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49607 .56303 m .47975 .56969 L p .48775 .61449 L .707 .577 .707 r
F P
0 g
s
.48797 .61575 m .48809 .61498 L .48775 .61449 L .707 .577 .707 r
F
.48809 .61498 m .49607 .56303 L .48775 .61449 L F
.4941 .6417 m .5013 .63442 L p .50047 .6328 L F P
0 g
s
.48846 .61552 m .49607 .56303 L p .48809 .61498 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48809 .61498 L .48797 .61575 L .707 .577 .707 r
F
.49519 .62245 m .49536 .60746 L .49046 .61319 L F
.50047 .6328 m .49546 .60795 L .49519 .62245 L F
.49546 .60795 m .49536 .60746 L .49519 .62245 L F
.49537 .60746 m .49538 .6067 L .48846 .61552 L F
.49607 .56303 m .49261 .58689 L p .49538 .6067 L F P
0 g
s
.49261 .58689 m .48846 .61552 L p .49538 .6067 L .707 .577 .707 r
F P
0 g
s
.50066 .63306 m .50043 .63258 L .50047 .6328 L .707 .577 .707 r
F
.50117 .63379 m .50043 .63258 L .50066 .63306 L F
.50321 .55396 m .49607 .56303 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .49536 .60746 L .50043 .63258 L .707 .577 .707 r
F
.49536 .6081 m .49547 .60734 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .50321 .55396 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.50117 .63379 m .49547 .60734 L p .50043 .63258 L .707 .577 .707 r
F P
0 g
s
.49547 .60734 m .49334 .59744 L p .49536 .60746 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .50117 .63379 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .49874 .62903 L p .49741 .62122 L .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .48846 .61552 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .4941 .6417 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.4941 .6417 m .48846 .61552 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .4952 .60831 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.4952 .60831 m .49536 .6081 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49537 .60746 L .49511 .6078 L .707 .577 .707 r
F
.49536 .60746 m .49334 .59744 L .49046 .61319 L F
.49334 .59744 m .49547 .60734 L p .49469 .60534 L F P
0 g
s
.49334 .59744 m .48614 .60472 L p .49046 .61319 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48823 .61717 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49454 .60495 L p .49538 .60711 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49334 .59744 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49874 .62903 m .49235 .59933 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49235 .59933 m .49078 .59205 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48614 .60472 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .48846 .61552 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .48823 .61717 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .47191 .62383 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49874 .62903 L .48668 .62606 L p .707 .577 .707 r
F P
0 g
s
.50045 .54339 m .49261 .59753 L .4917 .59672 L p .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .46989 .61317 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48668 .62606 m .47872 .58908 L .49078 .59205 L p .707 .577 .707 r
F P
0 g
s
.4917 .59672 m .48024 .58648 L p .4861 .57399 L .707 .577 .707 r
F P
0 g
s
.4861 .57399 m .50045 .54339 L .4917 .59672 L .707 .577 .707 r
F
.49261 .59753 m .4959 .584 L .49538 .60711 L F
.49454 .60495 m .49261 .59753 L p .49538 .60711 L F P
0 g
s
.49547 .60734 m .49536 .6081 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.49741 .62122 m .49469 .60534 L .49547 .60734 L .707 .577 .707 r
F
.49547 .60734 m .5013 .63442 L p .49741 .62122 L F P
0 g
s
.50321 .55396 m .49547 .60734 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .47202 .62307 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .44617 .62198 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .46989 .61317 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .47202 .62307 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.46477 .62491 m .47191 .62383 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .45288 .62794 L .44774 .62925 L .707 .577 .707 r
F
.44617 .62198 m .44774 .62925 L p .45288 .62794 L F P
0 g
s
.44774 .62925 m .45414 .65895 L .47193 .65235 L p .707 .577 .707 r
F P
0 g
s
.47193 .65235 m .47785 .65015 L p .44774 .62925 L .707 .577 .707 r
F P
0 g
s
.42215 .60483 m .41884 .62767 L .44587 .62747 L p .707 .577 .707 r
F P
0 g
s
.35644 .61813 m .36428 .56399 L .33714 .55518 L p .707 .577 .707 r
F P
0 g
s
.36428 .56399 m .35644 .61813 L .38729 .62445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64419 .66548 m .65216 .70246 L .64496 .70973 L p .707 .577 .707 r
F P
0 g
s
.63538 .7193 m .63748 .70113 L .6446 .6922 L p .707 .577 .707 r
F P
0 g
s
.6446 .6922 m .64249 .71037 L .63538 .7193 L p .707 .577 .707 r
F P
0 g
s
.66772 .54423 m .65987 .59837 L .64355 .60504 L p .707 .577 .707 r
F P
0 g
s
.8311 .56919 m .82325 .62333 L .80248 .61289 L p .707 .577 .707 r
F P
0 g
s
.80248 .61289 m .81033 .55875 L .8311 .56919 L p .707 .577 .707 r
F P
0 g
s
.32929 .60932 m .33714 .55518 L .31637 .54474 L p .707 .577 .707 r
F P
0 g
s
.33714 .55518 m .32929 .60932 L .35644 .61813 L p .707 .577 .707 r
F P
0 g
s
.39411 .67421 m .38615 .63724 L .35571 .6422 L p .707 .577 .707 r
F P
0 g
s
.38615 .63724 m .39411 .67421 L .42528 .66725 L p .707 .577 .707 r
F P
0 g
s
.42528 .66725 m .41732 .63027 L .38615 .63724 L p .707 .577 .707 r
F P
0 g
s
.65987 .59837 m .66772 .54423 L .69162 .54061 L p .707 .577 .707 r
F P
0 g
s
.41732 .63027 m .42528 .66725 L .45414 .65895 L p .707 .577 .707 r
F P
0 g
s
.45414 .65895 m .44617 .62198 L .41732 .63027 L p .707 .577 .707 r
F P
0 g
s
.35571 .6422 m .36368 .67918 L .39411 .67421 L p .707 .577 .707 r
F P
0 g
s
.36368 .67918 m .35571 .6422 L .32899 .64467 L p .707 .577 .707 r
F P
0 g
s
.65216 .70246 m .64419 .66548 L .66045 .65702 L p .707 .577 .707 r
F P
0 g
s
.83732 .71649 m .83522 .73466 L .82277 .72423 L p .707 .577 .707 r
F P
0 g
s
.82277 .72423 m .82488 .70606 L .83732 .71649 L p .707 .577 .707 r
F P
0 g
s
.32899 .64467 m .33696 .68165 L .36368 .67918 L p .707 .577 .707 r
F P
0 g
s
.31637 .54474 m .30852 .59888 L .32929 .60932 L p .707 .577 .707 r
F P
0 g
s
.66045 .65702 m .66841 .694 L .65216 .70246 L p .707 .577 .707 r
F P
0 g
s
.64249 .71037 m .6446 .6922 L .66093 .68539 L p .707 .577 .707 r
F P
0 g
s
.82173 .62579 m .82969 .66277 L .8093 .66251 L p .707 .577 .707 r
F P
0 g
s
.8093 .66251 m .80134 .62553 L .82173 .62579 L p .707 .577 .707 r
F P
0 g
s
.38671 .72577 m .38881 .70759 L .35785 .70213 L p .707 .577 .707 r
F P
0 g
s
.38881 .70759 m .38671 .72577 L .41836 .7282 L p .707 .577 .707 r
F P
0 g
s
.41836 .7282 m .42047 .71003 L .38881 .70759 L p .707 .577 .707 r
F P
0 g
s
.81033 .55875 m .80248 .61289 L .77534 .60407 L p .707 .577 .707 r
F P
0 g
s
.77534 .60407 m .78319 .54993 L .81033 .55875 L p .707 .577 .707 r
F P
0 g
s
.30852 .59888 m .31637 .54474 L .304 .53369 L p .707 .577 .707 r
F P
0 g
s
.69162 .54061 m .68378 .59475 L .65987 .59837 L p .707 .577 .707 r
F P
0 g
s
.68378 .59475 m .69162 .54061 L .72078 .5404 L p .707 .577 .707 r
F P
0 g
s
.42047 .71003 m .41836 .7282 L .4476 .72737 L p .707 .577 .707 r
F P
0 g
s
.4476 .72737 m .4497 .7092 L .42047 .71003 L p .707 .577 .707 r
F P
0 g
s
.66093 .68539 m .65883 .70357 L .64249 .71037 L p .707 .577 .707 r
F P
0 g
s
.35574 .72031 m .35785 .70213 L .33059 .69418 L p .707 .577 .707 r
F P
0 g
s
.35785 .70213 m .35574 .72031 L .38671 .72577 L p .707 .577 .707 r
F P
0 g
s
.33696 .68165 m .32899 .64467 L .3086 .64441 L p .707 .577 .707 r
F P
0 g
s
.33059 .69418 m .32849 .71236 L .35574 .72031 L p .707 .577 .707 r
F P
0 g
s
.3086 .64441 m .31657 .68138 L .33696 .68165 L p .707 .577 .707 r
F P
0 g
s
.78319 .54993 m .77534 .60407 L .74448 .59775 L p .707 .577 .707 r
F P
0 g
s
.74448 .59775 m .75233 .54361 L .78319 .54993 L p .707 .577 .707 r
F P
0 g
s
.71293 .59454 m .72078 .5404 L .75233 .54361 L p .707 .577 .707 r
F P
0 g
s
.72078 .5404 m .71293 .59454 L .68378 .59475 L p .707 .577 .707 r
F P
0 g
s
.4497 .7092 m .4476 .72737 L .47156 .72336 L p .707 .577 .707 r
F P
0 g
s
.47156 .72336 m .47366 .70518 L .4497 .7092 L p .707 .577 .707 r
F P
0 g
s
.66841 .694 m .66045 .65702 L .68416 .64822 L p .707 .577 .707 r
F P
0 g
s
.304 .53369 m .29616 .58783 L .30852 .59888 L p .707 .577 .707 r
F P
0 g
s
.82488 .70606 m .82277 .72423 L .8019 .71457 L p .707 .577 .707 r
F P
0 g
s
.8019 .71457 m .804 .69639 L .82488 .70606 L p .707 .577 .707 r
F P
0 g
s
.32849 .71236 m .33059 .69418 L .30972 .68452 L p .707 .577 .707 r
F P
0 g
s
.75233 .54361 m .74448 .59775 L .71293 .59454 L p .707 .577 .707 r
F P
0 g
s
.80134 .62553 m .8093 .66251 L .78258 .66498 L p .707 .577 .707 r
F P
0 g
s
.78258 .66498 m .77462 .628 L .80134 .62553 L p .707 .577 .707 r
F P
0 g
s
.68416 .64822 m .69212 .6852 L .66841 .694 L p .707 .577 .707 r
F P
0 g
s
.65883 .70357 m .66093 .68539 L .68489 .68138 L p .707 .577 .707 r
F P
0 g
s
.30972 .68452 m .30762 .70269 L .32849 .71236 L p .707 .577 .707 r
F P
0 g
s
.29616 .58783 m .304 .53369 L .30125 .52311 L p .707 .577 .707 r
F P
0 g
s
.68489 .68138 m .68279 .69955 L .65883 .70357 L p .707 .577 .707 r
F P
0 g
s
.31657 .68138 m .3086 .64441 L .29654 .64143 L p .707 .577 .707 r
F P
0 g
s
.69212 .6852 m .68416 .64822 L .71301 .63993 L p .707 .577 .707 r
F P
0 g
s
.47366 .70518 m .47156 .72336 L .4879 .71655 L p .707 .577 .707 r
F P
0 g
s
.4879 .71655 m .49 .69838 L .47366 .70518 L p .707 .577 .707 r
F P
0 g
s
.29654 .64143 m .30451 .67841 L .31657 .68138 L p .707 .577 .707 r
F P
0 g
s
.77462 .628 m .78258 .66498 L .75215 .66994 L p .707 .577 .707 r
F P
0 g
s
.75215 .66994 m .74418 .63296 L .77462 .628 L p .707 .577 .707 r
F P
0 g
s
.804 .69639 m .8019 .71457 L .77465 .70662 L p .707 .577 .707 r
F P
0 g
s
.77465 .70662 m .77675 .68844 L .804 .69639 L p .707 .577 .707 r
F P
0 g
s
.30762 .70269 m .30972 .68452 L .29727 .67409 L p .707 .577 .707 r
F P
0 g
s
.71301 .63993 m .72098 .67691 L .69212 .6852 L p .707 .577 .707 r
F P
0 g
s
.68279 .69955 m .68489 .68138 L .71413 .68055 L p .707 .577 .707 r
F P
0 g
s
.30125 .52311 m .29341 .57725 L .29616 .58783 L p .707 .577 .707 r
F P
0 g
s
.72098 .67691 m .71301 .63993 L .74418 .63296 L p .707 .577 .707 r
F P
0 g
s
.29727 .67409 m .29517 .69226 L .30762 .70269 L p .707 .577 .707 r
F P
0 g
s
.74418 .63296 m .75215 .66994 L .72098 .67691 L p .707 .577 .707 r
F P
0 g
s
.71413 .68055 m .71203 .69872 L .68279 .69955 L p .707 .577 .707 r
F P
0 g
s
.49261 .59753 m .50045 .54339 L .50321 .55396 L p .707 .577 .707 r
F P
0 g
s
.77675 .68844 m .77465 .70662 L .74368 .70116 L p .707 .577 .707 r
F P
0 g
s
.74368 .70116 m .74578 .68298 L .77675 .68844 L p .707 .577 .707 r
F P
0 g
s
.29341 .57725 m .30125 .52311 L .30839 .51405 L p .707 .577 .707 r
F P
0 g
s
.71203 .69872 m .71413 .68055 L .74578 .68298 L p .707 .577 .707 r
F P
0 g
s
.30451 .67841 m .29654 .64143 L .29398 .63605 L p .707 .577 .707 r
F P
0 g
s
.74578 .68298 m .74368 .70116 L .71203 .69872 L p .707 .577 .707 r
F P
0 g
s
.49 .69838 m .4879 .71655 L .49501 .70762 L p .707 .577 .707 r
F P
0 g
s
.49501 .70762 m .49711 .68945 L .49 .69838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29398 .63605 m .30195 .67302 L .30451 .67841 L p .707 .577 .707 r
F P
0 g
s
.29517 .69226 m .29727 .67409 L .29447 .66391 L p .707 .577 .707 r
F P
0 g
s
.29447 .66391 m .29237 .68208 L .29517 .69226 L p .707 .577 .707 r
F P
0 g
s
.30839 .51405 m .30054 .56819 L .29341 .57725 L p .707 .577 .707 r
F P
0 g
s
.48024 .58648 m .48809 .53234 L .50045 .54339 L p .707 .577 .707 r
F P
0 g
s
.30054 .56819 m .30839 .51405 L .32471 .50738 L p .707 .577 .707 r
F P
0 g
s
.30195 .67302 m .29398 .63605 L .30118 .62877 L p .707 .577 .707 r
F P
0 g
s
.49711 .68945 m .49501 .70762 L .49221 .69745 L p .707 .577 .707 r
F P
0 g
s
.49221 .69745 m .49431 .67927 L .49711 .68945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30118 .62877 m .30915 .66575 L .30195 .67302 L p .707 .577 .707 r
F P
0 g
s
.29237 .68208 m .29447 .66391 L .30159 .65498 L p .707 .577 .707 r
F P
0 g
s
.30159 .65498 m .29948 .67315 L .29237 .68208 L p .707 .577 .707 r
F P
0 g
s
.32471 .50738 m .31686 .56152 L .30054 .56819 L p .707 .577 .707 r
F P
0 g
s
.48809 .53234 m .48024 .58648 L .45947 .57604 L p .707 .577 .707 r
F P
0 g
s
.45947 .57604 m .46732 .5219 L .48809 .53234 L p .707 .577 .707 r
F P
0 g
s
.31686 .56152 m .32471 .50738 L .34861 .50376 L p .707 .577 .707 r
F P
0 g
s
.30915 .66575 m .30118 .62877 L .31744 .62031 L p .707 .577 .707 r
F P
0 g
s
.49431 .67927 m .49221 .69745 L .47976 .68701 L p .707 .577 .707 r
F P
0 g
s
.47976 .68701 m .48186 .66884 L .49431 .67927 L p .707 .577 .707 r
F P
0 g
s
.31744 .62031 m .3254 .65729 L .30915 .66575 L p .707 .577 .707 r
F P
0 g
s
.29948 .67315 m .30159 .65498 L .31792 .64818 L p .707 .577 .707 r
F P
0 g
s
.47872 .58908 m .48668 .62606 L .46629 .6258 L p .707 .577 .707 r
F P
0 g
s
.46629 .6258 m .45833 .58882 L .47872 .58908 L p .707 .577 .707 r
F P
0 g
s
.46732 .5219 m .45947 .57604 L .43233 .56722 L p .707 .577 .707 r
F P
0 g
s
.43233 .56722 m .44018 .51308 L .46732 .5219 L p .707 .577 .707 r
F P
0 g
s
.34861 .50376 m .34077 .5579 L .31686 .56152 L p .707 .577 .707 r
F P
0 g
s
.34077 .5579 m .34861 .50376 L .37777 .50355 L p .707 .577 .707 r
F P
0 g
s
.31792 .64818 m .31582 .66635 L .29948 .67315 L p .707 .577 .707 r
F P
0 g
s
.44018 .51308 m .43233 .56722 L .40147 .5609 L p .707 .577 .707 r
F P
0 g
s
.40147 .5609 m .40932 .50676 L .44018 .51308 L p .707 .577 .707 r
F P
0 g
s
.36992 .55769 m .37777 .50355 L .40932 .50676 L p .707 .577 .707 r
F P
0 g
s
.37777 .50355 m .36992 .55769 L .34077 .5579 L p .707 .577 .707 r
F P
0 g
s
.3254 .65729 m .31744 .62031 L .34115 .61151 L p .707 .577 .707 r
F P
0 g
s
.48186 .66884 m .47976 .68701 L .45889 .67735 L p .707 .577 .707 r
F P
0 g
s
.45889 .67735 m .46099 .65918 L .48186 .66884 L p .707 .577 .707 r
F P
0 g
s
.40932 .50676 m .40147 .5609 L .36992 .55769 L p .707 .577 .707 r
F P
0 g
s
.45833 .58882 m .46629 .6258 L .43957 .62827 L p .707 .577 .707 r
F P
0 g
s
.43957 .62827 m .43161 .59129 L .45833 .58882 L p .707 .577 .707 r
F P
0 g
s
.34115 .61151 m .34911 .64849 L .3254 .65729 L p .707 .577 .707 r
F P
0 g
s
.31582 .66635 m .31792 .64818 L .34188 .64416 L p .707 .577 .707 r
F P
0 g
s
.34188 .64416 m .33978 .66234 L .31582 .66635 L p .707 .577 .707 r
F P
0 g
s
.34911 .64849 m .34115 .61151 L .37 .60322 L p .707 .577 .707 r
F P
0 g
s
.43161 .59129 m .43957 .62827 L .40914 .63323 L p .707 .577 .707 r
F P
0 g
s
.40914 .63323 m .40117 .59625 L .43161 .59129 L p .707 .577 .707 r
F P
0 g
s
.46099 .65918 m .45889 .67735 L .43164 .6694 L p .707 .577 .707 r
F P
0 g
s
.43164 .6694 m .43374 .65122 L .46099 .65918 L p .707 .577 .707 r
F P
0 g
s
.37 .60322 m .37797 .64019 L .34911 .64849 L p .707 .577 .707 r
F P
0 g
s
.33978 .66234 m .34188 .64416 L .37112 .64333 L p .707 .577 .707 r
F P
0 g
s
.37797 .64019 m .37 .60322 L .40117 .59625 L p .707 .577 .707 r
F P
0 g
s
.40117 .59625 m .40914 .63323 L .37797 .64019 L p .707 .577 .707 r
F P
0 g
s
.37112 .64333 m .36902 .6615 L .33978 .66234 L p .707 .577 .707 r
F P
0 g
s
.43374 .65122 m .43164 .6694 L .40067 .66394 L p .707 .577 .707 r
F P
0 g
s
.40067 .66394 m .40277 .64576 L .43374 .65122 L p .707 .577 .707 r
F P
0 g
s
.36902 .6615 m .37112 .64333 L .40277 .64576 L p .707 .577 .707 r
F P
0 g
s
.40277 .64576 m .40067 .66394 L .36902 .6615 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001POol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005]oo`D000=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00FGoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Ioo`00Egoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol005Ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool@001<Ool005Aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70015Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00E7oo
00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00>Goo001DOol20004FUH01000FUIJEUYF4000
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00T005YFFUIJEP00FUH005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`00=Woo001DOol20003
FUH500000eYF001JEP02FUH30002FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH3000dOol005=oo`04001JEP00FUH20006FUH00`00FUIJEP04FUH40004FUH50000
0eYF000000020002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
<Woo001COol01P00FUH00000FUH000EJEP03001JEUYF00IJEP03001JEUYF00T000EJEP@000IJEP03
001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000`Ool005=oo`<0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF0P00;goo001COol20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30003FUH>0005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo001DOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF2`000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP03
FUH01000FUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000iOol@000=Ool20005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00
FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20003FUH50002FUH00`00FUIJEP03FUH40004Ool90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00<Woo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF00<005YFFUH01UYF1P001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00EJ
EP03001JEP0000<00003Ool0000000<000=oo`H000IJEP03001JEUYF00=JEP07001JEUYFFUH005YF
0000;7oo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40002Ool200000eYF001JEP04FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00=JEPL000Qoo`8000AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002moo`8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000H00004FUH0
00000006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`000UYF3@0000=JEP00FUH015YF00@0
05YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF1@002EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8002eoo`00;Woo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF0P00;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP04001JEUYF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0P001EYF2P000eYF00<005YF0000;Goo000]
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005
FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1`000eYF00<005YFFUH0
0eYF0P000UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00Ool0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00FUH0
15YF00<005YFFUH01EYF00<005YFFUH01EYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH01UYF0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF00<0
05YF00001@0015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUIJEPP000UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003Ool200000eYF001JEP06FUH200000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJ
EP03001JEUYF00P000=JEP03001JEUYF009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF00000003Ool30003FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002eoo`8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
0007FUH00`00FUIJEP04FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH30003Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool20003FUH500000eYF001JEP040009
Ool60006FUH200001UYF00000000FUH000IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000=JEP8000=JEP8000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002aoo`04001JEP00FUH20006FUH00`00
FUIJEP03FUH50004Ool500000goo000000020002FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000400000eYF0000000<FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo000/Ool01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00T000Eoo`D000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEUYFFUH0000]Ool002aoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00AJEPL000Eoo`03001JEP0000=JEP04001JEUYFFUHG0006FUH00`00FUIJEP06FUH3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0002FUH00`00
Oomoo`0[Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP<000=J
EPH00003FUH005YF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP<002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P0000=JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP0000000P001UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1`001eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEPH00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF
00QJEP03001JEUYF00AJEP<000EJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPD000UJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@00003FUH00000018000EJ
EP<000MJEP03001JEUYF00MJEP8000=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP00009JEQ4000UJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Woo00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUH000EJEP04001J
EP00FUH200000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH300000eYF001JEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0002FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05
FUH01000FUH00000<7oo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH00`00
FUIJEP02FUH40005FUH00`00FUIJEP0300000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH00`00
FUIJEP020003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH01000FUIJEUYF1@00<Woo000`Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF
001JEP04FUH50006FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP04001JEP00000g
Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF00IJEP04001JEUYF
0005FUH20003FUH00`00FUIJEP0200000eYF001JEP05FUH30007FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1000>Goo000cOol200000eYF001JEP06FUH300000eYF001JEP08FUH00`00FUIJ
EP05FUH40005FUH00`00FUH000030002FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH3000gOol003Eoo`<000=JEP<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYF0005FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEUYF
0P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000AJEP03001JEP0000<000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00>7oo0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00MJEPD000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP02FUH2000bOol0
03Eoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH005YF00IJEP03001JEUYF00AJEQL000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040006Ool20003FUH00`00FUIJEP04FUH2000aOol0039oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`000UYF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF1`0037oo0P0000=JEP00FUH01EYF00<005YF
0000<7oo000`Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH01P0000=JEP00FUH015YF00@005YFFUIJEPP000Aoo`<000ioo`<000AJ
EP05001JEUYFFUH0000_Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEQ<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020000
0eYF0000000<000015YF001JEP001goo1@0047oo0`0000=JEP00FUH00UYF00<007ooOol0;Goo000]
Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P0000=JEP00FUH015YF00<005YFFUH00P0000=JEP00Ool01Woo1@004goo0P000eYF0P00;Woo000]
Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF1`0015YF00<005YFFUH00UYF200000=JEP00FUH0
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP00008000AJEP04001JEUYFFUH20008Ool5000EOol00`00FUIJEP02000^Ool002aoo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP090009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00P002Goo0`005goo1000;Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP<00003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEP000080009J
EP8002Eoo`8002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF01L0009JEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYF0002Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH01000FUIJEUYF1@0097oo0`00;Woo000]Ool00`00FUH00002FUH50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP04FUH30003Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH6000NOol300000eYF001oo`0]
Ool002eoo`03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@000=JEP03001JEUYF009JEP<000Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP00
02ioo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YF0000100000=JEP00000027oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
0eYF300000=JEP00FUH02UYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8002moo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0`002Goo00<005YF00001UYF00<005YFFUH01UYF200035YF00<005YFFUH02EYF00<005YF
FUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF0`001UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<0
05YF00000eYF00@005YFFUIJEQL000IJEP03001JEUYF00IJEP<000Moo`03001JEP0000IJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP8000AJEPP0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000`Ool002aoo`03001JEP0000=JEP@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF008000Eo
o`03001JEP0000IJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEPH000AJEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000/Ool01000FUH005YF
0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=oo`0000000P001UYF00<0
05YFFUH00eYF00<007ooOol00Woo00<005YF00001EYF0`000eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF100015YF0P000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF00000Woo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPD003Ao
o`00;7oo00@005YF0000009JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEPD000Uo
o`@0009JEP03001JEUYF00=JEP8000=oo`03001JEP0000=JEP8000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH2
0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;Ool@000iOol002aoo`@000=JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00@0019oo`<000EJEP09001JEP00001oo`00FUH0
05YF00<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00
;7oo0P0000=JEP0000001@000UYF00<005YFFUH00UYF1P001Goo0`004Goo0P000eYF00@005YFFUIJ
EP800003FUH00000009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1DOol002aoo`03001JEUYF009JEP03001oogoo009oo`L0
00Yoo`D0019oo`800003FUH005YF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000002FUH00`00FUIJEP05FUH01000FUH00000Egoo000/Ool00`00FUIJEP02FUH3000COol5000D
Ool20003FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH0
15YF0P00FGoo000/Ool00`00FUIJEP02FUH00`00FUIJEP02000AOol5000FOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH01000Fgoo000/
Ool01@00FUIJEUYF00001EYF0P0047oo0`0067oo0P0000=JEP00000015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00D005YFFUH005YF00D005moo`00;Goo0P0000=JEP00FUH015YF00<005YF00000`00
9goo0P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001EYF0`00GWoo
000_Ool20005FUH00`00FUIJEP03FUH5000POol200001EYF000007oo000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P001eYF00<005YF00000P00Fgoo000aOol20003FUH00`00FUIJEP05FUH00`00
FUIJEP04000GOol50003FUH20002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP02FUH2001IOol003=oo`800003FUH005YF00IJEP03001JEUYF00AJEPL000Uoo`L000=J
EP07001JEUYFFUH005YF000017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEPD000EJEP03001JEUYF00AJEP8005Qo
o`00=Goo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00@005YF
FUIJEP8000Moo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP04001JEP000005Ool400000eYF001JEP05FUH01000FUH00000EWoo000h
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00
FUIJEUYF00002Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF10002goo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000lOol4
0006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000003Goo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01P0047oo
0P000eYF00<005YFFUH00UYF00<007ooOol0Dgoo0010Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1@004Woo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF1@000Woo1@004Goo0P0000=JEP00FUH00eYF00<007ooOol0Dgoo0014Ool70004FUH00`00FUIJ
EP02FUH8000KOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001goo1@00
4goo0P000eYF0P00EGoo001;Ool9000YOolO000=Ool5000EOol00`00FUIJEP02001EOol008moo`03
001JEP0000EJEP<0011oo`<001Moo`@005Eoo`00T7oo0P001UYF00<005YF00000`009goo0`00EGoo
002AOol00`00FUIJEP04FUH00`00FUIJEP03FUH7000NOol5001EOol0099oo`8000=JEP03001JEUYF
00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP0005Eoo`00U7oo0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8005Ioo`00UWoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Io
o`00VGoo10000UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00WGoo1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Uoo`00XWoo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD005]oo`00YWoo5`00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59095 .75535 m .60357 .70269 L .57322 .69371 L p .707 .577 .707 r
F P
0 g
s
.60357 .70269 m .59095 .75535 L .6213 .76083 L p .707 .577 .707 r
F P
0 g
s
.62198 .76078 m .62195 .76067 L .6213 .76083 L .707 .577 .707 r
F
.62195 .76067 m .60357 .70269 L .62106 .76002 L F
.62195 .76067 m .62106 .76002 L .6213 .76083 L F
.60897 .77425 m .62209 .76077 L .59015 .76315 L F
.63155 .78758 m .62209 .76077 L p .60897 .77425 L F P
0 g
s
.65956 .7763 m .63155 .7593 L .62209 .76077 L .707 .577 .707 r
F
.64903 .75658 m .64367 .73859 L .62225 .76074 L F
.63466 .7083 m .62209 .76077 L p .64367 .73859 L F P
0 g
s
.62209 .76077 m .63155 .78758 L .64921 .78047 L p .707 .577 .707 r
F P
0 g
s
.64921 .78047 m .65956 .7763 L p .62209 .76077 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .62204 .76096 L p .62225 .76074 L .707 .577 .707 r
F P
0 g
s
.64367 .73859 m .62209 .76077 L .62225 .76074 L .707 .577 .707 r
F
.63466 .7083 m .60357 .70269 L p .62195 .76067 L F P
0 g
s
.62204 .76096 m .62209 .76077 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .63466 .7083 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.6423 .76582 m .65241 .75606 L .63155 .7593 L .707 .577 .707 r
F
.65956 .7763 m .65241 .75606 L p .6423 .76582 L F P
0 g
s
.65956 .7763 m .68273 .76558 L p .67083 .75719 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .66987 .73919 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .65241 .75606 L p .66987 .73919 L F P
0 g
s
.66987 .73919 m .65241 .75606 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .63466 .7083 L p .64824 .75395 L F P
0 g
s
.65083 .76265 m .65241 .75606 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .66345 .70999 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.68273 .76558 m .67707 .74955 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.68713 .70759 m .66345 .70999 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .67707 .74955 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68713 .70759 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.68862 .75322 m .68665 .74512 L .67707 .74955 L .707 .577 .707 r
F
.6988 .75646 m .69058 .74879 L .68862 .75322 L F
.69058 .74879 m .68665 .74512 L .68862 .75322 L F
.69575 .75819 m .6988 .75646 L p .67707 .74955 L F P
0 g
s
.68993 .7436 m .68924 .73466 L .68197 .74729 L .707 .577 .707 r
F
.68713 .70759 m .67707 .74955 L p .68924 .73466 L F P
0 g
s
.68924 .73466 m .67707 .74955 L .68197 .74729 L .707 .577 .707 r
F
.68608 .72047 m .67002 .72959 L p .68665 .74512 L F P
0 g
s
.6988 .75646 m .69365 .74189 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70337 .70135 m .68713 .70759 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69074 .75401 m .69365 .74189 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .70337 .70135 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.70033 .74613 m .69758 .73727 L .69365 .74189 L .707 .577 .707 r
F
.70618 .74985 m .70041 .7414 L .70033 .74613 L F
.70041 .7414 m .69758 .73727 L .70033 .74613 L F
.69365 .74189 m .6988 .75646 L .70594 .75007 L p F P
0 g
s
.70594 .75007 m .70618 .74985 L p .69365 .74189 L .707 .577 .707 r
F P
0 g
s
.69909 .7355 m .70011 .72733 L .69594 .73919 L .707 .577 .707 r
F
.70337 .70135 m .69365 .74189 L p .70011 .72733 L F P
0 g
s
.70011 .72733 m .69365 .74189 L .69594 .73919 L .707 .577 .707 r
F
.69347 .71385 m .68608 .72047 L p .69758 .73727 L F P
0 g
s
.70618 .74985 m .70052 .73382 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.71058 .69186 m .70337 .70135 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .70052 .73382 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .71058 .69186 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70618 .74985 m .70417 .74638 L p .70249 .74128 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .69347 .71385 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.69779 .73837 m .69796 .74452 L p .69909 .7355 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .69701 .7401 L .69074 .75401 L .707 .577 .707 r
F
.69909 .7355 m .69594 .73919 L .69074 .75401 L F
.68608 .72047 m .69365 .74189 L p .69758 .73727 L F P
0 g
s
.69796 .74452 m .69544 .73273 L p .6975 .72718 L .707 .577 .707 r
F P
0 g
s
.69347 .71385 m .70052 .73382 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.6975 .72718 m .69937 .7313 L .69796 .74452 L .707 .577 .707 r
F
.69146 .71038 m .69347 .71385 L p .69878 .73 L F P
0 g
s
.70052 .73382 m .69796 .74452 L p .69937 .7313 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69146 .71038 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .71058 .69186 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .69702 .72613 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .70806 .68006 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .69074 .75401 L p .69594 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .68608 .72047 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70417 .74638 m .69295 .74639 L p .69243 .73379 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .68344 .71977 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69146 .71038 m .69702 .72613 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69544 .73273 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .69146 .71038 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .68348 .71958 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68024 .7104 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .70806 .68006 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68344 .71977 m .68348 .71958 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69606 .66711 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .69702 .72613 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69243 .73379 m .69201 .72371 L .69702 .72613 L .707 .577 .707 r
F
.69702 .72613 m .70417 .74638 L p .69243 .73379 L F P
0 g
s
.70417 .74638 m .69702 .72613 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70076 .71837 m .70052 .73382 L .69937 .7313 L .707 .577 .707 r
F
.6975 .72718 m .70076 .71837 L .69937 .7313 L F
.70249 .74128 m .69878 .73 L .70052 .73382 L F
.70052 .73382 m .70618 .74985 L p .70249 .74128 L F P
0 g
s
.71058 .69186 m .70052 .73382 L p .70076 .71837 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68273 .76558 L .69575 .75819 L p .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .6745 .76025 L p .68197 .74729 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .69074 .75401 L p .68993 .7436 L .707 .577 .707 r
F P
0 g
s
.68993 .7436 m .68197 .74729 L .6745 .76025 L .707 .577 .707 r
F
.67002 .72959 m .67707 .74955 L p .68665 .74512 L F P
0 g
s
.67002 .72959 m .64685 .74031 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .67002 .72959 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65956 .7763 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65083 .76265 L p .65721 .75479 L .707 .577 .707 r
F P
0 g
s
.67083 .75719 m .66463 .75283 L .66112 .76907 L .707 .577 .707 r
F
.67083 .75719 m .66112 .76907 L .65956 .7763 L F
.64685 .74031 m .65241 .75606 L p .66463 .75283 L F P
0 g
s
.65083 .76265 m .6745 .76025 L p .67242 .75078 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .65721 .75479 L .65083 .76265 L .707 .577 .707 r
F
.64685 .74031 m .61884 .75158 L p .63155 .7593 L F P
0 g
s
.65241 .75606 m .64685 .74031 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.61884 .75158 m .62209 .76077 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.62204 .76096 m .65083 .76265 L p .64903 .75658 L .707 .577 .707 r
F P
0 g
s
.64903 .75658 m .62225 .76074 L .62204 .76096 L .707 .577 .707 r
F
.61884 .75158 m .58874 .76231 L p .59015 .76315 L F P
0 g
s
.62209 .76077 m .61884 .75158 L p .59015 .76315 L .707 .577 .707 r
F P
0 g
s
.6213 .76083 m .62204 .76096 L p .62198 .76078 L .707 .577 .707 r
F P
0 g
s
.5606 .74637 m .57322 .69371 L .54659 .68224 L p .707 .577 .707 r
F P
0 g
s
.57322 .69371 m .5606 .74637 L .59095 .75535 L p .707 .577 .707 r
F P
0 g
s
.53397 .7349 m .54659 .68224 L .52628 .6694 L p .707 .577 .707 r
F P
0 g
s
.54659 .68224 m .53397 .7349 L .5606 .74637 L p .707 .577 .707 r
F P
0 g
s
.60145 .79831 m .58874 .76231 L .55948 .77144 L p .707 .577 .707 r
F P
0 g
s
.58874 .76231 m .60145 .79831 L .63155 .78758 L p .707 .577 .707 r
F P
0 g
s
.55948 .77144 m .5722 .80744 L .60145 .79831 L p .707 .577 .707 r
F P
0 g
s
.5722 .80744 m .55948 .77144 L .53395 .77808 L p .707 .577 .707 r
F P
0 g
s
.53395 .77808 m .54666 .81408 L .5722 .80744 L p .707 .577 .707 r
F P
0 g
s
.52628 .6694 m .51366 .72206 L .53397 .7349 L p .707 .577 .707 r
F P
0 g
s
.51366 .72206 m .52628 .6694 L .51428 .65645 L p .707 .577 .707 r
F P
0 g
s
.59009 .85697 m .59348 .83915 L .56284 .83153 L p .707 .577 .707 r
F P
0 g
s
.59348 .83915 m .59009 .85697 L .62145 .86135 L p .707 .577 .707 r
F P
0 g
s
.62145 .86135 m .62483 .84353 L .59348 .83915 L p .707 .577 .707 r
F P
0 g
s
.62483 .84353 m .62145 .86135 L .65045 .86206 L p .707 .577 .707 r
F P
0 g
s
.65045 .86206 m .65384 .84424 L .62483 .84353 L p .707 .577 .707 r
F P
0 g
s
.55945 .84936 m .56284 .83153 L .53591 .82142 L p .707 .577 .707 r
F P
0 g
s
.56284 .83153 m .55945 .84936 L .59009 .85697 L p .707 .577 .707 r
F P
0 g
s
.54666 .81408 m .53395 .77808 L .51462 .78158 L p .707 .577 .707 r
F P
0 g
s
.53591 .82142 m .53253 .83925 L .55945 .84936 L p .707 .577 .707 r
F P
0 g
s
.53253 .83925 m .53591 .82145 L p .51534 .80982 L .707 .577 .707 r
F P
0 g
s
.53591 .82145 m .53591 .82142 L .53588 .82141 L p .707 .577 .707 r
F P
0 g
s
.53588 .82141 m .51534 .80982 L p .53591 .82145 L .707 .577 .707 r
F P
0 g
s
.52733 .81757 m .51858 .79278 L p .5034 .78159 L .707 .577 .707 r
F P
0 g
s
.51858 .79278 m .51462 .78158 L .51181 .78158 L p .707 .577 .707 r
F P
0 g
s
.51181 .78158 m .5034 .78159 L p .51858 .79278 L .707 .577 .707 r
F P
0 g
s
.51462 .78158 m .52733 .81757 L .54666 .81408 L p .707 .577 .707 r
F P
0 g
s
.51428 .65645 m .50166 .70911 L .51366 .72206 L p .707 .577 .707 r
F P
0 g
s
.65384 .84424 m .65045 .86206 L .67425 .85904 L p .707 .577 .707 r
F P
0 g
s
.67425 .85904 m .67764 .84121 L .65384 .84424 L p .707 .577 .707 r
F P
0 g
s
.50166 .70911 m .51428 .65645 L .51176 .64466 L p .707 .577 .707 r
F P
0 g
s
.51534 .80982 m .51195 .82764 L .53253 .83925 L p .707 .577 .707 r
F P
0 g
s
.51195 .82764 m .51487 .81229 L p .50313 .79784 L .707 .577 .707 r
F P
0 g
s
.51487 .81229 m .51534 .80982 L .51311 .80763 L p .707 .577 .707 r
F P
0 g
s
.51311 .80763 m .50313 .79784 L p .51487 .81229 L .707 .577 .707 r
F P
0 g
s
.51612 .81759 m .50523 .78677 L p .50139 .77812 L .707 .577 .707 r
F P
0 g
s
.50523 .78677 m .5034 .78159 L .50304 .78097 L p .707 .577 .707 r
F P
0 g
s
.50304 .78097 m .50139 .77812 L p .50523 .78677 L .707 .577 .707 r
F P
0 g
s
.5034 .78159 m .51612 .81759 L .52733 .81757 L p .707 .577 .707 r
F P
0 g
s
.67764 .84121 m .67425 .85904 L .69054 .85258 L p .707 .577 .707 r
F P
0 g
s
.69054 .85258 m .69393 .83475 L .67764 .84121 L p .707 .577 .707 r
F P
0 g
s
.51176 .64466 m .49914 .69732 L .50166 .70911 L p .707 .577 .707 r
F P
0 g
s
.50313 .79784 m .49974 .81567 L .51195 .82764 L p .707 .577 .707 r
F P
0 g
s
.49914 .69732 m .51176 .64466 L .51898 .63517 L p .707 .577 .707 r
F P
0 g
s
.49492 .8217 m .48824 .31914 L .44423 .31706 L p .707 .577 .707 r
F P
0 g
s
.49974 .81567 m .50313 .79784 L .50048 .78667 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .51612 .81759 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50139 .77812 m .50185 .77943 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50185 .77943 m .5141 .81412 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50048 .78667 m .49709 .8045 L .49974 .81567 L p .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50048 .78667 L .50297 .78345 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .50139 .77812 L .50878 .77151 L p .707 .577 .707 r
F P
0 g
s
.50297 .78345 m .50764 .7774 L p .50393 .78693 L .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50297 .78345 L .50393 .78693 L .707 .577 .707 r
F
.51898 .63517 m .50635 .68783 L .49914 .69732 L p F P
0 g
s
.50635 .68783 m .51898 .63517 L .53521 .62892 L p .707 .577 .707 r
F P
0 g
s
.50878 .77151 m .52149 .8075 L .5141 .81412 L p .707 .577 .707 r
F P
0 g
s
.53521 .62892 m .52259 .68159 L .50635 .68783 L p .707 .577 .707 r
F P
0 g
s
.50764 .7774 m .50426 .79523 L .49709 .8045 L p .707 .577 .707 r
F P
0 g
s
.52259 .68159 m .53521 .62892 L .55889 .62653 L p .707 .577 .707 r
F P
0 g
s
.52149 .8075 m .50878 .77151 L .52484 .76239 L p .707 .577 .707 r
F P
0 g
s
.50426 .79523 m .50764 .7774 L .52393 .77094 L p .707 .577 .707 r
F P
0 g
s
.55889 .62653 m .54627 .67919 L .52259 .68159 L p .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52149 .8075 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.52484 .76239 m .5253 .7637 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.5253 .7637 m .53755 .79838 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52484 .76239 L .54801 .75167 L p .707 .577 .707 r
F P
0 g
s
.52054 .78877 m .52393 .77094 L .53645 .76935 L p .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .53755 .79838 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54801 .75167 m .54984 .75685 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54984 .75685 m .56072 .78766 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .54801 .75167 L .57602 .74039 L p .707 .577 .707 r
F P
0 g
s
.57602 .74039 m .58873 .77639 L .56072 .78766 L p .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .54774 .76792 L .57144 .7685 L p .707 .577 .707 r
F P
0 g
s
.57144 .7685 m .57674 .76863 L p .57419 .76998 L .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .57144 .7685 L .57419 .76998 L .707 .577 .707 r
F
.53645 .76935 m .54774 .76792 L p .54212 .77222 L F P
0 g
s
.52054 .78877 m .53645 .76935 L .54212 .77222 L .707 .577 .707 r
F
.52393 .77094 m .52054 .78877 L .50426 .79523 L p F P
0 g
s
.54774 .76792 m .54435 .78574 L .52054 .78877 L p .707 .577 .707 r
F P
0 g
s
.48824 .31914 m .49492 .8217 L .53987 .82007 L p .707 .577 .707 r
F P
0 g
s
.53987 .82007 m .53318 .31751 L .48824 .31914 L p .707 .577 .707 r
F P
0 g
s
.54627 .67919 m .55889 .62653 L .58768 .62822 L p .707 .577 .707 r
F P
0 g
s
.58768 .62822 m .57506 .68088 L .54627 .67919 L p .707 .577 .707 r
F P
0 g
s
.57674 .76863 m .57335 .78646 L .54435 .78574 L p .707 .577 .707 r
F P
0 g
s
.58873 .77639 m .57602 .74039 L .60612 .72967 L p .707 .577 .707 r
F P
0 g
s
.60612 .72967 m .61884 .76566 L .58873 .77639 L p .707 .577 .707 r
F P
0 g
s
.57335 .78646 m .57674 .76863 L .60809 .77301 L p .707 .577 .707 r
F P
0 g
s
.60809 .77301 m .6047 .79083 L .57335 .78646 L p .707 .577 .707 r
F P
0 g
s
.53318 .31751 m .53987 .82007 L .58134 .81487 L p .707 .577 .707 r
F P
0 g
s
.57506 .68088 m .58768 .62822 L .61877 .63382 L p .707 .577 .707 r
F P
0 g
s
.61877 .63382 m .60615 .68649 L .57506 .68088 L p .707 .577 .707 r
F P
0 g
s
.58134 .81487 m .57466 .31232 L .53318 .31751 L p .707 .577 .707 r
F P
0 g
s
.69393 .83475 m .69054 .85258 L .69771 .84331 L p .707 .577 .707 r
F P
0 g
s
.69771 .84331 m .7011 .82548 L .69393 .83475 L p .707 .577 .707 r
F P
0 g
s
.45092 .81961 m .44423 .31706 L .40547 .31145 L p .707 .577 .707 r
F P
0 g
s
.44423 .31706 m .45092 .81961 L .49492 .8217 L p .707 .577 .707 r
F P
0 g
s
.61884 .76566 m .60612 .72967 L .63538 .72053 L p .707 .577 .707 r
F P
0 g
s
.63873 .78062 m .63534 .79845 L .6047 .79083 L p .707 .577 .707 r
F P
0 g
s
.6047 .79083 m .60809 .77301 L .63873 .78062 L p .707 .577 .707 r
F P
0 g
s
.57466 .31232 m .58134 .81487 L .6153 .80662 L p .707 .577 .707 r
F P
0 g
s
.64912 .6428 m .63649 .69546 L .60615 .68649 L p .707 .577 .707 r
F P
0 g
s
.60615 .68649 m .61877 .63382 L .64912 .6428 L p .707 .577 .707 r
F P
0 g
s
.6153 .80662 m .60861 .30407 L .57466 .31232 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .26056 .66582 L .23022 .65684 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .27882 .72405 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.26056 .66582 m .25142 .70397 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.25142 .70397 m .24794 .71848 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.27901 .72403 m .26056 .66582 L .27882 .72405 L .707 .577 .707 r
F
.26588 .73756 m .27904 .72403 L .247 .72642 L F
.28854 .75093 m .27904 .72403 L p .26588 .73756 L F P
0 g
s
.31655 .73965 m .28842 .72258 L .27904 .72403 L .707 .577 .707 r
F
.30605 .71983 m .30069 .7018 L .27909 .72403 L F
.29165 .67143 m .27904 .72403 L p .30069 .7018 L F P
0 g
s
.27904 .72403 m .28854 .75093 L .30626 .7438 L p .707 .577 .707 r
F P
0 g
s
.30626 .7438 m .31655 .73965 L p .27904 .72403 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .27903 .72409 L p .27909 .72403 L .707 .577 .707 r
F P
0 g
s
.30069 .7018 m .27904 .72403 L .27909 .72403 L .707 .577 .707 r
F
.29165 .67143 m .26056 .66582 L p .279 .724 L F P
0 g
s
.27903 .72409 m .27904 .72403 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .29165 .67143 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.29921 .72913 m .30937 .71932 L .28842 .72258 L .707 .577 .707 r
F
.31655 .73965 m .30937 .71932 L p .29921 .72913 L F P
0 g
s
.31655 .73965 m .33972 .72893 L p .32775 .7205 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .32688 .7024 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .30937 .71932 L p .32688 .7024 L F P
0 g
s
.32688 .7024 m .30937 .71932 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .29165 .67143 L p .30529 .71726 L F P
0 g
s
.30782 .72578 m .30937 .71932 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .32044 .67311 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.33972 .72893 m .33403 .71281 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.34412 .67072 m .32044 .67311 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .33403 .71281 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .34412 .67072 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.34556 .71652 m .34357 .7084 L .33403 .71281 L .707 .577 .707 r
F
.35579 .71982 m .34752 .7121 L .34556 .71652 L F
.34752 .7121 m .34357 .7084 L .34556 .71652 L F
.34693 .70685 m .34623 .69787 L .3389 .71056 L F
.34412 .67072 m .33403 .71281 L p .34623 .69787 L F P
0 g
s
.34623 .69787 m .33403 .71281 L .3389 .71056 L .707 .577 .707 r
F
.34308 .68383 m .32701 .69294 L p .34357 .7084 L F P
0 g
s
.35579 .71982 m .35061 .70515 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36036 .66447 m .34412 .67072 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.34773 .71713 m .35061 .70515 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .36036 .66447 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35729 .70943 m .35452 .70055 L .35061 .70515 L .707 .577 .707 r
F
.36317 .7132 m .35736 .70471 L .35729 .70943 L F
.35736 .70471 m .35452 .70055 L .35729 .70943 L F
.35061 .70515 m .35579 .71982 L .36297 .71338 L p F P
0 g
s
.36297 .71338 m .36317 .7132 L p .35061 .70515 L .707 .577 .707 r
F P
0 g
s
.35606 .69874 m .35709 .69054 L .3529 .70246 L .707 .577 .707 r
F
.36036 .66447 m .35061 .70515 L p .35709 .69054 L F P
0 g
s
.35709 .69054 m .35061 .70515 L .3529 .70246 L .707 .577 .707 r
F
.35046 .67721 m .34308 .68383 L p .35452 .70055 L F P
0 g
s
.36317 .7132 m .35748 .69708 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.36757 .65499 m .36036 .66447 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35748 .69708 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36757 .65499 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.36317 .7132 m .36116 .70973 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .35046 .67721 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.35477 .7016 m .35495 .70765 L p .35606 .69874 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35401 .70327 L .34773 .71713 L .707 .577 .707 r
F
.35606 .69874 m .3529 .70246 L .34773 .71713 L F
.34308 .68383 m .35061 .70515 L p .35452 .70055 L F P
0 g
s
.35495 .70765 m .35243 .69585 L p .35444 .69042 L .707 .577 .707 r
F P
0 g
s
.35046 .67721 m .35748 .69708 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35444 .69042 m .35634 .69457 L .35495 .70765 L .707 .577 .707 r
F
.34845 .67374 m .35046 .67721 L p .35575 .69328 L F P
0 g
s
.35748 .69708 m .35495 .70765 L p .35634 .69457 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .34845 .67374 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36757 .65499 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .35398 .6894 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36505 .64319 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34773 .71713 L p .3529 .70246 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34308 .68383 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .34994 .70974 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .34043 .6829 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.34845 .67374 m .35398 .6894 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.38244 .80543 m .37575 .30287 L .35798 .29217 L p .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .35243 .69585 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34845 .67374 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .34044 .68285 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .33723 .67375 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .36505 .64319 L p .34508 .67541 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36138 .65852 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.36138 .65852 m .35398 .6894 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.34459 .68485 m .36143 .65057 L .35398 .6894 L .707 .577 .707 r
F
.36466 .79473 m .36445 .7784 L p .36432 .77855 L F P
0 g
s
.34508 .67541 m .36505 .64319 L .34459 .68485 L .707 .577 .707 r
F
.36757 .65499 m .35748 .69708 L p .35772 .68158 L F P
0 g
s
.36445 .7784 m .35798 .29217 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36317 .7132 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .35389 .28038 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36116 .70973 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .35398 .6894 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .36466 .79473 L .38244 .80543 L p .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36058 .78294 L .36466 .79473 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36058 .78294 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36389 .26867 m .36429 .29882 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36429 .29882 m .37058 .77122 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34584 .66035 L .34508 .67541 L .707 .577 .707 r
F
.34584 .66035 m .35305 .63024 L .34508 .67541 L F
.34043 .6829 m .34044 .68285 L p .34046 .68285 L F P
0 g
s
.34044 .68285 m .35305 .63024 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36389 .26867 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36058 .78294 m .35624 .4567 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.35624 .4567 m .35389 .28038 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34508 .67541 L .34459 .68485 L .707 .577 .707 r
F
.34941 .697 m .349 .68699 L .35398 .6894 L F
.35772 .68158 m .35748 .69708 L .35634 .69457 L F
.35444 .69042 m .35772 .68158 L .35634 .69457 L F
.35944 .70451 m .35575 .69328 L .35748 .69708 L F
.33403 .71281 m .33972 .72893 L .35282 .7215 L p F P
0 g
s
.35282 .7215 m .35579 .71982 L p .33403 .71281 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .3315 .72338 L p .3389 .71056 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .34773 .71713 L p .34693 .70685 L .707 .577 .707 r
F P
0 g
s
.34693 .70685 m .3389 .71056 L .3315 .72338 L .707 .577 .707 r
F
.32701 .69294 m .33403 .71281 L p .34357 .7084 L F P
0 g
s
.32701 .69294 m .30384 .70366 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .32701 .69294 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .31655 .73965 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .30782 .72578 L p .31411 .71807 L .707 .577 .707 r
F P
0 g
s
.32775 .7205 m .32152 .71611 L .3181 .73231 L .707 .577 .707 r
F
.32775 .7205 m .3181 .73231 L .31655 .73965 L F
.30384 .70366 m .30937 .71932 L p .32152 .71611 L F P
0 g
s
.30782 .72578 m .3315 .72338 L p .32944 .71402 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .31411 .71807 L .30782 .72578 L .707 .577 .707 r
F
.30384 .70366 m .27583 .71494 L p .28842 .72258 L F P
0 g
s
.30937 .71932 m .30384 .70366 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27583 .71494 m .27904 .72403 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27903 .72409 m .30782 .72578 L p .30605 .71983 L .707 .577 .707 r
F P
0 g
s
.30605 .71983 m .27909 .72403 L .27903 .72409 L .707 .577 .707 r
F
.27583 .71494 m .24573 .72567 L p .247 .72642 L F P
0 g
s
.27904 .72403 m .27583 .71494 L p .247 .72642 L .707 .577 .707 r
F P
0 g
s
.27882 .72405 m .27903 .72409 L p .27901 .72403 L .707 .577 .707 r
F P
0 g
s
.41216 .81401 m .40547 .31145 L .37575 .30287 L p .707 .577 .707 r
F P
0 g
s
.40547 .31145 m .41216 .81401 L .45092 .81961 L p .707 .577 .707 r
F P
0 g
s
.21759 .7095 m .23022 .65684 L .20358 .64537 L p .707 .577 .707 r
F P
0 g
s
.23022 .65684 m .21759 .7095 L .24794 .71848 L p .707 .577 .707 r
F P
0 g
s
.7011 .82548 m .69771 .84331 L .69506 .83214 L p .707 .577 .707 r
F P
0 g
s
.69506 .83214 m .69844 .81431 L .7011 .82548 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19096 .69803 m .20358 .64537 L .18327 .63253 L p .707 .577 .707 r
F P
0 g
s
.20358 .64537 m .19096 .69803 L .21759 .7095 L p .707 .577 .707 r
F P
0 g
s
.63538 .72053 m .64809 .75653 L .61884 .76566 L p .707 .577 .707 r
F P
0 g
s
.63534 .79845 m .63873 .78062 L .66566 .79073 L p .707 .577 .707 r
F P
0 g
s
.60861 .30407 m .6153 .80662 L .63841 .79613 L p .707 .577 .707 r
F P
0 g
s
.67575 .65427 m .66313 .70694 L .63649 .69546 L p .707 .577 .707 r
F P
0 g
s
.63649 .69546 m .64912 .6428 L .67575 .65427 L p .707 .577 .707 r
F P
0 g
s
.64809 .75653 m .63538 .72053 L .66092 .71389 L p .707 .577 .707 r
F P
0 g
s
.63841 .79613 m .63172 .29357 L .60861 .30407 L p .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .67363 .74989 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .68348 .71958 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68344 .71977 L .68296 .71947 L p .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69295 .74639 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.67363 .74989 m .66092 .71389 L .68024 .7104 L p .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .68348 .71958 L p .66313 .70694 L .707 .577 .707 r
F P
0 g
s
.68296 .71947 m .66313 .70694 L p .68348 .71958 L .707 .577 .707 r
F P
0 g
s
.66313 .70694 m .67575 .65427 L .69606 .66711 L p .707 .577 .707 r
F P
0 g
s
.25844 .76166 m .24573 .72567 L .21648 .7348 L p .707 .577 .707 r
F P
0 g
s
.24573 .72567 m .25844 .76166 L .28854 .75093 L p .707 .577 .707 r
F P
0 g
s
.21648 .7348 m .22919 .77079 L .25844 .76166 L p .707 .577 .707 r
F P
0 g
s
.22919 .77079 m .21648 .7348 L .19094 .74144 L p .707 .577 .707 r
F P
0 g
s
.69844 .81431 m .69506 .83214 L .68284 .82017 L p .707 .577 .707 r
F P
0 g
s
.68284 .82017 m .68623 .80234 L .69844 .81431 L p .707 .577 .707 r
F P
0 g
s
.37575 .30287 m .38244 .80543 L .41216 .81401 L p .707 .577 .707 r
F P
0 g
s
.19094 .74144 m .20365 .77743 L .22919 .77079 L p .707 .577 .707 r
F P
0 g
s
.18327 .63253 m .17065 .68519 L .19096 .69803 L p .707 .577 .707 r
F P
0 g
s
.17065 .68519 m .18327 .63253 L .17127 .61958 L p .707 .577 .707 r
F P
0 g
s
.24708 .81951 m .25047 .80168 L .21983 .79407 L p .707 .577 .707 r
F P
0 g
s
.25047 .80168 m .24708 .81951 L .27844 .82389 L p .707 .577 .707 r
F P
0 g
s
.27844 .82389 m .28183 .80606 L .25047 .80168 L p .707 .577 .707 r
F P
0 g
s
.28183 .80606 m .27844 .82389 L .30744 .8246 L p .707 .577 .707 r
F P
0 g
s
.30744 .8246 m .31083 .80677 L .28183 .80606 L p .707 .577 .707 r
F P
0 g
s
.21644 .81189 m .21983 .79407 L .19291 .78396 L p .707 .577 .707 r
F P
0 g
s
.21983 .79407 m .21644 .81189 L .24708 .81951 L p .707 .577 .707 r
F P
0 g
s
.20365 .77743 m .19094 .74144 L .17161 .74494 L p .707 .577 .707 r
F P
0 g
s
.19291 .78396 m .18952 .80179 L .21644 .81189 L p .707 .577 .707 r
F P
0 g
s
.18952 .80179 m .1928 .78452 L p .17233 .77235 L .707 .577 .707 r
F P
0 g
s
.1928 .78452 m .19291 .78396 L .19223 .78358 L p .707 .577 .707 r
F P
0 g
s
.19223 .78358 m .17233 .77235 L p .1928 .78452 L .707 .577 .707 r
F P
0 g
s
.18432 .78093 m .17547 .75585 L p .1604 .74495 L .707 .577 .707 r
F P
0 g
s
.17547 .75585 m .17161 .74494 L .16887 .74494 L p .707 .577 .707 r
F P
0 g
s
.16887 .74494 m .1604 .74495 L p .17547 .75585 L .707 .577 .707 r
F P
0 g
s
.17161 .74494 m .18432 .78093 L .20365 .77743 L p .707 .577 .707 r
F P
0 g
s
.63172 .29357 m .63841 .79613 L .64841 .78441 L p .707 .577 .707 r
F P
0 g
s
.64841 .78441 m .64172 .28186 L .63172 .29357 L p .707 .577 .707 r
F P
0 g
s
.17127 .61958 m .15865 .67224 L .17065 .68519 L p .707 .577 .707 r
F P
0 g
s
.31083 .80677 m .30744 .8246 L .33125 .82158 L p .707 .577 .707 r
F P
0 g
s
.33125 .82158 m .33463 .80375 L .31083 .80677 L p .707 .577 .707 r
F P
0 g
s
.68623 .80234 m .68284 .82017 L .66227 .80856 L p .707 .577 .707 r
F P
0 g
s
.66227 .80856 m .66566 .79073 L .68623 .80234 L p .707 .577 .707 r
F P
0 g
s
.66092 .71389 m .67363 .74989 L .64809 .75653 L p .707 .577 .707 r
F P
0 g
s
.15865 .67224 m .17127 .61958 L .16875 .60778 L p .707 .577 .707 r
F P
0 g
s
.17233 .77235 m .16894 .79018 L .18952 .80179 L p .707 .577 .707 r
F P
0 g
s
.16894 .79018 m .17176 .77535 L p .16012 .76037 L .707 .577 .707 r
F P
0 g
s
.17176 .77535 m .17233 .77235 L .16962 .76969 L p .707 .577 .707 r
F P
0 g
s
.16962 .76969 m .16012 .76037 L p .17176 .77535 L .707 .577 .707 r
F P
0 g
s
.17311 .78094 m .16212 .74984 L p .15838 .74148 L .707 .577 .707 r
F P
0 g
s
.16212 .74984 m .1604 .74495 L .16005 .74436 L p .707 .577 .707 r
F P
0 g
s
.16005 .74436 m .15838 .74148 L p .16212 .74984 L .707 .577 .707 r
F P
0 g
s
.1604 .74495 m .17311 .78094 L .18432 .78093 L p .707 .577 .707 r
F P
0 g
s
.33463 .80375 m .33125 .82158 L .34753 .81511 L p .707 .577 .707 r
F P
0 g
s
.34753 .81511 m .35092 .79729 L .33463 .80375 L p .707 .577 .707 r
F P
0 g
s
.66566 .79073 m .66227 .80856 L .63534 .79845 L p .707 .577 .707 r
F P
0 g
s
.16875 .60778 m .15613 .66044 L .15865 .67224 L p .707 .577 .707 r
F P
0 g
s
.16012 .76037 m .15673 .7782 L .16894 .79018 L p .707 .577 .707 r
F P
0 g
s
.15613 .66044 m .16875 .60778 L .17597 .5983 L p .707 .577 .707 r
F P
0 g
s
.64172 .28186 m .64841 .78441 L .64432 .77263 L p .707 .577 .707 r
F P
0 g
s
.64432 .77263 m .63763 .27007 L .64172 .28186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35092 .79729 m .34753 .81511 L .3547 .80584 L p .707 .577 .707 r
F P
0 g
s
.3547 .80584 m .35809 .78802 L .35092 .79729 L p .707 .577 .707 r
F P
0 g
s
.15673 .7782 m .16012 .76037 L .15747 .7492 L p .707 .577 .707 r
F P
0 g
s
.15747 .7492 m .15408 .76703 L .15673 .7782 L p .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15747 .7492 L .15977 .74622 L p .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .17311 .78094 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15874 .7425 m .17109 .77747 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15838 .74148 m .15874 .7425 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .15838 .74148 L .16577 .73486 L p .707 .577 .707 r
F P
0 g
s
.15977 .74622 m .16463 .73993 L p .16078 .74983 L .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15977 .74622 L .16078 .74983 L .707 .577 .707 r
F
.17597 .5983 m .16334 .65096 L .15613 .66044 L p F P
0 g
s
.16334 .65096 m .17597 .5983 L .19221 .59205 L p .707 .577 .707 r
F P
0 g
s
.35809 .78802 m .3547 .80584 L .35205 .79467 L p .707 .577 .707 r
F P
0 g
s
.35205 .79467 m .35543 .77685 L .35809 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16577 .73486 m .17848 .77085 L .17109 .77747 L p .707 .577 .707 r
F P
0 g
s
.63763 .27007 m .64432 .77263 L .62655 .76192 L p .707 .577 .707 r
F P
0 g
s
.62655 .76192 m .61986 .25936 L .63763 .27007 L p .707 .577 .707 r
F P
0 g
s
.19221 .59205 m .17958 .64471 L .16334 .65096 L p .707 .577 .707 r
F P
0 g
s
.16463 .73993 m .16125 .75776 L .15408 .76703 L p .707 .577 .707 r
F P
0 g
s
.17958 .64471 m .19221 .59205 L .21588 .58965 L p .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .33062 .71324 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34044 .68285 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34043 .6829 L .34029 .68281 L p .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34994 .70974 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33062 .71324 m .31791 .67725 L .33723 .67375 L p .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .34044 .68285 L p .32012 .67006 L .707 .577 .707 r
F P
0 g
s
.34029 .68281 m .32012 .67006 L p .34044 .68285 L .707 .577 .707 r
F P
0 g
s
.32012 .67006 m .33274 .6174 L .35305 .63024 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36389 .26867 L .387 .25817 L p .707 .577 .707 r
F P
0 g
s
.17848 .77085 m .16577 .73486 L .18183 .72575 L p .707 .577 .707 r
F P
0 g
s
.35543 .77685 m .35205 .79467 L .33983 .7827 L p .707 .577 .707 r
F P
0 g
s
.33983 .7827 m .34322 .76487 L .35543 .77685 L p .707 .577 .707 r
F P
0 g
s
.16125 .75776 m .16463 .73993 L .18092 .73347 L p .707 .577 .707 r
F P
0 g
s
.21588 .58965 m .20326 .64232 L .17958 .64471 L p .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .17848 .77085 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.18219 .72677 m .19454 .76174 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .18183 .72575 L .205 .71502 L p .707 .577 .707 r
F P
0 g
s
.17753 .7513 m .18092 .73347 L .19251 .732 L p .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .19454 .76174 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.205 .71502 m .20673 .71991 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.20673 .71991 m .21771 .75102 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .205 .71502 L .23301 .70375 L p .707 .577 .707 r
F P
0 g
s
.23301 .70375 m .24572 .73974 L .21771 .75102 L p .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .20473 .73045 L .22729 .731 L p .707 .577 .707 r
F P
0 g
s
.22729 .731 m .23373 .73116 L p .23062 .7328 L .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .22729 .731 L .23062 .7328 L .707 .577 .707 r
F
.19251 .732 m .20473 .73045 L p .19865 .73511 L F P
0 g
s
.17753 .7513 m .19251 .732 L .19865 .73511 L .707 .577 .707 r
F
.18183 .72575 m .18219 .72677 L p .18177 .72655 L F P
0 g
s
.20326 .64232 m .21588 .58965 L .24467 .59134 L p .707 .577 .707 r
F P
0 g
s
.33274 .6174 m .32012 .67006 L .29348 .65859 L p .707 .577 .707 r
F P
0 g
s
.29348 .65859 m .30611 .60593 L .33274 .6174 L p .707 .577 .707 r
F P
0 g
s
.18092 .73347 m .17753 .7513 L .16125 .75776 L p .707 .577 .707 r
F P
0 g
s
.61986 .25936 m .62655 .76192 L .59682 .75335 L p .707 .577 .707 r
F P
0 g
s
.59682 .75335 m .59014 .25079 L .61986 .25936 L p .707 .577 .707 r
F P
0 g
s
.23205 .644 m .24467 .59134 L .27576 .59695 L p .707 .577 .707 r
F P
0 g
s
.24467 .59134 m .23205 .644 L .20326 .64232 L p .707 .577 .707 r
F P
0 g
s
.30611 .60593 m .29348 .65859 L .26314 .64961 L p .707 .577 .707 r
F P
0 g
s
.26314 .64961 m .27576 .59695 L .30611 .60593 L p .707 .577 .707 r
F P
0 g
s
.27576 .59695 m .26314 .64961 L .23205 .644 L p .707 .577 .707 r
F P
0 g
s
.34322 .76487 m .33983 .7827 L .31926 .77109 L p .707 .577 .707 r
F P
0 g
s
.31926 .77109 m .32265 .75326 L .34322 .76487 L p .707 .577 .707 r
F P
0 g
s
.31791 .67725 m .33062 .71324 L .30508 .71988 L p .707 .577 .707 r
F P
0 g
s
.30508 .71988 m .29237 .68389 L .31791 .67725 L p .707 .577 .707 r
F P
0 g
s
.72815 .66332 m .74078 .61065 L .71043 .60167 L p .707 .577 .707 r
F P
0 g
s
.74078 .61065 m .72815 .66332 L .75851 .66879 L p .707 .577 .707 r
F P
0 g
s
.75919 .66874 m .75915 .66863 L .75851 .66879 L .707 .577 .707 r
F
.75915 .66863 m .74078 .61065 L .75826 .66799 L F
.75915 .66863 m .75826 .66799 L .75851 .66879 L F
.74617 .68221 m .75929 .66873 L .72736 .67111 L F
.76876 .69554 m .75929 .66873 L p .74617 .68221 L F P
0 g
s
.79676 .68426 m .76876 .66726 L .75929 .66873 L .707 .577 .707 r
F
.78623 .66454 m .78088 .64655 L .75945 .66871 L F
.77187 .61626 m .75929 .66873 L p .78088 .64655 L F P
0 g
s
.75929 .66873 m .76876 .69554 L .78641 .68843 L p .707 .577 .707 r
F P
0 g
s
.78641 .68843 m .79676 .68426 L p .75929 .66873 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .75924 .66892 L p .75945 .66871 L .707 .577 .707 r
F P
0 g
s
.78088 .64655 m .75929 .66873 L .75945 .66871 L .707 .577 .707 r
F
.77187 .61626 m .74078 .61065 L p .75915 .66863 L F P
0 g
s
.75924 .66892 m .75929 .66873 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .77187 .61626 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.7795 .67378 m .78962 .66402 L .76876 .66726 L .707 .577 .707 r
F
.79676 .68426 m .78962 .66402 L p .7795 .67378 L F P
0 g
s
.79676 .68426 m .81994 .67354 L p .80803 .66516 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .80708 .64715 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .78962 .66402 L p .80708 .64715 L F P
0 g
s
.80708 .64715 m .78962 .66402 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .77187 .61626 L p .78545 .66191 L F P
0 g
s
.78804 .67061 m .78962 .66402 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .80066 .61795 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.81994 .67354 m .81427 .65751 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.82433 .61555 m .80066 .61795 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .81427 .65751 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .82433 .61555 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.82582 .66119 m .82386 .65308 L .81427 .65751 L .707 .577 .707 r
F
.836 .66443 m .82779 .65675 L .82582 .66119 L F
.82779 .65675 m .82386 .65308 L .82582 .66119 L F
.83296 .66615 m .836 .66443 L p .81427 .65751 L F P
0 g
s
.82714 .65157 m .82644 .64262 L .81917 .65525 L .707 .577 .707 r
F
.82433 .61555 m .81427 .65751 L p .82644 .64262 L F P
0 g
s
.82644 .64262 m .81427 .65751 L .81917 .65525 L .707 .577 .707 r
F
.82329 .62843 m .80722 .63755 L p .82386 .65308 L F P
0 g
s
.836 .66443 m .83085 .64985 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84057 .60931 m .82433 .61555 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.82795 .66197 m .83085 .64985 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .84057 .60931 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83754 .6541 m .83478 .64523 L .83085 .64985 L .707 .577 .707 r
F
.84339 .65781 m .83761 .64937 L .83754 .6541 L F
.83761 .64937 m .83478 .64523 L .83754 .6541 L F
.83085 .64985 m .836 .66443 L .84314 .65803 L p F P
0 g
s
.84314 .65803 m .84339 .65781 L p .83085 .64985 L .707 .577 .707 r
F P
0 g
s
.83629 .64347 m .83732 .63529 L .83315 .64715 L .707 .577 .707 r
F
.84057 .60931 m .83085 .64985 L p .83732 .63529 L F P
0 g
s
.83732 .63529 m .83085 .64985 L .83315 .64715 L .707 .577 .707 r
F
.83068 .62182 m .82329 .62843 L p .83478 .64523 L F P
0 g
s
.84339 .65781 m .83773 .64178 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.84778 .59982 m .84057 .60931 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83773 .64178 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .84778 .59982 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.84339 .65781 m .84137 .65434 L p .8397 .64924 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .83068 .62182 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.835 .64633 m .83516 .65248 L p .83629 .64347 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83422 .64806 L .82795 .66197 L .707 .577 .707 r
F
.83629 .64347 m .83315 .64715 L .82795 .66197 L F
.82329 .62843 m .83085 .64985 L p .83478 .64523 L F P
0 g
s
.83516 .65248 m .83264 .64069 L p .8347 .63514 L .707 .577 .707 r
F P
0 g
s
.83068 .62182 m .83773 .64178 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.8347 .63514 m .83658 .63926 L .83516 .65248 L .707 .577 .707 r
F
.82866 .61834 m .83068 .62182 L p .83599 .63796 L F P
0 g
s
.83773 .64178 m .83516 .65248 L p .83658 .63926 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .82866 .61834 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .84778 .59982 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .83422 .63409 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .84527 .58803 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82795 .66197 L p .83315 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82329 .62843 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84137 .65434 m .83016 .65435 L p .82963 .64175 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .82064 .62774 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82866 .61834 m .83422 .63409 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .83264 .64069 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82866 .61834 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .82069 .62755 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .81744 .61836 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .84527 .58803 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82064 .62774 m .82069 .62755 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83327 .57507 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .83422 .63409 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82963 .64175 m .82921 .63167 L .83422 .63409 L .707 .577 .707 r
F
.83422 .63409 m .84137 .65434 L p .82963 .64175 L F P
0 g
s
.84137 .65434 m .83422 .63409 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.83796 .62633 m .83773 .64178 L .83658 .63926 L .707 .577 .707 r
F
.8347 .63514 m .83796 .62633 L .83658 .63926 L F
.8397 .64924 m .83599 .63796 L .83773 .64178 L F
.83773 .64178 m .84339 .65781 L p .8397 .64924 L F P
0 g
s
.84778 .59982 m .83773 .64178 L p .83796 .62633 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81994 .67354 L .83296 .66615 L p .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81171 .66822 L p .81917 .65525 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .82795 .66197 L p .82714 .65157 L .707 .577 .707 r
F P
0 g
s
.82714 .65157 m .81917 .65525 L .81171 .66822 L .707 .577 .707 r
F
.80722 .63755 m .81427 .65751 L p .82386 .65308 L F P
0 g
s
.80722 .63755 m .78405 .64827 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .80722 .63755 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .79676 .68426 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .78804 .67061 L p .79442 .66275 L .707 .577 .707 r
F P
0 g
s
.80803 .66516 m .80184 .66079 L .79833 .67703 L .707 .577 .707 r
F
.80803 .66516 m .79833 .67703 L .79676 .68426 L F
.78405 .64827 m .78962 .66402 L p .80184 .66079 L F P
0 g
s
.78804 .67061 m .81171 .66822 L p .80963 .65874 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .79442 .66275 L .78804 .67061 L .707 .577 .707 r
F
.78405 .64827 m .75605 .65955 L p .76876 .66726 L F P
0 g
s
.78962 .66402 m .78405 .64827 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75605 .65955 m .75929 .66873 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75924 .66892 m .78804 .67061 L p .78623 .66454 L .707 .577 .707 r
F P
0 g
s
.78623 .66454 m .75945 .66871 L .75924 .66892 L .707 .577 .707 r
F
.75605 .65955 m .72594 .67027 L p .72736 .67111 L F P
0 g
s
.75929 .66873 m .75605 .65955 L p .72736 .67111 L .707 .577 .707 r
F P
0 g
s
.75851 .66879 m .75924 .66892 L p .75919 .66874 L .707 .577 .707 r
F P
0 g
s
.387 .25817 m .39369 .76073 L .37058 .77122 L p .707 .577 .707 r
F P
0 g
s
.39369 .76073 m .387 .25817 L .42095 .24992 L p .707 .577 .707 r
F P
0 g
s
.20473 .73045 m .20134 .74828 L .17753 .7513 L p .707 .577 .707 r
F P
0 g
s
.69781 .65434 m .71043 .60167 L .6838 .5902 L p .707 .577 .707 r
F P
0 g
s
.71043 .60167 m .69781 .65434 L .72815 .66332 L p .707 .577 .707 r
F P
0 g
s
.29237 .68389 m .30508 .71988 L .27583 .72901 L p .707 .577 .707 r
F P
0 g
s
.27583 .72901 m .26311 .69302 L .29237 .68389 L p .707 .577 .707 r
F P
0 g
s
.32265 .75326 m .31926 .77109 L .29233 .76098 L p .707 .577 .707 r
F P
0 g
s
.29233 .76098 m .29572 .74316 L .32265 .75326 L p .707 .577 .707 r
F P
0 g
s
.59014 .25079 m .59682 .75335 L .55806 .74774 L p .707 .577 .707 r
F P
0 g
s
.55806 .74774 m .55138 .24518 L .59014 .25079 L p .707 .577 .707 r
F P
0 g
s
.67117 .64287 m .6838 .5902 L .66349 .57736 L p .707 .577 .707 r
F P
0 g
s
.6838 .5902 m .67117 .64287 L .69781 .65434 L p .707 .577 .707 r
F P
0 g
s
.73865 .70627 m .72594 .67027 L .69669 .67941 L p .707 .577 .707 r
F P
0 g
s
.72594 .67027 m .73865 .70627 L .76876 .69554 L p .707 .577 .707 r
F P
0 g
s
.24572 .73974 m .23301 .70375 L .26311 .69302 L p .707 .577 .707 r
F P
0 g
s
.23373 .73116 m .23034 .74899 L .20134 .74828 L p .707 .577 .707 r
F P
0 g
s
.26311 .69302 m .27583 .72901 L .24572 .73974 L p .707 .577 .707 r
F P
0 g
s
.69669 .67941 m .7094 .7154 L .73865 .70627 L p .707 .577 .707 r
F P
0 g
s
.42764 .75248 m .42095 .24992 L .46243 .24472 L p .707 .577 .707 r
F P
0 g
s
.42095 .24992 m .42764 .75248 L .39369 .76073 L p .707 .577 .707 r
F P
0 g
s
.29572 .74316 m .29233 .76098 L .26169 .75337 L p .707 .577 .707 r
F P
0 g
s
.26169 .75337 m .26508 .73554 L .29572 .74316 L p .707 .577 .707 r
F P
0 g
s
.7094 .7154 m .69669 .67941 L .67115 .68605 L p .707 .577 .707 r
F P
0 g
s
.23034 .74899 m .23373 .73116 L .26508 .73554 L p .707 .577 .707 r
F P
0 g
s
.26508 .73554 m .26169 .75337 L .23034 .74899 L p .707 .577 .707 r
F P
0 g
s
.67115 .68605 m .68386 .72204 L .7094 .7154 L p .707 .577 .707 r
F P
0 g
s
.66349 .57736 m .65086 .63003 L .67117 .64287 L p .707 .577 .707 r
F P
0 g
s
.65086 .63003 m .66349 .57736 L .65148 .56441 L p .707 .577 .707 r
F P
0 g
s
.55138 .24518 m .55806 .74774 L .51406 .74565 L p .707 .577 .707 r
F P
0 g
s
.51406 .74565 m .50737 .24309 L .55138 .24518 L p .707 .577 .707 r
F P
0 g
s
.72729 .76494 m .73068 .74711 L .70004 .73949 L p .707 .577 .707 r
F P
0 g
s
.73068 .74711 m .72729 .76494 L .75865 .76931 L p .707 .577 .707 r
F P
0 g
s
.75865 .76931 m .76204 .75149 L .73068 .74711 L p .707 .577 .707 r
F P
0 g
s
.46912 .74728 m .46243 .24472 L .50737 .24309 L p .707 .577 .707 r
F P
0 g
s
.46243 .24472 m .46912 .74728 L .42764 .75248 L p .707 .577 .707 r
F P
0 g
s
.76204 .75149 m .75865 .76931 L .78765 .77003 L p .707 .577 .707 r
F P
0 g
s
.78765 .77003 m .79104 .7522 L .76204 .75149 L p .707 .577 .707 r
F P
0 g
s
.69666 .75732 m .70004 .73949 L .67312 .72939 L p .707 .577 .707 r
F P
0 g
s
.70004 .73949 m .69666 .75732 L .72729 .76494 L p .707 .577 .707 r
F P
0 g
s
.68386 .72204 m .67115 .68605 L .65183 .68954 L p .707 .577 .707 r
F P
0 g
s
.50737 .24309 m .51406 .74565 L .46912 .74728 L p .707 .577 .707 r
F P
0 g
s
.67312 .72939 m .66973 .74721 L .69666 .75732 L p .707 .577 .707 r
F P
0 g
s
.66973 .74721 m .67311 .72941 L p .65254 .71778 L .707 .577 .707 r
F P
0 g
s
.67311 .72941 m .67312 .72939 L .67309 .72937 L p .707 .577 .707 r
F P
0 g
s
.67309 .72937 m .65254 .71778 L p .67311 .72941 L .707 .577 .707 r
F P
0 g
s
.66454 .72554 m .65578 .70074 L p .64061 .68956 L .707 .577 .707 r
F P
0 g
s
.65578 .70074 m .65183 .68954 L .64901 .68955 L p .707 .577 .707 r
F P
0 g
s
.64901 .68955 m .64061 .68956 L p .65578 .70074 L .707 .577 .707 r
F P
0 g
s
.65183 .68954 m .66454 .72554 L .68386 .72204 L p .707 .577 .707 r
F P
0 g
s
.65148 .56441 m .63886 .61707 L .65086 .63003 L p .707 .577 .707 r
F P
0 g
s
.79104 .7522 m .78765 .77003 L .81146 .767 L p .707 .577 .707 r
F P
0 g
s
.81146 .767 m .81485 .74918 L .79104 .7522 L p .707 .577 .707 r
F P
0 g
s
.63886 .61707 m .65148 .56441 L .64897 .55262 L p .707 .577 .707 r
F P
0 g
s
.65254 .71778 m .64915 .7356 L .66973 .74721 L p .707 .577 .707 r
F P
0 g
s
.64915 .7356 m .65207 .72025 L p .64033 .7058 L .707 .577 .707 r
F P
0 g
s
.65207 .72025 m .65254 .71778 L .65031 .71559 L p .707 .577 .707 r
F P
0 g
s
.65031 .71559 m .64033 .7058 L p .65207 .72025 L .707 .577 .707 r
F P
0 g
s
.65332 .72555 m .64244 .69473 L p .63859 .68608 L .707 .577 .707 r
F P
0 g
s
.64244 .69473 m .64061 .68956 L .64024 .68893 L p .707 .577 .707 r
F P
0 g
s
.64024 .68893 m .63859 .68608 L p .64244 .69473 L .707 .577 .707 r
F P
0 g
s
.64061 .68956 m .65332 .72555 L .66454 .72554 L p .707 .577 .707 r
F P
0 g
s
.81485 .74918 m .81146 .767 L .82774 .76054 L p .707 .577 .707 r
F P
0 g
s
.82774 .76054 m .83113 .74271 L .81485 .74918 L p .707 .577 .707 r
F P
0 g
s
.64897 .55262 m .63634 .60528 L .63886 .61707 L p .707 .577 .707 r
F P
0 g
s
.64033 .7058 m .63694 .72363 L .64915 .7356 L p .707 .577 .707 r
F P
0 g
s
.63634 .60528 m .64897 .55262 L .65618 .54313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83113 .74271 m .82774 .76054 L .83491 .75127 L p .707 .577 .707 r
F P
0 g
s
.83491 .75127 m .8383 .73344 L .83113 .74271 L p .707 .577 .707 r
F P
0 g
s
.63694 .72363 m .64033 .7058 L .63768 .69463 L p .707 .577 .707 r
F P
0 g
s
.63768 .69463 m .63429 .71246 L .63694 .72363 L p .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .63768 .69463 L .64017 .69141 L p .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .65332 .72555 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63906 .68739 m .65131 .72208 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63859 .68608 m .63906 .68739 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .63859 .68608 L .64598 .67947 L p .707 .577 .707 r
F P
0 g
s
.64017 .69141 m .64485 .68536 L p .64114 .69489 L .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .64017 .69141 L .64114 .69489 L .707 .577 .707 r
F
.65618 .54313 m .64356 .59579 L .63634 .60528 L p F P
0 g
s
.64356 .59579 m .65618 .54313 L .67242 .53688 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .39777 .57378 L .36742 .5648 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .41602 .63201 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.39777 .57378 m .38862 .61193 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.38862 .61193 m .38514 .62644 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.41622 .632 m .39777 .57378 L .41602 .63201 L .707 .577 .707 r
F
.40308 .64552 m .41625 .63199 L .3842 .63438 L F
.42575 .65889 m .41625 .63199 L p .40308 .64552 L F P
0 g
s
.45375 .64762 m .42562 .63054 L .41625 .63199 L .707 .577 .707 r
F
.44326 .6278 m .43789 .60976 L .41629 .63199 L F
.42886 .57939 m .41625 .63199 L p .43789 .60976 L F P
0 g
s
.41625 .63199 m .42575 .65889 L .44346 .65176 L p .707 .577 .707 r
F P
0 g
s
.44346 .65176 m .45375 .64762 L p .41625 .63199 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .41623 .63205 L p .41629 .63199 L .707 .577 .707 r
F P
0 g
s
.43789 .60976 m .41625 .63199 L .41629 .63199 L .707 .577 .707 r
F
.42886 .57939 m .39777 .57378 L p .41621 .63196 L F P
0 g
s
.41623 .63205 m .41625 .63199 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .42886 .57939 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.43642 .63709 m .44657 .62728 L .42562 .63054 L .707 .577 .707 r
F
.45375 .64762 m .44657 .62728 L p .43642 .63709 L F P
0 g
s
.45375 .64762 m .47693 .6369 L p .46495 .62846 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .46409 .61036 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .44657 .62728 L p .46409 .61036 L F P
0 g
s
.46409 .61036 m .44657 .62728 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .42886 .57939 L p .44249 .62522 L F P
0 g
s
.44503 .63374 m .44657 .62728 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45765 .58108 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.47693 .6369 m .47123 .62077 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.48132 .57868 m .45765 .58108 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .47123 .62077 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .48132 .57868 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.48276 .62449 m .48077 .61637 L .47123 .62077 L .707 .577 .707 r
F
.49299 .62778 m .48473 .62006 L .48276 .62449 L F
.48473 .62006 m .48077 .61637 L .48276 .62449 L F
.48414 .61481 m .48344 .60583 L .47611 .61852 L F
.48132 .57868 m .47123 .62077 L p .48344 .60583 L F P
0 g
s
.48344 .60583 m .47123 .62077 L .47611 .61852 L .707 .577 .707 r
F
.48028 .59179 m .46421 .6009 L p .48077 .61637 L F P
0 g
s
.49299 .62778 m .48781 .61311 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49756 .57243 m .48132 .57868 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48494 .6251 m .48781 .61311 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .49756 .57243 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.4945 .61739 m .49172 .60852 L .48781 .61311 L .707 .577 .707 r
F
.50038 .62116 m .49457 .61267 L .4945 .61739 L F
.49457 .61267 m .49172 .60852 L .4945 .61739 L F
.48781 .61311 m .49299 .62778 L .50018 .62134 L p F P
0 g
s
.50018 .62134 m .50038 .62116 L p .48781 .61311 L .707 .577 .707 r
F P
0 g
s
.49327 .60671 m .49429 .5985 L .4901 .61042 L .707 .577 .707 r
F
.49756 .57243 m .48781 .61311 L p .49429 .5985 L F P
0 g
s
.49429 .5985 m .48781 .61311 L .4901 .61042 L .707 .577 .707 r
F
.48767 .58517 m .48028 .59179 L p .49172 .60852 L F P
0 g
s
.50038 .62116 m .49468 .60504 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.50477 .56295 m .49756 .57243 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49468 .60504 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .50477 .56295 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.50038 .62116 m .49836 .61769 L p .49664 .61247 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .48767 .58517 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.49197 .60956 m .49215 .61561 L p .49327 .60671 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49122 .61123 L .48494 .6251 L .707 .577 .707 r
F
.49327 .60671 m .4901 .61042 L .48494 .6251 L F
.48028 .59179 m .48781 .61311 L p .49172 .60852 L F P
0 g
s
.49215 .61561 m .48963 .60381 L p .49165 .59838 L .707 .577 .707 r
F P
0 g
s
.48767 .58517 m .49468 .60504 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49165 .59838 m .49354 .60253 L .49215 .61561 L .707 .577 .707 r
F
.48565 .5817 m .48767 .58517 L p .49295 .60124 L F P
0 g
s
.49468 .60504 m .49215 .61561 L p .49354 .60253 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48565 .5817 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .50477 .56295 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .49118 .59736 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .50226 .55115 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48494 .6251 L p .4901 .61042 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48028 .59179 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49836 .61769 m .48715 .61771 L p .48662 .60497 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .47763 .59086 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48565 .5817 m .49118 .59736 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48963 .60381 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .48565 .5817 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .47765 .59081 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47443 .58171 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .50226 .55115 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47763 .59086 m .47765 .59081 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .49026 .5382 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .49118 .59736 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48662 .60497 m .4862 .59495 L .49118 .59736 L .707 .577 .707 r
F
.49118 .59736 m .49836 .61769 L p .48662 .60497 L F P
0 g
s
.49836 .61769 m .49118 .59736 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49492 .58954 m .49468 .60504 L .49354 .60253 L .707 .577 .707 r
F
.49165 .59838 m .49492 .58954 L .49354 .60253 L F
.49664 .61247 m .49295 .60124 L .49468 .60504 L F
.49468 .60504 m .50038 .62116 L p .49664 .61247 L F P
0 g
s
.50477 .56295 m .49468 .60504 L p .49492 .58954 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .47693 .6369 L .49002 .62947 L p .707 .577 .707 r
F P
0 g
s
.49002 .62947 m .49299 .62778 L p .47123 .62077 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .4687 .63134 L p .47611 .61852 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .48494 .6251 L p .48414 .61481 L .707 .577 .707 r
F P
0 g
s
.48414 .61481 m .47611 .61852 L .4687 .63134 L .707 .577 .707 r
F
.46421 .6009 m .47123 .62077 L p .48077 .61637 L F P
0 g
s
.46421 .6009 m .44104 .61162 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .46421 .6009 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45375 .64762 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .44503 .63374 L p .45131 .62603 L .707 .577 .707 r
F P
0 g
s
.46495 .62846 m .45872 .62407 L .4553 .64027 L .707 .577 .707 r
F
.46495 .62846 m .4553 .64027 L .45375 .64762 L F
.44104 .61162 m .44657 .62728 L p .45872 .62407 L F P
0 g
s
.44503 .63374 m .4687 .63134 L p .46664 .62199 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .45131 .62603 L .44503 .63374 L .707 .577 .707 r
F
.44104 .61162 m .41304 .6229 L p .42562 .63054 L F P
0 g
s
.44657 .62728 m .44104 .61162 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41304 .6229 m .41625 .63199 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41623 .63205 m .44503 .63374 L p .44326 .6278 L .707 .577 .707 r
F P
0 g
s
.44326 .6278 m .41629 .63199 L .41623 .63205 L .707 .577 .707 r
F
.41304 .6229 m .38293 .63363 L p .3842 .63438 L F P
0 g
s
.41625 .63199 m .41304 .6229 L p .3842 .63438 L .707 .577 .707 r
F P
0 g
s
.41602 .63201 m .41623 .63205 L p .41622 .632 L .707 .577 .707 r
F P
0 g
s
.3548 .61746 m .36742 .5648 L .34079 .55333 L p .707 .577 .707 r
F P
0 g
s
.36742 .5648 m .3548 .61746 L .38514 .62644 L p .707 .577 .707 r
F P
0 g
s
.8383 .73344 m .83491 .75127 L .83226 .7401 L p .707 .577 .707 r
F P
0 g
s
.83226 .7401 m .83565 .72228 L .8383 .73344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64598 .67947 m .65869 .71546 L .65131 .72208 L p .707 .577 .707 r
F P
0 g
s
.67242 .53688 m .6598 .58955 L .64356 .59579 L p .707 .577 .707 r
F P
0 g
s
.64485 .68536 m .64146 .70319 L .63429 .71246 L p .707 .577 .707 r
F P
0 g
s
.32816 .60599 m .34079 .55333 L .32048 .54049 L p .707 .577 .707 r
F P
0 g
s
.34079 .55333 m .32816 .60599 L .3548 .61746 L p .707 .577 .707 r
F P
0 g
s
.6598 .58955 m .67242 .53688 L .69609 .53449 L p .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .81083 .65785 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82069 .62755 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .82064 .62774 L .82016 .62743 L p .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83016 .65435 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81083 .65785 m .79812 .62186 L .81744 .61836 L p .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .82069 .62755 L p .80033 .6149 L .707 .577 .707 r
F P
0 g
s
.82016 .62743 m .80033 .6149 L p .82069 .62755 L .707 .577 .707 r
F P
0 g
s
.80033 .6149 m .81295 .56223 L .83327 .57507 L p .707 .577 .707 r
F P
0 g
s
.39564 .66962 m .38293 .63363 L .35368 .64276 L p .707 .577 .707 r
F P
0 g
s
.38293 .63363 m .39564 .66962 L .42575 .65889 L p .707 .577 .707 r
F P
0 g
s
.35368 .64276 m .36639 .67875 L .39564 .66962 L p .707 .577 .707 r
F P
0 g
s
.36639 .67875 m .35368 .64276 L .32814 .6494 L p .707 .577 .707 r
F P
0 g
s
.65869 .71546 m .64598 .67947 L .66205 .67035 L p .707 .577 .707 r
F P
0 g
s
.83565 .72228 m .83226 .7401 L .82005 .72813 L p .707 .577 .707 r
F P
0 g
s
.82005 .72813 m .82344 .7103 L .83565 .72228 L p .707 .577 .707 r
F P
0 g
s
.32814 .6494 m .34085 .68539 L .36639 .67875 L p .707 .577 .707 r
F P
0 g
s
.64146 .70319 m .64485 .68536 L .66113 .6789 L p .707 .577 .707 r
F P
0 g
s
.32048 .54049 m .30785 .59315 L .32816 .60599 L p .707 .577 .707 r
F P
0 g
s
.30785 .59315 m .32048 .54049 L .30847 .52754 L p .707 .577 .707 r
F P
0 g
s
.69609 .53449 m .68347 .58715 L .6598 .58955 L p .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .65869 .71546 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.66251 .67166 m .67476 .70635 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .66205 .67035 L .68522 .65963 L p .707 .577 .707 r
F P
0 g
s
.65774 .69673 m .66113 .6789 L .67365 .67731 L p .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .67476 .70635 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68522 .65963 m .68705 .66481 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68705 .66481 m .69793 .69563 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .68522 .65963 L .71323 .64836 L p .707 .577 .707 r
F P
0 g
s
.71323 .64836 m .72594 .68435 L .69793 .69563 L p .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .68494 .67588 L .70865 .67646 L p .707 .577 .707 r
F P
0 g
s
.70865 .67646 m .71394 .67659 L p .71139 .67794 L .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .70865 .67646 L .71139 .67794 L .707 .577 .707 r
F
.67365 .67731 m .68494 .67588 L p .67932 .68019 L F P
0 g
s
.65774 .69673 m .67365 .67731 L .67932 .68019 L .707 .577 .707 r
F
.66205 .67035 m .66251 .67166 L p .66197 .67139 L F P
0 g
s
.68347 .58715 m .69609 .53449 L .72488 .53618 L p .707 .577 .707 r
F P
0 g
s
.81295 .56223 m .80033 .6149 L .7737 .60343 L p .707 .577 .707 r
F P
0 g
s
.7737 .60343 m .78632 .55076 L .81295 .56223 L p .707 .577 .707 r
F P
0 g
s
.38428 .72747 m .38767 .70964 L .35703 .70203 L p .707 .577 .707 r
F P
0 g
s
.38767 .70964 m .38428 .72747 L .41564 .73185 L p .707 .577 .707 r
F P
0 g
s
.41564 .73185 m .41903 .71402 L .38767 .70964 L p .707 .577 .707 r
F P
0 g
s
.66113 .6789 m .65774 .69673 L .64146 .70319 L p .707 .577 .707 r
F P
0 g
s
.41903 .71402 m .41564 .73185 L .44464 .73256 L p .707 .577 .707 r
F P
0 g
s
.44464 .73256 m .44803 .71473 L .41903 .71402 L p .707 .577 .707 r
F P
0 g
s
.35365 .71985 m .35703 .70203 L .33011 .69192 L p .707 .577 .707 r
F P
0 g
s
.35703 .70203 m .35365 .71985 L .38428 .72747 L p .707 .577 .707 r
F P
0 g
s
.34085 .68539 m .32814 .6494 L .30882 .6529 L p .707 .577 .707 r
F P
0 g
s
.33011 .69192 m .32672 .70975 L .35365 .71985 L p .707 .577 .707 r
F P
0 g
s
.32672 .70975 m .33 .69248 L p .30953 .68031 L .707 .577 .707 r
F P
0 g
s
.33 .69248 m .33011 .69192 L .32943 .69154 L p .707 .577 .707 r
F P
0 g
s
.32943 .69154 m .30953 .68031 L p .33 .69248 L .707 .577 .707 r
F P
0 g
s
.32153 .68889 m .31267 .66381 L p .2976 .65291 L .707 .577 .707 r
F P
0 g
s
.31267 .66381 m .30882 .6529 L .30608 .6529 L p .707 .577 .707 r
F P
0 g
s
.30608 .6529 m .2976 .65291 L p .31267 .66381 L .707 .577 .707 r
F P
0 g
s
.30882 .6529 m .32153 .68889 L .34085 .68539 L p .707 .577 .707 r
F P
0 g
s
.71226 .58884 m .72488 .53618 L .75598 .54178 L p .707 .577 .707 r
F P
0 g
s
.72488 .53618 m .71226 .58884 L .68347 .58715 L p .707 .577 .707 r
F P
0 g
s
.78632 .55076 m .7737 .60343 L .74335 .59445 L p .707 .577 .707 r
F P
0 g
s
.74335 .59445 m .75598 .54178 L .78632 .55076 L p .707 .577 .707 r
F P
0 g
s
.30847 .52754 m .29585 .5802 L .30785 .59315 L p .707 .577 .707 r
F P
0 g
s
.75598 .54178 m .74335 .59445 L .71226 .58884 L p .707 .577 .707 r
F P
0 g
s
.44803 .71473 m .44464 .73256 L .46845 .72954 L p .707 .577 .707 r
F P
0 g
s
.46845 .72954 m .47184 .71171 L .44803 .71473 L p .707 .577 .707 r
F P
0 g
s
.82344 .7103 m .82005 .72813 L .79947 .71652 L p .707 .577 .707 r
F P
0 g
s
.79947 .71652 m .80286 .69869 L .82344 .7103 L p .707 .577 .707 r
F P
0 g
s
.79812 .62186 m .81083 .65785 L .78529 .66449 L p .707 .577 .707 r
F P
0 g
s
.78529 .66449 m .77258 .6285 L .79812 .62186 L p .707 .577 .707 r
F P
0 g
s
.29585 .5802 m .30847 .52754 L .30596 .51574 L p .707 .577 .707 r
F P
0 g
s
.30953 .68031 m .30614 .69814 L .32672 .70975 L p .707 .577 .707 r
F P
0 g
s
.68494 .67588 m .68155 .6937 L .65774 .69673 L p .707 .577 .707 r
F P
0 g
s
.30614 .69814 m .30896 .68332 L p .29732 .66833 L .707 .577 .707 r
F P
0 g
s
.30896 .68332 m .30953 .68031 L .30682 .67765 L p .707 .577 .707 r
F P
0 g
s
.30682 .67765 m .29732 .66833 L p .30896 .68332 L .707 .577 .707 r
F P
0 g
s
.31031 .6889 m .29932 .6578 L p .29558 .64944 L .707 .577 .707 r
F P
0 g
s
.29932 .6578 m .2976 .65291 L .29725 .65232 L p .707 .577 .707 r
F P
0 g
s
.29725 .65232 m .29558 .64944 L p .29932 .6578 L .707 .577 .707 r
F P
0 g
s
.2976 .65291 m .31031 .6889 L .32153 .68889 L p .707 .577 .707 r
F P
0 g
s
.47184 .71171 m .46845 .72954 L .48473 .72307 L p .707 .577 .707 r
F P
0 g
s
.48473 .72307 m .48812 .70525 L .47184 .71171 L p .707 .577 .707 r
F P
0 g
s
.77258 .6285 m .78529 .66449 L .75604 .67362 L p .707 .577 .707 r
F P
0 g
s
.75604 .67362 m .74333 .63763 L .77258 .6285 L p .707 .577 .707 r
F P
0 g
s
.80286 .69869 m .79947 .71652 L .77255 .70641 L p .707 .577 .707 r
F P
0 g
s
.77255 .70641 m .77594 .68858 L .80286 .69869 L p .707 .577 .707 r
F P
0 g
s
.30596 .51574 m .29333 .5684 L .29585 .5802 L p .707 .577 .707 r
F P
0 g
s
.29732 .66833 m .29393 .68616 L .30614 .69814 L p .707 .577 .707 r
F P
0 g
s
.72594 .68435 m .71323 .64836 L .74333 .63763 L p .707 .577 .707 r
F P
0 g
s
.71394 .67659 m .71055 .69442 L .68155 .6937 L p .707 .577 .707 r
F P
0 g
s
.74333 .63763 m .75604 .67362 L .72594 .68435 L p .707 .577 .707 r
F P
0 g
s
.29333 .5684 m .30596 .51574 L .31317 .50626 L p .707 .577 .707 r
F P
0 g
s
.77594 .68858 m .77255 .70641 L .74191 .6988 L p .707 .577 .707 r
F P
0 g
s
.74191 .6988 m .7453 .68097 L .77594 .68858 L p .707 .577 .707 r
F P
0 g
s
.71055 .69442 m .71394 .67659 L .7453 .68097 L p .707 .577 .707 r
F P
0 g
s
.7453 .68097 m .74191 .6988 L .71055 .69442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.48812 .70525 m .48473 .72307 L .4919 .7138 L p .707 .577 .707 r
F P
0 g
s
.4919 .7138 m .49529 .69598 L .48812 .70525 L p .707 .577 .707 r
F P
0 g
s
.29393 .68616 m .29732 .66833 L .29467 .65717 L p .707 .577 .707 r
F P
0 g
s
.29467 .65717 m .29128 .67499 L .29393 .68616 L p .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29467 .65717 L .29698 .65418 L p .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .31031 .6889 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29594 .65046 m .3083 .68543 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29558 .64944 m .29594 .65046 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .29558 .64944 L .30297 .64282 L p .707 .577 .707 r
F P
0 g
s
.29698 .65418 m .30184 .6479 L p .29798 .6578 L .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29698 .65418 L .29798 .6578 L .707 .577 .707 r
F
.31317 .50626 m .30055 .55892 L .29333 .5684 L p F P
0 g
s
.30055 .55892 m .31317 .50626 L .32941 .50001 L p .707 .577 .707 r
F P
0 g
s
.49529 .69598 m .4919 .7138 L .48925 .70264 L p .707 .577 .707 r
F P
0 g
s
.48925 .70264 m .49264 .68481 L .49529 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30297 .64282 m .31568 .67881 L .3083 .68543 L p .707 .577 .707 r
F P
0 g
s
.32941 .50001 m .31679 .55267 L .30055 .55892 L p .707 .577 .707 r
F P
0 g
s
.30184 .6479 m .29845 .66572 L .29128 .67499 L p .707 .577 .707 r
F P
0 g
s
.31679 .55267 m .32941 .50001 L .35308 .49761 L p .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .46782 .6212 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .47765 .59081 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47763 .59086 L .47749 .59077 L p .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .48715 .61771 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.46782 .6212 m .45511 .58521 L .47443 .58171 L p .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .47765 .59081 L p .45732 .57802 L .707 .577 .707 r
F P
0 g
s
.47749 .59077 m .45732 .57802 L p .47765 .59081 L .707 .577 .707 r
F P
0 g
s
.45732 .57802 m .46994 .52536 L .49026 .5382 L p .707 .577 .707 r
F P
0 g
s
.31568 .67881 m .30297 .64282 L .31904 .63371 L p .707 .577 .707 r
F P
0 g
s
.49264 .68481 m .48925 .70264 L .47704 .69066 L p .707 .577 .707 r
F P
0 g
s
.47704 .69066 m .48043 .67283 L .49264 .68481 L p .707 .577 .707 r
F P
0 g
s
.29845 .66572 m .30184 .6479 L .31812 .64143 L p .707 .577 .707 r
F P
0 g
s
.35308 .49761 m .34046 .55028 L .31679 .55267 L p .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31568 .67881 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.3194 .63473 m .33175 .6697 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31904 .63371 L .34221 .62299 L p .707 .577 .707 r
F P
0 g
s
.31473 .65926 m .31812 .64143 L .32972 .63996 L p .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .33175 .6697 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34221 .62299 m .34393 .62788 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34393 .62788 m .35492 .65898 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .34221 .62299 L .37021 .61171 L p .707 .577 .707 r
F P
0 g
s
.37021 .61171 m .38293 .6477 L .35492 .65898 L p .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .34193 .63841 L .36449 .63896 L p .707 .577 .707 r
F P
0 g
s
.36449 .63896 m .37093 .63912 L p .36783 .64076 L .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .36449 .63896 L .36783 .64076 L .707 .577 .707 r
F
.32972 .63996 m .34193 .63841 L p .33585 .64307 L F P
0 g
s
.31473 .65926 m .32972 .63996 L .33585 .64307 L .707 .577 .707 r
F
.31904 .63371 m .3194 .63473 L p .31898 .63452 L F P
0 g
s
.34046 .55028 m .35308 .49761 L .38187 .4993 L p .707 .577 .707 r
F P
0 g
s
.46994 .52536 m .45732 .57802 L .43069 .56655 L p .707 .577 .707 r
F P
0 g
s
.43069 .56655 m .44331 .51389 L .46994 .52536 L p .707 .577 .707 r
F P
0 g
s
.31812 .64143 m .31473 .65926 L .29845 .66572 L p .707 .577 .707 r
F P
0 g
s
.36925 .55196 m .38187 .4993 L .41296 .50491 L p .707 .577 .707 r
F P
0 g
s
.38187 .4993 m .36925 .55196 L .34046 .55028 L p .707 .577 .707 r
F P
0 g
s
.44331 .51389 m .43069 .56655 L .40034 .55757 L p .707 .577 .707 r
F P
0 g
s
.40034 .55757 m .41296 .50491 L .44331 .51389 L p .707 .577 .707 r
F P
0 g
s
.41296 .50491 m .40034 .55757 L .36925 .55196 L p .707 .577 .707 r
F P
0 g
s
.48043 .67283 m .47704 .69066 L .45646 .67905 L p .707 .577 .707 r
F P
0 g
s
.45646 .67905 m .45985 .66122 L .48043 .67283 L p .707 .577 .707 r
F P
0 g
s
.45511 .58521 m .46782 .6212 L .44228 .62784 L p .707 .577 .707 r
F P
0 g
s
.44228 .62784 m .42957 .59185 L .45511 .58521 L p .707 .577 .707 r
F P
0 g
s
.34193 .63841 m .33854 .65624 L .31473 .65926 L p .707 .577 .707 r
F P
0 g
s
.42957 .59185 m .44228 .62784 L .41303 .63697 L p .707 .577 .707 r
F P
0 g
s
.41303 .63697 m .40032 .60098 L .42957 .59185 L p .707 .577 .707 r
F P
0 g
s
.45985 .66122 m .45646 .67905 L .42954 .66894 L p .707 .577 .707 r
F P
0 g
s
.42954 .66894 m .43293 .65112 L .45985 .66122 L p .707 .577 .707 r
F P
0 g
s
.38293 .6477 m .37021 .61171 L .40032 .60098 L p .707 .577 .707 r
F P
0 g
s
.37093 .63912 m .36754 .65695 L .33854 .65624 L p .707 .577 .707 r
F P
0 g
s
.40032 .60098 m .41303 .63697 L .38293 .6477 L p .707 .577 .707 r
F P
0 g
s
.43293 .65112 m .42954 .66894 L .3989 .66133 L p .707 .577 .707 r
F P
0 g
s
.3989 .66133 m .40229 .6435 L .43293 .65112 L p .707 .577 .707 r
F P
0 g
s
.36754 .65695 m .37093 .63912 L .40229 .6435 L p .707 .577 .707 r
F P
0 g
s
.40229 .6435 m .3989 .66133 L .36754 .65695 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0I7oo001TOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
06Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
065oo`P000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00GGoo10000eYF00@005YFFUIJ
EPT000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001IOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001FOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`04001JEUYF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001Woo4P00CGoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUH000030019Ool005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD004Aoo`00E7oo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003Ool0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@0041oo`00E7oo00<005YFFUH00eYF00@005YFFUIJEPd000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol005Aoo`80009JEPH0009JEP80
00=oo`04001JEUYF0002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF100015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000003Yoo`00E7oo10000UYF00<005YFFUH00eYF00H005YF000007oo0002FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00=goo001COol30003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01EYF0`0000AJEP00000000EJEP03001JEUYF
00AJEP03001JEUYF00AJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Eoo`00Dgoo0`000eYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF1@000eYF0`0000=JEP00FUH01UYF00<005YFFUH015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
=7oo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
000000030005FUH40006FUH00`00FUIJEP04FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000bOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000EJEP04001JEUYFFUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0;goo001COol00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP03
FUH200000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02io
o`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH90002
FUH20006FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8002moo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YF0000;Woo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH70004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000jOol7000EOol20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00UYF10000UYF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH50002FUH20003Ool7
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`0ZOol003Ioo`@000=JEP04001JEUYFFUH9000=Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF000005YF0000
1UYF0`0027oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0:Woo000dOol30005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60008Ool20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool40007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol0039oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000Moo`04001JEUYF0007FUH0
0`00FUIJEP07FUH50007FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP03001JEUYF00=JEP8000Moo`T0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000/Ool0031oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000Eoo`<000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH30004Ool50004Ool40007FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000Aoo`8000IJEP03001JEUYF00=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00T000Qoo`8000EJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00
;goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000Aoo`8000AJEP04001JEUYFFUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000:
Ool300000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`800004FUH005YFFUH30008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000Uoo`8000IJ
EP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004Ool40003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEPd000AJEP04001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<0
009oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00004FUH005YF0002
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPH0009J
EP03001JEUYF009JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF00000`000UYF00T005YFFUIJEP00FUH005YF000015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH00eYF0`00
15YF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH30006FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000=JEP8000QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH0
0`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000goo001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001J
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20006FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000001eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0300000eYF0000000>0008FUH40007FUH00`00
FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0017oo0`0025YF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000eYF00@005YFFUIJEPH000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP05001JEP00001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP040000
15YF000000000eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000Eoo`03001JEUYF00IJEP03001JEUYF00EJEP<0
0003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002eoo`03
001JEUYF009JEPD0009JEP80009oo`T000AJEP03001JEUYF00MJEPD00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00IJEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD000Aoo`8000IJEP03001JEUYF
009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^
Ool002eoo`800005FUH00000FUH00005FUH01000FUH000002Goo1P0025YF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001eYF0P000eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP80
00Aoo`8000=JEP03001JEUYF00<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool002aoo`04001JEP000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
27oo0`0000Aoo`00000000EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEPL000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP8000Aoo`800006FUH00000001JEP002EYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000AJEP00000000=JEP04001JEUYF
FUH>0006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01EYF0P000goo0`0015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01`00;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000goo000000030006Ool30003
FUH60006FUH30004FUH40002FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF
10001eYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEPH0009JEP05001JEP00FUH0000]
Ool002aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000Mo
o`800004FUH000000004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH50006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20006FUH40009FUH00`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH01000FUIJ
EUYF0P0000=JEP000000;Woo000/Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH60004Ool01000FUH000000UYF00<005YFFUH00eYF00@005YF000000EJEP03001J
EUYF00IJEP03001JEP0000D0009JEP03001JEUYF00EJEP@000aJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<00003FUH005YF00EJEP04001JEP000002FUH00`00Oomoo`0^Ool002eo
o`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2@0000=JEP00
FUH015YF0P001eYF00<005YFFUH01EYF0`001UYF10001UYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00003`0000AJEP000000035oo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF009J
EP800003FUH005YF00IJEP03001JEUYF00=JEP<000UJEP03001JEUYF008000=JEP03001JEUYF00=J
EP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP04FUH2000cOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUH0
05YF00000UYF0`000eYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01EYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF4`0015YF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
=Goo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH20005
FUH00`00FUIJEP02FUH50005FUH30007FUH00`00FUIJEP04FUH20006FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0100015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF0P00=goo000`Ool00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH20002FUH00`00FUIJ
EP0700001EYF001JEUYF000015YF1@001UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000MJEP<003Uoo`00<Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH00UYF1`00
0UYF00<005YFFUH00eYF00@005YFFUH000AJEPD000IJEP03001JEUYF00QJEP800003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL003aoo`00
<goo00@005YFFUH000MJEP03001JEUYF00MJEP04001JEUYFFUH30005FUH01000FUIJEP0015YF0`00
0UYF00<005YFFUH00UYF00@005YFFUH000AJEPD000IJEP03001JEUYF00UJEP<000AJEP03001JEUYF
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003eoo`00
=7oo0`001eYF00<005YFFUH01eYF100025YF10001EYF00<005YF00000P000UYF00<005YF00000UYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH0009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUIJEUYF400015YF00<0
05YFFUH01eYF00@005YFFUIJEP<003Yoo`00=Woo0P001UYF00<005YFFUH01UYF0P0000=JEP00FUH0
25YF00@005YFFUH000EJEP04001JEUYFFUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH60004FUH20002FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP05FUH2
000hOol003Qoo`8000AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH00`00FUIJEP05FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000D0009JEP03001JEUYF00IJEP<003Io
o`00>Woo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00<005YFFUH00UYF0`0025YF00<0
05YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH01EYF0`001Woo10001eYF00<005YFFUH00P00=7oo000lOol500000eYF001JEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09
FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00=JEP8000eoo`8000AJEP03001JEUYF
00=JEP80039oo`00?7oo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000
15YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH01eYF1@000UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP<0009JEP<000=JEP03001JEUYF
00EJEP03001JEP000080015oo`<00003FUH005YF00EJEP80035oo`00>Goo0`001eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000`000UYF00<005YF00000P0000=JEP00FUH025YF00<005YF
FUH015YF3P000eYF00<005YFFUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YF0000009JEP04001JEUYF0005FUH00`00FUIJEP04FUH30006Ool3000>Ool20006FUH2
000aOol003Moo`800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP<000IJEP05001J
EP00001JEP040006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YF
000000IJEP03001JEP0000@000Moo`D000moo`8000=JEP04001JEUYF000`Ool003Eoo`8000=JEP80
00MJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH00`00Ool00004
0002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYF0003FUH4
0002FUH20008Ool5000AOol01000FUIJEP000eYF00<007ooOol0;Goo000cOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000000Woo00D005YFFUH005YF00D0
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF1`000UYF00<005YFFUH00UYF00<007ooOol0
1Woo1@004Woo0`000eYF00<007ooOol0;Goo000aOol30005FUH<0008FUH40007FUH00`00FUIoo`04
FUH30004Ool01000FUIJEP001EYF1@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF0`000UYF00D0
05YFFUIJEP0000Uoo`<001Eoo`04001JEUYFFUH2000^Ool002moo`800003FUH0000000D00003FUH0
05YF00IJEP03001JEUYF00@00004FUH000000003FUH00`00FUIJEP03FUH00gooFUH00004FUH20007
Ool01000FUIJEP001EYF00<005YFFUH00UYF3P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YF00000P000eYF00<007oo
Ool087oo00D005YF001JEP0002ioo`00;Woo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF00@005YF000000Uoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20006FUH01000FUIJEUYF0P000UYF00<007ooOol08Goo0P0000=JEP00Ool0
;Goo000]Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
0007FUH2000;Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF10008goo00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH7000=Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH010007Woo0`00;goo000]Ool20003FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00@005YF000000ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUHQ0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH30006FUH0
0`00FUIJEP04FUH7000EOol200000eYF0000000_Ool002aoo`8000=JEPH000IJEP<000AJEP@0009J
EP03001JEUYF00MJEP04001JEUYFFUH2000<Ool01000FUIJEP001EYF00<005YFFUH01UYF2@002eYF
00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF
100015YF00<005YFFUH01UYF00<005YFFUH00UYF5@000eYF0P00;goo000/Ool2000015YF00000000
15YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF1@001UYF00<005YFFUH015YF0P002Woo00@0
05YFFUH000EJEP03001JEUYF00=JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEP0000@000IJEP03001JEUYF009JEP800003FUH00000008000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000`Ool002ao
o`03FUH00000009JEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUH00005
0002FUH00`00FUIJEP05FUH30008Ool01000FUIJEP001EYF00<005YF000010002UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00<005YFFUH00UYF0`00
1EYF00@005YF0000009JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000`Ool002]oo`D00003FUH005YF00AJEP8000MJEP03001JEUYF00EJEP<000Ioo`@0
00IJEP03001JEUYF008000Ioo`04001JEUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH;00000eYF
00000003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00<Goo000[Ool500000eYF001JEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH2000=Ool2
0003FUH00`00FUIJEP03FUH20004Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P0000=JEP00FUH01EYF0P002Goo1`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
03=oo`00:goo00D005YF001JEP00009JEP<000=JEP03001JEUYF00IJEP03001JEP000080015oo`80
0003FUH005YF00EJEP8000=oo`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF001J
EP03FUH2000BOolE000eOol002]oo`80009JEP03001JEUYF008000AJEP03001JEUYF00EJEP<000Eo
o`<000ioo`8000IJEP06001JEP00001oo`000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000000AJEP8005ioo`00;7oo00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH010001goo
1@003goo0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF000005YF00<0061oo`00;7oo00@005YFFUIJEP80009JEP03001JEUYF00D000]oo`D0
015oo`800003FUH005YF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
06=oo`00;Goo00<005YFFUH020003goo1@004goo0P0015YF0`0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH006Aoo`00;Woo0`001EYF00@005YF000000ioo`<001Ioo`03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0065oo`00<7oo00<005YFFUH00eYF
00@005YFFUIJEP<002Eoo`@00003Ool005YF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000AJEP8005moo`00<Goo0P000UYF00<005YFFUH01EYF10008goo0P0000=oo`00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P001UYF0`00GGoo000cOol30008FUH00`00FUIJEP04000NOol3
0002Ool01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YFFUH005aoo`00=Goo0P00
1eYF00<005YFFUH015YF1@005goo100017oo0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP@000IJEP03
001JEUYF009JEP8005Yoo`00=goo0P0015YF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF
0P001Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000Aoo`@0009JEP03001JEUYF00AJEP03001oogoo05Moo`00>Goo
0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0007Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH4000:
Ool30006FUH2001HOol003aoo`<000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008000]oo`@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00D0011oo`8000AJEP03001JEP0005Moo`00?goo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00011oo`D000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD00003Ool0000000<0015oo`04001JEUYF0003FUH0
0`00Oomoo`1DOol0049oo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000FOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Woo1@004Woo
0`000eYF00<007ooOol0E7oo0015Ool60004FUH00`00FUIJEP05FUH01000FUIJEUYF1@007Woo7`00
37oo1@0057oo00@005YFFUIJEP8005Eoo`00Bgoo4000=Goo0P001UYF00@005YF000000ioo`<001Io
o`05001JEP00FUH0001EOol0095oo`03001JEUYF00AJEP04001JEUYFFUH2000VOol200000eYF001o
o`1DOol0099oo`8000=JEP03001JEUYF00AJEP@002=oo`03001JEP0005Eoo`00U7oo0P0000=JEP00
FUH01UYF00<005YFFUH010007Woo0`00EWoo002FOol30006FUH00`00FUIJEP04FUH7000EOol20000
0eYF0000001FOol009Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000Qoo`D000=JEP80
05Ioo`00Vgoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYF
FUH2001GOol009ioo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001GOol00:5oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2001HOol00:Eoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001J
Ool00:aoo`P000AJEP04001JEUYFFUH5001LOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59095 .75535 m .60357 .70269 L .57322 .69371 L p .707 .577 .707 r
F P
0 g
s
.60357 .70269 m .59095 .75535 L .6213 .76083 L p .707 .577 .707 r
F P
0 g
s
.62198 .76078 m .62195 .76067 L .6213 .76083 L .707 .577 .707 r
F
.62195 .76067 m .60357 .70269 L .62106 .76002 L F
.62195 .76067 m .62106 .76002 L .6213 .76083 L F
.60897 .77425 m .62209 .76077 L .59015 .76315 L F
.63155 .78758 m .62209 .76077 L p .60897 .77425 L F P
0 g
s
.65956 .7763 m .63155 .7593 L .62209 .76077 L .707 .577 .707 r
F
.64903 .75658 m .64367 .73859 L .62225 .76074 L F
.63466 .7083 m .62209 .76077 L p .64367 .73859 L F P
0 g
s
.62209 .76077 m .63155 .78758 L .64921 .78047 L p .707 .577 .707 r
F P
0 g
s
.64921 .78047 m .65956 .7763 L p .62209 .76077 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .62204 .76096 L p .62225 .76074 L .707 .577 .707 r
F P
0 g
s
.64367 .73859 m .62209 .76077 L .62225 .76074 L .707 .577 .707 r
F
.63466 .7083 m .60357 .70269 L p .62195 .76067 L F P
0 g
s
.62204 .76096 m .62209 .76077 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.62209 .76077 m .63466 .7083 L p .62195 .76067 L .707 .577 .707 r
F P
0 g
s
.6423 .76582 m .65241 .75606 L .63155 .7593 L .707 .577 .707 r
F
.65956 .7763 m .65241 .75606 L p .6423 .76582 L F P
0 g
s
.65956 .7763 m .68273 .76558 L p .67083 .75719 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .66987 .73919 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .65241 .75606 L p .66987 .73919 L F P
0 g
s
.66987 .73919 m .65241 .75606 L .65721 .75479 L .707 .577 .707 r
F
.66345 .70999 m .63466 .7083 L p .64824 .75395 L F P
0 g
s
.65083 .76265 m .65241 .75606 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .66345 .70999 L p .64824 .75395 L .707 .577 .707 r
F P
0 g
s
.68273 .76558 m .67707 .74955 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.68713 .70759 m .66345 .70999 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .67707 .74955 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68713 .70759 L p .67159 .74702 L .707 .577 .707 r
F P
0 g
s
.68862 .75322 m .68665 .74512 L .67707 .74955 L .707 .577 .707 r
F
.6988 .75646 m .69058 .74879 L .68862 .75322 L F
.69058 .74879 m .68665 .74512 L .68862 .75322 L F
.69575 .75819 m .6988 .75646 L p .67707 .74955 L F P
0 g
s
.68993 .7436 m .68924 .73466 L .68197 .74729 L .707 .577 .707 r
F
.68713 .70759 m .67707 .74955 L p .68924 .73466 L F P
0 g
s
.68924 .73466 m .67707 .74955 L .68197 .74729 L .707 .577 .707 r
F
.68608 .72047 m .67002 .72959 L p .68665 .74512 L F P
0 g
s
.6988 .75646 m .69365 .74189 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70337 .70135 m .68713 .70759 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69074 .75401 m .69365 .74189 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .70337 .70135 L p .68959 .73919 L .707 .577 .707 r
F P
0 g
s
.70033 .74613 m .69758 .73727 L .69365 .74189 L .707 .577 .707 r
F
.70618 .74985 m .70041 .7414 L .70033 .74613 L F
.70041 .7414 m .69758 .73727 L .70033 .74613 L F
.69365 .74189 m .6988 .75646 L .70594 .75007 L p F P
0 g
s
.70594 .75007 m .70618 .74985 L p .69365 .74189 L .707 .577 .707 r
F P
0 g
s
.69909 .7355 m .70011 .72733 L .69594 .73919 L .707 .577 .707 r
F
.70337 .70135 m .69365 .74189 L p .70011 .72733 L F P
0 g
s
.70011 .72733 m .69365 .74189 L .69594 .73919 L .707 .577 .707 r
F
.69347 .71385 m .68608 .72047 L p .69758 .73727 L F P
0 g
s
.70618 .74985 m .70052 .73382 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.71058 .69186 m .70337 .70135 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .70052 .73382 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .71058 .69186 L p .69969 .73067 L .707 .577 .707 r
F P
0 g
s
.70618 .74985 m .70417 .74638 L p .70249 .74128 L .707 .577 .707 r
F P
0 g
s
.70052 .73382 m .69347 .71385 L p .69758 .73727 L .707 .577 .707 r
F P
0 g
s
.69779 .73837 m .69796 .74452 L p .69909 .7355 L .707 .577 .707 r
F P
0 g
s
.69796 .74452 m .69701 .7401 L .69074 .75401 L .707 .577 .707 r
F
.69909 .7355 m .69594 .73919 L .69074 .75401 L F
.68608 .72047 m .69365 .74189 L p .69758 .73727 L F P
0 g
s
.69796 .74452 m .69544 .73273 L p .6975 .72718 L .707 .577 .707 r
F P
0 g
s
.69347 .71385 m .70052 .73382 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.6975 .72718 m .69937 .7313 L .69796 .74452 L .707 .577 .707 r
F
.69146 .71038 m .69347 .71385 L p .69878 .73 L F P
0 g
s
.70052 .73382 m .69796 .74452 L p .69937 .7313 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69146 .71038 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .71058 .69186 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .69702 .72613 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .70806 .68006 L p .69927 .72237 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .69074 .75401 L p .69594 .73919 L .707 .577 .707 r
F P
0 g
s
.69365 .74189 m .68608 .72047 L p .68665 .74512 L .707 .577 .707 r
F P
0 g
s
.70417 .74638 m .69295 .74639 L p .69243 .73379 L .707 .577 .707 r
F P
0 g
s
.69544 .73273 m .68344 .71977 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69146 .71038 m .69702 .72613 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69702 .72613 m .69544 .73273 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .69146 .71038 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .68348 .71958 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68024 .7104 L p .69201 .72371 L .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .70806 .68006 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68344 .71977 m .68348 .71958 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69606 .66711 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.70806 .68006 m .69702 .72613 L p .68354 .71961 L .707 .577 .707 r
F P
0 g
s
.69243 .73379 m .69201 .72371 L .69702 .72613 L .707 .577 .707 r
F
.69702 .72613 m .70417 .74638 L p .69243 .73379 L F P
0 g
s
.70417 .74638 m .69702 .72613 L p .69878 .73 L .707 .577 .707 r
F P
0 g
s
.70076 .71837 m .70052 .73382 L .69937 .7313 L .707 .577 .707 r
F
.6975 .72718 m .70076 .71837 L .69937 .7313 L F
.70249 .74128 m .69878 .73 L .70052 .73382 L F
.70052 .73382 m .70618 .74985 L p .70249 .74128 L F P
0 g
s
.71058 .69186 m .70052 .73382 L p .70076 .71837 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .68273 .76558 L .69575 .75819 L p .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .6745 .76025 L p .68197 .74729 L .707 .577 .707 r
F P
0 g
s
.6745 .76025 m .69074 .75401 L p .68993 .7436 L .707 .577 .707 r
F P
0 g
s
.68993 .7436 m .68197 .74729 L .6745 .76025 L .707 .577 .707 r
F
.67002 .72959 m .67707 .74955 L p .68665 .74512 L F P
0 g
s
.67002 .72959 m .64685 .74031 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.67707 .74955 m .67002 .72959 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65956 .7763 L p .66463 .75283 L .707 .577 .707 r
F P
0 g
s
.65241 .75606 m .65083 .76265 L p .65721 .75479 L .707 .577 .707 r
F P
0 g
s
.67083 .75719 m .66463 .75283 L .66112 .76907 L .707 .577 .707 r
F
.67083 .75719 m .66112 .76907 L .65956 .7763 L F
.64685 .74031 m .65241 .75606 L p .66463 .75283 L F P
0 g
s
.65083 .76265 m .6745 .76025 L p .67242 .75078 L .707 .577 .707 r
F P
0 g
s
.67242 .75078 m .65721 .75479 L .65083 .76265 L .707 .577 .707 r
F
.64685 .74031 m .61884 .75158 L p .63155 .7593 L F P
0 g
s
.65241 .75606 m .64685 .74031 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.61884 .75158 m .62209 .76077 L p .63155 .7593 L .707 .577 .707 r
F P
0 g
s
.62204 .76096 m .65083 .76265 L p .64903 .75658 L .707 .577 .707 r
F P
0 g
s
.64903 .75658 m .62225 .76074 L .62204 .76096 L .707 .577 .707 r
F
.61884 .75158 m .58874 .76231 L p .59015 .76315 L F P
0 g
s
.62209 .76077 m .61884 .75158 L p .59015 .76315 L .707 .577 .707 r
F P
0 g
s
.6213 .76083 m .62204 .76096 L p .62198 .76078 L .707 .577 .707 r
F P
0 g
s
.5606 .74637 m .57322 .69371 L .54659 .68224 L p .707 .577 .707 r
F P
0 g
s
.57322 .69371 m .5606 .74637 L .59095 .75535 L p .707 .577 .707 r
F P
0 g
s
.53397 .7349 m .54659 .68224 L .52628 .6694 L p .707 .577 .707 r
F P
0 g
s
.54659 .68224 m .53397 .7349 L .5606 .74637 L p .707 .577 .707 r
F P
0 g
s
.60145 .79831 m .58874 .76231 L .55948 .77144 L p .707 .577 .707 r
F P
0 g
s
.58874 .76231 m .60145 .79831 L .63155 .78758 L p .707 .577 .707 r
F P
0 g
s
.55948 .77144 m .5722 .80744 L .60145 .79831 L p .707 .577 .707 r
F P
0 g
s
.5722 .80744 m .55948 .77144 L .53395 .77808 L p .707 .577 .707 r
F P
0 g
s
.53395 .77808 m .54666 .81408 L .5722 .80744 L p .707 .577 .707 r
F P
0 g
s
.52628 .6694 m .51366 .72206 L .53397 .7349 L p .707 .577 .707 r
F P
0 g
s
.51366 .72206 m .52628 .6694 L .51428 .65645 L p .707 .577 .707 r
F P
0 g
s
.59009 .85697 m .59348 .83915 L .56284 .83153 L p .707 .577 .707 r
F P
0 g
s
.59348 .83915 m .59009 .85697 L .62145 .86135 L p .707 .577 .707 r
F P
0 g
s
.62145 .86135 m .62483 .84353 L .59348 .83915 L p .707 .577 .707 r
F P
0 g
s
.62483 .84353 m .62145 .86135 L .65045 .86206 L p .707 .577 .707 r
F P
0 g
s
.65045 .86206 m .65384 .84424 L .62483 .84353 L p .707 .577 .707 r
F P
0 g
s
.55945 .84936 m .56284 .83153 L .53591 .82142 L p .707 .577 .707 r
F P
0 g
s
.56284 .83153 m .55945 .84936 L .59009 .85697 L p .707 .577 .707 r
F P
0 g
s
.54666 .81408 m .53395 .77808 L .51462 .78158 L p .707 .577 .707 r
F P
0 g
s
.53591 .82142 m .53253 .83925 L .55945 .84936 L p .707 .577 .707 r
F P
0 g
s
.53253 .83925 m .53591 .82145 L p .51534 .80982 L .707 .577 .707 r
F P
0 g
s
.53591 .82145 m .53591 .82142 L .53588 .82141 L p .707 .577 .707 r
F P
0 g
s
.53588 .82141 m .51534 .80982 L p .53591 .82145 L .707 .577 .707 r
F P
0 g
s
.52733 .81757 m .51858 .79278 L p .5034 .78159 L .707 .577 .707 r
F P
0 g
s
.51858 .79278 m .51462 .78158 L .51181 .78158 L p .707 .577 .707 r
F P
0 g
s
.51181 .78158 m .5034 .78159 L p .51858 .79278 L .707 .577 .707 r
F P
0 g
s
.51462 .78158 m .52733 .81757 L .54666 .81408 L p .707 .577 .707 r
F P
0 g
s
.51428 .65645 m .50166 .70911 L .51366 .72206 L p .707 .577 .707 r
F P
0 g
s
.65384 .84424 m .65045 .86206 L .67425 .85904 L p .707 .577 .707 r
F P
0 g
s
.67425 .85904 m .67764 .84121 L .65384 .84424 L p .707 .577 .707 r
F P
0 g
s
.50166 .70911 m .51428 .65645 L .51176 .64466 L p .707 .577 .707 r
F P
0 g
s
.51534 .80982 m .51195 .82764 L .53253 .83925 L p .707 .577 .707 r
F P
0 g
s
.51195 .82764 m .51487 .81229 L p .50313 .79784 L .707 .577 .707 r
F P
0 g
s
.51487 .81229 m .51534 .80982 L .51311 .80763 L p .707 .577 .707 r
F P
0 g
s
.51311 .80763 m .50313 .79784 L p .51487 .81229 L .707 .577 .707 r
F P
0 g
s
.51612 .81759 m .50523 .78677 L p .50139 .77812 L .707 .577 .707 r
F P
0 g
s
.50523 .78677 m .5034 .78159 L .50304 .78097 L p .707 .577 .707 r
F P
0 g
s
.50304 .78097 m .50139 .77812 L p .50523 .78677 L .707 .577 .707 r
F P
0 g
s
.5034 .78159 m .51612 .81759 L .52733 .81757 L p .707 .577 .707 r
F P
0 g
s
.67764 .84121 m .67425 .85904 L .69054 .85258 L p .707 .577 .707 r
F P
0 g
s
.69054 .85258 m .69393 .83475 L .67764 .84121 L p .707 .577 .707 r
F P
0 g
s
.51176 .64466 m .49914 .69732 L .50166 .70911 L p .707 .577 .707 r
F P
0 g
s
.50313 .79784 m .49974 .81567 L .51195 .82764 L p .707 .577 .707 r
F P
0 g
s
.49914 .69732 m .51176 .64466 L .51898 .63517 L p .707 .577 .707 r
F P
0 g
s
.49492 .8217 m .48824 .31914 L .44423 .31706 L p .707 .577 .707 r
F P
0 g
s
.49974 .81567 m .50313 .79784 L .50048 .78667 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .51612 .81759 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50139 .77812 m .50185 .77943 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50185 .77943 m .5141 .81412 L p .50178 .77916 L .707 .577 .707 r
F P
0 g
s
.50048 .78667 m .49709 .8045 L .49974 .81567 L p .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50048 .78667 L .50297 .78345 L p .707 .577 .707 r
F P
0 g
s
.5141 .81412 m .50139 .77812 L .50878 .77151 L p .707 .577 .707 r
F P
0 g
s
.50297 .78345 m .50764 .7774 L p .50393 .78693 L .707 .577 .707 r
F P
0 g
s
.49709 .8045 m .50297 .78345 L .50393 .78693 L .707 .577 .707 r
F
.51898 .63517 m .50635 .68783 L .49914 .69732 L p F P
0 g
s
.50635 .68783 m .51898 .63517 L .53521 .62892 L p .707 .577 .707 r
F P
0 g
s
.50878 .77151 m .52149 .8075 L .5141 .81412 L p .707 .577 .707 r
F P
0 g
s
.53521 .62892 m .52259 .68159 L .50635 .68783 L p .707 .577 .707 r
F P
0 g
s
.50764 .7774 m .50426 .79523 L .49709 .8045 L p .707 .577 .707 r
F P
0 g
s
.52259 .68159 m .53521 .62892 L .55889 .62653 L p .707 .577 .707 r
F P
0 g
s
.52149 .8075 m .50878 .77151 L .52484 .76239 L p .707 .577 .707 r
F P
0 g
s
.50426 .79523 m .50764 .7774 L .52393 .77094 L p .707 .577 .707 r
F P
0 g
s
.55889 .62653 m .54627 .67919 L .52259 .68159 L p .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52149 .8075 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.52484 .76239 m .5253 .7637 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.5253 .7637 m .53755 .79838 L p .52477 .76343 L .707 .577 .707 r
F P
0 g
s
.53755 .79838 m .52484 .76239 L .54801 .75167 L p .707 .577 .707 r
F P
0 g
s
.52054 .78877 m .52393 .77094 L .53645 .76935 L p .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .53755 .79838 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54801 .75167 m .54984 .75685 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.54984 .75685 m .56072 .78766 L p .54718 .75541 L .707 .577 .707 r
F P
0 g
s
.56072 .78766 m .54801 .75167 L .57602 .74039 L p .707 .577 .707 r
F P
0 g
s
.57602 .74039 m .58873 .77639 L .56072 .78766 L p .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .54774 .76792 L .57144 .7685 L p .707 .577 .707 r
F P
0 g
s
.57144 .7685 m .57674 .76863 L p .57419 .76998 L .707 .577 .707 r
F P
0 g
s
.54435 .78574 m .57144 .7685 L .57419 .76998 L .707 .577 .707 r
F
.53645 .76935 m .54774 .76792 L p .54212 .77222 L F P
0 g
s
.52054 .78877 m .53645 .76935 L .54212 .77222 L .707 .577 .707 r
F
.52393 .77094 m .52054 .78877 L .50426 .79523 L p F P
0 g
s
.54774 .76792 m .54435 .78574 L .52054 .78877 L p .707 .577 .707 r
F P
0 g
s
.48824 .31914 m .49492 .8217 L .53987 .82007 L p .707 .577 .707 r
F P
0 g
s
.53987 .82007 m .53318 .31751 L .48824 .31914 L p .707 .577 .707 r
F P
0 g
s
.54627 .67919 m .55889 .62653 L .58768 .62822 L p .707 .577 .707 r
F P
0 g
s
.58768 .62822 m .57506 .68088 L .54627 .67919 L p .707 .577 .707 r
F P
0 g
s
.57674 .76863 m .57335 .78646 L .54435 .78574 L p .707 .577 .707 r
F P
0 g
s
.58873 .77639 m .57602 .74039 L .60612 .72967 L p .707 .577 .707 r
F P
0 g
s
.60612 .72967 m .61884 .76566 L .58873 .77639 L p .707 .577 .707 r
F P
0 g
s
.57335 .78646 m .57674 .76863 L .60809 .77301 L p .707 .577 .707 r
F P
0 g
s
.60809 .77301 m .6047 .79083 L .57335 .78646 L p .707 .577 .707 r
F P
0 g
s
.53318 .31751 m .53987 .82007 L .58134 .81487 L p .707 .577 .707 r
F P
0 g
s
.57506 .68088 m .58768 .62822 L .61877 .63382 L p .707 .577 .707 r
F P
0 g
s
.61877 .63382 m .60615 .68649 L .57506 .68088 L p .707 .577 .707 r
F P
0 g
s
.58134 .81487 m .57466 .31232 L .53318 .31751 L p .707 .577 .707 r
F P
0 g
s
.69393 .83475 m .69054 .85258 L .69771 .84331 L p .707 .577 .707 r
F P
0 g
s
.69771 .84331 m .7011 .82548 L .69393 .83475 L p .707 .577 .707 r
F P
0 g
s
.45092 .81961 m .44423 .31706 L .40547 .31145 L p .707 .577 .707 r
F P
0 g
s
.44423 .31706 m .45092 .81961 L .49492 .8217 L p .707 .577 .707 r
F P
0 g
s
.61884 .76566 m .60612 .72967 L .63538 .72053 L p .707 .577 .707 r
F P
0 g
s
.63873 .78062 m .63534 .79845 L .6047 .79083 L p .707 .577 .707 r
F P
0 g
s
.6047 .79083 m .60809 .77301 L .63873 .78062 L p .707 .577 .707 r
F P
0 g
s
.57466 .31232 m .58134 .81487 L .6153 .80662 L p .707 .577 .707 r
F P
0 g
s
.64912 .6428 m .63649 .69546 L .60615 .68649 L p .707 .577 .707 r
F P
0 g
s
.60615 .68649 m .61877 .63382 L .64912 .6428 L p .707 .577 .707 r
F P
0 g
s
.6153 .80662 m .60861 .30407 L .57466 .31232 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .26056 .66582 L .23022 .65684 L p .707 .577 .707 r
F P
0 g
s
.24794 .71848 m .27882 .72405 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.26056 .66582 m .25142 .70397 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.25142 .70397 m .24794 .71848 L p .27874 .72381 L .707 .577 .707 r
F P
0 g
s
.27901 .72403 m .26056 .66582 L .27882 .72405 L .707 .577 .707 r
F
.26588 .73756 m .27904 .72403 L .247 .72642 L F
.28854 .75093 m .27904 .72403 L p .26588 .73756 L F P
0 g
s
.31655 .73965 m .28842 .72258 L .27904 .72403 L .707 .577 .707 r
F
.30605 .71983 m .30069 .7018 L .27909 .72403 L F
.29165 .67143 m .27904 .72403 L p .30069 .7018 L F P
0 g
s
.27904 .72403 m .28854 .75093 L .30626 .7438 L p .707 .577 .707 r
F P
0 g
s
.30626 .7438 m .31655 .73965 L p .27904 .72403 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .27903 .72409 L p .27909 .72403 L .707 .577 .707 r
F P
0 g
s
.30069 .7018 m .27904 .72403 L .27909 .72403 L .707 .577 .707 r
F
.29165 .67143 m .26056 .66582 L p .279 .724 L F P
0 g
s
.27903 .72409 m .27904 .72403 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.27904 .72403 m .29165 .67143 L p .279 .724 L .707 .577 .707 r
F P
0 g
s
.29921 .72913 m .30937 .71932 L .28842 .72258 L .707 .577 .707 r
F
.31655 .73965 m .30937 .71932 L p .29921 .72913 L F P
0 g
s
.31655 .73965 m .33972 .72893 L p .32775 .7205 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .32688 .7024 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .30937 .71932 L p .32688 .7024 L F P
0 g
s
.32688 .7024 m .30937 .71932 L .31411 .71807 L .707 .577 .707 r
F
.32044 .67311 m .29165 .67143 L p .30529 .71726 L F P
0 g
s
.30782 .72578 m .30937 .71932 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .32044 .67311 L p .30529 .71726 L .707 .577 .707 r
F P
0 g
s
.33972 .72893 m .33403 .71281 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.34412 .67072 m .32044 .67311 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .33403 .71281 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .34412 .67072 L p .32862 .71031 L .707 .577 .707 r
F P
0 g
s
.34556 .71652 m .34357 .7084 L .33403 .71281 L .707 .577 .707 r
F
.35579 .71982 m .34752 .7121 L .34556 .71652 L F
.34752 .7121 m .34357 .7084 L .34556 .71652 L F
.34693 .70685 m .34623 .69787 L .3389 .71056 L F
.34412 .67072 m .33403 .71281 L p .34623 .69787 L F P
0 g
s
.34623 .69787 m .33403 .71281 L .3389 .71056 L .707 .577 .707 r
F
.34308 .68383 m .32701 .69294 L p .34357 .7084 L F P
0 g
s
.35579 .71982 m .35061 .70515 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36036 .66447 m .34412 .67072 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.34773 .71713 m .35061 .70515 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .36036 .66447 L p .34659 .70248 L .707 .577 .707 r
F P
0 g
s
.35729 .70943 m .35452 .70055 L .35061 .70515 L .707 .577 .707 r
F
.36317 .7132 m .35736 .70471 L .35729 .70943 L F
.35736 .70471 m .35452 .70055 L .35729 .70943 L F
.35061 .70515 m .35579 .71982 L .36297 .71338 L p F P
0 g
s
.36297 .71338 m .36317 .7132 L p .35061 .70515 L .707 .577 .707 r
F P
0 g
s
.35606 .69874 m .35709 .69054 L .3529 .70246 L .707 .577 .707 r
F
.36036 .66447 m .35061 .70515 L p .35709 .69054 L F P
0 g
s
.35709 .69054 m .35061 .70515 L .3529 .70246 L .707 .577 .707 r
F
.35046 .67721 m .34308 .68383 L p .35452 .70055 L F P
0 g
s
.36317 .7132 m .35748 .69708 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.36757 .65499 m .36036 .66447 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35748 .69708 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36757 .65499 L p .35666 .69398 L .707 .577 .707 r
F P
0 g
s
.36317 .7132 m .36116 .70973 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .35046 .67721 L p .35452 .70055 L .707 .577 .707 r
F P
0 g
s
.35477 .7016 m .35495 .70765 L p .35606 .69874 L .707 .577 .707 r
F P
0 g
s
.35495 .70765 m .35401 .70327 L .34773 .71713 L .707 .577 .707 r
F
.35606 .69874 m .3529 .70246 L .34773 .71713 L F
.34308 .68383 m .35061 .70515 L p .35452 .70055 L F P
0 g
s
.35495 .70765 m .35243 .69585 L p .35444 .69042 L .707 .577 .707 r
F P
0 g
s
.35046 .67721 m .35748 .69708 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35444 .69042 m .35634 .69457 L .35495 .70765 L .707 .577 .707 r
F
.34845 .67374 m .35046 .67721 L p .35575 .69328 L F P
0 g
s
.35748 .69708 m .35495 .70765 L p .35634 .69457 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .34845 .67374 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36757 .65499 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .35398 .6894 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36505 .64319 L p .35619 .68571 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34773 .71713 L p .3529 .70246 L .707 .577 .707 r
F P
0 g
s
.35061 .70515 m .34308 .68383 L p .34357 .7084 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .34994 .70974 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.35243 .69585 m .34043 .6829 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.34845 .67374 m .35398 .6894 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.38244 .80543 m .37575 .30287 L .35798 .29217 L p .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .35243 .69585 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34845 .67374 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .34044 .68285 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .33723 .67375 L p .349 .68699 L .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .36505 .64319 L p .34508 .67541 L .707 .577 .707 r
F P
0 g
s
.36505 .64319 m .36138 .65852 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.36138 .65852 m .35398 .6894 L p .36143 .65057 L .707 .577 .707 r
F P
0 g
s
.34459 .68485 m .36143 .65057 L .35398 .6894 L .707 .577 .707 r
F
.36466 .79473 m .36445 .7784 L p .36432 .77855 L F P
0 g
s
.34508 .67541 m .36505 .64319 L .34459 .68485 L .707 .577 .707 r
F
.36757 .65499 m .35748 .69708 L p .35772 .68158 L F P
0 g
s
.36445 .7784 m .35798 .29217 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35748 .69708 m .36317 .7132 L p .35944 .70451 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .35389 .28038 L p .36432 .77855 L .707 .577 .707 r
F P
0 g
s
.35398 .6894 m .36116 .70973 L p .34941 .697 L .707 .577 .707 r
F P
0 g
s
.36116 .70973 m .35398 .6894 L p .35575 .69328 L .707 .577 .707 r
F P
0 g
s
.35798 .29217 m .36466 .79473 L .38244 .80543 L p .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36058 .78294 L .36466 .79473 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36058 .78294 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36389 .26867 m .36429 .29882 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36429 .29882 m .37058 .77122 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34584 .66035 L .34508 .67541 L .707 .577 .707 r
F
.34584 .66035 m .35305 .63024 L .34508 .67541 L F
.34043 .6829 m .34044 .68285 L p .34046 .68285 L F P
0 g
s
.34044 .68285 m .35305 .63024 L p .34046 .68285 L .707 .577 .707 r
F P
0 g
s
.35389 .28038 m .36389 .26867 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.36058 .78294 m .35624 .4567 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.35624 .4567 m .35389 .28038 L p .36361 .31217 L .707 .577 .707 r
F P
0 g
s
.34046 .68285 m .34508 .67541 L .34459 .68485 L .707 .577 .707 r
F
.34941 .697 m .349 .68699 L .35398 .6894 L F
.35772 .68158 m .35748 .69708 L .35634 .69457 L F
.35444 .69042 m .35772 .68158 L .35634 .69457 L F
.35944 .70451 m .35575 .69328 L .35748 .69708 L F
.33403 .71281 m .33972 .72893 L .35282 .7215 L p F P
0 g
s
.35282 .7215 m .35579 .71982 L p .33403 .71281 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .3315 .72338 L p .3389 .71056 L .707 .577 .707 r
F P
0 g
s
.3315 .72338 m .34773 .71713 L p .34693 .70685 L .707 .577 .707 r
F P
0 g
s
.34693 .70685 m .3389 .71056 L .3315 .72338 L .707 .577 .707 r
F
.32701 .69294 m .33403 .71281 L p .34357 .7084 L F P
0 g
s
.32701 .69294 m .30384 .70366 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.33403 .71281 m .32701 .69294 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .31655 .73965 L p .32152 .71611 L .707 .577 .707 r
F P
0 g
s
.30937 .71932 m .30782 .72578 L p .31411 .71807 L .707 .577 .707 r
F P
0 g
s
.32775 .7205 m .32152 .71611 L .3181 .73231 L .707 .577 .707 r
F
.32775 .7205 m .3181 .73231 L .31655 .73965 L F
.30384 .70366 m .30937 .71932 L p .32152 .71611 L F P
0 g
s
.30782 .72578 m .3315 .72338 L p .32944 .71402 L .707 .577 .707 r
F P
0 g
s
.32944 .71402 m .31411 .71807 L .30782 .72578 L .707 .577 .707 r
F
.30384 .70366 m .27583 .71494 L p .28842 .72258 L F P
0 g
s
.30937 .71932 m .30384 .70366 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27583 .71494 m .27904 .72403 L p .28842 .72258 L .707 .577 .707 r
F P
0 g
s
.27903 .72409 m .30782 .72578 L p .30605 .71983 L .707 .577 .707 r
F P
0 g
s
.30605 .71983 m .27909 .72403 L .27903 .72409 L .707 .577 .707 r
F
.27583 .71494 m .24573 .72567 L p .247 .72642 L F P
0 g
s
.27904 .72403 m .27583 .71494 L p .247 .72642 L .707 .577 .707 r
F P
0 g
s
.27882 .72405 m .27903 .72409 L p .27901 .72403 L .707 .577 .707 r
F P
0 g
s
.41216 .81401 m .40547 .31145 L .37575 .30287 L p .707 .577 .707 r
F P
0 g
s
.40547 .31145 m .41216 .81401 L .45092 .81961 L p .707 .577 .707 r
F P
0 g
s
.21759 .7095 m .23022 .65684 L .20358 .64537 L p .707 .577 .707 r
F P
0 g
s
.23022 .65684 m .21759 .7095 L .24794 .71848 L p .707 .577 .707 r
F P
0 g
s
.7011 .82548 m .69771 .84331 L .69506 .83214 L p .707 .577 .707 r
F P
0 g
s
.69506 .83214 m .69844 .81431 L .7011 .82548 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19096 .69803 m .20358 .64537 L .18327 .63253 L p .707 .577 .707 r
F P
0 g
s
.20358 .64537 m .19096 .69803 L .21759 .7095 L p .707 .577 .707 r
F P
0 g
s
.63538 .72053 m .64809 .75653 L .61884 .76566 L p .707 .577 .707 r
F P
0 g
s
.63534 .79845 m .63873 .78062 L .66566 .79073 L p .707 .577 .707 r
F P
0 g
s
.60861 .30407 m .6153 .80662 L .63841 .79613 L p .707 .577 .707 r
F P
0 g
s
.67575 .65427 m .66313 .70694 L .63649 .69546 L p .707 .577 .707 r
F P
0 g
s
.63649 .69546 m .64912 .6428 L .67575 .65427 L p .707 .577 .707 r
F P
0 g
s
.64809 .75653 m .63538 .72053 L .66092 .71389 L p .707 .577 .707 r
F P
0 g
s
.63841 .79613 m .63172 .29357 L .60861 .30407 L p .707 .577 .707 r
F P
0 g
s
.69295 .74639 m .67363 .74989 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68024 .7104 m .68348 .71958 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .68344 .71977 L .68296 .71947 L p .707 .577 .707 r
F P
0 g
s
.68348 .71958 m .69295 .74639 L p .67887 .71859 L .707 .577 .707 r
F P
0 g
s
.67363 .74989 m .66092 .71389 L .68024 .7104 L p .707 .577 .707 r
F P
0 g
s
.69606 .66711 m .68348 .71958 L p .66313 .70694 L .707 .577 .707 r
F P
0 g
s
.68296 .71947 m .66313 .70694 L p .68348 .71958 L .707 .577 .707 r
F P
0 g
s
.66313 .70694 m .67575 .65427 L .69606 .66711 L p .707 .577 .707 r
F P
0 g
s
.25844 .76166 m .24573 .72567 L .21648 .7348 L p .707 .577 .707 r
F P
0 g
s
.24573 .72567 m .25844 .76166 L .28854 .75093 L p .707 .577 .707 r
F P
0 g
s
.21648 .7348 m .22919 .77079 L .25844 .76166 L p .707 .577 .707 r
F P
0 g
s
.22919 .77079 m .21648 .7348 L .19094 .74144 L p .707 .577 .707 r
F P
0 g
s
.69844 .81431 m .69506 .83214 L .68284 .82017 L p .707 .577 .707 r
F P
0 g
s
.68284 .82017 m .68623 .80234 L .69844 .81431 L p .707 .577 .707 r
F P
0 g
s
.37575 .30287 m .38244 .80543 L .41216 .81401 L p .707 .577 .707 r
F P
0 g
s
.19094 .74144 m .20365 .77743 L .22919 .77079 L p .707 .577 .707 r
F P
0 g
s
.18327 .63253 m .17065 .68519 L .19096 .69803 L p .707 .577 .707 r
F P
0 g
s
.17065 .68519 m .18327 .63253 L .17127 .61958 L p .707 .577 .707 r
F P
0 g
s
.24708 .81951 m .25047 .80168 L .21983 .79407 L p .707 .577 .707 r
F P
0 g
s
.25047 .80168 m .24708 .81951 L .27844 .82389 L p .707 .577 .707 r
F P
0 g
s
.27844 .82389 m .28183 .80606 L .25047 .80168 L p .707 .577 .707 r
F P
0 g
s
.28183 .80606 m .27844 .82389 L .30744 .8246 L p .707 .577 .707 r
F P
0 g
s
.30744 .8246 m .31083 .80677 L .28183 .80606 L p .707 .577 .707 r
F P
0 g
s
.21644 .81189 m .21983 .79407 L .19291 .78396 L p .707 .577 .707 r
F P
0 g
s
.21983 .79407 m .21644 .81189 L .24708 .81951 L p .707 .577 .707 r
F P
0 g
s
.20365 .77743 m .19094 .74144 L .17161 .74494 L p .707 .577 .707 r
F P
0 g
s
.19291 .78396 m .18952 .80179 L .21644 .81189 L p .707 .577 .707 r
F P
0 g
s
.18952 .80179 m .1928 .78452 L p .17233 .77235 L .707 .577 .707 r
F P
0 g
s
.1928 .78452 m .19291 .78396 L .19223 .78358 L p .707 .577 .707 r
F P
0 g
s
.19223 .78358 m .17233 .77235 L p .1928 .78452 L .707 .577 .707 r
F P
0 g
s
.18432 .78093 m .17547 .75585 L p .1604 .74495 L .707 .577 .707 r
F P
0 g
s
.17547 .75585 m .17161 .74494 L .16887 .74494 L p .707 .577 .707 r
F P
0 g
s
.16887 .74494 m .1604 .74495 L p .17547 .75585 L .707 .577 .707 r
F P
0 g
s
.17161 .74494 m .18432 .78093 L .20365 .77743 L p .707 .577 .707 r
F P
0 g
s
.63172 .29357 m .63841 .79613 L .64841 .78441 L p .707 .577 .707 r
F P
0 g
s
.64841 .78441 m .64172 .28186 L .63172 .29357 L p .707 .577 .707 r
F P
0 g
s
.17127 .61958 m .15865 .67224 L .17065 .68519 L p .707 .577 .707 r
F P
0 g
s
.31083 .80677 m .30744 .8246 L .33125 .82158 L p .707 .577 .707 r
F P
0 g
s
.33125 .82158 m .33463 .80375 L .31083 .80677 L p .707 .577 .707 r
F P
0 g
s
.68623 .80234 m .68284 .82017 L .66227 .80856 L p .707 .577 .707 r
F P
0 g
s
.66227 .80856 m .66566 .79073 L .68623 .80234 L p .707 .577 .707 r
F P
0 g
s
.66092 .71389 m .67363 .74989 L .64809 .75653 L p .707 .577 .707 r
F P
0 g
s
.15865 .67224 m .17127 .61958 L .16875 .60778 L p .707 .577 .707 r
F P
0 g
s
.17233 .77235 m .16894 .79018 L .18952 .80179 L p .707 .577 .707 r
F P
0 g
s
.16894 .79018 m .17176 .77535 L p .16012 .76037 L .707 .577 .707 r
F P
0 g
s
.17176 .77535 m .17233 .77235 L .16962 .76969 L p .707 .577 .707 r
F P
0 g
s
.16962 .76969 m .16012 .76037 L p .17176 .77535 L .707 .577 .707 r
F P
0 g
s
.17311 .78094 m .16212 .74984 L p .15838 .74148 L .707 .577 .707 r
F P
0 g
s
.16212 .74984 m .1604 .74495 L .16005 .74436 L p .707 .577 .707 r
F P
0 g
s
.16005 .74436 m .15838 .74148 L p .16212 .74984 L .707 .577 .707 r
F P
0 g
s
.1604 .74495 m .17311 .78094 L .18432 .78093 L p .707 .577 .707 r
F P
0 g
s
.33463 .80375 m .33125 .82158 L .34753 .81511 L p .707 .577 .707 r
F P
0 g
s
.34753 .81511 m .35092 .79729 L .33463 .80375 L p .707 .577 .707 r
F P
0 g
s
.66566 .79073 m .66227 .80856 L .63534 .79845 L p .707 .577 .707 r
F P
0 g
s
.16875 .60778 m .15613 .66044 L .15865 .67224 L p .707 .577 .707 r
F P
0 g
s
.16012 .76037 m .15673 .7782 L .16894 .79018 L p .707 .577 .707 r
F P
0 g
s
.15613 .66044 m .16875 .60778 L .17597 .5983 L p .707 .577 .707 r
F P
0 g
s
.64172 .28186 m .64841 .78441 L .64432 .77263 L p .707 .577 .707 r
F P
0 g
s
.64432 .77263 m .63763 .27007 L .64172 .28186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35092 .79729 m .34753 .81511 L .3547 .80584 L p .707 .577 .707 r
F P
0 g
s
.3547 .80584 m .35809 .78802 L .35092 .79729 L p .707 .577 .707 r
F P
0 g
s
.15673 .7782 m .16012 .76037 L .15747 .7492 L p .707 .577 .707 r
F P
0 g
s
.15747 .7492 m .15408 .76703 L .15673 .7782 L p .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15747 .7492 L .15977 .74622 L p .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .17311 .78094 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15874 .7425 m .17109 .77747 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.15838 .74148 m .15874 .7425 L p .15868 .74229 L .707 .577 .707 r
F P
0 g
s
.17109 .77747 m .15838 .74148 L .16577 .73486 L p .707 .577 .707 r
F P
0 g
s
.15977 .74622 m .16463 .73993 L p .16078 .74983 L .707 .577 .707 r
F P
0 g
s
.15408 .76703 m .15977 .74622 L .16078 .74983 L .707 .577 .707 r
F
.17597 .5983 m .16334 .65096 L .15613 .66044 L p F P
0 g
s
.16334 .65096 m .17597 .5983 L .19221 .59205 L p .707 .577 .707 r
F P
0 g
s
.35809 .78802 m .3547 .80584 L .35205 .79467 L p .707 .577 .707 r
F P
0 g
s
.35205 .79467 m .35543 .77685 L .35809 .78802 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16577 .73486 m .17848 .77085 L .17109 .77747 L p .707 .577 .707 r
F P
0 g
s
.63763 .27007 m .64432 .77263 L .62655 .76192 L p .707 .577 .707 r
F P
0 g
s
.62655 .76192 m .61986 .25936 L .63763 .27007 L p .707 .577 .707 r
F P
0 g
s
.19221 .59205 m .17958 .64471 L .16334 .65096 L p .707 .577 .707 r
F P
0 g
s
.16463 .73993 m .16125 .75776 L .15408 .76703 L p .707 .577 .707 r
F P
0 g
s
.17958 .64471 m .19221 .59205 L .21588 .58965 L p .707 .577 .707 r
F P
0 g
s
.34994 .70974 m .33062 .71324 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33723 .67375 m .34044 .68285 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34043 .6829 L .34029 .68281 L p .707 .577 .707 r
F P
0 g
s
.34044 .68285 m .34994 .70974 L p .33587 .68186 L .707 .577 .707 r
F P
0 g
s
.33062 .71324 m .31791 .67725 L .33723 .67375 L p .707 .577 .707 r
F P
0 g
s
.35305 .63024 m .34044 .68285 L p .32012 .67006 L .707 .577 .707 r
F P
0 g
s
.34029 .68281 m .32012 .67006 L p .34044 .68285 L .707 .577 .707 r
F P
0 g
s
.32012 .67006 m .33274 .6174 L .35305 .63024 L p .707 .577 .707 r
F P
0 g
s
.37058 .77122 m .36389 .26867 L .387 .25817 L p .707 .577 .707 r
F P
0 g
s
.17848 .77085 m .16577 .73486 L .18183 .72575 L p .707 .577 .707 r
F P
0 g
s
.35543 .77685 m .35205 .79467 L .33983 .7827 L p .707 .577 .707 r
F P
0 g
s
.33983 .7827 m .34322 .76487 L .35543 .77685 L p .707 .577 .707 r
F P
0 g
s
.16125 .75776 m .16463 .73993 L .18092 .73347 L p .707 .577 .707 r
F P
0 g
s
.21588 .58965 m .20326 .64232 L .17958 .64471 L p .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .17848 .77085 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.18219 .72677 m .19454 .76174 L p .18177 .72655 L .707 .577 .707 r
F P
0 g
s
.19454 .76174 m .18183 .72575 L .205 .71502 L p .707 .577 .707 r
F P
0 g
s
.17753 .7513 m .18092 .73347 L .19251 .732 L p .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .19454 .76174 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.205 .71502 m .20673 .71991 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.20673 .71991 m .21771 .75102 L p .20421 .71856 L .707 .577 .707 r
F P
0 g
s
.21771 .75102 m .205 .71502 L .23301 .70375 L p .707 .577 .707 r
F P
0 g
s
.23301 .70375 m .24572 .73974 L .21771 .75102 L p .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .20473 .73045 L .22729 .731 L p .707 .577 .707 r
F P
0 g
s
.22729 .731 m .23373 .73116 L p .23062 .7328 L .707 .577 .707 r
F P
0 g
s
.20134 .74828 m .22729 .731 L .23062 .7328 L .707 .577 .707 r
F
.19251 .732 m .20473 .73045 L p .19865 .73511 L F P
0 g
s
.17753 .7513 m .19251 .732 L .19865 .73511 L .707 .577 .707 r
F
.18183 .72575 m .18219 .72677 L p .18177 .72655 L F P
0 g
s
.20326 .64232 m .21588 .58965 L .24467 .59134 L p .707 .577 .707 r
F P
0 g
s
.33274 .6174 m .32012 .67006 L .29348 .65859 L p .707 .577 .707 r
F P
0 g
s
.29348 .65859 m .30611 .60593 L .33274 .6174 L p .707 .577 .707 r
F P
0 g
s
.18092 .73347 m .17753 .7513 L .16125 .75776 L p .707 .577 .707 r
F P
0 g
s
.61986 .25936 m .62655 .76192 L .59682 .75335 L p .707 .577 .707 r
F P
0 g
s
.59682 .75335 m .59014 .25079 L .61986 .25936 L p .707 .577 .707 r
F P
0 g
s
.23205 .644 m .24467 .59134 L .27576 .59695 L p .707 .577 .707 r
F P
0 g
s
.24467 .59134 m .23205 .644 L .20326 .64232 L p .707 .577 .707 r
F P
0 g
s
.30611 .60593 m .29348 .65859 L .26314 .64961 L p .707 .577 .707 r
F P
0 g
s
.26314 .64961 m .27576 .59695 L .30611 .60593 L p .707 .577 .707 r
F P
0 g
s
.27576 .59695 m .26314 .64961 L .23205 .644 L p .707 .577 .707 r
F P
0 g
s
.34322 .76487 m .33983 .7827 L .31926 .77109 L p .707 .577 .707 r
F P
0 g
s
.31926 .77109 m .32265 .75326 L .34322 .76487 L p .707 .577 .707 r
F P
0 g
s
.31791 .67725 m .33062 .71324 L .30508 .71988 L p .707 .577 .707 r
F P
0 g
s
.30508 .71988 m .29237 .68389 L .31791 .67725 L p .707 .577 .707 r
F P
0 g
s
.72815 .66332 m .74078 .61065 L .71043 .60167 L p .707 .577 .707 r
F P
0 g
s
.74078 .61065 m .72815 .66332 L .75851 .66879 L p .707 .577 .707 r
F P
0 g
s
.75919 .66874 m .75915 .66863 L .75851 .66879 L .707 .577 .707 r
F
.75915 .66863 m .74078 .61065 L .75826 .66799 L F
.75915 .66863 m .75826 .66799 L .75851 .66879 L F
.74617 .68221 m .75929 .66873 L .72736 .67111 L F
.76876 .69554 m .75929 .66873 L p .74617 .68221 L F P
0 g
s
.79676 .68426 m .76876 .66726 L .75929 .66873 L .707 .577 .707 r
F
.78623 .66454 m .78088 .64655 L .75945 .66871 L F
.77187 .61626 m .75929 .66873 L p .78088 .64655 L F P
0 g
s
.75929 .66873 m .76876 .69554 L .78641 .68843 L p .707 .577 .707 r
F P
0 g
s
.78641 .68843 m .79676 .68426 L p .75929 .66873 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .75924 .66892 L p .75945 .66871 L .707 .577 .707 r
F P
0 g
s
.78088 .64655 m .75929 .66873 L .75945 .66871 L .707 .577 .707 r
F
.77187 .61626 m .74078 .61065 L p .75915 .66863 L F P
0 g
s
.75924 .66892 m .75929 .66873 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.75929 .66873 m .77187 .61626 L p .75915 .66863 L .707 .577 .707 r
F P
0 g
s
.7795 .67378 m .78962 .66402 L .76876 .66726 L .707 .577 .707 r
F
.79676 .68426 m .78962 .66402 L p .7795 .67378 L F P
0 g
s
.79676 .68426 m .81994 .67354 L p .80803 .66516 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .80708 .64715 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .78962 .66402 L p .80708 .64715 L F P
0 g
s
.80708 .64715 m .78962 .66402 L .79442 .66275 L .707 .577 .707 r
F
.80066 .61795 m .77187 .61626 L p .78545 .66191 L F P
0 g
s
.78804 .67061 m .78962 .66402 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .80066 .61795 L p .78545 .66191 L .707 .577 .707 r
F P
0 g
s
.81994 .67354 m .81427 .65751 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.82433 .61555 m .80066 .61795 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .81427 .65751 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .82433 .61555 L p .8088 .65498 L .707 .577 .707 r
F P
0 g
s
.82582 .66119 m .82386 .65308 L .81427 .65751 L .707 .577 .707 r
F
.836 .66443 m .82779 .65675 L .82582 .66119 L F
.82779 .65675 m .82386 .65308 L .82582 .66119 L F
.83296 .66615 m .836 .66443 L p .81427 .65751 L F P
0 g
s
.82714 .65157 m .82644 .64262 L .81917 .65525 L .707 .577 .707 r
F
.82433 .61555 m .81427 .65751 L p .82644 .64262 L F P
0 g
s
.82644 .64262 m .81427 .65751 L .81917 .65525 L .707 .577 .707 r
F
.82329 .62843 m .80722 .63755 L p .82386 .65308 L F P
0 g
s
.836 .66443 m .83085 .64985 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84057 .60931 m .82433 .61555 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.82795 .66197 m .83085 .64985 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .84057 .60931 L p .82679 .64715 L .707 .577 .707 r
F P
0 g
s
.83754 .6541 m .83478 .64523 L .83085 .64985 L .707 .577 .707 r
F
.84339 .65781 m .83761 .64937 L .83754 .6541 L F
.83761 .64937 m .83478 .64523 L .83754 .6541 L F
.83085 .64985 m .836 .66443 L .84314 .65803 L p F P
0 g
s
.84314 .65803 m .84339 .65781 L p .83085 .64985 L .707 .577 .707 r
F P
0 g
s
.83629 .64347 m .83732 .63529 L .83315 .64715 L .707 .577 .707 r
F
.84057 .60931 m .83085 .64985 L p .83732 .63529 L F P
0 g
s
.83732 .63529 m .83085 .64985 L .83315 .64715 L .707 .577 .707 r
F
.83068 .62182 m .82329 .62843 L p .83478 .64523 L F P
0 g
s
.84339 .65781 m .83773 .64178 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.84778 .59982 m .84057 .60931 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83773 .64178 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .84778 .59982 L p .8369 .63863 L .707 .577 .707 r
F P
0 g
s
.84339 .65781 m .84137 .65434 L p .8397 .64924 L .707 .577 .707 r
F P
0 g
s
.83773 .64178 m .83068 .62182 L p .83478 .64523 L .707 .577 .707 r
F P
0 g
s
.835 .64633 m .83516 .65248 L p .83629 .64347 L .707 .577 .707 r
F P
0 g
s
.83516 .65248 m .83422 .64806 L .82795 .66197 L .707 .577 .707 r
F
.83629 .64347 m .83315 .64715 L .82795 .66197 L F
.82329 .62843 m .83085 .64985 L p .83478 .64523 L F P
0 g
s
.83516 .65248 m .83264 .64069 L p .8347 .63514 L .707 .577 .707 r
F P
0 g
s
.83068 .62182 m .83773 .64178 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.8347 .63514 m .83658 .63926 L .83516 .65248 L .707 .577 .707 r
F
.82866 .61834 m .83068 .62182 L p .83599 .63796 L F P
0 g
s
.83773 .64178 m .83516 .65248 L p .83658 .63926 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .82866 .61834 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .84778 .59982 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .83422 .63409 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .84527 .58803 L p .83648 .63034 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82795 .66197 L p .83315 .64715 L .707 .577 .707 r
F P
0 g
s
.83085 .64985 m .82329 .62843 L p .82386 .65308 L .707 .577 .707 r
F P
0 g
s
.84137 .65434 m .83016 .65435 L p .82963 .64175 L .707 .577 .707 r
F P
0 g
s
.83264 .64069 m .82064 .62774 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82866 .61834 m .83422 .63409 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83422 .63409 m .83264 .64069 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82866 .61834 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .82069 .62755 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .81744 .61836 L p .82921 .63167 L .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .84527 .58803 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82064 .62774 m .82069 .62755 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83327 .57507 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.84527 .58803 m .83422 .63409 L p .82074 .62757 L .707 .577 .707 r
F P
0 g
s
.82963 .64175 m .82921 .63167 L .83422 .63409 L .707 .577 .707 r
F
.83422 .63409 m .84137 .65434 L p .82963 .64175 L F P
0 g
s
.84137 .65434 m .83422 .63409 L p .83599 .63796 L .707 .577 .707 r
F P
0 g
s
.83796 .62633 m .83773 .64178 L .83658 .63926 L .707 .577 .707 r
F
.8347 .63514 m .83796 .62633 L .83658 .63926 L F
.8397 .64924 m .83599 .63796 L .83773 .64178 L F
.83773 .64178 m .84339 .65781 L p .8397 .64924 L F P
0 g
s
.84778 .59982 m .83773 .64178 L p .83796 .62633 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81994 .67354 L .83296 .66615 L p .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .81171 .66822 L p .81917 .65525 L .707 .577 .707 r
F P
0 g
s
.81171 .66822 m .82795 .66197 L p .82714 .65157 L .707 .577 .707 r
F P
0 g
s
.82714 .65157 m .81917 .65525 L .81171 .66822 L .707 .577 .707 r
F
.80722 .63755 m .81427 .65751 L p .82386 .65308 L F P
0 g
s
.80722 .63755 m .78405 .64827 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.81427 .65751 m .80722 .63755 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .79676 .68426 L p .80184 .66079 L .707 .577 .707 r
F P
0 g
s
.78962 .66402 m .78804 .67061 L p .79442 .66275 L .707 .577 .707 r
F P
0 g
s
.80803 .66516 m .80184 .66079 L .79833 .67703 L .707 .577 .707 r
F
.80803 .66516 m .79833 .67703 L .79676 .68426 L F
.78405 .64827 m .78962 .66402 L p .80184 .66079 L F P
0 g
s
.78804 .67061 m .81171 .66822 L p .80963 .65874 L .707 .577 .707 r
F P
0 g
s
.80963 .65874 m .79442 .66275 L .78804 .67061 L .707 .577 .707 r
F
.78405 .64827 m .75605 .65955 L p .76876 .66726 L F P
0 g
s
.78962 .66402 m .78405 .64827 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75605 .65955 m .75929 .66873 L p .76876 .66726 L .707 .577 .707 r
F P
0 g
s
.75924 .66892 m .78804 .67061 L p .78623 .66454 L .707 .577 .707 r
F P
0 g
s
.78623 .66454 m .75945 .66871 L .75924 .66892 L .707 .577 .707 r
F
.75605 .65955 m .72594 .67027 L p .72736 .67111 L F P
0 g
s
.75929 .66873 m .75605 .65955 L p .72736 .67111 L .707 .577 .707 r
F P
0 g
s
.75851 .66879 m .75924 .66892 L p .75919 .66874 L .707 .577 .707 r
F P
0 g
s
.387 .25817 m .39369 .76073 L .37058 .77122 L p .707 .577 .707 r
F P
0 g
s
.39369 .76073 m .387 .25817 L .42095 .24992 L p .707 .577 .707 r
F P
0 g
s
.20473 .73045 m .20134 .74828 L .17753 .7513 L p .707 .577 .707 r
F P
0 g
s
.69781 .65434 m .71043 .60167 L .6838 .5902 L p .707 .577 .707 r
F P
0 g
s
.71043 .60167 m .69781 .65434 L .72815 .66332 L p .707 .577 .707 r
F P
0 g
s
.29237 .68389 m .30508 .71988 L .27583 .72901 L p .707 .577 .707 r
F P
0 g
s
.27583 .72901 m .26311 .69302 L .29237 .68389 L p .707 .577 .707 r
F P
0 g
s
.32265 .75326 m .31926 .77109 L .29233 .76098 L p .707 .577 .707 r
F P
0 g
s
.29233 .76098 m .29572 .74316 L .32265 .75326 L p .707 .577 .707 r
F P
0 g
s
.59014 .25079 m .59682 .75335 L .55806 .74774 L p .707 .577 .707 r
F P
0 g
s
.55806 .74774 m .55138 .24518 L .59014 .25079 L p .707 .577 .707 r
F P
0 g
s
.67117 .64287 m .6838 .5902 L .66349 .57736 L p .707 .577 .707 r
F P
0 g
s
.6838 .5902 m .67117 .64287 L .69781 .65434 L p .707 .577 .707 r
F P
0 g
s
.73865 .70627 m .72594 .67027 L .69669 .67941 L p .707 .577 .707 r
F P
0 g
s
.72594 .67027 m .73865 .70627 L .76876 .69554 L p .707 .577 .707 r
F P
0 g
s
.24572 .73974 m .23301 .70375 L .26311 .69302 L p .707 .577 .707 r
F P
0 g
s
.23373 .73116 m .23034 .74899 L .20134 .74828 L p .707 .577 .707 r
F P
0 g
s
.26311 .69302 m .27583 .72901 L .24572 .73974 L p .707 .577 .707 r
F P
0 g
s
.69669 .67941 m .7094 .7154 L .73865 .70627 L p .707 .577 .707 r
F P
0 g
s
.42764 .75248 m .42095 .24992 L .46243 .24472 L p .707 .577 .707 r
F P
0 g
s
.42095 .24992 m .42764 .75248 L .39369 .76073 L p .707 .577 .707 r
F P
0 g
s
.29572 .74316 m .29233 .76098 L .26169 .75337 L p .707 .577 .707 r
F P
0 g
s
.26169 .75337 m .26508 .73554 L .29572 .74316 L p .707 .577 .707 r
F P
0 g
s
.7094 .7154 m .69669 .67941 L .67115 .68605 L p .707 .577 .707 r
F P
0 g
s
.23034 .74899 m .23373 .73116 L .26508 .73554 L p .707 .577 .707 r
F P
0 g
s
.26508 .73554 m .26169 .75337 L .23034 .74899 L p .707 .577 .707 r
F P
0 g
s
.67115 .68605 m .68386 .72204 L .7094 .7154 L p .707 .577 .707 r
F P
0 g
s
.66349 .57736 m .65086 .63003 L .67117 .64287 L p .707 .577 .707 r
F P
0 g
s
.65086 .63003 m .66349 .57736 L .65148 .56441 L p .707 .577 .707 r
F P
0 g
s
.55138 .24518 m .55806 .74774 L .51406 .74565 L p .707 .577 .707 r
F P
0 g
s
.51406 .74565 m .50737 .24309 L .55138 .24518 L p .707 .577 .707 r
F P
0 g
s
.72729 .76494 m .73068 .74711 L .70004 .73949 L p .707 .577 .707 r
F P
0 g
s
.73068 .74711 m .72729 .76494 L .75865 .76931 L p .707 .577 .707 r
F P
0 g
s
.75865 .76931 m .76204 .75149 L .73068 .74711 L p .707 .577 .707 r
F P
0 g
s
.46912 .74728 m .46243 .24472 L .50737 .24309 L p .707 .577 .707 r
F P
0 g
s
.46243 .24472 m .46912 .74728 L .42764 .75248 L p .707 .577 .707 r
F P
0 g
s
.76204 .75149 m .75865 .76931 L .78765 .77003 L p .707 .577 .707 r
F P
0 g
s
.78765 .77003 m .79104 .7522 L .76204 .75149 L p .707 .577 .707 r
F P
0 g
s
.69666 .75732 m .70004 .73949 L .67312 .72939 L p .707 .577 .707 r
F P
0 g
s
.70004 .73949 m .69666 .75732 L .72729 .76494 L p .707 .577 .707 r
F P
0 g
s
.68386 .72204 m .67115 .68605 L .65183 .68954 L p .707 .577 .707 r
F P
0 g
s
.50737 .24309 m .51406 .74565 L .46912 .74728 L p .707 .577 .707 r
F P
0 g
s
.67312 .72939 m .66973 .74721 L .69666 .75732 L p .707 .577 .707 r
F P
0 g
s
.66973 .74721 m .67311 .72941 L p .65254 .71778 L .707 .577 .707 r
F P
0 g
s
.67311 .72941 m .67312 .72939 L .67309 .72937 L p .707 .577 .707 r
F P
0 g
s
.67309 .72937 m .65254 .71778 L p .67311 .72941 L .707 .577 .707 r
F P
0 g
s
.66454 .72554 m .65578 .70074 L p .64061 .68956 L .707 .577 .707 r
F P
0 g
s
.65578 .70074 m .65183 .68954 L .64901 .68955 L p .707 .577 .707 r
F P
0 g
s
.64901 .68955 m .64061 .68956 L p .65578 .70074 L .707 .577 .707 r
F P
0 g
s
.65183 .68954 m .66454 .72554 L .68386 .72204 L p .707 .577 .707 r
F P
0 g
s
.65148 .56441 m .63886 .61707 L .65086 .63003 L p .707 .577 .707 r
F P
0 g
s
.79104 .7522 m .78765 .77003 L .81146 .767 L p .707 .577 .707 r
F P
0 g
s
.81146 .767 m .81485 .74918 L .79104 .7522 L p .707 .577 .707 r
F P
0 g
s
.63886 .61707 m .65148 .56441 L .64897 .55262 L p .707 .577 .707 r
F P
0 g
s
.65254 .71778 m .64915 .7356 L .66973 .74721 L p .707 .577 .707 r
F P
0 g
s
.64915 .7356 m .65207 .72025 L p .64033 .7058 L .707 .577 .707 r
F P
0 g
s
.65207 .72025 m .65254 .71778 L .65031 .71559 L p .707 .577 .707 r
F P
0 g
s
.65031 .71559 m .64033 .7058 L p .65207 .72025 L .707 .577 .707 r
F P
0 g
s
.65332 .72555 m .64244 .69473 L p .63859 .68608 L .707 .577 .707 r
F P
0 g
s
.64244 .69473 m .64061 .68956 L .64024 .68893 L p .707 .577 .707 r
F P
0 g
s
.64024 .68893 m .63859 .68608 L p .64244 .69473 L .707 .577 .707 r
F P
0 g
s
.64061 .68956 m .65332 .72555 L .66454 .72554 L p .707 .577 .707 r
F P
0 g
s
.81485 .74918 m .81146 .767 L .82774 .76054 L p .707 .577 .707 r
F P
0 g
s
.82774 .76054 m .83113 .74271 L .81485 .74918 L p .707 .577 .707 r
F P
0 g
s
.64897 .55262 m .63634 .60528 L .63886 .61707 L p .707 .577 .707 r
F P
0 g
s
.64033 .7058 m .63694 .72363 L .64915 .7356 L p .707 .577 .707 r
F P
0 g
s
.63634 .60528 m .64897 .55262 L .65618 .54313 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83113 .74271 m .82774 .76054 L .83491 .75127 L p .707 .577 .707 r
F P
0 g
s
.83491 .75127 m .8383 .73344 L .83113 .74271 L p .707 .577 .707 r
F P
0 g
s
.63694 .72363 m .64033 .7058 L .63768 .69463 L p .707 .577 .707 r
F P
0 g
s
.63768 .69463 m .63429 .71246 L .63694 .72363 L p .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .63768 .69463 L .64017 .69141 L p .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .65332 .72555 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63906 .68739 m .65131 .72208 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.63859 .68608 m .63906 .68739 L p .63898 .68712 L .707 .577 .707 r
F P
0 g
s
.65131 .72208 m .63859 .68608 L .64598 .67947 L p .707 .577 .707 r
F P
0 g
s
.64017 .69141 m .64485 .68536 L p .64114 .69489 L .707 .577 .707 r
F P
0 g
s
.63429 .71246 m .64017 .69141 L .64114 .69489 L .707 .577 .707 r
F
.65618 .54313 m .64356 .59579 L .63634 .60528 L p F P
0 g
s
.64356 .59579 m .65618 .54313 L .67242 .53688 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .39777 .57378 L .36742 .5648 L p .707 .577 .707 r
F P
0 g
s
.38514 .62644 m .41602 .63201 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.39777 .57378 m .38862 .61193 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.38862 .61193 m .38514 .62644 L p .41595 .63178 L .707 .577 .707 r
F P
0 g
s
.41622 .632 m .39777 .57378 L .41602 .63201 L .707 .577 .707 r
F
.40308 .64552 m .41625 .63199 L .3842 .63438 L F
.42575 .65889 m .41625 .63199 L p .40308 .64552 L F P
0 g
s
.45375 .64762 m .42562 .63054 L .41625 .63199 L .707 .577 .707 r
F
.44326 .6278 m .43789 .60976 L .41629 .63199 L F
.42886 .57939 m .41625 .63199 L p .43789 .60976 L F P
0 g
s
.41625 .63199 m .42575 .65889 L .44346 .65176 L p .707 .577 .707 r
F P
0 g
s
.44346 .65176 m .45375 .64762 L p .41625 .63199 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .41623 .63205 L p .41629 .63199 L .707 .577 .707 r
F P
0 g
s
.43789 .60976 m .41625 .63199 L .41629 .63199 L .707 .577 .707 r
F
.42886 .57939 m .39777 .57378 L p .41621 .63196 L F P
0 g
s
.41623 .63205 m .41625 .63199 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.41625 .63199 m .42886 .57939 L p .41621 .63196 L .707 .577 .707 r
F P
0 g
s
.43642 .63709 m .44657 .62728 L .42562 .63054 L .707 .577 .707 r
F
.45375 .64762 m .44657 .62728 L p .43642 .63709 L F P
0 g
s
.45375 .64762 m .47693 .6369 L p .46495 .62846 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .46409 .61036 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .44657 .62728 L p .46409 .61036 L F P
0 g
s
.46409 .61036 m .44657 .62728 L .45131 .62603 L .707 .577 .707 r
F
.45765 .58108 m .42886 .57939 L p .44249 .62522 L F P
0 g
s
.44503 .63374 m .44657 .62728 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45765 .58108 L p .44249 .62522 L .707 .577 .707 r
F P
0 g
s
.47693 .6369 m .47123 .62077 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.48132 .57868 m .45765 .58108 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .47123 .62077 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .48132 .57868 L p .46583 .61827 L .707 .577 .707 r
F P
0 g
s
.48276 .62449 m .48077 .61637 L .47123 .62077 L .707 .577 .707 r
F
.49299 .62778 m .48473 .62006 L .48276 .62449 L F
.48473 .62006 m .48077 .61637 L .48276 .62449 L F
.48414 .61481 m .48344 .60583 L .47611 .61852 L F
.48132 .57868 m .47123 .62077 L p .48344 .60583 L F P
0 g
s
.48344 .60583 m .47123 .62077 L .47611 .61852 L .707 .577 .707 r
F
.48028 .59179 m .46421 .6009 L p .48077 .61637 L F P
0 g
s
.49299 .62778 m .48781 .61311 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49756 .57243 m .48132 .57868 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48494 .6251 m .48781 .61311 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .49756 .57243 L p .4838 .61044 L .707 .577 .707 r
F P
0 g
s
.4945 .61739 m .49172 .60852 L .48781 .61311 L .707 .577 .707 r
F
.50038 .62116 m .49457 .61267 L .4945 .61739 L F
.49457 .61267 m .49172 .60852 L .4945 .61739 L F
.48781 .61311 m .49299 .62778 L .50018 .62134 L p F P
0 g
s
.50018 .62134 m .50038 .62116 L p .48781 .61311 L .707 .577 .707 r
F P
0 g
s
.49327 .60671 m .49429 .5985 L .4901 .61042 L .707 .577 .707 r
F
.49756 .57243 m .48781 .61311 L p .49429 .5985 L F P
0 g
s
.49429 .5985 m .48781 .61311 L .4901 .61042 L .707 .577 .707 r
F
.48767 .58517 m .48028 .59179 L p .49172 .60852 L F P
0 g
s
.50038 .62116 m .49468 .60504 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.50477 .56295 m .49756 .57243 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49468 .60504 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .50477 .56295 L p .49386 .60194 L .707 .577 .707 r
F P
0 g
s
.50038 .62116 m .49836 .61769 L p .49664 .61247 L .707 .577 .707 r
F P
0 g
s
.49468 .60504 m .48767 .58517 L p .49172 .60852 L .707 .577 .707 r
F P
0 g
s
.49197 .60956 m .49215 .61561 L p .49327 .60671 L .707 .577 .707 r
F P
0 g
s
.49215 .61561 m .49122 .61123 L .48494 .6251 L .707 .577 .707 r
F
.49327 .60671 m .4901 .61042 L .48494 .6251 L F
.48028 .59179 m .48781 .61311 L p .49172 .60852 L F P
0 g
s
.49215 .61561 m .48963 .60381 L p .49165 .59838 L .707 .577 .707 r
F P
0 g
s
.48767 .58517 m .49468 .60504 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49165 .59838 m .49354 .60253 L .49215 .61561 L .707 .577 .707 r
F
.48565 .5817 m .48767 .58517 L p .49295 .60124 L F P
0 g
s
.49468 .60504 m .49215 .61561 L p .49354 .60253 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48565 .5817 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .50477 .56295 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .49118 .59736 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .50226 .55115 L p .49339 .59367 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48494 .6251 L p .4901 .61042 L .707 .577 .707 r
F P
0 g
s
.48781 .61311 m .48028 .59179 L p .48077 .61637 L .707 .577 .707 r
F P
0 g
s
.49836 .61769 m .48715 .61771 L p .48662 .60497 L .707 .577 .707 r
F P
0 g
s
.48963 .60381 m .47763 .59086 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48565 .5817 m .49118 .59736 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49118 .59736 m .48963 .60381 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .48565 .5817 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .47765 .59081 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47443 .58171 L p .4862 .59495 L .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .50226 .55115 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47763 .59086 m .47765 .59081 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .49026 .5382 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.50226 .55115 m .49118 .59736 L p .47766 .59081 L .707 .577 .707 r
F P
0 g
s
.48662 .60497 m .4862 .59495 L .49118 .59736 L .707 .577 .707 r
F
.49118 .59736 m .49836 .61769 L p .48662 .60497 L F P
0 g
s
.49836 .61769 m .49118 .59736 L p .49295 .60124 L .707 .577 .707 r
F P
0 g
s
.49492 .58954 m .49468 .60504 L .49354 .60253 L .707 .577 .707 r
F
.49165 .59838 m .49492 .58954 L .49354 .60253 L F
.49664 .61247 m .49295 .60124 L .49468 .60504 L F
.49468 .60504 m .50038 .62116 L p .49664 .61247 L F P
0 g
s
.50477 .56295 m .49468 .60504 L p .49492 .58954 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .47693 .6369 L .49002 .62947 L p .707 .577 .707 r
F P
0 g
s
.49002 .62947 m .49299 .62778 L p .47123 .62077 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .4687 .63134 L p .47611 .61852 L .707 .577 .707 r
F P
0 g
s
.4687 .63134 m .48494 .6251 L p .48414 .61481 L .707 .577 .707 r
F P
0 g
s
.48414 .61481 m .47611 .61852 L .4687 .63134 L .707 .577 .707 r
F
.46421 .6009 m .47123 .62077 L p .48077 .61637 L F P
0 g
s
.46421 .6009 m .44104 .61162 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.47123 .62077 m .46421 .6009 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .45375 .64762 L p .45872 .62407 L .707 .577 .707 r
F P
0 g
s
.44657 .62728 m .44503 .63374 L p .45131 .62603 L .707 .577 .707 r
F P
0 g
s
.46495 .62846 m .45872 .62407 L .4553 .64027 L .707 .577 .707 r
F
.46495 .62846 m .4553 .64027 L .45375 .64762 L F
.44104 .61162 m .44657 .62728 L p .45872 .62407 L F P
0 g
s
.44503 .63374 m .4687 .63134 L p .46664 .62199 L .707 .577 .707 r
F P
0 g
s
.46664 .62199 m .45131 .62603 L .44503 .63374 L .707 .577 .707 r
F
.44104 .61162 m .41304 .6229 L p .42562 .63054 L F P
0 g
s
.44657 .62728 m .44104 .61162 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41304 .6229 m .41625 .63199 L p .42562 .63054 L .707 .577 .707 r
F P
0 g
s
.41623 .63205 m .44503 .63374 L p .44326 .6278 L .707 .577 .707 r
F P
0 g
s
.44326 .6278 m .41629 .63199 L .41623 .63205 L .707 .577 .707 r
F
.41304 .6229 m .38293 .63363 L p .3842 .63438 L F P
0 g
s
.41625 .63199 m .41304 .6229 L p .3842 .63438 L .707 .577 .707 r
F P
0 g
s
.41602 .63201 m .41623 .63205 L p .41622 .632 L .707 .577 .707 r
F P
0 g
s
.3548 .61746 m .36742 .5648 L .34079 .55333 L p .707 .577 .707 r
F P
0 g
s
.36742 .5648 m .3548 .61746 L .38514 .62644 L p .707 .577 .707 r
F P
0 g
s
.8383 .73344 m .83491 .75127 L .83226 .7401 L p .707 .577 .707 r
F P
0 g
s
.83226 .7401 m .83565 .72228 L .8383 .73344 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64598 .67947 m .65869 .71546 L .65131 .72208 L p .707 .577 .707 r
F P
0 g
s
.67242 .53688 m .6598 .58955 L .64356 .59579 L p .707 .577 .707 r
F P
0 g
s
.64485 .68536 m .64146 .70319 L .63429 .71246 L p .707 .577 .707 r
F P
0 g
s
.32816 .60599 m .34079 .55333 L .32048 .54049 L p .707 .577 .707 r
F P
0 g
s
.34079 .55333 m .32816 .60599 L .3548 .61746 L p .707 .577 .707 r
F P
0 g
s
.6598 .58955 m .67242 .53688 L .69609 .53449 L p .707 .577 .707 r
F P
0 g
s
.83016 .65435 m .81083 .65785 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81744 .61836 m .82069 .62755 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .82064 .62774 L .82016 .62743 L p .707 .577 .707 r
F P
0 g
s
.82069 .62755 m .83016 .65435 L p .81607 .62655 L .707 .577 .707 r
F P
0 g
s
.81083 .65785 m .79812 .62186 L .81744 .61836 L p .707 .577 .707 r
F P
0 g
s
.83327 .57507 m .82069 .62755 L p .80033 .6149 L .707 .577 .707 r
F P
0 g
s
.82016 .62743 m .80033 .6149 L p .82069 .62755 L .707 .577 .707 r
F P
0 g
s
.80033 .6149 m .81295 .56223 L .83327 .57507 L p .707 .577 .707 r
F P
0 g
s
.39564 .66962 m .38293 .63363 L .35368 .64276 L p .707 .577 .707 r
F P
0 g
s
.38293 .63363 m .39564 .66962 L .42575 .65889 L p .707 .577 .707 r
F P
0 g
s
.35368 .64276 m .36639 .67875 L .39564 .66962 L p .707 .577 .707 r
F P
0 g
s
.36639 .67875 m .35368 .64276 L .32814 .6494 L p .707 .577 .707 r
F P
0 g
s
.65869 .71546 m .64598 .67947 L .66205 .67035 L p .707 .577 .707 r
F P
0 g
s
.83565 .72228 m .83226 .7401 L .82005 .72813 L p .707 .577 .707 r
F P
0 g
s
.82005 .72813 m .82344 .7103 L .83565 .72228 L p .707 .577 .707 r
F P
0 g
s
.32814 .6494 m .34085 .68539 L .36639 .67875 L p .707 .577 .707 r
F P
0 g
s
.64146 .70319 m .64485 .68536 L .66113 .6789 L p .707 .577 .707 r
F P
0 g
s
.32048 .54049 m .30785 .59315 L .32816 .60599 L p .707 .577 .707 r
F P
0 g
s
.30785 .59315 m .32048 .54049 L .30847 .52754 L p .707 .577 .707 r
F P
0 g
s
.69609 .53449 m .68347 .58715 L .6598 .58955 L p .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .65869 .71546 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.66251 .67166 m .67476 .70635 L p .66197 .67139 L .707 .577 .707 r
F P
0 g
s
.67476 .70635 m .66205 .67035 L .68522 .65963 L p .707 .577 .707 r
F P
0 g
s
.65774 .69673 m .66113 .6789 L .67365 .67731 L p .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .67476 .70635 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68522 .65963 m .68705 .66481 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.68705 .66481 m .69793 .69563 L p .68438 .66337 L .707 .577 .707 r
F P
0 g
s
.69793 .69563 m .68522 .65963 L .71323 .64836 L p .707 .577 .707 r
F P
0 g
s
.71323 .64836 m .72594 .68435 L .69793 .69563 L p .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .68494 .67588 L .70865 .67646 L p .707 .577 .707 r
F P
0 g
s
.70865 .67646 m .71394 .67659 L p .71139 .67794 L .707 .577 .707 r
F P
0 g
s
.68155 .6937 m .70865 .67646 L .71139 .67794 L .707 .577 .707 r
F
.67365 .67731 m .68494 .67588 L p .67932 .68019 L F P
0 g
s
.65774 .69673 m .67365 .67731 L .67932 .68019 L .707 .577 .707 r
F
.66205 .67035 m .66251 .67166 L p .66197 .67139 L F P
0 g
s
.68347 .58715 m .69609 .53449 L .72488 .53618 L p .707 .577 .707 r
F P
0 g
s
.81295 .56223 m .80033 .6149 L .7737 .60343 L p .707 .577 .707 r
F P
0 g
s
.7737 .60343 m .78632 .55076 L .81295 .56223 L p .707 .577 .707 r
F P
0 g
s
.38428 .72747 m .38767 .70964 L .35703 .70203 L p .707 .577 .707 r
F P
0 g
s
.38767 .70964 m .38428 .72747 L .41564 .73185 L p .707 .577 .707 r
F P
0 g
s
.41564 .73185 m .41903 .71402 L .38767 .70964 L p .707 .577 .707 r
F P
0 g
s
.66113 .6789 m .65774 .69673 L .64146 .70319 L p .707 .577 .707 r
F P
0 g
s
.41903 .71402 m .41564 .73185 L .44464 .73256 L p .707 .577 .707 r
F P
0 g
s
.44464 .73256 m .44803 .71473 L .41903 .71402 L p .707 .577 .707 r
F P
0 g
s
.35365 .71985 m .35703 .70203 L .33011 .69192 L p .707 .577 .707 r
F P
0 g
s
.35703 .70203 m .35365 .71985 L .38428 .72747 L p .707 .577 .707 r
F P
0 g
s
.34085 .68539 m .32814 .6494 L .30882 .6529 L p .707 .577 .707 r
F P
0 g
s
.33011 .69192 m .32672 .70975 L .35365 .71985 L p .707 .577 .707 r
F P
0 g
s
.32672 .70975 m .33 .69248 L p .30953 .68031 L .707 .577 .707 r
F P
0 g
s
.33 .69248 m .33011 .69192 L .32943 .69154 L p .707 .577 .707 r
F P
0 g
s
.32943 .69154 m .30953 .68031 L p .33 .69248 L .707 .577 .707 r
F P
0 g
s
.32153 .68889 m .31267 .66381 L p .2976 .65291 L .707 .577 .707 r
F P
0 g
s
.31267 .66381 m .30882 .6529 L .30608 .6529 L p .707 .577 .707 r
F P
0 g
s
.30608 .6529 m .2976 .65291 L p .31267 .66381 L .707 .577 .707 r
F P
0 g
s
.30882 .6529 m .32153 .68889 L .34085 .68539 L p .707 .577 .707 r
F P
0 g
s
.71226 .58884 m .72488 .53618 L .75598 .54178 L p .707 .577 .707 r
F P
0 g
s
.72488 .53618 m .71226 .58884 L .68347 .58715 L p .707 .577 .707 r
F P
0 g
s
.78632 .55076 m .7737 .60343 L .74335 .59445 L p .707 .577 .707 r
F P
0 g
s
.74335 .59445 m .75598 .54178 L .78632 .55076 L p .707 .577 .707 r
F P
0 g
s
.30847 .52754 m .29585 .5802 L .30785 .59315 L p .707 .577 .707 r
F P
0 g
s
.75598 .54178 m .74335 .59445 L .71226 .58884 L p .707 .577 .707 r
F P
0 g
s
.44803 .71473 m .44464 .73256 L .46845 .72954 L p .707 .577 .707 r
F P
0 g
s
.46845 .72954 m .47184 .71171 L .44803 .71473 L p .707 .577 .707 r
F P
0 g
s
.82344 .7103 m .82005 .72813 L .79947 .71652 L p .707 .577 .707 r
F P
0 g
s
.79947 .71652 m .80286 .69869 L .82344 .7103 L p .707 .577 .707 r
F P
0 g
s
.79812 .62186 m .81083 .65785 L .78529 .66449 L p .707 .577 .707 r
F P
0 g
s
.78529 .66449 m .77258 .6285 L .79812 .62186 L p .707 .577 .707 r
F P
0 g
s
.29585 .5802 m .30847 .52754 L .30596 .51574 L p .707 .577 .707 r
F P
0 g
s
.30953 .68031 m .30614 .69814 L .32672 .70975 L p .707 .577 .707 r
F P
0 g
s
.68494 .67588 m .68155 .6937 L .65774 .69673 L p .707 .577 .707 r
F P
0 g
s
.30614 .69814 m .30896 .68332 L p .29732 .66833 L .707 .577 .707 r
F P
0 g
s
.30896 .68332 m .30953 .68031 L .30682 .67765 L p .707 .577 .707 r
F P
0 g
s
.30682 .67765 m .29732 .66833 L p .30896 .68332 L .707 .577 .707 r
F P
0 g
s
.31031 .6889 m .29932 .6578 L p .29558 .64944 L .707 .577 .707 r
F P
0 g
s
.29932 .6578 m .2976 .65291 L .29725 .65232 L p .707 .577 .707 r
F P
0 g
s
.29725 .65232 m .29558 .64944 L p .29932 .6578 L .707 .577 .707 r
F P
0 g
s
.2976 .65291 m .31031 .6889 L .32153 .68889 L p .707 .577 .707 r
F P
0 g
s
.47184 .71171 m .46845 .72954 L .48473 .72307 L p .707 .577 .707 r
F P
0 g
s
.48473 .72307 m .48812 .70525 L .47184 .71171 L p .707 .577 .707 r
F P
0 g
s
.77258 .6285 m .78529 .66449 L .75604 .67362 L p .707 .577 .707 r
F P
0 g
s
.75604 .67362 m .74333 .63763 L .77258 .6285 L p .707 .577 .707 r
F P
0 g
s
.80286 .69869 m .79947 .71652 L .77255 .70641 L p .707 .577 .707 r
F P
0 g
s
.77255 .70641 m .77594 .68858 L .80286 .69869 L p .707 .577 .707 r
F P
0 g
s
.30596 .51574 m .29333 .5684 L .29585 .5802 L p .707 .577 .707 r
F P
0 g
s
.29732 .66833 m .29393 .68616 L .30614 .69814 L p .707 .577 .707 r
F P
0 g
s
.72594 .68435 m .71323 .64836 L .74333 .63763 L p .707 .577 .707 r
F P
0 g
s
.71394 .67659 m .71055 .69442 L .68155 .6937 L p .707 .577 .707 r
F P
0 g
s
.74333 .63763 m .75604 .67362 L .72594 .68435 L p .707 .577 .707 r
F P
0 g
s
.29333 .5684 m .30596 .51574 L .31317 .50626 L p .707 .577 .707 r
F P
0 g
s
.77594 .68858 m .77255 .70641 L .74191 .6988 L p .707 .577 .707 r
F P
0 g
s
.74191 .6988 m .7453 .68097 L .77594 .68858 L p .707 .577 .707 r
F P
0 g
s
.71055 .69442 m .71394 .67659 L .7453 .68097 L p .707 .577 .707 r
F P
0 g
s
.7453 .68097 m .74191 .6988 L .71055 .69442 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.48812 .70525 m .48473 .72307 L .4919 .7138 L p .707 .577 .707 r
F P
0 g
s
.4919 .7138 m .49529 .69598 L .48812 .70525 L p .707 .577 .707 r
F P
0 g
s
.29393 .68616 m .29732 .66833 L .29467 .65717 L p .707 .577 .707 r
F P
0 g
s
.29467 .65717 m .29128 .67499 L .29393 .68616 L p .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29467 .65717 L .29698 .65418 L p .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .31031 .6889 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29594 .65046 m .3083 .68543 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.29558 .64944 m .29594 .65046 L p .29589 .65025 L .707 .577 .707 r
F P
0 g
s
.3083 .68543 m .29558 .64944 L .30297 .64282 L p .707 .577 .707 r
F P
0 g
s
.29698 .65418 m .30184 .6479 L p .29798 .6578 L .707 .577 .707 r
F P
0 g
s
.29128 .67499 m .29698 .65418 L .29798 .6578 L .707 .577 .707 r
F
.31317 .50626 m .30055 .55892 L .29333 .5684 L p F P
0 g
s
.30055 .55892 m .31317 .50626 L .32941 .50001 L p .707 .577 .707 r
F P
0 g
s
.49529 .69598 m .4919 .7138 L .48925 .70264 L p .707 .577 .707 r
F P
0 g
s
.48925 .70264 m .49264 .68481 L .49529 .69598 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30297 .64282 m .31568 .67881 L .3083 .68543 L p .707 .577 .707 r
F P
0 g
s
.32941 .50001 m .31679 .55267 L .30055 .55892 L p .707 .577 .707 r
F P
0 g
s
.30184 .6479 m .29845 .66572 L .29128 .67499 L p .707 .577 .707 r
F P
0 g
s
.31679 .55267 m .32941 .50001 L .35308 .49761 L p .707 .577 .707 r
F P
0 g
s
.48715 .61771 m .46782 .6212 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47443 .58171 m .47765 .59081 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .47763 .59086 L .47749 .59077 L p .707 .577 .707 r
F P
0 g
s
.47765 .59081 m .48715 .61771 L p .47308 .58983 L .707 .577 .707 r
F P
0 g
s
.46782 .6212 m .45511 .58521 L .47443 .58171 L p .707 .577 .707 r
F P
0 g
s
.49026 .5382 m .47765 .59081 L p .45732 .57802 L .707 .577 .707 r
F P
0 g
s
.47749 .59077 m .45732 .57802 L p .47765 .59081 L .707 .577 .707 r
F P
0 g
s
.45732 .57802 m .46994 .52536 L .49026 .5382 L p .707 .577 .707 r
F P
0 g
s
.31568 .67881 m .30297 .64282 L .31904 .63371 L p .707 .577 .707 r
F P
0 g
s
.49264 .68481 m .48925 .70264 L .47704 .69066 L p .707 .577 .707 r
F P
0 g
s
.47704 .69066 m .48043 .67283 L .49264 .68481 L p .707 .577 .707 r
F P
0 g
s
.29845 .66572 m .30184 .6479 L .31812 .64143 L p .707 .577 .707 r
F P
0 g
s
.35308 .49761 m .34046 .55028 L .31679 .55267 L p .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31568 .67881 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.3194 .63473 m .33175 .6697 L p .31898 .63452 L .707 .577 .707 r
F P
0 g
s
.33175 .6697 m .31904 .63371 L .34221 .62299 L p .707 .577 .707 r
F P
0 g
s
.31473 .65926 m .31812 .64143 L .32972 .63996 L p .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .33175 .6697 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34221 .62299 m .34393 .62788 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.34393 .62788 m .35492 .65898 L p .34142 .62652 L .707 .577 .707 r
F P
0 g
s
.35492 .65898 m .34221 .62299 L .37021 .61171 L p .707 .577 .707 r
F P
0 g
s
.37021 .61171 m .38293 .6477 L .35492 .65898 L p .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .34193 .63841 L .36449 .63896 L p .707 .577 .707 r
F P
0 g
s
.36449 .63896 m .37093 .63912 L p .36783 .64076 L .707 .577 .707 r
F P
0 g
s
.33854 .65624 m .36449 .63896 L .36783 .64076 L .707 .577 .707 r
F
.32972 .63996 m .34193 .63841 L p .33585 .64307 L F P
0 g
s
.31473 .65926 m .32972 .63996 L .33585 .64307 L .707 .577 .707 r
F
.31904 .63371 m .3194 .63473 L p .31898 .63452 L F P
0 g
s
.34046 .55028 m .35308 .49761 L .38187 .4993 L p .707 .577 .707 r
F P
0 g
s
.46994 .52536 m .45732 .57802 L .43069 .56655 L p .707 .577 .707 r
F P
0 g
s
.43069 .56655 m .44331 .51389 L .46994 .52536 L p .707 .577 .707 r
F P
0 g
s
.31812 .64143 m .31473 .65926 L .29845 .66572 L p .707 .577 .707 r
F P
0 g
s
.36925 .55196 m .38187 .4993 L .41296 .50491 L p .707 .577 .707 r
F P
0 g
s
.38187 .4993 m .36925 .55196 L .34046 .55028 L p .707 .577 .707 r
F P
0 g
s
.44331 .51389 m .43069 .56655 L .40034 .55757 L p .707 .577 .707 r
F P
0 g
s
.40034 .55757 m .41296 .50491 L .44331 .51389 L p .707 .577 .707 r
F P
0 g
s
.41296 .50491 m .40034 .55757 L .36925 .55196 L p .707 .577 .707 r
F P
0 g
s
.48043 .67283 m .47704 .69066 L .45646 .67905 L p .707 .577 .707 r
F P
0 g
s
.45646 .67905 m .45985 .66122 L .48043 .67283 L p .707 .577 .707 r
F P
0 g
s
.45511 .58521 m .46782 .6212 L .44228 .62784 L p .707 .577 .707 r
F P
0 g
s
.44228 .62784 m .42957 .59185 L .45511 .58521 L p .707 .577 .707 r
F P
0 g
s
.34193 .63841 m .33854 .65624 L .31473 .65926 L p .707 .577 .707 r
F P
0 g
s
.42957 .59185 m .44228 .62784 L .41303 .63697 L p .707 .577 .707 r
F P
0 g
s
.41303 .63697 m .40032 .60098 L .42957 .59185 L p .707 .577 .707 r
F P
0 g
s
.45985 .66122 m .45646 .67905 L .42954 .66894 L p .707 .577 .707 r
F P
0 g
s
.42954 .66894 m .43293 .65112 L .45985 .66122 L p .707 .577 .707 r
F P
0 g
s
.38293 .6477 m .37021 .61171 L .40032 .60098 L p .707 .577 .707 r
F P
0 g
s
.37093 .63912 m .36754 .65695 L .33854 .65624 L p .707 .577 .707 r
F P
0 g
s
.40032 .60098 m .41303 .63697 L .38293 .6477 L p .707 .577 .707 r
F P
0 g
s
.43293 .65112 m .42954 .66894 L .3989 .66133 L p .707 .577 .707 r
F P
0 g
s
.3989 .66133 m .40229 .6435 L .43293 .65112 L p .707 .577 .707 r
F P
0 g
s
.36754 .65695 m .37093 .63912 L .40229 .6435 L p .707 .577 .707 r
F P
0 g
s
.40229 .6435 m .3989 .66133 L .36754 .65695 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00I7oo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0I7oo001TOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol0
06Eoo`04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP00
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
065oo`P000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00GGoo10000eYF00@005YFFUIJ
EPT000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00Fgoo0`001EYF00<005YFFUH01UYF00<005YFFUH00UYF
1P0000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001IOol20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001F
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001FOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`04001JEUYF0003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP<000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0000QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P001Woo4P00CGoo001EOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool200000eYF001JEP04FUH0
0`00FUIJEP06FUH00`00FUH000030019Ool005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD004Aoo`00E7oo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003Ool0000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@0041oo`00E7oo00<005YFFUH00eYF00@005YFFUIJEPd000MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000lOol005Aoo`80009JEPH0009JEP80
00=oo`04001JEUYF0002FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF100015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF000003Yoo`00E7oo10000UYF00<005YFFUH00eYF00H005YF000007oo0002FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`00=goo001COol30003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01EYF0`0000AJEP00000000EJEP03001JEUYF
00AJEP03001JEUYF00AJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8003Eoo`00Dgoo0`000eYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF1@000eYF0`0000=JEP00FUH01UYF00<005YFFUH015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P00
=7oo001COol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000eYF
000000030005FUH40006FUH00`00FUIJEP04FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000bOol005=oo`03001J
EP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000EJEP04001JEUYFFUH2
0004FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0;goo001COol00`00
FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60003FUH00`00FUIJEP03
FUH200000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02io
o`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH90002
FUH20006FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8002moo`00E7oo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YF0000;Woo001EOol01000FUIJEP001EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1@000eYF00@005YFFUIJEP8000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH70004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo000jOol7000EOol20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH00UYF10000UYF00<005YF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH50002FUH20003Ool7
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`0ZOol003Ioo`@000=JEP04001JEUYFFUH9000=Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF000005YF0000
1UYF0`0027oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0:Woo000dOol30005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60008Ool20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool40007FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol0039oo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000Moo`04001JEUYF0007FUH0
0`00FUIJEP07FUH50007FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00=J
EP03001JEUYF00=JEP8000Moo`T0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH2
000/Ool0031oo`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00=JEP<000Eoo`<000MJEP03001JEUYF00IJEP800003FUH005YF00QJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP030004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH30004Ool50004Ool40007FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH2000/Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000Aoo`8000IJEP03001JEUYF00=JEP<000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00T000Qoo`8000EJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00
;goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YF000000Aoo`8000AJEP04001JEUYFFUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000:
Ool300000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool002moo`03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
00Aoo`800004FUH005YFFUH30008FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000Uoo`8000IJ
EP04001JEUYFFUH2000]Ool002ioo`04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004Ool40003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEPd000AJEP04001JEUYFFUH2000]Ool002ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<0
009oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00004FUH005YF0002
FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJ
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPH0009J
EP03001JEUYF009JEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000P001eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF00000`000UYF00T005YFFUIJEP00FUH005YF000015YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH00eYF0`00
15YF0P00;Goo000^Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH30006FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0`001UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool002ioo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000=JEP8000QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH0
0`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000goo001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001J
EP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20006FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000001eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00UYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP0300000eYF0000000>0008FUH40007FUH00`00
FUIJEP04FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P0017oo0`0025YF00<005YFFUH01UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002ioo`00;Goo00<005YF00000eYF00@005YFFUIJEPH000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP05001JEP00001JEP030005FUH00`00FUIJEP05FUH00`00FUIJEP040000
15YF000000000eYF00<005YFFUH01EYF00<005YFFUH00UYF0P0035YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000Eoo`03001JEUYF00IJEP03001JEUYF00EJEP<0
0003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002eoo`03
001JEUYF009JEPD0009JEP80009oo`T000AJEP03001JEUYF00MJEPD00003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00IJEP06001JEP00001JEP0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD000Aoo`8000IJEP03001JEUYF
009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^
Ool002eoo`800005FUH00000FUH00005FUH01000FUH000002Goo1P0025YF0`000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001eYF0P000eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP80
00Aoo`8000=JEP03001JEUYF00<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000^Ool002aoo`04001JEP000002FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
27oo0`0000Aoo`00000000EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEPL000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP8000Aoo`800006FUH00000001JEP002EYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;7oo0`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF0`0017oo1@000goo0`0000AJEP00000000=JEP04001JEUYF
FUH>0006FUH00`00FUIJEP07FUH01000FUH000001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01EYF0P000goo0`0015YF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01`00;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH0000200000goo000000030006Ool30003
FUH60006FUH30004FUH40002FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF
10001eYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEPH0009JEP05001JEP00FUH0000]
Ool002aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00=JEPH000Mo
o`800004FUH000000004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH50006FUH00`00FUIJ
EP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20006FUH40009FUH00`00FUIJEP06FUH00`00FUIJEP06FUH50003FUH01000FUIJ
EUYF0P0000=JEP000000;Woo000/Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH60004Ool01000FUH000000UYF00<005YFFUH00eYF00@005YF000000EJEP03001J
EUYF00IJEP03001JEP0000D0009JEP03001JEUYF00EJEP@000aJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP8000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP<00003FUH005YF00EJEP04001JEP000002FUH00`00Oomoo`0^Ool002eo
o`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF2@0000=JEP00
FUH015YF0P001eYF00<005YFFUH01EYF0`001UYF10001UYF00<005YFFUH00P002eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF0P001EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00003`0000AJEP000000035oo`00;Goo00D005YFFUIJEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF009J
EP800003FUH005YF00IJEP03001JEUYF00=JEP<000UJEP03001JEUYF008000=JEP03001JEUYF00=J
EP8000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004
FUH000000007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP04FUH2000cOol0
02ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUH0
05YF00000UYF0`000eYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH01eYF00<005YF
FUH00UYF0P0000=JEP00FUH01EYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF4`0015YF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
=Goo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30005FUH20005
FUH00`00FUIJEP02FUH50005FUH30007FUH00`00FUIJEP04FUH20006FUH01000FUH000001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0100015YF
00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF0P00=goo000`Ool00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH20002FUH00`00FUIJ
EP0700001EYF001JEUYF000015YF1@001UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@00003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000MJEP<003Uoo`00<Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0000=JEP00FUH00UYF1`00
0UYF00<005YFFUH00eYF00@005YFFUH000AJEPD000IJEP03001JEUYF00QJEP800003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL003aoo`00
<goo00@005YFFUH000MJEP03001JEUYF00MJEP04001JEUYFFUH30005FUH01000FUIJEP0015YF0`00
0UYF00<005YFFUH00UYF00@005YFFUH000AJEPD000IJEP03001JEUYF00UJEP<000AJEP03001JEUYF
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000003eoo`00
=7oo0`001eYF00<005YFFUH01eYF100025YF10001EYF00<005YF00000P000UYF00<005YF00000UYF
00<005YFFUH00eYF0`001eYF00<005YFFUH02EYF00@005YFFUH0009JEP8000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH01000FUIJEUYF400015YF00<0
05YFFUH01eYF00@005YFFUIJEP<003Yoo`00=Woo0P001UYF00<005YFFUH01UYF0P0000=JEP00FUH0
25YF00@005YFFUH000EJEP04001JEUYFFUH30002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00@005YFFUIJEP@000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH60004FUH20002FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP05FUH2
000hOol003Qoo`8000AJEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH00`00FUIJEP05FUH400000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1000
1EYF00@005YF000000EJEP03001JEUYF00IJEP03001JEP0000D0009JEP03001JEUYF00IJEP<003Io
o`00>Woo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00<005YFFUH00UYF0`0025YF00<0
05YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH01EYF0`001Woo10001eYF00<005YFFUH00P00=7oo000lOol500000eYF001JEP08
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09
FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH0
00030002FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00=JEP8000eoo`8000AJEP03001JEUYF
00=JEP80039oo`00?7oo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000
15YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH01eYF1@000UYF0P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF001JEP<0009JEP<000=JEP03001JEUYF
00EJEP03001JEP000080015oo`<00003FUH005YF00EJEP80035oo`00>Goo0`001eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YF00000`000UYF00<005YF00000P0000=JEP00FUH025YF00<005YF
FUH015YF3P000eYF00<005YFFUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YF0000009JEP04001JEUYF0005FUH00`00FUIJEP04FUH30006Ool3000>Ool20006FUH2
000aOol003Moo`800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP<000IJEP05001J
EP00001JEP040006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000UYF00@005YF
000000IJEP03001JEP0000@000Moo`D000moo`8000=JEP04001JEUYF000`Ool003Eoo`8000=JEP80
00MJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH50004FUH00`00Ool00004
0002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000025YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYF0003FUH4
0002FUH20008Ool5000AOol01000FUIJEP000eYF00<007ooOol0;Goo000cOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUH0000:0005FUH01000FUH000000Woo00D005YFFUH005YF00D0
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF1`000UYF00<005YFFUH00UYF00<007ooOol0
1Woo1@004Woo0`000eYF00<007ooOol0;Goo000aOol30005FUH<0008FUH40007FUH00`00FUIoo`04
FUH30004Ool01000FUIJEP001EYF1@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000]JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001EYF0`000UYF00D0
05YFFUIJEP0000Uoo`<001Eoo`04001JEUYFFUH2000^Ool002moo`800003FUH0000000D00003FUH0
05YF00IJEP03001JEUYF00@00004FUH000000003FUH00`00FUIJEP03FUH00gooFUH00004FUH20007
Ool01000FUIJEP001EYF00<005YFFUH00UYF3P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001UYF00<005YF00000P000eYF00<007oo
Ool087oo00D005YF001JEP0002ioo`00;Woo100000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH015YF1@000UYF00<005YFFUH01UYF00@005YF000000Uoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20006FUH01000FUIJEUYF0P000UYF00<007ooOol08Goo0P0000=JEP00Ool0
;Goo000]Ool30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
0007FUH2000;Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YF
FUH015YF10008goo00<005YF0000;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH7000=Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000UYF0P0000=JEP00FUH01UYF00<005YFFUH010007Woo0`00;goo000]Ool20003FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01eYF00@005YF000000ioo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUHQ0008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH30006FUH0
0`00FUIJEP04FUH7000EOol200000eYF0000000_Ool002aoo`8000=JEPH000IJEP<000AJEP@0009J
EP03001JEUYF00MJEP04001JEUYFFUH2000<Ool01000FUIJEP001EYF00<005YFFUH01UYF2@002eYF
00<005YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF
100015YF00<005YFFUH01UYF00<005YFFUH00UYF5@000eYF0P00;goo000/Ool2000015YF00000000
15YF00<005YFFUH00UYF0P000UYF00<005YFFUH01UYF1@001UYF00<005YFFUH015YF0P002Woo00@0
05YFFUH000EJEP03001JEUYF00=JEP<000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEP0000@000IJEP03001JEUYF009JEP800003FUH00000008000AJEP<00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000`Ool002ao
o`03FUH00000009JEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUH00005
0002FUH00`00FUIJEP05FUH30008Ool01000FUIJEP001EYF00<005YF000010002UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10000UYF00<005YFFUH00UYF0`00
1EYF00@005YF0000009JEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2000`Ool002]oo`D00003FUH005YF00AJEP8000MJEP03001JEUYF00EJEP<000Ioo`@0
00IJEP03001JEUYF008000Ioo`04001JEUYF0005FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH000020004FUH;00000eYF
00000003Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00<Goo000[Ool500000eYF001JEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH2000=Ool2
0003FUH00`00FUIJEP03FUH20004Ool01000FUIJEP000eYF0P001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0P0000=JEP00FUH01EYF0P002Goo1`0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
03=oo`00:goo00D005YF001JEP00009JEP<000=JEP03001JEUYF00IJEP03001JEP000080015oo`80
0003FUH005YF00EJEP8000=oo`05001JEUYF001JEP020008FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF001J
EP03FUH2000BOolE000eOol002]oo`80009JEP03001JEUYF008000AJEP03001JEUYF00EJEP<000Eo
o`<000ioo`8000IJEP06001JEP00001oo`000UYF0P0000=JEP00FUH01eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000000AJEP8005ioo`00;7oo00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH010001goo
1@003goo0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
15YF00D005YF000005YF00<0061oo`00;7oo00@005YFFUIJEP80009JEP03001JEUYF00D000]oo`D0
015oo`800003FUH005YF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
06=oo`00;Goo00<005YFFUH020003goo1@004goo0P0015YF0`0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH015YF00@005YFFUH006Aoo`00;Woo0`001EYF00@005YF000000ioo`<001Ioo`03001JEUYF00@0
00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0065oo`00<7oo00<005YFFUH00eYF
00@005YFFUIJEP<002Eoo`@00003Ool005YF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000AJEP8005moo`00<Goo0P000UYF00<005YFFUH01EYF10008goo0P0000=oo`00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P001UYF0`00GGoo000cOol30008FUH00`00FUIJEP04000NOol3
0002Ool01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YFFUH005aoo`00=Goo0P00
1eYF00<005YFFUH015YF1@005goo100017oo0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP@000IJEP03
001JEUYF009JEP8005Yoo`00=goo0P0015YF00<005YFFUH01eYF00<005YFFUH010003Woo1@000UYF
0P001Woo0P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000Aoo`@0009JEP03001JEUYF00AJEP03001oogoo05Moo`00>Goo
0`0000=JEP00FUH025YF00<005YFFUH015YF3P000eYF00H005YFFUH005YF0007Ool30006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH4000:
Ool30006FUH2001HOol003aoo`<000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008000]oo`@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00D0011oo`8000AJEP03001JEP0005Moo`00?goo0`0015YF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00011oo`D000QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD00003Ool0000000<0015oo`04001JEUYF0003FUH0
0`00Oomoo`1DOol0049oo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EP00000FOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF1P001Woo1@004Woo
0`000eYF00<007ooOol0E7oo0015Ool60004FUH00`00FUIJEP05FUH01000FUIJEUYF1@007Woo7`00
37oo1@0057oo00@005YFFUIJEP8005Eoo`00Bgoo4000=Goo0P001UYF00@005YF000000ioo`<001Io
o`05001JEP00FUH0001EOol0095oo`03001JEUYF00AJEP04001JEUYFFUH2000VOol200000eYF001o
o`1DOol0099oo`8000=JEP03001JEUYF00AJEP@002=oo`03001JEP0005Eoo`00U7oo0P0000=JEP00
FUH01UYF00<005YFFUH010007Woo0`00EWoo002FOol30006FUH00`00FUIJEP04FUH7000EOol20000
0eYF0000001FOol009Uoo`8000AJEP03001JEUYF00IJEP03001JEUYF009JEPP000Qoo`D000=JEP80
05Ioo`00Vgoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPP000=JEP04001JEUYF
FUH2001GOol009ioo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001GOol00:5oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2001HOol00:Eoo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001J
Ool00:aoo`P000AJEP04001JEUYFFUH5001LOol00;Aoo`P0065oo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5931 .75334 m .60094 .6992 L .57009 .69288 L p .707 .577 .707 r
F P
0 g
s
.60094 .6992 m .5931 .75334 L .62465 .75656 L p .707 .577 .707 r
F P
0 g
s
.62465 .75656 m .6325 .70242 L .60094 .6992 L p .707 .577 .707 r
F P
0 g
s
.6325 .70242 m .62797 .73363 L p .6538 .75634 L .707 .577 .707 r
F P
0 g
s
.65178 .75636 m .6538 .75634 L p .62797 .73363 L .707 .577 .707 r
F P
0 g
s
.6538 .75634 m .66165 .7022 L .6325 .70242 L p .707 .577 .707 r
F P
0 g
s
.66165 .7022 m .6538 .75634 L .66979 .75392 L p .707 .577 .707 r
F P
0 g
s
.67747 .75197 m .66165 .7022 L .66979 .75392 L .707 .577 .707 r
F
.68556 .69858 m .66165 .7022 L p .67727 .75134 L F P
0 g
s
.67747 .75197 m .67753 .75158 L .67727 .75134 L .707 .577 .707 r
F
.67753 .75158 m .68556 .69858 L .67727 .75134 L F
.67783 .75188 m .68556 .69858 L p .67747 .75197 L F P
0 g
s
.69991 .77044 m .68237 .74979 L .67783 .75188 L .707 .577 .707 r
F
.67783 .75188 m .68366 .7789 L .69818 .77134 L p F P
0 g
s
.69818 .77134 m .69991 .77044 L p .67783 .75188 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .67783 .75188 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.68556 .69858 m .67783 .75188 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.70188 .69192 m .68556 .69858 L p .69353 .74324 L .707 .577 .707 r
F P
0 g
s
.69376 .74456 m .69389 .74376 L .69353 .74324 L .707 .577 .707 r
F
.69389 .74376 m .70188 .69192 L .69353 .74324 L F
.69991 .77044 m .70711 .76317 L p .70635 .76169 L F P
0 g
s
.69428 .74433 m .70188 .69192 L p .69389 .74376 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69389 .74376 L .69376 .74456 L .707 .577 .707 r
F
.70101 .75123 m .70119 .73626 L .69629 .74198 L F
.70635 .76169 m .70128 .73669 L .70101 .75123 L F
.70128 .73669 m .70119 .73626 L .70101 .75123 L F
.70117 .73627 m .70119 .73544 L .69428 .74433 L F
.70188 .69192 m .69843 .7157 L p .70119 .73544 L F P
0 g
s
.69843 .7157 m .69428 .74433 L p .70119 .73544 L .707 .577 .707 r
F P
0 g
s
.70711 .76317 m .70699 .7626 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70699 .7626 m .70129 .73614 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.70901 .68285 m .70188 .69192 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70901 .68285 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .69914 .72619 L p .70119 .73626 L .707 .577 .707 r
F P
0 g
s
.70129 .73614 m .70119 .73626 L .70635 .76169 L .707 .577 .707 r
F
.70116 .73699 m .70129 .73614 L p .70117 .73627 L F P
0 g
s
.70711 .76317 m .70455 .75778 L p .70324 .75011 L .707 .577 .707 r
F P
0 g
s
.70635 .76169 m .69629 .74198 L .69428 .74433 L .707 .577 .707 r
F
.69194 .73347 m .69428 .74433 L p .69629 .74198 L F P
0 g
s
.69428 .74433 m .69991 .77044 L p .70635 .76169 L .707 .577 .707 r
F P
0 g
s
.69991 .77044 m .69428 .74433 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .70102 .73717 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70102 .73717 m .70116 .73699 L p .70093 .73661 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70117 .73627 L .70093 .73661 L .707 .577 .707 r
F
.70119 .73626 m .69914 .72619 L .69629 .74198 L F
.69914 .72619 m .70129 .73614 L p .7005 .73413 L F P
0 g
s
.69914 .72619 m .69194 .73347 L p .69629 .74198 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69403 .74606 L p .70117 .73627 L .707 .577 .707 r
F P
0 g
s
.70116 .73699 m .70025 .73349 L p .70119 .73589 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .69914 .72619 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.70455 .75778 m .69816 .72813 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69816 .72813 m .69659 .7208 L p .70246 .74555 L .707 .577 .707 r
F P
0 g
s
.69428 .74433 m .69194 .73347 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69403 .74606 m .69428 .74433 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .69403 .74606 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67771 .75272 L p .69376 .74456 L .707 .577 .707 r
F P
0 g
s
.69659 .7208 m .70455 .75778 L .69249 .75481 L p .707 .577 .707 r
F P
0 g
s
.70626 .67228 m .69841 .72642 L .69755 .72565 L p .707 .577 .707 r
F P
0 g
s
.69194 .73347 m .67569 .74192 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.69249 .75481 m .68452 .71783 L .69659 .7208 L p .707 .577 .707 r
F P
0 g
s
.69755 .72565 m .68605 .71537 L p .69193 .70283 L .707 .577 .707 r
F P
0 g
s
.69193 .70283 m .70626 .67228 L .69755 .72565 L .707 .577 .707 r
F
.69841 .72642 m .70171 .71285 L .70119 .73589 L F
.70025 .73349 m .69841 .72642 L p .70119 .73589 L F P
0 g
s
.70129 .73614 m .70116 .73699 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.70324 .75011 m .7005 .73413 L .70129 .73614 L .707 .577 .707 r
F
.70129 .73614 m .70711 .76317 L p .70324 .75011 L F P
0 g
s
.70901 .68285 m .70129 .73614 L p .70171 .71285 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .67783 .75188 L p .68237 .74979 L .707 .577 .707 r
F P
0 g
s
.67569 .74192 m .65198 .75073 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67783 .75188 m .67569 .74192 L p .65873 .75674 L .707 .577 .707 r
F P
0 g
s
.67771 .75272 m .67783 .75188 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.66979 .75392 m .67771 .75272 L p .67747 .75197 L .707 .577 .707 r
F P
0 g
s
.68366 .7789 m .65873 .75674 L .65356 .75806 L .707 .577 .707 r
F
.65198 .75073 m .65356 .75806 L p .65873 .75674 L F P
0 g
s
.65356 .75806 m .65994 .7877 L .6777 .78111 L p .707 .577 .707 r
F P
0 g
s
.6777 .78111 m .68366 .7789 L p .65356 .75806 L .707 .577 .707 r
F P
0 g
s
.62797 .73363 m .62465 .75656 L .65178 .75636 L p .707 .577 .707 r
F P
0 g
s
.56224 .74702 m .57009 .69288 L .54295 .68407 L p .707 .577 .707 r
F P
0 g
s
.57009 .69288 m .56224 .74702 L .5931 .75334 L p .707 .577 .707 r
F P
0 g
s
.5351 .73821 m .54295 .68407 L .52218 .67363 L p .707 .577 .707 r
F P
0 g
s
.54295 .68407 m .5351 .73821 L .56224 .74702 L p .707 .577 .707 r
F P
0 g
s
.59992 .80296 m .59195 .76599 L .56152 .77095 L p .707 .577 .707 r
F P
0 g
s
.59195 .76599 m .59992 .80296 L .63109 .796 L p .707 .577 .707 r
F P
0 g
s
.63109 .796 m .62312 .75902 L .59195 .76599 L p .707 .577 .707 r
F P
0 g
s
.62312 .75902 m .63109 .796 L .65994 .7877 L p .707 .577 .707 r
F P
0 g
s
.65994 .7877 m .65198 .75073 L .62312 .75902 L p .707 .577 .707 r
F P
0 g
s
.56152 .77095 m .56948 .80792 L .59992 .80296 L p .707 .577 .707 r
F P
0 g
s
.56948 .80792 m .56152 .77095 L .5348 .77342 L p .707 .577 .707 r
F P
0 g
s
.5348 .77342 m .54276 .81039 L .56948 .80792 L p .707 .577 .707 r
F P
0 g
s
.52218 .67363 m .51433 .72777 L .5351 .73821 L p .707 .577 .707 r
F P
0 g
s
.59252 .85502 m .59462 .83685 L .56365 .83139 L p .707 .577 .707 r
F P
0 g
s
.59462 .83685 m .59252 .85502 L .62417 .85746 L p .707 .577 .707 r
F P
0 g
s
.62417 .85746 m .62627 .83928 L .59462 .83685 L p .707 .577 .707 r
F P
0 g
s
.51433 .72777 m .52218 .67363 L .50981 .66258 L p .707 .577 .707 r
F P
0 g
s
.62627 .83928 m .62417 .85746 L .65341 .85663 L p .707 .577 .707 r
F P
0 g
s
.65341 .85663 m .65551 .83845 L .62627 .83928 L p .707 .577 .707 r
F P
0 g
s
.56155 .84956 m .56365 .83139 L .5364 .82344 L p .707 .577 .707 r
F P
0 g
s
.56365 .83139 m .56155 .84956 L .59252 .85502 L p .707 .577 .707 r
F P
0 g
s
.54276 .81039 m .5348 .77342 L .51441 .77315 L p .707 .577 .707 r
F P
0 g
s
.5364 .82344 m .5343 .84161 L .56155 .84956 L p .707 .577 .707 r
F P
0 g
s
.51441 .77315 m .52238 .81013 L .54276 .81039 L p .707 .577 .707 r
F P
0 g
s
.65551 .83845 m .65341 .85663 L .67736 .85261 L p .707 .577 .707 r
F P
0 g
s
.67736 .85261 m .67947 .83444 L .65551 .83845 L p .707 .577 .707 r
F P
0 g
s
.50981 .66258 m .50196 .71672 L .51433 .72777 L p .707 .577 .707 r
F P
0 g
s
.5343 .84161 m .5364 .82344 L .51553 .81378 L p .707 .577 .707 r
F P
0 g
s
.51553 .81378 m .51342 .83195 L .5343 .84161 L p .707 .577 .707 r
F P
0 g
s
.50196 .71672 m .50981 .66258 L .50706 .652 L p .707 .577 .707 r
F P
0 g
s
.52238 .81013 m .51441 .77315 L .50235 .77018 L p .707 .577 .707 r
F P
0 g
s
.67947 .83444 m .67736 .85261 L .6937 .84581 L p .707 .577 .707 r
F P
0 g
s
.6937 .84581 m .6958 .82763 L .67947 .83444 L p .707 .577 .707 r
F P
0 g
s
.50235 .77018 m .51031 .80716 L .52238 .81013 L p .707 .577 .707 r
F P
0 g
s
.51342 .83195 m .51553 .81378 L .50308 .80334 L p .707 .577 .707 r
F P
0 g
s
.50706 .652 m .49921 .70614 L .50196 .71672 L p .707 .577 .707 r
F P
0 g
s
.50308 .80334 m .50098 .82152 L .51342 .83195 L p .707 .577 .707 r
F P
0 g
s
.69841 .72642 m .70626 .67228 L .70901 .68285 L p .707 .577 .707 r
F P
0 g
s
.49921 .70614 m .50706 .652 L .51419 .64294 L p .707 .577 .707 r
F P
0 g
s
.51031 .80716 m .50235 .77018 L .49979 .7648 L p .707 .577 .707 r
F P
0 g
s
.49321 .82176 m .48908 .31945 L .44507 .31713 L p .707 .577 .707 r
F P
0 g
s
.49979 .7648 m .50775 .80177 L .51031 .80716 L p .707 .577 .707 r
F P
0 g
s
.50098 .82152 m .50308 .80334 L .50028 .79317 L p .707 .577 .707 r
F P
0 g
s
.50028 .79317 m .49817 .81134 L .50098 .82152 L p .707 .577 .707 r
F P
0 g
s
.51419 .64294 m .50635 .69708 L .49921 .70614 L p .707 .577 .707 r
F P
0 g
s
.50635 .69708 m .51419 .64294 L .53051 .63627 L p .707 .577 .707 r
F P
0 g
s
.50775 .80177 m .49979 .7648 L .50699 .75752 L p .707 .577 .707 r
F P
0 g
s
.50699 .75752 m .51495 .79449 L .50775 .80177 L p .707 .577 .707 r
F P
0 g
s
.49817 .81134 m .50028 .79317 L .50739 .78424 L p .707 .577 .707 r
F P
0 g
s
.50739 .78424 m .50529 .80241 L .49817 .81134 L p .707 .577 .707 r
F P
0 g
s
.53051 .63627 m .52266 .69041 L .50635 .69708 L p .707 .577 .707 r
F P
0 g
s
.52266 .69041 m .53051 .63627 L .55442 .63265 L p .707 .577 .707 r
F P
0 g
s
.51495 .79449 m .50699 .75752 L .52324 .74906 L p .707 .577 .707 r
F P
0 g
s
.52324 .74906 m .53121 .78604 L .51495 .79449 L p .707 .577 .707 r
F P
0 g
s
.50529 .80241 m .50739 .78424 L .52373 .77743 L p .707 .577 .707 r
F P
0 g
s
.55442 .63265 m .54657 .68679 L .52266 .69041 L p .707 .577 .707 r
F P
0 g
s
.52373 .77743 m .52163 .79561 L .50529 .80241 L p .707 .577 .707 r
F P
0 g
s
.53121 .78604 m .52324 .74906 L .54696 .74026 L p .707 .577 .707 r
F P
0 g
s
.54696 .74026 m .55492 .77724 L .53121 .78604 L p .707 .577 .707 r
F P
0 g
s
.52163 .79561 m .52373 .77743 L .54769 .77342 L p .707 .577 .707 r
F P
0 g
s
.54769 .77342 m .54559 .79159 L .52163 .79561 L p .707 .577 .707 r
F P
0 g
s
.48908 .31945 m .49321 .82176 L .53815 .82033 L p .707 .577 .707 r
F P
0 g
s
.53815 .82033 m .53402 .31802 L .48908 .31945 L p .707 .577 .707 r
F P
0 g
s
.6958 .82763 m .6937 .84581 L .70082 .83688 L p .707 .577 .707 r
F P
0 g
s
.70082 .83688 m .70292 .81871 L .6958 .82763 L p .707 .577 .707 r
F P
0 g
s
.54657 .68679 m .55442 .63265 L .58358 .63244 L p .707 .577 .707 r
F P
0 g
s
.58358 .63244 m .57573 .68658 L .54657 .68679 L p .707 .577 .707 r
F P
0 g
s
.55492 .77724 m .54696 .74026 L .57581 .73197 L p .707 .577 .707 r
F P
0 g
s
.57581 .73197 m .58377 .76894 L .55492 .77724 L p .707 .577 .707 r
F P
0 g
s
.54559 .79159 m .54769 .77342 L .57692 .77259 L p .707 .577 .707 r
F P
0 g
s
.57692 .77259 m .57482 .79076 L .54559 .79159 L p .707 .577 .707 r
F P
0 g
s
.57482 .79076 m .57692 .77259 L .60858 .77502 L p .707 .577 .707 r
F P
0 g
s
.60858 .77502 m .60647 .79319 L .57482 .79076 L p .707 .577 .707 r
F P
0 g
s
.53402 .31802 m .53815 .82033 L .57963 .8153 L p .707 .577 .707 r
F P
0 g
s
.57573 .68658 m .58358 .63244 L .61513 .63565 L p .707 .577 .707 r
F P
0 g
s
.61513 .63565 m .60728 .68979 L .57573 .68658 L p .707 .577 .707 r
F P
0 g
s
.58377 .76894 m .57581 .73197 L .60698 .725 L p .707 .577 .707 r
F P
0 g
s
.57963 .8153 m .5755 .31298 L .53402 .31802 L p .707 .577 .707 r
F P
0 g
s
.4492 .81944 m .44507 .31713 L .40631 .3113 L p .707 .577 .707 r
F P
0 g
s
.44507 .31713 m .4492 .81944 L .49321 .82176 L p .707 .577 .707 r
F P
0 g
s
.61494 .76198 m .60698 .725 L .63741 .72004 L p .707 .577 .707 r
F P
0 g
s
.60698 .725 m .61494 .76198 L .58377 .76894 L p .707 .577 .707 r
F P
0 g
s
.63954 .78048 m .63744 .79865 L .60647 .79319 L p .707 .577 .707 r
F P
0 g
s
.60647 .79319 m .60858 .77502 L .63954 .78048 L p .707 .577 .707 r
F P
0 g
s
.5755 .31298 m .57963 .8153 L .61359 .80715 L p .707 .577 .707 r
F P
0 g
s
.64598 .64197 m .63813 .69611 L .60728 .68979 L p .707 .577 .707 r
F P
0 g
s
.60728 .68979 m .61513 .63565 L .64598 .64197 L p .707 .577 .707 r
F P
0 g
s
.61359 .80715 m .60946 .30484 L .5755 .31298 L p .707 .577 .707 r
F P
0 g
s
.68605 .71537 m .69389 .66123 L .70626 .67228 L p .707 .577 .707 r
F P
0 g
s
.25009 .71649 m .25794 .66235 L .22708 .65603 L p .707 .577 .707 r
F P
0 g
s
.25794 .66235 m .25009 .71649 L .28164 .7197 L p .707 .577 .707 r
F P
0 g
s
.28164 .7197 m .28949 .66556 L .25794 .66235 L p .707 .577 .707 r
F P
0 g
s
.41044 .81361 m .40631 .3113 L .37659 .30252 L p .707 .577 .707 r
F P
0 g
s
.40631 .3113 m .41044 .81361 L .4492 .81944 L p .707 .577 .707 r
F P
0 g
s
.70292 .81871 m .70082 .83688 L .69801 .8267 L p .707 .577 .707 r
F P
0 g
s
.69801 .8267 m .70012 .80853 L .70292 .81871 L p .707 .577 .707 r
F P
0 g
s
.28949 .66556 m .28495 .69686 L p .31079 .71949 L .707 .577 .707 r
F P
0 g
s
.30867 .71951 m .31079 .71949 L p .28495 .69686 L .707 .577 .707 r
F P
0 g
s
.31079 .71949 m .31864 .66535 L .28949 .66556 L p .707 .577 .707 r
F P
0 g
s
.31864 .66535 m .31079 .71949 L .32757 .71695 L p .707 .577 .707 r
F P
0 g
s
.33449 .71519 m .31864 .66535 L .32757 .71695 L .707 .577 .707 r
F
.34255 .66173 m .31864 .66535 L p .3343 .71462 L F P
0 g
s
.33449 .71519 m .33454 .71485 L .3343 .71462 L .707 .577 .707 r
F
.33454 .71485 m .34255 .66173 L .3343 .71462 L F
.33481 .71511 m .34255 .66173 L p .33449 .71519 L F P
0 g
s
.3569 .73373 m .33933 .71304 L .33481 .71511 L .707 .577 .707 r
F
.33481 .71511 m .34065 .74219 L .3552 .73462 L p F P
0 g
s
.3552 .73462 m .3569 .73373 L p .33481 .71511 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .33481 .71511 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.34255 .66173 m .33481 .71511 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35887 .65507 m .34255 .66173 L p .35054 .70653 L .707 .577 .707 r
F P
0 g
s
.35077 .70778 m .35089 .70702 L .35054 .70653 L .707 .577 .707 r
F
.35089 .70702 m .35887 .65507 L .35054 .70653 L F
.3569 .73373 m .3641 .72646 L p .36327 .72484 L F P
0 g
s
.35126 .70756 m .35887 .65507 L p .35089 .70702 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35089 .70702 L .35077 .70778 L .707 .577 .707 r
F
.35799 .71449 m .35816 .6995 L .35326 .70523 L F
.36327 .72484 m .35825 .69998 L .35799 .71449 L F
.35825 .69998 m .35816 .6995 L .35799 .71449 L F
.35816 .69949 m .35818 .69874 L .35126 .70756 L F
.35887 .65507 m .35541 .67893 L p .35818 .69874 L F P
0 g
s
.35541 .67893 m .35126 .70756 L p .35818 .69874 L .707 .577 .707 r
F P
0 g
s
.36345 .7251 m .36323 .72462 L .36327 .72484 L .707 .577 .707 r
F
.36396 .72583 m .36323 .72462 L .36345 .7251 L F
.366 .646 m .35887 .65507 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .35816 .6995 L .36323 .72462 L .707 .577 .707 r
F
.35815 .70014 m .35827 .69938 L p .35816 .69949 L F P
0 g
s
.35827 .69938 m .366 .646 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.36396 .72583 m .35827 .69938 L p .36323 .72462 L .707 .577 .707 r
F P
0 g
s
.35827 .69938 m .35613 .68948 L p .35816 .6995 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36396 .72583 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3641 .72646 m .36154 .72107 L p .3602 .71326 L .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .35126 .70756 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .3569 .73373 L p .36327 .72484 L .707 .577 .707 r
F P
0 g
s
.3569 .73373 m .35126 .70756 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35799 .70035 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35799 .70035 m .35815 .70014 L p .35791 .69984 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35816 .69949 L .35791 .69984 L .707 .577 .707 r
F
.35816 .6995 m .35613 .68948 L .35326 .70523 L F
.35613 .68948 m .35827 .69938 L p .35749 .69737 L F P
0 g
s
.35613 .68948 m .34893 .69676 L p .35326 .70523 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .35102 .70921 L p .35816 .69949 L .707 .577 .707 r
F P
0 g
s
.35815 .70014 m .35733 .69699 L p .35818 .69915 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .35613 .68948 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.36154 .72107 m .35514 .69136 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35514 .69136 m .35358 .68409 L p .35944 .70881 L .707 .577 .707 r
F P
0 g
s
.35126 .70756 m .34893 .69676 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.35102 .70921 m .35126 .70756 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .35102 .70921 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .3347 .71587 L p .35077 .70778 L .707 .577 .707 r
F P
0 g
s
.35358 .68409 m .36154 .72107 L .34948 .7181 L p .707 .577 .707 r
F P
0 g
s
.36325 .63543 m .3554 .68957 L .3545 .68876 L p .707 .577 .707 r
F P
0 g
s
.34893 .69676 m .33268 .70521 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.34948 .7181 m .34151 .68112 L .35358 .68409 L p .707 .577 .707 r
F P
0 g
s
.3545 .68876 m .34304 .67852 L p .3489 .66602 L .707 .577 .707 r
F P
0 g
s
.3489 .66602 m .36325 .63543 L .3545 .68876 L .707 .577 .707 r
F
.3554 .68957 m .35869 .67604 L .35818 .69915 L F
.35733 .69699 m .3554 .68957 L p .35818 .69915 L F P
0 g
s
.35827 .69938 m .35815 .70014 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.3602 .71326 m .35749 .69737 L .35827 .69938 L .707 .577 .707 r
F
.35827 .69938 m .3641 .72646 L p .3602 .71326 L F P
0 g
s
.366 .646 m .35827 .69938 L p .35869 .67604 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .33481 .71511 L p .33933 .71304 L .707 .577 .707 r
F P
0 g
s
.33268 .70521 m .30897 .71402 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.33481 .71511 m .33268 .70521 L p .31567 .71998 L .707 .577 .707 r
F P
0 g
s
.3347 .71587 m .33481 .71511 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.32757 .71695 m .3347 .71587 L p .33449 .71519 L .707 .577 .707 r
F P
0 g
s
.34065 .74219 m .31567 .71998 L .31053 .72129 L .707 .577 .707 r
F
.30897 .71402 m .31053 .72129 L p .31567 .71998 L F P
0 g
s
.31053 .72129 m .31693 .75099 L .33473 .74439 L p .707 .577 .707 r
F P
0 g
s
.33473 .74439 m .34065 .74219 L p .31053 .72129 L .707 .577 .707 r
F P
0 g
s
.28495 .69686 m .28164 .7197 L .30867 .71951 L p .707 .577 .707 r
F P
0 g
s
.21923 .71017 m .22708 .65603 L .19994 .64722 L p .707 .577 .707 r
F P
0 g
s
.22708 .65603 m .21923 .71017 L .25009 .71649 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69389 .66123 m .68605 .71537 L .66528 .70493 L p .707 .577 .707 r
F P
0 g
s
.66528 .70493 m .67312 .65079 L .69389 .66123 L p .707 .577 .707 r
F P
0 g
s
.63741 .72004 m .64538 .75701 L .61494 .76198 L p .707 .577 .707 r
F P
0 g
s
.60946 .30484 m .61359 .80715 L .6367 .79669 L p .707 .577 .707 r
F P
0 g
s
.6367 .79669 m .63257 .29438 L .60946 .30484 L p .707 .577 .707 r
F P
0 g
s
.19209 .70136 m .19994 .64722 L .17917 .63677 L p .707 .577 .707 r
F P
0 g
s
.19994 .64722 m .19209 .70136 L .21923 .71017 L p .707 .577 .707 r
F P
0 g
s
.25691 .76625 m .24895 .72928 L .21851 .73424 L p .707 .577 .707 r
F P
0 g
s
.24895 .72928 m .25691 .76625 L .28808 .75928 L p .707 .577 .707 r
F P
0 g
s
.28808 .75928 m .28011 .72231 L .24895 .72928 L p .707 .577 .707 r
F P
0 g
s
.28011 .72231 m .28808 .75928 L .31693 .75099 L p .707 .577 .707 r
F P
0 g
s
.31693 .75099 m .30897 .71402 L .28011 .72231 L p .707 .577 .707 r
F P
0 g
s
.21851 .73424 m .22648 .77121 L .25691 .76625 L p .707 .577 .707 r
F P
0 g
s
.22648 .77121 m .21851 .73424 L .19179 .73671 L p .707 .577 .707 r
F P
0 g
s
.70012 .80853 m .69801 .8267 L .68557 .81627 L p .707 .577 .707 r
F P
0 g
s
.68557 .81627 m .68767 .7981 L .70012 .80853 L p .707 .577 .707 r
F P
0 g
s
.38072 .80483 m .37659 .30252 L .35881 .29165 L p .707 .577 .707 r
F P
0 g
s
.37659 .30252 m .38072 .80483 L .41044 .81361 L p .707 .577 .707 r
F P
0 g
s
.19179 .73671 m .19976 .77368 L .22648 .77121 L p .707 .577 .707 r
F P
0 g
s
.17917 .63677 m .17132 .69091 L .19209 .70136 L p .707 .577 .707 r
F P
0 g
s
.68452 .71783 m .69249 .75481 L .6721 .75454 L p .707 .577 .707 r
F P
0 g
s
.6721 .75454 m .66413 .71757 L .68452 .71783 L p .707 .577 .707 r
F P
0 g
s
.24951 .81781 m .25161 .79963 L .22064 .79417 L p .707 .577 .707 r
F P
0 g
s
.25161 .79963 m .24951 .81781 L .28116 .82024 L p .707 .577 .707 r
F P
0 g
s
.28116 .82024 m .28326 .80207 L .25161 .79963 L p .707 .577 .707 r
F P
0 g
s
.67312 .65079 m .66528 .70493 L .63813 .69611 L p .707 .577 .707 r
F P
0 g
s
.63813 .69611 m .64598 .64197 L .67312 .65079 L p .707 .577 .707 r
F P
0 g
s
.17132 .69091 m .17917 .63677 L .1668 .62572 L p .707 .577 .707 r
F P
0 g
s
.28326 .80207 m .28116 .82024 L .3104 .81941 L p .707 .577 .707 r
F P
0 g
s
.3104 .81941 m .3125 .80123 L .28326 .80207 L p .707 .577 .707 r
F P
0 g
s
.21854 .81235 m .22064 .79417 L .19339 .78622 L p .707 .577 .707 r
F P
0 g
s
.22064 .79417 m .21854 .81235 L .24951 .81781 L p .707 .577 .707 r
F P
0 g
s
.19976 .77368 m .19179 .73671 L .1714 .73644 L p .707 .577 .707 r
F P
0 g
s
.19339 .78622 m .19129 .80439 L .21854 .81235 L p .707 .577 .707 r
F P
0 g
s
.1714 .73644 m .17937 .77342 L .19976 .77368 L p .707 .577 .707 r
F P
0 g
s
.66413 .71757 m .6721 .75454 L .64538 .75701 L p .707 .577 .707 r
F P
0 g
s
.64538 .75701 m .63741 .72004 L .66413 .71757 L p .707 .577 .707 r
F P
0 g
s
.63744 .79865 m .63954 .78048 L .6668 .78843 L p .707 .577 .707 r
F P
0 g
s
.63257 .29438 m .6367 .79669 L .6467 .78494 L p .707 .577 .707 r
F P
0 g
s
.6467 .78494 m .64257 .28263 L .63257 .29438 L p .707 .577 .707 r
F P
0 g
s
.3125 .80123 m .3104 .81941 L .33436 .81539 L p .707 .577 .707 r
F P
0 g
s
.33436 .81539 m .33646 .79722 L .3125 .80123 L p .707 .577 .707 r
F P
0 g
s
.1668 .62572 m .15895 .67987 L .17132 .69091 L p .707 .577 .707 r
F P
0 g
s
.68767 .7981 m .68557 .81627 L .6647 .8066 L p .707 .577 .707 r
F P
0 g
s
.6647 .8066 m .6668 .78843 L .68767 .7981 L p .707 .577 .707 r
F P
0 g
s
.19129 .80439 m .19339 .78622 L .17252 .77656 L p .707 .577 .707 r
F P
0 g
s
.17252 .77656 m .17041 .79473 L .19129 .80439 L p .707 .577 .707 r
F P
0 g
s
.15895 .67987 m .1668 .62572 L .16405 .61515 L p .707 .577 .707 r
F P
0 g
s
.17937 .77342 m .1714 .73644 L .15934 .73347 L p .707 .577 .707 r
F P
0 g
s
.3554 .68957 m .36325 .63543 L .366 .646 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .36325 .63543 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34304 .67852 m .34488 .66583 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.34488 .66583 m .35088 .62438 L p .34457 .67526 L .707 .577 .707 r
F P
0 g
s
.36294 .79396 m .35881 .29165 L .35472 .27976 L p .707 .577 .707 r
F P
0 g
s
.35881 .29165 m .36294 .79396 L .38072 .80483 L p .707 .577 .707 r
F P
0 g
s
.35781 .79966 m .35991 .78149 L .3528 .79042 L p .707 .577 .707 r
F P
0 g
s
.35991 .78149 m .35781 .79966 L .35501 .78948 L p .707 .577 .707 r
F P
0 g
s
.35501 .78948 m .35711 .77131 L .35991 .78149 L p .707 .577 .707 r
F P
0 g
s
.35472 .27976 m .35885 .78207 L .36294 .79396 L p .707 .577 .707 r
F P
0 g
s
.35885 .78207 m .35529 .34893 L p .36472 .26801 L .707 .577 .707 r
F P
0 g
s
.35529 .34893 m .35472 .27976 L .35768 .27628 L p .707 .577 .707 r
F P
0 g
s
.35768 .27628 m .36472 .26801 L p .35529 .34893 L .707 .577 .707 r
F P
0 g
s
.33646 .79722 m .33436 .81539 L .35069 .80859 L p .707 .577 .707 r
F P
0 g
s
.35069 .80859 m .3528 .79042 L .33646 .79722 L p .707 .577 .707 r
F P
0 g
s
.15934 .73347 m .1673 .77045 L .17937 .77342 L p .707 .577 .707 r
F P
0 g
s
.6668 .78843 m .6647 .8066 L .63744 .79865 L p .707 .577 .707 r
F P
0 g
s
.17041 .79473 m .17252 .77656 L .16007 .76613 L p .707 .577 .707 r
F P
0 g
s
.16405 .61515 m .1562 .66929 L .15895 .67987 L p .707 .577 .707 r
F P
0 g
s
.16007 .76613 m .15797 .7843 L .17041 .79473 L p .707 .577 .707 r
F P
0 g
s
.1562 .66929 m .16405 .61515 L .17118 .60609 L p .707 .577 .707 r
F P
0 g
s
.64257 .28263 m .6467 .78494 L .64261 .77305 L p .707 .577 .707 r
F P
0 g
s
.64261 .77305 m .63848 .27074 L .64257 .28263 L p .707 .577 .707 r
F P
0 g
s
.1673 .77045 m .15934 .73347 L .15678 .72808 L p .707 .577 .707 r
F P
0 g
s
.3528 .79042 m .35069 .80859 L .35781 .79966 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15678 .72808 m .16474 .76506 L .1673 .77045 L p .707 .577 .707 r
F P
0 g
s
.15797 .7843 m .16007 .76613 L .15727 .75595 L p .707 .577 .707 r
F P
0 g
s
.15727 .75595 m .15516 .77412 L .15797 .7843 L p .707 .577 .707 r
F P
0 g
s
.17118 .60609 m .16334 .66023 L .1562 .66929 L p .707 .577 .707 r
F P
0 g
s
.16334 .66023 m .17118 .60609 L .1875 .59942 L p .707 .577 .707 r
F P
0 g
s
.16474 .76506 m .15678 .72808 L .16398 .72081 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16398 .72081 m .17194 .75778 L .16474 .76506 L p .707 .577 .707 r
F P
0 g
s
.15516 .77412 m .15727 .75595 L .16438 .74702 L p .707 .577 .707 r
F P
0 g
s
.63848 .27074 m .64261 .77305 L .62483 .76219 L p .707 .577 .707 r
F P
0 g
s
.62483 .76219 m .6207 .25987 L .63848 .27074 L p .707 .577 .707 r
F P
0 g
s
.16438 .74702 m .16228 .76519 L .15516 .77412 L p .707 .577 .707 r
F P
0 g
s
.1875 .59942 m .17966 .65356 L .16334 .66023 L p .707 .577 .707 r
F P
0 g
s
.35088 .62438 m .34304 .67852 L .32227 .66807 L p .707 .577 .707 r
F P
0 g
s
.32227 .66807 m .33011 .61393 L .35088 .62438 L p .707 .577 .707 r
F P
0 g
s
.17966 .65356 m .1875 .59942 L .21141 .5958 L p .707 .577 .707 r
F P
0 g
s
.36885 .77032 m .36472 .26801 L .38783 .25755 L p .707 .577 .707 r
F P
0 g
s
.36472 .26801 m .36885 .77032 L .35885 .78207 L p .707 .577 .707 r
F P
0 g
s
.17194 .75778 m .16398 .72081 L .18023 .71235 L p .707 .577 .707 r
F P
0 g
s
.35711 .77131 m .35501 .78948 L .34256 .77905 L p .707 .577 .707 r
F P
0 g
s
.34256 .77905 m .34466 .76088 L .35711 .77131 L p .707 .577 .707 r
F P
0 g
s
.18023 .71235 m .1882 .74933 L .17194 .75778 L p .707 .577 .707 r
F P
0 g
s
.16228 .76519 m .16438 .74702 L .18072 .74022 L p .707 .577 .707 r
F P
0 g
s
.34151 .68112 m .34948 .7181 L .32909 .71783 L p .707 .577 .707 r
F P
0 g
s
.32909 .71783 m .32112 .68086 L .34151 .68112 L p .707 .577 .707 r
F P
0 g
s
.33011 .61393 m .32227 .66807 L .29512 .65926 L p .707 .577 .707 r
F P
0 g
s
.29512 .65926 m .30297 .60512 L .33011 .61393 L p .707 .577 .707 r
F P
0 g
s
.21141 .5958 m .20356 .64994 L .17966 .65356 L p .707 .577 .707 r
F P
0 g
s
.20356 .64994 m .21141 .5958 L .24057 .59559 L p .707 .577 .707 r
F P
0 g
s
.18072 .74022 m .17862 .75839 L .16228 .76519 L p .707 .577 .707 r
F P
0 g
s
.6207 .25987 m .62483 .76219 L .59511 .7534 L p .707 .577 .707 r
F P
0 g
s
.59511 .7534 m .59098 .25109 L .6207 .25987 L p .707 .577 .707 r
F P
0 g
s
.30297 .60512 m .29512 .65926 L .26427 .65294 L p .707 .577 .707 r
F P
0 g
s
.26427 .65294 m .27212 .5988 L .30297 .60512 L p .707 .577 .707 r
F P
0 g
s
.23272 .64973 m .24057 .59559 L .27212 .5988 L p .707 .577 .707 r
F P
0 g
s
.24057 .59559 m .23272 .64973 L .20356 .64994 L p .707 .577 .707 r
F P
0 g
s
.1882 .74933 m .18023 .71235 L .20395 .70355 L p .707 .577 .707 r
F P
0 g
s
.34466 .76088 m .34256 .77905 L .32169 .76939 L p .707 .577 .707 r
F P
0 g
s
.32169 .76939 m .32379 .75121 L .34466 .76088 L p .707 .577 .707 r
F P
0 g
s
.27212 .5988 m .26427 .65294 L .23272 .64973 L p .707 .577 .707 r
F P
0 g
s
.32112 .68086 m .32909 .71783 L .30237 .7203 L p .707 .577 .707 r
F P
0 g
s
.30237 .7203 m .2944 .68333 L .32112 .68086 L p .707 .577 .707 r
F P
0 g
s
.20395 .70355 m .21191 .74053 L .1882 .74933 L p .707 .577 .707 r
F P
0 g
s
.17862 .75839 m .18072 .74022 L .20468 .7362 L p .707 .577 .707 r
F P
0 g
s
.7303 .66131 m .73815 .60717 L .70729 .60084 L p .707 .577 .707 r
F P
0 g
s
.73815 .60717 m .7303 .66131 L .76185 .66452 L p .707 .577 .707 r
F P
0 g
s
.76185 .66452 m .7697 .61038 L .73815 .60717 L p .707 .577 .707 r
F P
0 g
s
.38783 .25755 m .39196 .75986 L .36885 .77032 L p .707 .577 .707 r
F P
0 g
s
.39196 .75986 m .38783 .25755 L .42179 .2494 L p .707 .577 .707 r
F P
0 g
s
.7697 .61038 m .76517 .64159 L p .79101 .6643 L .707 .577 .707 r
F P
0 g
s
.78898 .66432 m .79101 .6643 L p .76517 .64159 L .707 .577 .707 r
F P
0 g
s
.79101 .6643 m .79886 .61016 L .7697 .61038 L p .707 .577 .707 r
F P
0 g
s
.79886 .61016 m .79101 .6643 L .807 .66188 L p .707 .577 .707 r
F P
0 g
s
.81468 .65993 m .79886 .61016 L .807 .66188 L .707 .577 .707 r
F
.82276 .60655 m .79886 .61016 L p .81447 .6593 L F P
0 g
s
.81468 .65993 m .81473 .65955 L .81447 .6593 L .707 .577 .707 r
F
.81473 .65955 m .82276 .60655 L .81447 .6593 L F
.81504 .65984 m .82276 .60655 L p .81468 .65993 L F P
0 g
s
.83711 .67841 m .81958 .65775 L .81504 .65984 L .707 .577 .707 r
F
.81504 .65984 m .82086 .68686 L .83539 .6793 L p F P
0 g
s
.83539 .6793 m .83711 .67841 L p .81504 .65984 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .81504 .65984 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.82276 .60655 m .81504 .65984 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83908 .59988 m .82276 .60655 L p .83073 .6512 L .707 .577 .707 r
F P
0 g
s
.83097 .65253 m .83109 .65172 L .83073 .6512 L .707 .577 .707 r
F
.83109 .65172 m .83908 .59988 L .83073 .6512 L F
.83711 .67841 m .84431 .67113 L p .84356 .66966 L F P
0 g
s
.83149 .65229 m .83908 .59988 L p .83109 .65172 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83109 .65172 L .83097 .65253 L .707 .577 .707 r
F
.83821 .65919 m .83839 .64422 L .83349 .64994 L F
.84356 .66966 m .83848 .64466 L .83821 .65919 L F
.83848 .64466 m .83839 .64422 L .83821 .65919 L F
.83838 .64424 m .83839 .6434 L .83149 .65229 L F
.83908 .59988 m .83564 .62366 L p .83839 .6434 L F P
0 g
s
.83564 .62366 m .83149 .65229 L p .83839 .6434 L .707 .577 .707 r
F P
0 g
s
.84431 .67113 m .84419 .67056 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84419 .67056 m .83849 .64411 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.84622 .59081 m .83908 .59988 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .84622 .59081 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83635 .63415 L p .83839 .64422 L .707 .577 .707 r
F P
0 g
s
.83849 .64411 m .83839 .64422 L .84356 .66966 L .707 .577 .707 r
F
.83837 .64495 m .83849 .64411 L p .83838 .64424 L F P
0 g
s
.84431 .67113 m .84176 .66574 L p .84044 .65807 L .707 .577 .707 r
F P
0 g
s
.84356 .66966 m .83349 .64994 L .83149 .65229 L .707 .577 .707 r
F
.82915 .64143 m .83149 .65229 L p .83349 .64994 L F P
0 g
s
.83149 .65229 m .83711 .67841 L p .84356 .66966 L .707 .577 .707 r
F P
0 g
s
.83711 .67841 m .83149 .65229 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83823 .64513 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83823 .64513 m .83837 .64495 L p .83813 .64458 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83838 .64424 L .83813 .64458 L .707 .577 .707 r
F
.83839 .64422 m .83635 .63415 L .83349 .64994 L F
.83635 .63415 m .83849 .64411 L p .83771 .64209 L F P
0 g
s
.83635 .63415 m .82915 .64143 L p .83349 .64994 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .83124 .65402 L p .83838 .64424 L .707 .577 .707 r
F P
0 g
s
.83837 .64495 m .83746 .64145 L p .83839 .64385 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .83635 .63415 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.84176 .66574 m .83537 .63609 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83537 .63609 m .83379 .62876 L p .83966 .65351 L .707 .577 .707 r
F P
0 g
s
.83149 .65229 m .82915 .64143 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.83124 .65402 m .83149 .65229 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .83124 .65402 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .81492 .66069 L p .83097 .65253 L .707 .577 .707 r
F P
0 g
s
.83379 .62876 m .84176 .66574 L .82969 .66277 L p .707 .577 .707 r
F P
0 g
s
.84346 .58024 m .83562 .63438 L .83476 .63361 L p .707 .577 .707 r
F P
0 g
s
.82915 .64143 m .8129 .64988 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.82969 .66277 m .82173 .62579 L .83379 .62876 L p .707 .577 .707 r
F P
0 g
s
.83476 .63361 m .82325 .62333 L p .82913 .61079 L .707 .577 .707 r
F P
0 g
s
.82913 .61079 m .84346 .58024 L .83476 .63361 L .707 .577 .707 r
F
.83562 .63438 m .83892 .62081 L .83839 .64385 L F
.83746 .64145 m .83562 .63438 L p .83839 .64385 L F P
0 g
s
.83849 .64411 m .83837 .64495 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.84044 .65807 m .83771 .64209 L .83849 .64411 L .707 .577 .707 r
F
.83849 .64411 m .84431 .67113 L p .84044 .65807 L F P
0 g
s
.84622 .59081 m .83849 .64411 L p .83892 .62081 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .81504 .65984 L p .81958 .65775 L .707 .577 .707 r
F P
0 g
s
.8129 .64988 m .78918 .65869 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81504 .65984 m .8129 .64988 L p .79594 .6647 L .707 .577 .707 r
F P
0 g
s
.81492 .66069 m .81504 .65984 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.807 .66188 m .81492 .66069 L p .81468 .65993 L .707 .577 .707 r
F P
0 g
s
.82086 .68686 m .79594 .6647 L .79076 .66602 L .707 .577 .707 r
F
.78918 .65869 m .79076 .66602 L p .79594 .6647 L F P
0 g
s
.79076 .66602 m .79715 .69567 L .81491 .68907 L p .707 .577 .707 r
F P
0 g
s
.81491 .68907 m .82086 .68686 L p .79076 .66602 L .707 .577 .707 r
F P
0 g
s
.76517 .64159 m .76185 .66452 L .78898 .66432 L p .707 .577 .707 r
F P
0 g
s
.20468 .7362 m .20258 .75437 L .17862 .75839 L p .707 .577 .707 r
F P
0 g
s
.69945 .65498 m .70729 .60084 L .68015 .59203 L p .707 .577 .707 r
F P
0 g
s
.70729 .60084 m .69945 .65498 L .7303 .66131 L p .707 .577 .707 r
F P
0 g
s
.21191 .74053 m .20395 .70355 L .2328 .69526 L p .707 .577 .707 r
F P
0 g
s
.2944 .68333 m .30237 .7203 L .27193 .72527 L p .707 .577 .707 r
F P
0 g
s
.27193 .72527 m .26397 .68829 L .2944 .68333 L p .707 .577 .707 r
F P
0 g
s
.32379 .75121 m .32169 .76939 L .29443 .76144 L p .707 .577 .707 r
F P
0 g
s
.29443 .76144 m .29653 .74326 L .32379 .75121 L p .707 .577 .707 r
F P
0 g
s
.59098 .25109 m .59511 .7534 L .55635 .74757 L p .707 .577 .707 r
F P
0 g
s
.55635 .74757 m .55221 .24526 L .59098 .25109 L p .707 .577 .707 r
F P
0 g
s
.2328 .69526 m .24076 .73223 L .21191 .74053 L p .707 .577 .707 r
F P
0 g
s
.6723 .64617 m .68015 .59203 L .65938 .58159 L p .707 .577 .707 r
F P
0 g
s
.68015 .59203 m .6723 .64617 L .69945 .65498 L p .707 .577 .707 r
F P
0 g
s
.20258 .75437 m .20468 .7362 L .23391 .73537 L p .707 .577 .707 r
F P
0 g
s
.73712 .71092 m .72916 .67395 L .69872 .67891 L p .707 .577 .707 r
F P
0 g
s
.72916 .67395 m .73712 .71092 L .76829 .70396 L p .707 .577 .707 r
F P
0 g
s
.76829 .70396 m .76033 .66698 L .72916 .67395 L p .707 .577 .707 r
F P
0 g
s
.24076 .73223 m .2328 .69526 L .26397 .68829 L p .707 .577 .707 r
F P
0 g
s
.76033 .66698 m .76829 .70396 L .79715 .69567 L p .707 .577 .707 r
F P
0 g
s
.79715 .69567 m .78918 .65869 L .76033 .66698 L p .707 .577 .707 r
F P
0 g
s
.26397 .68829 m .27193 .72527 L .24076 .73223 L p .707 .577 .707 r
F P
0 g
s
.23391 .73537 m .23181 .75354 L .20258 .75437 L p .707 .577 .707 r
F P
0 g
s
.42592 .75172 m .42179 .2494 L .46327 .24437 L p .707 .577 .707 r
F P
0 g
s
.42179 .2494 m .42592 .75172 L .39196 .75986 L p .707 .577 .707 r
F P
0 g
s
.69872 .67891 m .70669 .71589 L .73712 .71092 L p .707 .577 .707 r
F P
0 g
s
.70669 .71589 m .69872 .67891 L .672 .68138 L p .707 .577 .707 r
F P
0 g
s
.29653 .74326 m .29443 .76144 L .26346 .75598 L p .707 .577 .707 r
F P
0 g
s
.26346 .75598 m .26557 .7378 L .29653 .74326 L p .707 .577 .707 r
F P
0 g
s
.23181 .75354 m .23391 .73537 L .26557 .7378 L p .707 .577 .707 r
F P
0 g
s
.26557 .7378 m .26346 .75598 L .23181 .75354 L p .707 .577 .707 r
F P
0 g
s
.672 .68138 m .67997 .71836 L .70669 .71589 L p .707 .577 .707 r
F P
0 g
s
.65938 .58159 m .65153 .63573 L .6723 .64617 L p .707 .577 .707 r
F P
0 g
s
.55221 .24526 m .55635 .74757 L .51234 .74525 L p .707 .577 .707 r
F P
0 g
s
.51234 .74525 m .50821 .24294 L .55221 .24526 L p .707 .577 .707 r
F P
0 g
s
.72972 .76298 m .73182 .74481 L .70086 .73935 L p .707 .577 .707 r
F P
0 g
s
.73182 .74481 m .72972 .76298 L .76137 .76542 L p .707 .577 .707 r
F P
0 g
s
.76137 .76542 m .76348 .74725 L .73182 .74481 L p .707 .577 .707 r
F P
0 g
s
.65153 .63573 m .65938 .58159 L .64701 .57054 L p .707 .577 .707 r
F P
0 g
s
.76348 .74725 m .76137 .76542 L .79061 .76459 L p .707 .577 .707 r
F P
0 g
s
.79061 .76459 m .79271 .74641 L .76348 .74725 L p .707 .577 .707 r
F P
0 g
s
.4674 .74668 m .46327 .24437 L .50821 .24294 L p .707 .577 .707 r
F P
0 g
s
.46327 .24437 m .4674 .74668 L .42592 .75172 L p .707 .577 .707 r
F P
0 g
s
.69875 .75753 m .70086 .73935 L .6736 .7314 L p .707 .577 .707 r
F P
0 g
s
.70086 .73935 m .69875 .75753 L .72972 .76298 L p .707 .577 .707 r
F P
0 g
s
.67997 .71836 m .672 .68138 L .65161 .68112 L p .707 .577 .707 r
F P
0 g
s
.50821 .24294 m .51234 .74525 L .4674 .74668 L p .707 .577 .707 r
F P
0 g
s
.6736 .7314 m .6715 .74957 L .69875 .75753 L p .707 .577 .707 r
F P
0 g
s
.65161 .68112 m .65958 .71809 L .67997 .71836 L p .707 .577 .707 r
F P
0 g
s
.79271 .74641 m .79061 .76459 L .81457 .76057 L p .707 .577 .707 r
F P
0 g
s
.81457 .76057 m .81667 .7424 L .79271 .74641 L p .707 .577 .707 r
F P
0 g
s
.64701 .57054 m .63917 .62468 L .65153 .63573 L p .707 .577 .707 r
F P
0 g
s
.6715 .74957 m .6736 .7314 L .65273 .72174 L p .707 .577 .707 r
F P
0 g
s
.65273 .72174 m .65063 .73991 L .6715 .74957 L p .707 .577 .707 r
F P
0 g
s
.63917 .62468 m .64701 .57054 L .64426 .55996 L p .707 .577 .707 r
F P
0 g
s
.65958 .71809 m .65161 .68112 L .63955 .67815 L p .707 .577 .707 r
F P
0 g
s
.81667 .7424 m .81457 .76057 L .83091 .75377 L p .707 .577 .707 r
F P
0 g
s
.83091 .75377 m .83301 .7356 L .81667 .7424 L p .707 .577 .707 r
F P
0 g
s
.63955 .67815 m .64752 .71512 L .65958 .71809 L p .707 .577 .707 r
F P
0 g
s
.65063 .73991 m .65273 .72174 L .64028 .71131 L p .707 .577 .707 r
F P
0 g
s
.64426 .55996 m .63642 .6141 L .63917 .62468 L p .707 .577 .707 r
F P
0 g
s
.64028 .71131 m .63818 .72948 L .65063 .73991 L p .707 .577 .707 r
F P
0 g
s
.83562 .63438 m .84346 .58024 L .84622 .59081 L p .707 .577 .707 r
F P
0 g
s
.63642 .6141 m .64426 .55996 L .6514 .5509 L p .707 .577 .707 r
F P
0 g
s
.64752 .71512 m .63955 .67815 L .63699 .67276 L p .707 .577 .707 r
F P
0 g
s
.83301 .7356 m .83091 .75377 L .83802 .74484 L p .707 .577 .707 r
F P
0 g
s
.83802 .74484 m .84012 .72667 L .83301 .7356 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63699 .67276 m .64496 .70973 L .64752 .71512 L p .707 .577 .707 r
F P
0 g
s
.63818 .72948 m .64028 .71131 L .63748 .70113 L p .707 .577 .707 r
F P
0 g
s
.63748 .70113 m .63538 .7193 L .63818 .72948 L p .707 .577 .707 r
F P
0 g
s
.6514 .5509 m .64355 .60504 L .63642 .6141 L p .707 .577 .707 r
F P
0 g
s
.82325 .62333 m .8311 .56919 L .84346 .58024 L p .707 .577 .707 r
F P
0 g
s
.64355 .60504 m .6514 .5509 L .66772 .54423 L p .707 .577 .707 r
F P
0 g
s
.38729 .62445 m .39514 .57031 L .36428 .56399 L p .707 .577 .707 r
F P
0 g
s
.39514 .57031 m .38729 .62445 L .41884 .62767 L p .707 .577 .707 r
F P
0 g
s
.41884 .62767 m .42669 .57353 L .39514 .57031 L p .707 .577 .707 r
F P
0 g
s
.64496 .70973 m .63699 .67276 L .64419 .66548 L p .707 .577 .707 r
F P
0 g
s
.84012 .72667 m .83802 .74484 L .83522 .73466 L p .707 .577 .707 r
F P
0 g
s
.83522 .73466 m .83732 .71649 L .84012 .72667 L p .707 .577 .707 r
F P
0 g
s
.42669 .57353 m .42215 .60483 L p .448 .62745 L .707 .577 .707 r
F P
0 g
s
.44587 .62747 m .448 .62745 L p .42215 .60483 L .707 .577 .707 r
F P
0 g
s
.448 .62745 m .45585 .57331 L .42669 .57353 L p .707 .577 .707 r
F P
0 g
s
.45585 .57331 m .448 .62745 L .46477 .62491 L p .707 .577 .707 r
F P
0 g
s
.47169 .62315 m .45585 .57331 L .46477 .62491 L .707 .577 .707 r
F
.47975 .56969 m .45585 .57331 L p .47151 .62258 L F P
0 g
s
.47169 .62315 m .47174 .62281 L .47151 .62258 L .707 .577 .707 r
F
.47174 .62281 m .47975 .56969 L .47151 .62258 L F
.47202 .62307 m .47975 .56969 L p .47169 .62315 L F P
0 g
s
.4941 .6417 m .47653 .621 L .47202 .62307 L .707 .577 .707 r
F
.47202 .62307 m .47785 .65015 L .49241 .64258 L p F P
0 g
s
.49241 .64258 m .4941 .6417 L p .47202 .62307 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .47202 .62307 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47975 .56969 m .47202 .62307 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49607 .56303 m .47975 .56969 L p .48775 .61449 L .707 .577 .707 r
F P
0 g
s
.48797 .61575 m .48809 .61498 L .48775 .61449 L .707 .577 .707 r
F
.48809 .61498 m .49607 .56303 L .48775 .61449 L F
.4941 .6417 m .5013 .63442 L p .50047 .6328 L F P
0 g
s
.48846 .61552 m .49607 .56303 L p .48809 .61498 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48809 .61498 L .48797 .61575 L .707 .577 .707 r
F
.49519 .62245 m .49536 .60746 L .49046 .61319 L F
.50047 .6328 m .49546 .60795 L .49519 .62245 L F
.49546 .60795 m .49536 .60746 L .49519 .62245 L F
.49537 .60746 m .49538 .6067 L .48846 .61552 L F
.49607 .56303 m .49261 .58689 L p .49538 .6067 L F P
0 g
s
.49261 .58689 m .48846 .61552 L p .49538 .6067 L .707 .577 .707 r
F P
0 g
s
.50066 .63306 m .50043 .63258 L .50047 .6328 L .707 .577 .707 r
F
.50117 .63379 m .50043 .63258 L .50066 .63306 L F
.50321 .55396 m .49607 .56303 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .49536 .60746 L .50043 .63258 L .707 .577 .707 r
F
.49536 .6081 m .49547 .60734 L p .49537 .60746 L F P
0 g
s
.49547 .60734 m .50321 .55396 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.50117 .63379 m .49547 .60734 L p .50043 .63258 L .707 .577 .707 r
F P
0 g
s
.49547 .60734 m .49334 .59744 L p .49536 .60746 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .50117 .63379 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.5013 .63442 m .49874 .62903 L p .49741 .62122 L .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .48846 .61552 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .4941 .6417 L p .50047 .6328 L .707 .577 .707 r
F P
0 g
s
.4941 .6417 m .48846 .61552 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .4952 .60831 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.4952 .60831 m .49536 .6081 L p .49511 .6078 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49537 .60746 L .49511 .6078 L .707 .577 .707 r
F
.49536 .60746 m .49334 .59744 L .49046 .61319 L F
.49334 .59744 m .49547 .60734 L p .49469 .60534 L F P
0 g
s
.49334 .59744 m .48614 .60472 L p .49046 .61319 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48823 .61717 L p .49537 .60746 L .707 .577 .707 r
F P
0 g
s
.49536 .6081 m .49454 .60495 L p .49538 .60711 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49334 .59744 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49874 .62903 m .49235 .59933 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.49235 .59933 m .49078 .59205 L p .49665 .61677 L .707 .577 .707 r
F P
0 g
s
.48846 .61552 m .48614 .60472 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48823 .61717 m .48846 .61552 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .48823 .61717 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .47191 .62383 L p .48797 .61575 L .707 .577 .707 r
F P
0 g
s
.49078 .59205 m .49874 .62903 L .48668 .62606 L p .707 .577 .707 r
F P
0 g
s
.50045 .54339 m .49261 .59753 L .4917 .59672 L p .707 .577 .707 r
F P
0 g
s
.48614 .60472 m .46989 .61317 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.48668 .62606 m .47872 .58908 L .49078 .59205 L p .707 .577 .707 r
F P
0 g
s
.4917 .59672 m .48024 .58648 L p .4861 .57399 L .707 .577 .707 r
F P
0 g
s
.4861 .57399 m .50045 .54339 L .4917 .59672 L .707 .577 .707 r
F
.49261 .59753 m .4959 .584 L .49538 .60711 L F
.49454 .60495 m .49261 .59753 L p .49538 .60711 L F P
0 g
s
.49547 .60734 m .49536 .6081 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.49741 .62122 m .49469 .60534 L .49547 .60734 L .707 .577 .707 r
F
.49547 .60734 m .5013 .63442 L p .49741 .62122 L F P
0 g
s
.50321 .55396 m .49547 .60734 L p .4959 .584 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .47202 .62307 L p .47653 .621 L .707 .577 .707 r
F P
0 g
s
.46989 .61317 m .44617 .62198 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47202 .62307 m .46989 .61317 L p .45288 .62794 L .707 .577 .707 r
F P
0 g
s
.47191 .62383 m .47202 .62307 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.46477 .62491 m .47191 .62383 L p .47169 .62315 L .707 .577 .707 r
F P
0 g
s
.47785 .65015 m .45288 .62794 L .44774 .62925 L .707 .577 .707 r
F
.44617 .62198 m .44774 .62925 L p .45288 .62794 L F P
0 g
s
.44774 .62925 m .45414 .65895 L .47193 .65235 L p .707 .577 .707 r
F P
0 g
s
.47193 .65235 m .47785 .65015 L p .44774 .62925 L .707 .577 .707 r
F P
0 g
s
.42215 .60483 m .41884 .62767 L .44587 .62747 L p .707 .577 .707 r
F P
0 g
s
.35644 .61813 m .36428 .56399 L .33714 .55518 L p .707 .577 .707 r
F P
0 g
s
.36428 .56399 m .35644 .61813 L .38729 .62445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64419 .66548 m .65216 .70246 L .64496 .70973 L p .707 .577 .707 r
F P
0 g
s
.63538 .7193 m .63748 .70113 L .6446 .6922 L p .707 .577 .707 r
F P
0 g
s
.6446 .6922 m .64249 .71037 L .63538 .7193 L p .707 .577 .707 r
F P
0 g
s
.66772 .54423 m .65987 .59837 L .64355 .60504 L p .707 .577 .707 r
F P
0 g
s
.8311 .56919 m .82325 .62333 L .80248 .61289 L p .707 .577 .707 r
F P
0 g
s
.80248 .61289 m .81033 .55875 L .8311 .56919 L p .707 .577 .707 r
F P
0 g
s
.32929 .60932 m .33714 .55518 L .31637 .54474 L p .707 .577 .707 r
F P
0 g
s
.33714 .55518 m .32929 .60932 L .35644 .61813 L p .707 .577 .707 r
F P
0 g
s
.39411 .67421 m .38615 .63724 L .35571 .6422 L p .707 .577 .707 r
F P
0 g
s
.38615 .63724 m .39411 .67421 L .42528 .66725 L p .707 .577 .707 r
F P
0 g
s
.42528 .66725 m .41732 .63027 L .38615 .63724 L p .707 .577 .707 r
F P
0 g
s
.65987 .59837 m .66772 .54423 L .69162 .54061 L p .707 .577 .707 r
F P
0 g
s
.41732 .63027 m .42528 .66725 L .45414 .65895 L p .707 .577 .707 r
F P
0 g
s
.45414 .65895 m .44617 .62198 L .41732 .63027 L p .707 .577 .707 r
F P
0 g
s
.35571 .6422 m .36368 .67918 L .39411 .67421 L p .707 .577 .707 r
F P
0 g
s
.36368 .67918 m .35571 .6422 L .32899 .64467 L p .707 .577 .707 r
F P
0 g
s
.65216 .70246 m .64419 .66548 L .66045 .65702 L p .707 .577 .707 r
F P
0 g
s
.83732 .71649 m .83522 .73466 L .82277 .72423 L p .707 .577 .707 r
F P
0 g
s
.82277 .72423 m .82488 .70606 L .83732 .71649 L p .707 .577 .707 r
F P
0 g
s
.32899 .64467 m .33696 .68165 L .36368 .67918 L p .707 .577 .707 r
F P
0 g
s
.31637 .54474 m .30852 .59888 L .32929 .60932 L p .707 .577 .707 r
F P
0 g
s
.66045 .65702 m .66841 .694 L .65216 .70246 L p .707 .577 .707 r
F P
0 g
s
.64249 .71037 m .6446 .6922 L .66093 .68539 L p .707 .577 .707 r
F P
0 g
s
.82173 .62579 m .82969 .66277 L .8093 .66251 L p .707 .577 .707 r
F P
0 g
s
.8093 .66251 m .80134 .62553 L .82173 .62579 L p .707 .577 .707 r
F P
0 g
s
.38671 .72577 m .38881 .70759 L .35785 .70213 L p .707 .577 .707 r
F P
0 g
s
.38881 .70759 m .38671 .72577 L .41836 .7282 L p .707 .577 .707 r
F P
0 g
s
.41836 .7282 m .42047 .71003 L .38881 .70759 L p .707 .577 .707 r
F P
0 g
s
.81033 .55875 m .80248 .61289 L .77534 .60407 L p .707 .577 .707 r
F P
0 g
s
.77534 .60407 m .78319 .54993 L .81033 .55875 L p .707 .577 .707 r
F P
0 g
s
.30852 .59888 m .31637 .54474 L .304 .53369 L p .707 .577 .707 r
F P
0 g
s
.69162 .54061 m .68378 .59475 L .65987 .59837 L p .707 .577 .707 r
F P
0 g
s
.68378 .59475 m .69162 .54061 L .72078 .5404 L p .707 .577 .707 r
F P
0 g
s
.42047 .71003 m .41836 .7282 L .4476 .72737 L p .707 .577 .707 r
F P
0 g
s
.4476 .72737 m .4497 .7092 L .42047 .71003 L p .707 .577 .707 r
F P
0 g
s
.66093 .68539 m .65883 .70357 L .64249 .71037 L p .707 .577 .707 r
F P
0 g
s
.35574 .72031 m .35785 .70213 L .33059 .69418 L p .707 .577 .707 r
F P
0 g
s
.35785 .70213 m .35574 .72031 L .38671 .72577 L p .707 .577 .707 r
F P
0 g
s
.33696 .68165 m .32899 .64467 L .3086 .64441 L p .707 .577 .707 r
F P
0 g
s
.33059 .69418 m .32849 .71236 L .35574 .72031 L p .707 .577 .707 r
F P
0 g
s
.3086 .64441 m .31657 .68138 L .33696 .68165 L p .707 .577 .707 r
F P
0 g
s
.78319 .54993 m .77534 .60407 L .74448 .59775 L p .707 .577 .707 r
F P
0 g
s
.74448 .59775 m .75233 .54361 L .78319 .54993 L p .707 .577 .707 r
F P
0 g
s
.71293 .59454 m .72078 .5404 L .75233 .54361 L p .707 .577 .707 r
F P
0 g
s
.72078 .5404 m .71293 .59454 L .68378 .59475 L p .707 .577 .707 r
F P
0 g
s
.4497 .7092 m .4476 .72737 L .47156 .72336 L p .707 .577 .707 r
F P
0 g
s
.47156 .72336 m .47366 .70518 L .4497 .7092 L p .707 .577 .707 r
F P
0 g
s
.66841 .694 m .66045 .65702 L .68416 .64822 L p .707 .577 .707 r
F P
0 g
s
.304 .53369 m .29616 .58783 L .30852 .59888 L p .707 .577 .707 r
F P
0 g
s
.82488 .70606 m .82277 .72423 L .8019 .71457 L p .707 .577 .707 r
F P
0 g
s
.8019 .71457 m .804 .69639 L .82488 .70606 L p .707 .577 .707 r
F P
0 g
s
.32849 .71236 m .33059 .69418 L .30972 .68452 L p .707 .577 .707 r
F P
0 g
s
.75233 .54361 m .74448 .59775 L .71293 .59454 L p .707 .577 .707 r
F P
0 g
s
.80134 .62553 m .8093 .66251 L .78258 .66498 L p .707 .577 .707 r
F P
0 g
s
.78258 .66498 m .77462 .628 L .80134 .62553 L p .707 .577 .707 r
F P
0 g
s
.68416 .64822 m .69212 .6852 L .66841 .694 L p .707 .577 .707 r
F P
0 g
s
.65883 .70357 m .66093 .68539 L .68489 .68138 L p .707 .577 .707 r
F P
0 g
s
.30972 .68452 m .30762 .70269 L .32849 .71236 L p .707 .577 .707 r
F P
0 g
s
.29616 .58783 m .304 .53369 L .30125 .52311 L p .707 .577 .707 r
F P
0 g
s
.68489 .68138 m .68279 .69955 L .65883 .70357 L p .707 .577 .707 r
F P
0 g
s
.31657 .68138 m .3086 .64441 L .29654 .64143 L p .707 .577 .707 r
F P
0 g
s
.69212 .6852 m .68416 .64822 L .71301 .63993 L p .707 .577 .707 r
F P
0 g
s
.47366 .70518 m .47156 .72336 L .4879 .71655 L p .707 .577 .707 r
F P
0 g
s
.4879 .71655 m .49 .69838 L .47366 .70518 L p .707 .577 .707 r
F P
0 g
s
.29654 .64143 m .30451 .67841 L .31657 .68138 L p .707 .577 .707 r
F P
0 g
s
.77462 .628 m .78258 .66498 L .75215 .66994 L p .707 .577 .707 r
F P
0 g
s
.75215 .66994 m .74418 .63296 L .77462 .628 L p .707 .577 .707 r
F P
0 g
s
.804 .69639 m .8019 .71457 L .77465 .70662 L p .707 .577 .707 r
F P
0 g
s
.77465 .70662 m .77675 .68844 L .804 .69639 L p .707 .577 .707 r
F P
0 g
s
.30762 .70269 m .30972 .68452 L .29727 .67409 L p .707 .577 .707 r
F P
0 g
s
.71301 .63993 m .72098 .67691 L .69212 .6852 L p .707 .577 .707 r
F P
0 g
s
.68279 .69955 m .68489 .68138 L .71413 .68055 L p .707 .577 .707 r
F P
0 g
s
.30125 .52311 m .29341 .57725 L .29616 .58783 L p .707 .577 .707 r
F P
0 g
s
.72098 .67691 m .71301 .63993 L .74418 .63296 L p .707 .577 .707 r
F P
0 g
s
.29727 .67409 m .29517 .69226 L .30762 .70269 L p .707 .577 .707 r
F P
0 g
s
.74418 .63296 m .75215 .66994 L .72098 .67691 L p .707 .577 .707 r
F P
0 g
s
.71413 .68055 m .71203 .69872 L .68279 .69955 L p .707 .577 .707 r
F P
0 g
s
.49261 .59753 m .50045 .54339 L .50321 .55396 L p .707 .577 .707 r
F P
0 g
s
.77675 .68844 m .77465 .70662 L .74368 .70116 L p .707 .577 .707 r
F P
0 g
s
.74368 .70116 m .74578 .68298 L .77675 .68844 L p .707 .577 .707 r
F P
0 g
s
.29341 .57725 m .30125 .52311 L .30839 .51405 L p .707 .577 .707 r
F P
0 g
s
.71203 .69872 m .71413 .68055 L .74578 .68298 L p .707 .577 .707 r
F P
0 g
s
.30451 .67841 m .29654 .64143 L .29398 .63605 L p .707 .577 .707 r
F P
0 g
s
.74578 .68298 m .74368 .70116 L .71203 .69872 L p .707 .577 .707 r
F P
0 g
s
.49 .69838 m .4879 .71655 L .49501 .70762 L p .707 .577 .707 r
F P
0 g
s
.49501 .70762 m .49711 .68945 L .49 .69838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29398 .63605 m .30195 .67302 L .30451 .67841 L p .707 .577 .707 r
F P
0 g
s
.29517 .69226 m .29727 .67409 L .29447 .66391 L p .707 .577 .707 r
F P
0 g
s
.29447 .66391 m .29237 .68208 L .29517 .69226 L p .707 .577 .707 r
F P
0 g
s
.30839 .51405 m .30054 .56819 L .29341 .57725 L p .707 .577 .707 r
F P
0 g
s
.48024 .58648 m .48809 .53234 L .50045 .54339 L p .707 .577 .707 r
F P
0 g
s
.30054 .56819 m .30839 .51405 L .32471 .50738 L p .707 .577 .707 r
F P
0 g
s
.30195 .67302 m .29398 .63605 L .30118 .62877 L p .707 .577 .707 r
F P
0 g
s
.49711 .68945 m .49501 .70762 L .49221 .69745 L p .707 .577 .707 r
F P
0 g
s
.49221 .69745 m .49431 .67927 L .49711 .68945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30118 .62877 m .30915 .66575 L .30195 .67302 L p .707 .577 .707 r
F P
0 g
s
.29237 .68208 m .29447 .66391 L .30159 .65498 L p .707 .577 .707 r
F P
0 g
s
.30159 .65498 m .29948 .67315 L .29237 .68208 L p .707 .577 .707 r
F P
0 g
s
.32471 .50738 m .31686 .56152 L .30054 .56819 L p .707 .577 .707 r
F P
0 g
s
.48809 .53234 m .48024 .58648 L .45947 .57604 L p .707 .577 .707 r
F P
0 g
s
.45947 .57604 m .46732 .5219 L .48809 .53234 L p .707 .577 .707 r
F P
0 g
s
.31686 .56152 m .32471 .50738 L .34861 .50376 L p .707 .577 .707 r
F P
0 g
s
.30915 .66575 m .30118 .62877 L .31744 .62031 L p .707 .577 .707 r
F P
0 g
s
.49431 .67927 m .49221 .69745 L .47976 .68701 L p .707 .577 .707 r
F P
0 g
s
.47976 .68701 m .48186 .66884 L .49431 .67927 L p .707 .577 .707 r
F P
0 g
s
.31744 .62031 m .3254 .65729 L .30915 .66575 L p .707 .577 .707 r
F P
0 g
s
.29948 .67315 m .30159 .65498 L .31792 .64818 L p .707 .577 .707 r
F P
0 g
s
.47872 .58908 m .48668 .62606 L .46629 .6258 L p .707 .577 .707 r
F P
0 g
s
.46629 .6258 m .45833 .58882 L .47872 .58908 L p .707 .577 .707 r
F P
0 g
s
.46732 .5219 m .45947 .57604 L .43233 .56722 L p .707 .577 .707 r
F P
0 g
s
.43233 .56722 m .44018 .51308 L .46732 .5219 L p .707 .577 .707 r
F P
0 g
s
.34861 .50376 m .34077 .5579 L .31686 .56152 L p .707 .577 .707 r
F P
0 g
s
.34077 .5579 m .34861 .50376 L .37777 .50355 L p .707 .577 .707 r
F P
0 g
s
.31792 .64818 m .31582 .66635 L .29948 .67315 L p .707 .577 .707 r
F P
0 g
s
.44018 .51308 m .43233 .56722 L .40147 .5609 L p .707 .577 .707 r
F P
0 g
s
.40147 .5609 m .40932 .50676 L .44018 .51308 L p .707 .577 .707 r
F P
0 g
s
.36992 .55769 m .37777 .50355 L .40932 .50676 L p .707 .577 .707 r
F P
0 g
s
.37777 .50355 m .36992 .55769 L .34077 .5579 L p .707 .577 .707 r
F P
0 g
s
.3254 .65729 m .31744 .62031 L .34115 .61151 L p .707 .577 .707 r
F P
0 g
s
.48186 .66884 m .47976 .68701 L .45889 .67735 L p .707 .577 .707 r
F P
0 g
s
.45889 .67735 m .46099 .65918 L .48186 .66884 L p .707 .577 .707 r
F P
0 g
s
.40932 .50676 m .40147 .5609 L .36992 .55769 L p .707 .577 .707 r
F P
0 g
s
.45833 .58882 m .46629 .6258 L .43957 .62827 L p .707 .577 .707 r
F P
0 g
s
.43957 .62827 m .43161 .59129 L .45833 .58882 L p .707 .577 .707 r
F P
0 g
s
.34115 .61151 m .34911 .64849 L .3254 .65729 L p .707 .577 .707 r
F P
0 g
s
.31582 .66635 m .31792 .64818 L .34188 .64416 L p .707 .577 .707 r
F P
0 g
s
.34188 .64416 m .33978 .66234 L .31582 .66635 L p .707 .577 .707 r
F P
0 g
s
.34911 .64849 m .34115 .61151 L .37 .60322 L p .707 .577 .707 r
F P
0 g
s
.43161 .59129 m .43957 .62827 L .40914 .63323 L p .707 .577 .707 r
F P
0 g
s
.40914 .63323 m .40117 .59625 L .43161 .59129 L p .707 .577 .707 r
F P
0 g
s
.46099 .65918 m .45889 .67735 L .43164 .6694 L p .707 .577 .707 r
F P
0 g
s
.43164 .6694 m .43374 .65122 L .46099 .65918 L p .707 .577 .707 r
F P
0 g
s
.37 .60322 m .37797 .64019 L .34911 .64849 L p .707 .577 .707 r
F P
0 g
s
.33978 .66234 m .34188 .64416 L .37112 .64333 L p .707 .577 .707 r
F P
0 g
s
.37797 .64019 m .37 .60322 L .40117 .59625 L p .707 .577 .707 r
F P
0 g
s
.40117 .59625 m .40914 .63323 L .37797 .64019 L p .707 .577 .707 r
F P
0 g
s
.37112 .64333 m .36902 .6615 L .33978 .66234 L p .707 .577 .707 r
F P
0 g
s
.43374 .65122 m .43164 .6694 L .40067 .66394 L p .707 .577 .707 r
F P
0 g
s
.40067 .66394 m .40277 .64576 L .43374 .65122 L p .707 .577 .707 r
F P
0 g
s
.36902 .6615 m .37112 .64333 L .40277 .64576 L p .707 .577 .707 r
F P
0 g
s
.40277 .64576 m .40067 .66394 L .36902 .6615 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001POol@0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol005]oo`D000=JEP03001JEUYF00EJEP03001JEUYF
009JEPT000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00FGoo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8006Ioo`00Egoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol005Ioo`8000AJEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Eoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<007ooOol0I7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ao
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool@001<Ool005Aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20005Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70015Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003Ool00000009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP@003eoo`00E7oo
00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YF00000`00>Goo001DOol20004FUH01000FUIJEUYF4000
15YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00T005YFFUIJEP00FUH005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`00=Woo001DOol20003
FUH500000eYF001JEP02FUH30002FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH3000dOol005=oo`04001JEP00FUH20006FUH00`00FUIJEP04FUH40004FUH50000
0eYF000000020002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P00
<Woo001COol01P00FUH00000FUH000EJEP03001JEUYF00IJEP03001JEUYF00T000EJEP@000IJEP03
001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000`Ool005=oo`<0009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF0P00;goo001COol20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH30003FUH>0005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH2000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo001COol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00D0
05YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000]Ool005Aoo`04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Goo001DOol01000FUIJEP001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF2`000UYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP03
FUH01000FUH005YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000iOol@000=Ool20005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP030003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00
FUIJEUYF001JEP0002aoo`00=7oo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`001goo00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH20003FUH50002FUH00`00FUIJEP03FUH40004Ool90004FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0002aoo`00<Woo0P0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH0100017oo0P000eYF00<005YFFUH01UYF1P001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00EJ
EP03001JEP0000<00003Ool0000000<000=oo`H000IJEP03001JEUYF00=JEP07001JEUYFFUH005YF
0000;7oo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40002Ool200000eYF001JEP04FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00=JEPL000Qoo`8000AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002moo`8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000H00004FUH0
00000006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF0`000UYF3@0000=JEP00FUH015YF00@0
05YFFUIJEP8002eoo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF1@002EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYF0005FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P00;Goo000^Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF009JEP8002eoo`00;Woo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF0`0015YF0P00;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP04001JEUYF0003FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0P001EYF2P000eYF00<005YF0000;Goo000]
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005
FUH80003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUIJEP001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1`000eYF00<005YFFUH0
0eYF0P000UYF00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10001UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P0000=JEP00Ool0;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00FUH0
15YF00<005YFFUH01EYF00<005YFFUH01EYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH01UYF0P001UYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo0P000eYF00<005YFFUH01EYF00<0
05YF00001@0015YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEP0015YF00<005YFFUH015YF00@005YFFUIJEPP000UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30003Ool200000eYF001JEP06FUH200000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJ
EP03001JEUYF00P000=JEP03001JEUYF009JEPL0009JEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF00000003Ool30003FUH30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002eoo`8000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04
0007FUH00`00FUIJEP04FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003FUH30003Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo000]Ool20003FUH500000eYF001JEP040009
Ool60006FUH200001UYF00000000FUH000IJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00AJEP@000=JEP8000=JEP8000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002aoo`04001JEP00FUH20006FUH00`00
FUIJEP03FUH50004Ool500000goo000000020002FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000400000eYF0000000<FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH20005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo000/Ool01P00FUH00000FUH000IJEP03001JEUYF00EJEP03001JEUYF00T000Eoo`D000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@0
00aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP80
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEUYFFUH0000]Ool002aoo`<0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00AJEPL000Eoo`03001JEP0000=JEP04001JEUYFFUHG0006FUH00`00FUIJEP06FUH3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0002FUH00`00
Oomoo`0[Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP<000=J
EPH00003FUH005YF009JEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF009JEPT000AJEP03001JEUYF00=JEP<002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P0000=JEP00FUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=JEP0000000P001UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF1`001eYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF00000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP8002ioo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEPH00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF
00QJEP03001JEUYF00AJEP<000EJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEPD000UJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Goo00@005YF
FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@00003FUH00000018000EJ
EP<000MJEP03001JEUYF00MJEP8000=JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP00009JEQ4000UJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00;Woo00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF100015YF00@005YFFUH000EJEP04001J
EP00FUH200000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH300000eYF001JEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0002FUH40003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP05
FUH01000FUH00000<7oo000_Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH80003FUH00`00
FUIJEP02FUH40005FUH00`00FUIJEP0300000eYF001JEP04FUH50006FUH00`00FUIJEP08FUH00`00
FUIJEP020003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60004
FUH01000FUIJEUYF1@00<Woo000`Ool00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020005FUH00`00FUH0000200000eYF
001JEP04FUH50006FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP04001JEP00000g
Ool0035oo`8000=JEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF00IJEP04001JEUYF
0005FUH20003FUH00`00FUIJEP0200000eYF001JEP05FUH30007FUH00`00FUIJEP08FUH00`00FUIJ
EP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF1000>Goo000cOol200000eYF001JEP06FUH300000eYF001JEP08FUH00`00FUIJ
EP05FUH40005FUH00`00FUH000030002FUH200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH>0004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH3000gOol003Eoo`<000=JEP<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP04001J
EUYF0005FUH00`00FUIJEP03FUH60006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEUYF
0P0000=JEP00000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000AJEP03001JEP0000<000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEP00
008003Aoo`00>7oo0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00MJEPD000=JEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH30003FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60006FUH00`00FUIJEP02FUH2000bOol0
03Eoo`<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003
FUH005YF00IJEP03001JEUYF00AJEQL000=JEP07001JEUYFFUH005YF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040006Ool20003FUH00`00FUIJEP04FUH2000aOol0039oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20005
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`000UYF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF1`0037oo0P0000=JEP00FUH01EYF00<005YF
0000<7oo000`Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH01P0000=JEP00FUH015YF00@005YFFUIJEPP000Aoo`<000ioo`<000AJ
EP05001JEUYFFUH0000_Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00AJEQ<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020000
0eYF0000000<000015YF001JEP001goo1@0047oo0`0000=JEP00FUH00UYF00<007ooOol0;Goo000]
Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1@002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF
0P0000=JEP00FUH015YF00<005YFFUH00P0000=JEP00Ool01Woo1@004goo0P000eYF0P00;Woo000]
Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF1`0015YF00<005YFFUH00UYF200000=JEP00FUH0
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001J
EP00008000AJEP04001JEUYFFUH20008Ool5000EOol00`00FUIJEP02000^Ool002aoo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP090009FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00P002Goo0`005goo1000;Woo000/Ool01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF10002EYF00<005YFFUH01EYF0P001UYF00@005YFFUIJEP<00003
FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEP000080009J
EP8002Eoo`8002ioo`00;7oo00@005YFFUH000AJEP03001JEUYF01L0009JEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYF0002Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0006FUH01000FUIJEUYF1@0097oo0`00;Woo000]Ool00`00FUH00002FUH50003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP04FUH30003Ool00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH6000NOol300000eYF001oo`0]
Ool002eoo`03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEP@000=JEP03001JEUYF009JEP<000Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000000=JEP03001JEUYF00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP00
02ioo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YF0000100000=JEP00000027oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
0eYF300000=JEP00FUH02UYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0P0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8002moo`00;Goo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH00eYF0`002Goo00<005YF00001UYF00<005YFFUH01UYF200035YF00<005YFFUH02EYF00<005YF
FUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF0`001UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<0
05YF00000eYF00@005YFFUIJEQL000IJEP03001JEUYF00IJEP<000Moo`03001JEP0000IJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@0
00IJEP03001JEUYF009JEP8000AJEPP0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000`Ool002aoo`03001JEP0000=JEP@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF008000Eo
o`03001JEP0000IJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEPH000AJEP04001JEUYFFUH70004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Woo000/Ool01000FUH005YF
0`0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0100000=oo`0000000P001UYF00<0
05YFFUH00eYF00<007ooOol00Woo00<005YF00001EYF0`000eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF100015YF0P000UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YF00000Woo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPD003Ao
o`00;7oo00@005YF0000009JEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00AJEPD000Uo
o`@0009JEP03001JEUYF00=JEP8000=oo`03001JEP0000=JEP8000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH2
0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;Ool@000iOol002aoo`@000=JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00@0019oo`<000EJEP09001JEP00001oo`00FUH0
05YF00<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00
;7oo0P0000=JEP0000001@000UYF00<005YFFUH00UYF1P001Goo0`004Goo0P000eYF00@005YFFUIJ
EP800003FUH00000009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`1DOol002aoo`03001JEUYF009JEP03001oogoo009oo`L0
00Yoo`D0019oo`800003FUH005YF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EP000002FUH00`00FUIJEP05FUH01000FUH00000Egoo000/Ool00`00FUIJEP02FUH3000COol5000D
Ool20003FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH0
15YF0P00FGoo000/Ool00`00FUIJEP02FUH00`00FUIJEP02000AOol5000FOol01000FUH005YF0P00
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH01000Fgoo000/
Ool01@00FUIJEUYF00001EYF0P0047oo0`0067oo0P0000=JEP00000015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH00eYF00D005YFFUH005YF00D005moo`00;Goo0P0000=JEP00FUH015YF00<005YF00000`00
9goo0P0000=JEP00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001EYF0`00GWoo
000_Ool20005FUH00`00FUIJEP03FUH5000POol200001EYF000007oo000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P001eYF00<005YF00000P00Fgoo000aOol20003FUH00`00FUIJEP05FUH00`00
FUIJEP04000GOol50003FUH20002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH0
0`00FUIJEP02FUH2001IOol003=oo`800003FUH005YF00IJEP03001JEUYF00AJEPL000Uoo`L000=J
EP07001JEUYFFUH005YF000017oo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEPD000EJEP03001JEUYF00AJEP8005Qo
o`00=Goo0`001UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000eYF00<005YFFUH015YF00@005YF
FUIJEP8000Moo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP04001JEP000005Ool400000eYF001JEP05FUH01000FUH00000EWoo000h
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00
FUIJEUYF00002Woo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF10002goo0P001EYF00<005YFFUH00UYF00<007ooOol0Dgoo000lOol4
0006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH000003Goo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01P0047oo
0P000eYF00<005YFFUH00UYF00<007ooOol0Dgoo0010Ool40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1@004Woo100025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF1@000Woo1@004Goo0P0000=JEP00FUH00eYF00<007ooOol0Dgoo0014Ool70004FUH00`00FUIJ
EP02FUH8000KOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01000FUIJEUYF1P001goo1@00
4goo0P000eYF0P00EGoo001;Ool9000YOolO000=Ool5000EOol00`00FUIJEP02001EOol008moo`03
001JEP0000EJEP<0011oo`<001Moo`@005Eoo`00T7oo0P001UYF00<005YF00000`009goo0`00EGoo
002AOol00`00FUIJEP04FUH00`00FUIJEP03FUH7000NOol5001EOol0099oo`8000=JEP03001JEUYF
00IJEP03001JEUYF009JEPT0011oo`D0009JEP03001JEP0005Eoo`00U7oo0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF40000eYF00@005YFFUIJEP8005Ioo`00UWoo0`001UYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Io
o`00VGoo10000UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8005Moo`00WGoo1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YF000005Uoo`00XWoo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD005]oo`00YWoo5`00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59852 .74498 m .59068 .68916 L .55982 .69174 L p .707 .577 .707 r
F P
0 g
s
.59068 .68916 m .59852 .74498 L .63007 .74015 L p .707 .577 .707 r
F P
0 g
s
.63007 .74015 m .62223 .68433 L .59068 .68916 L p .707 .577 .707 r
F P
0 g
s
.62223 .68433 m .63007 .74015 L .65923 .73356 L p .707 .577 .707 r
F P
0 g
s
.65923 .73356 m .65138 .67774 L .62223 .68433 L p .707 .577 .707 r
F P
0 g
s
.56767 .74757 m .55982 .69174 L .53268 .69184 L p .707 .577 .707 r
F P
0 g
s
.55982 .69174 m .56767 .74757 L .59852 .74498 L p .707 .577 .707 r
F P
0 g
s
.65138 .67774 m .65923 .73356 L .68314 .72585 L p .707 .577 .707 r
F P
0 g
s
.68314 .72585 m .67529 .67002 L .65138 .67774 L p .707 .577 .707 r
F P
0 g
s
.53268 .69184 m .54053 .74767 L .56767 .74757 L p .707 .577 .707 r
F P
0 g
s
.59086 .81566 m .59882 .78039 L .56839 .77179 L p .707 .577 .707 r
F P
0 g
s
.59882 .78039 m .59086 .81566 L .62203 .82093 L p .707 .577 .707 r
F P
0 g
s
.62203 .82093 m .62999 .78566 L .59882 .78039 L p .707 .577 .707 r
F P
0 g
s
.54053 .74767 m .53268 .69184 L .51191 .68944 L p .707 .577 .707 r
F P
0 g
s
.56043 .80706 m .56839 .77179 L .54167 .76069 L p .707 .577 .707 r
F P
0 g
s
.56839 .77179 m .56043 .80706 L .59086 .81566 L p .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .65811 .81958 L .63785 .82371 L p .707 .577 .707 r
F P
0 g
s
.63785 .82371 m .62888 .82554 L p .63467 .82788 L .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .63785 .82371 L .63467 .82788 L .707 .577 .707 r
F
.65811 .81958 m .66022 .8382 L .68418 .8309 L p F P
0 g
s
.68418 .8309 m .68207 .81227 L .66657 .817 L p .707 .577 .707 r
F P
0 g
s
.66657 .817 m .65811 .81958 L p .6635 .82192 L .707 .577 .707 r
F P
0 g
s
.68418 .8309 m .66657 .817 L .6635 .82192 L .707 .577 .707 r
F
.68207 .81227 m .68418 .8309 L .70051 .82296 L p F P
0 g
s
.70051 .82296 m .69841 .80434 L .68893 .80894 L p .707 .577 .707 r
F P
0 g
s
.68893 .80894 m .68207 .81227 L p .68672 .81497 L .707 .577 .707 r
F P
0 g
s
.70051 .82296 m .68893 .80894 L .68672 .81497 L .707 .577 .707 r
F
.69085 .81348 m .69805 .80405 L p .69869 .78235 L F P
0 g
s
.69881 .77821 m .69658 .78811 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.69658 .78811 m .69085 .81348 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .69085 .81348 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68256 .78452 m .68015 .79521 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68015 .79521 m .6746 .81978 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .6746 .81978 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65885 .78709 m .65591 .80008 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65591 .80008 m .65088 .82235 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.62999 .78566 m .62203 .82093 L .65088 .82235 L p .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .65885 .78709 L .62999 .78566 L p .707 .577 .707 r
F P
0 g
s
.67529 .67002 m .68314 .72585 L .69946 .71777 L p .707 .577 .707 r
F P
0 g
s
.69946 .71777 m .69161 .66194 L .67529 .67002 L p .707 .577 .707 r
F P
0 g
s
.59933 .84819 m .59723 .82957 L .56626 .83127 L p .707 .577 .707 r
F P
0 g
s
.59723 .82957 m .59933 .84819 L .63098 .84416 L p .707 .577 .707 r
F P
0 g
s
.63098 .84416 m .62888 .82554 L .59723 .82957 L p .707 .577 .707 r
F P
0 g
s
.51191 .68944 m .51976 .74526 L .54053 .74767 L p .707 .577 .707 r
F P
0 g
s
.62888 .82554 m .63098 .84416 L .66022 .8382 L p .707 .577 .707 r
F P
0 g
s
.54167 .76069 m .53371 .79596 L .56043 .80706 L p .707 .577 .707 r
F P
0 g
s
.53371 .79596 m .54167 .76069 L .52128 .74819 L p .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .68256 .78452 L .65885 .78709 L p .707 .577 .707 r
F P
0 g
s
.56626 .83127 m .56836 .84989 L .59933 .84819 L p .707 .577 .707 r
F P
0 g
s
.56836 .84989 m .56626 .83127 L .539 .83048 L p .707 .577 .707 r
F P
0 g
s
.539 .83048 m .54111 .8491 L .56836 .84989 L p .707 .577 .707 r
F P
0 g
s
.51976 .74526 m .51191 .68944 L .49954 .68477 L p .707 .577 .707 r
F P
0 g
s
.52128 .74819 m .51332 .78346 L .53371 .79596 L p .707 .577 .707 r
F P
0 g
s
.69161 .66194 m .69946 .71777 L .70659 .71011 L p .707 .577 .707 r
F P
0 g
s
.70659 .71011 m .69874 .65429 L .69161 .66194 L p .707 .577 .707 r
F P
0 g
s
.54111 .8491 m .539 .83048 L .51813 .82727 L p .707 .577 .707 r
F P
0 g
s
.49954 .68477 m .50739 .74059 L .50829 .74093 L p .707 .577 .707 r
F P
0 g
s
.5139 .72772 m .49954 .68477 L .50829 .74093 L .707 .577 .707 r
F
.50739 .74059 m .49954 .68477 L .49679 .67829 L p F P
0 g
s
.50739 .74059 m .5041 .72125 L .50453 .73332 L .707 .577 .707 r
F
.50335 .75258 m .50724 .74125 L .50531 .7356 L F
.50546 .73605 m .50739 .74059 L p .50453 .73332 L F P
0 g
s
.4987 .75915 m .50125 .77078 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50666 .72389 m .50453 .73332 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .4987 .75915 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50453 .73332 L p .5041 .72125 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50393 .67063 L p .50462 .73214 L .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50666 .72389 L p .50531 .7356 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .50666 .72389 L p .50581 .73175 L .707 .577 .707 r
F P
0 g
s
.50463 .73363 m .50464 .73411 L .50546 .73605 L p .707 .577 .707 r
F P
0 g
s
.50464 .73411 m .50453 .73332 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50724 .74125 m .50922 .73551 L .50531 .7356 L .707 .577 .707 r
F
.51177 .72646 m .50464 .73411 L p .50463 .7332 L F P
0 g
s
.50666 .72389 m .51386 .71446 L p .50954 .7272 L .707 .577 .707 r
F P
0 g
s
.50581 .73175 m .50666 .72389 L .50954 .7272 L .707 .577 .707 r
F
.51153 .72476 m .51177 .72646 L p .50463 .7332 L F P
0 g
s
.50125 .77078 m .50765 .74244 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.50765 .74244 m .50922 .73551 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .4987 .75915 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .51153 .72476 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .5059 .74973 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .53011 .70815 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51177 .72646 m .51153 .72476 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.50829 .74093 m .51976 .74526 L p .5139 .72772 L .707 .577 .707 r
F P
0 g
s
.51332 .78346 m .52128 .74819 L .50922 .73551 L p .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50125 .77078 L .51332 .78346 L p .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .51386 .71446 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .51177 .72646 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .52798 .71759 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .52798 .71759 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52809 .71838 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .5059 .74973 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52215 .74342 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .51153 .72476 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51203 .72455 m .51153 .72476 L .51225 .72285 L .707 .577 .707 r
F
.50393 .67063 m .52024 .66256 L p .51225 .72285 L F P
0 g
s
.51153 .72476 m .50393 .67063 L p .51225 .72285 L .707 .577 .707 r
F P
0 g
s
.50393 .67063 m .51153 .72476 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50481 .74114 m .50581 .73175 L .50954 .7272 L .707 .577 .707 r
F
.50453 .73332 m .50581 .73175 L .50481 .74114 L F
.50463 .7332 m .50453 .73332 L .50462 .73214 L F
.50453 .73332 m .49679 .67829 L p .50462 .73214 L F P
0 g
s
.4987 .75915 m .50453 .73332 L p .50481 .74114 L .707 .577 .707 r
F P
0 g
s
.69085 .81348 m .69881 .77821 L .68256 .78452 L p .707 .577 .707 r
F P
0 g
s
.51813 .82727 m .52023 .8459 L .54111 .8491 L p .707 .577 .707 r
F P
0 g
s
.52023 .8459 m .51813 .82727 L .50569 .82197 L p .707 .577 .707 r
F P
0 g
s
.69805 .80405 m .70601 .76879 L .69881 .77821 L p .707 .577 .707 r
F P
0 g
s
.50569 .82197 m .50779 .84059 L .52023 .8459 L p .707 .577 .707 r
F P
0 g
s
.69874 .65429 m .70659 .71011 L .70384 .70364 L p .707 .577 .707 r
F P
0 g
s
.70384 .70364 m .69599 .64781 L .69874 .65429 L p .707 .577 .707 r
F P
0 g
s
.69841 .80434 m .70051 .82296 L .70763 .81517 L p .707 .577 .707 r
F P
0 g
s
.70763 .81517 m .70553 .79654 L .69841 .80434 L p .707 .577 .707 r
F P
0 g
s
.48766 .8219 m .49179 .32047 L .44778 .31742 L p .707 .577 .707 r
F P
0 g
s
.50779 .84059 m .50569 .82197 L .50288 .81508 L p .707 .577 .707 r
F P
0 g
s
.50288 .81508 m .50499 .83371 L .50779 .84059 L p .707 .577 .707 r
F P
0 g
s
.50499 .83371 m .50288 .81508 L .51 .80729 L p .707 .577 .707 r
F P
0 g
s
.51 .80729 m .5121 .82591 L .50499 .83371 L p .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .55383 .70559 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .52798 .71759 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .53011 .70815 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.55383 .70559 m .55226 .71252 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.54415 .65484 m .552 .71067 L .53522 .71608 L p .707 .577 .707 r
F P
0 g
s
.53522 .71608 m .52809 .71838 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52831 .71752 m .54415 .65484 L .53522 .71608 L .707 .577 .707 r
F
.54586 .74085 m .52215 .74342 L p .54712 .71359 L F P
0 g
s
.55226 .71252 m .54586 .74085 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .52798 .71759 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .54415 .65484 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52024 .66256 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.5121 .82591 m .51 .80729 L .52634 .79935 L p .707 .577 .707 r
F P
0 g
s
.52634 .79935 m .52844 .81798 L .5121 .82591 L p .707 .577 .707 r
F P
0 g
s
.52844 .81798 m .52634 .79935 L .55029 .79205 L p .707 .577 .707 r
F P
0 g
s
.55029 .79205 m .5524 .81067 L .52844 .81798 L p .707 .577 .707 r
F P
0 g
s
.49179 .32047 m .48766 .8219 L .5326 .82113 L p .707 .577 .707 r
F P
0 g
s
.5326 .82113 m .53673 .3197 L .49179 .32047 L p .707 .577 .707 r
F P
0 g
s
.552 .71067 m .54415 .65484 L .57331 .64825 L p .707 .577 .707 r
F P
0 g
s
.54586 .74085 m .55383 .70559 L .58268 .70701 L p .707 .577 .707 r
F P
0 g
s
.57331 .64825 m .58115 .70407 L .552 .71067 L p .707 .577 .707 r
F P
0 g
s
.58268 .70701 m .57471 .74227 L .54586 .74085 L p .707 .577 .707 r
F P
0 g
s
.5524 .81067 m .55029 .79205 L .57953 .78609 L p .707 .577 .707 r
F P
0 g
s
.57953 .78609 m .58163 .80471 L .5524 .81067 L p .707 .577 .707 r
F P
0 g
s
.53673 .3197 m .5326 .82113 L .57408 .81662 L p .707 .577 .707 r
F P
0 g
s
.58115 .70407 m .57331 .64825 L .60486 .64342 L p .707 .577 .707 r
F P
0 g
s
.57408 .81662 m .57821 .3152 L .53673 .3197 L p .707 .577 .707 r
F P
0 g
s
.44365 .81885 m .44778 .31742 L .40902 .31085 L p .707 .577 .707 r
F P
0 g
s
.44778 .31742 m .44365 .81885 L .48766 .8219 L p .707 .577 .707 r
F P
0 g
s
.70601 .76879 m .69805 .80405 L .69549 .79243 L p .707 .577 .707 r
F P
0 g
s
.69549 .79243 m .70052 .77015 L p .70601 .76879 L .707 .577 .707 r
F P
0 g
s
.70346 .75716 m .69549 .79243 L .68343 .77974 L p .707 .577 .707 r
F P
0 g
s
.69238 .80298 m .69125 .79299 L p .70272 .78966 L .707 .577 .707 r
F P
0 g
s
.69125 .79299 m .69028 .78435 L .6941 .78598 L p .707 .577 .707 r
F P
0 g
s
.6941 .78598 m .70272 .78966 L p .69125 .79299 L .707 .577 .707 r
F P
0 g
s
.70052 .77015 m .70346 .75716 L .70428 .7609 L p .707 .577 .707 r
F P
0 g
s
.70428 .7609 m .70601 .76879 L p .70052 .77015 L .707 .577 .707 r
F P
0 g
s
.69599 .64781 m .70384 .70364 L .69147 .69897 L p .707 .577 .707 r
F P
0 g
s
.69147 .69897 m .68363 .64314 L .69599 .64781 L p .707 .577 .707 r
F P
0 g
s
.60486 .64342 m .61271 .69925 L .58115 .70407 L p .707 .577 .707 r
F P
0 g
s
.57471 .74227 m .58268 .70701 L .61385 .71228 L p .707 .577 .707 r
F P
0 g
s
.61385 .71228 m .60588 .74754 L .57471 .74227 L p .707 .577 .707 r
F P
0 g
s
.58163 .80471 m .57953 .78609 L .61118 .78206 L p .707 .577 .707 r
F P
0 g
s
.61118 .78206 m .61329 .80068 L .58163 .80471 L p .707 .577 .707 r
F P
0 g
s
.57821 .3152 m .57408 .81662 L .60804 .80882 L p .707 .577 .707 r
F P
0 g
s
.61271 .69925 m .60486 .64342 L .63571 .64083 L p .707 .577 .707 r
F P
0 g
s
.64428 .72088 m .63632 .75615 L .60588 .74754 L p .707 .577 .707 r
F P
0 g
s
.60588 .74754 m .61385 .71228 L .64428 .72088 L p .707 .577 .707 r
F P
0 g
s
.60804 .80882 m .61217 .30739 L .57821 .3152 L p .707 .577 .707 r
F P
0 g
s
.70553 .79654 m .70763 .81517 L .70483 .80828 L p .707 .577 .707 r
F P
0 g
s
.70483 .80828 m .70272 .78966 L .70553 .79654 L p .707 .577 .707 r
F P
0 g
s
.40489 .81228 m .40902 .31085 L .3793 .30141 L p .707 .577 .707 r
F P
0 g
s
.40902 .31085 m .40489 .81228 L .44365 .81885 L p .707 .577 .707 r
F P
0 g
s
.25552 .7082 m .24767 .65238 L .21681 .65496 L p .707 .577 .707 r
F P
0 g
s
.24767 .65238 m .25552 .7082 L .28707 .70337 L p .707 .577 .707 r
F P
0 g
s
.28707 .70337 m .27922 .64755 L .24767 .65238 L p .707 .577 .707 r
F P
0 g
s
.27922 .64755 m .28707 .70337 L .31622 .69678 L p .707 .577 .707 r
F P
0 g
s
.31622 .69678 m .30837 .64096 L .27922 .64755 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22466 .71079 m .21681 .65496 L .18967 .65506 L p .707 .577 .707 r
F P
0 g
s
.21681 .65496 m .22466 .71079 L .25552 .7082 L p .707 .577 .707 r
F P
0 g
s
.30837 .64096 m .31622 .69678 L .34013 .68907 L p .707 .577 .707 r
F P
0 g
s
.34013 .68907 m .33228 .63324 L .30837 .64096 L p .707 .577 .707 r
F P
0 g
s
.68343 .77974 m .69139 .74448 L .70346 .75716 L p .707 .577 .707 r
F P
0 g
s
.68363 .64314 m .69147 .69897 L .6707 .69656 L p .707 .577 .707 r
F P
0 g
s
.6707 .69656 m .66286 .64074 L .68363 .64314 L p .707 .577 .707 r
F P
0 g
s
.63571 .64083 m .64356 .69666 L .61271 .69925 L p .707 .577 .707 r
F P
0 g
s
.64215 .78036 m .64425 .79898 L .61329 .80068 L p .707 .577 .707 r
F P
0 g
s
.61329 .80068 m .61118 .78206 L .64215 .78036 L p .707 .577 .707 r
F P
0 g
s
.61217 .30739 m .60804 .80882 L .63115 .79847 L p .707 .577 .707 r
F P
0 g
s
.63115 .79847 m .63528 .29705 L .61217 .30739 L p .707 .577 .707 r
F P
0 g
s
.18967 .65506 m .19752 .71089 L .22466 .71079 L p .707 .577 .707 r
F P
0 g
s
.24785 .77874 m .25582 .74347 L .22538 .73487 L p .707 .577 .707 r
F P
0 g
s
.25582 .74347 m .24785 .77874 L .27902 .78401 L p .707 .577 .707 r
F P
0 g
s
.27902 .78401 m .28699 .74875 L .25582 .74347 L p .707 .577 .707 r
F P
0 g
s
.19752 .71089 m .18967 .65506 L .1689 .65266 L p .707 .577 .707 r
F P
0 g
s
.70272 .78966 m .70483 .80828 L .69238 .80298 L p .707 .577 .707 r
F P
0 g
s
.21742 .77014 m .22538 .73487 L .19866 .72377 L p .707 .577 .707 r
F P
0 g
s
.22538 .73487 m .21742 .77014 L .24785 .77874 L p .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .31511 .78317 L .29449 .78737 L p .707 .577 .707 r
F P
0 g
s
.29449 .78737 m .28587 .78913 L p .29143 .79137 L .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .29449 .78737 L .29143 .79137 L .707 .577 .707 r
F
.31511 .78317 m .31721 .80179 L .34117 .79449 L p F P
0 g
s
.34117 .79449 m .33907 .77586 L .32325 .78068 L p .707 .577 .707 r
F P
0 g
s
.32325 .78068 m .31511 .78317 L p .3203 .78542 L .707 .577 .707 r
F P
0 g
s
.34117 .79449 m .32325 .78068 L .3203 .78542 L .707 .577 .707 r
F
.33907 .77586 m .34117 .79449 L .3575 .78655 L p F P
0 g
s
.3575 .78655 m .3554 .76792 L .34572 .77263 L p .707 .577 .707 r
F P
0 g
s
.34572 .77263 m .33907 .77586 L p .34358 .77848 L .707 .577 .707 r
F P
0 g
s
.3575 .78655 m .34572 .77263 L .34358 .77848 L .707 .577 .707 r
F
.34784 .77656 m .35504 .76713 L p .35568 .7455 L F P
0 g
s
.3558 .74129 m .35353 .75135 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.35353 .75135 m .34784 .77656 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .34784 .77656 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.33955 .7476 m .3371 .75845 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.3371 .75845 m .33159 .78286 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .33159 .78286 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31584 .75017 m .31287 .76333 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31287 .76333 m .30787 .78543 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.28699 .74875 m .27902 .78401 L .30787 .78543 L p .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .31584 .75017 L .28699 .74875 L p .707 .577 .707 r
F P
0 g
s
.37516 .80284 m .3793 .30141 L .36152 .29002 L p .707 .577 .707 r
F P
0 g
s
.3793 .30141 m .37516 .80284 L .40489 .81228 L p .707 .577 .707 r
F P
0 g
s
.33228 .63324 m .34013 .68907 L .35645 .68099 L p .707 .577 .707 r
F P
0 g
s
.35645 .68099 m .3486 .62516 L .33228 .63324 L p .707 .577 .707 r
F P
0 g
s
.25632 .81178 m .25422 .79315 L .22325 .79486 L p .707 .577 .707 r
F P
0 g
s
.25422 .79315 m .25632 .81178 L .28797 .80775 L p .707 .577 .707 r
F P
0 g
s
.28797 .80775 m .28587 .78913 L .25422 .79315 L p .707 .577 .707 r
F P
0 g
s
.1689 .65266 m .17675 .70848 L .19752 .71089 L p .707 .577 .707 r
F P
0 g
s
.28587 .78913 m .28797 .80775 L .31721 .80179 L p .707 .577 .707 r
F P
0 g
s
.19866 .72377 m .1907 .75904 L .21742 .77014 L p .707 .577 .707 r
F P
0 g
s
.1907 .75904 m .19866 .72377 L .17827 .71127 L p .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .33955 .7476 L .31584 .75017 L p .707 .577 .707 r
F P
0 g
s
.22325 .79486 m .22535 .81348 L .25632 .81178 L p .707 .577 .707 r
F P
0 g
s
.66286 .64074 m .6707 .69656 L .64356 .69666 L p .707 .577 .707 r
F P
0 g
s
.64356 .69666 m .63571 .64083 L .66286 .64074 L p .707 .577 .707 r
F P
0 g
s
.69139 .74448 m .68343 .77974 L .66304 .76724 L p .707 .577 .707 r
F P
0 g
s
.66304 .76724 m .671 .73198 L .69139 .74448 L p .707 .577 .707 r
F P
0 g
s
.22535 .81348 m .22325 .79486 L .196 .79407 L p .707 .577 .707 r
F P
0 g
s
.196 .79407 m .1981 .81269 L .22535 .81348 L p .707 .577 .707 r
F P
0 g
s
.17675 .70848 m .1689 .65266 L .15653 .64799 L p .707 .577 .707 r
F P
0 g
s
.17827 .71127 m .17031 .74654 L .1907 .75904 L p .707 .577 .707 r
F P
0 g
s
.69028 .78435 m .69238 .80298 L .67151 .79977 L p .707 .577 .707 r
F P
0 g
s
.67151 .79977 m .66941 .78115 L .69028 .78435 L p .707 .577 .707 r
F P
0 g
s
.671 .73198 m .66304 .76724 L .63632 .75615 L p .707 .577 .707 r
F P
0 g
s
.63632 .75615 m .64428 .72088 L .671 .73198 L p .707 .577 .707 r
F P
0 g
s
.63528 .29705 m .63115 .79847 L .64115 .78661 L p .707 .577 .707 r
F P
0 g
s
.64115 .78661 m .64528 .28518 L .63528 .29705 L p .707 .577 .707 r
F P
0 g
s
.3486 .62516 m .35645 .68099 L .36358 .67334 L p .707 .577 .707 r
F P
0 g
s
.36358 .67334 m .35573 .61751 L .3486 .62516 L p .707 .577 .707 r
F P
0 g
s
.1981 .81269 m .196 .79407 L .17512 .79086 L p .707 .577 .707 r
F P
0 g
s
.15653 .64799 m .16438 .70381 L .16524 .70414 L p .707 .577 .707 r
F P
0 g
s
.17087 .69088 m .15653 .64799 L .16524 .70414 L .707 .577 .707 r
F
.16438 .70381 m .15653 .64799 L .15378 .64151 L p F P
0 g
s
.16438 .70381 m .16108 .6844 L .16151 .69646 L .707 .577 .707 r
F
.16034 .7157 m .16422 .70438 L .16229 .69875 L F
.16254 .69948 m .16438 .70381 L p .16151 .69646 L F P
0 g
s
.15569 .72223 m .15824 .73386 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16365 .68697 m .16151 .69646 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .15569 .72223 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16151 .69646 L p .16108 .6844 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16092 .63386 L p .16161 .69515 L .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .16365 .68697 L p .16229 .69875 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .16365 .68697 L p .1628 .69488 L .707 .577 .707 r
F P
0 g
s
.16162 .6968 m .16163 .69733 L .16254 .69948 L p .707 .577 .707 r
F P
0 g
s
.16163 .69733 m .16151 .69646 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16422 .70438 m .16621 .69859 L .16229 .69875 L .707 .577 .707 r
F
.16876 .68968 m .16163 .69733 L p .16162 .69632 L F P
0 g
s
.16365 .68697 m .17085 .67754 L p .1665 .69035 L .707 .577 .707 r
F P
0 g
s
.1628 .69488 m .16365 .68697 L .1665 .69035 L .707 .577 .707 r
F
.16851 .68789 m .16876 .68968 L p .16162 .69632 L F P
0 g
s
.15824 .73386 m .16463 .70558 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16463 .70558 m .16621 .69859 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .15569 .72223 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .16851 .68789 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .16289 .71281 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .1871 .67123 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16876 .68968 m .16851 .68789 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.16524 .70414 m .17675 .70848 L p .17087 .69088 L .707 .577 .707 r
F P
0 g
s
.17031 .74654 m .17827 .71127 L .16621 .69859 L p .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .15824 .73386 L .17031 .74654 L p .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .17085 .67754 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .16876 .68968 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .18496 .68073 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .18496 .68073 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .18508 .6816 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .16289 .71281 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17914 .7065 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .16851 .68789 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16903 .68767 m .16851 .68789 L .16927 .68589 L .707 .577 .707 r
F
.16092 .63386 m .17723 .62578 L p .16927 .68589 L F P
0 g
s
.16851 .68789 m .16092 .63386 L p .16927 .68589 L .707 .577 .707 r
F P
0 g
s
.16092 .63386 m .16851 .68789 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16178 .70426 m .1628 .69488 L .1665 .69035 L .707 .577 .707 r
F
.16151 .69646 m .1628 .69488 L .16178 .70426 L F
.16162 .69632 m .16151 .69646 L .16161 .69515 L F
.16151 .69646 m .15378 .64151 L p .16161 .69515 L F P
0 g
s
.15569 .72223 m .16151 .69646 L p .16178 .70426 L .707 .577 .707 r
F P
0 g
s
.34784 .77656 m .3558 .74129 L .33955 .7476 L p .707 .577 .707 r
F P
0 g
s
.17512 .79086 m .17723 .80949 L .1981 .81269 L p .707 .577 .707 r
F P
0 g
s
.35504 .76713 m .363 .73187 L .3558 .74129 L p .707 .577 .707 r
F P
0 g
s
.35573 .61751 m .36358 .67334 L .36083 .66686 L p .707 .577 .707 r
F P
0 g
s
.36083 .66686 m .35298 .61103 L .35573 .61751 L p .707 .577 .707 r
F P
0 g
s
.3554 .76792 m .3575 .78655 L .36462 .77876 L p .707 .577 .707 r
F P
0 g
s
.36462 .77876 m .36462 .77875 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .77875 m .3554 .76792 L .36462 .77876 L .707 .577 .707 r
F
.36152 .29002 m .35743 .27779 L p .35741 .51257 L F P
0 g
s
.36252 .76013 m .3554 .76792 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36462 .77875 m .36461 .7787 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .7787 m .36252 .76013 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.363 .73187 m .35504 .76713 L .35248 .75551 L p .707 .577 .707 r
F P
0 g
s
.35248 .75551 m .35747 .7334 L p .363 .73187 L .707 .577 .707 r
F P
0 g
s
.35747 .7334 m .36045 .72024 L .36128 .72403 L p .707 .577 .707 r
F P
0 g
s
.36128 .72403 m .363 .73187 L p .35747 .7334 L .707 .577 .707 r
F P
0 g
s
.36045 .72024 m .35248 .75551 L .34071 .74313 L p .707 .577 .707 r
F P
0 g
s
.34071 .74313 m .34042 .74282 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34075 .74245 m .36045 .72024 L .34071 .74313 L .707 .577 .707 r
F
.35915 .57699 m .36152 .29002 L p .35741 .51257 L F P
0 g
s
.34937 .76656 m .3482 .75624 L p .35971 .75324 L .707 .577 .707 r
F P
0 g
s
.35094 .7495 m .35971 .75324 L p .3482 .75624 L .707 .577 .707 r
F P
0 g
s
.35298 .61103 m .36083 .66686 L .34846 .66219 L p .707 .577 .707 r
F P
0 g
s
.36252 .76013 m .36462 .77875 L .36182 .77187 L p .707 .577 .707 r
F P
0 g
s
.36182 .77187 m .35971 .75324 L .36252 .76013 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .36045 .72024 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34042 .74282 m .34084 .74094 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34084 .74094 m .34838 .70756 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.35971 .75324 m .36182 .77187 L .34937 .76656 L p .707 .577 .707 r
F P
0 g
s
.36152 .29002 m .35739 .79144 L .37516 .80284 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .35753 .7742 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35739 .79144 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35739 .79144 m .35915 .57699 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35753 .7742 m .3533 .77922 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .36483 .36022 L .36465 .40786 L .707 .577 .707 r
F
.36743 .26592 m .36693 .327 L p .36483 .36022 L F P
0 g
s
.36693 .327 m .3633 .76735 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .36743 .26592 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .35594 .45834 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35594 .45834 m .3533 .77922 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35554 .5078 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35554 .5078 m .35743 .27779 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.3482 .75624 m .34727 .74794 L .35094 .7495 L p .707 .577 .707 r
F P
0 g
s
.66941 .78115 m .67151 .79977 L .64425 .79898 L p .707 .577 .707 r
F P
0 g
s
.64425 .79898 m .64215 .78036 L .66941 .78115 L p .707 .577 .707 r
F P
0 g
s
.17723 .80949 m .17512 .79086 L .16268 .78556 L p .707 .577 .707 r
F P
0 g
s
.16268 .78556 m .16478 .80418 L .17723 .80949 L p .707 .577 .707 r
F P
0 g
s
.64528 .28518 m .64115 .78661 L .63706 .77438 L p .707 .577 .707 r
F P
0 g
s
.63706 .77438 m .64119 .27295 L .64528 .28518 L p .707 .577 .707 r
F P
0 g
s
.16478 .80418 m .16268 .78556 L .15987 .77867 L p .707 .577 .707 r
F P
0 g
s
.15987 .77867 m .16198 .79729 L .16478 .80418 L p .707 .577 .707 r
F P
0 g
s
.34846 .66219 m .34062 .60636 L .35298 .61103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64119 .27295 m .63706 .77438 L .61928 .76298 L p .707 .577 .707 r
F P
0 g
s
.61928 .76298 m .62341 .26156 L .64119 .27295 L p .707 .577 .707 r
F P
0 g
s
.16198 .79729 m .15987 .77867 L .16699 .77088 L p .707 .577 .707 r
F P
0 g
s
.16699 .77088 m .16909 .7895 L .16198 .79729 L p .707 .577 .707 r
F P
0 g
s
.34062 .60636 m .34846 .66219 L .32769 .65978 L p .707 .577 .707 r
F P
0 g
s
.32769 .65978 m .31985 .60396 L .34062 .60636 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .36743 .26592 L .39054 .25558 L p .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .21082 .66867 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .18496 .68073 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .1871 .67123 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.21082 .66867 m .20924 .67565 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.20114 .61806 m .20899 .67389 L .193 .67905 L p .707 .577 .707 r
F P
0 g
s
.193 .67905 m .18508 .6816 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18532 .68065 m .20114 .61806 L .193 .67905 L .707 .577 .707 r
F
.20285 .70393 m .17914 .7065 L p .20406 .67674 L F P
0 g
s
.20924 .67565 m .20285 .70393 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .18496 .68073 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .20114 .61806 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17723 .62578 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.31985 .60396 m .32769 .65978 L .30055 .65988 L p .707 .577 .707 r
F P
0 g
s
.30055 .65988 m .2927 .60405 L .31985 .60396 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .34042 .74282 L .32003 .73032 L p .707 .577 .707 r
F P
0 g
s
.32003 .73032 m .32799 .69506 L .34838 .70756 L p .707 .577 .707 r
F P
0 g
s
.16909 .7895 m .16699 .77088 L .18333 .76294 L p .707 .577 .707 r
F P
0 g
s
.18333 .76294 m .18543 .78156 L .16909 .7895 L p .707 .577 .707 r
F P
0 g
s
.62341 .26156 m .61928 .76298 L .58956 .75354 L p .707 .577 .707 r
F P
0 g
s
.58956 .75354 m .59369 .25211 L .62341 .26156 L p .707 .577 .707 r
F P
0 g
s
.20899 .67389 m .20114 .61806 L .2303 .61147 L p .707 .577 .707 r
F P
0 g
s
.34727 .74794 m .34937 .76656 L .3285 .76336 L p .707 .577 .707 r
F P
0 g
s
.3285 .76336 m .3264 .74474 L .34727 .74794 L p .707 .577 .707 r
F P
0 g
s
.2927 .60405 m .30055 .65988 L .2697 .66247 L p .707 .577 .707 r
F P
0 g
s
.2697 .66247 m .26185 .60664 L .2927 .60405 L p .707 .577 .707 r
F P
0 g
s
.39054 .25558 m .38641 .75701 L .3633 .76735 L p .707 .577 .707 r
F P
0 g
s
.38641 .75701 m .39054 .25558 L .4245 .24777 L p .707 .577 .707 r
F P
0 g
s
.20285 .70393 m .21082 .66867 L .23967 .67009 L p .707 .577 .707 r
F P
0 g
s
.32799 .69506 m .32003 .73032 L .29331 .71923 L p .707 .577 .707 r
F P
0 g
s
.29331 .71923 m .30127 .68396 L .32799 .69506 L p .707 .577 .707 r
F P
0 g
s
.23815 .6673 m .2303 .61147 L .26185 .60664 L p .707 .577 .707 r
F P
0 g
s
.2303 .61147 m .23815 .6673 L .20899 .67389 L p .707 .577 .707 r
F P
0 g
s
.73573 .65294 m .72788 .59712 L .69703 .59971 L p .707 .577 .707 r
F P
0 g
s
.72788 .59712 m .73573 .65294 L .76728 .64811 L p .707 .577 .707 r
F P
0 g
s
.76728 .64811 m .75943 .59229 L .72788 .59712 L p .707 .577 .707 r
F P
0 g
s
.26185 .60664 m .2697 .66247 L .23815 .6673 L p .707 .577 .707 r
F P
0 g
s
.75943 .59229 m .76728 .64811 L .79644 .64152 L p .707 .577 .707 r
F P
0 g
s
.79644 .64152 m .78859 .5857 L .75943 .59229 L p .707 .577 .707 r
F P
0 g
s
.18543 .78156 m .18333 .76294 L .20729 .75563 L p .707 .577 .707 r
F P
0 g
s
.20729 .75563 m .20939 .77426 L .18543 .78156 L p .707 .577 .707 r
F P
0 g
s
.70487 .65553 m .69703 .59971 L .66988 .5998 L p .707 .577 .707 r
F P
0 g
s
.69703 .59971 m .70487 .65553 L .73573 .65294 L p .707 .577 .707 r
F P
0 g
s
.23967 .67009 m .23171 .70535 L .20285 .70393 L p .707 .577 .707 r
F P
0 g
s
.23171 .70535 m .23967 .67009 L .27084 .67536 L p .707 .577 .707 r
F P
0 g
s
.30127 .68396 m .29331 .71923 L .26287 .71062 L p .707 .577 .707 r
F P
0 g
s
.26287 .71062 m .27084 .67536 L .30127 .68396 L p .707 .577 .707 r
F P
0 g
s
.3264 .74474 m .3285 .76336 L .30124 .76257 L p .707 .577 .707 r
F P
0 g
s
.30124 .76257 m .29914 .74395 L .3264 .74474 L p .707 .577 .707 r
F P
0 g
s
.78859 .5857 m .79644 .64152 L .82034 .63381 L p .707 .577 .707 r
F P
0 g
s
.82034 .63381 m .8125 .57798 L .78859 .5857 L p .707 .577 .707 r
F P
0 g
s
.59369 .25211 m .58956 .75354 L .55079 .74697 L p .707 .577 .707 r
F P
0 g
s
.55079 .74697 m .55493 .24555 L .59369 .25211 L p .707 .577 .707 r
F P
0 g
s
.27084 .67536 m .26287 .71062 L .23171 .70535 L p .707 .577 .707 r
F P
0 g
s
.66988 .5998 m .67773 .65563 L .70487 .65553 L p .707 .577 .707 r
F P
0 g
s
.72806 .72362 m .73603 .68836 L .70559 .67975 L p .707 .577 .707 r
F P
0 g
s
.73603 .68836 m .72806 .72362 L .75923 .72889 L p .707 .577 .707 r
F P
0 g
s
.75923 .72889 m .7672 .69363 L .73603 .68836 L p .707 .577 .707 r
F P
0 g
s
.20939 .77426 m .20729 .75563 L .23652 .74967 L p .707 .577 .707 r
F P
0 g
s
.67773 .65563 m .66988 .5998 L .64911 .5974 L p .707 .577 .707 r
F P
0 g
s
.42036 .7492 m .4245 .24777 L .46598 .24326 L p .707 .577 .707 r
F P
0 g
s
.4245 .24777 m .42036 .7492 L .38641 .75701 L p .707 .577 .707 r
F P
0 g
s
.69763 .71502 m .70559 .67975 L .67887 .66866 L p .707 .577 .707 r
F P
0 g
s
.70559 .67975 m .69763 .71502 L .72806 .72362 L p .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .79532 .72754 L .77506 .73167 L p .707 .577 .707 r
F P
0 g
s
.77506 .73167 m .76608 .7335 L p .77187 .73584 L .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .77506 .73167 L .77187 .73584 L .707 .577 .707 r
F
.79532 .72754 m .79742 .74617 L .82138 .73886 L p F P
0 g
s
.82138 .73886 m .81928 .72024 L .80377 .72497 L p .707 .577 .707 r
F P
0 g
s
.80377 .72497 m .79532 .72754 L p .80071 .72988 L .707 .577 .707 r
F P
0 g
s
.82138 .73886 m .80377 .72497 L .80071 .72988 L .707 .577 .707 r
F
.81928 .72024 m .82138 .73886 L .83772 .73092 L p F P
0 g
s
.83772 .73092 m .83562 .7123 L .82613 .71691 L p .707 .577 .707 r
F P
0 g
s
.82613 .71691 m .81928 .72024 L p .82392 .72293 L .707 .577 .707 r
F P
0 g
s
.83772 .73092 m .82613 .71691 L .82392 .72293 L .707 .577 .707 r
F
.82805 .72144 m .83525 .71201 L p .8359 .69031 L F P
0 g
s
.83602 .68617 m .83378 .69607 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.83378 .69607 m .82805 .72144 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .82805 .72144 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81977 .69248 m .81735 .70317 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81735 .70317 m .8118 .72775 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .8118 .72775 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79605 .69505 m .79312 .70804 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79312 .70804 m .78809 .73031 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.7672 .69363 m .75923 .72889 L .78809 .73031 L p .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .79605 .69505 L .7672 .69363 L p .707 .577 .707 r
F P
0 g
s
.23652 .74967 m .23862 .7683 L .20939 .77426 L p .707 .577 .707 r
F P
0 g
s
.29914 .74395 m .30124 .76257 L .27028 .76427 L p .707 .577 .707 r
F P
0 g
s
.27028 .76427 m .26817 .74565 L .29914 .74395 L p .707 .577 .707 r
F P
0 g
s
.8125 .57798 m .82034 .63381 L .83666 .62573 L p .707 .577 .707 r
F P
0 g
s
.83666 .62573 m .82881 .5699 L .8125 .57798 L p .707 .577 .707 r
F P
0 g
s
.23862 .7683 m .23652 .74967 L .26817 .74565 L p .707 .577 .707 r
F P
0 g
s
.73653 .75615 m .73443 .73753 L .70346 .73923 L p .707 .577 .707 r
F P
0 g
s
.73443 .73753 m .73653 .75615 L .76819 .75212 L p .707 .577 .707 r
F P
0 g
s
.76819 .75212 m .76608 .7335 L .73443 .73753 L p .707 .577 .707 r
F P
0 g
s
.26817 .74565 m .27028 .76427 L .23862 .7683 L p .707 .577 .707 r
F P
0 g
s
.64911 .5974 m .65696 .65322 L .67773 .65563 L p .707 .577 .707 r
F P
0 g
s
.55493 .24555 m .55079 .74697 L .50679 .74392 L p .707 .577 .707 r
F P
0 g
s
.50679 .74392 m .51092 .2425 L .55493 .24555 L p .707 .577 .707 r
F P
0 g
s
.76608 .7335 m .76819 .75212 L .79742 .74617 L p .707 .577 .707 r
F P
0 g
s
.67887 .66866 m .67091 .70392 L .69763 .71502 L p .707 .577 .707 r
F P
0 g
s
.67091 .70392 m .67887 .66866 L .65849 .65615 L p .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .81977 .69248 L .79605 .69505 L p .707 .577 .707 r
F P
0 g
s
.70346 .73923 m .70556 .75785 L .73653 .75615 L p .707 .577 .707 r
F P
0 g
s
.46184 .74469 m .46598 .24326 L .51092 .2425 L p .707 .577 .707 r
F P
0 g
s
.46598 .24326 m .46184 .74469 L .42036 .7492 L p .707 .577 .707 r
F P
0 g
s
.70556 .75785 m .70346 .73923 L .67621 .73844 L p .707 .577 .707 r
F P
0 g
s
.51092 .2425 m .50679 .74392 L .46184 .74469 L p .707 .577 .707 r
F P
0 g
s
.67621 .73844 m .67831 .75706 L .70556 .75785 L p .707 .577 .707 r
F P
0 g
s
.65696 .65322 m .64911 .5974 L .63675 .59273 L p .707 .577 .707 r
F P
0 g
s
.65849 .65615 m .65052 .69142 L .67091 .70392 L p .707 .577 .707 r
F P
0 g
s
.82881 .5699 m .83666 .62573 L .8438 .61808 L p .707 .577 .707 r
F P
0 g
s
.8438 .61808 m .83595 .56225 L .82881 .5699 L p .707 .577 .707 r
F P
0 g
s
.67831 .75706 m .67621 .73844 L .65534 .73524 L p .707 .577 .707 r
F P
0 g
s
.63675 .59273 m .64459 .64855 L .6455 .64889 L p .707 .577 .707 r
F P
0 g
s
.6511 .63568 m .63675 .59273 L .6455 .64889 L .707 .577 .707 r
F
.64459 .64855 m .63675 .59273 L .634 .58625 L p F P
0 g
s
.64459 .64855 m .6413 .62921 L .64173 .64129 L .707 .577 .707 r
F
.64055 .66054 m .64445 .64922 L .64251 .64357 L F
.64266 .64401 m .64459 .64855 L p .64173 .64129 L F P
0 g
s
.6359 .66711 m .63846 .67874 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64386 .63185 m .64173 .64129 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .6359 .66711 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64173 .64129 L p .6413 .62921 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64113 .5786 L p .64182 .6401 L .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .64386 .63185 L p .64251 .64357 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .64386 .63185 L p .64302 .63971 L .707 .577 .707 r
F P
0 g
s
.64184 .64159 m .64184 .64207 L .64266 .64401 L p .707 .577 .707 r
F P
0 g
s
.64184 .64207 m .64173 .64129 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64445 .64922 m .64642 .64347 L .64251 .64357 L .707 .577 .707 r
F
.64898 .63442 m .64184 .64207 L p .64183 .64116 L F P
0 g
s
.64386 .63185 m .65106 .62242 L p .64674 .63516 L .707 .577 .707 r
F P
0 g
s
.64302 .63971 m .64386 .63185 L .64674 .63516 L .707 .577 .707 r
F
.64874 .63272 m .64898 .63442 L p .64183 .64116 L F P
0 g
s
.63846 .67874 m .64486 .65041 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.64486 .65041 m .64642 .64347 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .6359 .66711 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .64874 .63272 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .6431 .65769 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .66732 .61612 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64898 .63442 m .64874 .63272 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.6455 .64889 m .65696 .65322 L p .6511 .63568 L .707 .577 .707 r
F P
0 g
s
.65052 .69142 m .65849 .65615 L .64642 .64347 L p .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .63846 .67874 L .65052 .69142 L p .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .65106 .62242 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .64898 .63442 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .66518 .62555 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .66518 .62555 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .6653 .62634 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .6431 .65769 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65935 .65138 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .64874 .63272 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64923 .63251 m .64874 .63272 L .64945 .63082 L .707 .577 .707 r
F
.64113 .5786 m .65745 .57052 L p .64945 .63082 L F P
0 g
s
.64874 .63272 m .64113 .5786 L p .64945 .63082 L .707 .577 .707 r
F P
0 g
s
.64113 .5786 m .64874 .63272 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64201 .64911 m .64302 .63971 L .64674 .63516 L .707 .577 .707 r
F
.64173 .64129 m .64302 .63971 L .64201 .64911 L F
.64183 .64116 m .64173 .64129 L .64182 .6401 L F
.64173 .64129 m .634 .58625 L p .64182 .6401 L F P
0 g
s
.6359 .66711 m .64173 .64129 L p .64201 .64911 L .707 .577 .707 r
F P
0 g
s
.82805 .72144 m .83602 .68617 L .81977 .69248 L p .707 .577 .707 r
F P
0 g
s
.65534 .73524 m .65744 .75386 L .67831 .75706 L p .707 .577 .707 r
F P
0 g
s
.65744 .75386 m .65534 .73524 L .64289 .72993 L p .707 .577 .707 r
F P
0 g
s
.83525 .71201 m .84322 .67675 L .83602 .68617 L p .707 .577 .707 r
F P
0 g
s
.64289 .72993 m .64499 .74856 L .65744 .75386 L p .707 .577 .707 r
F P
0 g
s
.83595 .56225 m .8438 .61808 L .84104 .6116 L p .707 .577 .707 r
F P
0 g
s
.84104 .6116 m .8332 .55577 L .83595 .56225 L p .707 .577 .707 r
F P
0 g
s
.83562 .7123 m .83772 .73092 L .84483 .72313 L p .707 .577 .707 r
F P
0 g
s
.84483 .72313 m .84273 .7045 L .83562 .7123 L p .707 .577 .707 r
F P
0 g
s
.64499 .74856 m .64289 .72993 L .64009 .72304 L p .707 .577 .707 r
F P
0 g
s
.64009 .72304 m .64219 .74167 L .64499 .74856 L p .707 .577 .707 r
F P
0 g
s
.84322 .67675 m .83525 .71201 L .8327 .70039 L p .707 .577 .707 r
F P
0 g
s
.8327 .70039 m .83773 .67812 L p .84322 .67675 L .707 .577 .707 r
F P
0 g
s
.84066 .66512 m .8327 .70039 L .82063 .68771 L p .707 .577 .707 r
F P
0 g
s
.82958 .71094 m .82846 .70095 L p .83993 .69762 L .707 .577 .707 r
F P
0 g
s
.82846 .70095 m .82748 .69231 L .8313 .69394 L p .707 .577 .707 r
F P
0 g
s
.8313 .69394 m .83993 .69762 L p .82846 .70095 L .707 .577 .707 r
F P
0 g
s
.83773 .67812 m .84066 .66512 L .84148 .66886 L p .707 .577 .707 r
F P
0 g
s
.84148 .66886 m .84322 .67675 L p .83773 .67812 L .707 .577 .707 r
F P
0 g
s
.8332 .55577 m .84104 .6116 L .82868 .60693 L p .707 .577 .707 r
F P
0 g
s
.82868 .60693 m .82083 .5511 L .8332 .55577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84273 .7045 m .84483 .72313 L .84203 .71624 L p .707 .577 .707 r
F P
0 g
s
.84203 .71624 m .83993 .69762 L .84273 .7045 L p .707 .577 .707 r
F P
0 g
s
.39272 .61616 m .38487 .56034 L .35402 .56293 L p .707 .577 .707 r
F P
0 g
s
.38487 .56034 m .39272 .61616 L .42427 .61134 L p .707 .577 .707 r
F P
0 g
s
.42427 .61134 m .41642 .55551 L .38487 .56034 L p .707 .577 .707 r
F P
0 g
s
.41642 .55551 m .42427 .61134 L .45343 .60474 L p .707 .577 .707 r
F P
0 g
s
.45343 .60474 m .44558 .54892 L .41642 .55551 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36186 .61875 m .35402 .56293 L .32687 .56302 L p .707 .577 .707 r
F P
0 g
s
.35402 .56293 m .36186 .61875 L .39272 .61616 L p .707 .577 .707 r
F P
0 g
s
.64219 .74167 m .64009 .72304 L .6472 .71525 L p .707 .577 .707 r
F P
0 g
s
.44558 .54892 m .45343 .60474 L .47733 .59703 L p .707 .577 .707 r
F P
0 g
s
.47733 .59703 m .46949 .5412 L .44558 .54892 L p .707 .577 .707 r
F P
0 g
s
.82063 .68771 m .8286 .65244 L .84066 .66512 L p .707 .577 .707 r
F P
0 g
s
.6472 .71525 m .64931 .73388 L .64219 .74167 L p .707 .577 .707 r
F P
0 g
s
.82083 .5511 m .82868 .60693 L .80791 .60452 L p .707 .577 .707 r
F P
0 g
s
.80791 .60452 m .80006 .5487 L .82083 .5511 L p .707 .577 .707 r
F P
0 g
s
.32687 .56302 m .33472 .61885 L .36186 .61875 L p .707 .577 .707 r
F P
0 g
s
.38505 .6867 m .39302 .65144 L .36258 .64283 L p .707 .577 .707 r
F P
0 g
s
.39302 .65144 m .38505 .6867 L .41622 .69197 L p .707 .577 .707 r
F P
0 g
s
.41622 .69197 m .42419 .65671 L .39302 .65144 L p .707 .577 .707 r
F P
0 g
s
.33472 .61885 m .32687 .56302 L .3061 .56062 L p .707 .577 .707 r
F P
0 g
s
.83993 .69762 m .84203 .71624 L .82958 .71094 L p .707 .577 .707 r
F P
0 g
s
.35462 .6781 m .36258 .64283 L .33586 .63174 L p .707 .577 .707 r
F P
0 g
s
.36258 .64283 m .35462 .6781 L .38505 .6867 L p .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .45231 .69113 L .4317 .69533 L p .707 .577 .707 r
F P
0 g
s
.4317 .69533 m .42307 .69709 L p .42863 .69934 L .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .4317 .69533 L .42863 .69934 L .707 .577 .707 r
F
.45231 .69113 m .45441 .70975 L .47837 .70245 L p F P
0 g
s
.47837 .70245 m .47627 .68382 L .46045 .68865 L p .707 .577 .707 r
F P
0 g
s
.46045 .68865 m .45231 .69113 L p .4575 .69338 L .707 .577 .707 r
F P
0 g
s
.47837 .70245 m .46045 .68865 L .4575 .69338 L .707 .577 .707 r
F
.47627 .68382 m .47837 .70245 L .49471 .69451 L p F P
0 g
s
.49471 .69451 m .49261 .67589 L .48293 .68059 L p .707 .577 .707 r
F P
0 g
s
.48293 .68059 m .47627 .68382 L p .48078 .68644 L .707 .577 .707 r
F P
0 g
s
.49471 .69451 m .48293 .68059 L .48078 .68644 L .707 .577 .707 r
F
.48504 .68452 m .49224 .67509 L p .49288 .65346 L F P
0 g
s
.49301 .64925 m .49074 .65932 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.49074 .65932 m .48504 .68452 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .48504 .68452 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.47676 .65556 m .4743 .66642 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.4743 .66642 m .46879 .69083 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .46879 .69083 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45304 .65813 m .45007 .67129 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45007 .67129 m .44508 .69339 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.42419 .65671 m .41622 .69197 L .44508 .69339 L p .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .45304 .65813 L .42419 .65671 L p .707 .577 .707 r
F P
0 g
s
.46949 .5412 m .47733 .59703 L .49365 .58895 L p .707 .577 .707 r
F P
0 g
s
.49365 .58895 m .4858 .53313 L .46949 .5412 L p .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .69103 .61355 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .66518 .62555 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .66732 .61612 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.69103 .61355 m .68946 .62048 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.68136 .5628 m .6892 .61863 L .67243 .62404 L p .707 .577 .707 r
F P
0 g
s
.67243 .62404 m .6653 .62634 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66551 .62549 m .68136 .5628 L .67243 .62404 L .707 .577 .707 r
F
.68307 .64881 m .65935 .65138 L p .68432 .62156 L F P
0 g
s
.68946 .62048 m .68307 .64881 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .66518 .62555 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .68136 .5628 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65745 .57052 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.39352 .71974 m .39142 .70111 L .36045 .70282 L p .707 .577 .707 r
F P
0 g
s
.39142 .70111 m .39352 .71974 L .42518 .71571 L p .707 .577 .707 r
F P
0 g
s
.42518 .71571 m .42307 .69709 L .39142 .70111 L p .707 .577 .707 r
F P
0 g
s
.3061 .56062 m .31395 .61644 L .33472 .61885 L p .707 .577 .707 r
F P
0 g
s
.42307 .69709 m .42518 .71571 L .45441 .70975 L p .707 .577 .707 r
F P
0 g
s
.33586 .63174 m .3279 .667 L .35462 .6781 L p .707 .577 .707 r
F P
0 g
s
.3279 .667 m .33586 .63174 L .31547 .61923 L p .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .47676 .65556 L .45304 .65813 L p .707 .577 .707 r
F P
0 g
s
.36045 .70282 m .36255 .72144 L .39352 .71974 L p .707 .577 .707 r
F P
0 g
s
.80006 .5487 m .80791 .60452 L .78077 .60462 L p .707 .577 .707 r
F P
0 g
s
.78077 .60462 m .77292 .5488 L .80006 .5487 L p .707 .577 .707 r
F P
0 g
s
.8286 .65244 m .82063 .68771 L .80024 .6752 L p .707 .577 .707 r
F P
0 g
s
.80024 .6752 m .80821 .63994 L .8286 .65244 L p .707 .577 .707 r
F P
0 g
s
.64931 .73388 m .6472 .71525 L .66354 .70731 L p .707 .577 .707 r
F P
0 g
s
.36255 .72144 m .36045 .70282 L .3332 .70203 L p .707 .577 .707 r
F P
0 g
s
.66354 .70731 m .66564 .72594 L .64931 .73388 L p .707 .577 .707 r
F P
0 g
s
.3332 .70203 m .3353 .72065 L .36255 .72144 L p .707 .577 .707 r
F P
0 g
s
.31395 .61644 m .3061 .56062 L .29374 .55595 L p .707 .577 .707 r
F P
0 g
s
.6892 .61863 m .68136 .5628 L .71051 .55621 L p .707 .577 .707 r
F P
0 g
s
.31547 .61923 m .30751 .6545 L .3279 .667 L p .707 .577 .707 r
F P
0 g
s
.82748 .69231 m .82958 .71094 L .80871 .70773 L p .707 .577 .707 r
F P
0 g
s
.80871 .70773 m .80661 .68911 L .82748 .69231 L p .707 .577 .707 r
F P
0 g
s
.77292 .5488 m .78077 .60462 L .74991 .60721 L p .707 .577 .707 r
F P
0 g
s
.74991 .60721 m .74206 .55138 L .77292 .5488 L p .707 .577 .707 r
F P
0 g
s
.4858 .53313 m .49365 .58895 L .50079 .5813 L p .707 .577 .707 r
F P
0 g
s
.50079 .5813 m .49294 .52547 L .4858 .53313 L p .707 .577 .707 r
F P
0 g
s
.3353 .72065 m .3332 .70203 L .31233 .69882 L p .707 .577 .707 r
F P
0 g
s
.29374 .55595 m .30158 .61177 L .30244 .6121 L p .707 .577 .707 r
F P
0 g
s
.30807 .59884 m .29374 .55595 L .30244 .6121 L .707 .577 .707 r
F
.30158 .61177 m .29374 .55595 L .29099 .54947 L p F P
0 g
s
.30158 .61177 m .29828 .59237 L .29871 .60442 L .707 .577 .707 r
F
.29754 .62366 m .30142 .61234 L .29949 .60671 L F
.29974 .60744 m .30158 .61177 L p .29871 .60442 L F P
0 g
s
.29289 .63019 m .29545 .64182 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.30085 .59493 m .29871 .60442 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .29289 .63019 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29871 .60442 L p .29828 .59237 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29812 .54182 L p .29881 .60311 L .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .30085 .59493 L p .29949 .60671 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .30085 .59493 L p .3 .60284 L .707 .577 .707 r
F P
0 g
s
.29883 .60476 m .29883 .60529 L .29974 .60744 L p .707 .577 .707 r
F P
0 g
s
.29883 .60529 m .29871 .60442 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.30142 .61234 m .30341 .60655 L .29949 .60671 L .707 .577 .707 r
F
.30597 .59764 m .29883 .60529 L p .29882 .60428 L F P
0 g
s
.30085 .59493 m .30805 .5855 L p .30371 .59831 L .707 .577 .707 r
F P
0 g
s
.3 .60284 m .30085 .59493 L .30371 .59831 L .707 .577 .707 r
F
.30572 .59586 m .30597 .59764 L p .29882 .60428 L F P
0 g
s
.29545 .64182 m .30183 .61354 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30183 .61354 m .30341 .60655 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .29289 .63019 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .30572 .59586 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30009 .62077 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .32431 .57919 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30597 .59764 m .30572 .59586 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.30244 .6121 m .31395 .61644 L p .30807 .59884 L .707 .577 .707 r
F P
0 g
s
.30751 .6545 m .31547 .61923 L .30341 .60655 L p .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .29545 .64182 L .30751 .6545 L p .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30805 .5855 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .30597 .59764 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .32216 .58869 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .32216 .58869 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32229 .58956 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .30009 .62077 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31634 .61446 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .30572 .59586 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30623 .59563 m .30572 .59586 L .30647 .59385 L .707 .577 .707 r
F
.29812 .54182 m .31444 .53374 L p .30647 .59385 L F P
0 g
s
.30572 .59586 m .29812 .54182 L p .30647 .59385 L .707 .577 .707 r
F P
0 g
s
.29812 .54182 m .30572 .59586 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.29899 .61222 m .3 .60284 L .30371 .59831 L .707 .577 .707 r
F
.29871 .60442 m .3 .60284 L .29899 .61222 L F
.29882 .60428 m .29871 .60442 L .29881 .60311 L F
.29871 .60442 m .29099 .54947 L p .29881 .60311 L F P
0 g
s
.29289 .63019 m .29871 .60442 L p .29899 .61222 L .707 .577 .707 r
F P
0 g
s
.48504 .68452 m .49301 .64925 L .47676 .65556 L p .707 .577 .707 r
F P
0 g
s
.68307 .64881 m .69103 .61355 L .71988 .61497 L p .707 .577 .707 r
F P
0 g
s
.80821 .63994 m .80024 .6752 L .77352 .66411 L p .707 .577 .707 r
F P
0 g
s
.77352 .66411 m .78149 .62884 L .80821 .63994 L p .707 .577 .707 r
F P
0 g
s
.71836 .61204 m .71051 .55621 L .74206 .55138 L p .707 .577 .707 r
F P
0 g
s
.71051 .55621 m .71836 .61204 L .6892 .61863 L p .707 .577 .707 r
F P
0 g
s
.31233 .69882 m .31443 .71745 L .3353 .72065 L p .707 .577 .707 r
F P
0 g
s
.74206 .55138 m .74991 .60721 L .71836 .61204 L p .707 .577 .707 r
F P
0 g
s
.66564 .72594 m .66354 .70731 L .6875 .70001 L p .707 .577 .707 r
F P
0 g
s
.6875 .70001 m .6896 .71863 L .66564 .72594 L p .707 .577 .707 r
F P
0 g
s
.71988 .61497 m .71192 .65023 L .68307 .64881 L p .707 .577 .707 r
F P
0 g
s
.71192 .65023 m .71988 .61497 L .75105 .62024 L p .707 .577 .707 r
F P
0 g
s
.78149 .62884 m .77352 .66411 L .74309 .6555 L p .707 .577 .707 r
F P
0 g
s
.74309 .6555 m .75105 .62024 L .78149 .62884 L p .707 .577 .707 r
F P
0 g
s
.80661 .68911 m .80871 .70773 L .78146 .70694 L p .707 .577 .707 r
F P
0 g
s
.78146 .70694 m .77936 .68832 L .80661 .68911 L p .707 .577 .707 r
F P
0 g
s
.75105 .62024 m .74309 .6555 L .71192 .65023 L p .707 .577 .707 r
F P
0 g
s
.31443 .71745 m .31233 .69882 L .29988 .69352 L p .707 .577 .707 r
F P
0 g
s
.49224 .67509 m .50021 .63983 L .49301 .64925 L p .707 .577 .707 r
F P
0 g
s
.6896 .71863 m .6875 .70001 L .71674 .69405 L p .707 .577 .707 r
F P
0 g
s
.29988 .69352 m .30198 .71214 L .31443 .71745 L p .707 .577 .707 r
F P
0 g
s
.49294 .52547 m .50079 .5813 L .49803 .57482 L p .707 .577 .707 r
F P
0 g
s
.49803 .57482 m .49019 .51899 L .49294 .52547 L p .707 .577 .707 r
F P
0 g
s
.71674 .69405 m .71884 .71267 L .6896 .71863 L p .707 .577 .707 r
F P
0 g
s
.77936 .68832 m .78146 .70694 L .75049 .70865 L p .707 .577 .707 r
F P
0 g
s
.75049 .70865 m .74839 .69002 L .77936 .68832 L p .707 .577 .707 r
F P
0 g
s
.49261 .67589 m .49471 .69451 L .50182 .68672 L p .707 .577 .707 r
F P
0 g
s
.50182 .68672 m .49972 .66809 L .49261 .67589 L p .707 .577 .707 r
F P
0 g
s
.71884 .71267 m .71674 .69405 L .74839 .69002 L p .707 .577 .707 r
F P
0 g
s
.74839 .69002 m .75049 .70865 L .71884 .71267 L p .707 .577 .707 r
F P
0 g
s
.30198 .71214 m .29988 .69352 L .29708 .68663 L p .707 .577 .707 r
F P
0 g
s
.50021 .63983 m .49224 .67509 L .48969 .66347 L p .707 .577 .707 r
F P
0 g
s
.48969 .66347 m .49468 .64136 L p .50021 .63983 L .707 .577 .707 r
F P
0 g
s
.49765 .6282 m .48969 .66347 L .47762 .65079 L p .707 .577 .707 r
F P
0 g
s
.48657 .67452 m .48541 .6642 L p .49692 .66121 L .707 .577 .707 r
F P
0 g
s
.48541 .6642 m .48447 .6559 L .48814 .65747 L p .707 .577 .707 r
F P
0 g
s
.48814 .65747 m .49692 .66121 L p .48541 .6642 L .707 .577 .707 r
F P
0 g
s
.49468 .64136 m .49765 .6282 L .49848 .63199 L p .707 .577 .707 r
F P
0 g
s
.49848 .63199 m .50021 .63983 L p .49468 .64136 L .707 .577 .707 r
F P
0 g
s
.29708 .68663 m .29918 .70526 L .30198 .71214 L p .707 .577 .707 r
F P
0 g
s
.49019 .51899 m .49803 .57482 L .48567 .57015 L p .707 .577 .707 r
F P
0 g
s
.48567 .57015 m .47782 .51432 L .49019 .51899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49972 .66809 m .50182 .68672 L .49902 .67983 L p .707 .577 .707 r
F P
0 g
s
.49902 .67983 m .49692 .66121 L .49972 .66809 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29918 .70526 m .29708 .68663 L .30419 .67884 L p .707 .577 .707 r
F P
0 g
s
.47762 .65079 m .48559 .61552 L .49765 .6282 L p .707 .577 .707 r
F P
0 g
s
.30419 .67884 m .30629 .69746 L .29918 .70526 L p .707 .577 .707 r
F P
0 g
s
.47782 .51432 m .48567 .57015 L .4649 .56774 L p .707 .577 .707 r
F P
0 g
s
.4649 .56774 m .45705 .51192 L .47782 .51432 L p .707 .577 .707 r
F P
0 g
s
.49692 .66121 m .49902 .67983 L .48657 .67452 L p .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .34802 .57663 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .32216 .58869 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32431 .57919 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.34802 .57663 m .34644 .58362 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.33835 .52602 m .34619 .58185 L .3302 .58701 L p .707 .577 .707 r
F P
0 g
s
.3302 .58701 m .32229 .58956 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32253 .58861 m .33835 .52602 L .3302 .58701 L .707 .577 .707 r
F
.34005 .61189 m .31634 .61446 L p .34126 .5847 L F P
0 g
s
.34644 .58362 m .34005 .61189 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .32216 .58869 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .33835 .52602 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31444 .53374 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.45705 .51192 m .4649 .56774 L .43776 .56784 L p .707 .577 .707 r
F P
0 g
s
.43776 .56784 m .42991 .51202 L .45705 .51192 L p .707 .577 .707 r
F P
0 g
s
.48559 .61552 m .47762 .65079 L .45723 .63828 L p .707 .577 .707 r
F P
0 g
s
.45723 .63828 m .4652 .60302 L .48559 .61552 L p .707 .577 .707 r
F P
0 g
s
.30629 .69746 m .30419 .67884 L .32053 .6709 L p .707 .577 .707 r
F P
0 g
s
.32053 .6709 m .32263 .68952 L .30629 .69746 L p .707 .577 .707 r
F P
0 g
s
.34619 .58185 m .33835 .52602 L .3675 .51943 L p .707 .577 .707 r
F P
0 g
s
.48447 .6559 m .48657 .67452 L .4657 .67132 L p .707 .577 .707 r
F P
0 g
s
.4657 .67132 m .4636 .6527 L .48447 .6559 L p .707 .577 .707 r
F P
0 g
s
.42991 .51202 m .43776 .56784 L .4069 .57043 L p .707 .577 .707 r
F P
0 g
s
.4069 .57043 m .39905 .5146 L .42991 .51202 L p .707 .577 .707 r
F P
0 g
s
.34005 .61189 m .34802 .57663 L .37687 .57805 L p .707 .577 .707 r
F P
0 g
s
.4652 .60302 m .45723 .63828 L .43051 .62719 L p .707 .577 .707 r
F P
0 g
s
.43051 .62719 m .43848 .59192 L .4652 .60302 L p .707 .577 .707 r
F P
0 g
s
.37535 .57526 m .3675 .51943 L .39905 .5146 L p .707 .577 .707 r
F P
0 g
s
.3675 .51943 m .37535 .57526 L .34619 .58185 L p .707 .577 .707 r
F P
0 g
s
.39905 .5146 m .4069 .57043 L .37535 .57526 L p .707 .577 .707 r
F P
0 g
s
.32263 .68952 m .32053 .6709 L .34449 .66359 L p .707 .577 .707 r
F P
0 g
s
.34449 .66359 m .34659 .68222 L .32263 .68952 L p .707 .577 .707 r
F P
0 g
s
.37687 .57805 m .36891 .61331 L .34005 .61189 L p .707 .577 .707 r
F P
0 g
s
.36891 .61331 m .37687 .57805 L .40804 .58332 L p .707 .577 .707 r
F P
0 g
s
.43848 .59192 m .43051 .62719 L .40008 .61858 L p .707 .577 .707 r
F P
0 g
s
.40008 .61858 m .40804 .58332 L .43848 .59192 L p .707 .577 .707 r
F P
0 g
s
.4636 .6527 m .4657 .67132 L .43845 .67053 L p .707 .577 .707 r
F P
0 g
s
.43845 .67053 m .43635 .65191 L .4636 .6527 L p .707 .577 .707 r
F P
0 g
s
.40804 .58332 m .40008 .61858 L .36891 .61331 L p .707 .577 .707 r
F P
0 g
s
.34659 .68222 m .34449 .66359 L .37373 .65764 L p .707 .577 .707 r
F P
0 g
s
.37373 .65764 m .37583 .67626 L .34659 .68222 L p .707 .577 .707 r
F P
0 g
s
.43635 .65191 m .43845 .67053 L .40748 .67223 L p .707 .577 .707 r
F P
0 g
s
.40748 .67223 m .40538 .65361 L .43635 .65191 L p .707 .577 .707 r
F P
0 g
s
.37583 .67626 m .37373 .65764 L .40538 .65361 L p .707 .577 .707 r
F P
0 g
s
.40538 .65361 m .40748 .67223 L .37583 .67626 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01EYF3P0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP0015YF2@0015YF00<005YF
FUH015YF00<005YFFUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IGoo001UOol00`00FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol006=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00E7oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000IOolJ000cOol0059oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Eoo`@0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00DWoo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80015oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000=Ool400000eYF
001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH01000
FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1P0000EJEP00001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800004Ool000000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP0:0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000EJEP03001JEUYF009JEPD000IJEP04001JEUYF
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001COol01000FUIJEP0015YF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001EYF0`001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool004moo`H0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF009JEPh000=JEP05001JEUYFFUH0000]Ool004Ioo`T000AJEP800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000MJEP03001JEUYF00=JEPH0009J
EP03001oogoo02]oo`00@7oo1P0015YF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEUYFFUH4000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<000=JEQ@000AJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00>7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEQ`000QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00@000EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00=7oo100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEP0000EJEP03
001JEUYF00@000IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004
FUH01000FUIJEUYF10001eYF00<005YFFUH015YF1P0025YF00<005YFFUH015YF00<005YFFUH00UYF
0P00;Woo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20004FUH3
0005FUH00`00FUIJEP040006FUH00`00FUIJEP05FUH300000eYF001JEP06FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00<7oo0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01000
1UYF10001EYF00<005YF00000P001UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH400000eYF001JEP06FUH01000
FUIJEP00<7oo000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH40002FUH40006FUH50004FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001UYF0`00<Goo000]Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP04FUH01@00FUH00000FUH010001EYF1P0015YF00<005YFFUH015YF0P0000=JEP00FUH01EYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP8003=oo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00@005YFFUIJEPD000EJ
EPH000AJEP03001JEUYF00IJEP8000IJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@003Eoo`00:goo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF00<005YF00000P001EYF00<005YFFUH025YF0P0015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
=Goo000[Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEP00=7oo000[Ool01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YF00000P0015YF0P00
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF00@005YFFUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPD00003FUH0
05YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo02moo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00L000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUHB0004Ool40007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00EJEPP000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH30005FUH01000FUIJEP003Woo10000UYF
00<005YFFUH01UYF00<005YFFUH015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90007FUH01P00FUH00000FUH0009JEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00
15YF00@005YFFUH0019oo`<000QJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP04001JEUYFFUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
0eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001oogoo00Qoo`<000Qoo`8000IJEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00X000QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPl000=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH30003FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0027oo1@002Goo0P00
0eYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;7oo00<005YF00001EYF00<005YFFUH00eYF
10001UYF00<005YFFUH010001EYF00<005YFFUH01EYF10001EYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@001eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP04001JEP000002FUH20008Ool5000;Ool2
00000eYF001JEP05FUH01000FUIJEUYF0P00;Goo000/Ool01000FUIJEP0015YF00@005YFFUIJEP80
0003FUH005YF00IJEP03001JEUYF00EJEP@00003FUH005YF00EJEP80009JEP03001JEUYF00AJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH500000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00@0
05YFFUIJEP@000Qoo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool01000FUIJEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`000eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF10001Woo0`0047oo0P000eYF
00@005YFFUIJEP<002eoo`00;7oo00@005YFFUH0009JEP03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00=JEP@00004FUH00000FUH300000eYF
000000040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0`0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH010005goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUH000040002Ool01000FUIJEP0015YF1`000eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005OolA0003FUH2000^
Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0003FUH40005Ool01000FUIJEP001EYF3@0015YF00@005YFFUIJEPH000AJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPT000AJEP03001JEUYF00EJEP03001JEUYF
00@00003FUH0000002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00800003FUH0000000Ioo`04001JEUYF0005
FUH00`00FUH000020005FUH00`00FUIJEP080005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200000eYF000000020002FUH30004Ool01000FUIJEP001EYF00<005YFFUH015YF1@001eYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEPL0009JEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00004FUH005YFFUHI0004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUH000020003FUH40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool20003FUHB0007FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool2
00000eYF000000030003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01@00FUIJEUYF0000;Goo000/
Ool01000FUH000000UYF00<007ooOol03`0017oo1@001UYF00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P00
00=JEP00FUH01UYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
00<007ooOol0:goo000/Ool30003FUH3000HOol40002FUH00`00FUIJEP0200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF1P00;7oo000/Ool30003FUH00`00FUIJEP02000JOol40003FUH;0004FUH00`00FUIJEP02FUH8
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP03FUH400000goo000000020002FUH00`00FUH0
00040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP000000;7oo000/
Ool30002FUH00`00FUIJEP03FUH3000>Ool3000:Ool20004FUH00`00FUIJEP04FUH:00000eYF001J
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000300000eYF00000006Ool90003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUH0000/Ool002aoo`8000=J
EP03001JEUYF00AJEP04001JEP00000;Ool5000;Ool200000eYF001JEP05FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP<000ao
o`D0009JEP03001JEUYF00IJEP04001JEUYFFUH50005FUH2000]Ool002eoo`05001JEUYFFUH00006
FUH01000FUIJEUYF0`0027oo1@003Goo0P001UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYF001JEP07000@Ool300000goo0000000=0004FUH00`00
FUIJEP03FUH00`00Oomoo`0/Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH30005Ool5
000?Ool20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00000015YF00<007ooOol057oo2@0015YF00<005YFFUH015YF00<005YFFUH00P00;goo
000^Ool01000FUIJEP001EYF00<005YFFUH01UYF00@005YF000000Aoo`<0019oo`05001JEUYFFUH0
0002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000002@0027oo
2@0015YF00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000^Ool00`00FUH00006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH3000GOol30003FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8003=oo`00;goo0P001UYF00<005YFFUH01EYF00<005YFFUH01EYF1P00
17oo3P0000=oo`00FUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eoo`00
<7oo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJ
EP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000iOol0035oo`8000=JEP03
001JEUYF00EJEPX000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000nOol003=oo`800004FUH005YFFUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00
FUIJEP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUH000040006FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP040015Ool003Eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP8000IJEQL004Uoo`00=7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200015YF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP8000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJ
EP<000AJEP03001JEUYF00AJEP04001JEUYFFUH2001DOol0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEPd0009JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
00Ioo`00000005YF0006FUH01000FUIJEUYF0P00E7oo000`Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P0000=J
EP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000017oo0P001UYF00H005YFFUH005YF001DOol0
02moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP@000Ioo`8000=JEP04001JEUYFFUH3001DOol002ioo`8000AJEP03001JEUYF00=J
EP@000Aoo`<00003FUH0000000@000=JEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000Qoo`800003FUH005YF009J
EP03001JEP0005Aoo`00;Goo00<005YF000015YF00<005YF00000`002goo1`000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000Moo`8000=JEP8005Eoo`00;Goo00@005YFFUH000=JEP80015oo``000AJEP04001J
EUYFFUH60003FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000eYF1`000Woo
00<005YFFUH00P00EGoo000]Ool01@00FUIJEP00FUH00P0057oo0`0027oo20001EYF00@005YFFUIJ
EP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP07001EOol0
02ioo`03001JEP0000<001Uoo`H000IJEP03001JEUYF00AJEP06001JEP00001oo`0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000MJEP03001JEUYF00=JEP04001JEP00001EOol002io
o`800004FUH005YFFUH70009Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo000^Ool01000FUIJEP001EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00008000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000aoo`<000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEPl000=JEP05001JEUYFFUH0001DOol002ioo`05001JEUYFFUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000BOol30006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH0
00030008FUH00`00FUIJEP03FUH60002FUH00`00Oomoo`1BOol002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL001Uoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH6001COol0035oo`@000=JEP03001JEUYF00EJEP03001J
EUYF009JEPP002Aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF0000001C
Ool003Eooa00035oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EP0000P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0001C
Ool007aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP06001JEP00001JEWoo0UYF0P00E7oo0024OolJ000;OolI0005FUH2001DOol0
08ioo`03001JEUYF008001Moo`<00003Ool0000000T0009JEP03001JEUYF00AJEP04001JEUYFFUH2
001EOol008moo`800003FUH00000008000moo`T000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP00001GOol008moo`80009JEP03001JEUYF00l000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<005Uoo`00Sgoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00G7oo002?Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001P
Ool0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@006=oo`00TWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
1`00Igoo002FOolI001^Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59966 .7419 m .58703 .68652 L .55669 .69188 L p .707 .577 .707 r
F P
0 g
s
.58703 .68652 m .59966 .7419 L .63075 .73457 L p .707 .577 .707 r
F P
0 g
s
.63075 .73457 m .61812 .6792 L .58703 .68652 L p .707 .577 .707 r
F P
0 g
s
.61812 .6792 m .63075 .73457 L .65954 .726 L p .707 .577 .707 r
F P
0 g
s
.65954 .726 m .64691 .67063 L .61812 .6792 L p .707 .577 .707 r
F P
0 g
s
.56931 .74725 m .55669 .69188 L .53005 .69474 L p .707 .577 .707 r
F P
0 g
s
.55669 .69188 m .56931 .74725 L .59966 .7419 L p .707 .577 .707 r
F P
0 g
s
.64691 .67063 m .65954 .726 L .68321 .71702 L p .707 .577 .707 r
F P
0 g
s
.68321 .71702 m .67059 .66164 L .64691 .67063 L p .707 .577 .707 r
F P
0 g
s
.53005 .69474 m .54268 .75011 L .56931 .74725 L p .707 .577 .707 r
F P
0 g
s
.58697 .81857 m .59968 .78531 L .57043 .77279 L p .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .62906 .82137 L .59874 .82721 L p .707 .577 .707 r
F P
0 g
s
.59874 .82721 m .59771 .82741 L p .59827 .82761 L .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .59874 .82721 L .59827 .82761 L .707 .577 .707 r
F
.63245 .83992 m .66145 .83237 L p .63217 .82242 L F P
0 g
s
.62906 .82137 m .62964 .8245 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.62964 .8245 m .63245 .83992 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .65807 .81382 L .62906 .82137 L p .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .68526 .82404 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65807 .81382 m .65941 .82117 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65941 .82117 m .66145 .83237 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .68187 .80549 L .67028 .80954 L p .707 .577 .707 r
F P
0 g
s
.67028 .80954 m .65807 .81382 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .67028 .80954 L .66415 .8161 L .707 .577 .707 r
F
.68187 .80549 m .68526 .82404 L .70155 .81575 L p F P
0 g
s
.70155 .81575 m .69816 .7972 L .68187 .80549 L p .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .69703 .79188 L .68174 .79729 L p .707 .577 .707 r
F P
0 g
s
.68174 .79729 m .68096 .79757 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .68174 .79729 L .68102 .79806 L .707 .577 .707 r
F
.66825 .83083 m .68431 .82514 L p .68102 .79806 L F P
0 g
s
.68096 .79757 m .6806 .79851 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.6806 .79851 m .66825 .83083 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .66825 .83083 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65779 .79833 m .65606 .80285 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65606 .80285 m .64508 .8316 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .64508 .8316 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62978 .79411 m .62593 .8042 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62593 .8042 m .61707 .82737 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.59968 .78531 m .58697 .81857 L .61707 .82737 L p .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .62978 .79411 L .59968 .78531 L p .707 .577 .707 r
F P
0 g
s
.55771 .80605 m .57043 .77279 L .54489 .75778 L p .707 .577 .707 r
F P
0 g
s
.57043 .77279 m .55771 .80605 L .58697 .81857 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53005 .69474 L .50974 .69483 L p .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .65779 .79833 L .62978 .79411 L p .707 .577 .707 r
F P
0 g
s
.67059 .66164 m .68321 .71702 L .69945 .7085 L p .707 .577 .707 r
F P
0 g
s
.69945 .7085 m .68683 .65313 L .67059 .66164 L p .707 .577 .707 r
F P
0 g
s
.6011 .84596 m .59771 .82741 L .56707 .83133 L p .707 .577 .707 r
F P
0 g
s
.59771 .82741 m .6011 .84596 L .63245 .83992 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53556 .73816 L .52235 .75015 L .707 .577 .707 r
F
.50974 .69483 m .52235 .75015 L p .53556 .73816 L F P
0 g
s
.50974 .69483 m .49774 .69214 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.5225 .7502 m .54268 .75011 L p .52235 .75015 L .707 .577 .707 r
F P
0 g
s
.51285 .77501 m .53218 .79104 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52556 .74174 m .52235 .75015 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .51285 .77501 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.51336 .75831 m .52038 .74878 L .5138 .74419 L .707 .577 .707 r
F
.51285 .77501 m .52235 .75015 L p .51336 .75831 L F P
0 g
s
.52234 .75014 m .52224 .74992 L .52193 .74985 L .707 .577 .707 r
F
.49774 .69214 m .50041 .70384 L p .52224 .74992 L F P
0 g
s
.52235 .75015 m .52038 .74878 L .51336 .75831 L .707 .577 .707 r
F
.50041 .70384 m .50882 .74073 L p .51494 .73452 L F P
0 g
s
.49774 .69214 m .49522 .68694 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50163 .75952 m .50882 .74073 L p .50507 .74452 L .707 .577 .707 r
F P
0 g
s
.50882 .74073 m .49774 .69214 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50835 .73946 m .50508 .72636 L .50531 .7312 L .707 .577 .707 r
F
.49522 .68694 m .50531 .7312 L p .50508 .72636 L F P
0 g
s
.50882 .74073 m .50805 .73865 L .50507 .74452 L .707 .577 .707 r
F
.50507 .74452 m .50805 .73865 L .50704 .73591 L F
.49962 .7461 m .50163 .75952 L p .50335 .75202 L F P
0 g
s
.51233 .71283 m .50531 .7312 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .49962 .7461 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.49522 .68694 m .50244 .67972 L p .50613 .72249 L .707 .577 .707 r
F P
0 g
s
.50737 .73679 m .50785 .74231 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51435 .72626 m .51233 .71283 L p .50704 .73591 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .50974 .69483 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.51233 .71283 m .51972 .70279 L p .50827 .72745 L .707 .577 .707 r
F P
0 g
s
.50805 .73865 m .51435 .72626 L .50704 .73591 L .707 .577 .707 r
F
.50785 .74231 m .50531 .7312 L p .50673 .7294 L F P
0 g
s
.50688 .72921 m .51233 .71283 L .50827 .72745 L .707 .577 .707 r
F
.50882 .74073 m .51435 .72626 L p .50805 .73865 L F P
0 g
s
.50882 .74073 m .50163 .75952 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.50785 .74231 m .51036 .74752 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .50882 .74073 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .51494 .73452 L .50882 .74073 L .707 .577 .707 r
F
.50163 .75952 m .51285 .77501 L p .5138 .74419 L F P
0 g
s
.50882 .74073 m .51036 .74752 L p .52193 .74985 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .50882 .74073 L .52193 .74985 L .707 .577 .707 r
F
.51435 .72626 m .50882 .74073 L p .5138 .74419 L F P
0 g
s
.52556 .74174 m .51435 .72626 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .50785 .74231 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .51233 .71283 L p .50688 .72921 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51506 .73509 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .51219 .72249 L p .49962 .7461 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .50701 .73605 L .49982 .74582 L p .707 .577 .707 r
F P
0 g
s
.49982 .74582 m .49962 .7461 L p .51219 .72249 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .53578 .6971 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .51219 .72249 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51972 .70279 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .51506 .73509 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .52877 .71546 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .52877 .71546 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .5313 .72658 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .50701 .73605 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .52307 .73036 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.50701 .73605 m .51219 .72249 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51586 .72093 m .51219 .72249 L .5162 .71492 L .707 .577 .707 r
F
.50244 .67972 m .51868 .6712 L p .5162 .71492 L F P
0 g
s
.51219 .72249 m .50244 .67972 L p .5162 .71492 L .707 .577 .707 r
F P
0 g
s
.50244 .67972 m .51219 .72249 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .50688 .72921 L .50543 .73358 L .707 .577 .707 r
F
.50543 .73358 m .50688 .72921 L .50827 .72745 L F
.50673 .7294 m .50531 .7312 L .50613 .72249 L F
.50531 .7312 m .49522 .68694 L p .50613 .72249 L F P
0 g
s
.49962 .7461 m .50531 .7312 L p .50543 .73358 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52556 .74174 L p .52038 .74878 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .52237 .75021 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.52234 .75014 m .52193 .74985 L .51036 .74752 L .707 .577 .707 r
F
.52237 .75021 m .52235 .75015 L p .52234 .75014 L F P
0 g
s
.52038 .74878 m .52556 .74174 L .5138 .74419 L .707 .577 .707 r
F
.54489 .75778 m .52556 .74174 L p .52692 .75187 L F P
0 g
s
.53218 .79104 m .5446 .75854 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.5446 .75854 m .54489 .75778 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52237 .75021 L .5225 .7502 L p .707 .577 .707 r
F P
0 g
s
.54489 .75778 m .53218 .79104 L .55771 .80605 L p .707 .577 .707 r
F P
0 g
s
.56707 .83133 m .57046 .84989 L .6011 .84596 L p .707 .577 .707 r
F P
0 g
s
.57046 .84989 m .56707 .83133 L .54015 .83277 L p .707 .577 .707 r
F P
0 g
s
.66825 .83083 m .68096 .79757 L .65779 .79833 L p .707 .577 .707 r
F P
0 g
s
.54015 .83277 m .54353 .85133 L .57046 .84989 L p .707 .577 .707 r
F P
0 g
s
.68683 .65313 m .69945 .7085 L .70666 .70128 L p .707 .577 .707 r
F P
0 g
s
.70666 .70128 m .69404 .64591 L .68683 .65313 L p .707 .577 .707 r
F P
0 g
s
.54353 .85133 m .54015 .83277 L .51957 .83158 L p .707 .577 .707 r
F P
0 g
s
.51957 .83158 m .52296 .85013 L .54353 .85133 L p .707 .577 .707 r
F P
0 g
s
.52296 .85013 m .51957 .83158 L .50736 .82787 L p .707 .577 .707 r
F P
0 g
s
.69404 .64591 m .70666 .70128 L .70415 .69608 L p .707 .577 .707 r
F P
0 g
s
.70415 .69608 m .69152 .6407 L .69404 .64591 L p .707 .577 .707 r
F P
0 g
s
.50736 .82787 m .51075 .84642 L .52296 .85013 L p .707 .577 .707 r
F P
0 g
s
.69703 .79188 m .68431 .82514 L .6917 .8151 L p .707 .577 .707 r
F P
0 g
s
.70155 .81575 m .70871 .80831 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.69816 .7972 m .70084 .8119 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70084 .8119 m .70155 .81575 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70871 .80831 m .70533 .78976 L .69816 .7972 L p .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .70405 .78278 L p .69703 .79188 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .70441 .78183 L .70405 .78232 L p .707 .577 .707 r
F P
0 g
s
.70405 .78232 m .69703 .79188 L p .70405 .78278 L .707 .577 .707 r
F P
0 g
s
.70606 .80245 m .70402 .79124 L p .70533 .78976 L .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .68969 .80167 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .6917 .8151 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.68969 .80167 m .70067 .77293 L p .70441 .78183 L .707 .577 .707 r
F P
0 g
s
.70067 .77293 m .7024 .76841 L .70274 .7707 L p .707 .577 .707 r
F P
0 g
s
.70274 .7707 m .70441 .78183 L p .70067 .77293 L .707 .577 .707 r
F P
0 g
s
.7024 .76841 m .68969 .80167 L .67847 .78619 L p .707 .577 .707 r
F P
0 g
s
.69385 .79874 m .69104 .78331 L p .70267 .78389 L .707 .577 .707 r
F P
0 g
s
.69104 .78331 m .69046 .78018 L .69317 .78101 L p .707 .577 .707 r
F P
0 g
s
.69317 .78101 m .70267 .78389 L p .69104 .78331 L .707 .577 .707 r
F P
0 g
s
.70402 .79124 m .70267 .78389 L .70403 .7869 L p .707 .577 .707 r
F P
0 g
s
.70403 .7869 m .70533 .78976 L p .70402 .79124 L .707 .577 .707 r
F P
0 g
s
.70441 .78183 m .70405 .78278 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.48594 .82192 m .49262 .3208 L .44862 .31753 L p .707 .577 .707 r
F P
0 g
s
.51075 .84642 m .50736 .82787 L .50471 .822 L p .707 .577 .707 r
F P
0 g
s
.50471 .822 m .5081 .84056 L .51075 .84642 L p .707 .577 .707 r
F P
0 g
s
.5081 .84056 m .50471 .822 L .51187 .81456 L p .707 .577 .707 r
F P
0 g
s
.51187 .81456 m .51526 .83312 L .5081 .84056 L p .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .55895 .69633 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .53578 .6971 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .54235 .66222 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .52877 .71546 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .51868 .6712 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .5313 .72658 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .55342 .7108 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .55342 .7108 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55497 .71759 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .52307 .73036 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54624 .7296 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .52877 .71546 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51526 .83312 m .51187 .81456 L .52816 .80627 L p .707 .577 .707 r
F P
0 g
s
.52816 .80627 m .53155 .82482 L .51526 .83312 L p .707 .577 .707 r
F P
0 g
s
.53155 .82482 m .52816 .80627 L .55197 .79794 L p .707 .577 .707 r
F P
0 g
s
.49262 .3208 m .48594 .82192 L .53088 .82136 L p .707 .577 .707 r
F P
0 g
s
.53088 .82136 m .53757 .32024 L .49262 .3208 L p .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .58696 .70056 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55895 .69633 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .57114 .65365 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .55342 .7108 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54235 .66222 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .55497 .71759 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .58375 .70896 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .58375 .70896 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58376 .70902 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .54624 .7296 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57425 .73382 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .55342 .7108 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55197 .79794 m .55536 .8165 L .53155 .82482 L p .707 .577 .707 r
F P
0 g
s
.55536 .8165 m .55197 .79794 L .58097 .79039 L p .707 .577 .707 r
F P
0 g
s
.58097 .79039 m .58436 .80894 L .55536 .8165 L p .707 .577 .707 r
F P
0 g
s
.53757 .32024 m .53088 .82136 L .57236 .81702 L p .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58696 .70056 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .60223 .64632 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .58375 .70896 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57114 .65365 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .61707 .70936 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.60223 .64632 m .61485 .7017 L .58376 .70902 L p .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .58375 .70896 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57236 .81702 m .57904 .31589 L .53757 .32024 L p .707 .577 .707 r
F P
0 g
s
.44193 .81865 m .44862 .31753 L .40986 .31073 L p .707 .577 .707 r
F P
0 g
s
.44862 .31753 m .44193 .81865 L .48594 .82192 L p .707 .577 .707 r
F P
0 g
s
.69152 .6407 m .70415 .69608 L .69214 .69339 L p .707 .577 .707 r
F P
0 g
s
.69214 .69339 m .67952 .63801 L .69152 .6407 L p .707 .577 .707 r
F P
0 g
s
.61707 .70936 m .60435 .74262 L .57425 .73382 L p .707 .577 .707 r
F P
0 g
s
.58436 .80894 m .58097 .79039 L .61232 .78435 L p .707 .577 .707 r
F P
0 g
s
.61232 .78435 m .61571 .80291 L .58436 .80894 L p .707 .577 .707 r
F P
0 g
s
.57904 .31589 m .57236 .81702 L .60631 .80931 L p .707 .577 .707 r
F P
0 g
s
.61485 .7017 m .60223 .64632 L .63258 .64097 L p .707 .577 .707 r
F P
0 g
s
.64632 .72188 m .63361 .75514 L .60435 .74262 L p .707 .577 .707 r
F P
0 g
s
.60435 .74262 m .61707 .70936 L .64632 .72188 L p .707 .577 .707 r
F P
0 g
s
.60631 .80931 m .613 .30819 L .57904 .31589 L p .707 .577 .707 r
F P
0 g
s
.70533 .78976 m .70871 .80831 L .70606 .80245 L p .707 .577 .707 r
F P
0 g
s
.40317 .81185 m .40986 .31073 L .38014 .30108 L p .707 .577 .707 r
F P
0 g
s
.40986 .31073 m .40317 .81185 L .44193 .81865 L p .707 .577 .707 r
F P
0 g
s
.25665 .70514 m .24402 .64977 L .21368 .65512 L p .707 .577 .707 r
F P
0 g
s
.24402 .64977 m .25665 .70514 L .28774 .69782 L p .707 .577 .707 r
F P
0 g
s
.28774 .69782 m .27511 .64244 L .24402 .64977 L p .707 .577 .707 r
F P
0 g
s
.27511 .64244 m .28774 .69782 L .31653 .68924 L p .707 .577 .707 r
F P
0 g
s
.31653 .68924 m .30391 .63387 L .27511 .64244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2263 .71049 m .21368 .65512 L .18704 .65799 L p .707 .577 .707 r
F P
0 g
s
.21368 .65512 m .2263 .71049 L .25665 .70514 L p .707 .577 .707 r
F P
0 g
s
.30391 .63387 m .31653 .68924 L .3402 .68026 L p .707 .577 .707 r
F P
0 g
s
.3402 .68026 m .32758 .62489 L .30391 .63387 L p .707 .577 .707 r
F P
0 g
s
.67952 .63801 m .69214 .69339 L .67183 .69348 L p .707 .577 .707 r
F P
0 g
s
.67183 .69348 m .65921 .63811 L .67952 .63801 L p .707 .577 .707 r
F P
0 g
s
.63258 .64097 m .6452 .69634 L .61485 .7017 L p .707 .577 .707 r
F P
0 g
s
.64296 .78042 m .64635 .79898 L .61571 .80291 L p .707 .577 .707 r
F P
0 g
s
.61571 .80291 m .61232 .78435 L .64296 .78042 L p .707 .577 .707 r
F P
0 g
s
.613 .30819 m .60631 .80931 L .62942 .79901 L p .707 .577 .707 r
F P
0 g
s
.62942 .79901 m .63611 .29788 L .613 .30819 L p .707 .577 .707 r
F P
0 g
s
.67847 .78619 m .68733 .76301 L p .7024 .76841 L .707 .577 .707 r
F P
0 g
s
.69118 .75292 m .67847 .78619 L .65915 .77015 L p .707 .577 .707 r
F P
0 g
s
.67328 .79754 m .67 .77957 L p .69046 .78018 L .707 .577 .707 r
F P
0 g
s
.67 .77957 m .66989 .77899 L .67057 .77903 L p .707 .577 .707 r
F P
0 g
s
.67057 .77903 m .69046 .78018 L p .67 .77957 L .707 .577 .707 r
F P
0 g
s
.68733 .76301 m .69118 .75292 L .69392 .75671 L p .707 .577 .707 r
F P
0 g
s
.69392 .75671 m .7024 .76841 L p .68733 .76301 L .707 .577 .707 r
F P
0 g
s
.18704 .65799 m .19967 .71336 L .2263 .71049 L p .707 .577 .707 r
F P
0 g
s
.24396 .78159 m .25667 .74832 L .22742 .7358 L p .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .28606 .78521 L .25475 .79123 L p .707 .577 .707 r
F P
0 g
s
.25475 .79123 m .2547 .79124 L p .25473 .79125 L .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .25475 .79123 L .25473 .79125 L .707 .577 .707 r
F
.28944 .80376 m .31845 .79621 L p .28861 .78607 L F P
0 g
s
.28606 .78521 m .28653 .78778 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.28653 .78778 m .28944 .80376 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .31506 .77765 L .28606 .78521 L p .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .34225 .78788 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.31506 .77765 m .3163 .78445 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.3163 .78445 m .31845 .79621 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .33887 .76933 L .32635 .7737 L p .707 .577 .707 r
F P
0 g
s
.32635 .7737 m .31506 .77765 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .32635 .7737 L .32068 .77977 L .707 .577 .707 r
F
.33887 .76933 m .34225 .78788 L .35854 .77959 L p F P
0 g
s
.35854 .77959 m .35515 .76103 L .33887 .76933 L p .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .35402 .7549 L .33895 .76023 L p .707 .577 .707 r
F P
0 g
s
.33895 .76023 m .33795 .76058 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .33895 .76023 L .33803 .76121 L .707 .577 .707 r
F
.32524 .79385 m .34131 .78816 L p .33803 .76121 L F P
0 g
s
.33795 .76058 m .33749 .76179 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.33749 .76179 m .32524 .79385 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .32524 .79385 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31478 .76135 m .31295 .76613 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31295 .76613 m .30207 .79461 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .30207 .79461 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28677 .75713 m .28282 .76748 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28282 .76748 m .27406 .79039 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.25667 .74832 m .24396 .78159 L .27406 .79039 L p .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .28677 .75713 L .25667 .74832 L p .707 .577 .707 r
F P
0 g
s
.70267 .78389 m .70606 .80245 L .69385 .79874 L p .707 .577 .707 r
F P
0 g
s
.21471 .76907 m .22742 .7358 L .20188 .72079 L p .707 .577 .707 r
F P
0 g
s
.22742 .7358 m .21471 .76907 L .24396 .78159 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .18704 .65799 L .16673 .65808 L p .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .31478 .76135 L .28677 .75713 L p .707 .577 .707 r
F P
0 g
s
.37345 .80221 m .38014 .30108 L .36236 .28953 L p .707 .577 .707 r
F P
0 g
s
.38014 .30108 m .37345 .80221 L .40317 .81185 L p .707 .577 .707 r
F P
0 g
s
.32758 .62489 m .3402 .68026 L .35644 .67174 L p .707 .577 .707 r
F P
0 g
s
.35644 .67174 m .34382 .61637 L .32758 .62489 L p .707 .577 .707 r
F P
0 g
s
.25809 .8098 m .2547 .79124 L .22406 .79517 L p .707 .577 .707 r
F P
0 g
s
.2547 .79124 m .25809 .8098 L .28944 .80376 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .19248 .70129 L .17931 .71325 L .707 .577 .707 r
F
.16673 .65808 m .17931 .71325 L p .19248 .70129 L F P
0 g
s
.16673 .65808 m .15473 .65539 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17984 .71345 m .19967 .71336 L p .17931 .71325 L .707 .577 .707 r
F P
0 g
s
.16984 .73802 m .18917 .75406 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.18255 .70476 m .17931 .71325 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16984 .73802 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17035 .72138 m .17733 .71187 L .17078 .70731 L .707 .577 .707 r
F
.16984 .73802 m .17931 .71325 L p .17035 .72138 L F P
0 g
s
.17925 .71321 m .17893 .71246 L .17797 .71231 L .707 .577 .707 r
F
.15473 .65539 m .15737 .66694 L p .17893 .71246 L F P
0 g
s
.17931 .71325 m .17733 .71187 L .17035 .72138 L .707 .577 .707 r
F
.15737 .66694 m .16577 .70383 L p .1719 .69762 L F P
0 g
s
.15473 .65539 m .15221 .65018 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.15862 .72253 m .16577 .70383 L p .16205 .7076 L .707 .577 .707 r
F P
0 g
s
.16577 .70383 m .15473 .65539 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.1653 .70253 m .16204 .68948 L .16227 .6943 L .707 .577 .707 r
F
.15221 .65018 m .16227 .6943 L p .16204 .68948 L F P
0 g
s
.16577 .70383 m .16501 .70175 L .16205 .7076 L .707 .577 .707 r
F
.16205 .7076 m .16501 .70175 L .16401 .69903 L F
.15661 .70911 m .15862 .72253 L p .1603 .71522 L F P
0 g
s
.16932 .67585 m .16227 .6943 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .15661 .70911 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.15221 .65018 m .15943 .64296 L p .1631 .68548 L .707 .577 .707 r
F P
0 g
s
.16435 .69996 m .16484 .70555 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17134 .68927 m .16932 .67585 L p .16401 .69903 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16673 .65808 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.16932 .67585 m .17671 .6658 L p .16521 .69057 L .707 .577 .707 r
F P
0 g
s
.16501 .70175 m .17134 .68927 L .16401 .69903 L .707 .577 .707 r
F
.16484 .70555 m .16227 .6943 L p .16371 .69248 L F P
0 g
s
.16383 .69232 m .16932 .67585 L .16521 .69057 L .707 .577 .707 r
F
.16577 .70383 m .17134 .68927 L p .16501 .70175 L F P
0 g
s
.16577 .70383 m .15862 .72253 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.16484 .70555 m .16735 .71076 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .16577 .70383 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .1719 .69762 L .16577 .70383 L .707 .577 .707 r
F
.15862 .72253 m .16984 .73802 L p .17078 .70731 L F P
0 g
s
.16577 .70383 m .16735 .71076 L p .17797 .71231 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .16577 .70383 L .17797 .71231 L .707 .577 .707 r
F
.17134 .68927 m .16577 .70383 L p .17078 .70731 L F P
0 g
s
.18255 .70476 m .17134 .68927 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16484 .70555 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16932 .67585 L p .16383 .69232 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17205 .69834 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .16915 .68559 L p .15661 .70911 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .164 .69906 L .15686 .70878 L p .707 .577 .707 r
F P
0 g
s
.15686 .70878 m .15661 .70911 L p .16915 .68559 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .19277 .66011 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16915 .68559 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17671 .6658 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .17205 .69834 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .18572 .67857 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .18572 .67857 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18829 .68982 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .164 .69906 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18006 .69338 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.164 .69906 m .16915 .68559 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17286 .68402 m .16915 .68559 L .17321 .67793 L .707 .577 .707 r
F
.15943 .64296 m .17567 .63445 L p .17321 .67793 L F P
0 g
s
.16915 .68559 m .15943 .64296 L p .17321 .67793 L .707 .577 .707 r
F P
0 g
s
.15943 .64296 m .16915 .68559 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16383 .69232 L .16239 .69666 L .707 .577 .707 r
F
.16239 .69666 m .16383 .69232 L .16521 .69057 L F
.16371 .69248 m .16227 .6943 L .1631 .68548 L F
.16227 .6943 m .15221 .65018 L p .1631 .68548 L F P
0 g
s
.15661 .70911 m .16227 .6943 L p .16239 .69666 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .18255 .70476 L p .17733 .71187 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .17936 .71345 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17925 .71321 m .17797 .71231 L .16735 .71076 L .707 .577 .707 r
F
.17936 .71345 m .17931 .71325 L p .17925 .71321 L F P
0 g
s
.17733 .71187 m .18255 .70476 L .17078 .70731 L .707 .577 .707 r
F
.20188 .72079 m .18255 .70476 L p .18393 .71499 L F P
0 g
s
.18917 .75406 m .20155 .72164 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.20155 .72164 m .20188 .72079 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .17936 .71345 L .17984 .71345 L p .707 .577 .707 r
F P
0 g
s
.20188 .72079 m .18917 .75406 L .21471 .76907 L p .707 .577 .707 r
F P
0 g
s
.22406 .79517 m .22745 .81373 L .25809 .8098 L p .707 .577 .707 r
F P
0 g
s
.65921 .63811 m .67183 .69348 L .6452 .69634 L p .707 .577 .707 r
F P
0 g
s
.6452 .69634 m .63258 .64097 L .65921 .63811 L p .707 .577 .707 r
F P
0 g
s
.32524 .79385 m .33795 .76058 L .31478 .76135 L p .707 .577 .707 r
F P
0 g
s
.22745 .81373 m .22406 .79517 L .19714 .79661 L p .707 .577 .707 r
F P
0 g
s
.65915 .77015 m .67186 .73689 L .69118 .75292 L p .707 .577 .707 r
F P
0 g
s
.19714 .79661 m .20053 .81516 L .22745 .81373 L p .707 .577 .707 r
F P
0 g
s
.69046 .78018 m .69385 .79874 L .67328 .79754 L p .707 .577 .707 r
F P
0 g
s
.67186 .73689 m .65915 .77015 L .63361 .75514 L p .707 .577 .707 r
F P
0 g
s
.63361 .75514 m .64632 .72188 L .67186 .73689 L p .707 .577 .707 r
F P
0 g
s
.63611 .29788 m .62942 .79901 L .63942 .7871 L p .707 .577 .707 r
F P
0 g
s
.63942 .7871 m .64611 .28598 L .63611 .29788 L p .707 .577 .707 r
F P
0 g
s
.34382 .61637 m .35644 .67174 L .36365 .66453 L p .707 .577 .707 r
F P
0 g
s
.36365 .66453 m .35103 .60915 L .34382 .61637 L p .707 .577 .707 r
F P
0 g
s
.20053 .81516 m .19714 .79661 L .17656 .79541 L p .707 .577 .707 r
F P
0 g
s
.17656 .79541 m .17995 .81397 L .20053 .81516 L p .707 .577 .707 r
F P
0 g
s
.35103 .60915 m .36365 .66453 L .36114 .65932 L p .707 .577 .707 r
F P
0 g
s
.36114 .65932 m .34851 .60395 L .35103 .60915 L p .707 .577 .707 r
F P
0 g
s
.35515 .76103 m .35854 .77959 L .36395 .77397 L p .707 .577 .707 r
F P
0 g
s
.36395 .77397 m .36571 .77215 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35515 .76103 L .36395 .77397 L .707 .577 .707 r
F
.36236 .28953 m .35828 .2772 L p .35665 .59931 L F P
0 g
s
.35983 .75618 m .35515 .76103 L p .35886 .76494 L .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .36094 .74606 L p .35402 .7549 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .3614 .74485 L .36094 .74547 L p .707 .577 .707 r
F P
0 g
s
.36094 .74547 m .35402 .7549 L p .36094 .74606 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .35983 .75618 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36305 .76628 m .36091 .75453 L p .36232 .75359 L .707 .577 .707 r
F P
0 g
s
.35402 .7549 m .34131 .78816 L .34869 .77811 L p .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .34668 .76469 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .34869 .77811 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36091 .75453 m .35967 .74773 L .36092 .75051 L p .707 .577 .707 r
F P
0 g
s
.36092 .75051 m .36232 .75359 L p .36091 .75453 L .707 .577 .707 r
F P
0 g
s
.3614 .74485 m .36094 .74606 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35983 .75618 L .35886 .76494 L .707 .577 .707 r
F
.36571 .77215 m .36333 .75912 L p .36379 .77013 L F P
0 g
s
.36333 .75912 m .36232 .75359 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.34851 .60395 m .36114 .65932 L .34914 .65663 L p .707 .577 .707 r
F P
0 g
s
.34668 .76469 m .35756 .73621 L p .3614 .74485 L .707 .577 .707 r
F P
0 g
s
.35756 .73621 m .35939 .73143 L .35975 .73385 L p .707 .577 .707 r
F P
0 g
s
.35975 .73385 m .3614 .74485 L p .35756 .73621 L .707 .577 .707 r
F P
0 g
s
.35939 .73143 m .34668 .76469 L .33808 .75281 L p .707 .577 .707 r
F P
0 g
s
.33808 .75281 m .33546 .7492 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .35939 .73143 L .33808 .75281 L .707 .577 .707 r
F
.35785 .62804 m .36236 .28953 L p .35665 .59931 L F P
0 g
s
.35084 .76257 m .34792 .74659 L p .35967 .74773 L .707 .577 .707 r
F P
0 g
s
.34968 .7447 m .35967 .74773 L p .34792 .74659 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .36571 .77215 L .36305 .76628 L p .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .3453 .72525 L .35939 .73143 L .707 .577 .707 r
F
.33546 .7492 m .33943 .73883 L p .33865 .74683 L F P
0 g
s
.33943 .73883 m .34817 .71594 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .33546 .7492 L .31614 .73317 L p .707 .577 .707 r
F P
0 g
s
.33027 .76138 m .32688 .74285 L p .34745 .74402 L .707 .577 .707 r
F P
0 g
s
.32688 .74285 m .32688 .74282 L .32691 .74283 L p .707 .577 .707 r
F P
0 g
s
.32691 .74283 m .34745 .74402 L p .32688 .74285 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .35098 .71982 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35098 .71982 m .35939 .73143 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35967 .74773 m .36305 .76628 L .35084 .76257 L p .707 .577 .707 r
F P
0 g
s
.36236 .28953 m .35568 .79065 L .37345 .80221 L p .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35568 .79065 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35573 .78004 m .35785 .62804 L .35665 .59931 L .707 .577 .707 r
F
.35583 .77955 m .35785 .62804 L p .35573 .78004 L F P
0 g
s
.35591 .77318 m .35159 .77832 L p .3588 .55667 L .707 .577 .707 r
F P
0 g
s
.3588 .55667 m .35971 .52868 L .35591 .77318 L .707 .577 .707 r
F
.36159 .76642 m .35591 .77318 L p .35971 .52868 L F P
0 g
s
.36828 .26529 m .36557 .46794 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.36557 .46794 m .36159 .76642 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .36828 .26529 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .35462 .55094 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35462 .55094 m .35159 .77832 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35415 .58625 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35415 .58625 m .35828 .2772 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.34792 .74659 m .34745 .74402 L .34968 .7447 L p .707 .577 .707 r
F P
0 g
s
.35568 .79065 m .35583 .77955 L p .35573 .78004 L .707 .577 .707 r
F P
0 g
s
.66989 .77899 m .67328 .79754 L .64635 .79898 L p .707 .577 .707 r
F P
0 g
s
.64635 .79898 m .64296 .78042 L .66989 .77899 L p .707 .577 .707 r
F P
0 g
s
.17995 .81397 m .17656 .79541 L .16435 .7917 L p .707 .577 .707 r
F P
0 g
s
.16435 .7917 m .16774 .81026 L .17995 .81397 L p .707 .577 .707 r
F P
0 g
s
.64611 .28598 m .63942 .7871 L .63533 .77477 L p .707 .577 .707 r
F P
0 g
s
.63533 .77477 m .64202 .27365 L .64611 .28598 L p .707 .577 .707 r
F P
0 g
s
.16774 .81026 m .16435 .7917 L .1617 .78584 L p .707 .577 .707 r
F P
0 g
s
.1617 .78584 m .16509 .80439 L .16774 .81026 L p .707 .577 .707 r
F P
0 g
s
.34914 .65663 m .33651 .60126 L .34851 .60395 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64202 .27365 m .63533 .77477 L .61756 .76322 L p .707 .577 .707 r
F P
0 g
s
.61756 .76322 m .62425 .26209 L .64202 .27365 L p .707 .577 .707 r
F P
0 g
s
.16509 .80439 m .1617 .78584 L .16887 .7784 L p .707 .577 .707 r
F P
0 g
s
.33651 .60126 m .34914 .65663 L .32882 .65672 L p .707 .577 .707 r
F P
0 g
s
.32882 .65672 m .3162 .60135 L .33651 .60126 L p .707 .577 .707 r
F P
0 g
s
.16887 .7784 m .17225 .79695 L .16509 .80439 L p .707 .577 .707 r
F P
0 g
s
.36159 .76642 m .36828 .26529 L .39139 .25499 L p .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .21594 .65935 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .18572 .67857 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .19277 .66011 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .18829 .68982 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .21038 .6739 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .21038 .6739 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21196 .68083 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .18006 .69338 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .20323 .69261 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .18572 .67857 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .19934 .62546 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .17567 .63445 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.3162 .60135 m .32882 .65672 L .30219 .65958 L p .707 .577 .707 r
F P
0 g
s
.30219 .65958 m .28957 .60421 L .3162 .60135 L p .707 .577 .707 r
F P
0 g
s
.17225 .79695 m .16887 .7784 L .18515 .77011 L p .707 .577 .707 r
F P
0 g
s
.31614 .73317 m .32885 .6999 L .34817 .71594 L p .707 .577 .707 r
F P
0 g
s
.18515 .77011 m .18854 .78866 L .17225 .79695 L p .707 .577 .707 r
F P
0 g
s
.62425 .26209 m .61756 .76322 L .58784 .75357 L p .707 .577 .707 r
F P
0 g
s
.58784 .75357 m .59452 .25245 L .62425 .26209 L p .707 .577 .707 r
F P
0 g
s
.34745 .74402 m .35084 .76257 L .33027 .76138 L p .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .24395 .66357 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .21038 .6739 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21594 .65935 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .21196 .68083 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .24071 .67206 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .24071 .67206 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24075 .67226 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .20323 .69261 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .23124 .69683 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .21038 .6739 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .22813 .61689 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .19934 .62546 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.28957 .60421 m .30219 .65958 L .27184 .66494 L p .707 .577 .707 r
F P
0 g
s
.27184 .66494 m .25922 .60957 L .28957 .60421 L p .707 .577 .707 r
F P
0 g
s
.39139 .25499 m .3847 .75611 L .36159 .76642 L p .707 .577 .707 r
F P
0 g
s
.3847 .75611 m .39139 .25499 L .42534 .24728 L p .707 .577 .707 r
F P
0 g
s
.32885 .6999 m .31614 .73317 L .2906 .71816 L p .707 .577 .707 r
F P
0 g
s
.2906 .71816 m .30331 .68489 L .32885 .6999 L p .707 .577 .707 r
F P
0 g
s
.73686 .64986 m .72424 .59449 L .69389 .59984 L p .707 .577 .707 r
F P
0 g
s
.72424 .59449 m .73686 .64986 L .76795 .64253 L p .707 .577 .707 r
F P
0 g
s
.76795 .64253 m .75533 .58716 L .72424 .59449 L p .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .27406 .67237 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .24071 .67206 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24395 .66357 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.25922 .60957 m .27184 .66494 L .24075 .67226 L p .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .24071 .67206 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .25922 .60957 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .22813 .61689 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.75533 .58716 m .76795 .64253 L .79674 .63396 L p .707 .577 .707 r
F P
0 g
s
.79674 .63396 m .78412 .57859 L .75533 .58716 L p .707 .577 .707 r
F P
0 g
s
.18854 .78866 m .18515 .77011 L .20896 .76178 L p .707 .577 .707 r
F P
0 g
s
.20896 .76178 m .21235 .78033 L .18854 .78866 L p .707 .577 .707 r
F P
0 g
s
.70651 .65521 m .69389 .59984 L .66726 .6027 L p .707 .577 .707 r
F P
0 g
s
.69389 .59984 m .70651 .65521 L .73686 .64986 L p .707 .577 .707 r
F P
0 g
s
.30331 .68489 m .2906 .71816 L .26134 .70564 L p .707 .577 .707 r
F P
0 g
s
.26134 .70564 m .27406 .67237 L .30331 .68489 L p .707 .577 .707 r
F P
0 g
s
.32688 .74282 m .33027 .76138 L .30334 .76282 L p .707 .577 .707 r
F P
0 g
s
.30334 .76282 m .29995 .74426 L .32688 .74282 L p .707 .577 .707 r
F P
0 g
s
.78412 .57859 m .79674 .63396 L .82042 .62498 L p .707 .577 .707 r
F P
0 g
s
.82042 .62498 m .80779 .5696 L .78412 .57859 L p .707 .577 .707 r
F P
0 g
s
.27406 .67237 m .26134 .70564 L .23124 .69683 L p .707 .577 .707 r
F P
0 g
s
.59452 .25245 m .58784 .75357 L .54908 .74678 L p .707 .577 .707 r
F P
0 g
s
.54908 .74678 m .55576 .24565 L .59452 .25245 L p .707 .577 .707 r
F P
0 g
s
.66726 .6027 m .67988 .65808 L .70651 .65521 L p .707 .577 .707 r
F P
0 g
s
.72417 .72653 m .73688 .69327 L .70763 .68075 L p .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .76627 .72933 L .73595 .73517 L p .707 .577 .707 r
F P
0 g
s
.73595 .73517 m .73491 .73537 L p .73547 .73557 L .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .73595 .73517 L .73547 .73557 L .707 .577 .707 r
F
.76966 .74789 m .79866 .74033 L p .76937 .73039 L F P
0 g
s
.76627 .72933 m .76684 .73246 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.76684 .73246 m .76966 .74789 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .79527 .72178 L .76627 .72933 L p .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .82247 .73201 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79527 .72178 m .79661 .72913 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79661 .72913 m .79866 .74033 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .81908 .71345 L .80748 .71751 L p .707 .577 .707 r
F P
0 g
s
.80748 .71751 m .79527 .72178 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .80748 .71751 L .80135 .72407 L .707 .577 .707 r
F
.81908 .71345 m .82247 .73201 L .83875 .72371 L p F P
0 g
s
.83875 .72371 m .83536 .70516 L .81908 .71345 L p .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .83423 .69984 L .81895 .70525 L p .707 .577 .707 r
F P
0 g
s
.81895 .70525 m .81817 .70553 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .81895 .70525 L .81823 .70602 L .707 .577 .707 r
F
.80545 .73879 m .82152 .73311 L p .81823 .70602 L F P
0 g
s
.81817 .70553 m .8178 .70647 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.8178 .70647 m .80545 .73879 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .80545 .73879 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79499 .7063 m .79327 .71081 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79327 .71081 m .78228 .73956 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .78228 .73956 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76699 .70207 m .76313 .71216 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76313 .71216 m .75427 .73534 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.73688 .69327 m .72417 .72653 L .75427 .73534 L p .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .76699 .70207 L .73688 .69327 L p .707 .577 .707 r
F P
0 g
s
.21235 .78033 m .20896 .76178 L .23796 .75423 L p .707 .577 .707 r
F P
0 g
s
.41865 .74841 m .42534 .24728 L .46682 .24294 L p .707 .577 .707 r
F P
0 g
s
.42534 .24728 m .41865 .74841 L .3847 .75611 L p .707 .577 .707 r
F P
0 g
s
.69492 .71401 m .70763 .68075 L .68209 .66574 L p .707 .577 .707 r
F P
0 g
s
.70763 .68075 m .69492 .71401 L .72417 .72653 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .66726 .6027 L .64695 .60279 L p .707 .577 .707 r
F P
0 g
s
.23796 .75423 m .24135 .77278 L .21235 .78033 L p .707 .577 .707 r
F P
0 g
s
.29995 .74426 m .30334 .76282 L .2727 .76674 L p .707 .577 .707 r
F P
0 g
s
.2727 .76674 m .26931 .74819 L .29995 .74426 L p .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .79499 .7063 L .76699 .70207 L p .707 .577 .707 r
F P
0 g
s
.80779 .5696 m .82042 .62498 L .83665 .61646 L p .707 .577 .707 r
F P
0 g
s
.83665 .61646 m .82403 .56109 L .80779 .5696 L p .707 .577 .707 r
F P
0 g
s
.24135 .77278 m .23796 .75423 L .26931 .74819 L p .707 .577 .707 r
F P
0 g
s
.7383 .75392 m .73491 .73537 L .70427 .7393 L p .707 .577 .707 r
F P
0 g
s
.73491 .73537 m .7383 .75392 L .76966 .74789 L p .707 .577 .707 r
F P
0 g
s
.26931 .74819 m .2727 .76674 L .24135 .77278 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .67276 .64612 L .65956 .65811 L .707 .577 .707 r
F
.64695 .60279 m .65956 .65811 L p .67276 .64612 L F P
0 g
s
.64695 .60279 m .63494 .60011 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65971 .65817 m .67988 .65808 L p .65956 .65811 L .707 .577 .707 r
F P
0 g
s
.65006 .68297 m .66938 .699 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.66277 .6497 m .65956 .65811 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65006 .68297 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65057 .66627 m .65759 .65674 L .651 .65215 L .707 .577 .707 r
F
.65006 .68297 m .65956 .65811 L p .65057 .66627 L F P
0 g
s
.65954 .6581 m .65945 .65788 L .65914 .65782 L .707 .577 .707 r
F
.63494 .60011 m .63761 .6118 L p .65945 .65788 L F P
0 g
s
.65956 .65811 m .65759 .65674 L .65057 .66627 L .707 .577 .707 r
F
.63761 .6118 m .64602 .64869 L p .65215 .64248 L F P
0 g
s
.63494 .60011 m .63243 .5949 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.63884 .66748 m .64602 .64869 L p .64227 .65248 L .707 .577 .707 r
F P
0 g
s
.64602 .64869 m .63494 .60011 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64555 .64742 m .64228 .63433 L .64252 .63916 L .707 .577 .707 r
F
.63243 .5949 m .64252 .63916 L p .64228 .63433 L F P
0 g
s
.64602 .64869 m .64526 .64661 L .64227 .65248 L .707 .577 .707 r
F
.64227 .65248 m .64526 .64661 L .64425 .64387 L F
.63682 .65406 m .63884 .66748 L p .64056 .65998 L F P
0 g
s
.64954 .62079 m .64252 .63916 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .63682 .65406 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.63243 .5949 m .63964 .58768 L p .64334 .63045 L .707 .577 .707 r
F P
0 g
s
.64457 .64475 m .64505 .65027 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65155 .63422 m .64954 .62079 L p .64425 .64387 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .64695 .60279 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.64954 .62079 m .65692 .61075 L p .64548 .63541 L .707 .577 .707 r
F P
0 g
s
.64526 .64661 m .65155 .63422 L .64425 .64387 L .707 .577 .707 r
F
.64505 .65027 m .64252 .63916 L p .64394 .63736 L F P
0 g
s
.64409 .63717 m .64954 .62079 L .64548 .63541 L .707 .577 .707 r
F
.64602 .64869 m .65155 .63422 L p .64526 .64661 L F P
0 g
s
.64602 .64869 m .63884 .66748 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.64505 .65027 m .64757 .65548 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .64602 .64869 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .65215 .64248 L .64602 .64869 L .707 .577 .707 r
F
.63884 .66748 m .65006 .68297 L p .651 .65215 L F P
0 g
s
.64602 .64869 m .64757 .65548 L p .65914 .65782 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .64602 .64869 L .65914 .65782 L .707 .577 .707 r
F
.65155 .63422 m .64602 .64869 L p .651 .65215 L F P
0 g
s
.66277 .6497 m .65155 .63422 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64505 .65027 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64954 .62079 L p .64409 .63717 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65226 .64305 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .64939 .63045 L p .63682 .65406 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .64421 .64401 L .63703 .65378 L p .707 .577 .707 r
F P
0 g
s
.63703 .65378 m .63682 .65406 L p .64939 .63045 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .67299 .60506 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64939 .63045 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65692 .61075 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .65226 .64305 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .66597 .62343 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .66597 .62343 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .6685 .63454 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .64421 .64401 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .66028 .63833 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.64421 .64401 m .64939 .63045 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65307 .6289 m .64939 .63045 L .65341 .62288 L .707 .577 .707 r
F
.63964 .58768 m .65588 .57917 L p .65341 .62288 L F P
0 g
s
.64939 .63045 m .63964 .58768 L p .65341 .62288 L .707 .577 .707 r
F P
0 g
s
.63964 .58768 m .64939 .63045 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64409 .63717 L .64263 .64154 L .707 .577 .707 r
F
.64263 .64154 m .64409 .63717 L .64548 .63541 L F
.64394 .63736 m .64252 .63916 L .64334 .63045 L F
.64252 .63916 m .63243 .5949 L p .64334 .63045 L F P
0 g
s
.63682 .65406 m .64252 .63916 L p .64263 .64154 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .66277 .6497 L p .65759 .65674 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .65957 .65817 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65954 .6581 m .65914 .65782 L .64757 .65548 L .707 .577 .707 r
F
.65957 .65817 m .65956 .65811 L p .65954 .6581 L F P
0 g
s
.65759 .65674 m .66277 .6497 L .651 .65215 L .707 .577 .707 r
F
.68209 .66574 m .66277 .6497 L p .66413 .65983 L F P
0 g
s
.66938 .699 m .6818 .6665 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.6818 .6665 m .68209 .66574 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65957 .65817 L .65971 .65817 L p .707 .577 .707 r
F P
0 g
s
.55576 .24565 m .54908 .74678 L .50507 .7435 L p .707 .577 .707 r
F P
0 g
s
.50507 .7435 m .51176 .24238 L .55576 .24565 L p .707 .577 .707 r
F P
0 g
s
.68209 .66574 m .66938 .699 L .69492 .71401 L p .707 .577 .707 r
F P
0 g
s
.70427 .7393 m .70766 .75785 L .7383 .75392 L p .707 .577 .707 r
F P
0 g
s
.46013 .74406 m .46682 .24294 L .51176 .24238 L p .707 .577 .707 r
F P
0 g
s
.46682 .24294 m .46013 .74406 L .41865 .74841 L p .707 .577 .707 r
F P
0 g
s
.70766 .75785 m .70427 .7393 L .67735 .74073 L p .707 .577 .707 r
F P
0 g
s
.80545 .73879 m .81817 .70553 L .79499 .7063 L p .707 .577 .707 r
F P
0 g
s
.51176 .24238 m .50507 .7435 L .46013 .74406 L p .707 .577 .707 r
F P
0 g
s
.67735 .74073 m .68074 .75929 L .70766 .75785 L p .707 .577 .707 r
F P
0 g
s
.82403 .56109 m .83665 .61646 L .84387 .60924 L p .707 .577 .707 r
F P
0 g
s
.84387 .60924 m .83124 .55387 L .82403 .56109 L p .707 .577 .707 r
F P
0 g
s
.68074 .75929 m .67735 .74073 L .65677 .73954 L p .707 .577 .707 r
F P
0 g
s
.65677 .73954 m .66016 .75809 L .68074 .75929 L p .707 .577 .707 r
F P
0 g
s
.66016 .75809 m .65677 .73954 L .64456 .73583 L p .707 .577 .707 r
F P
0 g
s
.83124 .55387 m .84387 .60924 L .84135 .60404 L p .707 .577 .707 r
F P
0 g
s
.84135 .60404 m .82873 .54867 L .83124 .55387 L p .707 .577 .707 r
F P
0 g
s
.64456 .73583 m .64795 .75438 L .66016 .75809 L p .707 .577 .707 r
F P
0 g
s
.83423 .69984 m .82152 .73311 L .82891 .72306 L p .707 .577 .707 r
F P
0 g
s
.83875 .72371 m .84592 .71627 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83536 .70516 m .83805 .71986 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83805 .71986 m .83875 .72371 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.84592 .71627 m .84253 .69772 L .83536 .70516 L p .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .84126 .69074 L p .83423 .69984 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .84162 .6898 L .84126 .69028 L p .707 .577 .707 r
F P
0 g
s
.84126 .69028 m .83423 .69984 L p .84126 .69074 L .707 .577 .707 r
F P
0 g
s
.84327 .71041 m .84122 .69921 L p .84253 .69772 L .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .82689 .70964 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .82891 .72306 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.82689 .70964 m .83788 .68089 L p .84162 .6898 L .707 .577 .707 r
F P
0 g
s
.83788 .68089 m .8396 .67637 L .83995 .67866 L p .707 .577 .707 r
F P
0 g
s
.83995 .67866 m .84162 .6898 L p .83788 .68089 L .707 .577 .707 r
F P
0 g
s
.8396 .67637 m .82689 .70964 L .81567 .69415 L p .707 .577 .707 r
F P
0 g
s
.83106 .7067 m .82824 .69127 L p .83988 .69186 L .707 .577 .707 r
F P
0 g
s
.82824 .69127 m .82767 .68814 L .83038 .68897 L p .707 .577 .707 r
F P
0 g
s
.83038 .68897 m .83988 .69186 L p .82824 .69127 L .707 .577 .707 r
F P
0 g
s
.84122 .69921 m .83988 .69186 L .84124 .69486 L p .707 .577 .707 r
F P
0 g
s
.84124 .69486 m .84253 .69772 L p .84122 .69921 L .707 .577 .707 r
F P
0 g
s
.84162 .6898 m .84126 .69074 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.64795 .75438 m .64456 .73583 L .64191 .72996 L p .707 .577 .707 r
F P
0 g
s
.64191 .72996 m .6453 .74852 L .64795 .75438 L p .707 .577 .707 r
F P
0 g
s
.82873 .54867 m .84135 .60404 L .82935 .60135 L p .707 .577 .707 r
F P
0 g
s
.82935 .60135 m .81673 .54598 L .82873 .54867 L p .707 .577 .707 r
F P
0 g
s
.84253 .69772 m .84592 .71627 L .84327 .71041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39385 .6131 m .38123 .55773 L .35088 .56308 L p .707 .577 .707 r
F P
0 g
s
.38123 .55773 m .39385 .6131 L .42494 .60578 L p .707 .577 .707 r
F P
0 g
s
.42494 .60578 m .41232 .55041 L .38123 .55773 L p .707 .577 .707 r
F P
0 g
s
.41232 .55041 m .42494 .60578 L .45373 .5972 L p .707 .577 .707 r
F P
0 g
s
.45373 .5972 m .44111 .54183 L .41232 .55041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3635 .61846 m .35088 .56308 L .32425 .56595 L p .707 .577 .707 r
F P
0 g
s
.35088 .56308 m .3635 .61846 L .39385 .6131 L p .707 .577 .707 r
F P
0 g
s
.44111 .54183 m .45373 .5972 L .47741 .58822 L p .707 .577 .707 r
F P
0 g
s
.47741 .58822 m .46478 .53285 L .44111 .54183 L p .707 .577 .707 r
F P
0 g
s
.6453 .74852 m .64191 .72996 L .64908 .72252 L p .707 .577 .707 r
F P
0 g
s
.64908 .72252 m .65247 .74108 L .6453 .74852 L p .707 .577 .707 r
F P
0 g
s
.81673 .54598 m .82935 .60135 L .80904 .60144 L p .707 .577 .707 r
F P
0 g
s
.80904 .60144 m .79642 .54607 L .81673 .54598 L p .707 .577 .707 r
F P
0 g
s
.81567 .69415 m .82453 .67097 L p .8396 .67637 L .707 .577 .707 r
F P
0 g
s
.82839 .66089 m .81567 .69415 L .79635 .67812 L p .707 .577 .707 r
F P
0 g
s
.81048 .7055 m .8072 .68753 L p .82767 .68814 L .707 .577 .707 r
F P
0 g
s
.8072 .68753 m .80709 .68695 L .80777 .68699 L p .707 .577 .707 r
F P
0 g
s
.80777 .68699 m .82767 .68814 L p .8072 .68753 L .707 .577 .707 r
F P
0 g
s
.82453 .67097 m .82839 .66089 L .83113 .66467 L p .707 .577 .707 r
F P
0 g
s
.83113 .66467 m .8396 .67637 L p .82453 .67097 L .707 .577 .707 r
F P
0 g
s
.32425 .56595 m .33687 .62132 L .3635 .61846 L p .707 .577 .707 r
F P
0 g
s
.38116 .68955 m .39387 .65628 L .36462 .64376 L p .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .42326 .69317 L .39196 .69919 L p .707 .577 .707 r
F P
0 g
s
.39196 .69919 m .3919 .6992 L p .39193 .69921 L .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .39196 .69919 L .39193 .69921 L .707 .577 .707 r
F
.42665 .71172 m .45565 .70417 L p .42581 .69404 L F P
0 g
s
.42326 .69317 m .42373 .69574 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.42373 .69574 m .42665 .71172 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .45226 .68562 L .42326 .69317 L p .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .47946 .69584 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.45226 .68562 m .4535 .69241 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.4535 .69241 m .45565 .70417 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .47607 .67729 L .46355 .68167 L p .707 .577 .707 r
F P
0 g
s
.46355 .68167 m .45226 .68562 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .46355 .68167 L .45788 .68773 L .707 .577 .707 r
F
.47607 .67729 m .47946 .69584 L .49574 .68755 L p F P
0 g
s
.49574 .68755 m .49235 .669 L .47607 .67729 L p .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .49122 .66286 L .47616 .66819 L p .707 .577 .707 r
F P
0 g
s
.47616 .66819 m .47516 .66854 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .47616 .66819 L .47523 .66918 L .707 .577 .707 r
F
.46244 .70181 m .47851 .69612 L p .47523 .66918 L F P
0 g
s
.47516 .66854 m .47469 .66975 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47469 .66975 m .46244 .70181 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .46244 .70181 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45198 .66931 m .45016 .6741 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45016 .6741 m .43927 .70258 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .43927 .70258 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42398 .66509 m .42002 .67544 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42002 .67544 m .41127 .69835 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.39387 .65628 m .38116 .68955 L .41127 .69835 L p .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .42398 .66509 L .39387 .65628 L p .707 .577 .707 r
F P
0 g
s
.83988 .69186 m .84327 .71041 L .83106 .7067 L p .707 .577 .707 r
F P
0 g
s
.35191 .67703 m .36462 .64376 L .33908 .62875 L p .707 .577 .707 r
F P
0 g
s
.36462 .64376 m .35191 .67703 L .38116 .68955 L p .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32425 .56595 L .30394 .56604 L p .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .45198 .66931 L .42398 .66509 L p .707 .577 .707 r
F P
0 g
s
.46478 .53285 m .47741 .58822 L .49364 .5797 L p .707 .577 .707 r
F P
0 g
s
.49364 .5797 m .48102 .52433 L .46478 .53285 L p .707 .577 .707 r
F P
0 g
s
.39529 .71776 m .3919 .6992 L .36126 .70313 L p .707 .577 .707 r
F P
0 g
s
.3919 .6992 m .39529 .71776 L .42665 .71172 L p .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .69616 .60429 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .66597 .62343 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .67299 .60506 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .6685 .63454 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .69063 .61876 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .69063 .61876 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69218 .62555 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .66028 .63833 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .68345 .63756 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .66597 .62343 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .67955 .57018 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .65588 .57917 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32968 .60925 L .31651 .62121 L .707 .577 .707 r
F
.30394 .56604 m .31651 .62121 L p .32968 .60925 L F P
0 g
s
.30394 .56604 m .29193 .56335 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31704 .62141 m .33687 .62132 L p .31651 .62121 L .707 .577 .707 r
F P
0 g
s
.30705 .64598 m .32637 .66202 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31976 .61272 m .31651 .62121 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30705 .64598 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.30756 .62934 m .31454 .61983 L .30799 .61527 L .707 .577 .707 r
F
.30705 .64598 m .31651 .62121 L p .30756 .62934 L F P
0 g
s
.31646 .62117 m .31614 .62042 L .31517 .62027 L .707 .577 .707 r
F
.29193 .56335 m .29457 .5749 L p .31614 .62042 L F P
0 g
s
.31651 .62121 m .31454 .61983 L .30756 .62934 L .707 .577 .707 r
F
.29457 .5749 m .30298 .61179 L p .30911 .60558 L F P
0 g
s
.29193 .56335 m .28942 .55814 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.29583 .6305 m .30298 .61179 L p .29925 .61557 L .707 .577 .707 r
F P
0 g
s
.30298 .61179 m .29193 .56335 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.3025 .61049 m .29924 .59744 L .29947 .60226 L .707 .577 .707 r
F
.28942 .55814 m .29947 .60226 L p .29924 .59744 L F P
0 g
s
.30298 .61179 m .30221 .60971 L .29925 .61557 L .707 .577 .707 r
F
.29925 .61557 m .30221 .60971 L .30121 .60699 L F
.29381 .61707 m .29583 .6305 L p .2975 .62318 L F P
0 g
s
.30653 .58381 m .29947 .60226 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .29381 .61707 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.28942 .55814 m .29663 .55093 L p .30031 .59344 L .707 .577 .707 r
F P
0 g
s
.30156 .60792 m .30204 .61351 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30854 .59723 m .30653 .58381 L p .30121 .60699 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30394 .56604 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.30653 .58381 m .31391 .57376 L p .30242 .59853 L .707 .577 .707 r
F P
0 g
s
.30221 .60971 m .30854 .59723 L .30121 .60699 L .707 .577 .707 r
F
.30204 .61351 m .29947 .60226 L p .30091 .60044 L F P
0 g
s
.30104 .60028 m .30653 .58381 L .30242 .59853 L .707 .577 .707 r
F
.30298 .61179 m .30854 .59723 L p .30221 .60971 L F P
0 g
s
.30298 .61179 m .29583 .6305 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30204 .61351 m .30456 .61872 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .30298 .61179 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30911 .60558 L .30298 .61179 L .707 .577 .707 r
F
.29583 .6305 m .30705 .64598 L p .30799 .61527 L F P
0 g
s
.30298 .61179 m .30456 .61872 L p .31517 .62027 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30298 .61179 L .31517 .62027 L .707 .577 .707 r
F
.30854 .59723 m .30298 .61179 L p .30799 .61527 L F P
0 g
s
.31976 .61272 m .30854 .59723 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30204 .61351 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30653 .58381 L p .30104 .60028 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .30925 .6063 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .30635 .59355 L p .29381 .61707 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .3012 .60703 L .29406 .61674 L p .707 .577 .707 r
F P
0 g
s
.29406 .61674 m .29381 .61707 L p .30635 .59355 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .32998 .56808 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30635 .59355 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .31391 .57376 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .30925 .6063 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .32293 .58653 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .32293 .58653 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32549 .59778 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .3012 .60703 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31727 .60134 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.3012 .60703 m .30635 .59355 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31006 .59198 m .30635 .59355 L .31041 .5859 L .707 .577 .707 r
F
.29663 .55093 m .31287 .54241 L p .31041 .5859 L F P
0 g
s
.30635 .59355 m .29663 .55093 L p .31041 .5859 L .707 .577 .707 r
F P
0 g
s
.29663 .55093 m .30635 .59355 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30104 .60028 L .29959 .60462 L .707 .577 .707 r
F
.29959 .60462 m .30104 .60028 L .30242 .59853 L F
.30091 .60044 m .29947 .60226 L .30031 .59344 L F
.29947 .60226 m .28942 .55814 L p .30031 .59344 L F P
0 g
s
.29381 .61707 m .29947 .60226 L p .29959 .60462 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31976 .61272 L p .31454 .61983 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .31656 .62141 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31646 .62117 m .31517 .62027 L .30456 .61872 L .707 .577 .707 r
F
.31656 .62141 m .31651 .62121 L p .31646 .62117 L F P
0 g
s
.31454 .61983 m .31976 .61272 L .30799 .61527 L .707 .577 .707 r
F
.33908 .62875 m .31976 .61272 L p .32113 .62295 L F P
0 g
s
.32637 .66202 m .33876 .6296 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.33876 .6296 m .33908 .62875 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31656 .62141 L .31704 .62141 L p .707 .577 .707 r
F P
0 g
s
.33908 .62875 m .32637 .66202 L .35191 .67703 L p .707 .577 .707 r
F P
0 g
s
.36126 .70313 m .36465 .72169 L .39529 .71776 L p .707 .577 .707 r
F P
0 g
s
.79642 .54607 m .80904 .60144 L .78241 .6043 L p .707 .577 .707 r
F P
0 g
s
.78241 .6043 m .76978 .54893 L .79642 .54607 L p .707 .577 .707 r
F P
0 g
s
.46244 .70181 m .47516 .66854 L .45198 .66931 L p .707 .577 .707 r
F P
0 g
s
.36465 .72169 m .36126 .70313 L .33434 .70457 L p .707 .577 .707 r
F P
0 g
s
.65247 .74108 m .64908 .72252 L .66536 .71423 L p .707 .577 .707 r
F P
0 g
s
.79635 .67812 m .80906 .64485 L .82839 .66089 L p .707 .577 .707 r
F P
0 g
s
.33434 .70457 m .33773 .72312 L .36465 .72169 L p .707 .577 .707 r
F P
0 g
s
.66536 .71423 m .66875 .73279 L .65247 .74108 L p .707 .577 .707 r
F P
0 g
s
.82767 .68814 m .83106 .7067 L .81048 .7055 L p .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .72417 .60852 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .69063 .61876 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69616 .60429 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .69218 .62555 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .72095 .61692 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .72095 .61692 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72097 .61698 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .68345 .63756 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .71146 .64178 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .69063 .61876 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .70834 .56161 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .67955 .57018 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.48102 .52433 m .49364 .5797 L .50086 .57249 L p .707 .577 .707 r
F P
0 g
s
.50086 .57249 m .48823 .51712 L .48102 .52433 L p .707 .577 .707 r
F P
0 g
s
.76978 .54893 m .78241 .6043 L .75206 .60966 L p .707 .577 .707 r
F P
0 g
s
.75206 .60966 m .73944 .55428 L .76978 .54893 L p .707 .577 .707 r
F P
0 g
s
.33773 .72312 m .33434 .70457 L .31376 .70337 L p .707 .577 .707 r
F P
0 g
s
.80906 .64485 m .79635 .67812 L .77081 .6631 L p .707 .577 .707 r
F P
0 g
s
.77081 .6631 m .78352 .62984 L .80906 .64485 L p .707 .577 .707 r
F P
0 g
s
.31376 .70337 m .31715 .72193 L .33773 .72312 L p .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .75427 .61732 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .72095 .61692 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72417 .60852 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.73944 .55428 m .75206 .60966 L .72097 .61698 L p .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .72095 .61692 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .73944 .55428 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .70834 .56161 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.66875 .73279 m .66536 .71423 L .68917 .7059 L p .707 .577 .707 r
F P
0 g
s
.68917 .7059 m .69256 .72446 L .66875 .73279 L p .707 .577 .707 r
F P
0 g
s
.78352 .62984 m .77081 .6631 L .74156 .65058 L p .707 .577 .707 r
F P
0 g
s
.74156 .65058 m .75427 .61732 L .78352 .62984 L p .707 .577 .707 r
F P
0 g
s
.80709 .68695 m .81048 .7055 L .78356 .70694 L p .707 .577 .707 r
F P
0 g
s
.78356 .70694 m .78017 .68839 L .80709 .68695 L p .707 .577 .707 r
F P
0 g
s
.75427 .61732 m .74156 .65058 L .71146 .64178 L p .707 .577 .707 r
F P
0 g
s
.31715 .72193 m .31376 .70337 L .30155 .69966 L p .707 .577 .707 r
F P
0 g
s
.48823 .51712 m .50086 .57249 L .49834 .56728 L p .707 .577 .707 r
F P
0 g
s
.49834 .56728 m .48572 .51191 L .48823 .51712 L p .707 .577 .707 r
F P
0 g
s
.30155 .69966 m .30494 .71822 L .31715 .72193 L p .707 .577 .707 r
F P
0 g
s
.69256 .72446 m .68917 .7059 L .71817 .69835 L p .707 .577 .707 r
F P
0 g
s
.49122 .66286 m .47851 .69612 L .4859 .68607 L p .707 .577 .707 r
F P
0 g
s
.49574 .68755 m .50291 .68011 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49235 .669 m .49494 .68314 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49494 .68314 m .49574 .68755 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.50291 .68011 m .49952 .66155 L .49235 .669 L p .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .49814 .65402 L p .49122 .66286 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .49861 .65281 L .49815 .65344 L p .707 .577 .707 r
F P
0 g
s
.49815 .65344 m .49122 .66286 L p .49814 .65402 L .707 .577 .707 r
F P
0 g
s
.50026 .67425 m .49811 .66249 L p .49952 .66155 L .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .48388 .67265 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .4859 .68607 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49811 .66249 m .49687 .65569 L .49813 .65847 L p .707 .577 .707 r
F P
0 g
s
.49813 .65847 m .49952 .66155 L p .49811 .66249 L .707 .577 .707 r
F P
0 g
s
.49861 .65281 m .49814 .65402 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.71817 .69835 m .72156 .71691 L .69256 .72446 L p .707 .577 .707 r
F P
0 g
s
.78017 .68839 m .78356 .70694 L .75292 .71087 L p .707 .577 .707 r
F P
0 g
s
.75292 .71087 m .74953 .69231 L .78017 .68839 L p .707 .577 .707 r
F P
0 g
s
.72156 .71691 m .71817 .69835 L .74953 .69231 L p .707 .577 .707 r
F P
0 g
s
.74953 .69231 m .75292 .71087 L .72156 .71691 L p .707 .577 .707 r
F P
0 g
s
.30494 .71822 m .30155 .69966 L .2989 .6938 L p .707 .577 .707 r
F P
0 g
s
.2989 .6938 m .30229 .71235 L .30494 .71822 L p .707 .577 .707 r
F P
0 g
s
.48572 .51191 m .49834 .56728 L .48634 .56459 L p .707 .577 .707 r
F P
0 g
s
.48634 .56459 m .47372 .50922 L .48572 .51191 L p .707 .577 .707 r
F P
0 g
s
.48388 .67265 m .49477 .64417 L p .49861 .65281 L .707 .577 .707 r
F P
0 g
s
.49659 .63939 m .48388 .67265 L .47266 .65716 L p .707 .577 .707 r
F P
0 g
s
.48805 .67054 m .48513 .65455 L p .49687 .65569 L .707 .577 .707 r
F P
0 g
s
.48513 .65455 m .48466 .65198 L .48689 .65266 L p .707 .577 .707 r
F P
0 g
s
.48689 .65266 m .49687 .65569 L p .48513 .65455 L .707 .577 .707 r
F P
0 g
s
.49477 .64417 m .49659 .63939 L .49696 .64181 L p .707 .577 .707 r
F P
0 g
s
.49696 .64181 m .49861 .65281 L p .49477 .64417 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49952 .66155 m .50291 .68011 L .50026 .67425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30229 .71235 m .2989 .6938 L .30607 .68636 L p .707 .577 .707 r
F P
0 g
s
.47372 .50922 m .48634 .56459 L .46603 .56468 L p .707 .577 .707 r
F P
0 g
s
.46603 .56468 m .45341 .50931 L .47372 .50922 L p .707 .577 .707 r
F P
0 g
s
.30607 .68636 m .30946 .70491 L .30229 .71235 L p .707 .577 .707 r
F P
0 g
s
.47266 .65716 m .48142 .63425 L p .49659 .63939 L .707 .577 .707 r
F P
0 g
s
.48538 .6239 m .47266 .65716 L .45334 .64113 L p .707 .577 .707 r
F P
0 g
s
.46747 .66934 m .46409 .65081 L p .48466 .65198 L .707 .577 .707 r
F P
0 g
s
.46409 .65081 m .46408 .65079 L .46412 .65079 L p .707 .577 .707 r
F P
0 g
s
.46412 .65079 m .48466 .65198 L p .46409 .65081 L .707 .577 .707 r
F P
0 g
s
.48142 .63425 m .48538 .6239 L .48819 .62778 L p .707 .577 .707 r
F P
0 g
s
.48819 .62778 m .49659 .63939 L p .48142 .63425 L .707 .577 .707 r
F P
0 g
s
.49687 .65569 m .50026 .67425 L .48805 .67054 L p .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .35315 .56731 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .32293 .58653 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32998 .56808 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .32549 .59778 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .34759 .58186 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .34759 .58186 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34917 .5888 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .31727 .60134 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34044 .60057 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .32293 .58653 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .33654 .53342 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31287 .54241 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.45341 .50931 m .46603 .56468 L .4394 .56755 L p .707 .577 .707 r
F P
0 g
s
.4394 .56755 m .42677 .51217 L .45341 .50931 L p .707 .577 .707 r
F P
0 g
s
.30946 .70491 m .30607 .68636 L .32235 .67807 L p .707 .577 .707 r
F P
0 g
s
.45334 .64113 m .46605 .60787 L .48538 .6239 L p .707 .577 .707 r
F P
0 g
s
.32235 .67807 m .32574 .69662 L .30946 .70491 L p .707 .577 .707 r
F P
0 g
s
.48466 .65198 m .48805 .67054 L .46747 .66934 L p .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .38116 .57153 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .34759 .58186 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .35315 .56731 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .34917 .5888 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .37791 .58002 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .37791 .58002 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .37796 .58022 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .34044 .60057 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36844 .6048 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .34759 .58186 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .36533 .52485 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .33654 .53342 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.42677 .51217 m .4394 .56755 L .40905 .5729 L p .707 .577 .707 r
F P
0 g
s
.40905 .5729 m .39643 .51753 L .42677 .51217 L p .707 .577 .707 r
F P
0 g
s
.46605 .60787 m .45334 .64113 L .4278 .62612 L p .707 .577 .707 r
F P
0 g
s
.4278 .62612 m .44051 .59285 L .46605 .60787 L p .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .41126 .58033 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .37791 .58002 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .38116 .57153 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.39643 .51753 m .40905 .5729 L .37796 .58022 L p .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .37791 .58002 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .39643 .51753 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36533 .52485 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.32574 .69662 m .32235 .67807 L .34616 .66974 L p .707 .577 .707 r
F P
0 g
s
.34616 .66974 m .34955 .68829 L .32574 .69662 L p .707 .577 .707 r
F P
0 g
s
.44051 .59285 m .4278 .62612 L .39855 .6136 L p .707 .577 .707 r
F P
0 g
s
.39855 .6136 m .41126 .58033 L .44051 .59285 L p .707 .577 .707 r
F P
0 g
s
.46408 .65079 m .46747 .66934 L .44055 .67078 L p .707 .577 .707 r
F P
0 g
s
.44055 .67078 m .43716 .65222 L .46408 .65079 L p .707 .577 .707 r
F P
0 g
s
.41126 .58033 m .39855 .6136 L .36844 .6048 L p .707 .577 .707 r
F P
0 g
s
.34955 .68829 m .34616 .66974 L .37516 .66219 L p .707 .577 .707 r
F P
0 g
s
.37516 .66219 m .37855 .68074 L .34955 .68829 L p .707 .577 .707 r
F P
0 g
s
.43716 .65222 m .44055 .67078 L .40991 .67471 L p .707 .577 .707 r
F P
0 g
s
.40991 .67471 m .40652 .65615 L .43716 .65222 L p .707 .577 .707 r
F P
0 g
s
.37855 .68074 m .37516 .66219 L .40652 .65615 L p .707 .577 .707 r
F P
0 g
s
.40652 .65615 m .40991 .67471 L .37855 .68074 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH6
0003FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF1@001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0009JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000<000MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0069oo`@00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005ioo`@0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05aoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol005Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00F7oo0P001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05Ioo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000XOol;000cOol005Aoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000POol80003FUH0
0`00FUIJEP03FUH01000FUH00000<Goo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000IOol70003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool0059oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8001Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P004Goo10001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP/00005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000?Ool200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool0059oo`800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`<000=JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P001UYF00<005YFFUH015YF00<005YF
FUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0009Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00
0080009JEP05001JEUYFFUH00008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
02moo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005Ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
00IJEP03001JEUYF00EJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP03FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002io
o`00EGoo0P000eYF00@005YFFUIJEP@000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00D7oo1P000UYF1`00
0eYF10000UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@002eoo`00C7oo10000UYF00<0
05YF00001@0015YF00<005YFFUH01EYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<007ooOol0:goo0017Ool50006FUH01@00FUH005YF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000]Ool004=oo`@0009JEP03001JEUYF00MJEP@000=JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPH000UJEP03001JEUYF00EJEP04001JEUYF0009
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00;Woo000oOol40006FUH00`00FUIJEP07FUH00`00FUH00002
0003FUH20002FUH00`00FUIJEP02FUH80002FUH01000FUIJEUYF0P001UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH30007FUH00`00FUH00008FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003]oo`@00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEP00009JEP<0009JEPP00003FUH0000000IJEP03001JEUYF00=JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP<000QJEP03001JEUYF00EJEP04001JEP00000`Ool003Moo`@000EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF009JEP800006FUH005YFFUH005YF0P001UYF00<0
05YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP<0039o
o`00=Goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00@005YFFUH0
00AJEP80009JEP04001JEP000006FUH40005FUH30008FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH2000eOol003=oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP04001JEUYF0004FUH300000eYF001JEP020006FUH50004FUH00`00FUIJEP020005FUH00`00FUIJ
EP04FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000eYF00@005YF000003Moo`00<Goo0P001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH200000eYF00000005FUH6
0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP08FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00MJEPH003Uoo`00;goo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000EJEPH000AJ
EP03001JEUYF00AJEP<000MJEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000=JEP/000AJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2000jOol002eoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH00`00FUIJEP04FUH20006FUH00`00FUH000020005FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF00000005FUH00`00FUIJEP03FUH60007FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000hOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP07FUH00`00FUIJEP07FUH20004FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00Oomoo`0eOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01eYF00<005YFFUH025YF
0`000UYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00D005YFFUIJEP0000MJEP03001JEUYF00=JEP<00003FUH005YF00QJEP03
001JEUYF00IJEP<003Eoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30009FUHE000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH015YF00@005YFFUH000MJEP03001JEUYF00@0009oo`<000QJEP03001JEUYF00EJ
EP05001JEUYFFUH0000dOol002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH01EYF
2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJEP00001JEP00009JEP04001JEUYF0003
FUH60009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH00003FUH00000
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
0P000eYF200047oo0`0000=JEP00FUH01eYF00<005YFFUH015YF00<007ooOol0;goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00Oomoo`0AOol20007FUH00`00
FUIJEP05FUH00`00Oomoo`0_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP02FUH20006FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF0P000eYF00<007ooOol027oo0`00
27oo0P001EYF00<005YFFUH015YF00<005YF0000<7oo000/Ool01000FUIJEP000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01@000eYF00<005YFFUH01UYF00<005YFFUH015YF1P001EYF
00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0`000UYF00<007ooOol01goo1@002Goo0P000eYF
00<005YFFUH01eYF00<007ooOol0;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH30006FUH200000eYF001JEP06FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJ
EP04FUH70007FUH00`00FUIJEP04FUH01000FUH005YF1@0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF00@005YFFUIJEP<000Uoo`D000]oo`<000IJ
EP80009JEP03001oogoo02eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YF
FUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0002FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001UYF00<005YFFUH00eYF
0P0027oo1@003Goo00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;7oo000]Ool01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF
00@005YF000000MJEP03001JEUYF00AJEP@00004FUH000000004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUIJEP00FUH00P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF100025YF00<005YFFUH01EYF0P001goo0`003goo00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0;7oo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00001JEP0000MJEP03001JEUYF00@000=JEPH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200001EYF000005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01eYF0`00
67oo00D005YFFUIJEP0000AJEP8002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH0
1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YFFUH0000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH20004FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0037oo500000=JEP00Ool0;7oo000^Ool20003FUH01000FUIJEUYF10001eYF00<0
05YFFUH01UYF00<005YFFUH01eYF0`0015YF00@005YFFUIJEP800005Ool005YFFUH00004FUH80002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP0000QJEP03001JEUYF
00=JEP8000=oo`L000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002eoo`00;Woo
00<005YFFUH01`000eYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUH000AJEP04
001JEP000003Ool01000FUIJEP001UYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF100025YF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH5
0007FUH00`00FUIJEP06FUH01000FUIJEP000eYF0`001Goo00@005YFFUH000AJEPd000AJEP03001J
EUYF00AJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00002FUH01P00FUIJEUYFOol0
00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP05001JEUYF001JEP020002FUH00`00Oomo
o`03Ool80004FUH00`00FUIJEP06FUH=000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20005FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000/Ool40003FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH200000eYF0000000:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUH000020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0002FUH00`00Oomoo`0[Ool002ao
o`04001JEP000004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP040004Ool20006FUH01000FUH0
00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH010000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0015YF00<005YFFUH015YF0`002EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00D005YFFUH005YF00@002aoo`00;7oo00<005YF00000eYF0P000UYF3@002Woo0P0015YF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF009JEP80009JEP03001JEUYF00MJEP03001JEUYF009JEPT00003OomJ
EUYF009JEP8000EJEP04001JEUYFFUH300000eYF0000000/Ool002aoo`03001oo`0000=JEP03001J
EUYF009JEP8001Ioo`800004FUH005YFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUH000020004FUH00`00FUIJEP06FUH80004
FUH01000FUIJEWoo15YF0P001EYF00@005YFFUIJEP8000=JEP03001oogoo02Yoo`00;Goo00D005YF
FUIJEP00009JEP03OomJEUYF009JEP03001oogoo01Eoo`8000=JEP80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPL000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP800003FUH005YF00EJ
EP03001JEUYF009JEP<0009JEP03001JEP0000@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF008002eoo`00;Goo00D005YFFUIJEP00009JEP03OomJEUYF009JEP<0
00aoo`<000Qoo`8000=JEQ@00003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJ
EP03001JEP0000D00004FUH005YFFUH50003FUH01@00FUIJEUYFOol00UYF0P001EYF00@005YFFUIJ
EP80009JEP03001oogoo02aoo`00;Woo00@005YFFUH0009JEP05OomJEUYFFUH00003FUH00`00Oomo
o`08Ool50009Ool20003FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP02FUH30006Ool300000eYF0000
00030002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8002moo`00;Woo00@0
05YFFUH000IJEP03001JEUYF009JEP03001oogoo00Moo`D000]oo`<000MJEP03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEP000080
00aoo`D000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000aOol002moo`8000IJ
EP03001JEUYF00AJEP8000Moo`D000eoo`03001JEUYF00AJEP800005FUH005YFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH01000FUIJEUYF0`004Woo0`0000=JEP00FUH01eYF00<0
05YFFUH00eYF00<005YFFUH00P00<goo000`Ool00`00FUIJEP04FUH00`00FUIJEP06FUH20006Ool3
000?Ool00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00H005YF000005YF000>Ool700000eYF000000030004FUH00`00FUIJEP03FUH0
1000FUH00000=Goo000aOol00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000005goo00<005YF
00000UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF01@000=JEP03001JEUYF00IJEPd003Moo`00<Woo00D005YFFUIJEP0000QJEP03001JEUYF
009JEP<000Yooa<0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEQT000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol003=oo`04001JEUYF0008
FUH00`00FUIJEP05FUH:0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00
@7oo000dOol20009FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040015Ool003Eo
o`03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH00UYF1P00BGoo000fOol20006FUH400000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF0`000eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YF
FUH00UYF0`000eYF5000Cgoo000hOol60005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH@0002FUH0
0`00FUH000030006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH300000eYF001JEP03FUH200000goo00000003FUH00`00FUIJEP07FUH00`00
Oomoo`1DOol003Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP04001JEP000002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000goo0`00
1eYF00@005YFFUH005Ioo`00=7oo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF20001eYF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP8000Eoo`03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05=oo`00<goo0P001eYF00<005YF
FUH015YF200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF10001Woo00<005YFFUH00eYF00<005YFFUH00UYF00<007oo
Ool0Dgoo000aOol200000eYF001JEP06FUH00`00FUIJEP040003FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000
00Moo`05001JEUYFFUH00004FUH2001EOol0031oo`05001JEUYFFUH00006FUH40003Ool200000eYF
001JEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000400000AJEP00FUH005Aoo`00;Woo0`0015YF
00@005YFFUIJEP8000Uoo`P0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020007FUH00`00FUIJEP03
FUH5001DOol002eoo`04001JEUYF0004FUH01000FUH000003Woo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF0080
00MJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo00@005YFFUH000=JEP<000moo`/000AJ
EP03001JEUYF00AJEP03001JEUYF00<000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP05001JEP00FUH00008FUH00`00FUIJEP02FUH00`00FUIJEP02001DOol002eoo`05001JEUYF
001JEP02000>Ool40002FUH00`00FUIJEP06FUH?0006Ool01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Aoo`00;Woo00<005YF0000
4@001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002goo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH00UYF1P000eYF00@005YFFUH005Aoo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0100047oo0P001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00002@000eYF1P0000=JEP000000Dgoo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000EOol20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF100000=ooeYFFUH00eYF00<005YFFUH00eYF0P000UYF1P00Dgoo000^Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000
FUH0009JEP03OomJEUYF009JEP8000EJEP04001JEUYFFUH20003FUH00`00Oomoo`1AOol002moo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Aoo`D000QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000=JEP03001JEUYF00EJEP03
001JEUYF00=JEP8000=JEP03001JEUYF008005Aoo`00<Goo5000<7oo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02@000eYF00D005YFFUIJEWoo00=JEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00Oomoo`1COol007]oo`T000IJEP03001JEUYF00UJEP03
001JEUYF00AJEP/00003FUH0000000<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF
FUH005YF0P00EWoo0024OolI000;Ool60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`00F7oo002?Ool01000FUIJEP000eYF0`004Goo100000=JEP00FUH01eYF00<005YFFUH00eYF
00<005YFFUH00P00FWoo002?Ool01@00FUIJEP00FUH00P0047oo1`0000=JEP0000000`0015YF00<0
05YFFUH00eYF00@005YF000005aoo`00Sgoo00<005YFFUH050000eYF00<005YFFUH01UYF3@00GWoo
002@Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04001SOol0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEPD006Moo`00T7oo0P000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01000K7oo002AOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
001`Ool009=oo`@000=JEP03001JEUYF009JEPP007Ioo`00Ugoo2000OWoo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59966 .7419 m .58703 .68652 L .55669 .69188 L p .707 .577 .707 r
F P
0 g
s
.58703 .68652 m .59966 .7419 L .63075 .73457 L p .707 .577 .707 r
F P
0 g
s
.63075 .73457 m .61812 .6792 L .58703 .68652 L p .707 .577 .707 r
F P
0 g
s
.61812 .6792 m .63075 .73457 L .65954 .726 L p .707 .577 .707 r
F P
0 g
s
.65954 .726 m .64691 .67063 L .61812 .6792 L p .707 .577 .707 r
F P
0 g
s
.56931 .74725 m .55669 .69188 L .53005 .69474 L p .707 .577 .707 r
F P
0 g
s
.55669 .69188 m .56931 .74725 L .59966 .7419 L p .707 .577 .707 r
F P
0 g
s
.64691 .67063 m .65954 .726 L .68321 .71702 L p .707 .577 .707 r
F P
0 g
s
.68321 .71702 m .67059 .66164 L .64691 .67063 L p .707 .577 .707 r
F P
0 g
s
.53005 .69474 m .54268 .75011 L .56931 .74725 L p .707 .577 .707 r
F P
0 g
s
.58697 .81857 m .59968 .78531 L .57043 .77279 L p .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .62906 .82137 L .59874 .82721 L p .707 .577 .707 r
F P
0 g
s
.59874 .82721 m .59771 .82741 L p .59827 .82761 L .707 .577 .707 r
F P
0 g
s
.63245 .83992 m .59874 .82721 L .59827 .82761 L .707 .577 .707 r
F
.63245 .83992 m .66145 .83237 L p .63217 .82242 L F P
0 g
s
.62906 .82137 m .62964 .8245 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.62964 .8245 m .63245 .83992 L p .63217 .82242 L .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .65807 .81382 L .62906 .82137 L p .707 .577 .707 r
F P
0 g
s
.66145 .83237 m .68526 .82404 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65807 .81382 m .65941 .82117 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.65941 .82117 m .66145 .83237 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .68187 .80549 L .67028 .80954 L p .707 .577 .707 r
F P
0 g
s
.67028 .80954 m .65807 .81382 L p .66415 .8161 L .707 .577 .707 r
F P
0 g
s
.68526 .82404 m .67028 .80954 L .66415 .8161 L .707 .577 .707 r
F
.68187 .80549 m .68526 .82404 L .70155 .81575 L p F P
0 g
s
.70155 .81575 m .69816 .7972 L .68187 .80549 L p .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .69703 .79188 L .68174 .79729 L p .707 .577 .707 r
F P
0 g
s
.68174 .79729 m .68096 .79757 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.68431 .82514 m .68174 .79729 L .68102 .79806 L .707 .577 .707 r
F
.66825 .83083 m .68431 .82514 L p .68102 .79806 L F P
0 g
s
.68096 .79757 m .6806 .79851 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.6806 .79851 m .66825 .83083 L p .68102 .79806 L .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .66825 .83083 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65779 .79833 m .65606 .80285 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.65606 .80285 m .64508 .8316 L p .65858 .80079 L .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .64508 .8316 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62978 .79411 m .62593 .8042 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.62593 .8042 m .61707 .82737 L p .63185 .79918 L .707 .577 .707 r
F P
0 g
s
.59968 .78531 m .58697 .81857 L .61707 .82737 L p .707 .577 .707 r
F P
0 g
s
.61707 .82737 m .62978 .79411 L .59968 .78531 L p .707 .577 .707 r
F P
0 g
s
.55771 .80605 m .57043 .77279 L .54489 .75778 L p .707 .577 .707 r
F P
0 g
s
.57043 .77279 m .55771 .80605 L .58697 .81857 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53005 .69474 L .50974 .69483 L p .707 .577 .707 r
F P
0 g
s
.64508 .8316 m .65779 .79833 L .62978 .79411 L p .707 .577 .707 r
F P
0 g
s
.67059 .66164 m .68321 .71702 L .69945 .7085 L p .707 .577 .707 r
F P
0 g
s
.69945 .7085 m .68683 .65313 L .67059 .66164 L p .707 .577 .707 r
F P
0 g
s
.6011 .84596 m .59771 .82741 L .56707 .83133 L p .707 .577 .707 r
F P
0 g
s
.59771 .82741 m .6011 .84596 L .63245 .83992 L p .707 .577 .707 r
F P
0 g
s
.54268 .75011 m .53556 .73816 L .52235 .75015 L .707 .577 .707 r
F
.50974 .69483 m .52235 .75015 L p .53556 .73816 L F P
0 g
s
.50974 .69483 m .49774 .69214 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.5225 .7502 m .54268 .75011 L p .52235 .75015 L .707 .577 .707 r
F P
0 g
s
.51285 .77501 m .53218 .79104 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52556 .74174 m .52235 .75015 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .51285 .77501 L p .5284 .76292 L .707 .577 .707 r
F P
0 g
s
.51336 .75831 m .52038 .74878 L .5138 .74419 L .707 .577 .707 r
F
.51285 .77501 m .52235 .75015 L p .51336 .75831 L F P
0 g
s
.52234 .75014 m .52224 .74992 L .52193 .74985 L .707 .577 .707 r
F
.49774 .69214 m .50041 .70384 L p .52224 .74992 L F P
0 g
s
.52235 .75015 m .52038 .74878 L .51336 .75831 L .707 .577 .707 r
F
.50041 .70384 m .50882 .74073 L p .51494 .73452 L F P
0 g
s
.49774 .69214 m .49522 .68694 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50163 .75952 m .50882 .74073 L p .50507 .74452 L .707 .577 .707 r
F P
0 g
s
.50882 .74073 m .49774 .69214 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.50835 .73946 m .50508 .72636 L .50531 .7312 L .707 .577 .707 r
F
.49522 .68694 m .50531 .7312 L p .50508 .72636 L F P
0 g
s
.50882 .74073 m .50805 .73865 L .50507 .74452 L .707 .577 .707 r
F
.50507 .74452 m .50805 .73865 L .50704 .73591 L F
.49962 .7461 m .50163 .75952 L p .50335 .75202 L F P
0 g
s
.51233 .71283 m .50531 .7312 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .49962 .7461 L p .50335 .75202 L .707 .577 .707 r
F P
0 g
s
.49522 .68694 m .50244 .67972 L p .50613 .72249 L .707 .577 .707 r
F P
0 g
s
.50737 .73679 m .50785 .74231 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51435 .72626 m .51233 .71283 L p .50704 .73591 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .50974 .69483 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.51233 .71283 m .51972 .70279 L p .50827 .72745 L .707 .577 .707 r
F P
0 g
s
.50805 .73865 m .51435 .72626 L .50704 .73591 L .707 .577 .707 r
F
.50785 .74231 m .50531 .7312 L p .50673 .7294 L F P
0 g
s
.50688 .72921 m .51233 .71283 L .50827 .72745 L .707 .577 .707 r
F
.50882 .74073 m .51435 .72626 L p .50805 .73865 L F P
0 g
s
.50882 .74073 m .50163 .75952 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.50785 .74231 m .51036 .74752 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .50882 .74073 L p .50835 .73946 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .51494 .73452 L .50882 .74073 L .707 .577 .707 r
F
.50163 .75952 m .51285 .77501 L p .5138 .74419 L F P
0 g
s
.50882 .74073 m .51036 .74752 L p .52193 .74985 L .707 .577 .707 r
F P
0 g
s
.52224 .74992 m .50882 .74073 L .52193 .74985 L .707 .577 .707 r
F
.51435 .72626 m .50882 .74073 L p .5138 .74419 L F P
0 g
s
.52556 .74174 m .51435 .72626 L p .5138 .74419 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .50785 .74231 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .51233 .71283 L p .50688 .72921 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51506 .73509 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .51219 .72249 L p .49962 .7461 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .50701 .73605 L .49982 .74582 L p .707 .577 .707 r
F P
0 g
s
.49982 .74582 m .49962 .7461 L p .51219 .72249 L .707 .577 .707 r
F P
0 g
s
.51972 .70279 m .53578 .6971 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51506 .73509 m .51219 .72249 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.51219 .72249 m .51972 .70279 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .51506 .73509 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .52877 .71546 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .52877 .71546 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .5313 .72658 L p .51586 .72093 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .50701 .73605 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .52307 .73036 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.50701 .73605 m .51219 .72249 L p .51923 .71951 L .707 .577 .707 r
F P
0 g
s
.51586 .72093 m .51219 .72249 L .5162 .71492 L .707 .577 .707 r
F
.50244 .67972 m .51868 .6712 L p .5162 .71492 L F P
0 g
s
.51219 .72249 m .50244 .67972 L p .5162 .71492 L .707 .577 .707 r
F P
0 g
s
.50244 .67972 m .51219 .72249 L p .50673 .7294 L .707 .577 .707 r
F P
0 g
s
.50531 .7312 m .50688 .72921 L .50543 .73358 L .707 .577 .707 r
F
.50543 .73358 m .50688 .72921 L .50827 .72745 L F
.50673 .7294 m .50531 .7312 L .50613 .72249 L F
.50531 .7312 m .49522 .68694 L p .50613 .72249 L F P
0 g
s
.49962 .7461 m .50531 .7312 L p .50543 .73358 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52556 .74174 L p .52038 .74878 L .707 .577 .707 r
F P
0 g
s
.51036 .74752 m .52237 .75021 L p .52234 .75014 L .707 .577 .707 r
F P
0 g
s
.52234 .75014 m .52193 .74985 L .51036 .74752 L .707 .577 .707 r
F
.52237 .75021 m .52235 .75015 L p .52234 .75014 L F P
0 g
s
.52038 .74878 m .52556 .74174 L .5138 .74419 L .707 .577 .707 r
F
.54489 .75778 m .52556 .74174 L p .52692 .75187 L F P
0 g
s
.53218 .79104 m .5446 .75854 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.5446 .75854 m .54489 .75778 L p .52692 .75187 L .707 .577 .707 r
F P
0 g
s
.52235 .75015 m .52237 .75021 L .5225 .7502 L p .707 .577 .707 r
F P
0 g
s
.54489 .75778 m .53218 .79104 L .55771 .80605 L p .707 .577 .707 r
F P
0 g
s
.56707 .83133 m .57046 .84989 L .6011 .84596 L p .707 .577 .707 r
F P
0 g
s
.57046 .84989 m .56707 .83133 L .54015 .83277 L p .707 .577 .707 r
F P
0 g
s
.66825 .83083 m .68096 .79757 L .65779 .79833 L p .707 .577 .707 r
F P
0 g
s
.54015 .83277 m .54353 .85133 L .57046 .84989 L p .707 .577 .707 r
F P
0 g
s
.68683 .65313 m .69945 .7085 L .70666 .70128 L p .707 .577 .707 r
F P
0 g
s
.70666 .70128 m .69404 .64591 L .68683 .65313 L p .707 .577 .707 r
F P
0 g
s
.54353 .85133 m .54015 .83277 L .51957 .83158 L p .707 .577 .707 r
F P
0 g
s
.51957 .83158 m .52296 .85013 L .54353 .85133 L p .707 .577 .707 r
F P
0 g
s
.52296 .85013 m .51957 .83158 L .50736 .82787 L p .707 .577 .707 r
F P
0 g
s
.69404 .64591 m .70666 .70128 L .70415 .69608 L p .707 .577 .707 r
F P
0 g
s
.70415 .69608 m .69152 .6407 L .69404 .64591 L p .707 .577 .707 r
F P
0 g
s
.50736 .82787 m .51075 .84642 L .52296 .85013 L p .707 .577 .707 r
F P
0 g
s
.69703 .79188 m .68431 .82514 L .6917 .8151 L p .707 .577 .707 r
F P
0 g
s
.70155 .81575 m .70871 .80831 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.69816 .7972 m .70084 .8119 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70084 .8119 m .70155 .81575 L p .70202 .80126 L .707 .577 .707 r
F P
0 g
s
.70871 .80831 m .70533 .78976 L .69816 .7972 L p .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .70405 .78278 L p .69703 .79188 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .70441 .78183 L .70405 .78232 L p .707 .577 .707 r
F P
0 g
s
.70405 .78232 m .69703 .79188 L p .70405 .78278 L .707 .577 .707 r
F P
0 g
s
.70606 .80245 m .70402 .79124 L p .70533 .78976 L .707 .577 .707 r
F P
0 g
s
.6917 .8151 m .68969 .80167 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.70405 .78278 m .6917 .8151 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.68969 .80167 m .70067 .77293 L p .70441 .78183 L .707 .577 .707 r
F P
0 g
s
.70067 .77293 m .7024 .76841 L .70274 .7707 L p .707 .577 .707 r
F P
0 g
s
.70274 .7707 m .70441 .78183 L p .70067 .77293 L .707 .577 .707 r
F P
0 g
s
.7024 .76841 m .68969 .80167 L .67847 .78619 L p .707 .577 .707 r
F P
0 g
s
.69385 .79874 m .69104 .78331 L p .70267 .78389 L .707 .577 .707 r
F P
0 g
s
.69104 .78331 m .69046 .78018 L .69317 .78101 L p .707 .577 .707 r
F P
0 g
s
.69317 .78101 m .70267 .78389 L p .69104 .78331 L .707 .577 .707 r
F P
0 g
s
.70402 .79124 m .70267 .78389 L .70403 .7869 L p .707 .577 .707 r
F P
0 g
s
.70403 .7869 m .70533 .78976 L p .70402 .79124 L .707 .577 .707 r
F P
0 g
s
.70441 .78183 m .70405 .78278 L p .70411 .78224 L .707 .577 .707 r
F P
0 g
s
.48594 .82192 m .49262 .3208 L .44862 .31753 L p .707 .577 .707 r
F P
0 g
s
.51075 .84642 m .50736 .82787 L .50471 .822 L p .707 .577 .707 r
F P
0 g
s
.50471 .822 m .5081 .84056 L .51075 .84642 L p .707 .577 .707 r
F P
0 g
s
.5081 .84056 m .50471 .822 L .51187 .81456 L p .707 .577 .707 r
F P
0 g
s
.51187 .81456 m .51526 .83312 L .5081 .84056 L p .707 .577 .707 r
F P
0 g
s
.53578 .6971 m .55895 .69633 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .53578 .6971 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51868 .6712 m .54235 .66222 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.5313 .72658 m .52877 .71546 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.52877 .71546 m .51868 .6712 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .5313 .72658 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .55342 .7108 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .55342 .7108 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55497 .71759 L p .53336 .7146 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .52307 .73036 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54624 .7296 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.52307 .73036 m .52877 .71546 L p .54127 .7131 L .707 .577 .707 r
F P
0 g
s
.51526 .83312 m .51187 .81456 L .52816 .80627 L p .707 .577 .707 r
F P
0 g
s
.52816 .80627 m .53155 .82482 L .51526 .83312 L p .707 .577 .707 r
F P
0 g
s
.53155 .82482 m .52816 .80627 L .55197 .79794 L p .707 .577 .707 r
F P
0 g
s
.49262 .3208 m .48594 .82192 L .53088 .82136 L p .707 .577 .707 r
F P
0 g
s
.53088 .82136 m .53757 .32024 L .49262 .3208 L p .707 .577 .707 r
F P
0 g
s
.55895 .69633 m .58696 .70056 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .55895 .69633 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54235 .66222 m .57114 .65365 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55497 .71759 m .55342 .7108 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.55342 .7108 m .54235 .66222 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .55497 .71759 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .58375 .70896 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .58375 .70896 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58376 .70902 L p .55674 .7106 L .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .54624 .7296 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57425 .73382 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.54624 .7296 m .55342 .7108 L p .57438 .70953 L .707 .577 .707 r
F P
0 g
s
.55197 .79794 m .55536 .8165 L .53155 .82482 L p .707 .577 .707 r
F P
0 g
s
.55536 .8165 m .55197 .79794 L .58097 .79039 L p .707 .577 .707 r
F P
0 g
s
.58097 .79039 m .58436 .80894 L .55536 .8165 L p .707 .577 .707 r
F P
0 g
s
.53757 .32024 m .53088 .82136 L .57236 .81702 L p .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .58696 .70056 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57114 .65365 m .60223 .64632 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58376 .70902 m .58375 .70896 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58375 .70896 m .57114 .65365 L p .58378 .70896 L .707 .577 .707 r
F P
0 g
s
.58696 .70056 m .61707 .70936 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.60223 .64632 m .61485 .7017 L .58376 .70902 L p .707 .577 .707 r
F P
0 g
s
.57425 .73382 m .58375 .70896 L p .61579 .71008 L .707 .577 .707 r
F P
0 g
s
.57236 .81702 m .57904 .31589 L .53757 .32024 L p .707 .577 .707 r
F P
0 g
s
.44193 .81865 m .44862 .31753 L .40986 .31073 L p .707 .577 .707 r
F P
0 g
s
.44862 .31753 m .44193 .81865 L .48594 .82192 L p .707 .577 .707 r
F P
0 g
s
.69152 .6407 m .70415 .69608 L .69214 .69339 L p .707 .577 .707 r
F P
0 g
s
.69214 .69339 m .67952 .63801 L .69152 .6407 L p .707 .577 .707 r
F P
0 g
s
.61707 .70936 m .60435 .74262 L .57425 .73382 L p .707 .577 .707 r
F P
0 g
s
.58436 .80894 m .58097 .79039 L .61232 .78435 L p .707 .577 .707 r
F P
0 g
s
.61232 .78435 m .61571 .80291 L .58436 .80894 L p .707 .577 .707 r
F P
0 g
s
.57904 .31589 m .57236 .81702 L .60631 .80931 L p .707 .577 .707 r
F P
0 g
s
.61485 .7017 m .60223 .64632 L .63258 .64097 L p .707 .577 .707 r
F P
0 g
s
.64632 .72188 m .63361 .75514 L .60435 .74262 L p .707 .577 .707 r
F P
0 g
s
.60435 .74262 m .61707 .70936 L .64632 .72188 L p .707 .577 .707 r
F P
0 g
s
.60631 .80931 m .613 .30819 L .57904 .31589 L p .707 .577 .707 r
F P
0 g
s
.70533 .78976 m .70871 .80831 L .70606 .80245 L p .707 .577 .707 r
F P
0 g
s
.40317 .81185 m .40986 .31073 L .38014 .30108 L p .707 .577 .707 r
F P
0 g
s
.40986 .31073 m .40317 .81185 L .44193 .81865 L p .707 .577 .707 r
F P
0 g
s
.25665 .70514 m .24402 .64977 L .21368 .65512 L p .707 .577 .707 r
F P
0 g
s
.24402 .64977 m .25665 .70514 L .28774 .69782 L p .707 .577 .707 r
F P
0 g
s
.28774 .69782 m .27511 .64244 L .24402 .64977 L p .707 .577 .707 r
F P
0 g
s
.27511 .64244 m .28774 .69782 L .31653 .68924 L p .707 .577 .707 r
F P
0 g
s
.31653 .68924 m .30391 .63387 L .27511 .64244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.2263 .71049 m .21368 .65512 L .18704 .65799 L p .707 .577 .707 r
F P
0 g
s
.21368 .65512 m .2263 .71049 L .25665 .70514 L p .707 .577 .707 r
F P
0 g
s
.30391 .63387 m .31653 .68924 L .3402 .68026 L p .707 .577 .707 r
F P
0 g
s
.3402 .68026 m .32758 .62489 L .30391 .63387 L p .707 .577 .707 r
F P
0 g
s
.67952 .63801 m .69214 .69339 L .67183 .69348 L p .707 .577 .707 r
F P
0 g
s
.67183 .69348 m .65921 .63811 L .67952 .63801 L p .707 .577 .707 r
F P
0 g
s
.63258 .64097 m .6452 .69634 L .61485 .7017 L p .707 .577 .707 r
F P
0 g
s
.64296 .78042 m .64635 .79898 L .61571 .80291 L p .707 .577 .707 r
F P
0 g
s
.61571 .80291 m .61232 .78435 L .64296 .78042 L p .707 .577 .707 r
F P
0 g
s
.613 .30819 m .60631 .80931 L .62942 .79901 L p .707 .577 .707 r
F P
0 g
s
.62942 .79901 m .63611 .29788 L .613 .30819 L p .707 .577 .707 r
F P
0 g
s
.67847 .78619 m .68733 .76301 L p .7024 .76841 L .707 .577 .707 r
F P
0 g
s
.69118 .75292 m .67847 .78619 L .65915 .77015 L p .707 .577 .707 r
F P
0 g
s
.67328 .79754 m .67 .77957 L p .69046 .78018 L .707 .577 .707 r
F P
0 g
s
.67 .77957 m .66989 .77899 L .67057 .77903 L p .707 .577 .707 r
F P
0 g
s
.67057 .77903 m .69046 .78018 L p .67 .77957 L .707 .577 .707 r
F P
0 g
s
.68733 .76301 m .69118 .75292 L .69392 .75671 L p .707 .577 .707 r
F P
0 g
s
.69392 .75671 m .7024 .76841 L p .68733 .76301 L .707 .577 .707 r
F P
0 g
s
.18704 .65799 m .19967 .71336 L .2263 .71049 L p .707 .577 .707 r
F P
0 g
s
.24396 .78159 m .25667 .74832 L .22742 .7358 L p .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .28606 .78521 L .25475 .79123 L p .707 .577 .707 r
F P
0 g
s
.25475 .79123 m .2547 .79124 L p .25473 .79125 L .707 .577 .707 r
F P
0 g
s
.28944 .80376 m .25475 .79123 L .25473 .79125 L .707 .577 .707 r
F
.28944 .80376 m .31845 .79621 L p .28861 .78607 L F P
0 g
s
.28606 .78521 m .28653 .78778 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.28653 .78778 m .28944 .80376 L p .28861 .78607 L .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .31506 .77765 L .28606 .78521 L p .707 .577 .707 r
F P
0 g
s
.31845 .79621 m .34225 .78788 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.31506 .77765 m .3163 .78445 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.3163 .78445 m .31845 .79621 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .33887 .76933 L .32635 .7737 L p .707 .577 .707 r
F P
0 g
s
.32635 .7737 m .31506 .77765 L p .32068 .77977 L .707 .577 .707 r
F P
0 g
s
.34225 .78788 m .32635 .7737 L .32068 .77977 L .707 .577 .707 r
F
.33887 .76933 m .34225 .78788 L .35854 .77959 L p F P
0 g
s
.35854 .77959 m .35515 .76103 L .33887 .76933 L p .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .35402 .7549 L .33895 .76023 L p .707 .577 .707 r
F P
0 g
s
.33895 .76023 m .33795 .76058 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.34131 .78816 m .33895 .76023 L .33803 .76121 L .707 .577 .707 r
F
.32524 .79385 m .34131 .78816 L p .33803 .76121 L F P
0 g
s
.33795 .76058 m .33749 .76179 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.33749 .76179 m .32524 .79385 L p .33803 .76121 L .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .32524 .79385 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31478 .76135 m .31295 .76613 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.31295 .76613 m .30207 .79461 L p .31562 .76395 L .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .30207 .79461 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28677 .75713 m .28282 .76748 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.28282 .76748 m .27406 .79039 L p .2889 .76233 L .707 .577 .707 r
F P
0 g
s
.25667 .74832 m .24396 .78159 L .27406 .79039 L p .707 .577 .707 r
F P
0 g
s
.27406 .79039 m .28677 .75713 L .25667 .74832 L p .707 .577 .707 r
F P
0 g
s
.70267 .78389 m .70606 .80245 L .69385 .79874 L p .707 .577 .707 r
F P
0 g
s
.21471 .76907 m .22742 .7358 L .20188 .72079 L p .707 .577 .707 r
F P
0 g
s
.22742 .7358 m .21471 .76907 L .24396 .78159 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .18704 .65799 L .16673 .65808 L p .707 .577 .707 r
F P
0 g
s
.30207 .79461 m .31478 .76135 L .28677 .75713 L p .707 .577 .707 r
F P
0 g
s
.37345 .80221 m .38014 .30108 L .36236 .28953 L p .707 .577 .707 r
F P
0 g
s
.38014 .30108 m .37345 .80221 L .40317 .81185 L p .707 .577 .707 r
F P
0 g
s
.32758 .62489 m .3402 .68026 L .35644 .67174 L p .707 .577 .707 r
F P
0 g
s
.35644 .67174 m .34382 .61637 L .32758 .62489 L p .707 .577 .707 r
F P
0 g
s
.25809 .8098 m .2547 .79124 L .22406 .79517 L p .707 .577 .707 r
F P
0 g
s
.2547 .79124 m .25809 .8098 L .28944 .80376 L p .707 .577 .707 r
F P
0 g
s
.19967 .71336 m .19248 .70129 L .17931 .71325 L .707 .577 .707 r
F
.16673 .65808 m .17931 .71325 L p .19248 .70129 L F P
0 g
s
.16673 .65808 m .15473 .65539 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17984 .71345 m .19967 .71336 L p .17931 .71325 L .707 .577 .707 r
F P
0 g
s
.16984 .73802 m .18917 .75406 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.18255 .70476 m .17931 .71325 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16984 .73802 L p .18542 .72615 L .707 .577 .707 r
F P
0 g
s
.17035 .72138 m .17733 .71187 L .17078 .70731 L .707 .577 .707 r
F
.16984 .73802 m .17931 .71325 L p .17035 .72138 L F P
0 g
s
.17925 .71321 m .17893 .71246 L .17797 .71231 L .707 .577 .707 r
F
.15473 .65539 m .15737 .66694 L p .17893 .71246 L F P
0 g
s
.17931 .71325 m .17733 .71187 L .17035 .72138 L .707 .577 .707 r
F
.15737 .66694 m .16577 .70383 L p .1719 .69762 L F P
0 g
s
.15473 .65539 m .15221 .65018 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.15862 .72253 m .16577 .70383 L p .16205 .7076 L .707 .577 .707 r
F P
0 g
s
.16577 .70383 m .15473 .65539 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.1653 .70253 m .16204 .68948 L .16227 .6943 L .707 .577 .707 r
F
.15221 .65018 m .16227 .6943 L p .16204 .68948 L F P
0 g
s
.16577 .70383 m .16501 .70175 L .16205 .7076 L .707 .577 .707 r
F
.16205 .7076 m .16501 .70175 L .16401 .69903 L F
.15661 .70911 m .15862 .72253 L p .1603 .71522 L F P
0 g
s
.16932 .67585 m .16227 .6943 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .15661 .70911 L p .1603 .71522 L .707 .577 .707 r
F P
0 g
s
.15221 .65018 m .15943 .64296 L p .1631 .68548 L .707 .577 .707 r
F P
0 g
s
.16435 .69996 m .16484 .70555 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17134 .68927 m .16932 .67585 L p .16401 .69903 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .16673 .65808 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.16932 .67585 m .17671 .6658 L p .16521 .69057 L .707 .577 .707 r
F P
0 g
s
.16501 .70175 m .17134 .68927 L .16401 .69903 L .707 .577 .707 r
F
.16484 .70555 m .16227 .6943 L p .16371 .69248 L F P
0 g
s
.16383 .69232 m .16932 .67585 L .16521 .69057 L .707 .577 .707 r
F
.16577 .70383 m .17134 .68927 L p .16501 .70175 L F P
0 g
s
.16577 .70383 m .15862 .72253 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.16484 .70555 m .16735 .71076 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .16577 .70383 L p .1653 .70253 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .1719 .69762 L .16577 .70383 L .707 .577 .707 r
F
.15862 .72253 m .16984 .73802 L p .17078 .70731 L F P
0 g
s
.16577 .70383 m .16735 .71076 L p .17797 .71231 L .707 .577 .707 r
F P
0 g
s
.17893 .71246 m .16577 .70383 L .17797 .71231 L .707 .577 .707 r
F
.17134 .68927 m .16577 .70383 L p .17078 .70731 L F P
0 g
s
.18255 .70476 m .17134 .68927 L p .17078 .70731 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16484 .70555 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16932 .67585 L p .16383 .69232 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17205 .69834 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .16915 .68559 L p .15661 .70911 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .164 .69906 L .15686 .70878 L p .707 .577 .707 r
F P
0 g
s
.15686 .70878 m .15661 .70911 L p .16915 .68559 L .707 .577 .707 r
F P
0 g
s
.17671 .6658 m .19277 .66011 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17205 .69834 m .16915 .68559 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.16915 .68559 m .17671 .6658 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .17205 .69834 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .18572 .67857 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .18572 .67857 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18829 .68982 L p .17286 .68402 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .164 .69906 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .18006 .69338 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.164 .69906 m .16915 .68559 L p .17614 .68263 L .707 .577 .707 r
F P
0 g
s
.17286 .68402 m .16915 .68559 L .17321 .67793 L .707 .577 .707 r
F
.15943 .64296 m .17567 .63445 L p .17321 .67793 L F P
0 g
s
.16915 .68559 m .15943 .64296 L p .17321 .67793 L .707 .577 .707 r
F P
0 g
s
.15943 .64296 m .16915 .68559 L p .16371 .69248 L .707 .577 .707 r
F P
0 g
s
.16227 .6943 m .16383 .69232 L .16239 .69666 L .707 .577 .707 r
F
.16239 .69666 m .16383 .69232 L .16521 .69057 L F
.16371 .69248 m .16227 .6943 L .1631 .68548 L F
.16227 .6943 m .15221 .65018 L p .1631 .68548 L F P
0 g
s
.15661 .70911 m .16227 .6943 L p .16239 .69666 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .18255 .70476 L p .17733 .71187 L .707 .577 .707 r
F P
0 g
s
.16735 .71076 m .17936 .71345 L p .17925 .71321 L .707 .577 .707 r
F P
0 g
s
.17925 .71321 m .17797 .71231 L .16735 .71076 L .707 .577 .707 r
F
.17936 .71345 m .17931 .71325 L p .17925 .71321 L F P
0 g
s
.17733 .71187 m .18255 .70476 L .17078 .70731 L .707 .577 .707 r
F
.20188 .72079 m .18255 .70476 L p .18393 .71499 L F P
0 g
s
.18917 .75406 m .20155 .72164 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.20155 .72164 m .20188 .72079 L p .18393 .71499 L .707 .577 .707 r
F P
0 g
s
.17931 .71325 m .17936 .71345 L .17984 .71345 L p .707 .577 .707 r
F P
0 g
s
.20188 .72079 m .18917 .75406 L .21471 .76907 L p .707 .577 .707 r
F P
0 g
s
.22406 .79517 m .22745 .81373 L .25809 .8098 L p .707 .577 .707 r
F P
0 g
s
.65921 .63811 m .67183 .69348 L .6452 .69634 L p .707 .577 .707 r
F P
0 g
s
.6452 .69634 m .63258 .64097 L .65921 .63811 L p .707 .577 .707 r
F P
0 g
s
.32524 .79385 m .33795 .76058 L .31478 .76135 L p .707 .577 .707 r
F P
0 g
s
.22745 .81373 m .22406 .79517 L .19714 .79661 L p .707 .577 .707 r
F P
0 g
s
.65915 .77015 m .67186 .73689 L .69118 .75292 L p .707 .577 .707 r
F P
0 g
s
.19714 .79661 m .20053 .81516 L .22745 .81373 L p .707 .577 .707 r
F P
0 g
s
.69046 .78018 m .69385 .79874 L .67328 .79754 L p .707 .577 .707 r
F P
0 g
s
.67186 .73689 m .65915 .77015 L .63361 .75514 L p .707 .577 .707 r
F P
0 g
s
.63361 .75514 m .64632 .72188 L .67186 .73689 L p .707 .577 .707 r
F P
0 g
s
.63611 .29788 m .62942 .79901 L .63942 .7871 L p .707 .577 .707 r
F P
0 g
s
.63942 .7871 m .64611 .28598 L .63611 .29788 L p .707 .577 .707 r
F P
0 g
s
.34382 .61637 m .35644 .67174 L .36365 .66453 L p .707 .577 .707 r
F P
0 g
s
.36365 .66453 m .35103 .60915 L .34382 .61637 L p .707 .577 .707 r
F P
0 g
s
.20053 .81516 m .19714 .79661 L .17656 .79541 L p .707 .577 .707 r
F P
0 g
s
.17656 .79541 m .17995 .81397 L .20053 .81516 L p .707 .577 .707 r
F P
0 g
s
.35103 .60915 m .36365 .66453 L .36114 .65932 L p .707 .577 .707 r
F P
0 g
s
.36114 .65932 m .34851 .60395 L .35103 .60915 L p .707 .577 .707 r
F P
0 g
s
.35515 .76103 m .35854 .77959 L .36395 .77397 L p .707 .577 .707 r
F P
0 g
s
.36395 .77397 m .36571 .77215 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35515 .76103 L .36395 .77397 L .707 .577 .707 r
F
.36236 .28953 m .35828 .2772 L p .35665 .59931 L F P
0 g
s
.35983 .75618 m .35515 .76103 L p .35886 .76494 L .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .36094 .74606 L p .35402 .7549 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .3614 .74485 L .36094 .74547 L p .707 .577 .707 r
F P
0 g
s
.36094 .74547 m .35402 .7549 L p .36094 .74606 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .35983 .75618 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.36305 .76628 m .36091 .75453 L p .36232 .75359 L .707 .577 .707 r
F P
0 g
s
.35402 .7549 m .34131 .78816 L .34869 .77811 L p .707 .577 .707 r
F P
0 g
s
.34869 .77811 m .34668 .76469 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36094 .74606 m .34869 .77811 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36091 .75453 m .35967 .74773 L .36092 .75051 L p .707 .577 .707 r
F P
0 g
s
.36092 .75051 m .36232 .75359 L p .36091 .75453 L .707 .577 .707 r
F P
0 g
s
.3614 .74485 m .36094 .74606 L p .36102 .74537 L .707 .577 .707 r
F P
0 g
s
.36379 .77013 m .35983 .75618 L .35886 .76494 L .707 .577 .707 r
F
.36571 .77215 m .36333 .75912 L p .36379 .77013 L F P
0 g
s
.36333 .75912 m .36232 .75359 L p .36379 .77013 L .707 .577 .707 r
F P
0 g
s
.34851 .60395 m .36114 .65932 L .34914 .65663 L p .707 .577 .707 r
F P
0 g
s
.34668 .76469 m .35756 .73621 L p .3614 .74485 L .707 .577 .707 r
F P
0 g
s
.35756 .73621 m .35939 .73143 L .35975 .73385 L p .707 .577 .707 r
F P
0 g
s
.35975 .73385 m .3614 .74485 L p .35756 .73621 L .707 .577 .707 r
F P
0 g
s
.35939 .73143 m .34668 .76469 L .33808 .75281 L p .707 .577 .707 r
F P
0 g
s
.33808 .75281 m .33546 .7492 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .35939 .73143 L .33808 .75281 L .707 .577 .707 r
F
.35785 .62804 m .36236 .28953 L p .35665 .59931 L F P
0 g
s
.35084 .76257 m .34792 .74659 L p .35967 .74773 L .707 .577 .707 r
F P
0 g
s
.34968 .7447 m .35967 .74773 L p .34792 .74659 L .707 .577 .707 r
F P
0 g
s
.36232 .75359 m .36571 .77215 L .36305 .76628 L p .707 .577 .707 r
F P
0 g
s
.33865 .74683 m .3453 .72525 L .35939 .73143 L .707 .577 .707 r
F
.33546 .7492 m .33943 .73883 L p .33865 .74683 L F P
0 g
s
.33943 .73883 m .34817 .71594 L p .33865 .74683 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .33546 .7492 L .31614 .73317 L p .707 .577 .707 r
F P
0 g
s
.33027 .76138 m .32688 .74285 L p .34745 .74402 L .707 .577 .707 r
F P
0 g
s
.32688 .74285 m .32688 .74282 L .32691 .74283 L p .707 .577 .707 r
F P
0 g
s
.32691 .74283 m .34745 .74402 L p .32688 .74285 L .707 .577 .707 r
F P
0 g
s
.34817 .71594 m .35098 .71982 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35098 .71982 m .35939 .73143 L p .3453 .72525 L .707 .577 .707 r
F P
0 g
s
.35967 .74773 m .36305 .76628 L .35084 .76257 L p .707 .577 .707 r
F P
0 g
s
.36236 .28953 m .35568 .79065 L .37345 .80221 L p .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35568 .79065 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35573 .78004 m .35785 .62804 L .35665 .59931 L .707 .577 .707 r
F
.35583 .77955 m .35785 .62804 L p .35573 .78004 L F P
0 g
s
.35591 .77318 m .35159 .77832 L p .3588 .55667 L .707 .577 .707 r
F P
0 g
s
.3588 .55667 m .35971 .52868 L .35591 .77318 L .707 .577 .707 r
F
.36159 .76642 m .35591 .77318 L p .35971 .52868 L F P
0 g
s
.36828 .26529 m .36557 .46794 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.36557 .46794 m .36159 .76642 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .36828 .26529 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35828 .2772 m .35462 .55094 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35462 .55094 m .35159 .77832 L p .35665 .59931 L .707 .577 .707 r
F P
0 g
s
.35159 .77832 m .35415 .58625 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.35415 .58625 m .35828 .2772 L p .35971 .52868 L .707 .577 .707 r
F P
0 g
s
.34792 .74659 m .34745 .74402 L .34968 .7447 L p .707 .577 .707 r
F P
0 g
s
.35568 .79065 m .35583 .77955 L p .35573 .78004 L .707 .577 .707 r
F P
0 g
s
.66989 .77899 m .67328 .79754 L .64635 .79898 L p .707 .577 .707 r
F P
0 g
s
.64635 .79898 m .64296 .78042 L .66989 .77899 L p .707 .577 .707 r
F P
0 g
s
.17995 .81397 m .17656 .79541 L .16435 .7917 L p .707 .577 .707 r
F P
0 g
s
.16435 .7917 m .16774 .81026 L .17995 .81397 L p .707 .577 .707 r
F P
0 g
s
.64611 .28598 m .63942 .7871 L .63533 .77477 L p .707 .577 .707 r
F P
0 g
s
.63533 .77477 m .64202 .27365 L .64611 .28598 L p .707 .577 .707 r
F P
0 g
s
.16774 .81026 m .16435 .7917 L .1617 .78584 L p .707 .577 .707 r
F P
0 g
s
.1617 .78584 m .16509 .80439 L .16774 .81026 L p .707 .577 .707 r
F P
0 g
s
.34914 .65663 m .33651 .60126 L .34851 .60395 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64202 .27365 m .63533 .77477 L .61756 .76322 L p .707 .577 .707 r
F P
0 g
s
.61756 .76322 m .62425 .26209 L .64202 .27365 L p .707 .577 .707 r
F P
0 g
s
.16509 .80439 m .1617 .78584 L .16887 .7784 L p .707 .577 .707 r
F P
0 g
s
.33651 .60126 m .34914 .65663 L .32882 .65672 L p .707 .577 .707 r
F P
0 g
s
.32882 .65672 m .3162 .60135 L .33651 .60126 L p .707 .577 .707 r
F P
0 g
s
.16887 .7784 m .17225 .79695 L .16509 .80439 L p .707 .577 .707 r
F P
0 g
s
.36159 .76642 m .36828 .26529 L .39139 .25499 L p .707 .577 .707 r
F P
0 g
s
.19277 .66011 m .21594 .65935 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18829 .68982 m .18572 .67857 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .19277 .66011 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .18829 .68982 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .21038 .6739 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .21038 .6739 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21196 .68083 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .18006 .69338 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .20323 .69261 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.18006 .69338 m .18572 .67857 L p .19816 .67621 L .707 .577 .707 r
F P
0 g
s
.17567 .63445 m .19934 .62546 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.18572 .67857 m .17567 .63445 L p .19037 .67769 L .707 .577 .707 r
F P
0 g
s
.3162 .60135 m .32882 .65672 L .30219 .65958 L p .707 .577 .707 r
F P
0 g
s
.30219 .65958 m .28957 .60421 L .3162 .60135 L p .707 .577 .707 r
F P
0 g
s
.17225 .79695 m .16887 .7784 L .18515 .77011 L p .707 .577 .707 r
F P
0 g
s
.31614 .73317 m .32885 .6999 L .34817 .71594 L p .707 .577 .707 r
F P
0 g
s
.18515 .77011 m .18854 .78866 L .17225 .79695 L p .707 .577 .707 r
F P
0 g
s
.62425 .26209 m .61756 .76322 L .58784 .75357 L p .707 .577 .707 r
F P
0 g
s
.58784 .75357 m .59452 .25245 L .62425 .26209 L p .707 .577 .707 r
F P
0 g
s
.34745 .74402 m .35084 .76257 L .33027 .76138 L p .707 .577 .707 r
F P
0 g
s
.21594 .65935 m .24395 .66357 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.21196 .68083 m .21038 .6739 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .21594 .65935 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .21196 .68083 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .24071 .67206 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .24071 .67206 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24075 .67226 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .20323 .69261 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .23124 .69683 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.20323 .69261 m .21038 .6739 L p .23124 .67264 L .707 .577 .707 r
F P
0 g
s
.19934 .62546 m .22813 .61689 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.21038 .6739 m .19934 .62546 L p .21377 .6737 L .707 .577 .707 r
F P
0 g
s
.28957 .60421 m .30219 .65958 L .27184 .66494 L p .707 .577 .707 r
F P
0 g
s
.27184 .66494 m .25922 .60957 L .28957 .60421 L p .707 .577 .707 r
F P
0 g
s
.39139 .25499 m .3847 .75611 L .36159 .76642 L p .707 .577 .707 r
F P
0 g
s
.3847 .75611 m .39139 .25499 L .42534 .24728 L p .707 .577 .707 r
F P
0 g
s
.32885 .6999 m .31614 .73317 L .2906 .71816 L p .707 .577 .707 r
F P
0 g
s
.2906 .71816 m .30331 .68489 L .32885 .6999 L p .707 .577 .707 r
F P
0 g
s
.73686 .64986 m .72424 .59449 L .69389 .59984 L p .707 .577 .707 r
F P
0 g
s
.72424 .59449 m .73686 .64986 L .76795 .64253 L p .707 .577 .707 r
F P
0 g
s
.76795 .64253 m .75533 .58716 L .72424 .59449 L p .707 .577 .707 r
F P
0 g
s
.24395 .66357 m .27406 .67237 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.24075 .67226 m .24071 .67206 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .24395 .66357 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.25922 .60957 m .27184 .66494 L .24075 .67226 L p .707 .577 .707 r
F P
0 g
s
.23124 .69683 m .24071 .67206 L p .27264 .67318 L .707 .577 .707 r
F P
0 g
s
.22813 .61689 m .25922 .60957 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.24071 .67206 m .22813 .61689 L p .24081 .67206 L .707 .577 .707 r
F P
0 g
s
.75533 .58716 m .76795 .64253 L .79674 .63396 L p .707 .577 .707 r
F P
0 g
s
.79674 .63396 m .78412 .57859 L .75533 .58716 L p .707 .577 .707 r
F P
0 g
s
.18854 .78866 m .18515 .77011 L .20896 .76178 L p .707 .577 .707 r
F P
0 g
s
.20896 .76178 m .21235 .78033 L .18854 .78866 L p .707 .577 .707 r
F P
0 g
s
.70651 .65521 m .69389 .59984 L .66726 .6027 L p .707 .577 .707 r
F P
0 g
s
.69389 .59984 m .70651 .65521 L .73686 .64986 L p .707 .577 .707 r
F P
0 g
s
.30331 .68489 m .2906 .71816 L .26134 .70564 L p .707 .577 .707 r
F P
0 g
s
.26134 .70564 m .27406 .67237 L .30331 .68489 L p .707 .577 .707 r
F P
0 g
s
.32688 .74282 m .33027 .76138 L .30334 .76282 L p .707 .577 .707 r
F P
0 g
s
.30334 .76282 m .29995 .74426 L .32688 .74282 L p .707 .577 .707 r
F P
0 g
s
.78412 .57859 m .79674 .63396 L .82042 .62498 L p .707 .577 .707 r
F P
0 g
s
.82042 .62498 m .80779 .5696 L .78412 .57859 L p .707 .577 .707 r
F P
0 g
s
.27406 .67237 m .26134 .70564 L .23124 .69683 L p .707 .577 .707 r
F P
0 g
s
.59452 .25245 m .58784 .75357 L .54908 .74678 L p .707 .577 .707 r
F P
0 g
s
.54908 .74678 m .55576 .24565 L .59452 .25245 L p .707 .577 .707 r
F P
0 g
s
.66726 .6027 m .67988 .65808 L .70651 .65521 L p .707 .577 .707 r
F P
0 g
s
.72417 .72653 m .73688 .69327 L .70763 .68075 L p .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .76627 .72933 L .73595 .73517 L p .707 .577 .707 r
F P
0 g
s
.73595 .73517 m .73491 .73537 L p .73547 .73557 L .707 .577 .707 r
F P
0 g
s
.76966 .74789 m .73595 .73517 L .73547 .73557 L .707 .577 .707 r
F
.76966 .74789 m .79866 .74033 L p .76937 .73039 L F P
0 g
s
.76627 .72933 m .76684 .73246 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.76684 .73246 m .76966 .74789 L p .76937 .73039 L .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .79527 .72178 L .76627 .72933 L p .707 .577 .707 r
F P
0 g
s
.79866 .74033 m .82247 .73201 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79527 .72178 m .79661 .72913 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.79661 .72913 m .79866 .74033 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .81908 .71345 L .80748 .71751 L p .707 .577 .707 r
F P
0 g
s
.80748 .71751 m .79527 .72178 L p .80135 .72407 L .707 .577 .707 r
F P
0 g
s
.82247 .73201 m .80748 .71751 L .80135 .72407 L .707 .577 .707 r
F
.81908 .71345 m .82247 .73201 L .83875 .72371 L p F P
0 g
s
.83875 .72371 m .83536 .70516 L .81908 .71345 L p .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .83423 .69984 L .81895 .70525 L p .707 .577 .707 r
F P
0 g
s
.81895 .70525 m .81817 .70553 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.82152 .73311 m .81895 .70525 L .81823 .70602 L .707 .577 .707 r
F
.80545 .73879 m .82152 .73311 L p .81823 .70602 L F P
0 g
s
.81817 .70553 m .8178 .70647 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.8178 .70647 m .80545 .73879 L p .81823 .70602 L .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .80545 .73879 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79499 .7063 m .79327 .71081 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.79327 .71081 m .78228 .73956 L p .79579 .70875 L .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .78228 .73956 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76699 .70207 m .76313 .71216 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.76313 .71216 m .75427 .73534 L p .76906 .70714 L .707 .577 .707 r
F P
0 g
s
.73688 .69327 m .72417 .72653 L .75427 .73534 L p .707 .577 .707 r
F P
0 g
s
.75427 .73534 m .76699 .70207 L .73688 .69327 L p .707 .577 .707 r
F P
0 g
s
.21235 .78033 m .20896 .76178 L .23796 .75423 L p .707 .577 .707 r
F P
0 g
s
.41865 .74841 m .42534 .24728 L .46682 .24294 L p .707 .577 .707 r
F P
0 g
s
.42534 .24728 m .41865 .74841 L .3847 .75611 L p .707 .577 .707 r
F P
0 g
s
.69492 .71401 m .70763 .68075 L .68209 .66574 L p .707 .577 .707 r
F P
0 g
s
.70763 .68075 m .69492 .71401 L .72417 .72653 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .66726 .6027 L .64695 .60279 L p .707 .577 .707 r
F P
0 g
s
.23796 .75423 m .24135 .77278 L .21235 .78033 L p .707 .577 .707 r
F P
0 g
s
.29995 .74426 m .30334 .76282 L .2727 .76674 L p .707 .577 .707 r
F P
0 g
s
.2727 .76674 m .26931 .74819 L .29995 .74426 L p .707 .577 .707 r
F P
0 g
s
.78228 .73956 m .79499 .7063 L .76699 .70207 L p .707 .577 .707 r
F P
0 g
s
.80779 .5696 m .82042 .62498 L .83665 .61646 L p .707 .577 .707 r
F P
0 g
s
.83665 .61646 m .82403 .56109 L .80779 .5696 L p .707 .577 .707 r
F P
0 g
s
.24135 .77278 m .23796 .75423 L .26931 .74819 L p .707 .577 .707 r
F P
0 g
s
.7383 .75392 m .73491 .73537 L .70427 .7393 L p .707 .577 .707 r
F P
0 g
s
.73491 .73537 m .7383 .75392 L .76966 .74789 L p .707 .577 .707 r
F P
0 g
s
.26931 .74819 m .2727 .76674 L .24135 .77278 L p .707 .577 .707 r
F P
0 g
s
.67988 .65808 m .67276 .64612 L .65956 .65811 L .707 .577 .707 r
F
.64695 .60279 m .65956 .65811 L p .67276 .64612 L F P
0 g
s
.64695 .60279 m .63494 .60011 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65971 .65817 m .67988 .65808 L p .65956 .65811 L .707 .577 .707 r
F P
0 g
s
.65006 .68297 m .66938 .699 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.66277 .6497 m .65956 .65811 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65006 .68297 L p .66561 .67088 L .707 .577 .707 r
F P
0 g
s
.65057 .66627 m .65759 .65674 L .651 .65215 L .707 .577 .707 r
F
.65006 .68297 m .65956 .65811 L p .65057 .66627 L F P
0 g
s
.65954 .6581 m .65945 .65788 L .65914 .65782 L .707 .577 .707 r
F
.63494 .60011 m .63761 .6118 L p .65945 .65788 L F P
0 g
s
.65956 .65811 m .65759 .65674 L .65057 .66627 L .707 .577 .707 r
F
.63761 .6118 m .64602 .64869 L p .65215 .64248 L F P
0 g
s
.63494 .60011 m .63243 .5949 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.63884 .66748 m .64602 .64869 L p .64227 .65248 L .707 .577 .707 r
F P
0 g
s
.64602 .64869 m .63494 .60011 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64555 .64742 m .64228 .63433 L .64252 .63916 L .707 .577 .707 r
F
.63243 .5949 m .64252 .63916 L p .64228 .63433 L F P
0 g
s
.64602 .64869 m .64526 .64661 L .64227 .65248 L .707 .577 .707 r
F
.64227 .65248 m .64526 .64661 L .64425 .64387 L F
.63682 .65406 m .63884 .66748 L p .64056 .65998 L F P
0 g
s
.64954 .62079 m .64252 .63916 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .63682 .65406 L p .64056 .65998 L .707 .577 .707 r
F P
0 g
s
.63243 .5949 m .63964 .58768 L p .64334 .63045 L .707 .577 .707 r
F P
0 g
s
.64457 .64475 m .64505 .65027 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65155 .63422 m .64954 .62079 L p .64425 .64387 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .64695 .60279 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.64954 .62079 m .65692 .61075 L p .64548 .63541 L .707 .577 .707 r
F P
0 g
s
.64526 .64661 m .65155 .63422 L .64425 .64387 L .707 .577 .707 r
F
.64505 .65027 m .64252 .63916 L p .64394 .63736 L F P
0 g
s
.64409 .63717 m .64954 .62079 L .64548 .63541 L .707 .577 .707 r
F
.64602 .64869 m .65155 .63422 L p .64526 .64661 L F P
0 g
s
.64602 .64869 m .63884 .66748 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.64505 .65027 m .64757 .65548 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .64602 .64869 L p .64555 .64742 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .65215 .64248 L .64602 .64869 L .707 .577 .707 r
F
.63884 .66748 m .65006 .68297 L p .651 .65215 L F P
0 g
s
.64602 .64869 m .64757 .65548 L p .65914 .65782 L .707 .577 .707 r
F P
0 g
s
.65945 .65788 m .64602 .64869 L .65914 .65782 L .707 .577 .707 r
F
.65155 .63422 m .64602 .64869 L p .651 .65215 L F P
0 g
s
.66277 .6497 m .65155 .63422 L p .651 .65215 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64505 .65027 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64954 .62079 L p .64409 .63717 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65226 .64305 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .64939 .63045 L p .63682 .65406 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .64421 .64401 L .63703 .65378 L p .707 .577 .707 r
F P
0 g
s
.63703 .65378 m .63682 .65406 L p .64939 .63045 L .707 .577 .707 r
F P
0 g
s
.65692 .61075 m .67299 .60506 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65226 .64305 m .64939 .63045 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.64939 .63045 m .65692 .61075 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .65226 .64305 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .66597 .62343 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .66597 .62343 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .6685 .63454 L p .65307 .6289 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .64421 .64401 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .66028 .63833 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.64421 .64401 m .64939 .63045 L p .65643 .62747 L .707 .577 .707 r
F P
0 g
s
.65307 .6289 m .64939 .63045 L .65341 .62288 L .707 .577 .707 r
F
.63964 .58768 m .65588 .57917 L p .65341 .62288 L F P
0 g
s
.64939 .63045 m .63964 .58768 L p .65341 .62288 L .707 .577 .707 r
F P
0 g
s
.63964 .58768 m .64939 .63045 L p .64394 .63736 L .707 .577 .707 r
F P
0 g
s
.64252 .63916 m .64409 .63717 L .64263 .64154 L .707 .577 .707 r
F
.64263 .64154 m .64409 .63717 L .64548 .63541 L F
.64394 .63736 m .64252 .63916 L .64334 .63045 L F
.64252 .63916 m .63243 .5949 L p .64334 .63045 L F P
0 g
s
.63682 .65406 m .64252 .63916 L p .64263 .64154 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .66277 .6497 L p .65759 .65674 L .707 .577 .707 r
F P
0 g
s
.64757 .65548 m .65957 .65817 L p .65954 .6581 L .707 .577 .707 r
F P
0 g
s
.65954 .6581 m .65914 .65782 L .64757 .65548 L .707 .577 .707 r
F
.65957 .65817 m .65956 .65811 L p .65954 .6581 L F P
0 g
s
.65759 .65674 m .66277 .6497 L .651 .65215 L .707 .577 .707 r
F
.68209 .66574 m .66277 .6497 L p .66413 .65983 L F P
0 g
s
.66938 .699 m .6818 .6665 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.6818 .6665 m .68209 .66574 L p .66413 .65983 L .707 .577 .707 r
F P
0 g
s
.65956 .65811 m .65957 .65817 L .65971 .65817 L p .707 .577 .707 r
F P
0 g
s
.55576 .24565 m .54908 .74678 L .50507 .7435 L p .707 .577 .707 r
F P
0 g
s
.50507 .7435 m .51176 .24238 L .55576 .24565 L p .707 .577 .707 r
F P
0 g
s
.68209 .66574 m .66938 .699 L .69492 .71401 L p .707 .577 .707 r
F P
0 g
s
.70427 .7393 m .70766 .75785 L .7383 .75392 L p .707 .577 .707 r
F P
0 g
s
.46013 .74406 m .46682 .24294 L .51176 .24238 L p .707 .577 .707 r
F P
0 g
s
.46682 .24294 m .46013 .74406 L .41865 .74841 L p .707 .577 .707 r
F P
0 g
s
.70766 .75785 m .70427 .7393 L .67735 .74073 L p .707 .577 .707 r
F P
0 g
s
.80545 .73879 m .81817 .70553 L .79499 .7063 L p .707 .577 .707 r
F P
0 g
s
.51176 .24238 m .50507 .7435 L .46013 .74406 L p .707 .577 .707 r
F P
0 g
s
.67735 .74073 m .68074 .75929 L .70766 .75785 L p .707 .577 .707 r
F P
0 g
s
.82403 .56109 m .83665 .61646 L .84387 .60924 L p .707 .577 .707 r
F P
0 g
s
.84387 .60924 m .83124 .55387 L .82403 .56109 L p .707 .577 .707 r
F P
0 g
s
.68074 .75929 m .67735 .74073 L .65677 .73954 L p .707 .577 .707 r
F P
0 g
s
.65677 .73954 m .66016 .75809 L .68074 .75929 L p .707 .577 .707 r
F P
0 g
s
.66016 .75809 m .65677 .73954 L .64456 .73583 L p .707 .577 .707 r
F P
0 g
s
.83124 .55387 m .84387 .60924 L .84135 .60404 L p .707 .577 .707 r
F P
0 g
s
.84135 .60404 m .82873 .54867 L .83124 .55387 L p .707 .577 .707 r
F P
0 g
s
.64456 .73583 m .64795 .75438 L .66016 .75809 L p .707 .577 .707 r
F P
0 g
s
.83423 .69984 m .82152 .73311 L .82891 .72306 L p .707 .577 .707 r
F P
0 g
s
.83875 .72371 m .84592 .71627 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83536 .70516 m .83805 .71986 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.83805 .71986 m .83875 .72371 L p .83922 .70922 L .707 .577 .707 r
F P
0 g
s
.84592 .71627 m .84253 .69772 L .83536 .70516 L p .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .84126 .69074 L p .83423 .69984 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .84162 .6898 L .84126 .69028 L p .707 .577 .707 r
F P
0 g
s
.84126 .69028 m .83423 .69984 L p .84126 .69074 L .707 .577 .707 r
F P
0 g
s
.84327 .71041 m .84122 .69921 L p .84253 .69772 L .707 .577 .707 r
F P
0 g
s
.82891 .72306 m .82689 .70964 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.84126 .69074 m .82891 .72306 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.82689 .70964 m .83788 .68089 L p .84162 .6898 L .707 .577 .707 r
F P
0 g
s
.83788 .68089 m .8396 .67637 L .83995 .67866 L p .707 .577 .707 r
F P
0 g
s
.83995 .67866 m .84162 .6898 L p .83788 .68089 L .707 .577 .707 r
F P
0 g
s
.8396 .67637 m .82689 .70964 L .81567 .69415 L p .707 .577 .707 r
F P
0 g
s
.83106 .7067 m .82824 .69127 L p .83988 .69186 L .707 .577 .707 r
F P
0 g
s
.82824 .69127 m .82767 .68814 L .83038 .68897 L p .707 .577 .707 r
F P
0 g
s
.83038 .68897 m .83988 .69186 L p .82824 .69127 L .707 .577 .707 r
F P
0 g
s
.84122 .69921 m .83988 .69186 L .84124 .69486 L p .707 .577 .707 r
F P
0 g
s
.84124 .69486 m .84253 .69772 L p .84122 .69921 L .707 .577 .707 r
F P
0 g
s
.84162 .6898 m .84126 .69074 L p .84132 .6902 L .707 .577 .707 r
F P
0 g
s
.64795 .75438 m .64456 .73583 L .64191 .72996 L p .707 .577 .707 r
F P
0 g
s
.64191 .72996 m .6453 .74852 L .64795 .75438 L p .707 .577 .707 r
F P
0 g
s
.82873 .54867 m .84135 .60404 L .82935 .60135 L p .707 .577 .707 r
F P
0 g
s
.82935 .60135 m .81673 .54598 L .82873 .54867 L p .707 .577 .707 r
F P
0 g
s
.84253 .69772 m .84592 .71627 L .84327 .71041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39385 .6131 m .38123 .55773 L .35088 .56308 L p .707 .577 .707 r
F P
0 g
s
.38123 .55773 m .39385 .6131 L .42494 .60578 L p .707 .577 .707 r
F P
0 g
s
.42494 .60578 m .41232 .55041 L .38123 .55773 L p .707 .577 .707 r
F P
0 g
s
.41232 .55041 m .42494 .60578 L .45373 .5972 L p .707 .577 .707 r
F P
0 g
s
.45373 .5972 m .44111 .54183 L .41232 .55041 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3635 .61846 m .35088 .56308 L .32425 .56595 L p .707 .577 .707 r
F P
0 g
s
.35088 .56308 m .3635 .61846 L .39385 .6131 L p .707 .577 .707 r
F P
0 g
s
.44111 .54183 m .45373 .5972 L .47741 .58822 L p .707 .577 .707 r
F P
0 g
s
.47741 .58822 m .46478 .53285 L .44111 .54183 L p .707 .577 .707 r
F P
0 g
s
.6453 .74852 m .64191 .72996 L .64908 .72252 L p .707 .577 .707 r
F P
0 g
s
.64908 .72252 m .65247 .74108 L .6453 .74852 L p .707 .577 .707 r
F P
0 g
s
.81673 .54598 m .82935 .60135 L .80904 .60144 L p .707 .577 .707 r
F P
0 g
s
.80904 .60144 m .79642 .54607 L .81673 .54598 L p .707 .577 .707 r
F P
0 g
s
.81567 .69415 m .82453 .67097 L p .8396 .67637 L .707 .577 .707 r
F P
0 g
s
.82839 .66089 m .81567 .69415 L .79635 .67812 L p .707 .577 .707 r
F P
0 g
s
.81048 .7055 m .8072 .68753 L p .82767 .68814 L .707 .577 .707 r
F P
0 g
s
.8072 .68753 m .80709 .68695 L .80777 .68699 L p .707 .577 .707 r
F P
0 g
s
.80777 .68699 m .82767 .68814 L p .8072 .68753 L .707 .577 .707 r
F P
0 g
s
.82453 .67097 m .82839 .66089 L .83113 .66467 L p .707 .577 .707 r
F P
0 g
s
.83113 .66467 m .8396 .67637 L p .82453 .67097 L .707 .577 .707 r
F P
0 g
s
.32425 .56595 m .33687 .62132 L .3635 .61846 L p .707 .577 .707 r
F P
0 g
s
.38116 .68955 m .39387 .65628 L .36462 .64376 L p .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .42326 .69317 L .39196 .69919 L p .707 .577 .707 r
F P
0 g
s
.39196 .69919 m .3919 .6992 L p .39193 .69921 L .707 .577 .707 r
F P
0 g
s
.42665 .71172 m .39196 .69919 L .39193 .69921 L .707 .577 .707 r
F
.42665 .71172 m .45565 .70417 L p .42581 .69404 L F P
0 g
s
.42326 .69317 m .42373 .69574 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.42373 .69574 m .42665 .71172 L p .42581 .69404 L .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .45226 .68562 L .42326 .69317 L p .707 .577 .707 r
F P
0 g
s
.45565 .70417 m .47946 .69584 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.45226 .68562 m .4535 .69241 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.4535 .69241 m .45565 .70417 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .47607 .67729 L .46355 .68167 L p .707 .577 .707 r
F P
0 g
s
.46355 .68167 m .45226 .68562 L p .45788 .68773 L .707 .577 .707 r
F P
0 g
s
.47946 .69584 m .46355 .68167 L .45788 .68773 L .707 .577 .707 r
F
.47607 .67729 m .47946 .69584 L .49574 .68755 L p F P
0 g
s
.49574 .68755 m .49235 .669 L .47607 .67729 L p .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .49122 .66286 L .47616 .66819 L p .707 .577 .707 r
F P
0 g
s
.47616 .66819 m .47516 .66854 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47851 .69612 m .47616 .66819 L .47523 .66918 L .707 .577 .707 r
F
.46244 .70181 m .47851 .69612 L p .47523 .66918 L F P
0 g
s
.47516 .66854 m .47469 .66975 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.47469 .66975 m .46244 .70181 L p .47523 .66918 L .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .46244 .70181 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45198 .66931 m .45016 .6741 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.45016 .6741 m .43927 .70258 L p .45282 .67191 L .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .43927 .70258 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42398 .66509 m .42002 .67544 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.42002 .67544 m .41127 .69835 L p .4261 .67029 L .707 .577 .707 r
F P
0 g
s
.39387 .65628 m .38116 .68955 L .41127 .69835 L p .707 .577 .707 r
F P
0 g
s
.41127 .69835 m .42398 .66509 L .39387 .65628 L p .707 .577 .707 r
F P
0 g
s
.83988 .69186 m .84327 .71041 L .83106 .7067 L p .707 .577 .707 r
F P
0 g
s
.35191 .67703 m .36462 .64376 L .33908 .62875 L p .707 .577 .707 r
F P
0 g
s
.36462 .64376 m .35191 .67703 L .38116 .68955 L p .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32425 .56595 L .30394 .56604 L p .707 .577 .707 r
F P
0 g
s
.43927 .70258 m .45198 .66931 L .42398 .66509 L p .707 .577 .707 r
F P
0 g
s
.46478 .53285 m .47741 .58822 L .49364 .5797 L p .707 .577 .707 r
F P
0 g
s
.49364 .5797 m .48102 .52433 L .46478 .53285 L p .707 .577 .707 r
F P
0 g
s
.39529 .71776 m .3919 .6992 L .36126 .70313 L p .707 .577 .707 r
F P
0 g
s
.3919 .6992 m .39529 .71776 L .42665 .71172 L p .707 .577 .707 r
F P
0 g
s
.67299 .60506 m .69616 .60429 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.6685 .63454 m .66597 .62343 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .67299 .60506 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .6685 .63454 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .69063 .61876 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .69063 .61876 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69218 .62555 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .66028 .63833 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .68345 .63756 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.66028 .63833 m .66597 .62343 L p .67848 .62106 L .707 .577 .707 r
F P
0 g
s
.65588 .57917 m .67955 .57018 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.66597 .62343 m .65588 .57917 L p .67056 .62256 L .707 .577 .707 r
F P
0 g
s
.33687 .62132 m .32968 .60925 L .31651 .62121 L .707 .577 .707 r
F
.30394 .56604 m .31651 .62121 L p .32968 .60925 L F P
0 g
s
.30394 .56604 m .29193 .56335 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31704 .62141 m .33687 .62132 L p .31651 .62121 L .707 .577 .707 r
F P
0 g
s
.30705 .64598 m .32637 .66202 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31976 .61272 m .31651 .62121 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30705 .64598 L p .32263 .63411 L .707 .577 .707 r
F P
0 g
s
.30756 .62934 m .31454 .61983 L .30799 .61527 L .707 .577 .707 r
F
.30705 .64598 m .31651 .62121 L p .30756 .62934 L F P
0 g
s
.31646 .62117 m .31614 .62042 L .31517 .62027 L .707 .577 .707 r
F
.29193 .56335 m .29457 .5749 L p .31614 .62042 L F P
0 g
s
.31651 .62121 m .31454 .61983 L .30756 .62934 L .707 .577 .707 r
F
.29457 .5749 m .30298 .61179 L p .30911 .60558 L F P
0 g
s
.29193 .56335 m .28942 .55814 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.29583 .6305 m .30298 .61179 L p .29925 .61557 L .707 .577 .707 r
F P
0 g
s
.30298 .61179 m .29193 .56335 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.3025 .61049 m .29924 .59744 L .29947 .60226 L .707 .577 .707 r
F
.28942 .55814 m .29947 .60226 L p .29924 .59744 L F P
0 g
s
.30298 .61179 m .30221 .60971 L .29925 .61557 L .707 .577 .707 r
F
.29925 .61557 m .30221 .60971 L .30121 .60699 L F
.29381 .61707 m .29583 .6305 L p .2975 .62318 L F P
0 g
s
.30653 .58381 m .29947 .60226 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .29381 .61707 L p .2975 .62318 L .707 .577 .707 r
F P
0 g
s
.28942 .55814 m .29663 .55093 L p .30031 .59344 L .707 .577 .707 r
F P
0 g
s
.30156 .60792 m .30204 .61351 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30854 .59723 m .30653 .58381 L p .30121 .60699 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .30394 .56604 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.30653 .58381 m .31391 .57376 L p .30242 .59853 L .707 .577 .707 r
F P
0 g
s
.30221 .60971 m .30854 .59723 L .30121 .60699 L .707 .577 .707 r
F
.30204 .61351 m .29947 .60226 L p .30091 .60044 L F P
0 g
s
.30104 .60028 m .30653 .58381 L .30242 .59853 L .707 .577 .707 r
F
.30298 .61179 m .30854 .59723 L p .30221 .60971 L F P
0 g
s
.30298 .61179 m .29583 .6305 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30204 .61351 m .30456 .61872 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .30298 .61179 L p .3025 .61049 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30911 .60558 L .30298 .61179 L .707 .577 .707 r
F
.29583 .6305 m .30705 .64598 L p .30799 .61527 L F P
0 g
s
.30298 .61179 m .30456 .61872 L p .31517 .62027 L .707 .577 .707 r
F P
0 g
s
.31614 .62042 m .30298 .61179 L .31517 .62027 L .707 .577 .707 r
F
.30854 .59723 m .30298 .61179 L p .30799 .61527 L F P
0 g
s
.31976 .61272 m .30854 .59723 L p .30799 .61527 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30204 .61351 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30653 .58381 L p .30104 .60028 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .30925 .6063 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .30635 .59355 L p .29381 .61707 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .3012 .60703 L .29406 .61674 L p .707 .577 .707 r
F P
0 g
s
.29406 .61674 m .29381 .61707 L p .30635 .59355 L .707 .577 .707 r
F P
0 g
s
.31391 .57376 m .32998 .56808 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.30925 .6063 m .30635 .59355 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.30635 .59355 m .31391 .57376 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .30925 .6063 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .32293 .58653 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .32293 .58653 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32549 .59778 L p .31006 .59198 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .3012 .60703 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31727 .60134 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.3012 .60703 m .30635 .59355 L p .31335 .59059 L .707 .577 .707 r
F P
0 g
s
.31006 .59198 m .30635 .59355 L .31041 .5859 L .707 .577 .707 r
F
.29663 .55093 m .31287 .54241 L p .31041 .5859 L F P
0 g
s
.30635 .59355 m .29663 .55093 L p .31041 .5859 L .707 .577 .707 r
F P
0 g
s
.29663 .55093 m .30635 .59355 L p .30091 .60044 L .707 .577 .707 r
F P
0 g
s
.29947 .60226 m .30104 .60028 L .29959 .60462 L .707 .577 .707 r
F
.29959 .60462 m .30104 .60028 L .30242 .59853 L F
.30091 .60044 m .29947 .60226 L .30031 .59344 L F
.29947 .60226 m .28942 .55814 L p .30031 .59344 L F P
0 g
s
.29381 .61707 m .29947 .60226 L p .29959 .60462 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31976 .61272 L p .31454 .61983 L .707 .577 .707 r
F P
0 g
s
.30456 .61872 m .31656 .62141 L p .31646 .62117 L .707 .577 .707 r
F P
0 g
s
.31646 .62117 m .31517 .62027 L .30456 .61872 L .707 .577 .707 r
F
.31656 .62141 m .31651 .62121 L p .31646 .62117 L F P
0 g
s
.31454 .61983 m .31976 .61272 L .30799 .61527 L .707 .577 .707 r
F
.33908 .62875 m .31976 .61272 L p .32113 .62295 L F P
0 g
s
.32637 .66202 m .33876 .6296 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.33876 .6296 m .33908 .62875 L p .32113 .62295 L .707 .577 .707 r
F P
0 g
s
.31651 .62121 m .31656 .62141 L .31704 .62141 L p .707 .577 .707 r
F P
0 g
s
.33908 .62875 m .32637 .66202 L .35191 .67703 L p .707 .577 .707 r
F P
0 g
s
.36126 .70313 m .36465 .72169 L .39529 .71776 L p .707 .577 .707 r
F P
0 g
s
.79642 .54607 m .80904 .60144 L .78241 .6043 L p .707 .577 .707 r
F P
0 g
s
.78241 .6043 m .76978 .54893 L .79642 .54607 L p .707 .577 .707 r
F P
0 g
s
.46244 .70181 m .47516 .66854 L .45198 .66931 L p .707 .577 .707 r
F P
0 g
s
.36465 .72169 m .36126 .70313 L .33434 .70457 L p .707 .577 .707 r
F P
0 g
s
.65247 .74108 m .64908 .72252 L .66536 .71423 L p .707 .577 .707 r
F P
0 g
s
.79635 .67812 m .80906 .64485 L .82839 .66089 L p .707 .577 .707 r
F P
0 g
s
.33434 .70457 m .33773 .72312 L .36465 .72169 L p .707 .577 .707 r
F P
0 g
s
.66536 .71423 m .66875 .73279 L .65247 .74108 L p .707 .577 .707 r
F P
0 g
s
.82767 .68814 m .83106 .7067 L .81048 .7055 L p .707 .577 .707 r
F P
0 g
s
.69616 .60429 m .72417 .60852 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.69218 .62555 m .69063 .61876 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .69616 .60429 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .69218 .62555 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .72095 .61692 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .72095 .61692 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72097 .61698 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .68345 .63756 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .71146 .64178 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.68345 .63756 m .69063 .61876 L p .71158 .61749 L .707 .577 .707 r
F P
0 g
s
.67955 .57018 m .70834 .56161 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.69063 .61876 m .67955 .57018 L p .69394 .61856 L .707 .577 .707 r
F P
0 g
s
.48102 .52433 m .49364 .5797 L .50086 .57249 L p .707 .577 .707 r
F P
0 g
s
.50086 .57249 m .48823 .51712 L .48102 .52433 L p .707 .577 .707 r
F P
0 g
s
.76978 .54893 m .78241 .6043 L .75206 .60966 L p .707 .577 .707 r
F P
0 g
s
.75206 .60966 m .73944 .55428 L .76978 .54893 L p .707 .577 .707 r
F P
0 g
s
.33773 .72312 m .33434 .70457 L .31376 .70337 L p .707 .577 .707 r
F P
0 g
s
.80906 .64485 m .79635 .67812 L .77081 .6631 L p .707 .577 .707 r
F P
0 g
s
.77081 .6631 m .78352 .62984 L .80906 .64485 L p .707 .577 .707 r
F P
0 g
s
.31376 .70337 m .31715 .72193 L .33773 .72312 L p .707 .577 .707 r
F P
0 g
s
.72417 .60852 m .75427 .61732 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.72097 .61698 m .72095 .61692 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .72417 .60852 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.73944 .55428 m .75206 .60966 L .72097 .61698 L p .707 .577 .707 r
F P
0 g
s
.71146 .64178 m .72095 .61692 L p .753 .61805 L .707 .577 .707 r
F P
0 g
s
.70834 .56161 m .73944 .55428 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.72095 .61692 m .70834 .56161 L p .72098 .61692 L .707 .577 .707 r
F P
0 g
s
.66875 .73279 m .66536 .71423 L .68917 .7059 L p .707 .577 .707 r
F P
0 g
s
.68917 .7059 m .69256 .72446 L .66875 .73279 L p .707 .577 .707 r
F P
0 g
s
.78352 .62984 m .77081 .6631 L .74156 .65058 L p .707 .577 .707 r
F P
0 g
s
.74156 .65058 m .75427 .61732 L .78352 .62984 L p .707 .577 .707 r
F P
0 g
s
.80709 .68695 m .81048 .7055 L .78356 .70694 L p .707 .577 .707 r
F P
0 g
s
.78356 .70694 m .78017 .68839 L .80709 .68695 L p .707 .577 .707 r
F P
0 g
s
.75427 .61732 m .74156 .65058 L .71146 .64178 L p .707 .577 .707 r
F P
0 g
s
.31715 .72193 m .31376 .70337 L .30155 .69966 L p .707 .577 .707 r
F P
0 g
s
.48823 .51712 m .50086 .57249 L .49834 .56728 L p .707 .577 .707 r
F P
0 g
s
.49834 .56728 m .48572 .51191 L .48823 .51712 L p .707 .577 .707 r
F P
0 g
s
.30155 .69966 m .30494 .71822 L .31715 .72193 L p .707 .577 .707 r
F P
0 g
s
.69256 .72446 m .68917 .7059 L .71817 .69835 L p .707 .577 .707 r
F P
0 g
s
.49122 .66286 m .47851 .69612 L .4859 .68607 L p .707 .577 .707 r
F P
0 g
s
.49574 .68755 m .50291 .68011 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49235 .669 m .49494 .68314 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.49494 .68314 m .49574 .68755 L p .49606 .6729 L .707 .577 .707 r
F P
0 g
s
.50291 .68011 m .49952 .66155 L .49235 .669 L p .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .49814 .65402 L p .49122 .66286 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .49861 .65281 L .49815 .65344 L p .707 .577 .707 r
F P
0 g
s
.49815 .65344 m .49122 .66286 L p .49814 .65402 L .707 .577 .707 r
F P
0 g
s
.50026 .67425 m .49811 .66249 L p .49952 .66155 L .707 .577 .707 r
F P
0 g
s
.4859 .68607 m .48388 .67265 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49814 .65402 m .4859 .68607 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.49811 .66249 m .49687 .65569 L .49813 .65847 L p .707 .577 .707 r
F P
0 g
s
.49813 .65847 m .49952 .66155 L p .49811 .66249 L .707 .577 .707 r
F P
0 g
s
.49861 .65281 m .49814 .65402 L p .49822 .65333 L .707 .577 .707 r
F P
0 g
s
.71817 .69835 m .72156 .71691 L .69256 .72446 L p .707 .577 .707 r
F P
0 g
s
.78017 .68839 m .78356 .70694 L .75292 .71087 L p .707 .577 .707 r
F P
0 g
s
.75292 .71087 m .74953 .69231 L .78017 .68839 L p .707 .577 .707 r
F P
0 g
s
.72156 .71691 m .71817 .69835 L .74953 .69231 L p .707 .577 .707 r
F P
0 g
s
.74953 .69231 m .75292 .71087 L .72156 .71691 L p .707 .577 .707 r
F P
0 g
s
.30494 .71822 m .30155 .69966 L .2989 .6938 L p .707 .577 .707 r
F P
0 g
s
.2989 .6938 m .30229 .71235 L .30494 .71822 L p .707 .577 .707 r
F P
0 g
s
.48572 .51191 m .49834 .56728 L .48634 .56459 L p .707 .577 .707 r
F P
0 g
s
.48634 .56459 m .47372 .50922 L .48572 .51191 L p .707 .577 .707 r
F P
0 g
s
.48388 .67265 m .49477 .64417 L p .49861 .65281 L .707 .577 .707 r
F P
0 g
s
.49659 .63939 m .48388 .67265 L .47266 .65716 L p .707 .577 .707 r
F P
0 g
s
.48805 .67054 m .48513 .65455 L p .49687 .65569 L .707 .577 .707 r
F P
0 g
s
.48513 .65455 m .48466 .65198 L .48689 .65266 L p .707 .577 .707 r
F P
0 g
s
.48689 .65266 m .49687 .65569 L p .48513 .65455 L .707 .577 .707 r
F P
0 g
s
.49477 .64417 m .49659 .63939 L .49696 .64181 L p .707 .577 .707 r
F P
0 g
s
.49696 .64181 m .49861 .65281 L p .49477 .64417 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49952 .66155 m .50291 .68011 L .50026 .67425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30229 .71235 m .2989 .6938 L .30607 .68636 L p .707 .577 .707 r
F P
0 g
s
.47372 .50922 m .48634 .56459 L .46603 .56468 L p .707 .577 .707 r
F P
0 g
s
.46603 .56468 m .45341 .50931 L .47372 .50922 L p .707 .577 .707 r
F P
0 g
s
.30607 .68636 m .30946 .70491 L .30229 .71235 L p .707 .577 .707 r
F P
0 g
s
.47266 .65716 m .48142 .63425 L p .49659 .63939 L .707 .577 .707 r
F P
0 g
s
.48538 .6239 m .47266 .65716 L .45334 .64113 L p .707 .577 .707 r
F P
0 g
s
.46747 .66934 m .46409 .65081 L p .48466 .65198 L .707 .577 .707 r
F P
0 g
s
.46409 .65081 m .46408 .65079 L .46412 .65079 L p .707 .577 .707 r
F P
0 g
s
.46412 .65079 m .48466 .65198 L p .46409 .65081 L .707 .577 .707 r
F P
0 g
s
.48142 .63425 m .48538 .6239 L .48819 .62778 L p .707 .577 .707 r
F P
0 g
s
.48819 .62778 m .49659 .63939 L p .48142 .63425 L .707 .577 .707 r
F P
0 g
s
.49687 .65569 m .50026 .67425 L .48805 .67054 L p .707 .577 .707 r
F P
0 g
s
.32998 .56808 m .35315 .56731 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.32549 .59778 m .32293 .58653 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .32998 .56808 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .32549 .59778 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .34759 .58186 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .34759 .58186 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34917 .5888 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .31727 .60134 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .34044 .60057 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31727 .60134 m .32293 .58653 L p .33536 .58417 L .707 .577 .707 r
F P
0 g
s
.31287 .54241 m .33654 .53342 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.32293 .58653 m .31287 .54241 L p .32758 .58565 L .707 .577 .707 r
F P
0 g
s
.45341 .50931 m .46603 .56468 L .4394 .56755 L p .707 .577 .707 r
F P
0 g
s
.4394 .56755 m .42677 .51217 L .45341 .50931 L p .707 .577 .707 r
F P
0 g
s
.30946 .70491 m .30607 .68636 L .32235 .67807 L p .707 .577 .707 r
F P
0 g
s
.45334 .64113 m .46605 .60787 L .48538 .6239 L p .707 .577 .707 r
F P
0 g
s
.32235 .67807 m .32574 .69662 L .30946 .70491 L p .707 .577 .707 r
F P
0 g
s
.48466 .65198 m .48805 .67054 L .46747 .66934 L p .707 .577 .707 r
F P
0 g
s
.35315 .56731 m .38116 .57153 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34917 .5888 m .34759 .58186 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .35315 .56731 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .34917 .5888 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .37791 .58002 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .37791 .58002 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .37796 .58022 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .34044 .60057 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36844 .6048 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.34044 .60057 m .34759 .58186 L p .36845 .5806 L .707 .577 .707 r
F P
0 g
s
.33654 .53342 m .36533 .52485 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.34759 .58186 m .33654 .53342 L p .35097 .58166 L .707 .577 .707 r
F P
0 g
s
.42677 .51217 m .4394 .56755 L .40905 .5729 L p .707 .577 .707 r
F P
0 g
s
.40905 .5729 m .39643 .51753 L .42677 .51217 L p .707 .577 .707 r
F P
0 g
s
.46605 .60787 m .45334 .64113 L .4278 .62612 L p .707 .577 .707 r
F P
0 g
s
.4278 .62612 m .44051 .59285 L .46605 .60787 L p .707 .577 .707 r
F P
0 g
s
.38116 .57153 m .41126 .58033 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.37796 .58022 m .37791 .58002 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .38116 .57153 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.39643 .51753 m .40905 .5729 L .37796 .58022 L p .707 .577 .707 r
F P
0 g
s
.36844 .6048 m .37791 .58002 L p .40984 .58114 L .707 .577 .707 r
F P
0 g
s
.36533 .52485 m .39643 .51753 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.37791 .58002 m .36533 .52485 L p .37802 .58003 L .707 .577 .707 r
F P
0 g
s
.32574 .69662 m .32235 .67807 L .34616 .66974 L p .707 .577 .707 r
F P
0 g
s
.34616 .66974 m .34955 .68829 L .32574 .69662 L p .707 .577 .707 r
F P
0 g
s
.44051 .59285 m .4278 .62612 L .39855 .6136 L p .707 .577 .707 r
F P
0 g
s
.39855 .6136 m .41126 .58033 L .44051 .59285 L p .707 .577 .707 r
F P
0 g
s
.46408 .65079 m .46747 .66934 L .44055 .67078 L p .707 .577 .707 r
F P
0 g
s
.44055 .67078 m .43716 .65222 L .46408 .65079 L p .707 .577 .707 r
F P
0 g
s
.41126 .58033 m .39855 .6136 L .36844 .6048 L p .707 .577 .707 r
F P
0 g
s
.34955 .68829 m .34616 .66974 L .37516 .66219 L p .707 .577 .707 r
F P
0 g
s
.37516 .66219 m .37855 .68074 L .34955 .68829 L p .707 .577 .707 r
F P
0 g
s
.43716 .65222 m .44055 .67078 L .40991 .67471 L p .707 .577 .707 r
F P
0 g
s
.40991 .67471 m .40652 .65615 L .43716 .65222 L p .707 .577 .707 r
F P
0 g
s
.37855 .68074 m .37516 .66219 L .40652 .65615 L p .707 .577 .707 r
F P
0 g
s
.40652 .65615 m .40991 .67471 L .37855 .68074 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH0
05YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH;0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH6
0003FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF1@001UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0009JEP@0009JEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000<000MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0069oo`@00003FUH0
05YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005ioo`@0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05aoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol005Yoo`8000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00F7oo0P001UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0
0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05Ioo`<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000XOol;000cOol005Aoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000POol80003FUH0
0`00FUIJEP03FUH01000FUH00000<Goo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000IOol70003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool0059oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8001Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P004Goo10001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP/00005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000?Ool200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000_Ool0059oo`800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`<000=JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF1P001UYF00<005YFFUH015YF00<005YF
FUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0009Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;goo001COol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002moo`00Dgoo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00
0080009JEP05001JEUYFFUH00008FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
02moo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0P00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000MJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005Ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP000080
00IJEP03001JEUYF00EJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH00`00
FUIJEP03FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00<005YF
00000`002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00MJEPD00003FUH005YF00]JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002io
o`00EGoo0P000eYF00@005YFFUIJEP@000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF
FUH200000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00D7oo1P000UYF1`00
0eYF10000UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00eYF0P0035YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEQ@002eoo`00C7oo10000UYF00<0
05YF00001@0015YF00<005YFFUH01EYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<007ooOol0:goo0017Ool50006FUH01@00FUH005YF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01eYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00
FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000]Ool004=oo`@0009JEP03001JEUYF00MJEP@000=JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF009JEPH000UJEP03001JEUYF00EJEP04001JEUYF0009
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00;Woo000oOol40006FUH00`00FUIJEP07FUH00`00FUH00002
0003FUH20002FUH00`00FUIJEP02FUH80002FUH01000FUIJEUYF0P001UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH0
0002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH30007FUH00`00FUH00008FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool003]oo`@00003FUH005YF00QJEP03001J
EUYF00IJEP03001JEP00009JEP<0009JEPP00003FUH0000000IJEP03001JEUYF00=JEP8000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP<000QJEP03001JEUYF00EJEP04001JEP00000`Ool003Moo`@000EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEP0000=JEP03001JEUYF009JEP800006FUH005YFFUH005YF0P001UYF00<0
05YFFUH01EYF0P0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000IJEP03001JEUYF00AJEP<0039o
o`00=Goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00@005YFFUH0
00AJEP80009JEP04001JEP000006FUH40005FUH30008FUH00`00FUIJEP04FUH20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02
FUH2000eOol003=oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=J
EP04001JEUYF0004FUH300000eYF001JEP020006FUH50004FUH00`00FUIJEP020005FUH00`00FUIJ
EP04FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P000eYF00@005YF000003Moo`00<Goo0P001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF0P000UYF00@005YFFUH000=JEP04001JEUYFFUH200000eYF00000005FUH6
0004FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP08FUH01000FUIJEP0035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00MJEPH003Uoo`00;goo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000EJEPH000AJ
EP03001JEUYF00AJEP<000MJEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<000=JEP/000AJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH2000jOol002eoo`80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000006FUH00`00FUIJEP04FUH20006FUH00`00FUH000020005FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF00000005FUH00`00FUIJEP03FUH60007FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000hOol002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJEP06FUH20004FUH00`00
FUIJEP07FUH00`00FUIJEP07FUH20004FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00Oomoo`0eOol002]oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YFFUH01eYF00<005YFFUH025YF
0`000UYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0015YF00D005YFFUIJEP0000MJEP03001JEUYF00=JEP<00003FUH005YF00QJEP03
001JEUYF00IJEP<003Eoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30009FUHE000015YF001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH015YF00@005YFFUH000MJEP03001JEUYF00@0009oo`<000QJEP03001JEUYF00EJ
EP05001JEUYFFUH0000dOol002]oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH01EYF
2P0015YF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000EJEP00001JEP00009JEP04001JEUYF0003
FUH60009Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH00003FUH00000
00UJEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07
001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF
0P000eYF200047oo0`0000=JEP00FUH01eYF00<005YFFUH015YF00<007ooOol0;goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040003FUH0
0`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF10001UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20005FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00Oomoo`0AOol20007FUH00`00
FUIJEP05FUH00`00Oomoo`0_Ool002aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH50008FUH00`00FUIJEP02FUH20006FUH400000eYF001JEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF0P000eYF00<007ooOol027oo0`00
27oo0P001EYF00<005YFFUH015YF00<005YF0000<7oo000/Ool01000FUIJEP000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01@000eYF00<005YFFUH01UYF00<005YFFUH015YF1P001EYF
00<005YFFUH01eYF00<005YFFUH00UYF4`000UYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0`000UYF00<007ooOol01goo1@002Goo0P000eYF
00<005YFFUH01eYF00<007ooOol0;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH30006FUH200000eYF001JEP06FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJ
EP04FUH70007FUH00`00FUIJEP04FUH01000FUH005YF1@0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF00@005YFFUIJEP<000Uoo`D000]oo`<000IJ
EP80009JEP03001oogoo02eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000P001UYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YF
FUH010001EYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUH005YF0002FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEP001UYF00<005YFFUH00eYF
0P0027oo1@003Goo00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0;7oo000]Ool01000FUIJ
EP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF
00@005YF000000MJEP03001JEUYF00AJEP@00004FUH000000004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01@00FUIJEP00FUH00P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF100025YF00<005YFFUH01EYF0P001goo0`003goo00<005YFFUH00eYF00<005YFFUH0
0UYF00<007ooOol0;7oo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000EJEP00001JEP0000MJEP03001JEUYF00@000=JEPH000=J
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200001EYF000005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF00<005YFFUH01eYF0`00
67oo00D005YFFUIJEP0000AJEP8002ioo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01eYF0P000eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH0
1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP800005FUH005YFFUH0000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH20004FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0037oo500000=JEP00Ool0;7oo000^Ool20003FUH01000FUIJEUYF10001eYF00<0
05YFFUH01UYF00<005YFFUH01eYF0`0015YF00@005YFFUIJEP800005Ool005YFFUH00004FUH80002
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF10000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00D005YFFUIJEP0000QJEP03001JEUYF
00=JEP8000=oo`L000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008002eoo`00;Woo
00<005YFFUH01`000eYF10000UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUH000AJEP04
001JEP000003Ool01000FUIJEP001UYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF100025YF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH000020005FUH00`00FUIJEP05FUH5
0007FUH00`00FUIJEP06FUH01000FUIJEP000eYF0`001Goo00@005YFFUH000AJEPd000AJEP03001J
EUYF00AJEP04001JEP000008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH00000;Goo000]Ool00`00FUH00002FUH01P00FUIJEUYFOol0
00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00MJEP05001JEUYF001JEP020002FUH00`00Oomo
o`03Ool80004FUH00`00FUIJEP06FUH=000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH20005FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;Goo000/Ool40003FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40009FUH200000eYF0000000:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUH000020006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0002FUH00`00Oomoo`0[Ool002ao
o`04001JEP000004FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP040004Ool20006FUH01000FUH0
00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH010000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0015YF00<005YFFUH015YF0`002EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
1EYF00D005YFFUH005YF00@002aoo`00;7oo00<005YF00000eYF0P000UYF3@002Woo0P0015YF00@0
05YF0000009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000AJEP03001JEUYF009JEP80009JEP03001JEUYF00MJEP03001JEUYF009JEPT00003OomJ
EUYF009JEP8000EJEP04001JEUYFFUH300000eYF0000000/Ool002aoo`03001oo`0000=JEP03001J
EUYF009JEP8001Ioo`800004FUH005YFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP05000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUH000020004FUH00`00FUIJEP06FUH80004
FUH01000FUIJEWoo15YF0P001EYF00@005YFFUIJEP8000=JEP03001oogoo02Yoo`00;Goo00D005YF
FUIJEP00009JEP03OomJEUYF009JEP03001oogoo01Eoo`8000=JEP80009JEP03001JEUYF00=JEP03
001JEUYF00AJEP03001JEUYF009JEPL000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP800003FUH005YF00EJ
EP03001JEUYF009JEP<0009JEP03001JEP0000@000=JEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF008002eoo`00;Goo00D005YFFUIJEP00009JEP03OomJEUYF009JEP<0
00aoo`<000Qoo`8000=JEQ@00003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPH000=JEP03001JEUYF00AJ
EP03001JEP0000D00004FUH005YFFUH50003FUH01@00FUIJEUYFOol00UYF0P001EYF00@005YFFUIJ
EP80009JEP03001oogoo02aoo`00;Woo00@005YFFUH0009JEP05OomJEUYFFUH00003FUH00`00Oomo
o`08Ool50009Ool20003FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP02FUH30006Ool300000eYF0000
00030002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP8002moo`00;Woo00@0
05YFFUH000IJEP03001JEUYF009JEP03001oogoo00Moo`D000]oo`<000MJEP03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEP000080
00aoo`D000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000aOol002moo`8000IJ
EP03001JEUYF00AJEP8000Moo`D000eoo`03001JEUYF00AJEP800005FUH005YFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30002FUH01000FUIJEUYF0`004Woo0`0000=JEP00FUH01eYF00<0
05YFFUH00eYF00<005YFFUH00P00<goo000`Ool00`00FUIJEP04FUH00`00FUIJEP06FUH20006Ool3
000?Ool00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00H005YF000005YF000>Ool700000eYF000000030004FUH00`00FUIJEP03FUH0
1000FUH00000=Goo000aOol00`00FUIJEP03FUH00`00FUIJEP06FUH01000FUH000005goo00<005YF
00000UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF01@000=JEP03001JEUYF00IJEPd003Moo`00<Woo00D005YFFUIJEP0000QJEP03001JEUYF
009JEP<000Yooa<0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00=JEQT000IJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005FUH00000FUH00005FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol003=oo`04001JEUYF0008
FUH00`00FUIJEP05FUH:0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH8000<FUH00`00FUIJEP09FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200001EYF000005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00
@7oo000dOol20009FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF0000
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP040015Ool003Eo
o`03001JEUYF00IJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP001UYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH010001UYF00<005YFFUH00UYF0P000UYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH00UYF1P00BGoo000fOol20006FUH400000eYF001JEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF0`000eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00<005YF
FUH00UYF0`000eYF5000Cgoo000hOol60005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH@0002FUH0
0`00FUH000030006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH300000eYF001JEP03FUH200000goo00000003FUH00`00FUIJEP07FUH00`00
Oomoo`1DOol003Ioo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001J
EUYF00AJEP04001JEP000002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH0000015YF0P000goo0`00
1eYF00@005YFFUH005Ioo`00=7oo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF20001eYF00<0
05YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP80009J
EP8000Eoo`03001JEUYF00AJEP03001JEUYF009JEP03001oogoo05=oo`00<goo0P001eYF00<005YF
FUH015YF200015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF10001Woo00<005YFFUH00eYF00<005YFFUH00UYF00<007oo
Ool0Dgoo000aOol200000eYF001JEP06FUH00`00FUIJEP040003FUH60003FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF0000
00Moo`05001JEUYFFUH00004FUH2001EOol0031oo`05001JEUYFFUH00006FUH40003Ool200000eYF
001JEP050002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000400000AJEP00FUH005Aoo`00;Woo0`0015YF
00@005YFFUIJEP8000Uoo`P0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04
001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP020007FUH00`00FUIJEP03
FUH5001DOol002eoo`04001JEUYF0004FUH01000FUH000003Woo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00@005YFFUIJEPD000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF0080
00MJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Goo00@005YFFUH000=JEP<000moo`/000AJ
EP03001JEUYF00AJEP03001JEUYF00<000=oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP05001JEP00FUH00008FUH00`00FUIJEP02FUH00`00FUIJEP02001DOol002eoo`05001JEUYF
001JEP02000>Ool40002FUH00`00FUIJEP06FUH?0006Ool01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000005Aoo`00;Woo00<005YF0000
4@001UYF00<005YFFUH01UYF00<005YFFUH01EYF0`002goo0P0000=JEP00FUH01UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH00UYF1P000eYF00@005YFFUH005Aoo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0100047oo0P001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF00002@000eYF1P0000=JEP000000Dgoo000^Ool20002FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH5000EOol20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF100000=ooeYFFUH00eYF00<005YFFUH00eYF0P000UYF1P00Dgoo000^Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04000LOol40002FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01P00FUH00000
FUH0009JEP03OomJEUYF009JEP8000EJEP04001JEUYFFUH20003FUH00`00Oomoo`1AOol002moo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPL002Aoo`D000QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000=JEP03001JEUYF00EJEP03
001JEUYF00=JEP8000=JEP03001JEUYF008005Aoo`00<Goo5000<7oo1P000UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02@000eYF00D005YFFUIJEWoo00=JEP03001J
EUYF00=JEP04001JEUYFFUH20002FUH00`00Oomoo`1COol007]oo`T000IJEP03001JEUYF00UJEP03
001JEUYF00AJEP/00003FUH0000000<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF
FUH005YF0P00EWoo0024OolI000;Ool60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0`00F7oo002?Ool01000FUIJEP000eYF0`004Goo100000=JEP00FUH01eYF00<005YFFUH00eYF
00<005YFFUH00P00FWoo002?Ool01@00FUIJEP00FUH00P0047oo1`0000=JEP0000000`0015YF00<0
05YFFUH00eYF00@005YF000005aoo`00Sgoo00<005YFFUH050000eYF00<005YFFUH01UYF3@00GWoo
002@Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04001SOol0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00AJEPD006Moo`00T7oo0P000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01000K7oo002AOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6
001`Ool009=oo`@000=JEP03001JEUYF009JEPP007Ioo`00Ugoo2000OWoo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59852 .74498 m .59068 .68916 L .55982 .69174 L p .707 .577 .707 r
F P
0 g
s
.59068 .68916 m .59852 .74498 L .63007 .74015 L p .707 .577 .707 r
F P
0 g
s
.63007 .74015 m .62223 .68433 L .59068 .68916 L p .707 .577 .707 r
F P
0 g
s
.62223 .68433 m .63007 .74015 L .65923 .73356 L p .707 .577 .707 r
F P
0 g
s
.65923 .73356 m .65138 .67774 L .62223 .68433 L p .707 .577 .707 r
F P
0 g
s
.56767 .74757 m .55982 .69174 L .53268 .69184 L p .707 .577 .707 r
F P
0 g
s
.55982 .69174 m .56767 .74757 L .59852 .74498 L p .707 .577 .707 r
F P
0 g
s
.65138 .67774 m .65923 .73356 L .68314 .72585 L p .707 .577 .707 r
F P
0 g
s
.68314 .72585 m .67529 .67002 L .65138 .67774 L p .707 .577 .707 r
F P
0 g
s
.53268 .69184 m .54053 .74767 L .56767 .74757 L p .707 .577 .707 r
F P
0 g
s
.59086 .81566 m .59882 .78039 L .56839 .77179 L p .707 .577 .707 r
F P
0 g
s
.59882 .78039 m .59086 .81566 L .62203 .82093 L p .707 .577 .707 r
F P
0 g
s
.62203 .82093 m .62999 .78566 L .59882 .78039 L p .707 .577 .707 r
F P
0 g
s
.54053 .74767 m .53268 .69184 L .51191 .68944 L p .707 .577 .707 r
F P
0 g
s
.56043 .80706 m .56839 .77179 L .54167 .76069 L p .707 .577 .707 r
F P
0 g
s
.56839 .77179 m .56043 .80706 L .59086 .81566 L p .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .65811 .81958 L .63785 .82371 L p .707 .577 .707 r
F P
0 g
s
.63785 .82371 m .62888 .82554 L p .63467 .82788 L .707 .577 .707 r
F P
0 g
s
.66022 .8382 m .63785 .82371 L .63467 .82788 L .707 .577 .707 r
F
.65811 .81958 m .66022 .8382 L .68418 .8309 L p F P
0 g
s
.68418 .8309 m .68207 .81227 L .66657 .817 L p .707 .577 .707 r
F P
0 g
s
.66657 .817 m .65811 .81958 L p .6635 .82192 L .707 .577 .707 r
F P
0 g
s
.68418 .8309 m .66657 .817 L .6635 .82192 L .707 .577 .707 r
F
.68207 .81227 m .68418 .8309 L .70051 .82296 L p F P
0 g
s
.70051 .82296 m .69841 .80434 L .68893 .80894 L p .707 .577 .707 r
F P
0 g
s
.68893 .80894 m .68207 .81227 L p .68672 .81497 L .707 .577 .707 r
F P
0 g
s
.70051 .82296 m .68893 .80894 L .68672 .81497 L .707 .577 .707 r
F
.69085 .81348 m .69805 .80405 L p .69869 .78235 L F P
0 g
s
.69881 .77821 m .69658 .78811 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.69658 .78811 m .69085 .81348 L p .69869 .78235 L .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .69085 .81348 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68256 .78452 m .68015 .79521 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.68015 .79521 m .6746 .81978 L p .6839 .78919 L .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .6746 .81978 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65885 .78709 m .65591 .80008 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.65591 .80008 m .65088 .82235 L p .66155 .7927 L .707 .577 .707 r
F P
0 g
s
.62999 .78566 m .62203 .82093 L .65088 .82235 L p .707 .577 .707 r
F P
0 g
s
.65088 .82235 m .65885 .78709 L .62999 .78566 L p .707 .577 .707 r
F P
0 g
s
.67529 .67002 m .68314 .72585 L .69946 .71777 L p .707 .577 .707 r
F P
0 g
s
.69946 .71777 m .69161 .66194 L .67529 .67002 L p .707 .577 .707 r
F P
0 g
s
.59933 .84819 m .59723 .82957 L .56626 .83127 L p .707 .577 .707 r
F P
0 g
s
.59723 .82957 m .59933 .84819 L .63098 .84416 L p .707 .577 .707 r
F P
0 g
s
.63098 .84416 m .62888 .82554 L .59723 .82957 L p .707 .577 .707 r
F P
0 g
s
.51191 .68944 m .51976 .74526 L .54053 .74767 L p .707 .577 .707 r
F P
0 g
s
.62888 .82554 m .63098 .84416 L .66022 .8382 L p .707 .577 .707 r
F P
0 g
s
.54167 .76069 m .53371 .79596 L .56043 .80706 L p .707 .577 .707 r
F P
0 g
s
.53371 .79596 m .54167 .76069 L .52128 .74819 L p .707 .577 .707 r
F P
0 g
s
.6746 .81978 m .68256 .78452 L .65885 .78709 L p .707 .577 .707 r
F P
0 g
s
.56626 .83127 m .56836 .84989 L .59933 .84819 L p .707 .577 .707 r
F P
0 g
s
.56836 .84989 m .56626 .83127 L .539 .83048 L p .707 .577 .707 r
F P
0 g
s
.539 .83048 m .54111 .8491 L .56836 .84989 L p .707 .577 .707 r
F P
0 g
s
.51976 .74526 m .51191 .68944 L .49954 .68477 L p .707 .577 .707 r
F P
0 g
s
.52128 .74819 m .51332 .78346 L .53371 .79596 L p .707 .577 .707 r
F P
0 g
s
.69161 .66194 m .69946 .71777 L .70659 .71011 L p .707 .577 .707 r
F P
0 g
s
.70659 .71011 m .69874 .65429 L .69161 .66194 L p .707 .577 .707 r
F P
0 g
s
.54111 .8491 m .539 .83048 L .51813 .82727 L p .707 .577 .707 r
F P
0 g
s
.49954 .68477 m .50739 .74059 L .50829 .74093 L p .707 .577 .707 r
F P
0 g
s
.5139 .72772 m .49954 .68477 L .50829 .74093 L .707 .577 .707 r
F
.50739 .74059 m .49954 .68477 L .49679 .67829 L p F P
0 g
s
.50739 .74059 m .5041 .72125 L .50453 .73332 L .707 .577 .707 r
F
.50335 .75258 m .50724 .74125 L .50531 .7356 L F
.50546 .73605 m .50739 .74059 L p .50453 .73332 L F P
0 g
s
.4987 .75915 m .50125 .77078 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50666 .72389 m .50453 .73332 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .4987 .75915 L p .50259 .75919 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50453 .73332 L p .5041 .72125 L .707 .577 .707 r
F P
0 g
s
.49679 .67829 m .50393 .67063 L p .50462 .73214 L .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50666 .72389 L p .50531 .7356 L .707 .577 .707 r
F P
0 g
s
.50453 .73332 m .50666 .72389 L p .50581 .73175 L .707 .577 .707 r
F P
0 g
s
.50463 .73363 m .50464 .73411 L .50546 .73605 L p .707 .577 .707 r
F P
0 g
s
.50464 .73411 m .50453 .73332 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50724 .74125 m .50922 .73551 L .50531 .7356 L .707 .577 .707 r
F
.51177 .72646 m .50464 .73411 L p .50463 .7332 L F P
0 g
s
.50666 .72389 m .51386 .71446 L p .50954 .7272 L .707 .577 .707 r
F P
0 g
s
.50581 .73175 m .50666 .72389 L .50954 .7272 L .707 .577 .707 r
F
.51153 .72476 m .51177 .72646 L p .50463 .7332 L F P
0 g
s
.50125 .77078 m .50765 .74244 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.50765 .74244 m .50922 .73551 L p .50335 .75258 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .4987 .75915 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .51153 .72476 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .5059 .74973 L p .49952 .75671 L .707 .577 .707 r
F P
0 g
s
.51386 .71446 m .53011 .70815 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51177 .72646 m .51153 .72476 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.50829 .74093 m .51976 .74526 L p .5139 .72772 L .707 .577 .707 r
F P
0 g
s
.51332 .78346 m .52128 .74819 L .50922 .73551 L p .707 .577 .707 r
F P
0 g
s
.50922 .73551 m .50125 .77078 L .51332 .78346 L p .707 .577 .707 r
F P
0 g
s
.51153 .72476 m .51386 .71446 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .51177 .72646 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .52798 .71759 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .52798 .71759 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52809 .71838 L p .51203 .72455 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .5059 .74973 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52215 .74342 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.5059 .74973 m .51153 .72476 L p .52347 .71956 L .707 .577 .707 r
F P
0 g
s
.51203 .72455 m .51153 .72476 L .51225 .72285 L .707 .577 .707 r
F
.50393 .67063 m .52024 .66256 L p .51225 .72285 L F P
0 g
s
.51153 .72476 m .50393 .67063 L p .51225 .72285 L .707 .577 .707 r
F P
0 g
s
.50393 .67063 m .51153 .72476 L p .50463 .7332 L .707 .577 .707 r
F P
0 g
s
.50481 .74114 m .50581 .73175 L .50954 .7272 L .707 .577 .707 r
F
.50453 .73332 m .50581 .73175 L .50481 .74114 L F
.50463 .7332 m .50453 .73332 L .50462 .73214 L F
.50453 .73332 m .49679 .67829 L p .50462 .73214 L F P
0 g
s
.4987 .75915 m .50453 .73332 L p .50481 .74114 L .707 .577 .707 r
F P
0 g
s
.69085 .81348 m .69881 .77821 L .68256 .78452 L p .707 .577 .707 r
F P
0 g
s
.51813 .82727 m .52023 .8459 L .54111 .8491 L p .707 .577 .707 r
F P
0 g
s
.52023 .8459 m .51813 .82727 L .50569 .82197 L p .707 .577 .707 r
F P
0 g
s
.69805 .80405 m .70601 .76879 L .69881 .77821 L p .707 .577 .707 r
F P
0 g
s
.50569 .82197 m .50779 .84059 L .52023 .8459 L p .707 .577 .707 r
F P
0 g
s
.69874 .65429 m .70659 .71011 L .70384 .70364 L p .707 .577 .707 r
F P
0 g
s
.70384 .70364 m .69599 .64781 L .69874 .65429 L p .707 .577 .707 r
F P
0 g
s
.69841 .80434 m .70051 .82296 L .70763 .81517 L p .707 .577 .707 r
F P
0 g
s
.70763 .81517 m .70553 .79654 L .69841 .80434 L p .707 .577 .707 r
F P
0 g
s
.48766 .8219 m .49179 .32047 L .44778 .31742 L p .707 .577 .707 r
F P
0 g
s
.50779 .84059 m .50569 .82197 L .50288 .81508 L p .707 .577 .707 r
F P
0 g
s
.50288 .81508 m .50499 .83371 L .50779 .84059 L p .707 .577 .707 r
F P
0 g
s
.50499 .83371 m .50288 .81508 L .51 .80729 L p .707 .577 .707 r
F P
0 g
s
.51 .80729 m .5121 .82591 L .50499 .83371 L p .707 .577 .707 r
F P
0 g
s
.53011 .70815 m .55383 .70559 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52809 .71838 m .52798 .71759 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .53011 .70815 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.55383 .70559 m .55226 .71252 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.54415 .65484 m .552 .71067 L .53522 .71608 L p .707 .577 .707 r
F P
0 g
s
.53522 .71608 m .52809 .71838 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52831 .71752 m .54415 .65484 L .53522 .71608 L .707 .577 .707 r
F
.54586 .74085 m .52215 .74342 L p .54712 .71359 L F P
0 g
s
.55226 .71252 m .54586 .74085 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52215 .74342 m .52798 .71759 L p .54712 .71359 L .707 .577 .707 r
F P
0 g
s
.52024 .66256 m .54415 .65484 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.52798 .71759 m .52024 .66256 L p .52831 .71752 L .707 .577 .707 r
F P
0 g
s
.5121 .82591 m .51 .80729 L .52634 .79935 L p .707 .577 .707 r
F P
0 g
s
.52634 .79935 m .52844 .81798 L .5121 .82591 L p .707 .577 .707 r
F P
0 g
s
.52844 .81798 m .52634 .79935 L .55029 .79205 L p .707 .577 .707 r
F P
0 g
s
.55029 .79205 m .5524 .81067 L .52844 .81798 L p .707 .577 .707 r
F P
0 g
s
.49179 .32047 m .48766 .8219 L .5326 .82113 L p .707 .577 .707 r
F P
0 g
s
.5326 .82113 m .53673 .3197 L .49179 .32047 L p .707 .577 .707 r
F P
0 g
s
.552 .71067 m .54415 .65484 L .57331 .64825 L p .707 .577 .707 r
F P
0 g
s
.54586 .74085 m .55383 .70559 L .58268 .70701 L p .707 .577 .707 r
F P
0 g
s
.57331 .64825 m .58115 .70407 L .552 .71067 L p .707 .577 .707 r
F P
0 g
s
.58268 .70701 m .57471 .74227 L .54586 .74085 L p .707 .577 .707 r
F P
0 g
s
.5524 .81067 m .55029 .79205 L .57953 .78609 L p .707 .577 .707 r
F P
0 g
s
.57953 .78609 m .58163 .80471 L .5524 .81067 L p .707 .577 .707 r
F P
0 g
s
.53673 .3197 m .5326 .82113 L .57408 .81662 L p .707 .577 .707 r
F P
0 g
s
.58115 .70407 m .57331 .64825 L .60486 .64342 L p .707 .577 .707 r
F P
0 g
s
.57408 .81662 m .57821 .3152 L .53673 .3197 L p .707 .577 .707 r
F P
0 g
s
.44365 .81885 m .44778 .31742 L .40902 .31085 L p .707 .577 .707 r
F P
0 g
s
.44778 .31742 m .44365 .81885 L .48766 .8219 L p .707 .577 .707 r
F P
0 g
s
.70601 .76879 m .69805 .80405 L .69549 .79243 L p .707 .577 .707 r
F P
0 g
s
.69549 .79243 m .70052 .77015 L p .70601 .76879 L .707 .577 .707 r
F P
0 g
s
.70346 .75716 m .69549 .79243 L .68343 .77974 L p .707 .577 .707 r
F P
0 g
s
.69238 .80298 m .69125 .79299 L p .70272 .78966 L .707 .577 .707 r
F P
0 g
s
.69125 .79299 m .69028 .78435 L .6941 .78598 L p .707 .577 .707 r
F P
0 g
s
.6941 .78598 m .70272 .78966 L p .69125 .79299 L .707 .577 .707 r
F P
0 g
s
.70052 .77015 m .70346 .75716 L .70428 .7609 L p .707 .577 .707 r
F P
0 g
s
.70428 .7609 m .70601 .76879 L p .70052 .77015 L .707 .577 .707 r
F P
0 g
s
.69599 .64781 m .70384 .70364 L .69147 .69897 L p .707 .577 .707 r
F P
0 g
s
.69147 .69897 m .68363 .64314 L .69599 .64781 L p .707 .577 .707 r
F P
0 g
s
.60486 .64342 m .61271 .69925 L .58115 .70407 L p .707 .577 .707 r
F P
0 g
s
.57471 .74227 m .58268 .70701 L .61385 .71228 L p .707 .577 .707 r
F P
0 g
s
.61385 .71228 m .60588 .74754 L .57471 .74227 L p .707 .577 .707 r
F P
0 g
s
.58163 .80471 m .57953 .78609 L .61118 .78206 L p .707 .577 .707 r
F P
0 g
s
.61118 .78206 m .61329 .80068 L .58163 .80471 L p .707 .577 .707 r
F P
0 g
s
.57821 .3152 m .57408 .81662 L .60804 .80882 L p .707 .577 .707 r
F P
0 g
s
.61271 .69925 m .60486 .64342 L .63571 .64083 L p .707 .577 .707 r
F P
0 g
s
.64428 .72088 m .63632 .75615 L .60588 .74754 L p .707 .577 .707 r
F P
0 g
s
.60588 .74754 m .61385 .71228 L .64428 .72088 L p .707 .577 .707 r
F P
0 g
s
.60804 .80882 m .61217 .30739 L .57821 .3152 L p .707 .577 .707 r
F P
0 g
s
.70553 .79654 m .70763 .81517 L .70483 .80828 L p .707 .577 .707 r
F P
0 g
s
.70483 .80828 m .70272 .78966 L .70553 .79654 L p .707 .577 .707 r
F P
0 g
s
.40489 .81228 m .40902 .31085 L .3793 .30141 L p .707 .577 .707 r
F P
0 g
s
.40902 .31085 m .40489 .81228 L .44365 .81885 L p .707 .577 .707 r
F P
0 g
s
.25552 .7082 m .24767 .65238 L .21681 .65496 L p .707 .577 .707 r
F P
0 g
s
.24767 .65238 m .25552 .7082 L .28707 .70337 L p .707 .577 .707 r
F P
0 g
s
.28707 .70337 m .27922 .64755 L .24767 .65238 L p .707 .577 .707 r
F P
0 g
s
.27922 .64755 m .28707 .70337 L .31622 .69678 L p .707 .577 .707 r
F P
0 g
s
.31622 .69678 m .30837 .64096 L .27922 .64755 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22466 .71079 m .21681 .65496 L .18967 .65506 L p .707 .577 .707 r
F P
0 g
s
.21681 .65496 m .22466 .71079 L .25552 .7082 L p .707 .577 .707 r
F P
0 g
s
.30837 .64096 m .31622 .69678 L .34013 .68907 L p .707 .577 .707 r
F P
0 g
s
.34013 .68907 m .33228 .63324 L .30837 .64096 L p .707 .577 .707 r
F P
0 g
s
.68343 .77974 m .69139 .74448 L .70346 .75716 L p .707 .577 .707 r
F P
0 g
s
.68363 .64314 m .69147 .69897 L .6707 .69656 L p .707 .577 .707 r
F P
0 g
s
.6707 .69656 m .66286 .64074 L .68363 .64314 L p .707 .577 .707 r
F P
0 g
s
.63571 .64083 m .64356 .69666 L .61271 .69925 L p .707 .577 .707 r
F P
0 g
s
.64215 .78036 m .64425 .79898 L .61329 .80068 L p .707 .577 .707 r
F P
0 g
s
.61329 .80068 m .61118 .78206 L .64215 .78036 L p .707 .577 .707 r
F P
0 g
s
.61217 .30739 m .60804 .80882 L .63115 .79847 L p .707 .577 .707 r
F P
0 g
s
.63115 .79847 m .63528 .29705 L .61217 .30739 L p .707 .577 .707 r
F P
0 g
s
.18967 .65506 m .19752 .71089 L .22466 .71079 L p .707 .577 .707 r
F P
0 g
s
.24785 .77874 m .25582 .74347 L .22538 .73487 L p .707 .577 .707 r
F P
0 g
s
.25582 .74347 m .24785 .77874 L .27902 .78401 L p .707 .577 .707 r
F P
0 g
s
.27902 .78401 m .28699 .74875 L .25582 .74347 L p .707 .577 .707 r
F P
0 g
s
.19752 .71089 m .18967 .65506 L .1689 .65266 L p .707 .577 .707 r
F P
0 g
s
.70272 .78966 m .70483 .80828 L .69238 .80298 L p .707 .577 .707 r
F P
0 g
s
.21742 .77014 m .22538 .73487 L .19866 .72377 L p .707 .577 .707 r
F P
0 g
s
.22538 .73487 m .21742 .77014 L .24785 .77874 L p .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .31511 .78317 L .29449 .78737 L p .707 .577 .707 r
F P
0 g
s
.29449 .78737 m .28587 .78913 L p .29143 .79137 L .707 .577 .707 r
F P
0 g
s
.31721 .80179 m .29449 .78737 L .29143 .79137 L .707 .577 .707 r
F
.31511 .78317 m .31721 .80179 L .34117 .79449 L p F P
0 g
s
.34117 .79449 m .33907 .77586 L .32325 .78068 L p .707 .577 .707 r
F P
0 g
s
.32325 .78068 m .31511 .78317 L p .3203 .78542 L .707 .577 .707 r
F P
0 g
s
.34117 .79449 m .32325 .78068 L .3203 .78542 L .707 .577 .707 r
F
.33907 .77586 m .34117 .79449 L .3575 .78655 L p F P
0 g
s
.3575 .78655 m .3554 .76792 L .34572 .77263 L p .707 .577 .707 r
F P
0 g
s
.34572 .77263 m .33907 .77586 L p .34358 .77848 L .707 .577 .707 r
F P
0 g
s
.3575 .78655 m .34572 .77263 L .34358 .77848 L .707 .577 .707 r
F
.34784 .77656 m .35504 .76713 L p .35568 .7455 L F P
0 g
s
.3558 .74129 m .35353 .75135 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.35353 .75135 m .34784 .77656 L p .35568 .7455 L .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .34784 .77656 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.33955 .7476 m .3371 .75845 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.3371 .75845 m .33159 .78286 L p .34091 .75234 L .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .33159 .78286 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31584 .75017 m .31287 .76333 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.31287 .76333 m .30787 .78543 L p .31858 .75585 L .707 .577 .707 r
F P
0 g
s
.28699 .74875 m .27902 .78401 L .30787 .78543 L p .707 .577 .707 r
F P
0 g
s
.30787 .78543 m .31584 .75017 L .28699 .74875 L p .707 .577 .707 r
F P
0 g
s
.37516 .80284 m .3793 .30141 L .36152 .29002 L p .707 .577 .707 r
F P
0 g
s
.3793 .30141 m .37516 .80284 L .40489 .81228 L p .707 .577 .707 r
F P
0 g
s
.33228 .63324 m .34013 .68907 L .35645 .68099 L p .707 .577 .707 r
F P
0 g
s
.35645 .68099 m .3486 .62516 L .33228 .63324 L p .707 .577 .707 r
F P
0 g
s
.25632 .81178 m .25422 .79315 L .22325 .79486 L p .707 .577 .707 r
F P
0 g
s
.25422 .79315 m .25632 .81178 L .28797 .80775 L p .707 .577 .707 r
F P
0 g
s
.28797 .80775 m .28587 .78913 L .25422 .79315 L p .707 .577 .707 r
F P
0 g
s
.1689 .65266 m .17675 .70848 L .19752 .71089 L p .707 .577 .707 r
F P
0 g
s
.28587 .78913 m .28797 .80775 L .31721 .80179 L p .707 .577 .707 r
F P
0 g
s
.19866 .72377 m .1907 .75904 L .21742 .77014 L p .707 .577 .707 r
F P
0 g
s
.1907 .75904 m .19866 .72377 L .17827 .71127 L p .707 .577 .707 r
F P
0 g
s
.33159 .78286 m .33955 .7476 L .31584 .75017 L p .707 .577 .707 r
F P
0 g
s
.22325 .79486 m .22535 .81348 L .25632 .81178 L p .707 .577 .707 r
F P
0 g
s
.66286 .64074 m .6707 .69656 L .64356 .69666 L p .707 .577 .707 r
F P
0 g
s
.64356 .69666 m .63571 .64083 L .66286 .64074 L p .707 .577 .707 r
F P
0 g
s
.69139 .74448 m .68343 .77974 L .66304 .76724 L p .707 .577 .707 r
F P
0 g
s
.66304 .76724 m .671 .73198 L .69139 .74448 L p .707 .577 .707 r
F P
0 g
s
.22535 .81348 m .22325 .79486 L .196 .79407 L p .707 .577 .707 r
F P
0 g
s
.196 .79407 m .1981 .81269 L .22535 .81348 L p .707 .577 .707 r
F P
0 g
s
.17675 .70848 m .1689 .65266 L .15653 .64799 L p .707 .577 .707 r
F P
0 g
s
.17827 .71127 m .17031 .74654 L .1907 .75904 L p .707 .577 .707 r
F P
0 g
s
.69028 .78435 m .69238 .80298 L .67151 .79977 L p .707 .577 .707 r
F P
0 g
s
.67151 .79977 m .66941 .78115 L .69028 .78435 L p .707 .577 .707 r
F P
0 g
s
.671 .73198 m .66304 .76724 L .63632 .75615 L p .707 .577 .707 r
F P
0 g
s
.63632 .75615 m .64428 .72088 L .671 .73198 L p .707 .577 .707 r
F P
0 g
s
.63528 .29705 m .63115 .79847 L .64115 .78661 L p .707 .577 .707 r
F P
0 g
s
.64115 .78661 m .64528 .28518 L .63528 .29705 L p .707 .577 .707 r
F P
0 g
s
.3486 .62516 m .35645 .68099 L .36358 .67334 L p .707 .577 .707 r
F P
0 g
s
.36358 .67334 m .35573 .61751 L .3486 .62516 L p .707 .577 .707 r
F P
0 g
s
.1981 .81269 m .196 .79407 L .17512 .79086 L p .707 .577 .707 r
F P
0 g
s
.15653 .64799 m .16438 .70381 L .16524 .70414 L p .707 .577 .707 r
F P
0 g
s
.17087 .69088 m .15653 .64799 L .16524 .70414 L .707 .577 .707 r
F
.16438 .70381 m .15653 .64799 L .15378 .64151 L p F P
0 g
s
.16438 .70381 m .16108 .6844 L .16151 .69646 L .707 .577 .707 r
F
.16034 .7157 m .16422 .70438 L .16229 .69875 L F
.16254 .69948 m .16438 .70381 L p .16151 .69646 L F P
0 g
s
.15569 .72223 m .15824 .73386 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16365 .68697 m .16151 .69646 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .15569 .72223 L p .15956 .72247 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16151 .69646 L p .16108 .6844 L .707 .577 .707 r
F P
0 g
s
.15378 .64151 m .16092 .63386 L p .16161 .69515 L .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .16365 .68697 L p .16229 .69875 L .707 .577 .707 r
F P
0 g
s
.16151 .69646 m .16365 .68697 L p .1628 .69488 L .707 .577 .707 r
F P
0 g
s
.16162 .6968 m .16163 .69733 L .16254 .69948 L p .707 .577 .707 r
F P
0 g
s
.16163 .69733 m .16151 .69646 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16422 .70438 m .16621 .69859 L .16229 .69875 L .707 .577 .707 r
F
.16876 .68968 m .16163 .69733 L p .16162 .69632 L F P
0 g
s
.16365 .68697 m .17085 .67754 L p .1665 .69035 L .707 .577 .707 r
F P
0 g
s
.1628 .69488 m .16365 .68697 L .1665 .69035 L .707 .577 .707 r
F
.16851 .68789 m .16876 .68968 L p .16162 .69632 L F P
0 g
s
.15824 .73386 m .16463 .70558 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16463 .70558 m .16621 .69859 L p .16034 .7157 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .15569 .72223 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .16851 .68789 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .16289 .71281 L p .15644 .72001 L .707 .577 .707 r
F P
0 g
s
.17085 .67754 m .1871 .67123 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16876 .68968 m .16851 .68789 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.16524 .70414 m .17675 .70848 L p .17087 .69088 L .707 .577 .707 r
F P
0 g
s
.17031 .74654 m .17827 .71127 L .16621 .69859 L p .707 .577 .707 r
F P
0 g
s
.16621 .69859 m .15824 .73386 L .17031 .74654 L p .707 .577 .707 r
F P
0 g
s
.16851 .68789 m .17085 .67754 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .16876 .68968 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .18496 .68073 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .18496 .68073 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .18508 .6816 L p .16903 .68767 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .16289 .71281 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17914 .7065 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16289 .71281 m .16851 .68789 L p .18042 .6827 L .707 .577 .707 r
F P
0 g
s
.16903 .68767 m .16851 .68789 L .16927 .68589 L .707 .577 .707 r
F
.16092 .63386 m .17723 .62578 L p .16927 .68589 L F P
0 g
s
.16851 .68789 m .16092 .63386 L p .16927 .68589 L .707 .577 .707 r
F P
0 g
s
.16092 .63386 m .16851 .68789 L p .16162 .69632 L .707 .577 .707 r
F P
0 g
s
.16178 .70426 m .1628 .69488 L .1665 .69035 L .707 .577 .707 r
F
.16151 .69646 m .1628 .69488 L .16178 .70426 L F
.16162 .69632 m .16151 .69646 L .16161 .69515 L F
.16151 .69646 m .15378 .64151 L p .16161 .69515 L F P
0 g
s
.15569 .72223 m .16151 .69646 L p .16178 .70426 L .707 .577 .707 r
F P
0 g
s
.34784 .77656 m .3558 .74129 L .33955 .7476 L p .707 .577 .707 r
F P
0 g
s
.17512 .79086 m .17723 .80949 L .1981 .81269 L p .707 .577 .707 r
F P
0 g
s
.35504 .76713 m .363 .73187 L .3558 .74129 L p .707 .577 .707 r
F P
0 g
s
.35573 .61751 m .36358 .67334 L .36083 .66686 L p .707 .577 .707 r
F P
0 g
s
.36083 .66686 m .35298 .61103 L .35573 .61751 L p .707 .577 .707 r
F P
0 g
s
.3554 .76792 m .3575 .78655 L .36462 .77876 L p .707 .577 .707 r
F P
0 g
s
.36462 .77876 m .36462 .77875 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .77875 m .3554 .76792 L .36462 .77876 L .707 .577 .707 r
F
.36152 .29002 m .35743 .27779 L p .35741 .51257 L F P
0 g
s
.36252 .76013 m .3554 .76792 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36462 .77875 m .36461 .7787 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.36461 .7787 m .36252 .76013 L p .36461 .77875 L .707 .577 .707 r
F P
0 g
s
.363 .73187 m .35504 .76713 L .35248 .75551 L p .707 .577 .707 r
F P
0 g
s
.35248 .75551 m .35747 .7334 L p .363 .73187 L .707 .577 .707 r
F P
0 g
s
.35747 .7334 m .36045 .72024 L .36128 .72403 L p .707 .577 .707 r
F P
0 g
s
.36128 .72403 m .363 .73187 L p .35747 .7334 L .707 .577 .707 r
F P
0 g
s
.36045 .72024 m .35248 .75551 L .34071 .74313 L p .707 .577 .707 r
F P
0 g
s
.34071 .74313 m .34042 .74282 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34075 .74245 m .36045 .72024 L .34071 .74313 L .707 .577 .707 r
F
.35915 .57699 m .36152 .29002 L p .35741 .51257 L F P
0 g
s
.34937 .76656 m .3482 .75624 L p .35971 .75324 L .707 .577 .707 r
F P
0 g
s
.35094 .7495 m .35971 .75324 L p .3482 .75624 L .707 .577 .707 r
F P
0 g
s
.35298 .61103 m .36083 .66686 L .34846 .66219 L p .707 .577 .707 r
F P
0 g
s
.36252 .76013 m .36462 .77875 L .36182 .77187 L p .707 .577 .707 r
F P
0 g
s
.36182 .77187 m .35971 .75324 L .36252 .76013 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .36045 .72024 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34042 .74282 m .34084 .74094 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.34084 .74094 m .34838 .70756 L p .34075 .74245 L .707 .577 .707 r
F P
0 g
s
.35971 .75324 m .36182 .77187 L .34937 .76656 L p .707 .577 .707 r
F P
0 g
s
.36152 .29002 m .35739 .79144 L .37516 .80284 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .35753 .7742 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35739 .79144 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35739 .79144 m .35915 .57699 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35753 .7742 m .3533 .77922 L p .36465 .40786 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .36483 .36022 L .36465 .40786 L .707 .577 .707 r
F
.36743 .26592 m .36693 .327 L p .36483 .36022 L F P
0 g
s
.36693 .327 m .3633 .76735 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .36743 .26592 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35743 .27779 m .35594 .45834 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.35594 .45834 m .3533 .77922 L p .35741 .51257 L .707 .577 .707 r
F P
0 g
s
.3533 .77922 m .35554 .5078 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.35554 .5078 m .35743 .27779 L p .36483 .36022 L .707 .577 .707 r
F P
0 g
s
.3482 .75624 m .34727 .74794 L .35094 .7495 L p .707 .577 .707 r
F P
0 g
s
.66941 .78115 m .67151 .79977 L .64425 .79898 L p .707 .577 .707 r
F P
0 g
s
.64425 .79898 m .64215 .78036 L .66941 .78115 L p .707 .577 .707 r
F P
0 g
s
.17723 .80949 m .17512 .79086 L .16268 .78556 L p .707 .577 .707 r
F P
0 g
s
.16268 .78556 m .16478 .80418 L .17723 .80949 L p .707 .577 .707 r
F P
0 g
s
.64528 .28518 m .64115 .78661 L .63706 .77438 L p .707 .577 .707 r
F P
0 g
s
.63706 .77438 m .64119 .27295 L .64528 .28518 L p .707 .577 .707 r
F P
0 g
s
.16478 .80418 m .16268 .78556 L .15987 .77867 L p .707 .577 .707 r
F P
0 g
s
.15987 .77867 m .16198 .79729 L .16478 .80418 L p .707 .577 .707 r
F P
0 g
s
.34846 .66219 m .34062 .60636 L .35298 .61103 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64119 .27295 m .63706 .77438 L .61928 .76298 L p .707 .577 .707 r
F P
0 g
s
.61928 .76298 m .62341 .26156 L .64119 .27295 L p .707 .577 .707 r
F P
0 g
s
.16198 .79729 m .15987 .77867 L .16699 .77088 L p .707 .577 .707 r
F P
0 g
s
.16699 .77088 m .16909 .7895 L .16198 .79729 L p .707 .577 .707 r
F P
0 g
s
.34062 .60636 m .34846 .66219 L .32769 .65978 L p .707 .577 .707 r
F P
0 g
s
.32769 .65978 m .31985 .60396 L .34062 .60636 L p .707 .577 .707 r
F P
0 g
s
.3633 .76735 m .36743 .26592 L .39054 .25558 L p .707 .577 .707 r
F P
0 g
s
.1871 .67123 m .21082 .66867 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.18508 .6816 m .18496 .68073 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .1871 .67123 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.21082 .66867 m .20924 .67565 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.20114 .61806 m .20899 .67389 L .193 .67905 L p .707 .577 .707 r
F P
0 g
s
.193 .67905 m .18508 .6816 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18532 .68065 m .20114 .61806 L .193 .67905 L .707 .577 .707 r
F
.20285 .70393 m .17914 .7065 L p .20406 .67674 L F P
0 g
s
.20924 .67565 m .20285 .70393 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17914 .7065 m .18496 .68073 L p .20406 .67674 L .707 .577 .707 r
F P
0 g
s
.17723 .62578 m .20114 .61806 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.18496 .68073 m .17723 .62578 L p .18532 .68065 L .707 .577 .707 r
F P
0 g
s
.31985 .60396 m .32769 .65978 L .30055 .65988 L p .707 .577 .707 r
F P
0 g
s
.30055 .65988 m .2927 .60405 L .31985 .60396 L p .707 .577 .707 r
F P
0 g
s
.34838 .70756 m .34042 .74282 L .32003 .73032 L p .707 .577 .707 r
F P
0 g
s
.32003 .73032 m .32799 .69506 L .34838 .70756 L p .707 .577 .707 r
F P
0 g
s
.16909 .7895 m .16699 .77088 L .18333 .76294 L p .707 .577 .707 r
F P
0 g
s
.18333 .76294 m .18543 .78156 L .16909 .7895 L p .707 .577 .707 r
F P
0 g
s
.62341 .26156 m .61928 .76298 L .58956 .75354 L p .707 .577 .707 r
F P
0 g
s
.58956 .75354 m .59369 .25211 L .62341 .26156 L p .707 .577 .707 r
F P
0 g
s
.20899 .67389 m .20114 .61806 L .2303 .61147 L p .707 .577 .707 r
F P
0 g
s
.34727 .74794 m .34937 .76656 L .3285 .76336 L p .707 .577 .707 r
F P
0 g
s
.3285 .76336 m .3264 .74474 L .34727 .74794 L p .707 .577 .707 r
F P
0 g
s
.2927 .60405 m .30055 .65988 L .2697 .66247 L p .707 .577 .707 r
F P
0 g
s
.2697 .66247 m .26185 .60664 L .2927 .60405 L p .707 .577 .707 r
F P
0 g
s
.39054 .25558 m .38641 .75701 L .3633 .76735 L p .707 .577 .707 r
F P
0 g
s
.38641 .75701 m .39054 .25558 L .4245 .24777 L p .707 .577 .707 r
F P
0 g
s
.20285 .70393 m .21082 .66867 L .23967 .67009 L p .707 .577 .707 r
F P
0 g
s
.32799 .69506 m .32003 .73032 L .29331 .71923 L p .707 .577 .707 r
F P
0 g
s
.29331 .71923 m .30127 .68396 L .32799 .69506 L p .707 .577 .707 r
F P
0 g
s
.23815 .6673 m .2303 .61147 L .26185 .60664 L p .707 .577 .707 r
F P
0 g
s
.2303 .61147 m .23815 .6673 L .20899 .67389 L p .707 .577 .707 r
F P
0 g
s
.73573 .65294 m .72788 .59712 L .69703 .59971 L p .707 .577 .707 r
F P
0 g
s
.72788 .59712 m .73573 .65294 L .76728 .64811 L p .707 .577 .707 r
F P
0 g
s
.76728 .64811 m .75943 .59229 L .72788 .59712 L p .707 .577 .707 r
F P
0 g
s
.26185 .60664 m .2697 .66247 L .23815 .6673 L p .707 .577 .707 r
F P
0 g
s
.75943 .59229 m .76728 .64811 L .79644 .64152 L p .707 .577 .707 r
F P
0 g
s
.79644 .64152 m .78859 .5857 L .75943 .59229 L p .707 .577 .707 r
F P
0 g
s
.18543 .78156 m .18333 .76294 L .20729 .75563 L p .707 .577 .707 r
F P
0 g
s
.20729 .75563 m .20939 .77426 L .18543 .78156 L p .707 .577 .707 r
F P
0 g
s
.70487 .65553 m .69703 .59971 L .66988 .5998 L p .707 .577 .707 r
F P
0 g
s
.69703 .59971 m .70487 .65553 L .73573 .65294 L p .707 .577 .707 r
F P
0 g
s
.23967 .67009 m .23171 .70535 L .20285 .70393 L p .707 .577 .707 r
F P
0 g
s
.23171 .70535 m .23967 .67009 L .27084 .67536 L p .707 .577 .707 r
F P
0 g
s
.30127 .68396 m .29331 .71923 L .26287 .71062 L p .707 .577 .707 r
F P
0 g
s
.26287 .71062 m .27084 .67536 L .30127 .68396 L p .707 .577 .707 r
F P
0 g
s
.3264 .74474 m .3285 .76336 L .30124 .76257 L p .707 .577 .707 r
F P
0 g
s
.30124 .76257 m .29914 .74395 L .3264 .74474 L p .707 .577 .707 r
F P
0 g
s
.78859 .5857 m .79644 .64152 L .82034 .63381 L p .707 .577 .707 r
F P
0 g
s
.82034 .63381 m .8125 .57798 L .78859 .5857 L p .707 .577 .707 r
F P
0 g
s
.59369 .25211 m .58956 .75354 L .55079 .74697 L p .707 .577 .707 r
F P
0 g
s
.55079 .74697 m .55493 .24555 L .59369 .25211 L p .707 .577 .707 r
F P
0 g
s
.27084 .67536 m .26287 .71062 L .23171 .70535 L p .707 .577 .707 r
F P
0 g
s
.66988 .5998 m .67773 .65563 L .70487 .65553 L p .707 .577 .707 r
F P
0 g
s
.72806 .72362 m .73603 .68836 L .70559 .67975 L p .707 .577 .707 r
F P
0 g
s
.73603 .68836 m .72806 .72362 L .75923 .72889 L p .707 .577 .707 r
F P
0 g
s
.75923 .72889 m .7672 .69363 L .73603 .68836 L p .707 .577 .707 r
F P
0 g
s
.20939 .77426 m .20729 .75563 L .23652 .74967 L p .707 .577 .707 r
F P
0 g
s
.67773 .65563 m .66988 .5998 L .64911 .5974 L p .707 .577 .707 r
F P
0 g
s
.42036 .7492 m .4245 .24777 L .46598 .24326 L p .707 .577 .707 r
F P
0 g
s
.4245 .24777 m .42036 .7492 L .38641 .75701 L p .707 .577 .707 r
F P
0 g
s
.69763 .71502 m .70559 .67975 L .67887 .66866 L p .707 .577 .707 r
F P
0 g
s
.70559 .67975 m .69763 .71502 L .72806 .72362 L p .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .79532 .72754 L .77506 .73167 L p .707 .577 .707 r
F P
0 g
s
.77506 .73167 m .76608 .7335 L p .77187 .73584 L .707 .577 .707 r
F P
0 g
s
.79742 .74617 m .77506 .73167 L .77187 .73584 L .707 .577 .707 r
F
.79532 .72754 m .79742 .74617 L .82138 .73886 L p F P
0 g
s
.82138 .73886 m .81928 .72024 L .80377 .72497 L p .707 .577 .707 r
F P
0 g
s
.80377 .72497 m .79532 .72754 L p .80071 .72988 L .707 .577 .707 r
F P
0 g
s
.82138 .73886 m .80377 .72497 L .80071 .72988 L .707 .577 .707 r
F
.81928 .72024 m .82138 .73886 L .83772 .73092 L p F P
0 g
s
.83772 .73092 m .83562 .7123 L .82613 .71691 L p .707 .577 .707 r
F P
0 g
s
.82613 .71691 m .81928 .72024 L p .82392 .72293 L .707 .577 .707 r
F P
0 g
s
.83772 .73092 m .82613 .71691 L .82392 .72293 L .707 .577 .707 r
F
.82805 .72144 m .83525 .71201 L p .8359 .69031 L F P
0 g
s
.83602 .68617 m .83378 .69607 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.83378 .69607 m .82805 .72144 L p .8359 .69031 L .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .82805 .72144 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81977 .69248 m .81735 .70317 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.81735 .70317 m .8118 .72775 L p .8211 .69715 L .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .8118 .72775 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79605 .69505 m .79312 .70804 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.79312 .70804 m .78809 .73031 L p .79876 .70066 L .707 .577 .707 r
F P
0 g
s
.7672 .69363 m .75923 .72889 L .78809 .73031 L p .707 .577 .707 r
F P
0 g
s
.78809 .73031 m .79605 .69505 L .7672 .69363 L p .707 .577 .707 r
F P
0 g
s
.23652 .74967 m .23862 .7683 L .20939 .77426 L p .707 .577 .707 r
F P
0 g
s
.29914 .74395 m .30124 .76257 L .27028 .76427 L p .707 .577 .707 r
F P
0 g
s
.27028 .76427 m .26817 .74565 L .29914 .74395 L p .707 .577 .707 r
F P
0 g
s
.8125 .57798 m .82034 .63381 L .83666 .62573 L p .707 .577 .707 r
F P
0 g
s
.83666 .62573 m .82881 .5699 L .8125 .57798 L p .707 .577 .707 r
F P
0 g
s
.23862 .7683 m .23652 .74967 L .26817 .74565 L p .707 .577 .707 r
F P
0 g
s
.73653 .75615 m .73443 .73753 L .70346 .73923 L p .707 .577 .707 r
F P
0 g
s
.73443 .73753 m .73653 .75615 L .76819 .75212 L p .707 .577 .707 r
F P
0 g
s
.76819 .75212 m .76608 .7335 L .73443 .73753 L p .707 .577 .707 r
F P
0 g
s
.26817 .74565 m .27028 .76427 L .23862 .7683 L p .707 .577 .707 r
F P
0 g
s
.64911 .5974 m .65696 .65322 L .67773 .65563 L p .707 .577 .707 r
F P
0 g
s
.55493 .24555 m .55079 .74697 L .50679 .74392 L p .707 .577 .707 r
F P
0 g
s
.50679 .74392 m .51092 .2425 L .55493 .24555 L p .707 .577 .707 r
F P
0 g
s
.76608 .7335 m .76819 .75212 L .79742 .74617 L p .707 .577 .707 r
F P
0 g
s
.67887 .66866 m .67091 .70392 L .69763 .71502 L p .707 .577 .707 r
F P
0 g
s
.67091 .70392 m .67887 .66866 L .65849 .65615 L p .707 .577 .707 r
F P
0 g
s
.8118 .72775 m .81977 .69248 L .79605 .69505 L p .707 .577 .707 r
F P
0 g
s
.70346 .73923 m .70556 .75785 L .73653 .75615 L p .707 .577 .707 r
F P
0 g
s
.46184 .74469 m .46598 .24326 L .51092 .2425 L p .707 .577 .707 r
F P
0 g
s
.46598 .24326 m .46184 .74469 L .42036 .7492 L p .707 .577 .707 r
F P
0 g
s
.70556 .75785 m .70346 .73923 L .67621 .73844 L p .707 .577 .707 r
F P
0 g
s
.51092 .2425 m .50679 .74392 L .46184 .74469 L p .707 .577 .707 r
F P
0 g
s
.67621 .73844 m .67831 .75706 L .70556 .75785 L p .707 .577 .707 r
F P
0 g
s
.65696 .65322 m .64911 .5974 L .63675 .59273 L p .707 .577 .707 r
F P
0 g
s
.65849 .65615 m .65052 .69142 L .67091 .70392 L p .707 .577 .707 r
F P
0 g
s
.82881 .5699 m .83666 .62573 L .8438 .61808 L p .707 .577 .707 r
F P
0 g
s
.8438 .61808 m .83595 .56225 L .82881 .5699 L p .707 .577 .707 r
F P
0 g
s
.67831 .75706 m .67621 .73844 L .65534 .73524 L p .707 .577 .707 r
F P
0 g
s
.63675 .59273 m .64459 .64855 L .6455 .64889 L p .707 .577 .707 r
F P
0 g
s
.6511 .63568 m .63675 .59273 L .6455 .64889 L .707 .577 .707 r
F
.64459 .64855 m .63675 .59273 L .634 .58625 L p F P
0 g
s
.64459 .64855 m .6413 .62921 L .64173 .64129 L .707 .577 .707 r
F
.64055 .66054 m .64445 .64922 L .64251 .64357 L F
.64266 .64401 m .64459 .64855 L p .64173 .64129 L F P
0 g
s
.6359 .66711 m .63846 .67874 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64386 .63185 m .64173 .64129 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .6359 .66711 L p .63979 .66715 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64173 .64129 L p .6413 .62921 L .707 .577 .707 r
F P
0 g
s
.634 .58625 m .64113 .5786 L p .64182 .6401 L .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .64386 .63185 L p .64251 .64357 L .707 .577 .707 r
F P
0 g
s
.64173 .64129 m .64386 .63185 L p .64302 .63971 L .707 .577 .707 r
F P
0 g
s
.64184 .64159 m .64184 .64207 L .64266 .64401 L p .707 .577 .707 r
F P
0 g
s
.64184 .64207 m .64173 .64129 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64445 .64922 m .64642 .64347 L .64251 .64357 L .707 .577 .707 r
F
.64898 .63442 m .64184 .64207 L p .64183 .64116 L F P
0 g
s
.64386 .63185 m .65106 .62242 L p .64674 .63516 L .707 .577 .707 r
F P
0 g
s
.64302 .63971 m .64386 .63185 L .64674 .63516 L .707 .577 .707 r
F
.64874 .63272 m .64898 .63442 L p .64183 .64116 L F P
0 g
s
.63846 .67874 m .64486 .65041 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.64486 .65041 m .64642 .64347 L p .64055 .66054 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .6359 .66711 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .64874 .63272 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .6431 .65769 L p .63673 .66467 L .707 .577 .707 r
F P
0 g
s
.65106 .62242 m .66732 .61612 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64898 .63442 m .64874 .63272 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.6455 .64889 m .65696 .65322 L p .6511 .63568 L .707 .577 .707 r
F P
0 g
s
.65052 .69142 m .65849 .65615 L .64642 .64347 L p .707 .577 .707 r
F P
0 g
s
.64642 .64347 m .63846 .67874 L .65052 .69142 L p .707 .577 .707 r
F P
0 g
s
.64874 .63272 m .65106 .62242 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .64898 .63442 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .66518 .62555 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .66518 .62555 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .6653 .62634 L p .64923 .63251 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .6431 .65769 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65935 .65138 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.6431 .65769 m .64874 .63272 L p .66067 .62752 L .707 .577 .707 r
F P
0 g
s
.64923 .63251 m .64874 .63272 L .64945 .63082 L .707 .577 .707 r
F
.64113 .5786 m .65745 .57052 L p .64945 .63082 L F P
0 g
s
.64874 .63272 m .64113 .5786 L p .64945 .63082 L .707 .577 .707 r
F P
0 g
s
.64113 .5786 m .64874 .63272 L p .64183 .64116 L .707 .577 .707 r
F P
0 g
s
.64201 .64911 m .64302 .63971 L .64674 .63516 L .707 .577 .707 r
F
.64173 .64129 m .64302 .63971 L .64201 .64911 L F
.64183 .64116 m .64173 .64129 L .64182 .6401 L F
.64173 .64129 m .634 .58625 L p .64182 .6401 L F P
0 g
s
.6359 .66711 m .64173 .64129 L p .64201 .64911 L .707 .577 .707 r
F P
0 g
s
.82805 .72144 m .83602 .68617 L .81977 .69248 L p .707 .577 .707 r
F P
0 g
s
.65534 .73524 m .65744 .75386 L .67831 .75706 L p .707 .577 .707 r
F P
0 g
s
.65744 .75386 m .65534 .73524 L .64289 .72993 L p .707 .577 .707 r
F P
0 g
s
.83525 .71201 m .84322 .67675 L .83602 .68617 L p .707 .577 .707 r
F P
0 g
s
.64289 .72993 m .64499 .74856 L .65744 .75386 L p .707 .577 .707 r
F P
0 g
s
.83595 .56225 m .8438 .61808 L .84104 .6116 L p .707 .577 .707 r
F P
0 g
s
.84104 .6116 m .8332 .55577 L .83595 .56225 L p .707 .577 .707 r
F P
0 g
s
.83562 .7123 m .83772 .73092 L .84483 .72313 L p .707 .577 .707 r
F P
0 g
s
.84483 .72313 m .84273 .7045 L .83562 .7123 L p .707 .577 .707 r
F P
0 g
s
.64499 .74856 m .64289 .72993 L .64009 .72304 L p .707 .577 .707 r
F P
0 g
s
.64009 .72304 m .64219 .74167 L .64499 .74856 L p .707 .577 .707 r
F P
0 g
s
.84322 .67675 m .83525 .71201 L .8327 .70039 L p .707 .577 .707 r
F P
0 g
s
.8327 .70039 m .83773 .67812 L p .84322 .67675 L .707 .577 .707 r
F P
0 g
s
.84066 .66512 m .8327 .70039 L .82063 .68771 L p .707 .577 .707 r
F P
0 g
s
.82958 .71094 m .82846 .70095 L p .83993 .69762 L .707 .577 .707 r
F P
0 g
s
.82846 .70095 m .82748 .69231 L .8313 .69394 L p .707 .577 .707 r
F P
0 g
s
.8313 .69394 m .83993 .69762 L p .82846 .70095 L .707 .577 .707 r
F P
0 g
s
.83773 .67812 m .84066 .66512 L .84148 .66886 L p .707 .577 .707 r
F P
0 g
s
.84148 .66886 m .84322 .67675 L p .83773 .67812 L .707 .577 .707 r
F P
0 g
s
.8332 .55577 m .84104 .6116 L .82868 .60693 L p .707 .577 .707 r
F P
0 g
s
.82868 .60693 m .82083 .5511 L .8332 .55577 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84273 .7045 m .84483 .72313 L .84203 .71624 L p .707 .577 .707 r
F P
0 g
s
.84203 .71624 m .83993 .69762 L .84273 .7045 L p .707 .577 .707 r
F P
0 g
s
.39272 .61616 m .38487 .56034 L .35402 .56293 L p .707 .577 .707 r
F P
0 g
s
.38487 .56034 m .39272 .61616 L .42427 .61134 L p .707 .577 .707 r
F P
0 g
s
.42427 .61134 m .41642 .55551 L .38487 .56034 L p .707 .577 .707 r
F P
0 g
s
.41642 .55551 m .42427 .61134 L .45343 .60474 L p .707 .577 .707 r
F P
0 g
s
.45343 .60474 m .44558 .54892 L .41642 .55551 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36186 .61875 m .35402 .56293 L .32687 .56302 L p .707 .577 .707 r
F P
0 g
s
.35402 .56293 m .36186 .61875 L .39272 .61616 L p .707 .577 .707 r
F P
0 g
s
.64219 .74167 m .64009 .72304 L .6472 .71525 L p .707 .577 .707 r
F P
0 g
s
.44558 .54892 m .45343 .60474 L .47733 .59703 L p .707 .577 .707 r
F P
0 g
s
.47733 .59703 m .46949 .5412 L .44558 .54892 L p .707 .577 .707 r
F P
0 g
s
.82063 .68771 m .8286 .65244 L .84066 .66512 L p .707 .577 .707 r
F P
0 g
s
.6472 .71525 m .64931 .73388 L .64219 .74167 L p .707 .577 .707 r
F P
0 g
s
.82083 .5511 m .82868 .60693 L .80791 .60452 L p .707 .577 .707 r
F P
0 g
s
.80791 .60452 m .80006 .5487 L .82083 .5511 L p .707 .577 .707 r
F P
0 g
s
.32687 .56302 m .33472 .61885 L .36186 .61875 L p .707 .577 .707 r
F P
0 g
s
.38505 .6867 m .39302 .65144 L .36258 .64283 L p .707 .577 .707 r
F P
0 g
s
.39302 .65144 m .38505 .6867 L .41622 .69197 L p .707 .577 .707 r
F P
0 g
s
.41622 .69197 m .42419 .65671 L .39302 .65144 L p .707 .577 .707 r
F P
0 g
s
.33472 .61885 m .32687 .56302 L .3061 .56062 L p .707 .577 .707 r
F P
0 g
s
.83993 .69762 m .84203 .71624 L .82958 .71094 L p .707 .577 .707 r
F P
0 g
s
.35462 .6781 m .36258 .64283 L .33586 .63174 L p .707 .577 .707 r
F P
0 g
s
.36258 .64283 m .35462 .6781 L .38505 .6867 L p .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .45231 .69113 L .4317 .69533 L p .707 .577 .707 r
F P
0 g
s
.4317 .69533 m .42307 .69709 L p .42863 .69934 L .707 .577 .707 r
F P
0 g
s
.45441 .70975 m .4317 .69533 L .42863 .69934 L .707 .577 .707 r
F
.45231 .69113 m .45441 .70975 L .47837 .70245 L p F P
0 g
s
.47837 .70245 m .47627 .68382 L .46045 .68865 L p .707 .577 .707 r
F P
0 g
s
.46045 .68865 m .45231 .69113 L p .4575 .69338 L .707 .577 .707 r
F P
0 g
s
.47837 .70245 m .46045 .68865 L .4575 .69338 L .707 .577 .707 r
F
.47627 .68382 m .47837 .70245 L .49471 .69451 L p F P
0 g
s
.49471 .69451 m .49261 .67589 L .48293 .68059 L p .707 .577 .707 r
F P
0 g
s
.48293 .68059 m .47627 .68382 L p .48078 .68644 L .707 .577 .707 r
F P
0 g
s
.49471 .69451 m .48293 .68059 L .48078 .68644 L .707 .577 .707 r
F
.48504 .68452 m .49224 .67509 L p .49288 .65346 L F P
0 g
s
.49301 .64925 m .49074 .65932 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.49074 .65932 m .48504 .68452 L p .49288 .65346 L .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .48504 .68452 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.47676 .65556 m .4743 .66642 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.4743 .66642 m .46879 .69083 L p .47811 .6603 L .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .46879 .69083 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45304 .65813 m .45007 .67129 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.45007 .67129 m .44508 .69339 L p .45578 .66381 L .707 .577 .707 r
F P
0 g
s
.42419 .65671 m .41622 .69197 L .44508 .69339 L p .707 .577 .707 r
F P
0 g
s
.44508 .69339 m .45304 .65813 L .42419 .65671 L p .707 .577 .707 r
F P
0 g
s
.46949 .5412 m .47733 .59703 L .49365 .58895 L p .707 .577 .707 r
F P
0 g
s
.49365 .58895 m .4858 .53313 L .46949 .5412 L p .707 .577 .707 r
F P
0 g
s
.66732 .61612 m .69103 .61355 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.6653 .62634 m .66518 .62555 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .66732 .61612 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.69103 .61355 m .68946 .62048 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.68136 .5628 m .6892 .61863 L .67243 .62404 L p .707 .577 .707 r
F P
0 g
s
.67243 .62404 m .6653 .62634 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66551 .62549 m .68136 .5628 L .67243 .62404 L .707 .577 .707 r
F
.68307 .64881 m .65935 .65138 L p .68432 .62156 L F P
0 g
s
.68946 .62048 m .68307 .64881 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65935 .65138 m .66518 .62555 L p .68432 .62156 L .707 .577 .707 r
F P
0 g
s
.65745 .57052 m .68136 .5628 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.66518 .62555 m .65745 .57052 L p .66551 .62549 L .707 .577 .707 r
F P
0 g
s
.39352 .71974 m .39142 .70111 L .36045 .70282 L p .707 .577 .707 r
F P
0 g
s
.39142 .70111 m .39352 .71974 L .42518 .71571 L p .707 .577 .707 r
F P
0 g
s
.42518 .71571 m .42307 .69709 L .39142 .70111 L p .707 .577 .707 r
F P
0 g
s
.3061 .56062 m .31395 .61644 L .33472 .61885 L p .707 .577 .707 r
F P
0 g
s
.42307 .69709 m .42518 .71571 L .45441 .70975 L p .707 .577 .707 r
F P
0 g
s
.33586 .63174 m .3279 .667 L .35462 .6781 L p .707 .577 .707 r
F P
0 g
s
.3279 .667 m .33586 .63174 L .31547 .61923 L p .707 .577 .707 r
F P
0 g
s
.46879 .69083 m .47676 .65556 L .45304 .65813 L p .707 .577 .707 r
F P
0 g
s
.36045 .70282 m .36255 .72144 L .39352 .71974 L p .707 .577 .707 r
F P
0 g
s
.80006 .5487 m .80791 .60452 L .78077 .60462 L p .707 .577 .707 r
F P
0 g
s
.78077 .60462 m .77292 .5488 L .80006 .5487 L p .707 .577 .707 r
F P
0 g
s
.8286 .65244 m .82063 .68771 L .80024 .6752 L p .707 .577 .707 r
F P
0 g
s
.80024 .6752 m .80821 .63994 L .8286 .65244 L p .707 .577 .707 r
F P
0 g
s
.64931 .73388 m .6472 .71525 L .66354 .70731 L p .707 .577 .707 r
F P
0 g
s
.36255 .72144 m .36045 .70282 L .3332 .70203 L p .707 .577 .707 r
F P
0 g
s
.66354 .70731 m .66564 .72594 L .64931 .73388 L p .707 .577 .707 r
F P
0 g
s
.3332 .70203 m .3353 .72065 L .36255 .72144 L p .707 .577 .707 r
F P
0 g
s
.31395 .61644 m .3061 .56062 L .29374 .55595 L p .707 .577 .707 r
F P
0 g
s
.6892 .61863 m .68136 .5628 L .71051 .55621 L p .707 .577 .707 r
F P
0 g
s
.31547 .61923 m .30751 .6545 L .3279 .667 L p .707 .577 .707 r
F P
0 g
s
.82748 .69231 m .82958 .71094 L .80871 .70773 L p .707 .577 .707 r
F P
0 g
s
.80871 .70773 m .80661 .68911 L .82748 .69231 L p .707 .577 .707 r
F P
0 g
s
.77292 .5488 m .78077 .60462 L .74991 .60721 L p .707 .577 .707 r
F P
0 g
s
.74991 .60721 m .74206 .55138 L .77292 .5488 L p .707 .577 .707 r
F P
0 g
s
.4858 .53313 m .49365 .58895 L .50079 .5813 L p .707 .577 .707 r
F P
0 g
s
.50079 .5813 m .49294 .52547 L .4858 .53313 L p .707 .577 .707 r
F P
0 g
s
.3353 .72065 m .3332 .70203 L .31233 .69882 L p .707 .577 .707 r
F P
0 g
s
.29374 .55595 m .30158 .61177 L .30244 .6121 L p .707 .577 .707 r
F P
0 g
s
.30807 .59884 m .29374 .55595 L .30244 .6121 L .707 .577 .707 r
F
.30158 .61177 m .29374 .55595 L .29099 .54947 L p F P
0 g
s
.30158 .61177 m .29828 .59237 L .29871 .60442 L .707 .577 .707 r
F
.29754 .62366 m .30142 .61234 L .29949 .60671 L F
.29974 .60744 m .30158 .61177 L p .29871 .60442 L F P
0 g
s
.29289 .63019 m .29545 .64182 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.30085 .59493 m .29871 .60442 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .29289 .63019 L p .29676 .63043 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29871 .60442 L p .29828 .59237 L .707 .577 .707 r
F P
0 g
s
.29099 .54947 m .29812 .54182 L p .29881 .60311 L .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .30085 .59493 L p .29949 .60671 L .707 .577 .707 r
F P
0 g
s
.29871 .60442 m .30085 .59493 L p .3 .60284 L .707 .577 .707 r
F P
0 g
s
.29883 .60476 m .29883 .60529 L .29974 .60744 L p .707 .577 .707 r
F P
0 g
s
.29883 .60529 m .29871 .60442 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.30142 .61234 m .30341 .60655 L .29949 .60671 L .707 .577 .707 r
F
.30597 .59764 m .29883 .60529 L p .29882 .60428 L F P
0 g
s
.30085 .59493 m .30805 .5855 L p .30371 .59831 L .707 .577 .707 r
F P
0 g
s
.3 .60284 m .30085 .59493 L .30371 .59831 L .707 .577 .707 r
F
.30572 .59586 m .30597 .59764 L p .29882 .60428 L F P
0 g
s
.29545 .64182 m .30183 .61354 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30183 .61354 m .30341 .60655 L p .29754 .62366 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .29289 .63019 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .30572 .59586 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30009 .62077 L p .29364 .62798 L .707 .577 .707 r
F P
0 g
s
.30805 .5855 m .32431 .57919 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30597 .59764 m .30572 .59586 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.30244 .6121 m .31395 .61644 L p .30807 .59884 L .707 .577 .707 r
F P
0 g
s
.30751 .6545 m .31547 .61923 L .30341 .60655 L p .707 .577 .707 r
F P
0 g
s
.30341 .60655 m .29545 .64182 L .30751 .6545 L p .707 .577 .707 r
F P
0 g
s
.30572 .59586 m .30805 .5855 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .30597 .59764 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .32216 .58869 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .32216 .58869 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32229 .58956 L p .30623 .59563 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .30009 .62077 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31634 .61446 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30009 .62077 m .30572 .59586 L p .31762 .59067 L .707 .577 .707 r
F P
0 g
s
.30623 .59563 m .30572 .59586 L .30647 .59385 L .707 .577 .707 r
F
.29812 .54182 m .31444 .53374 L p .30647 .59385 L F P
0 g
s
.30572 .59586 m .29812 .54182 L p .30647 .59385 L .707 .577 .707 r
F P
0 g
s
.29812 .54182 m .30572 .59586 L p .29882 .60428 L .707 .577 .707 r
F P
0 g
s
.29899 .61222 m .3 .60284 L .30371 .59831 L .707 .577 .707 r
F
.29871 .60442 m .3 .60284 L .29899 .61222 L F
.29882 .60428 m .29871 .60442 L .29881 .60311 L F
.29871 .60442 m .29099 .54947 L p .29881 .60311 L F P
0 g
s
.29289 .63019 m .29871 .60442 L p .29899 .61222 L .707 .577 .707 r
F P
0 g
s
.48504 .68452 m .49301 .64925 L .47676 .65556 L p .707 .577 .707 r
F P
0 g
s
.68307 .64881 m .69103 .61355 L .71988 .61497 L p .707 .577 .707 r
F P
0 g
s
.80821 .63994 m .80024 .6752 L .77352 .66411 L p .707 .577 .707 r
F P
0 g
s
.77352 .66411 m .78149 .62884 L .80821 .63994 L p .707 .577 .707 r
F P
0 g
s
.71836 .61204 m .71051 .55621 L .74206 .55138 L p .707 .577 .707 r
F P
0 g
s
.71051 .55621 m .71836 .61204 L .6892 .61863 L p .707 .577 .707 r
F P
0 g
s
.31233 .69882 m .31443 .71745 L .3353 .72065 L p .707 .577 .707 r
F P
0 g
s
.74206 .55138 m .74991 .60721 L .71836 .61204 L p .707 .577 .707 r
F P
0 g
s
.66564 .72594 m .66354 .70731 L .6875 .70001 L p .707 .577 .707 r
F P
0 g
s
.6875 .70001 m .6896 .71863 L .66564 .72594 L p .707 .577 .707 r
F P
0 g
s
.71988 .61497 m .71192 .65023 L .68307 .64881 L p .707 .577 .707 r
F P
0 g
s
.71192 .65023 m .71988 .61497 L .75105 .62024 L p .707 .577 .707 r
F P
0 g
s
.78149 .62884 m .77352 .66411 L .74309 .6555 L p .707 .577 .707 r
F P
0 g
s
.74309 .6555 m .75105 .62024 L .78149 .62884 L p .707 .577 .707 r
F P
0 g
s
.80661 .68911 m .80871 .70773 L .78146 .70694 L p .707 .577 .707 r
F P
0 g
s
.78146 .70694 m .77936 .68832 L .80661 .68911 L p .707 .577 .707 r
F P
0 g
s
.75105 .62024 m .74309 .6555 L .71192 .65023 L p .707 .577 .707 r
F P
0 g
s
.31443 .71745 m .31233 .69882 L .29988 .69352 L p .707 .577 .707 r
F P
0 g
s
.49224 .67509 m .50021 .63983 L .49301 .64925 L p .707 .577 .707 r
F P
0 g
s
.6896 .71863 m .6875 .70001 L .71674 .69405 L p .707 .577 .707 r
F P
0 g
s
.29988 .69352 m .30198 .71214 L .31443 .71745 L p .707 .577 .707 r
F P
0 g
s
.49294 .52547 m .50079 .5813 L .49803 .57482 L p .707 .577 .707 r
F P
0 g
s
.49803 .57482 m .49019 .51899 L .49294 .52547 L p .707 .577 .707 r
F P
0 g
s
.71674 .69405 m .71884 .71267 L .6896 .71863 L p .707 .577 .707 r
F P
0 g
s
.77936 .68832 m .78146 .70694 L .75049 .70865 L p .707 .577 .707 r
F P
0 g
s
.75049 .70865 m .74839 .69002 L .77936 .68832 L p .707 .577 .707 r
F P
0 g
s
.49261 .67589 m .49471 .69451 L .50182 .68672 L p .707 .577 .707 r
F P
0 g
s
.50182 .68672 m .49972 .66809 L .49261 .67589 L p .707 .577 .707 r
F P
0 g
s
.71884 .71267 m .71674 .69405 L .74839 .69002 L p .707 .577 .707 r
F P
0 g
s
.74839 .69002 m .75049 .70865 L .71884 .71267 L p .707 .577 .707 r
F P
0 g
s
.30198 .71214 m .29988 .69352 L .29708 .68663 L p .707 .577 .707 r
F P
0 g
s
.50021 .63983 m .49224 .67509 L .48969 .66347 L p .707 .577 .707 r
F P
0 g
s
.48969 .66347 m .49468 .64136 L p .50021 .63983 L .707 .577 .707 r
F P
0 g
s
.49765 .6282 m .48969 .66347 L .47762 .65079 L p .707 .577 .707 r
F P
0 g
s
.48657 .67452 m .48541 .6642 L p .49692 .66121 L .707 .577 .707 r
F P
0 g
s
.48541 .6642 m .48447 .6559 L .48814 .65747 L p .707 .577 .707 r
F P
0 g
s
.48814 .65747 m .49692 .66121 L p .48541 .6642 L .707 .577 .707 r
F P
0 g
s
.49468 .64136 m .49765 .6282 L .49848 .63199 L p .707 .577 .707 r
F P
0 g
s
.49848 .63199 m .50021 .63983 L p .49468 .64136 L .707 .577 .707 r
F P
0 g
s
.29708 .68663 m .29918 .70526 L .30198 .71214 L p .707 .577 .707 r
F P
0 g
s
.49019 .51899 m .49803 .57482 L .48567 .57015 L p .707 .577 .707 r
F P
0 g
s
.48567 .57015 m .47782 .51432 L .49019 .51899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49972 .66809 m .50182 .68672 L .49902 .67983 L p .707 .577 .707 r
F P
0 g
s
.49902 .67983 m .49692 .66121 L .49972 .66809 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29918 .70526 m .29708 .68663 L .30419 .67884 L p .707 .577 .707 r
F P
0 g
s
.47762 .65079 m .48559 .61552 L .49765 .6282 L p .707 .577 .707 r
F P
0 g
s
.30419 .67884 m .30629 .69746 L .29918 .70526 L p .707 .577 .707 r
F P
0 g
s
.47782 .51432 m .48567 .57015 L .4649 .56774 L p .707 .577 .707 r
F P
0 g
s
.4649 .56774 m .45705 .51192 L .47782 .51432 L p .707 .577 .707 r
F P
0 g
s
.49692 .66121 m .49902 .67983 L .48657 .67452 L p .707 .577 .707 r
F P
0 g
s
.32431 .57919 m .34802 .57663 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.32229 .58956 m .32216 .58869 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .32431 .57919 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.34802 .57663 m .34644 .58362 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.33835 .52602 m .34619 .58185 L .3302 .58701 L p .707 .577 .707 r
F P
0 g
s
.3302 .58701 m .32229 .58956 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32253 .58861 m .33835 .52602 L .3302 .58701 L .707 .577 .707 r
F
.34005 .61189 m .31634 .61446 L p .34126 .5847 L F P
0 g
s
.34644 .58362 m .34005 .61189 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31634 .61446 m .32216 .58869 L p .34126 .5847 L .707 .577 .707 r
F P
0 g
s
.31444 .53374 m .33835 .52602 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.32216 .58869 m .31444 .53374 L p .32253 .58861 L .707 .577 .707 r
F P
0 g
s
.45705 .51192 m .4649 .56774 L .43776 .56784 L p .707 .577 .707 r
F P
0 g
s
.43776 .56784 m .42991 .51202 L .45705 .51192 L p .707 .577 .707 r
F P
0 g
s
.48559 .61552 m .47762 .65079 L .45723 .63828 L p .707 .577 .707 r
F P
0 g
s
.45723 .63828 m .4652 .60302 L .48559 .61552 L p .707 .577 .707 r
F P
0 g
s
.30629 .69746 m .30419 .67884 L .32053 .6709 L p .707 .577 .707 r
F P
0 g
s
.32053 .6709 m .32263 .68952 L .30629 .69746 L p .707 .577 .707 r
F P
0 g
s
.34619 .58185 m .33835 .52602 L .3675 .51943 L p .707 .577 .707 r
F P
0 g
s
.48447 .6559 m .48657 .67452 L .4657 .67132 L p .707 .577 .707 r
F P
0 g
s
.4657 .67132 m .4636 .6527 L .48447 .6559 L p .707 .577 .707 r
F P
0 g
s
.42991 .51202 m .43776 .56784 L .4069 .57043 L p .707 .577 .707 r
F P
0 g
s
.4069 .57043 m .39905 .5146 L .42991 .51202 L p .707 .577 .707 r
F P
0 g
s
.34005 .61189 m .34802 .57663 L .37687 .57805 L p .707 .577 .707 r
F P
0 g
s
.4652 .60302 m .45723 .63828 L .43051 .62719 L p .707 .577 .707 r
F P
0 g
s
.43051 .62719 m .43848 .59192 L .4652 .60302 L p .707 .577 .707 r
F P
0 g
s
.37535 .57526 m .3675 .51943 L .39905 .5146 L p .707 .577 .707 r
F P
0 g
s
.3675 .51943 m .37535 .57526 L .34619 .58185 L p .707 .577 .707 r
F P
0 g
s
.39905 .5146 m .4069 .57043 L .37535 .57526 L p .707 .577 .707 r
F P
0 g
s
.32263 .68952 m .32053 .6709 L .34449 .66359 L p .707 .577 .707 r
F P
0 g
s
.34449 .66359 m .34659 .68222 L .32263 .68952 L p .707 .577 .707 r
F P
0 g
s
.37687 .57805 m .36891 .61331 L .34005 .61189 L p .707 .577 .707 r
F P
0 g
s
.36891 .61331 m .37687 .57805 L .40804 .58332 L p .707 .577 .707 r
F P
0 g
s
.43848 .59192 m .43051 .62719 L .40008 .61858 L p .707 .577 .707 r
F P
0 g
s
.40008 .61858 m .40804 .58332 L .43848 .59192 L p .707 .577 .707 r
F P
0 g
s
.4636 .6527 m .4657 .67132 L .43845 .67053 L p .707 .577 .707 r
F P
0 g
s
.43845 .67053 m .43635 .65191 L .4636 .6527 L p .707 .577 .707 r
F P
0 g
s
.40804 .58332 m .40008 .61858 L .36891 .61331 L p .707 .577 .707 r
F P
0 g
s
.34659 .68222 m .34449 .66359 L .37373 .65764 L p .707 .577 .707 r
F P
0 g
s
.37373 .65764 m .37583 .67626 L .34659 .68222 L p .707 .577 .707 r
F P
0 g
s
.43635 .65191 m .43845 .67053 L .40748 .67223 L p .707 .577 .707 r
F P
0 g
s
.40748 .67223 m .40538 .65361 L .43635 .65191 L p .707 .577 .707 r
F P
0 g
s
.37583 .67626 m .37373 .65764 L .40538 .65361 L p .707 .577 .707 r
F P
0 g
s
.40538 .65361 m .40748 .67223 L .37583 .67626 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01EYF3P0035YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP0015YF2@0015YF00<005YF
FUH015YF00<005YFFUH01@001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P00IGoo001UOol00`00FUH000050004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001UOol006=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001UOol005moo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo100000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00FGoo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00E7oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP80
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00
Dgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2000IOolJ000cOol0059oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001Eoo`@0009JEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0035oo`00DWoo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80015oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000`Ool0059oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000=Ool400000eYF
001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009Ool40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00FUH0;goo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH?0003FUH01000
FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
1Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF2@001eYF00<005YFFUH015YF1P0000EJEP00001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001J
EP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP800004Ool000000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001COol00`00FUH00005FUH00`00FUIJEP04
FUH00`00FUIJEP0:0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH300000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000EJEP03001JEUYF009JEPD000IJEP04001JEUYF
FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Woo001COol01000FUIJEP0015YF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YF00000P001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo001COol01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01UYF0`000UYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002ioo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001EYF0`001eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP05001JEUYFFUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH01000FUIJEUYF1P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool004moo`H0
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF009JEPh000=JEP05001JEUYFFUH0000]Ool004Ioo`T000AJEP800003FUH005YF009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000MJEP03001JEUYF00=JEPH0009J
EP03001oogoo02]oo`00@7oo1P0015YF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEUYFFUH4000]Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP<000=JEQ@000AJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF009JEPP000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eo
o`00>7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001JEQ`000QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPD000AJEP03001JEUYF00@000EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00=7oo100000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF0000009JEP03001JEP0000EJEP03
001JEUYF00@000IJEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004
FUH01000FUIJEUYF10001eYF00<005YFFUH015YF1P0025YF00<005YFFUH015YF00<005YFFUH00UYF
0P00;Woo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20004FUH3
0005FUH00`00FUIJEP040006FUH00`00FUIJEP05FUH300000eYF001JEP06FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@0
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02eoo`00<7oo0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00P000eYF00<005YFFUH01000
1UYF10001EYF00<005YF00000P001UYF00<005YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH400000eYF001JEP06FUH01000
FUIJEP00<7oo000^Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH40002FUH40006FUH50004FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00000P001UYF0`00<Goo000]Ool00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP04FUH01@00FUH00000FUH010001EYF1P0015YF00<005YFFUH015YF0P0000=JEP00FUH01EYF00@0
05YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP8003=oo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00@005YFFUIJEPD000EJ
EPH000AJEP03001JEUYF00IJEP8000IJEP09001JEUYFFUH005YF001JEP0000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP@003Eoo`00:goo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01EYF0`0015YF00<005YF00000P001EYF00<005YFFUH025YF0P0015YF00T005YFFUIJ
EP00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`00
=Goo000[Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00001EYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEP00=7oo000[Ool01000FUIJEP0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00001UYF
00<005YFFUH01EYF00<005YFFUH00UYF0`002EYF00<005YFFUH02EYF00<005YF00000P0015YF0P00
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0eYF00@005YFFUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80039o
o`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP<000IJEP03001JEUYF00EJEP03001JEUYF00EJEQP00003FUH005YF00=JEP80009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEPD00003FUH0
05YF00IJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001oogoo02moo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00L000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH00000FUHB0004Ool40007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH2000`Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000=JEP03001JEUYF00EJEPP000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH30005FUH01000FUIJEP003Woo10000UYF
00<005YFFUH01UYF00<005YFFUH015YF0P00<7oo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90007FUH01P00FUH00000FUH0009JEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00P00
15YF00@005YFFUH0019oo`<000QJEP03001JEUYF00=JEP04001JEUYF000_Ool002aoo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP04001JEUYFFUH40000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00
0eYF00<005YFFUH00UYF00D005YFFUIJEP00009JEP03001oogoo00Qoo`<000Qoo`8000IJEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00X000QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPl000=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEUYFFUH30003FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0027oo1@002Goo0P00
0eYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;7oo00<005YF00001EYF00<005YFFUH00eYF
10001UYF00<005YFFUH010001EYF00<005YFFUH01EYF10001EYF00<005YFFUH01UYF00<005YFFUH0
0UYF2@001eYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP04001JEP000002FUH20008Ool5000;Ool2
00000eYF001JEP05FUH01000FUIJEUYF0P00;Goo000/Ool01000FUIJEP0015YF00@005YFFUIJEP80
0003FUH005YF00IJEP03001JEUYF00EJEP@00003FUH005YF00EJEP80009JEP03001JEUYF00AJEP03
001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH500000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00@0
05YFFUIJEP@000Qoo`D000eoo`8000IJEP06001JEUYF001JEP00;Goo000/Ool01000FUIJEP0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000`000eYF00<005YFFUH0
0UYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF10001Woo0`0047oo0P000eYF
00@005YFFUIJEP<002eoo`00;7oo00@005YFFUH0009JEP03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP@000AJEP03001JEUYF00=JEP@00004FUH00000FUH300000eYF
000000040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF0`0000=JEP00
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH010005goo0P0000=JEP00FUH00UYF00<005YF0000;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUH00004FUH00`00FUH000040002Ool01000FUIJEP0015YF1`000eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000=JEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50005OolA0003FUH2000^
Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYF0003FUH40005Ool01000FUIJEP001EYF3@0015YF00@005YFFUIJEPH000AJ
EP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPT000AJEP03001JEUYF00EJEP03001JEUYF
00@00003FUH0000002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00D005YFFUH005YF00800003FUH0000000Ioo`04001JEUYF0005
FUH00`00FUH000020005FUH00`00FUIJEP080005FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P0015YF00<005YFFUH01EYF
00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000;Woo000]
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH200000eYF000000020002FUH30004Ool01000FUIJEP001EYF00<005YFFUH015YF1@001eYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEPL0009JEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool002eoo`03001JEUYF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<00004FUH005YFFUHI0004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUH000020003FUH40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000]Ool20003FUHB0007FUH0
0`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH00002000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool2
00000eYF000000030003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0003FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP02FUHG0003FUH01@00FUIJEUYF0000;Goo000/
Ool01000FUH000000UYF00<007ooOol03`0017oo1@001UYF00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100015YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P00
00=JEP00FUH01UYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF1P000UYF
00<007ooOol0:goo000/Ool30003FUH3000HOol40002FUH00`00FUIJEP0200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP05FUH0
0`00FUIJEP040004FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF1P00;7oo000/Ool30003FUH00`00FUIJEP02000JOol40003FUH;0004FUH00`00FUIJEP02FUH8
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP03FUH400000goo000000020002FUH00`00FUH0
00040003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP000000;7oo000/
Ool30002FUH00`00FUIJEP03FUH3000>Ool3000:Ool20004FUH00`00FUIJEP04FUH:00000eYF001J
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH0000300000eYF00000006Ool90003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUH0000/Ool002aoo`8000=J
EP03001JEUYF00AJEP04001JEP00000;Ool5000;Ool200000eYF001JEP05FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP<0009JEP<000ao
o`D0009JEP03001JEUYF00IJEP04001JEUYFFUH50005FUH2000]Ool002eoo`05001JEUYFFUH00006
FUH01000FUIJEUYF0`0027oo1@003Goo0P001UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEUYF001JEP07000@Ool300000goo0000000=0004FUH00`00
FUIJEP03FUH00`00Oomoo`0/Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH30005Ool5
000?Ool20004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00000015YF00<007ooOol057oo2@0015YF00<005YFFUH015YF00<005YFFUH00P00;goo
000^Ool01000FUIJEP001EYF00<005YFFUH01UYF00@005YF000000Aoo`<0019oo`05001JEUYFFUH0
0002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000002@0027oo
2@0015YF00<005YFFUH01UYF00<005YFFUH015YF0`00<Goo000^Ool00`00FUH00006FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH3000GOol30003FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP8003=oo`00;goo0P001UYF00<005YFFUH01EYF00<005YFFUH01EYF1P00
17oo3P0000=oo`00FUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eoo`00
<7oo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF2@0015YF00<005YFFUH015YF00<0
05YFFUH0100000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJ
EP09FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000iOol0035oo`8000=JEP03
001JEUYF00EJEPX000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0009JEP03
001JEUYF00=JEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00EJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000nOol003=oo`800004FUH005YFFUH60004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00
FUIJEP03FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUH000040006FUH00`00FUIJEP02FUH20003FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP040015Ool003Eoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP<000=JEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@0009JEP03001J
EUYF009JEP8000IJEQL004Uoo`00=7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF200015YF00<005YFFUH00eYF0P000UYF00@005YFFUIJEP8000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJ
EP<000AJEP03001JEUYF00AJEP04001JEUYFFUH2001DOol0039oo`<000EJEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEPd0009JEP04001JEP000008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
00Ioo`00000005YF0006FUH01000FUIJEUYF0P00E7oo000`Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF0P0000=J
EP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00000017oo0P001UYF00H005YFFUH005YF001DOol0
02moo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00@000AJEP03001JEP00008000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP@000Ioo`8000=JEP04001JEUYFFUH3001DOol002ioo`8000AJEP03001JEUYF00=J
EP@000Aoo`<00003FUH0000000@000=JEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH0
05YF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000Qoo`800003FUH005YF009J
EP03001JEP0005Aoo`00;Goo00<005YF000015YF00<005YF00000`002goo1`000eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YF0000009JEP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000@000Moo`8000=JEP8005Eoo`00;Goo00@005YFFUH000=JEP80015oo``000AJEP04001J
EUYFFUH60003FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000eYF1`000Woo
00<005YFFUH00P00EGoo000]Ool01@00FUIJEP00FUH00P0057oo0`0027oo20001EYF00@005YFFUIJ
EP8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP07001EOol0
02ioo`03001JEP0000<001Uoo`H000IJEP03001JEUYF00AJEP06001JEP00001oo`0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00@005YF000000MJEP03001JEUYF00=JEP04001JEP00001EOol002io
o`800004FUH005YFFUH70009Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003Ool00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00EGoo000^Ool01000FUIJEP001EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00008000Moo`80009JEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP80
009JEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008005Aoo`00;Woo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@000aoo`<000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00=JEPl000=JEP05001JEUYFFUH0001DOol002ioo`05001JEUYFFUH00004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000BOol30006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH0
00030008FUH00`00FUIJEP03FUH60002FUH00`00Oomoo`1BOol002moo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL001Uoo`@0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP<000=JEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH6001COol0035oo`@000=JEP03001JEUYF00EJEP03001J
EUYF009JEPP002Aoo`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF009JEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH300000eYF0000001C
Ool003Eooa00035oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EP0000P000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0001C
Ool007aoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP06001JEP00001JEWoo0UYF0P00E7oo0024OolJ000;OolI0005FUH2001DOol0
08ioo`03001JEUYF008001Moo`<00003Ool0000000T0009JEP03001JEUYF00AJEP04001JEUYFFUH2
001EOol008moo`800003FUH00000008000moo`T000AJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEP00001GOol008moo`80009JEP03001JEUYF00l000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<005Uoo`00Sgoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00G7oo002?Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001P
Ool0091oo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00@006=oo`00TWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
1`00Igoo002FOolI001^Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]68\[InvisibleSpace]"     "\
\[InvisibleSpace]16.224616979580794`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 68, "     ", 16.224616979580794, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59848 .7556 m .59046 .70157 L .55962 .70333 L p .707 .577 .707 r
F P
0 g
s
.59046 .70157 m .59848 .7556 L .63002 .75051 L p .707 .577 .707 r
F P
0 g
s
.63002 .75051 m .622 .69648 L .59046 .70157 L p .707 .577 .707 r
F P
0 g
s
.622 .69648 m .63002 .75051 L .65916 .74258 L p .707 .577 .707 r
F P
0 g
s
.65916 .74258 m .65114 .68855 L .622 .69648 L p .707 .577 .707 r
F P
0 g
s
.56764 .75736 m .55962 .70333 L .53249 .70157 L p .707 .577 .707 r
F P
0 g
s
.55962 .70333 m .56764 .75736 L .59848 .7556 L p .707 .577 .707 r
F P
0 g
s
.65114 .68855 m .65916 .74258 L .68306 .73259 L p .707 .577 .707 r
F P
0 g
s
.68306 .73259 m .67504 .67856 L .65114 .68855 L p .707 .577 .707 r
F P
0 g
s
.59205 .79976 m .59992 .76274 L .56939 .75519 L p .707 .577 .707 r
F P
0 g
s
.59992 .76274 m .59205 .79976 L .62321 .80562 L p .707 .577 .707 r
F P
0 g
s
.62321 .80562 m .63108 .7686 L .59992 .76274 L p .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53249 .70157 L .51172 .69648 L p .707 .577 .707 r
F P
0 g
s
.53249 .70157 m .54051 .75561 L .54078 .75562 L p .707 .577 .707 r
F P
0 g
s
.5572 .74079 m .53249 .70157 L .54078 .75562 L .707 .577 .707 r
F
.51172 .69648 m .51952 .74901 L p .51952 .74901 L F P
0 g
s
.53123 .73655 m .51172 .69648 L .51952 .74901 L .707 .577 .707 r
F
.51172 .69648 m .49935 .68856 L p .51917 .74879 L F P
0 g
s
.51398 .77511 m .51952 .74902 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L p .51952 .74901 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L .51215 .75686 L .707 .577 .707 r
F
.51215 .75686 m .51702 .74742 L .5108 .74343 L F
.49935 .68856 m .50715 .7411 L p .50716 .7411 L F P
0 g
s
.51917 .74879 m .51264 .72895 L .50716 .7411 L .707 .577 .707 r
F
.51264 .72895 m .49935 .68856 L .50716 .7411 L F
.49935 .68856 m .4966 .67857 L p .50709 .74089 L F P
0 g
s
.50947 .7302 m .50716 .74111 L p .51398 .77511 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50161 .76723 L .51343 .77476 L p .707 .577 .707 r
F P
0 g
s
.51343 .77476 m .51398 .77511 L p .50716 .74111 L .707 .577 .707 r
F P
0 g
s
.50374 .74867 m .50663 .73936 L .5053 .735 L .707 .577 .707 r
F
.50161 .76723 m .50716 .74111 L p .50374 .74867 L F P
0 g
s
.50716 .74111 m .50716 .7411 L p .50715 .7411 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50715 .7411 L .50374 .74867 L .707 .577 .707 r
F
.50506 .73421 m .50685 .73947 L .50464 .73267 L F
.50709 .74089 m .50685 .73947 L .50506 .73421 L F
.4966 .67857 m .50092 .70765 L p .50685 .73947 L F P
0 g
s
.50092 .70765 m .50462 .7326 L p .50685 .73947 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .49935 .68856 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.50716 .7411 m .50947 .7302 L p .50374 .74867 L .707 .577 .707 r
F P
0 g
s
.50464 .73269 m .50506 .73421 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .50466 .73289 L p .50161 .76723 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .49873 .76084 L .5011 .76609 L p .707 .577 .707 r
F P
0 g
s
.5011 .76609 m .50161 .76723 L p .50466 .73289 L .707 .577 .707 r
F P
0 g
s
.50372 .66749 m .50834 .6986 L p .50462 .7326 L .707 .577 .707 r
F P
0 g
s
.50506 .73421 m .5058 .73688 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.5058 .73688 m .50738 .74259 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50709 .74089 L .50581 .73668 L .707 .577 .707 r
F
.50947 .7302 m .50659 .72382 L p .5053 .735 L F P
0 g
s
.50663 .73936 m .50947 .7302 L .5053 .735 L .707 .577 .707 r
F
.51952 .74901 m .51172 .69648 L p .51917 .74879 L F P
0 g
s
.52184 .73809 m .50947 .7302 L p .5108 .74343 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .51347 .71956 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .50659 .72382 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50834 .6986 m .51174 .72152 L .50471 .73246 L p .707 .577 .707 r
F P
0 g
s
.50471 .73246 m .50462 .7326 L p .50834 .6986 L .707 .577 .707 r
F P
0 g
s
.49873 .76084 m .50466 .73289 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .50464 .73269 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50715 .7411 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.51952 .74901 m .52184 .73809 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53123 .73655 L .51952 .74901 L .707 .577 .707 r
F
.53769 .75492 m .54051 .75561 L p .51952 .74901 L F P
0 g
s
.52184 .73809 m .51398 .77511 L .53463 .78372 L p .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .51974 .75052 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .50738 .74259 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51974 .75052 m .51952 .74901 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51702 .74742 m .52184 .73809 L .5108 .74343 L .707 .577 .707 r
F
.52959 .76574 m .53706 .75471 L .52544 .75093 L F
.54055 .75584 m .54249 .7467 L p .52959 .76574 L F P
0 g
s
.51952 .74901 m .51974 .75052 L .53769 .75492 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .52184 .73809 L p .52544 .75093 L .707 .577 .707 r
F P
0 g
s
.53706 .75471 m .54249 .7467 L .52544 .75093 L .707 .577 .707 r
F
.53463 .78372 m .54055 .75584 L p .52959 .76574 L F P
0 g
s
.54078 .75562 m .56764 .75736 L p .5572 .74079 L .707 .577 .707 r
F P
0 g
s
.63108 .7686 m .62321 .80562 L .65196 .80922 L p .707 .577 .707 r
F P
0 g
s
.65196 .80922 m .65982 .7722 L .63108 .7686 L p .707 .577 .707 r
F P
0 g
s
.56153 .79222 m .56939 .75519 L .54249 .7467 L p .707 .577 .707 r
F P
0 g
s
.56939 .75519 m .56153 .79222 L .59205 .79976 L p .707 .577 .707 r
F P
0 g
s
.67504 .67856 m .68306 .73259 L .69936 .72152 L p .707 .577 .707 r
F P
0 g
s
.69936 .72152 m .69134 .66749 L .67504 .67856 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .53463 .78372 L .56153 .79222 L p .707 .577 .707 r
F P
0 g
s
.65982 .7722 m .65196 .80922 L .67547 .81021 L p .707 .577 .707 r
F P
0 g
s
.67547 .81021 m .68333 .77319 L .65982 .7722 L p .707 .577 .707 r
F P
0 g
s
.59892 .85633 m .59691 .83815 L .56593 .83901 L p .707 .577 .707 r
F P
0 g
s
.59691 .83815 m .59892 .85633 L .63059 .8523 L p .707 .577 .707 r
F P
0 g
s
.63059 .8523 m .62858 .83413 L .59691 .83815 L p .707 .577 .707 r
F P
0 g
s
.62858 .83413 m .63059 .8523 L .65985 .8455 L p .707 .577 .707 r
F P
0 g
s
.65985 .8455 m .65784 .82732 L .62858 .83413 L p .707 .577 .707 r
F P
0 g
s
.56593 .83901 m .56794 .85719 L .59892 .85633 L p .707 .577 .707 r
F P
0 g
s
.56794 .85719 m .56593 .83901 L .53868 .8366 L p .707 .577 .707 r
F P
0 g
s
.65784 .82732 m .65985 .8455 L .68384 .83658 L p .707 .577 .707 r
F P
0 g
s
.68384 .83658 m .68183 .8184 L .65784 .82732 L p .707 .577 .707 r
F P
0 g
s
.53868 .8366 m .54068 .85478 L .56794 .85719 L p .707 .577 .707 r
F P
0 g
s
.69134 .66749 m .69936 .72152 L .70649 .71044 L p .707 .577 .707 r
F P
0 g
s
.70649 .71044 m .69847 .65641 L .69134 .66749 L p .707 .577 .707 r
F P
0 g
s
.68333 .77319 m .67547 .81021 L .69145 .80849 L p .707 .577 .707 r
F P
0 g
s
.69145 .80849 m .69931 .77147 L .68333 .77319 L p .707 .577 .707 r
F P
0 g
s
.54068 .85478 m .53868 .8366 L .51782 .83118 L p .707 .577 .707 r
F P
0 g
s
.51782 .83118 m .51982 .84936 L .54068 .85478 L p .707 .577 .707 r
F P
0 g
s
.68183 .8184 m .68384 .83658 L .70021 .82643 L p .707 .577 .707 r
F P
0 g
s
.70021 .82643 m .6982 .80825 L .68183 .8184 L p .707 .577 .707 r
F P
0 g
s
.69847 .65641 m .70649 .71044 L .70373 .70045 L p .707 .577 .707 r
F P
0 g
s
.70373 .70045 m .69571 .64642 L .69847 .65641 L p .707 .577 .707 r
F P
0 g
s
.69931 .77147 m .69145 .80849 L .69834 .80423 L p .707 .577 .707 r
F P
0 g
s
.69834 .80423 m .7062 .76721 L .69931 .77147 L p .707 .577 .707 r
F P
0 g
s
.51982 .84936 m .51782 .83118 L .50539 .82327 L p .707 .577 .707 r
F P
0 g
s
.50539 .82327 m .5074 .84145 L .51982 .84936 L p .707 .577 .707 r
F P
0 g
s
.6982 .80825 m .70021 .82643 L .70736 .81603 L p .707 .577 .707 r
F P
0 g
s
.70736 .81603 m .70535 .79785 L .6982 .80825 L p .707 .577 .707 r
F P
0 g
s
.48871 .8218 m .48871 .31992 L .44482 .31709 L p .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .4966 .67857 L .50372 .66749 L p .707 .577 .707 r
F P
0 g
s
.5074 .84145 m .50539 .82327 L .50261 .81364 L p .707 .577 .707 r
F P
0 g
s
.50261 .81364 m .50462 .83182 L .5074 .84145 L p .707 .577 .707 r
F P
0 g
s
.51347 .71956 m .51228 .72517 L p .49873 .76084 L .707 .577 .707 r
F P
0 g
s
.51228 .72517 m .50561 .75658 L .50109 .75938 L p .707 .577 .707 r
F P
0 g
s
.50109 .75938 m .49873 .76084 L p .51228 .72517 L .707 .577 .707 r
F P
0 g
s
.52003 .65642 m .52463 .68742 L p .51174 .72152 L .707 .577 .707 r
F P
0 g
s
.50561 .75658 m .51347 .71956 L .52946 .71784 L p .707 .577 .707 r
F P
0 g
s
.52463 .68742 m .52805 .71045 L .51397 .72001 L p .707 .577 .707 r
F P
0 g
s
.51397 .72001 m .51174 .72152 L p .52463 .68742 L .707 .577 .707 r
F P
0 g
s
.51174 .72152 m .50372 .66749 L .52003 .65642 L p .707 .577 .707 r
F P
0 g
s
.50462 .83182 m .50261 .81364 L .50976 .80324 L p .707 .577 .707 r
F P
0 g
s
.50976 .80324 m .51177 .82142 L .50462 .83182 L p .707 .577 .707 r
F P
0 g
s
.52946 .71784 m .5216 .75486 L .50561 .75658 L p .707 .577 .707 r
F P
0 g
s
.51177 .82142 m .50976 .80324 L .52613 .79308 L p .707 .577 .707 r
F P
0 g
s
.52613 .79308 m .52814 .81126 L .51177 .82142 L p .707 .577 .707 r
F P
0 g
s
.5216 .75486 m .52946 .71784 L .55297 .71883 L p .707 .577 .707 r
F P
0 g
s
.55297 .71883 m .54511 .75585 L .5216 .75486 L p .707 .577 .707 r
F P
0 g
s
.52814 .81126 m .52613 .79308 L .55012 .78417 L p .707 .577 .707 r
F P
0 g
s
.55012 .78417 m .55213 .80235 L .52814 .81126 L p .707 .577 .707 r
F P
0 g
s
.48871 .31992 m .48871 .8218 L .5337 .82085 L p .707 .577 .707 r
F P
0 g
s
.52805 .71045 m .52003 .65642 L .54392 .64643 L p .707 .577 .707 r
F P
0 g
s
.54392 .64643 m .55195 .70046 L .52805 .71045 L p .707 .577 .707 r
F P
0 g
s
.5337 .82085 m .5337 .31896 L .48871 .31992 L p .707 .577 .707 r
F P
0 g
s
.55195 .70046 m .54392 .64643 L .57307 .6385 L p .707 .577 .707 r
F P
0 g
s
.57307 .6385 m .58109 .69253 L .55195 .70046 L p .707 .577 .707 r
F P
0 g
s
.54511 .75585 m .55297 .71883 L .58171 .72243 L p .707 .577 .707 r
F P
0 g
s
.58171 .72243 m .57385 .75945 L .54511 .75585 L p .707 .577 .707 r
F P
0 g
s
.55213 .80235 m .55012 .78417 L .57938 .77736 L p .707 .577 .707 r
F P
0 g
s
.57938 .77736 m .58139 .79554 L .55213 .80235 L p .707 .577 .707 r
F P
0 g
s
.5337 .31896 m .5337 .82085 L .57539 .81622 L p .707 .577 .707 r
F P
0 g
s
.58109 .69253 m .57307 .6385 L .6046 .63341 L p .707 .577 .707 r
F P
0 g
s
.57385 .75945 m .58171 .72243 L .61287 .72829 L p .707 .577 .707 r
F P
0 g
s
.61287 .72829 m .60501 .76531 L .57385 .75945 L p .707 .577 .707 r
F P
0 g
s
.57539 .81622 m .57539 .31433 L .5337 .31896 L p .707 .577 .707 r
F P
0 g
s
.44482 .81898 m .44482 .31709 L .40634 .31077 L p .707 .577 .707 r
F P
0 g
s
.44482 .31709 m .44482 .81898 L .48871 .8218 L p .707 .577 .707 r
F P
0 g
s
.69571 .64642 m .70373 .70045 L .69137 .69253 L p .707 .577 .707 r
F P
0 g
s
.69137 .69253 m .68335 .63849 L .69571 .64642 L p .707 .577 .707 r
F P
0 g
s
.7062 .76721 m .69834 .80423 L .69546 .79785 L p .707 .577 .707 r
F P
0 g
s
.69546 .79785 m .70332 .76082 L .7062 .76721 L p .707 .577 .707 r
F P
0 g
s
.6046 .63341 m .61262 .68744 L .58109 .69253 L p .707 .577 .707 r
F P
0 g
s
.6434 .73584 m .63554 .77286 L .60501 .76531 L p .707 .577 .707 r
F P
0 g
s
.60501 .76531 m .61287 .72829 L .6434 .73584 L p .707 .577 .707 r
F P
0 g
s
.58139 .79554 m .57938 .77736 L .61105 .77334 L p .707 .577 .707 r
F P
0 g
s
.61105 .77334 m .61306 .79152 L .58139 .79554 L p .707 .577 .707 r
F P
0 g
s
.57539 .31433 m .57539 .81622 L .6097 .80835 L p .707 .577 .707 r
F P
0 g
s
.61262 .68744 m .6046 .63341 L .63545 .63165 L p .707 .577 .707 r
F P
0 g
s
.6097 .80835 m .6097 .30646 L .57539 .31433 L p .707 .577 .707 r
F P
0 g
s
.70535 .79785 m .70736 .81603 L .70458 .8064 L p .707 .577 .707 r
F P
0 g
s
.70458 .8064 m .70257 .78822 L .70535 .79785 L p .707 .577 .707 r
F P
0 g
s
.40634 .81265 m .40634 .31077 L .37702 .30156 L p .707 .577 .707 r
F P
0 g
s
.40634 .31077 m .40634 .81265 L .44482 .81898 L p .707 .577 .707 r
F P
0 g
s
.25424 .69954 m .25078 .64245 L .21967 .64336 L p .707 .577 .707 r
F P
0 g
s
.25078 .64245 m .25424 .69954 L .28602 .69727 L p .707 .577 .707 r
F P
0 g
s
.28602 .69727 m .28256 .64018 L .25078 .64245 L p .707 .577 .707 r
F P
0 g
s
.28256 .64018 m .28602 .69727 L .31535 .69387 L p .707 .577 .707 r
F P
0 g
s
.31535 .69387 m .3119 .63678 L .28256 .64018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22312 .70046 m .21967 .64336 L .19227 .64283 L p .707 .577 .707 r
F P
0 g
s
.21967 .64336 m .22312 .70046 L .25424 .69954 L p .707 .577 .707 r
F P
0 g
s
.68335 .63849 m .69137 .69253 L .6706 .68744 L p .707 .577 .707 r
F P
0 g
s
.6706 .68744 m .66258 .6334 L .68335 .63849 L p .707 .577 .707 r
F P
0 g
s
.3119 .63678 m .31535 .69387 L .33937 .68967 L p .707 .577 .707 r
F P
0 g
s
.33937 .68967 m .33591 .63258 L .3119 .63678 L p .707 .577 .707 r
F P
0 g
s
.19227 .64283 m .19572 .69993 L .22312 .70046 L p .707 .577 .707 r
F P
0 g
s
.63545 .63165 m .64347 .68568 L .61262 .68744 L p .707 .577 .707 r
F P
0 g
s
.6703 .74433 m .66244 .78135 L .63554 .77286 L p .707 .577 .707 r
F P
0 g
s
.64203 .77248 m .64404 .79066 L .61306 .79152 L p .707 .577 .707 r
F P
0 g
s
.63554 .77286 m .6434 .73584 L .6703 .74433 L p .707 .577 .707 r
F P
0 g
s
.61306 .79152 m .61105 .77334 L .64203 .77248 L p .707 .577 .707 r
F P
0 g
s
.6097 .30646 m .6097 .80835 L .63327 .79802 L p .707 .577 .707 r
F P
0 g
s
.63327 .79802 m .63327 .29613 L .6097 .30646 L p .707 .577 .707 r
F P
0 g
s
.70332 .76082 m .69546 .79785 L .68309 .78996 L p .707 .577 .707 r
F P
0 g
s
.68309 .78996 m .69095 .75294 L .70332 .76082 L p .707 .577 .707 r
F P
0 g
s
.70257 .78822 m .70458 .8064 L .69215 .79849 L p .707 .577 .707 r
F P
0 g
s
.69215 .79849 m .69015 .78031 L .70257 .78822 L p .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .25343 .78659 L .23499 .7867 L p .707 .577 .707 r
F P
0 g
s
.23499 .7867 m .2223 .78678 L p .23022 .79142 L .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .23499 .7867 L .23022 .79142 L .707 .577 .707 r
F
.25343 .78659 m .2543 .80553 L .2861 .80365 L p F P
0 g
s
.2861 .80365 m .28524 .7847 L .26816 .78571 L p .707 .577 .707 r
F P
0 g
s
.26816 .78571 m .25343 .78659 L p .26262 .79138 L .707 .577 .707 r
F P
0 g
s
.2861 .80365 m .26816 .78571 L .26262 .79138 L .707 .577 .707 r
F
.28524 .7847 m .2861 .80365 L .31548 .80027 L p F P
0 g
s
.31548 .80027 m .31461 .78132 L .30052 .78294 L p .707 .577 .707 r
F P
0 g
s
.30052 .78294 m .28524 .7847 L p .2952 .78983 L .707 .577 .707 r
F P
0 g
s
.31548 .80027 m .30052 .78294 L .2952 .78983 L .707 .577 .707 r
F
.31461 .78132 m .31548 .80027 L .33954 .79571 L p F P
0 g
s
.33954 .79571 m .33867 .77676 L .32841 .77871 L p .707 .577 .707 r
F P
0 g
s
.32841 .77871 m .31461 .78132 L p .32433 .78693 L .707 .577 .707 r
F P
0 g
s
.33954 .79571 m .32841 .77871 L .32433 .78693 L .707 .577 .707 r
F
.33867 .77676 m .33954 .79571 L .35593 .79043 L p F P
0 g
s
.35593 .79043 m .35507 .77148 L .33867 .77676 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .3528 .76861 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.34014 .74593 m .33899 .75739 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.33899 .75739 m .33673 .77998 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .33673 .77998 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31636 .75379 m .31536 .76376 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31536 .76376 m .31295 .78784 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .31295 .78784 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2872 .75736 m .28621 .76725 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.28621 .76725 m .28379 .79142 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .28379 .79142 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25552 .7563 m .25439 .7675 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25439 .7675 m .2521 .79036 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .25552 .7563 L .22441 .75071 L p .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .2872 .75736 L .25552 .7563 L p .707 .577 .707 r
F P
0 g
s
.19572 .69993 m .19227 .64283 L .17126 .64092 L p .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .31636 .75379 L .2872 .75736 L p .707 .577 .707 r
F P
0 g
s
.22099 .78476 m .22441 .75071 L .19692 .74114 L p .707 .577 .707 r
F P
0 g
s
.22441 .75071 m .22099 .78476 L .2521 .79036 L p .707 .577 .707 r
F P
0 g
s
.17126 .64092 m .17471 .69801 L .19572 .69993 L p .707 .577 .707 r
F P
0 g
s
.66258 .6334 m .6706 .68744 L .64347 .68568 L p .707 .577 .707 r
F P
0 g
s
.64347 .68568 m .63545 .63165 L .66258 .6334 L p .707 .577 .707 r
F P
0 g
s
.37702 .80345 m .37702 .30156 L .35975 .29037 L p .707 .577 .707 r
F P
0 g
s
.37702 .30156 m .37702 .80345 L .40634 .81265 L p .707 .577 .707 r
F P
0 g
s
.33591 .63258 m .33937 .68967 L .35572 .68509 L p .707 .577 .707 r
F P
0 g
s
.35572 .68509 m .35227 .62799 L .33591 .63258 L p .707 .577 .707 r
F P
0 g
s
.2223 .78678 m .22317 .80572 L .2543 .80553 L p .707 .577 .707 r
F P
0 g
s
.22317 .80572 m .2223 .78678 L .1949 .78526 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .34014 .74593 L .31636 .75379 L p .707 .577 .707 r
F P
0 g
s
.19351 .77519 m .19692 .74114 L .17575 .72852 L p .707 .577 .707 r
F P
0 g
s
.19692 .74114 m .19351 .77519 L .22099 .78476 L p .707 .577 .707 r
F P
0 g
s
.1949 .78526 m .19576 .80421 L .22317 .80572 L p .707 .577 .707 r
F P
0 g
s
.69095 .75294 m .68309 .78996 L .66244 .78135 L p .707 .577 .707 r
F P
0 g
s
.66244 .78135 m .6703 .74433 L .69095 .75294 L p .707 .577 .707 r
F P
0 g
s
.17471 .69801 m .17126 .64092 L .1587 .63779 L p .707 .577 .707 r
F P
0 g
s
.69015 .78031 m .69215 .79849 L .67129 .79306 L p .707 .577 .707 r
F P
0 g
s
.67129 .79306 m .66929 .77488 L .69015 .78031 L p .707 .577 .707 r
F P
0 g
s
.64404 .79066 m .64203 .77248 L .66929 .77488 L p .707 .577 .707 r
F P
0 g
s
.63327 .29613 m .63327 .79802 L .6438 .78625 L p .707 .577 .707 r
F P
0 g
s
.6438 .78625 m .6438 .28436 L .63327 .29613 L p .707 .577 .707 r
F P
0 g
s
.1587 .63779 m .16215 .69489 L .17471 .69801 L p .707 .577 .707 r
F P
0 g
s
.19576 .80421 m .1949 .78526 L .1739 .78219 L p .707 .577 .707 r
F P
0 g
s
.17575 .72852 m .17234 .76257 L .19351 .77519 L p .707 .577 .707 r
F P
0 g
s
.1739 .78219 m .17476 .80114 L .19576 .80421 L p .707 .577 .707 r
F P
0 g
s
.3528 .76861 m .35622 .73456 L .34014 .74593 L p .707 .577 .707 r
F P
0 g
s
.17234 .76257 m .17575 .72852 L .16296 .71408 L p .707 .577 .707 r
F P
0 g
s
.35227 .62799 m .35572 .68509 L .3628 .68056 L p .707 .577 .707 r
F P
0 g
s
.3628 .68056 m .35935 .62347 L .35227 .62799 L p .707 .577 .707 r
F P
0 g
s
.35622 .73456 m .3528 .76861 L .3596 .75483 L p .707 .577 .707 r
F P
0 g
s
.3596 .75483 m .36301 .72078 L .35622 .73456 L p .707 .577 .707 r
F P
0 g
s
.35935 .62347 m .3628 .68056 L .35992 .67654 L p .707 .577 .707 r
F P
0 g
s
.35992 .67654 m .35647 .61945 L .35935 .62347 L p .707 .577 .707 r
F P
0 g
s
.35507 .77148 m .35593 .79043 L .36305 .78494 L p .707 .577 .707 r
F P
0 g
s
.36305 .78494 m .36219 .76599 L .35507 .77148 L p .707 .577 .707 r
F P
0 g
s
.36301 .72078 m .3596 .75483 L .35645 .74 L p .707 .577 .707 r
F P
0 g
s
.35645 .74 m .35986 .70595 L .36301 .72078 L p .707 .577 .707 r
F P
0 g
s
.35647 .61945 m .35992 .67654 L .34736 .67342 L p .707 .577 .707 r
F P
0 g
s
.36021 .77977 m .35934 .76083 L .36219 .76599 L p .707 .577 .707 r
F P
0 g
s
.35986 .70595 m .35645 .74 L .34366 .72557 L p .707 .577 .707 r
F P
0 g
s
.34366 .72557 m .34707 .69152 L .35986 .70595 L p .707 .577 .707 r
F P
0 g
s
.35934 .76083 m .36021 .77977 L .34767 .77544 L p .707 .577 .707 r
F P
0 g
s
.35974 .79226 m .35975 .29037 L .3562 .2783 L p .707 .577 .707 r
F P
0 g
s
.36219 .76599 m .36305 .78494 L .36021 .77977 L p .707 .577 .707 r
F P
0 g
s
.35975 .29037 m .35974 .79226 L .37702 .80345 L p .707 .577 .707 r
F P
0 g
s
.66929 .77488 m .67129 .79306 L .64404 .79066 L p .707 .577 .707 r
F P
0 g
s
.16215 .69489 m .1587 .63779 L .15582 .63378 L p .707 .577 .707 r
F P
0 g
s
.16296 .71408 m .15955 .74814 L .17234 .76257 L p .707 .577 .707 r
F P
0 g
s
.17476 .80114 m .1739 .78219 L .16136 .77786 L p .707 .577 .707 r
F P
0 g
s
.16136 .77786 m .16223 .79681 L .17476 .80114 L p .707 .577 .707 r
F P
0 g
s
.15955 .74814 m .16296 .71408 L .15981 .69925 L p .707 .577 .707 r
F P
0 g
s
.15981 .69925 m .1564 .7333 L .15955 .74814 L p .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15981 .69925 L .15988 .69912 L p .707 .577 .707 r
F P
0 g
s
.16 .69188 m .16215 .69489 L p .16024 .67645 L .707 .577 .707 r
F P
0 g
s
.15988 .69912 m .16661 .68548 L p .15957 .71843 L .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15988 .69912 L .15957 .71843 L .707 .577 .707 r
F
.15582 .63378 m .15927 .69087 L .16 .69188 L p F P
0 g
s
.16024 .67645 m .15582 .63378 L .16 .69188 L .707 .577 .707 r
F
.6438 .28436 m .6438 .78625 L .64025 .77418 L p F P
0 g
s
.64025 .77418 m .64025 .27229 L .6438 .28436 L p .707 .577 .707 r
F P
0 g
s
.15927 .69087 m .15582 .63378 L .1629 .62925 L p .707 .577 .707 r
F P
0 g
s
.16223 .79681 m .16136 .77786 L .15852 .7727 L p .707 .577 .707 r
F P
0 g
s
.15852 .7727 m .15938 .79165 L .16223 .79681 L p .707 .577 .707 r
F P
0 g
s
.1629 .62925 m .16636 .68635 L .15927 .69087 L p .707 .577 .707 r
F P
0 g
s
.34736 .67342 m .34391 .61633 L .35647 .61945 L p .707 .577 .707 r
F P
0 g
s
.34767 .77544 m .34681 .7565 L .35934 .76083 L p .707 .577 .707 r
F P
0 g
s
.3562 .2783 m .3562 .78019 L .35974 .79226 L p .707 .577 .707 r
F P
0 g
s
.3562 .78019 m .3562 .2783 L .36672 .26652 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17925 .62467 m .17975 .63286 L p .16636 .68635 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .18268 .6741 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .16604 .69118 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16661 .68548 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18268 .6741 L p .18616 .68153 L .707 .577 .707 r
F P
0 g
s
.18275 .68258 m .18616 .68153 L .19051 .69082 L .707 .577 .707 r
F
.18192 .68169 m .18616 .68153 L .18275 .68258 L F
.20672 .67756 m .18903 .68065 L p .20552 .6756 L F P
0 g
s
.20552 .6756 m .20646 .66624 L p .21189 .67565 L .707 .577 .707 r
F P
0 g
s
.20672 .67756 m .20666 .67647 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20552 .6756 m .21189 .67565 L .20666 .67647 L .707 .577 .707 r
F
.23606 .67416 m .20672 .67756 L p .20723 .67638 L F P
0 g
s
.20646 .66624 m .23562 .66267 L p .22634 .67339 L .707 .577 .707 r
F P
0 g
s
.21189 .67565 m .20646 .66624 L .22634 .67339 L .707 .577 .707 r
F
.23562 .66267 m .26731 .66373 L p .25861 .6719 L F P
0 g
s
.24199 .67277 m .23562 .66267 L .25861 .6719 L .707 .577 .707 r
F
.23606 .67416 m .23599 .67308 L p .23659 .67305 L F P
0 g
s
.23468 .67209 m .23562 .66267 L p .24199 .67277 L .707 .577 .707 r
F P
0 g
s
.23606 .67416 m .23659 .67305 L .267 .67192 L .707 .577 .707 r
F
.26653 .67149 m .26731 .66373 L p .28039 .68418 L F P
0 g
s
.26784 .67189 m .26703 .67195 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26703 .67195 m .23606 .67416 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26731 .66373 m .29842 .66932 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.26781 .67142 m .26784 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.26389 .69778 m .26653 .67149 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .24199 .67277 L .24783 .68203 L .707 .577 .707 r
F
.23468 .67209 m .24199 .67277 L .23599 .67308 L F
.26731 .66373 m .26389 .69778 L .23221 .69672 L p F P
0 g
s
.26438 .6148 m .26781 .67142 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.2326 .61707 m .26438 .6148 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23606 .67416 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.23562 .66267 m .23457 .67315 L p .20305 .70029 L .707 .577 .707 r
F P
0 g
s
.23457 .67315 m .23221 .69672 L .20593 .69994 L p .707 .577 .707 r
F P
0 g
s
.20593 .69994 m .20305 .70029 L p .23457 .67315 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .23592 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .2326 .61707 L p .23647 .67138 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23647 .67138 L .23659 .67305 L .707 .577 .707 r
F
.24783 .68203 m .24199 .67277 L .25861 .6719 L F
.23221 .69672 m .23468 .67209 L p .24783 .68203 L F P
0 g
s
.2326 .61707 m .23592 .67189 L p .23468 .67209 L .707 .577 .707 r
F P
0 g
s
.20723 .67638 m .21533 .65745 L .23468 .67209 L .707 .577 .707 r
F
.21533 .65745 m .2326 .61707 L .23468 .67209 L F
.21688 .68432 m .21189 .67565 L .22634 .67339 L F
.20666 .67647 m .21189 .67565 L .21688 .68432 L F
.20327 .62047 m .2326 .61707 L p .20723 .67638 L F P
0 g
s
.18268 .6741 m .20646 .66624 L p .19051 .69082 L .707 .577 .707 r
F P
0 g
s
.20666 .67647 m .20659 .67528 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20646 .66624 m .20305 .70029 L .17927 .70815 L p .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20327 .62047 L p .20711 .67466 L .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20711 .67466 L .20723 .67638 L .707 .577 .707 r
F
.20659 .67528 m .20666 .67647 L p .20552 .6756 L F P
0 g
s
.20666 .67647 m .20672 .67756 L p .20552 .6756 L .707 .577 .707 r
F P
0 g
s
.20305 .70029 m .20552 .6756 L p .21688 .68432 L .707 .577 .707 r
F P
0 g
s
.20327 .62047 m .20659 .67528 L p .18271 .68176 L .707 .577 .707 r
F P
0 g
s
.18903 .68065 m .18271 .68176 L p .20659 .67528 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .18271 .68176 L .18214 .68192 L p .707 .577 .707 r
F P
0 g
s
.18214 .68192 m .18101 .68224 L p .18192 .68169 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18267 .68124 L .18214 .68192 L .707 .577 .707 r
F
.17927 .70815 m .18192 .68169 L p .19051 .69082 L F P
0 g
s
.17927 .70815 m .16319 .71953 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.18268 .6741 m .1818 .68287 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.1818 .68287 m .17927 .70815 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.17925 .62467 m .20327 .62047 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18271 .68176 m .18267 .68124 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .17925 .62467 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.17975 .63286 m .18267 .68124 L p .16723 .6861 L .707 .577 .707 r
F P
0 g
s
.18101 .68224 m .16723 .6861 L p .18267 .68124 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .16604 .69118 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16723 .6861 m .16636 .68635 L p .17975 .63286 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .1564 .7333 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16319 .71953 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64025 .27229 m .64025 .77418 L .62297 .76299 L p .707 .577 .707 r
F P
0 g
s
.62297 .76299 m .62297 .2611 L .64025 .27229 L p .707 .577 .707 r
F P
0 g
s
.16636 .68635 m .1629 .62925 L .17925 .62467 L p .707 .577 .707 r
F P
0 g
s
.15938 .79165 m .15852 .7727 L .16564 .76721 L p .707 .577 .707 r
F P
0 g
s
.16564 .76721 m .1665 .78615 L .15938 .79165 L p .707 .577 .707 r
F P
0 g
s
.34391 .61633 m .34736 .67342 L .32635 .6715 L p .707 .577 .707 r
F P
0 g
s
.32635 .6715 m .3229 .61441 L .34391 .61633 L p .707 .577 .707 r
F P
0 g
s
.36672 .76841 m .36672 .26652 L .3903 .2562 L p .707 .577 .707 r
F P
0 g
s
.36672 .26652 m .36672 .76841 L .3562 .78019 L p .707 .577 .707 r
F P
0 g
s
.34707 .69152 m .34366 .72557 L .32249 .71295 L p .707 .577 .707 r
F P
0 g
s
.32249 .71295 m .3259 .6789 L .34707 .69152 L p .707 .577 .707 r
F P
0 g
s
.1665 .78615 m .16564 .76721 L .18203 .76192 L p .707 .577 .707 r
F P
0 g
s
.18203 .76192 m .1829 .78087 L .1665 .78615 L p .707 .577 .707 r
F P
0 g
s
.62297 .2611 m .62297 .76299 L .59366 .75378 L p .707 .577 .707 r
F P
0 g
s
.59366 .75378 m .59366 .25189 L .62297 .2611 L p .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .3259 .6789 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.295 .70337 m .29796 .67385 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29796 .67385 m .29842 .66932 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .295 .70337 L .26389 .69778 L p .707 .577 .707 r
F P
0 g
s
.2955 .61388 m .29895 .67098 L .29589 .67107 L p .707 .577 .707 r
F P
0 g
s
.29589 .67107 m .26784 .67189 L p .27901 .64846 L .707 .577 .707 r
F P
0 g
s
.27901 .64846 m .2955 .61388 L .29589 .67107 L .707 .577 .707 r
F
.3229 .61441 m .32635 .6715 L .29895 .67098 L p F P
0 g
s
.29895 .67098 m .2955 .61388 L .3229 .61441 L p .707 .577 .707 r
F P
0 g
s
.34681 .7565 m .34767 .77544 L .32667 .77237 L p .707 .577 .707 r
F P
0 g
s
.32667 .77237 m .32581 .75342 L .34681 .7565 L p .707 .577 .707 r
F P
0 g
s
.3259 .6789 m .32249 .71295 L .295 .70337 L p .707 .577 .707 r
F P
0 g
s
.26784 .67189 m .26438 .6148 L .2955 .61388 L p .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73561 .61666 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .74139 .66903 L .73359 .67036 L .707 .577 .707 r
F
.73347 .66902 m .73359 .67036 L p .74139 .66903 L F P
0 g
s
.73561 .61666 m .7045 .61212 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.7045 .61212 m .70105 .66491 L .73216 .66946 L p .707 .577 .707 r
F P
0 g
s
.73269 .66031 m .70158 .66262 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.7361 .69854 m .73347 .66902 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73297 .66947 L p .73299 .66944 L .707 .577 .707 r
F P
0 g
s
.73561 .61666 m .73219 .66902 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76739 .61726 m .73561 .61666 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76408 .66795 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76739 .61726 L p .76353 .6675 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76353 .6675 L .76341 .66905 L .707 .577 .707 r
F
.79695 .69205 m .77366 .66719 L .76543 .66905 L F
.76543 .66905 m .76779 .69551 L .79407 .69239 L p F P
0 g
s
.79407 .69239 m .79695 .69205 L p .76543 .66905 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .76543 .66905 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.75216 .67984 m .76401 .66905 L .74139 .66903 L .707 .577 .707 r
F
.76779 .69551 m .76401 .66905 L .75216 .67984 L F
.76532 .66785 m .76543 .66905 L p .77366 .66719 L F P
0 g
s
.76408 .66795 m .76401 .66905 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76437 .65728 L .74139 .66903 L .707 .577 .707 r
F
.76543 .66905 m .76532 .66785 L p .76401 .66905 L F P
0 g
s
.76739 .61726 m .76408 .66795 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76532 .66785 m .76437 .65728 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .78467 .65022 L .76532 .66785 L .707 .577 .707 r
F
.78467 .65022 m .76739 .61726 L .76532 .66785 L F
.79673 .61384 m .76739 .61726 L p .79114 .66256 L F P
0 g
s
.79277 .66567 m .79289 .66407 L .79114 .66256 L .707 .577 .707 r
F
.79289 .66407 m .79673 .61384 L .79114 .66256 L F
.79695 .69205 m .82073 .68851 L p .81965 .68713 L F P
0 g
s
.79334 .66562 m .79341 .66452 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79673 .61384 L p .79289 .66407 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79289 .66407 L .79277 .66567 L .707 .577 .707 r
F
.79334 .66562 m .79353 .65382 L .77366 .66719 L F
.79458 .66553 m .79447 .66433 L p .79334 .66562 L F P
0 g
s
.79673 .61384 m .79341 .66452 L p .79451 .66429 L .707 .577 .707 r
F P
0 g
s
.81097 .66141 m .81729 .65954 L p .79341 .66452 L .707 .577 .707 r
F P
0 g
s
.79447 .66433 m .79353 .65382 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81098 .6455 L .79451 .66429 L .707 .577 .707 r
F
.81098 .6455 m .79673 .61384 L .79451 .66429 L F
.81965 .68713 m .81794 .66017 L .80088 .66319 L F
.79353 .65382 m .79458 .66553 L p .81965 .68713 L F P
0 g
s
.79458 .66553 m .79695 .69205 L p .81965 .68713 L .707 .577 .707 r
F P
0 g
s
.79695 .69205 m .79458 .66553 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.78312 .67729 m .79334 .66562 L .77366 .66719 L .707 .577 .707 r
F
.79695 .69205 m .79334 .66562 L .78312 .67729 L F
.79327 .66663 m .81097 .66141 L p .79447 .66433 L F P
0 g
s
.79341 .66452 m .79334 .66562 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.79334 .66562 m .79327 .66663 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .82075 .60675 L .79673 .61384 L p .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .79353 .65382 L p .80088 .66319 L .707 .577 .707 r
F P
0 g
s
.82073 .68851 m .83681 .68523 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.82075 .60675 m .81732 .65906 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .82073 .68851 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81786 .65919 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81732 .65906 m .81729 .65954 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.83001 .63745 m .82075 .60675 L .81788 .65887 L .707 .577 .707 r
F
.81808 .6588 m .81788 .65887 L .81786 .65919 L F
.83001 .63745 m .81788 .65887 L .81808 .6588 L F
.83364 .64946 m .83001 .63745 L .81808 .6588 L F
.82069 .68802 m .81808 .6588 L p .81965 .68713 L F P
0 g
s
.81808 .6588 m .81732 .65028 L p .81788 .65916 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .81788 .65916 L .81965 .68713 L .707 .577 .707 r
F
.81786 .65919 m .81899 .65849 L p .81808 .6588 L F P
0 g
s
.81899 .65849 m .83364 .64946 L p .81808 .6588 L .707 .577 .707 r
F P
0 g
s
.83364 .64946 m .8371 .59667 L .82075 .60675 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .81732 .65028 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83681 .68523 m .83396 .6534 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83396 .6534 m .83339 .647 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .81808 .6588 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81724 .66029 m .81732 .65028 L .80088 .66319 L .707 .577 .707 r
F
.81794 .66017 m .81788 .65916 L .81724 .66029 L F
.81788 .65916 m .81732 .65028 L .81724 .66029 L F
.82073 .68851 m .82069 .68802 L p .81965 .68713 L F P
0 g
s
.79353 .65382 m .76437 .65728 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.79327 .66663 m .79334 .66562 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .76532 .66785 L .76394 .67005 L .707 .577 .707 r
F
.76401 .66905 m .76394 .67005 L p .76532 .66785 L F P
0 g
s
.76394 .67005 m .79327 .66663 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .76532 .66785 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .73269 .66031 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76401 .66905 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73216 .66946 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73219 .66902 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.73347 .66902 m .73269 .66031 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76341 .66905 L .73299 .66944 L .707 .577 .707 r
F
.73297 .66947 m .76394 .67005 L p .73299 .66944 L F P
0 g
s
.73269 .66031 m .73347 .66902 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.73359 .67036 m .7361 .69854 L .76062 .69619 L p .707 .577 .707 r
F P
0 g
s
.76062 .69619 m .76779 .69551 L p .73359 .67036 L .707 .577 .707 r
F P
0 g
s
.3903 .2562 m .3903 .75809 L .36672 .76841 L p .707 .577 .707 r
F P
0 g
s
.3903 .75809 m .3903 .2562 L .42461 .24833 L p .707 .577 .707 r
F P
0 g
s
.1829 .78087 m .18203 .76192 L .20609 .75737 L p .707 .577 .707 r
F P
0 g
s
.70105 .66491 m .7045 .61212 L .6771 .60406 L p .707 .577 .707 r
F P
0 g
s
.20609 .75737 m .20696 .77631 L .1829 .78087 L p .707 .577 .707 r
F P
0 g
s
.32581 .75342 m .32667 .77237 L .29927 .77086 L p .707 .577 .707 r
F P
0 g
s
.29927 .77086 m .2984 .75191 L .32581 .75342 L p .707 .577 .707 r
F P
0 g
s
.59366 .25189 m .59366 .75378 L .55518 .74746 L p .707 .577 .707 r
F P
0 g
s
.55518 .74746 m .55518 .24557 L .59366 .25189 L p .707 .577 .707 r
F P
0 g
s
.67364 .65685 m .6771 .60406 L .65609 .59329 L p .707 .577 .707 r
F P
0 g
s
.6771 .60406 m .67364 .65685 L .70105 .66491 L p .707 .577 .707 r
F P
0 g
s
.20696 .77631 m .20609 .75737 L .23547 .75398 L p .707 .577 .707 r
F P
0 g
s
.70158 .66262 m .705 .70085 L .7361 .69854 L p .707 .577 .707 r
F P
0 g
s
.23547 .75398 m .23633 .77293 L .20696 .77631 L p .707 .577 .707 r
F P
0 g
s
.42461 .75022 m .42461 .24833 L .4663 .2437 L p .707 .577 .707 r
F P
0 g
s
.42461 .24833 m .42461 .75022 L .3903 .75809 L p .707 .577 .707 r
F P
0 g
s
.705 .70085 m .70158 .66262 L .6741 .66398 L p .707 .577 .707 r
F P
0 g
s
.2984 .75191 m .29927 .77086 L .26814 .77105 L p .707 .577 .707 r
F P
0 g
s
.26814 .77105 m .26727 .7521 L .2984 .75191 L p .707 .577 .707 r
F P
0 g
s
.6741 .66398 m .67751 .70221 L .705 .70085 L p .707 .577 .707 r
F P
0 g
s
.23633 .77293 m .23547 .75398 L .26727 .7521 L p .707 .577 .707 r
F P
0 g
s
.55518 .24557 m .55518 .74746 L .51129 .74463 L p .707 .577 .707 r
F P
0 g
s
.51129 .74463 m .51129 .24274 L .55518 .24557 L p .707 .577 .707 r
F P
0 g
s
.26727 .7521 m .26814 .77105 L .23633 .77293 L p .707 .577 .707 r
F P
0 g
s
.65264 .64608 m .65609 .59329 L .64353 .58085 L p .707 .577 .707 r
F P
0 g
s
.65609 .59329 m .65264 .64608 L .67364 .65685 L p .707 .577 .707 r
F P
0 g
s
.73186 .76859 m .73272 .75072 L .70159 .7468 L p .707 .577 .707 r
F P
0 g
s
.73272 .75072 m .73186 .76859 L .76367 .76887 L p .707 .577 .707 r
F P
0 g
s
.76367 .76887 m .76453 .751 L .73272 .75072 L p .707 .577 .707 r
F P
0 g
s
.4663 .74558 m .4663 .2437 L .51129 .24274 L p .707 .577 .707 r
F P
0 g
s
.4663 .2437 m .4663 .74558 L .42461 .75022 L p .707 .577 .707 r
F P
0 g
s
.67751 .70221 m .6741 .66398 L .65292 .66426 L p .707 .577 .707 r
F P
0 g
s
.76453 .751 m .76367 .76887 L .79304 .76549 L p .707 .577 .707 r
F P
0 g
s
.79304 .76549 m .7939 .74762 L .76453 .751 L p .707 .577 .707 r
F P
0 g
s
.65292 .66426 m .65634 .70249 L .67751 .70221 L p .707 .577 .707 r
F P
0 g
s
.51129 .24274 m .51129 .74463 L .4663 .74558 L p .707 .577 .707 r
F P
0 g
s
.70073 .76467 m .70159 .7468 L .67419 .73963 L p .707 .577 .707 r
F P
0 g
s
.70159 .7468 m .70073 .76467 L .73186 .76859 L p .707 .577 .707 r
F P
0 g
s
.67419 .73963 m .67333 .7575 L .70073 .76467 L p .707 .577 .707 r
F P
0 g
s
.7939 .74762 m .79304 .76549 L .8171 .75876 L p .707 .577 .707 r
F P
0 g
s
.8171 .75876 m .81796 .74089 L .7939 .74762 L p .707 .577 .707 r
F P
0 g
s
.8371 .59667 m .83364 .64946 L .84072 .63739 L p .707 .577 .707 r
F P
0 g
s
.84072 .63739 m .84418 .5846 L .8371 .59667 L p .707 .577 .707 r
F P
0 g
s
.67333 .7575 m .67419 .73963 L .65319 .7299 L p .707 .577 .707 r
F P
0 g
s
.64353 .58085 m .64008 .63364 L .65264 .64608 L p .707 .577 .707 r
F P
0 g
s
.64008 .63364 m .64353 .58085 L .64065 .56796 L p .707 .577 .707 r
F P
0 g
s
.65634 .70249 m .65292 .66426 L .64014 .66343 L p .707 .577 .707 r
F P
0 g
s
.65319 .7299 m .65233 .74777 L .67333 .7575 L p .707 .577 .707 r
F P
0 g
s
.64014 .66343 m .64355 .70166 L .65634 .70249 L p .707 .577 .707 r
F P
0 g
s
.81796 .74089 m .8171 .75876 L .8335 .74936 L p .707 .577 .707 r
F P
0 g
s
.8335 .74936 m .83436 .73149 L .81796 .74089 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .83681 .68523 L .8436 .68253 L p .707 .577 .707 r
F P
0 g
s
.8436 .68253 m .84019 .6443 L .83339 .647 L p .707 .577 .707 r
F P
0 g
s
.65233 .74777 m .65319 .7299 L .64065 .71857 L p .707 .577 .707 r
F P
0 g
s
.84418 .5846 m .84072 .63739 L .83785 .6245 L p .707 .577 .707 r
F P
0 g
s
.83785 .6245 m .8413 .57171 L .84418 .5846 L p .707 .577 .707 r
F P
0 g
s
.64065 .56796 m .6372 .62075 L .64008 .63364 L p .707 .577 .707 r
F P
0 g
s
.64065 .71857 m .63979 .73644 L .65233 .74777 L p .707 .577 .707 r
F P
0 g
s
.6372 .62075 m .64065 .56796 L .64773 .55589 L p .707 .577 .707 r
F P
0 g
s
.64355 .70166 m .64014 .66343 L .63699 .66158 L p .707 .577 .707 r
F P
0 g
s
.63699 .66158 m .6404 .69981 L .64355 .70166 L p .707 .577 .707 r
F P
0 g
s
.83436 .73149 m .8335 .74936 L .84062 .73821 L p .707 .577 .707 r
F P
0 g
s
.84062 .73821 m .84148 .72034 L .83436 .73149 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63979 .73644 m .64065 .71857 L .63781 .70675 L p .707 .577 .707 r
F P
0 g
s
.84019 .6443 m .8436 .68253 L .84045 .68067 L p .707 .577 .707 r
F P
0 g
s
.84045 .68067 m .83703 .64245 L .84019 .6443 L p .707 .577 .707 r
F P
0 g
s
.8413 .57171 m .83785 .6245 L .82529 .61206 L p .707 .577 .707 r
F P
0 g
s
.82529 .61206 m .82874 .55927 L .8413 .57171 L p .707 .577 .707 r
F P
0 g
s
.64773 .55589 m .64428 .60868 L .6372 .62075 L p .707 .577 .707 r
F P
0 g
s
.63781 .70675 m .63695 .72462 L .63979 .73644 L p .707 .577 .707 r
F P
0 g
s
.64428 .60868 m .64773 .55589 L .66408 .54581 L p .707 .577 .707 r
F P
0 g
s
.6404 .69981 m .63699 .66158 L .64378 .65888 L p .707 .577 .707 r
F P
0 g
s
.64378 .65888 m .6472 .69711 L .6404 .69981 L p .707 .577 .707 r
F P
0 g
s
.38737 .61375 m .39539 .5579 L .36455 .55215 L p .707 .577 .707 r
F P
0 g
s
.39539 .5579 m .38737 .61375 L .41891 .6175 L p .707 .577 .707 r
F P
0 g
s
.41891 .6175 m .42693 .56164 L .39539 .5579 L p .707 .577 .707 r
F P
0 g
s
.84148 .72034 m .84062 .73821 L .83777 .72638 L p .707 .577 .707 r
F P
0 g
s
.83777 .72638 m .83863 .70851 L .84148 .72034 L p .707 .577 .707 r
F P
0 g
s
.42693 .56164 m .41891 .6175 L .44805 .61887 L p .707 .577 .707 r
F P
0 g
s
.44805 .61887 m .45607 .56301 L .42693 .56164 L p .707 .577 .707 r
F P
0 g
s
.35653 .60801 m .36455 .55215 L .33742 .54496 L p .707 .577 .707 r
F P
0 g
s
.36455 .55215 m .35653 .60801 L .38737 .61375 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63695 .72462 m .63781 .70675 L .64493 .69559 L p .707 .577 .707 r
F P
0 g
s
.82874 .55927 m .82529 .61206 L .80428 .60129 L p .707 .577 .707 r
F P
0 g
s
.80428 .60129 m .80773 .5485 L .82874 .55927 L p .707 .577 .707 r
F P
0 g
s
.66408 .54581 m .66063 .5986 L .64428 .60868 L p .707 .577 .707 r
F P
0 g
s
.83703 .64245 m .84045 .68067 L .82766 .67985 L p .707 .577 .707 r
F P
0 g
s
.82766 .67985 m .82425 .64162 L .83703 .64245 L p .707 .577 .707 r
F P
0 g
s
.45607 .56301 m .44805 .61887 L .47195 .61773 L p .707 .577 .707 r
F P
0 g
s
.47195 .61773 m .47997 .56187 L .45607 .56301 L p .707 .577 .707 r
F P
0 g
s
.64493 .69559 m .64407 .71346 L .63695 .72462 L p .707 .577 .707 r
F P
0 g
s
.33742 .54496 m .3294 .60082 L .35653 .60801 L p .707 .577 .707 r
F P
0 g
s
.66063 .5986 m .66408 .54581 L .6881 .53872 L p .707 .577 .707 r
F P
0 g
s
.3294 .60082 m .33742 .54496 L .31665 .53703 L p .707 .577 .707 r
F P
0 g
s
.39499 .6899 m .38712 .65467 L .3566 .65815 L p .707 .577 .707 r
F P
0 g
s
.38712 .65467 m .39499 .6899 L .42615 .68278 L p .707 .577 .707 r
F P
0 g
s
.42615 .68278 m .41828 .64754 L .38712 .65467 L p .707 .577 .707 r
F P
0 g
s
.41828 .64754 m .42615 .68278 L .45489 .6727 L p .707 .577 .707 r
F P
0 g
s
.45489 .6727 m .44703 .63747 L .41828 .64754 L p .707 .577 .707 r
F P
0 g
s
.6472 .69711 m .64378 .65888 L .65986 .6556 L p .707 .577 .707 r
F P
0 g
s
.83863 .70851 m .83777 .72638 L .82524 .71505 L p .707 .577 .707 r
F P
0 g
s
.82524 .71505 m .8261 .69718 L .83863 .70851 L p .707 .577 .707 r
F P
0 g
s
.65986 .6556 m .66327 .69383 L .6472 .69711 L p .707 .577 .707 r
F P
0 g
s
.36446 .69339 m .3566 .65815 L .3297 .65765 L p .707 .577 .707 r
F P
0 g
s
.3566 .65815 m .36446 .69339 L .39499 .6899 L p .707 .577 .707 r
F P
0 g
s
.31665 .53703 m .30863 .59289 L .3294 .60082 L p .707 .577 .707 r
F P
0 g
s
.44703 .63747 m .45489 .6727 L .4784 .66067 L p .707 .577 .707 r
F P
0 g
s
.4784 .66067 m .47054 .62544 L .44703 .63747 L p .707 .577 .707 r
F P
0 g
s
.80773 .5485 m .80428 .60129 L .77688 .59323 L p .707 .577 .707 r
F P
0 g
s
.77688 .59323 m .78033 .54044 L .80773 .5485 L p .707 .577 .707 r
F P
0 g
s
.38694 .718 m .38894 .69936 L .35797 .69458 L p .707 .577 .707 r
F P
0 g
s
.38894 .69936 m .38694 .718 L .41861 .72061 L p .707 .577 .707 r
F P
0 g
s
.41861 .72061 m .42062 .70197 L .38894 .69936 L p .707 .577 .707 r
F P
0 g
s
.48603 .61468 m .48825 .6142 L p .47536 .59393 L .707 .577 .707 r
F P
0 g
s
.48652 .61263 m .48772 .61797 L p .50127 .63552 L .707 .577 .707 r
F P
0 g
s
.48772 .61797 m .49438 .64786 L .49891 .63976 L p .707 .577 .707 r
F P
0 g
s
.49891 .63976 m .50127 .63552 L p .48772 .61797 L .707 .577 .707 r
F P
0 g
s
.47997 .56187 m .47536 .59393 L p .48825 .6142 L .707 .577 .707 r
F P
0 g
s
.47536 .59393 m .47195 .61773 L .48603 .61468 L p .707 .577 .707 r
F P
0 g
s
.48825 .6142 m .49627 .55834 L .47997 .56187 L p .707 .577 .707 r
F P
0 g
s
.68465 .59151 m .6881 .53872 L .71744 .5353 L p .707 .577 .707 r
F P
0 g
s
.6881 .53872 m .68465 .59151 L .66063 .5986 L p .707 .577 .707 r
F P
0 g
s
.64407 .71346 m .64493 .69559 L .66132 .68619 L p .707 .577 .707 r
F P
0 g
s
.42062 .70197 m .41861 .72061 L .44787 .72079 L p .707 .577 .707 r
F P
0 g
s
.44787 .72079 m .44988 .70215 L .42062 .70197 L p .707 .577 .707 r
F P
0 g
s
.35797 .69458 m .35596 .71321 L .38694 .718 L p .707 .577 .707 r
F P
0 g
s
.35596 .71321 m .35693 .7042 L p .33071 .68808 L .707 .577 .707 r
F P
0 g
s
.34841 .6923 m .33071 .68808 L p .35693 .7042 L .707 .577 .707 r
F P
0 g
s
.33756 .69289 m .33245 .67001 L p .30905 .65321 L .707 .577 .707 r
F P
0 g
s
.33245 .67001 m .3297 .65765 L .3225 .6561 L p .707 .577 .707 r
F P
0 g
s
.3225 .6561 m .30905 .65321 L p .33245 .67001 L .707 .577 .707 r
F P
0 g
s
.35693 .7042 m .35797 .69458 L .34841 .6923 L p .707 .577 .707 r
F P
0 g
s
.30863 .59289 m .31665 .53703 L .30428 .52914 L p .707 .577 .707 r
F P
0 g
s
.82425 .64162 m .82766 .67985 L .80649 .68013 L p .707 .577 .707 r
F P
0 g
s
.80649 .68013 m .80307 .6419 L .82425 .64162 L p .707 .577 .707 r
F P
0 g
s
.3297 .65765 m .33756 .69289 L .36446 .69339 L p .707 .577 .707 r
F P
0 g
s
.66132 .68619 m .66046 .70406 L .64407 .71346 L p .707 .577 .707 r
F P
0 g
s
.33071 .68808 m .3287 .70672 L .35596 .71321 L p .707 .577 .707 r
F P
0 g
s
.78033 .54044 m .77688 .59323 L .74576 .58869 L p .707 .577 .707 r
F P
0 g
s
.74576 .58869 m .74922 .53589 L .78033 .54044 L p .707 .577 .707 r
F P
0 g
s
.71398 .58809 m .71744 .5353 L .74922 .53589 L p .707 .577 .707 r
F P
0 g
s
.71744 .5353 m .71398 .58809 L .68465 .59151 L p .707 .577 .707 r
F P
0 g
s
.47054 .62544 m .4784 .66067 L .49438 .64786 L p .707 .577 .707 r
F P
0 g
s
.49438 .64786 m .48652 .61263 L .47054 .62544 L p .707 .577 .707 r
F P
0 g
s
.44988 .70215 m .44787 .72079 L .47186 .71852 L p .707 .577 .707 r
F P
0 g
s
.47186 .71852 m .47387 .69988 L .44988 .70215 L p .707 .577 .707 r
F P
0 g
s
.74922 .53589 m .74576 .58869 L .71398 .58809 L p .707 .577 .707 r
F P
0 g
s
.66327 .69383 m .65986 .6556 L .68364 .65206 L p .707 .577 .707 r
F P
0 g
s
.30428 .52914 m .29626 .585 L .30863 .59289 L p .707 .577 .707 r
F P
0 g
s
.8261 .69718 m .82524 .71505 L .80424 .70532 L p .707 .577 .707 r
F P
0 g
s
.80424 .70532 m .8051 .68746 L .8261 .69718 L p .707 .577 .707 r
F P
0 g
s
.3287 .70672 m .3295 .69934 L p .30985 .68052 L .707 .577 .707 r
F P
0 g
s
.32216 .68498 m .30985 .68052 L p .3295 .69934 L .707 .577 .707 r
F P
0 g
s
.31691 .68845 m .31147 .66407 L p .29668 .64528 L .707 .577 .707 r
F P
0 g
s
.31147 .66407 m .30905 .65321 L .3044 .65023 L p .707 .577 .707 r
F P
0 g
s
.3044 .65023 m .29668 .64528 L p .31147 .66407 L .707 .577 .707 r
F P
0 g
s
.3295 .69934 m .33071 .68808 L .32216 .68498 L p .707 .577 .707 r
F P
0 g
s
.68364 .65206 m .68705 .69028 L .66327 .69383 L p .707 .577 .707 r
F P
0 g
s
.30985 .68052 m .30784 .69916 L .3287 .70672 L p .707 .577 .707 r
F P
0 g
s
.30905 .65321 m .31691 .68845 L .33756 .69289 L p .707 .577 .707 r
F P
0 g
s
.66046 .70406 m .66132 .68619 L .68538 .67947 L p .707 .577 .707 r
F P
0 g
s
.49166 .5905 m .48825 .6142 L .49529 .60869 L p .707 .577 .707 r
F P
0 g
s
.49341 .60029 m .48652 .61263 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.50127 .63552 m .49534 .60891 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49534 .60891 m .49341 .60029 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49627 .55834 m .49166 .5905 L p .49538 .60862 L .707 .577 .707 r
F P
0 g
s
.49529 .60869 m .49538 .60862 L p .49166 .5905 L .707 .577 .707 r
F P
0 g
s
.49538 .60862 m .5034 .55276 L .49627 .55834 L p .707 .577 .707 r
F P
0 g
s
.5034 .55276 m .49538 .60862 L .49535 .60856 L p .707 .577 .707 r
F P
0 g
s
.49493 .60748 m .49262 .60154 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49469 .60662 L .49534 .60892 L .708 .578 .707 r
F
.49341 .60029 m .49534 .60891 L p .49469 .60662 L F P
0 g
s
.49534 .60891 m .49534 .60892 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49535 .60856 m .49493 .60748 L p .49668 .58319 L .707 .577 .707 r
F P
0 g
s
.49053 .58963 m .49341 .60029 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49262 .60154 m .49284 .60001 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49262 .60154 m .48026 .59365 L p .48082 .59231 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .4922 .59959 L .49262 .60154 L .707 .577 .707 r
F
.49839 .62486 m .48602 .61693 L p .4892 .59767 L F P
0 g
s
.49053 .58963 m .49284 .6 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .49262 .60154 L p .4922 .59959 L .707 .577 .707 r
F P
0 g
s
.47816 .58169 m .49053 .58963 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48735 .57695 m .49284 .6 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49284 .60001 L .4922 .59959 L F
.48048 .59209 m .47816 .58169 L .4892 .59767 L F
.48048 .59209 m .48026 .59365 L p .47932 .59175 L F P
0 g
s
.47816 .58169 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45751 .57726 m .47816 .58169 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .46231 .58679 L p .47932 .59175 L .707 .577 .707 r
F P
0 g
s
.46537 .61249 m .45945 .58596 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45946 .58596 m .45751 .57726 L .47456 .59036 L .707 .577 .707 r
F
.45945 .58596 m .45751 .57726 L p .45946 .58596 L F P
0 g
s
.45751 .57726 m .46537 .61249 L .43847 .61199 L p .707 .577 .707 r
F P
0 g
s
.46751 .52986 m .45949 .58572 L .45921 .58565 L p .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .45751 .57726 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43847 .61199 m .43182 .58221 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43182 .58221 m .43061 .57676 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .43847 .61199 L .40794 .61548 L p .707 .577 .707 r
F P
0 g
s
.40794 .61548 m .40008 .58024 L .43061 .57676 L p .707 .577 .707 r
F P
0 g
s
.44038 .52267 m .43236 .57853 L .42821 .57776 L p .707 .577 .707 r
F P
0 g
s
.42821 .57776 m .40151 .57278 L p .41258 .55851 L .707 .577 .707 r
F P
0 g
s
.41258 .55851 m .44038 .52267 L .42821 .57776 L .707 .577 .707 r
F
.45921 .58565 m .43236 .57853 L p .4428 .56408 L F P
0 g
s
.4428 .56408 m .46751 .52986 L .45921 .58565 L .707 .577 .707 r
F
.45945 .58596 m .45945 .58596 L p .45946 .58596 L F P
0 g
s
.45949 .58572 m .46877 .57027 L .47932 .59175 L .707 .577 .707 r
F
.46231 .58679 m .45949 .58572 L p .47932 .59175 L F P
0 g
s
.46877 .57027 m .48048 .59209 L .47932 .59175 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L .47932 .59175 L F
.48602 .61693 m .46537 .61249 L p .47456 .59036 L F P
0 g
s
.48828 .53779 m .50064 .54568 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .48048 .59209 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48828 .53779 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48602 .61693 L p .47706 .59617 L .707 .577 .707 r
F P
0 g
s
.47456 .59036 m .48048 .59209 L .47706 .59617 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L p .48048 .59209 L F P
0 g
s
.48048 .59209 m .47816 .58169 L p .48048 .59209 L .707 .577 .707 r
F P
0 g
s
.48828 .53779 m .48048 .59209 L p .46877 .57027 L .707 .577 .707 r
F P
0 g
s
.48602 .61693 m .48048 .59209 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .6 m .49839 .62486 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .48735 .57695 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49053 .58963 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.50064 .54568 m .49284 .60001 L p .48735 .57695 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49284 .6 L p .49284 .60001 L .708 .578 .707 r
F P
0 g
s
.49626 .61436 m .49284 .60001 L .49469 .60662 L .708 .578 .707 r
F
.49839 .62486 m .49284 .60001 L .49626 .61436 L F
.50064 .54568 m .5034 .55276 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .50064 .54568 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49291 .60024 m .49668 .58319 L .49493 .60748 L .707 .577 .707 r
F
.49668 .58319 m .5034 .55276 L .49535 .60856 L F
.49534 .60892 m .50127 .63552 L .4989 .62675 L p .708 .578 .707 r
F P
0 g
s
.4989 .62675 m .49839 .62486 L p .49534 .60892 L .708 .578 .707 r
F P
0 g
s
.80307 .6419 m .80649 .68013 L .779 .68149 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .77559 .64326 L .80307 .6419 L p .707 .577 .707 r
F P
0 g
s
.68538 .67947 m .68452 .69734 L .66046 .70406 L p .707 .577 .707 r
F P
0 g
s
.29626 .585 m .30428 .52914 L .30153 .52206 L p .707 .577 .707 r
F P
0 g
s
.47387 .69988 m .47186 .71852 L .48823 .71402 L p .707 .577 .707 r
F P
0 g
s
.48823 .71402 m .49024 .69538 L .47387 .69988 L p .707 .577 .707 r
F P
0 g
s
.68705 .69028 m .68364 .65206 L .7128 .6486 L p .707 .577 .707 r
F P
0 g
s
.8051 .68746 m .80424 .70532 L .77683 .69815 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .7479 .6838 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77559 .64326 m .77696 .65859 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77696 .65859 m .779 .68149 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .77769 .68028 L .79428 .68462 L p .707 .577 .707 r
F P
0 g
s
.79428 .68462 m .8051 .68746 L p .79796 .69015 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .79428 .68462 L .79796 .69015 L .707 .577 .707 r
F
.7128 .6486 m .71621 .68683 L .68705 .69028 L p F P
0 g
s
.304 .67681 m .29742 .67263 L p .3083 .69495 L .707 .577 .707 r
F P
0 g
s
.30454 .68051 m .29911 .65617 L p .2938 .63462 L .708 .578 .707 r
F P
0 g
s
.29911 .65617 m .29668 .64528 L .29547 .6408 L p .708 .578 .707 r
F P
0 g
s
.29547 .6408 m .2938 .63462 L p .29911 .65617 L .708 .578 .707 r
F P
0 g
s
.30784 .69916 m .3083 .69495 L p .29742 .67263 L .707 .577 .707 r
F P
0 g
s
.3083 .69495 m .30985 .68052 L .304 .67681 L p .707 .577 .707 r
F P
0 g
s
.68452 .69734 m .68538 .67947 L .71476 .67608 L p .707 .577 .707 r
F P
0 g
s
.30153 .52206 m .29351 .57791 L .29626 .585 L p .707 .577 .707 r
F P
0 g
s
.29742 .67263 m .29541 .69127 L .30784 .69916 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .74448 .64557 L .77559 .64326 L p .707 .577 .707 r
F P
0 g
s
.29668 .64528 m .30454 .68051 L .31691 .68845 L p .707 .577 .707 r
F P
0 g
s
.71621 .68683 m .7128 .6486 L .74448 .64557 L p .707 .577 .707 r
F P
0 g
s
.71476 .67608 m .71389 .69395 L .68452 .69734 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .71621 .68683 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.74561 .65814 m .7479 .6838 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .74656 .67636 L .76501 .67868 L p .707 .577 .707 r
F P
0 g
s
.76501 .67868 m .77769 .68028 L p .76978 .68373 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .76501 .67868 L .76978 .68373 L .707 .577 .707 r
F
.74448 .64557 m .74561 .65814 L p .73996 .65217 L F P
0 g
s
.77769 .68028 m .77683 .69815 L .7457 .69423 L p .707 .577 .707 r
F P
0 g
s
.71389 .69395 m .71476 .67608 L .74656 .67636 L p .707 .577 .707 r
F P
0 g
s
.74656 .67636 m .7457 .69423 L .71389 .69395 L p .707 .577 .707 r
F P
0 g
s
.49024 .69538 m .48823 .71402 L .49538 .70774 L p .707 .577 .707 r
F P
0 g
s
.49538 .70774 m .49739 .6891 L .49024 .69538 L p .707 .577 .707 r
F P
0 g
s
.29351 .57791 m .30153 .52206 L .30865 .51648 L p .707 .577 .707 r
F P
0 g
s
.29541 .69127 m .29742 .67263 L .29465 .66518 L p .707 .577 .707 r
F P
0 g
s
.29465 .66518 m .29264 .68381 L .29541 .69127 L p .707 .577 .707 r
F P
0 g
s
.29264 .68381 m .29465 .66518 L .2994 .661 L p .707 .577 .707 r
F P
0 g
s
.30166 .66986 m .30454 .68051 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.29662 .64728 m .30166 .66986 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.2938 .63462 m .29662 .64728 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.30166 .66986 m .2938 .63462 L .30068 .62228 L p .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30166 .66986 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30068 .62228 m .30418 .63794 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30418 .63794 m .30854 .65752 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30068 .62228 L .31666 .60947 L p .707 .577 .707 r
F P
0 g
s
.31666 .60947 m .32453 .6447 L .30854 .65752 L p .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .30179 .6589 L .31285 .65586 L p .707 .577 .707 r
F P
0 g
s
.31285 .65586 m .31816 .6544 L p .31442 .65911 L .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .31285 .65586 L .31442 .65911 L .707 .577 .707 r
F
.2994 .661 m .30179 .6589 L p .29997 .66384 L F P
0 g
s
.29264 .68381 m .2994 .661 L .29997 .66384 L .707 .577 .707 r
F
.30865 .51648 m .30063 .57233 L .29351 .57791 L p F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49739 .6891 m .49538 .70774 L .4926 .70029 L p .707 .577 .707 r
F P
0 g
s
.4926 .70029 m .49461 .68165 L .49739 .6891 L p .707 .577 .707 r
F P
0 g
s
.30063 .57233 m .30865 .51648 L .32496 .51295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30179 .6589 m .29978 .67753 L .29264 .68381 L p .707 .577 .707 r
F P
0 g
s
.32496 .51295 m .31694 .5688 L .30063 .57233 L p .707 .577 .707 r
F P
0 g
s
.45949 .58572 m .46751 .52986 L .48828 .53779 L p .707 .577 .707 r
F P
0 g
s
.31694 .5688 m .32496 .51295 L .34886 .51181 L p .707 .577 .707 r
F P
0 g
s
.49461 .68165 m .4926 .70029 L .48017 .6924 L p .707 .577 .707 r
F P
0 g
s
.48017 .6924 m .48218 .67376 L .49461 .68165 L p .707 .577 .707 r
F P
0 g
s
.34886 .51181 m .34083 .56767 L .31694 .5688 L p .707 .577 .707 r
F P
0 g
s
.31816 .6544 m .31615 .67304 L .29978 .67753 L p .707 .577 .707 r
F P
0 g
s
.43236 .57853 m .44038 .52267 L .46751 .52986 L p .707 .577 .707 r
F P
0 g
s
.34083 .56767 m .34886 .51181 L .378 .51318 L p .707 .577 .707 r
F P
0 g
s
.32453 .6447 m .31666 .60947 L .34018 .59744 L p .707 .577 .707 r
F P
0 g
s
.48218 .67376 m .48017 .6924 L .45931 .68483 L p .707 .577 .707 r
F P
0 g
s
.45931 .68483 m .46132 .6662 L .48218 .67376 L p .707 .577 .707 r
F P
0 g
s
.40151 .57278 m .40953 .51692 L .44038 .52267 L p .707 .577 .707 r
F P
0 g
s
.378 .51318 m .36998 .56904 L .34083 .56767 L p .707 .577 .707 r
F P
0 g
s
.36998 .56904 m .378 .51318 L .40953 .51692 L p .707 .577 .707 r
F P
0 g
s
.31615 .67304 m .31816 .6544 L .34215 .65213 L p .707 .577 .707 r
F P
0 g
s
.34018 .59744 m .34804 .63267 L .32453 .6447 L p .707 .577 .707 r
F P
0 g
s
.40953 .51692 m .40151 .57278 L .36998 .56904 L p .707 .577 .707 r
F P
0 g
s
.34215 .65213 m .34015 .67077 L .31615 .67304 L p .707 .577 .707 r
F P
0 g
s
.34804 .63267 m .34018 .59744 L .36892 .58737 L p .707 .577 .707 r
F P
0 g
s
.37678 .6226 m .36892 .58737 L .40008 .58024 L p .707 .577 .707 r
F P
0 g
s
.36892 .58737 m .37678 .6226 L .34804 .63267 L p .707 .577 .707 r
F P
0 g
s
.40008 .58024 m .40794 .61548 L .37678 .6226 L p .707 .577 .707 r
F P
0 g
s
.46132 .6662 m .45931 .68483 L .43206 .67834 L p .707 .577 .707 r
F P
0 g
s
.43206 .67834 m .43407 .65971 L .46132 .6662 L p .707 .577 .707 r
F P
0 g
s
.34015 .67077 m .34215 .65213 L .37142 .65231 L p .707 .577 .707 r
F P
0 g
s
.37142 .65231 m .36941 .67095 L .34015 .67077 L p .707 .577 .707 r
F P
0 g
s
.43407 .65971 m .43206 .67834 L .40108 .67356 L p .707 .577 .707 r
F P
0 g
s
.40108 .67356 m .40309 .65492 L .43407 .65971 L p .707 .577 .707 r
F P
0 g
s
.36941 .67095 m .37142 .65231 L .40309 .65492 L p .707 .577 .707 r
F P
0 g
s
.40309 .65492 m .40108 .67356 L .36941 .67095 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001JOolE0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001GOol30002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH7000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P004Goo4@00A7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002goo1P000eYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH0
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000lOol005Aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP<003Uoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004Ool2
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000gOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000eOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000cOol005Aoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0002
FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@000=J
EP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80031oo`00Dgoo00<005YF00000UYF5P0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000;Woo
001COol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF001JEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJ
EP0002eoo`00Dgoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
1`0015YF00<005YF00000`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800005FUH005YFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Goo001DOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eo
o`<000EJEP03001JEUYF00IJEPD000IJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0004
FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00Egoo0P0015YF00<005YFFUH00eYF100000=JEP00
FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00=JEPH0015oo`H0
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FGoo0`0000AJEP00FUIJEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP03001JEP0000<0011oo`<000Yoo`8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo02]oo`00G7oo1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF10004Goo1@002goo0`0000=JEP00FUH015YF00@005YFFUIJEP8002eo
o`00GGoo00@005YFFUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH00UYF0`003Woo1@003Woo0P001EYF00@005YFFUIJEP8002eo
o`00Fgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YF10001EYF00@005YF000000aoo`D0011oo`8000=JEP04001JEUYFFUH2
000]Ool005Yoo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP04001JEUYFFUH3000:Ool3
000@Ool500000eYF001JEP02FUH2000]Ool004Mooa@000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPl000=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF1P004Woo1@001EYF
0P000eYF00<007ooOol0;7oo000nOol90004FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF2@0015YF00@005YFFUIJEPP0009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH00UYF4P0035YF00@005YFFUH002ioo`00=Woo200015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01000
1UYF00<005YFFUH0200000=JEP00FUH00P000UYF10000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF01QJEP<002ioo`00<Goo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH015YF00<005YFFUH015YF1P002EYF00<005YFFUH02EYF0P00
1EYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001J
EP0002ioo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P001EYF00<005YFFUH015YF00<005YFFUH010001EYF10001UYF00<005YFFUH025YF0`001EYF
00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001JEP00
02ioo`00;Goo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00MJEP04
001JEUYF0005FUH01000FUH000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
01QJEP03001JEP0002ioo`00;7oo00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000=JEP04001JEUYF0005FUH5
0005FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF01AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH0
0003FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF
00H005YFFUH005YF0003FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00eYF0P001UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00eJEP03
001JEUYF00AJEP07001JEUYFOol005YF0000;Woo000/Ool00`00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF0`000UYF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00<00003FUH005YF00EJEP03001JEUYF00=JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUHF000_Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF
0`001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP<000QJEP03001JEUYF00=J
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20003FUH20003FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<0009JEP03001JEP00
0100009JEP@00003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH200000eYF000000060003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`0015YF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20007FUH20007FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYFFUHA0004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1eYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH00`00FUH00002FUH500000eYF001JEP06
FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH60006FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF00@005YFFUIJEQ0000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF00000eYF00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000EJEP00FUIJEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEP0000@0009JEP03001JEUYF00AJEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF01T002eoo`00;Goo00<005YF0000
0UYF0P001EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP@000EJEP@000AJEP05001JEUYFFUH00004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEPD0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP040006FUH00`00
FUIJEP04000]Ool002eoo`03001JEP0000800003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYFFUH50002FUH20007FUH00`00FUIJEP04FUH900000eYF001JEP0:FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000AJEP<0035oo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP800003FUH005YF00IJEP03001JEUYF
009JEPL000EJEP03001JEUYF00UJEP03001JEUYF008000=JEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00;Goo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF3`00
0UYF10001UYF00<005YFFUH02EYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00=JEPh000IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001J
EUYF009JEPT000EJEP03001JEUYF00UJEP04001JEUYFFUH50004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF1P0000=JEP00FUH00eYF
20000goo1P001UYF00<005YFFUH00UYF0P00<Woo000]Ool00eYFOol00002FUH00`00FUIJEP03FUH<
0009Ool40002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHE0003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000eYF00<005YF00003`004Goo10000UYF00<005YFFUH00eYF0P00<Goo000]Ool00eYF001JEP02
FUH00`00FUH00003000IOol40006FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF0P000eYF00<005YFFUH00UYF00@005YFFUH0
01Uoo`<000EJEP04001JEP00000_Ool002eoo`03FUH005YF009JEP80025oo`@0009JEP04001JEUYF
FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYF
FUH005YF001JEP8000IJEP05001JEUYFFUH00002FUH00`00Oomoo`0JOol20003FUH01@00FUIJEUYF
0000;Woo000]Ool01EYF001JEUYF00009goo0`001EYF00<005YF00000`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF00<0
05YF00007Woo0P0000=JEP00FUH00UYF00<007ooOol0;7oo000/Ool00`00FUH00002000[Ool20003
FUH01P00FUIJEUYF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20009Ool3000EOol20003FUH2000]Ool002aoo`04
001JEP00000^Ool01000FUIJEP000eYF00@005YFFUH0009JEQh000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008Ool5000FOol00`00FUIJEP02000]Ool002aoo`@001Qoo`<001Aoo`<000=JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH00UYF00<007oo
Ool01goo1@005goo1000;Goo000/Ool300000eYF001oo`0EOol5000EOol01@00FUIJEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800004FUH005YF0007FUH01000FUIJEP00
2Woo1@006Goo0P00;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0COol5000FOol01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000MJEP<000aoo`<001Uo
o`8002ioo`00;7oo0P000eYF0`004goo1@005goo00<005YF00000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YFFUIJEP0000=JEP<000EJEP8002Uoo`<002ioo`00;7oo0P000eYF00<005YFFUH0
0P004Woo0`006Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00800003FUH0000002Uoo`800003FUH0000002ioo`00;7oo0P000eYF00<005YFFUH00UYF
0`00:Goo0P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJ
EP02FUH3000VOol30003FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00005FUH01000FUH00000
9Woo00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00FUH0
0003000NOol400000eYF001JEP02FUH2000_Ool002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF
0`008Goo0P0015YF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP`000aJEPT000QJ
EP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH7000BOol5
0005FUH01@00FUIJEUYF0000<7oo000^Ool01000FUIJEP001EYF00<005YFFUH015YF10001Goo4@00
0goo100000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@002eYF00<005YF
FUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002mo
o`03001JEP0000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF
001JEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP050006FUH01000FUIJEUYF0P001EYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<7oo0P001EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01`000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00@005YFFUIJEP8000IJEP@000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<Goo00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF0000009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20006
FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000`00=Woo000aOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEUYF008000IJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000goo4P00?goo
000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEPH000=JEP03001JEUYF00=JEP06001JEUYF001JEP00E7oo000]
Ool00`00FUH00004FUH00`00FUIJEP02FUH60008FUH50004FUH20006FUH20005FUH500000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH70002FUH01P00FUIJEP00FUH005Aoo`00
;Goo00<005YF000015YF00<005YF000010000eYF00<005YFFUH01UYF1@0015YF0P001UYF00<005YF
FUH00eYF0`000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0`001eYF00<005YFFUH01000
00=JEP000000EGoo000]Ool00`00FUH00002FUH40005Ool200000eYF001JEP07FUH50004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000IJEP03001JEUYF00=JEP@005Eoo`00;Goo00<005YF00000P000UYF3`00
15YF10001EYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF009JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EGoo000]Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH00UYF1@00
0eYF00AooeYFFUH000=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=JEP03001JEUYF
00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH90004FUH00`00FUIJEP04FUH01000FUH000000Woo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF0P0015YF1P0015YF00@005YFFUH005Eoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP<0
0004FUH005YFFUH2001DOol0031oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPL000aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP020003FUH00`00Oomoo`1BOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPT0
01Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000MJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001oo`1C
Ool003]ooa80021oo`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPT000AJEP03001JEUYF00=JEP03001JEUYF00L005Aoo`00Kgoo0`00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF
100027oo3@000Woo0`0000=JEP000000Dgoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000DOol20002FUH01000FUIJEP00Dgoo001iOol;0006FUH0
0`00FUIJEP0:FUH00`00FUIJEP04FUH70004Ool5000BOol20005FUH00`00FUH0001COol008AooaX0
00]oo`D0011oo`800003FUH005YF00AJEP8005Aoo`00Sgoo0P006Goo0`003goo0P000eYF00<005YF
FUH00eYF00<007ooOol0Dgoo002?Ool3000WOol30006FUH00`00FUIJEP02001FOol008moo`03001J
EUYF00@001moo`@00003FUH005YF00IJEP<005Qoo`00Sgoo0P000UYF00<005YFFUH01`004Goo1`00
1EYF00<005YFFUH015YF0P00FWoo002@Ool01000FUIJEP001EYF00@005YFFUIJEQ4000AJEP03001J
EUYF00IJEP04001JEUYFFUH2001LOol0091oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002AOol30005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol009=oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@006=oo`00UGoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Igoo002HOolG001^Ool00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63086 .75143 m .61796 .69895 L .58691 .70655 L p .707 .577 .707 r
F P
0 g
s
.61796 .69895 m .63086 .75143 L .65959 .74084 L p .707 .577 .707 r
F P
0 g
s
.65959 .74084 m .64669 .68836 L .61796 .69895 L p .707 .577 .707 r
F P
0 g
s
.59981 .75903 m .58691 .70655 L .55658 .71042 L p .707 .577 .707 r
F P
0 g
s
.58691 .70655 m .59981 .75903 L .63086 .75143 L p .707 .577 .707 r
F P
0 g
s
.64669 .68836 m .65959 .74084 L .68318 .72828 L p .707 .577 .707 r
F P
0 g
s
.68318 .72828 m .67029 .6758 L .64669 .68836 L p .707 .577 .707 r
F P
0 g
s
.55996 .78187 m .58941 .79288 L p .5817 .77138 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .55658 .71042 L .56309 .75438 L .707 .577 .707 r
F
.56863 .75944 m .56851 .75894 L p .56798 .75885 L F P
0 g
s
.56851 .75894 m .55658 .71042 L p .56798 .75885 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .52994 .71016 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .56863 .75944 L p .59981 .75903 L .707 .577 .707 r
F P
0 g
s
.5817 .77138 m .57771 .76025 L .56863 .75944 L .707 .577 .707 r
F
.56798 .75885 m .55996 .78187 L p .5817 .77138 L F P
0 g
s
.58508 .76091 m .59981 .75903 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.58941 .79288 m .60198 .75682 L .57253 .74581 L p .707 .577 .707 r
F P
0 g
s
.56863 .75944 m .56948 .7629 L .58508 .76091 L p .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .56798 .75885 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.57771 .76025 m .57253 .74581 L .56863 .75944 L .707 .577 .707 r
F
.55996 .78187 m .56798 .75885 L p .55262 .75603 L F P
0 g
s
.53402 .77088 m .55996 .78187 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54001 .75371 m .53402 .77088 L p .54715 .76039 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54067 .75383 L .54715 .76039 L .707 .577 .707 r
F
.54067 .75383 m .54001 .75371 L .54715 .76039 L F
.52994 .71016 m .50959 .70582 L p .53334 .74641 L F P
0 g
s
.54015 .75331 m .52994 .71016 L .53334 .74641 L .707 .577 .707 r
F
.54067 .75383 m .54057 .75344 L p .54015 .75331 L F P
0 g
s
.54057 .75344 m .52994 .71016 L p .54015 .75331 L .707 .577 .707 r
F P
0 g
s
.53402 .77088 m .54015 .75331 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.52994 .71016 m .54067 .75383 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .54015 .75331 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54001 .75371 L p .54067 .75383 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54015 .75331 L .54067 .75383 L .707 .577 .707 r
F
.54283 .76264 m .54067 .75383 L p .53334 .74641 L F P
0 g
s
.51415 .76098 m .53402 .77088 L p .5335 .76757 L .707 .577 .707 r
F P
0 g
s
.5335 .76757 m .53075 .75029 L .52463 .75423 L .707 .577 .707 r
F
.5335 .76757 m .52463 .75423 L .51415 .76098 L F
.50959 .70582 m .49753 .69781 L p .51455 .73905 L F P
0 g
s
.5193 .7462 m .50959 .70582 L .51455 .73905 L .707 .577 .707 r
F
.51964 .74672 m .51955 .74637 L p .5193 .7462 L F P
0 g
s
.51955 .74637 m .50959 .70582 L p .5193 .7462 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .5193 .7462 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50959 .70582 m .51964 .74672 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.52672 .72493 m .5193 .7462 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.5193 .7462 m .51917 .74657 L p .51964 .74672 L .707 .577 .707 r
F P
0 g
s
.53075 .75029 m .5193 .7462 L .51964 .74672 L .707 .577 .707 r
F
.51917 .74657 m .51415 .76098 L p .53075 .75029 L F P
0 g
s
.52249 .7583 m .51964 .74672 L p .51455 .73905 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .51443 .74311 L .50961 .74709 L .707 .577 .707 r
F
.50227 .75316 m .51275 .76007 L p .50961 .74709 L F P
0 g
s
.51275 .76007 m .51415 .76098 L p .50961 .74709 L .707 .577 .707 r
F P
0 g
s
.51686 .74465 m .5121 .73312 L .5076 .73877 L .707 .577 .707 r
F
.49753 .69781 m .50751 .73842 L p .5121 .73312 L F P
0 g
s
.50751 .73842 m .5076 .73877 L p .5121 .73312 L .707 .577 .707 r
F P
0 g
s
.50734 .73861 m .50227 .75316 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.5076 .73877 m .51043 .75029 L p .51686 .74465 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .49753 .69781 L .50596 .73201 L .705 .576 .708 r
F
.5076 .73877 m .50751 .73842 L p .50747 .73824 L F P
0 g
s
.50751 .73842 m .49753 .69781 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.50734 .73861 m .50747 .73824 L p .50516 .74113 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .51484 .7171 L p .50705 .73644 L .707 .577 .707 r
F P
0 g
s
.50713 .73679 m .50747 .73824 L .50596 .73201 L .705 .576 .708 r
F
.51484 .7171 m .50747 .73824 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .50734 .73861 L p .5076 .73877 L .707 .577 .707 r
F P
0 g
s
.51443 .74311 m .50747 .73824 L .5076 .73877 L .707 .577 .707 r
F
.51484 .7171 m .51214 .71211 L p .50667 .73484 L F P
0 g
s
.50705 .73644 m .51484 .7171 L .50667 .73484 L .707 .577 .707 r
F
.50713 .73679 m .50596 .73201 L .50658 .73443 L .705 .576 .708 r
F
.49956 .74816 m .50227 .75316 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50207 .6742 L p .50664 .72587 L .707 .577 .707 r
F P
0 g
s
.51214 .71211 m .50582 .73021 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50582 .73021 L .50572 .73077 L .707 .577 .707 r
F
.52672 .72493 m .51484 .7171 L p .51443 .74311 L F P
0 g
s
.51214 .71211 m .51886 .71043 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50572 .73077 L p .50582 .73021 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50582 .73021 L .50695 .72931 L .707 .577 .707 r
F
.50572 .73077 m .49494 .68691 L p .50664 .72587 L F P
0 g
s
.50582 .73021 m .50568 .73061 L p .50572 .73077 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50192 .71532 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50596 .73201 m .50432 .72525 L .50784 .73939 L .705 .576 .708 r
F
.50192 .71532 m .50562 .73037 L p .50432 .72525 L F P
0 g
s
.50562 .73037 m .50784 .73939 L p .50432 .72525 L .705 .576 .708 r
F P
0 g
s
.50582 .73021 m .51214 .71211 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .50784 .73939 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.51886 .71043 m .51453 .72285 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .51419 .7235 L p .51453 .72285 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51886 .71043 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51517 .72267 m .51453 .72285 L .51522 .72153 L .707 .577 .707 r
F
.51497 .72668 m .51453 .72285 L .51517 .72267 L F
.51886 .71043 m .53435 .71224 L p .52914 .7186 L F P
0 g
s
.51419 .7235 m .51497 .72668 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .51043 .75029 L p .50713 .73679 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .5076 .73877 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .50747 .73824 L .50713 .73679 L .705 .576 .708 r
F
.51822 .66092 m .53112 .7134 L .51497 .72668 L p .707 .577 .707 r
F P
0 g
s
.50629 .74649 m .51453 .72285 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51435 .72337 L p .51419 .7235 L .707 .577 .707 r
F P
0 g
s
.51078 .72624 m .51453 .72285 L .51419 .7235 L .707 .577 .707 r
F
.50207 .6742 m .51822 .66092 L p .51522 .72153 L F P
0 g
s
.51419 .7235 m .50207 .6742 L p .51522 .72153 L .707 .577 .707 r
F P
0 g
s
.50207 .6742 m .51419 .7235 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50658 .73444 L .49956 .74816 L .707 .577 .707 r
F
.49753 .69781 m .49494 .68691 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50658 .73444 m .50568 .73061 L .49956 .74816 L .707 .577 .707 r
F
.50713 .73679 m .50658 .73443 L .50784 .73939 L .705 .576 .708 r
F
.50747 .73824 m .50705 .73644 L .50516 .74113 L .707 .577 .707 r
F
.50516 .74113 m .50705 .73644 L .50667 .73484 L F
.50227 .75316 m .50734 .73861 L p .50516 .74113 L F P
0 g
s
.50629 .74649 m .49956 .74816 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51435 .72337 m .50629 .74649 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50663 .73435 m .50582 .73021 L .51078 .72624 L .707 .577 .707 r
F
.49956 .74816 m .50568 .73061 L p .50663 .73435 L F P
0 g
s
.50568 .73061 m .50582 .73021 L p .50663 .73435 L .707 .577 .707 r
F P
0 g
s
.50695 .72931 m .50582 .73021 L .50664 .72587 L .707 .577 .707 r
F
.51043 .75029 m .52249 .7583 L p .51686 .74465 L F P
0 g
s
.5193 .7462 m .52672 .72493 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.52249 .7583 m .54283 .76264 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.51964 .74672 m .52249 .7583 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .52672 .72493 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54659 .73482 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54283 .76264 m .56948 .7629 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54067 .75383 m .54283 .76264 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .54659 .73482 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.56948 .7629 m .56863 .75944 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .57253 .74581 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.60198 .75682 m .58941 .79288 L .6195 .80283 L p .707 .577 .707 r
F P
0 g
s
.6195 .80283 m .63207 .76678 L .60198 .75682 L p .707 .577 .707 r
F P
0 g
s
.63207 .76678 m .6195 .80283 L .64728 .81075 L p .707 .577 .707 r
F P
0 g
s
.64728 .81075 m .65985 .7747 L .63207 .76678 L p .707 .577 .707 r
F P
0 g
s
.67029 .6758 m .68318 .72828 L .69934 .715 L p .707 .577 .707 r
F P
0 g
s
.69934 .715 m .68644 .66252 L .67029 .6758 L p .707 .577 .707 r
F P
0 g
s
.65985 .7747 m .64728 .81075 L .67003 .81587 L p .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .6826 .77982 L .65985 .7747 L p .707 .577 .707 r
F P
0 g
s
.60058 .85912 m .59735 .84127 L .56666 .84374 L p .707 .577 .707 r
F P
0 g
s
.59735 .84127 m .60058 .85912 L .63198 .85316 L p .707 .577 .707 r
F P
0 g
s
.63198 .85316 m .62875 .83531 L .59735 .84127 L p .707 .577 .707 r
F P
0 g
s
.62875 .83531 m .63198 .85316 L .66102 .84432 L p .707 .577 .707 r
F P
0 g
s
.66102 .84432 m .65779 .82646 L .62875 .83531 L p .707 .577 .707 r
F P
0 g
s
.56666 .84374 m .5699 .86159 L .60058 .85912 L p .707 .577 .707 r
F P
0 g
s
.5699 .86159 m .56666 .84374 L .5397 .8425 L p .707 .577 .707 r
F P
0 g
s
.68644 .66252 m .69934 .715 L .70647 .70229 L p .707 .577 .707 r
F P
0 g
s
.70647 .70229 m .69357 .64981 L .68644 .66252 L p .707 .577 .707 r
F P
0 g
s
.65779 .82646 m .66102 .84432 L .68486 .83344 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .68163 .81559 L .65876 .82602 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .70117 .82161 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68163 .81559 m .68175 .81626 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68175 .81626 m .68486 .83344 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .69793 .80376 L .68238 .81504 L p .707 .577 .707 r
F P
0 g
s
.68238 .81504 m .68163 .81559 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .68238 .81504 L .68203 .81572 L .707 .577 .707 r
F
.69225 .81601 m .70482 .77995 L .69999 .78116 L p F P
0 g
s
.69999 .78116 m .6981 .78163 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69225 .81601 m .69999 .78116 L .6973 .78633 L .707 .577 .707 r
F
.68553 .81768 m .69225 .81601 L p .6973 .78633 L F P
0 g
s
.6981 .78163 m .69474 .79125 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69474 .79125 m .68553 .81768 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .68553 .81768 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.6826 .77982 m .67666 .79686 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.67666 .79686 m .67003 .81587 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.65876 .82602 m .65779 .82646 L p .65839 .82662 L .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .65876 .82602 L .65839 .82662 L .707 .577 .707 r
F
.5397 .8425 m .54293 .86035 L .5699 .86159 L p F P
0 g
s
.68553 .81768 m .6981 .78163 L .6826 .77982 L p .707 .577 .707 r
F P
0 g
s
.54293 .86035 m .5397 .8425 L .51909 .83767 L p .707 .577 .707 r
F P
0 g
s
.51909 .83767 m .52233 .85552 L .54293 .86035 L p .707 .577 .707 r
F P
0 g
s
.69357 .64981 m .70647 .70229 L .70388 .6914 L p .705 .576 .708 r
F P
0 g
s
.70388 .6914 m .69098 .63892 L .69357 .64981 L p .705 .576 .708 r
F P
0 g
s
.52233 .85552 m .51909 .83767 L .50686 .82971 L p .707 .577 .707 r
F P
0 g
s
.69793 .80376 m .70117 .82161 L .70834 .80997 L p .707 .577 .707 r
F P
0 g
s
.70834 .80997 m .70511 .79212 L .69793 .80376 L p .707 .577 .707 r
F P
0 g
s
.50686 .82971 m .5101 .84756 L .52233 .85552 L p .707 .577 .707 r
F P
0 g
s
.48764 .82178 m .48764 .31989 L .44383 .31698 L p .707 .577 .707 r
F P
0 g
s
.5101 .84756 m .50686 .82971 L .5042 .8194 L p .707 .578 .707 r
F P
0 g
s
.5042 .8194 m .50744 .83725 L .5101 .84756 L p .707 .578 .707 r
F P
0 g
s
.50744 .83725 m .5042 .8194 L .51138 .80776 L p .707 .577 .707 r
F P
0 g
s
.51138 .80776 m .51461 .82562 L .50744 .83725 L p .707 .577 .707 r
F P
0 g
s
.53435 .71224 m .52178 .7483 L .50629 .74649 L p .707 .577 .707 r
F P
0 g
s
.53112 .7134 m .51822 .66092 L .54182 .64837 L p .707 .577 .707 r
F P
0 g
s
.51461 .82562 m .51138 .80776 L .52768 .79593 L p .707 .577 .707 r
F P
0 g
s
.52178 .7483 m .53435 .71224 L .55711 .71736 L p .707 .577 .707 r
F P
0 g
s
.52768 .79593 m .53092 .81378 L .51461 .82562 L p .707 .577 .707 r
F P
0 g
s
.55711 .71736 m .54453 .75341 L .52178 .7483 L p .707 .577 .707 r
F P
0 g
s
.53092 .81378 m .52768 .79593 L .55152 .78506 L p .707 .577 .707 r
F P
0 g
s
.55152 .78506 m .55476 .80291 L .53092 .81378 L p .707 .577 .707 r
F P
0 g
s
.48764 .31989 m .48764 .82178 L .53266 .82092 L p .707 .577 .707 r
F P
0 g
s
.54182 .64837 m .55472 .70085 L .53112 .7134 L p .707 .577 .707 r
F P
0 g
s
.53266 .82092 m .53266 .31903 L .48764 .31989 L p .707 .577 .707 r
F P
0 g
s
.55472 .70085 m .54182 .64837 L .57055 .63777 L p .707 .577 .707 r
F P
0 g
s
.57055 .63777 m .58345 .69025 L .55472 .70085 L p .707 .577 .707 r
F P
0 g
s
.54453 .75341 m .55711 .71736 L .58489 .72528 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .57231 .76134 L .54453 .75341 L p .707 .577 .707 r
F P
0 g
s
.55476 .80291 m .55152 .78506 L .58056 .77621 L p .707 .577 .707 r
F P
0 g
s
.58056 .77621 m .5838 .79406 L .55476 .80291 L p .707 .577 .707 r
F P
0 g
s
.53266 .31903 m .53266 .82092 L .57447 .81636 L p .707 .577 .707 r
F P
0 g
s
.58345 .69025 m .57055 .63777 L .6016 .63017 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .61498 .73524 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.57231 .76134 m .58036 .73825 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.58036 .73825 m .58489 .72528 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.63193 .62631 m .64483 .67879 L .6145 .68265 L p .707 .577 .707 r
F P
0 g
s
.6145 .68265 m .6016 .63017 L .63193 .62631 L p .707 .577 .707 r
F P
0 g
s
.6016 .63017 m .6145 .68265 L .58345 .69025 L p .707 .577 .707 r
F P
0 g
s
.67036 .75724 m .65779 .79329 L .63186 .7823 L p .707 .577 .707 r
F P
0 g
s
.63186 .7823 m .64443 .74625 L .67036 .75724 L p .707 .577 .707 r
F P
0 g
s
.64443 .74625 m .63186 .7823 L .61088 .77446 L p .707 .577 .707 r
F P
0 g
s
.61088 .77446 m .6024 .77129 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61131 .76598 m .64443 .74625 L .61088 .77446 L .707 .577 .707 r
F
.64483 .67879 m .63193 .62631 L .65857 .62656 L p F P
0 g
s
.65779 .79329 m .66927 .76036 L p .69024 .76713 L .707 .577 .707 r
F P
0 g
s
.64588 .78563 m .64379 .77411 L p .66961 .76902 L .707 .577 .707 r
F P
0 g
s
.64379 .77411 m .64265 .76778 L .65452 .76832 L p .707 .577 .707 r
F P
0 g
s
.65452 .76832 m .66961 .76902 L p .64379 .77411 L .707 .577 .707 r
F P
0 g
s
.66927 .76036 m .67036 .75724 L .67281 .75846 L p .707 .577 .707 r
F P
0 g
s
.67281 .75846 m .69024 .76713 L p .66927 .76036 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .64443 .74625 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.6024 .77129 m .61252 .74227 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61252 .74227 m .61498 .73524 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.64265 .76778 m .64588 .78563 L .6152 .78811 L p .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .64371 .28465 L .63542 .29362 L p .707 .577 .707 r
F P
0 g
s
.63542 .29362 m .63286 .2964 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .63542 .29362 L .63359 .3295 L .707 .577 .707 r
F
.6152 .78811 m .61196 .77026 L .64265 .76778 L p F P
0 g
s
.63286 .79829 m .64371 .78653 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .2964 m .63286 .34386 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .34386 m .63286 .79829 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .6024 .77129 L .57231 .76134 L p .707 .577 .707 r
F P
0 g
s
.5838 .79406 m .58056 .77621 L .61196 .77026 L p .707 .577 .707 r
F P
0 g
s
.61196 .77026 m .6152 .78811 L .5838 .79406 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .63286 .79829 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .30668 m .609 .36022 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .36022 m .609 .80857 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.57447 .81636 m .57447 .31448 L .53266 .31903 L p .707 .577 .707 r
F P
0 g
s
.69098 .63892 m .70388 .6914 L .69182 .68339 L p .707 .577 .707 r
F P
0 g
s
.69182 .68339 m .67892 .63091 L .69098 .63892 L p .707 .577 .707 r
F P
0 g
s
.44383 .81887 m .44383 .31698 L .40553 .31058 L p .707 .577 .707 r
F P
0 g
s
.44383 .31698 m .44383 .81887 L .48764 .82178 L p .707 .577 .707 r
F P
0 g
s
.70482 .77995 m .69225 .81601 L .68954 .81101 L p .707 .577 .707 r
F P
0 g
s
.68954 .81101 m .70181 .77583 L p .70482 .77995 L .707 .577 .707 r
F P
0 g
s
.70211 .77496 m .68954 .81101 L .67767 .80318 L p .707 .577 .707 r
F P
0 g
s
.69345 .7917 m .69274 .78779 L p .70245 .78181 L .707 .577 .707 r
F P
0 g
s
.67767 .80318 m .68999 .76786 L p .70211 .77496 L .707 .577 .707 r
F P
0 g
s
.68999 .76786 m .69024 .76713 L .69069 .76742 L p .707 .577 .707 r
F P
0 g
s
.69069 .76742 m .70211 .77496 L p .68999 .76786 L .707 .577 .707 r
F P
0 g
s
.69024 .76713 m .67767 .80318 L .65779 .79329 L p .707 .577 .707 r
F P
0 g
s
.67285 .78687 m .67148 .77934 L p .69022 .77385 L .707 .577 .707 r
F P
0 g
s
.67148 .77934 m .66961 .76902 L .68304 .77217 L p .707 .577 .707 r
F P
0 g
s
.68304 .77217 m .69022 .77385 L p .67148 .77934 L .707 .577 .707 r
F P
0 g
s
.69274 .78779 m .69022 .77385 L .69899 .77956 L p .707 .577 .707 r
F P
0 g
s
.69899 .77956 m .70245 .78181 L p .69274 .78779 L .707 .577 .707 r
F P
0 g
s
.70181 .77583 m .70211 .77496 L .70226 .77523 L p .707 .577 .707 r
F P
0 g
s
.70226 .77523 m .70482 .77995 L p .70181 .77583 L .707 .577 .707 r
F P
0 g
s
.57447 .31448 m .57447 .81636 L .609 .80857 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .609 .30668 L .57447 .31448 L p .707 .577 .707 r
F P
0 g
s
.70511 .79212 m .70834 .80997 L .70568 .79966 L p .707 .578 .707 r
F P
0 g
s
.70568 .79966 m .70245 .78181 L .70511 .79212 L p .707 .578 .707 r
F P
0 g
s
.40553 .81247 m .40553 .31058 L .37647 .30131 L p .707 .577 .707 r
F P
0 g
s
.40553 .31058 m .40553 .81247 L .44383 .81887 L p .707 .577 .707 r
F P
0 g
s
.25511 .69095 m .24951 .63358 L .21847 .63628 L p .707 .577 .707 r
F P
0 g
s
.24951 .63358 m .25511 .69095 L .28679 .68773 L p .707 .577 .707 r
F P
0 g
s
.28679 .68773 m .28119 .63036 L .24951 .63358 L p .707 .577 .707 r
F P
0 g
s
.67892 .63091 m .69182 .68339 L .67147 .67904 L p .707 .577 .707 r
F P
0 g
s
.67147 .67904 m .65857 .62656 L .67892 .63091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21847 .63628 m .22408 .69365 L .25511 .69095 L p .707 .577 .707 r
F P
0 g
s
.28119 .63036 m .28679 .68773 L .31602 .6843 L p .707 .577 .707 r
F P
0 g
s
.31602 .6843 m .31042 .62694 L .28119 .63036 L p .707 .577 .707 r
F P
0 g
s
.22408 .69365 m .21847 .63628 L .19113 .6382 L p .707 .577 .707 r
F P
0 g
s
.19113 .6382 m .19673 .69556 L .22408 .69365 L p .707 .577 .707 r
F P
0 g
s
.63286 .79829 m .63286 .2964 L .609 .30668 L p .707 .577 .707 r
F P
0 g
s
.31042 .62694 m .31602 .6843 L .33994 .681 L p .707 .577 .707 r
F P
0 g
s
.33994 .681 m .33434 .62364 L .31042 .62694 L p .707 .577 .707 r
F P
0 g
s
.70245 .78181 m .70568 .79966 L .69345 .7917 L p .707 .577 .707 r
F P
0 g
s
.19673 .69556 m .19113 .6382 L .17015 .63914 L p .707 .577 .707 r
F P
0 g
s
.65857 .62656 m .67147 .67904 L .64483 .67879 L p .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .25373 .78052 L .23921 .78123 L p .707 .577 .707 r
F P
0 g
s
.23074 .78642 m .23829 .78179 L .22265 .78204 L .707 .577 .707 r
F
.23776 .7813 m .22265 .78204 L p .23829 .78179 L F P
0 g
s
.22265 .78204 m .22404 .80112 L .25512 .7996 L p .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .22265 .78204 L .20359 .78225 L p .707 .577 .707 r
F P
0 g
s
.20359 .78225 m .19529 .78235 L p .19958 .78515 L .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .20359 .78225 L .19958 .78515 L .707 .577 .707 r
F
.23921 .78123 m .23776 .7813 L p .23829 .78179 L F P
0 g
s
.25512 .7996 m .23921 .78123 L .23074 .78642 L .707 .577 .707 r
F
.22085 .7923 m .25181 .79974 L p .22861 .76424 L F P
0 g
s
.22642 .7609 m .22543 .76653 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22543 .76653 m .22085 .7923 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22085 .7923 m .22493 .76931 L p .19899 .7486 L .707 .577 .707 r
F P
0 g
s
.22493 .76931 m .22642 .7609 L .20627 .75187 L p .707 .577 .707 r
F P
0 g
s
.20627 .75187 m .19899 .7486 L p .22493 .76931 L .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .28688 .79701 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25373 .78052 m .25469 .79373 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25469 .79373 m .25512 .7996 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .28642 .79077 L p .25373 .78052 L .707 .577 .707 r
F P
0 g
s
.28642 .79077 m .28548 .77793 L .26788 .77936 L p .707 .577 .707 r
F P
0 g
s
.26788 .77936 m .25373 .78052 L p .28642 .79077 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .25665 .77245 L p .22642 .7609 L .707 .577 .707 r
F P
0 g
s
.25665 .77245 m .25738 .76834 L .24524 .76542 L p .707 .577 .707 r
F P
0 g
s
.24524 .76542 m .22642 .7609 L p .25665 .77245 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .3162 .79361 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28548 .77793 m .28675 .79528 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28675 .79528 m .28688 .79701 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.3162 .79361 m .31555 .78473 L p .28548 .77793 L .707 .577 .707 r
F P
0 g
s
.31555 .78473 m .31481 .77453 L .2978 .7765 L p .707 .577 .707 r
F P
0 g
s
.2978 .7765 m .28548 .77793 L p .31555 .78473 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .28848 .77218 L p .25738 .76834 L .707 .577 .707 r
F P
0 g
s
.28848 .77218 m .28883 .7702 L .28355 .76989 L p .707 .577 .707 r
F P
0 g
s
.28355 .76989 m .25738 .76834 L p .28848 .77218 L .707 .577 .707 r
F P
0 g
s
.31481 .77453 m .3162 .79361 L .3185 .79324 L p .707 .577 .707 r
F P
0 g
s
.3185 .79324 m .34022 .78973 L p .3263 .7814 L .707 .577 .707 r
F P
0 g
s
.3263 .7814 m .31481 .77453 L .3185 .79324 L .707 .577 .707 r
F
.34022 .78973 m .33933 .7775 L p .31481 .77453 L F P
0 g
s
.33933 .7775 m .33883 .77064 L .32719 .77252 L p .707 .577 .707 r
F P
0 g
s
.32719 .77252 m .31481 .77453 L p .33933 .7775 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .3173 .76847 L p .28883 .7702 L .707 .577 .707 r
F P
0 g
s
.3173 .76847 m .31769 .76629 L .3134 .76687 L p .707 .577 .707 r
F P
0 g
s
.3134 .76687 m .28883 .7702 L p .3173 .76847 L .707 .577 .707 r
F P
0 g
s
.33883 .77064 m .34022 .78973 L .35659 .78574 L p .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .3552 .76666 L .35059 .76778 L p .707 .577 .707 r
F P
0 g
s
.35059 .76778 m .33883 .77064 L p .34763 .77813 L .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .35059 .76778 L .34763 .77813 L .707 .577 .707 r
F
.35129 .77462 m .35778 .75772 L p .357 .74534 L F P
0 g
s
.35686 .74322 m .35565 .75007 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.35565 .75007 m .35129 .77462 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .35129 .77462 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34113 .75699 m .34066 .75964 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34066 .75964 m .33556 .78839 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .33556 .78839 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31769 .76629 m .31763 .76659 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31763 .76659 m .31211 .79769 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .31211 .79769 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28883 .7702 m .28882 .77027 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28882 .77027 m .28326 .8016 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .28326 .8016 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25738 .76834 m .25703 .77031 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25703 .77031 m .25181 .79974 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.17015 .63914 m .17575 .69651 L .19673 .69556 L p .707 .577 .707 r
F P
0 g
s
.37647 .8032 m .37647 .30131 L .3595 .29009 L p .707 .577 .707 r
F P
0 g
s
.37647 .30131 m .37647 .8032 L .40553 .81247 L p .707 .577 .707 r
F P
0 g
s
.33434 .62364 m .33994 .681 L .35621 .67816 L p .707 .577 .707 r
F P
0 g
s
.35621 .67816 m .3506 .62079 L .33434 .62364 L p .707 .577 .707 r
F P
0 g
s
.19529 .78235 m .19668 .80143 L .22404 .80112 L p .707 .577 .707 r
F P
0 g
s
.19341 .78 m .19899 .7486 L .17775 .73264 L p .707 .577 .707 r
F P
0 g
s
.19899 .7486 m .19341 .78 L .22085 .7923 L p .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .34113 .75699 L .31769 .76629 L p .707 .577 .707 r
F P
0 g
s
.69022 .77385 m .69345 .7917 L .67285 .78687 L p .707 .577 .707 r
F P
0 g
s
.17575 .69651 m .17015 .63914 L .15759 .63902 L p .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .16319 .69638 L .17575 .69651 L p .707 .577 .707 r
F P
0 g
s
.19668 .80143 m .19529 .78235 L .17432 .78141 L p .707 .577 .707 r
F P
0 g
s
.17432 .78141 m .17572 .80049 L .19668 .80143 L p .707 .577 .707 r
F P
0 g
s
.17218 .76404 m .17775 .73264 L .1648 .7146 L p .707 .577 .707 r
F P
0 g
s
.17775 .73264 m .17218 .76404 L .19341 .78 L p .707 .577 .707 r
F P
0 g
s
.3506 .62079 m .35621 .67816 L .36323 .67605 L p .707 .577 .707 r
F P
0 g
s
.36323 .67605 m .35762 .61868 L .3506 .62079 L p .707 .577 .707 r
F P
0 g
s
.35129 .77462 m .35686 .74322 L .34113 .75699 L p .707 .577 .707 r
F P
0 g
s
.66961 .76902 m .67285 .78687 L .64588 .78563 L p .707 .577 .707 r
F P
0 g
s
.35778 .75772 m .36335 .72632 L .35686 .74322 L p .707 .577 .707 r
F P
0 g
s
.3552 .76666 m .35659 .78574 L .3637 .78205 L p .707 .577 .707 r
F P
0 g
s
.3637 .78205 m .36231 .76297 L .3552 .76666 L p .707 .577 .707 r
F P
0 g
s
.35762 .61868 m .36323 .67605 L .36031 .67487 L p .707 .577 .707 r
F P
0 g
s
.36031 .67487 m .35471 .6175 L .35762 .61868 L p .707 .577 .707 r
F P
0 g
s
.36335 .72632 m .35778 .75772 L .35438 .73934 L p .707 .577 .707 r
F P
0 g
s
.35438 .73934 m .35995 .70794 L .36335 .72632 L p .707 .577 .707 r
F P
0 g
s
.36086 .77901 m .35947 .75993 L .36231 .76297 L p .707 .577 .707 r
F P
0 g
s
.35471 .6175 m .36031 .67487 L .34775 .67475 L p .707 .577 .707 r
F P
0 g
s
.35995 .70794 m .35438 .73934 L .34143 .72129 L p .707 .577 .707 r
F P
0 g
s
.34143 .72129 m .347 .6899 L .35995 .70794 L p .707 .577 .707 r
F P
0 g
s
.35947 .75993 m .36086 .77901 L .34835 .77692 L p .707 .577 .707 r
F P
0 g
s
.34835 .77692 m .34695 .75784 L .35947 .75993 L p .707 .577 .707 r
F P
0 g
s
.3595 .79198 m .3595 .29009 L .35628 .27801 L p .707 .577 .707 r
F P
0 g
s
.36231 .76297 m .3637 .78205 L .36086 .77901 L p .707 .577 .707 r
F P
0 g
s
.3595 .29009 m .3595 .79198 L .37647 .8032 L p .707 .577 .707 r
F P
0 g
s
.17572 .80049 m .17432 .78141 L .16181 .77932 L p .707 .577 .707 r
F P
0 g
s
.16319 .69638 m .16195 .68365 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.15468 .63784 m .16028 .69521 L .16319 .69638 L p .707 .577 .707 r
F P
0 g
s
.15923 .74599 m .1648 .7146 L .1614 .69622 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .15583 .72762 L .15923 .74599 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .16789 .67932 L p .16458 .69256 L .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .15468 .63784 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.16195 .68365 m .15759 .63902 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16387 .69413 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16789 .67932 L p .16935 .68853 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16701 .69015 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16935 .68853 L .16701 .69015 L .707 .577 .707 r
F
.18356 .69025 m .1673 .69309 L p .16793 .68951 L F P
0 g
s
.16789 .67932 m .18362 .66555 L p .17445 .68499 L .707 .577 .707 r
F P
0 g
s
.16935 .68853 m .16789 .67932 L .17445 .68499 L .707 .577 .707 r
F
.16793 .68951 m .18097 .68047 L .18356 .69025 L F
.18097 .68047 m .18362 .66555 L p .18679 .67984 L F P
0 g
s
.18356 .69025 m .18268 .68126 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.18097 .68047 m .18679 .67984 L .18268 .68126 L .707 .577 .707 r
F
.20748 .68695 m .18356 .69025 L p .18669 .67988 L F P
0 g
s
.18362 .66555 m .20706 .65625 L p .19137 .67826 L .707 .577 .707 r
F P
0 g
s
.18679 .67984 m .18362 .66555 L .19137 .67826 L .707 .577 .707 r
F
.20706 .65625 m .23592 .65234 L p .21559 .67319 L F P
0 g
s
.21125 .67395 m .20706 .65625 L .21559 .67319 L .707 .577 .707 r
F
.20188 .62959 m .23111 .62616 L p .21263 .67371 L F P
0 g
s
.20748 .68695 m .2063 .67481 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20393 .67393 m .20706 .65625 L p .21125 .67395 L .707 .577 .707 r
F P
0 g
s
.23671 .68353 m .20748 .68695 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .21125 .67395 L .21196 .67692 L .707 .577 .707 r
F
.20393 .67393 m .21125 .67395 L .2063 .67481 L F
.23592 .65234 m .26737 .6542 L p .24667 .67071 L F P
0 g
s
.24136 .67103 m .23592 .65234 L .24667 .67071 L .707 .577 .707 r
F
.23111 .62616 m .26279 .62294 L p .24211 .67098 L F P
0 g
s
.23671 .68353 m .23553 .67137 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23275 .6702 m .23592 .65234 L p .24136 .67103 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .23671 .68353 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .24136 .67103 L .24229 .67421 L .707 .577 .707 r
F
.23275 .6702 m .24136 .67103 L .23553 .67137 L F
.29943 .6776 m .2684 .6803 L p .27215 .67144 L F P
0 g
s
.26737 .6542 m .29832 .66164 L p .2828 .67182 L .707 .577 .707 r
F P
0 g
s
.27436 .67152 m .26737 .6542 L .2828 .67182 L .707 .577 .707 r
F
.27215 .67144 m .29643 .67231 L .29943 .6776 L F
.29643 .67231 m .29832 .66164 L p .30537 .67535 L F P
0 g
s
.31496 .67652 m .29943 .6776 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29643 .67231 m .30537 .67535 L .29913 .6746 L .707 .577 .707 r
F
.29832 .66164 m .32576 .67394 L p .32021 .67715 L F P
0 g
s
.30537 .67535 m .29832 .66164 L .32021 .67715 L .707 .577 .707 r
F
.29383 .62024 m .32117 .61832 L p .30047 .67476 L F P
0 g
s
.29943 .6776 m .29913 .6746 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29832 .66164 m .29609 .67423 L p .26179 .6856 L .707 .577 .707 r
F P
0 g
s
.29609 .67423 m .29275 .69304 L .27401 .68853 L p .707 .577 .707 r
F P
0 g
s
.27401 .68853 m .26179 .6856 L p .29609 .67423 L .707 .577 .707 r
F P
0 g
s
.29913 .6746 m .29892 .6724 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .29383 .62024 L p .30009 .67164 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .30009 .67164 L .30047 .67476 L .707 .577 .707 r
F
.30948 .68336 m .30537 .67535 L .32021 .67715 L F
.29913 .6746 m .30537 .67535 L .30948 .68336 L F
.32576 .67394 m .347 .6899 L p .33636 .69603 L F P
0 g
s
.32019 .70534 m .32509 .67774 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32509 .67774 m .32576 .67394 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32576 .67394 m .32019 .70534 L .29275 .69304 L p .707 .577 .707 r
F P
0 g
s
.32117 .61832 m .32677 .67569 L .32394 .67589 L p .707 .577 .707 r
F P
0 g
s
.32394 .67589 m .31496 .67652 L p .31635 .66356 L .707 .577 .707 r
F P
0 g
s
.31635 .66356 m .32117 .61832 L .32394 .67589 L .707 .577 .707 r
F
.30047 .67476 m .32117 .61832 L .31496 .67652 L F
.29892 .6724 m .29913 .6746 L p .29643 .67231 L F P
0 g
s
.29913 .6746 m .29943 .6776 L p .29643 .67231 L .707 .577 .707 r
F P
0 g
s
.29275 .69304 m .29643 .67231 L p .30948 .68336 L .707 .577 .707 r
F P
0 g
s
.26462 .66966 m .26737 .6542 L p .27436 .67152 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .26751 .67127 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .27436 .67152 L .27622 .67614 L .707 .577 .707 r
F
.26462 .66966 m .27436 .67152 L .26751 .67127 L F
.26279 .62294 m .29383 .62024 L p .27215 .67144 L F P
0 g
s
.26734 .6695 m .2684 .6803 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .23275 .6702 L .23671 .68353 L .707 .577 .707 r
F
.23537 .66975 m .23553 .67137 L p .23275 .6702 L F P
0 g
s
.23553 .67137 m .23671 .68353 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.26737 .6542 m .26436 .67116 L p .24875 .67693 L .707 .577 .707 r
F P
0 g
s
.23035 .68374 m .24229 .67421 L .24875 .67693 L .707 .577 .707 r
F
.24229 .67421 m .26737 .6542 L .24875 .67693 L F
.26436 .67116 m .26179 .6856 L .24067 .68435 L p F P
0 g
s
.24067 .68435 m .23035 .68374 L p .26436 .67116 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .26734 .6695 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .26279 .62294 L p .27134 .66727 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .27134 .66727 L .27215 .67144 L .707 .577 .707 r
F
.29383 .62024 m .29892 .6724 L p .27215 .67144 L F P
0 g
s
.27622 .67614 m .27436 .67152 L .2828 .67182 L .707 .577 .707 r
F
.26179 .6856 m .26462 .66966 L p .27622 .67614 L F P
0 g
s
.26279 .62294 m .26734 .6695 L p .26462 .66966 L .707 .577 .707 r
F P
0 g
s
.24211 .67098 m .24694 .65978 L .26462 .66966 L .707 .577 .707 r
F
.24694 .65978 m .26279 .62294 L .26462 .66966 L F
.18669 .67988 m .20393 .67393 L .20748 .68695 L F
.20614 .67316 m .2063 .67481 L p .20393 .67393 L F P
0 g
s
.2063 .67481 m .20748 .68695 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.23592 .65234 m .23251 .67155 L p .2179 .67913 L .707 .577 .707 r
F P
0 g
s
.20149 .68765 m .21196 .67692 L .2179 .67913 L .707 .577 .707 r
F
.21196 .67692 m .23592 .65234 L .2179 .67913 L F
.23251 .67155 m .23035 .68374 L .20848 .6867 L p F P
0 g
s
.20848 .6867 m .20149 .68765 L p .23251 .67155 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .23537 .66975 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .23111 .62616 L p .24095 .66623 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .24095 .66623 L .24211 .67098 L .707 .577 .707 r
F
.24229 .67421 m .24136 .67103 L .24667 .67071 L F
.23035 .68374 m .23275 .6702 L p .24229 .67421 L F P
0 g
s
.23111 .62616 m .23537 .66975 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .21663 .66342 L .23275 .6702 L .707 .577 .707 r
F
.21663 .66342 m .23111 .62616 L .23275 .6702 L F
.18268 .68126 m .18356 .69025 L p .18097 .68047 L F P
0 g
s
.20706 .65625 m .20369 .67526 L p .17805 .69695 L .707 .577 .707 r
F P
0 g
s
.20369 .67526 m .20149 .68765 L .17875 .69667 L p .707 .577 .707 r
F P
0 g
s
.17875 .69667 m .17805 .69695 L p .20369 .67526 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .20614 .67316 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .20188 .62959 L p .2114 .66865 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .2114 .66865 L .21263 .67371 L .707 .577 .707 r
F
.21196 .67692 m .21125 .67395 L .21559 .67319 L F
.20149 .68765 m .20393 .67393 L p .21196 .67692 L F P
0 g
s
.20188 .62959 m .20614 .67316 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.18669 .67988 m .19005 .66876 L .20393 .67393 L .707 .577 .707 r
F
.19005 .66876 m .20188 .62959 L .20393 .67393 L F
.18761 .68354 m .18679 .67984 L .19137 .67826 L F
.18268 .68126 m .18679 .67984 L .18761 .68354 L F
.17796 .63288 m .20188 .62959 L p .18669 .67988 L F P
0 g
s
.17805 .69695 m .16231 .71072 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18362 .66555 m .18071 .68194 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18071 .68194 m .17805 .69695 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18268 .68126 m .1825 .67941 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .17796 .63288 L p .18575 .67481 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .18575 .67481 L .18669 .67988 L .707 .577 .707 r
F
.1825 .67941 m .18268 .68126 L p .18097 .68047 L F P
0 g
s
.17805 .69695 m .18097 .68047 L p .18761 .68354 L .707 .577 .707 r
F P
0 g
s
.17796 .63288 m .1825 .67941 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.17022 .69396 m .16935 .68853 L .17445 .68499 L .707 .577 .707 r
F
.16701 .69015 m .16935 .68853 L .17022 .69396 L F
.16231 .71072 m .15583 .72762 L p .16049 .70895 L F P
0 g
s
.16789 .67932 m .16582 .69098 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.16582 .69098 m .16231 .71072 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .17796 .63288 L p .17042 .67544 L .707 .577 .707 r
F P
0 g
s
.16793 .68951 m .16746 .68544 L .17042 .67544 L .707 .577 .707 r
F
.16746 .68544 m .1617 .63573 L .17042 .67544 L F
.16701 .69015 m .1617 .63573 L p .16793 .68951 L F P
0 g
s
.16678 .68775 m .16701 .69015 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16701 .69015 m .1673 .69309 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16231 .71072 m .16615 .68913 L p .17022 .69396 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .16678 .68775 L p .16028 .69521 L .707 .577 .707 r
F P
0 g
s
.16105 .7003 m .1614 .69622 L .16458 .69256 L .707 .577 .707 r
F
.16387 .69413 m .16028 .69521 L p .16678 .68775 L F P
0 g
s
.16022 .71004 m .16105 .7003 L .16458 .69256 L .707 .577 .707 r
F
.15583 .72762 m .16096 .69871 L p .16022 .71004 L F P
0 g
s
.16096 .69871 m .1614 .69622 L p .16022 .71004 L .707 .577 .707 r
F P
0 g
s
.1648 .7146 m .15923 .74599 L .17218 .76404 L p .707 .577 .707 r
F P
0 g
s
.16181 .77932 m .16321 .7984 L .17572 .80049 L p .707 .577 .707 r
F P
0 g
s
.64371 .28465 m .64371 .78653 L .6405 .77446 L p .707 .577 .707 r
F P
0 g
s
.6405 .77446 m .6405 .27257 L .64371 .28465 L p .707 .577 .707 r
F P
0 g
s
.16321 .7984 m .16181 .77932 L .15897 .77627 L p .707 .577 .707 r
F P
0 g
s
.15897 .77627 m .16037 .79536 L .16321 .7984 L p .707 .577 .707 r
F P
0 g
s
.16028 .69521 m .15468 .63784 L .1617 .63573 L p .707 .577 .707 r
F P
0 g
s
.35628 .27801 m .35628 .7799 L .3595 .79198 L p .707 .577 .707 r
F P
0 g
s
.35628 .7799 m .35628 .27801 L .36714 .26626 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34775 .67475 m .34215 .61738 L .35471 .6175 L p .707 .577 .707 r
F P
0 g
s
.6405 .27257 m .6405 .77446 L .62353 .76323 L p .707 .577 .707 r
F P
0 g
s
.62353 .76323 m .62353 .26135 L .6405 .27257 L p .707 .577 .707 r
F P
0 g
s
.16037 .79536 m .15897 .77627 L .16608 .77258 L p .707 .577 .707 r
F P
0 g
s
.16608 .77258 m .16748 .79166 L .16037 .79536 L p .707 .577 .707 r
F P
0 g
s
.34215 .61738 m .34775 .67475 L .32677 .67569 L p .707 .577 .707 r
F P
0 g
s
.32677 .67569 m .32117 .61832 L .34215 .61738 L p .707 .577 .707 r
F P
0 g
s
.36714 .76815 m .36714 .26626 L .391 .25598 L p .707 .577 .707 r
F P
0 g
s
.36714 .26626 m .36714 .76815 L .35628 .7799 L p .707 .577 .707 r
F P
0 g
s
.347 .6899 m .34143 .72129 L .32019 .70534 L p .707 .577 .707 r
F P
0 g
s
.16748 .79166 m .16608 .77258 L .18245 .7686 L p .707 .577 .707 r
F P
0 g
s
.18245 .7686 m .18385 .78768 L .16748 .79166 L p .707 .577 .707 r
F P
0 g
s
.62353 .26135 m .62353 .76323 L .59447 .75397 L p .707 .577 .707 r
F P
0 g
s
.59447 .75397 m .59447 .25208 L .62353 .26135 L p .707 .577 .707 r
F P
0 g
s
.34695 .75784 m .34835 .77692 L .32739 .77598 L p .707 .577 .707 r
F P
0 g
s
.32739 .77598 m .32599 .7569 L .34695 .75784 L p .707 .577 .707 r
F P
0 g
s
.7372 .62575 m .70617 .61972 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73266 .66671 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .7372 .62575 L p .72865 .66425 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .72865 .66425 L .72785 .66788 L .707 .577 .707 r
F
.75125 .67453 m .75333 .66679 L .73564 .66854 L F
.76965 .68161 m .75771 .67077 L .75125 .67453 L F
.75771 .67077 m .75333 .66679 L .75125 .67453 L F
.76889 .62707 m .76463 .66541 L p .78337 .65584 L F P
0 g
s
.76463 .66541 m .76447 .66684 L p .76725 .66522 L .707 .577 .707 r
F P
0 g
s
.78337 .65584 m .76463 .66541 L .76725 .66522 L .707 .577 .707 r
F
.76972 .6816 m .79851 .67814 L p .78804 .66764 L F P
0 g
s
.79812 .62355 m .79386 .66189 L p .80995 .65097 L .707 .577 .707 r
F P
0 g
s
.79386 .66189 m .7937 .66333 L p .79607 .66153 L .707 .577 .707 r
F P
0 g
s
.80995 .65097 m .79386 .66189 L .79607 .66153 L .707 .577 .707 r
F
.79851 .67814 m .82195 .67594 L p .80863 .6595 L F P
0 g
s
.79607 .66153 m .79851 .67814 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78875 .66369 L .78441 .664 L .707 .577 .707 r
F
.79851 .67814 m .79631 .66315 L p .78804 .66764 L F P
0 g
s
.79631 .66315 m .79607 .66153 L p .7937 .66333 L .707 .577 .707 r
F P
0 g
s
.79631 .66315 m .7937 .66333 L .78804 .66764 L .707 .577 .707 r
F
.79812 .62355 m .76889 .62707 L p .78737 .66379 L F P
0 g
s
.7937 .66333 m .79812 .62355 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.79607 .66153 m .79293 .64014 L p .78804 .66764 L .707 .577 .707 r
F P
0 g
s
.79252 .67402 m .7937 .66333 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.76965 .68161 m .76972 .6816 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78441 .664 L .76972 .6816 L .707 .577 .707 r
F
.76725 .66522 m .76965 .68161 L p .78441 .664 L F P
0 g
s
.7372 .62575 m .73266 .66671 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .75306 .65723 L .73537 .66672 L .707 .577 .707 r
F
.75306 .65723 m .7372 .62575 L .73537 .66672 L F
.7382 .68601 m .73564 .66854 L p .73248 .66827 L F P
0 g
s
.72378 .67294 m .73248 .66827 L .7172 .66697 L .707 .577 .707 r
F
.7382 .68601 m .73248 .66827 L .72378 .67294 L F
.73564 .66854 m .73537 .66672 L p .73248 .66827 L F P
0 g
s
.76889 .62707 m .7372 .62575 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.76408 .64361 m .73263 .64801 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.75771 .67077 m .75864 .66681 L .75333 .66679 L .707 .577 .707 r
F
.76447 .66684 m .76889 .62707 L p .75789 .66681 L F P
0 g
s
.75864 .66681 m .76408 .64361 L .75333 .66679 L .707 .577 .707 r
F
.76965 .68161 m .76725 .66522 L p .75771 .67077 L F P
0 g
s
.76725 .66522 m .76408 .64361 L p .75771 .67077 L .707 .577 .707 r
F P
0 g
s
.76328 .67753 m .76447 .66684 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73537 .66672 m .73564 .66854 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73564 .66854 m .7382 .68601 L .75932 .68305 L p .707 .577 .707 r
F P
0 g
s
.75932 .68305 m .76965 .68161 L p .73564 .66854 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .73537 .66672 L .7316 .67621 L .707 .577 .707 r
F
.73266 .66671 m .73248 .66827 L p .73537 .66672 L F P
0 g
s
.73248 .66827 m .7316 .67621 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .7382 .68601 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70725 .69091 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70617 .61972 m .67883 .60958 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .70391 .66814 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70357 .66582 L p .70086 .66754 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70086 .66754 L .69052 .67415 L .707 .577 .707 r
F
.67883 .60958 m .67323 .66005 L .67605 .6611 L p F P
0 g
s
.67323 .66005 m .67883 .60958 L .65785 .59631 L p .707 .577 .707 r
F P
0 g
s
.65785 .59631 m .65225 .64678 L .67323 .66005 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .653 .66229 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67981 .69583 m .67491 .66243 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67491 .66243 m .67423 .65783 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67605 .6611 m .68503 .66443 L p .68365 .65222 L .707 .577 .707 r
F P
0 g
s
.68365 .65222 m .67883 .60958 L .67605 .6611 L .707 .577 .707 r
F
.69052 .67415 m .69463 .66632 L .67978 .66339 L F
.69953 .66728 m .67883 .60958 L .68503 .66443 L F
.70086 .66754 m .70617 .61972 L p .69953 .66728 L F P
0 g
s
.70617 .61972 m .70108 .66561 L p .70357 .66582 L .707 .577 .707 r
F P
0 g
s
.70108 .66561 m .70057 .67019 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70167 .65291 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.68503 .66443 m .70057 .67019 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70057 .67019 m .70086 .66754 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70167 .65291 m .67423 .65783 L p .67978 .66339 L .707 .577 .707 r
F P
0 g
s
.69463 .66632 m .70167 .65291 L .67978 .66339 L .707 .577 .707 r
F
.72785 .66788 m .72171 .65423 L .70357 .66582 L F
.72171 .65423 m .70617 .61972 L .70357 .66582 L F
.70057 .67019 m .7316 .67621 L p .72785 .66788 L F P
0 g
s
.70167 .65291 m .70357 .66582 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73263 .64801 L .7172 .66697 L .707 .577 .707 r
F
.73537 .66672 m .73263 .64801 L p .73248 .66827 L F P
0 g
s
.76328 .67753 m .79252 .67402 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.78737 .66379 m .78337 .65584 L .77521 .66466 L .707 .577 .707 r
F
.78737 .66379 m .77521 .66466 L .76328 .67753 L F
.76447 .66684 m .76328 .67753 L p .78337 .65584 L F P
0 g
s
.79293 .64014 m .76408 .64361 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78875 .66369 m .79293 .64014 L .78441 .664 L .707 .577 .707 r
F
.8133 .65875 m .80995 .65097 L .80278 .66045 L F
.7937 .66333 m .79252 .67402 L p .80995 .65097 L F P
0 g
s
.82195 .67594 m .81929 .65778 L p .81731 .6581 L .707 .577 .707 r
F P
0 g
s
.81239 .66415 m .81731 .6581 L .80863 .6595 L .707 .577 .707 r
F
.82195 .67594 m .81731 .6581 L .81239 .66415 L F
.82195 .67594 m .83768 .67523 L p .82555 .65399 L F P
0 g
s
.83207 .65199 m .8296 .64302 L .82284 .65483 L .707 .577 .707 r
F
.82204 .61554 m .81749 .65647 L p .8296 .64302 L F P
0 g
s
.81749 .65647 m .81731 .6581 L p .81903 .656 L .707 .577 .707 r
F P
0 g
s
.8296 .64302 m .81749 .65647 L .81903 .656 L .707 .577 .707 r
F
.81903 .656 m .82195 .67594 L p .82555 .65399 L F P
0 g
s
.82204 .61554 m .79812 .62355 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .81731 .6581 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .82204 .61554 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81929 .65778 m .81638 .63795 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .81644 .66601 L p .8296 .64302 L .707 .577 .707 r
F P
0 g
s
.83768 .67523 m .83418 .65134 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.82978 .6614 m .83299 .6517 L .82555 .65399 L .707 .577 .707 r
F
.83768 .67523 m .83299 .6517 L .82978 .6614 L F
.8383 .60383 m .83322 .64959 L p .83942 .6323 L F P
0 g
s
.83322 .64959 m .83299 .6517 L p .83385 .6491 L .707 .577 .707 r
F P
0 g
s
.83942 .6323 m .83322 .64959 L .83385 .6491 L .707 .577 .707 r
F
.83768 .67523 m .84417 .67608 L p .83542 .64788 L F P
0 g
s
.83385 .6491 m .83768 .67523 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8383 .60383 m .82204 .61554 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83299 .6517 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .8383 .60383 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .83211 .63724 L .82555 .65399 L .707 .577 .707 r
F
.83418 .65134 m .83385 .6491 L p .83299 .6517 L F P
0 g
s
.83385 .6491 m .83211 .63724 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .83942 .6323 L .83442 .64865 L .707 .577 .707 r
F
.83613 .64732 m .83972 .64002 L p .83442 .64865 L F P
0 g
s
.83299 .6517 m .8327 .65429 L p .83942 .6323 L .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .83211 .63724 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.84417 .67608 m .83956 .64464 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83956 .64464 m .8386 .63808 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83613 .64732 L p .83442 .64865 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .83385 .6491 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .81638 .63795 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81638 .63795 m .81903 .656 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .8327 .65429 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83207 .65199 m .82284 .65483 L .81644 .66601 L .707 .577 .707 r
F
.81638 .63795 m .79293 .64014 L p .80863 .6595 L F P
0 g
s
.79252 .67402 m .81644 .66601 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.8133 .65875 m .80278 .66045 L .79252 .67402 L .707 .577 .707 r
F
.79293 .64014 m .79607 .66153 L p .80863 .6595 L F P
0 g
s
.76408 .64361 m .76725 .66522 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .76328 .67753 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .73537 .66672 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .70167 .65291 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .73248 .66827 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.391 .25598 m .391 .75787 L .36714 .76815 L p .707 .577 .707 r
F P
0 g
s
.391 .75787 m .391 .25598 L .42552 .24818 L p .707 .577 .707 r
F P
0 g
s
.18385 .78768 m .18245 .7686 L .20647 .76472 L p .707 .577 .707 r
F P
0 g
s
.20647 .76472 m .20787 .7838 L .18385 .78768 L p .707 .577 .707 r
F P
0 g
s
.32599 .7569 m .32739 .77598 L .30003 .77629 L p .707 .577 .707 r
F P
0 g
s
.30003 .77629 m .29863 .75721 L .32599 .7569 L p .707 .577 .707 r
F P
0 g
s
.59447 .25208 m .59447 .75397 L .55616 .74757 L p .707 .577 .707 r
F P
0 g
s
.55616 .74757 m .55616 .24568 L .59447 .25208 L p .707 .577 .707 r
F P
0 g
s
.20787 .7838 m .20647 .76472 L .2358 .76132 L p .707 .577 .707 r
F P
0 g
s
.2358 .76132 m .23719 .7804 L .20787 .7838 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .67981 .69583 L .70725 .69091 L p .707 .577 .707 r
F P
0 g
s
.42552 .75007 m .42552 .24818 L .46734 .24363 L p .707 .577 .707 r
F P
0 g
s
.42552 .24818 m .42552 .75007 L .391 .75787 L p .707 .577 .707 r
F P
0 g
s
.29863 .75721 m .30003 .77629 L .26895 .77781 L p .707 .577 .707 r
F P
0 g
s
.26895 .77781 m .26755 .75873 L .29863 .75721 L p .707 .577 .707 r
F P
0 g
s
.23719 .7804 m .2358 .76132 L .26755 .75873 L p .707 .577 .707 r
F P
0 g
s
.55616 .24568 m .55616 .74757 L .51236 .74466 L p .707 .577 .707 r
F P
0 g
s
.51236 .74466 m .51236 .24277 L .55616 .24568 L p .707 .577 .707 r
F P
0 g
s
.26755 .75873 m .26895 .77781 L .23719 .7804 L p .707 .577 .707 r
F P
0 g
s
.65225 .64678 m .65785 .59631 L .64529 .58122 L p .707 .577 .707 r
F P
0 g
s
.653 .66229 m .65857 .70029 L .67981 .69583 L p .707 .577 .707 r
F P
0 g
s
.46734 .74552 m .46734 .24363 L .51236 .24277 L p .707 .577 .707 r
F P
0 g
s
.46734 .24363 m .46734 .74552 L .42552 .75007 L p .707 .577 .707 r
F P
0 g
s
.73105 .77388 m .73245 .75653 L .70137 .75144 L p .707 .577 .707 r
F P
0 g
s
.73245 .75653 m .73105 .77388 L .76281 .77475 L p .707 .577 .707 r
F P
0 g
s
.76281 .77475 m .7642 .7574 L .73245 .75653 L p .707 .577 .707 r
F P
0 g
s
.51236 .24277 m .51236 .74466 L .46734 .74552 L p .707 .577 .707 r
F P
0 g
s
.7642 .7574 m .76281 .77475 L .79213 .77132 L p .707 .577 .707 r
F P
0 g
s
.79213 .77132 m .79353 .75398 L .7642 .7574 L p .707 .577 .707 r
F P
0 g
s
.69997 .76879 m .70137 .75144 L .67401 .74263 L p .707 .577 .707 r
F P
0 g
s
.70137 .75144 m .69997 .76879 L .73105 .77388 L p .707 .577 .707 r
F P
0 g
s
.67401 .74263 m .67261 .75998 L .69997 .76879 L p .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .84532 .58955 L .8383 .60383 L p .707 .577 .707 r
F P
0 g
s
.79353 .75398 m .79213 .77132 L .81615 .76393 L p .707 .577 .707 r
F P
0 g
s
.81615 .76393 m .81755 .74658 L .79353 .75398 L p .707 .577 .707 r
F P
0 g
s
.63969 .63169 m .64529 .58122 L .64237 .56578 L p .707 .577 .707 r
F P
0 g
s
.64529 .58122 m .63969 .63169 L .65225 .64678 L p .707 .577 .707 r
F P
0 g
s
.67261 .75998 m .67401 .74263 L .65304 .73097 L p .707 .577 .707 r
F P
0 g
s
.64005 .66586 m .64562 .70385 L .65857 .70029 L p .707 .577 .707 r
F P
0 g
s
.65857 .70029 m .653 .66229 L .64005 .66586 L p .707 .577 .707 r
F P
0 g
s
.65304 .73097 m .65165 .74831 L .67261 .75998 L p .707 .577 .707 r
F P
0 g
s
.81755 .74658 m .81615 .76393 L .83252 .75329 L p .707 .577 .707 r
F P
0 g
s
.83252 .75329 m .83392 .73595 L .81755 .74658 L p .707 .577 .707 r
F P
0 g
s
.65165 .74831 m .65304 .73097 L .64053 .71759 L p .707 .577 .707 r
F P
0 g
s
.84532 .58955 m .83972 .64002 L .83681 .62458 L p .707 .577 .707 r
F P
0 g
s
.83681 .62458 m .84241 .57411 L .84532 .58955 L p .707 .577 .707 r
F P
0 g
s
.64237 .56578 m .63677 .61625 L .63969 .63169 L p .707 .577 .707 r
F P
0 g
s
.63677 .61625 m .64237 .56578 L .64939 .55151 L p .707 .577 .707 r
F P
0 g
s
.64053 .71759 m .63913 .73494 L .65165 .74831 L p .707 .577 .707 r
F P
0 g
s
.63665 .66818 m .64222 .70617 L .64562 .70385 L p .707 .577 .707 r
F P
0 g
s
.64562 .70385 m .64005 .66586 L .63665 .66818 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83392 .73595 m .83252 .75329 L .83963 .74045 L p .707 .577 .707 r
F P
0 g
s
.83963 .74045 m .84103 .72311 L .83392 .73595 L p .707 .577 .707 r
F P
0 g
s
.63913 .73494 m .64053 .71759 L .63769 .70381 L p .707 .577 .707 r
F P
0 g
s
.84241 .57411 m .83681 .62458 L .82425 .60949 L p .707 .577 .707 r
F P
0 g
s
.82425 .60949 m .82985 .55902 L .84241 .57411 L p .707 .577 .707 r
F P
0 g
s
.64939 .55151 m .64379 .60197 L .63677 .61625 L p .707 .577 .707 r
F P
0 g
s
.64379 .60197 m .64939 .55151 L .66566 .53979 L p .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .84417 .67608 L .84077 .6784 L p .707 .577 .707 r
F P
0 g
s
.63769 .70381 m .63629 .72115 L .63913 .73494 L p .707 .577 .707 r
F P
0 g
s
.84077 .6784 m .8352 .6404 L .8386 .63808 L p .707 .577 .707 r
F P
0 g
s
.64314 .66902 m .64871 .70702 L .64222 .70617 L p .707 .577 .707 r
F P
0 g
s
.64222 .70617 m .63665 .66818 L .64314 .66902 L p .707 .577 .707 r
F P
0 g
s
.3855 .60908 m .3984 .55371 L .36807 .54558 L p .707 .577 .707 r
F P
0 g
s
.3984 .55371 m .3855 .60908 L .41655 .61563 L p .707 .577 .707 r
F P
0 g
s
.41655 .61563 m .42945 .56026 L .3984 .55371 L p .707 .577 .707 r
F P
0 g
s
.84103 .72311 m .83963 .74045 L .83679 .72667 L p .707 .577 .707 r
F P
0 g
s
.83679 .72667 m .83819 .70932 L .84103 .72311 L p .707 .577 .707 r
F P
0 g
s
.42945 .56026 m .41655 .61563 L .44528 .61995 L p .707 .577 .707 r
F P
0 g
s
.44528 .61995 m .45818 .56458 L .42945 .56026 L p .707 .577 .707 r
F P
0 g
s
.35517 .60095 m .36807 .54558 L .34142 .53667 L p .707 .577 .707 r
F P
0 g
s
.36807 .54558 m .35517 .60095 L .3855 .60908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63629 .72115 m .63769 .70381 L .6448 .69097 L p .707 .577 .707 r
F P
0 g
s
.82985 .55902 m .82425 .60949 L .80327 .59622 L p .707 .577 .707 r
F P
0 g
s
.80327 .59622 m .80887 .54575 L .82985 .55902 L p .707 .577 .707 r
F P
0 g
s
.66566 .53979 m .66006 .59026 L .64379 .60197 L p .707 .577 .707 r
F P
0 g
s
.66006 .59026 m .66566 .53979 L .68958 .53178 L p .707 .577 .707 r
F P
0 g
s
.34142 .53667 m .32852 .59204 L .35517 .60095 L p .707 .577 .707 r
F P
0 g
s
.6448 .69097 m .64341 .70832 L .63629 .72115 L p .707 .577 .707 r
F P
0 g
s
.46325 .62123 m .46888 .62163 L p .44867 .60541 L .707 .577 .707 r
F P
0 g
s
.46564 .62137 m .46722 .62555 L p .49371 .63866 L .707 .577 .707 r
F P
0 g
s
.46722 .62555 m .47822 .65463 L .48632 .64628 L p .707 .577 .707 r
F P
0 g
s
.48632 .64628 m .49371 .63866 L p .46722 .62555 L .707 .577 .707 r
F P
0 g
s
.45818 .56458 m .44867 .60541 L p .46888 .62163 L .707 .577 .707 r
F P
0 g
s
.44867 .60541 m .44528 .61995 L .46325 .62123 L p .707 .577 .707 r
F P
0 g
s
.46888 .62163 m .48177 .56626 L .45818 .56458 L p .707 .577 .707 r
F P
0 g
s
.8352 .6404 m .84077 .6784 L .82782 .68196 L p .707 .577 .707 r
F P
0 g
s
.82782 .68196 m .82225 .64396 L .8352 .6404 L p .707 .577 .707 r
F P
0 g
s
.32852 .59204 m .34142 .53667 L .32108 .52784 L p .707 .577 .707 r
F P
0 g
s
.42768 .68417 m .41511 .65091 L .38502 .66159 L p .707 .577 .707 r
F P
0 g
s
.41511 .65091 m .42768 .68417 L .45546 .67032 L p .707 .577 .707 r
F P
0 g
s
.45546 .67032 m .44289 .63705 L .41511 .65091 L p .707 .577 .707 r
F P
0 g
s
.39759 .69485 m .38502 .66159 L .35557 .66804 L p .707 .577 .707 r
F P
0 g
s
.38502 .66159 m .39759 .69485 L .42768 .68417 L p .707 .577 .707 r
F P
0 g
s
.65887 .66831 m .66444 .70631 L .64871 .70702 L p .707 .577 .707 r
F P
0 g
s
.64871 .70702 m .64314 .66902 L .65887 .66831 L p .707 .577 .707 r
F P
0 g
s
.80887 .54575 m .80327 .59622 L .77592 .58608 L p .707 .577 .707 r
F P
0 g
s
.77592 .58608 m .78152 .53561 L .80887 .54575 L p .707 .577 .707 r
F P
0 g
s
.68398 .58225 m .68958 .53178 L .71881 .52827 L p .707 .577 .707 r
F P
0 g
s
.68958 .53178 m .68398 .58225 L .66006 .59026 L p .707 .577 .707 r
F P
0 g
s
.44289 .63705 m .45546 .67032 L .47822 .65463 L p .707 .577 .707 r
F P
0 g
s
.47822 .65463 m .46564 .62137 L .44289 .63705 L p .707 .577 .707 r
F P
0 g
s
.83819 .70932 m .83679 .72667 L .82428 .71329 L p .707 .577 .707 r
F P
0 g
s
.82428 .71329 m .82567 .69595 L .83819 .70932 L p .707 .577 .707 r
F P
0 g
s
.32108 .52784 m .30818 .58321 L .32852 .59204 L p .707 .577 .707 r
F P
0 g
s
.3848 .71489 m .3875 .69937 L p .35735 .68973 L .707 .577 .707 r
F P
0 g
s
.38231 .69508 m .35735 .68973 L p .3875 .69937 L .707 .577 .707 r
F P
0 g
s
.35735 .68973 m .35411 .70832 L .3848 .71489 L p .707 .577 .707 r
F P
0 g
s
.35411 .70832 m .3562 .69633 L p .33039 .68194 L .707 .577 .707 r
F P
0 g
s
.3562 .69633 m .35735 .68973 L .34548 .6863 L p .707 .577 .707 r
F P
0 g
s
.34548 .6863 m .33039 .68194 L p .3562 .69633 L .707 .577 .707 r
F P
0 g
s
.33039 .68194 m .32715 .70052 L .35411 .70832 L p .707 .577 .707 r
F P
0 g
s
.32715 .70052 m .32851 .69269 L p .30978 .6737 L .707 .577 .707 r
F P
0 g
s
.32851 .69269 m .33039 .68194 L .31695 .67657 L p .707 .577 .707 r
F P
0 g
s
.31695 .67657 m .30978 .6737 L p .32851 .69269 L .707 .577 .707 r
F P
0 g
s
.30978 .6737 m .30654 .69228 L .32715 .70052 L p .707 .577 .707 r
F P
0 g
s
.30654 .69228 m .30725 .68821 L p .29755 .66581 L .707 .577 .707 r
F P
0 g
s
.30725 .68821 m .30978 .6737 L .30101 .66804 L p .707 .577 .707 r
F P
0 g
s
.30101 .66804 m .29755 .66581 L p .30725 .68821 L .707 .577 .707 r
F P
0 g
s
.32233 .69947 m .31001 .66688 L p .29788 .65811 L .707 .577 .707 r
F P
0 g
s
.30931 .6659 m .29788 .65811 L p .31001 .66688 L .707 .577 .707 r
F P
0 g
s
.29788 .65811 m .31045 .69137 L .32233 .69947 L p .707 .577 .707 r
F P
0 g
s
.31045 .69137 m .29819 .65892 L p .29517 .64612 L .707 .577 .707 r
F P
0 g
s
.29819 .65892 m .29788 .65811 L .29773 .65744 L p .707 .577 .707 r
F P
0 g
s
.29773 .65744 m .29517 .64612 L p .29819 .65892 L .707 .577 .707 r
F P
0 g
s
.31001 .66688 m .30976 .66621 L .30931 .6659 L p .707 .577 .707 r
F P
0 g
s
.3422 .70289 m .33072 .67252 L p .30976 .66621 L .707 .577 .707 r
F P
0 g
s
.33072 .67252 m .32963 .66963 L .32719 .66921 L p .707 .577 .707 r
F P
0 g
s
.32719 .66921 m .30976 .66621 L p .33072 .67252 L .707 .577 .707 r
F P
0 g
s
.36814 .7013 m .35827 .6752 L p .32963 .66963 L .707 .577 .707 r
F P
0 g
s
.35827 .6752 m .35557 .66804 L .35003 .66838 L p .707 .577 .707 r
F P
0 g
s
.35003 .66838 m .32963 .66963 L p .35827 .6752 L .707 .577 .707 r
F P
0 g
s
.3875 .69937 m .38803 .69631 L .38231 .69508 L p .707 .577 .707 r
F P
0 g
s
.38803 .69631 m .3848 .71489 L .4162 .71961 L p .707 .577 .707 r
F P
0 g
s
.4162 .71961 m .41943 .70103 L .38803 .69631 L p .707 .577 .707 r
F P
0 g
s
.35557 .66804 m .36814 .7013 L .39759 .69485 L p .707 .577 .707 r
F P
0 g
s
.66444 .70631 m .65971 .67403 L p .68231 .66611 L .707 .577 .707 r
F P
0 g
s
.65971 .67403 m .65887 .66831 L .66458 .66778 L p .707 .577 .707 r
F P
0 g
s
.66458 .66778 m .68231 .66611 L p .65971 .67403 L .707 .577 .707 r
F P
0 g
s
.64341 .70832 m .64461 .6934 L p .66117 .68033 L .707 .577 .707 r
F P
0 g
s
.64461 .6934 m .6448 .69097 L .64824 .68874 L p .707 .577 .707 r
F P
0 g
s
.64824 .68874 m .66117 .68033 L p .64461 .6934 L .707 .577 .707 r
F P
0 g
s
.41943 .70103 m .4162 .71961 L .44524 .722 L p .707 .577 .707 r
F P
0 g
s
.44524 .722 m .44847 .70342 L .41943 .70103 L p .707 .577 .707 r
F P
0 g
s
.48177 .56626 m .46888 .62163 L .47759 .62102 L p .707 .577 .707 r
F P
0 g
s
.48483 .61719 m .48477 .61626 L .47759 .62102 L .707 .577 .707 r
F
.48477 .61626 m .48177 .56626 L .47837 .61074 L F
.48477 .61626 m .47837 .61074 L .47759 .62102 L F
.49371 .63866 m .49854 .62811 L p .48581 .61715 L F P
0 g
s
.48547 .61686 m .48565 .61733 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.48565 .61733 m .49371 .63866 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.49305 .6087 m .49336 .60598 L .48581 .61715 L .707 .577 .707 r
F
.49793 .56513 m .48983 .5999 L p .49336 .60598 L F P
0 g
s
.48983 .5999 m .48581 .61715 L p .49336 .60598 L .707 .577 .707 r
F P
0 g
s
.49793 .56513 m .48177 .56626 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.49371 .63866 m .48547 .61686 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .48983 .5999 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.48983 .5999 m .49793 .56513 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .4983 .61451 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49417 .60739 m .49432 .60777 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .50043 .62396 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .48547 .61686 L p .48589 .61705 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .48922 .61317 L .48589 .61705 L .707 .577 .707 r
F
.48922 .61317 m .48114 .60539 L .48589 .61705 L F
.49423 .60733 m .49359 .6039 L p .49305 .6087 L F P
0 g
s
.48786 .59069 m .48114 .60539 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .49432 .60777 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .48786 .59069 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49466 .59435 m .50506 .5613 L .49793 .56513 L p .707 .577 .707 r
F P
0 g
s
.50247 .55515 m .50506 .5613 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49423 .60733 L p .49216 .61667 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .49423 .60733 L .49305 .6087 L .707 .577 .707 r
F
.48786 .59069 m .49417 .60739 L p .49427 .60752 L F P
0 g
s
.49287 .60004 m .49404 .59633 L .49428 .60758 L .707 .577 .707 r
F
.50506 .5613 m .49808 .59127 L p .49404 .59633 L F P
0 g
s
.49808 .59127 m .49428 .60758 L p .49404 .59633 L .707 .577 .707 r
F P
0 g
s
.49332 .60248 m .48786 .59069 L .49427 .60752 L .707 .577 .707 r
F
.49287 .60004 m .49744 .57675 L .49614 .58965 L F
.49249 .598 m .49744 .57675 L p .49287 .60004 L F P
0 g
s
.48515 .57871 m .48786 .59069 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .49265 .59855 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .48515 .57871 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.48515 .57871 m .49253 .59821 L p .49237 .59835 L .707 .577 .707 r
F P
0 g
s
.48957 .61052 m .47751 .60265 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .48868 .59578 L .48957 .61052 L .707 .577 .707 r
F
.48557 .59362 m .48515 .57871 L .49237 .59835 L F
.4924 .59837 m .48957 .61052 L p .48868 .59578 L F P
0 g
s
.48724 .60482 m .48585 .60387 L p .49253 .59821 L .707 .577 .707 r
F P
0 g
s
.49249 .598 m .4924 .59837 L p .4879 .58288 L .707 .577 .707 r
F P
0 g
s
.4879 .58288 m .4924 .59837 L .48868 .59578 L .707 .577 .707 r
F
.49773 .61197 m .49332 .60248 L .49427 .60752 L F
.48957 .61052 m .49249 .598 L p .49287 .60004 L F P
0 g
s
.49854 .62811 m .50043 .62396 L p .48547 .61686 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .49216 .61667 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.48581 .61715 m .48503 .6205 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .48957 .61052 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.4983 .61451 m .49773 .61197 L p .49417 .60739 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49216 .61667 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .48724 .60482 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49253 .59821 m .49265 .59855 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .49773 .61197 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .48557 .59362 L .49237 .59835 L .707 .577 .707 r
F
.47328 .57061 m .48515 .57871 L p .48557 .59362 L F P
0 g
s
.47751 .60265 m .48036 .59043 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.47328 .57061 m .4807 .59023 L p .48036 .59043 L .707 .577 .707 r
F P
0 g
s
.47751 .60265 m .45716 .59382 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .47751 .60265 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4665 .5983 m .46925 .58708 L .48036 .59043 L .707 .577 .707 r
F
.46925 .58708 m .47328 .57061 L .48036 .59043 L F
.4807 .59023 m .47328 .57061 L p .48557 .59362 L F P
0 g
s
.4534 .56718 m .47328 .57061 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .45933 .58452 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4534 .56718 m .45985 .58424 L p .45933 .58452 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .43052 .58491 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45716 .59382 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.44343 .59319 m .44738 .5829 L .45933 .58452 L .707 .577 .707 r
F
.44738 .5829 m .4534 .56718 L .45933 .58452 L F
.45985 .58424 m .4534 .56718 L p .46925 .58708 L F P
0 g
s
.42747 .56878 m .4534 .56718 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.43052 .58491 m .43137 .58125 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.42747 .56878 m .43201 .58081 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43052 .58491 L .41492 .58072 L p .707 .577 .707 r
F P
0 g
s
.4183 .59035 m .42229 .58096 L .43137 .58125 L .707 .577 .707 r
F
.42229 .58096 m .42747 .56878 L .43137 .58125 L F
.43201 .58081 m .42747 .56878 L p .44738 .5829 L F P
0 g
s
.39801 .57523 m .42747 .56878 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.41059 .60849 m .4002 .58102 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.4002 .58102 m .39801 .57523 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.39801 .57523 m .41059 .60849 L .3805 .61917 L p .707 .577 .707 r
F P
0 g
s
.3805 .61917 m .36792 .58591 L .39801 .57523 L p .707 .577 .707 r
F P
0 g
s
.41309 .5214 m .40019 .57678 L .39463 .57561 L p .707 .577 .707 r
F P
0 g
s
.39463 .57561 m .36914 .57023 L p .37845 .55988 L .707 .577 .707 r
F P
0 g
s
.37845 .55988 m .41309 .5214 L .39463 .57561 L .707 .577 .707 r
F
.44342 .52953 m .43137 .58125 L p .40019 .57678 L F P
0 g
s
.41492 .58072 m .40019 .57678 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43149 .58074 L p .43201 .58081 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43201 .58081 L .4338 .58105 L .707 .577 .707 r
F
.44004 .60204 m .41059 .60849 L p .4183 .59035 L F P
0 g
s
.43201 .58081 m .44004 .60204 L p .4183 .59035 L .707 .577 .707 r
F P
0 g
s
.44004 .60204 m .43201 .58081 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.44342 .52953 m .47006 .53845 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.43149 .58074 m .44342 .52953 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .45933 .58452 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45942 .58411 L p .45985 .58424 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45985 .58424 L .46327 .58527 L .707 .577 .707 r
F
.46597 .60045 m .44004 .60204 L p .44343 .59319 L F P
0 g
s
.45985 .58424 m .46597 .60045 L p .44343 .59319 L .707 .577 .707 r
F P
0 g
s
.46597 .60045 m .45985 .58424 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .49041 .54727 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.45942 .58411 m .47006 .53845 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .48036 .59043 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .48044 .59006 L p .4807 .59023 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .4807 .59023 L .48314 .59193 L .707 .577 .707 r
F
.48585 .60387 m .46597 .60045 L p .4665 .5983 L F P
0 g
s
.4807 .59023 m .48585 .60387 L p .4665 .5983 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .4807 .59023 L p .48557 .59362 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .50247 .55515 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48044 .59006 m .49041 .54727 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .4879 .58288 L .48868 .59578 L .707 .577 .707 r
F
.50247 .55515 m .49249 .598 L p .4879 .58288 L F P
0 g
s
.49744 .57675 m .50247 .55515 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .46564 .62137 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48547 .61686 m .48114 .60539 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.47759 .62102 m .48503 .6205 L p .48483 .61719 L .707 .577 .707 r
F P
0 g
s
.78152 .53561 m .77592 .58608 L .74489 .58005 L p .707 .577 .707 r
F P
0 g
s
.74489 .58005 m .75049 .52959 L .78152 .53561 L p .707 .577 .707 r
F P
0 g
s
.71321 .57873 m .71881 .52827 L .75049 .52959 L p .707 .577 .707 r
F P
0 g
s
.71881 .52827 m .71321 .57873 L .68398 .58225 L p .707 .577 .707 r
F P
0 g
s
.30818 .58321 m .32108 .52784 L .30902 .51996 L p .707 .577 .707 r
F P
0 g
s
.66117 .68033 m .65977 .69768 L .64341 .70832 L p .707 .577 .707 r
F P
0 g
s
.75049 .52959 m .74489 .58005 L .71321 .57873 L p .707 .577 .707 r
F P
0 g
s
.82225 .64396 m .82782 .68196 L .80658 .68642 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .80101 .64842 L .82225 .64396 L p .707 .577 .707 r
F P
0 g
s
.32963 .66963 m .3422 .70289 L .36814 .7013 L p .707 .577 .707 r
F P
0 g
s
.44847 .70342 m .44524 .722 L .46908 .72185 L p .707 .577 .707 r
F P
0 g
s
.46908 .72185 m .47231 .70326 L .44847 .70342 L p .707 .577 .707 r
F P
0 g
s
.68231 .66611 m .68788 .70411 L .66444 .70631 L p .707 .577 .707 r
F P
0 g
s
.30902 .51996 m .29612 .57534 L .30818 .58321 L p .707 .577 .707 r
F P
0 g
s
.82567 .69595 m .82428 .71329 L .80332 .70163 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .77915 .69134 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80101 .64842 m .80276 .66035 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80276 .66035 m .80658 .68642 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .80471 .68428 L .82022 .69291 L p .707 .577 .707 r
F P
0 g
s
.82022 .69291 m .82567 .69595 L p .82231 .6968 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .82022 .69291 L .82231 .6968 L .707 .577 .707 r
F
.68788 .70411 m .6827 .66876 L p .71117 .66265 L F P
0 g
s
.6827 .66876 m .68231 .66611 L .6866 .6656 L p .707 .577 .707 r
F P
0 g
s
.6866 .6656 m .71117 .66265 L p .6827 .66876 L .707 .577 .707 r
F P
0 g
s
.65977 .69768 m .66067 .68657 L p .68519 .67294 L .707 .577 .707 r
F P
0 g
s
.66067 .68657 m .66117 .68033 L .67281 .67675 L p .707 .577 .707 r
F P
0 g
s
.67281 .67675 m .68519 .67294 L p .66067 .68657 L .707 .577 .707 r
F P
0 g
s
.30976 .66621 m .32233 .69947 L .3422 .70289 L p .707 .577 .707 r
F P
0 g
s
.68519 .67294 m .6838 .69029 L .65977 .69768 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .77357 .65335 L .80101 .64842 L p .707 .577 .707 r
F P
0 g
s
.29612 .57534 m .30902 .51996 L .30643 .51381 L p .707 .577 .707 r
F P
0 g
s
.47231 .70326 m .46908 .72185 L .48538 .71915 L p .707 .577 .707 r
F P
0 g
s
.48538 .71915 m .48862 .70056 L .47231 .70326 L p .707 .577 .707 r
F P
0 g
s
.71117 .66265 m .71674 .70064 L .68788 .70411 L p .707 .577 .707 r
F P
0 g
s
.80471 .68428 m .80332 .70163 L .77595 .69282 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .74819 .69624 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77357 .65335 m .77457 .66016 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77457 .66016 m .77915 .69134 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .77735 .67548 L .7964 .68161 L p .707 .577 .707 r
F P
0 g
s
.7964 .68161 m .80471 .68428 L p .80042 .68556 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .7964 .68161 L .80042 .68556 L .707 .577 .707 r
F
.71674 .70064 m .71152 .66504 L p .74262 .65825 L F P
0 g
s
.71152 .66504 m .71117 .66265 L .71645 .66191 L p .707 .577 .707 r
F P
0 g
s
.71645 .66191 m .74262 .65825 L p .71152 .66504 L .707 .577 .707 r
F P
0 g
s
.6838 .69029 m .68444 .68222 L p .71452 .66951 L .707 .577 .707 r
F P
0 g
s
.68444 .68222 m .68519 .67294 L .7022 .67095 L p .707 .577 .707 r
F P
0 g
s
.7022 .67095 m .71452 .66951 L p .68444 .68222 L .707 .577 .707 r
F P
0 g
s
.30643 .51381 m .29353 .56918 L .29612 .57534 L p .707 .577 .707 r
F P
0 g
s
.29755 .66581 m .29431 .68439 L .30654 .69228 L p .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .74334 .66322 L p .77357 .65335 L .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .71674 .70064 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74262 .65825 m .74296 .66063 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74296 .66063 m .74819 .69624 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .74488 .68773 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.77735 .67548 m .7767 .6836 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.7767 .6836 m .77595 .69282 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.71312 .68686 m .71358 .68119 L p .74627 .67039 L .707 .577 .707 r
F P
0 g
s
.71358 .68119 m .71452 .66951 L .73211 .67 L p .707 .577 .707 r
F P
0 g
s
.73211 .67 m .74627 .67039 L p .71358 .68119 L .707 .577 .707 r
F P
0 g
s
.74334 .66322 m .74262 .65825 L .75476 .65633 L p .707 .577 .707 r
F P
0 g
s
.75476 .65633 m .77357 .65335 L p .74334 .66322 L .707 .577 .707 r
F P
0 g
s
.71452 .66951 m .71312 .68686 L .6838 .69029 L p .707 .577 .707 r
F P
0 g
s
.74488 .68773 m .74627 .67039 L .77735 .67548 L p .707 .577 .707 r
F P
0 g
s
.74627 .67039 m .74488 .68773 L .71312 .68686 L p .707 .577 .707 r
F P
0 g
s
.48862 .70056 m .48538 .71915 L .49256 .71417 L p .707 .577 .707 r
F P
0 g
s
.49256 .71417 m .49579 .69559 L .48862 .70056 L p .707 .577 .707 r
F P
0 g
s
.29353 .56918 m .30643 .51381 L .31356 .50998 L p .707 .577 .707 r
F P
0 g
s
.29431 .68439 m .29755 .66581 L .29489 .65904 L p .707 .577 .707 r
F P
0 g
s
.29489 .65904 m .29165 .67763 L .29431 .68439 L p .707 .577 .707 r
F P
0 g
s
.31356 .50998 m .30066 .56535 L .29353 .56918 L p .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .31045 .69137 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.29672 .6502 m .30775 .67939 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .29517 .64612 L .3019 .63142 L p .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29489 .65904 L .29977 .65566 L p .707 .577 .707 r
F P
0 g
s
.29977 .65566 m .30206 .65407 L p .30066 .65726 L .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29977 .65566 L .30066 .65726 L .707 .577 .707 r
F
.29517 .64612 m .29672 .6502 L p .2963 .64946 L F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .69559 m .49256 .71417 L .4899 .70741 L p .707 .577 .707 r
F P
0 g
s
.4899 .70741 m .49314 .68883 L .49579 .69559 L p .707 .577 .707 r
F P
0 g
s
.30066 .56535 m .31356 .50998 L .32971 .50885 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30206 .65407 m .29883 .67265 L .29165 .67763 L p .707 .577 .707 r
F P
0 g
s
.32971 .50885 m .31681 .56422 L .30066 .56535 L p .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .30775 .67939 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.30525 .6403 m .31447 .66469 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .3019 .63142 L .31739 .61545 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31447 .66469 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31739 .61545 m .32333 .63117 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.32333 .63117 m .32996 .64871 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .31837 .65137 L .34123 .65122 L p .707 .577 .707 r
F P
0 g
s
.34123 .65122 m .34221 .65121 L p .3416 .65163 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .34123 .65122 L .3416 .65163 L .707 .577 .707 r
F
.29883 .67265 m .30206 .65407 L .31761 .6515 L p F P
0 g
s
.31761 .6515 m .31837 .65137 L p .31796 .65181 L .707 .577 .707 r
F P
0 g
s
.29883 .67265 m .31761 .6515 L .31796 .65181 L .707 .577 .707 r
F
.3019 .63142 m .30525 .6403 L p .3027 .63799 L F P
0 g
s
.49314 .68883 m .4899 .70741 L .47767 .69952 L p .707 .577 .707 r
F P
0 g
s
.47767 .69952 m .4809 .68094 L .49314 .68883 L p .707 .577 .707 r
F P
0 g
s
.31681 .56422 m .32971 .50885 L .35331 .51053 L p .707 .577 .707 r
F P
0 g
s
.35331 .51053 m .34041 .5659 L .31681 .56422 L p .707 .577 .707 r
F P
0 g
s
.31837 .65137 m .31513 .66995 L .29883 .67265 L p .707 .577 .707 r
F P
0 g
s
.34041 .5659 m .35331 .51053 L .38204 .51486 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31739 .61545 L .34014 .59976 L p .707 .577 .707 r
F P
0 g
s
.4809 .68094 m .47767 .69952 L .45706 .69127 L p .707 .577 .707 r
F P
0 g
s
.45706 .69127 m .4603 .67269 L .4809 .68094 L p .707 .577 .707 r
F P
0 g
s
.38204 .51486 m .36914 .57023 L .34041 .5659 L p .707 .577 .707 r
F P
0 g
s
.40019 .57678 m .41309 .5214 L .44342 .52953 L p .707 .577 .707 r
F P
0 g
s
.36914 .57023 m .38204 .51486 L .41309 .5214 L p .707 .577 .707 r
F P
0 g
s
.34221 .65121 m .33897 .66979 L .31513 .66995 L p .707 .577 .707 r
F P
0 g
s
.34014 .59976 m .35272 .63303 L .32996 .64871 L p .707 .577 .707 r
F P
0 g
s
.35272 .63303 m .34014 .59976 L .36792 .58591 L p .707 .577 .707 r
F P
0 g
s
.36792 .58591 m .3805 .61917 L .35272 .63303 L p .707 .577 .707 r
F P
0 g
s
.4603 .67269 m .45706 .69127 L .4301 .68348 L p .707 .577 .707 r
F P
0 g
s
.4301 .68348 m .43333 .6649 L .4603 .67269 L p .707 .577 .707 r
F P
0 g
s
.33897 .66979 m .34221 .65121 L .37125 .65361 L p .707 .577 .707 r
F P
0 g
s
.37125 .65361 m .36801 .67219 L .33897 .66979 L p .707 .577 .707 r
F P
0 g
s
.43333 .6649 m .4301 .68348 L .39941 .67691 L p .707 .577 .707 r
F P
0 g
s
.39941 .67691 m .40265 .65832 L .43333 .6649 L p .707 .577 .707 r
F P
0 g
s
.36801 .67219 m .37125 .65361 L .40265 .65832 L p .707 .577 .707 r
F P
0 g
s
.40265 .65832 m .39941 .67691 L .36801 .67219 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001LOol50004Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol300000eYF001JEP02FUH80006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH80008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1P002eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo011oo`l004Eoo`00EWoo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo00Yoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@0045oo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol01Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000?Goo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool30006FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P00>Goo001EOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000gOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oo`0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<003Eoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=o
o`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00
E7oo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00
Dgoo00<005YF000030001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`0000=JEP00FUH02eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000;goo001COol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP040002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH02@00FUIJEUYF001JEP00FUH0000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00EJEPH000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo001DOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH00eYF1P002EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00
Egoo00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF100015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEPH000moo`@0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Qoo`8000=JEP03001JEUYF00EJEP03
001JEUYF008000QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EP03001JEP0000<001Uoo`@000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00FWoo0P00
00=JEP00FUH01UYF10002EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool005aoo`<000EJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00Oomoo`0SOol300000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00Ggoo1@001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF001JEP00
00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000
00005Woo0`003goo0P001EYF00L005YFFUIJEP00FUH0000/Ool0061oo`8000QJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF0`004goo1@0047oo0P000eYF00L005YF
FUIJEP00FUH0000/Ool005moo`8000UJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEPD00003
FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEUYFFUH00002FUH00`00Oomoo`0@Ool5000BOol01000FUIJEP000eYF0P00;Goo001NOol01000
FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YF00000P00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF00@005YFFUIJEP80011oo`D001=oo`<000=JEP8002eoo`00G7oo0P000eYF00<005YFFUH01eYF
00<005YFFUH01EYF100025YF00<005YFFUH015YF0`0000=JEP0000000P000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH00eYF0P003goo0`00
5Woo00@005YFFUIJEP8002eoo`00Fgoo00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00D005YF001JEP0000=JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01EYF0P00
9Woo0P0000AJEP00FUH002eoo`00F7oo0`001eYF00<005YFFUH01eYF00<005YF00000P000eYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01eYF0`008Goo0P0000IJEP00
FUH005YF000]Ool004moo`T00003FUH0000000MJEP03001JEUYF00MJEP800003FUH005YF00MJEP03
001JEP0000X0009JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEP0015YF00<005YFFUH02eYF1P005goo100000AJEP00FUIJEP800003FUH007oo02aoo`00AWoo
2@0015YF00@005YFFUIJEP800003FUH0000000MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000EJEP80009JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEP0015YF00<005YFFUH04EYF2@002Goo1@001EYF00L005YFFUIJEP00FUH0000]Ool0
03ioo`P000eJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH30006FUH0
0`00FUIJEP06FUH01@00FUIJEUYF000015YF0P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF01YJEPT000=JEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Goo000`Ool>000EFUH00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUH000020005FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH07UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0`00
0UYF00<005YFFUH015YF00<005YFFUH05eYF0`001EYF0P001eYF0P000UYF00<005YFFUH00eYF1@00
1EYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF01QJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00mJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00=JEP800005FUH005YFFUH0
0005FUH50005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0:000^Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00EJEP04001JEUYF0005FUH0
1000FUIJEUYF0P000eYF00@005YFFUH000IJEP<000IJEP03001JEUYF00<000QJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH01000FUIJEUYF1`000eYF00@005YF
FUIJEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH0
1EYF00<005YFFUH00P001EYF0`0000=JEP00FUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP<0
00=JEP03001JEUYF00EJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH00eYF1@0000=JEP000000;Woo000[Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJ
EP04001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF
1`000UYF00@005YFFUIJEP8002ioo`00:goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP8000MJEP03001JEUYF00IJEP03001JEUYF01D000=JEP03001JEUYF00=JEP8000QJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF00=JEP04001JEUYF0006FUH60004FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30002FUH30002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009J
EP03001JEUYF00IJEP03001JEUYF009JEP8000YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP800003FUH00000
00EJEP03001JEP0000MJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040007FUH01@00FUIJ
EUYF000035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000010000UYF00<005YFFUH01EYF2@000eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
FUH000EJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@000AJEP@000aJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH3000015YF001JEUYF2`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH000MJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00009JEPd000AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000@0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00P000EJEP80009JEQ4000IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH0000000=JEP03
001JEUYF00AJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01UYF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
;Goo000/Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF0P001UYF1`001UYF00<005YF
FUH01EYF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH60005FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002aoo`04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00005FUH20003FUH00`00FUH00004FUH0
0`00FUIJEP04FUH20008FUH30002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF
009JEP<0031oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00eYF3@001eYF00D0
05YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP@000EJ
EP03001JEUYF00AJEP<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<00004FUH00000000cOol002eoo`03001JEP0000=JEP03001JEUYF009JEPP000QJEP04
001JEUYFFUH30004FUH300001EYF000005YF000015YF00<005YFFUH015YF0P001UYF1@000eYF0`00
0eYF100000=JEP00FUH01EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006FUH0
0`00FUIJEP05FUH3000fOol002eoo`03001JEP00009JEP04001JEUYFFUH20007FUH00`00FUIJEP02
FUH90002Ool3000015YF001JEUYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH015YF
20000UYF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH60004
FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eo
o`<0009JEP03001JEP0000l000ioo`<000=JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00QJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUH0000300000eYF00000007FUH0
0`00FUIJEP04FUH700000goo000000020006FUH00`00FUIJEP02FUH2000bOol002eoo`03001JEP00
009JEP<0021oo`8000=JEP@000=JEP03001JEUYF00AJEP03001JEUYF00P000EJEP03001JEUYF00UJ
EP04001JEP000003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP04000<Ool40002FUH00`00FUIJ
EP03FUH2000aOol002eoo`05FUH005YFFUH0000UOol300000eYF0000000>0003FUH00`00FUIJEP02
FUH80008FUH60002FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1P0057oo0`001EYF00<005YF0000
<7oo000]Ool015YF001JEP00:Goo0P000eYF100000=JEP00FUH025YF00<005YFFUH01UYF00@005YF
FUIJEPP000=JEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEUYFFUH40002FUH=000MOol20003FUH01000FUIJEP00;goo000]Ool00eYF0000000/Ool0
0`00FUIJEP02FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPH000EJEP03001JEUYF00=JEP8001moo`800003FUH005YF009JEP03001oogoo02aoo`00;7oo
00<005YF0000;Woo00D005YFFUIJEP0000=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo021oo`8000=JEP03001oogoo02aoo`00;7oo0`00;goo0P0000=JEP00FUH00UYF00@005YFFUH0
009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol027oo0`005goo00@005YFFUH002ioo`00;7oo1000<7oo0P000eYF00@0
05YFFUH000IJEP03001JEUYF00P000AJEP03001JEUYF00AJEP03001JEUYF00<000IJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000Yoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`05001JEP00FUH0000GOol3000F
Ool01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00003@002EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF
00AJEP04001JEUYF000;Ool5000GOol200000eYF001oo`0/Ool002aoo`05001JEP00FUH0000FOol5
000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<0
05YF00001eYF0P0037oo1@0067oo00<005YF0000;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0C
Ool5000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=J
EP8000IJEP8000ioo`<001Uoo`03001JEP0002eoo`00;7oo0P0015YF00<007ooOol04Woo1@005goo
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP<000=JEP8002aoo`80
02ioo`00;7oo0P0015YF0`004goo0`0067oo0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YFFUH0009JEP<002ioo`8002ioo`00;Goo00<005YFFUH00UYF00@005YFFUH0
02ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP8002aoo`@002ioo`00;Goo00D005YFFUIJEP0000AJEP8002aoo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000005FUH2000XOol20002FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00006
FUH00`00Oomoo`0YOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF1P0025YF
00<005YFFUH02UYF2P001eYF00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YF00000`00
8Woo0P000eYF0P00;goo000^Ool01000FUIJEP001UYF0`009goo0P0000EJEP00FUIJEP0000IJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP03FUH5000IOol40000
0eYF001JEP02FUH00`00Oomoo`0^Ool002ioo`04001JEUYF0006FUH00`00FUIJEP02000TOol00`00
FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000<7oo000_Ool20006FUH0
0`00FUIJEP03FUH20009OolN0002FUH00`00FUIJEP03FUH400000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH00`00FUIJEP02000aOol0
02moo`8000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<005YFFUH01UYF
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo
000`Ool00`00FUIJEP04FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF
00AJEP80009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8003Eoo`00<Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00
0UYF2P0015YF1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=goo000_Ool3
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001eYF
00<005YF00000P0000AJEP000000009oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003Yo
o`00;Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
5P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF009JEP80009J
EP03001oogoo00=ooa00041oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
4P001eYF00<005YFFUH00eYF00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEUYF008000MJEP03001JEUYF009JEPD005Aoo`00;Goo00<005YF000015YF00@005YFFUIJ
EPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF009JEP03001JEUYF
008005Aoo`00;Goo00<005YF00000eYF1@0000=JEP0000000eYF00<005YFFUH01UYF0P0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH02`0015YF00<005YF0000EGoo000]Ool01000FUH005YF0P0015YF00@005YFFUIJEP800003
FUH005YF00MJEP8000QJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=oo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEP00FUH200000eYF001JEP05FUH300000eYF001JEP02
001DOol002eoo`03001JEP00008000EJEP03001JEUYF00=JEP@000IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000Qoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
00AJEP8000IJEP03001JEUYF0080009JEP03001oogoo059oo`00;Goo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF1@003Goo0P00
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YF000000AJEP04001JEUYF
FUH4001DOol002ioobL001Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH200000eYF
001JEP02FUH00`00FUH00002001DOol006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00AJ
EP8000=JEP<00003FUH0000005=oo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`000goo100000=JEP00FUH01UYF00<005YF
00000P0000=JEP0000000UYF00<007ooOol0DGoo001_Ool300000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40009Ool50003FUH00`00FUIJEP02
FUH01000FUH000000UYF00<007ooOol0DGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000=Ool50002FUH30002FUH2001DOol007Uoo`/000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0015oo`H0009JEP8005Aoo`00Q7oo6P002goo1@00
3goo0P000UYF00<005YFFUH00eYF00<007ooOol0Dgoo002?Ool01000FUIJEP005goo0`003Woo0P00
15YF00@005YFFUIJEP8005Ioo`00Sgoo00<005YF00009goo0P001eYF0`00F7oo002@Ool2000SOol4
00000eYF001JEP06FUH00`00Oomoo`1HOol0091oo`03001JEP0001eoo`D000EJEP03001JEUYF00=J
EP8005]oo`00T7oo00<005YFFUH00`005Woo10000UYF00<005YFFUH01UYF00<005YFFUH00P00GGoo
002@Ool01000FUIJEP000UYF5P001UYF00<005YFFUH01UYF0`00Ggoo002@Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P00HGoo002AOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
Hgoo002BOol30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001WOol009Ao
o`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@006aoo`00Ugoo5P00L7oo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63086 .75143 m .61796 .69895 L .58691 .70655 L p .707 .577 .707 r
F P
0 g
s
.61796 .69895 m .63086 .75143 L .65959 .74084 L p .707 .577 .707 r
F P
0 g
s
.65959 .74084 m .64669 .68836 L .61796 .69895 L p .707 .577 .707 r
F P
0 g
s
.59981 .75903 m .58691 .70655 L .55658 .71042 L p .707 .577 .707 r
F P
0 g
s
.58691 .70655 m .59981 .75903 L .63086 .75143 L p .707 .577 .707 r
F P
0 g
s
.64669 .68836 m .65959 .74084 L .68318 .72828 L p .707 .577 .707 r
F P
0 g
s
.68318 .72828 m .67029 .6758 L .64669 .68836 L p .707 .577 .707 r
F P
0 g
s
.55996 .78187 m .58941 .79288 L p .5817 .77138 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .55658 .71042 L .56309 .75438 L .707 .577 .707 r
F
.56863 .75944 m .56851 .75894 L p .56798 .75885 L F P
0 g
s
.56851 .75894 m .55658 .71042 L p .56798 .75885 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .52994 .71016 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .56863 .75944 L p .59981 .75903 L .707 .577 .707 r
F P
0 g
s
.5817 .77138 m .57771 .76025 L .56863 .75944 L .707 .577 .707 r
F
.56798 .75885 m .55996 .78187 L p .5817 .77138 L F P
0 g
s
.58508 .76091 m .59981 .75903 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.58941 .79288 m .60198 .75682 L .57253 .74581 L p .707 .577 .707 r
F P
0 g
s
.56863 .75944 m .56948 .7629 L .58508 .76091 L p .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .56798 .75885 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.57771 .76025 m .57253 .74581 L .56863 .75944 L .707 .577 .707 r
F
.55996 .78187 m .56798 .75885 L p .55262 .75603 L F P
0 g
s
.53402 .77088 m .55996 .78187 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54001 .75371 m .53402 .77088 L p .54715 .76039 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54067 .75383 L .54715 .76039 L .707 .577 .707 r
F
.54067 .75383 m .54001 .75371 L .54715 .76039 L F
.52994 .71016 m .50959 .70582 L p .53334 .74641 L F P
0 g
s
.54015 .75331 m .52994 .71016 L .53334 .74641 L .707 .577 .707 r
F
.54067 .75383 m .54057 .75344 L p .54015 .75331 L F P
0 g
s
.54057 .75344 m .52994 .71016 L p .54015 .75331 L .707 .577 .707 r
F P
0 g
s
.53402 .77088 m .54015 .75331 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.52994 .71016 m .54067 .75383 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .54015 .75331 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54001 .75371 L p .54067 .75383 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54015 .75331 L .54067 .75383 L .707 .577 .707 r
F
.54283 .76264 m .54067 .75383 L p .53334 .74641 L F P
0 g
s
.51415 .76098 m .53402 .77088 L p .5335 .76757 L .707 .577 .707 r
F P
0 g
s
.5335 .76757 m .53075 .75029 L .52463 .75423 L .707 .577 .707 r
F
.5335 .76757 m .52463 .75423 L .51415 .76098 L F
.50959 .70582 m .49753 .69781 L p .51455 .73905 L F P
0 g
s
.5193 .7462 m .50959 .70582 L .51455 .73905 L .707 .577 .707 r
F
.51964 .74672 m .51955 .74637 L p .5193 .7462 L F P
0 g
s
.51955 .74637 m .50959 .70582 L p .5193 .7462 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .5193 .7462 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50959 .70582 m .51964 .74672 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.52672 .72493 m .5193 .7462 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.5193 .7462 m .51917 .74657 L p .51964 .74672 L .707 .577 .707 r
F P
0 g
s
.53075 .75029 m .5193 .7462 L .51964 .74672 L .707 .577 .707 r
F
.51917 .74657 m .51415 .76098 L p .53075 .75029 L F P
0 g
s
.52249 .7583 m .51964 .74672 L p .51455 .73905 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .51443 .74311 L .50961 .74709 L .707 .577 .707 r
F
.50227 .75316 m .51275 .76007 L p .50961 .74709 L F P
0 g
s
.51275 .76007 m .51415 .76098 L p .50961 .74709 L .707 .577 .707 r
F P
0 g
s
.51686 .74465 m .5121 .73312 L .5076 .73877 L .707 .577 .707 r
F
.49753 .69781 m .50751 .73842 L p .5121 .73312 L F P
0 g
s
.50751 .73842 m .5076 .73877 L p .5121 .73312 L .707 .577 .707 r
F P
0 g
s
.50734 .73861 m .50227 .75316 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.5076 .73877 m .51043 .75029 L p .51686 .74465 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .49753 .69781 L .50596 .73201 L .705 .576 .708 r
F
.5076 .73877 m .50751 .73842 L p .50747 .73824 L F P
0 g
s
.50751 .73842 m .49753 .69781 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.50734 .73861 m .50747 .73824 L p .50516 .74113 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .51484 .7171 L p .50705 .73644 L .707 .577 .707 r
F P
0 g
s
.50713 .73679 m .50747 .73824 L .50596 .73201 L .705 .576 .708 r
F
.51484 .7171 m .50747 .73824 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .50734 .73861 L p .5076 .73877 L .707 .577 .707 r
F P
0 g
s
.51443 .74311 m .50747 .73824 L .5076 .73877 L .707 .577 .707 r
F
.51484 .7171 m .51214 .71211 L p .50667 .73484 L F P
0 g
s
.50705 .73644 m .51484 .7171 L .50667 .73484 L .707 .577 .707 r
F
.50713 .73679 m .50596 .73201 L .50658 .73443 L .705 .576 .708 r
F
.49956 .74816 m .50227 .75316 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50207 .6742 L p .50664 .72587 L .707 .577 .707 r
F P
0 g
s
.51214 .71211 m .50582 .73021 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50582 .73021 L .50572 .73077 L .707 .577 .707 r
F
.52672 .72493 m .51484 .7171 L p .51443 .74311 L F P
0 g
s
.51214 .71211 m .51886 .71043 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50572 .73077 L p .50582 .73021 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50582 .73021 L .50695 .72931 L .707 .577 .707 r
F
.50572 .73077 m .49494 .68691 L p .50664 .72587 L F P
0 g
s
.50582 .73021 m .50568 .73061 L p .50572 .73077 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50192 .71532 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50596 .73201 m .50432 .72525 L .50784 .73939 L .705 .576 .708 r
F
.50192 .71532 m .50562 .73037 L p .50432 .72525 L F P
0 g
s
.50562 .73037 m .50784 .73939 L p .50432 .72525 L .705 .576 .708 r
F P
0 g
s
.50582 .73021 m .51214 .71211 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .50784 .73939 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.51886 .71043 m .51453 .72285 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .51419 .7235 L p .51453 .72285 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51886 .71043 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51517 .72267 m .51453 .72285 L .51522 .72153 L .707 .577 .707 r
F
.51497 .72668 m .51453 .72285 L .51517 .72267 L F
.51886 .71043 m .53435 .71224 L p .52914 .7186 L F P
0 g
s
.51419 .7235 m .51497 .72668 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .51043 .75029 L p .50713 .73679 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .5076 .73877 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .50747 .73824 L .50713 .73679 L .705 .576 .708 r
F
.51822 .66092 m .53112 .7134 L .51497 .72668 L p .707 .577 .707 r
F P
0 g
s
.50629 .74649 m .51453 .72285 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51435 .72337 L p .51419 .7235 L .707 .577 .707 r
F P
0 g
s
.51078 .72624 m .51453 .72285 L .51419 .7235 L .707 .577 .707 r
F
.50207 .6742 m .51822 .66092 L p .51522 .72153 L F P
0 g
s
.51419 .7235 m .50207 .6742 L p .51522 .72153 L .707 .577 .707 r
F P
0 g
s
.50207 .6742 m .51419 .7235 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50658 .73444 L .49956 .74816 L .707 .577 .707 r
F
.49753 .69781 m .49494 .68691 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50658 .73444 m .50568 .73061 L .49956 .74816 L .707 .577 .707 r
F
.50713 .73679 m .50658 .73443 L .50784 .73939 L .705 .576 .708 r
F
.50747 .73824 m .50705 .73644 L .50516 .74113 L .707 .577 .707 r
F
.50516 .74113 m .50705 .73644 L .50667 .73484 L F
.50227 .75316 m .50734 .73861 L p .50516 .74113 L F P
0 g
s
.50629 .74649 m .49956 .74816 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51435 .72337 m .50629 .74649 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50663 .73435 m .50582 .73021 L .51078 .72624 L .707 .577 .707 r
F
.49956 .74816 m .50568 .73061 L p .50663 .73435 L F P
0 g
s
.50568 .73061 m .50582 .73021 L p .50663 .73435 L .707 .577 .707 r
F P
0 g
s
.50695 .72931 m .50582 .73021 L .50664 .72587 L .707 .577 .707 r
F
.51043 .75029 m .52249 .7583 L p .51686 .74465 L F P
0 g
s
.5193 .7462 m .52672 .72493 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.52249 .7583 m .54283 .76264 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.51964 .74672 m .52249 .7583 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .52672 .72493 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54659 .73482 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54283 .76264 m .56948 .7629 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54067 .75383 m .54283 .76264 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .54659 .73482 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.56948 .7629 m .56863 .75944 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .57253 .74581 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.60198 .75682 m .58941 .79288 L .6195 .80283 L p .707 .577 .707 r
F P
0 g
s
.6195 .80283 m .63207 .76678 L .60198 .75682 L p .707 .577 .707 r
F P
0 g
s
.63207 .76678 m .6195 .80283 L .64728 .81075 L p .707 .577 .707 r
F P
0 g
s
.64728 .81075 m .65985 .7747 L .63207 .76678 L p .707 .577 .707 r
F P
0 g
s
.67029 .6758 m .68318 .72828 L .69934 .715 L p .707 .577 .707 r
F P
0 g
s
.69934 .715 m .68644 .66252 L .67029 .6758 L p .707 .577 .707 r
F P
0 g
s
.65985 .7747 m .64728 .81075 L .67003 .81587 L p .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .6826 .77982 L .65985 .7747 L p .707 .577 .707 r
F P
0 g
s
.60058 .85912 m .59735 .84127 L .56666 .84374 L p .707 .577 .707 r
F P
0 g
s
.59735 .84127 m .60058 .85912 L .63198 .85316 L p .707 .577 .707 r
F P
0 g
s
.63198 .85316 m .62875 .83531 L .59735 .84127 L p .707 .577 .707 r
F P
0 g
s
.62875 .83531 m .63198 .85316 L .66102 .84432 L p .707 .577 .707 r
F P
0 g
s
.66102 .84432 m .65779 .82646 L .62875 .83531 L p .707 .577 .707 r
F P
0 g
s
.56666 .84374 m .5699 .86159 L .60058 .85912 L p .707 .577 .707 r
F P
0 g
s
.5699 .86159 m .56666 .84374 L .5397 .8425 L p .707 .577 .707 r
F P
0 g
s
.68644 .66252 m .69934 .715 L .70647 .70229 L p .707 .577 .707 r
F P
0 g
s
.70647 .70229 m .69357 .64981 L .68644 .66252 L p .707 .577 .707 r
F P
0 g
s
.65779 .82646 m .66102 .84432 L .68486 .83344 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .68163 .81559 L .65876 .82602 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .70117 .82161 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68163 .81559 m .68175 .81626 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68175 .81626 m .68486 .83344 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .69793 .80376 L .68238 .81504 L p .707 .577 .707 r
F P
0 g
s
.68238 .81504 m .68163 .81559 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .68238 .81504 L .68203 .81572 L .707 .577 .707 r
F
.69225 .81601 m .70482 .77995 L .69999 .78116 L p F P
0 g
s
.69999 .78116 m .6981 .78163 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69225 .81601 m .69999 .78116 L .6973 .78633 L .707 .577 .707 r
F
.68553 .81768 m .69225 .81601 L p .6973 .78633 L F P
0 g
s
.6981 .78163 m .69474 .79125 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69474 .79125 m .68553 .81768 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .68553 .81768 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.6826 .77982 m .67666 .79686 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.67666 .79686 m .67003 .81587 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.65876 .82602 m .65779 .82646 L p .65839 .82662 L .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .65876 .82602 L .65839 .82662 L .707 .577 .707 r
F
.5397 .8425 m .54293 .86035 L .5699 .86159 L p F P
0 g
s
.68553 .81768 m .6981 .78163 L .6826 .77982 L p .707 .577 .707 r
F P
0 g
s
.54293 .86035 m .5397 .8425 L .51909 .83767 L p .707 .577 .707 r
F P
0 g
s
.51909 .83767 m .52233 .85552 L .54293 .86035 L p .707 .577 .707 r
F P
0 g
s
.69357 .64981 m .70647 .70229 L .70388 .6914 L p .705 .576 .708 r
F P
0 g
s
.70388 .6914 m .69098 .63892 L .69357 .64981 L p .705 .576 .708 r
F P
0 g
s
.52233 .85552 m .51909 .83767 L .50686 .82971 L p .707 .577 .707 r
F P
0 g
s
.69793 .80376 m .70117 .82161 L .70834 .80997 L p .707 .577 .707 r
F P
0 g
s
.70834 .80997 m .70511 .79212 L .69793 .80376 L p .707 .577 .707 r
F P
0 g
s
.50686 .82971 m .5101 .84756 L .52233 .85552 L p .707 .577 .707 r
F P
0 g
s
.48764 .82178 m .48764 .31989 L .44383 .31698 L p .707 .577 .707 r
F P
0 g
s
.5101 .84756 m .50686 .82971 L .5042 .8194 L p .707 .578 .707 r
F P
0 g
s
.5042 .8194 m .50744 .83725 L .5101 .84756 L p .707 .578 .707 r
F P
0 g
s
.50744 .83725 m .5042 .8194 L .51138 .80776 L p .707 .577 .707 r
F P
0 g
s
.51138 .80776 m .51461 .82562 L .50744 .83725 L p .707 .577 .707 r
F P
0 g
s
.53435 .71224 m .52178 .7483 L .50629 .74649 L p .707 .577 .707 r
F P
0 g
s
.53112 .7134 m .51822 .66092 L .54182 .64837 L p .707 .577 .707 r
F P
0 g
s
.51461 .82562 m .51138 .80776 L .52768 .79593 L p .707 .577 .707 r
F P
0 g
s
.52178 .7483 m .53435 .71224 L .55711 .71736 L p .707 .577 .707 r
F P
0 g
s
.52768 .79593 m .53092 .81378 L .51461 .82562 L p .707 .577 .707 r
F P
0 g
s
.55711 .71736 m .54453 .75341 L .52178 .7483 L p .707 .577 .707 r
F P
0 g
s
.53092 .81378 m .52768 .79593 L .55152 .78506 L p .707 .577 .707 r
F P
0 g
s
.55152 .78506 m .55476 .80291 L .53092 .81378 L p .707 .577 .707 r
F P
0 g
s
.48764 .31989 m .48764 .82178 L .53266 .82092 L p .707 .577 .707 r
F P
0 g
s
.54182 .64837 m .55472 .70085 L .53112 .7134 L p .707 .577 .707 r
F P
0 g
s
.53266 .82092 m .53266 .31903 L .48764 .31989 L p .707 .577 .707 r
F P
0 g
s
.55472 .70085 m .54182 .64837 L .57055 .63777 L p .707 .577 .707 r
F P
0 g
s
.57055 .63777 m .58345 .69025 L .55472 .70085 L p .707 .577 .707 r
F P
0 g
s
.54453 .75341 m .55711 .71736 L .58489 .72528 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .57231 .76134 L .54453 .75341 L p .707 .577 .707 r
F P
0 g
s
.55476 .80291 m .55152 .78506 L .58056 .77621 L p .707 .577 .707 r
F P
0 g
s
.58056 .77621 m .5838 .79406 L .55476 .80291 L p .707 .577 .707 r
F P
0 g
s
.53266 .31903 m .53266 .82092 L .57447 .81636 L p .707 .577 .707 r
F P
0 g
s
.58345 .69025 m .57055 .63777 L .6016 .63017 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .61498 .73524 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.57231 .76134 m .58036 .73825 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.58036 .73825 m .58489 .72528 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.63193 .62631 m .64483 .67879 L .6145 .68265 L p .707 .577 .707 r
F P
0 g
s
.6145 .68265 m .6016 .63017 L .63193 .62631 L p .707 .577 .707 r
F P
0 g
s
.6016 .63017 m .6145 .68265 L .58345 .69025 L p .707 .577 .707 r
F P
0 g
s
.67036 .75724 m .65779 .79329 L .63186 .7823 L p .707 .577 .707 r
F P
0 g
s
.63186 .7823 m .64443 .74625 L .67036 .75724 L p .707 .577 .707 r
F P
0 g
s
.64443 .74625 m .63186 .7823 L .61088 .77446 L p .707 .577 .707 r
F P
0 g
s
.61088 .77446 m .6024 .77129 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61131 .76598 m .64443 .74625 L .61088 .77446 L .707 .577 .707 r
F
.64483 .67879 m .63193 .62631 L .65857 .62656 L p F P
0 g
s
.65779 .79329 m .66927 .76036 L p .69024 .76713 L .707 .577 .707 r
F P
0 g
s
.64588 .78563 m .64379 .77411 L p .66961 .76902 L .707 .577 .707 r
F P
0 g
s
.64379 .77411 m .64265 .76778 L .65452 .76832 L p .707 .577 .707 r
F P
0 g
s
.65452 .76832 m .66961 .76902 L p .64379 .77411 L .707 .577 .707 r
F P
0 g
s
.66927 .76036 m .67036 .75724 L .67281 .75846 L p .707 .577 .707 r
F P
0 g
s
.67281 .75846 m .69024 .76713 L p .66927 .76036 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .64443 .74625 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.6024 .77129 m .61252 .74227 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61252 .74227 m .61498 .73524 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.64265 .76778 m .64588 .78563 L .6152 .78811 L p .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .64371 .28465 L .63542 .29362 L p .707 .577 .707 r
F P
0 g
s
.63542 .29362 m .63286 .2964 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .63542 .29362 L .63359 .3295 L .707 .577 .707 r
F
.6152 .78811 m .61196 .77026 L .64265 .76778 L p F P
0 g
s
.63286 .79829 m .64371 .78653 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .2964 m .63286 .34386 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .34386 m .63286 .79829 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .6024 .77129 L .57231 .76134 L p .707 .577 .707 r
F P
0 g
s
.5838 .79406 m .58056 .77621 L .61196 .77026 L p .707 .577 .707 r
F P
0 g
s
.61196 .77026 m .6152 .78811 L .5838 .79406 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .63286 .79829 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .30668 m .609 .36022 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .36022 m .609 .80857 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.57447 .81636 m .57447 .31448 L .53266 .31903 L p .707 .577 .707 r
F P
0 g
s
.69098 .63892 m .70388 .6914 L .69182 .68339 L p .707 .577 .707 r
F P
0 g
s
.69182 .68339 m .67892 .63091 L .69098 .63892 L p .707 .577 .707 r
F P
0 g
s
.44383 .81887 m .44383 .31698 L .40553 .31058 L p .707 .577 .707 r
F P
0 g
s
.44383 .31698 m .44383 .81887 L .48764 .82178 L p .707 .577 .707 r
F P
0 g
s
.70482 .77995 m .69225 .81601 L .68954 .81101 L p .707 .577 .707 r
F P
0 g
s
.68954 .81101 m .70181 .77583 L p .70482 .77995 L .707 .577 .707 r
F P
0 g
s
.70211 .77496 m .68954 .81101 L .67767 .80318 L p .707 .577 .707 r
F P
0 g
s
.69345 .7917 m .69274 .78779 L p .70245 .78181 L .707 .577 .707 r
F P
0 g
s
.67767 .80318 m .68999 .76786 L p .70211 .77496 L .707 .577 .707 r
F P
0 g
s
.68999 .76786 m .69024 .76713 L .69069 .76742 L p .707 .577 .707 r
F P
0 g
s
.69069 .76742 m .70211 .77496 L p .68999 .76786 L .707 .577 .707 r
F P
0 g
s
.69024 .76713 m .67767 .80318 L .65779 .79329 L p .707 .577 .707 r
F P
0 g
s
.67285 .78687 m .67148 .77934 L p .69022 .77385 L .707 .577 .707 r
F P
0 g
s
.67148 .77934 m .66961 .76902 L .68304 .77217 L p .707 .577 .707 r
F P
0 g
s
.68304 .77217 m .69022 .77385 L p .67148 .77934 L .707 .577 .707 r
F P
0 g
s
.69274 .78779 m .69022 .77385 L .69899 .77956 L p .707 .577 .707 r
F P
0 g
s
.69899 .77956 m .70245 .78181 L p .69274 .78779 L .707 .577 .707 r
F P
0 g
s
.70181 .77583 m .70211 .77496 L .70226 .77523 L p .707 .577 .707 r
F P
0 g
s
.70226 .77523 m .70482 .77995 L p .70181 .77583 L .707 .577 .707 r
F P
0 g
s
.57447 .31448 m .57447 .81636 L .609 .80857 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .609 .30668 L .57447 .31448 L p .707 .577 .707 r
F P
0 g
s
.70511 .79212 m .70834 .80997 L .70568 .79966 L p .707 .578 .707 r
F P
0 g
s
.70568 .79966 m .70245 .78181 L .70511 .79212 L p .707 .578 .707 r
F P
0 g
s
.40553 .81247 m .40553 .31058 L .37647 .30131 L p .707 .577 .707 r
F P
0 g
s
.40553 .31058 m .40553 .81247 L .44383 .81887 L p .707 .577 .707 r
F P
0 g
s
.25511 .69095 m .24951 .63358 L .21847 .63628 L p .707 .577 .707 r
F P
0 g
s
.24951 .63358 m .25511 .69095 L .28679 .68773 L p .707 .577 .707 r
F P
0 g
s
.28679 .68773 m .28119 .63036 L .24951 .63358 L p .707 .577 .707 r
F P
0 g
s
.67892 .63091 m .69182 .68339 L .67147 .67904 L p .707 .577 .707 r
F P
0 g
s
.67147 .67904 m .65857 .62656 L .67892 .63091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21847 .63628 m .22408 .69365 L .25511 .69095 L p .707 .577 .707 r
F P
0 g
s
.28119 .63036 m .28679 .68773 L .31602 .6843 L p .707 .577 .707 r
F P
0 g
s
.31602 .6843 m .31042 .62694 L .28119 .63036 L p .707 .577 .707 r
F P
0 g
s
.22408 .69365 m .21847 .63628 L .19113 .6382 L p .707 .577 .707 r
F P
0 g
s
.19113 .6382 m .19673 .69556 L .22408 .69365 L p .707 .577 .707 r
F P
0 g
s
.63286 .79829 m .63286 .2964 L .609 .30668 L p .707 .577 .707 r
F P
0 g
s
.31042 .62694 m .31602 .6843 L .33994 .681 L p .707 .577 .707 r
F P
0 g
s
.33994 .681 m .33434 .62364 L .31042 .62694 L p .707 .577 .707 r
F P
0 g
s
.70245 .78181 m .70568 .79966 L .69345 .7917 L p .707 .577 .707 r
F P
0 g
s
.19673 .69556 m .19113 .6382 L .17015 .63914 L p .707 .577 .707 r
F P
0 g
s
.65857 .62656 m .67147 .67904 L .64483 .67879 L p .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .25373 .78052 L .23921 .78123 L p .707 .577 .707 r
F P
0 g
s
.23074 .78642 m .23829 .78179 L .22265 .78204 L .707 .577 .707 r
F
.23776 .7813 m .22265 .78204 L p .23829 .78179 L F P
0 g
s
.22265 .78204 m .22404 .80112 L .25512 .7996 L p .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .22265 .78204 L .20359 .78225 L p .707 .577 .707 r
F P
0 g
s
.20359 .78225 m .19529 .78235 L p .19958 .78515 L .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .20359 .78225 L .19958 .78515 L .707 .577 .707 r
F
.23921 .78123 m .23776 .7813 L p .23829 .78179 L F P
0 g
s
.25512 .7996 m .23921 .78123 L .23074 .78642 L .707 .577 .707 r
F
.22085 .7923 m .25181 .79974 L p .22861 .76424 L F P
0 g
s
.22642 .7609 m .22543 .76653 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22543 .76653 m .22085 .7923 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22085 .7923 m .22493 .76931 L p .19899 .7486 L .707 .577 .707 r
F P
0 g
s
.22493 .76931 m .22642 .7609 L .20627 .75187 L p .707 .577 .707 r
F P
0 g
s
.20627 .75187 m .19899 .7486 L p .22493 .76931 L .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .28688 .79701 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25373 .78052 m .25469 .79373 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25469 .79373 m .25512 .7996 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .28642 .79077 L p .25373 .78052 L .707 .577 .707 r
F P
0 g
s
.28642 .79077 m .28548 .77793 L .26788 .77936 L p .707 .577 .707 r
F P
0 g
s
.26788 .77936 m .25373 .78052 L p .28642 .79077 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .25665 .77245 L p .22642 .7609 L .707 .577 .707 r
F P
0 g
s
.25665 .77245 m .25738 .76834 L .24524 .76542 L p .707 .577 .707 r
F P
0 g
s
.24524 .76542 m .22642 .7609 L p .25665 .77245 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .3162 .79361 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28548 .77793 m .28675 .79528 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28675 .79528 m .28688 .79701 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.3162 .79361 m .31555 .78473 L p .28548 .77793 L .707 .577 .707 r
F P
0 g
s
.31555 .78473 m .31481 .77453 L .2978 .7765 L p .707 .577 .707 r
F P
0 g
s
.2978 .7765 m .28548 .77793 L p .31555 .78473 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .28848 .77218 L p .25738 .76834 L .707 .577 .707 r
F P
0 g
s
.28848 .77218 m .28883 .7702 L .28355 .76989 L p .707 .577 .707 r
F P
0 g
s
.28355 .76989 m .25738 .76834 L p .28848 .77218 L .707 .577 .707 r
F P
0 g
s
.31481 .77453 m .3162 .79361 L .3185 .79324 L p .707 .577 .707 r
F P
0 g
s
.3185 .79324 m .34022 .78973 L p .3263 .7814 L .707 .577 .707 r
F P
0 g
s
.3263 .7814 m .31481 .77453 L .3185 .79324 L .707 .577 .707 r
F
.34022 .78973 m .33933 .7775 L p .31481 .77453 L F P
0 g
s
.33933 .7775 m .33883 .77064 L .32719 .77252 L p .707 .577 .707 r
F P
0 g
s
.32719 .77252 m .31481 .77453 L p .33933 .7775 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .3173 .76847 L p .28883 .7702 L .707 .577 .707 r
F P
0 g
s
.3173 .76847 m .31769 .76629 L .3134 .76687 L p .707 .577 .707 r
F P
0 g
s
.3134 .76687 m .28883 .7702 L p .3173 .76847 L .707 .577 .707 r
F P
0 g
s
.33883 .77064 m .34022 .78973 L .35659 .78574 L p .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .3552 .76666 L .35059 .76778 L p .707 .577 .707 r
F P
0 g
s
.35059 .76778 m .33883 .77064 L p .34763 .77813 L .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .35059 .76778 L .34763 .77813 L .707 .577 .707 r
F
.35129 .77462 m .35778 .75772 L p .357 .74534 L F P
0 g
s
.35686 .74322 m .35565 .75007 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.35565 .75007 m .35129 .77462 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .35129 .77462 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34113 .75699 m .34066 .75964 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34066 .75964 m .33556 .78839 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .33556 .78839 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31769 .76629 m .31763 .76659 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31763 .76659 m .31211 .79769 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .31211 .79769 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28883 .7702 m .28882 .77027 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28882 .77027 m .28326 .8016 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .28326 .8016 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25738 .76834 m .25703 .77031 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25703 .77031 m .25181 .79974 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.17015 .63914 m .17575 .69651 L .19673 .69556 L p .707 .577 .707 r
F P
0 g
s
.37647 .8032 m .37647 .30131 L .3595 .29009 L p .707 .577 .707 r
F P
0 g
s
.37647 .30131 m .37647 .8032 L .40553 .81247 L p .707 .577 .707 r
F P
0 g
s
.33434 .62364 m .33994 .681 L .35621 .67816 L p .707 .577 .707 r
F P
0 g
s
.35621 .67816 m .3506 .62079 L .33434 .62364 L p .707 .577 .707 r
F P
0 g
s
.19529 .78235 m .19668 .80143 L .22404 .80112 L p .707 .577 .707 r
F P
0 g
s
.19341 .78 m .19899 .7486 L .17775 .73264 L p .707 .577 .707 r
F P
0 g
s
.19899 .7486 m .19341 .78 L .22085 .7923 L p .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .34113 .75699 L .31769 .76629 L p .707 .577 .707 r
F P
0 g
s
.69022 .77385 m .69345 .7917 L .67285 .78687 L p .707 .577 .707 r
F P
0 g
s
.17575 .69651 m .17015 .63914 L .15759 .63902 L p .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .16319 .69638 L .17575 .69651 L p .707 .577 .707 r
F P
0 g
s
.19668 .80143 m .19529 .78235 L .17432 .78141 L p .707 .577 .707 r
F P
0 g
s
.17432 .78141 m .17572 .80049 L .19668 .80143 L p .707 .577 .707 r
F P
0 g
s
.17218 .76404 m .17775 .73264 L .1648 .7146 L p .707 .577 .707 r
F P
0 g
s
.17775 .73264 m .17218 .76404 L .19341 .78 L p .707 .577 .707 r
F P
0 g
s
.3506 .62079 m .35621 .67816 L .36323 .67605 L p .707 .577 .707 r
F P
0 g
s
.36323 .67605 m .35762 .61868 L .3506 .62079 L p .707 .577 .707 r
F P
0 g
s
.35129 .77462 m .35686 .74322 L .34113 .75699 L p .707 .577 .707 r
F P
0 g
s
.66961 .76902 m .67285 .78687 L .64588 .78563 L p .707 .577 .707 r
F P
0 g
s
.35778 .75772 m .36335 .72632 L .35686 .74322 L p .707 .577 .707 r
F P
0 g
s
.3552 .76666 m .35659 .78574 L .3637 .78205 L p .707 .577 .707 r
F P
0 g
s
.3637 .78205 m .36231 .76297 L .3552 .76666 L p .707 .577 .707 r
F P
0 g
s
.35762 .61868 m .36323 .67605 L .36031 .67487 L p .707 .577 .707 r
F P
0 g
s
.36031 .67487 m .35471 .6175 L .35762 .61868 L p .707 .577 .707 r
F P
0 g
s
.36335 .72632 m .35778 .75772 L .35438 .73934 L p .707 .577 .707 r
F P
0 g
s
.35438 .73934 m .35995 .70794 L .36335 .72632 L p .707 .577 .707 r
F P
0 g
s
.36086 .77901 m .35947 .75993 L .36231 .76297 L p .707 .577 .707 r
F P
0 g
s
.35471 .6175 m .36031 .67487 L .34775 .67475 L p .707 .577 .707 r
F P
0 g
s
.35995 .70794 m .35438 .73934 L .34143 .72129 L p .707 .577 .707 r
F P
0 g
s
.34143 .72129 m .347 .6899 L .35995 .70794 L p .707 .577 .707 r
F P
0 g
s
.35947 .75993 m .36086 .77901 L .34835 .77692 L p .707 .577 .707 r
F P
0 g
s
.34835 .77692 m .34695 .75784 L .35947 .75993 L p .707 .577 .707 r
F P
0 g
s
.3595 .79198 m .3595 .29009 L .35628 .27801 L p .707 .577 .707 r
F P
0 g
s
.36231 .76297 m .3637 .78205 L .36086 .77901 L p .707 .577 .707 r
F P
0 g
s
.3595 .29009 m .3595 .79198 L .37647 .8032 L p .707 .577 .707 r
F P
0 g
s
.17572 .80049 m .17432 .78141 L .16181 .77932 L p .707 .577 .707 r
F P
0 g
s
.16319 .69638 m .16195 .68365 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.15468 .63784 m .16028 .69521 L .16319 .69638 L p .707 .577 .707 r
F P
0 g
s
.15923 .74599 m .1648 .7146 L .1614 .69622 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .15583 .72762 L .15923 .74599 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .16789 .67932 L p .16458 .69256 L .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .15468 .63784 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.16195 .68365 m .15759 .63902 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16387 .69413 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16789 .67932 L p .16935 .68853 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16701 .69015 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16935 .68853 L .16701 .69015 L .707 .577 .707 r
F
.18356 .69025 m .1673 .69309 L p .16793 .68951 L F P
0 g
s
.16789 .67932 m .18362 .66555 L p .17445 .68499 L .707 .577 .707 r
F P
0 g
s
.16935 .68853 m .16789 .67932 L .17445 .68499 L .707 .577 .707 r
F
.16793 .68951 m .18097 .68047 L .18356 .69025 L F
.18097 .68047 m .18362 .66555 L p .18679 .67984 L F P
0 g
s
.18356 .69025 m .18268 .68126 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.18097 .68047 m .18679 .67984 L .18268 .68126 L .707 .577 .707 r
F
.20748 .68695 m .18356 .69025 L p .18669 .67988 L F P
0 g
s
.18362 .66555 m .20706 .65625 L p .19137 .67826 L .707 .577 .707 r
F P
0 g
s
.18679 .67984 m .18362 .66555 L .19137 .67826 L .707 .577 .707 r
F
.20706 .65625 m .23592 .65234 L p .21559 .67319 L F P
0 g
s
.21125 .67395 m .20706 .65625 L .21559 .67319 L .707 .577 .707 r
F
.20188 .62959 m .23111 .62616 L p .21263 .67371 L F P
0 g
s
.20748 .68695 m .2063 .67481 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20393 .67393 m .20706 .65625 L p .21125 .67395 L .707 .577 .707 r
F P
0 g
s
.23671 .68353 m .20748 .68695 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .21125 .67395 L .21196 .67692 L .707 .577 .707 r
F
.20393 .67393 m .21125 .67395 L .2063 .67481 L F
.23592 .65234 m .26737 .6542 L p .24667 .67071 L F P
0 g
s
.24136 .67103 m .23592 .65234 L .24667 .67071 L .707 .577 .707 r
F
.23111 .62616 m .26279 .62294 L p .24211 .67098 L F P
0 g
s
.23671 .68353 m .23553 .67137 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23275 .6702 m .23592 .65234 L p .24136 .67103 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .23671 .68353 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .24136 .67103 L .24229 .67421 L .707 .577 .707 r
F
.23275 .6702 m .24136 .67103 L .23553 .67137 L F
.29943 .6776 m .2684 .6803 L p .27215 .67144 L F P
0 g
s
.26737 .6542 m .29832 .66164 L p .2828 .67182 L .707 .577 .707 r
F P
0 g
s
.27436 .67152 m .26737 .6542 L .2828 .67182 L .707 .577 .707 r
F
.27215 .67144 m .29643 .67231 L .29943 .6776 L F
.29643 .67231 m .29832 .66164 L p .30537 .67535 L F P
0 g
s
.31496 .67652 m .29943 .6776 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29643 .67231 m .30537 .67535 L .29913 .6746 L .707 .577 .707 r
F
.29832 .66164 m .32576 .67394 L p .32021 .67715 L F P
0 g
s
.30537 .67535 m .29832 .66164 L .32021 .67715 L .707 .577 .707 r
F
.29383 .62024 m .32117 .61832 L p .30047 .67476 L F P
0 g
s
.29943 .6776 m .29913 .6746 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29832 .66164 m .29609 .67423 L p .26179 .6856 L .707 .577 .707 r
F P
0 g
s
.29609 .67423 m .29275 .69304 L .27401 .68853 L p .707 .577 .707 r
F P
0 g
s
.27401 .68853 m .26179 .6856 L p .29609 .67423 L .707 .577 .707 r
F P
0 g
s
.29913 .6746 m .29892 .6724 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .29383 .62024 L p .30009 .67164 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .30009 .67164 L .30047 .67476 L .707 .577 .707 r
F
.30948 .68336 m .30537 .67535 L .32021 .67715 L F
.29913 .6746 m .30537 .67535 L .30948 .68336 L F
.32576 .67394 m .347 .6899 L p .33636 .69603 L F P
0 g
s
.32019 .70534 m .32509 .67774 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32509 .67774 m .32576 .67394 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32576 .67394 m .32019 .70534 L .29275 .69304 L p .707 .577 .707 r
F P
0 g
s
.32117 .61832 m .32677 .67569 L .32394 .67589 L p .707 .577 .707 r
F P
0 g
s
.32394 .67589 m .31496 .67652 L p .31635 .66356 L .707 .577 .707 r
F P
0 g
s
.31635 .66356 m .32117 .61832 L .32394 .67589 L .707 .577 .707 r
F
.30047 .67476 m .32117 .61832 L .31496 .67652 L F
.29892 .6724 m .29913 .6746 L p .29643 .67231 L F P
0 g
s
.29913 .6746 m .29943 .6776 L p .29643 .67231 L .707 .577 .707 r
F P
0 g
s
.29275 .69304 m .29643 .67231 L p .30948 .68336 L .707 .577 .707 r
F P
0 g
s
.26462 .66966 m .26737 .6542 L p .27436 .67152 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .26751 .67127 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .27436 .67152 L .27622 .67614 L .707 .577 .707 r
F
.26462 .66966 m .27436 .67152 L .26751 .67127 L F
.26279 .62294 m .29383 .62024 L p .27215 .67144 L F P
0 g
s
.26734 .6695 m .2684 .6803 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .23275 .6702 L .23671 .68353 L .707 .577 .707 r
F
.23537 .66975 m .23553 .67137 L p .23275 .6702 L F P
0 g
s
.23553 .67137 m .23671 .68353 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.26737 .6542 m .26436 .67116 L p .24875 .67693 L .707 .577 .707 r
F P
0 g
s
.23035 .68374 m .24229 .67421 L .24875 .67693 L .707 .577 .707 r
F
.24229 .67421 m .26737 .6542 L .24875 .67693 L F
.26436 .67116 m .26179 .6856 L .24067 .68435 L p F P
0 g
s
.24067 .68435 m .23035 .68374 L p .26436 .67116 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .26734 .6695 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .26279 .62294 L p .27134 .66727 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .27134 .66727 L .27215 .67144 L .707 .577 .707 r
F
.29383 .62024 m .29892 .6724 L p .27215 .67144 L F P
0 g
s
.27622 .67614 m .27436 .67152 L .2828 .67182 L .707 .577 .707 r
F
.26179 .6856 m .26462 .66966 L p .27622 .67614 L F P
0 g
s
.26279 .62294 m .26734 .6695 L p .26462 .66966 L .707 .577 .707 r
F P
0 g
s
.24211 .67098 m .24694 .65978 L .26462 .66966 L .707 .577 .707 r
F
.24694 .65978 m .26279 .62294 L .26462 .66966 L F
.18669 .67988 m .20393 .67393 L .20748 .68695 L F
.20614 .67316 m .2063 .67481 L p .20393 .67393 L F P
0 g
s
.2063 .67481 m .20748 .68695 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.23592 .65234 m .23251 .67155 L p .2179 .67913 L .707 .577 .707 r
F P
0 g
s
.20149 .68765 m .21196 .67692 L .2179 .67913 L .707 .577 .707 r
F
.21196 .67692 m .23592 .65234 L .2179 .67913 L F
.23251 .67155 m .23035 .68374 L .20848 .6867 L p F P
0 g
s
.20848 .6867 m .20149 .68765 L p .23251 .67155 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .23537 .66975 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .23111 .62616 L p .24095 .66623 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .24095 .66623 L .24211 .67098 L .707 .577 .707 r
F
.24229 .67421 m .24136 .67103 L .24667 .67071 L F
.23035 .68374 m .23275 .6702 L p .24229 .67421 L F P
0 g
s
.23111 .62616 m .23537 .66975 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .21663 .66342 L .23275 .6702 L .707 .577 .707 r
F
.21663 .66342 m .23111 .62616 L .23275 .6702 L F
.18268 .68126 m .18356 .69025 L p .18097 .68047 L F P
0 g
s
.20706 .65625 m .20369 .67526 L p .17805 .69695 L .707 .577 .707 r
F P
0 g
s
.20369 .67526 m .20149 .68765 L .17875 .69667 L p .707 .577 .707 r
F P
0 g
s
.17875 .69667 m .17805 .69695 L p .20369 .67526 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .20614 .67316 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .20188 .62959 L p .2114 .66865 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .2114 .66865 L .21263 .67371 L .707 .577 .707 r
F
.21196 .67692 m .21125 .67395 L .21559 .67319 L F
.20149 .68765 m .20393 .67393 L p .21196 .67692 L F P
0 g
s
.20188 .62959 m .20614 .67316 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.18669 .67988 m .19005 .66876 L .20393 .67393 L .707 .577 .707 r
F
.19005 .66876 m .20188 .62959 L .20393 .67393 L F
.18761 .68354 m .18679 .67984 L .19137 .67826 L F
.18268 .68126 m .18679 .67984 L .18761 .68354 L F
.17796 .63288 m .20188 .62959 L p .18669 .67988 L F P
0 g
s
.17805 .69695 m .16231 .71072 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18362 .66555 m .18071 .68194 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18071 .68194 m .17805 .69695 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18268 .68126 m .1825 .67941 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .17796 .63288 L p .18575 .67481 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .18575 .67481 L .18669 .67988 L .707 .577 .707 r
F
.1825 .67941 m .18268 .68126 L p .18097 .68047 L F P
0 g
s
.17805 .69695 m .18097 .68047 L p .18761 .68354 L .707 .577 .707 r
F P
0 g
s
.17796 .63288 m .1825 .67941 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.17022 .69396 m .16935 .68853 L .17445 .68499 L .707 .577 .707 r
F
.16701 .69015 m .16935 .68853 L .17022 .69396 L F
.16231 .71072 m .15583 .72762 L p .16049 .70895 L F P
0 g
s
.16789 .67932 m .16582 .69098 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.16582 .69098 m .16231 .71072 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .17796 .63288 L p .17042 .67544 L .707 .577 .707 r
F P
0 g
s
.16793 .68951 m .16746 .68544 L .17042 .67544 L .707 .577 .707 r
F
.16746 .68544 m .1617 .63573 L .17042 .67544 L F
.16701 .69015 m .1617 .63573 L p .16793 .68951 L F P
0 g
s
.16678 .68775 m .16701 .69015 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16701 .69015 m .1673 .69309 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16231 .71072 m .16615 .68913 L p .17022 .69396 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .16678 .68775 L p .16028 .69521 L .707 .577 .707 r
F P
0 g
s
.16105 .7003 m .1614 .69622 L .16458 .69256 L .707 .577 .707 r
F
.16387 .69413 m .16028 .69521 L p .16678 .68775 L F P
0 g
s
.16022 .71004 m .16105 .7003 L .16458 .69256 L .707 .577 .707 r
F
.15583 .72762 m .16096 .69871 L p .16022 .71004 L F P
0 g
s
.16096 .69871 m .1614 .69622 L p .16022 .71004 L .707 .577 .707 r
F P
0 g
s
.1648 .7146 m .15923 .74599 L .17218 .76404 L p .707 .577 .707 r
F P
0 g
s
.16181 .77932 m .16321 .7984 L .17572 .80049 L p .707 .577 .707 r
F P
0 g
s
.64371 .28465 m .64371 .78653 L .6405 .77446 L p .707 .577 .707 r
F P
0 g
s
.6405 .77446 m .6405 .27257 L .64371 .28465 L p .707 .577 .707 r
F P
0 g
s
.16321 .7984 m .16181 .77932 L .15897 .77627 L p .707 .577 .707 r
F P
0 g
s
.15897 .77627 m .16037 .79536 L .16321 .7984 L p .707 .577 .707 r
F P
0 g
s
.16028 .69521 m .15468 .63784 L .1617 .63573 L p .707 .577 .707 r
F P
0 g
s
.35628 .27801 m .35628 .7799 L .3595 .79198 L p .707 .577 .707 r
F P
0 g
s
.35628 .7799 m .35628 .27801 L .36714 .26626 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34775 .67475 m .34215 .61738 L .35471 .6175 L p .707 .577 .707 r
F P
0 g
s
.6405 .27257 m .6405 .77446 L .62353 .76323 L p .707 .577 .707 r
F P
0 g
s
.62353 .76323 m .62353 .26135 L .6405 .27257 L p .707 .577 .707 r
F P
0 g
s
.16037 .79536 m .15897 .77627 L .16608 .77258 L p .707 .577 .707 r
F P
0 g
s
.16608 .77258 m .16748 .79166 L .16037 .79536 L p .707 .577 .707 r
F P
0 g
s
.34215 .61738 m .34775 .67475 L .32677 .67569 L p .707 .577 .707 r
F P
0 g
s
.32677 .67569 m .32117 .61832 L .34215 .61738 L p .707 .577 .707 r
F P
0 g
s
.36714 .76815 m .36714 .26626 L .391 .25598 L p .707 .577 .707 r
F P
0 g
s
.36714 .26626 m .36714 .76815 L .35628 .7799 L p .707 .577 .707 r
F P
0 g
s
.347 .6899 m .34143 .72129 L .32019 .70534 L p .707 .577 .707 r
F P
0 g
s
.16748 .79166 m .16608 .77258 L .18245 .7686 L p .707 .577 .707 r
F P
0 g
s
.18245 .7686 m .18385 .78768 L .16748 .79166 L p .707 .577 .707 r
F P
0 g
s
.62353 .26135 m .62353 .76323 L .59447 .75397 L p .707 .577 .707 r
F P
0 g
s
.59447 .75397 m .59447 .25208 L .62353 .26135 L p .707 .577 .707 r
F P
0 g
s
.34695 .75784 m .34835 .77692 L .32739 .77598 L p .707 .577 .707 r
F P
0 g
s
.32739 .77598 m .32599 .7569 L .34695 .75784 L p .707 .577 .707 r
F P
0 g
s
.7372 .62575 m .70617 .61972 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73266 .66671 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .7372 .62575 L p .72865 .66425 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .72865 .66425 L .72785 .66788 L .707 .577 .707 r
F
.75125 .67453 m .75333 .66679 L .73564 .66854 L F
.76965 .68161 m .75771 .67077 L .75125 .67453 L F
.75771 .67077 m .75333 .66679 L .75125 .67453 L F
.76889 .62707 m .76463 .66541 L p .78337 .65584 L F P
0 g
s
.76463 .66541 m .76447 .66684 L p .76725 .66522 L .707 .577 .707 r
F P
0 g
s
.78337 .65584 m .76463 .66541 L .76725 .66522 L .707 .577 .707 r
F
.76972 .6816 m .79851 .67814 L p .78804 .66764 L F P
0 g
s
.79812 .62355 m .79386 .66189 L p .80995 .65097 L .707 .577 .707 r
F P
0 g
s
.79386 .66189 m .7937 .66333 L p .79607 .66153 L .707 .577 .707 r
F P
0 g
s
.80995 .65097 m .79386 .66189 L .79607 .66153 L .707 .577 .707 r
F
.79851 .67814 m .82195 .67594 L p .80863 .6595 L F P
0 g
s
.79607 .66153 m .79851 .67814 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78875 .66369 L .78441 .664 L .707 .577 .707 r
F
.79851 .67814 m .79631 .66315 L p .78804 .66764 L F P
0 g
s
.79631 .66315 m .79607 .66153 L p .7937 .66333 L .707 .577 .707 r
F P
0 g
s
.79631 .66315 m .7937 .66333 L .78804 .66764 L .707 .577 .707 r
F
.79812 .62355 m .76889 .62707 L p .78737 .66379 L F P
0 g
s
.7937 .66333 m .79812 .62355 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.79607 .66153 m .79293 .64014 L p .78804 .66764 L .707 .577 .707 r
F P
0 g
s
.79252 .67402 m .7937 .66333 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.76965 .68161 m .76972 .6816 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78441 .664 L .76972 .6816 L .707 .577 .707 r
F
.76725 .66522 m .76965 .68161 L p .78441 .664 L F P
0 g
s
.7372 .62575 m .73266 .66671 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .75306 .65723 L .73537 .66672 L .707 .577 .707 r
F
.75306 .65723 m .7372 .62575 L .73537 .66672 L F
.7382 .68601 m .73564 .66854 L p .73248 .66827 L F P
0 g
s
.72378 .67294 m .73248 .66827 L .7172 .66697 L .707 .577 .707 r
F
.7382 .68601 m .73248 .66827 L .72378 .67294 L F
.73564 .66854 m .73537 .66672 L p .73248 .66827 L F P
0 g
s
.76889 .62707 m .7372 .62575 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.76408 .64361 m .73263 .64801 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.75771 .67077 m .75864 .66681 L .75333 .66679 L .707 .577 .707 r
F
.76447 .66684 m .76889 .62707 L p .75789 .66681 L F P
0 g
s
.75864 .66681 m .76408 .64361 L .75333 .66679 L .707 .577 .707 r
F
.76965 .68161 m .76725 .66522 L p .75771 .67077 L F P
0 g
s
.76725 .66522 m .76408 .64361 L p .75771 .67077 L .707 .577 .707 r
F P
0 g
s
.76328 .67753 m .76447 .66684 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73537 .66672 m .73564 .66854 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73564 .66854 m .7382 .68601 L .75932 .68305 L p .707 .577 .707 r
F P
0 g
s
.75932 .68305 m .76965 .68161 L p .73564 .66854 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .73537 .66672 L .7316 .67621 L .707 .577 .707 r
F
.73266 .66671 m .73248 .66827 L p .73537 .66672 L F P
0 g
s
.73248 .66827 m .7316 .67621 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .7382 .68601 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70725 .69091 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70617 .61972 m .67883 .60958 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .70391 .66814 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70357 .66582 L p .70086 .66754 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70086 .66754 L .69052 .67415 L .707 .577 .707 r
F
.67883 .60958 m .67323 .66005 L .67605 .6611 L p F P
0 g
s
.67323 .66005 m .67883 .60958 L .65785 .59631 L p .707 .577 .707 r
F P
0 g
s
.65785 .59631 m .65225 .64678 L .67323 .66005 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .653 .66229 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67981 .69583 m .67491 .66243 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67491 .66243 m .67423 .65783 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67605 .6611 m .68503 .66443 L p .68365 .65222 L .707 .577 .707 r
F P
0 g
s
.68365 .65222 m .67883 .60958 L .67605 .6611 L .707 .577 .707 r
F
.69052 .67415 m .69463 .66632 L .67978 .66339 L F
.69953 .66728 m .67883 .60958 L .68503 .66443 L F
.70086 .66754 m .70617 .61972 L p .69953 .66728 L F P
0 g
s
.70617 .61972 m .70108 .66561 L p .70357 .66582 L .707 .577 .707 r
F P
0 g
s
.70108 .66561 m .70057 .67019 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70167 .65291 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.68503 .66443 m .70057 .67019 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70057 .67019 m .70086 .66754 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70167 .65291 m .67423 .65783 L p .67978 .66339 L .707 .577 .707 r
F P
0 g
s
.69463 .66632 m .70167 .65291 L .67978 .66339 L .707 .577 .707 r
F
.72785 .66788 m .72171 .65423 L .70357 .66582 L F
.72171 .65423 m .70617 .61972 L .70357 .66582 L F
.70057 .67019 m .7316 .67621 L p .72785 .66788 L F P
0 g
s
.70167 .65291 m .70357 .66582 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73263 .64801 L .7172 .66697 L .707 .577 .707 r
F
.73537 .66672 m .73263 .64801 L p .73248 .66827 L F P
0 g
s
.76328 .67753 m .79252 .67402 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.78737 .66379 m .78337 .65584 L .77521 .66466 L .707 .577 .707 r
F
.78737 .66379 m .77521 .66466 L .76328 .67753 L F
.76447 .66684 m .76328 .67753 L p .78337 .65584 L F P
0 g
s
.79293 .64014 m .76408 .64361 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78875 .66369 m .79293 .64014 L .78441 .664 L .707 .577 .707 r
F
.8133 .65875 m .80995 .65097 L .80278 .66045 L F
.7937 .66333 m .79252 .67402 L p .80995 .65097 L F P
0 g
s
.82195 .67594 m .81929 .65778 L p .81731 .6581 L .707 .577 .707 r
F P
0 g
s
.81239 .66415 m .81731 .6581 L .80863 .6595 L .707 .577 .707 r
F
.82195 .67594 m .81731 .6581 L .81239 .66415 L F
.82195 .67594 m .83768 .67523 L p .82555 .65399 L F P
0 g
s
.83207 .65199 m .8296 .64302 L .82284 .65483 L .707 .577 .707 r
F
.82204 .61554 m .81749 .65647 L p .8296 .64302 L F P
0 g
s
.81749 .65647 m .81731 .6581 L p .81903 .656 L .707 .577 .707 r
F P
0 g
s
.8296 .64302 m .81749 .65647 L .81903 .656 L .707 .577 .707 r
F
.81903 .656 m .82195 .67594 L p .82555 .65399 L F P
0 g
s
.82204 .61554 m .79812 .62355 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .81731 .6581 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .82204 .61554 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81929 .65778 m .81638 .63795 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .81644 .66601 L p .8296 .64302 L .707 .577 .707 r
F P
0 g
s
.83768 .67523 m .83418 .65134 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.82978 .6614 m .83299 .6517 L .82555 .65399 L .707 .577 .707 r
F
.83768 .67523 m .83299 .6517 L .82978 .6614 L F
.8383 .60383 m .83322 .64959 L p .83942 .6323 L F P
0 g
s
.83322 .64959 m .83299 .6517 L p .83385 .6491 L .707 .577 .707 r
F P
0 g
s
.83942 .6323 m .83322 .64959 L .83385 .6491 L .707 .577 .707 r
F
.83768 .67523 m .84417 .67608 L p .83542 .64788 L F P
0 g
s
.83385 .6491 m .83768 .67523 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8383 .60383 m .82204 .61554 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83299 .6517 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .8383 .60383 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .83211 .63724 L .82555 .65399 L .707 .577 .707 r
F
.83418 .65134 m .83385 .6491 L p .83299 .6517 L F P
0 g
s
.83385 .6491 m .83211 .63724 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .83942 .6323 L .83442 .64865 L .707 .577 .707 r
F
.83613 .64732 m .83972 .64002 L p .83442 .64865 L F P
0 g
s
.83299 .6517 m .8327 .65429 L p .83942 .6323 L .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .83211 .63724 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.84417 .67608 m .83956 .64464 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83956 .64464 m .8386 .63808 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83613 .64732 L p .83442 .64865 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .83385 .6491 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .81638 .63795 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81638 .63795 m .81903 .656 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .8327 .65429 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83207 .65199 m .82284 .65483 L .81644 .66601 L .707 .577 .707 r
F
.81638 .63795 m .79293 .64014 L p .80863 .6595 L F P
0 g
s
.79252 .67402 m .81644 .66601 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.8133 .65875 m .80278 .66045 L .79252 .67402 L .707 .577 .707 r
F
.79293 .64014 m .79607 .66153 L p .80863 .6595 L F P
0 g
s
.76408 .64361 m .76725 .66522 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .76328 .67753 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .73537 .66672 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .70167 .65291 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .73248 .66827 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.391 .25598 m .391 .75787 L .36714 .76815 L p .707 .577 .707 r
F P
0 g
s
.391 .75787 m .391 .25598 L .42552 .24818 L p .707 .577 .707 r
F P
0 g
s
.18385 .78768 m .18245 .7686 L .20647 .76472 L p .707 .577 .707 r
F P
0 g
s
.20647 .76472 m .20787 .7838 L .18385 .78768 L p .707 .577 .707 r
F P
0 g
s
.32599 .7569 m .32739 .77598 L .30003 .77629 L p .707 .577 .707 r
F P
0 g
s
.30003 .77629 m .29863 .75721 L .32599 .7569 L p .707 .577 .707 r
F P
0 g
s
.59447 .25208 m .59447 .75397 L .55616 .74757 L p .707 .577 .707 r
F P
0 g
s
.55616 .74757 m .55616 .24568 L .59447 .25208 L p .707 .577 .707 r
F P
0 g
s
.20787 .7838 m .20647 .76472 L .2358 .76132 L p .707 .577 .707 r
F P
0 g
s
.2358 .76132 m .23719 .7804 L .20787 .7838 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .67981 .69583 L .70725 .69091 L p .707 .577 .707 r
F P
0 g
s
.42552 .75007 m .42552 .24818 L .46734 .24363 L p .707 .577 .707 r
F P
0 g
s
.42552 .24818 m .42552 .75007 L .391 .75787 L p .707 .577 .707 r
F P
0 g
s
.29863 .75721 m .30003 .77629 L .26895 .77781 L p .707 .577 .707 r
F P
0 g
s
.26895 .77781 m .26755 .75873 L .29863 .75721 L p .707 .577 .707 r
F P
0 g
s
.23719 .7804 m .2358 .76132 L .26755 .75873 L p .707 .577 .707 r
F P
0 g
s
.55616 .24568 m .55616 .74757 L .51236 .74466 L p .707 .577 .707 r
F P
0 g
s
.51236 .74466 m .51236 .24277 L .55616 .24568 L p .707 .577 .707 r
F P
0 g
s
.26755 .75873 m .26895 .77781 L .23719 .7804 L p .707 .577 .707 r
F P
0 g
s
.65225 .64678 m .65785 .59631 L .64529 .58122 L p .707 .577 .707 r
F P
0 g
s
.653 .66229 m .65857 .70029 L .67981 .69583 L p .707 .577 .707 r
F P
0 g
s
.46734 .74552 m .46734 .24363 L .51236 .24277 L p .707 .577 .707 r
F P
0 g
s
.46734 .24363 m .46734 .74552 L .42552 .75007 L p .707 .577 .707 r
F P
0 g
s
.73105 .77388 m .73245 .75653 L .70137 .75144 L p .707 .577 .707 r
F P
0 g
s
.73245 .75653 m .73105 .77388 L .76281 .77475 L p .707 .577 .707 r
F P
0 g
s
.76281 .77475 m .7642 .7574 L .73245 .75653 L p .707 .577 .707 r
F P
0 g
s
.51236 .24277 m .51236 .74466 L .46734 .74552 L p .707 .577 .707 r
F P
0 g
s
.7642 .7574 m .76281 .77475 L .79213 .77132 L p .707 .577 .707 r
F P
0 g
s
.79213 .77132 m .79353 .75398 L .7642 .7574 L p .707 .577 .707 r
F P
0 g
s
.69997 .76879 m .70137 .75144 L .67401 .74263 L p .707 .577 .707 r
F P
0 g
s
.70137 .75144 m .69997 .76879 L .73105 .77388 L p .707 .577 .707 r
F P
0 g
s
.67401 .74263 m .67261 .75998 L .69997 .76879 L p .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .84532 .58955 L .8383 .60383 L p .707 .577 .707 r
F P
0 g
s
.79353 .75398 m .79213 .77132 L .81615 .76393 L p .707 .577 .707 r
F P
0 g
s
.81615 .76393 m .81755 .74658 L .79353 .75398 L p .707 .577 .707 r
F P
0 g
s
.63969 .63169 m .64529 .58122 L .64237 .56578 L p .707 .577 .707 r
F P
0 g
s
.64529 .58122 m .63969 .63169 L .65225 .64678 L p .707 .577 .707 r
F P
0 g
s
.67261 .75998 m .67401 .74263 L .65304 .73097 L p .707 .577 .707 r
F P
0 g
s
.64005 .66586 m .64562 .70385 L .65857 .70029 L p .707 .577 .707 r
F P
0 g
s
.65857 .70029 m .653 .66229 L .64005 .66586 L p .707 .577 .707 r
F P
0 g
s
.65304 .73097 m .65165 .74831 L .67261 .75998 L p .707 .577 .707 r
F P
0 g
s
.81755 .74658 m .81615 .76393 L .83252 .75329 L p .707 .577 .707 r
F P
0 g
s
.83252 .75329 m .83392 .73595 L .81755 .74658 L p .707 .577 .707 r
F P
0 g
s
.65165 .74831 m .65304 .73097 L .64053 .71759 L p .707 .577 .707 r
F P
0 g
s
.84532 .58955 m .83972 .64002 L .83681 .62458 L p .707 .577 .707 r
F P
0 g
s
.83681 .62458 m .84241 .57411 L .84532 .58955 L p .707 .577 .707 r
F P
0 g
s
.64237 .56578 m .63677 .61625 L .63969 .63169 L p .707 .577 .707 r
F P
0 g
s
.63677 .61625 m .64237 .56578 L .64939 .55151 L p .707 .577 .707 r
F P
0 g
s
.64053 .71759 m .63913 .73494 L .65165 .74831 L p .707 .577 .707 r
F P
0 g
s
.63665 .66818 m .64222 .70617 L .64562 .70385 L p .707 .577 .707 r
F P
0 g
s
.64562 .70385 m .64005 .66586 L .63665 .66818 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83392 .73595 m .83252 .75329 L .83963 .74045 L p .707 .577 .707 r
F P
0 g
s
.83963 .74045 m .84103 .72311 L .83392 .73595 L p .707 .577 .707 r
F P
0 g
s
.63913 .73494 m .64053 .71759 L .63769 .70381 L p .707 .577 .707 r
F P
0 g
s
.84241 .57411 m .83681 .62458 L .82425 .60949 L p .707 .577 .707 r
F P
0 g
s
.82425 .60949 m .82985 .55902 L .84241 .57411 L p .707 .577 .707 r
F P
0 g
s
.64939 .55151 m .64379 .60197 L .63677 .61625 L p .707 .577 .707 r
F P
0 g
s
.64379 .60197 m .64939 .55151 L .66566 .53979 L p .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .84417 .67608 L .84077 .6784 L p .707 .577 .707 r
F P
0 g
s
.63769 .70381 m .63629 .72115 L .63913 .73494 L p .707 .577 .707 r
F P
0 g
s
.84077 .6784 m .8352 .6404 L .8386 .63808 L p .707 .577 .707 r
F P
0 g
s
.64314 .66902 m .64871 .70702 L .64222 .70617 L p .707 .577 .707 r
F P
0 g
s
.64222 .70617 m .63665 .66818 L .64314 .66902 L p .707 .577 .707 r
F P
0 g
s
.3855 .60908 m .3984 .55371 L .36807 .54558 L p .707 .577 .707 r
F P
0 g
s
.3984 .55371 m .3855 .60908 L .41655 .61563 L p .707 .577 .707 r
F P
0 g
s
.41655 .61563 m .42945 .56026 L .3984 .55371 L p .707 .577 .707 r
F P
0 g
s
.84103 .72311 m .83963 .74045 L .83679 .72667 L p .707 .577 .707 r
F P
0 g
s
.83679 .72667 m .83819 .70932 L .84103 .72311 L p .707 .577 .707 r
F P
0 g
s
.42945 .56026 m .41655 .61563 L .44528 .61995 L p .707 .577 .707 r
F P
0 g
s
.44528 .61995 m .45818 .56458 L .42945 .56026 L p .707 .577 .707 r
F P
0 g
s
.35517 .60095 m .36807 .54558 L .34142 .53667 L p .707 .577 .707 r
F P
0 g
s
.36807 .54558 m .35517 .60095 L .3855 .60908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63629 .72115 m .63769 .70381 L .6448 .69097 L p .707 .577 .707 r
F P
0 g
s
.82985 .55902 m .82425 .60949 L .80327 .59622 L p .707 .577 .707 r
F P
0 g
s
.80327 .59622 m .80887 .54575 L .82985 .55902 L p .707 .577 .707 r
F P
0 g
s
.66566 .53979 m .66006 .59026 L .64379 .60197 L p .707 .577 .707 r
F P
0 g
s
.66006 .59026 m .66566 .53979 L .68958 .53178 L p .707 .577 .707 r
F P
0 g
s
.34142 .53667 m .32852 .59204 L .35517 .60095 L p .707 .577 .707 r
F P
0 g
s
.6448 .69097 m .64341 .70832 L .63629 .72115 L p .707 .577 .707 r
F P
0 g
s
.46325 .62123 m .46888 .62163 L p .44867 .60541 L .707 .577 .707 r
F P
0 g
s
.46564 .62137 m .46722 .62555 L p .49371 .63866 L .707 .577 .707 r
F P
0 g
s
.46722 .62555 m .47822 .65463 L .48632 .64628 L p .707 .577 .707 r
F P
0 g
s
.48632 .64628 m .49371 .63866 L p .46722 .62555 L .707 .577 .707 r
F P
0 g
s
.45818 .56458 m .44867 .60541 L p .46888 .62163 L .707 .577 .707 r
F P
0 g
s
.44867 .60541 m .44528 .61995 L .46325 .62123 L p .707 .577 .707 r
F P
0 g
s
.46888 .62163 m .48177 .56626 L .45818 .56458 L p .707 .577 .707 r
F P
0 g
s
.8352 .6404 m .84077 .6784 L .82782 .68196 L p .707 .577 .707 r
F P
0 g
s
.82782 .68196 m .82225 .64396 L .8352 .6404 L p .707 .577 .707 r
F P
0 g
s
.32852 .59204 m .34142 .53667 L .32108 .52784 L p .707 .577 .707 r
F P
0 g
s
.42768 .68417 m .41511 .65091 L .38502 .66159 L p .707 .577 .707 r
F P
0 g
s
.41511 .65091 m .42768 .68417 L .45546 .67032 L p .707 .577 .707 r
F P
0 g
s
.45546 .67032 m .44289 .63705 L .41511 .65091 L p .707 .577 .707 r
F P
0 g
s
.39759 .69485 m .38502 .66159 L .35557 .66804 L p .707 .577 .707 r
F P
0 g
s
.38502 .66159 m .39759 .69485 L .42768 .68417 L p .707 .577 .707 r
F P
0 g
s
.65887 .66831 m .66444 .70631 L .64871 .70702 L p .707 .577 .707 r
F P
0 g
s
.64871 .70702 m .64314 .66902 L .65887 .66831 L p .707 .577 .707 r
F P
0 g
s
.80887 .54575 m .80327 .59622 L .77592 .58608 L p .707 .577 .707 r
F P
0 g
s
.77592 .58608 m .78152 .53561 L .80887 .54575 L p .707 .577 .707 r
F P
0 g
s
.68398 .58225 m .68958 .53178 L .71881 .52827 L p .707 .577 .707 r
F P
0 g
s
.68958 .53178 m .68398 .58225 L .66006 .59026 L p .707 .577 .707 r
F P
0 g
s
.44289 .63705 m .45546 .67032 L .47822 .65463 L p .707 .577 .707 r
F P
0 g
s
.47822 .65463 m .46564 .62137 L .44289 .63705 L p .707 .577 .707 r
F P
0 g
s
.83819 .70932 m .83679 .72667 L .82428 .71329 L p .707 .577 .707 r
F P
0 g
s
.82428 .71329 m .82567 .69595 L .83819 .70932 L p .707 .577 .707 r
F P
0 g
s
.32108 .52784 m .30818 .58321 L .32852 .59204 L p .707 .577 .707 r
F P
0 g
s
.3848 .71489 m .3875 .69937 L p .35735 .68973 L .707 .577 .707 r
F P
0 g
s
.38231 .69508 m .35735 .68973 L p .3875 .69937 L .707 .577 .707 r
F P
0 g
s
.35735 .68973 m .35411 .70832 L .3848 .71489 L p .707 .577 .707 r
F P
0 g
s
.35411 .70832 m .3562 .69633 L p .33039 .68194 L .707 .577 .707 r
F P
0 g
s
.3562 .69633 m .35735 .68973 L .34548 .6863 L p .707 .577 .707 r
F P
0 g
s
.34548 .6863 m .33039 .68194 L p .3562 .69633 L .707 .577 .707 r
F P
0 g
s
.33039 .68194 m .32715 .70052 L .35411 .70832 L p .707 .577 .707 r
F P
0 g
s
.32715 .70052 m .32851 .69269 L p .30978 .6737 L .707 .577 .707 r
F P
0 g
s
.32851 .69269 m .33039 .68194 L .31695 .67657 L p .707 .577 .707 r
F P
0 g
s
.31695 .67657 m .30978 .6737 L p .32851 .69269 L .707 .577 .707 r
F P
0 g
s
.30978 .6737 m .30654 .69228 L .32715 .70052 L p .707 .577 .707 r
F P
0 g
s
.30654 .69228 m .30725 .68821 L p .29755 .66581 L .707 .577 .707 r
F P
0 g
s
.30725 .68821 m .30978 .6737 L .30101 .66804 L p .707 .577 .707 r
F P
0 g
s
.30101 .66804 m .29755 .66581 L p .30725 .68821 L .707 .577 .707 r
F P
0 g
s
.32233 .69947 m .31001 .66688 L p .29788 .65811 L .707 .577 .707 r
F P
0 g
s
.30931 .6659 m .29788 .65811 L p .31001 .66688 L .707 .577 .707 r
F P
0 g
s
.29788 .65811 m .31045 .69137 L .32233 .69947 L p .707 .577 .707 r
F P
0 g
s
.31045 .69137 m .29819 .65892 L p .29517 .64612 L .707 .577 .707 r
F P
0 g
s
.29819 .65892 m .29788 .65811 L .29773 .65744 L p .707 .577 .707 r
F P
0 g
s
.29773 .65744 m .29517 .64612 L p .29819 .65892 L .707 .577 .707 r
F P
0 g
s
.31001 .66688 m .30976 .66621 L .30931 .6659 L p .707 .577 .707 r
F P
0 g
s
.3422 .70289 m .33072 .67252 L p .30976 .66621 L .707 .577 .707 r
F P
0 g
s
.33072 .67252 m .32963 .66963 L .32719 .66921 L p .707 .577 .707 r
F P
0 g
s
.32719 .66921 m .30976 .66621 L p .33072 .67252 L .707 .577 .707 r
F P
0 g
s
.36814 .7013 m .35827 .6752 L p .32963 .66963 L .707 .577 .707 r
F P
0 g
s
.35827 .6752 m .35557 .66804 L .35003 .66838 L p .707 .577 .707 r
F P
0 g
s
.35003 .66838 m .32963 .66963 L p .35827 .6752 L .707 .577 .707 r
F P
0 g
s
.3875 .69937 m .38803 .69631 L .38231 .69508 L p .707 .577 .707 r
F P
0 g
s
.38803 .69631 m .3848 .71489 L .4162 .71961 L p .707 .577 .707 r
F P
0 g
s
.4162 .71961 m .41943 .70103 L .38803 .69631 L p .707 .577 .707 r
F P
0 g
s
.35557 .66804 m .36814 .7013 L .39759 .69485 L p .707 .577 .707 r
F P
0 g
s
.66444 .70631 m .65971 .67403 L p .68231 .66611 L .707 .577 .707 r
F P
0 g
s
.65971 .67403 m .65887 .66831 L .66458 .66778 L p .707 .577 .707 r
F P
0 g
s
.66458 .66778 m .68231 .66611 L p .65971 .67403 L .707 .577 .707 r
F P
0 g
s
.64341 .70832 m .64461 .6934 L p .66117 .68033 L .707 .577 .707 r
F P
0 g
s
.64461 .6934 m .6448 .69097 L .64824 .68874 L p .707 .577 .707 r
F P
0 g
s
.64824 .68874 m .66117 .68033 L p .64461 .6934 L .707 .577 .707 r
F P
0 g
s
.41943 .70103 m .4162 .71961 L .44524 .722 L p .707 .577 .707 r
F P
0 g
s
.44524 .722 m .44847 .70342 L .41943 .70103 L p .707 .577 .707 r
F P
0 g
s
.48177 .56626 m .46888 .62163 L .47759 .62102 L p .707 .577 .707 r
F P
0 g
s
.48483 .61719 m .48477 .61626 L .47759 .62102 L .707 .577 .707 r
F
.48477 .61626 m .48177 .56626 L .47837 .61074 L F
.48477 .61626 m .47837 .61074 L .47759 .62102 L F
.49371 .63866 m .49854 .62811 L p .48581 .61715 L F P
0 g
s
.48547 .61686 m .48565 .61733 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.48565 .61733 m .49371 .63866 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.49305 .6087 m .49336 .60598 L .48581 .61715 L .707 .577 .707 r
F
.49793 .56513 m .48983 .5999 L p .49336 .60598 L F P
0 g
s
.48983 .5999 m .48581 .61715 L p .49336 .60598 L .707 .577 .707 r
F P
0 g
s
.49793 .56513 m .48177 .56626 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.49371 .63866 m .48547 .61686 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .48983 .5999 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.48983 .5999 m .49793 .56513 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .4983 .61451 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49417 .60739 m .49432 .60777 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .50043 .62396 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .48547 .61686 L p .48589 .61705 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .48922 .61317 L .48589 .61705 L .707 .577 .707 r
F
.48922 .61317 m .48114 .60539 L .48589 .61705 L F
.49423 .60733 m .49359 .6039 L p .49305 .6087 L F P
0 g
s
.48786 .59069 m .48114 .60539 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .49432 .60777 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .48786 .59069 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49466 .59435 m .50506 .5613 L .49793 .56513 L p .707 .577 .707 r
F P
0 g
s
.50247 .55515 m .50506 .5613 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49423 .60733 L p .49216 .61667 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .49423 .60733 L .49305 .6087 L .707 .577 .707 r
F
.48786 .59069 m .49417 .60739 L p .49427 .60752 L F P
0 g
s
.49287 .60004 m .49404 .59633 L .49428 .60758 L .707 .577 .707 r
F
.50506 .5613 m .49808 .59127 L p .49404 .59633 L F P
0 g
s
.49808 .59127 m .49428 .60758 L p .49404 .59633 L .707 .577 .707 r
F P
0 g
s
.49332 .60248 m .48786 .59069 L .49427 .60752 L .707 .577 .707 r
F
.49287 .60004 m .49744 .57675 L .49614 .58965 L F
.49249 .598 m .49744 .57675 L p .49287 .60004 L F P
0 g
s
.48515 .57871 m .48786 .59069 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .49265 .59855 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .48515 .57871 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.48515 .57871 m .49253 .59821 L p .49237 .59835 L .707 .577 .707 r
F P
0 g
s
.48957 .61052 m .47751 .60265 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .48868 .59578 L .48957 .61052 L .707 .577 .707 r
F
.48557 .59362 m .48515 .57871 L .49237 .59835 L F
.4924 .59837 m .48957 .61052 L p .48868 .59578 L F P
0 g
s
.48724 .60482 m .48585 .60387 L p .49253 .59821 L .707 .577 .707 r
F P
0 g
s
.49249 .598 m .4924 .59837 L p .4879 .58288 L .707 .577 .707 r
F P
0 g
s
.4879 .58288 m .4924 .59837 L .48868 .59578 L .707 .577 .707 r
F
.49773 .61197 m .49332 .60248 L .49427 .60752 L F
.48957 .61052 m .49249 .598 L p .49287 .60004 L F P
0 g
s
.49854 .62811 m .50043 .62396 L p .48547 .61686 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .49216 .61667 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.48581 .61715 m .48503 .6205 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .48957 .61052 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.4983 .61451 m .49773 .61197 L p .49417 .60739 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49216 .61667 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .48724 .60482 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49253 .59821 m .49265 .59855 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .49773 .61197 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .48557 .59362 L .49237 .59835 L .707 .577 .707 r
F
.47328 .57061 m .48515 .57871 L p .48557 .59362 L F P
0 g
s
.47751 .60265 m .48036 .59043 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.47328 .57061 m .4807 .59023 L p .48036 .59043 L .707 .577 .707 r
F P
0 g
s
.47751 .60265 m .45716 .59382 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .47751 .60265 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4665 .5983 m .46925 .58708 L .48036 .59043 L .707 .577 .707 r
F
.46925 .58708 m .47328 .57061 L .48036 .59043 L F
.4807 .59023 m .47328 .57061 L p .48557 .59362 L F P
0 g
s
.4534 .56718 m .47328 .57061 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .45933 .58452 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4534 .56718 m .45985 .58424 L p .45933 .58452 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .43052 .58491 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45716 .59382 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.44343 .59319 m .44738 .5829 L .45933 .58452 L .707 .577 .707 r
F
.44738 .5829 m .4534 .56718 L .45933 .58452 L F
.45985 .58424 m .4534 .56718 L p .46925 .58708 L F P
0 g
s
.42747 .56878 m .4534 .56718 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.43052 .58491 m .43137 .58125 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.42747 .56878 m .43201 .58081 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43052 .58491 L .41492 .58072 L p .707 .577 .707 r
F P
0 g
s
.4183 .59035 m .42229 .58096 L .43137 .58125 L .707 .577 .707 r
F
.42229 .58096 m .42747 .56878 L .43137 .58125 L F
.43201 .58081 m .42747 .56878 L p .44738 .5829 L F P
0 g
s
.39801 .57523 m .42747 .56878 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.41059 .60849 m .4002 .58102 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.4002 .58102 m .39801 .57523 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.39801 .57523 m .41059 .60849 L .3805 .61917 L p .707 .577 .707 r
F P
0 g
s
.3805 .61917 m .36792 .58591 L .39801 .57523 L p .707 .577 .707 r
F P
0 g
s
.41309 .5214 m .40019 .57678 L .39463 .57561 L p .707 .577 .707 r
F P
0 g
s
.39463 .57561 m .36914 .57023 L p .37845 .55988 L .707 .577 .707 r
F P
0 g
s
.37845 .55988 m .41309 .5214 L .39463 .57561 L .707 .577 .707 r
F
.44342 .52953 m .43137 .58125 L p .40019 .57678 L F P
0 g
s
.41492 .58072 m .40019 .57678 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43149 .58074 L p .43201 .58081 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43201 .58081 L .4338 .58105 L .707 .577 .707 r
F
.44004 .60204 m .41059 .60849 L p .4183 .59035 L F P
0 g
s
.43201 .58081 m .44004 .60204 L p .4183 .59035 L .707 .577 .707 r
F P
0 g
s
.44004 .60204 m .43201 .58081 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.44342 .52953 m .47006 .53845 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.43149 .58074 m .44342 .52953 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .45933 .58452 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45942 .58411 L p .45985 .58424 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45985 .58424 L .46327 .58527 L .707 .577 .707 r
F
.46597 .60045 m .44004 .60204 L p .44343 .59319 L F P
0 g
s
.45985 .58424 m .46597 .60045 L p .44343 .59319 L .707 .577 .707 r
F P
0 g
s
.46597 .60045 m .45985 .58424 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .49041 .54727 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.45942 .58411 m .47006 .53845 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .48036 .59043 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .48044 .59006 L p .4807 .59023 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .4807 .59023 L .48314 .59193 L .707 .577 .707 r
F
.48585 .60387 m .46597 .60045 L p .4665 .5983 L F P
0 g
s
.4807 .59023 m .48585 .60387 L p .4665 .5983 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .4807 .59023 L p .48557 .59362 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .50247 .55515 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48044 .59006 m .49041 .54727 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .4879 .58288 L .48868 .59578 L .707 .577 .707 r
F
.50247 .55515 m .49249 .598 L p .4879 .58288 L F P
0 g
s
.49744 .57675 m .50247 .55515 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .46564 .62137 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48547 .61686 m .48114 .60539 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.47759 .62102 m .48503 .6205 L p .48483 .61719 L .707 .577 .707 r
F P
0 g
s
.78152 .53561 m .77592 .58608 L .74489 .58005 L p .707 .577 .707 r
F P
0 g
s
.74489 .58005 m .75049 .52959 L .78152 .53561 L p .707 .577 .707 r
F P
0 g
s
.71321 .57873 m .71881 .52827 L .75049 .52959 L p .707 .577 .707 r
F P
0 g
s
.71881 .52827 m .71321 .57873 L .68398 .58225 L p .707 .577 .707 r
F P
0 g
s
.30818 .58321 m .32108 .52784 L .30902 .51996 L p .707 .577 .707 r
F P
0 g
s
.66117 .68033 m .65977 .69768 L .64341 .70832 L p .707 .577 .707 r
F P
0 g
s
.75049 .52959 m .74489 .58005 L .71321 .57873 L p .707 .577 .707 r
F P
0 g
s
.82225 .64396 m .82782 .68196 L .80658 .68642 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .80101 .64842 L .82225 .64396 L p .707 .577 .707 r
F P
0 g
s
.32963 .66963 m .3422 .70289 L .36814 .7013 L p .707 .577 .707 r
F P
0 g
s
.44847 .70342 m .44524 .722 L .46908 .72185 L p .707 .577 .707 r
F P
0 g
s
.46908 .72185 m .47231 .70326 L .44847 .70342 L p .707 .577 .707 r
F P
0 g
s
.68231 .66611 m .68788 .70411 L .66444 .70631 L p .707 .577 .707 r
F P
0 g
s
.30902 .51996 m .29612 .57534 L .30818 .58321 L p .707 .577 .707 r
F P
0 g
s
.82567 .69595 m .82428 .71329 L .80332 .70163 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .77915 .69134 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80101 .64842 m .80276 .66035 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80276 .66035 m .80658 .68642 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .80471 .68428 L .82022 .69291 L p .707 .577 .707 r
F P
0 g
s
.82022 .69291 m .82567 .69595 L p .82231 .6968 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .82022 .69291 L .82231 .6968 L .707 .577 .707 r
F
.68788 .70411 m .6827 .66876 L p .71117 .66265 L F P
0 g
s
.6827 .66876 m .68231 .66611 L .6866 .6656 L p .707 .577 .707 r
F P
0 g
s
.6866 .6656 m .71117 .66265 L p .6827 .66876 L .707 .577 .707 r
F P
0 g
s
.65977 .69768 m .66067 .68657 L p .68519 .67294 L .707 .577 .707 r
F P
0 g
s
.66067 .68657 m .66117 .68033 L .67281 .67675 L p .707 .577 .707 r
F P
0 g
s
.67281 .67675 m .68519 .67294 L p .66067 .68657 L .707 .577 .707 r
F P
0 g
s
.30976 .66621 m .32233 .69947 L .3422 .70289 L p .707 .577 .707 r
F P
0 g
s
.68519 .67294 m .6838 .69029 L .65977 .69768 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .77357 .65335 L .80101 .64842 L p .707 .577 .707 r
F P
0 g
s
.29612 .57534 m .30902 .51996 L .30643 .51381 L p .707 .577 .707 r
F P
0 g
s
.47231 .70326 m .46908 .72185 L .48538 .71915 L p .707 .577 .707 r
F P
0 g
s
.48538 .71915 m .48862 .70056 L .47231 .70326 L p .707 .577 .707 r
F P
0 g
s
.71117 .66265 m .71674 .70064 L .68788 .70411 L p .707 .577 .707 r
F P
0 g
s
.80471 .68428 m .80332 .70163 L .77595 .69282 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .74819 .69624 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77357 .65335 m .77457 .66016 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77457 .66016 m .77915 .69134 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .77735 .67548 L .7964 .68161 L p .707 .577 .707 r
F P
0 g
s
.7964 .68161 m .80471 .68428 L p .80042 .68556 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .7964 .68161 L .80042 .68556 L .707 .577 .707 r
F
.71674 .70064 m .71152 .66504 L p .74262 .65825 L F P
0 g
s
.71152 .66504 m .71117 .66265 L .71645 .66191 L p .707 .577 .707 r
F P
0 g
s
.71645 .66191 m .74262 .65825 L p .71152 .66504 L .707 .577 .707 r
F P
0 g
s
.6838 .69029 m .68444 .68222 L p .71452 .66951 L .707 .577 .707 r
F P
0 g
s
.68444 .68222 m .68519 .67294 L .7022 .67095 L p .707 .577 .707 r
F P
0 g
s
.7022 .67095 m .71452 .66951 L p .68444 .68222 L .707 .577 .707 r
F P
0 g
s
.30643 .51381 m .29353 .56918 L .29612 .57534 L p .707 .577 .707 r
F P
0 g
s
.29755 .66581 m .29431 .68439 L .30654 .69228 L p .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .74334 .66322 L p .77357 .65335 L .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .71674 .70064 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74262 .65825 m .74296 .66063 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74296 .66063 m .74819 .69624 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .74488 .68773 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.77735 .67548 m .7767 .6836 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.7767 .6836 m .77595 .69282 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.71312 .68686 m .71358 .68119 L p .74627 .67039 L .707 .577 .707 r
F P
0 g
s
.71358 .68119 m .71452 .66951 L .73211 .67 L p .707 .577 .707 r
F P
0 g
s
.73211 .67 m .74627 .67039 L p .71358 .68119 L .707 .577 .707 r
F P
0 g
s
.74334 .66322 m .74262 .65825 L .75476 .65633 L p .707 .577 .707 r
F P
0 g
s
.75476 .65633 m .77357 .65335 L p .74334 .66322 L .707 .577 .707 r
F P
0 g
s
.71452 .66951 m .71312 .68686 L .6838 .69029 L p .707 .577 .707 r
F P
0 g
s
.74488 .68773 m .74627 .67039 L .77735 .67548 L p .707 .577 .707 r
F P
0 g
s
.74627 .67039 m .74488 .68773 L .71312 .68686 L p .707 .577 .707 r
F P
0 g
s
.48862 .70056 m .48538 .71915 L .49256 .71417 L p .707 .577 .707 r
F P
0 g
s
.49256 .71417 m .49579 .69559 L .48862 .70056 L p .707 .577 .707 r
F P
0 g
s
.29353 .56918 m .30643 .51381 L .31356 .50998 L p .707 .577 .707 r
F P
0 g
s
.29431 .68439 m .29755 .66581 L .29489 .65904 L p .707 .577 .707 r
F P
0 g
s
.29489 .65904 m .29165 .67763 L .29431 .68439 L p .707 .577 .707 r
F P
0 g
s
.31356 .50998 m .30066 .56535 L .29353 .56918 L p .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .31045 .69137 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.29672 .6502 m .30775 .67939 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .29517 .64612 L .3019 .63142 L p .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29489 .65904 L .29977 .65566 L p .707 .577 .707 r
F P
0 g
s
.29977 .65566 m .30206 .65407 L p .30066 .65726 L .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29977 .65566 L .30066 .65726 L .707 .577 .707 r
F
.29517 .64612 m .29672 .6502 L p .2963 .64946 L F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .69559 m .49256 .71417 L .4899 .70741 L p .707 .577 .707 r
F P
0 g
s
.4899 .70741 m .49314 .68883 L .49579 .69559 L p .707 .577 .707 r
F P
0 g
s
.30066 .56535 m .31356 .50998 L .32971 .50885 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30206 .65407 m .29883 .67265 L .29165 .67763 L p .707 .577 .707 r
F P
0 g
s
.32971 .50885 m .31681 .56422 L .30066 .56535 L p .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .30775 .67939 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.30525 .6403 m .31447 .66469 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .3019 .63142 L .31739 .61545 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31447 .66469 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31739 .61545 m .32333 .63117 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.32333 .63117 m .32996 .64871 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .31837 .65137 L .34123 .65122 L p .707 .577 .707 r
F P
0 g
s
.34123 .65122 m .34221 .65121 L p .3416 .65163 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .34123 .65122 L .3416 .65163 L .707 .577 .707 r
F
.29883 .67265 m .30206 .65407 L .31761 .6515 L p F P
0 g
s
.31761 .6515 m .31837 .65137 L p .31796 .65181 L .707 .577 .707 r
F P
0 g
s
.29883 .67265 m .31761 .6515 L .31796 .65181 L .707 .577 .707 r
F
.3019 .63142 m .30525 .6403 L p .3027 .63799 L F P
0 g
s
.49314 .68883 m .4899 .70741 L .47767 .69952 L p .707 .577 .707 r
F P
0 g
s
.47767 .69952 m .4809 .68094 L .49314 .68883 L p .707 .577 .707 r
F P
0 g
s
.31681 .56422 m .32971 .50885 L .35331 .51053 L p .707 .577 .707 r
F P
0 g
s
.35331 .51053 m .34041 .5659 L .31681 .56422 L p .707 .577 .707 r
F P
0 g
s
.31837 .65137 m .31513 .66995 L .29883 .67265 L p .707 .577 .707 r
F P
0 g
s
.34041 .5659 m .35331 .51053 L .38204 .51486 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31739 .61545 L .34014 .59976 L p .707 .577 .707 r
F P
0 g
s
.4809 .68094 m .47767 .69952 L .45706 .69127 L p .707 .577 .707 r
F P
0 g
s
.45706 .69127 m .4603 .67269 L .4809 .68094 L p .707 .577 .707 r
F P
0 g
s
.38204 .51486 m .36914 .57023 L .34041 .5659 L p .707 .577 .707 r
F P
0 g
s
.40019 .57678 m .41309 .5214 L .44342 .52953 L p .707 .577 .707 r
F P
0 g
s
.36914 .57023 m .38204 .51486 L .41309 .5214 L p .707 .577 .707 r
F P
0 g
s
.34221 .65121 m .33897 .66979 L .31513 .66995 L p .707 .577 .707 r
F P
0 g
s
.34014 .59976 m .35272 .63303 L .32996 .64871 L p .707 .577 .707 r
F P
0 g
s
.35272 .63303 m .34014 .59976 L .36792 .58591 L p .707 .577 .707 r
F P
0 g
s
.36792 .58591 m .3805 .61917 L .35272 .63303 L p .707 .577 .707 r
F P
0 g
s
.4603 .67269 m .45706 .69127 L .4301 .68348 L p .707 .577 .707 r
F P
0 g
s
.4301 .68348 m .43333 .6649 L .4603 .67269 L p .707 .577 .707 r
F P
0 g
s
.33897 .66979 m .34221 .65121 L .37125 .65361 L p .707 .577 .707 r
F P
0 g
s
.37125 .65361 m .36801 .67219 L .33897 .66979 L p .707 .577 .707 r
F P
0 g
s
.43333 .6649 m .4301 .68348 L .39941 .67691 L p .707 .577 .707 r
F P
0 g
s
.39941 .67691 m .40265 .65832 L .43333 .6649 L p .707 .577 .707 r
F P
0 g
s
.36801 .67219 m .37125 .65361 L .40265 .65832 L p .707 .577 .707 r
F P
0 g
s
.40265 .65832 m .39941 .67691 L .36801 .67219 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001LOol50004Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol300000eYF001JEP02FUH80006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH80008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1P002eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo011oo`l004Eoo`00EWoo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo00Yoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@0045oo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol01Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000?Goo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool30006FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P00>Goo001EOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000gOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oo`0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<003Eoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=o
o`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00
E7oo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00
Dgoo00<005YF000030001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`0000=JEP00FUH02eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000;goo001COol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP040002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH02@00FUIJEUYF001JEP00FUH0000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00EJEPH000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo001DOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH00eYF1P002EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00
Egoo00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF100015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEPH000moo`@0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Qoo`8000=JEP03001JEUYF00EJEP03
001JEUYF008000QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EP03001JEP0000<001Uoo`@000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00FWoo0P00
00=JEP00FUH01UYF10002EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool005aoo`<000EJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00Oomoo`0SOol300000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00Ggoo1@001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF001JEP00
00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000
00005Woo0`003goo0P001EYF00L005YFFUIJEP00FUH0000/Ool0061oo`8000QJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF0`004goo1@0047oo0P000eYF00L005YF
FUIJEP00FUH0000/Ool005moo`8000UJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEPD00003
FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEUYFFUH00002FUH00`00Oomoo`0@Ool5000BOol01000FUIJEP000eYF0P00;Goo001NOol01000
FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YF00000P00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF00@005YFFUIJEP80011oo`D001=oo`<000=JEP8002eoo`00G7oo0P000eYF00<005YFFUH01eYF
00<005YFFUH01EYF100025YF00<005YFFUH015YF0`0000=JEP0000000P000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH00eYF0P003goo0`00
5Woo00@005YFFUIJEP8002eoo`00Fgoo00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00D005YF001JEP0000=JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01EYF0P00
9Woo0P0000AJEP00FUH002eoo`00F7oo0`001eYF00<005YFFUH01eYF00<005YF00000P000eYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01eYF0`008Goo0P0000IJEP00
FUH005YF000]Ool004moo`T00003FUH0000000MJEP03001JEUYF00MJEP800003FUH005YF00MJEP03
001JEP0000X0009JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEP0015YF00<005YFFUH02eYF1P005goo100000AJEP00FUIJEP800003FUH007oo02aoo`00AWoo
2@0015YF00@005YFFUIJEP800003FUH0000000MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000EJEP80009JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEP0015YF00<005YFFUH04EYF2@002Goo1@001EYF00L005YFFUIJEP00FUH0000]Ool0
03ioo`P000eJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH30006FUH0
0`00FUIJEP06FUH01@00FUIJEUYF000015YF0P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF01YJEPT000=JEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Goo000`Ool>000EFUH00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUH000020005FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH07UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0`00
0UYF00<005YFFUH015YF00<005YFFUH05eYF0`001EYF0P001eYF0P000UYF00<005YFFUH00eYF1@00
1EYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF01QJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00mJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00=JEP800005FUH005YFFUH0
0005FUH50005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0:000^Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00EJEP04001JEUYF0005FUH0
1000FUIJEUYF0P000eYF00@005YFFUH000IJEP<000IJEP03001JEUYF00<000QJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH01000FUIJEUYF1`000eYF00@005YF
FUIJEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH0
1EYF00<005YFFUH00P001EYF0`0000=JEP00FUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP<0
00=JEP03001JEUYF00EJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH00eYF1@0000=JEP000000;Woo000[Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJ
EP04001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF
1`000UYF00@005YFFUIJEP8002ioo`00:goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP8000MJEP03001JEUYF00IJEP03001JEUYF01D000=JEP03001JEUYF00=JEP8000QJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF00=JEP04001JEUYF0006FUH60004FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30002FUH30002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009J
EP03001JEUYF00IJEP03001JEUYF009JEP8000YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP800003FUH00000
00EJEP03001JEP0000MJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040007FUH01@00FUIJ
EUYF000035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000010000UYF00<005YFFUH01EYF2@000eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
FUH000EJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@000AJEP@000aJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH3000015YF001JEUYF2`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH000MJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00009JEPd000AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000@0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00P000EJEP80009JEQ4000IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH0000000=JEP03
001JEUYF00AJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01UYF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
;Goo000/Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF0P001UYF1`001UYF00<005YF
FUH01EYF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH60005FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002aoo`04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00005FUH20003FUH00`00FUH00004FUH0
0`00FUIJEP04FUH20008FUH30002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF
009JEP<0031oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00eYF3@001eYF00D0
05YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP@000EJ
EP03001JEUYF00AJEP<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<00004FUH00000000cOol002eoo`03001JEP0000=JEP03001JEUYF009JEPP000QJEP04
001JEUYFFUH30004FUH300001EYF000005YF000015YF00<005YFFUH015YF0P001UYF1@000eYF0`00
0eYF100000=JEP00FUH01EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006FUH0
0`00FUIJEP05FUH3000fOol002eoo`03001JEP00009JEP04001JEUYFFUH20007FUH00`00FUIJEP02
FUH90002Ool3000015YF001JEUYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH015YF
20000UYF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH60004
FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eo
o`<0009JEP03001JEP0000l000ioo`<000=JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00QJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUH0000300000eYF00000007FUH0
0`00FUIJEP04FUH700000goo000000020006FUH00`00FUIJEP02FUH2000bOol002eoo`03001JEP00
009JEP<0021oo`8000=JEP@000=JEP03001JEUYF00AJEP03001JEUYF00P000EJEP03001JEUYF00UJ
EP04001JEP000003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP04000<Ool40002FUH00`00FUIJ
EP03FUH2000aOol002eoo`05FUH005YFFUH0000UOol300000eYF0000000>0003FUH00`00FUIJEP02
FUH80008FUH60002FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1P0057oo0`001EYF00<005YF0000
<7oo000]Ool015YF001JEP00:Goo0P000eYF100000=JEP00FUH025YF00<005YFFUH01UYF00@005YF
FUIJEPP000=JEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEUYFFUH40002FUH=000MOol20003FUH01000FUIJEP00;goo000]Ool00eYF0000000/Ool0
0`00FUIJEP02FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPH000EJEP03001JEUYF00=JEP8001moo`800003FUH005YF009JEP03001oogoo02aoo`00;7oo
00<005YF0000;Woo00D005YFFUIJEP0000=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo021oo`8000=JEP03001oogoo02aoo`00;7oo0`00;goo0P0000=JEP00FUH00UYF00@005YFFUH0
009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol027oo0`005goo00@005YFFUH002ioo`00;7oo1000<7oo0P000eYF00@0
05YFFUH000IJEP03001JEUYF00P000AJEP03001JEUYF00AJEP03001JEUYF00<000IJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000Yoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`05001JEP00FUH0000GOol3000F
Ool01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00003@002EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF
00AJEP04001JEUYF000;Ool5000GOol200000eYF001oo`0/Ool002aoo`05001JEP00FUH0000FOol5
000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<0
05YF00001eYF0P0037oo1@0067oo00<005YF0000;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0C
Ool5000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=J
EP8000IJEP8000ioo`<001Uoo`03001JEP0002eoo`00;7oo0P0015YF00<007ooOol04Woo1@005goo
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP<000=JEP8002aoo`80
02ioo`00;7oo0P0015YF0`004goo0`0067oo0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YFFUH0009JEP<002ioo`8002ioo`00;Goo00<005YFFUH00UYF00@005YFFUH0
02ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP8002aoo`@002ioo`00;Goo00D005YFFUIJEP0000AJEP8002aoo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000005FUH2000XOol20002FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00006
FUH00`00Oomoo`0YOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF1P0025YF
00<005YFFUH02UYF2P001eYF00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YF00000`00
8Woo0P000eYF0P00;goo000^Ool01000FUIJEP001UYF0`009goo0P0000EJEP00FUIJEP0000IJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP03FUH5000IOol40000
0eYF001JEP02FUH00`00Oomoo`0^Ool002ioo`04001JEUYF0006FUH00`00FUIJEP02000TOol00`00
FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000<7oo000_Ool20006FUH0
0`00FUIJEP03FUH20009OolN0002FUH00`00FUIJEP03FUH400000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH00`00FUIJEP02000aOol0
02moo`8000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<005YFFUH01UYF
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo
000`Ool00`00FUIJEP04FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF
00AJEP80009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8003Eoo`00<Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00
0UYF2P0015YF1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=goo000_Ool3
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001eYF
00<005YF00000P0000AJEP000000009oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003Yo
o`00;Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
5P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF009JEP80009J
EP03001oogoo00=ooa00041oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
4P001eYF00<005YFFUH00eYF00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEUYF008000MJEP03001JEUYF009JEPD005Aoo`00;Goo00<005YF000015YF00@005YFFUIJ
EPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF009JEP03001JEUYF
008005Aoo`00;Goo00<005YF00000eYF1@0000=JEP0000000eYF00<005YFFUH01UYF0P0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH02`0015YF00<005YF0000EGoo000]Ool01000FUH005YF0P0015YF00@005YFFUIJEP800003
FUH005YF00MJEP8000QJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=oo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEP00FUH200000eYF001JEP05FUH300000eYF001JEP02
001DOol002eoo`03001JEP00008000EJEP03001JEUYF00=JEP@000IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000Qoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
00AJEP8000IJEP03001JEUYF0080009JEP03001oogoo059oo`00;Goo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF1@003Goo0P00
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YF000000AJEP04001JEUYF
FUH4001DOol002ioobL001Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH200000eYF
001JEP02FUH00`00FUH00002001DOol006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00AJ
EP8000=JEP<00003FUH0000005=oo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`000goo100000=JEP00FUH01UYF00<005YF
00000P0000=JEP0000000UYF00<007ooOol0DGoo001_Ool300000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40009Ool50003FUH00`00FUIJEP02
FUH01000FUH000000UYF00<007ooOol0DGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000=Ool50002FUH30002FUH2001DOol007Uoo`/000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0015oo`H0009JEP8005Aoo`00Q7oo6P002goo1@00
3goo0P000UYF00<005YFFUH00eYF00<007ooOol0Dgoo002?Ool01000FUIJEP005goo0`003Woo0P00
15YF00@005YFFUIJEP8005Ioo`00Sgoo00<005YF00009goo0P001eYF0`00F7oo002@Ool2000SOol4
00000eYF001JEP06FUH00`00Oomoo`1HOol0091oo`03001JEP0001eoo`D000EJEP03001JEUYF00=J
EP8005]oo`00T7oo00<005YFFUH00`005Woo10000UYF00<005YFFUH01UYF00<005YFFUH00P00GGoo
002@Ool01000FUIJEP000UYF5P001UYF00<005YFFUH01UYF0`00Ggoo002@Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P00HGoo002AOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
Hgoo002BOol30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001WOol009Ao
o`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@006aoo`00Ugoo5P00L7oo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59848 .7556 m .59046 .70157 L .55962 .70333 L p .707 .577 .707 r
F P
0 g
s
.59046 .70157 m .59848 .7556 L .63002 .75051 L p .707 .577 .707 r
F P
0 g
s
.63002 .75051 m .622 .69648 L .59046 .70157 L p .707 .577 .707 r
F P
0 g
s
.622 .69648 m .63002 .75051 L .65916 .74258 L p .707 .577 .707 r
F P
0 g
s
.65916 .74258 m .65114 .68855 L .622 .69648 L p .707 .577 .707 r
F P
0 g
s
.56764 .75736 m .55962 .70333 L .53249 .70157 L p .707 .577 .707 r
F P
0 g
s
.55962 .70333 m .56764 .75736 L .59848 .7556 L p .707 .577 .707 r
F P
0 g
s
.65114 .68855 m .65916 .74258 L .68306 .73259 L p .707 .577 .707 r
F P
0 g
s
.68306 .73259 m .67504 .67856 L .65114 .68855 L p .707 .577 .707 r
F P
0 g
s
.59205 .79976 m .59992 .76274 L .56939 .75519 L p .707 .577 .707 r
F P
0 g
s
.59992 .76274 m .59205 .79976 L .62321 .80562 L p .707 .577 .707 r
F P
0 g
s
.62321 .80562 m .63108 .7686 L .59992 .76274 L p .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53249 .70157 L .51172 .69648 L p .707 .577 .707 r
F P
0 g
s
.53249 .70157 m .54051 .75561 L .54078 .75562 L p .707 .577 .707 r
F P
0 g
s
.5572 .74079 m .53249 .70157 L .54078 .75562 L .707 .577 .707 r
F
.51172 .69648 m .51952 .74901 L p .51952 .74901 L F P
0 g
s
.53123 .73655 m .51172 .69648 L .51952 .74901 L .707 .577 .707 r
F
.51172 .69648 m .49935 .68856 L p .51917 .74879 L F P
0 g
s
.51398 .77511 m .51952 .74902 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L p .51952 .74901 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L .51215 .75686 L .707 .577 .707 r
F
.51215 .75686 m .51702 .74742 L .5108 .74343 L F
.49935 .68856 m .50715 .7411 L p .50716 .7411 L F P
0 g
s
.51917 .74879 m .51264 .72895 L .50716 .7411 L .707 .577 .707 r
F
.51264 .72895 m .49935 .68856 L .50716 .7411 L F
.49935 .68856 m .4966 .67857 L p .50709 .74089 L F P
0 g
s
.50947 .7302 m .50716 .74111 L p .51398 .77511 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50161 .76723 L .51343 .77476 L p .707 .577 .707 r
F P
0 g
s
.51343 .77476 m .51398 .77511 L p .50716 .74111 L .707 .577 .707 r
F P
0 g
s
.50374 .74867 m .50663 .73936 L .5053 .735 L .707 .577 .707 r
F
.50161 .76723 m .50716 .74111 L p .50374 .74867 L F P
0 g
s
.50716 .74111 m .50716 .7411 L p .50715 .7411 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50715 .7411 L .50374 .74867 L .707 .577 .707 r
F
.50506 .73421 m .50685 .73947 L .50464 .73267 L F
.50709 .74089 m .50685 .73947 L .50506 .73421 L F
.4966 .67857 m .50092 .70765 L p .50685 .73947 L F P
0 g
s
.50092 .70765 m .50462 .7326 L p .50685 .73947 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .49935 .68856 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.50716 .7411 m .50947 .7302 L p .50374 .74867 L .707 .577 .707 r
F P
0 g
s
.50464 .73269 m .50506 .73421 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .50466 .73289 L p .50161 .76723 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .49873 .76084 L .5011 .76609 L p .707 .577 .707 r
F P
0 g
s
.5011 .76609 m .50161 .76723 L p .50466 .73289 L .707 .577 .707 r
F P
0 g
s
.50372 .66749 m .50834 .6986 L p .50462 .7326 L .707 .577 .707 r
F P
0 g
s
.50506 .73421 m .5058 .73688 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.5058 .73688 m .50738 .74259 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50709 .74089 L .50581 .73668 L .707 .577 .707 r
F
.50947 .7302 m .50659 .72382 L p .5053 .735 L F P
0 g
s
.50663 .73936 m .50947 .7302 L .5053 .735 L .707 .577 .707 r
F
.51952 .74901 m .51172 .69648 L p .51917 .74879 L F P
0 g
s
.52184 .73809 m .50947 .7302 L p .5108 .74343 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .51347 .71956 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .50659 .72382 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50834 .6986 m .51174 .72152 L .50471 .73246 L p .707 .577 .707 r
F P
0 g
s
.50471 .73246 m .50462 .7326 L p .50834 .6986 L .707 .577 .707 r
F P
0 g
s
.49873 .76084 m .50466 .73289 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .50464 .73269 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50715 .7411 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.51952 .74901 m .52184 .73809 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53123 .73655 L .51952 .74901 L .707 .577 .707 r
F
.53769 .75492 m .54051 .75561 L p .51952 .74901 L F P
0 g
s
.52184 .73809 m .51398 .77511 L .53463 .78372 L p .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .51974 .75052 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .50738 .74259 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51974 .75052 m .51952 .74901 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51702 .74742 m .52184 .73809 L .5108 .74343 L .707 .577 .707 r
F
.52959 .76574 m .53706 .75471 L .52544 .75093 L F
.54055 .75584 m .54249 .7467 L p .52959 .76574 L F P
0 g
s
.51952 .74901 m .51974 .75052 L .53769 .75492 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .52184 .73809 L p .52544 .75093 L .707 .577 .707 r
F P
0 g
s
.53706 .75471 m .54249 .7467 L .52544 .75093 L .707 .577 .707 r
F
.53463 .78372 m .54055 .75584 L p .52959 .76574 L F P
0 g
s
.54078 .75562 m .56764 .75736 L p .5572 .74079 L .707 .577 .707 r
F P
0 g
s
.63108 .7686 m .62321 .80562 L .65196 .80922 L p .707 .577 .707 r
F P
0 g
s
.65196 .80922 m .65982 .7722 L .63108 .7686 L p .707 .577 .707 r
F P
0 g
s
.56153 .79222 m .56939 .75519 L .54249 .7467 L p .707 .577 .707 r
F P
0 g
s
.56939 .75519 m .56153 .79222 L .59205 .79976 L p .707 .577 .707 r
F P
0 g
s
.67504 .67856 m .68306 .73259 L .69936 .72152 L p .707 .577 .707 r
F P
0 g
s
.69936 .72152 m .69134 .66749 L .67504 .67856 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .53463 .78372 L .56153 .79222 L p .707 .577 .707 r
F P
0 g
s
.65982 .7722 m .65196 .80922 L .67547 .81021 L p .707 .577 .707 r
F P
0 g
s
.67547 .81021 m .68333 .77319 L .65982 .7722 L p .707 .577 .707 r
F P
0 g
s
.59892 .85633 m .59691 .83815 L .56593 .83901 L p .707 .577 .707 r
F P
0 g
s
.59691 .83815 m .59892 .85633 L .63059 .8523 L p .707 .577 .707 r
F P
0 g
s
.63059 .8523 m .62858 .83413 L .59691 .83815 L p .707 .577 .707 r
F P
0 g
s
.62858 .83413 m .63059 .8523 L .65985 .8455 L p .707 .577 .707 r
F P
0 g
s
.65985 .8455 m .65784 .82732 L .62858 .83413 L p .707 .577 .707 r
F P
0 g
s
.56593 .83901 m .56794 .85719 L .59892 .85633 L p .707 .577 .707 r
F P
0 g
s
.56794 .85719 m .56593 .83901 L .53868 .8366 L p .707 .577 .707 r
F P
0 g
s
.65784 .82732 m .65985 .8455 L .68384 .83658 L p .707 .577 .707 r
F P
0 g
s
.68384 .83658 m .68183 .8184 L .65784 .82732 L p .707 .577 .707 r
F P
0 g
s
.53868 .8366 m .54068 .85478 L .56794 .85719 L p .707 .577 .707 r
F P
0 g
s
.69134 .66749 m .69936 .72152 L .70649 .71044 L p .707 .577 .707 r
F P
0 g
s
.70649 .71044 m .69847 .65641 L .69134 .66749 L p .707 .577 .707 r
F P
0 g
s
.68333 .77319 m .67547 .81021 L .69145 .80849 L p .707 .577 .707 r
F P
0 g
s
.69145 .80849 m .69931 .77147 L .68333 .77319 L p .707 .577 .707 r
F P
0 g
s
.54068 .85478 m .53868 .8366 L .51782 .83118 L p .707 .577 .707 r
F P
0 g
s
.51782 .83118 m .51982 .84936 L .54068 .85478 L p .707 .577 .707 r
F P
0 g
s
.68183 .8184 m .68384 .83658 L .70021 .82643 L p .707 .577 .707 r
F P
0 g
s
.70021 .82643 m .6982 .80825 L .68183 .8184 L p .707 .577 .707 r
F P
0 g
s
.69847 .65641 m .70649 .71044 L .70373 .70045 L p .707 .577 .707 r
F P
0 g
s
.70373 .70045 m .69571 .64642 L .69847 .65641 L p .707 .577 .707 r
F P
0 g
s
.69931 .77147 m .69145 .80849 L .69834 .80423 L p .707 .577 .707 r
F P
0 g
s
.69834 .80423 m .7062 .76721 L .69931 .77147 L p .707 .577 .707 r
F P
0 g
s
.51982 .84936 m .51782 .83118 L .50539 .82327 L p .707 .577 .707 r
F P
0 g
s
.50539 .82327 m .5074 .84145 L .51982 .84936 L p .707 .577 .707 r
F P
0 g
s
.6982 .80825 m .70021 .82643 L .70736 .81603 L p .707 .577 .707 r
F P
0 g
s
.70736 .81603 m .70535 .79785 L .6982 .80825 L p .707 .577 .707 r
F P
0 g
s
.48871 .8218 m .48871 .31992 L .44482 .31709 L p .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .4966 .67857 L .50372 .66749 L p .707 .577 .707 r
F P
0 g
s
.5074 .84145 m .50539 .82327 L .50261 .81364 L p .707 .577 .707 r
F P
0 g
s
.50261 .81364 m .50462 .83182 L .5074 .84145 L p .707 .577 .707 r
F P
0 g
s
.51347 .71956 m .51228 .72517 L p .49873 .76084 L .707 .577 .707 r
F P
0 g
s
.51228 .72517 m .50561 .75658 L .50109 .75938 L p .707 .577 .707 r
F P
0 g
s
.50109 .75938 m .49873 .76084 L p .51228 .72517 L .707 .577 .707 r
F P
0 g
s
.52003 .65642 m .52463 .68742 L p .51174 .72152 L .707 .577 .707 r
F P
0 g
s
.50561 .75658 m .51347 .71956 L .52946 .71784 L p .707 .577 .707 r
F P
0 g
s
.52463 .68742 m .52805 .71045 L .51397 .72001 L p .707 .577 .707 r
F P
0 g
s
.51397 .72001 m .51174 .72152 L p .52463 .68742 L .707 .577 .707 r
F P
0 g
s
.51174 .72152 m .50372 .66749 L .52003 .65642 L p .707 .577 .707 r
F P
0 g
s
.50462 .83182 m .50261 .81364 L .50976 .80324 L p .707 .577 .707 r
F P
0 g
s
.50976 .80324 m .51177 .82142 L .50462 .83182 L p .707 .577 .707 r
F P
0 g
s
.52946 .71784 m .5216 .75486 L .50561 .75658 L p .707 .577 .707 r
F P
0 g
s
.51177 .82142 m .50976 .80324 L .52613 .79308 L p .707 .577 .707 r
F P
0 g
s
.52613 .79308 m .52814 .81126 L .51177 .82142 L p .707 .577 .707 r
F P
0 g
s
.5216 .75486 m .52946 .71784 L .55297 .71883 L p .707 .577 .707 r
F P
0 g
s
.55297 .71883 m .54511 .75585 L .5216 .75486 L p .707 .577 .707 r
F P
0 g
s
.52814 .81126 m .52613 .79308 L .55012 .78417 L p .707 .577 .707 r
F P
0 g
s
.55012 .78417 m .55213 .80235 L .52814 .81126 L p .707 .577 .707 r
F P
0 g
s
.48871 .31992 m .48871 .8218 L .5337 .82085 L p .707 .577 .707 r
F P
0 g
s
.52805 .71045 m .52003 .65642 L .54392 .64643 L p .707 .577 .707 r
F P
0 g
s
.54392 .64643 m .55195 .70046 L .52805 .71045 L p .707 .577 .707 r
F P
0 g
s
.5337 .82085 m .5337 .31896 L .48871 .31992 L p .707 .577 .707 r
F P
0 g
s
.55195 .70046 m .54392 .64643 L .57307 .6385 L p .707 .577 .707 r
F P
0 g
s
.57307 .6385 m .58109 .69253 L .55195 .70046 L p .707 .577 .707 r
F P
0 g
s
.54511 .75585 m .55297 .71883 L .58171 .72243 L p .707 .577 .707 r
F P
0 g
s
.58171 .72243 m .57385 .75945 L .54511 .75585 L p .707 .577 .707 r
F P
0 g
s
.55213 .80235 m .55012 .78417 L .57938 .77736 L p .707 .577 .707 r
F P
0 g
s
.57938 .77736 m .58139 .79554 L .55213 .80235 L p .707 .577 .707 r
F P
0 g
s
.5337 .31896 m .5337 .82085 L .57539 .81622 L p .707 .577 .707 r
F P
0 g
s
.58109 .69253 m .57307 .6385 L .6046 .63341 L p .707 .577 .707 r
F P
0 g
s
.57385 .75945 m .58171 .72243 L .61287 .72829 L p .707 .577 .707 r
F P
0 g
s
.61287 .72829 m .60501 .76531 L .57385 .75945 L p .707 .577 .707 r
F P
0 g
s
.57539 .81622 m .57539 .31433 L .5337 .31896 L p .707 .577 .707 r
F P
0 g
s
.44482 .81898 m .44482 .31709 L .40634 .31077 L p .707 .577 .707 r
F P
0 g
s
.44482 .31709 m .44482 .81898 L .48871 .8218 L p .707 .577 .707 r
F P
0 g
s
.69571 .64642 m .70373 .70045 L .69137 .69253 L p .707 .577 .707 r
F P
0 g
s
.69137 .69253 m .68335 .63849 L .69571 .64642 L p .707 .577 .707 r
F P
0 g
s
.7062 .76721 m .69834 .80423 L .69546 .79785 L p .707 .577 .707 r
F P
0 g
s
.69546 .79785 m .70332 .76082 L .7062 .76721 L p .707 .577 .707 r
F P
0 g
s
.6046 .63341 m .61262 .68744 L .58109 .69253 L p .707 .577 .707 r
F P
0 g
s
.6434 .73584 m .63554 .77286 L .60501 .76531 L p .707 .577 .707 r
F P
0 g
s
.60501 .76531 m .61287 .72829 L .6434 .73584 L p .707 .577 .707 r
F P
0 g
s
.58139 .79554 m .57938 .77736 L .61105 .77334 L p .707 .577 .707 r
F P
0 g
s
.61105 .77334 m .61306 .79152 L .58139 .79554 L p .707 .577 .707 r
F P
0 g
s
.57539 .31433 m .57539 .81622 L .6097 .80835 L p .707 .577 .707 r
F P
0 g
s
.61262 .68744 m .6046 .63341 L .63545 .63165 L p .707 .577 .707 r
F P
0 g
s
.6097 .80835 m .6097 .30646 L .57539 .31433 L p .707 .577 .707 r
F P
0 g
s
.70535 .79785 m .70736 .81603 L .70458 .8064 L p .707 .577 .707 r
F P
0 g
s
.70458 .8064 m .70257 .78822 L .70535 .79785 L p .707 .577 .707 r
F P
0 g
s
.40634 .81265 m .40634 .31077 L .37702 .30156 L p .707 .577 .707 r
F P
0 g
s
.40634 .31077 m .40634 .81265 L .44482 .81898 L p .707 .577 .707 r
F P
0 g
s
.25424 .69954 m .25078 .64245 L .21967 .64336 L p .707 .577 .707 r
F P
0 g
s
.25078 .64245 m .25424 .69954 L .28602 .69727 L p .707 .577 .707 r
F P
0 g
s
.28602 .69727 m .28256 .64018 L .25078 .64245 L p .707 .577 .707 r
F P
0 g
s
.28256 .64018 m .28602 .69727 L .31535 .69387 L p .707 .577 .707 r
F P
0 g
s
.31535 .69387 m .3119 .63678 L .28256 .64018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22312 .70046 m .21967 .64336 L .19227 .64283 L p .707 .577 .707 r
F P
0 g
s
.21967 .64336 m .22312 .70046 L .25424 .69954 L p .707 .577 .707 r
F P
0 g
s
.68335 .63849 m .69137 .69253 L .6706 .68744 L p .707 .577 .707 r
F P
0 g
s
.6706 .68744 m .66258 .6334 L .68335 .63849 L p .707 .577 .707 r
F P
0 g
s
.3119 .63678 m .31535 .69387 L .33937 .68967 L p .707 .577 .707 r
F P
0 g
s
.33937 .68967 m .33591 .63258 L .3119 .63678 L p .707 .577 .707 r
F P
0 g
s
.19227 .64283 m .19572 .69993 L .22312 .70046 L p .707 .577 .707 r
F P
0 g
s
.63545 .63165 m .64347 .68568 L .61262 .68744 L p .707 .577 .707 r
F P
0 g
s
.6703 .74433 m .66244 .78135 L .63554 .77286 L p .707 .577 .707 r
F P
0 g
s
.64203 .77248 m .64404 .79066 L .61306 .79152 L p .707 .577 .707 r
F P
0 g
s
.63554 .77286 m .6434 .73584 L .6703 .74433 L p .707 .577 .707 r
F P
0 g
s
.61306 .79152 m .61105 .77334 L .64203 .77248 L p .707 .577 .707 r
F P
0 g
s
.6097 .30646 m .6097 .80835 L .63327 .79802 L p .707 .577 .707 r
F P
0 g
s
.63327 .79802 m .63327 .29613 L .6097 .30646 L p .707 .577 .707 r
F P
0 g
s
.70332 .76082 m .69546 .79785 L .68309 .78996 L p .707 .577 .707 r
F P
0 g
s
.68309 .78996 m .69095 .75294 L .70332 .76082 L p .707 .577 .707 r
F P
0 g
s
.70257 .78822 m .70458 .8064 L .69215 .79849 L p .707 .577 .707 r
F P
0 g
s
.69215 .79849 m .69015 .78031 L .70257 .78822 L p .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .25343 .78659 L .23499 .7867 L p .707 .577 .707 r
F P
0 g
s
.23499 .7867 m .2223 .78678 L p .23022 .79142 L .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .23499 .7867 L .23022 .79142 L .707 .577 .707 r
F
.25343 .78659 m .2543 .80553 L .2861 .80365 L p F P
0 g
s
.2861 .80365 m .28524 .7847 L .26816 .78571 L p .707 .577 .707 r
F P
0 g
s
.26816 .78571 m .25343 .78659 L p .26262 .79138 L .707 .577 .707 r
F P
0 g
s
.2861 .80365 m .26816 .78571 L .26262 .79138 L .707 .577 .707 r
F
.28524 .7847 m .2861 .80365 L .31548 .80027 L p F P
0 g
s
.31548 .80027 m .31461 .78132 L .30052 .78294 L p .707 .577 .707 r
F P
0 g
s
.30052 .78294 m .28524 .7847 L p .2952 .78983 L .707 .577 .707 r
F P
0 g
s
.31548 .80027 m .30052 .78294 L .2952 .78983 L .707 .577 .707 r
F
.31461 .78132 m .31548 .80027 L .33954 .79571 L p F P
0 g
s
.33954 .79571 m .33867 .77676 L .32841 .77871 L p .707 .577 .707 r
F P
0 g
s
.32841 .77871 m .31461 .78132 L p .32433 .78693 L .707 .577 .707 r
F P
0 g
s
.33954 .79571 m .32841 .77871 L .32433 .78693 L .707 .577 .707 r
F
.33867 .77676 m .33954 .79571 L .35593 .79043 L p F P
0 g
s
.35593 .79043 m .35507 .77148 L .33867 .77676 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .3528 .76861 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.34014 .74593 m .33899 .75739 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.33899 .75739 m .33673 .77998 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .33673 .77998 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31636 .75379 m .31536 .76376 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31536 .76376 m .31295 .78784 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .31295 .78784 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2872 .75736 m .28621 .76725 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.28621 .76725 m .28379 .79142 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .28379 .79142 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25552 .7563 m .25439 .7675 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25439 .7675 m .2521 .79036 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .25552 .7563 L .22441 .75071 L p .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .2872 .75736 L .25552 .7563 L p .707 .577 .707 r
F P
0 g
s
.19572 .69993 m .19227 .64283 L .17126 .64092 L p .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .31636 .75379 L .2872 .75736 L p .707 .577 .707 r
F P
0 g
s
.22099 .78476 m .22441 .75071 L .19692 .74114 L p .707 .577 .707 r
F P
0 g
s
.22441 .75071 m .22099 .78476 L .2521 .79036 L p .707 .577 .707 r
F P
0 g
s
.17126 .64092 m .17471 .69801 L .19572 .69993 L p .707 .577 .707 r
F P
0 g
s
.66258 .6334 m .6706 .68744 L .64347 .68568 L p .707 .577 .707 r
F P
0 g
s
.64347 .68568 m .63545 .63165 L .66258 .6334 L p .707 .577 .707 r
F P
0 g
s
.37702 .80345 m .37702 .30156 L .35975 .29037 L p .707 .577 .707 r
F P
0 g
s
.37702 .30156 m .37702 .80345 L .40634 .81265 L p .707 .577 .707 r
F P
0 g
s
.33591 .63258 m .33937 .68967 L .35572 .68509 L p .707 .577 .707 r
F P
0 g
s
.35572 .68509 m .35227 .62799 L .33591 .63258 L p .707 .577 .707 r
F P
0 g
s
.2223 .78678 m .22317 .80572 L .2543 .80553 L p .707 .577 .707 r
F P
0 g
s
.22317 .80572 m .2223 .78678 L .1949 .78526 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .34014 .74593 L .31636 .75379 L p .707 .577 .707 r
F P
0 g
s
.19351 .77519 m .19692 .74114 L .17575 .72852 L p .707 .577 .707 r
F P
0 g
s
.19692 .74114 m .19351 .77519 L .22099 .78476 L p .707 .577 .707 r
F P
0 g
s
.1949 .78526 m .19576 .80421 L .22317 .80572 L p .707 .577 .707 r
F P
0 g
s
.69095 .75294 m .68309 .78996 L .66244 .78135 L p .707 .577 .707 r
F P
0 g
s
.66244 .78135 m .6703 .74433 L .69095 .75294 L p .707 .577 .707 r
F P
0 g
s
.17471 .69801 m .17126 .64092 L .1587 .63779 L p .707 .577 .707 r
F P
0 g
s
.69015 .78031 m .69215 .79849 L .67129 .79306 L p .707 .577 .707 r
F P
0 g
s
.67129 .79306 m .66929 .77488 L .69015 .78031 L p .707 .577 .707 r
F P
0 g
s
.64404 .79066 m .64203 .77248 L .66929 .77488 L p .707 .577 .707 r
F P
0 g
s
.63327 .29613 m .63327 .79802 L .6438 .78625 L p .707 .577 .707 r
F P
0 g
s
.6438 .78625 m .6438 .28436 L .63327 .29613 L p .707 .577 .707 r
F P
0 g
s
.1587 .63779 m .16215 .69489 L .17471 .69801 L p .707 .577 .707 r
F P
0 g
s
.19576 .80421 m .1949 .78526 L .1739 .78219 L p .707 .577 .707 r
F P
0 g
s
.17575 .72852 m .17234 .76257 L .19351 .77519 L p .707 .577 .707 r
F P
0 g
s
.1739 .78219 m .17476 .80114 L .19576 .80421 L p .707 .577 .707 r
F P
0 g
s
.3528 .76861 m .35622 .73456 L .34014 .74593 L p .707 .577 .707 r
F P
0 g
s
.17234 .76257 m .17575 .72852 L .16296 .71408 L p .707 .577 .707 r
F P
0 g
s
.35227 .62799 m .35572 .68509 L .3628 .68056 L p .707 .577 .707 r
F P
0 g
s
.3628 .68056 m .35935 .62347 L .35227 .62799 L p .707 .577 .707 r
F P
0 g
s
.35622 .73456 m .3528 .76861 L .3596 .75483 L p .707 .577 .707 r
F P
0 g
s
.3596 .75483 m .36301 .72078 L .35622 .73456 L p .707 .577 .707 r
F P
0 g
s
.35935 .62347 m .3628 .68056 L .35992 .67654 L p .707 .577 .707 r
F P
0 g
s
.35992 .67654 m .35647 .61945 L .35935 .62347 L p .707 .577 .707 r
F P
0 g
s
.35507 .77148 m .35593 .79043 L .36305 .78494 L p .707 .577 .707 r
F P
0 g
s
.36305 .78494 m .36219 .76599 L .35507 .77148 L p .707 .577 .707 r
F P
0 g
s
.36301 .72078 m .3596 .75483 L .35645 .74 L p .707 .577 .707 r
F P
0 g
s
.35645 .74 m .35986 .70595 L .36301 .72078 L p .707 .577 .707 r
F P
0 g
s
.35647 .61945 m .35992 .67654 L .34736 .67342 L p .707 .577 .707 r
F P
0 g
s
.36021 .77977 m .35934 .76083 L .36219 .76599 L p .707 .577 .707 r
F P
0 g
s
.35986 .70595 m .35645 .74 L .34366 .72557 L p .707 .577 .707 r
F P
0 g
s
.34366 .72557 m .34707 .69152 L .35986 .70595 L p .707 .577 .707 r
F P
0 g
s
.35934 .76083 m .36021 .77977 L .34767 .77544 L p .707 .577 .707 r
F P
0 g
s
.35974 .79226 m .35975 .29037 L .3562 .2783 L p .707 .577 .707 r
F P
0 g
s
.36219 .76599 m .36305 .78494 L .36021 .77977 L p .707 .577 .707 r
F P
0 g
s
.35975 .29037 m .35974 .79226 L .37702 .80345 L p .707 .577 .707 r
F P
0 g
s
.66929 .77488 m .67129 .79306 L .64404 .79066 L p .707 .577 .707 r
F P
0 g
s
.16215 .69489 m .1587 .63779 L .15582 .63378 L p .707 .577 .707 r
F P
0 g
s
.16296 .71408 m .15955 .74814 L .17234 .76257 L p .707 .577 .707 r
F P
0 g
s
.17476 .80114 m .1739 .78219 L .16136 .77786 L p .707 .577 .707 r
F P
0 g
s
.16136 .77786 m .16223 .79681 L .17476 .80114 L p .707 .577 .707 r
F P
0 g
s
.15955 .74814 m .16296 .71408 L .15981 .69925 L p .707 .577 .707 r
F P
0 g
s
.15981 .69925 m .1564 .7333 L .15955 .74814 L p .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15981 .69925 L .15988 .69912 L p .707 .577 .707 r
F P
0 g
s
.16 .69188 m .16215 .69489 L p .16024 .67645 L .707 .577 .707 r
F P
0 g
s
.15988 .69912 m .16661 .68548 L p .15957 .71843 L .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15988 .69912 L .15957 .71843 L .707 .577 .707 r
F
.15582 .63378 m .15927 .69087 L .16 .69188 L p F P
0 g
s
.16024 .67645 m .15582 .63378 L .16 .69188 L .707 .577 .707 r
F
.6438 .28436 m .6438 .78625 L .64025 .77418 L p F P
0 g
s
.64025 .77418 m .64025 .27229 L .6438 .28436 L p .707 .577 .707 r
F P
0 g
s
.15927 .69087 m .15582 .63378 L .1629 .62925 L p .707 .577 .707 r
F P
0 g
s
.16223 .79681 m .16136 .77786 L .15852 .7727 L p .707 .577 .707 r
F P
0 g
s
.15852 .7727 m .15938 .79165 L .16223 .79681 L p .707 .577 .707 r
F P
0 g
s
.1629 .62925 m .16636 .68635 L .15927 .69087 L p .707 .577 .707 r
F P
0 g
s
.34736 .67342 m .34391 .61633 L .35647 .61945 L p .707 .577 .707 r
F P
0 g
s
.34767 .77544 m .34681 .7565 L .35934 .76083 L p .707 .577 .707 r
F P
0 g
s
.3562 .2783 m .3562 .78019 L .35974 .79226 L p .707 .577 .707 r
F P
0 g
s
.3562 .78019 m .3562 .2783 L .36672 .26652 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17925 .62467 m .17975 .63286 L p .16636 .68635 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .18268 .6741 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .16604 .69118 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16661 .68548 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18268 .6741 L p .18616 .68153 L .707 .577 .707 r
F P
0 g
s
.18275 .68258 m .18616 .68153 L .19051 .69082 L .707 .577 .707 r
F
.18192 .68169 m .18616 .68153 L .18275 .68258 L F
.20672 .67756 m .18903 .68065 L p .20552 .6756 L F P
0 g
s
.20552 .6756 m .20646 .66624 L p .21189 .67565 L .707 .577 .707 r
F P
0 g
s
.20672 .67756 m .20666 .67647 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20552 .6756 m .21189 .67565 L .20666 .67647 L .707 .577 .707 r
F
.23606 .67416 m .20672 .67756 L p .20723 .67638 L F P
0 g
s
.20646 .66624 m .23562 .66267 L p .22634 .67339 L .707 .577 .707 r
F P
0 g
s
.21189 .67565 m .20646 .66624 L .22634 .67339 L .707 .577 .707 r
F
.23562 .66267 m .26731 .66373 L p .25861 .6719 L F P
0 g
s
.24199 .67277 m .23562 .66267 L .25861 .6719 L .707 .577 .707 r
F
.23606 .67416 m .23599 .67308 L p .23659 .67305 L F P
0 g
s
.23468 .67209 m .23562 .66267 L p .24199 .67277 L .707 .577 .707 r
F P
0 g
s
.23606 .67416 m .23659 .67305 L .267 .67192 L .707 .577 .707 r
F
.26653 .67149 m .26731 .66373 L p .28039 .68418 L F P
0 g
s
.26784 .67189 m .26703 .67195 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26703 .67195 m .23606 .67416 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26731 .66373 m .29842 .66932 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.26781 .67142 m .26784 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.26389 .69778 m .26653 .67149 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .24199 .67277 L .24783 .68203 L .707 .577 .707 r
F
.23468 .67209 m .24199 .67277 L .23599 .67308 L F
.26731 .66373 m .26389 .69778 L .23221 .69672 L p F P
0 g
s
.26438 .6148 m .26781 .67142 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.2326 .61707 m .26438 .6148 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23606 .67416 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.23562 .66267 m .23457 .67315 L p .20305 .70029 L .707 .577 .707 r
F P
0 g
s
.23457 .67315 m .23221 .69672 L .20593 .69994 L p .707 .577 .707 r
F P
0 g
s
.20593 .69994 m .20305 .70029 L p .23457 .67315 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .23592 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .2326 .61707 L p .23647 .67138 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23647 .67138 L .23659 .67305 L .707 .577 .707 r
F
.24783 .68203 m .24199 .67277 L .25861 .6719 L F
.23221 .69672 m .23468 .67209 L p .24783 .68203 L F P
0 g
s
.2326 .61707 m .23592 .67189 L p .23468 .67209 L .707 .577 .707 r
F P
0 g
s
.20723 .67638 m .21533 .65745 L .23468 .67209 L .707 .577 .707 r
F
.21533 .65745 m .2326 .61707 L .23468 .67209 L F
.21688 .68432 m .21189 .67565 L .22634 .67339 L F
.20666 .67647 m .21189 .67565 L .21688 .68432 L F
.20327 .62047 m .2326 .61707 L p .20723 .67638 L F P
0 g
s
.18268 .6741 m .20646 .66624 L p .19051 .69082 L .707 .577 .707 r
F P
0 g
s
.20666 .67647 m .20659 .67528 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20646 .66624 m .20305 .70029 L .17927 .70815 L p .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20327 .62047 L p .20711 .67466 L .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20711 .67466 L .20723 .67638 L .707 .577 .707 r
F
.20659 .67528 m .20666 .67647 L p .20552 .6756 L F P
0 g
s
.20666 .67647 m .20672 .67756 L p .20552 .6756 L .707 .577 .707 r
F P
0 g
s
.20305 .70029 m .20552 .6756 L p .21688 .68432 L .707 .577 .707 r
F P
0 g
s
.20327 .62047 m .20659 .67528 L p .18271 .68176 L .707 .577 .707 r
F P
0 g
s
.18903 .68065 m .18271 .68176 L p .20659 .67528 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .18271 .68176 L .18214 .68192 L p .707 .577 .707 r
F P
0 g
s
.18214 .68192 m .18101 .68224 L p .18192 .68169 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18267 .68124 L .18214 .68192 L .707 .577 .707 r
F
.17927 .70815 m .18192 .68169 L p .19051 .69082 L F P
0 g
s
.17927 .70815 m .16319 .71953 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.18268 .6741 m .1818 .68287 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.1818 .68287 m .17927 .70815 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.17925 .62467 m .20327 .62047 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18271 .68176 m .18267 .68124 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .17925 .62467 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.17975 .63286 m .18267 .68124 L p .16723 .6861 L .707 .577 .707 r
F P
0 g
s
.18101 .68224 m .16723 .6861 L p .18267 .68124 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .16604 .69118 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16723 .6861 m .16636 .68635 L p .17975 .63286 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .1564 .7333 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16319 .71953 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64025 .27229 m .64025 .77418 L .62297 .76299 L p .707 .577 .707 r
F P
0 g
s
.62297 .76299 m .62297 .2611 L .64025 .27229 L p .707 .577 .707 r
F P
0 g
s
.16636 .68635 m .1629 .62925 L .17925 .62467 L p .707 .577 .707 r
F P
0 g
s
.15938 .79165 m .15852 .7727 L .16564 .76721 L p .707 .577 .707 r
F P
0 g
s
.16564 .76721 m .1665 .78615 L .15938 .79165 L p .707 .577 .707 r
F P
0 g
s
.34391 .61633 m .34736 .67342 L .32635 .6715 L p .707 .577 .707 r
F P
0 g
s
.32635 .6715 m .3229 .61441 L .34391 .61633 L p .707 .577 .707 r
F P
0 g
s
.36672 .76841 m .36672 .26652 L .3903 .2562 L p .707 .577 .707 r
F P
0 g
s
.36672 .26652 m .36672 .76841 L .3562 .78019 L p .707 .577 .707 r
F P
0 g
s
.34707 .69152 m .34366 .72557 L .32249 .71295 L p .707 .577 .707 r
F P
0 g
s
.32249 .71295 m .3259 .6789 L .34707 .69152 L p .707 .577 .707 r
F P
0 g
s
.1665 .78615 m .16564 .76721 L .18203 .76192 L p .707 .577 .707 r
F P
0 g
s
.18203 .76192 m .1829 .78087 L .1665 .78615 L p .707 .577 .707 r
F P
0 g
s
.62297 .2611 m .62297 .76299 L .59366 .75378 L p .707 .577 .707 r
F P
0 g
s
.59366 .75378 m .59366 .25189 L .62297 .2611 L p .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .3259 .6789 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.295 .70337 m .29796 .67385 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29796 .67385 m .29842 .66932 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .295 .70337 L .26389 .69778 L p .707 .577 .707 r
F P
0 g
s
.2955 .61388 m .29895 .67098 L .29589 .67107 L p .707 .577 .707 r
F P
0 g
s
.29589 .67107 m .26784 .67189 L p .27901 .64846 L .707 .577 .707 r
F P
0 g
s
.27901 .64846 m .2955 .61388 L .29589 .67107 L .707 .577 .707 r
F
.3229 .61441 m .32635 .6715 L .29895 .67098 L p F P
0 g
s
.29895 .67098 m .2955 .61388 L .3229 .61441 L p .707 .577 .707 r
F P
0 g
s
.34681 .7565 m .34767 .77544 L .32667 .77237 L p .707 .577 .707 r
F P
0 g
s
.32667 .77237 m .32581 .75342 L .34681 .7565 L p .707 .577 .707 r
F P
0 g
s
.3259 .6789 m .32249 .71295 L .295 .70337 L p .707 .577 .707 r
F P
0 g
s
.26784 .67189 m .26438 .6148 L .2955 .61388 L p .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73561 .61666 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .74139 .66903 L .73359 .67036 L .707 .577 .707 r
F
.73347 .66902 m .73359 .67036 L p .74139 .66903 L F P
0 g
s
.73561 .61666 m .7045 .61212 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.7045 .61212 m .70105 .66491 L .73216 .66946 L p .707 .577 .707 r
F P
0 g
s
.73269 .66031 m .70158 .66262 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.7361 .69854 m .73347 .66902 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73297 .66947 L p .73299 .66944 L .707 .577 .707 r
F P
0 g
s
.73561 .61666 m .73219 .66902 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76739 .61726 m .73561 .61666 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76408 .66795 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76739 .61726 L p .76353 .6675 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76353 .6675 L .76341 .66905 L .707 .577 .707 r
F
.79695 .69205 m .77366 .66719 L .76543 .66905 L F
.76543 .66905 m .76779 .69551 L .79407 .69239 L p F P
0 g
s
.79407 .69239 m .79695 .69205 L p .76543 .66905 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .76543 .66905 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.75216 .67984 m .76401 .66905 L .74139 .66903 L .707 .577 .707 r
F
.76779 .69551 m .76401 .66905 L .75216 .67984 L F
.76532 .66785 m .76543 .66905 L p .77366 .66719 L F P
0 g
s
.76408 .66795 m .76401 .66905 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76437 .65728 L .74139 .66903 L .707 .577 .707 r
F
.76543 .66905 m .76532 .66785 L p .76401 .66905 L F P
0 g
s
.76739 .61726 m .76408 .66795 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76532 .66785 m .76437 .65728 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .78467 .65022 L .76532 .66785 L .707 .577 .707 r
F
.78467 .65022 m .76739 .61726 L .76532 .66785 L F
.79673 .61384 m .76739 .61726 L p .79114 .66256 L F P
0 g
s
.79277 .66567 m .79289 .66407 L .79114 .66256 L .707 .577 .707 r
F
.79289 .66407 m .79673 .61384 L .79114 .66256 L F
.79695 .69205 m .82073 .68851 L p .81965 .68713 L F P
0 g
s
.79334 .66562 m .79341 .66452 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79673 .61384 L p .79289 .66407 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79289 .66407 L .79277 .66567 L .707 .577 .707 r
F
.79334 .66562 m .79353 .65382 L .77366 .66719 L F
.79458 .66553 m .79447 .66433 L p .79334 .66562 L F P
0 g
s
.79673 .61384 m .79341 .66452 L p .79451 .66429 L .707 .577 .707 r
F P
0 g
s
.81097 .66141 m .81729 .65954 L p .79341 .66452 L .707 .577 .707 r
F P
0 g
s
.79447 .66433 m .79353 .65382 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81098 .6455 L .79451 .66429 L .707 .577 .707 r
F
.81098 .6455 m .79673 .61384 L .79451 .66429 L F
.81965 .68713 m .81794 .66017 L .80088 .66319 L F
.79353 .65382 m .79458 .66553 L p .81965 .68713 L F P
0 g
s
.79458 .66553 m .79695 .69205 L p .81965 .68713 L .707 .577 .707 r
F P
0 g
s
.79695 .69205 m .79458 .66553 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.78312 .67729 m .79334 .66562 L .77366 .66719 L .707 .577 .707 r
F
.79695 .69205 m .79334 .66562 L .78312 .67729 L F
.79327 .66663 m .81097 .66141 L p .79447 .66433 L F P
0 g
s
.79341 .66452 m .79334 .66562 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.79334 .66562 m .79327 .66663 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .82075 .60675 L .79673 .61384 L p .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .79353 .65382 L p .80088 .66319 L .707 .577 .707 r
F P
0 g
s
.82073 .68851 m .83681 .68523 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.82075 .60675 m .81732 .65906 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .82073 .68851 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81786 .65919 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81732 .65906 m .81729 .65954 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.83001 .63745 m .82075 .60675 L .81788 .65887 L .707 .577 .707 r
F
.81808 .6588 m .81788 .65887 L .81786 .65919 L F
.83001 .63745 m .81788 .65887 L .81808 .6588 L F
.83364 .64946 m .83001 .63745 L .81808 .6588 L F
.82069 .68802 m .81808 .6588 L p .81965 .68713 L F P
0 g
s
.81808 .6588 m .81732 .65028 L p .81788 .65916 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .81788 .65916 L .81965 .68713 L .707 .577 .707 r
F
.81786 .65919 m .81899 .65849 L p .81808 .6588 L F P
0 g
s
.81899 .65849 m .83364 .64946 L p .81808 .6588 L .707 .577 .707 r
F P
0 g
s
.83364 .64946 m .8371 .59667 L .82075 .60675 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .81732 .65028 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83681 .68523 m .83396 .6534 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83396 .6534 m .83339 .647 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .81808 .6588 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81724 .66029 m .81732 .65028 L .80088 .66319 L .707 .577 .707 r
F
.81794 .66017 m .81788 .65916 L .81724 .66029 L F
.81788 .65916 m .81732 .65028 L .81724 .66029 L F
.82073 .68851 m .82069 .68802 L p .81965 .68713 L F P
0 g
s
.79353 .65382 m .76437 .65728 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.79327 .66663 m .79334 .66562 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .76532 .66785 L .76394 .67005 L .707 .577 .707 r
F
.76401 .66905 m .76394 .67005 L p .76532 .66785 L F P
0 g
s
.76394 .67005 m .79327 .66663 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .76532 .66785 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .73269 .66031 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76401 .66905 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73216 .66946 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73219 .66902 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.73347 .66902 m .73269 .66031 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76341 .66905 L .73299 .66944 L .707 .577 .707 r
F
.73297 .66947 m .76394 .67005 L p .73299 .66944 L F P
0 g
s
.73269 .66031 m .73347 .66902 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.73359 .67036 m .7361 .69854 L .76062 .69619 L p .707 .577 .707 r
F P
0 g
s
.76062 .69619 m .76779 .69551 L p .73359 .67036 L .707 .577 .707 r
F P
0 g
s
.3903 .2562 m .3903 .75809 L .36672 .76841 L p .707 .577 .707 r
F P
0 g
s
.3903 .75809 m .3903 .2562 L .42461 .24833 L p .707 .577 .707 r
F P
0 g
s
.1829 .78087 m .18203 .76192 L .20609 .75737 L p .707 .577 .707 r
F P
0 g
s
.70105 .66491 m .7045 .61212 L .6771 .60406 L p .707 .577 .707 r
F P
0 g
s
.20609 .75737 m .20696 .77631 L .1829 .78087 L p .707 .577 .707 r
F P
0 g
s
.32581 .75342 m .32667 .77237 L .29927 .77086 L p .707 .577 .707 r
F P
0 g
s
.29927 .77086 m .2984 .75191 L .32581 .75342 L p .707 .577 .707 r
F P
0 g
s
.59366 .25189 m .59366 .75378 L .55518 .74746 L p .707 .577 .707 r
F P
0 g
s
.55518 .74746 m .55518 .24557 L .59366 .25189 L p .707 .577 .707 r
F P
0 g
s
.67364 .65685 m .6771 .60406 L .65609 .59329 L p .707 .577 .707 r
F P
0 g
s
.6771 .60406 m .67364 .65685 L .70105 .66491 L p .707 .577 .707 r
F P
0 g
s
.20696 .77631 m .20609 .75737 L .23547 .75398 L p .707 .577 .707 r
F P
0 g
s
.70158 .66262 m .705 .70085 L .7361 .69854 L p .707 .577 .707 r
F P
0 g
s
.23547 .75398 m .23633 .77293 L .20696 .77631 L p .707 .577 .707 r
F P
0 g
s
.42461 .75022 m .42461 .24833 L .4663 .2437 L p .707 .577 .707 r
F P
0 g
s
.42461 .24833 m .42461 .75022 L .3903 .75809 L p .707 .577 .707 r
F P
0 g
s
.705 .70085 m .70158 .66262 L .6741 .66398 L p .707 .577 .707 r
F P
0 g
s
.2984 .75191 m .29927 .77086 L .26814 .77105 L p .707 .577 .707 r
F P
0 g
s
.26814 .77105 m .26727 .7521 L .2984 .75191 L p .707 .577 .707 r
F P
0 g
s
.6741 .66398 m .67751 .70221 L .705 .70085 L p .707 .577 .707 r
F P
0 g
s
.23633 .77293 m .23547 .75398 L .26727 .7521 L p .707 .577 .707 r
F P
0 g
s
.55518 .24557 m .55518 .74746 L .51129 .74463 L p .707 .577 .707 r
F P
0 g
s
.51129 .74463 m .51129 .24274 L .55518 .24557 L p .707 .577 .707 r
F P
0 g
s
.26727 .7521 m .26814 .77105 L .23633 .77293 L p .707 .577 .707 r
F P
0 g
s
.65264 .64608 m .65609 .59329 L .64353 .58085 L p .707 .577 .707 r
F P
0 g
s
.65609 .59329 m .65264 .64608 L .67364 .65685 L p .707 .577 .707 r
F P
0 g
s
.73186 .76859 m .73272 .75072 L .70159 .7468 L p .707 .577 .707 r
F P
0 g
s
.73272 .75072 m .73186 .76859 L .76367 .76887 L p .707 .577 .707 r
F P
0 g
s
.76367 .76887 m .76453 .751 L .73272 .75072 L p .707 .577 .707 r
F P
0 g
s
.4663 .74558 m .4663 .2437 L .51129 .24274 L p .707 .577 .707 r
F P
0 g
s
.4663 .2437 m .4663 .74558 L .42461 .75022 L p .707 .577 .707 r
F P
0 g
s
.67751 .70221 m .6741 .66398 L .65292 .66426 L p .707 .577 .707 r
F P
0 g
s
.76453 .751 m .76367 .76887 L .79304 .76549 L p .707 .577 .707 r
F P
0 g
s
.79304 .76549 m .7939 .74762 L .76453 .751 L p .707 .577 .707 r
F P
0 g
s
.65292 .66426 m .65634 .70249 L .67751 .70221 L p .707 .577 .707 r
F P
0 g
s
.51129 .24274 m .51129 .74463 L .4663 .74558 L p .707 .577 .707 r
F P
0 g
s
.70073 .76467 m .70159 .7468 L .67419 .73963 L p .707 .577 .707 r
F P
0 g
s
.70159 .7468 m .70073 .76467 L .73186 .76859 L p .707 .577 .707 r
F P
0 g
s
.67419 .73963 m .67333 .7575 L .70073 .76467 L p .707 .577 .707 r
F P
0 g
s
.7939 .74762 m .79304 .76549 L .8171 .75876 L p .707 .577 .707 r
F P
0 g
s
.8171 .75876 m .81796 .74089 L .7939 .74762 L p .707 .577 .707 r
F P
0 g
s
.8371 .59667 m .83364 .64946 L .84072 .63739 L p .707 .577 .707 r
F P
0 g
s
.84072 .63739 m .84418 .5846 L .8371 .59667 L p .707 .577 .707 r
F P
0 g
s
.67333 .7575 m .67419 .73963 L .65319 .7299 L p .707 .577 .707 r
F P
0 g
s
.64353 .58085 m .64008 .63364 L .65264 .64608 L p .707 .577 .707 r
F P
0 g
s
.64008 .63364 m .64353 .58085 L .64065 .56796 L p .707 .577 .707 r
F P
0 g
s
.65634 .70249 m .65292 .66426 L .64014 .66343 L p .707 .577 .707 r
F P
0 g
s
.65319 .7299 m .65233 .74777 L .67333 .7575 L p .707 .577 .707 r
F P
0 g
s
.64014 .66343 m .64355 .70166 L .65634 .70249 L p .707 .577 .707 r
F P
0 g
s
.81796 .74089 m .8171 .75876 L .8335 .74936 L p .707 .577 .707 r
F P
0 g
s
.8335 .74936 m .83436 .73149 L .81796 .74089 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .83681 .68523 L .8436 .68253 L p .707 .577 .707 r
F P
0 g
s
.8436 .68253 m .84019 .6443 L .83339 .647 L p .707 .577 .707 r
F P
0 g
s
.65233 .74777 m .65319 .7299 L .64065 .71857 L p .707 .577 .707 r
F P
0 g
s
.84418 .5846 m .84072 .63739 L .83785 .6245 L p .707 .577 .707 r
F P
0 g
s
.83785 .6245 m .8413 .57171 L .84418 .5846 L p .707 .577 .707 r
F P
0 g
s
.64065 .56796 m .6372 .62075 L .64008 .63364 L p .707 .577 .707 r
F P
0 g
s
.64065 .71857 m .63979 .73644 L .65233 .74777 L p .707 .577 .707 r
F P
0 g
s
.6372 .62075 m .64065 .56796 L .64773 .55589 L p .707 .577 .707 r
F P
0 g
s
.64355 .70166 m .64014 .66343 L .63699 .66158 L p .707 .577 .707 r
F P
0 g
s
.63699 .66158 m .6404 .69981 L .64355 .70166 L p .707 .577 .707 r
F P
0 g
s
.83436 .73149 m .8335 .74936 L .84062 .73821 L p .707 .577 .707 r
F P
0 g
s
.84062 .73821 m .84148 .72034 L .83436 .73149 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63979 .73644 m .64065 .71857 L .63781 .70675 L p .707 .577 .707 r
F P
0 g
s
.84019 .6443 m .8436 .68253 L .84045 .68067 L p .707 .577 .707 r
F P
0 g
s
.84045 .68067 m .83703 .64245 L .84019 .6443 L p .707 .577 .707 r
F P
0 g
s
.8413 .57171 m .83785 .6245 L .82529 .61206 L p .707 .577 .707 r
F P
0 g
s
.82529 .61206 m .82874 .55927 L .8413 .57171 L p .707 .577 .707 r
F P
0 g
s
.64773 .55589 m .64428 .60868 L .6372 .62075 L p .707 .577 .707 r
F P
0 g
s
.63781 .70675 m .63695 .72462 L .63979 .73644 L p .707 .577 .707 r
F P
0 g
s
.64428 .60868 m .64773 .55589 L .66408 .54581 L p .707 .577 .707 r
F P
0 g
s
.6404 .69981 m .63699 .66158 L .64378 .65888 L p .707 .577 .707 r
F P
0 g
s
.64378 .65888 m .6472 .69711 L .6404 .69981 L p .707 .577 .707 r
F P
0 g
s
.38737 .61375 m .39539 .5579 L .36455 .55215 L p .707 .577 .707 r
F P
0 g
s
.39539 .5579 m .38737 .61375 L .41891 .6175 L p .707 .577 .707 r
F P
0 g
s
.41891 .6175 m .42693 .56164 L .39539 .5579 L p .707 .577 .707 r
F P
0 g
s
.84148 .72034 m .84062 .73821 L .83777 .72638 L p .707 .577 .707 r
F P
0 g
s
.83777 .72638 m .83863 .70851 L .84148 .72034 L p .707 .577 .707 r
F P
0 g
s
.42693 .56164 m .41891 .6175 L .44805 .61887 L p .707 .577 .707 r
F P
0 g
s
.44805 .61887 m .45607 .56301 L .42693 .56164 L p .707 .577 .707 r
F P
0 g
s
.35653 .60801 m .36455 .55215 L .33742 .54496 L p .707 .577 .707 r
F P
0 g
s
.36455 .55215 m .35653 .60801 L .38737 .61375 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63695 .72462 m .63781 .70675 L .64493 .69559 L p .707 .577 .707 r
F P
0 g
s
.82874 .55927 m .82529 .61206 L .80428 .60129 L p .707 .577 .707 r
F P
0 g
s
.80428 .60129 m .80773 .5485 L .82874 .55927 L p .707 .577 .707 r
F P
0 g
s
.66408 .54581 m .66063 .5986 L .64428 .60868 L p .707 .577 .707 r
F P
0 g
s
.83703 .64245 m .84045 .68067 L .82766 .67985 L p .707 .577 .707 r
F P
0 g
s
.82766 .67985 m .82425 .64162 L .83703 .64245 L p .707 .577 .707 r
F P
0 g
s
.45607 .56301 m .44805 .61887 L .47195 .61773 L p .707 .577 .707 r
F P
0 g
s
.47195 .61773 m .47997 .56187 L .45607 .56301 L p .707 .577 .707 r
F P
0 g
s
.64493 .69559 m .64407 .71346 L .63695 .72462 L p .707 .577 .707 r
F P
0 g
s
.33742 .54496 m .3294 .60082 L .35653 .60801 L p .707 .577 .707 r
F P
0 g
s
.66063 .5986 m .66408 .54581 L .6881 .53872 L p .707 .577 .707 r
F P
0 g
s
.3294 .60082 m .33742 .54496 L .31665 .53703 L p .707 .577 .707 r
F P
0 g
s
.39499 .6899 m .38712 .65467 L .3566 .65815 L p .707 .577 .707 r
F P
0 g
s
.38712 .65467 m .39499 .6899 L .42615 .68278 L p .707 .577 .707 r
F P
0 g
s
.42615 .68278 m .41828 .64754 L .38712 .65467 L p .707 .577 .707 r
F P
0 g
s
.41828 .64754 m .42615 .68278 L .45489 .6727 L p .707 .577 .707 r
F P
0 g
s
.45489 .6727 m .44703 .63747 L .41828 .64754 L p .707 .577 .707 r
F P
0 g
s
.6472 .69711 m .64378 .65888 L .65986 .6556 L p .707 .577 .707 r
F P
0 g
s
.83863 .70851 m .83777 .72638 L .82524 .71505 L p .707 .577 .707 r
F P
0 g
s
.82524 .71505 m .8261 .69718 L .83863 .70851 L p .707 .577 .707 r
F P
0 g
s
.65986 .6556 m .66327 .69383 L .6472 .69711 L p .707 .577 .707 r
F P
0 g
s
.36446 .69339 m .3566 .65815 L .3297 .65765 L p .707 .577 .707 r
F P
0 g
s
.3566 .65815 m .36446 .69339 L .39499 .6899 L p .707 .577 .707 r
F P
0 g
s
.31665 .53703 m .30863 .59289 L .3294 .60082 L p .707 .577 .707 r
F P
0 g
s
.44703 .63747 m .45489 .6727 L .4784 .66067 L p .707 .577 .707 r
F P
0 g
s
.4784 .66067 m .47054 .62544 L .44703 .63747 L p .707 .577 .707 r
F P
0 g
s
.80773 .5485 m .80428 .60129 L .77688 .59323 L p .707 .577 .707 r
F P
0 g
s
.77688 .59323 m .78033 .54044 L .80773 .5485 L p .707 .577 .707 r
F P
0 g
s
.38694 .718 m .38894 .69936 L .35797 .69458 L p .707 .577 .707 r
F P
0 g
s
.38894 .69936 m .38694 .718 L .41861 .72061 L p .707 .577 .707 r
F P
0 g
s
.41861 .72061 m .42062 .70197 L .38894 .69936 L p .707 .577 .707 r
F P
0 g
s
.48603 .61468 m .48825 .6142 L p .47536 .59393 L .707 .577 .707 r
F P
0 g
s
.48652 .61263 m .48772 .61797 L p .50127 .63552 L .707 .577 .707 r
F P
0 g
s
.48772 .61797 m .49438 .64786 L .49891 .63976 L p .707 .577 .707 r
F P
0 g
s
.49891 .63976 m .50127 .63552 L p .48772 .61797 L .707 .577 .707 r
F P
0 g
s
.47997 .56187 m .47536 .59393 L p .48825 .6142 L .707 .577 .707 r
F P
0 g
s
.47536 .59393 m .47195 .61773 L .48603 .61468 L p .707 .577 .707 r
F P
0 g
s
.48825 .6142 m .49627 .55834 L .47997 .56187 L p .707 .577 .707 r
F P
0 g
s
.68465 .59151 m .6881 .53872 L .71744 .5353 L p .707 .577 .707 r
F P
0 g
s
.6881 .53872 m .68465 .59151 L .66063 .5986 L p .707 .577 .707 r
F P
0 g
s
.64407 .71346 m .64493 .69559 L .66132 .68619 L p .707 .577 .707 r
F P
0 g
s
.42062 .70197 m .41861 .72061 L .44787 .72079 L p .707 .577 .707 r
F P
0 g
s
.44787 .72079 m .44988 .70215 L .42062 .70197 L p .707 .577 .707 r
F P
0 g
s
.35797 .69458 m .35596 .71321 L .38694 .718 L p .707 .577 .707 r
F P
0 g
s
.35596 .71321 m .35693 .7042 L p .33071 .68808 L .707 .577 .707 r
F P
0 g
s
.34841 .6923 m .33071 .68808 L p .35693 .7042 L .707 .577 .707 r
F P
0 g
s
.33756 .69289 m .33245 .67001 L p .30905 .65321 L .707 .577 .707 r
F P
0 g
s
.33245 .67001 m .3297 .65765 L .3225 .6561 L p .707 .577 .707 r
F P
0 g
s
.3225 .6561 m .30905 .65321 L p .33245 .67001 L .707 .577 .707 r
F P
0 g
s
.35693 .7042 m .35797 .69458 L .34841 .6923 L p .707 .577 .707 r
F P
0 g
s
.30863 .59289 m .31665 .53703 L .30428 .52914 L p .707 .577 .707 r
F P
0 g
s
.82425 .64162 m .82766 .67985 L .80649 .68013 L p .707 .577 .707 r
F P
0 g
s
.80649 .68013 m .80307 .6419 L .82425 .64162 L p .707 .577 .707 r
F P
0 g
s
.3297 .65765 m .33756 .69289 L .36446 .69339 L p .707 .577 .707 r
F P
0 g
s
.66132 .68619 m .66046 .70406 L .64407 .71346 L p .707 .577 .707 r
F P
0 g
s
.33071 .68808 m .3287 .70672 L .35596 .71321 L p .707 .577 .707 r
F P
0 g
s
.78033 .54044 m .77688 .59323 L .74576 .58869 L p .707 .577 .707 r
F P
0 g
s
.74576 .58869 m .74922 .53589 L .78033 .54044 L p .707 .577 .707 r
F P
0 g
s
.71398 .58809 m .71744 .5353 L .74922 .53589 L p .707 .577 .707 r
F P
0 g
s
.71744 .5353 m .71398 .58809 L .68465 .59151 L p .707 .577 .707 r
F P
0 g
s
.47054 .62544 m .4784 .66067 L .49438 .64786 L p .707 .577 .707 r
F P
0 g
s
.49438 .64786 m .48652 .61263 L .47054 .62544 L p .707 .577 .707 r
F P
0 g
s
.44988 .70215 m .44787 .72079 L .47186 .71852 L p .707 .577 .707 r
F P
0 g
s
.47186 .71852 m .47387 .69988 L .44988 .70215 L p .707 .577 .707 r
F P
0 g
s
.74922 .53589 m .74576 .58869 L .71398 .58809 L p .707 .577 .707 r
F P
0 g
s
.66327 .69383 m .65986 .6556 L .68364 .65206 L p .707 .577 .707 r
F P
0 g
s
.30428 .52914 m .29626 .585 L .30863 .59289 L p .707 .577 .707 r
F P
0 g
s
.8261 .69718 m .82524 .71505 L .80424 .70532 L p .707 .577 .707 r
F P
0 g
s
.80424 .70532 m .8051 .68746 L .8261 .69718 L p .707 .577 .707 r
F P
0 g
s
.3287 .70672 m .3295 .69934 L p .30985 .68052 L .707 .577 .707 r
F P
0 g
s
.32216 .68498 m .30985 .68052 L p .3295 .69934 L .707 .577 .707 r
F P
0 g
s
.31691 .68845 m .31147 .66407 L p .29668 .64528 L .707 .577 .707 r
F P
0 g
s
.31147 .66407 m .30905 .65321 L .3044 .65023 L p .707 .577 .707 r
F P
0 g
s
.3044 .65023 m .29668 .64528 L p .31147 .66407 L .707 .577 .707 r
F P
0 g
s
.3295 .69934 m .33071 .68808 L .32216 .68498 L p .707 .577 .707 r
F P
0 g
s
.68364 .65206 m .68705 .69028 L .66327 .69383 L p .707 .577 .707 r
F P
0 g
s
.30985 .68052 m .30784 .69916 L .3287 .70672 L p .707 .577 .707 r
F P
0 g
s
.30905 .65321 m .31691 .68845 L .33756 .69289 L p .707 .577 .707 r
F P
0 g
s
.66046 .70406 m .66132 .68619 L .68538 .67947 L p .707 .577 .707 r
F P
0 g
s
.49166 .5905 m .48825 .6142 L .49529 .60869 L p .707 .577 .707 r
F P
0 g
s
.49341 .60029 m .48652 .61263 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.50127 .63552 m .49534 .60891 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49534 .60891 m .49341 .60029 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49627 .55834 m .49166 .5905 L p .49538 .60862 L .707 .577 .707 r
F P
0 g
s
.49529 .60869 m .49538 .60862 L p .49166 .5905 L .707 .577 .707 r
F P
0 g
s
.49538 .60862 m .5034 .55276 L .49627 .55834 L p .707 .577 .707 r
F P
0 g
s
.5034 .55276 m .49538 .60862 L .49535 .60856 L p .707 .577 .707 r
F P
0 g
s
.49493 .60748 m .49262 .60154 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49469 .60662 L .49534 .60892 L .708 .578 .707 r
F
.49341 .60029 m .49534 .60891 L p .49469 .60662 L F P
0 g
s
.49534 .60891 m .49534 .60892 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49535 .60856 m .49493 .60748 L p .49668 .58319 L .707 .577 .707 r
F P
0 g
s
.49053 .58963 m .49341 .60029 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49262 .60154 m .49284 .60001 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49262 .60154 m .48026 .59365 L p .48082 .59231 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .4922 .59959 L .49262 .60154 L .707 .577 .707 r
F
.49839 .62486 m .48602 .61693 L p .4892 .59767 L F P
0 g
s
.49053 .58963 m .49284 .6 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .49262 .60154 L p .4922 .59959 L .707 .577 .707 r
F P
0 g
s
.47816 .58169 m .49053 .58963 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48735 .57695 m .49284 .6 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49284 .60001 L .4922 .59959 L F
.48048 .59209 m .47816 .58169 L .4892 .59767 L F
.48048 .59209 m .48026 .59365 L p .47932 .59175 L F P
0 g
s
.47816 .58169 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45751 .57726 m .47816 .58169 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .46231 .58679 L p .47932 .59175 L .707 .577 .707 r
F P
0 g
s
.46537 .61249 m .45945 .58596 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45946 .58596 m .45751 .57726 L .47456 .59036 L .707 .577 .707 r
F
.45945 .58596 m .45751 .57726 L p .45946 .58596 L F P
0 g
s
.45751 .57726 m .46537 .61249 L .43847 .61199 L p .707 .577 .707 r
F P
0 g
s
.46751 .52986 m .45949 .58572 L .45921 .58565 L p .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .45751 .57726 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43847 .61199 m .43182 .58221 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43182 .58221 m .43061 .57676 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .43847 .61199 L .40794 .61548 L p .707 .577 .707 r
F P
0 g
s
.40794 .61548 m .40008 .58024 L .43061 .57676 L p .707 .577 .707 r
F P
0 g
s
.44038 .52267 m .43236 .57853 L .42821 .57776 L p .707 .577 .707 r
F P
0 g
s
.42821 .57776 m .40151 .57278 L p .41258 .55851 L .707 .577 .707 r
F P
0 g
s
.41258 .55851 m .44038 .52267 L .42821 .57776 L .707 .577 .707 r
F
.45921 .58565 m .43236 .57853 L p .4428 .56408 L F P
0 g
s
.4428 .56408 m .46751 .52986 L .45921 .58565 L .707 .577 .707 r
F
.45945 .58596 m .45945 .58596 L p .45946 .58596 L F P
0 g
s
.45949 .58572 m .46877 .57027 L .47932 .59175 L .707 .577 .707 r
F
.46231 .58679 m .45949 .58572 L p .47932 .59175 L F P
0 g
s
.46877 .57027 m .48048 .59209 L .47932 .59175 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L .47932 .59175 L F
.48602 .61693 m .46537 .61249 L p .47456 .59036 L F P
0 g
s
.48828 .53779 m .50064 .54568 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .48048 .59209 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48828 .53779 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48602 .61693 L p .47706 .59617 L .707 .577 .707 r
F P
0 g
s
.47456 .59036 m .48048 .59209 L .47706 .59617 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L p .48048 .59209 L F P
0 g
s
.48048 .59209 m .47816 .58169 L p .48048 .59209 L .707 .577 .707 r
F P
0 g
s
.48828 .53779 m .48048 .59209 L p .46877 .57027 L .707 .577 .707 r
F P
0 g
s
.48602 .61693 m .48048 .59209 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .6 m .49839 .62486 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .48735 .57695 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49053 .58963 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.50064 .54568 m .49284 .60001 L p .48735 .57695 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49284 .6 L p .49284 .60001 L .708 .578 .707 r
F P
0 g
s
.49626 .61436 m .49284 .60001 L .49469 .60662 L .708 .578 .707 r
F
.49839 .62486 m .49284 .60001 L .49626 .61436 L F
.50064 .54568 m .5034 .55276 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .50064 .54568 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49291 .60024 m .49668 .58319 L .49493 .60748 L .707 .577 .707 r
F
.49668 .58319 m .5034 .55276 L .49535 .60856 L F
.49534 .60892 m .50127 .63552 L .4989 .62675 L p .708 .578 .707 r
F P
0 g
s
.4989 .62675 m .49839 .62486 L p .49534 .60892 L .708 .578 .707 r
F P
0 g
s
.80307 .6419 m .80649 .68013 L .779 .68149 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .77559 .64326 L .80307 .6419 L p .707 .577 .707 r
F P
0 g
s
.68538 .67947 m .68452 .69734 L .66046 .70406 L p .707 .577 .707 r
F P
0 g
s
.29626 .585 m .30428 .52914 L .30153 .52206 L p .707 .577 .707 r
F P
0 g
s
.47387 .69988 m .47186 .71852 L .48823 .71402 L p .707 .577 .707 r
F P
0 g
s
.48823 .71402 m .49024 .69538 L .47387 .69988 L p .707 .577 .707 r
F P
0 g
s
.68705 .69028 m .68364 .65206 L .7128 .6486 L p .707 .577 .707 r
F P
0 g
s
.8051 .68746 m .80424 .70532 L .77683 .69815 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .7479 .6838 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77559 .64326 m .77696 .65859 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77696 .65859 m .779 .68149 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .77769 .68028 L .79428 .68462 L p .707 .577 .707 r
F P
0 g
s
.79428 .68462 m .8051 .68746 L p .79796 .69015 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .79428 .68462 L .79796 .69015 L .707 .577 .707 r
F
.7128 .6486 m .71621 .68683 L .68705 .69028 L p F P
0 g
s
.304 .67681 m .29742 .67263 L p .3083 .69495 L .707 .577 .707 r
F P
0 g
s
.30454 .68051 m .29911 .65617 L p .2938 .63462 L .708 .578 .707 r
F P
0 g
s
.29911 .65617 m .29668 .64528 L .29547 .6408 L p .708 .578 .707 r
F P
0 g
s
.29547 .6408 m .2938 .63462 L p .29911 .65617 L .708 .578 .707 r
F P
0 g
s
.30784 .69916 m .3083 .69495 L p .29742 .67263 L .707 .577 .707 r
F P
0 g
s
.3083 .69495 m .30985 .68052 L .304 .67681 L p .707 .577 .707 r
F P
0 g
s
.68452 .69734 m .68538 .67947 L .71476 .67608 L p .707 .577 .707 r
F P
0 g
s
.30153 .52206 m .29351 .57791 L .29626 .585 L p .707 .577 .707 r
F P
0 g
s
.29742 .67263 m .29541 .69127 L .30784 .69916 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .74448 .64557 L .77559 .64326 L p .707 .577 .707 r
F P
0 g
s
.29668 .64528 m .30454 .68051 L .31691 .68845 L p .707 .577 .707 r
F P
0 g
s
.71621 .68683 m .7128 .6486 L .74448 .64557 L p .707 .577 .707 r
F P
0 g
s
.71476 .67608 m .71389 .69395 L .68452 .69734 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .71621 .68683 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.74561 .65814 m .7479 .6838 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .74656 .67636 L .76501 .67868 L p .707 .577 .707 r
F P
0 g
s
.76501 .67868 m .77769 .68028 L p .76978 .68373 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .76501 .67868 L .76978 .68373 L .707 .577 .707 r
F
.74448 .64557 m .74561 .65814 L p .73996 .65217 L F P
0 g
s
.77769 .68028 m .77683 .69815 L .7457 .69423 L p .707 .577 .707 r
F P
0 g
s
.71389 .69395 m .71476 .67608 L .74656 .67636 L p .707 .577 .707 r
F P
0 g
s
.74656 .67636 m .7457 .69423 L .71389 .69395 L p .707 .577 .707 r
F P
0 g
s
.49024 .69538 m .48823 .71402 L .49538 .70774 L p .707 .577 .707 r
F P
0 g
s
.49538 .70774 m .49739 .6891 L .49024 .69538 L p .707 .577 .707 r
F P
0 g
s
.29351 .57791 m .30153 .52206 L .30865 .51648 L p .707 .577 .707 r
F P
0 g
s
.29541 .69127 m .29742 .67263 L .29465 .66518 L p .707 .577 .707 r
F P
0 g
s
.29465 .66518 m .29264 .68381 L .29541 .69127 L p .707 .577 .707 r
F P
0 g
s
.29264 .68381 m .29465 .66518 L .2994 .661 L p .707 .577 .707 r
F P
0 g
s
.30166 .66986 m .30454 .68051 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.29662 .64728 m .30166 .66986 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.2938 .63462 m .29662 .64728 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.30166 .66986 m .2938 .63462 L .30068 .62228 L p .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30166 .66986 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30068 .62228 m .30418 .63794 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30418 .63794 m .30854 .65752 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30068 .62228 L .31666 .60947 L p .707 .577 .707 r
F P
0 g
s
.31666 .60947 m .32453 .6447 L .30854 .65752 L p .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .30179 .6589 L .31285 .65586 L p .707 .577 .707 r
F P
0 g
s
.31285 .65586 m .31816 .6544 L p .31442 .65911 L .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .31285 .65586 L .31442 .65911 L .707 .577 .707 r
F
.2994 .661 m .30179 .6589 L p .29997 .66384 L F P
0 g
s
.29264 .68381 m .2994 .661 L .29997 .66384 L .707 .577 .707 r
F
.30865 .51648 m .30063 .57233 L .29351 .57791 L p F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49739 .6891 m .49538 .70774 L .4926 .70029 L p .707 .577 .707 r
F P
0 g
s
.4926 .70029 m .49461 .68165 L .49739 .6891 L p .707 .577 .707 r
F P
0 g
s
.30063 .57233 m .30865 .51648 L .32496 .51295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30179 .6589 m .29978 .67753 L .29264 .68381 L p .707 .577 .707 r
F P
0 g
s
.32496 .51295 m .31694 .5688 L .30063 .57233 L p .707 .577 .707 r
F P
0 g
s
.45949 .58572 m .46751 .52986 L .48828 .53779 L p .707 .577 .707 r
F P
0 g
s
.31694 .5688 m .32496 .51295 L .34886 .51181 L p .707 .577 .707 r
F P
0 g
s
.49461 .68165 m .4926 .70029 L .48017 .6924 L p .707 .577 .707 r
F P
0 g
s
.48017 .6924 m .48218 .67376 L .49461 .68165 L p .707 .577 .707 r
F P
0 g
s
.34886 .51181 m .34083 .56767 L .31694 .5688 L p .707 .577 .707 r
F P
0 g
s
.31816 .6544 m .31615 .67304 L .29978 .67753 L p .707 .577 .707 r
F P
0 g
s
.43236 .57853 m .44038 .52267 L .46751 .52986 L p .707 .577 .707 r
F P
0 g
s
.34083 .56767 m .34886 .51181 L .378 .51318 L p .707 .577 .707 r
F P
0 g
s
.32453 .6447 m .31666 .60947 L .34018 .59744 L p .707 .577 .707 r
F P
0 g
s
.48218 .67376 m .48017 .6924 L .45931 .68483 L p .707 .577 .707 r
F P
0 g
s
.45931 .68483 m .46132 .6662 L .48218 .67376 L p .707 .577 .707 r
F P
0 g
s
.40151 .57278 m .40953 .51692 L .44038 .52267 L p .707 .577 .707 r
F P
0 g
s
.378 .51318 m .36998 .56904 L .34083 .56767 L p .707 .577 .707 r
F P
0 g
s
.36998 .56904 m .378 .51318 L .40953 .51692 L p .707 .577 .707 r
F P
0 g
s
.31615 .67304 m .31816 .6544 L .34215 .65213 L p .707 .577 .707 r
F P
0 g
s
.34018 .59744 m .34804 .63267 L .32453 .6447 L p .707 .577 .707 r
F P
0 g
s
.40953 .51692 m .40151 .57278 L .36998 .56904 L p .707 .577 .707 r
F P
0 g
s
.34215 .65213 m .34015 .67077 L .31615 .67304 L p .707 .577 .707 r
F P
0 g
s
.34804 .63267 m .34018 .59744 L .36892 .58737 L p .707 .577 .707 r
F P
0 g
s
.37678 .6226 m .36892 .58737 L .40008 .58024 L p .707 .577 .707 r
F P
0 g
s
.36892 .58737 m .37678 .6226 L .34804 .63267 L p .707 .577 .707 r
F P
0 g
s
.40008 .58024 m .40794 .61548 L .37678 .6226 L p .707 .577 .707 r
F P
0 g
s
.46132 .6662 m .45931 .68483 L .43206 .67834 L p .707 .577 .707 r
F P
0 g
s
.43206 .67834 m .43407 .65971 L .46132 .6662 L p .707 .577 .707 r
F P
0 g
s
.34015 .67077 m .34215 .65213 L .37142 .65231 L p .707 .577 .707 r
F P
0 g
s
.37142 .65231 m .36941 .67095 L .34015 .67077 L p .707 .577 .707 r
F P
0 g
s
.43407 .65971 m .43206 .67834 L .40108 .67356 L p .707 .577 .707 r
F P
0 g
s
.40108 .67356 m .40309 .65492 L .43407 .65971 L p .707 .577 .707 r
F P
0 g
s
.36941 .67095 m .37142 .65231 L .40309 .65492 L p .707 .577 .707 r
F P
0 g
s
.40309 .65492 m .40108 .67356 L .36941 .67095 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001JOolE0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001GOol30002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH7000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P004Goo4@00A7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002goo1P000eYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH0
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000lOol005Aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP<003Uoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004Ool2
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000gOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000eOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000cOol005Aoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0002
FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@000=J
EP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80031oo`00Dgoo00<005YF00000UYF5P0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000;Woo
001COol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF001JEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJ
EP0002eoo`00Dgoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
1`0015YF00<005YF00000`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800005FUH005YFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Goo001DOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eo
o`<000EJEP03001JEUYF00IJEPD000IJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0004
FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00Egoo0P0015YF00<005YFFUH00eYF100000=JEP00
FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00=JEPH0015oo`H0
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FGoo0`0000AJEP00FUIJEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP03001JEP0000<0011oo`<000Yoo`8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo02]oo`00G7oo1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF10004Goo1@002goo0`0000=JEP00FUH015YF00@005YFFUIJEP8002eo
o`00GGoo00@005YFFUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH00UYF0`003Woo1@003Woo0P001EYF00@005YFFUIJEP8002eo
o`00Fgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YF10001EYF00@005YF000000aoo`D0011oo`8000=JEP04001JEUYFFUH2
000]Ool005Yoo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP04001JEUYFFUH3000:Ool3
000@Ool500000eYF001JEP02FUH2000]Ool004Mooa@000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPl000=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF1P004Woo1@001EYF
0P000eYF00<007ooOol0;7oo000nOol90004FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF2@0015YF00@005YFFUIJEPP0009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH00UYF4P0035YF00@005YFFUH002ioo`00=Woo200015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01000
1UYF00<005YFFUH0200000=JEP00FUH00P000UYF10000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF01QJEP<002ioo`00<Goo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH015YF00<005YFFUH015YF1P002EYF00<005YFFUH02EYF0P00
1EYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001J
EP0002ioo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P001EYF00<005YFFUH015YF00<005YFFUH010001EYF10001UYF00<005YFFUH025YF0`001EYF
00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001JEP00
02ioo`00;Goo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00MJEP04
001JEUYF0005FUH01000FUH000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
01QJEP03001JEP0002ioo`00;7oo00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000=JEP04001JEUYF0005FUH5
0005FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF01AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH0
0003FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF
00H005YFFUH005YF0003FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00eYF0P001UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00eJEP03
001JEUYF00AJEP07001JEUYFOol005YF0000;Woo000/Ool00`00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF0`000UYF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00<00003FUH005YF00EJEP03001JEUYF00=JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUHF000_Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF
0`001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP<000QJEP03001JEUYF00=J
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20003FUH20003FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<0009JEP03001JEP00
0100009JEP@00003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH200000eYF000000060003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`0015YF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20007FUH20007FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYFFUHA0004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1eYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH00`00FUH00002FUH500000eYF001JEP06
FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH60006FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF00@005YFFUIJEQ0000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF00000eYF00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000EJEP00FUIJEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEP0000@0009JEP03001JEUYF00AJEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF01T002eoo`00;Goo00<005YF0000
0UYF0P001EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP@000EJEP@000AJEP05001JEUYFFUH00004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEPD0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP040006FUH00`00
FUIJEP04000]Ool002eoo`03001JEP0000800003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYFFUH50002FUH20007FUH00`00FUIJEP04FUH900000eYF001JEP0:FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000AJEP<0035oo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP800003FUH005YF00IJEP03001JEUYF
009JEPL000EJEP03001JEUYF00UJEP03001JEUYF008000=JEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00;Goo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF3`00
0UYF10001UYF00<005YFFUH02EYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00=JEPh000IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001J
EUYF009JEPT000EJEP03001JEUYF00UJEP04001JEUYFFUH50004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF1P0000=JEP00FUH00eYF
20000goo1P001UYF00<005YFFUH00UYF0P00<Woo000]Ool00eYFOol00002FUH00`00FUIJEP03FUH<
0009Ool40002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHE0003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000eYF00<005YF00003`004Goo10000UYF00<005YFFUH00eYF0P00<Goo000]Ool00eYF001JEP02
FUH00`00FUH00003000IOol40006FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF0P000eYF00<005YFFUH00UYF00@005YFFUH0
01Uoo`<000EJEP04001JEP00000_Ool002eoo`03FUH005YF009JEP80025oo`@0009JEP04001JEUYF
FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYF
FUH005YF001JEP8000IJEP05001JEUYFFUH00002FUH00`00Oomoo`0JOol20003FUH01@00FUIJEUYF
0000;Woo000]Ool01EYF001JEUYF00009goo0`001EYF00<005YF00000`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF00<0
05YF00007Woo0P0000=JEP00FUH00UYF00<007ooOol0;7oo000/Ool00`00FUH00002000[Ool20003
FUH01P00FUIJEUYF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20009Ool3000EOol20003FUH2000]Ool002aoo`04
001JEP00000^Ool01000FUIJEP000eYF00@005YFFUH0009JEQh000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008Ool5000FOol00`00FUIJEP02000]Ool002aoo`@001Qoo`<001Aoo`<000=JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH00UYF00<007oo
Ool01goo1@005goo1000;Goo000/Ool300000eYF001oo`0EOol5000EOol01@00FUIJEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800004FUH005YF0007FUH01000FUIJEP00
2Woo1@006Goo0P00;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0COol5000FOol01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000MJEP<000aoo`<001Uo
o`8002ioo`00;7oo0P000eYF0`004goo1@005goo00<005YF00000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YFFUIJEP0000=JEP<000EJEP8002Uoo`<002ioo`00;7oo0P000eYF00<005YFFUH0
0P004Woo0`006Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00800003FUH0000002Uoo`800003FUH0000002ioo`00;7oo0P000eYF00<005YFFUH00UYF
0`00:Goo0P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJ
EP02FUH3000VOol30003FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00005FUH01000FUH00000
9Woo00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00FUH0
0003000NOol400000eYF001JEP02FUH2000_Ool002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF
0`008Goo0P0015YF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP`000aJEPT000QJ
EP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH7000BOol5
0005FUH01@00FUIJEUYF0000<7oo000^Ool01000FUIJEP001EYF00<005YFFUH015YF10001Goo4@00
0goo100000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@002eYF00<005YF
FUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002mo
o`03001JEP0000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF
001JEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP050006FUH01000FUIJEUYF0P001EYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<7oo0P001EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01`000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00@005YFFUIJEP8000IJEP@000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<Goo00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF0000009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20006
FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000`00=Woo000aOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEUYF008000IJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000goo4P00?goo
000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEPH000=JEP03001JEUYF00=JEP06001JEUYF001JEP00E7oo000]
Ool00`00FUH00004FUH00`00FUIJEP02FUH60008FUH50004FUH20006FUH20005FUH500000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH70002FUH01P00FUIJEP00FUH005Aoo`00
;Goo00<005YF000015YF00<005YF000010000eYF00<005YFFUH01UYF1@0015YF0P001UYF00<005YF
FUH00eYF0`000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0`001eYF00<005YFFUH01000
00=JEP000000EGoo000]Ool00`00FUH00002FUH40005Ool200000eYF001JEP07FUH50004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000IJEP03001JEUYF00=JEP@005Eoo`00;Goo00<005YF00000P000UYF3`00
15YF10001EYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF009JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EGoo000]Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH00UYF1@00
0eYF00AooeYFFUH000=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=JEP03001JEUYF
00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH90004FUH00`00FUIJEP04FUH01000FUH000000Woo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF0P0015YF1P0015YF00@005YFFUH005Eoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP<0
0004FUH005YFFUH2001DOol0031oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPL000aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP020003FUH00`00Oomoo`1BOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPT0
01Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000MJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001oo`1C
Ool003]ooa80021oo`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPT000AJEP03001JEUYF00=JEP03001JEUYF00L005Aoo`00Kgoo0`00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF
100027oo3@000Woo0`0000=JEP000000Dgoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000DOol20002FUH01000FUIJEP00Dgoo001iOol;0006FUH0
0`00FUIJEP0:FUH00`00FUIJEP04FUH70004Ool5000BOol20005FUH00`00FUH0001COol008AooaX0
00]oo`D0011oo`800003FUH005YF00AJEP8005Aoo`00Sgoo0P006Goo0`003goo0P000eYF00<005YF
FUH00eYF00<007ooOol0Dgoo002?Ool3000WOol30006FUH00`00FUIJEP02001FOol008moo`03001J
EUYF00@001moo`@00003FUH005YF00IJEP<005Qoo`00Sgoo0P000UYF00<005YFFUH01`004Goo1`00
1EYF00<005YFFUH015YF0P00FWoo002@Ool01000FUIJEP001EYF00@005YFFUIJEQ4000AJEP03001J
EUYF00IJEP04001JEUYFFUH2001LOol0091oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002AOol30005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol009=oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@006=oo`00UGoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Igoo002HOolG001^Ool00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59357 .74263 m .6016 .68677 L .57073 .68104 L p .707 .577 .707 r
F P
0 g
s
.6016 .68677 m .59357 .74263 L .6251 .74635 L p .707 .577 .707 r
F P
0 g
s
.6251 .74635 m .63313 .69049 L .6016 .68677 L p .707 .577 .707 r
F P
0 g
s
.63313 .69049 m .6251 .74635 L .65419 .7477 L p .707 .577 .707 r
F P
0 g
s
.65419 .7477 m .66222 .69184 L .63313 .69049 L p .707 .577 .707 r
F P
0 g
s
.5627 .7369 m .57073 .68104 L .54354 .67387 L p .707 .577 .707 r
F P
0 g
s
.57073 .68104 m .5627 .7369 L .59357 .74263 L p .707 .577 .707 r
F P
0 g
s
.66222 .69184 m .65419 .7477 L .678 .74654 L p .707 .577 .707 r
F P
0 g
s
.678 .74654 m .68603 .69068 L .66222 .69184 L p .707 .577 .707 r
F P
0 g
s
.54354 .67387 m .53551 .72973 L .5627 .7369 L p .707 .577 .707 r
F P
0 g
s
.53551 .72973 m .54354 .67387 L .52268 .66595 L p .707 .577 .707 r
F P
0 g
s
.59978 .81879 m .59194 .78353 L .56148 .78689 L p .707 .577 .707 r
F P
0 g
s
.59194 .78353 m .59978 .81879 L .63097 .81179 L p .707 .577 .707 r
F P
0 g
s
.63097 .81179 m .62313 .77653 L .59194 .78353 L p .707 .577 .707 r
F P
0 g
s
.62313 .77653 m .63097 .81179 L .65984 .80183 L p .707 .577 .707 r
F P
0 g
s
.65984 .80183 m .652 .76657 L .62313 .77653 L p .707 .577 .707 r
F P
0 g
s
.56932 .82215 m .56148 .78689 L .53474 .78627 L p .707 .577 .707 r
F P
0 g
s
.56148 .78689 m .56932 .82215 L .59978 .81879 L p .707 .577 .707 r
F P
0 g
s
.652 .76657 m .65984 .80183 L .68356 .78989 L p .707 .577 .707 r
F P
0 g
s
.68356 .78989 m .67572 .75463 L .652 .76657 L p .707 .577 .707 r
F P
0 g
s
.52268 .66595 m .51465 .72181 L .53551 .72973 L p .707 .577 .707 r
F P
0 g
s
.59323 .84687 m .59524 .82823 L .56423 .82348 L p .707 .577 .707 r
F P
0 g
s
.59524 .82823 m .59323 .84687 L .62489 .84945 L p .707 .577 .707 r
F P
0 g
s
.62489 .84945 m .62689 .83081 L .59524 .82823 L p .707 .577 .707 r
F P
0 g
s
.69152 .74359 m .6942 .743 L p .68117 .72447 L .707 .577 .707 r
F P
0 g
s
.69197 .74186 m .69294 .74622 L p .70701 .7648 L .707 .577 .707 r
F P
0 g
s
.69294 .74622 m .69981 .77712 L .70492 .76837 L p .707 .577 .707 r
F P
0 g
s
.70492 .76837 m .70701 .7648 L p .69294 .74622 L .707 .577 .707 r
F P
0 g
s
.68603 .69068 m .68117 .72447 L p .6942 .743 L .707 .577 .707 r
F P
0 g
s
.68117 .72447 m .678 .74654 L .69152 .74359 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70223 .68714 L .68603 .69068 L p .707 .577 .707 r
F P
0 g
s
.62689 .83081 m .62489 .84945 L .65409 .8496 L p .707 .577 .707 r
F P
0 g
s
.65409 .8496 m .6561 .83096 L .62689 .83081 L p .707 .577 .707 r
F P
0 g
s
.56423 .82348 m .56222 .84211 L .59323 .84687 L p .707 .577 .707 r
F P
0 g
s
.56222 .84211 m .56296 .83521 L p .53689 .81701 L .707 .577 .707 r
F P
0 g
s
.55309 .82084 m .53689 .81701 L p .56296 .83521 L .707 .577 .707 r
F P
0 g
s
.54257 .82153 m .53731 .79787 L p .51432 .78174 L .707 .577 .707 r
F P
0 g
s
.53731 .79787 m .53474 .78627 L .52838 .78486 L p .707 .577 .707 r
F P
0 g
s
.52838 .78486 m .51432 .78174 L p .53731 .79787 L .707 .577 .707 r
F P
0 g
s
.56296 .83521 m .56423 .82348 L .55309 .82084 L p .707 .577 .707 r
F P
0 g
s
.51465 .72181 m .52268 .66595 L .5102 .65806 L p .707 .577 .707 r
F P
0 g
s
.53474 .78627 m .54257 .82153 L .56932 .82215 L p .707 .577 .707 r
F P
0 g
s
.53689 .81701 m .53488 .83565 L .56222 .84211 L p .707 .577 .707 r
F P
0 g
s
.67572 .75463 m .68356 .78989 L .69981 .77712 L p .707 .577 .707 r
F P
0 g
s
.69981 .77712 m .69197 .74186 L .67572 .75463 L p .707 .577 .707 r
F P
0 g
s
.6561 .83096 m .65409 .8496 L .67798 .84731 L p .707 .577 .707 r
F P
0 g
s
.67798 .84731 m .67999 .82867 L .6561 .83096 L p .707 .577 .707 r
F P
0 g
s
.5102 .65806 m .50217 .71392 L .51465 .72181 L p .707 .577 .707 r
F P
0 g
s
.53488 .83565 m .53545 .83036 L p .51592 .80946 L .707 .577 .707 r
F P
0 g
s
.52718 .81351 m .51592 .80946 L p .53545 .83036 L .707 .577 .707 r
F P
0 g
s
.52216 .817 m .5166 .79198 L p .50224 .77374 L .707 .577 .707 r
F P
0 g
s
.5166 .79198 m .51432 .78174 L .51024 .77904 L p .707 .577 .707 r
F P
0 g
s
.51024 .77904 m .50224 .77374 L p .5166 .79198 L .707 .577 .707 r
F P
0 g
s
.53545 .83036 m .53689 .81701 L .52718 .81351 L p .707 .577 .707 r
F P
0 g
s
.51592 .80946 m .51391 .8281 L .53488 .83565 L p .707 .577 .707 r
F P
0 g
s
.51432 .78174 m .52216 .817 L .54257 .82153 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70048 .73799 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70223 .68714 m .69739 .72082 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.69739 .72082 m .6942 .743 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70701 .7648 m .70092 .73739 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70121 .73699 m .70223 .68714 L .70048 .73799 L .707 .577 .707 r
F
.70092 .73739 m .69917 .72954 L p .69464 .74593 L F P
0 g
s
.70092 .73739 m .70701 .7648 L .70474 .75535 L p .708 .578 .707 r
F P
0 g
s
.70048 .73799 m .7012 .73741 L p .70121 .73699 L .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .70092 .73739 L p .70108 .73815 L .708 .578 .707 r
F P
0 g
s
.70055 .73597 m .69917 .72954 L .70108 .73815 L .708 .578 .707 r
F
.7012 .73741 m .70923 .68155 L .70223 .68714 L p .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .69197 .74186 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70045 .73554 m .69832 .73033 L p .69868 .72873 L .707 .577 .707 r
F P
0 g
s
.6966 .71885 m .69875 .72854 L p .69848 .72926 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .68584 .72244 L p .68658 .72072 L .707 .577 .707 r
F P
0 g
s
.68452 .71085 m .68668 .7206 L p .68599 .72138 L .707 .577 .707 r
F P
0 g
s
.6641 .70632 m .66589 .71435 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66522 .71412 L .66586 .71438 L .707 .577 .707 r
F
.68584 .72244 m .66551 .71472 L p .66586 .71438 L F P
0 g
s
.66551 .71472 m .66498 .71452 L p .66586 .71438 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .6452 .74096 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.68599 .72138 m .68584 .72244 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .67194 .74158 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.67524 .73351 m .68093 .71961 L .68599 .72138 L .707 .577 .707 r
F
.68093 .71961 m .68452 .71085 L .68599 .72138 L F
.68658 .72072 m .68668 .7206 L .69832 .73033 L F
.69848 .72926 m .69832 .73033 L p .68664 .72057 L F P
0 g
s
.68452 .71085 m .6966 .71885 L p .69534 .72695 L .707 .577 .707 r
F P
0 g
s
.68892 .72224 m .68452 .71085 L .69534 .72695 L .707 .577 .707 r
F
.68693 .7217 m .68452 .71085 L p .69402 .73544 L F P
0 g
s
.69387 .66658 m .70635 .67446 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68584 .72244 m .68616 .72022 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68616 .72022 m .69387 .66658 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.69402 .73544 m .68892 .72224 L .69534 .72695 L .707 .577 .707 r
F
.69236 .74611 m .68693 .7217 L p .69402 .73544 L F P
0 g
s
.6641 .70632 m .68452 .71085 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .66589 .71435 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .6641 .70632 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .69387 .66658 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66505 .71406 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66505 .71406 m .67301 .65866 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66522 .71412 m .67481 .69821 L .68599 .72138 L .707 .577 .707 r
F
.69387 .66658 m .68616 .72022 L p .67481 .69821 L F P
0 g
s
.68616 .72022 m .68599 .72138 L p .67481 .69821 L .707 .577 .707 r
F P
0 g
s
.68658 .72072 m .68664 .72057 L .68668 .7206 L .707 .577 .707 r
F
.69236 .74611 m .67194 .74158 L p .67524 .73351 L F P
0 g
s
.68668 .7206 m .69236 .74611 L p .67524 .73351 L .707 .577 .707 r
F P
0 g
s
.69261 .74449 m .69534 .72695 L .69848 .72926 L .707 .577 .707 r
F
.69534 .72695 m .6966 .71885 L .69848 .72926 L F
.69868 .72873 m .69875 .72854 L .70045 .73554 L F
.6966 .71885 m .69917 .72954 L p .70055 .73597 L .708 .578 .707 r
F P
0 g
s
.69922 .73046 m .6966 .71885 L .70055 .73597 L .708 .578 .707 r
F
.699 .72964 m .6966 .71885 L p .70226 .74397 L F P
0 g
s
.70635 .67446 m .70923 .68155 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .69864 .72809 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69864 .72809 m .70635 .67446 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.70226 .74397 m .69922 .73046 L .70055 .73597 L .708 .578 .707 r
F
.70444 .75411 m .699 .72964 L p .70226 .74397 L F P
0 g
s
.68664 .72057 m .69335 .70487 L .69848 .72926 L .707 .577 .707 r
F
.70635 .67446 m .69864 .72809 L p .69335 .70487 L F P
0 g
s
.69864 .72809 m .69848 .72926 L p .69335 .70487 L .707 .577 .707 r
F P
0 g
s
.69868 .72873 m .69874 .72847 L .69875 .72854 L .707 .577 .707 r
F
.70444 .75411 m .69236 .74611 L p .69261 .74449 L F P
0 g
s
.69875 .72854 m .70444 .75411 L p .69261 .74449 L .707 .577 .707 r
F P
0 g
s
.70923 .68155 m .7012 .73741 L .70045 .73554 L p .707 .577 .707 r
F P
0 g
s
.69874 .72847 m .70923 .68155 L .70045 .73554 L .707 .577 .707 r
F
.70444 .75411 m .70055 .73597 L .70108 .73815 L .708 .578 .707 r
F
.70474 .75535 m .70444 .75411 L p .70092 .73739 L F P
0 g
s
.50217 .71392 m .5102 .65806 L .50732 .65098 L p .707 .577 .707 r
F P
0 g
s
.67999 .82867 m .67798 .84731 L .69422 .84279 L p .707 .577 .707 r
F P
0 g
s
.69422 .84279 m .69623 .82415 L .67999 .82867 L p .707 .577 .707 r
F P
0 g
s
.50938 .80536 m .50335 .80158 L p .51411 .82618 L .707 .577 .707 r
F P
0 g
s
.51008 .809 m .50454 .78407 L p .49967 .76305 L .708 .578 .707 r
F P
0 g
s
.50454 .78407 m .50224 .77374 L .50127 .76969 L p .708 .578 .707 r
F P
0 g
s
.50127 .76969 m .49967 .76305 L p .50454 .78407 L .708 .578 .707 r
F P
0 g
s
.51391 .8281 m .51411 .82618 L p .50335 .80158 L .707 .577 .707 r
F P
0 g
s
.51411 .82618 m .51592 .80946 L .50938 .80536 L p .707 .577 .707 r
F P
0 g
s
.50732 .65098 m .49929 .70684 L .50217 .71392 L p .707 .577 .707 r
F P
0 g
s
.50335 .80158 m .50134 .82022 L .51391 .8281 L p .707 .577 .707 r
F P
0 g
s
.50224 .77374 m .51008 .809 L .52216 .817 L p .707 .577 .707 r
F P
0 g
s
.49217 .82187 m .49217 .31998 L .44804 .31744 L p .707 .577 .707 r
F P
0 g
s
.49929 .70684 m .50732 .65098 L .51432 .64539 L p .707 .577 .707 r
F P
0 g
s
.50134 .82022 m .50335 .80158 L .50042 .79412 L p .707 .577 .707 r
F P
0 g
s
.50042 .79412 m .49841 .81276 L .50134 .82022 L p .707 .577 .707 r
F P
0 g
s
.51432 .64539 m .50629 .70125 L .49929 .70684 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .51008 .809 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49967 .76305 m .50268 .77659 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.50268 .77659 m .50751 .79831 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49841 .81276 m .50042 .79412 L .50546 .78959 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .49967 .76305 L .50686 .75073 L p .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50751 .79831 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.50686 .75073 m .5106 .76752 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5106 .76752 m .5147 .78599 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50686 .75073 L .52312 .73796 L p .707 .577 .707 r
F P
0 g
s
.52312 .73796 m .53096 .77322 L .5147 .78599 L p .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .50742 .78783 L .51927 .78454 L p .707 .577 .707 r
F P
0 g
s
.51927 .78454 m .52366 .78332 L p .52062 .78718 L .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .51927 .78454 L .52062 .78718 L .707 .577 .707 r
F
.50546 .78959 m .50742 .78783 L p .50595 .79189 L F P
0 g
s
.49841 .81276 m .50546 .78959 L .50595 .79189 L .707 .577 .707 r
F
.50629 .70125 m .51432 .64539 L .53052 .64184 L p F P
0 g
s
.50742 .78783 m .50541 .80647 L .49841 .81276 L p .707 .577 .707 r
F P
0 g
s
.53052 .64184 m .52249 .6977 L .50629 .70125 L p .707 .577 .707 r
F P
0 g
s
.52249 .6977 m .53052 .64184 L .55433 .64069 L p .707 .577 .707 r
F P
0 g
s
.55433 .64069 m .5463 .69655 L .52249 .6977 L p .707 .577 .707 r
F P
0 g
s
.52366 .78332 m .52165 .80196 L .50541 .80647 L p .707 .577 .707 r
F P
0 g
s
.53096 .77322 m .52312 .73796 L .54684 .72602 L p .707 .577 .707 r
F P
0 g
s
.52165 .80196 m .52366 .78332 L .54755 .78103 L p .707 .577 .707 r
F P
0 g
s
.54684 .72602 m .55468 .76128 L .53096 .77322 L p .707 .577 .707 r
F P
0 g
s
.54755 .78103 m .54554 .79966 L .52165 .80196 L p .707 .577 .707 r
F P
0 g
s
.49217 .31998 m .49217 .82187 L .53706 .82062 L p .707 .577 .707 r
F P
0 g
s
.53706 .82062 m .53706 .31874 L .49217 .31998 L p .707 .577 .707 r
F P
0 g
s
.69623 .82415 m .69422 .84279 L .70121 .8365 L p .707 .577 .707 r
F P
0 g
s
.70121 .8365 m .70322 .81786 L .69623 .82415 L p .707 .577 .707 r
F P
0 g
s
.5463 .69655 m .55433 .64069 L .58342 .64204 L p .707 .577 .707 r
F P
0 g
s
.58342 .64204 m .57539 .6979 L .5463 .69655 L p .707 .577 .707 r
F P
0 g
s
.55468 .76128 m .54684 .72602 L .57571 .71606 L p .707 .577 .707 r
F P
0 g
s
.57571 .71606 m .58355 .75132 L .55468 .76128 L p .707 .577 .707 r
F P
0 g
s
.54554 .79966 m .54755 .78103 L .57675 .78118 L p .707 .577 .707 r
F P
0 g
s
.57675 .78118 m .57474 .79981 L .54554 .79966 L p .707 .577 .707 r
F P
0 g
s
.57474 .79981 m .57675 .78118 L .60841 .78376 L p .707 .577 .707 r
F P
0 g
s
.60841 .78376 m .6064 .80239 L .57474 .79981 L p .707 .577 .707 r
F P
0 g
s
.53706 .31874 m .53706 .82062 L .57832 .81572 L p .707 .577 .707 r
F P
0 g
s
.57539 .6979 m .58342 .64204 L .61494 .64576 L p .707 .577 .707 r
F P
0 g
s
.61494 .64576 m .60691 .70162 L .57539 .6979 L p .707 .577 .707 r
F P
0 g
s
.58355 .75132 m .57571 .71606 L .6069 .70906 L p .707 .577 .707 r
F P
0 g
s
.57832 .81572 m .57832 .31383 L .53706 .31874 L p .707 .577 .707 r
F P
0 g
s
.44804 .81932 m .44804 .31744 L .409 .31136 L p .707 .577 .707 r
F P
0 g
s
.44804 .31744 m .44804 .81932 L .49217 .82187 L p .707 .577 .707 r
F P
0 g
s
.6069 .70906 m .61474 .74432 L .58355 .75132 L p .707 .577 .707 r
F P
0 g
s
.63942 .78851 m .63741 .80715 L .6064 .80239 L p .707 .577 .707 r
F P
0 g
s
.6064 .80239 m .60841 .78376 L .63942 .78851 L p .707 .577 .707 r
F P
0 g
s
.57832 .31383 m .57832 .81572 L .61192 .80764 L p .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6641 .70632 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63875 .71196 m .63736 .7057 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6452 .74096 L .61474 .74432 L p .707 .577 .707 r
F P
0 g
s
.61474 .74432 m .6069 .70906 L .63736 .7057 L p .707 .577 .707 r
F P
0 g
s
.64582 .65148 m .63779 .70734 L .63471 .70677 L p .707 .577 .707 r
F P
0 g
s
.63471 .70677 m .60691 .70162 L p .61879 .68631 L .707 .577 .707 r
F P
0 g
s
.61879 .68631 m .64582 .65148 L .63471 .70677 L .707 .577 .707 r
F
.6452 .74096 m .63875 .71196 L p .65184 .72878 L F P
0 g
s
.60691 .70162 m .61494 .64576 L .64582 .65148 L p .707 .577 .707 r
F P
0 g
s
.61192 .80764 m .61192 .30575 L .57832 .31383 L p .707 .577 .707 r
F P
0 g
s
.25234 .72468 m .25581 .67188 L .22466 .66738 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .28659 .75071 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25581 .67188 m .25234 .72468 L .25665 .72475 L p .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .25581 .67188 L .25665 .72475 L .707 .577 .707 r
F
.22466 .66738 m .22267 .69777 L p .25234 .72468 L F P
0 g
s
.22267 .69777 m .2212 .72018 L .25202 .72463 L p .707 .577 .707 r
F P
0 g
s
.25202 .72463 m .25234 .72468 L p .22267 .69777 L .707 .577 .707 r
F P
0 g
s
.25148 .71546 m .25232 .7249 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25232 .7249 m .25232 .72491 L p .25233 .72491 L .707 .577 .707 r
F P
0 g
s
.26059 .72461 m .25232 .7249 L .25233 .72491 L .707 .577 .707 r
F
.25232 .72491 m .25488 .7537 L p .26059 .72461 L F P
0 g
s
.28757 .67243 m .25581 .67188 L p .28272 .7226 L .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .2834 .72313 L .28272 .7226 L .707 .577 .707 r
F
.2834 .72313 m .28757 .67243 L .28272 .7226 L F
.28421 .72375 m .28757 .67243 L p .28334 .72378 L F P
0 g
s
.31588 .74729 m .29284 .72274 L .28421 .72376 L .707 .577 .707 r
F
.2842 .72375 m .28659 .75071 L .3147 .74743 L p F P
0 g
s
.28757 .67243 m .28421 .72376 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.3147 .74743 m .31588 .74729 L p .2842 .72375 L .707 .577 .707 r
F P
0 g
s
.28659 .75071 m .2842 .72375 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.31686 .66897 m .28757 .67243 L p .312 .7191 L .707 .577 .707 r
F P
0 g
s
.31268 .72041 m .31274 .71971 L .312 .7191 L .707 .577 .707 r
F
.31274 .71971 m .31686 .66897 L .312 .7191 L F
.31588 .74729 m .33987 .74379 L p .33557 .73834 L F P
0 g
s
.31349 .72031 m .31686 .66897 L p .31274 .71971 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31274 .71971 L .31268 .72041 L .707 .577 .707 r
F
.31349 .72031 m .31274 .71971 L .31348 .72031 L F
.33987 .74379 m .35622 .74055 L p .35005 .72962 L F P
0 g
s
.31686 .66897 m .31549 .68977 L p .33733 .71464 L .707 .577 .707 r
F P
0 g
s
.33733 .71464 m .31549 .68977 L .33711 .7147 L .707 .577 .707 r
F
.33348 .71579 m .33733 .71464 L p .31349 .72032 L F P
0 g
s
.33733 .71464 m .34079 .66184 L .31686 .66897 L p .707 .577 .707 r
F P
0 g
s
.34079 .66184 m .33733 .71464 L .35357 .70455 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .33731 .71492 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.33731 .71492 m .33987 .74379 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.31549 .68977 m .31349 .72032 L p .33711 .7147 L .707 .577 .707 r
F P
0 g
s
.33557 .73834 m .33621 .71517 L .32017 .71881 L .707 .577 .707 r
F
.31249 .70906 m .31348 .72031 L p .33557 .73834 L F P
0 g
s
.31348 .72031 m .31588 .74729 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31588 .74729 m .31348 .72031 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31349 .72032 m .31339 .72177 L .33348 .71579 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .31249 .70906 L p .32017 .71881 L .707 .577 .707 r
F P
0 g
s
.33621 .71517 m .33648 .70556 L .32017 .71881 L .707 .577 .707 r
F
.33987 .74379 m .33968 .7417 L p .33557 .73834 L F P
0 g
s
.33968 .7417 m .33648 .70556 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31249 .70906 m .2832 .71247 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31249 .70906 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31339 .72177 m .31349 .72031 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .31339 .72177 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28421 .72376 m .28411 .72523 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.2832 .71247 m .2842 .72375 L p .28421 .72376 L .707 .577 .707 r
F P
0 g
s
.29284 .72274 m .2832 .71247 L .28421 .72376 L .707 .577 .707 r
F
.2832 .71247 m .25148 .71546 L p .26059 .72461 L F P
0 g
s
.2842 .72375 m .2832 .71247 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .28421 .72375 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.25665 .72475 m .28411 .72523 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.409 .81325 m .409 .31136 L .37887 .30235 L p .707 .577 .707 r
F P
0 g
s
.409 .31136 m .409 .81325 L .44804 .81932 L p .707 .577 .707 r
F P
0 g
s
.70322 .81786 m .70121 .8365 L .69829 .82905 L p .707 .577 .707 r
F P
0 g
s
.69829 .82905 m .7003 .81041 L .70322 .81786 L p .707 .577 .707 r
F P
0 g
s
.2212 .72018 m .22466 .66738 L .1972 .65936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19374 .71216 m .1972 .65936 L .1761 .64862 L p .707 .577 .707 r
F P
0 g
s
.1972 .65936 m .19521 .68975 L p .2212 .72018 L .707 .577 .707 r
F P
0 g
s
.21751 .7191 m .2212 .72018 L p .19521 .68975 L .707 .577 .707 r
F P
0 g
s
.22044 .71774 m .22097 .72365 L p .25488 .7537 L .707 .577 .707 r
F P
0 g
s
.22097 .72365 m .22384 .75597 L .24438 .75446 L p .707 .577 .707 r
F P
0 g
s
.24438 .75446 m .25488 .7537 L p .22097 .72365 L .707 .577 .707 r
F P
0 g
s
.19521 .68975 m .19374 .71216 L .21751 .7191 L p .707 .577 .707 r
F P
0 g
s
.61192 .30575 m .61192 .80764 L .63456 .79716 L p .707 .577 .707 r
F P
0 g
s
.63456 .79716 m .63456 .29527 L .61192 .30575 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .25148 .71546 L .22044 .71774 L p .707 .577 .707 r
F P
0 g
s
.22384 .75597 m .22044 .71774 L .19312 .71908 L p .707 .577 .707 r
F P
0 g
s
.7003 .81041 m .69829 .82905 L .68572 .82116 L p .707 .577 .707 r
F P
0 g
s
.68572 .82116 m .68773 .80252 L .7003 .81041 L p .707 .577 .707 r
F P
0 g
s
.19312 .71908 m .19651 .75731 L .22384 .75597 L p .707 .577 .707 r
F P
0 g
s
.37887 .80423 m .37887 .30235 L .3606 .29127 L p .707 .577 .707 r
F P
0 g
s
.37887 .30235 m .37887 .80423 L .409 .81325 L p .707 .577 .707 r
F P
0 g
s
.35357 .70455 m .35703 .65175 L .34079 .66184 L p .707 .577 .707 r
F P
0 g
s
.17263 .70142 m .1761 .64862 L .16342 .6362 L p .707 .577 .707 r
F P
0 g
s
.1761 .64862 m .17263 .70142 L .19374 .71216 L p .707 .577 .707 r
F P
0 g
s
.25213 .82381 m .253 .80594 L .22184 .80207 L p .707 .577 .707 r
F P
0 g
s
.253 .80594 m .25213 .82381 L .28393 .82404 L p .707 .577 .707 r
F P
0 g
s
.28393 .82404 m .28479 .80617 L .253 .80594 L p .707 .577 .707 r
F P
0 g
s
.19651 .75731 m .19312 .71908 L .17218 .71935 L p .707 .577 .707 r
F P
0 g
s
.28479 .80617 m .28393 .82404 L .31324 .82061 L p .707 .577 .707 r
F P
0 g
s
.31324 .82061 m .3141 .80274 L .28479 .80617 L p .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .66498 .71452 L .63779 .70734 L p .707 .577 .707 r
F P
0 g
s
.63779 .70734 m .64582 .65148 L .67301 .65866 L p .707 .577 .707 r
F P
0 g
s
.17218 .71935 m .17557 .75758 L .19651 .75731 L p .707 .577 .707 r
F P
0 g
s
.22097 .81995 m .22184 .80207 L .19435 .79495 L p .707 .577 .707 r
F P
0 g
s
.22184 .80207 m .22097 .81995 L .25213 .82381 L p .707 .577 .707 r
F P
0 g
s
.19435 .79495 m .19349 .81282 L .22097 .81995 L p .707 .577 .707 r
F P
0 g
s
.35622 .74055 m .35282 .70231 L .33648 .70556 L p .707 .577 .707 r
F P
0 g
s
.63741 .80715 m .63942 .78851 L .66675 .79498 L p .707 .577 .707 r
F P
0 g
s
.63456 .29527 m .63456 .79716 L .64403 .78532 L p .707 .577 .707 r
F P
0 g
s
.64403 .78532 m .64403 .28343 L .63456 .29527 L p .707 .577 .707 r
F P
0 g
s
.3141 .80274 m .31324 .82061 L .3372 .81385 L p .707 .577 .707 r
F P
0 g
s
.3372 .81385 m .33806 .79598 L .3141 .80274 L p .707 .577 .707 r
F P
0 g
s
.68773 .80252 m .68572 .82116 L .66474 .81362 L p .707 .577 .707 r
F P
0 g
s
.66474 .81362 m .66675 .79498 L .68773 .80252 L p .707 .577 .707 r
F P
0 g
s
.35703 .65175 m .35357 .70455 L .36053 .69247 L p .707 .577 .707 r
F P
0 g
s
.36053 .69247 m .36399 .63967 L .35703 .65175 L p .707 .577 .707 r
F P
0 g
s
.19349 .81282 m .19435 .79495 L .17324 .78525 L p .707 .577 .707 r
F P
0 g
s
.16342 .6362 m .15996 .689 L .17263 .70142 L p .707 .577 .707 r
F P
0 g
s
.15996 .689 m .16342 .6362 L .16042 .62333 L p .707 .577 .707 r
F P
0 g
s
.17557 .75758 m .17218 .71935 L .15968 .71852 L p .707 .577 .707 r
F P
0 g
s
.17324 .78525 m .17237 .80312 L .19349 .81282 L p .707 .577 .707 r
F P
0 g
s
.35282 .70231 m .35622 .74055 L .36332 .73787 L p .707 .577 .707 r
F P
0 g
s
.36332 .73787 m .35992 .69964 L .35282 .70231 L p .707 .577 .707 r
F P
0 g
s
.36399 .63967 m .36053 .69247 L .35753 .67959 L p .707 .577 .707 r
F P
0 g
s
.35753 .67959 m .36099 .62679 L .36399 .63967 L p .707 .577 .707 r
F P
0 g
s
.36043 .79326 m .3613 .77539 L .35433 .78656 L p .707 .577 .707 r
F P
0 g
s
.35992 .69964 m .36332 .73787 L .36048 .73603 L p .707 .577 .707 r
F P
0 g
s
.36048 .73603 m .35709 .6978 L .35992 .69964 L p .707 .577 .707 r
F P
0 g
s
.36099 .62679 m .35753 .67959 L .34485 .66717 L p .707 .577 .707 r
F P
0 g
s
.34485 .66717 m .34832 .61437 L .36099 .62679 L p .707 .577 .707 r
F P
0 g
s
.3613 .77539 m .36043 .79326 L .35744 .78145 L p .707 .577 .707 r
F P
0 g
s
.35744 .78145 m .3583 .76358 L .3613 .77539 L p .707 .577 .707 r
F P
0 g
s
.35709 .6978 m .36048 .73603 L .34798 .73521 L p .707 .577 .707 r
F P
0 g
s
.3606 .79316 m .3606 .29127 L .35597 .27923 L p .707 .577 .707 r
F P
0 g
s
.3606 .29127 m .3606 .79316 L .37887 .80423 L p .707 .577 .707 r
F P
0 g
s
.15968 .71852 m .16307 .75675 L .17557 .75758 L p .707 .577 .707 r
F P
0 g
s
.33806 .79598 m .3372 .81385 L .35346 .80443 L p .707 .577 .707 r
F P
0 g
s
.35346 .80443 m .35433 .78656 L .33806 .79598 L p .707 .577 .707 r
F P
0 g
s
.66675 .79498 m .66474 .81362 L .63741 .80715 L p .707 .577 .707 r
F P
0 g
s
.17237 .80312 m .17324 .78525 L .16056 .77395 L p .707 .577 .707 r
F P
0 g
s
.16042 .62333 m .15695 .67613 L .15996 .689 L p .707 .577 .707 r
F P
0 g
s
.16056 .77395 m .1597 .79182 L .17237 .80312 L p .707 .577 .707 r
F P
0 g
s
.15695 .67613 m .16042 .62333 L .16738 .61125 L p .707 .577 .707 r
F P
0 g
s
.16307 .75675 m .15968 .71852 L .15684 .71668 L p .707 .577 .707 r
F P
0 g
s
.64403 .28343 m .64403 .78532 L .6394 .77327 L p .707 .577 .707 r
F P
0 g
s
.6394 .77327 m .6394 .27139 L .64403 .28343 L p .707 .577 .707 r
F P
0 g
s
.15684 .71668 m .16024 .75491 L .16307 .75675 L p .707 .577 .707 r
F P
0 g
s
.35433 .78656 m .35346 .80443 L .36043 .79326 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1597 .79182 m .16056 .77395 L .15756 .76213 L p .707 .577 .707 r
F P
0 g
s
.34798 .73521 m .34459 .69698 L .35709 .6978 L p .707 .577 .707 r
F P
0 g
s
.3583 .76358 m .35744 .78145 L .34476 .77014 L p .707 .577 .707 r
F P
0 g
s
.34476 .77014 m .34563 .75227 L .3583 .76358 L p .707 .577 .707 r
F P
0 g
s
.35597 .27923 m .35597 .78112 L .3606 .79316 L p .707 .577 .707 r
F P
0 g
s
.35597 .78112 m .35597 .27923 L .36544 .26739 L p .707 .577 .707 r
F P
0 g
s
.16738 .61125 m .16391 .66405 L .15695 .67613 L p .707 .577 .707 r
F P
0 g
s
.15756 .76213 m .1567 .78001 L .1597 .79182 L p .707 .577 .707 r
F P
0 g
s
.16391 .66405 m .16738 .61125 L .18362 .60115 L p .707 .577 .707 r
F P
0 g
s
.16024 .75491 m .15684 .71668 L .16394 .71401 L p .707 .577 .707 r
F P
0 g
s
.16394 .71401 m .16734 .75224 L .16024 .75491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1567 .78001 m .15756 .76213 L .16454 .75097 L p .707 .577 .707 r
F P
0 g
s
.6394 .27139 m .6394 .77327 L .62113 .7622 L p .707 .577 .707 r
F P
0 g
s
.62113 .7622 m .62113 .26031 L .6394 .27139 L p .707 .577 .707 r
F P
0 g
s
.34832 .61437 m .34485 .66717 L .32375 .65643 L p .707 .577 .707 r
F P
0 g
s
.32375 .65643 m .32721 .60363 L .34832 .61437 L p .707 .577 .707 r
F P
0 g
s
.18362 .60115 m .18016 .65395 L .16391 .66405 L p .707 .577 .707 r
F P
0 g
s
.16454 .75097 m .16367 .76884 L .1567 .78001 L p .707 .577 .707 r
F P
0 g
s
.18016 .65395 m .18362 .60115 L .20755 .59403 L p .707 .577 .707 r
F P
0 g
s
.36544 .76928 m .36544 .26739 L .38808 .25691 L p .707 .577 .707 r
F P
0 g
s
.36544 .26739 m .36544 .76928 L .35597 .78112 L p .707 .577 .707 r
F P
0 g
s
.16734 .75224 m .16394 .71401 L .18029 .71076 L p .707 .577 .707 r
F P
0 g
s
.18029 .71076 m .18368 .74899 L .16734 .75224 L p .707 .577 .707 r
F P
0 g
s
.32721 .60363 m .32375 .65643 L .29628 .64842 L p .707 .577 .707 r
F P
0 g
s
.29628 .64842 m .29975 .59562 L .32721 .60363 L p .707 .577 .707 r
F P
0 g
s
.20409 .64683 m .20755 .59403 L .23684 .59057 L p .707 .577 .707 r
F P
0 g
s
.20755 .59403 m .20409 .64683 L .18016 .65395 L p .707 .577 .707 r
F P
0 g
s
.16367 .76884 m .16454 .75097 L .1808 .74155 L p .707 .577 .707 r
F P
0 g
s
.34459 .69698 m .34798 .73521 L .32704 .73548 L p .707 .577 .707 r
F P
0 g
s
.32704 .73548 m .32365 .69725 L .34459 .69698 L p .707 .577 .707 r
F P
0 g
s
.1808 .74155 m .17994 .75942 L .16367 .76884 L p .707 .577 .707 r
F P
0 g
s
.29975 .59562 m .29628 .64842 L .26514 .64392 L p .707 .577 .707 r
F P
0 g
s
.26514 .64392 m .26861 .59112 L .29975 .59562 L p .707 .577 .707 r
F P
0 g
s
.23338 .64337 m .23684 .59057 L .26861 .59112 L p .707 .577 .707 r
F P
0 g
s
.23684 .59057 m .23338 .64337 L .20409 .64683 L p .707 .577 .707 r
F P
0 g
s
.62113 .26031 m .62113 .7622 L .591 .75319 L p .707 .577 .707 r
F P
0 g
s
.591 .75319 m .591 .2513 L .62113 .26031 L p .707 .577 .707 r
F P
0 g
s
.26861 .59112 m .26514 .64392 L .23338 .64337 L p .707 .577 .707 r
F P
0 g
s
.18368 .74899 m .18029 .71076 L .20428 .70726 L p .707 .577 .707 r
F P
0 g
s
.34563 .75227 m .34476 .77014 L .32365 .76045 L p .707 .577 .707 r
F P
0 g
s
.32365 .76045 m .32451 .74258 L .34563 .75227 L p .707 .577 .707 r
F P
0 g
s
.20428 .70726 m .20767 .74549 L .18368 .74899 L p .707 .577 .707 r
F P
0 g
s
.38808 .25691 m .38808 .7588 L .36544 .76928 L p .707 .577 .707 r
F P
0 g
s
.38808 .7588 m .38808 .25691 L .42168 .24883 L p .707 .577 .707 r
F P
0 g
s
.17994 .75942 m .1808 .74155 L .20476 .73479 L p .707 .577 .707 r
F P
0 g
s
.73485 .64433 m .73139 .58724 L .70025 .58818 L p .707 .577 .707 r
F P
0 g
s
.73139 .58724 m .73485 .64433 L .76662 .64204 L p .707 .577 .707 r
F P
0 g
s
.76662 .64204 m .76316 .58495 L .73139 .58724 L p .707 .577 .707 r
F P
0 g
s
.32365 .69725 m .32704 .73548 L .29972 .73682 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .29632 .69858 L .32365 .69725 L p .707 .577 .707 r
F P
0 g
s
.76316 .58495 m .76662 .64204 L .79591 .63862 L p .707 .577 .707 r
F P
0 g
s
.79591 .63862 m .79244 .58153 L .76316 .58495 L p .707 .577 .707 r
F P
0 g
s
.20476 .73479 m .20389 .75266 L .17994 .75942 L p .707 .577 .707 r
F P
0 g
s
.70371 .64527 m .70025 .58818 L .67278 .58767 L p .707 .577 .707 r
F P
0 g
s
.70025 .58818 m .70371 .64527 L .73485 .64433 L p .707 .577 .707 r
F P
0 g
s
.20767 .74549 m .20428 .70726 L .23357 .70385 L p .707 .577 .707 r
F P
0 g
s
.32451 .74258 m .32365 .76045 L .29616 .75332 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .26868 .73909 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29632 .69858 m .29779 .7151 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29779 .7151 m .29972 .73682 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .29703 .73545 L .31522 .74017 L p .707 .577 .707 r
F P
0 g
s
.31522 .74017 m .32451 .74258 L p .31849 .74486 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .31522 .74017 L .31849 .74486 L .707 .577 .707 r
F
.23357 .70385 m .23696 .74208 L .20767 .74549 L p F P
0 g
s
.67278 .58767 m .67625 .64476 L .70371 .64527 L p .707 .577 .707 r
F P
0 g
s
.79244 .58153 m .79591 .63862 L .81984 .63441 L p .707 .577 .707 r
F P
0 g
s
.81984 .63441 m .81638 .57732 L .79244 .58153 L p .707 .577 .707 r
F P
0 g
s
.591 .2513 m .591 .75319 L .55196 .74711 L p .707 .577 .707 r
F P
0 g
s
.55196 .74711 m .55196 .24522 L .591 .2513 L p .707 .577 .707 r
F P
0 g
s
.20389 .75266 m .20476 .73479 L .23407 .73136 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .26528 .70086 L .29632 .69858 L p .707 .577 .707 r
F P
0 g
s
.23696 .74208 m .23357 .70385 L .26528 .70086 L p .707 .577 .707 r
F P
0 g
s
.67625 .64476 m .67278 .58767 L .65168 .58576 L p .707 .577 .707 r
F P
0 g
s
.735 .75033 m .73413 .73138 L .71389 .73153 L p .707 .577 .707 r
F P
0 g
s
.71389 .73153 m .70297 .7316 L p .70966 .73551 L .707 .577 .707 r
F P
0 g
s
.735 .75033 m .71389 .73153 L .70966 .73551 L .707 .577 .707 r
F
.73413 .73138 m .735 .75033 L .76679 .74842 L p F P
0 g
s
.76679 .74842 m .76593 .72947 L .74717 .7306 L p .707 .577 .707 r
F P
0 g
s
.74717 .7306 m .73413 .73138 L p .74211 .73554 L .707 .577 .707 r
F P
0 g
s
.76679 .74842 m .74717 .7306 L .74211 .73554 L .707 .577 .707 r
F
.76593 .72947 m .76679 .74842 L .7961 .74501 L p F P
0 g
s
.7961 .74501 m .79524 .72606 L .77973 .72787 L p .707 .577 .707 r
F P
0 g
s
.77973 .72787 m .76593 .72947 L p .77476 .73402 L .707 .577 .707 r
F P
0 g
s
.7961 .74501 m .77973 .72787 L .77476 .73402 L .707 .577 .707 r
F
.79524 .72606 m .7961 .74501 L .82006 .74042 L p F P
0 g
s
.82006 .74042 m .8192 .72148 L .80787 .72364 L p .707 .577 .707 r
F P
0 g
s
.80787 .72364 m .79524 .72606 L p .804 .73113 L .707 .577 .707 r
F P
0 g
s
.82006 .74042 m .80787 .72364 L .804 .73113 L .707 .577 .707 r
F
.8192 .72148 m .82006 .74042 L .83633 .73512 L p F P
0 g
s
.83633 .73512 m .83546 .71618 L .8192 .72148 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .83266 .71377 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81971 .69107 m .81851 .70309 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81851 .70309 m .81631 .72509 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .81631 .72509 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79572 .69884 m .79467 .70936 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79467 .70936 m .79232 .73287 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .79232 .73287 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76643 .70231 m .76538 .71279 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76538 .71279 m .76304 .73633 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .76304 .73633 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73471 .70112 m .73352 .71305 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73352 .71305 m .73132 .73515 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .73471 .70112 L .70367 .6954 L p .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .76643 .70231 L .73471 .70112 L p .707 .577 .707 r
F P
0 g
s
.23407 .73136 m .23321 .74923 L .20389 .75266 L p .707 .577 .707 r
F P
0 g
s
.42168 .75072 m .42168 .24883 L .46294 .24392 L p .707 .577 .707 r
F P
0 g
s
.42168 .24883 m .42168 .75072 L .38808 .7588 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .23696 .74208 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.26647 .71427 m .26868 .73909 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .26586 .73158 L .28611 .7341 L p .707 .577 .707 r
F P
0 g
s
.28611 .7341 m .29703 .73545 L p .29034 .73838 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .28611 .7341 L .29034 .73838 L .707 .577 .707 r
F
.26528 .70086 m .26647 .71427 L p .26033 .70807 L F P
0 g
s
.29703 .73545 m .29616 .75332 L .265 .74946 L p .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .79572 .69884 L .76643 .70231 L p .707 .577 .707 r
F P
0 g
s
.70028 .72943 m .70367 .6954 L .67635 .68571 L p .707 .577 .707 r
F P
0 g
s
.70367 .6954 m .70028 .72943 L .73132 .73515 L p .707 .577 .707 r
F P
0 g
s
.23321 .74923 m .23407 .73136 L .26586 .73158 L p .707 .577 .707 r
F P
0 g
s
.65168 .58576 m .65514 .64285 L .67625 .64476 L p .707 .577 .707 r
F P
0 g
s
.26586 .73158 m .265 .74946 L .23321 .74923 L p .707 .577 .707 r
F P
0 g
s
.81638 .57732 m .81984 .63441 L .83608 .6298 L p .707 .577 .707 r
F P
0 g
s
.83608 .6298 m .83262 .57271 L .81638 .57732 L p .707 .577 .707 r
F P
0 g
s
.70297 .7316 m .70383 .75055 L .735 .75033 L p .707 .577 .707 r
F P
0 g
s
.55196 .24522 m .55196 .74711 L .50783 .74457 L p .707 .577 .707 r
F P
0 g
s
.50783 .74457 m .50783 .24268 L .55196 .24522 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .81971 .69107 L .79572 .69884 L p .707 .577 .707 r
F P
0 g
s
.70383 .75055 m .70297 .7316 L .67549 .73011 L p .707 .577 .707 r
F P
0 g
s
.46294 .74581 m .46294 .24392 L .50783 .24268 L p .707 .577 .707 r
F P
0 g
s
.46294 .24392 m .46294 .74581 L .42168 .75072 L p .707 .577 .707 r
F P
0 g
s
.67295 .71974 m .67635 .68571 L .65541 .67299 L p .707 .577 .707 r
F P
0 g
s
.67635 .68571 m .67295 .71974 L .70028 .72943 L p .707 .577 .707 r
F P
0 g
s
.67549 .73011 m .67635 .74906 L .70383 .75055 L p .707 .577 .707 r
F P
0 g
s
.50783 .24268 m .50783 .74457 L .46294 .74581 L p .707 .577 .707 r
F P
0 g
s
.65514 .64285 m .65168 .58576 L .63901 .58264 L p .707 .577 .707 r
F P
0 g
s
.63901 .58264 m .64247 .63973 L .65514 .64285 L p .707 .577 .707 r
F P
0 g
s
.67635 .74906 m .67549 .73011 L .65437 .72706 L p .707 .577 .707 r
F P
0 g
s
.83266 .71377 m .83605 .67974 L .81971 .69107 L p .707 .577 .707 r
F P
0 g
s
.65437 .72706 m .65524 .746 L .67635 .74906 L p .707 .577 .707 r
F P
0 g
s
.65541 .67299 m .65202 .70702 L .67295 .71974 L p .707 .577 .707 r
F P
0 g
s
.65202 .70702 m .65541 .67299 L .64291 .65849 L p .707 .577 .707 r
F P
0 g
s
.83262 .57271 m .83608 .6298 L .84304 .62527 L p .707 .577 .707 r
F P
0 g
s
.84304 .62527 m .83958 .56818 L .83262 .57271 L p .707 .577 .707 r
F P
0 g
s
.64247 .63973 m .63901 .58264 L .636 .57862 L p .707 .577 .707 r
F P
0 g
s
.65524 .746 m .65437 .72706 L .6417 .72274 L p .707 .577 .707 r
F P
0 g
s
.64291 .65849 m .63952 .69252 L .65202 .70702 L p .707 .577 .707 r
F P
0 g
s
.6417 .72274 m .64256 .74168 L .65524 .746 L p .707 .577 .707 r
F P
0 g
s
.636 .57862 m .63947 .63571 L .64247 .63973 L p .707 .577 .707 r
F P
0 g
s
.83605 .67974 m .83266 .71377 L .83976 .7 L p .707 .577 .707 r
F P
0 g
s
.83976 .7 m .84316 .66598 L .83605 .67974 L p .707 .577 .707 r
F P
0 g
s
.63952 .69252 m .64291 .65849 L .64007 .64363 L p .707 .577 .707 r
F P
0 g
s
.83958 .56818 m .84304 .62527 L .84004 .62125 L p .707 .577 .707 r
F P
0 g
s
.84004 .62125 m .83658 .56416 L .83958 .56818 L p .707 .577 .707 r
F P
0 g
s
.83546 .71618 m .83633 .73512 L .8433 .72962 L p .707 .577 .707 r
F P
0 g
s
.8433 .72962 m .84243 .71067 L .83546 .71618 L p .707 .577 .707 r
F P
0 g
s
.64007 .64363 m .63668 .67766 L .63952 .69252 L p .707 .577 .707 r
F P
0 g
s
.63947 .63571 m .636 .57862 L .64296 .57409 L p .707 .577 .707 r
F P
0 g
s
.64256 .74168 m .6417 .72274 L .6387 .71757 L p .707 .577 .707 r
F P
0 g
s
.6387 .71757 m .63956 .73652 L .64256 .74168 L p .707 .577 .707 r
F P
0 g
s
.84316 .66598 m .83976 .7 L .83693 .68515 L p .707 .577 .707 r
F P
0 g
s
.83693 .68515 m .84032 .65112 L .84316 .66598 L p .707 .577 .707 r
F P
0 g
s
.64296 .57409 m .64643 .63118 L .63947 .63571 L p .707 .577 .707 r
F P
0 g
s
.63668 .67766 m .64007 .64363 L .64718 .62987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83658 .56416 m .84004 .62125 L .82737 .61813 L p .707 .577 .707 r
F P
0 g
s
.82737 .61813 m .8239 .56104 L .83658 .56416 L p .707 .577 .707 r
F P
0 g
s
.84243 .71067 m .8433 .72962 L .8403 .72445 L p .707 .577 .707 r
F P
0 g
s
.8403 .72445 m .83944 .70551 L .84243 .71067 L p .707 .577 .707 r
F P
0 g
s
.39308 .62674 m .38505 .57272 L .35418 .57452 L p .707 .577 .707 r
F P
0 g
s
.38505 .57272 m .39308 .62674 L .42461 .62161 L p .707 .577 .707 r
F P
0 g
s
.42461 .62161 m .41658 .56758 L .38505 .57272 L p .707 .577 .707 r
F P
0 g
s
.41658 .56758 m .42461 .62161 L .4537 .61364 L p .707 .577 .707 r
F P
0 g
s
.4537 .61364 m .44567 .55961 L .41658 .56758 L p .707 .577 .707 r
F P
0 g
s
.65921 .56949 m .65992 .58131 L p .64643 .63118 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .64718 .62987 L .66352 .61854 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .64378 .6639 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .66269 .62688 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66013 .65257 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .68751 .61077 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .6866 .62236 L .66652 .6259 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .66269 .62688 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66352 .61854 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .66013 .65257 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .68651 .62079 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .68412 .6448 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .7168 .60731 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L .68732 .62069 L .707 .577 .707 r
F
.68651 .62079 m .68751 .61077 L p .70716 .61836 L F P
0 g
s
.71589 .61894 m .6866 .62236 L p .68732 .62069 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .71426 .61753 L .71589 .61894 L .707 .577 .707 r
F
.71341 .64133 m .68412 .6448 L p .70716 .61836 L F P
0 g
s
.7168 .60731 m .7158 .61734 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.7168 .60731 m .74852 .60849 L p .7394 .61701 L .707 .577 .707 r
F P
0 g
s
.74335 .61696 m .71589 .61894 L p .71665 .61733 L .707 .577 .707 r
F P
0 g
s
.72838 .62732 m .72255 .61725 L .7394 .61701 L .707 .577 .707 r
F
.72255 .61725 m .7168 .60731 L .7394 .61701 L F
.74852 .60849 m .74768 .61689 L p .71341 .64133 L F P
0 g
s
.74768 .61689 m .74512 .64252 L .71891 .64154 L p .707 .577 .707 r
F P
0 g
s
.71891 .64154 m .71341 .64133 L p .74768 .61689 L .707 .577 .707 r
F P
0 g
s
.74512 .64252 m .74852 .60849 L .77956 .61421 L p .707 .577 .707 r
F P
0 g
s
.77533 .55862 m .77733 .59149 L p .74766 .61665 L .707 .577 .707 r
F P
0 g
s
.77956 .61421 m .77903 .61947 L p .74512 .64252 L .707 .577 .707 r
F P
0 g
s
.77903 .61947 m .77616 .64824 L .75562 .64445 L p .707 .577 .707 r
F P
0 g
s
.75562 .64445 m .74512 .64252 L p .77903 .61947 L .707 .577 .707 r
F P
0 g
s
.77616 .64824 m .77956 .61421 L .80688 .6239 L p .707 .577 .707 r
F P
0 g
s
.8028 .55913 m .80479 .59199 L p .7788 .61571 L .707 .577 .707 r
F P
0 g
s
.80479 .59199 m .80626 .61622 L .78249 .61578 L p .707 .577 .707 r
F P
0 g
s
.78249 .61578 m .7788 .61571 L p .80479 .59199 L .707 .577 .707 r
F P
0 g
s
.77733 .59149 m .7788 .61571 L .74797 .61664 L p .707 .577 .707 r
F P
0 g
s
.74797 .61664 m .74766 .61665 L p .77733 .59149 L .707 .577 .707 r
F P
0 g
s
.74419 .55956 m .74766 .61665 L .74335 .61696 L p .707 .577 .707 r
F P
0 g
s
.71589 .61894 m .7158 .61734 L .71665 .61733 L .707 .577 .707 r
F
.7158 .61735 m .7158 .61734 L p .72838 .62732 L F P
0 g
s
.7158 .61734 m .7168 .60731 L p .72255 .61725 L .707 .577 .707 r
F P
0 g
s
.7158 .61734 m .72255 .61725 L .72838 .62732 L .707 .577 .707 r
F
.71589 .61894 m .71579 .61735 L p .7158 .61734 L F P
0 g
s
.71665 .61733 m .7158 .61734 L .71728 .61602 L .707 .577 .707 r
F
.71665 .61733 m .74419 .55956 L .74335 .61696 L F
.71243 .56185 m .74419 .55956 L p .71728 .61602 L F P
0 g
s
.70716 .61836 m .7158 .61734 L .71579 .61735 L .707 .577 .707 r
F
.71579 .61735 m .71243 .56185 L p .71728 .61602 L F P
0 g
s
.7158 .61734 m .7158 .61735 L p .71579 .61735 L .707 .577 .707 r
F P
0 g
s
.71579 .61734 m .71589 .61894 L p .69558 .60132 L .707 .577 .707 r
F P
0 g
s
.7158 .61735 m .71341 .64133 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .69558 .60132 L .71426 .61753 L .707 .577 .707 r
F
.71243 .56185 m .71579 .61734 L p .69558 .60132 L F P
0 g
s
.71341 .64133 m .7158 .61735 L p .72838 .62732 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .68651 .62079 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .68651 .62079 L .688 .61909 L .707 .577 .707 r
F
.68314 .56527 m .71243 .56185 L p .688 .61909 L F P
0 g
s
.68651 .62079 m .68314 .56527 L p .688 .61909 L .707 .577 .707 r
F P
0 g
s
.6845 .58776 m .68651 .62079 L p .66288 .62654 L .707 .577 .707 r
F P
0 g
s
.66652 .6259 m .66288 .62654 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.68314 .56527 m .6845 .58776 L p .66267 .62658 L .707 .577 .707 r
F P
0 g
s
.66288 .62654 m .66267 .62658 L p .6845 .58776 L .707 .577 .707 r
F P
0 g
s
.65992 .58131 m .66267 .62658 L .6477 .63082 L p .707 .577 .707 r
F P
0 g
s
.64718 .62987 m .64666 .63502 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.6477 .63082 m .64643 .63118 L p .65992 .58131 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .63668 .67766 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.64666 .63502 m .64378 .6639 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36221 .62854 m .35418 .57452 L .32698 .57281 L p .707 .577 .707 r
F P
0 g
s
.35418 .57452 m .36221 .62854 L .39308 .62674 L p .707 .577 .707 r
F P
0 g
s
.64643 .63118 m .64296 .57409 L .65921 .56949 L p .707 .577 .707 r
F P
0 g
s
.63956 .73652 m .6387 .71757 L .64567 .71207 L p .707 .577 .707 r
F P
0 g
s
.84032 .65112 m .83693 .68515 L .82443 .67065 L p .707 .577 .707 r
F P
0 g
s
.82443 .67065 m .82782 .63662 L .84032 .65112 L p .707 .577 .707 r
F P
0 g
s
.44567 .55961 m .4537 .61364 L .47751 .60361 L p .707 .577 .707 r
F P
0 g
s
.47751 .60361 m .46948 .54959 L .44567 .55961 L p .707 .577 .707 r
F P
0 g
s
.64567 .71207 m .64654 .73101 L .63956 .73652 L p .707 .577 .707 r
F P
0 g
s
.38526 .67084 m .3931 .63382 L .36264 .62624 L p .707 .577 .707 r
F P
0 g
s
.3931 .63382 m .38526 .67084 L .41645 .67674 L p .707 .577 .707 r
F P
0 g
s
.41645 .67674 m .42429 .63972 L .3931 .63382 L p .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .30612 .56775 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33495 .62639 m .32698 .57281 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .32914 .58728 L p .36221 .62854 L .707 .577 .707 r
F P
0 g
s
.32914 .58728 m .33501 .62683 L .35953 .62837 L p .707 .577 .707 r
F P
0 g
s
.35953 .62837 m .36221 .62854 L p .32914 .58728 L .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .38526 .67084 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.36264 .62624 m .3616 .63116 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.3616 .63116 m .3548 .66326 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .33411 .62616 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .3096 .59114 L p .33501 .62683 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32805 .65474 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.30764 .64612 m .32805 .65474 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32258 .60969 L .314 .62075 L .707 .577 .707 r
F
.3096 .59114 m .31383 .61962 L p .32258 .60969 L F P
0 g
s
.31383 .61962 m .314 .62075 L p .32258 .60969 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .29364 .55984 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31383 .61962 m .30612 .56775 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31307 .6205 L p .314 .62075 L .707 .577 .707 r
F P
0 g
s
.30598 .62854 m .31108 .61811 L .30466 .61457 L .707 .577 .707 r
F
.30764 .64612 m .31307 .6205 L p .30598 .62854 L F P
0 g
s
.31307 .6205 m .31331 .61934 L p .30598 .62854 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31108 .61811 L .30598 .62854 L .707 .577 .707 r
F
.31307 .6205 m .30764 .64612 L p .3169 .62667 L F P
0 g
s
.31907 .62211 m .314 .62075 L .3169 .62667 L .707 .577 .707 r
F
.314 .62075 m .31307 .6205 L .3169 .62667 L F
.31336 .61936 m .30664 .5991 L .30152 .61284 L F
.29364 .55984 m .30135 .61171 L p .30664 .5991 L F P
0 g
s
.30135 .61171 m .30152 .61284 L p .30664 .5991 L .707 .577 .707 r
F P
0 g
s
.29364 .55984 m .29076 .54986 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .30764 .64612 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.30132 .61178 m .30135 .61171 L .30126 .61144 L .707 .577 .707 r
F
.30152 .61284 m .30135 .61171 L p .30132 .61178 L F P
0 g
s
.30135 .61171 m .29364 .55984 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.30124 .61139 m .29556 .63824 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29773 .62033 m .30078 .61005 L .29945 .60622 L .707 .577 .707 r
F
.301 .61255 m .30124 .61139 L p .29773 .62033 L F P
0 g
s
.30124 .61139 m .30078 .61005 L .29773 .62033 L .707 .577 .707 r
F
.29955 .60651 m .30167 .61387 L p .30126 .61144 L F P
0 g
s
.30126 .61144 m .29076 .54986 L .29955 .60651 L .707 .577 .707 r
F
.30124 .61139 m .3034 .60122 L p .30078 .61005 L F P
0 g
s
.3034 .60122 m .30124 .61139 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29879 .60389 m .29955 .60651 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.3034 .60122 m .30083 .59485 L p .29945 .60622 L .707 .577 .707 r
F P
0 g
s
.30078 .61005 m .3034 .60122 L .29945 .60622 L .707 .577 .707 r
F
.31548 .6091 m .3034 .60122 L p .30466 .61457 L F P
0 g
s
.30083 .59485 m .30802 .59061 L p .30536 .59793 L .707 .577 .707 r
F P
0 g
s
.30038 .60203 m .30083 .59485 L .30536 .59793 L .707 .577 .707 r
F
.29879 .60389 m .29878 .60334 L .29908 .6031 L F
.30083 .59485 m .29908 .6031 L p .29556 .63824 L F P
0 g
s
.29526 .63749 m .29556 .63824 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29952 .60273 m .29904 .6035 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29904 .6035 m .29879 .60389 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29908 .6031 m .29299 .63187 L .29526 .63749 L p .707 .577 .707 r
F P
0 g
s
.29881 .60438 m .30083 .59485 L p .29965 .61357 L .707 .577 .707 r
F P
0 g
s
.29777 .53878 m .3058 .59281 L .29952 .60273 L p .707 .577 .707 r
F P
0 g
s
.29878 .60334 m .29777 .53878 L .29952 .60273 L .707 .577 .707 r
F
.29965 .61357 m .30038 .60203 L .30536 .59793 L F
.29299 .63187 m .29881 .60438 L p .29965 .61357 L F P
0 g
s
.29076 .54986 m .29872 .60339 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.29872 .60339 m .29879 .60389 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .30152 .61284 L p .30132 .61178 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .301 .61255 L p .29773 .62033 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .31415 .62177 L p .31342 .61956 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31336 .61936 L .31331 .61934 L .707 .577 .707 r
F
.31342 .61956 m .31331 .61934 L .30167 .61387 L F
.30152 .61284 m .30167 .61387 L p .31336 .61936 L F P
0 g
s
.31331 .61934 m .31548 .6091 L p .31108 .61811 L .707 .577 .707 r
F P
0 g
s
.31548 .6091 m .31331 .61934 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31383 .61962 L .31336 .61936 L .707 .577 .707 r
F
.314 .62075 m .31383 .61962 L p .31342 .61956 L F P
0 g
s
.31907 .62211 m .31331 .61934 L .314 .62075 L .707 .577 .707 r
F
.31415 .62177 m .314 .62075 L p .31342 .61956 L F P
0 g
s
.31108 .61811 m .31548 .6091 L .30466 .61457 L .707 .577 .707 r
F
.31415 .62177 m .33449 .6267 L p .33411 .62616 L F P
0 g
s
.314 .62075 m .31415 .62177 L p .33411 .62616 L .707 .577 .707 r
F P
0 g
s
.33449 .6267 m .33501 .62683 L p .3096 .59114 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .3548 .66326 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33501 .62683 m .33495 .62639 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .33411 .62616 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .31548 .6091 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .33589 .61772 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.8239 .56104 m .82737 .61813 L .80626 .61622 L p .707 .577 .707 r
F P
0 g
s
.80626 .61622 m .8028 .55913 L .8239 .56104 L p .707 .577 .707 r
F P
0 g
s
.42429 .63972 m .41645 .67674 L .44532 .68039 L p .707 .577 .707 r
F P
0 g
s
.44532 .68039 m .45316 .64337 L .42429 .63972 L p .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .36264 .62624 L .33589 .61772 L p .707 .577 .707 r
F P
0 g
s
.83944 .70551 m .8403 .72445 L .82763 .72013 L p .707 .577 .707 r
F P
0 g
s
.82763 .72013 m .82676 .70119 L .83944 .70551 L p .707 .577 .707 r
F P
0 g
s
.46948 .54959 m .47751 .60361 L .49371 .59252 L p .707 .577 .707 r
F P
0 g
s
.49371 .59252 m .48568 .5385 L .46948 .54959 L p .707 .577 .707 r
F P
0 g
s
.66267 .62658 m .65921 .56949 L .68314 .56527 L p .707 .577 .707 r
F P
0 g
s
.82782 .63662 m .82443 .67065 L .80349 .65793 L p .707 .577 .707 r
F P
0 g
s
.80349 .65793 m .80688 .6239 L .82782 .63662 L p .707 .577 .707 r
F P
0 g
s
.45316 .64337 m .44532 .68039 L .46904 .68142 L p .707 .577 .707 r
F P
0 g
s
.46904 .68142 m .47688 .6444 L .45316 .64337 L p .707 .577 .707 r
F P
0 g
s
.3936 .72747 m .39159 .7093 L .36058 .7102 L p .707 .577 .707 r
F P
0 g
s
.39159 .7093 m .3936 .72747 L .42526 .7234 L p .707 .577 .707 r
F P
0 g
s
.42526 .7234 m .42325 .70522 L .39159 .7093 L p .707 .577 .707 r
F P
0 g
s
.64654 .73101 m .64567 .71207 L .66194 .70677 L p .707 .577 .707 r
F P
0 g
s
.42325 .70522 m .42526 .7234 L .45446 .71655 L p .707 .577 .707 r
F P
0 g
s
.45446 .71655 m .45245 .69837 L .42325 .70522 L p .707 .577 .707 r
F P
0 g
s
.66194 .70677 m .6628 .72571 L .64654 .73101 L p .707 .577 .707 r
F P
0 g
s
.36058 .7102 m .36259 .72838 L .3936 .72747 L p .707 .577 .707 r
F P
0 g
s
.36259 .72838 m .36058 .7102 L .33325 .70785 L p .707 .577 .707 r
F P
0 g
s
.7788 .61571 m .77533 .55862 L .8028 .55913 L p .707 .577 .707 r
F P
0 g
s
.45245 .69837 m .45446 .71655 L .47835 .70759 L p .707 .577 .707 r
F P
0 g
s
.47835 .70759 m .47634 .68942 L .45245 .69837 L p .707 .577 .707 r
F P
0 g
s
.33325 .70785 m .33526 .72602 L .36259 .72838 L p .707 .577 .707 r
F P
0 g
s
.48568 .5385 m .49371 .59252 L .50071 .58144 L p .707 .577 .707 r
F P
0 g
s
.50071 .58144 m .49268 .52742 L .48568 .5385 L p .707 .577 .707 r
F P
0 g
s
.80688 .6239 m .80349 .65793 L .77616 .64824 L p .707 .577 .707 r
F P
0 g
s
.82676 .70119 m .82763 .72013 L .80651 .71707 L p .707 .577 .707 r
F P
0 g
s
.80651 .71707 m .80565 .69813 L .82676 .70119 L p .707 .577 .707 r
F P
0 g
s
.47688 .6444 m .46904 .68142 L .48529 .67973 L p .707 .577 .707 r
F P
0 g
s
.48529 .67973 m .49313 .64271 L .47688 .6444 L p .707 .577 .707 r
F P
0 g
s
.33526 .72602 m .33325 .70785 L .31227 .70246 L p .707 .577 .707 r
F P
0 g
s
.74766 .61665 m .74419 .55956 L .77533 .55862 L p .707 .577 .707 r
F P
0 g
s
.6628 .72571 m .66194 .70677 L .68589 .70218 L p .707 .577 .707 r
F P
0 g
s
.31227 .70246 m .31428 .72064 L .33526 .72602 L p .707 .577 .707 r
F P
0 g
s
.68589 .70218 m .68676 .72113 L .6628 .72571 L p .707 .577 .707 r
F P
0 g
s
.47634 .68942 m .47835 .70759 L .49459 .69741 L p .707 .577 .707 r
F P
0 g
s
.49459 .69741 m .49258 .67924 L .47634 .68942 L p .707 .577 .707 r
F P
0 g
s
.80565 .69813 m .80651 .71707 L .77903 .71558 L p .707 .577 .707 r
F P
0 g
s
.77903 .71558 m .77816 .69664 L .80565 .69813 L p .707 .577 .707 r
F P
0 g
s
.49268 .52742 m .50071 .58144 L .49783 .57146 L p .707 .577 .707 r
F P
0 g
s
.49783 .57146 m .4898 .51743 L .49268 .52742 L p .707 .577 .707 r
F P
0 g
s
.49313 .64271 m .48529 .67973 L .49249 .6755 L p .707 .577 .707 r
F P
0 g
s
.49249 .6755 m .50033 .63848 L .49313 .64271 L p .707 .577 .707 r
F P
0 g
s
.31428 .72064 m .31227 .70246 L .2997 .69457 L p .707 .577 .707 r
F P
0 g
s
.68676 .72113 m .68589 .70218 L .71521 .69877 L p .707 .577 .707 r
F P
0 g
s
.71521 .69877 m .71607 .71772 L .68676 .72113 L p .707 .577 .707 r
F P
0 g
s
.2997 .69457 m .30171 .71275 L .31428 .72064 L p .707 .577 .707 r
F P
0 g
s
.77816 .69664 m .77903 .71558 L .74786 .71581 L p .707 .577 .707 r
F P
0 g
s
.74786 .71581 m .747 .69686 L .77816 .69664 L p .707 .577 .707 r
F P
0 g
s
.49258 .67924 m .49459 .69741 L .50159 .68701 L p .707 .577 .707 r
F P
0 g
s
.50159 .68701 m .49958 .66883 L .49258 .67924 L p .707 .577 .707 r
F P
0 g
s
.71607 .71772 m .71521 .69877 L .747 .69686 L p .707 .577 .707 r
F P
0 g
s
.747 .69686 m .74786 .71581 L .71607 .71772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29879 .60389 m .29076 .54986 L .29777 .53878 L p .707 .577 .707 r
F P
0 g
s
.4898 .51743 m .49783 .57146 L .48535 .56355 L p .707 .577 .707 r
F P
0 g
s
.48535 .56355 m .47732 .50953 L .4898 .51743 L p .707 .577 .707 r
F P
0 g
s
.30171 .71275 m .2997 .69457 L .29677 .68495 L p .707 .577 .707 r
F P
0 g
s
.50033 .63848 m .49249 .6755 L .48992 .66913 L p .707 .577 .707 r
F P
0 g
s
.48992 .66913 m .49776 .63211 L .50033 .63848 L p .707 .577 .707 r
F P
0 g
s
.29677 .68495 m .29878 .70313 L .30171 .71275 L p .707 .577 .707 r
F P
0 g
s
.49958 .66883 m .50159 .68701 L .49866 .67739 L p .707 .577 .707 r
F P
0 g
s
.49866 .67739 m .49665 .65921 L .49958 .66883 L p .707 .577 .707 r
F P
0 g
s
.31396 .52769 m .31882 .56037 L p .3058 .59281 L .707 .577 .707 r
F P
0 g
s
.30018 .62763 m .30802 .59061 L .32428 .58893 L p .707 .577 .707 r
F P
0 g
s
.31882 .56037 m .32199 .58171 L .30848 .59097 L p .707 .577 .707 r
F P
0 g
s
.30802 .59061 m .30705 .59519 L p .29299 .63187 L .707 .577 .707 r
F P
0 g
s
.30848 .59097 m .3058 .59281 L p .31882 .56037 L .707 .577 .707 r
F P
0 g
s
.30705 .59519 m .30018 .62763 L .29507 .63064 L p .707 .577 .707 r
F P
0 g
s
.29507 .63064 m .29299 .63187 L p .30705 .59519 L .707 .577 .707 r
F P
0 g
s
.3058 .59281 m .29777 .53878 L .31396 .52769 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47732 .50953 m .48535 .56355 L .46449 .5585 L p .707 .577 .707 r
F P
0 g
s
.46449 .5585 m .45646 .50447 L .47732 .50953 L p .707 .577 .707 r
F P
0 g
s
.29878 .70313 m .29677 .68495 L .30377 .67455 L p .707 .577 .707 r
F P
0 g
s
.49776 .63211 m .48992 .66913 L .47784 .66124 L p .707 .577 .707 r
F P
0 g
s
.47784 .66124 m .48567 .62423 L .49776 .63211 L p .707 .577 .707 r
F P
0 g
s
.30377 .67455 m .30578 .69272 L .29878 .70313 L p .707 .577 .707 r
F P
0 g
s
.49665 .65921 m .49866 .67739 L .48609 .6695 L p .707 .577 .707 r
F P
0 g
s
.48609 .6695 m .48408 .65132 L .49665 .65921 L p .707 .577 .707 r
F P
0 g
s
.32199 .58171 m .31396 .52769 L .33778 .51767 L p .707 .577 .707 r
F P
0 g
s
.32428 .58893 m .31644 .62595 L .30018 .62763 L p .707 .577 .707 r
F P
0 g
s
.45646 .50447 m .46449 .5585 L .43729 .55679 L p .707 .577 .707 r
F P
0 g
s
.43729 .55679 m .42926 .50276 L .45646 .50447 L p .707 .577 .707 r
F P
0 g
s
.30578 .69272 m .30377 .67455 L .32001 .66437 L p .707 .577 .707 r
F P
0 g
s
.48567 .62423 m .47784 .66124 L .45742 .65262 L p .707 .577 .707 r
F P
0 g
s
.45742 .65262 m .46526 .6156 L .48567 .62423 L p .707 .577 .707 r
F P
0 g
s
.33778 .51767 m .34581 .57169 L .32199 .58171 L p .707 .577 .707 r
F P
0 g
s
.34581 .57169 m .33778 .51767 L .36687 .5097 L p .707 .577 .707 r
F P
0 g
s
.32001 .66437 m .32202 .68254 L .30578 .69272 L p .707 .577 .707 r
F P
0 g
s
.31644 .62595 m .32428 .58893 L .348 .58996 L p .707 .577 .707 r
F P
0 g
s
.42926 .50276 m .43729 .55679 L .40642 .55859 L p .707 .577 .707 r
F P
0 g
s
.40642 .55859 m .39839 .50456 L .42926 .50276 L p .707 .577 .707 r
F P
0 g
s
.48408 .65132 m .48609 .6695 L .46511 .66411 L p .707 .577 .707 r
F P
0 g
s
.46511 .66411 m .4631 .64594 L .48408 .65132 L p .707 .577 .707 r
F P
0 g
s
.348 .58996 m .34016 .62698 L .31644 .62595 L p .707 .577 .707 r
F P
0 g
s
.3749 .56372 m .36687 .5097 L .39839 .50456 L p .707 .577 .707 r
F P
0 g
s
.36687 .5097 m .3749 .56372 L .34581 .57169 L p .707 .577 .707 r
F P
0 g
s
.39839 .50456 m .40642 .55859 L .3749 .56372 L p .707 .577 .707 r
F P
0 g
s
.46526 .6156 m .45742 .65262 L .43068 .6441 L p .707 .577 .707 r
F P
0 g
s
.43068 .6441 m .43852 .60708 L .46526 .6156 L p .707 .577 .707 r
F P
0 g
s
.32202 .68254 m .32001 .66437 L .3439 .65541 L p .707 .577 .707 r
F P
0 g
s
.34016 .62698 m .348 .58996 L .37687 .5936 L p .707 .577 .707 r
F P
0 g
s
.3439 .65541 m .34591 .67359 L .32202 .68254 L p .707 .577 .707 r
F P
0 g
s
.4631 .64594 m .46511 .66411 L .43778 .66176 L p .707 .577 .707 r
F P
0 g
s
.43778 .66176 m .43577 .64358 L .4631 .64594 L p .707 .577 .707 r
F P
0 g
s
.37687 .5936 m .36903 .63062 L .34016 .62698 L p .707 .577 .707 r
F P
0 g
s
.43852 .60708 m .43068 .6441 L .40022 .63652 L p .707 .577 .707 r
F P
0 g
s
.40022 .63652 m .40806 .5995 L .43852 .60708 L p .707 .577 .707 r
F P
0 g
s
.36903 .63062 m .37687 .5936 L .40806 .5995 L p .707 .577 .707 r
F P
0 g
s
.34591 .67359 m .3439 .65541 L .3731 .64856 L p .707 .577 .707 r
F P
0 g
s
.40806 .5995 m .40022 .63652 L .36903 .63062 L p .707 .577 .707 r
F P
0 g
s
.43577 .64358 m .43778 .66176 L .40677 .66266 L p .707 .577 .707 r
F P
0 g
s
.40677 .66266 m .40476 .64449 L .43577 .64358 L p .707 .577 .707 r
F P
0 g
s
.3731 .64856 m .37511 .66674 L .34591 .67359 L p .707 .577 .707 r
F P
0 g
s
.37511 .66674 m .3731 .64856 L .40476 .64449 L p .707 .577 .707 r
F P
0 g
s
.40476 .64449 m .40677 .66266 L .37511 .66674 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEQL000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005moo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005eoo`800003
FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001GOol30007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20002FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool20004FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH015YF5@000eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000087oo2000?Goo001BOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH0
0eYF0`001EYF0`0000=JEP00FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000mooa4000AJEP04001JEUYFFUH<000aOol005=oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH0000000<000AJEP03001JEP0000<00003
FUH005YF00IJEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00001goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH010001EYF2`001EYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP8000EJEPD00003FUH005YF00X000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YF00001EYF00@005YFFUIJEPX000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH0
0005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP000eYF00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo0010Ool8000;Ool01@00FUIJEP00FUH03`00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool003Yoo`H000=JEP03001JEUYF009JEPT000=oo`04001JEP000004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH600000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0006FUH20005FUH01000FUH00000;Woo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000030006
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP8000EJEP04001JEUYF000^Ool003Aoo`8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00EJEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF0P001EYF0P00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF0P001EYF00<005YFFUH00P00;Goo000bOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH00eYF0P00
25YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH2
0005FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH20005FUH00`00FUIJEP02000]
Ool0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@0009JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_Ool0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUH0000200000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUHJ00000eYF0000000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH30005FUH01000FUIJEUYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00003P0015YF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF0P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0035oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02moo`00;Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH00UYF200015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3P001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00<7oo000]Ool20004FUH0
0`00FUIJEP03FUH60008Ool90004FUH01000FUIJEP001EYF00<005YFFUH00UYF00@005YFFUH000QJ
EQL000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUHG0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH2000`Ool002eoo`8000AJEP03001JEP0000<001Moo`H0009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000<000=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EP0000<001Qoo`D000IJEP03001JEUYF00AJEP03001JEP0002moo`00;7oo00<005YF000015YF0P00
4goo0`002goo1P0000=JEP00FUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF0P008Goo0P0015YF00<005YFFUH015YF00@005YFFUH002io
o`00;7oo00<005YF00000UYF0P000UYF0P0047oo1@003Woo1@0000=JEP0000000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF10008goo0`0000=JEP00FUH0
15YF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P0000=JEP00FUH00eYF0`003Goo1@0047oo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF100015YF10008Woo0P001EYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YF00000`002Goo1@003Woo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF
5`0015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYFFUH005YF0P001eYF00<005YF00000P008Goo0P000eYF00@005YFFUIJEP8002eoo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH00eYF10001Woo0`003Woo0P001eYF00<005YFFUH015YF1P00
25YF00<005YFFUH01EYF00<005YFFUH015YF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP02FUH2000;
Ool3000COol200000eYF001JEP02FUH2000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@0011oo`<00003FUH005YF00IJEP03001JEUYF00@0009JEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30008Ool5
000DOol20002FUH00`00FUH0000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00AJEQ4000=JEP03001JEUYF00AJEPD00003FUH005YF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEPD00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00D005YFFUIJEP0000IJEP04001JEUYF0007
Ool5000FOol01@00FUH005YF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP0?FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000=JEP800003FUH005YF00EJEP03
001JEUYF00=JEPH000AJEP03001JEUYF00AJEP08001JEUYFFUH005YF001JEP800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH300000eYF001JEP05FUH01000
FUIJEP001goo1@005Woo00D005YF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH03eYF00@005YFFUIJEP8000AJEP06001JEP00001JEP000eYF0P0000=JEP00
FUH01EYF10001EYF00<005YFFUH04@0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00P001EYF00@005YFFUIJEP8000Moo`<001Qoo`80
0003FUH007oo02aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP06
001JEUYF001JEP000eYF0`000eYF00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF
00UJEP03001JEUYF00AJEP<00004FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP80025oo`@002ioo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP07001JEUYF001JEP00FUH00P001UYF
00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00UJEP03001JEUYF009JEP80009J
EP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUH0000OOol20002FUH2000^Ool002io
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH01@00FUIJEP00FUH00P0000=JEP00
FUH015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH02EYF00<005YFFUH0
0P0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000IJEP04001JEUYFFUH400000eYF001oo`0LOol20004FUH2000^Ool002moo`03
001JEP0000EJEP03001JEUYF00AJEP80015JEP03001JEUYF008000=JEP03001JEUYF00=JEP03001J
EUYF009JEP800003FUH005YF00EJEP@000EJEP03001JEUYF00QJEP@00003FUH005YF00=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EUYF00AJEP03001JEUYF00AJEP<001Yoo`<00003FUH005YF00=JEP8002ioo`00<7oo0P001EYF00<0
05YFFUH015YF0P0045YF5P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001EYF
00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00006FUH00`00FUIJEP04FUHP00000eYF001JEP02FUH00`00FUH0000^Ool0
035oo`03001JEUYF00=JEP03001JEUYF00AJEP8000MJEPT000AJEP80009JEP80009JEP03001JEUYF
009JEP07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003FUH005YF00EJ
EP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00005FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP0600000eYF001oo`0]Ool0039oo`8000=JEP03001JEUYF00AJEPT000AJEP03001J
EUYF00IJEP80009JEP03001JEP00008000AJEP07001JEUYFFUH005YF00001UYF00<005YFFUH00eYF
1`001EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000P0000=JEP0000000`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000dOol2
00000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUHG
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo1@000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHH0003FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP8000MJEP03001JEUYF00AJEP@0009JEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUIJEP8000MJEP8000EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP04001JEUYFFUH80007FUH60003FUH20007FUH00`00FUIJEP04FUH20002FUH4
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00MJEP8000IJEP03001JEP0000@000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEPH000=JEP<00003FUH005YF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP80
00AJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPP000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPX0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00008000=JEPL0009JEP<000IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EP0000<00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF00001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF2@00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF1@0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF4`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00eYF40001EYF00<005YFFUH015YF00<005YFFUH00P00;goo000]Ool00`00FUH00003FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF10001EYF00<0
05YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH0035oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPP0009oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
=goo000]Ool01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP00008000Aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000D000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT003moo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFOol01EYF00<005YFFUH0
0UYF0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo6000B7oo
000]Ool20004FUH01000FUIJEUYF5P000goo1P001UYF00<005YFFUH00eYF0P0000Aoo`00FUH000IJ
EP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPH000IJEP03
001JEUYF009JEP03001JEP0000Moo`8000AJEP04001JEP00001DOol002eoo`8000AJEPT001Yoo`@0
009JEP03001JEUYF00=JEP800004Ool005YF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00
FUH00005Ool200000eYF001JEP03FUH01000FUIJEP00E7oo000/Ool00`00FUH00002FUH2000WOol4
0004FUH01P00FUH00000FUH000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000=oo`8000=JEP03001JEUYF
009JEP04001JEUYF001DOol002aoo`03001JEP00008002eoo`<00008FUH005YFFUH005YF001JEP<0
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUH000030006FUH01@00FUIJEUYF00000UYF00<007ooOol0
DWoo000/Ool00`00FUH0000bOol20002FUH01000FUH000000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000AJEP00FUH000MJEP03001JEUYF009JEP03001JEP0005Aoo`00;7oo0P006Woo0`0067oo
00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800004FUH005YF0007FUH00`00FUIJ
EP02FUH2001EOol002aoo`8001Uoo`D001Moo`04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00UYF00<007ooOol0E7oo000/Ool3000HOol5
000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF
00D005YFFUIJEP0005Moo`00;7oo0P0000=JEP0000005Woo1@006Goo0P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00EJEP03001JEP0005Qoo`00;7oo0P000eYF
00<007ooOol057oo0`006Goo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00EJEP8005Uoo`00;Goo00@005YFFUIJEP<002moo`800003FUH005YF00=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00EJEP03001oogoo05Qoo`00;Goo
00D005YFFUIJEP00009JEP8002]oo`800004FUH005YF0004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF000000020005FUH2001KOol002ioo`04001JEUYF0004FUH3000VOol20003FUH20000
0goo00000002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005FUH5001MOol002moo`<000EJEP03
001JEP0000<001ioo`@00003FUH005YF009JEP8000=oo`<000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00
FUIJEP05FUH00`00FUH00002001KOol0035oo`03001JEUYF00=JEP03001JEUYF00=JEPH0019oo`H0
00EJEP05001JEUYFFUH00006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00FGoo000bOol20003FUH00`00FUIJEP05FUH01000FUIJEUYF4P0015YF00<005YFFUH00eYF
00<005YFFUH00P002Goo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF10000UYF1P001EYF00<005YFFUH015YF0`00Egoo000dOol20000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
000>Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP060004FUH500000goo0000000200000eYF001JEP05FUH00`00FUIJEP02001EOol003Ioo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEPP000Yoo`<000AJEP03
001JEUYF009JEP03001oogoo05=oo`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P0077oo2`001UYF00<005YFFUH02UYF00@005YFFUIJEPH000AJEPP0011o
o`<00003FUH005YF00=JEP03001oogoo05=oo`00?Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P00:Woo8@000goo1@004goo0P000eYF0P00EGoo0013OolB000jOol200000eYF001JEP04FUH0
0`00FUIJEP04FUH60005Ool3000FOol200000eYF0000001EOol0095oo`<000AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT0011oo`H00004FUH00000001EOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ0000=JEP04001JEUYFFUH3001EOol009Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EGoo
002JOol400000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2001FOol009ioo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00<005Moo`00Y7oo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005Yoo`00[Goo
4000H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59194 .73798 m .60486 .68261 L .57449 .6745 L p .707 .577 .707 r
F P
0 g
s
.60486 .68261 m .59194 .73798 L .62297 .74451 L p .707 .577 .707 r
F P
0 g
s
.62297 .74451 m .63589 .68913 L .60486 .68261 L p .707 .577 .707 r
F P
0 g
s
.63589 .68913 m .62297 .74451 L .65162 .74881 L p .707 .577 .707 r
F P
0 g
s
.65162 .74881 m .66454 .69343 L .63589 .68913 L p .707 .577 .707 r
F P
0 g
s
.56156 .72987 m .57449 .6745 L .54774 .66559 L p .707 .577 .707 r
F P
0 g
s
.57449 .6745 m .56156 .72987 L .59194 .73798 L p .707 .577 .707 r
F P
0 g
s
.54774 .66559 m .53482 .72097 L .56156 .72987 L p .707 .577 .707 r
F P
0 g
s
.66454 .69343 m .65162 .74881 L .67508 .75046 L p .707 .577 .707 r
F P
0 g
s
.67508 .75046 m .688 .69508 L .66454 .69343 L p .707 .577 .707 r
F P
0 g
s
.53482 .72097 m .54774 .66559 L .52724 .65677 L p .707 .577 .707 r
F P
0 g
s
.6319 .81338 m .61939 .78005 L .58924 .79049 L p .707 .577 .707 r
F P
0 g
s
.61939 .78005 m .6319 .81338 L .65989 .79973 L p .707 .577 .707 r
F P
0 g
s
.65989 .79973 m .64738 .76639 L .61939 .78005 L p .707 .577 .707 r
F P
0 g
s
.60175 .82382 m .58924 .79049 L .55989 .79669 L p .707 .577 .707 r
F P
0 g
s
.58924 .79049 m .60175 .82382 L .6319 .81338 L p .707 .577 .707 r
F P
0 g
s
.64738 .76639 m .65989 .79973 L .68298 .7842 L p .707 .577 .707 r
F P
0 g
s
.68298 .7842 m .67047 .75086 L .64738 .76639 L p .707 .577 .707 r
F P
0 g
s
.52724 .65677 m .51432 .71215 L .53482 .72097 L p .707 .577 .707 r
F P
0 g
s
.59139 .84379 m .59368 .83066 L p .56389 .81866 L .707 .577 .707 r
F P
0 g
s
.5853 .82322 m .56389 .81866 L p .59368 .83066 L .707 .577 .707 r
F P
0 g
s
.56389 .81866 m .56065 .83725 L .59139 .84379 L p .707 .577 .707 r
F P
0 g
s
.56065 .83725 m .56237 .82737 L p .5368 .8109 L .707 .577 .707 r
F P
0 g
s
.56237 .82737 m .56389 .81866 L .54945 .81453 L p .707 .577 .707 r
F P
0 g
s
.54945 .81453 m .5368 .8109 L p .56237 .82737 L .707 .577 .707 r
F P
0 g
s
.5368 .8109 m .53356 .82948 L .56065 .83725 L p .707 .577 .707 r
F P
0 g
s
.53356 .82948 m .5368 .8109 L .51601 .80267 L p .707 .577 .707 r
F P
0 g
s
.54672 .83139 m .53498 .80014 L p .5147 .79444 L .707 .577 .707 r
F P
0 g
s
.53498 .80014 m .5342 .79806 L .53258 .79776 L p .707 .577 .707 r
F P
0 g
s
.53258 .79776 m .5147 .79444 L p .53498 .80014 L .707 .577 .707 r
F P
0 g
s
.5724 .83003 m .56213 .80267 L p .5342 .79806 L .707 .577 .707 r
F P
0 g
s
.56213 .80267 m .55989 .79669 L .55564 .79692 L p .707 .577 .707 r
F P
0 g
s
.55564 .79692 m .5342 .79806 L p .56213 .80267 L .707 .577 .707 r
F P
0 g
s
.59368 .83066 m .59463 .82521 L .5853 .82322 L p .707 .577 .707 r
F P
0 g
s
.59463 .82521 m .59139 .84379 L .62276 .84847 L p .707 .577 .707 r
F P
0 g
s
.62276 .84847 m .62601 .82989 L .59463 .82521 L p .707 .577 .707 r
F P
0 g
s
.55989 .79669 m .5724 .83003 L .60175 .82382 L p .707 .577 .707 r
F P
0 g
s
.62601 .82989 m .62276 .84847 L .65171 .85083 L p .707 .577 .707 r
F P
0 g
s
.65171 .85083 m .65495 .83224 L .62601 .82989 L p .707 .577 .707 r
F P
0 g
s
.688 .69508 m .67508 .75046 L .68325 .74987 L p .707 .577 .707 r
F P
0 g
s
.69082 .74507 m .688 .69508 L .68406 .74058 L .707 .577 .707 r
F
.69031 .74539 m .68406 .74058 L .68325 .74987 L F
.69082 .74507 m .68406 .74058 L .69031 .74539 L F
.69892 .76832 m .70474 .75648 L p .69172 .74647 L F P
0 g
s
.69031 .74539 m .69105 .74735 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69105 .74735 m .69892 .76832 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69898 .7369 m .69915 .7355 L .69172 .74647 L .707 .577 .707 r
F
.70398 .69393 m .69553 .73015 L p .69915 .7355 L F P
0 g
s
.69553 .73015 m .69172 .74647 L p .69915 .7355 L .707 .577 .707 r
F P
0 g
s
.69892 .76832 m .69031 .74539 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69106 .74931 m .70398 .69393 L .688 .69508 L p .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .70419 .74296 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .70016 .7377 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.70016 .7377 m .70614 .75363 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69362 .72029 m .68641 .73498 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .69957 .73613 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.69985 .73576 m .69943 .73309 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .69362 .72029 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69985 .73576 L p .69799 .74546 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .69985 .73576 L .69898 .7369 L .707 .577 .707 r
F
.70071 .72202 m .71091 .69009 L .70398 .69393 L p F P
0 g
s
.69362 .72029 m .69681 .72877 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69681 .72877 m .69957 .73613 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69868 .72838 m .69947 .72593 L .70001 .73679 L .707 .577 .707 r
F
.70358 .72151 m .70001 .73679 L p .69947 .72593 L F P
0 g
s
.70812 .68392 m .71091 .69009 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.69999 .73666 m .69742 .72812 L .69957 .73613 L .707 .577 .707 r
F
.69924 .73188 m .69742 .72812 L .69999 .73666 L F
.6983 .72599 m .70812 .68392 L p .69868 .72838 L F P
0 g
s
.69142 .70824 m .69362 .72029 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .699 .72843 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .69142 .70824 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.69142 .70824 m .69846 .72701 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.6952 .7393 m .68295 .73142 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69457 .7249 L .6952 .7393 L .707 .577 .707 r
F
.69206 .7229 m .69142 .70824 L .69793 .72758 L F
.69793 .72758 m .6952 .7393 L p .69457 .7249 L F P
0 g
s
.69255 .73336 m .69252 .73334 L p .69846 .72701 L .707 .577 .707 r
F P
0 g
s
.6983 .72599 m .69793 .72758 L p .69394 .71068 L .707 .577 .707 r
F P
0 g
s
.69394 .71068 m .69793 .72758 L .69457 .7249 L .707 .577 .707 r
F
.6952 .7393 m .6983 .72599 L p .69868 .72838 L F P
0 g
s
.70394 .74158 m .69924 .73188 L .69999 .73666 L .707 .577 .707 r
F
.68325 .74987 m .69106 .74931 L p .69086 .74581 L F P
0 g
s
.69086 .74581 m .69082 .74507 L .69031 .74539 L .707 .577 .707 r
F
.69086 .74581 m .69031 .74539 L .68325 .74987 L F
.68641 .73498 m .69031 .74539 L p .69191 .74622 L F P
0 g
s
.70614 .75363 m .69458 .7427 L .69191 .74622 L .707 .577 .707 r
F
.69458 .7427 m .68641 .73498 L .69191 .74622 L F
.70474 .75648 m .70614 .75363 L p .69031 .74539 L F P
0 g
s
.69106 .74931 m .69799 .74546 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69172 .74647 m .69106 .74931 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .6952 .7393 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70419 .74296 m .70394 .74158 L p .69957 .73613 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69799 .74546 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .69255 .73336 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69846 .72701 m .699 .72843 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .70394 .74158 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .69206 .7229 L .69793 .72758 L .707 .577 .707 r
F
.68001 .7 m .69142 .70824 L p .69206 .7229 L F P
0 g
s
.68295 .73142 m .68569 .71969 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68001 .7 m .68713 .71897 L p .68569 .71969 L .707 .577 .707 r
F P
0 g
s
.68295 .73142 m .66246 .7226 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68295 .73142 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.67401 .72551 m .67619 .71625 L .68569 .71969 L .707 .577 .707 r
F
.67619 .71625 m .68001 .7 L .68569 .71969 L F
.68713 .71897 m .68001 .7 L p .69206 .7229 L F P
0 g
s
.6605 .69639 m .68001 .7 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .66449 .71388 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.6605 .69639 m .66667 .71281 L p .66449 .71388 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .63571 .7137 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66246 .7226 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.65143 .72031 m .65458 .71201 L .66449 .71388 L .707 .577 .707 r
F
.65458 .71201 m .6605 .69639 L .66449 .71388 L F
.66667 .71281 m .6605 .69639 L p .67619 .71625 L F P
0 g
s
.63482 .69776 m .6605 .69639 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.63571 .7137 m .63639 .71079 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63482 .69776 m .63907 .70908 L p .63639 .71079 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63571 .7137 L .61845 .70909 L p .707 .577 .707 r
F P
0 g
s
.62661 .71703 m .62954 .71014 L .63639 .71079 L .707 .577 .707 r
F
.62954 .71014 m .63482 .69776 L .63639 .71079 L F
.63907 .70908 m .63482 .69776 L p .65458 .71201 L F P
0 g
s
.60547 .70396 m .63482 .69776 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .60825 .71137 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.60825 .71137 m .60547 .70396 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .58783 .74774 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60547 .70396 m .60698 .708 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60698 .708 m .61798 .7373 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .64681 .66611 L p .60534 .70559 L .707 .577 .707 r
F P
0 g
s
.64681 .66611 m .63639 .71079 L p .60873 .70616 L .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .64681 .66611 L .60873 .70616 L .707 .577 .707 r
F
.58783 .74774 m .57532 .7144 L .60547 .70396 L p F P
0 g
s
.61826 .65021 m .60534 .70559 L .60204 .7049 L p .707 .577 .707 r
F P
0 g
s
.60204 .7049 m .57431 .69906 L p .58503 .68714 L .707 .577 .707 r
F P
0 g
s
.58503 .68714 m .61826 .65021 L .60204 .7049 L .707 .577 .707 r
F
.61845 .70909 m .60534 .70559 L p .63639 .71079 L F P
0 g
s
.63639 .71079 m .63688 .70867 L p .63907 .70908 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63907 .70908 L .63957 .70918 L .707 .577 .707 r
F
.64733 .7311 m .61798 .7373 L p .62661 .71703 L F P
0 g
s
.63907 .70908 m .64733 .7311 L p .62661 .71703 L .707 .577 .707 r
F P
0 g
s
.64733 .7311 m .63907 .70908 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .67538 .66722 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63688 .70867 m .64863 .65832 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .66449 .71388 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66489 .71217 L p .66667 .71281 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66667 .71281 L .6689 .71362 L .707 .577 .707 r
F
.67302 .72973 m .64733 .7311 L p .65143 .72031 L F P
0 g
s
.66667 .71281 m .67302 .72973 L p .65143 .72031 L .707 .577 .707 r
F P
0 g
s
.67302 .72973 m .66667 .71281 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .69588 .67604 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.66489 .71217 m .67538 .66722 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .68569 .71969 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68606 .71812 L p .68713 .71897 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68713 .71897 L .68883 .72033 L .707 .577 .707 r
F
.69252 .73334 m .67302 .72973 L p .67401 .72551 L F P
0 g
s
.68713 .71897 m .69252 .73334 L p .67401 .72551 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .68713 .71897 L p .69206 .7229 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .70812 .68392 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68606 .71812 m .69588 .67604 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69394 .71068 L .69457 .7249 L .707 .577 .707 r
F
.70812 .68392 m .6983 .72599 L p .69394 .71068 L F P
0 g
s
.71091 .69009 m .70358 .72151 L p .69947 .72593 L .707 .577 .707 r
F P
0 g
s
.68641 .73498 m .67047 .75086 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69031 .74539 m .68641 .73498 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.51432 .71215 m .52724 .65677 L .515 .64889 L p .707 .577 .707 r
F P
0 g
s
.67047 .75086 m .68298 .7842 L .69892 .76832 L p .707 .577 .707 r
F P
0 g
s
.5342 .79806 m .54672 .83139 L .5724 .83003 L p .707 .577 .707 r
F P
0 g
s
.65495 .83224 m .65171 .85083 L .67538 .85063 L p .707 .577 .707 r
F P
0 g
s
.67538 .85063 m .67862 .83205 L .65495 .83224 L p .707 .577 .707 r
F P
0 g
s
.515 .64889 m .50208 .70427 L .51432 .71215 L p .707 .577 .707 r
F P
0 g
s
.51601 .80267 m .51277 .82125 L .53356 .82948 L p .707 .577 .707 r
F P
0 g
s
.5147 .79444 m .52721 .82778 L .54672 .83139 L p .707 .577 .707 r
F P
0 g
s
.50208 .70427 m .515 .64889 L .51221 .64273 L p .707 .577 .707 r
F P
0 g
s
.67862 .83205 m .67538 .85063 L .69147 .84791 L p .707 .577 .707 r
F P
0 g
s
.69147 .84791 m .69472 .82932 L .67862 .83205 L p .707 .577 .707 r
F P
0 g
s
.51277 .82125 m .51601 .80267 L .50356 .79478 L p .707 .577 .707 r
F P
0 g
s
.52721 .82778 m .5147 .79444 L .50328 .78621 L p .707 .577 .707 r
F P
0 g
s
.51221 .64273 m .49929 .69811 L .50208 .70427 L p .707 .577 .707 r
F P
0 g
s
.50356 .79478 m .50031 .81337 L .51277 .82125 L p .707 .577 .707 r
F P
0 g
s
.50328 .78621 m .5158 .81955 L .52721 .82778 L p .707 .577 .707 r
F P
0 g
s
.49323 .82188 m .49323 .31999 L .44904 .31754 L p .707 .577 .707 r
F P
0 g
s
.49929 .69811 m .51221 .64273 L .51914 .63888 L p .707 .577 .707 r
F P
0 g
s
.50031 .81337 m .50356 .79478 L .50065 .78801 L p .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50328 .78621 L .50162 .7771 L p .707 .577 .707 r
F P
0 g
s
.50162 .7771 m .50108 .77416 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50162 .7771 L .50245 .77838 L .707 .577 .707 r
F
.50065 .78801 m .49741 .8066 L .50031 .81337 L p F P
0 g
s
.5136 .8075 m .5158 .81955 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50108 .77416 m .50296 .77918 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50296 .77918 m .5136 .8075 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5136 .8075 m .50108 .77416 L .5083 .75947 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .49741 .8066 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50759 .78302 m .50713 .78562 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50713 .78562 m .50434 .8016 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50065 .78801 L .50613 .78407 L p .707 .577 .707 r
F P
0 g
s
.50613 .78407 m .50759 .78302 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50613 .78407 L .50673 .785 L .707 .577 .707 r
F
.51914 .63888 m .50622 .69426 L .49929 .69811 L p F P
0 g
s
.50622 .69426 m .51914 .63888 L .53512 .63773 L p .707 .577 .707 r
F P
0 g
s
.53512 .63773 m .5222 .69311 L .50622 .69426 L p .707 .577 .707 r
F P
0 g
s
.5083 .75947 m .52081 .79281 L .5136 .8075 L p .707 .577 .707 r
F P
0 g
s
.5222 .69311 m .53512 .63773 L .55858 .63939 L p .707 .577 .707 r
F P
0 g
s
.52081 .79281 m .5083 .75947 L .52423 .74359 L p .707 .577 .707 r
F P
0 g
s
.52423 .74359 m .53675 .77693 L .52081 .79281 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .50759 .78302 L .52368 .78029 L p .707 .577 .707 r
F P
0 g
s
.55858 .63939 m .54566 .69476 L .5222 .69311 L p .707 .577 .707 r
F P
0 g
s
.52368 .78029 m .52044 .79887 L .50434 .8016 L p .707 .577 .707 r
F P
0 g
s
.53675 .77693 m .52423 .74359 L .54733 .72806 L p .707 .577 .707 r
F P
0 g
s
.52044 .79887 m .52368 .78029 L .54735 .78009 L p .707 .577 .707 r
F P
0 g
s
.54735 .78009 m .54411 .79868 L .52044 .79887 L p .707 .577 .707 r
F P
0 g
s
.49323 .31999 m .49323 .82188 L .53809 .82055 L p .707 .577 .707 r
F P
0 g
s
.54733 .72806 m .55984 .7614 L .53675 .77693 L p .707 .577 .707 r
F P
0 g
s
.53809 .82055 m .53809 .31866 L .49323 .31999 L p .707 .577 .707 r
F P
0 g
s
.69472 .82932 m .69147 .84791 L .69841 .84291 L p .707 .577 .707 r
F P
0 g
s
.69841 .84291 m .70165 .82433 L .69472 .82932 L p .707 .577 .707 r
F P
0 g
s
.54566 .69476 m .55858 .63939 L .58723 .64369 L p .707 .577 .707 r
F P
0 g
s
.58723 .64369 m .57431 .69906 L .54566 .69476 L p .707 .577 .707 r
F P
0 g
s
.55984 .7614 m .54733 .72806 L .57532 .7144 L p .707 .577 .707 r
F P
0 g
s
.57532 .7144 m .58783 .74774 L .55984 .7614 L p .707 .577 .707 r
F P
0 g
s
.54411 .79868 m .54735 .78009 L .5763 .78245 L p .707 .577 .707 r
F P
0 g
s
.5763 .78245 m .57305 .80104 L .54411 .79868 L p .707 .577 .707 r
F P
0 g
s
.57305 .80104 m .5763 .78245 L .60767 .78713 L p .707 .577 .707 r
F P
0 g
s
.60767 .78713 m .60443 .80572 L .57305 .80104 L p .707 .577 .707 r
F P
0 g
s
.53809 .31866 m .53809 .82055 L .57922 .81556 L p .707 .577 .707 r
F P
0 g
s
.57431 .69906 m .58723 .64369 L .61826 .65021 L p .707 .577 .707 r
F P
0 g
s
.57922 .81556 m .57922 .31368 L .53809 .31866 L p .707 .577 .707 r
F P
0 g
s
.44904 .81943 m .44904 .31754 L .40983 .31154 L p .707 .577 .707 r
F P
0 g
s
.44904 .31754 m .44904 .81943 L .49323 .82188 L p .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .61826 .65021 L .64863 .65832 L p .707 .577 .707 r
F P
0 g
s
.63841 .79367 m .63517 .81226 L .60443 .80572 L p .707 .577 .707 r
F P
0 g
s
.60443 .80572 m .60767 .78713 L .63841 .79367 L p .707 .577 .707 r
F P
0 g
s
.57922 .31368 m .57922 .81556 L .61259 .80741 L p .707 .577 .707 r
F P
0 g
s
.61259 .80741 m .61259 .30552 L .57922 .31368 L p .707 .577 .707 r
F P
0 g
s
.40983 .81343 m .40983 .31154 L .37945 .30259 L p .707 .577 .707 r
F P
0 g
s
.40983 .31154 m .40983 .81343 L .44904 .81943 L p .707 .577 .707 r
F P
0 g
s
.25765 .68094 m .22657 .675 L p .2463 .71874 L .707 .577 .707 r
F P
0 g
s
.24811 .72276 m .24871 .72012 L .2463 .71874 L .707 .577 .707 r
F
.24871 .72012 m .25765 .68094 L .2463 .71874 L F
.25297 .72295 m .25765 .68094 L p .24811 .72276 L F P
0 g
s
.28785 .7367 m .27163 .72196 L .25372 .72298 L .707 .577 .707 r
F
.25372 .72298 m .25634 .74107 L .27967 .73783 L p F P
0 g
s
.27967 .73783 m .28785 .7367 L p .25372 .72298 L .707 .577 .707 r
F P
0 g
s
.25634 .74107 m .25372 .72298 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.24284 .72879 m .25297 .72295 L .23567 .72226 L .707 .577 .707 r
F
.25634 .74107 m .25297 .72295 L .24284 .72879 L F
.25366 .72256 m .25372 .72298 L p .27163 .72196 L F P
0 g
s
.25301 .72258 m .25297 .72295 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .25634 .74107 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .22549 .74597 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22657 .675 m .19913 .66493 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .22205 .72225 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22197 .72171 L p .22132 .72216 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22132 .72216 L .20984 .73015 L .707 .577 .707 r
F
.19913 .66493 m .1935 .71543 L .20683 .72031 L p F P
0 g
s
.20984 .73015 m .21392 .72122 L .19914 .71933 L .707 .577 .707 r
F
.21967 .72195 m .19913 .66493 L .20683 .72031 L F
.22132 .72216 m .22657 .675 L p .21967 .72195 L F P
0 g
s
.22657 .675 m .22137 .72169 L p .22197 .72171 L .707 .577 .707 r
F P
0 g
s
.22137 .72169 m .22095 .72549 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .21997 .70797 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.20683 .72031 m .22095 .72549 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22095 .72549 m .22132 .72216 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.1935 .71543 m .19913 .66493 L .178 .65173 L p .707 .577 .707 r
F P
0 g
s
.178 .65173 m .17398 .6878 L p .1935 .71543 L .707 .577 .707 r
F P
0 g
s
.17398 .6878 m .17237 .70222 L .18972 .71306 L p .707 .577 .707 r
F P
0 g
s
.18972 .71306 m .1935 .71543 L p .17398 .6878 L .707 .577 .707 r
F P
0 g
s
.19278 .7129 m .19374 .71952 L p .22549 .74597 L .707 .577 .707 r
F P
0 g
s
.19374 .71952 m .1983 .7509 L .21178 .74845 L p .707 .577 .707 r
F P
0 g
s
.21178 .74845 m .22549 .74597 L p .19374 .71952 L .707 .577 .707 r
F P
0 g
s
.21997 .70797 m .19278 .7129 L p .19914 .71933 L .707 .577 .707 r
F P
0 g
s
.21392 .72122 m .21997 .70797 L .19914 .71933 L .707 .577 .707 r
F
.24811 .72276 m .24151 .70811 L .22197 .72171 L F
.24151 .70811 m .22657 .675 L .22197 .72171 L F
.22095 .72549 m .25202 .73143 L p .24811 .72276 L F P
0 g
s
.21997 .70797 m .22197 .72171 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25297 .72295 m .25083 .70308 L .23567 .72226 L .707 .577 .707 r
F
.25372 .72298 m .25366 .72256 L p .25297 .72295 L F P
0 g
s
.25765 .68094 m .25301 .72258 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.25366 .72256 m .25083 .70308 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .27299 .71142 L .25366 .72256 L .707 .577 .707 r
F
.27299 .71142 m .25765 .68094 L .25366 .72256 L F
.28931 .68217 m .25765 .68094 L p .27574 .71689 L F P
0 g
s
.27819 .72175 m .27911 .71846 L .27574 .71689 L .707 .577 .707 r
F
.27911 .71846 m .28931 .68217 L .27574 .71689 L F
.28493 .72153 m .28931 .68217 L p .27819 .72175 L F P
0 g
s
.31692 .73326 m .30287 .71923 L .28564 .7215 L .707 .577 .707 r
F
.28564 .7215 m .28785 .7367 L .3121 .73383 L p F P
0 g
s
.3121 .73383 m .31692 .73326 L p .28564 .7215 L .707 .577 .707 r
F P
0 g
s
.28785 .7367 m .28564 .7215 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.27672 .72659 m .28493 .72153 L .27163 .72196 L .707 .577 .707 r
F
.28785 .7367 m .28493 .72153 L .27672 .72659 L F
.28559 .72112 m .28564 .7215 L p .30287 .71923 L F P
0 g
s
.28496 .72119 m .28493 .72153 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28493 .72153 m .28233 .6987 L .27163 .72196 L .707 .577 .707 r
F
.28564 .7215 m .28559 .72112 L p .28493 .72153 L F P
0 g
s
.28931 .68217 m .28496 .72119 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28559 .72112 m .28233 .6987 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.30763 .7187 m .30334 .71015 L .28559 .72112 L .707 .577 .707 r
F
.30334 .71015 m .28931 .68217 L .28559 .72112 L F
.31846 .67859 m .28931 .68217 L p .30763 .7187 L F P
0 g
s
.3114 .69527 m .28233 .6987 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31469 .71793 L p .31407 .718 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31407 .718 L .30718 .72353 L .707 .577 .707 r
F
.31692 .73326 m .3407 .73111 L p .32741 .71485 L F P
0 g
s
.33344 .71358 m .3299 .70531 L .32227 .71594 L .707 .577 .707 r
F
.31846 .67859 m .31411 .71766 L p .3299 .70531 L F P
0 g
s
.31411 .71766 m .31407 .718 L p .31463 .71755 L .707 .577 .707 r
F P
0 g
s
.3299 .70531 m .31411 .71766 L .31463 .71755 L .707 .577 .707 r
F
.31463 .71755 m .31692 .73326 L p .32741 .71485 L F P
0 g
s
.31407 .718 m .31846 .67859 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.31469 .71793 m .3114 .69527 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31407 .718 m .31283 .72908 L p .3299 .70531 L .707 .577 .707 r
F P
0 g
s
.3407 .73111 m .33802 .71262 L p .33754 .71272 L .707 .577 .707 r
F P
0 g
s
.33176 .72017 m .33754 .71272 L .32741 .71485 L .707 .577 .707 r
F
.3407 .73111 m .33754 .71272 L .33176 .72017 L F
.3407 .73111 m .35687 .73045 L p .34471 .70951 L F P
0 g
s
.352 .70662 m .34949 .69733 L .34236 .71044 L .707 .577 .707 r
F
.34224 .67052 m .33759 .71234 L p .34949 .69733 L F P
0 g
s
.33759 .71234 m .33754 .71272 L p .33795 .71219 L .707 .577 .707 r
F P
0 g
s
.34949 .69733 m .33759 .71234 L .33795 .71219 L .707 .577 .707 r
F
.33795 .71219 m .3407 .73111 L p .34471 .70951 L F P
0 g
s
.34224 .67052 m .31846 .67859 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .33754 .71272 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .34224 .67052 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33802 .71262 m .33518 .69311 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .33662 .72101 L p .34949 .69733 L .707 .577 .707 r
F P
0 g
s
.35687 .73045 m .35334 .70609 L p .35305 .70621 L .707 .577 .707 r
F P
0 g
s
.34944 .71766 m .35305 .70621 L .34471 .70951 L .707 .577 .707 r
F
.35687 .73045 m .35305 .70621 L .34944 .71766 L F
.35687 .73045 m .36386 .73135 L p .35496 .70367 L F P
0 g
s
.35953 .69498 m .35925 .68651 L .35402 .7047 L .707 .577 .707 r
F
.35585 .70268 m .35953 .69498 L p .35402 .7047 L F P
0 g
s
.35833 .65877 m .35311 .70571 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35311 .70571 m .35305 .70621 L p .35326 .70555 L .707 .577 .707 r
F P
0 g
s
.35925 .68651 m .35311 .70571 L .35326 .70555 L .707 .577 .707 r
F
.35326 .70555 m .35687 .73045 L p .35496 .70367 L F P
0 g
s
.35833 .65877 m .34224 .67052 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35305 .70621 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35833 .65877 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35334 .70609 m .35136 .69245 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35271 .70927 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .35136 .69245 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.36386 .73135 m .35916 .69903 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35916 .69903 m .35834 .69335 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .35326 .70555 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35585 .70268 L p .35402 .7047 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .33518 .69311 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33518 .69311 m .33795 .71219 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .35271 .70927 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.352 .70662 m .34236 .71044 L .33662 .72101 L .707 .577 .707 r
F
.33518 .69311 m .3114 .69527 L p .32741 .71485 L F P
0 g
s
.3114 .69527 m .31463 .71755 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.31283 .72908 m .33662 .72101 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33344 .71358 m .32227 .71594 L .31283 .72908 L .707 .577 .707 r
F
.30718 .72353 m .31407 .718 L .30287 .71923 L F
.31283 .72908 m .31407 .718 L p .30763 .7187 L F P
0 g
s
.30763 .7187 m .28559 .72112 L .28369 .73267 L .707 .577 .707 r
F
.28493 .72153 m .28369 .73267 L p .28559 .72112 L F P
0 g
s
.28369 .73267 m .31283 .72908 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .28559 .72112 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .25083 .70308 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.28369 .73267 m .28493 .72153 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .25366 .72256 L .25202 .73143 L .707 .577 .707 r
F
.25297 .72295 m .25202 .73143 L p .25366 .72256 L F P
0 g
s
.25202 .73143 m .28369 .73267 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .25366 .72256 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .21997 .70797 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25202 .73143 m .25297 .72295 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.70165 .82433 m .69841 .84291 L .6955 .83614 L p .707 .577 .707 r
F P
0 g
s
.6955 .83614 m .69875 .81755 L .70165 .82433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.61259 .30552 m .61259 .80741 L .63494 .79689 L p .707 .577 .707 r
F P
0 g
s
.63494 .79689 m .63494 .295 L .61259 .30552 L p .707 .577 .707 r
F P
0 g
s
.37945 .80447 m .37945 .30259 L .36087 .29155 L p .707 .577 .707 r
F P
0 g
s
.37945 .30259 m .37945 .80447 L .40983 .81343 L p .707 .577 .707 r
F P
0 g
s
.69875 .81755 m .6955 .83614 L .68305 .82825 L p .707 .577 .707 r
F P
0 g
s
.68305 .82825 m .68629 .80967 L .69875 .81755 L p .707 .577 .707 r
F P
0 g
s
.17237 .70222 m .178 .65173 L .16525 .63668 L p .707 .577 .707 r
F P
0 g
s
.17192 .71739 m .17744 .75538 L .1983 .7509 L p .707 .577 .707 r
F P
0 g
s
.1983 .7509 m .19278 .7129 L .17192 .71739 L p .707 .577 .707 r
F P
0 g
s
.25162 .82909 m .25302 .81173 L .22189 .80674 L p .707 .577 .707 r
F P
0 g
s
.25302 .81173 m .25162 .82909 L .28335 .82987 L p .707 .577 .707 r
F P
0 g
s
.28335 .82987 m .28476 .81252 L .25302 .81173 L p .707 .577 .707 r
F P
0 g
s
.28476 .81252 m .28335 .82987 L .31258 .82636 L p .707 .577 .707 r
F P
0 g
s
.31258 .82636 m .31398 .80901 L .28476 .81252 L p .707 .577 .707 r
F P
0 g
s
.22049 .82409 m .22189 .80674 L .19441 .79802 L p .707 .577 .707 r
F P
0 g
s
.22189 .80674 m .22049 .82409 L .25162 .82909 L p .707 .577 .707 r
F P
0 g
s
.63494 .295 m .63494 .79689 L .64409 .78503 L p .707 .577 .707 r
F P
0 g
s
.64409 .78503 m .64409 .28314 L .63494 .295 L p .707 .577 .707 r
F P
0 g
s
.19441 .79802 m .193 .81537 L .22049 .82409 L p .707 .577 .707 r
F P
0 g
s
.68629 .80967 m .68305 .82825 L .66226 .82002 L p .707 .577 .707 r
F P
0 g
s
.66226 .82002 m .6655 .80144 L .68629 .80967 L p .707 .577 .707 r
F P
0 g
s
.35953 .69498 m .36516 .64449 L .35833 .65877 L p .707 .577 .707 r
F P
0 g
s
.31398 .80901 m .31258 .82636 L .33644 .8189 L p .707 .577 .707 r
F P
0 g
s
.33644 .8189 m .33784 .80155 L .31398 .80901 L p .707 .577 .707 r
F P
0 g
s
.15963 .68718 m .16525 .63668 L .16214 .62126 L p .707 .577 .707 r
F P
0 g
s
.16525 .63668 m .15963 .68718 L .17237 .70222 L p .707 .577 .707 r
F P
0 g
s
.193 .81537 m .19441 .79802 L .17326 .78642 L p .707 .577 .707 r
F P
0 g
s
.15943 .72099 m .16495 .75899 L .17744 .75538 L p .707 .577 .707 r
F P
0 g
s
.17744 .75538 m .17192 .71739 L .15943 .72099 L p .707 .577 .707 r
F P
0 g
s
.36516 .64449 m .35953 .69498 L .35642 .67956 L p .707 .577 .707 r
F P
0 g
s
.35642 .67956 m .36204 .62907 L .36516 .64449 L p .707 .577 .707 r
F P
0 g
s
.35946 .79538 m .36087 .77802 L .35399 .79087 L p .707 .577 .707 r
F P
0 g
s
.36204 .62907 m .35642 .67956 L .34367 .66451 L p .707 .577 .707 r
F P
0 g
s
.34367 .66451 m .3493 .61402 L .36204 .62907 L p .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .36386 .73135 L .36096 .73371 L p .707 .577 .707 r
F P
0 g
s
.36096 .73371 m .35544 .69571 L .35834 .69335 L p .707 .577 .707 r
F P
0 g
s
.36087 .77802 m .35946 .79538 L .35638 .78161 L p .707 .577 .707 r
F P
0 g
s
.35638 .78161 m .35778 .76426 L .36087 .77802 L p .707 .577 .707 r
F P
0 g
s
.35544 .69571 m .36096 .73371 L .34847 .73731 L p .707 .577 .707 r
F P
0 g
s
.36087 .79344 m .36087 .29155 L .35591 .27951 L p .707 .577 .707 r
F P
0 g
s
.36087 .29155 m .36087 .79344 L .37945 .80447 L p .707 .577 .707 r
F P
0 g
s
.17326 .78642 m .17185 .80378 L .193 .81537 L p .707 .577 .707 r
F P
0 g
s
.33784 .80155 m .33644 .8189 L .35259 .80823 L p .707 .577 .707 r
F P
0 g
s
.35259 .80823 m .35399 .79087 L .33784 .80155 L p .707 .577 .707 r
F P
0 g
s
.6655 .80144 m .66226 .82002 L .63517 .81226 L p .707 .577 .707 r
F P
0 g
s
.63517 .81226 m .63841 .79367 L .6655 .80144 L p .707 .577 .707 r
F P
0 g
s
.17185 .80378 m .17326 .78642 L .16052 .77309 L p .707 .577 .707 r
F P
0 g
s
.16214 .62126 m .15651 .67176 L .15963 .68718 L p .707 .577 .707 r
F P
0 g
s
.15651 .67176 m .16214 .62126 L .16896 .60698 L p .707 .577 .707 r
F P
0 g
s
.16052 .77309 m .15911 .79045 L .17185 .80378 L p .707 .577 .707 r
F P
0 g
s
.15654 .72335 m .16205 .76135 L .16495 .75899 L p .707 .577 .707 r
F P
0 g
s
.16495 .75899 m .15943 .72099 L .15654 .72335 L p .707 .577 .707 r
F P
0 g
s
.64409 .28314 m .64409 .78503 L .63912 .773 L p .707 .577 .707 r
F P
0 g
s
.63912 .773 m .63912 .27111 L .64409 .28314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35399 .79087 m .35259 .80823 L .35946 .79538 L p .707 .577 .707 r
F P
0 g
s
.15911 .79045 m .16052 .77309 L .15743 .75933 L p .707 .577 .707 r
F P
0 g
s
.35778 .76426 m .35638 .78161 L .34364 .76828 L p .707 .577 .707 r
F P
0 g
s
.34364 .76828 m .34504 .75093 L .35778 .76426 L p .707 .577 .707 r
F P
0 g
s
.35591 .27951 m .35591 .7814 L .36087 .79344 L p .707 .577 .707 r
F P
0 g
s
.35591 .7814 m .35591 .27951 L .36505 .26766 L p .707 .577 .707 r
F P
0 g
s
.16896 .60698 m .16333 .65747 L .15651 .67176 L p .707 .577 .707 r
F P
0 g
s
.16333 .65747 m .16896 .60698 L .18505 .59523 L p .707 .577 .707 r
F P
0 g
s
.15743 .75933 m .15603 .77668 L .15911 .79045 L p .707 .577 .707 r
F P
0 g
s
.16352 .72425 m .16903 .76225 L .16205 .76135 L p .707 .577 .707 r
F P
0 g
s
.16205 .76135 m .15654 .72335 L .16352 .72425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15603 .77668 m .15743 .75933 L .1643 .74648 L p .707 .577 .707 r
F P
0 g
s
.3493 .61402 m .34367 .66451 L .32254 .65131 L p .707 .577 .707 r
F P
0 g
s
.32254 .65131 m .32817 .60082 L .3493 .61402 L p .707 .577 .707 r
F P
0 g
s
.18505 .59523 m .17942 .64572 L .16333 .65747 L p .707 .577 .707 r
F P
0 g
s
.17942 .64572 m .18505 .59523 L .20883 .58717 L p .707 .577 .707 r
F P
0 g
s
.63912 .27111 m .63912 .773 L .62054 .76196 L p .707 .577 .707 r
F P
0 g
s
.62054 .76196 m .62054 .26007 L .63912 .27111 L p .707 .577 .707 r
F P
0 g
s
.1643 .74648 m .1629 .76383 L .15603 .77668 L p .707 .577 .707 r
F P
0 g
s
.34847 .73731 m .34295 .69932 L .35544 .69571 L p .707 .577 .707 r
F P
0 g
s
.36505 .76954 m .36505 .26766 L .38741 .25714 L p .707 .577 .707 r
F P
0 g
s
.36505 .26766 m .36505 .76954 L .35591 .7814 L p .707 .577 .707 r
F P
0 g
s
.17969 .72359 m .18521 .76159 L .16903 .76225 L p .707 .577 .707 r
F P
0 g
s
.16903 .76225 m .16352 .72425 L .17969 .72359 L p .707 .577 .707 r
F P
0 g
s
.32817 .60082 m .32254 .65131 L .2951 .64125 L p .707 .577 .707 r
F P
0 g
s
.2951 .64125 m .30072 .59076 L .32817 .60082 L p .707 .577 .707 r
F P
0 g
s
.20321 .63766 m .20883 .58717 L .23798 .58358 L p .707 .577 .707 r
F P
0 g
s
.20883 .58717 m .20321 .63766 L .17942 .64572 L p .707 .577 .707 r
F P
0 g
s
.1629 .76383 m .1643 .74648 L .18046 .73581 L p .707 .577 .707 r
F P
0 g
s
.30072 .59076 m .2951 .64125 L .26402 .63531 L p .707 .577 .707 r
F P
0 g
s
.26402 .63531 m .26964 .58482 L .30072 .59076 L p .707 .577 .707 r
F P
0 g
s
.23236 .63407 m .23798 .58358 L .26964 .58482 L p .707 .577 .707 r
F P
0 g
s
.23798 .58358 m .23236 .63407 L .20321 .63766 L p .707 .577 .707 r
F P
0 g
s
.18046 .73581 m .17906 .75316 L .1629 .76383 L p .707 .577 .707 r
F P
0 g
s
.34295 .69932 m .34847 .73731 L .32761 .7418 L p .707 .577 .707 r
F P
0 g
s
.26964 .58482 m .26402 .63531 L .23236 .63407 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .32209 .7038 L .34295 .69932 L p .707 .577 .707 r
F P
0 g
s
.62054 .26007 m .62054 .76196 L .59016 .75301 L p .707 .577 .707 r
F P
0 g
s
.59016 .75301 m .59016 .25112 L .62054 .26007 L p .707 .577 .707 r
F P
0 g
s
.20348 .72144 m .20899 .75943 L .18521 .76159 L p .707 .577 .707 r
F P
0 g
s
.18521 .76159 m .17969 .72359 L .20348 .72144 L p .707 .577 .707 r
F P
0 g
s
.34504 .75093 m .34364 .76828 L .32249 .75669 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .30042 .74673 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32209 .7038 m .32421 .7184 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32421 .7184 m .32761 .7418 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .32389 .73934 L .34188 .7492 L p .707 .577 .707 r
F P
0 g
s
.34188 .7492 m .34504 .75093 L p .34315 .75141 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .34188 .7492 L .34315 .75141 L .707 .577 .707 r
F
.38741 .25714 m .38741 .75902 L .36505 .76954 L p F P
0 g
s
.38741 .75902 m .38741 .25714 L .42078 .24898 L p .707 .577 .707 r
F P
0 g
s
.17906 .75316 m .18046 .73581 L .20432 .72835 L p .707 .577 .707 r
F P
0 g
s
.73598 .63577 m .73035 .57841 L .69928 .58113 L p .707 .577 .707 r
F P
0 g
s
.73035 .57841 m .73598 .63577 L .76764 .63253 L p .707 .577 .707 r
F P
0 g
s
.76764 .63253 m .76202 .57517 L .73035 .57841 L p .707 .577 .707 r
F P
0 g
s
.20432 .72835 m .20291 .7457 L .17906 .75316 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .2949 .70873 L .32209 .7038 L p .707 .577 .707 r
F P
0 g
s
.69928 .58113 m .7049 .63849 L .73598 .63577 L p .707 .577 .707 r
F P
0 g
s
.76202 .57517 m .76764 .63253 L .79679 .62907 L p .707 .577 .707 r
F P
0 g
s
.79679 .62907 m .79116 .57171 L .76202 .57517 L p .707 .577 .707 r
F P
0 g
s
.23254 .718 m .23806 .756 L .20899 .75943 L p .707 .577 .707 r
F P
0 g
s
.20899 .75943 m .20348 .72144 L .23254 .718 L p .707 .577 .707 r
F P
0 g
s
.7049 .63849 m .69928 .58113 L .67183 .58306 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .26956 .75162 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.2949 .70873 m .29609 .71691 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.29609 .71691 m .30042 .74673 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .295 .74797 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32389 .73934 m .32366 .7422 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32366 .7422 m .32249 .75669 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .29641 .73062 L .32389 .73934 L p .707 .577 .707 r
F P
0 g
s
.67183 .58306 m .67746 .64042 L .7049 .63849 L p .707 .577 .707 r
F P
0 g
s
.23806 .756 m .23277 .71959 L p .26405 .71363 L .707 .577 .707 r
F P
0 g
s
.23277 .71959 m .23254 .718 L .23577 .71756 L p .707 .577 .707 r
F P
0 g
s
.23577 .71756 m .26405 .71363 L p .23277 .71959 L .707 .577 .707 r
F P
0 g
s
.20291 .7457 m .20341 .7395 L p .23354 .72484 L .707 .577 .707 r
F P
0 g
s
.20341 .7395 m .20432 .72835 L .2232 .72608 L p .707 .577 .707 r
F P
0 g
s
.2232 .72608 m .23354 .72484 L p .20341 .7395 L .707 .577 .707 r
F P
0 g
s
.59016 .25112 m .59016 .75301 L .55096 .74701 L p .707 .577 .707 r
F P
0 g
s
.55096 .74701 m .55096 .24512 L .59016 .25112 L p .707 .577 .707 r
F P
0 g
s
.79116 .57171 m .79679 .62907 L .82057 .62575 L p .707 .577 .707 r
F P
0 g
s
.82057 .62575 m .81495 .56839 L .79116 .57171 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .26405 .71363 L .2949 .70873 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .23806 .756 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.26453 .71692 m .26956 .75162 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .26387 .74297 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29641 .73062 m .29591 .73677 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29591 .73677 m .295 .74797 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.26405 .71363 m .26453 .71692 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.23354 .72484 m .23214 .74219 L .20291 .7457 L p .707 .577 .707 r
F P
0 g
s
.42078 .75087 m .42078 .24898 L .46191 .244 L p .707 .577 .707 r
F P
0 g
s
.42078 .24898 m .42078 .75087 L .38741 .75902 L p .707 .577 .707 r
F P
0 g
s
.26387 .74297 m .26527 .72562 L .29641 .73062 L p .707 .577 .707 r
F P
0 g
s
.67746 .64042 m .67183 .58306 L .6507 .584 L p .707 .577 .707 r
F P
0 g
s
.23214 .74219 m .23354 .72484 L .26527 .72562 L p .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .73472 .72534 L .7173 .72621 L p .707 .577 .707 r
F P
0 g
s
.7173 .72621 m .70359 .7269 L p .70998 .73034 L .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .7173 .72621 L .70998 .73034 L .707 .577 .707 r
F
.73613 .74442 m .76786 .74179 L p .74488 .73038 L F P
0 g
s
.73472 .72534 m .73554 .73638 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.73554 .73638 m .73613 .74442 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .76646 .72271 L .73472 .72534 L p .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .79708 .73835 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76646 .72271 m .76755 .73761 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76755 .73761 m .76786 .74179 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .79568 .71927 L .76646 .72271 L p .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .82094 .73443 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79568 .71927 m .79706 .73803 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79706 .73803 m .79708 .73835 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.82094 .73443 m .81954 .71535 L .79568 .71927 L p .707 .577 .707 r
F P
0 g
s
.81954 .71535 m .82094 .73443 L .8371 .73042 L p .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .8357 .71134 L .83012 .71273 L p .707 .577 .707 r
F P
0 g
s
.83012 .71273 m .81954 .71535 L p .82729 .722 L .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .83012 .71273 L .82729 .722 L .707 .577 .707 r
F
.83096 .72012 m .83795 .70323 L p .83672 .69116 L F P
0 g
s
.83648 .6888 m .83518 .6962 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.83518 .6962 m .83096 .72012 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .83096 .72012 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.82031 .70248 m .81976 .70558 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.81976 .70558 m .81479 .73381 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .81479 .73381 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79652 .71163 m .79639 .71239 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79639 .71239 m .79101 .74295 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .79101 .74295 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76745 .71533 m .76734 .71597 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76734 .71597 m .76194 .74666 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.70359 .7269 m .70499 .74598 L .73613 .74442 L p .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .76194 .74666 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73595 .71324 m .73547 .71596 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73547 .71596 m .73043 .74456 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .73595 .71324 L .70509 .70555 L p .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .76745 .71533 L .73595 .71324 L p .707 .577 .707 r
F P
0 g
s
.6507 .584 m .65633 .64136 L .67746 .64042 L p .707 .577 .707 r
F P
0 g
s
.26527 .72562 m .26387 .74297 L .23214 .74219 L p .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .70359 .7269 L .68123 .72717 L p .707 .577 .707 r
F P
0 g
s
.68123 .72717 m .67611 .72723 L p .67863 .72887 L .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .68123 .72717 L .67863 .72887 L .707 .577 .707 r
F
.69958 .73688 m .73043 .74456 L p .70781 .70974 L F P
0 g
s
.70509 .70555 m .70391 .7123 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.70391 .7123 m .69958 .73688 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.69958 .73688 m .70509 .70555 L .6779 .69302 L p .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .79652 .71163 L .76745 .71533 L p .707 .577 .707 r
F P
0 g
s
.55096 .24512 m .55096 .74701 L .50676 .74456 L p .707 .577 .707 r
F P
0 g
s
.50676 .74456 m .50676 .24267 L .55096 .24512 L p .707 .577 .707 r
F P
0 g
s
.81495 .56839 m .82057 .62575 L .83666 .62288 L p .707 .577 .707 r
F P
0 g
s
.83666 .62288 m .83104 .56552 L .81495 .56839 L p .707 .577 .707 r
F P
0 g
s
.67611 .72723 m .67751 .74631 L .70499 .74598 L p .707 .577 .707 r
F P
0 g
s
.46191 .74589 m .46191 .244 L .50676 .24267 L p .707 .577 .707 r
F P
0 g
s
.46191 .244 m .46191 .74589 L .42078 .75087 L p .707 .577 .707 r
F P
0 g
s
.67239 .72435 m .6779 .69302 L .65704 .67688 L p .707 .577 .707 r
F P
0 g
s
.6779 .69302 m .67239 .72435 L .69958 .73688 L p .707 .577 .707 r
F P
0 g
s
.50676 .24267 m .50676 .74456 L .46191 .74589 L p .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .82031 .70248 L .79652 .71163 L p .707 .577 .707 r
F P
0 g
s
.65633 .64136 m .6507 .584 L .63796 .58388 L p .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .64358 .64124 L .65633 .64136 L p .707 .577 .707 r
F P
0 g
s
.67751 .74631 m .67611 .72723 L .65496 .72631 L p .707 .577 .707 r
F P
0 g
s
.65496 .72631 m .65636 .74539 L .67751 .74631 L p .707 .577 .707 r
F P
0 g
s
.65153 .7082 m .65704 .67688 L .64455 .6587 L p .707 .577 .707 r
F P
0 g
s
.65704 .67688 m .65153 .7082 L .67239 .72435 L p .707 .577 .707 r
F P
0 g
s
.83096 .72012 m .83648 .6888 L .82031 .70248 L p .707 .577 .707 r
F P
0 g
s
.83104 .56552 m .83666 .62288 L .84349 .62075 L p .707 .577 .707 r
F P
0 g
s
.84349 .62075 m .83786 .56339 L .83104 .56552 L p .707 .577 .707 r
F P
0 g
s
.65636 .74539 m .65496 .72631 L .64222 .72422 L p .707 .577 .707 r
F P
0 g
s
.64358 .64124 m .6421 .62617 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.63484 .58269 m .64047 .64005 L .64358 .64124 L p .707 .577 .707 r
F P
0 g
s
.63904 .69002 m .64455 .6587 L .64166 .64026 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .63614 .67158 L .63904 .69002 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .64864 .62337 L p .64504 .63727 L .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .63484 .58269 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.6421 .62617 m .63796 .58388 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64414 .6389 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64864 .62337 L p .64977 .63276 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64695 .63444 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64977 .63276 L .64695 .63444 L .707 .577 .707 r
F
.66338 .63505 m .64729 .63792 L p .648 .63381 L F P
0 g
s
.64864 .62337 m .66481 .60969 L p .65529 .62945 L .707 .577 .707 r
F P
0 g
s
.64977 .63276 m .64864 .62337 L .65529 .62945 L .707 .577 .707 r
F
.648 .63381 m .66205 .62541 L .66338 .63505 L F
.66205 .62541 m .66481 .60969 L p .66743 .62417 L F P
0 g
s
.66338 .63505 m .66245 .62563 L p .66656 .62442 L .707 .577 .707 r
F P
0 g
s
.66205 .62541 m .66743 .62417 L .66245 .62563 L .707 .577 .707 r
F
.68716 .63173 m .66338 .63505 L p .66656 .62442 L F P
0 g
s
.66481 .60969 m .6886 .60054 L p .67259 .62266 L .707 .577 .707 r
F P
0 g
s
.66743 .62417 m .66481 .60969 L .67259 .62266 L .707 .577 .707 r
F
.6886 .60054 m .71767 .59684 L p .69713 .61764 L F P
0 g
s
.6921 .61832 m .6886 .60054 L .69713 .61764 L .707 .577 .707 r
F
.68716 .63173 m .68593 .61915 L p .69237 .61828 L F P
0 g
s
.68536 .61891 m .6886 .60054 L p .6921 .61832 L .707 .577 .707 r
F P
0 g
s
.71631 .62828 m .68716 .63173 L p .69237 .61828 L .707 .577 .707 r
F P
0 g
s
.68593 .61915 m .6921 .61832 L .69282 .622 L .707 .577 .707 r
F
.68536 .61891 m .6921 .61832 L .68593 .61915 L F
.71767 .59684 m .74917 .59893 L p .72837 .61535 L F P
0 g
s
.7223 .61547 m .71767 .59684 L .72837 .61535 L .707 .577 .707 r
F
.71631 .62828 m .71507 .61562 L p .72181 .61548 L F P
0 g
s
.71441 .61532 m .71767 .59684 L p .7223 .61547 L .707 .577 .707 r
F P
0 g
s
.74798 .62503 m .71631 .62828 L p .72181 .61548 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .74634 .61499 L .74798 .62503 L .707 .577 .707 r
F
.74634 .61499 m .74917 .59893 L p .75524 .61608 L F P
0 g
s
.77905 .62231 m .74798 .62503 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .77803 .61794 L .77905 .62231 L .707 .577 .707 r
F
.77803 .61794 m .78003 .60662 L p .78608 .61996 L F P
0 g
s
.79317 .62132 m .77905 .62231 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.77803 .61794 m .78608 .61996 L .77868 .61853 L .707 .577 .707 r
F
.78003 .60662 m .80722 .61915 L p .80086 .6228 L F P
0 g
s
.78608 .61996 m .78003 .60662 L .80086 .6228 L .707 .577 .707 r
F
.74917 .59893 m .78003 .60662 L p .76433 .61682 L F P
0 g
s
.75716 .62148 m .75524 .61608 L .76433 .61682 L .707 .577 .707 r
F
.75524 .61608 m .74917 .59893 L .76433 .61682 L F
.74634 .61499 m .75524 .61608 L .74703 .6154 L F
.69237 .61828 m .71441 .61532 L .71631 .62828 L F
.71441 .61532 m .7223 .61547 L .71507 .61562 L F
.71503 .61523 m .71507 .61562 L p .71441 .61532 L F P
0 g
s
.71507 .61562 m .71631 .62828 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.74917 .59893 m .74628 .61534 L p .7288 .62191 L .707 .577 .707 r
F P
0 g
s
.71215 .62816 m .72327 .61938 L .7288 .62191 L .707 .577 .707 r
F
.72327 .61938 m .74917 .59893 L .7288 .62191 L F
.74628 .61534 m .74365 .63025 L .72033 .6287 L p F P
0 g
s
.72033 .6287 m .71215 .62816 L p .74628 .61534 L .707 .577 .707 r
F P
0 g
s
.74235 .56767 m .77343 .56495 L p .7537 .61152 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .75128 .61276 L .7537 .61152 L .707 .577 .707 r
F
.75128 .61276 m .74235 .56767 L .7537 .61152 L F
.74798 .62503 m .74703 .6154 L p .75189 .6158 L F P
0 g
s
.74703 .6154 m .74235 .56767 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.78003 .60662 m .77795 .61839 L p .74365 .63025 L .707 .577 .707 r
F P
0 g
s
.77795 .61839 m .77451 .63794 L .7537 .63276 L p .707 .577 .707 r
F P
0 g
s
.7537 .63276 m .74365 .63025 L p .77795 .61839 L .707 .577 .707 r
F P
0 g
s
.77343 .56495 m .80087 .56303 L p .7812 .61647 L .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .7801 .61712 L .7812 .61647 L .707 .577 .707 r
F
.7801 .61712 m .77343 .56495 L .7812 .61647 L F
.77905 .62231 m .77868 .61853 L p .78033 .61885 L F P
0 g
s
.77868 .61853 m .77343 .56495 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.79016 .62895 m .78608 .61996 L .80086 .6228 L .707 .577 .707 r
F
.77868 .61853 m .78608 .61996 L .79016 .62895 L F
.80722 .61915 m .80626 .6246 L p .77451 .63794 L F P
0 g
s
.80626 .6246 m .8017 .65047 L .78822 .64426 L p .707 .577 .707 r
F P
0 g
s
.78822 .64426 m .77451 .63794 L p .80626 .6246 L .707 .577 .707 r
F P
0 g
s
.8017 .65047 m .80722 .61915 L .82808 .63529 L p .707 .577 .707 r
F P
0 g
s
.822 .56208 m .82602 .60306 L p .8065 .62039 L .707 .577 .707 r
F P
0 g
s
.82602 .60306 m .82763 .61944 L .81028 .62022 L p .707 .577 .707 r
F P
0 g
s
.81028 .62022 m .8065 .62039 L p .82602 .60306 L .707 .577 .707 r
F P
0 g
s
.80087 .56303 m .8065 .62039 L .79317 .62132 L p .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .80087 .56303 L .79317 .62132 L .707 .577 .707 r
F
.77863 .61799 m .77868 .61853 L p .77803 .61794 L F P
0 g
s
.77868 .61853 m .77905 .62231 L p .77803 .61794 L .707 .577 .707 r
F P
0 g
s
.77451 .63794 m .77803 .61794 L p .79016 .62895 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .75524 .61608 L .75716 .62148 L .707 .577 .707 r
F
.77343 .56495 m .77863 .61799 L p .75189 .6158 L F P
0 g
s
.74699 .61498 m .74703 .6154 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .74798 .62503 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74365 .63025 m .74634 .61499 L p .75716 .62148 L .707 .577 .707 r
F P
0 g
s
.71507 .61562 m .7223 .61547 L .72327 .61938 L .707 .577 .707 r
F
.74235 .56767 m .74699 .61498 L p .72181 .61548 L F P
0 g
s
.66656 .62442 m .68536 .61891 L .68716 .63173 L .707 .577 .707 r
F
.68589 .61876 m .68593 .61915 L p .68536 .61891 L F P
0 g
s
.68593 .61915 m .68716 .63173 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.71767 .59684 m .71436 .61564 L p .69798 .62414 L .707 .577 .707 r
F P
0 g
s
.68308 .63187 m .69282 .622 L .69798 .62414 L .707 .577 .707 r
F
.69282 .622 m .71767 .59684 L .69798 .62414 L F
.71436 .61564 m .71215 .62816 L .6879 .63125 L p F P
0 g
s
.6879 .63125 m .68308 .63187 L p .71436 .61564 L .707 .577 .707 r
F P
0 g
s
.71069 .57092 m .74235 .56767 L p .72426 .60979 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .72089 .61178 L .72426 .60979 L .707 .577 .707 r
F
.72089 .61178 m .71069 .57092 L .72426 .60979 L F
.71507 .61562 m .71069 .57092 L p .72181 .61548 L F P
0 g
s
.72327 .61938 m .7223 .61547 L .72837 .61535 L .707 .577 .707 r
F
.71215 .62816 m .71441 .61532 L p .72327 .61938 L F P
0 g
s
.71069 .57092 m .71503 .61523 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69666 .60719 L .71441 .61532 L .707 .577 .707 r
F
.69666 .60719 m .71069 .57092 L .71441 .61532 L F
.68308 .63187 m .6593 .64101 L p .66056 .63927 L F P
0 g
s
.6886 .60054 m .68531 .61923 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68531 .61923 m .68308 .63187 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68154 .57437 m .71069 .57092 L p .69505 .61134 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69139 .61431 L .69505 .61134 L .707 .577 .707 r
F
.69139 .61431 m .68154 .57437 L .69505 .61134 L F
.68593 .61915 m .68154 .57437 L p .69237 .61828 L F P
0 g
s
.69282 .622 m .6921 .61832 L .69713 .61764 L .707 .577 .707 r
F
.68308 .63187 m .68536 .61891 L p .69282 .622 L F P
0 g
s
.68154 .57437 m .68589 .61876 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .6701 .61259 L .68536 .61891 L .707 .577 .707 r
F
.6701 .61259 m .68154 .57437 L .68536 .61891 L F
.66824 .62866 m .66743 .62417 L .67259 .62266 L F
.66245 .62563 m .66743 .62417 L .66824 .62866 L F
.6593 .64101 m .64312 .65469 L p .64821 .64414 L F P
0 g
s
.66481 .60969 m .66198 .62577 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.66198 .62577 m .6593 .64101 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .68154 .57437 L p .66893 .61649 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .66584 .62062 L .66893 .61649 L .707 .577 .707 r
F
.66584 .62062 m .65775 .57769 L .66893 .61649 L F
.66245 .62563 m .65775 .57769 L p .66656 .62442 L F P
0 g
s
.66241 .62519 m .66245 .62563 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.66245 .62563 m .66338 .63505 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.6593 .64101 m .66205 .62541 L p .66824 .62866 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .66241 .62519 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.65055 .63928 m .64977 .63276 L .65529 .62945 L .707 .577 .707 r
F
.64695 .63444 m .64977 .63276 L .65055 .63928 L F
.64312 .65469 m .63614 .67158 L p .64164 .65039 L F P
0 g
s
.64864 .62337 m .64666 .63461 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64666 .63461 m .64312 .65469 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .65775 .57769 L p .64931 .6263 L .707 .577 .707 r
F P
0 g
s
.648 .63381 m .64771 .63133 L .64931 .6263 L .707 .577 .707 r
F
.64771 .63133 m .64166 .58056 L .64931 .6263 L F
.64695 .63444 m .64166 .58056 L p .648 .63381 L F P
0 g
s
.64689 .63388 m .64695 .63444 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64695 .63444 m .64729 .63792 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64312 .65469 m .64674 .63416 L p .65055 .63928 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .64689 .63388 L p .64047 .64005 L .707 .577 .707 r
F P
0 g
s
.64131 .64408 m .64166 .64026 L .64504 .63727 L .707 .577 .707 r
F
.64414 .6389 m .64047 .64005 L p .64689 .63388 L F P
0 g
s
.64023 .65581 m .64131 .64408 L .64504 .63727 L .707 .577 .707 r
F
.63614 .67158 m .64097 .6442 L p .64023 .65581 L F P
0 g
s
.64097 .6442 m .64166 .64026 L p .64023 .65581 L .707 .577 .707 r
F P
0 g
s
.64222 .72422 m .64362 .7433 L .65636 .74539 L p .707 .577 .707 r
F P
0 g
s
.64455 .6587 m .63904 .69002 L .65153 .7082 L p .707 .577 .707 r
F P
0 g
s
.83795 .70323 m .84346 .67191 L .83648 .6888 L p .707 .577 .707 r
F P
0 g
s
.8357 .71134 m .8371 .73042 L .84397 .72671 L p .707 .577 .707 r
F P
0 g
s
.84397 .72671 m .84257 .70763 L .8357 .71134 L p .707 .577 .707 r
F P
0 g
s
.83786 .56339 m .84349 .62075 L .84037 .61957 L p .707 .577 .707 r
F P
0 g
s
.84037 .61957 m .83475 .56221 L .83786 .56339 L p .707 .577 .707 r
F P
0 g
s
.64362 .7433 m .64222 .72422 L .63913 .72117 L p .707 .577 .707 r
F P
0 g
s
.63913 .72117 m .64053 .74025 L .64362 .7433 L p .707 .577 .707 r
F P
0 g
s
.64047 .64005 m .63484 .58269 L .64166 .58056 L p .707 .577 .707 r
F P
0 g
s
.84346 .67191 m .83795 .70323 L .83505 .6848 L p .707 .577 .707 r
F P
0 g
s
.83505 .6848 m .84057 .65347 L .84346 .67191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84257 .70763 m .84397 .72671 L .84088 .72366 L p .707 .577 .707 r
F P
0 g
s
.84088 .72366 m .83948 .70458 L .84257 .70763 L p .707 .577 .707 r
F P
0 g
s
.83475 .56221 m .84037 .61957 L .82763 .61944 L p .707 .577 .707 r
F P
0 g
s
.82763 .61944 m .822 .56208 L .83475 .56221 L p .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .38174 .57769 L .35136 .58164 L p .707 .577 .707 r
F P
0 g
s
.38174 .57769 m .39466 .63015 L .42569 .62246 L p .707 .577 .707 r
F P
0 g
s
.42569 .62246 m .41277 .57001 L .38174 .57769 L p .707 .577 .707 r
F P
0 g
s
.41277 .57001 m .42569 .62246 L .45434 .6118 L p .707 .577 .707 r
F P
0 g
s
.45434 .6118 m .44142 .55934 L .41277 .57001 L p .707 .577 .707 r
F P
0 g
s
.35266 .65285 m .38202 .66387 L p .37339 .63974 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .35136 .58164 L .35965 .62795 L .707 .577 .707 r
F
.36361 .63135 m .36311 .62933 L p .36093 .62904 L F P
0 g
s
.36311 .62933 m .35136 .58164 L p .36093 .62904 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .32462 .58147 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.38202 .66387 m .41216 .67384 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .35318 .58902 L p .39466 .63015 L .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .35318 .58902 L .39126 .63028 L .707 .577 .707 r
F
.38154 .63185 m .39466 .63015 L p .36361 .63135 L F P
0 g
s
.39453 .62781 m .39302 .63218 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.39302 .63218 m .38202 .66387 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35318 .58902 m .36361 .63135 L p .39126 .63028 L .707 .577 .707 r
F P
0 g
s
.37339 .63974 m .37045 .63154 L .36361 .63135 L .707 .577 .707 r
F
.36093 .62904 m .35266 .65285 L p .37339 .63974 L F P
0 g
s
.38202 .66387 m .39453 .62781 L .36518 .61679 L p .707 .577 .707 r
F P
0 g
s
.36361 .63135 m .36429 .6341 L .38154 .63185 L p .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .36093 .62904 L p .36361 .63135 L .707 .577 .707 r
F P
0 g
s
.37045 .63154 m .36518 .61679 L .36361 .63135 L .707 .577 .707 r
F
.35266 .65285 m .36093 .62904 L p .34542 .62698 L F P
0 g
s
.32698 .64187 m .35266 .65285 L p .34857 .63823 L .707 .577 .707 r
F P
0 g
s
.34857 .63823 m .34542 .62698 L .34078 .63073 L .707 .577 .707 r
F
.34857 .63823 m .34078 .63073 L .32698 .64187 L F
.32462 .58147 m .30412 .57718 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .32462 .58147 L .32898 .61938 L .707 .577 .707 r
F
.33551 .62566 m .33511 .62404 L p .33333 .62357 L F P
0 g
s
.33511 .62404 m .32462 .58147 L p .33333 .62357 L .707 .577 .707 r
F P
0 g
s
.32462 .58147 m .33551 .62566 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.32698 .64187 m .33333 .62357 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33273 .62529 m .32698 .64187 L p .34078 .63073 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .29188 .56922 L p .30958 .61171 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .31852 .62459 L .30747 .632 L .707 .577 .707 r
F
.31287 .61646 m .30412 .57718 L .30958 .61171 L F
.3143 .61852 m .31394 .61704 L p .31287 .61646 L F P
0 g
s
.31394 .61704 m .30412 .57718 L p .31287 .61646 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .31002 .60115 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .32381 .62104 L .31852 .62459 L .707 .577 .707 r
F
.31233 .618 m .30747 .632 L p .32381 .62104 L F P
0 g
s
.31002 .60115 m .31704 .62964 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .31287 .61646 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .30793 .61376 L .30379 .61741 L .707 .577 .707 r
F
.29606 .62421 m .30745 .63198 L p .30379 .61741 L F P
0 g
s
.30745 .63198 m .30747 .632 L p .30379 .61741 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .28908 .55834 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.30153 .60845 m .29188 .56922 L .30053 .60446 L .709 .579 .707 r
F
.30206 .61057 m .30169 .60906 L p .30153 .60845 L F P
0 g
s
.30169 .60906 m .29188 .56922 L p .30153 .60845 L .709 .579 .707 r
F P
0 g
s
.29606 .62421 m .30153 .60845 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .30206 .61057 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.30858 .58816 m .30153 .60845 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .301 .60999 L p .30206 .61057 L .707 .577 .707 r
F P
0 g
s
.30793 .61376 m .30153 .60845 L .30206 .61057 L .707 .577 .707 r
F
.301 .60999 m .29606 .62421 L p .30379 .61741 L F P
0 g
s
.30793 .61376 m .30206 .61057 L .30379 .61741 L .707 .577 .707 r
F
.30206 .61057 m .301 .60999 L .30379 .61741 L F
.28908 .55834 m .29602 .54562 L p .30085 .5982 L F P
0 g
s
.29606 .62421 m .30076 .60553 L .29851 .61 L .707 .577 .707 r
F
.28908 .55834 m .29642 .5881 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.29984 .60203 m .29386 .61926 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30053 .60446 m .29841 .59605 L .30201 .61079 L .709 .579 .707 r
F
.29642 .5881 m .29956 .60088 L p .29841 .59605 L F P
0 g
s
.29956 .60088 m .30201 .61079 L p .29841 .59605 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30053 .60446 L .30091 .60609 L .709 .579 .707 r
F
.3048 .62167 m .30206 .61057 L p .30053 .60446 L F P
0 g
s
.30637 .58321 m .30043 .60034 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29998 .60258 m .29956 .60088 L .30043 .60034 L .707 .577 .707 r
F
.30043 .60034 m .29984 .60203 L p .29998 .60258 L F P
0 g
s
.30076 .60553 m .30043 .60034 L .29998 .60258 L .707 .577 .707 r
F
.30201 .61079 m .3048 .62167 L p .30131 .60762 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30091 .60609 L .30201 .61079 L .709 .579 .707 r
F
.30858 .58816 m .30637 .58321 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .30858 .58816 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .29998 .60258 L p .30043 .60034 L .707 .577 .707 r
F P
0 g
s
.29984 .60203 m .30043 .60034 L p .30079 .60603 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .30637 .58321 L p .3025 .59903 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .30043 .60034 L .30101 .59997 L .707 .577 .707 r
F
.31999 .59595 m .30858 .58816 L p .30793 .61376 L F P
0 g
s
.30637 .58321 m .31359 .58158 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.3025 .59903 m .30637 .58321 L .30542 .59719 L .707 .577 .707 r
F
.30206 .61057 m .3048 .62167 L p .31117 .61553 L F P
0 g
s
.30894 .59808 m .30201 .61079 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.31359 .58158 m .30968 .59284 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30894 .59808 m .30828 .59539 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30542 .59719 m .30968 .59284 L .30828 .59539 L .707 .577 .707 r
F
.31359 .58158 m .32953 .58344 L p .32382 .5903 L F P
0 g
s
.30968 .59284 m .31359 .58158 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.312 .53231 m .32492 .58476 L .31675 .59157 L p .707 .577 .707 r
F P
0 g
s
.31675 .59157 m .30894 .59808 L p .30918 .59293 L .707 .577 .707 r
F P
0 g
s
.30918 .59293 m .312 .53231 L .31675 .59157 L .707 .577 .707 r
F
.30828 .59539 m .30894 .59808 L p .30101 .59997 L F P
0 g
s
.30108 .61764 m .30968 .59284 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.30968 .59284 m .30895 .59496 L p .30828 .59539 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .312 .53231 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30828 .59539 m .29602 .54562 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .30828 .59539 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.29386 .61926 m .29581 .62364 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.29581 .62364 m .29606 .62421 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.30108 .61764 m .29386 .61926 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30895 .59496 m .30108 .61764 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .3025 .59903 L .30079 .60603 L .707 .577 .707 r
F
.30043 .60034 m .28908 .55834 L .30085 .5982 L F
.29956 .60088 m .28908 .55834 L .30043 .60034 L F
.30101 .59997 m .30043 .60034 L .30085 .5982 L F
.30079 .60603 m .3025 .59903 L .30542 .59719 L F
.29386 .61926 m .29984 .60203 L p .30079 .60603 L F P
0 g
s
.3048 .62167 m .31704 .62964 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.31999 .59595 m .31287 .61646 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.31287 .61646 m .31233 .618 L p .3143 .61852 L .707 .577 .707 r
F P
0 g
s
.32381 .62104 m .31287 .61646 L .3143 .61852 L .707 .577 .707 r
F
.31704 .62964 m .3143 .61852 L p .30958 .61171 L F P
0 g
s
.31287 .61646 m .31999 .59595 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .32698 .64187 L p .32599 .63535 L .707 .577 .707 r
F P
0 g
s
.31704 .62964 m .33754 .63392 L p .33109 .62297 L .707 .577 .707 r
F P
0 g
s
.33109 .62297 m .32898 .61938 L .32628 .6217 L .707 .577 .707 r
F
.33109 .62297 m .32628 .6217 L .31704 .62964 L F
.34542 .62698 m .33551 .62566 L .34078 .63073 L F
.33551 .62566 m .33273 .62529 L .34078 .63073 L F
.33949 .60581 m .31999 .59595 L p .32381 .62104 L F P
0 g
s
.33949 .60581 m .33333 .62357 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.33333 .62357 m .33273 .62529 L p .33551 .62566 L .707 .577 .707 r
F P
0 g
s
.34542 .62698 m .33333 .62357 L .33551 .62566 L .707 .577 .707 r
F
.33754 .63392 m .33551 .62566 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .33949 .60581 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33754 .63392 m .36429 .6341 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.33551 .62566 m .33754 .63392 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .33949 .60581 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.36429 .6341 m .36361 .63135 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .36518 .61679 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.44142 .55934 m .45434 .6118 L .4778 .59919 L p .707 .577 .707 r
F P
0 g
s
.4778 .59919 m .46488 .54673 L .44142 .55934 L p .707 .577 .707 r
F P
0 g
s
.64053 .74025 m .63913 .72117 L .646 .71746 L p .707 .577 .707 r
F P
0 g
s
.84057 .65347 m .83505 .6848 L .82256 .66662 L p .707 .577 .707 r
F P
0 g
s
.82256 .66662 m .82808 .63529 L .84057 .65347 L p .707 .577 .707 r
F P
0 g
s
.646 .71746 m .64741 .73654 L .64053 .74025 L p .707 .577 .707 r
F P
0 g
s
.41216 .67384 m .42468 .63779 L .39453 .62781 L p .707 .577 .707 r
F P
0 g
s
.42468 .63779 m .41216 .67384 L .44015 .6818 L p .707 .577 .707 r
F P
0 g
s
.44015 .6818 m .45267 .64575 L .42468 .63779 L p .707 .577 .707 r
F P
0 g
s
.46488 .54673 m .4778 .59919 L .49378 .58587 L p .707 .577 .707 r
F P
0 g
s
.49378 .58587 m .48086 .53342 L .46488 .54673 L p .707 .577 .707 r
F P
0 g
s
.83948 .70458 m .84088 .72366 L .82814 .72157 L p .707 .577 .707 r
F P
0 g
s
.82814 .72157 m .82674 .70249 L .83948 .70458 L p .707 .577 .707 r
F P
0 g
s
.8065 .62039 m .80087 .56303 L .822 .56208 L p .707 .577 .707 r
F P
0 g
s
.82808 .63529 m .82256 .66662 L .8017 .65047 L p .707 .577 .707 r
F P
0 g
s
.45267 .64575 m .44015 .6818 L .46325 .68696 L p .707 .577 .707 r
F P
0 g
s
.46325 .68696 m .47576 .65091 L .45267 .64575 L p .707 .577 .707 r
F P
0 g
s
.64741 .73654 m .646 .71746 L .66216 .71345 L p .707 .577 .707 r
F P
0 g
s
.39557 .73024 m .39232 .7124 L .36159 .71497 L p .707 .577 .707 r
F P
0 g
s
.39232 .7124 m .39557 .73024 L .42694 .7242 L p .707 .577 .707 r
F P
0 g
s
.42694 .7242 m .4237 .70635 L .39232 .7124 L p .707 .577 .707 r
F P
0 g
s
.66216 .71345 m .66356 .73253 L .64741 .73654 L p .707 .577 .707 r
F P
0 g
s
.4237 .70635 m .42694 .7242 L .45589 .71527 L p .707 .577 .707 r
F P
0 g
s
.45589 .71527 m .45264 .69743 L .4237 .70635 L p .707 .577 .707 r
F P
0 g
s
.36159 .71497 m .36483 .73282 L .39557 .73024 L p .707 .577 .707 r
F P
0 g
s
.36483 .73282 m .36159 .71497 L .3345 .71382 L p .707 .577 .707 r
F P
0 g
s
.48086 .53342 m .49378 .58587 L .50071 .57316 L p .707 .577 .707 r
F P
0 g
s
.50071 .57316 m .48779 .5207 L .48086 .53342 L p .707 .577 .707 r
F P
0 g
s
.45264 .69743 m .45589 .71527 L .47956 .70433 L p .707 .577 .707 r
F P
0 g
s
.47956 .70433 m .47632 .68649 L .45264 .69743 L p .707 .577 .707 r
F P
0 g
s
.3345 .71382 m .33774 .73166 L .36483 .73282 L p .707 .577 .707 r
F P
0 g
s
.82674 .70249 m .82814 .72157 L .807 .72065 L p .707 .577 .707 r
F P
0 g
s
.807 .72065 m .80559 .70157 L .82674 .70249 L p .707 .577 .707 r
F P
0 g
s
.47632 .68649 m .47956 .70433 L .49565 .69246 L p .707 .577 .707 r
F P
0 g
s
.49565 .69246 m .49241 .67462 L .47632 .68649 L p .707 .577 .707 r
F P
0 g
s
.47576 .65091 m .46325 .68696 L .47918 .68882 L p .707 .577 .707 r
F P
0 g
s
.47918 .68882 m .4917 .65277 L .47576 .65091 L p .707 .577 .707 r
F P
0 g
s
.33774 .73166 m .3345 .71382 L .31371 .70905 L p .707 .577 .707 r
F P
0 g
s
.66356 .73253 m .66216 .71345 L .68602 .70953 L p .707 .577 .707 r
F P
0 g
s
.68602 .70953 m .68742 .72861 L .66356 .73253 L p .707 .577 .707 r
F P
0 g
s
.31371 .70905 m .31695 .7269 L .33774 .73166 L p .707 .577 .707 r
F P
0 g
s
.48779 .5207 m .50071 .57316 L .49792 .56228 L p .709 .579 .707 r
F P
0 g
s
.49792 .56228 m .485 .50983 L .48779 .5207 L p .709 .579 .707 r
F P
0 g
s
.80559 .70157 m .807 .72065 L .77951 .72098 L p .707 .577 .707 r
F P
0 g
s
.77951 .72098 m .77811 .7019 L .80559 .70157 L p .707 .577 .707 r
F P
0 g
s
.4917 .65277 m .47918 .68882 L .4864 .6872 L p .707 .577 .707 r
F P
0 g
s
.4864 .6872 m .49892 .65114 L .4917 .65277 L p .707 .577 .707 r
F P
0 g
s
.68742 .72861 m .68602 .70953 L .71524 .70609 L p .707 .577 .707 r
F P
0 g
s
.71524 .70609 m .71665 .72517 L .68742 .72861 L p .707 .577 .707 r
F P
0 g
s
.31695 .7269 m .31371 .70905 L .30125 .70114 L p .707 .577 .707 r
F P
0 g
s
.49241 .67462 m .49565 .69246 L .50259 .68081 L p .707 .577 .707 r
F P
0 g
s
.50259 .68081 m .49935 .66297 L .49241 .67462 L p .707 .577 .707 r
F P
0 g
s
.77811 .7019 m .77951 .72098 L .74838 .72254 L p .707 .577 .707 r
F P
0 g
s
.74838 .72254 m .74698 .70346 L .77811 .7019 L p .707 .577 .707 r
F P
0 g
s
.30125 .70114 m .30449 .71898 L .31695 .7269 L p .707 .577 .707 r
F P
0 g
s
.71665 .72517 m .71524 .70609 L .74698 .70346 L p .707 .577 .707 r
F P
0 g
s
.74698 .70346 m .74838 .72254 L .71665 .72517 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.485 .50983 m .49792 .56228 L .48568 .55431 L p .707 .577 .707 r
F P
0 g
s
.48568 .55431 m .47275 .50186 L .485 .50983 L p .707 .577 .707 r
F P
0 g
s
.49892 .65114 m .4864 .6872 L .4842 .68225 L p .707 .577 .707 r
F P
0 g
s
.4842 .68225 m .49671 .64619 L .49892 .65114 L p .707 .577 .707 r
F P
0 g
s
.30449 .71898 m .30125 .70114 L .29835 .69086 L p .707 .577 .707 r
F P
0 g
s
.49935 .66297 m .50259 .68081 L .49968 .67052 L p .707 .577 .707 r
F P
0 g
s
.49968 .67052 m .49644 .65268 L .49935 .66297 L p .707 .577 .707 r
F P
0 g
s
.29835 .69086 m .30159 .7087 L .30449 .71898 L p .707 .577 .707 r
F P
0 g
s
.47275 .50186 m .48568 .55431 L .46518 .55003 L p .707 .577 .707 r
F P
0 g
s
.46518 .55003 m .45226 .49758 L .47275 .50186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30159 .7087 m .29835 .69086 L .30528 .67921 L p .707 .577 .707 r
F P
0 g
s
.49671 .64619 m .4842 .68225 L .47279 .67446 L p .707 .577 .707 r
F P
0 g
s
.47279 .67446 m .4853 .6384 L .49671 .64619 L p .707 .577 .707 r
F P
0 g
s
.49644 .65268 m .49968 .67052 L .48723 .66261 L p .707 .577 .707 r
F P
0 g
s
.48723 .66261 m .48399 .64477 L .49644 .65268 L p .707 .577 .707 r
F P
0 g
s
.30528 .67921 m .30852 .69705 L .30159 .7087 L p .707 .577 .707 r
F P
0 g
s
.32492 .58476 m .312 .53231 L .33546 .5197 L p .707 .577 .707 r
F P
0 g
s
.32953 .58344 m .31701 .6195 L .30108 .61764 L p .707 .577 .707 r
F P
0 g
s
.45226 .49758 m .46518 .55003 L .43843 .54985 L p .707 .577 .707 r
F P
0 g
s
.43843 .54985 m .42551 .4974 L .45226 .49758 L p .707 .577 .707 r
F P
0 g
s
.30852 .69705 m .30528 .67921 L .32137 .66733 L p .707 .577 .707 r
F P
0 g
s
.4853 .6384 m .47279 .67446 L .45328 .66459 L p .707 .577 .707 r
F P
0 g
s
.45328 .66459 m .4658 .62854 L .4853 .6384 L p .707 .577 .707 r
F P
0 g
s
.34838 .57215 m .33546 .5197 L .36411 .50903 L p .707 .577 .707 r
F P
0 g
s
.33546 .5197 m .34838 .57215 L .32492 .58476 L p .707 .577 .707 r
F P
0 g
s
.42551 .4974 m .43843 .54985 L .40806 .5538 L p .707 .577 .707 r
F P
0 g
s
.40806 .5538 m .39514 .50135 L .42551 .4974 L p .707 .577 .707 r
F P
0 g
s
.48399 .64477 m .48723 .66261 L .46644 .65785 L p .707 .577 .707 r
F P
0 g
s
.46644 .65785 m .46319 .64 L .48399 .64477 L p .707 .577 .707 r
F P
0 g
s
.32137 .66733 m .32461 .68518 L .30852 .69705 L p .707 .577 .707 r
F P
0 g
s
.31701 .6195 m .32953 .58344 L .35262 .5886 L p .707 .577 .707 r
F P
0 g
s
.37703 .56149 m .36411 .50903 L .39514 .50135 L p .707 .577 .707 r
F P
0 g
s
.36411 .50903 m .37703 .56149 L .34838 .57215 L p .707 .577 .707 r
F P
0 g
s
.39514 .50135 m .40806 .5538 L .37703 .56149 L p .707 .577 .707 r
F P
0 g
s
.35262 .5886 m .34011 .62466 L .31701 .6195 L p .707 .577 .707 r
F P
0 g
s
.4658 .62854 m .45328 .66459 L .4276 .65361 L p .707 .577 .707 r
F P
0 g
s
.4276 .65361 m .44011 .61756 L .4658 .62854 L p .707 .577 .707 r
F P
0 g
s
.32461 .68518 m .32137 .66733 L .34505 .6564 L p .707 .577 .707 r
F P
0 g
s
.34011 .62466 m .35262 .5886 L .38061 .59656 L p .707 .577 .707 r
F P
0 g
s
.46319 .64 m .46644 .65785 L .43935 .65669 L p .707 .577 .707 r
F P
0 g
s
.43935 .65669 m .4361 .63885 L .46319 .64 L p .707 .577 .707 r
F P
0 g
s
.34505 .6564 m .34829 .67424 L .32461 .68518 L p .707 .577 .707 r
F P
0 g
s
.38061 .59656 m .3681 .63262 L .34011 .62466 L p .707 .577 .707 r
F P
0 g
s
.44011 .61756 m .4276 .65361 L .39824 .64259 L p .707 .577 .707 r
F P
0 g
s
.39824 .64259 m .41076 .60654 L .44011 .61756 L p .707 .577 .707 r
F P
0 g
s
.3681 .63262 m .38061 .59656 L .41076 .60654 L p .707 .577 .707 r
F P
0 g
s
.34829 .67424 m .34505 .6564 L .37399 .64747 L p .707 .577 .707 r
F P
0 g
s
.41076 .60654 m .39824 .64259 L .3681 .63262 L p .707 .577 .707 r
F P
0 g
s
.4361 .63885 m .43935 .65669 L .40861 .65926 L p .707 .577 .707 r
F P
0 g
s
.40861 .65926 m .40537 .64142 L .4361 .63885 L p .707 .577 .707 r
F P
0 g
s
.37399 .64747 m .37723 .66531 L .34829 .67424 L p .707 .577 .707 r
F P
0 g
s
.37723 .66531 m .37399 .64747 L .40537 .64142 L p .707 .577 .707 r
F P
0 g
s
.40537 .64142 m .40861 .65926 L .37723 .66531 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH015YF3`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH70003FUH00`00FUIJEP05FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo1@001UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0065oo`<000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo
0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GGoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001KOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Qoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`8000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
EWoo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP03001JEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF1P0025YF0P000UYF
00<005YFFUH0100000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH010001EYF00<005YFFUH015YF0P001EYF00<005YFFUH00UYF10000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF20001EYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0002moo`L002moo`00DWoo00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEPD000AJEP03001JEUYF00800003FUH005YF00IJEP03001JEUYF
009JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000POol?0002FUH01000FUIJEUYF0P00;Woo001BOol200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUH000020006FUH50004FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000GOol90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
001BOol200000eYF001JEP04FUH00`00FUIJEP05FUH300000eYF001JEP05FUH90007FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool0059oo`80009JEP03001JEUYF009JEP03001JEUYF00=JEP80009o
o`03001JEP0000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Woo
200035YF00=oo`00FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
Dgoo00@005YFFUH000AJEP04001JEUYFFUH20004Ool00`00FUH000070007FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo1@005EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0P000UYF0P00;Woo0010Ool8000;Ool200000eYF001JEP04FUH<0004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP00FUH05eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000jOol60003FUH00`00FUIJ
EP02FUH70004Ool200000eYF001JEP04FUH200000eYF000000030009FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0FFUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00H0009JEP04001JEUYFFUH20006FUH30007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF01IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Woo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF0P000eYF00<005YFFUH01EYF00<005YF
00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH05UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH025YF0P000eYF00<005YFFUH0
15YF00<005YFFUH015YF10002EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0=FUH0
1@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000aOol200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00006
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000`Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00<0
05YFFUH01UYF00@005YF000000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP8002eoo`00;goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P0025YF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0P00;Goo000_Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002io
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH0
1@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YF0000009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH?000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP020002FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH:000^Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000=JEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH01@00FUIJEUYF0000=7oo000^Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000UYF00<005YF
FUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01UYF0`002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF1`001eYF200015YF
00@005YFFUIoo`AJEP03001JEUYF009JEP80039oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P000eYF40001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP80009JEP8000MJEP03001JEUYF009JEPT0009oo`<00003FUH005YF00IJ
EP03001JEUYF00AJEP03001oogoo02moo`00;Goo00<005YF00000eYF00<005YFFUH00UYF1P003goo
10000UYF00<005YFFUH015YF0`0025YF00<005YFFUH01EYF0`0000=JEP00FUH01EYF1`0015YF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00H005YF000005YF0004FUH8000>Ool20007FUH00`00FUIJEP04FUH2000`
Ool002eoo`03001JEP0000=JEP03001JEP00008001Uoo`@000IJEP<000MJEP03001JEUYF00IJEP03
001JEP0000L000=JEP04001JEUYFFUH70003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH:000HOol20004FUH00`00FUIJEP05FUH2000`Ool0
02eoo`8000AJEP80021oo`8000AJEP03001JEUYF008000EJEP03001JEUYF00EJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0009JEP80009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001oogoo029oo`<00003FUH005YF00EJ
EP04001JEUYF000_Ool002eoo`80009JEP8002Aoo`<00003FUH005YF00=JEP<00003FUH005YF00=J
EP@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000XOol20006FUH01000FUIJEP00
;goo000]Ool400000eYF001oo`0DOol3000?Ool20005FUH00`00FUH0000500000eYF001JEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000/Ool00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo000]Ool20003FUH3000BOol5000@Ool20003FUH40005FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00;Goo00=JEP00FUH00UYF00@005YFFUH0015oo`D0019oo`<00003FUH005YF00MJEP03001J
EUYF00AJEPL000AJEP800003FUH0000000D000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002000/Ool200000eYF001JEP03
FUH00`00Oomoo`0/Ool002aoo`8000AJEP04001JEUYFFUH2000?Ool5000AOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH30006FUH40003FUH00`00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@002Yoo`8000AJEP03001o
ogoo02aoo`00;7oo0P0015YF00<005YFFUH00eYF0P003Woo0`0047oo0P001UYF00<005YFFUH015YF
1`001EYF00<005YFFUH01EYF00<005YFFUH00P0015YF00@005YFFUIJEP800004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P001EYF0P004Goo0`005Goo00<0
05YFFUH00UYF0P00;Goo000/Ool00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH00003000LOol2
0007FUH00`00FUIJEP040004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH500000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP00009JEP03001JEUYF00=JEP<000ioo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00
FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP03FUH5000EOol200000eYF001JEP05FUH400000eYF
001JEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP04FUH20003FUH20002FUH00`00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP03
001JEUYF008000aoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00QJEP@0011oo`03001JEUYF009JEP04001JEUYFFUH20002FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P000UYF00<005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH01@00FUIJEUYF
00001EYF0P002Woo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH035YF40001EYF00<005YF00000P0015YF00<005YF00001UYF10001EYF00@005YF
FUIJEP@000EJEP04001JEUYFFUH200001eYF001JEUYF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF00000eYF0P000UYF00<005YFFUH015YF0`002Goo0`0067oo0P00
00=JEP00Ool0;7oo000]Ool01@00FUIJEUYF00001UYF00<005YFFUH06UYF0P001EYF0P000UYF00@0
05YFOomJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<00003
FUH00000009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEUYF009JEP05001JEP00FUH00005FUH20002FUH2000SOol00`00FUH0000]Ool002eoo`05001J
EUYFFUH00006FUH00`00FUIJEP04FUH00`00FUIJEP0CFUH20004FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH025YF2@0000=JEP0000000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0P001EYF00<005YFFUH00UYF00<007ooOol08Goo0P00;Woo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00@005YFFUIoo`EJEP03001JEUYF00UJEP05001JEUYF001JEP020005FUH00`00FUH00003
00000eYF001JEP05FUH50004FUH00`00FUIJEP09FUH300000eYF001JEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000QOol3000^Ool002moo`03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00/00006FUH00000001JEP00
1UYF10001EYF00<005YFFUH025YF0P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP80009JEP07001J
EUYFFUH005YF000087oo00@005YF000002ioo`00<7oo0P001EYF00<005YFFUH01EYF00D005YFFUIJ
EWoo00AJEP04001JEUYFFUH90002FUH20006FUH5000015YF001JEP001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`001UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YF001JEP0000IJEP03001JEP00008000=JEP80021oo`03001JEUYF
008002ioo`00<Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH00UYF00<005YF00001UYF00<005YFFUH01UYF
00@005YFFUIJEP@00003FUH005YF00IJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEP00FUH00006FUH01000FUIJEUYF0`0000=JEP0000003goo
4`0000=JEP000000;Woo000bOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00AJEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEP00008002ioo`00<goo0P000UYF00@005YFFUIJEPH000IJEP03001JEUYF
00IJEPH0009JEP@000IJEP06001JEUYF001JEP001UYF00@005YFFUIJEP@0009JEP03001JEUYF00IJ
EP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF00001EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01P000eYF00@005YF0000009JEP03001JEUYF00L0009JEP03001JEP0000=JEPL000IJEP03001J
EUYF00IJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000bOol300000eYF001JEP06
FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUH00002FUH00`00FUIJEP03FUH01000FUIJ
EUYF200015YF00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002moo`<000AJEP8000IJEP@00004FUH000000005FUH00`00FUIJEP06FUH00`00FUH0
0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP040003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000eYF00D005YFFUIJEP0002eoo`00;7oo4P0015YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00AJEPD000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ8000IJEPP002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00@005YFFUIJ
EQ<000AJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00D0
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP@000EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP<00003FUH005YF00EJEP03001J
EUYF009JEPL000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH01000FUIJEUYF200025YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF0`00;Woo000]Ool00`00FUH00003FUH0
0`00FUH0000300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF
00<005YF000030000UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000=JEP<0
00UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPH0035oo`00;Goo00<005YF0000
0eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009J
EP04001JEUYFFUH500000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000
00001EYF00<005YFFUH00eYF0`001UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
03Moo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEUYF00EJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00000iOol002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHA0004FUH00`00
FUIJEP06FUH30006Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP02FUH5000kOol002eoo`8000=JEP03001JEUYF00=J
EPH000EJEP03001JEUYF00IJEP03001JEUYF00H000MJEP03001JEUYF008000Aoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000@00003FUH0000000h000Moo`T0041oo`00;Goo0P000eYF00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0017oo0P0015YF00<005YFFUH00eYF
0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<0
05YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000017oo0`000eYF1000
0UYF00<007ooOol0DWoo000]Ool20003FUH30006FUH00`00FUIJEP02FUH8000?Ool300001EYF001J
EUYFOol00eYF0P0000Aoo`00FUH000IJEP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEPH000IJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP04001JEUYF
001DOol002aoo`03001JEP00009JEP04001JEUYF0003FUH8000JOol20006FUH2000017oo001JEP00
1EYF10000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00eYF10000UYF00<005YFFUH00UYF00<005YF00000goo00D005YFFUIJEP0000EJEP04001J
EUYF001DOol002aoo`03001JEP0000T002Aoo`8000=JEP03001JEUYF00800003FUH005YF009JEP80
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP<000AJEP04001JEP00Ool20004FUH00`00FUIJEP03FUH00`00FUH0001EOol002aoo`03001J
EP0002moo`800003FUH005YF009JEP04001JEP00FUH30008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH01000FUH0
00001eYF00<005YFFUH00eYF0P00EGoo000/Ool2000bOol20003FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF00<005YFFUH00eYF00<007ooOol0E7oo000/
Ool2000JOol3000GOol00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000015YF
001JEP001eYF00D005YFFUIJEP0005Moo`00;7oo0`0067oo1@005goo00@005YF000000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP800004FUH005YF0007FUH01000FUIJEP00F7oo000/Ool200000eYF
001oo`0FOol5000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000QJ
EP8005Uoo`00;7oo0P000UYF00<007ooOol057oo1@006Goo0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00Oomoo`1HOol002eoo`05001JEUYFFUH0000FOol3000J
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF0P00
Fgoo000]Ool01000FUIJEUYF0`00<7oo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000eYF00<005YFFUH00UYF00<007ooOol0Fgoo000^Ool01000FUIJEP000UYF0P00;Goo0P0000=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00D005YFFUIJEP0005ioo`00;Woo
00<005YF00001EYF0`00:7oo0P0000=JEP00FUH00`000UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
0P0000=JEP0000001@00Ggoo000_Ool20006FUH01000FUH0000097oo0P000eYF0P000goo0`0025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP800003FUH005YF00AJEP<005moo`00<7oo00<005YFFUH015YF00@005YFFUIJEP<0
01moo`800003FUH005YF009JEP8000Eoo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP06FUH3001M
Ool0035oo`8000=JEP03001JEUYF00EJEPD001Qoo`8000=JEP05001JEUYFFUH00008Ool30004FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
0004FUH00`00FUIJEP06FUH00`00FUIJEP02001KOol003=oo`800003FUH005YF00MJEP04001JEUYF
FUH90009Ool60004FUH00`00FUIJEP02000<Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP060003FUH60006FUH00`00FUIJEP03FUH2001IOol0
03Eoo`<000MJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00=JEP<0015oo`@0
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009JEPD000AJEP<00003Ool0
000000AJEP03001JEUYF00AJEP<005Moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P005goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000MJEPD0009JEP8000Ioo`<00003FUH005YF00EJEP04001JEUYF001FOol003Yo
o`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<001mooal000EJ
EP03001JEUYF00EJEPL000]oo`<000AJEP05001JEUYFFUH0001FOol003eoo`H000AJEP03001JEUYF
00IJEP03001JEUYF009JEPD003Uoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0015oo`<0
0003FUH005YF009JEP8005Eoo`00@goo4P00@7oo0`000eYF00<005YFFUH015YF00<005YFFUH01@00
0eYF2@002goo0P000UYF00<005YF0000EGoo002HOol=0003FUH20007FUH00`00FUIJEP02FUH@0000
0eYF001oo`1DOol009]oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8005Ioo`00WWoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00Y7oo1`001UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF0000EWoo002[Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH2001GOol00:mooaH005Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59194 .73798 m .60486 .68261 L .57449 .6745 L p .707 .577 .707 r
F P
0 g
s
.60486 .68261 m .59194 .73798 L .62297 .74451 L p .707 .577 .707 r
F P
0 g
s
.62297 .74451 m .63589 .68913 L .60486 .68261 L p .707 .577 .707 r
F P
0 g
s
.63589 .68913 m .62297 .74451 L .65162 .74881 L p .707 .577 .707 r
F P
0 g
s
.65162 .74881 m .66454 .69343 L .63589 .68913 L p .707 .577 .707 r
F P
0 g
s
.56156 .72987 m .57449 .6745 L .54774 .66559 L p .707 .577 .707 r
F P
0 g
s
.57449 .6745 m .56156 .72987 L .59194 .73798 L p .707 .577 .707 r
F P
0 g
s
.54774 .66559 m .53482 .72097 L .56156 .72987 L p .707 .577 .707 r
F P
0 g
s
.66454 .69343 m .65162 .74881 L .67508 .75046 L p .707 .577 .707 r
F P
0 g
s
.67508 .75046 m .688 .69508 L .66454 .69343 L p .707 .577 .707 r
F P
0 g
s
.53482 .72097 m .54774 .66559 L .52724 .65677 L p .707 .577 .707 r
F P
0 g
s
.6319 .81338 m .61939 .78005 L .58924 .79049 L p .707 .577 .707 r
F P
0 g
s
.61939 .78005 m .6319 .81338 L .65989 .79973 L p .707 .577 .707 r
F P
0 g
s
.65989 .79973 m .64738 .76639 L .61939 .78005 L p .707 .577 .707 r
F P
0 g
s
.60175 .82382 m .58924 .79049 L .55989 .79669 L p .707 .577 .707 r
F P
0 g
s
.58924 .79049 m .60175 .82382 L .6319 .81338 L p .707 .577 .707 r
F P
0 g
s
.64738 .76639 m .65989 .79973 L .68298 .7842 L p .707 .577 .707 r
F P
0 g
s
.68298 .7842 m .67047 .75086 L .64738 .76639 L p .707 .577 .707 r
F P
0 g
s
.52724 .65677 m .51432 .71215 L .53482 .72097 L p .707 .577 .707 r
F P
0 g
s
.59139 .84379 m .59368 .83066 L p .56389 .81866 L .707 .577 .707 r
F P
0 g
s
.5853 .82322 m .56389 .81866 L p .59368 .83066 L .707 .577 .707 r
F P
0 g
s
.56389 .81866 m .56065 .83725 L .59139 .84379 L p .707 .577 .707 r
F P
0 g
s
.56065 .83725 m .56237 .82737 L p .5368 .8109 L .707 .577 .707 r
F P
0 g
s
.56237 .82737 m .56389 .81866 L .54945 .81453 L p .707 .577 .707 r
F P
0 g
s
.54945 .81453 m .5368 .8109 L p .56237 .82737 L .707 .577 .707 r
F P
0 g
s
.5368 .8109 m .53356 .82948 L .56065 .83725 L p .707 .577 .707 r
F P
0 g
s
.53356 .82948 m .5368 .8109 L .51601 .80267 L p .707 .577 .707 r
F P
0 g
s
.54672 .83139 m .53498 .80014 L p .5147 .79444 L .707 .577 .707 r
F P
0 g
s
.53498 .80014 m .5342 .79806 L .53258 .79776 L p .707 .577 .707 r
F P
0 g
s
.53258 .79776 m .5147 .79444 L p .53498 .80014 L .707 .577 .707 r
F P
0 g
s
.5724 .83003 m .56213 .80267 L p .5342 .79806 L .707 .577 .707 r
F P
0 g
s
.56213 .80267 m .55989 .79669 L .55564 .79692 L p .707 .577 .707 r
F P
0 g
s
.55564 .79692 m .5342 .79806 L p .56213 .80267 L .707 .577 .707 r
F P
0 g
s
.59368 .83066 m .59463 .82521 L .5853 .82322 L p .707 .577 .707 r
F P
0 g
s
.59463 .82521 m .59139 .84379 L .62276 .84847 L p .707 .577 .707 r
F P
0 g
s
.62276 .84847 m .62601 .82989 L .59463 .82521 L p .707 .577 .707 r
F P
0 g
s
.55989 .79669 m .5724 .83003 L .60175 .82382 L p .707 .577 .707 r
F P
0 g
s
.62601 .82989 m .62276 .84847 L .65171 .85083 L p .707 .577 .707 r
F P
0 g
s
.65171 .85083 m .65495 .83224 L .62601 .82989 L p .707 .577 .707 r
F P
0 g
s
.688 .69508 m .67508 .75046 L .68325 .74987 L p .707 .577 .707 r
F P
0 g
s
.69082 .74507 m .688 .69508 L .68406 .74058 L .707 .577 .707 r
F
.69031 .74539 m .68406 .74058 L .68325 .74987 L F
.69082 .74507 m .68406 .74058 L .69031 .74539 L F
.69892 .76832 m .70474 .75648 L p .69172 .74647 L F P
0 g
s
.69031 .74539 m .69105 .74735 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69105 .74735 m .69892 .76832 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69898 .7369 m .69915 .7355 L .69172 .74647 L .707 .577 .707 r
F
.70398 .69393 m .69553 .73015 L p .69915 .7355 L F P
0 g
s
.69553 .73015 m .69172 .74647 L p .69915 .7355 L .707 .577 .707 r
F P
0 g
s
.69892 .76832 m .69031 .74539 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69106 .74931 m .70398 .69393 L .688 .69508 L p .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .70419 .74296 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .70016 .7377 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.70016 .7377 m .70614 .75363 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69362 .72029 m .68641 .73498 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .69957 .73613 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.69985 .73576 m .69943 .73309 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .69362 .72029 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69985 .73576 L p .69799 .74546 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .69985 .73576 L .69898 .7369 L .707 .577 .707 r
F
.70071 .72202 m .71091 .69009 L .70398 .69393 L p F P
0 g
s
.69362 .72029 m .69681 .72877 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69681 .72877 m .69957 .73613 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69868 .72838 m .69947 .72593 L .70001 .73679 L .707 .577 .707 r
F
.70358 .72151 m .70001 .73679 L p .69947 .72593 L F P
0 g
s
.70812 .68392 m .71091 .69009 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.69999 .73666 m .69742 .72812 L .69957 .73613 L .707 .577 .707 r
F
.69924 .73188 m .69742 .72812 L .69999 .73666 L F
.6983 .72599 m .70812 .68392 L p .69868 .72838 L F P
0 g
s
.69142 .70824 m .69362 .72029 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .699 .72843 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .69142 .70824 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.69142 .70824 m .69846 .72701 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.6952 .7393 m .68295 .73142 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69457 .7249 L .6952 .7393 L .707 .577 .707 r
F
.69206 .7229 m .69142 .70824 L .69793 .72758 L F
.69793 .72758 m .6952 .7393 L p .69457 .7249 L F P
0 g
s
.69255 .73336 m .69252 .73334 L p .69846 .72701 L .707 .577 .707 r
F P
0 g
s
.6983 .72599 m .69793 .72758 L p .69394 .71068 L .707 .577 .707 r
F P
0 g
s
.69394 .71068 m .69793 .72758 L .69457 .7249 L .707 .577 .707 r
F
.6952 .7393 m .6983 .72599 L p .69868 .72838 L F P
0 g
s
.70394 .74158 m .69924 .73188 L .69999 .73666 L .707 .577 .707 r
F
.68325 .74987 m .69106 .74931 L p .69086 .74581 L F P
0 g
s
.69086 .74581 m .69082 .74507 L .69031 .74539 L .707 .577 .707 r
F
.69086 .74581 m .69031 .74539 L .68325 .74987 L F
.68641 .73498 m .69031 .74539 L p .69191 .74622 L F P
0 g
s
.70614 .75363 m .69458 .7427 L .69191 .74622 L .707 .577 .707 r
F
.69458 .7427 m .68641 .73498 L .69191 .74622 L F
.70474 .75648 m .70614 .75363 L p .69031 .74539 L F P
0 g
s
.69106 .74931 m .69799 .74546 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69172 .74647 m .69106 .74931 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .6952 .7393 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70419 .74296 m .70394 .74158 L p .69957 .73613 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69799 .74546 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .69255 .73336 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69846 .72701 m .699 .72843 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .70394 .74158 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .69206 .7229 L .69793 .72758 L .707 .577 .707 r
F
.68001 .7 m .69142 .70824 L p .69206 .7229 L F P
0 g
s
.68295 .73142 m .68569 .71969 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68001 .7 m .68713 .71897 L p .68569 .71969 L .707 .577 .707 r
F P
0 g
s
.68295 .73142 m .66246 .7226 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68295 .73142 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.67401 .72551 m .67619 .71625 L .68569 .71969 L .707 .577 .707 r
F
.67619 .71625 m .68001 .7 L .68569 .71969 L F
.68713 .71897 m .68001 .7 L p .69206 .7229 L F P
0 g
s
.6605 .69639 m .68001 .7 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .66449 .71388 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.6605 .69639 m .66667 .71281 L p .66449 .71388 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .63571 .7137 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66246 .7226 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.65143 .72031 m .65458 .71201 L .66449 .71388 L .707 .577 .707 r
F
.65458 .71201 m .6605 .69639 L .66449 .71388 L F
.66667 .71281 m .6605 .69639 L p .67619 .71625 L F P
0 g
s
.63482 .69776 m .6605 .69639 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.63571 .7137 m .63639 .71079 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63482 .69776 m .63907 .70908 L p .63639 .71079 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63571 .7137 L .61845 .70909 L p .707 .577 .707 r
F P
0 g
s
.62661 .71703 m .62954 .71014 L .63639 .71079 L .707 .577 .707 r
F
.62954 .71014 m .63482 .69776 L .63639 .71079 L F
.63907 .70908 m .63482 .69776 L p .65458 .71201 L F P
0 g
s
.60547 .70396 m .63482 .69776 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .60825 .71137 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.60825 .71137 m .60547 .70396 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .58783 .74774 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60547 .70396 m .60698 .708 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60698 .708 m .61798 .7373 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .64681 .66611 L p .60534 .70559 L .707 .577 .707 r
F P
0 g
s
.64681 .66611 m .63639 .71079 L p .60873 .70616 L .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .64681 .66611 L .60873 .70616 L .707 .577 .707 r
F
.58783 .74774 m .57532 .7144 L .60547 .70396 L p F P
0 g
s
.61826 .65021 m .60534 .70559 L .60204 .7049 L p .707 .577 .707 r
F P
0 g
s
.60204 .7049 m .57431 .69906 L p .58503 .68714 L .707 .577 .707 r
F P
0 g
s
.58503 .68714 m .61826 .65021 L .60204 .7049 L .707 .577 .707 r
F
.61845 .70909 m .60534 .70559 L p .63639 .71079 L F P
0 g
s
.63639 .71079 m .63688 .70867 L p .63907 .70908 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63907 .70908 L .63957 .70918 L .707 .577 .707 r
F
.64733 .7311 m .61798 .7373 L p .62661 .71703 L F P
0 g
s
.63907 .70908 m .64733 .7311 L p .62661 .71703 L .707 .577 .707 r
F P
0 g
s
.64733 .7311 m .63907 .70908 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .67538 .66722 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63688 .70867 m .64863 .65832 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .66449 .71388 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66489 .71217 L p .66667 .71281 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66667 .71281 L .6689 .71362 L .707 .577 .707 r
F
.67302 .72973 m .64733 .7311 L p .65143 .72031 L F P
0 g
s
.66667 .71281 m .67302 .72973 L p .65143 .72031 L .707 .577 .707 r
F P
0 g
s
.67302 .72973 m .66667 .71281 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .69588 .67604 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.66489 .71217 m .67538 .66722 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .68569 .71969 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68606 .71812 L p .68713 .71897 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68713 .71897 L .68883 .72033 L .707 .577 .707 r
F
.69252 .73334 m .67302 .72973 L p .67401 .72551 L F P
0 g
s
.68713 .71897 m .69252 .73334 L p .67401 .72551 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .68713 .71897 L p .69206 .7229 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .70812 .68392 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68606 .71812 m .69588 .67604 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69394 .71068 L .69457 .7249 L .707 .577 .707 r
F
.70812 .68392 m .6983 .72599 L p .69394 .71068 L F P
0 g
s
.71091 .69009 m .70358 .72151 L p .69947 .72593 L .707 .577 .707 r
F P
0 g
s
.68641 .73498 m .67047 .75086 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69031 .74539 m .68641 .73498 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.51432 .71215 m .52724 .65677 L .515 .64889 L p .707 .577 .707 r
F P
0 g
s
.67047 .75086 m .68298 .7842 L .69892 .76832 L p .707 .577 .707 r
F P
0 g
s
.5342 .79806 m .54672 .83139 L .5724 .83003 L p .707 .577 .707 r
F P
0 g
s
.65495 .83224 m .65171 .85083 L .67538 .85063 L p .707 .577 .707 r
F P
0 g
s
.67538 .85063 m .67862 .83205 L .65495 .83224 L p .707 .577 .707 r
F P
0 g
s
.515 .64889 m .50208 .70427 L .51432 .71215 L p .707 .577 .707 r
F P
0 g
s
.51601 .80267 m .51277 .82125 L .53356 .82948 L p .707 .577 .707 r
F P
0 g
s
.5147 .79444 m .52721 .82778 L .54672 .83139 L p .707 .577 .707 r
F P
0 g
s
.50208 .70427 m .515 .64889 L .51221 .64273 L p .707 .577 .707 r
F P
0 g
s
.67862 .83205 m .67538 .85063 L .69147 .84791 L p .707 .577 .707 r
F P
0 g
s
.69147 .84791 m .69472 .82932 L .67862 .83205 L p .707 .577 .707 r
F P
0 g
s
.51277 .82125 m .51601 .80267 L .50356 .79478 L p .707 .577 .707 r
F P
0 g
s
.52721 .82778 m .5147 .79444 L .50328 .78621 L p .707 .577 .707 r
F P
0 g
s
.51221 .64273 m .49929 .69811 L .50208 .70427 L p .707 .577 .707 r
F P
0 g
s
.50356 .79478 m .50031 .81337 L .51277 .82125 L p .707 .577 .707 r
F P
0 g
s
.50328 .78621 m .5158 .81955 L .52721 .82778 L p .707 .577 .707 r
F P
0 g
s
.49323 .82188 m .49323 .31999 L .44904 .31754 L p .707 .577 .707 r
F P
0 g
s
.49929 .69811 m .51221 .64273 L .51914 .63888 L p .707 .577 .707 r
F P
0 g
s
.50031 .81337 m .50356 .79478 L .50065 .78801 L p .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50328 .78621 L .50162 .7771 L p .707 .577 .707 r
F P
0 g
s
.50162 .7771 m .50108 .77416 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50162 .7771 L .50245 .77838 L .707 .577 .707 r
F
.50065 .78801 m .49741 .8066 L .50031 .81337 L p F P
0 g
s
.5136 .8075 m .5158 .81955 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50108 .77416 m .50296 .77918 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50296 .77918 m .5136 .8075 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5136 .8075 m .50108 .77416 L .5083 .75947 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .49741 .8066 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50759 .78302 m .50713 .78562 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50713 .78562 m .50434 .8016 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50065 .78801 L .50613 .78407 L p .707 .577 .707 r
F P
0 g
s
.50613 .78407 m .50759 .78302 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50613 .78407 L .50673 .785 L .707 .577 .707 r
F
.51914 .63888 m .50622 .69426 L .49929 .69811 L p F P
0 g
s
.50622 .69426 m .51914 .63888 L .53512 .63773 L p .707 .577 .707 r
F P
0 g
s
.53512 .63773 m .5222 .69311 L .50622 .69426 L p .707 .577 .707 r
F P
0 g
s
.5083 .75947 m .52081 .79281 L .5136 .8075 L p .707 .577 .707 r
F P
0 g
s
.5222 .69311 m .53512 .63773 L .55858 .63939 L p .707 .577 .707 r
F P
0 g
s
.52081 .79281 m .5083 .75947 L .52423 .74359 L p .707 .577 .707 r
F P
0 g
s
.52423 .74359 m .53675 .77693 L .52081 .79281 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .50759 .78302 L .52368 .78029 L p .707 .577 .707 r
F P
0 g
s
.55858 .63939 m .54566 .69476 L .5222 .69311 L p .707 .577 .707 r
F P
0 g
s
.52368 .78029 m .52044 .79887 L .50434 .8016 L p .707 .577 .707 r
F P
0 g
s
.53675 .77693 m .52423 .74359 L .54733 .72806 L p .707 .577 .707 r
F P
0 g
s
.52044 .79887 m .52368 .78029 L .54735 .78009 L p .707 .577 .707 r
F P
0 g
s
.54735 .78009 m .54411 .79868 L .52044 .79887 L p .707 .577 .707 r
F P
0 g
s
.49323 .31999 m .49323 .82188 L .53809 .82055 L p .707 .577 .707 r
F P
0 g
s
.54733 .72806 m .55984 .7614 L .53675 .77693 L p .707 .577 .707 r
F P
0 g
s
.53809 .82055 m .53809 .31866 L .49323 .31999 L p .707 .577 .707 r
F P
0 g
s
.69472 .82932 m .69147 .84791 L .69841 .84291 L p .707 .577 .707 r
F P
0 g
s
.69841 .84291 m .70165 .82433 L .69472 .82932 L p .707 .577 .707 r
F P
0 g
s
.54566 .69476 m .55858 .63939 L .58723 .64369 L p .707 .577 .707 r
F P
0 g
s
.58723 .64369 m .57431 .69906 L .54566 .69476 L p .707 .577 .707 r
F P
0 g
s
.55984 .7614 m .54733 .72806 L .57532 .7144 L p .707 .577 .707 r
F P
0 g
s
.57532 .7144 m .58783 .74774 L .55984 .7614 L p .707 .577 .707 r
F P
0 g
s
.54411 .79868 m .54735 .78009 L .5763 .78245 L p .707 .577 .707 r
F P
0 g
s
.5763 .78245 m .57305 .80104 L .54411 .79868 L p .707 .577 .707 r
F P
0 g
s
.57305 .80104 m .5763 .78245 L .60767 .78713 L p .707 .577 .707 r
F P
0 g
s
.60767 .78713 m .60443 .80572 L .57305 .80104 L p .707 .577 .707 r
F P
0 g
s
.53809 .31866 m .53809 .82055 L .57922 .81556 L p .707 .577 .707 r
F P
0 g
s
.57431 .69906 m .58723 .64369 L .61826 .65021 L p .707 .577 .707 r
F P
0 g
s
.57922 .81556 m .57922 .31368 L .53809 .31866 L p .707 .577 .707 r
F P
0 g
s
.44904 .81943 m .44904 .31754 L .40983 .31154 L p .707 .577 .707 r
F P
0 g
s
.44904 .31754 m .44904 .81943 L .49323 .82188 L p .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .61826 .65021 L .64863 .65832 L p .707 .577 .707 r
F P
0 g
s
.63841 .79367 m .63517 .81226 L .60443 .80572 L p .707 .577 .707 r
F P
0 g
s
.60443 .80572 m .60767 .78713 L .63841 .79367 L p .707 .577 .707 r
F P
0 g
s
.57922 .31368 m .57922 .81556 L .61259 .80741 L p .707 .577 .707 r
F P
0 g
s
.61259 .80741 m .61259 .30552 L .57922 .31368 L p .707 .577 .707 r
F P
0 g
s
.40983 .81343 m .40983 .31154 L .37945 .30259 L p .707 .577 .707 r
F P
0 g
s
.40983 .31154 m .40983 .81343 L .44904 .81943 L p .707 .577 .707 r
F P
0 g
s
.25765 .68094 m .22657 .675 L p .2463 .71874 L .707 .577 .707 r
F P
0 g
s
.24811 .72276 m .24871 .72012 L .2463 .71874 L .707 .577 .707 r
F
.24871 .72012 m .25765 .68094 L .2463 .71874 L F
.25297 .72295 m .25765 .68094 L p .24811 .72276 L F P
0 g
s
.28785 .7367 m .27163 .72196 L .25372 .72298 L .707 .577 .707 r
F
.25372 .72298 m .25634 .74107 L .27967 .73783 L p F P
0 g
s
.27967 .73783 m .28785 .7367 L p .25372 .72298 L .707 .577 .707 r
F P
0 g
s
.25634 .74107 m .25372 .72298 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.24284 .72879 m .25297 .72295 L .23567 .72226 L .707 .577 .707 r
F
.25634 .74107 m .25297 .72295 L .24284 .72879 L F
.25366 .72256 m .25372 .72298 L p .27163 .72196 L F P
0 g
s
.25301 .72258 m .25297 .72295 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .25634 .74107 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .22549 .74597 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22657 .675 m .19913 .66493 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .22205 .72225 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22197 .72171 L p .22132 .72216 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22132 .72216 L .20984 .73015 L .707 .577 .707 r
F
.19913 .66493 m .1935 .71543 L .20683 .72031 L p F P
0 g
s
.20984 .73015 m .21392 .72122 L .19914 .71933 L .707 .577 .707 r
F
.21967 .72195 m .19913 .66493 L .20683 .72031 L F
.22132 .72216 m .22657 .675 L p .21967 .72195 L F P
0 g
s
.22657 .675 m .22137 .72169 L p .22197 .72171 L .707 .577 .707 r
F P
0 g
s
.22137 .72169 m .22095 .72549 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .21997 .70797 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.20683 .72031 m .22095 .72549 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22095 .72549 m .22132 .72216 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.1935 .71543 m .19913 .66493 L .178 .65173 L p .707 .577 .707 r
F P
0 g
s
.178 .65173 m .17398 .6878 L p .1935 .71543 L .707 .577 .707 r
F P
0 g
s
.17398 .6878 m .17237 .70222 L .18972 .71306 L p .707 .577 .707 r
F P
0 g
s
.18972 .71306 m .1935 .71543 L p .17398 .6878 L .707 .577 .707 r
F P
0 g
s
.19278 .7129 m .19374 .71952 L p .22549 .74597 L .707 .577 .707 r
F P
0 g
s
.19374 .71952 m .1983 .7509 L .21178 .74845 L p .707 .577 .707 r
F P
0 g
s
.21178 .74845 m .22549 .74597 L p .19374 .71952 L .707 .577 .707 r
F P
0 g
s
.21997 .70797 m .19278 .7129 L p .19914 .71933 L .707 .577 .707 r
F P
0 g
s
.21392 .72122 m .21997 .70797 L .19914 .71933 L .707 .577 .707 r
F
.24811 .72276 m .24151 .70811 L .22197 .72171 L F
.24151 .70811 m .22657 .675 L .22197 .72171 L F
.22095 .72549 m .25202 .73143 L p .24811 .72276 L F P
0 g
s
.21997 .70797 m .22197 .72171 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25297 .72295 m .25083 .70308 L .23567 .72226 L .707 .577 .707 r
F
.25372 .72298 m .25366 .72256 L p .25297 .72295 L F P
0 g
s
.25765 .68094 m .25301 .72258 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.25366 .72256 m .25083 .70308 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .27299 .71142 L .25366 .72256 L .707 .577 .707 r
F
.27299 .71142 m .25765 .68094 L .25366 .72256 L F
.28931 .68217 m .25765 .68094 L p .27574 .71689 L F P
0 g
s
.27819 .72175 m .27911 .71846 L .27574 .71689 L .707 .577 .707 r
F
.27911 .71846 m .28931 .68217 L .27574 .71689 L F
.28493 .72153 m .28931 .68217 L p .27819 .72175 L F P
0 g
s
.31692 .73326 m .30287 .71923 L .28564 .7215 L .707 .577 .707 r
F
.28564 .7215 m .28785 .7367 L .3121 .73383 L p F P
0 g
s
.3121 .73383 m .31692 .73326 L p .28564 .7215 L .707 .577 .707 r
F P
0 g
s
.28785 .7367 m .28564 .7215 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.27672 .72659 m .28493 .72153 L .27163 .72196 L .707 .577 .707 r
F
.28785 .7367 m .28493 .72153 L .27672 .72659 L F
.28559 .72112 m .28564 .7215 L p .30287 .71923 L F P
0 g
s
.28496 .72119 m .28493 .72153 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28493 .72153 m .28233 .6987 L .27163 .72196 L .707 .577 .707 r
F
.28564 .7215 m .28559 .72112 L p .28493 .72153 L F P
0 g
s
.28931 .68217 m .28496 .72119 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28559 .72112 m .28233 .6987 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.30763 .7187 m .30334 .71015 L .28559 .72112 L .707 .577 .707 r
F
.30334 .71015 m .28931 .68217 L .28559 .72112 L F
.31846 .67859 m .28931 .68217 L p .30763 .7187 L F P
0 g
s
.3114 .69527 m .28233 .6987 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31469 .71793 L p .31407 .718 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31407 .718 L .30718 .72353 L .707 .577 .707 r
F
.31692 .73326 m .3407 .73111 L p .32741 .71485 L F P
0 g
s
.33344 .71358 m .3299 .70531 L .32227 .71594 L .707 .577 .707 r
F
.31846 .67859 m .31411 .71766 L p .3299 .70531 L F P
0 g
s
.31411 .71766 m .31407 .718 L p .31463 .71755 L .707 .577 .707 r
F P
0 g
s
.3299 .70531 m .31411 .71766 L .31463 .71755 L .707 .577 .707 r
F
.31463 .71755 m .31692 .73326 L p .32741 .71485 L F P
0 g
s
.31407 .718 m .31846 .67859 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.31469 .71793 m .3114 .69527 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31407 .718 m .31283 .72908 L p .3299 .70531 L .707 .577 .707 r
F P
0 g
s
.3407 .73111 m .33802 .71262 L p .33754 .71272 L .707 .577 .707 r
F P
0 g
s
.33176 .72017 m .33754 .71272 L .32741 .71485 L .707 .577 .707 r
F
.3407 .73111 m .33754 .71272 L .33176 .72017 L F
.3407 .73111 m .35687 .73045 L p .34471 .70951 L F P
0 g
s
.352 .70662 m .34949 .69733 L .34236 .71044 L .707 .577 .707 r
F
.34224 .67052 m .33759 .71234 L p .34949 .69733 L F P
0 g
s
.33759 .71234 m .33754 .71272 L p .33795 .71219 L .707 .577 .707 r
F P
0 g
s
.34949 .69733 m .33759 .71234 L .33795 .71219 L .707 .577 .707 r
F
.33795 .71219 m .3407 .73111 L p .34471 .70951 L F P
0 g
s
.34224 .67052 m .31846 .67859 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .33754 .71272 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .34224 .67052 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33802 .71262 m .33518 .69311 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .33662 .72101 L p .34949 .69733 L .707 .577 .707 r
F P
0 g
s
.35687 .73045 m .35334 .70609 L p .35305 .70621 L .707 .577 .707 r
F P
0 g
s
.34944 .71766 m .35305 .70621 L .34471 .70951 L .707 .577 .707 r
F
.35687 .73045 m .35305 .70621 L .34944 .71766 L F
.35687 .73045 m .36386 .73135 L p .35496 .70367 L F P
0 g
s
.35953 .69498 m .35925 .68651 L .35402 .7047 L .707 .577 .707 r
F
.35585 .70268 m .35953 .69498 L p .35402 .7047 L F P
0 g
s
.35833 .65877 m .35311 .70571 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35311 .70571 m .35305 .70621 L p .35326 .70555 L .707 .577 .707 r
F P
0 g
s
.35925 .68651 m .35311 .70571 L .35326 .70555 L .707 .577 .707 r
F
.35326 .70555 m .35687 .73045 L p .35496 .70367 L F P
0 g
s
.35833 .65877 m .34224 .67052 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35305 .70621 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35833 .65877 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35334 .70609 m .35136 .69245 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35271 .70927 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .35136 .69245 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.36386 .73135 m .35916 .69903 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35916 .69903 m .35834 .69335 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .35326 .70555 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35585 .70268 L p .35402 .7047 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .33518 .69311 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33518 .69311 m .33795 .71219 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .35271 .70927 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.352 .70662 m .34236 .71044 L .33662 .72101 L .707 .577 .707 r
F
.33518 .69311 m .3114 .69527 L p .32741 .71485 L F P
0 g
s
.3114 .69527 m .31463 .71755 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.31283 .72908 m .33662 .72101 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33344 .71358 m .32227 .71594 L .31283 .72908 L .707 .577 .707 r
F
.30718 .72353 m .31407 .718 L .30287 .71923 L F
.31283 .72908 m .31407 .718 L p .30763 .7187 L F P
0 g
s
.30763 .7187 m .28559 .72112 L .28369 .73267 L .707 .577 .707 r
F
.28493 .72153 m .28369 .73267 L p .28559 .72112 L F P
0 g
s
.28369 .73267 m .31283 .72908 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .28559 .72112 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .25083 .70308 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.28369 .73267 m .28493 .72153 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .25366 .72256 L .25202 .73143 L .707 .577 .707 r
F
.25297 .72295 m .25202 .73143 L p .25366 .72256 L F P
0 g
s
.25202 .73143 m .28369 .73267 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .25366 .72256 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .21997 .70797 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25202 .73143 m .25297 .72295 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.70165 .82433 m .69841 .84291 L .6955 .83614 L p .707 .577 .707 r
F P
0 g
s
.6955 .83614 m .69875 .81755 L .70165 .82433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.61259 .30552 m .61259 .80741 L .63494 .79689 L p .707 .577 .707 r
F P
0 g
s
.63494 .79689 m .63494 .295 L .61259 .30552 L p .707 .577 .707 r
F P
0 g
s
.37945 .80447 m .37945 .30259 L .36087 .29155 L p .707 .577 .707 r
F P
0 g
s
.37945 .30259 m .37945 .80447 L .40983 .81343 L p .707 .577 .707 r
F P
0 g
s
.69875 .81755 m .6955 .83614 L .68305 .82825 L p .707 .577 .707 r
F P
0 g
s
.68305 .82825 m .68629 .80967 L .69875 .81755 L p .707 .577 .707 r
F P
0 g
s
.17237 .70222 m .178 .65173 L .16525 .63668 L p .707 .577 .707 r
F P
0 g
s
.17192 .71739 m .17744 .75538 L .1983 .7509 L p .707 .577 .707 r
F P
0 g
s
.1983 .7509 m .19278 .7129 L .17192 .71739 L p .707 .577 .707 r
F P
0 g
s
.25162 .82909 m .25302 .81173 L .22189 .80674 L p .707 .577 .707 r
F P
0 g
s
.25302 .81173 m .25162 .82909 L .28335 .82987 L p .707 .577 .707 r
F P
0 g
s
.28335 .82987 m .28476 .81252 L .25302 .81173 L p .707 .577 .707 r
F P
0 g
s
.28476 .81252 m .28335 .82987 L .31258 .82636 L p .707 .577 .707 r
F P
0 g
s
.31258 .82636 m .31398 .80901 L .28476 .81252 L p .707 .577 .707 r
F P
0 g
s
.22049 .82409 m .22189 .80674 L .19441 .79802 L p .707 .577 .707 r
F P
0 g
s
.22189 .80674 m .22049 .82409 L .25162 .82909 L p .707 .577 .707 r
F P
0 g
s
.63494 .295 m .63494 .79689 L .64409 .78503 L p .707 .577 .707 r
F P
0 g
s
.64409 .78503 m .64409 .28314 L .63494 .295 L p .707 .577 .707 r
F P
0 g
s
.19441 .79802 m .193 .81537 L .22049 .82409 L p .707 .577 .707 r
F P
0 g
s
.68629 .80967 m .68305 .82825 L .66226 .82002 L p .707 .577 .707 r
F P
0 g
s
.66226 .82002 m .6655 .80144 L .68629 .80967 L p .707 .577 .707 r
F P
0 g
s
.35953 .69498 m .36516 .64449 L .35833 .65877 L p .707 .577 .707 r
F P
0 g
s
.31398 .80901 m .31258 .82636 L .33644 .8189 L p .707 .577 .707 r
F P
0 g
s
.33644 .8189 m .33784 .80155 L .31398 .80901 L p .707 .577 .707 r
F P
0 g
s
.15963 .68718 m .16525 .63668 L .16214 .62126 L p .707 .577 .707 r
F P
0 g
s
.16525 .63668 m .15963 .68718 L .17237 .70222 L p .707 .577 .707 r
F P
0 g
s
.193 .81537 m .19441 .79802 L .17326 .78642 L p .707 .577 .707 r
F P
0 g
s
.15943 .72099 m .16495 .75899 L .17744 .75538 L p .707 .577 .707 r
F P
0 g
s
.17744 .75538 m .17192 .71739 L .15943 .72099 L p .707 .577 .707 r
F P
0 g
s
.36516 .64449 m .35953 .69498 L .35642 .67956 L p .707 .577 .707 r
F P
0 g
s
.35642 .67956 m .36204 .62907 L .36516 .64449 L p .707 .577 .707 r
F P
0 g
s
.35946 .79538 m .36087 .77802 L .35399 .79087 L p .707 .577 .707 r
F P
0 g
s
.36204 .62907 m .35642 .67956 L .34367 .66451 L p .707 .577 .707 r
F P
0 g
s
.34367 .66451 m .3493 .61402 L .36204 .62907 L p .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .36386 .73135 L .36096 .73371 L p .707 .577 .707 r
F P
0 g
s
.36096 .73371 m .35544 .69571 L .35834 .69335 L p .707 .577 .707 r
F P
0 g
s
.36087 .77802 m .35946 .79538 L .35638 .78161 L p .707 .577 .707 r
F P
0 g
s
.35638 .78161 m .35778 .76426 L .36087 .77802 L p .707 .577 .707 r
F P
0 g
s
.35544 .69571 m .36096 .73371 L .34847 .73731 L p .707 .577 .707 r
F P
0 g
s
.36087 .79344 m .36087 .29155 L .35591 .27951 L p .707 .577 .707 r
F P
0 g
s
.36087 .29155 m .36087 .79344 L .37945 .80447 L p .707 .577 .707 r
F P
0 g
s
.17326 .78642 m .17185 .80378 L .193 .81537 L p .707 .577 .707 r
F P
0 g
s
.33784 .80155 m .33644 .8189 L .35259 .80823 L p .707 .577 .707 r
F P
0 g
s
.35259 .80823 m .35399 .79087 L .33784 .80155 L p .707 .577 .707 r
F P
0 g
s
.6655 .80144 m .66226 .82002 L .63517 .81226 L p .707 .577 .707 r
F P
0 g
s
.63517 .81226 m .63841 .79367 L .6655 .80144 L p .707 .577 .707 r
F P
0 g
s
.17185 .80378 m .17326 .78642 L .16052 .77309 L p .707 .577 .707 r
F P
0 g
s
.16214 .62126 m .15651 .67176 L .15963 .68718 L p .707 .577 .707 r
F P
0 g
s
.15651 .67176 m .16214 .62126 L .16896 .60698 L p .707 .577 .707 r
F P
0 g
s
.16052 .77309 m .15911 .79045 L .17185 .80378 L p .707 .577 .707 r
F P
0 g
s
.15654 .72335 m .16205 .76135 L .16495 .75899 L p .707 .577 .707 r
F P
0 g
s
.16495 .75899 m .15943 .72099 L .15654 .72335 L p .707 .577 .707 r
F P
0 g
s
.64409 .28314 m .64409 .78503 L .63912 .773 L p .707 .577 .707 r
F P
0 g
s
.63912 .773 m .63912 .27111 L .64409 .28314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35399 .79087 m .35259 .80823 L .35946 .79538 L p .707 .577 .707 r
F P
0 g
s
.15911 .79045 m .16052 .77309 L .15743 .75933 L p .707 .577 .707 r
F P
0 g
s
.35778 .76426 m .35638 .78161 L .34364 .76828 L p .707 .577 .707 r
F P
0 g
s
.34364 .76828 m .34504 .75093 L .35778 .76426 L p .707 .577 .707 r
F P
0 g
s
.35591 .27951 m .35591 .7814 L .36087 .79344 L p .707 .577 .707 r
F P
0 g
s
.35591 .7814 m .35591 .27951 L .36505 .26766 L p .707 .577 .707 r
F P
0 g
s
.16896 .60698 m .16333 .65747 L .15651 .67176 L p .707 .577 .707 r
F P
0 g
s
.16333 .65747 m .16896 .60698 L .18505 .59523 L p .707 .577 .707 r
F P
0 g
s
.15743 .75933 m .15603 .77668 L .15911 .79045 L p .707 .577 .707 r
F P
0 g
s
.16352 .72425 m .16903 .76225 L .16205 .76135 L p .707 .577 .707 r
F P
0 g
s
.16205 .76135 m .15654 .72335 L .16352 .72425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15603 .77668 m .15743 .75933 L .1643 .74648 L p .707 .577 .707 r
F P
0 g
s
.3493 .61402 m .34367 .66451 L .32254 .65131 L p .707 .577 .707 r
F P
0 g
s
.32254 .65131 m .32817 .60082 L .3493 .61402 L p .707 .577 .707 r
F P
0 g
s
.18505 .59523 m .17942 .64572 L .16333 .65747 L p .707 .577 .707 r
F P
0 g
s
.17942 .64572 m .18505 .59523 L .20883 .58717 L p .707 .577 .707 r
F P
0 g
s
.63912 .27111 m .63912 .773 L .62054 .76196 L p .707 .577 .707 r
F P
0 g
s
.62054 .76196 m .62054 .26007 L .63912 .27111 L p .707 .577 .707 r
F P
0 g
s
.1643 .74648 m .1629 .76383 L .15603 .77668 L p .707 .577 .707 r
F P
0 g
s
.34847 .73731 m .34295 .69932 L .35544 .69571 L p .707 .577 .707 r
F P
0 g
s
.36505 .76954 m .36505 .26766 L .38741 .25714 L p .707 .577 .707 r
F P
0 g
s
.36505 .26766 m .36505 .76954 L .35591 .7814 L p .707 .577 .707 r
F P
0 g
s
.17969 .72359 m .18521 .76159 L .16903 .76225 L p .707 .577 .707 r
F P
0 g
s
.16903 .76225 m .16352 .72425 L .17969 .72359 L p .707 .577 .707 r
F P
0 g
s
.32817 .60082 m .32254 .65131 L .2951 .64125 L p .707 .577 .707 r
F P
0 g
s
.2951 .64125 m .30072 .59076 L .32817 .60082 L p .707 .577 .707 r
F P
0 g
s
.20321 .63766 m .20883 .58717 L .23798 .58358 L p .707 .577 .707 r
F P
0 g
s
.20883 .58717 m .20321 .63766 L .17942 .64572 L p .707 .577 .707 r
F P
0 g
s
.1629 .76383 m .1643 .74648 L .18046 .73581 L p .707 .577 .707 r
F P
0 g
s
.30072 .59076 m .2951 .64125 L .26402 .63531 L p .707 .577 .707 r
F P
0 g
s
.26402 .63531 m .26964 .58482 L .30072 .59076 L p .707 .577 .707 r
F P
0 g
s
.23236 .63407 m .23798 .58358 L .26964 .58482 L p .707 .577 .707 r
F P
0 g
s
.23798 .58358 m .23236 .63407 L .20321 .63766 L p .707 .577 .707 r
F P
0 g
s
.18046 .73581 m .17906 .75316 L .1629 .76383 L p .707 .577 .707 r
F P
0 g
s
.34295 .69932 m .34847 .73731 L .32761 .7418 L p .707 .577 .707 r
F P
0 g
s
.26964 .58482 m .26402 .63531 L .23236 .63407 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .32209 .7038 L .34295 .69932 L p .707 .577 .707 r
F P
0 g
s
.62054 .26007 m .62054 .76196 L .59016 .75301 L p .707 .577 .707 r
F P
0 g
s
.59016 .75301 m .59016 .25112 L .62054 .26007 L p .707 .577 .707 r
F P
0 g
s
.20348 .72144 m .20899 .75943 L .18521 .76159 L p .707 .577 .707 r
F P
0 g
s
.18521 .76159 m .17969 .72359 L .20348 .72144 L p .707 .577 .707 r
F P
0 g
s
.34504 .75093 m .34364 .76828 L .32249 .75669 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .30042 .74673 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32209 .7038 m .32421 .7184 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32421 .7184 m .32761 .7418 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .32389 .73934 L .34188 .7492 L p .707 .577 .707 r
F P
0 g
s
.34188 .7492 m .34504 .75093 L p .34315 .75141 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .34188 .7492 L .34315 .75141 L .707 .577 .707 r
F
.38741 .25714 m .38741 .75902 L .36505 .76954 L p F P
0 g
s
.38741 .75902 m .38741 .25714 L .42078 .24898 L p .707 .577 .707 r
F P
0 g
s
.17906 .75316 m .18046 .73581 L .20432 .72835 L p .707 .577 .707 r
F P
0 g
s
.73598 .63577 m .73035 .57841 L .69928 .58113 L p .707 .577 .707 r
F P
0 g
s
.73035 .57841 m .73598 .63577 L .76764 .63253 L p .707 .577 .707 r
F P
0 g
s
.76764 .63253 m .76202 .57517 L .73035 .57841 L p .707 .577 .707 r
F P
0 g
s
.20432 .72835 m .20291 .7457 L .17906 .75316 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .2949 .70873 L .32209 .7038 L p .707 .577 .707 r
F P
0 g
s
.69928 .58113 m .7049 .63849 L .73598 .63577 L p .707 .577 .707 r
F P
0 g
s
.76202 .57517 m .76764 .63253 L .79679 .62907 L p .707 .577 .707 r
F P
0 g
s
.79679 .62907 m .79116 .57171 L .76202 .57517 L p .707 .577 .707 r
F P
0 g
s
.23254 .718 m .23806 .756 L .20899 .75943 L p .707 .577 .707 r
F P
0 g
s
.20899 .75943 m .20348 .72144 L .23254 .718 L p .707 .577 .707 r
F P
0 g
s
.7049 .63849 m .69928 .58113 L .67183 .58306 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .26956 .75162 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.2949 .70873 m .29609 .71691 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.29609 .71691 m .30042 .74673 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .295 .74797 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32389 .73934 m .32366 .7422 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32366 .7422 m .32249 .75669 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .29641 .73062 L .32389 .73934 L p .707 .577 .707 r
F P
0 g
s
.67183 .58306 m .67746 .64042 L .7049 .63849 L p .707 .577 .707 r
F P
0 g
s
.23806 .756 m .23277 .71959 L p .26405 .71363 L .707 .577 .707 r
F P
0 g
s
.23277 .71959 m .23254 .718 L .23577 .71756 L p .707 .577 .707 r
F P
0 g
s
.23577 .71756 m .26405 .71363 L p .23277 .71959 L .707 .577 .707 r
F P
0 g
s
.20291 .7457 m .20341 .7395 L p .23354 .72484 L .707 .577 .707 r
F P
0 g
s
.20341 .7395 m .20432 .72835 L .2232 .72608 L p .707 .577 .707 r
F P
0 g
s
.2232 .72608 m .23354 .72484 L p .20341 .7395 L .707 .577 .707 r
F P
0 g
s
.59016 .25112 m .59016 .75301 L .55096 .74701 L p .707 .577 .707 r
F P
0 g
s
.55096 .74701 m .55096 .24512 L .59016 .25112 L p .707 .577 .707 r
F P
0 g
s
.79116 .57171 m .79679 .62907 L .82057 .62575 L p .707 .577 .707 r
F P
0 g
s
.82057 .62575 m .81495 .56839 L .79116 .57171 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .26405 .71363 L .2949 .70873 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .23806 .756 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.26453 .71692 m .26956 .75162 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .26387 .74297 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29641 .73062 m .29591 .73677 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29591 .73677 m .295 .74797 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.26405 .71363 m .26453 .71692 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.23354 .72484 m .23214 .74219 L .20291 .7457 L p .707 .577 .707 r
F P
0 g
s
.42078 .75087 m .42078 .24898 L .46191 .244 L p .707 .577 .707 r
F P
0 g
s
.42078 .24898 m .42078 .75087 L .38741 .75902 L p .707 .577 .707 r
F P
0 g
s
.26387 .74297 m .26527 .72562 L .29641 .73062 L p .707 .577 .707 r
F P
0 g
s
.67746 .64042 m .67183 .58306 L .6507 .584 L p .707 .577 .707 r
F P
0 g
s
.23214 .74219 m .23354 .72484 L .26527 .72562 L p .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .73472 .72534 L .7173 .72621 L p .707 .577 .707 r
F P
0 g
s
.7173 .72621 m .70359 .7269 L p .70998 .73034 L .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .7173 .72621 L .70998 .73034 L .707 .577 .707 r
F
.73613 .74442 m .76786 .74179 L p .74488 .73038 L F P
0 g
s
.73472 .72534 m .73554 .73638 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.73554 .73638 m .73613 .74442 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .76646 .72271 L .73472 .72534 L p .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .79708 .73835 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76646 .72271 m .76755 .73761 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76755 .73761 m .76786 .74179 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .79568 .71927 L .76646 .72271 L p .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .82094 .73443 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79568 .71927 m .79706 .73803 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79706 .73803 m .79708 .73835 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.82094 .73443 m .81954 .71535 L .79568 .71927 L p .707 .577 .707 r
F P
0 g
s
.81954 .71535 m .82094 .73443 L .8371 .73042 L p .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .8357 .71134 L .83012 .71273 L p .707 .577 .707 r
F P
0 g
s
.83012 .71273 m .81954 .71535 L p .82729 .722 L .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .83012 .71273 L .82729 .722 L .707 .577 .707 r
F
.83096 .72012 m .83795 .70323 L p .83672 .69116 L F P
0 g
s
.83648 .6888 m .83518 .6962 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.83518 .6962 m .83096 .72012 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .83096 .72012 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.82031 .70248 m .81976 .70558 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.81976 .70558 m .81479 .73381 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .81479 .73381 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79652 .71163 m .79639 .71239 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79639 .71239 m .79101 .74295 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .79101 .74295 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76745 .71533 m .76734 .71597 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76734 .71597 m .76194 .74666 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.70359 .7269 m .70499 .74598 L .73613 .74442 L p .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .76194 .74666 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73595 .71324 m .73547 .71596 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73547 .71596 m .73043 .74456 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .73595 .71324 L .70509 .70555 L p .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .76745 .71533 L .73595 .71324 L p .707 .577 .707 r
F P
0 g
s
.6507 .584 m .65633 .64136 L .67746 .64042 L p .707 .577 .707 r
F P
0 g
s
.26527 .72562 m .26387 .74297 L .23214 .74219 L p .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .70359 .7269 L .68123 .72717 L p .707 .577 .707 r
F P
0 g
s
.68123 .72717 m .67611 .72723 L p .67863 .72887 L .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .68123 .72717 L .67863 .72887 L .707 .577 .707 r
F
.69958 .73688 m .73043 .74456 L p .70781 .70974 L F P
0 g
s
.70509 .70555 m .70391 .7123 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.70391 .7123 m .69958 .73688 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.69958 .73688 m .70509 .70555 L .6779 .69302 L p .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .79652 .71163 L .76745 .71533 L p .707 .577 .707 r
F P
0 g
s
.55096 .24512 m .55096 .74701 L .50676 .74456 L p .707 .577 .707 r
F P
0 g
s
.50676 .74456 m .50676 .24267 L .55096 .24512 L p .707 .577 .707 r
F P
0 g
s
.81495 .56839 m .82057 .62575 L .83666 .62288 L p .707 .577 .707 r
F P
0 g
s
.83666 .62288 m .83104 .56552 L .81495 .56839 L p .707 .577 .707 r
F P
0 g
s
.67611 .72723 m .67751 .74631 L .70499 .74598 L p .707 .577 .707 r
F P
0 g
s
.46191 .74589 m .46191 .244 L .50676 .24267 L p .707 .577 .707 r
F P
0 g
s
.46191 .244 m .46191 .74589 L .42078 .75087 L p .707 .577 .707 r
F P
0 g
s
.67239 .72435 m .6779 .69302 L .65704 .67688 L p .707 .577 .707 r
F P
0 g
s
.6779 .69302 m .67239 .72435 L .69958 .73688 L p .707 .577 .707 r
F P
0 g
s
.50676 .24267 m .50676 .74456 L .46191 .74589 L p .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .82031 .70248 L .79652 .71163 L p .707 .577 .707 r
F P
0 g
s
.65633 .64136 m .6507 .584 L .63796 .58388 L p .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .64358 .64124 L .65633 .64136 L p .707 .577 .707 r
F P
0 g
s
.67751 .74631 m .67611 .72723 L .65496 .72631 L p .707 .577 .707 r
F P
0 g
s
.65496 .72631 m .65636 .74539 L .67751 .74631 L p .707 .577 .707 r
F P
0 g
s
.65153 .7082 m .65704 .67688 L .64455 .6587 L p .707 .577 .707 r
F P
0 g
s
.65704 .67688 m .65153 .7082 L .67239 .72435 L p .707 .577 .707 r
F P
0 g
s
.83096 .72012 m .83648 .6888 L .82031 .70248 L p .707 .577 .707 r
F P
0 g
s
.83104 .56552 m .83666 .62288 L .84349 .62075 L p .707 .577 .707 r
F P
0 g
s
.84349 .62075 m .83786 .56339 L .83104 .56552 L p .707 .577 .707 r
F P
0 g
s
.65636 .74539 m .65496 .72631 L .64222 .72422 L p .707 .577 .707 r
F P
0 g
s
.64358 .64124 m .6421 .62617 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.63484 .58269 m .64047 .64005 L .64358 .64124 L p .707 .577 .707 r
F P
0 g
s
.63904 .69002 m .64455 .6587 L .64166 .64026 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .63614 .67158 L .63904 .69002 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .64864 .62337 L p .64504 .63727 L .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .63484 .58269 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.6421 .62617 m .63796 .58388 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64414 .6389 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64864 .62337 L p .64977 .63276 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64695 .63444 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64977 .63276 L .64695 .63444 L .707 .577 .707 r
F
.66338 .63505 m .64729 .63792 L p .648 .63381 L F P
0 g
s
.64864 .62337 m .66481 .60969 L p .65529 .62945 L .707 .577 .707 r
F P
0 g
s
.64977 .63276 m .64864 .62337 L .65529 .62945 L .707 .577 .707 r
F
.648 .63381 m .66205 .62541 L .66338 .63505 L F
.66205 .62541 m .66481 .60969 L p .66743 .62417 L F P
0 g
s
.66338 .63505 m .66245 .62563 L p .66656 .62442 L .707 .577 .707 r
F P
0 g
s
.66205 .62541 m .66743 .62417 L .66245 .62563 L .707 .577 .707 r
F
.68716 .63173 m .66338 .63505 L p .66656 .62442 L F P
0 g
s
.66481 .60969 m .6886 .60054 L p .67259 .62266 L .707 .577 .707 r
F P
0 g
s
.66743 .62417 m .66481 .60969 L .67259 .62266 L .707 .577 .707 r
F
.6886 .60054 m .71767 .59684 L p .69713 .61764 L F P
0 g
s
.6921 .61832 m .6886 .60054 L .69713 .61764 L .707 .577 .707 r
F
.68716 .63173 m .68593 .61915 L p .69237 .61828 L F P
0 g
s
.68536 .61891 m .6886 .60054 L p .6921 .61832 L .707 .577 .707 r
F P
0 g
s
.71631 .62828 m .68716 .63173 L p .69237 .61828 L .707 .577 .707 r
F P
0 g
s
.68593 .61915 m .6921 .61832 L .69282 .622 L .707 .577 .707 r
F
.68536 .61891 m .6921 .61832 L .68593 .61915 L F
.71767 .59684 m .74917 .59893 L p .72837 .61535 L F P
0 g
s
.7223 .61547 m .71767 .59684 L .72837 .61535 L .707 .577 .707 r
F
.71631 .62828 m .71507 .61562 L p .72181 .61548 L F P
0 g
s
.71441 .61532 m .71767 .59684 L p .7223 .61547 L .707 .577 .707 r
F P
0 g
s
.74798 .62503 m .71631 .62828 L p .72181 .61548 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .74634 .61499 L .74798 .62503 L .707 .577 .707 r
F
.74634 .61499 m .74917 .59893 L p .75524 .61608 L F P
0 g
s
.77905 .62231 m .74798 .62503 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .77803 .61794 L .77905 .62231 L .707 .577 .707 r
F
.77803 .61794 m .78003 .60662 L p .78608 .61996 L F P
0 g
s
.79317 .62132 m .77905 .62231 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.77803 .61794 m .78608 .61996 L .77868 .61853 L .707 .577 .707 r
F
.78003 .60662 m .80722 .61915 L p .80086 .6228 L F P
0 g
s
.78608 .61996 m .78003 .60662 L .80086 .6228 L .707 .577 .707 r
F
.74917 .59893 m .78003 .60662 L p .76433 .61682 L F P
0 g
s
.75716 .62148 m .75524 .61608 L .76433 .61682 L .707 .577 .707 r
F
.75524 .61608 m .74917 .59893 L .76433 .61682 L F
.74634 .61499 m .75524 .61608 L .74703 .6154 L F
.69237 .61828 m .71441 .61532 L .71631 .62828 L F
.71441 .61532 m .7223 .61547 L .71507 .61562 L F
.71503 .61523 m .71507 .61562 L p .71441 .61532 L F P
0 g
s
.71507 .61562 m .71631 .62828 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.74917 .59893 m .74628 .61534 L p .7288 .62191 L .707 .577 .707 r
F P
0 g
s
.71215 .62816 m .72327 .61938 L .7288 .62191 L .707 .577 .707 r
F
.72327 .61938 m .74917 .59893 L .7288 .62191 L F
.74628 .61534 m .74365 .63025 L .72033 .6287 L p F P
0 g
s
.72033 .6287 m .71215 .62816 L p .74628 .61534 L .707 .577 .707 r
F P
0 g
s
.74235 .56767 m .77343 .56495 L p .7537 .61152 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .75128 .61276 L .7537 .61152 L .707 .577 .707 r
F
.75128 .61276 m .74235 .56767 L .7537 .61152 L F
.74798 .62503 m .74703 .6154 L p .75189 .6158 L F P
0 g
s
.74703 .6154 m .74235 .56767 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.78003 .60662 m .77795 .61839 L p .74365 .63025 L .707 .577 .707 r
F P
0 g
s
.77795 .61839 m .77451 .63794 L .7537 .63276 L p .707 .577 .707 r
F P
0 g
s
.7537 .63276 m .74365 .63025 L p .77795 .61839 L .707 .577 .707 r
F P
0 g
s
.77343 .56495 m .80087 .56303 L p .7812 .61647 L .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .7801 .61712 L .7812 .61647 L .707 .577 .707 r
F
.7801 .61712 m .77343 .56495 L .7812 .61647 L F
.77905 .62231 m .77868 .61853 L p .78033 .61885 L F P
0 g
s
.77868 .61853 m .77343 .56495 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.79016 .62895 m .78608 .61996 L .80086 .6228 L .707 .577 .707 r
F
.77868 .61853 m .78608 .61996 L .79016 .62895 L F
.80722 .61915 m .80626 .6246 L p .77451 .63794 L F P
0 g
s
.80626 .6246 m .8017 .65047 L .78822 .64426 L p .707 .577 .707 r
F P
0 g
s
.78822 .64426 m .77451 .63794 L p .80626 .6246 L .707 .577 .707 r
F P
0 g
s
.8017 .65047 m .80722 .61915 L .82808 .63529 L p .707 .577 .707 r
F P
0 g
s
.822 .56208 m .82602 .60306 L p .8065 .62039 L .707 .577 .707 r
F P
0 g
s
.82602 .60306 m .82763 .61944 L .81028 .62022 L p .707 .577 .707 r
F P
0 g
s
.81028 .62022 m .8065 .62039 L p .82602 .60306 L .707 .577 .707 r
F P
0 g
s
.80087 .56303 m .8065 .62039 L .79317 .62132 L p .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .80087 .56303 L .79317 .62132 L .707 .577 .707 r
F
.77863 .61799 m .77868 .61853 L p .77803 .61794 L F P
0 g
s
.77868 .61853 m .77905 .62231 L p .77803 .61794 L .707 .577 .707 r
F P
0 g
s
.77451 .63794 m .77803 .61794 L p .79016 .62895 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .75524 .61608 L .75716 .62148 L .707 .577 .707 r
F
.77343 .56495 m .77863 .61799 L p .75189 .6158 L F P
0 g
s
.74699 .61498 m .74703 .6154 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .74798 .62503 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74365 .63025 m .74634 .61499 L p .75716 .62148 L .707 .577 .707 r
F P
0 g
s
.71507 .61562 m .7223 .61547 L .72327 .61938 L .707 .577 .707 r
F
.74235 .56767 m .74699 .61498 L p .72181 .61548 L F P
0 g
s
.66656 .62442 m .68536 .61891 L .68716 .63173 L .707 .577 .707 r
F
.68589 .61876 m .68593 .61915 L p .68536 .61891 L F P
0 g
s
.68593 .61915 m .68716 .63173 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.71767 .59684 m .71436 .61564 L p .69798 .62414 L .707 .577 .707 r
F P
0 g
s
.68308 .63187 m .69282 .622 L .69798 .62414 L .707 .577 .707 r
F
.69282 .622 m .71767 .59684 L .69798 .62414 L F
.71436 .61564 m .71215 .62816 L .6879 .63125 L p F P
0 g
s
.6879 .63125 m .68308 .63187 L p .71436 .61564 L .707 .577 .707 r
F P
0 g
s
.71069 .57092 m .74235 .56767 L p .72426 .60979 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .72089 .61178 L .72426 .60979 L .707 .577 .707 r
F
.72089 .61178 m .71069 .57092 L .72426 .60979 L F
.71507 .61562 m .71069 .57092 L p .72181 .61548 L F P
0 g
s
.72327 .61938 m .7223 .61547 L .72837 .61535 L .707 .577 .707 r
F
.71215 .62816 m .71441 .61532 L p .72327 .61938 L F P
0 g
s
.71069 .57092 m .71503 .61523 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69666 .60719 L .71441 .61532 L .707 .577 .707 r
F
.69666 .60719 m .71069 .57092 L .71441 .61532 L F
.68308 .63187 m .6593 .64101 L p .66056 .63927 L F P
0 g
s
.6886 .60054 m .68531 .61923 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68531 .61923 m .68308 .63187 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68154 .57437 m .71069 .57092 L p .69505 .61134 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69139 .61431 L .69505 .61134 L .707 .577 .707 r
F
.69139 .61431 m .68154 .57437 L .69505 .61134 L F
.68593 .61915 m .68154 .57437 L p .69237 .61828 L F P
0 g
s
.69282 .622 m .6921 .61832 L .69713 .61764 L .707 .577 .707 r
F
.68308 .63187 m .68536 .61891 L p .69282 .622 L F P
0 g
s
.68154 .57437 m .68589 .61876 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .6701 .61259 L .68536 .61891 L .707 .577 .707 r
F
.6701 .61259 m .68154 .57437 L .68536 .61891 L F
.66824 .62866 m .66743 .62417 L .67259 .62266 L F
.66245 .62563 m .66743 .62417 L .66824 .62866 L F
.6593 .64101 m .64312 .65469 L p .64821 .64414 L F P
0 g
s
.66481 .60969 m .66198 .62577 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.66198 .62577 m .6593 .64101 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .68154 .57437 L p .66893 .61649 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .66584 .62062 L .66893 .61649 L .707 .577 .707 r
F
.66584 .62062 m .65775 .57769 L .66893 .61649 L F
.66245 .62563 m .65775 .57769 L p .66656 .62442 L F P
0 g
s
.66241 .62519 m .66245 .62563 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.66245 .62563 m .66338 .63505 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.6593 .64101 m .66205 .62541 L p .66824 .62866 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .66241 .62519 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.65055 .63928 m .64977 .63276 L .65529 .62945 L .707 .577 .707 r
F
.64695 .63444 m .64977 .63276 L .65055 .63928 L F
.64312 .65469 m .63614 .67158 L p .64164 .65039 L F P
0 g
s
.64864 .62337 m .64666 .63461 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64666 .63461 m .64312 .65469 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .65775 .57769 L p .64931 .6263 L .707 .577 .707 r
F P
0 g
s
.648 .63381 m .64771 .63133 L .64931 .6263 L .707 .577 .707 r
F
.64771 .63133 m .64166 .58056 L .64931 .6263 L F
.64695 .63444 m .64166 .58056 L p .648 .63381 L F P
0 g
s
.64689 .63388 m .64695 .63444 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64695 .63444 m .64729 .63792 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64312 .65469 m .64674 .63416 L p .65055 .63928 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .64689 .63388 L p .64047 .64005 L .707 .577 .707 r
F P
0 g
s
.64131 .64408 m .64166 .64026 L .64504 .63727 L .707 .577 .707 r
F
.64414 .6389 m .64047 .64005 L p .64689 .63388 L F P
0 g
s
.64023 .65581 m .64131 .64408 L .64504 .63727 L .707 .577 .707 r
F
.63614 .67158 m .64097 .6442 L p .64023 .65581 L F P
0 g
s
.64097 .6442 m .64166 .64026 L p .64023 .65581 L .707 .577 .707 r
F P
0 g
s
.64222 .72422 m .64362 .7433 L .65636 .74539 L p .707 .577 .707 r
F P
0 g
s
.64455 .6587 m .63904 .69002 L .65153 .7082 L p .707 .577 .707 r
F P
0 g
s
.83795 .70323 m .84346 .67191 L .83648 .6888 L p .707 .577 .707 r
F P
0 g
s
.8357 .71134 m .8371 .73042 L .84397 .72671 L p .707 .577 .707 r
F P
0 g
s
.84397 .72671 m .84257 .70763 L .8357 .71134 L p .707 .577 .707 r
F P
0 g
s
.83786 .56339 m .84349 .62075 L .84037 .61957 L p .707 .577 .707 r
F P
0 g
s
.84037 .61957 m .83475 .56221 L .83786 .56339 L p .707 .577 .707 r
F P
0 g
s
.64362 .7433 m .64222 .72422 L .63913 .72117 L p .707 .577 .707 r
F P
0 g
s
.63913 .72117 m .64053 .74025 L .64362 .7433 L p .707 .577 .707 r
F P
0 g
s
.64047 .64005 m .63484 .58269 L .64166 .58056 L p .707 .577 .707 r
F P
0 g
s
.84346 .67191 m .83795 .70323 L .83505 .6848 L p .707 .577 .707 r
F P
0 g
s
.83505 .6848 m .84057 .65347 L .84346 .67191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84257 .70763 m .84397 .72671 L .84088 .72366 L p .707 .577 .707 r
F P
0 g
s
.84088 .72366 m .83948 .70458 L .84257 .70763 L p .707 .577 .707 r
F P
0 g
s
.83475 .56221 m .84037 .61957 L .82763 .61944 L p .707 .577 .707 r
F P
0 g
s
.82763 .61944 m .822 .56208 L .83475 .56221 L p .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .38174 .57769 L .35136 .58164 L p .707 .577 .707 r
F P
0 g
s
.38174 .57769 m .39466 .63015 L .42569 .62246 L p .707 .577 .707 r
F P
0 g
s
.42569 .62246 m .41277 .57001 L .38174 .57769 L p .707 .577 .707 r
F P
0 g
s
.41277 .57001 m .42569 .62246 L .45434 .6118 L p .707 .577 .707 r
F P
0 g
s
.45434 .6118 m .44142 .55934 L .41277 .57001 L p .707 .577 .707 r
F P
0 g
s
.35266 .65285 m .38202 .66387 L p .37339 .63974 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .35136 .58164 L .35965 .62795 L .707 .577 .707 r
F
.36361 .63135 m .36311 .62933 L p .36093 .62904 L F P
0 g
s
.36311 .62933 m .35136 .58164 L p .36093 .62904 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .32462 .58147 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.38202 .66387 m .41216 .67384 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .35318 .58902 L p .39466 .63015 L .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .35318 .58902 L .39126 .63028 L .707 .577 .707 r
F
.38154 .63185 m .39466 .63015 L p .36361 .63135 L F P
0 g
s
.39453 .62781 m .39302 .63218 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.39302 .63218 m .38202 .66387 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35318 .58902 m .36361 .63135 L p .39126 .63028 L .707 .577 .707 r
F P
0 g
s
.37339 .63974 m .37045 .63154 L .36361 .63135 L .707 .577 .707 r
F
.36093 .62904 m .35266 .65285 L p .37339 .63974 L F P
0 g
s
.38202 .66387 m .39453 .62781 L .36518 .61679 L p .707 .577 .707 r
F P
0 g
s
.36361 .63135 m .36429 .6341 L .38154 .63185 L p .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .36093 .62904 L p .36361 .63135 L .707 .577 .707 r
F P
0 g
s
.37045 .63154 m .36518 .61679 L .36361 .63135 L .707 .577 .707 r
F
.35266 .65285 m .36093 .62904 L p .34542 .62698 L F P
0 g
s
.32698 .64187 m .35266 .65285 L p .34857 .63823 L .707 .577 .707 r
F P
0 g
s
.34857 .63823 m .34542 .62698 L .34078 .63073 L .707 .577 .707 r
F
.34857 .63823 m .34078 .63073 L .32698 .64187 L F
.32462 .58147 m .30412 .57718 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .32462 .58147 L .32898 .61938 L .707 .577 .707 r
F
.33551 .62566 m .33511 .62404 L p .33333 .62357 L F P
0 g
s
.33511 .62404 m .32462 .58147 L p .33333 .62357 L .707 .577 .707 r
F P
0 g
s
.32462 .58147 m .33551 .62566 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.32698 .64187 m .33333 .62357 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33273 .62529 m .32698 .64187 L p .34078 .63073 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .29188 .56922 L p .30958 .61171 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .31852 .62459 L .30747 .632 L .707 .577 .707 r
F
.31287 .61646 m .30412 .57718 L .30958 .61171 L F
.3143 .61852 m .31394 .61704 L p .31287 .61646 L F P
0 g
s
.31394 .61704 m .30412 .57718 L p .31287 .61646 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .31002 .60115 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .32381 .62104 L .31852 .62459 L .707 .577 .707 r
F
.31233 .618 m .30747 .632 L p .32381 .62104 L F P
0 g
s
.31002 .60115 m .31704 .62964 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .31287 .61646 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .30793 .61376 L .30379 .61741 L .707 .577 .707 r
F
.29606 .62421 m .30745 .63198 L p .30379 .61741 L F P
0 g
s
.30745 .63198 m .30747 .632 L p .30379 .61741 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .28908 .55834 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.30153 .60845 m .29188 .56922 L .30053 .60446 L .709 .579 .707 r
F
.30206 .61057 m .30169 .60906 L p .30153 .60845 L F P
0 g
s
.30169 .60906 m .29188 .56922 L p .30153 .60845 L .709 .579 .707 r
F P
0 g
s
.29606 .62421 m .30153 .60845 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .30206 .61057 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.30858 .58816 m .30153 .60845 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .301 .60999 L p .30206 .61057 L .707 .577 .707 r
F P
0 g
s
.30793 .61376 m .30153 .60845 L .30206 .61057 L .707 .577 .707 r
F
.301 .60999 m .29606 .62421 L p .30379 .61741 L F P
0 g
s
.30793 .61376 m .30206 .61057 L .30379 .61741 L .707 .577 .707 r
F
.30206 .61057 m .301 .60999 L .30379 .61741 L F
.28908 .55834 m .29602 .54562 L p .30085 .5982 L F P
0 g
s
.29606 .62421 m .30076 .60553 L .29851 .61 L .707 .577 .707 r
F
.28908 .55834 m .29642 .5881 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.29984 .60203 m .29386 .61926 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30053 .60446 m .29841 .59605 L .30201 .61079 L .709 .579 .707 r
F
.29642 .5881 m .29956 .60088 L p .29841 .59605 L F P
0 g
s
.29956 .60088 m .30201 .61079 L p .29841 .59605 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30053 .60446 L .30091 .60609 L .709 .579 .707 r
F
.3048 .62167 m .30206 .61057 L p .30053 .60446 L F P
0 g
s
.30637 .58321 m .30043 .60034 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29998 .60258 m .29956 .60088 L .30043 .60034 L .707 .577 .707 r
F
.30043 .60034 m .29984 .60203 L p .29998 .60258 L F P
0 g
s
.30076 .60553 m .30043 .60034 L .29998 .60258 L .707 .577 .707 r
F
.30201 .61079 m .3048 .62167 L p .30131 .60762 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30091 .60609 L .30201 .61079 L .709 .579 .707 r
F
.30858 .58816 m .30637 .58321 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .30858 .58816 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .29998 .60258 L p .30043 .60034 L .707 .577 .707 r
F P
0 g
s
.29984 .60203 m .30043 .60034 L p .30079 .60603 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .30637 .58321 L p .3025 .59903 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .30043 .60034 L .30101 .59997 L .707 .577 .707 r
F
.31999 .59595 m .30858 .58816 L p .30793 .61376 L F P
0 g
s
.30637 .58321 m .31359 .58158 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.3025 .59903 m .30637 .58321 L .30542 .59719 L .707 .577 .707 r
F
.30206 .61057 m .3048 .62167 L p .31117 .61553 L F P
0 g
s
.30894 .59808 m .30201 .61079 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.31359 .58158 m .30968 .59284 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30894 .59808 m .30828 .59539 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30542 .59719 m .30968 .59284 L .30828 .59539 L .707 .577 .707 r
F
.31359 .58158 m .32953 .58344 L p .32382 .5903 L F P
0 g
s
.30968 .59284 m .31359 .58158 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.312 .53231 m .32492 .58476 L .31675 .59157 L p .707 .577 .707 r
F P
0 g
s
.31675 .59157 m .30894 .59808 L p .30918 .59293 L .707 .577 .707 r
F P
0 g
s
.30918 .59293 m .312 .53231 L .31675 .59157 L .707 .577 .707 r
F
.30828 .59539 m .30894 .59808 L p .30101 .59997 L F P
0 g
s
.30108 .61764 m .30968 .59284 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.30968 .59284 m .30895 .59496 L p .30828 .59539 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .312 .53231 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30828 .59539 m .29602 .54562 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .30828 .59539 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.29386 .61926 m .29581 .62364 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.29581 .62364 m .29606 .62421 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.30108 .61764 m .29386 .61926 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30895 .59496 m .30108 .61764 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .3025 .59903 L .30079 .60603 L .707 .577 .707 r
F
.30043 .60034 m .28908 .55834 L .30085 .5982 L F
.29956 .60088 m .28908 .55834 L .30043 .60034 L F
.30101 .59997 m .30043 .60034 L .30085 .5982 L F
.30079 .60603 m .3025 .59903 L .30542 .59719 L F
.29386 .61926 m .29984 .60203 L p .30079 .60603 L F P
0 g
s
.3048 .62167 m .31704 .62964 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.31999 .59595 m .31287 .61646 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.31287 .61646 m .31233 .618 L p .3143 .61852 L .707 .577 .707 r
F P
0 g
s
.32381 .62104 m .31287 .61646 L .3143 .61852 L .707 .577 .707 r
F
.31704 .62964 m .3143 .61852 L p .30958 .61171 L F P
0 g
s
.31287 .61646 m .31999 .59595 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .32698 .64187 L p .32599 .63535 L .707 .577 .707 r
F P
0 g
s
.31704 .62964 m .33754 .63392 L p .33109 .62297 L .707 .577 .707 r
F P
0 g
s
.33109 .62297 m .32898 .61938 L .32628 .6217 L .707 .577 .707 r
F
.33109 .62297 m .32628 .6217 L .31704 .62964 L F
.34542 .62698 m .33551 .62566 L .34078 .63073 L F
.33551 .62566 m .33273 .62529 L .34078 .63073 L F
.33949 .60581 m .31999 .59595 L p .32381 .62104 L F P
0 g
s
.33949 .60581 m .33333 .62357 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.33333 .62357 m .33273 .62529 L p .33551 .62566 L .707 .577 .707 r
F P
0 g
s
.34542 .62698 m .33333 .62357 L .33551 .62566 L .707 .577 .707 r
F
.33754 .63392 m .33551 .62566 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .33949 .60581 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33754 .63392 m .36429 .6341 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.33551 .62566 m .33754 .63392 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .33949 .60581 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.36429 .6341 m .36361 .63135 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .36518 .61679 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.44142 .55934 m .45434 .6118 L .4778 .59919 L p .707 .577 .707 r
F P
0 g
s
.4778 .59919 m .46488 .54673 L .44142 .55934 L p .707 .577 .707 r
F P
0 g
s
.64053 .74025 m .63913 .72117 L .646 .71746 L p .707 .577 .707 r
F P
0 g
s
.84057 .65347 m .83505 .6848 L .82256 .66662 L p .707 .577 .707 r
F P
0 g
s
.82256 .66662 m .82808 .63529 L .84057 .65347 L p .707 .577 .707 r
F P
0 g
s
.646 .71746 m .64741 .73654 L .64053 .74025 L p .707 .577 .707 r
F P
0 g
s
.41216 .67384 m .42468 .63779 L .39453 .62781 L p .707 .577 .707 r
F P
0 g
s
.42468 .63779 m .41216 .67384 L .44015 .6818 L p .707 .577 .707 r
F P
0 g
s
.44015 .6818 m .45267 .64575 L .42468 .63779 L p .707 .577 .707 r
F P
0 g
s
.46488 .54673 m .4778 .59919 L .49378 .58587 L p .707 .577 .707 r
F P
0 g
s
.49378 .58587 m .48086 .53342 L .46488 .54673 L p .707 .577 .707 r
F P
0 g
s
.83948 .70458 m .84088 .72366 L .82814 .72157 L p .707 .577 .707 r
F P
0 g
s
.82814 .72157 m .82674 .70249 L .83948 .70458 L p .707 .577 .707 r
F P
0 g
s
.8065 .62039 m .80087 .56303 L .822 .56208 L p .707 .577 .707 r
F P
0 g
s
.82808 .63529 m .82256 .66662 L .8017 .65047 L p .707 .577 .707 r
F P
0 g
s
.45267 .64575 m .44015 .6818 L .46325 .68696 L p .707 .577 .707 r
F P
0 g
s
.46325 .68696 m .47576 .65091 L .45267 .64575 L p .707 .577 .707 r
F P
0 g
s
.64741 .73654 m .646 .71746 L .66216 .71345 L p .707 .577 .707 r
F P
0 g
s
.39557 .73024 m .39232 .7124 L .36159 .71497 L p .707 .577 .707 r
F P
0 g
s
.39232 .7124 m .39557 .73024 L .42694 .7242 L p .707 .577 .707 r
F P
0 g
s
.42694 .7242 m .4237 .70635 L .39232 .7124 L p .707 .577 .707 r
F P
0 g
s
.66216 .71345 m .66356 .73253 L .64741 .73654 L p .707 .577 .707 r
F P
0 g
s
.4237 .70635 m .42694 .7242 L .45589 .71527 L p .707 .577 .707 r
F P
0 g
s
.45589 .71527 m .45264 .69743 L .4237 .70635 L p .707 .577 .707 r
F P
0 g
s
.36159 .71497 m .36483 .73282 L .39557 .73024 L p .707 .577 .707 r
F P
0 g
s
.36483 .73282 m .36159 .71497 L .3345 .71382 L p .707 .577 .707 r
F P
0 g
s
.48086 .53342 m .49378 .58587 L .50071 .57316 L p .707 .577 .707 r
F P
0 g
s
.50071 .57316 m .48779 .5207 L .48086 .53342 L p .707 .577 .707 r
F P
0 g
s
.45264 .69743 m .45589 .71527 L .47956 .70433 L p .707 .577 .707 r
F P
0 g
s
.47956 .70433 m .47632 .68649 L .45264 .69743 L p .707 .577 .707 r
F P
0 g
s
.3345 .71382 m .33774 .73166 L .36483 .73282 L p .707 .577 .707 r
F P
0 g
s
.82674 .70249 m .82814 .72157 L .807 .72065 L p .707 .577 .707 r
F P
0 g
s
.807 .72065 m .80559 .70157 L .82674 .70249 L p .707 .577 .707 r
F P
0 g
s
.47632 .68649 m .47956 .70433 L .49565 .69246 L p .707 .577 .707 r
F P
0 g
s
.49565 .69246 m .49241 .67462 L .47632 .68649 L p .707 .577 .707 r
F P
0 g
s
.47576 .65091 m .46325 .68696 L .47918 .68882 L p .707 .577 .707 r
F P
0 g
s
.47918 .68882 m .4917 .65277 L .47576 .65091 L p .707 .577 .707 r
F P
0 g
s
.33774 .73166 m .3345 .71382 L .31371 .70905 L p .707 .577 .707 r
F P
0 g
s
.66356 .73253 m .66216 .71345 L .68602 .70953 L p .707 .577 .707 r
F P
0 g
s
.68602 .70953 m .68742 .72861 L .66356 .73253 L p .707 .577 .707 r
F P
0 g
s
.31371 .70905 m .31695 .7269 L .33774 .73166 L p .707 .577 .707 r
F P
0 g
s
.48779 .5207 m .50071 .57316 L .49792 .56228 L p .709 .579 .707 r
F P
0 g
s
.49792 .56228 m .485 .50983 L .48779 .5207 L p .709 .579 .707 r
F P
0 g
s
.80559 .70157 m .807 .72065 L .77951 .72098 L p .707 .577 .707 r
F P
0 g
s
.77951 .72098 m .77811 .7019 L .80559 .70157 L p .707 .577 .707 r
F P
0 g
s
.4917 .65277 m .47918 .68882 L .4864 .6872 L p .707 .577 .707 r
F P
0 g
s
.4864 .6872 m .49892 .65114 L .4917 .65277 L p .707 .577 .707 r
F P
0 g
s
.68742 .72861 m .68602 .70953 L .71524 .70609 L p .707 .577 .707 r
F P
0 g
s
.71524 .70609 m .71665 .72517 L .68742 .72861 L p .707 .577 .707 r
F P
0 g
s
.31695 .7269 m .31371 .70905 L .30125 .70114 L p .707 .577 .707 r
F P
0 g
s
.49241 .67462 m .49565 .69246 L .50259 .68081 L p .707 .577 .707 r
F P
0 g
s
.50259 .68081 m .49935 .66297 L .49241 .67462 L p .707 .577 .707 r
F P
0 g
s
.77811 .7019 m .77951 .72098 L .74838 .72254 L p .707 .577 .707 r
F P
0 g
s
.74838 .72254 m .74698 .70346 L .77811 .7019 L p .707 .577 .707 r
F P
0 g
s
.30125 .70114 m .30449 .71898 L .31695 .7269 L p .707 .577 .707 r
F P
0 g
s
.71665 .72517 m .71524 .70609 L .74698 .70346 L p .707 .577 .707 r
F P
0 g
s
.74698 .70346 m .74838 .72254 L .71665 .72517 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.485 .50983 m .49792 .56228 L .48568 .55431 L p .707 .577 .707 r
F P
0 g
s
.48568 .55431 m .47275 .50186 L .485 .50983 L p .707 .577 .707 r
F P
0 g
s
.49892 .65114 m .4864 .6872 L .4842 .68225 L p .707 .577 .707 r
F P
0 g
s
.4842 .68225 m .49671 .64619 L .49892 .65114 L p .707 .577 .707 r
F P
0 g
s
.30449 .71898 m .30125 .70114 L .29835 .69086 L p .707 .577 .707 r
F P
0 g
s
.49935 .66297 m .50259 .68081 L .49968 .67052 L p .707 .577 .707 r
F P
0 g
s
.49968 .67052 m .49644 .65268 L .49935 .66297 L p .707 .577 .707 r
F P
0 g
s
.29835 .69086 m .30159 .7087 L .30449 .71898 L p .707 .577 .707 r
F P
0 g
s
.47275 .50186 m .48568 .55431 L .46518 .55003 L p .707 .577 .707 r
F P
0 g
s
.46518 .55003 m .45226 .49758 L .47275 .50186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30159 .7087 m .29835 .69086 L .30528 .67921 L p .707 .577 .707 r
F P
0 g
s
.49671 .64619 m .4842 .68225 L .47279 .67446 L p .707 .577 .707 r
F P
0 g
s
.47279 .67446 m .4853 .6384 L .49671 .64619 L p .707 .577 .707 r
F P
0 g
s
.49644 .65268 m .49968 .67052 L .48723 .66261 L p .707 .577 .707 r
F P
0 g
s
.48723 .66261 m .48399 .64477 L .49644 .65268 L p .707 .577 .707 r
F P
0 g
s
.30528 .67921 m .30852 .69705 L .30159 .7087 L p .707 .577 .707 r
F P
0 g
s
.32492 .58476 m .312 .53231 L .33546 .5197 L p .707 .577 .707 r
F P
0 g
s
.32953 .58344 m .31701 .6195 L .30108 .61764 L p .707 .577 .707 r
F P
0 g
s
.45226 .49758 m .46518 .55003 L .43843 .54985 L p .707 .577 .707 r
F P
0 g
s
.43843 .54985 m .42551 .4974 L .45226 .49758 L p .707 .577 .707 r
F P
0 g
s
.30852 .69705 m .30528 .67921 L .32137 .66733 L p .707 .577 .707 r
F P
0 g
s
.4853 .6384 m .47279 .67446 L .45328 .66459 L p .707 .577 .707 r
F P
0 g
s
.45328 .66459 m .4658 .62854 L .4853 .6384 L p .707 .577 .707 r
F P
0 g
s
.34838 .57215 m .33546 .5197 L .36411 .50903 L p .707 .577 .707 r
F P
0 g
s
.33546 .5197 m .34838 .57215 L .32492 .58476 L p .707 .577 .707 r
F P
0 g
s
.42551 .4974 m .43843 .54985 L .40806 .5538 L p .707 .577 .707 r
F P
0 g
s
.40806 .5538 m .39514 .50135 L .42551 .4974 L p .707 .577 .707 r
F P
0 g
s
.48399 .64477 m .48723 .66261 L .46644 .65785 L p .707 .577 .707 r
F P
0 g
s
.46644 .65785 m .46319 .64 L .48399 .64477 L p .707 .577 .707 r
F P
0 g
s
.32137 .66733 m .32461 .68518 L .30852 .69705 L p .707 .577 .707 r
F P
0 g
s
.31701 .6195 m .32953 .58344 L .35262 .5886 L p .707 .577 .707 r
F P
0 g
s
.37703 .56149 m .36411 .50903 L .39514 .50135 L p .707 .577 .707 r
F P
0 g
s
.36411 .50903 m .37703 .56149 L .34838 .57215 L p .707 .577 .707 r
F P
0 g
s
.39514 .50135 m .40806 .5538 L .37703 .56149 L p .707 .577 .707 r
F P
0 g
s
.35262 .5886 m .34011 .62466 L .31701 .6195 L p .707 .577 .707 r
F P
0 g
s
.4658 .62854 m .45328 .66459 L .4276 .65361 L p .707 .577 .707 r
F P
0 g
s
.4276 .65361 m .44011 .61756 L .4658 .62854 L p .707 .577 .707 r
F P
0 g
s
.32461 .68518 m .32137 .66733 L .34505 .6564 L p .707 .577 .707 r
F P
0 g
s
.34011 .62466 m .35262 .5886 L .38061 .59656 L p .707 .577 .707 r
F P
0 g
s
.46319 .64 m .46644 .65785 L .43935 .65669 L p .707 .577 .707 r
F P
0 g
s
.43935 .65669 m .4361 .63885 L .46319 .64 L p .707 .577 .707 r
F P
0 g
s
.34505 .6564 m .34829 .67424 L .32461 .68518 L p .707 .577 .707 r
F P
0 g
s
.38061 .59656 m .3681 .63262 L .34011 .62466 L p .707 .577 .707 r
F P
0 g
s
.44011 .61756 m .4276 .65361 L .39824 .64259 L p .707 .577 .707 r
F P
0 g
s
.39824 .64259 m .41076 .60654 L .44011 .61756 L p .707 .577 .707 r
F P
0 g
s
.3681 .63262 m .38061 .59656 L .41076 .60654 L p .707 .577 .707 r
F P
0 g
s
.34829 .67424 m .34505 .6564 L .37399 .64747 L p .707 .577 .707 r
F P
0 g
s
.41076 .60654 m .39824 .64259 L .3681 .63262 L p .707 .577 .707 r
F P
0 g
s
.4361 .63885 m .43935 .65669 L .40861 .65926 L p .707 .577 .707 r
F P
0 g
s
.40861 .65926 m .40537 .64142 L .4361 .63885 L p .707 .577 .707 r
F P
0 g
s
.37399 .64747 m .37723 .66531 L .34829 .67424 L p .707 .577 .707 r
F P
0 g
s
.37723 .66531 m .37399 .64747 L .40537 .64142 L p .707 .577 .707 r
F P
0 g
s
.40537 .64142 m .40861 .65926 L .37723 .66531 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH015YF3`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH70003FUH00`00FUIJEP05FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo1@001UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0065oo`<000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo
0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GGoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001KOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Qoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`8000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
EWoo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP03001JEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF1P0025YF0P000UYF
00<005YFFUH0100000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH010001EYF00<005YFFUH015YF0P001EYF00<005YFFUH00UYF10000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF20001EYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0002moo`L002moo`00DWoo00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEPD000AJEP03001JEUYF00800003FUH005YF00IJEP03001JEUYF
009JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000POol?0002FUH01000FUIJEUYF0P00;Woo001BOol200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUH000020006FUH50004FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000GOol90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
001BOol200000eYF001JEP04FUH00`00FUIJEP05FUH300000eYF001JEP05FUH90007FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool0059oo`80009JEP03001JEUYF009JEP03001JEUYF00=JEP80009o
o`03001JEP0000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Woo
200035YF00=oo`00FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
Dgoo00@005YFFUH000AJEP04001JEUYFFUH20004Ool00`00FUH000070007FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo1@005EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0P000UYF0P00;Woo0010Ool8000;Ool200000eYF001JEP04FUH<0004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP00FUH05eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000jOol60003FUH00`00FUIJ
EP02FUH70004Ool200000eYF001JEP04FUH200000eYF000000030009FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0FFUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00H0009JEP04001JEUYFFUH20006FUH30007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF01IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Woo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF0P000eYF00<005YFFUH01EYF00<005YF
00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH05UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH025YF0P000eYF00<005YFFUH0
15YF00<005YFFUH015YF10002EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0=FUH0
1@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000aOol200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00006
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000`Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00<0
05YFFUH01UYF00@005YF000000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP8002eoo`00;goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P0025YF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0P00;Goo000_Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002io
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH0
1@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YF0000009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH?000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP020002FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH:000^Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000=JEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH01@00FUIJEUYF0000=7oo000^Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000UYF00<005YF
FUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01UYF0`002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF1`001eYF200015YF
00@005YFFUIoo`AJEP03001JEUYF009JEP80039oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P000eYF40001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP80009JEP8000MJEP03001JEUYF009JEPT0009oo`<00003FUH005YF00IJ
EP03001JEUYF00AJEP03001oogoo02moo`00;Goo00<005YF00000eYF00<005YFFUH00UYF1P003goo
10000UYF00<005YFFUH015YF0`0025YF00<005YFFUH01EYF0`0000=JEP00FUH01EYF1`0015YF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00H005YF000005YF0004FUH8000>Ool20007FUH00`00FUIJEP04FUH2000`
Ool002eoo`03001JEP0000=JEP03001JEP00008001Uoo`@000IJEP<000MJEP03001JEUYF00IJEP03
001JEP0000L000=JEP04001JEUYFFUH70003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH:000HOol20004FUH00`00FUIJEP05FUH2000`Ool0
02eoo`8000AJEP80021oo`8000AJEP03001JEUYF008000EJEP03001JEUYF00EJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0009JEP80009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001oogoo029oo`<00003FUH005YF00EJ
EP04001JEUYF000_Ool002eoo`80009JEP8002Aoo`<00003FUH005YF00=JEP<00003FUH005YF00=J
EP@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000XOol20006FUH01000FUIJEP00
;goo000]Ool400000eYF001oo`0DOol3000?Ool20005FUH00`00FUH0000500000eYF001JEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000/Ool00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo000]Ool20003FUH3000BOol5000@Ool20003FUH40005FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00;Goo00=JEP00FUH00UYF00@005YFFUH0015oo`D0019oo`<00003FUH005YF00MJEP03001J
EUYF00AJEPL000AJEP800003FUH0000000D000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002000/Ool200000eYF001JEP03
FUH00`00Oomoo`0/Ool002aoo`8000AJEP04001JEUYFFUH2000?Ool5000AOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH30006FUH40003FUH00`00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@002Yoo`8000AJEP03001o
ogoo02aoo`00;7oo0P0015YF00<005YFFUH00eYF0P003Woo0`0047oo0P001UYF00<005YFFUH015YF
1`001EYF00<005YFFUH01EYF00<005YFFUH00P0015YF00@005YFFUIJEP800004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P001EYF0P004Goo0`005Goo00<0
05YFFUH00UYF0P00;Goo000/Ool00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH00003000LOol2
0007FUH00`00FUIJEP040004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH500000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP00009JEP03001JEUYF00=JEP<000ioo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00
FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP03FUH5000EOol200000eYF001JEP05FUH400000eYF
001JEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP04FUH20003FUH20002FUH00`00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP03
001JEUYF008000aoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00QJEP@0011oo`03001JEUYF009JEP04001JEUYFFUH20002FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P000UYF00<005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH01@00FUIJEUYF
00001EYF0P002Woo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH035YF40001EYF00<005YF00000P0015YF00<005YF00001UYF10001EYF00@005YF
FUIJEP@000EJEP04001JEUYFFUH200001eYF001JEUYF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF00000eYF0P000UYF00<005YFFUH015YF0`002Goo0`0067oo0P00
00=JEP00Ool0;7oo000]Ool01@00FUIJEUYF00001UYF00<005YFFUH06UYF0P001EYF0P000UYF00@0
05YFOomJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<00003
FUH00000009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEUYF009JEP05001JEP00FUH00005FUH20002FUH2000SOol00`00FUH0000]Ool002eoo`05001J
EUYFFUH00006FUH00`00FUIJEP04FUH00`00FUIJEP0CFUH20004FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH025YF2@0000=JEP0000000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0P001EYF00<005YFFUH00UYF00<007ooOol08Goo0P00;Woo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00@005YFFUIoo`EJEP03001JEUYF00UJEP05001JEUYF001JEP020005FUH00`00FUH00003
00000eYF001JEP05FUH50004FUH00`00FUIJEP09FUH300000eYF001JEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000QOol3000^Ool002moo`03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00/00006FUH00000001JEP00
1UYF10001EYF00<005YFFUH025YF0P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP80009JEP07001J
EUYFFUH005YF000087oo00@005YF000002ioo`00<7oo0P001EYF00<005YFFUH01EYF00D005YFFUIJ
EWoo00AJEP04001JEUYFFUH90002FUH20006FUH5000015YF001JEP001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`001UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YF001JEP0000IJEP03001JEP00008000=JEP80021oo`03001JEUYF
008002ioo`00<Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH00UYF00<005YF00001UYF00<005YFFUH01UYF
00@005YFFUIJEP@00003FUH005YF00IJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEP00FUH00006FUH01000FUIJEUYF0`0000=JEP0000003goo
4`0000=JEP000000;Woo000bOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00AJEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEP00008002ioo`00<goo0P000UYF00@005YFFUIJEPH000IJEP03001JEUYF
00IJEPH0009JEP@000IJEP06001JEUYF001JEP001UYF00@005YFFUIJEP@0009JEP03001JEUYF00IJ
EP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF00001EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01P000eYF00@005YF0000009JEP03001JEUYF00L0009JEP03001JEP0000=JEPL000IJEP03001J
EUYF00IJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000bOol300000eYF001JEP06
FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUH00002FUH00`00FUIJEP03FUH01000FUIJ
EUYF200015YF00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002moo`<000AJEP8000IJEP@00004FUH000000005FUH00`00FUIJEP06FUH00`00FUH0
0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP040003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000eYF00D005YFFUIJEP0002eoo`00;7oo4P0015YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00AJEPD000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ8000IJEPP002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00@005YFFUIJ
EQ<000AJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00D0
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP@000EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP<00003FUH005YF00EJEP03001J
EUYF009JEPL000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH01000FUIJEUYF200025YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF0`00;Woo000]Ool00`00FUH00003FUH0
0`00FUH0000300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF
00<005YF000030000UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000=JEP<0
00UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPH0035oo`00;Goo00<005YF0000
0eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009J
EP04001JEUYFFUH500000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000
00001EYF00<005YFFUH00eYF0`001UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
03Moo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEUYF00EJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00000iOol002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHA0004FUH00`00
FUIJEP06FUH30006Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP02FUH5000kOol002eoo`8000=JEP03001JEUYF00=J
EPH000EJEP03001JEUYF00IJEP03001JEUYF00H000MJEP03001JEUYF008000Aoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000@00003FUH0000000h000Moo`T0041oo`00;Goo0P000eYF00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0017oo0P0015YF00<005YFFUH00eYF
0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<0
05YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000017oo0`000eYF1000
0UYF00<007ooOol0DWoo000]Ool20003FUH30006FUH00`00FUIJEP02FUH8000?Ool300001EYF001J
EUYFOol00eYF0P0000Aoo`00FUH000IJEP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEPH000IJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP04001JEUYF
001DOol002aoo`03001JEP00009JEP04001JEUYF0003FUH8000JOol20006FUH2000017oo001JEP00
1EYF10000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00eYF10000UYF00<005YFFUH00UYF00<005YF00000goo00D005YFFUIJEP0000EJEP04001J
EUYF001DOol002aoo`03001JEP0000T002Aoo`8000=JEP03001JEUYF00800003FUH005YF009JEP80
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP<000AJEP04001JEP00Ool20004FUH00`00FUIJEP03FUH00`00FUH0001EOol002aoo`03001J
EP0002moo`800003FUH005YF009JEP04001JEP00FUH30008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH01000FUH0
00001eYF00<005YFFUH00eYF0P00EGoo000/Ool2000bOol20003FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF00<005YFFUH00eYF00<007ooOol0E7oo000/
Ool2000JOol3000GOol00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000015YF
001JEP001eYF00D005YFFUIJEP0005Moo`00;7oo0`0067oo1@005goo00@005YF000000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP800004FUH005YF0007FUH01000FUIJEP00F7oo000/Ool200000eYF
001oo`0FOol5000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000QJ
EP8005Uoo`00;7oo0P000UYF00<007ooOol057oo1@006Goo0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00Oomoo`1HOol002eoo`05001JEUYFFUH0000FOol3000J
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF0P00
Fgoo000]Ool01000FUIJEUYF0`00<7oo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000eYF00<005YFFUH00UYF00<007ooOol0Fgoo000^Ool01000FUIJEP000UYF0P00;Goo0P0000=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00D005YFFUIJEP0005ioo`00;Woo
00<005YF00001EYF0`00:7oo0P0000=JEP00FUH00`000UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
0P0000=JEP0000001@00Ggoo000_Ool20006FUH01000FUH0000097oo0P000eYF0P000goo0`0025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP800003FUH005YF00AJEP<005moo`00<7oo00<005YFFUH015YF00@005YFFUIJEP<0
01moo`800003FUH005YF009JEP8000Eoo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP06FUH3001M
Ool0035oo`8000=JEP03001JEUYF00EJEPD001Qoo`8000=JEP05001JEUYFFUH00008Ool30004FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
0004FUH00`00FUIJEP06FUH00`00FUIJEP02001KOol003=oo`800003FUH005YF00MJEP04001JEUYF
FUH90009Ool60004FUH00`00FUIJEP02000<Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP060003FUH60006FUH00`00FUIJEP03FUH2001IOol0
03Eoo`<000MJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00=JEP<0015oo`@0
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009JEPD000AJEP<00003Ool0
000000AJEP03001JEUYF00AJEP<005Moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P005goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000MJEPD0009JEP8000Ioo`<00003FUH005YF00EJEP04001JEUYF001FOol003Yo
o`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<001mooal000EJ
EP03001JEUYF00EJEPL000]oo`<000AJEP05001JEUYFFUH0001FOol003eoo`H000AJEP03001JEUYF
00IJEP03001JEUYF009JEPD003Uoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0015oo`<0
0003FUH005YF009JEP8005Eoo`00@goo4P00@7oo0`000eYF00<005YFFUH015YF00<005YFFUH01@00
0eYF2@002goo0P000UYF00<005YF0000EGoo002HOol=0003FUH20007FUH00`00FUIJEP02FUH@0000
0eYF001oo`1DOol009]oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8005Ioo`00WWoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00Y7oo1`001UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF0000EWoo002[Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH2001GOol00:mooaH005Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59357 .74263 m .6016 .68677 L .57073 .68104 L p .707 .577 .707 r
F P
0 g
s
.6016 .68677 m .59357 .74263 L .6251 .74635 L p .707 .577 .707 r
F P
0 g
s
.6251 .74635 m .63313 .69049 L .6016 .68677 L p .707 .577 .707 r
F P
0 g
s
.63313 .69049 m .6251 .74635 L .65419 .7477 L p .707 .577 .707 r
F P
0 g
s
.65419 .7477 m .66222 .69184 L .63313 .69049 L p .707 .577 .707 r
F P
0 g
s
.5627 .7369 m .57073 .68104 L .54354 .67387 L p .707 .577 .707 r
F P
0 g
s
.57073 .68104 m .5627 .7369 L .59357 .74263 L p .707 .577 .707 r
F P
0 g
s
.66222 .69184 m .65419 .7477 L .678 .74654 L p .707 .577 .707 r
F P
0 g
s
.678 .74654 m .68603 .69068 L .66222 .69184 L p .707 .577 .707 r
F P
0 g
s
.54354 .67387 m .53551 .72973 L .5627 .7369 L p .707 .577 .707 r
F P
0 g
s
.53551 .72973 m .54354 .67387 L .52268 .66595 L p .707 .577 .707 r
F P
0 g
s
.59978 .81879 m .59194 .78353 L .56148 .78689 L p .707 .577 .707 r
F P
0 g
s
.59194 .78353 m .59978 .81879 L .63097 .81179 L p .707 .577 .707 r
F P
0 g
s
.63097 .81179 m .62313 .77653 L .59194 .78353 L p .707 .577 .707 r
F P
0 g
s
.62313 .77653 m .63097 .81179 L .65984 .80183 L p .707 .577 .707 r
F P
0 g
s
.65984 .80183 m .652 .76657 L .62313 .77653 L p .707 .577 .707 r
F P
0 g
s
.56932 .82215 m .56148 .78689 L .53474 .78627 L p .707 .577 .707 r
F P
0 g
s
.56148 .78689 m .56932 .82215 L .59978 .81879 L p .707 .577 .707 r
F P
0 g
s
.652 .76657 m .65984 .80183 L .68356 .78989 L p .707 .577 .707 r
F P
0 g
s
.68356 .78989 m .67572 .75463 L .652 .76657 L p .707 .577 .707 r
F P
0 g
s
.52268 .66595 m .51465 .72181 L .53551 .72973 L p .707 .577 .707 r
F P
0 g
s
.59323 .84687 m .59524 .82823 L .56423 .82348 L p .707 .577 .707 r
F P
0 g
s
.59524 .82823 m .59323 .84687 L .62489 .84945 L p .707 .577 .707 r
F P
0 g
s
.62489 .84945 m .62689 .83081 L .59524 .82823 L p .707 .577 .707 r
F P
0 g
s
.69152 .74359 m .6942 .743 L p .68117 .72447 L .707 .577 .707 r
F P
0 g
s
.69197 .74186 m .69294 .74622 L p .70701 .7648 L .707 .577 .707 r
F P
0 g
s
.69294 .74622 m .69981 .77712 L .70492 .76837 L p .707 .577 .707 r
F P
0 g
s
.70492 .76837 m .70701 .7648 L p .69294 .74622 L .707 .577 .707 r
F P
0 g
s
.68603 .69068 m .68117 .72447 L p .6942 .743 L .707 .577 .707 r
F P
0 g
s
.68117 .72447 m .678 .74654 L .69152 .74359 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70223 .68714 L .68603 .69068 L p .707 .577 .707 r
F P
0 g
s
.62689 .83081 m .62489 .84945 L .65409 .8496 L p .707 .577 .707 r
F P
0 g
s
.65409 .8496 m .6561 .83096 L .62689 .83081 L p .707 .577 .707 r
F P
0 g
s
.56423 .82348 m .56222 .84211 L .59323 .84687 L p .707 .577 .707 r
F P
0 g
s
.56222 .84211 m .56296 .83521 L p .53689 .81701 L .707 .577 .707 r
F P
0 g
s
.55309 .82084 m .53689 .81701 L p .56296 .83521 L .707 .577 .707 r
F P
0 g
s
.54257 .82153 m .53731 .79787 L p .51432 .78174 L .707 .577 .707 r
F P
0 g
s
.53731 .79787 m .53474 .78627 L .52838 .78486 L p .707 .577 .707 r
F P
0 g
s
.52838 .78486 m .51432 .78174 L p .53731 .79787 L .707 .577 .707 r
F P
0 g
s
.56296 .83521 m .56423 .82348 L .55309 .82084 L p .707 .577 .707 r
F P
0 g
s
.51465 .72181 m .52268 .66595 L .5102 .65806 L p .707 .577 .707 r
F P
0 g
s
.53474 .78627 m .54257 .82153 L .56932 .82215 L p .707 .577 .707 r
F P
0 g
s
.53689 .81701 m .53488 .83565 L .56222 .84211 L p .707 .577 .707 r
F P
0 g
s
.67572 .75463 m .68356 .78989 L .69981 .77712 L p .707 .577 .707 r
F P
0 g
s
.69981 .77712 m .69197 .74186 L .67572 .75463 L p .707 .577 .707 r
F P
0 g
s
.6561 .83096 m .65409 .8496 L .67798 .84731 L p .707 .577 .707 r
F P
0 g
s
.67798 .84731 m .67999 .82867 L .6561 .83096 L p .707 .577 .707 r
F P
0 g
s
.5102 .65806 m .50217 .71392 L .51465 .72181 L p .707 .577 .707 r
F P
0 g
s
.53488 .83565 m .53545 .83036 L p .51592 .80946 L .707 .577 .707 r
F P
0 g
s
.52718 .81351 m .51592 .80946 L p .53545 .83036 L .707 .577 .707 r
F P
0 g
s
.52216 .817 m .5166 .79198 L p .50224 .77374 L .707 .577 .707 r
F P
0 g
s
.5166 .79198 m .51432 .78174 L .51024 .77904 L p .707 .577 .707 r
F P
0 g
s
.51024 .77904 m .50224 .77374 L p .5166 .79198 L .707 .577 .707 r
F P
0 g
s
.53545 .83036 m .53689 .81701 L .52718 .81351 L p .707 .577 .707 r
F P
0 g
s
.51592 .80946 m .51391 .8281 L .53488 .83565 L p .707 .577 .707 r
F P
0 g
s
.51432 .78174 m .52216 .817 L .54257 .82153 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70048 .73799 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70223 .68714 m .69739 .72082 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.69739 .72082 m .6942 .743 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70701 .7648 m .70092 .73739 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70121 .73699 m .70223 .68714 L .70048 .73799 L .707 .577 .707 r
F
.70092 .73739 m .69917 .72954 L p .69464 .74593 L F P
0 g
s
.70092 .73739 m .70701 .7648 L .70474 .75535 L p .708 .578 .707 r
F P
0 g
s
.70048 .73799 m .7012 .73741 L p .70121 .73699 L .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .70092 .73739 L p .70108 .73815 L .708 .578 .707 r
F P
0 g
s
.70055 .73597 m .69917 .72954 L .70108 .73815 L .708 .578 .707 r
F
.7012 .73741 m .70923 .68155 L .70223 .68714 L p .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .69197 .74186 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70045 .73554 m .69832 .73033 L p .69868 .72873 L .707 .577 .707 r
F P
0 g
s
.6966 .71885 m .69875 .72854 L p .69848 .72926 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .68584 .72244 L p .68658 .72072 L .707 .577 .707 r
F P
0 g
s
.68452 .71085 m .68668 .7206 L p .68599 .72138 L .707 .577 .707 r
F P
0 g
s
.6641 .70632 m .66589 .71435 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66522 .71412 L .66586 .71438 L .707 .577 .707 r
F
.68584 .72244 m .66551 .71472 L p .66586 .71438 L F P
0 g
s
.66551 .71472 m .66498 .71452 L p .66586 .71438 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .6452 .74096 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.68599 .72138 m .68584 .72244 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .67194 .74158 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.67524 .73351 m .68093 .71961 L .68599 .72138 L .707 .577 .707 r
F
.68093 .71961 m .68452 .71085 L .68599 .72138 L F
.68658 .72072 m .68668 .7206 L .69832 .73033 L F
.69848 .72926 m .69832 .73033 L p .68664 .72057 L F P
0 g
s
.68452 .71085 m .6966 .71885 L p .69534 .72695 L .707 .577 .707 r
F P
0 g
s
.68892 .72224 m .68452 .71085 L .69534 .72695 L .707 .577 .707 r
F
.68693 .7217 m .68452 .71085 L p .69402 .73544 L F P
0 g
s
.69387 .66658 m .70635 .67446 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68584 .72244 m .68616 .72022 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68616 .72022 m .69387 .66658 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.69402 .73544 m .68892 .72224 L .69534 .72695 L .707 .577 .707 r
F
.69236 .74611 m .68693 .7217 L p .69402 .73544 L F P
0 g
s
.6641 .70632 m .68452 .71085 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .66589 .71435 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .6641 .70632 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .69387 .66658 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66505 .71406 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66505 .71406 m .67301 .65866 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66522 .71412 m .67481 .69821 L .68599 .72138 L .707 .577 .707 r
F
.69387 .66658 m .68616 .72022 L p .67481 .69821 L F P
0 g
s
.68616 .72022 m .68599 .72138 L p .67481 .69821 L .707 .577 .707 r
F P
0 g
s
.68658 .72072 m .68664 .72057 L .68668 .7206 L .707 .577 .707 r
F
.69236 .74611 m .67194 .74158 L p .67524 .73351 L F P
0 g
s
.68668 .7206 m .69236 .74611 L p .67524 .73351 L .707 .577 .707 r
F P
0 g
s
.69261 .74449 m .69534 .72695 L .69848 .72926 L .707 .577 .707 r
F
.69534 .72695 m .6966 .71885 L .69848 .72926 L F
.69868 .72873 m .69875 .72854 L .70045 .73554 L F
.6966 .71885 m .69917 .72954 L p .70055 .73597 L .708 .578 .707 r
F P
0 g
s
.69922 .73046 m .6966 .71885 L .70055 .73597 L .708 .578 .707 r
F
.699 .72964 m .6966 .71885 L p .70226 .74397 L F P
0 g
s
.70635 .67446 m .70923 .68155 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .69864 .72809 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69864 .72809 m .70635 .67446 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.70226 .74397 m .69922 .73046 L .70055 .73597 L .708 .578 .707 r
F
.70444 .75411 m .699 .72964 L p .70226 .74397 L F P
0 g
s
.68664 .72057 m .69335 .70487 L .69848 .72926 L .707 .577 .707 r
F
.70635 .67446 m .69864 .72809 L p .69335 .70487 L F P
0 g
s
.69864 .72809 m .69848 .72926 L p .69335 .70487 L .707 .577 .707 r
F P
0 g
s
.69868 .72873 m .69874 .72847 L .69875 .72854 L .707 .577 .707 r
F
.70444 .75411 m .69236 .74611 L p .69261 .74449 L F P
0 g
s
.69875 .72854 m .70444 .75411 L p .69261 .74449 L .707 .577 .707 r
F P
0 g
s
.70923 .68155 m .7012 .73741 L .70045 .73554 L p .707 .577 .707 r
F P
0 g
s
.69874 .72847 m .70923 .68155 L .70045 .73554 L .707 .577 .707 r
F
.70444 .75411 m .70055 .73597 L .70108 .73815 L .708 .578 .707 r
F
.70474 .75535 m .70444 .75411 L p .70092 .73739 L F P
0 g
s
.50217 .71392 m .5102 .65806 L .50732 .65098 L p .707 .577 .707 r
F P
0 g
s
.67999 .82867 m .67798 .84731 L .69422 .84279 L p .707 .577 .707 r
F P
0 g
s
.69422 .84279 m .69623 .82415 L .67999 .82867 L p .707 .577 .707 r
F P
0 g
s
.50938 .80536 m .50335 .80158 L p .51411 .82618 L .707 .577 .707 r
F P
0 g
s
.51008 .809 m .50454 .78407 L p .49967 .76305 L .708 .578 .707 r
F P
0 g
s
.50454 .78407 m .50224 .77374 L .50127 .76969 L p .708 .578 .707 r
F P
0 g
s
.50127 .76969 m .49967 .76305 L p .50454 .78407 L .708 .578 .707 r
F P
0 g
s
.51391 .8281 m .51411 .82618 L p .50335 .80158 L .707 .577 .707 r
F P
0 g
s
.51411 .82618 m .51592 .80946 L .50938 .80536 L p .707 .577 .707 r
F P
0 g
s
.50732 .65098 m .49929 .70684 L .50217 .71392 L p .707 .577 .707 r
F P
0 g
s
.50335 .80158 m .50134 .82022 L .51391 .8281 L p .707 .577 .707 r
F P
0 g
s
.50224 .77374 m .51008 .809 L .52216 .817 L p .707 .577 .707 r
F P
0 g
s
.49217 .82187 m .49217 .31998 L .44804 .31744 L p .707 .577 .707 r
F P
0 g
s
.49929 .70684 m .50732 .65098 L .51432 .64539 L p .707 .577 .707 r
F P
0 g
s
.50134 .82022 m .50335 .80158 L .50042 .79412 L p .707 .577 .707 r
F P
0 g
s
.50042 .79412 m .49841 .81276 L .50134 .82022 L p .707 .577 .707 r
F P
0 g
s
.51432 .64539 m .50629 .70125 L .49929 .70684 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .51008 .809 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49967 .76305 m .50268 .77659 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.50268 .77659 m .50751 .79831 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49841 .81276 m .50042 .79412 L .50546 .78959 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .49967 .76305 L .50686 .75073 L p .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50751 .79831 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.50686 .75073 m .5106 .76752 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5106 .76752 m .5147 .78599 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50686 .75073 L .52312 .73796 L p .707 .577 .707 r
F P
0 g
s
.52312 .73796 m .53096 .77322 L .5147 .78599 L p .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .50742 .78783 L .51927 .78454 L p .707 .577 .707 r
F P
0 g
s
.51927 .78454 m .52366 .78332 L p .52062 .78718 L .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .51927 .78454 L .52062 .78718 L .707 .577 .707 r
F
.50546 .78959 m .50742 .78783 L p .50595 .79189 L F P
0 g
s
.49841 .81276 m .50546 .78959 L .50595 .79189 L .707 .577 .707 r
F
.50629 .70125 m .51432 .64539 L .53052 .64184 L p F P
0 g
s
.50742 .78783 m .50541 .80647 L .49841 .81276 L p .707 .577 .707 r
F P
0 g
s
.53052 .64184 m .52249 .6977 L .50629 .70125 L p .707 .577 .707 r
F P
0 g
s
.52249 .6977 m .53052 .64184 L .55433 .64069 L p .707 .577 .707 r
F P
0 g
s
.55433 .64069 m .5463 .69655 L .52249 .6977 L p .707 .577 .707 r
F P
0 g
s
.52366 .78332 m .52165 .80196 L .50541 .80647 L p .707 .577 .707 r
F P
0 g
s
.53096 .77322 m .52312 .73796 L .54684 .72602 L p .707 .577 .707 r
F P
0 g
s
.52165 .80196 m .52366 .78332 L .54755 .78103 L p .707 .577 .707 r
F P
0 g
s
.54684 .72602 m .55468 .76128 L .53096 .77322 L p .707 .577 .707 r
F P
0 g
s
.54755 .78103 m .54554 .79966 L .52165 .80196 L p .707 .577 .707 r
F P
0 g
s
.49217 .31998 m .49217 .82187 L .53706 .82062 L p .707 .577 .707 r
F P
0 g
s
.53706 .82062 m .53706 .31874 L .49217 .31998 L p .707 .577 .707 r
F P
0 g
s
.69623 .82415 m .69422 .84279 L .70121 .8365 L p .707 .577 .707 r
F P
0 g
s
.70121 .8365 m .70322 .81786 L .69623 .82415 L p .707 .577 .707 r
F P
0 g
s
.5463 .69655 m .55433 .64069 L .58342 .64204 L p .707 .577 .707 r
F P
0 g
s
.58342 .64204 m .57539 .6979 L .5463 .69655 L p .707 .577 .707 r
F P
0 g
s
.55468 .76128 m .54684 .72602 L .57571 .71606 L p .707 .577 .707 r
F P
0 g
s
.57571 .71606 m .58355 .75132 L .55468 .76128 L p .707 .577 .707 r
F P
0 g
s
.54554 .79966 m .54755 .78103 L .57675 .78118 L p .707 .577 .707 r
F P
0 g
s
.57675 .78118 m .57474 .79981 L .54554 .79966 L p .707 .577 .707 r
F P
0 g
s
.57474 .79981 m .57675 .78118 L .60841 .78376 L p .707 .577 .707 r
F P
0 g
s
.60841 .78376 m .6064 .80239 L .57474 .79981 L p .707 .577 .707 r
F P
0 g
s
.53706 .31874 m .53706 .82062 L .57832 .81572 L p .707 .577 .707 r
F P
0 g
s
.57539 .6979 m .58342 .64204 L .61494 .64576 L p .707 .577 .707 r
F P
0 g
s
.61494 .64576 m .60691 .70162 L .57539 .6979 L p .707 .577 .707 r
F P
0 g
s
.58355 .75132 m .57571 .71606 L .6069 .70906 L p .707 .577 .707 r
F P
0 g
s
.57832 .81572 m .57832 .31383 L .53706 .31874 L p .707 .577 .707 r
F P
0 g
s
.44804 .81932 m .44804 .31744 L .409 .31136 L p .707 .577 .707 r
F P
0 g
s
.44804 .31744 m .44804 .81932 L .49217 .82187 L p .707 .577 .707 r
F P
0 g
s
.6069 .70906 m .61474 .74432 L .58355 .75132 L p .707 .577 .707 r
F P
0 g
s
.63942 .78851 m .63741 .80715 L .6064 .80239 L p .707 .577 .707 r
F P
0 g
s
.6064 .80239 m .60841 .78376 L .63942 .78851 L p .707 .577 .707 r
F P
0 g
s
.57832 .31383 m .57832 .81572 L .61192 .80764 L p .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6641 .70632 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63875 .71196 m .63736 .7057 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6452 .74096 L .61474 .74432 L p .707 .577 .707 r
F P
0 g
s
.61474 .74432 m .6069 .70906 L .63736 .7057 L p .707 .577 .707 r
F P
0 g
s
.64582 .65148 m .63779 .70734 L .63471 .70677 L p .707 .577 .707 r
F P
0 g
s
.63471 .70677 m .60691 .70162 L p .61879 .68631 L .707 .577 .707 r
F P
0 g
s
.61879 .68631 m .64582 .65148 L .63471 .70677 L .707 .577 .707 r
F
.6452 .74096 m .63875 .71196 L p .65184 .72878 L F P
0 g
s
.60691 .70162 m .61494 .64576 L .64582 .65148 L p .707 .577 .707 r
F P
0 g
s
.61192 .80764 m .61192 .30575 L .57832 .31383 L p .707 .577 .707 r
F P
0 g
s
.25234 .72468 m .25581 .67188 L .22466 .66738 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .28659 .75071 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25581 .67188 m .25234 .72468 L .25665 .72475 L p .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .25581 .67188 L .25665 .72475 L .707 .577 .707 r
F
.22466 .66738 m .22267 .69777 L p .25234 .72468 L F P
0 g
s
.22267 .69777 m .2212 .72018 L .25202 .72463 L p .707 .577 .707 r
F P
0 g
s
.25202 .72463 m .25234 .72468 L p .22267 .69777 L .707 .577 .707 r
F P
0 g
s
.25148 .71546 m .25232 .7249 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25232 .7249 m .25232 .72491 L p .25233 .72491 L .707 .577 .707 r
F P
0 g
s
.26059 .72461 m .25232 .7249 L .25233 .72491 L .707 .577 .707 r
F
.25232 .72491 m .25488 .7537 L p .26059 .72461 L F P
0 g
s
.28757 .67243 m .25581 .67188 L p .28272 .7226 L .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .2834 .72313 L .28272 .7226 L .707 .577 .707 r
F
.2834 .72313 m .28757 .67243 L .28272 .7226 L F
.28421 .72375 m .28757 .67243 L p .28334 .72378 L F P
0 g
s
.31588 .74729 m .29284 .72274 L .28421 .72376 L .707 .577 .707 r
F
.2842 .72375 m .28659 .75071 L .3147 .74743 L p F P
0 g
s
.28757 .67243 m .28421 .72376 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.3147 .74743 m .31588 .74729 L p .2842 .72375 L .707 .577 .707 r
F P
0 g
s
.28659 .75071 m .2842 .72375 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.31686 .66897 m .28757 .67243 L p .312 .7191 L .707 .577 .707 r
F P
0 g
s
.31268 .72041 m .31274 .71971 L .312 .7191 L .707 .577 .707 r
F
.31274 .71971 m .31686 .66897 L .312 .7191 L F
.31588 .74729 m .33987 .74379 L p .33557 .73834 L F P
0 g
s
.31349 .72031 m .31686 .66897 L p .31274 .71971 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31274 .71971 L .31268 .72041 L .707 .577 .707 r
F
.31349 .72031 m .31274 .71971 L .31348 .72031 L F
.33987 .74379 m .35622 .74055 L p .35005 .72962 L F P
0 g
s
.31686 .66897 m .31549 .68977 L p .33733 .71464 L .707 .577 .707 r
F P
0 g
s
.33733 .71464 m .31549 .68977 L .33711 .7147 L .707 .577 .707 r
F
.33348 .71579 m .33733 .71464 L p .31349 .72032 L F P
0 g
s
.33733 .71464 m .34079 .66184 L .31686 .66897 L p .707 .577 .707 r
F P
0 g
s
.34079 .66184 m .33733 .71464 L .35357 .70455 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .33731 .71492 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.33731 .71492 m .33987 .74379 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.31549 .68977 m .31349 .72032 L p .33711 .7147 L .707 .577 .707 r
F P
0 g
s
.33557 .73834 m .33621 .71517 L .32017 .71881 L .707 .577 .707 r
F
.31249 .70906 m .31348 .72031 L p .33557 .73834 L F P
0 g
s
.31348 .72031 m .31588 .74729 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31588 .74729 m .31348 .72031 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31349 .72032 m .31339 .72177 L .33348 .71579 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .31249 .70906 L p .32017 .71881 L .707 .577 .707 r
F P
0 g
s
.33621 .71517 m .33648 .70556 L .32017 .71881 L .707 .577 .707 r
F
.33987 .74379 m .33968 .7417 L p .33557 .73834 L F P
0 g
s
.33968 .7417 m .33648 .70556 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31249 .70906 m .2832 .71247 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31249 .70906 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31339 .72177 m .31349 .72031 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .31339 .72177 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28421 .72376 m .28411 .72523 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.2832 .71247 m .2842 .72375 L p .28421 .72376 L .707 .577 .707 r
F P
0 g
s
.29284 .72274 m .2832 .71247 L .28421 .72376 L .707 .577 .707 r
F
.2832 .71247 m .25148 .71546 L p .26059 .72461 L F P
0 g
s
.2842 .72375 m .2832 .71247 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .28421 .72375 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.25665 .72475 m .28411 .72523 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.409 .81325 m .409 .31136 L .37887 .30235 L p .707 .577 .707 r
F P
0 g
s
.409 .31136 m .409 .81325 L .44804 .81932 L p .707 .577 .707 r
F P
0 g
s
.70322 .81786 m .70121 .8365 L .69829 .82905 L p .707 .577 .707 r
F P
0 g
s
.69829 .82905 m .7003 .81041 L .70322 .81786 L p .707 .577 .707 r
F P
0 g
s
.2212 .72018 m .22466 .66738 L .1972 .65936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19374 .71216 m .1972 .65936 L .1761 .64862 L p .707 .577 .707 r
F P
0 g
s
.1972 .65936 m .19521 .68975 L p .2212 .72018 L .707 .577 .707 r
F P
0 g
s
.21751 .7191 m .2212 .72018 L p .19521 .68975 L .707 .577 .707 r
F P
0 g
s
.22044 .71774 m .22097 .72365 L p .25488 .7537 L .707 .577 .707 r
F P
0 g
s
.22097 .72365 m .22384 .75597 L .24438 .75446 L p .707 .577 .707 r
F P
0 g
s
.24438 .75446 m .25488 .7537 L p .22097 .72365 L .707 .577 .707 r
F P
0 g
s
.19521 .68975 m .19374 .71216 L .21751 .7191 L p .707 .577 .707 r
F P
0 g
s
.61192 .30575 m .61192 .80764 L .63456 .79716 L p .707 .577 .707 r
F P
0 g
s
.63456 .79716 m .63456 .29527 L .61192 .30575 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .25148 .71546 L .22044 .71774 L p .707 .577 .707 r
F P
0 g
s
.22384 .75597 m .22044 .71774 L .19312 .71908 L p .707 .577 .707 r
F P
0 g
s
.7003 .81041 m .69829 .82905 L .68572 .82116 L p .707 .577 .707 r
F P
0 g
s
.68572 .82116 m .68773 .80252 L .7003 .81041 L p .707 .577 .707 r
F P
0 g
s
.19312 .71908 m .19651 .75731 L .22384 .75597 L p .707 .577 .707 r
F P
0 g
s
.37887 .80423 m .37887 .30235 L .3606 .29127 L p .707 .577 .707 r
F P
0 g
s
.37887 .30235 m .37887 .80423 L .409 .81325 L p .707 .577 .707 r
F P
0 g
s
.35357 .70455 m .35703 .65175 L .34079 .66184 L p .707 .577 .707 r
F P
0 g
s
.17263 .70142 m .1761 .64862 L .16342 .6362 L p .707 .577 .707 r
F P
0 g
s
.1761 .64862 m .17263 .70142 L .19374 .71216 L p .707 .577 .707 r
F P
0 g
s
.25213 .82381 m .253 .80594 L .22184 .80207 L p .707 .577 .707 r
F P
0 g
s
.253 .80594 m .25213 .82381 L .28393 .82404 L p .707 .577 .707 r
F P
0 g
s
.28393 .82404 m .28479 .80617 L .253 .80594 L p .707 .577 .707 r
F P
0 g
s
.19651 .75731 m .19312 .71908 L .17218 .71935 L p .707 .577 .707 r
F P
0 g
s
.28479 .80617 m .28393 .82404 L .31324 .82061 L p .707 .577 .707 r
F P
0 g
s
.31324 .82061 m .3141 .80274 L .28479 .80617 L p .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .66498 .71452 L .63779 .70734 L p .707 .577 .707 r
F P
0 g
s
.63779 .70734 m .64582 .65148 L .67301 .65866 L p .707 .577 .707 r
F P
0 g
s
.17218 .71935 m .17557 .75758 L .19651 .75731 L p .707 .577 .707 r
F P
0 g
s
.22097 .81995 m .22184 .80207 L .19435 .79495 L p .707 .577 .707 r
F P
0 g
s
.22184 .80207 m .22097 .81995 L .25213 .82381 L p .707 .577 .707 r
F P
0 g
s
.19435 .79495 m .19349 .81282 L .22097 .81995 L p .707 .577 .707 r
F P
0 g
s
.35622 .74055 m .35282 .70231 L .33648 .70556 L p .707 .577 .707 r
F P
0 g
s
.63741 .80715 m .63942 .78851 L .66675 .79498 L p .707 .577 .707 r
F P
0 g
s
.63456 .29527 m .63456 .79716 L .64403 .78532 L p .707 .577 .707 r
F P
0 g
s
.64403 .78532 m .64403 .28343 L .63456 .29527 L p .707 .577 .707 r
F P
0 g
s
.3141 .80274 m .31324 .82061 L .3372 .81385 L p .707 .577 .707 r
F P
0 g
s
.3372 .81385 m .33806 .79598 L .3141 .80274 L p .707 .577 .707 r
F P
0 g
s
.68773 .80252 m .68572 .82116 L .66474 .81362 L p .707 .577 .707 r
F P
0 g
s
.66474 .81362 m .66675 .79498 L .68773 .80252 L p .707 .577 .707 r
F P
0 g
s
.35703 .65175 m .35357 .70455 L .36053 .69247 L p .707 .577 .707 r
F P
0 g
s
.36053 .69247 m .36399 .63967 L .35703 .65175 L p .707 .577 .707 r
F P
0 g
s
.19349 .81282 m .19435 .79495 L .17324 .78525 L p .707 .577 .707 r
F P
0 g
s
.16342 .6362 m .15996 .689 L .17263 .70142 L p .707 .577 .707 r
F P
0 g
s
.15996 .689 m .16342 .6362 L .16042 .62333 L p .707 .577 .707 r
F P
0 g
s
.17557 .75758 m .17218 .71935 L .15968 .71852 L p .707 .577 .707 r
F P
0 g
s
.17324 .78525 m .17237 .80312 L .19349 .81282 L p .707 .577 .707 r
F P
0 g
s
.35282 .70231 m .35622 .74055 L .36332 .73787 L p .707 .577 .707 r
F P
0 g
s
.36332 .73787 m .35992 .69964 L .35282 .70231 L p .707 .577 .707 r
F P
0 g
s
.36399 .63967 m .36053 .69247 L .35753 .67959 L p .707 .577 .707 r
F P
0 g
s
.35753 .67959 m .36099 .62679 L .36399 .63967 L p .707 .577 .707 r
F P
0 g
s
.36043 .79326 m .3613 .77539 L .35433 .78656 L p .707 .577 .707 r
F P
0 g
s
.35992 .69964 m .36332 .73787 L .36048 .73603 L p .707 .577 .707 r
F P
0 g
s
.36048 .73603 m .35709 .6978 L .35992 .69964 L p .707 .577 .707 r
F P
0 g
s
.36099 .62679 m .35753 .67959 L .34485 .66717 L p .707 .577 .707 r
F P
0 g
s
.34485 .66717 m .34832 .61437 L .36099 .62679 L p .707 .577 .707 r
F P
0 g
s
.3613 .77539 m .36043 .79326 L .35744 .78145 L p .707 .577 .707 r
F P
0 g
s
.35744 .78145 m .3583 .76358 L .3613 .77539 L p .707 .577 .707 r
F P
0 g
s
.35709 .6978 m .36048 .73603 L .34798 .73521 L p .707 .577 .707 r
F P
0 g
s
.3606 .79316 m .3606 .29127 L .35597 .27923 L p .707 .577 .707 r
F P
0 g
s
.3606 .29127 m .3606 .79316 L .37887 .80423 L p .707 .577 .707 r
F P
0 g
s
.15968 .71852 m .16307 .75675 L .17557 .75758 L p .707 .577 .707 r
F P
0 g
s
.33806 .79598 m .3372 .81385 L .35346 .80443 L p .707 .577 .707 r
F P
0 g
s
.35346 .80443 m .35433 .78656 L .33806 .79598 L p .707 .577 .707 r
F P
0 g
s
.66675 .79498 m .66474 .81362 L .63741 .80715 L p .707 .577 .707 r
F P
0 g
s
.17237 .80312 m .17324 .78525 L .16056 .77395 L p .707 .577 .707 r
F P
0 g
s
.16042 .62333 m .15695 .67613 L .15996 .689 L p .707 .577 .707 r
F P
0 g
s
.16056 .77395 m .1597 .79182 L .17237 .80312 L p .707 .577 .707 r
F P
0 g
s
.15695 .67613 m .16042 .62333 L .16738 .61125 L p .707 .577 .707 r
F P
0 g
s
.16307 .75675 m .15968 .71852 L .15684 .71668 L p .707 .577 .707 r
F P
0 g
s
.64403 .28343 m .64403 .78532 L .6394 .77327 L p .707 .577 .707 r
F P
0 g
s
.6394 .77327 m .6394 .27139 L .64403 .28343 L p .707 .577 .707 r
F P
0 g
s
.15684 .71668 m .16024 .75491 L .16307 .75675 L p .707 .577 .707 r
F P
0 g
s
.35433 .78656 m .35346 .80443 L .36043 .79326 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1597 .79182 m .16056 .77395 L .15756 .76213 L p .707 .577 .707 r
F P
0 g
s
.34798 .73521 m .34459 .69698 L .35709 .6978 L p .707 .577 .707 r
F P
0 g
s
.3583 .76358 m .35744 .78145 L .34476 .77014 L p .707 .577 .707 r
F P
0 g
s
.34476 .77014 m .34563 .75227 L .3583 .76358 L p .707 .577 .707 r
F P
0 g
s
.35597 .27923 m .35597 .78112 L .3606 .79316 L p .707 .577 .707 r
F P
0 g
s
.35597 .78112 m .35597 .27923 L .36544 .26739 L p .707 .577 .707 r
F P
0 g
s
.16738 .61125 m .16391 .66405 L .15695 .67613 L p .707 .577 .707 r
F P
0 g
s
.15756 .76213 m .1567 .78001 L .1597 .79182 L p .707 .577 .707 r
F P
0 g
s
.16391 .66405 m .16738 .61125 L .18362 .60115 L p .707 .577 .707 r
F P
0 g
s
.16024 .75491 m .15684 .71668 L .16394 .71401 L p .707 .577 .707 r
F P
0 g
s
.16394 .71401 m .16734 .75224 L .16024 .75491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1567 .78001 m .15756 .76213 L .16454 .75097 L p .707 .577 .707 r
F P
0 g
s
.6394 .27139 m .6394 .77327 L .62113 .7622 L p .707 .577 .707 r
F P
0 g
s
.62113 .7622 m .62113 .26031 L .6394 .27139 L p .707 .577 .707 r
F P
0 g
s
.34832 .61437 m .34485 .66717 L .32375 .65643 L p .707 .577 .707 r
F P
0 g
s
.32375 .65643 m .32721 .60363 L .34832 .61437 L p .707 .577 .707 r
F P
0 g
s
.18362 .60115 m .18016 .65395 L .16391 .66405 L p .707 .577 .707 r
F P
0 g
s
.16454 .75097 m .16367 .76884 L .1567 .78001 L p .707 .577 .707 r
F P
0 g
s
.18016 .65395 m .18362 .60115 L .20755 .59403 L p .707 .577 .707 r
F P
0 g
s
.36544 .76928 m .36544 .26739 L .38808 .25691 L p .707 .577 .707 r
F P
0 g
s
.36544 .26739 m .36544 .76928 L .35597 .78112 L p .707 .577 .707 r
F P
0 g
s
.16734 .75224 m .16394 .71401 L .18029 .71076 L p .707 .577 .707 r
F P
0 g
s
.18029 .71076 m .18368 .74899 L .16734 .75224 L p .707 .577 .707 r
F P
0 g
s
.32721 .60363 m .32375 .65643 L .29628 .64842 L p .707 .577 .707 r
F P
0 g
s
.29628 .64842 m .29975 .59562 L .32721 .60363 L p .707 .577 .707 r
F P
0 g
s
.20409 .64683 m .20755 .59403 L .23684 .59057 L p .707 .577 .707 r
F P
0 g
s
.20755 .59403 m .20409 .64683 L .18016 .65395 L p .707 .577 .707 r
F P
0 g
s
.16367 .76884 m .16454 .75097 L .1808 .74155 L p .707 .577 .707 r
F P
0 g
s
.34459 .69698 m .34798 .73521 L .32704 .73548 L p .707 .577 .707 r
F P
0 g
s
.32704 .73548 m .32365 .69725 L .34459 .69698 L p .707 .577 .707 r
F P
0 g
s
.1808 .74155 m .17994 .75942 L .16367 .76884 L p .707 .577 .707 r
F P
0 g
s
.29975 .59562 m .29628 .64842 L .26514 .64392 L p .707 .577 .707 r
F P
0 g
s
.26514 .64392 m .26861 .59112 L .29975 .59562 L p .707 .577 .707 r
F P
0 g
s
.23338 .64337 m .23684 .59057 L .26861 .59112 L p .707 .577 .707 r
F P
0 g
s
.23684 .59057 m .23338 .64337 L .20409 .64683 L p .707 .577 .707 r
F P
0 g
s
.62113 .26031 m .62113 .7622 L .591 .75319 L p .707 .577 .707 r
F P
0 g
s
.591 .75319 m .591 .2513 L .62113 .26031 L p .707 .577 .707 r
F P
0 g
s
.26861 .59112 m .26514 .64392 L .23338 .64337 L p .707 .577 .707 r
F P
0 g
s
.18368 .74899 m .18029 .71076 L .20428 .70726 L p .707 .577 .707 r
F P
0 g
s
.34563 .75227 m .34476 .77014 L .32365 .76045 L p .707 .577 .707 r
F P
0 g
s
.32365 .76045 m .32451 .74258 L .34563 .75227 L p .707 .577 .707 r
F P
0 g
s
.20428 .70726 m .20767 .74549 L .18368 .74899 L p .707 .577 .707 r
F P
0 g
s
.38808 .25691 m .38808 .7588 L .36544 .76928 L p .707 .577 .707 r
F P
0 g
s
.38808 .7588 m .38808 .25691 L .42168 .24883 L p .707 .577 .707 r
F P
0 g
s
.17994 .75942 m .1808 .74155 L .20476 .73479 L p .707 .577 .707 r
F P
0 g
s
.73485 .64433 m .73139 .58724 L .70025 .58818 L p .707 .577 .707 r
F P
0 g
s
.73139 .58724 m .73485 .64433 L .76662 .64204 L p .707 .577 .707 r
F P
0 g
s
.76662 .64204 m .76316 .58495 L .73139 .58724 L p .707 .577 .707 r
F P
0 g
s
.32365 .69725 m .32704 .73548 L .29972 .73682 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .29632 .69858 L .32365 .69725 L p .707 .577 .707 r
F P
0 g
s
.76316 .58495 m .76662 .64204 L .79591 .63862 L p .707 .577 .707 r
F P
0 g
s
.79591 .63862 m .79244 .58153 L .76316 .58495 L p .707 .577 .707 r
F P
0 g
s
.20476 .73479 m .20389 .75266 L .17994 .75942 L p .707 .577 .707 r
F P
0 g
s
.70371 .64527 m .70025 .58818 L .67278 .58767 L p .707 .577 .707 r
F P
0 g
s
.70025 .58818 m .70371 .64527 L .73485 .64433 L p .707 .577 .707 r
F P
0 g
s
.20767 .74549 m .20428 .70726 L .23357 .70385 L p .707 .577 .707 r
F P
0 g
s
.32451 .74258 m .32365 .76045 L .29616 .75332 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .26868 .73909 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29632 .69858 m .29779 .7151 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29779 .7151 m .29972 .73682 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .29703 .73545 L .31522 .74017 L p .707 .577 .707 r
F P
0 g
s
.31522 .74017 m .32451 .74258 L p .31849 .74486 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .31522 .74017 L .31849 .74486 L .707 .577 .707 r
F
.23357 .70385 m .23696 .74208 L .20767 .74549 L p F P
0 g
s
.67278 .58767 m .67625 .64476 L .70371 .64527 L p .707 .577 .707 r
F P
0 g
s
.79244 .58153 m .79591 .63862 L .81984 .63441 L p .707 .577 .707 r
F P
0 g
s
.81984 .63441 m .81638 .57732 L .79244 .58153 L p .707 .577 .707 r
F P
0 g
s
.591 .2513 m .591 .75319 L .55196 .74711 L p .707 .577 .707 r
F P
0 g
s
.55196 .74711 m .55196 .24522 L .591 .2513 L p .707 .577 .707 r
F P
0 g
s
.20389 .75266 m .20476 .73479 L .23407 .73136 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .26528 .70086 L .29632 .69858 L p .707 .577 .707 r
F P
0 g
s
.23696 .74208 m .23357 .70385 L .26528 .70086 L p .707 .577 .707 r
F P
0 g
s
.67625 .64476 m .67278 .58767 L .65168 .58576 L p .707 .577 .707 r
F P
0 g
s
.735 .75033 m .73413 .73138 L .71389 .73153 L p .707 .577 .707 r
F P
0 g
s
.71389 .73153 m .70297 .7316 L p .70966 .73551 L .707 .577 .707 r
F P
0 g
s
.735 .75033 m .71389 .73153 L .70966 .73551 L .707 .577 .707 r
F
.73413 .73138 m .735 .75033 L .76679 .74842 L p F P
0 g
s
.76679 .74842 m .76593 .72947 L .74717 .7306 L p .707 .577 .707 r
F P
0 g
s
.74717 .7306 m .73413 .73138 L p .74211 .73554 L .707 .577 .707 r
F P
0 g
s
.76679 .74842 m .74717 .7306 L .74211 .73554 L .707 .577 .707 r
F
.76593 .72947 m .76679 .74842 L .7961 .74501 L p F P
0 g
s
.7961 .74501 m .79524 .72606 L .77973 .72787 L p .707 .577 .707 r
F P
0 g
s
.77973 .72787 m .76593 .72947 L p .77476 .73402 L .707 .577 .707 r
F P
0 g
s
.7961 .74501 m .77973 .72787 L .77476 .73402 L .707 .577 .707 r
F
.79524 .72606 m .7961 .74501 L .82006 .74042 L p F P
0 g
s
.82006 .74042 m .8192 .72148 L .80787 .72364 L p .707 .577 .707 r
F P
0 g
s
.80787 .72364 m .79524 .72606 L p .804 .73113 L .707 .577 .707 r
F P
0 g
s
.82006 .74042 m .80787 .72364 L .804 .73113 L .707 .577 .707 r
F
.8192 .72148 m .82006 .74042 L .83633 .73512 L p F P
0 g
s
.83633 .73512 m .83546 .71618 L .8192 .72148 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .83266 .71377 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81971 .69107 m .81851 .70309 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81851 .70309 m .81631 .72509 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .81631 .72509 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79572 .69884 m .79467 .70936 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79467 .70936 m .79232 .73287 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .79232 .73287 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76643 .70231 m .76538 .71279 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76538 .71279 m .76304 .73633 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .76304 .73633 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73471 .70112 m .73352 .71305 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73352 .71305 m .73132 .73515 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .73471 .70112 L .70367 .6954 L p .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .76643 .70231 L .73471 .70112 L p .707 .577 .707 r
F P
0 g
s
.23407 .73136 m .23321 .74923 L .20389 .75266 L p .707 .577 .707 r
F P
0 g
s
.42168 .75072 m .42168 .24883 L .46294 .24392 L p .707 .577 .707 r
F P
0 g
s
.42168 .24883 m .42168 .75072 L .38808 .7588 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .23696 .74208 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.26647 .71427 m .26868 .73909 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .26586 .73158 L .28611 .7341 L p .707 .577 .707 r
F P
0 g
s
.28611 .7341 m .29703 .73545 L p .29034 .73838 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .28611 .7341 L .29034 .73838 L .707 .577 .707 r
F
.26528 .70086 m .26647 .71427 L p .26033 .70807 L F P
0 g
s
.29703 .73545 m .29616 .75332 L .265 .74946 L p .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .79572 .69884 L .76643 .70231 L p .707 .577 .707 r
F P
0 g
s
.70028 .72943 m .70367 .6954 L .67635 .68571 L p .707 .577 .707 r
F P
0 g
s
.70367 .6954 m .70028 .72943 L .73132 .73515 L p .707 .577 .707 r
F P
0 g
s
.23321 .74923 m .23407 .73136 L .26586 .73158 L p .707 .577 .707 r
F P
0 g
s
.65168 .58576 m .65514 .64285 L .67625 .64476 L p .707 .577 .707 r
F P
0 g
s
.26586 .73158 m .265 .74946 L .23321 .74923 L p .707 .577 .707 r
F P
0 g
s
.81638 .57732 m .81984 .63441 L .83608 .6298 L p .707 .577 .707 r
F P
0 g
s
.83608 .6298 m .83262 .57271 L .81638 .57732 L p .707 .577 .707 r
F P
0 g
s
.70297 .7316 m .70383 .75055 L .735 .75033 L p .707 .577 .707 r
F P
0 g
s
.55196 .24522 m .55196 .74711 L .50783 .74457 L p .707 .577 .707 r
F P
0 g
s
.50783 .74457 m .50783 .24268 L .55196 .24522 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .81971 .69107 L .79572 .69884 L p .707 .577 .707 r
F P
0 g
s
.70383 .75055 m .70297 .7316 L .67549 .73011 L p .707 .577 .707 r
F P
0 g
s
.46294 .74581 m .46294 .24392 L .50783 .24268 L p .707 .577 .707 r
F P
0 g
s
.46294 .24392 m .46294 .74581 L .42168 .75072 L p .707 .577 .707 r
F P
0 g
s
.67295 .71974 m .67635 .68571 L .65541 .67299 L p .707 .577 .707 r
F P
0 g
s
.67635 .68571 m .67295 .71974 L .70028 .72943 L p .707 .577 .707 r
F P
0 g
s
.67549 .73011 m .67635 .74906 L .70383 .75055 L p .707 .577 .707 r
F P
0 g
s
.50783 .24268 m .50783 .74457 L .46294 .74581 L p .707 .577 .707 r
F P
0 g
s
.65514 .64285 m .65168 .58576 L .63901 .58264 L p .707 .577 .707 r
F P
0 g
s
.63901 .58264 m .64247 .63973 L .65514 .64285 L p .707 .577 .707 r
F P
0 g
s
.67635 .74906 m .67549 .73011 L .65437 .72706 L p .707 .577 .707 r
F P
0 g
s
.83266 .71377 m .83605 .67974 L .81971 .69107 L p .707 .577 .707 r
F P
0 g
s
.65437 .72706 m .65524 .746 L .67635 .74906 L p .707 .577 .707 r
F P
0 g
s
.65541 .67299 m .65202 .70702 L .67295 .71974 L p .707 .577 .707 r
F P
0 g
s
.65202 .70702 m .65541 .67299 L .64291 .65849 L p .707 .577 .707 r
F P
0 g
s
.83262 .57271 m .83608 .6298 L .84304 .62527 L p .707 .577 .707 r
F P
0 g
s
.84304 .62527 m .83958 .56818 L .83262 .57271 L p .707 .577 .707 r
F P
0 g
s
.64247 .63973 m .63901 .58264 L .636 .57862 L p .707 .577 .707 r
F P
0 g
s
.65524 .746 m .65437 .72706 L .6417 .72274 L p .707 .577 .707 r
F P
0 g
s
.64291 .65849 m .63952 .69252 L .65202 .70702 L p .707 .577 .707 r
F P
0 g
s
.6417 .72274 m .64256 .74168 L .65524 .746 L p .707 .577 .707 r
F P
0 g
s
.636 .57862 m .63947 .63571 L .64247 .63973 L p .707 .577 .707 r
F P
0 g
s
.83605 .67974 m .83266 .71377 L .83976 .7 L p .707 .577 .707 r
F P
0 g
s
.83976 .7 m .84316 .66598 L .83605 .67974 L p .707 .577 .707 r
F P
0 g
s
.63952 .69252 m .64291 .65849 L .64007 .64363 L p .707 .577 .707 r
F P
0 g
s
.83958 .56818 m .84304 .62527 L .84004 .62125 L p .707 .577 .707 r
F P
0 g
s
.84004 .62125 m .83658 .56416 L .83958 .56818 L p .707 .577 .707 r
F P
0 g
s
.83546 .71618 m .83633 .73512 L .8433 .72962 L p .707 .577 .707 r
F P
0 g
s
.8433 .72962 m .84243 .71067 L .83546 .71618 L p .707 .577 .707 r
F P
0 g
s
.64007 .64363 m .63668 .67766 L .63952 .69252 L p .707 .577 .707 r
F P
0 g
s
.63947 .63571 m .636 .57862 L .64296 .57409 L p .707 .577 .707 r
F P
0 g
s
.64256 .74168 m .6417 .72274 L .6387 .71757 L p .707 .577 .707 r
F P
0 g
s
.6387 .71757 m .63956 .73652 L .64256 .74168 L p .707 .577 .707 r
F P
0 g
s
.84316 .66598 m .83976 .7 L .83693 .68515 L p .707 .577 .707 r
F P
0 g
s
.83693 .68515 m .84032 .65112 L .84316 .66598 L p .707 .577 .707 r
F P
0 g
s
.64296 .57409 m .64643 .63118 L .63947 .63571 L p .707 .577 .707 r
F P
0 g
s
.63668 .67766 m .64007 .64363 L .64718 .62987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83658 .56416 m .84004 .62125 L .82737 .61813 L p .707 .577 .707 r
F P
0 g
s
.82737 .61813 m .8239 .56104 L .83658 .56416 L p .707 .577 .707 r
F P
0 g
s
.84243 .71067 m .8433 .72962 L .8403 .72445 L p .707 .577 .707 r
F P
0 g
s
.8403 .72445 m .83944 .70551 L .84243 .71067 L p .707 .577 .707 r
F P
0 g
s
.39308 .62674 m .38505 .57272 L .35418 .57452 L p .707 .577 .707 r
F P
0 g
s
.38505 .57272 m .39308 .62674 L .42461 .62161 L p .707 .577 .707 r
F P
0 g
s
.42461 .62161 m .41658 .56758 L .38505 .57272 L p .707 .577 .707 r
F P
0 g
s
.41658 .56758 m .42461 .62161 L .4537 .61364 L p .707 .577 .707 r
F P
0 g
s
.4537 .61364 m .44567 .55961 L .41658 .56758 L p .707 .577 .707 r
F P
0 g
s
.65921 .56949 m .65992 .58131 L p .64643 .63118 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .64718 .62987 L .66352 .61854 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .64378 .6639 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .66269 .62688 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66013 .65257 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .68751 .61077 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .6866 .62236 L .66652 .6259 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .66269 .62688 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66352 .61854 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .66013 .65257 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .68651 .62079 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .68412 .6448 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .7168 .60731 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L .68732 .62069 L .707 .577 .707 r
F
.68651 .62079 m .68751 .61077 L p .70716 .61836 L F P
0 g
s
.71589 .61894 m .6866 .62236 L p .68732 .62069 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .71426 .61753 L .71589 .61894 L .707 .577 .707 r
F
.71341 .64133 m .68412 .6448 L p .70716 .61836 L F P
0 g
s
.7168 .60731 m .7158 .61734 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.7168 .60731 m .74852 .60849 L p .7394 .61701 L .707 .577 .707 r
F P
0 g
s
.74335 .61696 m .71589 .61894 L p .71665 .61733 L .707 .577 .707 r
F P
0 g
s
.72838 .62732 m .72255 .61725 L .7394 .61701 L .707 .577 .707 r
F
.72255 .61725 m .7168 .60731 L .7394 .61701 L F
.74852 .60849 m .74768 .61689 L p .71341 .64133 L F P
0 g
s
.74768 .61689 m .74512 .64252 L .71891 .64154 L p .707 .577 .707 r
F P
0 g
s
.71891 .64154 m .71341 .64133 L p .74768 .61689 L .707 .577 .707 r
F P
0 g
s
.74512 .64252 m .74852 .60849 L .77956 .61421 L p .707 .577 .707 r
F P
0 g
s
.77533 .55862 m .77733 .59149 L p .74766 .61665 L .707 .577 .707 r
F P
0 g
s
.77956 .61421 m .77903 .61947 L p .74512 .64252 L .707 .577 .707 r
F P
0 g
s
.77903 .61947 m .77616 .64824 L .75562 .64445 L p .707 .577 .707 r
F P
0 g
s
.75562 .64445 m .74512 .64252 L p .77903 .61947 L .707 .577 .707 r
F P
0 g
s
.77616 .64824 m .77956 .61421 L .80688 .6239 L p .707 .577 .707 r
F P
0 g
s
.8028 .55913 m .80479 .59199 L p .7788 .61571 L .707 .577 .707 r
F P
0 g
s
.80479 .59199 m .80626 .61622 L .78249 .61578 L p .707 .577 .707 r
F P
0 g
s
.78249 .61578 m .7788 .61571 L p .80479 .59199 L .707 .577 .707 r
F P
0 g
s
.77733 .59149 m .7788 .61571 L .74797 .61664 L p .707 .577 .707 r
F P
0 g
s
.74797 .61664 m .74766 .61665 L p .77733 .59149 L .707 .577 .707 r
F P
0 g
s
.74419 .55956 m .74766 .61665 L .74335 .61696 L p .707 .577 .707 r
F P
0 g
s
.71589 .61894 m .7158 .61734 L .71665 .61733 L .707 .577 .707 r
F
.7158 .61735 m .7158 .61734 L p .72838 .62732 L F P
0 g
s
.7158 .61734 m .7168 .60731 L p .72255 .61725 L .707 .577 .707 r
F P
0 g
s
.7158 .61734 m .72255 .61725 L .72838 .62732 L .707 .577 .707 r
F
.71589 .61894 m .71579 .61735 L p .7158 .61734 L F P
0 g
s
.71665 .61733 m .7158 .61734 L .71728 .61602 L .707 .577 .707 r
F
.71665 .61733 m .74419 .55956 L .74335 .61696 L F
.71243 .56185 m .74419 .55956 L p .71728 .61602 L F P
0 g
s
.70716 .61836 m .7158 .61734 L .71579 .61735 L .707 .577 .707 r
F
.71579 .61735 m .71243 .56185 L p .71728 .61602 L F P
0 g
s
.7158 .61734 m .7158 .61735 L p .71579 .61735 L .707 .577 .707 r
F P
0 g
s
.71579 .61734 m .71589 .61894 L p .69558 .60132 L .707 .577 .707 r
F P
0 g
s
.7158 .61735 m .71341 .64133 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .69558 .60132 L .71426 .61753 L .707 .577 .707 r
F
.71243 .56185 m .71579 .61734 L p .69558 .60132 L F P
0 g
s
.71341 .64133 m .7158 .61735 L p .72838 .62732 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .68651 .62079 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .68651 .62079 L .688 .61909 L .707 .577 .707 r
F
.68314 .56527 m .71243 .56185 L p .688 .61909 L F P
0 g
s
.68651 .62079 m .68314 .56527 L p .688 .61909 L .707 .577 .707 r
F P
0 g
s
.6845 .58776 m .68651 .62079 L p .66288 .62654 L .707 .577 .707 r
F P
0 g
s
.66652 .6259 m .66288 .62654 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.68314 .56527 m .6845 .58776 L p .66267 .62658 L .707 .577 .707 r
F P
0 g
s
.66288 .62654 m .66267 .62658 L p .6845 .58776 L .707 .577 .707 r
F P
0 g
s
.65992 .58131 m .66267 .62658 L .6477 .63082 L p .707 .577 .707 r
F P
0 g
s
.64718 .62987 m .64666 .63502 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.6477 .63082 m .64643 .63118 L p .65992 .58131 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .63668 .67766 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.64666 .63502 m .64378 .6639 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36221 .62854 m .35418 .57452 L .32698 .57281 L p .707 .577 .707 r
F P
0 g
s
.35418 .57452 m .36221 .62854 L .39308 .62674 L p .707 .577 .707 r
F P
0 g
s
.64643 .63118 m .64296 .57409 L .65921 .56949 L p .707 .577 .707 r
F P
0 g
s
.63956 .73652 m .6387 .71757 L .64567 .71207 L p .707 .577 .707 r
F P
0 g
s
.84032 .65112 m .83693 .68515 L .82443 .67065 L p .707 .577 .707 r
F P
0 g
s
.82443 .67065 m .82782 .63662 L .84032 .65112 L p .707 .577 .707 r
F P
0 g
s
.44567 .55961 m .4537 .61364 L .47751 .60361 L p .707 .577 .707 r
F P
0 g
s
.47751 .60361 m .46948 .54959 L .44567 .55961 L p .707 .577 .707 r
F P
0 g
s
.64567 .71207 m .64654 .73101 L .63956 .73652 L p .707 .577 .707 r
F P
0 g
s
.38526 .67084 m .3931 .63382 L .36264 .62624 L p .707 .577 .707 r
F P
0 g
s
.3931 .63382 m .38526 .67084 L .41645 .67674 L p .707 .577 .707 r
F P
0 g
s
.41645 .67674 m .42429 .63972 L .3931 .63382 L p .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .30612 .56775 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33495 .62639 m .32698 .57281 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .32914 .58728 L p .36221 .62854 L .707 .577 .707 r
F P
0 g
s
.32914 .58728 m .33501 .62683 L .35953 .62837 L p .707 .577 .707 r
F P
0 g
s
.35953 .62837 m .36221 .62854 L p .32914 .58728 L .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .38526 .67084 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.36264 .62624 m .3616 .63116 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.3616 .63116 m .3548 .66326 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .33411 .62616 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .3096 .59114 L p .33501 .62683 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32805 .65474 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.30764 .64612 m .32805 .65474 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32258 .60969 L .314 .62075 L .707 .577 .707 r
F
.3096 .59114 m .31383 .61962 L p .32258 .60969 L F P
0 g
s
.31383 .61962 m .314 .62075 L p .32258 .60969 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .29364 .55984 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31383 .61962 m .30612 .56775 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31307 .6205 L p .314 .62075 L .707 .577 .707 r
F P
0 g
s
.30598 .62854 m .31108 .61811 L .30466 .61457 L .707 .577 .707 r
F
.30764 .64612 m .31307 .6205 L p .30598 .62854 L F P
0 g
s
.31307 .6205 m .31331 .61934 L p .30598 .62854 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31108 .61811 L .30598 .62854 L .707 .577 .707 r
F
.31307 .6205 m .30764 .64612 L p .3169 .62667 L F P
0 g
s
.31907 .62211 m .314 .62075 L .3169 .62667 L .707 .577 .707 r
F
.314 .62075 m .31307 .6205 L .3169 .62667 L F
.31336 .61936 m .30664 .5991 L .30152 .61284 L F
.29364 .55984 m .30135 .61171 L p .30664 .5991 L F P
0 g
s
.30135 .61171 m .30152 .61284 L p .30664 .5991 L .707 .577 .707 r
F P
0 g
s
.29364 .55984 m .29076 .54986 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .30764 .64612 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.30132 .61178 m .30135 .61171 L .30126 .61144 L .707 .577 .707 r
F
.30152 .61284 m .30135 .61171 L p .30132 .61178 L F P
0 g
s
.30135 .61171 m .29364 .55984 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.30124 .61139 m .29556 .63824 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29773 .62033 m .30078 .61005 L .29945 .60622 L .707 .577 .707 r
F
.301 .61255 m .30124 .61139 L p .29773 .62033 L F P
0 g
s
.30124 .61139 m .30078 .61005 L .29773 .62033 L .707 .577 .707 r
F
.29955 .60651 m .30167 .61387 L p .30126 .61144 L F P
0 g
s
.30126 .61144 m .29076 .54986 L .29955 .60651 L .707 .577 .707 r
F
.30124 .61139 m .3034 .60122 L p .30078 .61005 L F P
0 g
s
.3034 .60122 m .30124 .61139 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29879 .60389 m .29955 .60651 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.3034 .60122 m .30083 .59485 L p .29945 .60622 L .707 .577 .707 r
F P
0 g
s
.30078 .61005 m .3034 .60122 L .29945 .60622 L .707 .577 .707 r
F
.31548 .6091 m .3034 .60122 L p .30466 .61457 L F P
0 g
s
.30083 .59485 m .30802 .59061 L p .30536 .59793 L .707 .577 .707 r
F P
0 g
s
.30038 .60203 m .30083 .59485 L .30536 .59793 L .707 .577 .707 r
F
.29879 .60389 m .29878 .60334 L .29908 .6031 L F
.30083 .59485 m .29908 .6031 L p .29556 .63824 L F P
0 g
s
.29526 .63749 m .29556 .63824 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29952 .60273 m .29904 .6035 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29904 .6035 m .29879 .60389 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29908 .6031 m .29299 .63187 L .29526 .63749 L p .707 .577 .707 r
F P
0 g
s
.29881 .60438 m .30083 .59485 L p .29965 .61357 L .707 .577 .707 r
F P
0 g
s
.29777 .53878 m .3058 .59281 L .29952 .60273 L p .707 .577 .707 r
F P
0 g
s
.29878 .60334 m .29777 .53878 L .29952 .60273 L .707 .577 .707 r
F
.29965 .61357 m .30038 .60203 L .30536 .59793 L F
.29299 .63187 m .29881 .60438 L p .29965 .61357 L F P
0 g
s
.29076 .54986 m .29872 .60339 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.29872 .60339 m .29879 .60389 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .30152 .61284 L p .30132 .61178 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .301 .61255 L p .29773 .62033 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .31415 .62177 L p .31342 .61956 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31336 .61936 L .31331 .61934 L .707 .577 .707 r
F
.31342 .61956 m .31331 .61934 L .30167 .61387 L F
.30152 .61284 m .30167 .61387 L p .31336 .61936 L F P
0 g
s
.31331 .61934 m .31548 .6091 L p .31108 .61811 L .707 .577 .707 r
F P
0 g
s
.31548 .6091 m .31331 .61934 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31383 .61962 L .31336 .61936 L .707 .577 .707 r
F
.314 .62075 m .31383 .61962 L p .31342 .61956 L F P
0 g
s
.31907 .62211 m .31331 .61934 L .314 .62075 L .707 .577 .707 r
F
.31415 .62177 m .314 .62075 L p .31342 .61956 L F P
0 g
s
.31108 .61811 m .31548 .6091 L .30466 .61457 L .707 .577 .707 r
F
.31415 .62177 m .33449 .6267 L p .33411 .62616 L F P
0 g
s
.314 .62075 m .31415 .62177 L p .33411 .62616 L .707 .577 .707 r
F P
0 g
s
.33449 .6267 m .33501 .62683 L p .3096 .59114 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .3548 .66326 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33501 .62683 m .33495 .62639 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .33411 .62616 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .31548 .6091 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .33589 .61772 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.8239 .56104 m .82737 .61813 L .80626 .61622 L p .707 .577 .707 r
F P
0 g
s
.80626 .61622 m .8028 .55913 L .8239 .56104 L p .707 .577 .707 r
F P
0 g
s
.42429 .63972 m .41645 .67674 L .44532 .68039 L p .707 .577 .707 r
F P
0 g
s
.44532 .68039 m .45316 .64337 L .42429 .63972 L p .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .36264 .62624 L .33589 .61772 L p .707 .577 .707 r
F P
0 g
s
.83944 .70551 m .8403 .72445 L .82763 .72013 L p .707 .577 .707 r
F P
0 g
s
.82763 .72013 m .82676 .70119 L .83944 .70551 L p .707 .577 .707 r
F P
0 g
s
.46948 .54959 m .47751 .60361 L .49371 .59252 L p .707 .577 .707 r
F P
0 g
s
.49371 .59252 m .48568 .5385 L .46948 .54959 L p .707 .577 .707 r
F P
0 g
s
.66267 .62658 m .65921 .56949 L .68314 .56527 L p .707 .577 .707 r
F P
0 g
s
.82782 .63662 m .82443 .67065 L .80349 .65793 L p .707 .577 .707 r
F P
0 g
s
.80349 .65793 m .80688 .6239 L .82782 .63662 L p .707 .577 .707 r
F P
0 g
s
.45316 .64337 m .44532 .68039 L .46904 .68142 L p .707 .577 .707 r
F P
0 g
s
.46904 .68142 m .47688 .6444 L .45316 .64337 L p .707 .577 .707 r
F P
0 g
s
.3936 .72747 m .39159 .7093 L .36058 .7102 L p .707 .577 .707 r
F P
0 g
s
.39159 .7093 m .3936 .72747 L .42526 .7234 L p .707 .577 .707 r
F P
0 g
s
.42526 .7234 m .42325 .70522 L .39159 .7093 L p .707 .577 .707 r
F P
0 g
s
.64654 .73101 m .64567 .71207 L .66194 .70677 L p .707 .577 .707 r
F P
0 g
s
.42325 .70522 m .42526 .7234 L .45446 .71655 L p .707 .577 .707 r
F P
0 g
s
.45446 .71655 m .45245 .69837 L .42325 .70522 L p .707 .577 .707 r
F P
0 g
s
.66194 .70677 m .6628 .72571 L .64654 .73101 L p .707 .577 .707 r
F P
0 g
s
.36058 .7102 m .36259 .72838 L .3936 .72747 L p .707 .577 .707 r
F P
0 g
s
.36259 .72838 m .36058 .7102 L .33325 .70785 L p .707 .577 .707 r
F P
0 g
s
.7788 .61571 m .77533 .55862 L .8028 .55913 L p .707 .577 .707 r
F P
0 g
s
.45245 .69837 m .45446 .71655 L .47835 .70759 L p .707 .577 .707 r
F P
0 g
s
.47835 .70759 m .47634 .68942 L .45245 .69837 L p .707 .577 .707 r
F P
0 g
s
.33325 .70785 m .33526 .72602 L .36259 .72838 L p .707 .577 .707 r
F P
0 g
s
.48568 .5385 m .49371 .59252 L .50071 .58144 L p .707 .577 .707 r
F P
0 g
s
.50071 .58144 m .49268 .52742 L .48568 .5385 L p .707 .577 .707 r
F P
0 g
s
.80688 .6239 m .80349 .65793 L .77616 .64824 L p .707 .577 .707 r
F P
0 g
s
.82676 .70119 m .82763 .72013 L .80651 .71707 L p .707 .577 .707 r
F P
0 g
s
.80651 .71707 m .80565 .69813 L .82676 .70119 L p .707 .577 .707 r
F P
0 g
s
.47688 .6444 m .46904 .68142 L .48529 .67973 L p .707 .577 .707 r
F P
0 g
s
.48529 .67973 m .49313 .64271 L .47688 .6444 L p .707 .577 .707 r
F P
0 g
s
.33526 .72602 m .33325 .70785 L .31227 .70246 L p .707 .577 .707 r
F P
0 g
s
.74766 .61665 m .74419 .55956 L .77533 .55862 L p .707 .577 .707 r
F P
0 g
s
.6628 .72571 m .66194 .70677 L .68589 .70218 L p .707 .577 .707 r
F P
0 g
s
.31227 .70246 m .31428 .72064 L .33526 .72602 L p .707 .577 .707 r
F P
0 g
s
.68589 .70218 m .68676 .72113 L .6628 .72571 L p .707 .577 .707 r
F P
0 g
s
.47634 .68942 m .47835 .70759 L .49459 .69741 L p .707 .577 .707 r
F P
0 g
s
.49459 .69741 m .49258 .67924 L .47634 .68942 L p .707 .577 .707 r
F P
0 g
s
.80565 .69813 m .80651 .71707 L .77903 .71558 L p .707 .577 .707 r
F P
0 g
s
.77903 .71558 m .77816 .69664 L .80565 .69813 L p .707 .577 .707 r
F P
0 g
s
.49268 .52742 m .50071 .58144 L .49783 .57146 L p .707 .577 .707 r
F P
0 g
s
.49783 .57146 m .4898 .51743 L .49268 .52742 L p .707 .577 .707 r
F P
0 g
s
.49313 .64271 m .48529 .67973 L .49249 .6755 L p .707 .577 .707 r
F P
0 g
s
.49249 .6755 m .50033 .63848 L .49313 .64271 L p .707 .577 .707 r
F P
0 g
s
.31428 .72064 m .31227 .70246 L .2997 .69457 L p .707 .577 .707 r
F P
0 g
s
.68676 .72113 m .68589 .70218 L .71521 .69877 L p .707 .577 .707 r
F P
0 g
s
.71521 .69877 m .71607 .71772 L .68676 .72113 L p .707 .577 .707 r
F P
0 g
s
.2997 .69457 m .30171 .71275 L .31428 .72064 L p .707 .577 .707 r
F P
0 g
s
.77816 .69664 m .77903 .71558 L .74786 .71581 L p .707 .577 .707 r
F P
0 g
s
.74786 .71581 m .747 .69686 L .77816 .69664 L p .707 .577 .707 r
F P
0 g
s
.49258 .67924 m .49459 .69741 L .50159 .68701 L p .707 .577 .707 r
F P
0 g
s
.50159 .68701 m .49958 .66883 L .49258 .67924 L p .707 .577 .707 r
F P
0 g
s
.71607 .71772 m .71521 .69877 L .747 .69686 L p .707 .577 .707 r
F P
0 g
s
.747 .69686 m .74786 .71581 L .71607 .71772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29879 .60389 m .29076 .54986 L .29777 .53878 L p .707 .577 .707 r
F P
0 g
s
.4898 .51743 m .49783 .57146 L .48535 .56355 L p .707 .577 .707 r
F P
0 g
s
.48535 .56355 m .47732 .50953 L .4898 .51743 L p .707 .577 .707 r
F P
0 g
s
.30171 .71275 m .2997 .69457 L .29677 .68495 L p .707 .577 .707 r
F P
0 g
s
.50033 .63848 m .49249 .6755 L .48992 .66913 L p .707 .577 .707 r
F P
0 g
s
.48992 .66913 m .49776 .63211 L .50033 .63848 L p .707 .577 .707 r
F P
0 g
s
.29677 .68495 m .29878 .70313 L .30171 .71275 L p .707 .577 .707 r
F P
0 g
s
.49958 .66883 m .50159 .68701 L .49866 .67739 L p .707 .577 .707 r
F P
0 g
s
.49866 .67739 m .49665 .65921 L .49958 .66883 L p .707 .577 .707 r
F P
0 g
s
.31396 .52769 m .31882 .56037 L p .3058 .59281 L .707 .577 .707 r
F P
0 g
s
.30018 .62763 m .30802 .59061 L .32428 .58893 L p .707 .577 .707 r
F P
0 g
s
.31882 .56037 m .32199 .58171 L .30848 .59097 L p .707 .577 .707 r
F P
0 g
s
.30802 .59061 m .30705 .59519 L p .29299 .63187 L .707 .577 .707 r
F P
0 g
s
.30848 .59097 m .3058 .59281 L p .31882 .56037 L .707 .577 .707 r
F P
0 g
s
.30705 .59519 m .30018 .62763 L .29507 .63064 L p .707 .577 .707 r
F P
0 g
s
.29507 .63064 m .29299 .63187 L p .30705 .59519 L .707 .577 .707 r
F P
0 g
s
.3058 .59281 m .29777 .53878 L .31396 .52769 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47732 .50953 m .48535 .56355 L .46449 .5585 L p .707 .577 .707 r
F P
0 g
s
.46449 .5585 m .45646 .50447 L .47732 .50953 L p .707 .577 .707 r
F P
0 g
s
.29878 .70313 m .29677 .68495 L .30377 .67455 L p .707 .577 .707 r
F P
0 g
s
.49776 .63211 m .48992 .66913 L .47784 .66124 L p .707 .577 .707 r
F P
0 g
s
.47784 .66124 m .48567 .62423 L .49776 .63211 L p .707 .577 .707 r
F P
0 g
s
.30377 .67455 m .30578 .69272 L .29878 .70313 L p .707 .577 .707 r
F P
0 g
s
.49665 .65921 m .49866 .67739 L .48609 .6695 L p .707 .577 .707 r
F P
0 g
s
.48609 .6695 m .48408 .65132 L .49665 .65921 L p .707 .577 .707 r
F P
0 g
s
.32199 .58171 m .31396 .52769 L .33778 .51767 L p .707 .577 .707 r
F P
0 g
s
.32428 .58893 m .31644 .62595 L .30018 .62763 L p .707 .577 .707 r
F P
0 g
s
.45646 .50447 m .46449 .5585 L .43729 .55679 L p .707 .577 .707 r
F P
0 g
s
.43729 .55679 m .42926 .50276 L .45646 .50447 L p .707 .577 .707 r
F P
0 g
s
.30578 .69272 m .30377 .67455 L .32001 .66437 L p .707 .577 .707 r
F P
0 g
s
.48567 .62423 m .47784 .66124 L .45742 .65262 L p .707 .577 .707 r
F P
0 g
s
.45742 .65262 m .46526 .6156 L .48567 .62423 L p .707 .577 .707 r
F P
0 g
s
.33778 .51767 m .34581 .57169 L .32199 .58171 L p .707 .577 .707 r
F P
0 g
s
.34581 .57169 m .33778 .51767 L .36687 .5097 L p .707 .577 .707 r
F P
0 g
s
.32001 .66437 m .32202 .68254 L .30578 .69272 L p .707 .577 .707 r
F P
0 g
s
.31644 .62595 m .32428 .58893 L .348 .58996 L p .707 .577 .707 r
F P
0 g
s
.42926 .50276 m .43729 .55679 L .40642 .55859 L p .707 .577 .707 r
F P
0 g
s
.40642 .55859 m .39839 .50456 L .42926 .50276 L p .707 .577 .707 r
F P
0 g
s
.48408 .65132 m .48609 .6695 L .46511 .66411 L p .707 .577 .707 r
F P
0 g
s
.46511 .66411 m .4631 .64594 L .48408 .65132 L p .707 .577 .707 r
F P
0 g
s
.348 .58996 m .34016 .62698 L .31644 .62595 L p .707 .577 .707 r
F P
0 g
s
.3749 .56372 m .36687 .5097 L .39839 .50456 L p .707 .577 .707 r
F P
0 g
s
.36687 .5097 m .3749 .56372 L .34581 .57169 L p .707 .577 .707 r
F P
0 g
s
.39839 .50456 m .40642 .55859 L .3749 .56372 L p .707 .577 .707 r
F P
0 g
s
.46526 .6156 m .45742 .65262 L .43068 .6441 L p .707 .577 .707 r
F P
0 g
s
.43068 .6441 m .43852 .60708 L .46526 .6156 L p .707 .577 .707 r
F P
0 g
s
.32202 .68254 m .32001 .66437 L .3439 .65541 L p .707 .577 .707 r
F P
0 g
s
.34016 .62698 m .348 .58996 L .37687 .5936 L p .707 .577 .707 r
F P
0 g
s
.3439 .65541 m .34591 .67359 L .32202 .68254 L p .707 .577 .707 r
F P
0 g
s
.4631 .64594 m .46511 .66411 L .43778 .66176 L p .707 .577 .707 r
F P
0 g
s
.43778 .66176 m .43577 .64358 L .4631 .64594 L p .707 .577 .707 r
F P
0 g
s
.37687 .5936 m .36903 .63062 L .34016 .62698 L p .707 .577 .707 r
F P
0 g
s
.43852 .60708 m .43068 .6441 L .40022 .63652 L p .707 .577 .707 r
F P
0 g
s
.40022 .63652 m .40806 .5995 L .43852 .60708 L p .707 .577 .707 r
F P
0 g
s
.36903 .63062 m .37687 .5936 L .40806 .5995 L p .707 .577 .707 r
F P
0 g
s
.34591 .67359 m .3439 .65541 L .3731 .64856 L p .707 .577 .707 r
F P
0 g
s
.40806 .5995 m .40022 .63652 L .36903 .63062 L p .707 .577 .707 r
F P
0 g
s
.43577 .64358 m .43778 .66176 L .40677 .66266 L p .707 .577 .707 r
F P
0 g
s
.40677 .66266 m .40476 .64449 L .43577 .64358 L p .707 .577 .707 r
F P
0 g
s
.3731 .64856 m .37511 .66674 L .34591 .67359 L p .707 .577 .707 r
F P
0 g
s
.37511 .66674 m .3731 .64856 L .40476 .64449 L p .707 .577 .707 r
F P
0 g
s
.40476 .64449 m .40677 .66266 L .37511 .66674 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEQL000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005moo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005eoo`800003
FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001GOol30007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20002FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool20004FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH015YF5@000eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000087oo2000?Goo001BOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH0
0eYF0`001EYF0`0000=JEP00FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000mooa4000AJEP04001JEUYFFUH<000aOol005=oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH0000000<000AJEP03001JEP0000<00003
FUH005YF00IJEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00001goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH010001EYF2`001EYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP8000EJEPD00003FUH005YF00X000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YF00001EYF00@005YFFUIJEPX000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH0
0005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP000eYF00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo0010Ool8000;Ool01@00FUIJEP00FUH03`00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool003Yoo`H000=JEP03001JEUYF009JEPT000=oo`04001JEP000004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH600000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0006FUH20005FUH01000FUH00000;Woo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000030006
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP8000EJEP04001JEUYF000^Ool003Aoo`8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00EJEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF0P001EYF0P00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF0P001EYF00<005YFFUH00P00;Goo000bOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH00eYF0P00
25YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH2
0005FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH20005FUH00`00FUIJEP02000]
Ool0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@0009JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_Ool0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUH0000200000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUHJ00000eYF0000000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH30005FUH01000FUIJEUYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00003P0015YF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF0P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0035oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02moo`00;Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH00UYF200015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3P001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00<7oo000]Ool20004FUH0
0`00FUIJEP03FUH60008Ool90004FUH01000FUIJEP001EYF00<005YFFUH00UYF00@005YFFUH000QJ
EQL000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUHG0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH2000`Ool002eoo`8000AJEP03001JEP0000<001Moo`H0009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000<000=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EP0000<001Qoo`D000IJEP03001JEUYF00AJEP03001JEP0002moo`00;7oo00<005YF000015YF0P00
4goo0`002goo1P0000=JEP00FUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF0P008Goo0P0015YF00<005YFFUH015YF00@005YFFUH002io
o`00;7oo00<005YF00000UYF0P000UYF0P0047oo1@003Woo1@0000=JEP0000000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF10008goo0`0000=JEP00FUH0
15YF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P0000=JEP00FUH00eYF0`003Goo1@0047oo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF100015YF10008Woo0P001EYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YF00000`002Goo1@003Woo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF
5`0015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYFFUH005YF0P001eYF00<005YF00000P008Goo0P000eYF00@005YFFUIJEP8002eoo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH00eYF10001Woo0`003Woo0P001eYF00<005YFFUH015YF1P00
25YF00<005YFFUH01EYF00<005YFFUH015YF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP02FUH2000;
Ool3000COol200000eYF001JEP02FUH2000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@0011oo`<00003FUH005YF00IJEP03001JEUYF00@0009JEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30008Ool5
000DOol20002FUH00`00FUH0000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00AJEQ4000=JEP03001JEUYF00AJEPD00003FUH005YF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEPD00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00D005YFFUIJEP0000IJEP04001JEUYF0007
Ool5000FOol01@00FUH005YF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP0?FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000=JEP800003FUH005YF00EJEP03
001JEUYF00=JEPH000AJEP03001JEUYF00AJEP08001JEUYFFUH005YF001JEP800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH300000eYF001JEP05FUH01000
FUIJEP001goo1@005Woo00D005YF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH03eYF00@005YFFUIJEP8000AJEP06001JEP00001JEP000eYF0P0000=JEP00
FUH01EYF10001EYF00<005YFFUH04@0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00P001EYF00@005YFFUIJEP8000Moo`<001Qoo`80
0003FUH007oo02aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP06
001JEUYF001JEP000eYF0`000eYF00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF
00UJEP03001JEUYF00AJEP<00004FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP80025oo`@002ioo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP07001JEUYF001JEP00FUH00P001UYF
00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00UJEP03001JEUYF009JEP80009J
EP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUH0000OOol20002FUH2000^Ool002io
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH01@00FUIJEP00FUH00P0000=JEP00
FUH015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH02EYF00<005YFFUH0
0P0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000IJEP04001JEUYFFUH400000eYF001oo`0LOol20004FUH2000^Ool002moo`03
001JEP0000EJEP03001JEUYF00AJEP80015JEP03001JEUYF008000=JEP03001JEUYF00=JEP03001J
EUYF009JEP800003FUH005YF00EJEP@000EJEP03001JEUYF00QJEP@00003FUH005YF00=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EUYF00AJEP03001JEUYF00AJEP<001Yoo`<00003FUH005YF00=JEP8002ioo`00<7oo0P001EYF00<0
05YFFUH015YF0P0045YF5P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001EYF
00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00006FUH00`00FUIJEP04FUHP00000eYF001JEP02FUH00`00FUH0000^Ool0
035oo`03001JEUYF00=JEP03001JEUYF00AJEP8000MJEPT000AJEP80009JEP80009JEP03001JEUYF
009JEP07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003FUH005YF00EJ
EP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00005FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP0600000eYF001oo`0]Ool0039oo`8000=JEP03001JEUYF00AJEPT000AJEP03001J
EUYF00IJEP80009JEP03001JEP00008000AJEP07001JEUYFFUH005YF00001UYF00<005YFFUH00eYF
1`001EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000P0000=JEP0000000`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000dOol2
00000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUHG
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo1@000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHH0003FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP8000MJEP03001JEUYF00AJEP@0009JEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUIJEP8000MJEP8000EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP04001JEUYFFUH80007FUH60003FUH20007FUH00`00FUIJEP04FUH20002FUH4
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00MJEP8000IJEP03001JEP0000@000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEPH000=JEP<00003FUH005YF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP80
00AJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPP000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPX0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00008000=JEPL0009JEP<000IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EP0000<00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF00001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF2@00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF1@0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF4`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00eYF40001EYF00<005YFFUH015YF00<005YFFUH00P00;goo000]Ool00`00FUH00003FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF10001EYF00<0
05YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH0035oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPP0009oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
=goo000]Ool01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP00008000Aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000D000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT003moo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFOol01EYF00<005YFFUH0
0UYF0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo6000B7oo
000]Ool20004FUH01000FUIJEUYF5P000goo1P001UYF00<005YFFUH00eYF0P0000Aoo`00FUH000IJ
EP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPH000IJEP03
001JEUYF009JEP03001JEP0000Moo`8000AJEP04001JEP00001DOol002eoo`8000AJEPT001Yoo`@0
009JEP03001JEUYF00=JEP800004Ool005YF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00
FUH00005Ool200000eYF001JEP03FUH01000FUIJEP00E7oo000/Ool00`00FUH00002FUH2000WOol4
0004FUH01P00FUH00000FUH000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000=oo`8000=JEP03001JEUYF
009JEP04001JEUYF001DOol002aoo`03001JEP00008002eoo`<00008FUH005YFFUH005YF001JEP<0
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUH000030006FUH01@00FUIJEUYF00000UYF00<007ooOol0
DWoo000/Ool00`00FUH0000bOol20002FUH01000FUH000000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000AJEP00FUH000MJEP03001JEUYF009JEP03001JEP0005Aoo`00;7oo0P006Woo0`0067oo
00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800004FUH005YF0007FUH00`00FUIJ
EP02FUH2001EOol002aoo`8001Uoo`D001Moo`04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00UYF00<007ooOol0E7oo000/Ool3000HOol5
000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF
00D005YFFUIJEP0005Moo`00;7oo0P0000=JEP0000005Woo1@006Goo0P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00EJEP03001JEP0005Qoo`00;7oo0P000eYF
00<007ooOol057oo0`006Goo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00EJEP8005Uoo`00;Goo00@005YFFUIJEP<002moo`800003FUH005YF00=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00EJEP03001oogoo05Qoo`00;Goo
00D005YFFUIJEP00009JEP8002]oo`800004FUH005YF0004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF000000020005FUH2001KOol002ioo`04001JEUYF0004FUH3000VOol20003FUH20000
0goo00000002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005FUH5001MOol002moo`<000EJEP03
001JEP0000<001ioo`@00003FUH005YF009JEP8000=oo`<000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00
FUIJEP05FUH00`00FUH00002001KOol0035oo`03001JEUYF00=JEP03001JEUYF00=JEPH0019oo`H0
00EJEP05001JEUYFFUH00006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00FGoo000bOol20003FUH00`00FUIJEP05FUH01000FUIJEUYF4P0015YF00<005YFFUH00eYF
00<005YFFUH00P002Goo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF10000UYF1P001EYF00<005YFFUH015YF0`00Egoo000dOol20000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
000>Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP060004FUH500000goo0000000200000eYF001JEP05FUH00`00FUIJEP02001EOol003Ioo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEPP000Yoo`<000AJEP03
001JEUYF009JEP03001oogoo05=oo`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P0077oo2`001UYF00<005YFFUH02UYF00@005YFFUIJEPH000AJEPP0011o
o`<00003FUH005YF00=JEP03001oogoo05=oo`00?Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P00:Woo8@000goo1@004goo0P000eYF0P00EGoo0013OolB000jOol200000eYF001JEP04FUH0
0`00FUIJEP04FUH60005Ool3000FOol200000eYF0000001EOol0095oo`<000AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT0011oo`H00004FUH00000001EOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ0000=JEP04001JEUYFFUH3001EOol009Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EGoo
002JOol400000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2001FOol009ioo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00<005Moo`00Y7oo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005Yoo`00[Goo
4000H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59848 .7556 m .59046 .70157 L .55962 .70333 L p .707 .577 .707 r
F P
0 g
s
.59046 .70157 m .59848 .7556 L .63002 .75051 L p .707 .577 .707 r
F P
0 g
s
.63002 .75051 m .622 .69648 L .59046 .70157 L p .707 .577 .707 r
F P
0 g
s
.622 .69648 m .63002 .75051 L .65916 .74258 L p .707 .577 .707 r
F P
0 g
s
.65916 .74258 m .65114 .68855 L .622 .69648 L p .707 .577 .707 r
F P
0 g
s
.56764 .75736 m .55962 .70333 L .53249 .70157 L p .707 .577 .707 r
F P
0 g
s
.55962 .70333 m .56764 .75736 L .59848 .7556 L p .707 .577 .707 r
F P
0 g
s
.65114 .68855 m .65916 .74258 L .68306 .73259 L p .707 .577 .707 r
F P
0 g
s
.68306 .73259 m .67504 .67856 L .65114 .68855 L p .707 .577 .707 r
F P
0 g
s
.59205 .79976 m .59992 .76274 L .56939 .75519 L p .707 .577 .707 r
F P
0 g
s
.59992 .76274 m .59205 .79976 L .62321 .80562 L p .707 .577 .707 r
F P
0 g
s
.62321 .80562 m .63108 .7686 L .59992 .76274 L p .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53249 .70157 L .51172 .69648 L p .707 .577 .707 r
F P
0 g
s
.53249 .70157 m .54051 .75561 L .54078 .75562 L p .707 .577 .707 r
F P
0 g
s
.5572 .74079 m .53249 .70157 L .54078 .75562 L .707 .577 .707 r
F
.51172 .69648 m .51952 .74901 L p .51952 .74901 L F P
0 g
s
.53123 .73655 m .51172 .69648 L .51952 .74901 L .707 .577 .707 r
F
.51172 .69648 m .49935 .68856 L p .51917 .74879 L F P
0 g
s
.51398 .77511 m .51952 .74902 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L p .51952 .74901 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L .51215 .75686 L .707 .577 .707 r
F
.51215 .75686 m .51702 .74742 L .5108 .74343 L F
.49935 .68856 m .50715 .7411 L p .50716 .7411 L F P
0 g
s
.51917 .74879 m .51264 .72895 L .50716 .7411 L .707 .577 .707 r
F
.51264 .72895 m .49935 .68856 L .50716 .7411 L F
.49935 .68856 m .4966 .67857 L p .50709 .74089 L F P
0 g
s
.50947 .7302 m .50716 .74111 L p .51398 .77511 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50161 .76723 L .51343 .77476 L p .707 .577 .707 r
F P
0 g
s
.51343 .77476 m .51398 .77511 L p .50716 .74111 L .707 .577 .707 r
F P
0 g
s
.50374 .74867 m .50663 .73936 L .5053 .735 L .707 .577 .707 r
F
.50161 .76723 m .50716 .74111 L p .50374 .74867 L F P
0 g
s
.50716 .74111 m .50716 .7411 L p .50715 .7411 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50715 .7411 L .50374 .74867 L .707 .577 .707 r
F
.50506 .73421 m .50685 .73947 L .50464 .73267 L F
.50709 .74089 m .50685 .73947 L .50506 .73421 L F
.4966 .67857 m .50092 .70765 L p .50685 .73947 L F P
0 g
s
.50092 .70765 m .50462 .7326 L p .50685 .73947 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .49935 .68856 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.50716 .7411 m .50947 .7302 L p .50374 .74867 L .707 .577 .707 r
F P
0 g
s
.50464 .73269 m .50506 .73421 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .50466 .73289 L p .50161 .76723 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .49873 .76084 L .5011 .76609 L p .707 .577 .707 r
F P
0 g
s
.5011 .76609 m .50161 .76723 L p .50466 .73289 L .707 .577 .707 r
F P
0 g
s
.50372 .66749 m .50834 .6986 L p .50462 .7326 L .707 .577 .707 r
F P
0 g
s
.50506 .73421 m .5058 .73688 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.5058 .73688 m .50738 .74259 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50709 .74089 L .50581 .73668 L .707 .577 .707 r
F
.50947 .7302 m .50659 .72382 L p .5053 .735 L F P
0 g
s
.50663 .73936 m .50947 .7302 L .5053 .735 L .707 .577 .707 r
F
.51952 .74901 m .51172 .69648 L p .51917 .74879 L F P
0 g
s
.52184 .73809 m .50947 .7302 L p .5108 .74343 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .51347 .71956 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .50659 .72382 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50834 .6986 m .51174 .72152 L .50471 .73246 L p .707 .577 .707 r
F P
0 g
s
.50471 .73246 m .50462 .7326 L p .50834 .6986 L .707 .577 .707 r
F P
0 g
s
.49873 .76084 m .50466 .73289 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .50464 .73269 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50715 .7411 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.51952 .74901 m .52184 .73809 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53123 .73655 L .51952 .74901 L .707 .577 .707 r
F
.53769 .75492 m .54051 .75561 L p .51952 .74901 L F P
0 g
s
.52184 .73809 m .51398 .77511 L .53463 .78372 L p .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .51974 .75052 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .50738 .74259 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51974 .75052 m .51952 .74901 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51702 .74742 m .52184 .73809 L .5108 .74343 L .707 .577 .707 r
F
.52959 .76574 m .53706 .75471 L .52544 .75093 L F
.54055 .75584 m .54249 .7467 L p .52959 .76574 L F P
0 g
s
.51952 .74901 m .51974 .75052 L .53769 .75492 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .52184 .73809 L p .52544 .75093 L .707 .577 .707 r
F P
0 g
s
.53706 .75471 m .54249 .7467 L .52544 .75093 L .707 .577 .707 r
F
.53463 .78372 m .54055 .75584 L p .52959 .76574 L F P
0 g
s
.54078 .75562 m .56764 .75736 L p .5572 .74079 L .707 .577 .707 r
F P
0 g
s
.63108 .7686 m .62321 .80562 L .65196 .80922 L p .707 .577 .707 r
F P
0 g
s
.65196 .80922 m .65982 .7722 L .63108 .7686 L p .707 .577 .707 r
F P
0 g
s
.56153 .79222 m .56939 .75519 L .54249 .7467 L p .707 .577 .707 r
F P
0 g
s
.56939 .75519 m .56153 .79222 L .59205 .79976 L p .707 .577 .707 r
F P
0 g
s
.67504 .67856 m .68306 .73259 L .69936 .72152 L p .707 .577 .707 r
F P
0 g
s
.69936 .72152 m .69134 .66749 L .67504 .67856 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .53463 .78372 L .56153 .79222 L p .707 .577 .707 r
F P
0 g
s
.65982 .7722 m .65196 .80922 L .67547 .81021 L p .707 .577 .707 r
F P
0 g
s
.67547 .81021 m .68333 .77319 L .65982 .7722 L p .707 .577 .707 r
F P
0 g
s
.59892 .85633 m .59691 .83815 L .56593 .83901 L p .707 .577 .707 r
F P
0 g
s
.59691 .83815 m .59892 .85633 L .63059 .8523 L p .707 .577 .707 r
F P
0 g
s
.63059 .8523 m .62858 .83413 L .59691 .83815 L p .707 .577 .707 r
F P
0 g
s
.62858 .83413 m .63059 .8523 L .65985 .8455 L p .707 .577 .707 r
F P
0 g
s
.65985 .8455 m .65784 .82732 L .62858 .83413 L p .707 .577 .707 r
F P
0 g
s
.56593 .83901 m .56794 .85719 L .59892 .85633 L p .707 .577 .707 r
F P
0 g
s
.56794 .85719 m .56593 .83901 L .53868 .8366 L p .707 .577 .707 r
F P
0 g
s
.65784 .82732 m .65985 .8455 L .68384 .83658 L p .707 .577 .707 r
F P
0 g
s
.68384 .83658 m .68183 .8184 L .65784 .82732 L p .707 .577 .707 r
F P
0 g
s
.53868 .8366 m .54068 .85478 L .56794 .85719 L p .707 .577 .707 r
F P
0 g
s
.69134 .66749 m .69936 .72152 L .70649 .71044 L p .707 .577 .707 r
F P
0 g
s
.70649 .71044 m .69847 .65641 L .69134 .66749 L p .707 .577 .707 r
F P
0 g
s
.68333 .77319 m .67547 .81021 L .69145 .80849 L p .707 .577 .707 r
F P
0 g
s
.69145 .80849 m .69931 .77147 L .68333 .77319 L p .707 .577 .707 r
F P
0 g
s
.54068 .85478 m .53868 .8366 L .51782 .83118 L p .707 .577 .707 r
F P
0 g
s
.51782 .83118 m .51982 .84936 L .54068 .85478 L p .707 .577 .707 r
F P
0 g
s
.68183 .8184 m .68384 .83658 L .70021 .82643 L p .707 .577 .707 r
F P
0 g
s
.70021 .82643 m .6982 .80825 L .68183 .8184 L p .707 .577 .707 r
F P
0 g
s
.69847 .65641 m .70649 .71044 L .70373 .70045 L p .707 .577 .707 r
F P
0 g
s
.70373 .70045 m .69571 .64642 L .69847 .65641 L p .707 .577 .707 r
F P
0 g
s
.69931 .77147 m .69145 .80849 L .69834 .80423 L p .707 .577 .707 r
F P
0 g
s
.69834 .80423 m .7062 .76721 L .69931 .77147 L p .707 .577 .707 r
F P
0 g
s
.51982 .84936 m .51782 .83118 L .50539 .82327 L p .707 .577 .707 r
F P
0 g
s
.50539 .82327 m .5074 .84145 L .51982 .84936 L p .707 .577 .707 r
F P
0 g
s
.6982 .80825 m .70021 .82643 L .70736 .81603 L p .707 .577 .707 r
F P
0 g
s
.70736 .81603 m .70535 .79785 L .6982 .80825 L p .707 .577 .707 r
F P
0 g
s
.48871 .8218 m .48871 .31992 L .44482 .31709 L p .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .4966 .67857 L .50372 .66749 L p .707 .577 .707 r
F P
0 g
s
.5074 .84145 m .50539 .82327 L .50261 .81364 L p .707 .577 .707 r
F P
0 g
s
.50261 .81364 m .50462 .83182 L .5074 .84145 L p .707 .577 .707 r
F P
0 g
s
.51347 .71956 m .51228 .72517 L p .49873 .76084 L .707 .577 .707 r
F P
0 g
s
.51228 .72517 m .50561 .75658 L .50109 .75938 L p .707 .577 .707 r
F P
0 g
s
.50109 .75938 m .49873 .76084 L p .51228 .72517 L .707 .577 .707 r
F P
0 g
s
.52003 .65642 m .52463 .68742 L p .51174 .72152 L .707 .577 .707 r
F P
0 g
s
.50561 .75658 m .51347 .71956 L .52946 .71784 L p .707 .577 .707 r
F P
0 g
s
.52463 .68742 m .52805 .71045 L .51397 .72001 L p .707 .577 .707 r
F P
0 g
s
.51397 .72001 m .51174 .72152 L p .52463 .68742 L .707 .577 .707 r
F P
0 g
s
.51174 .72152 m .50372 .66749 L .52003 .65642 L p .707 .577 .707 r
F P
0 g
s
.50462 .83182 m .50261 .81364 L .50976 .80324 L p .707 .577 .707 r
F P
0 g
s
.50976 .80324 m .51177 .82142 L .50462 .83182 L p .707 .577 .707 r
F P
0 g
s
.52946 .71784 m .5216 .75486 L .50561 .75658 L p .707 .577 .707 r
F P
0 g
s
.51177 .82142 m .50976 .80324 L .52613 .79308 L p .707 .577 .707 r
F P
0 g
s
.52613 .79308 m .52814 .81126 L .51177 .82142 L p .707 .577 .707 r
F P
0 g
s
.5216 .75486 m .52946 .71784 L .55297 .71883 L p .707 .577 .707 r
F P
0 g
s
.55297 .71883 m .54511 .75585 L .5216 .75486 L p .707 .577 .707 r
F P
0 g
s
.52814 .81126 m .52613 .79308 L .55012 .78417 L p .707 .577 .707 r
F P
0 g
s
.55012 .78417 m .55213 .80235 L .52814 .81126 L p .707 .577 .707 r
F P
0 g
s
.48871 .31992 m .48871 .8218 L .5337 .82085 L p .707 .577 .707 r
F P
0 g
s
.52805 .71045 m .52003 .65642 L .54392 .64643 L p .707 .577 .707 r
F P
0 g
s
.54392 .64643 m .55195 .70046 L .52805 .71045 L p .707 .577 .707 r
F P
0 g
s
.5337 .82085 m .5337 .31896 L .48871 .31992 L p .707 .577 .707 r
F P
0 g
s
.55195 .70046 m .54392 .64643 L .57307 .6385 L p .707 .577 .707 r
F P
0 g
s
.57307 .6385 m .58109 .69253 L .55195 .70046 L p .707 .577 .707 r
F P
0 g
s
.54511 .75585 m .55297 .71883 L .58171 .72243 L p .707 .577 .707 r
F P
0 g
s
.58171 .72243 m .57385 .75945 L .54511 .75585 L p .707 .577 .707 r
F P
0 g
s
.55213 .80235 m .55012 .78417 L .57938 .77736 L p .707 .577 .707 r
F P
0 g
s
.57938 .77736 m .58139 .79554 L .55213 .80235 L p .707 .577 .707 r
F P
0 g
s
.5337 .31896 m .5337 .82085 L .57539 .81622 L p .707 .577 .707 r
F P
0 g
s
.58109 .69253 m .57307 .6385 L .6046 .63341 L p .707 .577 .707 r
F P
0 g
s
.57385 .75945 m .58171 .72243 L .61287 .72829 L p .707 .577 .707 r
F P
0 g
s
.61287 .72829 m .60501 .76531 L .57385 .75945 L p .707 .577 .707 r
F P
0 g
s
.57539 .81622 m .57539 .31433 L .5337 .31896 L p .707 .577 .707 r
F P
0 g
s
.44482 .81898 m .44482 .31709 L .40634 .31077 L p .707 .577 .707 r
F P
0 g
s
.44482 .31709 m .44482 .81898 L .48871 .8218 L p .707 .577 .707 r
F P
0 g
s
.69571 .64642 m .70373 .70045 L .69137 .69253 L p .707 .577 .707 r
F P
0 g
s
.69137 .69253 m .68335 .63849 L .69571 .64642 L p .707 .577 .707 r
F P
0 g
s
.7062 .76721 m .69834 .80423 L .69546 .79785 L p .707 .577 .707 r
F P
0 g
s
.69546 .79785 m .70332 .76082 L .7062 .76721 L p .707 .577 .707 r
F P
0 g
s
.6046 .63341 m .61262 .68744 L .58109 .69253 L p .707 .577 .707 r
F P
0 g
s
.6434 .73584 m .63554 .77286 L .60501 .76531 L p .707 .577 .707 r
F P
0 g
s
.60501 .76531 m .61287 .72829 L .6434 .73584 L p .707 .577 .707 r
F P
0 g
s
.58139 .79554 m .57938 .77736 L .61105 .77334 L p .707 .577 .707 r
F P
0 g
s
.61105 .77334 m .61306 .79152 L .58139 .79554 L p .707 .577 .707 r
F P
0 g
s
.57539 .31433 m .57539 .81622 L .6097 .80835 L p .707 .577 .707 r
F P
0 g
s
.61262 .68744 m .6046 .63341 L .63545 .63165 L p .707 .577 .707 r
F P
0 g
s
.6097 .80835 m .6097 .30646 L .57539 .31433 L p .707 .577 .707 r
F P
0 g
s
.70535 .79785 m .70736 .81603 L .70458 .8064 L p .707 .577 .707 r
F P
0 g
s
.70458 .8064 m .70257 .78822 L .70535 .79785 L p .707 .577 .707 r
F P
0 g
s
.40634 .81265 m .40634 .31077 L .37702 .30156 L p .707 .577 .707 r
F P
0 g
s
.40634 .31077 m .40634 .81265 L .44482 .81898 L p .707 .577 .707 r
F P
0 g
s
.25424 .69954 m .25078 .64245 L .21967 .64336 L p .707 .577 .707 r
F P
0 g
s
.25078 .64245 m .25424 .69954 L .28602 .69727 L p .707 .577 .707 r
F P
0 g
s
.28602 .69727 m .28256 .64018 L .25078 .64245 L p .707 .577 .707 r
F P
0 g
s
.28256 .64018 m .28602 .69727 L .31535 .69387 L p .707 .577 .707 r
F P
0 g
s
.31535 .69387 m .3119 .63678 L .28256 .64018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22312 .70046 m .21967 .64336 L .19227 .64283 L p .707 .577 .707 r
F P
0 g
s
.21967 .64336 m .22312 .70046 L .25424 .69954 L p .707 .577 .707 r
F P
0 g
s
.68335 .63849 m .69137 .69253 L .6706 .68744 L p .707 .577 .707 r
F P
0 g
s
.6706 .68744 m .66258 .6334 L .68335 .63849 L p .707 .577 .707 r
F P
0 g
s
.3119 .63678 m .31535 .69387 L .33937 .68967 L p .707 .577 .707 r
F P
0 g
s
.33937 .68967 m .33591 .63258 L .3119 .63678 L p .707 .577 .707 r
F P
0 g
s
.19227 .64283 m .19572 .69993 L .22312 .70046 L p .707 .577 .707 r
F P
0 g
s
.63545 .63165 m .64347 .68568 L .61262 .68744 L p .707 .577 .707 r
F P
0 g
s
.6703 .74433 m .66244 .78135 L .63554 .77286 L p .707 .577 .707 r
F P
0 g
s
.64203 .77248 m .64404 .79066 L .61306 .79152 L p .707 .577 .707 r
F P
0 g
s
.63554 .77286 m .6434 .73584 L .6703 .74433 L p .707 .577 .707 r
F P
0 g
s
.61306 .79152 m .61105 .77334 L .64203 .77248 L p .707 .577 .707 r
F P
0 g
s
.6097 .30646 m .6097 .80835 L .63327 .79802 L p .707 .577 .707 r
F P
0 g
s
.63327 .79802 m .63327 .29613 L .6097 .30646 L p .707 .577 .707 r
F P
0 g
s
.70332 .76082 m .69546 .79785 L .68309 .78996 L p .707 .577 .707 r
F P
0 g
s
.68309 .78996 m .69095 .75294 L .70332 .76082 L p .707 .577 .707 r
F P
0 g
s
.70257 .78822 m .70458 .8064 L .69215 .79849 L p .707 .577 .707 r
F P
0 g
s
.69215 .79849 m .69015 .78031 L .70257 .78822 L p .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .25343 .78659 L .23499 .7867 L p .707 .577 .707 r
F P
0 g
s
.23499 .7867 m .2223 .78678 L p .23022 .79142 L .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .23499 .7867 L .23022 .79142 L .707 .577 .707 r
F
.25343 .78659 m .2543 .80553 L .2861 .80365 L p F P
0 g
s
.2861 .80365 m .28524 .7847 L .26816 .78571 L p .707 .577 .707 r
F P
0 g
s
.26816 .78571 m .25343 .78659 L p .26262 .79138 L .707 .577 .707 r
F P
0 g
s
.2861 .80365 m .26816 .78571 L .26262 .79138 L .707 .577 .707 r
F
.28524 .7847 m .2861 .80365 L .31548 .80027 L p F P
0 g
s
.31548 .80027 m .31461 .78132 L .30052 .78294 L p .707 .577 .707 r
F P
0 g
s
.30052 .78294 m .28524 .7847 L p .2952 .78983 L .707 .577 .707 r
F P
0 g
s
.31548 .80027 m .30052 .78294 L .2952 .78983 L .707 .577 .707 r
F
.31461 .78132 m .31548 .80027 L .33954 .79571 L p F P
0 g
s
.33954 .79571 m .33867 .77676 L .32841 .77871 L p .707 .577 .707 r
F P
0 g
s
.32841 .77871 m .31461 .78132 L p .32433 .78693 L .707 .577 .707 r
F P
0 g
s
.33954 .79571 m .32841 .77871 L .32433 .78693 L .707 .577 .707 r
F
.33867 .77676 m .33954 .79571 L .35593 .79043 L p F P
0 g
s
.35593 .79043 m .35507 .77148 L .33867 .77676 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .3528 .76861 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.34014 .74593 m .33899 .75739 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.33899 .75739 m .33673 .77998 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .33673 .77998 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31636 .75379 m .31536 .76376 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31536 .76376 m .31295 .78784 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .31295 .78784 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2872 .75736 m .28621 .76725 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.28621 .76725 m .28379 .79142 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .28379 .79142 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25552 .7563 m .25439 .7675 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25439 .7675 m .2521 .79036 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .25552 .7563 L .22441 .75071 L p .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .2872 .75736 L .25552 .7563 L p .707 .577 .707 r
F P
0 g
s
.19572 .69993 m .19227 .64283 L .17126 .64092 L p .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .31636 .75379 L .2872 .75736 L p .707 .577 .707 r
F P
0 g
s
.22099 .78476 m .22441 .75071 L .19692 .74114 L p .707 .577 .707 r
F P
0 g
s
.22441 .75071 m .22099 .78476 L .2521 .79036 L p .707 .577 .707 r
F P
0 g
s
.17126 .64092 m .17471 .69801 L .19572 .69993 L p .707 .577 .707 r
F P
0 g
s
.66258 .6334 m .6706 .68744 L .64347 .68568 L p .707 .577 .707 r
F P
0 g
s
.64347 .68568 m .63545 .63165 L .66258 .6334 L p .707 .577 .707 r
F P
0 g
s
.37702 .80345 m .37702 .30156 L .35975 .29037 L p .707 .577 .707 r
F P
0 g
s
.37702 .30156 m .37702 .80345 L .40634 .81265 L p .707 .577 .707 r
F P
0 g
s
.33591 .63258 m .33937 .68967 L .35572 .68509 L p .707 .577 .707 r
F P
0 g
s
.35572 .68509 m .35227 .62799 L .33591 .63258 L p .707 .577 .707 r
F P
0 g
s
.2223 .78678 m .22317 .80572 L .2543 .80553 L p .707 .577 .707 r
F P
0 g
s
.22317 .80572 m .2223 .78678 L .1949 .78526 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .34014 .74593 L .31636 .75379 L p .707 .577 .707 r
F P
0 g
s
.19351 .77519 m .19692 .74114 L .17575 .72852 L p .707 .577 .707 r
F P
0 g
s
.19692 .74114 m .19351 .77519 L .22099 .78476 L p .707 .577 .707 r
F P
0 g
s
.1949 .78526 m .19576 .80421 L .22317 .80572 L p .707 .577 .707 r
F P
0 g
s
.69095 .75294 m .68309 .78996 L .66244 .78135 L p .707 .577 .707 r
F P
0 g
s
.66244 .78135 m .6703 .74433 L .69095 .75294 L p .707 .577 .707 r
F P
0 g
s
.17471 .69801 m .17126 .64092 L .1587 .63779 L p .707 .577 .707 r
F P
0 g
s
.69015 .78031 m .69215 .79849 L .67129 .79306 L p .707 .577 .707 r
F P
0 g
s
.67129 .79306 m .66929 .77488 L .69015 .78031 L p .707 .577 .707 r
F P
0 g
s
.64404 .79066 m .64203 .77248 L .66929 .77488 L p .707 .577 .707 r
F P
0 g
s
.63327 .29613 m .63327 .79802 L .6438 .78625 L p .707 .577 .707 r
F P
0 g
s
.6438 .78625 m .6438 .28436 L .63327 .29613 L p .707 .577 .707 r
F P
0 g
s
.1587 .63779 m .16215 .69489 L .17471 .69801 L p .707 .577 .707 r
F P
0 g
s
.19576 .80421 m .1949 .78526 L .1739 .78219 L p .707 .577 .707 r
F P
0 g
s
.17575 .72852 m .17234 .76257 L .19351 .77519 L p .707 .577 .707 r
F P
0 g
s
.1739 .78219 m .17476 .80114 L .19576 .80421 L p .707 .577 .707 r
F P
0 g
s
.3528 .76861 m .35622 .73456 L .34014 .74593 L p .707 .577 .707 r
F P
0 g
s
.17234 .76257 m .17575 .72852 L .16296 .71408 L p .707 .577 .707 r
F P
0 g
s
.35227 .62799 m .35572 .68509 L .3628 .68056 L p .707 .577 .707 r
F P
0 g
s
.3628 .68056 m .35935 .62347 L .35227 .62799 L p .707 .577 .707 r
F P
0 g
s
.35622 .73456 m .3528 .76861 L .3596 .75483 L p .707 .577 .707 r
F P
0 g
s
.3596 .75483 m .36301 .72078 L .35622 .73456 L p .707 .577 .707 r
F P
0 g
s
.35935 .62347 m .3628 .68056 L .35992 .67654 L p .707 .577 .707 r
F P
0 g
s
.35992 .67654 m .35647 .61945 L .35935 .62347 L p .707 .577 .707 r
F P
0 g
s
.35507 .77148 m .35593 .79043 L .36305 .78494 L p .707 .577 .707 r
F P
0 g
s
.36305 .78494 m .36219 .76599 L .35507 .77148 L p .707 .577 .707 r
F P
0 g
s
.36301 .72078 m .3596 .75483 L .35645 .74 L p .707 .577 .707 r
F P
0 g
s
.35645 .74 m .35986 .70595 L .36301 .72078 L p .707 .577 .707 r
F P
0 g
s
.35647 .61945 m .35992 .67654 L .34736 .67342 L p .707 .577 .707 r
F P
0 g
s
.36021 .77977 m .35934 .76083 L .36219 .76599 L p .707 .577 .707 r
F P
0 g
s
.35986 .70595 m .35645 .74 L .34366 .72557 L p .707 .577 .707 r
F P
0 g
s
.34366 .72557 m .34707 .69152 L .35986 .70595 L p .707 .577 .707 r
F P
0 g
s
.35934 .76083 m .36021 .77977 L .34767 .77544 L p .707 .577 .707 r
F P
0 g
s
.35974 .79226 m .35975 .29037 L .3562 .2783 L p .707 .577 .707 r
F P
0 g
s
.36219 .76599 m .36305 .78494 L .36021 .77977 L p .707 .577 .707 r
F P
0 g
s
.35975 .29037 m .35974 .79226 L .37702 .80345 L p .707 .577 .707 r
F P
0 g
s
.66929 .77488 m .67129 .79306 L .64404 .79066 L p .707 .577 .707 r
F P
0 g
s
.16215 .69489 m .1587 .63779 L .15582 .63378 L p .707 .577 .707 r
F P
0 g
s
.16296 .71408 m .15955 .74814 L .17234 .76257 L p .707 .577 .707 r
F P
0 g
s
.17476 .80114 m .1739 .78219 L .16136 .77786 L p .707 .577 .707 r
F P
0 g
s
.16136 .77786 m .16223 .79681 L .17476 .80114 L p .707 .577 .707 r
F P
0 g
s
.15955 .74814 m .16296 .71408 L .15981 .69925 L p .707 .577 .707 r
F P
0 g
s
.15981 .69925 m .1564 .7333 L .15955 .74814 L p .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15981 .69925 L .15988 .69912 L p .707 .577 .707 r
F P
0 g
s
.16 .69188 m .16215 .69489 L p .16024 .67645 L .707 .577 .707 r
F P
0 g
s
.15988 .69912 m .16661 .68548 L p .15957 .71843 L .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15988 .69912 L .15957 .71843 L .707 .577 .707 r
F
.15582 .63378 m .15927 .69087 L .16 .69188 L p F P
0 g
s
.16024 .67645 m .15582 .63378 L .16 .69188 L .707 .577 .707 r
F
.6438 .28436 m .6438 .78625 L .64025 .77418 L p F P
0 g
s
.64025 .77418 m .64025 .27229 L .6438 .28436 L p .707 .577 .707 r
F P
0 g
s
.15927 .69087 m .15582 .63378 L .1629 .62925 L p .707 .577 .707 r
F P
0 g
s
.16223 .79681 m .16136 .77786 L .15852 .7727 L p .707 .577 .707 r
F P
0 g
s
.15852 .7727 m .15938 .79165 L .16223 .79681 L p .707 .577 .707 r
F P
0 g
s
.1629 .62925 m .16636 .68635 L .15927 .69087 L p .707 .577 .707 r
F P
0 g
s
.34736 .67342 m .34391 .61633 L .35647 .61945 L p .707 .577 .707 r
F P
0 g
s
.34767 .77544 m .34681 .7565 L .35934 .76083 L p .707 .577 .707 r
F P
0 g
s
.3562 .2783 m .3562 .78019 L .35974 .79226 L p .707 .577 .707 r
F P
0 g
s
.3562 .78019 m .3562 .2783 L .36672 .26652 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17925 .62467 m .17975 .63286 L p .16636 .68635 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .18268 .6741 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .16604 .69118 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16661 .68548 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18268 .6741 L p .18616 .68153 L .707 .577 .707 r
F P
0 g
s
.18275 .68258 m .18616 .68153 L .19051 .69082 L .707 .577 .707 r
F
.18192 .68169 m .18616 .68153 L .18275 .68258 L F
.20672 .67756 m .18903 .68065 L p .20552 .6756 L F P
0 g
s
.20552 .6756 m .20646 .66624 L p .21189 .67565 L .707 .577 .707 r
F P
0 g
s
.20672 .67756 m .20666 .67647 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20552 .6756 m .21189 .67565 L .20666 .67647 L .707 .577 .707 r
F
.23606 .67416 m .20672 .67756 L p .20723 .67638 L F P
0 g
s
.20646 .66624 m .23562 .66267 L p .22634 .67339 L .707 .577 .707 r
F P
0 g
s
.21189 .67565 m .20646 .66624 L .22634 .67339 L .707 .577 .707 r
F
.23562 .66267 m .26731 .66373 L p .25861 .6719 L F P
0 g
s
.24199 .67277 m .23562 .66267 L .25861 .6719 L .707 .577 .707 r
F
.23606 .67416 m .23599 .67308 L p .23659 .67305 L F P
0 g
s
.23468 .67209 m .23562 .66267 L p .24199 .67277 L .707 .577 .707 r
F P
0 g
s
.23606 .67416 m .23659 .67305 L .267 .67192 L .707 .577 .707 r
F
.26653 .67149 m .26731 .66373 L p .28039 .68418 L F P
0 g
s
.26784 .67189 m .26703 .67195 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26703 .67195 m .23606 .67416 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26731 .66373 m .29842 .66932 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.26781 .67142 m .26784 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.26389 .69778 m .26653 .67149 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .24199 .67277 L .24783 .68203 L .707 .577 .707 r
F
.23468 .67209 m .24199 .67277 L .23599 .67308 L F
.26731 .66373 m .26389 .69778 L .23221 .69672 L p F P
0 g
s
.26438 .6148 m .26781 .67142 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.2326 .61707 m .26438 .6148 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23606 .67416 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.23562 .66267 m .23457 .67315 L p .20305 .70029 L .707 .577 .707 r
F P
0 g
s
.23457 .67315 m .23221 .69672 L .20593 .69994 L p .707 .577 .707 r
F P
0 g
s
.20593 .69994 m .20305 .70029 L p .23457 .67315 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .23592 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .2326 .61707 L p .23647 .67138 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23647 .67138 L .23659 .67305 L .707 .577 .707 r
F
.24783 .68203 m .24199 .67277 L .25861 .6719 L F
.23221 .69672 m .23468 .67209 L p .24783 .68203 L F P
0 g
s
.2326 .61707 m .23592 .67189 L p .23468 .67209 L .707 .577 .707 r
F P
0 g
s
.20723 .67638 m .21533 .65745 L .23468 .67209 L .707 .577 .707 r
F
.21533 .65745 m .2326 .61707 L .23468 .67209 L F
.21688 .68432 m .21189 .67565 L .22634 .67339 L F
.20666 .67647 m .21189 .67565 L .21688 .68432 L F
.20327 .62047 m .2326 .61707 L p .20723 .67638 L F P
0 g
s
.18268 .6741 m .20646 .66624 L p .19051 .69082 L .707 .577 .707 r
F P
0 g
s
.20666 .67647 m .20659 .67528 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20646 .66624 m .20305 .70029 L .17927 .70815 L p .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20327 .62047 L p .20711 .67466 L .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20711 .67466 L .20723 .67638 L .707 .577 .707 r
F
.20659 .67528 m .20666 .67647 L p .20552 .6756 L F P
0 g
s
.20666 .67647 m .20672 .67756 L p .20552 .6756 L .707 .577 .707 r
F P
0 g
s
.20305 .70029 m .20552 .6756 L p .21688 .68432 L .707 .577 .707 r
F P
0 g
s
.20327 .62047 m .20659 .67528 L p .18271 .68176 L .707 .577 .707 r
F P
0 g
s
.18903 .68065 m .18271 .68176 L p .20659 .67528 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .18271 .68176 L .18214 .68192 L p .707 .577 .707 r
F P
0 g
s
.18214 .68192 m .18101 .68224 L p .18192 .68169 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18267 .68124 L .18214 .68192 L .707 .577 .707 r
F
.17927 .70815 m .18192 .68169 L p .19051 .69082 L F P
0 g
s
.17927 .70815 m .16319 .71953 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.18268 .6741 m .1818 .68287 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.1818 .68287 m .17927 .70815 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.17925 .62467 m .20327 .62047 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18271 .68176 m .18267 .68124 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .17925 .62467 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.17975 .63286 m .18267 .68124 L p .16723 .6861 L .707 .577 .707 r
F P
0 g
s
.18101 .68224 m .16723 .6861 L p .18267 .68124 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .16604 .69118 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16723 .6861 m .16636 .68635 L p .17975 .63286 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .1564 .7333 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16319 .71953 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64025 .27229 m .64025 .77418 L .62297 .76299 L p .707 .577 .707 r
F P
0 g
s
.62297 .76299 m .62297 .2611 L .64025 .27229 L p .707 .577 .707 r
F P
0 g
s
.16636 .68635 m .1629 .62925 L .17925 .62467 L p .707 .577 .707 r
F P
0 g
s
.15938 .79165 m .15852 .7727 L .16564 .76721 L p .707 .577 .707 r
F P
0 g
s
.16564 .76721 m .1665 .78615 L .15938 .79165 L p .707 .577 .707 r
F P
0 g
s
.34391 .61633 m .34736 .67342 L .32635 .6715 L p .707 .577 .707 r
F P
0 g
s
.32635 .6715 m .3229 .61441 L .34391 .61633 L p .707 .577 .707 r
F P
0 g
s
.36672 .76841 m .36672 .26652 L .3903 .2562 L p .707 .577 .707 r
F P
0 g
s
.36672 .26652 m .36672 .76841 L .3562 .78019 L p .707 .577 .707 r
F P
0 g
s
.34707 .69152 m .34366 .72557 L .32249 .71295 L p .707 .577 .707 r
F P
0 g
s
.32249 .71295 m .3259 .6789 L .34707 .69152 L p .707 .577 .707 r
F P
0 g
s
.1665 .78615 m .16564 .76721 L .18203 .76192 L p .707 .577 .707 r
F P
0 g
s
.18203 .76192 m .1829 .78087 L .1665 .78615 L p .707 .577 .707 r
F P
0 g
s
.62297 .2611 m .62297 .76299 L .59366 .75378 L p .707 .577 .707 r
F P
0 g
s
.59366 .75378 m .59366 .25189 L .62297 .2611 L p .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .3259 .6789 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.295 .70337 m .29796 .67385 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29796 .67385 m .29842 .66932 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .295 .70337 L .26389 .69778 L p .707 .577 .707 r
F P
0 g
s
.2955 .61388 m .29895 .67098 L .29589 .67107 L p .707 .577 .707 r
F P
0 g
s
.29589 .67107 m .26784 .67189 L p .27901 .64846 L .707 .577 .707 r
F P
0 g
s
.27901 .64846 m .2955 .61388 L .29589 .67107 L .707 .577 .707 r
F
.3229 .61441 m .32635 .6715 L .29895 .67098 L p F P
0 g
s
.29895 .67098 m .2955 .61388 L .3229 .61441 L p .707 .577 .707 r
F P
0 g
s
.34681 .7565 m .34767 .77544 L .32667 .77237 L p .707 .577 .707 r
F P
0 g
s
.32667 .77237 m .32581 .75342 L .34681 .7565 L p .707 .577 .707 r
F P
0 g
s
.3259 .6789 m .32249 .71295 L .295 .70337 L p .707 .577 .707 r
F P
0 g
s
.26784 .67189 m .26438 .6148 L .2955 .61388 L p .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73561 .61666 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .74139 .66903 L .73359 .67036 L .707 .577 .707 r
F
.73347 .66902 m .73359 .67036 L p .74139 .66903 L F P
0 g
s
.73561 .61666 m .7045 .61212 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.7045 .61212 m .70105 .66491 L .73216 .66946 L p .707 .577 .707 r
F P
0 g
s
.73269 .66031 m .70158 .66262 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.7361 .69854 m .73347 .66902 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73297 .66947 L p .73299 .66944 L .707 .577 .707 r
F P
0 g
s
.73561 .61666 m .73219 .66902 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76739 .61726 m .73561 .61666 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76408 .66795 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76739 .61726 L p .76353 .6675 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76353 .6675 L .76341 .66905 L .707 .577 .707 r
F
.79695 .69205 m .77366 .66719 L .76543 .66905 L F
.76543 .66905 m .76779 .69551 L .79407 .69239 L p F P
0 g
s
.79407 .69239 m .79695 .69205 L p .76543 .66905 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .76543 .66905 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.75216 .67984 m .76401 .66905 L .74139 .66903 L .707 .577 .707 r
F
.76779 .69551 m .76401 .66905 L .75216 .67984 L F
.76532 .66785 m .76543 .66905 L p .77366 .66719 L F P
0 g
s
.76408 .66795 m .76401 .66905 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76437 .65728 L .74139 .66903 L .707 .577 .707 r
F
.76543 .66905 m .76532 .66785 L p .76401 .66905 L F P
0 g
s
.76739 .61726 m .76408 .66795 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76532 .66785 m .76437 .65728 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .78467 .65022 L .76532 .66785 L .707 .577 .707 r
F
.78467 .65022 m .76739 .61726 L .76532 .66785 L F
.79673 .61384 m .76739 .61726 L p .79114 .66256 L F P
0 g
s
.79277 .66567 m .79289 .66407 L .79114 .66256 L .707 .577 .707 r
F
.79289 .66407 m .79673 .61384 L .79114 .66256 L F
.79695 .69205 m .82073 .68851 L p .81965 .68713 L F P
0 g
s
.79334 .66562 m .79341 .66452 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79673 .61384 L p .79289 .66407 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79289 .66407 L .79277 .66567 L .707 .577 .707 r
F
.79334 .66562 m .79353 .65382 L .77366 .66719 L F
.79458 .66553 m .79447 .66433 L p .79334 .66562 L F P
0 g
s
.79673 .61384 m .79341 .66452 L p .79451 .66429 L .707 .577 .707 r
F P
0 g
s
.81097 .66141 m .81729 .65954 L p .79341 .66452 L .707 .577 .707 r
F P
0 g
s
.79447 .66433 m .79353 .65382 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81098 .6455 L .79451 .66429 L .707 .577 .707 r
F
.81098 .6455 m .79673 .61384 L .79451 .66429 L F
.81965 .68713 m .81794 .66017 L .80088 .66319 L F
.79353 .65382 m .79458 .66553 L p .81965 .68713 L F P
0 g
s
.79458 .66553 m .79695 .69205 L p .81965 .68713 L .707 .577 .707 r
F P
0 g
s
.79695 .69205 m .79458 .66553 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.78312 .67729 m .79334 .66562 L .77366 .66719 L .707 .577 .707 r
F
.79695 .69205 m .79334 .66562 L .78312 .67729 L F
.79327 .66663 m .81097 .66141 L p .79447 .66433 L F P
0 g
s
.79341 .66452 m .79334 .66562 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.79334 .66562 m .79327 .66663 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .82075 .60675 L .79673 .61384 L p .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .79353 .65382 L p .80088 .66319 L .707 .577 .707 r
F P
0 g
s
.82073 .68851 m .83681 .68523 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.82075 .60675 m .81732 .65906 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .82073 .68851 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81786 .65919 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81732 .65906 m .81729 .65954 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.83001 .63745 m .82075 .60675 L .81788 .65887 L .707 .577 .707 r
F
.81808 .6588 m .81788 .65887 L .81786 .65919 L F
.83001 .63745 m .81788 .65887 L .81808 .6588 L F
.83364 .64946 m .83001 .63745 L .81808 .6588 L F
.82069 .68802 m .81808 .6588 L p .81965 .68713 L F P
0 g
s
.81808 .6588 m .81732 .65028 L p .81788 .65916 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .81788 .65916 L .81965 .68713 L .707 .577 .707 r
F
.81786 .65919 m .81899 .65849 L p .81808 .6588 L F P
0 g
s
.81899 .65849 m .83364 .64946 L p .81808 .6588 L .707 .577 .707 r
F P
0 g
s
.83364 .64946 m .8371 .59667 L .82075 .60675 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .81732 .65028 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83681 .68523 m .83396 .6534 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83396 .6534 m .83339 .647 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .81808 .6588 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81724 .66029 m .81732 .65028 L .80088 .66319 L .707 .577 .707 r
F
.81794 .66017 m .81788 .65916 L .81724 .66029 L F
.81788 .65916 m .81732 .65028 L .81724 .66029 L F
.82073 .68851 m .82069 .68802 L p .81965 .68713 L F P
0 g
s
.79353 .65382 m .76437 .65728 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.79327 .66663 m .79334 .66562 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .76532 .66785 L .76394 .67005 L .707 .577 .707 r
F
.76401 .66905 m .76394 .67005 L p .76532 .66785 L F P
0 g
s
.76394 .67005 m .79327 .66663 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .76532 .66785 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .73269 .66031 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76401 .66905 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73216 .66946 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73219 .66902 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.73347 .66902 m .73269 .66031 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76341 .66905 L .73299 .66944 L .707 .577 .707 r
F
.73297 .66947 m .76394 .67005 L p .73299 .66944 L F P
0 g
s
.73269 .66031 m .73347 .66902 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.73359 .67036 m .7361 .69854 L .76062 .69619 L p .707 .577 .707 r
F P
0 g
s
.76062 .69619 m .76779 .69551 L p .73359 .67036 L .707 .577 .707 r
F P
0 g
s
.3903 .2562 m .3903 .75809 L .36672 .76841 L p .707 .577 .707 r
F P
0 g
s
.3903 .75809 m .3903 .2562 L .42461 .24833 L p .707 .577 .707 r
F P
0 g
s
.1829 .78087 m .18203 .76192 L .20609 .75737 L p .707 .577 .707 r
F P
0 g
s
.70105 .66491 m .7045 .61212 L .6771 .60406 L p .707 .577 .707 r
F P
0 g
s
.20609 .75737 m .20696 .77631 L .1829 .78087 L p .707 .577 .707 r
F P
0 g
s
.32581 .75342 m .32667 .77237 L .29927 .77086 L p .707 .577 .707 r
F P
0 g
s
.29927 .77086 m .2984 .75191 L .32581 .75342 L p .707 .577 .707 r
F P
0 g
s
.59366 .25189 m .59366 .75378 L .55518 .74746 L p .707 .577 .707 r
F P
0 g
s
.55518 .74746 m .55518 .24557 L .59366 .25189 L p .707 .577 .707 r
F P
0 g
s
.67364 .65685 m .6771 .60406 L .65609 .59329 L p .707 .577 .707 r
F P
0 g
s
.6771 .60406 m .67364 .65685 L .70105 .66491 L p .707 .577 .707 r
F P
0 g
s
.20696 .77631 m .20609 .75737 L .23547 .75398 L p .707 .577 .707 r
F P
0 g
s
.70158 .66262 m .705 .70085 L .7361 .69854 L p .707 .577 .707 r
F P
0 g
s
.23547 .75398 m .23633 .77293 L .20696 .77631 L p .707 .577 .707 r
F P
0 g
s
.42461 .75022 m .42461 .24833 L .4663 .2437 L p .707 .577 .707 r
F P
0 g
s
.42461 .24833 m .42461 .75022 L .3903 .75809 L p .707 .577 .707 r
F P
0 g
s
.705 .70085 m .70158 .66262 L .6741 .66398 L p .707 .577 .707 r
F P
0 g
s
.2984 .75191 m .29927 .77086 L .26814 .77105 L p .707 .577 .707 r
F P
0 g
s
.26814 .77105 m .26727 .7521 L .2984 .75191 L p .707 .577 .707 r
F P
0 g
s
.6741 .66398 m .67751 .70221 L .705 .70085 L p .707 .577 .707 r
F P
0 g
s
.23633 .77293 m .23547 .75398 L .26727 .7521 L p .707 .577 .707 r
F P
0 g
s
.55518 .24557 m .55518 .74746 L .51129 .74463 L p .707 .577 .707 r
F P
0 g
s
.51129 .74463 m .51129 .24274 L .55518 .24557 L p .707 .577 .707 r
F P
0 g
s
.26727 .7521 m .26814 .77105 L .23633 .77293 L p .707 .577 .707 r
F P
0 g
s
.65264 .64608 m .65609 .59329 L .64353 .58085 L p .707 .577 .707 r
F P
0 g
s
.65609 .59329 m .65264 .64608 L .67364 .65685 L p .707 .577 .707 r
F P
0 g
s
.73186 .76859 m .73272 .75072 L .70159 .7468 L p .707 .577 .707 r
F P
0 g
s
.73272 .75072 m .73186 .76859 L .76367 .76887 L p .707 .577 .707 r
F P
0 g
s
.76367 .76887 m .76453 .751 L .73272 .75072 L p .707 .577 .707 r
F P
0 g
s
.4663 .74558 m .4663 .2437 L .51129 .24274 L p .707 .577 .707 r
F P
0 g
s
.4663 .2437 m .4663 .74558 L .42461 .75022 L p .707 .577 .707 r
F P
0 g
s
.67751 .70221 m .6741 .66398 L .65292 .66426 L p .707 .577 .707 r
F P
0 g
s
.76453 .751 m .76367 .76887 L .79304 .76549 L p .707 .577 .707 r
F P
0 g
s
.79304 .76549 m .7939 .74762 L .76453 .751 L p .707 .577 .707 r
F P
0 g
s
.65292 .66426 m .65634 .70249 L .67751 .70221 L p .707 .577 .707 r
F P
0 g
s
.51129 .24274 m .51129 .74463 L .4663 .74558 L p .707 .577 .707 r
F P
0 g
s
.70073 .76467 m .70159 .7468 L .67419 .73963 L p .707 .577 .707 r
F P
0 g
s
.70159 .7468 m .70073 .76467 L .73186 .76859 L p .707 .577 .707 r
F P
0 g
s
.67419 .73963 m .67333 .7575 L .70073 .76467 L p .707 .577 .707 r
F P
0 g
s
.7939 .74762 m .79304 .76549 L .8171 .75876 L p .707 .577 .707 r
F P
0 g
s
.8171 .75876 m .81796 .74089 L .7939 .74762 L p .707 .577 .707 r
F P
0 g
s
.8371 .59667 m .83364 .64946 L .84072 .63739 L p .707 .577 .707 r
F P
0 g
s
.84072 .63739 m .84418 .5846 L .8371 .59667 L p .707 .577 .707 r
F P
0 g
s
.67333 .7575 m .67419 .73963 L .65319 .7299 L p .707 .577 .707 r
F P
0 g
s
.64353 .58085 m .64008 .63364 L .65264 .64608 L p .707 .577 .707 r
F P
0 g
s
.64008 .63364 m .64353 .58085 L .64065 .56796 L p .707 .577 .707 r
F P
0 g
s
.65634 .70249 m .65292 .66426 L .64014 .66343 L p .707 .577 .707 r
F P
0 g
s
.65319 .7299 m .65233 .74777 L .67333 .7575 L p .707 .577 .707 r
F P
0 g
s
.64014 .66343 m .64355 .70166 L .65634 .70249 L p .707 .577 .707 r
F P
0 g
s
.81796 .74089 m .8171 .75876 L .8335 .74936 L p .707 .577 .707 r
F P
0 g
s
.8335 .74936 m .83436 .73149 L .81796 .74089 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .83681 .68523 L .8436 .68253 L p .707 .577 .707 r
F P
0 g
s
.8436 .68253 m .84019 .6443 L .83339 .647 L p .707 .577 .707 r
F P
0 g
s
.65233 .74777 m .65319 .7299 L .64065 .71857 L p .707 .577 .707 r
F P
0 g
s
.84418 .5846 m .84072 .63739 L .83785 .6245 L p .707 .577 .707 r
F P
0 g
s
.83785 .6245 m .8413 .57171 L .84418 .5846 L p .707 .577 .707 r
F P
0 g
s
.64065 .56796 m .6372 .62075 L .64008 .63364 L p .707 .577 .707 r
F P
0 g
s
.64065 .71857 m .63979 .73644 L .65233 .74777 L p .707 .577 .707 r
F P
0 g
s
.6372 .62075 m .64065 .56796 L .64773 .55589 L p .707 .577 .707 r
F P
0 g
s
.64355 .70166 m .64014 .66343 L .63699 .66158 L p .707 .577 .707 r
F P
0 g
s
.63699 .66158 m .6404 .69981 L .64355 .70166 L p .707 .577 .707 r
F P
0 g
s
.83436 .73149 m .8335 .74936 L .84062 .73821 L p .707 .577 .707 r
F P
0 g
s
.84062 .73821 m .84148 .72034 L .83436 .73149 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63979 .73644 m .64065 .71857 L .63781 .70675 L p .707 .577 .707 r
F P
0 g
s
.84019 .6443 m .8436 .68253 L .84045 .68067 L p .707 .577 .707 r
F P
0 g
s
.84045 .68067 m .83703 .64245 L .84019 .6443 L p .707 .577 .707 r
F P
0 g
s
.8413 .57171 m .83785 .6245 L .82529 .61206 L p .707 .577 .707 r
F P
0 g
s
.82529 .61206 m .82874 .55927 L .8413 .57171 L p .707 .577 .707 r
F P
0 g
s
.64773 .55589 m .64428 .60868 L .6372 .62075 L p .707 .577 .707 r
F P
0 g
s
.63781 .70675 m .63695 .72462 L .63979 .73644 L p .707 .577 .707 r
F P
0 g
s
.64428 .60868 m .64773 .55589 L .66408 .54581 L p .707 .577 .707 r
F P
0 g
s
.6404 .69981 m .63699 .66158 L .64378 .65888 L p .707 .577 .707 r
F P
0 g
s
.64378 .65888 m .6472 .69711 L .6404 .69981 L p .707 .577 .707 r
F P
0 g
s
.38737 .61375 m .39539 .5579 L .36455 .55215 L p .707 .577 .707 r
F P
0 g
s
.39539 .5579 m .38737 .61375 L .41891 .6175 L p .707 .577 .707 r
F P
0 g
s
.41891 .6175 m .42693 .56164 L .39539 .5579 L p .707 .577 .707 r
F P
0 g
s
.84148 .72034 m .84062 .73821 L .83777 .72638 L p .707 .577 .707 r
F P
0 g
s
.83777 .72638 m .83863 .70851 L .84148 .72034 L p .707 .577 .707 r
F P
0 g
s
.42693 .56164 m .41891 .6175 L .44805 .61887 L p .707 .577 .707 r
F P
0 g
s
.44805 .61887 m .45607 .56301 L .42693 .56164 L p .707 .577 .707 r
F P
0 g
s
.35653 .60801 m .36455 .55215 L .33742 .54496 L p .707 .577 .707 r
F P
0 g
s
.36455 .55215 m .35653 .60801 L .38737 .61375 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63695 .72462 m .63781 .70675 L .64493 .69559 L p .707 .577 .707 r
F P
0 g
s
.82874 .55927 m .82529 .61206 L .80428 .60129 L p .707 .577 .707 r
F P
0 g
s
.80428 .60129 m .80773 .5485 L .82874 .55927 L p .707 .577 .707 r
F P
0 g
s
.66408 .54581 m .66063 .5986 L .64428 .60868 L p .707 .577 .707 r
F P
0 g
s
.83703 .64245 m .84045 .68067 L .82766 .67985 L p .707 .577 .707 r
F P
0 g
s
.82766 .67985 m .82425 .64162 L .83703 .64245 L p .707 .577 .707 r
F P
0 g
s
.45607 .56301 m .44805 .61887 L .47195 .61773 L p .707 .577 .707 r
F P
0 g
s
.47195 .61773 m .47997 .56187 L .45607 .56301 L p .707 .577 .707 r
F P
0 g
s
.64493 .69559 m .64407 .71346 L .63695 .72462 L p .707 .577 .707 r
F P
0 g
s
.33742 .54496 m .3294 .60082 L .35653 .60801 L p .707 .577 .707 r
F P
0 g
s
.66063 .5986 m .66408 .54581 L .6881 .53872 L p .707 .577 .707 r
F P
0 g
s
.3294 .60082 m .33742 .54496 L .31665 .53703 L p .707 .577 .707 r
F P
0 g
s
.39499 .6899 m .38712 .65467 L .3566 .65815 L p .707 .577 .707 r
F P
0 g
s
.38712 .65467 m .39499 .6899 L .42615 .68278 L p .707 .577 .707 r
F P
0 g
s
.42615 .68278 m .41828 .64754 L .38712 .65467 L p .707 .577 .707 r
F P
0 g
s
.41828 .64754 m .42615 .68278 L .45489 .6727 L p .707 .577 .707 r
F P
0 g
s
.45489 .6727 m .44703 .63747 L .41828 .64754 L p .707 .577 .707 r
F P
0 g
s
.6472 .69711 m .64378 .65888 L .65986 .6556 L p .707 .577 .707 r
F P
0 g
s
.83863 .70851 m .83777 .72638 L .82524 .71505 L p .707 .577 .707 r
F P
0 g
s
.82524 .71505 m .8261 .69718 L .83863 .70851 L p .707 .577 .707 r
F P
0 g
s
.65986 .6556 m .66327 .69383 L .6472 .69711 L p .707 .577 .707 r
F P
0 g
s
.36446 .69339 m .3566 .65815 L .3297 .65765 L p .707 .577 .707 r
F P
0 g
s
.3566 .65815 m .36446 .69339 L .39499 .6899 L p .707 .577 .707 r
F P
0 g
s
.31665 .53703 m .30863 .59289 L .3294 .60082 L p .707 .577 .707 r
F P
0 g
s
.44703 .63747 m .45489 .6727 L .4784 .66067 L p .707 .577 .707 r
F P
0 g
s
.4784 .66067 m .47054 .62544 L .44703 .63747 L p .707 .577 .707 r
F P
0 g
s
.80773 .5485 m .80428 .60129 L .77688 .59323 L p .707 .577 .707 r
F P
0 g
s
.77688 .59323 m .78033 .54044 L .80773 .5485 L p .707 .577 .707 r
F P
0 g
s
.38694 .718 m .38894 .69936 L .35797 .69458 L p .707 .577 .707 r
F P
0 g
s
.38894 .69936 m .38694 .718 L .41861 .72061 L p .707 .577 .707 r
F P
0 g
s
.41861 .72061 m .42062 .70197 L .38894 .69936 L p .707 .577 .707 r
F P
0 g
s
.48603 .61468 m .48825 .6142 L p .47536 .59393 L .707 .577 .707 r
F P
0 g
s
.48652 .61263 m .48772 .61797 L p .50127 .63552 L .707 .577 .707 r
F P
0 g
s
.48772 .61797 m .49438 .64786 L .49891 .63976 L p .707 .577 .707 r
F P
0 g
s
.49891 .63976 m .50127 .63552 L p .48772 .61797 L .707 .577 .707 r
F P
0 g
s
.47997 .56187 m .47536 .59393 L p .48825 .6142 L .707 .577 .707 r
F P
0 g
s
.47536 .59393 m .47195 .61773 L .48603 .61468 L p .707 .577 .707 r
F P
0 g
s
.48825 .6142 m .49627 .55834 L .47997 .56187 L p .707 .577 .707 r
F P
0 g
s
.68465 .59151 m .6881 .53872 L .71744 .5353 L p .707 .577 .707 r
F P
0 g
s
.6881 .53872 m .68465 .59151 L .66063 .5986 L p .707 .577 .707 r
F P
0 g
s
.64407 .71346 m .64493 .69559 L .66132 .68619 L p .707 .577 .707 r
F P
0 g
s
.42062 .70197 m .41861 .72061 L .44787 .72079 L p .707 .577 .707 r
F P
0 g
s
.44787 .72079 m .44988 .70215 L .42062 .70197 L p .707 .577 .707 r
F P
0 g
s
.35797 .69458 m .35596 .71321 L .38694 .718 L p .707 .577 .707 r
F P
0 g
s
.35596 .71321 m .35693 .7042 L p .33071 .68808 L .707 .577 .707 r
F P
0 g
s
.34841 .6923 m .33071 .68808 L p .35693 .7042 L .707 .577 .707 r
F P
0 g
s
.33756 .69289 m .33245 .67001 L p .30905 .65321 L .707 .577 .707 r
F P
0 g
s
.33245 .67001 m .3297 .65765 L .3225 .6561 L p .707 .577 .707 r
F P
0 g
s
.3225 .6561 m .30905 .65321 L p .33245 .67001 L .707 .577 .707 r
F P
0 g
s
.35693 .7042 m .35797 .69458 L .34841 .6923 L p .707 .577 .707 r
F P
0 g
s
.30863 .59289 m .31665 .53703 L .30428 .52914 L p .707 .577 .707 r
F P
0 g
s
.82425 .64162 m .82766 .67985 L .80649 .68013 L p .707 .577 .707 r
F P
0 g
s
.80649 .68013 m .80307 .6419 L .82425 .64162 L p .707 .577 .707 r
F P
0 g
s
.3297 .65765 m .33756 .69289 L .36446 .69339 L p .707 .577 .707 r
F P
0 g
s
.66132 .68619 m .66046 .70406 L .64407 .71346 L p .707 .577 .707 r
F P
0 g
s
.33071 .68808 m .3287 .70672 L .35596 .71321 L p .707 .577 .707 r
F P
0 g
s
.78033 .54044 m .77688 .59323 L .74576 .58869 L p .707 .577 .707 r
F P
0 g
s
.74576 .58869 m .74922 .53589 L .78033 .54044 L p .707 .577 .707 r
F P
0 g
s
.71398 .58809 m .71744 .5353 L .74922 .53589 L p .707 .577 .707 r
F P
0 g
s
.71744 .5353 m .71398 .58809 L .68465 .59151 L p .707 .577 .707 r
F P
0 g
s
.47054 .62544 m .4784 .66067 L .49438 .64786 L p .707 .577 .707 r
F P
0 g
s
.49438 .64786 m .48652 .61263 L .47054 .62544 L p .707 .577 .707 r
F P
0 g
s
.44988 .70215 m .44787 .72079 L .47186 .71852 L p .707 .577 .707 r
F P
0 g
s
.47186 .71852 m .47387 .69988 L .44988 .70215 L p .707 .577 .707 r
F P
0 g
s
.74922 .53589 m .74576 .58869 L .71398 .58809 L p .707 .577 .707 r
F P
0 g
s
.66327 .69383 m .65986 .6556 L .68364 .65206 L p .707 .577 .707 r
F P
0 g
s
.30428 .52914 m .29626 .585 L .30863 .59289 L p .707 .577 .707 r
F P
0 g
s
.8261 .69718 m .82524 .71505 L .80424 .70532 L p .707 .577 .707 r
F P
0 g
s
.80424 .70532 m .8051 .68746 L .8261 .69718 L p .707 .577 .707 r
F P
0 g
s
.3287 .70672 m .3295 .69934 L p .30985 .68052 L .707 .577 .707 r
F P
0 g
s
.32216 .68498 m .30985 .68052 L p .3295 .69934 L .707 .577 .707 r
F P
0 g
s
.31691 .68845 m .31147 .66407 L p .29668 .64528 L .707 .577 .707 r
F P
0 g
s
.31147 .66407 m .30905 .65321 L .3044 .65023 L p .707 .577 .707 r
F P
0 g
s
.3044 .65023 m .29668 .64528 L p .31147 .66407 L .707 .577 .707 r
F P
0 g
s
.3295 .69934 m .33071 .68808 L .32216 .68498 L p .707 .577 .707 r
F P
0 g
s
.68364 .65206 m .68705 .69028 L .66327 .69383 L p .707 .577 .707 r
F P
0 g
s
.30985 .68052 m .30784 .69916 L .3287 .70672 L p .707 .577 .707 r
F P
0 g
s
.30905 .65321 m .31691 .68845 L .33756 .69289 L p .707 .577 .707 r
F P
0 g
s
.66046 .70406 m .66132 .68619 L .68538 .67947 L p .707 .577 .707 r
F P
0 g
s
.49166 .5905 m .48825 .6142 L .49529 .60869 L p .707 .577 .707 r
F P
0 g
s
.49341 .60029 m .48652 .61263 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.50127 .63552 m .49534 .60891 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49534 .60891 m .49341 .60029 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49627 .55834 m .49166 .5905 L p .49538 .60862 L .707 .577 .707 r
F P
0 g
s
.49529 .60869 m .49538 .60862 L p .49166 .5905 L .707 .577 .707 r
F P
0 g
s
.49538 .60862 m .5034 .55276 L .49627 .55834 L p .707 .577 .707 r
F P
0 g
s
.5034 .55276 m .49538 .60862 L .49535 .60856 L p .707 .577 .707 r
F P
0 g
s
.49493 .60748 m .49262 .60154 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49469 .60662 L .49534 .60892 L .708 .578 .707 r
F
.49341 .60029 m .49534 .60891 L p .49469 .60662 L F P
0 g
s
.49534 .60891 m .49534 .60892 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49535 .60856 m .49493 .60748 L p .49668 .58319 L .707 .577 .707 r
F P
0 g
s
.49053 .58963 m .49341 .60029 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49262 .60154 m .49284 .60001 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49262 .60154 m .48026 .59365 L p .48082 .59231 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .4922 .59959 L .49262 .60154 L .707 .577 .707 r
F
.49839 .62486 m .48602 .61693 L p .4892 .59767 L F P
0 g
s
.49053 .58963 m .49284 .6 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .49262 .60154 L p .4922 .59959 L .707 .577 .707 r
F P
0 g
s
.47816 .58169 m .49053 .58963 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48735 .57695 m .49284 .6 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49284 .60001 L .4922 .59959 L F
.48048 .59209 m .47816 .58169 L .4892 .59767 L F
.48048 .59209 m .48026 .59365 L p .47932 .59175 L F P
0 g
s
.47816 .58169 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45751 .57726 m .47816 .58169 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .46231 .58679 L p .47932 .59175 L .707 .577 .707 r
F P
0 g
s
.46537 .61249 m .45945 .58596 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45946 .58596 m .45751 .57726 L .47456 .59036 L .707 .577 .707 r
F
.45945 .58596 m .45751 .57726 L p .45946 .58596 L F P
0 g
s
.45751 .57726 m .46537 .61249 L .43847 .61199 L p .707 .577 .707 r
F P
0 g
s
.46751 .52986 m .45949 .58572 L .45921 .58565 L p .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .45751 .57726 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43847 .61199 m .43182 .58221 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43182 .58221 m .43061 .57676 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .43847 .61199 L .40794 .61548 L p .707 .577 .707 r
F P
0 g
s
.40794 .61548 m .40008 .58024 L .43061 .57676 L p .707 .577 .707 r
F P
0 g
s
.44038 .52267 m .43236 .57853 L .42821 .57776 L p .707 .577 .707 r
F P
0 g
s
.42821 .57776 m .40151 .57278 L p .41258 .55851 L .707 .577 .707 r
F P
0 g
s
.41258 .55851 m .44038 .52267 L .42821 .57776 L .707 .577 .707 r
F
.45921 .58565 m .43236 .57853 L p .4428 .56408 L F P
0 g
s
.4428 .56408 m .46751 .52986 L .45921 .58565 L .707 .577 .707 r
F
.45945 .58596 m .45945 .58596 L p .45946 .58596 L F P
0 g
s
.45949 .58572 m .46877 .57027 L .47932 .59175 L .707 .577 .707 r
F
.46231 .58679 m .45949 .58572 L p .47932 .59175 L F P
0 g
s
.46877 .57027 m .48048 .59209 L .47932 .59175 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L .47932 .59175 L F
.48602 .61693 m .46537 .61249 L p .47456 .59036 L F P
0 g
s
.48828 .53779 m .50064 .54568 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .48048 .59209 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48828 .53779 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48602 .61693 L p .47706 .59617 L .707 .577 .707 r
F P
0 g
s
.47456 .59036 m .48048 .59209 L .47706 .59617 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L p .48048 .59209 L F P
0 g
s
.48048 .59209 m .47816 .58169 L p .48048 .59209 L .707 .577 .707 r
F P
0 g
s
.48828 .53779 m .48048 .59209 L p .46877 .57027 L .707 .577 .707 r
F P
0 g
s
.48602 .61693 m .48048 .59209 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .6 m .49839 .62486 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .48735 .57695 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49053 .58963 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.50064 .54568 m .49284 .60001 L p .48735 .57695 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49284 .6 L p .49284 .60001 L .708 .578 .707 r
F P
0 g
s
.49626 .61436 m .49284 .60001 L .49469 .60662 L .708 .578 .707 r
F
.49839 .62486 m .49284 .60001 L .49626 .61436 L F
.50064 .54568 m .5034 .55276 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .50064 .54568 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49291 .60024 m .49668 .58319 L .49493 .60748 L .707 .577 .707 r
F
.49668 .58319 m .5034 .55276 L .49535 .60856 L F
.49534 .60892 m .50127 .63552 L .4989 .62675 L p .708 .578 .707 r
F P
0 g
s
.4989 .62675 m .49839 .62486 L p .49534 .60892 L .708 .578 .707 r
F P
0 g
s
.80307 .6419 m .80649 .68013 L .779 .68149 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .77559 .64326 L .80307 .6419 L p .707 .577 .707 r
F P
0 g
s
.68538 .67947 m .68452 .69734 L .66046 .70406 L p .707 .577 .707 r
F P
0 g
s
.29626 .585 m .30428 .52914 L .30153 .52206 L p .707 .577 .707 r
F P
0 g
s
.47387 .69988 m .47186 .71852 L .48823 .71402 L p .707 .577 .707 r
F P
0 g
s
.48823 .71402 m .49024 .69538 L .47387 .69988 L p .707 .577 .707 r
F P
0 g
s
.68705 .69028 m .68364 .65206 L .7128 .6486 L p .707 .577 .707 r
F P
0 g
s
.8051 .68746 m .80424 .70532 L .77683 .69815 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .7479 .6838 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77559 .64326 m .77696 .65859 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77696 .65859 m .779 .68149 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .77769 .68028 L .79428 .68462 L p .707 .577 .707 r
F P
0 g
s
.79428 .68462 m .8051 .68746 L p .79796 .69015 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .79428 .68462 L .79796 .69015 L .707 .577 .707 r
F
.7128 .6486 m .71621 .68683 L .68705 .69028 L p F P
0 g
s
.304 .67681 m .29742 .67263 L p .3083 .69495 L .707 .577 .707 r
F P
0 g
s
.30454 .68051 m .29911 .65617 L p .2938 .63462 L .708 .578 .707 r
F P
0 g
s
.29911 .65617 m .29668 .64528 L .29547 .6408 L p .708 .578 .707 r
F P
0 g
s
.29547 .6408 m .2938 .63462 L p .29911 .65617 L .708 .578 .707 r
F P
0 g
s
.30784 .69916 m .3083 .69495 L p .29742 .67263 L .707 .577 .707 r
F P
0 g
s
.3083 .69495 m .30985 .68052 L .304 .67681 L p .707 .577 .707 r
F P
0 g
s
.68452 .69734 m .68538 .67947 L .71476 .67608 L p .707 .577 .707 r
F P
0 g
s
.30153 .52206 m .29351 .57791 L .29626 .585 L p .707 .577 .707 r
F P
0 g
s
.29742 .67263 m .29541 .69127 L .30784 .69916 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .74448 .64557 L .77559 .64326 L p .707 .577 .707 r
F P
0 g
s
.29668 .64528 m .30454 .68051 L .31691 .68845 L p .707 .577 .707 r
F P
0 g
s
.71621 .68683 m .7128 .6486 L .74448 .64557 L p .707 .577 .707 r
F P
0 g
s
.71476 .67608 m .71389 .69395 L .68452 .69734 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .71621 .68683 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.74561 .65814 m .7479 .6838 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .74656 .67636 L .76501 .67868 L p .707 .577 .707 r
F P
0 g
s
.76501 .67868 m .77769 .68028 L p .76978 .68373 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .76501 .67868 L .76978 .68373 L .707 .577 .707 r
F
.74448 .64557 m .74561 .65814 L p .73996 .65217 L F P
0 g
s
.77769 .68028 m .77683 .69815 L .7457 .69423 L p .707 .577 .707 r
F P
0 g
s
.71389 .69395 m .71476 .67608 L .74656 .67636 L p .707 .577 .707 r
F P
0 g
s
.74656 .67636 m .7457 .69423 L .71389 .69395 L p .707 .577 .707 r
F P
0 g
s
.49024 .69538 m .48823 .71402 L .49538 .70774 L p .707 .577 .707 r
F P
0 g
s
.49538 .70774 m .49739 .6891 L .49024 .69538 L p .707 .577 .707 r
F P
0 g
s
.29351 .57791 m .30153 .52206 L .30865 .51648 L p .707 .577 .707 r
F P
0 g
s
.29541 .69127 m .29742 .67263 L .29465 .66518 L p .707 .577 .707 r
F P
0 g
s
.29465 .66518 m .29264 .68381 L .29541 .69127 L p .707 .577 .707 r
F P
0 g
s
.29264 .68381 m .29465 .66518 L .2994 .661 L p .707 .577 .707 r
F P
0 g
s
.30166 .66986 m .30454 .68051 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.29662 .64728 m .30166 .66986 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.2938 .63462 m .29662 .64728 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.30166 .66986 m .2938 .63462 L .30068 .62228 L p .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30166 .66986 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30068 .62228 m .30418 .63794 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30418 .63794 m .30854 .65752 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30068 .62228 L .31666 .60947 L p .707 .577 .707 r
F P
0 g
s
.31666 .60947 m .32453 .6447 L .30854 .65752 L p .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .30179 .6589 L .31285 .65586 L p .707 .577 .707 r
F P
0 g
s
.31285 .65586 m .31816 .6544 L p .31442 .65911 L .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .31285 .65586 L .31442 .65911 L .707 .577 .707 r
F
.2994 .661 m .30179 .6589 L p .29997 .66384 L F P
0 g
s
.29264 .68381 m .2994 .661 L .29997 .66384 L .707 .577 .707 r
F
.30865 .51648 m .30063 .57233 L .29351 .57791 L p F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49739 .6891 m .49538 .70774 L .4926 .70029 L p .707 .577 .707 r
F P
0 g
s
.4926 .70029 m .49461 .68165 L .49739 .6891 L p .707 .577 .707 r
F P
0 g
s
.30063 .57233 m .30865 .51648 L .32496 .51295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30179 .6589 m .29978 .67753 L .29264 .68381 L p .707 .577 .707 r
F P
0 g
s
.32496 .51295 m .31694 .5688 L .30063 .57233 L p .707 .577 .707 r
F P
0 g
s
.45949 .58572 m .46751 .52986 L .48828 .53779 L p .707 .577 .707 r
F P
0 g
s
.31694 .5688 m .32496 .51295 L .34886 .51181 L p .707 .577 .707 r
F P
0 g
s
.49461 .68165 m .4926 .70029 L .48017 .6924 L p .707 .577 .707 r
F P
0 g
s
.48017 .6924 m .48218 .67376 L .49461 .68165 L p .707 .577 .707 r
F P
0 g
s
.34886 .51181 m .34083 .56767 L .31694 .5688 L p .707 .577 .707 r
F P
0 g
s
.31816 .6544 m .31615 .67304 L .29978 .67753 L p .707 .577 .707 r
F P
0 g
s
.43236 .57853 m .44038 .52267 L .46751 .52986 L p .707 .577 .707 r
F P
0 g
s
.34083 .56767 m .34886 .51181 L .378 .51318 L p .707 .577 .707 r
F P
0 g
s
.32453 .6447 m .31666 .60947 L .34018 .59744 L p .707 .577 .707 r
F P
0 g
s
.48218 .67376 m .48017 .6924 L .45931 .68483 L p .707 .577 .707 r
F P
0 g
s
.45931 .68483 m .46132 .6662 L .48218 .67376 L p .707 .577 .707 r
F P
0 g
s
.40151 .57278 m .40953 .51692 L .44038 .52267 L p .707 .577 .707 r
F P
0 g
s
.378 .51318 m .36998 .56904 L .34083 .56767 L p .707 .577 .707 r
F P
0 g
s
.36998 .56904 m .378 .51318 L .40953 .51692 L p .707 .577 .707 r
F P
0 g
s
.31615 .67304 m .31816 .6544 L .34215 .65213 L p .707 .577 .707 r
F P
0 g
s
.34018 .59744 m .34804 .63267 L .32453 .6447 L p .707 .577 .707 r
F P
0 g
s
.40953 .51692 m .40151 .57278 L .36998 .56904 L p .707 .577 .707 r
F P
0 g
s
.34215 .65213 m .34015 .67077 L .31615 .67304 L p .707 .577 .707 r
F P
0 g
s
.34804 .63267 m .34018 .59744 L .36892 .58737 L p .707 .577 .707 r
F P
0 g
s
.37678 .6226 m .36892 .58737 L .40008 .58024 L p .707 .577 .707 r
F P
0 g
s
.36892 .58737 m .37678 .6226 L .34804 .63267 L p .707 .577 .707 r
F P
0 g
s
.40008 .58024 m .40794 .61548 L .37678 .6226 L p .707 .577 .707 r
F P
0 g
s
.46132 .6662 m .45931 .68483 L .43206 .67834 L p .707 .577 .707 r
F P
0 g
s
.43206 .67834 m .43407 .65971 L .46132 .6662 L p .707 .577 .707 r
F P
0 g
s
.34015 .67077 m .34215 .65213 L .37142 .65231 L p .707 .577 .707 r
F P
0 g
s
.37142 .65231 m .36941 .67095 L .34015 .67077 L p .707 .577 .707 r
F P
0 g
s
.43407 .65971 m .43206 .67834 L .40108 .67356 L p .707 .577 .707 r
F P
0 g
s
.40108 .67356 m .40309 .65492 L .43407 .65971 L p .707 .577 .707 r
F P
0 g
s
.36941 .67095 m .37142 .65231 L .40309 .65492 L p .707 .577 .707 r
F P
0 g
s
.40309 .65492 m .40108 .67356 L .36941 .67095 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001JOolE0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001GOol30002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH7000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P004Goo4@00A7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002goo1P000eYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH0
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000lOol005Aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP<003Uoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004Ool2
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000gOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000eOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000cOol005Aoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0002
FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@000=J
EP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80031oo`00Dgoo00<005YF00000UYF5P0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000;Woo
001COol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF001JEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJ
EP0002eoo`00Dgoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
1`0015YF00<005YF00000`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800005FUH005YFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Goo001DOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eo
o`<000EJEP03001JEUYF00IJEPD000IJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0004
FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00Egoo0P0015YF00<005YFFUH00eYF100000=JEP00
FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00=JEPH0015oo`H0
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FGoo0`0000AJEP00FUIJEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP03001JEP0000<0011oo`<000Yoo`8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo02]oo`00G7oo1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF10004Goo1@002goo0`0000=JEP00FUH015YF00@005YFFUIJEP8002eo
o`00GGoo00@005YFFUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH00UYF0`003Woo1@003Woo0P001EYF00@005YFFUIJEP8002eo
o`00Fgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YF10001EYF00@005YF000000aoo`D0011oo`8000=JEP04001JEUYFFUH2
000]Ool005Yoo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP04001JEUYFFUH3000:Ool3
000@Ool500000eYF001JEP02FUH2000]Ool004Mooa@000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPl000=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF1P004Woo1@001EYF
0P000eYF00<007ooOol0;7oo000nOol90004FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF2@0015YF00@005YFFUIJEPP0009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH00UYF4P0035YF00@005YFFUH002ioo`00=Woo200015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01000
1UYF00<005YFFUH0200000=JEP00FUH00P000UYF10000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF01QJEP<002ioo`00<Goo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH015YF00<005YFFUH015YF1P002EYF00<005YFFUH02EYF0P00
1EYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001J
EP0002ioo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P001EYF00<005YFFUH015YF00<005YFFUH010001EYF10001UYF00<005YFFUH025YF0`001EYF
00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001JEP00
02ioo`00;Goo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00MJEP04
001JEUYF0005FUH01000FUH000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
01QJEP03001JEP0002ioo`00;7oo00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000=JEP04001JEUYF0005FUH5
0005FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF01AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH0
0003FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF
00H005YFFUH005YF0003FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00eYF0P001UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00eJEP03
001JEUYF00AJEP07001JEUYFOol005YF0000;Woo000/Ool00`00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF0`000UYF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00<00003FUH005YF00EJEP03001JEUYF00=JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUHF000_Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF
0`001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP<000QJEP03001JEUYF00=J
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20003FUH20003FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<0009JEP03001JEP00
0100009JEP@00003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH200000eYF000000060003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`0015YF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20007FUH20007FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYFFUHA0004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1eYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH00`00FUH00002FUH500000eYF001JEP06
FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH60006FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF00@005YFFUIJEQ0000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF00000eYF00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000EJEP00FUIJEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEP0000@0009JEP03001JEUYF00AJEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF01T002eoo`00;Goo00<005YF0000
0UYF0P001EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP@000EJEP@000AJEP05001JEUYFFUH00004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEPD0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP040006FUH00`00
FUIJEP04000]Ool002eoo`03001JEP0000800003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYFFUH50002FUH20007FUH00`00FUIJEP04FUH900000eYF001JEP0:FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000AJEP<0035oo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP800003FUH005YF00IJEP03001JEUYF
009JEPL000EJEP03001JEUYF00UJEP03001JEUYF008000=JEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00;Goo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF3`00
0UYF10001UYF00<005YFFUH02EYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00=JEPh000IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001J
EUYF009JEPT000EJEP03001JEUYF00UJEP04001JEUYFFUH50004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF1P0000=JEP00FUH00eYF
20000goo1P001UYF00<005YFFUH00UYF0P00<Woo000]Ool00eYFOol00002FUH00`00FUIJEP03FUH<
0009Ool40002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHE0003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000eYF00<005YF00003`004Goo10000UYF00<005YFFUH00eYF0P00<Goo000]Ool00eYF001JEP02
FUH00`00FUH00003000IOol40006FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF0P000eYF00<005YFFUH00UYF00@005YFFUH0
01Uoo`<000EJEP04001JEP00000_Ool002eoo`03FUH005YF009JEP80025oo`@0009JEP04001JEUYF
FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYF
FUH005YF001JEP8000IJEP05001JEUYFFUH00002FUH00`00Oomoo`0JOol20003FUH01@00FUIJEUYF
0000;Woo000]Ool01EYF001JEUYF00009goo0`001EYF00<005YF00000`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF00<0
05YF00007Woo0P0000=JEP00FUH00UYF00<007ooOol0;7oo000/Ool00`00FUH00002000[Ool20003
FUH01P00FUIJEUYF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20009Ool3000EOol20003FUH2000]Ool002aoo`04
001JEP00000^Ool01000FUIJEP000eYF00@005YFFUH0009JEQh000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008Ool5000FOol00`00FUIJEP02000]Ool002aoo`@001Qoo`<001Aoo`<000=JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH00UYF00<007oo
Ool01goo1@005goo1000;Goo000/Ool300000eYF001oo`0EOol5000EOol01@00FUIJEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800004FUH005YF0007FUH01000FUIJEP00
2Woo1@006Goo0P00;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0COol5000FOol01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000MJEP<000aoo`<001Uo
o`8002ioo`00;7oo0P000eYF0`004goo1@005goo00<005YF00000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YFFUIJEP0000=JEP<000EJEP8002Uoo`<002ioo`00;7oo0P000eYF00<005YFFUH0
0P004Woo0`006Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00800003FUH0000002Uoo`800003FUH0000002ioo`00;7oo0P000eYF00<005YFFUH00UYF
0`00:Goo0P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJ
EP02FUH3000VOol30003FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00005FUH01000FUH00000
9Woo00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00FUH0
0003000NOol400000eYF001JEP02FUH2000_Ool002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF
0`008Goo0P0015YF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP`000aJEPT000QJ
EP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH7000BOol5
0005FUH01@00FUIJEUYF0000<7oo000^Ool01000FUIJEP001EYF00<005YFFUH015YF10001Goo4@00
0goo100000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@002eYF00<005YF
FUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002mo
o`03001JEP0000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF
001JEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP050006FUH01000FUIJEUYF0P001EYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<7oo0P001EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01`000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00@005YFFUIJEP8000IJEP@000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<Goo00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF0000009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20006
FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000`00=Woo000aOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEUYF008000IJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000goo4P00?goo
000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEPH000=JEP03001JEUYF00=JEP06001JEUYF001JEP00E7oo000]
Ool00`00FUH00004FUH00`00FUIJEP02FUH60008FUH50004FUH20006FUH20005FUH500000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH70002FUH01P00FUIJEP00FUH005Aoo`00
;Goo00<005YF000015YF00<005YF000010000eYF00<005YFFUH01UYF1@0015YF0P001UYF00<005YF
FUH00eYF0`000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0`001eYF00<005YFFUH01000
00=JEP000000EGoo000]Ool00`00FUH00002FUH40005Ool200000eYF001JEP07FUH50004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000IJEP03001JEUYF00=JEP@005Eoo`00;Goo00<005YF00000P000UYF3`00
15YF10001EYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF009JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EGoo000]Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH00UYF1@00
0eYF00AooeYFFUH000=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=JEP03001JEUYF
00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH90004FUH00`00FUIJEP04FUH01000FUH000000Woo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF0P0015YF1P0015YF00@005YFFUH005Eoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP<0
0004FUH005YFFUH2001DOol0031oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPL000aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP020003FUH00`00Oomoo`1BOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPT0
01Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000MJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001oo`1C
Ool003]ooa80021oo`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPT000AJEP03001JEUYF00=JEP03001JEUYF00L005Aoo`00Kgoo0`00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF
100027oo3@000Woo0`0000=JEP000000Dgoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000DOol20002FUH01000FUIJEP00Dgoo001iOol;0006FUH0
0`00FUIJEP0:FUH00`00FUIJEP04FUH70004Ool5000BOol20005FUH00`00FUH0001COol008AooaX0
00]oo`D0011oo`800003FUH005YF00AJEP8005Aoo`00Sgoo0P006Goo0`003goo0P000eYF00<005YF
FUH00eYF00<007ooOol0Dgoo002?Ool3000WOol30006FUH00`00FUIJEP02001FOol008moo`03001J
EUYF00@001moo`@00003FUH005YF00IJEP<005Qoo`00Sgoo0P000UYF00<005YFFUH01`004Goo1`00
1EYF00<005YFFUH015YF0P00FWoo002@Ool01000FUIJEP001EYF00@005YFFUIJEQ4000AJEP03001J
EUYF00IJEP04001JEUYFFUH2001LOol0091oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002AOol30005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol009=oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@006=oo`00UGoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Igoo002HOolG001^Ool00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63086 .75143 m .61796 .69895 L .58691 .70655 L p .707 .577 .707 r
F P
0 g
s
.61796 .69895 m .63086 .75143 L .65959 .74084 L p .707 .577 .707 r
F P
0 g
s
.65959 .74084 m .64669 .68836 L .61796 .69895 L p .707 .577 .707 r
F P
0 g
s
.59981 .75903 m .58691 .70655 L .55658 .71042 L p .707 .577 .707 r
F P
0 g
s
.58691 .70655 m .59981 .75903 L .63086 .75143 L p .707 .577 .707 r
F P
0 g
s
.64669 .68836 m .65959 .74084 L .68318 .72828 L p .707 .577 .707 r
F P
0 g
s
.68318 .72828 m .67029 .6758 L .64669 .68836 L p .707 .577 .707 r
F P
0 g
s
.55996 .78187 m .58941 .79288 L p .5817 .77138 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .55658 .71042 L .56309 .75438 L .707 .577 .707 r
F
.56863 .75944 m .56851 .75894 L p .56798 .75885 L F P
0 g
s
.56851 .75894 m .55658 .71042 L p .56798 .75885 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .52994 .71016 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .56863 .75944 L p .59981 .75903 L .707 .577 .707 r
F P
0 g
s
.5817 .77138 m .57771 .76025 L .56863 .75944 L .707 .577 .707 r
F
.56798 .75885 m .55996 .78187 L p .5817 .77138 L F P
0 g
s
.58508 .76091 m .59981 .75903 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.58941 .79288 m .60198 .75682 L .57253 .74581 L p .707 .577 .707 r
F P
0 g
s
.56863 .75944 m .56948 .7629 L .58508 .76091 L p .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .56798 .75885 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.57771 .76025 m .57253 .74581 L .56863 .75944 L .707 .577 .707 r
F
.55996 .78187 m .56798 .75885 L p .55262 .75603 L F P
0 g
s
.53402 .77088 m .55996 .78187 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54001 .75371 m .53402 .77088 L p .54715 .76039 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54067 .75383 L .54715 .76039 L .707 .577 .707 r
F
.54067 .75383 m .54001 .75371 L .54715 .76039 L F
.52994 .71016 m .50959 .70582 L p .53334 .74641 L F P
0 g
s
.54015 .75331 m .52994 .71016 L .53334 .74641 L .707 .577 .707 r
F
.54067 .75383 m .54057 .75344 L p .54015 .75331 L F P
0 g
s
.54057 .75344 m .52994 .71016 L p .54015 .75331 L .707 .577 .707 r
F P
0 g
s
.53402 .77088 m .54015 .75331 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.52994 .71016 m .54067 .75383 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .54015 .75331 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54001 .75371 L p .54067 .75383 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54015 .75331 L .54067 .75383 L .707 .577 .707 r
F
.54283 .76264 m .54067 .75383 L p .53334 .74641 L F P
0 g
s
.51415 .76098 m .53402 .77088 L p .5335 .76757 L .707 .577 .707 r
F P
0 g
s
.5335 .76757 m .53075 .75029 L .52463 .75423 L .707 .577 .707 r
F
.5335 .76757 m .52463 .75423 L .51415 .76098 L F
.50959 .70582 m .49753 .69781 L p .51455 .73905 L F P
0 g
s
.5193 .7462 m .50959 .70582 L .51455 .73905 L .707 .577 .707 r
F
.51964 .74672 m .51955 .74637 L p .5193 .7462 L F P
0 g
s
.51955 .74637 m .50959 .70582 L p .5193 .7462 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .5193 .7462 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50959 .70582 m .51964 .74672 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.52672 .72493 m .5193 .7462 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.5193 .7462 m .51917 .74657 L p .51964 .74672 L .707 .577 .707 r
F P
0 g
s
.53075 .75029 m .5193 .7462 L .51964 .74672 L .707 .577 .707 r
F
.51917 .74657 m .51415 .76098 L p .53075 .75029 L F P
0 g
s
.52249 .7583 m .51964 .74672 L p .51455 .73905 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .51443 .74311 L .50961 .74709 L .707 .577 .707 r
F
.50227 .75316 m .51275 .76007 L p .50961 .74709 L F P
0 g
s
.51275 .76007 m .51415 .76098 L p .50961 .74709 L .707 .577 .707 r
F P
0 g
s
.51686 .74465 m .5121 .73312 L .5076 .73877 L .707 .577 .707 r
F
.49753 .69781 m .50751 .73842 L p .5121 .73312 L F P
0 g
s
.50751 .73842 m .5076 .73877 L p .5121 .73312 L .707 .577 .707 r
F P
0 g
s
.50734 .73861 m .50227 .75316 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.5076 .73877 m .51043 .75029 L p .51686 .74465 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .49753 .69781 L .50596 .73201 L .705 .576 .708 r
F
.5076 .73877 m .50751 .73842 L p .50747 .73824 L F P
0 g
s
.50751 .73842 m .49753 .69781 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.50734 .73861 m .50747 .73824 L p .50516 .74113 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .51484 .7171 L p .50705 .73644 L .707 .577 .707 r
F P
0 g
s
.50713 .73679 m .50747 .73824 L .50596 .73201 L .705 .576 .708 r
F
.51484 .7171 m .50747 .73824 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .50734 .73861 L p .5076 .73877 L .707 .577 .707 r
F P
0 g
s
.51443 .74311 m .50747 .73824 L .5076 .73877 L .707 .577 .707 r
F
.51484 .7171 m .51214 .71211 L p .50667 .73484 L F P
0 g
s
.50705 .73644 m .51484 .7171 L .50667 .73484 L .707 .577 .707 r
F
.50713 .73679 m .50596 .73201 L .50658 .73443 L .705 .576 .708 r
F
.49956 .74816 m .50227 .75316 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50207 .6742 L p .50664 .72587 L .707 .577 .707 r
F P
0 g
s
.51214 .71211 m .50582 .73021 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50582 .73021 L .50572 .73077 L .707 .577 .707 r
F
.52672 .72493 m .51484 .7171 L p .51443 .74311 L F P
0 g
s
.51214 .71211 m .51886 .71043 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50572 .73077 L p .50582 .73021 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50582 .73021 L .50695 .72931 L .707 .577 .707 r
F
.50572 .73077 m .49494 .68691 L p .50664 .72587 L F P
0 g
s
.50582 .73021 m .50568 .73061 L p .50572 .73077 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50192 .71532 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50596 .73201 m .50432 .72525 L .50784 .73939 L .705 .576 .708 r
F
.50192 .71532 m .50562 .73037 L p .50432 .72525 L F P
0 g
s
.50562 .73037 m .50784 .73939 L p .50432 .72525 L .705 .576 .708 r
F P
0 g
s
.50582 .73021 m .51214 .71211 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .50784 .73939 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.51886 .71043 m .51453 .72285 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .51419 .7235 L p .51453 .72285 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51886 .71043 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51517 .72267 m .51453 .72285 L .51522 .72153 L .707 .577 .707 r
F
.51497 .72668 m .51453 .72285 L .51517 .72267 L F
.51886 .71043 m .53435 .71224 L p .52914 .7186 L F P
0 g
s
.51419 .7235 m .51497 .72668 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .51043 .75029 L p .50713 .73679 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .5076 .73877 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .50747 .73824 L .50713 .73679 L .705 .576 .708 r
F
.51822 .66092 m .53112 .7134 L .51497 .72668 L p .707 .577 .707 r
F P
0 g
s
.50629 .74649 m .51453 .72285 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51435 .72337 L p .51419 .7235 L .707 .577 .707 r
F P
0 g
s
.51078 .72624 m .51453 .72285 L .51419 .7235 L .707 .577 .707 r
F
.50207 .6742 m .51822 .66092 L p .51522 .72153 L F P
0 g
s
.51419 .7235 m .50207 .6742 L p .51522 .72153 L .707 .577 .707 r
F P
0 g
s
.50207 .6742 m .51419 .7235 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50658 .73444 L .49956 .74816 L .707 .577 .707 r
F
.49753 .69781 m .49494 .68691 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50658 .73444 m .50568 .73061 L .49956 .74816 L .707 .577 .707 r
F
.50713 .73679 m .50658 .73443 L .50784 .73939 L .705 .576 .708 r
F
.50747 .73824 m .50705 .73644 L .50516 .74113 L .707 .577 .707 r
F
.50516 .74113 m .50705 .73644 L .50667 .73484 L F
.50227 .75316 m .50734 .73861 L p .50516 .74113 L F P
0 g
s
.50629 .74649 m .49956 .74816 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51435 .72337 m .50629 .74649 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50663 .73435 m .50582 .73021 L .51078 .72624 L .707 .577 .707 r
F
.49956 .74816 m .50568 .73061 L p .50663 .73435 L F P
0 g
s
.50568 .73061 m .50582 .73021 L p .50663 .73435 L .707 .577 .707 r
F P
0 g
s
.50695 .72931 m .50582 .73021 L .50664 .72587 L .707 .577 .707 r
F
.51043 .75029 m .52249 .7583 L p .51686 .74465 L F P
0 g
s
.5193 .7462 m .52672 .72493 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.52249 .7583 m .54283 .76264 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.51964 .74672 m .52249 .7583 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .52672 .72493 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54659 .73482 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54283 .76264 m .56948 .7629 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54067 .75383 m .54283 .76264 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .54659 .73482 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.56948 .7629 m .56863 .75944 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .57253 .74581 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.60198 .75682 m .58941 .79288 L .6195 .80283 L p .707 .577 .707 r
F P
0 g
s
.6195 .80283 m .63207 .76678 L .60198 .75682 L p .707 .577 .707 r
F P
0 g
s
.63207 .76678 m .6195 .80283 L .64728 .81075 L p .707 .577 .707 r
F P
0 g
s
.64728 .81075 m .65985 .7747 L .63207 .76678 L p .707 .577 .707 r
F P
0 g
s
.67029 .6758 m .68318 .72828 L .69934 .715 L p .707 .577 .707 r
F P
0 g
s
.69934 .715 m .68644 .66252 L .67029 .6758 L p .707 .577 .707 r
F P
0 g
s
.65985 .7747 m .64728 .81075 L .67003 .81587 L p .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .6826 .77982 L .65985 .7747 L p .707 .577 .707 r
F P
0 g
s
.60058 .85912 m .59735 .84127 L .56666 .84374 L p .707 .577 .707 r
F P
0 g
s
.59735 .84127 m .60058 .85912 L .63198 .85316 L p .707 .577 .707 r
F P
0 g
s
.63198 .85316 m .62875 .83531 L .59735 .84127 L p .707 .577 .707 r
F P
0 g
s
.62875 .83531 m .63198 .85316 L .66102 .84432 L p .707 .577 .707 r
F P
0 g
s
.66102 .84432 m .65779 .82646 L .62875 .83531 L p .707 .577 .707 r
F P
0 g
s
.56666 .84374 m .5699 .86159 L .60058 .85912 L p .707 .577 .707 r
F P
0 g
s
.5699 .86159 m .56666 .84374 L .5397 .8425 L p .707 .577 .707 r
F P
0 g
s
.68644 .66252 m .69934 .715 L .70647 .70229 L p .707 .577 .707 r
F P
0 g
s
.70647 .70229 m .69357 .64981 L .68644 .66252 L p .707 .577 .707 r
F P
0 g
s
.65779 .82646 m .66102 .84432 L .68486 .83344 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .68163 .81559 L .65876 .82602 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .70117 .82161 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68163 .81559 m .68175 .81626 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68175 .81626 m .68486 .83344 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .69793 .80376 L .68238 .81504 L p .707 .577 .707 r
F P
0 g
s
.68238 .81504 m .68163 .81559 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .68238 .81504 L .68203 .81572 L .707 .577 .707 r
F
.69225 .81601 m .70482 .77995 L .69999 .78116 L p F P
0 g
s
.69999 .78116 m .6981 .78163 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69225 .81601 m .69999 .78116 L .6973 .78633 L .707 .577 .707 r
F
.68553 .81768 m .69225 .81601 L p .6973 .78633 L F P
0 g
s
.6981 .78163 m .69474 .79125 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69474 .79125 m .68553 .81768 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .68553 .81768 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.6826 .77982 m .67666 .79686 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.67666 .79686 m .67003 .81587 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.65876 .82602 m .65779 .82646 L p .65839 .82662 L .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .65876 .82602 L .65839 .82662 L .707 .577 .707 r
F
.5397 .8425 m .54293 .86035 L .5699 .86159 L p F P
0 g
s
.68553 .81768 m .6981 .78163 L .6826 .77982 L p .707 .577 .707 r
F P
0 g
s
.54293 .86035 m .5397 .8425 L .51909 .83767 L p .707 .577 .707 r
F P
0 g
s
.51909 .83767 m .52233 .85552 L .54293 .86035 L p .707 .577 .707 r
F P
0 g
s
.69357 .64981 m .70647 .70229 L .70388 .6914 L p .705 .576 .708 r
F P
0 g
s
.70388 .6914 m .69098 .63892 L .69357 .64981 L p .705 .576 .708 r
F P
0 g
s
.52233 .85552 m .51909 .83767 L .50686 .82971 L p .707 .577 .707 r
F P
0 g
s
.69793 .80376 m .70117 .82161 L .70834 .80997 L p .707 .577 .707 r
F P
0 g
s
.70834 .80997 m .70511 .79212 L .69793 .80376 L p .707 .577 .707 r
F P
0 g
s
.50686 .82971 m .5101 .84756 L .52233 .85552 L p .707 .577 .707 r
F P
0 g
s
.48764 .82178 m .48764 .31989 L .44383 .31698 L p .707 .577 .707 r
F P
0 g
s
.5101 .84756 m .50686 .82971 L .5042 .8194 L p .707 .578 .707 r
F P
0 g
s
.5042 .8194 m .50744 .83725 L .5101 .84756 L p .707 .578 .707 r
F P
0 g
s
.50744 .83725 m .5042 .8194 L .51138 .80776 L p .707 .577 .707 r
F P
0 g
s
.51138 .80776 m .51461 .82562 L .50744 .83725 L p .707 .577 .707 r
F P
0 g
s
.53435 .71224 m .52178 .7483 L .50629 .74649 L p .707 .577 .707 r
F P
0 g
s
.53112 .7134 m .51822 .66092 L .54182 .64837 L p .707 .577 .707 r
F P
0 g
s
.51461 .82562 m .51138 .80776 L .52768 .79593 L p .707 .577 .707 r
F P
0 g
s
.52178 .7483 m .53435 .71224 L .55711 .71736 L p .707 .577 .707 r
F P
0 g
s
.52768 .79593 m .53092 .81378 L .51461 .82562 L p .707 .577 .707 r
F P
0 g
s
.55711 .71736 m .54453 .75341 L .52178 .7483 L p .707 .577 .707 r
F P
0 g
s
.53092 .81378 m .52768 .79593 L .55152 .78506 L p .707 .577 .707 r
F P
0 g
s
.55152 .78506 m .55476 .80291 L .53092 .81378 L p .707 .577 .707 r
F P
0 g
s
.48764 .31989 m .48764 .82178 L .53266 .82092 L p .707 .577 .707 r
F P
0 g
s
.54182 .64837 m .55472 .70085 L .53112 .7134 L p .707 .577 .707 r
F P
0 g
s
.53266 .82092 m .53266 .31903 L .48764 .31989 L p .707 .577 .707 r
F P
0 g
s
.55472 .70085 m .54182 .64837 L .57055 .63777 L p .707 .577 .707 r
F P
0 g
s
.57055 .63777 m .58345 .69025 L .55472 .70085 L p .707 .577 .707 r
F P
0 g
s
.54453 .75341 m .55711 .71736 L .58489 .72528 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .57231 .76134 L .54453 .75341 L p .707 .577 .707 r
F P
0 g
s
.55476 .80291 m .55152 .78506 L .58056 .77621 L p .707 .577 .707 r
F P
0 g
s
.58056 .77621 m .5838 .79406 L .55476 .80291 L p .707 .577 .707 r
F P
0 g
s
.53266 .31903 m .53266 .82092 L .57447 .81636 L p .707 .577 .707 r
F P
0 g
s
.58345 .69025 m .57055 .63777 L .6016 .63017 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .61498 .73524 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.57231 .76134 m .58036 .73825 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.58036 .73825 m .58489 .72528 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.63193 .62631 m .64483 .67879 L .6145 .68265 L p .707 .577 .707 r
F P
0 g
s
.6145 .68265 m .6016 .63017 L .63193 .62631 L p .707 .577 .707 r
F P
0 g
s
.6016 .63017 m .6145 .68265 L .58345 .69025 L p .707 .577 .707 r
F P
0 g
s
.67036 .75724 m .65779 .79329 L .63186 .7823 L p .707 .577 .707 r
F P
0 g
s
.63186 .7823 m .64443 .74625 L .67036 .75724 L p .707 .577 .707 r
F P
0 g
s
.64443 .74625 m .63186 .7823 L .61088 .77446 L p .707 .577 .707 r
F P
0 g
s
.61088 .77446 m .6024 .77129 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61131 .76598 m .64443 .74625 L .61088 .77446 L .707 .577 .707 r
F
.64483 .67879 m .63193 .62631 L .65857 .62656 L p F P
0 g
s
.65779 .79329 m .66927 .76036 L p .69024 .76713 L .707 .577 .707 r
F P
0 g
s
.64588 .78563 m .64379 .77411 L p .66961 .76902 L .707 .577 .707 r
F P
0 g
s
.64379 .77411 m .64265 .76778 L .65452 .76832 L p .707 .577 .707 r
F P
0 g
s
.65452 .76832 m .66961 .76902 L p .64379 .77411 L .707 .577 .707 r
F P
0 g
s
.66927 .76036 m .67036 .75724 L .67281 .75846 L p .707 .577 .707 r
F P
0 g
s
.67281 .75846 m .69024 .76713 L p .66927 .76036 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .64443 .74625 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.6024 .77129 m .61252 .74227 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61252 .74227 m .61498 .73524 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.64265 .76778 m .64588 .78563 L .6152 .78811 L p .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .64371 .28465 L .63542 .29362 L p .707 .577 .707 r
F P
0 g
s
.63542 .29362 m .63286 .2964 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .63542 .29362 L .63359 .3295 L .707 .577 .707 r
F
.6152 .78811 m .61196 .77026 L .64265 .76778 L p F P
0 g
s
.63286 .79829 m .64371 .78653 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .2964 m .63286 .34386 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .34386 m .63286 .79829 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .6024 .77129 L .57231 .76134 L p .707 .577 .707 r
F P
0 g
s
.5838 .79406 m .58056 .77621 L .61196 .77026 L p .707 .577 .707 r
F P
0 g
s
.61196 .77026 m .6152 .78811 L .5838 .79406 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .63286 .79829 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .30668 m .609 .36022 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .36022 m .609 .80857 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.57447 .81636 m .57447 .31448 L .53266 .31903 L p .707 .577 .707 r
F P
0 g
s
.69098 .63892 m .70388 .6914 L .69182 .68339 L p .707 .577 .707 r
F P
0 g
s
.69182 .68339 m .67892 .63091 L .69098 .63892 L p .707 .577 .707 r
F P
0 g
s
.44383 .81887 m .44383 .31698 L .40553 .31058 L p .707 .577 .707 r
F P
0 g
s
.44383 .31698 m .44383 .81887 L .48764 .82178 L p .707 .577 .707 r
F P
0 g
s
.70482 .77995 m .69225 .81601 L .68954 .81101 L p .707 .577 .707 r
F P
0 g
s
.68954 .81101 m .70181 .77583 L p .70482 .77995 L .707 .577 .707 r
F P
0 g
s
.70211 .77496 m .68954 .81101 L .67767 .80318 L p .707 .577 .707 r
F P
0 g
s
.69345 .7917 m .69274 .78779 L p .70245 .78181 L .707 .577 .707 r
F P
0 g
s
.67767 .80318 m .68999 .76786 L p .70211 .77496 L .707 .577 .707 r
F P
0 g
s
.68999 .76786 m .69024 .76713 L .69069 .76742 L p .707 .577 .707 r
F P
0 g
s
.69069 .76742 m .70211 .77496 L p .68999 .76786 L .707 .577 .707 r
F P
0 g
s
.69024 .76713 m .67767 .80318 L .65779 .79329 L p .707 .577 .707 r
F P
0 g
s
.67285 .78687 m .67148 .77934 L p .69022 .77385 L .707 .577 .707 r
F P
0 g
s
.67148 .77934 m .66961 .76902 L .68304 .77217 L p .707 .577 .707 r
F P
0 g
s
.68304 .77217 m .69022 .77385 L p .67148 .77934 L .707 .577 .707 r
F P
0 g
s
.69274 .78779 m .69022 .77385 L .69899 .77956 L p .707 .577 .707 r
F P
0 g
s
.69899 .77956 m .70245 .78181 L p .69274 .78779 L .707 .577 .707 r
F P
0 g
s
.70181 .77583 m .70211 .77496 L .70226 .77523 L p .707 .577 .707 r
F P
0 g
s
.70226 .77523 m .70482 .77995 L p .70181 .77583 L .707 .577 .707 r
F P
0 g
s
.57447 .31448 m .57447 .81636 L .609 .80857 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .609 .30668 L .57447 .31448 L p .707 .577 .707 r
F P
0 g
s
.70511 .79212 m .70834 .80997 L .70568 .79966 L p .707 .578 .707 r
F P
0 g
s
.70568 .79966 m .70245 .78181 L .70511 .79212 L p .707 .578 .707 r
F P
0 g
s
.40553 .81247 m .40553 .31058 L .37647 .30131 L p .707 .577 .707 r
F P
0 g
s
.40553 .31058 m .40553 .81247 L .44383 .81887 L p .707 .577 .707 r
F P
0 g
s
.25511 .69095 m .24951 .63358 L .21847 .63628 L p .707 .577 .707 r
F P
0 g
s
.24951 .63358 m .25511 .69095 L .28679 .68773 L p .707 .577 .707 r
F P
0 g
s
.28679 .68773 m .28119 .63036 L .24951 .63358 L p .707 .577 .707 r
F P
0 g
s
.67892 .63091 m .69182 .68339 L .67147 .67904 L p .707 .577 .707 r
F P
0 g
s
.67147 .67904 m .65857 .62656 L .67892 .63091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21847 .63628 m .22408 .69365 L .25511 .69095 L p .707 .577 .707 r
F P
0 g
s
.28119 .63036 m .28679 .68773 L .31602 .6843 L p .707 .577 .707 r
F P
0 g
s
.31602 .6843 m .31042 .62694 L .28119 .63036 L p .707 .577 .707 r
F P
0 g
s
.22408 .69365 m .21847 .63628 L .19113 .6382 L p .707 .577 .707 r
F P
0 g
s
.19113 .6382 m .19673 .69556 L .22408 .69365 L p .707 .577 .707 r
F P
0 g
s
.63286 .79829 m .63286 .2964 L .609 .30668 L p .707 .577 .707 r
F P
0 g
s
.31042 .62694 m .31602 .6843 L .33994 .681 L p .707 .577 .707 r
F P
0 g
s
.33994 .681 m .33434 .62364 L .31042 .62694 L p .707 .577 .707 r
F P
0 g
s
.70245 .78181 m .70568 .79966 L .69345 .7917 L p .707 .577 .707 r
F P
0 g
s
.19673 .69556 m .19113 .6382 L .17015 .63914 L p .707 .577 .707 r
F P
0 g
s
.65857 .62656 m .67147 .67904 L .64483 .67879 L p .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .25373 .78052 L .23921 .78123 L p .707 .577 .707 r
F P
0 g
s
.23074 .78642 m .23829 .78179 L .22265 .78204 L .707 .577 .707 r
F
.23776 .7813 m .22265 .78204 L p .23829 .78179 L F P
0 g
s
.22265 .78204 m .22404 .80112 L .25512 .7996 L p .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .22265 .78204 L .20359 .78225 L p .707 .577 .707 r
F P
0 g
s
.20359 .78225 m .19529 .78235 L p .19958 .78515 L .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .20359 .78225 L .19958 .78515 L .707 .577 .707 r
F
.23921 .78123 m .23776 .7813 L p .23829 .78179 L F P
0 g
s
.25512 .7996 m .23921 .78123 L .23074 .78642 L .707 .577 .707 r
F
.22085 .7923 m .25181 .79974 L p .22861 .76424 L F P
0 g
s
.22642 .7609 m .22543 .76653 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22543 .76653 m .22085 .7923 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22085 .7923 m .22493 .76931 L p .19899 .7486 L .707 .577 .707 r
F P
0 g
s
.22493 .76931 m .22642 .7609 L .20627 .75187 L p .707 .577 .707 r
F P
0 g
s
.20627 .75187 m .19899 .7486 L p .22493 .76931 L .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .28688 .79701 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25373 .78052 m .25469 .79373 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25469 .79373 m .25512 .7996 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .28642 .79077 L p .25373 .78052 L .707 .577 .707 r
F P
0 g
s
.28642 .79077 m .28548 .77793 L .26788 .77936 L p .707 .577 .707 r
F P
0 g
s
.26788 .77936 m .25373 .78052 L p .28642 .79077 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .25665 .77245 L p .22642 .7609 L .707 .577 .707 r
F P
0 g
s
.25665 .77245 m .25738 .76834 L .24524 .76542 L p .707 .577 .707 r
F P
0 g
s
.24524 .76542 m .22642 .7609 L p .25665 .77245 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .3162 .79361 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28548 .77793 m .28675 .79528 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28675 .79528 m .28688 .79701 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.3162 .79361 m .31555 .78473 L p .28548 .77793 L .707 .577 .707 r
F P
0 g
s
.31555 .78473 m .31481 .77453 L .2978 .7765 L p .707 .577 .707 r
F P
0 g
s
.2978 .7765 m .28548 .77793 L p .31555 .78473 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .28848 .77218 L p .25738 .76834 L .707 .577 .707 r
F P
0 g
s
.28848 .77218 m .28883 .7702 L .28355 .76989 L p .707 .577 .707 r
F P
0 g
s
.28355 .76989 m .25738 .76834 L p .28848 .77218 L .707 .577 .707 r
F P
0 g
s
.31481 .77453 m .3162 .79361 L .3185 .79324 L p .707 .577 .707 r
F P
0 g
s
.3185 .79324 m .34022 .78973 L p .3263 .7814 L .707 .577 .707 r
F P
0 g
s
.3263 .7814 m .31481 .77453 L .3185 .79324 L .707 .577 .707 r
F
.34022 .78973 m .33933 .7775 L p .31481 .77453 L F P
0 g
s
.33933 .7775 m .33883 .77064 L .32719 .77252 L p .707 .577 .707 r
F P
0 g
s
.32719 .77252 m .31481 .77453 L p .33933 .7775 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .3173 .76847 L p .28883 .7702 L .707 .577 .707 r
F P
0 g
s
.3173 .76847 m .31769 .76629 L .3134 .76687 L p .707 .577 .707 r
F P
0 g
s
.3134 .76687 m .28883 .7702 L p .3173 .76847 L .707 .577 .707 r
F P
0 g
s
.33883 .77064 m .34022 .78973 L .35659 .78574 L p .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .3552 .76666 L .35059 .76778 L p .707 .577 .707 r
F P
0 g
s
.35059 .76778 m .33883 .77064 L p .34763 .77813 L .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .35059 .76778 L .34763 .77813 L .707 .577 .707 r
F
.35129 .77462 m .35778 .75772 L p .357 .74534 L F P
0 g
s
.35686 .74322 m .35565 .75007 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.35565 .75007 m .35129 .77462 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .35129 .77462 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34113 .75699 m .34066 .75964 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34066 .75964 m .33556 .78839 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .33556 .78839 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31769 .76629 m .31763 .76659 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31763 .76659 m .31211 .79769 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .31211 .79769 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28883 .7702 m .28882 .77027 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28882 .77027 m .28326 .8016 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .28326 .8016 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25738 .76834 m .25703 .77031 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25703 .77031 m .25181 .79974 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.17015 .63914 m .17575 .69651 L .19673 .69556 L p .707 .577 .707 r
F P
0 g
s
.37647 .8032 m .37647 .30131 L .3595 .29009 L p .707 .577 .707 r
F P
0 g
s
.37647 .30131 m .37647 .8032 L .40553 .81247 L p .707 .577 .707 r
F P
0 g
s
.33434 .62364 m .33994 .681 L .35621 .67816 L p .707 .577 .707 r
F P
0 g
s
.35621 .67816 m .3506 .62079 L .33434 .62364 L p .707 .577 .707 r
F P
0 g
s
.19529 .78235 m .19668 .80143 L .22404 .80112 L p .707 .577 .707 r
F P
0 g
s
.19341 .78 m .19899 .7486 L .17775 .73264 L p .707 .577 .707 r
F P
0 g
s
.19899 .7486 m .19341 .78 L .22085 .7923 L p .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .34113 .75699 L .31769 .76629 L p .707 .577 .707 r
F P
0 g
s
.69022 .77385 m .69345 .7917 L .67285 .78687 L p .707 .577 .707 r
F P
0 g
s
.17575 .69651 m .17015 .63914 L .15759 .63902 L p .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .16319 .69638 L .17575 .69651 L p .707 .577 .707 r
F P
0 g
s
.19668 .80143 m .19529 .78235 L .17432 .78141 L p .707 .577 .707 r
F P
0 g
s
.17432 .78141 m .17572 .80049 L .19668 .80143 L p .707 .577 .707 r
F P
0 g
s
.17218 .76404 m .17775 .73264 L .1648 .7146 L p .707 .577 .707 r
F P
0 g
s
.17775 .73264 m .17218 .76404 L .19341 .78 L p .707 .577 .707 r
F P
0 g
s
.3506 .62079 m .35621 .67816 L .36323 .67605 L p .707 .577 .707 r
F P
0 g
s
.36323 .67605 m .35762 .61868 L .3506 .62079 L p .707 .577 .707 r
F P
0 g
s
.35129 .77462 m .35686 .74322 L .34113 .75699 L p .707 .577 .707 r
F P
0 g
s
.66961 .76902 m .67285 .78687 L .64588 .78563 L p .707 .577 .707 r
F P
0 g
s
.35778 .75772 m .36335 .72632 L .35686 .74322 L p .707 .577 .707 r
F P
0 g
s
.3552 .76666 m .35659 .78574 L .3637 .78205 L p .707 .577 .707 r
F P
0 g
s
.3637 .78205 m .36231 .76297 L .3552 .76666 L p .707 .577 .707 r
F P
0 g
s
.35762 .61868 m .36323 .67605 L .36031 .67487 L p .707 .577 .707 r
F P
0 g
s
.36031 .67487 m .35471 .6175 L .35762 .61868 L p .707 .577 .707 r
F P
0 g
s
.36335 .72632 m .35778 .75772 L .35438 .73934 L p .707 .577 .707 r
F P
0 g
s
.35438 .73934 m .35995 .70794 L .36335 .72632 L p .707 .577 .707 r
F P
0 g
s
.36086 .77901 m .35947 .75993 L .36231 .76297 L p .707 .577 .707 r
F P
0 g
s
.35471 .6175 m .36031 .67487 L .34775 .67475 L p .707 .577 .707 r
F P
0 g
s
.35995 .70794 m .35438 .73934 L .34143 .72129 L p .707 .577 .707 r
F P
0 g
s
.34143 .72129 m .347 .6899 L .35995 .70794 L p .707 .577 .707 r
F P
0 g
s
.35947 .75993 m .36086 .77901 L .34835 .77692 L p .707 .577 .707 r
F P
0 g
s
.34835 .77692 m .34695 .75784 L .35947 .75993 L p .707 .577 .707 r
F P
0 g
s
.3595 .79198 m .3595 .29009 L .35628 .27801 L p .707 .577 .707 r
F P
0 g
s
.36231 .76297 m .3637 .78205 L .36086 .77901 L p .707 .577 .707 r
F P
0 g
s
.3595 .29009 m .3595 .79198 L .37647 .8032 L p .707 .577 .707 r
F P
0 g
s
.17572 .80049 m .17432 .78141 L .16181 .77932 L p .707 .577 .707 r
F P
0 g
s
.16319 .69638 m .16195 .68365 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.15468 .63784 m .16028 .69521 L .16319 .69638 L p .707 .577 .707 r
F P
0 g
s
.15923 .74599 m .1648 .7146 L .1614 .69622 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .15583 .72762 L .15923 .74599 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .16789 .67932 L p .16458 .69256 L .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .15468 .63784 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.16195 .68365 m .15759 .63902 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16387 .69413 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16789 .67932 L p .16935 .68853 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16701 .69015 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16935 .68853 L .16701 .69015 L .707 .577 .707 r
F
.18356 .69025 m .1673 .69309 L p .16793 .68951 L F P
0 g
s
.16789 .67932 m .18362 .66555 L p .17445 .68499 L .707 .577 .707 r
F P
0 g
s
.16935 .68853 m .16789 .67932 L .17445 .68499 L .707 .577 .707 r
F
.16793 .68951 m .18097 .68047 L .18356 .69025 L F
.18097 .68047 m .18362 .66555 L p .18679 .67984 L F P
0 g
s
.18356 .69025 m .18268 .68126 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.18097 .68047 m .18679 .67984 L .18268 .68126 L .707 .577 .707 r
F
.20748 .68695 m .18356 .69025 L p .18669 .67988 L F P
0 g
s
.18362 .66555 m .20706 .65625 L p .19137 .67826 L .707 .577 .707 r
F P
0 g
s
.18679 .67984 m .18362 .66555 L .19137 .67826 L .707 .577 .707 r
F
.20706 .65625 m .23592 .65234 L p .21559 .67319 L F P
0 g
s
.21125 .67395 m .20706 .65625 L .21559 .67319 L .707 .577 .707 r
F
.20188 .62959 m .23111 .62616 L p .21263 .67371 L F P
0 g
s
.20748 .68695 m .2063 .67481 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20393 .67393 m .20706 .65625 L p .21125 .67395 L .707 .577 .707 r
F P
0 g
s
.23671 .68353 m .20748 .68695 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .21125 .67395 L .21196 .67692 L .707 .577 .707 r
F
.20393 .67393 m .21125 .67395 L .2063 .67481 L F
.23592 .65234 m .26737 .6542 L p .24667 .67071 L F P
0 g
s
.24136 .67103 m .23592 .65234 L .24667 .67071 L .707 .577 .707 r
F
.23111 .62616 m .26279 .62294 L p .24211 .67098 L F P
0 g
s
.23671 .68353 m .23553 .67137 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23275 .6702 m .23592 .65234 L p .24136 .67103 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .23671 .68353 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .24136 .67103 L .24229 .67421 L .707 .577 .707 r
F
.23275 .6702 m .24136 .67103 L .23553 .67137 L F
.29943 .6776 m .2684 .6803 L p .27215 .67144 L F P
0 g
s
.26737 .6542 m .29832 .66164 L p .2828 .67182 L .707 .577 .707 r
F P
0 g
s
.27436 .67152 m .26737 .6542 L .2828 .67182 L .707 .577 .707 r
F
.27215 .67144 m .29643 .67231 L .29943 .6776 L F
.29643 .67231 m .29832 .66164 L p .30537 .67535 L F P
0 g
s
.31496 .67652 m .29943 .6776 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29643 .67231 m .30537 .67535 L .29913 .6746 L .707 .577 .707 r
F
.29832 .66164 m .32576 .67394 L p .32021 .67715 L F P
0 g
s
.30537 .67535 m .29832 .66164 L .32021 .67715 L .707 .577 .707 r
F
.29383 .62024 m .32117 .61832 L p .30047 .67476 L F P
0 g
s
.29943 .6776 m .29913 .6746 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29832 .66164 m .29609 .67423 L p .26179 .6856 L .707 .577 .707 r
F P
0 g
s
.29609 .67423 m .29275 .69304 L .27401 .68853 L p .707 .577 .707 r
F P
0 g
s
.27401 .68853 m .26179 .6856 L p .29609 .67423 L .707 .577 .707 r
F P
0 g
s
.29913 .6746 m .29892 .6724 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .29383 .62024 L p .30009 .67164 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .30009 .67164 L .30047 .67476 L .707 .577 .707 r
F
.30948 .68336 m .30537 .67535 L .32021 .67715 L F
.29913 .6746 m .30537 .67535 L .30948 .68336 L F
.32576 .67394 m .347 .6899 L p .33636 .69603 L F P
0 g
s
.32019 .70534 m .32509 .67774 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32509 .67774 m .32576 .67394 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32576 .67394 m .32019 .70534 L .29275 .69304 L p .707 .577 .707 r
F P
0 g
s
.32117 .61832 m .32677 .67569 L .32394 .67589 L p .707 .577 .707 r
F P
0 g
s
.32394 .67589 m .31496 .67652 L p .31635 .66356 L .707 .577 .707 r
F P
0 g
s
.31635 .66356 m .32117 .61832 L .32394 .67589 L .707 .577 .707 r
F
.30047 .67476 m .32117 .61832 L .31496 .67652 L F
.29892 .6724 m .29913 .6746 L p .29643 .67231 L F P
0 g
s
.29913 .6746 m .29943 .6776 L p .29643 .67231 L .707 .577 .707 r
F P
0 g
s
.29275 .69304 m .29643 .67231 L p .30948 .68336 L .707 .577 .707 r
F P
0 g
s
.26462 .66966 m .26737 .6542 L p .27436 .67152 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .26751 .67127 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .27436 .67152 L .27622 .67614 L .707 .577 .707 r
F
.26462 .66966 m .27436 .67152 L .26751 .67127 L F
.26279 .62294 m .29383 .62024 L p .27215 .67144 L F P
0 g
s
.26734 .6695 m .2684 .6803 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .23275 .6702 L .23671 .68353 L .707 .577 .707 r
F
.23537 .66975 m .23553 .67137 L p .23275 .6702 L F P
0 g
s
.23553 .67137 m .23671 .68353 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.26737 .6542 m .26436 .67116 L p .24875 .67693 L .707 .577 .707 r
F P
0 g
s
.23035 .68374 m .24229 .67421 L .24875 .67693 L .707 .577 .707 r
F
.24229 .67421 m .26737 .6542 L .24875 .67693 L F
.26436 .67116 m .26179 .6856 L .24067 .68435 L p F P
0 g
s
.24067 .68435 m .23035 .68374 L p .26436 .67116 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .26734 .6695 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .26279 .62294 L p .27134 .66727 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .27134 .66727 L .27215 .67144 L .707 .577 .707 r
F
.29383 .62024 m .29892 .6724 L p .27215 .67144 L F P
0 g
s
.27622 .67614 m .27436 .67152 L .2828 .67182 L .707 .577 .707 r
F
.26179 .6856 m .26462 .66966 L p .27622 .67614 L F P
0 g
s
.26279 .62294 m .26734 .6695 L p .26462 .66966 L .707 .577 .707 r
F P
0 g
s
.24211 .67098 m .24694 .65978 L .26462 .66966 L .707 .577 .707 r
F
.24694 .65978 m .26279 .62294 L .26462 .66966 L F
.18669 .67988 m .20393 .67393 L .20748 .68695 L F
.20614 .67316 m .2063 .67481 L p .20393 .67393 L F P
0 g
s
.2063 .67481 m .20748 .68695 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.23592 .65234 m .23251 .67155 L p .2179 .67913 L .707 .577 .707 r
F P
0 g
s
.20149 .68765 m .21196 .67692 L .2179 .67913 L .707 .577 .707 r
F
.21196 .67692 m .23592 .65234 L .2179 .67913 L F
.23251 .67155 m .23035 .68374 L .20848 .6867 L p F P
0 g
s
.20848 .6867 m .20149 .68765 L p .23251 .67155 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .23537 .66975 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .23111 .62616 L p .24095 .66623 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .24095 .66623 L .24211 .67098 L .707 .577 .707 r
F
.24229 .67421 m .24136 .67103 L .24667 .67071 L F
.23035 .68374 m .23275 .6702 L p .24229 .67421 L F P
0 g
s
.23111 .62616 m .23537 .66975 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .21663 .66342 L .23275 .6702 L .707 .577 .707 r
F
.21663 .66342 m .23111 .62616 L .23275 .6702 L F
.18268 .68126 m .18356 .69025 L p .18097 .68047 L F P
0 g
s
.20706 .65625 m .20369 .67526 L p .17805 .69695 L .707 .577 .707 r
F P
0 g
s
.20369 .67526 m .20149 .68765 L .17875 .69667 L p .707 .577 .707 r
F P
0 g
s
.17875 .69667 m .17805 .69695 L p .20369 .67526 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .20614 .67316 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .20188 .62959 L p .2114 .66865 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .2114 .66865 L .21263 .67371 L .707 .577 .707 r
F
.21196 .67692 m .21125 .67395 L .21559 .67319 L F
.20149 .68765 m .20393 .67393 L p .21196 .67692 L F P
0 g
s
.20188 .62959 m .20614 .67316 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.18669 .67988 m .19005 .66876 L .20393 .67393 L .707 .577 .707 r
F
.19005 .66876 m .20188 .62959 L .20393 .67393 L F
.18761 .68354 m .18679 .67984 L .19137 .67826 L F
.18268 .68126 m .18679 .67984 L .18761 .68354 L F
.17796 .63288 m .20188 .62959 L p .18669 .67988 L F P
0 g
s
.17805 .69695 m .16231 .71072 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18362 .66555 m .18071 .68194 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18071 .68194 m .17805 .69695 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18268 .68126 m .1825 .67941 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .17796 .63288 L p .18575 .67481 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .18575 .67481 L .18669 .67988 L .707 .577 .707 r
F
.1825 .67941 m .18268 .68126 L p .18097 .68047 L F P
0 g
s
.17805 .69695 m .18097 .68047 L p .18761 .68354 L .707 .577 .707 r
F P
0 g
s
.17796 .63288 m .1825 .67941 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.17022 .69396 m .16935 .68853 L .17445 .68499 L .707 .577 .707 r
F
.16701 .69015 m .16935 .68853 L .17022 .69396 L F
.16231 .71072 m .15583 .72762 L p .16049 .70895 L F P
0 g
s
.16789 .67932 m .16582 .69098 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.16582 .69098 m .16231 .71072 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .17796 .63288 L p .17042 .67544 L .707 .577 .707 r
F P
0 g
s
.16793 .68951 m .16746 .68544 L .17042 .67544 L .707 .577 .707 r
F
.16746 .68544 m .1617 .63573 L .17042 .67544 L F
.16701 .69015 m .1617 .63573 L p .16793 .68951 L F P
0 g
s
.16678 .68775 m .16701 .69015 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16701 .69015 m .1673 .69309 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16231 .71072 m .16615 .68913 L p .17022 .69396 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .16678 .68775 L p .16028 .69521 L .707 .577 .707 r
F P
0 g
s
.16105 .7003 m .1614 .69622 L .16458 .69256 L .707 .577 .707 r
F
.16387 .69413 m .16028 .69521 L p .16678 .68775 L F P
0 g
s
.16022 .71004 m .16105 .7003 L .16458 .69256 L .707 .577 .707 r
F
.15583 .72762 m .16096 .69871 L p .16022 .71004 L F P
0 g
s
.16096 .69871 m .1614 .69622 L p .16022 .71004 L .707 .577 .707 r
F P
0 g
s
.1648 .7146 m .15923 .74599 L .17218 .76404 L p .707 .577 .707 r
F P
0 g
s
.16181 .77932 m .16321 .7984 L .17572 .80049 L p .707 .577 .707 r
F P
0 g
s
.64371 .28465 m .64371 .78653 L .6405 .77446 L p .707 .577 .707 r
F P
0 g
s
.6405 .77446 m .6405 .27257 L .64371 .28465 L p .707 .577 .707 r
F P
0 g
s
.16321 .7984 m .16181 .77932 L .15897 .77627 L p .707 .577 .707 r
F P
0 g
s
.15897 .77627 m .16037 .79536 L .16321 .7984 L p .707 .577 .707 r
F P
0 g
s
.16028 .69521 m .15468 .63784 L .1617 .63573 L p .707 .577 .707 r
F P
0 g
s
.35628 .27801 m .35628 .7799 L .3595 .79198 L p .707 .577 .707 r
F P
0 g
s
.35628 .7799 m .35628 .27801 L .36714 .26626 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34775 .67475 m .34215 .61738 L .35471 .6175 L p .707 .577 .707 r
F P
0 g
s
.6405 .27257 m .6405 .77446 L .62353 .76323 L p .707 .577 .707 r
F P
0 g
s
.62353 .76323 m .62353 .26135 L .6405 .27257 L p .707 .577 .707 r
F P
0 g
s
.16037 .79536 m .15897 .77627 L .16608 .77258 L p .707 .577 .707 r
F P
0 g
s
.16608 .77258 m .16748 .79166 L .16037 .79536 L p .707 .577 .707 r
F P
0 g
s
.34215 .61738 m .34775 .67475 L .32677 .67569 L p .707 .577 .707 r
F P
0 g
s
.32677 .67569 m .32117 .61832 L .34215 .61738 L p .707 .577 .707 r
F P
0 g
s
.36714 .76815 m .36714 .26626 L .391 .25598 L p .707 .577 .707 r
F P
0 g
s
.36714 .26626 m .36714 .76815 L .35628 .7799 L p .707 .577 .707 r
F P
0 g
s
.347 .6899 m .34143 .72129 L .32019 .70534 L p .707 .577 .707 r
F P
0 g
s
.16748 .79166 m .16608 .77258 L .18245 .7686 L p .707 .577 .707 r
F P
0 g
s
.18245 .7686 m .18385 .78768 L .16748 .79166 L p .707 .577 .707 r
F P
0 g
s
.62353 .26135 m .62353 .76323 L .59447 .75397 L p .707 .577 .707 r
F P
0 g
s
.59447 .75397 m .59447 .25208 L .62353 .26135 L p .707 .577 .707 r
F P
0 g
s
.34695 .75784 m .34835 .77692 L .32739 .77598 L p .707 .577 .707 r
F P
0 g
s
.32739 .77598 m .32599 .7569 L .34695 .75784 L p .707 .577 .707 r
F P
0 g
s
.7372 .62575 m .70617 .61972 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73266 .66671 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .7372 .62575 L p .72865 .66425 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .72865 .66425 L .72785 .66788 L .707 .577 .707 r
F
.75125 .67453 m .75333 .66679 L .73564 .66854 L F
.76965 .68161 m .75771 .67077 L .75125 .67453 L F
.75771 .67077 m .75333 .66679 L .75125 .67453 L F
.76889 .62707 m .76463 .66541 L p .78337 .65584 L F P
0 g
s
.76463 .66541 m .76447 .66684 L p .76725 .66522 L .707 .577 .707 r
F P
0 g
s
.78337 .65584 m .76463 .66541 L .76725 .66522 L .707 .577 .707 r
F
.76972 .6816 m .79851 .67814 L p .78804 .66764 L F P
0 g
s
.79812 .62355 m .79386 .66189 L p .80995 .65097 L .707 .577 .707 r
F P
0 g
s
.79386 .66189 m .7937 .66333 L p .79607 .66153 L .707 .577 .707 r
F P
0 g
s
.80995 .65097 m .79386 .66189 L .79607 .66153 L .707 .577 .707 r
F
.79851 .67814 m .82195 .67594 L p .80863 .6595 L F P
0 g
s
.79607 .66153 m .79851 .67814 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78875 .66369 L .78441 .664 L .707 .577 .707 r
F
.79851 .67814 m .79631 .66315 L p .78804 .66764 L F P
0 g
s
.79631 .66315 m .79607 .66153 L p .7937 .66333 L .707 .577 .707 r
F P
0 g
s
.79631 .66315 m .7937 .66333 L .78804 .66764 L .707 .577 .707 r
F
.79812 .62355 m .76889 .62707 L p .78737 .66379 L F P
0 g
s
.7937 .66333 m .79812 .62355 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.79607 .66153 m .79293 .64014 L p .78804 .66764 L .707 .577 .707 r
F P
0 g
s
.79252 .67402 m .7937 .66333 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.76965 .68161 m .76972 .6816 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78441 .664 L .76972 .6816 L .707 .577 .707 r
F
.76725 .66522 m .76965 .68161 L p .78441 .664 L F P
0 g
s
.7372 .62575 m .73266 .66671 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .75306 .65723 L .73537 .66672 L .707 .577 .707 r
F
.75306 .65723 m .7372 .62575 L .73537 .66672 L F
.7382 .68601 m .73564 .66854 L p .73248 .66827 L F P
0 g
s
.72378 .67294 m .73248 .66827 L .7172 .66697 L .707 .577 .707 r
F
.7382 .68601 m .73248 .66827 L .72378 .67294 L F
.73564 .66854 m .73537 .66672 L p .73248 .66827 L F P
0 g
s
.76889 .62707 m .7372 .62575 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.76408 .64361 m .73263 .64801 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.75771 .67077 m .75864 .66681 L .75333 .66679 L .707 .577 .707 r
F
.76447 .66684 m .76889 .62707 L p .75789 .66681 L F P
0 g
s
.75864 .66681 m .76408 .64361 L .75333 .66679 L .707 .577 .707 r
F
.76965 .68161 m .76725 .66522 L p .75771 .67077 L F P
0 g
s
.76725 .66522 m .76408 .64361 L p .75771 .67077 L .707 .577 .707 r
F P
0 g
s
.76328 .67753 m .76447 .66684 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73537 .66672 m .73564 .66854 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73564 .66854 m .7382 .68601 L .75932 .68305 L p .707 .577 .707 r
F P
0 g
s
.75932 .68305 m .76965 .68161 L p .73564 .66854 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .73537 .66672 L .7316 .67621 L .707 .577 .707 r
F
.73266 .66671 m .73248 .66827 L p .73537 .66672 L F P
0 g
s
.73248 .66827 m .7316 .67621 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .7382 .68601 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70725 .69091 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70617 .61972 m .67883 .60958 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .70391 .66814 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70357 .66582 L p .70086 .66754 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70086 .66754 L .69052 .67415 L .707 .577 .707 r
F
.67883 .60958 m .67323 .66005 L .67605 .6611 L p F P
0 g
s
.67323 .66005 m .67883 .60958 L .65785 .59631 L p .707 .577 .707 r
F P
0 g
s
.65785 .59631 m .65225 .64678 L .67323 .66005 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .653 .66229 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67981 .69583 m .67491 .66243 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67491 .66243 m .67423 .65783 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67605 .6611 m .68503 .66443 L p .68365 .65222 L .707 .577 .707 r
F P
0 g
s
.68365 .65222 m .67883 .60958 L .67605 .6611 L .707 .577 .707 r
F
.69052 .67415 m .69463 .66632 L .67978 .66339 L F
.69953 .66728 m .67883 .60958 L .68503 .66443 L F
.70086 .66754 m .70617 .61972 L p .69953 .66728 L F P
0 g
s
.70617 .61972 m .70108 .66561 L p .70357 .66582 L .707 .577 .707 r
F P
0 g
s
.70108 .66561 m .70057 .67019 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70167 .65291 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.68503 .66443 m .70057 .67019 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70057 .67019 m .70086 .66754 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70167 .65291 m .67423 .65783 L p .67978 .66339 L .707 .577 .707 r
F P
0 g
s
.69463 .66632 m .70167 .65291 L .67978 .66339 L .707 .577 .707 r
F
.72785 .66788 m .72171 .65423 L .70357 .66582 L F
.72171 .65423 m .70617 .61972 L .70357 .66582 L F
.70057 .67019 m .7316 .67621 L p .72785 .66788 L F P
0 g
s
.70167 .65291 m .70357 .66582 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73263 .64801 L .7172 .66697 L .707 .577 .707 r
F
.73537 .66672 m .73263 .64801 L p .73248 .66827 L F P
0 g
s
.76328 .67753 m .79252 .67402 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.78737 .66379 m .78337 .65584 L .77521 .66466 L .707 .577 .707 r
F
.78737 .66379 m .77521 .66466 L .76328 .67753 L F
.76447 .66684 m .76328 .67753 L p .78337 .65584 L F P
0 g
s
.79293 .64014 m .76408 .64361 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78875 .66369 m .79293 .64014 L .78441 .664 L .707 .577 .707 r
F
.8133 .65875 m .80995 .65097 L .80278 .66045 L F
.7937 .66333 m .79252 .67402 L p .80995 .65097 L F P
0 g
s
.82195 .67594 m .81929 .65778 L p .81731 .6581 L .707 .577 .707 r
F P
0 g
s
.81239 .66415 m .81731 .6581 L .80863 .6595 L .707 .577 .707 r
F
.82195 .67594 m .81731 .6581 L .81239 .66415 L F
.82195 .67594 m .83768 .67523 L p .82555 .65399 L F P
0 g
s
.83207 .65199 m .8296 .64302 L .82284 .65483 L .707 .577 .707 r
F
.82204 .61554 m .81749 .65647 L p .8296 .64302 L F P
0 g
s
.81749 .65647 m .81731 .6581 L p .81903 .656 L .707 .577 .707 r
F P
0 g
s
.8296 .64302 m .81749 .65647 L .81903 .656 L .707 .577 .707 r
F
.81903 .656 m .82195 .67594 L p .82555 .65399 L F P
0 g
s
.82204 .61554 m .79812 .62355 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .81731 .6581 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .82204 .61554 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81929 .65778 m .81638 .63795 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .81644 .66601 L p .8296 .64302 L .707 .577 .707 r
F P
0 g
s
.83768 .67523 m .83418 .65134 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.82978 .6614 m .83299 .6517 L .82555 .65399 L .707 .577 .707 r
F
.83768 .67523 m .83299 .6517 L .82978 .6614 L F
.8383 .60383 m .83322 .64959 L p .83942 .6323 L F P
0 g
s
.83322 .64959 m .83299 .6517 L p .83385 .6491 L .707 .577 .707 r
F P
0 g
s
.83942 .6323 m .83322 .64959 L .83385 .6491 L .707 .577 .707 r
F
.83768 .67523 m .84417 .67608 L p .83542 .64788 L F P
0 g
s
.83385 .6491 m .83768 .67523 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8383 .60383 m .82204 .61554 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83299 .6517 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .8383 .60383 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .83211 .63724 L .82555 .65399 L .707 .577 .707 r
F
.83418 .65134 m .83385 .6491 L p .83299 .6517 L F P
0 g
s
.83385 .6491 m .83211 .63724 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .83942 .6323 L .83442 .64865 L .707 .577 .707 r
F
.83613 .64732 m .83972 .64002 L p .83442 .64865 L F P
0 g
s
.83299 .6517 m .8327 .65429 L p .83942 .6323 L .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .83211 .63724 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.84417 .67608 m .83956 .64464 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83956 .64464 m .8386 .63808 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83613 .64732 L p .83442 .64865 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .83385 .6491 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .81638 .63795 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81638 .63795 m .81903 .656 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .8327 .65429 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83207 .65199 m .82284 .65483 L .81644 .66601 L .707 .577 .707 r
F
.81638 .63795 m .79293 .64014 L p .80863 .6595 L F P
0 g
s
.79252 .67402 m .81644 .66601 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.8133 .65875 m .80278 .66045 L .79252 .67402 L .707 .577 .707 r
F
.79293 .64014 m .79607 .66153 L p .80863 .6595 L F P
0 g
s
.76408 .64361 m .76725 .66522 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .76328 .67753 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .73537 .66672 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .70167 .65291 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .73248 .66827 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.391 .25598 m .391 .75787 L .36714 .76815 L p .707 .577 .707 r
F P
0 g
s
.391 .75787 m .391 .25598 L .42552 .24818 L p .707 .577 .707 r
F P
0 g
s
.18385 .78768 m .18245 .7686 L .20647 .76472 L p .707 .577 .707 r
F P
0 g
s
.20647 .76472 m .20787 .7838 L .18385 .78768 L p .707 .577 .707 r
F P
0 g
s
.32599 .7569 m .32739 .77598 L .30003 .77629 L p .707 .577 .707 r
F P
0 g
s
.30003 .77629 m .29863 .75721 L .32599 .7569 L p .707 .577 .707 r
F P
0 g
s
.59447 .25208 m .59447 .75397 L .55616 .74757 L p .707 .577 .707 r
F P
0 g
s
.55616 .74757 m .55616 .24568 L .59447 .25208 L p .707 .577 .707 r
F P
0 g
s
.20787 .7838 m .20647 .76472 L .2358 .76132 L p .707 .577 .707 r
F P
0 g
s
.2358 .76132 m .23719 .7804 L .20787 .7838 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .67981 .69583 L .70725 .69091 L p .707 .577 .707 r
F P
0 g
s
.42552 .75007 m .42552 .24818 L .46734 .24363 L p .707 .577 .707 r
F P
0 g
s
.42552 .24818 m .42552 .75007 L .391 .75787 L p .707 .577 .707 r
F P
0 g
s
.29863 .75721 m .30003 .77629 L .26895 .77781 L p .707 .577 .707 r
F P
0 g
s
.26895 .77781 m .26755 .75873 L .29863 .75721 L p .707 .577 .707 r
F P
0 g
s
.23719 .7804 m .2358 .76132 L .26755 .75873 L p .707 .577 .707 r
F P
0 g
s
.55616 .24568 m .55616 .74757 L .51236 .74466 L p .707 .577 .707 r
F P
0 g
s
.51236 .74466 m .51236 .24277 L .55616 .24568 L p .707 .577 .707 r
F P
0 g
s
.26755 .75873 m .26895 .77781 L .23719 .7804 L p .707 .577 .707 r
F P
0 g
s
.65225 .64678 m .65785 .59631 L .64529 .58122 L p .707 .577 .707 r
F P
0 g
s
.653 .66229 m .65857 .70029 L .67981 .69583 L p .707 .577 .707 r
F P
0 g
s
.46734 .74552 m .46734 .24363 L .51236 .24277 L p .707 .577 .707 r
F P
0 g
s
.46734 .24363 m .46734 .74552 L .42552 .75007 L p .707 .577 .707 r
F P
0 g
s
.73105 .77388 m .73245 .75653 L .70137 .75144 L p .707 .577 .707 r
F P
0 g
s
.73245 .75653 m .73105 .77388 L .76281 .77475 L p .707 .577 .707 r
F P
0 g
s
.76281 .77475 m .7642 .7574 L .73245 .75653 L p .707 .577 .707 r
F P
0 g
s
.51236 .24277 m .51236 .74466 L .46734 .74552 L p .707 .577 .707 r
F P
0 g
s
.7642 .7574 m .76281 .77475 L .79213 .77132 L p .707 .577 .707 r
F P
0 g
s
.79213 .77132 m .79353 .75398 L .7642 .7574 L p .707 .577 .707 r
F P
0 g
s
.69997 .76879 m .70137 .75144 L .67401 .74263 L p .707 .577 .707 r
F P
0 g
s
.70137 .75144 m .69997 .76879 L .73105 .77388 L p .707 .577 .707 r
F P
0 g
s
.67401 .74263 m .67261 .75998 L .69997 .76879 L p .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .84532 .58955 L .8383 .60383 L p .707 .577 .707 r
F P
0 g
s
.79353 .75398 m .79213 .77132 L .81615 .76393 L p .707 .577 .707 r
F P
0 g
s
.81615 .76393 m .81755 .74658 L .79353 .75398 L p .707 .577 .707 r
F P
0 g
s
.63969 .63169 m .64529 .58122 L .64237 .56578 L p .707 .577 .707 r
F P
0 g
s
.64529 .58122 m .63969 .63169 L .65225 .64678 L p .707 .577 .707 r
F P
0 g
s
.67261 .75998 m .67401 .74263 L .65304 .73097 L p .707 .577 .707 r
F P
0 g
s
.64005 .66586 m .64562 .70385 L .65857 .70029 L p .707 .577 .707 r
F P
0 g
s
.65857 .70029 m .653 .66229 L .64005 .66586 L p .707 .577 .707 r
F P
0 g
s
.65304 .73097 m .65165 .74831 L .67261 .75998 L p .707 .577 .707 r
F P
0 g
s
.81755 .74658 m .81615 .76393 L .83252 .75329 L p .707 .577 .707 r
F P
0 g
s
.83252 .75329 m .83392 .73595 L .81755 .74658 L p .707 .577 .707 r
F P
0 g
s
.65165 .74831 m .65304 .73097 L .64053 .71759 L p .707 .577 .707 r
F P
0 g
s
.84532 .58955 m .83972 .64002 L .83681 .62458 L p .707 .577 .707 r
F P
0 g
s
.83681 .62458 m .84241 .57411 L .84532 .58955 L p .707 .577 .707 r
F P
0 g
s
.64237 .56578 m .63677 .61625 L .63969 .63169 L p .707 .577 .707 r
F P
0 g
s
.63677 .61625 m .64237 .56578 L .64939 .55151 L p .707 .577 .707 r
F P
0 g
s
.64053 .71759 m .63913 .73494 L .65165 .74831 L p .707 .577 .707 r
F P
0 g
s
.63665 .66818 m .64222 .70617 L .64562 .70385 L p .707 .577 .707 r
F P
0 g
s
.64562 .70385 m .64005 .66586 L .63665 .66818 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83392 .73595 m .83252 .75329 L .83963 .74045 L p .707 .577 .707 r
F P
0 g
s
.83963 .74045 m .84103 .72311 L .83392 .73595 L p .707 .577 .707 r
F P
0 g
s
.63913 .73494 m .64053 .71759 L .63769 .70381 L p .707 .577 .707 r
F P
0 g
s
.84241 .57411 m .83681 .62458 L .82425 .60949 L p .707 .577 .707 r
F P
0 g
s
.82425 .60949 m .82985 .55902 L .84241 .57411 L p .707 .577 .707 r
F P
0 g
s
.64939 .55151 m .64379 .60197 L .63677 .61625 L p .707 .577 .707 r
F P
0 g
s
.64379 .60197 m .64939 .55151 L .66566 .53979 L p .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .84417 .67608 L .84077 .6784 L p .707 .577 .707 r
F P
0 g
s
.63769 .70381 m .63629 .72115 L .63913 .73494 L p .707 .577 .707 r
F P
0 g
s
.84077 .6784 m .8352 .6404 L .8386 .63808 L p .707 .577 .707 r
F P
0 g
s
.64314 .66902 m .64871 .70702 L .64222 .70617 L p .707 .577 .707 r
F P
0 g
s
.64222 .70617 m .63665 .66818 L .64314 .66902 L p .707 .577 .707 r
F P
0 g
s
.3855 .60908 m .3984 .55371 L .36807 .54558 L p .707 .577 .707 r
F P
0 g
s
.3984 .55371 m .3855 .60908 L .41655 .61563 L p .707 .577 .707 r
F P
0 g
s
.41655 .61563 m .42945 .56026 L .3984 .55371 L p .707 .577 .707 r
F P
0 g
s
.84103 .72311 m .83963 .74045 L .83679 .72667 L p .707 .577 .707 r
F P
0 g
s
.83679 .72667 m .83819 .70932 L .84103 .72311 L p .707 .577 .707 r
F P
0 g
s
.42945 .56026 m .41655 .61563 L .44528 .61995 L p .707 .577 .707 r
F P
0 g
s
.44528 .61995 m .45818 .56458 L .42945 .56026 L p .707 .577 .707 r
F P
0 g
s
.35517 .60095 m .36807 .54558 L .34142 .53667 L p .707 .577 .707 r
F P
0 g
s
.36807 .54558 m .35517 .60095 L .3855 .60908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63629 .72115 m .63769 .70381 L .6448 .69097 L p .707 .577 .707 r
F P
0 g
s
.82985 .55902 m .82425 .60949 L .80327 .59622 L p .707 .577 .707 r
F P
0 g
s
.80327 .59622 m .80887 .54575 L .82985 .55902 L p .707 .577 .707 r
F P
0 g
s
.66566 .53979 m .66006 .59026 L .64379 .60197 L p .707 .577 .707 r
F P
0 g
s
.66006 .59026 m .66566 .53979 L .68958 .53178 L p .707 .577 .707 r
F P
0 g
s
.34142 .53667 m .32852 .59204 L .35517 .60095 L p .707 .577 .707 r
F P
0 g
s
.6448 .69097 m .64341 .70832 L .63629 .72115 L p .707 .577 .707 r
F P
0 g
s
.46325 .62123 m .46888 .62163 L p .44867 .60541 L .707 .577 .707 r
F P
0 g
s
.46564 .62137 m .46722 .62555 L p .49371 .63866 L .707 .577 .707 r
F P
0 g
s
.46722 .62555 m .47822 .65463 L .48632 .64628 L p .707 .577 .707 r
F P
0 g
s
.48632 .64628 m .49371 .63866 L p .46722 .62555 L .707 .577 .707 r
F P
0 g
s
.45818 .56458 m .44867 .60541 L p .46888 .62163 L .707 .577 .707 r
F P
0 g
s
.44867 .60541 m .44528 .61995 L .46325 .62123 L p .707 .577 .707 r
F P
0 g
s
.46888 .62163 m .48177 .56626 L .45818 .56458 L p .707 .577 .707 r
F P
0 g
s
.8352 .6404 m .84077 .6784 L .82782 .68196 L p .707 .577 .707 r
F P
0 g
s
.82782 .68196 m .82225 .64396 L .8352 .6404 L p .707 .577 .707 r
F P
0 g
s
.32852 .59204 m .34142 .53667 L .32108 .52784 L p .707 .577 .707 r
F P
0 g
s
.42768 .68417 m .41511 .65091 L .38502 .66159 L p .707 .577 .707 r
F P
0 g
s
.41511 .65091 m .42768 .68417 L .45546 .67032 L p .707 .577 .707 r
F P
0 g
s
.45546 .67032 m .44289 .63705 L .41511 .65091 L p .707 .577 .707 r
F P
0 g
s
.39759 .69485 m .38502 .66159 L .35557 .66804 L p .707 .577 .707 r
F P
0 g
s
.38502 .66159 m .39759 .69485 L .42768 .68417 L p .707 .577 .707 r
F P
0 g
s
.65887 .66831 m .66444 .70631 L .64871 .70702 L p .707 .577 .707 r
F P
0 g
s
.64871 .70702 m .64314 .66902 L .65887 .66831 L p .707 .577 .707 r
F P
0 g
s
.80887 .54575 m .80327 .59622 L .77592 .58608 L p .707 .577 .707 r
F P
0 g
s
.77592 .58608 m .78152 .53561 L .80887 .54575 L p .707 .577 .707 r
F P
0 g
s
.68398 .58225 m .68958 .53178 L .71881 .52827 L p .707 .577 .707 r
F P
0 g
s
.68958 .53178 m .68398 .58225 L .66006 .59026 L p .707 .577 .707 r
F P
0 g
s
.44289 .63705 m .45546 .67032 L .47822 .65463 L p .707 .577 .707 r
F P
0 g
s
.47822 .65463 m .46564 .62137 L .44289 .63705 L p .707 .577 .707 r
F P
0 g
s
.83819 .70932 m .83679 .72667 L .82428 .71329 L p .707 .577 .707 r
F P
0 g
s
.82428 .71329 m .82567 .69595 L .83819 .70932 L p .707 .577 .707 r
F P
0 g
s
.32108 .52784 m .30818 .58321 L .32852 .59204 L p .707 .577 .707 r
F P
0 g
s
.3848 .71489 m .3875 .69937 L p .35735 .68973 L .707 .577 .707 r
F P
0 g
s
.38231 .69508 m .35735 .68973 L p .3875 .69937 L .707 .577 .707 r
F P
0 g
s
.35735 .68973 m .35411 .70832 L .3848 .71489 L p .707 .577 .707 r
F P
0 g
s
.35411 .70832 m .3562 .69633 L p .33039 .68194 L .707 .577 .707 r
F P
0 g
s
.3562 .69633 m .35735 .68973 L .34548 .6863 L p .707 .577 .707 r
F P
0 g
s
.34548 .6863 m .33039 .68194 L p .3562 .69633 L .707 .577 .707 r
F P
0 g
s
.33039 .68194 m .32715 .70052 L .35411 .70832 L p .707 .577 .707 r
F P
0 g
s
.32715 .70052 m .32851 .69269 L p .30978 .6737 L .707 .577 .707 r
F P
0 g
s
.32851 .69269 m .33039 .68194 L .31695 .67657 L p .707 .577 .707 r
F P
0 g
s
.31695 .67657 m .30978 .6737 L p .32851 .69269 L .707 .577 .707 r
F P
0 g
s
.30978 .6737 m .30654 .69228 L .32715 .70052 L p .707 .577 .707 r
F P
0 g
s
.30654 .69228 m .30725 .68821 L p .29755 .66581 L .707 .577 .707 r
F P
0 g
s
.30725 .68821 m .30978 .6737 L .30101 .66804 L p .707 .577 .707 r
F P
0 g
s
.30101 .66804 m .29755 .66581 L p .30725 .68821 L .707 .577 .707 r
F P
0 g
s
.32233 .69947 m .31001 .66688 L p .29788 .65811 L .707 .577 .707 r
F P
0 g
s
.30931 .6659 m .29788 .65811 L p .31001 .66688 L .707 .577 .707 r
F P
0 g
s
.29788 .65811 m .31045 .69137 L .32233 .69947 L p .707 .577 .707 r
F P
0 g
s
.31045 .69137 m .29819 .65892 L p .29517 .64612 L .707 .577 .707 r
F P
0 g
s
.29819 .65892 m .29788 .65811 L .29773 .65744 L p .707 .577 .707 r
F P
0 g
s
.29773 .65744 m .29517 .64612 L p .29819 .65892 L .707 .577 .707 r
F P
0 g
s
.31001 .66688 m .30976 .66621 L .30931 .6659 L p .707 .577 .707 r
F P
0 g
s
.3422 .70289 m .33072 .67252 L p .30976 .66621 L .707 .577 .707 r
F P
0 g
s
.33072 .67252 m .32963 .66963 L .32719 .66921 L p .707 .577 .707 r
F P
0 g
s
.32719 .66921 m .30976 .66621 L p .33072 .67252 L .707 .577 .707 r
F P
0 g
s
.36814 .7013 m .35827 .6752 L p .32963 .66963 L .707 .577 .707 r
F P
0 g
s
.35827 .6752 m .35557 .66804 L .35003 .66838 L p .707 .577 .707 r
F P
0 g
s
.35003 .66838 m .32963 .66963 L p .35827 .6752 L .707 .577 .707 r
F P
0 g
s
.3875 .69937 m .38803 .69631 L .38231 .69508 L p .707 .577 .707 r
F P
0 g
s
.38803 .69631 m .3848 .71489 L .4162 .71961 L p .707 .577 .707 r
F P
0 g
s
.4162 .71961 m .41943 .70103 L .38803 .69631 L p .707 .577 .707 r
F P
0 g
s
.35557 .66804 m .36814 .7013 L .39759 .69485 L p .707 .577 .707 r
F P
0 g
s
.66444 .70631 m .65971 .67403 L p .68231 .66611 L .707 .577 .707 r
F P
0 g
s
.65971 .67403 m .65887 .66831 L .66458 .66778 L p .707 .577 .707 r
F P
0 g
s
.66458 .66778 m .68231 .66611 L p .65971 .67403 L .707 .577 .707 r
F P
0 g
s
.64341 .70832 m .64461 .6934 L p .66117 .68033 L .707 .577 .707 r
F P
0 g
s
.64461 .6934 m .6448 .69097 L .64824 .68874 L p .707 .577 .707 r
F P
0 g
s
.64824 .68874 m .66117 .68033 L p .64461 .6934 L .707 .577 .707 r
F P
0 g
s
.41943 .70103 m .4162 .71961 L .44524 .722 L p .707 .577 .707 r
F P
0 g
s
.44524 .722 m .44847 .70342 L .41943 .70103 L p .707 .577 .707 r
F P
0 g
s
.48177 .56626 m .46888 .62163 L .47759 .62102 L p .707 .577 .707 r
F P
0 g
s
.48483 .61719 m .48477 .61626 L .47759 .62102 L .707 .577 .707 r
F
.48477 .61626 m .48177 .56626 L .47837 .61074 L F
.48477 .61626 m .47837 .61074 L .47759 .62102 L F
.49371 .63866 m .49854 .62811 L p .48581 .61715 L F P
0 g
s
.48547 .61686 m .48565 .61733 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.48565 .61733 m .49371 .63866 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.49305 .6087 m .49336 .60598 L .48581 .61715 L .707 .577 .707 r
F
.49793 .56513 m .48983 .5999 L p .49336 .60598 L F P
0 g
s
.48983 .5999 m .48581 .61715 L p .49336 .60598 L .707 .577 .707 r
F P
0 g
s
.49793 .56513 m .48177 .56626 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.49371 .63866 m .48547 .61686 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .48983 .5999 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.48983 .5999 m .49793 .56513 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .4983 .61451 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49417 .60739 m .49432 .60777 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .50043 .62396 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .48547 .61686 L p .48589 .61705 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .48922 .61317 L .48589 .61705 L .707 .577 .707 r
F
.48922 .61317 m .48114 .60539 L .48589 .61705 L F
.49423 .60733 m .49359 .6039 L p .49305 .6087 L F P
0 g
s
.48786 .59069 m .48114 .60539 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .49432 .60777 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .48786 .59069 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49466 .59435 m .50506 .5613 L .49793 .56513 L p .707 .577 .707 r
F P
0 g
s
.50247 .55515 m .50506 .5613 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49423 .60733 L p .49216 .61667 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .49423 .60733 L .49305 .6087 L .707 .577 .707 r
F
.48786 .59069 m .49417 .60739 L p .49427 .60752 L F P
0 g
s
.49287 .60004 m .49404 .59633 L .49428 .60758 L .707 .577 .707 r
F
.50506 .5613 m .49808 .59127 L p .49404 .59633 L F P
0 g
s
.49808 .59127 m .49428 .60758 L p .49404 .59633 L .707 .577 .707 r
F P
0 g
s
.49332 .60248 m .48786 .59069 L .49427 .60752 L .707 .577 .707 r
F
.49287 .60004 m .49744 .57675 L .49614 .58965 L F
.49249 .598 m .49744 .57675 L p .49287 .60004 L F P
0 g
s
.48515 .57871 m .48786 .59069 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .49265 .59855 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .48515 .57871 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.48515 .57871 m .49253 .59821 L p .49237 .59835 L .707 .577 .707 r
F P
0 g
s
.48957 .61052 m .47751 .60265 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .48868 .59578 L .48957 .61052 L .707 .577 .707 r
F
.48557 .59362 m .48515 .57871 L .49237 .59835 L F
.4924 .59837 m .48957 .61052 L p .48868 .59578 L F P
0 g
s
.48724 .60482 m .48585 .60387 L p .49253 .59821 L .707 .577 .707 r
F P
0 g
s
.49249 .598 m .4924 .59837 L p .4879 .58288 L .707 .577 .707 r
F P
0 g
s
.4879 .58288 m .4924 .59837 L .48868 .59578 L .707 .577 .707 r
F
.49773 .61197 m .49332 .60248 L .49427 .60752 L F
.48957 .61052 m .49249 .598 L p .49287 .60004 L F P
0 g
s
.49854 .62811 m .50043 .62396 L p .48547 .61686 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .49216 .61667 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.48581 .61715 m .48503 .6205 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .48957 .61052 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.4983 .61451 m .49773 .61197 L p .49417 .60739 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49216 .61667 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .48724 .60482 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49253 .59821 m .49265 .59855 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .49773 .61197 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .48557 .59362 L .49237 .59835 L .707 .577 .707 r
F
.47328 .57061 m .48515 .57871 L p .48557 .59362 L F P
0 g
s
.47751 .60265 m .48036 .59043 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.47328 .57061 m .4807 .59023 L p .48036 .59043 L .707 .577 .707 r
F P
0 g
s
.47751 .60265 m .45716 .59382 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .47751 .60265 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4665 .5983 m .46925 .58708 L .48036 .59043 L .707 .577 .707 r
F
.46925 .58708 m .47328 .57061 L .48036 .59043 L F
.4807 .59023 m .47328 .57061 L p .48557 .59362 L F P
0 g
s
.4534 .56718 m .47328 .57061 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .45933 .58452 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4534 .56718 m .45985 .58424 L p .45933 .58452 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .43052 .58491 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45716 .59382 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.44343 .59319 m .44738 .5829 L .45933 .58452 L .707 .577 .707 r
F
.44738 .5829 m .4534 .56718 L .45933 .58452 L F
.45985 .58424 m .4534 .56718 L p .46925 .58708 L F P
0 g
s
.42747 .56878 m .4534 .56718 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.43052 .58491 m .43137 .58125 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.42747 .56878 m .43201 .58081 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43052 .58491 L .41492 .58072 L p .707 .577 .707 r
F P
0 g
s
.4183 .59035 m .42229 .58096 L .43137 .58125 L .707 .577 .707 r
F
.42229 .58096 m .42747 .56878 L .43137 .58125 L F
.43201 .58081 m .42747 .56878 L p .44738 .5829 L F P
0 g
s
.39801 .57523 m .42747 .56878 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.41059 .60849 m .4002 .58102 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.4002 .58102 m .39801 .57523 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.39801 .57523 m .41059 .60849 L .3805 .61917 L p .707 .577 .707 r
F P
0 g
s
.3805 .61917 m .36792 .58591 L .39801 .57523 L p .707 .577 .707 r
F P
0 g
s
.41309 .5214 m .40019 .57678 L .39463 .57561 L p .707 .577 .707 r
F P
0 g
s
.39463 .57561 m .36914 .57023 L p .37845 .55988 L .707 .577 .707 r
F P
0 g
s
.37845 .55988 m .41309 .5214 L .39463 .57561 L .707 .577 .707 r
F
.44342 .52953 m .43137 .58125 L p .40019 .57678 L F P
0 g
s
.41492 .58072 m .40019 .57678 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43149 .58074 L p .43201 .58081 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43201 .58081 L .4338 .58105 L .707 .577 .707 r
F
.44004 .60204 m .41059 .60849 L p .4183 .59035 L F P
0 g
s
.43201 .58081 m .44004 .60204 L p .4183 .59035 L .707 .577 .707 r
F P
0 g
s
.44004 .60204 m .43201 .58081 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.44342 .52953 m .47006 .53845 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.43149 .58074 m .44342 .52953 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .45933 .58452 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45942 .58411 L p .45985 .58424 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45985 .58424 L .46327 .58527 L .707 .577 .707 r
F
.46597 .60045 m .44004 .60204 L p .44343 .59319 L F P
0 g
s
.45985 .58424 m .46597 .60045 L p .44343 .59319 L .707 .577 .707 r
F P
0 g
s
.46597 .60045 m .45985 .58424 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .49041 .54727 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.45942 .58411 m .47006 .53845 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .48036 .59043 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .48044 .59006 L p .4807 .59023 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .4807 .59023 L .48314 .59193 L .707 .577 .707 r
F
.48585 .60387 m .46597 .60045 L p .4665 .5983 L F P
0 g
s
.4807 .59023 m .48585 .60387 L p .4665 .5983 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .4807 .59023 L p .48557 .59362 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .50247 .55515 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48044 .59006 m .49041 .54727 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .4879 .58288 L .48868 .59578 L .707 .577 .707 r
F
.50247 .55515 m .49249 .598 L p .4879 .58288 L F P
0 g
s
.49744 .57675 m .50247 .55515 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .46564 .62137 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48547 .61686 m .48114 .60539 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.47759 .62102 m .48503 .6205 L p .48483 .61719 L .707 .577 .707 r
F P
0 g
s
.78152 .53561 m .77592 .58608 L .74489 .58005 L p .707 .577 .707 r
F P
0 g
s
.74489 .58005 m .75049 .52959 L .78152 .53561 L p .707 .577 .707 r
F P
0 g
s
.71321 .57873 m .71881 .52827 L .75049 .52959 L p .707 .577 .707 r
F P
0 g
s
.71881 .52827 m .71321 .57873 L .68398 .58225 L p .707 .577 .707 r
F P
0 g
s
.30818 .58321 m .32108 .52784 L .30902 .51996 L p .707 .577 .707 r
F P
0 g
s
.66117 .68033 m .65977 .69768 L .64341 .70832 L p .707 .577 .707 r
F P
0 g
s
.75049 .52959 m .74489 .58005 L .71321 .57873 L p .707 .577 .707 r
F P
0 g
s
.82225 .64396 m .82782 .68196 L .80658 .68642 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .80101 .64842 L .82225 .64396 L p .707 .577 .707 r
F P
0 g
s
.32963 .66963 m .3422 .70289 L .36814 .7013 L p .707 .577 .707 r
F P
0 g
s
.44847 .70342 m .44524 .722 L .46908 .72185 L p .707 .577 .707 r
F P
0 g
s
.46908 .72185 m .47231 .70326 L .44847 .70342 L p .707 .577 .707 r
F P
0 g
s
.68231 .66611 m .68788 .70411 L .66444 .70631 L p .707 .577 .707 r
F P
0 g
s
.30902 .51996 m .29612 .57534 L .30818 .58321 L p .707 .577 .707 r
F P
0 g
s
.82567 .69595 m .82428 .71329 L .80332 .70163 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .77915 .69134 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80101 .64842 m .80276 .66035 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80276 .66035 m .80658 .68642 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .80471 .68428 L .82022 .69291 L p .707 .577 .707 r
F P
0 g
s
.82022 .69291 m .82567 .69595 L p .82231 .6968 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .82022 .69291 L .82231 .6968 L .707 .577 .707 r
F
.68788 .70411 m .6827 .66876 L p .71117 .66265 L F P
0 g
s
.6827 .66876 m .68231 .66611 L .6866 .6656 L p .707 .577 .707 r
F P
0 g
s
.6866 .6656 m .71117 .66265 L p .6827 .66876 L .707 .577 .707 r
F P
0 g
s
.65977 .69768 m .66067 .68657 L p .68519 .67294 L .707 .577 .707 r
F P
0 g
s
.66067 .68657 m .66117 .68033 L .67281 .67675 L p .707 .577 .707 r
F P
0 g
s
.67281 .67675 m .68519 .67294 L p .66067 .68657 L .707 .577 .707 r
F P
0 g
s
.30976 .66621 m .32233 .69947 L .3422 .70289 L p .707 .577 .707 r
F P
0 g
s
.68519 .67294 m .6838 .69029 L .65977 .69768 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .77357 .65335 L .80101 .64842 L p .707 .577 .707 r
F P
0 g
s
.29612 .57534 m .30902 .51996 L .30643 .51381 L p .707 .577 .707 r
F P
0 g
s
.47231 .70326 m .46908 .72185 L .48538 .71915 L p .707 .577 .707 r
F P
0 g
s
.48538 .71915 m .48862 .70056 L .47231 .70326 L p .707 .577 .707 r
F P
0 g
s
.71117 .66265 m .71674 .70064 L .68788 .70411 L p .707 .577 .707 r
F P
0 g
s
.80471 .68428 m .80332 .70163 L .77595 .69282 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .74819 .69624 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77357 .65335 m .77457 .66016 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77457 .66016 m .77915 .69134 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .77735 .67548 L .7964 .68161 L p .707 .577 .707 r
F P
0 g
s
.7964 .68161 m .80471 .68428 L p .80042 .68556 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .7964 .68161 L .80042 .68556 L .707 .577 .707 r
F
.71674 .70064 m .71152 .66504 L p .74262 .65825 L F P
0 g
s
.71152 .66504 m .71117 .66265 L .71645 .66191 L p .707 .577 .707 r
F P
0 g
s
.71645 .66191 m .74262 .65825 L p .71152 .66504 L .707 .577 .707 r
F P
0 g
s
.6838 .69029 m .68444 .68222 L p .71452 .66951 L .707 .577 .707 r
F P
0 g
s
.68444 .68222 m .68519 .67294 L .7022 .67095 L p .707 .577 .707 r
F P
0 g
s
.7022 .67095 m .71452 .66951 L p .68444 .68222 L .707 .577 .707 r
F P
0 g
s
.30643 .51381 m .29353 .56918 L .29612 .57534 L p .707 .577 .707 r
F P
0 g
s
.29755 .66581 m .29431 .68439 L .30654 .69228 L p .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .74334 .66322 L p .77357 .65335 L .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .71674 .70064 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74262 .65825 m .74296 .66063 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74296 .66063 m .74819 .69624 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .74488 .68773 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.77735 .67548 m .7767 .6836 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.7767 .6836 m .77595 .69282 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.71312 .68686 m .71358 .68119 L p .74627 .67039 L .707 .577 .707 r
F P
0 g
s
.71358 .68119 m .71452 .66951 L .73211 .67 L p .707 .577 .707 r
F P
0 g
s
.73211 .67 m .74627 .67039 L p .71358 .68119 L .707 .577 .707 r
F P
0 g
s
.74334 .66322 m .74262 .65825 L .75476 .65633 L p .707 .577 .707 r
F P
0 g
s
.75476 .65633 m .77357 .65335 L p .74334 .66322 L .707 .577 .707 r
F P
0 g
s
.71452 .66951 m .71312 .68686 L .6838 .69029 L p .707 .577 .707 r
F P
0 g
s
.74488 .68773 m .74627 .67039 L .77735 .67548 L p .707 .577 .707 r
F P
0 g
s
.74627 .67039 m .74488 .68773 L .71312 .68686 L p .707 .577 .707 r
F P
0 g
s
.48862 .70056 m .48538 .71915 L .49256 .71417 L p .707 .577 .707 r
F P
0 g
s
.49256 .71417 m .49579 .69559 L .48862 .70056 L p .707 .577 .707 r
F P
0 g
s
.29353 .56918 m .30643 .51381 L .31356 .50998 L p .707 .577 .707 r
F P
0 g
s
.29431 .68439 m .29755 .66581 L .29489 .65904 L p .707 .577 .707 r
F P
0 g
s
.29489 .65904 m .29165 .67763 L .29431 .68439 L p .707 .577 .707 r
F P
0 g
s
.31356 .50998 m .30066 .56535 L .29353 .56918 L p .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .31045 .69137 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.29672 .6502 m .30775 .67939 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .29517 .64612 L .3019 .63142 L p .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29489 .65904 L .29977 .65566 L p .707 .577 .707 r
F P
0 g
s
.29977 .65566 m .30206 .65407 L p .30066 .65726 L .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29977 .65566 L .30066 .65726 L .707 .577 .707 r
F
.29517 .64612 m .29672 .6502 L p .2963 .64946 L F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .69559 m .49256 .71417 L .4899 .70741 L p .707 .577 .707 r
F P
0 g
s
.4899 .70741 m .49314 .68883 L .49579 .69559 L p .707 .577 .707 r
F P
0 g
s
.30066 .56535 m .31356 .50998 L .32971 .50885 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30206 .65407 m .29883 .67265 L .29165 .67763 L p .707 .577 .707 r
F P
0 g
s
.32971 .50885 m .31681 .56422 L .30066 .56535 L p .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .30775 .67939 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.30525 .6403 m .31447 .66469 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .3019 .63142 L .31739 .61545 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31447 .66469 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31739 .61545 m .32333 .63117 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.32333 .63117 m .32996 .64871 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .31837 .65137 L .34123 .65122 L p .707 .577 .707 r
F P
0 g
s
.34123 .65122 m .34221 .65121 L p .3416 .65163 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .34123 .65122 L .3416 .65163 L .707 .577 .707 r
F
.29883 .67265 m .30206 .65407 L .31761 .6515 L p F P
0 g
s
.31761 .6515 m .31837 .65137 L p .31796 .65181 L .707 .577 .707 r
F P
0 g
s
.29883 .67265 m .31761 .6515 L .31796 .65181 L .707 .577 .707 r
F
.3019 .63142 m .30525 .6403 L p .3027 .63799 L F P
0 g
s
.49314 .68883 m .4899 .70741 L .47767 .69952 L p .707 .577 .707 r
F P
0 g
s
.47767 .69952 m .4809 .68094 L .49314 .68883 L p .707 .577 .707 r
F P
0 g
s
.31681 .56422 m .32971 .50885 L .35331 .51053 L p .707 .577 .707 r
F P
0 g
s
.35331 .51053 m .34041 .5659 L .31681 .56422 L p .707 .577 .707 r
F P
0 g
s
.31837 .65137 m .31513 .66995 L .29883 .67265 L p .707 .577 .707 r
F P
0 g
s
.34041 .5659 m .35331 .51053 L .38204 .51486 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31739 .61545 L .34014 .59976 L p .707 .577 .707 r
F P
0 g
s
.4809 .68094 m .47767 .69952 L .45706 .69127 L p .707 .577 .707 r
F P
0 g
s
.45706 .69127 m .4603 .67269 L .4809 .68094 L p .707 .577 .707 r
F P
0 g
s
.38204 .51486 m .36914 .57023 L .34041 .5659 L p .707 .577 .707 r
F P
0 g
s
.40019 .57678 m .41309 .5214 L .44342 .52953 L p .707 .577 .707 r
F P
0 g
s
.36914 .57023 m .38204 .51486 L .41309 .5214 L p .707 .577 .707 r
F P
0 g
s
.34221 .65121 m .33897 .66979 L .31513 .66995 L p .707 .577 .707 r
F P
0 g
s
.34014 .59976 m .35272 .63303 L .32996 .64871 L p .707 .577 .707 r
F P
0 g
s
.35272 .63303 m .34014 .59976 L .36792 .58591 L p .707 .577 .707 r
F P
0 g
s
.36792 .58591 m .3805 .61917 L .35272 .63303 L p .707 .577 .707 r
F P
0 g
s
.4603 .67269 m .45706 .69127 L .4301 .68348 L p .707 .577 .707 r
F P
0 g
s
.4301 .68348 m .43333 .6649 L .4603 .67269 L p .707 .577 .707 r
F P
0 g
s
.33897 .66979 m .34221 .65121 L .37125 .65361 L p .707 .577 .707 r
F P
0 g
s
.37125 .65361 m .36801 .67219 L .33897 .66979 L p .707 .577 .707 r
F P
0 g
s
.43333 .6649 m .4301 .68348 L .39941 .67691 L p .707 .577 .707 r
F P
0 g
s
.39941 .67691 m .40265 .65832 L .43333 .6649 L p .707 .577 .707 r
F P
0 g
s
.36801 .67219 m .37125 .65361 L .40265 .65832 L p .707 .577 .707 r
F P
0 g
s
.40265 .65832 m .39941 .67691 L .36801 .67219 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001LOol50004Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol300000eYF001JEP02FUH80006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH80008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1P002eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo011oo`l004Eoo`00EWoo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo00Yoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@0045oo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol01Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000?Goo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool30006FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P00>Goo001EOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000gOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oo`0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<003Eoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=o
o`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00
E7oo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00
Dgoo00<005YF000030001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`0000=JEP00FUH02eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000;goo001COol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP040002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH02@00FUIJEUYF001JEP00FUH0000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00EJEPH000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo001DOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH00eYF1P002EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00
Egoo00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF100015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEPH000moo`@0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Qoo`8000=JEP03001JEUYF00EJEP03
001JEUYF008000QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EP03001JEP0000<001Uoo`@000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00FWoo0P00
00=JEP00FUH01UYF10002EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool005aoo`<000EJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00Oomoo`0SOol300000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00Ggoo1@001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF001JEP00
00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000
00005Woo0`003goo0P001EYF00L005YFFUIJEP00FUH0000/Ool0061oo`8000QJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF0`004goo1@0047oo0P000eYF00L005YF
FUIJEP00FUH0000/Ool005moo`8000UJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEPD00003
FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEUYFFUH00002FUH00`00Oomoo`0@Ool5000BOol01000FUIJEP000eYF0P00;Goo001NOol01000
FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YF00000P00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF00@005YFFUIJEP80011oo`D001=oo`<000=JEP8002eoo`00G7oo0P000eYF00<005YFFUH01eYF
00<005YFFUH01EYF100025YF00<005YFFUH015YF0`0000=JEP0000000P000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH00eYF0P003goo0`00
5Woo00@005YFFUIJEP8002eoo`00Fgoo00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00D005YF001JEP0000=JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01EYF0P00
9Woo0P0000AJEP00FUH002eoo`00F7oo0`001eYF00<005YFFUH01eYF00<005YF00000P000eYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01eYF0`008Goo0P0000IJEP00
FUH005YF000]Ool004moo`T00003FUH0000000MJEP03001JEUYF00MJEP800003FUH005YF00MJEP03
001JEP0000X0009JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEP0015YF00<005YFFUH02eYF1P005goo100000AJEP00FUIJEP800003FUH007oo02aoo`00AWoo
2@0015YF00@005YFFUIJEP800003FUH0000000MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000EJEP80009JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEP0015YF00<005YFFUH04EYF2@002Goo1@001EYF00L005YFFUIJEP00FUH0000]Ool0
03ioo`P000eJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH30006FUH0
0`00FUIJEP06FUH01@00FUIJEUYF000015YF0P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF01YJEPT000=JEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Goo000`Ool>000EFUH00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUH000020005FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH07UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0`00
0UYF00<005YFFUH015YF00<005YFFUH05eYF0`001EYF0P001eYF0P000UYF00<005YFFUH00eYF1@00
1EYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF01QJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00mJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00=JEP800005FUH005YFFUH0
0005FUH50005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0:000^Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00EJEP04001JEUYF0005FUH0
1000FUIJEUYF0P000eYF00@005YFFUH000IJEP<000IJEP03001JEUYF00<000QJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH01000FUIJEUYF1`000eYF00@005YF
FUIJEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH0
1EYF00<005YFFUH00P001EYF0`0000=JEP00FUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP<0
00=JEP03001JEUYF00EJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH00eYF1@0000=JEP000000;Woo000[Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJ
EP04001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF
1`000UYF00@005YFFUIJEP8002ioo`00:goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP8000MJEP03001JEUYF00IJEP03001JEUYF01D000=JEP03001JEUYF00=JEP8000QJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF00=JEP04001JEUYF0006FUH60004FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30002FUH30002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009J
EP03001JEUYF00IJEP03001JEUYF009JEP8000YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP800003FUH00000
00EJEP03001JEP0000MJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040007FUH01@00FUIJ
EUYF000035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000010000UYF00<005YFFUH01EYF2@000eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
FUH000EJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@000AJEP@000aJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH3000015YF001JEUYF2`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH000MJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00009JEPd000AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000@0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00P000EJEP80009JEQ4000IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH0000000=JEP03
001JEUYF00AJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01UYF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
;Goo000/Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF0P001UYF1`001UYF00<005YF
FUH01EYF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH60005FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002aoo`04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00005FUH20003FUH00`00FUH00004FUH0
0`00FUIJEP04FUH20008FUH30002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF
009JEP<0031oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00eYF3@001eYF00D0
05YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP@000EJ
EP03001JEUYF00AJEP<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<00004FUH00000000cOol002eoo`03001JEP0000=JEP03001JEUYF009JEPP000QJEP04
001JEUYFFUH30004FUH300001EYF000005YF000015YF00<005YFFUH015YF0P001UYF1@000eYF0`00
0eYF100000=JEP00FUH01EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006FUH0
0`00FUIJEP05FUH3000fOol002eoo`03001JEP00009JEP04001JEUYFFUH20007FUH00`00FUIJEP02
FUH90002Ool3000015YF001JEUYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH015YF
20000UYF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH60004
FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eo
o`<0009JEP03001JEP0000l000ioo`<000=JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00QJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUH0000300000eYF00000007FUH0
0`00FUIJEP04FUH700000goo000000020006FUH00`00FUIJEP02FUH2000bOol002eoo`03001JEP00
009JEP<0021oo`8000=JEP@000=JEP03001JEUYF00AJEP03001JEUYF00P000EJEP03001JEUYF00UJ
EP04001JEP000003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP04000<Ool40002FUH00`00FUIJ
EP03FUH2000aOol002eoo`05FUH005YFFUH0000UOol300000eYF0000000>0003FUH00`00FUIJEP02
FUH80008FUH60002FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1P0057oo0`001EYF00<005YF0000
<7oo000]Ool015YF001JEP00:Goo0P000eYF100000=JEP00FUH025YF00<005YFFUH01UYF00@005YF
FUIJEPP000=JEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEUYFFUH40002FUH=000MOol20003FUH01000FUIJEP00;goo000]Ool00eYF0000000/Ool0
0`00FUIJEP02FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPH000EJEP03001JEUYF00=JEP8001moo`800003FUH005YF009JEP03001oogoo02aoo`00;7oo
00<005YF0000;Woo00D005YFFUIJEP0000=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo021oo`8000=JEP03001oogoo02aoo`00;7oo0`00;goo0P0000=JEP00FUH00UYF00@005YFFUH0
009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol027oo0`005goo00@005YFFUH002ioo`00;7oo1000<7oo0P000eYF00@0
05YFFUH000IJEP03001JEUYF00P000AJEP03001JEUYF00AJEP03001JEUYF00<000IJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000Yoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`05001JEP00FUH0000GOol3000F
Ool01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00003@002EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF
00AJEP04001JEUYF000;Ool5000GOol200000eYF001oo`0/Ool002aoo`05001JEP00FUH0000FOol5
000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<0
05YF00001eYF0P0037oo1@0067oo00<005YF0000;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0C
Ool5000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=J
EP8000IJEP8000ioo`<001Uoo`03001JEP0002eoo`00;7oo0P0015YF00<007ooOol04Woo1@005goo
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP<000=JEP8002aoo`80
02ioo`00;7oo0P0015YF0`004goo0`0067oo0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YFFUH0009JEP<002ioo`8002ioo`00;Goo00<005YFFUH00UYF00@005YFFUH0
02ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP8002aoo`@002ioo`00;Goo00D005YFFUIJEP0000AJEP8002aoo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000005FUH2000XOol20002FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00006
FUH00`00Oomoo`0YOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF1P0025YF
00<005YFFUH02UYF2P001eYF00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YF00000`00
8Woo0P000eYF0P00;goo000^Ool01000FUIJEP001UYF0`009goo0P0000EJEP00FUIJEP0000IJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP03FUH5000IOol40000
0eYF001JEP02FUH00`00Oomoo`0^Ool002ioo`04001JEUYF0006FUH00`00FUIJEP02000TOol00`00
FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000<7oo000_Ool20006FUH0
0`00FUIJEP03FUH20009OolN0002FUH00`00FUIJEP03FUH400000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH00`00FUIJEP02000aOol0
02moo`8000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<005YFFUH01UYF
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo
000`Ool00`00FUIJEP04FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF
00AJEP80009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8003Eoo`00<Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00
0UYF2P0015YF1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=goo000_Ool3
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001eYF
00<005YF00000P0000AJEP000000009oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003Yo
o`00;Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
5P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF009JEP80009J
EP03001oogoo00=ooa00041oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
4P001eYF00<005YFFUH00eYF00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEUYF008000MJEP03001JEUYF009JEPD005Aoo`00;Goo00<005YF000015YF00@005YFFUIJ
EPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF009JEP03001JEUYF
008005Aoo`00;Goo00<005YF00000eYF1@0000=JEP0000000eYF00<005YFFUH01UYF0P0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH02`0015YF00<005YF0000EGoo000]Ool01000FUH005YF0P0015YF00@005YFFUIJEP800003
FUH005YF00MJEP8000QJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=oo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEP00FUH200000eYF001JEP05FUH300000eYF001JEP02
001DOol002eoo`03001JEP00008000EJEP03001JEUYF00=JEP@000IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000Qoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
00AJEP8000IJEP03001JEUYF0080009JEP03001oogoo059oo`00;Goo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF1@003Goo0P00
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YF000000AJEP04001JEUYF
FUH4001DOol002ioobL001Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH200000eYF
001JEP02FUH00`00FUH00002001DOol006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00AJ
EP8000=JEP<00003FUH0000005=oo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`000goo100000=JEP00FUH01UYF00<005YF
00000P0000=JEP0000000UYF00<007ooOol0DGoo001_Ool300000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40009Ool50003FUH00`00FUIJEP02
FUH01000FUH000000UYF00<007ooOol0DGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000=Ool50002FUH30002FUH2001DOol007Uoo`/000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0015oo`H0009JEP8005Aoo`00Q7oo6P002goo1@00
3goo0P000UYF00<005YFFUH00eYF00<007ooOol0Dgoo002?Ool01000FUIJEP005goo0`003Woo0P00
15YF00@005YFFUIJEP8005Ioo`00Sgoo00<005YF00009goo0P001eYF0`00F7oo002@Ool2000SOol4
00000eYF001JEP06FUH00`00Oomoo`1HOol0091oo`03001JEP0001eoo`D000EJEP03001JEUYF00=J
EP8005]oo`00T7oo00<005YFFUH00`005Woo10000UYF00<005YFFUH01UYF00<005YFFUH00P00GGoo
002@Ool01000FUIJEP000UYF5P001UYF00<005YFFUH01UYF0`00Ggoo002@Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P00HGoo002AOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
Hgoo002BOol30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001WOol009Ao
o`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@006aoo`00Ugoo5P00L7oo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63086 .75143 m .61796 .69895 L .58691 .70655 L p .707 .577 .707 r
F P
0 g
s
.61796 .69895 m .63086 .75143 L .65959 .74084 L p .707 .577 .707 r
F P
0 g
s
.65959 .74084 m .64669 .68836 L .61796 .69895 L p .707 .577 .707 r
F P
0 g
s
.59981 .75903 m .58691 .70655 L .55658 .71042 L p .707 .577 .707 r
F P
0 g
s
.58691 .70655 m .59981 .75903 L .63086 .75143 L p .707 .577 .707 r
F P
0 g
s
.64669 .68836 m .65959 .74084 L .68318 .72828 L p .707 .577 .707 r
F P
0 g
s
.68318 .72828 m .67029 .6758 L .64669 .68836 L p .707 .577 .707 r
F P
0 g
s
.55996 .78187 m .58941 .79288 L p .5817 .77138 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .55658 .71042 L .56309 .75438 L .707 .577 .707 r
F
.56863 .75944 m .56851 .75894 L p .56798 .75885 L F P
0 g
s
.56851 .75894 m .55658 .71042 L p .56798 .75885 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .52994 .71016 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.55658 .71042 m .56863 .75944 L p .59981 .75903 L .707 .577 .707 r
F P
0 g
s
.5817 .77138 m .57771 .76025 L .56863 .75944 L .707 .577 .707 r
F
.56798 .75885 m .55996 .78187 L p .5817 .77138 L F P
0 g
s
.58508 .76091 m .59981 .75903 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.58941 .79288 m .60198 .75682 L .57253 .74581 L p .707 .577 .707 r
F P
0 g
s
.56863 .75944 m .56948 .7629 L .58508 .76091 L p .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .56798 .75885 L p .56863 .75944 L .707 .577 .707 r
F P
0 g
s
.57771 .76025 m .57253 .74581 L .56863 .75944 L .707 .577 .707 r
F
.55996 .78187 m .56798 .75885 L p .55262 .75603 L F P
0 g
s
.53402 .77088 m .55996 .78187 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54001 .75371 m .53402 .77088 L p .54715 .76039 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54067 .75383 L .54715 .76039 L .707 .577 .707 r
F
.54067 .75383 m .54001 .75371 L .54715 .76039 L F
.52994 .71016 m .50959 .70582 L p .53334 .74641 L F P
0 g
s
.54015 .75331 m .52994 .71016 L .53334 .74641 L .707 .577 .707 r
F
.54067 .75383 m .54057 .75344 L p .54015 .75331 L F P
0 g
s
.54057 .75344 m .52994 .71016 L p .54015 .75331 L .707 .577 .707 r
F P
0 g
s
.53402 .77088 m .54015 .75331 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.52994 .71016 m .54067 .75383 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .54015 .75331 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54001 .75371 L p .54067 .75383 L .707 .577 .707 r
F P
0 g
s
.55262 .75603 m .54015 .75331 L .54067 .75383 L .707 .577 .707 r
F
.54283 .76264 m .54067 .75383 L p .53334 .74641 L F P
0 g
s
.51415 .76098 m .53402 .77088 L p .5335 .76757 L .707 .577 .707 r
F P
0 g
s
.5335 .76757 m .53075 .75029 L .52463 .75423 L .707 .577 .707 r
F
.5335 .76757 m .52463 .75423 L .51415 .76098 L F
.50959 .70582 m .49753 .69781 L p .51455 .73905 L F P
0 g
s
.5193 .7462 m .50959 .70582 L .51455 .73905 L .707 .577 .707 r
F
.51964 .74672 m .51955 .74637 L p .5193 .7462 L F P
0 g
s
.51955 .74637 m .50959 .70582 L p .5193 .7462 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .5193 .7462 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50959 .70582 m .51964 .74672 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.52672 .72493 m .5193 .7462 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.5193 .7462 m .51917 .74657 L p .51964 .74672 L .707 .577 .707 r
F P
0 g
s
.53075 .75029 m .5193 .7462 L .51964 .74672 L .707 .577 .707 r
F
.51917 .74657 m .51415 .76098 L p .53075 .75029 L F P
0 g
s
.52249 .7583 m .51964 .74672 L p .51455 .73905 L .707 .577 .707 r
F P
0 g
s
.51415 .76098 m .51443 .74311 L .50961 .74709 L .707 .577 .707 r
F
.50227 .75316 m .51275 .76007 L p .50961 .74709 L F P
0 g
s
.51275 .76007 m .51415 .76098 L p .50961 .74709 L .707 .577 .707 r
F P
0 g
s
.51686 .74465 m .5121 .73312 L .5076 .73877 L .707 .577 .707 r
F
.49753 .69781 m .50751 .73842 L p .5121 .73312 L F P
0 g
s
.50751 .73842 m .5076 .73877 L p .5121 .73312 L .707 .577 .707 r
F P
0 g
s
.50734 .73861 m .50227 .75316 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.5076 .73877 m .51043 .75029 L p .51686 .74465 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .49753 .69781 L .50596 .73201 L .705 .576 .708 r
F
.5076 .73877 m .50751 .73842 L p .50747 .73824 L F P
0 g
s
.50751 .73842 m .49753 .69781 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.50734 .73861 m .50747 .73824 L p .50516 .74113 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .51484 .7171 L p .50705 .73644 L .707 .577 .707 r
F P
0 g
s
.50713 .73679 m .50747 .73824 L .50596 .73201 L .705 .576 .708 r
F
.51484 .7171 m .50747 .73824 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.50747 .73824 m .50734 .73861 L p .5076 .73877 L .707 .577 .707 r
F P
0 g
s
.51443 .74311 m .50747 .73824 L .5076 .73877 L .707 .577 .707 r
F
.51484 .7171 m .51214 .71211 L p .50667 .73484 L F P
0 g
s
.50705 .73644 m .51484 .7171 L .50667 .73484 L .707 .577 .707 r
F
.50713 .73679 m .50596 .73201 L .50658 .73443 L .705 .576 .708 r
F
.49956 .74816 m .50227 .75316 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50207 .6742 L p .50664 .72587 L .707 .577 .707 r
F P
0 g
s
.51214 .71211 m .50582 .73021 L p .50667 .73484 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50582 .73021 L .50572 .73077 L .707 .577 .707 r
F
.52672 .72493 m .51484 .7171 L p .51443 .74311 L F P
0 g
s
.51214 .71211 m .51886 .71043 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50572 .73077 L p .50582 .73021 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .50582 .73021 L .50695 .72931 L .707 .577 .707 r
F
.50572 .73077 m .49494 .68691 L p .50664 .72587 L F P
0 g
s
.50582 .73021 m .50568 .73061 L p .50572 .73077 L .707 .577 .707 r
F P
0 g
s
.49494 .68691 m .50192 .71532 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50596 .73201 m .50432 .72525 L .50784 .73939 L .705 .576 .708 r
F
.50192 .71532 m .50562 .73037 L p .50432 .72525 L F P
0 g
s
.50562 .73037 m .50784 .73939 L p .50432 .72525 L .705 .576 .708 r
F P
0 g
s
.50582 .73021 m .51214 .71211 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .50784 .73939 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.51886 .71043 m .51453 .72285 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51497 .72668 m .51419 .7235 L p .51453 .72285 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51886 .71043 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51517 .72267 m .51453 .72285 L .51522 .72153 L .707 .577 .707 r
F
.51497 .72668 m .51453 .72285 L .51517 .72267 L F
.51886 .71043 m .53435 .71224 L p .52914 .7186 L F P
0 g
s
.51419 .7235 m .51497 .72668 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50784 .73939 m .51043 .75029 L p .50713 .73679 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .5076 .73877 L p .50747 .73824 L .705 .576 .708 r
F P
0 g
s
.51043 .75029 m .50747 .73824 L .50713 .73679 L .705 .576 .708 r
F
.51822 .66092 m .53112 .7134 L .51497 .72668 L p .707 .577 .707 r
F P
0 g
s
.50629 .74649 m .51453 .72285 L p .52914 .7186 L .707 .577 .707 r
F P
0 g
s
.51453 .72285 m .51435 .72337 L p .51419 .7235 L .707 .577 .707 r
F P
0 g
s
.51078 .72624 m .51453 .72285 L .51419 .7235 L .707 .577 .707 r
F
.50207 .6742 m .51822 .66092 L p .51522 .72153 L F P
0 g
s
.51419 .7235 m .50207 .6742 L p .51522 .72153 L .707 .577 .707 r
F P
0 g
s
.50207 .6742 m .51419 .7235 L p .50695 .72931 L .707 .577 .707 r
F P
0 g
s
.50667 .73484 m .50658 .73444 L .49956 .74816 L .707 .577 .707 r
F
.49753 .69781 m .49494 .68691 L p .50596 .73201 L .705 .576 .708 r
F P
0 g
s
.50658 .73444 m .50568 .73061 L .49956 .74816 L .707 .577 .707 r
F
.50713 .73679 m .50658 .73443 L .50784 .73939 L .705 .576 .708 r
F
.50747 .73824 m .50705 .73644 L .50516 .74113 L .707 .577 .707 r
F
.50516 .74113 m .50705 .73644 L .50667 .73484 L F
.50227 .75316 m .50734 .73861 L p .50516 .74113 L F P
0 g
s
.50629 .74649 m .49956 .74816 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.51435 .72337 m .50629 .74649 L p .51078 .72624 L .707 .577 .707 r
F P
0 g
s
.50663 .73435 m .50582 .73021 L .51078 .72624 L .707 .577 .707 r
F
.49956 .74816 m .50568 .73061 L p .50663 .73435 L F P
0 g
s
.50568 .73061 m .50582 .73021 L p .50663 .73435 L .707 .577 .707 r
F P
0 g
s
.50695 .72931 m .50582 .73021 L .50664 .72587 L .707 .577 .707 r
F
.51043 .75029 m .52249 .7583 L p .51686 .74465 L F P
0 g
s
.5193 .7462 m .52672 .72493 L p .51443 .74311 L .707 .577 .707 r
F P
0 g
s
.52249 .7583 m .54283 .76264 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.51964 .74672 m .52249 .7583 L p .53673 .75221 L .707 .577 .707 r
F P
0 g
s
.54659 .73482 m .52672 .72493 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54015 .75331 m .54659 .73482 L p .53075 .75029 L .707 .577 .707 r
F P
0 g
s
.54283 .76264 m .56948 .7629 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.54067 .75383 m .54283 .76264 L p .5662 .75852 L .707 .577 .707 r
F P
0 g
s
.57253 .74581 m .54659 .73482 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.56948 .7629 m .56863 .75944 L p .56309 .75438 L .707 .577 .707 r
F P
0 g
s
.56798 .75885 m .57253 .74581 L p .55262 .75603 L .707 .577 .707 r
F P
0 g
s
.60198 .75682 m .58941 .79288 L .6195 .80283 L p .707 .577 .707 r
F P
0 g
s
.6195 .80283 m .63207 .76678 L .60198 .75682 L p .707 .577 .707 r
F P
0 g
s
.63207 .76678 m .6195 .80283 L .64728 .81075 L p .707 .577 .707 r
F P
0 g
s
.64728 .81075 m .65985 .7747 L .63207 .76678 L p .707 .577 .707 r
F P
0 g
s
.67029 .6758 m .68318 .72828 L .69934 .715 L p .707 .577 .707 r
F P
0 g
s
.69934 .715 m .68644 .66252 L .67029 .6758 L p .707 .577 .707 r
F P
0 g
s
.65985 .7747 m .64728 .81075 L .67003 .81587 L p .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .6826 .77982 L .65985 .7747 L p .707 .577 .707 r
F P
0 g
s
.60058 .85912 m .59735 .84127 L .56666 .84374 L p .707 .577 .707 r
F P
0 g
s
.59735 .84127 m .60058 .85912 L .63198 .85316 L p .707 .577 .707 r
F P
0 g
s
.63198 .85316 m .62875 .83531 L .59735 .84127 L p .707 .577 .707 r
F P
0 g
s
.62875 .83531 m .63198 .85316 L .66102 .84432 L p .707 .577 .707 r
F P
0 g
s
.66102 .84432 m .65779 .82646 L .62875 .83531 L p .707 .577 .707 r
F P
0 g
s
.56666 .84374 m .5699 .86159 L .60058 .85912 L p .707 .577 .707 r
F P
0 g
s
.5699 .86159 m .56666 .84374 L .5397 .8425 L p .707 .577 .707 r
F P
0 g
s
.68644 .66252 m .69934 .715 L .70647 .70229 L p .707 .577 .707 r
F P
0 g
s
.70647 .70229 m .69357 .64981 L .68644 .66252 L p .707 .577 .707 r
F P
0 g
s
.65779 .82646 m .66102 .84432 L .68486 .83344 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .68163 .81559 L .65876 .82602 L p .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .70117 .82161 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68163 .81559 m .68175 .81626 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.68175 .81626 m .68486 .83344 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .69793 .80376 L .68238 .81504 L p .707 .577 .707 r
F P
0 g
s
.68238 .81504 m .68163 .81559 L p .68203 .81572 L .707 .577 .707 r
F P
0 g
s
.70117 .82161 m .68238 .81504 L .68203 .81572 L .707 .577 .707 r
F
.69225 .81601 m .70482 .77995 L .69999 .78116 L p F P
0 g
s
.69999 .78116 m .6981 .78163 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69225 .81601 m .69999 .78116 L .6973 .78633 L .707 .577 .707 r
F
.68553 .81768 m .69225 .81601 L p .6973 .78633 L F P
0 g
s
.6981 .78163 m .69474 .79125 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.69474 .79125 m .68553 .81768 L p .6973 .78633 L .707 .577 .707 r
F P
0 g
s
.67003 .81587 m .68553 .81768 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.6826 .77982 m .67666 .79686 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.67666 .79686 m .67003 .81587 L p .68311 .78635 L .707 .577 .707 r
F P
0 g
s
.65876 .82602 m .65779 .82646 L p .65839 .82662 L .707 .577 .707 r
F P
0 g
s
.68486 .83344 m .65876 .82602 L .65839 .82662 L .707 .577 .707 r
F
.5397 .8425 m .54293 .86035 L .5699 .86159 L p F P
0 g
s
.68553 .81768 m .6981 .78163 L .6826 .77982 L p .707 .577 .707 r
F P
0 g
s
.54293 .86035 m .5397 .8425 L .51909 .83767 L p .707 .577 .707 r
F P
0 g
s
.51909 .83767 m .52233 .85552 L .54293 .86035 L p .707 .577 .707 r
F P
0 g
s
.69357 .64981 m .70647 .70229 L .70388 .6914 L p .705 .576 .708 r
F P
0 g
s
.70388 .6914 m .69098 .63892 L .69357 .64981 L p .705 .576 .708 r
F P
0 g
s
.52233 .85552 m .51909 .83767 L .50686 .82971 L p .707 .577 .707 r
F P
0 g
s
.69793 .80376 m .70117 .82161 L .70834 .80997 L p .707 .577 .707 r
F P
0 g
s
.70834 .80997 m .70511 .79212 L .69793 .80376 L p .707 .577 .707 r
F P
0 g
s
.50686 .82971 m .5101 .84756 L .52233 .85552 L p .707 .577 .707 r
F P
0 g
s
.48764 .82178 m .48764 .31989 L .44383 .31698 L p .707 .577 .707 r
F P
0 g
s
.5101 .84756 m .50686 .82971 L .5042 .8194 L p .707 .578 .707 r
F P
0 g
s
.5042 .8194 m .50744 .83725 L .5101 .84756 L p .707 .578 .707 r
F P
0 g
s
.50744 .83725 m .5042 .8194 L .51138 .80776 L p .707 .577 .707 r
F P
0 g
s
.51138 .80776 m .51461 .82562 L .50744 .83725 L p .707 .577 .707 r
F P
0 g
s
.53435 .71224 m .52178 .7483 L .50629 .74649 L p .707 .577 .707 r
F P
0 g
s
.53112 .7134 m .51822 .66092 L .54182 .64837 L p .707 .577 .707 r
F P
0 g
s
.51461 .82562 m .51138 .80776 L .52768 .79593 L p .707 .577 .707 r
F P
0 g
s
.52178 .7483 m .53435 .71224 L .55711 .71736 L p .707 .577 .707 r
F P
0 g
s
.52768 .79593 m .53092 .81378 L .51461 .82562 L p .707 .577 .707 r
F P
0 g
s
.55711 .71736 m .54453 .75341 L .52178 .7483 L p .707 .577 .707 r
F P
0 g
s
.53092 .81378 m .52768 .79593 L .55152 .78506 L p .707 .577 .707 r
F P
0 g
s
.55152 .78506 m .55476 .80291 L .53092 .81378 L p .707 .577 .707 r
F P
0 g
s
.48764 .31989 m .48764 .82178 L .53266 .82092 L p .707 .577 .707 r
F P
0 g
s
.54182 .64837 m .55472 .70085 L .53112 .7134 L p .707 .577 .707 r
F P
0 g
s
.53266 .82092 m .53266 .31903 L .48764 .31989 L p .707 .577 .707 r
F P
0 g
s
.55472 .70085 m .54182 .64837 L .57055 .63777 L p .707 .577 .707 r
F P
0 g
s
.57055 .63777 m .58345 .69025 L .55472 .70085 L p .707 .577 .707 r
F P
0 g
s
.54453 .75341 m .55711 .71736 L .58489 .72528 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .57231 .76134 L .54453 .75341 L p .707 .577 .707 r
F P
0 g
s
.55476 .80291 m .55152 .78506 L .58056 .77621 L p .707 .577 .707 r
F P
0 g
s
.58056 .77621 m .5838 .79406 L .55476 .80291 L p .707 .577 .707 r
F P
0 g
s
.53266 .31903 m .53266 .82092 L .57447 .81636 L p .707 .577 .707 r
F P
0 g
s
.58345 .69025 m .57055 .63777 L .6016 .63017 L p .707 .577 .707 r
F P
0 g
s
.58489 .72528 m .61498 .73524 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.57231 .76134 m .58036 .73825 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.58036 .73825 m .58489 .72528 L p .57892 .7573 L .707 .577 .707 r
F P
0 g
s
.63193 .62631 m .64483 .67879 L .6145 .68265 L p .707 .577 .707 r
F P
0 g
s
.6145 .68265 m .6016 .63017 L .63193 .62631 L p .707 .577 .707 r
F P
0 g
s
.6016 .63017 m .6145 .68265 L .58345 .69025 L p .707 .577 .707 r
F P
0 g
s
.67036 .75724 m .65779 .79329 L .63186 .7823 L p .707 .577 .707 r
F P
0 g
s
.63186 .7823 m .64443 .74625 L .67036 .75724 L p .707 .577 .707 r
F P
0 g
s
.64443 .74625 m .63186 .7823 L .61088 .77446 L p .707 .577 .707 r
F P
0 g
s
.61088 .77446 m .6024 .77129 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61131 .76598 m .64443 .74625 L .61088 .77446 L .707 .577 .707 r
F
.64483 .67879 m .63193 .62631 L .65857 .62656 L p F P
0 g
s
.65779 .79329 m .66927 .76036 L p .69024 .76713 L .707 .577 .707 r
F P
0 g
s
.64588 .78563 m .64379 .77411 L p .66961 .76902 L .707 .577 .707 r
F P
0 g
s
.64379 .77411 m .64265 .76778 L .65452 .76832 L p .707 .577 .707 r
F P
0 g
s
.65452 .76832 m .66961 .76902 L p .64379 .77411 L .707 .577 .707 r
F P
0 g
s
.66927 .76036 m .67036 .75724 L .67281 .75846 L p .707 .577 .707 r
F P
0 g
s
.67281 .75846 m .69024 .76713 L p .66927 .76036 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .64443 .74625 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.6024 .77129 m .61252 .74227 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.61252 .74227 m .61498 .73524 L p .61131 .76598 L .707 .577 .707 r
F P
0 g
s
.64265 .76778 m .64588 .78563 L .6152 .78811 L p .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .64371 .28465 L .63542 .29362 L p .707 .577 .707 r
F P
0 g
s
.63542 .29362 m .63286 .2964 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.64371 .78653 m .63542 .29362 L .63359 .3295 L .707 .577 .707 r
F
.6152 .78811 m .61196 .77026 L .64265 .76778 L p F P
0 g
s
.63286 .79829 m .64371 .78653 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .2964 m .63286 .34386 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.63286 .34386 m .63286 .79829 L p .63359 .3295 L .707 .577 .707 r
F P
0 g
s
.61498 .73524 m .6024 .77129 L .57231 .76134 L p .707 .577 .707 r
F P
0 g
s
.5838 .79406 m .58056 .77621 L .61196 .77026 L p .707 .577 .707 r
F P
0 g
s
.61196 .77026 m .6152 .78811 L .5838 .79406 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .63286 .79829 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .30668 m .609 .36022 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.609 .36022 m .609 .80857 L p .61059 .33931 L .707 .577 .707 r
F P
0 g
s
.57447 .81636 m .57447 .31448 L .53266 .31903 L p .707 .577 .707 r
F P
0 g
s
.69098 .63892 m .70388 .6914 L .69182 .68339 L p .707 .577 .707 r
F P
0 g
s
.69182 .68339 m .67892 .63091 L .69098 .63892 L p .707 .577 .707 r
F P
0 g
s
.44383 .81887 m .44383 .31698 L .40553 .31058 L p .707 .577 .707 r
F P
0 g
s
.44383 .31698 m .44383 .81887 L .48764 .82178 L p .707 .577 .707 r
F P
0 g
s
.70482 .77995 m .69225 .81601 L .68954 .81101 L p .707 .577 .707 r
F P
0 g
s
.68954 .81101 m .70181 .77583 L p .70482 .77995 L .707 .577 .707 r
F P
0 g
s
.70211 .77496 m .68954 .81101 L .67767 .80318 L p .707 .577 .707 r
F P
0 g
s
.69345 .7917 m .69274 .78779 L p .70245 .78181 L .707 .577 .707 r
F P
0 g
s
.67767 .80318 m .68999 .76786 L p .70211 .77496 L .707 .577 .707 r
F P
0 g
s
.68999 .76786 m .69024 .76713 L .69069 .76742 L p .707 .577 .707 r
F P
0 g
s
.69069 .76742 m .70211 .77496 L p .68999 .76786 L .707 .577 .707 r
F P
0 g
s
.69024 .76713 m .67767 .80318 L .65779 .79329 L p .707 .577 .707 r
F P
0 g
s
.67285 .78687 m .67148 .77934 L p .69022 .77385 L .707 .577 .707 r
F P
0 g
s
.67148 .77934 m .66961 .76902 L .68304 .77217 L p .707 .577 .707 r
F P
0 g
s
.68304 .77217 m .69022 .77385 L p .67148 .77934 L .707 .577 .707 r
F P
0 g
s
.69274 .78779 m .69022 .77385 L .69899 .77956 L p .707 .577 .707 r
F P
0 g
s
.69899 .77956 m .70245 .78181 L p .69274 .78779 L .707 .577 .707 r
F P
0 g
s
.70181 .77583 m .70211 .77496 L .70226 .77523 L p .707 .577 .707 r
F P
0 g
s
.70226 .77523 m .70482 .77995 L p .70181 .77583 L .707 .577 .707 r
F P
0 g
s
.57447 .31448 m .57447 .81636 L .609 .80857 L p .707 .577 .707 r
F P
0 g
s
.609 .80857 m .609 .30668 L .57447 .31448 L p .707 .577 .707 r
F P
0 g
s
.70511 .79212 m .70834 .80997 L .70568 .79966 L p .707 .578 .707 r
F P
0 g
s
.70568 .79966 m .70245 .78181 L .70511 .79212 L p .707 .578 .707 r
F P
0 g
s
.40553 .81247 m .40553 .31058 L .37647 .30131 L p .707 .577 .707 r
F P
0 g
s
.40553 .31058 m .40553 .81247 L .44383 .81887 L p .707 .577 .707 r
F P
0 g
s
.25511 .69095 m .24951 .63358 L .21847 .63628 L p .707 .577 .707 r
F P
0 g
s
.24951 .63358 m .25511 .69095 L .28679 .68773 L p .707 .577 .707 r
F P
0 g
s
.28679 .68773 m .28119 .63036 L .24951 .63358 L p .707 .577 .707 r
F P
0 g
s
.67892 .63091 m .69182 .68339 L .67147 .67904 L p .707 .577 .707 r
F P
0 g
s
.67147 .67904 m .65857 .62656 L .67892 .63091 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21847 .63628 m .22408 .69365 L .25511 .69095 L p .707 .577 .707 r
F P
0 g
s
.28119 .63036 m .28679 .68773 L .31602 .6843 L p .707 .577 .707 r
F P
0 g
s
.31602 .6843 m .31042 .62694 L .28119 .63036 L p .707 .577 .707 r
F P
0 g
s
.22408 .69365 m .21847 .63628 L .19113 .6382 L p .707 .577 .707 r
F P
0 g
s
.19113 .6382 m .19673 .69556 L .22408 .69365 L p .707 .577 .707 r
F P
0 g
s
.63286 .79829 m .63286 .2964 L .609 .30668 L p .707 .577 .707 r
F P
0 g
s
.31042 .62694 m .31602 .6843 L .33994 .681 L p .707 .577 .707 r
F P
0 g
s
.33994 .681 m .33434 .62364 L .31042 .62694 L p .707 .577 .707 r
F P
0 g
s
.70245 .78181 m .70568 .79966 L .69345 .7917 L p .707 .577 .707 r
F P
0 g
s
.19673 .69556 m .19113 .6382 L .17015 .63914 L p .707 .577 .707 r
F P
0 g
s
.65857 .62656 m .67147 .67904 L .64483 .67879 L p .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .25373 .78052 L .23921 .78123 L p .707 .577 .707 r
F P
0 g
s
.23074 .78642 m .23829 .78179 L .22265 .78204 L .707 .577 .707 r
F
.23776 .7813 m .22265 .78204 L p .23829 .78179 L F P
0 g
s
.22265 .78204 m .22404 .80112 L .25512 .7996 L p .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .22265 .78204 L .20359 .78225 L p .707 .577 .707 r
F P
0 g
s
.20359 .78225 m .19529 .78235 L p .19958 .78515 L .707 .577 .707 r
F P
0 g
s
.22404 .80112 m .20359 .78225 L .19958 .78515 L .707 .577 .707 r
F
.23921 .78123 m .23776 .7813 L p .23829 .78179 L F P
0 g
s
.25512 .7996 m .23921 .78123 L .23074 .78642 L .707 .577 .707 r
F
.22085 .7923 m .25181 .79974 L p .22861 .76424 L F P
0 g
s
.22642 .7609 m .22543 .76653 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22543 .76653 m .22085 .7923 L p .22861 .76424 L .707 .577 .707 r
F P
0 g
s
.22085 .7923 m .22493 .76931 L p .19899 .7486 L .707 .577 .707 r
F P
0 g
s
.22493 .76931 m .22642 .7609 L .20627 .75187 L p .707 .577 .707 r
F P
0 g
s
.20627 .75187 m .19899 .7486 L p .22493 .76931 L .707 .577 .707 r
F P
0 g
s
.25512 .7996 m .28688 .79701 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25373 .78052 m .25469 .79373 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.25469 .79373 m .25512 .7996 L p .26544 .78634 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .28642 .79077 L p .25373 .78052 L .707 .577 .707 r
F P
0 g
s
.28642 .79077 m .28548 .77793 L .26788 .77936 L p .707 .577 .707 r
F P
0 g
s
.26788 .77936 m .25373 .78052 L p .28642 .79077 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .25665 .77245 L p .22642 .7609 L .707 .577 .707 r
F P
0 g
s
.25665 .77245 m .25738 .76834 L .24524 .76542 L p .707 .577 .707 r
F P
0 g
s
.24524 .76542 m .22642 .7609 L p .25665 .77245 L .707 .577 .707 r
F P
0 g
s
.28688 .79701 m .3162 .79361 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28548 .77793 m .28675 .79528 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.28675 .79528 m .28688 .79701 L p .29836 .7845 L .707 .577 .707 r
F P
0 g
s
.3162 .79361 m .31555 .78473 L p .28548 .77793 L .707 .577 .707 r
F P
0 g
s
.31555 .78473 m .31481 .77453 L .2978 .7765 L p .707 .577 .707 r
F P
0 g
s
.2978 .7765 m .28548 .77793 L p .31555 .78473 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .28848 .77218 L p .25738 .76834 L .707 .577 .707 r
F P
0 g
s
.28848 .77218 m .28883 .7702 L .28355 .76989 L p .707 .577 .707 r
F P
0 g
s
.28355 .76989 m .25738 .76834 L p .28848 .77218 L .707 .577 .707 r
F P
0 g
s
.31481 .77453 m .3162 .79361 L .3185 .79324 L p .707 .577 .707 r
F P
0 g
s
.3185 .79324 m .34022 .78973 L p .3263 .7814 L .707 .577 .707 r
F P
0 g
s
.3263 .7814 m .31481 .77453 L .3185 .79324 L .707 .577 .707 r
F
.34022 .78973 m .33933 .7775 L p .31481 .77453 L F P
0 g
s
.33933 .7775 m .33883 .77064 L .32719 .77252 L p .707 .577 .707 r
F P
0 g
s
.32719 .77252 m .31481 .77453 L p .33933 .7775 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .3173 .76847 L p .28883 .7702 L .707 .577 .707 r
F P
0 g
s
.3173 .76847 m .31769 .76629 L .3134 .76687 L p .707 .577 .707 r
F P
0 g
s
.3134 .76687 m .28883 .7702 L p .3173 .76847 L .707 .577 .707 r
F P
0 g
s
.33883 .77064 m .34022 .78973 L .35659 .78574 L p .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .3552 .76666 L .35059 .76778 L p .707 .577 .707 r
F P
0 g
s
.35059 .76778 m .33883 .77064 L p .34763 .77813 L .707 .577 .707 r
F P
0 g
s
.35659 .78574 m .35059 .76778 L .34763 .77813 L .707 .577 .707 r
F
.35129 .77462 m .35778 .75772 L p .357 .74534 L F P
0 g
s
.35686 .74322 m .35565 .75007 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.35565 .75007 m .35129 .77462 L p .357 .74534 L .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .35129 .77462 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34113 .75699 m .34066 .75964 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.34066 .75964 m .33556 .78839 L p .34172 .75802 L .707 .577 .707 r
F P
0 g
s
.31211 .79769 m .33556 .78839 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31769 .76629 m .31763 .76659 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.31763 .76659 m .31211 .79769 L p .3178 .76643 L .707 .577 .707 r
F P
0 g
s
.28326 .8016 m .31211 .79769 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28883 .7702 m .28882 .77027 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.28882 .77027 m .28326 .8016 L p .28886 .77024 L .707 .577 .707 r
F P
0 g
s
.25181 .79974 m .28326 .8016 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25738 .76834 m .25703 .77031 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.25703 .77031 m .25181 .79974 L p .25831 .76953 L .707 .577 .707 r
F P
0 g
s
.17015 .63914 m .17575 .69651 L .19673 .69556 L p .707 .577 .707 r
F P
0 g
s
.37647 .8032 m .37647 .30131 L .3595 .29009 L p .707 .577 .707 r
F P
0 g
s
.37647 .30131 m .37647 .8032 L .40553 .81247 L p .707 .577 .707 r
F P
0 g
s
.33434 .62364 m .33994 .681 L .35621 .67816 L p .707 .577 .707 r
F P
0 g
s
.35621 .67816 m .3506 .62079 L .33434 .62364 L p .707 .577 .707 r
F P
0 g
s
.19529 .78235 m .19668 .80143 L .22404 .80112 L p .707 .577 .707 r
F P
0 g
s
.19341 .78 m .19899 .7486 L .17775 .73264 L p .707 .577 .707 r
F P
0 g
s
.19899 .7486 m .19341 .78 L .22085 .7923 L p .707 .577 .707 r
F P
0 g
s
.33556 .78839 m .34113 .75699 L .31769 .76629 L p .707 .577 .707 r
F P
0 g
s
.69022 .77385 m .69345 .7917 L .67285 .78687 L p .707 .577 .707 r
F P
0 g
s
.17575 .69651 m .17015 .63914 L .15759 .63902 L p .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .16319 .69638 L .17575 .69651 L p .707 .577 .707 r
F P
0 g
s
.19668 .80143 m .19529 .78235 L .17432 .78141 L p .707 .577 .707 r
F P
0 g
s
.17432 .78141 m .17572 .80049 L .19668 .80143 L p .707 .577 .707 r
F P
0 g
s
.17218 .76404 m .17775 .73264 L .1648 .7146 L p .707 .577 .707 r
F P
0 g
s
.17775 .73264 m .17218 .76404 L .19341 .78 L p .707 .577 .707 r
F P
0 g
s
.3506 .62079 m .35621 .67816 L .36323 .67605 L p .707 .577 .707 r
F P
0 g
s
.36323 .67605 m .35762 .61868 L .3506 .62079 L p .707 .577 .707 r
F P
0 g
s
.35129 .77462 m .35686 .74322 L .34113 .75699 L p .707 .577 .707 r
F P
0 g
s
.66961 .76902 m .67285 .78687 L .64588 .78563 L p .707 .577 .707 r
F P
0 g
s
.35778 .75772 m .36335 .72632 L .35686 .74322 L p .707 .577 .707 r
F P
0 g
s
.3552 .76666 m .35659 .78574 L .3637 .78205 L p .707 .577 .707 r
F P
0 g
s
.3637 .78205 m .36231 .76297 L .3552 .76666 L p .707 .577 .707 r
F P
0 g
s
.35762 .61868 m .36323 .67605 L .36031 .67487 L p .707 .577 .707 r
F P
0 g
s
.36031 .67487 m .35471 .6175 L .35762 .61868 L p .707 .577 .707 r
F P
0 g
s
.36335 .72632 m .35778 .75772 L .35438 .73934 L p .707 .577 .707 r
F P
0 g
s
.35438 .73934 m .35995 .70794 L .36335 .72632 L p .707 .577 .707 r
F P
0 g
s
.36086 .77901 m .35947 .75993 L .36231 .76297 L p .707 .577 .707 r
F P
0 g
s
.35471 .6175 m .36031 .67487 L .34775 .67475 L p .707 .577 .707 r
F P
0 g
s
.35995 .70794 m .35438 .73934 L .34143 .72129 L p .707 .577 .707 r
F P
0 g
s
.34143 .72129 m .347 .6899 L .35995 .70794 L p .707 .577 .707 r
F P
0 g
s
.35947 .75993 m .36086 .77901 L .34835 .77692 L p .707 .577 .707 r
F P
0 g
s
.34835 .77692 m .34695 .75784 L .35947 .75993 L p .707 .577 .707 r
F P
0 g
s
.3595 .79198 m .3595 .29009 L .35628 .27801 L p .707 .577 .707 r
F P
0 g
s
.36231 .76297 m .3637 .78205 L .36086 .77901 L p .707 .577 .707 r
F P
0 g
s
.3595 .29009 m .3595 .79198 L .37647 .8032 L p .707 .577 .707 r
F P
0 g
s
.17572 .80049 m .17432 .78141 L .16181 .77932 L p .707 .577 .707 r
F P
0 g
s
.16319 .69638 m .16195 .68365 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.15468 .63784 m .16028 .69521 L .16319 .69638 L p .707 .577 .707 r
F P
0 g
s
.15923 .74599 m .1648 .7146 L .1614 .69622 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .15583 .72762 L .15923 .74599 L p .707 .577 .707 r
F P
0 g
s
.1614 .69622 m .16789 .67932 L p .16458 .69256 L .707 .577 .707 r
F P
0 g
s
.15759 .63902 m .15468 .63784 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.16195 .68365 m .15759 .63902 L p .16176 .68653 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16387 .69413 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16789 .67932 L p .16935 .68853 L .707 .577 .707 r
F P
0 g
s
.1673 .69309 m .16701 .69015 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.16615 .68913 m .16935 .68853 L .16701 .69015 L .707 .577 .707 r
F
.18356 .69025 m .1673 .69309 L p .16793 .68951 L F P
0 g
s
.16789 .67932 m .18362 .66555 L p .17445 .68499 L .707 .577 .707 r
F P
0 g
s
.16935 .68853 m .16789 .67932 L .17445 .68499 L .707 .577 .707 r
F
.16793 .68951 m .18097 .68047 L .18356 .69025 L F
.18097 .68047 m .18362 .66555 L p .18679 .67984 L F P
0 g
s
.18356 .69025 m .18268 .68126 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.18097 .68047 m .18679 .67984 L .18268 .68126 L .707 .577 .707 r
F
.20748 .68695 m .18356 .69025 L p .18669 .67988 L F P
0 g
s
.18362 .66555 m .20706 .65625 L p .19137 .67826 L .707 .577 .707 r
F P
0 g
s
.18679 .67984 m .18362 .66555 L .19137 .67826 L .707 .577 .707 r
F
.20706 .65625 m .23592 .65234 L p .21559 .67319 L F P
0 g
s
.21125 .67395 m .20706 .65625 L .21559 .67319 L .707 .577 .707 r
F
.20188 .62959 m .23111 .62616 L p .21263 .67371 L F P
0 g
s
.20748 .68695 m .2063 .67481 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20393 .67393 m .20706 .65625 L p .21125 .67395 L .707 .577 .707 r
F P
0 g
s
.23671 .68353 m .20748 .68695 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .21125 .67395 L .21196 .67692 L .707 .577 .707 r
F
.20393 .67393 m .21125 .67395 L .2063 .67481 L F
.23592 .65234 m .26737 .6542 L p .24667 .67071 L F P
0 g
s
.24136 .67103 m .23592 .65234 L .24667 .67071 L .707 .577 .707 r
F
.23111 .62616 m .26279 .62294 L p .24211 .67098 L F P
0 g
s
.23671 .68353 m .23553 .67137 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23275 .6702 m .23592 .65234 L p .24136 .67103 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .23671 .68353 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .24136 .67103 L .24229 .67421 L .707 .577 .707 r
F
.23275 .6702 m .24136 .67103 L .23553 .67137 L F
.29943 .6776 m .2684 .6803 L p .27215 .67144 L F P
0 g
s
.26737 .6542 m .29832 .66164 L p .2828 .67182 L .707 .577 .707 r
F P
0 g
s
.27436 .67152 m .26737 .6542 L .2828 .67182 L .707 .577 .707 r
F
.27215 .67144 m .29643 .67231 L .29943 .6776 L F
.29643 .67231 m .29832 .66164 L p .30537 .67535 L F P
0 g
s
.31496 .67652 m .29943 .6776 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29643 .67231 m .30537 .67535 L .29913 .6746 L .707 .577 .707 r
F
.29832 .66164 m .32576 .67394 L p .32021 .67715 L F P
0 g
s
.30537 .67535 m .29832 .66164 L .32021 .67715 L .707 .577 .707 r
F
.29383 .62024 m .32117 .61832 L p .30047 .67476 L F P
0 g
s
.29943 .6776 m .29913 .6746 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29832 .66164 m .29609 .67423 L p .26179 .6856 L .707 .577 .707 r
F P
0 g
s
.29609 .67423 m .29275 .69304 L .27401 .68853 L p .707 .577 .707 r
F P
0 g
s
.27401 .68853 m .26179 .6856 L p .29609 .67423 L .707 .577 .707 r
F P
0 g
s
.29913 .6746 m .29892 .6724 L p .30047 .67476 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .29383 .62024 L p .30009 .67164 L .707 .577 .707 r
F P
0 g
s
.29892 .6724 m .30009 .67164 L .30047 .67476 L .707 .577 .707 r
F
.30948 .68336 m .30537 .67535 L .32021 .67715 L F
.29913 .6746 m .30537 .67535 L .30948 .68336 L F
.32576 .67394 m .347 .6899 L p .33636 .69603 L F P
0 g
s
.32019 .70534 m .32509 .67774 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32509 .67774 m .32576 .67394 L p .33636 .69603 L .707 .577 .707 r
F P
0 g
s
.32576 .67394 m .32019 .70534 L .29275 .69304 L p .707 .577 .707 r
F P
0 g
s
.32117 .61832 m .32677 .67569 L .32394 .67589 L p .707 .577 .707 r
F P
0 g
s
.32394 .67589 m .31496 .67652 L p .31635 .66356 L .707 .577 .707 r
F P
0 g
s
.31635 .66356 m .32117 .61832 L .32394 .67589 L .707 .577 .707 r
F
.30047 .67476 m .32117 .61832 L .31496 .67652 L F
.29892 .6724 m .29913 .6746 L p .29643 .67231 L F P
0 g
s
.29913 .6746 m .29943 .6776 L p .29643 .67231 L .707 .577 .707 r
F P
0 g
s
.29275 .69304 m .29643 .67231 L p .30948 .68336 L .707 .577 .707 r
F P
0 g
s
.26462 .66966 m .26737 .6542 L p .27436 .67152 L .707 .577 .707 r
F P
0 g
s
.2684 .6803 m .26751 .67127 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .27436 .67152 L .27622 .67614 L .707 .577 .707 r
F
.26462 .66966 m .27436 .67152 L .26751 .67127 L F
.26279 .62294 m .29383 .62024 L p .27215 .67144 L F P
0 g
s
.26734 .6695 m .2684 .6803 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .23275 .6702 L .23671 .68353 L .707 .577 .707 r
F
.23537 .66975 m .23553 .67137 L p .23275 .6702 L F P
0 g
s
.23553 .67137 m .23671 .68353 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.26737 .6542 m .26436 .67116 L p .24875 .67693 L .707 .577 .707 r
F P
0 g
s
.23035 .68374 m .24229 .67421 L .24875 .67693 L .707 .577 .707 r
F
.24229 .67421 m .26737 .6542 L .24875 .67693 L F
.26436 .67116 m .26179 .6856 L .24067 .68435 L p F P
0 g
s
.24067 .68435 m .23035 .68374 L p .26436 .67116 L .707 .577 .707 r
F P
0 g
s
.26751 .67127 m .26734 .6695 L p .27215 .67144 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .26279 .62294 L p .27134 .66727 L .707 .577 .707 r
F P
0 g
s
.26734 .6695 m .27134 .66727 L .27215 .67144 L .707 .577 .707 r
F
.29383 .62024 m .29892 .6724 L p .27215 .67144 L F P
0 g
s
.27622 .67614 m .27436 .67152 L .2828 .67182 L .707 .577 .707 r
F
.26179 .6856 m .26462 .66966 L p .27622 .67614 L F P
0 g
s
.26279 .62294 m .26734 .6695 L p .26462 .66966 L .707 .577 .707 r
F P
0 g
s
.24211 .67098 m .24694 .65978 L .26462 .66966 L .707 .577 .707 r
F
.24694 .65978 m .26279 .62294 L .26462 .66966 L F
.18669 .67988 m .20393 .67393 L .20748 .68695 L F
.20614 .67316 m .2063 .67481 L p .20393 .67393 L F P
0 g
s
.2063 .67481 m .20748 .68695 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.23592 .65234 m .23251 .67155 L p .2179 .67913 L .707 .577 .707 r
F P
0 g
s
.20149 .68765 m .21196 .67692 L .2179 .67913 L .707 .577 .707 r
F
.21196 .67692 m .23592 .65234 L .2179 .67913 L F
.23251 .67155 m .23035 .68374 L .20848 .6867 L p F P
0 g
s
.20848 .6867 m .20149 .68765 L p .23251 .67155 L .707 .577 .707 r
F P
0 g
s
.23553 .67137 m .23537 .66975 L p .24211 .67098 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .23111 .62616 L p .24095 .66623 L .707 .577 .707 r
F P
0 g
s
.23537 .66975 m .24095 .66623 L .24211 .67098 L .707 .577 .707 r
F
.24229 .67421 m .24136 .67103 L .24667 .67071 L F
.23035 .68374 m .23275 .6702 L p .24229 .67421 L F P
0 g
s
.23111 .62616 m .23537 .66975 L p .23275 .6702 L .707 .577 .707 r
F P
0 g
s
.21263 .67371 m .21663 .66342 L .23275 .6702 L .707 .577 .707 r
F
.21663 .66342 m .23111 .62616 L .23275 .6702 L F
.18268 .68126 m .18356 .69025 L p .18097 .68047 L F P
0 g
s
.20706 .65625 m .20369 .67526 L p .17805 .69695 L .707 .577 .707 r
F P
0 g
s
.20369 .67526 m .20149 .68765 L .17875 .69667 L p .707 .577 .707 r
F P
0 g
s
.17875 .69667 m .17805 .69695 L p .20369 .67526 L .707 .577 .707 r
F P
0 g
s
.2063 .67481 m .20614 .67316 L p .21263 .67371 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .20188 .62959 L p .2114 .66865 L .707 .577 .707 r
F P
0 g
s
.20614 .67316 m .2114 .66865 L .21263 .67371 L .707 .577 .707 r
F
.21196 .67692 m .21125 .67395 L .21559 .67319 L F
.20149 .68765 m .20393 .67393 L p .21196 .67692 L F P
0 g
s
.20188 .62959 m .20614 .67316 L p .20393 .67393 L .707 .577 .707 r
F P
0 g
s
.18669 .67988 m .19005 .66876 L .20393 .67393 L .707 .577 .707 r
F
.19005 .66876 m .20188 .62959 L .20393 .67393 L F
.18761 .68354 m .18679 .67984 L .19137 .67826 L F
.18268 .68126 m .18679 .67984 L .18761 .68354 L F
.17796 .63288 m .20188 .62959 L p .18669 .67988 L F P
0 g
s
.17805 .69695 m .16231 .71072 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18362 .66555 m .18071 .68194 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18071 .68194 m .17805 .69695 L p .16623 .70243 L .707 .577 .707 r
F P
0 g
s
.18268 .68126 m .1825 .67941 L p .18669 .67988 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .17796 .63288 L p .18575 .67481 L .707 .577 .707 r
F P
0 g
s
.1825 .67941 m .18575 .67481 L .18669 .67988 L .707 .577 .707 r
F
.1825 .67941 m .18268 .68126 L p .18097 .68047 L F P
0 g
s
.17805 .69695 m .18097 .68047 L p .18761 .68354 L .707 .577 .707 r
F P
0 g
s
.17796 .63288 m .1825 .67941 L p .16793 .68951 L .707 .577 .707 r
F P
0 g
s
.17022 .69396 m .16935 .68853 L .17445 .68499 L .707 .577 .707 r
F
.16701 .69015 m .16935 .68853 L .17022 .69396 L F
.16231 .71072 m .15583 .72762 L p .16049 .70895 L F P
0 g
s
.16789 .67932 m .16582 .69098 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.16582 .69098 m .16231 .71072 L p .16049 .70895 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .17796 .63288 L p .17042 .67544 L .707 .577 .707 r
F P
0 g
s
.16793 .68951 m .16746 .68544 L .17042 .67544 L .707 .577 .707 r
F
.16746 .68544 m .1617 .63573 L .17042 .67544 L F
.16701 .69015 m .1617 .63573 L p .16793 .68951 L F P
0 g
s
.16678 .68775 m .16701 .69015 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16701 .69015 m .1673 .69309 L p .16615 .68913 L .707 .577 .707 r
F P
0 g
s
.16231 .71072 m .16615 .68913 L p .17022 .69396 L .707 .577 .707 r
F P
0 g
s
.1617 .63573 m .16678 .68775 L p .16028 .69521 L .707 .577 .707 r
F P
0 g
s
.16105 .7003 m .1614 .69622 L .16458 .69256 L .707 .577 .707 r
F
.16387 .69413 m .16028 .69521 L p .16678 .68775 L F P
0 g
s
.16022 .71004 m .16105 .7003 L .16458 .69256 L .707 .577 .707 r
F
.15583 .72762 m .16096 .69871 L p .16022 .71004 L F P
0 g
s
.16096 .69871 m .1614 .69622 L p .16022 .71004 L .707 .577 .707 r
F P
0 g
s
.1648 .7146 m .15923 .74599 L .17218 .76404 L p .707 .577 .707 r
F P
0 g
s
.16181 .77932 m .16321 .7984 L .17572 .80049 L p .707 .577 .707 r
F P
0 g
s
.64371 .28465 m .64371 .78653 L .6405 .77446 L p .707 .577 .707 r
F P
0 g
s
.6405 .77446 m .6405 .27257 L .64371 .28465 L p .707 .577 .707 r
F P
0 g
s
.16321 .7984 m .16181 .77932 L .15897 .77627 L p .707 .577 .707 r
F P
0 g
s
.15897 .77627 m .16037 .79536 L .16321 .7984 L p .707 .577 .707 r
F P
0 g
s
.16028 .69521 m .15468 .63784 L .1617 .63573 L p .707 .577 .707 r
F P
0 g
s
.35628 .27801 m .35628 .7799 L .3595 .79198 L p .707 .577 .707 r
F P
0 g
s
.35628 .7799 m .35628 .27801 L .36714 .26626 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34775 .67475 m .34215 .61738 L .35471 .6175 L p .707 .577 .707 r
F P
0 g
s
.6405 .27257 m .6405 .77446 L .62353 .76323 L p .707 .577 .707 r
F P
0 g
s
.62353 .76323 m .62353 .26135 L .6405 .27257 L p .707 .577 .707 r
F P
0 g
s
.16037 .79536 m .15897 .77627 L .16608 .77258 L p .707 .577 .707 r
F P
0 g
s
.16608 .77258 m .16748 .79166 L .16037 .79536 L p .707 .577 .707 r
F P
0 g
s
.34215 .61738 m .34775 .67475 L .32677 .67569 L p .707 .577 .707 r
F P
0 g
s
.32677 .67569 m .32117 .61832 L .34215 .61738 L p .707 .577 .707 r
F P
0 g
s
.36714 .76815 m .36714 .26626 L .391 .25598 L p .707 .577 .707 r
F P
0 g
s
.36714 .26626 m .36714 .76815 L .35628 .7799 L p .707 .577 .707 r
F P
0 g
s
.347 .6899 m .34143 .72129 L .32019 .70534 L p .707 .577 .707 r
F P
0 g
s
.16748 .79166 m .16608 .77258 L .18245 .7686 L p .707 .577 .707 r
F P
0 g
s
.18245 .7686 m .18385 .78768 L .16748 .79166 L p .707 .577 .707 r
F P
0 g
s
.62353 .26135 m .62353 .76323 L .59447 .75397 L p .707 .577 .707 r
F P
0 g
s
.59447 .75397 m .59447 .25208 L .62353 .26135 L p .707 .577 .707 r
F P
0 g
s
.34695 .75784 m .34835 .77692 L .32739 .77598 L p .707 .577 .707 r
F P
0 g
s
.32739 .77598 m .32599 .7569 L .34695 .75784 L p .707 .577 .707 r
F P
0 g
s
.7372 .62575 m .70617 .61972 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73266 .66671 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .7372 .62575 L p .72865 .66425 L .707 .577 .707 r
F P
0 g
s
.73266 .66671 m .72865 .66425 L .72785 .66788 L .707 .577 .707 r
F
.75125 .67453 m .75333 .66679 L .73564 .66854 L F
.76965 .68161 m .75771 .67077 L .75125 .67453 L F
.75771 .67077 m .75333 .66679 L .75125 .67453 L F
.76889 .62707 m .76463 .66541 L p .78337 .65584 L F P
0 g
s
.76463 .66541 m .76447 .66684 L p .76725 .66522 L .707 .577 .707 r
F P
0 g
s
.78337 .65584 m .76463 .66541 L .76725 .66522 L .707 .577 .707 r
F
.76972 .6816 m .79851 .67814 L p .78804 .66764 L F P
0 g
s
.79812 .62355 m .79386 .66189 L p .80995 .65097 L .707 .577 .707 r
F P
0 g
s
.79386 .66189 m .7937 .66333 L p .79607 .66153 L .707 .577 .707 r
F P
0 g
s
.80995 .65097 m .79386 .66189 L .79607 .66153 L .707 .577 .707 r
F
.79851 .67814 m .82195 .67594 L p .80863 .6595 L F P
0 g
s
.79607 .66153 m .79851 .67814 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78875 .66369 L .78441 .664 L .707 .577 .707 r
F
.79851 .67814 m .79631 .66315 L p .78804 .66764 L F P
0 g
s
.79631 .66315 m .79607 .66153 L p .7937 .66333 L .707 .577 .707 r
F P
0 g
s
.79631 .66315 m .7937 .66333 L .78804 .66764 L .707 .577 .707 r
F
.79812 .62355 m .76889 .62707 L p .78737 .66379 L F P
0 g
s
.7937 .66333 m .79812 .62355 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.79607 .66153 m .79293 .64014 L p .78804 .66764 L .707 .577 .707 r
F P
0 g
s
.79252 .67402 m .7937 .66333 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.76965 .68161 m .76972 .6816 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78804 .66764 m .78441 .664 L .76972 .6816 L .707 .577 .707 r
F
.76725 .66522 m .76965 .68161 L p .78441 .664 L F P
0 g
s
.7372 .62575 m .73266 .66671 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .75306 .65723 L .73537 .66672 L .707 .577 .707 r
F
.75306 .65723 m .7372 .62575 L .73537 .66672 L F
.7382 .68601 m .73564 .66854 L p .73248 .66827 L F P
0 g
s
.72378 .67294 m .73248 .66827 L .7172 .66697 L .707 .577 .707 r
F
.7382 .68601 m .73248 .66827 L .72378 .67294 L F
.73564 .66854 m .73537 .66672 L p .73248 .66827 L F P
0 g
s
.76889 .62707 m .7372 .62575 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.76408 .64361 m .73263 .64801 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.75771 .67077 m .75864 .66681 L .75333 .66679 L .707 .577 .707 r
F
.76447 .66684 m .76889 .62707 L p .75789 .66681 L F P
0 g
s
.75864 .66681 m .76408 .64361 L .75333 .66679 L .707 .577 .707 r
F
.76965 .68161 m .76725 .66522 L p .75771 .67077 L F P
0 g
s
.76725 .66522 m .76408 .64361 L p .75771 .67077 L .707 .577 .707 r
F P
0 g
s
.76328 .67753 m .76447 .66684 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73537 .66672 m .73564 .66854 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73564 .66854 m .7382 .68601 L .75932 .68305 L p .707 .577 .707 r
F P
0 g
s
.75932 .68305 m .76965 .68161 L p .73564 .66854 L .707 .577 .707 r
F P
0 g
s
.75789 .66681 m .73537 .66672 L .7316 .67621 L .707 .577 .707 r
F
.73266 .66671 m .73248 .66827 L p .73537 .66672 L F P
0 g
s
.73248 .66827 m .7316 .67621 L p .73537 .66672 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .7382 .68601 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70725 .69091 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.70617 .61972 m .67883 .60958 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70725 .69091 m .70391 .66814 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70357 .66582 L p .70086 .66754 L .707 .577 .707 r
F P
0 g
s
.70391 .66814 m .70086 .66754 L .69052 .67415 L .707 .577 .707 r
F
.67883 .60958 m .67323 .66005 L .67605 .6611 L p F P
0 g
s
.67323 .66005 m .67883 .60958 L .65785 .59631 L p .707 .577 .707 r
F P
0 g
s
.65785 .59631 m .65225 .64678 L .67323 .66005 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .653 .66229 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67981 .69583 m .67491 .66243 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67491 .66243 m .67423 .65783 L p .66364 .6756 L .707 .577 .707 r
F P
0 g
s
.67605 .6611 m .68503 .66443 L p .68365 .65222 L .707 .577 .707 r
F P
0 g
s
.68365 .65222 m .67883 .60958 L .67605 .6611 L .707 .577 .707 r
F
.69052 .67415 m .69463 .66632 L .67978 .66339 L F
.69953 .66728 m .67883 .60958 L .68503 .66443 L F
.70086 .66754 m .70617 .61972 L p .69953 .66728 L F P
0 g
s
.70617 .61972 m .70108 .66561 L p .70357 .66582 L .707 .577 .707 r
F P
0 g
s
.70108 .66561 m .70057 .67019 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.70357 .66582 m .70167 .65291 L p .69052 .67415 L .707 .577 .707 r
F P
0 g
s
.68503 .66443 m .70057 .67019 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70057 .67019 m .70086 .66754 L p .69953 .66728 L .707 .577 .707 r
F P
0 g
s
.70167 .65291 m .67423 .65783 L p .67978 .66339 L .707 .577 .707 r
F P
0 g
s
.69463 .66632 m .70167 .65291 L .67978 .66339 L .707 .577 .707 r
F
.72785 .66788 m .72171 .65423 L .70357 .66582 L F
.72171 .65423 m .70617 .61972 L .70357 .66582 L F
.70057 .67019 m .7316 .67621 L p .72785 .66788 L F P
0 g
s
.70167 .65291 m .70357 .66582 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.73248 .66827 m .73263 .64801 L .7172 .66697 L .707 .577 .707 r
F
.73537 .66672 m .73263 .64801 L p .73248 .66827 L F P
0 g
s
.76328 .67753 m .79252 .67402 L p .78737 .66379 L .707 .577 .707 r
F P
0 g
s
.78737 .66379 m .78337 .65584 L .77521 .66466 L .707 .577 .707 r
F
.78737 .66379 m .77521 .66466 L .76328 .67753 L F
.76447 .66684 m .76328 .67753 L p .78337 .65584 L F P
0 g
s
.79293 .64014 m .76408 .64361 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.78875 .66369 m .79293 .64014 L .78441 .664 L .707 .577 .707 r
F
.8133 .65875 m .80995 .65097 L .80278 .66045 L F
.7937 .66333 m .79252 .67402 L p .80995 .65097 L F P
0 g
s
.82195 .67594 m .81929 .65778 L p .81731 .6581 L .707 .577 .707 r
F P
0 g
s
.81239 .66415 m .81731 .6581 L .80863 .6595 L .707 .577 .707 r
F
.82195 .67594 m .81731 .6581 L .81239 .66415 L F
.82195 .67594 m .83768 .67523 L p .82555 .65399 L F P
0 g
s
.83207 .65199 m .8296 .64302 L .82284 .65483 L .707 .577 .707 r
F
.82204 .61554 m .81749 .65647 L p .8296 .64302 L F P
0 g
s
.81749 .65647 m .81731 .6581 L p .81903 .656 L .707 .577 .707 r
F P
0 g
s
.8296 .64302 m .81749 .65647 L .81903 .656 L .707 .577 .707 r
F
.81903 .656 m .82195 .67594 L p .82555 .65399 L F P
0 g
s
.82204 .61554 m .79812 .62355 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .81731 .6581 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .82204 .61554 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.81929 .65778 m .81638 .63795 L p .80863 .6595 L .707 .577 .707 r
F P
0 g
s
.81731 .6581 m .81644 .66601 L p .8296 .64302 L .707 .577 .707 r
F P
0 g
s
.83768 .67523 m .83418 .65134 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.82978 .6614 m .83299 .6517 L .82555 .65399 L .707 .577 .707 r
F
.83768 .67523 m .83299 .6517 L .82978 .6614 L F
.8383 .60383 m .83322 .64959 L p .83942 .6323 L F P
0 g
s
.83322 .64959 m .83299 .6517 L p .83385 .6491 L .707 .577 .707 r
F P
0 g
s
.83942 .6323 m .83322 .64959 L .83385 .6491 L .707 .577 .707 r
F
.83768 .67523 m .84417 .67608 L p .83542 .64788 L F P
0 g
s
.83385 .6491 m .83768 .67523 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8383 .60383 m .82204 .61554 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83299 .6517 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .8383 .60383 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83299 .6517 m .83211 .63724 L .82555 .65399 L .707 .577 .707 r
F
.83418 .65134 m .83385 .6491 L p .83299 .6517 L F P
0 g
s
.83385 .6491 m .83211 .63724 L p .83299 .6517 L .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .83942 .6323 L .83442 .64865 L .707 .577 .707 r
F
.83613 .64732 m .83972 .64002 L p .83442 .64865 L F P
0 g
s
.83299 .6517 m .8327 .65429 L p .83942 .6323 L .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .83211 .63724 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.84417 .67608 m .83956 .64464 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83956 .64464 m .8386 .63808 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.8327 .65429 m .83613 .64732 L p .83442 .64865 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .83385 .6491 L p .83542 .64788 L .707 .577 .707 r
F P
0 g
s
.83211 .63724 m .81638 .63795 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81638 .63795 m .81903 .656 L p .82555 .65399 L .707 .577 .707 r
F P
0 g
s
.81644 .66601 m .8327 .65429 L p .83207 .65199 L .707 .577 .707 r
F P
0 g
s
.83207 .65199 m .82284 .65483 L .81644 .66601 L .707 .577 .707 r
F
.81638 .63795 m .79293 .64014 L p .80863 .6595 L F P
0 g
s
.79252 .67402 m .81644 .66601 L p .8133 .65875 L .707 .577 .707 r
F P
0 g
s
.8133 .65875 m .80278 .66045 L .79252 .67402 L .707 .577 .707 r
F
.79293 .64014 m .79607 .66153 L p .80863 .6595 L F P
0 g
s
.76408 .64361 m .76725 .66522 L p .78441 .664 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .76328 .67753 L p .75789 .66681 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .73537 .66672 L p .75333 .66679 L .707 .577 .707 r
F P
0 g
s
.73263 .64801 m .70167 .65291 L p .7172 .66697 L .707 .577 .707 r
F P
0 g
s
.7316 .67621 m .73248 .66827 L p .72785 .66788 L .707 .577 .707 r
F P
0 g
s
.391 .25598 m .391 .75787 L .36714 .76815 L p .707 .577 .707 r
F P
0 g
s
.391 .75787 m .391 .25598 L .42552 .24818 L p .707 .577 .707 r
F P
0 g
s
.18385 .78768 m .18245 .7686 L .20647 .76472 L p .707 .577 .707 r
F P
0 g
s
.20647 .76472 m .20787 .7838 L .18385 .78768 L p .707 .577 .707 r
F P
0 g
s
.32599 .7569 m .32739 .77598 L .30003 .77629 L p .707 .577 .707 r
F P
0 g
s
.30003 .77629 m .29863 .75721 L .32599 .7569 L p .707 .577 .707 r
F P
0 g
s
.59447 .25208 m .59447 .75397 L .55616 .74757 L p .707 .577 .707 r
F P
0 g
s
.55616 .74757 m .55616 .24568 L .59447 .25208 L p .707 .577 .707 r
F P
0 g
s
.20787 .7838 m .20647 .76472 L .2358 .76132 L p .707 .577 .707 r
F P
0 g
s
.2358 .76132 m .23719 .7804 L .20787 .7838 L p .707 .577 .707 r
F P
0 g
s
.67423 .65783 m .67981 .69583 L .70725 .69091 L p .707 .577 .707 r
F P
0 g
s
.42552 .75007 m .42552 .24818 L .46734 .24363 L p .707 .577 .707 r
F P
0 g
s
.42552 .24818 m .42552 .75007 L .391 .75787 L p .707 .577 .707 r
F P
0 g
s
.29863 .75721 m .30003 .77629 L .26895 .77781 L p .707 .577 .707 r
F P
0 g
s
.26895 .77781 m .26755 .75873 L .29863 .75721 L p .707 .577 .707 r
F P
0 g
s
.23719 .7804 m .2358 .76132 L .26755 .75873 L p .707 .577 .707 r
F P
0 g
s
.55616 .24568 m .55616 .74757 L .51236 .74466 L p .707 .577 .707 r
F P
0 g
s
.51236 .74466 m .51236 .24277 L .55616 .24568 L p .707 .577 .707 r
F P
0 g
s
.26755 .75873 m .26895 .77781 L .23719 .7804 L p .707 .577 .707 r
F P
0 g
s
.65225 .64678 m .65785 .59631 L .64529 .58122 L p .707 .577 .707 r
F P
0 g
s
.653 .66229 m .65857 .70029 L .67981 .69583 L p .707 .577 .707 r
F P
0 g
s
.46734 .74552 m .46734 .24363 L .51236 .24277 L p .707 .577 .707 r
F P
0 g
s
.46734 .24363 m .46734 .74552 L .42552 .75007 L p .707 .577 .707 r
F P
0 g
s
.73105 .77388 m .73245 .75653 L .70137 .75144 L p .707 .577 .707 r
F P
0 g
s
.73245 .75653 m .73105 .77388 L .76281 .77475 L p .707 .577 .707 r
F P
0 g
s
.76281 .77475 m .7642 .7574 L .73245 .75653 L p .707 .577 .707 r
F P
0 g
s
.51236 .24277 m .51236 .74466 L .46734 .74552 L p .707 .577 .707 r
F P
0 g
s
.7642 .7574 m .76281 .77475 L .79213 .77132 L p .707 .577 .707 r
F P
0 g
s
.79213 .77132 m .79353 .75398 L .7642 .7574 L p .707 .577 .707 r
F P
0 g
s
.69997 .76879 m .70137 .75144 L .67401 .74263 L p .707 .577 .707 r
F P
0 g
s
.70137 .75144 m .69997 .76879 L .73105 .77388 L p .707 .577 .707 r
F P
0 g
s
.67401 .74263 m .67261 .75998 L .69997 .76879 L p .707 .577 .707 r
F P
0 g
s
.83972 .64002 m .84532 .58955 L .8383 .60383 L p .707 .577 .707 r
F P
0 g
s
.79353 .75398 m .79213 .77132 L .81615 .76393 L p .707 .577 .707 r
F P
0 g
s
.81615 .76393 m .81755 .74658 L .79353 .75398 L p .707 .577 .707 r
F P
0 g
s
.63969 .63169 m .64529 .58122 L .64237 .56578 L p .707 .577 .707 r
F P
0 g
s
.64529 .58122 m .63969 .63169 L .65225 .64678 L p .707 .577 .707 r
F P
0 g
s
.67261 .75998 m .67401 .74263 L .65304 .73097 L p .707 .577 .707 r
F P
0 g
s
.64005 .66586 m .64562 .70385 L .65857 .70029 L p .707 .577 .707 r
F P
0 g
s
.65857 .70029 m .653 .66229 L .64005 .66586 L p .707 .577 .707 r
F P
0 g
s
.65304 .73097 m .65165 .74831 L .67261 .75998 L p .707 .577 .707 r
F P
0 g
s
.81755 .74658 m .81615 .76393 L .83252 .75329 L p .707 .577 .707 r
F P
0 g
s
.83252 .75329 m .83392 .73595 L .81755 .74658 L p .707 .577 .707 r
F P
0 g
s
.65165 .74831 m .65304 .73097 L .64053 .71759 L p .707 .577 .707 r
F P
0 g
s
.84532 .58955 m .83972 .64002 L .83681 .62458 L p .707 .577 .707 r
F P
0 g
s
.83681 .62458 m .84241 .57411 L .84532 .58955 L p .707 .577 .707 r
F P
0 g
s
.64237 .56578 m .63677 .61625 L .63969 .63169 L p .707 .577 .707 r
F P
0 g
s
.63677 .61625 m .64237 .56578 L .64939 .55151 L p .707 .577 .707 r
F P
0 g
s
.64053 .71759 m .63913 .73494 L .65165 .74831 L p .707 .577 .707 r
F P
0 g
s
.63665 .66818 m .64222 .70617 L .64562 .70385 L p .707 .577 .707 r
F P
0 g
s
.64562 .70385 m .64005 .66586 L .63665 .66818 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83392 .73595 m .83252 .75329 L .83963 .74045 L p .707 .577 .707 r
F P
0 g
s
.83963 .74045 m .84103 .72311 L .83392 .73595 L p .707 .577 .707 r
F P
0 g
s
.63913 .73494 m .64053 .71759 L .63769 .70381 L p .707 .577 .707 r
F P
0 g
s
.84241 .57411 m .83681 .62458 L .82425 .60949 L p .707 .577 .707 r
F P
0 g
s
.82425 .60949 m .82985 .55902 L .84241 .57411 L p .707 .577 .707 r
F P
0 g
s
.64939 .55151 m .64379 .60197 L .63677 .61625 L p .707 .577 .707 r
F P
0 g
s
.64379 .60197 m .64939 .55151 L .66566 .53979 L p .707 .577 .707 r
F P
0 g
s
.8386 .63808 m .84417 .67608 L .84077 .6784 L p .707 .577 .707 r
F P
0 g
s
.63769 .70381 m .63629 .72115 L .63913 .73494 L p .707 .577 .707 r
F P
0 g
s
.84077 .6784 m .8352 .6404 L .8386 .63808 L p .707 .577 .707 r
F P
0 g
s
.64314 .66902 m .64871 .70702 L .64222 .70617 L p .707 .577 .707 r
F P
0 g
s
.64222 .70617 m .63665 .66818 L .64314 .66902 L p .707 .577 .707 r
F P
0 g
s
.3855 .60908 m .3984 .55371 L .36807 .54558 L p .707 .577 .707 r
F P
0 g
s
.3984 .55371 m .3855 .60908 L .41655 .61563 L p .707 .577 .707 r
F P
0 g
s
.41655 .61563 m .42945 .56026 L .3984 .55371 L p .707 .577 .707 r
F P
0 g
s
.84103 .72311 m .83963 .74045 L .83679 .72667 L p .707 .577 .707 r
F P
0 g
s
.83679 .72667 m .83819 .70932 L .84103 .72311 L p .707 .577 .707 r
F P
0 g
s
.42945 .56026 m .41655 .61563 L .44528 .61995 L p .707 .577 .707 r
F P
0 g
s
.44528 .61995 m .45818 .56458 L .42945 .56026 L p .707 .577 .707 r
F P
0 g
s
.35517 .60095 m .36807 .54558 L .34142 .53667 L p .707 .577 .707 r
F P
0 g
s
.36807 .54558 m .35517 .60095 L .3855 .60908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63629 .72115 m .63769 .70381 L .6448 .69097 L p .707 .577 .707 r
F P
0 g
s
.82985 .55902 m .82425 .60949 L .80327 .59622 L p .707 .577 .707 r
F P
0 g
s
.80327 .59622 m .80887 .54575 L .82985 .55902 L p .707 .577 .707 r
F P
0 g
s
.66566 .53979 m .66006 .59026 L .64379 .60197 L p .707 .577 .707 r
F P
0 g
s
.66006 .59026 m .66566 .53979 L .68958 .53178 L p .707 .577 .707 r
F P
0 g
s
.34142 .53667 m .32852 .59204 L .35517 .60095 L p .707 .577 .707 r
F P
0 g
s
.6448 .69097 m .64341 .70832 L .63629 .72115 L p .707 .577 .707 r
F P
0 g
s
.46325 .62123 m .46888 .62163 L p .44867 .60541 L .707 .577 .707 r
F P
0 g
s
.46564 .62137 m .46722 .62555 L p .49371 .63866 L .707 .577 .707 r
F P
0 g
s
.46722 .62555 m .47822 .65463 L .48632 .64628 L p .707 .577 .707 r
F P
0 g
s
.48632 .64628 m .49371 .63866 L p .46722 .62555 L .707 .577 .707 r
F P
0 g
s
.45818 .56458 m .44867 .60541 L p .46888 .62163 L .707 .577 .707 r
F P
0 g
s
.44867 .60541 m .44528 .61995 L .46325 .62123 L p .707 .577 .707 r
F P
0 g
s
.46888 .62163 m .48177 .56626 L .45818 .56458 L p .707 .577 .707 r
F P
0 g
s
.8352 .6404 m .84077 .6784 L .82782 .68196 L p .707 .577 .707 r
F P
0 g
s
.82782 .68196 m .82225 .64396 L .8352 .6404 L p .707 .577 .707 r
F P
0 g
s
.32852 .59204 m .34142 .53667 L .32108 .52784 L p .707 .577 .707 r
F P
0 g
s
.42768 .68417 m .41511 .65091 L .38502 .66159 L p .707 .577 .707 r
F P
0 g
s
.41511 .65091 m .42768 .68417 L .45546 .67032 L p .707 .577 .707 r
F P
0 g
s
.45546 .67032 m .44289 .63705 L .41511 .65091 L p .707 .577 .707 r
F P
0 g
s
.39759 .69485 m .38502 .66159 L .35557 .66804 L p .707 .577 .707 r
F P
0 g
s
.38502 .66159 m .39759 .69485 L .42768 .68417 L p .707 .577 .707 r
F P
0 g
s
.65887 .66831 m .66444 .70631 L .64871 .70702 L p .707 .577 .707 r
F P
0 g
s
.64871 .70702 m .64314 .66902 L .65887 .66831 L p .707 .577 .707 r
F P
0 g
s
.80887 .54575 m .80327 .59622 L .77592 .58608 L p .707 .577 .707 r
F P
0 g
s
.77592 .58608 m .78152 .53561 L .80887 .54575 L p .707 .577 .707 r
F P
0 g
s
.68398 .58225 m .68958 .53178 L .71881 .52827 L p .707 .577 .707 r
F P
0 g
s
.68958 .53178 m .68398 .58225 L .66006 .59026 L p .707 .577 .707 r
F P
0 g
s
.44289 .63705 m .45546 .67032 L .47822 .65463 L p .707 .577 .707 r
F P
0 g
s
.47822 .65463 m .46564 .62137 L .44289 .63705 L p .707 .577 .707 r
F P
0 g
s
.83819 .70932 m .83679 .72667 L .82428 .71329 L p .707 .577 .707 r
F P
0 g
s
.82428 .71329 m .82567 .69595 L .83819 .70932 L p .707 .577 .707 r
F P
0 g
s
.32108 .52784 m .30818 .58321 L .32852 .59204 L p .707 .577 .707 r
F P
0 g
s
.3848 .71489 m .3875 .69937 L p .35735 .68973 L .707 .577 .707 r
F P
0 g
s
.38231 .69508 m .35735 .68973 L p .3875 .69937 L .707 .577 .707 r
F P
0 g
s
.35735 .68973 m .35411 .70832 L .3848 .71489 L p .707 .577 .707 r
F P
0 g
s
.35411 .70832 m .3562 .69633 L p .33039 .68194 L .707 .577 .707 r
F P
0 g
s
.3562 .69633 m .35735 .68973 L .34548 .6863 L p .707 .577 .707 r
F P
0 g
s
.34548 .6863 m .33039 .68194 L p .3562 .69633 L .707 .577 .707 r
F P
0 g
s
.33039 .68194 m .32715 .70052 L .35411 .70832 L p .707 .577 .707 r
F P
0 g
s
.32715 .70052 m .32851 .69269 L p .30978 .6737 L .707 .577 .707 r
F P
0 g
s
.32851 .69269 m .33039 .68194 L .31695 .67657 L p .707 .577 .707 r
F P
0 g
s
.31695 .67657 m .30978 .6737 L p .32851 .69269 L .707 .577 .707 r
F P
0 g
s
.30978 .6737 m .30654 .69228 L .32715 .70052 L p .707 .577 .707 r
F P
0 g
s
.30654 .69228 m .30725 .68821 L p .29755 .66581 L .707 .577 .707 r
F P
0 g
s
.30725 .68821 m .30978 .6737 L .30101 .66804 L p .707 .577 .707 r
F P
0 g
s
.30101 .66804 m .29755 .66581 L p .30725 .68821 L .707 .577 .707 r
F P
0 g
s
.32233 .69947 m .31001 .66688 L p .29788 .65811 L .707 .577 .707 r
F P
0 g
s
.30931 .6659 m .29788 .65811 L p .31001 .66688 L .707 .577 .707 r
F P
0 g
s
.29788 .65811 m .31045 .69137 L .32233 .69947 L p .707 .577 .707 r
F P
0 g
s
.31045 .69137 m .29819 .65892 L p .29517 .64612 L .707 .577 .707 r
F P
0 g
s
.29819 .65892 m .29788 .65811 L .29773 .65744 L p .707 .577 .707 r
F P
0 g
s
.29773 .65744 m .29517 .64612 L p .29819 .65892 L .707 .577 .707 r
F P
0 g
s
.31001 .66688 m .30976 .66621 L .30931 .6659 L p .707 .577 .707 r
F P
0 g
s
.3422 .70289 m .33072 .67252 L p .30976 .66621 L .707 .577 .707 r
F P
0 g
s
.33072 .67252 m .32963 .66963 L .32719 .66921 L p .707 .577 .707 r
F P
0 g
s
.32719 .66921 m .30976 .66621 L p .33072 .67252 L .707 .577 .707 r
F P
0 g
s
.36814 .7013 m .35827 .6752 L p .32963 .66963 L .707 .577 .707 r
F P
0 g
s
.35827 .6752 m .35557 .66804 L .35003 .66838 L p .707 .577 .707 r
F P
0 g
s
.35003 .66838 m .32963 .66963 L p .35827 .6752 L .707 .577 .707 r
F P
0 g
s
.3875 .69937 m .38803 .69631 L .38231 .69508 L p .707 .577 .707 r
F P
0 g
s
.38803 .69631 m .3848 .71489 L .4162 .71961 L p .707 .577 .707 r
F P
0 g
s
.4162 .71961 m .41943 .70103 L .38803 .69631 L p .707 .577 .707 r
F P
0 g
s
.35557 .66804 m .36814 .7013 L .39759 .69485 L p .707 .577 .707 r
F P
0 g
s
.66444 .70631 m .65971 .67403 L p .68231 .66611 L .707 .577 .707 r
F P
0 g
s
.65971 .67403 m .65887 .66831 L .66458 .66778 L p .707 .577 .707 r
F P
0 g
s
.66458 .66778 m .68231 .66611 L p .65971 .67403 L .707 .577 .707 r
F P
0 g
s
.64341 .70832 m .64461 .6934 L p .66117 .68033 L .707 .577 .707 r
F P
0 g
s
.64461 .6934 m .6448 .69097 L .64824 .68874 L p .707 .577 .707 r
F P
0 g
s
.64824 .68874 m .66117 .68033 L p .64461 .6934 L .707 .577 .707 r
F P
0 g
s
.41943 .70103 m .4162 .71961 L .44524 .722 L p .707 .577 .707 r
F P
0 g
s
.44524 .722 m .44847 .70342 L .41943 .70103 L p .707 .577 .707 r
F P
0 g
s
.48177 .56626 m .46888 .62163 L .47759 .62102 L p .707 .577 .707 r
F P
0 g
s
.48483 .61719 m .48477 .61626 L .47759 .62102 L .707 .577 .707 r
F
.48477 .61626 m .48177 .56626 L .47837 .61074 L F
.48477 .61626 m .47837 .61074 L .47759 .62102 L F
.49371 .63866 m .49854 .62811 L p .48581 .61715 L F P
0 g
s
.48547 .61686 m .48565 .61733 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.48565 .61733 m .49371 .63866 L p .48581 .61715 L .707 .577 .707 r
F P
0 g
s
.49305 .6087 m .49336 .60598 L .48581 .61715 L .707 .577 .707 r
F
.49793 .56513 m .48983 .5999 L p .49336 .60598 L F P
0 g
s
.48983 .5999 m .48581 .61715 L p .49336 .60598 L .707 .577 .707 r
F P
0 g
s
.49793 .56513 m .48177 .56626 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.49371 .63866 m .48547 .61686 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .48983 .5999 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.48983 .5999 m .49793 .56513 L p .4828 .58333 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .4983 .61451 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49417 .60739 m .49432 .60777 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .50043 .62396 L p .49428 .60758 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .48547 .61686 L p .48589 .61705 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .48922 .61317 L .48589 .61705 L .707 .577 .707 r
F
.48922 .61317 m .48114 .60539 L .48589 .61705 L F
.49423 .60733 m .49359 .6039 L p .49305 .6087 L F P
0 g
s
.48786 .59069 m .48114 .60539 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.50043 .62396 m .49432 .60777 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49432 .60777 m .48786 .59069 L p .49337 .61716 L .707 .577 .707 r
F P
0 g
s
.49466 .59435 m .50506 .5613 L .49793 .56513 L p .707 .577 .707 r
F P
0 g
s
.50247 .55515 m .50506 .5613 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49423 .60733 L p .49216 .61667 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .49423 .60733 L .49305 .6087 L .707 .577 .707 r
F
.48786 .59069 m .49417 .60739 L p .49427 .60752 L F P
0 g
s
.49287 .60004 m .49404 .59633 L .49428 .60758 L .707 .577 .707 r
F
.50506 .5613 m .49808 .59127 L p .49404 .59633 L F P
0 g
s
.49808 .59127 m .49428 .60758 L p .49404 .59633 L .707 .577 .707 r
F P
0 g
s
.49332 .60248 m .48786 .59069 L .49427 .60752 L .707 .577 .707 r
F
.49287 .60004 m .49744 .57675 L .49614 .58965 L F
.49249 .598 m .49744 .57675 L p .49287 .60004 L F P
0 g
s
.48515 .57871 m .48786 .59069 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .49265 .59855 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .48515 .57871 L p .49484 .60574 L .707 .577 .707 r
F P
0 g
s
.48515 .57871 m .49253 .59821 L p .49237 .59835 L .707 .577 .707 r
F P
0 g
s
.48957 .61052 m .47751 .60265 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .48868 .59578 L .48957 .61052 L .707 .577 .707 r
F
.48557 .59362 m .48515 .57871 L .49237 .59835 L F
.4924 .59837 m .48957 .61052 L p .48868 .59578 L F P
0 g
s
.48724 .60482 m .48585 .60387 L p .49253 .59821 L .707 .577 .707 r
F P
0 g
s
.49249 .598 m .4924 .59837 L p .4879 .58288 L .707 .577 .707 r
F P
0 g
s
.4879 .58288 m .4924 .59837 L .48868 .59578 L .707 .577 .707 r
F
.49773 .61197 m .49332 .60248 L .49427 .60752 L F
.48957 .61052 m .49249 .598 L p .49287 .60004 L F P
0 g
s
.49854 .62811 m .50043 .62396 L p .48547 .61686 L .707 .577 .707 r
F P
0 g
s
.48503 .6205 m .49216 .61667 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.48581 .61715 m .48503 .6205 L p .49305 .6087 L .707 .577 .707 r
F P
0 g
s
.49216 .61667 m .48957 .61052 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.4983 .61451 m .49773 .61197 L p .49417 .60739 L .707 .577 .707 r
F P
0 g
s
.49428 .60758 m .49216 .61667 L p .49287 .60004 L .707 .577 .707 r
F P
0 g
s
.49773 .61197 m .48724 .60482 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49253 .59821 m .49265 .59855 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.49265 .59855 m .49773 .61197 L p .4924 .59837 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .48557 .59362 L .49237 .59835 L .707 .577 .707 r
F
.47328 .57061 m .48515 .57871 L p .48557 .59362 L F P
0 g
s
.47751 .60265 m .48036 .59043 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.47328 .57061 m .4807 .59023 L p .48036 .59043 L .707 .577 .707 r
F P
0 g
s
.47751 .60265 m .45716 .59382 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .47751 .60265 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4665 .5983 m .46925 .58708 L .48036 .59043 L .707 .577 .707 r
F
.46925 .58708 m .47328 .57061 L .48036 .59043 L F
.4807 .59023 m .47328 .57061 L p .48557 .59362 L F P
0 g
s
.4534 .56718 m .47328 .57061 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .45933 .58452 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.4534 .56718 m .45985 .58424 L p .45933 .58452 L .707 .577 .707 r
F P
0 g
s
.45716 .59382 m .43052 .58491 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45716 .59382 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.44343 .59319 m .44738 .5829 L .45933 .58452 L .707 .577 .707 r
F
.44738 .5829 m .4534 .56718 L .45933 .58452 L F
.45985 .58424 m .4534 .56718 L p .46925 .58708 L F P
0 g
s
.42747 .56878 m .4534 .56718 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.43052 .58491 m .43137 .58125 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.42747 .56878 m .43201 .58081 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43052 .58491 L .41492 .58072 L p .707 .577 .707 r
F P
0 g
s
.4183 .59035 m .42229 .58096 L .43137 .58125 L .707 .577 .707 r
F
.42229 .58096 m .42747 .56878 L .43137 .58125 L F
.43201 .58081 m .42747 .56878 L p .44738 .5829 L F P
0 g
s
.39801 .57523 m .42747 .56878 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.41059 .60849 m .4002 .58102 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.4002 .58102 m .39801 .57523 L p .41582 .59619 L .707 .577 .707 r
F P
0 g
s
.39801 .57523 m .41059 .60849 L .3805 .61917 L p .707 .577 .707 r
F P
0 g
s
.3805 .61917 m .36792 .58591 L .39801 .57523 L p .707 .577 .707 r
F P
0 g
s
.41309 .5214 m .40019 .57678 L .39463 .57561 L p .707 .577 .707 r
F P
0 g
s
.39463 .57561 m .36914 .57023 L p .37845 .55988 L .707 .577 .707 r
F P
0 g
s
.37845 .55988 m .41309 .5214 L .39463 .57561 L .707 .577 .707 r
F
.44342 .52953 m .43137 .58125 L p .40019 .57678 L F P
0 g
s
.41492 .58072 m .40019 .57678 L p .43137 .58125 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43149 .58074 L p .43201 .58081 L .707 .577 .707 r
F P
0 g
s
.43137 .58125 m .43201 .58081 L .4338 .58105 L .707 .577 .707 r
F
.44004 .60204 m .41059 .60849 L p .4183 .59035 L F P
0 g
s
.43201 .58081 m .44004 .60204 L p .4183 .59035 L .707 .577 .707 r
F P
0 g
s
.44004 .60204 m .43201 .58081 L p .44738 .5829 L .707 .577 .707 r
F P
0 g
s
.44342 .52953 m .47006 .53845 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.43149 .58074 m .44342 .52953 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .45933 .58452 L p .4338 .58105 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45942 .58411 L p .45985 .58424 L .707 .577 .707 r
F P
0 g
s
.45933 .58452 m .45985 .58424 L .46327 .58527 L .707 .577 .707 r
F
.46597 .60045 m .44004 .60204 L p .44343 .59319 L F P
0 g
s
.45985 .58424 m .46597 .60045 L p .44343 .59319 L .707 .577 .707 r
F P
0 g
s
.46597 .60045 m .45985 .58424 L p .46925 .58708 L .707 .577 .707 r
F P
0 g
s
.47006 .53845 m .49041 .54727 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.45942 .58411 m .47006 .53845 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .48036 .59043 L p .46327 .58527 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .48044 .59006 L p .4807 .59023 L .707 .577 .707 r
F P
0 g
s
.48036 .59043 m .4807 .59023 L .48314 .59193 L .707 .577 .707 r
F
.48585 .60387 m .46597 .60045 L p .4665 .5983 L F P
0 g
s
.4807 .59023 m .48585 .60387 L p .4665 .5983 L .707 .577 .707 r
F P
0 g
s
.48585 .60387 m .4807 .59023 L p .48557 .59362 L .707 .577 .707 r
F P
0 g
s
.49041 .54727 m .50247 .55515 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48044 .59006 m .49041 .54727 L p .48314 .59193 L .707 .577 .707 r
F P
0 g
s
.48314 .59193 m .4879 .58288 L .48868 .59578 L .707 .577 .707 r
F
.50247 .55515 m .49249 .598 L p .4879 .58288 L F P
0 g
s
.49744 .57675 m .50247 .55515 L p .49614 .58965 L .707 .577 .707 r
F P
0 g
s
.48114 .60539 m .46564 .62137 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.48547 .61686 m .48114 .60539 L p .47086 .62458 L .707 .577 .707 r
F P
0 g
s
.47759 .62102 m .48503 .6205 L p .48483 .61719 L .707 .577 .707 r
F P
0 g
s
.78152 .53561 m .77592 .58608 L .74489 .58005 L p .707 .577 .707 r
F P
0 g
s
.74489 .58005 m .75049 .52959 L .78152 .53561 L p .707 .577 .707 r
F P
0 g
s
.71321 .57873 m .71881 .52827 L .75049 .52959 L p .707 .577 .707 r
F P
0 g
s
.71881 .52827 m .71321 .57873 L .68398 .58225 L p .707 .577 .707 r
F P
0 g
s
.30818 .58321 m .32108 .52784 L .30902 .51996 L p .707 .577 .707 r
F P
0 g
s
.66117 .68033 m .65977 .69768 L .64341 .70832 L p .707 .577 .707 r
F P
0 g
s
.75049 .52959 m .74489 .58005 L .71321 .57873 L p .707 .577 .707 r
F P
0 g
s
.82225 .64396 m .82782 .68196 L .80658 .68642 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .80101 .64842 L .82225 .64396 L p .707 .577 .707 r
F P
0 g
s
.32963 .66963 m .3422 .70289 L .36814 .7013 L p .707 .577 .707 r
F P
0 g
s
.44847 .70342 m .44524 .722 L .46908 .72185 L p .707 .577 .707 r
F P
0 g
s
.46908 .72185 m .47231 .70326 L .44847 .70342 L p .707 .577 .707 r
F P
0 g
s
.68231 .66611 m .68788 .70411 L .66444 .70631 L p .707 .577 .707 r
F P
0 g
s
.30902 .51996 m .29612 .57534 L .30818 .58321 L p .707 .577 .707 r
F P
0 g
s
.82567 .69595 m .82428 .71329 L .80332 .70163 L p .707 .577 .707 r
F P
0 g
s
.80658 .68642 m .77915 .69134 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80101 .64842 m .80276 .66035 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80276 .66035 m .80658 .68642 L p .79875 .65287 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .80471 .68428 L .82022 .69291 L p .707 .577 .707 r
F P
0 g
s
.82022 .69291 m .82567 .69595 L p .82231 .6968 L .707 .577 .707 r
F P
0 g
s
.80332 .70163 m .82022 .69291 L .82231 .6968 L .707 .577 .707 r
F
.68788 .70411 m .6827 .66876 L p .71117 .66265 L F P
0 g
s
.6827 .66876 m .68231 .66611 L .6866 .6656 L p .707 .577 .707 r
F P
0 g
s
.6866 .6656 m .71117 .66265 L p .6827 .66876 L .707 .577 .707 r
F P
0 g
s
.65977 .69768 m .66067 .68657 L p .68519 .67294 L .707 .577 .707 r
F P
0 g
s
.66067 .68657 m .66117 .68033 L .67281 .67675 L p .707 .577 .707 r
F P
0 g
s
.67281 .67675 m .68519 .67294 L p .66067 .68657 L .707 .577 .707 r
F P
0 g
s
.30976 .66621 m .32233 .69947 L .3422 .70289 L p .707 .577 .707 r
F P
0 g
s
.68519 .67294 m .6838 .69029 L .65977 .69768 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .77357 .65335 L .80101 .64842 L p .707 .577 .707 r
F P
0 g
s
.29612 .57534 m .30902 .51996 L .30643 .51381 L p .707 .577 .707 r
F P
0 g
s
.47231 .70326 m .46908 .72185 L .48538 .71915 L p .707 .577 .707 r
F P
0 g
s
.48538 .71915 m .48862 .70056 L .47231 .70326 L p .707 .577 .707 r
F P
0 g
s
.71117 .66265 m .71674 .70064 L .68788 .70411 L p .707 .577 .707 r
F P
0 g
s
.80471 .68428 m .80332 .70163 L .77595 .69282 L p .707 .577 .707 r
F P
0 g
s
.77915 .69134 m .74819 .69624 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77357 .65335 m .77457 .66016 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77457 .66016 m .77915 .69134 L p .77139 .65704 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .77735 .67548 L .7964 .68161 L p .707 .577 .707 r
F P
0 g
s
.7964 .68161 m .80471 .68428 L p .80042 .68556 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .7964 .68161 L .80042 .68556 L .707 .577 .707 r
F
.71674 .70064 m .71152 .66504 L p .74262 .65825 L F P
0 g
s
.71152 .66504 m .71117 .66265 L .71645 .66191 L p .707 .577 .707 r
F P
0 g
s
.71645 .66191 m .74262 .65825 L p .71152 .66504 L .707 .577 .707 r
F P
0 g
s
.6838 .69029 m .68444 .68222 L p .71452 .66951 L .707 .577 .707 r
F P
0 g
s
.68444 .68222 m .68519 .67294 L .7022 .67095 L p .707 .577 .707 r
F P
0 g
s
.7022 .67095 m .71452 .66951 L p .68444 .68222 L .707 .577 .707 r
F P
0 g
s
.30643 .51381 m .29353 .56918 L .29612 .57534 L p .707 .577 .707 r
F P
0 g
s
.29755 .66581 m .29431 .68439 L .30654 .69228 L p .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .74334 .66322 L p .77357 .65335 L .707 .577 .707 r
F P
0 g
s
.74819 .69624 m .71674 .70064 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74262 .65825 m .74296 .66063 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.74296 .66063 m .74819 .69624 L p .74169 .65976 L .707 .577 .707 r
F P
0 g
s
.77595 .69282 m .74488 .68773 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.77735 .67548 m .7767 .6836 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.7767 .6836 m .77595 .69282 L p .76925 .67853 L .707 .577 .707 r
F P
0 g
s
.71312 .68686 m .71358 .68119 L p .74627 .67039 L .707 .577 .707 r
F P
0 g
s
.71358 .68119 m .71452 .66951 L .73211 .67 L p .707 .577 .707 r
F P
0 g
s
.73211 .67 m .74627 .67039 L p .71358 .68119 L .707 .577 .707 r
F P
0 g
s
.74334 .66322 m .74262 .65825 L .75476 .65633 L p .707 .577 .707 r
F P
0 g
s
.75476 .65633 m .77357 .65335 L p .74334 .66322 L .707 .577 .707 r
F P
0 g
s
.71452 .66951 m .71312 .68686 L .6838 .69029 L p .707 .577 .707 r
F P
0 g
s
.74488 .68773 m .74627 .67039 L .77735 .67548 L p .707 .577 .707 r
F P
0 g
s
.74627 .67039 m .74488 .68773 L .71312 .68686 L p .707 .577 .707 r
F P
0 g
s
.48862 .70056 m .48538 .71915 L .49256 .71417 L p .707 .577 .707 r
F P
0 g
s
.49256 .71417 m .49579 .69559 L .48862 .70056 L p .707 .577 .707 r
F P
0 g
s
.29353 .56918 m .30643 .51381 L .31356 .50998 L p .707 .577 .707 r
F P
0 g
s
.29431 .68439 m .29755 .66581 L .29489 .65904 L p .707 .577 .707 r
F P
0 g
s
.29489 .65904 m .29165 .67763 L .29431 .68439 L p .707 .577 .707 r
F P
0 g
s
.31356 .50998 m .30066 .56535 L .29353 .56918 L p .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .31045 .69137 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.29672 .6502 m .30775 .67939 L p .2963 .64946 L .707 .577 .707 r
F P
0 g
s
.30775 .67939 m .29517 .64612 L .3019 .63142 L p .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29489 .65904 L .29977 .65566 L p .707 .577 .707 r
F P
0 g
s
.29977 .65566 m .30206 .65407 L p .30066 .65726 L .707 .577 .707 r
F P
0 g
s
.29165 .67763 m .29977 .65566 L .30066 .65726 L .707 .577 .707 r
F
.29517 .64612 m .29672 .6502 L p .2963 .64946 L F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49579 .69559 m .49256 .71417 L .4899 .70741 L p .707 .577 .707 r
F P
0 g
s
.4899 .70741 m .49314 .68883 L .49579 .69559 L p .707 .577 .707 r
F P
0 g
s
.30066 .56535 m .31356 .50998 L .32971 .50885 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30206 .65407 m .29883 .67265 L .29165 .67763 L p .707 .577 .707 r
F P
0 g
s
.32971 .50885 m .31681 .56422 L .30066 .56535 L p .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .30775 .67939 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.30525 .6403 m .31447 .66469 L p .3027 .63799 L .707 .577 .707 r
F P
0 g
s
.31447 .66469 m .3019 .63142 L .31739 .61545 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31447 .66469 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31739 .61545 m .32333 .63117 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.32333 .63117 m .32996 .64871 L p .31689 .62395 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .31837 .65137 L .34123 .65122 L p .707 .577 .707 r
F P
0 g
s
.34123 .65122 m .34221 .65121 L p .3416 .65163 L .707 .577 .707 r
F P
0 g
s
.31513 .66995 m .34123 .65122 L .3416 .65163 L .707 .577 .707 r
F
.29883 .67265 m .30206 .65407 L .31761 .6515 L p F P
0 g
s
.31761 .6515 m .31837 .65137 L p .31796 .65181 L .707 .577 .707 r
F P
0 g
s
.29883 .67265 m .31761 .6515 L .31796 .65181 L .707 .577 .707 r
F
.3019 .63142 m .30525 .6403 L p .3027 .63799 L F P
0 g
s
.49314 .68883 m .4899 .70741 L .47767 .69952 L p .707 .577 .707 r
F P
0 g
s
.47767 .69952 m .4809 .68094 L .49314 .68883 L p .707 .577 .707 r
F P
0 g
s
.31681 .56422 m .32971 .50885 L .35331 .51053 L p .707 .577 .707 r
F P
0 g
s
.35331 .51053 m .34041 .5659 L .31681 .56422 L p .707 .577 .707 r
F P
0 g
s
.31837 .65137 m .31513 .66995 L .29883 .67265 L p .707 .577 .707 r
F P
0 g
s
.34041 .5659 m .35331 .51053 L .38204 .51486 L p .707 .577 .707 r
F P
0 g
s
.32996 .64871 m .31739 .61545 L .34014 .59976 L p .707 .577 .707 r
F P
0 g
s
.4809 .68094 m .47767 .69952 L .45706 .69127 L p .707 .577 .707 r
F P
0 g
s
.45706 .69127 m .4603 .67269 L .4809 .68094 L p .707 .577 .707 r
F P
0 g
s
.38204 .51486 m .36914 .57023 L .34041 .5659 L p .707 .577 .707 r
F P
0 g
s
.40019 .57678 m .41309 .5214 L .44342 .52953 L p .707 .577 .707 r
F P
0 g
s
.36914 .57023 m .38204 .51486 L .41309 .5214 L p .707 .577 .707 r
F P
0 g
s
.34221 .65121 m .33897 .66979 L .31513 .66995 L p .707 .577 .707 r
F P
0 g
s
.34014 .59976 m .35272 .63303 L .32996 .64871 L p .707 .577 .707 r
F P
0 g
s
.35272 .63303 m .34014 .59976 L .36792 .58591 L p .707 .577 .707 r
F P
0 g
s
.36792 .58591 m .3805 .61917 L .35272 .63303 L p .707 .577 .707 r
F P
0 g
s
.4603 .67269 m .45706 .69127 L .4301 .68348 L p .707 .577 .707 r
F P
0 g
s
.4301 .68348 m .43333 .6649 L .4603 .67269 L p .707 .577 .707 r
F P
0 g
s
.33897 .66979 m .34221 .65121 L .37125 .65361 L p .707 .577 .707 r
F P
0 g
s
.37125 .65361 m .36801 .67219 L .33897 .66979 L p .707 .577 .707 r
F P
0 g
s
.43333 .6649 m .4301 .68348 L .39941 .67691 L p .707 .577 .707 r
F P
0 g
s
.39941 .67691 m .40265 .65832 L .43333 .6649 L p .707 .577 .707 r
F P
0 g
s
.36801 .67219 m .37125 .65361 L .40265 .65832 L p .707 .577 .707 r
F P
0 g
s
.40265 .65832 m .39941 .67691 L .36801 .67219 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00EJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001LOol50004Ool01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001IOol300000eYF001JEP02FUH80006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`<000=JEP03001JEUYF00AJ
EP04001JEUYFFUH80008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00EWoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1P002eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo011oo`l004Eoo`00EWoo
0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo00Yoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@0045oo`00EGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol01Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000?Goo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH00000>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020007FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`02Ool30006FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P00>Goo001EOol20004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00Oomoo`020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH2000gOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oo`0000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP<003Eoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003=o
o`00E7oo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00
E7oo00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00
Dgoo00<005YF000030001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00`0000=JEP00FUH02eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000;goo001COol20003FUH00`00FUIJEP04FUH0
0`00FUIJEP040002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH02@00FUIJEUYF001JEP00FUH0000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=J
EP03001JEUYF00EJEPH000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo001DOol01@00FUIJEUYF00001EYF00<005YFFUH0
1EYF00<005YFFUH00eYF1P002EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009J
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP05001JEUYFFUH0000]Ool005Eoo`<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<0
0003FUH0000000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00
Egoo00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF0`001EYF100015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEPH000moo`@0009JEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Qoo`8000=JEP03001JEUYF00EJEP03
001JEUYF008000QJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=J
EP03001JEP0000<001Uoo`@000IJEP03001JEUYF00=JEP03001JEUYF009JEP8002aoo`00FWoo0P00
00=JEP00FUH01UYF10002EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool005aoo`<000EJ
EP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF00<000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH00`00Oomoo`0SOol300000eYF001JEP04FUH01`00FUIJEUYF001JEP0002aoo`00Ggoo1@001EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF001JEP00
00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000
00005Woo0`003goo0P001EYF00L005YFFUIJEP00FUH0000/Ool0061oo`8000QJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000EJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF0`004goo1@0047oo0P000eYF00L005YF
FUIJEP00FUH0000/Ool005moo`8000UJEP03001JEUYF00IJEP03001JEUYF00EJEPH000EJEPD00003
FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP05
001JEUYFFUH00002FUH00`00Oomoo`0@Ool5000BOol01000FUIJEP000eYF0P00;Goo001NOol01000
FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YF00000P00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`00
0eYF00@005YFFUIJEP80011oo`D001=oo`<000=JEP8002eoo`00G7oo0P000eYF00<005YFFUH01eYF
00<005YFFUH01EYF100025YF00<005YFFUH015YF0`0000=JEP0000000P000eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH00eYF0P003goo0`00
5Woo00@005YFFUIJEP8002eoo`00Fgoo00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00eYF
0`000UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00D005YF001JEP0000=JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01EYF0P00
9Woo0P0000AJEP00FUH002eoo`00F7oo0`001eYF00<005YFFUH01eYF00<005YF00000P000eYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH01eYF0`008Goo0P0000IJEP00
FUH005YF000]Ool004moo`T00003FUH0000000MJEP03001JEUYF00MJEP800003FUH005YF00MJEP03
001JEP0000X0009JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEP0015YF00<005YFFUH02eYF1P005goo100000AJEP00FUIJEP800003FUH007oo02aoo`00AWoo
2@0015YF00@005YFFUIJEP800003FUH0000000MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP<000EJEP80009JEP04001JEUYF000<FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01000FUIJEP0015YF00<005YFFUH04EYF2@002Goo1@001EYF00L005YFFUIJEP00FUH0000]Ool0
03ioo`P000eJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH30006FUH0
0`00FUIJEP06FUH01@00FUIJEUYF000015YF0P0000=JEP00FUH00UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF01YJEPT000=JEP03001JEUYF
00AJEP07001JEUYFFUH005YF0000;Goo000`Ool>000EFUH00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUH000020005FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00
FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEUYF00000eYF
00<005YFFUH07UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00;Goo0`00
0UYF00<005YFFUH015YF00<005YFFUH05eYF0`001EYF0P001eYF0P000UYF00<005YFFUH00eYF1@00
1EYF00<005YFFUH00eYF0P001EYF00<005YFFUH00eYF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF01QJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002]oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00mJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF00=JEP800005FUH005YFFUH0
0005FUH50005FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP04
FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0:000^Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00mJEP03001JEUYF00EJEP04001JEUYF0005FUH0
1000FUIJEUYF0P000eYF00@005YFFUH000IJEP<000IJEP03001JEUYF00<000QJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEP000005FUH00`00FUIJEP0>FUH00gooFUIJEP07FUH01000FUIJEUYF1`000eYF00@005YF
FUIJEP<002ioo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH0
1EYF00<005YFFUH00P001EYF0`0000=JEP00FUH00UYF00@005YFFUH000IJEP03001JEUYF00IJEP<0
00=JEP03001JEUYF00EJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF2@000eYF00<005YFFUH00eYF1@0000=JEP000000;Woo000[Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH03eYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00EJEP8000EJEP03001JEUYF00EJ
EP04001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF
1`000UYF00@005YFFUIJEP8002ioo`00:goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP8000MJEP03001JEUYF00IJEP03001JEUYF01D000=JEP03001JEUYF00=JEP8000QJEP03001J
EUYF00EJEP8000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF00=JEP04001JEUYF0006FUH60004FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP040002FUH300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30002FUH30002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00FUH00005FUH00`00FUIJ
EP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPD0009J
EP03001JEUYF00IJEP03001JEUYF009JEP8000YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP800003FUH00000
00EJEP03001JEP0000MJEP03001JEUYF00=JEP06001JEUYF001JEP00;Goo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040007FUH01@00FUIJ
EUYF000035YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000010000UYF00<005YFFUH01EYF2@000eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
FUH000EJEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00AJEP@000AJEP@000aJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH3000015YF001JEUYF2`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@0
05YFFUH000MJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP8000EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00009JEPd000AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEP0000@0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00P000EJEP80009JEQ4000IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH0000000=JEP03
001JEUYF00AJEPT000AJEP03001JEUYF00MJEP03001JEUYF00=JEP@000aJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF10001UYF00<0
05YFFUH01UYF00<005YF00000`000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
;Goo000/Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF0P000UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF0P001UYF1`001UYF00<005YF
FUH01EYF00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH60005FUH00`00FUIJEP03FUH00`00FUH00002000]Ool002aoo`04001JEUYF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH00005FUH20003FUH00`00FUH00004FUH0
0`00FUIJEP04FUH20008FUH30002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001JEUYF
009JEP<0031oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH00eYF3@001eYF00D0
05YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP@000EJ
EP03001JEUYF00AJEP<000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP08001J
EUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<00004FUH00000000cOol002eoo`03001JEP0000=JEP03001JEUYF009JEPP000QJEP04
001JEUYFFUH30004FUH300001EYF000005YF000015YF00<005YFFUH015YF0P001UYF1@000eYF0`00
0eYF100000=JEP00FUH01EYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH?0006FUH0
0`00FUIJEP05FUH3000fOol002eoo`03001JEP00009JEP04001JEUYFFUH20007FUH00`00FUIJEP02
FUH90002Ool3000015YF001JEUYF0`0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH015YF
20000UYF00<005YFFUH01EYF0`0015YF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP03FUH60004
FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eo
o`<0009JEP03001JEP0000l000ioo`<000=JEP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00QJEP<00003FUH005YF00=JEP03001JEUYF009JEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUH0000300000eYF00000007FUH0
0`00FUIJEP04FUH700000goo000000020006FUH00`00FUIJEP02FUH2000bOol002eoo`03001JEP00
009JEP<0021oo`8000=JEP@000=JEP03001JEUYF00AJEP03001JEUYF00P000EJEP03001JEUYF00UJ
EP04001JEP000003FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20003FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP04000<Ool40002FUH00`00FUIJ
EP03FUH2000aOol002eoo`05FUH005YFFUH0000UOol300000eYF0000000>0003FUH00`00FUIJEP02
FUH80008FUH60002FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P000UYF0P0000=JEP00FUH01EYF00<005YFFUH00UYF1P0057oo0`001EYF00<005YF0000
<7oo000]Ool015YF001JEP00:Goo0P000eYF100000=JEP00FUH025YF00<005YFFUH01UYF00@005YF
FUIJEPP000=JEP03001JEUYF00@000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP04001JEUYFFUH40002FUH=000MOol20003FUH01000FUIJEP00;goo000]Ool00eYF0000000/Ool0
0`00FUIJEP02FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF
FUIJEPH000EJEP03001JEUYF00=JEP8001moo`800003FUH005YF009JEP03001oogoo02aoo`00;7oo
00<005YF0000;Woo00D005YFFUIJEP0000=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP06001JEUYFFUH005YF0P0015YF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo021oo`8000=JEP03001oogoo02aoo`00;7oo0`00;goo0P0000=JEP00FUH00UYF00@005YFFUH0
009JEPL000AJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P0015YF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00`000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol027oo0`005goo00@005YFFUH002ioo`00;7oo1000<7oo0P000eYF00@0
05YFFUH000IJEP03001JEUYF00P000AJEP03001JEUYF00AJEP03001JEUYF00<000IJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP000UYF00<005YFFUH01EYF00D0
05YFFUIJEP0000Yoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`05001JEP00FUH0000GOol3000F
Ool01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00003@002EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUH005YF0080009JEP03001JEUYF
00AJEP04001JEUYF000;Ool5000GOol200000eYF001oo`0/Ool002aoo`05001JEP00FUH0000FOol5
000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<0
05YF00001eYF0P0037oo1@0067oo00<005YF0000;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0C
Ool5000FOol01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=J
EP8000IJEP8000ioo`<001Uoo`03001JEP0002eoo`00;7oo0P0015YF00<007ooOol04Woo1@005goo
0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP<000=JEP8002aoo`80
02ioo`00;7oo0P0015YF0`004goo0`0067oo0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YFFUH0009JEP<002ioo`8002ioo`00;Goo00<005YFFUH00UYF00@005YFFUH0
02ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP8002aoo`@002ioo`00;Goo00D005YFFUIJEP0000AJEP8002aoo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEQH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEP000005FUH2000XOol20002FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00006
FUH00`00Oomoo`0YOol20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF1P0025YF
00<005YFFUH02UYF2P001eYF00<005YFFUH01UYF00<005YFFUH00UYF10001EYF00<005YF00000`00
8Woo0P000eYF0P00;goo000^Ool01000FUIJEP001UYF0`009goo0P0000EJEP00FUIJEP0000IJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEP800004FUH000000003FUH00`00FUIJEP03FUH5000IOol40000
0eYF001JEP02FUH00`00Oomoo`0^Ool002ioo`04001JEUYF0006FUH00`00FUIJEP02000TOol00`00
FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP040008FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP040007FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP05FUH00`00FUIJEP04000@Ool50005FUH01@00FUIJEUYF0000<7oo000_Ool20006FUH0
0`00FUIJEP03FUH20009OolN0002FUH00`00FUIJEP03FUH400000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH30007FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH00`00FUIJEP02000aOol0
02moo`8000IJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEP000002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF0`0000=JEP00FUH00eYF00<005YFFUH01UYF
0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo
000`Ool00`00FUIJEP04FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF
00AJEP80009JEP@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP8003Eoo`00<Goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00
0UYF2P0015YF1@001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00=goo000_Ool3
00000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUH005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF10001eYF
00<005YF00000P0000AJEP000000009oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003Yo
o`00;Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
5P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF009JEP80009J
EP03001oogoo00=ooa00041oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
4P001eYF00<005YFFUH00eYF00@005YFFUH0009JEP8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEUYF008000MJEP03001JEUYF009JEPD005Aoo`00;Goo00<005YF000015YF00@005YFFUIJ
EPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF009JEP03001JEUYF
008005Aoo`00;Goo00<005YF00000eYF1@0000=JEP0000000eYF00<005YFFUH01UYF0P0025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000UYF100015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH02`0015YF00<005YF0000EGoo000]Ool01000FUH005YF0P0015YF00@005YFFUIJEP800003
FUH005YF00MJEP8000QJEP03001JEUYF00AJEP03001JEUYF00=JEPD000=oo`03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEP00FUH200000eYF001JEP05FUH300000eYF001JEP02
001DOol002eoo`03001JEP00008000EJEP03001JEUYF00=JEP@000IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000Qoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
00AJEP8000IJEP03001JEUYF0080009JEP03001oogoo059oo`00;Goo0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH00UYF1@003Goo0P00
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00eYF00@005YF000000AJEP04001JEUYF
FUH4001DOol002ioobL001Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH200000eYF
001JEP02FUH00`00FUH00002001DOol006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00008000IJEP03001JEUYF00AJ
EP8000=JEP<00003FUH0000005=oo`00KGoo0P0015YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0`000goo100000=JEP00FUH01UYF00<005YF
00000P0000=JEP0000000UYF00<007ooOol0DGoo001_Ool300000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40009Ool50003FUH00`00FUIJEP02
FUH01000FUH000000UYF00<007ooOol0DGoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000=Ool50002FUH30002FUH2001DOol007Uoo`/000IJEP03
001JEUYF00YJEP03001JEUYF00AJEPL000Aoo`D0015oo`H0009JEP8005Aoo`00Q7oo6P002goo1@00
3goo0P000UYF00<005YFFUH00eYF00<007ooOol0Dgoo002?Ool01000FUIJEP005goo0`003Woo0P00
15YF00@005YFFUIJEP8005Ioo`00Sgoo00<005YF00009goo0P001eYF0`00F7oo002@Ool2000SOol4
00000eYF001JEP06FUH00`00Oomoo`1HOol0091oo`03001JEP0001eoo`D000EJEP03001JEUYF00=J
EP8005]oo`00T7oo00<005YFFUH00`005Woo10000UYF00<005YFFUH01UYF00<005YFFUH00P00GGoo
002@Ool01000FUIJEP000UYF5P001UYF00<005YFFUH01UYF0`00Ggoo002@Ool01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P00HGoo002AOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000
Hgoo002BOol30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001WOol009Ao
o`<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@006aoo`00Ugoo5P00L7oo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59848 .7556 m .59046 .70157 L .55962 .70333 L p .707 .577 .707 r
F P
0 g
s
.59046 .70157 m .59848 .7556 L .63002 .75051 L p .707 .577 .707 r
F P
0 g
s
.63002 .75051 m .622 .69648 L .59046 .70157 L p .707 .577 .707 r
F P
0 g
s
.622 .69648 m .63002 .75051 L .65916 .74258 L p .707 .577 .707 r
F P
0 g
s
.65916 .74258 m .65114 .68855 L .622 .69648 L p .707 .577 .707 r
F P
0 g
s
.56764 .75736 m .55962 .70333 L .53249 .70157 L p .707 .577 .707 r
F P
0 g
s
.55962 .70333 m .56764 .75736 L .59848 .7556 L p .707 .577 .707 r
F P
0 g
s
.65114 .68855 m .65916 .74258 L .68306 .73259 L p .707 .577 .707 r
F P
0 g
s
.68306 .73259 m .67504 .67856 L .65114 .68855 L p .707 .577 .707 r
F P
0 g
s
.59205 .79976 m .59992 .76274 L .56939 .75519 L p .707 .577 .707 r
F P
0 g
s
.59992 .76274 m .59205 .79976 L .62321 .80562 L p .707 .577 .707 r
F P
0 g
s
.62321 .80562 m .63108 .7686 L .59992 .76274 L p .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53249 .70157 L .51172 .69648 L p .707 .577 .707 r
F P
0 g
s
.53249 .70157 m .54051 .75561 L .54078 .75562 L p .707 .577 .707 r
F P
0 g
s
.5572 .74079 m .53249 .70157 L .54078 .75562 L .707 .577 .707 r
F
.51172 .69648 m .51952 .74901 L p .51952 .74901 L F P
0 g
s
.53123 .73655 m .51172 .69648 L .51952 .74901 L .707 .577 .707 r
F
.51172 .69648 m .49935 .68856 L p .51917 .74879 L F P
0 g
s
.51398 .77511 m .51952 .74902 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L p .51952 .74901 L .707 .577 .707 r
F P
0 g
s
.51952 .74902 m .51952 .74901 L .51215 .75686 L .707 .577 .707 r
F
.51215 .75686 m .51702 .74742 L .5108 .74343 L F
.49935 .68856 m .50715 .7411 L p .50716 .7411 L F P
0 g
s
.51917 .74879 m .51264 .72895 L .50716 .7411 L .707 .577 .707 r
F
.51264 .72895 m .49935 .68856 L .50716 .7411 L F
.49935 .68856 m .4966 .67857 L p .50709 .74089 L F P
0 g
s
.50947 .7302 m .50716 .74111 L p .51398 .77511 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50161 .76723 L .51343 .77476 L p .707 .577 .707 r
F P
0 g
s
.51343 .77476 m .51398 .77511 L p .50716 .74111 L .707 .577 .707 r
F P
0 g
s
.50374 .74867 m .50663 .73936 L .5053 .735 L .707 .577 .707 r
F
.50161 .76723 m .50716 .74111 L p .50374 .74867 L F P
0 g
s
.50716 .74111 m .50716 .7411 L p .50715 .7411 L .707 .577 .707 r
F P
0 g
s
.50716 .74111 m .50715 .7411 L .50374 .74867 L .707 .577 .707 r
F
.50506 .73421 m .50685 .73947 L .50464 .73267 L F
.50709 .74089 m .50685 .73947 L .50506 .73421 L F
.4966 .67857 m .50092 .70765 L p .50685 .73947 L F P
0 g
s
.50092 .70765 m .50462 .7326 L p .50685 .73947 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .49935 .68856 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.50716 .7411 m .50947 .7302 L p .50374 .74867 L .707 .577 .707 r
F P
0 g
s
.50464 .73269 m .50506 .73421 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .50466 .73289 L p .50161 .76723 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .49873 .76084 L .5011 .76609 L p .707 .577 .707 r
F P
0 g
s
.5011 .76609 m .50161 .76723 L p .50466 .73289 L .707 .577 .707 r
F P
0 g
s
.50372 .66749 m .50834 .6986 L p .50462 .7326 L .707 .577 .707 r
F P
0 g
s
.50506 .73421 m .5058 .73688 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.5058 .73688 m .50738 .74259 L p .50581 .73668 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50709 .74089 L .50581 .73668 L .707 .577 .707 r
F
.50947 .7302 m .50659 .72382 L p .5053 .735 L F P
0 g
s
.50663 .73936 m .50947 .7302 L .5053 .735 L .707 .577 .707 r
F
.51952 .74901 m .51172 .69648 L p .51917 .74879 L F P
0 g
s
.52184 .73809 m .50947 .7302 L p .5108 .74343 L .707 .577 .707 r
F P
0 g
s
.50659 .72382 m .51347 .71956 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50466 .73289 m .50659 .72382 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50834 .6986 m .51174 .72152 L .50471 .73246 L p .707 .577 .707 r
F P
0 g
s
.50471 .73246 m .50462 .7326 L p .50834 .6986 L .707 .577 .707 r
F P
0 g
s
.49873 .76084 m .50466 .73289 L p .5055 .74188 L .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .50464 .73269 L p .50464 .73267 L .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .50715 .7411 L p .50709 .74089 L .707 .577 .707 r
F P
0 g
s
.51952 .74901 m .52184 .73809 L p .51215 .75686 L .707 .577 .707 r
F P
0 g
s
.54051 .75561 m .53123 .73655 L .51952 .74901 L .707 .577 .707 r
F
.53769 .75492 m .54051 .75561 L p .51952 .74901 L F P
0 g
s
.52184 .73809 m .51398 .77511 L .53463 .78372 L p .707 .577 .707 r
F P
0 g
s
.50738 .74259 m .51974 .75052 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.50715 .7411 m .50738 .74259 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51974 .75052 m .51952 .74901 L p .51917 .74879 L .707 .577 .707 r
F P
0 g
s
.51702 .74742 m .52184 .73809 L .5108 .74343 L .707 .577 .707 r
F
.52959 .76574 m .53706 .75471 L .52544 .75093 L F
.54055 .75584 m .54249 .7467 L p .52959 .76574 L F P
0 g
s
.51952 .74901 m .51974 .75052 L .53769 .75492 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .52184 .73809 L p .52544 .75093 L .707 .577 .707 r
F P
0 g
s
.53706 .75471 m .54249 .7467 L .52544 .75093 L .707 .577 .707 r
F
.53463 .78372 m .54055 .75584 L p .52959 .76574 L F P
0 g
s
.54078 .75562 m .56764 .75736 L p .5572 .74079 L .707 .577 .707 r
F P
0 g
s
.63108 .7686 m .62321 .80562 L .65196 .80922 L p .707 .577 .707 r
F P
0 g
s
.65196 .80922 m .65982 .7722 L .63108 .7686 L p .707 .577 .707 r
F P
0 g
s
.56153 .79222 m .56939 .75519 L .54249 .7467 L p .707 .577 .707 r
F P
0 g
s
.56939 .75519 m .56153 .79222 L .59205 .79976 L p .707 .577 .707 r
F P
0 g
s
.67504 .67856 m .68306 .73259 L .69936 .72152 L p .707 .577 .707 r
F P
0 g
s
.69936 .72152 m .69134 .66749 L .67504 .67856 L p .707 .577 .707 r
F P
0 g
s
.54249 .7467 m .53463 .78372 L .56153 .79222 L p .707 .577 .707 r
F P
0 g
s
.65982 .7722 m .65196 .80922 L .67547 .81021 L p .707 .577 .707 r
F P
0 g
s
.67547 .81021 m .68333 .77319 L .65982 .7722 L p .707 .577 .707 r
F P
0 g
s
.59892 .85633 m .59691 .83815 L .56593 .83901 L p .707 .577 .707 r
F P
0 g
s
.59691 .83815 m .59892 .85633 L .63059 .8523 L p .707 .577 .707 r
F P
0 g
s
.63059 .8523 m .62858 .83413 L .59691 .83815 L p .707 .577 .707 r
F P
0 g
s
.62858 .83413 m .63059 .8523 L .65985 .8455 L p .707 .577 .707 r
F P
0 g
s
.65985 .8455 m .65784 .82732 L .62858 .83413 L p .707 .577 .707 r
F P
0 g
s
.56593 .83901 m .56794 .85719 L .59892 .85633 L p .707 .577 .707 r
F P
0 g
s
.56794 .85719 m .56593 .83901 L .53868 .8366 L p .707 .577 .707 r
F P
0 g
s
.65784 .82732 m .65985 .8455 L .68384 .83658 L p .707 .577 .707 r
F P
0 g
s
.68384 .83658 m .68183 .8184 L .65784 .82732 L p .707 .577 .707 r
F P
0 g
s
.53868 .8366 m .54068 .85478 L .56794 .85719 L p .707 .577 .707 r
F P
0 g
s
.69134 .66749 m .69936 .72152 L .70649 .71044 L p .707 .577 .707 r
F P
0 g
s
.70649 .71044 m .69847 .65641 L .69134 .66749 L p .707 .577 .707 r
F P
0 g
s
.68333 .77319 m .67547 .81021 L .69145 .80849 L p .707 .577 .707 r
F P
0 g
s
.69145 .80849 m .69931 .77147 L .68333 .77319 L p .707 .577 .707 r
F P
0 g
s
.54068 .85478 m .53868 .8366 L .51782 .83118 L p .707 .577 .707 r
F P
0 g
s
.51782 .83118 m .51982 .84936 L .54068 .85478 L p .707 .577 .707 r
F P
0 g
s
.68183 .8184 m .68384 .83658 L .70021 .82643 L p .707 .577 .707 r
F P
0 g
s
.70021 .82643 m .6982 .80825 L .68183 .8184 L p .707 .577 .707 r
F P
0 g
s
.69847 .65641 m .70649 .71044 L .70373 .70045 L p .707 .577 .707 r
F P
0 g
s
.70373 .70045 m .69571 .64642 L .69847 .65641 L p .707 .577 .707 r
F P
0 g
s
.69931 .77147 m .69145 .80849 L .69834 .80423 L p .707 .577 .707 r
F P
0 g
s
.69834 .80423 m .7062 .76721 L .69931 .77147 L p .707 .577 .707 r
F P
0 g
s
.51982 .84936 m .51782 .83118 L .50539 .82327 L p .707 .577 .707 r
F P
0 g
s
.50539 .82327 m .5074 .84145 L .51982 .84936 L p .707 .577 .707 r
F P
0 g
s
.6982 .80825 m .70021 .82643 L .70736 .81603 L p .707 .577 .707 r
F P
0 g
s
.70736 .81603 m .70535 .79785 L .6982 .80825 L p .707 .577 .707 r
F P
0 g
s
.48871 .8218 m .48871 .31992 L .44482 .31709 L p .707 .577 .707 r
F P
0 g
s
.50462 .7326 m .4966 .67857 L .50372 .66749 L p .707 .577 .707 r
F P
0 g
s
.5074 .84145 m .50539 .82327 L .50261 .81364 L p .707 .577 .707 r
F P
0 g
s
.50261 .81364 m .50462 .83182 L .5074 .84145 L p .707 .577 .707 r
F P
0 g
s
.51347 .71956 m .51228 .72517 L p .49873 .76084 L .707 .577 .707 r
F P
0 g
s
.51228 .72517 m .50561 .75658 L .50109 .75938 L p .707 .577 .707 r
F P
0 g
s
.50109 .75938 m .49873 .76084 L p .51228 .72517 L .707 .577 .707 r
F P
0 g
s
.52003 .65642 m .52463 .68742 L p .51174 .72152 L .707 .577 .707 r
F P
0 g
s
.50561 .75658 m .51347 .71956 L .52946 .71784 L p .707 .577 .707 r
F P
0 g
s
.52463 .68742 m .52805 .71045 L .51397 .72001 L p .707 .577 .707 r
F P
0 g
s
.51397 .72001 m .51174 .72152 L p .52463 .68742 L .707 .577 .707 r
F P
0 g
s
.51174 .72152 m .50372 .66749 L .52003 .65642 L p .707 .577 .707 r
F P
0 g
s
.50462 .83182 m .50261 .81364 L .50976 .80324 L p .707 .577 .707 r
F P
0 g
s
.50976 .80324 m .51177 .82142 L .50462 .83182 L p .707 .577 .707 r
F P
0 g
s
.52946 .71784 m .5216 .75486 L .50561 .75658 L p .707 .577 .707 r
F P
0 g
s
.51177 .82142 m .50976 .80324 L .52613 .79308 L p .707 .577 .707 r
F P
0 g
s
.52613 .79308 m .52814 .81126 L .51177 .82142 L p .707 .577 .707 r
F P
0 g
s
.5216 .75486 m .52946 .71784 L .55297 .71883 L p .707 .577 .707 r
F P
0 g
s
.55297 .71883 m .54511 .75585 L .5216 .75486 L p .707 .577 .707 r
F P
0 g
s
.52814 .81126 m .52613 .79308 L .55012 .78417 L p .707 .577 .707 r
F P
0 g
s
.55012 .78417 m .55213 .80235 L .52814 .81126 L p .707 .577 .707 r
F P
0 g
s
.48871 .31992 m .48871 .8218 L .5337 .82085 L p .707 .577 .707 r
F P
0 g
s
.52805 .71045 m .52003 .65642 L .54392 .64643 L p .707 .577 .707 r
F P
0 g
s
.54392 .64643 m .55195 .70046 L .52805 .71045 L p .707 .577 .707 r
F P
0 g
s
.5337 .82085 m .5337 .31896 L .48871 .31992 L p .707 .577 .707 r
F P
0 g
s
.55195 .70046 m .54392 .64643 L .57307 .6385 L p .707 .577 .707 r
F P
0 g
s
.57307 .6385 m .58109 .69253 L .55195 .70046 L p .707 .577 .707 r
F P
0 g
s
.54511 .75585 m .55297 .71883 L .58171 .72243 L p .707 .577 .707 r
F P
0 g
s
.58171 .72243 m .57385 .75945 L .54511 .75585 L p .707 .577 .707 r
F P
0 g
s
.55213 .80235 m .55012 .78417 L .57938 .77736 L p .707 .577 .707 r
F P
0 g
s
.57938 .77736 m .58139 .79554 L .55213 .80235 L p .707 .577 .707 r
F P
0 g
s
.5337 .31896 m .5337 .82085 L .57539 .81622 L p .707 .577 .707 r
F P
0 g
s
.58109 .69253 m .57307 .6385 L .6046 .63341 L p .707 .577 .707 r
F P
0 g
s
.57385 .75945 m .58171 .72243 L .61287 .72829 L p .707 .577 .707 r
F P
0 g
s
.61287 .72829 m .60501 .76531 L .57385 .75945 L p .707 .577 .707 r
F P
0 g
s
.57539 .81622 m .57539 .31433 L .5337 .31896 L p .707 .577 .707 r
F P
0 g
s
.44482 .81898 m .44482 .31709 L .40634 .31077 L p .707 .577 .707 r
F P
0 g
s
.44482 .31709 m .44482 .81898 L .48871 .8218 L p .707 .577 .707 r
F P
0 g
s
.69571 .64642 m .70373 .70045 L .69137 .69253 L p .707 .577 .707 r
F P
0 g
s
.69137 .69253 m .68335 .63849 L .69571 .64642 L p .707 .577 .707 r
F P
0 g
s
.7062 .76721 m .69834 .80423 L .69546 .79785 L p .707 .577 .707 r
F P
0 g
s
.69546 .79785 m .70332 .76082 L .7062 .76721 L p .707 .577 .707 r
F P
0 g
s
.6046 .63341 m .61262 .68744 L .58109 .69253 L p .707 .577 .707 r
F P
0 g
s
.6434 .73584 m .63554 .77286 L .60501 .76531 L p .707 .577 .707 r
F P
0 g
s
.60501 .76531 m .61287 .72829 L .6434 .73584 L p .707 .577 .707 r
F P
0 g
s
.58139 .79554 m .57938 .77736 L .61105 .77334 L p .707 .577 .707 r
F P
0 g
s
.61105 .77334 m .61306 .79152 L .58139 .79554 L p .707 .577 .707 r
F P
0 g
s
.57539 .31433 m .57539 .81622 L .6097 .80835 L p .707 .577 .707 r
F P
0 g
s
.61262 .68744 m .6046 .63341 L .63545 .63165 L p .707 .577 .707 r
F P
0 g
s
.6097 .80835 m .6097 .30646 L .57539 .31433 L p .707 .577 .707 r
F P
0 g
s
.70535 .79785 m .70736 .81603 L .70458 .8064 L p .707 .577 .707 r
F P
0 g
s
.70458 .8064 m .70257 .78822 L .70535 .79785 L p .707 .577 .707 r
F P
0 g
s
.40634 .81265 m .40634 .31077 L .37702 .30156 L p .707 .577 .707 r
F P
0 g
s
.40634 .31077 m .40634 .81265 L .44482 .81898 L p .707 .577 .707 r
F P
0 g
s
.25424 .69954 m .25078 .64245 L .21967 .64336 L p .707 .577 .707 r
F P
0 g
s
.25078 .64245 m .25424 .69954 L .28602 .69727 L p .707 .577 .707 r
F P
0 g
s
.28602 .69727 m .28256 .64018 L .25078 .64245 L p .707 .577 .707 r
F P
0 g
s
.28256 .64018 m .28602 .69727 L .31535 .69387 L p .707 .577 .707 r
F P
0 g
s
.31535 .69387 m .3119 .63678 L .28256 .64018 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22312 .70046 m .21967 .64336 L .19227 .64283 L p .707 .577 .707 r
F P
0 g
s
.21967 .64336 m .22312 .70046 L .25424 .69954 L p .707 .577 .707 r
F P
0 g
s
.68335 .63849 m .69137 .69253 L .6706 .68744 L p .707 .577 .707 r
F P
0 g
s
.6706 .68744 m .66258 .6334 L .68335 .63849 L p .707 .577 .707 r
F P
0 g
s
.3119 .63678 m .31535 .69387 L .33937 .68967 L p .707 .577 .707 r
F P
0 g
s
.33937 .68967 m .33591 .63258 L .3119 .63678 L p .707 .577 .707 r
F P
0 g
s
.19227 .64283 m .19572 .69993 L .22312 .70046 L p .707 .577 .707 r
F P
0 g
s
.63545 .63165 m .64347 .68568 L .61262 .68744 L p .707 .577 .707 r
F P
0 g
s
.6703 .74433 m .66244 .78135 L .63554 .77286 L p .707 .577 .707 r
F P
0 g
s
.64203 .77248 m .64404 .79066 L .61306 .79152 L p .707 .577 .707 r
F P
0 g
s
.63554 .77286 m .6434 .73584 L .6703 .74433 L p .707 .577 .707 r
F P
0 g
s
.61306 .79152 m .61105 .77334 L .64203 .77248 L p .707 .577 .707 r
F P
0 g
s
.6097 .30646 m .6097 .80835 L .63327 .79802 L p .707 .577 .707 r
F P
0 g
s
.63327 .79802 m .63327 .29613 L .6097 .30646 L p .707 .577 .707 r
F P
0 g
s
.70332 .76082 m .69546 .79785 L .68309 .78996 L p .707 .577 .707 r
F P
0 g
s
.68309 .78996 m .69095 .75294 L .70332 .76082 L p .707 .577 .707 r
F P
0 g
s
.70257 .78822 m .70458 .8064 L .69215 .79849 L p .707 .577 .707 r
F P
0 g
s
.69215 .79849 m .69015 .78031 L .70257 .78822 L p .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .25343 .78659 L .23499 .7867 L p .707 .577 .707 r
F P
0 g
s
.23499 .7867 m .2223 .78678 L p .23022 .79142 L .707 .577 .707 r
F P
0 g
s
.2543 .80553 m .23499 .7867 L .23022 .79142 L .707 .577 .707 r
F
.25343 .78659 m .2543 .80553 L .2861 .80365 L p F P
0 g
s
.2861 .80365 m .28524 .7847 L .26816 .78571 L p .707 .577 .707 r
F P
0 g
s
.26816 .78571 m .25343 .78659 L p .26262 .79138 L .707 .577 .707 r
F P
0 g
s
.2861 .80365 m .26816 .78571 L .26262 .79138 L .707 .577 .707 r
F
.28524 .7847 m .2861 .80365 L .31548 .80027 L p F P
0 g
s
.31548 .80027 m .31461 .78132 L .30052 .78294 L p .707 .577 .707 r
F P
0 g
s
.30052 .78294 m .28524 .7847 L p .2952 .78983 L .707 .577 .707 r
F P
0 g
s
.31548 .80027 m .30052 .78294 L .2952 .78983 L .707 .577 .707 r
F
.31461 .78132 m .31548 .80027 L .33954 .79571 L p F P
0 g
s
.33954 .79571 m .33867 .77676 L .32841 .77871 L p .707 .577 .707 r
F P
0 g
s
.32841 .77871 m .31461 .78132 L p .32433 .78693 L .707 .577 .707 r
F P
0 g
s
.33954 .79571 m .32841 .77871 L .32433 .78693 L .707 .577 .707 r
F
.33867 .77676 m .33954 .79571 L .35593 .79043 L p F P
0 g
s
.35593 .79043 m .35507 .77148 L .33867 .77676 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .3528 .76861 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.34014 .74593 m .33899 .75739 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.33899 .75739 m .33673 .77998 L p .34254 .75023 L .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .33673 .77998 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31636 .75379 m .31536 .76376 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.31536 .76376 m .31295 .78784 L p .31973 .75812 L .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .31295 .78784 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2872 .75736 m .28621 .76725 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.28621 .76725 m .28379 .79142 L p .29122 .76213 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .28379 .79142 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25552 .7563 m .25439 .7675 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.25439 .7675 m .2521 .79036 L p .26004 .76192 L .707 .577 .707 r
F P
0 g
s
.2521 .79036 m .25552 .7563 L .22441 .75071 L p .707 .577 .707 r
F P
0 g
s
.28379 .79142 m .2872 .75736 L .25552 .7563 L p .707 .577 .707 r
F P
0 g
s
.19572 .69993 m .19227 .64283 L .17126 .64092 L p .707 .577 .707 r
F P
0 g
s
.31295 .78784 m .31636 .75379 L .2872 .75736 L p .707 .577 .707 r
F P
0 g
s
.22099 .78476 m .22441 .75071 L .19692 .74114 L p .707 .577 .707 r
F P
0 g
s
.22441 .75071 m .22099 .78476 L .2521 .79036 L p .707 .577 .707 r
F P
0 g
s
.17126 .64092 m .17471 .69801 L .19572 .69993 L p .707 .577 .707 r
F P
0 g
s
.66258 .6334 m .6706 .68744 L .64347 .68568 L p .707 .577 .707 r
F P
0 g
s
.64347 .68568 m .63545 .63165 L .66258 .6334 L p .707 .577 .707 r
F P
0 g
s
.37702 .80345 m .37702 .30156 L .35975 .29037 L p .707 .577 .707 r
F P
0 g
s
.37702 .30156 m .37702 .80345 L .40634 .81265 L p .707 .577 .707 r
F P
0 g
s
.33591 .63258 m .33937 .68967 L .35572 .68509 L p .707 .577 .707 r
F P
0 g
s
.35572 .68509 m .35227 .62799 L .33591 .63258 L p .707 .577 .707 r
F P
0 g
s
.2223 .78678 m .22317 .80572 L .2543 .80553 L p .707 .577 .707 r
F P
0 g
s
.22317 .80572 m .2223 .78678 L .1949 .78526 L p .707 .577 .707 r
F P
0 g
s
.33673 .77998 m .34014 .74593 L .31636 .75379 L p .707 .577 .707 r
F P
0 g
s
.19351 .77519 m .19692 .74114 L .17575 .72852 L p .707 .577 .707 r
F P
0 g
s
.19692 .74114 m .19351 .77519 L .22099 .78476 L p .707 .577 .707 r
F P
0 g
s
.1949 .78526 m .19576 .80421 L .22317 .80572 L p .707 .577 .707 r
F P
0 g
s
.69095 .75294 m .68309 .78996 L .66244 .78135 L p .707 .577 .707 r
F P
0 g
s
.66244 .78135 m .6703 .74433 L .69095 .75294 L p .707 .577 .707 r
F P
0 g
s
.17471 .69801 m .17126 .64092 L .1587 .63779 L p .707 .577 .707 r
F P
0 g
s
.69015 .78031 m .69215 .79849 L .67129 .79306 L p .707 .577 .707 r
F P
0 g
s
.67129 .79306 m .66929 .77488 L .69015 .78031 L p .707 .577 .707 r
F P
0 g
s
.64404 .79066 m .64203 .77248 L .66929 .77488 L p .707 .577 .707 r
F P
0 g
s
.63327 .29613 m .63327 .79802 L .6438 .78625 L p .707 .577 .707 r
F P
0 g
s
.6438 .78625 m .6438 .28436 L .63327 .29613 L p .707 .577 .707 r
F P
0 g
s
.1587 .63779 m .16215 .69489 L .17471 .69801 L p .707 .577 .707 r
F P
0 g
s
.19576 .80421 m .1949 .78526 L .1739 .78219 L p .707 .577 .707 r
F P
0 g
s
.17575 .72852 m .17234 .76257 L .19351 .77519 L p .707 .577 .707 r
F P
0 g
s
.1739 .78219 m .17476 .80114 L .19576 .80421 L p .707 .577 .707 r
F P
0 g
s
.3528 .76861 m .35622 .73456 L .34014 .74593 L p .707 .577 .707 r
F P
0 g
s
.17234 .76257 m .17575 .72852 L .16296 .71408 L p .707 .577 .707 r
F P
0 g
s
.35227 .62799 m .35572 .68509 L .3628 .68056 L p .707 .577 .707 r
F P
0 g
s
.3628 .68056 m .35935 .62347 L .35227 .62799 L p .707 .577 .707 r
F P
0 g
s
.35622 .73456 m .3528 .76861 L .3596 .75483 L p .707 .577 .707 r
F P
0 g
s
.3596 .75483 m .36301 .72078 L .35622 .73456 L p .707 .577 .707 r
F P
0 g
s
.35935 .62347 m .3628 .68056 L .35992 .67654 L p .707 .577 .707 r
F P
0 g
s
.35992 .67654 m .35647 .61945 L .35935 .62347 L p .707 .577 .707 r
F P
0 g
s
.35507 .77148 m .35593 .79043 L .36305 .78494 L p .707 .577 .707 r
F P
0 g
s
.36305 .78494 m .36219 .76599 L .35507 .77148 L p .707 .577 .707 r
F P
0 g
s
.36301 .72078 m .3596 .75483 L .35645 .74 L p .707 .577 .707 r
F P
0 g
s
.35645 .74 m .35986 .70595 L .36301 .72078 L p .707 .577 .707 r
F P
0 g
s
.35647 .61945 m .35992 .67654 L .34736 .67342 L p .707 .577 .707 r
F P
0 g
s
.36021 .77977 m .35934 .76083 L .36219 .76599 L p .707 .577 .707 r
F P
0 g
s
.35986 .70595 m .35645 .74 L .34366 .72557 L p .707 .577 .707 r
F P
0 g
s
.34366 .72557 m .34707 .69152 L .35986 .70595 L p .707 .577 .707 r
F P
0 g
s
.35934 .76083 m .36021 .77977 L .34767 .77544 L p .707 .577 .707 r
F P
0 g
s
.35974 .79226 m .35975 .29037 L .3562 .2783 L p .707 .577 .707 r
F P
0 g
s
.36219 .76599 m .36305 .78494 L .36021 .77977 L p .707 .577 .707 r
F P
0 g
s
.35975 .29037 m .35974 .79226 L .37702 .80345 L p .707 .577 .707 r
F P
0 g
s
.66929 .77488 m .67129 .79306 L .64404 .79066 L p .707 .577 .707 r
F P
0 g
s
.16215 .69489 m .1587 .63779 L .15582 .63378 L p .707 .577 .707 r
F P
0 g
s
.16296 .71408 m .15955 .74814 L .17234 .76257 L p .707 .577 .707 r
F P
0 g
s
.17476 .80114 m .1739 .78219 L .16136 .77786 L p .707 .577 .707 r
F P
0 g
s
.16136 .77786 m .16223 .79681 L .17476 .80114 L p .707 .577 .707 r
F P
0 g
s
.15955 .74814 m .16296 .71408 L .15981 .69925 L p .707 .577 .707 r
F P
0 g
s
.15981 .69925 m .1564 .7333 L .15955 .74814 L p .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15981 .69925 L .15988 .69912 L p .707 .577 .707 r
F P
0 g
s
.16 .69188 m .16215 .69489 L p .16024 .67645 L .707 .577 .707 r
F P
0 g
s
.15988 .69912 m .16661 .68548 L p .15957 .71843 L .707 .577 .707 r
F P
0 g
s
.1564 .7333 m .15988 .69912 L .15957 .71843 L .707 .577 .707 r
F
.15582 .63378 m .15927 .69087 L .16 .69188 L p F P
0 g
s
.16024 .67645 m .15582 .63378 L .16 .69188 L .707 .577 .707 r
F
.6438 .28436 m .6438 .78625 L .64025 .77418 L p F P
0 g
s
.64025 .77418 m .64025 .27229 L .6438 .28436 L p .707 .577 .707 r
F P
0 g
s
.15927 .69087 m .15582 .63378 L .1629 .62925 L p .707 .577 .707 r
F P
0 g
s
.16223 .79681 m .16136 .77786 L .15852 .7727 L p .707 .577 .707 r
F P
0 g
s
.15852 .7727 m .15938 .79165 L .16223 .79681 L p .707 .577 .707 r
F P
0 g
s
.1629 .62925 m .16636 .68635 L .15927 .69087 L p .707 .577 .707 r
F P
0 g
s
.34736 .67342 m .34391 .61633 L .35647 .61945 L p .707 .577 .707 r
F P
0 g
s
.34767 .77544 m .34681 .7565 L .35934 .76083 L p .707 .577 .707 r
F P
0 g
s
.3562 .2783 m .3562 .78019 L .35974 .79226 L p .707 .577 .707 r
F P
0 g
s
.3562 .78019 m .3562 .2783 L .36672 .26652 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17925 .62467 m .17975 .63286 L p .16636 .68635 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .18268 .6741 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .16604 .69118 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16661 .68548 L p .17857 .68369 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18268 .6741 L p .18616 .68153 L .707 .577 .707 r
F P
0 g
s
.18275 .68258 m .18616 .68153 L .19051 .69082 L .707 .577 .707 r
F
.18192 .68169 m .18616 .68153 L .18275 .68258 L F
.20672 .67756 m .18903 .68065 L p .20552 .6756 L F P
0 g
s
.20552 .6756 m .20646 .66624 L p .21189 .67565 L .707 .577 .707 r
F P
0 g
s
.20672 .67756 m .20666 .67647 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20552 .6756 m .21189 .67565 L .20666 .67647 L .707 .577 .707 r
F
.23606 .67416 m .20672 .67756 L p .20723 .67638 L F P
0 g
s
.20646 .66624 m .23562 .66267 L p .22634 .67339 L .707 .577 .707 r
F P
0 g
s
.21189 .67565 m .20646 .66624 L .22634 .67339 L .707 .577 .707 r
F
.23562 .66267 m .26731 .66373 L p .25861 .6719 L F P
0 g
s
.24199 .67277 m .23562 .66267 L .25861 .6719 L .707 .577 .707 r
F
.23606 .67416 m .23599 .67308 L p .23659 .67305 L F P
0 g
s
.23468 .67209 m .23562 .66267 L p .24199 .67277 L .707 .577 .707 r
F P
0 g
s
.23606 .67416 m .23659 .67305 L .267 .67192 L .707 .577 .707 r
F
.26653 .67149 m .26731 .66373 L p .28039 .68418 L F P
0 g
s
.26784 .67189 m .26703 .67195 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26703 .67195 m .23606 .67416 L p .267 .67192 L .707 .577 .707 r
F P
0 g
s
.26731 .66373 m .29842 .66932 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.26781 .67142 m .26784 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.26389 .69778 m .26653 .67149 L p .28039 .68418 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .24199 .67277 L .24783 .68203 L .707 .577 .707 r
F
.23468 .67209 m .24199 .67277 L .23599 .67308 L F
.26731 .66373 m .26389 .69778 L .23221 .69672 L p F P
0 g
s
.26438 .6148 m .26781 .67142 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.2326 .61707 m .26438 .6148 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23606 .67416 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.23562 .66267 m .23457 .67315 L p .20305 .70029 L .707 .577 .707 r
F P
0 g
s
.23457 .67315 m .23221 .69672 L .20593 .69994 L p .707 .577 .707 r
F P
0 g
s
.20593 .69994 m .20305 .70029 L p .23457 .67315 L .707 .577 .707 r
F P
0 g
s
.23599 .67308 m .23592 .67189 L p .23659 .67305 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .2326 .61707 L p .23647 .67138 L .707 .577 .707 r
F P
0 g
s
.23592 .67189 m .23647 .67138 L .23659 .67305 L .707 .577 .707 r
F
.24783 .68203 m .24199 .67277 L .25861 .6719 L F
.23221 .69672 m .23468 .67209 L p .24783 .68203 L F P
0 g
s
.2326 .61707 m .23592 .67189 L p .23468 .67209 L .707 .577 .707 r
F P
0 g
s
.20723 .67638 m .21533 .65745 L .23468 .67209 L .707 .577 .707 r
F
.21533 .65745 m .2326 .61707 L .23468 .67209 L F
.21688 .68432 m .21189 .67565 L .22634 .67339 L F
.20666 .67647 m .21189 .67565 L .21688 .68432 L F
.20327 .62047 m .2326 .61707 L p .20723 .67638 L F P
0 g
s
.18268 .6741 m .20646 .66624 L p .19051 .69082 L .707 .577 .707 r
F P
0 g
s
.20666 .67647 m .20659 .67528 L p .20723 .67638 L .707 .577 .707 r
F P
0 g
s
.20646 .66624 m .20305 .70029 L .17927 .70815 L p .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20327 .62047 L p .20711 .67466 L .707 .577 .707 r
F P
0 g
s
.20659 .67528 m .20711 .67466 L .20723 .67638 L .707 .577 .707 r
F
.20659 .67528 m .20666 .67647 L p .20552 .6756 L F P
0 g
s
.20666 .67647 m .20672 .67756 L p .20552 .6756 L .707 .577 .707 r
F P
0 g
s
.20305 .70029 m .20552 .6756 L p .21688 .68432 L .707 .577 .707 r
F P
0 g
s
.20327 .62047 m .20659 .67528 L p .18271 .68176 L .707 .577 .707 r
F P
0 g
s
.18903 .68065 m .18271 .68176 L p .20659 .67528 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .18271 .68176 L .18214 .68192 L p .707 .577 .707 r
F P
0 g
s
.18214 .68192 m .18101 .68224 L p .18192 .68169 L .707 .577 .707 r
F P
0 g
s
.18192 .68169 m .18267 .68124 L .18214 .68192 L .707 .577 .707 r
F
.17927 .70815 m .18192 .68169 L p .19051 .69082 L F P
0 g
s
.17927 .70815 m .16319 .71953 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.18268 .6741 m .1818 .68287 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.1818 .68287 m .17927 .70815 L p .16726 .71004 L .707 .577 .707 r
F P
0 g
s
.17925 .62467 m .20327 .62047 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18271 .68176 m .18267 .68124 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.18267 .68124 m .17925 .62467 L p .18323 .68021 L .707 .577 .707 r
F P
0 g
s
.17975 .63286 m .18267 .68124 L p .16723 .6861 L .707 .577 .707 r
F P
0 g
s
.18101 .68224 m .16723 .6861 L p .18267 .68124 L .707 .577 .707 r
F P
0 g
s
.16661 .68548 m .16604 .69118 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16723 .6861 m .16636 .68635 L p .17975 .63286 L .707 .577 .707 r
F P
0 g
s
.16319 .71953 m .1564 .7333 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.16604 .69118 m .16319 .71953 L p .15903 .72098 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64025 .27229 m .64025 .77418 L .62297 .76299 L p .707 .577 .707 r
F P
0 g
s
.62297 .76299 m .62297 .2611 L .64025 .27229 L p .707 .577 .707 r
F P
0 g
s
.16636 .68635 m .1629 .62925 L .17925 .62467 L p .707 .577 .707 r
F P
0 g
s
.15938 .79165 m .15852 .7727 L .16564 .76721 L p .707 .577 .707 r
F P
0 g
s
.16564 .76721 m .1665 .78615 L .15938 .79165 L p .707 .577 .707 r
F P
0 g
s
.34391 .61633 m .34736 .67342 L .32635 .6715 L p .707 .577 .707 r
F P
0 g
s
.32635 .6715 m .3229 .61441 L .34391 .61633 L p .707 .577 .707 r
F P
0 g
s
.36672 .76841 m .36672 .26652 L .3903 .2562 L p .707 .577 .707 r
F P
0 g
s
.36672 .26652 m .36672 .76841 L .3562 .78019 L p .707 .577 .707 r
F P
0 g
s
.34707 .69152 m .34366 .72557 L .32249 .71295 L p .707 .577 .707 r
F P
0 g
s
.32249 .71295 m .3259 .6789 L .34707 .69152 L p .707 .577 .707 r
F P
0 g
s
.1665 .78615 m .16564 .76721 L .18203 .76192 L p .707 .577 .707 r
F P
0 g
s
.18203 .76192 m .1829 .78087 L .1665 .78615 L p .707 .577 .707 r
F P
0 g
s
.62297 .2611 m .62297 .76299 L .59366 .75378 L p .707 .577 .707 r
F P
0 g
s
.59366 .75378 m .59366 .25189 L .62297 .2611 L p .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .3259 .6789 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.295 .70337 m .29796 .67385 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29796 .67385 m .29842 .66932 L p .31071 .69093 L .707 .577 .707 r
F P
0 g
s
.29842 .66932 m .295 .70337 L .26389 .69778 L p .707 .577 .707 r
F P
0 g
s
.2955 .61388 m .29895 .67098 L .29589 .67107 L p .707 .577 .707 r
F P
0 g
s
.29589 .67107 m .26784 .67189 L p .27901 .64846 L .707 .577 .707 r
F P
0 g
s
.27901 .64846 m .2955 .61388 L .29589 .67107 L .707 .577 .707 r
F
.3229 .61441 m .32635 .6715 L .29895 .67098 L p F P
0 g
s
.29895 .67098 m .2955 .61388 L .3229 .61441 L p .707 .577 .707 r
F P
0 g
s
.34681 .7565 m .34767 .77544 L .32667 .77237 L p .707 .577 .707 r
F P
0 g
s
.32667 .77237 m .32581 .75342 L .34681 .7565 L p .707 .577 .707 r
F P
0 g
s
.3259 .6789 m .32249 .71295 L .295 .70337 L p .707 .577 .707 r
F P
0 g
s
.26784 .67189 m .26438 .6148 L .2955 .61388 L p .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73561 .61666 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .74139 .66903 L .73359 .67036 L .707 .577 .707 r
F
.73347 .66902 m .73359 .67036 L p .74139 .66903 L F P
0 g
s
.73561 .61666 m .7045 .61212 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.7045 .61212 m .70105 .66491 L .73216 .66946 L p .707 .577 .707 r
F P
0 g
s
.73269 .66031 m .70158 .66262 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.7361 .69854 m .73347 .66902 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73297 .66947 L p .73299 .66944 L .707 .577 .707 r
F P
0 g
s
.73561 .61666 m .73219 .66902 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76739 .61726 m .73561 .61666 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76408 .66795 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76739 .61726 L p .76353 .6675 L .707 .577 .707 r
F P
0 g
s
.76408 .66795 m .76353 .6675 L .76341 .66905 L .707 .577 .707 r
F
.79695 .69205 m .77366 .66719 L .76543 .66905 L F
.76543 .66905 m .76779 .69551 L .79407 .69239 L p F P
0 g
s
.79407 .69239 m .79695 .69205 L p .76543 .66905 L .707 .577 .707 r
F P
0 g
s
.76779 .69551 m .76543 .66905 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.75216 .67984 m .76401 .66905 L .74139 .66903 L .707 .577 .707 r
F
.76779 .69551 m .76401 .66905 L .75216 .67984 L F
.76532 .66785 m .76543 .66905 L p .77366 .66719 L F P
0 g
s
.76408 .66795 m .76401 .66905 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76401 .66905 m .76437 .65728 L .74139 .66903 L .707 .577 .707 r
F
.76543 .66905 m .76532 .66785 L p .76401 .66905 L F P
0 g
s
.76739 .61726 m .76408 .66795 L p .76532 .66785 L .707 .577 .707 r
F P
0 g
s
.76532 .66785 m .76437 .65728 L p .76401 .66905 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .78467 .65022 L .76532 .66785 L .707 .577 .707 r
F
.78467 .65022 m .76739 .61726 L .76532 .66785 L F
.79673 .61384 m .76739 .61726 L p .79114 .66256 L F P
0 g
s
.79277 .66567 m .79289 .66407 L .79114 .66256 L .707 .577 .707 r
F
.79289 .66407 m .79673 .61384 L .79114 .66256 L F
.79695 .69205 m .82073 .68851 L p .81965 .68713 L F P
0 g
s
.79334 .66562 m .79341 .66452 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79673 .61384 L p .79289 .66407 L .707 .577 .707 r
F P
0 g
s
.79341 .66452 m .79289 .66407 L .79277 .66567 L .707 .577 .707 r
F
.79334 .66562 m .79353 .65382 L .77366 .66719 L F
.79458 .66553 m .79447 .66433 L p .79334 .66562 L F P
0 g
s
.79673 .61384 m .79341 .66452 L p .79451 .66429 L .707 .577 .707 r
F P
0 g
s
.81097 .66141 m .81729 .65954 L p .79341 .66452 L .707 .577 .707 r
F P
0 g
s
.79447 .66433 m .79353 .65382 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81098 .6455 L .79451 .66429 L .707 .577 .707 r
F
.81098 .6455 m .79673 .61384 L .79451 .66429 L F
.81965 .68713 m .81794 .66017 L .80088 .66319 L F
.79353 .65382 m .79458 .66553 L p .81965 .68713 L F P
0 g
s
.79458 .66553 m .79695 .69205 L p .81965 .68713 L .707 .577 .707 r
F P
0 g
s
.79695 .69205 m .79458 .66553 L p .79334 .66562 L .707 .577 .707 r
F P
0 g
s
.78312 .67729 m .79334 .66562 L .77366 .66719 L .707 .577 .707 r
F
.79695 .69205 m .79334 .66562 L .78312 .67729 L F
.79327 .66663 m .81097 .66141 L p .79447 .66433 L F P
0 g
s
.79341 .66452 m .79334 .66562 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.79334 .66562 m .79327 .66663 L p .79447 .66433 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .82075 .60675 L .79673 .61384 L p .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .79353 .65382 L p .80088 .66319 L .707 .577 .707 r
F P
0 g
s
.82073 .68851 m .83681 .68523 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.82075 .60675 m .81732 .65906 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .82073 .68851 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81729 .65954 m .81786 .65919 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.81732 .65906 m .81729 .65954 L p .81788 .65887 L .707 .577 .707 r
F P
0 g
s
.83001 .63745 m .82075 .60675 L .81788 .65887 L .707 .577 .707 r
F
.81808 .6588 m .81788 .65887 L .81786 .65919 L F
.83001 .63745 m .81788 .65887 L .81808 .6588 L F
.83364 .64946 m .83001 .63745 L .81808 .6588 L F
.82069 .68802 m .81808 .6588 L p .81965 .68713 L F P
0 g
s
.81808 .6588 m .81732 .65028 L p .81788 .65916 L .707 .577 .707 r
F P
0 g
s
.81808 .6588 m .81788 .65916 L .81965 .68713 L .707 .577 .707 r
F
.81786 .65919 m .81899 .65849 L p .81808 .6588 L F P
0 g
s
.81899 .65849 m .83364 .64946 L p .81808 .6588 L .707 .577 .707 r
F P
0 g
s
.83364 .64946 m .8371 .59667 L .82075 .60675 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .81732 .65028 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83681 .68523 m .83396 .6534 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.83396 .6534 m .83339 .647 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81732 .65028 m .81808 .6588 L p .82143 .65766 L .707 .577 .707 r
F P
0 g
s
.81724 .66029 m .81732 .65028 L .80088 .66319 L .707 .577 .707 r
F
.81794 .66017 m .81788 .65916 L .81724 .66029 L F
.81788 .65916 m .81732 .65028 L .81724 .66029 L F
.82073 .68851 m .82069 .68802 L p .81965 .68713 L F P
0 g
s
.79353 .65382 m .76437 .65728 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.79327 .66663 m .79334 .66562 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.79277 .66567 m .76532 .66785 L .76394 .67005 L .707 .577 .707 r
F
.76401 .66905 m .76394 .67005 L p .76532 .66785 L F P
0 g
s
.76394 .67005 m .79327 .66663 L p .79277 .66567 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .76532 .66785 L p .77366 .66719 L .707 .577 .707 r
F P
0 g
s
.76437 .65728 m .73269 .66031 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76401 .66905 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73219 .66902 m .73216 .66946 L p .76341 .66905 L .707 .577 .707 r
F P
0 g
s
.73216 .66946 m .73219 .66902 L p .73175 .6686 L .707 .577 .707 r
F P
0 g
s
.73347 .66902 m .73269 .66031 L p .71961 .68138 L .707 .577 .707 r
F P
0 g
s
.76394 .67005 m .76341 .66905 L .73299 .66944 L .707 .577 .707 r
F
.73297 .66947 m .76394 .67005 L p .73299 .66944 L F P
0 g
s
.73269 .66031 m .73347 .66902 L p .74139 .66903 L .707 .577 .707 r
F P
0 g
s
.73359 .67036 m .7361 .69854 L .76062 .69619 L p .707 .577 .707 r
F P
0 g
s
.76062 .69619 m .76779 .69551 L p .73359 .67036 L .707 .577 .707 r
F P
0 g
s
.3903 .2562 m .3903 .75809 L .36672 .76841 L p .707 .577 .707 r
F P
0 g
s
.3903 .75809 m .3903 .2562 L .42461 .24833 L p .707 .577 .707 r
F P
0 g
s
.1829 .78087 m .18203 .76192 L .20609 .75737 L p .707 .577 .707 r
F P
0 g
s
.70105 .66491 m .7045 .61212 L .6771 .60406 L p .707 .577 .707 r
F P
0 g
s
.20609 .75737 m .20696 .77631 L .1829 .78087 L p .707 .577 .707 r
F P
0 g
s
.32581 .75342 m .32667 .77237 L .29927 .77086 L p .707 .577 .707 r
F P
0 g
s
.29927 .77086 m .2984 .75191 L .32581 .75342 L p .707 .577 .707 r
F P
0 g
s
.59366 .25189 m .59366 .75378 L .55518 .74746 L p .707 .577 .707 r
F P
0 g
s
.55518 .74746 m .55518 .24557 L .59366 .25189 L p .707 .577 .707 r
F P
0 g
s
.67364 .65685 m .6771 .60406 L .65609 .59329 L p .707 .577 .707 r
F P
0 g
s
.6771 .60406 m .67364 .65685 L .70105 .66491 L p .707 .577 .707 r
F P
0 g
s
.20696 .77631 m .20609 .75737 L .23547 .75398 L p .707 .577 .707 r
F P
0 g
s
.70158 .66262 m .705 .70085 L .7361 .69854 L p .707 .577 .707 r
F P
0 g
s
.23547 .75398 m .23633 .77293 L .20696 .77631 L p .707 .577 .707 r
F P
0 g
s
.42461 .75022 m .42461 .24833 L .4663 .2437 L p .707 .577 .707 r
F P
0 g
s
.42461 .24833 m .42461 .75022 L .3903 .75809 L p .707 .577 .707 r
F P
0 g
s
.705 .70085 m .70158 .66262 L .6741 .66398 L p .707 .577 .707 r
F P
0 g
s
.2984 .75191 m .29927 .77086 L .26814 .77105 L p .707 .577 .707 r
F P
0 g
s
.26814 .77105 m .26727 .7521 L .2984 .75191 L p .707 .577 .707 r
F P
0 g
s
.6741 .66398 m .67751 .70221 L .705 .70085 L p .707 .577 .707 r
F P
0 g
s
.23633 .77293 m .23547 .75398 L .26727 .7521 L p .707 .577 .707 r
F P
0 g
s
.55518 .24557 m .55518 .74746 L .51129 .74463 L p .707 .577 .707 r
F P
0 g
s
.51129 .74463 m .51129 .24274 L .55518 .24557 L p .707 .577 .707 r
F P
0 g
s
.26727 .7521 m .26814 .77105 L .23633 .77293 L p .707 .577 .707 r
F P
0 g
s
.65264 .64608 m .65609 .59329 L .64353 .58085 L p .707 .577 .707 r
F P
0 g
s
.65609 .59329 m .65264 .64608 L .67364 .65685 L p .707 .577 .707 r
F P
0 g
s
.73186 .76859 m .73272 .75072 L .70159 .7468 L p .707 .577 .707 r
F P
0 g
s
.73272 .75072 m .73186 .76859 L .76367 .76887 L p .707 .577 .707 r
F P
0 g
s
.76367 .76887 m .76453 .751 L .73272 .75072 L p .707 .577 .707 r
F P
0 g
s
.4663 .74558 m .4663 .2437 L .51129 .24274 L p .707 .577 .707 r
F P
0 g
s
.4663 .2437 m .4663 .74558 L .42461 .75022 L p .707 .577 .707 r
F P
0 g
s
.67751 .70221 m .6741 .66398 L .65292 .66426 L p .707 .577 .707 r
F P
0 g
s
.76453 .751 m .76367 .76887 L .79304 .76549 L p .707 .577 .707 r
F P
0 g
s
.79304 .76549 m .7939 .74762 L .76453 .751 L p .707 .577 .707 r
F P
0 g
s
.65292 .66426 m .65634 .70249 L .67751 .70221 L p .707 .577 .707 r
F P
0 g
s
.51129 .24274 m .51129 .74463 L .4663 .74558 L p .707 .577 .707 r
F P
0 g
s
.70073 .76467 m .70159 .7468 L .67419 .73963 L p .707 .577 .707 r
F P
0 g
s
.70159 .7468 m .70073 .76467 L .73186 .76859 L p .707 .577 .707 r
F P
0 g
s
.67419 .73963 m .67333 .7575 L .70073 .76467 L p .707 .577 .707 r
F P
0 g
s
.7939 .74762 m .79304 .76549 L .8171 .75876 L p .707 .577 .707 r
F P
0 g
s
.8171 .75876 m .81796 .74089 L .7939 .74762 L p .707 .577 .707 r
F P
0 g
s
.8371 .59667 m .83364 .64946 L .84072 .63739 L p .707 .577 .707 r
F P
0 g
s
.84072 .63739 m .84418 .5846 L .8371 .59667 L p .707 .577 .707 r
F P
0 g
s
.67333 .7575 m .67419 .73963 L .65319 .7299 L p .707 .577 .707 r
F P
0 g
s
.64353 .58085 m .64008 .63364 L .65264 .64608 L p .707 .577 .707 r
F P
0 g
s
.64008 .63364 m .64353 .58085 L .64065 .56796 L p .707 .577 .707 r
F P
0 g
s
.65634 .70249 m .65292 .66426 L .64014 .66343 L p .707 .577 .707 r
F P
0 g
s
.65319 .7299 m .65233 .74777 L .67333 .7575 L p .707 .577 .707 r
F P
0 g
s
.64014 .66343 m .64355 .70166 L .65634 .70249 L p .707 .577 .707 r
F P
0 g
s
.81796 .74089 m .8171 .75876 L .8335 .74936 L p .707 .577 .707 r
F P
0 g
s
.8335 .74936 m .83436 .73149 L .81796 .74089 L p .707 .577 .707 r
F P
0 g
s
.83339 .647 m .83681 .68523 L .8436 .68253 L p .707 .577 .707 r
F P
0 g
s
.8436 .68253 m .84019 .6443 L .83339 .647 L p .707 .577 .707 r
F P
0 g
s
.65233 .74777 m .65319 .7299 L .64065 .71857 L p .707 .577 .707 r
F P
0 g
s
.84418 .5846 m .84072 .63739 L .83785 .6245 L p .707 .577 .707 r
F P
0 g
s
.83785 .6245 m .8413 .57171 L .84418 .5846 L p .707 .577 .707 r
F P
0 g
s
.64065 .56796 m .6372 .62075 L .64008 .63364 L p .707 .577 .707 r
F P
0 g
s
.64065 .71857 m .63979 .73644 L .65233 .74777 L p .707 .577 .707 r
F P
0 g
s
.6372 .62075 m .64065 .56796 L .64773 .55589 L p .707 .577 .707 r
F P
0 g
s
.64355 .70166 m .64014 .66343 L .63699 .66158 L p .707 .577 .707 r
F P
0 g
s
.63699 .66158 m .6404 .69981 L .64355 .70166 L p .707 .577 .707 r
F P
0 g
s
.83436 .73149 m .8335 .74936 L .84062 .73821 L p .707 .577 .707 r
F P
0 g
s
.84062 .73821 m .84148 .72034 L .83436 .73149 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63979 .73644 m .64065 .71857 L .63781 .70675 L p .707 .577 .707 r
F P
0 g
s
.84019 .6443 m .8436 .68253 L .84045 .68067 L p .707 .577 .707 r
F P
0 g
s
.84045 .68067 m .83703 .64245 L .84019 .6443 L p .707 .577 .707 r
F P
0 g
s
.8413 .57171 m .83785 .6245 L .82529 .61206 L p .707 .577 .707 r
F P
0 g
s
.82529 .61206 m .82874 .55927 L .8413 .57171 L p .707 .577 .707 r
F P
0 g
s
.64773 .55589 m .64428 .60868 L .6372 .62075 L p .707 .577 .707 r
F P
0 g
s
.63781 .70675 m .63695 .72462 L .63979 .73644 L p .707 .577 .707 r
F P
0 g
s
.64428 .60868 m .64773 .55589 L .66408 .54581 L p .707 .577 .707 r
F P
0 g
s
.6404 .69981 m .63699 .66158 L .64378 .65888 L p .707 .577 .707 r
F P
0 g
s
.64378 .65888 m .6472 .69711 L .6404 .69981 L p .707 .577 .707 r
F P
0 g
s
.38737 .61375 m .39539 .5579 L .36455 .55215 L p .707 .577 .707 r
F P
0 g
s
.39539 .5579 m .38737 .61375 L .41891 .6175 L p .707 .577 .707 r
F P
0 g
s
.41891 .6175 m .42693 .56164 L .39539 .5579 L p .707 .577 .707 r
F P
0 g
s
.84148 .72034 m .84062 .73821 L .83777 .72638 L p .707 .577 .707 r
F P
0 g
s
.83777 .72638 m .83863 .70851 L .84148 .72034 L p .707 .577 .707 r
F P
0 g
s
.42693 .56164 m .41891 .6175 L .44805 .61887 L p .707 .577 .707 r
F P
0 g
s
.44805 .61887 m .45607 .56301 L .42693 .56164 L p .707 .577 .707 r
F P
0 g
s
.35653 .60801 m .36455 .55215 L .33742 .54496 L p .707 .577 .707 r
F P
0 g
s
.36455 .55215 m .35653 .60801 L .38737 .61375 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63695 .72462 m .63781 .70675 L .64493 .69559 L p .707 .577 .707 r
F P
0 g
s
.82874 .55927 m .82529 .61206 L .80428 .60129 L p .707 .577 .707 r
F P
0 g
s
.80428 .60129 m .80773 .5485 L .82874 .55927 L p .707 .577 .707 r
F P
0 g
s
.66408 .54581 m .66063 .5986 L .64428 .60868 L p .707 .577 .707 r
F P
0 g
s
.83703 .64245 m .84045 .68067 L .82766 .67985 L p .707 .577 .707 r
F P
0 g
s
.82766 .67985 m .82425 .64162 L .83703 .64245 L p .707 .577 .707 r
F P
0 g
s
.45607 .56301 m .44805 .61887 L .47195 .61773 L p .707 .577 .707 r
F P
0 g
s
.47195 .61773 m .47997 .56187 L .45607 .56301 L p .707 .577 .707 r
F P
0 g
s
.64493 .69559 m .64407 .71346 L .63695 .72462 L p .707 .577 .707 r
F P
0 g
s
.33742 .54496 m .3294 .60082 L .35653 .60801 L p .707 .577 .707 r
F P
0 g
s
.66063 .5986 m .66408 .54581 L .6881 .53872 L p .707 .577 .707 r
F P
0 g
s
.3294 .60082 m .33742 .54496 L .31665 .53703 L p .707 .577 .707 r
F P
0 g
s
.39499 .6899 m .38712 .65467 L .3566 .65815 L p .707 .577 .707 r
F P
0 g
s
.38712 .65467 m .39499 .6899 L .42615 .68278 L p .707 .577 .707 r
F P
0 g
s
.42615 .68278 m .41828 .64754 L .38712 .65467 L p .707 .577 .707 r
F P
0 g
s
.41828 .64754 m .42615 .68278 L .45489 .6727 L p .707 .577 .707 r
F P
0 g
s
.45489 .6727 m .44703 .63747 L .41828 .64754 L p .707 .577 .707 r
F P
0 g
s
.6472 .69711 m .64378 .65888 L .65986 .6556 L p .707 .577 .707 r
F P
0 g
s
.83863 .70851 m .83777 .72638 L .82524 .71505 L p .707 .577 .707 r
F P
0 g
s
.82524 .71505 m .8261 .69718 L .83863 .70851 L p .707 .577 .707 r
F P
0 g
s
.65986 .6556 m .66327 .69383 L .6472 .69711 L p .707 .577 .707 r
F P
0 g
s
.36446 .69339 m .3566 .65815 L .3297 .65765 L p .707 .577 .707 r
F P
0 g
s
.3566 .65815 m .36446 .69339 L .39499 .6899 L p .707 .577 .707 r
F P
0 g
s
.31665 .53703 m .30863 .59289 L .3294 .60082 L p .707 .577 .707 r
F P
0 g
s
.44703 .63747 m .45489 .6727 L .4784 .66067 L p .707 .577 .707 r
F P
0 g
s
.4784 .66067 m .47054 .62544 L .44703 .63747 L p .707 .577 .707 r
F P
0 g
s
.80773 .5485 m .80428 .60129 L .77688 .59323 L p .707 .577 .707 r
F P
0 g
s
.77688 .59323 m .78033 .54044 L .80773 .5485 L p .707 .577 .707 r
F P
0 g
s
.38694 .718 m .38894 .69936 L .35797 .69458 L p .707 .577 .707 r
F P
0 g
s
.38894 .69936 m .38694 .718 L .41861 .72061 L p .707 .577 .707 r
F P
0 g
s
.41861 .72061 m .42062 .70197 L .38894 .69936 L p .707 .577 .707 r
F P
0 g
s
.48603 .61468 m .48825 .6142 L p .47536 .59393 L .707 .577 .707 r
F P
0 g
s
.48652 .61263 m .48772 .61797 L p .50127 .63552 L .707 .577 .707 r
F P
0 g
s
.48772 .61797 m .49438 .64786 L .49891 .63976 L p .707 .577 .707 r
F P
0 g
s
.49891 .63976 m .50127 .63552 L p .48772 .61797 L .707 .577 .707 r
F P
0 g
s
.47997 .56187 m .47536 .59393 L p .48825 .6142 L .707 .577 .707 r
F P
0 g
s
.47536 .59393 m .47195 .61773 L .48603 .61468 L p .707 .577 .707 r
F P
0 g
s
.48825 .6142 m .49627 .55834 L .47997 .56187 L p .707 .577 .707 r
F P
0 g
s
.68465 .59151 m .6881 .53872 L .71744 .5353 L p .707 .577 .707 r
F P
0 g
s
.6881 .53872 m .68465 .59151 L .66063 .5986 L p .707 .577 .707 r
F P
0 g
s
.64407 .71346 m .64493 .69559 L .66132 .68619 L p .707 .577 .707 r
F P
0 g
s
.42062 .70197 m .41861 .72061 L .44787 .72079 L p .707 .577 .707 r
F P
0 g
s
.44787 .72079 m .44988 .70215 L .42062 .70197 L p .707 .577 .707 r
F P
0 g
s
.35797 .69458 m .35596 .71321 L .38694 .718 L p .707 .577 .707 r
F P
0 g
s
.35596 .71321 m .35693 .7042 L p .33071 .68808 L .707 .577 .707 r
F P
0 g
s
.34841 .6923 m .33071 .68808 L p .35693 .7042 L .707 .577 .707 r
F P
0 g
s
.33756 .69289 m .33245 .67001 L p .30905 .65321 L .707 .577 .707 r
F P
0 g
s
.33245 .67001 m .3297 .65765 L .3225 .6561 L p .707 .577 .707 r
F P
0 g
s
.3225 .6561 m .30905 .65321 L p .33245 .67001 L .707 .577 .707 r
F P
0 g
s
.35693 .7042 m .35797 .69458 L .34841 .6923 L p .707 .577 .707 r
F P
0 g
s
.30863 .59289 m .31665 .53703 L .30428 .52914 L p .707 .577 .707 r
F P
0 g
s
.82425 .64162 m .82766 .67985 L .80649 .68013 L p .707 .577 .707 r
F P
0 g
s
.80649 .68013 m .80307 .6419 L .82425 .64162 L p .707 .577 .707 r
F P
0 g
s
.3297 .65765 m .33756 .69289 L .36446 .69339 L p .707 .577 .707 r
F P
0 g
s
.66132 .68619 m .66046 .70406 L .64407 .71346 L p .707 .577 .707 r
F P
0 g
s
.33071 .68808 m .3287 .70672 L .35596 .71321 L p .707 .577 .707 r
F P
0 g
s
.78033 .54044 m .77688 .59323 L .74576 .58869 L p .707 .577 .707 r
F P
0 g
s
.74576 .58869 m .74922 .53589 L .78033 .54044 L p .707 .577 .707 r
F P
0 g
s
.71398 .58809 m .71744 .5353 L .74922 .53589 L p .707 .577 .707 r
F P
0 g
s
.71744 .5353 m .71398 .58809 L .68465 .59151 L p .707 .577 .707 r
F P
0 g
s
.47054 .62544 m .4784 .66067 L .49438 .64786 L p .707 .577 .707 r
F P
0 g
s
.49438 .64786 m .48652 .61263 L .47054 .62544 L p .707 .577 .707 r
F P
0 g
s
.44988 .70215 m .44787 .72079 L .47186 .71852 L p .707 .577 .707 r
F P
0 g
s
.47186 .71852 m .47387 .69988 L .44988 .70215 L p .707 .577 .707 r
F P
0 g
s
.74922 .53589 m .74576 .58869 L .71398 .58809 L p .707 .577 .707 r
F P
0 g
s
.66327 .69383 m .65986 .6556 L .68364 .65206 L p .707 .577 .707 r
F P
0 g
s
.30428 .52914 m .29626 .585 L .30863 .59289 L p .707 .577 .707 r
F P
0 g
s
.8261 .69718 m .82524 .71505 L .80424 .70532 L p .707 .577 .707 r
F P
0 g
s
.80424 .70532 m .8051 .68746 L .8261 .69718 L p .707 .577 .707 r
F P
0 g
s
.3287 .70672 m .3295 .69934 L p .30985 .68052 L .707 .577 .707 r
F P
0 g
s
.32216 .68498 m .30985 .68052 L p .3295 .69934 L .707 .577 .707 r
F P
0 g
s
.31691 .68845 m .31147 .66407 L p .29668 .64528 L .707 .577 .707 r
F P
0 g
s
.31147 .66407 m .30905 .65321 L .3044 .65023 L p .707 .577 .707 r
F P
0 g
s
.3044 .65023 m .29668 .64528 L p .31147 .66407 L .707 .577 .707 r
F P
0 g
s
.3295 .69934 m .33071 .68808 L .32216 .68498 L p .707 .577 .707 r
F P
0 g
s
.68364 .65206 m .68705 .69028 L .66327 .69383 L p .707 .577 .707 r
F P
0 g
s
.30985 .68052 m .30784 .69916 L .3287 .70672 L p .707 .577 .707 r
F P
0 g
s
.30905 .65321 m .31691 .68845 L .33756 .69289 L p .707 .577 .707 r
F P
0 g
s
.66046 .70406 m .66132 .68619 L .68538 .67947 L p .707 .577 .707 r
F P
0 g
s
.49166 .5905 m .48825 .6142 L .49529 .60869 L p .707 .577 .707 r
F P
0 g
s
.49341 .60029 m .48652 .61263 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.50127 .63552 m .49534 .60891 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49534 .60891 m .49341 .60029 L p .4945 .625 L .707 .577 .707 r
F P
0 g
s
.49627 .55834 m .49166 .5905 L p .49538 .60862 L .707 .577 .707 r
F P
0 g
s
.49529 .60869 m .49538 .60862 L p .49166 .5905 L .707 .577 .707 r
F P
0 g
s
.49538 .60862 m .5034 .55276 L .49627 .55834 L p .707 .577 .707 r
F P
0 g
s
.5034 .55276 m .49538 .60862 L .49535 .60856 L p .707 .577 .707 r
F P
0 g
s
.49493 .60748 m .49262 .60154 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49469 .60662 L .49534 .60892 L .708 .578 .707 r
F
.49341 .60029 m .49534 .60891 L p .49469 .60662 L F P
0 g
s
.49534 .60891 m .49534 .60892 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49535 .60856 m .49493 .60748 L p .49668 .58319 L .707 .577 .707 r
F P
0 g
s
.49053 .58963 m .49341 .60029 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.49262 .60154 m .49284 .60001 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49262 .60154 m .48026 .59365 L p .48082 .59231 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .4922 .59959 L .49262 .60154 L .707 .577 .707 r
F
.49839 .62486 m .48602 .61693 L p .4892 .59767 L F P
0 g
s
.49053 .58963 m .49284 .6 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .49262 .60154 L p .4922 .59959 L .707 .577 .707 r
F P
0 g
s
.47816 .58169 m .49053 .58963 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48735 .57695 m .49284 .6 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49284 .60001 L .4922 .59959 L F
.48048 .59209 m .47816 .58169 L .4892 .59767 L F
.48048 .59209 m .48026 .59365 L p .47932 .59175 L F P
0 g
s
.47816 .58169 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45751 .57726 m .47816 .58169 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .46231 .58679 L p .47932 .59175 L .707 .577 .707 r
F P
0 g
s
.46537 .61249 m .45945 .58596 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.45946 .58596 m .45751 .57726 L .47456 .59036 L .707 .577 .707 r
F
.45945 .58596 m .45751 .57726 L p .45946 .58596 L F P
0 g
s
.45751 .57726 m .46537 .61249 L .43847 .61199 L p .707 .577 .707 r
F P
0 g
s
.46751 .52986 m .45949 .58572 L .45921 .58565 L p .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .45751 .57726 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43847 .61199 m .43182 .58221 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43182 .58221 m .43061 .57676 L p .44554 .5991 L .707 .577 .707 r
F P
0 g
s
.43061 .57676 m .43847 .61199 L .40794 .61548 L p .707 .577 .707 r
F P
0 g
s
.40794 .61548 m .40008 .58024 L .43061 .57676 L p .707 .577 .707 r
F P
0 g
s
.44038 .52267 m .43236 .57853 L .42821 .57776 L p .707 .577 .707 r
F P
0 g
s
.42821 .57776 m .40151 .57278 L p .41258 .55851 L .707 .577 .707 r
F P
0 g
s
.41258 .55851 m .44038 .52267 L .42821 .57776 L .707 .577 .707 r
F
.45921 .58565 m .43236 .57853 L p .4428 .56408 L F P
0 g
s
.4428 .56408 m .46751 .52986 L .45921 .58565 L .707 .577 .707 r
F
.45945 .58596 m .45945 .58596 L p .45946 .58596 L F P
0 g
s
.45949 .58572 m .46877 .57027 L .47932 .59175 L .707 .577 .707 r
F
.46231 .58679 m .45949 .58572 L p .47932 .59175 L F P
0 g
s
.46877 .57027 m .48048 .59209 L .47932 .59175 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L .47932 .59175 L F
.48602 .61693 m .46537 .61249 L p .47456 .59036 L F P
0 g
s
.48828 .53779 m .50064 .54568 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48026 .59365 m .48048 .59209 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48828 .53779 L p .48137 .59102 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48048 .59209 L p .47456 .59036 L .707 .577 .707 r
F P
0 g
s
.48048 .59209 m .48602 .61693 L p .47706 .59617 L .707 .577 .707 r
F P
0 g
s
.47456 .59036 m .48048 .59209 L .47706 .59617 L .707 .577 .707 r
F
.48048 .59209 m .48048 .59209 L p .48048 .59209 L F P
0 g
s
.48048 .59209 m .47816 .58169 L p .48048 .59209 L .707 .577 .707 r
F P
0 g
s
.48828 .53779 m .48048 .59209 L p .46877 .57027 L .707 .577 .707 r
F P
0 g
s
.48602 .61693 m .48048 .59209 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.49284 .6 m .49839 .62486 L p .4892 .59767 L .707 .577 .707 r
F P
0 g
s
.48082 .59231 m .48735 .57695 L .4922 .59959 L .707 .577 .707 r
F
.49284 .6 m .49053 .58963 L p .49469 .60662 L .708 .578 .707 r
F P
0 g
s
.50064 .54568 m .49284 .60001 L p .48735 .57695 L .707 .577 .707 r
F P
0 g
s
.49839 .62486 m .49284 .6 L p .49284 .60001 L .708 .578 .707 r
F P
0 g
s
.49626 .61436 m .49284 .60001 L .49469 .60662 L .708 .578 .707 r
F
.49839 .62486 m .49284 .60001 L .49626 .61436 L F
.50064 .54568 m .5034 .55276 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49284 .60001 m .50064 .54568 L p .49291 .60024 L .707 .577 .707 r
F P
0 g
s
.49291 .60024 m .49668 .58319 L .49493 .60748 L .707 .577 .707 r
F
.49668 .58319 m .5034 .55276 L .49535 .60856 L F
.49534 .60892 m .50127 .63552 L .4989 .62675 L p .708 .578 .707 r
F P
0 g
s
.4989 .62675 m .49839 .62486 L p .49534 .60892 L .708 .578 .707 r
F P
0 g
s
.80307 .6419 m .80649 .68013 L .779 .68149 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .77559 .64326 L .80307 .6419 L p .707 .577 .707 r
F P
0 g
s
.68538 .67947 m .68452 .69734 L .66046 .70406 L p .707 .577 .707 r
F P
0 g
s
.29626 .585 m .30428 .52914 L .30153 .52206 L p .707 .577 .707 r
F P
0 g
s
.47387 .69988 m .47186 .71852 L .48823 .71402 L p .707 .577 .707 r
F P
0 g
s
.48823 .71402 m .49024 .69538 L .47387 .69988 L p .707 .577 .707 r
F P
0 g
s
.68705 .69028 m .68364 .65206 L .7128 .6486 L p .707 .577 .707 r
F P
0 g
s
.8051 .68746 m .80424 .70532 L .77683 .69815 L p .707 .577 .707 r
F P
0 g
s
.779 .68149 m .7479 .6838 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77559 .64326 m .77696 .65859 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77696 .65859 m .779 .68149 L p .77112 .64981 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .77769 .68028 L .79428 .68462 L p .707 .577 .707 r
F P
0 g
s
.79428 .68462 m .8051 .68746 L p .79796 .69015 L .707 .577 .707 r
F P
0 g
s
.77683 .69815 m .79428 .68462 L .79796 .69015 L .707 .577 .707 r
F
.7128 .6486 m .71621 .68683 L .68705 .69028 L p F P
0 g
s
.304 .67681 m .29742 .67263 L p .3083 .69495 L .707 .577 .707 r
F P
0 g
s
.30454 .68051 m .29911 .65617 L p .2938 .63462 L .708 .578 .707 r
F P
0 g
s
.29911 .65617 m .29668 .64528 L .29547 .6408 L p .708 .578 .707 r
F P
0 g
s
.29547 .6408 m .2938 .63462 L p .29911 .65617 L .708 .578 .707 r
F P
0 g
s
.30784 .69916 m .3083 .69495 L p .29742 .67263 L .707 .577 .707 r
F P
0 g
s
.3083 .69495 m .30985 .68052 L .304 .67681 L p .707 .577 .707 r
F P
0 g
s
.68452 .69734 m .68538 .67947 L .71476 .67608 L p .707 .577 .707 r
F P
0 g
s
.30153 .52206 m .29351 .57791 L .29626 .585 L p .707 .577 .707 r
F P
0 g
s
.29742 .67263 m .29541 .69127 L .30784 .69916 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .74448 .64557 L .77559 .64326 L p .707 .577 .707 r
F P
0 g
s
.29668 .64528 m .30454 .68051 L .31691 .68845 L p .707 .577 .707 r
F P
0 g
s
.71621 .68683 m .7128 .6486 L .74448 .64557 L p .707 .577 .707 r
F P
0 g
s
.71476 .67608 m .71389 .69395 L .68452 .69734 L p .707 .577 .707 r
F P
0 g
s
.7479 .6838 m .71621 .68683 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.74561 .65814 m .7479 .6838 L p .73996 .65217 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .74656 .67636 L .76501 .67868 L p .707 .577 .707 r
F P
0 g
s
.76501 .67868 m .77769 .68028 L p .76978 .68373 L .707 .577 .707 r
F P
0 g
s
.7457 .69423 m .76501 .67868 L .76978 .68373 L .707 .577 .707 r
F
.74448 .64557 m .74561 .65814 L p .73996 .65217 L F P
0 g
s
.77769 .68028 m .77683 .69815 L .7457 .69423 L p .707 .577 .707 r
F P
0 g
s
.71389 .69395 m .71476 .67608 L .74656 .67636 L p .707 .577 .707 r
F P
0 g
s
.74656 .67636 m .7457 .69423 L .71389 .69395 L p .707 .577 .707 r
F P
0 g
s
.49024 .69538 m .48823 .71402 L .49538 .70774 L p .707 .577 .707 r
F P
0 g
s
.49538 .70774 m .49739 .6891 L .49024 .69538 L p .707 .577 .707 r
F P
0 g
s
.29351 .57791 m .30153 .52206 L .30865 .51648 L p .707 .577 .707 r
F P
0 g
s
.29541 .69127 m .29742 .67263 L .29465 .66518 L p .707 .577 .707 r
F P
0 g
s
.29465 .66518 m .29264 .68381 L .29541 .69127 L p .707 .577 .707 r
F P
0 g
s
.29264 .68381 m .29465 .66518 L .2994 .661 L p .707 .577 .707 r
F P
0 g
s
.30166 .66986 m .30454 .68051 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.29662 .64728 m .30166 .66986 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.2938 .63462 m .29662 .64728 L p .29573 .64287 L .708 .578 .707 r
F P
0 g
s
.30166 .66986 m .2938 .63462 L .30068 .62228 L p .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30166 .66986 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30068 .62228 m .30418 .63794 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30418 .63794 m .30854 .65752 L p .30086 .6311 L .707 .577 .707 r
F P
0 g
s
.30854 .65752 m .30068 .62228 L .31666 .60947 L p .707 .577 .707 r
F P
0 g
s
.31666 .60947 m .32453 .6447 L .30854 .65752 L p .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .30179 .6589 L .31285 .65586 L p .707 .577 .707 r
F P
0 g
s
.31285 .65586 m .31816 .6544 L p .31442 .65911 L .707 .577 .707 r
F P
0 g
s
.29978 .67753 m .31285 .65586 L .31442 .65911 L .707 .577 .707 r
F
.2994 .661 m .30179 .6589 L p .29997 .66384 L F P
0 g
s
.29264 .68381 m .2994 .661 L .29997 .66384 L .707 .577 .707 r
F
.30865 .51648 m .30063 .57233 L .29351 .57791 L p F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49739 .6891 m .49538 .70774 L .4926 .70029 L p .707 .577 .707 r
F P
0 g
s
.4926 .70029 m .49461 .68165 L .49739 .6891 L p .707 .577 .707 r
F P
0 g
s
.30063 .57233 m .30865 .51648 L .32496 .51295 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30179 .6589 m .29978 .67753 L .29264 .68381 L p .707 .577 .707 r
F P
0 g
s
.32496 .51295 m .31694 .5688 L .30063 .57233 L p .707 .577 .707 r
F P
0 g
s
.45949 .58572 m .46751 .52986 L .48828 .53779 L p .707 .577 .707 r
F P
0 g
s
.31694 .5688 m .32496 .51295 L .34886 .51181 L p .707 .577 .707 r
F P
0 g
s
.49461 .68165 m .4926 .70029 L .48017 .6924 L p .707 .577 .707 r
F P
0 g
s
.48017 .6924 m .48218 .67376 L .49461 .68165 L p .707 .577 .707 r
F P
0 g
s
.34886 .51181 m .34083 .56767 L .31694 .5688 L p .707 .577 .707 r
F P
0 g
s
.31816 .6544 m .31615 .67304 L .29978 .67753 L p .707 .577 .707 r
F P
0 g
s
.43236 .57853 m .44038 .52267 L .46751 .52986 L p .707 .577 .707 r
F P
0 g
s
.34083 .56767 m .34886 .51181 L .378 .51318 L p .707 .577 .707 r
F P
0 g
s
.32453 .6447 m .31666 .60947 L .34018 .59744 L p .707 .577 .707 r
F P
0 g
s
.48218 .67376 m .48017 .6924 L .45931 .68483 L p .707 .577 .707 r
F P
0 g
s
.45931 .68483 m .46132 .6662 L .48218 .67376 L p .707 .577 .707 r
F P
0 g
s
.40151 .57278 m .40953 .51692 L .44038 .52267 L p .707 .577 .707 r
F P
0 g
s
.378 .51318 m .36998 .56904 L .34083 .56767 L p .707 .577 .707 r
F P
0 g
s
.36998 .56904 m .378 .51318 L .40953 .51692 L p .707 .577 .707 r
F P
0 g
s
.31615 .67304 m .31816 .6544 L .34215 .65213 L p .707 .577 .707 r
F P
0 g
s
.34018 .59744 m .34804 .63267 L .32453 .6447 L p .707 .577 .707 r
F P
0 g
s
.40953 .51692 m .40151 .57278 L .36998 .56904 L p .707 .577 .707 r
F P
0 g
s
.34215 .65213 m .34015 .67077 L .31615 .67304 L p .707 .577 .707 r
F P
0 g
s
.34804 .63267 m .34018 .59744 L .36892 .58737 L p .707 .577 .707 r
F P
0 g
s
.37678 .6226 m .36892 .58737 L .40008 .58024 L p .707 .577 .707 r
F P
0 g
s
.36892 .58737 m .37678 .6226 L .34804 .63267 L p .707 .577 .707 r
F P
0 g
s
.40008 .58024 m .40794 .61548 L .37678 .6226 L p .707 .577 .707 r
F P
0 g
s
.46132 .6662 m .45931 .68483 L .43206 .67834 L p .707 .577 .707 r
F P
0 g
s
.43206 .67834 m .43407 .65971 L .46132 .6662 L p .707 .577 .707 r
F P
0 g
s
.34015 .67077 m .34215 .65213 L .37142 .65231 L p .707 .577 .707 r
F P
0 g
s
.37142 .65231 m .36941 .67095 L .34015 .67077 L p .707 .577 .707 r
F P
0 g
s
.43407 .65971 m .43206 .67834 L .40108 .67356 L p .707 .577 .707 r
F P
0 g
s
.40108 .67356 m .40309 .65492 L .43407 .65971 L p .707 .577 .707 r
F P
0 g
s
.36941 .67095 m .37142 .65231 L .40309 .65492 L p .707 .577 .707 r
F P
0 g
s
.40309 .65492 m .40108 .67356 L .36941 .67095 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
075oo`D0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`80009JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06]oo`00J7oo0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0P00JWoo001WOol20005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUH00000J7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF0000Igoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Io
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00IWoo001JOolE0009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001GOol30002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001FOol20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH7000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo
001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00IWoo001DOol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P004Goo4@00A7oo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P002goo1P000eYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00?Woo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH0
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000Moo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000lOol005Aoo`03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0P001Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP<003Uoo`00E7oo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004Ool2
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000gOol0
05Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000eOol005Aoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH200000goo001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000cOol005Aoo`8000AJEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0002
FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
10000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP@000=J
EP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80031oo`00Dgoo00<005YF00000UYF5P0015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000;Woo
001COol00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
05=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP@0
009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0
000]Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00AJEPH000IJEP03001JEUYF00=JEP03001JEUYF009JEP80009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF001JEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJ
EP0002eoo`00Dgoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
1`0015YF00<005YF00000`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800005FUH005YFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000;Goo001DOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YF
FUH01UYF00<005YFFUH00eYF100015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000]Ool005Eo
o`<000EJEP03001JEUYF00IJEPD000IJEP03001JEUYF00MJEP03001JEUYF009JEP04001JEUYF0004
FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP<000=JEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF009JEP03001oogoo02]oo`00Egoo0P0015YF00<005YFFUH00eYF100000=JEP00
FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000=JEP03001JEUYF00=JEPH0015oo`H0
00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02]oo`00FGoo0`0000AJEP00FUIJEP<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00
00=JEP03001JEP0000<0011oo`<000Yoo`8000AJEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo02]oo`00G7oo1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF10004Goo1@002goo0`0000=JEP00FUH015YF00@005YFFUIJEP8002eo
o`00GGoo00@005YFFUH000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001J
EUYFFUH005YF00000UYF00<005YFFUH00UYF0`003Woo1@003Woo0P001EYF00@005YFFUIJEP8002eo
o`00Fgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YF10001EYF00@005YF000000aoo`D0011oo`8000=JEP04001JEUYFFUH2
000]Ool005Yoo`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP04001JEUYFFUH3000:Ool3
000@Ool500000eYF001JEP02FUH2000]Ool004Mooa@000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEPl000=JEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF1P004Woo1@001EYF
0P000eYF00<007ooOol0;7oo000nOol90004FUH00`00FUIJEP06FUH01000FUH000000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF2@0015YF00@005YFFUIJEPP0009JEP05001JEUYF
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH00UYF4P0035YF00@005YFFUH002ioo`00=Woo200015YF00<005YF
FUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH01000
1UYF00<005YFFUH0200000=JEP00FUH00P000UYF10000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF01QJEP<002ioo`00<Goo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P001EYF00<005YFFUH015YF00<005YFFUH015YF1P002EYF00<005YFFUH02EYF0P00
1EYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJ
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001J
EP0002ioo`00;Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P001EYF00<005YFFUH015YF00<005YFFUH010001EYF10001UYF00<005YFFUH025YF0`001EYF
00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF01QJEP03001JEP00
02ioo`00;Goo0P000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@0
05YFFUH000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00MJEP04
001JEUYF0005FUH01000FUH000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
01QJEP03001JEP0002ioo`00;7oo00<005YF00000eYF0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP8000=JEP04001JEUYF0005FUH5
0005FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH01000FUIJEP000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF01AJEP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH0
0003FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF
00H005YFFUH005YF0003FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00eYF0P001UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00eJEP03
001JEUYF00AJEP07001JEUYFOol005YF0000;Woo000/Ool00`00FUH00003FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF0`000UYF00D005YFFUIJEP00
009JEP03001JEUYF00=JEP@000IJEP03001JEUYF00<00003FUH005YF00EJEP03001JEUYF00=JEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUHF000_Ool002aoo`03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000EJEP03001J
EUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF2@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF
0`001EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP<000QJEP03001JEUYF00=J
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20003FUH20003FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<0009JEP03001JEP00
0100009JEP@00003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF008000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH200000eYF000000060003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00L000=JEP03001JEUYF00EJEP03001JEUYF009JEPX000QJEP03001JEUYF
00AJEP<000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002
FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`0015YF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000MJEP03001JEUYF00=JEP04001JEUYF000^Ool002eoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP@000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20007FUH20007FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYFFUHA0004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0P00
1eYF0P001eYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH00`00FUH00002FUH500000eYF001JEP06
FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH0000200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH60006FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF00@005YFFUIJEQ0000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF00000eYF00<005YF000015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000EJEP00FUIJEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP<000MJEP03001JEP0000@0009JEP03001JEUYF00AJEP04001JEUYF
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJ
EP03001JEUYF009JEPH000AJEP03001JEUYF00IJEP03001JEUYF01T002eoo`00;Goo00<005YF0000
0UYF0P001EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP800003FUH005YF
009JEP03001JEUYF00EJEP03001JEUYF00EJEPD000AJEP@000EJEP@000AJEP05001JEUYFFUH00004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEPD0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF001JEP040006FUH00`00
FUIJEP04000]Ool002eoo`03001JEP0000800003FUH005YF00AJEP8000MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYFFUH50002FUH20007FUH00`00FUIJEP04FUH900000eYF001JEP0:FUH3
00000eYF001JEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000AJEP<0035oo`00;Goo0`000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP800003FUH005YF00IJEP03001JEUYF
009JEPL000EJEP03001JEUYF00UJEP03001JEUYF008000=JEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP08001JEUYFFUH005YF001JEP<000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00;Goo00<005YF00000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH015YF3`00
0UYF10001UYF00<005YFFUH02EYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP02000dOol002eoo`03001JEP00009JEP03
001JEUYF00AJEP03001JEUYF00=JEPh000IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001J
EUYF009JEPT000EJEP03001JEUYF00UJEP04001JEUYFFUH50004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF1P0000=JEP00FUH00eYF
20000goo1P001UYF00<005YFFUH00UYF0P00<Woo000]Ool00eYFOol00002FUH00`00FUIJEP03FUH<
0009Ool40002FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHE0003FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0`000eYF00<005YF00003`004Goo10000UYF00<005YFFUH00eYF0P00<Goo000]Ool00eYF001JEP02
FUH00`00FUH00003000IOol40006FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF0P000eYF00<005YFFUH00UYF00@005YFFUH0
01Uoo`<000EJEP04001JEP00000_Ool002eoo`03FUH005YF009JEP80025oo`@0009JEP04001JEUYF
FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP08001JEUYF
FUH005YF001JEP8000IJEP05001JEUYFFUH00002FUH00`00Oomoo`0JOol20003FUH01@00FUIJEUYF
0000;Woo000]Ool01EYF001JEUYF00009goo0`001EYF00<005YF00000`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF00<0
05YF00007Woo0P0000=JEP00FUH00UYF00<007ooOol0;7oo000/Ool00`00FUH00002000[Ool20003
FUH01P00FUIJEUYF001JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20009Ool3000EOol20003FUH2000]Ool002aoo`04
001JEP00000^Ool01000FUIJEP000eYF00@005YFFUH0009JEQh000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
0008Ool5000FOol00`00FUIJEP02000]Ool002aoo`@001Qoo`<001Aoo`<000=JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH00UYF00<007oo
Ool01goo1@005goo1000;Goo000/Ool300000eYF001oo`0EOol5000EOol01@00FUIJEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800004FUH005YF0007FUH01000FUIJEP00
2Woo1@006Goo0P00;Goo000/Ool00`00FUH00002FUH00`00Oomoo`0COol5000FOol01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP8000MJEP<000aoo`<001Uo
o`8002ioo`00;7oo0P000eYF0`004goo1@005goo00<005YF00000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YFFUIJEP0000=JEP<000EJEP8002Uoo`<002ioo`00;7oo0P000eYF00<005YFFUH0
0P004Woo0`006Goo0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03
001JEUYF00800003FUH0000002Uoo`800003FUH0000002ioo`00;7oo0P000eYF00<005YFFUH00UYF
0`00:Goo0P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJ
EP02FUH3000VOol30003FUH00`00Oomoo`0]Ool002eoo`05001JEUYFFUH00005FUH01000FUH00000
9Woo00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH50005FUH00`00FUH0
0003000NOol400000eYF001JEP02FUH2000_Ool002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF
0`008Goo0P0015YF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00AJEP`000aJEPT000QJ
EP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH7000BOol5
0005FUH01@00FUIJEUYF0000<7oo000^Ool01000FUIJEP001EYF00<005YFFUH015YF10001Goo4@00
0goo100000=JEP00FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF2@002eYF00<005YF
FUH02UYF00<005YFFUH01UYF1P000UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP8000=JEP03
001JEUYF00EJEP03001JEUYF009JEQ8000=JEP03001JEUYF00AJEP05001JEUYFFUH0000`Ool002mo
o`03001JEP0000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF00IJEP04001JEUYFFUH700000eYF
001JEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP050006FUH01000FUIJEUYF0P001EYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000
035oo`00<7oo0P001EYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01`000UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF10000UYF00@005YFFUIJEP8000IJEP@000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00<Goo00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF0000009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020003FUH20006
FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000`00=Woo000aOol30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF000000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP03
001JEUYF008000IJEP03001JEUYF00=JEP03001JEP0000H000AJEP03001JEUYF00IJEP03001JEUYF
009JEPD003Yoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEP000006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000goo4P00?goo
000]Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHP0003FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEPH000=JEP03001JEUYF00=JEP06001JEUYF001JEP00E7oo000]
Ool00`00FUH00004FUH00`00FUIJEP02FUH60008FUH50004FUH20006FUH20005FUH500000eYF0000
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH70002FUH01P00FUIJEP00FUH005Aoo`00
;Goo00<005YF000015YF00<005YF000010000eYF00<005YFFUH01UYF1@0015YF0P001UYF00<005YF
FUH00eYF0`000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0`001eYF00<005YFFUH01000
00=JEP000000EGoo000]Ool00`00FUH00002FUH40005Ool200000eYF001JEP07FUH50004FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00@005YF000000IJEP03001JEUYF00=JEP@005Eoo`00;Goo00<005YF00000P000UYF3`00
15YF10001EYF00<005YFFUH01EYF00@005YF000000AJEP03001JEUYF009JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP04001JEP000006FUH00`00FUIJEP03FUH01000FUH00000EGoo000]Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF2@0015YF00<005YFFUH00UYF1@00
0eYF00AooeYFFUH000=JEP<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=JEP03001JEUYF
00=JEP04001JEUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP04001JEUYFFUH90004FUH00`00FUIJEP04FUH01000FUH000000Woo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF0P0015YF1P0015YF00@005YFFUH005Eoo`00;Woo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUIJEPD000Eoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00=JEP<0
0004FUH005YFFUH2001DOol0031oo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPL000aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH00`00FUIJEP03FUH00`00
FUIJEP020003FUH00`00Oomoo`1BOol003Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPT0
01Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEP00008000MJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001oo`1C
Ool003]ooa80021oo`8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEPT000AJEP03001JEUYF00=JEP03001JEUYF00L005Aoo`00Kgoo0`00
00=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF
100027oo3@000Woo0`0000=JEP000000Dgoo001bOol70005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00008000DOol20002FUH01000FUIJEP00Dgoo001iOol;0006FUH0
0`00FUIJEP0:FUH00`00FUIJEP04FUH70004Ool5000BOol20005FUH00`00FUH0001COol008AooaX0
00]oo`D0011oo`800003FUH005YF00AJEP8005Aoo`00Sgoo0P006Goo0`003goo0P000eYF00<005YF
FUH00eYF00<007ooOol0Dgoo002?Ool3000WOol30006FUH00`00FUIJEP02001FOol008moo`03001J
EUYF00@001moo`@00003FUH005YF00IJEP<005Qoo`00Sgoo0P000UYF00<005YFFUH01`004Goo1`00
1EYF00<005YFFUH015YF0P00FWoo002@Ool01000FUIJEP001EYF00@005YFFUIJEQ4000AJEP03001J
EUYF00IJEP04001JEUYFFUH2001LOol0091oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000GWoo002AOol30005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001POol009=oo`8000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@006=oo`00UGoo0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00Igoo002HOolG001^Ool00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59357 .74263 m .6016 .68677 L .57073 .68104 L p .707 .577 .707 r
F P
0 g
s
.6016 .68677 m .59357 .74263 L .6251 .74635 L p .707 .577 .707 r
F P
0 g
s
.6251 .74635 m .63313 .69049 L .6016 .68677 L p .707 .577 .707 r
F P
0 g
s
.63313 .69049 m .6251 .74635 L .65419 .7477 L p .707 .577 .707 r
F P
0 g
s
.65419 .7477 m .66222 .69184 L .63313 .69049 L p .707 .577 .707 r
F P
0 g
s
.5627 .7369 m .57073 .68104 L .54354 .67387 L p .707 .577 .707 r
F P
0 g
s
.57073 .68104 m .5627 .7369 L .59357 .74263 L p .707 .577 .707 r
F P
0 g
s
.66222 .69184 m .65419 .7477 L .678 .74654 L p .707 .577 .707 r
F P
0 g
s
.678 .74654 m .68603 .69068 L .66222 .69184 L p .707 .577 .707 r
F P
0 g
s
.54354 .67387 m .53551 .72973 L .5627 .7369 L p .707 .577 .707 r
F P
0 g
s
.53551 .72973 m .54354 .67387 L .52268 .66595 L p .707 .577 .707 r
F P
0 g
s
.59978 .81879 m .59194 .78353 L .56148 .78689 L p .707 .577 .707 r
F P
0 g
s
.59194 .78353 m .59978 .81879 L .63097 .81179 L p .707 .577 .707 r
F P
0 g
s
.63097 .81179 m .62313 .77653 L .59194 .78353 L p .707 .577 .707 r
F P
0 g
s
.62313 .77653 m .63097 .81179 L .65984 .80183 L p .707 .577 .707 r
F P
0 g
s
.65984 .80183 m .652 .76657 L .62313 .77653 L p .707 .577 .707 r
F P
0 g
s
.56932 .82215 m .56148 .78689 L .53474 .78627 L p .707 .577 .707 r
F P
0 g
s
.56148 .78689 m .56932 .82215 L .59978 .81879 L p .707 .577 .707 r
F P
0 g
s
.652 .76657 m .65984 .80183 L .68356 .78989 L p .707 .577 .707 r
F P
0 g
s
.68356 .78989 m .67572 .75463 L .652 .76657 L p .707 .577 .707 r
F P
0 g
s
.52268 .66595 m .51465 .72181 L .53551 .72973 L p .707 .577 .707 r
F P
0 g
s
.59323 .84687 m .59524 .82823 L .56423 .82348 L p .707 .577 .707 r
F P
0 g
s
.59524 .82823 m .59323 .84687 L .62489 .84945 L p .707 .577 .707 r
F P
0 g
s
.62489 .84945 m .62689 .83081 L .59524 .82823 L p .707 .577 .707 r
F P
0 g
s
.69152 .74359 m .6942 .743 L p .68117 .72447 L .707 .577 .707 r
F P
0 g
s
.69197 .74186 m .69294 .74622 L p .70701 .7648 L .707 .577 .707 r
F P
0 g
s
.69294 .74622 m .69981 .77712 L .70492 .76837 L p .707 .577 .707 r
F P
0 g
s
.70492 .76837 m .70701 .7648 L p .69294 .74622 L .707 .577 .707 r
F P
0 g
s
.68603 .69068 m .68117 .72447 L p .6942 .743 L .707 .577 .707 r
F P
0 g
s
.68117 .72447 m .678 .74654 L .69152 .74359 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70223 .68714 L .68603 .69068 L p .707 .577 .707 r
F P
0 g
s
.62689 .83081 m .62489 .84945 L .65409 .8496 L p .707 .577 .707 r
F P
0 g
s
.65409 .8496 m .6561 .83096 L .62689 .83081 L p .707 .577 .707 r
F P
0 g
s
.56423 .82348 m .56222 .84211 L .59323 .84687 L p .707 .577 .707 r
F P
0 g
s
.56222 .84211 m .56296 .83521 L p .53689 .81701 L .707 .577 .707 r
F P
0 g
s
.55309 .82084 m .53689 .81701 L p .56296 .83521 L .707 .577 .707 r
F P
0 g
s
.54257 .82153 m .53731 .79787 L p .51432 .78174 L .707 .577 .707 r
F P
0 g
s
.53731 .79787 m .53474 .78627 L .52838 .78486 L p .707 .577 .707 r
F P
0 g
s
.52838 .78486 m .51432 .78174 L p .53731 .79787 L .707 .577 .707 r
F P
0 g
s
.56296 .83521 m .56423 .82348 L .55309 .82084 L p .707 .577 .707 r
F P
0 g
s
.51465 .72181 m .52268 .66595 L .5102 .65806 L p .707 .577 .707 r
F P
0 g
s
.53474 .78627 m .54257 .82153 L .56932 .82215 L p .707 .577 .707 r
F P
0 g
s
.53689 .81701 m .53488 .83565 L .56222 .84211 L p .707 .577 .707 r
F P
0 g
s
.67572 .75463 m .68356 .78989 L .69981 .77712 L p .707 .577 .707 r
F P
0 g
s
.69981 .77712 m .69197 .74186 L .67572 .75463 L p .707 .577 .707 r
F P
0 g
s
.6561 .83096 m .65409 .8496 L .67798 .84731 L p .707 .577 .707 r
F P
0 g
s
.67798 .84731 m .67999 .82867 L .6561 .83096 L p .707 .577 .707 r
F P
0 g
s
.5102 .65806 m .50217 .71392 L .51465 .72181 L p .707 .577 .707 r
F P
0 g
s
.53488 .83565 m .53545 .83036 L p .51592 .80946 L .707 .577 .707 r
F P
0 g
s
.52718 .81351 m .51592 .80946 L p .53545 .83036 L .707 .577 .707 r
F P
0 g
s
.52216 .817 m .5166 .79198 L p .50224 .77374 L .707 .577 .707 r
F P
0 g
s
.5166 .79198 m .51432 .78174 L .51024 .77904 L p .707 .577 .707 r
F P
0 g
s
.51024 .77904 m .50224 .77374 L p .5166 .79198 L .707 .577 .707 r
F P
0 g
s
.53545 .83036 m .53689 .81701 L .52718 .81351 L p .707 .577 .707 r
F P
0 g
s
.51592 .80946 m .51391 .8281 L .53488 .83565 L p .707 .577 .707 r
F P
0 g
s
.51432 .78174 m .52216 .817 L .54257 .82153 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70048 .73799 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70223 .68714 m .69739 .72082 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.69739 .72082 m .6942 .743 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70701 .7648 m .70092 .73739 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70121 .73699 m .70223 .68714 L .70048 .73799 L .707 .577 .707 r
F
.70092 .73739 m .69917 .72954 L p .69464 .74593 L F P
0 g
s
.70092 .73739 m .70701 .7648 L .70474 .75535 L p .708 .578 .707 r
F P
0 g
s
.70048 .73799 m .7012 .73741 L p .70121 .73699 L .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .70092 .73739 L p .70108 .73815 L .708 .578 .707 r
F P
0 g
s
.70055 .73597 m .69917 .72954 L .70108 .73815 L .708 .578 .707 r
F
.7012 .73741 m .70923 .68155 L .70223 .68714 L p .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .69197 .74186 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70045 .73554 m .69832 .73033 L p .69868 .72873 L .707 .577 .707 r
F P
0 g
s
.6966 .71885 m .69875 .72854 L p .69848 .72926 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .68584 .72244 L p .68658 .72072 L .707 .577 .707 r
F P
0 g
s
.68452 .71085 m .68668 .7206 L p .68599 .72138 L .707 .577 .707 r
F P
0 g
s
.6641 .70632 m .66589 .71435 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66522 .71412 L .66586 .71438 L .707 .577 .707 r
F
.68584 .72244 m .66551 .71472 L p .66586 .71438 L F P
0 g
s
.66551 .71472 m .66498 .71452 L p .66586 .71438 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .6452 .74096 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.68599 .72138 m .68584 .72244 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .67194 .74158 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.67524 .73351 m .68093 .71961 L .68599 .72138 L .707 .577 .707 r
F
.68093 .71961 m .68452 .71085 L .68599 .72138 L F
.68658 .72072 m .68668 .7206 L .69832 .73033 L F
.69848 .72926 m .69832 .73033 L p .68664 .72057 L F P
0 g
s
.68452 .71085 m .6966 .71885 L p .69534 .72695 L .707 .577 .707 r
F P
0 g
s
.68892 .72224 m .68452 .71085 L .69534 .72695 L .707 .577 .707 r
F
.68693 .7217 m .68452 .71085 L p .69402 .73544 L F P
0 g
s
.69387 .66658 m .70635 .67446 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68584 .72244 m .68616 .72022 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68616 .72022 m .69387 .66658 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.69402 .73544 m .68892 .72224 L .69534 .72695 L .707 .577 .707 r
F
.69236 .74611 m .68693 .7217 L p .69402 .73544 L F P
0 g
s
.6641 .70632 m .68452 .71085 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .66589 .71435 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .6641 .70632 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .69387 .66658 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66505 .71406 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66505 .71406 m .67301 .65866 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66522 .71412 m .67481 .69821 L .68599 .72138 L .707 .577 .707 r
F
.69387 .66658 m .68616 .72022 L p .67481 .69821 L F P
0 g
s
.68616 .72022 m .68599 .72138 L p .67481 .69821 L .707 .577 .707 r
F P
0 g
s
.68658 .72072 m .68664 .72057 L .68668 .7206 L .707 .577 .707 r
F
.69236 .74611 m .67194 .74158 L p .67524 .73351 L F P
0 g
s
.68668 .7206 m .69236 .74611 L p .67524 .73351 L .707 .577 .707 r
F P
0 g
s
.69261 .74449 m .69534 .72695 L .69848 .72926 L .707 .577 .707 r
F
.69534 .72695 m .6966 .71885 L .69848 .72926 L F
.69868 .72873 m .69875 .72854 L .70045 .73554 L F
.6966 .71885 m .69917 .72954 L p .70055 .73597 L .708 .578 .707 r
F P
0 g
s
.69922 .73046 m .6966 .71885 L .70055 .73597 L .708 .578 .707 r
F
.699 .72964 m .6966 .71885 L p .70226 .74397 L F P
0 g
s
.70635 .67446 m .70923 .68155 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .69864 .72809 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69864 .72809 m .70635 .67446 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.70226 .74397 m .69922 .73046 L .70055 .73597 L .708 .578 .707 r
F
.70444 .75411 m .699 .72964 L p .70226 .74397 L F P
0 g
s
.68664 .72057 m .69335 .70487 L .69848 .72926 L .707 .577 .707 r
F
.70635 .67446 m .69864 .72809 L p .69335 .70487 L F P
0 g
s
.69864 .72809 m .69848 .72926 L p .69335 .70487 L .707 .577 .707 r
F P
0 g
s
.69868 .72873 m .69874 .72847 L .69875 .72854 L .707 .577 .707 r
F
.70444 .75411 m .69236 .74611 L p .69261 .74449 L F P
0 g
s
.69875 .72854 m .70444 .75411 L p .69261 .74449 L .707 .577 .707 r
F P
0 g
s
.70923 .68155 m .7012 .73741 L .70045 .73554 L p .707 .577 .707 r
F P
0 g
s
.69874 .72847 m .70923 .68155 L .70045 .73554 L .707 .577 .707 r
F
.70444 .75411 m .70055 .73597 L .70108 .73815 L .708 .578 .707 r
F
.70474 .75535 m .70444 .75411 L p .70092 .73739 L F P
0 g
s
.50217 .71392 m .5102 .65806 L .50732 .65098 L p .707 .577 .707 r
F P
0 g
s
.67999 .82867 m .67798 .84731 L .69422 .84279 L p .707 .577 .707 r
F P
0 g
s
.69422 .84279 m .69623 .82415 L .67999 .82867 L p .707 .577 .707 r
F P
0 g
s
.50938 .80536 m .50335 .80158 L p .51411 .82618 L .707 .577 .707 r
F P
0 g
s
.51008 .809 m .50454 .78407 L p .49967 .76305 L .708 .578 .707 r
F P
0 g
s
.50454 .78407 m .50224 .77374 L .50127 .76969 L p .708 .578 .707 r
F P
0 g
s
.50127 .76969 m .49967 .76305 L p .50454 .78407 L .708 .578 .707 r
F P
0 g
s
.51391 .8281 m .51411 .82618 L p .50335 .80158 L .707 .577 .707 r
F P
0 g
s
.51411 .82618 m .51592 .80946 L .50938 .80536 L p .707 .577 .707 r
F P
0 g
s
.50732 .65098 m .49929 .70684 L .50217 .71392 L p .707 .577 .707 r
F P
0 g
s
.50335 .80158 m .50134 .82022 L .51391 .8281 L p .707 .577 .707 r
F P
0 g
s
.50224 .77374 m .51008 .809 L .52216 .817 L p .707 .577 .707 r
F P
0 g
s
.49217 .82187 m .49217 .31998 L .44804 .31744 L p .707 .577 .707 r
F P
0 g
s
.49929 .70684 m .50732 .65098 L .51432 .64539 L p .707 .577 .707 r
F P
0 g
s
.50134 .82022 m .50335 .80158 L .50042 .79412 L p .707 .577 .707 r
F P
0 g
s
.50042 .79412 m .49841 .81276 L .50134 .82022 L p .707 .577 .707 r
F P
0 g
s
.51432 .64539 m .50629 .70125 L .49929 .70684 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .51008 .809 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49967 .76305 m .50268 .77659 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.50268 .77659 m .50751 .79831 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49841 .81276 m .50042 .79412 L .50546 .78959 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .49967 .76305 L .50686 .75073 L p .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50751 .79831 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.50686 .75073 m .5106 .76752 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5106 .76752 m .5147 .78599 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50686 .75073 L .52312 .73796 L p .707 .577 .707 r
F P
0 g
s
.52312 .73796 m .53096 .77322 L .5147 .78599 L p .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .50742 .78783 L .51927 .78454 L p .707 .577 .707 r
F P
0 g
s
.51927 .78454 m .52366 .78332 L p .52062 .78718 L .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .51927 .78454 L .52062 .78718 L .707 .577 .707 r
F
.50546 .78959 m .50742 .78783 L p .50595 .79189 L F P
0 g
s
.49841 .81276 m .50546 .78959 L .50595 .79189 L .707 .577 .707 r
F
.50629 .70125 m .51432 .64539 L .53052 .64184 L p F P
0 g
s
.50742 .78783 m .50541 .80647 L .49841 .81276 L p .707 .577 .707 r
F P
0 g
s
.53052 .64184 m .52249 .6977 L .50629 .70125 L p .707 .577 .707 r
F P
0 g
s
.52249 .6977 m .53052 .64184 L .55433 .64069 L p .707 .577 .707 r
F P
0 g
s
.55433 .64069 m .5463 .69655 L .52249 .6977 L p .707 .577 .707 r
F P
0 g
s
.52366 .78332 m .52165 .80196 L .50541 .80647 L p .707 .577 .707 r
F P
0 g
s
.53096 .77322 m .52312 .73796 L .54684 .72602 L p .707 .577 .707 r
F P
0 g
s
.52165 .80196 m .52366 .78332 L .54755 .78103 L p .707 .577 .707 r
F P
0 g
s
.54684 .72602 m .55468 .76128 L .53096 .77322 L p .707 .577 .707 r
F P
0 g
s
.54755 .78103 m .54554 .79966 L .52165 .80196 L p .707 .577 .707 r
F P
0 g
s
.49217 .31998 m .49217 .82187 L .53706 .82062 L p .707 .577 .707 r
F P
0 g
s
.53706 .82062 m .53706 .31874 L .49217 .31998 L p .707 .577 .707 r
F P
0 g
s
.69623 .82415 m .69422 .84279 L .70121 .8365 L p .707 .577 .707 r
F P
0 g
s
.70121 .8365 m .70322 .81786 L .69623 .82415 L p .707 .577 .707 r
F P
0 g
s
.5463 .69655 m .55433 .64069 L .58342 .64204 L p .707 .577 .707 r
F P
0 g
s
.58342 .64204 m .57539 .6979 L .5463 .69655 L p .707 .577 .707 r
F P
0 g
s
.55468 .76128 m .54684 .72602 L .57571 .71606 L p .707 .577 .707 r
F P
0 g
s
.57571 .71606 m .58355 .75132 L .55468 .76128 L p .707 .577 .707 r
F P
0 g
s
.54554 .79966 m .54755 .78103 L .57675 .78118 L p .707 .577 .707 r
F P
0 g
s
.57675 .78118 m .57474 .79981 L .54554 .79966 L p .707 .577 .707 r
F P
0 g
s
.57474 .79981 m .57675 .78118 L .60841 .78376 L p .707 .577 .707 r
F P
0 g
s
.60841 .78376 m .6064 .80239 L .57474 .79981 L p .707 .577 .707 r
F P
0 g
s
.53706 .31874 m .53706 .82062 L .57832 .81572 L p .707 .577 .707 r
F P
0 g
s
.57539 .6979 m .58342 .64204 L .61494 .64576 L p .707 .577 .707 r
F P
0 g
s
.61494 .64576 m .60691 .70162 L .57539 .6979 L p .707 .577 .707 r
F P
0 g
s
.58355 .75132 m .57571 .71606 L .6069 .70906 L p .707 .577 .707 r
F P
0 g
s
.57832 .81572 m .57832 .31383 L .53706 .31874 L p .707 .577 .707 r
F P
0 g
s
.44804 .81932 m .44804 .31744 L .409 .31136 L p .707 .577 .707 r
F P
0 g
s
.44804 .31744 m .44804 .81932 L .49217 .82187 L p .707 .577 .707 r
F P
0 g
s
.6069 .70906 m .61474 .74432 L .58355 .75132 L p .707 .577 .707 r
F P
0 g
s
.63942 .78851 m .63741 .80715 L .6064 .80239 L p .707 .577 .707 r
F P
0 g
s
.6064 .80239 m .60841 .78376 L .63942 .78851 L p .707 .577 .707 r
F P
0 g
s
.57832 .31383 m .57832 .81572 L .61192 .80764 L p .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6641 .70632 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63875 .71196 m .63736 .7057 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6452 .74096 L .61474 .74432 L p .707 .577 .707 r
F P
0 g
s
.61474 .74432 m .6069 .70906 L .63736 .7057 L p .707 .577 .707 r
F P
0 g
s
.64582 .65148 m .63779 .70734 L .63471 .70677 L p .707 .577 .707 r
F P
0 g
s
.63471 .70677 m .60691 .70162 L p .61879 .68631 L .707 .577 .707 r
F P
0 g
s
.61879 .68631 m .64582 .65148 L .63471 .70677 L .707 .577 .707 r
F
.6452 .74096 m .63875 .71196 L p .65184 .72878 L F P
0 g
s
.60691 .70162 m .61494 .64576 L .64582 .65148 L p .707 .577 .707 r
F P
0 g
s
.61192 .80764 m .61192 .30575 L .57832 .31383 L p .707 .577 .707 r
F P
0 g
s
.25234 .72468 m .25581 .67188 L .22466 .66738 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .28659 .75071 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25581 .67188 m .25234 .72468 L .25665 .72475 L p .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .25581 .67188 L .25665 .72475 L .707 .577 .707 r
F
.22466 .66738 m .22267 .69777 L p .25234 .72468 L F P
0 g
s
.22267 .69777 m .2212 .72018 L .25202 .72463 L p .707 .577 .707 r
F P
0 g
s
.25202 .72463 m .25234 .72468 L p .22267 .69777 L .707 .577 .707 r
F P
0 g
s
.25148 .71546 m .25232 .7249 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25232 .7249 m .25232 .72491 L p .25233 .72491 L .707 .577 .707 r
F P
0 g
s
.26059 .72461 m .25232 .7249 L .25233 .72491 L .707 .577 .707 r
F
.25232 .72491 m .25488 .7537 L p .26059 .72461 L F P
0 g
s
.28757 .67243 m .25581 .67188 L p .28272 .7226 L .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .2834 .72313 L .28272 .7226 L .707 .577 .707 r
F
.2834 .72313 m .28757 .67243 L .28272 .7226 L F
.28421 .72375 m .28757 .67243 L p .28334 .72378 L F P
0 g
s
.31588 .74729 m .29284 .72274 L .28421 .72376 L .707 .577 .707 r
F
.2842 .72375 m .28659 .75071 L .3147 .74743 L p F P
0 g
s
.28757 .67243 m .28421 .72376 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.3147 .74743 m .31588 .74729 L p .2842 .72375 L .707 .577 .707 r
F P
0 g
s
.28659 .75071 m .2842 .72375 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.31686 .66897 m .28757 .67243 L p .312 .7191 L .707 .577 .707 r
F P
0 g
s
.31268 .72041 m .31274 .71971 L .312 .7191 L .707 .577 .707 r
F
.31274 .71971 m .31686 .66897 L .312 .7191 L F
.31588 .74729 m .33987 .74379 L p .33557 .73834 L F P
0 g
s
.31349 .72031 m .31686 .66897 L p .31274 .71971 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31274 .71971 L .31268 .72041 L .707 .577 .707 r
F
.31349 .72031 m .31274 .71971 L .31348 .72031 L F
.33987 .74379 m .35622 .74055 L p .35005 .72962 L F P
0 g
s
.31686 .66897 m .31549 .68977 L p .33733 .71464 L .707 .577 .707 r
F P
0 g
s
.33733 .71464 m .31549 .68977 L .33711 .7147 L .707 .577 .707 r
F
.33348 .71579 m .33733 .71464 L p .31349 .72032 L F P
0 g
s
.33733 .71464 m .34079 .66184 L .31686 .66897 L p .707 .577 .707 r
F P
0 g
s
.34079 .66184 m .33733 .71464 L .35357 .70455 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .33731 .71492 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.33731 .71492 m .33987 .74379 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.31549 .68977 m .31349 .72032 L p .33711 .7147 L .707 .577 .707 r
F P
0 g
s
.33557 .73834 m .33621 .71517 L .32017 .71881 L .707 .577 .707 r
F
.31249 .70906 m .31348 .72031 L p .33557 .73834 L F P
0 g
s
.31348 .72031 m .31588 .74729 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31588 .74729 m .31348 .72031 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31349 .72032 m .31339 .72177 L .33348 .71579 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .31249 .70906 L p .32017 .71881 L .707 .577 .707 r
F P
0 g
s
.33621 .71517 m .33648 .70556 L .32017 .71881 L .707 .577 .707 r
F
.33987 .74379 m .33968 .7417 L p .33557 .73834 L F P
0 g
s
.33968 .7417 m .33648 .70556 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31249 .70906 m .2832 .71247 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31249 .70906 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31339 .72177 m .31349 .72031 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .31339 .72177 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28421 .72376 m .28411 .72523 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.2832 .71247 m .2842 .72375 L p .28421 .72376 L .707 .577 .707 r
F P
0 g
s
.29284 .72274 m .2832 .71247 L .28421 .72376 L .707 .577 .707 r
F
.2832 .71247 m .25148 .71546 L p .26059 .72461 L F P
0 g
s
.2842 .72375 m .2832 .71247 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .28421 .72375 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.25665 .72475 m .28411 .72523 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.409 .81325 m .409 .31136 L .37887 .30235 L p .707 .577 .707 r
F P
0 g
s
.409 .31136 m .409 .81325 L .44804 .81932 L p .707 .577 .707 r
F P
0 g
s
.70322 .81786 m .70121 .8365 L .69829 .82905 L p .707 .577 .707 r
F P
0 g
s
.69829 .82905 m .7003 .81041 L .70322 .81786 L p .707 .577 .707 r
F P
0 g
s
.2212 .72018 m .22466 .66738 L .1972 .65936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19374 .71216 m .1972 .65936 L .1761 .64862 L p .707 .577 .707 r
F P
0 g
s
.1972 .65936 m .19521 .68975 L p .2212 .72018 L .707 .577 .707 r
F P
0 g
s
.21751 .7191 m .2212 .72018 L p .19521 .68975 L .707 .577 .707 r
F P
0 g
s
.22044 .71774 m .22097 .72365 L p .25488 .7537 L .707 .577 .707 r
F P
0 g
s
.22097 .72365 m .22384 .75597 L .24438 .75446 L p .707 .577 .707 r
F P
0 g
s
.24438 .75446 m .25488 .7537 L p .22097 .72365 L .707 .577 .707 r
F P
0 g
s
.19521 .68975 m .19374 .71216 L .21751 .7191 L p .707 .577 .707 r
F P
0 g
s
.61192 .30575 m .61192 .80764 L .63456 .79716 L p .707 .577 .707 r
F P
0 g
s
.63456 .79716 m .63456 .29527 L .61192 .30575 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .25148 .71546 L .22044 .71774 L p .707 .577 .707 r
F P
0 g
s
.22384 .75597 m .22044 .71774 L .19312 .71908 L p .707 .577 .707 r
F P
0 g
s
.7003 .81041 m .69829 .82905 L .68572 .82116 L p .707 .577 .707 r
F P
0 g
s
.68572 .82116 m .68773 .80252 L .7003 .81041 L p .707 .577 .707 r
F P
0 g
s
.19312 .71908 m .19651 .75731 L .22384 .75597 L p .707 .577 .707 r
F P
0 g
s
.37887 .80423 m .37887 .30235 L .3606 .29127 L p .707 .577 .707 r
F P
0 g
s
.37887 .30235 m .37887 .80423 L .409 .81325 L p .707 .577 .707 r
F P
0 g
s
.35357 .70455 m .35703 .65175 L .34079 .66184 L p .707 .577 .707 r
F P
0 g
s
.17263 .70142 m .1761 .64862 L .16342 .6362 L p .707 .577 .707 r
F P
0 g
s
.1761 .64862 m .17263 .70142 L .19374 .71216 L p .707 .577 .707 r
F P
0 g
s
.25213 .82381 m .253 .80594 L .22184 .80207 L p .707 .577 .707 r
F P
0 g
s
.253 .80594 m .25213 .82381 L .28393 .82404 L p .707 .577 .707 r
F P
0 g
s
.28393 .82404 m .28479 .80617 L .253 .80594 L p .707 .577 .707 r
F P
0 g
s
.19651 .75731 m .19312 .71908 L .17218 .71935 L p .707 .577 .707 r
F P
0 g
s
.28479 .80617 m .28393 .82404 L .31324 .82061 L p .707 .577 .707 r
F P
0 g
s
.31324 .82061 m .3141 .80274 L .28479 .80617 L p .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .66498 .71452 L .63779 .70734 L p .707 .577 .707 r
F P
0 g
s
.63779 .70734 m .64582 .65148 L .67301 .65866 L p .707 .577 .707 r
F P
0 g
s
.17218 .71935 m .17557 .75758 L .19651 .75731 L p .707 .577 .707 r
F P
0 g
s
.22097 .81995 m .22184 .80207 L .19435 .79495 L p .707 .577 .707 r
F P
0 g
s
.22184 .80207 m .22097 .81995 L .25213 .82381 L p .707 .577 .707 r
F P
0 g
s
.19435 .79495 m .19349 .81282 L .22097 .81995 L p .707 .577 .707 r
F P
0 g
s
.35622 .74055 m .35282 .70231 L .33648 .70556 L p .707 .577 .707 r
F P
0 g
s
.63741 .80715 m .63942 .78851 L .66675 .79498 L p .707 .577 .707 r
F P
0 g
s
.63456 .29527 m .63456 .79716 L .64403 .78532 L p .707 .577 .707 r
F P
0 g
s
.64403 .78532 m .64403 .28343 L .63456 .29527 L p .707 .577 .707 r
F P
0 g
s
.3141 .80274 m .31324 .82061 L .3372 .81385 L p .707 .577 .707 r
F P
0 g
s
.3372 .81385 m .33806 .79598 L .3141 .80274 L p .707 .577 .707 r
F P
0 g
s
.68773 .80252 m .68572 .82116 L .66474 .81362 L p .707 .577 .707 r
F P
0 g
s
.66474 .81362 m .66675 .79498 L .68773 .80252 L p .707 .577 .707 r
F P
0 g
s
.35703 .65175 m .35357 .70455 L .36053 .69247 L p .707 .577 .707 r
F P
0 g
s
.36053 .69247 m .36399 .63967 L .35703 .65175 L p .707 .577 .707 r
F P
0 g
s
.19349 .81282 m .19435 .79495 L .17324 .78525 L p .707 .577 .707 r
F P
0 g
s
.16342 .6362 m .15996 .689 L .17263 .70142 L p .707 .577 .707 r
F P
0 g
s
.15996 .689 m .16342 .6362 L .16042 .62333 L p .707 .577 .707 r
F P
0 g
s
.17557 .75758 m .17218 .71935 L .15968 .71852 L p .707 .577 .707 r
F P
0 g
s
.17324 .78525 m .17237 .80312 L .19349 .81282 L p .707 .577 .707 r
F P
0 g
s
.35282 .70231 m .35622 .74055 L .36332 .73787 L p .707 .577 .707 r
F P
0 g
s
.36332 .73787 m .35992 .69964 L .35282 .70231 L p .707 .577 .707 r
F P
0 g
s
.36399 .63967 m .36053 .69247 L .35753 .67959 L p .707 .577 .707 r
F P
0 g
s
.35753 .67959 m .36099 .62679 L .36399 .63967 L p .707 .577 .707 r
F P
0 g
s
.36043 .79326 m .3613 .77539 L .35433 .78656 L p .707 .577 .707 r
F P
0 g
s
.35992 .69964 m .36332 .73787 L .36048 .73603 L p .707 .577 .707 r
F P
0 g
s
.36048 .73603 m .35709 .6978 L .35992 .69964 L p .707 .577 .707 r
F P
0 g
s
.36099 .62679 m .35753 .67959 L .34485 .66717 L p .707 .577 .707 r
F P
0 g
s
.34485 .66717 m .34832 .61437 L .36099 .62679 L p .707 .577 .707 r
F P
0 g
s
.3613 .77539 m .36043 .79326 L .35744 .78145 L p .707 .577 .707 r
F P
0 g
s
.35744 .78145 m .3583 .76358 L .3613 .77539 L p .707 .577 .707 r
F P
0 g
s
.35709 .6978 m .36048 .73603 L .34798 .73521 L p .707 .577 .707 r
F P
0 g
s
.3606 .79316 m .3606 .29127 L .35597 .27923 L p .707 .577 .707 r
F P
0 g
s
.3606 .29127 m .3606 .79316 L .37887 .80423 L p .707 .577 .707 r
F P
0 g
s
.15968 .71852 m .16307 .75675 L .17557 .75758 L p .707 .577 .707 r
F P
0 g
s
.33806 .79598 m .3372 .81385 L .35346 .80443 L p .707 .577 .707 r
F P
0 g
s
.35346 .80443 m .35433 .78656 L .33806 .79598 L p .707 .577 .707 r
F P
0 g
s
.66675 .79498 m .66474 .81362 L .63741 .80715 L p .707 .577 .707 r
F P
0 g
s
.17237 .80312 m .17324 .78525 L .16056 .77395 L p .707 .577 .707 r
F P
0 g
s
.16042 .62333 m .15695 .67613 L .15996 .689 L p .707 .577 .707 r
F P
0 g
s
.16056 .77395 m .1597 .79182 L .17237 .80312 L p .707 .577 .707 r
F P
0 g
s
.15695 .67613 m .16042 .62333 L .16738 .61125 L p .707 .577 .707 r
F P
0 g
s
.16307 .75675 m .15968 .71852 L .15684 .71668 L p .707 .577 .707 r
F P
0 g
s
.64403 .28343 m .64403 .78532 L .6394 .77327 L p .707 .577 .707 r
F P
0 g
s
.6394 .77327 m .6394 .27139 L .64403 .28343 L p .707 .577 .707 r
F P
0 g
s
.15684 .71668 m .16024 .75491 L .16307 .75675 L p .707 .577 .707 r
F P
0 g
s
.35433 .78656 m .35346 .80443 L .36043 .79326 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1597 .79182 m .16056 .77395 L .15756 .76213 L p .707 .577 .707 r
F P
0 g
s
.34798 .73521 m .34459 .69698 L .35709 .6978 L p .707 .577 .707 r
F P
0 g
s
.3583 .76358 m .35744 .78145 L .34476 .77014 L p .707 .577 .707 r
F P
0 g
s
.34476 .77014 m .34563 .75227 L .3583 .76358 L p .707 .577 .707 r
F P
0 g
s
.35597 .27923 m .35597 .78112 L .3606 .79316 L p .707 .577 .707 r
F P
0 g
s
.35597 .78112 m .35597 .27923 L .36544 .26739 L p .707 .577 .707 r
F P
0 g
s
.16738 .61125 m .16391 .66405 L .15695 .67613 L p .707 .577 .707 r
F P
0 g
s
.15756 .76213 m .1567 .78001 L .1597 .79182 L p .707 .577 .707 r
F P
0 g
s
.16391 .66405 m .16738 .61125 L .18362 .60115 L p .707 .577 .707 r
F P
0 g
s
.16024 .75491 m .15684 .71668 L .16394 .71401 L p .707 .577 .707 r
F P
0 g
s
.16394 .71401 m .16734 .75224 L .16024 .75491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1567 .78001 m .15756 .76213 L .16454 .75097 L p .707 .577 .707 r
F P
0 g
s
.6394 .27139 m .6394 .77327 L .62113 .7622 L p .707 .577 .707 r
F P
0 g
s
.62113 .7622 m .62113 .26031 L .6394 .27139 L p .707 .577 .707 r
F P
0 g
s
.34832 .61437 m .34485 .66717 L .32375 .65643 L p .707 .577 .707 r
F P
0 g
s
.32375 .65643 m .32721 .60363 L .34832 .61437 L p .707 .577 .707 r
F P
0 g
s
.18362 .60115 m .18016 .65395 L .16391 .66405 L p .707 .577 .707 r
F P
0 g
s
.16454 .75097 m .16367 .76884 L .1567 .78001 L p .707 .577 .707 r
F P
0 g
s
.18016 .65395 m .18362 .60115 L .20755 .59403 L p .707 .577 .707 r
F P
0 g
s
.36544 .76928 m .36544 .26739 L .38808 .25691 L p .707 .577 .707 r
F P
0 g
s
.36544 .26739 m .36544 .76928 L .35597 .78112 L p .707 .577 .707 r
F P
0 g
s
.16734 .75224 m .16394 .71401 L .18029 .71076 L p .707 .577 .707 r
F P
0 g
s
.18029 .71076 m .18368 .74899 L .16734 .75224 L p .707 .577 .707 r
F P
0 g
s
.32721 .60363 m .32375 .65643 L .29628 .64842 L p .707 .577 .707 r
F P
0 g
s
.29628 .64842 m .29975 .59562 L .32721 .60363 L p .707 .577 .707 r
F P
0 g
s
.20409 .64683 m .20755 .59403 L .23684 .59057 L p .707 .577 .707 r
F P
0 g
s
.20755 .59403 m .20409 .64683 L .18016 .65395 L p .707 .577 .707 r
F P
0 g
s
.16367 .76884 m .16454 .75097 L .1808 .74155 L p .707 .577 .707 r
F P
0 g
s
.34459 .69698 m .34798 .73521 L .32704 .73548 L p .707 .577 .707 r
F P
0 g
s
.32704 .73548 m .32365 .69725 L .34459 .69698 L p .707 .577 .707 r
F P
0 g
s
.1808 .74155 m .17994 .75942 L .16367 .76884 L p .707 .577 .707 r
F P
0 g
s
.29975 .59562 m .29628 .64842 L .26514 .64392 L p .707 .577 .707 r
F P
0 g
s
.26514 .64392 m .26861 .59112 L .29975 .59562 L p .707 .577 .707 r
F P
0 g
s
.23338 .64337 m .23684 .59057 L .26861 .59112 L p .707 .577 .707 r
F P
0 g
s
.23684 .59057 m .23338 .64337 L .20409 .64683 L p .707 .577 .707 r
F P
0 g
s
.62113 .26031 m .62113 .7622 L .591 .75319 L p .707 .577 .707 r
F P
0 g
s
.591 .75319 m .591 .2513 L .62113 .26031 L p .707 .577 .707 r
F P
0 g
s
.26861 .59112 m .26514 .64392 L .23338 .64337 L p .707 .577 .707 r
F P
0 g
s
.18368 .74899 m .18029 .71076 L .20428 .70726 L p .707 .577 .707 r
F P
0 g
s
.34563 .75227 m .34476 .77014 L .32365 .76045 L p .707 .577 .707 r
F P
0 g
s
.32365 .76045 m .32451 .74258 L .34563 .75227 L p .707 .577 .707 r
F P
0 g
s
.20428 .70726 m .20767 .74549 L .18368 .74899 L p .707 .577 .707 r
F P
0 g
s
.38808 .25691 m .38808 .7588 L .36544 .76928 L p .707 .577 .707 r
F P
0 g
s
.38808 .7588 m .38808 .25691 L .42168 .24883 L p .707 .577 .707 r
F P
0 g
s
.17994 .75942 m .1808 .74155 L .20476 .73479 L p .707 .577 .707 r
F P
0 g
s
.73485 .64433 m .73139 .58724 L .70025 .58818 L p .707 .577 .707 r
F P
0 g
s
.73139 .58724 m .73485 .64433 L .76662 .64204 L p .707 .577 .707 r
F P
0 g
s
.76662 .64204 m .76316 .58495 L .73139 .58724 L p .707 .577 .707 r
F P
0 g
s
.32365 .69725 m .32704 .73548 L .29972 .73682 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .29632 .69858 L .32365 .69725 L p .707 .577 .707 r
F P
0 g
s
.76316 .58495 m .76662 .64204 L .79591 .63862 L p .707 .577 .707 r
F P
0 g
s
.79591 .63862 m .79244 .58153 L .76316 .58495 L p .707 .577 .707 r
F P
0 g
s
.20476 .73479 m .20389 .75266 L .17994 .75942 L p .707 .577 .707 r
F P
0 g
s
.70371 .64527 m .70025 .58818 L .67278 .58767 L p .707 .577 .707 r
F P
0 g
s
.70025 .58818 m .70371 .64527 L .73485 .64433 L p .707 .577 .707 r
F P
0 g
s
.20767 .74549 m .20428 .70726 L .23357 .70385 L p .707 .577 .707 r
F P
0 g
s
.32451 .74258 m .32365 .76045 L .29616 .75332 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .26868 .73909 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29632 .69858 m .29779 .7151 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29779 .7151 m .29972 .73682 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .29703 .73545 L .31522 .74017 L p .707 .577 .707 r
F P
0 g
s
.31522 .74017 m .32451 .74258 L p .31849 .74486 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .31522 .74017 L .31849 .74486 L .707 .577 .707 r
F
.23357 .70385 m .23696 .74208 L .20767 .74549 L p F P
0 g
s
.67278 .58767 m .67625 .64476 L .70371 .64527 L p .707 .577 .707 r
F P
0 g
s
.79244 .58153 m .79591 .63862 L .81984 .63441 L p .707 .577 .707 r
F P
0 g
s
.81984 .63441 m .81638 .57732 L .79244 .58153 L p .707 .577 .707 r
F P
0 g
s
.591 .2513 m .591 .75319 L .55196 .74711 L p .707 .577 .707 r
F P
0 g
s
.55196 .74711 m .55196 .24522 L .591 .2513 L p .707 .577 .707 r
F P
0 g
s
.20389 .75266 m .20476 .73479 L .23407 .73136 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .26528 .70086 L .29632 .69858 L p .707 .577 .707 r
F P
0 g
s
.23696 .74208 m .23357 .70385 L .26528 .70086 L p .707 .577 .707 r
F P
0 g
s
.67625 .64476 m .67278 .58767 L .65168 .58576 L p .707 .577 .707 r
F P
0 g
s
.735 .75033 m .73413 .73138 L .71389 .73153 L p .707 .577 .707 r
F P
0 g
s
.71389 .73153 m .70297 .7316 L p .70966 .73551 L .707 .577 .707 r
F P
0 g
s
.735 .75033 m .71389 .73153 L .70966 .73551 L .707 .577 .707 r
F
.73413 .73138 m .735 .75033 L .76679 .74842 L p F P
0 g
s
.76679 .74842 m .76593 .72947 L .74717 .7306 L p .707 .577 .707 r
F P
0 g
s
.74717 .7306 m .73413 .73138 L p .74211 .73554 L .707 .577 .707 r
F P
0 g
s
.76679 .74842 m .74717 .7306 L .74211 .73554 L .707 .577 .707 r
F
.76593 .72947 m .76679 .74842 L .7961 .74501 L p F P
0 g
s
.7961 .74501 m .79524 .72606 L .77973 .72787 L p .707 .577 .707 r
F P
0 g
s
.77973 .72787 m .76593 .72947 L p .77476 .73402 L .707 .577 .707 r
F P
0 g
s
.7961 .74501 m .77973 .72787 L .77476 .73402 L .707 .577 .707 r
F
.79524 .72606 m .7961 .74501 L .82006 .74042 L p F P
0 g
s
.82006 .74042 m .8192 .72148 L .80787 .72364 L p .707 .577 .707 r
F P
0 g
s
.80787 .72364 m .79524 .72606 L p .804 .73113 L .707 .577 .707 r
F P
0 g
s
.82006 .74042 m .80787 .72364 L .804 .73113 L .707 .577 .707 r
F
.8192 .72148 m .82006 .74042 L .83633 .73512 L p F P
0 g
s
.83633 .73512 m .83546 .71618 L .8192 .72148 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .83266 .71377 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81971 .69107 m .81851 .70309 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81851 .70309 m .81631 .72509 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .81631 .72509 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79572 .69884 m .79467 .70936 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79467 .70936 m .79232 .73287 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .79232 .73287 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76643 .70231 m .76538 .71279 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76538 .71279 m .76304 .73633 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .76304 .73633 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73471 .70112 m .73352 .71305 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73352 .71305 m .73132 .73515 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .73471 .70112 L .70367 .6954 L p .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .76643 .70231 L .73471 .70112 L p .707 .577 .707 r
F P
0 g
s
.23407 .73136 m .23321 .74923 L .20389 .75266 L p .707 .577 .707 r
F P
0 g
s
.42168 .75072 m .42168 .24883 L .46294 .24392 L p .707 .577 .707 r
F P
0 g
s
.42168 .24883 m .42168 .75072 L .38808 .7588 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .23696 .74208 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.26647 .71427 m .26868 .73909 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .26586 .73158 L .28611 .7341 L p .707 .577 .707 r
F P
0 g
s
.28611 .7341 m .29703 .73545 L p .29034 .73838 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .28611 .7341 L .29034 .73838 L .707 .577 .707 r
F
.26528 .70086 m .26647 .71427 L p .26033 .70807 L F P
0 g
s
.29703 .73545 m .29616 .75332 L .265 .74946 L p .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .79572 .69884 L .76643 .70231 L p .707 .577 .707 r
F P
0 g
s
.70028 .72943 m .70367 .6954 L .67635 .68571 L p .707 .577 .707 r
F P
0 g
s
.70367 .6954 m .70028 .72943 L .73132 .73515 L p .707 .577 .707 r
F P
0 g
s
.23321 .74923 m .23407 .73136 L .26586 .73158 L p .707 .577 .707 r
F P
0 g
s
.65168 .58576 m .65514 .64285 L .67625 .64476 L p .707 .577 .707 r
F P
0 g
s
.26586 .73158 m .265 .74946 L .23321 .74923 L p .707 .577 .707 r
F P
0 g
s
.81638 .57732 m .81984 .63441 L .83608 .6298 L p .707 .577 .707 r
F P
0 g
s
.83608 .6298 m .83262 .57271 L .81638 .57732 L p .707 .577 .707 r
F P
0 g
s
.70297 .7316 m .70383 .75055 L .735 .75033 L p .707 .577 .707 r
F P
0 g
s
.55196 .24522 m .55196 .74711 L .50783 .74457 L p .707 .577 .707 r
F P
0 g
s
.50783 .74457 m .50783 .24268 L .55196 .24522 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .81971 .69107 L .79572 .69884 L p .707 .577 .707 r
F P
0 g
s
.70383 .75055 m .70297 .7316 L .67549 .73011 L p .707 .577 .707 r
F P
0 g
s
.46294 .74581 m .46294 .24392 L .50783 .24268 L p .707 .577 .707 r
F P
0 g
s
.46294 .24392 m .46294 .74581 L .42168 .75072 L p .707 .577 .707 r
F P
0 g
s
.67295 .71974 m .67635 .68571 L .65541 .67299 L p .707 .577 .707 r
F P
0 g
s
.67635 .68571 m .67295 .71974 L .70028 .72943 L p .707 .577 .707 r
F P
0 g
s
.67549 .73011 m .67635 .74906 L .70383 .75055 L p .707 .577 .707 r
F P
0 g
s
.50783 .24268 m .50783 .74457 L .46294 .74581 L p .707 .577 .707 r
F P
0 g
s
.65514 .64285 m .65168 .58576 L .63901 .58264 L p .707 .577 .707 r
F P
0 g
s
.63901 .58264 m .64247 .63973 L .65514 .64285 L p .707 .577 .707 r
F P
0 g
s
.67635 .74906 m .67549 .73011 L .65437 .72706 L p .707 .577 .707 r
F P
0 g
s
.83266 .71377 m .83605 .67974 L .81971 .69107 L p .707 .577 .707 r
F P
0 g
s
.65437 .72706 m .65524 .746 L .67635 .74906 L p .707 .577 .707 r
F P
0 g
s
.65541 .67299 m .65202 .70702 L .67295 .71974 L p .707 .577 .707 r
F P
0 g
s
.65202 .70702 m .65541 .67299 L .64291 .65849 L p .707 .577 .707 r
F P
0 g
s
.83262 .57271 m .83608 .6298 L .84304 .62527 L p .707 .577 .707 r
F P
0 g
s
.84304 .62527 m .83958 .56818 L .83262 .57271 L p .707 .577 .707 r
F P
0 g
s
.64247 .63973 m .63901 .58264 L .636 .57862 L p .707 .577 .707 r
F P
0 g
s
.65524 .746 m .65437 .72706 L .6417 .72274 L p .707 .577 .707 r
F P
0 g
s
.64291 .65849 m .63952 .69252 L .65202 .70702 L p .707 .577 .707 r
F P
0 g
s
.6417 .72274 m .64256 .74168 L .65524 .746 L p .707 .577 .707 r
F P
0 g
s
.636 .57862 m .63947 .63571 L .64247 .63973 L p .707 .577 .707 r
F P
0 g
s
.83605 .67974 m .83266 .71377 L .83976 .7 L p .707 .577 .707 r
F P
0 g
s
.83976 .7 m .84316 .66598 L .83605 .67974 L p .707 .577 .707 r
F P
0 g
s
.63952 .69252 m .64291 .65849 L .64007 .64363 L p .707 .577 .707 r
F P
0 g
s
.83958 .56818 m .84304 .62527 L .84004 .62125 L p .707 .577 .707 r
F P
0 g
s
.84004 .62125 m .83658 .56416 L .83958 .56818 L p .707 .577 .707 r
F P
0 g
s
.83546 .71618 m .83633 .73512 L .8433 .72962 L p .707 .577 .707 r
F P
0 g
s
.8433 .72962 m .84243 .71067 L .83546 .71618 L p .707 .577 .707 r
F P
0 g
s
.64007 .64363 m .63668 .67766 L .63952 .69252 L p .707 .577 .707 r
F P
0 g
s
.63947 .63571 m .636 .57862 L .64296 .57409 L p .707 .577 .707 r
F P
0 g
s
.64256 .74168 m .6417 .72274 L .6387 .71757 L p .707 .577 .707 r
F P
0 g
s
.6387 .71757 m .63956 .73652 L .64256 .74168 L p .707 .577 .707 r
F P
0 g
s
.84316 .66598 m .83976 .7 L .83693 .68515 L p .707 .577 .707 r
F P
0 g
s
.83693 .68515 m .84032 .65112 L .84316 .66598 L p .707 .577 .707 r
F P
0 g
s
.64296 .57409 m .64643 .63118 L .63947 .63571 L p .707 .577 .707 r
F P
0 g
s
.63668 .67766 m .64007 .64363 L .64718 .62987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83658 .56416 m .84004 .62125 L .82737 .61813 L p .707 .577 .707 r
F P
0 g
s
.82737 .61813 m .8239 .56104 L .83658 .56416 L p .707 .577 .707 r
F P
0 g
s
.84243 .71067 m .8433 .72962 L .8403 .72445 L p .707 .577 .707 r
F P
0 g
s
.8403 .72445 m .83944 .70551 L .84243 .71067 L p .707 .577 .707 r
F P
0 g
s
.39308 .62674 m .38505 .57272 L .35418 .57452 L p .707 .577 .707 r
F P
0 g
s
.38505 .57272 m .39308 .62674 L .42461 .62161 L p .707 .577 .707 r
F P
0 g
s
.42461 .62161 m .41658 .56758 L .38505 .57272 L p .707 .577 .707 r
F P
0 g
s
.41658 .56758 m .42461 .62161 L .4537 .61364 L p .707 .577 .707 r
F P
0 g
s
.4537 .61364 m .44567 .55961 L .41658 .56758 L p .707 .577 .707 r
F P
0 g
s
.65921 .56949 m .65992 .58131 L p .64643 .63118 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .64718 .62987 L .66352 .61854 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .64378 .6639 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .66269 .62688 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66013 .65257 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .68751 .61077 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .6866 .62236 L .66652 .6259 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .66269 .62688 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66352 .61854 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .66013 .65257 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .68651 .62079 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .68412 .6448 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .7168 .60731 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L .68732 .62069 L .707 .577 .707 r
F
.68651 .62079 m .68751 .61077 L p .70716 .61836 L F P
0 g
s
.71589 .61894 m .6866 .62236 L p .68732 .62069 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .71426 .61753 L .71589 .61894 L .707 .577 .707 r
F
.71341 .64133 m .68412 .6448 L p .70716 .61836 L F P
0 g
s
.7168 .60731 m .7158 .61734 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.7168 .60731 m .74852 .60849 L p .7394 .61701 L .707 .577 .707 r
F P
0 g
s
.74335 .61696 m .71589 .61894 L p .71665 .61733 L .707 .577 .707 r
F P
0 g
s
.72838 .62732 m .72255 .61725 L .7394 .61701 L .707 .577 .707 r
F
.72255 .61725 m .7168 .60731 L .7394 .61701 L F
.74852 .60849 m .74768 .61689 L p .71341 .64133 L F P
0 g
s
.74768 .61689 m .74512 .64252 L .71891 .64154 L p .707 .577 .707 r
F P
0 g
s
.71891 .64154 m .71341 .64133 L p .74768 .61689 L .707 .577 .707 r
F P
0 g
s
.74512 .64252 m .74852 .60849 L .77956 .61421 L p .707 .577 .707 r
F P
0 g
s
.77533 .55862 m .77733 .59149 L p .74766 .61665 L .707 .577 .707 r
F P
0 g
s
.77956 .61421 m .77903 .61947 L p .74512 .64252 L .707 .577 .707 r
F P
0 g
s
.77903 .61947 m .77616 .64824 L .75562 .64445 L p .707 .577 .707 r
F P
0 g
s
.75562 .64445 m .74512 .64252 L p .77903 .61947 L .707 .577 .707 r
F P
0 g
s
.77616 .64824 m .77956 .61421 L .80688 .6239 L p .707 .577 .707 r
F P
0 g
s
.8028 .55913 m .80479 .59199 L p .7788 .61571 L .707 .577 .707 r
F P
0 g
s
.80479 .59199 m .80626 .61622 L .78249 .61578 L p .707 .577 .707 r
F P
0 g
s
.78249 .61578 m .7788 .61571 L p .80479 .59199 L .707 .577 .707 r
F P
0 g
s
.77733 .59149 m .7788 .61571 L .74797 .61664 L p .707 .577 .707 r
F P
0 g
s
.74797 .61664 m .74766 .61665 L p .77733 .59149 L .707 .577 .707 r
F P
0 g
s
.74419 .55956 m .74766 .61665 L .74335 .61696 L p .707 .577 .707 r
F P
0 g
s
.71589 .61894 m .7158 .61734 L .71665 .61733 L .707 .577 .707 r
F
.7158 .61735 m .7158 .61734 L p .72838 .62732 L F P
0 g
s
.7158 .61734 m .7168 .60731 L p .72255 .61725 L .707 .577 .707 r
F P
0 g
s
.7158 .61734 m .72255 .61725 L .72838 .62732 L .707 .577 .707 r
F
.71589 .61894 m .71579 .61735 L p .7158 .61734 L F P
0 g
s
.71665 .61733 m .7158 .61734 L .71728 .61602 L .707 .577 .707 r
F
.71665 .61733 m .74419 .55956 L .74335 .61696 L F
.71243 .56185 m .74419 .55956 L p .71728 .61602 L F P
0 g
s
.70716 .61836 m .7158 .61734 L .71579 .61735 L .707 .577 .707 r
F
.71579 .61735 m .71243 .56185 L p .71728 .61602 L F P
0 g
s
.7158 .61734 m .7158 .61735 L p .71579 .61735 L .707 .577 .707 r
F P
0 g
s
.71579 .61734 m .71589 .61894 L p .69558 .60132 L .707 .577 .707 r
F P
0 g
s
.7158 .61735 m .71341 .64133 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .69558 .60132 L .71426 .61753 L .707 .577 .707 r
F
.71243 .56185 m .71579 .61734 L p .69558 .60132 L F P
0 g
s
.71341 .64133 m .7158 .61735 L p .72838 .62732 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .68651 .62079 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .68651 .62079 L .688 .61909 L .707 .577 .707 r
F
.68314 .56527 m .71243 .56185 L p .688 .61909 L F P
0 g
s
.68651 .62079 m .68314 .56527 L p .688 .61909 L .707 .577 .707 r
F P
0 g
s
.6845 .58776 m .68651 .62079 L p .66288 .62654 L .707 .577 .707 r
F P
0 g
s
.66652 .6259 m .66288 .62654 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.68314 .56527 m .6845 .58776 L p .66267 .62658 L .707 .577 .707 r
F P
0 g
s
.66288 .62654 m .66267 .62658 L p .6845 .58776 L .707 .577 .707 r
F P
0 g
s
.65992 .58131 m .66267 .62658 L .6477 .63082 L p .707 .577 .707 r
F P
0 g
s
.64718 .62987 m .64666 .63502 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.6477 .63082 m .64643 .63118 L p .65992 .58131 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .63668 .67766 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.64666 .63502 m .64378 .6639 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36221 .62854 m .35418 .57452 L .32698 .57281 L p .707 .577 .707 r
F P
0 g
s
.35418 .57452 m .36221 .62854 L .39308 .62674 L p .707 .577 .707 r
F P
0 g
s
.64643 .63118 m .64296 .57409 L .65921 .56949 L p .707 .577 .707 r
F P
0 g
s
.63956 .73652 m .6387 .71757 L .64567 .71207 L p .707 .577 .707 r
F P
0 g
s
.84032 .65112 m .83693 .68515 L .82443 .67065 L p .707 .577 .707 r
F P
0 g
s
.82443 .67065 m .82782 .63662 L .84032 .65112 L p .707 .577 .707 r
F P
0 g
s
.44567 .55961 m .4537 .61364 L .47751 .60361 L p .707 .577 .707 r
F P
0 g
s
.47751 .60361 m .46948 .54959 L .44567 .55961 L p .707 .577 .707 r
F P
0 g
s
.64567 .71207 m .64654 .73101 L .63956 .73652 L p .707 .577 .707 r
F P
0 g
s
.38526 .67084 m .3931 .63382 L .36264 .62624 L p .707 .577 .707 r
F P
0 g
s
.3931 .63382 m .38526 .67084 L .41645 .67674 L p .707 .577 .707 r
F P
0 g
s
.41645 .67674 m .42429 .63972 L .3931 .63382 L p .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .30612 .56775 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33495 .62639 m .32698 .57281 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .32914 .58728 L p .36221 .62854 L .707 .577 .707 r
F P
0 g
s
.32914 .58728 m .33501 .62683 L .35953 .62837 L p .707 .577 .707 r
F P
0 g
s
.35953 .62837 m .36221 .62854 L p .32914 .58728 L .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .38526 .67084 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.36264 .62624 m .3616 .63116 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.3616 .63116 m .3548 .66326 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .33411 .62616 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .3096 .59114 L p .33501 .62683 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32805 .65474 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.30764 .64612 m .32805 .65474 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32258 .60969 L .314 .62075 L .707 .577 .707 r
F
.3096 .59114 m .31383 .61962 L p .32258 .60969 L F P
0 g
s
.31383 .61962 m .314 .62075 L p .32258 .60969 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .29364 .55984 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31383 .61962 m .30612 .56775 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31307 .6205 L p .314 .62075 L .707 .577 .707 r
F P
0 g
s
.30598 .62854 m .31108 .61811 L .30466 .61457 L .707 .577 .707 r
F
.30764 .64612 m .31307 .6205 L p .30598 .62854 L F P
0 g
s
.31307 .6205 m .31331 .61934 L p .30598 .62854 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31108 .61811 L .30598 .62854 L .707 .577 .707 r
F
.31307 .6205 m .30764 .64612 L p .3169 .62667 L F P
0 g
s
.31907 .62211 m .314 .62075 L .3169 .62667 L .707 .577 .707 r
F
.314 .62075 m .31307 .6205 L .3169 .62667 L F
.31336 .61936 m .30664 .5991 L .30152 .61284 L F
.29364 .55984 m .30135 .61171 L p .30664 .5991 L F P
0 g
s
.30135 .61171 m .30152 .61284 L p .30664 .5991 L .707 .577 .707 r
F P
0 g
s
.29364 .55984 m .29076 .54986 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .30764 .64612 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.30132 .61178 m .30135 .61171 L .30126 .61144 L .707 .577 .707 r
F
.30152 .61284 m .30135 .61171 L p .30132 .61178 L F P
0 g
s
.30135 .61171 m .29364 .55984 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.30124 .61139 m .29556 .63824 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29773 .62033 m .30078 .61005 L .29945 .60622 L .707 .577 .707 r
F
.301 .61255 m .30124 .61139 L p .29773 .62033 L F P
0 g
s
.30124 .61139 m .30078 .61005 L .29773 .62033 L .707 .577 .707 r
F
.29955 .60651 m .30167 .61387 L p .30126 .61144 L F P
0 g
s
.30126 .61144 m .29076 .54986 L .29955 .60651 L .707 .577 .707 r
F
.30124 .61139 m .3034 .60122 L p .30078 .61005 L F P
0 g
s
.3034 .60122 m .30124 .61139 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29879 .60389 m .29955 .60651 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.3034 .60122 m .30083 .59485 L p .29945 .60622 L .707 .577 .707 r
F P
0 g
s
.30078 .61005 m .3034 .60122 L .29945 .60622 L .707 .577 .707 r
F
.31548 .6091 m .3034 .60122 L p .30466 .61457 L F P
0 g
s
.30083 .59485 m .30802 .59061 L p .30536 .59793 L .707 .577 .707 r
F P
0 g
s
.30038 .60203 m .30083 .59485 L .30536 .59793 L .707 .577 .707 r
F
.29879 .60389 m .29878 .60334 L .29908 .6031 L F
.30083 .59485 m .29908 .6031 L p .29556 .63824 L F P
0 g
s
.29526 .63749 m .29556 .63824 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29952 .60273 m .29904 .6035 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29904 .6035 m .29879 .60389 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29908 .6031 m .29299 .63187 L .29526 .63749 L p .707 .577 .707 r
F P
0 g
s
.29881 .60438 m .30083 .59485 L p .29965 .61357 L .707 .577 .707 r
F P
0 g
s
.29777 .53878 m .3058 .59281 L .29952 .60273 L p .707 .577 .707 r
F P
0 g
s
.29878 .60334 m .29777 .53878 L .29952 .60273 L .707 .577 .707 r
F
.29965 .61357 m .30038 .60203 L .30536 .59793 L F
.29299 .63187 m .29881 .60438 L p .29965 .61357 L F P
0 g
s
.29076 .54986 m .29872 .60339 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.29872 .60339 m .29879 .60389 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .30152 .61284 L p .30132 .61178 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .301 .61255 L p .29773 .62033 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .31415 .62177 L p .31342 .61956 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31336 .61936 L .31331 .61934 L .707 .577 .707 r
F
.31342 .61956 m .31331 .61934 L .30167 .61387 L F
.30152 .61284 m .30167 .61387 L p .31336 .61936 L F P
0 g
s
.31331 .61934 m .31548 .6091 L p .31108 .61811 L .707 .577 .707 r
F P
0 g
s
.31548 .6091 m .31331 .61934 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31383 .61962 L .31336 .61936 L .707 .577 .707 r
F
.314 .62075 m .31383 .61962 L p .31342 .61956 L F P
0 g
s
.31907 .62211 m .31331 .61934 L .314 .62075 L .707 .577 .707 r
F
.31415 .62177 m .314 .62075 L p .31342 .61956 L F P
0 g
s
.31108 .61811 m .31548 .6091 L .30466 .61457 L .707 .577 .707 r
F
.31415 .62177 m .33449 .6267 L p .33411 .62616 L F P
0 g
s
.314 .62075 m .31415 .62177 L p .33411 .62616 L .707 .577 .707 r
F P
0 g
s
.33449 .6267 m .33501 .62683 L p .3096 .59114 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .3548 .66326 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33501 .62683 m .33495 .62639 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .33411 .62616 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .31548 .6091 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .33589 .61772 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.8239 .56104 m .82737 .61813 L .80626 .61622 L p .707 .577 .707 r
F P
0 g
s
.80626 .61622 m .8028 .55913 L .8239 .56104 L p .707 .577 .707 r
F P
0 g
s
.42429 .63972 m .41645 .67674 L .44532 .68039 L p .707 .577 .707 r
F P
0 g
s
.44532 .68039 m .45316 .64337 L .42429 .63972 L p .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .36264 .62624 L .33589 .61772 L p .707 .577 .707 r
F P
0 g
s
.83944 .70551 m .8403 .72445 L .82763 .72013 L p .707 .577 .707 r
F P
0 g
s
.82763 .72013 m .82676 .70119 L .83944 .70551 L p .707 .577 .707 r
F P
0 g
s
.46948 .54959 m .47751 .60361 L .49371 .59252 L p .707 .577 .707 r
F P
0 g
s
.49371 .59252 m .48568 .5385 L .46948 .54959 L p .707 .577 .707 r
F P
0 g
s
.66267 .62658 m .65921 .56949 L .68314 .56527 L p .707 .577 .707 r
F P
0 g
s
.82782 .63662 m .82443 .67065 L .80349 .65793 L p .707 .577 .707 r
F P
0 g
s
.80349 .65793 m .80688 .6239 L .82782 .63662 L p .707 .577 .707 r
F P
0 g
s
.45316 .64337 m .44532 .68039 L .46904 .68142 L p .707 .577 .707 r
F P
0 g
s
.46904 .68142 m .47688 .6444 L .45316 .64337 L p .707 .577 .707 r
F P
0 g
s
.3936 .72747 m .39159 .7093 L .36058 .7102 L p .707 .577 .707 r
F P
0 g
s
.39159 .7093 m .3936 .72747 L .42526 .7234 L p .707 .577 .707 r
F P
0 g
s
.42526 .7234 m .42325 .70522 L .39159 .7093 L p .707 .577 .707 r
F P
0 g
s
.64654 .73101 m .64567 .71207 L .66194 .70677 L p .707 .577 .707 r
F P
0 g
s
.42325 .70522 m .42526 .7234 L .45446 .71655 L p .707 .577 .707 r
F P
0 g
s
.45446 .71655 m .45245 .69837 L .42325 .70522 L p .707 .577 .707 r
F P
0 g
s
.66194 .70677 m .6628 .72571 L .64654 .73101 L p .707 .577 .707 r
F P
0 g
s
.36058 .7102 m .36259 .72838 L .3936 .72747 L p .707 .577 .707 r
F P
0 g
s
.36259 .72838 m .36058 .7102 L .33325 .70785 L p .707 .577 .707 r
F P
0 g
s
.7788 .61571 m .77533 .55862 L .8028 .55913 L p .707 .577 .707 r
F P
0 g
s
.45245 .69837 m .45446 .71655 L .47835 .70759 L p .707 .577 .707 r
F P
0 g
s
.47835 .70759 m .47634 .68942 L .45245 .69837 L p .707 .577 .707 r
F P
0 g
s
.33325 .70785 m .33526 .72602 L .36259 .72838 L p .707 .577 .707 r
F P
0 g
s
.48568 .5385 m .49371 .59252 L .50071 .58144 L p .707 .577 .707 r
F P
0 g
s
.50071 .58144 m .49268 .52742 L .48568 .5385 L p .707 .577 .707 r
F P
0 g
s
.80688 .6239 m .80349 .65793 L .77616 .64824 L p .707 .577 .707 r
F P
0 g
s
.82676 .70119 m .82763 .72013 L .80651 .71707 L p .707 .577 .707 r
F P
0 g
s
.80651 .71707 m .80565 .69813 L .82676 .70119 L p .707 .577 .707 r
F P
0 g
s
.47688 .6444 m .46904 .68142 L .48529 .67973 L p .707 .577 .707 r
F P
0 g
s
.48529 .67973 m .49313 .64271 L .47688 .6444 L p .707 .577 .707 r
F P
0 g
s
.33526 .72602 m .33325 .70785 L .31227 .70246 L p .707 .577 .707 r
F P
0 g
s
.74766 .61665 m .74419 .55956 L .77533 .55862 L p .707 .577 .707 r
F P
0 g
s
.6628 .72571 m .66194 .70677 L .68589 .70218 L p .707 .577 .707 r
F P
0 g
s
.31227 .70246 m .31428 .72064 L .33526 .72602 L p .707 .577 .707 r
F P
0 g
s
.68589 .70218 m .68676 .72113 L .6628 .72571 L p .707 .577 .707 r
F P
0 g
s
.47634 .68942 m .47835 .70759 L .49459 .69741 L p .707 .577 .707 r
F P
0 g
s
.49459 .69741 m .49258 .67924 L .47634 .68942 L p .707 .577 .707 r
F P
0 g
s
.80565 .69813 m .80651 .71707 L .77903 .71558 L p .707 .577 .707 r
F P
0 g
s
.77903 .71558 m .77816 .69664 L .80565 .69813 L p .707 .577 .707 r
F P
0 g
s
.49268 .52742 m .50071 .58144 L .49783 .57146 L p .707 .577 .707 r
F P
0 g
s
.49783 .57146 m .4898 .51743 L .49268 .52742 L p .707 .577 .707 r
F P
0 g
s
.49313 .64271 m .48529 .67973 L .49249 .6755 L p .707 .577 .707 r
F P
0 g
s
.49249 .6755 m .50033 .63848 L .49313 .64271 L p .707 .577 .707 r
F P
0 g
s
.31428 .72064 m .31227 .70246 L .2997 .69457 L p .707 .577 .707 r
F P
0 g
s
.68676 .72113 m .68589 .70218 L .71521 .69877 L p .707 .577 .707 r
F P
0 g
s
.71521 .69877 m .71607 .71772 L .68676 .72113 L p .707 .577 .707 r
F P
0 g
s
.2997 .69457 m .30171 .71275 L .31428 .72064 L p .707 .577 .707 r
F P
0 g
s
.77816 .69664 m .77903 .71558 L .74786 .71581 L p .707 .577 .707 r
F P
0 g
s
.74786 .71581 m .747 .69686 L .77816 .69664 L p .707 .577 .707 r
F P
0 g
s
.49258 .67924 m .49459 .69741 L .50159 .68701 L p .707 .577 .707 r
F P
0 g
s
.50159 .68701 m .49958 .66883 L .49258 .67924 L p .707 .577 .707 r
F P
0 g
s
.71607 .71772 m .71521 .69877 L .747 .69686 L p .707 .577 .707 r
F P
0 g
s
.747 .69686 m .74786 .71581 L .71607 .71772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29879 .60389 m .29076 .54986 L .29777 .53878 L p .707 .577 .707 r
F P
0 g
s
.4898 .51743 m .49783 .57146 L .48535 .56355 L p .707 .577 .707 r
F P
0 g
s
.48535 .56355 m .47732 .50953 L .4898 .51743 L p .707 .577 .707 r
F P
0 g
s
.30171 .71275 m .2997 .69457 L .29677 .68495 L p .707 .577 .707 r
F P
0 g
s
.50033 .63848 m .49249 .6755 L .48992 .66913 L p .707 .577 .707 r
F P
0 g
s
.48992 .66913 m .49776 .63211 L .50033 .63848 L p .707 .577 .707 r
F P
0 g
s
.29677 .68495 m .29878 .70313 L .30171 .71275 L p .707 .577 .707 r
F P
0 g
s
.49958 .66883 m .50159 .68701 L .49866 .67739 L p .707 .577 .707 r
F P
0 g
s
.49866 .67739 m .49665 .65921 L .49958 .66883 L p .707 .577 .707 r
F P
0 g
s
.31396 .52769 m .31882 .56037 L p .3058 .59281 L .707 .577 .707 r
F P
0 g
s
.30018 .62763 m .30802 .59061 L .32428 .58893 L p .707 .577 .707 r
F P
0 g
s
.31882 .56037 m .32199 .58171 L .30848 .59097 L p .707 .577 .707 r
F P
0 g
s
.30802 .59061 m .30705 .59519 L p .29299 .63187 L .707 .577 .707 r
F P
0 g
s
.30848 .59097 m .3058 .59281 L p .31882 .56037 L .707 .577 .707 r
F P
0 g
s
.30705 .59519 m .30018 .62763 L .29507 .63064 L p .707 .577 .707 r
F P
0 g
s
.29507 .63064 m .29299 .63187 L p .30705 .59519 L .707 .577 .707 r
F P
0 g
s
.3058 .59281 m .29777 .53878 L .31396 .52769 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47732 .50953 m .48535 .56355 L .46449 .5585 L p .707 .577 .707 r
F P
0 g
s
.46449 .5585 m .45646 .50447 L .47732 .50953 L p .707 .577 .707 r
F P
0 g
s
.29878 .70313 m .29677 .68495 L .30377 .67455 L p .707 .577 .707 r
F P
0 g
s
.49776 .63211 m .48992 .66913 L .47784 .66124 L p .707 .577 .707 r
F P
0 g
s
.47784 .66124 m .48567 .62423 L .49776 .63211 L p .707 .577 .707 r
F P
0 g
s
.30377 .67455 m .30578 .69272 L .29878 .70313 L p .707 .577 .707 r
F P
0 g
s
.49665 .65921 m .49866 .67739 L .48609 .6695 L p .707 .577 .707 r
F P
0 g
s
.48609 .6695 m .48408 .65132 L .49665 .65921 L p .707 .577 .707 r
F P
0 g
s
.32199 .58171 m .31396 .52769 L .33778 .51767 L p .707 .577 .707 r
F P
0 g
s
.32428 .58893 m .31644 .62595 L .30018 .62763 L p .707 .577 .707 r
F P
0 g
s
.45646 .50447 m .46449 .5585 L .43729 .55679 L p .707 .577 .707 r
F P
0 g
s
.43729 .55679 m .42926 .50276 L .45646 .50447 L p .707 .577 .707 r
F P
0 g
s
.30578 .69272 m .30377 .67455 L .32001 .66437 L p .707 .577 .707 r
F P
0 g
s
.48567 .62423 m .47784 .66124 L .45742 .65262 L p .707 .577 .707 r
F P
0 g
s
.45742 .65262 m .46526 .6156 L .48567 .62423 L p .707 .577 .707 r
F P
0 g
s
.33778 .51767 m .34581 .57169 L .32199 .58171 L p .707 .577 .707 r
F P
0 g
s
.34581 .57169 m .33778 .51767 L .36687 .5097 L p .707 .577 .707 r
F P
0 g
s
.32001 .66437 m .32202 .68254 L .30578 .69272 L p .707 .577 .707 r
F P
0 g
s
.31644 .62595 m .32428 .58893 L .348 .58996 L p .707 .577 .707 r
F P
0 g
s
.42926 .50276 m .43729 .55679 L .40642 .55859 L p .707 .577 .707 r
F P
0 g
s
.40642 .55859 m .39839 .50456 L .42926 .50276 L p .707 .577 .707 r
F P
0 g
s
.48408 .65132 m .48609 .6695 L .46511 .66411 L p .707 .577 .707 r
F P
0 g
s
.46511 .66411 m .4631 .64594 L .48408 .65132 L p .707 .577 .707 r
F P
0 g
s
.348 .58996 m .34016 .62698 L .31644 .62595 L p .707 .577 .707 r
F P
0 g
s
.3749 .56372 m .36687 .5097 L .39839 .50456 L p .707 .577 .707 r
F P
0 g
s
.36687 .5097 m .3749 .56372 L .34581 .57169 L p .707 .577 .707 r
F P
0 g
s
.39839 .50456 m .40642 .55859 L .3749 .56372 L p .707 .577 .707 r
F P
0 g
s
.46526 .6156 m .45742 .65262 L .43068 .6441 L p .707 .577 .707 r
F P
0 g
s
.43068 .6441 m .43852 .60708 L .46526 .6156 L p .707 .577 .707 r
F P
0 g
s
.32202 .68254 m .32001 .66437 L .3439 .65541 L p .707 .577 .707 r
F P
0 g
s
.34016 .62698 m .348 .58996 L .37687 .5936 L p .707 .577 .707 r
F P
0 g
s
.3439 .65541 m .34591 .67359 L .32202 .68254 L p .707 .577 .707 r
F P
0 g
s
.4631 .64594 m .46511 .66411 L .43778 .66176 L p .707 .577 .707 r
F P
0 g
s
.43778 .66176 m .43577 .64358 L .4631 .64594 L p .707 .577 .707 r
F P
0 g
s
.37687 .5936 m .36903 .63062 L .34016 .62698 L p .707 .577 .707 r
F P
0 g
s
.43852 .60708 m .43068 .6441 L .40022 .63652 L p .707 .577 .707 r
F P
0 g
s
.40022 .63652 m .40806 .5995 L .43852 .60708 L p .707 .577 .707 r
F P
0 g
s
.36903 .63062 m .37687 .5936 L .40806 .5995 L p .707 .577 .707 r
F P
0 g
s
.34591 .67359 m .3439 .65541 L .3731 .64856 L p .707 .577 .707 r
F P
0 g
s
.40806 .5995 m .40022 .63652 L .36903 .63062 L p .707 .577 .707 r
F P
0 g
s
.43577 .64358 m .43778 .66176 L .40677 .66266 L p .707 .577 .707 r
F P
0 g
s
.40677 .66266 m .40476 .64449 L .43577 .64358 L p .707 .577 .707 r
F P
0 g
s
.3731 .64856 m .37511 .66674 L .34591 .67359 L p .707 .577 .707 r
F P
0 g
s
.37511 .66674 m .3731 .64856 L .40476 .64449 L p .707 .577 .707 r
F P
0 g
s
.40476 .64449 m .40677 .66266 L .37511 .66674 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEQL000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005moo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005eoo`800003
FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001GOol30007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20002FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool20004FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH015YF5@000eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000087oo2000?Goo001BOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH0
0eYF0`001EYF0`0000=JEP00FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000mooa4000AJEP04001JEUYFFUH<000aOol005=oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH0000000<000AJEP03001JEP0000<00003
FUH005YF00IJEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00001goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH010001EYF2`001EYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP8000EJEPD00003FUH005YF00X000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YF00001EYF00@005YFFUIJEPX000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH0
0005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP000eYF00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo0010Ool8000;Ool01@00FUIJEP00FUH03`00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool003Yoo`H000=JEP03001JEUYF009JEPT000=oo`04001JEP000004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH600000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0006FUH20005FUH01000FUH00000;Woo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000030006
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP8000EJEP04001JEUYF000^Ool003Aoo`8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00EJEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF0P001EYF0P00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF0P001EYF00<005YFFUH00P00;Goo000bOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH00eYF0P00
25YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH2
0005FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH20005FUH00`00FUIJEP02000]
Ool0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@0009JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_Ool0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUH0000200000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUHJ00000eYF0000000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH30005FUH01000FUIJEUYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00003P0015YF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF0P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0035oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02moo`00;Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH00UYF200015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3P001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00<7oo000]Ool20004FUH0
0`00FUIJEP03FUH60008Ool90004FUH01000FUIJEP001EYF00<005YFFUH00UYF00@005YFFUH000QJ
EQL000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUHG0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH2000`Ool002eoo`8000AJEP03001JEP0000<001Moo`H0009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000<000=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EP0000<001Qoo`D000IJEP03001JEUYF00AJEP03001JEP0002moo`00;7oo00<005YF000015YF0P00
4goo0`002goo1P0000=JEP00FUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF0P008Goo0P0015YF00<005YFFUH015YF00@005YFFUH002io
o`00;7oo00<005YF00000UYF0P000UYF0P0047oo1@003Woo1@0000=JEP0000000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF10008goo0`0000=JEP00FUH0
15YF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P0000=JEP00FUH00eYF0`003Goo1@0047oo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF100015YF10008Woo0P001EYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YF00000`002Goo1@003Woo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF
5`0015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYFFUH005YF0P001eYF00<005YF00000P008Goo0P000eYF00@005YFFUIJEP8002eoo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH00eYF10001Woo0`003Woo0P001eYF00<005YFFUH015YF1P00
25YF00<005YFFUH01EYF00<005YFFUH015YF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP02FUH2000;
Ool3000COol200000eYF001JEP02FUH2000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@0011oo`<00003FUH005YF00IJEP03001JEUYF00@0009JEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30008Ool5
000DOol20002FUH00`00FUH0000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00AJEQ4000=JEP03001JEUYF00AJEPD00003FUH005YF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEPD00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00D005YFFUIJEP0000IJEP04001JEUYF0007
Ool5000FOol01@00FUH005YF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP0?FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000=JEP800003FUH005YF00EJEP03
001JEUYF00=JEPH000AJEP03001JEUYF00AJEP08001JEUYFFUH005YF001JEP800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH300000eYF001JEP05FUH01000
FUIJEP001goo1@005Woo00D005YF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH03eYF00@005YFFUIJEP8000AJEP06001JEP00001JEP000eYF0P0000=JEP00
FUH01EYF10001EYF00<005YFFUH04@0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00P001EYF00@005YFFUIJEP8000Moo`<001Qoo`80
0003FUH007oo02aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP06
001JEUYF001JEP000eYF0`000eYF00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF
00UJEP03001JEUYF00AJEP<00004FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP80025oo`@002ioo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP07001JEUYF001JEP00FUH00P001UYF
00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00UJEP03001JEUYF009JEP80009J
EP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUH0000OOol20002FUH2000^Ool002io
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH01@00FUIJEP00FUH00P0000=JEP00
FUH015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH02EYF00<005YFFUH0
0P0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000IJEP04001JEUYFFUH400000eYF001oo`0LOol20004FUH2000^Ool002moo`03
001JEP0000EJEP03001JEUYF00AJEP80015JEP03001JEUYF008000=JEP03001JEUYF00=JEP03001J
EUYF009JEP800003FUH005YF00EJEP@000EJEP03001JEUYF00QJEP@00003FUH005YF00=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EUYF00AJEP03001JEUYF00AJEP<001Yoo`<00003FUH005YF00=JEP8002ioo`00<7oo0P001EYF00<0
05YFFUH015YF0P0045YF5P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001EYF
00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00006FUH00`00FUIJEP04FUHP00000eYF001JEP02FUH00`00FUH0000^Ool0
035oo`03001JEUYF00=JEP03001JEUYF00AJEP8000MJEPT000AJEP80009JEP80009JEP03001JEUYF
009JEP07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003FUH005YF00EJ
EP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00005FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP0600000eYF001oo`0]Ool0039oo`8000=JEP03001JEUYF00AJEPT000AJEP03001J
EUYF00IJEP80009JEP03001JEP00008000AJEP07001JEUYFFUH005YF00001UYF00<005YFFUH00eYF
1`001EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000P0000=JEP0000000`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000dOol2
00000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUHG
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo1@000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHH0003FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP8000MJEP03001JEUYF00AJEP@0009JEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUIJEP8000MJEP8000EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP04001JEUYFFUH80007FUH60003FUH20007FUH00`00FUIJEP04FUH20002FUH4
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00MJEP8000IJEP03001JEP0000@000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEPH000=JEP<00003FUH005YF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP80
00AJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPP000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPX0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00008000=JEPL0009JEP<000IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EP0000<00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF00001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF2@00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF1@0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF4`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00eYF40001EYF00<005YFFUH015YF00<005YFFUH00P00;goo000]Ool00`00FUH00003FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF10001EYF00<0
05YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH0035oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPP0009oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
=goo000]Ool01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP00008000Aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000D000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT003moo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFOol01EYF00<005YFFUH0
0UYF0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo6000B7oo
000]Ool20004FUH01000FUIJEUYF5P000goo1P001UYF00<005YFFUH00eYF0P0000Aoo`00FUH000IJ
EP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPH000IJEP03
001JEUYF009JEP03001JEP0000Moo`8000AJEP04001JEP00001DOol002eoo`8000AJEPT001Yoo`@0
009JEP03001JEUYF00=JEP800004Ool005YF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00
FUH00005Ool200000eYF001JEP03FUH01000FUIJEP00E7oo000/Ool00`00FUH00002FUH2000WOol4
0004FUH01P00FUH00000FUH000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000=oo`8000=JEP03001JEUYF
009JEP04001JEUYF001DOol002aoo`03001JEP00008002eoo`<00008FUH005YFFUH005YF001JEP<0
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUH000030006FUH01@00FUIJEUYF00000UYF00<007ooOol0
DWoo000/Ool00`00FUH0000bOol20002FUH01000FUH000000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000AJEP00FUH000MJEP03001JEUYF009JEP03001JEP0005Aoo`00;7oo0P006Woo0`0067oo
00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800004FUH005YF0007FUH00`00FUIJ
EP02FUH2001EOol002aoo`8001Uoo`D001Moo`04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00UYF00<007ooOol0E7oo000/Ool3000HOol5
000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF
00D005YFFUIJEP0005Moo`00;7oo0P0000=JEP0000005Woo1@006Goo0P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00EJEP03001JEP0005Qoo`00;7oo0P000eYF
00<007ooOol057oo0`006Goo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00EJEP8005Uoo`00;Goo00@005YFFUIJEP<002moo`800003FUH005YF00=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00EJEP03001oogoo05Qoo`00;Goo
00D005YFFUIJEP00009JEP8002]oo`800004FUH005YF0004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF000000020005FUH2001KOol002ioo`04001JEUYF0004FUH3000VOol20003FUH20000
0goo00000002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005FUH5001MOol002moo`<000EJEP03
001JEP0000<001ioo`@00003FUH005YF009JEP8000=oo`<000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00
FUIJEP05FUH00`00FUH00002001KOol0035oo`03001JEUYF00=JEP03001JEUYF00=JEPH0019oo`H0
00EJEP05001JEUYFFUH00006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00FGoo000bOol20003FUH00`00FUIJEP05FUH01000FUIJEUYF4P0015YF00<005YFFUH00eYF
00<005YFFUH00P002Goo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF10000UYF1P001EYF00<005YFFUH015YF0`00Egoo000dOol20000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
000>Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP060004FUH500000goo0000000200000eYF001JEP05FUH00`00FUIJEP02001EOol003Ioo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEPP000Yoo`<000AJEP03
001JEUYF009JEP03001oogoo05=oo`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P0077oo2`001UYF00<005YFFUH02UYF00@005YFFUIJEPH000AJEPP0011o
o`<00003FUH005YF00=JEP03001oogoo05=oo`00?Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P00:Woo8@000goo1@004goo0P000eYF0P00EGoo0013OolB000jOol200000eYF001JEP04FUH0
0`00FUIJEP04FUH60005Ool3000FOol200000eYF0000001EOol0095oo`<000AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT0011oo`H00004FUH00000001EOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ0000=JEP04001JEUYFFUH3001EOol009Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EGoo
002JOol400000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2001FOol009ioo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00<005Moo`00Y7oo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005Yoo`00[Goo
4000H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59194 .73798 m .60486 .68261 L .57449 .6745 L p .707 .577 .707 r
F P
0 g
s
.60486 .68261 m .59194 .73798 L .62297 .74451 L p .707 .577 .707 r
F P
0 g
s
.62297 .74451 m .63589 .68913 L .60486 .68261 L p .707 .577 .707 r
F P
0 g
s
.63589 .68913 m .62297 .74451 L .65162 .74881 L p .707 .577 .707 r
F P
0 g
s
.65162 .74881 m .66454 .69343 L .63589 .68913 L p .707 .577 .707 r
F P
0 g
s
.56156 .72987 m .57449 .6745 L .54774 .66559 L p .707 .577 .707 r
F P
0 g
s
.57449 .6745 m .56156 .72987 L .59194 .73798 L p .707 .577 .707 r
F P
0 g
s
.54774 .66559 m .53482 .72097 L .56156 .72987 L p .707 .577 .707 r
F P
0 g
s
.66454 .69343 m .65162 .74881 L .67508 .75046 L p .707 .577 .707 r
F P
0 g
s
.67508 .75046 m .688 .69508 L .66454 .69343 L p .707 .577 .707 r
F P
0 g
s
.53482 .72097 m .54774 .66559 L .52724 .65677 L p .707 .577 .707 r
F P
0 g
s
.6319 .81338 m .61939 .78005 L .58924 .79049 L p .707 .577 .707 r
F P
0 g
s
.61939 .78005 m .6319 .81338 L .65989 .79973 L p .707 .577 .707 r
F P
0 g
s
.65989 .79973 m .64738 .76639 L .61939 .78005 L p .707 .577 .707 r
F P
0 g
s
.60175 .82382 m .58924 .79049 L .55989 .79669 L p .707 .577 .707 r
F P
0 g
s
.58924 .79049 m .60175 .82382 L .6319 .81338 L p .707 .577 .707 r
F P
0 g
s
.64738 .76639 m .65989 .79973 L .68298 .7842 L p .707 .577 .707 r
F P
0 g
s
.68298 .7842 m .67047 .75086 L .64738 .76639 L p .707 .577 .707 r
F P
0 g
s
.52724 .65677 m .51432 .71215 L .53482 .72097 L p .707 .577 .707 r
F P
0 g
s
.59139 .84379 m .59368 .83066 L p .56389 .81866 L .707 .577 .707 r
F P
0 g
s
.5853 .82322 m .56389 .81866 L p .59368 .83066 L .707 .577 .707 r
F P
0 g
s
.56389 .81866 m .56065 .83725 L .59139 .84379 L p .707 .577 .707 r
F P
0 g
s
.56065 .83725 m .56237 .82737 L p .5368 .8109 L .707 .577 .707 r
F P
0 g
s
.56237 .82737 m .56389 .81866 L .54945 .81453 L p .707 .577 .707 r
F P
0 g
s
.54945 .81453 m .5368 .8109 L p .56237 .82737 L .707 .577 .707 r
F P
0 g
s
.5368 .8109 m .53356 .82948 L .56065 .83725 L p .707 .577 .707 r
F P
0 g
s
.53356 .82948 m .5368 .8109 L .51601 .80267 L p .707 .577 .707 r
F P
0 g
s
.54672 .83139 m .53498 .80014 L p .5147 .79444 L .707 .577 .707 r
F P
0 g
s
.53498 .80014 m .5342 .79806 L .53258 .79776 L p .707 .577 .707 r
F P
0 g
s
.53258 .79776 m .5147 .79444 L p .53498 .80014 L .707 .577 .707 r
F P
0 g
s
.5724 .83003 m .56213 .80267 L p .5342 .79806 L .707 .577 .707 r
F P
0 g
s
.56213 .80267 m .55989 .79669 L .55564 .79692 L p .707 .577 .707 r
F P
0 g
s
.55564 .79692 m .5342 .79806 L p .56213 .80267 L .707 .577 .707 r
F P
0 g
s
.59368 .83066 m .59463 .82521 L .5853 .82322 L p .707 .577 .707 r
F P
0 g
s
.59463 .82521 m .59139 .84379 L .62276 .84847 L p .707 .577 .707 r
F P
0 g
s
.62276 .84847 m .62601 .82989 L .59463 .82521 L p .707 .577 .707 r
F P
0 g
s
.55989 .79669 m .5724 .83003 L .60175 .82382 L p .707 .577 .707 r
F P
0 g
s
.62601 .82989 m .62276 .84847 L .65171 .85083 L p .707 .577 .707 r
F P
0 g
s
.65171 .85083 m .65495 .83224 L .62601 .82989 L p .707 .577 .707 r
F P
0 g
s
.688 .69508 m .67508 .75046 L .68325 .74987 L p .707 .577 .707 r
F P
0 g
s
.69082 .74507 m .688 .69508 L .68406 .74058 L .707 .577 .707 r
F
.69031 .74539 m .68406 .74058 L .68325 .74987 L F
.69082 .74507 m .68406 .74058 L .69031 .74539 L F
.69892 .76832 m .70474 .75648 L p .69172 .74647 L F P
0 g
s
.69031 .74539 m .69105 .74735 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69105 .74735 m .69892 .76832 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69898 .7369 m .69915 .7355 L .69172 .74647 L .707 .577 .707 r
F
.70398 .69393 m .69553 .73015 L p .69915 .7355 L F P
0 g
s
.69553 .73015 m .69172 .74647 L p .69915 .7355 L .707 .577 .707 r
F P
0 g
s
.69892 .76832 m .69031 .74539 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69106 .74931 m .70398 .69393 L .688 .69508 L p .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .70419 .74296 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .70016 .7377 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.70016 .7377 m .70614 .75363 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69362 .72029 m .68641 .73498 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .69957 .73613 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.69985 .73576 m .69943 .73309 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .69362 .72029 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69985 .73576 L p .69799 .74546 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .69985 .73576 L .69898 .7369 L .707 .577 .707 r
F
.70071 .72202 m .71091 .69009 L .70398 .69393 L p F P
0 g
s
.69362 .72029 m .69681 .72877 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69681 .72877 m .69957 .73613 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69868 .72838 m .69947 .72593 L .70001 .73679 L .707 .577 .707 r
F
.70358 .72151 m .70001 .73679 L p .69947 .72593 L F P
0 g
s
.70812 .68392 m .71091 .69009 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.69999 .73666 m .69742 .72812 L .69957 .73613 L .707 .577 .707 r
F
.69924 .73188 m .69742 .72812 L .69999 .73666 L F
.6983 .72599 m .70812 .68392 L p .69868 .72838 L F P
0 g
s
.69142 .70824 m .69362 .72029 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .699 .72843 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .69142 .70824 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.69142 .70824 m .69846 .72701 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.6952 .7393 m .68295 .73142 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69457 .7249 L .6952 .7393 L .707 .577 .707 r
F
.69206 .7229 m .69142 .70824 L .69793 .72758 L F
.69793 .72758 m .6952 .7393 L p .69457 .7249 L F P
0 g
s
.69255 .73336 m .69252 .73334 L p .69846 .72701 L .707 .577 .707 r
F P
0 g
s
.6983 .72599 m .69793 .72758 L p .69394 .71068 L .707 .577 .707 r
F P
0 g
s
.69394 .71068 m .69793 .72758 L .69457 .7249 L .707 .577 .707 r
F
.6952 .7393 m .6983 .72599 L p .69868 .72838 L F P
0 g
s
.70394 .74158 m .69924 .73188 L .69999 .73666 L .707 .577 .707 r
F
.68325 .74987 m .69106 .74931 L p .69086 .74581 L F P
0 g
s
.69086 .74581 m .69082 .74507 L .69031 .74539 L .707 .577 .707 r
F
.69086 .74581 m .69031 .74539 L .68325 .74987 L F
.68641 .73498 m .69031 .74539 L p .69191 .74622 L F P
0 g
s
.70614 .75363 m .69458 .7427 L .69191 .74622 L .707 .577 .707 r
F
.69458 .7427 m .68641 .73498 L .69191 .74622 L F
.70474 .75648 m .70614 .75363 L p .69031 .74539 L F P
0 g
s
.69106 .74931 m .69799 .74546 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69172 .74647 m .69106 .74931 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .6952 .7393 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70419 .74296 m .70394 .74158 L p .69957 .73613 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69799 .74546 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .69255 .73336 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69846 .72701 m .699 .72843 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .70394 .74158 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .69206 .7229 L .69793 .72758 L .707 .577 .707 r
F
.68001 .7 m .69142 .70824 L p .69206 .7229 L F P
0 g
s
.68295 .73142 m .68569 .71969 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68001 .7 m .68713 .71897 L p .68569 .71969 L .707 .577 .707 r
F P
0 g
s
.68295 .73142 m .66246 .7226 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68295 .73142 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.67401 .72551 m .67619 .71625 L .68569 .71969 L .707 .577 .707 r
F
.67619 .71625 m .68001 .7 L .68569 .71969 L F
.68713 .71897 m .68001 .7 L p .69206 .7229 L F P
0 g
s
.6605 .69639 m .68001 .7 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .66449 .71388 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.6605 .69639 m .66667 .71281 L p .66449 .71388 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .63571 .7137 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66246 .7226 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.65143 .72031 m .65458 .71201 L .66449 .71388 L .707 .577 .707 r
F
.65458 .71201 m .6605 .69639 L .66449 .71388 L F
.66667 .71281 m .6605 .69639 L p .67619 .71625 L F P
0 g
s
.63482 .69776 m .6605 .69639 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.63571 .7137 m .63639 .71079 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63482 .69776 m .63907 .70908 L p .63639 .71079 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63571 .7137 L .61845 .70909 L p .707 .577 .707 r
F P
0 g
s
.62661 .71703 m .62954 .71014 L .63639 .71079 L .707 .577 .707 r
F
.62954 .71014 m .63482 .69776 L .63639 .71079 L F
.63907 .70908 m .63482 .69776 L p .65458 .71201 L F P
0 g
s
.60547 .70396 m .63482 .69776 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .60825 .71137 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.60825 .71137 m .60547 .70396 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .58783 .74774 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60547 .70396 m .60698 .708 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60698 .708 m .61798 .7373 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .64681 .66611 L p .60534 .70559 L .707 .577 .707 r
F P
0 g
s
.64681 .66611 m .63639 .71079 L p .60873 .70616 L .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .64681 .66611 L .60873 .70616 L .707 .577 .707 r
F
.58783 .74774 m .57532 .7144 L .60547 .70396 L p F P
0 g
s
.61826 .65021 m .60534 .70559 L .60204 .7049 L p .707 .577 .707 r
F P
0 g
s
.60204 .7049 m .57431 .69906 L p .58503 .68714 L .707 .577 .707 r
F P
0 g
s
.58503 .68714 m .61826 .65021 L .60204 .7049 L .707 .577 .707 r
F
.61845 .70909 m .60534 .70559 L p .63639 .71079 L F P
0 g
s
.63639 .71079 m .63688 .70867 L p .63907 .70908 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63907 .70908 L .63957 .70918 L .707 .577 .707 r
F
.64733 .7311 m .61798 .7373 L p .62661 .71703 L F P
0 g
s
.63907 .70908 m .64733 .7311 L p .62661 .71703 L .707 .577 .707 r
F P
0 g
s
.64733 .7311 m .63907 .70908 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .67538 .66722 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63688 .70867 m .64863 .65832 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .66449 .71388 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66489 .71217 L p .66667 .71281 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66667 .71281 L .6689 .71362 L .707 .577 .707 r
F
.67302 .72973 m .64733 .7311 L p .65143 .72031 L F P
0 g
s
.66667 .71281 m .67302 .72973 L p .65143 .72031 L .707 .577 .707 r
F P
0 g
s
.67302 .72973 m .66667 .71281 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .69588 .67604 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.66489 .71217 m .67538 .66722 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .68569 .71969 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68606 .71812 L p .68713 .71897 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68713 .71897 L .68883 .72033 L .707 .577 .707 r
F
.69252 .73334 m .67302 .72973 L p .67401 .72551 L F P
0 g
s
.68713 .71897 m .69252 .73334 L p .67401 .72551 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .68713 .71897 L p .69206 .7229 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .70812 .68392 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68606 .71812 m .69588 .67604 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69394 .71068 L .69457 .7249 L .707 .577 .707 r
F
.70812 .68392 m .6983 .72599 L p .69394 .71068 L F P
0 g
s
.71091 .69009 m .70358 .72151 L p .69947 .72593 L .707 .577 .707 r
F P
0 g
s
.68641 .73498 m .67047 .75086 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69031 .74539 m .68641 .73498 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.51432 .71215 m .52724 .65677 L .515 .64889 L p .707 .577 .707 r
F P
0 g
s
.67047 .75086 m .68298 .7842 L .69892 .76832 L p .707 .577 .707 r
F P
0 g
s
.5342 .79806 m .54672 .83139 L .5724 .83003 L p .707 .577 .707 r
F P
0 g
s
.65495 .83224 m .65171 .85083 L .67538 .85063 L p .707 .577 .707 r
F P
0 g
s
.67538 .85063 m .67862 .83205 L .65495 .83224 L p .707 .577 .707 r
F P
0 g
s
.515 .64889 m .50208 .70427 L .51432 .71215 L p .707 .577 .707 r
F P
0 g
s
.51601 .80267 m .51277 .82125 L .53356 .82948 L p .707 .577 .707 r
F P
0 g
s
.5147 .79444 m .52721 .82778 L .54672 .83139 L p .707 .577 .707 r
F P
0 g
s
.50208 .70427 m .515 .64889 L .51221 .64273 L p .707 .577 .707 r
F P
0 g
s
.67862 .83205 m .67538 .85063 L .69147 .84791 L p .707 .577 .707 r
F P
0 g
s
.69147 .84791 m .69472 .82932 L .67862 .83205 L p .707 .577 .707 r
F P
0 g
s
.51277 .82125 m .51601 .80267 L .50356 .79478 L p .707 .577 .707 r
F P
0 g
s
.52721 .82778 m .5147 .79444 L .50328 .78621 L p .707 .577 .707 r
F P
0 g
s
.51221 .64273 m .49929 .69811 L .50208 .70427 L p .707 .577 .707 r
F P
0 g
s
.50356 .79478 m .50031 .81337 L .51277 .82125 L p .707 .577 .707 r
F P
0 g
s
.50328 .78621 m .5158 .81955 L .52721 .82778 L p .707 .577 .707 r
F P
0 g
s
.49323 .82188 m .49323 .31999 L .44904 .31754 L p .707 .577 .707 r
F P
0 g
s
.49929 .69811 m .51221 .64273 L .51914 .63888 L p .707 .577 .707 r
F P
0 g
s
.50031 .81337 m .50356 .79478 L .50065 .78801 L p .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50328 .78621 L .50162 .7771 L p .707 .577 .707 r
F P
0 g
s
.50162 .7771 m .50108 .77416 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50162 .7771 L .50245 .77838 L .707 .577 .707 r
F
.50065 .78801 m .49741 .8066 L .50031 .81337 L p F P
0 g
s
.5136 .8075 m .5158 .81955 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50108 .77416 m .50296 .77918 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50296 .77918 m .5136 .8075 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5136 .8075 m .50108 .77416 L .5083 .75947 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .49741 .8066 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50759 .78302 m .50713 .78562 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50713 .78562 m .50434 .8016 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50065 .78801 L .50613 .78407 L p .707 .577 .707 r
F P
0 g
s
.50613 .78407 m .50759 .78302 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50613 .78407 L .50673 .785 L .707 .577 .707 r
F
.51914 .63888 m .50622 .69426 L .49929 .69811 L p F P
0 g
s
.50622 .69426 m .51914 .63888 L .53512 .63773 L p .707 .577 .707 r
F P
0 g
s
.53512 .63773 m .5222 .69311 L .50622 .69426 L p .707 .577 .707 r
F P
0 g
s
.5083 .75947 m .52081 .79281 L .5136 .8075 L p .707 .577 .707 r
F P
0 g
s
.5222 .69311 m .53512 .63773 L .55858 .63939 L p .707 .577 .707 r
F P
0 g
s
.52081 .79281 m .5083 .75947 L .52423 .74359 L p .707 .577 .707 r
F P
0 g
s
.52423 .74359 m .53675 .77693 L .52081 .79281 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .50759 .78302 L .52368 .78029 L p .707 .577 .707 r
F P
0 g
s
.55858 .63939 m .54566 .69476 L .5222 .69311 L p .707 .577 .707 r
F P
0 g
s
.52368 .78029 m .52044 .79887 L .50434 .8016 L p .707 .577 .707 r
F P
0 g
s
.53675 .77693 m .52423 .74359 L .54733 .72806 L p .707 .577 .707 r
F P
0 g
s
.52044 .79887 m .52368 .78029 L .54735 .78009 L p .707 .577 .707 r
F P
0 g
s
.54735 .78009 m .54411 .79868 L .52044 .79887 L p .707 .577 .707 r
F P
0 g
s
.49323 .31999 m .49323 .82188 L .53809 .82055 L p .707 .577 .707 r
F P
0 g
s
.54733 .72806 m .55984 .7614 L .53675 .77693 L p .707 .577 .707 r
F P
0 g
s
.53809 .82055 m .53809 .31866 L .49323 .31999 L p .707 .577 .707 r
F P
0 g
s
.69472 .82932 m .69147 .84791 L .69841 .84291 L p .707 .577 .707 r
F P
0 g
s
.69841 .84291 m .70165 .82433 L .69472 .82932 L p .707 .577 .707 r
F P
0 g
s
.54566 .69476 m .55858 .63939 L .58723 .64369 L p .707 .577 .707 r
F P
0 g
s
.58723 .64369 m .57431 .69906 L .54566 .69476 L p .707 .577 .707 r
F P
0 g
s
.55984 .7614 m .54733 .72806 L .57532 .7144 L p .707 .577 .707 r
F P
0 g
s
.57532 .7144 m .58783 .74774 L .55984 .7614 L p .707 .577 .707 r
F P
0 g
s
.54411 .79868 m .54735 .78009 L .5763 .78245 L p .707 .577 .707 r
F P
0 g
s
.5763 .78245 m .57305 .80104 L .54411 .79868 L p .707 .577 .707 r
F P
0 g
s
.57305 .80104 m .5763 .78245 L .60767 .78713 L p .707 .577 .707 r
F P
0 g
s
.60767 .78713 m .60443 .80572 L .57305 .80104 L p .707 .577 .707 r
F P
0 g
s
.53809 .31866 m .53809 .82055 L .57922 .81556 L p .707 .577 .707 r
F P
0 g
s
.57431 .69906 m .58723 .64369 L .61826 .65021 L p .707 .577 .707 r
F P
0 g
s
.57922 .81556 m .57922 .31368 L .53809 .31866 L p .707 .577 .707 r
F P
0 g
s
.44904 .81943 m .44904 .31754 L .40983 .31154 L p .707 .577 .707 r
F P
0 g
s
.44904 .31754 m .44904 .81943 L .49323 .82188 L p .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .61826 .65021 L .64863 .65832 L p .707 .577 .707 r
F P
0 g
s
.63841 .79367 m .63517 .81226 L .60443 .80572 L p .707 .577 .707 r
F P
0 g
s
.60443 .80572 m .60767 .78713 L .63841 .79367 L p .707 .577 .707 r
F P
0 g
s
.57922 .31368 m .57922 .81556 L .61259 .80741 L p .707 .577 .707 r
F P
0 g
s
.61259 .80741 m .61259 .30552 L .57922 .31368 L p .707 .577 .707 r
F P
0 g
s
.40983 .81343 m .40983 .31154 L .37945 .30259 L p .707 .577 .707 r
F P
0 g
s
.40983 .31154 m .40983 .81343 L .44904 .81943 L p .707 .577 .707 r
F P
0 g
s
.25765 .68094 m .22657 .675 L p .2463 .71874 L .707 .577 .707 r
F P
0 g
s
.24811 .72276 m .24871 .72012 L .2463 .71874 L .707 .577 .707 r
F
.24871 .72012 m .25765 .68094 L .2463 .71874 L F
.25297 .72295 m .25765 .68094 L p .24811 .72276 L F P
0 g
s
.28785 .7367 m .27163 .72196 L .25372 .72298 L .707 .577 .707 r
F
.25372 .72298 m .25634 .74107 L .27967 .73783 L p F P
0 g
s
.27967 .73783 m .28785 .7367 L p .25372 .72298 L .707 .577 .707 r
F P
0 g
s
.25634 .74107 m .25372 .72298 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.24284 .72879 m .25297 .72295 L .23567 .72226 L .707 .577 .707 r
F
.25634 .74107 m .25297 .72295 L .24284 .72879 L F
.25366 .72256 m .25372 .72298 L p .27163 .72196 L F P
0 g
s
.25301 .72258 m .25297 .72295 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .25634 .74107 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .22549 .74597 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22657 .675 m .19913 .66493 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .22205 .72225 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22197 .72171 L p .22132 .72216 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22132 .72216 L .20984 .73015 L .707 .577 .707 r
F
.19913 .66493 m .1935 .71543 L .20683 .72031 L p F P
0 g
s
.20984 .73015 m .21392 .72122 L .19914 .71933 L .707 .577 .707 r
F
.21967 .72195 m .19913 .66493 L .20683 .72031 L F
.22132 .72216 m .22657 .675 L p .21967 .72195 L F P
0 g
s
.22657 .675 m .22137 .72169 L p .22197 .72171 L .707 .577 .707 r
F P
0 g
s
.22137 .72169 m .22095 .72549 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .21997 .70797 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.20683 .72031 m .22095 .72549 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22095 .72549 m .22132 .72216 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.1935 .71543 m .19913 .66493 L .178 .65173 L p .707 .577 .707 r
F P
0 g
s
.178 .65173 m .17398 .6878 L p .1935 .71543 L .707 .577 .707 r
F P
0 g
s
.17398 .6878 m .17237 .70222 L .18972 .71306 L p .707 .577 .707 r
F P
0 g
s
.18972 .71306 m .1935 .71543 L p .17398 .6878 L .707 .577 .707 r
F P
0 g
s
.19278 .7129 m .19374 .71952 L p .22549 .74597 L .707 .577 .707 r
F P
0 g
s
.19374 .71952 m .1983 .7509 L .21178 .74845 L p .707 .577 .707 r
F P
0 g
s
.21178 .74845 m .22549 .74597 L p .19374 .71952 L .707 .577 .707 r
F P
0 g
s
.21997 .70797 m .19278 .7129 L p .19914 .71933 L .707 .577 .707 r
F P
0 g
s
.21392 .72122 m .21997 .70797 L .19914 .71933 L .707 .577 .707 r
F
.24811 .72276 m .24151 .70811 L .22197 .72171 L F
.24151 .70811 m .22657 .675 L .22197 .72171 L F
.22095 .72549 m .25202 .73143 L p .24811 .72276 L F P
0 g
s
.21997 .70797 m .22197 .72171 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25297 .72295 m .25083 .70308 L .23567 .72226 L .707 .577 .707 r
F
.25372 .72298 m .25366 .72256 L p .25297 .72295 L F P
0 g
s
.25765 .68094 m .25301 .72258 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.25366 .72256 m .25083 .70308 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .27299 .71142 L .25366 .72256 L .707 .577 .707 r
F
.27299 .71142 m .25765 .68094 L .25366 .72256 L F
.28931 .68217 m .25765 .68094 L p .27574 .71689 L F P
0 g
s
.27819 .72175 m .27911 .71846 L .27574 .71689 L .707 .577 .707 r
F
.27911 .71846 m .28931 .68217 L .27574 .71689 L F
.28493 .72153 m .28931 .68217 L p .27819 .72175 L F P
0 g
s
.31692 .73326 m .30287 .71923 L .28564 .7215 L .707 .577 .707 r
F
.28564 .7215 m .28785 .7367 L .3121 .73383 L p F P
0 g
s
.3121 .73383 m .31692 .73326 L p .28564 .7215 L .707 .577 .707 r
F P
0 g
s
.28785 .7367 m .28564 .7215 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.27672 .72659 m .28493 .72153 L .27163 .72196 L .707 .577 .707 r
F
.28785 .7367 m .28493 .72153 L .27672 .72659 L F
.28559 .72112 m .28564 .7215 L p .30287 .71923 L F P
0 g
s
.28496 .72119 m .28493 .72153 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28493 .72153 m .28233 .6987 L .27163 .72196 L .707 .577 .707 r
F
.28564 .7215 m .28559 .72112 L p .28493 .72153 L F P
0 g
s
.28931 .68217 m .28496 .72119 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28559 .72112 m .28233 .6987 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.30763 .7187 m .30334 .71015 L .28559 .72112 L .707 .577 .707 r
F
.30334 .71015 m .28931 .68217 L .28559 .72112 L F
.31846 .67859 m .28931 .68217 L p .30763 .7187 L F P
0 g
s
.3114 .69527 m .28233 .6987 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31469 .71793 L p .31407 .718 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31407 .718 L .30718 .72353 L .707 .577 .707 r
F
.31692 .73326 m .3407 .73111 L p .32741 .71485 L F P
0 g
s
.33344 .71358 m .3299 .70531 L .32227 .71594 L .707 .577 .707 r
F
.31846 .67859 m .31411 .71766 L p .3299 .70531 L F P
0 g
s
.31411 .71766 m .31407 .718 L p .31463 .71755 L .707 .577 .707 r
F P
0 g
s
.3299 .70531 m .31411 .71766 L .31463 .71755 L .707 .577 .707 r
F
.31463 .71755 m .31692 .73326 L p .32741 .71485 L F P
0 g
s
.31407 .718 m .31846 .67859 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.31469 .71793 m .3114 .69527 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31407 .718 m .31283 .72908 L p .3299 .70531 L .707 .577 .707 r
F P
0 g
s
.3407 .73111 m .33802 .71262 L p .33754 .71272 L .707 .577 .707 r
F P
0 g
s
.33176 .72017 m .33754 .71272 L .32741 .71485 L .707 .577 .707 r
F
.3407 .73111 m .33754 .71272 L .33176 .72017 L F
.3407 .73111 m .35687 .73045 L p .34471 .70951 L F P
0 g
s
.352 .70662 m .34949 .69733 L .34236 .71044 L .707 .577 .707 r
F
.34224 .67052 m .33759 .71234 L p .34949 .69733 L F P
0 g
s
.33759 .71234 m .33754 .71272 L p .33795 .71219 L .707 .577 .707 r
F P
0 g
s
.34949 .69733 m .33759 .71234 L .33795 .71219 L .707 .577 .707 r
F
.33795 .71219 m .3407 .73111 L p .34471 .70951 L F P
0 g
s
.34224 .67052 m .31846 .67859 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .33754 .71272 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .34224 .67052 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33802 .71262 m .33518 .69311 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .33662 .72101 L p .34949 .69733 L .707 .577 .707 r
F P
0 g
s
.35687 .73045 m .35334 .70609 L p .35305 .70621 L .707 .577 .707 r
F P
0 g
s
.34944 .71766 m .35305 .70621 L .34471 .70951 L .707 .577 .707 r
F
.35687 .73045 m .35305 .70621 L .34944 .71766 L F
.35687 .73045 m .36386 .73135 L p .35496 .70367 L F P
0 g
s
.35953 .69498 m .35925 .68651 L .35402 .7047 L .707 .577 .707 r
F
.35585 .70268 m .35953 .69498 L p .35402 .7047 L F P
0 g
s
.35833 .65877 m .35311 .70571 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35311 .70571 m .35305 .70621 L p .35326 .70555 L .707 .577 .707 r
F P
0 g
s
.35925 .68651 m .35311 .70571 L .35326 .70555 L .707 .577 .707 r
F
.35326 .70555 m .35687 .73045 L p .35496 .70367 L F P
0 g
s
.35833 .65877 m .34224 .67052 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35305 .70621 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35833 .65877 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35334 .70609 m .35136 .69245 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35271 .70927 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .35136 .69245 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.36386 .73135 m .35916 .69903 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35916 .69903 m .35834 .69335 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .35326 .70555 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35585 .70268 L p .35402 .7047 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .33518 .69311 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33518 .69311 m .33795 .71219 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .35271 .70927 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.352 .70662 m .34236 .71044 L .33662 .72101 L .707 .577 .707 r
F
.33518 .69311 m .3114 .69527 L p .32741 .71485 L F P
0 g
s
.3114 .69527 m .31463 .71755 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.31283 .72908 m .33662 .72101 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33344 .71358 m .32227 .71594 L .31283 .72908 L .707 .577 .707 r
F
.30718 .72353 m .31407 .718 L .30287 .71923 L F
.31283 .72908 m .31407 .718 L p .30763 .7187 L F P
0 g
s
.30763 .7187 m .28559 .72112 L .28369 .73267 L .707 .577 .707 r
F
.28493 .72153 m .28369 .73267 L p .28559 .72112 L F P
0 g
s
.28369 .73267 m .31283 .72908 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .28559 .72112 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .25083 .70308 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.28369 .73267 m .28493 .72153 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .25366 .72256 L .25202 .73143 L .707 .577 .707 r
F
.25297 .72295 m .25202 .73143 L p .25366 .72256 L F P
0 g
s
.25202 .73143 m .28369 .73267 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .25366 .72256 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .21997 .70797 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25202 .73143 m .25297 .72295 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.70165 .82433 m .69841 .84291 L .6955 .83614 L p .707 .577 .707 r
F P
0 g
s
.6955 .83614 m .69875 .81755 L .70165 .82433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.61259 .30552 m .61259 .80741 L .63494 .79689 L p .707 .577 .707 r
F P
0 g
s
.63494 .79689 m .63494 .295 L .61259 .30552 L p .707 .577 .707 r
F P
0 g
s
.37945 .80447 m .37945 .30259 L .36087 .29155 L p .707 .577 .707 r
F P
0 g
s
.37945 .30259 m .37945 .80447 L .40983 .81343 L p .707 .577 .707 r
F P
0 g
s
.69875 .81755 m .6955 .83614 L .68305 .82825 L p .707 .577 .707 r
F P
0 g
s
.68305 .82825 m .68629 .80967 L .69875 .81755 L p .707 .577 .707 r
F P
0 g
s
.17237 .70222 m .178 .65173 L .16525 .63668 L p .707 .577 .707 r
F P
0 g
s
.17192 .71739 m .17744 .75538 L .1983 .7509 L p .707 .577 .707 r
F P
0 g
s
.1983 .7509 m .19278 .7129 L .17192 .71739 L p .707 .577 .707 r
F P
0 g
s
.25162 .82909 m .25302 .81173 L .22189 .80674 L p .707 .577 .707 r
F P
0 g
s
.25302 .81173 m .25162 .82909 L .28335 .82987 L p .707 .577 .707 r
F P
0 g
s
.28335 .82987 m .28476 .81252 L .25302 .81173 L p .707 .577 .707 r
F P
0 g
s
.28476 .81252 m .28335 .82987 L .31258 .82636 L p .707 .577 .707 r
F P
0 g
s
.31258 .82636 m .31398 .80901 L .28476 .81252 L p .707 .577 .707 r
F P
0 g
s
.22049 .82409 m .22189 .80674 L .19441 .79802 L p .707 .577 .707 r
F P
0 g
s
.22189 .80674 m .22049 .82409 L .25162 .82909 L p .707 .577 .707 r
F P
0 g
s
.63494 .295 m .63494 .79689 L .64409 .78503 L p .707 .577 .707 r
F P
0 g
s
.64409 .78503 m .64409 .28314 L .63494 .295 L p .707 .577 .707 r
F P
0 g
s
.19441 .79802 m .193 .81537 L .22049 .82409 L p .707 .577 .707 r
F P
0 g
s
.68629 .80967 m .68305 .82825 L .66226 .82002 L p .707 .577 .707 r
F P
0 g
s
.66226 .82002 m .6655 .80144 L .68629 .80967 L p .707 .577 .707 r
F P
0 g
s
.35953 .69498 m .36516 .64449 L .35833 .65877 L p .707 .577 .707 r
F P
0 g
s
.31398 .80901 m .31258 .82636 L .33644 .8189 L p .707 .577 .707 r
F P
0 g
s
.33644 .8189 m .33784 .80155 L .31398 .80901 L p .707 .577 .707 r
F P
0 g
s
.15963 .68718 m .16525 .63668 L .16214 .62126 L p .707 .577 .707 r
F P
0 g
s
.16525 .63668 m .15963 .68718 L .17237 .70222 L p .707 .577 .707 r
F P
0 g
s
.193 .81537 m .19441 .79802 L .17326 .78642 L p .707 .577 .707 r
F P
0 g
s
.15943 .72099 m .16495 .75899 L .17744 .75538 L p .707 .577 .707 r
F P
0 g
s
.17744 .75538 m .17192 .71739 L .15943 .72099 L p .707 .577 .707 r
F P
0 g
s
.36516 .64449 m .35953 .69498 L .35642 .67956 L p .707 .577 .707 r
F P
0 g
s
.35642 .67956 m .36204 .62907 L .36516 .64449 L p .707 .577 .707 r
F P
0 g
s
.35946 .79538 m .36087 .77802 L .35399 .79087 L p .707 .577 .707 r
F P
0 g
s
.36204 .62907 m .35642 .67956 L .34367 .66451 L p .707 .577 .707 r
F P
0 g
s
.34367 .66451 m .3493 .61402 L .36204 .62907 L p .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .36386 .73135 L .36096 .73371 L p .707 .577 .707 r
F P
0 g
s
.36096 .73371 m .35544 .69571 L .35834 .69335 L p .707 .577 .707 r
F P
0 g
s
.36087 .77802 m .35946 .79538 L .35638 .78161 L p .707 .577 .707 r
F P
0 g
s
.35638 .78161 m .35778 .76426 L .36087 .77802 L p .707 .577 .707 r
F P
0 g
s
.35544 .69571 m .36096 .73371 L .34847 .73731 L p .707 .577 .707 r
F P
0 g
s
.36087 .79344 m .36087 .29155 L .35591 .27951 L p .707 .577 .707 r
F P
0 g
s
.36087 .29155 m .36087 .79344 L .37945 .80447 L p .707 .577 .707 r
F P
0 g
s
.17326 .78642 m .17185 .80378 L .193 .81537 L p .707 .577 .707 r
F P
0 g
s
.33784 .80155 m .33644 .8189 L .35259 .80823 L p .707 .577 .707 r
F P
0 g
s
.35259 .80823 m .35399 .79087 L .33784 .80155 L p .707 .577 .707 r
F P
0 g
s
.6655 .80144 m .66226 .82002 L .63517 .81226 L p .707 .577 .707 r
F P
0 g
s
.63517 .81226 m .63841 .79367 L .6655 .80144 L p .707 .577 .707 r
F P
0 g
s
.17185 .80378 m .17326 .78642 L .16052 .77309 L p .707 .577 .707 r
F P
0 g
s
.16214 .62126 m .15651 .67176 L .15963 .68718 L p .707 .577 .707 r
F P
0 g
s
.15651 .67176 m .16214 .62126 L .16896 .60698 L p .707 .577 .707 r
F P
0 g
s
.16052 .77309 m .15911 .79045 L .17185 .80378 L p .707 .577 .707 r
F P
0 g
s
.15654 .72335 m .16205 .76135 L .16495 .75899 L p .707 .577 .707 r
F P
0 g
s
.16495 .75899 m .15943 .72099 L .15654 .72335 L p .707 .577 .707 r
F P
0 g
s
.64409 .28314 m .64409 .78503 L .63912 .773 L p .707 .577 .707 r
F P
0 g
s
.63912 .773 m .63912 .27111 L .64409 .28314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35399 .79087 m .35259 .80823 L .35946 .79538 L p .707 .577 .707 r
F P
0 g
s
.15911 .79045 m .16052 .77309 L .15743 .75933 L p .707 .577 .707 r
F P
0 g
s
.35778 .76426 m .35638 .78161 L .34364 .76828 L p .707 .577 .707 r
F P
0 g
s
.34364 .76828 m .34504 .75093 L .35778 .76426 L p .707 .577 .707 r
F P
0 g
s
.35591 .27951 m .35591 .7814 L .36087 .79344 L p .707 .577 .707 r
F P
0 g
s
.35591 .7814 m .35591 .27951 L .36505 .26766 L p .707 .577 .707 r
F P
0 g
s
.16896 .60698 m .16333 .65747 L .15651 .67176 L p .707 .577 .707 r
F P
0 g
s
.16333 .65747 m .16896 .60698 L .18505 .59523 L p .707 .577 .707 r
F P
0 g
s
.15743 .75933 m .15603 .77668 L .15911 .79045 L p .707 .577 .707 r
F P
0 g
s
.16352 .72425 m .16903 .76225 L .16205 .76135 L p .707 .577 .707 r
F P
0 g
s
.16205 .76135 m .15654 .72335 L .16352 .72425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15603 .77668 m .15743 .75933 L .1643 .74648 L p .707 .577 .707 r
F P
0 g
s
.3493 .61402 m .34367 .66451 L .32254 .65131 L p .707 .577 .707 r
F P
0 g
s
.32254 .65131 m .32817 .60082 L .3493 .61402 L p .707 .577 .707 r
F P
0 g
s
.18505 .59523 m .17942 .64572 L .16333 .65747 L p .707 .577 .707 r
F P
0 g
s
.17942 .64572 m .18505 .59523 L .20883 .58717 L p .707 .577 .707 r
F P
0 g
s
.63912 .27111 m .63912 .773 L .62054 .76196 L p .707 .577 .707 r
F P
0 g
s
.62054 .76196 m .62054 .26007 L .63912 .27111 L p .707 .577 .707 r
F P
0 g
s
.1643 .74648 m .1629 .76383 L .15603 .77668 L p .707 .577 .707 r
F P
0 g
s
.34847 .73731 m .34295 .69932 L .35544 .69571 L p .707 .577 .707 r
F P
0 g
s
.36505 .76954 m .36505 .26766 L .38741 .25714 L p .707 .577 .707 r
F P
0 g
s
.36505 .26766 m .36505 .76954 L .35591 .7814 L p .707 .577 .707 r
F P
0 g
s
.17969 .72359 m .18521 .76159 L .16903 .76225 L p .707 .577 .707 r
F P
0 g
s
.16903 .76225 m .16352 .72425 L .17969 .72359 L p .707 .577 .707 r
F P
0 g
s
.32817 .60082 m .32254 .65131 L .2951 .64125 L p .707 .577 .707 r
F P
0 g
s
.2951 .64125 m .30072 .59076 L .32817 .60082 L p .707 .577 .707 r
F P
0 g
s
.20321 .63766 m .20883 .58717 L .23798 .58358 L p .707 .577 .707 r
F P
0 g
s
.20883 .58717 m .20321 .63766 L .17942 .64572 L p .707 .577 .707 r
F P
0 g
s
.1629 .76383 m .1643 .74648 L .18046 .73581 L p .707 .577 .707 r
F P
0 g
s
.30072 .59076 m .2951 .64125 L .26402 .63531 L p .707 .577 .707 r
F P
0 g
s
.26402 .63531 m .26964 .58482 L .30072 .59076 L p .707 .577 .707 r
F P
0 g
s
.23236 .63407 m .23798 .58358 L .26964 .58482 L p .707 .577 .707 r
F P
0 g
s
.23798 .58358 m .23236 .63407 L .20321 .63766 L p .707 .577 .707 r
F P
0 g
s
.18046 .73581 m .17906 .75316 L .1629 .76383 L p .707 .577 .707 r
F P
0 g
s
.34295 .69932 m .34847 .73731 L .32761 .7418 L p .707 .577 .707 r
F P
0 g
s
.26964 .58482 m .26402 .63531 L .23236 .63407 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .32209 .7038 L .34295 .69932 L p .707 .577 .707 r
F P
0 g
s
.62054 .26007 m .62054 .76196 L .59016 .75301 L p .707 .577 .707 r
F P
0 g
s
.59016 .75301 m .59016 .25112 L .62054 .26007 L p .707 .577 .707 r
F P
0 g
s
.20348 .72144 m .20899 .75943 L .18521 .76159 L p .707 .577 .707 r
F P
0 g
s
.18521 .76159 m .17969 .72359 L .20348 .72144 L p .707 .577 .707 r
F P
0 g
s
.34504 .75093 m .34364 .76828 L .32249 .75669 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .30042 .74673 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32209 .7038 m .32421 .7184 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32421 .7184 m .32761 .7418 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .32389 .73934 L .34188 .7492 L p .707 .577 .707 r
F P
0 g
s
.34188 .7492 m .34504 .75093 L p .34315 .75141 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .34188 .7492 L .34315 .75141 L .707 .577 .707 r
F
.38741 .25714 m .38741 .75902 L .36505 .76954 L p F P
0 g
s
.38741 .75902 m .38741 .25714 L .42078 .24898 L p .707 .577 .707 r
F P
0 g
s
.17906 .75316 m .18046 .73581 L .20432 .72835 L p .707 .577 .707 r
F P
0 g
s
.73598 .63577 m .73035 .57841 L .69928 .58113 L p .707 .577 .707 r
F P
0 g
s
.73035 .57841 m .73598 .63577 L .76764 .63253 L p .707 .577 .707 r
F P
0 g
s
.76764 .63253 m .76202 .57517 L .73035 .57841 L p .707 .577 .707 r
F P
0 g
s
.20432 .72835 m .20291 .7457 L .17906 .75316 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .2949 .70873 L .32209 .7038 L p .707 .577 .707 r
F P
0 g
s
.69928 .58113 m .7049 .63849 L .73598 .63577 L p .707 .577 .707 r
F P
0 g
s
.76202 .57517 m .76764 .63253 L .79679 .62907 L p .707 .577 .707 r
F P
0 g
s
.79679 .62907 m .79116 .57171 L .76202 .57517 L p .707 .577 .707 r
F P
0 g
s
.23254 .718 m .23806 .756 L .20899 .75943 L p .707 .577 .707 r
F P
0 g
s
.20899 .75943 m .20348 .72144 L .23254 .718 L p .707 .577 .707 r
F P
0 g
s
.7049 .63849 m .69928 .58113 L .67183 .58306 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .26956 .75162 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.2949 .70873 m .29609 .71691 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.29609 .71691 m .30042 .74673 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .295 .74797 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32389 .73934 m .32366 .7422 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32366 .7422 m .32249 .75669 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .29641 .73062 L .32389 .73934 L p .707 .577 .707 r
F P
0 g
s
.67183 .58306 m .67746 .64042 L .7049 .63849 L p .707 .577 .707 r
F P
0 g
s
.23806 .756 m .23277 .71959 L p .26405 .71363 L .707 .577 .707 r
F P
0 g
s
.23277 .71959 m .23254 .718 L .23577 .71756 L p .707 .577 .707 r
F P
0 g
s
.23577 .71756 m .26405 .71363 L p .23277 .71959 L .707 .577 .707 r
F P
0 g
s
.20291 .7457 m .20341 .7395 L p .23354 .72484 L .707 .577 .707 r
F P
0 g
s
.20341 .7395 m .20432 .72835 L .2232 .72608 L p .707 .577 .707 r
F P
0 g
s
.2232 .72608 m .23354 .72484 L p .20341 .7395 L .707 .577 .707 r
F P
0 g
s
.59016 .25112 m .59016 .75301 L .55096 .74701 L p .707 .577 .707 r
F P
0 g
s
.55096 .74701 m .55096 .24512 L .59016 .25112 L p .707 .577 .707 r
F P
0 g
s
.79116 .57171 m .79679 .62907 L .82057 .62575 L p .707 .577 .707 r
F P
0 g
s
.82057 .62575 m .81495 .56839 L .79116 .57171 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .26405 .71363 L .2949 .70873 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .23806 .756 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.26453 .71692 m .26956 .75162 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .26387 .74297 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29641 .73062 m .29591 .73677 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29591 .73677 m .295 .74797 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.26405 .71363 m .26453 .71692 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.23354 .72484 m .23214 .74219 L .20291 .7457 L p .707 .577 .707 r
F P
0 g
s
.42078 .75087 m .42078 .24898 L .46191 .244 L p .707 .577 .707 r
F P
0 g
s
.42078 .24898 m .42078 .75087 L .38741 .75902 L p .707 .577 .707 r
F P
0 g
s
.26387 .74297 m .26527 .72562 L .29641 .73062 L p .707 .577 .707 r
F P
0 g
s
.67746 .64042 m .67183 .58306 L .6507 .584 L p .707 .577 .707 r
F P
0 g
s
.23214 .74219 m .23354 .72484 L .26527 .72562 L p .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .73472 .72534 L .7173 .72621 L p .707 .577 .707 r
F P
0 g
s
.7173 .72621 m .70359 .7269 L p .70998 .73034 L .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .7173 .72621 L .70998 .73034 L .707 .577 .707 r
F
.73613 .74442 m .76786 .74179 L p .74488 .73038 L F P
0 g
s
.73472 .72534 m .73554 .73638 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.73554 .73638 m .73613 .74442 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .76646 .72271 L .73472 .72534 L p .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .79708 .73835 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76646 .72271 m .76755 .73761 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76755 .73761 m .76786 .74179 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .79568 .71927 L .76646 .72271 L p .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .82094 .73443 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79568 .71927 m .79706 .73803 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79706 .73803 m .79708 .73835 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.82094 .73443 m .81954 .71535 L .79568 .71927 L p .707 .577 .707 r
F P
0 g
s
.81954 .71535 m .82094 .73443 L .8371 .73042 L p .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .8357 .71134 L .83012 .71273 L p .707 .577 .707 r
F P
0 g
s
.83012 .71273 m .81954 .71535 L p .82729 .722 L .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .83012 .71273 L .82729 .722 L .707 .577 .707 r
F
.83096 .72012 m .83795 .70323 L p .83672 .69116 L F P
0 g
s
.83648 .6888 m .83518 .6962 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.83518 .6962 m .83096 .72012 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .83096 .72012 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.82031 .70248 m .81976 .70558 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.81976 .70558 m .81479 .73381 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .81479 .73381 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79652 .71163 m .79639 .71239 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79639 .71239 m .79101 .74295 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .79101 .74295 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76745 .71533 m .76734 .71597 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76734 .71597 m .76194 .74666 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.70359 .7269 m .70499 .74598 L .73613 .74442 L p .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .76194 .74666 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73595 .71324 m .73547 .71596 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73547 .71596 m .73043 .74456 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .73595 .71324 L .70509 .70555 L p .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .76745 .71533 L .73595 .71324 L p .707 .577 .707 r
F P
0 g
s
.6507 .584 m .65633 .64136 L .67746 .64042 L p .707 .577 .707 r
F P
0 g
s
.26527 .72562 m .26387 .74297 L .23214 .74219 L p .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .70359 .7269 L .68123 .72717 L p .707 .577 .707 r
F P
0 g
s
.68123 .72717 m .67611 .72723 L p .67863 .72887 L .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .68123 .72717 L .67863 .72887 L .707 .577 .707 r
F
.69958 .73688 m .73043 .74456 L p .70781 .70974 L F P
0 g
s
.70509 .70555 m .70391 .7123 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.70391 .7123 m .69958 .73688 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.69958 .73688 m .70509 .70555 L .6779 .69302 L p .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .79652 .71163 L .76745 .71533 L p .707 .577 .707 r
F P
0 g
s
.55096 .24512 m .55096 .74701 L .50676 .74456 L p .707 .577 .707 r
F P
0 g
s
.50676 .74456 m .50676 .24267 L .55096 .24512 L p .707 .577 .707 r
F P
0 g
s
.81495 .56839 m .82057 .62575 L .83666 .62288 L p .707 .577 .707 r
F P
0 g
s
.83666 .62288 m .83104 .56552 L .81495 .56839 L p .707 .577 .707 r
F P
0 g
s
.67611 .72723 m .67751 .74631 L .70499 .74598 L p .707 .577 .707 r
F P
0 g
s
.46191 .74589 m .46191 .244 L .50676 .24267 L p .707 .577 .707 r
F P
0 g
s
.46191 .244 m .46191 .74589 L .42078 .75087 L p .707 .577 .707 r
F P
0 g
s
.67239 .72435 m .6779 .69302 L .65704 .67688 L p .707 .577 .707 r
F P
0 g
s
.6779 .69302 m .67239 .72435 L .69958 .73688 L p .707 .577 .707 r
F P
0 g
s
.50676 .24267 m .50676 .74456 L .46191 .74589 L p .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .82031 .70248 L .79652 .71163 L p .707 .577 .707 r
F P
0 g
s
.65633 .64136 m .6507 .584 L .63796 .58388 L p .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .64358 .64124 L .65633 .64136 L p .707 .577 .707 r
F P
0 g
s
.67751 .74631 m .67611 .72723 L .65496 .72631 L p .707 .577 .707 r
F P
0 g
s
.65496 .72631 m .65636 .74539 L .67751 .74631 L p .707 .577 .707 r
F P
0 g
s
.65153 .7082 m .65704 .67688 L .64455 .6587 L p .707 .577 .707 r
F P
0 g
s
.65704 .67688 m .65153 .7082 L .67239 .72435 L p .707 .577 .707 r
F P
0 g
s
.83096 .72012 m .83648 .6888 L .82031 .70248 L p .707 .577 .707 r
F P
0 g
s
.83104 .56552 m .83666 .62288 L .84349 .62075 L p .707 .577 .707 r
F P
0 g
s
.84349 .62075 m .83786 .56339 L .83104 .56552 L p .707 .577 .707 r
F P
0 g
s
.65636 .74539 m .65496 .72631 L .64222 .72422 L p .707 .577 .707 r
F P
0 g
s
.64358 .64124 m .6421 .62617 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.63484 .58269 m .64047 .64005 L .64358 .64124 L p .707 .577 .707 r
F P
0 g
s
.63904 .69002 m .64455 .6587 L .64166 .64026 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .63614 .67158 L .63904 .69002 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .64864 .62337 L p .64504 .63727 L .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .63484 .58269 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.6421 .62617 m .63796 .58388 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64414 .6389 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64864 .62337 L p .64977 .63276 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64695 .63444 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64977 .63276 L .64695 .63444 L .707 .577 .707 r
F
.66338 .63505 m .64729 .63792 L p .648 .63381 L F P
0 g
s
.64864 .62337 m .66481 .60969 L p .65529 .62945 L .707 .577 .707 r
F P
0 g
s
.64977 .63276 m .64864 .62337 L .65529 .62945 L .707 .577 .707 r
F
.648 .63381 m .66205 .62541 L .66338 .63505 L F
.66205 .62541 m .66481 .60969 L p .66743 .62417 L F P
0 g
s
.66338 .63505 m .66245 .62563 L p .66656 .62442 L .707 .577 .707 r
F P
0 g
s
.66205 .62541 m .66743 .62417 L .66245 .62563 L .707 .577 .707 r
F
.68716 .63173 m .66338 .63505 L p .66656 .62442 L F P
0 g
s
.66481 .60969 m .6886 .60054 L p .67259 .62266 L .707 .577 .707 r
F P
0 g
s
.66743 .62417 m .66481 .60969 L .67259 .62266 L .707 .577 .707 r
F
.6886 .60054 m .71767 .59684 L p .69713 .61764 L F P
0 g
s
.6921 .61832 m .6886 .60054 L .69713 .61764 L .707 .577 .707 r
F
.68716 .63173 m .68593 .61915 L p .69237 .61828 L F P
0 g
s
.68536 .61891 m .6886 .60054 L p .6921 .61832 L .707 .577 .707 r
F P
0 g
s
.71631 .62828 m .68716 .63173 L p .69237 .61828 L .707 .577 .707 r
F P
0 g
s
.68593 .61915 m .6921 .61832 L .69282 .622 L .707 .577 .707 r
F
.68536 .61891 m .6921 .61832 L .68593 .61915 L F
.71767 .59684 m .74917 .59893 L p .72837 .61535 L F P
0 g
s
.7223 .61547 m .71767 .59684 L .72837 .61535 L .707 .577 .707 r
F
.71631 .62828 m .71507 .61562 L p .72181 .61548 L F P
0 g
s
.71441 .61532 m .71767 .59684 L p .7223 .61547 L .707 .577 .707 r
F P
0 g
s
.74798 .62503 m .71631 .62828 L p .72181 .61548 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .74634 .61499 L .74798 .62503 L .707 .577 .707 r
F
.74634 .61499 m .74917 .59893 L p .75524 .61608 L F P
0 g
s
.77905 .62231 m .74798 .62503 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .77803 .61794 L .77905 .62231 L .707 .577 .707 r
F
.77803 .61794 m .78003 .60662 L p .78608 .61996 L F P
0 g
s
.79317 .62132 m .77905 .62231 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.77803 .61794 m .78608 .61996 L .77868 .61853 L .707 .577 .707 r
F
.78003 .60662 m .80722 .61915 L p .80086 .6228 L F P
0 g
s
.78608 .61996 m .78003 .60662 L .80086 .6228 L .707 .577 .707 r
F
.74917 .59893 m .78003 .60662 L p .76433 .61682 L F P
0 g
s
.75716 .62148 m .75524 .61608 L .76433 .61682 L .707 .577 .707 r
F
.75524 .61608 m .74917 .59893 L .76433 .61682 L F
.74634 .61499 m .75524 .61608 L .74703 .6154 L F
.69237 .61828 m .71441 .61532 L .71631 .62828 L F
.71441 .61532 m .7223 .61547 L .71507 .61562 L F
.71503 .61523 m .71507 .61562 L p .71441 .61532 L F P
0 g
s
.71507 .61562 m .71631 .62828 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.74917 .59893 m .74628 .61534 L p .7288 .62191 L .707 .577 .707 r
F P
0 g
s
.71215 .62816 m .72327 .61938 L .7288 .62191 L .707 .577 .707 r
F
.72327 .61938 m .74917 .59893 L .7288 .62191 L F
.74628 .61534 m .74365 .63025 L .72033 .6287 L p F P
0 g
s
.72033 .6287 m .71215 .62816 L p .74628 .61534 L .707 .577 .707 r
F P
0 g
s
.74235 .56767 m .77343 .56495 L p .7537 .61152 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .75128 .61276 L .7537 .61152 L .707 .577 .707 r
F
.75128 .61276 m .74235 .56767 L .7537 .61152 L F
.74798 .62503 m .74703 .6154 L p .75189 .6158 L F P
0 g
s
.74703 .6154 m .74235 .56767 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.78003 .60662 m .77795 .61839 L p .74365 .63025 L .707 .577 .707 r
F P
0 g
s
.77795 .61839 m .77451 .63794 L .7537 .63276 L p .707 .577 .707 r
F P
0 g
s
.7537 .63276 m .74365 .63025 L p .77795 .61839 L .707 .577 .707 r
F P
0 g
s
.77343 .56495 m .80087 .56303 L p .7812 .61647 L .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .7801 .61712 L .7812 .61647 L .707 .577 .707 r
F
.7801 .61712 m .77343 .56495 L .7812 .61647 L F
.77905 .62231 m .77868 .61853 L p .78033 .61885 L F P
0 g
s
.77868 .61853 m .77343 .56495 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.79016 .62895 m .78608 .61996 L .80086 .6228 L .707 .577 .707 r
F
.77868 .61853 m .78608 .61996 L .79016 .62895 L F
.80722 .61915 m .80626 .6246 L p .77451 .63794 L F P
0 g
s
.80626 .6246 m .8017 .65047 L .78822 .64426 L p .707 .577 .707 r
F P
0 g
s
.78822 .64426 m .77451 .63794 L p .80626 .6246 L .707 .577 .707 r
F P
0 g
s
.8017 .65047 m .80722 .61915 L .82808 .63529 L p .707 .577 .707 r
F P
0 g
s
.822 .56208 m .82602 .60306 L p .8065 .62039 L .707 .577 .707 r
F P
0 g
s
.82602 .60306 m .82763 .61944 L .81028 .62022 L p .707 .577 .707 r
F P
0 g
s
.81028 .62022 m .8065 .62039 L p .82602 .60306 L .707 .577 .707 r
F P
0 g
s
.80087 .56303 m .8065 .62039 L .79317 .62132 L p .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .80087 .56303 L .79317 .62132 L .707 .577 .707 r
F
.77863 .61799 m .77868 .61853 L p .77803 .61794 L F P
0 g
s
.77868 .61853 m .77905 .62231 L p .77803 .61794 L .707 .577 .707 r
F P
0 g
s
.77451 .63794 m .77803 .61794 L p .79016 .62895 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .75524 .61608 L .75716 .62148 L .707 .577 .707 r
F
.77343 .56495 m .77863 .61799 L p .75189 .6158 L F P
0 g
s
.74699 .61498 m .74703 .6154 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .74798 .62503 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74365 .63025 m .74634 .61499 L p .75716 .62148 L .707 .577 .707 r
F P
0 g
s
.71507 .61562 m .7223 .61547 L .72327 .61938 L .707 .577 .707 r
F
.74235 .56767 m .74699 .61498 L p .72181 .61548 L F P
0 g
s
.66656 .62442 m .68536 .61891 L .68716 .63173 L .707 .577 .707 r
F
.68589 .61876 m .68593 .61915 L p .68536 .61891 L F P
0 g
s
.68593 .61915 m .68716 .63173 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.71767 .59684 m .71436 .61564 L p .69798 .62414 L .707 .577 .707 r
F P
0 g
s
.68308 .63187 m .69282 .622 L .69798 .62414 L .707 .577 .707 r
F
.69282 .622 m .71767 .59684 L .69798 .62414 L F
.71436 .61564 m .71215 .62816 L .6879 .63125 L p F P
0 g
s
.6879 .63125 m .68308 .63187 L p .71436 .61564 L .707 .577 .707 r
F P
0 g
s
.71069 .57092 m .74235 .56767 L p .72426 .60979 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .72089 .61178 L .72426 .60979 L .707 .577 .707 r
F
.72089 .61178 m .71069 .57092 L .72426 .60979 L F
.71507 .61562 m .71069 .57092 L p .72181 .61548 L F P
0 g
s
.72327 .61938 m .7223 .61547 L .72837 .61535 L .707 .577 .707 r
F
.71215 .62816 m .71441 .61532 L p .72327 .61938 L F P
0 g
s
.71069 .57092 m .71503 .61523 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69666 .60719 L .71441 .61532 L .707 .577 .707 r
F
.69666 .60719 m .71069 .57092 L .71441 .61532 L F
.68308 .63187 m .6593 .64101 L p .66056 .63927 L F P
0 g
s
.6886 .60054 m .68531 .61923 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68531 .61923 m .68308 .63187 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68154 .57437 m .71069 .57092 L p .69505 .61134 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69139 .61431 L .69505 .61134 L .707 .577 .707 r
F
.69139 .61431 m .68154 .57437 L .69505 .61134 L F
.68593 .61915 m .68154 .57437 L p .69237 .61828 L F P
0 g
s
.69282 .622 m .6921 .61832 L .69713 .61764 L .707 .577 .707 r
F
.68308 .63187 m .68536 .61891 L p .69282 .622 L F P
0 g
s
.68154 .57437 m .68589 .61876 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .6701 .61259 L .68536 .61891 L .707 .577 .707 r
F
.6701 .61259 m .68154 .57437 L .68536 .61891 L F
.66824 .62866 m .66743 .62417 L .67259 .62266 L F
.66245 .62563 m .66743 .62417 L .66824 .62866 L F
.6593 .64101 m .64312 .65469 L p .64821 .64414 L F P
0 g
s
.66481 .60969 m .66198 .62577 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.66198 .62577 m .6593 .64101 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .68154 .57437 L p .66893 .61649 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .66584 .62062 L .66893 .61649 L .707 .577 .707 r
F
.66584 .62062 m .65775 .57769 L .66893 .61649 L F
.66245 .62563 m .65775 .57769 L p .66656 .62442 L F P
0 g
s
.66241 .62519 m .66245 .62563 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.66245 .62563 m .66338 .63505 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.6593 .64101 m .66205 .62541 L p .66824 .62866 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .66241 .62519 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.65055 .63928 m .64977 .63276 L .65529 .62945 L .707 .577 .707 r
F
.64695 .63444 m .64977 .63276 L .65055 .63928 L F
.64312 .65469 m .63614 .67158 L p .64164 .65039 L F P
0 g
s
.64864 .62337 m .64666 .63461 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64666 .63461 m .64312 .65469 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .65775 .57769 L p .64931 .6263 L .707 .577 .707 r
F P
0 g
s
.648 .63381 m .64771 .63133 L .64931 .6263 L .707 .577 .707 r
F
.64771 .63133 m .64166 .58056 L .64931 .6263 L F
.64695 .63444 m .64166 .58056 L p .648 .63381 L F P
0 g
s
.64689 .63388 m .64695 .63444 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64695 .63444 m .64729 .63792 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64312 .65469 m .64674 .63416 L p .65055 .63928 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .64689 .63388 L p .64047 .64005 L .707 .577 .707 r
F P
0 g
s
.64131 .64408 m .64166 .64026 L .64504 .63727 L .707 .577 .707 r
F
.64414 .6389 m .64047 .64005 L p .64689 .63388 L F P
0 g
s
.64023 .65581 m .64131 .64408 L .64504 .63727 L .707 .577 .707 r
F
.63614 .67158 m .64097 .6442 L p .64023 .65581 L F P
0 g
s
.64097 .6442 m .64166 .64026 L p .64023 .65581 L .707 .577 .707 r
F P
0 g
s
.64222 .72422 m .64362 .7433 L .65636 .74539 L p .707 .577 .707 r
F P
0 g
s
.64455 .6587 m .63904 .69002 L .65153 .7082 L p .707 .577 .707 r
F P
0 g
s
.83795 .70323 m .84346 .67191 L .83648 .6888 L p .707 .577 .707 r
F P
0 g
s
.8357 .71134 m .8371 .73042 L .84397 .72671 L p .707 .577 .707 r
F P
0 g
s
.84397 .72671 m .84257 .70763 L .8357 .71134 L p .707 .577 .707 r
F P
0 g
s
.83786 .56339 m .84349 .62075 L .84037 .61957 L p .707 .577 .707 r
F P
0 g
s
.84037 .61957 m .83475 .56221 L .83786 .56339 L p .707 .577 .707 r
F P
0 g
s
.64362 .7433 m .64222 .72422 L .63913 .72117 L p .707 .577 .707 r
F P
0 g
s
.63913 .72117 m .64053 .74025 L .64362 .7433 L p .707 .577 .707 r
F P
0 g
s
.64047 .64005 m .63484 .58269 L .64166 .58056 L p .707 .577 .707 r
F P
0 g
s
.84346 .67191 m .83795 .70323 L .83505 .6848 L p .707 .577 .707 r
F P
0 g
s
.83505 .6848 m .84057 .65347 L .84346 .67191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84257 .70763 m .84397 .72671 L .84088 .72366 L p .707 .577 .707 r
F P
0 g
s
.84088 .72366 m .83948 .70458 L .84257 .70763 L p .707 .577 .707 r
F P
0 g
s
.83475 .56221 m .84037 .61957 L .82763 .61944 L p .707 .577 .707 r
F P
0 g
s
.82763 .61944 m .822 .56208 L .83475 .56221 L p .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .38174 .57769 L .35136 .58164 L p .707 .577 .707 r
F P
0 g
s
.38174 .57769 m .39466 .63015 L .42569 .62246 L p .707 .577 .707 r
F P
0 g
s
.42569 .62246 m .41277 .57001 L .38174 .57769 L p .707 .577 .707 r
F P
0 g
s
.41277 .57001 m .42569 .62246 L .45434 .6118 L p .707 .577 .707 r
F P
0 g
s
.45434 .6118 m .44142 .55934 L .41277 .57001 L p .707 .577 .707 r
F P
0 g
s
.35266 .65285 m .38202 .66387 L p .37339 .63974 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .35136 .58164 L .35965 .62795 L .707 .577 .707 r
F
.36361 .63135 m .36311 .62933 L p .36093 .62904 L F P
0 g
s
.36311 .62933 m .35136 .58164 L p .36093 .62904 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .32462 .58147 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.38202 .66387 m .41216 .67384 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .35318 .58902 L p .39466 .63015 L .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .35318 .58902 L .39126 .63028 L .707 .577 .707 r
F
.38154 .63185 m .39466 .63015 L p .36361 .63135 L F P
0 g
s
.39453 .62781 m .39302 .63218 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.39302 .63218 m .38202 .66387 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35318 .58902 m .36361 .63135 L p .39126 .63028 L .707 .577 .707 r
F P
0 g
s
.37339 .63974 m .37045 .63154 L .36361 .63135 L .707 .577 .707 r
F
.36093 .62904 m .35266 .65285 L p .37339 .63974 L F P
0 g
s
.38202 .66387 m .39453 .62781 L .36518 .61679 L p .707 .577 .707 r
F P
0 g
s
.36361 .63135 m .36429 .6341 L .38154 .63185 L p .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .36093 .62904 L p .36361 .63135 L .707 .577 .707 r
F P
0 g
s
.37045 .63154 m .36518 .61679 L .36361 .63135 L .707 .577 .707 r
F
.35266 .65285 m .36093 .62904 L p .34542 .62698 L F P
0 g
s
.32698 .64187 m .35266 .65285 L p .34857 .63823 L .707 .577 .707 r
F P
0 g
s
.34857 .63823 m .34542 .62698 L .34078 .63073 L .707 .577 .707 r
F
.34857 .63823 m .34078 .63073 L .32698 .64187 L F
.32462 .58147 m .30412 .57718 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .32462 .58147 L .32898 .61938 L .707 .577 .707 r
F
.33551 .62566 m .33511 .62404 L p .33333 .62357 L F P
0 g
s
.33511 .62404 m .32462 .58147 L p .33333 .62357 L .707 .577 .707 r
F P
0 g
s
.32462 .58147 m .33551 .62566 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.32698 .64187 m .33333 .62357 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33273 .62529 m .32698 .64187 L p .34078 .63073 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .29188 .56922 L p .30958 .61171 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .31852 .62459 L .30747 .632 L .707 .577 .707 r
F
.31287 .61646 m .30412 .57718 L .30958 .61171 L F
.3143 .61852 m .31394 .61704 L p .31287 .61646 L F P
0 g
s
.31394 .61704 m .30412 .57718 L p .31287 .61646 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .31002 .60115 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .32381 .62104 L .31852 .62459 L .707 .577 .707 r
F
.31233 .618 m .30747 .632 L p .32381 .62104 L F P
0 g
s
.31002 .60115 m .31704 .62964 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .31287 .61646 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .30793 .61376 L .30379 .61741 L .707 .577 .707 r
F
.29606 .62421 m .30745 .63198 L p .30379 .61741 L F P
0 g
s
.30745 .63198 m .30747 .632 L p .30379 .61741 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .28908 .55834 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.30153 .60845 m .29188 .56922 L .30053 .60446 L .709 .579 .707 r
F
.30206 .61057 m .30169 .60906 L p .30153 .60845 L F P
0 g
s
.30169 .60906 m .29188 .56922 L p .30153 .60845 L .709 .579 .707 r
F P
0 g
s
.29606 .62421 m .30153 .60845 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .30206 .61057 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.30858 .58816 m .30153 .60845 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .301 .60999 L p .30206 .61057 L .707 .577 .707 r
F P
0 g
s
.30793 .61376 m .30153 .60845 L .30206 .61057 L .707 .577 .707 r
F
.301 .60999 m .29606 .62421 L p .30379 .61741 L F P
0 g
s
.30793 .61376 m .30206 .61057 L .30379 .61741 L .707 .577 .707 r
F
.30206 .61057 m .301 .60999 L .30379 .61741 L F
.28908 .55834 m .29602 .54562 L p .30085 .5982 L F P
0 g
s
.29606 .62421 m .30076 .60553 L .29851 .61 L .707 .577 .707 r
F
.28908 .55834 m .29642 .5881 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.29984 .60203 m .29386 .61926 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30053 .60446 m .29841 .59605 L .30201 .61079 L .709 .579 .707 r
F
.29642 .5881 m .29956 .60088 L p .29841 .59605 L F P
0 g
s
.29956 .60088 m .30201 .61079 L p .29841 .59605 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30053 .60446 L .30091 .60609 L .709 .579 .707 r
F
.3048 .62167 m .30206 .61057 L p .30053 .60446 L F P
0 g
s
.30637 .58321 m .30043 .60034 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29998 .60258 m .29956 .60088 L .30043 .60034 L .707 .577 .707 r
F
.30043 .60034 m .29984 .60203 L p .29998 .60258 L F P
0 g
s
.30076 .60553 m .30043 .60034 L .29998 .60258 L .707 .577 .707 r
F
.30201 .61079 m .3048 .62167 L p .30131 .60762 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30091 .60609 L .30201 .61079 L .709 .579 .707 r
F
.30858 .58816 m .30637 .58321 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .30858 .58816 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .29998 .60258 L p .30043 .60034 L .707 .577 .707 r
F P
0 g
s
.29984 .60203 m .30043 .60034 L p .30079 .60603 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .30637 .58321 L p .3025 .59903 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .30043 .60034 L .30101 .59997 L .707 .577 .707 r
F
.31999 .59595 m .30858 .58816 L p .30793 .61376 L F P
0 g
s
.30637 .58321 m .31359 .58158 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.3025 .59903 m .30637 .58321 L .30542 .59719 L .707 .577 .707 r
F
.30206 .61057 m .3048 .62167 L p .31117 .61553 L F P
0 g
s
.30894 .59808 m .30201 .61079 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.31359 .58158 m .30968 .59284 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30894 .59808 m .30828 .59539 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30542 .59719 m .30968 .59284 L .30828 .59539 L .707 .577 .707 r
F
.31359 .58158 m .32953 .58344 L p .32382 .5903 L F P
0 g
s
.30968 .59284 m .31359 .58158 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.312 .53231 m .32492 .58476 L .31675 .59157 L p .707 .577 .707 r
F P
0 g
s
.31675 .59157 m .30894 .59808 L p .30918 .59293 L .707 .577 .707 r
F P
0 g
s
.30918 .59293 m .312 .53231 L .31675 .59157 L .707 .577 .707 r
F
.30828 .59539 m .30894 .59808 L p .30101 .59997 L F P
0 g
s
.30108 .61764 m .30968 .59284 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.30968 .59284 m .30895 .59496 L p .30828 .59539 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .312 .53231 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30828 .59539 m .29602 .54562 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .30828 .59539 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.29386 .61926 m .29581 .62364 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.29581 .62364 m .29606 .62421 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.30108 .61764 m .29386 .61926 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30895 .59496 m .30108 .61764 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .3025 .59903 L .30079 .60603 L .707 .577 .707 r
F
.30043 .60034 m .28908 .55834 L .30085 .5982 L F
.29956 .60088 m .28908 .55834 L .30043 .60034 L F
.30101 .59997 m .30043 .60034 L .30085 .5982 L F
.30079 .60603 m .3025 .59903 L .30542 .59719 L F
.29386 .61926 m .29984 .60203 L p .30079 .60603 L F P
0 g
s
.3048 .62167 m .31704 .62964 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.31999 .59595 m .31287 .61646 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.31287 .61646 m .31233 .618 L p .3143 .61852 L .707 .577 .707 r
F P
0 g
s
.32381 .62104 m .31287 .61646 L .3143 .61852 L .707 .577 .707 r
F
.31704 .62964 m .3143 .61852 L p .30958 .61171 L F P
0 g
s
.31287 .61646 m .31999 .59595 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .32698 .64187 L p .32599 .63535 L .707 .577 .707 r
F P
0 g
s
.31704 .62964 m .33754 .63392 L p .33109 .62297 L .707 .577 .707 r
F P
0 g
s
.33109 .62297 m .32898 .61938 L .32628 .6217 L .707 .577 .707 r
F
.33109 .62297 m .32628 .6217 L .31704 .62964 L F
.34542 .62698 m .33551 .62566 L .34078 .63073 L F
.33551 .62566 m .33273 .62529 L .34078 .63073 L F
.33949 .60581 m .31999 .59595 L p .32381 .62104 L F P
0 g
s
.33949 .60581 m .33333 .62357 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.33333 .62357 m .33273 .62529 L p .33551 .62566 L .707 .577 .707 r
F P
0 g
s
.34542 .62698 m .33333 .62357 L .33551 .62566 L .707 .577 .707 r
F
.33754 .63392 m .33551 .62566 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .33949 .60581 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33754 .63392 m .36429 .6341 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.33551 .62566 m .33754 .63392 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .33949 .60581 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.36429 .6341 m .36361 .63135 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .36518 .61679 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.44142 .55934 m .45434 .6118 L .4778 .59919 L p .707 .577 .707 r
F P
0 g
s
.4778 .59919 m .46488 .54673 L .44142 .55934 L p .707 .577 .707 r
F P
0 g
s
.64053 .74025 m .63913 .72117 L .646 .71746 L p .707 .577 .707 r
F P
0 g
s
.84057 .65347 m .83505 .6848 L .82256 .66662 L p .707 .577 .707 r
F P
0 g
s
.82256 .66662 m .82808 .63529 L .84057 .65347 L p .707 .577 .707 r
F P
0 g
s
.646 .71746 m .64741 .73654 L .64053 .74025 L p .707 .577 .707 r
F P
0 g
s
.41216 .67384 m .42468 .63779 L .39453 .62781 L p .707 .577 .707 r
F P
0 g
s
.42468 .63779 m .41216 .67384 L .44015 .6818 L p .707 .577 .707 r
F P
0 g
s
.44015 .6818 m .45267 .64575 L .42468 .63779 L p .707 .577 .707 r
F P
0 g
s
.46488 .54673 m .4778 .59919 L .49378 .58587 L p .707 .577 .707 r
F P
0 g
s
.49378 .58587 m .48086 .53342 L .46488 .54673 L p .707 .577 .707 r
F P
0 g
s
.83948 .70458 m .84088 .72366 L .82814 .72157 L p .707 .577 .707 r
F P
0 g
s
.82814 .72157 m .82674 .70249 L .83948 .70458 L p .707 .577 .707 r
F P
0 g
s
.8065 .62039 m .80087 .56303 L .822 .56208 L p .707 .577 .707 r
F P
0 g
s
.82808 .63529 m .82256 .66662 L .8017 .65047 L p .707 .577 .707 r
F P
0 g
s
.45267 .64575 m .44015 .6818 L .46325 .68696 L p .707 .577 .707 r
F P
0 g
s
.46325 .68696 m .47576 .65091 L .45267 .64575 L p .707 .577 .707 r
F P
0 g
s
.64741 .73654 m .646 .71746 L .66216 .71345 L p .707 .577 .707 r
F P
0 g
s
.39557 .73024 m .39232 .7124 L .36159 .71497 L p .707 .577 .707 r
F P
0 g
s
.39232 .7124 m .39557 .73024 L .42694 .7242 L p .707 .577 .707 r
F P
0 g
s
.42694 .7242 m .4237 .70635 L .39232 .7124 L p .707 .577 .707 r
F P
0 g
s
.66216 .71345 m .66356 .73253 L .64741 .73654 L p .707 .577 .707 r
F P
0 g
s
.4237 .70635 m .42694 .7242 L .45589 .71527 L p .707 .577 .707 r
F P
0 g
s
.45589 .71527 m .45264 .69743 L .4237 .70635 L p .707 .577 .707 r
F P
0 g
s
.36159 .71497 m .36483 .73282 L .39557 .73024 L p .707 .577 .707 r
F P
0 g
s
.36483 .73282 m .36159 .71497 L .3345 .71382 L p .707 .577 .707 r
F P
0 g
s
.48086 .53342 m .49378 .58587 L .50071 .57316 L p .707 .577 .707 r
F P
0 g
s
.50071 .57316 m .48779 .5207 L .48086 .53342 L p .707 .577 .707 r
F P
0 g
s
.45264 .69743 m .45589 .71527 L .47956 .70433 L p .707 .577 .707 r
F P
0 g
s
.47956 .70433 m .47632 .68649 L .45264 .69743 L p .707 .577 .707 r
F P
0 g
s
.3345 .71382 m .33774 .73166 L .36483 .73282 L p .707 .577 .707 r
F P
0 g
s
.82674 .70249 m .82814 .72157 L .807 .72065 L p .707 .577 .707 r
F P
0 g
s
.807 .72065 m .80559 .70157 L .82674 .70249 L p .707 .577 .707 r
F P
0 g
s
.47632 .68649 m .47956 .70433 L .49565 .69246 L p .707 .577 .707 r
F P
0 g
s
.49565 .69246 m .49241 .67462 L .47632 .68649 L p .707 .577 .707 r
F P
0 g
s
.47576 .65091 m .46325 .68696 L .47918 .68882 L p .707 .577 .707 r
F P
0 g
s
.47918 .68882 m .4917 .65277 L .47576 .65091 L p .707 .577 .707 r
F P
0 g
s
.33774 .73166 m .3345 .71382 L .31371 .70905 L p .707 .577 .707 r
F P
0 g
s
.66356 .73253 m .66216 .71345 L .68602 .70953 L p .707 .577 .707 r
F P
0 g
s
.68602 .70953 m .68742 .72861 L .66356 .73253 L p .707 .577 .707 r
F P
0 g
s
.31371 .70905 m .31695 .7269 L .33774 .73166 L p .707 .577 .707 r
F P
0 g
s
.48779 .5207 m .50071 .57316 L .49792 .56228 L p .709 .579 .707 r
F P
0 g
s
.49792 .56228 m .485 .50983 L .48779 .5207 L p .709 .579 .707 r
F P
0 g
s
.80559 .70157 m .807 .72065 L .77951 .72098 L p .707 .577 .707 r
F P
0 g
s
.77951 .72098 m .77811 .7019 L .80559 .70157 L p .707 .577 .707 r
F P
0 g
s
.4917 .65277 m .47918 .68882 L .4864 .6872 L p .707 .577 .707 r
F P
0 g
s
.4864 .6872 m .49892 .65114 L .4917 .65277 L p .707 .577 .707 r
F P
0 g
s
.68742 .72861 m .68602 .70953 L .71524 .70609 L p .707 .577 .707 r
F P
0 g
s
.71524 .70609 m .71665 .72517 L .68742 .72861 L p .707 .577 .707 r
F P
0 g
s
.31695 .7269 m .31371 .70905 L .30125 .70114 L p .707 .577 .707 r
F P
0 g
s
.49241 .67462 m .49565 .69246 L .50259 .68081 L p .707 .577 .707 r
F P
0 g
s
.50259 .68081 m .49935 .66297 L .49241 .67462 L p .707 .577 .707 r
F P
0 g
s
.77811 .7019 m .77951 .72098 L .74838 .72254 L p .707 .577 .707 r
F P
0 g
s
.74838 .72254 m .74698 .70346 L .77811 .7019 L p .707 .577 .707 r
F P
0 g
s
.30125 .70114 m .30449 .71898 L .31695 .7269 L p .707 .577 .707 r
F P
0 g
s
.71665 .72517 m .71524 .70609 L .74698 .70346 L p .707 .577 .707 r
F P
0 g
s
.74698 .70346 m .74838 .72254 L .71665 .72517 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.485 .50983 m .49792 .56228 L .48568 .55431 L p .707 .577 .707 r
F P
0 g
s
.48568 .55431 m .47275 .50186 L .485 .50983 L p .707 .577 .707 r
F P
0 g
s
.49892 .65114 m .4864 .6872 L .4842 .68225 L p .707 .577 .707 r
F P
0 g
s
.4842 .68225 m .49671 .64619 L .49892 .65114 L p .707 .577 .707 r
F P
0 g
s
.30449 .71898 m .30125 .70114 L .29835 .69086 L p .707 .577 .707 r
F P
0 g
s
.49935 .66297 m .50259 .68081 L .49968 .67052 L p .707 .577 .707 r
F P
0 g
s
.49968 .67052 m .49644 .65268 L .49935 .66297 L p .707 .577 .707 r
F P
0 g
s
.29835 .69086 m .30159 .7087 L .30449 .71898 L p .707 .577 .707 r
F P
0 g
s
.47275 .50186 m .48568 .55431 L .46518 .55003 L p .707 .577 .707 r
F P
0 g
s
.46518 .55003 m .45226 .49758 L .47275 .50186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30159 .7087 m .29835 .69086 L .30528 .67921 L p .707 .577 .707 r
F P
0 g
s
.49671 .64619 m .4842 .68225 L .47279 .67446 L p .707 .577 .707 r
F P
0 g
s
.47279 .67446 m .4853 .6384 L .49671 .64619 L p .707 .577 .707 r
F P
0 g
s
.49644 .65268 m .49968 .67052 L .48723 .66261 L p .707 .577 .707 r
F P
0 g
s
.48723 .66261 m .48399 .64477 L .49644 .65268 L p .707 .577 .707 r
F P
0 g
s
.30528 .67921 m .30852 .69705 L .30159 .7087 L p .707 .577 .707 r
F P
0 g
s
.32492 .58476 m .312 .53231 L .33546 .5197 L p .707 .577 .707 r
F P
0 g
s
.32953 .58344 m .31701 .6195 L .30108 .61764 L p .707 .577 .707 r
F P
0 g
s
.45226 .49758 m .46518 .55003 L .43843 .54985 L p .707 .577 .707 r
F P
0 g
s
.43843 .54985 m .42551 .4974 L .45226 .49758 L p .707 .577 .707 r
F P
0 g
s
.30852 .69705 m .30528 .67921 L .32137 .66733 L p .707 .577 .707 r
F P
0 g
s
.4853 .6384 m .47279 .67446 L .45328 .66459 L p .707 .577 .707 r
F P
0 g
s
.45328 .66459 m .4658 .62854 L .4853 .6384 L p .707 .577 .707 r
F P
0 g
s
.34838 .57215 m .33546 .5197 L .36411 .50903 L p .707 .577 .707 r
F P
0 g
s
.33546 .5197 m .34838 .57215 L .32492 .58476 L p .707 .577 .707 r
F P
0 g
s
.42551 .4974 m .43843 .54985 L .40806 .5538 L p .707 .577 .707 r
F P
0 g
s
.40806 .5538 m .39514 .50135 L .42551 .4974 L p .707 .577 .707 r
F P
0 g
s
.48399 .64477 m .48723 .66261 L .46644 .65785 L p .707 .577 .707 r
F P
0 g
s
.46644 .65785 m .46319 .64 L .48399 .64477 L p .707 .577 .707 r
F P
0 g
s
.32137 .66733 m .32461 .68518 L .30852 .69705 L p .707 .577 .707 r
F P
0 g
s
.31701 .6195 m .32953 .58344 L .35262 .5886 L p .707 .577 .707 r
F P
0 g
s
.37703 .56149 m .36411 .50903 L .39514 .50135 L p .707 .577 .707 r
F P
0 g
s
.36411 .50903 m .37703 .56149 L .34838 .57215 L p .707 .577 .707 r
F P
0 g
s
.39514 .50135 m .40806 .5538 L .37703 .56149 L p .707 .577 .707 r
F P
0 g
s
.35262 .5886 m .34011 .62466 L .31701 .6195 L p .707 .577 .707 r
F P
0 g
s
.4658 .62854 m .45328 .66459 L .4276 .65361 L p .707 .577 .707 r
F P
0 g
s
.4276 .65361 m .44011 .61756 L .4658 .62854 L p .707 .577 .707 r
F P
0 g
s
.32461 .68518 m .32137 .66733 L .34505 .6564 L p .707 .577 .707 r
F P
0 g
s
.34011 .62466 m .35262 .5886 L .38061 .59656 L p .707 .577 .707 r
F P
0 g
s
.46319 .64 m .46644 .65785 L .43935 .65669 L p .707 .577 .707 r
F P
0 g
s
.43935 .65669 m .4361 .63885 L .46319 .64 L p .707 .577 .707 r
F P
0 g
s
.34505 .6564 m .34829 .67424 L .32461 .68518 L p .707 .577 .707 r
F P
0 g
s
.38061 .59656 m .3681 .63262 L .34011 .62466 L p .707 .577 .707 r
F P
0 g
s
.44011 .61756 m .4276 .65361 L .39824 .64259 L p .707 .577 .707 r
F P
0 g
s
.39824 .64259 m .41076 .60654 L .44011 .61756 L p .707 .577 .707 r
F P
0 g
s
.3681 .63262 m .38061 .59656 L .41076 .60654 L p .707 .577 .707 r
F P
0 g
s
.34829 .67424 m .34505 .6564 L .37399 .64747 L p .707 .577 .707 r
F P
0 g
s
.41076 .60654 m .39824 .64259 L .3681 .63262 L p .707 .577 .707 r
F P
0 g
s
.4361 .63885 m .43935 .65669 L .40861 .65926 L p .707 .577 .707 r
F P
0 g
s
.40861 .65926 m .40537 .64142 L .4361 .63885 L p .707 .577 .707 r
F P
0 g
s
.37399 .64747 m .37723 .66531 L .34829 .67424 L p .707 .577 .707 r
F P
0 g
s
.37723 .66531 m .37399 .64747 L .40537 .64142 L p .707 .577 .707 r
F P
0 g
s
.40537 .64142 m .40861 .65926 L .37723 .66531 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH015YF3`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH70003FUH00`00FUIJEP05FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo1@001UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0065oo`<000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo
0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GGoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001KOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Qoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`8000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
EWoo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP03001JEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF1P0025YF0P000UYF
00<005YFFUH0100000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH010001EYF00<005YFFUH015YF0P001EYF00<005YFFUH00UYF10000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF20001EYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0002moo`L002moo`00DWoo00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEPD000AJEP03001JEUYF00800003FUH005YF00IJEP03001JEUYF
009JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000POol?0002FUH01000FUIJEUYF0P00;Woo001BOol200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUH000020006FUH50004FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000GOol90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
001BOol200000eYF001JEP04FUH00`00FUIJEP05FUH300000eYF001JEP05FUH90007FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool0059oo`80009JEP03001JEUYF009JEP03001JEUYF00=JEP80009o
o`03001JEP0000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Woo
200035YF00=oo`00FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
Dgoo00@005YFFUH000AJEP04001JEUYFFUH20004Ool00`00FUH000070007FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo1@005EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0P000UYF0P00;Woo0010Ool8000;Ool200000eYF001JEP04FUH<0004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP00FUH05eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000jOol60003FUH00`00FUIJ
EP02FUH70004Ool200000eYF001JEP04FUH200000eYF000000030009FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0FFUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00H0009JEP04001JEUYFFUH20006FUH30007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF01IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Woo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF0P000eYF00<005YFFUH01EYF00<005YF
00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH05UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH025YF0P000eYF00<005YFFUH0
15YF00<005YFFUH015YF10002EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0=FUH0
1@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000aOol200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00006
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000`Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00<0
05YFFUH01UYF00@005YF000000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP8002eoo`00;goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P0025YF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0P00;Goo000_Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002io
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH0
1@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YF0000009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH?000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP020002FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH:000^Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000=JEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH01@00FUIJEUYF0000=7oo000^Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000UYF00<005YF
FUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01UYF0`002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF1`001eYF200015YF
00@005YFFUIoo`AJEP03001JEUYF009JEP80039oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P000eYF40001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP80009JEP8000MJEP03001JEUYF009JEPT0009oo`<00003FUH005YF00IJ
EP03001JEUYF00AJEP03001oogoo02moo`00;Goo00<005YF00000eYF00<005YFFUH00UYF1P003goo
10000UYF00<005YFFUH015YF0`0025YF00<005YFFUH01EYF0`0000=JEP00FUH01EYF1`0015YF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00H005YF000005YF0004FUH8000>Ool20007FUH00`00FUIJEP04FUH2000`
Ool002eoo`03001JEP0000=JEP03001JEP00008001Uoo`@000IJEP<000MJEP03001JEUYF00IJEP03
001JEP0000L000=JEP04001JEUYFFUH70003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH:000HOol20004FUH00`00FUIJEP05FUH2000`Ool0
02eoo`8000AJEP80021oo`8000AJEP03001JEUYF008000EJEP03001JEUYF00EJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0009JEP80009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001oogoo029oo`<00003FUH005YF00EJ
EP04001JEUYF000_Ool002eoo`80009JEP8002Aoo`<00003FUH005YF00=JEP<00003FUH005YF00=J
EP@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000XOol20006FUH01000FUIJEP00
;goo000]Ool400000eYF001oo`0DOol3000?Ool20005FUH00`00FUH0000500000eYF001JEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000/Ool00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo000]Ool20003FUH3000BOol5000@Ool20003FUH40005FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00;Goo00=JEP00FUH00UYF00@005YFFUH0015oo`D0019oo`<00003FUH005YF00MJEP03001J
EUYF00AJEPL000AJEP800003FUH0000000D000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002000/Ool200000eYF001JEP03
FUH00`00Oomoo`0/Ool002aoo`8000AJEP04001JEUYFFUH2000?Ool5000AOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH30006FUH40003FUH00`00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@002Yoo`8000AJEP03001o
ogoo02aoo`00;7oo0P0015YF00<005YFFUH00eYF0P003Woo0`0047oo0P001UYF00<005YFFUH015YF
1`001EYF00<005YFFUH01EYF00<005YFFUH00P0015YF00@005YFFUIJEP800004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P001EYF0P004Goo0`005Goo00<0
05YFFUH00UYF0P00;Goo000/Ool00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH00003000LOol2
0007FUH00`00FUIJEP040004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH500000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP00009JEP03001JEUYF00=JEP<000ioo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00
FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP03FUH5000EOol200000eYF001JEP05FUH400000eYF
001JEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP04FUH20003FUH20002FUH00`00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP03
001JEUYF008000aoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00QJEP@0011oo`03001JEUYF009JEP04001JEUYFFUH20002FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P000UYF00<005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH01@00FUIJEUYF
00001EYF0P002Woo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH035YF40001EYF00<005YF00000P0015YF00<005YF00001UYF10001EYF00@005YF
FUIJEP@000EJEP04001JEUYFFUH200001eYF001JEUYF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF00000eYF0P000UYF00<005YFFUH015YF0`002Goo0`0067oo0P00
00=JEP00Ool0;7oo000]Ool01@00FUIJEUYF00001UYF00<005YFFUH06UYF0P001EYF0P000UYF00@0
05YFOomJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<00003
FUH00000009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEUYF009JEP05001JEP00FUH00005FUH20002FUH2000SOol00`00FUH0000]Ool002eoo`05001J
EUYFFUH00006FUH00`00FUIJEP04FUH00`00FUIJEP0CFUH20004FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH025YF2@0000=JEP0000000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0P001EYF00<005YFFUH00UYF00<007ooOol08Goo0P00;Woo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00@005YFFUIoo`EJEP03001JEUYF00UJEP05001JEUYF001JEP020005FUH00`00FUH00003
00000eYF001JEP05FUH50004FUH00`00FUIJEP09FUH300000eYF001JEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000QOol3000^Ool002moo`03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00/00006FUH00000001JEP00
1UYF10001EYF00<005YFFUH025YF0P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP80009JEP07001J
EUYFFUH005YF000087oo00@005YF000002ioo`00<7oo0P001EYF00<005YFFUH01EYF00D005YFFUIJ
EWoo00AJEP04001JEUYFFUH90002FUH20006FUH5000015YF001JEP001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`001UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YF001JEP0000IJEP03001JEP00008000=JEP80021oo`03001JEUYF
008002ioo`00<Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH00UYF00<005YF00001UYF00<005YFFUH01UYF
00@005YFFUIJEP@00003FUH005YF00IJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEP00FUH00006FUH01000FUIJEUYF0`0000=JEP0000003goo
4`0000=JEP000000;Woo000bOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00AJEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEP00008002ioo`00<goo0P000UYF00@005YFFUIJEPH000IJEP03001JEUYF
00IJEPH0009JEP@000IJEP06001JEUYF001JEP001UYF00@005YFFUIJEP@0009JEP03001JEUYF00IJ
EP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF00001EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01P000eYF00@005YF0000009JEP03001JEUYF00L0009JEP03001JEP0000=JEPL000IJEP03001J
EUYF00IJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000bOol300000eYF001JEP06
FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUH00002FUH00`00FUIJEP03FUH01000FUIJ
EUYF200015YF00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002moo`<000AJEP8000IJEP@00004FUH000000005FUH00`00FUIJEP06FUH00`00FUH0
0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP040003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000eYF00D005YFFUIJEP0002eoo`00;7oo4P0015YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00AJEPD000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ8000IJEPP002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00@005YFFUIJ
EQ<000AJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00D0
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP@000EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP<00003FUH005YF00EJEP03001J
EUYF009JEPL000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH01000FUIJEUYF200025YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF0`00;Woo000]Ool00`00FUH00003FUH0
0`00FUH0000300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF
00<005YF000030000UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000=JEP<0
00UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPH0035oo`00;Goo00<005YF0000
0eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009J
EP04001JEUYFFUH500000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000
00001EYF00<005YFFUH00eYF0`001UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
03Moo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEUYF00EJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00000iOol002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHA0004FUH00`00
FUIJEP06FUH30006Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP02FUH5000kOol002eoo`8000=JEP03001JEUYF00=J
EPH000EJEP03001JEUYF00IJEP03001JEUYF00H000MJEP03001JEUYF008000Aoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000@00003FUH0000000h000Moo`T0041oo`00;Goo0P000eYF00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0017oo0P0015YF00<005YFFUH00eYF
0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<0
05YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000017oo0`000eYF1000
0UYF00<007ooOol0DWoo000]Ool20003FUH30006FUH00`00FUIJEP02FUH8000?Ool300001EYF001J
EUYFOol00eYF0P0000Aoo`00FUH000IJEP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEPH000IJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP04001JEUYF
001DOol002aoo`03001JEP00009JEP04001JEUYF0003FUH8000JOol20006FUH2000017oo001JEP00
1EYF10000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00eYF10000UYF00<005YFFUH00UYF00<005YF00000goo00D005YFFUIJEP0000EJEP04001J
EUYF001DOol002aoo`03001JEP0000T002Aoo`8000=JEP03001JEUYF00800003FUH005YF009JEP80
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP<000AJEP04001JEP00Ool20004FUH00`00FUIJEP03FUH00`00FUH0001EOol002aoo`03001J
EP0002moo`800003FUH005YF009JEP04001JEP00FUH30008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH01000FUH0
00001eYF00<005YFFUH00eYF0P00EGoo000/Ool2000bOol20003FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF00<005YFFUH00eYF00<007ooOol0E7oo000/
Ool2000JOol3000GOol00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000015YF
001JEP001eYF00D005YFFUIJEP0005Moo`00;7oo0`0067oo1@005goo00@005YF000000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP800004FUH005YF0007FUH01000FUIJEP00F7oo000/Ool200000eYF
001oo`0FOol5000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000QJ
EP8005Uoo`00;7oo0P000UYF00<007ooOol057oo1@006Goo0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00Oomoo`1HOol002eoo`05001JEUYFFUH0000FOol3000J
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF0P00
Fgoo000]Ool01000FUIJEUYF0`00<7oo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000eYF00<005YFFUH00UYF00<007ooOol0Fgoo000^Ool01000FUIJEP000UYF0P00;Goo0P0000=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00D005YFFUIJEP0005ioo`00;Woo
00<005YF00001EYF0`00:7oo0P0000=JEP00FUH00`000UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
0P0000=JEP0000001@00Ggoo000_Ool20006FUH01000FUH0000097oo0P000eYF0P000goo0`0025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP800003FUH005YF00AJEP<005moo`00<7oo00<005YFFUH015YF00@005YFFUIJEP<0
01moo`800003FUH005YF009JEP8000Eoo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP06FUH3001M
Ool0035oo`8000=JEP03001JEUYF00EJEPD001Qoo`8000=JEP05001JEUYFFUH00008Ool30004FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
0004FUH00`00FUIJEP06FUH00`00FUIJEP02001KOol003=oo`800003FUH005YF00MJEP04001JEUYF
FUH90009Ool60004FUH00`00FUIJEP02000<Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP060003FUH60006FUH00`00FUIJEP03FUH2001IOol0
03Eoo`<000MJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00=JEP<0015oo`@0
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009JEPD000AJEP<00003Ool0
000000AJEP03001JEUYF00AJEP<005Moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P005goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000MJEPD0009JEP8000Ioo`<00003FUH005YF00EJEP04001JEUYF001FOol003Yo
o`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<001mooal000EJ
EP03001JEUYF00EJEPL000]oo`<000AJEP05001JEUYFFUH0001FOol003eoo`H000AJEP03001JEUYF
00IJEP03001JEUYF009JEPD003Uoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0015oo`<0
0003FUH005YF009JEP8005Eoo`00@goo4P00@7oo0`000eYF00<005YFFUH015YF00<005YFFUH01@00
0eYF2@002goo0P000UYF00<005YF0000EGoo002HOol=0003FUH20007FUH00`00FUIJEP02FUH@0000
0eYF001oo`1DOol009]oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8005Ioo`00WWoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00Y7oo1`001UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF0000EWoo002[Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH2001GOol00:mooaH005Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59194 .73798 m .60486 .68261 L .57449 .6745 L p .707 .577 .707 r
F P
0 g
s
.60486 .68261 m .59194 .73798 L .62297 .74451 L p .707 .577 .707 r
F P
0 g
s
.62297 .74451 m .63589 .68913 L .60486 .68261 L p .707 .577 .707 r
F P
0 g
s
.63589 .68913 m .62297 .74451 L .65162 .74881 L p .707 .577 .707 r
F P
0 g
s
.65162 .74881 m .66454 .69343 L .63589 .68913 L p .707 .577 .707 r
F P
0 g
s
.56156 .72987 m .57449 .6745 L .54774 .66559 L p .707 .577 .707 r
F P
0 g
s
.57449 .6745 m .56156 .72987 L .59194 .73798 L p .707 .577 .707 r
F P
0 g
s
.54774 .66559 m .53482 .72097 L .56156 .72987 L p .707 .577 .707 r
F P
0 g
s
.66454 .69343 m .65162 .74881 L .67508 .75046 L p .707 .577 .707 r
F P
0 g
s
.67508 .75046 m .688 .69508 L .66454 .69343 L p .707 .577 .707 r
F P
0 g
s
.53482 .72097 m .54774 .66559 L .52724 .65677 L p .707 .577 .707 r
F P
0 g
s
.6319 .81338 m .61939 .78005 L .58924 .79049 L p .707 .577 .707 r
F P
0 g
s
.61939 .78005 m .6319 .81338 L .65989 .79973 L p .707 .577 .707 r
F P
0 g
s
.65989 .79973 m .64738 .76639 L .61939 .78005 L p .707 .577 .707 r
F P
0 g
s
.60175 .82382 m .58924 .79049 L .55989 .79669 L p .707 .577 .707 r
F P
0 g
s
.58924 .79049 m .60175 .82382 L .6319 .81338 L p .707 .577 .707 r
F P
0 g
s
.64738 .76639 m .65989 .79973 L .68298 .7842 L p .707 .577 .707 r
F P
0 g
s
.68298 .7842 m .67047 .75086 L .64738 .76639 L p .707 .577 .707 r
F P
0 g
s
.52724 .65677 m .51432 .71215 L .53482 .72097 L p .707 .577 .707 r
F P
0 g
s
.59139 .84379 m .59368 .83066 L p .56389 .81866 L .707 .577 .707 r
F P
0 g
s
.5853 .82322 m .56389 .81866 L p .59368 .83066 L .707 .577 .707 r
F P
0 g
s
.56389 .81866 m .56065 .83725 L .59139 .84379 L p .707 .577 .707 r
F P
0 g
s
.56065 .83725 m .56237 .82737 L p .5368 .8109 L .707 .577 .707 r
F P
0 g
s
.56237 .82737 m .56389 .81866 L .54945 .81453 L p .707 .577 .707 r
F P
0 g
s
.54945 .81453 m .5368 .8109 L p .56237 .82737 L .707 .577 .707 r
F P
0 g
s
.5368 .8109 m .53356 .82948 L .56065 .83725 L p .707 .577 .707 r
F P
0 g
s
.53356 .82948 m .5368 .8109 L .51601 .80267 L p .707 .577 .707 r
F P
0 g
s
.54672 .83139 m .53498 .80014 L p .5147 .79444 L .707 .577 .707 r
F P
0 g
s
.53498 .80014 m .5342 .79806 L .53258 .79776 L p .707 .577 .707 r
F P
0 g
s
.53258 .79776 m .5147 .79444 L p .53498 .80014 L .707 .577 .707 r
F P
0 g
s
.5724 .83003 m .56213 .80267 L p .5342 .79806 L .707 .577 .707 r
F P
0 g
s
.56213 .80267 m .55989 .79669 L .55564 .79692 L p .707 .577 .707 r
F P
0 g
s
.55564 .79692 m .5342 .79806 L p .56213 .80267 L .707 .577 .707 r
F P
0 g
s
.59368 .83066 m .59463 .82521 L .5853 .82322 L p .707 .577 .707 r
F P
0 g
s
.59463 .82521 m .59139 .84379 L .62276 .84847 L p .707 .577 .707 r
F P
0 g
s
.62276 .84847 m .62601 .82989 L .59463 .82521 L p .707 .577 .707 r
F P
0 g
s
.55989 .79669 m .5724 .83003 L .60175 .82382 L p .707 .577 .707 r
F P
0 g
s
.62601 .82989 m .62276 .84847 L .65171 .85083 L p .707 .577 .707 r
F P
0 g
s
.65171 .85083 m .65495 .83224 L .62601 .82989 L p .707 .577 .707 r
F P
0 g
s
.688 .69508 m .67508 .75046 L .68325 .74987 L p .707 .577 .707 r
F P
0 g
s
.69082 .74507 m .688 .69508 L .68406 .74058 L .707 .577 .707 r
F
.69031 .74539 m .68406 .74058 L .68325 .74987 L F
.69082 .74507 m .68406 .74058 L .69031 .74539 L F
.69892 .76832 m .70474 .75648 L p .69172 .74647 L F P
0 g
s
.69031 .74539 m .69105 .74735 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69105 .74735 m .69892 .76832 L p .69172 .74647 L .707 .577 .707 r
F P
0 g
s
.69898 .7369 m .69915 .7355 L .69172 .74647 L .707 .577 .707 r
F
.70398 .69393 m .69553 .73015 L p .69915 .7355 L F P
0 g
s
.69553 .73015 m .69172 .74647 L p .69915 .7355 L .707 .577 .707 r
F P
0 g
s
.69892 .76832 m .69031 .74539 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69106 .74931 m .70398 .69393 L .688 .69508 L p .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .70419 .74296 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .70016 .7377 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.70016 .7377 m .70614 .75363 L p .70001 .73679 L .707 .577 .707 r
F P
0 g
s
.69362 .72029 m .68641 .73498 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70614 .75363 m .69957 .73613 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.69985 .73576 m .69943 .73309 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69957 .73613 m .69362 .72029 L p .69458 .7427 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69985 .73576 L p .69799 .74546 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .69985 .73576 L .69898 .7369 L .707 .577 .707 r
F
.70071 .72202 m .71091 .69009 L .70398 .69393 L p F P
0 g
s
.69362 .72029 m .69681 .72877 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69681 .72877 m .69957 .73613 L p .69742 .72812 L .707 .577 .707 r
F P
0 g
s
.69868 .72838 m .69947 .72593 L .70001 .73679 L .707 .577 .707 r
F
.70358 .72151 m .70001 .73679 L p .69947 .72593 L F P
0 g
s
.70812 .68392 m .71091 .69009 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.69999 .73666 m .69742 .72812 L .69957 .73613 L .707 .577 .707 r
F
.69924 .73188 m .69742 .72812 L .69999 .73666 L F
.6983 .72599 m .70812 .68392 L p .69868 .72838 L F P
0 g
s
.69142 .70824 m .69362 .72029 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .699 .72843 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .69142 .70824 L p .70104 .73561 L .707 .577 .707 r
F P
0 g
s
.69142 .70824 m .69846 .72701 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.6952 .7393 m .68295 .73142 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69457 .7249 L .6952 .7393 L .707 .577 .707 r
F
.69206 .7229 m .69142 .70824 L .69793 .72758 L F
.69793 .72758 m .6952 .7393 L p .69457 .7249 L F P
0 g
s
.69255 .73336 m .69252 .73334 L p .69846 .72701 L .707 .577 .707 r
F P
0 g
s
.6983 .72599 m .69793 .72758 L p .69394 .71068 L .707 .577 .707 r
F P
0 g
s
.69394 .71068 m .69793 .72758 L .69457 .7249 L .707 .577 .707 r
F
.6952 .7393 m .6983 .72599 L p .69868 .72838 L F P
0 g
s
.70394 .74158 m .69924 .73188 L .69999 .73666 L .707 .577 .707 r
F
.68325 .74987 m .69106 .74931 L p .69086 .74581 L F P
0 g
s
.69086 .74581 m .69082 .74507 L .69031 .74539 L .707 .577 .707 r
F
.69086 .74581 m .69031 .74539 L .68325 .74987 L F
.68641 .73498 m .69031 .74539 L p .69191 .74622 L F P
0 g
s
.70614 .75363 m .69458 .7427 L .69191 .74622 L .707 .577 .707 r
F
.69458 .7427 m .68641 .73498 L .69191 .74622 L F
.70474 .75648 m .70614 .75363 L p .69031 .74539 L F P
0 g
s
.69106 .74931 m .69799 .74546 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69172 .74647 m .69106 .74931 L p .69898 .7369 L .707 .577 .707 r
F P
0 g
s
.69799 .74546 m .6952 .7393 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70419 .74296 m .70394 .74158 L p .69957 .73613 L .707 .577 .707 r
F P
0 g
s
.70001 .73679 m .69799 .74546 L p .69868 .72838 L .707 .577 .707 r
F P
0 g
s
.70394 .74158 m .69255 .73336 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69846 .72701 m .699 .72843 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.699 .72843 m .70394 .74158 L p .69793 .72758 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .69206 .7229 L .69793 .72758 L .707 .577 .707 r
F
.68001 .7 m .69142 .70824 L p .69206 .7229 L F P
0 g
s
.68295 .73142 m .68569 .71969 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68001 .7 m .68713 .71897 L p .68569 .71969 L .707 .577 .707 r
F P
0 g
s
.68295 .73142 m .66246 .7226 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68295 .73142 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.67401 .72551 m .67619 .71625 L .68569 .71969 L .707 .577 .707 r
F
.67619 .71625 m .68001 .7 L .68569 .71969 L F
.68713 .71897 m .68001 .7 L p .69206 .7229 L F P
0 g
s
.6605 .69639 m .68001 .7 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .66449 .71388 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.6605 .69639 m .66667 .71281 L p .66449 .71388 L .707 .577 .707 r
F P
0 g
s
.66246 .7226 m .63571 .7137 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66246 .7226 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.65143 .72031 m .65458 .71201 L .66449 .71388 L .707 .577 .707 r
F
.65458 .71201 m .6605 .69639 L .66449 .71388 L F
.66667 .71281 m .6605 .69639 L p .67619 .71625 L F P
0 g
s
.63482 .69776 m .6605 .69639 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.63571 .7137 m .63639 .71079 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63482 .69776 m .63907 .70908 L p .63639 .71079 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63571 .7137 L .61845 .70909 L p .707 .577 .707 r
F P
0 g
s
.62661 .71703 m .62954 .71014 L .63639 .71079 L .707 .577 .707 r
F
.62954 .71014 m .63482 .69776 L .63639 .71079 L F
.63907 .70908 m .63482 .69776 L p .65458 .71201 L F P
0 g
s
.60547 .70396 m .63482 .69776 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .60825 .71137 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.60825 .71137 m .60547 .70396 L p .62263 .72638 L .707 .577 .707 r
F P
0 g
s
.61798 .7373 m .58783 .74774 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60547 .70396 m .60698 .708 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.60698 .708 m .61798 .7373 L p .60153 .71373 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .64681 .66611 L p .60534 .70559 L .707 .577 .707 r
F P
0 g
s
.64681 .66611 m .63639 .71079 L p .60873 .70616 L .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .64681 .66611 L .60873 .70616 L .707 .577 .707 r
F
.58783 .74774 m .57532 .7144 L .60547 .70396 L p F P
0 g
s
.61826 .65021 m .60534 .70559 L .60204 .7049 L p .707 .577 .707 r
F P
0 g
s
.60204 .7049 m .57431 .69906 L p .58503 .68714 L .707 .577 .707 r
F P
0 g
s
.58503 .68714 m .61826 .65021 L .60204 .7049 L .707 .577 .707 r
F
.61845 .70909 m .60534 .70559 L p .63639 .71079 L F P
0 g
s
.63639 .71079 m .63688 .70867 L p .63907 .70908 L .707 .577 .707 r
F P
0 g
s
.63639 .71079 m .63907 .70908 L .63957 .70918 L .707 .577 .707 r
F
.64733 .7311 m .61798 .7373 L p .62661 .71703 L F P
0 g
s
.63907 .70908 m .64733 .7311 L p .62661 .71703 L .707 .577 .707 r
F P
0 g
s
.64733 .7311 m .63907 .70908 L p .65458 .71201 L .707 .577 .707 r
F P
0 g
s
.64863 .65832 m .67538 .66722 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.63688 .70867 m .64863 .65832 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .66449 .71388 L p .63957 .70918 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66489 .71217 L p .66667 .71281 L .707 .577 .707 r
F P
0 g
s
.66449 .71388 m .66667 .71281 L .6689 .71362 L .707 .577 .707 r
F
.67302 .72973 m .64733 .7311 L p .65143 .72031 L F P
0 g
s
.66667 .71281 m .67302 .72973 L p .65143 .72031 L .707 .577 .707 r
F P
0 g
s
.67302 .72973 m .66667 .71281 L p .67619 .71625 L .707 .577 .707 r
F P
0 g
s
.67538 .66722 m .69588 .67604 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.66489 .71217 m .67538 .66722 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .68569 .71969 L p .6689 .71362 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68606 .71812 L p .68713 .71897 L .707 .577 .707 r
F P
0 g
s
.68569 .71969 m .68713 .71897 L .68883 .72033 L .707 .577 .707 r
F
.69252 .73334 m .67302 .72973 L p .67401 .72551 L F P
0 g
s
.68713 .71897 m .69252 .73334 L p .67401 .72551 L .707 .577 .707 r
F P
0 g
s
.69252 .73334 m .68713 .71897 L p .69206 .7229 L .707 .577 .707 r
F P
0 g
s
.69588 .67604 m .70812 .68392 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68606 .71812 m .69588 .67604 L p .68883 .72033 L .707 .577 .707 r
F P
0 g
s
.68883 .72033 m .69394 .71068 L .69457 .7249 L .707 .577 .707 r
F
.70812 .68392 m .6983 .72599 L p .69394 .71068 L F P
0 g
s
.71091 .69009 m .70358 .72151 L p .69947 .72593 L .707 .577 .707 r
F P
0 g
s
.68641 .73498 m .67047 .75086 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.69031 .74539 m .68641 .73498 L p .67618 .75436 L .707 .577 .707 r
F P
0 g
s
.51432 .71215 m .52724 .65677 L .515 .64889 L p .707 .577 .707 r
F P
0 g
s
.67047 .75086 m .68298 .7842 L .69892 .76832 L p .707 .577 .707 r
F P
0 g
s
.5342 .79806 m .54672 .83139 L .5724 .83003 L p .707 .577 .707 r
F P
0 g
s
.65495 .83224 m .65171 .85083 L .67538 .85063 L p .707 .577 .707 r
F P
0 g
s
.67538 .85063 m .67862 .83205 L .65495 .83224 L p .707 .577 .707 r
F P
0 g
s
.515 .64889 m .50208 .70427 L .51432 .71215 L p .707 .577 .707 r
F P
0 g
s
.51601 .80267 m .51277 .82125 L .53356 .82948 L p .707 .577 .707 r
F P
0 g
s
.5147 .79444 m .52721 .82778 L .54672 .83139 L p .707 .577 .707 r
F P
0 g
s
.50208 .70427 m .515 .64889 L .51221 .64273 L p .707 .577 .707 r
F P
0 g
s
.67862 .83205 m .67538 .85063 L .69147 .84791 L p .707 .577 .707 r
F P
0 g
s
.69147 .84791 m .69472 .82932 L .67862 .83205 L p .707 .577 .707 r
F P
0 g
s
.51277 .82125 m .51601 .80267 L .50356 .79478 L p .707 .577 .707 r
F P
0 g
s
.52721 .82778 m .5147 .79444 L .50328 .78621 L p .707 .577 .707 r
F P
0 g
s
.51221 .64273 m .49929 .69811 L .50208 .70427 L p .707 .577 .707 r
F P
0 g
s
.50356 .79478 m .50031 .81337 L .51277 .82125 L p .707 .577 .707 r
F P
0 g
s
.50328 .78621 m .5158 .81955 L .52721 .82778 L p .707 .577 .707 r
F P
0 g
s
.49323 .82188 m .49323 .31999 L .44904 .31754 L p .707 .577 .707 r
F P
0 g
s
.49929 .69811 m .51221 .64273 L .51914 .63888 L p .707 .577 .707 r
F P
0 g
s
.50031 .81337 m .50356 .79478 L .50065 .78801 L p .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50328 .78621 L .50162 .7771 L p .707 .577 .707 r
F P
0 g
s
.50162 .7771 m .50108 .77416 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5158 .81955 m .50162 .7771 L .50245 .77838 L .707 .577 .707 r
F
.50065 .78801 m .49741 .8066 L .50031 .81337 L p F P
0 g
s
.5136 .8075 m .5158 .81955 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50108 .77416 m .50296 .77918 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.50296 .77918 m .5136 .8075 L p .50245 .77838 L .707 .577 .707 r
F P
0 g
s
.5136 .8075 m .50108 .77416 L .5083 .75947 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .49741 .8066 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50759 .78302 m .50713 .78562 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.50713 .78562 m .50434 .8016 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50065 .78801 L .50613 .78407 L p .707 .577 .707 r
F P
0 g
s
.50613 .78407 m .50759 .78302 L p .50673 .785 L .707 .577 .707 r
F P
0 g
s
.49741 .8066 m .50613 .78407 L .50673 .785 L .707 .577 .707 r
F
.51914 .63888 m .50622 .69426 L .49929 .69811 L p F P
0 g
s
.50622 .69426 m .51914 .63888 L .53512 .63773 L p .707 .577 .707 r
F P
0 g
s
.53512 .63773 m .5222 .69311 L .50622 .69426 L p .707 .577 .707 r
F P
0 g
s
.5083 .75947 m .52081 .79281 L .5136 .8075 L p .707 .577 .707 r
F P
0 g
s
.5222 .69311 m .53512 .63773 L .55858 .63939 L p .707 .577 .707 r
F P
0 g
s
.52081 .79281 m .5083 .75947 L .52423 .74359 L p .707 .577 .707 r
F P
0 g
s
.52423 .74359 m .53675 .77693 L .52081 .79281 L p .707 .577 .707 r
F P
0 g
s
.50434 .8016 m .50759 .78302 L .52368 .78029 L p .707 .577 .707 r
F P
0 g
s
.55858 .63939 m .54566 .69476 L .5222 .69311 L p .707 .577 .707 r
F P
0 g
s
.52368 .78029 m .52044 .79887 L .50434 .8016 L p .707 .577 .707 r
F P
0 g
s
.53675 .77693 m .52423 .74359 L .54733 .72806 L p .707 .577 .707 r
F P
0 g
s
.52044 .79887 m .52368 .78029 L .54735 .78009 L p .707 .577 .707 r
F P
0 g
s
.54735 .78009 m .54411 .79868 L .52044 .79887 L p .707 .577 .707 r
F P
0 g
s
.49323 .31999 m .49323 .82188 L .53809 .82055 L p .707 .577 .707 r
F P
0 g
s
.54733 .72806 m .55984 .7614 L .53675 .77693 L p .707 .577 .707 r
F P
0 g
s
.53809 .82055 m .53809 .31866 L .49323 .31999 L p .707 .577 .707 r
F P
0 g
s
.69472 .82932 m .69147 .84791 L .69841 .84291 L p .707 .577 .707 r
F P
0 g
s
.69841 .84291 m .70165 .82433 L .69472 .82932 L p .707 .577 .707 r
F P
0 g
s
.54566 .69476 m .55858 .63939 L .58723 .64369 L p .707 .577 .707 r
F P
0 g
s
.58723 .64369 m .57431 .69906 L .54566 .69476 L p .707 .577 .707 r
F P
0 g
s
.55984 .7614 m .54733 .72806 L .57532 .7144 L p .707 .577 .707 r
F P
0 g
s
.57532 .7144 m .58783 .74774 L .55984 .7614 L p .707 .577 .707 r
F P
0 g
s
.54411 .79868 m .54735 .78009 L .5763 .78245 L p .707 .577 .707 r
F P
0 g
s
.5763 .78245 m .57305 .80104 L .54411 .79868 L p .707 .577 .707 r
F P
0 g
s
.57305 .80104 m .5763 .78245 L .60767 .78713 L p .707 .577 .707 r
F P
0 g
s
.60767 .78713 m .60443 .80572 L .57305 .80104 L p .707 .577 .707 r
F P
0 g
s
.53809 .31866 m .53809 .82055 L .57922 .81556 L p .707 .577 .707 r
F P
0 g
s
.57431 .69906 m .58723 .64369 L .61826 .65021 L p .707 .577 .707 r
F P
0 g
s
.57922 .81556 m .57922 .31368 L .53809 .31866 L p .707 .577 .707 r
F P
0 g
s
.44904 .81943 m .44904 .31754 L .40983 .31154 L p .707 .577 .707 r
F P
0 g
s
.44904 .31754 m .44904 .81943 L .49323 .82188 L p .707 .577 .707 r
F P
0 g
s
.60534 .70559 m .61826 .65021 L .64863 .65832 L p .707 .577 .707 r
F P
0 g
s
.63841 .79367 m .63517 .81226 L .60443 .80572 L p .707 .577 .707 r
F P
0 g
s
.60443 .80572 m .60767 .78713 L .63841 .79367 L p .707 .577 .707 r
F P
0 g
s
.57922 .31368 m .57922 .81556 L .61259 .80741 L p .707 .577 .707 r
F P
0 g
s
.61259 .80741 m .61259 .30552 L .57922 .31368 L p .707 .577 .707 r
F P
0 g
s
.40983 .81343 m .40983 .31154 L .37945 .30259 L p .707 .577 .707 r
F P
0 g
s
.40983 .31154 m .40983 .81343 L .44904 .81943 L p .707 .577 .707 r
F P
0 g
s
.25765 .68094 m .22657 .675 L p .2463 .71874 L .707 .577 .707 r
F P
0 g
s
.24811 .72276 m .24871 .72012 L .2463 .71874 L .707 .577 .707 r
F
.24871 .72012 m .25765 .68094 L .2463 .71874 L F
.25297 .72295 m .25765 .68094 L p .24811 .72276 L F P
0 g
s
.28785 .7367 m .27163 .72196 L .25372 .72298 L .707 .577 .707 r
F
.25372 .72298 m .25634 .74107 L .27967 .73783 L p F P
0 g
s
.27967 .73783 m .28785 .7367 L p .25372 .72298 L .707 .577 .707 r
F P
0 g
s
.25634 .74107 m .25372 .72298 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.24284 .72879 m .25297 .72295 L .23567 .72226 L .707 .577 .707 r
F
.25634 .74107 m .25297 .72295 L .24284 .72879 L F
.25366 .72256 m .25372 .72298 L p .27163 .72196 L F P
0 g
s
.25301 .72258 m .25297 .72295 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .25634 .74107 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .22549 .74597 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.22657 .675 m .19913 .66493 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22549 .74597 m .22205 .72225 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22197 .72171 L p .22132 .72216 L .707 .577 .707 r
F P
0 g
s
.22205 .72225 m .22132 .72216 L .20984 .73015 L .707 .577 .707 r
F
.19913 .66493 m .1935 .71543 L .20683 .72031 L p F P
0 g
s
.20984 .73015 m .21392 .72122 L .19914 .71933 L .707 .577 .707 r
F
.21967 .72195 m .19913 .66493 L .20683 .72031 L F
.22132 .72216 m .22657 .675 L p .21967 .72195 L F P
0 g
s
.22657 .675 m .22137 .72169 L p .22197 .72171 L .707 .577 .707 r
F P
0 g
s
.22137 .72169 m .22095 .72549 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.22197 .72171 m .21997 .70797 L p .20984 .73015 L .707 .577 .707 r
F P
0 g
s
.20683 .72031 m .22095 .72549 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.22095 .72549 m .22132 .72216 L p .21967 .72195 L .707 .577 .707 r
F P
0 g
s
.1935 .71543 m .19913 .66493 L .178 .65173 L p .707 .577 .707 r
F P
0 g
s
.178 .65173 m .17398 .6878 L p .1935 .71543 L .707 .577 .707 r
F P
0 g
s
.17398 .6878 m .17237 .70222 L .18972 .71306 L p .707 .577 .707 r
F P
0 g
s
.18972 .71306 m .1935 .71543 L p .17398 .6878 L .707 .577 .707 r
F P
0 g
s
.19278 .7129 m .19374 .71952 L p .22549 .74597 L .707 .577 .707 r
F P
0 g
s
.19374 .71952 m .1983 .7509 L .21178 .74845 L p .707 .577 .707 r
F P
0 g
s
.21178 .74845 m .22549 .74597 L p .19374 .71952 L .707 .577 .707 r
F P
0 g
s
.21997 .70797 m .19278 .7129 L p .19914 .71933 L .707 .577 .707 r
F P
0 g
s
.21392 .72122 m .21997 .70797 L .19914 .71933 L .707 .577 .707 r
F
.24811 .72276 m .24151 .70811 L .22197 .72171 L F
.24151 .70811 m .22657 .675 L .22197 .72171 L F
.22095 .72549 m .25202 .73143 L p .24811 .72276 L F P
0 g
s
.21997 .70797 m .22197 .72171 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25297 .72295 m .25083 .70308 L .23567 .72226 L .707 .577 .707 r
F
.25372 .72298 m .25366 .72256 L p .25297 .72295 L F P
0 g
s
.25765 .68094 m .25301 .72258 L p .25366 .72256 L .707 .577 .707 r
F P
0 g
s
.25366 .72256 m .25083 .70308 L p .25297 .72295 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .27299 .71142 L .25366 .72256 L .707 .577 .707 r
F
.27299 .71142 m .25765 .68094 L .25366 .72256 L F
.28931 .68217 m .25765 .68094 L p .27574 .71689 L F P
0 g
s
.27819 .72175 m .27911 .71846 L .27574 .71689 L .707 .577 .707 r
F
.27911 .71846 m .28931 .68217 L .27574 .71689 L F
.28493 .72153 m .28931 .68217 L p .27819 .72175 L F P
0 g
s
.31692 .73326 m .30287 .71923 L .28564 .7215 L .707 .577 .707 r
F
.28564 .7215 m .28785 .7367 L .3121 .73383 L p F P
0 g
s
.3121 .73383 m .31692 .73326 L p .28564 .7215 L .707 .577 .707 r
F P
0 g
s
.28785 .7367 m .28564 .7215 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.27672 .72659 m .28493 .72153 L .27163 .72196 L .707 .577 .707 r
F
.28785 .7367 m .28493 .72153 L .27672 .72659 L F
.28559 .72112 m .28564 .7215 L p .30287 .71923 L F P
0 g
s
.28496 .72119 m .28493 .72153 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28493 .72153 m .28233 .6987 L .27163 .72196 L .707 .577 .707 r
F
.28564 .7215 m .28559 .72112 L p .28493 .72153 L F P
0 g
s
.28931 .68217 m .28496 .72119 L p .28559 .72112 L .707 .577 .707 r
F P
0 g
s
.28559 .72112 m .28233 .6987 L p .28493 .72153 L .707 .577 .707 r
F P
0 g
s
.30763 .7187 m .30334 .71015 L .28559 .72112 L .707 .577 .707 r
F
.30334 .71015 m .28931 .68217 L .28559 .72112 L F
.31846 .67859 m .28931 .68217 L p .30763 .7187 L F P
0 g
s
.3114 .69527 m .28233 .6987 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31469 .71793 L p .31407 .718 L .707 .577 .707 r
F P
0 g
s
.31692 .73326 m .31407 .718 L .30718 .72353 L .707 .577 .707 r
F
.31692 .73326 m .3407 .73111 L p .32741 .71485 L F P
0 g
s
.33344 .71358 m .3299 .70531 L .32227 .71594 L .707 .577 .707 r
F
.31846 .67859 m .31411 .71766 L p .3299 .70531 L F P
0 g
s
.31411 .71766 m .31407 .718 L p .31463 .71755 L .707 .577 .707 r
F P
0 g
s
.3299 .70531 m .31411 .71766 L .31463 .71755 L .707 .577 .707 r
F
.31463 .71755 m .31692 .73326 L p .32741 .71485 L F P
0 g
s
.31407 .718 m .31846 .67859 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.31469 .71793 m .3114 .69527 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.31407 .718 m .31283 .72908 L p .3299 .70531 L .707 .577 .707 r
F P
0 g
s
.3407 .73111 m .33802 .71262 L p .33754 .71272 L .707 .577 .707 r
F P
0 g
s
.33176 .72017 m .33754 .71272 L .32741 .71485 L .707 .577 .707 r
F
.3407 .73111 m .33754 .71272 L .33176 .72017 L F
.3407 .73111 m .35687 .73045 L p .34471 .70951 L F P
0 g
s
.352 .70662 m .34949 .69733 L .34236 .71044 L .707 .577 .707 r
F
.34224 .67052 m .33759 .71234 L p .34949 .69733 L F P
0 g
s
.33759 .71234 m .33754 .71272 L p .33795 .71219 L .707 .577 .707 r
F P
0 g
s
.34949 .69733 m .33759 .71234 L .33795 .71219 L .707 .577 .707 r
F
.33795 .71219 m .3407 .73111 L p .34471 .70951 L F P
0 g
s
.34224 .67052 m .31846 .67859 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .33754 .71272 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .34224 .67052 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33802 .71262 m .33518 .69311 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.33754 .71272 m .33662 .72101 L p .34949 .69733 L .707 .577 .707 r
F P
0 g
s
.35687 .73045 m .35334 .70609 L p .35305 .70621 L .707 .577 .707 r
F P
0 g
s
.34944 .71766 m .35305 .70621 L .34471 .70951 L .707 .577 .707 r
F
.35687 .73045 m .35305 .70621 L .34944 .71766 L F
.35687 .73045 m .36386 .73135 L p .35496 .70367 L F P
0 g
s
.35953 .69498 m .35925 .68651 L .35402 .7047 L .707 .577 .707 r
F
.35585 .70268 m .35953 .69498 L p .35402 .7047 L F P
0 g
s
.35833 .65877 m .35311 .70571 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35311 .70571 m .35305 .70621 L p .35326 .70555 L .707 .577 .707 r
F P
0 g
s
.35925 .68651 m .35311 .70571 L .35326 .70555 L .707 .577 .707 r
F
.35326 .70555 m .35687 .73045 L p .35496 .70367 L F P
0 g
s
.35833 .65877 m .34224 .67052 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35305 .70621 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35833 .65877 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.35334 .70609 m .35136 .69245 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.35305 .70621 m .35271 .70927 L p .35925 .68651 L .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .35136 .69245 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.36386 .73135 m .35916 .69903 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35916 .69903 m .35834 .69335 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .35326 .70555 L p .35496 .70367 L .707 .577 .707 r
F P
0 g
s
.35271 .70927 m .35585 .70268 L p .35402 .7047 L .707 .577 .707 r
F P
0 g
s
.35136 .69245 m .33518 .69311 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33518 .69311 m .33795 .71219 L p .34471 .70951 L .707 .577 .707 r
F P
0 g
s
.33662 .72101 m .35271 .70927 L p .352 .70662 L .707 .577 .707 r
F P
0 g
s
.352 .70662 m .34236 .71044 L .33662 .72101 L .707 .577 .707 r
F
.33518 .69311 m .3114 .69527 L p .32741 .71485 L F P
0 g
s
.3114 .69527 m .31463 .71755 L p .32741 .71485 L .707 .577 .707 r
F P
0 g
s
.31283 .72908 m .33662 .72101 L p .33344 .71358 L .707 .577 .707 r
F P
0 g
s
.33344 .71358 m .32227 .71594 L .31283 .72908 L .707 .577 .707 r
F
.30718 .72353 m .31407 .718 L .30287 .71923 L F
.31283 .72908 m .31407 .718 L p .30763 .7187 L F P
0 g
s
.30763 .7187 m .28559 .72112 L .28369 .73267 L .707 .577 .707 r
F
.28493 .72153 m .28369 .73267 L p .28559 .72112 L F P
0 g
s
.28369 .73267 m .31283 .72908 L p .30763 .7187 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .28559 .72112 L p .30287 .71923 L .707 .577 .707 r
F P
0 g
s
.28233 .6987 m .25083 .70308 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.28369 .73267 m .28493 .72153 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.27819 .72175 m .25366 .72256 L .25202 .73143 L .707 .577 .707 r
F
.25297 .72295 m .25202 .73143 L p .25366 .72256 L F P
0 g
s
.25202 .73143 m .28369 .73267 L p .27819 .72175 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .25366 .72256 L p .27163 .72196 L .707 .577 .707 r
F P
0 g
s
.25083 .70308 m .21997 .70797 L p .23567 .72226 L .707 .577 .707 r
F P
0 g
s
.25202 .73143 m .25297 .72295 L p .24811 .72276 L .707 .577 .707 r
F P
0 g
s
.70165 .82433 m .69841 .84291 L .6955 .83614 L p .707 .577 .707 r
F P
0 g
s
.6955 .83614 m .69875 .81755 L .70165 .82433 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.61259 .30552 m .61259 .80741 L .63494 .79689 L p .707 .577 .707 r
F P
0 g
s
.63494 .79689 m .63494 .295 L .61259 .30552 L p .707 .577 .707 r
F P
0 g
s
.37945 .80447 m .37945 .30259 L .36087 .29155 L p .707 .577 .707 r
F P
0 g
s
.37945 .30259 m .37945 .80447 L .40983 .81343 L p .707 .577 .707 r
F P
0 g
s
.69875 .81755 m .6955 .83614 L .68305 .82825 L p .707 .577 .707 r
F P
0 g
s
.68305 .82825 m .68629 .80967 L .69875 .81755 L p .707 .577 .707 r
F P
0 g
s
.17237 .70222 m .178 .65173 L .16525 .63668 L p .707 .577 .707 r
F P
0 g
s
.17192 .71739 m .17744 .75538 L .1983 .7509 L p .707 .577 .707 r
F P
0 g
s
.1983 .7509 m .19278 .7129 L .17192 .71739 L p .707 .577 .707 r
F P
0 g
s
.25162 .82909 m .25302 .81173 L .22189 .80674 L p .707 .577 .707 r
F P
0 g
s
.25302 .81173 m .25162 .82909 L .28335 .82987 L p .707 .577 .707 r
F P
0 g
s
.28335 .82987 m .28476 .81252 L .25302 .81173 L p .707 .577 .707 r
F P
0 g
s
.28476 .81252 m .28335 .82987 L .31258 .82636 L p .707 .577 .707 r
F P
0 g
s
.31258 .82636 m .31398 .80901 L .28476 .81252 L p .707 .577 .707 r
F P
0 g
s
.22049 .82409 m .22189 .80674 L .19441 .79802 L p .707 .577 .707 r
F P
0 g
s
.22189 .80674 m .22049 .82409 L .25162 .82909 L p .707 .577 .707 r
F P
0 g
s
.63494 .295 m .63494 .79689 L .64409 .78503 L p .707 .577 .707 r
F P
0 g
s
.64409 .78503 m .64409 .28314 L .63494 .295 L p .707 .577 .707 r
F P
0 g
s
.19441 .79802 m .193 .81537 L .22049 .82409 L p .707 .577 .707 r
F P
0 g
s
.68629 .80967 m .68305 .82825 L .66226 .82002 L p .707 .577 .707 r
F P
0 g
s
.66226 .82002 m .6655 .80144 L .68629 .80967 L p .707 .577 .707 r
F P
0 g
s
.35953 .69498 m .36516 .64449 L .35833 .65877 L p .707 .577 .707 r
F P
0 g
s
.31398 .80901 m .31258 .82636 L .33644 .8189 L p .707 .577 .707 r
F P
0 g
s
.33644 .8189 m .33784 .80155 L .31398 .80901 L p .707 .577 .707 r
F P
0 g
s
.15963 .68718 m .16525 .63668 L .16214 .62126 L p .707 .577 .707 r
F P
0 g
s
.16525 .63668 m .15963 .68718 L .17237 .70222 L p .707 .577 .707 r
F P
0 g
s
.193 .81537 m .19441 .79802 L .17326 .78642 L p .707 .577 .707 r
F P
0 g
s
.15943 .72099 m .16495 .75899 L .17744 .75538 L p .707 .577 .707 r
F P
0 g
s
.17744 .75538 m .17192 .71739 L .15943 .72099 L p .707 .577 .707 r
F P
0 g
s
.36516 .64449 m .35953 .69498 L .35642 .67956 L p .707 .577 .707 r
F P
0 g
s
.35642 .67956 m .36204 .62907 L .36516 .64449 L p .707 .577 .707 r
F P
0 g
s
.35946 .79538 m .36087 .77802 L .35399 .79087 L p .707 .577 .707 r
F P
0 g
s
.36204 .62907 m .35642 .67956 L .34367 .66451 L p .707 .577 .707 r
F P
0 g
s
.34367 .66451 m .3493 .61402 L .36204 .62907 L p .707 .577 .707 r
F P
0 g
s
.35834 .69335 m .36386 .73135 L .36096 .73371 L p .707 .577 .707 r
F P
0 g
s
.36096 .73371 m .35544 .69571 L .35834 .69335 L p .707 .577 .707 r
F P
0 g
s
.36087 .77802 m .35946 .79538 L .35638 .78161 L p .707 .577 .707 r
F P
0 g
s
.35638 .78161 m .35778 .76426 L .36087 .77802 L p .707 .577 .707 r
F P
0 g
s
.35544 .69571 m .36096 .73371 L .34847 .73731 L p .707 .577 .707 r
F P
0 g
s
.36087 .79344 m .36087 .29155 L .35591 .27951 L p .707 .577 .707 r
F P
0 g
s
.36087 .29155 m .36087 .79344 L .37945 .80447 L p .707 .577 .707 r
F P
0 g
s
.17326 .78642 m .17185 .80378 L .193 .81537 L p .707 .577 .707 r
F P
0 g
s
.33784 .80155 m .33644 .8189 L .35259 .80823 L p .707 .577 .707 r
F P
0 g
s
.35259 .80823 m .35399 .79087 L .33784 .80155 L p .707 .577 .707 r
F P
0 g
s
.6655 .80144 m .66226 .82002 L .63517 .81226 L p .707 .577 .707 r
F P
0 g
s
.63517 .81226 m .63841 .79367 L .6655 .80144 L p .707 .577 .707 r
F P
0 g
s
.17185 .80378 m .17326 .78642 L .16052 .77309 L p .707 .577 .707 r
F P
0 g
s
.16214 .62126 m .15651 .67176 L .15963 .68718 L p .707 .577 .707 r
F P
0 g
s
.15651 .67176 m .16214 .62126 L .16896 .60698 L p .707 .577 .707 r
F P
0 g
s
.16052 .77309 m .15911 .79045 L .17185 .80378 L p .707 .577 .707 r
F P
0 g
s
.15654 .72335 m .16205 .76135 L .16495 .75899 L p .707 .577 .707 r
F P
0 g
s
.16495 .75899 m .15943 .72099 L .15654 .72335 L p .707 .577 .707 r
F P
0 g
s
.64409 .28314 m .64409 .78503 L .63912 .773 L p .707 .577 .707 r
F P
0 g
s
.63912 .773 m .63912 .27111 L .64409 .28314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35399 .79087 m .35259 .80823 L .35946 .79538 L p .707 .577 .707 r
F P
0 g
s
.15911 .79045 m .16052 .77309 L .15743 .75933 L p .707 .577 .707 r
F P
0 g
s
.35778 .76426 m .35638 .78161 L .34364 .76828 L p .707 .577 .707 r
F P
0 g
s
.34364 .76828 m .34504 .75093 L .35778 .76426 L p .707 .577 .707 r
F P
0 g
s
.35591 .27951 m .35591 .7814 L .36087 .79344 L p .707 .577 .707 r
F P
0 g
s
.35591 .7814 m .35591 .27951 L .36505 .26766 L p .707 .577 .707 r
F P
0 g
s
.16896 .60698 m .16333 .65747 L .15651 .67176 L p .707 .577 .707 r
F P
0 g
s
.16333 .65747 m .16896 .60698 L .18505 .59523 L p .707 .577 .707 r
F P
0 g
s
.15743 .75933 m .15603 .77668 L .15911 .79045 L p .707 .577 .707 r
F P
0 g
s
.16352 .72425 m .16903 .76225 L .16205 .76135 L p .707 .577 .707 r
F P
0 g
s
.16205 .76135 m .15654 .72335 L .16352 .72425 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15603 .77668 m .15743 .75933 L .1643 .74648 L p .707 .577 .707 r
F P
0 g
s
.3493 .61402 m .34367 .66451 L .32254 .65131 L p .707 .577 .707 r
F P
0 g
s
.32254 .65131 m .32817 .60082 L .3493 .61402 L p .707 .577 .707 r
F P
0 g
s
.18505 .59523 m .17942 .64572 L .16333 .65747 L p .707 .577 .707 r
F P
0 g
s
.17942 .64572 m .18505 .59523 L .20883 .58717 L p .707 .577 .707 r
F P
0 g
s
.63912 .27111 m .63912 .773 L .62054 .76196 L p .707 .577 .707 r
F P
0 g
s
.62054 .76196 m .62054 .26007 L .63912 .27111 L p .707 .577 .707 r
F P
0 g
s
.1643 .74648 m .1629 .76383 L .15603 .77668 L p .707 .577 .707 r
F P
0 g
s
.34847 .73731 m .34295 .69932 L .35544 .69571 L p .707 .577 .707 r
F P
0 g
s
.36505 .76954 m .36505 .26766 L .38741 .25714 L p .707 .577 .707 r
F P
0 g
s
.36505 .26766 m .36505 .76954 L .35591 .7814 L p .707 .577 .707 r
F P
0 g
s
.17969 .72359 m .18521 .76159 L .16903 .76225 L p .707 .577 .707 r
F P
0 g
s
.16903 .76225 m .16352 .72425 L .17969 .72359 L p .707 .577 .707 r
F P
0 g
s
.32817 .60082 m .32254 .65131 L .2951 .64125 L p .707 .577 .707 r
F P
0 g
s
.2951 .64125 m .30072 .59076 L .32817 .60082 L p .707 .577 .707 r
F P
0 g
s
.20321 .63766 m .20883 .58717 L .23798 .58358 L p .707 .577 .707 r
F P
0 g
s
.20883 .58717 m .20321 .63766 L .17942 .64572 L p .707 .577 .707 r
F P
0 g
s
.1629 .76383 m .1643 .74648 L .18046 .73581 L p .707 .577 .707 r
F P
0 g
s
.30072 .59076 m .2951 .64125 L .26402 .63531 L p .707 .577 .707 r
F P
0 g
s
.26402 .63531 m .26964 .58482 L .30072 .59076 L p .707 .577 .707 r
F P
0 g
s
.23236 .63407 m .23798 .58358 L .26964 .58482 L p .707 .577 .707 r
F P
0 g
s
.23798 .58358 m .23236 .63407 L .20321 .63766 L p .707 .577 .707 r
F P
0 g
s
.18046 .73581 m .17906 .75316 L .1629 .76383 L p .707 .577 .707 r
F P
0 g
s
.34295 .69932 m .34847 .73731 L .32761 .7418 L p .707 .577 .707 r
F P
0 g
s
.26964 .58482 m .26402 .63531 L .23236 .63407 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .32209 .7038 L .34295 .69932 L p .707 .577 .707 r
F P
0 g
s
.62054 .26007 m .62054 .76196 L .59016 .75301 L p .707 .577 .707 r
F P
0 g
s
.59016 .75301 m .59016 .25112 L .62054 .26007 L p .707 .577 .707 r
F P
0 g
s
.20348 .72144 m .20899 .75943 L .18521 .76159 L p .707 .577 .707 r
F P
0 g
s
.18521 .76159 m .17969 .72359 L .20348 .72144 L p .707 .577 .707 r
F P
0 g
s
.34504 .75093 m .34364 .76828 L .32249 .75669 L p .707 .577 .707 r
F P
0 g
s
.32761 .7418 m .30042 .74673 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32209 .7038 m .32421 .7184 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32421 .7184 m .32761 .7418 L p .31916 .7096 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .32389 .73934 L .34188 .7492 L p .707 .577 .707 r
F P
0 g
s
.34188 .7492 m .34504 .75093 L p .34315 .75141 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .34188 .7492 L .34315 .75141 L .707 .577 .707 r
F
.38741 .25714 m .38741 .75902 L .36505 .76954 L p F P
0 g
s
.38741 .75902 m .38741 .25714 L .42078 .24898 L p .707 .577 .707 r
F P
0 g
s
.17906 .75316 m .18046 .73581 L .20432 .72835 L p .707 .577 .707 r
F P
0 g
s
.73598 .63577 m .73035 .57841 L .69928 .58113 L p .707 .577 .707 r
F P
0 g
s
.73035 .57841 m .73598 .63577 L .76764 .63253 L p .707 .577 .707 r
F P
0 g
s
.76764 .63253 m .76202 .57517 L .73035 .57841 L p .707 .577 .707 r
F P
0 g
s
.20432 .72835 m .20291 .7457 L .17906 .75316 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .2949 .70873 L .32209 .7038 L p .707 .577 .707 r
F P
0 g
s
.69928 .58113 m .7049 .63849 L .73598 .63577 L p .707 .577 .707 r
F P
0 g
s
.76202 .57517 m .76764 .63253 L .79679 .62907 L p .707 .577 .707 r
F P
0 g
s
.79679 .62907 m .79116 .57171 L .76202 .57517 L p .707 .577 .707 r
F P
0 g
s
.23254 .718 m .23806 .756 L .20899 .75943 L p .707 .577 .707 r
F P
0 g
s
.20899 .75943 m .20348 .72144 L .23254 .718 L p .707 .577 .707 r
F P
0 g
s
.7049 .63849 m .69928 .58113 L .67183 .58306 L p .707 .577 .707 r
F P
0 g
s
.30042 .74673 m .26956 .75162 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.2949 .70873 m .29609 .71691 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.29609 .71691 m .30042 .74673 L p .29219 .71333 L .707 .577 .707 r
F P
0 g
s
.32249 .75669 m .295 .74797 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32389 .73934 m .32366 .7422 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.32366 .7422 m .32249 .75669 L p .32136 .74009 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .29641 .73062 L .32389 .73934 L p .707 .577 .707 r
F P
0 g
s
.67183 .58306 m .67746 .64042 L .7049 .63849 L p .707 .577 .707 r
F P
0 g
s
.23806 .756 m .23277 .71959 L p .26405 .71363 L .707 .577 .707 r
F P
0 g
s
.23277 .71959 m .23254 .718 L .23577 .71756 L p .707 .577 .707 r
F P
0 g
s
.23577 .71756 m .26405 .71363 L p .23277 .71959 L .707 .577 .707 r
F P
0 g
s
.20291 .7457 m .20341 .7395 L p .23354 .72484 L .707 .577 .707 r
F P
0 g
s
.20341 .7395 m .20432 .72835 L .2232 .72608 L p .707 .577 .707 r
F P
0 g
s
.2232 .72608 m .23354 .72484 L p .20341 .7395 L .707 .577 .707 r
F P
0 g
s
.59016 .25112 m .59016 .75301 L .55096 .74701 L p .707 .577 .707 r
F P
0 g
s
.55096 .74701 m .55096 .24512 L .59016 .25112 L p .707 .577 .707 r
F P
0 g
s
.79116 .57171 m .79679 .62907 L .82057 .62575 L p .707 .577 .707 r
F P
0 g
s
.82057 .62575 m .81495 .56839 L .79116 .57171 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .26405 .71363 L .2949 .70873 L p .707 .577 .707 r
F P
0 g
s
.26956 .75162 m .23806 .756 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.26453 .71692 m .26956 .75162 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.295 .74797 m .26387 .74297 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29641 .73062 m .29591 .73677 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.29591 .73677 m .295 .74797 L p .29001 .73304 L .707 .577 .707 r
F P
0 g
s
.26405 .71363 m .26453 .71692 L p .26272 .71578 L .707 .577 .707 r
F P
0 g
s
.23354 .72484 m .23214 .74219 L .20291 .7457 L p .707 .577 .707 r
F P
0 g
s
.42078 .75087 m .42078 .24898 L .46191 .244 L p .707 .577 .707 r
F P
0 g
s
.42078 .24898 m .42078 .75087 L .38741 .75902 L p .707 .577 .707 r
F P
0 g
s
.26387 .74297 m .26527 .72562 L .29641 .73062 L p .707 .577 .707 r
F P
0 g
s
.67746 .64042 m .67183 .58306 L .6507 .584 L p .707 .577 .707 r
F P
0 g
s
.23214 .74219 m .23354 .72484 L .26527 .72562 L p .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .73472 .72534 L .7173 .72621 L p .707 .577 .707 r
F P
0 g
s
.7173 .72621 m .70359 .7269 L p .70998 .73034 L .707 .577 .707 r
F P
0 g
s
.73613 .74442 m .7173 .72621 L .70998 .73034 L .707 .577 .707 r
F
.73613 .74442 m .76786 .74179 L p .74488 .73038 L F P
0 g
s
.73472 .72534 m .73554 .73638 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.73554 .73638 m .73613 .74442 L p .74488 .73038 L .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .76646 .72271 L .73472 .72534 L p .707 .577 .707 r
F P
0 g
s
.76786 .74179 m .79708 .73835 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76646 .72271 m .76755 .73761 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.76755 .73761 m .76786 .74179 L p .7779 .72856 L .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .79568 .71927 L .76646 .72271 L p .707 .577 .707 r
F P
0 g
s
.79708 .73835 m .82094 .73443 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79568 .71927 m .79706 .73803 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.79706 .73803 m .79708 .73835 L p .80589 .7254 L .707 .577 .707 r
F P
0 g
s
.82094 .73443 m .81954 .71535 L .79568 .71927 L p .707 .577 .707 r
F P
0 g
s
.81954 .71535 m .82094 .73443 L .8371 .73042 L p .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .8357 .71134 L .83012 .71273 L p .707 .577 .707 r
F P
0 g
s
.83012 .71273 m .81954 .71535 L p .82729 .722 L .707 .577 .707 r
F P
0 g
s
.8371 .73042 m .83012 .71273 L .82729 .722 L .707 .577 .707 r
F
.83096 .72012 m .83795 .70323 L p .83672 .69116 L F P
0 g
s
.83648 .6888 m .83518 .6962 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.83518 .6962 m .83096 .72012 L p .83672 .69116 L .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .83096 .72012 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.82031 .70248 m .81976 .70558 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.81976 .70558 m .81479 .73381 L p .82106 .70373 L .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .81479 .73381 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79652 .71163 m .79639 .71239 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.79639 .71239 m .79101 .74295 L p .79683 .712 L .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .79101 .74295 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76745 .71533 m .76734 .71597 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.76734 .71597 m .76194 .74666 L p .76777 .7157 L .707 .577 .707 r
F P
0 g
s
.70359 .7269 m .70499 .74598 L .73613 .74442 L p .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .76194 .74666 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73595 .71324 m .73547 .71596 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73547 .71596 m .73043 .74456 L p .73727 .71494 L .707 .577 .707 r
F P
0 g
s
.73043 .74456 m .73595 .71324 L .70509 .70555 L p .707 .577 .707 r
F P
0 g
s
.76194 .74666 m .76745 .71533 L .73595 .71324 L p .707 .577 .707 r
F P
0 g
s
.6507 .584 m .65633 .64136 L .67746 .64042 L p .707 .577 .707 r
F P
0 g
s
.26527 .72562 m .26387 .74297 L .23214 .74219 L p .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .70359 .7269 L .68123 .72717 L p .707 .577 .707 r
F P
0 g
s
.68123 .72717 m .67611 .72723 L p .67863 .72887 L .707 .577 .707 r
F P
0 g
s
.70499 .74598 m .68123 .72717 L .67863 .72887 L .707 .577 .707 r
F
.69958 .73688 m .73043 .74456 L p .70781 .70974 L F P
0 g
s
.70509 .70555 m .70391 .7123 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.70391 .7123 m .69958 .73688 L p .70781 .70974 L .707 .577 .707 r
F P
0 g
s
.69958 .73688 m .70509 .70555 L .6779 .69302 L p .707 .577 .707 r
F P
0 g
s
.79101 .74295 m .79652 .71163 L .76745 .71533 L p .707 .577 .707 r
F P
0 g
s
.55096 .24512 m .55096 .74701 L .50676 .74456 L p .707 .577 .707 r
F P
0 g
s
.50676 .74456 m .50676 .24267 L .55096 .24512 L p .707 .577 .707 r
F P
0 g
s
.81495 .56839 m .82057 .62575 L .83666 .62288 L p .707 .577 .707 r
F P
0 g
s
.83666 .62288 m .83104 .56552 L .81495 .56839 L p .707 .577 .707 r
F P
0 g
s
.67611 .72723 m .67751 .74631 L .70499 .74598 L p .707 .577 .707 r
F P
0 g
s
.46191 .74589 m .46191 .244 L .50676 .24267 L p .707 .577 .707 r
F P
0 g
s
.46191 .244 m .46191 .74589 L .42078 .75087 L p .707 .577 .707 r
F P
0 g
s
.67239 .72435 m .6779 .69302 L .65704 .67688 L p .707 .577 .707 r
F P
0 g
s
.6779 .69302 m .67239 .72435 L .69958 .73688 L p .707 .577 .707 r
F P
0 g
s
.50676 .24267 m .50676 .74456 L .46191 .74589 L p .707 .577 .707 r
F P
0 g
s
.81479 .73381 m .82031 .70248 L .79652 .71163 L p .707 .577 .707 r
F P
0 g
s
.65633 .64136 m .6507 .584 L .63796 .58388 L p .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .64358 .64124 L .65633 .64136 L p .707 .577 .707 r
F P
0 g
s
.67751 .74631 m .67611 .72723 L .65496 .72631 L p .707 .577 .707 r
F P
0 g
s
.65496 .72631 m .65636 .74539 L .67751 .74631 L p .707 .577 .707 r
F P
0 g
s
.65153 .7082 m .65704 .67688 L .64455 .6587 L p .707 .577 .707 r
F P
0 g
s
.65704 .67688 m .65153 .7082 L .67239 .72435 L p .707 .577 .707 r
F P
0 g
s
.83096 .72012 m .83648 .6888 L .82031 .70248 L p .707 .577 .707 r
F P
0 g
s
.83104 .56552 m .83666 .62288 L .84349 .62075 L p .707 .577 .707 r
F P
0 g
s
.84349 .62075 m .83786 .56339 L .83104 .56552 L p .707 .577 .707 r
F P
0 g
s
.65636 .74539 m .65496 .72631 L .64222 .72422 L p .707 .577 .707 r
F P
0 g
s
.64358 .64124 m .6421 .62617 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.63484 .58269 m .64047 .64005 L .64358 .64124 L p .707 .577 .707 r
F P
0 g
s
.63904 .69002 m .64455 .6587 L .64166 .64026 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .63614 .67158 L .63904 .69002 L p .707 .577 .707 r
F P
0 g
s
.64166 .64026 m .64864 .62337 L p .64504 .63727 L .707 .577 .707 r
F P
0 g
s
.63796 .58388 m .63484 .58269 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.6421 .62617 m .63796 .58388 L p .64187 .6298 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64414 .6389 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64864 .62337 L p .64977 .63276 L .707 .577 .707 r
F P
0 g
s
.64729 .63792 m .64695 .63444 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.64674 .63416 m .64977 .63276 L .64695 .63444 L .707 .577 .707 r
F
.66338 .63505 m .64729 .63792 L p .648 .63381 L F P
0 g
s
.64864 .62337 m .66481 .60969 L p .65529 .62945 L .707 .577 .707 r
F P
0 g
s
.64977 .63276 m .64864 .62337 L .65529 .62945 L .707 .577 .707 r
F
.648 .63381 m .66205 .62541 L .66338 .63505 L F
.66205 .62541 m .66481 .60969 L p .66743 .62417 L F P
0 g
s
.66338 .63505 m .66245 .62563 L p .66656 .62442 L .707 .577 .707 r
F P
0 g
s
.66205 .62541 m .66743 .62417 L .66245 .62563 L .707 .577 .707 r
F
.68716 .63173 m .66338 .63505 L p .66656 .62442 L F P
0 g
s
.66481 .60969 m .6886 .60054 L p .67259 .62266 L .707 .577 .707 r
F P
0 g
s
.66743 .62417 m .66481 .60969 L .67259 .62266 L .707 .577 .707 r
F
.6886 .60054 m .71767 .59684 L p .69713 .61764 L F P
0 g
s
.6921 .61832 m .6886 .60054 L .69713 .61764 L .707 .577 .707 r
F
.68716 .63173 m .68593 .61915 L p .69237 .61828 L F P
0 g
s
.68536 .61891 m .6886 .60054 L p .6921 .61832 L .707 .577 .707 r
F P
0 g
s
.71631 .62828 m .68716 .63173 L p .69237 .61828 L .707 .577 .707 r
F P
0 g
s
.68593 .61915 m .6921 .61832 L .69282 .622 L .707 .577 .707 r
F
.68536 .61891 m .6921 .61832 L .68593 .61915 L F
.71767 .59684 m .74917 .59893 L p .72837 .61535 L F P
0 g
s
.7223 .61547 m .71767 .59684 L .72837 .61535 L .707 .577 .707 r
F
.71631 .62828 m .71507 .61562 L p .72181 .61548 L F P
0 g
s
.71441 .61532 m .71767 .59684 L p .7223 .61547 L .707 .577 .707 r
F P
0 g
s
.74798 .62503 m .71631 .62828 L p .72181 .61548 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .74634 .61499 L .74798 .62503 L .707 .577 .707 r
F
.74634 .61499 m .74917 .59893 L p .75524 .61608 L F P
0 g
s
.77905 .62231 m .74798 .62503 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .77803 .61794 L .77905 .62231 L .707 .577 .707 r
F
.77803 .61794 m .78003 .60662 L p .78608 .61996 L F P
0 g
s
.79317 .62132 m .77905 .62231 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.77803 .61794 m .78608 .61996 L .77868 .61853 L .707 .577 .707 r
F
.78003 .60662 m .80722 .61915 L p .80086 .6228 L F P
0 g
s
.78608 .61996 m .78003 .60662 L .80086 .6228 L .707 .577 .707 r
F
.74917 .59893 m .78003 .60662 L p .76433 .61682 L F P
0 g
s
.75716 .62148 m .75524 .61608 L .76433 .61682 L .707 .577 .707 r
F
.75524 .61608 m .74917 .59893 L .76433 .61682 L F
.74634 .61499 m .75524 .61608 L .74703 .6154 L F
.69237 .61828 m .71441 .61532 L .71631 .62828 L F
.71441 .61532 m .7223 .61547 L .71507 .61562 L F
.71503 .61523 m .71507 .61562 L p .71441 .61532 L F P
0 g
s
.71507 .61562 m .71631 .62828 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.74917 .59893 m .74628 .61534 L p .7288 .62191 L .707 .577 .707 r
F P
0 g
s
.71215 .62816 m .72327 .61938 L .7288 .62191 L .707 .577 .707 r
F
.72327 .61938 m .74917 .59893 L .7288 .62191 L F
.74628 .61534 m .74365 .63025 L .72033 .6287 L p F P
0 g
s
.72033 .6287 m .71215 .62816 L p .74628 .61534 L .707 .577 .707 r
F P
0 g
s
.74235 .56767 m .77343 .56495 L p .7537 .61152 L .707 .577 .707 r
F P
0 g
s
.75189 .6158 m .75128 .61276 L .7537 .61152 L .707 .577 .707 r
F
.75128 .61276 m .74235 .56767 L .7537 .61152 L F
.74798 .62503 m .74703 .6154 L p .75189 .6158 L F P
0 g
s
.74703 .6154 m .74235 .56767 L p .75189 .6158 L .707 .577 .707 r
F P
0 g
s
.78003 .60662 m .77795 .61839 L p .74365 .63025 L .707 .577 .707 r
F P
0 g
s
.77795 .61839 m .77451 .63794 L .7537 .63276 L p .707 .577 .707 r
F P
0 g
s
.7537 .63276 m .74365 .63025 L p .77795 .61839 L .707 .577 .707 r
F P
0 g
s
.77343 .56495 m .80087 .56303 L p .7812 .61647 L .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .7801 .61712 L .7812 .61647 L .707 .577 .707 r
F
.7801 .61712 m .77343 .56495 L .7812 .61647 L F
.77905 .62231 m .77868 .61853 L p .78033 .61885 L F P
0 g
s
.77868 .61853 m .77343 .56495 L p .78033 .61885 L .707 .577 .707 r
F P
0 g
s
.79016 .62895 m .78608 .61996 L .80086 .6228 L .707 .577 .707 r
F
.77868 .61853 m .78608 .61996 L .79016 .62895 L F
.80722 .61915 m .80626 .6246 L p .77451 .63794 L F P
0 g
s
.80626 .6246 m .8017 .65047 L .78822 .64426 L p .707 .577 .707 r
F P
0 g
s
.78822 .64426 m .77451 .63794 L p .80626 .6246 L .707 .577 .707 r
F P
0 g
s
.8017 .65047 m .80722 .61915 L .82808 .63529 L p .707 .577 .707 r
F P
0 g
s
.822 .56208 m .82602 .60306 L p .8065 .62039 L .707 .577 .707 r
F P
0 g
s
.82602 .60306 m .82763 .61944 L .81028 .62022 L p .707 .577 .707 r
F P
0 g
s
.81028 .62022 m .8065 .62039 L p .82602 .60306 L .707 .577 .707 r
F P
0 g
s
.80087 .56303 m .8065 .62039 L .79317 .62132 L p .707 .577 .707 r
F P
0 g
s
.78033 .61885 m .80087 .56303 L .79317 .62132 L .707 .577 .707 r
F
.77863 .61799 m .77868 .61853 L p .77803 .61794 L F P
0 g
s
.77868 .61853 m .77905 .62231 L p .77803 .61794 L .707 .577 .707 r
F P
0 g
s
.77451 .63794 m .77803 .61794 L p .79016 .62895 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .75524 .61608 L .75716 .62148 L .707 .577 .707 r
F
.77343 .56495 m .77863 .61799 L p .75189 .6158 L F P
0 g
s
.74699 .61498 m .74703 .6154 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74703 .6154 m .74798 .62503 L p .74634 .61499 L .707 .577 .707 r
F P
0 g
s
.74365 .63025 m .74634 .61499 L p .75716 .62148 L .707 .577 .707 r
F P
0 g
s
.71507 .61562 m .7223 .61547 L .72327 .61938 L .707 .577 .707 r
F
.74235 .56767 m .74699 .61498 L p .72181 .61548 L F P
0 g
s
.66656 .62442 m .68536 .61891 L .68716 .63173 L .707 .577 .707 r
F
.68589 .61876 m .68593 .61915 L p .68536 .61891 L F P
0 g
s
.68593 .61915 m .68716 .63173 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.71767 .59684 m .71436 .61564 L p .69798 .62414 L .707 .577 .707 r
F P
0 g
s
.68308 .63187 m .69282 .622 L .69798 .62414 L .707 .577 .707 r
F
.69282 .622 m .71767 .59684 L .69798 .62414 L F
.71436 .61564 m .71215 .62816 L .6879 .63125 L p F P
0 g
s
.6879 .63125 m .68308 .63187 L p .71436 .61564 L .707 .577 .707 r
F P
0 g
s
.71069 .57092 m .74235 .56767 L p .72426 .60979 L .707 .577 .707 r
F P
0 g
s
.72181 .61548 m .72089 .61178 L .72426 .60979 L .707 .577 .707 r
F
.72089 .61178 m .71069 .57092 L .72426 .60979 L F
.71507 .61562 m .71069 .57092 L p .72181 .61548 L F P
0 g
s
.72327 .61938 m .7223 .61547 L .72837 .61535 L .707 .577 .707 r
F
.71215 .62816 m .71441 .61532 L p .72327 .61938 L F P
0 g
s
.71069 .57092 m .71503 .61523 L p .71441 .61532 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69666 .60719 L .71441 .61532 L .707 .577 .707 r
F
.69666 .60719 m .71069 .57092 L .71441 .61532 L F
.68308 .63187 m .6593 .64101 L p .66056 .63927 L F P
0 g
s
.6886 .60054 m .68531 .61923 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68531 .61923 m .68308 .63187 L p .66056 .63927 L .707 .577 .707 r
F P
0 g
s
.68154 .57437 m .71069 .57092 L p .69505 .61134 L .707 .577 .707 r
F P
0 g
s
.69237 .61828 m .69139 .61431 L .69505 .61134 L .707 .577 .707 r
F
.69139 .61431 m .68154 .57437 L .69505 .61134 L F
.68593 .61915 m .68154 .57437 L p .69237 .61828 L F P
0 g
s
.69282 .622 m .6921 .61832 L .69713 .61764 L .707 .577 .707 r
F
.68308 .63187 m .68536 .61891 L p .69282 .622 L F P
0 g
s
.68154 .57437 m .68589 .61876 L p .68536 .61891 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .6701 .61259 L .68536 .61891 L .707 .577 .707 r
F
.6701 .61259 m .68154 .57437 L .68536 .61891 L F
.66824 .62866 m .66743 .62417 L .67259 .62266 L F
.66245 .62563 m .66743 .62417 L .66824 .62866 L F
.6593 .64101 m .64312 .65469 L p .64821 .64414 L F P
0 g
s
.66481 .60969 m .66198 .62577 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.66198 .62577 m .6593 .64101 L p .64821 .64414 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .68154 .57437 L p .66893 .61649 L .707 .577 .707 r
F P
0 g
s
.66656 .62442 m .66584 .62062 L .66893 .61649 L .707 .577 .707 r
F
.66584 .62062 m .65775 .57769 L .66893 .61649 L F
.66245 .62563 m .65775 .57769 L p .66656 .62442 L F P
0 g
s
.66241 .62519 m .66245 .62563 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.66245 .62563 m .66338 .63505 L p .66205 .62541 L .707 .577 .707 r
F P
0 g
s
.6593 .64101 m .66205 .62541 L p .66824 .62866 L .707 .577 .707 r
F P
0 g
s
.65775 .57769 m .66241 .62519 L p .648 .63381 L .707 .577 .707 r
F P
0 g
s
.65055 .63928 m .64977 .63276 L .65529 .62945 L .707 .577 .707 r
F
.64695 .63444 m .64977 .63276 L .65055 .63928 L F
.64312 .65469 m .63614 .67158 L p .64164 .65039 L F P
0 g
s
.64864 .62337 m .64666 .63461 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64666 .63461 m .64312 .65469 L p .64164 .65039 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .65775 .57769 L p .64931 .6263 L .707 .577 .707 r
F P
0 g
s
.648 .63381 m .64771 .63133 L .64931 .6263 L .707 .577 .707 r
F
.64771 .63133 m .64166 .58056 L .64931 .6263 L F
.64695 .63444 m .64166 .58056 L p .648 .63381 L F P
0 g
s
.64689 .63388 m .64695 .63444 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64695 .63444 m .64729 .63792 L p .64674 .63416 L .707 .577 .707 r
F P
0 g
s
.64312 .65469 m .64674 .63416 L p .65055 .63928 L .707 .577 .707 r
F P
0 g
s
.64166 .58056 m .64689 .63388 L p .64047 .64005 L .707 .577 .707 r
F P
0 g
s
.64131 .64408 m .64166 .64026 L .64504 .63727 L .707 .577 .707 r
F
.64414 .6389 m .64047 .64005 L p .64689 .63388 L F P
0 g
s
.64023 .65581 m .64131 .64408 L .64504 .63727 L .707 .577 .707 r
F
.63614 .67158 m .64097 .6442 L p .64023 .65581 L F P
0 g
s
.64097 .6442 m .64166 .64026 L p .64023 .65581 L .707 .577 .707 r
F P
0 g
s
.64222 .72422 m .64362 .7433 L .65636 .74539 L p .707 .577 .707 r
F P
0 g
s
.64455 .6587 m .63904 .69002 L .65153 .7082 L p .707 .577 .707 r
F P
0 g
s
.83795 .70323 m .84346 .67191 L .83648 .6888 L p .707 .577 .707 r
F P
0 g
s
.8357 .71134 m .8371 .73042 L .84397 .72671 L p .707 .577 .707 r
F P
0 g
s
.84397 .72671 m .84257 .70763 L .8357 .71134 L p .707 .577 .707 r
F P
0 g
s
.83786 .56339 m .84349 .62075 L .84037 .61957 L p .707 .577 .707 r
F P
0 g
s
.84037 .61957 m .83475 .56221 L .83786 .56339 L p .707 .577 .707 r
F P
0 g
s
.64362 .7433 m .64222 .72422 L .63913 .72117 L p .707 .577 .707 r
F P
0 g
s
.63913 .72117 m .64053 .74025 L .64362 .7433 L p .707 .577 .707 r
F P
0 g
s
.64047 .64005 m .63484 .58269 L .64166 .58056 L p .707 .577 .707 r
F P
0 g
s
.84346 .67191 m .83795 .70323 L .83505 .6848 L p .707 .577 .707 r
F P
0 g
s
.83505 .6848 m .84057 .65347 L .84346 .67191 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84257 .70763 m .84397 .72671 L .84088 .72366 L p .707 .577 .707 r
F P
0 g
s
.84088 .72366 m .83948 .70458 L .84257 .70763 L p .707 .577 .707 r
F P
0 g
s
.83475 .56221 m .84037 .61957 L .82763 .61944 L p .707 .577 .707 r
F P
0 g
s
.82763 .61944 m .822 .56208 L .83475 .56221 L p .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .38174 .57769 L .35136 .58164 L p .707 .577 .707 r
F P
0 g
s
.38174 .57769 m .39466 .63015 L .42569 .62246 L p .707 .577 .707 r
F P
0 g
s
.42569 .62246 m .41277 .57001 L .38174 .57769 L p .707 .577 .707 r
F P
0 g
s
.41277 .57001 m .42569 .62246 L .45434 .6118 L p .707 .577 .707 r
F P
0 g
s
.45434 .6118 m .44142 .55934 L .41277 .57001 L p .707 .577 .707 r
F P
0 g
s
.35266 .65285 m .38202 .66387 L p .37339 .63974 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .35136 .58164 L .35965 .62795 L .707 .577 .707 r
F
.36361 .63135 m .36311 .62933 L p .36093 .62904 L F P
0 g
s
.36311 .62933 m .35136 .58164 L p .36093 .62904 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .32462 .58147 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.38202 .66387 m .41216 .67384 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35136 .58164 m .35318 .58902 L p .39466 .63015 L .707 .577 .707 r
F P
0 g
s
.39466 .63015 m .35318 .58902 L .39126 .63028 L .707 .577 .707 r
F
.38154 .63185 m .39466 .63015 L p .36361 .63135 L F P
0 g
s
.39453 .62781 m .39302 .63218 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.39302 .63218 m .38202 .66387 L p .39847 .63808 L .707 .577 .707 r
F P
0 g
s
.35318 .58902 m .36361 .63135 L p .39126 .63028 L .707 .577 .707 r
F P
0 g
s
.37339 .63974 m .37045 .63154 L .36361 .63135 L .707 .577 .707 r
F
.36093 .62904 m .35266 .65285 L p .37339 .63974 L F P
0 g
s
.38202 .66387 m .39453 .62781 L .36518 .61679 L p .707 .577 .707 r
F P
0 g
s
.36361 .63135 m .36429 .6341 L .38154 .63185 L p .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .36093 .62904 L p .36361 .63135 L .707 .577 .707 r
F P
0 g
s
.37045 .63154 m .36518 .61679 L .36361 .63135 L .707 .577 .707 r
F
.35266 .65285 m .36093 .62904 L p .34542 .62698 L F P
0 g
s
.32698 .64187 m .35266 .65285 L p .34857 .63823 L .707 .577 .707 r
F P
0 g
s
.34857 .63823 m .34542 .62698 L .34078 .63073 L .707 .577 .707 r
F
.34857 .63823 m .34078 .63073 L .32698 .64187 L F
.32462 .58147 m .30412 .57718 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .32462 .58147 L .32898 .61938 L .707 .577 .707 r
F
.33551 .62566 m .33511 .62404 L p .33333 .62357 L F P
0 g
s
.33511 .62404 m .32462 .58147 L p .33333 .62357 L .707 .577 .707 r
F P
0 g
s
.32462 .58147 m .33551 .62566 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.32698 .64187 m .33333 .62357 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33273 .62529 m .32698 .64187 L p .34078 .63073 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .29188 .56922 L p .30958 .61171 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .31852 .62459 L .30747 .632 L .707 .577 .707 r
F
.31287 .61646 m .30412 .57718 L .30958 .61171 L F
.3143 .61852 m .31394 .61704 L p .31287 .61646 L F P
0 g
s
.31394 .61704 m .30412 .57718 L p .31287 .61646 L .707 .577 .707 r
F P
0 g
s
.30412 .57718 m .31002 .60115 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.32599 .63535 m .32381 .62104 L .31852 .62459 L .707 .577 .707 r
F
.31233 .618 m .30747 .632 L p .32381 .62104 L F P
0 g
s
.31002 .60115 m .31704 .62964 L p .32898 .61938 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .31287 .61646 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .30793 .61376 L .30379 .61741 L .707 .577 .707 r
F
.29606 .62421 m .30745 .63198 L p .30379 .61741 L F P
0 g
s
.30745 .63198 m .30747 .632 L p .30379 .61741 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .28908 .55834 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.30153 .60845 m .29188 .56922 L .30053 .60446 L .709 .579 .707 r
F
.30206 .61057 m .30169 .60906 L p .30153 .60845 L F P
0 g
s
.30169 .60906 m .29188 .56922 L p .30153 .60845 L .709 .579 .707 r
F P
0 g
s
.29606 .62421 m .30153 .60845 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29188 .56922 m .30206 .61057 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.30858 .58816 m .30153 .60845 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .301 .60999 L p .30206 .61057 L .707 .577 .707 r
F P
0 g
s
.30793 .61376 m .30153 .60845 L .30206 .61057 L .707 .577 .707 r
F
.301 .60999 m .29606 .62421 L p .30379 .61741 L F P
0 g
s
.30793 .61376 m .30206 .61057 L .30379 .61741 L .707 .577 .707 r
F
.30206 .61057 m .301 .60999 L .30379 .61741 L F
.28908 .55834 m .29602 .54562 L p .30085 .5982 L F P
0 g
s
.29606 .62421 m .30076 .60553 L .29851 .61 L .707 .577 .707 r
F
.28908 .55834 m .29642 .5881 L p .30053 .60446 L .709 .579 .707 r
F P
0 g
s
.29984 .60203 m .29386 .61926 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30053 .60446 m .29841 .59605 L .30201 .61079 L .709 .579 .707 r
F
.29642 .5881 m .29956 .60088 L p .29841 .59605 L F P
0 g
s
.29956 .60088 m .30201 .61079 L p .29841 .59605 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30053 .60446 L .30091 .60609 L .709 .579 .707 r
F
.3048 .62167 m .30206 .61057 L p .30053 .60446 L F P
0 g
s
.30637 .58321 m .30043 .60034 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.29998 .60258 m .29956 .60088 L .30043 .60034 L .707 .577 .707 r
F
.30043 .60034 m .29984 .60203 L p .29998 .60258 L F P
0 g
s
.30076 .60553 m .30043 .60034 L .29998 .60258 L .707 .577 .707 r
F
.30201 .61079 m .3048 .62167 L p .30131 .60762 L .709 .579 .707 r
F P
0 g
s
.30131 .60762 m .30091 .60609 L .30201 .61079 L .709 .579 .707 r
F
.30858 .58816 m .30637 .58321 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30153 .60845 m .30858 .58816 L p .30076 .60553 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .29998 .60258 L p .30043 .60034 L .707 .577 .707 r
F P
0 g
s
.29984 .60203 m .30043 .60034 L p .30079 .60603 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .30637 .58321 L p .3025 .59903 L .707 .577 .707 r
F P
0 g
s
.30201 .61079 m .30043 .60034 L .30101 .59997 L .707 .577 .707 r
F
.31999 .59595 m .30858 .58816 L p .30793 .61376 L F P
0 g
s
.30637 .58321 m .31359 .58158 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.3025 .59903 m .30637 .58321 L .30542 .59719 L .707 .577 .707 r
F
.30206 .61057 m .3048 .62167 L p .31117 .61553 L F P
0 g
s
.30894 .59808 m .30201 .61079 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.31359 .58158 m .30968 .59284 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30894 .59808 m .30828 .59539 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30542 .59719 m .30968 .59284 L .30828 .59539 L .707 .577 .707 r
F
.31359 .58158 m .32953 .58344 L p .32382 .5903 L F P
0 g
s
.30968 .59284 m .31359 .58158 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.312 .53231 m .32492 .58476 L .31675 .59157 L p .707 .577 .707 r
F P
0 g
s
.31675 .59157 m .30894 .59808 L p .30918 .59293 L .707 .577 .707 r
F P
0 g
s
.30918 .59293 m .312 .53231 L .31675 .59157 L .707 .577 .707 r
F
.30828 .59539 m .30894 .59808 L p .30101 .59997 L F P
0 g
s
.30108 .61764 m .30968 .59284 L p .32382 .5903 L .707 .577 .707 r
F P
0 g
s
.30968 .59284 m .30895 .59496 L p .30828 .59539 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .312 .53231 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.30828 .59539 m .29602 .54562 L p .30914 .59383 L .707 .577 .707 r
F P
0 g
s
.29602 .54562 m .30828 .59539 L p .30101 .59997 L .707 .577 .707 r
F P
0 g
s
.29386 .61926 m .29581 .62364 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.29581 .62364 m .29606 .62421 L p .29851 .61 L .707 .577 .707 r
F P
0 g
s
.30108 .61764 m .29386 .61926 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30895 .59496 m .30108 .61764 L p .30542 .59719 L .707 .577 .707 r
F P
0 g
s
.30043 .60034 m .3025 .59903 L .30079 .60603 L .707 .577 .707 r
F
.30043 .60034 m .28908 .55834 L .30085 .5982 L F
.29956 .60088 m .28908 .55834 L .30043 .60034 L F
.30101 .59997 m .30043 .60034 L .30085 .5982 L F
.30079 .60603 m .3025 .59903 L .30542 .59719 L F
.29386 .61926 m .29984 .60203 L p .30079 .60603 L F P
0 g
s
.3048 .62167 m .31704 .62964 L p .31117 .61553 L .707 .577 .707 r
F P
0 g
s
.31999 .59595 m .31287 .61646 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.31287 .61646 m .31233 .618 L p .3143 .61852 L .707 .577 .707 r
F P
0 g
s
.32381 .62104 m .31287 .61646 L .3143 .61852 L .707 .577 .707 r
F
.31704 .62964 m .3143 .61852 L p .30958 .61171 L F P
0 g
s
.31287 .61646 m .31999 .59595 L p .30793 .61376 L .707 .577 .707 r
F P
0 g
s
.30747 .632 m .32698 .64187 L p .32599 .63535 L .707 .577 .707 r
F P
0 g
s
.31704 .62964 m .33754 .63392 L p .33109 .62297 L .707 .577 .707 r
F P
0 g
s
.33109 .62297 m .32898 .61938 L .32628 .6217 L .707 .577 .707 r
F
.33109 .62297 m .32628 .6217 L .31704 .62964 L F
.34542 .62698 m .33551 .62566 L .34078 .63073 L F
.33551 .62566 m .33273 .62529 L .34078 .63073 L F
.33949 .60581 m .31999 .59595 L p .32381 .62104 L F P
0 g
s
.33949 .60581 m .33333 .62357 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.33333 .62357 m .33273 .62529 L p .33551 .62566 L .707 .577 .707 r
F P
0 g
s
.34542 .62698 m .33333 .62357 L .33551 .62566 L .707 .577 .707 r
F
.33754 .63392 m .33551 .62566 L p .32898 .61938 L F P
0 g
s
.33333 .62357 m .33949 .60581 L p .32381 .62104 L .707 .577 .707 r
F P
0 g
s
.33754 .63392 m .36429 .6341 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.33551 .62566 m .33754 .63392 L p .36043 .62898 L .707 .577 .707 r
F P
0 g
s
.36518 .61679 m .33949 .60581 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.36429 .6341 m .36361 .63135 L p .35965 .62795 L .707 .577 .707 r
F P
0 g
s
.36093 .62904 m .36518 .61679 L p .34542 .62698 L .707 .577 .707 r
F P
0 g
s
.44142 .55934 m .45434 .6118 L .4778 .59919 L p .707 .577 .707 r
F P
0 g
s
.4778 .59919 m .46488 .54673 L .44142 .55934 L p .707 .577 .707 r
F P
0 g
s
.64053 .74025 m .63913 .72117 L .646 .71746 L p .707 .577 .707 r
F P
0 g
s
.84057 .65347 m .83505 .6848 L .82256 .66662 L p .707 .577 .707 r
F P
0 g
s
.82256 .66662 m .82808 .63529 L .84057 .65347 L p .707 .577 .707 r
F P
0 g
s
.646 .71746 m .64741 .73654 L .64053 .74025 L p .707 .577 .707 r
F P
0 g
s
.41216 .67384 m .42468 .63779 L .39453 .62781 L p .707 .577 .707 r
F P
0 g
s
.42468 .63779 m .41216 .67384 L .44015 .6818 L p .707 .577 .707 r
F P
0 g
s
.44015 .6818 m .45267 .64575 L .42468 .63779 L p .707 .577 .707 r
F P
0 g
s
.46488 .54673 m .4778 .59919 L .49378 .58587 L p .707 .577 .707 r
F P
0 g
s
.49378 .58587 m .48086 .53342 L .46488 .54673 L p .707 .577 .707 r
F P
0 g
s
.83948 .70458 m .84088 .72366 L .82814 .72157 L p .707 .577 .707 r
F P
0 g
s
.82814 .72157 m .82674 .70249 L .83948 .70458 L p .707 .577 .707 r
F P
0 g
s
.8065 .62039 m .80087 .56303 L .822 .56208 L p .707 .577 .707 r
F P
0 g
s
.82808 .63529 m .82256 .66662 L .8017 .65047 L p .707 .577 .707 r
F P
0 g
s
.45267 .64575 m .44015 .6818 L .46325 .68696 L p .707 .577 .707 r
F P
0 g
s
.46325 .68696 m .47576 .65091 L .45267 .64575 L p .707 .577 .707 r
F P
0 g
s
.64741 .73654 m .646 .71746 L .66216 .71345 L p .707 .577 .707 r
F P
0 g
s
.39557 .73024 m .39232 .7124 L .36159 .71497 L p .707 .577 .707 r
F P
0 g
s
.39232 .7124 m .39557 .73024 L .42694 .7242 L p .707 .577 .707 r
F P
0 g
s
.42694 .7242 m .4237 .70635 L .39232 .7124 L p .707 .577 .707 r
F P
0 g
s
.66216 .71345 m .66356 .73253 L .64741 .73654 L p .707 .577 .707 r
F P
0 g
s
.4237 .70635 m .42694 .7242 L .45589 .71527 L p .707 .577 .707 r
F P
0 g
s
.45589 .71527 m .45264 .69743 L .4237 .70635 L p .707 .577 .707 r
F P
0 g
s
.36159 .71497 m .36483 .73282 L .39557 .73024 L p .707 .577 .707 r
F P
0 g
s
.36483 .73282 m .36159 .71497 L .3345 .71382 L p .707 .577 .707 r
F P
0 g
s
.48086 .53342 m .49378 .58587 L .50071 .57316 L p .707 .577 .707 r
F P
0 g
s
.50071 .57316 m .48779 .5207 L .48086 .53342 L p .707 .577 .707 r
F P
0 g
s
.45264 .69743 m .45589 .71527 L .47956 .70433 L p .707 .577 .707 r
F P
0 g
s
.47956 .70433 m .47632 .68649 L .45264 .69743 L p .707 .577 .707 r
F P
0 g
s
.3345 .71382 m .33774 .73166 L .36483 .73282 L p .707 .577 .707 r
F P
0 g
s
.82674 .70249 m .82814 .72157 L .807 .72065 L p .707 .577 .707 r
F P
0 g
s
.807 .72065 m .80559 .70157 L .82674 .70249 L p .707 .577 .707 r
F P
0 g
s
.47632 .68649 m .47956 .70433 L .49565 .69246 L p .707 .577 .707 r
F P
0 g
s
.49565 .69246 m .49241 .67462 L .47632 .68649 L p .707 .577 .707 r
F P
0 g
s
.47576 .65091 m .46325 .68696 L .47918 .68882 L p .707 .577 .707 r
F P
0 g
s
.47918 .68882 m .4917 .65277 L .47576 .65091 L p .707 .577 .707 r
F P
0 g
s
.33774 .73166 m .3345 .71382 L .31371 .70905 L p .707 .577 .707 r
F P
0 g
s
.66356 .73253 m .66216 .71345 L .68602 .70953 L p .707 .577 .707 r
F P
0 g
s
.68602 .70953 m .68742 .72861 L .66356 .73253 L p .707 .577 .707 r
F P
0 g
s
.31371 .70905 m .31695 .7269 L .33774 .73166 L p .707 .577 .707 r
F P
0 g
s
.48779 .5207 m .50071 .57316 L .49792 .56228 L p .709 .579 .707 r
F P
0 g
s
.49792 .56228 m .485 .50983 L .48779 .5207 L p .709 .579 .707 r
F P
0 g
s
.80559 .70157 m .807 .72065 L .77951 .72098 L p .707 .577 .707 r
F P
0 g
s
.77951 .72098 m .77811 .7019 L .80559 .70157 L p .707 .577 .707 r
F P
0 g
s
.4917 .65277 m .47918 .68882 L .4864 .6872 L p .707 .577 .707 r
F P
0 g
s
.4864 .6872 m .49892 .65114 L .4917 .65277 L p .707 .577 .707 r
F P
0 g
s
.68742 .72861 m .68602 .70953 L .71524 .70609 L p .707 .577 .707 r
F P
0 g
s
.71524 .70609 m .71665 .72517 L .68742 .72861 L p .707 .577 .707 r
F P
0 g
s
.31695 .7269 m .31371 .70905 L .30125 .70114 L p .707 .577 .707 r
F P
0 g
s
.49241 .67462 m .49565 .69246 L .50259 .68081 L p .707 .577 .707 r
F P
0 g
s
.50259 .68081 m .49935 .66297 L .49241 .67462 L p .707 .577 .707 r
F P
0 g
s
.77811 .7019 m .77951 .72098 L .74838 .72254 L p .707 .577 .707 r
F P
0 g
s
.74838 .72254 m .74698 .70346 L .77811 .7019 L p .707 .577 .707 r
F P
0 g
s
.30125 .70114 m .30449 .71898 L .31695 .7269 L p .707 .577 .707 r
F P
0 g
s
.71665 .72517 m .71524 .70609 L .74698 .70346 L p .707 .577 .707 r
F P
0 g
s
.74698 .70346 m .74838 .72254 L .71665 .72517 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.485 .50983 m .49792 .56228 L .48568 .55431 L p .707 .577 .707 r
F P
0 g
s
.48568 .55431 m .47275 .50186 L .485 .50983 L p .707 .577 .707 r
F P
0 g
s
.49892 .65114 m .4864 .6872 L .4842 .68225 L p .707 .577 .707 r
F P
0 g
s
.4842 .68225 m .49671 .64619 L .49892 .65114 L p .707 .577 .707 r
F P
0 g
s
.30449 .71898 m .30125 .70114 L .29835 .69086 L p .707 .577 .707 r
F P
0 g
s
.49935 .66297 m .50259 .68081 L .49968 .67052 L p .707 .577 .707 r
F P
0 g
s
.49968 .67052 m .49644 .65268 L .49935 .66297 L p .707 .577 .707 r
F P
0 g
s
.29835 .69086 m .30159 .7087 L .30449 .71898 L p .707 .577 .707 r
F P
0 g
s
.47275 .50186 m .48568 .55431 L .46518 .55003 L p .707 .577 .707 r
F P
0 g
s
.46518 .55003 m .45226 .49758 L .47275 .50186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30159 .7087 m .29835 .69086 L .30528 .67921 L p .707 .577 .707 r
F P
0 g
s
.49671 .64619 m .4842 .68225 L .47279 .67446 L p .707 .577 .707 r
F P
0 g
s
.47279 .67446 m .4853 .6384 L .49671 .64619 L p .707 .577 .707 r
F P
0 g
s
.49644 .65268 m .49968 .67052 L .48723 .66261 L p .707 .577 .707 r
F P
0 g
s
.48723 .66261 m .48399 .64477 L .49644 .65268 L p .707 .577 .707 r
F P
0 g
s
.30528 .67921 m .30852 .69705 L .30159 .7087 L p .707 .577 .707 r
F P
0 g
s
.32492 .58476 m .312 .53231 L .33546 .5197 L p .707 .577 .707 r
F P
0 g
s
.32953 .58344 m .31701 .6195 L .30108 .61764 L p .707 .577 .707 r
F P
0 g
s
.45226 .49758 m .46518 .55003 L .43843 .54985 L p .707 .577 .707 r
F P
0 g
s
.43843 .54985 m .42551 .4974 L .45226 .49758 L p .707 .577 .707 r
F P
0 g
s
.30852 .69705 m .30528 .67921 L .32137 .66733 L p .707 .577 .707 r
F P
0 g
s
.4853 .6384 m .47279 .67446 L .45328 .66459 L p .707 .577 .707 r
F P
0 g
s
.45328 .66459 m .4658 .62854 L .4853 .6384 L p .707 .577 .707 r
F P
0 g
s
.34838 .57215 m .33546 .5197 L .36411 .50903 L p .707 .577 .707 r
F P
0 g
s
.33546 .5197 m .34838 .57215 L .32492 .58476 L p .707 .577 .707 r
F P
0 g
s
.42551 .4974 m .43843 .54985 L .40806 .5538 L p .707 .577 .707 r
F P
0 g
s
.40806 .5538 m .39514 .50135 L .42551 .4974 L p .707 .577 .707 r
F P
0 g
s
.48399 .64477 m .48723 .66261 L .46644 .65785 L p .707 .577 .707 r
F P
0 g
s
.46644 .65785 m .46319 .64 L .48399 .64477 L p .707 .577 .707 r
F P
0 g
s
.32137 .66733 m .32461 .68518 L .30852 .69705 L p .707 .577 .707 r
F P
0 g
s
.31701 .6195 m .32953 .58344 L .35262 .5886 L p .707 .577 .707 r
F P
0 g
s
.37703 .56149 m .36411 .50903 L .39514 .50135 L p .707 .577 .707 r
F P
0 g
s
.36411 .50903 m .37703 .56149 L .34838 .57215 L p .707 .577 .707 r
F P
0 g
s
.39514 .50135 m .40806 .5538 L .37703 .56149 L p .707 .577 .707 r
F P
0 g
s
.35262 .5886 m .34011 .62466 L .31701 .6195 L p .707 .577 .707 r
F P
0 g
s
.4658 .62854 m .45328 .66459 L .4276 .65361 L p .707 .577 .707 r
F P
0 g
s
.4276 .65361 m .44011 .61756 L .4658 .62854 L p .707 .577 .707 r
F P
0 g
s
.32461 .68518 m .32137 .66733 L .34505 .6564 L p .707 .577 .707 r
F P
0 g
s
.34011 .62466 m .35262 .5886 L .38061 .59656 L p .707 .577 .707 r
F P
0 g
s
.46319 .64 m .46644 .65785 L .43935 .65669 L p .707 .577 .707 r
F P
0 g
s
.43935 .65669 m .4361 .63885 L .46319 .64 L p .707 .577 .707 r
F P
0 g
s
.34505 .6564 m .34829 .67424 L .32461 .68518 L p .707 .577 .707 r
F P
0 g
s
.38061 .59656 m .3681 .63262 L .34011 .62466 L p .707 .577 .707 r
F P
0 g
s
.44011 .61756 m .4276 .65361 L .39824 .64259 L p .707 .577 .707 r
F P
0 g
s
.39824 .64259 m .41076 .60654 L .44011 .61756 L p .707 .577 .707 r
F P
0 g
s
.3681 .63262 m .38061 .59656 L .41076 .60654 L p .707 .577 .707 r
F P
0 g
s
.34829 .67424 m .34505 .6564 L .37399 .64747 L p .707 .577 .707 r
F P
0 g
s
.41076 .60654 m .39824 .64259 L .3681 .63262 L p .707 .577 .707 r
F P
0 g
s
.4361 .63885 m .43935 .65669 L .40861 .65926 L p .707 .577 .707 r
F P
0 g
s
.40861 .65926 m .40537 .64142 L .4361 .63885 L p .707 .577 .707 r
F P
0 g
s
.37399 .64747 m .37723 .66531 L .34829 .67424 L p .707 .577 .707 r
F P
0 g
s
.37723 .66531 m .37399 .64747 L .40537 .64142 L p .707 .577 .707 r
F P
0 g
s
.40537 .64142 m .40861 .65926 L .37723 .66531 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH015YF3`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH70003FUH00`00FUIJEP05FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo1@001UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0065oo`<000AJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Ggoo
0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00GGoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001KOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`8000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Qoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`8000MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
EWoo00@005YFFUH000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo00D005YFFUIJEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPl000=JEP03001JEP0000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00Dgoo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01EYF1P0025YF0P000UYF
00<005YFFUH0100000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH010001EYF00<005YFFUH015YF0P001EYF00<005YFFUH00UYF10000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001B
Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF20001EYF00<005YFFUH00UYF0P00
1eYF00<005YFFUH00UYF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0002moo`L002moo`00DWoo00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEPD000AJEP03001JEUYF00800003FUH005YF00IJEP03001JEUYF
009JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0000POol?0002FUH01000FUIJEUYF0P00;Woo001BOol200000eYF001JEP04FUH0
0`00FUIJEP05FUH00`00FUH000020006FUH50004FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000GOol90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
001BOol200000eYF001JEP04FUH00`00FUIJEP05FUH300000eYF001JEP05FUH90007FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool0059oo`80009JEP03001JEUYF009JEP03001JEUYF00=JEP80009o
o`03001JEP0000IJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP06001J
EUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Woo
200035YF00=oo`00FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
Dgoo00@005YFFUH000AJEP04001JEUYFFUH20004Ool00`00FUH000070007FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo1@005EYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF0P000UYF0P00;Woo0010Ool8000;Ool200000eYF001JEP04FUH<0004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP00FUH05eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000jOol60003FUH00`00FUIJ
EP02FUH70004Ool200000eYF001JEP04FUH200000eYF000000030009FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0FFUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Qoo`800003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00H0009JEP04001JEUYFFUH20006FUH30007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF01IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=Woo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF0P000eYF00<005YFFUH01EYF00<005YF
00000`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000EJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH05UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00
=7oo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH025YF0P000eYF00<005YFFUH0
15YF00<005YFFUH015YF10002EYF00<005YFFUH01UYF00<005YFFUH015YF0P001eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0=FUH0
1@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00<goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP04001JEP000007FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000aOol200000eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20009FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00006
FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000`Ool01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00<0
05YFFUH01UYF00@005YF000000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP8002eoo`00;goo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000P0025YF0`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0P00;Goo000_Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH30003FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002io
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Woo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH0
1@000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YF0000009JEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001J
EUYFFUH?000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP05001JEUYF001JEP020002FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH:000^Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEPL000AJEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF009JEPT000=JEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH01@00FUIJEUYF0000=7oo000^Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0`000UYF00<005YF
FUH015YF100025YF00<005YFFUH01UYF00<005YFFUH01UYF0`002EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF1`001eYF200015YF
00@005YFFUIoo`AJEP03001JEUYF009JEP80039oo`00;Goo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH00UYF3`001UYF00<005YFFUH00UYF0P000eYF40001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000=JEP80009JEP8000MJEP03001JEUYF009JEPT0009oo`<00003FUH005YF00IJ
EP03001JEUYF00AJEP03001oogoo02moo`00;Goo00<005YF00000eYF00<005YFFUH00UYF1P003goo
10000UYF00<005YFFUH015YF0`0025YF00<005YFFUH01EYF0`0000=JEP00FUH01EYF1`0015YF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00H005YF000005YF0004FUH8000>Ool20007FUH00`00FUIJEP04FUH2000`
Ool002eoo`03001JEP0000=JEP03001JEP00008001Uoo`@000IJEP<000MJEP03001JEUYF00IJEP03
001JEP0000L000=JEP04001JEUYFFUH70003FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH:000HOol20004FUH00`00FUIJEP05FUH2000`Ool0
02eoo`8000AJEP80021oo`8000AJEP03001JEUYF008000EJEP03001JEUYF00EJEP@0009JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0009JEP80009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001oogoo029oo`<00003FUH005YF00EJ
EP04001JEUYF000_Ool002eoo`80009JEP8002Aoo`<00003FUH005YF00=JEP<00003FUH005YF00=J
EP@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000XOol20006FUH01000FUIJEP00
;goo000]Ool400000eYF001oo`0DOol3000?Ool20005FUH00`00FUH0000500000eYF001JEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000/Ool00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo000]Ool20003FUH3000BOol5000@Ool20003FUH40005FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH70004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00;Goo00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00;Goo00=JEP00FUH00UYF00@005YFFUH0015oo`D0019oo`<00003FUH005YF00MJEP03001J
EUYF00AJEPL000AJEP800003FUH0000000D000=JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002000/Ool200000eYF001JEP03
FUH00`00Oomoo`0/Ool002aoo`8000AJEP04001JEUYFFUH2000?Ool5000AOol20003FUH00`00FUIJ
EP06FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH30006FUH40003FUH00`00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000AJEP00001JEP@002Yoo`8000AJEP03001o
ogoo02aoo`00;7oo0P0015YF00<005YFFUH00eYF0P003Woo0`0047oo0P001UYF00<005YFFUH015YF
1`001EYF00<005YFFUH01EYF00<005YFFUH00P0015YF00@005YFFUIJEP800004FUH005YF000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P001EYF0P004Goo0`005Goo00<0
05YFFUH00UYF0P00;Goo000/Ool00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH00003000LOol2
0007FUH00`00FUIJEP040004FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH500000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF
001JEP00009JEP03001JEUYF00=JEP<000ioo`D001Eoo`06001JEUYF001JEP00;Goo000/Ool00`00
FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP03FUH5000EOol200000eYF001JEP05FUH400000eYF
001JEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP04FUH20003FUH20002FUH00`00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00=JEP03
001JEUYF008000aoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00QJEP@0011oo`03001JEUYF009JEP04001JEUYFFUH20002FUH200000eYF001J
EP05FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P000UYF00<005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH01@00FUIJEUYF
00001EYF0P002Woo1@005Woo00D005YF001JEP0002eoo`00;7oo00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH035YF40001EYF00<005YF00000P0015YF00<005YF00001UYF10001EYF00@005YF
FUIJEP@000EJEP04001JEUYFFUH200001eYF001JEUYF001JEP0000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP07001JEUYFFUH005YF00000eYF0P000UYF00<005YFFUH015YF0`002Goo0`0067oo0P00
00=JEP00Ool0;7oo000]Ool01@00FUIJEUYF00001UYF00<005YFFUH06UYF0P001EYF0P000UYF00@0
05YFOomJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00EJEP<00003FUH005YF00=JEP<00003
FUH00000009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEUYF009JEP05001JEP00FUH00005FUH20002FUH2000SOol00`00FUH0000]Ool002eoo`05001J
EUYFFUH00006FUH00`00FUIJEP04FUH00`00FUIJEP0CFUH20004FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH025YF2@0000=JEP0000000UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0P001EYF00<005YFFUH00UYF00<007ooOol08Goo0P00;Woo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00@005YFFUIoo`EJEP03001JEUYF00UJEP05001JEUYF001JEP020005FUH00`00FUH00003
00000eYF001JEP05FUH50004FUH00`00FUIJEP09FUH300000eYF001JEP03FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
0UYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000QOol3000^Ool002moo`03001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00/00006FUH00000001JEP00
1UYF10001EYF00<005YFFUH025YF0P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP80009JEP07001J
EUYFFUH005YF000087oo00@005YF000002ioo`00<7oo0P001EYF00<005YFFUH01EYF00D005YFFUIJ
EWoo00AJEP04001JEUYFFUH90002FUH20006FUH5000015YF001JEP001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`001UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00D005YF001JEP0000IJEP03001JEP00008000=JEP80021oo`03001JEUYF
008002ioo`00<Goo00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0015YF00<005YF
FUH00UYF0P0000=JEP00FUH00eYF0`0000=JEP00FUH00UYF00<005YF00001UYF00<005YFFUH01UYF
00@005YFFUIJEP@00003FUH005YF00IJEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP05001JEP00FUH00006FUH01000FUIJEUYF0`0000=JEP0000003goo
4`0000=JEP000000;Woo000bOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00EJ
EPD000EJEP03001JEUYF00AJEP8000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP00008000IJEP03001JEUYF00AJEQ8000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEP00008002ioo`00<goo0P000UYF00@005YFFUIJEPH000IJEP03001JEUYF
00IJEPH0009JEP@000IJEP06001JEUYF001JEP001UYF00@005YFFUIJEP@0009JEP03001JEUYF00IJ
EP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01@00FUH005YF00001EYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo1P000eYF00<005YFFUH01UYF00<005YF
FUH01P000eYF00@005YF0000009JEP03001JEUYF00L0009JEP03001JEP0000=JEPL000IJEP03001J
EUYF00IJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH00002FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000bOol300000eYF001JEP06
FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUH00002FUH00`00FUIJEP03FUH01000FUIJ
EUYF200015YF00<005YFFUH01eYF00<005YFFUH015YF100035YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002moo`<000AJEP8000IJEP@00004FUH000000005FUH00`00FUIJEP06FUH00`00FUH0
0003FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP040003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000eYF00D005YFFUIJEP0002eoo`00;7oo4P0015YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00AJEPD000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEQ8000IJEPP002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00@005YFFUIJ
EQ<000AJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00D0
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00=JEP@000EJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP<00003FUH005YF00EJEP03001J
EUYF009JEPL000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0003FUH01000FUIJEUYF200025YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF0`00;Woo000]Ool00`00FUH00003FUH0
0`00FUH0000300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF
00<005YF000030000UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUIJEPH000=JEP<0
00UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPH0035oo`00;Goo00<005YF0000
0eYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0009J
EP04001JEUYFFUH500000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF0000
00001EYF00<005YFFUH00eYF0`001UYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80
03Moo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPH000Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009J
EP03001JEUYF00=JEP03001JEUYF00EJEPD0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001J
EP00000iOol002eoo`04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUHA0004FUH00`00
FUIJEP06FUH30006Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP02FUH5000kOol002eoo`8000=JEP03001JEUYF00=J
EPH000EJEP03001JEUYF00IJEP03001JEUYF00H000MJEP03001JEUYF008000Aoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03001JEUYF00MJEPT000QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000@00003FUH0000000h000Moo`T0041oo`00;Goo0P000eYF00<0
05YF00000`000eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0017oo0P0015YF00<005YFFUH00eYF
0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02eYF00<005YFFUH02EYF00<0
05YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000017oo0`000eYF1000
0UYF00<007ooOol0DWoo000]Ool20003FUH30006FUH00`00FUIJEP02FUH8000?Ool300001EYF001J
EUYFOol00eYF0P0000Aoo`00FUH000IJEP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEPH000IJEP03001JEUYF009JEP03001JEP0000Aoo`<000IJEP04001JEUYF
001DOol002aoo`03001JEP00009JEP04001JEUYF0003FUH8000JOol20006FUH2000017oo001JEP00
1EYF10000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH00eYF10000UYF00<005YFFUH00UYF00<005YF00000goo00D005YFFUIJEP0000EJEP04001J
EUYF001DOol002aoo`03001JEP0000T002Aoo`8000=JEP03001JEUYF00800003FUH005YF009JEP80
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00MJEP<000AJEP04001JEP00Ool20004FUH00`00FUIJEP03FUH00`00FUH0001EOol002aoo`03001J
EP0002moo`800003FUH005YF009JEP04001JEP00FUH30008FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH01000FUH0
00001eYF00<005YFFUH00eYF0P00EGoo000/Ool2000bOol20003FUH01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0`0000=JEP0000001eYF00<005YFFUH00eYF00<007ooOol0E7oo000/
Ool2000JOol3000GOol00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000015YF
001JEP001eYF00D005YFFUIJEP0005Moo`00;7oo0`0067oo1@005goo00@005YF000000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP800004FUH005YF0007FUH01000FUIJEP00F7oo000/Ool200000eYF
001oo`0FOol5000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000QJ
EP8005Uoo`00;7oo0P000UYF00<007ooOol057oo1@006Goo0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF00H005YF000005YF0008FUH00`00Oomoo`1HOol002eoo`05001JEUYFFUH0000FOol3000J
Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF0P00
Fgoo000]Ool01000FUIJEUYF0`00<7oo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000eYF00<005YFFUH00UYF00<007ooOol0Fgoo000^Ool01000FUIJEP000UYF0P00;Goo0P0000=J
EP00FUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00D005YFFUIJEP0005ioo`00;Woo
00<005YF00001EYF0`00:7oo0P0000=JEP00FUH00`000UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
0P0000=JEP0000001@00Ggoo000_Ool20006FUH01000FUH0000097oo0P000eYF0P000goo0`0025YF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00@005YFFUIJEP800003FUH005YF00AJEP<005moo`00<7oo00<005YFFUH015YF00@005YFFUIJEP<0
01moo`800003FUH005YF009JEP8000Eoo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP06FUH3001M
Ool0035oo`8000=JEP03001JEUYF00EJEPD001Qoo`8000=JEP05001JEUYFFUH00008Ool30004FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH4
0004FUH00`00FUIJEP06FUH00`00FUIJEP02001KOol003=oo`800003FUH005YF00MJEP04001JEUYF
FUH90009Ool60004FUH00`00FUIJEP02000<Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP060003FUH60006FUH00`00FUIJEP03FUH2001IOol0
03Eoo`<000MJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00=JEP<0015oo`@0
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009JEPD000AJEP<00003Ool0
000000AJEP03001JEUYF00AJEP<005Moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P005goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00@005YFFUIJEPH000MJEPD0009JEP8000Ioo`<00003FUH005YF00EJEP04001JEUYF001FOol003Yo
o`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<001mooal000EJ
EP03001JEUYF00EJEPL000]oo`<000AJEP05001JEUYFFUH0001FOol003eoo`H000AJEP03001JEUYF
00IJEP03001JEUYF009JEPD003Uoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP@0015oo`<0
0003FUH005YF009JEP8005Eoo`00@goo4P00@7oo0`000eYF00<005YFFUH015YF00<005YFFUH01@00
0eYF2@002goo0P000UYF00<005YF0000EGoo002HOol=0003FUH20007FUH00`00FUIJEP02FUH@0000
0eYF001oo`1DOol009]oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF009JEP8005Ioo`00WWoo1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP<005Ioo`00Y7oo1`001UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YF0000EWoo002[Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH2001GOol00:mooaH005Qoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59357 .74263 m .6016 .68677 L .57073 .68104 L p .707 .577 .707 r
F P
0 g
s
.6016 .68677 m .59357 .74263 L .6251 .74635 L p .707 .577 .707 r
F P
0 g
s
.6251 .74635 m .63313 .69049 L .6016 .68677 L p .707 .577 .707 r
F P
0 g
s
.63313 .69049 m .6251 .74635 L .65419 .7477 L p .707 .577 .707 r
F P
0 g
s
.65419 .7477 m .66222 .69184 L .63313 .69049 L p .707 .577 .707 r
F P
0 g
s
.5627 .7369 m .57073 .68104 L .54354 .67387 L p .707 .577 .707 r
F P
0 g
s
.57073 .68104 m .5627 .7369 L .59357 .74263 L p .707 .577 .707 r
F P
0 g
s
.66222 .69184 m .65419 .7477 L .678 .74654 L p .707 .577 .707 r
F P
0 g
s
.678 .74654 m .68603 .69068 L .66222 .69184 L p .707 .577 .707 r
F P
0 g
s
.54354 .67387 m .53551 .72973 L .5627 .7369 L p .707 .577 .707 r
F P
0 g
s
.53551 .72973 m .54354 .67387 L .52268 .66595 L p .707 .577 .707 r
F P
0 g
s
.59978 .81879 m .59194 .78353 L .56148 .78689 L p .707 .577 .707 r
F P
0 g
s
.59194 .78353 m .59978 .81879 L .63097 .81179 L p .707 .577 .707 r
F P
0 g
s
.63097 .81179 m .62313 .77653 L .59194 .78353 L p .707 .577 .707 r
F P
0 g
s
.62313 .77653 m .63097 .81179 L .65984 .80183 L p .707 .577 .707 r
F P
0 g
s
.65984 .80183 m .652 .76657 L .62313 .77653 L p .707 .577 .707 r
F P
0 g
s
.56932 .82215 m .56148 .78689 L .53474 .78627 L p .707 .577 .707 r
F P
0 g
s
.56148 .78689 m .56932 .82215 L .59978 .81879 L p .707 .577 .707 r
F P
0 g
s
.652 .76657 m .65984 .80183 L .68356 .78989 L p .707 .577 .707 r
F P
0 g
s
.68356 .78989 m .67572 .75463 L .652 .76657 L p .707 .577 .707 r
F P
0 g
s
.52268 .66595 m .51465 .72181 L .53551 .72973 L p .707 .577 .707 r
F P
0 g
s
.59323 .84687 m .59524 .82823 L .56423 .82348 L p .707 .577 .707 r
F P
0 g
s
.59524 .82823 m .59323 .84687 L .62489 .84945 L p .707 .577 .707 r
F P
0 g
s
.62489 .84945 m .62689 .83081 L .59524 .82823 L p .707 .577 .707 r
F P
0 g
s
.69152 .74359 m .6942 .743 L p .68117 .72447 L .707 .577 .707 r
F P
0 g
s
.69197 .74186 m .69294 .74622 L p .70701 .7648 L .707 .577 .707 r
F P
0 g
s
.69294 .74622 m .69981 .77712 L .70492 .76837 L p .707 .577 .707 r
F P
0 g
s
.70492 .76837 m .70701 .7648 L p .69294 .74622 L .707 .577 .707 r
F P
0 g
s
.68603 .69068 m .68117 .72447 L p .6942 .743 L .707 .577 .707 r
F P
0 g
s
.68117 .72447 m .678 .74654 L .69152 .74359 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70223 .68714 L .68603 .69068 L p .707 .577 .707 r
F P
0 g
s
.62689 .83081 m .62489 .84945 L .65409 .8496 L p .707 .577 .707 r
F P
0 g
s
.65409 .8496 m .6561 .83096 L .62689 .83081 L p .707 .577 .707 r
F P
0 g
s
.56423 .82348 m .56222 .84211 L .59323 .84687 L p .707 .577 .707 r
F P
0 g
s
.56222 .84211 m .56296 .83521 L p .53689 .81701 L .707 .577 .707 r
F P
0 g
s
.55309 .82084 m .53689 .81701 L p .56296 .83521 L .707 .577 .707 r
F P
0 g
s
.54257 .82153 m .53731 .79787 L p .51432 .78174 L .707 .577 .707 r
F P
0 g
s
.53731 .79787 m .53474 .78627 L .52838 .78486 L p .707 .577 .707 r
F P
0 g
s
.52838 .78486 m .51432 .78174 L p .53731 .79787 L .707 .577 .707 r
F P
0 g
s
.56296 .83521 m .56423 .82348 L .55309 .82084 L p .707 .577 .707 r
F P
0 g
s
.51465 .72181 m .52268 .66595 L .5102 .65806 L p .707 .577 .707 r
F P
0 g
s
.53474 .78627 m .54257 .82153 L .56932 .82215 L p .707 .577 .707 r
F P
0 g
s
.53689 .81701 m .53488 .83565 L .56222 .84211 L p .707 .577 .707 r
F P
0 g
s
.67572 .75463 m .68356 .78989 L .69981 .77712 L p .707 .577 .707 r
F P
0 g
s
.69981 .77712 m .69197 .74186 L .67572 .75463 L p .707 .577 .707 r
F P
0 g
s
.6561 .83096 m .65409 .8496 L .67798 .84731 L p .707 .577 .707 r
F P
0 g
s
.67798 .84731 m .67999 .82867 L .6561 .83096 L p .707 .577 .707 r
F P
0 g
s
.5102 .65806 m .50217 .71392 L .51465 .72181 L p .707 .577 .707 r
F P
0 g
s
.53488 .83565 m .53545 .83036 L p .51592 .80946 L .707 .577 .707 r
F P
0 g
s
.52718 .81351 m .51592 .80946 L p .53545 .83036 L .707 .577 .707 r
F P
0 g
s
.52216 .817 m .5166 .79198 L p .50224 .77374 L .707 .577 .707 r
F P
0 g
s
.5166 .79198 m .51432 .78174 L .51024 .77904 L p .707 .577 .707 r
F P
0 g
s
.51024 .77904 m .50224 .77374 L p .5166 .79198 L .707 .577 .707 r
F P
0 g
s
.53545 .83036 m .53689 .81701 L .52718 .81351 L p .707 .577 .707 r
F P
0 g
s
.51592 .80946 m .51391 .8281 L .53488 .83565 L p .707 .577 .707 r
F P
0 g
s
.51432 .78174 m .52216 .817 L .54257 .82153 L p .707 .577 .707 r
F P
0 g
s
.6942 .743 m .70048 .73799 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70223 .68714 m .69739 .72082 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.69739 .72082 m .6942 .743 L p .70055 .7357 L .707 .577 .707 r
F P
0 g
s
.70701 .7648 m .70092 .73739 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70121 .73699 m .70223 .68714 L .70048 .73799 L .707 .577 .707 r
F
.70092 .73739 m .69917 .72954 L p .69464 .74593 L F P
0 g
s
.70092 .73739 m .70701 .7648 L .70474 .75535 L p .708 .578 .707 r
F P
0 g
s
.70048 .73799 m .7012 .73741 L p .70121 .73699 L .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .70092 .73739 L p .70108 .73815 L .708 .578 .707 r
F P
0 g
s
.70055 .73597 m .69917 .72954 L .70108 .73815 L .708 .578 .707 r
F
.7012 .73741 m .70923 .68155 L .70223 .68714 L p .707 .577 .707 r
F P
0 g
s
.69917 .72954 m .69197 .74186 L p .69464 .74593 L .707 .577 .707 r
F P
0 g
s
.70045 .73554 m .69832 .73033 L p .69868 .72873 L .707 .577 .707 r
F P
0 g
s
.6966 .71885 m .69875 .72854 L p .69848 .72926 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .68584 .72244 L p .68658 .72072 L .707 .577 .707 r
F P
0 g
s
.68452 .71085 m .68668 .7206 L p .68599 .72138 L .707 .577 .707 r
F P
0 g
s
.6641 .70632 m .66589 .71435 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66522 .71412 L .66586 .71438 L .707 .577 .707 r
F
.68584 .72244 m .66551 .71472 L p .66586 .71438 L F P
0 g
s
.66551 .71472 m .66498 .71452 L p .66586 .71438 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .6452 .74096 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.68599 .72138 m .68584 .72244 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .67194 .74158 L p .65288 .72688 L .707 .577 .707 r
F P
0 g
s
.67524 .73351 m .68093 .71961 L .68599 .72138 L .707 .577 .707 r
F
.68093 .71961 m .68452 .71085 L .68599 .72138 L F
.68658 .72072 m .68668 .7206 L .69832 .73033 L F
.69848 .72926 m .69832 .73033 L p .68664 .72057 L F P
0 g
s
.68452 .71085 m .6966 .71885 L p .69534 .72695 L .707 .577 .707 r
F P
0 g
s
.68892 .72224 m .68452 .71085 L .69534 .72695 L .707 .577 .707 r
F
.68693 .7217 m .68452 .71085 L p .69402 .73544 L F P
0 g
s
.69387 .66658 m .70635 .67446 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68584 .72244 m .68616 .72022 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.68616 .72022 m .69387 .66658 L p .68664 .72057 L .707 .577 .707 r
F P
0 g
s
.69402 .73544 m .68892 .72224 L .69534 .72695 L .707 .577 .707 r
F
.69236 .74611 m .68693 .7217 L p .69402 .73544 L F P
0 g
s
.6641 .70632 m .68452 .71085 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67194 .74158 m .66589 .71435 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.66589 .71435 m .6641 .70632 L p .68093 .71961 L .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .69387 .66658 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66498 .71452 m .66505 .71406 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66505 .71406 m .67301 .65866 L p .66522 .71412 L .707 .577 .707 r
F P
0 g
s
.66522 .71412 m .67481 .69821 L .68599 .72138 L .707 .577 .707 r
F
.69387 .66658 m .68616 .72022 L p .67481 .69821 L F P
0 g
s
.68616 .72022 m .68599 .72138 L p .67481 .69821 L .707 .577 .707 r
F P
0 g
s
.68658 .72072 m .68664 .72057 L .68668 .7206 L .707 .577 .707 r
F
.69236 .74611 m .67194 .74158 L p .67524 .73351 L F P
0 g
s
.68668 .7206 m .69236 .74611 L p .67524 .73351 L .707 .577 .707 r
F P
0 g
s
.69261 .74449 m .69534 .72695 L .69848 .72926 L .707 .577 .707 r
F
.69534 .72695 m .6966 .71885 L .69848 .72926 L F
.69868 .72873 m .69875 .72854 L .70045 .73554 L F
.6966 .71885 m .69917 .72954 L p .70055 .73597 L .708 .578 .707 r
F P
0 g
s
.69922 .73046 m .6966 .71885 L .70055 .73597 L .708 .578 .707 r
F
.699 .72964 m .6966 .71885 L p .70226 .74397 L F P
0 g
s
.70635 .67446 m .70923 .68155 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69832 .73033 m .69864 .72809 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.69864 .72809 m .70635 .67446 L p .69874 .72847 L .707 .577 .707 r
F P
0 g
s
.70226 .74397 m .69922 .73046 L .70055 .73597 L .708 .578 .707 r
F
.70444 .75411 m .699 .72964 L p .70226 .74397 L F P
0 g
s
.68664 .72057 m .69335 .70487 L .69848 .72926 L .707 .577 .707 r
F
.70635 .67446 m .69864 .72809 L p .69335 .70487 L F P
0 g
s
.69864 .72809 m .69848 .72926 L p .69335 .70487 L .707 .577 .707 r
F P
0 g
s
.69868 .72873 m .69874 .72847 L .69875 .72854 L .707 .577 .707 r
F
.70444 .75411 m .69236 .74611 L p .69261 .74449 L F P
0 g
s
.69875 .72854 m .70444 .75411 L p .69261 .74449 L .707 .577 .707 r
F P
0 g
s
.70923 .68155 m .7012 .73741 L .70045 .73554 L p .707 .577 .707 r
F P
0 g
s
.69874 .72847 m .70923 .68155 L .70045 .73554 L .707 .577 .707 r
F
.70444 .75411 m .70055 .73597 L .70108 .73815 L .708 .578 .707 r
F
.70474 .75535 m .70444 .75411 L p .70092 .73739 L F P
0 g
s
.50217 .71392 m .5102 .65806 L .50732 .65098 L p .707 .577 .707 r
F P
0 g
s
.67999 .82867 m .67798 .84731 L .69422 .84279 L p .707 .577 .707 r
F P
0 g
s
.69422 .84279 m .69623 .82415 L .67999 .82867 L p .707 .577 .707 r
F P
0 g
s
.50938 .80536 m .50335 .80158 L p .51411 .82618 L .707 .577 .707 r
F P
0 g
s
.51008 .809 m .50454 .78407 L p .49967 .76305 L .708 .578 .707 r
F P
0 g
s
.50454 .78407 m .50224 .77374 L .50127 .76969 L p .708 .578 .707 r
F P
0 g
s
.50127 .76969 m .49967 .76305 L p .50454 .78407 L .708 .578 .707 r
F P
0 g
s
.51391 .8281 m .51411 .82618 L p .50335 .80158 L .707 .577 .707 r
F P
0 g
s
.51411 .82618 m .51592 .80946 L .50938 .80536 L p .707 .577 .707 r
F P
0 g
s
.50732 .65098 m .49929 .70684 L .50217 .71392 L p .707 .577 .707 r
F P
0 g
s
.50335 .80158 m .50134 .82022 L .51391 .8281 L p .707 .577 .707 r
F P
0 g
s
.50224 .77374 m .51008 .809 L .52216 .817 L p .707 .577 .707 r
F P
0 g
s
.49217 .82187 m .49217 .31998 L .44804 .31744 L p .707 .577 .707 r
F P
0 g
s
.49929 .70684 m .50732 .65098 L .51432 .64539 L p .707 .577 .707 r
F P
0 g
s
.50134 .82022 m .50335 .80158 L .50042 .79412 L p .707 .577 .707 r
F P
0 g
s
.50042 .79412 m .49841 .81276 L .50134 .82022 L p .707 .577 .707 r
F P
0 g
s
.51432 .64539 m .50629 .70125 L .49929 .70684 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .51008 .809 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49967 .76305 m .50268 .77659 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.50268 .77659 m .50751 .79831 L p .50172 .77208 L .708 .578 .707 r
F P
0 g
s
.49841 .81276 m .50042 .79412 L .50546 .78959 L p .707 .577 .707 r
F P
0 g
s
.50751 .79831 m .49967 .76305 L .50686 .75073 L p .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50751 .79831 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.50686 .75073 m .5106 .76752 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5106 .76752 m .5147 .78599 L p .507 .76046 L .707 .577 .707 r
F P
0 g
s
.5147 .78599 m .50686 .75073 L .52312 .73796 L p .707 .577 .707 r
F P
0 g
s
.52312 .73796 m .53096 .77322 L .5147 .78599 L p .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .50742 .78783 L .51927 .78454 L p .707 .577 .707 r
F P
0 g
s
.51927 .78454 m .52366 .78332 L p .52062 .78718 L .707 .577 .707 r
F P
0 g
s
.50541 .80647 m .51927 .78454 L .52062 .78718 L .707 .577 .707 r
F
.50546 .78959 m .50742 .78783 L p .50595 .79189 L F P
0 g
s
.49841 .81276 m .50546 .78959 L .50595 .79189 L .707 .577 .707 r
F
.50629 .70125 m .51432 .64539 L .53052 .64184 L p F P
0 g
s
.50742 .78783 m .50541 .80647 L .49841 .81276 L p .707 .577 .707 r
F P
0 g
s
.53052 .64184 m .52249 .6977 L .50629 .70125 L p .707 .577 .707 r
F P
0 g
s
.52249 .6977 m .53052 .64184 L .55433 .64069 L p .707 .577 .707 r
F P
0 g
s
.55433 .64069 m .5463 .69655 L .52249 .6977 L p .707 .577 .707 r
F P
0 g
s
.52366 .78332 m .52165 .80196 L .50541 .80647 L p .707 .577 .707 r
F P
0 g
s
.53096 .77322 m .52312 .73796 L .54684 .72602 L p .707 .577 .707 r
F P
0 g
s
.52165 .80196 m .52366 .78332 L .54755 .78103 L p .707 .577 .707 r
F P
0 g
s
.54684 .72602 m .55468 .76128 L .53096 .77322 L p .707 .577 .707 r
F P
0 g
s
.54755 .78103 m .54554 .79966 L .52165 .80196 L p .707 .577 .707 r
F P
0 g
s
.49217 .31998 m .49217 .82187 L .53706 .82062 L p .707 .577 .707 r
F P
0 g
s
.53706 .82062 m .53706 .31874 L .49217 .31998 L p .707 .577 .707 r
F P
0 g
s
.69623 .82415 m .69422 .84279 L .70121 .8365 L p .707 .577 .707 r
F P
0 g
s
.70121 .8365 m .70322 .81786 L .69623 .82415 L p .707 .577 .707 r
F P
0 g
s
.5463 .69655 m .55433 .64069 L .58342 .64204 L p .707 .577 .707 r
F P
0 g
s
.58342 .64204 m .57539 .6979 L .5463 .69655 L p .707 .577 .707 r
F P
0 g
s
.55468 .76128 m .54684 .72602 L .57571 .71606 L p .707 .577 .707 r
F P
0 g
s
.57571 .71606 m .58355 .75132 L .55468 .76128 L p .707 .577 .707 r
F P
0 g
s
.54554 .79966 m .54755 .78103 L .57675 .78118 L p .707 .577 .707 r
F P
0 g
s
.57675 .78118 m .57474 .79981 L .54554 .79966 L p .707 .577 .707 r
F P
0 g
s
.57474 .79981 m .57675 .78118 L .60841 .78376 L p .707 .577 .707 r
F P
0 g
s
.60841 .78376 m .6064 .80239 L .57474 .79981 L p .707 .577 .707 r
F P
0 g
s
.53706 .31874 m .53706 .82062 L .57832 .81572 L p .707 .577 .707 r
F P
0 g
s
.57539 .6979 m .58342 .64204 L .61494 .64576 L p .707 .577 .707 r
F P
0 g
s
.61494 .64576 m .60691 .70162 L .57539 .6979 L p .707 .577 .707 r
F P
0 g
s
.58355 .75132 m .57571 .71606 L .6069 .70906 L p .707 .577 .707 r
F P
0 g
s
.57832 .81572 m .57832 .31383 L .53706 .31874 L p .707 .577 .707 r
F P
0 g
s
.44804 .81932 m .44804 .31744 L .409 .31136 L p .707 .577 .707 r
F P
0 g
s
.44804 .31744 m .44804 .81932 L .49217 .82187 L p .707 .577 .707 r
F P
0 g
s
.6069 .70906 m .61474 .74432 L .58355 .75132 L p .707 .577 .707 r
F P
0 g
s
.63942 .78851 m .63741 .80715 L .6064 .80239 L p .707 .577 .707 r
F P
0 g
s
.6064 .80239 m .60841 .78376 L .63942 .78851 L p .707 .577 .707 r
F P
0 g
s
.57832 .31383 m .57832 .81572 L .61192 .80764 L p .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6641 .70632 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63875 .71196 m .63736 .7057 L p .65184 .72878 L .707 .577 .707 r
F P
0 g
s
.63736 .7057 m .6452 .74096 L .61474 .74432 L p .707 .577 .707 r
F P
0 g
s
.61474 .74432 m .6069 .70906 L .63736 .7057 L p .707 .577 .707 r
F P
0 g
s
.64582 .65148 m .63779 .70734 L .63471 .70677 L p .707 .577 .707 r
F P
0 g
s
.63471 .70677 m .60691 .70162 L p .61879 .68631 L .707 .577 .707 r
F P
0 g
s
.61879 .68631 m .64582 .65148 L .63471 .70677 L .707 .577 .707 r
F
.6452 .74096 m .63875 .71196 L p .65184 .72878 L F P
0 g
s
.60691 .70162 m .61494 .64576 L .64582 .65148 L p .707 .577 .707 r
F P
0 g
s
.61192 .80764 m .61192 .30575 L .57832 .31383 L p .707 .577 .707 r
F P
0 g
s
.25234 .72468 m .25581 .67188 L .22466 .66738 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .28659 .75071 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25581 .67188 m .25234 .72468 L .25665 .72475 L p .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .25581 .67188 L .25665 .72475 L .707 .577 .707 r
F
.22466 .66738 m .22267 .69777 L p .25234 .72468 L F P
0 g
s
.22267 .69777 m .2212 .72018 L .25202 .72463 L p .707 .577 .707 r
F P
0 g
s
.25202 .72463 m .25234 .72468 L p .22267 .69777 L .707 .577 .707 r
F P
0 g
s
.25148 .71546 m .25232 .7249 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.25232 .7249 m .25232 .72491 L p .25233 .72491 L .707 .577 .707 r
F P
0 g
s
.26059 .72461 m .25232 .7249 L .25233 .72491 L .707 .577 .707 r
F
.25232 .72491 m .25488 .7537 L p .26059 .72461 L F P
0 g
s
.28757 .67243 m .25581 .67188 L p .28272 .7226 L .707 .577 .707 r
F P
0 g
s
.28334 .72378 m .2834 .72313 L .28272 .7226 L .707 .577 .707 r
F
.2834 .72313 m .28757 .67243 L .28272 .7226 L F
.28421 .72375 m .28757 .67243 L p .28334 .72378 L F P
0 g
s
.31588 .74729 m .29284 .72274 L .28421 .72376 L .707 .577 .707 r
F
.2842 .72375 m .28659 .75071 L .3147 .74743 L p F P
0 g
s
.28757 .67243 m .28421 .72376 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.3147 .74743 m .31588 .74729 L p .2842 .72375 L .707 .577 .707 r
F P
0 g
s
.28659 .75071 m .2842 .72375 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.31686 .66897 m .28757 .67243 L p .312 .7191 L .707 .577 .707 r
F P
0 g
s
.31268 .72041 m .31274 .71971 L .312 .7191 L .707 .577 .707 r
F
.31274 .71971 m .31686 .66897 L .312 .7191 L F
.31588 .74729 m .33987 .74379 L p .33557 .73834 L F P
0 g
s
.31349 .72031 m .31686 .66897 L p .31274 .71971 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31274 .71971 L .31268 .72041 L .707 .577 .707 r
F
.31349 .72031 m .31274 .71971 L .31348 .72031 L F
.33987 .74379 m .35622 .74055 L p .35005 .72962 L F P
0 g
s
.31686 .66897 m .31549 .68977 L p .33733 .71464 L .707 .577 .707 r
F P
0 g
s
.33733 .71464 m .31549 .68977 L .33711 .7147 L .707 .577 .707 r
F
.33348 .71579 m .33733 .71464 L p .31349 .72032 L F P
0 g
s
.33733 .71464 m .34079 .66184 L .31686 .66897 L p .707 .577 .707 r
F P
0 g
s
.34079 .66184 m .33733 .71464 L .35357 .70455 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .33731 .71492 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.33731 .71492 m .33987 .74379 L p .35005 .72962 L .707 .577 .707 r
F P
0 g
s
.31549 .68977 m .31349 .72032 L p .33711 .7147 L .707 .577 .707 r
F P
0 g
s
.33557 .73834 m .33621 .71517 L .32017 .71881 L .707 .577 .707 r
F
.31249 .70906 m .31348 .72031 L p .33557 .73834 L F P
0 g
s
.31348 .72031 m .31588 .74729 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31588 .74729 m .31348 .72031 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31349 .72032 m .31339 .72177 L .33348 .71579 L p .707 .577 .707 r
F P
0 g
s
.33648 .70556 m .31249 .70906 L p .32017 .71881 L .707 .577 .707 r
F P
0 g
s
.33621 .71517 m .33648 .70556 L .32017 .71881 L .707 .577 .707 r
F
.33987 .74379 m .33968 .7417 L p .33557 .73834 L F P
0 g
s
.33968 .7417 m .33648 .70556 L p .33557 .73834 L .707 .577 .707 r
F P
0 g
s
.31249 .70906 m .2832 .71247 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31348 .72031 m .31249 .70906 L p .29284 .72274 L .707 .577 .707 r
F P
0 g
s
.31339 .72177 m .31349 .72031 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .31339 .72177 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.28421 .72376 m .28411 .72523 L p .31268 .72041 L .707 .577 .707 r
F P
0 g
s
.2832 .71247 m .2842 .72375 L p .28421 .72376 L .707 .577 .707 r
F P
0 g
s
.29284 .72274 m .2832 .71247 L .28421 .72376 L .707 .577 .707 r
F
.2832 .71247 m .25148 .71546 L p .26059 .72461 L F P
0 g
s
.2842 .72375 m .2832 .71247 L p .26059 .72461 L .707 .577 .707 r
F P
0 g
s
.28411 .72523 m .28421 .72375 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.25665 .72475 m .28411 .72523 L p .28334 .72378 L .707 .577 .707 r
F P
0 g
s
.409 .81325 m .409 .31136 L .37887 .30235 L p .707 .577 .707 r
F P
0 g
s
.409 .31136 m .409 .81325 L .44804 .81932 L p .707 .577 .707 r
F P
0 g
s
.70322 .81786 m .70121 .8365 L .69829 .82905 L p .707 .577 .707 r
F P
0 g
s
.69829 .82905 m .7003 .81041 L .70322 .81786 L p .707 .577 .707 r
F P
0 g
s
.2212 .72018 m .22466 .66738 L .1972 .65936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19374 .71216 m .1972 .65936 L .1761 .64862 L p .707 .577 .707 r
F P
0 g
s
.1972 .65936 m .19521 .68975 L p .2212 .72018 L .707 .577 .707 r
F P
0 g
s
.21751 .7191 m .2212 .72018 L p .19521 .68975 L .707 .577 .707 r
F P
0 g
s
.22044 .71774 m .22097 .72365 L p .25488 .7537 L .707 .577 .707 r
F P
0 g
s
.22097 .72365 m .22384 .75597 L .24438 .75446 L p .707 .577 .707 r
F P
0 g
s
.24438 .75446 m .25488 .7537 L p .22097 .72365 L .707 .577 .707 r
F P
0 g
s
.19521 .68975 m .19374 .71216 L .21751 .7191 L p .707 .577 .707 r
F P
0 g
s
.61192 .30575 m .61192 .80764 L .63456 .79716 L p .707 .577 .707 r
F P
0 g
s
.63456 .79716 m .63456 .29527 L .61192 .30575 L p .707 .577 .707 r
F P
0 g
s
.25488 .7537 m .25148 .71546 L .22044 .71774 L p .707 .577 .707 r
F P
0 g
s
.22384 .75597 m .22044 .71774 L .19312 .71908 L p .707 .577 .707 r
F P
0 g
s
.7003 .81041 m .69829 .82905 L .68572 .82116 L p .707 .577 .707 r
F P
0 g
s
.68572 .82116 m .68773 .80252 L .7003 .81041 L p .707 .577 .707 r
F P
0 g
s
.19312 .71908 m .19651 .75731 L .22384 .75597 L p .707 .577 .707 r
F P
0 g
s
.37887 .80423 m .37887 .30235 L .3606 .29127 L p .707 .577 .707 r
F P
0 g
s
.37887 .30235 m .37887 .80423 L .409 .81325 L p .707 .577 .707 r
F P
0 g
s
.35357 .70455 m .35703 .65175 L .34079 .66184 L p .707 .577 .707 r
F P
0 g
s
.17263 .70142 m .1761 .64862 L .16342 .6362 L p .707 .577 .707 r
F P
0 g
s
.1761 .64862 m .17263 .70142 L .19374 .71216 L p .707 .577 .707 r
F P
0 g
s
.25213 .82381 m .253 .80594 L .22184 .80207 L p .707 .577 .707 r
F P
0 g
s
.253 .80594 m .25213 .82381 L .28393 .82404 L p .707 .577 .707 r
F P
0 g
s
.28393 .82404 m .28479 .80617 L .253 .80594 L p .707 .577 .707 r
F P
0 g
s
.19651 .75731 m .19312 .71908 L .17218 .71935 L p .707 .577 .707 r
F P
0 g
s
.28479 .80617 m .28393 .82404 L .31324 .82061 L p .707 .577 .707 r
F P
0 g
s
.31324 .82061 m .3141 .80274 L .28479 .80617 L p .707 .577 .707 r
F P
0 g
s
.67301 .65866 m .66498 .71452 L .63779 .70734 L p .707 .577 .707 r
F P
0 g
s
.63779 .70734 m .64582 .65148 L .67301 .65866 L p .707 .577 .707 r
F P
0 g
s
.17218 .71935 m .17557 .75758 L .19651 .75731 L p .707 .577 .707 r
F P
0 g
s
.22097 .81995 m .22184 .80207 L .19435 .79495 L p .707 .577 .707 r
F P
0 g
s
.22184 .80207 m .22097 .81995 L .25213 .82381 L p .707 .577 .707 r
F P
0 g
s
.19435 .79495 m .19349 .81282 L .22097 .81995 L p .707 .577 .707 r
F P
0 g
s
.35622 .74055 m .35282 .70231 L .33648 .70556 L p .707 .577 .707 r
F P
0 g
s
.63741 .80715 m .63942 .78851 L .66675 .79498 L p .707 .577 .707 r
F P
0 g
s
.63456 .29527 m .63456 .79716 L .64403 .78532 L p .707 .577 .707 r
F P
0 g
s
.64403 .78532 m .64403 .28343 L .63456 .29527 L p .707 .577 .707 r
F P
0 g
s
.3141 .80274 m .31324 .82061 L .3372 .81385 L p .707 .577 .707 r
F P
0 g
s
.3372 .81385 m .33806 .79598 L .3141 .80274 L p .707 .577 .707 r
F P
0 g
s
.68773 .80252 m .68572 .82116 L .66474 .81362 L p .707 .577 .707 r
F P
0 g
s
.66474 .81362 m .66675 .79498 L .68773 .80252 L p .707 .577 .707 r
F P
0 g
s
.35703 .65175 m .35357 .70455 L .36053 .69247 L p .707 .577 .707 r
F P
0 g
s
.36053 .69247 m .36399 .63967 L .35703 .65175 L p .707 .577 .707 r
F P
0 g
s
.19349 .81282 m .19435 .79495 L .17324 .78525 L p .707 .577 .707 r
F P
0 g
s
.16342 .6362 m .15996 .689 L .17263 .70142 L p .707 .577 .707 r
F P
0 g
s
.15996 .689 m .16342 .6362 L .16042 .62333 L p .707 .577 .707 r
F P
0 g
s
.17557 .75758 m .17218 .71935 L .15968 .71852 L p .707 .577 .707 r
F P
0 g
s
.17324 .78525 m .17237 .80312 L .19349 .81282 L p .707 .577 .707 r
F P
0 g
s
.35282 .70231 m .35622 .74055 L .36332 .73787 L p .707 .577 .707 r
F P
0 g
s
.36332 .73787 m .35992 .69964 L .35282 .70231 L p .707 .577 .707 r
F P
0 g
s
.36399 .63967 m .36053 .69247 L .35753 .67959 L p .707 .577 .707 r
F P
0 g
s
.35753 .67959 m .36099 .62679 L .36399 .63967 L p .707 .577 .707 r
F P
0 g
s
.36043 .79326 m .3613 .77539 L .35433 .78656 L p .707 .577 .707 r
F P
0 g
s
.35992 .69964 m .36332 .73787 L .36048 .73603 L p .707 .577 .707 r
F P
0 g
s
.36048 .73603 m .35709 .6978 L .35992 .69964 L p .707 .577 .707 r
F P
0 g
s
.36099 .62679 m .35753 .67959 L .34485 .66717 L p .707 .577 .707 r
F P
0 g
s
.34485 .66717 m .34832 .61437 L .36099 .62679 L p .707 .577 .707 r
F P
0 g
s
.3613 .77539 m .36043 .79326 L .35744 .78145 L p .707 .577 .707 r
F P
0 g
s
.35744 .78145 m .3583 .76358 L .3613 .77539 L p .707 .577 .707 r
F P
0 g
s
.35709 .6978 m .36048 .73603 L .34798 .73521 L p .707 .577 .707 r
F P
0 g
s
.3606 .79316 m .3606 .29127 L .35597 .27923 L p .707 .577 .707 r
F P
0 g
s
.3606 .29127 m .3606 .79316 L .37887 .80423 L p .707 .577 .707 r
F P
0 g
s
.15968 .71852 m .16307 .75675 L .17557 .75758 L p .707 .577 .707 r
F P
0 g
s
.33806 .79598 m .3372 .81385 L .35346 .80443 L p .707 .577 .707 r
F P
0 g
s
.35346 .80443 m .35433 .78656 L .33806 .79598 L p .707 .577 .707 r
F P
0 g
s
.66675 .79498 m .66474 .81362 L .63741 .80715 L p .707 .577 .707 r
F P
0 g
s
.17237 .80312 m .17324 .78525 L .16056 .77395 L p .707 .577 .707 r
F P
0 g
s
.16042 .62333 m .15695 .67613 L .15996 .689 L p .707 .577 .707 r
F P
0 g
s
.16056 .77395 m .1597 .79182 L .17237 .80312 L p .707 .577 .707 r
F P
0 g
s
.15695 .67613 m .16042 .62333 L .16738 .61125 L p .707 .577 .707 r
F P
0 g
s
.16307 .75675 m .15968 .71852 L .15684 .71668 L p .707 .577 .707 r
F P
0 g
s
.64403 .28343 m .64403 .78532 L .6394 .77327 L p .707 .577 .707 r
F P
0 g
s
.6394 .77327 m .6394 .27139 L .64403 .28343 L p .707 .577 .707 r
F P
0 g
s
.15684 .71668 m .16024 .75491 L .16307 .75675 L p .707 .577 .707 r
F P
0 g
s
.35433 .78656 m .35346 .80443 L .36043 .79326 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.1597 .79182 m .16056 .77395 L .15756 .76213 L p .707 .577 .707 r
F P
0 g
s
.34798 .73521 m .34459 .69698 L .35709 .6978 L p .707 .577 .707 r
F P
0 g
s
.3583 .76358 m .35744 .78145 L .34476 .77014 L p .707 .577 .707 r
F P
0 g
s
.34476 .77014 m .34563 .75227 L .3583 .76358 L p .707 .577 .707 r
F P
0 g
s
.35597 .27923 m .35597 .78112 L .3606 .79316 L p .707 .577 .707 r
F P
0 g
s
.35597 .78112 m .35597 .27923 L .36544 .26739 L p .707 .577 .707 r
F P
0 g
s
.16738 .61125 m .16391 .66405 L .15695 .67613 L p .707 .577 .707 r
F P
0 g
s
.15756 .76213 m .1567 .78001 L .1597 .79182 L p .707 .577 .707 r
F P
0 g
s
.16391 .66405 m .16738 .61125 L .18362 .60115 L p .707 .577 .707 r
F P
0 g
s
.16024 .75491 m .15684 .71668 L .16394 .71401 L p .707 .577 .707 r
F P
0 g
s
.16394 .71401 m .16734 .75224 L .16024 .75491 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1567 .78001 m .15756 .76213 L .16454 .75097 L p .707 .577 .707 r
F P
0 g
s
.6394 .27139 m .6394 .77327 L .62113 .7622 L p .707 .577 .707 r
F P
0 g
s
.62113 .7622 m .62113 .26031 L .6394 .27139 L p .707 .577 .707 r
F P
0 g
s
.34832 .61437 m .34485 .66717 L .32375 .65643 L p .707 .577 .707 r
F P
0 g
s
.32375 .65643 m .32721 .60363 L .34832 .61437 L p .707 .577 .707 r
F P
0 g
s
.18362 .60115 m .18016 .65395 L .16391 .66405 L p .707 .577 .707 r
F P
0 g
s
.16454 .75097 m .16367 .76884 L .1567 .78001 L p .707 .577 .707 r
F P
0 g
s
.18016 .65395 m .18362 .60115 L .20755 .59403 L p .707 .577 .707 r
F P
0 g
s
.36544 .76928 m .36544 .26739 L .38808 .25691 L p .707 .577 .707 r
F P
0 g
s
.36544 .26739 m .36544 .76928 L .35597 .78112 L p .707 .577 .707 r
F P
0 g
s
.16734 .75224 m .16394 .71401 L .18029 .71076 L p .707 .577 .707 r
F P
0 g
s
.18029 .71076 m .18368 .74899 L .16734 .75224 L p .707 .577 .707 r
F P
0 g
s
.32721 .60363 m .32375 .65643 L .29628 .64842 L p .707 .577 .707 r
F P
0 g
s
.29628 .64842 m .29975 .59562 L .32721 .60363 L p .707 .577 .707 r
F P
0 g
s
.20409 .64683 m .20755 .59403 L .23684 .59057 L p .707 .577 .707 r
F P
0 g
s
.20755 .59403 m .20409 .64683 L .18016 .65395 L p .707 .577 .707 r
F P
0 g
s
.16367 .76884 m .16454 .75097 L .1808 .74155 L p .707 .577 .707 r
F P
0 g
s
.34459 .69698 m .34798 .73521 L .32704 .73548 L p .707 .577 .707 r
F P
0 g
s
.32704 .73548 m .32365 .69725 L .34459 .69698 L p .707 .577 .707 r
F P
0 g
s
.1808 .74155 m .17994 .75942 L .16367 .76884 L p .707 .577 .707 r
F P
0 g
s
.29975 .59562 m .29628 .64842 L .26514 .64392 L p .707 .577 .707 r
F P
0 g
s
.26514 .64392 m .26861 .59112 L .29975 .59562 L p .707 .577 .707 r
F P
0 g
s
.23338 .64337 m .23684 .59057 L .26861 .59112 L p .707 .577 .707 r
F P
0 g
s
.23684 .59057 m .23338 .64337 L .20409 .64683 L p .707 .577 .707 r
F P
0 g
s
.62113 .26031 m .62113 .7622 L .591 .75319 L p .707 .577 .707 r
F P
0 g
s
.591 .75319 m .591 .2513 L .62113 .26031 L p .707 .577 .707 r
F P
0 g
s
.26861 .59112 m .26514 .64392 L .23338 .64337 L p .707 .577 .707 r
F P
0 g
s
.18368 .74899 m .18029 .71076 L .20428 .70726 L p .707 .577 .707 r
F P
0 g
s
.34563 .75227 m .34476 .77014 L .32365 .76045 L p .707 .577 .707 r
F P
0 g
s
.32365 .76045 m .32451 .74258 L .34563 .75227 L p .707 .577 .707 r
F P
0 g
s
.20428 .70726 m .20767 .74549 L .18368 .74899 L p .707 .577 .707 r
F P
0 g
s
.38808 .25691 m .38808 .7588 L .36544 .76928 L p .707 .577 .707 r
F P
0 g
s
.38808 .7588 m .38808 .25691 L .42168 .24883 L p .707 .577 .707 r
F P
0 g
s
.17994 .75942 m .1808 .74155 L .20476 .73479 L p .707 .577 .707 r
F P
0 g
s
.73485 .64433 m .73139 .58724 L .70025 .58818 L p .707 .577 .707 r
F P
0 g
s
.73139 .58724 m .73485 .64433 L .76662 .64204 L p .707 .577 .707 r
F P
0 g
s
.76662 .64204 m .76316 .58495 L .73139 .58724 L p .707 .577 .707 r
F P
0 g
s
.32365 .69725 m .32704 .73548 L .29972 .73682 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .29632 .69858 L .32365 .69725 L p .707 .577 .707 r
F P
0 g
s
.76316 .58495 m .76662 .64204 L .79591 .63862 L p .707 .577 .707 r
F P
0 g
s
.79591 .63862 m .79244 .58153 L .76316 .58495 L p .707 .577 .707 r
F P
0 g
s
.20476 .73479 m .20389 .75266 L .17994 .75942 L p .707 .577 .707 r
F P
0 g
s
.70371 .64527 m .70025 .58818 L .67278 .58767 L p .707 .577 .707 r
F P
0 g
s
.70025 .58818 m .70371 .64527 L .73485 .64433 L p .707 .577 .707 r
F P
0 g
s
.20767 .74549 m .20428 .70726 L .23357 .70385 L p .707 .577 .707 r
F P
0 g
s
.32451 .74258 m .32365 .76045 L .29616 .75332 L p .707 .577 .707 r
F P
0 g
s
.29972 .73682 m .26868 .73909 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29632 .69858 m .29779 .7151 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29779 .7151 m .29972 .73682 L p .29136 .70586 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .29703 .73545 L .31522 .74017 L p .707 .577 .707 r
F P
0 g
s
.31522 .74017 m .32451 .74258 L p .31849 .74486 L .707 .577 .707 r
F P
0 g
s
.29616 .75332 m .31522 .74017 L .31849 .74486 L .707 .577 .707 r
F
.23357 .70385 m .23696 .74208 L .20767 .74549 L p F P
0 g
s
.67278 .58767 m .67625 .64476 L .70371 .64527 L p .707 .577 .707 r
F P
0 g
s
.79244 .58153 m .79591 .63862 L .81984 .63441 L p .707 .577 .707 r
F P
0 g
s
.81984 .63441 m .81638 .57732 L .79244 .58153 L p .707 .577 .707 r
F P
0 g
s
.591 .2513 m .591 .75319 L .55196 .74711 L p .707 .577 .707 r
F P
0 g
s
.55196 .74711 m .55196 .24522 L .591 .2513 L p .707 .577 .707 r
F P
0 g
s
.20389 .75266 m .20476 .73479 L .23407 .73136 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .26528 .70086 L .29632 .69858 L p .707 .577 .707 r
F P
0 g
s
.23696 .74208 m .23357 .70385 L .26528 .70086 L p .707 .577 .707 r
F P
0 g
s
.67625 .64476 m .67278 .58767 L .65168 .58576 L p .707 .577 .707 r
F P
0 g
s
.735 .75033 m .73413 .73138 L .71389 .73153 L p .707 .577 .707 r
F P
0 g
s
.71389 .73153 m .70297 .7316 L p .70966 .73551 L .707 .577 .707 r
F P
0 g
s
.735 .75033 m .71389 .73153 L .70966 .73551 L .707 .577 .707 r
F
.73413 .73138 m .735 .75033 L .76679 .74842 L p F P
0 g
s
.76679 .74842 m .76593 .72947 L .74717 .7306 L p .707 .577 .707 r
F P
0 g
s
.74717 .7306 m .73413 .73138 L p .74211 .73554 L .707 .577 .707 r
F P
0 g
s
.76679 .74842 m .74717 .7306 L .74211 .73554 L .707 .577 .707 r
F
.76593 .72947 m .76679 .74842 L .7961 .74501 L p F P
0 g
s
.7961 .74501 m .79524 .72606 L .77973 .72787 L p .707 .577 .707 r
F P
0 g
s
.77973 .72787 m .76593 .72947 L p .77476 .73402 L .707 .577 .707 r
F P
0 g
s
.7961 .74501 m .77973 .72787 L .77476 .73402 L .707 .577 .707 r
F
.79524 .72606 m .7961 .74501 L .82006 .74042 L p F P
0 g
s
.82006 .74042 m .8192 .72148 L .80787 .72364 L p .707 .577 .707 r
F P
0 g
s
.80787 .72364 m .79524 .72606 L p .804 .73113 L .707 .577 .707 r
F P
0 g
s
.82006 .74042 m .80787 .72364 L .804 .73113 L .707 .577 .707 r
F
.8192 .72148 m .82006 .74042 L .83633 .73512 L p F P
0 g
s
.83633 .73512 m .83546 .71618 L .8192 .72148 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .83266 .71377 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81971 .69107 m .81851 .70309 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.81851 .70309 m .81631 .72509 L p .82234 .69568 L .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .81631 .72509 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79572 .69884 m .79467 .70936 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.79467 .70936 m .79232 .73287 L p .79938 .70351 L .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .79232 .73287 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76643 .70231 m .76538 .71279 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.76538 .71279 m .76304 .73633 L p .77082 .70748 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .76304 .73633 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73471 .70112 m .73352 .71305 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73352 .71305 m .73132 .73515 L p .73967 .70728 L .707 .577 .707 r
F P
0 g
s
.73132 .73515 m .73471 .70112 L .70367 .6954 L p .707 .577 .707 r
F P
0 g
s
.76304 .73633 m .76643 .70231 L .73471 .70112 L p .707 .577 .707 r
F P
0 g
s
.23407 .73136 m .23321 .74923 L .20389 .75266 L p .707 .577 .707 r
F P
0 g
s
.42168 .75072 m .42168 .24883 L .46294 .24392 L p .707 .577 .707 r
F P
0 g
s
.42168 .24883 m .42168 .75072 L .38808 .7588 L p .707 .577 .707 r
F P
0 g
s
.26868 .73909 m .23696 .74208 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.26647 .71427 m .26868 .73909 L p .26033 .70807 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .26586 .73158 L .28611 .7341 L p .707 .577 .707 r
F P
0 g
s
.28611 .7341 m .29703 .73545 L p .29034 .73838 L .707 .577 .707 r
F P
0 g
s
.265 .74946 m .28611 .7341 L .29034 .73838 L .707 .577 .707 r
F
.26528 .70086 m .26647 .71427 L p .26033 .70807 L F P
0 g
s
.29703 .73545 m .29616 .75332 L .265 .74946 L p .707 .577 .707 r
F P
0 g
s
.79232 .73287 m .79572 .69884 L .76643 .70231 L p .707 .577 .707 r
F P
0 g
s
.70028 .72943 m .70367 .6954 L .67635 .68571 L p .707 .577 .707 r
F P
0 g
s
.70367 .6954 m .70028 .72943 L .73132 .73515 L p .707 .577 .707 r
F P
0 g
s
.23321 .74923 m .23407 .73136 L .26586 .73158 L p .707 .577 .707 r
F P
0 g
s
.65168 .58576 m .65514 .64285 L .67625 .64476 L p .707 .577 .707 r
F P
0 g
s
.26586 .73158 m .265 .74946 L .23321 .74923 L p .707 .577 .707 r
F P
0 g
s
.81638 .57732 m .81984 .63441 L .83608 .6298 L p .707 .577 .707 r
F P
0 g
s
.83608 .6298 m .83262 .57271 L .81638 .57732 L p .707 .577 .707 r
F P
0 g
s
.70297 .7316 m .70383 .75055 L .735 .75033 L p .707 .577 .707 r
F P
0 g
s
.55196 .24522 m .55196 .74711 L .50783 .74457 L p .707 .577 .707 r
F P
0 g
s
.50783 .74457 m .50783 .24268 L .55196 .24522 L p .707 .577 .707 r
F P
0 g
s
.81631 .72509 m .81971 .69107 L .79572 .69884 L p .707 .577 .707 r
F P
0 g
s
.70383 .75055 m .70297 .7316 L .67549 .73011 L p .707 .577 .707 r
F P
0 g
s
.46294 .74581 m .46294 .24392 L .50783 .24268 L p .707 .577 .707 r
F P
0 g
s
.46294 .24392 m .46294 .74581 L .42168 .75072 L p .707 .577 .707 r
F P
0 g
s
.67295 .71974 m .67635 .68571 L .65541 .67299 L p .707 .577 .707 r
F P
0 g
s
.67635 .68571 m .67295 .71974 L .70028 .72943 L p .707 .577 .707 r
F P
0 g
s
.67549 .73011 m .67635 .74906 L .70383 .75055 L p .707 .577 .707 r
F P
0 g
s
.50783 .24268 m .50783 .74457 L .46294 .74581 L p .707 .577 .707 r
F P
0 g
s
.65514 .64285 m .65168 .58576 L .63901 .58264 L p .707 .577 .707 r
F P
0 g
s
.63901 .58264 m .64247 .63973 L .65514 .64285 L p .707 .577 .707 r
F P
0 g
s
.67635 .74906 m .67549 .73011 L .65437 .72706 L p .707 .577 .707 r
F P
0 g
s
.83266 .71377 m .83605 .67974 L .81971 .69107 L p .707 .577 .707 r
F P
0 g
s
.65437 .72706 m .65524 .746 L .67635 .74906 L p .707 .577 .707 r
F P
0 g
s
.65541 .67299 m .65202 .70702 L .67295 .71974 L p .707 .577 .707 r
F P
0 g
s
.65202 .70702 m .65541 .67299 L .64291 .65849 L p .707 .577 .707 r
F P
0 g
s
.83262 .57271 m .83608 .6298 L .84304 .62527 L p .707 .577 .707 r
F P
0 g
s
.84304 .62527 m .83958 .56818 L .83262 .57271 L p .707 .577 .707 r
F P
0 g
s
.64247 .63973 m .63901 .58264 L .636 .57862 L p .707 .577 .707 r
F P
0 g
s
.65524 .746 m .65437 .72706 L .6417 .72274 L p .707 .577 .707 r
F P
0 g
s
.64291 .65849 m .63952 .69252 L .65202 .70702 L p .707 .577 .707 r
F P
0 g
s
.6417 .72274 m .64256 .74168 L .65524 .746 L p .707 .577 .707 r
F P
0 g
s
.636 .57862 m .63947 .63571 L .64247 .63973 L p .707 .577 .707 r
F P
0 g
s
.83605 .67974 m .83266 .71377 L .83976 .7 L p .707 .577 .707 r
F P
0 g
s
.83976 .7 m .84316 .66598 L .83605 .67974 L p .707 .577 .707 r
F P
0 g
s
.63952 .69252 m .64291 .65849 L .64007 .64363 L p .707 .577 .707 r
F P
0 g
s
.83958 .56818 m .84304 .62527 L .84004 .62125 L p .707 .577 .707 r
F P
0 g
s
.84004 .62125 m .83658 .56416 L .83958 .56818 L p .707 .577 .707 r
F P
0 g
s
.83546 .71618 m .83633 .73512 L .8433 .72962 L p .707 .577 .707 r
F P
0 g
s
.8433 .72962 m .84243 .71067 L .83546 .71618 L p .707 .577 .707 r
F P
0 g
s
.64007 .64363 m .63668 .67766 L .63952 .69252 L p .707 .577 .707 r
F P
0 g
s
.63947 .63571 m .636 .57862 L .64296 .57409 L p .707 .577 .707 r
F P
0 g
s
.64256 .74168 m .6417 .72274 L .6387 .71757 L p .707 .577 .707 r
F P
0 g
s
.6387 .71757 m .63956 .73652 L .64256 .74168 L p .707 .577 .707 r
F P
0 g
s
.84316 .66598 m .83976 .7 L .83693 .68515 L p .707 .577 .707 r
F P
0 g
s
.83693 .68515 m .84032 .65112 L .84316 .66598 L p .707 .577 .707 r
F P
0 g
s
.64296 .57409 m .64643 .63118 L .63947 .63571 L p .707 .577 .707 r
F P
0 g
s
.63668 .67766 m .64007 .64363 L .64718 .62987 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83658 .56416 m .84004 .62125 L .82737 .61813 L p .707 .577 .707 r
F P
0 g
s
.82737 .61813 m .8239 .56104 L .83658 .56416 L p .707 .577 .707 r
F P
0 g
s
.84243 .71067 m .8433 .72962 L .8403 .72445 L p .707 .577 .707 r
F P
0 g
s
.8403 .72445 m .83944 .70551 L .84243 .71067 L p .707 .577 .707 r
F P
0 g
s
.39308 .62674 m .38505 .57272 L .35418 .57452 L p .707 .577 .707 r
F P
0 g
s
.38505 .57272 m .39308 .62674 L .42461 .62161 L p .707 .577 .707 r
F P
0 g
s
.42461 .62161 m .41658 .56758 L .38505 .57272 L p .707 .577 .707 r
F P
0 g
s
.41658 .56758 m .42461 .62161 L .4537 .61364 L p .707 .577 .707 r
F P
0 g
s
.4537 .61364 m .44567 .55961 L .41658 .56758 L p .707 .577 .707 r
F P
0 g
s
.65921 .56949 m .65992 .58131 L p .64643 .63118 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .64718 .62987 L .66352 .61854 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .64378 .6639 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .66269 .62688 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66013 .65257 L p .64995 .64973 L .707 .577 .707 r
F P
0 g
s
.66352 .61854 m .68751 .61077 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .6866 .62236 L .66652 .6259 L p .707 .577 .707 r
F P
0 g
s
.66013 .65257 m .66269 .62688 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.66269 .62688 m .66352 .61854 L p .67983 .6225 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .66013 .65257 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .68651 .62079 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68651 .62079 m .68412 .6448 L p .66443 .646 L .707 .577 .707 r
F P
0 g
s
.68751 .61077 m .7168 .60731 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.6866 .62236 m .68651 .62079 L .68732 .62069 L .707 .577 .707 r
F
.68651 .62079 m .68751 .61077 L p .70716 .61836 L F P
0 g
s
.71589 .61894 m .6866 .62236 L p .68732 .62069 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .71426 .61753 L .71589 .61894 L .707 .577 .707 r
F
.71341 .64133 m .68412 .6448 L p .70716 .61836 L F P
0 g
s
.7168 .60731 m .7158 .61734 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.7168 .60731 m .74852 .60849 L p .7394 .61701 L .707 .577 .707 r
F P
0 g
s
.74335 .61696 m .71589 .61894 L p .71665 .61733 L .707 .577 .707 r
F P
0 g
s
.72838 .62732 m .72255 .61725 L .7394 .61701 L .707 .577 .707 r
F
.72255 .61725 m .7168 .60731 L .7394 .61701 L F
.74852 .60849 m .74768 .61689 L p .71341 .64133 L F P
0 g
s
.74768 .61689 m .74512 .64252 L .71891 .64154 L p .707 .577 .707 r
F P
0 g
s
.71891 .64154 m .71341 .64133 L p .74768 .61689 L .707 .577 .707 r
F P
0 g
s
.74512 .64252 m .74852 .60849 L .77956 .61421 L p .707 .577 .707 r
F P
0 g
s
.77533 .55862 m .77733 .59149 L p .74766 .61665 L .707 .577 .707 r
F P
0 g
s
.77956 .61421 m .77903 .61947 L p .74512 .64252 L .707 .577 .707 r
F P
0 g
s
.77903 .61947 m .77616 .64824 L .75562 .64445 L p .707 .577 .707 r
F P
0 g
s
.75562 .64445 m .74512 .64252 L p .77903 .61947 L .707 .577 .707 r
F P
0 g
s
.77616 .64824 m .77956 .61421 L .80688 .6239 L p .707 .577 .707 r
F P
0 g
s
.8028 .55913 m .80479 .59199 L p .7788 .61571 L .707 .577 .707 r
F P
0 g
s
.80479 .59199 m .80626 .61622 L .78249 .61578 L p .707 .577 .707 r
F P
0 g
s
.78249 .61578 m .7788 .61571 L p .80479 .59199 L .707 .577 .707 r
F P
0 g
s
.77733 .59149 m .7788 .61571 L .74797 .61664 L p .707 .577 .707 r
F P
0 g
s
.74797 .61664 m .74766 .61665 L p .77733 .59149 L .707 .577 .707 r
F P
0 g
s
.74419 .55956 m .74766 .61665 L .74335 .61696 L p .707 .577 .707 r
F P
0 g
s
.71589 .61894 m .7158 .61734 L .71665 .61733 L .707 .577 .707 r
F
.7158 .61735 m .7158 .61734 L p .72838 .62732 L F P
0 g
s
.7158 .61734 m .7168 .60731 L p .72255 .61725 L .707 .577 .707 r
F P
0 g
s
.7158 .61734 m .72255 .61725 L .72838 .62732 L .707 .577 .707 r
F
.71589 .61894 m .71579 .61735 L p .7158 .61734 L F P
0 g
s
.71665 .61733 m .7158 .61734 L .71728 .61602 L .707 .577 .707 r
F
.71665 .61733 m .74419 .55956 L .74335 .61696 L F
.71243 .56185 m .74419 .55956 L p .71728 .61602 L F P
0 g
s
.70716 .61836 m .7158 .61734 L .71579 .61735 L .707 .577 .707 r
F
.71579 .61735 m .71243 .56185 L p .71728 .61602 L F P
0 g
s
.7158 .61734 m .7158 .61735 L p .71579 .61735 L .707 .577 .707 r
F P
0 g
s
.71579 .61734 m .71589 .61894 L p .69558 .60132 L .707 .577 .707 r
F P
0 g
s
.7158 .61735 m .71341 .64133 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .69558 .60132 L .71426 .61753 L .707 .577 .707 r
F
.71243 .56185 m .71579 .61734 L p .69558 .60132 L F P
0 g
s
.71341 .64133 m .7158 .61735 L p .72838 .62732 L .707 .577 .707 r
F P
0 g
s
.68412 .6448 m .68651 .62079 L p .70716 .61836 L .707 .577 .707 r
F P
0 g
s
.68732 .62069 m .68651 .62079 L .688 .61909 L .707 .577 .707 r
F
.68314 .56527 m .71243 .56185 L p .688 .61909 L F P
0 g
s
.68651 .62079 m .68314 .56527 L p .688 .61909 L .707 .577 .707 r
F P
0 g
s
.6845 .58776 m .68651 .62079 L p .66288 .62654 L .707 .577 .707 r
F P
0 g
s
.66652 .6259 m .66288 .62654 L p .68651 .62079 L .707 .577 .707 r
F P
0 g
s
.68314 .56527 m .6845 .58776 L p .66267 .62658 L .707 .577 .707 r
F P
0 g
s
.66288 .62654 m .66267 .62658 L p .6845 .58776 L .707 .577 .707 r
F P
0 g
s
.65992 .58131 m .66267 .62658 L .6477 .63082 L p .707 .577 .707 r
F P
0 g
s
.64718 .62987 m .64666 .63502 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.6477 .63082 m .64643 .63118 L p .65992 .58131 L .707 .577 .707 r
F P
0 g
s
.64378 .6639 m .63668 .67766 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.64666 .63502 m .64378 .6639 L p .64107 .65769 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36221 .62854 m .35418 .57452 L .32698 .57281 L p .707 .577 .707 r
F P
0 g
s
.35418 .57452 m .36221 .62854 L .39308 .62674 L p .707 .577 .707 r
F P
0 g
s
.64643 .63118 m .64296 .57409 L .65921 .56949 L p .707 .577 .707 r
F P
0 g
s
.63956 .73652 m .6387 .71757 L .64567 .71207 L p .707 .577 .707 r
F P
0 g
s
.84032 .65112 m .83693 .68515 L .82443 .67065 L p .707 .577 .707 r
F P
0 g
s
.82443 .67065 m .82782 .63662 L .84032 .65112 L p .707 .577 .707 r
F P
0 g
s
.44567 .55961 m .4537 .61364 L .47751 .60361 L p .707 .577 .707 r
F P
0 g
s
.47751 .60361 m .46948 .54959 L .44567 .55961 L p .707 .577 .707 r
F P
0 g
s
.64567 .71207 m .64654 .73101 L .63956 .73652 L p .707 .577 .707 r
F P
0 g
s
.38526 .67084 m .3931 .63382 L .36264 .62624 L p .707 .577 .707 r
F P
0 g
s
.3931 .63382 m .38526 .67084 L .41645 .67674 L p .707 .577 .707 r
F P
0 g
s
.41645 .67674 m .42429 .63972 L .3931 .63382 L p .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .30612 .56775 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33495 .62639 m .32698 .57281 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.32698 .57281 m .32914 .58728 L p .36221 .62854 L .707 .577 .707 r
F P
0 g
s
.32914 .58728 m .33501 .62683 L .35953 .62837 L p .707 .577 .707 r
F P
0 g
s
.35953 .62837 m .36221 .62854 L p .32914 .58728 L .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .38526 .67084 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.36264 .62624 m .3616 .63116 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.3616 .63116 m .3548 .66326 L p .37285 .64637 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .33411 .62616 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .3096 .59114 L p .33501 .62683 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32805 .65474 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.30764 .64612 m .32805 .65474 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .32258 .60969 L .314 .62075 L .707 .577 .707 r
F
.3096 .59114 m .31383 .61962 L p .32258 .60969 L F P
0 g
s
.31383 .61962 m .314 .62075 L p .32258 .60969 L .707 .577 .707 r
F P
0 g
s
.30612 .56775 m .29364 .55984 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31383 .61962 m .30612 .56775 L p .31336 .61936 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31307 .6205 L p .314 .62075 L .707 .577 .707 r
F P
0 g
s
.30598 .62854 m .31108 .61811 L .30466 .61457 L .707 .577 .707 r
F
.30764 .64612 m .31307 .6205 L p .30598 .62854 L F P
0 g
s
.31307 .6205 m .31331 .61934 L p .30598 .62854 L .707 .577 .707 r
F P
0 g
s
.31331 .61934 m .31108 .61811 L .30598 .62854 L .707 .577 .707 r
F
.31307 .6205 m .30764 .64612 L p .3169 .62667 L F P
0 g
s
.31907 .62211 m .314 .62075 L .3169 .62667 L .707 .577 .707 r
F
.314 .62075 m .31307 .6205 L .3169 .62667 L F
.31336 .61936 m .30664 .5991 L .30152 .61284 L F
.29364 .55984 m .30135 .61171 L p .30664 .5991 L F P
0 g
s
.30135 .61171 m .30152 .61284 L p .30664 .5991 L .707 .577 .707 r
F P
0 g
s
.29364 .55984 m .29076 .54986 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .30764 .64612 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.30132 .61178 m .30135 .61171 L .30126 .61144 L .707 .577 .707 r
F
.30152 .61284 m .30135 .61171 L p .30132 .61178 L F P
0 g
s
.30135 .61171 m .29364 .55984 L p .30126 .61144 L .707 .577 .707 r
F P
0 g
s
.30124 .61139 m .29556 .63824 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29773 .62033 m .30078 .61005 L .29945 .60622 L .707 .577 .707 r
F
.301 .61255 m .30124 .61139 L p .29773 .62033 L F P
0 g
s
.30124 .61139 m .30078 .61005 L .29773 .62033 L .707 .577 .707 r
F
.29955 .60651 m .30167 .61387 L p .30126 .61144 L F P
0 g
s
.30126 .61144 m .29076 .54986 L .29955 .60651 L .707 .577 .707 r
F
.30124 .61139 m .3034 .60122 L p .30078 .61005 L F P
0 g
s
.3034 .60122 m .30124 .61139 L p .30739 .64346 L .707 .577 .707 r
F P
0 g
s
.29879 .60389 m .29955 .60651 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.3034 .60122 m .30083 .59485 L p .29945 .60622 L .707 .577 .707 r
F P
0 g
s
.30078 .61005 m .3034 .60122 L .29945 .60622 L .707 .577 .707 r
F
.31548 .6091 m .3034 .60122 L p .30466 .61457 L F P
0 g
s
.30083 .59485 m .30802 .59061 L p .30536 .59793 L .707 .577 .707 r
F P
0 g
s
.30038 .60203 m .30083 .59485 L .30536 .59793 L .707 .577 .707 r
F
.29879 .60389 m .29878 .60334 L .29908 .6031 L F
.30083 .59485 m .29908 .6031 L p .29556 .63824 L F P
0 g
s
.29526 .63749 m .29556 .63824 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29952 .60273 m .29904 .6035 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29904 .6035 m .29879 .60389 L p .29908 .6031 L .707 .577 .707 r
F P
0 g
s
.29908 .6031 m .29299 .63187 L .29526 .63749 L p .707 .577 .707 r
F P
0 g
s
.29881 .60438 m .30083 .59485 L p .29965 .61357 L .707 .577 .707 r
F P
0 g
s
.29777 .53878 m .3058 .59281 L .29952 .60273 L p .707 .577 .707 r
F P
0 g
s
.29878 .60334 m .29777 .53878 L .29952 .60273 L .707 .577 .707 r
F
.29965 .61357 m .30038 .60203 L .30536 .59793 L F
.29299 .63187 m .29881 .60438 L p .29965 .61357 L F P
0 g
s
.29076 .54986 m .29872 .60339 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.29872 .60339 m .29879 .60389 L p .29821 .5979 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .30152 .61284 L p .30132 .61178 L .707 .577 .707 r
F P
0 g
s
.29556 .63824 m .301 .61255 L p .29773 .62033 L .707 .577 .707 r
F P
0 g
s
.30167 .61387 m .31415 .62177 L p .31342 .61956 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31336 .61936 L .31331 .61934 L .707 .577 .707 r
F
.31342 .61956 m .31331 .61934 L .30167 .61387 L F
.30152 .61284 m .30167 .61387 L p .31336 .61936 L F P
0 g
s
.31331 .61934 m .31548 .6091 L p .31108 .61811 L .707 .577 .707 r
F P
0 g
s
.31548 .6091 m .31331 .61934 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.31342 .61956 m .31383 .61962 L .31336 .61936 L .707 .577 .707 r
F
.314 .62075 m .31383 .61962 L p .31342 .61956 L F P
0 g
s
.31907 .62211 m .31331 .61934 L .314 .62075 L .707 .577 .707 r
F
.31415 .62177 m .314 .62075 L p .31342 .61956 L F P
0 g
s
.31108 .61811 m .31548 .6091 L .30466 .61457 L .707 .577 .707 r
F
.31415 .62177 m .33449 .6267 L p .33411 .62616 L F P
0 g
s
.314 .62075 m .31415 .62177 L p .33411 .62616 L .707 .577 .707 r
F P
0 g
s
.33449 .6267 m .33501 .62683 L p .3096 .59114 L .707 .577 .707 r
F P
0 g
s
.32805 .65474 m .3548 .66326 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33501 .62683 m .33495 .62639 L p .33477 .62634 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .33411 .62616 L p .34711 .64475 L .707 .577 .707 r
F P
0 g
s
.33589 .61772 m .31548 .6091 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.33411 .62616 m .33589 .61772 L p .31907 .62211 L .707 .577 .707 r
F P
0 g
s
.8239 .56104 m .82737 .61813 L .80626 .61622 L p .707 .577 .707 r
F P
0 g
s
.80626 .61622 m .8028 .55913 L .8239 .56104 L p .707 .577 .707 r
F P
0 g
s
.42429 .63972 m .41645 .67674 L .44532 .68039 L p .707 .577 .707 r
F P
0 g
s
.44532 .68039 m .45316 .64337 L .42429 .63972 L p .707 .577 .707 r
F P
0 g
s
.3548 .66326 m .36264 .62624 L .33589 .61772 L p .707 .577 .707 r
F P
0 g
s
.83944 .70551 m .8403 .72445 L .82763 .72013 L p .707 .577 .707 r
F P
0 g
s
.82763 .72013 m .82676 .70119 L .83944 .70551 L p .707 .577 .707 r
F P
0 g
s
.46948 .54959 m .47751 .60361 L .49371 .59252 L p .707 .577 .707 r
F P
0 g
s
.49371 .59252 m .48568 .5385 L .46948 .54959 L p .707 .577 .707 r
F P
0 g
s
.66267 .62658 m .65921 .56949 L .68314 .56527 L p .707 .577 .707 r
F P
0 g
s
.82782 .63662 m .82443 .67065 L .80349 .65793 L p .707 .577 .707 r
F P
0 g
s
.80349 .65793 m .80688 .6239 L .82782 .63662 L p .707 .577 .707 r
F P
0 g
s
.45316 .64337 m .44532 .68039 L .46904 .68142 L p .707 .577 .707 r
F P
0 g
s
.46904 .68142 m .47688 .6444 L .45316 .64337 L p .707 .577 .707 r
F P
0 g
s
.3936 .72747 m .39159 .7093 L .36058 .7102 L p .707 .577 .707 r
F P
0 g
s
.39159 .7093 m .3936 .72747 L .42526 .7234 L p .707 .577 .707 r
F P
0 g
s
.42526 .7234 m .42325 .70522 L .39159 .7093 L p .707 .577 .707 r
F P
0 g
s
.64654 .73101 m .64567 .71207 L .66194 .70677 L p .707 .577 .707 r
F P
0 g
s
.42325 .70522 m .42526 .7234 L .45446 .71655 L p .707 .577 .707 r
F P
0 g
s
.45446 .71655 m .45245 .69837 L .42325 .70522 L p .707 .577 .707 r
F P
0 g
s
.66194 .70677 m .6628 .72571 L .64654 .73101 L p .707 .577 .707 r
F P
0 g
s
.36058 .7102 m .36259 .72838 L .3936 .72747 L p .707 .577 .707 r
F P
0 g
s
.36259 .72838 m .36058 .7102 L .33325 .70785 L p .707 .577 .707 r
F P
0 g
s
.7788 .61571 m .77533 .55862 L .8028 .55913 L p .707 .577 .707 r
F P
0 g
s
.45245 .69837 m .45446 .71655 L .47835 .70759 L p .707 .577 .707 r
F P
0 g
s
.47835 .70759 m .47634 .68942 L .45245 .69837 L p .707 .577 .707 r
F P
0 g
s
.33325 .70785 m .33526 .72602 L .36259 .72838 L p .707 .577 .707 r
F P
0 g
s
.48568 .5385 m .49371 .59252 L .50071 .58144 L p .707 .577 .707 r
F P
0 g
s
.50071 .58144 m .49268 .52742 L .48568 .5385 L p .707 .577 .707 r
F P
0 g
s
.80688 .6239 m .80349 .65793 L .77616 .64824 L p .707 .577 .707 r
F P
0 g
s
.82676 .70119 m .82763 .72013 L .80651 .71707 L p .707 .577 .707 r
F P
0 g
s
.80651 .71707 m .80565 .69813 L .82676 .70119 L p .707 .577 .707 r
F P
0 g
s
.47688 .6444 m .46904 .68142 L .48529 .67973 L p .707 .577 .707 r
F P
0 g
s
.48529 .67973 m .49313 .64271 L .47688 .6444 L p .707 .577 .707 r
F P
0 g
s
.33526 .72602 m .33325 .70785 L .31227 .70246 L p .707 .577 .707 r
F P
0 g
s
.74766 .61665 m .74419 .55956 L .77533 .55862 L p .707 .577 .707 r
F P
0 g
s
.6628 .72571 m .66194 .70677 L .68589 .70218 L p .707 .577 .707 r
F P
0 g
s
.31227 .70246 m .31428 .72064 L .33526 .72602 L p .707 .577 .707 r
F P
0 g
s
.68589 .70218 m .68676 .72113 L .6628 .72571 L p .707 .577 .707 r
F P
0 g
s
.47634 .68942 m .47835 .70759 L .49459 .69741 L p .707 .577 .707 r
F P
0 g
s
.49459 .69741 m .49258 .67924 L .47634 .68942 L p .707 .577 .707 r
F P
0 g
s
.80565 .69813 m .80651 .71707 L .77903 .71558 L p .707 .577 .707 r
F P
0 g
s
.77903 .71558 m .77816 .69664 L .80565 .69813 L p .707 .577 .707 r
F P
0 g
s
.49268 .52742 m .50071 .58144 L .49783 .57146 L p .707 .577 .707 r
F P
0 g
s
.49783 .57146 m .4898 .51743 L .49268 .52742 L p .707 .577 .707 r
F P
0 g
s
.49313 .64271 m .48529 .67973 L .49249 .6755 L p .707 .577 .707 r
F P
0 g
s
.49249 .6755 m .50033 .63848 L .49313 .64271 L p .707 .577 .707 r
F P
0 g
s
.31428 .72064 m .31227 .70246 L .2997 .69457 L p .707 .577 .707 r
F P
0 g
s
.68676 .72113 m .68589 .70218 L .71521 .69877 L p .707 .577 .707 r
F P
0 g
s
.71521 .69877 m .71607 .71772 L .68676 .72113 L p .707 .577 .707 r
F P
0 g
s
.2997 .69457 m .30171 .71275 L .31428 .72064 L p .707 .577 .707 r
F P
0 g
s
.77816 .69664 m .77903 .71558 L .74786 .71581 L p .707 .577 .707 r
F P
0 g
s
.74786 .71581 m .747 .69686 L .77816 .69664 L p .707 .577 .707 r
F P
0 g
s
.49258 .67924 m .49459 .69741 L .50159 .68701 L p .707 .577 .707 r
F P
0 g
s
.50159 .68701 m .49958 .66883 L .49258 .67924 L p .707 .577 .707 r
F P
0 g
s
.71607 .71772 m .71521 .69877 L .747 .69686 L p .707 .577 .707 r
F P
0 g
s
.747 .69686 m .74786 .71581 L .71607 .71772 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29879 .60389 m .29076 .54986 L .29777 .53878 L p .707 .577 .707 r
F P
0 g
s
.4898 .51743 m .49783 .57146 L .48535 .56355 L p .707 .577 .707 r
F P
0 g
s
.48535 .56355 m .47732 .50953 L .4898 .51743 L p .707 .577 .707 r
F P
0 g
s
.30171 .71275 m .2997 .69457 L .29677 .68495 L p .707 .577 .707 r
F P
0 g
s
.50033 .63848 m .49249 .6755 L .48992 .66913 L p .707 .577 .707 r
F P
0 g
s
.48992 .66913 m .49776 .63211 L .50033 .63848 L p .707 .577 .707 r
F P
0 g
s
.29677 .68495 m .29878 .70313 L .30171 .71275 L p .707 .577 .707 r
F P
0 g
s
.49958 .66883 m .50159 .68701 L .49866 .67739 L p .707 .577 .707 r
F P
0 g
s
.49866 .67739 m .49665 .65921 L .49958 .66883 L p .707 .577 .707 r
F P
0 g
s
.31396 .52769 m .31882 .56037 L p .3058 .59281 L .707 .577 .707 r
F P
0 g
s
.30018 .62763 m .30802 .59061 L .32428 .58893 L p .707 .577 .707 r
F P
0 g
s
.31882 .56037 m .32199 .58171 L .30848 .59097 L p .707 .577 .707 r
F P
0 g
s
.30802 .59061 m .30705 .59519 L p .29299 .63187 L .707 .577 .707 r
F P
0 g
s
.30848 .59097 m .3058 .59281 L p .31882 .56037 L .707 .577 .707 r
F P
0 g
s
.30705 .59519 m .30018 .62763 L .29507 .63064 L p .707 .577 .707 r
F P
0 g
s
.29507 .63064 m .29299 .63187 L p .30705 .59519 L .707 .577 .707 r
F P
0 g
s
.3058 .59281 m .29777 .53878 L .31396 .52769 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47732 .50953 m .48535 .56355 L .46449 .5585 L p .707 .577 .707 r
F P
0 g
s
.46449 .5585 m .45646 .50447 L .47732 .50953 L p .707 .577 .707 r
F P
0 g
s
.29878 .70313 m .29677 .68495 L .30377 .67455 L p .707 .577 .707 r
F P
0 g
s
.49776 .63211 m .48992 .66913 L .47784 .66124 L p .707 .577 .707 r
F P
0 g
s
.47784 .66124 m .48567 .62423 L .49776 .63211 L p .707 .577 .707 r
F P
0 g
s
.30377 .67455 m .30578 .69272 L .29878 .70313 L p .707 .577 .707 r
F P
0 g
s
.49665 .65921 m .49866 .67739 L .48609 .6695 L p .707 .577 .707 r
F P
0 g
s
.48609 .6695 m .48408 .65132 L .49665 .65921 L p .707 .577 .707 r
F P
0 g
s
.32199 .58171 m .31396 .52769 L .33778 .51767 L p .707 .577 .707 r
F P
0 g
s
.32428 .58893 m .31644 .62595 L .30018 .62763 L p .707 .577 .707 r
F P
0 g
s
.45646 .50447 m .46449 .5585 L .43729 .55679 L p .707 .577 .707 r
F P
0 g
s
.43729 .55679 m .42926 .50276 L .45646 .50447 L p .707 .577 .707 r
F P
0 g
s
.30578 .69272 m .30377 .67455 L .32001 .66437 L p .707 .577 .707 r
F P
0 g
s
.48567 .62423 m .47784 .66124 L .45742 .65262 L p .707 .577 .707 r
F P
0 g
s
.45742 .65262 m .46526 .6156 L .48567 .62423 L p .707 .577 .707 r
F P
0 g
s
.33778 .51767 m .34581 .57169 L .32199 .58171 L p .707 .577 .707 r
F P
0 g
s
.34581 .57169 m .33778 .51767 L .36687 .5097 L p .707 .577 .707 r
F P
0 g
s
.32001 .66437 m .32202 .68254 L .30578 .69272 L p .707 .577 .707 r
F P
0 g
s
.31644 .62595 m .32428 .58893 L .348 .58996 L p .707 .577 .707 r
F P
0 g
s
.42926 .50276 m .43729 .55679 L .40642 .55859 L p .707 .577 .707 r
F P
0 g
s
.40642 .55859 m .39839 .50456 L .42926 .50276 L p .707 .577 .707 r
F P
0 g
s
.48408 .65132 m .48609 .6695 L .46511 .66411 L p .707 .577 .707 r
F P
0 g
s
.46511 .66411 m .4631 .64594 L .48408 .65132 L p .707 .577 .707 r
F P
0 g
s
.348 .58996 m .34016 .62698 L .31644 .62595 L p .707 .577 .707 r
F P
0 g
s
.3749 .56372 m .36687 .5097 L .39839 .50456 L p .707 .577 .707 r
F P
0 g
s
.36687 .5097 m .3749 .56372 L .34581 .57169 L p .707 .577 .707 r
F P
0 g
s
.39839 .50456 m .40642 .55859 L .3749 .56372 L p .707 .577 .707 r
F P
0 g
s
.46526 .6156 m .45742 .65262 L .43068 .6441 L p .707 .577 .707 r
F P
0 g
s
.43068 .6441 m .43852 .60708 L .46526 .6156 L p .707 .577 .707 r
F P
0 g
s
.32202 .68254 m .32001 .66437 L .3439 .65541 L p .707 .577 .707 r
F P
0 g
s
.34016 .62698 m .348 .58996 L .37687 .5936 L p .707 .577 .707 r
F P
0 g
s
.3439 .65541 m .34591 .67359 L .32202 .68254 L p .707 .577 .707 r
F P
0 g
s
.4631 .64594 m .46511 .66411 L .43778 .66176 L p .707 .577 .707 r
F P
0 g
s
.43778 .66176 m .43577 .64358 L .4631 .64594 L p .707 .577 .707 r
F P
0 g
s
.37687 .5936 m .36903 .63062 L .34016 .62698 L p .707 .577 .707 r
F P
0 g
s
.43852 .60708 m .43068 .6441 L .40022 .63652 L p .707 .577 .707 r
F P
0 g
s
.40022 .63652 m .40806 .5995 L .43852 .60708 L p .707 .577 .707 r
F P
0 g
s
.36903 .63062 m .37687 .5936 L .40806 .5995 L p .707 .577 .707 r
F P
0 g
s
.34591 .67359 m .3439 .65541 L .3731 .64856 L p .707 .577 .707 r
F P
0 g
s
.40806 .5995 m .40022 .63652 L .36903 .63062 L p .707 .577 .707 r
F P
0 g
s
.43577 .64358 m .43778 .66176 L .40677 .66266 L p .707 .577 .707 r
F P
0 g
s
.40677 .66266 m .40476 .64449 L .43577 .64358 L p .707 .577 .707 r
F P
0 g
s
.3731 .64856 m .37511 .66674 L .34591 .67359 L p .707 .577 .707 r
F P
0 g
s
.37511 .66674 m .3731 .64856 L .40476 .64449 L p .707 .577 .707 r
F P
0 g
s
.40476 .64449 m .40677 .66266 L .37511 .66674 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEQL000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001@0015YF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH0100025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0069oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005moo`<000IJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005eoo`800003
FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05
001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005]oo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001GOol30007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001EOol20002FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001C
Ool20004FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001COol20005FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001BOol01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH015YF5@000eYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000087oo2000?Goo001BOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YFFUH0
0eYF0`001EYF0`0000=JEP00FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0000mooa4000AJEP04001JEUYFFUH<000aOol005=oo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH0000000<000AJEP03001JEP0000<00003
FUH005YF00IJEP04001JEP000003FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00001goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002moo`00Dgoo00<005YF000015YF00<005YFFUH01EYF
00<005YFFUH010001EYF2`001EYF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool50003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP8000EJEPD00003FUH005YF00X000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00<005YF00001EYF00@005YFFUIJEPX000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP06001JEP00001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH0
0005FUH01000FUH000001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00H005YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP0015YF
0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001COol01000FUIJEP000eYF00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00=JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo0010Ool8000;Ool01@00FUIJEP00FUH03`00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH00`00FUIJEP03FUH0
0`00FUIJEP02000^Ool003Yoo`H000=JEP03001JEUYF009JEPT000=oo`04001JEP000004FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH600000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJ
EP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0006FUH20005FUH01000FUH00000;Woo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH400000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH000030006
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP8000MJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000IJEP8000EJEP04001JEUYF000^Ool003Aoo`8000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF009JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF00IJEP03001JEUYF00EJEP<000IJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF0P001EYF0P00
1eYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF0P001EYF00<005YFFUH00P00;Goo000bOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH00eYF0P00
25YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH2
0005FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20006FUH20005FUH00`00FUIJEP02000]
Ool0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@0009JEP04001JEUYFFUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000_Ool0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUH0000200000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH4
000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP05FUHJ00000eYF0000000]Ool002eoo`03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH30005FUH01000FUIJEUYF0`00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20003FUH01`00FUIJEUYF001JEP0002eoo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00003P0015YF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0`001EYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF0P00
;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000UYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<0035oo`00;Goo0P00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001oogoo02moo`00;Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH00UYF200015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00P005YFFUH005YF001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH00UYF3P001eYF00<005YFFUH01EYF00<005YFFUH015YF0P00<7oo000]Ool20004FUH0
0`00FUIJEP03FUH60008Ool90004FUH01000FUIJEP001EYF00<005YFFUH00UYF00@005YFFUH000QJ
EQL000=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUHG0003FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH2000`Ool002eoo`8000AJEP03001JEP0000<001Moo`H0009JEP8000=JEP03001JEUYF00EJ
EP03001JEUYF00L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000<000=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001J
EP0000<001Qoo`D000IJEP03001JEUYF00AJEP03001JEP0002moo`00;7oo00<005YF000015YF0P00
4goo0`002goo1P0000=JEP00FUH01EYF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0015YF0P008Goo0P0015YF00<005YFFUH015YF00@005YFFUH002io
o`00;7oo00<005YF00000UYF0P000UYF0P0047oo1@003Woo1@0000=JEP0000000P001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF10008goo0`0000=JEP00FUH0
15YF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000P0000=JEP00FUH00eYF0`003Goo1@0047oo
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF100015YF10008Woo0P001EYF00D005YFFUIJEP0002ioo`00;7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YF00000`002Goo1@003Woo0P001EYF00<005YFFUH01UYF00<005YFFUH00UYF
5`0015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001J
EUYFFUH005YF0P001eYF00<005YF00000P008Goo0P000eYF00@005YFFUIJEP8002eoo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH00eYF10001Woo0`003Woo0P001eYF00<005YFFUH015YF1P00
25YF00<005YFFUH01EYF00<005YFFUH015YF0`0000AJEP00FUIJEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP05FUH00`00FUIJEP02FUH2000;
Ool3000COol200000eYF001JEP02FUH2000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF
00AJEP03001JEUYF00@0011oo`<00003FUH005YF00IJEP03001JEUYF00@0009JEPD000IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP800003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30008Ool5
000DOol20002FUH00`00FUH0000]Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF00AJEQ4000=JEP03001JEUYF00AJEPD00003FUH005YF00EJEP03001JEP0000<0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEPD00003FUH005YF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF00D005YFFUIJEP0000IJEP04001JEUYF0007
Ool5000FOol01@00FUH005YF0000;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP0?FUH01000FUIJEUYF0P0015YF00@005YFFUIJEP8000=JEP800003FUH005YF00EJEP03
001JEUYF00=JEPH000AJEP03001JEUYF00AJEP08001JEUYFFUH005YF001JEP800003FUH005YF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH300000eYF001JEP05FUH01000
FUIJEP001goo1@005Woo00D005YF001JEP0002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH03eYF00@005YFFUIJEP8000AJEP06001JEP00001JEP000eYF0P0000=JEP00
FUH01EYF10001EYF00<005YFFUH04@0000IJEP00000005YF000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00P001EYF00@005YFFUIJEP8000Moo`<001Qoo`80
0003FUH007oo02aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP06
001JEUYF001JEP000eYF0`000eYF00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF
00UJEP03001JEUYF00AJEP<00004FUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0015YF00<005YFFUH00UYF0`000UYF00@005YFFUIJEP80025oo`@002ioo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00mJEP07001JEUYF001JEP00FUH00P001UYF
00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00UJEP03001JEUYF009JEP80009J
EP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUH0000OOol20002FUH2000^Ool002io
o`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH01@00FUIJEP00FUH00P0000=JEP00
FUH015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF1@0015YF00<005YFFUH02EYF00<005YFFUH0
0P0015YF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00D005YFFUIJEP0000IJEP04001JEUYFFUH400000eYF001oo`0LOol20004FUH2000^Ool002moo`03
001JEP0000EJEP03001JEUYF00AJEP80015JEP03001JEUYF008000=JEP03001JEUYF00=JEP03001J
EUYF009JEP800003FUH005YF00EJEP@000EJEP03001JEUYF00QJEP@00003FUH005YF00=JEP80009J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001J
EUYF00AJEP03001JEUYF00AJEP<001Yoo`<00003FUH005YF00=JEP8002ioo`00<7oo0P001EYF00<0
05YFFUH015YF0P0045YF5P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`001EYF
00<005YFFUH00UYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00006FUH00`00FUIJEP04FUHP00000eYF001JEP02FUH00`00FUH0000^Ool0
035oo`03001JEUYF00=JEP03001JEUYF00AJEP8000MJEPT000AJEP80009JEP80009JEP03001JEUYF
009JEP07001JEUYFFUH005YF00001UYF00<005YFFUH01UYF00@005YFFUIJEP@00003FUH005YF00EJ
EP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP05001JEP00FUH00005FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP0600000eYF001oo`0]Ool0039oo`8000=JEP03001JEUYF00AJEPT000AJEP03001J
EUYF00IJEP80009JEP03001JEP00008000AJEP07001JEUYFFUH005YF00001UYF00<005YFFUH00eYF
1`001EYF00<005YFFUH015YF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF00000P0000=JEP0000000`000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000dOol2
00000eYF000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUHG
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00
02ioo`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<0
05YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;7oo1@000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF000005YF0004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5000<FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHH0003FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF009JEPd000=JEP8000MJEP03001JEUYF00AJEP@0009JEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
FUIJEP8000MJEP8000EJEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF009JEPL000QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP04001JEUYFFUH80007FUH60003FUH20007FUH00`00FUIJEP04FUH20002FUH4
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP80
00MJEP8000IJEP03001JEP0000@000AJEP03001JEUYF009JEPP000=JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP00009JEPH000=JEP<00003FUH005YF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP80
00AJEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH01EYF00@005YFFUIJEPP000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPX0009JEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00008000=JEPL0009JEP<000IJEP03001JEP00008000AJEP03001JEUYF00IJEP03001J
EP0000<00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF00001EYF00<005YFFUH00UYF
1P000eYF00<005YFFUH00UYF30000UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH01000FUIJEUYF2@00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00@005YFFUIJEP8002ioo`00;Goo00<005YF
000015YF1@0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF4`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YF
FUH00eYF40001EYF00<005YFFUH015YF00<005YFFUH00P00;goo000]Ool00`00FUH00003FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF10001EYF00<0
05YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPH0035oo`00;Goo00@005YF001JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEPP0009oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000
=goo000]Ool01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP80009JEP03001JEP00008000Aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP`00003FUH005YF00UJEPT000QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000D000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT003moo`00
;Goo0P0015YF00<005YFFUH00eYF00<005YFFUH00UYF4P0015YF00<005YFOol01EYF00<005YFFUH0
0UYF0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo6000B7oo
000]Ool20004FUH01000FUIJEUYF5P000goo1P001UYF00<005YFFUH00eYF0P0000Aoo`00FUH000IJ
EP03001JEUYF00@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEPH000IJEP03
001JEUYF009JEP03001JEP0000Moo`8000AJEP04001JEP00001DOol002eoo`8000AJEPT001Yoo`@0
009JEP03001JEUYF00=JEP800004Ool005YF0005FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP02FUH00`00
FUH00005Ool200000eYF001JEP03FUH01000FUIJEP00E7oo000/Ool00`00FUH00002FUH2000WOol4
0004FUH01P00FUH00000FUH000=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@000AJEP03001JEP0000=oo`8000=JEP03001JEUYF
009JEP04001JEUYF001DOol002aoo`03001JEP00008002eoo`<00008FUH005YFFUH005YF001JEP<0
00QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP04001JEUYFFUH20002FUH00`00FUH000030006FUH01@00FUIJEUYF00000UYF00<007ooOol0
DWoo000/Ool00`00FUH0000bOol20002FUH01000FUH000000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`0000AJEP00FUH000MJEP03001JEUYF009JEP03001JEP0005Aoo`00;7oo0P006Woo0`0067oo
00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800004FUH005YF0007FUH00`00FUIJ
EP02FUH2001EOol002aoo`8001Uoo`D001Moo`04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00UYF00<007ooOol0E7oo000/Ool3000HOol5
000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000UYF00<005YFFUH015YF
00D005YFFUIJEP0005Moo`00;7oo0P0000=JEP0000005Woo1@006Goo0P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00EJEP03001JEP0005Qoo`00;7oo0P000eYF
00<007ooOol057oo0`006Goo0`0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH0009J
EP03001JEUYF00EJEP8005Uoo`00;Goo00@005YFFUIJEP<002moo`800003FUH005YF00=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00EJEP03001oogoo05Qoo`00;Goo
00D005YFFUIJEP00009JEP8002]oo`800004FUH005YF0004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF000000020005FUH2001KOol002ioo`04001JEUYF0004FUH3000VOol20003FUH20000
0goo00000002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30005FUH5001MOol002moo`<000EJEP03
001JEP0000<001ioo`@00003FUH005YF009JEP8000=oo`<000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00
FUIJEP05FUH00`00FUH00002001KOol0035oo`03001JEUYF00=JEP03001JEUYF00=JEPH0019oo`H0
00EJEP05001JEUYFFUH00006Ool20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00FGoo000bOol20003FUH00`00FUIJEP05FUH01000FUIJEUYF4P0015YF00<005YFFUH00eYF
00<005YFFUH00P002Goo0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH015YF10000UYF1P001EYF00<005YFFUH015YF0`00Egoo000dOol20000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
000>Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP060004FUH500000goo0000000200000eYF001JEP05FUH00`00FUIJEP02001EOol003Ioo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`L0
00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEPD0009JEPP000Yoo`<000AJEP03
001JEUYF009JEP03001oogoo05=oo`00>Goo100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000P0077oo2`001UYF00<005YFFUH02UYF00@005YFFUIJEPH000AJEPP0011o
o`<00003FUH005YF00=JEP03001oogoo05=oo`00?Goo1P0015YF00<005YFFUH01UYF00<005YFFUH0
0UYF1P00:Woo8@000goo1@004goo0P000eYF0P00EGoo0013OolB000jOol200000eYF001JEP04FUH0
0`00FUIJEP04FUH60005Ool3000FOol200000eYF0000001EOol0095oo`<000AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT0011oo`H00004FUH00000001EOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF009JEQ0000=JEP04001JEUYFFUH3001EOol009Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EGoo
002JOol400000eYF001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2001FOol009ioo`H000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00<005Moo`00Y7oo2@0015YF00<005YFFUH01EYF00@005YFFUIJEPH005Yoo`00[Goo
4000H7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .7495 m .59613 .69391 L .56496 .69201 L p .707 .577 .707 r
F P
0 g
s
.59613 .69391 m .59613 .7495 L .62796 .74872 L p .707 .577 .707 r
F P
0 g
s
.62796 .74872 m .62796 .69314 L .59613 .69391 L p .707 .577 .707 r
F P
0 g
s
.62796 .69314 m .62796 .74872 L .65735 .74534 L p .707 .577 .707 r
F P
0 g
s
.65735 .74534 m .65734 .68976 L .62796 .69314 L p .707 .577 .707 r
F P
0 g
s
.56496 .7476 m .56496 .69201 L .5375 .68762 L p .707 .577 .707 r
F P
0 g
s
.56496 .69201 m .56496 .7476 L .59613 .7495 L p .707 .577 .707 r
F P
0 g
s
.65734 .68976 m .65735 .74534 L .6814 .73969 L p .707 .577 .707 r
F P
0 g
s
.6814 .73969 m .6814 .68411 L .65734 .68976 L p .707 .577 .707 r
F P
0 g
s
.59613 .80986 m .59613 .7728 L .56496 .7709 L p .707 .577 .707 r
F P
0 g
s
.59613 .7728 m .59613 .80986 L .62796 .80908 L p .707 .577 .707 r
F P
0 g
s
.62796 .80908 m .62796 .77203 L .59613 .7728 L p .707 .577 .707 r
F P
0 g
s
.5375 .68762 m .5375 .7432 L .56496 .7476 L p .707 .577 .707 r
F P
0 g
s
.5375 .7432 m .5375 .68762 L .51644 .68117 L p .707 .577 .707 r
F P
0 g
s
.62796 .77203 m .62796 .80908 L .65735 .8057 L p .707 .577 .707 r
F P
0 g
s
.65735 .8057 m .65735 .76865 L .62796 .77203 L p .707 .577 .707 r
F P
0 g
s
.56496 .80796 m .56496 .7709 L .5375 .76651 L p .707 .577 .707 r
F P
0 g
s
.56496 .7709 m .56496 .80796 L .59613 .80986 L p .707 .577 .707 r
F P
0 g
s
.6814 .68411 m .6814 .73969 L .69777 .73232 L p .707 .577 .707 r
F P
0 g
s
.69777 .73232 m .69777 .67674 L .6814 .68411 L p .707 .577 .707 r
F P
0 g
s
.65735 .76865 m .65735 .8057 L .6814 .80005 L p .707 .577 .707 r
F P
0 g
s
.6814 .80005 m .6814 .763 L .65735 .76865 L p .707 .577 .707 r
F P
0 g
s
.51644 .68117 m .51644 .73675 L .5375 .7432 L p .707 .577 .707 r
F P
0 g
s
.59613 .85169 m .59613 .83317 L .56496 .83126 L p .707 .577 .707 r
F P
0 g
s
.59613 .83317 m .59613 .85169 L .62796 .85092 L p .707 .577 .707 r
F P
0 g
s
.62796 .85092 m .62796 .83239 L .59613 .83317 L p .707 .577 .707 r
F P
0 g
s
.5375 .76651 m .5375 .80357 L .56496 .80796 L p .707 .577 .707 r
F P
0 g
s
.62796 .83239 m .62796 .85092 L .65735 .84754 L p .707 .577 .707 r
F P
0 g
s
.65735 .84754 m .65735 .82901 L .62796 .83239 L p .707 .577 .707 r
F P
0 g
s
.56496 .83126 m .56496 .84979 L .59613 .85169 L p .707 .577 .707 r
F P
0 g
s
.5375 .80357 m .5375 .76651 L .51644 .76006 L p .707 .577 .707 r
F P
0 g
s
.56496 .84979 m .56496 .83126 L .5375 .82687 L p .707 .577 .707 r
F P
0 g
s
.51644 .73675 m .51644 .68117 L .50385 .67328 L p .707 .577 .707 r
F P
0 g
s
.5375 .82687 m .5375 .8454 L .56496 .84979 L p .707 .577 .707 r
F P
0 g
s
.65735 .82901 m .65735 .84754 L .6814 .84189 L p .707 .577 .707 r
F P
0 g
s
.6814 .84189 m .6814 .82336 L .65735 .82901 L p .707 .577 .707 r
F P
0 g
s
.51644 .76006 m .51644 .79711 L .5375 .80357 L p .707 .577 .707 r
F P
0 g
s
.6814 .763 m .6814 .80005 L .69777 .79268 L p .707 .577 .707 r
F P
0 g
s
.69777 .79268 m .69777 .75563 L .6814 .763 L p .707 .577 .707 r
F P
0 g
s
.50385 .67328 m .50385 .72886 L .51644 .73675 L p .707 .577 .707 r
F P
0 g
s
.5375 .8454 m .5375 .82687 L .51644 .82042 L p .707 .577 .707 r
F P
0 g
s
.69777 .67674 m .69777 .73232 L .70485 .72396 L p .707 .577 .707 r
F P
0 g
s
.70485 .72396 m .70485 .66838 L .69777 .67674 L p .707 .577 .707 r
F P
0 g
s
.51644 .82042 m .51644 .83895 L .5375 .8454 L p .707 .577 .707 r
F P
0 g
s
.51644 .79711 m .51644 .76006 L .50385 .75217 L p .707 .577 .707 r
F P
0 g
s
.6814 .82336 m .6814 .84189 L .69777 .83452 L p .707 .577 .707 r
F P
0 g
s
.69777 .83452 m .69777 .81599 L .6814 .82336 L p .707 .577 .707 r
F P
0 g
s
.50385 .72886 m .50385 .67328 L .50095 .66474 L p .707 .577 .707 r
F P
0 g
s
.50385 .75217 m .50385 .78923 L .51644 .79711 L p .707 .577 .707 r
F P
0 g
s
.69777 .75563 m .69777 .79268 L .70485 .78432 L p .707 .577 .707 r
F P
0 g
s
.70485 .78432 m .70485 .74727 L .69777 .75563 L p .707 .577 .707 r
F P
0 g
s
.51644 .83895 m .51644 .82042 L .50385 .81253 L p .707 .577 .707 r
F P
0 g
s
.50095 .66474 m .50095 .72032 L .50385 .72886 L p .707 .577 .707 r
F P
0 g
s
.50385 .81253 m .50385 .83106 L .51644 .83895 L p .707 .577 .707 r
F P
0 g
s
.70485 .66838 m .70485 .72396 L .70195 .71542 L p .707 .577 .707 r
F P
0 g
s
.70195 .71542 m .70195 .65983 L .70485 .66838 L p .707 .577 .707 r
F P
0 g
s
.50385 .78923 m .50385 .75217 L .50095 .74363 L p .707 .577 .707 r
F P
0 g
s
.69777 .81599 m .69777 .83452 L .70485 .82615 L p .707 .577 .707 r
F P
0 g
s
.70485 .82615 m .70485 .80763 L .69777 .81599 L p .707 .577 .707 r
F P
0 g
s
.49044 .82184 m .49044 .31995 L .44643 .31727 L p .707 .577 .707 r
F P
0 g
s
.50095 .72032 m .50095 .66474 L .50804 .65638 L p .707 .577 .707 r
F P
0 g
s
.50095 .74363 m .50095 .78068 L .50385 .78923 L p .707 .577 .707 r
F P
0 g
s
.50385 .83106 m .50385 .81253 L .50095 .80399 L p .707 .577 .707 r
F P
0 g
s
.50095 .80399 m .50095 .82252 L .50385 .83106 L p .707 .577 .707 r
F P
0 g
s
.50804 .65638 m .50804 .71196 L .50095 .72032 L p .707 .577 .707 r
F P
0 g
s
.50095 .78068 m .50095 .74363 L .50804 .73527 L p .707 .577 .707 r
F P
0 g
s
.50804 .71196 m .50804 .65638 L .5244 .64901 L p .707 .577 .707 r
F P
0 g
s
.50804 .73527 m .50804 .77232 L .50095 .78068 L p .707 .577 .707 r
F P
0 g
s
.50095 .82252 m .50095 .80399 L .50804 .79563 L p .707 .577 .707 r
F P
0 g
s
.50804 .79563 m .50804 .81416 L .50095 .82252 L p .707 .577 .707 r
F P
0 g
s
.5244 .64901 m .5244 .70459 L .50804 .71196 L p .707 .577 .707 r
F P
0 g
s
.50804 .77232 m .50804 .73527 L .5244 .7279 L p .707 .577 .707 r
F P
0 g
s
.5244 .70459 m .5244 .64901 L .54846 .64336 L p .707 .577 .707 r
F P
0 g
s
.5244 .7279 m .5244 .76495 L .50804 .77232 L p .707 .577 .707 r
F P
0 g
s
.50804 .81416 m .50804 .79563 L .5244 .78826 L p .707 .577 .707 r
F P
0 g
s
.54846 .64336 m .54846 .69894 L .5244 .70459 L p .707 .577 .707 r
F P
0 g
s
.5244 .78826 m .5244 .80679 L .50804 .81416 L p .707 .577 .707 r
F P
0 g
s
.5244 .76495 m .5244 .7279 L .54846 .72225 L p .707 .577 .707 r
F P
0 g
s
.54846 .72225 m .54846 .7593 L .5244 .76495 L p .707 .577 .707 r
F P
0 g
s
.5244 .80679 m .5244 .78826 L .54846 .78261 L p .707 .577 .707 r
F P
0 g
s
.54846 .78261 m .54846 .80114 L .5244 .80679 L p .707 .577 .707 r
F P
0 g
s
.49044 .31995 m .49044 .82184 L .53538 .82074 L p .707 .577 .707 r
F P
0 g
s
.53538 .82074 m .53538 .31885 L .49044 .31995 L p .707 .577 .707 r
F P
0 g
s
.54846 .69894 m .54846 .64336 L .57784 .63998 L p .707 .577 .707 r
F P
0 g
s
.57784 .63998 m .57784 .69556 L .54846 .69894 L p .707 .577 .707 r
F P
0 g
s
.54846 .7593 m .54846 .72225 L .57784 .71887 L p .707 .577 .707 r
F P
0 g
s
.57784 .71887 m .57784 .75592 L .54846 .7593 L p .707 .577 .707 r
F P
0 g
s
.54846 .80114 m .54846 .78261 L .57784 .77923 L p .707 .577 .707 r
F P
0 g
s
.57784 .77923 m .57784 .79776 L .54846 .80114 L p .707 .577 .707 r
F P
0 g
s
.53538 .31885 m .53538 .82074 L .57686 .81597 L p .707 .577 .707 r
F P
0 g
s
.57686 .81597 m .57686 .31408 L .53538 .31885 L p .707 .577 .707 r
F P
0 g
s
.44643 .81915 m .44643 .31727 L .40766 .31107 L p .707 .577 .707 r
F P
0 g
s
.44643 .31727 m .44643 .81915 L .49044 .82184 L p .707 .577 .707 r
F P
0 g
s
.70485 .74727 m .70485 .78432 L .70195 .77578 L p .707 .577 .707 r
F P
0 g
s
.70195 .77578 m .70195 .73872 L .70485 .74727 L p .707 .577 .707 r
F P
0 g
s
.70195 .65983 m .70195 .71542 L .68936 .70753 L p .707 .577 .707 r
F P
0 g
s
.68936 .70753 m .68936 .65195 L .70195 .65983 L p .707 .577 .707 r
F P
0 g
s
.57784 .69556 m .57784 .63998 L .60968 .6392 L p .707 .577 .707 r
F P
0 g
s
.60968 .6392 m .60968 .69478 L .57784 .69556 L p .707 .577 .707 r
F P
0 g
s
.57784 .75592 m .57784 .71887 L .60968 .71809 L p .707 .577 .707 r
F P
0 g
s
.60968 .71809 m .60968 .75515 L .57784 .75592 L p .707 .577 .707 r
F P
0 g
s
.64085 .78036 m .64085 .79888 L .60968 .79698 L p .707 .577 .707 r
F P
0 g
s
.60968 .79698 m .60968 .77845 L .64085 .78036 L p .707 .577 .707 r
F P
0 g
s
.57784 .79776 m .57784 .77923 L .60968 .77845 L p .707 .577 .707 r
F P
0 g
s
.60968 .77845 m .60968 .79698 L .57784 .79776 L p .707 .577 .707 r
F P
0 g
s
.57686 .31408 m .57686 .81597 L .61082 .80799 L p .707 .577 .707 r
F P
0 g
s
.64085 .6411 m .64085 .69669 L .60968 .69478 L p .707 .577 .707 r
F P
0 g
s
.60968 .69478 m .60968 .6392 L .64085 .6411 L p .707 .577 .707 r
F P
0 g
s
.64085 .71999 m .64085 .75705 L .60968 .75515 L p .707 .577 .707 r
F P
0 g
s
.60968 .75515 m .60968 .71809 L .64085 .71999 L p .707 .577 .707 r
F P
0 g
s
.61082 .80799 m .61082 .30611 L .57686 .31408 L p .707 .577 .707 r
F P
0 g
s
.70485 .80763 m .70485 .82615 L .70195 .81761 L p .707 .577 .707 r
F P
0 g
s
.70195 .81761 m .70195 .79909 L .70485 .80763 L p .707 .577 .707 r
F P
0 g
s
.25312 .71268 m .25312 .6571 L .22195 .6552 L p .707 .577 .707 r
F P
0 g
s
.25312 .6571 m .25312 .71268 L .28495 .7119 L p .707 .577 .707 r
F P
0 g
s
.28495 .7119 m .28495 .65632 L .25312 .6571 L p .707 .577 .707 r
F P
0 g
s
.40766 .81295 m .40766 .31107 L .37794 .30195 L p .707 .577 .707 r
F P
0 g
s
.40766 .31107 m .40766 .81295 L .44643 .81915 L p .707 .577 .707 r
F P
0 g
s
.28495 .65632 m .28495 .7119 L .31434 .70852 L p .707 .577 .707 r
F P
0 g
s
.31434 .70852 m .31434 .65294 L .28495 .65632 L p .707 .577 .707 r
F P
0 g
s
.22195 .71078 m .22195 .6552 L .19449 .65081 L p .707 .577 .707 r
F P
0 g
s
.22195 .6552 m .22195 .71078 L .25312 .71268 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73872 m .70195 .77578 L .68936 .76789 L p .707 .577 .707 r
F P
0 g
s
.68936 .76789 m .68936 .73084 L .70195 .73872 L p .707 .577 .707 r
F P
0 g
s
.31434 .65294 m .31434 .70852 L .33839 .70287 L p .707 .577 .707 r
F P
0 g
s
.33839 .70287 m .33839 .64729 L .31434 .65294 L p .707 .577 .707 r
F P
0 g
s
.68936 .65195 m .68936 .70753 L .66831 .70108 L p .707 .577 .707 r
F P
0 g
s
.66831 .70108 m .66831 .6455 L .68936 .65195 L p .707 .577 .707 r
F P
0 g
s
.61082 .30611 m .61082 .80799 L .63393 .79759 L p .707 .577 .707 r
F P
0 g
s
.63393 .79759 m .63393 .2957 L .61082 .30611 L p .707 .577 .707 r
F P
0 g
s
.25312 .77304 m .25312 .73599 L .22195 .73409 L p .707 .577 .707 r
F P
0 g
s
.25312 .73599 m .25312 .77304 L .28495 .77227 L p .707 .577 .707 r
F P
0 g
s
.28495 .77227 m .28495 .73521 L .25312 .73599 L p .707 .577 .707 r
F P
0 g
s
.19449 .65081 m .19449 .70639 L .22195 .71078 L p .707 .577 .707 r
F P
0 g
s
.19449 .70639 m .19449 .65081 L .17343 .64435 L p .707 .577 .707 r
F P
0 g
s
.28495 .73521 m .28495 .77227 L .31434 .76889 L p .707 .577 .707 r
F P
0 g
s
.31434 .76889 m .31434 .73183 L .28495 .73521 L p .707 .577 .707 r
F P
0 g
s
.22195 .77114 m .22195 .73409 L .19449 .7297 L p .707 .577 .707 r
F P
0 g
s
.22195 .73409 m .22195 .77114 L .25312 .77304 L p .707 .577 .707 r
F P
0 g
s
.70195 .79909 m .70195 .81761 L .68936 .80973 L p .707 .577 .707 r
F P
0 g
s
.68936 .80973 m .68936 .7912 L .70195 .79909 L p .707 .577 .707 r
F P
0 g
s
.37794 .80384 m .37794 .30195 L .36016 .29082 L p .707 .577 .707 r
F P
0 g
s
.37794 .30195 m .37794 .80384 L .40766 .81295 L p .707 .577 .707 r
F P
0 g
s
.33839 .64729 m .33839 .70287 L .35476 .69551 L p .707 .577 .707 r
F P
0 g
s
.35476 .69551 m .35476 .63992 L .33839 .64729 L p .707 .577 .707 r
F P
0 g
s
.31434 .73183 m .31434 .76889 L .33839 .76324 L p .707 .577 .707 r
F P
0 g
s
.33839 .76324 m .33839 .72618 L .31434 .73183 L p .707 .577 .707 r
F P
0 g
s
.17343 .64435 m .17343 .69993 L .19449 .70639 L p .707 .577 .707 r
F P
0 g
s
.25312 .81488 m .25312 .79635 L .22195 .79445 L p .707 .577 .707 r
F P
0 g
s
.25312 .79635 m .25312 .81488 L .28495 .8141 L p .707 .577 .707 r
F P
0 g
s
.28495 .8141 m .28495 .79557 L .25312 .79635 L p .707 .577 .707 r
F P
0 g
s
.19449 .7297 m .19449 .76675 L .22195 .77114 L p .707 .577 .707 r
F P
0 g
s
.68936 .73084 m .68936 .76789 L .66831 .76144 L p .707 .577 .707 r
F P
0 g
s
.66831 .76144 m .66831 .72439 L .68936 .73084 L p .707 .577 .707 r
F P
0 g
s
.28495 .79557 m .28495 .8141 L .31434 .81072 L p .707 .577 .707 r
F P
0 g
s
.31434 .81072 m .31434 .79219 L .28495 .79557 L p .707 .577 .707 r
F P
0 g
s
.66831 .6455 m .66831 .70108 L .64085 .69669 L p .707 .577 .707 r
F P
0 g
s
.64085 .69669 m .64085 .6411 L .66831 .6455 L p .707 .577 .707 r
F P
0 g
s
.22195 .79445 m .22195 .81298 L .25312 .81488 L p .707 .577 .707 r
F P
0 g
s
.19449 .76675 m .19449 .7297 L .17343 .72324 L p .707 .577 .707 r
F P
0 g
s
.22195 .81298 m .22195 .79445 L .19449 .79006 L p .707 .577 .707 r
F P
0 g
s
.17343 .69993 m .17343 .64435 L .16084 .63647 L p .707 .577 .707 r
F P
0 g
s
.19449 .79006 m .19449 .80858 L .22195 .81298 L p .707 .577 .707 r
F P
0 g
s
.31434 .79219 m .31434 .81072 L .33839 .80507 L p .707 .577 .707 r
F P
0 g
s
.33839 .80507 m .33839 .78654 L .31434 .79219 L p .707 .577 .707 r
F P
0 g
s
.17343 .72324 m .17343 .7603 L .19449 .76675 L p .707 .577 .707 r
F P
0 g
s
.66831 .72439 m .66831 .76144 L .64085 .75705 L p .707 .577 .707 r
F P
0 g
s
.64085 .75705 m .64085 .71999 L .66831 .72439 L p .707 .577 .707 r
F P
0 g
s
.64085 .79888 m .64085 .78036 L .66831 .78475 L p .707 .577 .707 r
F P
0 g
s
.63393 .2957 m .63393 .79759 L .64393 .78578 L p .707 .577 .707 r
F P
0 g
s
.64393 .78578 m .64393 .2839 L .63393 .2957 L p .707 .577 .707 r
F P
0 g
s
.33839 .72618 m .33839 .76324 L .35476 .75587 L p .707 .577 .707 r
F P
0 g
s
.35476 .75587 m .35476 .71881 L .33839 .72618 L p .707 .577 .707 r
F P
0 g
s
.68936 .7912 m .68936 .80973 L .66831 .80327 L p .707 .577 .707 r
F P
0 g
s
.66831 .80327 m .66831 .78475 L .68936 .7912 L p .707 .577 .707 r
F P
0 g
s
.16084 .63647 m .16084 .69205 L .17343 .69993 L p .707 .577 .707 r
F P
0 g
s
.19449 .80858 m .19449 .79006 L .17343 .7836 L p .707 .577 .707 r
F P
0 g
s
.35476 .63992 m .35476 .69551 L .36184 .68714 L p .707 .577 .707 r
F P
0 g
s
.36184 .68714 m .36184 .63156 L .35476 .63992 L p .707 .577 .707 r
F P
0 g
s
.17343 .7836 m .17343 .80213 L .19449 .80858 L p .707 .577 .707 r
F P
0 g
s
.17343 .7603 m .17343 .72324 L .16084 .71536 L p .707 .577 .707 r
F P
0 g
s
.35476 .71881 m .35476 .75587 L .36184 .7475 L p .707 .577 .707 r
F P
0 g
s
.36184 .7475 m .36184 .71045 L .35476 .71881 L p .707 .577 .707 r
F P
0 g
s
.36184 .63156 m .36184 .68714 L .35894 .6786 L p .707 .577 .707 r
F P
0 g
s
.35894 .6786 m .35894 .62302 L .36184 .63156 L p .707 .577 .707 r
F P
0 g
s
.35476 .77918 m .35476 .7977 L .36184 .78934 L p .707 .577 .707 r
F P
0 g
s
.36184 .78934 m .36184 .77081 L .35476 .77918 L p .707 .577 .707 r
F P
0 g
s
.36184 .71045 m .36184 .7475 L .35894 .73896 L p .707 .577 .707 r
F P
0 g
s
.35894 .73896 m .35894 .70191 L .36184 .71045 L p .707 .577 .707 r
F P
0 g
s
.35894 .62302 m .35894 .6786 L .34635 .67072 L p .707 .577 .707 r
F P
0 g
s
.34635 .67072 m .34635 .61513 L .35894 .62302 L p .707 .577 .707 r
F P
0 g
s
.36184 .77081 m .36184 .78934 L .35894 .7808 L p .707 .577 .707 r
F P
0 g
s
.35894 .7808 m .35894 .76227 L .36184 .77081 L p .707 .577 .707 r
F P
0 g
s
.36016 .79271 m .36016 .29082 L .35607 .27876 L p .707 .577 .707 r
F P
0 g
s
.36016 .29082 m .36016 .79271 L .37794 .80384 L p .707 .577 .707 r
F P
0 g
s
.33839 .78654 m .33839 .80507 L .35476 .7977 L p .707 .577 .707 r
F P
0 g
s
.35476 .7977 m .35476 .77918 L .33839 .78654 L p .707 .577 .707 r
F P
0 g
s
.16084 .69205 m .16084 .63647 L .15794 .62793 L p .707 .577 .707 r
F P
0 g
s
.16084 .71536 m .16084 .75241 L .17343 .7603 L p .707 .577 .707 r
F P
0 g
s
.66831 .78475 m .66831 .80327 L .64085 .79888 L p .707 .577 .707 r
F P
0 g
s
.17343 .80213 m .17343 .7836 L .16084 .77572 L p .707 .577 .707 r
F P
0 g
s
.15794 .62793 m .15794 .68351 L .16084 .69205 L p .707 .577 .707 r
F P
0 g
s
.16084 .77572 m .16084 .79425 L .17343 .80213 L p .707 .577 .707 r
F P
0 g
s
.16084 .75241 m .16084 .71536 L .15794 .70681 L p .707 .577 .707 r
F P
0 g
s
.64393 .2839 m .64393 .78578 L .63984 .77372 L p .707 .577 .707 r
F P
0 g
s
.63984 .77372 m .63984 .27184 L .64393 .2839 L p .707 .577 .707 r
F P
0 g
s
.15794 .68351 m .15794 .62793 L .16503 .61956 L p .707 .577 .707 r
F P
0 g
s
.15794 .70681 m .15794 .74387 L .16084 .75241 L p .707 .577 .707 r
F P
0 g
s
.16084 .79425 m .16084 .77572 L .15794 .76718 L p .707 .577 .707 r
F P
0 g
s
.35894 .70191 m .35894 .73896 L .34635 .73108 L p .707 .577 .707 r
F P
0 g
s
.34635 .73108 m .34635 .69402 L .35894 .70191 L p .707 .577 .707 r
F P
0 g
s
.35894 .76227 m .35894 .7808 L .34635 .77291 L p .707 .577 .707 r
F P
0 g
s
.34635 .77291 m .34635 .75439 L .35894 .76227 L p .707 .577 .707 r
F P
0 g
s
.35607 .27876 m .35607 .78065 L .36016 .79271 L p .707 .577 .707 r
F P
0 g
s
.35607 .78065 m .35607 .27876 L .36607 .26695 L p .707 .577 .707 r
F P
0 g
s
.15794 .76718 m .15794 .7857 L .16084 .79425 L p .707 .577 .707 r
F P
0 g
s
.16503 .61956 m .16503 .67514 L .15794 .68351 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .74387 m .15794 .70681 L .16503 .69845 L p .707 .577 .707 r
F P
0 g
s
.16503 .67514 m .16503 .61956 L .1814 .61219 L p .707 .577 .707 r
F P
0 g
s
.16503 .69845 m .16503 .73551 L .15794 .74387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63984 .27184 m .63984 .77372 L .62206 .76259 L p .707 .577 .707 r
F P
0 g
s
.62206 .76259 m .62206 .26071 L .63984 .27184 L p .707 .577 .707 r
F P
0 g
s
.15794 .7857 m .15794 .76718 L .16503 .75881 L p .707 .577 .707 r
F P
0 g
s
.16503 .75881 m .16503 .77734 L .15794 .7857 L p .707 .577 .707 r
F P
0 g
s
.1814 .61219 m .1814 .66778 L .16503 .67514 L p .707 .577 .707 r
F P
0 g
s
.34635 .61513 m .34635 .67072 L .3253 .66426 L p .707 .577 .707 r
F P
0 g
s
.3253 .66426 m .3253 .60868 L .34635 .61513 L p .707 .577 .707 r
F P
0 g
s
.16503 .73551 m .16503 .69845 L .1814 .69108 L p .707 .577 .707 r
F P
0 g
s
.36607 .76884 m .36607 .26695 L .38918 .25655 L p .707 .577 .707 r
F P
0 g
s
.36607 .26695 m .36607 .76884 L .35607 .78065 L p .707 .577 .707 r
F P
0 g
s
.1814 .66778 m .1814 .61219 L .20545 .60654 L p .707 .577 .707 r
F P
0 g
s
.1814 .69108 m .1814 .72814 L .16503 .73551 L p .707 .577 .707 r
F P
0 g
s
.34635 .69402 m .34635 .73108 L .3253 .72462 L p .707 .577 .707 r
F P
0 g
s
.3253 .72462 m .3253 .68757 L .34635 .69402 L p .707 .577 .707 r
F P
0 g
s
.16503 .77734 m .16503 .75881 L .1814 .75145 L p .707 .577 .707 r
F P
0 g
s
.3253 .60868 m .3253 .66426 L .29784 .65987 L p .707 .577 .707 r
F P
0 g
s
.29784 .65987 m .29784 .60429 L .3253 .60868 L p .707 .577 .707 r
F P
0 g
s
.20545 .60654 m .20545 .66213 L .1814 .66778 L p .707 .577 .707 r
F P
0 g
s
.1814 .75145 m .1814 .76997 L .16503 .77734 L p .707 .577 .707 r
F P
0 g
s
.20545 .66213 m .20545 .60654 L .23483 .60316 L p .707 .577 .707 r
F P
0 g
s
.62206 .26071 m .62206 .76259 L .59233 .75348 L p .707 .577 .707 r
F P
0 g
s
.59233 .75348 m .59233 .25159 L .62206 .26071 L p .707 .577 .707 r
F P
0 g
s
.1814 .72814 m .1814 .69108 L .20545 .68543 L p .707 .577 .707 r
F P
0 g
s
.34635 .75439 m .34635 .77291 L .3253 .76646 L p .707 .577 .707 r
F P
0 g
s
.3253 .76646 m .3253 .74793 L .34635 .75439 L p .707 .577 .707 r
F P
0 g
s
.29784 .60429 m .29784 .65987 L .26667 .65797 L p .707 .577 .707 r
F P
0 g
s
.26667 .65797 m .26667 .60239 L .29784 .60429 L p .707 .577 .707 r
F P
0 g
s
.20545 .68543 m .20545 .72249 L .1814 .72814 L p .707 .577 .707 r
F P
0 g
s
.23483 .65875 m .23483 .60316 L .26667 .60239 L p .707 .577 .707 r
F P
0 g
s
.23483 .60316 m .23483 .65875 L .20545 .66213 L p .707 .577 .707 r
F P
0 g
s
.3253 .68757 m .3253 .72462 L .29784 .72023 L p .707 .577 .707 r
F P
0 g
s
.29784 .72023 m .29784 .68318 L .3253 .68757 L p .707 .577 .707 r
F P
0 g
s
.26667 .60239 m .26667 .65797 L .23483 .65875 L p .707 .577 .707 r
F P
0 g
s
.38918 .25655 m .38918 .75844 L .36607 .76884 L p .707 .577 .707 r
F P
0 g
s
.38918 .75844 m .38918 .25655 L .42314 .24858 L p .707 .577 .707 r
F P
0 g
s
.73333 .65746 m .73333 .60188 L .70216 .59997 L p .707 .577 .707 r
F P
0 g
s
.73333 .60188 m .73333 .65746 L .76517 .65668 L p .707 .577 .707 r
F P
0 g
s
.76517 .65668 m .76517 .6011 L .73333 .60188 L p .707 .577 .707 r
F P
0 g
s
.1814 .76997 m .1814 .75145 L .20545 .7458 L p .707 .577 .707 r
F P
0 g
s
.76517 .6011 m .76517 .65668 L .79455 .6533 L p .707 .577 .707 r
F P
0 g
s
.79455 .6533 m .79455 .59772 L .76517 .6011 L p .707 .577 .707 r
F P
0 g
s
.20545 .72249 m .20545 .68543 L .23483 .68205 L p .707 .577 .707 r
F P
0 g
s
.70216 .65556 m .70216 .59997 L .6747 .59558 L p .707 .577 .707 r
F P
0 g
s
.70216 .59997 m .70216 .65556 L .73333 .65746 L p .707 .577 .707 r
F P
0 g
s
.20545 .7458 m .20545 .76432 L .1814 .76997 L p .707 .577 .707 r
F P
0 g
s
.29784 .68318 m .29784 .72023 L .26667 .71833 L p .707 .577 .707 r
F P
0 g
s
.26667 .71833 m .26667 .68128 L .29784 .68318 L p .707 .577 .707 r
F P
0 g
s
.3253 .74793 m .3253 .76646 L .29784 .76207 L p .707 .577 .707 r
F P
0 g
s
.29784 .76207 m .29784 .74354 L .3253 .74793 L p .707 .577 .707 r
F P
0 g
s
.79455 .59772 m .79455 .6533 L .8186 .64765 L p .707 .577 .707 r
F P
0 g
s
.8186 .64765 m .8186 .59207 L .79455 .59772 L p .707 .577 .707 r
F P
0 g
s
.23483 .68205 m .23483 .71911 L .20545 .72249 L p .707 .577 .707 r
F P
0 g
s
.59233 .25159 m .59233 .75348 L .55357 .74728 L p .707 .577 .707 r
F P
0 g
s
.55357 .74728 m .55357 .24539 L .59233 .25159 L p .707 .577 .707 r
F P
0 g
s
.23483 .71911 m .23483 .68205 L .26667 .68128 L p .707 .577 .707 r
F P
0 g
s
.26667 .68128 m .26667 .71833 L .23483 .71911 L p .707 .577 .707 r
F P
0 g
s
.73333 .71782 m .73333 .68076 L .70216 .67886 L p .707 .577 .707 r
F P
0 g
s
.73333 .68076 m .73333 .71782 L .76517 .71704 L p .707 .577 .707 r
F P
0 g
s
.76517 .71704 m .76517 .67999 L .73333 .68076 L p .707 .577 .707 r
F P
0 g
s
.20545 .76432 m .20545 .7458 L .23483 .74242 L p .707 .577 .707 r
F P
0 g
s
.6747 .59558 m .6747 .65116 L .70216 .65556 L p .707 .577 .707 r
F P
0 g
s
.6747 .65116 m .6747 .59558 L .65365 .58913 L p .707 .577 .707 r
F P
0 g
s
.76517 .67999 m .76517 .71704 L .79455 .71366 L p .707 .577 .707 r
F P
0 g
s
.79455 .71366 m .79455 .67661 L .76517 .67999 L p .707 .577 .707 r
F P
0 g
s
.23483 .74242 m .23483 .76094 L .20545 .76432 L p .707 .577 .707 r
F P
0 g
s
.42314 .75047 m .42314 .24858 L .46462 .24381 L p .707 .577 .707 r
F P
0 g
s
.42314 .24858 m .42314 .75047 L .38918 .75844 L p .707 .577 .707 r
F P
0 g
s
.70216 .71592 m .70216 .67886 L .6747 .67447 L p .707 .577 .707 r
F P
0 g
s
.70216 .67886 m .70216 .71592 L .73333 .71782 L p .707 .577 .707 r
F P
0 g
s
.29784 .74354 m .29784 .76207 L .26667 .76017 L p .707 .577 .707 r
F P
0 g
s
.26667 .76017 m .26667 .74164 L .29784 .74354 L p .707 .577 .707 r
F P
0 g
s
.23483 .76094 m .23483 .74242 L .26667 .74164 L p .707 .577 .707 r
F P
0 g
s
.8186 .59207 m .8186 .64765 L .83497 .64028 L p .707 .577 .707 r
F P
0 g
s
.83497 .64028 m .83497 .5847 L .8186 .59207 L p .707 .577 .707 r
F P
0 g
s
.79455 .67661 m .79455 .71366 L .8186 .70801 L p .707 .577 .707 r
F P
0 g
s
.8186 .70801 m .8186 .67096 L .79455 .67661 L p .707 .577 .707 r
F P
0 g
s
.26667 .74164 m .26667 .76017 L .23483 .76094 L p .707 .577 .707 r
F P
0 g
s
.65365 .58913 m .65365 .64471 L .6747 .65116 L p .707 .577 .707 r
F P
0 g
s
.55357 .24539 m .55357 .74728 L .50956 .7446 L p .707 .577 .707 r
F P
0 g
s
.50956 .7446 m .50956 .24271 L .55357 .24539 L p .707 .577 .707 r
F P
0 g
s
.73333 .75965 m .73333 .74113 L .70216 .73923 L p .707 .577 .707 r
F P
0 g
s
.73333 .74113 m .73333 .75965 L .76517 .75888 L p .707 .577 .707 r
F P
0 g
s
.76517 .75888 m .76517 .74035 L .73333 .74113 L p .707 .577 .707 r
F P
0 g
s
.6747 .67447 m .6747 .71153 L .70216 .71592 L p .707 .577 .707 r
F P
0 g
s
.76517 .74035 m .76517 .75888 L .79455 .7555 L p .707 .577 .707 r
F P
0 g
s
.79455 .7555 m .79455 .73697 L .76517 .74035 L p .707 .577 .707 r
F P
0 g
s
.70216 .73923 m .70216 .75775 L .73333 .75965 L p .707 .577 .707 r
F P
0 g
s
.46462 .7457 m .46462 .24381 L .50956 .24271 L p .707 .577 .707 r
F P
0 g
s
.46462 .24381 m .46462 .7457 L .42314 .75047 L p .707 .577 .707 r
F P
0 g
s
.6747 .71153 m .6747 .67447 L .65365 .66802 L p .707 .577 .707 r
F P
0 g
s
.70216 .75775 m .70216 .73923 L .6747 .73483 L p .707 .577 .707 r
F P
0 g
s
.65365 .64471 m .65365 .58913 L .64105 .58124 L p .707 .577 .707 r
F P
0 g
s
.50956 .24271 m .50956 .7446 L .46462 .7457 L p .707 .577 .707 r
F P
0 g
s
.6747 .73483 m .6747 .75336 L .70216 .75775 L p .707 .577 .707 r
F P
0 g
s
.79455 .73697 m .79455 .7555 L .8186 .74985 L p .707 .577 .707 r
F P
0 g
s
.8186 .74985 m .8186 .73132 L .79455 .73697 L p .707 .577 .707 r
F P
0 g
s
.65365 .66802 m .65365 .70507 L .6747 .71153 L p .707 .577 .707 r
F P
0 g
s
.8186 .67096 m .8186 .70801 L .83497 .70065 L p .707 .577 .707 r
F P
0 g
s
.83497 .70065 m .83497 .66359 L .8186 .67096 L p .707 .577 .707 r
F P
0 g
s
.64105 .58124 m .64105 .63683 L .65365 .64471 L p .707 .577 .707 r
F P
0 g
s
.6747 .75336 m .6747 .73483 L .65365 .72838 L p .707 .577 .707 r
F P
0 g
s
.83497 .5847 m .83497 .64028 L .84205 .63192 L p .707 .577 .707 r
F P
0 g
s
.84205 .63192 m .84205 .57634 L .83497 .5847 L p .707 .577 .707 r
F P
0 g
s
.65365 .72838 m .65365 .74691 L .6747 .75336 L p .707 .577 .707 r
F P
0 g
s
.65365 .70507 m .65365 .66802 L .64105 .66013 L p .707 .577 .707 r
F P
0 g
s
.8186 .73132 m .8186 .74985 L .83497 .74248 L p .707 .577 .707 r
F P
0 g
s
.83497 .74248 m .83497 .72395 L .8186 .73132 L p .707 .577 .707 r
F P
0 g
s
.64105 .63683 m .64105 .58124 L .63816 .5727 L p .707 .577 .707 r
F P
0 g
s
.64105 .66013 m .64105 .69719 L .65365 .70507 L p .707 .577 .707 r
F P
0 g
s
.83497 .66359 m .83497 .70065 L .84206 .69228 L p .707 .577 .707 r
F P
0 g
s
.84206 .69228 m .84205 .65523 L .83497 .66359 L p .707 .577 .707 r
F P
0 g
s
.65365 .74691 m .65365 .72838 L .64105 .7205 L p .707 .577 .707 r
F P
0 g
s
.63816 .5727 m .63816 .62828 L .64105 .63683 L p .707 .577 .707 r
F P
0 g
s
.64105 .7205 m .64105 .73902 L .65365 .74691 L p .707 .577 .707 r
F P
0 g
s
.84205 .57634 m .84205 .63192 L .83916 .62338 L p .707 .577 .707 r
F P
0 g
s
.83916 .62338 m .83916 .56779 L .84205 .57634 L p .707 .577 .707 r
F P
0 g
s
.64105 .69719 m .64105 .66013 L .63816 .65159 L p .707 .577 .707 r
F P
0 g
s
.83497 .72395 m .83497 .74248 L .84206 .73412 L p .707 .577 .707 r
F P
0 g
s
.84206 .73412 m .84206 .71559 L .83497 .72395 L p .707 .577 .707 r
F P
0 g
s
.63816 .62828 m .63816 .5727 L .64524 .56434 L p .707 .577 .707 r
F P
0 g
s
.63816 .65159 m .63816 .68865 L .64105 .69719 L p .707 .577 .707 r
F P
0 g
s
.64105 .73902 m .64105 .7205 L .63816 .71195 L p .707 .577 .707 r
F P
0 g
s
.84205 .65523 m .84206 .69228 L .83916 .68374 L p .707 .577 .707 r
F P
0 g
s
.83916 .68374 m .83916 .64668 L .84205 .65523 L p .707 .577 .707 r
F P
0 g
s
.63816 .71195 m .63816 .73048 L .64105 .73902 L p .707 .577 .707 r
F P
0 g
s
.64524 .56434 m .64524 .61992 L .63816 .62828 L p .707 .577 .707 r
F P
0 g
s
.83916 .56779 m .83916 .62338 L .82657 .61549 L p .707 .577 .707 r
F P
0 g
s
.82657 .61549 m .82657 .55991 L .83916 .56779 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .68865 m .63816 .65159 L .64524 .64323 L p .707 .577 .707 r
F P
0 g
s
.84206 .71559 m .84206 .73412 L .83916 .72557 L p .707 .577 .707 r
F P
0 g
s
.83916 .72557 m .83916 .70705 L .84206 .71559 L p .707 .577 .707 r
F P
0 g
s
.39032 .62064 m .39032 .56506 L .35915 .56316 L p .707 .577 .707 r
F P
0 g
s
.39032 .56506 m .39032 .62064 L .42216 .61986 L p .707 .577 .707 r
F P
0 g
s
.42216 .61986 m .42216 .56428 L .39032 .56506 L p .707 .577 .707 r
F P
0 g
s
.64524 .61992 m .64524 .56434 L .66161 .55697 L p .707 .577 .707 r
F P
0 g
s
.42216 .56428 m .42216 .61986 L .45154 .61649 L p .707 .577 .707 r
F P
0 g
s
.45154 .61649 m .45154 .5609 L .42216 .56428 L p .707 .577 .707 r
F P
0 g
s
.64524 .64323 m .64524 .68028 L .63816 .68865 L p .707 .577 .707 r
F P
0 g
s
.35915 .61874 m .35915 .56316 L .33169 .55877 L p .707 .577 .707 r
F P
0 g
s
.35915 .56316 m .35915 .61874 L .39032 .62064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .73048 m .63816 .71195 L .64524 .70359 L p .707 .577 .707 r
F P
0 g
s
.83916 .64668 m .83916 .68374 L .82657 .67586 L p .707 .577 .707 r
F P
0 g
s
.82657 .67586 m .82657 .6388 L .83916 .64668 L p .707 .577 .707 r
F P
0 g
s
.45154 .5609 m .45154 .61649 L .47559 .61084 L p .707 .577 .707 r
F P
0 g
s
.47559 .61084 m .47559 .55525 L .45154 .5609 L p .707 .577 .707 r
F P
0 g
s
.64524 .70359 m .64524 .72212 L .63816 .73048 L p .707 .577 .707 r
F P
0 g
s
.66161 .55697 m .66161 .61255 L .64524 .61992 L p .707 .577 .707 r
F P
0 g
s
.82657 .55991 m .82657 .61549 L .80551 .60904 L p .707 .577 .707 r
F P
0 g
s
.80551 .60904 m .80551 .55346 L .82657 .55991 L p .707 .577 .707 r
F P
0 g
s
.39032 .681 m .39032 .64395 L .35915 .64205 L p .707 .577 .707 r
F P
0 g
s
.39032 .64395 m .39032 .681 L .42216 .68023 L p .707 .577 .707 r
F P
0 g
s
.42216 .68023 m .42216 .64317 L .39032 .64395 L p .707 .577 .707 r
F P
0 g
s
.33169 .55877 m .33169 .61435 L .35915 .61874 L p .707 .577 .707 r
F P
0 g
s
.33169 .61435 m .33169 .55877 L .31064 .55231 L p .707 .577 .707 r
F P
0 g
s
.64524 .68028 m .64524 .64323 L .66161 .63586 L p .707 .577 .707 r
F P
0 g
s
.42216 .64317 m .42216 .68023 L .45154 .67685 L p .707 .577 .707 r
F P
0 g
s
.45154 .67685 m .45154 .63979 L .42216 .64317 L p .707 .577 .707 r
F P
0 g
s
.35915 .6791 m .35915 .64205 L .33169 .63766 L p .707 .577 .707 r
F P
0 g
s
.35915 .64205 m .35915 .6791 L .39032 .681 L p .707 .577 .707 r
F P
0 g
s
.83916 .70705 m .83916 .72557 L .82657 .71769 L p .707 .577 .707 r
F P
0 g
s
.82657 .71769 m .82657 .69916 L .83916 .70705 L p .707 .577 .707 r
F P
0 g
s
.66161 .61255 m .66161 .55697 L .68566 .55132 L p .707 .577 .707 r
F P
0 g
s
.66161 .63586 m .66161 .67291 L .64524 .68028 L p .707 .577 .707 r
F P
0 g
s
.47559 .55525 m .47559 .61084 L .49196 .60347 L p .707 .577 .707 r
F P
0 g
s
.49196 .60347 m .49196 .54789 L .47559 .55525 L p .707 .577 .707 r
F P
0 g
s
.45154 .63979 m .45154 .67685 L .47559 .6712 L p .707 .577 .707 r
F P
0 g
s
.47559 .6712 m .47559 .63414 L .45154 .63979 L p .707 .577 .707 r
F P
0 g
s
.31064 .55231 m .31064 .6079 L .33169 .61435 L p .707 .577 .707 r
F P
0 g
s
.39032 .72284 m .39032 .70431 L .35915 .70241 L p .707 .577 .707 r
F P
0 g
s
.39032 .70431 m .39032 .72284 L .42216 .72206 L p .707 .577 .707 r
F P
0 g
s
.42216 .72206 m .42216 .70353 L .39032 .70431 L p .707 .577 .707 r
F P
0 g
s
.33169 .63766 m .33169 .67471 L .35915 .6791 L p .707 .577 .707 r
F P
0 g
s
.82657 .6388 m .82657 .67586 L .80551 .6694 L p .707 .577 .707 r
F P
0 g
s
.80551 .6694 m .80551 .63235 L .82657 .6388 L p .707 .577 .707 r
F P
0 g
s
.64524 .72212 m .64524 .70359 L .66161 .69622 L p .707 .577 .707 r
F P
0 g
s
.42216 .70353 m .42216 .72206 L .45154 .71868 L p .707 .577 .707 r
F P
0 g
s
.45154 .71868 m .45154 .70016 L .42216 .70353 L p .707 .577 .707 r
F P
0 g
s
.80551 .55346 m .80551 .60904 L .77805 .60465 L p .707 .577 .707 r
F P
0 g
s
.77805 .60465 m .77805 .54906 L .80551 .55346 L p .707 .577 .707 r
F P
0 g
s
.35915 .70241 m .35915 .72094 L .39032 .72284 L p .707 .577 .707 r
F P
0 g
s
.68566 .55132 m .68566 .6069 L .66161 .61255 L p .707 .577 .707 r
F P
0 g
s
.33169 .67471 m .33169 .63766 L .31064 .6312 L p .707 .577 .707 r
F P
0 g
s
.35915 .72094 m .35915 .70241 L .33169 .69802 L p .707 .577 .707 r
F P
0 g
s
.31064 .6079 m .31064 .55231 L .29804 .54443 L p .707 .577 .707 r
F P
0 g
s
.66161 .69622 m .66161 .71475 L .64524 .72212 L p .707 .577 .707 r
F P
0 g
s
.68566 .6069 m .68566 .55132 L .71504 .54794 L p .707 .577 .707 r
F P
0 g
s
.33169 .69802 m .33169 .71655 L .35915 .72094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67291 m .66161 .63586 L .68566 .63021 L p .707 .577 .707 r
F P
0 g
s
.45154 .70016 m .45154 .71868 L .47559 .71303 L p .707 .577 .707 r
F P
0 g
s
.47559 .71303 m .47559 .69451 L .45154 .70016 L p .707 .577 .707 r
F P
0 g
s
.31064 .6312 m .31064 .66826 L .33169 .67471 L p .707 .577 .707 r
F P
0 g
s
.47559 .63414 m .47559 .6712 L .49196 .66383 L p .707 .577 .707 r
F P
0 g
s
.49196 .66383 m .49196 .62678 L .47559 .63414 L p .707 .577 .707 r
F P
0 g
s
.82657 .69916 m .82657 .71769 L .80551 .71124 L p .707 .577 .707 r
F P
0 g
s
.80551 .71124 m .80551 .69271 L .82657 .69916 L p .707 .577 .707 r
F P
0 g
s
.77805 .54906 m .77805 .60465 L .74688 .60275 L p .707 .577 .707 r
F P
0 g
s
.74688 .60275 m .74688 .54716 L .77805 .54906 L p .707 .577 .707 r
F P
0 g
s
.29804 .54443 m .29804 .60001 L .31064 .6079 L p .707 .577 .707 r
F P
0 g
s
.68566 .63021 m .68566 .66726 L .66161 .67291 L p .707 .577 .707 r
F P
0 g
s
.33169 .71655 m .33169 .69802 L .31064 .69157 L p .707 .577 .707 r
F P
0 g
s
.71504 .60352 m .71504 .54794 L .74688 .54716 L p .707 .577 .707 r
F P
0 g
s
.71504 .54794 m .71504 .60352 L .68566 .6069 L p .707 .577 .707 r
F P
0 g
s
.49196 .54789 m .49196 .60347 L .49904 .5951 L p .707 .577 .707 r
F P
0 g
s
.49904 .5951 m .49904 .53952 L .49196 .54789 L p .707 .577 .707 r
F P
0 g
s
.80551 .63235 m .80551 .6694 L .77805 .66501 L p .707 .577 .707 r
F P
0 g
s
.77805 .66501 m .77805 .62795 L .80551 .63235 L p .707 .577 .707 r
F P
0 g
s
.74688 .54716 m .74688 .60275 L .71504 .60352 L p .707 .577 .707 r
F P
0 g
s
.31064 .69157 m .31064 .71009 L .33169 .71655 L p .707 .577 .707 r
F P
0 g
s
.31064 .66826 m .31064 .6312 L .29804 .62332 L p .707 .577 .707 r
F P
0 g
s
.66161 .71475 m .66161 .69622 L .68566 .69057 L p .707 .577 .707 r
F P
0 g
s
.68566 .66726 m .68566 .63021 L .71504 .62683 L p .707 .577 .707 r
F P
0 g
s
.68566 .69057 m .68566 .7091 L .66161 .71475 L p .707 .577 .707 r
F P
0 g
s
.47559 .69451 m .47559 .71303 L .49196 .70567 L p .707 .577 .707 r
F P
0 g
s
.49196 .70567 m .49196 .68714 L .47559 .69451 L p .707 .577 .707 r
F P
0 g
s
.29804 .60001 m .29804 .54443 L .29515 .53589 L p .707 .577 .707 r
F P
0 g
s
.29804 .62332 m .29804 .66037 L .31064 .66826 L p .707 .577 .707 r
F P
0 g
s
.77805 .62795 m .77805 .66501 L .74688 .66311 L p .707 .577 .707 r
F P
0 g
s
.74688 .66311 m .74688 .62605 L .77805 .62795 L p .707 .577 .707 r
F P
0 g
s
.80551 .69271 m .80551 .71124 L .77805 .70684 L p .707 .577 .707 r
F P
0 g
s
.77805 .70684 m .77805 .68832 L .80551 .69271 L p .707 .577 .707 r
F P
0 g
s
.71504 .62683 m .71504 .66389 L .68566 .66726 L p .707 .577 .707 r
F P
0 g
s
.71504 .66389 m .71504 .62683 L .74688 .62605 L p .707 .577 .707 r
F P
0 g
s
.49196 .62678 m .49196 .66383 L .49904 .65547 L p .707 .577 .707 r
F P
0 g
s
.49904 .65547 m .49904 .61841 L .49196 .62678 L p .707 .577 .707 r
F P
0 g
s
.31064 .71009 m .31064 .69157 L .29804 .68368 L p .707 .577 .707 r
F P
0 g
s
.74688 .62605 m .74688 .66311 L .71504 .66389 L p .707 .577 .707 r
F P
0 g
s
.68566 .7091 m .68566 .69057 L .71504 .68719 L p .707 .577 .707 r
F P
0 g
s
.29515 .53589 m .29515 .59147 L .29804 .60001 L p .707 .577 .707 r
F P
0 g
s
.29804 .68368 m .29804 .70221 L .31064 .71009 L p .707 .577 .707 r
F P
0 g
s
.49904 .53952 m .49904 .5951 L .49615 .58656 L p .707 .577 .707 r
F P
0 g
s
.49615 .58656 m .49615 .53098 L .49904 .53952 L p .707 .577 .707 r
F P
0 g
s
.71504 .68719 m .71504 .70572 L .68566 .7091 L p .707 .577 .707 r
F P
0 g
s
.29804 .66037 m .29804 .62332 L .29515 .61478 L p .707 .577 .707 r
F P
0 g
s
.77805 .68832 m .77805 .70684 L .74688 .70494 L p .707 .577 .707 r
F P
0 g
s
.74688 .70494 m .74688 .68642 L .77805 .68832 L p .707 .577 .707 r
F P
0 g
s
.71504 .70572 m .71504 .68719 L .74688 .68642 L p .707 .577 .707 r
F P
0 g
s
.49196 .68714 m .49196 .70567 L .49904 .6973 L p .707 .577 .707 r
F P
0 g
s
.49904 .6973 m .49904 .67877 L .49196 .68714 L p .707 .577 .707 r
F P
0 g
s
.74688 .68642 m .74688 .70494 L .71504 .70572 L p .707 .577 .707 r
F P
0 g
s
.29515 .59147 m .29515 .53589 L .30223 .52752 L p .707 .577 .707 r
F P
0 g
s
.29515 .61478 m .29515 .65183 L .29804 .66037 L p .707 .577 .707 r
F P
0 g
s
.29804 .70221 m .29804 .68368 L .29515 .67514 L p .707 .577 .707 r
F P
0 g
s
.49904 .61841 m .49904 .65547 L .49615 .64692 L p .707 .577 .707 r
F P
0 g
s
.49615 .64692 m .49615 .60987 L .49904 .61841 L p .707 .577 .707 r
F P
0 g
s
.29515 .67514 m .29515 .69367 L .29804 .70221 L p .707 .577 .707 r
F P
0 g
s
.30223 .52752 m .30223 .5831 L .29515 .59147 L p .707 .577 .707 r
F P
0 g
s
.49615 .53098 m .49615 .58656 L .48356 .57868 L p .707 .577 .707 r
F P
0 g
s
.48356 .57868 m .48356 .5231 L .49615 .53098 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .65183 m .29515 .61478 L .30223 .60641 L p .707 .577 .707 r
F P
0 g
s
.49904 .67877 m .49904 .6973 L .49615 .68876 L p .707 .577 .707 r
F P
0 g
s
.49615 .68876 m .49615 .67023 L .49904 .67877 L p .707 .577 .707 r
F P
0 g
s
.30223 .5831 m .30223 .52752 L .3186 .52015 L p .707 .577 .707 r
F P
0 g
s
.30223 .60641 m .30223 .64347 L .29515 .65183 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .69367 m .29515 .67514 L .30223 .66677 L p .707 .577 .707 r
F P
0 g
s
.49615 .60987 m .49615 .64692 L .48356 .63904 L p .707 .577 .707 r
F P
0 g
s
.48356 .63904 m .48356 .60199 L .49615 .60987 L p .707 .577 .707 r
F P
0 g
s
.30223 .66677 m .30223 .6853 L .29515 .69367 L p .707 .577 .707 r
F P
0 g
s
.3186 .52015 m .3186 .57574 L .30223 .5831 L p .707 .577 .707 r
F P
0 g
s
.48356 .5231 m .48356 .57868 L .4625 .57222 L p .707 .577 .707 r
F P
0 g
s
.4625 .57222 m .4625 .51664 L .48356 .5231 L p .707 .577 .707 r
F P
0 g
s
.30223 .64347 m .30223 .60641 L .3186 .59904 L p .707 .577 .707 r
F P
0 g
s
.49615 .67023 m .49615 .68876 L .48356 .68088 L p .707 .577 .707 r
F P
0 g
s
.48356 .68088 m .48356 .66235 L .49615 .67023 L p .707 .577 .707 r
F P
0 g
s
.3186 .57574 m .3186 .52015 L .34265 .5145 L p .707 .577 .707 r
F P
0 g
s
.3186 .59904 m .3186 .6361 L .30223 .64347 L p .707 .577 .707 r
F P
0 g
s
.48356 .60199 m .48356 .63904 L .4625 .63259 L p .707 .577 .707 r
F P
0 g
s
.4625 .63259 m .4625 .59553 L .48356 .60199 L p .707 .577 .707 r
F P
0 g
s
.30223 .6853 m .30223 .66677 L .3186 .65941 L p .707 .577 .707 r
F P
0 g
s
.4625 .51664 m .4625 .57222 L .43504 .56783 L p .707 .577 .707 r
F P
0 g
s
.43504 .56783 m .43504 .51225 L .4625 .51664 L p .707 .577 .707 r
F P
0 g
s
.34265 .5145 m .34265 .57009 L .3186 .57574 L p .707 .577 .707 r
F P
0 g
s
.3186 .65941 m .3186 .67793 L .30223 .6853 L p .707 .577 .707 r
F P
0 g
s
.34265 .57009 m .34265 .5145 L .37203 .51113 L p .707 .577 .707 r
F P
0 g
s
.3186 .6361 m .3186 .59904 L .34265 .59339 L p .707 .577 .707 r
F P
0 g
s
.48356 .66235 m .48356 .68088 L .4625 .67442 L p .707 .577 .707 r
F P
0 g
s
.4625 .67442 m .4625 .65589 L .48356 .66235 L p .707 .577 .707 r
F P
0 g
s
.43504 .51225 m .43504 .56783 L .40387 .56593 L p .707 .577 .707 r
F P
0 g
s
.40387 .56593 m .40387 .51035 L .43504 .51225 L p .707 .577 .707 r
F P
0 g
s
.34265 .59339 m .34265 .63045 L .3186 .6361 L p .707 .577 .707 r
F P
0 g
s
.37203 .56671 m .37203 .51113 L .40387 .51035 L p .707 .577 .707 r
F P
0 g
s
.37203 .51113 m .37203 .56671 L .34265 .57009 L p .707 .577 .707 r
F P
0 g
s
.4625 .59553 m .4625 .63259 L .43504 .62819 L p .707 .577 .707 r
F P
0 g
s
.43504 .62819 m .43504 .59114 L .4625 .59553 L p .707 .577 .707 r
F P
0 g
s
.40387 .51035 m .40387 .56593 L .37203 .56671 L p .707 .577 .707 r
F P
0 g
s
.3186 .67793 m .3186 .65941 L .34265 .65376 L p .707 .577 .707 r
F P
0 g
s
.34265 .63045 m .34265 .59339 L .37203 .59002 L p .707 .577 .707 r
F P
0 g
s
.34265 .65376 m .34265 .67228 L .3186 .67793 L p .707 .577 .707 r
F P
0 g
s
.43504 .59114 m .43504 .62819 L .40387 .62629 L p .707 .577 .707 r
F P
0 g
s
.40387 .62629 m .40387 .58924 L .43504 .59114 L p .707 .577 .707 r
F P
0 g
s
.4625 .65589 m .4625 .67442 L .43504 .67003 L p .707 .577 .707 r
F P
0 g
s
.43504 .67003 m .43504 .6515 L .4625 .65589 L p .707 .577 .707 r
F P
0 g
s
.37203 .59002 m .37203 .62707 L .34265 .63045 L p .707 .577 .707 r
F P
0 g
s
.37203 .62707 m .37203 .59002 L .40387 .58924 L p .707 .577 .707 r
F P
0 g
s
.40387 .58924 m .40387 .62629 L .37203 .62707 L p .707 .577 .707 r
F P
0 g
s
.34265 .67228 m .34265 .65376 L .37203 .65038 L p .707 .577 .707 r
F P
0 g
s
.37203 .65038 m .37203 .66891 L .34265 .67228 L p .707 .577 .707 r
F P
0 g
s
.43504 .6515 m .43504 .67003 L .40387 .66813 L p .707 .577 .707 r
F P
0 g
s
.40387 .66813 m .40387 .6496 L .43504 .6515 L p .707 .577 .707 r
F P
0 g
s
.37203 .66891 m .37203 .65038 L .40387 .6496 L p .707 .577 .707 r
F P
0 g
s
.40387 .6496 m .40387 .66813 L .37203 .66891 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001gOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0
07Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00KGoo0`0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0`0000=JEP00FUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001XOol2
0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006Qo
o`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00FWoo10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`80009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00EGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooa8004Aoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPT000MJEP03001JEUYF
00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00Dgoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001C
Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF4@0000=JEP00FUH01UYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol20003FUH00`00FUIJEP03FUH00`00FUH000050003FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH800000eYF001JEP05FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005=oo`8000=JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P000UYF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001DOol01000FUIJEUYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P000eYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo6P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF1`0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00=Goo1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000P0015YF00@005YFFUIJEP8002eoo`00<Woo0`001EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP0200000eYF0000000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQT000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006
FUH00`00FUIJEP02FUH3000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP04001JEUYFFUH80002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0009JEP03001JEUYF009JEP03001JEP0002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00000eYF1@0015YF00@005YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001J
EUYF00UJEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020004FUH2000^Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20004
FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP80009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH01000FUIJEUYF200015YF10000UYF2@00
0eYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH4000_Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Woo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUHA00000eYF001JEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00=JEP03001JEP0000D0
00=JEP03001JEUYF00IJEP03001JEUYF009JEPP00003FUH005YF00EJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00@005YFFUIJEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60002FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF009JEQH000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01P00FUIJEUYF
001JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009JEQ80
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000=J
EPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP02FUH80008Ool30005Ool80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YF00000P000UYF00@005YFFUIJEP8000Moo`D000aoo`D000AJEP04001J
EUYFFUH2000]Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00D005YF001JEP0000AJEP04001JEUYFFUH90007FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1P000UYF00@005YFFUIJEP8000Moo`D000ioo`H00003
FUH005YF009JEP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00D005YF001JEP0000=JEPD0009JEP@0009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPD0009JEP@00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF
0P001goo1@002Goo1@001EYF0`000eYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUHA00001eYF001JEP00FUH005YF00<000IJEP04001JEUYFFUHI0007FUH01000FUIJEUYF0P00
0eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
008000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YF00001@000eYF00<005YFFUH01UYF00<005YFFUH0
0UYF100000IJEP00000005YF0006FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF1@001EYF00<0
05YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo0P00
0eYF00@005YFFUIJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH0
000000@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUHK0006FUH00`00FUIJEP02FUH3000]Ool002eo
o`04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20002FUH3
0002FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EPD0009JEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00H005YF000005YF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUH000020004FUH200000eYF0000
0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH000020004FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEPT0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00MJEP@00003FUH005YF009JEP03001JEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80009JEP8002ioo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YFFUIJEP0000EJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50005FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF1000;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF009JEQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000_Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP06FUH80003
FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP06
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUH000040004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH01@00FUIJ
EUYF0000;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00003FUH30003FUH00`00FUH000080004FUH400000eYF000000070008
Ool300000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEQL000IJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P001UYF00<005YFFUH00UYF0`000goo2@0057oo0P000eYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH60009Ool3000;Ool40002FUH00`00FUIJEP03FUH0
0`00FUH0000H0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01@00FUH00000FUH01@000UYF00<005YFFUH00UYF00<005YF00001goo1@00
5Woo0P0000=JEP000000;Goo000/Ool00`00FUH00004FUH00`00FUH00003000>Ool5000>Ool50003
FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00
FUH00eYF00<005YF00000P0015YF0P0027oo1@005Goo0P0000AJEP00000002eoo`00;7oo00<005YF
00000eYF0`0000=JEP0000000`0037oo1@003goo20000UYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP<00003FUH005YF00=JEP80009JEP8000Uoo`<001=oo`<000=JEP<0
02eoo`00;7oo00@005YF001JEP8000EJEP04001JEUYFFUH80004Ool5000:Ool50005FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF
00D0009JEP@001aoo`@00003FUH005YF00=JEP03001JEP0002eoo`00;7oo00H005YF000005YF0005
FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEP00
00D001Moo`D000EJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF2@0000=JEP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00=JEQT000=JEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00@005YFFUIJ
EP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH2000_Ool002aoo`8000=JEP03001JEUYF00=JEPP000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF3@002eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP00000aOol002eoo`04001JEUYFFUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@00<goo000^Ool01P00FUH00000FUH000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF00<005YFFUH00eYF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YF
FUH00eYF2@0015YF00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP@000AJEP03
001JEP00009oo`D000AJEP04001JEUYFFUH20003Ool90018Ool002eoo`8000AJEP04001JEUYFFUH9
0007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEP000UYF00@005YF000000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP05001JEUYFFUH00003FUH00`00FUH00004Ool600000eYF001JEP02FUH2001DOol002aoo`03001J
EP0000AJEPP000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPL00006Ool00000
001JEP000UYF00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P0000=JEP00FUH01@00
1EYF0`000eYF0P00E7oo000/Ool00`00FUH00002FUH20008OolK000;Ool20002FUH00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00001UYF00<005YFFUH00P0000=J
EP000000E7oo000/Ool00`00FUH00002000FOol5000GOol01000FUH0000015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF009JEP<005Aoo`00;7oo00@005YF
000001Moo`D001Qoo`<000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000002FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3001DOol002aoo`80009JEP<001Aoo`D001Ioo`D000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0005Aoo`00
;7oo0P000eYF00<005YF00000P004Woo0`0057oo0`000UYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00@005YFFUH000AJEP@00003FUH005YF00=JEP03001JEP0005Aoo`00;7oo0P000eYF00<0
05YFFUH00UYF1@0087oo100000=JEP00FUH00UYF00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00001UYF00<005YFFUH010000UYF0P00EGoo000]Ool01@00FUIJEUYF00001EYF
00@005YFFUIJEPP001=oo`D000EJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH30006FUH00`00FUIJEP03FUH4001FOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000
FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`80009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP800003FUH005YF00EJEP03001JEUYF00=JEP04001JEP00001FOol002moo`<000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEP000005Ool30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF2@000eYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00<Goo0`000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`002Goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF000005YF0007FUH50004FUH01@00FUIJEUYF
0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
0003000>Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH50003Ool300000eYF001JEP02FUH2001DOol0
03Uoo`@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD001Aoo`<00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEPh000]o
o`8000=JEP8005Aoo`00?Goo6@0077oo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YF000020005Woo0P0000=JEP000000E7oo001iOol<0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP03FUH70004Ool5000GOol4001DOol008EooaT000]oo`D001Eoo`800004FUH00000001D
Ool008ioo`80009JEP03001JEP00008001=oo`<0015oo`D000=JEP03001JEP0005Aoo`00Sgoo00@0
05YFFUH000AJEPD001]oo`L000=JEP03001JEUYF009JEP8005Eoo`00Sgoo00@005YFFUH000EJEP04
001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]69\[InvisibleSpace]"     "\
\[InvisibleSpace]16.263096237724497`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 69, "     ", 16.263096237724497, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Static Mode Plots", "Subsection",
  PageWidth->PaperWidth],

Cell[BoxData[
    \(\(modePlot[k_, factorT_, factorR_] := 
        Block[{j}, \n
          transvec = 
            Partition[
              Table[vecs[\([k, transdof[\([j]\)]]\)], {j, 1, 
                  Length[transdof]}], 3]; \n
          rotatevec = 
            Partition[
              Table[vecs[\([k, rotatedof[\([j]\)]]\)], {j, 1, 
                  Length[rotatedof]}], 3]; \[IndentingNewLine]jsin = 
            Table[Sin[j\ Pi], {j, 0.5, 1.5, 
                1}]; \[IndentingNewLine]Table[\[IndentingNewLine]Show[\
\[IndentingNewLine]Table[\[IndentingNewLine]TranslateShape[\[IndentingNewLine]\
RotateShape[\[IndentingNewLine]RotateShape[\[IndentingNewLine]Graphics3D[
                        Cylinder[legMassRadius, 
                          massCylinderHalfHeights[\([i - 2]\)], 
                          20]], \[IndentingNewLine]Pi/
                        2, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([i, 
                            2]\)], \(-Pi\)/2 - 
                        jsin[\([j]\)]\ factorR\ \ rotatevec[\([i, 3]\)]], 
                    0, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([i, 1]\)], 
                    0], \[IndentingNewLine]massPositions[\([i - 2]\)] + 
                    jsin[\([j]\)]\ factorT\ transvec[\([i]\)]], \
\[IndentingNewLine]{i, 3, 
                  nElements - 
                    1}], \[IndentingNewLine]TranslateShape[\[IndentingNewLine]\
RotateShape[\[IndentingNewLine]RotateShape[\[IndentingNewLine]Graphics3D[
                      Cylinder[downtubeRadius, downtubeMassHeight/2, 
                        20]], \[IndentingNewLine]Pi/
                      2, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([nElements, 
                          2]\)], \(-Pi\)/2 - 
                      jsin[\([j]\)]\ factorR\ \ rotatevec[\([nElements, 
                            3]\)]], 
                  0, \(-jsin[\([j]\)]\)\ factorR\ rotatevec[\([nElements, 
                        1]\)], 
                  0], \[IndentingNewLine]massPositions[\([nElements - 2]\)] + 
                  jsin[\([j]\)]\ factorT\ transvec[\([nElements]\)]], \
\[IndentingNewLine]Graphics3D[{PointSize[0.02], 
                  pts}], \[IndentingNewLine]BoxRatios \[Rule] {1, 1, 1}, 
              PlotRange \[Rule] {{\(-range\), range}, {\(-range\), 
                    range}, {\(-1.2\)\ range, 0.8\ range}}, 
              ViewPoint \[Rule] {40000, 100000, 30000}, 
              Boxed \[Rule] False], \[IndentingNewLine]{j, 1, 2}]; \n
          Print["\<Mode # \>", k, "\<     \>", 
            freqs[\([k]\)], "\< Hz\>"];\[IndentingNewLine]];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Do[
        modePlot[opticstableModes[\([k]\)], 20, 1], {k, 1, 
          nPlots}];\)\)], "Input",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59997 .75691 m .59683 .70404 L .56568 .70283 L p .707 .577 .707 r
F P
0 g
s
.59683 .70404 m .59997 .75691 L .63175 .75413 L p .707 .577 .707 r
F P
0 g
s
.63175 .75413 m .62861 .70125 L .59683 .70404 L p .707 .577 .707 r
F P
0 g
s
.62861 .70125 m .63175 .75413 L .66104 .74762 L p .707 .577 .707 r
F P
0 g
s
.66104 .74762 m .6579 .69474 L .62861 .70125 L p .707 .577 .707 r
F P
0 g
s
.56882 .7557 m .56568 .70283 L .5382 .69774 L p .707 .577 .707 r
F P
0 g
s
.56568 .70283 m .56882 .7557 L .59997 .75691 L p .707 .577 .707 r
F P
0 g
s
.6579 .69474 m .66104 .74762 L .68498 .73802 L p .707 .577 .707 r
F P
0 g
s
.68498 .73802 m .68184 .68515 L .6579 .69474 L p .707 .577 .707 r
F P
0 g
s
.54134 .75062 m .5382 .69774 L .51709 .68928 L p .707 .577 .707 r
F P
0 g
s
.5382 .69774 m .54134 .75062 L .56882 .7557 L p .707 .577 .707 r
F P
0 g
s
.68184 .68515 m .68498 .73802 L .70122 .72628 L p .707 .577 .707 r
F P
0 g
s
.70122 .72628 m .69808 .67341 L .68184 .68515 L p .707 .577 .707 r
F P
0 g
s
.60425 .81778 m .6008 .78413 L .56968 .78336 L p .707 .577 .707 r
F P
0 g
s
.6008 .78413 m .60425 .81778 L .63592 .81373 L p .707 .577 .707 r
F P
0 g
s
.63592 .81373 m .63248 .78009 L .6008 .78413 L p .707 .577 .707 r
F P
0 g
s
.63248 .78009 m .63592 .81373 L .66506 .80526 L p .707 .577 .707 r
F P
0 g
s
.66506 .80526 m .66161 .77162 L .63248 .78009 L p .707 .577 .707 r
F P
0 g
s
.57313 .817 m .56968 .78336 L .54217 .77784 L p .707 .577 .707 r
F P
0 g
s
.56968 .78336 m .57313 .817 L .60425 .81778 L p .707 .577 .707 r
F P
0 g
s
.66161 .77162 m .66506 .80526 L .6888 .7932 L p .707 .577 .707 r
F P
0 g
s
.6888 .7932 m .68535 .75956 L .66161 .77162 L p .707 .577 .707 r
F P
0 g
s
.52023 .74216 m .51709 .68928 L .5044 .67827 L p .707 .577 .707 r
F P
0 g
s
.51709 .68928 m .52023 .74216 L .54134 .75062 L p .707 .577 .707 r
F P
0 g
s
.54562 .81148 m .54217 .77784 L .52096 .76812 L p .707 .577 .707 r
F P
0 g
s
.54217 .77784 m .54562 .81148 L .57313 .817 L p .707 .577 .707 r
F P
0 g
s
.69808 .67341 m .70122 .72628 L .70818 .71355 L p .707 .577 .707 r
F P
0 g
s
.70818 .71355 m .70504 .66067 L .69808 .67341 L p .707 .577 .707 r
F P
0 g
s
.60729 .8501 m .60552 .83334 L .57441 .8326 L p .707 .577 .707 r
F P
0 g
s
.60552 .83334 m .60729 .8501 L .63896 .84598 L p .707 .577 .707 r
F P
0 g
s
.63896 .84598 m .63719 .82921 L .60552 .83334 L p .707 .577 .707 r
F P
0 g
s
.63719 .82921 m .63896 .84598 L .66808 .83738 L p .707 .577 .707 r
F P
0 g
s
.66808 .83738 m .66631 .82061 L .63719 .82921 L p .707 .577 .707 r
F P
0 g
s
.68535 .75956 m .6888 .7932 L .70482 .77873 L p .707 .577 .707 r
F P
0 g
s
.70482 .77873 m .70137 .74508 L .68535 .75956 L p .707 .577 .707 r
F P
0 g
s
.57618 .84936 m .57441 .8326 L .54689 .82705 L p .707 .577 .707 r
F P
0 g
s
.57441 .8326 m .57618 .84936 L .60729 .8501 L p .707 .577 .707 r
F P
0 g
s
.5044 .67827 m .50754 .73114 L .52023 .74216 L p .707 .577 .707 r
F P
0 g
s
.66631 .82061 m .66808 .83738 L .6918 .82515 L p .707 .577 .707 r
F P
0 g
s
.6918 .82515 m .69003 .80839 L .66631 .82061 L p .707 .577 .707 r
F P
0 g
s
.50754 .73114 m .5044 .67827 L .50139 .66578 L p .707 .577 .707 r
F P
0 g
s
.52096 .76812 m .5244 .80176 L .54562 .81148 L p .707 .577 .707 r
F P
0 g
s
.54689 .82705 m .54866 .84381 L .57618 .84936 L p .707 .577 .707 r
F P
0 g
s
.5244 .80176 m .52096 .76812 L .50811 .75514 L p .707 .577 .707 r
F P
0 g
s
.54866 .84381 m .54689 .82705 L .52567 .81724 L p .707 .577 .707 r
F P
0 g
s
.70504 .66067 m .70818 .71355 L .70517 .70106 L p .707 .577 .707 r
F P
0 g
s
.70517 .70106 m .70203 .64819 L .70504 .66067 L p .707 .577 .707 r
F P
0 g
s
.70137 .74508 m .70482 .77873 L .71156 .76325 L p .707 .577 .707 r
F P
0 g
s
.71156 .76325 m .70811 .72961 L .70137 .74508 L p .707 .577 .707 r
F P
0 g
s
.69003 .80839 m .6918 .82515 L .70781 .81049 L p .707 .577 .707 r
F P
0 g
s
.70781 .81049 m .70604 .79373 L .69003 .80839 L p .707 .577 .707 r
F P
0 g
s
.52567 .81724 m .52744 .83401 L .54866 .84381 L p .707 .577 .707 r
F P
0 g
s
.50139 .66578 m .50453 .71866 L .50754 .73114 L p .707 .577 .707 r
F P
0 g
s
.50811 .75514 m .51156 .78879 L .5244 .80176 L p .707 .577 .707 r
F P
0 g
s
.50453 .71866 m .50139 .66578 L .50835 .65304 L p .707 .577 .707 r
F P
0 g
s
.52744 .83401 m .52567 .81724 L .51281 .80414 L p .707 .577 .707 r
F P
0 g
s
.51156 .78879 m .50811 .75514 L .50491 .74019 L p .707 .577 .707 r
F P
0 g
s
.70604 .79373 m .70781 .81049 L .71452 .79483 L p .707 .577 .707 r
F P
0 g
s
.71452 .79483 m .71275 .77807 L .70604 .79373 L p .707 .577 .707 r
F P
0 g
s
.51281 .80414 m .51458 .8209 L .52744 .83401 L p .707 .577 .707 r
F P
0 g
s
.70811 .72961 m .71156 .76325 L .70835 .7483 L p .707 .577 .707 r
F P
0 g
s
.70835 .7483 m .7049 .71465 L .70811 .72961 L p .707 .577 .707 r
F P
0 g
s
.70203 .64819 m .70517 .70106 L .69248 .69005 L p .707 .577 .707 r
F P
0 g
s
.69248 .69005 m .68934 .63717 L .70203 .64819 L p .707 .577 .707 r
F P
0 g
s
.50491 .74019 m .50835 .77384 L .51156 .78879 L p .707 .577 .707 r
F P
0 g
s
.50835 .65304 m .51149 .70592 L .50453 .71866 L p .707 .577 .707 r
F P
0 g
s
.51458 .8209 m .51281 .80414 L .50959 .78902 L p .707 .577 .707 r
F P
0 g
s
.51149 .70592 m .50835 .65304 L .52459 .6413 L p .707 .577 .707 r
F P
0 g
s
.50835 .77384 m .50491 .74019 L .51164 .72472 L p .707 .577 .707 r
F P
0 g
s
.25696 .7201 m .25382 .66722 L .22267 .66601 L p .707 .577 .707 r
F P
0 g
s
.25382 .66722 m .25696 .7201 L .28874 .71731 L p .707 .577 .707 r
F P
0 g
s
.28874 .71731 m .2856 .66443 L .25382 .66722 L p .707 .577 .707 r
F P
0 g
s
.2856 .66443 m .28874 .71731 L .31803 .7108 L p .707 .577 .707 r
F P
0 g
s
.31803 .7108 m .31489 .65793 L .2856 .66443 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71275 .77807 m .71452 .79483 L .7113 .77971 L p .707 .577 .707 r
F P
0 g
s
.7113 .77971 m .70953 .76295 L .71275 .77807 L p .707 .577 .707 r
F P
0 g
s
.50959 .78902 m .51136 .80578 L .51458 .8209 L p .707 .577 .707 r
F P
0 g
s
.22581 .71889 m .22267 .66601 L .19519 .66093 L p .707 .577 .707 r
F P
0 g
s
.22267 .66601 m .22581 .71889 L .25696 .7201 L p .707 .577 .707 r
F P
0 g
s
.7049 .71465 m .70835 .7483 L .69551 .73533 L p .707 .577 .707 r
F P
0 g
s
.69551 .73533 m .69206 .70168 L .7049 .71465 L p .707 .577 .707 r
F P
0 g
s
.68934 .63717 m .69248 .69005 L .67137 .68158 L p .707 .577 .707 r
F P
0 g
s
.67137 .68158 m .66823 .62871 L .68934 .63717 L p .707 .577 .707 r
F P
0 g
s
.31489 .65793 m .31803 .7108 L .34197 .70121 L p .707 .577 .707 r
F P
0 g
s
.34197 .70121 m .33883 .64833 L .31489 .65793 L p .707 .577 .707 r
F P
0 g
s
.51164 .72472 m .51509 .75836 L .50835 .77384 L p .707 .577 .707 r
F P
0 g
s
.52459 .6413 m .52773 .69418 L .51149 .70592 L p .707 .577 .707 r
F P
0 g
s
.19833 .7138 m .19519 .66093 L .17408 .65246 L p .707 .577 .707 r
F P
0 g
s
.19519 .66093 m .19833 .7138 L .22581 .71889 L p .707 .577 .707 r
F P
0 g
s
.52773 .69418 m .52459 .6413 L .54853 .63171 L p .707 .577 .707 r
F P
0 g
s
.51136 .80578 m .50959 .78902 L .51631 .77336 L p .707 .577 .707 r
F P
0 g
s
.51509 .75836 m .51164 .72472 L .52766 .71024 L p .707 .577 .707 r
F P
0 g
s
.33883 .64833 m .34197 .70121 L .35821 .68947 L p .707 .577 .707 r
F P
0 g
s
.35821 .68947 m .35507 .63659 L .33883 .64833 L p .707 .577 .707 r
F P
0 g
s
.66823 .62871 m .67137 .68158 L .64389 .6765 L p .707 .577 .707 r
F P
0 g
s
.64389 .6765 m .64075 .62362 L .66823 .62871 L p .707 .577 .707 r
F P
0 g
s
.26124 .78096 m .25779 .74731 L .22667 .74654 L p .707 .577 .707 r
F P
0 g
s
.25779 .74731 m .26124 .78096 L .29292 .77692 L p .707 .577 .707 r
F P
0 g
s
.29292 .77692 m .28947 .74327 L .25779 .74731 L p .707 .577 .707 r
F P
0 g
s
.70953 .76295 m .7113 .77971 L .69844 .76661 L p .707 .577 .707 r
F P
0 g
s
.69844 .76661 m .69667 .74985 L .70953 .76295 L p .707 .577 .707 r
F P
0 g
s
.28947 .74327 m .29292 .77692 L .32205 .76845 L p .707 .577 .707 r
F P
0 g
s
.32205 .76845 m .3186 .7348 L .28947 .74327 L p .707 .577 .707 r
F P
0 g
s
.51631 .77336 m .51808 .79013 L .51136 .80578 L p .707 .577 .707 r
F P
0 g
s
.69206 .70168 m .69551 .73533 L .67429 .72561 L p .707 .577 .707 r
F P
0 g
s
.67429 .72561 m .67085 .69196 L .69206 .70168 L p .707 .577 .707 r
F P
0 g
s
.23012 .78019 m .22667 .74654 L .19916 .74102 L p .707 .577 .707 r
F P
0 g
s
.22667 .74654 m .23012 .78019 L .26124 .78096 L p .707 .577 .707 r
F P
0 g
s
.55167 .68459 m .54853 .63171 L .57782 .6252 L p .707 .577 .707 r
F P
0 g
s
.54853 .63171 m .55167 .68459 L .52773 .69418 L p .707 .577 .707 r
F P
0 g
s
.3186 .7348 m .32205 .76845 L .34579 .75639 L p .707 .577 .707 r
F P
0 g
s
.34579 .75639 m .34234 .72274 L .3186 .7348 L p .707 .577 .707 r
F P
0 g
s
.52766 .71024 m .53111 .74389 L .51509 .75836 L p .707 .577 .707 r
F P
0 g
s
.17722 .70534 m .17408 .65246 L .16139 .64145 L p .707 .577 .707 r
F P
0 g
s
.17408 .65246 m .17722 .70534 L .19833 .7138 L p .707 .577 .707 r
F P
0 g
s
.64075 .62362 m .64389 .6765 L .61274 .67529 L p .707 .577 .707 r
F P
0 g
s
.61274 .67529 m .6096 .62241 L .64075 .62362 L p .707 .577 .707 r
F P
0 g
s
.53111 .74389 m .52766 .71024 L .5514 .69818 L p .707 .577 .707 r
F P
0 g
s
.51808 .79013 m .51631 .77336 L .53231 .7587 L p .707 .577 .707 r
F P
0 g
s
.58096 .67808 m .57782 .6252 L .6096 .62241 L p .707 .577 .707 r
F P
0 g
s
.57782 .6252 m .58096 .67808 L .55167 .68459 L p .707 .577 .707 r
F P
0 g
s
.6096 .62241 m .61274 .67529 L .58096 .67808 L p .707 .577 .707 r
F P
0 g
s
.20261 .77467 m .19916 .74102 L .17795 .7313 L p .707 .577 .707 r
F P
0 g
s
.19916 .74102 m .20261 .77467 L .23012 .78019 L p .707 .577 .707 r
F P
0 g
s
.67085 .69196 m .67429 .72561 L .64678 .72009 L p .707 .577 .707 r
F P
0 g
s
.64678 .72009 m .64333 .68644 L .67085 .69196 L p .707 .577 .707 r
F P
0 g
s
.35507 .63659 m .35821 .68947 L .36517 .67673 L p .707 .577 .707 r
F P
0 g
s
.36517 .67673 m .36203 .62386 L .35507 .63659 L p .707 .577 .707 r
F P
0 g
s
.26428 .81329 m .26251 .79653 L .2314 .79578 L p .707 .577 .707 r
F P
0 g
s
.26251 .79653 m .26428 .81329 L .29595 .80916 L p .707 .577 .707 r
F P
0 g
s
.29595 .80916 m .29418 .7924 L .26251 .79653 L p .707 .577 .707 r
F P
0 g
s
.29418 .7924 m .29595 .80916 L .32507 .80056 L p .707 .577 .707 r
F P
0 g
s
.32507 .80056 m .3233 .7838 L .29418 .7924 L p .707 .577 .707 r
F P
0 g
s
.69667 .74985 m .69844 .76661 L .67722 .7568 L p .707 .577 .707 r
F P
0 g
s
.67722 .7568 m .67545 .74004 L .69667 .74985 L p .707 .577 .707 r
F P
0 g
s
.53231 .7587 m .53408 .77547 L .51808 .79013 L p .707 .577 .707 r
F P
0 g
s
.34234 .72274 m .34579 .75639 L .36181 .74191 L p .707 .577 .707 r
F P
0 g
s
.36181 .74191 m .35836 .70826 L .34234 .72274 L p .707 .577 .707 r
F P
0 g
s
.23317 .81254 m .2314 .79578 L .20388 .79023 L p .707 .577 .707 r
F P
0 g
s
.2314 .79578 m .23317 .81254 L .26428 .81329 L p .707 .577 .707 r
F P
0 g
s
.55485 .73183 m .5514 .69818 L .58054 .68971 L p .707 .577 .707 r
F P
0 g
s
.5514 .69818 m .55485 .73183 L .53111 .74389 L p .707 .577 .707 r
F P
0 g
s
.16139 .64145 m .16453 .69433 L .17722 .70534 L p .707 .577 .707 r
F P
0 g
s
.3233 .7838 m .32507 .80056 L .34879 .78833 L p .707 .577 .707 r
F P
0 g
s
.34879 .78833 m .34702 .77157 L .3233 .7838 L p .707 .577 .707 r
F P
0 g
s
.64333 .68644 m .64678 .72009 L .61566 .71931 L p .707 .577 .707 r
F P
0 g
s
.61566 .71931 m .61222 .68567 L .64333 .68644 L p .707 .577 .707 r
F P
0 g
s
.16453 .69433 m .16139 .64145 L .15838 .62896 L p .707 .577 .707 r
F P
0 g
s
.17795 .7313 m .18139 .76495 L .20261 .77467 L p .707 .577 .707 r
F P
0 g
s
.20388 .79023 m .20565 .807 L .23317 .81254 L p .707 .577 .707 r
F P
0 g
s
.53408 .77547 m .53231 .7587 L .55603 .74648 L p .707 .577 .707 r
F P
0 g
s
.18139 .76495 m .17795 .7313 L .16511 .71833 L p .707 .577 .707 r
F P
0 g
s
.58399 .72336 m .58054 .68971 L .61222 .68567 L p .707 .577 .707 r
F P
0 g
s
.58054 .68971 m .58399 .72336 L .55485 .73183 L p .707 .577 .707 r
F P
0 g
s
.61222 .68567 m .61566 .71931 L .58399 .72336 L p .707 .577 .707 r
F P
0 g
s
.20565 .807 m .20388 .79023 L .18266 .78043 L p .707 .577 .707 r
F P
0 g
s
.67545 .74004 m .67722 .7568 L .6497 .75126 L p .707 .577 .707 r
F P
0 g
s
.6497 .75126 m .64793 .73449 L .67545 .74004 L p .707 .577 .707 r
F P
0 g
s
.55603 .74648 m .5578 .76324 L .53408 .77547 L p .707 .577 .707 r
F P
0 g
s
.36203 .62386 m .36517 .67673 L .36216 .66425 L p .707 .577 .707 r
F P
0 g
s
.36216 .66425 m .35902 .61137 L .36203 .62386 L p .707 .577 .707 r
F P
0 g
s
.35836 .70826 m .36181 .74191 L .36855 .72644 L p .707 .577 .707 r
F P
0 g
s
.36855 .72644 m .3651 .69279 L .35836 .70826 L p .707 .577 .707 r
F P
0 g
s
.34702 .77157 m .34879 .78833 L .3648 .77367 L p .707 .577 .707 r
F P
0 g
s
.3648 .77367 m .36303 .75691 L .34702 .77157 L p .707 .577 .707 r
F P
0 g
s
.18266 .78043 m .18443 .79719 L .20565 .807 L p .707 .577 .707 r
F P
0 g
s
.5578 .76324 m .55603 .74648 L .58515 .73788 L p .707 .577 .707 r
F P
0 g
s
.15838 .62896 m .16152 .68184 L .16453 .69433 L p .707 .577 .707 r
F P
0 g
s
.16511 .71833 m .16855 .75197 L .18139 .76495 L p .707 .577 .707 r
F P
0 g
s
.64793 .73449 m .6497 .75126 L .61859 .75051 L p .707 .577 .707 r
F P
0 g
s
.61859 .75051 m .61682 .73375 L .64793 .73449 L p .707 .577 .707 r
F P
0 g
s
.51041 .24351 m .45001 .76084 L .49389 .76573 L p .707 .577 .707 r
F P
0 g
s
.49389 .76573 m .55429 .2484 L .51041 .24351 L p .707 .577 .707 r
F P
0 g
s
.55429 .2484 m .49389 .76573 L .53845 .77105 L p .707 .577 .707 r
F P
0 g
s
.16152 .68184 m .15838 .62896 L .16534 .61623 L p .707 .577 .707 r
F P
0 g
s
.58515 .73788 m .58692 .75464 L .5578 .76324 L p .707 .577 .707 r
F P
0 g
s
.53845 .77105 m .59885 .25372 L .55429 .2484 L p .707 .577 .707 r
F P
0 g
s
.59885 .25372 m .53845 .77105 L .57934 .77627 L p .707 .577 .707 r
F P
0 g
s
.18443 .79719 m .18266 .78043 L .16981 .76732 L p .707 .577 .707 r
F P
0 g
s
.58692 .75464 m .58515 .73788 L .61682 .73375 L p .707 .577 .707 r
F P
0 g
s
.16855 .75197 m .16511 .71833 L .1619 .70337 L p .707 .577 .707 r
F P
0 g
s
.61682 .73375 m .61859 .75051 L .58692 .75464 L p .707 .577 .707 r
F P
0 g
s
.47151 .23952 m .41111 .75685 L .45001 .76084 L p .707 .577 .707 r
F P
0 g
s
.45001 .76084 m .51041 .24351 L .47151 .23952 L p .707 .577 .707 r
F P
0 g
s
.36303 .75691 m .3648 .77367 L .37152 .75802 L p .707 .577 .707 r
F P
0 g
s
.37152 .75802 m .36975 .74126 L .36303 .75691 L p .707 .577 .707 r
F P
0 g
s
.16981 .76732 m .17158 .78409 L .18443 .79719 L p .707 .577 .707 r
F P
0 g
s
.3651 .69279 m .36855 .72644 L .36534 .71148 L p .707 .577 .707 r
F P
0 g
s
.36534 .71148 m .36189 .67784 L .3651 .69279 L p .707 .577 .707 r
F P
0 g
s
.35902 .61137 m .36216 .66425 L .34947 .65323 L p .707 .577 .707 r
F P
0 g
s
.34947 .65323 m .34633 .60036 L .35902 .61137 L p .707 .577 .707 r
F P
0 g
s
.57934 .77627 m .63974 .25895 L .59885 .25372 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.63974 .25895 m .57934 .77627 L .61255 .78089 L p .707 .577 .707 r
F P
0 g
s
.1619 .70337 m .16534 .73702 L .16855 .75197 L p .707 .577 .707 r
F P
0 g
s
.16534 .61623 m .16848 .6691 L .16152 .68184 L p .707 .577 .707 r
F P
0 g
s
.17158 .78409 m .16981 .76732 L .16658 .7522 L p .707 .577 .707 r
F P
0 g
s
.44141 .23682 m .38101 .75415 L .41111 .75685 L p .707 .577 .707 r
F P
0 g
s
.41111 .75685 m .47151 .23952 L .44141 .23682 L p .707 .577 .707 r
F P
0 g
s
.16848 .6691 m .16534 .61623 L .18158 .60449 L p .707 .577 .707 r
F P
0 g
s
.16534 .73702 m .1619 .70337 L .16863 .6879 L p .707 .577 .707 r
F P
0 g
s
.61255 .78089 m .67295 .26356 L .63974 .25895 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.36975 .74126 m .37152 .75802 L .36829 .7429 L p .707 .577 .707 r
F P
0 g
s
.36829 .7429 m .36652 .72614 L .36975 .74126 L p .707 .577 .707 r
F P
0 g
s
.16658 .7522 m .16835 .76897 L .17158 .78409 L p .707 .577 .707 r
F P
0 g
s
.36189 .67784 m .36534 .71148 L .3525 .69851 L p .707 .577 .707 r
F P
0 g
s
.3525 .69851 m .34905 .66487 L .36189 .67784 L p .707 .577 .707 r
F P
0 g
s
.34633 .60036 m .34947 .65323 L .32836 .64477 L p .707 .577 .707 r
F P
0 g
s
.32836 .64477 m .32522 .59189 L .34633 .60036 L p .707 .577 .707 r
F P
0 g
s
.16863 .6879 m .17208 .72155 L .16534 .73702 L p .707 .577 .707 r
F P
0 g
s
.67295 .26356 m .61255 .78089 L .63483 .78445 L p .707 .577 .707 r
F P
0 g
s
.18158 .60449 m .18472 .65736 L .16848 .6691 L p .707 .577 .707 r
F P
0 g
s
.18472 .65736 m .18158 .60449 L .20552 .59489 L p .707 .577 .707 r
F P
0 g
s
.16835 .76897 m .16658 .7522 L .1733 .73655 L p .707 .577 .707 r
F P
0 g
s
.17208 .72155 m .16863 .6879 L .18466 .67343 L p .707 .577 .707 r
F P
0 g
s
.36652 .72614 m .36829 .7429 L .35543 .72979 L p .707 .577 .707 r
F P
0 g
s
.35543 .72979 m .35366 .71303 L .36652 .72614 L p .707 .577 .707 r
F P
0 g
s
.42304 .23569 m .36264 .75301 L .38101 .75415 L p .707 .577 .707 r
F P
0 g
s
.38101 .75415 m .44141 .23682 L .42304 .23569 L p .707 .577 .707 r
F P
0 g
s
.63483 .78445 m .69523 .26712 L .67295 .26356 L p .707 .577 .707 r
F P
0 g
s
.32522 .59189 m .32836 .64477 L .30088 .63968 L p .707 .577 .707 r
F P
0 g
s
.30088 .63968 m .29774 .58681 L .32522 .59189 L p .707 .577 .707 r
F P
0 g
s
.1733 .73655 m .17507 .75331 L .16835 .76897 L p .707 .577 .707 r
F P
0 g
s
.34905 .66487 m .3525 .69851 L .33128 .68879 L p .707 .577 .707 r
F P
0 g
s
.33128 .68879 m .32784 .65514 L .34905 .66487 L p .707 .577 .707 r
F P
0 g
s
.20866 .64777 m .20552 .59489 L .23481 .58839 L p .707 .577 .707 r
F P
0 g
s
.20552 .59489 m .20866 .64777 L .18472 .65736 L p .707 .577 .707 r
F P
0 g
s
.18466 .67343 m .1881 .70707 L .17208 .72155 L p .707 .577 .707 r
F P
0 g
s
.29774 .58681 m .30088 .63968 L .26973 .63848 L p .707 .577 .707 r
F P
0 g
s
.26973 .63848 m .26659 .5856 L .29774 .58681 L p .707 .577 .707 r
F P
0 g
s
.1881 .70707 m .18466 .67343 L .2084 .66136 L p .707 .577 .707 r
F P
0 g
s
.17507 .75331 m .1733 .73655 L .1893 .72189 L p .707 .577 .707 r
F P
0 g
s
.23795 .64126 m .23481 .58839 L .26659 .5856 L p .707 .577 .707 r
F P
0 g
s
.23481 .58839 m .23795 .64126 L .20866 .64777 L p .707 .577 .707 r
F P
0 g
s
.26659 .5856 m .26973 .63848 L .23795 .64126 L p .707 .577 .707 r
F P
0 g
s
.32784 .65514 m .33128 .68879 L .30377 .68327 L p .707 .577 .707 r
F P
0 g
s
.30377 .68327 m .30032 .64963 L .32784 .65514 L p .707 .577 .707 r
F P
0 g
s
.63483 .78445 m .644 .7866 L p .6641 .58285 L .707 .577 .707 r
F P
0 g
s
.644 .7866 m .63917 .78713 L p .65543 .65806 L .707 .577 .707 r
F P
0 g
s
.66535 .60852 m .66403 .60799 L p .66483 .61114 L .707 .577 .707 r
F P
0 g
s
.67854 .66543 m .66403 .60799 L .66398 .62859 L .707 .577 .707 r
F
.7044 .26927 m .69523 .26712 L p .6641 .58285 L F P
0 g
s
.644 .7866 m .66401 .61521 L p .6641 .58285 L .707 .577 .707 r
F P
0 g
s
.66401 .61521 m .7044 .26927 L p .6641 .58285 L .707 .577 .707 r
F P
0 g
s
.66422 .5327 m .63483 .78445 L p .6641 .58285 L .707 .577 .707 r
F P
0 g
s
.65429 .60409 m .64161 .59307 L p .65637 .65268 L .707 .577 .707 r
F P
0 g
s
.65543 .65806 m .65702 .6501 L .644 .7866 L .707 .577 .707 r
F
.66242 .62882 m .644 .7866 L p .65702 .6501 L F P
0 g
s
.65702 .6501 m .65429 .60409 L p .65637 .65268 L .707 .577 .707 r
F P
0 g
s
.65429 .60409 m .65702 .6501 L p .65983 .63608 L .707 .577 .707 r
F P
0 g
s
.66401 .61521 m .66242 .62882 L p .65702 .6501 L .707 .577 .707 r
F P
0 g
s
.66398 .62859 m .66222 .62415 L .6639 .65956 L .707 .577 .707 r
F
.66222 .62415 m .65429 .60409 L .65983 .63608 L F
.66222 .62415 m .65983 .63608 L .6639 .65956 L F
.66403 .60799 m .65429 .60409 L p .66222 .62415 L F P
0 g
s
.66398 .62859 m .66401 .61521 L .66222 .62415 L .707 .577 .707 r
F
.66401 .61521 m .66403 .60799 L .66222 .62415 L F
.69523 .26712 m .66422 .5327 L p .6641 .58285 L F P
0 g
s
.64161 .59307 m .64475 .64595 L .65567 .65543 L p .707 .577 .707 r
F P
0 g
s
.65543 .65806 m .65577 .65502 L .65585 .65473 L .707 .577 .707 r
F
.65637 .65268 m .64161 .59307 L .65567 .65543 L F
.65258 .67228 m .69957 .2698 L p .65543 .65806 L F P
0 g
s
.7044 .26927 m .66401 .61521 L p .65702 .6501 L .707 .577 .707 r
F P
0 g
s
.65543 .65806 m .65585 .65473 L .65702 .6501 L .707 .577 .707 r
F
.65585 .65473 m .7044 .26927 L .65702 .6501 L F
.65567 .65543 m .65743 .65696 L p .65637 .65268 L F P
0 g
s
.69957 .2698 m .7044 .26927 L p .65585 .65473 L .707 .577 .707 r
F P
0 g
s
.65577 .65502 m .69957 .2698 L .65585 .65473 L .707 .577 .707 r
F
.63917 .78713 m .65224 .6752 L p .65401 .66933 L F P
0 g
s
.64475 .64595 m .64161 .59307 L .6386 .58059 L p .707 .577 .707 r
F P
0 g
s
.63917 .78713 m .6208 .78599 L p .6431 .63987 L .707 .577 .707 r
F P
0 g
s
.6386 .58059 m .64122 .62478 L p .64475 .64595 L .707 .577 .707 r
F P
0 g
s
.6429 .6383 m .64475 .64595 L p .64122 .62478 L .707 .577 .707 r
F P
0 g
s
.69957 .2698 m .64994 .69486 L p .6431 .63987 L .707 .577 .707 r
F P
0 g
s
.64994 .69486 m .63917 .78713 L p .6431 .63987 L .707 .577 .707 r
F P
0 g
s
.6812 .26867 m .69957 .2698 L p .6378 .67455 L .707 .577 .707 r
F P
0 g
s
.64122 .62478 m .6386 .58059 L .64481 .5692 L p .707 .577 .707 r
F P
0 g
s
.6812 .26867 m .6435 .59155 L p .65309 .42853 L .707 .577 .707 r
F P
0 g
s
.64481 .5692 m .64507 .56874 L p .6435 .59155 L .707 .577 .707 r
F P
0 g
s
.64122 .62478 m .64481 .5692 L .6435 .59155 L .707 .577 .707 r
F
.6208 .78599 m .59069 .7833 L p .65309 .42853 L F P
0 g
s
.6435 .59155 m .6208 .78599 L p .65309 .42853 L .707 .577 .707 r
F P
0 g
s
.6208 .78599 m .6435 .59155 L p .6378 .67455 L .707 .577 .707 r
F P
0 g
s
.6435 .59155 m .6812 .26867 L p .6378 .67455 L .707 .577 .707 r
F P
0 g
s
.64122 .62478 m .64174 .63346 L .6429 .6383 L p .707 .577 .707 r
F P
0 g
s
.64174 .63346 m .64122 .62478 L p .64555 .56785 L .707 .577 .707 r
F P
0 g
s
.64507 .56874 m .64555 .56785 L p .64122 .62478 L .707 .577 .707 r
F P
0 g
s
.66161 .72708 m .65816 .69343 L .64941 .68459 L p .707 .577 .707 r
F P
0 g
s
.64941 .68459 m .64532 .68046 L p .64818 .68865 L .707 .577 .707 r
F P
0 g
s
.66161 .72708 m .64941 .68459 L .64818 .68865 L .707 .577 .707 r
F
.65401 .66933 m .65258 .67228 L .65543 .65806 L F
.65224 .6752 m .65258 .67228 L p .65401 .66933 L F P
0 g
s
.65743 .65696 m .65702 .6501 L p .65637 .65268 L .707 .577 .707 r
F P
0 g
s
.65743 .65696 m .6639 .65956 L p .65983 .63608 L .707 .577 .707 r
F P
0 g
s
.65702 .6501 m .65743 .65696 L p .65983 .63608 L .707 .577 .707 r
F P
0 g
s
.6639 .65956 m .67854 .66543 L p .66398 .62859 L .707 .577 .707 r
F P
0 g
s
.67854 .66543 m .6754 .61255 L .66535 .60852 L p .707 .577 .707 r
F P
0 g
s
.67854 .66543 m .66535 .60852 L .66483 .61114 L .707 .577 .707 r
F
.35366 .71303 m .35543 .72979 L .33421 .71999 L p F P
0 g
s
.33421 .71999 m .33244 .70323 L .35366 .71303 L p .707 .577 .707 r
F P
0 g
s
.1893 .72189 m .19107 .73865 L .17507 .75331 L p .707 .577 .707 r
F P
0 g
s
.21184 .69501 m .2084 .66136 L .23753 .6529 L p .707 .577 .707 r
F P
0 g
s
.2084 .66136 m .21184 .69501 L .1881 .70707 L p .707 .577 .707 r
F P
0 g
s
.73717 .67172 m .73403 .61884 L .70288 .61764 L p .707 .577 .707 r
F P
0 g
s
.73403 .61884 m .73717 .67172 L .76895 .66893 L p .707 .577 .707 r
F P
0 g
s
.76895 .66893 m .76581 .61606 L .73403 .61884 L p .707 .577 .707 r
F P
0 g
s
.76581 .61606 m .76895 .66893 L .79824 .66242 L p .707 .577 .707 r
F P
0 g
s
.79824 .66242 m .7951 .60955 L .76581 .61606 L p .707 .577 .707 r
F P
0 g
s
.30032 .64963 m .30377 .68327 L .27265 .6825 L p .707 .577 .707 r
F P
0 g
s
.27265 .6825 m .26921 .64885 L .30032 .64963 L p .707 .577 .707 r
F P
0 g
s
.4182 .23622 m .3578 .75355 L .36264 .75301 L p .707 .577 .707 r
F P
0 g
s
.36264 .75301 m .42304 .23569 L .4182 .23622 L p .707 .577 .707 r
F P
0 g
s
.70602 .67051 m .70288 .61764 L .6754 .61255 L p .707 .577 .707 r
F P
0 g
s
.70288 .61764 m .70602 .67051 L .73717 .67172 L p .707 .577 .707 r
F P
0 g
s
.19107 .73865 m .1893 .72189 L .21302 .70966 L p .707 .577 .707 r
F P
0 g
s
.24098 .68654 m .23753 .6529 L .26921 .64885 L p .707 .577 .707 r
F P
0 g
s
.23753 .6529 m .24098 .68654 L .21184 .69501 L p .707 .577 .707 r
F P
0 g
s
.26921 .64885 m .27265 .6825 L .24098 .68654 L p .707 .577 .707 r
F P
0 g
s
.7951 .60955 m .79824 .66242 L .82218 .65283 L p .707 .577 .707 r
F P
0 g
s
.82218 .65283 m .81904 .59995 L .7951 .60955 L p .707 .577 .707 r
F P
0 g
s
.33244 .70323 m .33421 .71999 L .30669 .71444 L p .707 .577 .707 r
F P
0 g
s
.30669 .71444 m .30492 .69768 L .33244 .70323 L p .707 .577 .707 r
F P
0 g
s
.21302 .70966 m .21479 .72642 L .19107 .73865 L p .707 .577 .707 r
F P
0 g
s
.6754 .61255 m .67854 .66543 L .70602 .67051 L p .707 .577 .707 r
F P
0 g
s
.21479 .72642 m .21302 .70966 L .24214 .70106 L p .707 .577 .707 r
F P
0 g
s
.30492 .69768 m .30669 .71444 L .27558 .7137 L p .707 .577 .707 r
F P
0 g
s
.27558 .7137 m .27381 .69693 L .30492 .69768 L p .707 .577 .707 r
F P
0 g
s
.81904 .59995 m .82218 .65283 L .83842 .64109 L p .707 .577 .707 r
F P
0 g
s
.83842 .64109 m .83528 .58821 L .81904 .59995 L p .707 .577 .707 r
F P
0 g
s
.24214 .70106 m .24391 .71782 L .21479 .72642 L p .707 .577 .707 r
F P
0 g
s
.24391 .71782 m .24214 .70106 L .27381 .69693 L p .707 .577 .707 r
F P
0 g
s
.74145 .74309 m .738 .70945 L .70689 .70867 L p .707 .577 .707 r
F P
0 g
s
.738 .70945 m .74145 .74309 L .77313 .73905 L p .707 .577 .707 r
F P
0 g
s
.77313 .73905 m .76968 .7054 L .738 .70945 L p .707 .577 .707 r
F P
0 g
s
.27381 .69693 m .27558 .7137 L .24391 .71782 L p .707 .577 .707 r
F P
0 g
s
.76968 .7054 m .77313 .73905 L .80226 .73058 L p .707 .577 .707 r
F P
0 g
s
.80226 .73058 m .79882 .69694 L .76968 .7054 L p .707 .577 .707 r
F P
0 g
s
.71034 .74232 m .70689 .70867 L .67937 .70315 L p .707 .577 .707 r
F P
0 g
s
.70689 .70867 m .71034 .74232 L .74145 .74309 L p .707 .577 .707 r
F P
0 g
s
.79882 .69694 m .80226 .73058 L .826 .71852 L p .707 .577 .707 r
F P
0 g
s
.826 .71852 m .82256 .68487 L .79882 .69694 L p .707 .577 .707 r
F P
0 g
s
.42737 .23837 m .36697 .7557 L .3578 .75355 L p .707 .577 .707 r
F P
0 g
s
.3578 .75355 m .4182 .23622 L .42737 .23837 L p .707 .577 .707 r
F P
0 g
s
.83528 .58821 m .83842 .64109 L .84538 .62835 L p .707 .577 .707 r
F P
0 g
s
.84538 .62835 m .84224 .57548 L .83528 .58821 L p .707 .577 .707 r
F P
0 g
s
.68282 .7368 m .67937 .70315 L .65816 .69343 L p .707 .577 .707 r
F P
0 g
s
.67937 .70315 m .68282 .7368 L .71034 .74232 L p .707 .577 .707 r
F P
0 g
s
.82256 .68487 m .826 .71852 L .84203 .70404 L p .707 .577 .707 r
F P
0 g
s
.84203 .70404 m .83858 .6704 L .82256 .68487 L p .707 .577 .707 r
F P
0 g
s
.7445 .79208 m .74273 .77532 L .71161 .77457 L p .707 .577 .707 r
F P
0 g
s
.74273 .77532 m .7445 .79208 L .77616 .78795 L p .707 .577 .707 r
F P
0 g
s
.77616 .78795 m .77439 .77119 L .74273 .77532 L p .707 .577 .707 r
F P
0 g
s
.77439 .77119 m .77616 .78795 L .80529 .77935 L p .707 .577 .707 r
F P
0 g
s
.80529 .77935 m .80352 .76259 L .77439 .77119 L p .707 .577 .707 r
F P
0 g
s
.71338 .79133 m .71161 .77457 L .6841 .76902 L p .707 .577 .707 r
F P
0 g
s
.71161 .77457 m .71338 .79133 L .7445 .79208 L p .707 .577 .707 r
F P
0 g
s
.65816 .69343 m .66161 .72708 L .68282 .7368 L p .707 .577 .707 r
F P
0 g
s
.80352 .76259 m .80529 .77935 L .82901 .76712 L p .707 .577 .707 r
F P
0 g
s
.82901 .76712 m .82724 .75036 L .80352 .76259 L p .707 .577 .707 r
F P
0 g
s
.6841 .76902 m .68587 .78579 L .71338 .79133 L p .707 .577 .707 r
F P
0 g
s
.84224 .57548 m .84538 .62835 L .84237 .61587 L p .707 .577 .707 r
F P
0 g
s
.84237 .61587 m .83923 .56299 L .84224 .57548 L p .707 .577 .707 r
F P
0 g
s
.83858 .6704 m .84203 .70404 L .84876 .68857 L p .707 .577 .707 r
F P
0 g
s
.84876 .68857 m .84531 .65493 L .83858 .6704 L p .707 .577 .707 r
F P
0 g
s
.68587 .78579 m .6841 .76902 L .66287 .75922 L p .707 .577 .707 r
F P
0 g
s
.38926 .75925 m .36697 .7557 L p .4018 .5393 L .707 .577 .707 r
F P
0 g
s
.40927 .58787 m .38926 .75925 L p .4018 .5393 L .707 .577 .707 r
F P
0 g
s
.42737 .23837 m .44966 .24193 L p .4018 .5393 L .707 .577 .707 r
F P
0 g
s
.36697 .7557 m .39637 .50395 L p .4018 .5393 L .707 .577 .707 r
F P
0 g
s
.39637 .50395 m .42737 .23837 L p .4018 .5393 L .707 .577 .707 r
F P
0 g
s
.42247 .76387 m .38926 .75925 L p .41721 .60613 L .707 .577 .707 r
F P
0 g
s
.4228 .57924 m .40814 .58053 L p .41606 .60347 L .707 .577 .707 r
F P
0 g
s
.42553 .62526 m .4228 .57924 L p .41606 .60347 L .707 .577 .707 r
F P
0 g
s
.4228 .57924 m .42553 .62526 L p .45523 .62561 L .707 .577 .707 r
F P
0 g
s
.43689 .64037 m .43588 .64903 L p .42553 .62526 L .707 .577 .707 r
F P
0 g
s
.43588 .64903 m .42247 .76387 L p .41721 .60613 L .707 .577 .707 r
F P
0 g
s
.42553 .62526 m .42594 .63212 L .43001 .63121 L p .707 .577 .707 r
F P
0 g
s
.43001 .63121 m .45523 .62561 L p .42553 .62526 L .707 .577 .707 r
F P
0 g
s
.45523 .62561 m .45209 .57273 L .4228 .57924 L p .707 .577 .707 r
F P
0 g
s
.48287 .24654 m .43689 .64037 L p .41721 .60613 L .707 .577 .707 r
F P
0 g
s
.41721 .60613 m .43689 .64037 L .42553 .62526 L .707 .577 .707 r
F
.44966 .24193 m .48287 .24654 L p .41721 .60613 L F P
0 g
s
.38926 .75925 m .40927 .58787 L p .41721 .60613 L .707 .577 .707 r
F P
0 g
s
.42594 .63212 m .40814 .58053 L .41328 .61395 L .707 .577 .707 r
F
.40927 .58787 m .44966 .24193 L p .41721 .60613 L F P
0 g
s
.41328 .61395 m .40927 .58787 L .39102 .58203 L .707 .577 .707 r
F
.40814 .58053 m .40615 .5807 L p .40927 .58787 L F P
0 g
s
.40615 .5807 m .39102 .58203 L p .40927 .58787 L .707 .577 .707 r
F P
0 g
s
.42594 .63212 m .42553 .62526 L p .41606 .60347 L .707 .577 .707 r
F P
0 g
s
.39102 .58203 m .39416 .6349 L .4162 .63297 L p .707 .577 .707 r
F P
0 g
s
.4162 .63297 m .42594 .63212 L p .41328 .61395 L .707 .577 .707 r
F P
0 g
s
.41328 .61395 m .39102 .58203 L .4162 .63297 L .707 .577 .707 r
F
.44966 .24193 m .40927 .58787 L p .4018 .5393 L F P
0 g
s
.82724 .75036 m .82901 .76712 L .84501 .75246 L p .707 .577 .707 r
F P
0 g
s
.84501 .75246 m .84324 .7357 L .82724 .75036 L p .707 .577 .707 r
F P
0 g
s
.66287 .75922 m .66464 .77598 L .68587 .78579 L p .707 .577 .707 r
F P
0 g
s
.64532 .68046 m .64877 .71411 L .66161 .72708 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64877 .71411 m .64532 .68046 L .64211 .66551 L p .707 .577 .707 r
F P
0 g
s
.66464 .77598 m .66287 .75922 L .65002 .74611 L p .707 .577 .707 r
F P
0 g
s
.83923 .56299 m .84237 .61587 L .82969 .60485 L p .707 .577 .707 r
F P
0 g
s
.82969 .60485 m .82655 .55198 L .83923 .56299 L p .707 .577 .707 r
F P
0 g
s
.84531 .65493 m .84876 .68857 L .84555 .67362 L p .707 .577 .707 r
F P
0 g
s
.84555 .67362 m .84211 .63997 L .84531 .65493 L p .707 .577 .707 r
F P
0 g
s
.84324 .7357 m .84501 .75246 L .85173 .73681 L p .707 .577 .707 r
F P
0 g
s
.85173 .73681 m .84996 .72005 L .84324 .7357 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65002 .74611 m .65179 .76288 L .66464 .77598 L p .707 .577 .707 r
F P
0 g
s
.64555 .56785 m .64869 .62073 L .64174 .63346 L p .707 .577 .707 r
F P
0 g
s
.64211 .66551 m .64556 .69915 L .64877 .71411 L p .707 .577 .707 r
F P
0 g
s
.64869 .62073 m .64555 .56785 L .6618 .55611 L p .707 .577 .707 r
F P
0 g
s
.39416 .6349 m .39102 .58203 L .35987 .58082 L p .707 .577 .707 r
F P
0 g
s
.59069 .7833 m .65109 .26597 L .6812 .26867 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64556 .69915 m .64211 .66551 L .64885 .65003 L p .707 .577 .707 r
F P
0 g
s
.65179 .76288 m .65002 .74611 L .64679 .73099 L p .707 .577 .707 r
F P
0 g
s
.36301 .6337 m .35987 .58082 L .33239 .57573 L p .707 .577 .707 r
F P
0 g
s
.35987 .58082 m .36301 .6337 L .39416 .6349 L p .707 .577 .707 r
F P
0 g
s
.82655 .55198 m .82969 .60485 L .80857 .59639 L p .707 .577 .707 r
F P
0 g
s
.80857 .59639 m .80543 .54351 L .82655 .55198 L p .707 .577 .707 r
F P
0 g
s
.84211 .63997 m .84555 .67362 L .83271 .66064 L p .707 .577 .707 r
F P
0 g
s
.83271 .66064 m .82927 .627 L .84211 .63997 L p .707 .577 .707 r
F P
0 g
s
.46336 .76909 m .42247 .76387 L p .44362 .65691 L .707 .577 .707 r
F P
0 g
s
.45209 .57273 m .45523 .62561 L .46989 .61973 L p .707 .577 .707 r
F P
0 g
s
.47605 .61102 m .45209 .57273 L .46989 .61973 L .707 .577 .707 r
F
.48295 .60125 m .46336 .76909 L p .45403 .71606 L F P
0 g
s
.44362 .65691 m .47866 .60733 L .45403 .71606 L .707 .577 .707 r
F
.47866 .60733 m .48295 .60125 L .45403 .71606 L F
.47603 .56314 m .47866 .60733 L p .48456 .58125 L F P
0 g
s
.47603 .56314 m .45209 .57273 L p .47605 .61102 L .707 .577 .707 r
F P
0 g
s
.47917 .61601 m .47866 .60733 L p .47605 .61102 L .707 .577 .707 r
F P
0 g
s
.47866 .60733 m .47603 .56314 L p .47605 .61102 L .707 .577 .707 r
F P
0 g
s
.46336 .76909 m .48111 .61702 L p .50302 .57562 L .707 .577 .707 r
F P
0 g
s
.50792 .77441 m .46336 .76909 L p .50302 .57562 L .707 .577 .707 r
F P
0 g
s
.56832 .25709 m .53909 .50746 L p .50302 .57562 L .707 .577 .707 r
F P
0 g
s
.53909 .50746 m .50792 .77441 L p .50302 .57562 L .707 .577 .707 r
F P
0 g
s
.48299 .6817 m .47955 .64806 L .45922 .65838 L p .707 .577 .707 r
F P
0 g
s
.45922 .65838 m .45581 .66012 L p .45756 .66152 L .707 .577 .707 r
F P
0 g
s
.48299 .6817 m .45922 .65838 L .45756 .66152 L .707 .577 .707 r
F
.45925 .69377 m .48299 .6817 L p .45756 .66152 L F P
0 g
s
.45581 .66012 m .45621 .66407 L p .45756 .66152 L .707 .577 .707 r
F P
0 g
s
.45621 .66407 m .45925 .69377 L p .45756 .66152 L .707 .577 .707 r
F P
0 g
s
.50302 .57562 m .48606 .57465 L .56832 .25709 L .707 .577 .707 r
F
.48111 .61702 m .48606 .57465 L p .50302 .57562 L F P
0 g
s
.49055 .55264 m .47603 .56314 L p .48606 .57465 L .707 .577 .707 r
F P
0 g
s
.48606 .57465 m .52376 .25177 L .55132 .25506 L p .707 .577 .707 r
F P
0 g
s
.55132 .25506 m .56832 .25709 L p .48606 .57465 L .707 .577 .707 r
F P
0 g
s
.48456 .58125 m .48606 .57465 L .47603 .56314 L .707 .577 .707 r
F
.49114 .55222 m .49055 .55264 L p .48606 .57465 L F P
0 g
s
.49541 .60427 m .49227 .5514 L .49114 .55222 L p .707 .577 .707 r
F P
0 g
s
.48606 .57465 m .48295 .60125 L p .47866 .60733 L .707 .577 .707 r
F P
0 g
s
.49541 .60427 m .49114 .55222 L .48456 .58125 L .707 .577 .707 r
F
.52376 .25177 m .48606 .57465 L p .44362 .65691 L F P
0 g
s
.44362 .65691 m .48606 .57465 L .47866 .60733 L .707 .577 .707 r
F
.47917 .61601 m .49541 .60427 L p .48456 .58125 L F P
0 g
s
.47866 .60733 m .47917 .61601 L p .48456 .58125 L .707 .577 .707 r
F P
0 g
s
.46989 .61973 m .47917 .61601 L p .47605 .61102 L .707 .577 .707 r
F P
0 g
s
.84996 .72005 m .85173 .73681 L .8485 .72169 L p .707 .577 .707 r
F P
0 g
s
.8485 .72169 m .84673 .70492 L .84996 .72005 L p .707 .577 .707 r
F P
0 g
s
.64679 .73099 m .64856 .74776 L .65179 .76288 L p .707 .577 .707 r
F P
0 g
s
.64885 .65003 m .65229 .68368 L .64556 .69915 L p .707 .577 .707 r
F P
0 g
s
.6618 .55611 m .66494 .60899 L .64869 .62073 L p .707 .577 .707 r
F P
0 g
s
.65109 .26597 m .59069 .7833 L .5518 .77931 L p .707 .577 .707 r
F P
0 g
s
.33553 .62861 m .33239 .57573 L .31128 .56727 L p .707 .577 .707 r
F P
0 g
s
.33239 .57573 m .33553 .62861 L .36301 .6337 L p .707 .577 .707 r
F P
0 g
s
.66494 .60899 m .6618 .55611 L .68573 .54652 L p .707 .577 .707 r
F P
0 g
s
.65229 .68368 m .64885 .65003 L .66487 .63556 L p .707 .577 .707 r
F P
0 g
s
.42247 .76387 m .48287 .24654 L .52376 .25177 L p .707 .577 .707 r
F P
0 g
s
.80543 .54351 m .80857 .59639 L .7811 .59131 L p .707 .577 .707 r
F P
0 g
s
.7811 .59131 m .77796 .53843 L .80543 .54351 L p .707 .577 .707 r
F P
0 g
s
.64856 .74776 m .64679 .73099 L .65351 .71534 L p .707 .577 .707 r
F P
0 g
s
.5518 .77931 m .6122 .26198 L .65109 .26597 L p .707 .577 .707 r
F P
0 g
s
.39844 .70628 m .395 .67263 L .36388 .67186 L p .707 .577 .707 r
F P
0 g
s
.395 .67263 m .39844 .70628 L .43012 .70223 L p .707 .577 .707 r
F P
0 g
s
.43012 .70223 m .42667 .66859 L .395 .67263 L p .707 .577 .707 r
F P
0 g
s
.42667 .66859 m .43012 .70223 L .45925 .69377 L p .707 .577 .707 r
F P
0 g
s
.45925 .69377 m .45581 .66012 L .42667 .66859 L p .707 .577 .707 r
F P
0 g
s
.82927 .627 m .83271 .66064 L .8115 .65092 L p .707 .577 .707 r
F P
0 g
s
.8115 .65092 m .80805 .61728 L .82927 .627 L p .707 .577 .707 r
F P
0 g
s
.84673 .70492 m .8485 .72169 L .83565 .70858 L p .707 .577 .707 r
F P
0 g
s
.83565 .70858 m .83388 .69182 L .84673 .70492 L p .707 .577 .707 r
F P
0 g
s
.68887 .59939 m .68573 .54652 L .71503 .54001 L p .707 .577 .707 r
F P
0 g
s
.68573 .54652 m .68887 .59939 L .66494 .60899 L p .707 .577 .707 r
F P
0 g
s
.65351 .71534 m .65528 .7321 L .64856 .74776 L p .707 .577 .707 r
F P
0 g
s
.36733 .7055 m .36388 .67186 L .33636 .66634 L p .707 .577 .707 r
F P
0 g
s
.36388 .67186 m .36733 .7055 L .39844 .70628 L p .707 .577 .707 r
F P
0 g
s
.6122 .26198 m .5518 .77931 L .50792 .77441 L p .707 .577 .707 r
F P
0 g
s
.31442 .62015 m .31128 .56727 L .2986 .55626 L p .707 .577 .707 r
F P
0 g
s
.31128 .56727 m .31442 .62015 L .33553 .62861 L p .707 .577 .707 r
F P
0 g
s
.66487 .63556 m .66832 .6692 L .65229 .68368 L p .707 .577 .707 r
F P
0 g
s
.77796 .53843 m .7811 .59131 L .74994 .5901 L p .707 .577 .707 r
F P
0 g
s
.74994 .5901 m .7468 .53722 L .77796 .53843 L p .707 .577 .707 r
F P
0 g
s
.71817 .59288 m .71503 .54001 L .7468 .53722 L p .707 .577 .707 r
F P
0 g
s
.71503 .54001 m .71817 .59288 L .68887 .59939 L p .707 .577 .707 r
F P
0 g
s
.66832 .6692 m .66487 .63556 L .68861 .6235 L p .707 .577 .707 r
F P
0 g
s
.50792 .77441 m .56832 .25709 L .6122 .26198 L p .707 .577 .707 r
F P
0 g
s
.7468 .53722 m .74994 .5901 L .71817 .59288 L p .707 .577 .707 r
F P
0 g
s
.49227 .5514 m .49541 .60427 L .50237 .59154 L p .707 .577 .707 r
F P
0 g
s
.50237 .59154 m .49923 .53866 L .49227 .5514 L p .707 .577 .707 r
F P
0 g
s
.33981 .69999 m .33636 .66634 L .31515 .65662 L p .707 .577 .707 r
F P
0 g
s
.33636 .66634 m .33981 .69999 L .36733 .7055 L p .707 .577 .707 r
F P
0 g
s
.80805 .61728 m .8115 .65092 L .78399 .64541 L p .707 .577 .707 r
F P
0 g
s
.78399 .64541 m .78054 .61176 L .80805 .61728 L p .707 .577 .707 r
F P
0 g
s
.65528 .7321 m .65351 .71534 L .66951 .70068 L p .707 .577 .707 r
F P
0 g
s
.47955 .64806 m .48299 .6817 L .49902 .66723 L p .707 .577 .707 r
F P
0 g
s
.49902 .66723 m .49557 .63358 L .47955 .64806 L p .707 .577 .707 r
F P
0 g
s
.40149 .75526 m .39972 .7385 L .3686 .73776 L p .707 .577 .707 r
F P
0 g
s
.39972 .7385 m .40149 .75526 L .43315 .75113 L p .707 .577 .707 r
F P
0 g
s
.43315 .75113 m .43138 .73437 L .39972 .7385 L p .707 .577 .707 r
F P
0 g
s
.43138 .73437 m .43315 .75113 L .46228 .74254 L p .707 .577 .707 r
F P
0 g
s
.46228 .74254 m .46051 .72577 L .43138 .73437 L p .707 .577 .707 r
F P
0 g
s
.83388 .69182 m .83565 .70858 L .81443 .69878 L p .707 .577 .707 r
F P
0 g
s
.81443 .69878 m .81266 .68201 L .83388 .69182 L p .707 .577 .707 r
F P
0 g
s
.2986 .55626 m .30174 .60913 L .31442 .62015 L p .707 .577 .707 r
F P
0 g
s
.66951 .70068 m .67128 .71744 L .65528 .7321 L p .707 .577 .707 r
F P
0 g
s
.69206 .65714 m .68861 .6235 L .71774 .61503 L p .707 .577 .707 r
F P
0 g
s
.68861 .6235 m .69206 .65714 L .66832 .6692 L p .707 .577 .707 r
F P
0 g
s
.30174 .60913 m .2986 .55626 L .29559 .54377 L p .707 .577 .707 r
F P
0 g
s
.37037 .75452 m .3686 .73776 L .34109 .73221 L p .707 .577 .707 r
F P
0 g
s
.3686 .73776 m .37037 .75452 L .40149 .75526 L p .707 .577 .707 r
F P
0 g
s
.78054 .61176 m .78399 .64541 L .75287 .64463 L p .707 .577 .707 r
F P
0 g
s
.75287 .64463 m .74942 .61098 L .78054 .61176 L p .707 .577 .707 r
F P
0 g
s
.31515 .65662 m .3186 .69026 L .33981 .69999 L p .707 .577 .707 r
F P
0 g
s
.46051 .72577 m .46228 .74254 L .486 .73031 L p .707 .577 .707 r
F P
0 g
s
.486 .73031 m .48423 .71355 L .46051 .72577 L p .707 .577 .707 r
F P
0 g
s
.3186 .69026 m .31515 .65662 L .30231 .64365 L p .707 .577 .707 r
F P
0 g
s
.72119 .64867 m .71774 .61503 L .74942 .61098 L p .707 .577 .707 r
F P
0 g
s
.71774 .61503 m .72119 .64867 L .69206 .65714 L p .707 .577 .707 r
F P
0 g
s
.74942 .61098 m .75287 .64463 L .72119 .64867 L p .707 .577 .707 r
F P
0 g
s
.34109 .73221 m .34286 .74897 L .37037 .75452 L p .707 .577 .707 r
F P
0 g
s
.67128 .71744 m .66951 .70068 L .69324 .68845 L p .707 .577 .707 r
F P
0 g
s
.49923 .53866 m .50237 .59154 L .49936 .57905 L p .707 .577 .707 r
F P
0 g
s
.49936 .57905 m .49622 .52618 L .49923 .53866 L p .707 .577 .707 r
F P
0 g
s
.49557 .63358 m .49902 .66723 L .50575 .65176 L p .707 .577 .707 r
F P
0 g
s
.50575 .65176 m .5023 .61811 L .49557 .63358 L p .707 .577 .707 r
F P
0 g
s
.34286 .74897 m .34109 .73221 L .31986 .7224 L p .707 .577 .707 r
F P
0 g
s
.81266 .68201 m .81443 .69878 L .78691 .69323 L p .707 .577 .707 r
F P
0 g
s
.78691 .69323 m .78514 .67647 L .81266 .68201 L p .707 .577 .707 r
F P
0 g
s
.69324 .68845 m .69501 .70521 L .67128 .71744 L p .707 .577 .707 r
F P
0 g
s
.29559 .54377 m .29873 .59665 L .30174 .60913 L p .707 .577 .707 r
F P
0 g
s
.48423 .71355 m .486 .73031 L .502 .71565 L p .707 .577 .707 r
F P
0 g
s
.502 .71565 m .50023 .69889 L .48423 .71355 L p .707 .577 .707 r
F P
0 g
s
.31986 .7224 m .32163 .73916 L .34286 .74897 L p .707 .577 .707 r
F P
0 g
s
.30231 .64365 m .30576 .67729 L .3186 .69026 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.69501 .70521 m .69324 .68845 L .72236 .67985 L p .707 .577 .707 r
F P
0 g
s
.29873 .59665 m .29559 .54377 L .30254 .53103 L p .707 .577 .707 r
F P
0 g
s
.78514 .67647 m .78691 .69323 L .75579 .69248 L p .707 .577 .707 r
F P
0 g
s
.75579 .69248 m .75402 .67572 L .78514 .67647 L p .707 .577 .707 r
F P
0 g
s
.30576 .67729 m .30231 .64365 L .2991 .62869 L p .707 .577 .707 r
F P
0 g
s
.72236 .67985 m .72413 .69661 L .69501 .70521 L p .707 .577 .707 r
F P
0 g
s
.32163 .73916 m .31986 .7224 L .30701 .7093 L p .707 .577 .707 r
F P
0 g
s
.72413 .69661 m .72236 .67985 L .75402 .67572 L p .707 .577 .707 r
F P
0 g
s
.75402 .67572 m .75579 .69248 L .72413 .69661 L p .707 .577 .707 r
F P
0 g
s
.49622 .52618 m .49936 .57905 L .48668 .56804 L p .707 .577 .707 r
F P
0 g
s
.48668 .56804 m .48354 .51516 L .49622 .52618 L p .707 .577 .707 r
F P
0 g
s
.5023 .61811 m .50575 .65176 L .50254 .6368 L p .707 .577 .707 r
F P
0 g
s
.50254 .6368 m .4991 .60316 L .5023 .61811 L p .707 .577 .707 r
F P
0 g
s
.50023 .69889 m .502 .71565 L .50872 .69999 L p .707 .577 .707 r
F P
0 g
s
.50872 .69999 m .50695 .68323 L .50023 .69889 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30701 .7093 m .30878 .72606 L .32163 .73916 L p .707 .577 .707 r
F P
0 g
s
.30254 .53103 m .30568 .58391 L .29873 .59665 L p .707 .577 .707 r
F P
0 g
s
.2991 .62869 m .30255 .66234 L .30576 .67729 L p .707 .577 .707 r
F P
0 g
s
.30568 .58391 m .30254 .53103 L .31878 .51929 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30255 .66234 m .2991 .62869 L .30584 .61322 L p .707 .577 .707 r
F P
0 g
s
.30878 .72606 m .30701 .7093 L .30378 .69418 L p .707 .577 .707 r
F P
0 g
s
.48354 .51516 m .48668 .56804 L .46556 .55957 L p .707 .577 .707 r
F P
0 g
s
.46556 .55957 m .46242 .5067 L .48354 .51516 L p .707 .577 .707 r
F P
0 g
s
.4991 .60316 m .50254 .6368 L .4897 .62383 L p .707 .577 .707 r
F P
0 g
s
.4897 .62383 m .48626 .59018 L .4991 .60316 L p .707 .577 .707 r
F P
0 g
s
.50695 .68323 m .50872 .69999 L .50549 .68487 L p .707 .577 .707 r
F P
0 g
s
.50549 .68487 m .50372 .66811 L .50695 .68323 L p .707 .577 .707 r
F P
0 g
s
.30378 .69418 m .30555 .71094 L .30878 .72606 L p .707 .577 .707 r
F P
0 g
s
.30584 .61322 m .30928 .64686 L .30255 .66234 L p .707 .577 .707 r
F P
0 g
s
.31878 .51929 m .32192 .57217 L .30568 .58391 L p .707 .577 .707 r
F P
0 g
s
.32192 .57217 m .31878 .51929 L .34272 .5097 L p .707 .577 .707 r
F P
0 g
s
.30928 .64686 m .30584 .61322 L .32186 .59874 L p .707 .577 .707 r
F P
0 g
s
.46242 .5067 m .46556 .55957 L .43809 .55449 L p .707 .577 .707 r
F P
0 g
s
.43809 .55449 m .43495 .50161 L .46242 .5067 L p .707 .577 .707 r
F P
0 g
s
.30555 .71094 m .30378 .69418 L .3105 .67852 L p .707 .577 .707 r
F P
0 g
s
.48626 .59018 m .4897 .62383 L .46849 .61411 L p .707 .577 .707 r
F P
0 g
s
.46849 .61411 m .46504 .58046 L .48626 .59018 L p .707 .577 .707 r
F P
0 g
s
.50372 .66811 m .50549 .68487 L .49264 .67177 L p .707 .577 .707 r
F P
0 g
s
.49264 .67177 m .49087 .65501 L .50372 .66811 L p .707 .577 .707 r
F P
0 g
s
.34586 .56258 m .34272 .5097 L .37202 .50319 L p .707 .577 .707 r
F P
0 g
s
.34272 .5097 m .34586 .56258 L .32192 .57217 L p .707 .577 .707 r
F P
0 g
s
.3105 .67852 m .31227 .69528 L .30555 .71094 L p .707 .577 .707 r
F P
0 g
s
.32186 .59874 m .32531 .63239 L .30928 .64686 L p .707 .577 .707 r
F P
0 g
s
.43495 .50161 m .43809 .55449 L .40693 .55328 L p .707 .577 .707 r
F P
0 g
s
.40693 .55328 m .40379 .50041 L .43495 .50161 L p .707 .577 .707 r
F P
0 g
s
.37516 .55607 m .37202 .50319 L .40379 .50041 L p .707 .577 .707 r
F P
0 g
s
.37202 .50319 m .37516 .55607 L .34586 .56258 L p .707 .577 .707 r
F P
0 g
s
.32531 .63239 m .32186 .59874 L .3456 .58668 L p .707 .577 .707 r
F P
0 g
s
.40379 .50041 m .40693 .55328 L .37516 .55607 L p .707 .577 .707 r
F P
0 g
s
.46504 .58046 m .46849 .61411 L .44097 .60859 L p .707 .577 .707 r
F P
0 g
s
.44097 .60859 m .43753 .57494 L .46504 .58046 L p .707 .577 .707 r
F P
0 g
s
.31227 .69528 m .3105 .67852 L .3265 .66386 L p .707 .577 .707 r
F P
0 g
s
.49087 .65501 m .49264 .67177 L .47141 .66196 L p .707 .577 .707 r
F P
0 g
s
.47141 .66196 m .46964 .6452 L .49087 .65501 L p .707 .577 .707 r
F P
0 g
s
.3265 .66386 m .32827 .68062 L .31227 .69528 L p .707 .577 .707 r
F P
0 g
s
.34905 .62033 m .3456 .58668 L .37473 .57821 L p .707 .577 .707 r
F P
0 g
s
.3456 .58668 m .34905 .62033 L .32531 .63239 L p .707 .577 .707 r
F P
0 g
s
.43753 .57494 m .44097 .60859 L .40986 .60781 L p .707 .577 .707 r
F P
0 g
s
.40986 .60781 m .40641 .57417 L .43753 .57494 L p .707 .577 .707 r
F P
0 g
s
.37818 .61186 m .37473 .57821 L .40641 .57417 L p .707 .577 .707 r
F P
0 g
s
.37473 .57821 m .37818 .61186 L .34905 .62033 L p .707 .577 .707 r
F P
0 g
s
.40641 .57417 m .40986 .60781 L .37818 .61186 L p .707 .577 .707 r
F P
0 g
s
.32827 .68062 m .3265 .66386 L .35023 .65163 L p .707 .577 .707 r
F P
0 g
s
.46964 .6452 m .47141 .66196 L .4439 .65641 L p .707 .577 .707 r
F P
0 g
s
.4439 .65641 m .44213 .63965 L .46964 .6452 L p .707 .577 .707 r
F P
0 g
s
.35023 .65163 m .352 .6684 L .32827 .68062 L p .707 .577 .707 r
F P
0 g
s
.352 .6684 m .35023 .65163 L .37935 .64304 L p .707 .577 .707 r
F P
0 g
s
.44213 .63965 m .4439 .65641 L .41278 .65567 L p .707 .577 .707 r
F P
0 g
s
.41278 .65567 m .41101 .63891 L .44213 .63965 L p .707 .577 .707 r
F P
0 g
s
.37935 .64304 m .38112 .6598 L .352 .6684 L p .707 .577 .707 r
F P
0 g
s
.38112 .6598 m .37935 .64304 L .41101 .63891 L p .707 .577 .707 r
F P
0 g
s
.41101 .63891 m .41278 .65567 L .38112 .6598 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001fOol<002KOol007Ioo`04
001JEUYF0002FUH@002AOol007Ioo`04001JEUYF0005FUH00`00FUIJEP050005FUH;0026Ool007Io
o`04001JEUYF0005FUH00`00FUIJEP05FUH80002FUH00`00FUIJEP03FUH:001lOol007Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP03FUH90009FUH6001fOol007Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH01000FUIJEUYF1`0025YF2@00KGoo001eOol01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH025YF2@0025YF2000IGoo001eOol0
1000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH015YF
300015YF1@00H7oo001eOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH00eYF3P00Fgoo001eOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH05UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP`005Aoo`00
MGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005Aoo`00MGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005Aoo`00MGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005Aoo`00M7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF015JEP03
001JEUYF009JEP03001JEP0005Aoo`00M7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00eJEUEoo`00M7oo
00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEUEoo`00M7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF05Eoo`00M7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0005Eoo`00M7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0005Eoo`00M7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0005Eoo`00M7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0005Eoo`00M7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
05Eoo`00Lgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00EJEUIoo`00Lgoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF05Ioo`00Lgoo00@005YFFUH000EJ
EP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF05Ioo`00Lgoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0005Ioo`00Lgoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0005Ioo`00Lgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0005Ioo`00Lgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0005Ioo`00Lgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005Ioo`00Lgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0EWoo
001bOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0Egoo001bOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0Egoo001bOol01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Egoo001bOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Egoo001bOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000Egoo001bOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000Egoo001bOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000Egoo001bOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`1GOol0075oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIo
o`1GOol0075oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1HOol0
075oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001HOol0075oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001HOol0075oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001HOol0075oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001HOol0075oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001HOol0075oo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIoo`1HOol0075oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEWoo05Qoo`00L7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF05Uoo`00L7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
05Uoo`00L7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005Uoo`00
L7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0000<FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001IOol0071o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001IOol0071oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001IOol0071oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1IOol0071oo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEWoo05Uoo`00L7oo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFOol0FGoo001_Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000FWoo001_Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000FWoo001_Ool01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000FWoo
001_Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000FWoo001_Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000FWoo001_Ool01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000FWoo001_Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0FWoo001_Ool00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001KOol006ioo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001KOol0
06ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001KOol006ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1KOol006ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8005aoo`00KWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00G7oo001]Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
G7oo001]Ool@0004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001LOol006Ioo`P000AJEP03001JEUYF00IJ
EP03001JEP0000@000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0005aoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF10001eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000G7oo001NOol200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001LOol005ao
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP80009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEWoo05aoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00GGoo001IOol20006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
GGoo001HOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00eYF0P00GGoo001GOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP00
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
05eoo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001MOol005Eoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000@Ool90014Ool005Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0009Ool70004FUH00`00FUIJEP02FUH8000lOol005Aoo`03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIoo`05Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo001D
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0`001UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P00=7oo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P0000Aoo`00000000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP80039oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80035oo`00E7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF1P001UYF00<005YFFUH01UYF10000UYF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEP00031oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010000Woo00<005YF
FUH010000eYF00<005YFFUH01eYF00<005YFFUH0100015YF00@005YFFUH000UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool005Aoo`03
001JEP0000AJEP03001JEUYF00=JEP@000Ioo`03001JEUYF00D0009JEP03001JEUYF00MJEP03001J
EUYF00AJEP<00005FUH005YFFUH00009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH00`00FUH0
0003000:Ool00`00FUIJEP050002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH20002FUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH0
1@00FUIJEUYF0000;Woo001DOol00`00FUH00004FUH2000>Ool00`00FUIJEP050002FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH200000eYF00000008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo001DOol00`00FUH0
0003FUH00`00FUIJEP03000;Ool00`00FUIJEP0A000;FUH50008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo001D
Ool01000FUH005YF0P0015YF00<005YF00000`001Goo1P0015YF00<005YFFUH01UYF00<005YF0000
0`002UYF0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF00@005YFFUIJEP8002eoo`00E7oo00<005YF00000P001EYF00<005YFFUH00eYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF10001UYF0`001eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo0017Ool>
000015YF001JEP001EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP00008000=JEP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00@Goo1P0015YF00<005YFFUH01UYF
0P000UYF00<005YFFUH00eYF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP8000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00?Goo100000=JEP00FUH01eYF
00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF0P001EYF00<005YFFUH00eYF00<005YFFUH015YF1`00
2Goo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00>Goo10001EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P000eYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF100025YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH010001goo0`003Woo
10001EYF00D005YFFUIJEP0002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000eYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF009JEP03001JEUYF00=JEP<000Yoo`D0015oo`8000=JEP05001J
EUYFFUH0000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80
00=JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP02FUH01000FUIJEUYF0P003Goo1@0047oo0P0000EJEP00001JEP0000=JEP8002aoo`00
<Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0P0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF1`0015YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF009J
EP04001JEP00000?Ool5000>Ool20003FUH01000FUH000000eYF0P00;7oo000aOol00`00FUH00006
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP040007FUH80004FUH00`00FUIJEP03FUH00`00FUH00007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P004Woo3P00
00Aoo`00000000EJEP05001JEUYFFUH00002FUH2000/Ool0031oo`04001JEUYF0006FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP0:FUH01000FUIJEUYF1@001EYF00@005YF000000IJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH200000eYF000000030008Ool60004FUH0
0`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP02FUH4000/Ool002moo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP04FUH0
0`00FUIJEP040006FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH20003FUH01000FUH000001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH010000eYF00@005YFFUIJEPP0
0003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=JEP<002ao
o`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
0P001EYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YFFUH02UYF00<005YFFUH01EYF0P00
00IJEP00001JEP00FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEP00FUH00P000eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001EYF0`00;7oo000^Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFFUH025YF00@005YF0000009JEP03001JEUYF00AJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP03001JEUYF00<0
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001J
EP0002aoo`00;Goo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0P001EYF00<005YF00000P001UYF00<005YFFUH01EYF0`002UYF0P002UYF00L0
05YFFUIJEP00FUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30002FUH0
0`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP8000=JEP@0009J
EP03001JEUYF00AJEPD000EJEP80009JEP03001JEUYF00UJEP07001JEUYFFUH005YF00001UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF00@005YFFUIJEP8000=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003
FUH0000002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000eYF00<005YF00001EYF00<005YF00004P0015YF00<005YF
FUH025YF00<005YFFUH00UYF0`001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
0P000eYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP00008002eoo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF3P0000=JEP00FUH00P000UYF00<005YFFUH00eYF00@0
05YFFUH0009oo`05001JEUYF001JEP0A0008FUH01000FUIJEUYF0P0000=JEP0000001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000eYF0`001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH002ioo`00;Goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF1P003Goo00<005YF00000`000UYF00<0
05YFFUH00eYF00@005YFFUH0009oo`L000AJEP03001JEUYF00IJEP03001JEP0000<000AJEP07001J
EUYF001JEP00FUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002eoo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH010004goo00<005YF00000goo100015YF00D005YFFUH007oo00800003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<00004FUH005YF0002FUH01000FUH0000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000MJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03
001JEP0000AJEP03001JEUYF00=JEP@000Yoo`h00003FUH007oo00Ioo`<00003FUH005YF00<000=J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP04001JEUYF0004FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000eYF00<005YFFUH01EYF
00<005YFFUH015YF1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00@005YFFUH002eo
o`00;Goo00<005YF000015YF00<005YF00000`0027oo1P0015YF00<005YFFUH01UYF00<005YF0000
0`000Woo0P0000=JEP00FUH00`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YF000015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000<000AJEP03001JEUYF008002aoo`00;Goo00<005YF000015YF0P00
2Woo0P0000=JEP00FUH01eYF00<005YFFUH01UYF0P000UYF00<005YF00000P000UYF0P0000=JEP00
FUH01eYF00<005YFFUH00UYF3`001UYF00@005YFFUIJEP800003FUH0000000EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00AJEP<00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000015YF001JEUYF0P00;7oo
000]Ool00`00FUH00003FUH00`00FUIJEP030004Ool30003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20002FUH3000015YF000000000eYF00<005YFFUH01EYF1`002EYF00<005YFFUH00UYF10000UYF
00<005YFFUH00UYF10001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000Eoo`8000=JEP03001oogoo02Yoo`00;Goo00@005YF001JEP8000AJEP03001J
EP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF008000IJEP03001J
EUYF009JEP<000EJEP03001JEUYF00MJEP03001JEUYF00800004FUH005YFFUH30004FUH01000FUH0
00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03
001JEUYF008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000Uoo`04001J
EUYF000/Ool002eoo`03001JEP00008000EJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP80009JEP04001JEP000007FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH30003FUH00`00FUIJEP03FUH20003FUH01000FUIJEP0015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEPL000AJEP03001JEUYF00IJEP<000IJEP03
001JEUYF00@000eoo`03001JEP0002aoo`00;Goo00D005YF001JEP0000AJEP8000=JEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00EJEPH0009JEP03
001JEUYF00=JEP04001JEUYFFUH60006FUH00`00FUIJEP05FUH200001EYF001JEUYF00000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00000UYF00@005YFFUIJEP8000EJ
EPT000=JEPD00003FUH0000000D0015oo`<002aoo`00;Goo0P000UYF00<005YFFUH00P001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYFFUH20002
FUH@0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH000000UYF00D005YFFUIJEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH01P00FUIJEP00FUH000EJEP03001J
EUYF008000Aoo`T001Moo`800003FUH0000002]oo`00;Goo0P000UYF00@005YF000000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP04001JEP000006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20002FUH01000FUH00000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEP00
009JEP03001JEUYF00=JEP05001JEUYFFUH00007OolC0008Ool200000eYF001JEP02000[Ool002eo
o`80009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
00AJEP<000MJEP03001JEUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP<0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYF0002FUH6
0005FUH01@00FUIJEUYF00000goo1P0015YF00<005YFFUH01UYF00@005YFFUIJEPD0009oo`06001J
EUYFFUH005YF0P00:goo000]Ool200000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH@0003FUH01000FUIJEP001eYF00<005YFFUH015YF1@001UYF00<005YFFUH01UYF
00<005YFFUH00UYF0P001UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUH20004Ool20003FUH01000FUIJEUYF100000=JEP00FUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YF000000AJEP04001JEUYF000[Ool002eoo`<000AJEP03001JEUYF
00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00=JEP800003FUH0000000AJEP03001JEUYF00AJ
EP03001JEUYF00AJEPD000MJEP03001JEUYF00EJEP03001JEUYF008000QJEP80009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH40004Ool400000eYF000000020005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00@005YF
FUH002]oo`00;Woo0P0015YF00<005YFFUH01EYF00<005YFFUH010001EYF00<005YFFUH01eYF00H0
05YFFUIJEP00FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP05FUH3
00000eYF001JEP07FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0000=JEP0000000`000UYF00<005YF00000P001eYF00<005YFFUH015YF1`0015YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUH002]oo`00;Woo0P001EYF00<005YFFUH015YF
0`0000=JEP00FUH01eYF00<005YFFUH01UYF00P005YFFUIJEP00FUH005YF0`000eYF00<005YFFUH0
1EYF00<005YFFUH015YF0`0025YF00<005YFFUH015YF0P000UYF00<005YFFUH01UYF00<005YF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP800003
FUH0000000<0009JEP03001JEUYF00EJEP03001JEUYF00@000Moo`P000AJEP03001JEUYF00=JEP@0
02aoo`00;Woo0P001EYF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF3P0000AJEP000000009J
EP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001J
EUYFFUH00003FUH00`00FUH000030004FUH00`00FUIJEP04FUH4000AOol70005FUH4000/Ool002io
o`8000EJEP03001JEUYF008000IJEP03001JEUYF00H000AJEP03001JEUYF00IJEP80009JEPX000AJ
EP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00EJEP800004FUH005YF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000UYF00@005YFFUH000IJEP03001JEUYF
00@0015oo`@0009JEP03001JEUYF009JEP8000=JEP03001JEP0002eoo`00;Woo0P001EYF10001UYF
100000=JEP00FUH01eYF00<005YFFUH01UYF0P001UYF0`000goo4P0015YF00<005YFFUH025YF00<0
05YFFUH00eYF0P0000=JEP0000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP80009JEP04001JEP000006FUH5000<Ool70006FUH00`00FUIJEP04FUH200001EYF
001JEUYF0000;7oo000^Ool00`00FUH00004FUH200000eYF001JEP02FUH30005FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH20006FUH00`00FUIJEP020002Ool300000eYF001JEP05FUH00`00FUIJEP06
FUH2000:FUH00`00FUIJEP02FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH00eYF0P000UYF3`0015YF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001oogoo02Yoo`00;Woo00<005YF
00000eYF00<007ooOol01P0025YF00<005YFFUH015YF1`000eYF0`001UYF00@005YFFUIJEP@0009J
EP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP05001JEUYFFUH00004FUH01@00FUIJEUYF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YF
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF00000P0000=JEP00Ool0:goo000^Ool01000FUH005YF0P0017oo0P000UYF00<005YFFUH01UYF
00<005YFFUH010000UYF3@0015YF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF0P002UYF00<005YF00000P0015YF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000AJEP@000IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00=JEP8000=oo`03001JEP0002]oo`00;Woo00@005YF000000Aoo`8000EJEP03001JEUYF
00AJEPX000Qoo`800003FUH007oo00D000AJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP8000YJEP80009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH01000FUIJEP001UYF00<005YFFUH01EYF1@001EYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<007ooOol00goo0P00:goo000^Ool00`00FUH00004Ool00`00
FUIJEP05FUH00`00FUIJEP040004Ool3000<Ool01000FUIJEP001Goo0P000eYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH01eYF0P001EYF00<005YF00001EYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF1@001EYF00<005YFFUH01eYF00@005YFFUIJEP8000Moo`03001oogoo
02Uoo`00;Woo00@005YF0000009oo`8000MJEP<000Moo`D000]oo`03001JEUYF00<00004Ool00000
FUH300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20007FUH2
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00FUIJ
EP00FUH000EJEP03001JEUYF00=JEP03001JEUYF00EJEPD000IJEP03001JEUYF00IJEP04001JEP00
0008Ool2000[Ool002ioo`80009JEP800003FUH005YF00AJEP8000Yoo`D000aoo`03001JEP00009J
EP80009JEP03001JEUYF00<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH40000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP0200000eYF00000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH3
0007FUH00`00FUIJEP05FUH3000:Ool3000ZOol002ioo`80009JEP05001JEUYFFUH00002FUH2000<
Ool5000=Ool00`00FUH00003FUH50002FUH01000FUIJEP001EYF00<005YFFUH01UYF1@001EYF00<0
05YFFUH00eYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFFUH00P000eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0037oo00@005YFFUH002Yoo`00;goo00<005YF000015YF0`003goo0`0037oo0P00
00=JEP00000015YF00@005YFFUIJEPT0009JEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03
001JEUYF008000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000@000=JEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000mo
o`04001JEUYF000ZOol002moo`<000AJEP@001Yoo`<000=JEP<000=JEP03001JEUYF00EJEP03001J
EUYF009JEPL000IJEP03001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP@000AJEP<000=oo`@00003FUH005YF00MJEP03001JEUYF009JEPH0
015oo`800003FUH007oo02Yoo`00;goo0`000eYF00D005YFFUH005YF00@0011oo`H000IJEP03001J
EUYF00<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP04001J
EP000004Ool@000FOol01@00FUH005YF0000:goo000_Ool01000FUH005YF0P000eYF00<005YFFUH0
0eYF400015YF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00001UYF00@005YFFUIJEP800005Ool00000FUH0000ROol0
1@00FUIJEUYF0000;7oo000_Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH7000CFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH000001UYF00<005YFFUH00UYF0`0000=JEP0000007goo0P0015YF00<007ooOol0:Woo000_
Ool01@00FUH005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF0P0000=oo`000000400000=JEP00FUH02EYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP@0009J
EP03001JEUYF00=JEP800003FUH0000001eoo`800003FUH005YF009JEP03001oogoo02]oo`00;goo
0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P0017oo00@005YF001oo`H000MJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002
FUH00`00Ool000030004FUH01@00FUH005YF00006goo0P000eYF00@005YFFUH002ioo`00;goo0P00
00=oo`0000001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUIJEP8000Eoo`<000Qoo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH300000goo
00000003000015YF001JEUYF0P0067oo0`001EYF00<005YF0000;goo000_Ool20002Ool00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00001Goo0P0000=JEP0000003Goo20001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF001oo`00FUH00002FUH2000015YF001JEUYF
0P000UYF0P005Woo0P0000=JEP00FUH01EYF0P00<7oo000_Ool20003Ool20003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30006Ool01@00FUIJEUYF00005Woo
2@002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00L005YF
001oo`00FUH00004FUH30003FUH00`00FUH0000DOol30003FUH00`00FUIJEP03FUH2000aOol002mo
o`<000Aoo`800003FUH005YF00IJEP03001JEUYF00AJEP<000QJEP03001JEUYF00@000Moo`8000AJ
EP03001oogoo01eoo`H000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<0009oo`<000EJEP03001JEP0000@00003FUH007oo00aoo`H000IJEP04001JEUYFFUH2
000cOol002moo`800003FUH007oo00Aoo`D000AJEP03001JEUYF00=JEPD000EJEPD000Uoo`800003
FUH005YF009JEP03001oogoo02Aoo`T000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJ
EP04001JEP00000eOol0031oo`04001JEUYF0009Ool900000eYF0000000300000eYF00000002000<
Ool20003FUH01000FUIJEP00:Woo0`000eYF30001EYF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF0`00=goo000`Ool00`00FUIJEP03000@Ool7000=Ool30006FUH00`00FUH0000ZOol2000015YF
001JEP0015YF00@005YFFUIJEPh000AJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF0080
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8003Yoo`00<Goo
00<005YF00000UYF0P0047oo0`003Goo0P0000=JEP00FUH01UYF0P00:goo00<005YFFUH00`0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YF00002`0015YF00<005YFFUH00UYF0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00?7oo000bOol00`00FUH00003FUH3000JOol3
0003FUH00`00FUIJEP04FUH2000/Ool01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPD0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH003moo`00<goo0P0015YF00<005YF00000`0047oo1P001eYF00@005YFFUIJEP80
02ioo`06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<007ooOol00Woo4000AGoo000dOol00`00FUIJEP02FUH00`00
FUIJEP03FUH@0004FUH00`00FUIJEP06FUH01000FUH00000<7oo00<005YF00000`001EYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8000Aoo`80
009JEP03001oogoo04moo`00=Goo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`00<goo0P000Woo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF000000Eoo`05001JEP00FUH0001BOol003Mo
o`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8003Ioo`03
001oogoo009oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<000Ioo`04001JEUYFFUH2001BOol003Uoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP00008003Qoo`8000Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000Qoo`03001JEUYF009JEP03001oogoo055oo`00?7oo10000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1P00>goo00<005YF00001Woo0`001EYF00<005YFFUH01EYF0`001eYF
00<005YF00000P002Goo0`0015YF00<007ooOol0DGoo0010Ool@0011Ool200000eYF001oo`07Ool4
00000eYF001JEP05FUH50002FUH6000:Ool20002FUH01@00FUIJEUYF0000E7oo002BOol01000FUIJ
EP002goo3`003Woo0P0015YF00@005YF000005Eoo`00TWoo00<005YFFUH00`004Goo1@003Woo0P00
1UYF0P00Egoo002COol00`00FUH00002FUH2000@Ool3000;Ool400000eYF001JEP05FUH00`00Oomo
o`1FOol009=oo`03001JEP0000AJEPD0019oo`L000EJEP03001JEUYF009JEP8005Uoo`00U7oo0P00
1EYF00@005YFFUIJEQ8000AJEP03001JEUYF00EJEP03001JEUYF008005]oo`00UGoo0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00GGoo002GOol30000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2001OOol009Yoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0065oo`00WGoo10000UYF00<005YF
FUH01UYF00<005YFFUH00UYF1`00IGoo002QOol@001/Ool00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49208 .84945 m .43168 .41316 L .3878 .41251 L p .707 .577 .707 r
F P
0 g
s
.5561 .84806 m .55787 .82892 L .53035 .82576 L p .707 .577 .707 r
F P
0 g
s
.53035 .82576 m .52858 .8449 L .5561 .84806 L p .707 .577 .707 r
F P
0 g
s
.53151 .79312 m .53496 .75485 L .51374 .75187 L p .707 .577 .707 r
F P
0 g
s
.51374 .75187 m .51029 .79015 L .53151 .79312 L p .707 .577 .707 r
F P
0 g
s
.52858 .8449 m .53035 .82576 L .50913 .82289 L p .707 .577 .707 r
F P
0 g
s
.50913 .82289 m .50736 .84202 L .52858 .8449 L p .707 .577 .707 r
F P
0 g
s
.50378 .66858 m .50064 .72567 L .51332 .7303 L p .707 .577 .707 r
F P
0 g
s
.51029 .79015 m .51374 .75187 L .5009 .74941 L p .707 .577 .707 r
F P
0 g
s
.5009 .74941 m .49745 .78768 L .51029 .79015 L p .707 .577 .707 r
F P
0 g
s
.50736 .84202 m .50913 .82289 L .49627 .82057 L p .707 .577 .707 r
F P
0 g
s
.49627 .82057 m .4945 .83971 L .50736 .84202 L p .707 .577 .707 r
F P
0 g
s
.50064 .72567 m .50378 .66858 L .50077 .66413 L p .707 .577 .707 r
F P
0 g
s
.50077 .66413 m .49763 .72122 L .50064 .72567 L p .707 .577 .707 r
F P
0 g
s
.49745 .78768 m .5009 .74941 L .49769 .7477 L p .707 .577 .707 r
F P
0 g
s
.49769 .7477 m .49425 .78597 L .49745 .78768 L p .707 .577 .707 r
F P
0 g
s
.4945 .83971 m .49627 .82057 L .49305 .81905 L p .707 .577 .707 r
F P
0 g
s
.49305 .81905 m .49128 .83819 L .4945 .83971 L p .707 .577 .707 r
F P
0 g
s
.51332 .7303 m .51646 .67321 L .50378 .66858 L p .707 .577 .707 r
F P
0 g
s
.49763 .72122 m .50077 .66413 L .50772 .66031 L p .707 .577 .707 r
F P
0 g
s
.50772 .66031 m .50458 .7174 L .49763 .72122 L p .707 .577 .707 r
F P
0 g
s
.49425 .78597 m .49769 .7477 L .50443 .74691 L p .707 .577 .707 r
F P
0 g
s
.50443 .74691 m .50098 .78518 L .49425 .78597 L p .707 .577 .707 r
F P
0 g
s
.49128 .83819 m .49305 .81905 L .49977 .81847 L p .707 .577 .707 r
F P
0 g
s
.49977 .81847 m .498 .83761 L .49128 .83819 L p .707 .577 .707 r
F P
0 g
s
.50458 .7174 m .50772 .66031 L .50945 .66001 L p .707 .577 .707 r
F P
0 g
s
.51394 .67846 m .47624 .40616 L .44868 .41049 L p .707 .577 .707 r
F P
0 g
s
.56191 .73834 m .56505 .68125 L .53757 .67758 L p .707 .577 .707 r
F P
0 g
s
.53757 .67758 m .53443 .73466 L .56191 .73834 L p .707 .577 .707 r
F P
0 g
s
.56247 .75804 m .55902 .79631 L .59014 .79941 L p .707 .577 .707 r
F P
0 g
s
.55902 .79631 m .56247 .75804 L .53496 .75485 L p .707 .577 .707 r
F P
0 g
s
.53443 .73466 m .53757 .67758 L .51646 .67321 L p .707 .577 .707 r
F P
0 g
s
.51646 .67321 m .51332 .7303 L .53443 .73466 L p .707 .577 .707 r
F P
0 g
s
.47624 .40616 m .51394 .67846 L p .52817 .71203 L .707 .577 .707 r
F P
0 g
s
.55637 .74027 m .47624 .40616 L .52817 .71203 L .707 .577 .707 r
F
.52083 .71457 m .52134 .70519 L p .52395 .70781 L F P
0 g
s
.58721 .85119 m .58898 .83206 L .55787 .82892 L p .707 .577 .707 r
F P
0 g
s
.53496 .75485 m .53151 .79312 L .55902 .79631 L p .707 .577 .707 r
F P
0 g
s
.55787 .82892 m .5561 .84806 L .58721 .85119 L p .707 .577 .707 r
F P
0 g
s
.53011 .71397 m .52083 .71457 L p .52395 .70781 L .707 .577 .707 r
F P
0 g
s
.517 .78539 m .52045 .74712 L .54078 .74813 L p .707 .577 .707 r
F P
0 g
s
.54078 .74813 m .54419 .7483 L p .54243 .7507 L .707 .577 .707 r
F P
0 g
s
.517 .78539 m .54078 .74813 L .54243 .7507 L .707 .577 .707 r
F
.50458 .7174 m .50945 .66001 L .51533 .68417 L F
.49698 .68023 m .51394 .67846 L .43168 .41316 L F
.52817 .71203 m .51394 .67846 L .52134 .70519 L F
.52397 .65748 m .52083 .71457 L .50458 .7174 L p F P
0 g
s
.50098 .78518 m .50443 .74691 L .52045 .74712 L p .707 .577 .707 r
F P
0 g
s
.52045 .74712 m .517 .78539 L .50098 .78518 L p .707 .577 .707 r
F P
0 g
s
.54074 .78657 m .517 .78539 L p .54243 .7507 L .707 .577 .707 r
F P
0 g
s
.54419 .7483 m .54379 .75279 L p .54243 .7507 L .707 .577 .707 r
F P
0 g
s
.54379 .75279 m .54074 .78657 L p .54243 .7507 L .707 .577 .707 r
F P
0 g
s
.498 .83761 m .49977 .81847 L .51577 .81889 L p .707 .577 .707 r
F P
0 g
s
.51577 .81889 m .514 .83802 L .498 .83761 L p .707 .577 .707 r
F P
0 g
s
.514 .83802 m .51577 .81889 L .53949 .82026 L p .707 .577 .707 r
F P
0 g
s
.53949 .82026 m .53772 .83939 L .514 .83802 L p .707 .577 .707 r
F P
0 g
s
.49208 .84945 m .53664 .84245 L p .49698 .68023 L .707 .577 .707 r
F P
0 g
s
.43168 .41316 m .46091 .62431 L p .49698 .68023 L .707 .577 .707 r
F P
0 g
s
.46091 .62431 m .49208 .84945 L p .49698 .68023 L .707 .577 .707 r
F P
0 g
s
.53664 .84245 m .51889 .71419 L p .49698 .68023 L .707 .577 .707 r
F P
0 g
s
.51889 .71419 m .51394 .67846 L p .49698 .68023 L .707 .577 .707 r
F P
0 g
s
.59014 .79941 m .59359 .76114 L .56247 .75804 L p .707 .577 .707 r
F P
0 g
s
.54074 .78657 m .54284 .76331 L p .57333 .75034 L .707 .577 .707 r
F P
0 g
s
.54284 .76331 m .54419 .7483 L .55346 .74895 L p .707 .577 .707 r
F P
0 g
s
.55346 .74895 m .57333 .75034 L p .54284 .76331 L .707 .577 .707 r
F P
0 g
s
.59306 .74096 m .5962 .68387 L .56505 .68125 L p .707 .577 .707 r
F P
0 g
s
.5962 .68387 m .59306 .74096 L .62484 .74227 L p .707 .577 .707 r
F P
0 g
s
.56505 .68125 m .56191 .73834 L .59306 .74096 L p .707 .577 .707 r
F P
0 g
s
.59359 .76114 m .59014 .79941 L .62182 .80212 L p .707 .577 .707 r
F P
0 g
s
.62182 .80212 m .62526 .76384 L .59359 .76114 L p .707 .577 .707 r
F P
0 g
s
.62484 .74227 m .62798 .68518 L .5962 .68387 L p .707 .577 .707 r
F P
0 g
s
.60897 .65711 m .60583 .7142 L .5838 .71329 L p .707 .577 .707 r
F P
0 g
s
.5838 .71329 m .57406 .71289 L p .58672 .69266 L .707 .577 .707 r
F P
0 g
s
.58672 .69266 m .60897 .65711 L .5838 .71329 L .707 .577 .707 r
F
.62526 .76384 m .62182 .80212 L .65095 .80416 L p F P
0 g
s
.65095 .80416 m .6544 .76589 L .62526 .76384 L p .707 .577 .707 r
F P
0 g
s
.62798 .68518 m .62484 .74227 L .65413 .74214 L p .707 .577 .707 r
F P
0 g
s
.65413 .74214 m .65727 .68505 L .62798 .68518 L p .707 .577 .707 r
F P
0 g
s
.63699 .71682 m .60635 .71424 L p .6329 .67139 L .707 .577 .707 r
F P
0 g
s
.60633 .7134 m .63288 .67124 L .60635 .71424 L .707 .577 .707 r
F
.63288 .67124 m .64013 .65973 L .6329 .67139 L F
.63288 .67124 m .6329 .67139 L .60635 .71424 L F
.58179 .32471 m .57262 .34937 L p .6038 .53382 L F P
0 g
s
.60897 .65711 m .64013 .65973 L p .60633 .7134 L .707 .577 .707 r
F P
0 g
s
.63267 .79442 m .63612 .75614 L .64619 .75731 L p .707 .577 .707 r
F P
0 g
s
.6544 .76589 m .65095 .80416 L .67469 .80534 L p .707 .577 .707 r
F P
0 g
s
.67469 .80534 m .67814 .76707 L .6544 .76589 L p .707 .577 .707 r
F P
0 g
s
.64619 .75731 m .66363 .75934 L p .64914 .77576 L .707 .577 .707 r
F P
0 g
s
.63267 .79442 m .64619 .75731 L .64914 .77576 L .707 .577 .707 r
F
.6422 .761 m .60301 .47795 L p .6038 .53382 L F P
0 g
s
.63612 .75614 m .63267 .79442 L .60742 .7919 L p .707 .577 .707 r
F P
0 g
s
.60747 .78529 m .63612 .75614 L .60742 .7919 L .707 .577 .707 r
F
.60155 .79132 m .605 .75304 L .60774 .75332 L p F P
0 g
s
.60774 .75332 m .63612 .75614 L p .60747 .78529 L .707 .577 .707 r
F P
0 g
s
.60155 .79132 m .60774 .75332 L .60747 .78529 L .707 .577 .707 r
F
.60444 .57919 m .60891 .61147 L p .6038 .53382 L F P
0 g
s
.60891 .61147 m .63302 .78566 L p .60917 .58009 L .707 .577 .707 r
F P
0 g
s
.6038 .53382 m .60891 .61147 L .60917 .58009 L .707 .577 .707 r
F
.63302 .78566 m .6422 .761 L p .60928 .56626 L F P
0 g
s
.60928 .56626 m .6038 .53382 L .60917 .58009 L .707 .577 .707 r
F
.60928 .56626 m .60917 .58009 L .63302 .78566 L F
.60742 .7919 m .60155 .79132 L p .60747 .78529 L F P
0 g
s
.6422 .761 m .63736 .73735 L p .60755 .51595 L .707 .577 .707 r
F P
0 g
s
.60301 .47795 m .58179 .32471 L p .6038 .53382 L .707 .577 .707 r
F P
0 g
s
.60755 .51595 m .59851 .44881 L .61037 .53357 L .707 .577 .707 r
F
.60755 .51595 m .61037 .53357 L .6422 .761 L F
.60583 .7142 m .60624 .70678 L p .60633 .7134 L F P
0 g
s
.60624 .70678 m .60897 .65711 L p .60633 .7134 L .707 .577 .707 r
F P
0 g
s
.57696 .30106 m .58179 .32471 L p .59851 .44881 L .707 .577 .707 r
F P
0 g
s
.63736 .73735 m .58803 .38103 L p .59851 .44881 L .707 .577 .707 r
F P
0 g
s
.58803 .38103 m .57696 .30106 L p .59851 .44881 L .707 .577 .707 r
F P
0 g
s
.58179 .32471 m .60301 .47795 L p .59851 .44881 L .707 .577 .707 r
F P
0 g
s
.60301 .47795 m .6422 .761 L p .59851 .44881 L .707 .577 .707 r
F P
0 g
s
.64013 .65973 m .63776 .70279 L p .6329 .67139 L .707 .577 .707 r
F P
0 g
s
.63776 .70279 m .63699 .71682 L p .6329 .67139 L .707 .577 .707 r
F P
0 g
s
.60635 .71424 m .60583 .7142 L p .60633 .7134 L .707 .577 .707 r
F P
0 g
s
.57262 .34937 m .60444 .57919 L p .6038 .53382 L .707 .577 .707 r
F P
0 g
s
.55034 .37262 m .59073 .66437 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.57262 .34937 m .55034 .37262 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.58672 .69266 m .58749 .68722 L .60897 .65711 L .707 .577 .707 r
F
.59385 .65649 m .60897 .65711 L p .57446 .70548 L F P
0 g
s
.63302 .78566 m .60363 .57335 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.60363 .57335 m .57262 .34937 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.57406 .71289 m .57446 .70548 L p .58749 .68722 L .707 .577 .707 r
F P
0 g
s
.57406 .71289 m .58749 .68722 L .58672 .69266 L .707 .577 .707 r
F
.51713 .39219 m .56311 .72432 L p .58278 .68445 L F P
0 g
s
.57446 .70548 m .57406 .71289 L .56999 .71291 L p .707 .577 .707 r
F P
0 g
s
.56311 .72432 m .56412 .73162 L p .57446 .70548 L .707 .577 .707 r
F P
0 g
s
.58278 .68445 m .56311 .72432 L .57446 .70548 L .707 .577 .707 r
F
.57333 .75034 m .56988 .78861 L .54074 .78657 L p F P
0 g
s
.56988 .78861 m .57333 .75034 L .58038 .75094 L p .707 .577 .707 r
F P
0 g
s
.58038 .75094 m .605 .75304 L p .5739 .78454 L .707 .577 .707 r
F P
0 g
s
.56988 .78861 m .58038 .75094 L .5739 .78454 L .707 .577 .707 r
F
.605 .75304 m .60155 .79132 L .56988 .78861 L p F P
0 g
s
.61074 .80891 m .55034 .37262 L .51713 .39219 L p .707 .577 .707 r
F P
0 g
s
.57446 .70548 m .5772 .6558 L .59385 .65649 L p .707 .577 .707 r
F P
0 g
s
.59073 .66437 m .59338 .68352 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.59338 .68352 m .61074 .80891 L p .60044 .64693 L .707 .577 .707 r
F P
0 g
s
.5982 .61169 m .59338 .68352 L .60044 .64693 L .707 .577 .707 r
F
.56684 .84159 m .56861 .82245 L .60028 .82525 L p F P
0 g
s
.57753 .82848 m .51713 .39219 L .47624 .40616 L p .707 .577 .707 r
F P
0 g
s
.5772 .6558 m .57446 .70548 L p .54476 .71302 L .707 .577 .707 r
F P
0 g
s
.56999 .71291 m .54476 .71302 L p .57446 .70548 L .707 .577 .707 r
F P
0 g
s
.58707 .70353 m .58278 .68445 L .56446 .73408 L .707 .577 .707 r
F
.56412 .73162 m .56446 .73408 L p .58278 .68445 L F P
0 g
s
.61074 .80891 m .63302 .78566 L p .5982 .61169 L .707 .577 .707 r
F P
0 g
s
.57753 .82848 m .61074 .80891 L p .58707 .70353 L .707 .577 .707 r
F P
0 g
s
.56446 .73408 m .57753 .82848 L p .58707 .70353 L .707 .577 .707 r
F P
0 g
s
.53772 .83939 m .53949 .82026 L .56861 .82245 L p .707 .577 .707 r
F P
0 g
s
.56861 .82245 m .56684 .84159 L .53772 .83939 L p .707 .577 .707 r
F P
0 g
s
.55738 .83536 m .57753 .82848 L p .52817 .71203 L .707 .577 .707 r
F P
0 g
s
.52817 .71203 m .52134 .70519 L .55738 .83536 L .707 .577 .707 r
F
.5479 .65593 m .54476 .71302 L .53011 .71397 L p F P
0 g
s
.52395 .70781 m .5479 .65593 L .53011 .71397 L .707 .577 .707 r
F
.52397 .65748 m .5479 .65593 L p .52395 .70781 L F P
0 g
s
.52134 .70519 m .52397 .65748 L p .52395 .70781 L .707 .577 .707 r
F P
0 g
s
.57753 .82848 m .55637 .74027 L .52817 .71203 L .707 .577 .707 r
F
.51533 .68417 m .51394 .67846 L .51543 .68386 L F
.51394 .67846 m .53664 .84245 L .55738 .83536 L p F P
0 g
s
.50945 .66001 m .52397 .65748 L p .51543 .68386 L .707 .577 .707 r
F P
0 g
s
.51394 .67846 m .50945 .66001 L .51543 .68386 L .707 .577 .707 r
F
.44868 .41049 m .43168 .41316 L p .51394 .67846 L F P
0 g
s
.4482 .8488 m .3878 .41251 L .34891 .40428 L p .707 .577 .707 r
F P
0 g
s
.3878 .41251 m .4482 .8488 L .49208 .84945 L p .707 .577 .707 r
F P
0 g
s
.40931 .84057 m .34891 .40428 L .3188 .38926 L p .707 .577 .707 r
F P
0 g
s
.34891 .40428 m .40931 .84057 L .4482 .8488 L p .707 .577 .707 r
F P
0 g
s
.65727 .68505 m .65413 .74214 L .67807 .74059 L p .707 .577 .707 r
F P
0 g
s
.67807 .74059 m .68121 .6835 L .65727 .68505 L p .707 .577 .707 r
F P
0 g
s
.58898 .83206 m .58721 .85119 L .61888 .85399 L p .707 .577 .707 r
F P
0 g
s
.61888 .85399 m .62065 .83486 L .58898 .83206 L p .707 .577 .707 r
F P
0 g
s
.62065 .83486 m .61888 .85399 L .648 .85619 L p .707 .577 .707 r
F P
0 g
s
.648 .85619 m .64977 .83705 L .62065 .83486 L p .707 .577 .707 r
F P
0 g
s
.68121 .6835 m .67807 .74059 L .69431 .73776 L p .707 .577 .707 r
F P
0 g
s
.69431 .73776 m .69745 .68067 L .68121 .6835 L p .707 .577 .707 r
F P
0 g
s
.64977 .83705 m .648 .85619 L .67172 .85756 L p .707 .577 .707 r
F P
0 g
s
.67172 .85756 m .67349 .83842 L .64977 .83705 L p .707 .577 .707 r
F P
0 g
s
.35131 .70095 m .35445 .64386 L .3382 .64668 L p .707 .577 .707 r
F P
0 g
s
.35445 .64386 m .35131 .70095 L .35826 .69712 L p .707 .577 .707 r
F P
0 g
s
.36734 .6313 m .34691 .52945 L .36199 .66773 L .707 .577 .707 r
F
.3565 .66156 m .3792 .82555 L p .34691 .52945 L F P
0 g
s
.35826 .69712 m .35861 .69073 L p .35445 .64386 L .707 .577 .707 r
F P
0 g
s
.35861 .69073 m .35878 .68775 L p .35734 .67318 L .707 .577 .707 r
F P
0 g
s
.35861 .69073 m .35734 .67318 L .35445 .64386 L .707 .577 .707 r
F
.3792 .82555 m .3596 .68399 L p .36219 .72697 L F P
0 g
s
.3596 .68399 m .3565 .66156 L p .35878 .68775 L .707 .577 .707 r
F P
0 g
s
.3596 .68399 m .35878 .68775 L .36219 .72697 L .707 .577 .707 r
F
.35752 .67328 m .3614 .64003 L .35493 .64359 L p F P
0 g
s
.35493 .64359 m .35445 .64386 L p .35878 .68775 L .707 .577 .707 r
F P
0 g
s
.35861 .69073 m .35826 .69712 L .35778 .69641 L p .707 .577 .707 r
F P
0 g
s
.3188 .38926 m .30043 .36893 L p .3569 .69628 L .707 .577 .707 r
F P
0 g
s
.35778 .69641 m .35709 .6954 L p .35861 .69073 L .707 .577 .707 r
F P
0 g
s
.35805 .69106 m .35861 .69073 L .35709 .6954 L .707 .577 .707 r
F
.36219 .72697 m .35775 .69241 L .3569 .69628 L F
.35775 .69241 m .3188 .38926 L .3569 .69628 L F
.35878 .68775 m .35861 .69073 L p .35805 .69106 L F P
0 g
s
.3565 .66156 m .3188 .38926 L p .36219 .72697 L .707 .577 .707 r
F P
0 g
s
.3382 .64668 m .33506 .70377 L .35131 .70095 L p .707 .577 .707 r
F P
0 g
s
.3477 .76873 m .35115 .73046 L .33513 .73025 L p .707 .577 .707 r
F P
0 g
s
.35115 .73046 m .3477 .76873 L .35444 .76794 L p .707 .577 .707 r
F P
0 g
s
.35444 .76794 m .35789 .72967 L .35115 .73046 L p .707 .577 .707 r
F P
0 g
s
.35444 .76794 m .35123 .76623 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.35789 .72967 m .3558 .75284 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.3558 .75284 m .35444 .76794 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.34513 .69343 m .30043 .36893 L .34415 .68763 L .707 .577 .707 r
F
.33513 .73025 m .33168 .76853 L .3477 .76873 L p F P
0 g
s
.33839 .76377 m .34184 .7255 L .35059 .72717 L p .707 .577 .707 r
F P
0 g
s
.35059 .72717 m .35468 .72796 L p .35182 .73425 L .707 .577 .707 r
F P
0 g
s
.33839 .76377 m .35059 .72717 L .35182 .73425 L .707 .577 .707 r
F
.35083 .733 m .34776 .71082 L p .35027 .73074 L F P
0 g
s
.34776 .71082 m .34641 .70106 L p .34743 .7089 L .707 .577 .707 r
F P
0 g
s
.34776 .71082 m .34743 .7089 L .35027 .73074 L .707 .577 .707 r
F
.34641 .70106 m .30043 .36893 L p .34513 .69343 L F P
0 g
s
.34641 .70106 m .34513 .69343 L .35027 .73074 L .707 .577 .707 r
F
.30043 .36893 m .29559 .34528 L p .34415 .68763 L F P
0 g
s
.36083 .80522 m .3792 .82555 L p .35954 .71157 L .707 .577 .707 r
F P
0 g
s
.30043 .36893 m .34641 .70106 L p .35954 .71157 L .707 .577 .707 r
F P
0 g
s
.35468 .72796 m .35789 .72967 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.35123 .76623 m .35333 .74297 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.35333 .74297 m .35468 .72796 L p .35457 .74791 L .707 .577 .707 r
F P
0 g
s
.35468 .72796 m .35123 .76623 L .33839 .76377 L p .707 .577 .707 r
F P
0 g
s
.35599 .78157 m .36083 .80522 L p .35027 .73074 L .707 .577 .707 r
F P
0 g
s
.34257 .68805 m .34298 .68064 L p .34363 .68453 L .707 .577 .707 r
F P
0 g
s
.34433 .68869 m .34257 .68805 L p .34363 .68453 L .707 .577 .707 r
F P
0 g
s
.33506 .70377 m .3382 .64668 L .31426 .64824 L p .707 .577 .707 r
F P
0 g
s
.29559 .34528 m .30477 .32062 L p .3359 .60078 L .707 .577 .707 r
F P
0 g
s
.34257 .68805 m .3361 .68671 L p .33778 .6482 L .707 .577 .707 r
F P
0 g
s
.33602 .65202 m .33778 .6482 L .3361 .68671 L .707 .577 .707 r
F
.29559 .34528 m .33598 .63703 L p .34457 .69058 L F P
0 g
s
.34571 .63096 m .34298 .68064 L p .33778 .6482 L .707 .577 .707 r
F P
0 g
s
.34298 .68064 m .34257 .68805 L p .33778 .6482 L .707 .577 .707 r
F P
0 g
s
.35027 .73074 m .34457 .69058 L .34734 .71905 L .707 .577 .707 r
F
.33598 .63703 m .29559 .34528 L p .3359 .60078 L F P
0 g
s
.31426 .64824 m .31112 .70532 L .33506 .70377 L p .707 .577 .707 r
F P
0 g
s
.32145 .68368 m .32459 .62659 L .33597 .62894 L p .707 .577 .707 r
F P
0 g
s
.33597 .62894 m .34571 .63096 L p .33602 .65202 L .707 .577 .707 r
F P
0 g
s
.32145 .68368 m .33597 .62894 L .33602 .65202 L .707 .577 .707 r
F
.34641 .70106 m .36083 .80522 L p .35954 .71157 L F P
0 g
s
.3188 .38926 m .3565 .66156 L p .34691 .52945 L .707 .577 .707 r
F P
0 g
s
.34571 .63096 m .35839 .63559 L p .34363 .68453 L .707 .577 .707 r
F P
0 g
s
.34298 .68064 m .34571 .63096 L p .34363 .68453 L .707 .577 .707 r
F P
0 g
s
.35839 .63559 m .35525 .69268 L .34433 .68869 L p .707 .577 .707 r
F P
0 g
s
.34363 .68453 m .35839 .63559 L .34433 .68869 L .707 .577 .707 r
F
.36083 .80522 m .35083 .733 L p .35027 .73074 L F P
0 g
s
.36517 .75691 m .35599 .78157 L p .3359 .60078 L .707 .577 .707 r
F P
0 g
s
.30477 .32062 m .33577 .5446 L p .3359 .60078 L .707 .577 .707 r
F P
0 g
s
.35709 .6954 m .35525 .69268 L p .35805 .69106 L .707 .577 .707 r
F P
0 g
s
.3614 .64003 m .35878 .68775 L p .35525 .69268 L .707 .577 .707 r
F P
0 g
s
.35525 .69268 m .35878 .68775 L .35805 .69106 L .707 .577 .707 r
F
.35525 .69268 m .35839 .63559 L .3614 .64003 L p F P
0 g
s
.33577 .5446 m .36517 .75691 L p .3359 .60078 L .707 .577 .707 r
F P
0 g
s
.33598 .63703 m .34734 .71905 L p .34457 .69058 L .707 .577 .707 r
F P
0 g
s
.34734 .71905 m .35599 .78157 L p .35027 .73074 L .707 .577 .707 r
F P
0 g
s
.35027 .73074 m .34513 .69343 L .34415 .68763 L .707 .577 .707 r
F
.35599 .78157 m .33598 .63703 L p .3359 .60078 L F P
0 g
s
.3361 .68671 m .32145 .68368 L p .33602 .65202 L .707 .577 .707 r
F P
0 g
s
.3792 .82555 m .40931 .84057 L p .36734 .6313 L .707 .577 .707 r
F P
0 g
s
.36734 .6313 m .36199 .66773 L .3792 .82555 L .707 .577 .707 r
F
.67814 .76707 m .67469 .80534 L .69071 .80555 L p F P
0 g
s
.69071 .80555 m .69416 .76727 L .67814 .76707 L p .707 .577 .707 r
F P
0 g
s
.67349 .83842 m .67172 .85756 L .68773 .85797 L p .707 .577 .707 r
F P
0 g
s
.68773 .85797 m .6895 .83883 L .67349 .83842 L p .707 .577 .707 r
F P
0 g
s
.69745 .68067 m .69431 .73776 L .70127 .73394 L p .707 .577 .707 r
F P
0 g
s
.70127 .73394 m .70441 .67685 L .69745 .68067 L p .707 .577 .707 r
F P
0 g
s
.69416 .76727 m .69071 .80555 L .69745 .80476 L p .707 .577 .707 r
F P
0 g
s
.69745 .80476 m .7009 .76648 L .69416 .76727 L p .707 .577 .707 r
F P
0 g
s
.6895 .83883 m .68773 .85797 L .69444 .85739 L p .707 .577 .707 r
F P
0 g
s
.69444 .85739 m .69621 .83825 L .6895 .83883 L p .707 .577 .707 r
F P
0 g
s
.70441 .67685 m .70127 .73394 L .69826 .72949 L p .707 .577 .707 r
F P
0 g
s
.69826 .72949 m .7014 .6724 L .70441 .67685 L p .707 .577 .707 r
F P
0 g
s
.7009 .76648 m .69745 .80476 L .69424 .80304 L p .707 .577 .707 r
F P
0 g
s
.69424 .80304 m .69769 .76477 L .7009 .76648 L p .707 .577 .707 r
F P
0 g
s
.69621 .83825 m .69444 .85739 L .69122 .85587 L p .707 .577 .707 r
F P
0 g
s
.69122 .85587 m .69299 .83673 L .69621 .83825 L p .707 .577 .707 r
F P
0 g
s
.57696 .30106 m .63736 .73735 L .61899 .71702 L p .707 .577 .707 r
F P
0 g
s
.61899 .71702 m .55859 .28073 L .57696 .30106 L p .707 .577 .707 r
F P
0 g
s
.7014 .6724 m .69826 .72949 L .68558 .72486 L p .707 .577 .707 r
F P
0 g
s
.68558 .72486 m .68872 .66777 L .7014 .6724 L p .707 .577 .707 r
F P
0 g
s
.25006 .70414 m .2532 .64705 L .22204 .64443 L p .707 .577 .707 r
F P
0 g
s
.2532 .64705 m .25006 .70414 L .28183 .70545 L p .707 .577 .707 r
F P
0 g
s
.28183 .70545 m .28497 .64836 L .2532 .64705 L p .707 .577 .707 r
F P
0 g
s
.28497 .64836 m .28183 .70545 L .31112 .70532 L p .707 .577 .707 r
F P
0 g
s
.31112 .70532 m .31426 .64824 L .28497 .64836 L p .707 .577 .707 r
F P
0 g
s
.2189 .70152 m .22204 .64443 L .19456 .64076 L p .707 .577 .707 r
F P
0 g
s
.22204 .64443 m .2189 .70152 L .25006 .70414 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.69769 .76477 m .69424 .80304 L .6814 .80058 L p .707 .577 .707 r
F P
0 g
s
.6814 .80058 m .68485 .76231 L .69769 .76477 L p .707 .577 .707 r
F P
0 g
s
.19456 .64076 m .19143 .69785 L .2189 .70152 L p .707 .577 .707 r
F P
0 g
s
.24713 .7626 m .25058 .72433 L .21946 .72123 L p .707 .577 .707 r
F P
0 g
s
.25058 .72433 m .24713 .7626 L .27881 .7653 L p .707 .577 .707 r
F P
0 g
s
.27881 .7653 m .28226 .72703 L .25058 .72433 L p .707 .577 .707 r
F P
0 g
s
.21946 .72123 m .21601 .7595 L .24713 .7626 L p .707 .577 .707 r
F P
0 g
s
.36517 .75691 m .30477 .32062 L .32705 .29737 L p .707 .577 .707 r
F P
0 g
s
.28226 .72703 m .27881 .7653 L .30794 .76734 L p .707 .577 .707 r
F P
0 g
s
.30794 .76734 m .31139 .72907 L .28226 .72703 L p .707 .577 .707 r
F P
0 g
s
.69299 .83673 m .69122 .85587 L .67836 .85356 L p .707 .577 .707 r
F P
0 g
s
.67836 .85356 m .68013 .83442 L .69299 .83673 L p .707 .577 .707 r
F P
0 g
s
.21601 .7595 m .21946 .72123 L .19195 .71803 L p .707 .577 .707 r
F P
0 g
s
.2442 .81438 m .24597 .79524 L .21486 .79211 L p .707 .577 .707 r
F P
0 g
s
.24597 .79524 m .2442 .81438 L .27587 .81718 L p .707 .577 .707 r
F P
0 g
s
.27587 .81718 m .27764 .79804 L .24597 .79524 L p .707 .577 .707 r
F P
0 g
s
.19143 .69785 m .19456 .64076 L .17345 .63639 L p .707 .577 .707 r
F P
0 g
s
.19195 .71803 m .1885 .7563 L .21601 .7595 L p .707 .577 .707 r
F P
0 g
s
.21486 .79211 m .21309 .81124 L .2442 .81438 L p .707 .577 .707 r
F P
0 g
s
.68872 .66777 m .68558 .72486 L .66446 .72049 L p .707 .577 .707 r
F P
0 g
s
.66446 .72049 m .6676 .66341 L .68872 .66777 L p .707 .577 .707 r
F P
0 g
s
.55859 .28073 m .61899 .71702 L .58888 .702 L p .707 .577 .707 r
F P
0 g
s
.58888 .702 m .52848 .26571 L .55859 .28073 L p .707 .577 .707 r
F P
0 g
s
.27764 .79804 m .27587 .81718 L .30499 .81937 L p .707 .577 .707 r
F P
0 g
s
.30499 .81937 m .30676 .80023 L .27764 .79804 L p .707 .577 .707 r
F P
0 g
s
.21309 .81124 m .21486 .79211 L .18734 .78895 L p .707 .577 .707 r
F P
0 g
s
.18734 .78895 m .18557 .80809 L .21309 .81124 L p .707 .577 .707 r
F P
0 g
s
.17345 .63639 m .17031 .69348 L .19143 .69785 L p .707 .577 .707 r
F P
0 g
s
.31139 .72907 m .30794 .76734 L .33168 .76853 L p .707 .577 .707 r
F P
0 g
s
.33168 .76853 m .33513 .73025 L .31139 .72907 L p .707 .577 .707 r
F P
0 g
s
.1885 .7563 m .19195 .71803 L .17073 .71506 L p .707 .577 .707 r
F P
0 g
s
.30676 .80023 m .30499 .81937 L .32871 .82074 L p .707 .577 .707 r
F P
0 g
s
.32871 .82074 m .33048 .8016 L .30676 .80023 L p .707 .577 .707 r
F P
0 g
s
.17073 .71506 m .16729 .75333 L .1885 .7563 L p .707 .577 .707 r
F P
0 g
s
.68485 .76231 m .6814 .80058 L .66018 .79761 L p .707 .577 .707 r
F P
0 g
s
.66018 .79761 m .66363 .75934 L .68485 .76231 L p .707 .577 .707 r
F P
0 g
s
.18557 .80809 m .18734 .78895 L .16612 .78607 L p .707 .577 .707 r
F P
0 g
s
.16612 .78607 m .16435 .80521 L .18557 .80809 L p .707 .577 .707 r
F P
0 g
s
.17031 .69348 m .17345 .63639 L .16077 .63176 L p .707 .577 .707 r
F P
0 g
s
.6676 .66341 m .66446 .72049 L .63699 .71682 L p .707 .577 .707 r
F P
0 g
s
.63699 .71682 m .64013 .65973 L .6676 .66341 L p .707 .577 .707 r
F P
0 g
s
.68013 .83442 m .67836 .85356 L .65714 .85068 L p .707 .577 .707 r
F P
0 g
s
.65714 .85068 m .65891 .83154 L .68013 .83442 L p .707 .577 .707 r
F P
0 g
s
.32705 .29737 m .38745 .73366 L .36517 .75691 L p .707 .577 .707 r
F P
0 g
s
.38745 .73366 m .32705 .29737 L .36026 .2778 L p .707 .577 .707 r
F P
0 g
s
.16077 .63176 m .15763 .68885 L .17031 .69348 L p .707 .577 .707 r
F P
0 g
s
.54476 .71302 m .5479 .65593 L .5772 .6558 L p .707 .577 .707 r
F P
0 g
s
.52848 .26571 m .58888 .702 L .54999 .69377 L p .707 .577 .707 r
F P
0 g
s
.54999 .69377 m .48959 .25748 L .52848 .26571 L p .707 .577 .707 r
F P
0 g
s
.33048 .8016 m .32871 .82074 L .34472 .82116 L p .707 .577 .707 r
F P
0 g
s
.34472 .82116 m .34649 .80202 L .33048 .8016 L p .707 .577 .707 r
F P
0 g
s
.16729 .75333 m .17073 .71506 L .15789 .7126 L p .707 .577 .707 r
F P
0 g
s
.15789 .7126 m .15445 .75087 L .16729 .75333 L p .707 .577 .707 r
F P
0 g
s
.66363 .75934 m .66018 .79761 L .63267 .79442 L p .707 .577 .707 r
F P
0 g
s
.16435 .80521 m .16612 .78607 L .15327 .78376 L p .707 .577 .707 r
F P
0 g
s
.15327 .78376 m .1515 .8029 L .16435 .80521 L p .707 .577 .707 r
F P
0 g
s
.65891 .83154 m .65714 .85068 L .62962 .84752 L p .707 .577 .707 r
F P
0 g
s
.62962 .84752 m .63139 .82838 L .65891 .83154 L p .707 .577 .707 r
F P
0 g
s
.42066 .71409 m .36026 .2778 L .40115 .26383 L p .707 .577 .707 r
F P
0 g
s
.36026 .2778 m .42066 .71409 L .38745 .73366 L p .707 .577 .707 r
F P
0 g
s
.15763 .68885 m .16077 .63176 L .15776 .62732 L p .707 .577 .707 r
F P
0 g
s
.48959 .25748 m .54999 .69377 L .50611 .69312 L p .707 .577 .707 r
F P
0 g
s
.50611 .69312 m .44571 .25683 L .48959 .25748 L p .707 .577 .707 r
F P
0 g
s
.15776 .62732 m .15462 .6844 L .15763 .68885 L p .707 .577 .707 r
F P
0 g
s
.46155 .70012 m .40115 .26383 L .44571 .25683 L p .707 .577 .707 r
F P
0 g
s
.40115 .26383 m .46155 .70012 L .42066 .71409 L p .707 .577 .707 r
F P
0 g
s
.44571 .25683 m .50611 .69312 L .46155 .70012 L p .707 .577 .707 r
F P
0 g
s
.63139 .82838 m .62962 .84752 L .59851 .84439 L p .707 .577 .707 r
F P
0 g
s
.59851 .84439 m .60028 .82525 L .63139 .82838 L p .707 .577 .707 r
F P
0 g
s
.34649 .80202 m .34472 .82116 L .35144 .82057 L p .707 .577 .707 r
F P
0 g
s
.35144 .82057 m .35321 .80144 L .34649 .80202 L p .707 .577 .707 r
F P
0 g
s
.15445 .75087 m .15789 .7126 L .15468 .71089 L p .707 .577 .707 r
F P
0 g
s
.60028 .82525 m .59851 .84439 L .56684 .84159 L p .707 .577 .707 r
F P
0 g
s
.15468 .71089 m .15124 .74916 L .15445 .75087 L p .707 .577 .707 r
F P
0 g
s
.1515 .8029 m .15327 .78376 L .15004 .78224 L p .707 .577 .707 r
F P
0 g
s
.15004 .78224 m .14827 .80137 L .1515 .8029 L p .707 .577 .707 r
F P
0 g
s
.15462 .6844 m .15776 .62732 L .16471 .62349 L p .707 .577 .707 r
F P
0 g
s
.16471 .62349 m .16157 .68058 L .15462 .6844 L p .707 .577 .707 r
F P
0 g
s
.35321 .80144 m .35144 .82057 L .34821 .81905 L p .707 .577 .707 r
F P
0 g
s
.34821 .81905 m .34998 .79992 L .35321 .80144 L p .707 .577 .707 r
F P
0 g
s
.15124 .74916 m .15468 .71089 L .16142 .7101 L p .707 .577 .707 r
F P
0 g
s
.16142 .7101 m .15797 .74837 L .15124 .74916 L p .707 .577 .707 r
F P
0 g
s
.14827 .80137 m .15004 .78224 L .15676 .78166 L p .707 .577 .707 r
F P
0 g
s
.15676 .78166 m .15499 .80079 L .14827 .80137 L p .707 .577 .707 r
F P
0 g
s
.16157 .68058 m .16471 .62349 L .18096 .62067 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18096 .62067 m .17782 .67776 L .16157 .68058 L p .707 .577 .707 r
F P
0 g
s
.34998 .79992 m .34821 .81905 L .33535 .81674 L p .707 .577 .707 r
F P
0 g
s
.33535 .81674 m .33712 .7976 L .34998 .79992 L p .707 .577 .707 r
F P
0 g
s
.15797 .74837 m .16142 .7101 L .17744 .7103 L p .707 .577 .707 r
F P
0 g
s
.17744 .7103 m .17399 .74857 L .15797 .74837 L p .707 .577 .707 r
F P
0 g
s
.15499 .80079 m .15676 .78166 L .17276 .78207 L p .707 .577 .707 r
F P
0 g
s
.17276 .78207 m .17099 .80121 L .15499 .80079 L p .707 .577 .707 r
F P
0 g
s
.17782 .67776 m .18096 .62067 L .20489 .61911 L p .707 .577 .707 r
F P
0 g
s
.34184 .7255 m .33839 .76377 L .31718 .76079 L p .707 .577 .707 r
F P
0 g
s
.31718 .76079 m .32062 .72252 L .34184 .7255 L p .707 .577 .707 r
F P
0 g
s
.20489 .61911 m .20175 .6762 L .17782 .67776 L p .707 .577 .707 r
F P
0 g
s
.32459 .62659 m .32145 .68368 L .29398 .68001 L p .707 .577 .707 r
F P
0 g
s
.29398 .68001 m .29712 .62292 L .32459 .62659 L p .707 .577 .707 r
F P
0 g
s
.33712 .7976 m .33535 .81674 L .31413 .81386 L p .707 .577 .707 r
F P
0 g
s
.31413 .81386 m .3159 .79473 L .33712 .7976 L p .707 .577 .707 r
F P
0 g
s
.17399 .74857 m .17744 .7103 L .20118 .71148 L p .707 .577 .707 r
F P
0 g
s
.20118 .71148 m .19773 .74976 L .17399 .74857 L p .707 .577 .707 r
F P
0 g
s
.20175 .6762 m .20489 .61911 L .23419 .61899 L p .707 .577 .707 r
F P
0 g
s
.17099 .80121 m .17276 .78207 L .19648 .78344 L p .707 .577 .707 r
F P
0 g
s
.19648 .78344 m .19471 .80258 L .17099 .80121 L p .707 .577 .707 r
F P
0 g
s
.23419 .61899 m .23105 .67608 L .20175 .6762 L p .707 .577 .707 r
F P
0 g
s
.29712 .62292 m .29398 .68001 L .26282 .67739 L p .707 .577 .707 r
F P
0 g
s
.26282 .67739 m .26596 .6203 L .29712 .62292 L p .707 .577 .707 r
F P
0 g
s
.32062 .72252 m .31718 .76079 L .28966 .7576 L p .707 .577 .707 r
F P
0 g
s
.28966 .7576 m .29311 .71933 L .32062 .72252 L p .707 .577 .707 r
F P
0 g
s
.73027 .64207 m .73341 .58498 L .70226 .58236 L p .707 .577 .707 r
F P
0 g
s
.73341 .58498 m .73027 .64207 L .76205 .64338 L p .707 .577 .707 r
F P
0 g
s
.76205 .64338 m .76519 .58629 L .73341 .58498 L p .707 .577 .707 r
F P
0 g
s
.23105 .67608 m .23419 .61899 L .26596 .6203 L p .707 .577 .707 r
F P
0 g
s
.76519 .58629 m .76205 .64338 L .79134 .64326 L p .707 .577 .707 r
F P
0 g
s
.79134 .64326 m .79448 .58617 L .76519 .58629 L p .707 .577 .707 r
F P
0 g
s
.26596 .6203 m .26282 .67739 L .23105 .67608 L p .707 .577 .707 r
F P
0 g
s
.19773 .74976 m .20118 .71148 L .23032 .71353 L p .707 .577 .707 r
F P
0 g
s
.69912 .63945 m .70226 .58236 L .67478 .57869 L p .707 .577 .707 r
F P
0 g
s
.70226 .58236 m .69912 .63945 L .73027 .64207 L p .707 .577 .707 r
F P
0 g
s
.3159 .79473 m .31413 .81386 L .28661 .8107 L p .707 .577 .707 r
F P
0 g
s
.28661 .8107 m .28838 .79157 L .3159 .79473 L p .707 .577 .707 r
F P
0 g
s
.23032 .71353 m .22687 .7518 L .19773 .74976 L p .707 .577 .707 r
F P
0 g
s
.72734 .69002 m .73079 .65175 L .69967 .64865 L p .707 .577 .707 r
F P
0 g
s
.73079 .65175 m .72734 .69002 L .75902 .69272 L p .707 .577 .707 r
F P
0 g
s
.75902 .69272 m .76247 .65445 L .73079 .65175 L p .707 .577 .707 r
F P
0 g
s
.69967 .64865 m .69623 .68692 L .72734 .69002 L p .707 .577 .707 r
F P
0 g
s
.19471 .80258 m .19648 .78344 L .2256 .78563 L p .707 .577 .707 r
F P
0 g
s
.67478 .57869 m .67164 .63578 L .69912 .63945 L p .707 .577 .707 r
F P
0 g
s
.2256 .78563 m .22383 .80477 L .19471 .80258 L p .707 .577 .707 r
F P
0 g
s
.72442 .72514 m .72619 .70601 L .69507 .70287 L p .707 .577 .707 r
F P
0 g
s
.72619 .70601 m .72442 .72514 L .75608 .72794 L p .707 .577 .707 r
F P
0 g
s
.75608 .72794 m .75785 .70881 L .72619 .70601 L p .707 .577 .707 r
F P
0 g
s
.76247 .65445 m .75902 .69272 L .78815 .69477 L p .707 .577 .707 r
F P
0 g
s
.78815 .69477 m .7916 .65649 L .76247 .65445 L p .707 .577 .707 r
F P
0 g
s
.29311 .71933 m .28966 .7576 L .25854 .7545 L p .707 .577 .707 r
F P
0 g
s
.25854 .7545 m .26199 .71623 L .29311 .71933 L p .707 .577 .707 r
F P
0 g
s
.69507 .70287 m .6933 .72201 L .72442 .72514 L p .707 .577 .707 r
F P
0 g
s
.79448 .58617 m .79134 .64326 L .81528 .6417 L p .707 .577 .707 r
F P
0 g
s
.81528 .6417 m .81842 .58461 L .79448 .58617 L p .707 .577 .707 r
F P
0 g
s
.75785 .70881 m .75608 .72794 L .78521 .73014 L p .707 .577 .707 r
F P
0 g
s
.78521 .73014 m .78698 .711 L .75785 .70881 L p .707 .577 .707 r
F P
0 g
s
.69623 .68692 m .69967 .64865 L .67216 .64545 L p .707 .577 .707 r
F P
0 g
s
.22687 .7518 m .23032 .71353 L .26199 .71623 L p .707 .577 .707 r
F P
0 g
s
.67216 .64545 m .66871 .68373 L .69623 .68692 L p .707 .577 .707 r
F P
0 g
s
.26199 .71623 m .25854 .7545 L .22687 .7518 L p .707 .577 .707 r
F P
0 g
s
.6933 .72201 m .69507 .70287 L .66756 .69971 L p .707 .577 .707 r
F P
0 g
s
.66756 .69971 m .66579 .71885 L .6933 .72201 L p .707 .577 .707 r
F P
0 g
s
.67164 .63578 m .67478 .57869 L .65366 .57433 L p .707 .577 .707 r
F P
0 g
s
.28838 .79157 m .28661 .8107 L .2555 .80757 L p .707 .577 .707 r
F P
0 g
s
.2555 .80757 m .25727 .78843 L .28838 .79157 L p .707 .577 .707 r
F P
0 g
s
.22383 .80477 m .2256 .78563 L .25727 .78843 L p .707 .577 .707 r
F P
0 g
s
.25727 .78843 m .2555 .80757 L .22383 .80477 L p .707 .577 .707 r
F P
0 g
s
.7916 .65649 m .78815 .69477 L .81189 .69595 L p .707 .577 .707 r
F P
0 g
s
.81189 .69595 m .81534 .65768 L .7916 .65649 L p .707 .577 .707 r
F P
0 g
s
.65366 .57433 m .65052 .63141 L .67164 .63578 L p .707 .577 .707 r
F P
0 g
s
.78698 .711 m .78521 .73014 L .80893 .73151 L p .707 .577 .707 r
F P
0 g
s
.80893 .73151 m .8107 .71237 L .78698 .711 L p .707 .577 .707 r
F P
0 g
s
.66871 .68373 m .67216 .64545 L .65095 .64248 L p .707 .577 .707 r
F P
0 g
s
.65095 .64248 m .6475 .68075 L .66871 .68373 L p .707 .577 .707 r
F P
0 g
s
.81842 .58461 m .81528 .6417 L .83152 .63888 L p .707 .577 .707 r
F P
0 g
s
.83152 .63888 m .83466 .58179 L .81842 .58461 L p .707 .577 .707 r
F P
0 g
s
.66579 .71885 m .66756 .69971 L .64633 .69684 L p .707 .577 .707 r
F P
0 g
s
.64633 .69684 m .64456 .71597 L .66579 .71885 L p .707 .577 .707 r
F P
0 g
s
.65052 .63141 m .65366 .57433 L .64098 .56969 L p .707 .577 .707 r
F P
0 g
s
.81534 .65768 m .81189 .69595 L .82792 .69615 L p .707 .577 .707 r
F P
0 g
s
.82792 .69615 m .83137 .65788 L .81534 .65768 L p .707 .577 .707 r
F P
0 g
s
.8107 .71237 m .80893 .73151 L .82493 .73192 L p .707 .577 .707 r
F P
0 g
s
.82493 .73192 m .8267 .71278 L .8107 .71237 L p .707 .577 .707 r
F P
0 g
s
.64098 .56969 m .63784 .62678 L .65052 .63141 L p .707 .577 .707 r
F P
0 g
s
.6475 .68075 m .65095 .64248 L .63811 .64002 L p .707 .577 .707 r
F P
0 g
s
.63811 .64002 m .63466 .67829 L .6475 .68075 L p .707 .577 .707 r
F P
0 g
s
.64456 .71597 m .64633 .69684 L .63348 .69452 L p .707 .577 .707 r
F P
0 g
s
.63348 .69452 m .63171 .71366 L .64456 .71597 L p .707 .577 .707 r
F P
0 g
s
.83466 .58179 m .83152 .63888 L .83848 .63505 L p .707 .577 .707 r
F P
0 g
s
.83848 .63505 m .84162 .57797 L .83466 .58179 L p .707 .577 .707 r
F P
0 g
s
.63784 .62678 m .64098 .56969 L .63797 .56525 L p .707 .577 .707 r
F P
0 g
s
.83137 .65788 m .82792 .69615 L .83465 .69536 L p .707 .577 .707 r
F P
0 g
s
.83465 .69536 m .8381 .65709 L .83137 .65788 L p .707 .577 .707 r
F P
0 g
s
.8267 .71278 m .82493 .73192 L .83165 .73134 L p .707 .577 .707 r
F P
0 g
s
.83165 .73134 m .83342 .7122 L .8267 .71278 L p .707 .577 .707 r
F P
0 g
s
.63797 .56525 m .63483 .62234 L .63784 .62678 L p .707 .577 .707 r
F P
0 g
s
.63466 .67829 m .63811 .64002 L .6349 .63831 L p .707 .577 .707 r
F P
0 g
s
.6349 .63831 m .63145 .67658 L .63466 .67829 L p .707 .577 .707 r
F P
0 g
s
.63171 .71366 m .63348 .69452 L .63025 .693 L p .707 .577 .707 r
F P
0 g
s
.63025 .693 m .62848 .71214 L .63171 .71366 L p .707 .577 .707 r
F P
0 g
s
.84162 .57797 m .83848 .63505 L .83546 .63061 L p .707 .577 .707 r
F P
0 g
s
.83546 .63061 m .8386 .57352 L .84162 .57797 L p .707 .577 .707 r
F P
0 g
s
.63483 .62234 m .63797 .56525 L .64493 .56142 L p .707 .577 .707 r
F P
0 g
s
.8381 .65709 m .83465 .69536 L .83145 .69365 L p .707 .577 .707 r
F P
0 g
s
.83145 .69365 m .83489 .65538 L .8381 .65709 L p .707 .577 .707 r
F P
0 g
s
.83342 .7122 m .83165 .73134 L .82842 .72982 L p .707 .577 .707 r
F P
0 g
s
.82842 .72982 m .83019 .71068 L .83342 .7122 L p .707 .577 .707 r
F P
0 g
s
.64493 .56142 m .64179 .61851 L .63483 .62234 L p .707 .577 .707 r
F P
0 g
s
.63145 .67658 m .6349 .63831 L .64163 .63752 L p .707 .577 .707 r
F P
0 g
s
.64163 .63752 m .63819 .67579 L .63145 .67658 L p .707 .577 .707 r
F P
0 g
s
.62848 .71214 m .63025 .693 L .63697 .69242 L p .707 .577 .707 r
F P
0 g
s
.63697 .69242 m .6352 .71156 L .62848 .71214 L p .707 .577 .707 r
F P
0 g
s
.8386 .57352 m .83546 .63061 L .82278 .62598 L p .707 .577 .707 r
F P
0 g
s
.82278 .62598 m .82592 .56889 L .8386 .57352 L p .707 .577 .707 r
F P
0 g
s
.38726 .60526 m .3904 .54817 L .35925 .54555 L p .707 .577 .707 r
F P
0 g
s
.3904 .54817 m .38726 .60526 L .41904 .60657 L p .707 .577 .707 r
F P
0 g
s
.41904 .60657 m .42218 .54948 L .3904 .54817 L p .707 .577 .707 r
F P
0 g
s
.42218 .54948 m .41904 .60657 L .44833 .60644 L p .707 .577 .707 r
F P
0 g
s
.44833 .60644 m .45147 .54935 L .42218 .54948 L p .707 .577 .707 r
F P
0 g
s
.64179 .61851 m .64493 .56142 L .66117 .5586 L p .707 .577 .707 r
F P
0 g
s
.35611 .60264 m .35925 .54555 L .33177 .54188 L p .707 .577 .707 r
F P
0 g
s
.35925 .54555 m .35611 .60264 L .38726 .60526 L p .707 .577 .707 r
F P
0 g
s
.83489 .65538 m .83145 .69365 L .8186 .69119 L p .707 .577 .707 r
F P
0 g
s
.8186 .69119 m .82205 .65292 L .83489 .65538 L p .707 .577 .707 r
F P
0 g
s
.83019 .71068 m .82842 .72982 L .81557 .7275 L p .707 .577 .707 r
F P
0 g
s
.81557 .7275 m .81734 .70837 L .83019 .71068 L p .707 .577 .707 r
F P
0 g
s
.38433 .6532 m .38778 .61493 L .35666 .61183 L p .707 .577 .707 r
F P
0 g
s
.38778 .61493 m .38433 .6532 L .41601 .65591 L p .707 .577 .707 r
F P
0 g
s
.41601 .65591 m .41946 .61763 L .38778 .61493 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66117 .5586 m .65803 .61569 L .64179 .61851 L p .707 .577 .707 r
F P
0 g
s
.35666 .61183 m .35322 .6501 L .38433 .6532 L p .707 .577 .707 r
F P
0 g
s
.33177 .54188 m .32863 .59896 L .35611 .60264 L p .707 .577 .707 r
F P
0 g
s
.38141 .68833 m .38318 .66919 L .35206 .66606 L p .707 .577 .707 r
F P
0 g
s
.38318 .66919 m .38141 .68833 L .41307 .69113 L p .707 .577 .707 r
F P
0 g
s
.41307 .69113 m .41484 .67199 L .38318 .66919 L p .707 .577 .707 r
F P
0 g
s
.41946 .61763 m .41601 .65591 L .44514 .65795 L p .707 .577 .707 r
F P
0 g
s
.44514 .65795 m .44859 .61968 L .41946 .61763 L p .707 .577 .707 r
F P
0 g
s
.35206 .66606 m .35029 .68519 L .38141 .68833 L p .707 .577 .707 r
F P
0 g
s
.45147 .54935 m .44833 .60644 L .47227 .60489 L p .707 .577 .707 r
F P
0 g
s
.47227 .60489 m .47541 .5478 L .45147 .54935 L p .707 .577 .707 r
F P
0 g
s
.63819 .67579 m .64163 .63752 L .65766 .63772 L p .707 .577 .707 r
F P
0 g
s
.41484 .67199 m .41307 .69113 L .4422 .69332 L p .707 .577 .707 r
F P
0 g
s
.4422 .69332 m .44397 .67418 L .41484 .67199 L p .707 .577 .707 r
F P
0 g
s
.35322 .6501 m .35666 .61183 L .32915 .60864 L p .707 .577 .707 r
F P
0 g
s
.65766 .63772 m .65421 .67599 L .63819 .67579 L p .707 .577 .707 r
F P
0 g
s
.32915 .60864 m .3257 .64691 L .35322 .6501 L p .707 .577 .707 r
F P
0 g
s
.6352 .71156 m .63697 .69242 L .65297 .69283 L p .707 .577 .707 r
F P
0 g
s
.35029 .68519 m .35206 .66606 L .32455 .6629 L p .707 .577 .707 r
F P
0 g
s
.65297 .69283 m .6512 .71197 L .6352 .71156 L p .707 .577 .707 r
F P
0 g
s
.32455 .6629 m .32278 .68203 L .35029 .68519 L p .707 .577 .707 r
F P
0 g
s
.32863 .59896 m .33177 .54188 L .31065 .53751 L p .707 .577 .707 r
F P
0 g
s
.82592 .56889 m .82278 .62598 L .80167 .62161 L p .707 .577 .707 r
F P
0 g
s
.80167 .62161 m .80481 .56452 L .82592 .56889 L p .707 .577 .707 r
F P
0 g
s
.44859 .61968 m .44514 .65795 L .46889 .65913 L p .707 .577 .707 r
F P
0 g
s
.46889 .65913 m .47233 .62086 L .44859 .61968 L p .707 .577 .707 r
F P
0 g
s
.31065 .53751 m .30751 .5946 L .32863 .59896 L p .707 .577 .707 r
F P
0 g
s
.44397 .67418 m .4422 .69332 L .46592 .69469 L p .707 .577 .707 r
F P
0 g
s
.46592 .69469 m .46769 .67555 L .44397 .67418 L p .707 .577 .707 r
F P
0 g
s
.65803 .61569 m .66117 .5586 L .68511 .55705 L p .707 .577 .707 r
F P
0 g
s
.3257 .64691 m .32915 .60864 L .30794 .60566 L p .707 .577 .707 r
F P
0 g
s
.30794 .60566 m .30449 .64394 L .3257 .64691 L p .707 .577 .707 r
F P
0 g
s
.47541 .5478 m .47227 .60489 L .48851 .60206 L p .707 .577 .707 r
F P
0 g
s
.48851 .60206 m .49165 .54497 L .47541 .5478 L p .707 .577 .707 r
F P
0 g
s
.82205 .65292 m .8186 .69119 L .79739 .68822 L p .707 .577 .707 r
F P
0 g
s
.79739 .68822 m .80084 .64994 L .82205 .65292 L p .707 .577 .707 r
F P
0 g
s
.32278 .68203 m .32455 .6629 L .30332 .66002 L p .707 .577 .707 r
F P
0 g
s
.30332 .66002 m .30155 .67916 L .32278 .68203 L p .707 .577 .707 r
F P
0 g
s
.81734 .70837 m .81557 .7275 L .79435 .72463 L p .707 .577 .707 r
F P
0 g
s
.79435 .72463 m .79612 .70549 L .81734 .70837 L p .707 .577 .707 r
F P
0 g
s
.68511 .55705 m .68197 .61413 L .65803 .61569 L p .707 .577 .707 r
F P
0 g
s
.65421 .67599 m .65766 .63772 L .6814 .6389 L p .707 .577 .707 r
F P
0 g
s
.30751 .5946 m .31065 .53751 L .29797 .53288 L p .707 .577 .707 r
F P
0 g
s
.80481 .56452 m .80167 .62161 L .77419 .61794 L p .707 .577 .707 r
F P
0 g
s
.77419 .61794 m .77733 .56085 L .80481 .56452 L p .707 .577 .707 r
F P
0 g
s
.6814 .6389 m .67795 .67718 L .65421 .67599 L p .707 .577 .707 r
F P
0 g
s
.6512 .71197 m .65297 .69283 L .6767 .69421 L p .707 .577 .707 r
F P
0 g
s
.47233 .62086 m .46889 .65913 L .48491 .65934 L p .707 .577 .707 r
F P
0 g
s
.48491 .65934 m .48836 .62106 L .47233 .62086 L p .707 .577 .707 r
F P
0 g
s
.6767 .69421 m .67493 .71334 L .6512 .71197 L p .707 .577 .707 r
F P
0 g
s
.46769 .67555 m .46592 .69469 L .48192 .69511 L p .707 .577 .707 r
F P
0 g
s
.48192 .69511 m .48369 .67597 L .46769 .67555 L p .707 .577 .707 r
F P
0 g
s
.29797 .53288 m .29483 .58997 L .30751 .5946 L p .707 .577 .707 r
F P
0 g
s
.68197 .61413 m .68511 .55705 L .7144 .55692 L p .707 .577 .707 r
F P
0 g
s
.30449 .64394 m .30794 .60566 L .2951 .6032 L p .707 .577 .707 r
F P
0 g
s
.2951 .6032 m .29165 .64148 L .30449 .64394 L p .707 .577 .707 r
F P
0 g
s
.80084 .64994 m .79739 .68822 L .76988 .68502 L p .707 .577 .707 r
F P
0 g
s
.76988 .68502 m .77332 .64675 L .80084 .64994 L p .707 .577 .707 r
F P
0 g
s
.30155 .67916 m .30332 .66002 L .29047 .65771 L p .707 .577 .707 r
F P
0 g
s
.7144 .55692 m .71126 .61401 L .68197 .61413 L p .707 .577 .707 r
F P
0 g
s
.29047 .65771 m .2887 .67685 L .30155 .67916 L p .707 .577 .707 r
F P
0 g
s
.77733 .56085 m .77419 .61794 L .74304 .61532 L p .707 .577 .707 r
F P
0 g
s
.74304 .61532 m .74618 .55823 L .77733 .56085 L p .707 .577 .707 r
F P
0 g
s
.79612 .70549 m .79435 .72463 L .76683 .72147 L p .707 .577 .707 r
F P
0 g
s
.76683 .72147 m .7686 .70233 L .79612 .70549 L p .707 .577 .707 r
F P
0 g
s
.49165 .54497 m .48851 .60206 L .49547 .59824 L p .707 .577 .707 r
F P
0 g
s
.49547 .59824 m .49861 .54115 L .49165 .54497 L p .707 .577 .707 r
F P
0 g
s
.71126 .61401 m .7144 .55692 L .74618 .55823 L p .707 .577 .707 r
F P
0 g
s
.67795 .67718 m .6814 .6389 L .71053 .64095 L p .707 .577 .707 r
F P
0 g
s
.71053 .64095 m .70708 .67922 L .67795 .67718 L p .707 .577 .707 r
F P
0 g
s
.74618 .55823 m .74304 .61532 L .71126 .61401 L p .707 .577 .707 r
F P
0 g
s
.67493 .71334 m .6767 .69421 L .70582 .6964 L p .707 .577 .707 r
F P
0 g
s
.70582 .6964 m .70405 .71554 L .67493 .71334 L p .707 .577 .707 r
F P
0 g
s
.29483 .58997 m .29797 .53288 L .29496 .52843 L p .707 .577 .707 r
F P
0 g
s
.77332 .64675 m .76988 .68502 L .73876 .68192 L p .707 .577 .707 r
F P
0 g
s
.73876 .68192 m .74221 .64365 L .77332 .64675 L p .707 .577 .707 r
F P
0 g
s
.48836 .62106 m .48491 .65934 L .49164 .65855 L p .707 .577 .707 r
F P
0 g
s
.49164 .65855 m .49509 .62027 L .48836 .62106 L p .707 .577 .707 r
F P
0 g
s
.7686 .70233 m .76683 .72147 L .73571 .71834 L p .707 .577 .707 r
F P
0 g
s
.73571 .71834 m .73748 .6992 L .7686 .70233 L p .707 .577 .707 r
F P
0 g
s
.70708 .67922 m .71053 .64095 L .74221 .64365 L p .707 .577 .707 r
F P
0 g
s
.48369 .67597 m .48192 .69511 L .48864 .69452 L p .707 .577 .707 r
F P
0 g
s
.48864 .69452 m .49041 .67539 L .48369 .67597 L p .707 .577 .707 r
F P
0 g
s
.74221 .64365 m .73876 .68192 L .70708 .67922 L p .707 .577 .707 r
F P
0 g
s
.29496 .52843 m .29182 .58552 L .29483 .58997 L p .707 .577 .707 r
F P
0 g
s
.70405 .71554 m .70582 .6964 L .73748 .6992 L p .707 .577 .707 r
F P
0 g
s
.73748 .6992 m .73571 .71834 L .70405 .71554 L p .707 .577 .707 r
F P
0 g
s
.29165 .64148 m .2951 .6032 L .29189 .60149 L p .707 .577 .707 r
F P
0 g
s
.29189 .60149 m .28844 .63976 L .29165 .64148 L p .707 .577 .707 r
F P
0 g
s
.2887 .67685 m .29047 .65771 L .28724 .65619 L p .707 .577 .707 r
F P
0 g
s
.28724 .65619 m .28547 .67532 L .2887 .67685 L p .707 .577 .707 r
F P
0 g
s
.49861 .54115 m .49547 .59824 L .49245 .59379 L p .707 .577 .707 r
F P
0 g
s
.49245 .59379 m .49559 .53671 L .49861 .54115 L p .707 .577 .707 r
F P
0 g
s
.29182 .58552 m .29496 .52843 L .30192 .52461 L p .707 .577 .707 r
F P
0 g
s
.49509 .62027 m .49164 .65855 L .48843 .65684 L p .707 .577 .707 r
F P
0 g
s
.48843 .65684 m .49188 .61856 L .49509 .62027 L p .707 .577 .707 r
F P
0 g
s
.49041 .67539 m .48864 .69452 L .48541 .693 L p .707 .577 .707 r
F P
0 g
s
.48541 .693 m .48718 .67387 L .49041 .67539 L p .707 .577 .707 r
F P
0 g
s
.30192 .52461 m .29878 .5817 L .29182 .58552 L p .707 .577 .707 r
F P
0 g
s
.28844 .63976 m .29189 .60149 L .29862 .6007 L p .707 .577 .707 r
F P
0 g
s
.29862 .6007 m .29518 .63897 L .28844 .63976 L p .707 .577 .707 r
F P
0 g
s
.28547 .67532 m .28724 .65619 L .29396 .6556 L p .707 .577 .707 r
F P
0 g
s
.29396 .6556 m .29219 .67474 L .28547 .67532 L p .707 .577 .707 r
F P
0 g
s
.49559 .53671 m .49245 .59379 L .47977 .58916 L p .707 .577 .707 r
F P
0 g
s
.47977 .58916 m .48291 .53207 L .49559 .53671 L p .707 .577 .707 r
F P
0 g
s
.29878 .5817 m .30192 .52461 L .31816 .52178 L p .707 .577 .707 r
F P
0 g
s
.49188 .61856 m .48843 .65684 L .47559 .65437 L p .707 .577 .707 r
F P
0 g
s
.47559 .65437 m .47904 .6161 L .49188 .61856 L p .707 .577 .707 r
F P
0 g
s
.48718 .67387 m .48541 .693 L .47256 .69069 L p .707 .577 .707 r
F P
0 g
s
.47256 .69069 m .47433 .67155 L .48718 .67387 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31816 .52178 m .31502 .57887 L .29878 .5817 L p .707 .577 .707 r
F P
0 g
s
.29518 .63897 m .29862 .6007 L .31465 .60091 L p .707 .577 .707 r
F P
0 g
s
.31465 .60091 m .3112 .63918 L .29518 .63897 L p .707 .577 .707 r
F P
0 g
s
.29219 .67474 m .29396 .6556 L .30996 .65602 L p .707 .577 .707 r
F P
0 g
s
.30996 .65602 m .30819 .67516 L .29219 .67474 L p .707 .577 .707 r
F P
0 g
s
.48291 .53207 m .47977 .58916 L .45866 .58479 L p .707 .577 .707 r
F P
0 g
s
.45866 .58479 m .4618 .52771 L .48291 .53207 L p .707 .577 .707 r
F P
0 g
s
.31502 .57887 m .31816 .52178 L .3421 .52023 L p .707 .577 .707 r
F P
0 g
s
.47904 .6161 m .47559 .65437 L .45438 .6514 L p .707 .577 .707 r
F P
0 g
s
.45438 .6514 m .45783 .61313 L .47904 .6161 L p .707 .577 .707 r
F P
0 g
s
.47433 .67155 m .47256 .69069 L .45133 .68781 L p .707 .577 .707 r
F P
0 g
s
.45133 .68781 m .4531 .66868 L .47433 .67155 L p .707 .577 .707 r
F P
0 g
s
.3421 .52023 m .33896 .57732 L .31502 .57887 L p .707 .577 .707 r
F P
0 g
s
.3112 .63918 m .31465 .60091 L .33839 .60209 L p .707 .577 .707 r
F P
0 g
s
.4618 .52771 m .45866 .58479 L .43118 .58112 L p .707 .577 .707 r
F P
0 g
s
.43118 .58112 m .43432 .52403 L .4618 .52771 L p .707 .577 .707 r
F P
0 g
s
.33839 .60209 m .33494 .64036 L .3112 .63918 L p .707 .577 .707 r
F P
0 g
s
.30819 .67516 m .30996 .65602 L .33369 .65739 L p .707 .577 .707 r
F P
0 g
s
.33369 .65739 m .33192 .67653 L .30819 .67516 L p .707 .577 .707 r
F P
0 g
s
.33896 .57732 m .3421 .52023 L .37139 .5201 L p .707 .577 .707 r
F P
0 g
s
.45783 .61313 m .45438 .6514 L .42687 .64821 L p .707 .577 .707 r
F P
0 g
s
.42687 .64821 m .43031 .60993 L .45783 .61313 L p .707 .577 .707 r
F P
0 g
s
.37139 .5201 m .36825 .57719 L .33896 .57732 L p .707 .577 .707 r
F P
0 g
s
.43432 .52403 m .43118 .58112 L .40003 .5785 L p .707 .577 .707 r
F P
0 g
s
.40003 .5785 m .40317 .52141 L .43432 .52403 L p .707 .577 .707 r
F P
0 g
s
.4531 .66868 m .45133 .68781 L .42382 .68465 L p .707 .577 .707 r
F P
0 g
s
.42382 .68465 m .42559 .66552 L .4531 .66868 L p .707 .577 .707 r
F P
0 g
s
.36825 .57719 m .37139 .5201 L .40317 .52141 L p .707 .577 .707 r
F P
0 g
s
.33494 .64036 m .33839 .60209 L .36752 .60413 L p .707 .577 .707 r
F P
0 g
s
.36752 .60413 m .36407 .6424 L .33494 .64036 L p .707 .577 .707 r
F P
0 g
s
.40317 .52141 m .40003 .5785 L .36825 .57719 L p .707 .577 .707 r
F P
0 g
s
.33192 .67653 m .33369 .65739 L .36281 .65958 L p .707 .577 .707 r
F P
0 g
s
.36281 .65958 m .36104 .67872 L .33192 .67653 L p .707 .577 .707 r
F P
0 g
s
.43031 .60993 m .42687 .64821 L .39575 .64511 L p .707 .577 .707 r
F P
0 g
s
.39575 .64511 m .3992 .60683 L .43031 .60993 L p .707 .577 .707 r
F P
0 g
s
.42559 .66552 m .42382 .68465 L .3927 .68152 L p .707 .577 .707 r
F P
0 g
s
.3927 .68152 m .39447 .66238 L .42559 .66552 L p .707 .577 .707 r
F P
0 g
s
.36407 .6424 m .36752 .60413 L .3992 .60683 L p .707 .577 .707 r
F P
0 g
s
.3992 .60683 m .39575 .64511 L .36407 .6424 L p .707 .577 .707 r
F P
0 g
s
.36104 .67872 m .36281 .65958 L .39447 .66238 L p .707 .577 .707 r
F P
0 g
s
.39447 .66238 m .3927 .68152 L .36104 .67872 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001lOolB002?Ool007Ioo`H0009JEP03001JEUYF
00eJEPH008Uoo`00LGoo1@0025YF00<005YFFUH04eYF0`00QWoo001^Ool300000eYF001JEP0:FUH0
0`00FUIJEP0FFUH20024Ool006]oo`<000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00YJEP80089oo`00J7oo0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH035YF0P00
P7oo001VOol2000;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH2001nOol006Aoo`<000aJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001oogoo07]oo`00HWoo0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<007ooOol0NWoo001POol20004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomo
o`1jOol005ioo`8000MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP0007]oo`00G7oo0P002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH007Yoo`00Fgoo0P00
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0007Uoo`00FWoo00<005YF00002UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYFNGoo001IOol01000
FUIJEP002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0MWoo001IOol01@00FUIJEUYF00002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
FUH00UYF00<007ooOol0MWoo001HOol00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`1fOol005Moo`03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001hOol005Io
o`03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001gOol005Ioo`03001JEUYF00AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYFFUH2001gOol005Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2
001gOol005Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001gOol005Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo07Eoo`00EGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH015YF00<005YFFUH00UYF0P00MWoo001DOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
FUH00UYF0P00MWoo001DOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8007Ioo`00
E7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001fOol005Aoo`04001JEUYF0006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF0P00MWoo001DOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00@005YFFUIJEP8007Ioo`00EGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH2001f
Ool005Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001eOol005Eoo`04001JEUYF0006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00MGoo001EOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUIJEP8007Eoo`00EGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001eOol005Eo
o`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEUYF0P00MGoo001EOol01000FUIJEP001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00@005YFFUIJEP8007Eoo`00EWoo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03
001JEUYF009JEP8007Aoo`00EWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP80
07Aoo`00EWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001dOol005Ioo`04001J
EUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00M7oo001FOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8007Aoo`00EWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH2001dOol005Ioo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEUYF0P00M7oo001GOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0LWoo001GOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00Lgoo001GOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH015YF00<005YFFUH00UYF0P00Lgoo001GOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8007=oo`00Egoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001cOol005Mo
o`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Lgoo001GOol01000FUIJEP001eYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0LGoo001GOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00UYF00<007ooOol0LGoo001HOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF0P00LWoo001HOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF0P00LWoo001HOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80079oo`00F7oo
00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001bOol005Qoo`04001JEUYF0007FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00LWoo001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF00<007ooOol0L7oo001HOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF00<007ooOol0L7oo001IOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00
LGoo001IOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00LGoo001IOol01000
FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80075oo`00FGoo00@005YFFUH000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001aOol005Uoo`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00LGoo001IOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
Kgoo001IOol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0Kgoo001I
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00L7oo001JOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00L7oo001JOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH015YF00<005YFFUH00UYF0P00L7oo001JOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP80071oo`00FWoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH2001`Ool005Yo
o`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yoo`04001J
EUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool005Yoo`04001JEUYFFUH@0000
0eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH2001_Ool005Qoo`H000=JEP03001JEUYF00EJEP03001JEUYF009JEPT000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP80
06moo`00EGoo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF20002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006mo
o`00Dgoo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH2001_Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000]JEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001oogoo06eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000000UJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo06eoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0025YF00<005YFFUH025YF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0KGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020008FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001^Ool005=o
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP8006ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0025YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006ioo`00Dgoo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P002EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP80
06ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Goo7P00AGoo001BOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002EYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH0
0UYF00<007ooOol01Woo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPP003eoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0009FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`04Ool30003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1`00=Woo001BOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000UJEP03001JEUYF00QJEP03001JEUYF
00AJEP03001JEUYF009JEP8000Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@0039oo`00DWoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00UYF0P001Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<7oo001BOol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol00`00FUH0
0002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEUYF0P001Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00DWoo00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF1`000eYF00<005YFFUH00P002eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol00goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH0000000]JEP03001JEUYF00QJEP03001J
EUYF00AJEP03001JEUYF009JEP03001oogoo00=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
000]Ool005Aoo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00Oomoo`02Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00;Goo001FOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`002eYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P000goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00
E7oo3@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool0059oo`<000AJEP04001JEUYF
FUH@00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000goo00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00L005YFFUIJEP00FUH0000]Ool0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEQ`000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP07001oogooOol005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DWoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
200000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF00L007ooOomoo`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF
00L007ooOomoo`00FUH00004FUH01000FUIJEUYF6@0015YF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0200035YF00<005YFFUH025YF
00<005YFFUH015YF00<005YFFUH00UYF00H007ooOomoo`00FUH90007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000aOolO0002Ool20004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH20002Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Woo000^Ool30002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000<FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH2000^Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003Ool200000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00=oo`@000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Moo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF2P000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUH0
05YF008000aJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo01L000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002moo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P00
0UYF00<005YFFUH00eYF400015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00H0
07ooOol005YF0003FUH00`00FUIJEP04FUH01000FUIJEUYF9@00<goo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH<0004FUH00`00FUIJ
EP05FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF4@00?Woo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0:
0004FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000017oo001JEP000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Moo`00;7oo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEPT000AJEP03001JEUYF00AJEPL000=JEP03
001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001oo`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000bOol002]oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEQ<000MJEP03001JEUYF00AJEPP000AJEP03
001JEUYF00=JEPP00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP05001oo`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF009JEPT000UJEP03001JEUYF009JEQ80009JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF009JEPP00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH80006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF30001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00:goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP8002ioo`00:goo00<005YF00000UYF7`000UYF0`0000=JEP0000002`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF00=JEQ4000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002]o
o`03001JEP0000<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEQ0000=JEQ80
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000050003FUH00`00FUIJEP03FUHB
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60002
FUH90004FUH00`00FUH0000400000eYF000000060004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00EJEPL000=JEP03001JEUYF00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000_Ool002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF2`000UYF00<005YFFUH0
15YF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF00<005YF
FUH015YF1`000eYF00@005YFFUIJEP8002moo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000UYF
00<005YFFUH01EYF00<005YF00002P0015YF00<005YFFUH00eYF1@0000=JEP00000015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000EJEP03001J
EUYF00AJEP04001JEUYFFUH200000goo0000000@0004FUH00`00FUIJEP02FUH50002FUH2000_Ool0
02moo`@000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00<000AJEP03001JEUYF0180
009JEQ8000QJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH0000000/000=JEP8001=ooa80
02moo`00<goo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH03UYF1P001UYF0P00
1EYF00<005YFFUH00UYF1P000UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00000eYF00<0
05YFFUH015YF00@005YFFUIJEQ8004Moo`00>Woo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00UJ
EPD000aJEP8000EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF009JEP8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003moo`00@goo8000
0UYF00<005YFFUH01EYF00<005YFFUH03eYF0`000eYF0P0035YF00<005YFFUH015YF00<005YFFUH0
2eYF0P001EYF00H005YFFUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1`00>7oo000]Ool9000/Ool01000FUIJEP001eYF00<005YF
FUH035YF0`001eYF00<005YFFUH02UYF00<005YFFUH015YF00<005YFFUH035YF0`000eYF00H005YF
FUH005YF0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05000cOol002]oo`<000AJEP04001JEUYFFUH@000LOol01000FUIJ
EP001eYF00<005YFFUH02EYF0`002UYF00<005YFFUH02UYF00<005YFFUH00eYF2P001UYF00<005YF
FUH00P0000AJEP00FUIJEQ8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP000080031oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@004goo00@005YFFUH000MJEP03001JEUYF00MJEP800003FUH005YF
00YJEP03001JEUYF00YJEP03001JEUYF00<000IJEP8000QJEP03001JEUYF009JEP8000AJEPH000=J
EP03001JEUYF00AJEPT000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF0080031oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF20002goo00@005YFFUH000MJEP03001JEUYF00EJEP8000=JEP03001JEUYF
00UJEP03001JEUYF00YJEP8000YJEP8000QJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH80004
FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00<7oo
000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`0017oo0P000UYF00<005YFFUH02UYF0P001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF0P002eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000eYF00<005YF
FUH00UYF2`0015YF00<005YFFUH03@0015YF00<005YFFUH00eYF00@005YFFUIJEP80031oo`00:goo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01P000UYF00<005YFFUH025YF0P001eYF00<005YFFUH02EYF0P00
2eYF0P002eYF00<005YFFUH01eYF00<005YFFUH015YF0P000UYF00D005YFFUIJEP0000IJEP@0009J
EP800003Ool0000000X00003FUH005YF00EJEP`0009JEP80031oo`00:goo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`000UYF00<005YFFUH01UYF0P002EYF00<005YFFUH02EYF0P0035YF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH4
0009OolA0003FUH01000FUIJEUYF1000<7oo000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP05FUH00`00FUH00009FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH0000JOol:000aOol002]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF
00AJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01000EWoo
000[Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0000=JEP04001JEUYFFUH6001JOol002]oo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEP00009JEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH8001P
Ool002]oo`X000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00IJEP03001JEWoo00EJEP04001JEUYF001WOol0
02]oo`80009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP8000]JEP03001JEUYF00MJEP03001ooeYF00AJEP05001JEUYFFUH0001VOol002eoo`D0
00=JEP03001JEUYF00EJEP03001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00UJEP8000aJEP03001J
EUYF00UJEP03001JEUYF00MJEP8000EJEP05001JEUYFFUH0001VOol0039ooa0000AJEP03001JEUYF
00EJEPP000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00MJEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYFFUH9001NOol0049oo`T000AJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP05001IOol004]oo`P000AJ
EP03001JEUYF00=JEPP00005FUH005YFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF
00<005YFFUH00eYF00<005YF00000`00EGoo001COolB00001EYF001JEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00B7oo0`006Goo0`000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
05Eoo`00Agoo1@006Goo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF0P002eYF00<005YFFUH01eYF00<005YFFUH015YF0P001eYF00<005YFFUH00eYF00@0
05YFFUIJEP8005Eoo`00Agoo1@006Goo00D005YFFUIJEP0000QJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP8000]JEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF
00AJEP04001JEUYFFUH2001EOol002Yooa8000]oo`D001Uoo`03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8005Eoo`00:Woo00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH00UYF2@000goo0`006Woo00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH00UYF200067oo00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P00
1eYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00:Woo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPl000Uoo`8000]JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF009JEPH0
00AJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol002Yoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00D0
00Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P00EWoo000ZOol:
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH0000300000goo001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH50002FUH2001FOol002]oo`H000=JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH200000goo001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH2000;FUH00`00FUIJEP09FUHC00000eYF00000002001FOol0035oo`L000AJEP03
001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002Ool00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00Oomoo`0AOol4001GOol003Qoo`T000AJEP03001JEUYF00EJEPP000AJEP03001J
EUYF00=JEP03001JEUYF008000Aoo`03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00UJEP80
00aJEP03001JEUYF00UJEP03001JEUYF00AJEP@006moo`00@Goo2@0015YF00<005YFFUH015YF1`00
0eYF00<005YFFUH00P0017oo00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH03eYF1@00Kgoo001:Ool@0002FUH80005Ool00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH5001_Ool0
05Yoo`X000Ioo`03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00L006moo`00Jgoo00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF2`00KWoo001/Ool2000@FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH20005FUH00`00FUIJEP02FUH8001VOol006ioo`8000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00EJEP<000MJEP03001JEUYF
00IJEP04001JEUYFFUH7001OOol0071oo`80009JEP03001JEUYF025JEP03001JEUYF009JEP<00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00L005Qoo`00LWoo0`002UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00Egoo001dOol30008FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH50003FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02001GOol007Moo`H0009JEP03001JEUYF00UJEP04001JEUYFFUH;0004FUH0
0`00FUIJEP05FUH@0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Egoo001mOolB000;Ool80004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P00Egoo002ROolB0004FUH0
0`00FUIJEP02FUH50002FUH2001GOol00;Aooa8005Moo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]1\[InvisibleSpace]"     "\
\[InvisibleSpace]1.3573695695536339`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 1, "     ", 1.3573695695536339, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58736 .74927 m .59521 .69513 L .56435 .68881 L p .707 .577 .707 r
F P
0 g
s
.59521 .69513 m .58736 .74927 L .61891 .75248 L p .707 .577 .707 r
F P
0 g
s
.61891 .75248 m .62676 .69834 L .59521 .69513 L p .707 .577 .707 r
F P
0 g
s
.62676 .69834 m .61891 .75248 L .64807 .75227 L p .707 .577 .707 r
F P
0 g
s
.64807 .75227 m .65591 .69813 L .62676 .69834 L p .707 .577 .707 r
F P
0 g
s
.5565 .74295 m .56435 .68881 L .53721 .67999 L p .707 .577 .707 r
F P
0 g
s
.56435 .68881 m .5565 .74295 L .58736 .74927 L p .707 .577 .707 r
F P
0 g
s
.65591 .69813 m .64807 .75227 L .67197 .74865 L p .707 .577 .707 r
F P
0 g
s
.67197 .74865 m .67982 .69451 L .65591 .69813 L p .707 .577 .707 r
F P
0 g
s
.52936 .73413 m .53721 .67999 L .51644 .66955 L p .707 .577 .707 r
F P
0 g
s
.53721 .67999 m .52936 .73413 L .5565 .74295 L p .707 .577 .707 r
F P
0 g
s
.5778 .80596 m .58642 .77093 L .55612 .76178 L p .707 .577 .707 r
F P
0 g
s
.58642 .77093 m .5778 .80596 L .60886 .81173 L p .707 .577 .707 r
F P
0 g
s
.60886 .81173 m .61748 .77669 L .58642 .77093 L p .707 .577 .707 r
F P
0 g
s
.5475 .79682 m .55612 .76178 L .52953 .75014 L p .707 .577 .707 r
F P
0 g
s
.55612 .76178 m .5475 .79682 L .5778 .80596 L p .707 .577 .707 r
F P
0 g
s
.61748 .77669 m .60886 .81173 L .63762 .81354 L p .707 .577 .707 r
F P
0 g
s
.63762 .81354 m .64624 .7785 L .61748 .77669 L p .707 .577 .707 r
F P
0 g
s
.67982 .69451 m .67197 .74865 L .68829 .74198 L p .707 .577 .707 r
F P
0 g
s
.68829 .74198 m .69614 .68784 L .67982 .69451 L p .707 .577 .707 r
F P
0 g
s
.51644 .66955 m .50859 .72369 L .52936 .73413 L p .707 .577 .707 r
F P
0 g
s
.50859 .72369 m .51644 .66955 L .50407 .6585 L p .707 .577 .707 r
F P
0 g
s
.52953 .75014 m .52091 .78517 L .5475 .79682 L p .707 .577 .707 r
F P
0 g
s
.52091 .78517 m .52953 .75014 L .50925 .73715 L p .707 .577 .707 r
F P
0 g
s
.64624 .7785 m .63762 .81354 L .66127 .81122 L p .707 .577 .707 r
F P
0 g
s
.66127 .81122 m .66989 .77619 L .64624 .7785 L p .707 .577 .707 r
F P
0 g
s
.57028 .83908 m .57471 .82161 L .54445 .81227 L p .707 .577 .707 r
F P
0 g
s
.57471 .82161 m .57028 .83908 L .6013 .84502 L p .707 .577 .707 r
F P
0 g
s
.6013 .84502 m .60572 .82754 L .57471 .82161 L p .707 .577 .707 r
F P
0 g
s
.54003 .82974 m .54445 .81227 L .51791 .80043 L p .707 .577 .707 r
F P
0 g
s
.54445 .81227 m .54003 .82974 L .57028 .83908 L p .707 .577 .707 r
F P
0 g
s
.60572 .82754 m .6013 .84502 L .63002 .84696 L p .707 .577 .707 r
F P
0 g
s
.63002 .84696 m .63445 .82949 L .60572 .82754 L p .707 .577 .707 r
F P
0 g
s
.51791 .80043 m .51348 .81791 L .54003 .82974 L p .707 .577 .707 r
F P
0 g
s
.50925 .73715 m .50063 .77218 L .52091 .78517 L p .707 .577 .707 r
F P
0 g
s
.50407 .6585 m .49623 .71264 L .50859 .72369 L p .707 .577 .707 r
F P
0 g
s
.51348 .81791 m .51791 .80043 L .49768 .78727 L p .707 .577 .707 r
F P
0 g
s
.63445 .82949 m .63002 .84696 L .65366 .84473 L p .707 .577 .707 r
F P
0 g
s
.65366 .84473 m .65808 .82726 L .63445 .82949 L p .707 .577 .707 r
F P
0 g
s
.50063 .77218 m .50925 .73715 L .49728 .72407 L p .707 .577 .707 r
F P
0 g
s
.69614 .68784 m .68829 .74198 L .69543 .73292 L p .707 .577 .707 r
F P
0 g
s
.69543 .73292 m .70327 .67878 L .69614 .68784 L p .707 .577 .707 r
F P
0 g
s
.66989 .77619 m .66127 .81122 L .67751 .805 L p .707 .577 .707 r
F P
0 g
s
.67751 .805 m .68613 .76997 L .66989 .77619 L p .707 .577 .707 r
F P
0 g
s
.49768 .78727 m .49325 .80474 L .51348 .81791 L p .707 .577 .707 r
F P
0 g
s
.49623 .71264 m .50407 .6585 L .50132 .64793 L p .707 .577 .707 r
F P
0 g
s
.49728 .72407 m .48866 .75911 L .50063 .77218 L p .707 .577 .707 r
F P
0 g
s
.49325 .80474 m .49768 .78727 L .48574 .77406 L p .707 .577 .707 r
F P
0 g
s
.65808 .82726 m .65366 .84473 L .66988 .83854 L p .707 .577 .707 r
F P
0 g
s
.66988 .83854 m .67431 .82107 L .65808 .82726 L p .707 .577 .707 r
F P
0 g
s
.50132 .64793 m .49347 .70207 L .49623 .71264 L p .707 .577 .707 r
F P
0 g
s
.48574 .77406 m .48132 .79153 L .49325 .80474 L p .707 .577 .707 r
F P
0 g
s
.48866 .75911 m .49728 .72407 L .49478 .7122 L p .707 .577 .707 r
F P
0 g
s
.68613 .76997 m .67751 .805 L .68473 .79549 L p .707 .577 .707 r
F P
0 g
s
.68473 .79549 m .69335 .76045 L .68613 .76997 L p .707 .577 .707 r
F P
0 g
s
.70327 .67878 m .69543 .73292 L .69267 .72234 L p .707 .577 .707 r
F P
0 g
s
.69267 .72234 m .70052 .6682 L .70327 .67878 L p .707 .577 .707 r
F P
0 g
s
.49347 .70207 m .50132 .64793 L .50845 .63886 L p .707 .577 .707 r
F P
0 g
s
.49478 .7122 m .48616 .74723 L .48866 .75911 L p .707 .577 .707 r
F P
0 g
s
.48132 .79153 m .48574 .77406 L .48327 .7621 L p .707 .577 .707 r
F P
0 g
s
.67431 .82107 m .66988 .83854 L .67711 .829 L p .707 .577 .707 r
F P
0 g
s
.67711 .829 m .68153 .81153 L .67431 .82107 L p .707 .577 .707 r
F P
0 g
s
.48327 .7621 m .47884 .77957 L .48132 .79153 L p .707 .577 .707 r
F P
0 g
s
.50845 .63886 m .50061 .693 L .49347 .70207 L p .707 .577 .707 r
F P
0 g
s
.48616 .74723 m .49478 .7122 L .50201 .70269 L p .707 .577 .707 r
F P
0 g
s
.69335 .76045 m .68473 .79549 L .68223 .78361 L p .707 .577 .707 r
F P
0 g
s
.68223 .78361 m .69085 .74858 L .69335 .76045 L p .707 .577 .707 r
F P
0 g
s
.70052 .6682 m .69267 .72234 L .68031 .71129 L p .707 .577 .707 r
F P
0 g
s
.68031 .71129 m .68816 .65715 L .70052 .6682 L p .707 .577 .707 r
F P
0 g
s
.50061 .693 m .50845 .63886 L .52477 .6322 L p .707 .577 .707 r
F P
0 g
s
.50201 .70269 m .49338 .73772 L .48616 .74723 L p .707 .577 .707 r
F P
0 g
s
.24435 .71934 m .2522 .66519 L .22134 .65887 L p .707 .577 .707 r
F P
0 g
s
.2522 .66519 m .24435 .71934 L .2759 .72255 L p .707 .577 .707 r
F P
0 g
s
.2759 .72255 m .28375 .66841 L .2522 .66519 L p .707 .577 .707 r
F P
0 g
s
.28375 .66841 m .2759 .72255 L .30506 .72233 L p .707 .577 .707 r
F P
0 g
s
.30506 .72233 m .3129 .66819 L .28375 .66841 L p .707 .577 .707 r
F P
0 g
s
.47884 .77957 m .48327 .7621 L .49049 .75255 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21349 .71301 m .22134 .65887 L .1942 .65006 L p .707 .577 .707 r
F P
0 g
s
.22134 .65887 m .21349 .71301 L .24435 .71934 L p .707 .577 .707 r
F P
0 g
s
.68153 .81153 m .67711 .829 L .67463 .81704 L p .707 .577 .707 r
F P
0 g
s
.67463 .81704 m .67906 .79956 L .68153 .81153 L p .707 .577 .707 r
F P
0 g
s
.49049 .75255 m .48607 .77003 L .47884 .77957 L p .707 .577 .707 r
F P
0 g
s
.52477 .6322 m .51693 .68634 L .50061 .693 L p .707 .577 .707 r
F P
0 g
s
.49338 .73772 m .50201 .70269 L .51824 .69647 L p .707 .577 .707 r
F P
0 g
s
.69085 .74858 m .68223 .78361 L .67026 .77054 L p .707 .577 .707 r
F P
0 g
s
.67026 .77054 m .67888 .73551 L .69085 .74858 L p .707 .577 .707 r
F P
0 g
s
.3129 .66819 m .30506 .72233 L .32896 .71872 L p .707 .577 .707 r
F P
0 g
s
.32896 .71872 m .33681 .66458 L .3129 .66819 L p .707 .577 .707 r
F P
0 g
s
.68816 .65715 m .68031 .71129 L .65954 .70085 L p .707 .577 .707 r
F P
0 g
s
.65954 .70085 m .66739 .64671 L .68816 .65715 L p .707 .577 .707 r
F P
0 g
s
.18635 .7042 m .1942 .65006 L .17343 .63962 L p .707 .577 .707 r
F P
0 g
s
.1942 .65006 m .18635 .7042 L .21349 .71301 L p .707 .577 .707 r
F P
0 g
s
.51693 .68634 m .52477 .6322 L .54868 .62858 L p .707 .577 .707 r
F P
0 g
s
.48636 .79528 m .33468 .30242 L .29276 .31343 L p .707 .577 .707 r
F P
0 g
s
.51824 .69647 m .50962 .7315 L .49338 .73772 L p .707 .577 .707 r
F P
0 g
s
.48607 .77003 m .49049 .75255 L .50672 .74636 L p .707 .577 .707 r
F P
0 g
s
.50672 .74636 m .50229 .76384 L .48607 .77003 L p .707 .577 .707 r
F P
0 g
s
.50229 .76384 m .50672 .74636 L .53035 .74413 L p .707 .577 .707 r
F P
0 g
s
.53035 .74413 m .52592 .76161 L .50229 .76384 L p .707 .577 .707 r
F P
0 g
s
.33468 .30242 m .48636 .79528 L .52942 .78183 L p .707 .577 .707 r
F P
0 g
s
.50962 .7315 m .51824 .69647 L .54189 .69415 L p .707 .577 .707 r
F P
0 g
s
.54189 .69415 m .53327 .72918 L .50962 .7315 L p .707 .577 .707 r
F P
0 g
s
.52942 .78183 m .37774 .28898 L .33468 .30242 L p .707 .577 .707 r
F P
0 g
s
.23479 .78659 m .24342 .75156 L .21311 .74241 L p .707 .577 .707 r
F P
0 g
s
.24342 .75156 m .23479 .78659 L .26585 .79235 L p .707 .577 .707 r
F P
0 g
s
.26585 .79235 m .27447 .75732 L .24342 .75156 L p .707 .577 .707 r
F P
0 g
s
.54868 .62858 m .54083 .68272 L .51693 .68634 L p .707 .577 .707 r
F P
0 g
s
.53327 .72918 m .54189 .69415 L .57065 .69596 L p .707 .577 .707 r
F P
0 g
s
.57065 .69596 m .56203 .73099 L .53327 .72918 L p .707 .577 .707 r
F P
0 g
s
.52592 .76161 m .53035 .74413 L .55908 .74608 L p .707 .577 .707 r
F P
0 g
s
.55908 .74608 m .55465 .76356 L .52592 .76161 L p .707 .577 .707 r
F P
0 g
s
.55465 .76356 m .55908 .74608 L .59009 .75202 L p .707 .577 .707 r
F P
0 g
s
.59009 .75202 m .58566 .76949 L .55465 .76356 L p .707 .577 .707 r
F P
0 g
s
.37774 .28898 m .52942 .78183 L .56941 .76726 L p .707 .577 .707 r
F P
0 g
s
.54083 .68272 m .54868 .62858 L .57784 .62836 L p .707 .577 .707 r
F P
0 g
s
.57784 .62836 m .56999 .68251 L .54083 .68272 L p .707 .577 .707 r
F P
0 g
s
.56941 .76726 m .41773 .27441 L .37774 .28898 L p .707 .577 .707 r
F P
0 g
s
.20449 .77744 m .21311 .74241 L .18652 .73077 L p .707 .577 .707 r
F P
0 g
s
.21311 .74241 m .20449 .77744 L .23479 .78659 L p .707 .577 .707 r
F P
0 g
s
.27447 .75732 m .26585 .79235 L .29461 .79416 L p .707 .577 .707 r
F P
0 g
s
.29461 .79416 m .30323 .75913 L .27447 .75732 L p .707 .577 .707 r
F P
0 g
s
.67906 .79956 m .67463 .81704 L .66269 .80383 L p .707 .577 .707 r
F P
0 g
s
.66269 .80383 m .66712 .78635 L .67906 .79956 L p .707 .577 .707 r
F P
0 g
s
.33681 .66458 m .32896 .71872 L .34528 .71205 L p .707 .577 .707 r
F P
0 g
s
.34528 .71205 m .35313 .65791 L .33681 .66458 L p .707 .577 .707 r
F P
0 g
s
.17343 .63962 m .16558 .69376 L .18635 .7042 L p .707 .577 .707 r
F P
0 g
s
.44444 .80629 m .29276 .31343 L .25608 .32092 L p .707 .577 .707 r
F P
0 g
s
.29276 .31343 m .44444 .80629 L .48636 .79528 L p .707 .577 .707 r
F P
0 g
s
.66739 .64671 m .65954 .70085 L .6324 .69204 L p .707 .577 .707 r
F P
0 g
s
.6324 .69204 m .64024 .6379 L .66739 .64671 L p .707 .577 .707 r
F P
0 g
s
.16558 .69376 m .17343 .63962 L .16106 .62857 L p .707 .577 .707 r
F P
0 g
s
.56999 .68251 m .57784 .62836 L .60939 .63158 L p .707 .577 .707 r
F P
0 g
s
.60939 .63158 m .60154 .68572 L .56999 .68251 L p .707 .577 .707 r
F P
0 g
s
.56203 .73099 m .57065 .69596 L .60171 .70172 L p .707 .577 .707 r
F P
0 g
s
.63201 .71087 m .62339 .74591 L .59309 .73676 L p .707 .577 .707 r
F P
0 g
s
.59309 .73676 m .60171 .70172 L .63201 .71087 L p .707 .577 .707 r
F P
0 g
s
.60171 .70172 m .59309 .73676 L .56203 .73099 L p .707 .577 .707 r
F P
0 g
s
.58566 .76949 m .59009 .75202 L .62035 .76136 L p .707 .577 .707 r
F P
0 g
s
.41773 .27441 m .56941 .76726 L .60241 .753 L p .707 .577 .707 r
F P
0 g
s
.60241 .753 m .45073 .26014 L .41773 .27441 L p .707 .577 .707 r
F P
0 g
s
.67888 .73551 m .67026 .77054 L .64998 .75755 L p .707 .577 .707 r
F P
0 g
s
.64998 .75755 m .6586 .72251 L .67888 .73551 L p .707 .577 .707 r
F P
0 g
s
.18652 .73077 m .1779 .7658 L .20449 .77744 L p .707 .577 .707 r
F P
0 g
s
.1779 .7658 m .18652 .73077 L .16625 .71777 L p .707 .577 .707 r
F P
0 g
s
.30323 .75913 m .29461 .79416 L .31826 .79185 L p .707 .577 .707 r
F P
0 g
s
.31826 .79185 m .32689 .75681 L .30323 .75913 L p .707 .577 .707 r
F P
0 g
s
.22728 .83644 m .2317 .81897 L .20144 .80963 L p .707 .577 .707 r
F P
0 g
s
.2317 .81897 m .22728 .83644 L .25829 .84237 L p .707 .577 .707 r
F P
0 g
s
.25829 .84237 m .26271 .8249 L .2317 .81897 L p .707 .577 .707 r
F P
0 g
s
.64024 .6379 m .6324 .69204 L .60154 .68572 L p .707 .577 .707 r
F P
0 g
s
.60154 .68572 m .60939 .63158 L .64024 .6379 L p .707 .577 .707 r
F P
0 g
s
.19702 .8271 m .20144 .80963 L .1749 .79779 L p .707 .577 .707 r
F P
0 g
s
.20144 .80963 m .19702 .8271 L .22728 .83644 L p .707 .577 .707 r
F P
0 g
s
.26271 .8249 m .25829 .84237 L .28701 .84432 L p .707 .577 .707 r
F P
0 g
s
.28701 .84432 m .29144 .82685 L .26271 .8249 L p .707 .577 .707 r
F P
0 g
s
.16625 .71777 m .15762 .75281 L .1779 .7658 L p .707 .577 .707 r
F P
0 g
s
.16106 .62857 m .15322 .68271 L .16558 .69376 L p .707 .577 .707 r
F P
0 g
s
.1749 .79779 m .17047 .81527 L .19702 .8271 L p .707 .577 .707 r
F P
0 g
s
.66712 .78635 m .66269 .80383 L .64246 .79066 L p .707 .577 .707 r
F P
0 g
s
.64246 .79066 m .64689 .77319 L .66712 .78635 L p .707 .577 .707 r
F P
0 g
s
.35313 .65791 m .34528 .71205 L .35242 .70298 L p .707 .577 .707 r
F P
0 g
s
.35242 .70298 m .36026 .64884 L .35313 .65791 L p .707 .577 .707 r
F P
0 g
s
.36026 .64884 m .35242 .70298 L .35051 .69565 L p .707 .577 .707 r
F P
0 g
s
.35051 .69565 m .34967 .69241 L p .35352 .67658 L .707 .577 .707 r
F P
0 g
s
.35352 .67658 m .36026 .64884 L .35051 .69565 L .707 .577 .707 r
F
.40777 .81377 m .44444 .80629 L p .36524 .6022 L F P
0 g
s
.25608 .32092 m .35759 .65074 L p .36524 .6022 L .707 .577 .707 r
F P
0 g
s
.34967 .69241 m .35066 .68552 L p .36026 .64884 L .707 .577 .707 r
F P
0 g
s
.25608 .32092 m .22824 .32415 L p .35421 .66771 L .707 .577 .707 r
F P
0 g
s
.35759 .65074 m .25608 .32092 L p .35421 .66771 L .707 .577 .707 r
F P
0 g
s
.35896 .64384 m .36026 .64884 L p .35066 .68552 L .707 .577 .707 r
F P
0 g
s
.37992 .81701 m .40777 .81377 L p .35647 .67388 L .707 .577 .707 r
F P
0 g
s
.22824 .32415 m .34373 .69941 L p .35647 .67388 L .707 .577 .707 r
F P
0 g
s
.35066 .68552 m .34967 .69241 L .34798 .6909 L p .707 .577 .707 r
F P
0 g
s
.34373 .69941 m .37992 .81701 L p .35647 .67388 L .707 .577 .707 r
F P
0 g
s
.22824 .32415 m .21196 .32282 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.37992 .81701 m .35286 .72909 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.35286 .72909 m .22824 .32415 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.32443 .67489 m .31976 .67254 L p .31976 .66599 L .707 .577 .707 r
F P
0 g
s
.31976 .67254 m .31653 .67092 L p .31835 .66813 L .707 .577 .707 r
F P
0 g
s
.31835 .66813 m .31976 .66599 L .31976 .67254 L .707 .577 .707 r
F
.21196 .32282 m .20883 .31705 L p .29592 .59756 L F P
0 g
s
.34172 .77611 m .35034 .74108 L .34312 .75059 L p .707 .577 .707 r
F P
0 g
s
.3345 .78563 m .34312 .75059 L .32689 .75681 L p .707 .577 .707 r
F P
0 g
s
.34312 .75059 m .3345 .78563 L .34172 .77611 L p .707 .577 .707 r
F P
0 g
s
.35034 .74108 m .34172 .77611 L .33922 .76424 L p .707 .577 .707 r
F P
0 g
s
.33922 .76424 m .34784 .72921 L .35034 .74108 L p .707 .577 .707 r
F P
0 g
s
.33922 .76424 m .32725 .75117 L p .34051 .73703 L .707 .577 .707 r
F P
0 g
s
.34784 .72921 m .34363 .7463 L p .34051 .73703 L .707 .577 .707 r
F P
0 g
s
.34363 .7463 m .33922 .76424 L p .34051 .73703 L .707 .577 .707 r
F P
0 g
s
.31835 .66813 m .31779 .66224 L .31976 .66599 L .707 .577 .707 r
F
.31653 .67092 m .31738 .66506 L p .31835 .66813 L F P
0 g
s
.31738 .66506 m .31779 .66224 L p .31835 .66813 L .707 .577 .707 r
F P
0 g
s
.32725 .75117 m .33587 .71613 L .34784 .72921 L p .707 .577 .707 r
F P
0 g
s
.31653 .67092 m .28939 .6621 L p .30869 .63709 L .707 .577 .707 r
F P
0 g
s
.30869 .63709 m .30954 .63981 L .31653 .67092 L .707 .577 .707 r
F
.31779 .66224 m .31653 .67092 L p .30887 .63686 L F P
0 g
s
.30669 .63064 m .21196 .32282 L p .26425 .49393 L .707 .577 .707 r
F P
0 g
s
.21196 .32282 m .30669 .63064 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.34484 .7138 m .30669 .63064 L .31779 .66224 L .707 .577 .707 r
F
.28939 .6621 m .29723 .60796 L .32438 .61678 L p F P
0 g
s
.31447 .65591 m .30669 .63064 L p .29592 .59756 L .707 .577 .707 r
F P
0 g
s
.30669 .63064 m .26425 .49393 L .29592 .59756 L .707 .577 .707 r
F
.30869 .63709 m .30887 .63686 L .30954 .63981 L F
.32438 .61678 m .31779 .66224 L p .30887 .63686 L F P
0 g
s
.30669 .63064 m .31447 .65591 L p .31779 .66224 L .707 .577 .707 r
F P
0 g
s
.20883 .31705 m .21916 .30741 L p .25743 .44346 L .707 .577 .707 r
F P
0 g
s
.32725 .75117 m .32531 .74993 L p .33399 .71756 L .707 .577 .707 r
F P
0 g
s
.32044 .7279 m .33399 .71756 L .32531 .74993 L .707 .577 .707 r
F
.33587 .71613 m .33485 .72025 L p .33399 .71756 L F P
0 g
s
.33485 .72025 m .32725 .75117 L p .33399 .71756 L .707 .577 .707 r
F P
0 g
s
.30697 .73817 m .31559 .70314 L .33294 .71425 L p .707 .577 .707 r
F P
0 g
s
.33294 .71425 m .33587 .71613 L p .33399 .71756 L .707 .577 .707 r
F P
0 g
s
.30697 .73817 m .33294 .71425 L .33399 .71756 L .707 .577 .707 r
F
.27206 .52251 m .28233 .5559 L p .29592 .59756 L F P
0 g
s
.28233 .5559 m .36051 .80991 L p .30128 .6152 L .707 .577 .707 r
F P
0 g
s
.29592 .59756 m .28233 .5559 L .30128 .6152 L .707 .577 .707 r
F
.36051 .80991 m .36364 .81568 L p .30521 .62747 L F P
0 g
s
.30521 .62747 m .29592 .59756 L .30128 .6152 L .707 .577 .707 r
F
.30521 .62747 m .30128 .6152 L .36051 .80991 L F
.20883 .31705 m .27206 .52251 L p .29592 .59756 L F P
0 g
s
.32416 .68853 m .31447 .65591 L .29592 .59756 L .707 .577 .707 r
F
.36364 .81568 m .32815 .70035 L p .32416 .68853 L F P
0 g
s
.32815 .70035 m .31447 .65591 L p .32416 .68853 L .707 .577 .707 r
F P
0 g
s
.31447 .65591 m .36364 .81568 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.32438 .61678 m .34515 .62722 L p .31976 .66599 L .707 .577 .707 r
F P
0 g
s
.31779 .66224 m .32438 .61678 L p .31976 .66599 L .707 .577 .707 r
F P
0 g
s
.31976 .66599 m .34515 .62722 L .32443 .67489 L .707 .577 .707 r
F
.36051 .80991 m .28233 .5559 L p .25743 .44346 L F P
0 g
s
.28233 .5559 m .20883 .31705 L p .25743 .44346 L .707 .577 .707 r
F P
0 g
s
.32531 .74993 m .30697 .73817 L p .32044 .7279 L .707 .577 .707 r
F P
0 g
s
.36364 .81568 m .37992 .81701 L p .34484 .7138 L .707 .577 .707 r
F P
0 g
s
.34515 .62722 m .3373 .68136 L .32443 .67489 L p .707 .577 .707 r
F P
0 g
s
.35751 .63827 m .35066 .68552 L p .3373 .68136 L .707 .577 .707 r
F P
0 g
s
.34798 .6909 m .3373 .68136 L p .35066 .68552 L .707 .577 .707 r
F P
0 g
s
.35066 .68552 m .35751 .63827 L .35896 .64384 L p .707 .577 .707 r
F P
0 g
s
.40777 .81377 m .35759 .65074 L p .35421 .66771 L .707 .577 .707 r
F P
0 g
s
.35759 .65074 m .40777 .81377 L p .36524 .6022 L .707 .577 .707 r
F P
0 g
s
.6586 .72251 m .64998 .75755 L .62339 .74591 L p .707 .577 .707 r
F P
0 g
s
.62339 .74591 m .63201 .71087 L .6586 .72251 L p .707 .577 .707 r
F P
0 g
s
.15762 .75281 m .16625 .71777 L .15427 .7047 L p .707 .577 .707 r
F P
0 g
s
.32689 .75681 m .31826 .79185 L .3345 .78563 L p .707 .577 .707 r
F P
0 g
s
.17047 .81527 m .1749 .79779 L .15467 .78463 L p .707 .577 .707 r
F P
0 g
s
.15322 .68271 m .16106 .62857 L .15831 .61799 L p .707 .577 .707 r
F P
0 g
s
.45073 .26014 m .60241 .753 L .62519 .74043 L p .707 .577 .707 r
F P
0 g
s
.62519 .74043 m .47351 .24757 L .45073 .26014 L p .707 .577 .707 r
F P
0 g
s
.29144 .82685 m .28701 .84432 L .31065 .84209 L p .707 .577 .707 r
F P
0 g
s
.31065 .84209 m .31507 .82462 L .29144 .82685 L p .707 .577 .707 r
F P
0 g
s
.15467 .78463 m .15024 .8021 L .17047 .81527 L p .707 .577 .707 r
F P
0 g
s
.15427 .7047 m .14565 .73973 L .15762 .75281 L p .707 .577 .707 r
F P
0 g
s
.64689 .77319 m .64246 .79066 L .61592 .77883 L p .707 .577 .707 r
F P
0 g
s
.61592 .77883 m .62035 .76136 L .64689 .77319 L p .707 .577 .707 r
F P
0 g
s
.15831 .61799 m .15047 .67213 L .15322 .68271 L p .707 .577 .707 r
F P
0 g
s
.15024 .8021 m .15467 .78463 L .14273 .77142 L p .707 .577 .707 r
F P
0 g
s
.31507 .82462 m .31065 .84209 L .32687 .8359 L p .707 .577 .707 r
F P
0 g
s
.32687 .8359 m .3313 .81843 L .31507 .82462 L p .707 .577 .707 r
F P
0 g
s
.14565 .73973 m .15427 .7047 L .15178 .69283 L p .707 .577 .707 r
F P
0 g
s
.14273 .77142 m .13831 .78889 L .15024 .8021 L p .707 .577 .707 r
F P
0 g
s
.62035 .76136 m .61592 .77883 L .58566 .76949 L p .707 .577 .707 r
F P
0 g
s
.15047 .67213 m .15831 .61799 L .16545 .60893 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15178 .69283 m .14315 .72786 L .14565 .73973 L p .707 .577 .707 r
F P
0 g
s
.47351 .24757 m .62519 .74043 L .63552 .73079 L p .707 .577 .707 r
F P
0 g
s
.63552 .73079 m .48384 .23793 L .47351 .24757 L p .707 .577 .707 r
F P
0 g
s
.13831 .78889 m .14273 .77142 L .14026 .75945 L p .707 .577 .707 r
F P
0 g
s
.16545 .60893 m .1576 .66307 L .15047 .67213 L p .707 .577 .707 r
F P
0 g
s
.3313 .81843 m .32687 .8359 L .3341 .82636 L p .707 .577 .707 r
F P
0 g
s
.3341 .82636 m .33852 .80889 L .3313 .81843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.14315 .72786 m .15178 .69283 L .159 .68331 L p .707 .577 .707 r
F P
0 g
s
.14026 .75945 m .13583 .77693 L .13831 .78889 L p .707 .577 .707 r
F P
0 g
s
.3373 .68136 m .34515 .62722 L .35751 .63827 L p .707 .577 .707 r
F P
0 g
s
.1576 .66307 m .16545 .60893 L .18176 .60226 L p .707 .577 .707 r
F P
0 g
s
.159 .68331 m .15037 .71835 L .14315 .72786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.13583 .77693 m .14026 .75945 L .14748 .74991 L p .707 .577 .707 r
F P
0 g
s
.18176 .60226 m .17392 .6564 L .1576 .66307 L p .707 .577 .707 r
F P
0 g
s
.33852 .80889 m .3341 .82636 L .33162 .8144 L p .707 .577 .707 r
F P
0 g
s
.33162 .8144 m .33605 .79692 L .33852 .80889 L p .707 .577 .707 r
F P
0 g
s
.48384 .23793 m .63552 .73079 L .63239 .72502 L p .707 .577 .707 r
F P
0 g
s
.63239 .72502 m .48071 .23216 L .48384 .23793 L p .707 .577 .707 r
F P
0 g
s
.15037 .71835 m .159 .68331 L .17523 .67709 L p .707 .577 .707 r
F P
0 g
s
.14748 .74991 m .14306 .76739 L .13583 .77693 L p .707 .577 .707 r
F P
0 g
s
.17392 .6564 m .18176 .60226 L .20567 .59864 L p .707 .577 .707 r
F P
0 g
s
.17523 .67709 m .16661 .71213 L .15037 .71835 L p .707 .577 .707 r
F P
0 g
s
.20567 .59864 m .19782 .65278 L .17392 .6564 L p .707 .577 .707 r
F P
0 g
s
.14306 .76739 m .14748 .74991 L .16371 .74372 L p .707 .577 .707 r
F P
0 g
s
.19782 .65278 m .20567 .59864 L .23483 .59843 L p .707 .577 .707 r
F P
0 g
s
.33605 .79692 m .33162 .8144 L .31968 .80119 L p .707 .577 .707 r
F P
0 g
s
.31968 .80119 m .32411 .78371 L .33605 .79692 L p .707 .577 .707 r
F P
0 g
s
.16661 .71213 m .17523 .67709 L .19888 .67478 L p .707 .577 .707 r
F P
0 g
s
.16371 .74372 m .15928 .7612 L .14306 .76739 L p .707 .577 .707 r
F P
0 g
s
.29723 .60796 m .28939 .6621 L .25853 .65578 L p .707 .577 .707 r
F P
0 g
s
.25853 .65578 m .26638 .60164 L .29723 .60796 L p .707 .577 .707 r
F P
0 g
s
.22698 .65257 m .23483 .59843 L .26638 .60164 L p .707 .577 .707 r
F P
0 g
s
.23483 .59843 m .22698 .65257 L .19782 .65278 L p .707 .577 .707 r
F P
0 g
s
.19888 .67478 m .19026 .70981 L .16661 .71213 L p .707 .577 .707 r
F P
0 g
s
.26638 .60164 m .25853 .65578 L .22698 .65257 L p .707 .577 .707 r
F P
0 g
s
.48071 .23216 m .63239 .72502 L .6161 .72369 L p .707 .577 .707 r
F P
0 g
s
.6161 .72369 m .46442 .23083 L .48071 .23216 L p .707 .577 .707 r
F P
0 g
s
.72456 .65723 m .73241 .60309 L .70156 .59677 L p .707 .577 .707 r
F P
0 g
s
.73241 .60309 m .72456 .65723 L .75611 .66044 L p .707 .577 .707 r
F P
0 g
s
.75611 .66044 m .76396 .6063 L .73241 .60309 L p .707 .577 .707 r
F P
0 g
s
.76396 .6063 m .75611 .66044 L .78527 .66023 L p .707 .577 .707 r
F P
0 g
s
.78527 .66023 m .79312 .60609 L .76396 .6063 L p .707 .577 .707 r
F P
0 g
s
.19026 .70981 m .19888 .67478 L .22764 .67659 L p .707 .577 .707 r
F P
0 g
s
.31559 .70314 m .30697 .73817 L .28038 .72653 L p .707 .577 .707 r
F P
0 g
s
.28038 .72653 m .289 .6915 L .31559 .70314 L p .707 .577 .707 r
F P
0 g
s
.69371 .65091 m .70156 .59677 L .67441 .58796 L p .707 .577 .707 r
F P
0 g
s
.70156 .59677 m .69371 .65091 L .72456 .65723 L p .707 .577 .707 r
F P
0 g
s
.15928 .7612 m .16371 .74372 L .18734 .74149 L p .707 .577 .707 r
F P
0 g
s
.32411 .78371 m .31968 .80119 L .29945 .78802 L p .707 .577 .707 r
F P
0 g
s
.29945 .78802 m .30388 .77055 L .32411 .78371 L p .707 .577 .707 r
F P
0 g
s
.18734 .74149 m .18291 .75897 L .15928 .7612 L p .707 .577 .707 r
F P
0 g
s
.79312 .60609 m .78527 .66023 L .80918 .65661 L p .707 .577 .707 r
F P
0 g
s
.80918 .65661 m .81703 .60247 L .79312 .60609 L p .707 .577 .707 r
F P
0 g
s
.22764 .67659 m .21902 .71162 L .19026 .70981 L p .707 .577 .707 r
F P
0 g
s
.21902 .71162 m .22764 .67659 L .2587 .68235 L p .707 .577 .707 r
F P
0 g
s
.289 .6915 m .28038 .72653 L .25008 .71738 L p .707 .577 .707 r
F P
0 g
s
.25008 .71738 m .2587 .68235 L .289 .6915 L p .707 .577 .707 r
F P
0 g
s
.66657 .6421 m .67441 .58796 L .65364 .57751 L p .707 .577 .707 r
F P
0 g
s
.67441 .58796 m .66657 .6421 L .69371 .65091 L p .707 .577 .707 r
F P
0 g
s
.2587 .68235 m .25008 .71738 L .21902 .71162 L p .707 .577 .707 r
F P
0 g
s
.71501 .71393 m .72363 .67889 L .69332 .66974 L p .707 .577 .707 r
F P
0 g
s
.72363 .67889 m .71501 .71393 L .74606 .71969 L p .707 .577 .707 r
F P
0 g
s
.74606 .71969 m .75468 .68466 L .72363 .67889 L p .707 .577 .707 r
F P
0 g
s
.18291 .75897 m .18734 .74149 L .21607 .74344 L p .707 .577 .707 r
F P
0 g
s
.30388 .77055 m .29945 .78802 L .27291 .77619 L p .707 .577 .707 r
F P
0 g
s
.27291 .77619 m .27734 .75872 L .30388 .77055 L p .707 .577 .707 r
F P
0 g
s
.6847 .70478 m .69332 .66974 L .66673 .6581 L p .707 .577 .707 r
F P
0 g
s
.69332 .66974 m .6847 .70478 L .71501 .71393 L p .707 .577 .707 r
F P
0 g
s
.75468 .68466 m .74606 .71969 L .77482 .7215 L p .707 .577 .707 r
F P
0 g
s
.77482 .7215 m .78344 .68647 L .75468 .68466 L p .707 .577 .707 r
F P
0 g
s
.37084 .80027 m .21916 .30741 L .24194 .29484 L p .707 .577 .707 r
F P
0 g
s
.21916 .30741 m .37084 .80027 L .36051 .80991 L p .707 .577 .707 r
F P
0 g
s
.21607 .74344 m .21164 .76091 L .18291 .75897 L p .707 .577 .707 r
F P
0 g
s
.81703 .60247 m .80918 .65661 L .8255 .64995 L p .707 .577 .707 r
F P
0 g
s
.8255 .64995 m .83334 .5958 L .81703 .60247 L p .707 .577 .707 r
F P
0 g
s
.65364 .57751 m .6458 .63165 L .66657 .6421 L p .707 .577 .707 r
F P
0 g
s
.46442 .23083 m .6161 .72369 L .58826 .72693 L p .707 .577 .707 r
F P
0 g
s
.58826 .72693 m .43658 .23407 L .46442 .23083 L p .707 .577 .707 r
F P
0 g
s
.21164 .76091 m .21607 .74344 L .24708 .74937 L p .707 .577 .707 r
F P
0 g
s
.6458 .63165 m .65364 .57751 L .64128 .56646 L p .707 .577 .707 r
F P
0 g
s
.27734 .75872 m .27291 .77619 L .24265 .76685 L p .707 .577 .707 r
F P
0 g
s
.24265 .76685 m .24708 .74937 L .27734 .75872 L p .707 .577 .707 r
F P
0 g
s
.66673 .6581 m .65811 .69314 L .6847 .70478 L p .707 .577 .707 r
F P
0 g
s
.65811 .69314 m .66673 .6581 L .64646 .64511 L p .707 .577 .707 r
F P
0 g
s
.78344 .68647 m .77482 .7215 L .79848 .71918 L p .707 .577 .707 r
F P
0 g
s
.79848 .71918 m .8071 .68415 L .78344 .68647 L p .707 .577 .707 r
F P
0 g
s
.70749 .74704 m .71191 .72957 L .68166 .72023 L p .707 .577 .707 r
F P
0 g
s
.71191 .72957 m .70749 .74704 L .7385 .75298 L p .707 .577 .707 r
F P
0 g
s
.7385 .75298 m .74293 .7355 L .71191 .72957 L p .707 .577 .707 r
F P
0 g
s
.24708 .74937 m .24265 .76685 L .21164 .76091 L p .707 .577 .707 r
F P
0 g
s
.67723 .7377 m .68166 .72023 L .65511 .7084 L p .707 .577 .707 r
F P
0 g
s
.68166 .72023 m .67723 .7377 L .70749 .74704 L p .707 .577 .707 r
F P
0 g
s
.74293 .7355 m .7385 .75298 L .76723 .75493 L p .707 .577 .707 r
F P
0 g
s
.76723 .75493 m .77165 .73745 L .74293 .7355 L p .707 .577 .707 r
F P
0 g
s
.65511 .7084 m .65069 .72587 L .67723 .7377 L p .707 .577 .707 r
F P
0 g
s
.64646 .64511 m .63784 .68014 L .65811 .69314 L p .707 .577 .707 r
F P
0 g
s
.64128 .56646 m .63343 .6206 L .6458 .63165 L p .707 .577 .707 r
F P
0 g
s
.65069 .72587 m .65511 .7084 L .63488 .69523 L p .707 .577 .707 r
F P
0 g
s
.77165 .73745 m .76723 .75493 L .79086 .7527 L p .707 .577 .707 r
F P
0 g
s
.79086 .7527 m .79529 .73522 L .77165 .73745 L p .707 .577 .707 r
F P
0 g
s
.63784 .68014 m .64646 .64511 L .63449 .63204 L p .707 .577 .707 r
F P
0 g
s
.83334 .5958 m .8255 .64995 L .83263 .64088 L p .707 .577 .707 r
F P
0 g
s
.83263 .64088 m .84048 .58674 L .83334 .5958 L p .707 .577 .707 r
F P
0 g
s
.8071 .68415 m .79848 .71918 L .81471 .71296 L p .707 .577 .707 r
F P
0 g
s
.81471 .71296 m .82333 .67793 L .8071 .68415 L p .707 .577 .707 r
F P
0 g
s
.63488 .69523 m .63046 .7127 L .65069 .72587 L p .707 .577 .707 r
F P
0 g
s
.63343 .6206 m .64128 .56646 L .63853 .55589 L p .707 .577 .707 r
F P
0 g
s
.24194 .29484 m .39362 .7877 L .37084 .80027 L p .707 .577 .707 r
F P
0 g
s
.39362 .7877 m .24194 .29484 L .27493 .28058 L p .707 .577 .707 r
F P
0 g
s
.43658 .23407 m .58826 .72693 L .55159 .73441 L p .707 .577 .707 r
F P
0 g
s
.55159 .73441 m .3999 .24155 L .43658 .23407 L p .707 .577 .707 r
F P
0 g
s
.63449 .63204 m .62587 .66707 L .63784 .68014 L p .707 .577 .707 r
F P
0 g
s
.63046 .7127 m .63488 .69523 L .62295 .68202 L p .707 .577 .707 r
F P
0 g
s
.79529 .73522 m .79086 .7527 L .80708 .74651 L p .707 .577 .707 r
F P
0 g
s
.80708 .74651 m .81151 .72903 L .79529 .73522 L p .707 .577 .707 r
F P
0 g
s
.63853 .55589 m .63068 .61003 L .63343 .6206 L p .707 .577 .707 r
F P
0 g
s
.62295 .68202 m .61852 .69949 L .63046 .7127 L p .707 .577 .707 r
F P
0 g
s
.62587 .66707 m .63449 .63204 L .63199 .62016 L p .707 .577 .707 r
F P
0 g
s
.82333 .67793 m .81471 .71296 L .82193 .70345 L p .707 .577 .707 r
F P
0 g
s
.82193 .70345 m .83055 .66842 L .82333 .67793 L p .707 .577 .707 r
F P
0 g
s
.84048 .58674 m .83263 .64088 L .82988 .63031 L p .707 .577 .707 r
F P
0 g
s
.82988 .63031 m .83773 .57617 L .84048 .58674 L p .707 .577 .707 r
F P
0 g
s
.42662 .77343 m .37745 .61367 L p .4025 .66388 L .707 .577 .707 r
F P
0 g
s
.37745 .61367 m .36967 .5884 L p .38281 .61862 L .707 .577 .707 r
F P
0 g
s
.37745 .61367 m .38281 .61862 L .4025 .66388 L .707 .577 .707 r
F
.3894 .57316 m .38281 .61862 L p .4131 .63051 L F P
0 g
s
.39355 .62852 m .4131 .63051 L p .38281 .61862 L .707 .577 .707 r
F P
0 g
s
.38281 .61862 m .3894 .57316 L .3616 .56746 L p .707 .577 .707 r
F P
0 g
s
.36967 .5884 m .37745 .61367 L p .31188 .43843 L .707 .577 .707 r
F P
0 g
s
.38205 .62863 m .39112 .6581 L p .37222 .61461 L .707 .577 .707 r
F P
0 g
s
.39112 .6581 m .42662 .77343 L p .38613 .65521 L .707 .577 .707 r
F P
0 g
s
.37222 .61461 m .39112 .6581 L .38613 .65521 L .707 .577 .707 r
F
.4131 .63051 m .42095 .57637 L .3894 .57316 L p F P
0 g
s
.42095 .57637 m .4131 .63051 L .43828 .63032 L p .707 .577 .707 r
F P
0 g
s
.44191 .64375 m .43041 .64126 L .43886 .62953 L .707 .577 .707 r
F
.4666 .75886 m .43379 .65226 L p .44191 .64375 L F P
0 g
s
.43379 .65226 m .43041 .64126 L p .44191 .64375 L .707 .577 .707 r
F P
0 g
s
.4666 .75886 m .42662 .77343 L p .40093 .65676 L .707 .577 .707 r
F P
0 g
s
.31492 .26601 m .43379 .65226 L p .40093 .65676 L .707 .577 .707 r
F P
0 g
s
.43379 .65226 m .4666 .75886 L p .40093 .65676 L .707 .577 .707 r
F P
0 g
s
.43181 .70212 m .44043 .66709 L .42083 .66586 L p .707 .577 .707 r
F P
0 g
s
.42083 .66586 m .41167 .66528 L p .41521 .67175 L .707 .577 .707 r
F P
0 g
s
.43181 .70212 m .42083 .66586 L .41521 .67175 L .707 .577 .707 r
F
.44086 .62674 m .42095 .57637 L .43828 .63032 L F
.50966 .74542 m .4666 .75886 L p .43886 .62953 L F P
0 g
s
.45011 .57615 m .42095 .57637 L p .44086 .62674 L .707 .577 .707 r
F P
0 g
s
.44326 .62341 m .45011 .57615 L p .44086 .62674 L .707 .577 .707 r
F P
0 g
s
.45949 .58238 m .46347 .59532 L p .44326 .62341 L .707 .577 .707 r
F P
0 g
s
.46347 .59532 m .50966 .74542 L p .44006 .6315 L .707 .577 .707 r
F P
0 g
s
.43886 .62953 m .44326 .62341 L .44006 .6315 L .707 .577 .707 r
F
.44326 .62341 m .46347 .59532 L .44006 .6315 L F
.3999 .24155 m .55159 .73441 L .50966 .74542 L p F P
0 g
s
.35798 .25256 m .3999 .24155 L p .46671 .54822 L .707 .577 .707 r
F P
0 g
s
.50966 .74542 m .45949 .58238 L p .46671 .54822 L .707 .577 .707 r
F P
0 g
s
.46116 .57448 m .45011 .57615 L p .45949 .58238 L .707 .577 .707 r
F P
0 g
s
.45949 .58238 m .35798 .25256 L p .46671 .54822 L .707 .577 .707 r
F P
0 g
s
.45538 .59275 m .45949 .58238 L .45011 .57615 L .707 .577 .707 r
F
.46271 .57425 m .46116 .57448 L p .45949 .58238 L F P
0 g
s
.46617 .62668 m .47402 .57254 L .46271 .57425 L p .707 .577 .707 r
F P
0 g
s
.46617 .62668 m .46271 .57425 L .45538 .59275 L .707 .577 .707 r
F
.44226 .63029 m .46617 .62668 L p .45538 .59275 L F P
0 g
s
.45011 .57615 m .44326 .62341 L p .45538 .59275 L .707 .577 .707 r
F P
0 g
s
.44326 .62341 m .44226 .63029 L p .45538 .59275 L .707 .577 .707 r
F P
0 g
s
.35798 .25256 m .45949 .58238 L p .43886 .62953 L .707 .577 .707 r
F P
0 g
s
.43886 .62953 m .45949 .58238 L .44326 .62341 L .707 .577 .707 r
F
.44226 .63029 m .44326 .62341 L p .44086 .62674 L F P
0 g
s
.43828 .63032 m .44226 .63029 L p .44086 .62674 L .707 .577 .707 r
F P
0 g
s
.31492 .26601 m .35798 .25256 L p .43886 .62953 L .707 .577 .707 r
F P
0 g
s
.43041 .64126 m .31492 .26601 L p .43886 .62953 L .707 .577 .707 r
F P
0 g
s
.40305 .70031 m .43181 .70212 L p .41544 .67217 L .707 .577 .707 r
F P
0 g
s
.41167 .66528 m .41066 .6694 L p .41544 .67217 L .707 .577 .707 r
F P
0 g
s
.41066 .6694 m .40305 .70031 L p .41544 .67217 L .707 .577 .707 r
F P
0 g
s
.42662 .77343 m .39362 .7877 L p .31188 .43843 L .707 .577 .707 r
F P
0 g
s
.40305 .70031 m .41066 .6694 L p .38062 .65952 L .707 .577 .707 r
F P
0 g
s
.41066 .6694 m .41167 .66528 L .40718 .66445 L p .707 .577 .707 r
F P
0 g
s
.27493 .28058 m .31492 .26601 L p .39753 .64129 L .707 .577 .707 r
F P
0 g
s
.4025 .66388 m .39403 .63843 L .39753 .64129 L .707 .577 .707 r
F
.39403 .63843 m .27493 .28058 L .39753 .64129 L F
.38281 .61862 m .3616 .56746 L .36967 .5884 L F
.36967 .5884 m .27493 .28058 L p .4025 .66388 L F P
0 g
s
.40718 .66445 m .38062 .65952 L p .41066 .6694 L .707 .577 .707 r
F P
0 g
s
.37745 .61367 m .38205 .62863 L p .36545 .59485 L .707 .577 .707 r
F P
0 g
s
.36545 .59485 m .38205 .62863 L .37222 .61461 L .707 .577 .707 r
F
.31188 .43843 m .37745 .61367 L .36545 .59485 L F
.38281 .61862 m .3824 .62144 L p .39355 .62852 L F P
0 g
s
.3824 .62144 m .38155 .6273 L .38645 .6278 L p .707 .577 .707 r
F P
0 g
s
.38645 .6278 m .39355 .62852 L p .3824 .62144 L .707 .577 .707 r
F P
0 g
s
.3616 .56746 m .36046 .56723 L p .36967 .5884 L .707 .577 .707 r
F P
0 g
s
.27493 .28058 m .36967 .5884 L p .31188 .43843 L .707 .577 .707 r
F P
0 g
s
.38155 .6273 m .38281 .61862 L p .35855 .56683 L .707 .577 .707 r
F P
0 g
s
.36046 .56723 m .35855 .56683 L p .38281 .61862 L .707 .577 .707 r
F P
0 g
s
.63068 .61003 m .63853 .55589 L .64566 .54682 L p .707 .577 .707 r
F P
0 g
s
.63199 .62016 m .62337 .6552 L .62587 .66707 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.61852 .69949 m .62295 .68202 L .62047 .67006 L p .707 .577 .707 r
F P
0 g
s
.81151 .72903 m .80708 .74651 L .81431 .73696 L p .707 .577 .707 r
F P
0 g
s
.81431 .73696 m .81874 .71949 L .81151 .72903 L p .707 .577 .707 r
F P
0 g
s
.62047 .67006 m .61604 .68753 L .61852 .69949 L p .707 .577 .707 r
F P
0 g
s
.64566 .54682 m .63781 .60096 L .63068 .61003 L p .707 .577 .707 r
F P
0 g
s
.62337 .6552 m .63199 .62016 L .63921 .61065 L p .707 .577 .707 r
F P
0 g
s
.83055 .66842 m .82193 .70345 L .81943 .69158 L p .707 .577 .707 r
F P
0 g
s
.81943 .69158 m .82805 .65654 L .83055 .66842 L p .707 .577 .707 r
F P
0 g
s
.83773 .57617 m .82988 .63031 L .81751 .61926 L p .707 .577 .707 r
F P
0 g
s
.81751 .61926 m .82536 .56512 L .83773 .57617 L p .707 .577 .707 r
F P
0 g
s
.63781 .60096 m .64566 .54682 L .66198 .54016 L p .707 .577 .707 r
F P
0 g
s
.63921 .61065 m .63059 .64568 L .62337 .6552 L p .707 .577 .707 r
F P
0 g
s
.61604 .68753 m .62047 .67006 L .6277 .66051 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3507 .62097 m .35855 .56683 L .3314 .55802 L p .707 .577 .707 r
F P
0 g
s
.35855 .56683 m .3507 .62097 L .38155 .6273 L p .707 .577 .707 r
F P
0 g
s
.81874 .71949 m .81431 .73696 L .81184 .725 L p .707 .577 .707 r
F P
0 g
s
.81184 .725 m .81626 .70753 L .81874 .71949 L p .707 .577 .707 r
F P
0 g
s
.6277 .66051 m .62327 .67799 L .61604 .68753 L p .707 .577 .707 r
F P
0 g
s
.66198 .54016 m .65413 .5943 L .63781 .60096 L p .707 .577 .707 r
F P
0 g
s
.63059 .64568 m .63921 .61065 L .65544 .60443 L p .707 .577 .707 r
F P
0 g
s
.82805 .65654 m .81943 .69158 L .80746 .6785 L p .707 .577 .707 r
F P
0 g
s
.80746 .6785 m .81608 .64347 L .82805 .65654 L p .707 .577 .707 r
F P
0 g
s
.82536 .56512 m .81751 .61926 L .79674 .60881 L p .707 .577 .707 r
F P
0 g
s
.79674 .60881 m .80459 .55467 L .82536 .56512 L p .707 .577 .707 r
F P
0 g
s
.32356 .61216 m .3314 .55802 L .31063 .54758 L p .707 .577 .707 r
F P
0 g
s
.3314 .55802 m .32356 .61216 L .3507 .62097 L p .707 .577 .707 r
F P
0 g
s
.65413 .5943 m .66198 .54016 L .68589 .53654 L p .707 .577 .707 r
F P
0 g
s
.372 .69455 m .38062 .65952 L .35031 .65037 L p .707 .577 .707 r
F P
0 g
s
.38062 .65952 m .372 .69455 L .40305 .70031 L p .707 .577 .707 r
F P
0 g
s
.65544 .60443 m .64682 .63946 L .63059 .64568 L p .707 .577 .707 r
F P
0 g
s
.34169 .6854 m .35031 .65037 L .32372 .63873 L p .707 .577 .707 r
F P
0 g
s
.35031 .65037 m .34169 .6854 L .372 .69455 L p .707 .577 .707 r
F P
0 g
s
.62327 .67799 m .6277 .66051 L .64392 .65433 L p .707 .577 .707 r
F P
0 g
s
.81626 .70753 m .81184 .725 L .7999 .71179 L p .707 .577 .707 r
F P
0 g
s
.7999 .71179 m .80432 .69432 L .81626 .70753 L p .707 .577 .707 r
F P
0 g
s
.47402 .57254 m .46617 .62668 L .48249 .62001 L p .707 .577 .707 r
F P
0 g
s
.48249 .62001 m .49033 .56587 L .47402 .57254 L p .707 .577 .707 r
F P
0 g
s
.31063 .54758 m .30279 .60172 L .32356 .61216 L p .707 .577 .707 r
F P
0 g
s
.80459 .55467 m .79674 .60881 L .7696 .6 L p .707 .577 .707 r
F P
0 g
s
.7696 .6 m .77745 .54586 L .80459 .55467 L p .707 .577 .707 r
F P
0 g
s
.68589 .53654 m .67804 .59068 L .65413 .5943 L p .707 .577 .707 r
F P
0 g
s
.64392 .65433 m .6395 .6718 L .62327 .67799 L p .707 .577 .707 r
F P
0 g
s
.30279 .60172 m .31063 .54758 L .29827 .53653 L p .707 .577 .707 r
F P
0 g
s
.64682 .63946 m .65544 .60443 L .6791 .60211 L p .707 .577 .707 r
F P
0 g
s
.67804 .59068 m .68589 .53654 L .71504 .53633 L p .707 .577 .707 r
F P
0 g
s
.81608 .64347 m .80746 .6785 L .78719 .66551 L p .707 .577 .707 r
F P
0 g
s
.78719 .66551 m .79581 .63047 L .81608 .64347 L p .707 .577 .707 r
F P
0 g
s
.32372 .63873 m .3151 .67376 L .34169 .6854 L p .707 .577 .707 r
F P
0 g
s
.3151 .67376 m .32372 .63873 L .30345 .62573 L p .707 .577 .707 r
F P
0 g
s
.44043 .66709 m .43181 .70212 L .45547 .69981 L p .707 .577 .707 r
F P
0 g
s
.45547 .69981 m .46409 .66477 L .44043 .66709 L p .707 .577 .707 r
F P
0 g
s
.36448 .7444 m .3689 .72693 L .33865 .71759 L p .707 .577 .707 r
F P
0 g
s
.3689 .72693 m .36448 .7444 L .39549 .75034 L p .707 .577 .707 r
F P
0 g
s
.39549 .75034 m .39992 .73286 L .3689 .72693 L p .707 .577 .707 r
F P
0 g
s
.77745 .54586 m .7696 .6 L .73875 .59368 L p .707 .577 .707 r
F P
0 g
s
.73875 .59368 m .74659 .53954 L .77745 .54586 L p .707 .577 .707 r
F P
0 g
s
.6791 .60211 m .67047 .63715 L .64682 .63946 L p .707 .577 .707 r
F P
0 g
s
.70719 .59047 m .71504 .53633 L .74659 .53954 L p .707 .577 .707 r
F P
0 g
s
.71504 .53633 m .70719 .59047 L .67804 .59068 L p .707 .577 .707 r
F P
0 g
s
.33422 .73506 m .33865 .71759 L .3121 .70575 L p .707 .577 .707 r
F P
0 g
s
.33865 .71759 m .33422 .73506 L .36448 .7444 L p .707 .577 .707 r
F P
0 g
s
.39992 .73286 m .39549 .75034 L .42422 .75228 L p .707 .577 .707 r
F P
0 g
s
.42422 .75228 m .42864 .73481 L .39992 .73286 L p .707 .577 .707 r
F P
0 g
s
.30345 .62573 m .29483 .66077 L .3151 .67376 L p .707 .577 .707 r
F P
0 g
s
.74659 .53954 m .73875 .59368 L .70719 .59047 L p .707 .577 .707 r
F P
0 g
s
.29827 .53653 m .29042 .59067 L .30279 .60172 L p .707 .577 .707 r
F P
0 g
s
.6395 .6718 m .64392 .65433 L .66755 .6521 L p .707 .577 .707 r
F P
0 g
s
.3121 .70575 m .30768 .72323 L .33422 .73506 L p .707 .577 .707 r
F P
0 g
s
.80432 .69432 m .7999 .71179 L .77967 .69862 L p .707 .577 .707 r
F P
0 g
s
.77967 .69862 m .78409 .68115 L .80432 .69432 L p .707 .577 .707 r
F P
0 g
s
.67047 .63715 m .6791 .60211 L .70786 .60392 L p .707 .577 .707 r
F P
0 g
s
.79581 .63047 m .78719 .66551 L .7606 .65387 L p .707 .577 .707 r
F P
0 g
s
.7606 .65387 m .76922 .61883 L .79581 .63047 L p .707 .577 .707 r
F P
0 g
s
.49033 .56587 m .48249 .62001 L .48962 .61094 L p .707 .577 .707 r
F P
0 g
s
.48962 .61094 m .49747 .5568 L .49033 .56587 L p .707 .577 .707 r
F P
0 g
s
.29483 .66077 m .30345 .62573 L .29148 .61266 L p .707 .577 .707 r
F P
0 g
s
.66755 .6521 m .66313 .66957 L .6395 .6718 L p .707 .577 .707 r
F P
0 g
s
.46409 .66477 m .45547 .69981 L .4717 .69359 L p .707 .577 .707 r
F P
0 g
s
.4717 .69359 m .48032 .65855 L .46409 .66477 L p .707 .577 .707 r
F P
0 g
s
.30768 .72323 m .3121 .70575 L .29187 .69259 L p .707 .577 .707 r
F P
0 g
s
.29042 .59067 m .29827 .53653 L .29552 .52595 L p .707 .577 .707 r
F P
0 g
s
.42864 .73481 m .42422 .75228 L .44785 .75005 L p .707 .577 .707 r
F P
0 g
s
.44785 .75005 m .45228 .73258 L .42864 .73481 L p .707 .577 .707 r
F P
0 g
s
.29187 .69259 m .28745 .71006 L .30768 .72323 L p .707 .577 .707 r
F P
0 g
s
.70786 .60392 m .69924 .63896 L .67047 .63715 L p .707 .577 .707 r
F P
0 g
s
.69924 .63896 m .70786 .60392 L .73891 .60968 L p .707 .577 .707 r
F P
0 g
s
.76922 .61883 m .7606 .65387 L .73029 .64472 L p .707 .577 .707 r
F P
0 g
s
.73029 .64472 m .73891 .60968 L .76922 .61883 L p .707 .577 .707 r
F P
0 g
s
.29148 .61266 m .28286 .64769 L .29483 .66077 L p .707 .577 .707 r
F P
0 g
s
.66313 .66957 m .66755 .6521 L .69628 .65404 L p .707 .577 .707 r
F P
0 g
s
.73891 .60968 m .73029 .64472 L .69924 .63896 L p .707 .577 .707 r
F P
0 g
s
.78409 .68115 m .77967 .69862 L .75312 .68679 L p .707 .577 .707 r
F P
0 g
s
.75312 .68679 m .75755 .66932 L .78409 .68115 L p .707 .577 .707 r
F P
0 g
s
.29552 .52595 m .28767 .58009 L .29042 .59067 L p .707 .577 .707 r
F P
0 g
s
.69628 .65404 m .69186 .67152 L .66313 .66957 L p .707 .577 .707 r
F P
0 g
s
.28745 .71006 m .29187 .69259 L .27993 .67938 L p .707 .577 .707 r
F P
0 g
s
.45228 .73258 m .44785 .75005 L .46407 .74387 L p .707 .577 .707 r
F P
0 g
s
.46407 .74387 m .4685 .72639 L .45228 .73258 L p .707 .577 .707 r
F P
0 g
s
.28286 .64769 m .29148 .61266 L .28898 .60079 L p .707 .577 .707 r
F P
0 g
s
.49747 .5568 m .48962 .61094 L .48687 .60037 L p .707 .577 .707 r
F P
0 g
s
.48687 .60037 m .49472 .54623 L .49747 .5568 L p .707 .577 .707 r
F P
0 g
s
.48032 .65855 m .4717 .69359 L .47892 .68407 L p .707 .577 .707 r
F P
0 g
s
.47892 .68407 m .48754 .64904 L .48032 .65855 L p .707 .577 .707 r
F P
0 g
s
.69186 .67152 m .69628 .65404 L .72729 .65998 L p .707 .577 .707 r
F P
0 g
s
.27993 .67938 m .27551 .69685 L .28745 .71006 L p .707 .577 .707 r
F P
0 g
s
.75755 .66932 m .75312 .68679 L .72287 .67745 L p .707 .577 .707 r
F P
0 g
s
.72287 .67745 m .72729 .65998 L .75755 .66932 L p .707 .577 .707 r
F P
0 g
s
.28767 .58009 m .29552 .52595 L .30265 .51689 L p .707 .577 .707 r
F P
0 g
s
.72729 .65998 m .72287 .67745 L .69186 .67152 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.28898 .60079 m .28036 .63582 L .28286 .64769 L p .707 .577 .707 r
F P
0 g
s
.27551 .69685 m .27993 .67938 L .27746 .66742 L p .707 .577 .707 r
F P
0 g
s
.30265 .51689 m .2948 .57103 L .28767 .58009 L p .707 .577 .707 r
F P
0 g
s
.4685 .72639 m .46407 .74387 L .4713 .73432 L p .707 .577 .707 r
F P
0 g
s
.4713 .73432 m .47573 .71685 L .4685 .72639 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28036 .63582 m .28898 .60079 L .2962 .59127 L p .707 .577 .707 r
F P
0 g
s
.27746 .66742 m .27303 .68489 L .27551 .69685 L p .707 .577 .707 r
F P
0 g
s
.48754 .64904 m .47892 .68407 L .47642 .6722 L p .707 .577 .707 r
F P
0 g
s
.47642 .6722 m .48504 .63717 L .48754 .64904 L p .707 .577 .707 r
F P
0 g
s
.49472 .54623 m .48687 .60037 L .4745 .58932 L p .707 .577 .707 r
F P
0 g
s
.4745 .58932 m .48235 .53518 L .49472 .54623 L p .707 .577 .707 r
F P
0 g
s
.2948 .57103 m .30265 .51689 L .31897 .51022 L p .707 .577 .707 r
F P
0 g
s
.2962 .59127 m .28758 .62631 L .28036 .63582 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.27303 .68489 m .27746 .66742 L .28469 .65787 L p .707 .577 .707 r
F P
0 g
s
.31897 .51022 m .31112 .56436 L .2948 .57103 L p .707 .577 .707 r
F P
0 g
s
.47573 .71685 m .4713 .73432 L .46883 .72236 L p .707 .577 .707 r
F P
0 g
s
.46883 .72236 m .47325 .70489 L .47573 .71685 L p .707 .577 .707 r
F P
0 g
s
.48235 .53518 m .4745 .58932 L .45373 .57888 L p .707 .577 .707 r
F P
0 g
s
.45373 .57888 m .46158 .52474 L .48235 .53518 L p .707 .577 .707 r
F P
0 g
s
.28758 .62631 m .2962 .59127 L .31243 .58505 L p .707 .577 .707 r
F P
0 g
s
.28469 .65787 m .28026 .67535 L .27303 .68489 L p .707 .577 .707 r
F P
0 g
s
.48504 .63717 m .47642 .6722 L .46445 .65913 L p .707 .577 .707 r
F P
0 g
s
.46445 .65913 m .47307 .62409 L .48504 .63717 L p .707 .577 .707 r
F P
0 g
s
.31112 .56436 m .31897 .51022 L .34288 .5066 L p .707 .577 .707 r
F P
0 g
s
.31243 .58505 m .30381 .62009 L .28758 .62631 L p .707 .577 .707 r
F P
0 g
s
.46158 .52474 m .45373 .57888 L .42659 .57006 L p .707 .577 .707 r
F P
0 g
s
.42659 .57006 m .43444 .51592 L .46158 .52474 L p .707 .577 .707 r
F P
0 g
s
.34288 .5066 m .33503 .56074 L .31112 .56436 L p .707 .577 .707 r
F P
0 g
s
.28026 .67535 m .28469 .65787 L .30091 .65168 L p .707 .577 .707 r
F P
0 g
s
.33503 .56074 m .34288 .5066 L .37203 .50639 L p .707 .577 .707 r
F P
0 g
s
.47325 .70489 m .46883 .72236 L .45689 .70915 L p .707 .577 .707 r
F P
0 g
s
.45689 .70915 m .46131 .69168 L .47325 .70489 L p .707 .577 .707 r
F P
0 g
s
.30381 .62009 m .31243 .58505 L .33608 .58274 L p .707 .577 .707 r
F P
0 g
s
.47307 .62409 m .46445 .65913 L .44418 .64613 L p .707 .577 .707 r
F P
0 g
s
.44418 .64613 m .4528 .6111 L .47307 .62409 L p .707 .577 .707 r
F P
0 g
s
.30091 .65168 m .29649 .66916 L .28026 .67535 L p .707 .577 .707 r
F P
0 g
s
.43444 .51592 m .42659 .57006 L .39573 .56374 L p .707 .577 .707 r
F P
0 g
s
.39573 .56374 m .40358 .5096 L .43444 .51592 L p .707 .577 .707 r
F P
0 g
s
.36418 .56053 m .37203 .50639 L .40358 .5096 L p .707 .577 .707 r
F P
0 g
s
.37203 .50639 m .36418 .56053 L .33503 .56074 L p .707 .577 .707 r
F P
0 g
s
.33608 .58274 m .32746 .61777 L .30381 .62009 L p .707 .577 .707 r
F P
0 g
s
.40358 .5096 m .39573 .56374 L .36418 .56053 L p .707 .577 .707 r
F P
0 g
s
.32746 .61777 m .33608 .58274 L .36485 .58455 L p .707 .577 .707 r
F P
0 g
s
.4528 .6111 m .44418 .64613 L .41759 .63449 L p .707 .577 .707 r
F P
0 g
s
.41759 .63449 m .42621 .59946 L .4528 .6111 L p .707 .577 .707 r
F P
0 g
s
.29649 .66916 m .30091 .65168 L .32454 .64945 L p .707 .577 .707 r
F P
0 g
s
.46131 .69168 m .45689 .70915 L .43666 .69598 L p .707 .577 .707 r
F P
0 g
s
.43666 .69598 m .44108 .67851 L .46131 .69168 L p .707 .577 .707 r
F P
0 g
s
.32454 .64945 m .32012 .66693 L .29649 .66916 L p .707 .577 .707 r
F P
0 g
s
.36485 .58455 m .35623 .61958 L .32746 .61777 L p .707 .577 .707 r
F P
0 g
s
.35623 .61958 m .36485 .58455 L .3959 .59031 L p .707 .577 .707 r
F P
0 g
s
.42621 .59946 m .41759 .63449 L .38728 .62534 L p .707 .577 .707 r
F P
0 g
s
.38728 .62534 m .3959 .59031 L .42621 .59946 L p .707 .577 .707 r
F P
0 g
s
.3959 .59031 m .38728 .62534 L .35623 .61958 L p .707 .577 .707 r
F P
0 g
s
.32012 .66693 m .32454 .64945 L .35327 .6514 L p .707 .577 .707 r
F P
0 g
s
.44108 .67851 m .43666 .69598 L .41011 .68415 L p .707 .577 .707 r
F P
0 g
s
.41011 .68415 m .41454 .66668 L .44108 .67851 L p .707 .577 .707 r
F P
0 g
s
.35327 .6514 m .34885 .66888 L .32012 .66693 L p .707 .577 .707 r
F P
0 g
s
.34885 .66888 m .35327 .6514 L .38428 .65734 L p .707 .577 .707 r
F P
0 g
s
.41454 .66668 m .41011 .68415 L .37986 .67481 L p .707 .577 .707 r
F P
0 g
s
.37986 .67481 m .38428 .65734 L .41454 .66668 L p .707 .577 .707 r
F P
0 g
s
.38428 .65734 m .37986 .67481 L .34885 .66888 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol0085oo`D009Moo`00NWoo1`001EYF0`00U7oo001dOol6
000;FUH01@00FUIJEUYF0000Tgoo001`Ool40009FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Tgoo
001/Ool4000=FUH00`00FUIJEP05FUH01000FUIJEUYF0P00TWoo001XOol40006FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUIJEUYF0000TWoo001TOol4000:FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000TWoo001QOol3000>FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00TGoo001NOol30005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00TGoo001KOol30008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUJAOol005Qoo`<000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH0002AOol005Eoo`<000mJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP04001JEUYFFUH2002@Ool005=oo`8000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEY1oo`00D7oo0`001eYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP00091oo`00CGoo0`00
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJ
EP8008moo`00Bgoo0P0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00P00Sgoo0018Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000Sgoo0016
Ool20007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01000FUIJEUYF0P00SWoo0014Ool20009FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02002>Ool0049oo`<000]J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH0002>Ool0045oo`05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00SGoo000oOol2
0004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00SGoo000nOol00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUIJEP00FUH0SGoo000mOol20007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000SGoo000l
Ool01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8008aoo`00>goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008008aoo`00>goo00D005YFFUIJEP0000IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH0002<Ool003aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00Rgoo000lOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00Rgoo000l
Ool01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008]oo`00?Goo00@005YFFUH0
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP04001JEUYFFUH2002:Ool003eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02002:Ool003eoo`05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000RWoo000mOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8008Uoo`00
?Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20029Ool003ioo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020029Ool003ioo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000RGoo000oOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@0
05YFFUIJEP8008Qoo`00?goo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008008Qo
o`00?goo00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00028Ool0041oo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Qgoo0010Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Qgoo0010Ool01@00FUIJEUYF00001UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0008Moo`00@Goo00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH20026
Ool0045oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020026Ool0045oo`05001J
EUYFFUH00006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000QWoo0011Ool01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00@005YFFUIJEP8008Eoo`00@Woo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH20025Ool0049oo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
0025Ool0049oo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000QGoo0013Ool0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8008Aoo`00@goo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008008Aoo`00@goo00D005YFFUIJEP0000IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP05001JEUYFFUH00024Ool004Aoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00Pgoo0014Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00Pgoo0014
Ool01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0008=oo`00AGoo00@005YFFUH0
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP04001JEUYFFUH20022Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020022Ool004Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000PWoo0015Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP80085oo`00
AWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20021Ool004Ioo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020021Ool004Ioo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000PGoo0017Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00@0
05YFFUIJEP80081oo`00Agoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080081o
o`00Agoo00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH00020Ool004Qoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Ogoo0018Ool01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00Ogoo0018Ool01@00FUIJEUYF00001UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF
00D005YFFUIJEP0007moo`00BGoo00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001n
Ool004Uoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00OWoo0019Ool01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00OWoo001:Ool01000FUIJEP001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00D005YFFUIJEP0007ioo`00BWoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP04
001JEUYFFUH2001mOol004Yoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02001m
Ool004Yoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF0000OGoo001;Ool01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8007aoo`00Bgoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF008007aoo`00Bgoo00D005YFFUIJEP0000IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP05001JEUYFFUH0001lOol004aoo`05001JEUYFFUH00006FUH00`00FUIJEP04FUHG0007FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Ngoo001<Ool01@00FUIJ
EUYF00001UYF00<005YFFUH010000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00Ngoo001<Ool0
1@00FUIJEUYF00001UYF10001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1000
35YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0007]oo`00CGoo00@005YFFUH000EJ
EP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P00NWoo001=Ool01@00FUIJ
EUYF00000eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00@005YFFUIJEP<000QJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001jOol0
04eoo`05001JEUYFFUH00002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02001jOol004ioo`04001JEUYF0002FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000NWoo001>Ool01P00FUIJEUYF001JEP8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH2001iOol004ioo`04001JEUYF
FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP09FUH00`00FUIJEP06FUH00`00
FUIJEP02000LOol@001=Ool004ioo`04001JEUYFFUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH3
000;FUH00`00FUIJEP05FUH01@00FUIJEUYF00005goo1@000UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1P00Agoo001?Ool01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000]JEP03
001JEUYF00EJEP04001JEUYFFUH2000DOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030013Ool004moo`04001JEUYFFUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00002UYF00<005YFFUH01UYF00<005YFFUH00P004Woo0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000?goo001?Ool01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00EJEP05001JEUYFFUH0000AOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000k
Ool0051oo`05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH0
1EYF00@005YFFUIJEP80011oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP<003Qoo`00D7oo00D005YF001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02000?Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000fOol0051oo`05001JEP00FUH00003FUH01000FUIJEUYF400015YF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00H005YFFUH005YF000;FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
3goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00P00=7oo001AOol30003FUH50002FUH01000FUIJEUYF0P000eYF00<0
05YFFUH00UYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P003Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00<Woo001AOol01000
FUH005YF0`001EYF00<005YFFUH015YF10001UYF2@000UYF00<005YFFUH01EYF00<005YFFUH00eYF
00H005YFFUIJEP00FUH2000:FUH00`00FUIJEP05FUH01000FUIJEUYF0P003Woo0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF0P00<Goo001AOol01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
00001UYF1@0000AJEP00FUIJEP@000EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP09
FUH00`00FUIJEP06FUH00`00FUIJEP02000=Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000;goo001AOol30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEP001UYF0`000UYF
00<005YFFUH015YF100000=JEP00FUH01EYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF
00EJEP05001JEUYFFUH0000=Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo
001AOol00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEP002eYF00<005YF
FUH025YF0P001UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00EJEP04001JEUYFFUH2
000<Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0055oo`03
001JEUYF00=JEP03001JEUYF009JEPL00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP8000=JEP03001JEUYF009JEP80009JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080
00aoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02aoo`00DWoo00<0
05YFFUH00UYF1@000eYF00@005YFFUIJEPT000UJEP03001JEUYF00]JEP800003FUH005YF00=JEP80
009JEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYFFUH0000<Ool00`00FUH00003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00;Woo001BOol01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<0
05YFFUH00UYF1P000eYF00<005YFFUH03EYF0P000eYF00<005YF00000UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00@005YFFUIJEP8000]oo`8000=JEP03001JEUYF00=JEPh000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`<0009JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00eJEP03001JEP00
009JEP03001JEP0000=JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000]oo`8000=J
EP03001JEP0000@00003FUH00000008000Qoo`L000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2000^Ool005=oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEP<000eJEP03001JEUYF00<00003FUH005YF009JEP03001JEUYF00UJEP03001J
EUYF00EJEP05001JEUYFFUH0000;Ool015YF001JEUYF0`0015YF00<005YFFUH00eYF1@001goo1`00
0UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002ioo`00=goo40002goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`002UYF00<005YF
FUH00UYF0P0015YF00<005YFFUH02EYF00<005YFFUH01EYF00@005YFFUIJEP8000Uoo`03001JEP00
00<000IJEP03001JEUYF00EJEP03001JEUYF00@0009oo`D000=oo`@000IJEP03001JEUYF00AJEP05
001JEUYFFUH0000_Ool003=oo`@000=JEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000008
FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020009Ool3
0002FUHD0002FUH70007Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool0035oo`<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJEP07
001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0000Uoo`<0
0005FUH00000FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP0E00000eYF001JEP04FUH01000FUIJ
EUYF0P00;goo000_Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH20004FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00EJEP04001JEUYFFUH20008Ool01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01EYF10001EYF00<005YFFUH01EYF0P001EYF00@005YFFUIJEP8002moo`00;Woo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000=J
EP00FUH00eYF0P001eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000Qoo`<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00IJ
EP04001JEP000003FUH01000FUIJEUYF0P00;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH01000FUIJEUYF1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF0P001eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P002Goo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`001UYF00@005YFFUIJEP800003FUH005YF
009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF1@001eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P0025YF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0000Qo
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<000=J
EP03001JEUYF00AJEP8000=JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P0000EJEP00001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEPX000MJEP03001JEUYF00EJEP03001JEUYF00AJEP8000YJEP03001JEUYF00UJEP03001J
EUYF00EJEP04001JEUYFFUH20007Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP0200000eYF001JEP05FUH01`00FUH005YF001JEP0002mo
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF0P000eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF20001EYF00<005YFFUH01EYF00<0
05YFFUH015YF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P001goo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0P001UYF00<005YFFUH00`00<7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH01000FUIJEUYF0P001UYF00<005YFFUH025YF
2@0000=JEP00FUH01eYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF00<005YFFUH01EYF00@0
05YFFUIJEP@000=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF009JEP80031oo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000eYF00<005YFFUH00UYF0P001UYF00<005YFFUH025YF1P000UYF0`001eYF00<005YFFUH00eYF
00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF00000002
00001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0000=JEP00FUH00eYF0P00<7oo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH20004FUH00`00
FUIJEP08FUH60005FUH20004FUH00`00FUIJEP04FUH01@00FUIJEUYF00002UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00`0015YF0P000eYF4P001eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEP00031oo`00;7oo0P0015YF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH01EYF00@005YF
0000009JEP03001JEUYF00QJEP03001JEP00008000QJEP<00003FUH005YF00EJEP05001JEUYFFUH0
000:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF0P0000=JEP0000001000
00Aoo`00000000IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH0031oo`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF009JEP800003
FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF008000IJEP04001JEUYFFUH20009FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF0P000UYF00@005YFFUIJEP<00003Ool00000
00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH00000035o
o`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00D005YFFUIJEP0000AJEPL0009JEP<000UJEP03001JEUYF00YJEP04001JEUYFFUH20004
FUH01P00FUIJEP00FUH000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000=JEP80
00AJEP<000=JEP<00006Ool00000001JEP001eYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000039oo`00:goo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00EJEP03001JEUYF00D000=JEP04001JEUYFFUH9000BFUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YF00002UYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP80
00AJEP03001JEUYF00l000AJEP03001JEUYF00IJEP<000MJEP03001JEUYF00=JEP05001JEUYFFUH0
000bOol002]oo`8000=JEPD0009JEP04001JEUYFFUH20008Ool70006FUH200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH7000;FUH00`00FUIJEP04FUH30003FUH00`00FUH0000:FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF0P000UYF1P000UYF00<005YFFUH0
1EYF00<005YFFUH02P0015YF00<005YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH00UYF00<0
07ooOol0;goo000[Ool2000015YF000000001EYF00<005YFFUH015YF10001Woo2`000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000]JEP03001JEUYF00EJEP04001J
EUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000UYF10000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF10000Woo2`000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF00<007ooOol0;goo000[Ool00eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP040002Ool50003Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP02000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUH00002000:Ool30006FUH01000FUIJEUYF0P00<Goo000ZOol30003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70002Ool00`00FUH00003FUH01000FUIJ
EUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF4P0000AJEP00FUH000aJEP03001JEUYF00UJ
EP03001JEUYF00EJEP05001JEUYFFUH00002FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH30009Ool00`00FUIJEP04FUH01`00FUIJEUYF001JEP00031o
o`00:Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
10000eYF1`001EYF200015YF00<005YFFUH01eYF00@005YF000000AJEP03001JEUYF00=JEP03001J
EUYF00800003FUH0000000]JEP03001JEUYF00UJEP03001JEUYF00EJEP04001JEUYFFUH40003FUH0
1000FUIJEUYF3P001UYF00<005YFFUH01UYF0`001goo0P000eYF00<005YFFUH00UYF00<005YF0000
<7oo000ZOol00`00FUIJEP03FUH00`00FUIJEP02FUH700000eYF001JEP08FUH00`00FUIJEP04FUH2
00000eYF00000005FUH30007FUH00`00FUIJEP02FUH60008FUH01000FUIJEUYF10001UYF00H005YF
FUIJEP00FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH50003FUH0
0`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP07FUH01000FUH000001goo0P0000=JEP00
FUH00UYF00@005YFFUH0031oo`00:Woo00<005YFFUH00eYF1@000eYF00@005YFFUIJEPL000AJEP03
001JEUYF00=JEP04001JEP000007FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH01000FUIJEUYF1`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1P0025YF
00@005YFFUIJEP8000Moo`8000=JEP03001JEP00035oo`00:goo00@005YFFUIJEP<000IJEP03001J
EUYF00EJEP03001JEUYF00@000IJEP@000MJEP05001JEUYF001JEP0300000eYF001JEP07FUH00`00
FUIJEP02FUH400000eYF001JEP07FUH30002FUH00`00FUIJEP02FUH200000eYF0000000;FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000AJEP00FUH000IJEP03001JEUYF00EJEP03
001JEUYF00EJEPH000AJEP03001JEUYF00AJEP8000Moo`06001JEUYF001JEP00<Goo000[Ool01000
FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1@0000=JEP00FUH00P00
1UYF00D005YFFUIJEP0000=JEP@000MJEP04001JEUYFFUH80007FUH01P00FUIJEP00FUH000AJEP80
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00D0009JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00IJEP<00003Ool0
000000<0009JEP03001JEP00035oo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00P0000AJEP00FUH000EJEP05001JEUYFFUH00003FUH01000FUIJEUYF
0P001EYF00@005YFFUIJEPH0009JEP8000AJEP03001JEUYF009JEP8000=JEP8000=JEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00800003FUH0000000AJEP04001JEUYF
0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30006FUH01000FUIJEP000eYF00H005YF000005YF
000bOol002aoo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF0P000eYF00<005YFFUH00UYF00@005YFFUH000EJEP<00003FUH005YF00=JEPH000AJEP<0
0003FUH005YF00EJEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF0080009JEP8000AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EP000003FUH00`00FUIJEP02FUH30003FUH00`00FUH0000bOol002]oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH400000eYF001JEP03
FUH01@00FUIJEUYF00001UYF1@000eYF100025YF0P001UYF10001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YF000015YF0`0015YF0P001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00L005YFFUIJEP00FUH0000bOol002]oo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH30004FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF10000UYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEP0000AJEPH00003FUH005YF008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP8000IJEP80009JEP03001JEP00039oo`00:Woo0P0015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF10000eYF00@005YFFUH000MJ
EP03001JEUYF00EJEQ00009JEP04001JEUYF0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01000FUIJEP000eYF00@005YFFUH0009JEP8000=JEP800003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00EJEP<000AJEP04001JEP00FUH2000cOol002Yoo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP<0009JEP05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP<00003FUH0000000=J
EP<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF0`00<goo
000ZOol20003FUH01000FUIJEUYF1`0015YF00<005YFFUH01eYF00<005YFFUH01EYF0P001UYF1P00
0eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF0P0015YF00<005YFFUH015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00`001UYF0P000UYF0P0000AJ
EP00FUIJEP<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30004FUH00`00Oomo
o`0bOol002Uoo`03001JEP00009JEPD000Moo`L000IJEP03001JEUYF00IJEP04001JEP000004FUH0
0`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUH00003
FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF
00@005YF0000009JEP8000=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP03001oogoo039oo`00:Goo0P0000AJEP000000011oo`H0009JEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH02000FUIJEP00FUH005YF0006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH01000FUIJEUYF0`0015YF00<005YFFUH00UYF0`0000IJEP00FUH005YF0003Ool60000
0eYF000000020007FUH00`00FUIJEP03FUH00`00FUH00002FUH2000dOol002Uoo`03FUH0000000=J
EP03001oogoo015oo`H000MJEP03001JEUYF009JEP<000MJEP@000IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00800003FUH00000009JEP03001JEUYF00AJEPD00003FUH007oo00Qoo`P0
00AJEP04001JEUYFFUH50002FUH2000dOol002Qoo`<000AJEP<001Ioo`D0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEP0000<000=JEP03001JEUYF00UJEP03001JEUYF00UJEP04001JEUYF
FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH50002FUH01000FUIJEUYF
0P0025YF00<005YF00000P002Woo1@000goo20001Goo0P0000=JEP00Ool0<goo000XOol00`00FUH0
0003FUH01000FUIJEUYF0P004goo1@0000=oo`0000000P001eYF0P001UYF00<005YFFUH00eYF1@00
2UYF00<005YFFUH02EYF00<005YFFUH00`001eYF00<005YFFUH02UYF00<005YFFUH01eYF1`0015YF
1@000eYF0P001eYF00<005YFFUH00UYF0`001goo1@004Goo00<005YF0000=7oo000XOol00`00FUH0
0003FUH00`00FUIJEP03FUH2000AOol50005Ool20004FUH00`00FUIJEP020003FUH00`00FUIJEP06
FUH00`00FUIJEP040006FUH00`00FUIJEP0:FUH200000eYF001JEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP060004FUH00`00FUIJEP04FUH01@00FUIJEUYF00001EYF0P0015YF00<005YFFUH01UYF1000
17oo0`004Woo0P00=Goo000XOol00`00FUIJEP03FUH00`00FUIJEP04FUH3000?Ool50007Ool30000
0eYF001JEP03FUH200000eYF001JEP07FUH00`00FUIJEP04FUHC0002FUH20009FUH00`00FUIJEP09
FUH4000:FUH00`00FUIJEP04FUH01000FUIJEP001UYF00<005YF00000P0000=JEP00FUH025YF00<0
05YFFUH010004goo1000=Goo000YOol01@00FUIJEUYF00001UYF00@005YFFUIJEP8000ioo`<000]o
o`8000IJEP<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0
000:FUH00`00FUIJEP05FUH40003FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20007FUH00`00FUIJ
EP02FUH30008FUH00`00FUIJEP04FUHC0002FUH2000eOol002Uoo`05001JEUYFFUH00004FUH70000
0eYF0000000LOol00`00FUIJEP03FUH00`00FUH000040002FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000;FUH00`00FUIJEP040008FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50004FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02000fOol002Yoo`03001JEUYF00D000=JEP04001JEUYFFUH7
000IOol20002FUH01000FUIJEP000eYF1P001UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YF
FUIJEP0000]JEPD000]JEP03001JEUYF00QJEP03001JEUYF009JEP<000MJEP03001JEUYF00AJEP05
001JEP00001oo`0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00=Woo000ZOol300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000GOol00`00FUH0
0002FUH01@00FUIJEUYF00001EYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF0000
0P0025YF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEPD000IJEP03001JEUYF
00=JEP03001JEUYF009JEP04001oogooOol30007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02000gOol002Uoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP@0
01Aoo`8000=JEP05001JEUYFFUH00006FUH00`00FUH0000B0002FUH00`00FUIJEP03FUH30007FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH:0004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomo
o`04Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000>Goo000XOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00003000BOol01000FUIJEP00
0eYF00<005YFFUH015YF00<005YFFUH05eYF0`002eYF00<005YFFUH02EYF00<005YFFUH01eYF0P00
2Goo0P0000=JEP00FUH01EYF00@005YFFUIJEP8000Yooa<003]oo`009goo00<005YF00000eYF00@0
05YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00AJEQ<00003FUH0000000=JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00QJEP<00003FUH005YF00]JEP03001JEUYF00UJEP03001J
EUYF00EJEP80009JEP<000Qoo`8000IJEP07001JEUYFFUH005YF0000Egoo000WOol20003FUH50000
0eYF001JEP04FUH60007FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP03FUH00`00FUIJEP020000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30004FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH30007FUH30007Ool20004FUH01`00FUIJEUYF001J
EP0005Moo`009goo0P0000=JEP0000001Goo0P0025YF00<005YFFUH010000UYF00<005YFFUH01eYF
00<005YFFUH00P000UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP0>FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH01P00FUH00000FUH000UJEP04
001JEP000007Ool01000FUIJEP000eYF00@005YFFUH005Moo`009Woo00@005YF000000Uoo`8000IJ
EP03001JEUYF00AJEPD000IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009JEP<000=JEP03001J
EUYF00AJEP03001JEUYF00]JEP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEPP000QJEP04001J
EUYFFUH20006Ool30003FUH00`00FUH0001HOol002Ioo`<000aoo`8000=JEP03001JEUYF00IJEP04
001JEUYFFUH40002FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH200000gooFUIJEP09FUH0
0`00FUIJEP07FUH4000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH30005FUH60004FUH00`00FUIJ
EP04FUH20006Ool01`00FUIJEUYF001JEP0005Qoo`009Woo00@005YF000000eoo`800003FUH005YF
00MJEP04001JEUYFFUH70008FUH30002FUH00`00FUIJEP02FUH200000goo001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH3
0008FUH00`00FUIJEP02FUH300000eYF001JEP06FUH300000goo000000030002FUH00`00FUH0001H
Ool002Ioo`04001JEP00000?Ool30007FUH01000FUIJEUYF1P0000=JEP0000001UYF00<005YFFUH0
0`000eYF0P000Woo00D005YFFUIJEP0000IJEP03001JEUYF009JEP<000IJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00EJEP<000IJEP04001JEUYF
0003FUH01P00FUH00000FUH005Uoo`009Woo0P000UYF00<007ooOol03goo10000UYF00<005YFFUH0
0UYF1P000eYF0P000eYF00<005YFFUH00eYF0P000UYF0P000goo0eYF00<005YFFUH01eYF0P002EYF
00<005YFFUH02UYF00<005YFFUH02EYF0`0015YF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF
000000=JEP03001JEUYF009JEP<000=JEP03001JEP0005Uoo`009goo00D005YFFUIJEP0001Aoo`D0
00=JEP<00003FUH005YF00AJEP800003FUH005YF00EJEP@000Aoo`03001JEUYF00QJEP<000YJEP03
001JEUYF00YJEP03001JEUYF00IJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP800003FUH005YF00EJEP07001JEUYFFUH005YF0000FGoo000WOol01000FUIJEUYF0`005goo
10000UYF00<005YFFUH01EYF0`001EYF00<005YF00001Woo00D005YFFUIJEP0000AJEP80009JEP03
001JEUYF01]JEP<000Aoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00IJEP80009JEP03001JEP0005Uoo`00:7oo00@005YFFUH0009JEP8001Uoo`l000=JEP04001JEUYF
0005Ool01@00FUIJEUYF00000eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YF00000P0000=JEP00Ool01Woo0P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF
0`0015YF00@005YF001JEP8005Yoo`00:7oo00<005YF00001EYF0P009Woo0`0015YF00<007ooOol0
0goo1EYF0P001EYF00<005YFFUH02EYF00<005YFFUH02EYF100015YF0P001goo0`0025YF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEUYFFUH3001JOol002Uoo`8000IJEP<0
02Ioo`03001JEUYF009JEP03001oogoo00=oo`05001JEUYFFUH00008FUH00`00FUIJEP0@FUH40000
17oo000000001UYF0P0027oo0`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP<0
00AJEP03001oogoo05Uoo`00:Woo00<005YFFUH015YF00<005YFFUH00P009Goo00D005YFFUIJEP00
00Eoo`04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP040007Ool00`00
FUIJEP04FUH01000FUH000002Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF00<007ooOol0FGoo000[Ool20003FUH00`00FUIJEP03FUH2000TOol01@00FUH0
05YF00001Goo00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01eYF1@0037oo00<005YFFUH0
0UYF00<005YFFUH00UYF0P002Woo1P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000
0UYF0P00Fgoo000]Ool200000eYF001JEP06FUH3000ROol200000eYF001oo`04Ool00`00FUIJEP0:
FUH00`00FUIJEP06000BOol20002FUH00`00FUIJEP04FUH3000=Ool80004FUH01000FUIJEUYF1@00
0UYF0P00Fgoo000_Ool20008FUH00`00FUH00003000OOol20007Ool30002FUH01000FUIJEUYF1P00
6Woo0P0025YF00<005YF00000P002Woo1@000goo20001Goo0P0000=JEP00Ool0FWoo000aOol20006
FUH00`00FUIJEP03FUH5000IOol3000:Ool6000QOol20007FUH00`00FUIJEP02FUH30007Ool5000A
Ool00`00FUH0001KOol003=oo`8000=JEP03001JEUYF00IJEP03001JEUYF00@001=oo`800003FUH0
07oo03=oo`8000AJEP03001JEUYF00IJEP@000=oo`D0015oo`8005aoo`00=Goo0P0000=JEP00FUH0
1eYF00<005YFFUH015YF1P0027oo1@000UYF0P00=Woo0`0000=JEP00FUH025YF00<005YFFUH01`00
47oo1000G7oo000gOol30006FUH00`00FUIJEP07FUH01000FUIJEUYF20000eYF00D005YFFUIJEP00
03Yoo`<000QJEP03001JEUYF00AJEQ<0009JEP8005aoo`00>Woo10000UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00?Goo0`0015YF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P00GGoo000nOol50006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01@00FUIJEUYF0000@Goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP8005eoo`00@goo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
000004Eoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005ioo`00Agoo1P00
15YF00@005YFFUIJEPD004Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00001P
Ool004eoo`P005=ooa<0069oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60426 .74905 m .59642 .69323 L .56556 .69582 L p .707 .577 .707 r
F P
0 g
s
.59642 .69323 m .60426 .74905 L .63581 .74423 L p .707 .577 .707 r
F P
0 g
s
.63581 .74423 m .62797 .6884 L .59642 .69323 L p .707 .577 .707 r
F P
0 g
s
.62797 .6884 m .63581 .74423 L .66497 .73763 L p .707 .577 .707 r
F P
0 g
s
.66497 .73763 m .65712 .68181 L .62797 .6884 L p .707 .577 .707 r
F P
0 g
s
.57341 .75164 m .56556 .69582 L .53842 .69591 L p .707 .577 .707 r
F P
0 g
s
.56556 .69582 m .57341 .75164 L .60426 .74905 L p .707 .577 .707 r
F P
0 g
s
.65712 .68181 m .66497 .73763 L .68888 .72992 L p .707 .577 .707 r
F P
0 g
s
.68888 .72992 m .68103 .6741 L .65712 .68181 L p .707 .577 .707 r
F P
0 g
s
.61272 .81247 m .6041 .77558 L .57379 .78112 L p .707 .577 .707 r
F P
0 g
s
.6041 .77558 m .61272 .81247 L .64377 .80498 L p .707 .577 .707 r
F P
0 g
s
.64377 .80498 m .63515 .7681 L .6041 .77558 L p .707 .577 .707 r
F P
0 g
s
.53842 .69591 m .54626 .75174 L .57341 .75164 L p .707 .577 .707 r
F P
0 g
s
.63515 .7681 m .64377 .80498 L .67253 .79628 L p .707 .577 .707 r
F P
0 g
s
.67253 .79628 m .66391 .7594 L .63515 .7681 L p .707 .577 .707 r
F P
0 g
s
.54626 .75174 m .53842 .69591 L .51765 .69351 L p .707 .577 .707 r
F P
0 g
s
.57379 .78112 m .58241 .818 L .61272 .81247 L p .707 .577 .707 r
F P
0 g
s
.58241 .818 m .57379 .78112 L .5472 .78416 L p .707 .577 .707 r
F P
0 g
s
.66391 .7594 m .67253 .79628 L .69619 .78722 L p .707 .577 .707 r
F P
0 g
s
.69619 .78722 m .68757 .75033 L .66391 .7594 L p .707 .577 .707 r
F P
0 g
s
.68103 .6741 m .68888 .72992 L .7052 .72184 L p .707 .577 .707 r
F P
0 g
s
.7052 .72184 m .69735 .66602 L .68103 .6741 L p .707 .577 .707 r
F P
0 g
s
.62014 .86353 m .61572 .84511 L .58546 .85084 L p .707 .577 .707 r
F P
0 g
s
.61572 .84511 m .62014 .86353 L .65115 .85586 L p .707 .577 .707 r
F P
0 g
s
.65115 .85586 m .64673 .83744 L .61572 .84511 L p .707 .577 .707 r
F P
0 g
s
.5472 .78416 m .55582 .82105 L .58241 .818 L p .707 .577 .707 r
F P
0 g
s
.64673 .83744 m .65115 .85586 L .67988 .84702 L p .707 .577 .707 r
F P
0 g
s
.67988 .84702 m .67545 .82859 L .64673 .83744 L p .707 .577 .707 r
F P
0 g
s
.51765 .69351 m .52549 .74934 L .54626 .75174 L p .707 .577 .707 r
F P
0 g
s
.58546 .85084 m .58988 .86927 L .62014 .86353 L p .707 .577 .707 r
F P
0 g
s
.58988 .86927 m .58546 .85084 L .55891 .85409 L p .707 .577 .707 r
F P
0 g
s
.55582 .82105 m .5472 .78416 L .52693 .78441 L p .707 .577 .707 r
F P
0 g
s
.55891 .85409 m .56334 .87251 L .58988 .86927 L p .707 .577 .707 r
F P
0 g
s
.67545 .82859 m .67988 .84702 L .70351 .83786 L p .707 .577 .707 r
F P
0 g
s
.70351 .83786 m .69909 .81943 L .67545 .82859 L p .707 .577 .707 r
F P
0 g
s
.52549 .74934 m .51765 .69351 L .50528 .68884 L p .707 .577 .707 r
F P
0 g
s
.50528 .68884 m .51313 .74467 L .52549 .74934 L p .707 .577 .707 r
F P
0 g
s
.51313 .74467 m .50528 .68884 L .50253 .68236 L p .707 .577 .707 r
F P
0 g
s
.50253 .68236 m .51038 .73819 L .51313 .74467 L p .707 .577 .707 r
F P
0 g
s
.51038 .73819 m .50253 .68236 L .50966 .67471 L p .707 .577 .707 r
F P
0 g
s
.50966 .67471 m .51751 .73053 L .51038 .73819 L p .707 .577 .707 r
F P
0 g
s
.51751 .73053 m .50966 .67471 L .52598 .66663 L p .707 .577 .707 r
F P
0 g
s
.52598 .66663 m .53383 .72245 L .51751 .73053 L p .707 .577 .707 r
F P
0 g
s
.52693 .78441 m .53555 .8213 L .55582 .82105 L p .707 .577 .707 r
F P
0 g
s
.53555 .8213 m .52693 .78441 L .51495 .78185 L p .707 .577 .707 r
F P
0 g
s
.51495 .78185 m .52358 .81874 L .53555 .8213 L p .707 .577 .707 r
F P
0 g
s
.52358 .81874 m .51495 .78185 L .51246 .77673 L p .707 .577 .707 r
F P
0 g
s
.51246 .77673 m .52108 .81361 L .52358 .81874 L p .707 .577 .707 r
F P
0 g
s
.52108 .81361 m .51246 .77673 L .51968 .76954 L p .707 .577 .707 r
F P
0 g
s
.51968 .76954 m .5283 .80643 L .52108 .81361 L p .707 .577 .707 r
F P
0 g
s
.5283 .80643 m .51968 .76954 L .53591 .761 L p .707 .577 .707 r
F P
0 g
s
.53591 .761 m .54453 .79788 L .5283 .80643 L p .707 .577 .707 r
F P
0 g
s
.54453 .79788 m .53591 .761 L .55956 .75193 L p .707 .577 .707 r
F P
0 g
s
.49033 .82264 m .53339 .83348 L p .56045 .71615 L .707 .577 .707 r
F P
0 g
s
.64201 .36234 m .54051 .67037 L p .55674 .70764 L .707 .577 .707 r
F P
0 g
s
.56114 .71313 m .64201 .36234 L .55674 .70764 L .707 .577 .707 r
F
.55956 .75193 m .56818 .78881 L .54453 .79788 L p F P
0 g
s
.68508 .37319 m .64201 .36234 L p .56114 .71313 L .707 .577 .707 r
F P
0 g
s
.56172 .71384 m .55774 .71474 L p .55914 .71063 L .707 .577 .707 r
F P
0 g
s
.56818 .78881 m .55956 .75193 L .57917 .746 L p .707 .577 .707 r
F P
0 g
s
.57917 .746 m .58832 .74323 L p .58479 .75123 L .707 .577 .707 r
F P
0 g
s
.56818 .78881 m .57917 .746 L .58479 .75123 L .707 .577 .707 r
F
.55809 .72636 m .56959 .72365 L .56114 .71313 L F
.53339 .83348 m .5662 .73392 L p .55809 .72636 L F P
0 g
s
.5662 .73392 m .56959 .72365 L p .55809 .72636 L .707 .577 .707 r
F P
0 g
s
.56959 .72365 m .68508 .37319 L p .56114 .71313 L .707 .577 .707 r
F P
0 g
s
.54311 .87294 m .53868 .85452 L .52675 .8521 L p .707 .577 .707 r
F P
0 g
s
.53592 .85834 m .5315 .83992 L .54772 .83134 L p .707 .577 .707 r
F P
0 g
s
.56334 .87251 m .55891 .85409 L .53868 .85452 L p .707 .577 .707 r
F P
0 g
s
.53868 .85452 m .54311 .87294 L .56334 .87251 L p .707 .577 .707 r
F P
0 g
s
.54772 .83134 m .55215 .84976 L .53592 .85834 L p .707 .577 .707 r
F P
0 g
s
.68508 .37319 m .56045 .75137 L p .58387 .72784 L .707 .577 .707 r
F P
0 g
s
.55215 .84976 m .54772 .83134 L .57135 .82218 L p .707 .577 .707 r
F P
0 g
s
.59695 .78011 m .56818 .78881 L p .58456 .75175 L .707 .577 .707 r
F P
0 g
s
.58832 .74323 m .58934 .74757 L p .58456 .75175 L .707 .577 .707 r
F P
0 g
s
.58934 .74757 m .59695 .78011 L p .58456 .75175 L .707 .577 .707 r
F P
0 g
s
.57135 .82218 m .57578 .8406 L .55215 .84976 L p .707 .577 .707 r
F P
0 g
s
.628 .77263 m .61938 .73574 L .64968 .73021 L p .707 .577 .707 r
F P
0 g
s
.61938 .73574 m .61972 .73719 L p .59695 .78011 L .707 .577 .707 r
F P
0 g
s
.61972 .73719 m .628 .77263 L .59991 .7794 L p .707 .577 .707 r
F P
0 g
s
.59991 .7794 m .59695 .78011 L p .61972 .73719 L .707 .577 .707 r
F P
0 g
s
.67644 .70064 m .66859 .64481 L .68936 .64721 L p .707 .577 .707 r
F P
0 g
s
.66859 .64481 m .67644 .70064 L .6493 .70073 L p .707 .577 .707 r
F P
0 g
s
.6583 .76709 m .64968 .73021 L .67627 .72717 L p .707 .577 .707 r
F P
0 g
s
.64968 .73021 m .6583 .76709 L .628 .77263 L p .707 .577 .707 r
F P
0 g
s
.63552 .82409 m .63109 .80567 L .66135 .79993 L p .707 .577 .707 r
F P
0 g
s
.60451 .83176 m .60008 .81333 L .63109 .80567 L p .707 .577 .707 r
F P
0 g
s
.63109 .80567 m .63552 .82409 L .61645 .82881 L p .707 .577 .707 r
F P
0 g
s
.61645 .82881 m .60451 .83176 L p .62142 .81516 L .707 .577 .707 r
F P
0 g
s
.62142 .81516 m .63109 .80567 L .61645 .82881 L .707 .577 .707 r
F
.69735 .66602 m .7052 .72184 L .71233 .71419 L p F P
0 g
s
.71233 .71419 m .70448 .65836 L .69735 .66602 L p .707 .577 .707 r
F P
0 g
s
.69721 .70304 m .68936 .64721 L .70173 .65189 L p .707 .577 .707 r
F P
0 g
s
.68936 .64721 m .69721 .70304 L .67644 .70064 L p .707 .577 .707 r
F P
0 g
s
.62916 .828 m .63949 .81409 L p .74257 .48856 L .707 .577 .707 r
F P
0 g
s
.74257 .48856 m .74675 .47375 L .62916 .828 L .707 .577 .707 r
F
.748 .46736 m .62916 .828 L p .75787 .44023 L F P
0 g
s
.60638 .8363 m .62916 .828 L p .70976 .54537 L .707 .577 .707 r
F P
0 g
s
.62916 .828 m .78084 .3677 L .75806 .376 L p .707 .577 .707 r
F P
0 g
s
.63949 .81409 m .79117 .35379 L .78084 .3677 L p .707 .577 .707 r
F P
0 g
s
.68455 .59907 m .60638 .8363 L p .70976 .54537 L .707 .577 .707 r
F P
0 g
s
.6493 .70073 m .64145 .64491 L .66859 .64481 L p .707 .577 .707 r
F P
0 g
s
.64145 .64491 m .6493 .70073 L .61844 .70332 L p .707 .577 .707 r
F P
0 g
s
.60638 .8363 m .75806 .376 L .72506 .37789 L p .707 .577 .707 r
F P
0 g
s
.75806 .376 m .68455 .59907 L p .70976 .54537 L .707 .577 .707 r
F P
0 g
s
.57578 .8406 m .57135 .82218 L .60008 .81333 L p .707 .577 .707 r
F P
0 g
s
.60008 .81333 m .60451 .83176 L .57578 .8406 L p .707 .577 .707 r
F P
0 g
s
.57338 .83819 m .60638 .8363 L p .64107 .70233 L .707 .577 .707 r
F P
0 g
s
.69112 .62857 m .69331 .62313 L .67562 .60388 L .707 .577 .707 r
F
.74257 .48856 m .75787 .44023 L .74675 .47375 L F
.70408 .60253 m .69331 .62313 L .79117 .35379 L F
.67583 .6832 m .68092 .6607 L .69479 .62906 L F
.63636 .79595 m .67185 .68824 L p .67583 .6832 L F P
0 g
s
.67185 .68824 m .68092 .6607 L p .67583 .6832 L .707 .577 .707 r
F P
0 g
s
.63636 .79595 m .62809 .78547 L p .68221 .65075 L .707 .577 .707 r
F P
0 g
s
.69331 .62313 m .68553 .64673 L p .68221 .65075 L .707 .577 .707 r
F P
0 g
s
.68553 .64673 m .63636 .79595 L p .68221 .65075 L .707 .577 .707 r
F P
0 g
s
.64107 .70233 m .66135 .62398 L .60887 .73048 L .707 .577 .707 r
F
.61844 .70332 m .61759 .69728 L p .64145 .64491 L F P
0 g
s
.61759 .69728 m .61718 .69437 L p .62562 .67719 L .707 .577 .707 r
F P
0 g
s
.61759 .69728 m .62562 .67719 L .64145 .64491 L .707 .577 .707 r
F
.63954 .64507 m .64145 .64491 L p .61718 .69437 L F P
0 g
s
.66135 .62398 m .68812 .52059 L .62255 .68898 L .707 .577 .707 r
F
.72506 .37789 m .63033 .66538 L p .68812 .52059 L F P
0 g
s
.59695 .78011 m .58832 .74323 L .61938 .73574 L p .707 .577 .707 r
F P
0 g
s
.5975 .7378 m .68508 .37319 L .55307 .8358 L .707 .577 .707 r
F
.61377 .67006 m .6106 .6475 L .61936 .64676 L p F P
0 g
s
.61718 .69437 m .61759 .69728 L p .60645 .70516 L .707 .577 .707 r
F P
0 g
s
.61759 .69728 m .61844 .70332 L .61354 .70407 L p .707 .577 .707 r
F P
0 g
s
.61354 .70407 m .60645 .70516 L p .61759 .69728 L .707 .577 .707 r
F P
0 g
s
.57338 .83819 m .72506 .37789 L .68508 .37319 L p .707 .577 .707 r
F P
0 g
s
.61936 .64676 m .63954 .64507 L p .61377 .67006 L .707 .577 .707 r
F P
0 g
s
.61718 .69437 m .61377 .67006 L p .63954 .64507 L .707 .577 .707 r
F P
0 g
s
.63033 .66538 m .62255 .68898 L p .68812 .52059 L .707 .577 .707 r
F P
0 g
s
.62255 .68898 m .60887 .73048 L p .66135 .62398 L .707 .577 .707 r
F P
0 g
s
.67562 .60388 m .65485 .60147 L p .68024 .65313 L .707 .577 .707 r
F P
0 g
s
.68118 .65199 m .67562 .60388 L .68024 .65313 L .707 .577 .707 r
F
.62809 .78547 m .62008 .77534 L p .67696 .65711 L F P
0 g
s
.68221 .65075 m .67562 .60388 L p .68118 .65199 L .707 .577 .707 r
F P
0 g
s
.69479 .62906 m .68553 .64673 L .70408 .60253 L .707 .577 .707 r
F
.68092 .6607 m .68553 .64673 L p .69479 .62906 L F P
0 g
s
.68553 .64673 m .69331 .62313 L p .70408 .60253 L .707 .577 .707 r
F P
0 g
s
.67583 .6832 m .69479 .62906 L .68029 .67756 L .707 .577 .707 r
F
.71766 .57686 m .63949 .81409 L p .69479 .62906 L F P
0 g
s
.70448 .65836 m .71233 .71419 L .70958 .70771 L p .707 .577 .707 r
F P
0 g
s
.70958 .70771 m .70173 .65189 L .70448 .65836 L p .707 .577 .707 r
F P
0 g
s
.70173 .65189 m .70958 .70771 L .69721 .70304 L p .707 .577 .707 r
F P
0 g
s
.67562 .60388 m .68347 .6597 L .71061 .6596 L p .707 .577 .707 r
F P
0 g
s
.67696 .65711 m .68221 .65075 L .62809 .78547 L .707 .577 .707 r
F
.65485 .60147 m .6627 .6573 L .67557 .65879 L p F P
0 g
s
.62008 .77534 m .65515 .68351 L .67696 .65711 L .707 .577 .707 r
F
.67557 .65879 m .68347 .6597 L p .68024 .65313 L F P
0 g
s
.68024 .65313 m .65485 .60147 L .67557 .65879 L .707 .577 .707 r
F
.70008 .60379 m .67562 .60388 L p .69331 .62313 L F P
0 g
s
.78804 .33565 m .69331 .62313 L p .67696 .65711 L .707 .577 .707 r
F P
0 g
s
.65515 .68351 m .78804 .33565 L .67696 .65711 L .707 .577 .707 r
F
.67696 .65711 m .69331 .62313 L .68221 .65075 L F
.68262 .65366 m .68221 .65075 L p .68164 .65599 L F P
0 g
s
.68221 .65075 m .68118 .65199 L .68164 .65599 L .707 .577 .707 r
F
.68164 .65599 m .68118 .65199 L .68024 .65313 L F
.63949 .81409 m .63636 .79595 L p .67583 .6832 L F P
0 g
s
.67583 .6832 m .68029 .67756 L .63949 .81409 L .707 .577 .707 r
F
.66078 .7267 m .67275 .72926 L p .65949 .70386 L F P
0 g
s
.6627 .6573 m .65485 .60147 L .64249 .5968 L p .707 .577 .707 r
F P
0 g
s
.64249 .5968 m .64933 .64552 L p .6627 .6573 L .707 .577 .707 r
F P
0 g
s
.60887 .73048 m .57338 .83819 L p .64107 .70233 L .707 .577 .707 r
F P
0 g
s
.64352 .62878 m .64933 .64552 L .62008 .77534 L .707 .577 .707 r
F
.65627 .66551 m .65374 .67319 L p .64933 .64552 L F P
0 g
s
.65374 .67319 m .62008 .77534 L p .64933 .64552 L .707 .577 .707 r
F P
0 g
s
.64933 .64552 m .64249 .5968 L .64121 .59381 L p .707 .577 .707 r
F P
0 g
s
.6106 .6475 m .61718 .69437 L p .58689 .70815 L .707 .577 .707 r
F P
0 g
s
.60645 .70516 m .58689 .70815 L p .61718 .69437 L .707 .577 .707 r
F P
0 g
s
.55307 .8358 m .57338 .83819 L p .5975 .7378 L .707 .577 .707 r
F P
0 g
s
.64241 .60201 m .59223 .75428 L p .63476 .54947 L .707 .577 .707 r
F P
0 g
s
.64121 .59381 m .64104 .59339 L p .64241 .60201 L .707 .577 .707 r
F P
0 g
s
.64933 .64552 m .64121 .59381 L .64241 .60201 L .707 .577 .707 r
F
.53339 .83348 m .55307 .8358 L p .58387 .72784 L F P
0 g
s
.56045 .75137 m .53339 .83348 L p .58387 .72784 L .707 .577 .707 r
F P
0 g
s
.57905 .65232 m .58689 .70815 L .56172 .71384 L p .707 .577 .707 r
F P
0 g
s
.58689 .70815 m .57905 .65232 L .6106 .6475 L p .707 .577 .707 r
F P
0 g
s
.59223 .75428 m .55556 .73484 L p .63476 .54947 L .707 .577 .707 r
F P
0 g
s
.74391 .29398 m .64241 .60201 L p .63476 .54947 L .707 .577 .707 r
F P
0 g
s
.65202 .65326 m .6627 .6573 L p .64933 .64552 L .707 .577 .707 r
F P
0 g
s
.77176 .31504 m .65627 .66551 L p .64352 .62878 L .707 .577 .707 r
F P
0 g
s
.59223 .75428 m .74391 .29398 L .77176 .31504 L p .707 .577 .707 r
F P
0 g
s
.65033 .65263 m .64933 .64552 L p .63973 .59032 L .707 .577 .707 r
F P
0 g
s
.64104 .59339 m .63973 .59032 L p .64933 .64552 L .707 .577 .707 r
F P
0 g
s
.64933 .64552 m .65033 .65263 L .65202 .65326 L p .707 .577 .707 r
F P
0 g
s
.62008 .77534 m .59223 .75428 L p .64352 .62878 L .707 .577 .707 r
F P
0 g
s
.62008 .77534 m .77176 .31504 L .78804 .33565 L p .707 .577 .707 r
F P
0 g
s
.65216 .68982 m .65637 .70782 L p .65949 .70386 L .707 .577 .707 r
F P
0 g
s
.65637 .70782 m .66078 .7267 L p .65949 .70386 L .707 .577 .707 r
F P
0 g
s
.68757 .75033 m .69619 .78722 L .71242 .77867 L p .707 .577 .707 r
F P
0 g
s
.71242 .77867 m .7038 .74179 L .68757 .75033 L p .707 .577 .707 r
F P
0 g
s
.6849 .76405 m .67627 .72717 L .69655 .72691 L p .707 .577 .707 r
F P
0 g
s
.67627 .72717 m .6849 .76405 L .6583 .76709 L p .707 .577 .707 r
F P
0 g
s
.67275 .72926 m .69302 .72901 L p .66601 .69475 L .707 .577 .707 r
F P
0 g
s
.66413 .69238 m .66514 .69672 L p .66601 .69475 L .707 .577 .707 r
F P
0 g
s
.66514 .69672 m .67275 .72926 L p .66601 .69475 L .707 .577 .707 r
F P
0 g
s
.68347 .6597 m .68262 .65366 L p .68164 .65599 L .707 .577 .707 r
F P
0 g
s
.78084 .3677 m .748 .46736 L p .75787 .44023 L .707 .577 .707 r
F P
0 g
s
.78998 .34691 m .79117 .35379 L p .69331 .62313 L .707 .577 .707 r
F P
0 g
s
.70108 .60379 m .70008 .60379 L p .69331 .62313 L .707 .577 .707 r
F P
0 g
s
.69331 .62313 m .78804 .33565 L .78998 .34691 L p .707 .577 .707 r
F P
0 g
s
.79117 .35379 m .71766 .57686 L p .69479 .62906 L .707 .577 .707 r
F P
0 g
s
.71061 .6596 m .70276 .60378 L .70108 .60379 L p .707 .577 .707 r
F P
0 g
s
.71061 .6596 m .70108 .60379 L .69112 .62857 L .707 .577 .707 r
F
.66413 .69238 m .65216 .68982 L p .65949 .70386 L F P
0 g
s
.67275 .72926 m .66514 .69672 L p .65949 .70386 L .707 .577 .707 r
F P
0 g
s
.66514 .69672 m .66413 .69238 L p .65949 .70386 L .707 .577 .707 r
F P
0 g
s
.6844 .69212 m .66706 .69234 L p .67956 .71194 L .707 .577 .707 r
F P
0 g
s
.66706 .69234 m .66413 .69238 L p .66601 .69475 L .707 .577 .707 r
F P
0 g
s
.67956 .71194 m .66706 .69234 L .66601 .69475 L .707 .577 .707 r
F
.69302 .72901 m .68474 .69357 L p .67956 .71194 L F P
0 g
s
.68474 .69357 m .6844 .69212 L p .67956 .71194 L .707 .577 .707 r
F P
0 g
s
.55914 .71063 m .57905 .65232 L .56172 .71384 L .707 .577 .707 r
F
.54989 .65892 m .57905 .65232 L p .55914 .71063 L F P
0 g
s
.55774 .71474 m .55674 .70764 L p .55914 .71063 L .707 .577 .707 r
F P
0 g
s
.55674 .70764 m .54989 .65892 L p .55914 .71063 L .707 .577 .707 r
F P
0 g
s
.56045 .71615 m .56114 .71313 L .55674 .70764 L .707 .577 .707 r
F
.53383 .72245 m .52598 .66663 L .53729 .66298 L p F P
0 g
s
.53383 .72245 m .53729 .66298 L .53856 .66588 L .707 .577 .707 r
F
.54051 .67037 m .64201 .36234 L p .53329 .63626 L F P
0 g
s
.53884 .66248 m .54989 .65892 L p .54346 .68433 L .707 .577 .707 r
F P
0 g
s
.53383 .72245 m .53884 .66248 L .54346 .68433 L .707 .577 .707 r
F
.54989 .65892 m .55774 .71474 L .53383 .72245 L p F P
0 g
s
.54051 .67037 m .49033 .82264 L p .56045 .71615 L .707 .577 .707 r
F P
0 g
s
.53729 .66298 m .53884 .66248 L p .53856 .66588 L .707 .577 .707 r
F P
0 g
s
.64201 .36234 m .60009 .34642 L p .53329 .63626 L .707 .577 .707 r
F P
0 g
s
.49033 .82264 m .54051 .67037 L p .53329 .63626 L .707 .577 .707 r
F P
0 g
s
.44841 .80671 m .60009 .34642 L .56342 .32697 L p .707 .577 .707 r
F P
0 g
s
.60009 .34642 m .44841 .80671 L .49033 .82264 L p .707 .577 .707 r
F P
0 g
s
.69909 .81943 m .70351 .83786 L .71974 .82928 L p .707 .577 .707 r
F P
0 g
s
.71974 .82928 m .71531 .81086 L .69909 .81943 L p .707 .577 .707 r
F P
0 g
s
.41174 .78727 m .56342 .32697 L .53557 .30592 L p .707 .577 .707 r
F P
0 g
s
.56342 .32697 m .41174 .78727 L .44841 .80671 L p .707 .577 .707 r
F P
0 g
s
.7038 .74179 m .71242 .77867 L .71964 .77148 L p .707 .577 .707 r
F P
0 g
s
.71964 .77148 m .71102 .7346 L .7038 .74179 L p .707 .577 .707 r
F P
0 g
s
.52675 .8521 m .53117 .87053 L .54311 .87294 L p .707 .577 .707 r
F P
0 g
s
.71531 .81086 m .71974 .82928 L .72696 .82213 L p .707 .577 .707 r
F P
0 g
s
.72696 .82213 m .72254 .8037 L .71531 .81086 L p .707 .577 .707 r
F P
0 g
s
.38389 .76621 m .53557 .30592 L .51929 .28531 L p .707 .577 .707 r
F P
0 g
s
.53557 .30592 m .38389 .76621 L .41174 .78727 L p .707 .577 .707 r
F P
0 g
s
.71102 .7346 m .71964 .77148 L .71714 .76636 L p .707 .577 .707 r
F P
0 g
s
.71714 .76636 m .70852 .72947 L .71102 .7346 L p .707 .577 .707 r
F P
0 g
s
.53117 .87053 m .52675 .8521 L .52427 .84707 L p .707 .577 .707 r
F P
0 g
s
.52427 .84707 m .5287 .8655 L .53117 .87053 L p .707 .577 .707 r
F P
0 g
s
.72254 .8037 m .72696 .82213 L .72449 .81709 L p .707 .577 .707 r
F P
0 g
s
.72449 .81709 m .72006 .79867 L .72254 .8037 L p .707 .577 .707 r
F P
0 g
s
.26125 .70536 m .25341 .64953 L .22255 .65212 L p .707 .577 .707 r
F P
0 g
s
.25341 .64953 m .26125 .70536 L .2928 .70053 L p .707 .577 .707 r
F P
0 g
s
.2928 .70053 m .28496 .64471 L .25341 .64953 L p .707 .577 .707 r
F P
0 g
s
.28496 .64471 m .2928 .70053 L .32196 .69394 L p .707 .577 .707 r
F P
0 g
s
.32196 .69394 m .31411 .63811 L .28496 .64471 L p .707 .577 .707 r
F P
0 g
s
.2304 .70795 m .22255 .65212 L .19541 .65222 L p .707 .577 .707 r
F P
0 g
s
.22255 .65212 m .2304 .70795 L .26125 .70536 L p .707 .577 .707 r
F P
0 g
s
.37673 .75829 m .3723 .73987 L .35608 .74844 L p .707 .577 .707 r
F P
0 g
s
.36079 .68753 m .36941 .72441 L .37663 .71723 L p .707 .577 .707 r
F P
0 g
s
.37663 .71723 m .36801 .68034 L .36079 .68753 L p .707 .577 .707 r
F P
0 g
s
.36801 .68034 m .37663 .71723 L .37413 .7121 L p .707 .577 .707 r
F P
0 g
s
.35318 .73296 m .36941 .72441 L p .35126 .70372 L .707 .577 .707 r
F P
0 g
s
.34456 .69608 m .34793 .7105 L p .35126 .70372 L .707 .577 .707 r
F P
0 g
s
.34793 .7105 m .35318 .73296 L p .35126 .70372 L .707 .577 .707 r
F P
0 g
s
.36896 .74126 m .36511 .72526 L .3734 .72694 L p .707 .577 .707 r
F P
0 g
s
.3734 .72694 m .37705 .72768 L p .36896 .74126 L .707 .577 .707 r
F P
0 g
s
.36954 .74369 m .36896 .74126 L p .37705 .72768 L .707 .577 .707 r
F P
0 g
s
.36511 .72526 m .36954 .74369 L .34931 .74412 L p .707 .577 .707 r
F P
0 g
s
.36761 .74561 m .51929 .28531 L .51616 .26716 L p .707 .577 .707 r
F P
0 g
s
.36941 .72441 m .36079 .68753 L .34456 .69608 L p .707 .577 .707 r
F P
0 g
s
.37413 .7121 m .36794 .68562 L p .36801 .68034 L .707 .577 .707 r
F P
0 g
s
.36794 .68562 m .36551 .67522 L .36737 .67904 L p .707 .577 .707 r
F P
0 g
s
.36737 .67904 m .36801 .68034 L p .36794 .68562 L .707 .577 .707 r
F P
0 g
s
.36551 .67522 m .37413 .7121 L .36216 .70954 L p .707 .577 .707 r
F P
0 g
s
.51616 .26716 m .36448 .72746 L .36761 .74561 L p .707 .577 .707 r
F P
0 g
s
.52649 .25326 m .42243 .56905 L p .44206 .50582 L .707 .577 .707 r
F P
0 g
s
.42243 .56905 m .37481 .71355 L p .44206 .50582 L .707 .577 .707 r
F P
0 g
s
.37481 .71355 m .37082 .71892 L p .44206 .50582 L .707 .577 .707 r
F P
0 g
s
.37082 .71892 m .36448 .72746 L p .37013 .71092 L .707 .577 .707 r
F P
0 g
s
.37013 .71092 m .52649 .25326 L .37082 .71892 L .707 .577 .707 r
F
.51616 .26716 m .52649 .25326 L p .42123 .56136 L F P
0 g
s
.36448 .72746 m .41512 .57379 L p .42123 .56136 L .707 .577 .707 r
F P
0 g
s
.41512 .57379 m .51616 .26716 L p .42123 .56136 L .707 .577 .707 r
F P
0 g
s
.3723 .73987 m .37673 .75829 L .38395 .75114 L p .707 .577 .707 r
F P
0 g
s
.38395 .75114 m .37953 .73271 L .3723 .73987 L p .707 .577 .707 r
F P
0 g
s
.37953 .73271 m .38395 .75114 L .38148 .7461 L p .707 .577 .707 r
F P
0 g
s
.38148 .7461 m .37705 .72768 L .37953 .73271 L p .707 .577 .707 r
F P
0 g
s
.37705 .72768 m .38148 .7461 L .36954 .74369 L p .707 .577 .707 r
F P
0 g
s
.51929 .28531 m .36761 .74561 L .38389 .76621 L p .707 .577 .707 r
F P
0 g
s
.70852 .72947 m .71714 .76636 L .70517 .7638 L p .707 .577 .707 r
F P
0 g
s
.70517 .7638 m .69655 .72691 L .70852 .72947 L p .707 .577 .707 r
F P
0 g
s
.31411 .63811 m .32196 .69394 L .34587 .68623 L p .707 .577 .707 r
F P
0 g
s
.34587 .68623 m .33802 .6304 L .31411 .63811 L p .707 .577 .707 r
F P
0 g
s
.5287 .8655 m .52427 .84707 L .5315 .83992 L p .707 .577 .707 r
F P
0 g
s
.26971 .75821 m .26109 .72133 L .23078 .72686 L p .707 .577 .707 r
F P
0 g
s
.26109 .72133 m .26971 .75821 L .30076 .75073 L p .707 .577 .707 r
F P
0 g
s
.30076 .75073 m .29214 .71384 L .26109 .72133 L p .707 .577 .707 r
F P
0 g
s
.29214 .71384 m .30076 .75073 L .32952 .74203 L p .707 .577 .707 r
F P
0 g
s
.32952 .74203 m .3209 .70514 L .29214 .71384 L p .707 .577 .707 r
F P
0 g
s
.5315 .83992 m .53592 .85834 L .5287 .8655 L p .707 .577 .707 r
F P
0 g
s
.19541 .65222 m .20326 .70804 L .2304 .70795 L p .707 .577 .707 r
F P
0 g
s
.23078 .72686 m .2394 .76375 L .26971 .75821 L p .707 .577 .707 r
F P
0 g
s
.72006 .79867 m .72449 .81709 L .71255 .81468 L p .707 .577 .707 r
F P
0 g
s
.71255 .81468 m .70812 .79625 L .72006 .79867 L p .707 .577 .707 r
F P
0 g
s
.20326 .70804 m .19541 .65222 L .17464 .64982 L p .707 .577 .707 r
F P
0 g
s
.2394 .76375 m .23078 .72686 L .20419 .72991 L p .707 .577 .707 r
F P
0 g
s
.27713 .79254 m .27271 .77412 L .24245 .77985 L p .707 .577 .707 r
F P
0 g
s
.27271 .77412 m .27713 .79254 L .30814 .78487 L p .707 .577 .707 r
F P
0 g
s
.30814 .78487 m .30372 .76645 L .27271 .77412 L p .707 .577 .707 r
F P
0 g
s
.30372 .76645 m .30814 .78487 L .33687 .77603 L p .707 .577 .707 r
F P
0 g
s
.33687 .77603 m .33244 .7576 L .30372 .76645 L p .707 .577 .707 r
F P
0 g
s
.3209 .70514 m .32952 .74203 L .35318 .73296 L p .707 .577 .707 r
F P
0 g
s
.35318 .73296 m .34456 .69608 L .3209 .70514 L p .707 .577 .707 r
F P
0 g
s
.24245 .77985 m .24687 .79828 L .27713 .79254 L p .707 .577 .707 r
F P
0 g
s
.20419 .72991 m .21281 .76679 L .2394 .76375 L p .707 .577 .707 r
F P
0 g
s
.33802 .6304 m .34587 .68623 L .36219 .67815 L p .707 .577 .707 r
F P
0 g
s
.36219 .67815 m .35434 .62232 L .33802 .6304 L p .707 .577 .707 r
F P
0 g
s
.24687 .79828 m .24245 .77985 L .21591 .7831 L p .707 .577 .707 r
F P
0 g
s
.17464 .64982 m .18249 .70564 L .20326 .70804 L p .707 .577 .707 r
F P
0 g
s
.21591 .7831 m .22033 .80152 L .24687 .79828 L p .707 .577 .707 r
F P
0 g
s
.69655 .72691 m .70517 .7638 L .6849 .76405 L p .707 .577 .707 r
F P
0 g
s
.33244 .7576 m .33687 .77603 L .3605 .76687 L p .707 .577 .707 r
F P
0 g
s
.3605 .76687 m .35608 .74844 L .33244 .7576 L p .707 .577 .707 r
F P
0 g
s
.21281 .76679 m .20419 .72991 L .18392 .73016 L p .707 .577 .707 r
F P
0 g
s
.18249 .70564 m .17464 .64982 L .16227 .64515 L p .707 .577 .707 r
F P
0 g
s
.18392 .73016 m .19254 .76704 L .21281 .76679 L p .707 .577 .707 r
F P
0 g
s
.22033 .80152 m .21591 .7831 L .19567 .78353 L p .707 .577 .707 r
F P
0 g
s
.70812 .79625 m .71255 .81468 L .69232 .81511 L p .707 .577 .707 r
F P
0 g
s
.69232 .81511 m .68789 .79669 L .70812 .79625 L p .707 .577 .707 r
F P
0 g
s
.19567 .78353 m .2001 .80196 L .22033 .80152 L p .707 .577 .707 r
F P
0 g
s
.35608 .74844 m .3605 .76687 L .37673 .75829 L p .707 .577 .707 r
F P
0 g
s
.35434 .62232 m .36219 .67815 L .36932 .67049 L p .707 .577 .707 r
F P
0 g
s
.36932 .67049 m .36147 .61467 L .35434 .62232 L p .707 .577 .707 r
F P
0 g
s
.16227 .64515 m .17012 .70097 L .18249 .70564 L p .707 .577 .707 r
F P
0 g
s
.19254 .76704 m .18392 .73016 L .17195 .7276 L p .707 .577 .707 r
F P
0 g
s
.17195 .7276 m .18057 .76448 L .19254 .76704 L p .707 .577 .707 r
F P
0 g
s
.2001 .80196 m .19567 .78353 L .18374 .78111 L p .707 .577 .707 r
F P
0 g
s
.68789 .79669 m .69232 .81511 L .66578 .81836 L p .707 .577 .707 r
F P
0 g
s
.66578 .81836 m .66135 .79993 L .68789 .79669 L p .707 .577 .707 r
F P
0 g
s
.17012 .70097 m .16227 .64515 L .15952 .63867 L p .707 .577 .707 r
F P
0 g
s
.18374 .78111 m .18816 .79954 L .2001 .80196 L p .707 .577 .707 r
F P
0 g
s
.36147 .61467 m .36932 .67049 L .36657 .66401 L p .707 .577 .707 r
F P
0 g
s
.36657 .66401 m .35872 .60819 L .36147 .61467 L p .707 .577 .707 r
F P
0 g
s
.15952 .63867 m .16737 .69449 L .17012 .70097 L p .707 .577 .707 r
F P
0 g
s
.37481 .71355 m .52649 .25326 L .54927 .24495 L p .707 .577 .707 r
F P
0 g
s
.66135 .79993 m .66578 .81836 L .63552 .82409 L p .707 .577 .707 r
F P
0 g
s
.18057 .76448 m .17195 .7276 L .16945 .72247 L p .707 .577 .707 r
F P
0 g
s
.16945 .72247 m .17807 .75936 L .18057 .76448 L p .707 .577 .707 r
F P
0 g
s
.18816 .79954 m .18374 .78111 L .18126 .77608 L p .707 .577 .707 r
F P
0 g
s
.16737 .69449 m .15952 .63867 L .16665 .63101 L p .707 .577 .707 r
F P
0 g
s
.18126 .77608 m .18569 .79451 L .18816 .79954 L p .707 .577 .707 r
F P
0 g
s
.35872 .60819 m .36657 .66401 L .3542 .65934 L p .707 .577 .707 r
F P
0 g
s
.3542 .65934 m .34635 .60352 L .35872 .60819 L p .707 .577 .707 r
F P
0 g
s
.16665 .63101 m .1745 .68684 L .16737 .69449 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17807 .75936 m .16945 .72247 L .17667 .71529 L p .707 .577 .707 r
F P
0 g
s
.54927 .24495 m .39759 .70525 L .37481 .71355 L p .707 .577 .707 r
F P
0 g
s
.39759 .70525 m .54927 .24495 L .58227 .24306 L p .707 .577 .707 r
F P
0 g
s
.17667 .71529 m .18529 .75217 L .17807 .75936 L p .707 .577 .707 r
F P
0 g
s
.36216 .70954 m .35354 .67266 L .36551 .67522 L p .707 .577 .707 r
F P
0 g
s
.18569 .79451 m .18126 .77608 L .18849 .76893 L p .707 .577 .707 r
F P
0 g
s
.1745 .68684 m .16665 .63101 L .18297 .62293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18849 .76893 m .19291 .78735 L .18569 .79451 L p .707 .577 .707 r
F P
0 g
s
.34635 .60352 m .3542 .65934 L .33343 .65694 L p .707 .577 .707 r
F P
0 g
s
.33343 .65694 m .32558 .60112 L .34635 .60352 L p .707 .577 .707 r
F P
0 g
s
.18297 .62293 m .19082 .67876 L .1745 .68684 L p .707 .577 .707 r
F P
0 g
s
.18529 .75217 m .17667 .71529 L .1929 .70674 L p .707 .577 .707 r
F P
0 g
s
.43059 .70336 m .58227 .24306 L .62225 .24777 L p .707 .577 .707 r
F P
0 g
s
.58227 .24306 m .43059 .70336 L .39759 .70525 L p .707 .577 .707 r
F P
0 g
s
.1929 .70674 m .20152 .74363 L .18529 .75217 L p .707 .577 .707 r
F P
0 g
s
.19082 .67876 m .18297 .62293 L .20688 .61522 L p .707 .577 .707 r
F P
0 g
s
.55556 .73484 m .70724 .27454 L .74391 .29398 L p .707 .577 .707 r
F P
0 g
s
.35354 .67266 m .36216 .70954 L .34189 .7098 L p .707 .577 .707 r
F P
0 g
s
.34189 .7098 m .33327 .67291 L .35354 .67266 L p .707 .577 .707 r
F P
0 g
s
.19291 .78735 m .18849 .76893 L .20471 .76035 L p .707 .577 .707 r
F P
0 g
s
.20471 .76035 m .20914 .77877 L .19291 .78735 L p .707 .577 .707 r
F P
0 g
s
.32558 .60112 m .33343 .65694 L .30629 .65704 L p .707 .577 .707 r
F P
0 g
s
.30629 .65704 m .29844 .60121 L .32558 .60112 L p .707 .577 .707 r
F P
0 g
s
.34931 .74412 m .34488 .7257 L .36511 .72526 L p .707 .577 .707 r
F P
0 g
s
.20688 .61522 m .21473 .67105 L .19082 .67876 L p .707 .577 .707 r
F P
0 g
s
.47057 .70807 m .62225 .24777 L .66532 .25862 L p .707 .577 .707 r
F P
0 g
s
.62225 .24777 m .47057 .70807 L .43059 .70336 L p .707 .577 .707 r
F P
0 g
s
.70724 .27454 m .55556 .73484 L .51363 .71892 L p .707 .577 .707 r
F P
0 g
s
.51363 .71892 m .66532 .25862 L .70724 .27454 L p .707 .577 .707 r
F P
0 g
s
.20152 .74363 m .1929 .70674 L .21655 .69767 L p .707 .577 .707 r
F P
0 g
s
.21473 .67105 m .20688 .61522 L .23604 .60863 L p .707 .577 .707 r
F P
0 g
s
.66532 .25862 m .51363 .71892 L .47057 .70807 L p .707 .577 .707 r
F P
0 g
s
.33327 .67291 m .34189 .7098 L .3153 .71284 L p .707 .577 .707 r
F P
0 g
s
.3153 .71284 m .30667 .67595 L .33327 .67291 L p .707 .577 .707 r
F P
0 g
s
.29844 .60121 m .30629 .65704 L .27543 .65963 L p .707 .577 .707 r
F P
0 g
s
.27543 .65963 m .26759 .6038 L .29844 .60121 L p .707 .577 .707 r
F P
0 g
s
.21655 .69767 m .22517 .73456 L .20152 .74363 L p .707 .577 .707 r
F P
0 g
s
.20914 .77877 m .20471 .76035 L .22834 .75119 L p .707 .577 .707 r
F P
0 g
s
.24388 .66445 m .23604 .60863 L .26759 .6038 L p .707 .577 .707 r
F P
0 g
s
.23604 .60863 m .24388 .66445 L .21473 .67105 L p .707 .577 .707 r
F P
0 g
s
.22834 .75119 m .23277 .76961 L .20914 .77877 L p .707 .577 .707 r
F P
0 g
s
.26759 .6038 m .27543 .65963 L .24388 .66445 L p .707 .577 .707 r
F P
0 g
s
.74147 .65702 m .73362 .60119 L .70276 .60378 L p .707 .577 .707 r
F P
0 g
s
.73362 .60119 m .74147 .65702 L .77302 .65219 L p .707 .577 .707 r
F P
0 g
s
.77302 .65219 m .76517 .59636 L .73362 .60119 L p .707 .577 .707 r
F P
0 g
s
.34488 .7257 m .34931 .74412 L .32277 .74737 L p .707 .577 .707 r
F P
0 g
s
.32277 .74737 m .31834 .72894 L .34488 .7257 L p .707 .577 .707 r
F P
0 g
s
.76517 .59636 m .77302 .65219 L .80217 .6456 L p .707 .577 .707 r
F P
0 g
s
.80217 .6456 m .79433 .58977 L .76517 .59636 L p .707 .577 .707 r
F P
0 g
s
.22517 .73456 m .21655 .69767 L .24532 .68897 L p .707 .577 .707 r
F P
0 g
s
.30667 .67595 m .3153 .71284 L .28499 .71837 L p .707 .577 .707 r
F P
0 g
s
.28499 .71837 m .27637 .68149 L .30667 .67595 L p .707 .577 .707 r
F P
0 g
s
.70276 .60378 m .71061 .6596 L .74147 .65702 L p .707 .577 .707 r
F P
0 g
s
.24532 .68897 m .25394 .72586 L .22517 .73456 L p .707 .577 .707 r
F P
0 g
s
.79433 .58977 m .80217 .6456 L .82608 .63788 L p .707 .577 .707 r
F P
0 g
s
.82608 .63788 m .81823 .58206 L .79433 .58977 L p .707 .577 .707 r
F P
0 g
s
.23277 .76961 m .22834 .75119 L .25707 .74234 L p .707 .577 .707 r
F P
0 g
s
.25394 .72586 m .24532 .68897 L .27637 .68149 L p .707 .577 .707 r
F P
0 g
s
.27637 .68149 m .28499 .71837 L .25394 .72586 L p .707 .577 .707 r
F P
0 g
s
.25707 .74234 m .2615 .76077 L .23277 .76961 L p .707 .577 .707 r
F P
0 g
s
.31834 .72894 m .32277 .74737 L .29251 .7531 L p .707 .577 .707 r
F P
0 g
s
.29251 .7531 m .28808 .73468 L .31834 .72894 L p .707 .577 .707 r
F P
0 g
s
.74992 .72043 m .7413 .68355 L .711 .68908 L p .707 .577 .707 r
F P
0 g
s
.7413 .68355 m .74992 .72043 L .78098 .71295 L p .707 .577 .707 r
F P
0 g
s
.78098 .71295 m .77235 .67606 L .7413 .68355 L p .707 .577 .707 r
F P
0 g
s
.77235 .67606 m .78098 .71295 L .80974 .70424 L p .707 .577 .707 r
F P
0 g
s
.80974 .70424 m .80112 .66736 L .77235 .67606 L p .707 .577 .707 r
F P
0 g
s
.2615 .76077 m .25707 .74234 L .28808 .73468 L p .707 .577 .707 r
F P
0 g
s
.28808 .73468 m .29251 .7531 L .2615 .76077 L p .707 .577 .707 r
F P
0 g
s
.711 .68908 m .71962 .72597 L .74992 .72043 L p .707 .577 .707 r
F P
0 g
s
.71962 .72597 m .711 .68908 L .6844 .69212 L p .707 .577 .707 r
F P
0 g
s
.80112 .66736 m .80974 .70424 L .83339 .69518 L p .707 .577 .707 r
F P
0 g
s
.83339 .69518 m .82477 .65829 L .80112 .66736 L p .707 .577 .707 r
F P
0 g
s
.81823 .58206 m .82608 .63788 L .8424 .6298 L p .707 .577 .707 r
F P
0 g
s
.8424 .6298 m .83455 .57398 L .81823 .58206 L p .707 .577 .707 r
F P
0 g
s
.75735 .77149 m .75292 .75307 L .72266 .7588 L p .707 .577 .707 r
F P
0 g
s
.75292 .75307 m .75735 .77149 L .78836 .76383 L p .707 .577 .707 r
F P
0 g
s
.78836 .76383 m .78393 .7454 L .75292 .75307 L p .707 .577 .707 r
F P
0 g
s
.6844 .69212 m .69302 .72901 L .71962 .72597 L p .707 .577 .707 r
F P
0 g
s
.78393 .7454 m .78836 .76383 L .81708 .75498 L p .707 .577 .707 r
F P
0 g
s
.81708 .75498 m .81266 .73656 L .78393 .7454 L p .707 .577 .707 r
F P
0 g
s
.72266 .7588 m .72709 .77723 L .75735 .77149 L p .707 .577 .707 r
F P
0 g
s
.72709 .77723 m .72266 .7588 L .69612 .76205 L p .707 .577 .707 r
F P
0 g
s
.69612 .76205 m .70054 .78047 L .72709 .77723 L p .707 .577 .707 r
F P
0 g
s
.81266 .73656 m .81708 .75498 L .84072 .74582 L p .707 .577 .707 r
F P
0 g
s
.84072 .74582 m .83629 .7274 L .81266 .73656 L p .707 .577 .707 r
F P
0 g
s
.82477 .65829 m .83339 .69518 L .84962 .68663 L p .707 .577 .707 r
F P
0 g
s
.84962 .68663 m .841 .64975 L .82477 .65829 L p .707 .577 .707 r
F P
0 g
s
.83455 .57398 m .8424 .6298 L .84953 .62215 L p .707 .577 .707 r
F P
0 g
s
.84953 .62215 m .84169 .56633 L .83455 .57398 L p .707 .577 .707 r
F P
0 g
s
.70054 .78047 m .69612 .76205 L .67589 .76248 L p .707 .577 .707 r
F P
0 g
s
.67589 .76248 m .68031 .78091 L .70054 .78047 L p .707 .577 .707 r
F P
0 g
s
.83629 .7274 m .84072 .74582 L .85694 .73724 L p .707 .577 .707 r
F P
0 g
s
.85694 .73724 m .85251 .71882 L .83629 .7274 L p .707 .577 .707 r
F P
0 g
s
.841 .64975 m .84962 .68663 L .85684 .67945 L p .707 .577 .707 r
F P
0 g
s
.85684 .67945 m .84822 .64256 L .841 .64975 L p .707 .577 .707 r
F P
0 g
s
.68031 .78091 m .67589 .76248 L .66395 .76007 L p .707 .577 .707 r
F P
0 g
s
.66395 .76007 m .66838 .77849 L .68031 .78091 L p .707 .577 .707 r
F P
0 g
s
.84169 .56633 m .84953 .62215 L .84678 .61567 L p .707 .577 .707 r
F P
0 g
s
.84678 .61567 m .83893 .55985 L .84169 .56633 L p .707 .577 .707 r
F P
0 g
s
.63973 .59032 m .64758 .64615 L .65033 .65263 L p .707 .577 .707 r
F P
0 g
s
.85251 .71882 m .85694 .73724 L .86417 .73009 L p .707 .577 .707 r
F P
0 g
s
.86417 .73009 m .85974 .71166 L .85251 .71882 L p .707 .577 .707 r
F P
0 g
s
.66078 .7267 m .65216 .68982 L .64966 .68469 L p .707 .577 .707 r
F P
0 g
s
.64966 .68469 m .65828 .72158 L .66078 .7267 L p .707 .577 .707 r
F P
0 g
s
.84822 .64256 m .85684 .67945 L .85435 .67432 L p .707 .577 .707 r
F P
0 g
s
.85435 .67432 m .84573 .63744 L .84822 .64256 L p .707 .577 .707 r
F P
0 g
s
.64758 .64615 m .63973 .59032 L .64687 .58267 L p .707 .577 .707 r
F P
0 g
s
.66838 .77849 m .66395 .76007 L .66147 .75503 L p .707 .577 .707 r
F P
0 g
s
.66147 .75503 m .6659 .77346 L .66838 .77849 L p .707 .577 .707 r
F P
0 g
s
.83893 .55985 m .84678 .61567 L .83442 .611 L p .707 .577 .707 r
F P
0 g
s
.83442 .611 m .82657 .55518 L .83893 .55985 L p .707 .577 .707 r
F P
0 g
s
.64687 .58267 m .65471 .63849 L .64758 .64615 L p .707 .577 .707 r
F P
0 g
s
.85974 .71166 m .86417 .73009 L .86169 .72506 L p .707 .577 .707 r
F P
0 g
s
.86169 .72506 m .85727 .70663 L .85974 .71166 L p .707 .577 .707 r
F P
0 g
s
.39846 .61332 m .39061 .55749 L .35975 .56008 L p .707 .577 .707 r
F P
0 g
s
.39061 .55749 m .39846 .61332 L .43001 .60849 L p .707 .577 .707 r
F P
0 g
s
.43001 .60849 m .42216 .55267 L .39061 .55749 L p .707 .577 .707 r
F P
0 g
s
.65828 .72158 m .64966 .68469 L .65688 .6775 L p .707 .577 .707 r
F P
0 g
s
.42216 .55267 m .43001 .60849 L .45916 .6019 L p .707 .577 .707 r
F P
0 g
s
.45916 .6019 m .45132 .54608 L .42216 .55267 L p .707 .577 .707 r
F P
0 g
s
.65688 .6775 m .6655 .71439 L .65828 .72158 L p .707 .577 .707 r
F P
0 g
s
.3676 .61591 m .35975 .56008 L .33261 .56018 L p .707 .577 .707 r
F P
0 g
s
.35975 .56008 m .3676 .61591 L .39846 .61332 L p .707 .577 .707 r
F P
0 g
s
.84573 .63744 m .85435 .67432 L .84237 .67176 L p .707 .577 .707 r
F P
0 g
s
.84237 .67176 m .83375 .63488 L .84573 .63744 L p .707 .577 .707 r
F P
0 g
s
.65471 .63849 m .64687 .58267 L .66319 .57459 L p .707 .577 .707 r
F P
0 g
s
.45132 .54608 m .45916 .6019 L .48307 .59419 L p .707 .577 .707 r
F P
0 g
s
.48307 .59419 m .47522 .53836 L .45132 .54608 L p .707 .577 .707 r
F P
0 g
s
.6659 .77346 m .66147 .75503 L .6687 .74788 L p .707 .577 .707 r
F P
0 g
s
.40691 .66617 m .39829 .62929 L .36799 .63482 L p .707 .577 .707 r
F P
0 g
s
.39829 .62929 m .40691 .66617 L .43797 .65869 L p .707 .577 .707 r
F P
0 g
s
.43797 .65869 m .42934 .62181 L .39829 .62929 L p .707 .577 .707 r
F P
0 g
s
.42934 .62181 m .43797 .65869 L .46673 .64999 L p .707 .577 .707 r
F P
0 g
s
.46673 .64999 m .45811 .6131 L .42934 .62181 L p .707 .577 .707 r
F P
0 g
s
.6687 .74788 m .67313 .7663 L .6659 .77346 L p .707 .577 .707 r
F P
0 g
s
.82657 .55518 m .83442 .611 L .81365 .6086 L p .707 .577 .707 r
F P
0 g
s
.81365 .6086 m .8058 .55277 L .82657 .55518 L p .707 .577 .707 r
F P
0 g
s
.33261 .56018 m .34046 .61601 L .3676 .61591 L p .707 .577 .707 r
F P
0 g
s
.66319 .57459 m .67103 .63042 L .65471 .63849 L p .707 .577 .707 r
F P
0 g
s
.36799 .63482 m .37661 .67171 L .40691 .66617 L p .707 .577 .707 r
F P
0 g
s
.85727 .70663 m .86169 .72506 L .84975 .72264 L p .707 .577 .707 r
F P
0 g
s
.84975 .72264 m .84533 .70421 L .85727 .70663 L p .707 .577 .707 r
F P
0 g
s
.34046 .61601 m .33261 .56018 L .31184 .55778 L p .707 .577 .707 r
F P
0 g
s
.37661 .67171 m .36799 .63482 L .34139 .63787 L p .707 .577 .707 r
F P
0 g
s
.41434 .7005 m .40991 .68208 L .37965 .68781 L p .707 .577 .707 r
F P
0 g
s
.40991 .68208 m .41434 .7005 L .44535 .69284 L p .707 .577 .707 r
F P
0 g
s
.44535 .69284 m .44092 .67441 L .40991 .68208 L p .707 .577 .707 r
F P
0 g
s
.44092 .67441 m .44535 .69284 L .47407 .68399 L p .707 .577 .707 r
F P
0 g
s
.47407 .68399 m .46965 .66557 L .44092 .67441 L p .707 .577 .707 r
F P
0 g
s
.45811 .6131 m .46673 .64999 L .49038 .64092 L p .707 .577 .707 r
F P
0 g
s
.49038 .64092 m .48176 .60404 L .45811 .6131 L p .707 .577 .707 r
F P
0 g
s
.37965 .68781 m .38408 .70624 L .41434 .7005 L p .707 .577 .707 r
F P
0 g
s
.6655 .71439 m .65688 .6775 L .67311 .66896 L p .707 .577 .707 r
F P
0 g
s
.34139 .63787 m .35001 .67475 L .37661 .67171 L p .707 .577 .707 r
F P
0 g
s
.47522 .53836 m .48307 .59419 L .49939 .58611 L p .707 .577 .707 r
F P
0 g
s
.49939 .58611 m .49154 .53028 L .47522 .53836 L p .707 .577 .707 r
F P
0 g
s
.38408 .70624 m .37965 .68781 L .35311 .69106 L p .707 .577 .707 r
F P
0 g
s
.67103 .63042 m .66319 .57459 L .68709 .56688 L p .707 .577 .707 r
F P
0 g
s
.31184 .55778 m .31969 .6136 L .34046 .61601 L p .707 .577 .707 r
F P
0 g
s
.67311 .66896 m .68173 .70584 L .6655 .71439 L p .707 .577 .707 r
F P
0 g
s
.35311 .69106 m .35753 .70948 L .38408 .70624 L p .707 .577 .707 r
F P
0 g
s
.83375 .63488 m .84237 .67176 L .8221 .67201 L p .707 .577 .707 r
F P
0 g
s
.8221 .67201 m .81348 .63513 L .83375 .63488 L p .707 .577 .707 r
F P
0 g
s
.46965 .66557 m .47407 .68399 L .49771 .67483 L p .707 .577 .707 r
F P
0 g
s
.49771 .67483 m .49328 .65641 L .46965 .66557 L p .707 .577 .707 r
F P
0 g
s
.35001 .67475 m .34139 .63787 L .32112 .63812 L p .707 .577 .707 r
F P
0 g
s
.8058 .55277 m .81365 .6086 L .7865 .60869 L p .707 .577 .707 r
F P
0 g
s
.7865 .60869 m .77866 .55287 L .8058 .55277 L p .707 .577 .707 r
F P
0 g
s
.67313 .7663 m .6687 .74788 L .68493 .7393 L p .707 .577 .707 r
F P
0 g
s
.68709 .56688 m .69494 .6227 L .67103 .63042 L p .707 .577 .707 r
F P
0 g
s
.48176 .60404 m .49038 .64092 L .50661 .63238 L p .707 .577 .707 r
F P
0 g
s
.50661 .63238 m .49799 .59549 L .48176 .60404 L p .707 .577 .707 r
F P
0 g
s
.31969 .6136 m .31184 .55778 L .29947 .55311 L p .707 .577 .707 r
F P
0 g
s
.68493 .7393 m .68935 .75773 L .67313 .7663 L p .707 .577 .707 r
F P
0 g
s
.32112 .63812 m .32974 .67501 L .35001 .67475 L p .707 .577 .707 r
F P
0 g
s
.35753 .70948 m .35311 .69106 L .33288 .69149 L p .707 .577 .707 r
F P
0 g
s
.84533 .70421 m .84975 .72264 L .82952 .72307 L p .707 .577 .707 r
F P
0 g
s
.82952 .72307 m .8251 .70465 L .84533 .70421 L p .707 .577 .707 r
F P
0 g
s
.69494 .6227 m .68709 .56688 L .71625 .56028 L p .707 .577 .707 r
F P
0 g
s
.33288 .69149 m .3373 .70992 L .35753 .70948 L p .707 .577 .707 r
F P
0 g
s
.68173 .70584 m .67311 .66896 L .69677 .65989 L p .707 .577 .707 r
F P
0 g
s
.49328 .65641 m .49771 .67483 L .51393 .66625 L p .707 .577 .707 r
F P
0 g
s
.51393 .66625 m .5095 .64783 L .49328 .65641 L p .707 .577 .707 r
F P
0 g
s
.49154 .53028 m .49939 .58611 L .50652 .57845 L p .707 .577 .707 r
F P
0 g
s
.50652 .57845 m .49868 .52263 L .49154 .53028 L p .707 .577 .707 r
F P
0 g
s
.77866 .55287 m .7865 .60869 L .75565 .61128 L p .707 .577 .707 r
F P
0 g
s
.75565 .61128 m .7478 .55546 L .77866 .55287 L p .707 .577 .707 r
F P
0 g
s
.29947 .55311 m .30732 .60893 L .31969 .6136 L p .707 .577 .707 r
F P
0 g
s
.81348 .63513 m .8221 .67201 L .79551 .67506 L p .707 .577 .707 r
F P
0 g
s
.79551 .67506 m .78689 .63817 L .81348 .63513 L p .707 .577 .707 r
F P
0 g
s
.69677 .65989 m .70539 .69678 L .68173 .70584 L p .707 .577 .707 r
F P
0 g
s
.7241 .61611 m .71625 .56028 L .7478 .55546 L p .707 .577 .707 r
F P
0 g
s
.71625 .56028 m .7241 .61611 L .69494 .6227 L p .707 .577 .707 r
F P
0 g
s
.32974 .67501 m .32112 .63812 L .30915 .63556 L p .707 .577 .707 r
F P
0 g
s
.7478 .55546 m .75565 .61128 L .7241 .61611 L p .707 .577 .707 r
F P
0 g
s
.68935 .75773 m .68493 .7393 L .70856 .73014 L p .707 .577 .707 r
F P
0 g
s
.30915 .63556 m .31777 .67244 L .32974 .67501 L p .707 .577 .707 r
F P
0 g
s
.49799 .59549 m .50661 .63238 L .51383 .62519 L p .707 .577 .707 r
F P
0 g
s
.51383 .62519 m .50521 .58831 L .49799 .59549 L p .707 .577 .707 r
F P
0 g
s
.70856 .73014 m .71298 .74857 L .68935 .75773 L p .707 .577 .707 r
F P
0 g
s
.70539 .69678 m .69677 .65989 L .72553 .65119 L p .707 .577 .707 r
F P
0 g
s
.3373 .70992 m .33288 .69149 L .32094 .68908 L p .707 .577 .707 r
F P
0 g
s
.8251 .70465 m .82952 .72307 L .80298 .72632 L p .707 .577 .707 r
F P
0 g
s
.80298 .72632 m .79856 .70789 L .8251 .70465 L p .707 .577 .707 r
F P
0 g
s
.30732 .60893 m .29947 .55311 L .29672 .54663 L p .707 .577 .707 r
F P
0 g
s
.78689 .63817 m .79551 .67506 L .7652 .68059 L p .707 .577 .707 r
F P
0 g
s
.7652 .68059 m .75658 .64371 L .78689 .63817 L p .707 .577 .707 r
F P
0 g
s
.32094 .68908 m .32537 .7075 L .3373 .70992 L p .707 .577 .707 r
F P
0 g
s
.72553 .65119 m .73415 .68807 L .70539 .69678 L p .707 .577 .707 r
F P
0 g
s
.5095 .64783 m .51393 .66625 L .52116 .6591 L p .707 .577 .707 r
F P
0 g
s
.52116 .6591 m .51673 .64067 L .5095 .64783 L p .707 .577 .707 r
F P
0 g
s
.73415 .68807 m .72553 .65119 L .75658 .64371 L p .707 .577 .707 r
F P
0 g
s
.75658 .64371 m .7652 .68059 L .73415 .68807 L p .707 .577 .707 r
F P
0 g
s
.49868 .52263 m .50652 .57845 L .50377 .57198 L p .707 .577 .707 r
F P
0 g
s
.50377 .57198 m .49592 .51615 L .49868 .52263 L p .707 .577 .707 r
F P
0 g
s
.29672 .54663 m .30457 .60245 L .30732 .60893 L p .707 .577 .707 r
F P
0 g
s
.71298 .74857 m .70856 .73014 L .73729 .7213 L p .707 .577 .707 r
F P
0 g
s
.73729 .7213 m .74171 .73972 L .71298 .74857 L p .707 .577 .707 r
F P
0 g
s
.79856 .70789 m .80298 .72632 L .77272 .73205 L p .707 .577 .707 r
F P
0 g
s
.77272 .73205 m .7683 .71363 L .79856 .70789 L p .707 .577 .707 r
F P
0 g
s
.31777 .67244 m .30915 .63556 L .30665 .63043 L p .707 .577 .707 r
F P
0 g
s
.74171 .73972 m .73729 .7213 L .7683 .71363 L p .707 .577 .707 r
F P
0 g
s
.30665 .63043 m .31527 .66732 L .31777 .67244 L p .707 .577 .707 r
F P
0 g
s
.7683 .71363 m .77272 .73205 L .74171 .73972 L p .707 .577 .707 r
F P
0 g
s
.50521 .58831 m .51383 .62519 L .51134 .62006 L p .707 .577 .707 r
F P
0 g
s
.51134 .62006 m .50271 .58318 L .50521 .58831 L p .707 .577 .707 r
F P
0 g
s
.32537 .7075 m .32094 .68908 L .31846 .68404 L p .707 .577 .707 r
F P
0 g
s
.30457 .60245 m .29672 .54663 L .30386 .53897 L p .707 .577 .707 r
F P
0 g
s
.31846 .68404 m .32289 .70247 L .32537 .7075 L p .707 .577 .707 r
F P
0 g
s
.51673 .64067 m .52116 .6591 L .51868 .65407 L p .707 .577 .707 r
F P
0 g
s
.51868 .65407 m .51426 .63564 L .51673 .64067 L p .707 .577 .707 r
F P
0 g
s
.49592 .51615 m .50377 .57198 L .49141 .56731 L p .707 .577 .707 r
F P
0 g
s
.49141 .56731 m .48356 .51148 L .49592 .51615 L p .707 .577 .707 r
F P
0 g
s
.30386 .53897 m .3117 .5948 L .30457 .60245 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31527 .66732 m .30665 .63043 L .31387 .62325 L p .707 .577 .707 r
F P
0 g
s
.31387 .62325 m .32249 .66013 L .31527 .66732 L p .707 .577 .707 r
F P
0 g
s
.50271 .58318 m .51134 .62006 L .49936 .6175 L p .707 .577 .707 r
F P
0 g
s
.49936 .6175 m .49074 .58062 L .50271 .58318 L p .707 .577 .707 r
F P
0 g
s
.32289 .70247 m .31846 .68404 L .32569 .67689 L p .707 .577 .707 r
F P
0 g
s
.3117 .5948 m .30386 .53897 L .32018 .5309 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32569 .67689 m .33012 .69531 L .32289 .70247 L p .707 .577 .707 r
F P
0 g
s
.51426 .63564 m .51868 .65407 L .50674 .65165 L p .707 .577 .707 r
F P
0 g
s
.50674 .65165 m .50232 .63322 L .51426 .63564 L p .707 .577 .707 r
F P
0 g
s
.48356 .51148 m .49141 .56731 L .47064 .5649 L p .707 .577 .707 r
F P
0 g
s
.47064 .5649 m .46279 .50908 L .48356 .51148 L p .707 .577 .707 r
F P
0 g
s
.32018 .5309 m .32802 .58672 L .3117 .5948 L p .707 .577 .707 r
F P
0 g
s
.32249 .66013 m .31387 .62325 L .3301 .6147 L p .707 .577 .707 r
F P
0 g
s
.3301 .6147 m .33872 .65159 L .32249 .66013 L p .707 .577 .707 r
F P
0 g
s
.32802 .58672 m .32018 .5309 L .34408 .52318 L p .707 .577 .707 r
F P
0 g
s
.49074 .58062 m .49936 .6175 L .47909 .61776 L p .707 .577 .707 r
F P
0 g
s
.47909 .61776 m .47047 .58087 L .49074 .58062 L p .707 .577 .707 r
F P
0 g
s
.33012 .69531 m .32569 .67689 L .34192 .66831 L p .707 .577 .707 r
F P
0 g
s
.34192 .66831 m .34634 .68674 L .33012 .69531 L p .707 .577 .707 r
F P
0 g
s
.46279 .50908 m .47064 .5649 L .44349 .565 L p .707 .577 .707 r
F P
0 g
s
.44349 .565 m .43565 .50917 L .46279 .50908 L p .707 .577 .707 r
F P
0 g
s
.50232 .63322 m .50674 .65165 L .48651 .65208 L p .707 .577 .707 r
F P
0 g
s
.48651 .65208 m .48209 .63366 L .50232 .63322 L p .707 .577 .707 r
F P
0 g
s
.34408 .52318 m .35193 .57901 L .32802 .58672 L p .707 .577 .707 r
F P
0 g
s
.33872 .65159 m .3301 .6147 L .35376 .60563 L p .707 .577 .707 r
F P
0 g
s
.35193 .57901 m .34408 .52318 L .37324 .51659 L p .707 .577 .707 r
F P
0 g
s
.47047 .58087 m .47909 .61776 L .4525 .6208 L p .707 .577 .707 r
F P
0 g
s
.4525 .6208 m .44388 .58391 L .47047 .58087 L p .707 .577 .707 r
F P
0 g
s
.43565 .50917 m .44349 .565 L .41264 .56759 L p .707 .577 .707 r
F P
0 g
s
.41264 .56759 m .40479 .51176 L .43565 .50917 L p .707 .577 .707 r
F P
0 g
s
.35376 .60563 m .36238 .64252 L .33872 .65159 L p .707 .577 .707 r
F P
0 g
s
.34634 .68674 m .34192 .66831 L .36555 .65915 L p .707 .577 .707 r
F P
0 g
s
.38109 .57241 m .37324 .51659 L .40479 .51176 L p .707 .577 .707 r
F P
0 g
s
.37324 .51659 m .38109 .57241 L .35193 .57901 L p .707 .577 .707 r
F P
0 g
s
.36555 .65915 m .36997 .67758 L .34634 .68674 L p .707 .577 .707 r
F P
0 g
s
.40479 .51176 m .41264 .56759 L .38109 .57241 L p .707 .577 .707 r
F P
0 g
s
.48209 .63366 m .48651 .65208 L .45997 .65533 L p .707 .577 .707 r
F P
0 g
s
.45997 .65533 m .45554 .6369 L .48209 .63366 L p .707 .577 .707 r
F P
0 g
s
.36238 .64252 m .35376 .60563 L .38252 .59693 L p .707 .577 .707 r
F P
0 g
s
.44388 .58391 m .4525 .6208 L .42219 .62633 L p .707 .577 .707 r
F P
0 g
s
.42219 .62633 m .41357 .58945 L .44388 .58391 L p .707 .577 .707 r
F P
0 g
s
.38252 .59693 m .39114 .63382 L .36238 .64252 L p .707 .577 .707 r
F P
0 g
s
.36997 .67758 m .36555 .65915 L .39428 .65031 L p .707 .577 .707 r
F P
0 g
s
.39114 .63382 m .38252 .59693 L .41357 .58945 L p .707 .577 .707 r
F P
0 g
s
.41357 .58945 m .42219 .62633 L .39114 .63382 L p .707 .577 .707 r
F P
0 g
s
.39428 .65031 m .3987 .66873 L .36997 .67758 L p .707 .577 .707 r
F P
0 g
s
.45554 .6369 m .45997 .65533 L .42971 .66106 L p .707 .577 .707 r
F P
0 g
s
.42971 .66106 m .42529 .64264 L .45554 .6369 L p .707 .577 .707 r
F P
0 g
s
.3987 .66873 m .39428 .65031 L .42529 .64264 L p .707 .577 .707 r
F P
0 g
s
.42529 .64264 m .42971 .66106 L .3987 .66873 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Vgoo4000LWoo002IOol200000eYF001JEP07FUH00`00FUIJEP03FUH8001ZOol009Moo`80009JEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00@006Ioo`00UGoo0P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH01EYF1000HWoo002DOol20005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH4001NOol009=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00]JEP04001JEP00001LOol009=oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF009JEP8005Yoo`00TWoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02eYF00<005YFFUH015YF0`00Egoo002BOol20005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH2001EOol0095oo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP8005=oo`00TGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02eYF
0`00DGoo002AOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJ
EP0>FUH2001?Ool0091oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00]JEP03001JEUYF00=JEP8004eoo`00T7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YFFUH01EYF0P00Bgoo002@
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH20019Ool008moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP8004Qoo`00Sgoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YFFUH02eYF0P00AWoo
002?Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH00`00Oomoo`13Ool008ioo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00=JEP03001oogoo049oo`00SWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02eYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF0P00@Woo002>Ool20005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00Oomoo`0oOol008eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00]JEP03001JEUYF00]JEP03001JEUYF00QJEP03Ool005YF00QJEP80041o
o`00SGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF0000@7oo002=Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUIJEP00?goo002<Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF0000?Woo002<
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00Oomoo`0lOol008aoo`8000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo03]oo`00Rgoo0`001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00<007ooOol0>goo002;Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00goo001JEP08FUH00`00FUIJ
EP03FUH00`00FUH0000lOol008]oo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00
03aoo`00RWoo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000?7oo002:Ool00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00?7oo002:Ool20005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00?7oo0029Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH00`00FUH0000mOol008Uoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00]JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF000mOol008Uoo`8000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]J
EP03001JEUYF00YJEP03001JEUYF00MJEP03OomJEP0000UJEP03001JEUYF00=JEP04001JEUYF000m
Ool008Qoo`<000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0003ioo`00R7oo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000?Woo0028Ool20006FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH01000FUIJEP00?Woo0027Ool30005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH0000oOol008Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEP0003moo`00Qgoo0P001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH003moo`00
QWoo0`001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000@7oo0026Ool00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00010Ool008Ioo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0010Ool008Eoo`<000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP00045oo`00QGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
0000@Goo0025Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00@Goo0024Ool3
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00012Ool008Aoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP80
00QJEP03001JEUYF00AJEP03001JEP00049oo`00Q7oo0P001UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH0049oo`00Pgoo0`001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
@goo0023Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH20008FUH00`00FUIJEP04FUH00`00FUH00013Ool008=oo`8000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP04001JEUYF0013Ool0089oo`<000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0004Aoo`00PWoo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF0P0025YF0P001EYF00<005YF0000A7oo0022Ool2
0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00A7oo0021Ool30005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH00015Ool0085oo`<000EJEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP8000EJEP03001JEP00
04Eoo`00PGoo0P001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF0000AGoo0020Ool30005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00016Ool0081oo`<000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJ
EP8000EJEP03001JEP0004Ioo`00P7oo0P001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
0000AWoo001oOol30005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00017Ool007moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP8000EJEP03001JEP0004Moo`00Ogoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YF0000Agoo001nOol30005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUIJEP00Agoo001nOol30005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH20005FUH00`00FUH00018Ool007ioo`8000IJ
EP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0004Qoo`00OGoo0`001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@005YFFUH004Qoo`00OGoo0`001EYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF0P001EYF00<005YF
0000BGoo001mOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00019Ool0
07aoo`<000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0019Ool007aoo`<000EJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004Yoo`00O7oo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF0000BWoo001hOol>0006FUH00`00FUIJEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
BWoo001_Ool90003FUH00`00FUIJEP05FUH00`00FUIJEP0500000eYF001JEP09FUH00`00FUIJEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001;
Ool006Qoo`L000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000:
FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH0001;Ool006Aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYF000:FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001;Ool0065oo`<000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00
04aoo`00Ggoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YFFUIJEP0000QJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEP0004aoo`00GGoo0P000UYF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000QJEP03001J
EUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0004aoo`00FWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0004eoo`00F7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000MJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0004eoo`00EWoo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P001UYF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF0000CGoo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00
FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH0001>Ool005Aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJ
EP0;FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH00gooFUIJEP04FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUH0001>Ool005Aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00005
FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH0001>Ool005Aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH00004OolI000bOol005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH00UYF00=ooeYFFUH015YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF000010000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00<7oo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00EGoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3P000eYF
00D005YFFUIJEP00009JEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000^Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF009JEPT000MJEP03001JEUYF00AJEPD0009JEP04001JEUYF000=FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH0
0`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH400000eYF001JEP06
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEP00
FUH0;Goo001EOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00003EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF02eoo`00EGoo00<005YF
00001EYF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00D005YF001JEP0000eJEP03001JEUYF00YJEP03001JEUYF00UJEP<00003FUH0
05YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001JEP0000EJEP03001JEP0000<000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPh0009JEP03001JEUYF00]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`04001JEUYF
0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH90003FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000eJEP03001JEUYF00YJEP03001JEUYF00QJEP8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002aoo`00EGoo00@005YFFUH0009JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00L000AJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000=FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9J
EP<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008000eJEP03001JEUYF00YJEP03001JEUYF00MJEP04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`9JEP8000EJEP03001JEUYF00EJEP04
001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00P00;7oo001AOol5000015YF001JEP001EYF00<005YFFUH01EYF00H005YF000005YF0009FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000/Ool004Yoo`L0
00=JEP04001JEP000002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF00<005YFFUH0
2UYF00@005YFFUH000QJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000/Ool004Ioo`@0
009JEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP030007FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF000035YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ao
o`00?goo1`001UYF00<005YFFUH01UYF00H005YF000005YF0004FUH400000eYF001JEP07FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP04FUHJ0002FUH2000[Ool003Yoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIJEP02000:FUH00`00FUIJEP0:FUH01000FUIJEP0025YF0P00
0UYF00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP@002]oo`00>7oo0`0025YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2P000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF0P000UYF00D0
05YFFUIJEP0000MJEP03001JEUYF00AJEP@00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000[Ool003Ioo`80009JEP03001JEUYF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00=JEP@000QJEP03001JEUYF00YJEP04
001JEUYF0008FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP0002]oo`00<goo
0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEUYF00=JEP8002aoo`00<Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01EYF1@0025YF00<005YFFUH015YF00<005YFFUH00eYF0P002EYF00<005YFFUH02EYF00@005YF
FUH000UJEP06001JEUYF001JEP0015YF00<005YF00000`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo000_Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH01@00FUIJEUYF
00000UYF00@005YFFUIJEP8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000]Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00EJEPD000QJEP03001JEUYF00EJEP03001JEUYF00d000MJEP03001JEUYF00UJEP03001JEUYF
00YJEP05001JEUYFFUH00002FUH01000FUH000002UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF2`00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP09
0008FUH00`00FUH000080003FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH015YF0P0000=JEP00FUH02EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPH000=JEP03001JEUYF009JEP03001JEP00008002aoo`00;Goo00<005YF0000
1EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP@000EJEP@000AJEPH000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH20005FUH01000FUIJEP002eYF00<0
05YFFUH01UYF00<005YFFUH01UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00P00
:goo000]Ool00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH00UYF0P000eYF00<005YFFUH01UYF1@0000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000IJEP03001JEUYF00UJEP04
001JEUYF0009FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH01eYF00<005YFFUH0
1@001UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUH005YF02]oo`00;Goo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP800003FUH0
05YF00AJEP04001JEP000005FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
0eYF00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP@0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000[Ool002eoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJ
EUYF10001UYF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF2`00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YF00002EYF0P001EYF0P0000=JEP00FUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000ZOol002ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPH0009JEP04001JEP000003FUH00`00FUIJEP04FUH30004FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH80003FUH40003FUH40003FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH400000eYF001JEP08FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000QJEP8000EJEP03001JEUYF
009JEP8000MJEP03001JEUYF00IJEPH000YJEP800003FUH005YF00=JEP04001JEUYF0003FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH90005FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000ZOol002ioo`03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00AJEPH000QJEP03001JEUYF00EJEP03001JEP00
00EJEP03001JEUYF00<000UJEP03001JEUYF009JEP@000AJEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP8000=JEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP8000AJEP800005FUH00000
FUH00008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000ZOol002ioo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00005FUH20003FUH00`00FUIJEP06FUH00`00FUH0
00020008FUH00`00FUIJEP03FUH30006FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002Yoo`00;Woo00<0
05YF00001EYF00<005YFFUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<0
05YFFUH00`001EYF00<005YFFUH01EYF0`0000=JEP00FUH01eYF00<005YFFUH0100000=JEP00FUH0
1UYF00@005YF000000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP8000=JEP<0
00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYF000ZOol002ioo`03001JEP0000EJEP04001JEUYFFUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH600000eYF001JEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH50005FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH20008
FUH500000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUHD000YOol0
02ioo`04001JEUYF0004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH01UYF2@0000=J
EP0000000eYF00<005YFFUH015YF1P001UYF00<005YFFUH010000UYF00<005YFFUH01UYF00@005YF
FUIJEP8000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP<000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03001J
EUYF009JEP04001JEP00000YOol002ioo`04001JEUYF0003FUH40007FUH00`00FUIJEP06FUH00`00
FUIJEP070004FUH01000FUIJEUYF0P001EYF00@005YFFUIJEP<0009oo`<00003FUH0000000H000IJ
EP03001JEUYF00IJEP04001JEP00000<FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH0000YOol002moo`9JEP04001JEP000003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000EJEP04001JEP000002FUH0
1@00Oomoo`00FUH01P0000=JEP00FUH01eYF00<005YFFUH01EYF0`003EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP8002Yoo`00;goo
0UYF0P001EYF00<005YFFUH01EYF00@005YFFUIJEP@000MJEP03001JEUYF00IJEP03001JEP00009J
EP04001JEUYFFUH3000015YF001JEUYF2`0000=JEP00FUH025YF00<005YFFUH00UYF0P000UYF00<0
05YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP@000UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF
FUH2000[Ool002moo`04FUH005YF0005FUH00`00FUIJEP05FUH01P00FUH00000FUH000UJEP03001J
EUYF00IJEP03001JEP00009JEP03001JEP0000P000=JEP03001JEUYF00D00003FUH005YF00QJEP03
001JEP00008000AJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJ
EP<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP00000]Ool002moo`80009JEP03001JEUYF009JEP03
001JEUYF00AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020005FUH0
0`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP0;FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH300000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000_Ool002mo
o`80009JEP03001JEUYF00=JEP03001JEUYF00<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000YJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEP00009J
EP03001JEUYF009JEP03001JEUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP80035oo`00<7oo0P0000=JEP00FUH00eYF100000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH00UYF1P000UYF00<005YFFUH05eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF0`000UYF00<005YFFUH00UYF00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00@005YF000003=oo`00<Woo1P001UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF009JEQH000EJEP03
001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP80009JEP03001JEP00
00AJEP<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEQ0002Uoo`00=Goo0P00
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH03`0000=JEP000000
0P000UYF00<005YFFUH01eYF00@005YFFUIJEPP000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP07001JEUYFFUH005YF00000eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000L000=JEP03001JEUYF00=JEP04001JEUYF000YOol003=oo`80009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
00=JEP04001JEP000006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH40007FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH01@00FUIJEUYF00000UYF0`000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00:7oo000bOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00@005YFFUIJEP@0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00IJEP8000=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00MJEP@00003FUH0
05YF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000XOol0035oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000QJEP03001JEUYF00AJEP03001JEUYF009J
EP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00IJEP@000YJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
000XOol0031oo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH010001eYF00<005YFFUH0
1eYF00@005YFFUIJEP/00003FUH0000002Moo`00<7oo00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEPD000QJEP03001JEUYF00EJEP03001JEUYF00T0009JEP03001JEUYF00AJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF008000EJEP03001JEUYF00YJEP03
001JEUYF00IJEP8000EJEP80009JEP03001JEUYF009JEP03001JEUYF009JEPL00003FUH005YF00QJ
EP03001JEUYF00AJEPH000Aoo`<000=JEP@002Moo`00<7oo00@005YFFUH000AJEP03001JEUYF00EJ
EP03001JEUYF00T000QJEP03001JEP0000P000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP0?0005FUH00`00FUIJEP07FUH00`00FUIJEP04
0008Ool200000eYF001JEP04FUH00`00FUH0000WOol0035oo`03001JEP0000AJEP03001JEUYF00AJ
EP@000AJEPD000AJEPH000AJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP8000aJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJ
EP04FUH5000:Ool20003FUH00`00FUIJEP03FUH2000XOol0035oo`03001JEP0000AJEP03001JEUYF
009JEP8000=JEP03001JEUYF00=JEP@0009JEP800003FUH005YF00MJEP03001JEUYF00IJEP07001J
EUYFFUH005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF0P004eYF0P001EYF00<005YF000015YF00<005YFFUH00P000eYF00<005YFFUH01UYF00<005YF
FUH0100037oo0`001EYF00<005YFFUH00eYF00<007ooOol09goo000aOol00`00FUH00005FUH01000
FUH000001EYF00<005YFFUH01UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF0`00
1eYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP<000IJEP03001JEUYF00AJEP@0
00aoo`@00003FUH005YF00IJEP03001JEUYF008002Yoo`00<Goo00@005YFFUH000=JEP@000IJEP03
001JEUYF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP800003FUH0000000EJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF0003FUH30007FUH00`00FUIJEP04000<Ool40006FUH00`00FUIJ
EP04FUH3000/Ool0035oo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH40002FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH60004Ool300000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH2000<FUH20005FUH00`00FUH00002
FUH20002FUH00`00FUIJEP04FUH4000>Ool200000eYF001JEP07FUH00`00FUIJEP03FUH2000^Ool0
039oo`9JEP8000EJEP03001JEUYF009JEP<000IJEP03001JEUYF00MJEP03001JEUYF00@000Qoo`80
0003FUH005YF009JEP03001JEUYF00aJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP8000IJEP<000UJEP03001JEUYF00=JEP05001JEUYF001JEP020004FUH01000FUIJEUYF0P0000=J
EP00000037oo0`0015YF00<005YFFUH01UYF00<005YF00000P00<7oo000bOol015YF001JEP001EYF
00<005YFFUH00`002EYF00<005YFFUH015YF1@002Woo0P000eYF00<005YFFUH00UYF00D005YFFUIJ
EP0000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP8000QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00=JEP03001JEP000080009JEP8000Ioo`H0
00MJEP03001JEUYF00EJEP<003=oo`00<Woo00@005YFFUH000EJEP<000=JEP03001JEUYF00IJEP03
001JEUYF00@000aoo`<000EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00
FUH005YF00000UYF00@005YFFUIJEP80009JEP03001JEUYF00P000AJEP03001JEUYF00IJEP03001J
EUYF00=JEP8003Ioo`00<Woo0P000UYF00<005YFFUH00`001EYF00<005YFFUH01EYF100037oo1000
00=JEP00FUH01UYF00<005YFFUH00P0000=oo`00FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF
00<005YFFUH02EYF0P002UYF0`001EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUH0
00080003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002000hOol003=oo`800006FUH0
0000001JEP001eYF00<005YFFUH0100037oo10001EYF00<005YFFUH01EYF0`0017oo00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF0P002UYF00@005YFFUH000AJEP03
001JEUYF00=JEP03001JEUYF00@00003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00AJEP@003]oo`00=Goo0P000eYF00<005YFFUH015YF10003Goo0`0000=JEP00FUH01eYF
00<005YFFUH00eYF0P001goo00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEPH00003FUH005YF00AJ
EP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00@003moo`00=7oo0P001EYF00@005YFFUIJ
EP8000Moo`<000Aoo`<000AJEP03001JEUYF00IJEP03001JEP0000<000Yoo`80015JEP03001JEUYF
00]JEP03001JEUYF00UJEP8000YJEP8000AJEP<000EJEP04001JEUYF0003FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH015YF1@00@goo000cOol00`00FUH00005FUH01000FUH0000027oo
20001eYF00<005YFFUH01EYF0`0047oo00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF0P002UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP05001J
EUYFFUH00005FUH00`00FUIJEP04FUH00`00FUIJEP040018Ool003=oo`04001JEUYF0003FUH30004
Ool;00000eYF001JEP08FUH00`00FUIJEP02FUH2000DOol01@00FUIJEUYF00002eYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH02EYF0P000UYF00@0
05YFFUIJEP`004aoo`00<goo00D005YFFUH005YF00T000=JEP03001JEUYF00D00003FUH005YF00QJ
EP03001JEP00008001Moo`8000aJEP03001JEUYF00]JEP03001JEUYF00UJEP8000AJEP03001JEUYF
00=JEP8000QJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH800000eYF0000001DOol003Aoo`04
001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP04FUH4000LOol00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH2000:FUH00`00FUIJEP07FUH20002FUH01000
FUIJEP001EYF00<005YFFUH015YF0P00EWoo000dOol200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04000QOol20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEP002UYF00<005YFFUH00UYF0P00F7oo000dOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH6000WOol20006FUH00`00FUIJEP0;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH20008FUH00`00FUIJEP020002FUH00`00FUIJEP05FUH01000
FUH00000FWoo000dOol20002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH8000_Ool00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF
00000UYF00<005YFFUH00eYF3P00DWoo000eOol200000eYF001JEP02FUH7000hOol20003FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP03FUH01000FUH00000D7oo000gOol50011Ool2000>FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH20008FUH00`00FUIJEP02FUH00`00FUH0000300000eYF001JEP06
FUH00`00FUIJEP03FUH00`00FUIJEP02001?Ool007moo`8000]JEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEP00001?Ool0085oo`<000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP8000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF001?Ool008Aoo`<0
00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
00MJEP04001JEUYFFUH;00000eYF0000001>Ool008Moo`<000iJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF009JEP8000IJEPH000Ioo`80009JEP@004ioo`00RWoo0`002eYF00<005YFFUH0
2EYF00<005YFFUH035YF0P000UYF10002Woo0P001EYF00<005YF0000CWoo002=Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000:Ool400000eYF001JEP04FUH2001?Ool0
095oo`@0009JEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH2000;Ool30005FUH00`00
FUIJEP03FUH00`00Oomoo`1>Ool009Eoo`D000UJEP03001JEUYF00QJEP<000]oo`800003FUH005YF
00IJEP03001JEUYF0080055oo`00VGoo1`0025YF1P002goo0`0015YF00<005YFFUH015YF0`00Dgoo
002GOol20002FUH00`00FUIJEP02FUH8000>Ool30007FUH00`00FUIJEP03FUH2001EOol009Ioo`80
00AJEP03001JEUYF00=JEP<000eoo`@00003FUH005YF00QJEP03001JEP00008005Moo`00UGoo00<0
05YF000015YF00<005YF00000`002Goo1`001UYF00<005YFFUH01EYF0`00FWoo002EOol00`00FUH0
0004FUH20005Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001MOol009Eoo`04001JEUYF
0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002001OOol009Eoo`03001J
EUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@0069oo`00UGoo0P00
00=JEP0000001EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01000IWoo002FOol20000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5001ZOol009Ioo`05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP04001_Ool009Ioo`80009JEP03001JEUYF00=JEP04001JEUYF
FUH6001cOol009Qoo``007Uoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]2\[InvisibleSpace]"     "\
\[InvisibleSpace]1.3589970153897604`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 2, "     ", 1.3589970153897604, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60738 .75562 m .59812 .70197 L .56727 .70444 L p .707 .577 .707 r
F P
0 g
s
.59812 .70197 m .60738 .75562 L .63876 .74971 L p .707 .577 .707 r
F P
0 g
s
.63876 .74971 m .62951 .69606 L .59812 .70197 L p .707 .577 .707 r
F P
0 g
s
.62951 .69606 m .63876 .74971 L .66761 .74095 L p .707 .577 .707 r
F P
0 g
s
.66761 .74095 m .65836 .6873 L .62951 .69606 L p .707 .577 .707 r
F P
0 g
s
.57653 .75809 m .56727 .70444 L .53997 .70324 L p .707 .577 .707 r
F P
0 g
s
.56727 .70444 m .57653 .75809 L .60738 .75562 L p .707 .577 .707 r
F P
0 g
s
.65836 .6873 m .66761 .74095 L .6911 .73019 L p .707 .577 .707 r
F P
0 g
s
.6911 .73019 m .68184 .67654 L .65836 .6873 L p .707 .577 .707 r
F P
0 g
s
.54923 .75689 m .53997 .70324 L .51891 .69849 L p .707 .577 .707 r
F P
0 g
s
.53997 .70324 m .54923 .75689 L .57653 .75809 L p .707 .577 .707 r
F P
0 g
s
.61941 .81907 m .60943 .7847 L .57914 .7899 L p .707 .577 .707 r
F P
0 g
s
.60943 .7847 m .61941 .81907 L .65006 .80999 L p .707 .577 .707 r
F P
0 g
s
.65006 .80999 m .64008 .77562 L .60943 .7847 L p .707 .577 .707 r
F P
0 g
s
.64008 .77562 m .65006 .80999 L .67806 .79792 L p .707 .577 .707 r
F P
0 g
s
.67806 .79792 m .66808 .76355 L .64008 .77562 L p .707 .577 .707 r
F P
0 g
s
.68184 .67654 m .6911 .73019 L .70693 .7185 L p .707 .577 .707 r
F P
0 g
s
.70693 .7185 m .69767 .66484 L .68184 .67654 L p .707 .577 .707 r
F P
0 g
s
.58911 .82427 m .57914 .7899 L .55215 .7907 L p .707 .577 .707 r
F P
0 g
s
.57914 .7899 m .58911 .82427 L .61941 .81907 L p .707 .577 .707 r
F P
0 g
s
.66808 .76355 m .67806 .79792 L .70066 .78404 L p .707 .577 .707 r
F P
0 g
s
.70066 .78404 m .69069 .74967 L .66808 .76355 L p .707 .577 .707 r
F P
0 g
s
.51891 .69849 m .52817 .75214 L .54923 .75689 L p .707 .577 .707 r
F P
0 g
s
.52817 .75214 m .51891 .69849 L .50613 .69064 L p .707 .577 .707 r
F P
0 g
s
.63001 .86096 m .62465 .84398 L .59435 .85004 L p .707 .577 .707 r
F P
0 g
s
.62465 .84398 m .63001 .86096 L .66035 .85096 L p .707 .577 .707 r
F P
0 g
s
.66035 .85096 m .655 .83397 L .62465 .84398 L p .707 .577 .707 r
F P
0 g
s
.55215 .7907 m .56213 .82507 L .58911 .82427 L p .707 .577 .707 r
F P
0 g
s
.655 .83397 m .66035 .85096 L .68776 .83799 L p .707 .577 .707 r
F P
0 g
s
.68776 .83799 m .68241 .82101 L .655 .83397 L p .707 .577 .707 r
F P
0 g
s
.56213 .82507 m .55215 .7907 L .53113 .78704 L p .707 .577 .707 r
F P
0 g
s
.69069 .74967 m .70066 .78404 L .71567 .76971 L p .707 .577 .707 r
F P
0 g
s
.71567 .76971 m .70569 .73534 L .69069 .74967 L p .707 .577 .707 r
F P
0 g
s
.69767 .66484 m .70693 .7185 L .71355 .707 L p .707 .577 .707 r
F P
0 g
s
.71355 .707 m .70429 .65335 L .69767 .66484 L p .707 .577 .707 r
F P
0 g
s
.59435 .85004 m .5997 .86703 L .63001 .86096 L p .707 .577 .707 r
F P
0 g
s
.5997 .86703 m .59435 .85004 L .56704 .85157 L p .707 .577 .707 r
F P
0 g
s
.68241 .82101 m .68776 .83799 L .70955 .82334 L p .707 .577 .707 r
F P
0 g
s
.70955 .82334 m .7042 .80635 L .68241 .82101 L p .707 .577 .707 r
F P
0 g
s
.56704 .85157 m .5724 .86856 L .5997 .86703 L p .707 .577 .707 r
F P
0 g
s
.50613 .69064 m .51539 .7443 L .52817 .75214 L p .707 .577 .707 r
F P
0 g
s
.53113 .78704 m .54111 .82141 L .56213 .82507 L p .707 .577 .707 r
F P
0 g
s
.5724 .86856 m .56704 .85157 L .54542 .84842 L p .707 .577 .707 r
F P
0 g
s
.51539 .7443 m .50613 .69064 L .50289 .68047 L p .707 .577 .707 r
F P
0 g
s
.54111 .82141 m .53113 .78704 L .51812 .77927 L p .707 .577 .707 r
F P
0 g
s
.7042 .80635 m .70955 .82334 L .7236 .80842 L p .707 .577 .707 r
F P
0 g
s
.7236 .80842 m .71824 .79144 L .7042 .80635 L p .707 .577 .707 r
F P
0 g
s
.70569 .73534 m .71567 .76971 L .7216 .75633 L p .707 .577 .707 r
F P
0 g
s
.7216 .75633 m .71162 .72196 L .70569 .73534 L p .707 .577 .707 r
F P
0 g
s
.54542 .84842 m .55077 .86541 L .5724 .86856 L p .707 .577 .707 r
F P
0 g
s
.70429 .65335 m .71355 .707 L .71032 .69683 L p .707 .577 .707 r
F P
0 g
s
.71032 .69683 m .70106 .64318 L .70429 .65335 L p .707 .577 .707 r
F P
0 g
s
.51812 .77927 m .5281 .81364 L .54111 .82141 L p .707 .577 .707 r
F P
0 g
s
.50289 .68047 m .51215 .73413 L .51539 .7443 L p .707 .577 .707 r
F P
0 g
s
.55077 .86541 m .54542 .84842 L .53158 .8409 L p .707 .577 .707 r
F P
0 g
s
.47979 .82154 m .47979 .31965 L .43665 .3161 L p .707 .577 .707 r
F P
0 g
s
.5281 .81364 m .51812 .77927 L .5144 .76815 L p .708 .578 .707 r
F P
0 g
s
.51215 .73413 m .50289 .68047 L .50951 .66898 L p .707 .577 .707 r
F P
0 g
s
.5144 .76815 m .52437 .80252 L .5281 .81364 L p .708 .578 .707 r
F P
0 g
s
.50951 .66898 m .51877 .72263 L .51215 .73413 L p .707 .577 .707 r
F P
0 g
s
.52437 .80252 m .5144 .76815 L .52033 .75477 L p .707 .577 .707 r
F P
0 g
s
.51877 .72263 m .50951 .66898 L .52534 .65728 L p .707 .577 .707 r
F P
0 g
s
.47979 .31965 m .47979 .82154 L .52491 .82134 L p .707 .577 .707 r
F P
0 g
s
.52033 .75477 m .53031 .78914 L .52437 .80252 L p .707 .577 .707 r
F P
0 g
s
.52534 .65728 m .5346 .71093 L .51877 .72263 L p .707 .577 .707 r
F P
0 g
s
.53031 .78914 m .52033 .75477 L .53533 .74044 L p .707 .577 .707 r
F P
0 g
s
.52491 .82134 m .52491 .31945 L .47979 .31965 L p .707 .577 .707 r
F P
0 g
s
.53158 .8409 m .53694 .85788 L .55077 .86541 L p .707 .577 .707 r
F P
0 g
s
.53694 .85788 m .53158 .8409 L .52689 .82973 L p .707 .577 .707 r
F P
0 g
s
.52689 .82973 m .53225 .84672 L .53694 .85788 L p .707 .577 .707 r
F P
0 g
s
.53225 .84672 m .52689 .82973 L .53181 .81602 L p .707 .577 .707 r
F P
0 g
s
.5346 .71093 m .52534 .65728 L .54883 .64652 L p .707 .577 .707 r
F P
0 g
s
.53181 .81602 m .53717 .83301 L .53225 .84672 L p .707 .577 .707 r
F P
0 g
s
.53533 .74044 m .54531 .7748 L .53031 .78914 L p .707 .577 .707 r
F P
0 g
s
.55809 .70018 m .54883 .64652 L .57768 .63776 L p .707 .577 .707 r
F P
0 g
s
.54883 .64652 m .55809 .70018 L .5346 .71093 L p .707 .577 .707 r
F P
0 g
s
.53717 .83301 m .53181 .81602 L .54586 .80111 L p .707 .577 .707 r
F P
0 g
s
.54531 .7748 m .53533 .74044 L .55794 .72656 L p .707 .577 .707 r
F P
0 g
s
.54586 .80111 m .55121 .81809 L .53717 .83301 L p .707 .577 .707 r
F P
0 g
s
.55794 .72656 m .56792 .76092 L .54531 .7748 L p .707 .577 .707 r
F P
0 g
s
.56792 .76092 m .55794 .72656 L .58594 .71449 L p .707 .577 .707 r
F P
0 g
s
.55121 .81809 m .54586 .80111 L .56765 .78645 L p .707 .577 .707 r
F P
0 g
s
.56765 .78645 m .573 .80344 L .55121 .81809 L p .707 .577 .707 r
F P
0 g
s
.52491 .31945 m .52491 .82134 L .5676 .81741 L p .707 .577 .707 r
F P
0 g
s
.57768 .63776 m .58694 .69142 L .55809 .70018 L p .707 .577 .707 r
F P
0 g
s
.5676 .81741 m .5676 .31552 L .52491 .31945 L p .707 .577 .707 r
F P
0 g
s
.71824 .79144 m .7236 .80842 L .72852 .79471 L p .707 .577 .707 r
F P
0 g
s
.72852 .79471 m .72316 .77773 L .71824 .79144 L p .707 .577 .707 r
F P
0 g
s
.71162 .72196 m .7216 .75633 L .71788 .74521 L p .708 .578 .707 r
F P
0 g
s
.71788 .74521 m .7079 .71084 L .71162 .72196 L p .708 .578 .707 r
F P
0 g
s
.43665 .81799 m .43665 .3161 L .3997 .30915 L p .707 .577 .707 r
F P
0 g
s
.43665 .3161 m .43665 .81799 L .47979 .82154 L p .707 .577 .707 r
F P
0 g
s
.58694 .69142 m .57768 .63776 L .60907 .63186 L p .707 .577 .707 r
F P
0 g
s
.60907 .63186 m .61833 .68551 L .58694 .69142 L p .707 .577 .707 r
F P
0 g
s
.59591 .74885 m .58594 .71449 L .61659 .70541 L p .707 .577 .707 r
F P
0 g
s
.58594 .71449 m .59591 .74885 L .56792 .76092 L p .707 .577 .707 r
F P
0 g
s
.61659 .70541 m .62656 .73978 L .59591 .74885 L p .707 .577 .707 r
F P
0 g
s
.573 .80344 m .56765 .78645 L .59506 .77348 L p .707 .577 .707 r
F P
0 g
s
.59506 .77348 m .60041 .79047 L .573 .80344 L p .707 .577 .707 r
F P
0 g
s
.60041 .79047 m .59506 .77348 L .6254 .76348 L p .707 .577 .707 r
F P
0 g
s
.6254 .76348 m .63076 .78047 L .60041 .79047 L p .707 .577 .707 r
F P
0 g
s
.5676 .31552 m .5676 .81741 L .60367 .81013 L p .707 .577 .707 r
F P
0 g
s
.60367 .81013 m .60367 .30824 L .5676 .31552 L p .707 .577 .707 r
F P
0 g
s
.70106 .64318 m .71032 .69683 L .69754 .68899 L p .707 .577 .707 r
F P
0 g
s
.69754 .68899 m .68828 .63533 L .70106 .64318 L p .707 .577 .707 r
F P
0 g
s
.25906 .69941 m .25505 .64222 L .22384 .64364 L p .707 .577 .707 r
F P
0 g
s
.25505 .64222 m .25906 .69941 L .29077 .69682 L p .707 .577 .707 r
F P
0 g
s
.29077 .69682 m .28675 .63963 L .25505 .64222 L p .707 .577 .707 r
F P
0 g
s
.28675 .63963 m .29077 .69682 L .31988 .69333 L p .707 .577 .707 r
F P
0 g
s
.31988 .69333 m .31586 .63614 L .28675 .63963 L p .707 .577 .707 r
F P
0 g
s
.72316 .77773 m .72852 .79471 L .72383 .78355 L p .707 .577 .707 r
F P
0 g
s
.72383 .78355 m .71847 .76656 L .72316 .77773 L p .707 .577 .707 r
F P
0 g
s
.22384 .64364 m .22786 .70083 L .25906 .69941 L p .707 .577 .707 r
F P
0 g
s
.22786 .70083 m .22384 .64364 L .19619 .64376 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.3997 .81103 m .3997 .30915 L .37258 .29947 L p .707 .577 .707 r
F P
0 g
s
.3997 .30915 m .3997 .81103 L .43665 .81799 L p .707 .577 .707 r
F P
0 g
s
.26592 .75255 m .26151 .71434 L .23028 .71784 L p .707 .577 .707 r
F P
0 g
s
.26151 .71434 m .26592 .75255 L .2974 .74884 L p .707 .577 .707 r
F P
0 g
s
.2974 .74884 m .29299 .71063 L .26151 .71434 L p .707 .577 .707 r
F P
0 g
s
.7079 .71084 m .71788 .74521 L .70487 .73743 L p .707 .577 .707 r
F P
0 g
s
.70487 .73743 m .69489 .70307 L .7079 .71084 L p .707 .577 .707 r
F P
0 g
s
.23028 .71784 m .23469 .75604 L .26592 .75255 L p .707 .577 .707 r
F P
0 g
s
.19619 .64376 m .20021 .70095 L .22786 .70083 L p .707 .577 .707 r
F P
0 g
s
.63992 .62938 m .64918 .68303 L .61833 .68551 L p .707 .577 .707 r
F P
0 g
s
.61833 .68551 m .60907 .63186 L .63992 .62938 L p .707 .577 .707 r
F P
0 g
s
.62656 .73978 m .61659 .70541 L .64688 .70021 L p .707 .577 .707 r
F P
0 g
s
.63076 .78047 m .6254 .76348 L .65571 .75741 L p .707 .577 .707 r
F P
0 g
s
.60367 .30824 m .60367 .81013 L .62959 .80022 L p .707 .577 .707 r
F P
0 g
s
.64688 .70021 m .65686 .73458 L .62656 .73978 L p .707 .577 .707 r
F P
0 g
s
.62959 .80022 m .62959 .29833 L .60367 .30824 L p .707 .577 .707 r
F P
0 g
s
.31586 .63614 m .31988 .69333 L .34353 .68928 L p .707 .577 .707 r
F P
0 g
s
.34353 .68928 m .33951 .63209 L .31586 .63614 L p .707 .577 .707 r
F P
0 g
s
.29299 .71063 m .2974 .74884 L .32606 .74527 L p .707 .577 .707 r
F P
0 g
s
.32606 .74527 m .32166 .70706 L .29299 .71063 L p .707 .577 .707 r
F P
0 g
s
.2724 .79524 m .27 .77616 L .23864 .78006 L p .707 .577 .707 r
F P
0 g
s
.27 .77616 m .2724 .79524 L .30369 .79127 L p .707 .577 .707 r
F P
0 g
s
.30369 .79127 m .3013 .77219 L .27 .77616 L p .707 .577 .707 r
F P
0 g
s
.23864 .78006 m .24104 .79914 L .2724 .79524 L p .707 .577 .707 r
F P
0 g
s
.68828 .63533 m .69754 .68899 L .67647 .68423 L p .707 .577 .707 r
F P
0 g
s
.67647 .68423 m .66721 .63058 L .68828 .63533 L p .707 .577 .707 r
F P
0 g
s
.23469 .75604 m .23028 .71784 L .20238 .72077 L p .707 .577 .707 r
F P
0 g
s
.20238 .72077 m .20678 .75897 L .23469 .75604 L p .707 .577 .707 r
F P
0 g
s
.24104 .79914 m .23864 .78006 L .21029 .78349 L p .707 .577 .707 r
F P
0 g
s
.21029 .78349 m .21268 .80258 L .24104 .79914 L p .707 .577 .707 r
F P
0 g
s
.3013 .77219 m .30369 .79127 L .33186 .78761 L p .707 .577 .707 r
F P
0 g
s
.33186 .78761 m .32946 .76853 L .3013 .77219 L p .707 .577 .707 r
F P
0 g
s
.20021 .70095 m .19619 .64376 L .1748 .64257 L p .707 .577 .707 r
F P
0 g
s
.1748 .64257 m .17882 .69977 L .20021 .70095 L p .707 .577 .707 r
F P
0 g
s
.32166 .70706 m .32606 .74527 L .3491 .7422 L p .707 .577 .707 r
F P
0 g
s
.3491 .7422 m .34469 .70399 L .32166 .70706 L p .707 .577 .707 r
F P
0 g
s
.20678 .75897 m .20238 .72077 L .18051 .72285 L p .707 .577 .707 r
F P
0 g
s
.18051 .72285 m .18492 .76106 L .20678 .75897 L p .707 .577 .707 r
F P
0 g
s
.71847 .76656 m .72383 .78355 L .71 .77602 L p .707 .577 .707 r
F P
0 g
s
.71 .77602 m .70464 .75903 L .71847 .76656 L p .707 .577 .707 r
F P
0 g
s
.21268 .80258 m .21029 .78349 L .18771 .78614 L p .707 .577 .707 r
F P
0 g
s
.18771 .78614 m .1901 .80522 L .21268 .80258 L p .707 .577 .707 r
F P
0 g
s
.33951 .63209 m .34353 .68928 L .35942 .68505 L p .707 .577 .707 r
F P
0 g
s
.35942 .68505 m .3554 .62786 L .33951 .63209 L p .707 .577 .707 r
F P
0 g
s
.32946 .76853 m .33186 .78761 L .35413 .78462 L p .707 .577 .707 r
F P
0 g
s
.35413 .78462 m .35174 .76554 L .32946 .76853 L p .707 .577 .707 r
F P
0 g
s
.69489 .70307 m .70487 .73743 L .68384 .73377 L p .707 .577 .707 r
F P
0 g
s
.68384 .73377 m .67387 .6994 L .69489 .70307 L p .707 .577 .707 r
F P
0 g
s
.66721 .63058 m .67647 .68423 L .64918 .68303 L p .707 .577 .707 r
F P
0 g
s
.64918 .68303 m .63992 .62938 L .66721 .63058 L p .707 .577 .707 r
F P
0 g
s
.17882 .69977 m .1748 .64257 L .16177 .64019 L p .707 .577 .707 r
F P
0 g
s
.36595 .76351 m .36834 .78259 L .3731 .78172 L p .707 .577 .707 r
F P
0 g
s
.3731 .78172 m .3707 .76264 L .36595 .76351 L p .707 .577 .707 r
F P
0 g
s
.36834 .78259 m .36595 .76351 L .36021 .76433 L p .707 .577 .707 r
F P
0 g
s
.36021 .76433 m .35174 .76554 L p .36029 .77432 L .707 .577 .707 r
F P
0 g
s
.36834 .78259 m .36021 .76433 L .36029 .77432 L .707 .577 .707 r
F
.35792 .28802 m .35718 .27591 L p .35737 .40929 L .708 .578 .707 r
F P
0 g
s
.34469 .70399 m .3491 .7422 L .36425 .73992 L p .707 .577 .707 r
F P
0 g
s
.36425 .73992 m .35984 .70171 L .34469 .70399 L p .707 .577 .707 r
F P
0 g
s
.35174 .76554 m .35413 .78462 L .36834 .78259 L p .707 .577 .707 r
F P
0 g
s
.3554 .62786 m .35942 .68505 L .36598 .68108 L p .707 .577 .707 r
F P
0 g
s
.36598 .68108 m .36196 .62388 L .3554 .62786 L p .707 .577 .707 r
F P
0 g
s
.35856 .62054 m .36258 .67773 L .34954 .67535 L p .707 .577 .707 r
F P
0 g
s
.34954 .67535 m .34553 .61816 L .35856 .62054 L p .707 .577 .707 r
F P
0 g
s
.35984 .70171 m .36425 .73992 L .37003 .73866 L p .707 .577 .707 r
F P
0 g
s
.37003 .73866 m .36562 .70045 L .35984 .70171 L p .707 .577 .707 r
F P
0 g
s
.36148 .70033 m .36589 .73854 L .35221 .73957 L p .707 .577 .707 r
F P
0 g
s
.35221 .73957 m .3478 .70136 L .36148 .70033 L p .707 .577 .707 r
F P
0 g
s
.36553 .76302 m .36792 .7821 L .35334 .78369 L p .707 .577 .707 r
F P
0 g
s
.35334 .78369 m .35094 .76461 L .36553 .76302 L p .707 .577 .707 r
F P
0 g
s
.35792 .7899 m .35792 .47836 L p .35737 .40929 L .708 .578 .707 r
F P
0 g
s
.35792 .47836 m .35792 .28802 L p .35737 .40929 L .708 .578 .707 r
F P
0 g
s
.3707 .76264 m .3731 .78172 L .36792 .7821 L p .707 .577 .707 r
F P
0 g
s
.37257 .80136 m .37258 .29947 L .35792 .28802 L p .707 .577 .707 r
F P
0 g
s
.37258 .29947 m .37257 .80136 L .3997 .81103 L p .707 .577 .707 r
F P
0 g
s
.65571 .75741 m .66106 .7744 L .63076 .78047 L p .707 .577 .707 r
F P
0 g
s
.62959 .29833 m .62959 .80022 L .64282 .78864 L p .707 .577 .707 r
F P
0 g
s
.64282 .78864 m .64282 .28675 L .62959 .29833 L p .707 .577 .707 r
F P
0 g
s
.16177 .64019 m .16579 .69738 L .17882 .69977 L p .707 .577 .707 r
F P
0 g
s
.18492 .76106 m .18051 .72285 L .16684 .72388 L p .707 .577 .707 r
F P
0 g
s
.16684 .72388 m .17125 .76209 L .18492 .76106 L p .707 .577 .707 r
F P
0 g
s
.1901 .80522 m .18771 .78614 L .17312 .78772 L p .707 .577 .707 r
F P
0 g
s
.17312 .78772 m .17552 .80681 L .1901 .80522 L p .707 .577 .707 r
F P
0 g
s
.70464 .75903 m .71 .77602 L .68837 .77287 L p .707 .577 .707 r
F P
0 g
s
.68837 .77287 m .68301 .75588 L .70464 .75903 L p .707 .577 .707 r
F P
0 g
s
.67387 .6994 m .68384 .73377 L .65686 .73458 L p .707 .577 .707 r
F P
0 g
s
.65686 .73458 m .64688 .70021 L .67387 .6994 L p .707 .577 .707 r
F P
0 g
s
.16579 .69738 m .16177 .64019 L .15837 .63685 L p .707 .577 .707 r
F P
0 g
s
.15837 .63685 m .16238 .69404 L .16579 .69738 L p .707 .577 .707 r
F P
0 g
s
.17125 .76209 m .16684 .72388 L .16269 .72376 L p .707 .577 .707 r
F P
0 g
s
.16269 .72376 m .1671 .76197 L .17125 .76209 L p .707 .577 .707 r
F P
0 g
s
.68301 .75588 m .68837 .77287 L .66106 .7744 L p .707 .577 .707 r
F P
0 g
s
.66106 .7744 m .65571 .75741 L .68301 .75588 L p .707 .577 .707 r
F P
0 g
s
.17552 .80681 m .17312 .78772 L .16795 .7881 L p .707 .577 .707 r
F P
0 g
s
.16795 .7881 m .17034 .80719 L .17552 .80681 L p .707 .577 .707 r
F P
0 g
s
.36196 .62388 m .36598 .68108 L .36258 .67773 L p .707 .577 .707 r
F P
0 g
s
.36258 .67773 m .35856 .62054 L .36196 .62388 L p .707 .577 .707 r
F P
0 g
s
.36562 .70045 m .37003 .73866 L .36589 .73854 L p .707 .577 .707 r
F P
0 g
s
.36589 .73854 m .36148 .70033 L .36562 .70045 L p .707 .577 .707 r
F P
0 g
s
.36792 .7821 m .36553 .76302 L .3707 .76264 L p .707 .577 .707 r
F P
0 g
s
.35792 .28802 m .35792 .7899 L .37257 .80136 L p .707 .577 .707 r
F P
0 g
s
.64282 .28675 m .64282 .78864 L .64208 .77653 L p .708 .578 .707 r
F P
0 g
s
.64208 .77653 m .64208 .27464 L .64282 .28675 L p .708 .578 .707 r
F P
0 g
s
.16238 .69404 m .15837 .63685 L .16493 .63287 L p .707 .577 .707 r
F P
0 g
s
.16493 .63287 m .16895 .69006 L .16238 .69404 L p .707 .577 .707 r
F P
0 g
s
.1671 .76197 m .16269 .72376 L .16848 .7225 L p .707 .577 .707 r
F P
0 g
s
.16848 .7225 m .17289 .76071 L .1671 .76197 L p .707 .577 .707 r
F P
0 g
s
.17034 .80719 m .16795 .7881 L .1727 .78724 L p .707 .577 .707 r
F P
0 g
s
.1727 .78724 m .1751 .80632 L .17034 .80719 L p .707 .577 .707 r
F P
0 g
s
.35718 .27591 m .35718 .7778 L .35792 .7899 L p .708 .578 .707 r
F P
0 g
s
.35718 .7778 m .35718 .27591 L .37041 .26433 L p .707 .577 .707 r
F P
0 g
s
.64208 .27464 m .64208 .77653 L .62742 .76508 L p .707 .577 .707 r
F P
0 g
s
.62742 .76508 m .62742 .26319 L .64208 .27464 L p .707 .577 .707 r
F P
0 g
s
.16895 .69006 m .16493 .63287 L .18082 .62864 L p .707 .577 .707 r
F P
0 g
s
.18082 .62864 m .18483 .68584 L .16895 .69006 L p .707 .577 .707 r
F P
0 g
s
.17289 .76071 m .16848 .7225 L .18363 .72022 L p .707 .577 .707 r
F P
0 g
s
.18363 .72022 m .18804 .75843 L .17289 .76071 L p .707 .577 .707 r
F P
0 g
s
.1751 .80632 m .1727 .78724 L .18691 .78521 L p .707 .577 .707 r
F P
0 g
s
.18691 .78521 m .18931 .80429 L .1751 .80632 L p .707 .577 .707 r
F P
0 g
s
.34553 .61816 m .34954 .67535 L .32816 .67416 L p .707 .577 .707 r
F P
0 g
s
.32816 .67416 m .32414 .61697 L .34553 .61816 L p .707 .577 .707 r
F P
0 g
s
.18483 .68584 m .18082 .62864 L .20447 .62459 L p .707 .577 .707 r
F P
0 g
s
.3478 .70136 m .35221 .73957 L .33035 .74165 L p .707 .577 .707 r
F P
0 g
s
.33035 .74165 m .32594 .70345 L .3478 .70136 L p .707 .577 .707 r
F P
0 g
s
.20447 .62459 m .20849 .68178 L .18483 .68584 L p .707 .577 .707 r
F P
0 g
s
.37041 .26433 m .37041 .76622 L .35718 .7778 L p .707 .577 .707 r
F P
0 g
s
.37041 .76622 m .37041 .26433 L .39633 .25442 L p .707 .577 .707 r
F P
0 g
s
.18804 .75843 m .18363 .72022 L .20666 .71715 L p .707 .577 .707 r
F P
0 g
s
.62742 .26319 m .62742 .76508 L .6003 .7554 L p .707 .577 .707 r
F P
0 g
s
.6003 .7554 m .6003 .25351 L .62742 .26319 L p .707 .577 .707 r
F P
0 g
s
.20666 .71715 m .21107 .75536 L .18804 .75843 L p .707 .577 .707 r
F P
0 g
s
.18931 .80429 m .18691 .78521 L .20919 .78222 L p .707 .577 .707 r
F P
0 g
s
.20919 .78222 m .21158 .8013 L .18931 .80429 L p .707 .577 .707 r
F P
0 g
s
.32414 .61697 m .32816 .67416 L .3005 .67428 L p .707 .577 .707 r
F P
0 g
s
.3005 .67428 m .29649 .61709 L .32414 .61697 L p .707 .577 .707 r
F P
0 g
s
.35094 .76461 m .35334 .78369 L .33076 .78633 L p .707 .577 .707 r
F P
0 g
s
.33076 .78633 m .32836 .76725 L .35094 .76461 L p .707 .577 .707 r
F P
0 g
s
.20849 .68178 m .20447 .62459 L .23357 .6211 L p .707 .577 .707 r
F P
0 g
s
.23357 .6211 m .23759 .67829 L .20849 .68178 L p .707 .577 .707 r
F P
0 g
s
.32594 .70345 m .33035 .74165 L .30244 .74459 L p .707 .577 .707 r
F P
0 g
s
.30244 .74459 m .29803 .70638 L .32594 .70345 L p .707 .577 .707 r
F P
0 g
s
.29649 .61709 m .3005 .67428 L .2693 .67571 L p .707 .577 .707 r
F P
0 g
s
.2693 .67571 m .26528 .61852 L .29649 .61709 L p .707 .577 .707 r
F P
0 g
s
.21107 .75536 m .20666 .71715 L .23532 .71358 L p .707 .577 .707 r
F P
0 g
s
.23532 .71358 m .23973 .75179 L .21107 .75536 L p .707 .577 .707 r
F P
0 g
s
.23759 .67829 m .23357 .6211 L .26528 .61852 L p .707 .577 .707 r
F P
0 g
s
.21158 .8013 m .20919 .78222 L .23735 .77856 L p .707 .577 .707 r
F P
0 g
s
.23735 .77856 m .23975 .79764 L .21158 .8013 L p .707 .577 .707 r
F P
0 g
s
.32836 .76725 m .33076 .78633 L .3024 .78977 L p .707 .577 .707 r
F P
0 g
s
.3024 .78977 m .30001 .77069 L .32836 .76725 L p .707 .577 .707 r
F P
0 g
s
.26528 .61852 m .2693 .67571 L .23759 .67829 L p .707 .577 .707 r
F P
0 g
s
.7307 .66929 m .73472 .61698 L .70351 .61226 L p .707 .577 .707 r
F P
0 g
s
.73472 .61698 m .7307 .66929 L .76241 .66988 L p .707 .577 .707 r
F P
0 g
s
.76241 .66988 m .76642 .61757 L .73472 .61698 L p .707 .577 .707 r
F P
0 g
s
.39633 .75631 m .39633 .25442 L .4324 .24714 L p .707 .577 .707 r
F P
0 g
s
.39633 .25442 m .39633 .75631 L .37041 .76622 L p .707 .577 .707 r
F P
0 g
s
.29803 .70638 m .30244 .74459 L .27122 .74808 L p .707 .577 .707 r
F P
0 g
s
.27122 .74808 m .26681 .70987 L .29803 .70638 L p .707 .577 .707 r
F P
0 g
s
.6003 .25351 m .6003 .7554 L .56335 .74845 L p .707 .577 .707 r
F P
0 g
s
.56335 .74845 m .56335 .24656 L .6003 .25351 L p .707 .577 .707 r
F P
0 g
s
.23973 .75179 m .23532 .71358 L .26681 .70987 L p .707 .577 .707 r
F P
0 g
s
.76642 .61757 m .76241 .66988 L .79151 .66628 L p .707 .577 .707 r
F P
0 g
s
.79151 .66628 m .79553 .61397 L .76642 .61757 L p .707 .577 .707 r
F P
0 g
s
.26681 .70987 m .27122 .74808 L .23973 .75179 L p .707 .577 .707 r
F P
0 g
s
.69949 .66457 m .70351 .61226 L .67586 .60386 L p .707 .577 .707 r
F P
0 g
s
.70351 .61226 m .69949 .66457 L .7307 .66929 L p .707 .577 .707 r
F P
0 g
s
.23975 .79764 m .23735 .77856 L .26865 .77458 L p .707 .577 .707 r
F P
0 g
s
.26865 .77458 m .27104 .79367 L .23975 .79764 L p .707 .577 .707 r
F P
0 g
s
.30001 .77069 m .3024 .78977 L .27104 .79367 L p .707 .577 .707 r
F P
0 g
s
.27104 .79367 m .26865 .77458 L .30001 .77069 L p .707 .577 .707 r
F P
0 g
s
.79553 .61397 m .79151 .66628 L .81516 .65883 L p .707 .577 .707 r
F P
0 g
s
.81516 .65883 m .81918 .60652 L .79553 .61397 L p .707 .577 .707 r
F P
0 g
s
.67184 .65617 m .67586 .60386 L .65447 .59261 L p .707 .577 .707 r
F P
0 g
s
.67586 .60386 m .67184 .65617 L .69949 .66457 L p .707 .577 .707 r
F P
0 g
s
.4324 .74903 m .4324 .24714 L .47508 .24321 L p .707 .577 .707 r
F P
0 g
s
.4324 .24714 m .4324 .74903 L .39633 .75631 L p .707 .577 .707 r
F P
0 g
s
.56335 .24656 m .56335 .74845 L .52021 .7449 L p .707 .577 .707 r
F P
0 g
s
.52021 .7449 m .52021 .24301 L .56335 .24656 L p .707 .577 .707 r
F P
0 g
s
.72878 .7353 m .73319 .70223 L .70197 .69619 L p .707 .577 .707 r
F P
0 g
s
.73319 .70223 m .72878 .7353 L .76027 .73636 L p .707 .577 .707 r
F P
0 g
s
.76027 .73636 m .76468 .70328 L .73319 .70223 L p .707 .577 .707 r
F P
0 g
s
.81918 .60652 m .81516 .65883 L .83105 .64827 L p .707 .577 .707 r
F P
0 g
s
.83105 .64827 m .83507 .59596 L .81918 .60652 L p .707 .577 .707 r
F P
0 g
s
.69756 .72927 m .70197 .69619 L .67406 .68577 L p .707 .577 .707 r
F P
0 g
s
.70197 .69619 m .69756 .72927 L .72878 .7353 L p .707 .577 .707 r
F P
0 g
s
.65045 .64492 m .65447 .59261 L .64144 .57961 L p .707 .577 .707 r
F P
0 g
s
.65447 .59261 m .65045 .64492 L .67184 .65617 L p .707 .577 .707 r
F P
0 g
s
.47508 .7451 m .47508 .24321 L .52021 .24301 L p .707 .577 .707 r
F P
0 g
s
.47508 .24321 m .47508 .7451 L .4324 .74903 L p .707 .577 .707 r
F P
0 g
s
.76468 .70328 m .76027 .73636 L .78893 .73233 L p .707 .577 .707 r
F P
0 g
s
.78893 .73233 m .79334 .69925 L .76468 .70328 L p .707 .577 .707 r
F P
0 g
s
.52021 .24301 m .52021 .7449 L .47508 .7451 L p .707 .577 .707 r
F P
0 g
s
.66965 .71884 m .67406 .68577 L .6522 .67197 L p .707 .577 .707 r
F P
0 g
s
.67406 .68577 m .66965 .71884 L .69756 .72927 L p .707 .577 .707 r
F P
0 g
s
.79334 .69925 m .78893 .73233 L .81196 .72361 L p .707 .577 .707 r
F P
0 g
s
.81196 .72361 m .81637 .69053 L .79334 .69925 L p .707 .577 .707 r
F P
0 g
s
.83507 .59596 m .83105 .64827 L .83761 .63563 L p .707 .577 .707 r
F P
0 g
s
.83761 .63563 m .84163 .58333 L .83507 .59596 L p .707 .577 .707 r
F P
0 g
s
.64144 .57961 m .63742 .63192 L .65045 .64492 L p .707 .577 .707 r
F P
0 g
s
.72896 .77673 m .73135 .76031 L .69999 .75448 L p .707 .577 .707 r
F P
0 g
s
.73135 .76031 m .72896 .77673 L .76025 .77746 L p .707 .577 .707 r
F P
0 g
s
.76025 .77746 m .76264 .76104 L .73135 .76031 L p .707 .577 .707 r
F P
0 g
s
.63742 .63192 m .64144 .57961 L .63804 .56613 L p .707 .577 .707 r
F P
0 g
s
.6976 .7709 m .69999 .75448 L .67163 .74412 L p .707 .577 .707 r
F P
0 g
s
.69999 .75448 m .6976 .7709 L .72896 .77673 L p .707 .577 .707 r
F P
0 g
s
.64779 .70505 m .6522 .67197 L .63852 .65616 L p .707 .577 .707 r
F P
0 g
s
.6522 .67197 m .64779 .70505 L .66965 .71884 L p .707 .577 .707 r
F P
0 g
s
.76264 .76104 m .76025 .77746 L .78841 .773 L p .707 .577 .707 r
F P
0 g
s
.78841 .773 m .79081 .75659 L .76264 .76104 L p .707 .577 .707 r
F P
0 g
s
.81637 .69053 m .81196 .72361 L .82711 .71106 L p .707 .577 .707 r
F P
0 g
s
.82711 .71106 m .83152 .67798 L .81637 .69053 L p .707 .577 .707 r
F P
0 g
s
.67163 .74412 m .66924 .76054 L .6976 .7709 L p .707 .577 .707 r
F P
0 g
s
.66924 .76054 m .67163 .74412 L .64906 .73024 L p .707 .577 .707 r
F P
0 g
s
.79081 .75659 m .78841 .773 L .81069 .76381 L p .707 .577 .707 r
F P
0 g
s
.81069 .76381 m .81309 .74739 L .79081 .75659 L p .707 .577 .707 r
F P
0 g
s
.64906 .73024 m .64666 .74666 L .66924 .76054 L p .707 .577 .707 r
F P
0 g
s
.63852 .65616 m .63411 .68924 L .64779 .70505 L p .707 .577 .707 r
F P
0 g
s
.63804 .56613 m .63402 .61844 L .63742 .63192 L p .707 .577 .707 r
F P
0 g
s
.84163 .58333 m .83761 .63563 L .83421 .62216 L p .707 .577 .707 r
F P
0 g
s
.83421 .62216 m .83823 .56985 L .84163 .58333 L p .707 .577 .707 r
F P
0 g
s
.63411 .68924 m .63852 .65616 L .63437 .63988 L p .707 .577 .707 r
F P
0 g
s
.63402 .61844 m .63804 .56613 L .6446 .55349 L p .707 .577 .707 r
F P
0 g
s
.64666 .74666 m .64906 .73024 L .63447 .7142 L p .707 .577 .707 r
F P
0 g
s
.83152 .67798 m .82711 .71106 L .8329 .69589 L p .707 .577 .707 r
F P
0 g
s
.8329 .69589 m .83731 .66282 L .83152 .67798 L p .707 .577 .707 r
F P
0 g
s
.63447 .7142 m .63207 .73062 L .64666 .74666 L p .707 .577 .707 r
F P
0 g
s
.81309 .74739 m .81069 .76381 L .8249 .75078 L p .707 .577 .707 r
F P
0 g
s
.8249 .75078 m .8273 .73436 L .81309 .74739 L p .707 .577 .707 r
F P
0 g
s
.63437 .63988 m .62997 .67295 L .63411 .68924 L p .707 .577 .707 r
F P
0 g
s
.63207 .73062 m .63447 .7142 L .6293 .69757 L p .707 .577 .707 r
F P
0 g
s
.6446 .55349 m .64058 .6058 L .63402 .61844 L p .707 .577 .707 r
F P
0 g
s
.83823 .56985 m .83421 .62216 L .82118 .60916 L p .707 .577 .707 r
F P
0 g
s
.82118 .60916 m .8252 .55685 L .83823 .56985 L p .707 .577 .707 r
F P
0 g
s
.62997 .67295 m .63437 .63988 L .64016 .62472 L p .707 .577 .707 r
F P
0 g
s
.64058 .6058 m .6446 .55349 L .66049 .54294 L p .707 .577 .707 r
F P
0 g
s
.38167 .61354 m .39093 .55773 L .36008 .55148 L p .707 .577 .707 r
F P
0 g
s
.39093 .55773 m .38167 .61354 L .41306 .61788 L p .707 .577 .707 r
F P
0 g
s
.41306 .61788 m .42232 .56208 L .39093 .55773 L p .707 .577 .707 r
F P
0 g
s
.83731 .66282 m .8329 .69589 L .82875 .67961 L p .707 .577 .707 r
F P
0 g
s
.82875 .67961 m .83316 .64653 L .83731 .66282 L p .707 .577 .707 r
F P
0 g
s
.42232 .56208 m .41306 .61788 L .44191 .61989 L p .707 .577 .707 r
F P
0 g
s
.44191 .61989 m .45117 .56409 L .42232 .56208 L p .707 .577 .707 r
F P
0 g
s
.6293 .69757 m .6269 .71399 L .63207 .73062 L p .707 .577 .707 r
F P
0 g
s
.35082 .60728 m .36008 .55148 L .33279 .54393 L p .707 .577 .707 r
F P
0 g
s
.36008 .55148 m .35082 .60728 L .38167 .61354 L p .707 .577 .707 r
F P
0 g
s
.8273 .73436 m .8249 .75078 L .82965 .73519 L p .707 .577 .707 r
F P
0 g
s
.82965 .73519 m .83205 .71877 L .8273 .73436 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64016 .62472 m .63575 .65779 L .62997 .67295 L p .707 .577 .707 r
F P
0 g
s
.33279 .54393 m .32353 .59973 L .35082 .60728 L p .707 .577 .707 r
F P
0 g
s
.37343 .66992 m .38341 .63321 L .35311 .62423 L p .707 .577 .707 r
F P
0 g
s
.38341 .63321 m .37343 .66992 L .40408 .67746 L p .707 .577 .707 r
F P
0 g
s
.40408 .67746 m .41406 .64076 L .38341 .63321 L p .707 .577 .707 r
F P
0 g
s
.45117 .56409 m .44191 .61989 L .4654 .61936 L p .707 .577 .707 r
F P
0 g
s
.4654 .61936 m .47466 .56356 L .45117 .56409 L p .707 .577 .707 r
F P
0 g
s
.32353 .59973 m .33279 .54393 L .31172 .53581 L p .707 .577 .707 r
F P
0 g
s
.6269 .71399 m .6293 .69757 L .63405 .68198 L p .707 .577 .707 r
F P
0 g
s
.34314 .66094 m .35311 .62423 L .32613 .61469 L p .707 .577 .707 r
F P
0 g
s
.35311 .62423 m .34314 .66094 L .37343 .66992 L p .707 .577 .707 r
F P
0 g
s
.8252 .55685 m .82118 .60916 L .79979 .59791 L p .707 .577 .707 r
F P
0 g
s
.79979 .59791 m .80381 .5456 L .8252 .55685 L p .707 .577 .707 r
F P
0 g
s
.41406 .64076 m .40408 .67746 L .43208 .68283 L p .707 .577 .707 r
F P
0 g
s
.43208 .68283 m .44206 .64612 L .41406 .64076 L p .707 .577 .707 r
F P
0 g
s
.66049 .54294 m .65647 .59524 L .64058 .6058 L p .707 .577 .707 r
F P
0 g
s
.63575 .65779 m .64016 .62472 L .65531 .61216 L p .707 .577 .707 r
F P
0 g
s
.65647 .59524 m .66049 .54294 L .68414 .53549 L p .707 .577 .707 r
F P
0 g
s
.32613 .61469 m .31615 .6514 L .34314 .66094 L p .707 .577 .707 r
F P
0 g
s
.36924 .71232 m .37459 .69402 L .34429 .68461 L p .707 .577 .707 r
F P
0 g
s
.37459 .69402 m .36924 .71232 L .39958 .72035 L p .707 .577 .707 r
F P
0 g
s
.39958 .72035 m .40494 .70205 L .37459 .69402 L p .707 .577 .707 r
F P
0 g
s
.83316 .64653 m .82875 .67961 L .81508 .6638 L p .707 .577 .707 r
F P
0 g
s
.81508 .6638 m .81948 .63072 L .83316 .64653 L p .707 .577 .707 r
F P
0 g
s
.63405 .68198 m .63165 .69839 L .6269 .71399 L p .707 .577 .707 r
F P
0 g
s
.34429 .68461 m .33893 .7029 L .36924 .71232 L p .707 .577 .707 r
F P
0 g
s
.31172 .53581 m .30246 .59161 L .32353 .59973 L p .707 .577 .707 r
F P
0 g
s
.33893 .7029 m .34429 .68461 L .31698 .67474 L p .707 .577 .707 r
F P
0 g
s
.40494 .70205 m .39958 .72035 L .42699 .72621 L p .707 .577 .707 r
F P
0 g
s
.42699 .72621 m .43235 .70792 L .40494 .70205 L p .707 .577 .707 r
F P
0 g
s
.31698 .67474 m .31163 .69303 L .33893 .7029 L p .707 .577 .707 r
F P
0 g
s
.83205 .71877 m .82965 .73519 L .82448 .71856 L p .707 .577 .707 r
F P
0 g
s
.82448 .71856 m .82688 .70214 L .83205 .71877 L p .707 .577 .707 r
F P
0 g
s
.31615 .6514 m .32613 .61469 L .30511 .60552 L p .707 .577 .707 r
F P
0 g
s
.44206 .64612 m .43208 .68283 L .45469 .68549 L p .707 .577 .707 r
F P
0 g
s
.45469 .68549 m .46466 .64878 L .44206 .64612 L p .707 .577 .707 r
F P
0 g
s
.47466 .56356 m .4654 .61936 L .48123 .61635 L p .707 .577 .707 r
F P
0 g
s
.48123 .61635 m .49049 .56055 L .47466 .56356 L p .707 .577 .707 r
F P
0 g
s
.30511 .60552 m .29513 .64223 L .31615 .6514 L p .707 .577 .707 r
F P
0 g
s
.30246 .59161 m .31172 .53581 L .29894 .52793 L p .707 .577 .707 r
F P
0 g
s
.80381 .5456 m .79979 .59791 L .77214 .58951 L p .707 .577 .707 r
F P
0 g
s
.77214 .58951 m .77616 .5372 L .80381 .5456 L p .707 .577 .707 r
F P
0 g
s
.65531 .61216 m .6509 .64524 L .63575 .65779 L p .707 .577 .707 r
F P
0 g
s
.68012 .5878 m .68414 .53549 L .71324 .53189 L p .707 .577 .707 r
F P
0 g
s
.68414 .53549 m .68012 .5878 L .65647 .59524 L p .707 .577 .707 r
F P
0 g
s
.31163 .69303 m .31698 .67474 L .29536 .66538 L p .707 .577 .707 r
F P
0 g
s
.29536 .66538 m .29 .68367 L .31163 .69303 L p .707 .577 .707 r
F P
0 g
s
.63165 .69839 m .63405 .68198 L .64826 .66895 L p .707 .577 .707 r
F P
0 g
s
.6509 .64524 m .65531 .61216 L .67834 .60344 L p .707 .577 .707 r
F P
0 g
s
.43235 .70792 m .42699 .72621 L .44879 .72934 L p .707 .577 .707 r
F P
0 g
s
.44879 .72934 m .45414 .71104 L .43235 .70792 L p .707 .577 .707 r
F P
0 g
s
.29894 .52793 m .28968 .58373 L .30246 .59161 L p .707 .577 .707 r
F P
0 g
s
.81948 .63072 m .81508 .6638 L .79321 .65001 L p .707 .577 .707 r
F P
0 g
s
.79321 .65001 m .79762 .61693 L .81948 .63072 L p .707 .577 .707 r
F P
0 g
s
.77616 .5372 m .77214 .58951 L .74093 .58478 L p .707 .577 .707 r
F P
0 g
s
.74093 .58478 m .74495 .53247 L .77616 .5372 L p .707 .577 .707 r
F P
0 g
s
.70923 .58419 m .71324 .53189 L .74495 .53247 L p .707 .577 .707 r
F P
0 g
s
.71324 .53189 m .70923 .58419 L .68012 .5878 L p .707 .577 .707 r
F P
0 g
s
.29513 .64223 m .30511 .60552 L .2921 .59762 L p .707 .577 .707 r
F P
0 g
s
.64826 .66895 m .64586 .68537 L .63165 .69839 L p .707 .577 .707 r
F P
0 g
s
.46466 .64878 m .45469 .68549 L .46969 .68519 L p .707 .577 .707 r
F P
0 g
s
.46969 .68519 m .47967 .64848 L .46466 .64878 L p .707 .577 .707 r
F P
0 g
s
.74495 .53247 m .74093 .58478 L .70923 .58419 L p .707 .577 .707 r
F P
0 g
s
.82688 .70214 m .82448 .71856 L .80989 .70252 L p .707 .577 .707 r
F P
0 g
s
.80989 .70252 m .81229 .6861 L .82688 .70214 L p .707 .577 .707 r
F P
0 g
s
.2921 .59762 m .28212 .63433 L .29513 .64223 L p .707 .577 .707 r
F P
0 g
s
.49049 .56055 m .48123 .61635 L .48785 .61116 L p .707 .577 .707 r
F P
0 g
s
.48785 .61116 m .49711 .55536 L .49049 .56055 L p .707 .577 .707 r
F P
0 g
s
.29 .68367 m .29536 .66538 L .28152 .65744 L p .707 .577 .707 r
F P
0 g
s
.67834 .60344 m .67393 .63652 L .6509 .64524 L p .707 .577 .707 r
F P
0 g
s
.67393 .63652 m .67834 .60344 L .707 .59942 L p .707 .577 .707 r
F P
0 g
s
.28152 .65744 m .27617 .67573 L .29 .68367 L p .707 .577 .707 r
F P
0 g
s
.28968 .58373 m .29894 .52793 L .2957 .52106 L p .707 .577 .707 r
F P
0 g
s
.45414 .71104 m .44879 .72934 L .46283 .72942 L p .707 .577 .707 r
F P
0 g
s
.46283 .72942 m .46818 .71112 L .45414 .71104 L p .707 .577 .707 r
F P
0 g
s
.79762 .61693 m .79321 .65001 L .7653 .63958 L p .707 .577 .707 r
F P
0 g
s
.7653 .63958 m .76971 .6065 L .79762 .61693 L p .707 .577 .707 r
F P
0 g
s
.64586 .68537 m .64826 .66895 L .67054 .65976 L p .707 .577 .707 r
F P
0 g
s
.2957 .52106 m .28644 .57686 L .28968 .58373 L p .707 .577 .707 r
F P
0 g
s
.7026 .63249 m .707 .59942 L .73849 .60047 L p .707 .577 .707 r
F P
0 g
s
.707 .59942 m .7026 .63249 L .67393 .63652 L p .707 .577 .707 r
F P
0 g
s
.67054 .65976 m .66814 .67617 L .64586 .68537 L p .707 .577 .707 r
F P
0 g
s
.76971 .6065 m .7653 .63958 L .73408 .63355 L p .707 .577 .707 r
F P
0 g
s
.73408 .63355 m .73849 .60047 L .76971 .6065 L p .707 .577 .707 r
F P
0 g
s
.81229 .6861 m .80989 .70252 L .78732 .68864 L p .707 .577 .707 r
F P
0 g
s
.78732 .68864 m .78971 .67222 L .81229 .6861 L p .707 .577 .707 r
F P
0 g
s
.28212 .63433 m .2921 .59762 L .28837 .59176 L p .707 .577 .707 r
F P
0 g
s
.47967 .64848 m .46969 .68519 L .47562 .68195 L p .707 .577 .707 r
F P
0 g
s
.47562 .68195 m .4856 .64524 L .47967 .64848 L p .707 .577 .707 r
F P
0 g
s
.73849 .60047 m .73408 .63355 L .7026 .63249 L p .707 .577 .707 r
F P
0 g
s
.28837 .59176 m .2784 .62847 L .28212 .63433 L p .707 .577 .707 r
F P
0 g
s
.66814 .67617 m .67054 .65976 L .6987 .6553 L p .707 .577 .707 r
F P
0 g
s
.27617 .67573 m .28152 .65744 L .27683 .6517 L p .707 .577 .707 r
F P
0 g
s
.49711 .55536 m .48785 .61116 L .48461 .60428 L p .707 .577 .707 r
F P
0 g
s
.48461 .60428 m .49387 .54848 L .49711 .55536 L p .707 .577 .707 r
F P
0 g
s
.27683 .6517 m .27148 .67 L .27617 .67573 L p .707 .577 .707 r
F P
0 g
s
.46818 .71112 m .46283 .72942 L .46775 .72644 L p .707 .577 .707 r
F P
0 g
s
.46775 .72644 m .4731 .70815 L .46818 .71112 L p .707 .577 .707 r
F P
0 g
s
.28644 .57686 m .2957 .52106 L .30232 .51586 L p .707 .577 .707 r
F P
0 g
s
.78971 .67222 m .78732 .68864 L .75896 .67828 L p .707 .577 .707 r
F P
0 g
s
.75896 .67828 m .76136 .66186 L .78971 .67222 L p .707 .577 .707 r
F P
0 g
s
.6987 .6553 m .69631 .67172 L .66814 .67617 L p .707 .577 .707 r
F P
0 g
s
.69631 .67172 m .6987 .6553 L .73 .65603 L p .707 .577 .707 r
F P
0 g
s
.30232 .51586 m .29306 .57166 L .28644 .57686 L p .707 .577 .707 r
F P
0 g
s
.76136 .66186 m .75896 .67828 L .7276 .67245 L p .707 .577 .707 r
F P
0 g
s
.7276 .67245 m .73 .65603 L .76136 .66186 L p .707 .577 .707 r
F P
0 g
s
.73 .65603 m .7276 .67245 L .69631 .67172 L p .707 .577 .707 r
F P
0 g
s
.2784 .62847 m .28837 .59176 L .29431 .58853 L p .707 .577 .707 r
F P
0 g
s
.4856 .64524 m .47562 .68195 L .4719 .6761 L p .707 .577 .707 r
F P
0 g
s
.4719 .6761 m .48188 .63939 L .4856 .64524 L p .707 .577 .707 r
F P
0 g
s
.29431 .58853 m .28433 .62524 L .2784 .62847 L p .707 .577 .707 r
F P
0 g
s
.27148 .67 m .27683 .6517 L .28175 .64873 L p .707 .577 .707 r
F P
0 g
s
.49387 .54848 m .48461 .60428 L .47183 .5964 L p .707 .577 .707 r
F P
0 g
s
.47183 .5964 m .48109 .5406 L .49387 .54848 L p .707 .577 .707 r
F P
0 g
s
.28175 .64873 m .2764 .66702 L .27148 .67 L p .707 .577 .707 r
F P
0 g
s
.29306 .57166 m .30232 .51586 L .31815 .51285 L p .707 .577 .707 r
F P
0 g
s
.4731 .70815 m .46775 .72644 L .46306 .7207 L p .707 .577 .707 r
F P
0 g
s
.46306 .7207 m .46842 .70241 L .4731 .70815 L p .707 .577 .707 r
F P
0 g
s
.31815 .51285 m .30889 .56865 L .29306 .57166 L p .707 .577 .707 r
F P
0 g
s
.28433 .62524 m .29431 .58853 L .30931 .58822 L p .707 .577 .707 r
F P
0 g
s
.48188 .63939 m .4719 .6761 L .45889 .6682 L p .707 .577 .707 r
F P
0 g
s
.45889 .6682 m .46887 .63149 L .48188 .63939 L p .707 .577 .707 r
F P
0 g
s
.30931 .58822 m .29933 .62493 L .28433 .62524 L p .707 .577 .707 r
F P
0 g
s
.48109 .5406 m .47183 .5964 L .45076 .58829 L p .707 .577 .707 r
F P
0 g
s
.45076 .58829 m .46002 .53249 L .48109 .5406 L p .707 .577 .707 r
F P
0 g
s
.2764 .66702 m .28175 .64873 L .2958 .64881 L p .707 .577 .707 r
F P
0 g
s
.2958 .64881 m .29044 .6671 L .2764 .66702 L p .707 .577 .707 r
F P
0 g
s
.30889 .56865 m .31815 .51285 L .34164 .51233 L p .707 .577 .707 r
F P
0 g
s
.46842 .70241 m .46306 .7207 L .44923 .71277 L p .707 .577 .707 r
F P
0 g
s
.44923 .71277 m .45458 .69447 L .46842 .70241 L p .707 .577 .707 r
F P
0 g
s
.34164 .51233 m .33238 .56813 L .30889 .56865 L p .707 .577 .707 r
F P
0 g
s
.29933 .62493 m .30931 .58822 L .33192 .59089 L p .707 .577 .707 r
F P
0 g
s
.46887 .63149 m .45889 .6682 L .43787 .65903 L p .707 .577 .707 r
F P
0 g
s
.43787 .65903 m .44784 .62232 L .46887 .63149 L p .707 .577 .707 r
F P
0 g
s
.46002 .53249 m .45076 .58829 L .42347 .58073 L p .707 .577 .707 r
F P
0 g
s
.42347 .58073 m .43273 .52493 L .46002 .53249 L p .707 .577 .707 r
F P
0 g
s
.33238 .56813 m .34164 .51233 L .37049 .51433 L p .707 .577 .707 r
F P
0 g
s
.33192 .59089 m .32194 .6276 L .29933 .62493 L p .707 .577 .707 r
F P
0 g
s
.29044 .6671 m .2958 .64881 L .31759 .65193 L p .707 .577 .707 r
F P
0 g
s
.31759 .65193 m .31224 .67023 L .29044 .6671 L p .707 .577 .707 r
F P
0 g
s
.45458 .69447 m .44923 .71277 L .4276 .7034 L p .707 .577 .707 r
F P
0 g
s
.4276 .7034 m .43295 .68511 L .45458 .69447 L p .707 .577 .707 r
F P
0 g
s
.37049 .51433 m .36123 .57014 L .33238 .56813 L p .707 .577 .707 r
F P
0 g
s
.43273 .52493 m .42347 .58073 L .39262 .57448 L p .707 .577 .707 r
F P
0 g
s
.39262 .57448 m .40188 .51868 L .43273 .52493 L p .707 .577 .707 r
F P
0 g
s
.36123 .57014 m .37049 .51433 L .40188 .51868 L p .707 .577 .707 r
F P
0 g
s
.32194 .6276 m .33192 .59089 L .35991 .59625 L p .707 .577 .707 r
F P
0 g
s
.40188 .51868 m .39262 .57448 L .36123 .57014 L p .707 .577 .707 r
F P
0 g
s
.44784 .62232 m .43787 .65903 L .41088 .64948 L p .707 .577 .707 r
F P
0 g
s
.41088 .64948 m .42086 .61277 L .44784 .62232 L p .707 .577 .707 r
F P
0 g
s
.35991 .59625 m .34994 .63296 L .32194 .6276 L p .707 .577 .707 r
F P
0 g
s
.31224 .67023 m .31759 .65193 L .345 .6578 L p .707 .577 .707 r
F P
0 g
s
.345 .6578 m .33965 .67609 L .31224 .67023 L p .707 .577 .707 r
F P
0 g
s
.43295 .68511 m .4276 .7034 L .4003 .69353 L p .707 .577 .707 r
F P
0 g
s
.4003 .69353 m .40565 .67524 L .43295 .68511 L p .707 .577 .707 r
F P
0 g
s
.34994 .63296 m .35991 .59625 L .39056 .60379 L p .707 .577 .707 r
F P
0 g
s
.42086 .61277 m .41088 .64948 L .38059 .6405 L p .707 .577 .707 r
F P
0 g
s
.38059 .6405 m .39056 .60379 L .42086 .61277 L p .707 .577 .707 r
F P
0 g
s
.39056 .60379 m .38059 .6405 L .34994 .63296 L p .707 .577 .707 r
F P
0 g
s
.33965 .67609 m .345 .6578 L .37534 .66583 L p .707 .577 .707 r
F P
0 g
s
.40565 .67524 m .4003 .69353 L .36999 .68412 L p .707 .577 .707 r
F P
0 g
s
.36999 .68412 m .37534 .66583 L .40565 .67524 L p .707 .577 .707 r
F P
0 g
s
.37534 .66583 m .36999 .68412 L .33965 .67609 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6@00Pgoo001hOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001jOol007=oo`D0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00D007Eoo`00Kgoo1000
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001HOol>0003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001EOol30002FUH00`00FUIJEP04FUH01000FUIJEUYF2@000UYF00<005YFFUH0
1eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF1`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF10002UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00E7oo00<0
05YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YF00000`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00011ooa4004Eoo`00Dgoo0P0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
00000`002eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000Yo
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPH003moo`00Dgoo0P000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
0P002UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000Ioo`@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000mOol005=oo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF0`00>Woo001COol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000goo0P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P00>7oo001BOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00H005YFFUIJEP00Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000fOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02000dOol0059oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP80039oo`00DWoo0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00005FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00<Goo001BOol00eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0000`Ool0059oo`04FUH005YFFUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;goo001AOol0
0`00FUH000030005FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00H005YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001AOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01P00FUIJEP00FUH000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001J
EUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002ioo`00DGoo00<005YFFUH00UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP06001JEUYF001JEP001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00H005YFFUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001AOol00`00
FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH40006
FUH00`00FUIJEP03FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00DWoo00@005YF
FUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@0009JEP03
001JEUYF00=JEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool005=oo`P00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP04001JEUYFFUH20007FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH6000AOol60006
FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000]Ool0055oo`<000=JEP04001JEUYFFUH70002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH00UYF
0P001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP0000=JEP03
001JEP0000<001eoo`8000AJEP03001JEUYF00=JEP03001JEUYF009JEP8002eoo`00DGoo0P0015YF
00<005YFFUH015YF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP80009JEP03001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEP00FUH00003FUH3000ROol300000eYF001JEP04FUH01`00FUIJEUYF001JEP0002eoo`00DGoo
0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01@0025YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YF00000P0000=JEP00FUH01UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YF001JEP00009JEP80009JEP8000Ioo`l000ioo`8000EJEP07001JEUYFFUH0
05YF0000;Goo001@Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF001JEP<00003FUH005YF00=JEPH000=JEP03001J
EUYF00IJEP03001JEUYF00@000aoo`8000=JEP07001JEUYFFUH005YF0000;Goo001@Ool20004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YF001JEP00009JEP03001JEUYF009JEP<000MJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000Yoo`800003FUH005YF009JEP03001JEP0002eoo`00D7oo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`0025YF00<005YFFUH00eYF00L005YF
FUIJEP00FUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH00000
0eYF00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000Ioo`<00003FUH0000000=JEP8002ioo`00D7oo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00@005YFFUIJEP8000UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH30004FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P0015YF00<005YF00000UYF
0P00;Woo0017Ool;0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH000040006FUH00`00FUIJEP02000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUH000000UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH015YF0P001EYF00<005YFFUH01000;Woo000oOol80004FUH01000FUIJEUYF
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF2`002eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`00
0UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF0`000eYF00<005YFFUH00UYF0P00;Woo000gOol80003FUH00`00FUIJEP06FUH01000FUIJEUYF
2@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000AJ
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYF0002FUH01000FUIJEUYF0`00;Woo000aOol60003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01`00FUIJEUYF001JEP00009JEP04001JEUYFFUH50007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH3000^Ool002io
o`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH0
0`00FUIJEP04FUH00`00FUH000030002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00005FUH0
0`00FUIJEP04FUH50007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH0100000=JEP00FUH00eYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF
00<005YF0000;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF009JEP@000AJEP03001JEUYF00MJEP03001J
EUYF009JEPH000IJEP03001JEUYF00AJEP04001JEP00FUH2000_Ool002eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00EJEP@000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20009
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH00002
00000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH0
15YF00<005YFFUH00`00;goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000QJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF00EJEP05001JEUYFFUH0000`Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
FUH800000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40007FUH00`00FUIJEP04FUH0
1000FUIJEP000UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YF00000eYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0P001EYF00<005YFFUH00UYF00<007ooOol0;Woo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020003FUH00`00FUIJEP050006FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH00eYF00D005YFFUIJEP00
00]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP00FUH20003FUH20000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJ
EP02FUH00`00Oomoo`0^Ool002eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUH0000300000eYF001JEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00FUH01EYF00L005YFFUIJEP00FUH00009FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH50006FUH30003FUH?0006FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF0P00;goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH015YF10001eYF00<005YFFUH01EYF00<005YFFUH01EYF0P001UYF00L005YFFUIJEP00FUH00009
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60006FUH50003FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH2000_Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP04001JEUYFFUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH400000eYF
001JEP03FUH00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUH00003
00000goo001JEP02FUH00`00FUH0000_Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEPT000=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000MJEP03001J
EUYF00EJEP04001JEUYFFUH200000eYF001JEP03FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH2000015YF001JEP000UYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01eYF00D005YF000005YF00D000Ioo`06001JEUYF001JEP00;goo000^Ool00eYF001J
EP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00
FUH000040007FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH20003FUH00`00FUH0000:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20000
15YF001JEUYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF0`002Woo00D005YF001JEP0002moo`00;Woo00=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF0`0015YF00<005YFFUH00eYF1@000UYF00<005YFFUH01eYF00<005YF
FUH00UYF100025YF00<005YFFUH015YF0`0000AJEP00FUH000YJEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP<0009JEP8000AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP80
00Qoo`05001JEP00FUH0000_Ool002ioo`9JEP05001JEUYFFUH00006FUH00`00FUIJEP02FUH?0003
FUH00`00FUIJEP05FUH00`00FUH000060006FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP04FUH0
0`00FUIJEP03000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60004FUH60003
FUH00`00FUIJEP020009Ool60007FUH30007Ool200000eYF001oo`0^Ool002ioo`9JEP05001JEUYF
FUH00005FUH70008FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP02FUH200000eYF
001JEP040002FUH00`00FUIJEP07FUH00`00FUH0000300000eYF001JEP05FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP03001JEP0000<0
00=JEP03001JEUYF00=JEP04001JEP00000?Ool20004FUH01@00FUIJEUYF00001goo0P00<7oo000^
Ool2FUH01P00FUIJEUYF001JEP@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000IJEP03001J
EUYF00AJEP<0009JEP03001JEP0000<000MJEP03001JEUYF00AJEPl000]JEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP<000=JEPH000=JEP04001JEP00000AOol3
00000eYF001JEP03FUH20004Ool3000`Ool002ioo`9JEP03001JEUYF00<0009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00EJEP03001JEP00008000=JEP04
001JEP000005FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH300001EYF001JEUYF00001EYF0P0000=JEP0000000`000UYF00<007oo
Ool04Woo0P001UYF00D007ooOol005YF0080031oo`00;Woo0UYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01eYF00<005YFFUH00UYF1000
0eYF0`0000=JEP00FUH01eYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP800005FUH005YFFUH00006FUH00`00FUH000030002FUH00`00
FUH0000FOol20004FUH30003FUH00`00Oomoo`0^Ool002ioo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJ
EP@000=JEP<000MJEP03001JEUYF00=JEP8000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP@0009JEP03001JEUYF00AJEP03001JEUYF00=JEPD001Qoo`80009J
EP05001JEP00001JEP02000`Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF009JEQ8000=o
o`@0009JEP03001JEUYF00MJEP03001JEUYF00@0009JEP8000EJEP03001JEUYF00AJEP<000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP03001JEP00
00IJEP03001JEUYF00EJEP03001JEUYF00@0011oo`D00004FUH000000003FUH3000`Ool003Eooa00
01Uoo`@000MJEP03001JEUYF00EJEPL00003FUH005YF00EJEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20002FUH30006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000`Ool0051ooa00009J
EP8000EJEP03001JEUYF00MJEP03001JEP0000D000EJEP03001JEUYF009JEP03001JEP0000]JEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000a
Ool004Moo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000800003FUH005YF00QJ
EP03001JEUYF00AJEPD00003FUH005YF00=JEP04001JEP00000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH20002FUH00`00FUH000020003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00Oomoo`0_Ool003mo
o`P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00FUH40007FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P0015YF00@005YF000000]JEP03001JEUYF00YJEP03001JEUYF
00MJEP03001JEUYF00EJEP07001JEP00FUH005YF00000UYF00@005YFFUH000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800004FUH005YF000`Ool003Qoo`L0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00
00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00=JEP800006FUH005YF001JEP00
2eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YF001JEP00FUH00003FUH3
0007FUH00`00FUIJEP07FUH40005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020000
0eYF001oo`0_Ool0039oo`H0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP@000IJEP03001JEUYF
00AJEP08001JEP00001JEP00FUH000]JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP000080009JEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEPH000=JEP03001JEUYF
00EJEP03001JEUYF00=JEP<00004Ool005YF000`Ool002ioo`@0009JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00@0009JEP03001JEUYF00AJEP03001JEUYF0080009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP04001J
EUYF0006FUH20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
Oomoogoo001JEP00031oo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH015YF1@000eYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP03001JEP0000MJEP@00003FUH005YF00MJEPH0
00=JEP03001JEUYF00EJEP04001JEUYFFUH20004Ool00`00FUH0000`Ool002ioo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP0000L000=JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP8000AJEP03001JEP00
00MJEP03001JEUYF00@000IJEP03001JEP00008000AJEP03001JEUYF00EJEP04001JEP000007Ool0
0`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000=JEPd000=JEPD0009JEP03001JEUYF00IJEP03001JEUYF009JEPD0
00Uoo`03001oogoo02moo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH0009JEP07001JEUYF001JEP00FUH00P0017oo10000UYF00<0
07oo00003`003Goo0P00<Goo000^Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH<0003FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP<000Qoo`@00003FUH007oo01]oo`03001JEP00035oo`00;goo
00=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
50000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF6@001UYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEP8000IJEP8000Ioo`05001JEUYF001JEP02000KOol00`00FUH0
000bOol002moo`03FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ00
00aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH80007FUH00`00FUIJEP0:FUH00`00FUIJEP02
FUH90007FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF00@005YF000000=oo`05001JEUYFFUH0
0002FUH00`00Oomoo`0GOol20002FUH00`00Oomoo`0`Ool002moo`03FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF009JEPl001Eoo`05001JEUYFFUH00006FUH00`00FUIJEP03FUH30003FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000040002FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001oo`8000AJEP04001JEUYFFUH30004FUH01000FUIJEP005goo0P0000EJEP00FUIJ
EP00039oo`00;goo0UYF00D005YFFUIJEP0000=JEPh001ioo`05001JEUYFFUH00006FUH00`00FUH0
00030006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH0000;FUH00`00FUIJEP04FUH40006
FUH01@00FUIJEUYF00000goo0P000UYF00<005YFFUH015YF100000EJEP00FUIJEP0001Aoo`8000=J
EP03001JEP0003=oo`00;goo0UYF00<005YFFUH02`009Woo00D005YFFUIJEP0000EJEP<000YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000]JEP03001JEUYF00MJEP<000AJEP06001JEUYF
FUH007oo1`001eYF00<005YFFUH01@003goo1@0015YF00<005YF0000=7oo000_Ool9000]Ool01P00
FUIJEUYF001JEP@0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00<00003FUH005YF009JEP80009JEP04001JEUYFFUH20006
FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH2000eOol0065oo`D000=JEP8000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000=JEP05001JEUYFFUH00005FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000fOol005Yoo`L0009JEP03001JEP00009JEP8000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP00008003Qoo`00DGoo2@000eYF00<005YFFUH00eYF00L0
05YF001JEP00FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000020004FUH00`00FUIJEP02FUH;0004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000kOol004Qoo`T000AJEP03001JEUYF00EJEP03001J
EUYF00AJEP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYFFUH005YF20001UYF1000
00=JEP0000001`0015YF00<005YFFUH01000?Woo0010Ool80004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
1UYF00<005YFFUH01UYF0P0000Eoo`00001JEP0000Ioo`L0049oo`00>Goo1`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP@000=JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP05FUH00`00Oomoo`02Ool2001?Ool0035oo`P0
009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP`000=JEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH00008FUH00`00FUIJEP03FUH20005Ool00`00
FUH0001>Ool002moo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPT000Yoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF000025YF00@0
05YFFUIJEP8000Moo`03001JEP0004ioo`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2`004Woo00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF0080
00UJEP<000Uoo`04001JEUYF001=Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPl001Moo`<000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJEP03001oogoo00Qoo`80
0003FUH007oo04eoo`00<7oo0P000eYF00@005YFFUIJEQ00021oo`8000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00AJEP8000Yoo`05001JEP00FUH0001>Ool0031oo`80009JEPd002Yoo`8000AJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYFFUH20006FUH00`00FUIJEP02FUH2000;Ool01@00FUIJEUYF0000Cgoo000`Ool4000i
Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH000020008FUH01000FUH0000037oo00<005YFFUH00UYF00<007ooOol0CGoo001`
Ool40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002
FUH00`00FUIJEP05FUH3000<Ool30003FUH00`00Oomoo`1>Ool007Aoo`H0009JEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00X0009JEP03001JEUYF00@000eoo`80009J
EP04001JEUYF001AOol007Yoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0009JEP03001J
EUYF00X000moo`8000EJEP03001JEP00055oo`00PWoo6P000eYF00<005YFFUH01EYF00<005YF0000
10004goo00<005YFFUH01EYF0P00DWoo002FOol20002FUH00`00Ool0000@000BOol30007FUH00`00
Oomoo`1AOol009Eoo`03001JEUYF008002=oo`8000=JEP03001JEUYF009JEP8005Aoo`00UGoo00@0
05YFFUH0029oo`8000EJEP05001JEUYFFUH0001FOol009Ioo`03001JEP0001moo`<000QJEP<005Mo
o`00UWoo0P0077oo10000UYF00<005YFFUH01EYF0P00FGoo002GOol00`00Oomoo`0EOol50006FUH0
0`00FUIJEP03FUH2001KOol009Moo`<0015oo`@0009JEP03001JEUYF00MJEP03001JEP00008005eo
o`00Ugoo00<005YFFUH010001goo1P001eYF00<005YFFUH01EYF0`00H7oo002HOol01000FUIJEP00
0UYF1`000eYF00<005YFFUH01eYF00<005YFFUH00eYF0P00Hgoo002HOol01000FUIJEP001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YF00000P00IGoo002IOol01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF1000J7oo002JOol30005FUH00`00FUIJEP05FUH00`00FUIJEP04001/
Ool009aooa40071oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58466 .74222 m .59385 .68644 L .56319 .68006 L p .707 .577 .707 r
F P
0 g
s
.59385 .68644 m .58466 .74222 L .61613 .7467 L p .707 .577 .707 r
F P
0 g
s
.61613 .7467 m .62532 .69093 L .59385 .68644 L p .707 .577 .707 r
F P
0 g
s
.62532 .69093 m .61613 .7467 L .64534 .74885 L p .707 .577 .707 r
F P
0 g
s
.64534 .74885 m .65452 .69308 L .62532 .69093 L p .707 .577 .707 r
F P
0 g
s
.554 .73584 m .56319 .68006 L .53635 .67241 L p .707 .577 .707 r
F P
0 g
s
.56319 .68006 m .554 .73584 L .58466 .74222 L p .707 .577 .707 r
F P
0 g
s
.65452 .69308 m .64534 .74885 L .66942 .74846 L p .707 .577 .707 r
F P
0 g
s
.66942 .74846 m .67861 .69269 L .65452 .69308 L p .707 .577 .707 r
F P
0 g
s
.57229 .7982 m .58207 .76152 L .55224 .75239 L p .707 .577 .707 r
F P
0 g
s
.58207 .76152 m .57229 .7982 L .60317 .80595 L p .707 .577 .707 r
F P
0 g
s
.60317 .80595 m .61295 .76927 L .58207 .76152 L p .707 .577 .707 r
F P
0 g
s
.53635 .67241 m .52716 .72818 L .554 .73584 L p .707 .577 .707 r
F P
0 g
s
.61295 .76927 m .60317 .80595 L .63206 .81155 L p .707 .577 .707 r
F P
0 g
s
.63206 .81155 m .64185 .77487 L .61295 .76927 L p .707 .577 .707 r
F P
0 g
s
.52716 .72818 m .53635 .67241 L .51595 .66423 L p .707 .577 .707 r
F P
0 g
s
.55224 .75239 m .54245 .78907 L .57229 .7982 L p .707 .577 .707 r
F P
0 g
s
.54245 .78907 m .55224 .75239 L .52636 .74277 L p .707 .577 .707 r
F P
0 g
s
.56163 .84003 m .56679 .82176 L .53735 .81212 L p .707 .577 .707 r
F P
0 g
s
.56679 .82176 m .56163 .84003 L .59242 .8484 L p .707 .577 .707 r
F P
0 g
s
.59242 .8484 m .59758 .83013 L .56679 .82176 L p .707 .577 .707 r
F P
0 g
s
.52636 .74277 m .51658 .77945 L .54245 .78907 L p .707 .577 .707 r
F P
0 g
s
.59758 .83013 m .59242 .8484 L .62156 .85468 L p .707 .577 .707 r
F P
0 g
s
.62156 .85468 m .62672 .83641 L .59758 .83013 L p .707 .577 .707 r
F P
0 g
s
.53735 .81212 m .5322 .83039 L .56163 .84003 L p .707 .577 .707 r
F P
0 g
s
.64185 .77487 m .63206 .81155 L .65615 .81446 L p .707 .577 .707 r
F P
0 g
s
.65615 .81446 m .66593 .77778 L .64185 .77487 L p .707 .577 .707 r
F P
0 g
s
.51595 .66423 m .50677 .72001 L .52716 .72818 L p .707 .577 .707 r
F P
0 g
s
.67861 .69269 m .66942 .74846 L .68602 .74556 L p .707 .577 .707 r
F P
0 g
s
.68602 .74556 m .69521 .68978 L .67861 .69269 L p .707 .577 .707 r
F P
0 g
s
.5322 .83039 m .53735 .81212 L .51216 .80215 L p .707 .577 .707 r
F P
0 g
s
.51216 .80215 m .507 .82043 L .5322 .83039 L p .707 .577 .707 r
F P
0 g
s
.51658 .77945 m .52636 .74277 L .50697 .7336 L p .707 .577 .707 r
F P
0 g
s
.62672 .83641 m .62156 .85468 L .64619 .85826 L p .707 .577 .707 r
F P
0 g
s
.64619 .85826 m .65135 .83999 L .62672 .83641 L p .707 .577 .707 r
F P
0 g
s
.50677 .72001 m .51595 .66423 L .50399 .65633 L p .707 .577 .707 r
F P
0 g
s
.50697 .7336 m .49719 .77028 L .51658 .77945 L p .707 .577 .707 r
F P
0 g
s
.66593 .77778 m .65615 .81446 L .67306 .81439 L p .707 .577 .707 r
F P
0 g
s
.67306 .81439 m .68285 .77771 L .66593 .77778 L p .707 .577 .707 r
F P
0 g
s
.507 .82043 m .51216 .80215 L .49368 .79284 L p .707 .577 .707 r
F P
0 g
s
.50399 .65633 m .49481 .71211 L .50677 .72001 L p .707 .577 .707 r
F P
0 g
s
.49368 .79284 m .48852 .81111 L .507 .82043 L p .707 .577 .707 r
F P
0 g
s
.65135 .83999 m .64619 .85826 L .6639 .85878 L p .707 .577 .707 r
F P
0 g
s
.6639 .85878 m .66906 .84051 L .65135 .83999 L p .707 .577 .707 r
F P
0 g
s
.49719 .77028 m .50697 .7336 L .49598 .72578 L p .707 .577 .707 r
F P
0 g
s
.69521 .68978 m .68602 .74556 L .69351 .74043 L p .707 .577 .707 r
F P
0 g
s
.69351 .74043 m .7027 .68466 L .69521 .68978 L p .707 .577 .707 r
F P
0 g
s
.49598 .72578 m .4862 .76246 L .49719 .77028 L p .707 .577 .707 r
F P
0 g
s
.49481 .71211 m .50399 .65633 L .50165 .64949 L p .707 .577 .707 r
F P
0 g
s
.48852 .81111 m .49368 .79284 L .48371 .78508 L p .707 .577 .707 r
F P
0 g
s
.68285 .77771 m .67306 .81439 L .68115 .81136 L p .707 .577 .707 r
F P
0 g
s
.68115 .81136 m .69094 .77467 L .68285 .77771 L p .707 .577 .707 r
F P
0 g
s
.48371 .78508 m .47855 .80336 L .48852 .81111 L p .707 .577 .707 r
F P
0 g
s
.50165 .64949 m .49246 .70526 L .49481 .71211 L p .707 .577 .707 r
F P
0 g
s
.66906 .84051 m .6639 .85878 L .67297 .8562 L p .707 .577 .707 r
F P
0 g
s
.67297 .8562 m .67812 .83793 L .66906 .84051 L p .707 .577 .707 r
F P
0 g
s
.4862 .76246 m .49598 .72578 L .49446 .72007 L p .707 .577 .707 r
F P
0 g
s
.7027 .68466 m .69351 .74043 L .69117 .73359 L p .707 .577 .707 r
F P
0 g
s
.69117 .73359 m .70035 .67781 L .7027 .68466 L p .707 .577 .707 r
F P
0 g
s
.49446 .72007 m .48467 .75675 L .4862 .76246 L p .707 .577 .707 r
F P
0 g
s
.49246 .70526 m .50165 .64949 L .50914 .64436 L p .707 .577 .707 r
F P
0 g
s
.50914 .64436 m .49995 .70014 L .49246 .70526 L p .707 .577 .707 r
F P
0 g
s
.48467 .75675 m .49446 .72007 L .50255 .71703 L p .707 .577 .707 r
F P
0 g
s
.50255 .71703 m .49276 .75371 L .48467 .75675 L p .707 .577 .707 r
F P
0 g
s
.49995 .70014 m .50914 .64436 L .52574 .64146 L p .707 .577 .707 r
F P
0 g
s
.52574 .64146 m .51655 .69724 L .49995 .70014 L p .707 .577 .707 r
F P
0 g
s
.49276 .75371 m .50255 .71703 L .51946 .71696 L p .707 .577 .707 r
F P
0 g
s
.51946 .71696 m .50968 .75364 L .49276 .75371 L p .707 .577 .707 r
F P
0 g
s
.48713 .79534 m .49229 .77707 L .51 .77759 L p .707 .577 .707 r
F P
0 g
s
.51 .77759 m .50485 .79587 L .48713 .79534 L p .707 .577 .707 r
F P
0 g
s
.50113 .82192 m .50113 .32003 L .4565 .31823 L p .707 .577 .707 r
F P
0 g
s
.51655 .69724 m .52574 .64146 L .54982 .64107 L p .707 .577 .707 r
F P
0 g
s
.54982 .64107 m .54064 .69684 L .51655 .69724 L p .707 .577 .707 r
F P
0 g
s
.50968 .75364 m .51946 .71696 L .54354 .71987 L p .707 .577 .707 r
F P
0 g
s
.54354 .71987 m .53376 .75655 L .50968 .75364 L p .707 .577 .707 r
F P
0 g
s
.50485 .79587 m .51 .77759 L .53463 .78117 L p .707 .577 .707 r
F P
0 g
s
.53463 .78117 m .52948 .79944 L .50485 .79587 L p .707 .577 .707 r
F P
0 g
s
.53376 .75655 m .54354 .71987 L .57244 .72547 L p .707 .577 .707 r
F P
0 g
s
.57244 .72547 m .56266 .76216 L .53376 .75655 L p .707 .577 .707 r
F P
0 g
s
.52948 .79944 m .53463 .78117 L .56377 .78745 L p .707 .577 .707 r
F P
0 g
s
.56377 .78745 m .55862 .80572 L .52948 .79944 L p .707 .577 .707 r
F P
0 g
s
.50113 .32003 m .50113 .82192 L .54565 .81993 L p .707 .577 .707 r
F P
0 g
s
.54064 .69684 m .54982 .64107 L .57903 .64322 L p .707 .577 .707 r
F P
0 g
s
.57903 .64322 m .56984 .69899 L .54064 .69684 L p .707 .577 .707 r
F P
0 g
s
.54565 .81993 m .54565 .31805 L .50113 .32003 L p .707 .577 .707 r
F P
0 g
s
.47855 .80336 m .48371 .78508 L .48323 .77965 L p .707 .577 .707 r
F P
0 g
s
.4565 .82012 m .4565 .31823 L .41613 .31282 L p .707 .577 .707 r
F P
0 g
s
.48323 .77965 m .47807 .79792 L .47855 .80336 L p .707 .577 .707 r
F P
0 g
s
.47807 .79792 m .48323 .77965 L .49229 .77707 L p .707 .577 .707 r
F P
0 g
s
.49229 .77707 m .48713 .79534 L .47807 .79792 L p .707 .577 .707 r
F P
0 g
s
.4565 .31823 m .4565 .82012 L .50113 .82192 L p .707 .577 .707 r
F P
0 g
s
.56984 .69899 m .57903 .64322 L .6105 .6477 L p .707 .577 .707 r
F P
0 g
s
.6105 .6477 m .60131 .70348 L .56984 .69899 L p .707 .577 .707 r
F P
0 g
s
.56266 .76216 m .57244 .72547 L .60332 .73322 L p .707 .577 .707 r
F P
0 g
s
.60332 .73322 m .59353 .7699 L .56266 .76216 L p .707 .577 .707 r
F P
0 g
s
.55862 .80572 m .56377 .78745 L .59456 .79582 L p .707 .577 .707 r
F P
0 g
s
.59456 .79582 m .58941 .81409 L .55862 .80572 L p .707 .577 .707 r
F P
0 g
s
.54565 .31805 m .54565 .81993 L .5857 .81435 L p .707 .577 .707 r
F P
0 g
s
.5857 .81435 m .5857 .31246 L .54565 .31805 L p .707 .577 .707 r
F P
0 g
s
.69094 .77467 m .68115 .81136 L .67963 .80565 L p .707 .577 .707 r
F P
0 g
s
.67963 .80565 m .68941 .76897 L .69094 .77467 L p .707 .577 .707 r
F P
0 g
s
.67812 .83793 m .67297 .8562 L .67249 .85077 L p .707 .577 .707 r
F P
0 g
s
.67249 .85077 m .67765 .8325 L .67812 .83793 L p .707 .577 .707 r
F P
0 g
s
.70035 .67781 m .69117 .73359 L .67921 .72569 L p .707 .577 .707 r
F P
0 g
s
.67921 .72569 m .68839 .66992 L .70035 .67781 L p .707 .577 .707 r
F P
0 g
s
.41613 .81471 m .41613 .31282 L .38397 .30433 L p .707 .577 .707 r
F P
0 g
s
.41613 .31282 m .41613 .81471 L .4565 .82012 L p .707 .577 .707 r
F P
0 g
s
.64116 .65409 m .63197 .70986 L .60131 .70348 L p .707 .577 .707 r
F P
0 g
s
.60131 .70348 m .6105 .6477 L .64116 .65409 L p .707 .577 .707 r
F P
0 g
s
.63316 .74235 m .62337 .77903 L .59353 .7699 L p .707 .577 .707 r
F P
0 g
s
.59353 .7699 m .60332 .73322 L .63316 .74235 L p .707 .577 .707 r
F P
0 g
s
.58941 .81409 m .59456 .79582 L .624 .80546 L p .707 .577 .707 r
F P
0 g
s
.5857 .31246 m .5857 .81435 L .61736 .80572 L p .707 .577 .707 r
F P
0 g
s
.61736 .80572 m .61736 .30383 L .5857 .31246 L p .707 .577 .707 r
F P
0 g
s
.24767 .72453 m .25161 .67229 L .2206 .66723 L p .707 .577 .707 r
F P
0 g
s
.25161 .67229 m .24767 .72453 L .27946 .72545 L p .707 .577 .707 r
F P
0 g
s
.27946 .72545 m .28341 .67321 L .25161 .67229 L p .707 .577 .707 r
F P
0 g
s
.68941 .76897 m .67963 .80565 L .66863 .79782 L p .707 .577 .707 r
F P
0 g
s
.66863 .79782 m .67842 .76114 L .68941 .76897 L p .707 .577 .707 r
F P
0 g
s
.28341 .67321 m .27946 .72545 L .30892 .72214 L p .707 .577 .707 r
F P
0 g
s
.30892 .72214 m .31287 .6699 L .28341 .67321 L p .707 .577 .707 r
F P
0 g
s
.21666 .71947 m .2206 .66723 L .1934 .65853 L p .707 .577 .707 r
F P
0 g
s
.2206 .66723 m .21666 .71947 L .24767 .72453 L p .707 .577 .707 r
F P
0 g
s
.67765 .8325 m .67249 .85077 L .66252 .84301 L p .707 .577 .707 r
F P
0 g
s
.66252 .84301 m .66768 .82474 L .67765 .8325 L p .707 .577 .707 r
F P
0 g
s
.68839 .66992 m .67921 .72569 L .65881 .71751 L p .707 .577 .707 r
F P
0 g
s
.65881 .71751 m .668 .66174 L .68839 .66992 L p .707 .577 .707 r
F P
0 g
s
.31287 .6699 m .30892 .72214 L .33317 .71492 L p .707 .577 .707 r
F P
0 g
s
.33317 .71492 m .33711 .66268 L .31287 .6699 L p .707 .577 .707 r
F P
0 g
s
.38397 .80621 m .38397 .30433 L .36317 .29358 L p .707 .577 .707 r
F P
0 g
s
.38397 .30433 m .38397 .80621 L .41613 .81471 L p .707 .577 .707 r
F P
0 g
s
.18946 .71076 m .1934 .65853 L .17268 .64703 L p .707 .577 .707 r
F P
0 g
s
.1934 .65853 m .18946 .71076 L .21666 .71947 L p .707 .577 .707 r
F P
0 g
s
.668 .66174 m .65881 .71751 L .63197 .70986 L p .707 .577 .707 r
F P
0 g
s
.63197 .70986 m .64116 .65409 L .668 .66174 L p .707 .577 .707 r
F P
0 g
s
.65903 .75197 m .64925 .78865 L .62337 .77903 L p .707 .577 .707 r
F P
0 g
s
.62337 .77903 m .63316 .74235 L .65903 .75197 L p .707 .577 .707 r
F P
0 g
s
.61736 .30383 m .61736 .80572 L .63753 .79489 L p .707 .577 .707 r
F P
0 g
s
.63753 .79489 m .63753 .293 L .61736 .30383 L p .707 .577 .707 r
F P
0 g
s
.67842 .76114 m .66863 .79782 L .64925 .78865 L p .707 .577 .707 r
F P
0 g
s
.64925 .78865 m .65903 .75197 L .67842 .76114 L p .707 .577 .707 r
F P
0 g
s
.33711 .66268 m .33317 .71492 L .34983 .7045 L p .707 .577 .707 r
F P
0 g
s
.34983 .7045 m .35377 .65226 L .33711 .66268 L p .707 .577 .707 r
F P
0 g
s
.24162 .79067 m .24584 .75783 L .21507 .75082 L p .707 .577 .707 r
F P
0 g
s
.24584 .75783 m .24162 .79067 L .27333 .79267 L p .707 .577 .707 r
F P
0 g
s
.27333 .79267 m .27755 .75983 L .24584 .75783 L p .707 .577 .707 r
F P
0 g
s
.27755 .75983 m .27333 .79267 L .30289 .78947 L p .707 .577 .707 r
F P
0 g
s
.30289 .78947 m .30711 .75662 L .27755 .75983 L p .707 .577 .707 r
F P
0 g
s
.66768 .82474 m .66252 .84301 L .64403 .8337 L p .707 .577 .707 r
F P
0 g
s
.64403 .8337 m .64919 .81543 L .66768 .82474 L p .707 .577 .707 r
F P
0 g
s
.21085 .78367 m .21507 .75082 L .18827 .7395 L p .707 .577 .707 r
F P
0 g
s
.21507 .75082 m .21085 .78367 L .24162 .79067 L p .707 .577 .707 r
F P
0 g
s
.16874 .69926 m .17268 .64703 L .16047 .63386 L p .707 .577 .707 r
F P
0 g
s
.17268 .64703 m .16874 .69926 L .18946 .71076 L p .707 .577 .707 r
F P
0 g
s
.30711 .75662 m .30289 .78947 L .3274 .78138 L p .707 .577 .707 r
F P
0 g
s
.3274 .78138 m .33162 .74853 L .30711 .75662 L p .707 .577 .707 r
F P
0 g
s
.18405 .77234 m .18827 .7395 L .16805 .72496 L p .707 .577 .707 r
F P
0 g
s
.18827 .7395 m .18405 .77234 L .21085 .78367 L p .707 .577 .707 r
F P
0 g
s
.35726 .6919 m .36121 .63966 L .35377 .65226 L p .707 .577 .707 r
F P
0 g
s
.35377 .65226 m .34983 .7045 L .35726 .6919 L p .707 .577 .707 r
F P
0 g
s
.36121 .63966 m .35726 .6919 L .35475 .67835 L p .707 .577 .707 r
F P
0 g
s
.35475 .67835 m .3587 .62612 L .36121 .63966 L p .707 .577 .707 r
F P
0 g
s
.36317 .79547 m .36317 .29358 L .35576 .28163 L p .707 .577 .707 r
F P
0 g
s
.36317 .29358 m .36317 .79547 L .38397 .80621 L p .707 .577 .707 r
F P
0 g
s
.63753 .293 m .63753 .79489 L .64424 .78291 L p .707 .577 .707 r
F P
0 g
s
.64424 .78291 m .64424 .28103 L .63753 .293 L p .707 .577 .707 r
F P
0 g
s
.64919 .81543 m .64403 .8337 L .61884 .82373 L p .707 .577 .707 r
F P
0 g
s
.61884 .82373 m .624 .80546 L .64919 .81543 L p .707 .577 .707 r
F P
0 g
s
.23533 .83238 m .23753 .81621 L .20704 .80847 L p .707 .577 .707 r
F P
0 g
s
.23753 .81621 m .23533 .83238 L .26707 .83496 L p .707 .577 .707 r
F P
0 g
s
.26707 .83496 m .26927 .81878 L .23753 .81621 L p .707 .577 .707 r
F P
0 g
s
.16047 .63386 m .15653 .6861 L .16874 .69926 L p .707 .577 .707 r
F P
0 g
s
.15653 .6861 m .16047 .63386 L .15796 .62031 L p .707 .577 .707 r
F P
0 g
s
.26927 .81878 m .26707 .83496 L .29696 .83213 L p .707 .577 .707 r
F P
0 g
s
.29696 .83213 m .29916 .81595 L .26927 .81878 L p .707 .577 .707 r
F P
0 g
s
.33162 .74853 m .3274 .78138 L .34446 .76919 L p .707 .577 .707 r
F P
0 g
s
.34446 .76919 m .34868 .73635 L .33162 .74853 L p .707 .577 .707 r
F P
0 g
s
.20484 .82465 m .20704 .80847 L .18079 .79634 L p .707 .577 .707 r
F P
0 g
s
.20704 .80847 m .20484 .82465 L .23533 .83238 L p .707 .577 .707 r
F P
0 g
s
.16805 .72496 m .16383 .7578 L .18405 .77234 L p .707 .577 .707 r
F P
0 g
s
.16383 .7578 m .16805 .72496 L .15639 .70863 L p .707 .577 .707 r
F P
0 g
s
.29916 .81595 m .29696 .83213 L .32208 .82416 L p .707 .577 .707 r
F P
0 g
s
.32208 .82416 m .32428 .80798 L .29916 .81595 L p .707 .577 .707 r
F P
0 g
s
.18079 .79634 m .1786 .81251 L .20484 .82465 L p .707 .577 .707 r
F P
0 g
s
.624 .80546 m .61884 .82373 L .58941 .81409 L p .707 .577 .707 r
F P
0 g
s
.1786 .81251 m .18079 .79634 L .16136 .78099 L p .707 .577 .707 r
F P
0 g
s
.15796 .62031 m .15402 .67255 L .15653 .6861 L p .707 .577 .707 r
F P
0 g
s
.15639 .70863 m .15217 .74148 L .16383 .7578 L p .707 .577 .707 r
F P
0 g
s
.34868 .73635 m .34446 .76919 L .35241 .7541 L p .707 .577 .707 r
F P
0 g
s
.35241 .7541 m .35662 .72126 L .34868 .73635 L p .707 .577 .707 r
F P
0 g
s
.16136 .78099 m .15916 .79717 L .1786 .81251 L p .707 .577 .707 r
F P
0 g
s
.15402 .67255 m .15796 .62031 L .1654 .60771 L p .707 .577 .707 r
F P
0 g
s
.32428 .80798 m .32208 .82416 L .33996 .81184 L p .707 .577 .707 r
F P
0 g
s
.33996 .81184 m .34216 .79566 L .32428 .80798 L p .707 .577 .707 r
F P
0 g
s
.15217 .74148 m .15639 .70863 L .15444 .69212 L p .707 .577 .707 r
F P
0 g
s
.3587 .62612 m .35475 .67835 L .34254 .66518 L p .707 .577 .707 r
F P
0 g
s
.34254 .66518 m .34648 .61295 L .3587 .62612 L p .707 .577 .707 r
F P
0 g
s
.35662 .72126 m .35241 .7541 L .35046 .73758 L p .707 .577 .707 r
F P
0 g
s
.35046 .73758 m .35467 .70474 L .35662 .72126 L p .707 .577 .707 r
F P
0 g
s
.35576 .28163 m .35576 .78352 L .36317 .79547 L p .707 .577 .707 r
F P
0 g
s
.35576 .78352 m .35576 .28163 L .36247 .26966 L p .707 .577 .707 r
F P
0 g
s
.64424 .28103 m .64424 .78291 L .63683 .77097 L p .707 .577 .707 r
F P
0 g
s
.63683 .77097 m .63683 .26908 L .64424 .28103 L p .707 .577 .707 r
F P
0 g
s
.15916 .79717 m .16136 .78099 L .15063 .76393 L p .707 .577 .707 r
F P
0 g
s
.15063 .76393 m .14844 .78011 L .15916 .79717 L p .707 .577 .707 r
F P
0 g
s
.15444 .69212 m .15022 .72496 L .15217 .74148 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34216 .79566 m .33996 .81184 L .34885 .79637 L p .707 .577 .707 r
F P
0 g
s
.34885 .79637 m .35105 .7802 L .34216 .79566 L p .707 .577 .707 r
F P
0 g
s
.1654 .60771 m .16145 .65995 L .15402 .67255 L p .707 .577 .707 r
F P
0 g
s
.16145 .65995 m .1654 .60771 L .18205 .5973 L p .707 .577 .707 r
F P
0 g
s
.15022 .72496 m .15444 .69212 L .16238 .67703 L p .707 .577 .707 r
F P
0 g
s
.14844 .78011 m .15063 .76393 L .14967 .74683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.14967 .74683 m .14747 .76301 L .14844 .78011 L p .707 .577 .707 r
F P
0 g
s
.36247 .77155 m .36247 .26966 L .38264 .25883 L p .707 .577 .707 r
F P
0 g
s
.36247 .26966 m .36247 .77155 L .35576 .78352 L p .707 .577 .707 r
F P
0 g
s
.34648 .61295 m .34254 .66518 L .32182 .65369 L p .707 .577 .707 r
F P
0 g
s
.32182 .65369 m .32576 .60145 L .34648 .61295 L p .707 .577 .707 r
F P
0 g
s
.63683 .26908 m .63683 .77097 L .61603 .76022 L p .707 .577 .707 r
F P
0 g
s
.61603 .76022 m .61603 .25833 L .63683 .26908 L p .707 .577 .707 r
F P
0 g
s
.16238 .67703 m .15816 .70987 L .15022 .72496 L p .707 .577 .707 r
F P
0 g
s
.35105 .7802 m .34885 .79637 L .34789 .77928 L p .707 .577 .707 r
F P
0 g
s
.34789 .77928 m .35009 .7631 L .35105 .7802 L p .707 .577 .707 r
F P
0 g
s
.35467 .70474 m .35046 .73758 L .3388 .72126 L p .707 .577 .707 r
F P
0 g
s
.3388 .72126 m .34302 .68841 L .35467 .70474 L p .707 .577 .707 r
F P
0 g
s
.18205 .5973 m .17811 .64953 L .16145 .65995 L p .707 .577 .707 r
F P
0 g
s
.17811 .64953 m .18205 .5973 L .2063 .59008 L p .707 .577 .707 r
F P
0 g
s
.15816 .70987 m .16238 .67703 L .17944 .66484 L p .707 .577 .707 r
F P
0 g
s
.14747 .76301 m .14967 .74683 L .15857 .73137 L p .707 .577 .707 r
F P
0 g
s
.32576 .60145 m .32182 .65369 L .29462 .64498 L p .707 .577 .707 r
F P
0 g
s
.29462 .64498 m .29857 .59274 L .32576 .60145 L p .707 .577 .707 r
F P
0 g
s
.15857 .73137 m .15637 .74754 L .14747 .76301 L p .707 .577 .707 r
F P
0 g
s
.20236 .64231 m .2063 .59008 L .23576 .58676 L p .707 .577 .707 r
F P
0 g
s
.2063 .59008 m .20236 .64231 L .17811 .64953 L p .707 .577 .707 r
F P
0 g
s
.17944 .66484 m .17522 .69768 L .15816 .70987 L p .707 .577 .707 r
F P
0 g
s
.34302 .68841 m .3388 .72126 L .31858 .70672 L p .707 .577 .707 r
F P
0 g
s
.31858 .70672 m .32279 .67388 L .34302 .68841 L p .707 .577 .707 r
F P
0 g
s
.35009 .7631 m .34789 .77928 L .33717 .76222 L p .707 .577 .707 r
F P
0 g
s
.33717 .76222 m .33936 .74604 L .35009 .7631 L p .707 .577 .707 r
F P
0 g
s
.17522 .69768 m .17944 .66484 L .20395 .65675 L p .707 .577 .707 r
F P
0 g
s
.29857 .59274 m .29462 .64498 L .26361 .63992 L p .707 .577 .707 r
F P
0 g
s
.26361 .63992 m .26755 .58768 L .29857 .59274 L p .707 .577 .707 r
F P
0 g
s
.23182 .639 m .23576 .58676 L .26755 .58768 L p .707 .577 .707 r
F P
0 g
s
.23576 .58676 m .23182 .639 L .20236 .64231 L p .707 .577 .707 r
F P
0 g
s
.38264 .76072 m .38264 .25883 L .4143 .2502 L p .707 .577 .707 r
F P
0 g
s
.38264 .25883 m .38264 .76072 L .36247 .77155 L p .707 .577 .707 r
F P
0 g
s
.15637 .74754 m .15857 .73137 L .17645 .71905 L p .707 .577 .707 r
F P
0 g
s
.61603 .25833 m .61603 .76022 L .58386 .75173 L p .707 .577 .707 r
F P
0 g
s
.58386 .75173 m .58386 .24984 L .61603 .25833 L p .707 .577 .707 r
F P
0 g
s
.26755 .58768 m .26361 .63992 L .23182 .639 L p .707 .577 .707 r
F P
0 g
s
.73639 .64404 m .73244 .58682 L .70143 .58812 L p .707 .577 .707 r
F P
0 g
s
.73244 .58682 m .73639 .64404 L .76818 .6416 L p .707 .577 .707 r
F P
0 g
s
.76818 .6416 m .76424 .58438 L .73244 .58682 L p .707 .577 .707 r
F P
0 g
s
.76424 .58438 m .76818 .6416 L .79764 .63825 L p .707 .577 .707 r
F P
0 g
s
.79764 .63825 m .7937 .58103 L .76424 .58438 L p .707 .577 .707 r
F P
0 g
s
.32279 .67388 m .31858 .70672 L .29177 .6954 L p .707 .577 .707 r
F P
0 g
s
.29177 .6954 m .29599 .66255 L .32279 .67388 L p .707 .577 .707 r
F P
0 g
s
.17645 .71905 m .17425 .73522 L .15637 .74754 L p .707 .577 .707 r
F P
0 g
s
.70143 .58812 m .70537 .64533 L .73639 .64404 L p .707 .577 .707 r
F P
0 g
s
.70537 .64533 m .70143 .58812 L .67423 .58814 L p .707 .577 .707 r
F P
0 g
s
.19973 .68959 m .20395 .65675 L .23351 .65355 L p .707 .577 .707 r
F P
0 g
s
.20395 .65675 m .19973 .68959 L .17522 .69768 L p .707 .577 .707 r
F P
0 g
s
.33936 .74604 m .33717 .76222 L .31773 .74687 L p .707 .577 .707 r
F P
0 g
s
.31773 .74687 m .31993 .73069 L .33936 .74604 L p .707 .577 .707 r
F P
0 g
s
.73899 .69678 m .73477 .65855 L .70401 .66189 L p .707 .577 .707 r
F P
0 g
s
.73477 .65855 m .73899 .69678 L .7707 .69327 L p .707 .577 .707 r
F P
0 g
s
.7707 .69327 m .76649 .65504 L .73477 .65855 L p .707 .577 .707 r
F P
0 g
s
.70401 .66189 m .70822 .70012 L .73899 .69678 L p .707 .577 .707 r
F P
0 g
s
.67423 .58814 m .67818 .64536 L .70537 .64533 L p .707 .577 .707 r
F P
0 g
s
.7937 .58103 m .79764 .63825 L .82189 .63433 L p .707 .577 .707 r
F P
0 g
s
.82189 .63433 m .81794 .57711 L .7937 .58103 L p .707 .577 .707 r
F P
0 g
s
.76649 .65504 m .7707 .69327 L .80026 .68994 L p .707 .577 .707 r
F P
0 g
s
.80026 .68994 m .79605 .65171 L .76649 .65504 L p .707 .577 .707 r
F P
0 g
s
.70631 .72347 m .70851 .74257 L .739 .7389 L p .707 .577 .707 r
F P
0 g
s
.739 .7389 m .7368 .7198 L .70631 .72347 L p .707 .577 .707 r
F P
0 g
s
.7368 .7198 m .739 .7389 L .77074 .73527 L p .707 .577 .707 r
F P
0 g
s
.77074 .73527 m .76854 .71617 L .7368 .7198 L p .707 .577 .707 r
F P
0 g
s
.29599 .66255 m .29177 .6954 L .26101 .68839 L p .707 .577 .707 r
F P
0 g
s
.26101 .68839 m .26522 .65554 L .29599 .66255 L p .707 .577 .707 r
F P
0 g
s
.17425 .73522 m .17645 .71905 L .20156 .71108 L p .707 .577 .707 r
F P
0 g
s
.76854 .71617 m .77074 .73527 L .80063 .73202 L p .707 .577 .707 r
F P
0 g
s
.80063 .73202 m .79844 .71292 L .76854 .71617 L p .707 .577 .707 r
F P
0 g
s
.22929 .68639 m .23351 .65355 L .26522 .65554 L p .707 .577 .707 r
F P
0 g
s
.23351 .65355 m .22929 .68639 L .19973 .68959 L p .707 .577 .707 r
F P
0 g
s
.70822 .70012 m .70401 .66189 L .6772 .66475 L p .707 .577 .707 r
F P
0 g
s
.6772 .66475 m .68142 .70298 L .70822 .70012 L p .707 .577 .707 r
F P
0 g
s
.26522 .65554 m .26101 .68839 L .22929 .68639 L p .707 .577 .707 r
F P
0 g
s
.67818 .64536 m .67423 .58814 L .65351 .58689 L p .707 .577 .707 r
F P
0 g
s
.4143 .2502 m .4143 .75209 L .38264 .76072 L p .707 .577 .707 r
F P
0 g
s
.4143 .75209 m .4143 .2502 L .45435 .24461 L p .707 .577 .707 r
F P
0 g
s
.79605 .65171 m .80026 .68994 L .82477 .68712 L p .707 .577 .707 r
F P
0 g
s
.82477 .68712 m .82056 .64888 L .79605 .65171 L p .707 .577 .707 r
F P
0 g
s
.58386 .24984 m .58386 .75173 L .54349 .74631 L p .707 .577 .707 r
F P
0 g
s
.54349 .74631 m .54349 .24443 L .58386 .24984 L p .707 .577 .707 r
F P
0 g
s
.68007 .72681 m .68227 .74591 L .70851 .74257 L p .707 .577 .707 r
F P
0 g
s
.70851 .74257 m .70631 .72347 L .68007 .72681 L p .707 .577 .707 r
F P
0 g
s
.20156 .71108 m .19936 .72726 L .17425 .73522 L p .707 .577 .707 r
F P
0 g
s
.79844 .71292 m .80063 .73202 L .82575 .72949 L p .707 .577 .707 r
F P
0 g
s
.82575 .72949 m .82355 .71038 L .79844 .71292 L p .707 .577 .707 r
F P
0 g
s
.65351 .58689 m .65746 .64411 L .67818 .64536 L p .707 .577 .707 r
F P
0 g
s
.31993 .73069 m .31773 .74687 L .29148 .73473 L p .707 .577 .707 r
F P
0 g
s
.29148 .73473 m .29368 .71856 L .31993 .73069 L p .707 .577 .707 r
F P
0 g
s
.81794 .57711 m .82189 .63433 L .83854 .63021 L p .707 .577 .707 r
F P
0 g
s
.83854 .63021 m .8346 .57299 L .81794 .57711 L p .707 .577 .707 r
F P
0 g
s
.19936 .72726 m .20156 .71108 L .23145 .70825 L p .707 .577 .707 r
F P
0 g
s
.68142 .70298 m .6772 .66475 L .65698 .66683 L p .707 .577 .707 r
F P
0 g
s
.65698 .66683 m .6612 .70506 L .68142 .70298 L p .707 .577 .707 r
F P
0 g
s
.66063 .7295 m .66283 .7486 L .68227 .74591 L p .707 .577 .707 r
F P
0 g
s
.68227 .74591 m .68007 .72681 L .66063 .7295 L p .707 .577 .707 r
F P
0 g
s
.29368 .71856 m .29148 .73473 L .261 .727 L p .707 .577 .707 r
F P
0 g
s
.261 .727 m .2632 .71082 L .29368 .71856 L p .707 .577 .707 r
F P
0 g
s
.45435 .7465 m .45435 .24461 L .49886 .24263 L p .707 .577 .707 r
F P
0 g
s
.45435 .24461 m .45435 .7465 L .4143 .75209 L p .707 .577 .707 r
F P
0 g
s
.54349 .24443 m .54349 .74631 L .49886 .74451 L p .707 .577 .707 r
F P
0 g
s
.49886 .74451 m .49886 .24263 L .54349 .24443 L p .707 .577 .707 r
F P
0 g
s
.82056 .64888 m .82477 .68712 L .84184 .68507 L p .707 .577 .707 r
F P
0 g
s
.84184 .68507 m .83762 .64684 L .82056 .64888 L p .707 .577 .707 r
F P
0 g
s
.23145 .70825 m .22925 .72442 L .19936 .72726 L p .707 .577 .707 r
F P
0 g
s
.22925 .72442 m .23145 .70825 L .2632 .71082 L p .707 .577 .707 r
F P
0 g
s
.65746 .64411 m .65351 .58689 L .6413 .58449 L p .707 .577 .707 r
F P
0 g
s
.82355 .71038 m .82575 .72949 L .84363 .7279 L p .707 .577 .707 r
F P
0 g
s
.84363 .7279 m .84143 .7088 L .82355 .71038 L p .707 .577 .707 r
F P
0 g
s
.2632 .71082 m .261 .727 L .22925 .72442 L p .707 .577 .707 r
F P
0 g
s
.49886 .24263 m .49886 .74451 L .45435 .7465 L p .707 .577 .707 r
F P
0 g
s
.6413 .58449 m .64525 .64171 L .65746 .64411 L p .707 .577 .707 r
F P
0 g
s
.8346 .57299 m .83854 .63021 L .84598 .6263 L p .707 .577 .707 r
F P
0 g
s
.84598 .6263 m .84204 .56908 L .8346 .57299 L p .707 .577 .707 r
F P
0 g
s
.6612 .70506 m .65698 .66683 L .64533 .66794 L p .707 .577 .707 r
F P
0 g
s
.64533 .66794 m .64954 .70617 L .6612 .70506 L p .707 .577 .707 r
F P
0 g
s
.64991 .73127 m .65211 .75037 L .66283 .7486 L p .707 .577 .707 r
F P
0 g
s
.66283 .7486 m .66063 .7295 L .64991 .73127 L p .707 .577 .707 r
F P
0 g
s
.83762 .64684 m .84184 .68507 L .84978 .68401 L p .707 .577 .707 r
F P
0 g
s
.84978 .68401 m .84556 .64578 L .83762 .64684 L p .707 .577 .707 r
F P
0 g
s
.84143 .7088 m .84363 .7279 L .85252 .72743 L p .707 .577 .707 r
F P
0 g
s
.85252 .72743 m .85033 .70833 L .84143 .7088 L p .707 .577 .707 r
F P
0 g
s
.64525 .64171 m .6413 .58449 L .63879 .58118 L p .707 .577 .707 r
F P
0 g
s
.63879 .58118 m .64274 .63839 L .64525 .64171 L p .707 .577 .707 r
F P
0 g
s
.64954 .70617 m .64533 .66794 L .64337 .66796 L p .707 .577 .707 r
F P
0 g
s
.64337 .66796 m .64759 .70619 L .64954 .70617 L p .707 .577 .707 r
F P
0 g
s
.84204 .56908 m .84598 .6263 L .84347 .62298 L p .707 .577 .707 r
F P
0 g
s
.84347 .62298 m .83953 .56577 L .84204 .56908 L p .707 .577 .707 r
F P
0 g
s
.64895 .73195 m .65115 .75106 L .65211 .75037 L p .707 .577 .707 r
F P
0 g
s
.65211 .75037 m .64991 .73127 L .64895 .73195 L p .707 .577 .707 r
F P
0 g
s
.84556 .64578 m .84978 .68401 L .84783 .68404 L p .707 .577 .707 r
F P
0 g
s
.84783 .68404 m .84361 .64581 L .84556 .64578 L p .707 .577 .707 r
F P
0 g
s
.85033 .70833 m .85252 .72743 L .85156 .72811 L p .707 .577 .707 r
F P
0 g
s
.85156 .72811 m .84936 .70901 L .85033 .70833 L p .707 .577 .707 r
F P
0 g
s
.64274 .63839 m .63879 .58118 L .64623 .57727 L p .707 .577 .707 r
F P
0 g
s
.64623 .57727 m .65017 .63448 L .64274 .63839 L p .707 .577 .707 r
F P
0 g
s
.64759 .70619 m .64337 .66796 L .65132 .6669 L p .707 .577 .707 r
F P
0 g
s
.83953 .56577 m .84347 .62298 L .83126 .62058 L p .707 .577 .707 r
F P
0 g
s
.83126 .62058 m .82731 .56337 L .83953 .56577 L p .707 .577 .707 r
F P
0 g
s
.65132 .6669 m .65553 .70513 L .64759 .70619 L p .707 .577 .707 r
F P
0 g
s
.65784 .73148 m .66004 .75058 L .65115 .75106 L p .707 .577 .707 r
F P
0 g
s
.65115 .75106 m .64895 .73195 L .65784 .73148 L p .707 .577 .707 r
F P
0 g
s
.84361 .64581 m .84783 .68404 L .83617 .68515 L p .707 .577 .707 r
F P
0 g
s
.83617 .68515 m .83195 .64691 L .84361 .64581 L p .707 .577 .707 r
F P
0 g
s
.84936 .70901 m .85156 .72811 L .84084 .72988 L p .707 .577 .707 r
F P
0 g
s
.84084 .72988 m .83864 .71078 L .84936 .70901 L p .707 .577 .707 r
F P
0 g
s
.39868 .62685 m .3895 .57312 L .35884 .57527 L p .707 .577 .707 r
F P
0 g
s
.3895 .57312 m .39868 .62685 L .43016 .62127 L p .707 .577 .707 r
F P
0 g
s
.43016 .62127 m .42097 .56755 L .3895 .57312 L p .707 .577 .707 r
F P
0 g
s
.42097 .56755 m .43016 .62127 L .45936 .61281 L p .707 .577 .707 r
F P
0 g
s
.45936 .61281 m .45018 .55908 L .42097 .56755 L p .707 .577 .707 r
F P
0 g
s
.65017 .63448 m .64623 .57727 L .66288 .57315 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66288 .57315 m .66683 .63037 L .65017 .63448 L p .707 .577 .707 r
F P
0 g
s
.36803 .62899 m .35884 .57527 L .332 .57376 L p .707 .577 .707 r
F P
0 g
s
.35884 .57527 m .36803 .62899 L .39868 .62685 L p .707 .577 .707 r
F P
0 g
s
.45018 .55908 m .45936 .61281 L .48344 .60228 L p .707 .577 .707 r
F P
0 g
s
.48344 .60228 m .47426 .54855 L .45018 .55908 L p .707 .577 .707 r
F P
0 g
s
.82731 .56337 m .83126 .62058 L .81054 .61933 L p .707 .577 .707 r
F P
0 g
s
.81054 .61933 m .80659 .56212 L .82731 .56337 L p .707 .577 .707 r
F P
0 g
s
.65553 .70513 m .65132 .6669 L .66838 .66486 L p .707 .577 .707 r
F P
0 g
s
.66838 .66486 m .6726 .70309 L .65553 .70513 L p .707 .577 .707 r
F P
0 g
s
.67572 .7299 m .67792 .749 L .66004 .75058 L p .707 .577 .707 r
F P
0 g
s
.66004 .75058 m .65784 .73148 L .67572 .7299 L p .707 .577 .707 r
F P
0 g
s
.34119 .62748 m .332 .57376 L .3116 .56876 L p .707 .577 .707 r
F P
0 g
s
.332 .57376 m .34119 .62748 L .36803 .62899 L p .707 .577 .707 r
F P
0 g
s
.43734 .68246 m .42756 .64786 L .39668 .656 L p .707 .577 .707 r
F P
0 g
s
.42756 .64786 m .43734 .68246 L .46624 .67122 L p .707 .577 .707 r
F P
0 g
s
.46624 .67122 m .45645 .63662 L .42756 .64786 L p .707 .577 .707 r
F P
0 g
s
.83195 .64691 m .83617 .68515 L .81595 .68723 L p .707 .577 .707 r
F P
0 g
s
.81595 .68723 m .81173 .649 L .83195 .64691 L p .707 .577 .707 r
F P
0 g
s
.40646 .6906 m .39668 .656 L .36684 .66022 L p .707 .577 .707 r
F P
0 g
s
.39668 .656 m .40646 .6906 L .43734 .68246 L p .707 .577 .707 r
F P
0 g
s
.47426 .54855 m .48344 .60228 L .50004 .59072 L p .707 .577 .707 r
F P
0 g
s
.50004 .59072 m .49086 .53699 L .47426 .54855 L p .707 .577 .707 r
F P
0 g
s
.66683 .63037 m .66288 .57315 L .68713 .56923 L p .707 .577 .707 r
F P
0 g
s
.83864 .71078 m .84084 .72988 L .8214 .73257 L p .707 .577 .707 r
F P
0 g
s
.8214 .73257 m .81921 .71347 L .83864 .71078 L p .707 .577 .707 r
F P
0 g
s
.45645 .63662 m .46624 .67122 L .49032 .65797 L p .707 .577 .707 r
F P
0 g
s
.49032 .65797 m .48054 .62337 L .45645 .63662 L p .707 .577 .707 r
F P
0 g
s
.68713 .56923 m .69107 .62644 L .66683 .63037 L p .707 .577 .707 r
F P
0 g
s
.37663 .69482 m .36684 .66022 L .34096 .66013 L p .707 .577 .707 r
F P
0 g
s
.36684 .66022 m .37663 .69482 L .40646 .6906 L p .707 .577 .707 r
F P
0 g
s
.80659 .56212 m .81054 .61933 L .78334 .61936 L p .707 .577 .707 r
F P
0 g
s
.78334 .61936 m .7794 .56214 L .80659 .56212 L p .707 .577 .707 r
F P
0 g
s
.6726 .70309 m .66838 .66486 L .69289 .66203 L p .707 .577 .707 r
F P
0 g
s
.69289 .66203 m .69711 .70027 L .6726 .70309 L p .707 .577 .707 r
F P
0 g
s
.3116 .56876 m .32079 .62248 L .34119 .62748 L p .707 .577 .707 r
F P
0 g
s
.44138 .72463 m .43623 .7074 L .40543 .71555 L p .707 .577 .707 r
F P
0 g
s
.43623 .7074 m .44138 .72463 L .47052 .71328 L p .707 .577 .707 r
F P
0 g
s
.47052 .71328 m .46536 .69605 L .43623 .7074 L p .707 .577 .707 r
F P
0 g
s
.69107 .62644 m .68713 .56923 L .71659 .56588 L p .707 .577 .707 r
F P
0 g
s
.70084 .72736 m .70304 .74646 L .67792 .749 L p .707 .577 .707 r
F P
0 g
s
.67792 .749 m .67572 .7299 L .70084 .72736 L p .707 .577 .707 r
F P
0 g
s
.32079 .62248 m .3116 .56876 L .29964 .56074 L p .707 .577 .707 r
F P
0 g
s
.41059 .73278 m .40543 .71555 L .376 .71971 L p .707 .577 .707 r
F P
0 g
s
.40543 .71555 m .41059 .73278 L .44138 .72463 L p .707 .577 .707 r
F P
0 g
s
.48054 .62337 m .49032 .65797 L .50724 .644 L p .707 .577 .707 r
F P
0 g
s
.50724 .644 m .49745 .6094 L .48054 .62337 L p .707 .577 .707 r
F P
0 g
s
.81173 .649 m .81595 .68723 L .78914 .69008 L p .707 .577 .707 r
F P
0 g
s
.78914 .69008 m .78493 .65185 L .81173 .649 L p .707 .577 .707 r
F P
0 g
s
.34096 .66013 m .35075 .69473 L .37663 .69482 L p .707 .577 .707 r
F P
0 g
s
.49086 .53699 m .50004 .59072 L .50754 .57926 L p .707 .577 .707 r
F P
0 g
s
.50754 .57926 m .49835 .52553 L .49086 .53699 L p .707 .577 .707 r
F P
0 g
s
.46536 .69605 m .47052 .71328 L .49515 .69985 L p .707 .577 .707 r
F P
0 g
s
.49515 .69985 m .48999 .68262 L .46536 .69605 L p .707 .577 .707 r
F P
0 g
s
.81921 .71347 m .8214 .73257 L .79516 .73591 L p .707 .577 .707 r
F P
0 g
s
.79516 .73591 m .79296 .71681 L .81921 .71347 L p .707 .577 .707 r
F P
0 g
s
.71659 .56588 m .72054 .6231 L .69107 .62644 L p .707 .577 .707 r
F P
0 g
s
.7794 .56214 m .78334 .61936 L .75233 .62066 L p .707 .577 .707 r
F P
0 g
s
.75233 .62066 m .74838 .56344 L .7794 .56214 L p .707 .577 .707 r
F P
0 g
s
.376 .71971 m .38116 .73694 L .41059 .73278 L p .707 .577 .707 r
F P
0 g
s
.35075 .69473 m .34096 .66013 L .32158 .65572 L p .707 .577 .707 r
F P
0 g
s
.72054 .6231 m .71659 .56588 L .74838 .56344 L p .707 .577 .707 r
F P
0 g
s
.38116 .73694 m .376 .71971 L .35081 .71947 L p .707 .577 .707 r
F P
0 g
s
.69711 .70027 m .69289 .66203 L .72245 .6587 L p .707 .577 .707 r
F P
0 g
s
.74838 .56344 m .75233 .62066 L .72054 .6231 L p .707 .577 .707 r
F P
0 g
s
.72245 .6587 m .72666 .69694 L .69711 .70027 L p .707 .577 .707 r
F P
0 g
s
.78493 .65185 m .78914 .69008 L .75838 .69343 L p .707 .577 .707 r
F P
0 g
s
.75838 .69343 m .75416 .6552 L .78493 .65185 L p .707 .577 .707 r
F P
0 g
s
.29964 .56074 m .30883 .61447 L .32079 .62248 L p .707 .577 .707 r
F P
0 g
s
.35081 .71947 m .35596 .7367 L .38116 .73694 L p .707 .577 .707 r
F P
0 g
s
.73073 .72411 m .73293 .74322 L .70304 .74646 L p .707 .577 .707 r
F P
0 g
s
.70304 .74646 m .70084 .72736 L .73073 .72411 L p .707 .577 .707 r
F P
0 g
s
.48999 .68262 m .49515 .69985 L .51286 .68565 L p .707 .577 .707 r
F P
0 g
s
.51286 .68565 m .50771 .66842 L .48999 .68262 L p .707 .577 .707 r
F P
0 g
s
.32158 .65572 m .33136 .69032 L .35075 .69473 L p .707 .577 .707 r
F P
0 g
s
.79296 .71681 m .79516 .73591 L .76467 .73958 L p .707 .577 .707 r
F P
0 g
s
.76467 .73958 m .76247 .72048 L .79296 .71681 L p .707 .577 .707 r
F P
0 g
s
.49745 .6094 m .50724 .644 L .51533 .63069 L p .707 .577 .707 r
F P
0 g
s
.51533 .63069 m .50554 .59609 L .49745 .6094 L p .707 .577 .707 r
F P
0 g
s
.72666 .69694 m .72245 .6587 L .75416 .6552 L p .707 .577 .707 r
F P
0 g
s
.75416 .6552 m .75838 .69343 L .72666 .69694 L p .707 .577 .707 r
F P
0 g
s
.30883 .61447 m .29964 .56074 L .2973 .55051 L p .707 .578 .707 r
F P
0 g
s
.76247 .72048 m .76467 .73958 L .73293 .74322 L p .707 .577 .707 r
F P
0 g
s
.73293 .74322 m .73073 .72411 L .76247 .72048 L p .707 .577 .707 r
F P
0 g
s
.35596 .7367 m .35081 .71947 L .33232 .71485 L p .707 .577 .707 r
F P
0 g
s
.49835 .52553 m .50754 .57926 L .50519 .56902 L p .707 .578 .707 r
F P
0 g
s
.50519 .56902 m .496 .5153 L .49835 .52553 L p .707 .578 .707 r
F P
0 g
s
.33136 .69032 m .32158 .65572 L .31059 .64744 L p .707 .577 .707 r
F P
0 g
s
.33232 .71485 m .33748 .73208 L .35596 .7367 L p .707 .577 .707 r
F P
0 g
s
.50771 .66842 m .51286 .68565 L .52193 .67206 L p .707 .577 .707 r
F P
0 g
s
.52193 .67206 m .51677 .65483 L .50771 .66842 L p .707 .577 .707 r
F P
0 g
s
.31059 .64744 m .32037 .68204 L .33136 .69032 L p .707 .577 .707 r
F P
0 g
s
.2973 .55051 m .30648 .60423 L .30883 .61447 L p .707 .578 .707 r
F P
0 g
s
.50554 .59609 m .51533 .63069 L .5138 .61933 L p .707 .577 .707 r
F P
0 g
s
.5138 .61933 m .50402 .58473 L .50554 .59609 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.33748 .73208 m .33232 .71485 L .32235 .70631 L p .707 .577 .707 r
F P
0 g
s
.30648 .60423 m .2973 .55051 L .30479 .53905 L p .707 .577 .707 r
F P
0 g
s
.32037 .68204 m .31059 .64744 L .30906 .63608 L p .707 .577 .707 r
F P
0 g
s
.496 .5153 m .50519 .56902 L .49323 .56101 L p .707 .577 .707 r
F P
0 g
s
.49323 .56101 m .48405 .50729 L .496 .5153 L p .707 .577 .707 r
F P
0 g
s
.32235 .70631 m .32751 .72353 L .33748 .73208 L p .707 .577 .707 r
F P
0 g
s
.51677 .65483 m .52193 .67206 L .52145 .66043 L p .707 .577 .707 r
F P
0 g
s
.52145 .66043 m .51629 .6432 L .51677 .65483 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30906 .63608 m .31884 .67068 L .32037 .68204 L p .707 .577 .707 r
F P
0 g
s
.30479 .53905 m .31398 .59277 L .30648 .60423 L p .707 .577 .707 r
F P
0 g
s
.50402 .58473 m .5138 .61933 L .50281 .61105 L p .707 .577 .707 r
F P
0 g
s
.50281 .61105 m .49302 .57645 L .50402 .58473 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32751 .72353 m .32235 .70631 L .32187 .69467 L p .707 .577 .707 r
F P
0 g
s
.31398 .59277 m .30479 .53905 L .32139 .52749 L p .707 .577 .707 r
F P
0 g
s
.48405 .50729 m .49323 .56101 L .47283 .55601 L p .707 .577 .707 r
F P
0 g
s
.47283 .55601 m .46365 .50228 L .48405 .50729 L p .707 .577 .707 r
F P
0 g
s
.31884 .67068 m .30906 .63608 L .31715 .62277 L p .707 .577 .707 r
F P
0 g
s
.32187 .69467 m .32703 .7119 L .32751 .72353 L p .707 .577 .707 r
F P
0 g
s
.51629 .6432 m .52145 .66043 L .51148 .65189 L p .707 .577 .707 r
F P
0 g
s
.51148 .65189 m .50632 .63466 L .51629 .6432 L p .707 .577 .707 r
F P
0 g
s
.31715 .62277 m .32693 .65737 L .31884 .67068 L p .707 .577 .707 r
F P
0 g
s
.32139 .52749 m .33058 .58121 L .31398 .59277 L p .707 .577 .707 r
F P
0 g
s
.49302 .57645 m .50281 .61105 L .48342 .60664 L p .707 .577 .707 r
F P
0 g
s
.48342 .60664 m .47364 .57204 L .49302 .57645 L p .707 .577 .707 r
F P
0 g
s
.33058 .58121 m .32139 .52749 L .34547 .51696 L p .707 .577 .707 r
F P
0 g
s
.46365 .50228 m .47283 .55601 L .44599 .5545 L p .707 .577 .707 r
F P
0 g
s
.44599 .5545 m .43681 .50078 L .46365 .50228 L p .707 .577 .707 r
F P
0 g
s
.32703 .7119 m .32187 .69467 L .33093 .68109 L p .707 .577 .707 r
F P
0 g
s
.32693 .65737 m .31715 .62277 L .33406 .6088 L p .707 .577 .707 r
F P
0 g
s
.33093 .68109 m .33609 .69832 L .32703 .7119 L p .707 .577 .707 r
F P
0 g
s
.50632 .63466 m .51148 .65189 L .49299 .64727 L p .707 .577 .707 r
F P
0 g
s
.49299 .64727 m .48784 .63004 L .50632 .63466 L p .707 .577 .707 r
F P
0 g
s
.35466 .57068 m .34547 .51696 L .37468 .50849 L p .707 .577 .707 r
F P
0 g
s
.34547 .51696 m .35466 .57068 L .33058 .58121 L p .707 .577 .707 r
F P
0 g
s
.43681 .50078 m .44599 .5545 L .41534 .55664 L p .707 .577 .707 r
F P
0 g
s
.41534 .55664 m .40615 .50292 L .43681 .50078 L p .707 .577 .707 r
F P
0 g
s
.33406 .6088 m .34385 .6434 L .32693 .65737 L p .707 .577 .707 r
F P
0 g
s
.47364 .57204 m .48342 .60664 L .45754 .60655 L p .707 .577 .707 r
F P
0 g
s
.45754 .60655 m .44776 .57195 L .47364 .57204 L p .707 .577 .707 r
F P
0 g
s
.38386 .56222 m .37468 .50849 L .40615 .50292 L p .707 .577 .707 r
F P
0 g
s
.37468 .50849 m .38386 .56222 L .35466 .57068 L p .707 .577 .707 r
F P
0 g
s
.40615 .50292 m .41534 .55664 L .38386 .56222 L p .707 .577 .707 r
F P
0 g
s
.34385 .6434 m .33406 .6088 L .35815 .59555 L p .707 .577 .707 r
F P
0 g
s
.33609 .69832 m .33093 .68109 L .34865 .66689 L p .707 .577 .707 r
F P
0 g
s
.34865 .66689 m .3538 .68412 L .33609 .69832 L p .707 .577 .707 r
F P
0 g
s
.44776 .57195 m .45754 .60655 L .42771 .61078 L p .707 .577 .707 r
F P
0 g
s
.42771 .61078 m .41792 .57617 L .44776 .57195 L p .707 .577 .707 r
F P
0 g
s
.48784 .63004 m .49299 .64727 L .4678 .64702 L p .707 .577 .707 r
F P
0 g
s
.4678 .64702 m .46264 .62979 L .48784 .63004 L p .707 .577 .707 r
F P
0 g
s
.35815 .59555 m .36793 .63015 L .34385 .6434 L p .707 .577 .707 r
F P
0 g
s
.36793 .63015 m .35815 .59555 L .38704 .58431 L p .707 .577 .707 r
F P
0 g
s
.41792 .57617 m .42771 .61078 L .39683 .61891 L p .707 .577 .707 r
F P
0 g
s
.39683 .61891 m .38704 .58431 L .41792 .57617 L p .707 .577 .707 r
F P
0 g
s
.38704 .58431 m .39683 .61891 L .36793 .63015 L p .707 .577 .707 r
F P
0 g
s
.3538 .68412 m .34865 .66689 L .37328 .65345 L p .707 .577 .707 r
F P
0 g
s
.37328 .65345 m .37844 .67068 L .3538 .68412 L p .707 .577 .707 r
F P
0 g
s
.46264 .62979 m .4678 .64702 L .43837 .65118 L p .707 .577 .707 r
F P
0 g
s
.43837 .65118 m .43321 .63395 L .46264 .62979 L p .707 .577 .707 r
F P
0 g
s
.37844 .67068 m .37328 .65345 L .40242 .64211 L p .707 .577 .707 r
F P
0 g
s
.43321 .63395 m .43837 .65118 L .40757 .65934 L p .707 .577 .707 r
F P
0 g
s
.40757 .65934 m .40242 .64211 L .43321 .63395 L p .707 .577 .707 r
F P
0 g
s
.40242 .64211 m .40757 .65934 L .37844 .67068 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo7P00P7oo001iOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1@00L7oo001/Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH3001]Ool006Yoo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006]oo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00P00JGoo001WOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
001WOol006Ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Ioo`00IWoo0P0015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF000015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00004FUH00`00FUIJEP06FUH00`00FUIJEP0=0008FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000AJEP03001JEUYF00T000AJEP03001JEUYF00AJEP03001JEP00008000EJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00@005YF
001JEPH000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00H0
05YF000005YF0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol006Aoo`<0
00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00HGoo
0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
000000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00Ggoo
0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00
06Eoo`00GGoo0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0006Eoo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0`001eYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00Egoo0P000UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00
06Eoo`00EWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000]JEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo0P001EYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Eoo`00
EGoo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0006Eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0001UOol005Aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7
0004FUH00`00FUIJEP03FUH01000FUH000002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH00UYF2@001UYF20000eYF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00<005YF000015YF00<005YFFUH01EYF00<005YF
FUH01EYF1P000eYF00<005YFFUH01UYF0`001UYF00<005YF00000`000UYF00<005YFFUH025YF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00008Goo3`00=Goo001EOol00`00
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF000000030002FUH00`00FUIJEP02
FUH400000eYF001JEP06FUH00`00FUIJEP02FUH4000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH0000@OolA0004FUH00`00FUIJEP05FUH00`00FUIJEP07000^Ool005Eo
o`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUH000020003FUH00`00FUH000040002FUH50005
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUH0000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Eoo`04001JEUYF0004FUH00`00FUIJ
EP03FUH300000eYF001JEP03FUH00`00FUH000060002FUH01000FUIJEUYF3P0015YF00@005YF0000
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000Ioo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF008002eoo`00EGoo00@005YFFUH000AJEP04001JEUYFFUHA0003FUH60004FUH00`00FUIJEP04
FUH00`00FUIJEP050002FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00002Ool40005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`03001JEP0000AJEP04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP08FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool005Ioo`03001JEP00
00AJEP8000MJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEP00000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003moo`T000ioo`04001JEUYF0002FUH0
0`00FUH00007FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Uoo`H000AJEP03001JEUYF009JEPP000Io
o`03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00=Goo
100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPL0009JEP03001JEUYF00=JEP03001J
EUYF00EJEP<000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009J
EP04001JEUYF0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP02000]Ool003=oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP03FUH20008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002EYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
02eoo`00<Woo0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00L005YF001J
EP00FUH00004FUH01000FUIJEUYF0`002EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00<7oo0P0000=JEP00FUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF
009JEP04001JEP000003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002moo`05001JEUYFFUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YF
FUH00UYF0P001EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF3P000UYF00@005YF
FUH000QJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000EJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH0009JEP05001JEUYFFUH00007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH60004FUH01000FUH000001UYF0`000UYF00<005YFFUH01UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008002aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUH0009JEP03001JEUYF008000MJEP03001JEUYF00MJEP03001JEUYF
009JEP<0009JEP03001JEUYF00AJEP<000QJEP800004FUH005YF0008FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/
Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEUYFFUH00002FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
00020005FUH00`00FUIJEP050008FUH20002FUH00`00FUH000020007FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/
Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000IJEPD000AJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000MJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF009JEQd00003FUH0000002aoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P000UYF00<005YFFUH010002EYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P001eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00
FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0`00;7oo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUH0
000900000eYF001JEP0:FUH00`00FUIJEP02FUH30005FUH01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00@005YFFUIJEPP000QJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00
;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF0`000UYF00<005YF000010000UYF
00<005YFFUH025YF3@000UYF00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP800004FUH005YFFUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP04000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP02
FUH00`00FUIJEP02FUH30004FUH00`00FUH000040002FUH01000FUIJEUYF1`000eYF00<005YFFUH0
15YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH6000aOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
009JEPl000IJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUH0000200000eYF001JEP03
FUH00`00FUH000040002FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0`00
25YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00=goo000/Ool00`00
FUH00003FUH00`00FUIJEP03FUH6000?Ool40002FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF
0P000UYF00<005YF000015YF00<005YFFUH01P001UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YF00001eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00H0
05YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000nOol002ao
o`03001JEP0000=JEP03001JEP0000<001Uoo`@000=JEP04001JEUYF0004FUH20003FUH00`00FUH0
0004FUH00`00FUIJEP0200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP00OolM
000DOol7000/Ool002]oo`03001JEP0000AJEP80025oo`@000=JEP06001JEP00001JEP000eYF00<0
05YF000015YF0`000eYF00<005YFFUH01eYF00<005YFFUH00UYF3P000UYF00<005YF00001UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000:goo1`000UYF00<005YFFUH0
0P00;7oo000[Ool00`00FUH00002FUH4000:Ool9000AOol01000FUIJEUYF0P000eYF00<005YFFUH0
0P0000AJEP00FUIJEP8000MJEP03001JEUYF00AJEPL00003FUH005YF00IJEP03001JEUYF00D00003
FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0002=oo`P0
00=JEP03001JEUYF00=JEP03001JEUYF008002aoo`00:goo00<005YF00000P0000AJEP00FUIJEP80
00=oo`D000AJEP03001JEUYF009JEPL000]oo`03001JEUYF008000=JEP03001JEUYF00800003FUH0
0000008000QJEP03001JEUYF00D000QJEP03001JEUYF00EJEP<000AJEP<000EJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0001Yoo`T000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002aoo`00:goo00<005YF00000eYF00<005YFFUH00UYF100025YF00<0
05YFFUH01UYF00<005YFFUH010001goo00<005YF00000UYF2P000UYF00<005YFFUH01EYF100015YF
00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH00UYF0P0000=JEP00FUH015YF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000010003Goo2@0015YF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000[Ool20003FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003Ool01000FUH0
00000eYF00@005YFFUIJEP8000EJEP03001JEUYF009JEP8000QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP06001JEUYFFUH005YF0P001EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF000015YF0`000Woo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YFFUH00P00;7oo000[Ool20003FUH00`00FUIJEP020004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000Woo00<005YF000015YF
00<005YF00001eYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01eYF00@005YF000000EJ
EP04001JEUYF0002FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH<0003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP02000[Ool002]oo`8000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP03FUH30007FUH20004FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH20007FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0P000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo
0P000UYF0P000UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000eYF0P0000=JEP00FUH015YF0P001UYF00<005YFFUH01eYF00<0
05YFFUH015YF0P002EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00=JEP80009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool002]oo`80
0003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP030008FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2000;FUH200001EYF001JEUYF00001UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]oo`00:goo1000
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00@005YF000000EJEP<000=JEP03001JEUYF009JEP@000UJEP06001JEP00001JEP002UYF00<0
05YFFUH00UYF0P001eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEUYF008002]oo`00;7oo00<005YF00000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00<0
05YFFUH00eYF00@005YFFUIJEPD000MJEP@000=JEP03001JEUYF00IJEP8000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF1`00:goo000/Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP06
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH01000FUIJEUYF1P000UYF10001eYF00<005YFFUH0
15YF0P0000=JEP00FUH00eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00<005YF00000UYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH9000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEPH00003
FUH005YF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03001JEP00009JEP03001JEP00
008000MJEP03001JEUYF00P000]JEP03001JEUYF009JEP8000=JEP05001JEUYFFUH0000:FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2`00=Woo000[Ool00`00FUH00003FUH0
0`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH40006FUH20003FUHC0003FUH00`00
FUIJEP09FUH00`00FUIJEP020006FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH=000mOol002]oo`03001JEP0000=JEP80009JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH20004FUH20003FUH01000FUH005YF0`0000=JEP00FUH0
0eYF00<005YFFUH01UYF00<005YFFUH02EYF10001eYF0P0035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00H005YF000005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH<0016
Ool002]oo`80009JEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP<00003FUH00000009JEP0:001JEUYF001JEP00Ool005YF0004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH20002FUH00`00FUIJEP04FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01P00FUH00000FUH0009JEQ4004moo`00:goo10000goo00@005YFFUH000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000@0009JEP04001JEUYFFUH2
00000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20005FUH01000FUIJEUYF0P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001`00
0eYF00<005YFFUH00P00EWoo000ZOol00`00FUH00006Ool30007FUH:0008FUH00`00FUIJEP05FUH0
1000FUIJEUYF0`000UYF00@005YFFUIJEP800003FUH005YF00=JEP03001JEUYF00IJEP03001JEUYF
009JEP@000MJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02000VOol5000[Ool002Yo
o`04001JEP000007Ool200000eYF000000040003FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01UYF1@00
0UYF00<005YFFUH01UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEP8001Qooa400003FUH007oo
02Yoo`00:Woo10001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<0
05YFFUH00UYF00<005YF00000P000eYF0P0000=JEP00FUH00eYF00<005YFFUH01`001UYF00<005YF
FUH015YF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YF00000P0000=JEP00FUH015YF00@005YFFUIJEP8000Yoo`<0009oo`l000=JEP03001JEUYF
00=JEP04001JEUYF000[Ool002Yoo`<00003FUH007oo009oo`8000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP@0009JEP03001JEP0000D0009JEPh000AJEP03001JEUYF00MJEP04
001JEUYFFUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUH005YF100015YF00@005YFFUIJEP8000Iooa0000AJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002Yoo`00:Woo00H005YF001JEP00Ool30005FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030004Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUH0000015YF0`0000=JEP00FUH00UYF3`0015YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002Yoo`00:Woo0P000UYF0P00
0UYF00<005YFFUH00UYF5@001UYF00<005YFFUH00UYF0P001Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH015YF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000IJEPd000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000ZOol002Yoo`800003
FUH005YF009JEP04001JEUYFFUH2000@Ool90002FUH00`00FUIJEP04FUH20003Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH0000<0003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP07000ZOol002Yoo`@0
00=JEP04001JEP00000BOol50004Ool30007FUH20003Ool30003FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH6000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH00`00FUH000060002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH01000FUIJEUYF1P00<Goo000[Ool30003FUH4000COol30008Ool20005FUH0
0`00FUH00005Ool?0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUH00000FUH000EJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003Moo`00:goo0P000UYF0P0015YF0P00
7Woo0P000eYF00<005YFFUH00P000Woo1@0000=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00H005YF000005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000o
Ool002]oo`@000IJEP04001JEP00000NOol200000eYF001JEP03FUH20002FUH300000eYF001JEP03
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01`00FUH005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
009JEPT004Qoo`00:Woo00D005YF001JEP0000IJEP04001JEUYFFUH3000MOol20005FUH01000FUH0
05YF0P0000=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH015YF30001UYF00<005YFFUH00eYF
30001EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000P0000AJEP00FUIJEPh0055oo`00
:Woo0P0000=oo`0000001UYF00<005YFFUH015YF0`0077oo00<005YFFUH00UYF0`0000EJEP00001J
EP0000AJEP03001JEUYF00EJEPP000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF009J
EPL000QJEP03001JEUYF00=JEP04001JEP00FUH5001OOol002Uoo`80009oo`8000IJEP03001JEUYF
00EJEP03001JEP0000<001Ioo`800006FUH00000FUH005YF0P0000EJEP00001JEP0000AJEP03001J
EUYF009JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP@000EJEP03001JEUYF00=JEP03001JEP0000=JEP<005moo`00:Goo0P000goo00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH00eYF1`002Goo1P001EYF0P000UYF0P0000Aoo`00FUH000AJEP03
001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEUYFFUH400000eYF001JEP04FUH00`00FUH00002FUH01000FUIJEUYF0P00GGoo000YOol2
0004Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH20003FUH01@00Ool005YF000015YF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P001EYF00<005YF00000UYF00<005YFFUH0
0eYF00<007ooOol0FWoo000YOol20006Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP05001oo`00FUH00002FUH20000
0eYF001JEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH30003FUH00`00FUH00002FUH00`00FUIJEP03FUH3001JOol002Uoo`<000Ioo`<0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
0002FUH01000Ool005YF0`000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P0000AJEP00FUH0009JEP03
001JEUYF00=JEP04001JEUYF001IOol002Yoo`8000Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF
00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00@00004Ool005YF0005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP001EYF00D005YFFUIJEP0005Uoo`00:Woo00<0
05YF00002Goo0P000eYF00<005YFFUH01UYF00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF001oo`<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30000
0eYF001JEP04FUH01000FUIJEUYF0P00F7oo000ZOol00`00FUH0000;Ool200000eYF001JEP07FUH0
0`00FUIJEP0500000eYF001JEP07FUH00`00FUIJEP04FUH20003Ool2000017oo000000001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF00H005YFFUH005YF001HOol002]oo`03
001JEP0000aoo`@000IJEP03001JEUYF00D00003FUH005YF00MJEP03001JEUYF00=JEP8000Aoo`80
0004Ool005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF00001EYF00D005YF
FUH005YF05Uoo`00:goo00<005YF00000P003Woo10000UYF00@005YFFUIJEP<0009JEP03001JEUYF
00IJEP03001JEP0000<000Ioo`800004Ool005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP05FUH00`00FUIJEP02001IOol002aoo`80009JEP03001oogoo00moo`L000AJEP03
001JEUYF009JEPH000Yoo`80009oo`8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEPD000AJEP04
001JEUYFFUH2001IOol002aoo`8000=JEP8001Ioo`T000moo`03001JEP00009oo`8000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<00003FUH005YF009JEP03001oogoo05Qoo`00
;Goo00<005YFFUH00eYF0P00;7oo00<005YF00000goo00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00eYF00@005YF000000=JEP03001oogoo05Qoo`00;Woo00<005YFFUH0
0UYF00@005YF000002Qoo`@000Eoo`8000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20006FUH01P00
FUIJEUYF001JEP8005Yoo`00;goo00D005YFFUIJEP0000=JEP8002Aoo`800003FUH0000000Qoo`80
0003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YFFUH00UYF0`00FWoo000`Ool00`00FUH0
0006FUH3000OOol20003FUH2000:Ool40006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP02FUH2001KOol0035oo`80
00MJEP03001JEP00008001Yoo`800003FUH005YF009JEP03001oogoo00eoo`@0009JEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00<000EJEP03001J
EP0000<000=JEP03001JEUYF009JEP03001JEP0005]oo`00<Woo0P001UYF00<005YFFUH00UYF0`00
5Goo0P000eYF00@005YFFUH001Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00IJEPD000MJEP03001JEUYF00AJEPX005aoo`00=7oo0P0015YF00<005YFFUH01EYF5@0015YF00@0
05YF000001Yoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000Eoo`8000EJ
EP03001JEUYF00EJEP<0069oo`00=Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P008Woo7`000UYF0`0027oo0`0000=JEP00FUH01eYF00<005YFFUH00P00
H7oo000iOol30006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000fOol20003
FUH00`00FUIJEP07FUH01000FUH000002Goo0`001UYF00<005YFFUH00eYF00<007ooOol0GGoo000l
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000jOol200000eYF001JEP07
FUH00`00FUIJEP02FUH30009Ool20004FUH00`00FUIJEP03FUH3001MOol0041oo`L000AJEP03001J
EUYF009JEPH0041oo`<000MJEP03001JEUYF00EJEPH000Eoo`<00003FUH005YF00AJEP04001JEUYF
001LOol004Moo`T004Uoo`@0009JEP03001JEUYF00MJEP03001JEUYF009JEP/000=JEP05001JEUYF
FUH0001LOol009eoo`@000QJEP03001JEUYF00IJEP04001JEUYFFUH500000eYF001JEP02FUH00`00
Oomoo`1JOol00:5oo`<000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000002FUH2001L
Ool00:Aoo`<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEUYF009JEP@005aoo`00Ygoo0`00
1eYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000GGoo002ZOol40002FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001MOol00:ioo`H000=JEP03001JEUYF009JEP04001JEP00001M
Ool00;Aoo`X005moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]3\[InvisibleSpace]"     "\
\[InvisibleSpace]2.258504055131208`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 3, "     ", 2.2585040551312079, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59255 .73283 m .59626 .67559 L .56511 .67284 L p .707 .577 .707 r
F P
0 g
s
.59626 .67559 m .59255 .73283 L .6243 .73452 L p .707 .577 .707 r
F P
0 g
s
.6243 .73452 m .62801 .67729 L .59626 .67559 L p .707 .577 .707 r
F P
0 g
s
.62801 .67729 m .6243 .73452 L .65356 .73499 L p .707 .577 .707 r
F P
0 g
s
.65356 .73499 m .65727 .67776 L .62801 .67729 L p .707 .577 .707 r
F P
0 g
s
.56511 .67284 m .5614 .73007 L .59255 .73283 L p .707 .577 .707 r
F P
0 g
s
.5614 .73007 m .56511 .67284 L .53763 .6693 L p .707 .577 .707 r
F P
0 g
s
.58942 .78172 m .59342 .74346 L .56232 .74017 L p .707 .577 .707 r
F P
0 g
s
.59342 .74346 m .58942 .78172 L .62104 .78499 L p .707 .577 .707 r
F P
0 g
s
.62104 .78499 m .62504 .74674 L .59342 .74346 L p .707 .577 .707 r
F P
0 g
s
.56232 .74017 m .55833 .77842 L .58942 .78172 L p .707 .577 .707 r
F P
0 g
s
.53763 .6693 m .53392 .72653 L .5614 .73007 L p .707 .577 .707 r
F P
0 g
s
.62504 .74674 m .62104 .78499 L .65009 .78792 L p .707 .577 .707 r
F P
0 g
s
.65009 .78792 m .65408 .74967 L .62504 .74674 L p .707 .577 .707 r
F P
0 g
s
.55799 .79547 m .55577 .81457 L .58685 .81803 L p .707 .577 .707 r
F P
0 g
s
.58685 .81803 m .58907 .79893 L .55799 .79547 L p .707 .577 .707 r
F P
0 g
s
.58907 .79893 m .58685 .81803 L .61842 .82177 L p .707 .577 .707 r
F P
0 g
s
.61842 .82177 m .62064 .80267 L .58907 .79893 L p .707 .577 .707 r
F P
0 g
s
.65727 .67776 m .65356 .73499 L .67745 .7342 L p .707 .577 .707 r
F P
0 g
s
.67745 .7342 m .68116 .67697 L .65727 .67776 L p .707 .577 .707 r
F P
0 g
s
.55833 .77842 m .56232 .74017 L .53479 .73717 L p .707 .577 .707 r
F P
0 g
s
.53479 .73717 m .53079 .77543 L .55833 .77842 L p .707 .577 .707 r
F P
0 g
s
.62064 .80267 m .61842 .82177 L .64739 .82544 L p .707 .577 .707 r
F P
0 g
s
.64739 .82544 m .64961 .80634 L .62064 .80267 L p .707 .577 .707 r
F P
0 g
s
.53044 .79264 m .52822 .81173 L .55577 .81457 L p .707 .577 .707 r
F P
0 g
s
.55577 .81457 m .55799 .79547 L .53044 .79264 L p .707 .577 .707 r
F P
0 g
s
.53392 .72653 m .53763 .6693 L .51649 .66532 L p .707 .577 .707 r
F P
0 g
s
.65408 .74967 m .65009 .78792 L .67372 .79023 L p .707 .577 .707 r
F P
0 g
s
.67372 .79023 m .67772 .75197 L .65408 .74967 L p .707 .577 .707 r
F P
0 g
s
.51649 .66532 m .51278 .72255 L .53392 .72653 L p .707 .577 .707 r
F P
0 g
s
.64961 .80634 m .64739 .82544 L .67092 .82866 L p .707 .577 .707 r
F P
0 g
s
.67092 .82866 m .67314 .80956 L .64961 .80634 L p .707 .577 .707 r
F P
0 g
s
.53079 .77543 m .53479 .73717 L .51352 .73477 L p .707 .577 .707 r
F P
0 g
s
.51352 .73477 m .50952 .77302 L .53079 .77543 L p .707 .577 .707 r
F P
0 g
s
.68116 .67697 m .67745 .7342 L .69364 .73221 L p .707 .577 .707 r
F P
0 g
s
.69364 .73221 m .69735 .67498 L .68116 .67697 L p .707 .577 .707 r
F P
0 g
s
.50912 .7907 m .5069 .8098 L .52822 .81173 L p .707 .577 .707 r
F P
0 g
s
.52822 .81173 m .53044 .79264 L .50912 .7907 L p .707 .577 .707 r
F P
0 g
s
.51278 .72255 m .51649 .66532 L .50377 .66129 L p .707 .577 .707 r
F P
0 g
s
.67772 .75197 m .67372 .79023 L .68963 .79167 L p .707 .577 .707 r
F P
0 g
s
.68963 .79167 m .69362 .75341 L .67772 .75197 L p .707 .577 .707 r
F P
0 g
s
.50377 .66129 m .50006 .71852 L .51278 .72255 L p .707 .577 .707 r
F P
0 g
s
.67314 .80956 m .67092 .82866 L .68671 .83113 L p .707 .577 .707 r
F P
0 g
s
.68671 .83113 m .68892 .81203 L .67314 .80956 L p .707 .577 .707 r
F P
0 g
s
.50952 .77302 m .51352 .73477 L .50059 .73319 L p .707 .577 .707 r
F P
0 g
s
.50059 .73319 m .4966 .77145 L .50952 .77302 L p .707 .577 .707 r
F P
0 g
s
.49611 .78986 m .49389 .80896 L .5069 .8098 L p .707 .577 .707 r
F P
0 g
s
.5069 .8098 m .50912 .7907 L .49611 .78986 L p .707 .577 .707 r
F P
0 g
s
.69735 .67498 m .69364 .73221 L .70055 .72923 L p .707 .577 .707 r
F P
0 g
s
.70055 .72923 m .70426 .672 L .69735 .67498 L p .707 .577 .707 r
F P
0 g
s
.50006 .71852 m .50377 .66129 L .50071 .6576 L p .707 .577 .707 r
F P
0 g
s
.69362 .75341 m .68963 .79167 L .69624 .79212 L p .707 .577 .707 r
F P
0 g
s
.69624 .79212 m .70023 .75386 L .69362 .75341 L p .707 .577 .707 r
F P
0 g
s
.68892 .81203 m .68671 .83113 L .69321 .83261 L p .707 .577 .707 r
F P
0 g
s
.69321 .83261 m .69543 .81351 L .68892 .81203 L p .707 .577 .707 r
F P
0 g
s
.50071 .6576 m .49701 .71483 L .50006 .71852 L p .707 .577 .707 r
F P
0 g
s
.4966 .77145 m .50059 .73319 L .49727 .7326 L p .707 .577 .707 r
F P
0 g
s
.49727 .7326 m .49328 .77086 L .4966 .77145 L p .707 .577 .707 r
F P
0 g
s
.49269 .7902 m .49047 .80929 L .49389 .80896 L p .707 .577 .707 r
F P
0 g
s
.49389 .80896 m .49611 .78986 L .49269 .7902 L p .707 .577 .707 r
F P
0 g
s
.70426 .672 m .70055 .72923 L .69749 .72554 L p .707 .577 .707 r
F P
0 g
s
.69749 .72554 m .7012 .66831 L .70426 .672 L p .707 .577 .707 r
F P
0 g
s
.49701 .71483 m .50071 .6576 L .50762 .65462 L p .707 .577 .707 r
F P
0 g
s
.70023 .75386 m .69624 .79212 L .69292 .79153 L p .707 .577 .707 r
F P
0 g
s
.69292 .79153 m .69692 .75327 L .70023 .75386 L p .707 .577 .707 r
F P
0 g
s
.69543 .81351 m .69321 .83261 L .68979 .83294 L p .707 .577 .707 r
F P
0 g
s
.68979 .83294 m .69201 .81384 L .69543 .81351 L p .707 .577 .707 r
F P
0 g
s
.50762 .65462 m .50391 .71185 L .49701 .71483 L p .707 .577 .707 r
F P
0 g
s
.49328 .77086 m .49727 .7326 L .50389 .73305 L p .707 .577 .707 r
F P
0 g
s
.50389 .73305 m .49989 .77131 L .49328 .77086 L p .707 .577 .707 r
F P
0 g
s
.49919 .79167 m .49697 .81077 L .49047 .80929 L p .707 .577 .707 r
F P
0 g
s
.49047 .80929 m .49269 .7902 L .49919 .79167 L p .707 .577 .707 r
F P
0 g
s
.7012 .66831 m .69749 .72554 L .68478 .72151 L p .707 .577 .707 r
F P
0 g
s
.68478 .72151 m .68848 .66428 L .7012 .66831 L p .707 .577 .707 r
F P
0 g
s
.24954 .69601 m .25325 .63878 L .2221 .63603 L p .707 .577 .707 r
F P
0 g
s
.25325 .63878 m .24954 .69601 L .28129 .69771 L p .707 .577 .707 r
F P
0 g
s
.28129 .69771 m .285 .64048 L .25325 .63878 L p .707 .577 .707 r
F P
0 g
s
.285 .64048 m .28129 .69771 L .31055 .69818 L p .707 .577 .707 r
F P
0 g
s
.31055 .69818 m .31426 .64095 L .285 .64048 L p .707 .577 .707 r
F P
0 g
s
.50391 .71185 m .50762 .65462 L .52381 .65263 L p .707 .577 .707 r
F P
0 g
s
.2221 .63603 m .2184 .69326 L .24954 .69601 L p .707 .577 .707 r
F P
0 g
s
.2184 .69326 m .2221 .63603 L .19462 .63249 L p .707 .577 .707 r
F P
0 g
s
.69692 .75327 m .69292 .79153 L .68 .78995 L p .707 .577 .707 r
F P
0 g
s
.68 .78995 m .68399 .7517 L .69692 .75327 L p .707 .577 .707 r
F P
0 g
s
.47346 .80641 m .50712 .2896 L .46315 .2857 L p .707 .577 .707 r
F P
0 g
s
.52381 .65263 m .5201 .70986 L .50391 .71185 L p .707 .577 .707 r
F P
0 g
s
.49989 .77131 m .50389 .73305 L .51979 .7345 L p .707 .577 .707 r
F P
0 g
s
.51979 .7345 m .5158 .77275 L .49989 .77131 L p .707 .577 .707 r
F P
0 g
s
.51498 .79414 m .51276 .81324 L .49697 .81077 L p .707 .577 .707 r
F P
0 g
s
.49697 .81077 m .49919 .79167 L .51498 .79414 L p .707 .577 .707 r
F P
0 g
s
.5158 .77275 m .51979 .7345 L .5399 .73645 L p .707 .577 .707 r
F P
0 g
s
.5399 .73645 m .54342 .7368 L p .53999 .74126 L .707 .577 .707 r
F P
0 g
s
.5158 .77275 m .5399 .73645 L .53999 .74126 L .707 .577 .707 r
F
.5201 .70986 m .52381 .65263 L .54771 .65183 L p F P
0 g
s
.54771 .65183 m .544 .70907 L .5201 .70986 L p .707 .577 .707 r
F P
0 g
s
.54342 .7368 m .53943 .77505 L .5158 .77275 L p .707 .577 .707 r
F P
0 g
s
.51276 .81324 m .51498 .79414 L .53801 .7973 L p .707 .577 .707 r
F P
0 g
s
.53801 .7973 m .53851 .79736 L p .53803 .79766 L .707 .577 .707 r
F P
0 g
s
.51276 .81324 m .53801 .7973 L .53803 .79766 L .707 .577 .707 r
F
.51828 .80883 m .53047 .62173 L p .50712 .2896 L F P
0 g
s
.53047 .62173 m .5362 .53376 L p .52133 .40891 L .707 .577 .707 r
F P
0 g
s
.53047 .62173 m .52133 .40891 L .50712 .2896 L .707 .577 .707 r
F
.5362 .53376 m .55194 .29201 L .53176 .29092 L p F P
0 g
s
.53176 .29092 m .50712 .2896 L p .5362 .53376 L .707 .577 .707 r
F P
0 g
s
.50712 .2896 m .47346 .80641 L .51828 .80883 L p .707 .577 .707 r
F P
0 g
s
.24641 .74491 m .25041 .70665 L .21931 .70335 L p .707 .577 .707 r
F P
0 g
s
.25041 .70665 m .24641 .74491 L .27804 .74818 L p .707 .577 .707 r
F P
0 g
s
.27804 .74818 m .28203 .70992 L .25041 .70665 L p .707 .577 .707 r
F P
0 g
s
.69201 .81384 m .68979 .83294 L .67678 .8321 L p .707 .577 .707 r
F P
0 g
s
.21931 .70335 m .21532 .74161 L .24641 .74491 L p .707 .577 .707 r
F P
0 g
s
.67678 .8321 m .679 .813 L .69201 .81384 L p .707 .577 .707 r
F P
0 g
s
.19462 .63249 m .19091 .68972 L .2184 .69326 L p .707 .577 .707 r
F P
0 g
s
.53851 .79736 m .53629 .81646 L .51276 .81324 L p .707 .577 .707 r
F P
0 g
s
.544 .70907 m .54771 .65183 L .57696 .65231 L p .707 .577 .707 r
F P
0 g
s
.57696 .65231 m .57325 .70954 L .544 .70907 L p .707 .577 .707 r
F P
0 g
s
.53943 .77505 m .54342 .7368 L .55501 .73797 L p .707 .577 .707 r
F P
0 g
s
.55501 .73797 m .57247 .73973 L p .54795 .76594 L .707 .577 .707 r
F P
0 g
s
.53943 .77505 m .55501 .73797 L .54795 .76594 L .707 .577 .707 r
F
.57247 .73973 m .56848 .77798 L .53943 .77505 L p F P
0 g
s
.57325 .70954 m .57696 .65231 L .60872 .654 L p .707 .577 .707 r
F P
0 g
s
.60872 .654 m .60501 .71123 L .57325 .70954 L p .707 .577 .707 r
F P
0 g
s
.56748 .80103 m .56526 .82013 L .54072 .81702 L p .707 .577 .707 r
F P
0 g
s
.54072 .81702 m .53629 .81646 L p .54173 .81377 L .707 .577 .707 r
F P
0 g
s
.54173 .81377 m .56748 .80103 L .54072 .81702 L .707 .577 .707 r
F
.53629 .81646 m .53851 .79736 L .5465 .79837 L p F P
0 g
s
.5465 .79837 m .56748 .80103 L p .54173 .81377 L .707 .577 .707 r
F P
0 g
s
.53629 .81646 m .5465 .79837 L .54173 .81377 L .707 .577 .707 r
F
.56746 .68864 m .56398 .74199 L p .59328 .58629 L F P
0 g
s
.56398 .74199 m .55958 .80952 L p .57528 .70554 L .707 .577 .707 r
F P
0 g
s
.59328 .58629 m .56398 .74199 L .57528 .70554 L .707 .577 .707 r
F
.56848 .77798 m .57247 .73973 L .58037 .74055 L p F P
0 g
s
.58037 .74055 m .60409 .743 L p .57669 .76992 L .707 .577 .707 r
F P
0 g
s
.56848 .77798 m .58037 .74055 L .57669 .76992 L .707 .577 .707 r
F
.63986 .65676 m .63615 .71399 L .60501 .71123 L p F P
0 g
s
.60501 .71123 m .60872 .654 L .63986 .65676 L p .707 .577 .707 r
F P
0 g
s
.63519 .7463 m .63119 .78455 L .6001 .78126 L p .707 .577 .707 r
F P
0 g
s
.6001 .78126 m .60409 .743 L .63519 .7463 L p .707 .577 .707 r
F P
0 g
s
.60409 .743 m .6001 .78126 L .56848 .77798 L p .707 .577 .707 r
F P
0 g
s
.59683 .82387 m .59905 .80477 L .63013 .80823 L p .707 .577 .707 r
F P
0 g
s
.59905 .80477 m .59683 .82387 L .5721 .82094 L p .707 .577 .707 r
F P
0 g
s
.5721 .82094 m .56526 .82013 L p .57271 .81674 L .707 .577 .707 r
F P
0 g
s
.57271 .81674 m .59905 .80477 L .5721 .82094 L .707 .577 .707 r
F
.56526 .82013 m .56748 .80103 L .57484 .8019 L p F P
0 g
s
.57484 .8019 m .59905 .80477 L p .57271 .81674 L .707 .577 .707 r
F P
0 g
s
.56526 .82013 m .57484 .8019 L .57271 .81674 L .707 .577 .707 r
F
.6165 .4525 m .60942 .56118 L p .62502 .38452 L F P
0 g
s
.60942 .56118 m .59331 .80844 L p .61441 .52646 L .707 .577 .707 r
F P
0 g
s
.62502 .38452 m .60942 .56118 L .61441 .52646 L .707 .577 .707 r
F
.59331 .80844 m .61617 .80568 L p .62335 .46421 L F P
0 g
s
.62335 .46421 m .62502 .38452 L .61441 .52646 L .707 .577 .707 r
F
.62335 .46421 m .61441 .52646 L .59331 .80844 L F
.62697 .29162 m .6165 .4525 L p .62502 .38452 L F P
0 g
s
.55958 .80952 m .59331 .80844 L p .59329 .64744 L .707 .577 .707 r
F P
0 g
s
.59329 .64744 m .59328 .58629 L .57528 .70554 L .707 .577 .707 r
F
.59329 .64744 m .57528 .70554 L .55958 .80952 L F
.59324 .29271 m .56746 .68864 L p .59328 .58629 L F P
0 g
s
.55194 .29201 m .51828 .80883 L .55958 .80952 L p .707 .577 .707 r
F P
0 g
s
.55958 .80952 m .59324 .29271 L .55194 .29201 L p .707 .577 .707 r
F P
0 g
s
.28203 .70992 m .27804 .74818 L .30708 .75111 L p .707 .577 .707 r
F P
0 g
s
.30708 .75111 m .31108 .71285 L .28203 .70992 L p .707 .577 .707 r
F P
0 g
s
.21498 .75865 m .21276 .77775 L .24384 .78121 L p .707 .577 .707 r
F P
0 g
s
.24384 .78121 m .24606 .76211 L .21498 .75865 L p .707 .577 .707 r
F P
0 g
s
.24606 .76211 m .24384 .78121 L .27541 .78496 L p .707 .577 .707 r
F P
0 g
s
.27541 .78496 m .27763 .76586 L .24606 .76211 L p .707 .577 .707 r
F P
0 g
s
.31426 .64095 m .31055 .69818 L .33444 .69738 L p .707 .577 .707 r
F P
0 g
s
.33444 .69738 m .33815 .64015 L .31426 .64095 L p .707 .577 .707 r
F P
0 g
s
.21532 .74161 m .21931 .70335 L .19178 .70036 L p .707 .577 .707 r
F P
0 g
s
.42949 .80252 m .46315 .2857 L .42434 .28071 L p .707 .577 .707 r
F P
0 g
s
.46315 .2857 m .42949 .80252 L .47346 .80641 L p .707 .577 .707 r
F P
0 g
s
.19178 .70036 m .18778 .73861 L .21532 .74161 L p .707 .577 .707 r
F P
0 g
s
.27763 .76586 m .27541 .78496 L .30438 .78862 L p .707 .577 .707 r
F P
0 g
s
.30438 .78862 m .3066 .76952 L .27763 .76586 L p .707 .577 .707 r
F P
0 g
s
.18743 .75582 m .18521 .77492 L .21276 .77775 L p .707 .577 .707 r
F P
0 g
s
.21276 .77775 m .21498 .75865 L .18743 .75582 L p .707 .577 .707 r
F P
0 g
s
.19091 .68972 m .19462 .63249 L .17348 .62851 L p .707 .577 .707 r
F P
0 g
s
.68848 .66428 m .68478 .72151 L .66364 .71753 L p .707 .577 .707 r
F P
0 g
s
.66364 .71753 m .66735 .6603 L .68848 .66428 L p .707 .577 .707 r
F P
0 g
s
.31108 .71285 m .30708 .75111 L .33071 .75341 L p .707 .577 .707 r
F P
0 g
s
.33071 .75341 m .33471 .71515 L .31108 .71285 L p .707 .577 .707 r
F P
0 g
s
.17348 .62851 m .16977 .68574 L .19091 .68972 L p .707 .577 .707 r
F P
0 g
s
.3066 .76952 m .30438 .78862 L .32791 .79185 L p .707 .577 .707 r
F P
0 g
s
.59331 .80844 m .62697 .29162 L .59324 .29271 L p .707 .577 .707 r
F P
0 g
s
.32791 .79185 m .33013 .77275 L .3066 .76952 L p .707 .577 .707 r
F P
0 g
s
.18778 .73861 m .19178 .70036 L .17051 .69795 L p .707 .577 .707 r
F P
0 g
s
.17051 .69795 m .16651 .73621 L .18778 .73861 L p .707 .577 .707 r
F P
0 g
s
.68399 .7517 m .68 .78995 L .65873 .78755 L p .707 .577 .707 r
F P
0 g
s
.65873 .78755 m .66272 .74929 L .68399 .7517 L p .707 .577 .707 r
F P
0 g
s
.33815 .64015 m .33444 .69738 L .35064 .6954 L p .707 .577 .707 r
F P
0 g
s
.35064 .6954 m .35434 .63817 L .33815 .64015 L p .707 .577 .707 r
F P
0 g
s
.16611 .75389 m .16389 .77299 L .18521 .77492 L p .707 .577 .707 r
F P
0 g
s
.18521 .77492 m .18743 .75582 L .16611 .75389 L p .707 .577 .707 r
F P
0 g
s
.679 .813 m .67678 .8321 L .65546 .83016 L p .707 .577 .707 r
F P
0 g
s
.39068 .79753 m .42434 .28071 L .3945 .27511 L p .707 .577 .707 r
F P
0 g
s
.42434 .28071 m .39068 .79753 L .42949 .80252 L p .707 .577 .707 r
F P
0 g
s
.65546 .83016 m .65768 .81107 L .679 .813 L p .707 .577 .707 r
F P
0 g
s
.16977 .68574 m .17348 .62851 L .16076 .62447 L p .707 .577 .707 r
F P
0 g
s
.66735 .6603 m .66364 .71753 L .63615 .71399 L p .707 .577 .707 r
F P
0 g
s
.63615 .71399 m .63986 .65676 L .66735 .6603 L p .707 .577 .707 r
F P
0 g
s
.33471 .71515 m .33071 .75341 L .34662 .75486 L p .707 .577 .707 r
F P
0 g
s
.34662 .75486 m .35061 .7166 L .33471 .71515 L p .707 .577 .707 r
F P
0 g
s
.16076 .62447 m .15705 .6817 L .16977 .68574 L p .707 .577 .707 r
F P
0 g
s
.33013 .77275 m .32791 .79185 L .3437 .79432 L p .707 .577 .707 r
F P
0 g
s
.3437 .79432 m .34592 .77522 L .33013 .77275 L p .707 .577 .707 r
F P
0 g
s
.16651 .73621 m .17051 .69795 L .15758 .69638 L p .707 .577 .707 r
F P
0 g
s
.15758 .69638 m .15359 .73463 L .16651 .73621 L p .707 .577 .707 r
F P
0 g
s
.66272 .74929 m .65873 .78755 L .63119 .78455 L p .707 .577 .707 r
F P
0 g
s
.63119 .78455 m .63519 .7463 L .66272 .74929 L p .707 .577 .707 r
F P
0 g
s
.1531 .75305 m .15088 .77215 L .16389 .77299 L p .707 .577 .707 r
F P
0 g
s
.16389 .77299 m .16611 .75389 L .1531 .75305 L p .707 .577 .707 r
F P
0 g
s
.61617 .80568 m .64983 .28886 L .62697 .29162 L p .707 .577 .707 r
F P
0 g
s
.65768 .81107 m .65546 .83016 L .62791 .82733 L p .707 .577 .707 r
F P
0 g
s
.35434 .63817 m .35064 .6954 L .35754 .69241 L p .707 .577 .707 r
F P
0 g
s
.35754 .69241 m .36125 .63518 L .35434 .63817 L p .707 .577 .707 r
F P
0 g
s
.62791 .82733 m .63013 .80823 L .65768 .81107 L p .707 .577 .707 r
F P
0 g
s
.36084 .79193 m .3945 .27511 L .37654 .26945 L p .707 .577 .707 r
F P
0 g
s
.3945 .27511 m .36084 .79193 L .39068 .79753 L p .707 .577 .707 r
F P
0 g
s
.15705 .6817 m .16076 .62447 L .1577 .62079 L p .707 .577 .707 r
F P
0 g
s
.35061 .7166 m .34662 .75486 L .35323 .7553 L p .707 .577 .707 r
F P
0 g
s
.35323 .7553 m .35722 .71705 L .35061 .7166 L p .707 .577 .707 r
F P
0 g
s
.63013 .80823 m .62791 .82733 L .59683 .82387 L p .707 .577 .707 r
F P
0 g
s
.34592 .77522 m .3437 .79432 L .3502 .79579 L p .707 .577 .707 r
F P
0 g
s
.3502 .79579 m .35242 .77669 L .34592 .77522 L p .707 .577 .707 r
F P
0 g
s
.1577 .62079 m .154 .67802 L .15705 .6817 L p .707 .577 .707 r
F P
0 g
s
.15359 .73463 m .15758 .69638 L .15426 .69579 L p .707 .577 .707 r
F P
0 g
s
.15426 .69579 m .15027 .73404 L .15359 .73463 L p .707 .577 .707 r
F P
0 g
s
.14968 .75338 m .14746 .77248 L .15088 .77215 L p .707 .577 .707 r
F P
0 g
s
.15088 .77215 m .1531 .75305 L .14968 .75338 L p .707 .577 .707 r
F P
0 g
s
.36125 .63518 m .35754 .69241 L .35449 .68872 L p .707 .577 .707 r
F P
0 g
s
.35449 .68872 m .35819 .63149 L .36125 .63518 L p .707 .577 .707 r
F P
0 g
s
.64983 .28886 m .61617 .80568 L .62592 .80151 L p .707 .577 .707 r
F P
0 g
s
.62592 .80151 m .65958 .28469 L .64983 .28886 L p .707 .577 .707 r
F P
0 g
s
.154 .67802 m .1577 .62079 L .16461 .6178 L p .707 .577 .707 r
F P
0 g
s
.35722 .71705 m .35323 .7553 L .34991 .75471 L p .707 .577 .707 r
F P
0 g
s
.34991 .75471 m .35391 .71646 L .35722 .71705 L p .707 .577 .707 r
F P
0 g
s
.35242 .77669 m .3502 .79579 L .34678 .79612 L p .707 .577 .707 r
F P
0 g
s
.34678 .79612 m .349 .77702 L .35242 .77669 L p .707 .577 .707 r
F P
0 g
s
.16461 .6178 m .1609 .67503 L .154 .67802 L p .707 .577 .707 r
F P
0 g
s
.35819 .63149 m .35449 .68872 L .34177 .68469 L p .707 .577 .707 r
F P
0 g
s
.34177 .68469 m .34547 .62746 L .35819 .63149 L p .707 .577 .707 r
F P
0 g
s
.35391 .71646 m .34991 .75471 L .34721 .75438 L p .707 .577 .707 r
F P
0 g
s
.34721 .75438 m .33699 .75314 L p .34823 .72876 L .707 .577 .707 r
F P
0 g
s
.34823 .72876 m .35391 .71646 L .34721 .75438 L .707 .577 .707 r
F
.37654 .26945 m .37223 .26428 L p .35337 .59964 L F P
0 g
s
.33699 .75314 m .34098 .71488 L .34875 .71583 L p .707 .577 .707 r
F P
0 g
s
.34875 .71583 m .35391 .71646 L p .34823 .72876 L .707 .577 .707 r
F P
0 g
s
.33699 .75314 m .34875 .71583 L .34823 .72876 L .707 .577 .707 r
F
.349 .77702 m .34678 .79612 L .34479 .79599 L p F P
0 g
s
.34479 .79599 m .33377 .79528 L p .34526 .78151 L .707 .577 .707 r
F P
0 g
s
.34526 .78151 m .349 .77702 L .34479 .79599 L .707 .577 .707 r
F
.33377 .79528 m .33599 .77618 L .34541 .77679 L p F P
0 g
s
.34541 .77679 m .349 .77702 L p .34526 .78151 L .707 .577 .707 r
F P
0 g
s
.33377 .79528 m .34541 .77679 L .34526 .78151 L .707 .577 .707 r
F
.35808 .4815 m .35185 .57719 L p .35337 .59964 L F P
0 g
s
.35185 .57719 m .33857 .7811 L p .34965 .64526 L .707 .577 .707 r
F P
0 g
s
.35337 .59964 m .35185 .57719 L .34965 .64526 L .707 .577 .707 r
F
.33857 .7811 m .34288 .78627 L p .34809 .6936 L F P
0 g
s
.34809 .6936 m .35337 .59964 L .34965 .64526 L .707 .577 .707 r
F
.34809 .6936 m .34965 .64526 L .33857 .7811 L F
.37223 .26428 m .35808 .4815 L p .35337 .59964 L F P
0 g
s
.34288 .78627 m .35076 .66538 L p .35337 .59964 L .707 .577 .707 r
F P
0 g
s
.35076 .66538 m .37654 .26945 L p .35337 .59964 L .707 .577 .707 r
F P
0 g
s
.37654 .26945 m .34288 .78627 L .36084 .79193 L p .707 .577 .707 r
F P
0 g
s
.15027 .73404 m .15426 .69579 L .16088 .69624 L p .707 .577 .707 r
F P
0 g
s
.16088 .69624 m .15688 .73449 L .15027 .73404 L p .707 .577 .707 r
F P
0 g
s
.15618 .75485 m .15396 .77395 L .14746 .77248 L p .707 .577 .707 r
F P
0 g
s
.14746 .77248 m .14968 .75338 L .15618 .75485 L p .707 .577 .707 r
F P
0 g
s
.1609 .67503 m .16461 .6178 L .1808 .61581 L p .707 .577 .707 r
F P
0 g
s
.1808 .61581 m .1771 .67305 L .1609 .67503 L p .707 .577 .707 r
F P
0 g
s
.65958 .28469 m .62592 .80151 L .6216 .79634 L p .707 .577 .707 r
F P
0 g
s
.6216 .79634 m .65526 .27952 L .65958 .28469 L p .707 .577 .707 r
F P
0 g
s
.15688 .73449 m .16088 .69624 L .17678 .69768 L p .707 .577 .707 r
F P
0 g
s
.17678 .69768 m .17279 .73594 L .15688 .73449 L p .707 .577 .707 r
F P
0 g
s
.17197 .75732 m .16975 .77642 L .15396 .77395 L p .707 .577 .707 r
F P
0 g
s
.15396 .77395 m .15618 .75485 L .17197 .75732 L p .707 .577 .707 r
F P
0 g
s
.34547 .62746 m .34177 .68469 L .32063 .68071 L p .707 .577 .707 r
F P
0 g
s
.32063 .68071 m .32434 .62348 L .34547 .62746 L p .707 .577 .707 r
F P
0 g
s
.33857 .7811 m .37223 .26428 L .38197 .26011 L p .707 .577 .707 r
F P
0 g
s
.1771 .67305 m .1808 .61581 L .2047 .61502 L p .707 .577 .707 r
F P
0 g
s
.34098 .71488 m .33699 .75314 L .31572 .75074 L p .707 .577 .707 r
F P
0 g
s
.31572 .75074 m .31971 .71248 L .34098 .71488 L p .707 .577 .707 r
F P
0 g
s
.2047 .61502 m .20099 .67225 L .1771 .67305 L p .707 .577 .707 r
F P
0 g
s
.33599 .77618 m .33377 .79528 L .31245 .79335 L p .707 .577 .707 r
F P
0 g
s
.31245 .79335 m .31467 .77425 L .33599 .77618 L p .707 .577 .707 r
F P
0 g
s
.17279 .73594 m .17678 .69768 L .20041 .69998 L p .707 .577 .707 r
F P
0 g
s
.20041 .69998 m .19642 .73824 L .17279 .73594 L p .707 .577 .707 r
F P
0 g
s
.32434 .62348 m .32063 .68071 L .29314 .67717 L p .707 .577 .707 r
F P
0 g
s
.29314 .67717 m .29685 .61994 L .32434 .62348 L p .707 .577 .707 r
F P
0 g
s
.1955 .76055 m .19328 .77965 L .16975 .77642 L p .707 .577 .707 r
F P
0 g
s
.16975 .77642 m .17197 .75732 L .1955 .76055 L p .707 .577 .707 r
F P
0 g
s
.20099 .67225 m .2047 .61502 L .23395 .61549 L p .707 .577 .707 r
F P
0 g
s
.65526 .27952 m .6216 .79634 L .60364 .79068 L p .707 .577 .707 r
F P
0 g
s
.60364 .79068 m .6373 .27386 L .65526 .27952 L p .707 .577 .707 r
F P
0 g
s
.23395 .61549 m .23024 .67272 L .20099 .67225 L p .707 .577 .707 r
F P
0 g
s
.31971 .71248 m .31572 .75074 L .28818 .74774 L p .707 .577 .707 r
F P
0 g
s
.28818 .74774 m .29218 .70948 L .31971 .71248 L p .707 .577 .707 r
F P
0 g
s
.29685 .61994 m .29314 .67717 L .262 .67442 L p .707 .577 .707 r
F P
0 g
s
.262 .67442 m .26571 .61719 L .29685 .61994 L p .707 .577 .707 r
F P
0 g
s
.31467 .77425 m .31245 .79335 L .2849 .79052 L p .707 .577 .707 r
F P
0 g
s
.2849 .79052 m .28712 .77142 L .31467 .77425 L p .707 .577 .707 r
F P
0 g
s
.19642 .73824 m .20041 .69998 L .22946 .70291 L p .707 .577 .707 r
F P
0 g
s
.22946 .70291 m .22547 .74117 L .19642 .73824 L p .707 .577 .707 r
F P
0 g
s
.23024 .67272 m .23395 .61549 L .26571 .61719 L p .707 .577 .707 r
F P
0 g
s
.72975 .6457 m .73346 .58847 L .70232 .58572 L p .707 .577 .707 r
F P
0 g
s
.73346 .58847 m .72975 .6457 L .76151 .6474 L p .707 .577 .707 r
F P
0 g
s
.76151 .6474 m .76521 .59017 L .73346 .58847 L p .707 .577 .707 r
F P
0 g
s
.26571 .61719 m .262 .67442 L .23024 .67272 L p .707 .577 .707 r
F P
0 g
s
.76521 .59017 m .76151 .6474 L .79076 .64787 L p .707 .577 .707 r
F P
0 g
s
.79076 .64787 m .79447 .59064 L .76521 .59017 L p .707 .577 .707 r
F P
0 g
s
.22447 .76421 m .22225 .78331 L .19328 .77965 L p .707 .577 .707 r
F P
0 g
s
.19328 .77965 m .1955 .76055 L .22447 .76421 L p .707 .577 .707 r
F P
0 g
s
.34831 .77693 m .38197 .26011 L .40483 .25735 L p .707 .577 .707 r
F P
0 g
s
.38197 .26011 m .34831 .77693 L .33857 .7811 L p .707 .577 .707 r
F P
0 g
s
.70232 .58572 m .69861 .64295 L .72975 .6457 L p .707 .577 .707 r
F P
0 g
s
.69861 .64295 m .70232 .58572 L .67483 .58218 L p .707 .577 .707 r
F P
0 g
s
.29218 .70948 m .28818 .74774 L .25709 .74444 L p .707 .577 .707 r
F P
0 g
s
.25709 .74444 m .26108 .70619 L .29218 .70948 L p .707 .577 .707 r
F P
0 g
s
.22547 .74117 m .22946 .70291 L .26108 .70619 L p .707 .577 .707 r
F P
0 g
s
.26108 .70619 m .25709 .74444 L .22547 .74117 L p .707 .577 .707 r
F P
0 g
s
.67483 .58218 m .67112 .63941 L .69861 .64295 L p .707 .577 .707 r
F P
0 g
s
.28712 .77142 m .2849 .79052 L .25382 .78706 L p .707 .577 .707 r
F P
0 g
s
.72663 .70116 m .73062 .6629 L .69952 .6596 L p .707 .577 .707 r
F P
0 g
s
.73062 .6629 m .72663 .70116 L .75825 .70443 L p .707 .577 .707 r
F P
0 g
s
.75825 .70443 m .76224 .66617 L .73062 .6629 L p .707 .577 .707 r
F P
0 g
s
.25382 .78706 m .25604 .76796 L .28712 .77142 L p .707 .577 .707 r
F P
0 g
s
.69952 .6596 m .69553 .69786 L .72663 .70116 L p .707 .577 .707 r
F P
0 g
s
.79447 .59064 m .79076 .64787 L .81466 .64707 L p .707 .577 .707 r
F P
0 g
s
.81466 .64707 m .81836 .58984 L .79447 .59064 L p .707 .577 .707 r
F P
0 g
s
.25604 .76796 m .25382 .78706 L .22225 .78331 L p .707 .577 .707 r
F P
0 g
s
.22225 .78331 m .22447 .76421 L .25604 .76796 L p .707 .577 .707 r
F P
0 g
s
.76224 .66617 m .75825 .70443 L .7873 .70736 L p .707 .577 .707 r
F P
0 g
s
.7873 .70736 m .79129 .6691 L .76224 .66617 L p .707 .577 .707 r
F P
0 g
s
.69519 .72413 m .69297 .74323 L .72406 .74669 L p .707 .577 .707 r
F P
0 g
s
.72406 .74669 m .72627 .72759 L .69519 .72413 L p .707 .577 .707 r
F P
0 g
s
.72627 .72759 m .72406 .74669 L .75562 .75043 L p .707 .577 .707 r
F P
0 g
s
.69553 .69786 m .69952 .6596 L .67199 .65661 L p .707 .577 .707 r
F P
0 g
s
.75562 .75043 m .75784 .73133 L .72627 .72759 L p .707 .577 .707 r
F P
0 g
s
.67199 .65661 m .668 .69486 L .69553 .69786 L p .707 .577 .707 r
F P
0 g
s
.67112 .63941 m .67483 .58218 L .65369 .5782 L p .707 .577 .707 r
F P
0 g
s
.75784 .73133 m .75562 .75043 L .78459 .7541 L p .707 .577 .707 r
F P
0 g
s
.78459 .7541 m .78681 .735 L .75784 .73133 L p .707 .577 .707 r
F P
0 g
s
.66764 .7213 m .66543 .7404 L .69297 .74323 L p .707 .577 .707 r
F P
0 g
s
.69297 .74323 m .69519 .72413 L .66764 .7213 L p .707 .577 .707 r
F P
0 g
s
.65369 .5782 m .64999 .63543 L .67112 .63941 L p .707 .577 .707 r
F P
0 g
s
.79129 .6691 m .7873 .70736 L .81093 .70966 L p .707 .577 .707 r
F P
0 g
s
.81093 .70966 m .81492 .6714 L .79129 .6691 L p .707 .577 .707 r
F P
0 g
s
.6373 .27386 m .60364 .79068 L .5738 .78508 L p .707 .577 .707 r
F P
0 g
s
.5738 .78508 m .60746 .26826 L .6373 .27386 L p .707 .577 .707 r
F P
0 g
s
.668 .69486 m .67199 .65661 L .65072 .6542 L p .707 .577 .707 r
F P
0 g
s
.78681 .735 m .78459 .7541 L .80812 .75732 L p .707 .577 .707 r
F P
0 g
s
.65072 .6542 m .64673 .69246 L .668 .69486 L p .707 .577 .707 r
F P
0 g
s
.80812 .75732 m .81034 .73822 L .78681 .735 L p .707 .577 .707 r
F P
0 g
s
.81836 .58984 m .81466 .64707 L .83085 .64509 L p .707 .577 .707 r
F P
0 g
s
.83085 .64509 m .83456 .58786 L .81836 .58984 L p .707 .577 .707 r
F P
0 g
s
.64632 .71936 m .6441 .73846 L .66543 .7404 L p .707 .577 .707 r
F P
0 g
s
.66543 .7404 m .66764 .7213 L .64632 .71936 L p .707 .577 .707 r
F P
0 g
s
.40483 .25735 m .37117 .77417 L .34831 .77693 L p .707 .577 .707 r
F P
0 g
s
.37117 .77417 m .40483 .25735 L .43856 .25626 L p .707 .577 .707 r
F P
0 g
s
.64999 .63543 m .65369 .5782 L .64097 .57416 L p .707 .577 .707 r
F P
0 g
s
.81492 .6714 m .81093 .70966 L .82683 .71111 L p .707 .577 .707 r
F P
0 g
s
.82683 .71111 m .83082 .67285 L .81492 .6714 L p .707 .577 .707 r
F P
0 g
s
.64097 .57416 m .63727 .6314 L .64999 .63543 L p .707 .577 .707 r
F P
0 g
s
.81034 .73822 m .80812 .75732 L .82391 .75979 L p .707 .577 .707 r
F P
0 g
s
.82391 .75979 m .82613 .74069 L .81034 .73822 L p .707 .577 .707 r
F P
0 g
s
.64673 .69246 m .65072 .6542 L .63779 .65263 L p .707 .577 .707 r
F P
0 g
s
.63779 .65263 m .6338 .69089 L .64673 .69246 L p .707 .577 .707 r
F P
0 g
s
.60746 .26826 m .5738 .78508 L .535 .78009 L p .707 .577 .707 r
F P
0 g
s
.535 .78009 m .56866 .26327 L .60746 .26826 L p .707 .577 .707 r
F P
0 g
s
.83456 .58786 m .83085 .64509 L .83775 .6421 L p .707 .577 .707 r
F P
0 g
s
.83775 .6421 m .84146 .58487 L .83456 .58786 L p .707 .577 .707 r
F P
0 g
s
.63331 .71852 m .6311 .73762 L .6441 .73846 L p .707 .577 .707 r
F P
0 g
s
.6441 .73846 m .64632 .71936 L .63331 .71852 L p .707 .577 .707 r
F P
0 g
s
.4049 .77308 m .43856 .25626 L .47986 .25696 L p .707 .577 .707 r
F P
0 g
s
.43856 .25626 m .4049 .77308 L .37117 .77417 L p .707 .577 .707 r
F P
0 g
s
.63727 .6314 m .64097 .57416 L .63792 .57048 L p .707 .577 .707 r
F P
0 g
s
.83082 .67285 m .82683 .71111 L .83345 .71156 L p .707 .577 .707 r
F P
0 g
s
.83345 .71156 m .83744 .6733 L .83082 .67285 L p .707 .577 .707 r
F P
0 g
s
.63792 .57048 m .63421 .62771 L .63727 .6314 L p .707 .577 .707 r
F P
0 g
s
.82613 .74069 m .82391 .75979 L .83041 .76127 L p .707 .577 .707 r
F P
0 g
s
.83041 .76127 m .83263 .74217 L .82613 .74069 L p .707 .577 .707 r
F P
0 g
s
.56866 .26327 m .535 .78009 L .49103 .77619 L p .707 .577 .707 r
F P
0 g
s
.49103 .77619 m .52469 .25938 L .56866 .26327 L p .707 .577 .707 r
F P
0 g
s
.6338 .69089 m .63779 .65263 L .63447 .65204 L p .707 .577 .707 r
F P
0 g
s
.63447 .65204 m .63048 .69029 L .6338 .69089 L p .707 .577 .707 r
F P
0 g
s
.4462 .77378 m .47986 .25696 L .52469 .25938 L p .707 .577 .707 r
F P
0 g
s
.47986 .25696 m .4462 .77378 L .4049 .77308 L p .707 .577 .707 r
F P
0 g
s
.62989 .71886 m .62768 .73796 L .6311 .73762 L p .707 .577 .707 r
F P
0 g
s
.6311 .73762 m .63331 .71852 L .62989 .71886 L p .707 .577 .707 r
F P
0 g
s
.52469 .25938 m .49103 .77619 L .4462 .77378 L p .707 .577 .707 r
F P
0 g
s
.84146 .58487 m .83775 .6421 L .8347 .63842 L p .707 .577 .707 r
F P
0 g
s
.8347 .63842 m .83841 .58118 L .84146 .58487 L p .707 .577 .707 r
F P
0 g
s
.63421 .62771 m .63792 .57048 L .64482 .56749 L p .707 .577 .707 r
F P
0 g
s
.83744 .6733 m .83345 .71156 L .83013 .71096 L p .707 .577 .707 r
F P
0 g
s
.83013 .71096 m .83412 .67271 L .83744 .6733 L p .707 .577 .707 r
F P
0 g
s
.64482 .56749 m .64112 .62472 L .63421 .62771 L p .707 .577 .707 r
F P
0 g
s
.83263 .74217 m .83041 .76127 L .82699 .7616 L p .707 .577 .707 r
F P
0 g
s
.82699 .7616 m .82921 .7425 L .83263 .74217 L p .707 .577 .707 r
F P
0 g
s
.63048 .69029 m .63447 .65204 L .64109 .65249 L p .707 .577 .707 r
F P
0 g
s
.64109 .65249 m .6371 .69074 L .63048 .69029 L p .707 .577 .707 r
F P
0 g
s
.6364 .72033 m .63418 .73943 L .62768 .73796 L p .707 .577 .707 r
F P
0 g
s
.62768 .73796 m .62989 .71886 L .6364 .72033 L p .707 .577 .707 r
F P
0 g
s
.83841 .58118 m .8347 .63842 L .82198 .63438 L p .707 .577 .707 r
F P
0 g
s
.82198 .63438 m .82569 .57715 L .83841 .58118 L p .707 .577 .707 r
F P
0 g
s
.38674 .60889 m .39045 .55165 L .35931 .5489 L p .707 .577 .707 r
F P
0 g
s
.39045 .55165 m .38674 .60889 L .4185 .61058 L p .707 .577 .707 r
F P
0 g
s
.4185 .61058 m .4222 .55335 L .39045 .55165 L p .707 .577 .707 r
F P
0 g
s
.4222 .55335 m .4185 .61058 L .44775 .61105 L p .707 .577 .707 r
F P
0 g
s
.44775 .61105 m .45146 .55382 L .4222 .55335 L p .707 .577 .707 r
F P
0 g
s
.64112 .62472 m .64482 .56749 L .66102 .56551 L p .707 .577 .707 r
F P
0 g
s
.35931 .5489 m .3556 .60613 L .38674 .60889 L p .707 .577 .707 r
F P
0 g
s
.3556 .60613 m .35931 .5489 L .33182 .54536 L p .707 .577 .707 r
F P
0 g
s
.83412 .67271 m .83013 .71096 L .8172 .70939 L p .707 .577 .707 r
F P
0 g
s
.8172 .70939 m .82119 .67113 L .83412 .67271 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66102 .56551 m .65731 .62274 L .64112 .62472 L p .707 .577 .707 r
F P
0 g
s
.33182 .54536 m .32811 .60259 L .3556 .60613 L p .707 .577 .707 r
F P
0 g
s
.38362 .66434 m .38761 .62608 L .35651 .62279 L p .707 .577 .707 r
F P
0 g
s
.38761 .62608 m .38362 .66434 L .41524 .66761 L p .707 .577 .707 r
F P
0 g
s
.41524 .66761 m .41923 .62936 L .38761 .62608 L p .707 .577 .707 r
F P
0 g
s
.35651 .62279 m .35252 .66104 L .38362 .66434 L p .707 .577 .707 r
F P
0 g
s
.82921 .7425 m .82699 .7616 L .81399 .76076 L p .707 .577 .707 r
F P
0 g
s
.45146 .55382 m .44775 .61105 L .47165 .61026 L p .707 .577 .707 r
F P
0 g
s
.47165 .61026 m .47535 .55303 L .45146 .55382 L p .707 .577 .707 r
F P
0 g
s
.81399 .76076 m .8162 .74166 L .82921 .7425 L p .707 .577 .707 r
F P
0 g
s
.41923 .62936 m .41524 .66761 L .44429 .67055 L p .707 .577 .707 r
F P
0 g
s
.44429 .67055 m .44828 .63229 L .41923 .62936 L p .707 .577 .707 r
F P
0 g
s
.35218 .68732 m .34997 .70641 L .38105 .70987 L p .707 .577 .707 r
F P
0 g
s
.38105 .70987 m .38326 .69077 L .35218 .68732 L p .707 .577 .707 r
F P
0 g
s
.38326 .69077 m .38105 .70987 L .41261 .71362 L p .707 .577 .707 r
F P
0 g
s
.6371 .69074 m .64109 .65249 L .65699 .65393 L p .707 .577 .707 r
F P
0 g
s
.35252 .66104 m .35651 .62279 L .32898 .61979 L p .707 .577 .707 r
F P
0 g
s
.65699 .65393 m .653 .69219 L .6371 .69074 L p .707 .577 .707 r
F P
0 g
s
.41261 .71362 m .41483 .69452 L .38326 .69077 L p .707 .577 .707 r
F P
0 g
s
.32898 .61979 m .32499 .65805 L .35252 .66104 L p .707 .577 .707 r
F P
0 g
s
.32811 .60259 m .33182 .54536 L .31068 .54138 L p .707 .577 .707 r
F P
0 g
s
.41483 .69452 m .41261 .71362 L .44158 .71728 L p .707 .577 .707 r
F P
0 g
s
.44158 .71728 m .4438 .69818 L .41483 .69452 L p .707 .577 .707 r
F P
0 g
s
.82569 .57715 m .82198 .63438 L .80084 .6304 L p .707 .577 .707 r
F P
0 g
s
.80084 .6304 m .80455 .57317 L .82569 .57715 L p .707 .577 .707 r
F P
0 g
s
.65219 .7228 m .64997 .7419 L .63418 .73943 L p .707 .577 .707 r
F P
0 g
s
.63418 .73943 m .6364 .72033 L .65219 .7228 L p .707 .577 .707 r
F P
0 g
s
.32463 .68448 m .32242 .70358 L .34997 .70641 L p .707 .577 .707 r
F P
0 g
s
.34997 .70641 m .35218 .68732 L .32463 .68448 L p .707 .577 .707 r
F P
0 g
s
.31068 .54138 m .30698 .59861 L .32811 .60259 L p .707 .577 .707 r
F P
0 g
s
.44828 .63229 m .44429 .67055 L .46792 .67285 L p .707 .577 .707 r
F P
0 g
s
.46792 .67285 m .47191 .63459 L .44828 .63229 L p .707 .577 .707 r
F P
0 g
s
.65731 .62274 m .66102 .56551 L .68491 .56471 L p .707 .577 .707 r
F P
0 g
s
.32499 .65805 m .32898 .61979 L .30771 .61739 L p .707 .577 .707 r
F P
0 g
s
.4438 .69818 m .44158 .71728 L .46511 .72051 L p .707 .577 .707 r
F P
0 g
s
.30771 .61739 m .30372 .65564 L .32499 .65805 L p .707 .577 .707 r
F P
0 g
s
.46511 .72051 m .46733 .70141 L .4438 .69818 L p .707 .577 .707 r
F P
0 g
s
.47535 .55303 m .47165 .61026 L .48784 .60827 L p .707 .577 .707 r
F P
0 g
s
.48784 .60827 m .49155 .55104 L .47535 .55303 L p .707 .577 .707 r
F P
0 g
s
.82119 .67113 m .8172 .70939 L .79593 .70699 L p .707 .577 .707 r
F P
0 g
s
.79593 .70699 m .79992 .66873 L .82119 .67113 L p .707 .577 .707 r
F P
0 g
s
.68491 .56471 m .6812 .62194 L .65731 .62274 L p .707 .577 .707 r
F P
0 g
s
.30331 .68255 m .30109 .70165 L .32242 .70358 L p .707 .577 .707 r
F P
0 g
s
.32242 .70358 m .32463 .68448 L .30331 .68255 L p .707 .577 .707 r
F P
0 g
s
.8162 .74166 m .81399 .76076 L .79266 .75883 L p .707 .577 .707 r
F P
0 g
s
.79266 .75883 m .79488 .73973 L .8162 .74166 L p .707 .577 .707 r
F P
0 g
s
.30698 .59861 m .31068 .54138 L .29796 .53735 L p .707 .577 .707 r
F P
0 g
s
.653 .69219 m .65699 .65393 L .68062 .65623 L p .707 .577 .707 r
F P
0 g
s
.68062 .65623 m .67663 .69449 L .653 .69219 L p .707 .577 .707 r
F P
0 g
s
.80455 .57317 m .80084 .6304 L .77336 .62686 L p .707 .577 .707 r
F P
0 g
s
.77336 .62686 m .77706 .56963 L .80455 .57317 L p .707 .577 .707 r
F P
0 g
s
.47191 .63459 m .46792 .67285 L .48382 .67429 L p .707 .577 .707 r
F P
0 g
s
.48382 .67429 m .48781 .63603 L .47191 .63459 L p .707 .577 .707 r
F P
0 g
s
.29796 .53735 m .29426 .59458 L .30698 .59861 L p .707 .577 .707 r
F P
0 g
s
.67572 .72602 m .6735 .74512 L .64997 .7419 L p .707 .577 .707 r
F P
0 g
s
.64997 .7419 m .65219 .7228 L .67572 .72602 L p .707 .577 .707 r
F P
0 g
s
.6812 .62194 m .68491 .56471 L .71417 .56518 L p .707 .577 .707 r
F P
0 g
s
.46733 .70141 m .46511 .72051 L .4809 .72298 L p .707 .577 .707 r
F P
0 g
s
.4809 .72298 m .48312 .70388 L .46733 .70141 L p .707 .577 .707 r
F P
0 g
s
.30372 .65564 m .30771 .61739 L .29478 .61581 L p .707 .577 .707 r
F P
0 g
s
.29478 .61581 m .29079 .65407 L .30372 .65564 L p .707 .577 .707 r
F P
0 g
s
.71417 .56518 m .71046 .62241 L .6812 .62194 L p .707 .577 .707 r
F P
0 g
s
.79992 .66873 m .79593 .70699 L .7684 .70399 L p .707 .577 .707 r
F P
0 g
s
.7684 .70399 m .77239 .66573 L .79992 .66873 L p .707 .577 .707 r
F P
0 g
s
.77706 .56963 m .77336 .62686 L .74221 .62411 L p .707 .577 .707 r
F P
0 g
s
.74221 .62411 m .74592 .56688 L .77706 .56963 L p .707 .577 .707 r
F P
0 g
s
.49155 .55104 m .48784 .60827 L .49474 .60529 L p .707 .577 .707 r
F P
0 g
s
.49474 .60529 m .49845 .54806 L .49155 .55104 L p .707 .577 .707 r
F P
0 g
s
.2903 .68171 m .28808 .70081 L .30109 .70165 L p .707 .577 .707 r
F P
0 g
s
.30109 .70165 m .30331 .68255 L .2903 .68171 L p .707 .577 .707 r
F P
0 g
s
.71046 .62241 m .71417 .56518 L .74592 .56688 L p .707 .577 .707 r
F P
0 g
s
.67663 .69449 m .68062 .65623 L .70967 .65916 L p .707 .577 .707 r
F P
0 g
s
.79488 .73973 m .79266 .75883 L .76511 .75599 L p .707 .577 .707 r
F P
0 g
s
.70967 .65916 m .70568 .69742 L .67663 .69449 L p .707 .577 .707 r
F P
0 g
s
.76511 .75599 m .76733 .73689 L .79488 .73973 L p .707 .577 .707 r
F P
0 g
s
.74592 .56688 m .74221 .62411 L .71046 .62241 L p .707 .577 .707 r
F P
0 g
s
.70468 .72969 m .70246 .74879 L .6735 .74512 L p .707 .577 .707 r
F P
0 g
s
.6735 .74512 m .67572 .72602 L .70468 .72969 L p .707 .577 .707 r
F P
0 g
s
.29426 .59458 m .29796 .53735 L .29491 .53366 L p .707 .577 .707 r
F P
0 g
s
.77239 .66573 m .7684 .70399 L .7373 .70069 L p .707 .577 .707 r
F P
0 g
s
.7373 .70069 m .74129 .66244 L .77239 .66573 L p .707 .577 .707 r
F P
0 g
s
.48781 .63603 m .48382 .67429 L .49044 .67474 L p .707 .577 .707 r
F P
0 g
s
.49044 .67474 m .49443 .63648 L .48781 .63603 L p .707 .577 .707 r
F P
0 g
s
.29491 .53366 m .2912 .59089 L .29426 .59458 L p .707 .577 .707 r
F P
0 g
s
.70568 .69742 m .70967 .65916 L .74129 .66244 L p .707 .577 .707 r
F P
0 g
s
.74129 .66244 m .7373 .70069 L .70568 .69742 L p .707 .577 .707 r
F P
0 g
s
.76733 .73689 m .76511 .75599 L .73403 .75253 L p .707 .577 .707 r
F P
0 g
s
.48312 .70388 m .4809 .72298 L .4874 .72445 L p .707 .577 .707 r
F P
0 g
s
.73403 .75253 m .73625 .73343 L .76733 .73689 L p .707 .577 .707 r
F P
0 g
s
.4874 .72445 m .48962 .70535 L .48312 .70388 L p .707 .577 .707 r
F P
0 g
s
.73625 .73343 m .73403 .75253 L .70246 .74879 L p .707 .577 .707 r
F P
0 g
s
.70246 .74879 m .70468 .72969 L .73625 .73343 L p .707 .577 .707 r
F P
0 g
s
.29079 .65407 m .29478 .61581 L .29146 .61522 L p .707 .577 .707 r
F P
0 g
s
.29146 .61522 m .28747 .65348 L .29079 .65407 L p .707 .577 .707 r
F P
0 g
s
.28688 .68204 m .28466 .70114 L .28808 .70081 L p .707 .577 .707 r
F P
0 g
s
.28808 .70081 m .2903 .68171 L .28688 .68204 L p .707 .577 .707 r
F P
0 g
s
.49845 .54806 m .49474 .60529 L .49169 .6016 L p .707 .577 .707 r
F P
0 g
s
.49169 .6016 m .4954 .54437 L .49845 .54806 L p .707 .577 .707 r
F P
0 g
s
.2912 .59089 m .29491 .53366 L .30181 .53068 L p .707 .577 .707 r
F P
0 g
s
.49443 .63648 m .49044 .67474 L .48712 .67415 L p .707 .577 .707 r
F P
0 g
s
.48712 .67415 m .49111 .63589 L .49443 .63648 L p .707 .577 .707 r
F P
0 g
s
.30181 .53068 m .29811 .58791 L .2912 .59089 L p .707 .577 .707 r
F P
0 g
s
.48962 .70535 m .4874 .72445 L .48398 .72478 L p .707 .577 .707 r
F P
0 g
s
.48398 .72478 m .4862 .70568 L .48962 .70535 L p .707 .577 .707 r
F P
0 g
s
.28747 .65348 m .29146 .61522 L .29808 .61567 L p .707 .577 .707 r
F P
0 g
s
.29808 .61567 m .29409 .65393 L .28747 .65348 L p .707 .577 .707 r
F P
0 g
s
.29339 .68351 m .29117 .70261 L .28466 .70114 L p .707 .577 .707 r
F P
0 g
s
.28466 .70114 m .28688 .68204 L .29339 .68351 L p .707 .577 .707 r
F P
0 g
s
.4954 .54437 m .49169 .6016 L .47897 .59757 L p .707 .577 .707 r
F P
0 g
s
.47897 .59757 m .48268 .54034 L .4954 .54437 L p .707 .577 .707 r
F P
0 g
s
.29811 .58791 m .30181 .53068 L .31801 .52869 L p .707 .577 .707 r
F P
0 g
s
.49111 .63589 m .48712 .67415 L .47419 .67257 L p .707 .577 .707 r
F P
0 g
s
.47419 .67257 m .47818 .63432 L .49111 .63589 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31801 .52869 m .3143 .58592 L .29811 .58791 L p .707 .577 .707 r
F P
0 g
s
.4862 .70568 m .48398 .72478 L .47098 .72394 L p .707 .577 .707 r
F P
0 g
s
.47098 .72394 m .47319 .70484 L .4862 .70568 L p .707 .577 .707 r
F P
0 g
s
.29409 .65393 m .29808 .61567 L .31398 .61712 L p .707 .577 .707 r
F P
0 g
s
.31398 .61712 m .30999 .65537 L .29409 .65393 L p .707 .577 .707 r
F P
0 g
s
.48268 .54034 m .47897 .59757 L .45783 .59359 L p .707 .577 .707 r
F P
0 g
s
.45783 .59359 m .46154 .53636 L .48268 .54034 L p .707 .577 .707 r
F P
0 g
s
.30918 .68598 m .30696 .70508 L .29117 .70261 L p .707 .577 .707 r
F P
0 g
s
.29117 .70261 m .29339 .68351 L .30918 .68598 L p .707 .577 .707 r
F P
0 g
s
.3143 .58592 m .31801 .52869 L .3419 .52789 L p .707 .577 .707 r
F P
0 g
s
.47818 .63432 m .47419 .67257 L .45292 .67017 L p .707 .577 .707 r
F P
0 g
s
.45292 .67017 m .45691 .63191 L .47818 .63432 L p .707 .577 .707 r
F P
0 g
s
.3419 .52789 m .33819 .58513 L .3143 .58592 L p .707 .577 .707 r
F P
0 g
s
.47319 .70484 m .47098 .72394 L .44965 .72201 L p .707 .577 .707 r
F P
0 g
s
.44965 .72201 m .45187 .70291 L .47319 .70484 L p .707 .577 .707 r
F P
0 g
s
.30999 .65537 m .31398 .61712 L .33761 .61942 L p .707 .577 .707 r
F P
0 g
s
.33761 .61942 m .33362 .65767 L .30999 .65537 L p .707 .577 .707 r
F P
0 g
s
.46154 .53636 m .45783 .59359 L .43035 .59005 L p .707 .577 .707 r
F P
0 g
s
.43035 .59005 m .43405 .53282 L .46154 .53636 L p .707 .577 .707 r
F P
0 g
s
.33271 .68921 m .33049 .70831 L .30696 .70508 L p .707 .577 .707 r
F P
0 g
s
.30696 .70508 m .30918 .68598 L .33271 .68921 L p .707 .577 .707 r
F P
0 g
s
.33819 .58513 m .3419 .52789 L .37116 .52837 L p .707 .577 .707 r
F P
0 g
s
.37116 .52837 m .36745 .5856 L .33819 .58513 L p .707 .577 .707 r
F P
0 g
s
.45691 .63191 m .45292 .67017 L .42539 .66717 L p .707 .577 .707 r
F P
0 g
s
.42539 .66717 m .42938 .62892 L .45691 .63191 L p .707 .577 .707 r
F P
0 g
s
.43405 .53282 m .43035 .59005 L .3992 .58729 L p .707 .577 .707 r
F P
0 g
s
.3992 .58729 m .40291 .53006 L .43405 .53282 L p .707 .577 .707 r
F P
0 g
s
.36745 .5856 m .37116 .52837 L .40291 .53006 L p .707 .577 .707 r
F P
0 g
s
.33362 .65767 m .33761 .61942 L .36666 .62235 L p .707 .577 .707 r
F P
0 g
s
.45187 .70291 m .44965 .72201 L .4221 .71918 L p .707 .577 .707 r
F P
0 g
s
.36666 .62235 m .36267 .6606 L .33362 .65767 L p .707 .577 .707 r
F P
0 g
s
.4221 .71918 m .42432 .70008 L .45187 .70291 L p .707 .577 .707 r
F P
0 g
s
.40291 .53006 m .3992 .58729 L .36745 .5856 L p .707 .577 .707 r
F P
0 g
s
.36167 .69287 m .35945 .71197 L .33049 .70831 L p .707 .577 .707 r
F P
0 g
s
.33049 .70831 m .33271 .68921 L .36167 .69287 L p .707 .577 .707 r
F P
0 g
s
.42938 .62892 m .42539 .66717 L .39429 .66388 L p .707 .577 .707 r
F P
0 g
s
.39429 .66388 m .39828 .62562 L .42938 .62892 L p .707 .577 .707 r
F P
0 g
s
.36267 .6606 m .36666 .62235 L .39828 .62562 L p .707 .577 .707 r
F P
0 g
s
.39828 .62562 m .39429 .66388 L .36267 .6606 L p .707 .577 .707 r
F P
0 g
s
.42432 .70008 m .4221 .71918 L .39102 .71572 L p .707 .577 .707 r
F P
0 g
s
.39102 .71572 m .39324 .69662 L .42432 .70008 L p .707 .577 .707 r
F P
0 g
s
.39324 .69662 m .39102 .71572 L .35945 .71197 L p .707 .577 .707 r
F P
0 g
s
.35945 .71197 m .36167 .69287 L .39324 .69662 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00N7oo2P00Vgoo001`Ool80004FUH00`00FUIJEP03FUHI0022
Ool006]oo`D000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00=J
EPT007Uoo`00JGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01P00Lgoo001YOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1`00K7oo001YOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH00UYF1P00IWoo001YOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YF000006Aoo`00JGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001ROol0
06Uoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1POol006Uoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001QOol006Uoo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001QOol006Qoo`800003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF009JEP80065oo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP80065oo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00aJEP80065oo`00J7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP80065oo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001oogoo05moo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001oogoo05moo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEWoo065oo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EWoo065oo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo065o
o`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo065oo`00J7oo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo065oo`00J7oo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo065oo`00J7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP80069oo`00J7oo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80069oo`00J7oo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP80069oo`00Igoo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00HWoo
001WOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUIoo`1ROol006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1R
Ool006Moo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1ROol006Mo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1ROol006Moo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001S
Ool006Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001J
EUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Ioo`80009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00IWoo0P0000=JEP00FUH01EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001UOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001TOol006Eoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Ao
o`00IGoo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001U
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001EOolS000;FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=o
o`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPL000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005=oo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Ioo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo5@00CWoo
001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF2@00AGoo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF10000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPP003eoo`00DWoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00P005YFFUH005YF001JEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL003Ioo`00DWoo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01@00<Goo001BOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000^Ool0059oo`03
001JEP00009JEQH000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`03001JEP0000<000EJEP03
001JEUYF00EJEP03001JEUYF00EJEQ4000AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000]Ool0059oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000=JEP03001JEUYF0080009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`D000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@00003FUH005YF00]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005Yoo`L000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo001QOol8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP0400000eYF001J
EP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH2000]Ool006=oo`04001JEUYF0002FUHP0005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1`00FUIJEUYF001JEP0002eoo`00=goo1`0057oo00<007ooOol03Woo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02ioo`T000=JEP04001JEUYFFUHB0002Ool:0007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo0`00
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
FUH00eYF00<005YFFUH04@002EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00@005YFFUIJEPL0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009J
EPX000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH0000000L000IJEQ8000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH6000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH70003FUH01000FUIJEUYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP080002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002
FUH2000^Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006Ool70004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF0P003Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Woo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P005Woo2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000;goo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P007goo5P00<goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF2`00Ggoo000[Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH90003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF00@005YFFUIJEPL005Qoo`00:goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF4`0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP04001J
EUYFFUH9001?Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP04001JEUYFFUH;0004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH00UYF2@00AWoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP04FUH:0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF2000?Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH90003FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEUYFFUH<000bOol002]oo`03001JEP00024000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EP0000T00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<002ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP@000=JEPL000=JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH30003
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH0
000A0002FUH00`00FUIJEP03FUH00`00FUIJEP050002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0;goo000_Ool40003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH01P00FUH005YF001JEQ<000=JEP03001JEUYF00D00003FUH005YF00YJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008002moo`00<goo1`0015YF00<005YF
FUH01EYF00<005YFFUH01UYF0P000UYF00D005YFFUIJEP0000IJEP03001JEP0000@000=JEP/00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP/000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002]oo`D000Yooa4000AJEP800003FUH005YF
00=JEP03001JEUYF00AJEP03001JEUYF00=JEPL00004FUH005YFFUH;0006FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH:0004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;goo000[Ool00`00FUH00002FUH5000FOol600000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH900000eYF001JEP03FUH7000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH<0004FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;goo000[Ool00`00FUH00004FUH0
0`00FUIJEP0A000:Ool50002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUHC0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30007FUH00`00FUIJEP03FUH01000FUIJEUYF0P000Woo300015YF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8002moo`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001Woo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH02P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0`001eYF00<005YFFUH00eYF00@005YFFUIJEP8000]oo`/000AJEP03001JEUYF00=JEP03
001JEUYF0080031oo`00:goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF20000goo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000MJEP03001JEUYF00=JEP04001JEUYFFUH2000COol?00000eYF0000000`Ool0
02]oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH60004Ool:0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0`001eYF
00<005YFFUH00eYF00@005YFFUIJEP80025oo`@0031oo`00:Woo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
1@000UYF00<005YFFUH00eYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEPH000AJEP03001J
EUYF00=JEP04001JEUYFFUH20009Ool30019Ool002Yoo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF00=JEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000;0003
FUH01000FUIJEUYF0P0027oo1@00B7oo000ZOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH<0002FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF4`001Woo1@00B7oo000Z
Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH400000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH40004FUH01000FUIJEUYF1`0000=JEP00FUH00eYF2`00B7oo000ZOol00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF001JEP03FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000AJEP00FUIJEPP004Aoo`00:Woo
1@000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00
FUH01000@7oo000]Ool?0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHB
000eOol0039ooa<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP/000=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH=000bOol0049oo`/000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Uoo`L000AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
031oo`00Bgoo2P0015YF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEPL000]oo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000`Ool005=oo`T000=JEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF001JEP02FUH<0008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00<7oo000ZOol?000ROol60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUH00003000=Ool80004FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00<7oo000ZOol01000FUH005YF1P0000=JEP00FUH00UYF20007goo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00IJEP03001JEUYF00=JEP04
001JEUYFFUH2000EOol70003FUH01000FUIJEUYF0P00<7oo000ZOol00`00FUH00003FUH01000FUIJ
EUYF1`000UYF00@005YFFUIJEPT001Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P0077oo2@00<7oo000YOol00`00
FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH00eYF2@003Goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF00=JEP05001J
EUYF001JEP1FOol002Uoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEPT00003FUH005YF00=JEPL000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH30007FUH00`00FUIJEP04FUH00`00FUIJEP02001FOol002Uoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00L0009J
EP03001JEUYF00=JEP03001JEUYF00=JEPX000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EWoo000ZOol90003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF30000UYF30002UYF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00<goo200015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10005eYF00<005YFFUH0
2UYF00<005YFFUH025YF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8005Ioo`00>goo2@0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00eYF0`0065YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YF
FUIJEP8005Ioo`00A7oo200015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P005eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF00001@0015YF00<005YFFUH0
0UYF3P000eYF00<005YFFUH00P00Egoo001<Ool80004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000EFUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60003FUH2
0002Ool?00000eYF0000001GOol005Aoo`L000=JEP03001JEUYF009JEP03001oo`0000D000mJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
0003FUH00000011oo`@005Moo`00Fgoo2@001goo1`0025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0`00Jgoo001bOol60002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
001[Ool007Qoo`P000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00AJEPD006Uoo`00P7oo6@001UYF00<005YFFUH00UYF6000HGoo002;Ool40002FUH00`00FUIJEP04
FUH<0006FUH00`00FUIJEP06FUH01000FUIJEUYF3@00FGoo002?Ool60003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP09001GOol009Eoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
001GOol009eoo`T000=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF
FUH2001GOol00:Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001GOol0
0:ioo`P000AJEP03001JEUYF00=JEP04001JEUYFFUH2001GOol00;Iooa0005Moo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60079 .7646 m .59709 .71234 L .56594 .71125 L p .707 .577 .707 r
F P
0 g
s
.59709 .71234 m .60079 .7646 L .63255 .76146 L p .707 .577 .707 r
F P
0 g
s
.63255 .76146 m .62884 .7092 L .59709 .71234 L p .707 .577 .707 r
F P
0 g
s
.62884 .7092 m .63255 .76146 L .6618 .7544 L p .707 .577 .707 r
F P
0 g
s
.6618 .7544 m .6581 .70214 L .62884 .7092 L p .707 .577 .707 r
F P
0 g
s
.56965 .76351 m .56594 .71125 L .53846 .70605 L p .707 .577 .707 r
F P
0 g
s
.56594 .71125 m .56965 .76351 L .60079 .7646 L p .707 .577 .707 r
F P
0 g
s
.6581 .70214 m .6618 .7544 L .6857 .74411 L p .707 .577 .707 r
F P
0 g
s
.6857 .74411 m .68199 .69185 L .6581 .70214 L p .707 .577 .707 r
F P
0 g
s
.54216 .7583 m .53846 .70605 L .51732 .69723 L p .707 .577 .707 r
F P
0 g
s
.53846 .70605 m .54216 .7583 L .56965 .76351 L p .707 .577 .707 r
F P
0 g
s
.68199 .69185 m .6857 .74411 L .70189 .73159 L p .707 .577 .707 r
F P
0 g
s
.70189 .73159 m .69818 .67934 L .68199 .69185 L p .707 .577 .707 r
F P
0 g
s
.60571 .83459 m .60171 .80169 L .57062 .80109 L p .707 .577 .707 r
F P
0 g
s
.60171 .80169 m .60571 .83459 L .63733 .83005 L p .707 .577 .707 r
F P
0 g
s
.63733 .83005 m .63334 .79715 L .60171 .80169 L p .707 .577 .707 r
F P
0 g
s
.63334 .79715 m .63733 .83005 L .66638 .82081 L p .707 .577 .707 r
F P
0 g
s
.66638 .82081 m .66238 .78791 L .63334 .79715 L p .707 .577 .707 r
F P
0 g
s
.57461 .83399 m .57062 .80109 L .54308 .7954 L p .707 .577 .707 r
F P
0 g
s
.57062 .80109 m .57461 .83399 L .60571 .83459 L p .707 .577 .707 r
F P
0 g
s
.52103 .74949 m .51732 .69723 L .5046 .68566 L p .707 .577 .707 r
F P
0 g
s
.51732 .69723 m .52103 .74949 L .54216 .7583 L p .707 .577 .707 r
F P
0 g
s
.66238 .78791 m .66638 .82081 L .69001 .80778 L p .707 .577 .707 r
F P
0 g
s
.69001 .80778 m .68601 .77488 L .66238 .78791 L p .707 .577 .707 r
F P
0 g
s
.69818 .67934 m .70189 .73159 L .7088 .71809 L p .707 .577 .707 r
F P
0 g
s
.7088 .71809 m .70509 .66583 L .69818 .67934 L p .707 .577 .707 r
F P
0 g
s
.54708 .8283 m .54308 .7954 L .52181 .78518 L p .707 .577 .707 r
F P
0 g
s
.54308 .7954 m .54708 .8283 L .57461 .83399 L p .707 .577 .707 r
F P
0 g
s
.68601 .77488 m .69001 .80778 L .70591 .79222 L p .707 .577 .707 r
F P
0 g
s
.70591 .79222 m .70192 .75932 L .68601 .77488 L p .707 .577 .707 r
F P
0 g
s
.50897 .82857 m .47531 .35691 L .43134 .35539 L p .707 .577 .707 r
F P
0 g
s
.5046 .68566 m .50831 .73792 L .52103 .74949 L p .707 .577 .707 r
F P
0 g
s
.50831 .73792 m .5046 .68566 L .50155 .67248 L p .707 .577 .707 r
F P
0 g
s
.52181 .78518 m .52581 .81808 L .54708 .8283 L p .707 .577 .707 r
F P
0 g
s
.52581 .81808 m .52181 .78518 L .50889 .77144 L p .707 .577 .707 r
F P
0 g
s
.50155 .67248 m .50525 .72474 L .50831 .73792 L p .707 .577 .707 r
F P
0 g
s
.50889 .77144 m .51288 .80434 L .52581 .81808 L p .707 .577 .707 r
F P
0 g
s
.50525 .72474 m .50155 .67248 L .50845 .65897 L p .707 .577 .707 r
F P
0 g
s
.51288 .80434 m .50889 .77144 L .50557 .75551 L p .707 .577 .707 r
F P
0 g
s
.50845 .65897 m .51216 .71123 L .50525 .72474 L p .707 .577 .707 r
F P
0 g
s
.50557 .75551 m .50956 .78841 L .51288 .80434 L p .707 .577 .707 r
F P
0 g
s
.51216 .71123 m .50845 .65897 L .52464 .64646 L p .707 .577 .707 r
F P
0 g
s
.50956 .78841 m .50557 .75551 L .51219 .73896 L p .707 .577 .707 r
F P
0 g
s
.51601 .85076 m .5138 .83464 L .51038 .81793 L p .707 .577 .707 r
F P
0 g
s
.51038 .81793 m .51259 .83405 L .51601 .85076 L p .707 .577 .707 r
F P
0 g
s
.52464 .64646 m .52835 .69872 L .51216 .71123 L p .707 .577 .707 r
F P
0 g
s
.52835 .69872 m .52464 .64646 L .54854 .63617 L p .707 .577 .707 r
F P
0 g
s
.51219 .73896 m .51618 .77186 L .50956 .78841 L p .707 .577 .707 r
F P
0 g
s
.51618 .77186 m .51219 .73896 L .52809 .7234 L p .707 .577 .707 r
F P
0 g
s
.51259 .83405 m .51038 .81793 L .51688 .8005 L p .707 .577 .707 r
F P
0 g
s
.54854 .63617 m .55224 .68843 L .52835 .69872 L p .707 .577 .707 r
F P
0 g
s
.51688 .8005 m .5191 .81663 L .51259 .83405 L p .707 .577 .707 r
F P
0 g
s
.52809 .7234 m .53208 .7563 L .51618 .77186 L p .707 .577 .707 r
F P
0 g
s
.53208 .7563 m .52809 .7234 L .55172 .71037 L p .707 .577 .707 r
F P
0 g
s
.5191 .81663 m .51688 .8005 L .53267 .78408 L p .707 .577 .707 r
F P
0 g
s
.53267 .78408 m .53489 .8002 L .5191 .81663 L p .707 .577 .707 r
F P
0 g
s
.55172 .71037 m .55571 .74327 L .53208 .7563 L p .707 .577 .707 r
F P
0 g
s
.53489 .8002 m .53267 .78408 L .5562 .77025 L p .707 .577 .707 r
F P
0 g
s
.5562 .77025 m .55842 .78638 L .53489 .8002 L p .707 .577 .707 r
F P
0 g
s
.47531 .35691 m .50897 .82857 L .5538 .82412 L p .707 .577 .707 r
F P
0 g
s
.5538 .82412 m .52014 .35246 L .47531 .35691 L p .707 .577 .707 r
F P
0 g
s
.55224 .68843 m .54854 .63617 L .57779 .62911 L p .707 .577 .707 r
F P
0 g
s
.57779 .62911 m .5815 .68137 L .55224 .68843 L p .707 .577 .707 r
F P
0 g
s
.55571 .74327 m .55172 .71037 L .58077 .70113 L p .707 .577 .707 r
F P
0 g
s
.58077 .70113 m .58476 .73403 L .55571 .74327 L p .707 .577 .707 r
F P
0 g
s
.55842 .78638 m .5562 .77025 L .58516 .76039 L p .707 .577 .707 r
F P
0 g
s
.58738 .77651 m .58516 .76039 L .61673 .75545 L p .707 .577 .707 r
F P
0 g
s
.58516 .76039 m .58738 .77651 L .55842 .78638 L p .707 .577 .707 r
F P
0 g
s
.61673 .75545 m .61895 .77157 L .58738 .77651 L p .707 .577 .707 r
F P
0 g
s
.52014 .35246 m .5538 .82412 L .5951 .81412 L p .707 .577 .707 r
F P
0 g
s
.5815 .68137 m .57779 .62911 L .60955 .62597 L p .707 .577 .707 r
F P
0 g
s
.60955 .62597 m .61325 .67823 L .5815 .68137 L p .707 .577 .707 r
F P
0 g
s
.58476 .73403 m .58077 .70113 L .61239 .69659 L p .707 .577 .707 r
F P
0 g
s
.61239 .69659 m .61638 .72949 L .58476 .73403 L p .707 .577 .707 r
F P
0 g
s
.5951 .81412 m .56144 .34246 L .52014 .35246 L p .707 .577 .707 r
F P
0 g
s
.60897 .88205 m .60676 .86592 L .57568 .86546 L p .707 .577 .707 r
F P
0 g
s
.60676 .86592 m .60897 .88205 L .64054 .8771 L p .707 .577 .707 r
F P
0 g
s
.64054 .8771 m .63832 .86098 L .60676 .86592 L p .707 .577 .707 r
F P
0 g
s
.63832 .86098 m .64054 .8771 L .66951 .86724 L p .707 .577 .707 r
F P
0 g
s
.66951 .86724 m .66729 .85112 L .63832 .86098 L p .707 .577 .707 r
F P
0 g
s
.465 .82704 m .43134 .35539 L .39254 .34803 L p .707 .577 .707 r
F P
0 g
s
.43134 .35539 m .465 .82704 L .50897 .82857 L p .707 .577 .707 r
F P
0 g
s
.57789 .88158 m .57568 .86546 L .54813 .85963 L p .707 .577 .707 r
F P
0 g
s
.57568 .86546 m .57789 .88158 L .60897 .88205 L p .707 .577 .707 r
F P
0 g
s
.66729 .85112 m .66951 .86724 L .69304 .85342 L p .707 .577 .707 r
F P
0 g
s
.69304 .85342 m .69082 .83729 L .66729 .85112 L p .707 .577 .707 r
F P
0 g
s
.64349 .69719 m .64748 .73009 L .61638 .72949 L p .707 .577 .707 r
F P
0 g
s
.61638 .72949 m .61239 .69659 L .64349 .69719 L p .707 .577 .707 r
F P
0 g
s
.64781 .75591 m .65003 .77204 L .61895 .77157 L p .707 .577 .707 r
F P
0 g
s
.61895 .77157 m .61673 .75545 L .64781 .75591 L p .707 .577 .707 r
F P
0 g
s
.56144 .34246 m .5951 .81412 L .62883 .79956 L p .707 .577 .707 r
F P
0 g
s
.64069 .62706 m .6444 .67931 L .61325 .67823 L p .707 .577 .707 r
F P
0 g
s
.61325 .67823 m .60955 .62597 L .64069 .62706 L p .707 .577 .707 r
F P
0 g
s
.62883 .79956 m .59517 .3279 L .56144 .34246 L p .707 .577 .707 r
F P
0 g
s
.70509 .66583 m .7088 .71809 L .70574 .7049 L p .707 .577 .707 r
F P
0 g
s
.70574 .7049 m .70203 .65265 L .70509 .66583 L p .707 .577 .707 r
F P
0 g
s
.54813 .85963 m .55034 .87575 L .57789 .88158 L p .707 .577 .707 r
F P
0 g
s
.70192 .75932 m .70591 .79222 L .71252 .77567 L p .707 .577 .707 r
F P
0 g
s
.71252 .77567 m .70853 .74277 L .70192 .75932 L p .707 .577 .707 r
F P
0 g
s
.55034 .87575 m .54813 .85963 L .5268 .84901 L p .707 .577 .707 r
F P
0 g
s
.69082 .83729 m .69304 .85342 L .70883 .83699 L p .707 .577 .707 r
F P
0 g
s
.70883 .83699 m .70661 .82087 L .69082 .83729 L p .707 .577 .707 r
F P
0 g
s
.4262 .81968 m .39254 .34803 L .36269 .33556 L p .707 .577 .707 r
F P
0 g
s
.39254 .34803 m .4262 .81968 L .465 .82704 L p .707 .577 .707 r
F P
0 g
s
.5268 .84901 m .52902 .86513 L .55034 .87575 L p .707 .577 .707 r
F P
0 g
s
.67536 .76174 m .67758 .77786 L .65003 .77204 L p .707 .577 .707 r
F P
0 g
s
.65003 .77204 m .64781 .75591 L .67536 .76174 L p .707 .577 .707 r
F P
0 g
s
.59517 .3279 m .62883 .79956 L .65168 .78186 L p .707 .577 .707 r
F P
0 g
s
.67102 .70288 m .67501 .73578 L .64748 .73009 L p .707 .577 .707 r
F P
0 g
s
.64748 .73009 m .64349 .69719 L .67102 .70288 L p .707 .577 .707 r
F P
0 g
s
.65168 .78186 m .61802 .3102 L .59517 .3279 L p .707 .577 .707 r
F P
0 g
s
.52902 .86513 m .5268 .84901 L .5138 .83464 L p .707 .577 .707 r
F P
0 g
s
.70203 .65265 m .70574 .7049 L .69302 .69334 L p .707 .577 .707 r
F P
0 g
s
.69302 .69334 m .68931 .64108 L .70203 .65265 L p .707 .577 .707 r
F P
0 g
s
.70853 .74277 m .71252 .77567 L .70921 .75974 L p .707 .577 .707 r
F P
0 g
s
.70921 .75974 m .70521 .72684 L .70853 .74277 L p .707 .577 .707 r
F P
0 g
s
.70661 .82087 m .70883 .83699 L .71533 .81957 L p .707 .577 .707 r
F P
0 g
s
.71533 .81957 m .71311 .80344 L .70661 .82087 L p .707 .577 .707 r
F P
0 g
s
.5138 .83464 m .51601 .85076 L .52902 .86513 L p .707 .577 .707 r
F P
0 g
s
.39635 .80722 m .36269 .33556 L .34474 .3192 L p .707 .577 .707 r
F P
0 g
s
.36269 .33556 m .39635 .80722 L .4262 .81968 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25779 .72778 m .25408 .67553 L .22293 .67444 L p .707 .577 .707 r
F P
0 g
s
.25408 .67553 m .25779 .72778 L .28954 .72464 L p .707 .577 .707 r
F P
0 g
s
.28954 .72464 m .28583 .67238 L .25408 .67553 L p .707 .577 .707 r
F P
0 g
s
.28583 .67238 m .28954 .72464 L .3188 .71758 L p .707 .577 .707 r
F P
0 g
s
.3188 .71758 m .31509 .66532 L .28583 .67238 L p .707 .577 .707 r
F P
0 g
s
.22664 .7267 m .22293 .67444 L .19545 .66923 L p .707 .577 .707 r
F P
0 g
s
.22293 .67444 m .22664 .7267 L .25779 .72778 L p .707 .577 .707 r
F P
0 g
s
.68931 .64108 m .69302 .69334 L .67188 .68452 L p .707 .577 .707 r
F P
0 g
s
.67188 .68452 m .66818 .63226 L .68931 .64108 L p .707 .577 .707 r
F P
0 g
s
.70521 .72684 m .70921 .75974 L .69628 .746 L p .707 .577 .707 r
F P
0 g
s
.69628 .746 m .69229 .7131 L .70521 .72684 L p .707 .577 .707 r
F P
0 g
s
.71311 .80344 m .71533 .81957 L .71191 .80285 L p .707 .577 .707 r
F P
0 g
s
.71191 .80285 m .70969 .78673 L .71311 .80344 L p .707 .577 .707 r
F P
0 g
s
.66818 .63226 m .67188 .68452 L .6444 .67931 L p .707 .577 .707 r
F P
0 g
s
.6444 .67931 m .64069 .62706 L .66818 .63226 L p .707 .577 .707 r
F P
0 g
s
.61802 .3102 m .65168 .78186 L .66143 .76275 L p .707 .577 .707 r
F P
0 g
s
.66143 .76275 m .62777 .29109 L .61802 .3102 L p .707 .577 .707 r
F P
0 g
s
.31509 .66532 m .3188 .71758 L .34269 .70729 L p .707 .577 .707 r
F P
0 g
s
.34269 .70729 m .33898 .65503 L .31509 .66532 L p .707 .577 .707 r
F P
0 g
s
.19916 .72149 m .19545 .66923 L .17431 .66041 L p .707 .577 .707 r
F P
0 g
s
.19545 .66923 m .19916 .72149 L .22664 .7267 L p .707 .577 .707 r
F P
0 g
s
.33898 .65503 m .34269 .70729 L .35888 .69478 L p .707 .577 .707 r
F P
0 g
s
.35888 .69478 m .35517 .64252 L .33898 .65503 L p .707 .577 .707 r
F P
0 g
s
.3784 .79086 m .34474 .3192 L .34042 .30056 L p .707 .577 .707 r
F P
0 g
s
.34474 .3192 m .3784 .79086 L .39635 .80722 L p .707 .577 .707 r
F P
0 g
s
.69229 .7131 m .69628 .746 L .67501 .73578 L p .707 .577 .707 r
F P
0 g
s
.67501 .73578 m .67102 .70288 L .69229 .7131 L p .707 .577 .707 r
F P
0 g
s
.2627 .79777 m .25871 .76487 L .22761 .76427 L p .707 .577 .707 r
F P
0 g
s
.25871 .76487 m .2627 .79777 L .29432 .79323 L p .707 .577 .707 r
F P
0 g
s
.29432 .79323 m .29033 .76033 L .25871 .76487 L p .707 .577 .707 r
F P
0 g
s
.70969 .78673 m .71191 .80285 L .6989 .78848 L p .707 .577 .707 r
F P
0 g
s
.6989 .78848 m .69669 .77236 L .70969 .78673 L p .707 .577 .707 r
F P
0 g
s
.29033 .76033 m .29432 .79323 L .32337 .784 L p .707 .577 .707 r
F P
0 g
s
.32337 .784 m .31937 .75109 L .29033 .76033 L p .707 .577 .707 r
F P
0 g
s
.2316 .79717 m .22761 .76427 L .20008 .75858 L p .707 .577 .707 r
F P
0 g
s
.22761 .76427 m .2316 .79717 L .2627 .79777 L p .707 .577 .707 r
F P
0 g
s
.17802 .71267 m .17431 .66041 L .16159 .64885 L p .707 .577 .707 r
F P
0 g
s
.17431 .66041 m .17802 .71267 L .19916 .72149 L p .707 .577 .707 r
F P
0 g
s
.31937 .75109 m .32337 .784 L .347 .77096 L p .707 .577 .707 r
F P
0 g
s
.347 .77096 m .34301 .73806 L .31937 .75109 L p .707 .577 .707 r
F P
0 g
s
.66143 .76275 m .65711 .7441 L p .65191 .66368 L .707 .577 .707 r
F P
0 g
s
.65191 .66368 m .64662 .58213 L .65035 .62754 L .707 .577 .707 r
F
.65191 .66368 m .65035 .62754 L .66143 .76275 L F
.64192 .48933 m .66143 .76275 L p .64662 .58213 L F P
0 g
s
.62345 .27244 m .62777 .29109 L p .64662 .58213 L .707 .577 .707 r
F P
0 g
s
.65711 .7441 m .64924 .63378 L p .64662 .58213 L .707 .577 .707 r
F P
0 g
s
.64924 .63378 m .62345 .27244 L p .64662 .58213 L .707 .577 .707 r
F P
0 g
s
.62345 .27244 m .65711 .7441 L .63916 .72774 L p .707 .577 .707 r
F P
0 g
s
.64609 .66792 m .65008 .70082 L .65279 .7037 L p .707 .577 .707 r
F P
0 g
s
.65279 .7037 m .66301 .71457 L p .65176 .68356 L .707 .577 .707 r
F P
0 g
s
.65176 .68356 m .64609 .66792 L .65279 .7037 L .707 .577 .707 r
F
.66623 .7524 m .66401 .73628 L .65459 .72587 L p F P
0 g
s
.65459 .72587 m .651 .72191 L p .65474 .7294 L .707 .577 .707 r
F P
0 g
s
.66623 .7524 m .65459 .72587 L .65474 .7294 L .707 .577 .707 r
F
.66301 .71457 m .65902 .68167 L .65125 .67341 L p F P
0 g
s
.65125 .67341 m .64609 .66792 L p .65176 .68356 L .707 .577 .707 r
F P
0 g
s
.66301 .71457 m .65125 .67341 L .65176 .68356 L .707 .577 .707 r
F
.62777 .29109 m .64192 .48933 L p .64662 .58213 L F P
0 g
s
.35517 .64252 m .35888 .69478 L .36579 .68127 L p .707 .577 .707 r
F P
0 g
s
.36579 .68127 m .36208 .62901 L .35517 .64252 L p .707 .577 .707 r
F P
0 g
s
.20407 .79148 m .20008 .75858 L .17881 .74836 L p .707 .577 .707 r
F P
0 g
s
.20008 .75858 m .20407 .79148 L .2316 .79717 L p .707 .577 .707 r
F P
0 g
s
.69669 .77236 m .6989 .78848 L .67758 .77786 L p .707 .577 .707 r
F P
0 g
s
.67758 .77786 m .67536 .76174 L .69669 .77236 L p .707 .577 .707 r
F P
0 g
s
.34301 .73806 m .347 .77096 L .3629 .75541 L p .707 .577 .707 r
F P
0 g
s
.3629 .75541 m .35891 .72251 L .34301 .73806 L p .707 .577 .707 r
F P
0 g
s
.26597 .84523 m .26375 .82911 L .23267 .82864 L p .707 .577 .707 r
F P
0 g
s
.26375 .82911 m .26597 .84523 L .29753 .84029 L p .707 .577 .707 r
F P
0 g
s
.29753 .84029 m .29532 .82417 L .26375 .82911 L p .707 .577 .707 r
F P
0 g
s
.29532 .82417 m .29753 .84029 L .3265 .83042 L p .707 .577 .707 r
F P
0 g
s
.3265 .83042 m .32428 .8143 L .29532 .82417 L p .707 .577 .707 r
F P
0 g
s
.16159 .64885 m .1653 .70111 L .17802 .71267 L p .707 .577 .707 r
F P
0 g
s
.1653 .70111 m .16159 .64885 L .15854 .63567 L p .707 .577 .707 r
F P
0 g
s
.34042 .30056 m .37408 .77222 L .3784 .79086 L p .707 .577 .707 r
F P
0 g
s
.37408 .77222 m .34042 .30056 L .35017 .28145 L p .707 .577 .707 r
F P
0 g
s
.23489 .84476 m .23267 .82864 L .20512 .82282 L p .707 .577 .707 r
F P
0 g
s
.23267 .82864 m .23489 .84476 L .26597 .84523 L p .707 .577 .707 r
F P
0 g
s
.32428 .8143 m .3265 .83042 L .35003 .8166 L p .707 .577 .707 r
F P
0 g
s
.35003 .8166 m .34781 .80048 L .32428 .8143 L p .707 .577 .707 r
F P
0 g
s
.17881 .74836 m .1828 .78127 L .20407 .79148 L p .707 .577 .707 r
F P
0 g
s
.1828 .78127 m .17881 .74836 L .16588 .73462 L p .707 .577 .707 r
F P
0 g
s
.36208 .62901 m .36579 .68127 L .36273 .66809 L p .707 .577 .707 r
F P
0 g
s
.36273 .66809 m .35902 .61583 L .36208 .62901 L p .707 .577 .707 r
F P
0 g
s
.20512 .82282 m .20734 .83894 L .23489 .84476 L p .707 .577 .707 r
F P
0 g
s
.35891 .72251 m .3629 .75541 L .36952 .73886 L p .707 .577 .707 r
F P
0 g
s
.36952 .73886 m .36552 .70596 L .35891 .72251 L p .707 .577 .707 r
F P
0 g
s
.20734 .83894 m .20512 .82282 L .18379 .8122 L p .707 .577 .707 r
F P
0 g
s
.63916 .72774 m .6055 .25609 L .62345 .27244 L p .707 .577 .707 r
F P
0 g
s
.34781 .80048 m .35003 .8166 L .36582 .80017 L p .707 .577 .707 r
F P
0 g
s
.36582 .80017 m .3636 .78405 L .34781 .80048 L p .707 .577 .707 r
F P
0 g
s
.15854 .63567 m .16224 .68792 L .1653 .70111 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16588 .73462 m .16987 .76752 L .1828 .78127 L p .707 .577 .707 r
F P
0 g
s
.18379 .8122 m .18601 .82832 L .20734 .83894 L p .707 .577 .707 r
F P
0 g
s
.16224 .68792 m .15854 .63567 L .16544 .62216 L p .707 .577 .707 r
F P
0 g
s
.16987 .76752 m .16588 .73462 L .16256 .71869 L p .707 .577 .707 r
F P
0 g
s
.18601 .82832 m .18379 .8122 L .17079 .79783 L p .707 .577 .707 r
F P
0 g
s
.35902 .61583 m .36273 .66809 L .35001 .65652 L p .707 .577 .707 r
F P
0 g
s
.35001 .65652 m .34631 .60427 L .35902 .61583 L p .707 .577 .707 r
F P
0 g
s
.36552 .70596 m .36952 .73886 L .3662 .72293 L p .707 .577 .707 r
F P
0 g
s
.3662 .72293 m .36221 .69003 L .36552 .70596 L p .707 .577 .707 r
F P
0 g
s
.38383 .75311 m .35017 .28145 L .37302 .26375 L p .707 .577 .707 r
F P
0 g
s
.35017 .28145 m .38383 .75311 L .37408 .77222 L p .707 .577 .707 r
F P
0 g
s
.3636 .78405 m .36582 .80017 L .37232 .78275 L p .707 .577 .707 r
F P
0 g
s
.37232 .78275 m .3701 .76663 L .3636 .78405 L p .707 .577 .707 r
F P
0 g
s
.17079 .79783 m .173 .81395 L .18601 .82832 L p .707 .577 .707 r
F P
0 g
s
.16544 .62216 m .16915 .67441 L .16224 .68792 L p .707 .577 .707 r
F P
0 g
s
.16256 .71869 m .16655 .75159 L .16987 .76752 L p .707 .577 .707 r
F P
0 g
s
.16915 .67441 m .16544 .62216 L .18163 .60965 L p .707 .577 .707 r
F P
0 g
s
.6055 .25609 m .63916 .72774 L .60931 .71528 L p .707 .577 .707 r
F P
0 g
s
.60931 .71528 m .57565 .24362 L .6055 .25609 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16655 .75159 m .16256 .71869 L .16918 .70214 L p .707 .577 .707 r
F P
0 g
s
.173 .81395 m .17079 .79783 L .16737 .78111 L p .707 .577 .707 r
F P
0 g
s
.34631 .60427 m .35001 .65652 L .32888 .6477 L p .707 .577 .707 r
F P
0 g
s
.32888 .6477 m .32517 .59545 L .34631 .60427 L p .707 .577 .707 r
F P
0 g
s
.36221 .69003 m .3662 .72293 L .35327 .70918 L p .707 .577 .707 r
F P
0 g
s
.35327 .70918 m .34928 .67628 L .36221 .69003 L p .707 .577 .707 r
F P
0 g
s
.3701 .76663 m .37232 .78275 L .3689 .76604 L p .707 .577 .707 r
F P
0 g
s
.3689 .76604 m .36668 .74991 L .3701 .76663 L p .707 .577 .707 r
F P
0 g
s
.16737 .78111 m .16958 .79723 L .173 .81395 L p .707 .577 .707 r
F P
0 g
s
.40668 .7354 m .38383 .75311 L p .37498 .35218 L .707 .577 .707 r
F P
0 g
s
.3835 .41057 m .40668 .7354 L p .37498 .35218 L .707 .577 .707 r
F P
0 g
s
.40668 .7354 m .37302 .26375 L .40675 .24919 L p .707 .577 .707 r
F P
0 g
s
.44041 .72084 m .40668 .7354 L p .40671 .58362 L .707 .577 .707 r
F P
0 g
s
.40671 .58362 m .42472 .63007 L .44041 .72084 L .707 .577 .707 r
F
.43254 .61052 m .43601 .65921 L p .40671 .52597 L F P
0 g
s
.43601 .65921 m .44041 .72084 L p .42472 .63007 L .707 .577 .707 r
F P
0 g
s
.40671 .52597 m .43601 .65921 L .42472 .63007 L .707 .577 .707 r
F
.44805 .23919 m .48171 .71085 L .44041 .72084 L p F P
0 g
s
.4637 .71769 m .46149 .70157 L .45349 .70429 L p .707 .577 .707 r
F P
0 g
s
.44041 .72084 m .40675 .24919 L .44805 .23919 L p .707 .577 .707 r
F P
0 g
s
.45349 .70429 m .43252 .71143 L p .45827 .7166 L .707 .577 .707 r
F P
0 g
s
.4637 .71769 m .45349 .70429 L .45827 .7166 L .707 .577 .707 r
F
.43252 .71143 m .43474 .72755 L .45928 .7192 L p F P
0 g
s
.45928 .7192 m .4637 .71769 L p .45827 .7166 L .707 .577 .707 r
F P
0 g
s
.45827 .7166 m .43252 .71143 L .45928 .7192 L .707 .577 .707 r
F
.40671 .58362 m .40671 .52597 L .42472 .63007 L F
.40675 .24919 m .43254 .61052 L p .40671 .52597 L F P
0 g
s
.42753 .65682 m .43152 .68972 L .4545 .68241 L p .707 .577 .707 r
F P
0 g
s
.4545 .68241 m .46057 .68048 L p .45204 .67438 L .707 .577 .707 r
F P
0 g
s
.45204 .67438 m .42753 .65682 L .4545 .68241 L .707 .577 .707 r
F
.39591 .66136 m .3999 .69426 L .42441 .69074 L p F P
0 g
s
.42441 .69074 m .43152 .68972 L p .42331 .68318 L .707 .577 .707 r
F P
0 g
s
.42331 .68318 m .39591 .66136 L .42441 .69074 L .707 .577 .707 r
F
.37302 .26375 m .3835 .41057 L p .37498 .35218 L F P
0 g
s
.18163 .60965 m .18534 .6619 L .16915 .67441 L p .707 .577 .707 r
F P
0 g
s
.18534 .6619 m .18163 .60965 L .20553 .59936 L p .707 .577 .707 r
F P
0 g
s
.16918 .70214 m .17317 .73504 L .16655 .75159 L p .707 .577 .707 r
F P
0 g
s
.17317 .73504 m .16918 .70214 L .18508 .68659 L p .707 .577 .707 r
F P
0 g
s
.57565 .24362 m .60931 .71528 L .57051 .70792 L p .707 .577 .707 r
F P
0 g
s
.57051 .70792 m .53685 .23626 L .57565 .24362 L p .707 .577 .707 r
F P
0 g
s
.32517 .59545 m .32888 .6477 L .30139 .6425 L p .707 .577 .707 r
F P
0 g
s
.30139 .6425 m .29768 .59024 L .32517 .59545 L p .707 .577 .707 r
F P
0 g
s
.16958 .79723 m .16737 .78111 L .17387 .76369 L p .707 .577 .707 r
F P
0 g
s
.34928 .67628 m .35327 .70918 L .332 .69897 L p .707 .577 .707 r
F P
0 g
s
.332 .69897 m .32801 .66607 L .34928 .67628 L p .707 .577 .707 r
F P
0 g
s
.36668 .74991 m .3689 .76604 L .35589 .75167 L p .707 .577 .707 r
F P
0 g
s
.35589 .75167 m .35368 .73554 L .36668 .74991 L p .707 .577 .707 r
F P
0 g
s
.20924 .65161 m .20553 .59936 L .23478 .5923 L p .707 .577 .707 r
F P
0 g
s
.20553 .59936 m .20924 .65161 L .18534 .6619 L p .707 .577 .707 r
F P
0 g
s
.17387 .76369 m .17609 .77981 L .16958 .79723 L p .707 .577 .707 r
F P
0 g
s
.29768 .59024 m .30139 .6425 L .27024 .64141 L p .707 .577 .707 r
F P
0 g
s
.27024 .64141 m .26654 .58915 L .29768 .59024 L p .707 .577 .707 r
F P
0 g
s
.18508 .68659 m .18907 .71949 L .17317 .73504 L p .707 .577 .707 r
F P
0 g
s
.23849 .64455 m .23478 .5923 L .26654 .58915 L p .707 .577 .707 r
F P
0 g
s
.23478 .5923 m .23849 .64455 L .20924 .65161 L p .707 .577 .707 r
F P
0 g
s
.53685 .23626 m .57051 .70792 L .52654 .70639 L p .707 .577 .707 r
F P
0 g
s
.52654 .70639 m .49288 .23474 L .53685 .23626 L p .707 .577 .707 r
F P
0 g
s
.18907 .71949 m .18508 .68659 L .20871 .67355 L p .707 .577 .707 r
F P
0 g
s
.26654 .58915 m .27024 .64141 L .23849 .64455 L p .707 .577 .707 r
F P
0 g
s
.32801 .66607 m .332 .69897 L .30447 .69328 L p .707 .577 .707 r
F P
0 g
s
.30447 .69328 m .30048 .66038 L .32801 .66607 L p .707 .577 .707 r
F P
0 g
s
.17609 .77981 m .17387 .76369 L .18966 .74726 L p .707 .577 .707 r
F P
0 g
s
.48171 .71085 m .46953 .54009 L p .49288 .23474 L .707 .577 .707 r
F P
0 g
s
.46953 .54009 m .4638 .45981 L p .47867 .34473 L .707 .577 .707 r
F P
0 g
s
.46953 .54009 m .47867 .34473 L .49288 .23474 L .707 .577 .707 r
F
.49288 .23474 m .52654 .70639 L .48171 .71085 L p F P
0 g
s
.4637 .71769 m .48723 .70386 L p .46197 .70161 L .707 .577 .707 r
F P
0 g
s
.46149 .70157 m .46185 .7042 L p .46197 .70161 L .707 .577 .707 r
F P
0 g
s
.46185 .7042 m .4637 .71769 L p .46197 .70161 L .707 .577 .707 r
F P
0 g
s
.46057 .68048 m .4842 .66745 L p .46001 .65005 L .707 .577 .707 r
F P
0 g
s
.45658 .64758 m .45956 .6722 L p .46001 .65005 L .707 .577 .707 r
F P
0 g
s
.45956 .6722 m .46057 .68048 L p .46001 .65005 L .707 .577 .707 r
F P
0 g
s
.4638 .45981 m .44805 .23919 L .46824 .23718 L p .707 .577 .707 r
F P
0 g
s
.46824 .23718 m .49288 .23474 L p .4638 .45981 L .707 .577 .707 r
F P
0 g
s
.35368 .73554 m .35589 .75167 L .33457 .74105 L p .707 .577 .707 r
F P
0 g
s
.33457 .74105 m .33235 .72493 L .35368 .73554 L p .707 .577 .707 r
F P
0 g
s
.738 .66765 m .73429 .61539 L .70315 .6143 L p .707 .577 .707 r
F P
0 g
s
.73429 .61539 m .738 .66765 L .76975 .6645 L p .707 .577 .707 r
F P
0 g
s
.76975 .6645 m .76605 .61225 L .73429 .61539 L p .707 .577 .707 r
F P
0 g
s
.76605 .61225 m .76975 .6645 L .79901 .65744 L p .707 .577 .707 r
F P
0 g
s
.79901 .65744 m .7953 .60519 L .76605 .61225 L p .707 .577 .707 r
F P
0 g
s
.18966 .74726 m .19188 .76338 L .17609 .77981 L p .707 .577 .707 r
F P
0 g
s
.2127 .70645 m .20871 .67355 L .23776 .66431 L p .707 .577 .707 r
F P
0 g
s
.20871 .67355 m .2127 .70645 L .18907 .71949 L p .707 .577 .707 r
F P
0 g
s
.70685 .66656 m .70315 .6143 L .67566 .6091 L p .707 .577 .707 r
F P
0 g
s
.70315 .6143 m .70685 .66656 L .738 .66765 L p .707 .577 .707 r
F P
0 g
s
.30048 .66038 m .30447 .69328 L .27337 .69267 L p .707 .577 .707 r
F P
0 g
s
.27337 .69267 m .26938 .65977 L .30048 .66038 L p .707 .577 .707 r
F P
0 g
s
.7953 .60519 m .79901 .65744 L .8229 .64715 L p .707 .577 .707 r
F P
0 g
s
.8229 .64715 m .8192 .5949 L .7953 .60519 L p .707 .577 .707 r
F P
0 g
s
.24175 .69721 m .23776 .66431 L .26938 .65977 L p .707 .577 .707 r
F P
0 g
s
.23776 .66431 m .24175 .69721 L .2127 .70645 L p .707 .577 .707 r
F P
0 g
s
.26938 .65977 m .27337 .69267 L .24175 .69721 L p .707 .577 .707 r
F P
0 g
s
.19188 .76338 m .18966 .74726 L .21319 .73344 L p .707 .577 .707 r
F P
0 g
s
.33235 .72493 m .33457 .74105 L .30702 .73522 L p .707 .577 .707 r
F P
0 g
s
.30702 .73522 m .3048 .7191 L .33235 .72493 L p .707 .577 .707 r
F P
0 g
s
.67937 .66135 m .67566 .6091 L .65452 .60028 L p .707 .577 .707 r
F P
0 g
s
.67566 .6091 m .67937 .66135 L .70685 .66656 L p .707 .577 .707 r
F P
0 g
s
.21319 .73344 m .21541 .74956 L .19188 .76338 L p .707 .577 .707 r
F P
0 g
s
.8192 .5949 m .8229 .64715 L .8391 .63464 L p .707 .577 .707 r
F P
0 g
s
.8391 .63464 m .83539 .58238 L .8192 .5949 L p .707 .577 .707 r
F P
0 g
s
.21541 .74956 m .21319 .73344 L .24215 .72357 L p .707 .577 .707 r
F P
0 g
s
.74291 .73108 m .73892 .69818 L .70782 .69757 L p .707 .577 .707 r
F P
0 g
s
.73892 .69818 m .74291 .73108 L .77453 .72654 L p .707 .577 .707 r
F P
0 g
s
.77453 .72654 m .77054 .69364 L .73892 .69818 L p .707 .577 .707 r
F P
0 g
s
.3048 .7191 m .30702 .73522 L .27594 .73476 L p .707 .577 .707 r
F P
0 g
s
.27594 .73476 m .27372 .71863 L .3048 .7191 L p .707 .577 .707 r
F P
0 g
s
.77054 .69364 m .77453 .72654 L .80358 .7173 L p .707 .577 .707 r
F P
0 g
s
.80358 .7173 m .79959 .6844 L .77054 .69364 L p .707 .577 .707 r
F P
0 g
s
.24437 .7397 m .24215 .72357 L .27372 .71863 L p .707 .577 .707 r
F P
0 g
s
.24215 .72357 m .24437 .7397 L .21541 .74956 L p .707 .577 .707 r
F P
0 g
s
.71181 .73047 m .70782 .69757 L .68029 .69188 L p .707 .577 .707 r
F P
0 g
s
.70782 .69757 m .71181 .73047 L .74291 .73108 L p .707 .577 .707 r
F P
0 g
s
.27372 .71863 m .27594 .73476 L .24437 .7397 L p .707 .577 .707 r
F P
0 g
s
.65823 .65253 m .65452 .60028 L .64181 .58871 L p .707 .577 .707 r
F P
0 g
s
.65452 .60028 m .65823 .65253 L .67937 .66135 L p .707 .577 .707 r
F P
0 g
s
.79959 .6844 m .80358 .7173 L .82721 .70426 L p .707 .577 .707 r
F P
0 g
s
.82721 .70426 m .82322 .67136 L .79959 .6844 L p .707 .577 .707 r
F P
0 g
s
.83539 .58238 m .8391 .63464 L .846 .62113 L p .707 .577 .707 r
F P
0 g
s
.846 .62113 m .84229 .56888 L .83539 .58238 L p .707 .577 .707 r
F P
0 g
s
.68428 .72479 m .68029 .69188 L .65902 .68167 L p .707 .577 .707 r
F P
0 g
s
.68029 .69188 m .68428 .72479 L .71181 .73047 L p .707 .577 .707 r
F P
0 g
s
.82322 .67136 m .82721 .70426 L .84311 .68871 L p .707 .577 .707 r
F P
0 g
s
.84311 .68871 m .83912 .65581 L .82322 .67136 L p .707 .577 .707 r
F P
0 g
s
.74618 .76931 m .74396 .75319 L .71288 .75272 L p .707 .577 .707 r
F P
0 g
s
.74396 .75319 m .74618 .76931 L .77775 .76437 L p .707 .577 .707 r
F P
0 g
s
.77775 .76437 m .77553 .74825 L .74396 .75319 L p .707 .577 .707 r
F P
0 g
s
.77553 .74825 m .77775 .76437 L .80671 .7545 L p .707 .577 .707 r
F P
0 g
s
.80671 .7545 m .8045 .73838 L .77553 .74825 L p .707 .577 .707 r
F P
0 g
s
.64181 .58871 m .64551 .64097 L .65823 .65253 L p .707 .577 .707 r
F P
0 g
s
.7151 .76884 m .71288 .75272 L .68533 .74689 L p .707 .577 .707 r
F P
0 g
s
.71288 .75272 m .7151 .76884 L .74618 .76931 L p .707 .577 .707 r
F P
0 g
s
.64551 .64097 m .64181 .58871 L .63875 .57553 L p .707 .577 .707 r
F P
0 g
s
.8045 .73838 m .80671 .7545 L .83024 .74068 L p .707 .577 .707 r
F P
0 g
s
.83024 .74068 m .82803 .72456 L .8045 .73838 L p .707 .577 .707 r
F P
0 g
s
.65902 .68167 m .66301 .71457 L .68428 .72479 L p .707 .577 .707 r
F P
0 g
s
.68533 .74689 m .68755 .76302 L .7151 .76884 L p .707 .577 .707 r
F P
0 g
s
.84229 .56888 m .846 .62113 L .84295 .60795 L p .707 .577 .707 r
F P
0 g
s
.84295 .60795 m .83924 .55569 L .84229 .56888 L p .707 .577 .707 r
F P
0 g
s
.83912 .65581 m .84311 .68871 L .84973 .67216 L p .707 .577 .707 r
F P
0 g
s
.84973 .67216 m .84574 .63926 L .83912 .65581 L p .707 .577 .707 r
F P
0 g
s
.68755 .76302 m .68533 .74689 L .66401 .73628 L p .707 .577 .707 r
F P
0 g
s
.82803 .72456 m .83024 .74068 L .84603 .72425 L p .707 .577 .707 r
F P
0 g
s
.84603 .72425 m .84381 .70813 L .82803 .72456 L p .707 .577 .707 r
F P
0 g
s
.63875 .57553 m .64246 .62779 L .64551 .64097 L p .707 .577 .707 r
F P
0 g
s
.66401 .73628 m .66623 .7524 L .68755 .76302 L p .707 .577 .707 r
F P
0 g
s
.64246 .62779 m .63875 .57553 L .64566 .56202 L p .707 .577 .707 r
F P
0 g
s
.65008 .70082 m .64609 .66792 L .64277 .652 L p .707 .577 .707 r
F P
0 g
s
.84574 .63926 m .84973 .67216 L .84641 .65623 L p .707 .577 .707 r
F P
0 g
s
.84641 .65623 m .84242 .62333 L .84574 .63926 L p .707 .577 .707 r
F P
0 g
s
.84381 .70813 m .84603 .72425 L .85254 .70683 L p .707 .577 .707 r
F P
0 g
s
.85254 .70683 m .85032 .69071 L .84381 .70813 L p .707 .577 .707 r
F P
0 g
s
.83924 .55569 m .84295 .60795 L .83023 .59639 L p .707 .577 .707 r
F P
0 g
s
.83023 .59639 m .82652 .54413 L .83924 .55569 L p .707 .577 .707 r
F P
0 g
s
.651 .72191 m .65322 .73803 L .66623 .7524 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64277 .652 m .64677 .6849 L .65008 .70082 L p .707 .577 .707 r
F P
0 g
s
.64566 .56202 m .64936 .61428 L .64246 .62779 L p .707 .577 .707 r
F P
0 g
s
.64936 .61428 m .64566 .56202 L .66185 .54951 L p .707 .577 .707 r
F P
0 g
s
.39499 .63083 m .39128 .57857 L .36014 .57749 L p .707 .577 .707 r
F P
0 g
s
.39128 .57857 m .39499 .63083 L .42674 .62769 L p .707 .577 .707 r
F P
0 g
s
.42674 .62769 m .42304 .57543 L .39128 .57857 L p .707 .577 .707 r
F P
0 g
s
.64677 .6849 m .64277 .652 L .64939 .63544 L p .707 .577 .707 r
F P
0 g
s
.65322 .73803 m .651 .72191 L .64758 .70519 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42304 .57543 m .42674 .62769 L .456 .62063 L p .707 .577 .707 r
F P
0 g
s
.456 .62063 m .45229 .56837 L .42304 .57543 L p .707 .577 .707 r
F P
0 g
s
.85032 .69071 m .85254 .70683 L .84912 .69011 L p .707 .577 .707 r
F P
0 g
s
.84912 .69011 m .8469 .67399 L .85032 .69071 L p .707 .577 .707 r
F P
0 g
s
.36384 .62974 m .36014 .57749 L .33265 .57228 L p .707 .577 .707 r
F P
0 g
s
.36014 .57749 m .36384 .62974 L .39499 .63083 L p .707 .577 .707 r
F P
0 g
s
.82652 .54413 m .83023 .59639 L .80909 .58757 L p .707 .577 .707 r
F P
0 g
s
.80909 .58757 m .80538 .53531 L .82652 .54413 L p .707 .577 .707 r
F P
0 g
s
.84242 .62333 m .84641 .65623 L .83349 .64249 L p .707 .577 .707 r
F P
0 g
s
.83349 .64249 m .82949 .60959 L .84242 .62333 L p .707 .577 .707 r
F P
0 g
s
.64758 .70519 m .6498 .72131 L .65322 .73803 L p .707 .577 .707 r
F P
0 g
s
.45229 .56837 m .456 .62063 L .47989 .61034 L p .707 .577 .707 r
F P
0 g
s
.47989 .61034 m .47619 .55808 L .45229 .56837 L p .707 .577 .707 r
F P
0 g
s
.64939 .63544 m .65338 .66835 L .64677 .6849 L p .707 .577 .707 r
F P
0 g
s
.66185 .54951 m .66556 .60177 L .64936 .61428 L p .707 .577 .707 r
F P
0 g
s
.66556 .60177 m .66185 .54951 L .68574 .53922 L p .707 .577 .707 r
F P
0 g
s
.33636 .62454 m .33265 .57228 L .31151 .56346 L p .707 .577 .707 r
F P
0 g
s
.33265 .57228 m .33636 .62454 L .36384 .62974 L p .707 .577 .707 r
F P
0 g
s
.65338 .66835 m .64939 .63544 L .66529 .61989 L p .707 .577 .707 r
F P
0 g
s
.6498 .72131 m .64758 .70519 L .65408 .68777 L p .707 .577 .707 r
F P
0 g
s
.80538 .53531 m .80909 .58757 L .7816 .58236 L p .707 .577 .707 r
F P
0 g
s
.7816 .58236 m .7779 .5301 L .80538 .53531 L p .707 .577 .707 r
F P
0 g
s
.47619 .55808 m .47989 .61034 L .49609 .59783 L p .707 .577 .707 r
F P
0 g
s
.49609 .59783 m .49238 .54557 L .47619 .55808 L p .707 .577 .707 r
F P
0 g
s
.8469 .67399 m .84912 .69011 L .83611 .67574 L p .707 .577 .707 r
F P
0 g
s
.83611 .67574 m .83389 .65962 L .8469 .67399 L p .707 .577 .707 r
F P
0 g
s
.82949 .60959 m .83349 .64249 L .81221 .63227 L p .707 .577 .707 r
F P
0 g
s
.81221 .63227 m .80822 .59937 L .82949 .60959 L p .707 .577 .707 r
F P
0 g
s
.3999 .69426 m .39591 .66136 L .36481 .66076 L p .707 .577 .707 r
F P
0 g
s
.43152 .68972 m .42753 .65682 L .39591 .66136 L p .707 .577 .707 r
F P
0 g
s
.46057 .68048 m .45658 .64758 L .42753 .65682 L p .707 .577 .707 r
F P
0 g
s
.65408 .68777 m .6563 .70389 L .6498 .72131 L p .707 .577 .707 r
F P
0 g
s
.68945 .59148 m .68574 .53922 L .715 .53216 L p .707 .577 .707 r
F P
0 g
s
.68574 .53922 m .68945 .59148 L .66556 .60177 L p .707 .577 .707 r
F P
0 g
s
.3688 .69366 m .36481 .66076 L .33728 .65507 L p .707 .577 .707 r
F P
0 g
s
.36481 .66076 m .3688 .69366 L .3999 .69426 L p .707 .577 .707 r
F P
0 g
s
.31522 .61572 m .31151 .56346 L .2988 .5519 L p .707 .577 .707 r
F P
0 g
s
.31151 .56346 m .31522 .61572 L .33636 .62454 L p .707 .577 .707 r
F P
0 g
s
.7779 .5301 m .7816 .58236 L .75046 .58127 L p .707 .577 .707 r
F P
0 g
s
.75046 .58127 m .74675 .52902 L .7779 .5301 L p .707 .577 .707 r
F P
0 g
s
.4842 .66745 m .48021 .63455 L .45658 .64758 L p .707 .577 .707 r
F P
0 g
s
.66529 .61989 m .66928 .65279 L .65338 .66835 L p .707 .577 .707 r
F P
0 g
s
.66928 .65279 m .66529 .61989 L .68892 .60686 L p .707 .577 .707 r
F P
0 g
s
.7187 .58442 m .715 .53216 L .74675 .52902 L p .707 .577 .707 r
F P
0 g
s
.715 .53216 m .7187 .58442 L .68945 .59148 L p .707 .577 .707 r
F P
0 g
s
.74675 .52902 m .75046 .58127 L .7187 .58442 L p .707 .577 .707 r
F P
0 g
s
.6563 .70389 m .65408 .68777 L .66987 .67134 L p .707 .577 .707 r
F P
0 g
s
.80822 .59937 m .81221 .63227 L .78468 .62658 L p .707 .577 .707 r
F P
0 g
s
.78468 .62658 m .78069 .59368 L .80822 .59937 L p .707 .577 .707 r
F P
0 g
s
.49238 .54557 m .49609 .59783 L .50299 .58432 L p .707 .577 .707 r
F P
0 g
s
.50299 .58432 m .49928 .53206 L .49238 .54557 L p .707 .577 .707 r
F P
0 g
s
.34127 .68797 m .33728 .65507 L .31601 .64485 L p .707 .577 .707 r
F P
0 g
s
.33728 .65507 m .34127 .68797 L .3688 .69366 L p .707 .577 .707 r
F P
0 g
s
.83389 .65962 m .83611 .67574 L .81479 .66513 L p .707 .577 .707 r
F P
0 g
s
.81479 .66513 m .81257 .649 L .83389 .65962 L p .707 .577 .707 r
F P
0 g
s
.48021 .63455 m .4842 .66745 L .5001 .65189 L p .707 .577 .707 r
F P
0 g
s
.5001 .65189 m .49611 .61899 L .48021 .63455 L p .707 .577 .707 r
F P
0 g
s
.40317 .73249 m .40095 .71637 L .36987 .71591 L p .707 .577 .707 r
F P
0 g
s
.40095 .71637 m .40317 .73249 L .43474 .72755 L p .707 .577 .707 r
F P
0 g
s
.43474 .72755 m .43252 .71143 L .40095 .71637 L p .707 .577 .707 r
F P
0 g
s
.66987 .67134 m .67209 .68746 L .6563 .70389 L p .707 .577 .707 r
F P
0 g
s
.69292 .63976 m .68892 .60686 L .71797 .59762 L p .707 .577 .707 r
F P
0 g
s
.68892 .60686 m .69292 .63976 L .66928 .65279 L p .707 .577 .707 r
F P
0 g
s
.2988 .5519 m .3025 .60415 L .31522 .61572 L p .707 .577 .707 r
F P
0 g
s
.78069 .59368 m .78468 .62658 L .75358 .62598 L p .707 .577 .707 r
F P
0 g
s
.75358 .62598 m .74959 .59308 L .78069 .59368 L p .707 .577 .707 r
F P
0 g
s
.37209 .73203 m .36987 .71591 L .34232 .71008 L p .707 .577 .707 r
F P
0 g
s
.36987 .71591 m .37209 .73203 L .40317 .73249 L p .707 .577 .707 r
F P
0 g
s
.3025 .60415 m .2988 .5519 L .29574 .53871 L p .707 .577 .707 r
F P
0 g
s
.48723 .70386 m .48502 .68774 L .46149 .70157 L p .707 .577 .707 r
F P
0 g
s
.67209 .68746 m .66987 .67134 L .6934 .65752 L p .707 .577 .707 r
F P
0 g
s
.72196 .63052 m .71797 .59762 L .74959 .59308 L p .707 .577 .707 r
F P
0 g
s
.71797 .59762 m .72196 .63052 L .69292 .63976 L p .707 .577 .707 r
F P
0 g
s
.31601 .64485 m .32 .67775 L .34127 .68797 L p .707 .577 .707 r
F P
0 g
s
.74959 .59308 m .75358 .62598 L .72196 .63052 L p .707 .577 .707 r
F P
0 g
s
.32 .67775 m .31601 .64485 L .30308 .63111 L p .707 .577 .707 r
F P
0 g
s
.81257 .649 m .81479 .66513 L .78724 .6593 L p .707 .577 .707 r
F P
0 g
s
.78724 .6593 m .78502 .64318 L .81257 .649 L p .707 .577 .707 r
F P
0 g
s
.34232 .71008 m .34454 .7262 L .37209 .73203 L p .707 .577 .707 r
F P
0 g
s
.49928 .53206 m .50299 .58432 L .49994 .57114 L p .707 .577 .707 r
F P
0 g
s
.49994 .57114 m .49623 .51888 L .49928 .53206 L p .707 .577 .707 r
F P
0 g
s
.49611 .61899 m .5001 .65189 L .50672 .63534 L p .707 .577 .707 r
F P
0 g
s
.50672 .63534 m .50273 .60244 L .49611 .61899 L p .707 .577 .707 r
F P
0 g
s
.34454 .7262 m .34232 .71008 L .321 .69946 L p .707 .577 .707 r
F P
0 g
s
.6934 .65752 m .69562 .67364 L .67209 .68746 L p .707 .577 .707 r
F P
0 g
s
.48502 .68774 m .48723 .70386 L .50302 .68744 L p .707 .577 .707 r
F P
0 g
s
.50302 .68744 m .5008 .67132 L .48502 .68774 L p .707 .577 .707 r
F P
0 g
s
.69562 .67364 m .6934 .65752 L .72237 .64765 L p .707 .577 .707 r
F P
0 g
s
.78502 .64318 m .78724 .6593 L .75616 .65883 L p .707 .577 .707 r
F P
0 g
s
.75616 .65883 m .75394 .64271 L .78502 .64318 L p .707 .577 .707 r
F P
0 g
s
.29574 .53871 m .29945 .59097 L .3025 .60415 L p .707 .577 .707 r
F P
0 g
s
.321 .69946 m .32322 .71558 L .34454 .7262 L p .707 .577 .707 r
F P
0 g
s
.30308 .63111 m .30707 .66401 L .32 .67775 L p .707 .577 .707 r
F P
0 g
s
.29945 .59097 m .29574 .53871 L .30265 .5252 L p .707 .577 .707 r
F P
0 g
s
.72459 .66377 m .72237 .64765 L .75394 .64271 L p .707 .577 .707 r
F P
0 g
s
.72237 .64765 m .72459 .66377 L .69562 .67364 L p .707 .577 .707 r
F P
0 g
s
.75394 .64271 m .75616 .65883 L .72459 .66377 L p .707 .577 .707 r
F P
0 g
s
.30707 .66401 m .30308 .63111 L .29976 .61518 L p .707 .577 .707 r
F P
0 g
s
.32322 .71558 m .321 .69946 L .30799 .68509 L p .707 .577 .707 r
F P
0 g
s
.50273 .60244 m .50672 .63534 L .5034 .61942 L p .707 .577 .707 r
F P
0 g
s
.5034 .61942 m .49941 .58652 L .50273 .60244 L p .707 .577 .707 r
F P
0 g
s
.5008 .67132 m .50302 .68744 L .50953 .67001 L p .707 .577 .707 r
F P
0 g
s
.50953 .67001 m .50731 .65389 L .5008 .67132 L p .707 .577 .707 r
F P
0 g
s
.49623 .51888 m .49994 .57114 L .48722 .55957 L p .707 .577 .707 r
F P
0 g
s
.48722 .55957 m .48351 .50731 L .49623 .51888 L p .707 .577 .707 r
F P
0 g
s
.30799 .68509 m .31021 .70121 L .32322 .71558 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29976 .61518 m .30376 .64808 L .30707 .66401 L p .707 .577 .707 r
F P
0 g
s
.30265 .5252 m .30635 .57746 L .29945 .59097 L p .707 .577 .707 r
F P
0 g
s
.30635 .57746 m .30265 .5252 L .31884 .51269 L p .707 .577 .707 r
F P
0 g
s
.30376 .64808 m .29976 .61518 L .30638 .59863 L p .707 .577 .707 r
F P
0 g
s
.31021 .70121 m .30799 .68509 L .30457 .66838 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50731 .65389 m .50953 .67001 L .50611 .6533 L p .707 .577 .707 r
F P
0 g
s
.50611 .6533 m .50389 .63718 L .50731 .65389 L p .707 .577 .707 r
F P
0 g
s
.48351 .50731 m .48722 .55957 L .46608 .55075 L p .707 .577 .707 r
F P
0 g
s
.46608 .55075 m .46237 .49849 L .48351 .50731 L p .707 .577 .707 r
F P
0 g
s
.49941 .58652 m .5034 .61942 L .49047 .60567 L p .707 .577 .707 r
F P
0 g
s
.49047 .60567 m .48648 .57277 L .49941 .58652 L p .707 .577 .707 r
F P
0 g
s
.30457 .66838 m .30679 .6845 L .31021 .70121 L p .707 .577 .707 r
F P
0 g
s
.30638 .59863 m .31037 .63153 L .30376 .64808 L p .707 .577 .707 r
F P
0 g
s
.31884 .51269 m .32254 .56495 L .30635 .57746 L p .707 .577 .707 r
F P
0 g
s
.32254 .56495 m .31884 .51269 L .34273 .5024 L p .707 .577 .707 r
F P
0 g
s
.31037 .63153 m .30638 .59863 L .32228 .58308 L p .707 .577 .707 r
F P
0 g
s
.30679 .6845 m .30457 .66838 L .31107 .65095 L p .707 .577 .707 r
F P
0 g
s
.46237 .49849 m .46608 .55075 L .43859 .54554 L p .707 .577 .707 r
F P
0 g
s
.43859 .54554 m .43489 .49329 L .46237 .49849 L p .707 .577 .707 r
F P
0 g
s
.50389 .63718 m .50611 .6533 L .4931 .63893 L p .707 .577 .707 r
F P
0 g
s
.4931 .63893 m .49088 .62281 L .50389 .63718 L p .707 .577 .707 r
F P
0 g
s
.48648 .57277 m .49047 .60567 L .4692 .59545 L p .707 .577 .707 r
F P
0 g
s
.4692 .59545 m .46521 .56255 L .48648 .57277 L p .707 .577 .707 r
F P
0 g
s
.31107 .65095 m .31329 .66707 L .30679 .6845 L p .707 .577 .707 r
F P
0 g
s
.34644 .55466 m .34273 .5024 L .37199 .49534 L p .707 .577 .707 r
F P
0 g
s
.34273 .5024 m .34644 .55466 L .32254 .56495 L p .707 .577 .707 r
F P
0 g
s
.43489 .49329 m .43859 .54554 L .40745 .54446 L p .707 .577 .707 r
F P
0 g
s
.40745 .54446 m .40374 .4922 L .43489 .49329 L p .707 .577 .707 r
F P
0 g
s
.32228 .58308 m .32627 .61598 L .31037 .63153 L p .707 .577 .707 r
F P
0 g
s
.32627 .61598 m .32228 .58308 L .34591 .57004 L p .707 .577 .707 r
F P
0 g
s
.37569 .5476 m .37199 .49534 L .40374 .4922 L p .707 .577 .707 r
F P
0 g
s
.37199 .49534 m .37569 .5476 L .34644 .55466 L p .707 .577 .707 r
F P
0 g
s
.40374 .4922 m .40745 .54446 L .37569 .5476 L p .707 .577 .707 r
F P
0 g
s
.31329 .66707 m .31107 .65095 L .32686 .63452 L p .707 .577 .707 r
F P
0 g
s
.46521 .56255 m .4692 .59545 L .44167 .58976 L p .707 .577 .707 r
F P
0 g
s
.44167 .58976 m .43768 .55686 L .46521 .56255 L p .707 .577 .707 r
F P
0 g
s
.49088 .62281 m .4931 .63893 L .47178 .62831 L p .707 .577 .707 r
F P
0 g
s
.47178 .62831 m .46956 .61219 L .49088 .62281 L p .707 .577 .707 r
F P
0 g
s
.32686 .63452 m .32908 .65065 L .31329 .66707 L p .707 .577 .707 r
F P
0 g
s
.3499 .60294 m .34591 .57004 L .37496 .5608 L p .707 .577 .707 r
F P
0 g
s
.34591 .57004 m .3499 .60294 L .32627 .61598 L p .707 .577 .707 r
F P
0 g
s
.43768 .55686 m .44167 .58976 L .41057 .58916 L p .707 .577 .707 r
F P
0 g
s
.41057 .58916 m .40658 .55626 L .43768 .55686 L p .707 .577 .707 r
F P
0 g
s
.32908 .65065 m .32686 .63452 L .35039 .6207 L p .707 .577 .707 r
F P
0 g
s
.37895 .5937 m .37496 .5608 L .40658 .55626 L p .707 .577 .707 r
F P
0 g
s
.37496 .5608 m .37895 .5937 L .3499 .60294 L p .707 .577 .707 r
F P
0 g
s
.40658 .55626 m .41057 .58916 L .37895 .5937 L p .707 .577 .707 r
F P
0 g
s
.46956 .61219 m .47178 .62831 L .44423 .62248 L p .707 .577 .707 r
F P
0 g
s
.44423 .62248 m .44201 .60636 L .46956 .61219 L p .707 .577 .707 r
F P
0 g
s
.35039 .6207 m .35261 .63682 L .32908 .65065 L p .707 .577 .707 r
F P
0 g
s
.35261 .63682 m .35039 .6207 L .37936 .61084 L p .707 .577 .707 r
F P
0 g
s
.44201 .60636 m .44423 .62248 L .41315 .62202 L p .707 .577 .707 r
F P
0 g
s
.41315 .62202 m .41093 .6059 L .44201 .60636 L p .707 .577 .707 r
F P
0 g
s
.38158 .62696 m .37936 .61084 L .41093 .6059 L p .707 .577 .707 r
F P
0 g
s
.37936 .61084 m .38158 .62696 L .35261 .63682 L p .707 .577 .707 r
F P
0 g
s
.41093 .6059 m .41315 .62202 L .38158 .62696 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00RGoo2@00Rgoo0023Ool60003FUH00`00
FUIJEP03FUH90022Ool007eoo`H000UJEP03001JEUYF00UJEP03001JEUYF00H007aoo`00Mgoo1P00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1000N7oo001cOol40008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001eOol0075oo`<000]JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0079oo`00Kgoo0P00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0P00L7oo001]Ool20004FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00Oomoo`1]Ool006]oo`8000IJEP03001JEUYF00UJEP03001J
EUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00QJEP03001oogoo06aoo`00JWoo
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<007ooOol0Jgoo001XOol30008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00Oomoo`1ZOol006Moo`04001JEUYF
0008FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00Oomoo`1YOol006Ioo`05001JEUYFFUH00009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP0;FUI[Ool006Aoo`8000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00]JEV]o
o`00Hgoo00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0J7oo001ROol2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH017ooFUIJEP002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0J7oo001ROol20007FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1XOol0065oo`03001JEP0000MJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo06Qoo`00HGoo00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0J7oo001POol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0J7oo001POol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
J7oo001POol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0J7oo
001POol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH01UYF00Eo
oeYFFUIJEP0000aJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qo
o`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00IJEP03
OomJEUYF009JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Uoo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo
00D005YFFUIJEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00HGoo00@005YFFUH000IJEP03
001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Uoo`00HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00
HGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP03OomJEUYF
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065o
o`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00gooFUIJEP03
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol0
1000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH015YF00=ooeYFFUH00eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Uoo`00HGoo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001YOol0065oo`04001JEUYF0007FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<007ooOol0Igoo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<007ooOol0Igoo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF00<007ooOol0Igoo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
0P002UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00J7oo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF0P00
2UYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Qo
o`00HWoo00@005YFFUH000IJEP8000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P00J7oo001ROol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Qoo`00HWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH2001XOol0069o
o`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol0069oo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0069oo`05001JEUYFFUH0
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol0069oo`05001JEUYFFUH00006FUH00`00FUIJEP06
FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH2000:FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=o
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP8006Moo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001WOol006=oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<006Ioo`00Hgoo00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00Hgoo00D005YFFUIJEP0000IJEP03001J
EUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJ
EP03001JEUYF00IJEP8000YJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJ
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00I7oo00<005YFFUH060001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIVOol006Aoo`@00003FUH005YF00MJEP03
001JEUYF00IJEP04001JEUYFFUH6000<FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01P00FUIJEUYF001JEVIoo`00H7oo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF0`002eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUIJEP00
FUIVOol005ioo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF0000IGoo001LOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01`00FUIJEUYF001JEP0006Eoo`00FWoo0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001IOol20006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0Hgoo001HOol00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Hgoo001GOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001oogoo06=oo`00EWoo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000HOol?000nOol005Eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000AOol70004
FUH00`00FUIJEP06FUH00`00FUH00003000jOol005Aoo`03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000gOol005Aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2000:Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0027oo0`0025YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70008FUH80004FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJ
EP8000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01@00
1EYF00<005YFFUH01eYF00<005YFFUH015YF1@001EYF00D005YFFUIJEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH30003Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000`Ool0
05Aoo`04001JEUYF0003FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH20003FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<00004Ool000000005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol01000FUIJ
EP000eYF00@005YFFUIJEP8000Aoo`05001JEUYFFUH00005FUHA0005FUH400000eYF001JEP02FUH0
1@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool005Aoo`04001JEUYF0003FUH01000FUH000001goo00<005YF
FUH01P0015YF00<005YFFUH01UYF00@005YFFUIJEPH00003FUH005YF008000=JEP05001JEUYFFUH0
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Woo001DOol01000FUIJEP000eYF0P002Goo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF10000eYF00@005YFFUH000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEUYF0P00
;Goo001DOol2000015YF001JEUYF0`001goo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00P000eYF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYFFUH2000]Ool005Aoo`800004
FUH005YF0003FUH3000017oo000000001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000AJEP00FUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol20000
0eYF00000005FUH300000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH300000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00@005YF
000000AJEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<00003FUH005YF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol2000015YF
001JEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEUYF001JEP001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF3`00
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol200000eYF001JEP020006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJ
EP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00=JEP03001JEUYF00AJEPL000moo`@00003FUH005YF00AJEP05001JEUYFFUH0000]
Ool004Moo`l0009JEP800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF009JEPl000IJEP03
001JEUYF009JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04000JOol30004FUH0
1@00FUIJEUYF0000;Goo0011Ool60004FUH00`00FUIJEP06FUH20003FUH00`00FUH00007FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUH00005FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<0
05YFFUH00eYF0`002goo3P0027oo0`0000=JEP00FUH00UYF00<007ooOol0:goo000mOol400000eYF
001JEP07FUH00`00FUIJEP06FUH20002FUH01000FUIJEP001eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001EYF00@005YFFUH000AJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP04001JEUYFFUH2
0008Ool60004FUH00`00FUIJEP05FUH00`00FUH000030005Ool01000FUH000000eYF0P00;7oo000i
Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00FUIJEP05FUH0
0`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000
FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<0
05YFFUH00UYF00@005YF000000Moo`<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EPH000=JEP03001JEUYF008002aoo`00=goo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF100015YF00<005YFFUH015YF0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF0P0000EJEP00FUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP06001JEUYF001JEP0015YF0P001Woo0`0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF100015YF1000;7oo000eOol20003FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF3`00
0UYF00<005YFFUH015YF10000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0002FUH40004Ool20007FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH01000FUH00000;7oo000cOol20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP020006FUH0
0`00FUIJEP060004FUH00`00FUIJEP06FUH00`00FUH000030004FUH20003FUH00`00FUH00004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`0015YF1@0025YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF0`00;7oo
000bOol20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP03
FUH40007FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40006FUH00`00FUH0
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH02000FUIJEP00FUH005YF0005
FUH01000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0eYF0P0000AJEP00000002aoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYF0005FUH30003FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH30005FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH01000FUIJEUYF0P000eYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF000/Ool0
02moo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF0`0000=JEP00FUH00UYF0P001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF
00<005YFFUH00P000eYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP06001JEUYF001JEP00;7oo000^Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
009JEPL000QJEP03001JEUYF00@000IJEPT000AJEP04001JEUYFFUH400000eYF001JEP02FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF
00D005YFFUIJEP0002eoo`00;Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00@005YF0000009JEP03001JEUYF00EJEPL000=J
EPL000IJEPD000AJEP<00003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF0080009JEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ40
00=JEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0004FUH20005FUH00`00FUIJ
EP02FUH<0005FUH2000:FUH30002FUH00`00FUH00002FUH01@00FUIJEUYF00002eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH0
15YF1`001eYF00<005YFFUH01UYF1@001EYF00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00UYF
00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH00UYF1@001eYF0P002eYF100000IJEP00FUH0
05YF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH0
0`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
0P000eYF00<005YFFUH00P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH20007FUH40003FUH00`00FUIJEP050008FUH0
0`00FUIJEP08FUH30002FUH20002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P001EYF00<005YFFUH00eYF100025YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH00eYF0P0000AJEP00FUIJEP8002aoo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF4@0000AJEP00FUH000EJEP80009JEP8000=JEP04001J
EUYFFUH30009FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P001EYF00@005YFFUIJEP8000AJ
EP03001JEUYF00EJEP04001JEUYFFUH=0002FUH00`00FUIJEP03FUH01000FUH000000eYF00<007oo
Ool0:Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP04FUH6000>Ool00`00FUIJ
EP020002FUH00`00FUIJEP0200000eYF001JEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH015YF0P0015YF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP04001JEUYF0006FUH00`00FUIJEP05FUH4
0002FUH00`00FUIJEP06FUH00`00FUH000030004FUH20002Ool01000FUIJEP00;7oo000]Ool01000
FUIJEP000eYF00<005YFFUH015YF00<005YFFUH0100057oo0P0000=JEP00FUH00UYF0`000eYF00D0
05YFFUIJEP0000=JEP03001JEUYF00=JEP03001JEUYF00MJEP8000=JEP8000IJEP03001JEUYF00=J
EP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00005FUH4
0006FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0017oo00<005YF0000
;7oo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF10002Woo0`002goo0`0015YF00<007oo0000
0P0000=JEP00FUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00MJEPD00003FUH005YF00IJEP03
001JEUYF009JEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00005FUH01000FUIJEP001UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF000000Aoo`<002aoo`00;Goo00@005YFFUH000=JEP04001JEUYFFUH2000=Ool5000:Ool3
0003FUH00`00FUH000050003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH50005FUH00`00
FUIJEP05FUH01P00FUIJEUYF001JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP00009JEP05001JEUYFFUH00003FUH01000FUIJEUYF0`001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009oo`03001JEP0002aoo`00;Goo00@0
05YFFUH000=JEP04001JEP00000?OolB0002FUH01@00FUIJEUYF00000eYF2@001UYF1@000UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00@005YF0000009JEP8000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEP00009JEP05001JEUYF001JEP0200000eYF001JEP030007FUH0
0`00FUIJEP02FUH?0006FUH00`00FUIJEP02FUH300000eYF0000000[Ool002ioo`03001JEP0000=J
EP8000aoo`H000AJEP03001JEUYF00IJEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH70006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH20004FUH20003FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUH00002FUH00`00FUH000020002
FUH00`00FUIJEP04FUH60004FUH70004Ool40002FUH00`00FUIJEP03FUH200000eYF0000000[Ool0
02ioo`03001JEP00009JEP<000Yoo`800003FUH005YF00MJEP03001JEUYF00IJEP80009JEP8000EJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEP00009JEP8000=JEP<000AJEP03001JEUYF009JEP`000moo`<000EJEP80009JEP03001o
ogoo02Uoo`00;Woo00<005YF00000P000eYF1@000Woo0`000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001EYF00<005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YFFUH005YF008000=JEP03001JEUYF00AJEP03001JEP00008000Ioo`D001=o
o`8000=JEP05001JEP00FUH0000[Ool002ioo`04001JEP000005FUH01000FUIJEUYF0P001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000AJEP00000000EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000EJEP800003FUH005YF009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00@0009JEP8000IJEP@000Moo`D0
019oo`D00004FUH005YFFUH2000[Ool002ioo`800003FUH005YF00AJEP03001JEP00008000MJEP03
001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF008000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP04001JEP000004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0200001UYF001JEP00FUH0
00AJEP80009JEP8000Moo`D0015oo`04001JEUYF0002FUH20002FUH00`00Oomoo`0ZOol002ioo`80
0003FUH005YF00AJEP80009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP8000AJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH00002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEP000eYF00D005YFFUIJEP00009JEP03001JEP0000=JEP03001oogoo00Ioo`<0011oo`80
00AJEP07001JEUYFFUH005YF0000;7oo000^Ool01000FUIJEP000eYF0P0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF1@00
1eYF00<005YFFUH00eYF0P001EYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP<0009JEP05001J
EUYFFUH0000IOol20006FUH00`00FUIJEP02FUH00`00FUH0000[Ool002ioo`07001JEUYFFUH005YF
00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YF00000P00
1EYF00<005YFFUH00eYF1@001eYF00<005YF00000`0025YF0P0015YF00<005YFFUH015YF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00`001EYF0P000eYF00D005YFFUIJ
EP0001Moo`800003FUH005YF00EJEP03001JEUYF009JEP<002]oo`00;Woo0P000UYF0`001eYF00<0
05YFFUH01EYF00<005YFFUH015YF1`0015YF0P0000=JEP00FUH00eYF00<005YFFUH00UYF100000=J
EP00FUH015YF1@000UYF20002UYF0`000eYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YF00000P0000=JEP00FUH00UYF00<007oo
Ool04Woo0`000eYF00<005YFFUH015YF00D005YFFUIJEP00009oo`03001oogoo02Uoo`00;Woo0P00
0UYF00<005YF00001eYF00<005YFFUH01EYF00<005YFFUH010001UYF200000=JEP00FUH00UYF00<0
05YFFUH00eYF00<005YF00003P001eYF00<005YFFUH01eYF00@005YFFUH0009JEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH01P00FUIJ
EUYF001JEP@00003FUH0000000eoo`H000IJEP03001JEUYF00AJEP04001JEUYF0003Ool00`00Oomo
o`0YOol002moo`03001JEP00009JEP03001JEUYF00EJEP03001JEUYF00AJEP@00003FUH005YF00MJ
EP03001JEUYF00AJEP03001JEUYF00@000EJEP05001JEP00Ool00003FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH20006FUH20004FUH00`00FUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH02@00FUIJEUYF001JEP00FUH00004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUH00002Ool2000[Ool002moo`8000=JEP03001JEUYF00EJEP03001J
EUYF00@000EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00<00003FUH0000000=JEP05
001JEUYF001oo`03FUH00`00FUIJEP03FUH00`00FUIJEP07FUH20004FUH20006FUH20009FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P000goo00<0
05YF0000:Woo000`Ool00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00002FUH200001EYF000005YF00000UYF00<007oo00000UYF
00<005YFFUH00eYF00<005YFFUH025YF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01EYF
2P001UYF00<005YFFUH025YF00<005YFFUH01EYF00P005YFFUH005YF001JEP0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000goo00@0
05YFFUH002Yoo`00;goo0P0015YF00<005YFFUH00UYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF000015YF1@000UYF00<007oo00000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF0`0015YF00<005YFFUH00UYF0P000UYF1P002EYF2P0025YF00<005YFFUH01EYF00P0
05YFFUH005YF001JEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEP8000Eoo`04001JEUYF000ZOol002moo`8000AJEP03001JEUYF008000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEP0000@00005Ool0
05YFFUH00009FUH60007FUH00`00FUIJEP060002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF00000005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001Woo0P0000=JEP00Ool0:Woo000^Ool0
0`00FUH00004FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH30008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
1000FUIJEUYF10001UYF00<005YFFUH00P0000=JEP0000001EYF00<005YFFUH01EYF00<005YFFUH0
15YF0`0025YF00<005YFFUH015YF0`001goo00D005YF001JEP0002]oo`00;Woo00<005YF000015YF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF3`0000=JEP0000000`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`002UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF0P0015YF00<005YFFUH0100000=JEP0000000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF1@001eYF00<005YFFUH00UYF0P002Woo00@005YFFUH002aoo`00;Woo00@005YFFUH0
009JEP03001oogoo00D000AJEP03001JEUYF00H000AJEP03001JEUYF00IJEP03001JEP0000<0009o
o`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF
00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP<00004FUH005YFFUH40003FUH2
00000eYF001JEP06FUH00`00FUIJEP03FUH50007FUH00`00FUH00002000;Ool01@00FUIJEUYF0000
;7oo000^Ool01P00FUIJEP00FUH000Qoo`L00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00=JEP<00004Ool000000006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH40003FUH0
0`00FUH000040004FUH00`00FUIJEP03FUH50003FUH6000<Ool20003FUH00`00Oomoo`0[Ool002io
o`06001JEUYF001JEP002Woo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
0`000Woo10000UYF00<005YFFUH01UYF00<005YFFUH010002EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00
FUIJEP02FUH00`00FUH0000A000@Ool200001EYF001JEUYF0000;Woo000^Ool00`00FUIJEP020009
Ool20007FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP04FUH00`00FUIJEP020003FUHB000:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
1000FUH005YF0`0000=JEP00FUH015YF00@005YFFUH001eoo`8000=JEP03001JEP0002moo`00;goo
00<005YF000027oo0`0025YF00<005YFFUH010001goo200015YF00@005YFFUIJEP800005FUH005YF
FUH00009FUH20002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20002FUH01000FUH000001EYF00<005YFFUH00P006Goo
0`001EYF0P00<7oo000_Ool20007Ool20002FUH00`00FUIJEP05FUH4000COol50004FUH2000015YF
001JEP0025YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0`0000EJEP00000005YF008000=JEP03001J
EUYF008001Moo`800003FUH005YF00EJEP03001oogoo02moo`00;goo0`0017oo0P001EYF00<005YF
FUH00UYF0P006Goo0P0000=JEP0000000UYF00<005YF00000`001eYF00<005YFFUH00eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P000UYF0P0000EJEP00001JEP00009JEP8001Aoo`<000=JEP03001JEUYF
009JEP80039oo`00;goo00@005YFFUH0009oo`03001JEUYF00EJEP03001JEP00008001Uoo`8000AJ
EP<00003FUH005YF00<000EJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP00FUH20003FUH50003FUH0
0`00Oomoo`0>Ool40007FUH01000FUIJEP00=7oo000_Ool00`00FUIJEP040007FUH2000JOol20006
FUH00`00FUIJEP020002FUH00`00OomJEP03FUH20008FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUH0000300000eYF001oo`0;Ool40002FUH00`00FUIJEP06FUH3000eOol002moo`800005
FUH00000FUH00005FUH2000JOol200000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH007oo0eYF
00<005YF000025YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01@000UYF00<005YFFUH00eYF3P001UYF00<0
05YFFUH01EYF0P00=goo000_Ool200000eYF00000002FUH00`00FUIJEP02000IOol30003FUH00`00
FUIJEP05FUH02000FUIJEUYF001JEP00Ool2FUH01000FUIJEP0025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
FUIJEP80009oo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009J
EP8003Uoo`00<7oo00<005YF00000eYF0`0000=JEP0000000P0047oo1P001UYF00<005YFFUH01EYF
00D005YFFUH007oo00<0009JEP04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`00
00Aoo`00000000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003]oo`00<7oo0P00
15YF00<005YF00001EYF400015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000goo0P00
00=JEP00FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00@005YF0000009o
o`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003ioo`00<7oo0P000eYF00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000Aoo`80
0003FUH005YF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH2
0002FUH00`00FUH0000?0014Ool0031oo`80009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00EJEP<000MJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Eoo`@000=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00EJEP8000EJEP03001JEUYF009JEP<0009JEP03001oogoo051oo`00<7oo00@005YF
000000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP04001JEUYFFUH2
0007Ool4000<FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH50002FUH00`00FUIJEP03FUH20002FUH00`00Oomoo`1@Ool0
02moo`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00AJEPD000MJEP03001JEUYF00EJ
EP04001JEP000008Ool00`00FUH00002000<FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00Oomoo`02Ool30005FUH3
00000eYF001oo`1AOol002moo`03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
00MJEP03001JEUYF00AJEP<000Yoo`05001JEP00Ool00004FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00Oomoo`03Ool01000FUH000000eYF00@005YF000005=oo`00;goo00<005YF00000goo0P00
0eYF00<005YFFUH015YF00<005YFFUH015YF0`0025YF00<005YFFUH00UYF0P0037oo0P0000AJEP00
Ool000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP8000Aoo`8000AJEP800005FUH005YFFUH0001C
Ool002moo`03001JEP0000Eoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000eoo`04001JEP000002Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01@00FUIJEUYF
000017oo0P001UYF00@005YF0000009JEP03001oogoo055oo`00<7oo00<007ooOol01Woo1@000eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P003goo00<005YFFUH00P000goo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJ
EP05001JEUYF001oo`0400000eYF001JEP05FUH01`00FUIJEUYF001JEP0005=oo`00<7oo00<007oo
Ool02goo4@0057oo00D005YFFUIJEP0000Eoo`04001JEUYF000BFUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00Ool0DGoo000`Ool2000`Ool00`00FUIJEP02FUH00`00Oomoo`04Ool00`00FUH00008FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH2
00000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUH00002Ool2001BOol0031oo`03001JEP0002eo
o`<000=JEP03001oogoo00Ioo`8000QJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP8000Ao
o`03001oogoo051oo`00<Goo00<005YF0000:goo00@005YFFUH0009JEP03001oogoo00Qoo`8000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH2
0005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`03Ool00`00Oomoo`1@Ool0035oo`04
001JEUYF000XOol20004FUH00`00FUH0000<Ool20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool2
001BOol0035oo`03001JEUYF00<002Aoo`8000IJEP8000moo`8000=JEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEPH000IJEP03001JEUYF00IJEP03001JEUYF0080
00Moo`03001JEP00055oo`00<Woo00<005YF00000UYF0P007goo0`0000=JEP00FUH01EYF00<007oo
Ool047oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH015YF1000
00=JEP0000000`001eYF00<005YFFUH01EYF0`0027oo00@005YFFUH0055oo`00<Woo00<005YF0000
15YF0`006Goo0`0015YF00<005YFFUH00UYF0P005Goo100025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH010001EYF1@001eYF00<005YFFUH015YF0P002Woo00@005YFFUH0055oo`00<goo
0P001EYF00<005YF00000`003goo1P001eYF00<005YFFUH00P006goo1P000UYF00<005YFFUH02EYF
00<005YFFUH015YF2@000eYF00<005YFFUH015YF0`0025YF00<005YFFUH00UYF0P002goo0P0000=J
EP00Ool0DGoo000dOol00`00FUIJEP03FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP06FUH3000S
OolE0003Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002000<Ool01@00FUH0
05YF0000DWoo000eOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000dOol2000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6000?Ool01000
FUIJEP00Dgoo000gOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04000fOol2000>Ool@000DOol01@00FUIJEUYF0000Dgoo000iOol30006FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH5000jOol3000`Ool01@00FUIJEUYF0000E7oo000lOol40002FUH00`00FUIJEP06
FUH00`00FUIJEP04000oOol3000^Ool30002FUH00`00Oomoo`1COol0041oo`h004Aoo`03001JEP00
02]oo`80009JEP03001JEP0005Ioo`00TWoo00@005YFFUH002Qoo`8000AJEP8005Moo`00Tgoo00<0
05YF00000P0097oo0P001UYF00<007ooOol0EWoo002DOol20002FUH2000NOol400000eYF001JEP03
FUH2001IOol009Eoo`8000=JEP<001Ioo`D000EJEP05001JEUYFFUH0001KOol009Ioo`03001JEUYF
009JEP03001JEP0000<000ioo`@0009JEP03001JEUYF00IJEP<005aoo`00Ugoo0P000UYF00<005YF
FUH00eYF3P001UYF00<005YFFUH01EYF0P00GWoo002IOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00UYF0P00H7oo002JOol30006FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUH00002001ROol009aoo`@000AJEP03001JEUYF00IJEP03001JEUYF009JEPH006Eo
o`00X7oo4P00Jgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]4\[InvisibleSpace]"     "\
\[InvisibleSpace]2.3517602945677583`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 4, "     ", 2.3517602945677583, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5856 .75565 m .59487 .7019 L .56414 .69478 L p .707 .577 .707 r
F P
0 g
s
.59487 .7019 m .5856 .75565 L .61704 .75958 L p .707 .577 .707 r
F P
0 g
s
.61704 .75958 m .62631 .70583 L .59487 .7019 L p .707 .577 .707 r
F P
0 g
s
.62631 .70583 m .61704 .75958 L .6461 .75993 L p .707 .577 .707 r
F P
0 g
s
.6461 .75993 m .65537 .70618 L .62631 .70583 L p .707 .577 .707 r
F P
0 g
s
.55487 .74853 m .56414 .69478 L .53713 .68517 L p .707 .577 .707 r
F P
0 g
s
.56414 .69478 m .55487 .74853 L .5856 .75565 L p .707 .577 .707 r
F P
0 g
s
.65537 .70618 m .6461 .75993 L .66995 .75668 L p .707 .577 .707 r
F P
0 g
s
.66995 .75668 m .67922 .70293 L .65537 .70618 L p .707 .577 .707 r
F P
0 g
s
.52785 .73892 m .53713 .68517 L .51647 .67401 L p .707 .577 .707 r
F P
0 g
s
.53713 .68517 m .52785 .73892 L .55487 .74853 L p .707 .577 .707 r
F P
0 g
s
.57481 .82103 m .58481 .78653 L .55481 .77624 L p .707 .577 .707 r
F P
0 g
s
.58481 .78653 m .57481 .82103 L .60558 .82782 L p .707 .577 .707 r
F P
0 g
s
.60558 .82782 m .61558 .79332 L .58481 .78653 L p .707 .577 .707 r
F P
0 g
s
.54481 .81074 m .55481 .77624 L .52852 .76346 L p .707 .577 .707 r
F P
0 g
s
.55481 .77624 m .54481 .81074 L .57481 .82103 L p .707 .577 .707 r
F P
0 g
s
.61558 .79332 m .60558 .82782 L .63413 .83045 L p .707 .577 .707 r
F P
0 g
s
.63413 .83045 m .64413 .79595 L .61558 .79332 L p .707 .577 .707 r
F P
0 g
s
.51647 .67401 m .5072 .72776 L .52785 .73892 L p .707 .577 .707 r
F P
0 g
s
.67922 .70293 m .66995 .75668 L .68625 .75014 L p .707 .577 .707 r
F P
0 g
s
.68625 .75014 m .69552 .69639 L .67922 .70293 L p .707 .577 .707 r
F P
0 g
s
.5072 .72776 m .51647 .67401 L .50419 .6624 L p .707 .577 .707 r
F P
0 g
s
.51852 .79796 m .52852 .76346 L .50852 .74944 L p .707 .577 .707 r
F P
0 g
s
.52852 .76346 m .51852 .79796 L .54481 .81074 L p .707 .577 .707 r
F P
0 g
s
.64413 .79595 m .63413 .83045 L .65764 .82866 L p .707 .577 .707 r
F P
0 g
s
.65764 .82866 m .66764 .79416 L .64413 .79595 L p .707 .577 .707 r
F P
0 g
s
.56719 .86785 m .57275 .85084 L .54304 .83962 L p .707 .577 .707 r
F P
0 g
s
.57275 .85084 m .56719 .86785 L .59771 .87547 L p .707 .577 .707 r
F P
0 g
s
.59771 .87547 m .60327 .85846 L .57275 .85084 L p .707 .577 .707 r
F P
0 g
s
.53748 .85663 m .54304 .83962 L .51704 .82592 L p .707 .577 .707 r
F P
0 g
s
.54304 .83962 m .53748 .85663 L .56719 .86785 L p .707 .577 .707 r
F P
0 g
s
.60327 .85846 m .59771 .87547 L .62605 .87876 L p .707 .577 .707 r
F P
0 g
s
.62605 .87876 m .63161 .86175 L .60327 .85846 L p .707 .577 .707 r
F P
0 g
s
.50852 .74944 m .49852 .78394 L .51852 .79796 L p .707 .577 .707 r
F P
0 g
s
.50419 .6624 m .49492 .71614 L .5072 .72776 L p .707 .577 .707 r
F P
0 g
s
.51704 .82592 m .51148 .84293 L .53748 .85663 L p .707 .577 .707 r
F P
0 g
s
.69552 .69639 m .68625 .75014 L .6934 .74095 L p .707 .577 .707 r
F P
0 g
s
.6934 .74095 m .70268 .6872 L .69552 .69639 L p .707 .577 .707 r
F P
0 g
s
.49852 .78394 m .50852 .74944 L .49677 .73555 L p .707 .577 .707 r
F P
0 g
s
.51148 .84293 m .51704 .82592 L .4973 .81106 L p .707 .577 .707 r
F P
0 g
s
.49492 .71614 m .50419 .6624 L .5015 .65146 L p .707 .577 .707 r
F P
0 g
s
.66764 .79416 m .65764 .82866 L .67382 .82262 L p .707 .577 .707 r
F P
0 g
s
.67382 .82262 m .68382 .78812 L .66764 .79416 L p .707 .577 .707 r
F P
0 g
s
.63161 .86175 m .62605 .87876 L .64944 .87739 L p .707 .577 .707 r
F P
0 g
s
.64944 .87739 m .655 .86038 L .63161 .86175 L p .707 .577 .707 r
F P
0 g
s
.4973 .81106 m .49174 .82807 L .51148 .84293 L p .707 .577 .707 r
F P
0 g
s
.49677 .73555 m .48677 .77005 L .49852 .78394 L p .707 .577 .707 r
F P
0 g
s
.5015 .65146 m .49223 .7052 L .49492 .71614 L p .707 .577 .707 r
F P
0 g
s
.44574 .82069 m .52901 .33523 L .48562 .32522 L p .707 .577 .707 r
F P
0 g
s
.49174 .82807 m .4973 .81106 L .48575 .79651 L p .707 .577 .707 r
F P
0 g
s
.48677 .77005 m .49677 .73555 L .49441 .72315 L p .707 .577 .707 r
F P
0 g
s
.48575 .79651 m .48019 .81352 L .49174 .82807 L p .707 .577 .707 r
F P
0 g
s
.49223 .7052 m .5015 .65146 L .50865 .64227 L p .707 .577 .707 r
F P
0 g
s
.49441 .72315 m .48441 .75765 L .48677 .77005 L p .707 .577 .707 r
F P
0 g
s
.48019 .81352 m .48575 .79651 L .48352 .78369 L p .707 .577 .707 r
F P
0 g
s
.50865 .64227 m .49938 .69601 L .49223 .7052 L p .707 .577 .707 r
F P
0 g
s
.48352 .78369 m .47796 .80069 L .48019 .81352 L p .707 .577 .707 r
F P
0 g
s
.48441 .75765 m .49441 .72315 L .50168 .71345 L p .707 .577 .707 r
F P
0 g
s
.49938 .69601 m .50865 .64227 L .52495 .63572 L p .707 .577 .707 r
F P
0 g
s
.50168 .71345 m .49168 .74795 L .48441 .75765 L p .707 .577 .707 r
F P
0 g
s
.47796 .80069 m .48352 .78369 L .49084 .77385 L p .707 .577 .707 r
F P
0 g
s
.52495 .63572 m .51568 .68947 L .49938 .69601 L p .707 .577 .707 r
F P
0 g
s
.49084 .77385 m .48528 .79086 L .47796 .80069 L p .707 .577 .707 r
F P
0 g
s
.49168 .74795 m .50168 .71345 L .51786 .70742 L p .707 .577 .707 r
F P
0 g
s
.51786 .70742 m .50786 .74192 L .49168 .74795 L p .707 .577 .707 r
F P
0 g
s
.48528 .79086 m .49084 .77385 L .50697 .76795 L p .707 .577 .707 r
F P
0 g
s
.50697 .76795 m .50141 .78496 L .48528 .79086 L p .707 .577 .707 r
F P
0 g
s
.52901 .33523 m .44574 .82069 L .49013 .8262 L p .707 .577 .707 r
F P
0 g
s
.49013 .8262 m .57339 .34074 L .52901 .33523 L p .707 .577 .707 r
F P
0 g
s
.655 .86038 m .64944 .87739 L .66557 .8715 L p .707 .577 .707 r
F P
0 g
s
.66557 .8715 m .67113 .85449 L .655 .86038 L p .707 .577 .707 r
F P
0 g
s
.51568 .68947 m .52495 .63572 L .5488 .63247 L p .707 .577 .707 r
F P
0 g
s
.5488 .63247 m .53953 .68622 L .51568 .68947 L p .707 .577 .707 r
F P
0 g
s
.53953 .68622 m .5488 .63247 L .57787 .63283 L p .707 .577 .707 r
F P
0 g
s
.50786 .74192 m .51786 .70742 L .54138 .70562 L p .707 .577 .707 r
F P
0 g
s
.57787 .63283 m .5686 .68658 L .53953 .68622 L p .707 .577 .707 r
F P
0 g
s
.54138 .70562 m .53138 .74012 L .50786 .74192 L p .707 .577 .707 r
F P
0 g
s
.50141 .78496 m .50697 .76795 L .53036 .76658 L p .707 .577 .707 r
F P
0 g
s
.53138 .74012 m .54138 .70562 L .56992 .70825 L p .707 .577 .707 r
F P
0 g
s
.53036 .76658 m .5248 .78359 L .50141 .78496 L p .707 .577 .707 r
F P
0 g
s
.56992 .70825 m .55992 .74275 L .53138 .74012 L p .707 .577 .707 r
F P
0 g
s
.5248 .78359 m .53036 .76658 L .5587 .76987 L p .707 .577 .707 r
F P
0 g
s
.5587 .76987 m .55314 .78688 L .5248 .78359 L p .707 .577 .707 r
F P
0 g
s
.57339 .34074 m .49013 .8262 L .53117 .82667 L p .707 .577 .707 r
F P
0 g
s
.53117 .82667 m .61443 .34121 L .57339 .34074 L p .707 .577 .707 r
F P
0 g
s
.40235 .81068 m .48562 .32522 L .44747 .31169 L p .707 .577 .707 r
F P
0 g
s
.48562 .32522 m .40235 .81068 L .44574 .82069 L p .707 .577 .707 r
F P
0 g
s
.70268 .6872 m .6934 .74095 L .69071 .73001 L p .707 .577 .707 r
F P
0 g
s
.69071 .73001 m .69998 .67626 L .70268 .6872 L p .707 .577 .707 r
F P
0 g
s
.68382 .78812 m .67382 .82262 L .68109 .81292 L p .707 .577 .707 r
F P
0 g
s
.68109 .81292 m .69109 .77842 L .68382 .78812 L p .707 .577 .707 r
F P
0 g
s
.5686 .68658 m .57787 .63283 L .6093 .63676 L p .707 .577 .707 r
F P
0 g
s
.6093 .63676 m .60003 .6905 L .5686 .68658 L p .707 .577 .707 r
F P
0 g
s
.55992 .74275 m .56992 .70825 L .6007 .71504 L p .707 .577 .707 r
F P
0 g
s
.6007 .71504 m .5907 .74954 L .55992 .74275 L p .707 .577 .707 r
F P
0 g
s
.55314 .78688 m .5587 .76987 L .58922 .7775 L p .707 .577 .707 r
F P
0 g
s
.58922 .7775 m .58366 .79451 L .55314 .78688 L p .707 .577 .707 r
F P
0 g
s
.61443 .34121 m .53117 .82667 L .56484 .82206 L p .707 .577 .707 r
F P
0 g
s
.56484 .82206 m .6481 .3366 L .61443 .34121 L p .707 .577 .707 r
F P
0 g
s
.3642 .79715 m .44747 .31169 L .4183 .29597 L p .707 .577 .707 r
F P
0 g
s
.44747 .31169 m .3642 .79715 L .40235 .81068 L p .707 .577 .707 r
F P
0 g
s
.67113 .85449 m .66557 .8715 L .67289 .86166 L p .707 .577 .707 r
F P
0 g
s
.67289 .86166 m .67845 .84465 L .67113 .85449 L p .707 .577 .707 r
F P
0 g
s
.69998 .67626 m .69071 .73001 L .67844 .71839 L p .707 .577 .707 r
F P
0 g
s
.67844 .71839 m .68771 .66464 L .69998 .67626 L p .707 .577 .707 r
F P
0 g
s
.69109 .77842 m .68109 .81292 L .67874 .80053 L p .707 .577 .707 r
F P
0 g
s
.67874 .80053 m .68873 .76603 L .69109 .77842 L p .707 .577 .707 r
F P
0 g
s
.24259 .71396 m .25186 .66021 L .22113 .65309 L p .707 .577 .707 r
F P
0 g
s
.25186 .66021 m .24259 .71396 L .27403 .71789 L p .707 .577 .707 r
F P
0 g
s
.27403 .71789 m .2833 .66414 L .25186 .66021 L p .707 .577 .707 r
F P
0 g
s
.2833 .66414 m .27403 .71789 L .30309 .71824 L p .707 .577 .707 r
F P
0 g
s
.30309 .71824 m .31236 .66449 L .2833 .66414 L p .707 .577 .707 r
F P
0 g
s
.21186 .70684 m .22113 .65309 L .19412 .64348 L p .707 .577 .707 r
F P
0 g
s
.22113 .65309 m .21186 .70684 L .24259 .71396 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64003 .64387 m .63076 .69762 L .60003 .6905 L p .707 .577 .707 r
F P
0 g
s
.60003 .6905 m .6093 .63676 L .64003 .64387 L p .707 .577 .707 r
F P
0 g
s
.6307 .72533 m .6207 .75983 L .5907 .74954 L p .707 .577 .707 r
F P
0 g
s
.5907 .74954 m .6007 .71504 L .6307 .72533 L p .707 .577 .707 r
F P
0 g
s
.61893 .78871 m .61337 .80572 L .58366 .79451 L p .707 .577 .707 r
F P
0 g
s
.58366 .79451 m .58922 .7775 L .61893 .78871 L p .707 .577 .707 r
F P
0 g
s
.6481 .3366 m .56484 .82206 L .58785 .81282 L p .707 .577 .707 r
F P
0 g
s
.58785 .81282 m .67112 .32736 L .6481 .3366 L p .707 .577 .707 r
F P
0 g
s
.34324 .70845 m .35251 .6547 L .33621 .66124 L p .707 .577 .707 r
F P
0 g
s
.35251 .6547 m .34324 .70845 L .3504 .69926 L p .707 .577 .707 r
F P
0 g
s
.3504 .69926 m .35967 .64551 L .35251 .6547 L p .707 .577 .707 r
F P
0 g
s
.33082 .77443 m .34081 .73993 L .32463 .74597 L p .707 .577 .707 r
F P
0 g
s
.34081 .73993 m .33082 .77443 L .33808 .76474 L p .707 .577 .707 r
F P
0 g
s
.33808 .76474 m .34808 .73024 L .34081 .73993 L p .707 .577 .707 r
F P
0 g
s
.35967 .64551 m .3504 .69926 L .3477 .68832 L p .707 .577 .707 r
F P
0 g
s
.3477 .68832 m .35697 .63457 L .35967 .64551 L p .707 .577 .707 r
F P
0 g
s
.34808 .73024 m .33808 .76474 L .33573 .75234 L p .707 .577 .707 r
F P
0 g
s
.33573 .75234 m .34573 .71784 L .34808 .73024 L p .707 .577 .707 r
F P
0 g
s
.33621 .66124 m .32694 .71499 L .34324 .70845 L p .707 .577 .707 r
F P
0 g
s
.35697 .63457 m .3477 .68832 L .33543 .6767 L p .707 .577 .707 r
F P
0 g
s
.33543 .6767 m .3447 .62295 L .35697 .63457 L p .707 .577 .707 r
F P
0 g
s
.34573 .71784 m .33573 .75234 L .32397 .73845 L p .707 .577 .707 r
F P
0 g
s
.32397 .73845 m .33397 .70395 L .34573 .71784 L p .707 .577 .707 r
F P
0 g
s
.33504 .78143 m .4183 .29597 L .40097 .2796 L p .707 .577 .707 r
F P
0 g
s
.4183 .29597 m .33504 .78143 L .3642 .79715 L p .707 .577 .707 r
F P
0 g
s
.31236 .66449 m .30309 .71824 L .32694 .71499 L p .707 .577 .707 r
F P
0 g
s
.32694 .71499 m .33621 .66124 L .31236 .66449 L p .707 .577 .707 r
F P
0 g
s
.67845 .84465 m .67289 .86166 L .67066 .84884 L p .707 .577 .707 r
F P
0 g
s
.67066 .84884 m .67622 .83183 L .67845 .84465 L p .707 .577 .707 r
F P
0 g
s
.18485 .69723 m .19412 .64348 L .17346 .63232 L p .707 .577 .707 r
F P
0 g
s
.19412 .64348 m .18485 .69723 L .21186 .70684 L p .707 .577 .707 r
F P
0 g
s
.68771 .66464 m .67844 .71839 L .65778 .70723 L p .707 .577 .707 r
F P
0 g
s
.65778 .70723 m .66705 .65348 L .68771 .66464 L p .707 .577 .707 r
F P
0 g
s
.68873 .76603 m .67874 .80053 L .66698 .78664 L p .707 .577 .707 r
F P
0 g
s
.66698 .78664 m .67698 .75214 L .68873 .76603 L p .707 .577 .707 r
F P
0 g
s
.2318 .77284 m .2418 .73834 L .2118 .72805 L p .707 .577 .707 r
F P
0 g
s
.2418 .73834 m .2318 .77284 L .26258 .77963 L p .707 .577 .707 r
F P
0 g
s
.26258 .77963 m .27257 .74513 L .2418 .73834 L p .707 .577 .707 r
F P
0 g
s
.2018 .76255 m .2118 .72805 L .18551 .71527 L p .707 .577 .707 r
F P
0 g
s
.2118 .72805 m .2018 .76255 L .2318 .77284 L p .707 .577 .707 r
F P
0 g
s
.27257 .74513 m .26258 .77963 L .29112 .78226 L p .707 .577 .707 r
F P
0 g
s
.29112 .78226 m .30112 .74776 L .27257 .74513 L p .707 .577 .707 r
F P
0 g
s
.17346 .63232 m .16419 .68607 L .18485 .69723 L p .707 .577 .707 r
F P
0 g
s
.16419 .68607 m .17346 .63232 L .16118 .62071 L p .707 .577 .707 r
F P
0 g
s
.17551 .74977 m .18551 .71527 L .16551 .70125 L p .707 .577 .707 r
F P
0 g
s
.18551 .71527 m .17551 .74977 L .2018 .76255 L p .707 .577 .707 r
F P
0 g
s
.66705 .65348 m .65778 .70723 L .63076 .69762 L p .707 .577 .707 r
F P
0 g
s
.63076 .69762 m .64003 .64387 L .66705 .65348 L p .707 .577 .707 r
F P
0 g
s
.30112 .74776 m .29112 .78226 L .31463 .78047 L p .707 .577 .707 r
F P
0 g
s
.31463 .78047 m .32463 .74597 L .30112 .74776 L p .707 .577 .707 r
F P
0 g
s
.22418 .81053 m .22974 .79352 L .20003 .78231 L p .707 .577 .707 r
F P
0 g
s
.22974 .79352 m .22418 .81053 L .25471 .81816 L p .707 .577 .707 r
F P
0 g
s
.25471 .81816 m .26027 .80115 L .22974 .79352 L p .707 .577 .707 r
F P
0 g
s
.67622 .83183 m .67066 .84884 L .65911 .83429 L p .707 .577 .707 r
F P
0 g
s
.65911 .83429 m .66467 .81728 L .67622 .83183 L p .707 .577 .707 r
F P
0 g
s
.67112 .32736 m .58785 .81282 L .59795 .79985 L p .707 .577 .707 r
F P
0 g
s
.59795 .79985 m .68121 .31439 L .67112 .32736 L p .707 .577 .707 r
F P
0 g
s
.19447 .79932 m .20003 .78231 L .17403 .7686 L p .707 .577 .707 r
F P
0 g
s
.20003 .78231 m .19447 .79932 L .22418 .81053 L p .707 .577 .707 r
F P
0 g
s
.67698 .75214 m .66698 .78664 L .64698 .77261 L p .707 .577 .707 r
F P
0 g
s
.64698 .77261 m .65698 .73811 L .67698 .75214 L p .707 .577 .707 r
F P
0 g
s
.26027 .80115 m .25471 .81816 L .28304 .82145 L p .707 .577 .707 r
F P
0 g
s
.28304 .82145 m .2886 .80444 L .26027 .80115 L p .707 .577 .707 r
F P
0 g
s
.3447 .62295 m .33543 .6767 L .31477 .66554 L p .707 .577 .707 r
F P
0 g
s
.31477 .66554 m .32404 .61179 L .3447 .62295 L p .707 .577 .707 r
F P
0 g
s
.32397 .73845 m .30398 .72442 L p .33022 .70651 L .707 .577 .707 r
F P
0 g
s
.33397 .70395 m .32658 .72947 L p .33022 .70651 L .707 .577 .707 r
F P
0 g
s
.32658 .72947 m .32397 .73845 L p .33022 .70651 L .707 .577 .707 r
F P
0 g
s
.30398 .72442 m .31397 .68992 L .33397 .70395 L p .707 .577 .707 r
F P
0 g
s
.32463 .74597 m .31463 .78047 L .33082 .77443 L p .707 .577 .707 r
F P
0 g
s
.3161 .77697 m .29636 .76211 L p .32131 .75999 L .707 .577 .707 r
F P
0 g
s
.32166 .75996 m .32099 .76201 L p .32131 .75999 L .707 .577 .707 r
F P
0 g
s
.32099 .76201 m .3161 .77697 L p .32131 .75999 L .707 .577 .707 r
F P
0 g
s
.29636 .76211 m .30192 .7451 L .32166 .75996 L p .707 .577 .707 r
F P
0 g
s
.3177 .76506 m .34748 .59144 L p .39716 .26417 L .707 .577 .707 r
F P
0 g
s
.34748 .59144 m .3613 .51086 L p .38051 .37871 L .707 .577 .707 r
F P
0 g
s
.34748 .59144 m .38051 .37871 L .39716 .26417 L .707 .577 .707 r
F
.3613 .51086 m .40097 .2796 L .39918 .27237 L p F P
0 g
s
.39918 .27237 m .39716 .26417 L p .3613 .51086 L .707 .577 .707 r
F P
0 g
s
.32765 .79152 m .33321 .77451 L .33544 .78734 L p .707 .577 .707 r
F P
0 g
s
.33321 .77451 m .32765 .79152 L .3161 .77697 L p .707 .577 .707 r
F P
0 g
s
.3161 .77697 m .32166 .75996 L .33321 .77451 L p .707 .577 .707 r
F P
0 g
s
.40097 .2796 m .3177 .76506 L .33504 .78143 L p .707 .577 .707 r
F P
0 g
s
.16551 .70125 m .15551 .73575 L .17551 .74977 L p .707 .577 .707 r
F P
0 g
s
.17403 .7686 m .16847 .78561 L .19447 .79932 L p .707 .577 .707 r
F P
0 g
s
.16118 .62071 m .15191 .67445 L .16419 .68607 L p .707 .577 .707 r
F P
0 g
s
.16847 .78561 m .17403 .7686 L .15429 .75374 L p .707 .577 .707 r
F P
0 g
s
.15551 .73575 m .16551 .70125 L .15376 .68736 L p .707 .577 .707 r
F P
0 g
s
.2886 .80444 m .28304 .82145 L .30643 .82008 L p .707 .577 .707 r
F P
0 g
s
.30643 .82008 m .31199 .80307 L .2886 .80444 L p .707 .577 .707 r
F P
0 g
s
.15191 .67445 m .16118 .62071 L .15849 .60977 L p .707 .577 .707 r
F P
0 g
s
.15429 .75374 m .14873 .77075 L .16847 .78561 L p .707 .577 .707 r
F P
0 g
s
.65698 .73811 m .64698 .77261 L .6207 .75983 L p .707 .577 .707 r
F P
0 g
s
.6207 .75983 m .6307 .72533 L .65698 .73811 L p .707 .577 .707 r
F P
0 g
s
.66467 .81728 m .65911 .83429 L .63937 .81943 L p .707 .577 .707 r
F P
0 g
s
.63937 .81943 m .64493 .80242 L .66467 .81728 L p .707 .577 .707 r
F P
0 g
s
.15376 .68736 m .14376 .72186 L .15551 .73575 L p .707 .577 .707 r
F P
0 g
s
.14873 .77075 m .15429 .75374 L .14274 .73919 L p .707 .577 .707 r
F P
0 g
s
.15849 .60977 m .14922 .66351 L .15191 .67445 L p .707 .577 .707 r
F P
0 g
s
.31199 .80307 m .30643 .82008 L .32257 .81419 L p .707 .577 .707 r
F P
0 g
s
.32257 .81419 m .32813 .79718 L .31199 .80307 L p .707 .577 .707 r
F P
0 g
s
.14376 .72186 m .15376 .68736 L .1514 .67496 L p .707 .577 .707 r
F P
0 g
s
.14274 .73919 m .13718 .7562 L .14873 .77075 L p .707 .577 .707 r
F P
0 g
s
.68121 .31439 m .59795 .79985 L .59414 .78443 L p .707 .577 .707 r
F P
0 g
s
.59414 .78443 m .67741 .29896 L .68121 .31439 L p .707 .577 .707 r
F P
0 g
s
.64493 .80242 m .63937 .81943 L .61337 .80572 L p .707 .577 .707 r
F P
0 g
s
.61337 .80572 m .61893 .78871 L .64493 .80242 L p .707 .577 .707 r
F P
0 g
s
.39716 .26417 m .31389 .74963 L .3177 .76506 L p .707 .577 .707 r
F P
0 g
s
.31389 .74963 m .39716 .26417 L .40726 .2512 L p .707 .577 .707 r
F P
0 g
s
.14922 .66351 m .15849 .60977 L .16564 .60058 L p .707 .577 .707 r
F P
0 g
s
.1514 .67496 m .1414 .70946 L .14376 .72186 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.13718 .7562 m .14274 .73919 L .14051 .72637 L p .707 .577 .707 r
F P
0 g
s
.32813 .79718 m .32257 .81419 L .32988 .80435 L p .707 .577 .707 r
F P
0 g
s
.32988 .80435 m .33544 .78734 L .32813 .79718 L p .707 .577 .707 r
F P
0 g
s
.14051 .72637 m .13495 .74338 L .13718 .7562 L p .707 .577 .707 r
F P
0 g
s
.16564 .60058 m .15637 .65432 L .14922 .66351 L p .707 .577 .707 r
F P
0 g
s
.1414 .70946 m .1514 .67496 L .15867 .66527 L p .707 .577 .707 r
F P
0 g
s
.15637 .65432 m .16564 .60058 L .18194 .59403 L p .707 .577 .707 r
F P
0 g
s
.67741 .29896 m .59414 .78443 L .57681 .76805 L p .707 .577 .707 r
F P
0 g
s
.57681 .76805 m .66007 .28259 L .67741 .29896 L p .707 .577 .707 r
F P
0 g
s
.15867 .66527 m .14867 .69976 L .1414 .70946 L p .707 .577 .707 r
F P
0 g
s
.32399 .73666 m .40726 .2512 L .43027 .24196 L p .707 .577 .707 r
F P
0 g
s
.40726 .2512 m .32399 .73666 L .31389 .74963 L p .707 .577 .707 r
F P
0 g
s
.13495 .74338 m .14051 .72637 L .14783 .71653 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.33544 .78734 m .32988 .80435 L .32765 .79152 L p .707 .577 .707 r
F P
0 g
s
.14783 .71653 m .14227 .73354 L .13495 .74338 L p .707 .577 .707 r
F P
0 g
s
.18194 .59403 m .17267 .64778 L .15637 .65432 L p .707 .577 .707 r
F P
0 g
s
.14867 .69976 m .15867 .66527 L .17485 .65923 L p .707 .577 .707 r
F P
0 g
s
.17267 .64778 m .18194 .59403 L .20579 .59078 L p .707 .577 .707 r
F P
0 g
s
.17485 .65923 m .16485 .69373 L .14867 .69976 L p .707 .577 .707 r
F P
0 g
s
.14227 .73354 m .14783 .71653 L .16396 .71064 L p .707 .577 .707 r
F P
0 g
s
.66007 .28259 m .57681 .76805 L .54764 .75233 L p .707 .577 .707 r
F P
0 g
s
.54764 .75233 m .63091 .26687 L .66007 .28259 L p .707 .577 .707 r
F P
0 g
s
.20579 .59078 m .19652 .64453 L .17267 .64778 L p .707 .577 .707 r
F P
0 g
s
.32404 .61179 m .31477 .66554 L .28775 .65593 L p .707 .577 .707 r
F P
0 g
s
.28775 .65593 m .29702 .60218 L .32404 .61179 L p .707 .577 .707 r
F P
0 g
s
.43027 .24196 m .347 .72742 L .32399 .73666 L p .707 .577 .707 r
F P
0 g
s
.347 .72742 m .43027 .24196 L .46394 .23735 L p .707 .577 .707 r
F P
0 g
s
.16396 .71064 m .1584 .72765 L .14227 .73354 L p .707 .577 .707 r
F P
0 g
s
.19652 .64453 m .20579 .59078 L .23486 .59114 L p .707 .577 .707 r
F P
0 g
s
.16485 .69373 m .17485 .65923 L .19837 .65743 L p .707 .577 .707 r
F P
0 g
s
.29702 .60218 m .28775 .65593 L .25702 .64881 L p .707 .577 .707 r
F P
0 g
s
.25702 .64881 m .26629 .59507 L .29702 .60218 L p .707 .577 .707 r
F P
0 g
s
.22559 .64489 m .23486 .59114 L .26629 .59507 L p .707 .577 .707 r
F P
0 g
s
.23486 .59114 m .22559 .64489 L .19652 .64453 L p .707 .577 .707 r
F P
0 g
s
.19837 .65743 m .18837 .69193 L .16485 .69373 L p .707 .577 .707 r
F P
0 g
s
.26629 .59507 m .25702 .64881 L .22559 .64489 L p .707 .577 .707 r
F P
0 g
s
.1584 .72765 m .16396 .71064 L .18735 .70927 L p .707 .577 .707 r
F P
0 g
s
.18837 .69193 m .19837 .65743 L .22691 .66006 L p .707 .577 .707 r
F P
0 g
s
.7228 .66361 m .73208 .60986 L .70135 .60274 L p .707 .577 .707 r
F P
0 g
s
.73208 .60986 m .7228 .66361 L .75424 .66754 L p .707 .577 .707 r
F P
0 g
s
.75424 .66754 m .76351 .61379 L .73208 .60986 L p .707 .577 .707 r
F P
0 g
s
.31397 .68992 m .30398 .72442 L .27769 .71164 L p .707 .577 .707 r
F P
0 g
s
.27769 .71164 m .28769 .67714 L .31397 .68992 L p .707 .577 .707 r
F P
0 g
s
.18735 .70927 m .18179 .72628 L .1584 .72765 L p .707 .577 .707 r
F P
0 g
s
.63091 .26687 m .54764 .75233 L .50949 .73881 L p .707 .577 .707 r
F P
0 g
s
.50949 .73881 m .59276 .25334 L .63091 .26687 L p .707 .577 .707 r
F P
0 g
s
.76351 .61379 m .75424 .66754 L .78331 .66789 L p .707 .577 .707 r
F P
0 g
s
.78331 .66789 m .79258 .61414 L .76351 .61379 L p .707 .577 .707 r
F P
0 g
s
.38068 .72281 m .46394 .23735 L .50498 .23783 L p .707 .577 .707 r
F P
0 g
s
.38068 .72281 m .347 .72742 L p .43632 .35311 L .707 .577 .707 r
F P
0 g
s
.42428 .46861 m .38068 .72281 L p .43632 .35311 L .707 .577 .707 r
F P
0 g
s
.50498 .23783 m .42172 .72329 L .38068 .72281 L p .707 .577 .707 r
F P
0 g
s
.39978 .68759 m .40238 .67862 L p .379 .6463 L .707 .577 .707 r
F P
0 g
s
.40238 .67862 m .40978 .6531 L .40515 .65207 L p .707 .577 .707 r
F P
0 g
s
.40515 .65207 m .379 .6463 L p .40238 .67862 L .707 .577 .707 r
F P
0 g
s
.46394 .23735 m .42428 .46861 L p .43632 .35311 L .707 .577 .707 r
F P
0 g
s
.69207 .65649 m .70135 .60274 L .67433 .59314 L p .707 .577 .707 r
F P
0 g
s
.70135 .60274 m .69207 .65649 L .7228 .66361 L p .707 .577 .707 r
F P
0 g
s
.22691 .66006 m .21691 .69456 L .18837 .69193 L p .707 .577 .707 r
F P
0 g
s
.21691 .69456 m .22691 .66006 L .25769 .66685 L p .707 .577 .707 r
F P
0 g
s
.28769 .67714 m .27769 .71164 L .24769 .70135 L p .707 .577 .707 r
F P
0 g
s
.24769 .70135 m .25769 .66685 L .28769 .67714 L p .707 .577 .707 r
F P
0 g
s
.18179 .72628 m .18735 .70927 L .21569 .71256 L p .707 .577 .707 r
F P
0 g
s
.25769 .66685 m .24769 .70135 L .21691 .69456 L p .707 .577 .707 r
F P
0 g
s
.79258 .61414 m .78331 .66789 L .80716 .66464 L p .707 .577 .707 r
F P
0 g
s
.80716 .66464 m .81643 .61089 L .79258 .61414 L p .707 .577 .707 r
F P
0 g
s
.66506 .64688 m .67433 .59314 L .65367 .58198 L p .707 .577 .707 r
F P
0 g
s
.67433 .59314 m .66506 .64688 L .69207 .65649 L p .707 .577 .707 r
F P
0 g
s
.30192 .7451 m .29636 .76211 L .27036 .74841 L p .707 .577 .707 r
F P
0 g
s
.27036 .74841 m .27592 .7314 L .30192 .7451 L p .707 .577 .707 r
F P
0 g
s
.59276 .25334 m .50949 .73881 L .4661 .7288 L p .707 .577 .707 r
F P
0 g
s
.4661 .7288 m .54937 .24334 L .59276 .25334 L p .707 .577 .707 r
F P
0 g
s
.40978 .6531 m .39978 .68759 L .40566 .68814 L p .707 .577 .707 r
F P
0 g
s
.44416 .63889 m .441 .61086 L .46638 .55535 L .707 .577 .707 r
F
.42172 .72329 m .43257 .66002 L p .44416 .63889 L F P
0 g
s
.43257 .66002 m .441 .61086 L p .44416 .63889 L .707 .577 .707 r
F P
0 g
s
.54937 .24334 m .4661 .7288 L .42172 .72329 L p .707 .577 .707 r
F P
0 g
s
.42025 .72941 m .42581 .7124 L .40514 .71 L p .707 .577 .707 r
F P
0 g
s
.40514 .71 m .39747 .70911 L p .40295 .71399 L .707 .577 .707 r
F P
0 g
s
.42025 .72941 m .40514 .71 L .40295 .71399 L .707 .577 .707 r
F
.40566 .68814 m .42832 .69022 L p .416 .66554 L F P
0 g
s
.416 .66554 m .40978 .6531 L .40566 .68814 L .707 .577 .707 r
F
.50498 .23783 m .54937 .24334 L p .46638 .55535 L F P
0 g
s
.441 .61086 m .50498 .23783 L p .46638 .55535 L .707 .577 .707 r
F P
0 g
s
.21569 .71256 m .21013 .72957 L .18179 .72628 L p .707 .577 .707 r
F P
0 g
s
.71201 .72899 m .72201 .69449 L .69201 .6842 L p .707 .577 .707 r
F P
0 g
s
.72201 .69449 m .71201 .72899 L .74279 .73578 L p .707 .577 .707 r
F P
0 g
s
.74279 .73578 m .75279 .70128 L .72201 .69449 L p .707 .577 .707 r
F P
0 g
s
.21013 .72957 m .21569 .71256 L .24621 .72018 L p .707 .577 .707 r
F P
0 g
s
.68201 .7187 m .69201 .6842 L .66572 .67142 L p .707 .577 .707 r
F P
0 g
s
.69201 .6842 m .68201 .7187 L .71201 .72899 L p .707 .577 .707 r
F P
0 g
s
.75279 .70128 m .74279 .73578 L .77133 .73841 L p .707 .577 .707 r
F P
0 g
s
.77133 .73841 m .78133 .70391 L .75279 .70128 L p .707 .577 .707 r
F P
0 g
s
.27592 .7314 m .27036 .74841 L .24065 .73719 L p .707 .577 .707 r
F P
0 g
s
.24065 .73719 m .24621 .72018 L .27592 .7314 L p .707 .577 .707 r
F P
0 g
s
.24621 .72018 m .24065 .73719 L .21013 .72957 L p .707 .577 .707 r
F P
0 g
s
.65367 .58198 m .6444 .63572 L .66506 .64688 L p .707 .577 .707 r
F P
0 g
s
.81643 .61089 m .80716 .66464 L .82346 .6581 L p .707 .577 .707 r
F P
0 g
s
.82346 .6581 m .83273 .60435 L .81643 .61089 L p .707 .577 .707 r
F P
0 g
s
.6444 .63572 m .65367 .58198 L .6414 .57036 L p .707 .577 .707 r
F P
0 g
s
.65572 .70592 m .66572 .67142 L .64573 .6574 L p .707 .577 .707 r
F P
0 g
s
.66572 .67142 m .65572 .70592 L .68201 .7187 L p .707 .577 .707 r
F P
0 g
s
.78133 .70391 m .77133 .73841 L .79485 .73662 L p .707 .577 .707 r
F P
0 g
s
.79485 .73662 m .80484 .70212 L .78133 .70391 L p .707 .577 .707 r
F P
0 g
s
.7044 .77581 m .70996 .7588 L .68024 .74759 L p .707 .577 .707 r
F P
0 g
s
.70996 .7588 m .7044 .77581 L .73492 .78344 L p .707 .577 .707 r
F P
0 g
s
.73492 .78344 m .74048 .76643 L .70996 .7588 L p .707 .577 .707 r
F P
0 g
s
.67468 .7646 m .68024 .74759 L .65424 .73388 L p .707 .577 .707 r
F P
0 g
s
.68024 .74759 m .67468 .7646 L .7044 .77581 L p .707 .577 .707 r
F P
0 g
s
.74048 .76643 m .73492 .78344 L .76326 .78673 L p .707 .577 .707 r
F P
0 g
s
.76326 .78673 m .76882 .76972 L .74048 .76643 L p .707 .577 .707 r
F P
0 g
s
.64573 .6574 m .63573 .6919 L .65572 .70592 L p .707 .577 .707 r
F P
0 g
s
.6414 .57036 m .63213 .62411 L .6444 .63572 L p .707 .577 .707 r
F P
0 g
s
.65424 .73388 m .64868 .75089 L .67468 .7646 L p .707 .577 .707 r
F P
0 g
s
.83273 .60435 m .82346 .6581 L .83061 .64891 L p .707 .577 .707 r
F P
0 g
s
.83061 .64891 m .83988 .59516 L .83273 .60435 L p .707 .577 .707 r
F P
0 g
s
.63573 .6919 m .64573 .6574 L .63397 .64351 L p .707 .577 .707 r
F P
0 g
s
.64868 .75089 m .65424 .73388 L .6345 .71902 L p .707 .577 .707 r
F P
0 g
s
.63213 .62411 m .6414 .57036 L .6387 .55942 L p .707 .577 .707 r
F P
0 g
s
.80484 .70212 m .79485 .73662 L .81103 .73058 L p .707 .577 .707 r
F P
0 g
s
.81103 .73058 m .82103 .69608 L .80484 .70212 L p .707 .577 .707 r
F P
0 g
s
.76882 .76972 m .76326 .78673 L .78664 .78536 L p .707 .577 .707 r
F P
0 g
s
.78664 .78536 m .7922 .76835 L .76882 .76972 L p .707 .577 .707 r
F P
0 g
s
.6345 .71902 m .62894 .73603 L .64868 .75089 L p .707 .577 .707 r
F P
0 g
s
.63397 .64351 m .62397 .67801 L .63573 .6919 L p .707 .577 .707 r
F P
0 g
s
.6387 .55942 m .62943 .61317 L .63213 .62411 L p .707 .577 .707 r
F P
0 g
s
.62894 .73603 m .6345 .71902 L .62295 .70447 L p .707 .577 .707 r
F P
0 g
s
.62397 .67801 m .63397 .64351 L .63162 .63111 L p .707 .577 .707 r
F P
0 g
s
.7922 .76835 m .78664 .78536 L .80278 .77946 L p .707 .577 .707 r
F P
0 g
s
.80278 .77946 m .80834 .76245 L .7922 .76835 L p .707 .577 .707 r
F P
0 g
s
.62295 .70447 m .61739 .72148 L .62894 .73603 L p .707 .577 .707 r
F P
0 g
s
.83988 .59516 m .83061 .64891 L .82792 .63797 L p .707 .577 .707 r
F P
0 g
s
.82792 .63797 m .83719 .58422 L .83988 .59516 L p .707 .577 .707 r
F P
0 g
s
.82103 .69608 m .81103 .73058 L .8183 .72089 L p .707 .577 .707 r
F P
0 g
s
.8183 .72089 m .8283 .68639 L .82103 .69608 L p .707 .577 .707 r
F P
0 g
s
.62943 .61317 m .6387 .55942 L .64586 .55023 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63162 .63111 m .62162 .66561 L .62397 .67801 L p .707 .577 .707 r
F P
0 g
s
.61739 .72148 m .62295 .70447 L .62073 .69165 L p .707 .577 .707 r
F P
0 g
s
.64586 .55023 m .63659 .60398 L .62943 .61317 L p .707 .577 .707 r
F P
0 g
s
.80834 .76245 m .80278 .77946 L .81009 .76962 L p .707 .577 .707 r
F P
0 g
s
.81009 .76962 m .81565 .75261 L .80834 .76245 L p .707 .577 .707 r
F P
0 g
s
.62073 .69165 m .61517 .70866 L .61739 .72148 L p .707 .577 .707 r
F P
0 g
s
.62162 .66561 m .63162 .63111 L .63888 .62142 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83719 .58422 m .82792 .63797 L .81564 .62635 L p .707 .577 .707 r
F P
0 g
s
.81564 .62635 m .82491 .5726 L .83719 .58422 L p .707 .577 .707 r
F P
0 g
s
.8283 .68639 m .8183 .72089 L .81594 .70849 L p .707 .577 .707 r
F P
0 g
s
.81594 .70849 m .82594 .67399 L .8283 .68639 L p .707 .577 .707 r
F P
0 g
s
.63659 .60398 m .64586 .55023 L .66216 .54369 L p .707 .577 .707 r
F P
0 g
s
.37979 .62192 m .38907 .56817 L .35834 .56105 L p .707 .577 .707 r
F P
0 g
s
.38907 .56817 m .37979 .62192 L .41123 .62585 L p .707 .577 .707 r
F P
0 g
s
.41123 .62585 m .4205 .5721 L .38907 .56817 L p .707 .577 .707 r
F P
0 g
s
.63888 .62142 m .62888 .65592 L .62162 .66561 L p .707 .577 .707 r
F P
0 g
s
.4205 .5721 m .41123 .62585 L .4403 .6262 L p .707 .577 .707 r
F P
0 g
s
.4403 .6262 m .44957 .57245 L .4205 .5721 L p .707 .577 .707 r
F P
0 g
s
.34906 .6148 m .35834 .56105 L .33132 .55145 L p .707 .577 .707 r
F P
0 g
s
.35834 .56105 m .34906 .6148 L .37979 .62192 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.61517 .70866 m .62073 .69165 L .62804 .68181 L p .707 .577 .707 r
F P
0 g
s
.66216 .54369 m .65289 .59743 L .63659 .60398 L p .707 .577 .707 r
F P
0 g
s
.44957 .57245 m .4403 .6262 L .46415 .62295 L p .707 .577 .707 r
F P
0 g
s
.46415 .62295 m .47342 .5692 L .44957 .57245 L p .707 .577 .707 r
F P
0 g
s
.81565 .75261 m .81009 .76962 L .80787 .7568 L p .707 .577 .707 r
F P
0 g
s
.80787 .7568 m .81343 .73979 L .81565 .75261 L p .707 .577 .707 r
F P
0 g
s
.62804 .68181 m .62248 .69882 L .61517 .70866 L p .707 .577 .707 r
F P
0 g
s
.32205 .60519 m .33132 .55145 L .31066 .54029 L p .707 .577 .707 r
F P
0 g
s
.33132 .55145 m .32205 .60519 L .34906 .6148 L p .707 .577 .707 r
F P
0 g
s
.62888 .65592 m .63888 .62142 L .65507 .61538 L p .707 .577 .707 r
F P
0 g
s
.82491 .5726 m .81564 .62635 L .79498 .61519 L p .707 .577 .707 r
F P
0 g
s
.79498 .61519 m .80425 .56144 L .82491 .5726 L p .707 .577 .707 r
F P
0 g
s
.65289 .59743 m .66216 .54369 L .68601 .54043 L p .707 .577 .707 r
F P
0 g
s
.82594 .67399 m .81594 .70849 L .80419 .6946 L p .707 .577 .707 r
F P
0 g
s
.80419 .6946 m .81419 .6601 L .82594 .67399 L p .707 .577 .707 r
F P
0 g
s
.369 .6808 m .379 .6463 L .349 .63601 L p .707 .577 .707 r
F P
0 g
s
.379 .6463 m .369 .6808 L .39978 .68759 L p .707 .577 .707 r
F P
0 g
s
.339 .67051 m .349 .63601 L .32271 .62323 L p .707 .577 .707 r
F P
0 g
s
.349 .63601 m .339 .67051 L .369 .6808 L p .707 .577 .707 r
F P
0 g
s
.42832 .69022 m .43832 .65572 L .40978 .6531 L p .707 .577 .707 r
F P
0 g
s
.65507 .61538 m .64507 .64988 L .62888 .65592 L p .707 .577 .707 r
F P
0 g
s
.31066 .54029 m .30139 .59403 L .32205 .60519 L p .707 .577 .707 r
F P
0 g
s
.47342 .5692 m .46415 .62295 L .48045 .61641 L p .707 .577 .707 r
F P
0 g
s
.48045 .61641 m .48972 .56266 L .47342 .5692 L p .707 .577 .707 r
F P
0 g
s
.30139 .59403 m .31066 .54029 L .29839 .52867 L p .707 .577 .707 r
F P
0 g
s
.62248 .69882 m .62804 .68181 L .64418 .67591 L p .707 .577 .707 r
F P
0 g
s
.68601 .54043 m .67674 .59418 L .65289 .59743 L p .707 .577 .707 r
F P
0 g
s
.31271 .65773 m .32271 .62323 L .30272 .60921 L p .707 .577 .707 r
F P
0 g
s
.32271 .62323 m .31271 .65773 L .339 .67051 L p .707 .577 .707 r
F P
0 g
s
.80425 .56144 m .79498 .61519 L .76797 .60558 L p .707 .577 .707 r
F P
0 g
s
.76797 .60558 m .77724 .55183 L .80425 .56144 L p .707 .577 .707 r
F P
0 g
s
.67674 .59418 m .68601 .54043 L .71507 .54079 L p .707 .577 .707 r
F P
0 g
s
.43832 .65572 m .42832 .69022 L .45184 .68843 L p .707 .577 .707 r
F P
0 g
s
.45184 .68843 m .46183 .65393 L .43832 .65572 L p .707 .577 .707 r
F P
0 g
s
.36139 .71849 m .36695 .70148 L .33723 .69027 L p .707 .577 .707 r
F P
0 g
s
.36695 .70148 m .36139 .71849 L .39191 .72612 L p .707 .577 .707 r
F P
0 g
s
.39191 .72612 m .39747 .70911 L .36695 .70148 L p .707 .577 .707 r
F P
0 g
s
.64507 .64988 m .65507 .61538 L .67858 .61358 L p .707 .577 .707 r
F P
0 g
s
.81343 .73979 m .80787 .7568 L .79632 .74225 L p .707 .577 .707 r
F P
0 g
s
.79632 .74225 m .80188 .72524 L .81343 .73979 L p .707 .577 .707 r
F P
0 g
s
.64418 .67591 m .63862 .69292 L .62248 .69882 L p .707 .577 .707 r
F P
0 g
s
.33167 .70728 m .33723 .69027 L .31123 .67656 L p .707 .577 .707 r
F P
0 g
s
.33723 .69027 m .33167 .70728 L .36139 .71849 L p .707 .577 .707 r
F P
0 g
s
.81419 .6601 m .80419 .6946 L .78419 .68057 L p .707 .577 .707 r
F P
0 g
s
.78419 .68057 m .79419 .64607 L .81419 .6601 L p .707 .577 .707 r
F P
0 g
s
.39747 .70911 m .39191 .72612 L .42025 .72941 L p .707 .577 .707 r
F P
0 g
s
.30272 .60921 m .29272 .64371 L .31271 .65773 L p .707 .577 .707 r
F P
0 g
s
.31123 .67656 m .30567 .69357 L .33167 .70728 L p .707 .577 .707 r
F P
0 g
s
.77724 .55183 m .76797 .60558 L .73724 .59847 L p .707 .577 .707 r
F P
0 g
s
.73724 .59847 m .74651 .54472 L .77724 .55183 L p .707 .577 .707 r
F P
0 g
s
.7058 .59454 m .71507 .54079 L .74651 .54472 L p .707 .577 .707 r
F P
0 g
s
.71507 .54079 m .7058 .59454 L .67674 .59418 L p .707 .577 .707 r
F P
0 g
s
.29839 .52867 m .28912 .58242 L .30139 .59403 L p .707 .577 .707 r
F P
0 g
s
.67858 .61358 m .66858 .64808 L .64507 .64988 L p .707 .577 .707 r
F P
0 g
s
.74651 .54472 m .73724 .59847 L .7058 .59454 L p .707 .577 .707 r
F P
0 g
s
.30567 .69357 m .31123 .67656 L .29149 .66171 L p .707 .577 .707 r
F P
0 g
s
.29272 .64371 m .30272 .60921 L .29096 .59532 L p .707 .577 .707 r
F P
0 g
s
.48972 .56266 m .48045 .61641 L .4876 .60722 L p .707 .577 .707 r
F P
0 g
s
.4876 .60722 m .49687 .55347 L .48972 .56266 L p .707 .577 .707 r
F P
0 g
s
.42581 .7124 m .42025 .72941 L .44363 .72804 L p .707 .577 .707 r
F P
0 g
s
.44363 .72804 m .44919 .71103 L .42581 .7124 L p .707 .577 .707 r
F P
0 g
s
.46183 .65393 m .45184 .68843 L .46802 .68239 L p .707 .577 .707 r
F P
0 g
s
.46802 .68239 m .47802 .64789 L .46183 .65393 L p .707 .577 .707 r
F P
0 g
s
.63862 .69292 m .64418 .67591 L .66756 .67455 L p .707 .577 .707 r
F P
0 g
s
.28912 .58242 m .29839 .52867 L .29569 .51773 L p .707 .577 .707 r
F P
0 g
s
.66858 .64808 m .67858 .61358 L .70712 .61621 L p .707 .577 .707 r
F P
0 g
s
.29149 .66171 m .28593 .67872 L .30567 .69357 L p .707 .577 .707 r
F P
0 g
s
.79419 .64607 m .78419 .68057 L .7579 .66779 L p .707 .577 .707 r
F P
0 g
s
.7579 .66779 m .7679 .63329 L .79419 .64607 L p .707 .577 .707 r
F P
0 g
s
.80188 .72524 m .79632 .74225 L .77658 .72739 L p .707 .577 .707 r
F P
0 g
s
.77658 .72739 m .78214 .71038 L .80188 .72524 L p .707 .577 .707 r
F P
0 g
s
.66756 .67455 m .662 .69156 L .63862 .69292 L p .707 .577 .707 r
F P
0 g
s
.29096 .59532 m .28096 .62982 L .29272 .64371 L p .707 .577 .707 r
F P
0 g
s
.70712 .61621 m .69713 .65071 L .66858 .64808 L p .707 .577 .707 r
F P
0 g
s
.69713 .65071 m .70712 .61621 L .7379 .623 L p .707 .577 .707 r
F P
0 g
s
.28593 .67872 m .29149 .66171 L .27994 .64715 L p .707 .577 .707 r
F P
0 g
s
.7679 .63329 m .7579 .66779 L .7279 .6575 L p .707 .577 .707 r
F P
0 g
s
.7279 .6575 m .7379 .623 L .7679 .63329 L p .707 .577 .707 r
F P
0 g
s
.29569 .51773 m .28642 .57148 L .28912 .58242 L p .707 .577 .707 r
F P
0 g
s
.7379 .623 m .7279 .6575 L .69713 .65071 L p .707 .577 .707 r
F P
0 g
s
.44919 .71103 m .44363 .72804 L .45977 .72215 L p .707 .577 .707 r
F P
0 g
s
.45977 .72215 m .46533 .70514 L .44919 .71103 L p .707 .577 .707 r
F P
0 g
s
.662 .69156 m .66756 .67455 L .6959 .67784 L p .707 .577 .707 r
F P
0 g
s
.28096 .62982 m .29096 .59532 L .2886 .58292 L p .707 .577 .707 r
F P
0 g
s
.27994 .64715 m .27438 .66416 L .28593 .67872 L p .707 .577 .707 r
F P
0 g
s
.78214 .71038 m .77658 .72739 L .75058 .71369 L p .707 .577 .707 r
F P
0 g
s
.75058 .71369 m .75614 .69668 L .78214 .71038 L p .707 .577 .707 r
F P
0 g
s
.47802 .64789 m .46802 .68239 L .47529 .6727 L p .707 .577 .707 r
F P
0 g
s
.47529 .6727 m .48529 .6382 L .47802 .64789 L p .707 .577 .707 r
F P
0 g
s
.49687 .55347 m .4876 .60722 L .48491 .59628 L p .707 .577 .707 r
F P
0 g
s
.48491 .59628 m .49418 .54253 L .49687 .55347 L p .707 .577 .707 r
F P
0 g
s
.6959 .67784 m .69034 .69485 L .662 .69156 L p .707 .577 .707 r
F P
0 g
s
.28642 .57148 m .29569 .51773 L .30285 .50854 L p .707 .577 .707 r
F P
0 g
s
.2886 .58292 m .27861 .61742 L .28096 .62982 L p .707 .577 .707 r
F P
0 g
s
.69034 .69485 m .6959 .67784 L .72642 .68546 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.75614 .69668 m .75058 .71369 L .72086 .70247 L p .707 .577 .707 r
F P
0 g
s
.72086 .70247 m .72642 .68546 L .75614 .69668 L p .707 .577 .707 r
F P
0 g
s
.27438 .66416 m .27994 .64715 L .27772 .63433 L p .707 .577 .707 r
F P
0 g
s
.72642 .68546 m .72086 .70247 L .69034 .69485 L p .707 .577 .707 r
F P
0 g
s
.46533 .70514 m .45977 .72215 L .46708 .71231 L p .707 .577 .707 r
F P
0 g
s
.46708 .71231 m .47264 .6953 L .46533 .70514 L p .707 .577 .707 r
F P
0 g
s
.27772 .63433 m .27215 .65134 L .27438 .66416 L p .707 .577 .707 r
F P
0 g
s
.30285 .50854 m .29358 .56229 L .28642 .57148 L p .707 .577 .707 r
F P
0 g
s
.27861 .61742 m .2886 .58292 L .29587 .57323 L p .707 .577 .707 r
F P
0 g
s
.48529 .6382 m .47529 .6727 L .47293 .6603 L p .707 .577 .707 r
F P
0 g
s
.47293 .6603 m .48293 .6258 L .48529 .6382 L p .707 .577 .707 r
F P
0 g
s
.49418 .54253 m .48491 .59628 L .47263 .58466 L p .707 .577 .707 r
F P
0 g
s
.47263 .58466 m .4819 .53091 L .49418 .54253 L p .707 .577 .707 r
F P
0 g
s
.29358 .56229 m .30285 .50854 L .31915 .50199 L p .707 .577 .707 r
F P
0 g
s
.29587 .57323 m .28587 .60773 L .27861 .61742 L p .707 .577 .707 r
F P
0 g
s
.27215 .65134 m .27772 .63433 L .28503 .62449 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47264 .6953 m .46708 .71231 L .46486 .69948 L p .707 .577 .707 r
F P
0 g
s
.46486 .69948 m .47042 .68247 L .47264 .6953 L p .707 .577 .707 r
F P
0 g
s
.28503 .62449 m .27947 .6415 L .27215 .65134 L p .707 .577 .707 r
F P
0 g
s
.31915 .50199 m .30988 .55574 L .29358 .56229 L p .707 .577 .707 r
F P
0 g
s
.28587 .60773 m .29587 .57323 L .31206 .56719 L p .707 .577 .707 r
F P
0 g
s
.4819 .53091 m .47263 .58466 L .45197 .5735 L p .707 .577 .707 r
F P
0 g
s
.45197 .5735 m .46124 .51975 L .4819 .53091 L p .707 .577 .707 r
F P
0 g
s
.48293 .6258 m .47293 .6603 L .46118 .64641 L p .707 .577 .707 r
F P
0 g
s
.46118 .64641 m .47118 .61191 L .48293 .6258 L p .707 .577 .707 r
F P
0 g
s
.30988 .55574 m .31915 .50199 L .343 .49874 L p .707 .577 .707 r
F P
0 g
s
.31206 .56719 m .30206 .60169 L .28587 .60773 L p .707 .577 .707 r
F P
0 g
s
.27947 .6415 m .28503 .62449 L .30117 .6186 L p .707 .577 .707 r
F P
0 g
s
.343 .49874 m .33372 .55249 L .30988 .55574 L p .707 .577 .707 r
F P
0 g
s
.46124 .51975 m .45197 .5735 L .42496 .56389 L p .707 .577 .707 r
F P
0 g
s
.42496 .56389 m .43423 .51014 L .46124 .51975 L p .707 .577 .707 r
F P
0 g
s
.47042 .68247 m .46486 .69948 L .45331 .68493 L p .707 .577 .707 r
F P
0 g
s
.45331 .68493 m .45887 .66792 L .47042 .68247 L p .707 .577 .707 r
F P
0 g
s
.30117 .6186 m .29561 .63561 L .27947 .6415 L p .707 .577 .707 r
F P
0 g
s
.33372 .55249 m .343 .49874 L .37206 .4991 L p .707 .577 .707 r
F P
0 g
s
.30206 .60169 m .31206 .56719 L .33557 .56539 L p .707 .577 .707 r
F P
0 g
s
.47118 .61191 m .46118 .64641 L .44118 .63238 L p .707 .577 .707 r
F P
0 g
s
.44118 .63238 m .45118 .59789 L .47118 .61191 L p .707 .577 .707 r
F P
0 g
s
.43423 .51014 m .42496 .56389 L .39423 .55678 L p .707 .577 .707 r
F P
0 g
s
.39423 .55678 m .4035 .50303 L .43423 .51014 L p .707 .577 .707 r
F P
0 g
s
.36279 .55285 m .37206 .4991 L .4035 .50303 L p .707 .577 .707 r
F P
0 g
s
.37206 .4991 m .36279 .55285 L .33372 .55249 L p .707 .577 .707 r
F P
0 g
s
.33557 .56539 m .32557 .59989 L .30206 .60169 L p .707 .577 .707 r
F P
0 g
s
.4035 .50303 m .39423 .55678 L .36279 .55285 L p .707 .577 .707 r
F P
0 g
s
.29561 .63561 m .30117 .6186 L .32455 .61723 L p .707 .577 .707 r
F P
0 g
s
.32557 .59989 m .33557 .56539 L .36411 .56802 L p .707 .577 .707 r
F P
0 g
s
.45118 .59789 m .44118 .63238 L .41489 .6196 L p .707 .577 .707 r
F P
0 g
s
.41489 .6196 m .42489 .5851 L .45118 .59789 L p .707 .577 .707 r
F P
0 g
s
.45887 .66792 m .45331 .68493 L .43357 .67007 L p .707 .577 .707 r
F P
0 g
s
.43357 .67007 m .43913 .65307 L .45887 .66792 L p .707 .577 .707 r
F P
0 g
s
.32455 .61723 m .31899 .63424 L .29561 .63561 L p .707 .577 .707 r
F P
0 g
s
.36411 .56802 m .35411 .60252 L .32557 .59989 L p .707 .577 .707 r
F P
0 g
s
.35411 .60252 m .36411 .56802 L .39489 .57481 L p .707 .577 .707 r
F P
0 g
s
.42489 .5851 m .41489 .6196 L .38489 .60931 L p .707 .577 .707 r
F P
0 g
s
.38489 .60931 m .39489 .57481 L .42489 .5851 L p .707 .577 .707 r
F P
0 g
s
.31899 .63424 m .32455 .61723 L .35289 .62052 L p .707 .577 .707 r
F P
0 g
s
.39489 .57481 m .38489 .60931 L .35411 .60252 L p .707 .577 .707 r
F P
0 g
s
.43913 .65307 m .43357 .67007 L .40757 .65637 L p .707 .577 .707 r
F P
0 g
s
.40757 .65637 m .41313 .63936 L .43913 .65307 L p .707 .577 .707 r
F P
0 g
s
.35289 .62052 m .34733 .63753 L .31899 .63424 L p .707 .577 .707 r
F P
0 g
s
.34733 .63753 m .35289 .62052 L .38341 .62814 L p .707 .577 .707 r
F P
0 g
s
.41313 .63936 m .40757 .65637 L .37785 .64515 L p .707 .577 .707 r
F P
0 g
s
.37785 .64515 m .38341 .62814 L .41313 .63936 L p .707 .577 .707 r
F P
0 g
s
.38341 .62814 m .37785 .64515 L .34733 .63753 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo001oOolD002:Ool007Uoo`H0
00AJEP03001JEUYF00UJEP04001JEUYFFUH60024Ool007Moo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00MJEPD007moo`00MGoo0P000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<0
05YFFUH02eYF00<005YF00000`00Ngoo001cOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0;FUH00`00FUIJEP03FUH4001gOol0079oo`8000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF01EJEP@007=oo`00LGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF00000`00Kgoo001aOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH4001[Ool0
071oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
01AJEP8006Uoo`00L7oo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2eYF00<005YFFUH02EYF00<005YFFUH02EYF0`00Igoo001`Ool00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH01000FUIJEP00
IWoo001_Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH03EYF0P00I7oo001_Ool01000FUIJEP001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
HWoo001_Ool00`00FUH00006FUH00`00FUIJEP05FUH00goo001JEP0:FUH00`00FUIJEP09FUH00goo
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00Oomoo`1OOol006moo`03001JEP0000IJ
EP03001JEUYF00EJEP03Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00IJEP80061oo`00Kgoo00<005YF00001UYF00<005YFFUH01EYF00<005YFFUH02EYF
00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF0000Ggoo
001_Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00Oomoo`1LOol006ioo`04001JEUYF0005FUH0
0`00FUIJEP05FUH00goo001JEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00Oomoo`1KOol006ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00goo001J
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00Oomoo`1JOol006ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001oogoo05Yoo`00KWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<007ooOol0
FWoo001^Ool00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00Oomoo`1IOol006io
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00EJEP03001oogoo05Uoo`00KGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005]oo`00KGoo00@005YFFUH000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03OomJEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0005]oo`00KGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YFOol0Fgoo001]Ool00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUIoo`1KOol006eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00EJEUao
o`00KGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000G7oo001/Ool0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000G7oo001/Ool01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000G7oo001/Ool00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIoo`1LOol006aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEWoo05aoo`00K7oo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000GGoo001/Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001MOol006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001M
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001MOol006]o
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEWoo05eoo`00Jgoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YFOol0GGoo001[Ool00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0001NOol006]oo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0005ioo`00JWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0005ioo`00JWoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0005ioo`00JWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFOol0
GWoo001ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001OOol006Yoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005moo`00JWoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000Ggoo001YOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFOol0Ggoo001YOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001POol006Uoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00061oo`00JGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000H7oo001YOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001POol006Qoo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUIoo`1POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP80065oo`00J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HGoo
001XOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001QOol006Qoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00065oo`00Igoo00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP80069oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH025YF0P0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00HWoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001R
Ool006Moo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00069oo`00Igoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000HWoo001VOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P00Hgoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001SOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEP0006=oo`00IWoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
Hgoo001VOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001SOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001TOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP8000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Aoo`00GWoo3P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000I7oo001J
Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001TOol0
05Qoo`<000IJEP03001JEUYF00EJEP03001JEUYF00AJEPD00003FUH005YF00YJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Ao
o`00EWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00IGoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH40004FUH2000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001UOol005Eoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEP0000D000aJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF0`002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20009
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP04001JEP000007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol005=oo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Io
o`00Dgoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001COol20004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
001VOol005=oo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP06001JEP00001JEP0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00002Goo4000CGoo001COol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
000017oo1@000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Agoo001BOol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH00002Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000030013Ool0059oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8000]JEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003Ool0000000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP@003moo`00DWoo0P0015YF00@005YF
FUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF
00002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003eoo`00
DWoo0P000UYF1P000UYF00@005YFFUIJEP<000EJEP03001JEP0000D000IJEP03001JEUYF00IJEP03
001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEP<003Yoo`00DWoo00IJEP00000005YF0005FUH00`00FUIJEP04FUH4
0002FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000h
Ool0055oo`<000=JEP03001JEUYF009JEPL0009JEP03001JEUYF00@0009JEPH0009JEP@000MJEP03
001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF0`00=Woo001AOol30002FUH00`00FUH000030003FUH01000FUIJEUYF1`00
0UYF20001UYF0P0015YF00<005YFFUH015YF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP@000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008003Aoo`00DGoo00<005YFFUH00UYF0`00
1EYF00<005YFFUH01UYF00<005YFFUH05@0000=JEP00FUH01EYF00H005YFFUH005YF000;FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000bOol0055oo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00EJEP03001JEUYF00EJEP8000EJEP07001JEUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP80035oo`00DWoo0`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF
00EJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH2000aOol0059oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJEP04001JEUYFFUH2
00000eYF001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P001EYF00<005YFFUH015YF0P000eYF0P00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000_Ool0055oo`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP07001JEP00FUH005YF0000
2eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH015YF00D005YFFUIJEP0002moo`00<goo50002Woo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
00800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
05YF009JEP04001JEUYFFUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000aOol30006FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH70003Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF1@000UYF00D005YF000007oo00T000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00<00005FUH005YFFUH0
0003FUH70004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJ
EP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH00000FUH0
0`001UYF00@005YFFUIJEP<000Moo`L000IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYF
FUH005YF0000;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20002FUH80004FUH70007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH20002FUH0
0`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP020002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40006Ool80002FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01`00FUIJEUYF001JEP0002ioo`00;Woo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH00UYF100000=JEP0000000`0000=oo`0000001UYF00@005YF
FUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00@0009oo`D000=oo`@000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Woo
000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
0004FUH01000FUIJEUYF1`000UYF00<005YFFUH01EYF10001eYF00<005YFFUH01UYF00<005YFFUH0
0UYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Moo`@00003FUH005YF00EJEP04
001JEUYFFUH2000_Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000EJEP8000AJEP800003Ool005YF00@000IJEP04001JEUYFFUH20005FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000;FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH=0006FUH01000FUIJEUYF0P00;goo000]Ool20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH;0002FUH00`00FUIJEP040002FUH0
0`00FUIJEP03FUH300000eYF001JEP07FUH00`00FUIJEP04FUH400000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00005FUH60002FUH01000FUIJEUYF1`00
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00@005YFFUIJEP8002moo`00;7oo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
0`001UYF00@005YFFUIJEPH00003FUH005YF00L000AJEP<000MJEP03001JEUYF00AJEP03001JEP00
008000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEP00001JEP030002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP050009FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF0P00;goo000/Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUH000030006FUH90005FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000030003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH2
000_Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00IJEP<00003FUH005YF00EJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEP00Ool00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0002moo`00;7oo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P002eYF0P001UYF00@005YFFUIJEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003Ool0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00AJEP80009JEP03001JEP0002moo`00;7oo0P000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00L005YFFUIJEP00FUH00002FUH;0004FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP020004FUH01000FUIJEUYF0P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001J
EP0000800003FUH007oo02ioo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJEP04001JEUYFFUH70006FUH0
0`00FUIJEP06FUH20005FUH00`00FUIJEP02FUH01000FUIJEP0015YF0P002eYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
009JEP80031oo`00:goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`0000=JEP0000001EYF00<005YFFUH01UYF00<005YFFUH010000UYF00<0
05YFFUH01eYF0`000eYF00<005YFFUH00eYF0`000eYF00<005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P001UYF00<005YFFUH00UYF0P00<7oo
000[Ool00`00FUH00003FUH01000FUIJEUYF400015YF00@005YFFUIJEP<0009JEP8000EJEP03001J
EUYF00IJEP03001JEUYF00AJEP@000MJEP04001JEUYFFUH200000eYF001JEP06FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJ
EP8000AJEP07001JEUYFFUH005YF0000<7oo000[Ool20003FUH50002FUH01000FUIJEUYF0P0027oo
1P000UYF0`0000EJEP00FUIJEP0000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000005
FUH00`00FUIJEP03FUH20008FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH3000015YF001JEUYF300015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF0`000UYF00L005YFFUIJEP00FUH0000`Ool002]oo`03FUH005YF00<000EJEP03001JEUYF
00AJEP@000Moo`H00004FUH000000003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH300000eYF001JEP07FUH01000FUIJEUYF1@000UYF0P002eYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00eYF100000AJEP00000000AJEP<000=oo`T000AJEP03001JEUYF00MJ
EP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF0P00<Goo000ZOol01000FUH000000UYF00<0
05YFFUH00UYF1`000UYF00<005YFFUH010000Woo1@0000Aoo`00001JEP<000AJEP8000QJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000QJEP@000=JEP06001JEP00001JEP002eYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`000eYF00<005YFFUH00eYF0`000goo1000
0eYF1P0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF0P00<Goo000ZOol30002FUH00`00
FUH000030003FUH01000FUIJEUYF1`000UYF1`000Woo00D005YFFUH007oo008000=JEP8000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000IJEP04001JEUYF0002FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEP00001JEP000eYF0`000eYF
00@005YFFUH000Ioo`@0009JEP03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000bOol002Yoo`03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00`000=J
EPH00004FUH000000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020003FUH00`00
FUIJEP02FUH30003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH000020003FUH01`00FUIJEUYF001JEP0000AJEP8000Qoo`L00006FUH00000001JEP00
1eYF00<005YFFUH01EYF0P00=7oo000ZOol00`00FUIJEP0200000eYF001JEP05FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH40004FUH00`00FUIJEP030003FUH20002FUH300000eYF001JEP07FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000=JEP03001JEUYF009JEP8000IJ
EP03001oogoo00]oo`L000MJEP03001JEUYF00AJEP03001JEP0003Aoo`00:goo0`000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF0000009JEP04001JEUYF0002FUH01@00
FUIJEP00FUH00P0000=JEP00FUH00`001eYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF0P00
0UYF0P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF
00<005YFFUH015YF00<005YFFUH00eYF0P002goo1@000goo0P001EYF00<005YFFUH015YF00@005YF
FUH003=oo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00UYF1@0015YF0`000eYF0P0000AJEP00FUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEP00009JEP8000]JEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH005YF009JEP03001JEUYF00=JEPH0009JEP03001JEP0000Yoo`D000Eoo`80
00=JEP03001JEUYF00AJEP05001JEUYFFUH0000bOol002]oo`80009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP02FUH300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF1P000UYF
00@005YFFUIJEPL000Qoo`D000Moo`<000IJEP03001JEUYF009JEP03001oogoo031oo`00:Woo00<0
05YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF0`0000EJEP00FUIJEP0000AJEP03001JEUYF00@000AJEP@000MJEP03001JEUYF009J
EP8000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009J
EP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@000Eoo`<000Yoo`03001JEUYF
00AJEP04001JEUYFFUH2000bOol002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP04001JEUYFFUH200000eYF001JEP04FUH00`00
FUIJEP04FUH80007FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUH005YF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH015YF0`0047oo0P0015YF00L005YFFUIJEP00FUH0000aOol002Yoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03
001JEUYF00=JEP8000EJEP03001JEUYF00MJEPP000=JEP04001JEUYFFUH50003FUH2000<FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUH005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF0`0047oo00D005YFFUIJEP0000=JEP03001JEP00035oo`00
:Goo00<005YF00000UYF00@005YFFUIJEPL000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF009JEP8000QJEP8000=JEP03001JEUYF00IJEPH000=JEPL000EJEP05001JEP00FUH0000;FUH0
0`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF00000003FUH01000FUIJEUYF
1`0015YF00<005YFFUH01UYF00@005YFFUIJEP8000moo`<000=JEP04001JEUYF000aOol002Uoo`80
009JEPH00003FUH005YF00=JEPL000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEP0000<000QJEP03001JEP00008000IJEP03001JEUYF00QJEP800003FUH005YF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEPH0009JEP03001JEUYF009JEPH0
00MJEP03001JEUYF00=JEP8000moo`07001JEUYFFUH005YF0000<Woo000YOol400000eYF001oo`03
Ool30006FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH01EYF0P001UYF00<005YF
FUH00UYF0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF00002eYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001P000UYF00D005YFFUIJEP0000MJEP03001J
EUYF00@0009JEP03001JEUYF00IJEP8000ioo`06001JEUYF001JEP00<Woo000YOol20004FUH00`00
Oomoo`04Ool20004FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP06
FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP09FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01P00FUH00000FUH000=oo`800004FUH000000007FUH00`00FUIJEP05FUH4
0008FUH40008Ool40002FUH00`00FUH0000bOol002Qoo`8000EJEP8000Moo`<00003FUH005YF00MJ
EP03001JEUYF008000EJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00QJEP03001JEP00
00<000YJEP03001JEUYF00QJEP<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP05001JEP00001JEP0800000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUH000020004FUH01000
FUIJEUYF2@000UYF00H005YF000005YF000cOol002Qoo`8000AJEP03001JEUYF00P0009oo`<000IJ
EP03001JEUYF00=JEP<00003FUH005YF00MJEP06001JEUYFFUH005YF0`001eYF00<005YFFUH015YF
20000UYF00<005YFFUH01UYF0P0000=JEP00000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000UYF0P001UYF10001EYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
00=JEP00FUH015YF0P0000=JEP00FUH00eYF00L005YFFUIJEP00FUH0000cOol002Qoo`8000=JEPD0
00=JEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH20008FUH01`00FUIJEUYF001JEP00009JEP80
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP/0009JEP<000]JEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00=JEP<00004FUH005YF0007FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH20007FUH20004FUH01`00FUIJEUYF001JEP0003=oo`00:7oo1@0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH02@0015YF00@005YF000000IJEP03001JEUYF00=JEP03001JEUYF009JEP<0
0003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEUYFFUH005YF00002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0002FUH00`00FUIJEP03
FUH01000FUIJEUYF1@002EYF00<005YFFUH00eYF100000=JEP0000001EYF00<005YF00000eYF00@0
05YFFUIJEP8003Aoo`00:7oo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
100000=oo`000000200015YF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00@000IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000AJEP03001JEUYF009JEP03001JEUYF00=J
EP@000QJEP03001JEUYF009JEPD000=JEP8000=JEP03001JEUYF00<000AJEP8003Aoo`00:7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000000Uoo`800003FUH0
05YF009JEP03001JEUYF00EJEP03001JEUYF00=JEPD0009JEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D0
05YF001JEP0000AJEP8000=JEP03001JEUYF00AJEP800004FUH000000005FUH00`00FUIJEP02FUH5
0005FUH30005FUH00`00FUIJEP02FUH00`00Oomoo`0cOol002Moo`03001JEP00009JEP/000AJEP03
001JEUYF00MJEP03001JEUYF009JEP<000Qoo`8000=JEP03001JEP0000EJEPH0009JEP03001JEUYF
00H000AJEP03001JEUYF00AJEP04001JEP000002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH01000FUIJEP000UYF0P0000=JEP00FUH01EYF
00<005YF00000P0000IJEP00000005YF0005FUH50007FUH00`00FUIJEP04FUH00`00FUIJEP02000e
Ool002Moo`800005FUH00000FUH00005FUH01000FUIJEUYF1`001eYF00<005YFFUH01EYF0P0027oo
0P0000AJEP00FUH000=JEP8000QJEP03001JEUYF00IJEPd00003FUH0000000<000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYF0004FUH20005FUH00`00FUIJ
EP02FUH20003Ool40004FUH30008FUH20005FUH4000fOol002Moo`<00003Ool0000000EJEP03001J
EUYF00MJEP03001JEP0000<0009JEP03001JEUYF00MJEP<000Qoo`05001JEUYF001JEP0200000eYF
001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH01000FUIJEUYF10001UYF00<005YFFUH02EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF
0P001goo10000UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEP0003Moo`009Woo0`000goo
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF10001eYF00@005YFFUIJEP8000Moo`9J
EP8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@0009J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJ
EP<000=JEP03001JEUYF009JEP8000]ooa000003FUH005YF009JEP03001oogoo03Aoo`009Woo0`00
17oo00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000EJEP03001JEUYF
00=JEP8000Aoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP@000YJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000EJEP<000AJEP03
001JEUYF00800003FUH005YF009JEP03001JEP0001]oo`8000AJEP03001oogoo03=oo`009Woo00@0
05YF000000Aoo`80009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF00MJEP04001oogooOol30005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004
FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF0P000eYF0P007Goo00<005YFFUH00UYF00<007oo
Ool0<goo000VOol01000FUH000001Woo0P0025YF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF
1`001EYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF100000=JEP00FUH01eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH00UYF0`00
1eYF1@007Woo00<005YFFUH00P00=Goo000VOol20002FUH00`00Oomoo`04Ool20007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH30006FUH01`00FUH005YF001JEP0000eJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP8000QJEP03001JEUYF00=JEP8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP04001JEP00000NOol00`00FUIJEP02000eOol002Moo`05001JEUYF
FUH00007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP020003FUH01000FUIJ
EUYF0P003eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00@0
05YF000000IJEP03001JEUYF00=JEP8000EJEP03001JEUYF00AJEP<000EJEP03001JEUYF009JEP<0
01aoo`800003FUH007oo03Aoo`009goo00@005YFFUIJEP<000Moo`<00003FUH005YF00MJEP03001J
EUYF00MJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03
001JEUYF00=JEP03001JEUYF009JEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF008000=J
EP03001JEUYF00EJEP@001Uoo`03001JEP0003Eoo`00:7oo00@005YFFUH0009JEP03001oogoo00Mo
o`<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=J
EP80009JEP03001JEUYF00=JEP03001JEP0000=oo`<000IJEP03001JEUYF009JEP<000UJEP03001J
EUYF00@001Eoo`8003Ioo`00:7oo00<005YF000015YF0P002Woo0P001EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`001EYF00<005YF0000
1Woo0P0015YF00<005YFFUH015YF0P0025YF00<005YFFUH015YF1P003Goo1000=Woo000YOol20006
FUH00`00Oomoo`09Ool300000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00008Ool200000eYF001JEP05FUH00`00FUIJ
EP030004FUH00`00FUIJEP07FUH01000FUIJEUYF3@000UYF0P00=Woo000ZOol00`00FUIJEP04FUH3
000<Ool40004FUH40007FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUH00004FUH2
000;Ool20006FUH01000FUIJEUYF1@0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00P00=goo000[Ool00`00FUIJEP02FUH01000FUIJEUYF0P003Woo20001eYF00<005YF
FUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP04001JEUYF0003FUH2000=Ool20004FUH01`00FUIJEUYF001J
EP00009oo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000gOol002aoo`80
009JEP03001JEUYF00=JEP8000moo`L000AJEP04001JEUYFFUH50003FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH02@00
FUIJEUYF001JEP00FUH0000?Ool01@00FUIJEUYF00000eYF00<005YF00001Goo10000UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00P00>7oo000^Ool20008FUH2000=Ool50002Ool80005
Ool00`00FUIJEP020008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF001oo`0?Ool30003FUH01000FUIJEP00
2Goo1P0015YF00<005YFFUH015YF00@005YF000003Yoo`00;goo00<005YFFUH01UYF00<005YF0000
0P002goo0`0047oo00@005YF001JEP<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000<000moo`07001J
EUYFFUH005YF000047oo3@00?7oo000`Ool20006FUH00`00FUIJEP02FUH3000LOol2000015YF001o
ogoo0P003eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00<005YF00000eYF0P003Woo00H005YFFUH005YF001IOol0039oo`8000=JEP03001J
EUYF00IJEP<001Yoo`8000Eoo`8000eJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP@000Qoo`@0009JEP03001JEP0005Uoo`00=7oo
0P0000=JEP00FUH025YF00<005YF00000`005Goo0`001goo0`002UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF00<005YFFUH02@00
0UYF00H005YF000005YF001JOol003Ioo`<000MJEP03001JEUYF00AJEPL000aoo`800003FUH007oo
00Yoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP<000=JEP03001JEUYF00=JEP800003FUH005YF00=JEP07001JEUYFFUH005YF0000
FWoo000iOol20005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH2000>Ool2000AFUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH200000eYF001J
EP06FUH20004FUH01`00FUIJEUYF001JEP0005Yoo`00>goo0`0000=JEP00FUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00D005YFFUIJEP00015oo`<000iJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP8000QJEP8000=JEP07001JEUYFFUH005YF0000
FWoo000nOol40006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000DOol3000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP040000
0eYF00000005FUH00`00FUIJEP030004FUH2001KOol0049oo`@0009JEP03001JEUYF00IJEP03001J
EUYF00=JEP05001JEUYFFUH0000HOol4000CFUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF000000030003FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2001KOol0
04Ioo`H000AJEP03001JEUYF00AJEP04001JEP00000MOol4000?FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUH000030003FUH50005FUH30006FUH00`00FUIJEP02001LOol004aoo`d002=oo`T0
00IJEP03001JEUYF00QJEP03001JEUYF00EJEPP000=JEPD000MJEP03001JEUYF00AJEP@005eoo`00
QGoo30001EYF00<005YFFUH01@0027oo1`0025YF0`0015YF00<005YF0000GWoo002;Ool00`00FUIJ
EP03FUH8000AOol60004FUH01@00FUIJEUYF00000UYF00D005YFFUIJEP0005eoo`00S7oo0P0015YF
00<005YFFUH00P006Goo200000Aoo`00000000AJEP03001oogoo05Yoo`00SWoo00@005YFFUH000EJ
EP80029oo`03001JEUYF009JEP03001oogoo05Yoo`00Sgoo0`001eYF0`0087oo00<005YFFUH00P00
G7oo002AOol00`00FUIJEP06FUH01000FUH000007Woo00<005YFFUH00P00G7oo002BOol20005FUH0
0`00FUIJEP02FUH3000LOol200000eYF001oo`1KOol009Aoo`8000=JEP03001JEUYF00EJEP<001Yo
o`03001JEP0005aoo`00UWoo0`002EYF00<005YF00000P005goo00<005YF0000G7oo002HOol20008
FUH00`00FUIJEP02FUH3000BOol4001MOol009Yoo`<000AJEP03001JEUYF00IJEPD000Qoo`D0009J
EP8005eoo`00WGoo0`0000=JEP00FUH01eYF00<005YFFUH00UYF20000eYF00H005YFFUH005YF001M
Ool00:1oo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2001NOol00:=oo`@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008005moo`00Ygoo1P0015YF00<005YF
FUH015YF00@005YF0000065oo`00[Goo3@00Hgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60577 .74241 m .5965 .68667 L .56577 .69008 L p .707 .577 .707 r
F P
0 g
s
.5965 .68667 m .60577 .74241 L .63721 .73684 L p .707 .577 .707 r
F P
0 g
s
.63721 .73684 m .62794 .6811 L .5965 .68667 L p .707 .577 .707 r
F P
0 g
s
.62794 .6811 m .63721 .73684 L .66627 .72966 L p .707 .577 .707 r
F P
0 g
s
.66627 .72966 m .657 .67392 L .62794 .6811 L p .707 .577 .707 r
F P
0 g
s
.57504 .74582 m .56577 .69008 L .53875 .691 L p .707 .577 .707 r
F P
0 g
s
.56577 .69008 m .57504 .74582 L .60577 .74241 L p .707 .577 .707 r
F P
0 g
s
.657 .67392 m .66627 .72966 L .69012 .72157 L p .707 .577 .707 r
F P
0 g
s
.69012 .72157 m .68085 .66583 L .657 .67392 L p .707 .577 .707 r
F P
0 g
s
.6151 .79695 m .6051 .7603 L .5751 .76705 L p .707 .577 .707 r
F P
0 g
s
.6051 .7603 m .6151 .79695 L .64588 .78838 L p .707 .577 .707 r
F P
0 g
s
.64588 .78838 m .63588 .75173 L .6051 .7603 L p .707 .577 .707 r
F P
0 g
s
.63588 .75173 m .64588 .78838 L .67442 .77881 L p .707 .577 .707 r
F P
0 g
s
.67442 .77881 m .66443 .74217 L .63588 .75173 L p .707 .577 .707 r
F P
0 g
s
.53875 .691 m .54802 .74674 L .57504 .74582 L p .707 .577 .707 r
F P
0 g
s
.5751 .76705 m .5851 .80369 L .6151 .79695 L p .707 .577 .707 r
F P
0 g
s
.54802 .74674 m .53875 .691 L .5181 .68934 L p .707 .577 .707 r
F P
0 g
s
.5851 .80369 m .5751 .76705 L .54882 .77129 L p .707 .577 .707 r
F P
0 g
s
.62215 .8343 m .61659 .8161 L .58687 .82383 L p .707 .577 .707 r
F P
0 g
s
.61659 .8161 m .62215 .8343 L .65267 .82484 L p .707 .577 .707 r
F P
0 g
s
.65267 .82484 m .64711 .80664 L .61659 .8161 L p .707 .577 .707 r
F P
0 g
s
.64711 .80664 m .65267 .82484 L .68101 .81457 L p .707 .577 .707 r
F P
0 g
s
.68101 .81457 m .67545 .79637 L .64711 .80664 L p .707 .577 .707 r
F P
0 g
s
.66443 .74217 m .67442 .77881 L .69794 .76919 L p .707 .577 .707 r
F P
0 g
s
.69794 .76919 m .68794 .73255 L .66443 .74217 L p .707 .577 .707 r
F P
0 g
s
.58687 .82383 m .59243 .84203 L .62215 .8343 L p .707 .577 .707 r
F P
0 g
s
.54882 .77129 m .55882 .80794 L .5851 .80369 L p .707 .577 .707 r
F P
0 g
s
.68085 .66583 m .69012 .72157 L .70642 .71336 L p .707 .577 .707 r
F P
0 g
s
.70642 .71336 m .69715 .65762 L .68085 .66583 L p .707 .577 .707 r
F P
0 g
s
.59243 .84203 m .58687 .82383 L .56087 .82906 L p .707 .577 .707 r
F P
0 g
s
.5181 .68934 m .52737 .74508 L .54802 .74674 L p .707 .577 .707 r
F P
0 g
s
.67545 .79637 m .68101 .81457 L .70439 .8045 L p .707 .577 .707 r
F P
0 g
s
.70439 .8045 m .69883 .78629 L .67545 .79637 L p .707 .577 .707 r
F P
0 g
s
.56087 .82906 m .56643 .84726 L .59243 .84203 L p .707 .577 .707 r
F P
0 g
s
.55882 .80794 m .54882 .77129 L .52882 .77264 L p .707 .577 .707 r
F P
0 g
s
.68794 .73255 m .69794 .76919 L .71412 .76045 L p .707 .577 .707 r
F P
0 g
s
.71412 .76045 m .70412 .72381 L .68794 .73255 L p .707 .577 .707 r
F P
0 g
s
.52882 .77264 m .53882 .80928 L .55882 .80794 L p .707 .577 .707 r
F P
0 g
s
.52737 .74508 m .5181 .68934 L .50582 .68526 L p .707 .577 .707 r
F P
0 g
s
.56643 .84726 m .56087 .82906 L .54113 .83129 L p .707 .577 .707 r
F P
0 g
s
.54113 .83129 m .54669 .8495 L .56643 .84726 L p .707 .577 .707 r
F P
0 g
s
.69883 .78629 m .70439 .8045 L .72053 .7956 L p .707 .577 .707 r
F P
0 g
s
.72053 .7956 m .71497 .7774 L .69883 .78629 L p .707 .577 .707 r
F P
0 g
s
.69715 .65762 m .70642 .71336 L .71357 .70584 L p .707 .577 .707 r
F P
0 g
s
.71357 .70584 m .7043 .6501 L .69715 .65762 L p .707 .577 .707 r
F P
0 g
s
.50582 .68526 m .51509 .741 L .52737 .74508 L p .707 .577 .707 r
F P
0 g
s
.53882 .80928 m .52882 .77264 L .51707 .77094 L p .707 .577 .707 r
F P
0 g
s
.70412 .72381 m .71412 .76045 L .72139 .75346 L p .707 .577 .707 r
F P
0 g
s
.72139 .75346 m .71139 .71681 L .70412 .72381 L p .707 .577 .707 r
F P
0 g
s
.51707 .77094 m .52707 .80759 L .53882 .80928 L p .707 .577 .707 r
F P
0 g
s
.51509 .741 m .50582 .68526 L .50313 .67916 L p .707 .577 .707 r
F P
0 g
s
.54669 .8495 m .54113 .83129 L .52958 .8303 L p .707 .577 .707 r
F P
0 g
s
.52958 .8303 m .53514 .8485 L .54669 .8495 L p .707 .577 .707 r
F P
0 g
s
.71497 .7774 m .72053 .7956 L .72784 .78876 L p .707 .577 .707 r
F P
0 g
s
.72784 .78876 m .72228 .77056 L .71497 .7774 L p .707 .577 .707 r
F P
0 g
s
.7043 .6501 m .71357 .70584 L .71088 .69974 L p .707 .577 .707 r
F P
0 g
s
.71088 .69974 m .70161 .644 L .7043 .6501 L p .707 .577 .707 r
F P
0 g
s
.50313 .67916 m .5124 .73489 L .51509 .741 L p .707 .577 .707 r
F P
0 g
s
.52707 .80759 m .51707 .77094 L .51471 .76637 L p .707 .577 .707 r
F P
0 g
s
.51471 .76637 m .52471 .80301 L .52707 .80759 L p .707 .577 .707 r
F P
0 g
s
.71139 .71681 m .72139 .75346 L .71903 .74889 L p .707 .577 .707 r
F P
0 g
s
.71903 .74889 m .70903 .71224 L .71139 .71681 L p .707 .577 .707 r
F P
0 g
s
.53514 .8485 m .52958 .8303 L .52735 .82618 L p .707 .577 .707 r
F P
0 g
s
.5124 .73489 m .50313 .67916 L .51028 .67163 L p .707 .577 .707 r
F P
0 g
s
.52735 .82618 m .53291 .84439 L .53514 .8485 L p .707 .577 .707 r
F P
0 g
s
.72228 .77056 m .72784 .78876 L .72561 .78465 L p .707 .577 .707 r
F P
0 g
s
.72561 .78465 m .72005 .76644 L .72228 .77056 L p .707 .577 .707 r
F P
0 g
s
.51028 .67163 m .51955 .72737 L .5124 .73489 L p .707 .577 .707 r
F P
0 g
s
.52471 .80301 m .51471 .76637 L .52198 .75937 L p .707 .577 .707 r
F P
0 g
s
.52198 .75937 m .53198 .79602 L .52471 .80301 L p .707 .577 .707 r
F P
0 g
s
.53198 .79602 m .52198 .75937 L .53816 .75064 L p .707 .577 .707 r
F P
0 g
s
.53389 .81537 m .45063 .31203 L .40724 .31681 L p .707 .577 .707 r
F P
0 g
s
.51955 .72737 m .51028 .67163 L .52658 .66342 L p .707 .577 .707 r
F P
0 g
s
.52658 .66342 m .53585 .71916 L .51955 .72737 L p .707 .577 .707 r
F P
0 g
s
.53816 .75064 m .54816 .78728 L .53198 .79602 L p .707 .577 .707 r
F P
0 g
s
.53585 .71916 m .52658 .66342 L .55043 .65533 L p .707 .577 .707 r
F P
0 g
s
.54023 .83755 m .53467 .81934 L .55081 .81045 L p .707 .577 .707 r
F P
0 g
s
.55081 .81045 m .55637 .82865 L .54023 .83755 L p .707 .577 .707 r
F P
0 g
s
.55043 .65533 m .5597 .71107 L .53585 .71916 L p .707 .577 .707 r
F P
0 g
s
.54816 .78728 m .53816 .75064 L .56168 .74102 L p .707 .577 .707 r
F P
0 g
s
.56168 .74102 m .57168 .77766 L .54816 .78728 L p .707 .577 .707 r
F P
0 g
s
.55637 .82865 m .55081 .81045 L .57419 .80038 L p .707 .577 .707 r
F P
0 g
s
.57419 .80038 m .57975 .81858 L .55637 .82865 L p .707 .577 .707 r
F P
0 g
s
.57975 .81858 m .57419 .80038 L .59486 .79289 L p .707 .577 .707 r
F P
0 g
s
.59486 .79289 m .60253 .79011 L p .59705 .79696 L .707 .577 .707 r
F P
0 g
s
.57975 .81858 m .59486 .79289 L .59705 .79696 L .707 .577 .707 r
F
.53389 .81537 m .57828 .80754 L p .55584 .72041 L F P
0 g
s
.45063 .31203 m .50149 .61947 L p .55584 .72041 L .707 .577 .707 r
F P
0 g
s
.50149 .61947 m .53389 .81537 L p .55584 .72041 L .707 .577 .707 r
F P
0 g
s
.5597 .71107 m .55043 .65533 L .5795 .64815 L p .707 .577 .707 r
F P
0 g
s
.5795 .64815 m .58877 .70389 L .5597 .71107 L p .707 .577 .707 r
F P
0 g
s
.57168 .77766 m .56168 .74102 L .57879 .73528 L p .707 .577 .707 r
F P
0 g
s
.57879 .73528 m .59022 .73145 L p .584 .74694 L .707 .577 .707 r
F P
0 g
s
.57168 .77766 m .57879 .73528 L .584 .74694 L .707 .577 .707 r
F
.49502 .30421 m .45063 .31203 L p .53362 .63416 L F P
0 g
s
.59022 .73145 m .60022 .7681 L .57168 .77766 L p .707 .577 .707 r
F P
0 g
s
.57828 .80754 m .559 .69098 L p .53362 .63416 L .707 .577 .707 r
F P
0 g
s
.559 .69098 m .49502 .30421 L p .53362 .63416 L .707 .577 .707 r
F P
0 g
s
.70161 .644 m .71088 .69974 L .6986 .69566 L p .707 .577 .707 r
F P
0 g
s
.6986 .69566 m .68933 .63992 L .70161 .644 L p .707 .577 .707 r
F P
0 g
s
.58877 .70389 m .5795 .64815 L .61093 .64258 L p .707 .577 .707 r
F P
0 g
s
.61093 .64258 m .6202 .69832 L .58877 .70389 L p .707 .577 .707 r
F P
0 g
s
.60022 .7681 m .59762 .75856 L p .621 .72288 L .707 .577 .707 r
F P
0 g
s
.59762 .75856 m .59022 .73145 L .59485 .73016 L p .707 .577 .707 r
F P
0 g
s
.59485 .73016 m .621 .72288 L p .59762 .75856 L .707 .577 .707 r
F P
0 g
s
.64166 .63917 m .65093 .69491 L .6202 .69832 L p .707 .577 .707 r
F P
0 g
s
.6202 .69832 m .61093 .64258 L .64166 .63917 L p .707 .577 .707 r
F P
0 g
s
.651 .71614 m .661 .75278 L .631 .75952 L p .707 .577 .707 r
F P
0 g
s
.631 .75952 m .621 .72288 L .651 .71614 L p .707 .577 .707 r
F P
0 g
s
.621 .72288 m .631 .75952 L .60022 .7681 L p .707 .577 .707 r
F P
0 g
s
.66276 .77292 m .66832 .79112 L .63861 .79885 L p .707 .577 .707 r
F P
0 g
s
.63861 .79885 m .63305 .78064 L .66276 .77292 L p .707 .577 .707 r
F P
0 g
s
.60809 .80831 m .6032 .7923 L p .63305 .78064 L .707 .577 .707 r
F P
0 g
s
.6032 .7923 m .60253 .79011 L .60302 .78995 L p .707 .577 .707 r
F P
0 g
s
.60302 .78995 m .63305 .78064 L p .6032 .7923 L .707 .577 .707 r
F P
0 g
s
.63305 .78064 m .63861 .79885 L .60809 .80831 L p .707 .577 .707 r
F P
0 g
s
.61932 .79743 m .65299 .78603 L p .57811 .471 L .707 .577 .707 r
F P
0 g
s
.57811 .471 m .56368 .4103 L .5849 .55792 L .707 .577 .707 r
F
.57811 .471 m .5849 .55792 L .61932 .79743 L F
.53606 .2941 m .57572 .53387 L p .56368 .4103 L F P
0 g
s
.57572 .53387 m .61932 .79743 L p .56368 .4103 L .707 .577 .707 r
F P
0 g
s
.60253 .79011 m .60809 .80831 L .57975 .81858 L p .707 .577 .707 r
F P
0 g
s
.49502 .30421 m .57828 .80754 L .61932 .79743 L p .707 .577 .707 r
F P
0 g
s
.61932 .79743 m .53606 .2941 L .49502 .30421 L p .707 .577 .707 r
F P
0 g
s
.4905 .82014 m .40724 .31681 L .36909 .31806 L p .707 .577 .707 r
F P
0 g
s
.40724 .31681 m .4905 .82014 L .53389 .81537 L p .707 .577 .707 r
F P
0 g
s
.26276 .71047 m .25349 .65473 L .22276 .65814 L p .707 .577 .707 r
F P
0 g
s
.25349 .65473 m .26276 .71047 L .2942 .7049 L p .707 .577 .707 r
F P
0 g
s
.2942 .7049 m .28493 .64916 L .25349 .65473 L p .707 .577 .707 r
F P
0 g
s
.28493 .64916 m .2942 .7049 L .32326 .69772 L p .707 .577 .707 r
F P
0 g
s
.32326 .69772 m .31399 .64198 L .28493 .64916 L p .707 .577 .707 r
F P
0 g
s
.65299 .78603 m .56973 .28269 L .53606 .2941 L p .707 .577 .707 r
F P
0 g
s
.70903 .71224 m .71903 .74889 L .70728 .74719 L p .707 .577 .707 r
F P
0 g
s
.70728 .74719 m .69728 .71055 L .70903 .71224 L p .707 .577 .707 r
F P
0 g
s
.53291 .84439 m .52735 .82618 L .53467 .81934 L p .707 .577 .707 r
F P
0 g
s
.23203 .71388 m .22276 .65814 L .19574 .65906 L p .707 .577 .707 r
F P
0 g
s
.22276 .65814 m .23203 .71388 L .26276 .71047 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.53467 .81934 m .54023 .83755 L .53291 .84439 L p .707 .577 .707 r
F P
0 g
s
.31399 .64198 m .32326 .69772 L .34711 .68963 L p .707 .577 .707 r
F P
0 g
s
.34711 .68963 m .33784 .63389 L .31399 .64198 L p .707 .577 .707 r
F P
0 g
s
.72005 .76644 m .72561 .78465 L .71407 .78365 L p .707 .577 .707 r
F P
0 g
s
.71407 .78365 m .70851 .76545 L .72005 .76644 L p .707 .577 .707 r
F P
0 g
s
.68933 .63992 m .6986 .69566 L .67795 .69399 L p .707 .577 .707 r
F P
0 g
s
.67795 .69399 m .66868 .63825 L .68933 .63992 L p .707 .577 .707 r
F P
0 g
s
.2721 .77151 m .2621 .73486 L .2321 .7416 L p .707 .577 .707 r
F P
0 g
s
.2621 .73486 m .2721 .77151 L .30287 .76294 L p .707 .577 .707 r
F P
0 g
s
.30287 .76294 m .29287 .72629 L .2621 .73486 L p .707 .577 .707 r
F P
0 g
s
.19574 .65906 m .20502 .7148 L .23203 .71388 L p .707 .577 .707 r
F P
0 g
s
.29287 .72629 m .30287 .76294 L .33142 .75337 L p .707 .577 .707 r
F P
0 g
s
.33142 .75337 m .32142 .71673 L .29287 .72629 L p .707 .577 .707 r
F P
0 g
s
.45236 .8214 m .36909 .31806 L .33992 .31568 L p .707 .577 .707 r
F P
0 g
s
.36909 .31806 m .45236 .8214 L .4905 .82014 L p .707 .577 .707 r
F P
0 g
s
.2321 .7416 m .2421 .77825 L .2721 .77151 L p .707 .577 .707 r
F P
0 g
s
.20502 .7148 m .19574 .65906 L .17509 .6574 L p .707 .577 .707 r
F P
0 g
s
.2421 .77825 m .2321 .7416 L .20581 .74585 L p .707 .577 .707 r
F P
0 g
s
.66868 .63825 m .67795 .69399 L .65093 .69491 L p .707 .577 .707 r
F P
0 g
s
.65093 .69491 m .64166 .63917 L .66868 .63825 L p .707 .577 .707 r
F P
0 g
s
.67728 .71189 m .68728 .74853 L .661 .75278 L p .707 .577 .707 r
F P
0 g
s
.661 .75278 m .651 .71614 L .67728 .71189 L p .707 .577 .707 r
F P
0 g
s
.66832 .79112 m .66276 .77292 L .68876 .76768 L p .707 .577 .707 r
F P
0 g
s
.56973 .28269 m .65299 .78603 L .67601 .77444 L p .707 .577 .707 r
F P
0 g
s
.67601 .77444 m .59274 .27111 L .56973 .28269 L p .707 .577 .707 r
F P
0 g
s
.32142 .71673 m .33142 .75337 L .35493 .74375 L p .707 .577 .707 r
F P
0 g
s
.35493 .74375 m .34493 .7071 L .32142 .71673 L p .707 .577 .707 r
F P
0 g
s
.27914 .81799 m .27358 .79979 L .24386 .80751 L p .707 .577 .707 r
F P
0 g
s
.27358 .79979 m .27914 .81799 L .30966 .80853 L p .707 .577 .707 r
F P
0 g
s
.30966 .80853 m .3041 .79032 L .27358 .79979 L p .707 .577 .707 r
F P
0 g
s
.69728 .71055 m .70728 .74719 L .68728 .74853 L p .707 .577 .707 r
F P
0 g
s
.68728 .74853 m .67728 .71189 L .69728 .71055 L p .707 .577 .707 r
F P
0 g
s
.33784 .63389 m .34711 .68963 L .36341 .68142 L p .707 .577 .707 r
F P
0 g
s
.36341 .68142 m .35414 .62568 L .33784 .63389 L p .707 .577 .707 r
F P
0 g
s
.3041 .79032 m .30966 .80853 L .338 .79826 L p .707 .577 .707 r
F P
0 g
s
.338 .79826 m .33244 .78005 L .3041 .79032 L p .707 .577 .707 r
F P
0 g
s
.20581 .74585 m .21581 .7825 L .2421 .77825 L p .707 .577 .707 r
F P
0 g
s
.24386 .80751 m .24942 .82572 L .27914 .81799 L p .707 .577 .707 r
F P
0 g
s
.17509 .6574 m .18436 .71314 L .20502 .7148 L p .707 .577 .707 r
F P
0 g
s
.24942 .82572 m .24386 .80751 L .21786 .81275 L p .707 .577 .707 r
F P
0 g
s
.70851 .76545 m .71407 .78365 L .69433 .78589 L p .707 .577 .707 r
F P
0 g
s
.69433 .78589 m .68876 .76768 L .70851 .76545 L p .707 .577 .707 r
F P
0 g
s
.33244 .78005 m .338 .79826 L .36138 .78818 L p .707 .577 .707 r
F P
0 g
s
.36138 .78818 m .35582 .76998 L .33244 .78005 L p .707 .577 .707 r
F P
0 g
s
.21786 .81275 m .22342 .83095 L .24942 .82572 L p .707 .577 .707 r
F P
0 g
s
.21581 .7825 m .20581 .74585 L .18581 .7472 L p .707 .577 .707 r
F P
0 g
s
.18436 .71314 m .17509 .6574 L .16281 .65332 L p .707 .577 .707 r
F P
0 g
s
.34493 .7071 m .35493 .74375 L .37111 .73501 L p .707 .577 .707 r
F P
0 g
s
.37111 .73501 m .36111 .69837 L .34493 .7071 L p .707 .577 .707 r
F P
0 g
s
.18581 .7472 m .19581 .78384 L .21581 .7825 L p .707 .577 .707 r
F P
0 g
s
.42319 .81901 m .33992 .31568 L .32259 .30989 L p .707 .577 .707 r
F P
0 g
s
.33992 .31568 m .42319 .81901 L .45236 .8214 L p .707 .577 .707 r
F P
0 g
s
.35414 .62568 m .36341 .68142 L .37056 .6739 L p .707 .577 .707 r
F P
0 g
s
.37056 .6739 m .36129 .61816 L .35414 .62568 L p .707 .577 .707 r
F P
0 g
s
.22342 .83095 m .21786 .81275 L .19812 .81498 L p .707 .577 .707 r
F P
0 g
s
.16281 .65332 m .17208 .70905 L .18436 .71314 L p .707 .577 .707 r
F P
0 g
s
.19812 .81498 m .20368 .83318 L .22342 .83095 L p .707 .577 .707 r
F P
0 g
s
.35582 .76998 m .36138 .78818 L .37752 .77929 L p .707 .577 .707 r
F P
0 g
s
.37752 .77929 m .37196 .76109 L .35582 .76998 L p .707 .577 .707 r
F P
0 g
s
.59274 .27111 m .67601 .77444 L .6861 .76382 L p .707 .577 .707 r
F P
0 g
s
.6861 .76382 m .60284 .26048 L .59274 .27111 L p .707 .577 .707 r
F P
0 g
s
.68876 .76768 m .69433 .78589 L .66832 .79112 L p .707 .577 .707 r
F P
0 g
s
.19581 .78384 m .18581 .7472 L .17406 .7455 L p .707 .577 .707 r
F P
0 g
s
.36111 .69837 m .37111 .73501 L .37838 .72802 L p .707 .577 .707 r
F P
0 g
s
.37838 .72802 m .36838 .69137 L .36111 .69837 L p .707 .577 .707 r
F P
0 g
s
.17406 .7455 m .18406 .78214 L .19581 .78384 L p .707 .577 .707 r
F P
0 g
s
.17208 .70905 m .16281 .65332 L .16012 .64722 L p .707 .577 .707 r
F P
0 g
s
.20368 .83318 m .19812 .81498 L .18657 .81399 L p .707 .577 .707 r
F P
0 g
s
.18657 .81399 m .19213 .83219 L .20368 .83318 L p .707 .577 .707 r
F P
0 g
s
.36129 .61816 m .37056 .6739 L .36787 .6678 L p .707 .577 .707 r
F P
0 g
s
.36787 .6678 m .3586 .61206 L .36129 .61816 L p .707 .577 .707 r
F P
0 g
s
.37196 .76109 m .37752 .77929 L .38483 .77245 L p .707 .577 .707 r
F P
0 g
s
.38483 .77245 m .37927 .75425 L .37196 .76109 L p .707 .577 .707 r
F P
0 g
s
.16012 .64722 m .16939 .70295 L .17208 .70905 L p .707 .577 .707 r
F P
0 g
s
.40585 .81322 m .32259 .30989 L .31878 .30125 L p .707 .577 .707 r
F P
0 g
s
.32259 .30989 m .40585 .81322 L .42319 .81901 L p .707 .577 .707 r
F P
0 g
s
.18406 .78214 m .17406 .7455 L .1717 .74093 L p .707 .577 .707 r
F P
0 g
s
.1717 .74093 m .1817 .77757 L .18406 .78214 L p .707 .577 .707 r
F P
0 g
s
.36838 .69137 m .37838 .72802 L .37602 .72345 L p .707 .577 .707 r
F P
0 g
s
.37602 .72345 m .36603 .6868 L .36838 .69137 L p .707 .577 .707 r
F P
0 g
s
.16939 .70295 m .16012 .64722 L .16727 .63969 L p .707 .577 .707 r
F P
0 g
s
.60284 .26048 m .6861 .76382 L .6823 .75519 L p .707 .577 .707 r
F P
0 g
s
.6823 .75519 m .65252 .57518 L p .60284 .26048 L .707 .577 .707 r
F P
0 g
s
.65252 .57518 m .6387 .49163 L p .61949 .36781 L .707 .577 .707 r
F P
0 g
s
.65252 .57518 m .61949 .36781 L .60284 .26048 L .707 .577 .707 r
F
.59903 .25185 m .6823 .75519 L .66496 .74939 L p F P
0 g
s
.70364 .75523 m .69807 .73702 L .67865 .73922 L p .707 .577 .707 r
F P
0 g
s
.67865 .73922 m .67833 .73925 L p .67869 .73948 L .707 .577 .707 r
F P
0 g
s
.70364 .75523 m .67865 .73922 L .67869 .73948 L .707 .577 .707 r
F
.69602 .7159 m .68602 .67926 L .66903 .6804 L p F P
0 g
s
.66903 .6804 m .66603 .6806 L p .66977 .68501 L .707 .577 .707 r
F P
0 g
s
.69602 .7159 m .66903 .6804 L .66977 .68501 L .707 .577 .707 r
F
.6387 .49163 m .59903 .25185 L .60081 .2559 L p F P
0 g
s
.60081 .2559 m .60284 .26048 L p .6387 .49163 L .707 .577 .707 r
F P
0 g
s
.19213 .83219 m .18657 .81399 L .18434 .80987 L p .707 .577 .707 r
F P
0 g
s
.18434 .80987 m .18991 .82807 L .19213 .83219 L p .707 .577 .707 r
F P
0 g
s
.37927 .75425 m .38483 .77245 L .38261 .76833 L p .707 .577 .707 r
F P
0 g
s
.38261 .76833 m .37705 .75013 L .37927 .75425 L p .707 .577 .707 r
F P
0 g
s
.3586 .61206 m .36787 .6678 L .3556 .66371 L p .707 .577 .707 r
F P
0 g
s
.3556 .66371 m .34632 .60798 L .3586 .61206 L p .707 .577 .707 r
F P
0 g
s
.16727 .63969 m .17654 .69543 L .16939 .70295 L p .707 .577 .707 r
F P
0 g
s
.1817 .77757 m .1717 .74093 L .17897 .73393 L p .707 .577 .707 r
F P
0 g
s
.17897 .73393 m .18897 .77058 L .1817 .77757 L p .707 .577 .707 r
F P
0 g
s
.36603 .6868 m .37602 .72345 L .36427 .72175 L p .707 .577 .707 r
F P
0 g
s
.36427 .72175 m .35427 .6851 L .36603 .6868 L p .707 .577 .707 r
F P
0 g
s
.31878 .30125 m .40205 .80459 L .40585 .81322 L p .707 .577 .707 r
F P
0 g
s
.40205 .80459 m .31878 .30125 L .32888 .29063 L p .707 .577 .707 r
F P
0 g
s
.17654 .69543 m .16727 .63969 L .18357 .63148 L p .707 .577 .707 r
F P
0 g
s
.18991 .82807 m .18434 .80987 L .19166 .80303 L p .707 .577 .707 r
F P
0 g
s
.19166 .80303 m .19722 .82123 L .18991 .82807 L p .707 .577 .707 r
F P
0 g
s
.34632 .60798 m .3556 .66371 L .33494 .66205 L p .707 .577 .707 r
F P
0 g
s
.33494 .66205 m .32567 .60631 L .34632 .60798 L p .707 .577 .707 r
F P
0 g
s
.37705 .75013 m .38261 .76833 L .37106 .76734 L p .707 .577 .707 r
F P
0 g
s
.37106 .76734 m .3655 .74914 L .37705 .75013 L p .707 .577 .707 r
F P
0 g
s
.18357 .63148 m .19284 .68722 L .17654 .69543 L p .707 .577 .707 r
F P
0 g
s
.66496 .74939 m .5817 .24606 L .59903 .25185 L p .707 .577 .707 r
F P
0 g
s
.18897 .77058 m .17897 .73393 L .19515 .7252 L p .707 .577 .707 r
F P
0 g
s
.19284 .68722 m .18357 .63148 L .20742 .62339 L p .707 .577 .707 r
F P
0 g
s
.35427 .6851 m .36427 .72175 L .34427 .72309 L p .707 .577 .707 r
F P
0 g
s
.34427 .72309 m .33427 .68645 L .35427 .6851 L p .707 .577 .707 r
F P
0 g
s
.19515 .7252 m .20515 .76184 L .18897 .77058 L p .707 .577 .707 r
F P
0 g
s
.32567 .60631 m .33494 .66205 L .30792 .66297 L p .707 .577 .707 r
F P
0 g
s
.30792 .66297 m .29865 .60723 L .32567 .60631 L p .707 .577 .707 r
F P
0 g
s
.19722 .82123 m .19166 .80303 L .2078 .79414 L p .707 .577 .707 r
F P
0 g
s
.20742 .62339 m .21669 .67913 L .19284 .68722 L p .707 .577 .707 r
F P
0 g
s
.2078 .79414 m .21336 .81234 L .19722 .82123 L p .707 .577 .707 r
F P
0 g
s
.3655 .74914 m .37106 .76734 L .35132 .76957 L p .707 .577 .707 r
F P
0 g
s
.35132 .76957 m .34576 .75137 L .3655 .74914 L p .707 .577 .707 r
F P
0 g
s
.41215 .79396 m .32888 .29063 L .35189 .27904 L p .707 .577 .707 r
F P
0 g
s
.32888 .29063 m .41215 .79396 L .40205 .80459 L p .707 .577 .707 r
F P
0 g
s
.21669 .67913 m .20742 .62339 L .23649 .61621 L p .707 .577 .707 r
F P
0 g
s
.20515 .76184 m .19515 .7252 L .21867 .71557 L p .707 .577 .707 r
F P
0 g
s
.29865 .60723 m .30792 .66297 L .27719 .66638 L p .707 .577 .707 r
F P
0 g
s
.27719 .66638 m .26792 .61064 L .29865 .60723 L p .707 .577 .707 r
F P
0 g
s
.33427 .68645 m .34427 .72309 L .31799 .72734 L p .707 .577 .707 r
F P
0 g
s
.31799 .72734 m .30799 .69069 L .33427 .68645 L p .707 .577 .707 r
F P
0 g
s
.21867 .71557 m .22867 .75222 L .20515 .76184 L p .707 .577 .707 r
F P
0 g
s
.5817 .24606 m .66496 .74939 L .63579 .74701 L p .707 .577 .707 r
F P
0 g
s
.63579 .74701 m .55253 .24368 L .5817 .24606 L p .707 .577 .707 r
F P
0 g
s
.74297 .65037 m .7337 .59463 L .70297 .59804 L p .707 .577 .707 r
F P
0 g
s
.7337 .59463 m .74297 .65037 L .77441 .6448 L p .707 .577 .707 r
F P
0 g
s
.77441 .6448 m .76514 .58907 L .7337 .59463 L p .707 .577 .707 r
F P
0 g
s
.24576 .67195 m .23649 .61621 L .26792 .61064 L p .707 .577 .707 r
F P
0 g
s
.23649 .61621 m .24576 .67195 L .21669 .67913 L p .707 .577 .707 r
F P
0 g
s
.76514 .58907 m .77441 .6448 L .80348 .63762 L p .707 .577 .707 r
F P
0 g
s
.80348 .63762 m .79421 .58188 L .76514 .58907 L p .707 .577 .707 r
F P
0 g
s
.26792 .61064 m .27719 .66638 L .24576 .67195 L p .707 .577 .707 r
F P
0 g
s
.21336 .81234 m .2078 .79414 L .23118 .78406 L p .707 .577 .707 r
F P
0 g
s
.23118 .78406 m .23674 .80227 L .21336 .81234 L p .707 .577 .707 r
F P
0 g
s
.71224 .65378 m .70297 .59804 L .67596 .59896 L p .707 .577 .707 r
F P
0 g
s
.70297 .59804 m .71224 .65378 L .74297 .65037 L p .707 .577 .707 r
F P
0 g
s
.34576 .75137 m .35132 .76957 L .32532 .77481 L p .707 .577 .707 r
F P
0 g
s
.32532 .77481 m .31975 .7566 L .34576 .75137 L p .707 .577 .707 r
F P
0 g
s
.22867 .75222 m .21867 .71557 L .24721 .70601 L p .707 .577 .707 r
F P
0 g
s
.79421 .58188 m .80348 .63762 L .82733 .62953 L p .707 .577 .707 r
F P
0 g
s
.82733 .62953 m .81805 .57379 L .79421 .58188 L p .707 .577 .707 r
F P
0 g
s
.30799 .69069 m .31799 .72734 L .28799 .73408 L p .707 .577 .707 r
F P
0 g
s
.28799 .73408 m .27799 .69744 L .30799 .69069 L p .707 .577 .707 r
F P
0 g
s
.24721 .70601 m .25721 .74265 L .22867 .75222 L p .707 .577 .707 r
F P
0 g
s
.75231 .70491 m .74231 .66827 L .71231 .67501 L p .707 .577 .707 r
F P
0 g
s
.74231 .66827 m .75231 .70491 L .78309 .69634 L p .707 .577 .707 r
F P
0 g
s
.78309 .69634 m .77309 .65969 L .74231 .66827 L p .707 .577 .707 r
F P
0 g
s
.77309 .65969 m .78309 .69634 L .81163 .68677 L p .707 .577 .707 r
F P
0 g
s
.81163 .68677 m .80163 .65013 L .77309 .65969 L p .707 .577 .707 r
F P
0 g
s
.67596 .59896 m .68523 .6547 L .71224 .65378 L p .707 .577 .707 r
F P
0 g
s
.25721 .74265 m .24721 .70601 L .27799 .69744 L p .707 .577 .707 r
F P
0 g
s
.27799 .69744 m .28799 .73408 L .25721 .74265 L p .707 .577 .707 r
F P
0 g
s
.35189 .27904 m .43516 .78238 L .41215 .79396 L p .707 .577 .707 r
F P
0 g
s
.43516 .78238 m .35189 .27904 L .38557 .26764 L p .707 .577 .707 r
F P
0 g
s
.71231 .67501 m .72231 .71165 L .75231 .70491 L p .707 .577 .707 r
F P
0 g
s
.23674 .80227 m .23118 .78406 L .25952 .77379 L p .707 .577 .707 r
F P
0 g
s
.68523 .6547 m .67596 .59896 L .6553 .5973 L p .707 .577 .707 r
F P
0 g
s
.72231 .71165 m .71231 .67501 L .68602 .67926 L p .707 .577 .707 r
F P
0 g
s
.31975 .7566 m .32532 .77481 L .2956 .78253 L p .707 .577 .707 r
F P
0 g
s
.2956 .78253 m .29004 .76433 L .31975 .7566 L p .707 .577 .707 r
F P
0 g
s
.25952 .77379 m .26508 .792 L .23674 .80227 L p .707 .577 .707 r
F P
0 g
s
.75935 .74227 m .75379 .72406 L .72408 .73179 L p .707 .577 .707 r
F P
0 g
s
.75379 .72406 m .75935 .74227 L .78987 .7328 L p .707 .577 .707 r
F P
0 g
s
.78987 .7328 m .78431 .7146 L .75379 .72406 L p .707 .577 .707 r
F P
0 g
s
.78431 .7146 m .78987 .7328 L .81821 .72253 L p .707 .577 .707 r
F P
0 g
s
.81821 .72253 m .81265 .70433 L .78431 .7146 L p .707 .577 .707 r
F P
0 g
s
.80163 .65013 m .81163 .68677 L .83514 .67715 L p .707 .577 .707 r
F P
0 g
s
.83514 .67715 m .82514 .64051 L .80163 .65013 L p .707 .577 .707 r
F P
0 g
s
.72408 .73179 m .72964 .74999 L .75935 .74227 L p .707 .577 .707 r
F P
0 g
s
.68602 .67926 m .69602 .7159 L .72231 .71165 L p .707 .577 .707 r
F P
0 g
s
.81805 .57379 m .82733 .62953 L .84363 .62132 L p .707 .577 .707 r
F P
0 g
s
.84363 .62132 m .83435 .56558 L .81805 .57379 L p .707 .577 .707 r
F P
0 g
s
.55253 .24368 m .63579 .74701 L .59765 .74827 L p .707 .577 .707 r
F P
0 g
s
.59765 .74827 m .51438 .24493 L .55253 .24368 L p .707 .577 .707 r
F P
0 g
s
.26508 .792 m .25952 .77379 L .29004 .76433 L p .707 .577 .707 r
F P
0 g
s
.29004 .76433 m .2956 .78253 L .26508 .792 L p .707 .577 .707 r
F P
0 g
s
.72964 .74999 m .72408 .73179 L .69807 .73702 L p .707 .577 .707 r
F P
0 g
s
.6553 .5973 m .66457 .65304 L .68523 .6547 L p .707 .577 .707 r
F P
0 g
s
.81265 .70433 m .81821 .72253 L .84159 .71246 L p .707 .577 .707 r
F P
0 g
s
.84159 .71246 m .83603 .69425 L .81265 .70433 L p .707 .577 .707 r
F P
0 g
s
.69807 .73702 m .70364 .75523 L .72964 .74999 L p .707 .577 .707 r
F P
0 g
s
.82514 .64051 m .83514 .67715 L .85133 .66842 L p .707 .577 .707 r
F P
0 g
s
.85133 .66842 m .84133 .63177 L .82514 .64051 L p .707 .577 .707 r
F P
0 g
s
.66603 .6806 m .67602 .71724 L .69602 .7159 L p .707 .577 .707 r
F P
0 g
s
.66457 .65304 m .6553 .5973 L .64302 .59322 L p .707 .577 .707 r
F P
0 g
s
.46883 .77098 m .38557 .26764 L .4266 .25753 L p .707 .577 .707 r
F P
0 g
s
.38557 .26764 m .46883 .77098 L .43516 .78238 L p .707 .577 .707 r
F P
0 g
s
.51438 .24493 m .59765 .74827 L .55426 .75304 L p .707 .577 .707 r
F P
0 g
s
.55426 .75304 m .47099 .24971 L .51438 .24493 L p .707 .577 .707 r
F P
0 g
s
.67833 .73925 m .68389 .75746 L .70364 .75523 L p .707 .577 .707 r
F P
0 g
s
.83603 .69425 m .84159 .71246 L .85773 .70356 L p .707 .577 .707 r
F P
0 g
s
.85773 .70356 m .85217 .68536 L .83603 .69425 L p .707 .577 .707 r
F P
0 g
s
.83435 .56558 m .84363 .62132 L .85078 .6138 L p .707 .577 .707 r
F P
0 g
s
.85078 .6138 m .84151 .55806 L .83435 .56558 L p .707 .577 .707 r
F P
0 g
s
.64302 .59322 m .6523 .64896 L .66457 .65304 L p .707 .577 .707 r
F P
0 g
s
.50987 .76087 m .4266 .25753 L .47099 .24971 L p .707 .577 .707 r
F P
0 g
s
.4266 .25753 m .50987 .76087 L .46883 .77098 L p .707 .577 .707 r
F P
0 g
s
.67602 .71724 m .66603 .6806 L .65427 .6789 L p .707 .577 .707 r
F P
0 g
s
.47099 .24971 m .55426 .75304 L .50987 .76087 L p .707 .577 .707 r
F P
0 g
s
.84133 .63177 m .85133 .66842 L .8586 .66142 L p .707 .577 .707 r
F P
0 g
s
.8586 .66142 m .8486 .62477 L .84133 .63177 L p .707 .577 .707 r
F P
0 g
s
.65427 .6789 m .66427 .71555 L .67602 .71724 L p .707 .577 .707 r
F P
0 g
s
.6523 .64896 m .64302 .59322 L .64033 .58712 L p .707 .577 .707 r
F P
0 g
s
.68389 .75746 m .67833 .73925 L .66678 .73826 L p .707 .577 .707 r
F P
0 g
s
.66678 .73826 m .67235 .75647 L .68389 .75746 L p .707 .577 .707 r
F P
0 g
s
.85217 .68536 m .85773 .70356 L .86505 .69673 L p .707 .577 .707 r
F P
0 g
s
.86505 .69673 m .85949 .67852 L .85217 .68536 L p .707 .577 .707 r
F P
0 g
s
.84151 .55806 m .85078 .6138 L .84809 .6077 L p .707 .577 .707 r
F P
0 g
s
.84809 .6077 m .83881 .55196 L .84151 .55806 L p .707 .577 .707 r
F P
0 g
s
.64033 .58712 m .6496 .64286 L .6523 .64896 L p .707 .577 .707 r
F P
0 g
s
.66427 .71555 m .65427 .6789 L .65191 .67433 L p .707 .577 .707 r
F P
0 g
s
.65191 .67433 m .66191 .71098 L .66427 .71555 L p .707 .577 .707 r
F P
0 g
s
.8486 .62477 m .8586 .66142 L .85624 .65685 L p .707 .577 .707 r
F P
0 g
s
.85624 .65685 m .84624 .6202 L .8486 .62477 L p .707 .577 .707 r
F P
0 g
s
.67235 .75647 m .66678 .73826 L .66456 .73415 L p .707 .577 .707 r
F P
0 g
s
.6496 .64286 m .64033 .58712 L .64748 .57959 L p .707 .577 .707 r
F P
0 g
s
.66456 .73415 m .67012 .75235 L .67235 .75647 L p .707 .577 .707 r
F P
0 g
s
.85949 .67852 m .86505 .69673 L .86282 .69261 L p .707 .577 .707 r
F P
0 g
s
.86282 .69261 m .85726 .6744 L .85949 .67852 L p .707 .577 .707 r
F P
0 g
s
.83881 .55196 m .84809 .6077 L .83581 .60362 L p .707 .577 .707 r
F P
0 g
s
.83581 .60362 m .82654 .54788 L .83881 .55196 L p .707 .577 .707 r
F P
0 g
s
.64748 .57959 m .65676 .63533 L .6496 .64286 L p .707 .577 .707 r
F P
0 g
s
.66191 .71098 m .65191 .67433 L .65918 .66733 L p .707 .577 .707 r
F P
0 g
s
.39996 .61843 m .39069 .56269 L .35996 .5661 L p .707 .577 .707 r
F P
0 g
s
.39069 .56269 m .39996 .61843 L .4314 .61286 L p .707 .577 .707 r
F P
0 g
s
.4314 .61286 m .42213 .55712 L .39069 .56269 L p .707 .577 .707 r
F P
0 g
s
.42213 .55712 m .4314 .61286 L .46047 .60568 L p .707 .577 .707 r
F P
0 g
s
.46047 .60568 m .4512 .54994 L .42213 .55712 L p .707 .577 .707 r
F P
0 g
s
.65918 .66733 m .66918 .70398 L .66191 .71098 L p .707 .577 .707 r
F P
0 g
s
.84624 .6202 m .85624 .65685 L .84449 .65515 L p .707 .577 .707 r
F P
0 g
s
.84449 .65515 m .83449 .61851 L .84624 .6202 L p .707 .577 .707 r
F P
0 g
s
.65676 .63533 m .64748 .57959 L .66378 .57139 L p .707 .577 .707 r
F P
0 g
s
.67012 .75235 m .66456 .73415 L .67187 .72731 L p .707 .577 .707 r
F P
0 g
s
.36923 .62184 m .35996 .5661 L .33295 .56702 L p .707 .577 .707 r
F P
0 g
s
.35996 .5661 m .36923 .62184 L .39996 .61843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.67187 .72731 m .67743 .74551 L .67012 .75235 L p .707 .577 .707 r
F P
0 g
s
.4512 .54994 m .46047 .60568 L .48432 .59759 L p .707 .577 .707 r
F P
0 g
s
.48432 .59759 m .47505 .54185 L .4512 .54994 L p .707 .577 .707 r
F P
0 g
s
.85726 .6744 m .86282 .69261 L .85127 .69162 L p .707 .577 .707 r
F P
0 g
s
.85127 .69162 m .84571 .67341 L .85726 .6744 L p .707 .577 .707 r
F P
0 g
s
.82654 .54788 m .83581 .60362 L .81515 .60195 L p .707 .577 .707 r
F P
0 g
s
.81515 .60195 m .80588 .54621 L .82654 .54788 L p .707 .577 .707 r
F P
0 g
s
.66378 .57139 m .67306 .62712 L .65676 .63533 L p .707 .577 .707 r
F P
0 g
s
.4093 .67947 m .3993 .64283 L .3693 .64957 L p .707 .577 .707 r
F P
0 g
s
.3993 .64283 m .4093 .67947 L .44008 .6709 L p .707 .577 .707 r
F P
0 g
s
.44008 .6709 m .43008 .63425 L .3993 .64283 L p .707 .577 .707 r
F P
0 g
s
.33295 .56702 m .34222 .62276 L .36923 .62184 L p .707 .577 .707 r
F P
0 g
s
.43008 .63425 m .44008 .6709 L .46862 .66133 L p .707 .577 .707 r
F P
0 g
s
.46862 .66133 m .45862 .62469 L .43008 .63425 L p .707 .577 .707 r
F P
0 g
s
.3693 .64957 m .3793 .68621 L .4093 .67947 L p .707 .577 .707 r
F P
0 g
s
.34222 .62276 m .33295 .56702 L .31229 .56536 L p .707 .577 .707 r
F P
0 g
s
.66918 .70398 m .65918 .66733 L .67537 .6586 L p .707 .577 .707 r
F P
0 g
s
.3793 .68621 m .3693 .64957 L .34301 .65382 L p .707 .577 .707 r
F P
0 g
s
.45862 .62469 m .46862 .66133 L .49213 .65171 L p .707 .577 .707 r
F P
0 g
s
.49213 .65171 m .48213 .61507 L .45862 .62469 L p .707 .577 .707 r
F P
0 g
s
.41634 .72595 m .41078 .70775 L .38107 .71548 L p .707 .577 .707 r
F P
0 g
s
.41078 .70775 m .41634 .72595 L .44686 .71649 L p .707 .577 .707 r
F P
0 g
s
.44686 .71649 m .4413 .69829 L .41078 .70775 L p .707 .577 .707 r
F P
0 g
s
.83449 .61851 m .84449 .65515 L .82449 .65649 L p .707 .577 .707 r
F P
0 g
s
.82449 .65649 m .81449 .61985 L .83449 .61851 L p .707 .577 .707 r
F P
0 g
s
.67537 .6586 m .68537 .69524 L .66918 .70398 L p .707 .577 .707 r
F P
0 g
s
.47505 .54185 m .48432 .59759 L .50062 .58938 L p .707 .577 .707 r
F P
0 g
s
.50062 .58938 m .49134 .53364 L .47505 .54185 L p .707 .577 .707 r
F P
0 g
s
.67306 .62712 m .66378 .57139 L .68763 .56329 L p .707 .577 .707 r
F P
0 g
s
.4413 .69829 m .44686 .71649 L .4752 .70622 L p .707 .577 .707 r
F P
0 g
s
.4752 .70622 m .46964 .68802 L .4413 .69829 L p .707 .577 .707 r
F P
0 g
s
.34301 .65382 m .35301 .69046 L .3793 .68621 L p .707 .577 .707 r
F P
0 g
s
.38107 .71548 m .38663 .73368 L .41634 .72595 L p .707 .577 .707 r
F P
0 g
s
.31229 .56536 m .32156 .6211 L .34222 .62276 L p .707 .577 .707 r
F P
0 g
s
.67743 .74551 m .67187 .72731 L .68801 .71841 L p .707 .577 .707 r
F P
0 g
s
.80588 .54621 m .81515 .60195 L .78814 .60287 L p .707 .577 .707 r
F P
0 g
s
.78814 .60287 m .77887 .54713 L .80588 .54621 L p .707 .577 .707 r
F P
0 g
s
.68801 .71841 m .69357 .73662 L .67743 .74551 L p .707 .577 .707 r
F P
0 g
s
.38663 .73368 m .38107 .71548 L .35506 .72071 L p .707 .577 .707 r
F P
0 g
s
.84571 .67341 m .85127 .69162 L .83153 .69385 L p .707 .577 .707 r
F P
0 g
s
.83153 .69385 m .82597 .67564 L .84571 .67341 L p .707 .577 .707 r
F P
0 g
s
.46964 .68802 m .4752 .70622 L .49858 .69614 L p .707 .577 .707 r
F P
0 g
s
.49858 .69614 m .49302 .67794 L .46964 .68802 L p .707 .577 .707 r
F P
0 g
s
.35506 .72071 m .36063 .73891 L .38663 .73368 L p .707 .577 .707 r
F P
0 g
s
.68763 .56329 m .6969 .61903 L .67306 .62712 L p .707 .577 .707 r
F P
0 g
s
.35301 .69046 m .34301 .65382 L .32302 .65516 L p .707 .577 .707 r
F P
0 g
s
.32156 .6211 m .31229 .56536 L .30001 .56128 L p .707 .577 .707 r
F P
0 g
s
.48213 .61507 m .49213 .65171 L .50832 .64298 L p .707 .577 .707 r
F P
0 g
s
.50832 .64298 m .49832 .60633 L .48213 .61507 L p .707 .577 .707 r
F P
0 g
s
.32302 .65516 m .33301 .6918 L .35301 .69046 L p .707 .577 .707 r
F P
0 g
s
.68537 .69524 m .67537 .6586 L .69888 .64898 L p .707 .577 .707 r
F P
0 g
s
.6969 .61903 m .68763 .56329 L .7167 .55611 L p .707 .577 .707 r
F P
0 g
s
.81449 .61985 m .82449 .65649 L .7982 .66074 L p .707 .577 .707 r
F P
0 g
s
.7982 .66074 m .7882 .6241 L .81449 .61985 L p .707 .577 .707 r
F P
0 g
s
.77887 .54713 m .78814 .60287 L .75741 .60628 L p .707 .577 .707 r
F P
0 g
s
.75741 .60628 m .74814 .55054 L .77887 .54713 L p .707 .577 .707 r
F P
0 g
s
.69888 .64898 m .70888 .68562 L .68537 .69524 L p .707 .577 .707 r
F P
0 g
s
.49134 .53364 m .50062 .58938 L .50777 .58186 L p .707 .577 .707 r
F P
0 g
s
.50777 .58186 m .4985 .52612 L .49134 .53364 L p .707 .577 .707 r
F P
0 g
s
.36063 .73891 m .35506 .72071 L .33532 .72294 L p .707 .577 .707 r
F P
0 g
s
.30001 .56128 m .30929 .61702 L .32156 .6211 L p .707 .577 .707 r
F P
0 g
s
.33532 .72294 m .34088 .74114 L .36063 .73891 L p .707 .577 .707 r
F P
0 g
s
.49302 .67794 m .49858 .69614 L .51472 .68725 L p .707 .577 .707 r
F P
0 g
s
.51472 .68725 m .50916 .66905 L .49302 .67794 L p .707 .577 .707 r
F P
0 g
s
.72597 .61185 m .7167 .55611 L .74814 .55054 L p .707 .577 .707 r
F P
0 g
s
.7167 .55611 m .72597 .61185 L .6969 .61903 L p .707 .577 .707 r
F P
0 g
s
.69357 .73662 m .68801 .71841 L .71139 .70834 L p .707 .577 .707 r
F P
0 g
s
.74814 .55054 m .75741 .60628 L .72597 .61185 L p .707 .577 .707 r
F P
0 g
s
.71139 .70834 m .71695 .72654 L .69357 .73662 L p .707 .577 .707 r
F P
0 g
s
.82597 .67564 m .83153 .69385 L .80553 .69908 L p .707 .577 .707 r
F P
0 g
s
.80553 .69908 m .79997 .68088 L .82597 .67564 L p .707 .577 .707 r
F P
0 g
s
.33301 .6918 m .32302 .65516 L .31126 .65346 L p .707 .577 .707 r
F P
0 g
s
.70888 .68562 m .69888 .64898 L .72742 .63941 L p .707 .577 .707 r
F P
0 g
s
.7882 .6241 m .7982 .66074 L .7682 .66748 L p .707 .577 .707 r
F P
0 g
s
.7682 .66748 m .7582 .63084 L .7882 .6241 L p .707 .577 .707 r
F P
0 g
s
.49832 .60633 m .50832 .64298 L .51559 .63598 L p .707 .577 .707 r
F P
0 g
s
.51559 .63598 m .50559 .59933 L .49832 .60633 L p .707 .577 .707 r
F P
0 g
s
.31126 .65346 m .32126 .69011 L .33301 .6918 L p .707 .577 .707 r
F P
0 g
s
.72742 .63941 m .73742 .67606 L .70888 .68562 L p .707 .577 .707 r
F P
0 g
s
.30929 .61702 m .30001 .56128 L .29732 .55518 L p .707 .577 .707 r
F P
0 g
s
.73742 .67606 m .72742 .63941 L .7582 .63084 L p .707 .577 .707 r
F P
0 g
s
.71695 .72654 m .71139 .70834 L .73973 .69807 L p .707 .577 .707 r
F P
0 g
s
.7582 .63084 m .7682 .66748 L .73742 .67606 L p .707 .577 .707 r
F P
0 g
s
.34088 .74114 m .33532 .72294 L .32377 .72195 L p .707 .577 .707 r
F P
0 g
s
.79997 .68088 m .80553 .69908 L .77581 .70681 L p .707 .577 .707 r
F P
0 g
s
.77581 .70681 m .77025 .68861 L .79997 .68088 L p .707 .577 .707 r
F P
0 g
s
.73973 .69807 m .74529 .71627 L .71695 .72654 L p .707 .577 .707 r
F P
0 g
s
.32377 .72195 m .32933 .74015 L .34088 .74114 L p .707 .577 .707 r
F P
0 g
s
.4985 .52612 m .50777 .58186 L .50508 .57576 L p .707 .577 .707 r
F P
0 g
s
.50508 .57576 m .4958 .52002 L .4985 .52612 L p .707 .577 .707 r
F P
0 g
s
.50916 .66905 m .51472 .68725 L .52204 .68041 L p .707 .577 .707 r
F P
0 g
s
.52204 .68041 m .51648 .66221 L .50916 .66905 L p .707 .577 .707 r
F P
0 g
s
.29732 .55518 m .30659 .61092 L .30929 .61702 L p .707 .577 .707 r
F P
0 g
s
.74529 .71627 m .73973 .69807 L .77025 .68861 L p .707 .577 .707 r
F P
0 g
s
.77025 .68861 m .77581 .70681 L .74529 .71627 L p .707 .577 .707 r
F P
0 g
s
.32126 .69011 m .31126 .65346 L .3089 .64889 L p .707 .577 .707 r
F P
0 g
s
.3089 .64889 m .3189 .68554 L .32126 .69011 L p .707 .577 .707 r
F P
0 g
s
.50559 .59933 m .51559 .63598 L .51323 .63141 L p .707 .577 .707 r
F P
0 g
s
.51323 .63141 m .50323 .59476 L .50559 .59933 L p .707 .577 .707 r
F P
0 g
s
.30659 .61092 m .29732 .55518 L .30447 .54765 L p .707 .577 .707 r
F P
0 g
s
.32933 .74015 m .32377 .72195 L .32155 .71783 L p .707 .577 .707 r
F P
0 g
s
.32155 .71783 m .32711 .73603 L .32933 .74015 L p .707 .577 .707 r
F P
0 g
s
.51648 .66221 m .52204 .68041 L .51981 .67629 L p .707 .577 .707 r
F P
0 g
s
.51981 .67629 m .51425 .65809 L .51648 .66221 L p .707 .577 .707 r
F P
0 g
s
.4958 .52002 m .50508 .57576 L .4928 .57168 L p .707 .577 .707 r
F P
0 g
s
.4928 .57168 m .48353 .51594 L .4958 .52002 L p .707 .577 .707 r
F P
0 g
s
.30447 .54765 m .31375 .60339 L .30659 .61092 L p .707 .577 .707 r
F P
0 g
s
.3189 .68554 m .3089 .64889 L .31617 .64189 L p .707 .577 .707 r
F P
0 g
s
.31617 .64189 m .32617 .67854 L .3189 .68554 L p .707 .577 .707 r
F P
0 g
s
.50323 .59476 m .51323 .63141 L .50147 .62971 L p .707 .577 .707 r
F P
0 g
s
.50147 .62971 m .49148 .59307 L .50323 .59476 L p .707 .577 .707 r
F P
0 g
s
.31375 .60339 m .30447 .54765 L .32077 .53944 L p .707 .577 .707 r
F P
0 g
s
.32711 .73603 m .32155 .71783 L .32886 .71099 L p .707 .577 .707 r
F P
0 g
s
.32886 .71099 m .33442 .7292 L .32711 .73603 L p .707 .577 .707 r
F P
0 g
s
.48353 .51594 m .4928 .57168 L .47214 .57001 L p .707 .577 .707 r
F P
0 g
s
.47214 .57001 m .46287 .51427 L .48353 .51594 L p .707 .577 .707 r
F P
0 g
s
.51425 .65809 m .51981 .67629 L .50826 .6753 L p .707 .577 .707 r
F P
0 g
s
.50826 .6753 m .5027 .6571 L .51425 .65809 L p .707 .577 .707 r
F P
0 g
s
.32077 .53944 m .33004 .59518 L .31375 .60339 L p .707 .577 .707 r
F P
0 g
s
.32617 .67854 m .31617 .64189 L .33236 .63316 L p .707 .577 .707 r
F P
0 g
s
.33004 .59518 m .32077 .53944 L .34462 .53135 L p .707 .577 .707 r
F P
0 g
s
.49148 .59307 m .50147 .62971 L .48148 .63105 L p .707 .577 .707 r
F P
0 g
s
.48148 .63105 m .47148 .59441 L .49148 .59307 L p .707 .577 .707 r
F P
0 g
s
.33236 .63316 m .34236 .6698 L .32617 .67854 L p .707 .577 .707 r
F P
0 g
s
.46287 .51427 m .47214 .57001 L .44513 .57093 L p .707 .577 .707 r
F P
0 g
s
.44513 .57093 m .43586 .51519 L .46287 .51427 L p .707 .577 .707 r
F P
0 g
s
.33442 .7292 m .32886 .71099 L .345 .7021 L p .707 .577 .707 r
F P
0 g
s
.34462 .53135 m .35389 .58709 L .33004 .59518 L p .707 .577 .707 r
F P
0 g
s
.345 .7021 m .35056 .7203 L .33442 .7292 L p .707 .577 .707 r
F P
0 g
s
.5027 .6571 m .50826 .6753 L .48852 .67753 L p .707 .577 .707 r
F P
0 g
s
.48852 .67753 m .48296 .65933 L .5027 .6571 L p .707 .577 .707 r
F P
0 g
s
.35389 .58709 m .34462 .53135 L .37369 .52417 L p .707 .577 .707 r
F P
0 g
s
.34236 .6698 m .33236 .63316 L .35587 .62354 L p .707 .577 .707 r
F P
0 g
s
.43586 .51519 m .44513 .57093 L .4144 .57434 L p .707 .577 .707 r
F P
0 g
s
.4144 .57434 m .40513 .5186 L .43586 .51519 L p .707 .577 .707 r
F P
0 g
s
.47148 .59441 m .48148 .63105 L .45519 .6353 L p .707 .577 .707 r
F P
0 g
s
.45519 .6353 m .44519 .59866 L .47148 .59441 L p .707 .577 .707 r
F P
0 g
s
.35587 .62354 m .36587 .66018 L .34236 .6698 L p .707 .577 .707 r
F P
0 g
s
.38296 .57991 m .37369 .52417 L .40513 .5186 L p .707 .577 .707 r
F P
0 g
s
.37369 .52417 m .38296 .57991 L .35389 .58709 L p .707 .577 .707 r
F P
0 g
s
.40513 .5186 m .4144 .57434 L .38296 .57991 L p .707 .577 .707 r
F P
0 g
s
.35056 .7203 m .345 .7021 L .36838 .69202 L p .707 .577 .707 r
F P
0 g
s
.36838 .69202 m .37394 .71023 L .35056 .7203 L p .707 .577 .707 r
F P
0 g
s
.48296 .65933 m .48852 .67753 L .46252 .68277 L p .707 .577 .707 r
F P
0 g
s
.46252 .68277 m .45696 .66456 L .48296 .65933 L p .707 .577 .707 r
F P
0 g
s
.36587 .66018 m .35587 .62354 L .38441 .61397 L p .707 .577 .707 r
F P
0 g
s
.44519 .59866 m .45519 .6353 L .42519 .64204 L p .707 .577 .707 r
F P
0 g
s
.42519 .64204 m .41519 .6054 L .44519 .59866 L p .707 .577 .707 r
F P
0 g
s
.38441 .61397 m .39441 .65062 L .36587 .66018 L p .707 .577 .707 r
F P
0 g
s
.39441 .65062 m .38441 .61397 L .41519 .6054 L p .707 .577 .707 r
F P
0 g
s
.41519 .6054 m .42519 .64204 L .39441 .65062 L p .707 .577 .707 r
F P
0 g
s
.37394 .71023 m .36838 .69202 L .39672 .68175 L p .707 .577 .707 r
F P
0 g
s
.45696 .66456 m .46252 .68277 L .4328 .69049 L p .707 .577 .707 r
F P
0 g
s
.4328 .69049 m .42724 .67229 L .45696 .66456 L p .707 .577 .707 r
F P
0 g
s
.39672 .68175 m .40228 .69996 L .37394 .71023 L p .707 .577 .707 r
F P
0 g
s
.40228 .69996 m .39672 .68175 L .42724 .67229 L p .707 .577 .707 r
F P
0 g
s
.42724 .67229 m .4328 .69049 L .40228 .69996 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Sgoo4P00O7oo0029Ool6000BFUH7001eOol008=oo`H001mJEP<0079oo`00OGoo1P000UYF00<005YF
FUH08eYFLWoo001hOol50008FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUIbOol007Aoo`@00003FUH005YF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001oogoo06moo`00L7oo10001EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFLGoo001/Ool40009FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUIaOol0
06Uoo`<00003FUH005YF00]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001oogoo06ioo`00IWoo0`0015YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007oo
Ool0KWoo001SOol30008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1^Ool0065oo`800003FUH005YF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06ioo`00Ggoo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
L7oo001MOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUI`Ool005aoo`8000MJEP03001JEUYF
00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001oogoo06eoo`00Fgoo00<005YF00001eYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<007ooOol0KGoo001JOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006moo`00FWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06eoo`00FWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06eoo`00Fgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVmoo`00Fgoo00@005YF
FUH000MJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06aoo`00Fgoo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06aoo`00Fgoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001^Ool005]oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P00KWoo001KOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0K7oo001LOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYFKWoo001L
Ool01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Jgoo001LOol01000
FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Jgoo001LOol01@00FUIJEUYF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YF
FUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006eoo`00G7oo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYFFUH2001]Ool005aoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1[Ool005eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1[Ool005eoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
Oomoo`1ZOol005eoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1Z
Ool005eoo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00K7oo001MOol01@00
FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006aoo`00GGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYFFUH005YFK7oo001NOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0JWoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<007ooOol0JGoo001NOol01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
00<007ooOol0JGoo001NOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006]o
o`00GWoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001[Ool005ioo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEV]oo`00Ggoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Uoo`00Ggoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Yoo`00Ggoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001oogoo06Qoo`00Ggoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001ZOol005moo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JWoo001OOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Yoo`00H7oo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Qoo`00H7oo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Uoo`00H7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001oogoo06Moo`00H7oo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH2001YOol0061oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00JGoo001P
Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Uoo`00HGoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HGoo00@005YFFUH000MJEP03001JEUYF00IJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2
001XOol0065oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00J7oo001QOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEUYFFUH2001XOol0069oo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001WOol0069oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001WOol0069oo`05001JEUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00Igoo001ROol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Moo`00HWoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol0
1@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00Hgoo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH2001VOol006=oo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00I7oo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00I7oo00D005YFFUIJEP00
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUHC0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
IGoo001TOol01@00FUIJEUYF00001UYF00<005YF00001P000eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF
FUH2001UOol006Eoo`04001JEUYF0004FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8006Eoo`00IGoo00<005YFFUH01@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YF000000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Aoo`00I7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Aoo`00H7oo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001TOol005eoo`<00003FUH005YF00MJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001TOol005Yoo`<000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001TOol0
05Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH2001TOol005Ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000OOolC000a
Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000HOol70004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002000^Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0057oo10000UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00E7oo00@005YF
FUH000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2000@Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000]Ool005Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P0037oo
100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20008Ool40005FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Goo001EOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP<000=oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@00003FUH005YF
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0
000000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH0000]Ool005Eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000MJEP03001JEUYF00AJEP03001JEUYF009JEP@000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo
001EOol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH015YF1P001eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00@005YF000000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002aoo`00EGoo
00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001F
Ool00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001FOol00`00FUH00004
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01EYF00@005YFFUIJEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP80
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000/Ool005Ioo`03001JEP0000AJEP04
001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;7oo001FOol01000FUIJEP000eYF0`001eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF1`000UYF00<005YF00000P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000/Ool0
05Ioo`05001JEUYF001JEP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1P000eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000:goo001F
Ool00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH400000eYF
001JEP06FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH00UYF4`000UYF00<007ooOol0:Goo001AOol6000015YF001JEP001EYF00<005YFFUH0
15YF00<005YFFUH01eYF00<005YFFUH01@001UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
FUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000IJEP03001JEUYF00EJEP04001J
EUYFFUH4000[Ool004Yoo`L000=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000:goo0016Ool40002FUH00`00FUIJEP05FUH01000FUIJEP00
0eYF00<005YFFUH00UYF00<005YFFUH01EYF00@005YFFUIJEP@000IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000[Ool0045oo`D000IJEP03001JEUYF
00IJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH01P00FUH00000FUH000UJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7000/Ool003eoo`@0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50003FUH01000FUIJEUYF1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF100025YF
00<005YFFUH01eYF00<005YFFUH01EYF20000UYF00@005YF000002aoo`00>Goo10001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP060003FUH00`00FUIJEP04FUH01000FUH00000:goo000fOol300000eYF
001JEP07FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=J
EP@000MJEP03001JEUYF00IJEP03001JEUYF00EJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF000[Ool003=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00MJEP04001JEUYFFUH>0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01@001UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000aOol200000eYF001JEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH60005FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF10000UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00:Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP040004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUH00005FUH00`00FUIJEP05FUH01000FUIJEUYF10001eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YF000002Yoo`00;Woo0P0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1@001eYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00H005YF000005YF0009FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP00:Woo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P00
25YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH00eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00:Goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P001UYF00<005YFFUH01UYF00<005YFFUH015YF0`002UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH00`001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:Goo
000]Ool01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF100025YF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH010000eYF0`0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002Uoo`00;Goo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009J
EPL000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH70004FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=000YOol002ioo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP80
0003FUH005YF00AJEP03001JEUYF00AJEP@000MJEP03001JEUYF00MJEP03001JEUYF00IJEPL0009J
EP03001JEP00008000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP02
FUH00`00FUIJEP02000XOol002ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPH0009JEP03001JEUYF009JEP03001JEUYF009JEP80009JEP03
001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH00`00FUIJEP03FUH01000FUIJEP00
1UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000MJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYF000XOol002ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEPL000EJEP04001JEUYF0005FUH01000FUH0000015YF00<005YFFUH01eYF00<005YFFUH01eYF
0`0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH40007FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000YOol002ioo`04001JEUYF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH00`00FUH00004
FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUIJEUYF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF00<007ooOol0:Goo000^Ool01000FUIJEP000eYF00<005YFFUH01EYF
00<005YFFUH015YF100000=JEP00FUH01eYF00<005YFFUH015YF00D005YFFUH005YF008000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH40007FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP00008000IJEP03001JEUYF00IJEP03001J
EUYF00EJEPL002Uoo`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YFFUH01UYF
10000UYF00<005YFFUH01UYF00<005YFFUH015YF300015YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000QJEP03001J
EUYF00IJEP03001JEP0000H0009JEP03001JEUYF008002Qoo`00;goo00<005YF000015YF00<005YF
FUH00eYF1@0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH00UYF10001eYF00<005YFFUH01UYF00<005YF00001@0000=JEP00FUH00eYF00@005YF
FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP04001JEUYFFUH60003FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000:7oo000_Ool00`00FUH00004FUH00`00FUH000030004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH01EYF00H005YF
000005YF0009FUH00`00FUIJEP05FUH30002FUH20003FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH200000eYF001JEP03FUH00`00FUIJEP04FUH40007
FUH00`00FUIJEP07FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00:7oo000_
Ool01000FUIJEP000eYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
0UYF00<005YFFUH00eYF00@005YFFUIJEPD000AJEP03001JEUYF00MJEP03001JEUYF00@0009JEP<0
00IJEP04001JEUYFFUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEP000eYF00<005YFFUH00UYF0P000eYF00<005YFFUH01EYF00<005YFFUH00eYF10001UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Moo`00;goo00D005YFFUH005YF008000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUHD0007FUH00`00FUIJ
EP06FUH40003FUH300000eYF001JEP06FUH01000FUH000002EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJ
EP0200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP07000WOol002moo`03001JEUYF0080
00EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP@00003FUH005YF00IJEP03001J
EUYF00=JEP@000QJEP03001JEUYF00=JEP<000EJEP<000AJEP03001JEUYF00AJEP8000]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF00=JEP8000QJEP03001JEUYF
00EJEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEPH000=JEP04001JEUYF000WOol0031oo`04
FUH005YF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH01000FUIJEUYF1@001UYF00<005YFFUH0
1EYF00@005YFFUIJEP8000=JEP03001JEUYF00IJEP03001JEP0000<000AJEP<000MJEP03001JEUYF
009JEP<000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF009J
EP03001JEP0000QJEP03001JEUYF009JEP<000MJEP03001JEUYF00EJEPH00005Ool00000FUH00005
FUH00`00FUH0000WOol0031oo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000001EYF00<005YFFUH01EYF0`000eYF00<0
05YF00000P0000=JEP00FUH025YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001JEUYF0080
0003FUH005YF00QJEP03001JEUYF00@000Eoo`8000AJEP03001JEUYF009JEP8002Qoo`00<7oo00D0
05YFFUIJEP0000AJEP03001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30007FUH00`00FUIJEP050004FUH30005FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP0;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJ
EP05FUH30003FUH00`00FUIJEP06FUH40006Ool30006FUH00`00FUIJEP02FUH00`00Oomoo`0WOol0
031oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP06001JEP00001JEP002EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF1@000eYF00<005YF00000P0025YF00<005YF
FUH00eYF0P0025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000AJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP<000Qoo`800003FUH0
05YF00MJEP04001JEP00000ZOol0039oo`D000=JEP03001JEUYF00=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF10000goo1@0000=JEP00FUH02EYF
00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0P000eYF00<005YFFUH00UYF00H005YF000005YF0008FUH00`00FUH000020008Ool30004FUH0
0`00FUIJEP04FUH3000/Ool003Moo`T000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
008000EJEP04001JEP000002FUH60006FUH00`00FUIJEP06FUH300000eYF001JEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH<0003FUH00`00FUIJEP05FUH3
0008Ool30007FUH00`00FUIJEP02FUH2000_Ool003]oo`800003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001J
EUYF00=JEP<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYFFUH005YF10001UYF00<005YFFUH00UYF1@0017oo100000=JEP00
FUH025YF00@005YF0000035oo`00>Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01eYF0P000UYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP07FUH00`00FUH000020008FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0000=JEP00FUH01UYF00<005YF00002`001UYF00<005YFFUH01EYF0`00<goo000f
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40003FUH30003FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH5000:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH015YF0P000goo1@00
00=JEP00FUH01eYF00<005YFFUH00eYF0P00=Woo000dOol200000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YF
FUH010001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`001EYF00<005YFFUH00UYF0`000goo1@000UYF00<005YFFUH0
1eYF00<005YF00000P00>7oo000bOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH50007FUH300000eYF001JEP03FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP04FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEP001EYF00D005YF000005YF00D000MJEP03001JEUYF00IJEP<003]oo`00
<Goo0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YFFUH0
1EYF0P000UYF00<005YFFUH00eYF00<005YF00000`000goo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYF0004FUH60003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3000nOol0031oo`04001J
EUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP06FUH;
0007Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P000UYF00@005YF0000009JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEP000080045oo`00<7oo00@005YFFUH000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP@000QJEP03001JEUYF00IJEP03001JEUYF00AJEP8000Uoo`05001JEUYFFUH00005
FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH30014Ool0
035oo`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP8000]oo`05001JEUYFFUH00005FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP0;FUH00`00FUIJEP07FUHB0004FUH01@00FUH005YF00001EYF00<005YFFUH0
1EYF00<005YFFUH01000Agoo000aOol00`00FUH00005FUH00`00FUIJEP04FUH40007FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUH0000;0003Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF
00<005YFFUH05UYF00@005YFFUIJEPH000MJEP03001JEUYF00IJEP03001JEP0000D0009JEP03001J
EUYF00AJEP04001JEUYFFUH6001;Ool0035oo`04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH400000eYF001JEP03FUH01@00FUIJEUYF
000017oo0eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH04eYF200035YF00<005YFFUH0
1UYF00<005YFFUH015YF0P000UYF00@005YFFUIJEPH00003FUH007oo04ioo`00<Goo00@005YFFUH0
00EJEP04001JEP000004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00
FUIJEP03FUH01000FUIJEP0017oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00eJEPH0
00IJEP<000]JEP03001JEUYF00MJEP03001JEUYF00AJEPL000AJEP<0051oo`00<Woo00<005YF0000
1EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF100000=JEP00FUH01eYF00<005YFFUH00UYF
00D005YFFUIJEP0000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH500000eYF
001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
001JEP03FUH00`00Oomoo`1@Ool0039oo`03001JEP0000=JEP800003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003Ool0
1@00FUIJEUYF00001EYF00<005YFFUH03UYF10001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00009JEPL0051oo`00<Woo00<005YFFUH00`00
15YF00<005YFFUH015YF00<005YFFUH01eYF100000=JEP00FUH01eYF00<005YFFUH015YF30000Woo
00D005YFFUIJEP0000EJEP03001JEUYF00YJEP@000YJEP03001JEUYF00UJEP8000aJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP0000@0009JEP04001JEUYF001@Ool0039oo`03001JEUYF0080
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP<000EJEP03001JEUYF00IJEP03001JEP0000D00003
FUH005YF00=JEP04001JEUYF0002Ool01@00FUIJEUYF00003eYF0`000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF0P0035YF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF00D005YF
FUIJEP0004moo`00<goo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03001J
EUYF00EJEP<0009oo`8000=JEP03001JEUYF00=JEP8000Aoo`=JEP03001JEUYF00YJEP<000EJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00=JEP03001JEUYF00=JEP04001JEUYF001?Ool003=oo`80009JEP03001JEUYF00=JEP04001JEUYF
FUH700000eYF001JEP09FUH00`00FUIJEP040002Ool30005FUH00`00FUIJEP03FUH00`00Oomoo`03
Ool3FUH00`00FUIJEP06FUH40008FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH01000FUIJEUYF0P001EYF00<005YFFUH00eYF00@005YFFUH004moo`00=7oo4000
1UYF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00<005YFFUH00P001Woo00@005YFFUH0
00IJEP800003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEP00008000MJEP03001JEUYF00@0009JEP03001oogoo04aoo`00?goo0`0025YF
00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0`0027oo00<005YFFUH01EYF0P000eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
0`000UYF00<005YFFUH00UYF1P000eYF1000CWoo000mOol20003FUH00`00FUIJEP06FUH00`00FUH0
00020005Ool30007FUH00`00FUIJEP03FUH2000:Ool00`00FUIJEP03FUH20005FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH30004FUH60000
1Goo000005YF00001EYF00<005YF0000CWoo000kOol20005FUH00`00FUIJEP05FUH30005Ool30000
0eYF001JEP08FUH00`00FUH00002000<Ool01000FUIJEUYF0`001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF00000P001EYF0P001Goo0P0015YF00<0
05YFFUH00UYF0P00Cgoo000iOol30006FUH00`00FUIJEP03FUH20005Ool30005FUH00`00FUIJEP05
FUH3000@Ool2FUH01000FUIJEP001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF0`000eYF00<005YF00000P0017oo0`001UYF00<005YFFUH00UYF00<007ooOol0
CWoo000gOol20002FUH00`00FUIJEP05FUH00`00FUH000020004Ool30008FUH00`00FUIJEP03FUH2
000COol00eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0;FUH00`00FUIJEP04FUH40004FUH40005Ool200000eYF001JEP07FUH01000FUH00000DGoo000f
Ool00`00FUIJEP03FUH00`00FUIJEP03FUH30003Ool400000eYF001JEP09FUH00`00FUH00002000E
Ool00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP04
000015YF001JEUYF10001Woo0`0015YF00<005YFFUH015YF0`00Dgoo000eOol20005FUH00`00FUH0
00030002Ool40006FUH00`00FUIJEP06FUH3000HOol2000SFUH00`00FUIJEP07FUH60004FUH40007
Ool30007FUH00`00FUIJEP02FUH2001FOol003Aoo`04001JEUYF0004FUH20002Ool400000eYF001J
EP07FUH00`00FUIJEP03FUH3000LOol00`00FUIJEP02FUH00`00FUIJEP0LFUH01000FUIJEUYF1P00
0eYF00<005YFFUH00UYF10001goo0P0000=JEP00FUH025YF00@005YF000005Qoo`00=7oo00@005YF
FUH000=JEPD000EJEP03001JEUYF00MJEP03001JEP00008001moo`<0009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00MJEPH00003FUH005YF00IJEP03001JEP0000L000=oo`<000AJEP03
001JEUYF00EJEP<005Yoo`00=Goo00<005YFFUH00`000UYF00<005YFFUH01UYF00<005YFFUH015YF
10009Goo1P0015YF00<005YFFUH025YF00@005YFFUIJEPH0009oo`8000AJEP03001JEUYF00AJEP80
00=oo`P000MJEP03001JEUYF00=JEP8005eoo`00=Goo00@005YFFUH000EJEP03001JEUYF00EJEP03
001JEUYF00@002mooa<000Moo`8000EJEP03001JEUYF009JEP8000Eoo`D00003FUH005YF00QJEP03
001JEP00008005moo`00=Woo00AJEP00FUH000AJEP03001JEUYF00AJEP@004aoo`04001JEUYF0005
FUH01@00FUH00000Ool01P0000AJEP000000009JEP03001JEUYF00IJEP<0069oo`00=Woo00@005YF
FUH000EJEP03001JEP0000<0051oo`04001JEUYF0005FUH50003FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH3001UOol003Ioo`/005Eoo`03001JEP0000=JEP800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEP00008006Qoo`00UWoo00<005YFFUH00`0015YF00<005YFFUH015YF00<005YFFUH01EYF
0`00Jgoo002FOol00`00FUIJEP020005FUH00`00FUIJEP05FUH00`00FUIJEP04001^Ool009Moo`04
FUH005YF0006FUH01000FUIJEUYF1P00LWoo002GOol20002FUH01000FUIJEUYF1P00N7oo002HOol7
001nOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]5\[InvisibleSpace]"     "\
\[InvisibleSpace]2.3598988957761797`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 5, "     ", 2.3598988957761797, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .73291 m .59613 .67732 L .56496 .67542 L p .707 .577 .707 r
F P
0 g
s
.59613 .67732 m .59613 .73291 L .62796 .73213 L p .707 .577 .707 r
F P
0 g
s
.62796 .73213 m .62796 .67655 L .59613 .67732 L p .707 .577 .707 r
F P
0 g
s
.62796 .67655 m .62796 .73213 L .65734 .72875 L p .707 .577 .707 r
F P
0 g
s
.65734 .72875 m .65734 .67317 L .62796 .67655 L p .707 .577 .707 r
F P
0 g
s
.56496 .73101 m .56496 .67542 L .5375 .67103 L p .707 .577 .707 r
F P
0 g
s
.56496 .67542 m .56496 .73101 L .59613 .73291 L p .707 .577 .707 r
F P
0 g
s
.65734 .67317 m .65734 .72875 L .6814 .7231 L p .707 .577 .707 r
F P
0 g
s
.6814 .7231 m .6814 .66752 L .65734 .67317 L p .707 .577 .707 r
F P
0 g
s
.59613 .77117 m .59613 .73411 L .56496 .73221 L p .707 .577 .707 r
F P
0 g
s
.59613 .73411 m .59613 .77117 L .62796 .77039 L p .707 .577 .707 r
F P
0 g
s
.62796 .77039 m .62796 .73333 L .59613 .73411 L p .707 .577 .707 r
F P
0 g
s
.62796 .73333 m .62796 .77039 L .65735 .76701 L p .707 .577 .707 r
F P
0 g
s
.65735 .76701 m .65734 .72995 L .62796 .73333 L p .707 .577 .707 r
F P
0 g
s
.5375 .67103 m .5375 .72661 L .56496 .73101 L p .707 .577 .707 r
F P
0 g
s
.5375 .72661 m .5375 .67103 L .51644 .66458 L p .707 .577 .707 r
F P
0 g
s
.56496 .76926 m .56496 .73221 L .5375 .72782 L p .707 .577 .707 r
F P
0 g
s
.56496 .73221 m .56496 .76926 L .59613 .77117 L p .707 .577 .707 r
F P
0 g
s
.59613 .78456 m .59613 .76603 L .56496 .76413 L p .707 .577 .707 r
F P
0 g
s
.59613 .76603 m .59613 .78456 L .62796 .78378 L p .707 .577 .707 r
F P
0 g
s
.62796 .78378 m .62796 .76525 L .59613 .76603 L p .707 .577 .707 r
F P
0 g
s
.62796 .76525 m .62796 .78378 L .65735 .7804 L p .707 .577 .707 r
F P
0 g
s
.65735 .7804 m .65735 .76188 L .62796 .76525 L p .707 .577 .707 r
F P
0 g
s
.56496 .76413 m .56496 .78266 L .59613 .78456 L p .707 .577 .707 r
F P
0 g
s
.65734 .72995 m .65735 .76701 L .6814 .76136 L p .707 .577 .707 r
F P
0 g
s
.6814 .76136 m .6814 .7243 L .65734 .72995 L p .707 .577 .707 r
F P
0 g
s
.56496 .78266 m .56496 .76413 L .5375 .75974 L p .707 .577 .707 r
F P
0 g
s
.5375 .72782 m .5375 .76487 L .56496 .76926 L p .707 .577 .707 r
F P
0 g
s
.6814 .66752 m .6814 .7231 L .69777 .71573 L p .707 .577 .707 r
F P
0 g
s
.69777 .71573 m .69777 .66015 L .6814 .66752 L p .707 .577 .707 r
F P
0 g
s
.5375 .75974 m .5375 .77827 L .56496 .78266 L p .707 .577 .707 r
F P
0 g
s
.51644 .66458 m .51644 .72016 L .5375 .72661 L p .707 .577 .707 r
F P
0 g
s
.5375 .76487 m .5375 .72782 L .51644 .72136 L p .707 .577 .707 r
F P
0 g
s
.65735 .76188 m .65735 .7804 L .6814 .77475 L p .707 .577 .707 r
F P
0 g
s
.6814 .77475 m .6814 .75623 L .65735 .76188 L p .707 .577 .707 r
F P
0 g
s
.51644 .72016 m .51644 .66458 L .50385 .65669 L p .707 .577 .707 r
F P
0 g
s
.5375 .77827 m .5375 .75974 L .51644 .75329 L p .707 .577 .707 r
F P
0 g
s
.51644 .72136 m .51644 .75842 L .5375 .76487 L p .707 .577 .707 r
F P
0 g
s
.6814 .7243 m .6814 .76136 L .69777 .75399 L p .707 .577 .707 r
F P
0 g
s
.69777 .75399 m .69777 .71694 L .6814 .7243 L p .707 .577 .707 r
F P
0 g
s
.51644 .75329 m .51644 .77181 L .5375 .77827 L p .707 .577 .707 r
F P
0 g
s
.6814 .75623 m .6814 .77475 L .69777 .76739 L p .707 .577 .707 r
F P
0 g
s
.69777 .76739 m .69777 .74886 L .6814 .75623 L p .707 .577 .707 r
F P
0 g
s
.50385 .65669 m .50385 .71228 L .51644 .72016 L p .707 .577 .707 r
F P
0 g
s
.51644 .75842 m .51644 .72136 L .50385 .71348 L p .707 .577 .707 r
F P
0 g
s
.69777 .66015 m .69777 .71573 L .70485 .70737 L p .707 .577 .707 r
F P
0 g
s
.70485 .70737 m .70485 .65179 L .69777 .66015 L p .707 .577 .707 r
F P
0 g
s
.51644 .77181 m .51644 .75329 L .50385 .7454 L p .707 .577 .707 r
F P
0 g
s
.50385 .71348 m .50385 .75053 L .51644 .75842 L p .707 .577 .707 r
F P
0 g
s
.50385 .71228 m .50385 .65669 L .50095 .64815 L p .707 .577 .707 r
F P
0 g
s
.50385 .7454 m .50385 .76393 L .51644 .77181 L p .707 .577 .707 r
F P
0 g
s
.69777 .71694 m .69777 .75399 L .70485 .74563 L p .707 .577 .707 r
F P
0 g
s
.70485 .74563 m .70485 .70857 L .69777 .71694 L p .707 .577 .707 r
F P
0 g
s
.49044 .72587 m .49044 .22399 L .44643 .2213 L p .707 .577 .707 r
F P
0 g
s
.50095 .64815 m .50095 .70373 L .50385 .71228 L p .707 .577 .707 r
F P
0 g
s
.50385 .75053 m .50385 .71348 L .50095 .70494 L p .707 .577 .707 r
F P
0 g
s
.50095 .70494 m .50095 .74199 L .50385 .75053 L p .707 .577 .707 r
F P
0 g
s
.50095 .70373 m .50095 .64815 L .50804 .63979 L p .707 .577 .707 r
F P
0 g
s
.50804 .63979 m .50804 .69537 L .50095 .70373 L p .707 .577 .707 r
F P
0 g
s
.50385 .76393 m .50385 .7454 L .50095 .73686 L p .707 .577 .707 r
F P
0 g
s
.50095 .73686 m .50095 .75539 L .50385 .76393 L p .707 .577 .707 r
F P
0 g
s
.50095 .74199 m .50095 .70494 L .50804 .69657 L p .707 .577 .707 r
F P
0 g
s
.50804 .69657 m .50804 .73363 L .50095 .74199 L p .707 .577 .707 r
F P
0 g
s
.50804 .69537 m .50804 .63979 L .5244 .63242 L p .707 .577 .707 r
F P
0 g
s
.5244 .63242 m .5244 .688 L .50804 .69537 L p .707 .577 .707 r
F P
0 g
s
.50804 .73363 m .50804 .69657 L .5244 .68921 L p .707 .577 .707 r
F P
0 g
s
.50804 .74702 m .50804 .72849 L .5244 .72113 L p .707 .577 .707 r
F P
0 g
s
.5244 .68921 m .5244 .72626 L .50804 .73363 L p .707 .577 .707 r
F P
0 g
s
.5244 .688 m .5244 .63242 L .54846 .62677 L p .707 .577 .707 r
F P
0 g
s
.5244 .72113 m .5244 .73965 L .50804 .74702 L p .707 .577 .707 r
F P
0 g
s
.54846 .62677 m .54846 .68235 L .5244 .688 L p .707 .577 .707 r
F P
0 g
s
.5244 .72626 m .5244 .68921 L .54846 .68356 L p .707 .577 .707 r
F P
0 g
s
.5244 .73965 m .5244 .72113 L .54846 .71548 L p .707 .577 .707 r
F P
0 g
s
.54846 .68356 m .54846 .72061 L .5244 .72626 L p .707 .577 .707 r
F P
0 g
s
.49044 .22399 m .49044 .72587 L .53538 .72478 L p .707 .577 .707 r
F P
0 g
s
.53538 .72478 m .53538 .22289 L .49044 .22399 L p .707 .577 .707 r
F P
0 g
s
.54846 .68235 m .54846 .62677 L .57784 .62339 L p .707 .577 .707 r
F P
0 g
s
.54846 .71548 m .54846 .734 L .5244 .73965 L p .707 .577 .707 r
F P
0 g
s
.57784 .62339 m .57784 .67897 L .54846 .68235 L p .707 .577 .707 r
F P
0 g
s
.54846 .72061 m .54846 .68356 L .57784 .68018 L p .707 .577 .707 r
F P
0 g
s
.54846 .734 m .54846 .71548 L .57784 .7121 L p .707 .577 .707 r
F P
0 g
s
.57784 .68018 m .57784 .71723 L .54846 .72061 L p .707 .577 .707 r
F P
0 g
s
.57784 .7121 m .57784 .73063 L .54846 .734 L p .707 .577 .707 r
F P
0 g
s
.53538 .22289 m .53538 .72478 L .57686 .72001 L p .707 .577 .707 r
F P
0 g
s
.57686 .72001 m .57686 .21812 L .53538 .22289 L p .707 .577 .707 r
F P
0 g
s
.69777 .74886 m .69777 .76739 L .70485 .75902 L p .707 .577 .707 r
F P
0 g
s
.70485 .75902 m .70485 .74049 L .69777 .74886 L p .707 .577 .707 r
F P
0 g
s
.44643 .72319 m .44643 .2213 L .40766 .2151 L p .707 .577 .707 r
F P
0 g
s
.44643 .2213 m .44643 .72319 L .49044 .72587 L p .707 .577 .707 r
F P
0 g
s
.70485 .65179 m .70485 .70737 L .70195 .69883 L p .707 .577 .707 r
F P
0 g
s
.70195 .69883 m .70195 .64324 L .70485 .65179 L p .707 .577 .707 r
F P
0 g
s
.57784 .67897 m .57784 .62339 L .60968 .62261 L p .707 .577 .707 r
F P
0 g
s
.60968 .62261 m .60968 .6782 L .57784 .67897 L p .707 .577 .707 r
F P
0 g
s
.60968 .71645 m .60968 .6794 L .64085 .6813 L p .707 .577 .707 r
F P
0 g
s
.57784 .71723 m .57784 .68018 L .60968 .6794 L p .707 .577 .707 r
F P
0 g
s
.60968 .6794 m .60968 .71645 L .57784 .71723 L p .707 .577 .707 r
F P
0 g
s
.60968 .72985 m .60968 .71132 L .64085 .71322 L p .707 .577 .707 r
F P
0 g
s
.57784 .73063 m .57784 .7121 L .60968 .71132 L p .707 .577 .707 r
F P
0 g
s
.60968 .71132 m .60968 .72985 L .57784 .73063 L p .707 .577 .707 r
F P
0 g
s
.57686 .21812 m .57686 .72001 L .61082 .71203 L p .707 .577 .707 r
F P
0 g
s
.64085 .62451 m .64085 .6801 L .60968 .6782 L p .707 .577 .707 r
F P
0 g
s
.60968 .6782 m .60968 .62261 L .64085 .62451 L p .707 .577 .707 r
F P
0 g
s
.61082 .71203 m .61082 .21014 L .57686 .21812 L p .707 .577 .707 r
F P
0 g
s
.70485 .70857 m .70485 .74563 L .70195 .73709 L p .707 .577 .707 r
F P
0 g
s
.70195 .73709 m .70195 .70003 L .70485 .70857 L p .707 .577 .707 r
F P
0 g
s
.40766 .71699 m .40766 .2151 L .37794 .20599 L p .707 .577 .707 r
F P
0 g
s
.40766 .2151 m .40766 .71699 L .44643 .72319 L p .707 .577 .707 r
F P
0 g
s
.70485 .74049 m .70485 .75902 L .70195 .75048 L p .707 .577 .707 r
F P
0 g
s
.70195 .75048 m .70195 .73195 L .70485 .74049 L p .707 .577 .707 r
F P
0 g
s
.70195 .64324 m .70195 .69883 L .68936 .69094 L p .707 .577 .707 r
F P
0 g
s
.68936 .69094 m .68936 .63536 L .70195 .64324 L p .707 .577 .707 r
F P
0 g
s
.64085 .6813 m .64085 .71835 L .60968 .71645 L p .707 .577 .707 r
F P
0 g
s
.61082 .21014 m .61082 .71203 L .63393 .70163 L p .707 .577 .707 r
F P
0 g
s
.63393 .70163 m .63393 .19974 L .61082 .21014 L p .707 .577 .707 r
F P
0 g
s
.50095 .75539 m .50095 .73686 L .50804 .72849 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.25312 .69609 m .25312 .64051 L .22195 .63861 L p .707 .577 .707 r
F P
0 g
s
.25312 .64051 m .25312 .69609 L .28495 .69531 L p .707 .577 .707 r
F P
0 g
s
.28495 .69531 m .28495 .63973 L .25312 .64051 L p .707 .577 .707 r
F P
0 g
s
.50804 .72849 m .50804 .74702 L .50095 .75539 L p .707 .577 .707 r
F P
0 g
s
.28495 .63973 m .28495 .69531 L .31434 .69194 L p .707 .577 .707 r
F P
0 g
s
.31434 .69194 m .31434 .63635 L .28495 .63973 L p .707 .577 .707 r
F P
0 g
s
.70195 .70003 m .70195 .73709 L .68936 .7292 L p .707 .577 .707 r
F P
0 g
s
.68936 .7292 m .68936 .69215 L .70195 .70003 L p .707 .577 .707 r
F P
0 g
s
.22195 .69419 m .22195 .63861 L .19449 .63422 L p .707 .577 .707 r
F P
0 g
s
.22195 .63861 m .22195 .69419 L .25312 .69609 L p .707 .577 .707 r
F P
0 g
s
.37794 .70788 m .37794 .20599 L .36016 .19486 L p .707 .577 .707 r
F P
0 g
s
.37794 .20599 m .37794 .70788 L .40766 .71699 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70195 .73195 m .70195 .75048 L .68936 .7426 L p .707 .577 .707 r
F P
0 g
s
.68936 .7426 m .68936 .72407 L .70195 .73195 L p .707 .577 .707 r
F P
0 g
s
.31434 .63635 m .31434 .69194 L .33839 .68629 L p .707 .577 .707 r
F P
0 g
s
.33839 .68629 m .33839 .6307 L .31434 .63635 L p .707 .577 .707 r
F P
0 g
s
.25312 .73435 m .25312 .6973 L .22195 .69539 L p .707 .577 .707 r
F P
0 g
s
.25312 .6973 m .25312 .73435 L .28495 .73357 L p .707 .577 .707 r
F P
0 g
s
.28495 .73357 m .28495 .69652 L .25312 .6973 L p .707 .577 .707 r
F P
0 g
s
.68936 .63536 m .68936 .69094 L .66831 .68449 L p .707 .577 .707 r
F P
0 g
s
.66831 .68449 m .66831 .62891 L .68936 .63536 L p .707 .577 .707 r
F P
0 g
s
.28495 .69652 m .28495 .73357 L .31434 .73019 L p .707 .577 .707 r
F P
0 g
s
.31434 .73019 m .31434 .69314 L .28495 .69652 L p .707 .577 .707 r
F P
0 g
s
.19449 .63422 m .19449 .6898 L .22195 .69419 L p .707 .577 .707 r
F P
0 g
s
.19449 .6898 m .19449 .63422 L .17343 .62776 L p .707 .577 .707 r
F P
0 g
s
.22195 .73245 m .22195 .69539 L .19449 .691 L p .707 .577 .707 r
F P
0 g
s
.22195 .69539 m .22195 .73245 L .25312 .73435 L p .707 .577 .707 r
F P
0 g
s
.25312 .74774 m .25312 .72922 L .22195 .72732 L p .707 .577 .707 r
F P
0 g
s
.25312 .72922 m .25312 .74774 L .28495 .74697 L p .707 .577 .707 r
F P
0 g
s
.28495 .74697 m .28495 .72844 L .25312 .72922 L p .707 .577 .707 r
F P
0 g
s
.28495 .72844 m .28495 .74697 L .31434 .74359 L p .707 .577 .707 r
F P
0 g
s
.31434 .74359 m .31434 .72506 L .28495 .72844 L p .707 .577 .707 r
F P
0 g
s
.22195 .72732 m .22195 .74584 L .25312 .74774 L p .707 .577 .707 r
F P
0 g
s
.31434 .69314 m .31434 .73019 L .33839 .72454 L p .707 .577 .707 r
F P
0 g
s
.33839 .72454 m .33839 .68749 L .31434 .69314 L p .707 .577 .707 r
F P
0 g
s
.22195 .74584 m .22195 .72732 L .19449 .72292 L p .707 .577 .707 r
F P
0 g
s
.19449 .691 m .19449 .72806 L .22195 .73245 L p .707 .577 .707 r
F P
0 g
s
.66831 .62891 m .66831 .68449 L .64085 .6801 L p .707 .577 .707 r
F P
0 g
s
.64085 .6801 m .64085 .62451 L .66831 .62891 L p .707 .577 .707 r
F P
0 g
s
.64085 .71835 m .64085 .6813 L .66831 .68569 L p .707 .577 .707 r
F P
0 g
s
.63393 .19974 m .63393 .70163 L .64393 .68982 L p .707 .577 .707 r
F P
0 g
s
.64393 .68982 m .64393 .18793 L .63393 .19974 L p .707 .577 .707 r
F P
0 g
s
.68936 .69215 m .68936 .7292 L .66831 .72275 L p .707 .577 .707 r
F P
0 g
s
.66831 .72275 m .66831 .68569 L .68936 .69215 L p .707 .577 .707 r
F P
0 g
s
.33839 .6307 m .33839 .68629 L .35476 .67892 L p .707 .577 .707 r
F P
0 g
s
.35476 .67892 m .35476 .62334 L .33839 .6307 L p .707 .577 .707 r
F P
0 g
s
.19449 .72292 m .19449 .74145 L .22195 .74584 L p .707 .577 .707 r
F P
0 g
s
.17343 .62776 m .17343 .68334 L .19449 .6898 L p .707 .577 .707 r
F P
0 g
s
.19449 .72806 m .19449 .691 L .17343 .68455 L p .707 .577 .707 r
F P
0 g
s
.31434 .72506 m .31434 .74359 L .33839 .73794 L p .707 .577 .707 r
F P
0 g
s
.33839 .73794 m .33839 .71941 L .31434 .72506 L p .707 .577 .707 r
F P
0 g
s
.68936 .72407 m .68936 .7426 L .66831 .73614 L p .707 .577 .707 r
F P
0 g
s
.66831 .73614 m .66831 .71761 L .68936 .72407 L p .707 .577 .707 r
F P
0 g
s
.17343 .68334 m .17343 .62776 L .16084 .61988 L p .707 .577 .707 r
F P
0 g
s
.19449 .74145 m .19449 .72292 L .17343 .71647 L p .707 .577 .707 r
F P
0 g
s
.17343 .68455 m .17343 .7216 L .19449 .72806 L p .707 .577 .707 r
F P
0 g
s
.33839 .68749 m .33839 .72454 L .35476 .71718 L p .707 .577 .707 r
F P
0 g
s
.35476 .71718 m .35476 .68012 L .33839 .68749 L p .707 .577 .707 r
F P
0 g
s
.35476 .62334 m .35476 .67892 L .36184 .67055 L p .707 .577 .707 r
F P
0 g
s
.36184 .67055 m .36184 .61497 L .35476 .62334 L p .707 .577 .707 r
F P
0 g
s
.36184 .70881 m .36184 .67176 L .35476 .68012 L p .707 .577 .707 r
F P
0 g
s
.36184 .61497 m .36184 .67055 L .35894 .66201 L p .707 .577 .707 r
F P
0 g
s
.35894 .66201 m .35894 .60643 L .36184 .61497 L p .707 .577 .707 r
F P
0 g
s
.35476 .68012 m .35476 .71718 L .36184 .70881 L p .707 .577 .707 r
F P
0 g
s
.36184 .72221 m .36184 .70368 L .35476 .71204 L p .707 .577 .707 r
F P
0 g
s
.36184 .67176 m .36184 .70881 L .35894 .70027 L p .707 .577 .707 r
F P
0 g
s
.35894 .70027 m .35894 .66321 L .36184 .67176 L p .707 .577 .707 r
F P
0 g
s
.36016 .69675 m .36016 .19486 L .35607 .1828 L p .707 .577 .707 r
F P
0 g
s
.36016 .19486 m .36016 .69675 L .37794 .70788 L p .707 .577 .707 r
F P
0 g
s
.17343 .71647 m .17343 .735 L .19449 .74145 L p .707 .577 .707 r
F P
0 g
s
.66831 .68569 m .66831 .72275 L .64085 .71835 L p .707 .577 .707 r
F P
0 g
s
.33839 .71941 m .33839 .73794 L .35476 .73057 L p .707 .577 .707 r
F P
0 g
s
.35476 .73057 m .35476 .71204 L .33839 .71941 L p .707 .577 .707 r
F P
0 g
s
.16084 .61988 m .16084 .67546 L .17343 .68334 L p .707 .577 .707 r
F P
0 g
s
.17343 .7216 m .17343 .68455 L .16084 .67666 L p .707 .577 .707 r
F P
0 g
s
.66831 .71761 m .66831 .73614 L .64085 .73175 L p .707 .577 .707 r
F P
0 g
s
.64085 .73175 m .64085 .71322 L .66831 .71761 L p .707 .577 .707 r
F P
0 g
s
.17343 .735 m .17343 .71647 L .16084 .70859 L p .707 .577 .707 r
F P
0 g
s
.16084 .67666 m .16084 .71372 L .17343 .7216 L p .707 .577 .707 r
F P
0 g
s
.16084 .67546 m .16084 .61988 L .15794 .61134 L p .707 .577 .707 r
F P
0 g
s
.16084 .70859 m .16084 .72711 L .17343 .735 L p .707 .577 .707 r
F P
0 g
s
.64393 .18793 m .64393 .68982 L .63984 .67776 L p .707 .577 .707 r
F P
0 g
s
.63984 .67776 m .63984 .17587 L .64393 .18793 L p .707 .577 .707 r
F P
0 g
s
.64085 .71322 m .64085 .73175 L .60968 .72985 L p .707 .577 .707 r
F P
0 g
s
.35476 .71204 m .35476 .73057 L .36184 .72221 L p .707 .577 .707 r
F P
0 g
s
.15794 .61134 m .15794 .66692 L .16084 .67546 L p .707 .577 .707 r
F P
0 g
s
.16084 .71372 m .16084 .67666 L .15794 .66812 L p .707 .577 .707 r
F P
0 g
s
.35894 .60643 m .35894 .66201 L .34635 .65413 L p .707 .577 .707 r
F P
0 g
s
.34635 .65413 m .34635 .59854 L .35894 .60643 L p .707 .577 .707 r
F P
0 g
s
.35894 .66321 m .35894 .70027 L .34635 .69239 L p .707 .577 .707 r
F P
0 g
s
.34635 .69239 m .34635 .65533 L .35894 .66321 L p .707 .577 .707 r
F P
0 g
s
.35607 .1828 m .35607 .68469 L .36016 .69675 L p .707 .577 .707 r
F P
0 g
s
.35607 .68469 m .35607 .1828 L .36607 .17099 L p .707 .577 .707 r
F P
0 g
s
.16084 .72711 m .16084 .70859 L .15794 .70004 L p .707 .577 .707 r
F P
0 g
s
.15794 .66812 m .15794 .70518 L .16084 .71372 L p .707 .577 .707 r
F P
0 g
s
.15794 .70004 m .15794 .71857 L .16084 .72711 L p .707 .577 .707 r
F P
0 g
s
.15794 .66692 m .15794 .61134 L .16503 .60297 L p .707 .577 .707 r
F P
0 g
s
.36184 .70368 m .36184 .72221 L .35894 .71366 L p .707 .577 .707 r
F P
0 g
s
.35894 .71366 m .35894 .69514 L .36184 .70368 L p .707 .577 .707 r
F P
0 g
s
.63984 .17587 m .63984 .67776 L .62206 .66663 L p .707 .577 .707 r
F P
0 g
s
.62206 .66663 m .62206 .16474 L .63984 .17587 L p .707 .577 .707 r
F P
0 g
s
.16503 .60297 m .16503 .65855 L .15794 .66692 L p .707 .577 .707 r
F P
0 g
s
.15794 .70518 m .15794 .66812 L .16503 .65976 L p .707 .577 .707 r
F P
0 g
s
.15794 .71857 m .15794 .70004 L .16503 .69168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .65976 m .16503 .69681 L .15794 .70518 L p .707 .577 .707 r
F P
0 g
s
.16503 .69168 m .16503 .71021 L .15794 .71857 L p .707 .577 .707 r
F P
0 g
s
.16503 .65855 m .16503 .60297 L .1814 .5956 L p .707 .577 .707 r
F P
0 g
s
.36607 .67288 m .36607 .17099 L .38918 .16059 L p .707 .577 .707 r
F P
0 g
s
.36607 .17099 m .36607 .67288 L .35607 .68469 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .69514 m .35894 .71366 L .34635 .70578 L p .707 .577 .707 r
F P
0 g
s
.34635 .70578 m .34635 .68725 L .35894 .69514 L p .707 .577 .707 r
F P
0 g
s
.1814 .5956 m .1814 .65119 L .16503 .65855 L p .707 .577 .707 r
F P
0 g
s
.16503 .69681 m .16503 .65976 L .1814 .65239 L p .707 .577 .707 r
F P
0 g
s
.34635 .59854 m .34635 .65413 L .3253 .64767 L p .707 .577 .707 r
F P
0 g
s
.3253 .64767 m .3253 .59209 L .34635 .59854 L p .707 .577 .707 r
F P
0 g
s
.16503 .71021 m .16503 .69168 L .1814 .68431 L p .707 .577 .707 r
F P
0 g
s
.62206 .16474 m .62206 .66663 L .59233 .65752 L p .707 .577 .707 r
F P
0 g
s
.59233 .65752 m .59233 .15563 L .62206 .16474 L p .707 .577 .707 r
F P
0 g
s
.1814 .65239 m .1814 .68944 L .16503 .69681 L p .707 .577 .707 r
F P
0 g
s
.1814 .65119 m .1814 .5956 L .20545 .58995 L p .707 .577 .707 r
F P
0 g
s
.1814 .68431 m .1814 .70284 L .16503 .71021 L p .707 .577 .707 r
F P
0 g
s
.34635 .65533 m .34635 .69239 L .3253 .68593 L p .707 .577 .707 r
F P
0 g
s
.3253 .68593 m .3253 .64888 L .34635 .65533 L p .707 .577 .707 r
F P
0 g
s
.3253 .59209 m .3253 .64767 L .29784 .64328 L p .707 .577 .707 r
F P
0 g
s
.29784 .64328 m .29784 .5877 L .3253 .59209 L p .707 .577 .707 r
F P
0 g
s
.38918 .16059 m .38918 .66248 L .36607 .67288 L p .707 .577 .707 r
F P
0 g
s
.38918 .66248 m .38918 .16059 L .42314 .15261 L p .707 .577 .707 r
F P
0 g
s
.34635 .68725 m .34635 .70578 L .3253 .69933 L p .707 .577 .707 r
F P
0 g
s
.3253 .69933 m .3253 .6808 L .34635 .68725 L p .707 .577 .707 r
F P
0 g
s
.20545 .58995 m .20545 .64554 L .1814 .65119 L p .707 .577 .707 r
F P
0 g
s
.1814 .68944 m .1814 .65239 L .20545 .64674 L p .707 .577 .707 r
F P
0 g
s
.20545 .64554 m .20545 .58995 L .23483 .58657 L p .707 .577 .707 r
F P
0 g
s
.1814 .70284 m .1814 .68431 L .20545 .67866 L p .707 .577 .707 r
F P
0 g
s
.20545 .64674 m .20545 .68379 L .1814 .68944 L p .707 .577 .707 r
F P
0 g
s
.29784 .5877 m .29784 .64328 L .26667 .64138 L p .707 .577 .707 r
F P
0 g
s
.26667 .64138 m .26667 .5858 L .29784 .5877 L p .707 .577 .707 r
F P
0 g
s
.3253 .64888 m .3253 .68593 L .29784 .68154 L p .707 .577 .707 r
F P
0 g
s
.29784 .68154 m .29784 .64448 L .3253 .64888 L p .707 .577 .707 r
F P
0 g
s
.20545 .67866 m .20545 .69719 L .1814 .70284 L p .707 .577 .707 r
F P
0 g
s
.59233 .15563 m .59233 .65752 L .55357 .65132 L p .707 .577 .707 r
F P
0 g
s
.55357 .65132 m .55357 .14943 L .59233 .15563 L p .707 .577 .707 r
F P
0 g
s
.23483 .64216 m .23483 .58657 L .26667 .5858 L p .707 .577 .707 r
F P
0 g
s
.23483 .58657 m .23483 .64216 L .20545 .64554 L p .707 .577 .707 r
F P
0 g
s
.26667 .5858 m .26667 .64138 L .23483 .64216 L p .707 .577 .707 r
F P
0 g
s
.20545 .68379 m .20545 .64674 L .23483 .64336 L p .707 .577 .707 r
F P
0 g
s
.73333 .64087 m .73333 .58529 L .70216 .58339 L p .707 .577 .707 r
F P
0 g
s
.73333 .58529 m .73333 .64087 L .76517 .64009 L p .707 .577 .707 r
F P
0 g
s
.76517 .64009 m .76517 .58451 L .73333 .58529 L p .707 .577 .707 r
F P
0 g
s
.3253 .6808 m .3253 .69933 L .29784 .69493 L p .707 .577 .707 r
F P
0 g
s
.29784 .69493 m .29784 .67641 L .3253 .6808 L p .707 .577 .707 r
F P
0 g
s
.76517 .58451 m .76517 .64009 L .79455 .63671 L p .707 .577 .707 r
F P
0 g
s
.79455 .63671 m .79455 .58113 L .76517 .58451 L p .707 .577 .707 r
F P
0 g
s
.42314 .6545 m .42314 .15261 L .46462 .14784 L p .707 .577 .707 r
F P
0 g
s
.42314 .15261 m .42314 .6545 L .38918 .66248 L p .707 .577 .707 r
F P
0 g
s
.70216 .63897 m .70216 .58339 L .6747 .57899 L p .707 .577 .707 r
F P
0 g
s
.70216 .58339 m .70216 .63897 L .73333 .64087 L p .707 .577 .707 r
F P
0 g
s
.29784 .64448 m .29784 .68154 L .26667 .67964 L p .707 .577 .707 r
F P
0 g
s
.26667 .67964 m .26667 .64258 L .29784 .64448 L p .707 .577 .707 r
F P
0 g
s
.20545 .69719 m .20545 .67866 L .23483 .67528 L p .707 .577 .707 r
F P
0 g
s
.23483 .64336 m .23483 .68042 L .20545 .68379 L p .707 .577 .707 r
F P
0 g
s
.23483 .68042 m .23483 .64336 L .26667 .64258 L p .707 .577 .707 r
F P
0 g
s
.23483 .67528 m .23483 .69381 L .20545 .69719 L p .707 .577 .707 r
F P
0 g
s
.26667 .64258 m .26667 .67964 L .23483 .68042 L p .707 .577 .707 r
F P
0 g
s
.79455 .58113 m .79455 .63671 L .8186 .63106 L p .707 .577 .707 r
F P
0 g
s
.8186 .63106 m .8186 .57548 L .79455 .58113 L p .707 .577 .707 r
F P
0 g
s
.73333 .67913 m .73333 .64207 L .70216 .64017 L p .707 .577 .707 r
F P
0 g
s
.73333 .64207 m .73333 .67913 L .76517 .67835 L p .707 .577 .707 r
F P
0 g
s
.76517 .67835 m .76517 .64129 L .73333 .64207 L p .707 .577 .707 r
F P
0 g
s
.29784 .67641 m .29784 .69493 L .26667 .69303 L p .707 .577 .707 r
F P
0 g
s
.26667 .69303 m .26667 .67451 L .29784 .67641 L p .707 .577 .707 r
F P
0 g
s
.55357 .14943 m .55357 .65132 L .50956 .64863 L p .707 .577 .707 r
F P
0 g
s
.50956 .64863 m .50956 .14674 L .55357 .14943 L p .707 .577 .707 r
F P
0 g
s
.76517 .64129 m .76517 .67835 L .79455 .67497 L p .707 .577 .707 r
F P
0 g
s
.79455 .67497 m .79455 .63792 L .76517 .64129 L p .707 .577 .707 r
F P
0 g
s
.23483 .69381 m .23483 .67528 L .26667 .67451 L p .707 .577 .707 r
F P
0 g
s
.6747 .57899 m .6747 .63458 L .70216 .63897 L p .707 .577 .707 r
F P
0 g
s
.46462 .64973 m .46462 .14784 L .50956 .14674 L p .707 .577 .707 r
F P
0 g
s
.46462 .14784 m .46462 .64973 L .42314 .6545 L p .707 .577 .707 r
F P
0 g
s
.6747 .63458 m .6747 .57899 L .65365 .57254 L p .707 .577 .707 r
F P
0 g
s
.70216 .67723 m .70216 .64017 L .6747 .63578 L p .707 .577 .707 r
F P
0 g
s
.70216 .64017 m .70216 .67723 L .73333 .67913 L p .707 .577 .707 r
F P
0 g
s
.26667 .67451 m .26667 .69303 L .23483 .69381 L p .707 .577 .707 r
F P
0 g
s
.73333 .69252 m .73333 .67399 L .70216 .67209 L p .707 .577 .707 r
F P
0 g
s
.73333 .67399 m .73333 .69252 L .76517 .69174 L p .707 .577 .707 r
F P
0 g
s
.76517 .69174 m .76517 .67322 L .73333 .67399 L p .707 .577 .707 r
F P
0 g
s
.50956 .14674 m .50956 .64863 L .46462 .64973 L p .707 .577 .707 r
F P
0 g
s
.76517 .67322 m .76517 .69174 L .79455 .68837 L p .707 .577 .707 r
F P
0 g
s
.79455 .68837 m .79455 .66984 L .76517 .67322 L p .707 .577 .707 r
F P
0 g
s
.70216 .67209 m .70216 .69062 L .73333 .69252 L p .707 .577 .707 r
F P
0 g
s
.79455 .63792 m .79455 .67497 L .8186 .66932 L p .707 .577 .707 r
F P
0 g
s
.8186 .66932 m .8186 .63227 L .79455 .63792 L p .707 .577 .707 r
F P
0 g
s
.70216 .69062 m .70216 .67209 L .6747 .6677 L p .707 .577 .707 r
F P
0 g
s
.6747 .63578 m .6747 .67283 L .70216 .67723 L p .707 .577 .707 r
F P
0 g
s
.8186 .57548 m .8186 .63106 L .83497 .62369 L p .707 .577 .707 r
F P
0 g
s
.83497 .62369 m .83497 .56811 L .8186 .57548 L p .707 .577 .707 r
F P
0 g
s
.6747 .6677 m .6747 .68623 L .70216 .69062 L p .707 .577 .707 r
F P
0 g
s
.65365 .57254 m .65365 .62812 L .6747 .63458 L p .707 .577 .707 r
F P
0 g
s
.6747 .67283 m .6747 .63578 L .65365 .62933 L p .707 .577 .707 r
F P
0 g
s
.79455 .66984 m .79455 .68837 L .8186 .68272 L p .707 .577 .707 r
F P
0 g
s
.8186 .68272 m .8186 .66419 L .79455 .66984 L p .707 .577 .707 r
F P
0 g
s
.65365 .62812 m .65365 .57254 L .64105 .56465 L p .707 .577 .707 r
F P
0 g
s
.6747 .68623 m .6747 .6677 L .65365 .66125 L p .707 .577 .707 r
F P
0 g
s
.65365 .62933 m .65365 .66638 L .6747 .67283 L p .707 .577 .707 r
F P
0 g
s
.8186 .63227 m .8186 .66932 L .83497 .66195 L p .707 .577 .707 r
F P
0 g
s
.83497 .66195 m .83497 .6249 L .8186 .63227 L p .707 .577 .707 r
F P
0 g
s
.65365 .66125 m .65365 .67977 L .6747 .68623 L p .707 .577 .707 r
F P
0 g
s
.8186 .66419 m .8186 .68272 L .83497 .67535 L p .707 .577 .707 r
F P
0 g
s
.83497 .67535 m .83497 .65682 L .8186 .66419 L p .707 .577 .707 r
F P
0 g
s
.64105 .56465 m .64105 .62024 L .65365 .62812 L p .707 .577 .707 r
F P
0 g
s
.65365 .66638 m .65365 .62933 L .64105 .62144 L p .707 .577 .707 r
F P
0 g
s
.83497 .56811 m .83497 .62369 L .84205 .61533 L p .707 .577 .707 r
F P
0 g
s
.84205 .61533 m .84205 .55975 L .83497 .56811 L p .707 .577 .707 r
F P
0 g
s
.65365 .67977 m .65365 .66125 L .64105 .65336 L p .707 .577 .707 r
F P
0 g
s
.64105 .62144 m .64105 .6585 L .65365 .66638 L p .707 .577 .707 r
F P
0 g
s
.64105 .62024 m .64105 .56465 L .63816 .55611 L p .707 .577 .707 r
F P
0 g
s
.64105 .65336 m .64105 .67189 L .65365 .67977 L p .707 .577 .707 r
F P
0 g
s
.83497 .6249 m .83497 .66195 L .84205 .65359 L p .707 .577 .707 r
F P
0 g
s
.84205 .65359 m .84205 .61653 L .83497 .6249 L p .707 .577 .707 r
F P
0 g
s
.83497 .65682 m .83497 .67535 L .84205 .66698 L p .707 .577 .707 r
F P
0 g
s
.84205 .66698 m .84205 .64846 L .83497 .65682 L p .707 .577 .707 r
F P
0 g
s
.63816 .55611 m .63816 .61169 L .64105 .62024 L p .707 .577 .707 r
F P
0 g
s
.64105 .6585 m .64105 .62144 L .63816 .6129 L p .707 .577 .707 r
F P
0 g
s
.84205 .55975 m .84205 .61533 L .83916 .60679 L p .707 .577 .707 r
F P
0 g
s
.83916 .60679 m .83916 .55121 L .84205 .55975 L p .707 .577 .707 r
F P
0 g
s
.64105 .67189 m .64105 .65336 L .63816 .64482 L p .707 .577 .707 r
F P
0 g
s
.63816 .6129 m .63816 .64995 L .64105 .6585 L p .707 .577 .707 r
F P
0 g
s
.63816 .64482 m .63816 .66335 L .64105 .67189 L p .707 .577 .707 r
F P
0 g
s
.63816 .61169 m .63816 .55611 L .64524 .54775 L p .707 .577 .707 r
F P
0 g
s
.84205 .61653 m .84205 .65359 L .83916 .64505 L p .707 .577 .707 r
F P
0 g
s
.83916 .64505 m .83916 .60799 L .84205 .61653 L p .707 .577 .707 r
F P
0 g
s
.84205 .64846 m .84205 .66698 L .83916 .65844 L p .707 .577 .707 r
F P
0 g
s
.83916 .65844 m .83916 .63991 L .84205 .64846 L p .707 .577 .707 r
F P
0 g
s
.64524 .54775 m .64524 .60333 L .63816 .61169 L p .707 .577 .707 r
F P
0 g
s
.63816 .64995 m .63816 .6129 L .64524 .60453 L p .707 .577 .707 r
F P
0 g
s
.83916 .55121 m .83916 .60679 L .82657 .5989 L p .707 .577 .707 r
F P
0 g
s
.82657 .5989 m .82657 .54332 L .83916 .55121 L p .707 .577 .707 r
F P
0 g
s
.63816 .66335 m .63816 .64482 L .64524 .63646 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .60453 m .64524 .64159 L .63816 .64995 L p .707 .577 .707 r
F P
0 g
s
.39032 .60405 m .39032 .54847 L .35915 .54657 L p .707 .577 .707 r
F P
0 g
s
.39032 .54847 m .39032 .60405 L .42216 .60328 L p .707 .577 .707 r
F P
0 g
s
.42216 .60328 m .42216 .54769 L .39032 .54847 L p .707 .577 .707 r
F P
0 g
s
.64524 .63646 m .64524 .65498 L .63816 .66335 L p .707 .577 .707 r
F P
0 g
s
.64524 .60333 m .64524 .54775 L .66161 .54038 L p .707 .577 .707 r
F P
0 g
s
.42216 .54769 m .42216 .60328 L .45154 .5999 L p .707 .577 .707 r
F P
0 g
s
.45154 .5999 m .45154 .54431 L .42216 .54769 L p .707 .577 .707 r
F P
0 g
s
.83916 .60799 m .83916 .64505 L .82657 .63716 L p .707 .577 .707 r
F P
0 g
s
.82657 .63716 m .82657 .60011 L .83916 .60799 L p .707 .577 .707 r
F P
0 g
s
.35915 .60215 m .35915 .54657 L .33169 .54218 L p .707 .577 .707 r
F P
0 g
s
.35915 .54657 m .35915 .60215 L .39032 .60405 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63991 m .83916 .65844 L .82657 .65056 L p .707 .577 .707 r
F P
0 g
s
.82657 .65056 m .82657 .63203 L .83916 .63991 L p .707 .577 .707 r
F P
0 g
s
.45154 .54431 m .45154 .5999 L .47559 .59425 L p .707 .577 .707 r
F P
0 g
s
.47559 .59425 m .47559 .53866 L .45154 .54431 L p .707 .577 .707 r
F P
0 g
s
.39032 .64231 m .39032 .60526 L .35915 .60336 L p .707 .577 .707 r
F P
0 g
s
.39032 .60526 m .39032 .64231 L .42216 .64153 L p .707 .577 .707 r
F P
0 g
s
.42216 .64153 m .42216 .60448 L .39032 .60526 L p .707 .577 .707 r
F P
0 g
s
.66161 .54038 m .66161 .59596 L .64524 .60333 L p .707 .577 .707 r
F P
0 g
s
.64524 .64159 m .64524 .60453 L .66161 .59717 L p .707 .577 .707 r
F P
0 g
s
.82657 .54332 m .82657 .5989 L .80551 .59245 L p .707 .577 .707 r
F P
0 g
s
.80551 .59245 m .80551 .53687 L .82657 .54332 L p .707 .577 .707 r
F P
0 g
s
.42216 .60448 m .42216 .64153 L .45154 .63816 L p .707 .577 .707 r
F P
0 g
s
.45154 .63816 m .45154 .6011 L .42216 .60448 L p .707 .577 .707 r
F P
0 g
s
.33169 .54218 m .33169 .59776 L .35915 .60215 L p .707 .577 .707 r
F P
0 g
s
.33169 .59776 m .33169 .54218 L .31064 .53572 L p .707 .577 .707 r
F P
0 g
s
.35915 .64041 m .35915 .60336 L .33169 .59896 L p .707 .577 .707 r
F P
0 g
s
.35915 .60336 m .35915 .64041 L .39032 .64231 L p .707 .577 .707 r
F P
0 g
s
.39032 .65571 m .39032 .63718 L .35915 .63528 L p .707 .577 .707 r
F P
0 g
s
.39032 .63718 m .39032 .65571 L .42216 .65493 L p .707 .577 .707 r
F P
0 g
s
.42216 .65493 m .42216 .6364 L .39032 .63718 L p .707 .577 .707 r
F P
0 g
s
.64524 .65498 m .64524 .63646 L .66161 .62909 L p .707 .577 .707 r
F P
0 g
s
.42216 .6364 m .42216 .65493 L .45154 .65155 L p .707 .577 .707 r
F P
0 g
s
.45154 .65155 m .45154 .63302 L .42216 .6364 L p .707 .577 .707 r
F P
0 g
s
.66161 .59717 m .66161 .63422 L .64524 .64159 L p .707 .577 .707 r
F P
0 g
s
.66161 .59596 m .66161 .54038 L .68566 .53473 L p .707 .577 .707 r
F P
0 g
s
.35915 .63528 m .35915 .65381 L .39032 .65571 L p .707 .577 .707 r
F P
0 g
s
.45154 .6011 m .45154 .63816 L .47559 .63251 L p .707 .577 .707 r
F P
0 g
s
.47559 .63251 m .47559 .59545 L .45154 .6011 L p .707 .577 .707 r
F P
0 g
s
.35915 .65381 m .35915 .63528 L .33169 .63089 L p .707 .577 .707 r
F P
0 g
s
.66161 .62909 m .66161 .64762 L .64524 .65498 L p .707 .577 .707 r
F P
0 g
s
.33169 .59896 m .33169 .63602 L .35915 .64041 L p .707 .577 .707 r
F P
0 g
s
.82657 .60011 m .82657 .63716 L .80551 .63071 L p .707 .577 .707 r
F P
0 g
s
.80551 .63071 m .80551 .59365 L .82657 .60011 L p .707 .577 .707 r
F P
0 g
s
.47559 .53866 m .47559 .59425 L .49196 .58688 L p .707 .577 .707 r
F P
0 g
s
.49196 .58688 m .49196 .5313 L .47559 .53866 L p .707 .577 .707 r
F P
0 g
s
.33169 .63089 m .33169 .64941 L .35915 .65381 L p .707 .577 .707 r
F P
0 g
s
.31064 .53572 m .31064 .59131 L .33169 .59776 L p .707 .577 .707 r
F P
0 g
s
.33169 .63602 m .33169 .59896 L .31064 .59251 L p .707 .577 .707 r
F P
0 g
s
.45154 .63302 m .45154 .65155 L .47559 .6459 L p .707 .577 .707 r
F P
0 g
s
.47559 .6459 m .47559 .62737 L .45154 .63302 L p .707 .577 .707 r
F P
0 g
s
.80551 .53687 m .80551 .59245 L .77805 .58806 L p .707 .577 .707 r
F P
0 g
s
.77805 .58806 m .77805 .53247 L .80551 .53687 L p .707 .577 .707 r
F P
0 g
s
.82657 .63203 m .82657 .65056 L .80551 .6441 L p .707 .577 .707 r
F P
0 g
s
.80551 .6441 m .80551 .62558 L .82657 .63203 L p .707 .577 .707 r
F P
0 g
s
.68566 .53473 m .68566 .59031 L .66161 .59596 L p .707 .577 .707 r
F P
0 g
s
.66161 .63422 m .66161 .59717 L .68566 .59152 L p .707 .577 .707 r
F P
0 g
s
.31064 .59131 m .31064 .53572 L .29804 .52784 L p .707 .577 .707 r
F P
0 g
s
.33169 .64941 m .33169 .63089 L .31064 .62443 L p .707 .577 .707 r
F P
0 g
s
.31064 .59251 m .31064 .62956 L .33169 .63602 L p .707 .577 .707 r
F P
0 g
s
.68566 .59031 m .68566 .53473 L .71504 .53135 L p .707 .577 .707 r
F P
0 g
s
.47559 .59545 m .47559 .63251 L .49196 .62514 L p .707 .577 .707 r
F P
0 g
s
.49196 .62514 m .49196 .58808 L .47559 .59545 L p .707 .577 .707 r
F P
0 g
s
.31064 .62443 m .31064 .64296 L .33169 .64941 L p .707 .577 .707 r
F P
0 g
s
.66161 .64762 m .66161 .62909 L .68566 .62344 L p .707 .577 .707 r
F P
0 g
s
.68566 .59152 m .68566 .62857 L .66161 .63422 L p .707 .577 .707 r
F P
0 g
s
.77805 .53247 m .77805 .58806 L .74688 .58616 L p .707 .577 .707 r
F P
0 g
s
.74688 .58616 m .74688 .53057 L .77805 .53247 L p .707 .577 .707 r
F P
0 g
s
.80551 .59365 m .80551 .63071 L .77805 .62632 L p .707 .577 .707 r
F P
0 g
s
.77805 .62632 m .77805 .58926 L .80551 .59365 L p .707 .577 .707 r
F P
0 g
s
.68566 .62344 m .68566 .64197 L .66161 .64762 L p .707 .577 .707 r
F P
0 g
s
.47559 .62737 m .47559 .6459 L .49196 .63853 L p .707 .577 .707 r
F P
0 g
s
.49196 .63853 m .49196 .62 L .47559 .62737 L p .707 .577 .707 r
F P
0 g
s
.29804 .52784 m .29804 .58342 L .31064 .59131 L p .707 .577 .707 r
F P
0 g
s
.71504 .58693 m .71504 .53135 L .74688 .53057 L p .707 .577 .707 r
F P
0 g
s
.71504 .53135 m .71504 .58693 L .68566 .59031 L p .707 .577 .707 r
F P
0 g
s
.31064 .62956 m .31064 .59251 L .29804 .58463 L p .707 .577 .707 r
F P
0 g
s
.49196 .5313 m .49196 .58688 L .49904 .57851 L p .707 .577 .707 r
F P
0 g
s
.49904 .57851 m .49904 .52293 L .49196 .5313 L p .707 .577 .707 r
F P
0 g
s
.74688 .53057 m .74688 .58616 L .71504 .58693 L p .707 .577 .707 r
F P
0 g
s
.68566 .62857 m .68566 .59152 L .71504 .58814 L p .707 .577 .707 r
F P
0 g
s
.80551 .62558 m .80551 .6441 L .77805 .63971 L p .707 .577 .707 r
F P
0 g
s
.77805 .63971 m .77805 .62118 L .80551 .62558 L p .707 .577 .707 r
F P
0 g
s
.31064 .64296 m .31064 .62443 L .29804 .61655 L p .707 .577 .707 r
F P
0 g
s
.29804 .58463 m .29804 .62168 L .31064 .62956 L p .707 .577 .707 r
F P
0 g
s
.77805 .58926 m .77805 .62632 L .74688 .62442 L p .707 .577 .707 r
F P
0 g
s
.74688 .62442 m .74688 .58736 L .77805 .58926 L p .707 .577 .707 r
F P
0 g
s
.68566 .64197 m .68566 .62344 L .71504 .62006 L p .707 .577 .707 r
F P
0 g
s
.29804 .58342 m .29804 .52784 L .29515 .5193 L p .707 .577 .707 r
F P
0 g
s
.71504 .58814 m .71504 .62519 L .68566 .62857 L p .707 .577 .707 r
F P
0 g
s
.29804 .61655 m .29804 .63507 L .31064 .64296 L p .707 .577 .707 r
F P
0 g
s
.71504 .62519 m .71504 .58814 L .74688 .58736 L p .707 .577 .707 r
F P
0 g
s
.49196 .58808 m .49196 .62514 L .49904 .61677 L p .707 .577 .707 r
F P
0 g
s
.49904 .61677 m .49904 .57972 L .49196 .58808 L p .707 .577 .707 r
F P
0 g
s
.71504 .62006 m .71504 .63859 L .68566 .64197 L p .707 .577 .707 r
F P
0 g
s
.74688 .58736 m .74688 .62442 L .71504 .62519 L p .707 .577 .707 r
F P
0 g
s
.77805 .62118 m .77805 .63971 L .74688 .63781 L p .707 .577 .707 r
F P
0 g
s
.74688 .63781 m .74688 .61928 L .77805 .62118 L p .707 .577 .707 r
F P
0 g
s
.71504 .63859 m .71504 .62006 L .74688 .61928 L p .707 .577 .707 r
F P
0 g
s
.49196 .62 m .49196 .63853 L .49904 .63017 L p .707 .577 .707 r
F P
0 g
s
.49904 .63017 m .49904 .61164 L .49196 .62 L p .707 .577 .707 r
F P
0 g
s
.74688 .61928 m .74688 .63781 L .71504 .63859 L p .707 .577 .707 r
F P
0 g
s
.29515 .5193 m .29515 .57488 L .29804 .58342 L p .707 .577 .707 r
F P
0 g
s
.29804 .62168 m .29804 .58463 L .29515 .57608 L p .707 .577 .707 r
F P
0 g
s
.49904 .52293 m .49904 .57851 L .49615 .56997 L p .707 .577 .707 r
F P
0 g
s
.49615 .56997 m .49615 .51439 L .49904 .52293 L p .707 .577 .707 r
F P
0 g
s
.29804 .63507 m .29804 .61655 L .29515 .60801 L p .707 .577 .707 r
F P
0 g
s
.29515 .57608 m .29515 .61314 L .29804 .62168 L p .707 .577 .707 r
F P
0 g
s
.29515 .60801 m .29515 .62653 L .29804 .63507 L p .707 .577 .707 r
F P
0 g
s
.29515 .57488 m .29515 .5193 L .30223 .51093 L p .707 .577 .707 r
F P
0 g
s
.49904 .57972 m .49904 .61677 L .49615 .60823 L p .707 .577 .707 r
F P
0 g
s
.49615 .60823 m .49615 .57118 L .49904 .57972 L p .707 .577 .707 r
F P
0 g
s
.49904 .61164 m .49904 .63017 L .49615 .62163 L p .707 .577 .707 r
F P
0 g
s
.49615 .62163 m .49615 .6031 L .49904 .61164 L p .707 .577 .707 r
F P
0 g
s
.30223 .51093 m .30223 .56651 L .29515 .57488 L p .707 .577 .707 r
F P
0 g
s
.29515 .61314 m .29515 .57608 L .30223 .56772 L p .707 .577 .707 r
F P
0 g
s
.49615 .51439 m .49615 .56997 L .48356 .56209 L p .707 .577 .707 r
F P
0 g
s
.48356 .56209 m .48356 .50651 L .49615 .51439 L p .707 .577 .707 r
F P
0 g
s
.29515 .62653 m .29515 .60801 L .30223 .59964 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .56772 m .30223 .60477 L .29515 .61314 L p .707 .577 .707 r
F P
0 g
s
.30223 .59964 m .30223 .61817 L .29515 .62653 L p .707 .577 .707 r
F P
0 g
s
.30223 .56651 m .30223 .51093 L .3186 .50356 L p .707 .577 .707 r
F P
0 g
s
.49615 .57118 m .49615 .60823 L .48356 .60035 L p .707 .577 .707 r
F P
0 g
s
.48356 .60035 m .48356 .56329 L .49615 .57118 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .6031 m .49615 .62163 L .48356 .61374 L p .707 .577 .707 r
F P
0 g
s
.48356 .61374 m .48356 .59521 L .49615 .6031 L p .707 .577 .707 r
F P
0 g
s
.3186 .50356 m .3186 .55915 L .30223 .56651 L p .707 .577 .707 r
F P
0 g
s
.30223 .60477 m .30223 .56772 L .3186 .56035 L p .707 .577 .707 r
F P
0 g
s
.48356 .50651 m .48356 .56209 L .4625 .55563 L p .707 .577 .707 r
F P
0 g
s
.4625 .55563 m .4625 .50005 L .48356 .50651 L p .707 .577 .707 r
F P
0 g
s
.30223 .61817 m .30223 .59964 L .3186 .59227 L p .707 .577 .707 r
F P
0 g
s
.3186 .56035 m .3186 .59741 L .30223 .60477 L p .707 .577 .707 r
F P
0 g
s
.3186 .55915 m .3186 .50356 L .34265 .49791 L p .707 .577 .707 r
F P
0 g
s
.3186 .59227 m .3186 .6108 L .30223 .61817 L p .707 .577 .707 r
F P
0 g
s
.48356 .56329 m .48356 .60035 L .4625 .59389 L p .707 .577 .707 r
F P
0 g
s
.4625 .59389 m .4625 .55684 L .48356 .56329 L p .707 .577 .707 r
F P
0 g
s
.4625 .50005 m .4625 .55563 L .43504 .55124 L p .707 .577 .707 r
F P
0 g
s
.43504 .55124 m .43504 .49566 L .4625 .50005 L p .707 .577 .707 r
F P
0 g
s
.48356 .59521 m .48356 .61374 L .4625 .60729 L p .707 .577 .707 r
F P
0 g
s
.4625 .60729 m .4625 .58876 L .48356 .59521 L p .707 .577 .707 r
F P
0 g
s
.34265 .49791 m .34265 .5535 L .3186 .55915 L p .707 .577 .707 r
F P
0 g
s
.3186 .59741 m .3186 .56035 L .34265 .5547 L p .707 .577 .707 r
F P
0 g
s
.34265 .5535 m .34265 .49791 L .37203 .49454 L p .707 .577 .707 r
F P
0 g
s
.3186 .6108 m .3186 .59227 L .34265 .58662 L p .707 .577 .707 r
F P
0 g
s
.34265 .5547 m .34265 .59176 L .3186 .59741 L p .707 .577 .707 r
F P
0 g
s
.43504 .49566 m .43504 .55124 L .40387 .54934 L p .707 .577 .707 r
F P
0 g
s
.40387 .54934 m .40387 .49376 L .43504 .49566 L p .707 .577 .707 r
F P
0 g
s
.4625 .55684 m .4625 .59389 L .43504 .5895 L p .707 .577 .707 r
F P
0 g
s
.43504 .5895 m .43504 .55245 L .4625 .55684 L p .707 .577 .707 r
F P
0 g
s
.34265 .58662 m .34265 .60515 L .3186 .6108 L p .707 .577 .707 r
F P
0 g
s
.37203 .55012 m .37203 .49454 L .40387 .49376 L p .707 .577 .707 r
F P
0 g
s
.37203 .49454 m .37203 .55012 L .34265 .5535 L p .707 .577 .707 r
F P
0 g
s
.40387 .49376 m .40387 .54934 L .37203 .55012 L p .707 .577 .707 r
F P
0 g
s
.34265 .59176 m .34265 .5547 L .37203 .55132 L p .707 .577 .707 r
F P
0 g
s
.4625 .58876 m .4625 .60729 L .43504 .60289 L p .707 .577 .707 r
F P
0 g
s
.43504 .60289 m .43504 .58437 L .4625 .58876 L p .707 .577 .707 r
F P
0 g
s
.43504 .55245 m .43504 .5895 L .40387 .5876 L p .707 .577 .707 r
F P
0 g
s
.40387 .5876 m .40387 .55055 L .43504 .55245 L p .707 .577 .707 r
F P
0 g
s
.34265 .60515 m .34265 .58662 L .37203 .58324 L p .707 .577 .707 r
F P
0 g
s
.37203 .55132 m .37203 .58838 L .34265 .59176 L p .707 .577 .707 r
F P
0 g
s
.37203 .58838 m .37203 .55132 L .40387 .55055 L p .707 .577 .707 r
F P
0 g
s
.37203 .58324 m .37203 .60177 L .34265 .60515 L p .707 .577 .707 r
F P
0 g
s
.40387 .55055 m .40387 .5876 L .37203 .58838 L p .707 .577 .707 r
F P
0 g
s
.43504 .58437 m .43504 .60289 L .40387 .60099 L p .707 .577 .707 r
F P
0 g
s
.40387 .60099 m .40387 .58247 L .43504 .58437 L p .707 .577 .707 r
F P
0 g
s
.37203 .60177 m .37203 .58324 L .40387 .58247 L p .707 .577 .707 r
F P
0 g
s
.40387 .58247 m .40387 .60099 L .37203 .60177 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol008]oo``008Ioo`00Ogoo30001EYF00<005YFFUH015YF2@00OGoo001fOol9
0005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075oo`D0009JEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=oo`00KWoo0`001eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00
Kgoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP03FUH3001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP8006]oo`00J7oo0P0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
06Qoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006EooaP000MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00
0eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001E
Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
01Qoo`T004Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000moo`T000AJ
EP03001JEUYF009JEPP003aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00Qoo`L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool50002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH007oo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0031oo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1P00
0eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000UYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP0000AJEP03001JEP0000<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF00000eYF0`001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000010000eYF00@005YF
FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`04001JEP00FUH200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH0
1000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`<000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
03mooa4000=oo`03001JEP0000AJEP03001JEUYF00AJEP8000IJEP03001JEUYF00IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000iOol60003FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP0025YF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH0
0`00FUIJEP02FUHP0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000eOol400000eYF001J
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH01@00FUIJEUYF00000UYF1@00
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH0
0UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEP0000P000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH0
1000FUIJEUYF0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00003FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000`Ool20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P00
00=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YF
FUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
0`0000=JEP000000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH30004FUH01000FUIJEUYF2@000eYF2P0015YF00<005YFFUH015YF1P0015YF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF1P001eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEQH000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800005FUH005YFFUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH300000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P0000AJEP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP<0009JEP03001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPH000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P000eYF00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH0
1EYF00<005YF00000`0000=JEP00FUH00UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF00000P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000eYF0P00
;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00000UYF10001UYF1@0015YF1@0000=JEP00000030001EYF00@005YF
FUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP<00003FUH0000002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH0
0`000UYF00@005YFFUIJEPX000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0P0000=JEP00FUH015YF00<005YFFUH00UYF60001EYF00<005YFFUH00eYF00<005YFFUH00`00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG000015YF0000000015YF00<0
05YFFUH00eYF0`001eYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP02FUHM00000eYF0000000200000eYF001JEP04FUH01000FUIJEUYF0P00;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH=00000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00
FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUH0000300000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF2P0015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF000050001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00;Goo000/Ool00`00FUH00003FUH3
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
000200000eYF000000060004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJEP09
FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo
000/Ool01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00D005YFFUH005YF01<00003FUH005YF
00]JEP03001JEUYF00YJEP03001JEUYF00QJEPL000IJEP03001JEUYF009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00800003FUH0000002eoo`00;7oo00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009J
EP03001JEUYF00=JEP03001JEUYF00D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEP00
001JEP03000]Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH3
0002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH3000]Ool002aoo`<000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH01000FUIJEUYF0P001EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP80009JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEP0000<00003
FUH005YF00=JEP03001JEP0002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF0P000UYF00<005YF00000P0000=JEP00FUH0
1UYF00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1@001EYF00<005YFFUH00UYF0P00;Woo000/
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
10000UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF5`000eYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH20006FUH50004FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP800004FUH000000005FUH01000FUIJEUYF1@0025YF1@0015YF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF0P0000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPH000AJEP03001JEUYF008000AJ
EP04001JEUYFFUH300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF000000020004FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00
FUH00004FUH20005FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUH00002000015YF001JEUYF0P0015YF00<005YFFUH01P002UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF0000009JEP@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol0
02aoo`03001JEP0000AJEP04001JEP000003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH20004FUH00`00FUIJEP06000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH000001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00>7oo000/
Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH50004FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YF
FUH00UYF7000?goo000/Ool01@00FUH005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF6@00
15YF00<005YFFUH00eYF00<005YFFUH00P0015YF00@005YFFUIJEP<00003FUH005YF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0000IJEP03001JEUYF00=JEP<00003FUH0000005Aoo`00;7oo00@005YF000000=JEP04001JEUYF
FUH90003FUHC0002FUH60004FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
0`001UYF00<005YFFUH00eYF00<005YF00000`00E7oo000/Ool30003FUH60007FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH30002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<007ooOol00`001eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`06001JEP00001J
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00P0000=JEP00Ool00goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000EJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH30006Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH40007FUH20005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool3
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUH0000200000eYF001oo`09Ool50008FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP050002FUH50004FUH00`00FUH0000300000eYF
001JEP04FUH01000FUIJEUYF0P0027oo0`00BGoo000/Ool2000015YF000000001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<0
05YF00003goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@001eYF00<0
05YFFUH00UYF00D005YFFUIJEP0000EJEP@000=JEP04001JEUYFFUH20007Ool50018Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03
001JEP0000<00003FUH005YF009JEP03001JEP0001Eoo`T000IJEP03001JEUYF00YJEP03001JEUYF
00H000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000=JEP80
00Moo`D004Qoo`00;Goo00D005YFFUIJEP00009JEP800003FUH005YF00EJEPD000AJEPD000EJEP03
001JEUYF009JEPD000EJEP04001JEUYFFUH2000OOolG0008FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH20007Ool50018Ool002ioo`04001JEUYF0004
FUH20002FUH00`00FUIJEP02FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP00
02Uoo`04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000030008Ool30019Ool002moo`<000EJEP04001JEUYFFUH50007FUH5
0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000:Woo10000eYF00<005YFFUH00UYF
80000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00<Goo0`000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00;7oo00<005YF000015YF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YF
FUIJEP8005Aoo`00=7oo1@001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YF00000`00;goo00<005YF00000eYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0P00E7oo000iOol40002FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5000cOol01000FUH005YF0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0eYF0P00E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000001DOol0
08ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00D005Aoo`00SWoo0P0000=JEP0000001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0UYF0`00E7oo002>Ool20002FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00
FUIJEP05FUH01000FUIJEUYF100015YF00<005YF0000E7oo002?Ool01@00FUIJEP00FUH00`0000=J
EP00FUH01UYF00<005YFFUH01UYF1@0015YF00<005YFFUH00UYF1`000eYF00<005YFFUH00UYF0P00
EGoo002?Ool01000FUIJEP0015YF0P0000=JEP00000015YF5`000eYF00<005YFFUH015YF00<005YF
FUH00UYF0P00EGoo002@Ool30005FUH01000FUIJEUYF1@0025YF1@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP8005Ioo`00B7oo0`00Agoo0P0015YF00<005YFFUH01EYF00<005YF
FUH01UYF10001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000005Qoo`00Agoo1@00B7oo
0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPD005Yoo`00Agoo1@00Bgoo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
1`00Ggoo0017Ool5001@Ool90004FUH00`00FUIJEP02FUH9001VOol004Qoo`<005Yoo`T006moo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ZWoo0`00L7oo002Y
Ool5001_Ool00:Uoo`D006moo`00ZGoo1@00Kgoo002ZOol3001`Ool00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .76609 m .59613 .7105 L .56496 .7086 L p .707 .577 .707 r
F P
0 g
s
.59613 .7105 m .59613 .76609 L .62796 .76531 L p .707 .577 .707 r
F P
0 g
s
.62796 .76531 m .62796 .70973 L .59613 .7105 L p .707 .577 .707 r
F P
0 g
s
.62796 .70973 m .62796 .76531 L .65735 .76193 L p .707 .577 .707 r
F P
0 g
s
.65735 .76193 m .65734 .70635 L .62796 .70973 L p .707 .577 .707 r
F P
0 g
s
.56496 .76418 m .56496 .7086 L .5375 .70421 L p .707 .577 .707 r
F P
0 g
s
.56496 .7086 m .56496 .76418 L .59613 .76609 L p .707 .577 .707 r
F P
0 g
s
.65734 .70635 m .65735 .76193 L .6814 .75628 L p .707 .577 .707 r
F P
0 g
s
.6814 .75628 m .6814 .7007 L .65734 .70635 L p .707 .577 .707 r
F P
0 g
s
.5375 .70421 m .5375 .75979 L .56496 .76418 L p .707 .577 .707 r
F P
0 g
s
.5375 .75979 m .5375 .70421 L .51644 .69776 L p .707 .577 .707 r
F P
0 g
s
.59613 .84855 m .59613 .8115 L .56496 .8096 L p .707 .577 .707 r
F P
0 g
s
.59613 .8115 m .59613 .84855 L .62796 .84777 L p .707 .577 .707 r
F P
0 g
s
.62796 .84777 m .62796 .81072 L .59613 .8115 L p .707 .577 .707 r
F P
0 g
s
.62796 .81072 m .62796 .84777 L .65735 .84439 L p .707 .577 .707 r
F P
0 g
s
.65735 .84439 m .65735 .80734 L .62796 .81072 L p .707 .577 .707 r
F P
0 g
s
.56496 .84665 m .56496 .8096 L .5375 .8052 L p .707 .577 .707 r
F P
0 g
s
.56496 .8096 m .56496 .84665 L .59613 .84855 L p .707 .577 .707 r
F P
0 g
s
.6814 .7007 m .6814 .75628 L .69777 .74891 L p .707 .577 .707 r
F P
0 g
s
.69777 .74891 m .69777 .69333 L .6814 .7007 L p .707 .577 .707 r
F P
0 g
s
.51644 .69776 m .51644 .75334 L .5375 .75979 L p .707 .577 .707 r
F P
0 g
s
.65735 .80734 m .65735 .84439 L .6814 .83874 L p .707 .577 .707 r
F P
0 g
s
.6814 .83874 m .6814 .80169 L .65735 .80734 L p .707 .577 .707 r
F P
0 g
s
.5375 .8052 m .5375 .84226 L .56496 .84665 L p .707 .577 .707 r
F P
0 g
s
.51644 .75334 m .51644 .69776 L .50385 .68987 L p .707 .577 .707 r
F P
0 g
s
.5375 .84226 m .5375 .8052 L .51644 .79875 L p .707 .577 .707 r
F P
0 g
s
.59613 .91883 m .59613 .9003 L .56496 .8984 L p .707 .577 .707 r
F P
0 g
s
.59613 .9003 m .59613 .91883 L .62796 .91805 L p .707 .577 .707 r
F P
0 g
s
.62796 .91805 m .62796 .89952 L .59613 .9003 L p .707 .577 .707 r
F P
0 g
s
.62796 .89952 m .62796 .91805 L .65735 .91467 L p .707 .577 .707 r
F P
0 g
s
.65735 .91467 m .65735 .89614 L .62796 .89952 L p .707 .577 .707 r
F P
0 g
s
.56496 .8984 m .56496 .91693 L .59613 .91883 L p .707 .577 .707 r
F P
0 g
s
.56496 .91693 m .56496 .8984 L .5375 .89401 L p .707 .577 .707 r
F P
0 g
s
.51644 .79875 m .51644 .8358 L .5375 .84226 L p .707 .577 .707 r
F P
0 g
s
.50385 .68987 m .50385 .74545 L .51644 .75334 L p .707 .577 .707 r
F P
0 g
s
.69777 .69333 m .69777 .74891 L .70485 .74055 L p .707 .577 .707 r
F P
0 g
s
.70485 .74055 m .70485 .68497 L .69777 .69333 L p .707 .577 .707 r
F P
0 g
s
.6814 .80169 m .6814 .83874 L .69777 .83138 L p .707 .577 .707 r
F P
0 g
s
.69777 .83138 m .69777 .79432 L .6814 .80169 L p .707 .577 .707 r
F P
0 g
s
.5375 .89401 m .5375 .91253 L .56496 .91693 L p .707 .577 .707 r
F P
0 g
s
.65735 .89614 m .65735 .91467 L .6814 .90902 L p .707 .577 .707 r
F P
0 g
s
.6814 .90902 m .6814 .89049 L .65735 .89614 L p .707 .577 .707 r
F P
0 g
s
.51644 .8358 m .51644 .79875 L .50385 .79087 L p .707 .577 .707 r
F P
0 g
s
.50385 .74545 m .50385 .68987 L .50095 .68133 L p .707 .577 .707 r
F P
0 g
s
.5375 .91253 m .5375 .89401 L .51644 .88755 L p .707 .577 .707 r
F P
0 g
s
.51644 .88755 m .51644 .90608 L .5375 .91253 L p .707 .577 .707 r
F P
0 g
s
.50385 .79087 m .50385 .82792 L .51644 .8358 L p .707 .577 .707 r
F P
0 g
s
.6814 .89049 m .6814 .90902 L .69777 .90165 L p .707 .577 .707 r
F P
0 g
s
.69777 .90165 m .69777 .88313 L .6814 .89049 L p .707 .577 .707 r
F P
0 g
s
.50095 .68133 m .50095 .73691 L .50385 .74545 L p .707 .577 .707 r
F P
0 g
s
.69777 .79432 m .69777 .83138 L .70485 .82301 L p .707 .577 .707 r
F P
0 g
s
.70485 .82301 m .70485 .78596 L .69777 .79432 L p .707 .577 .707 r
F P
0 g
s
.70485 .68497 m .70485 .74055 L .70195 .73201 L p .707 .577 .707 r
F P
0 g
s
.70195 .73201 m .70195 .67642 L .70485 .68497 L p .707 .577 .707 r
F P
0 g
s
.51644 .90608 m .51644 .88755 L .50385 .87967 L p .707 .577 .707 r
F P
0 g
s
.50385 .82792 m .50385 .79087 L .50095 .78232 L p .707 .577 .707 r
F P
0 g
s
.50385 .87967 m .50385 .8982 L .51644 .90608 L p .707 .577 .707 r
F P
0 g
s
.50095 .73691 m .50095 .68133 L .50804 .67297 L p .707 .577 .707 r
F P
0 g
s
.50095 .78232 m .50095 .81938 L .50385 .82792 L p .707 .577 .707 r
F P
0 g
s
.69777 .88313 m .69777 .90165 L .70485 .89329 L p .707 .577 .707 r
F P
0 g
s
.70485 .89329 m .70485 .87476 L .69777 .88313 L p .707 .577 .707 r
F P
0 g
s
.70485 .78596 m .70485 .82301 L .70195 .81447 L p .707 .577 .707 r
F P
0 g
s
.70195 .81447 m .70195 .77742 L .70485 .78596 L p .707 .577 .707 r
F P
0 g
s
.50804 .67297 m .50804 .72855 L .50095 .73691 L p .707 .577 .707 r
F P
0 g
s
.70195 .67642 m .70195 .73201 L .68936 .72412 L p .707 .577 .707 r
F P
0 g
s
.68936 .72412 m .68936 .66854 L .70195 .67642 L p .707 .577 .707 r
F P
0 g
s
.49044 .91388 m .49044 .41591 L .44643 .41323 L p .707 .577 .707 r
F P
0 g
s
.50385 .8982 m .50385 .87967 L .50095 .87113 L p .707 .577 .707 r
F P
0 g
s
.50095 .87113 m .50095 .88965 L .50385 .8982 L p .707 .577 .707 r
F P
0 g
s
.50095 .81938 m .50095 .78232 L .50804 .77396 L p .707 .577 .707 r
F P
0 g
s
.50804 .72855 m .50804 .67297 L .5244 .6656 L p .707 .577 .707 r
F P
0 g
s
.50804 .77396 m .50804 .81101 L .50095 .81938 L p .707 .577 .707 r
F P
0 g
s
.5244 .6656 m .5244 .72118 L .50804 .72855 L p .707 .577 .707 r
F P
0 g
s
.50095 .88965 m .50095 .87113 L .50804 .86276 L p .707 .577 .707 r
F P
0 g
s
.50804 .86276 m .50804 .88129 L .50095 .88965 L p .707 .577 .707 r
F P
0 g
s
.50804 .81101 m .50804 .77396 L .5244 .76659 L p .707 .577 .707 r
F P
0 g
s
.5244 .76659 m .5244 .80365 L .50804 .81101 L p .707 .577 .707 r
F P
0 g
s
.50804 .88129 m .50804 .86276 L .5244 .85539 L p .707 .577 .707 r
F P
0 g
s
.5244 .80365 m .5244 .76659 L .54846 .76094 L p .707 .577 .707 r
F P
0 g
s
.5244 .85539 m .5244 .87392 L .50804 .88129 L p .707 .577 .707 r
F P
0 g
s
.54846 .76094 m .54846 .798 L .5244 .80365 L p .707 .577 .707 r
F P
0 g
s
.5244 .87392 m .5244 .85539 L .54846 .84974 L p .707 .577 .707 r
F P
0 g
s
.54846 .84974 m .54846 .86827 L .5244 .87392 L p .707 .577 .707 r
F P
0 g
s
.49044 .41591 m .49044 .91388 L .53503 .91279 L p .707 .577 .707 r
F P
0 g
s
.53503 .91279 m .53538 .91278 L p .49044 .41591 L .707 .577 .707 r
F P
0 g
s
.5244 .72118 m .5244 .6656 L .54846 .65995 L p .707 .577 .707 r
F P
0 g
s
.54846 .65995 m .54846 .71553 L .5244 .72118 L p .707 .577 .707 r
F P
0 g
s
.53538 .91278 m .53538 .41482 L .49044 .41591 L p .707 .577 .707 r
F P
0 g
s
.54846 .71553 m .54846 .65995 L .57784 .65657 L p .707 .577 .707 r
F P
0 g
s
.57784 .65657 m .57784 .71215 L .54846 .71553 L p .707 .577 .707 r
F P
0 g
s
.54846 .798 m .54846 .76094 L .57784 .75756 L p .707 .577 .707 r
F P
0 g
s
.57784 .75756 m .57784 .79462 L .54846 .798 L p .707 .577 .707 r
F P
0 g
s
.54846 .86827 m .54846 .84974 L .57784 .84637 L p .707 .577 .707 r
F P
0 g
s
.57784 .84637 m .57784 .86489 L .54846 .86827 L p .707 .577 .707 r
F P
0 g
s
.53538 .41482 m .53538 .91278 L .57654 .90805 L p .707 .577 .707 r
F P
0 g
s
.57654 .90805 m .57686 .90801 L p .53538 .41482 L .707 .577 .707 r
F P
0 g
s
.57686 .90801 m .57686 .41005 L .53538 .41482 L p .707 .577 .707 r
F P
0 g
s
.25312 .72927 m .25312 .67369 L .22195 .67179 L p .707 .577 .707 r
F P
0 g
s
.25312 .67369 m .25312 .72927 L .28495 .72849 L p .707 .577 .707 r
F P
0 g
s
.28495 .72849 m .28495 .67291 L .25312 .67369 L p .707 .577 .707 r
F P
0 g
s
.44643 .9112 m .44643 .41323 L .40766 .40703 L p .707 .577 .707 r
F P
0 g
s
.44643 .41323 m .44643 .9112 L .49009 .91386 L p .707 .577 .707 r
F P
0 g
s
.49009 .91386 m .49044 .91388 L p .44643 .41323 L .707 .577 .707 r
F P
0 g
s
.28495 .67291 m .28495 .72849 L .31434 .72511 L p .707 .577 .707 r
F P
0 g
s
.31434 .72511 m .31434 .66953 L .28495 .67291 L p .707 .577 .707 r
F P
0 g
s
.22195 .72737 m .22195 .67179 L .19449 .66739 L p .707 .577 .707 r
F P
0 g
s
.22195 .67179 m .22195 .72737 L .25312 .72927 L p .707 .577 .707 r
F P
0 g
s
.70485 .87476 m .70485 .89329 L .70195 .88475 L p .707 .577 .707 r
F P
0 g
s
.70195 .88475 m .70195 .86622 L .70485 .87476 L p .707 .577 .707 r
F P
0 g
s
.57784 .71215 m .57784 .65657 L .60968 .65579 L p .707 .577 .707 r
F P
0 g
s
.60968 .65579 m .60968 .71137 L .57784 .71215 L p .707 .577 .707 r
F P
0 g
s
.57784 .79462 m .57784 .75756 L .60968 .75678 L p .707 .577 .707 r
F P
0 g
s
.60968 .75678 m .60968 .79384 L .57784 .79462 L p .707 .577 .707 r
F P
0 g
s
.57784 .86489 m .57784 .84637 L .60968 .84559 L p .707 .577 .707 r
F P
0 g
s
.60968 .84559 m .60968 .86412 L .57784 .86489 L p .707 .577 .707 r
F P
0 g
s
.57686 .41005 m .57686 .90801 L .61055 .9001 L p .707 .577 .707 r
F P
0 g
s
.61055 .9001 m .61082 .90004 L p .57686 .41005 L .707 .577 .707 r
F P
0 g
s
.64085 .65769 m .64085 .71327 L .60968 .71137 L p .707 .577 .707 r
F P
0 g
s
.60968 .71137 m .60968 .65579 L .64085 .65769 L p .707 .577 .707 r
F P
0 g
s
.64085 .75869 m .64085 .79574 L .60968 .79384 L p .707 .577 .707 r
F P
0 g
s
.60968 .79384 m .60968 .75678 L .64085 .75869 L p .707 .577 .707 r
F P
0 g
s
.64085 .84749 m .64085 .86602 L .60968 .86412 L p .707 .577 .707 r
F P
0 g
s
.60968 .86412 m .60968 .84559 L .64085 .84749 L p .707 .577 .707 r
F P
0 g
s
.61082 .90004 m .61082 .40207 L .57686 .41005 L p .707 .577 .707 r
F P
0 g
s
.31434 .66953 m .31434 .72511 L .33839 .71946 L p .707 .577 .707 r
F P
0 g
s
.33839 .71946 m .33839 .66388 L .31434 .66953 L p .707 .577 .707 r
F P
0 g
s
.70195 .77742 m .70195 .81447 L .68936 .80659 L p .707 .577 .707 r
F P
0 g
s
.68936 .80659 m .68936 .76953 L .70195 .77742 L p .707 .577 .707 r
F P
0 g
s
.68936 .66854 m .68936 .72412 L .66831 .71767 L p .707 .577 .707 r
F P
0 g
s
.66831 .71767 m .66831 .66208 L .68936 .66854 L p .707 .577 .707 r
F P
0 g
s
.19449 .66739 m .19449 .72298 L .22195 .72737 L p .707 .577 .707 r
F P
0 g
s
.19449 .72298 m .19449 .66739 L .17343 .66094 L p .707 .577 .707 r
F P
0 g
s
.40766 .905 m .40766 .40703 L .37794 .39792 L p .707 .577 .707 r
F P
0 g
s
.40766 .40703 m .40766 .905 L .44612 .91115 L p .707 .577 .707 r
F P
0 g
s
.44612 .91115 m .44643 .9112 L p .40766 .40703 L .707 .577 .707 r
F P
0 g
s
.25312 .81174 m .25312 .77468 L .22195 .77278 L p .707 .577 .707 r
F P
0 g
s
.25312 .77468 m .25312 .81174 L .28495 .81096 L p .707 .577 .707 r
F P
0 g
s
.28495 .81096 m .28495 .7739 L .25312 .77468 L p .707 .577 .707 r
F P
0 g
s
.28495 .7739 m .28495 .81096 L .31434 .80758 L p .707 .577 .707 r
F P
0 g
s
.31434 .80758 m .31434 .77052 L .28495 .7739 L p .707 .577 .707 r
F P
0 g
s
.22195 .80983 m .22195 .77278 L .19449 .76839 L p .707 .577 .707 r
F P
0 g
s
.22195 .77278 m .22195 .80983 L .25312 .81174 L p .707 .577 .707 r
F P
0 g
s
.33839 .66388 m .33839 .71946 L .35476 .7121 L p .707 .577 .707 r
F P
0 g
s
.35476 .7121 m .35476 .65651 L .33839 .66388 L p .707 .577 .707 r
F P
0 g
s
.17343 .66094 m .17343 .71652 L .19449 .72298 L p .707 .577 .707 r
F P
0 g
s
.61082 .40207 m .61082 .90004 L .63375 .88972 L p .707 .577 .707 r
F P
0 g
s
.63375 .88972 m .63393 .88964 L p .61082 .40207 L .707 .577 .707 r
F P
0 g
s
.63393 .88964 m .63393 .39167 L .61082 .40207 L p .707 .577 .707 r
F P
0 g
s
.66831 .66208 m .66831 .71767 L .64085 .71327 L p .707 .577 .707 r
F P
0 g
s
.64085 .71327 m .64085 .65769 L .66831 .66208 L p .707 .577 .707 r
F P
0 g
s
.70195 .86622 m .70195 .88475 L .68936 .87686 L p .707 .577 .707 r
F P
0 g
s
.68936 .87686 m .68936 .85833 L .70195 .86622 L p .707 .577 .707 r
F P
0 g
s
.31434 .77052 m .31434 .80758 L .33839 .80193 L p .707 .577 .707 r
F P
0 g
s
.33839 .80193 m .33839 .76487 L .31434 .77052 L p .707 .577 .707 r
F P
0 g
s
.19449 .76839 m .19449 .80544 L .22195 .80983 L p .707 .577 .707 r
F P
0 g
s
.17343 .71652 m .17343 .66094 L .16084 .65306 L p .707 .577 .707 r
F P
0 g
s
.68936 .76953 m .68936 .80659 L .66831 .80013 L p .707 .577 .707 r
F P
0 g
s
.66831 .80013 m .66831 .76308 L .68936 .76953 L p .707 .577 .707 r
F P
0 g
s
.19449 .80544 m .19449 .76839 L .17343 .76193 L p .707 .577 .707 r
F P
0 g
s
.25312 .88201 m .25312 .86348 L .22195 .86158 L p .707 .577 .707 r
F P
0 g
s
.25312 .86348 m .25312 .88201 L .28495 .88123 L p .707 .577 .707 r
F P
0 g
s
.28495 .88123 m .28495 .86271 L .25312 .86348 L p .707 .577 .707 r
F P
0 g
s
.28495 .86271 m .28495 .88123 L .31434 .87785 L p .707 .577 .707 r
F P
0 g
s
.31434 .87785 m .31434 .85933 L .28495 .86271 L p .707 .577 .707 r
F P
0 g
s
.37794 .89589 m .37794 .39792 L .36016 .38679 L p .707 .577 .707 r
F P
0 g
s
.37794 .39792 m .37794 .89589 L .40743 .90493 L p .707 .577 .707 r
F P
0 g
s
.40743 .90493 m .40766 .905 L p .37794 .39792 L .707 .577 .707 r
F P
0 g
s
.22195 .86158 m .22195 .88011 L .25312 .88201 L p .707 .577 .707 r
F P
0 g
s
.22195 .88011 m .22195 .86158 L .19449 .85719 L p .707 .577 .707 r
F P
0 g
s
.17343 .76193 m .17343 .79899 L .19449 .80544 L p .707 .577 .707 r
F P
0 g
s
.16084 .65306 m .16084 .70864 L .17343 .71652 L p .707 .577 .707 r
F P
0 g
s
.35476 .65651 m .35476 .7121 L .36184 .70373 L p .707 .577 .707 r
F P
0 g
s
.36184 .70373 m .36184 .64815 L .35476 .65651 L p .707 .577 .707 r
F P
0 g
s
.33839 .76487 m .33839 .80193 L .35476 .79456 L p .707 .577 .707 r
F P
0 g
s
.35476 .79456 m .35476 .75751 L .33839 .76487 L p .707 .577 .707 r
F P
0 g
s
.19449 .85719 m .19449 .87572 L .22195 .88011 L p .707 .577 .707 r
F P
0 g
s
.31434 .85933 m .31434 .87785 L .33839 .87221 L p .707 .577 .707 r
F P
0 g
s
.33839 .87221 m .33839 .85368 L .31434 .85933 L p .707 .577 .707 r
F P
0 g
s
.66831 .76308 m .66831 .80013 L .64085 .79574 L p .707 .577 .707 r
F P
0 g
s
.64085 .79574 m .64085 .75869 L .66831 .76308 L p .707 .577 .707 r
F P
0 g
s
.68936 .85833 m .68936 .87686 L .66831 .87041 L p .707 .577 .707 r
F P
0 g
s
.66831 .87041 m .66831 .85188 L .68936 .85833 L p .707 .577 .707 r
F P
0 g
s
.17343 .79899 m .17343 .76193 L .16084 .75405 L p .707 .577 .707 r
F P
0 g
s
.16084 .70864 m .16084 .65306 L .15794 .64451 L p .707 .577 .707 r
F P
0 g
s
.19449 .87572 m .19449 .85719 L .17343 .85074 L p .707 .577 .707 r
F P
0 g
s
.66831 .85188 m .66831 .87041 L .64085 .86602 L p .707 .577 .707 r
F P
0 g
s
.64085 .86602 m .64085 .84749 L .66831 .85188 L p .707 .577 .707 r
F P
0 g
s
.63393 .39167 m .63393 .88964 L .64385 .87792 L p .707 .577 .707 r
F P
0 g
s
.64385 .87792 m .64393 .87783 L p .63393 .39167 L .707 .577 .707 r
F P
0 g
s
.64393 .87783 m .64393 .37986 L .63393 .39167 L p .707 .577 .707 r
F P
0 g
s
.17343 .85074 m .17343 .86926 L .19449 .87572 L p .707 .577 .707 r
F P
0 g
s
.16084 .75405 m .16084 .7911 L .17343 .79899 L p .707 .577 .707 r
F P
0 g
s
.33839 .85368 m .33839 .87221 L .35476 .86484 L p .707 .577 .707 r
F P
0 g
s
.35476 .86484 m .35476 .84631 L .33839 .85368 L p .707 .577 .707 r
F P
0 g
s
.15794 .64451 m .15794 .7001 L .16084 .70864 L p .707 .577 .707 r
F P
0 g
s
.35476 .75751 m .35476 .79456 L .36184 .7862 L p .707 .577 .707 r
F P
0 g
s
.36184 .7862 m .36184 .74914 L .35476 .75751 L p .707 .577 .707 r
F P
0 g
s
.36184 .64815 m .36184 .70373 L .35894 .69519 L p .707 .577 .707 r
F P
0 g
s
.35894 .69519 m .35894 .63961 L .36184 .64815 L p .707 .577 .707 r
F P
0 g
s
.35476 .84631 m .35476 .86484 L .36184 .85647 L p .707 .577 .707 r
F P
0 g
s
.36184 .85647 m .36184 .83795 L .35476 .84631 L p .707 .577 .707 r
F P
0 g
s
.36184 .74914 m .36184 .7862 L .35894 .77766 L p .707 .577 .707 r
F P
0 g
s
.35894 .77766 m .35894 .7406 L .36184 .74914 L p .707 .577 .707 r
F P
0 g
s
.35894 .63961 m .35894 .69519 L .34635 .68731 L p .707 .577 .707 r
F P
0 g
s
.34635 .68731 m .34635 .63172 L .35894 .63961 L p .707 .577 .707 r
F P
0 g
s
.36184 .83795 m .36184 .85647 L .35894 .84793 L p .707 .577 .707 r
F P
0 g
s
.35894 .84793 m .35894 .8294 L .36184 .83795 L p .707 .577 .707 r
F P
0 g
s
.36016 .88476 m .36016 .38679 L .35607 .37473 L p .707 .577 .707 r
F P
0 g
s
.36016 .38679 m .36016 .88476 L .3778 .8958 L p .707 .577 .707 r
F P
0 g
s
.3778 .8958 m .37794 .89589 L p .36016 .38679 L .707 .577 .707 r
F P
0 g
s
.17343 .86926 m .17343 .85074 L .16084 .84285 L p .707 .577 .707 r
F P
0 g
s
.16084 .7911 m .16084 .75405 L .15794 .74551 L p .707 .577 .707 r
F P
0 g
s
.16084 .84285 m .16084 .86138 L .17343 .86926 L p .707 .577 .707 r
F P
0 g
s
.15794 .7001 m .15794 .64451 L .16503 .63615 L p .707 .577 .707 r
F P
0 g
s
.15794 .74551 m .15794 .78256 L .16084 .7911 L p .707 .577 .707 r
F P
0 g
s
.16503 .63615 m .16503 .69173 L .15794 .7001 L p .707 .577 .707 r
F P
0 g
s
.64393 .37986 m .64393 .87783 L .63987 .86586 L p .707 .577 .707 r
F P
0 g
s
.63987 .86586 m .63984 .86577 L p .64393 .37986 L .707 .577 .707 r
F P
0 g
s
.63984 .86577 m .63984 .3678 L .64393 .37986 L p .707 .577 .707 r
F P
0 g
s
.16084 .86138 m .16084 .84285 L .15794 .83431 L p .707 .577 .707 r
F P
0 g
s
.15794 .83431 m .15794 .85284 L .16084 .86138 L p .707 .577 .707 r
F P
0 g
s
.15794 .78256 m .15794 .74551 L .16503 .73714 L p .707 .577 .707 r
F P
0 g
s
.16503 .69173 m .16503 .63615 L .1814 .62878 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.35894 .7406 m .35894 .77766 L .34635 .76977 L p .707 .577 .707 r
F P
0 g
s
.34635 .76977 m .34635 .73272 L .35894 .7406 L p .707 .577 .707 r
F P
0 g
s
.35894 .8294 m .35894 .84793 L .34635 .84005 L p .707 .577 .707 r
F P
0 g
s
.34635 .84005 m .34635 .82152 L .35894 .8294 L p .707 .577 .707 r
F P
0 g
s
.35607 .37473 m .35607 .8727 L .36013 .88466 L p .707 .577 .707 r
F P
0 g
s
.36013 .88466 m .36016 .88476 L p .35607 .37473 L .707 .577 .707 r
F P
0 g
s
.35607 .8727 m .35607 .37473 L .36607 .36292 L p .707 .577 .707 r
F P
0 g
s
.16503 .73714 m .16503 .7742 L .15794 .78256 L p .707 .577 .707 r
F P
0 g
s
.1814 .62878 m .1814 .68436 L .16503 .69173 L p .707 .577 .707 r
F P
0 g
s
.34635 .63172 m .34635 .68731 L .3253 .68085 L p .707 .577 .707 r
F P
0 g
s
.3253 .68085 m .3253 .62527 L .34635 .63172 L p .707 .577 .707 r
F P
0 g
s
.15794 .85284 m .15794 .83431 L .16503 .82595 L p .707 .577 .707 r
F P
0 g
s
.1814 .68436 m .1814 .62878 L .20545 .62313 L p .707 .577 .707 r
F P
0 g
s
.16503 .82595 m .16503 .84447 L .15794 .85284 L p .707 .577 .707 r
F P
0 g
s
.16503 .7742 m .16503 .73714 L .1814 .72978 L p .707 .577 .707 r
F P
0 g
s
.63984 .3678 m .63984 .86577 L .6222 .85473 L p .707 .577 .707 r
F P
0 g
s
.6222 .85473 m .62206 .85464 L p .63984 .3678 L .707 .577 .707 r
F P
0 g
s
.62206 .85464 m .62206 .35667 L .63984 .3678 L p .707 .577 .707 r
F P
0 g
s
.1814 .72978 m .1814 .76683 L .16503 .7742 L p .707 .577 .707 r
F P
0 g
s
.3253 .62527 m .3253 .68085 L .29784 .67646 L p .707 .577 .707 r
F P
0 g
s
.29784 .67646 m .29784 .62088 L .3253 .62527 L p .707 .577 .707 r
F P
0 g
s
.20545 .62313 m .20545 .67871 L .1814 .68436 L p .707 .577 .707 r
F P
0 g
s
.34635 .73272 m .34635 .76977 L .3253 .76332 L p .707 .577 .707 r
F P
0 g
s
.3253 .76332 m .3253 .72626 L .34635 .73272 L p .707 .577 .707 r
F P
0 g
s
.20545 .67871 m .20545 .62313 L .23483 .61975 L p .707 .577 .707 r
F P
0 g
s
.36607 .86089 m .36607 .36292 L .38918 .35252 L p .707 .577 .707 r
F P
0 g
s
.36607 .36292 m .36607 .86089 L .35615 .8726 L p .707 .577 .707 r
F P
0 g
s
.35615 .8726 m .35607 .8727 L p .36607 .36292 L .707 .577 .707 r
F P
0 g
s
.16503 .84447 m .16503 .82595 L .1814 .81858 L p .707 .577 .707 r
F P
0 g
s
.1814 .76683 m .1814 .72978 L .20545 .72413 L p .707 .577 .707 r
F P
0 g
s
.29784 .62088 m .29784 .67646 L .26667 .67456 L p .707 .577 .707 r
F P
0 g
s
.26667 .67456 m .26667 .61898 L .29784 .62088 L p .707 .577 .707 r
F P
0 g
s
.1814 .81858 m .1814 .83711 L .16503 .84447 L p .707 .577 .707 r
F P
0 g
s
.23483 .67534 m .23483 .61975 L .26667 .61898 L p .707 .577 .707 r
F P
0 g
s
.23483 .61975 m .23483 .67534 L .20545 .67871 L p .707 .577 .707 r
F P
0 g
s
.26667 .61898 m .26667 .67456 L .23483 .67534 L p .707 .577 .707 r
F P
0 g
s
.73333 .67405 m .73333 .61846 L .70216 .61656 L p .707 .577 .707 r
F P
0 g
s
.73333 .61846 m .73333 .67405 L .76517 .67327 L p .707 .577 .707 r
F P
0 g
s
.76517 .67327 m .76517 .61769 L .73333 .61846 L p .707 .577 .707 r
F P
0 g
s
.20545 .72413 m .20545 .76118 L .1814 .76683 L p .707 .577 .707 r
F P
0 g
s
.76517 .61769 m .76517 .67327 L .79455 .66989 L p .707 .577 .707 r
F P
0 g
s
.79455 .66989 m .79455 .61431 L .76517 .61769 L p .707 .577 .707 r
F P
0 g
s
.3253 .72626 m .3253 .76332 L .29784 .75893 L p .707 .577 .707 r
F P
0 g
s
.29784 .75893 m .29784 .72187 L .3253 .72626 L p .707 .577 .707 r
F P
0 g
s
.34635 .82152 m .34635 .84005 L .3253 .83359 L p .707 .577 .707 r
F P
0 g
s
.3253 .83359 m .3253 .81507 L .34635 .82152 L p .707 .577 .707 r
F P
0 g
s
.62206 .35667 m .62206 .85464 L .59257 .8456 L p .707 .577 .707 r
F P
0 g
s
.59257 .8456 m .59233 .84553 L p .62206 .35667 L .707 .577 .707 r
F P
0 g
s
.59233 .84553 m .59233 .34756 L .62206 .35667 L p .707 .577 .707 r
F P
0 g
s
.70216 .67215 m .70216 .61656 L .6747 .61217 L p .707 .577 .707 r
F P
0 g
s
.70216 .61656 m .70216 .67215 L .73333 .67405 L p .707 .577 .707 r
F P
0 g
s
.20545 .76118 m .20545 .72413 L .23483 .72075 L p .707 .577 .707 r
F P
0 g
s
.79455 .61431 m .79455 .66989 L .8186 .66424 L p .707 .577 .707 r
F P
0 g
s
.8186 .66424 m .8186 .60866 L .79455 .61431 L p .707 .577 .707 r
F P
0 g
s
.1814 .83711 m .1814 .81858 L .20545 .81293 L p .707 .577 .707 r
F P
0 g
s
.29784 .72187 m .29784 .75893 L .26667 .75702 L p .707 .577 .707 r
F P
0 g
s
.26667 .75702 m .26667 .71997 L .29784 .72187 L p .707 .577 .707 r
F P
0 g
s
.38918 .35252 m .38918 .85049 L .36625 .86081 L p .707 .577 .707 r
F P
0 g
s
.36625 .86081 m .36607 .86089 L p .38918 .35252 L .707 .577 .707 r
F P
0 g
s
.38918 .85049 m .38918 .35252 L .42314 .34454 L p .707 .577 .707 r
F P
0 g
s
.20545 .81293 m .20545 .83146 L .1814 .83711 L p .707 .577 .707 r
F P
0 g
s
.23483 .72075 m .23483 .7578 L .20545 .76118 L p .707 .577 .707 r
F P
0 g
s
.6747 .61217 m .6747 .66775 L .70216 .67215 L p .707 .577 .707 r
F P
0 g
s
.6747 .66775 m .6747 .61217 L .65365 .60572 L p .707 .577 .707 r
F P
0 g
s
.23483 .7578 m .23483 .72075 L .26667 .71997 L p .707 .577 .707 r
F P
0 g
s
.26667 .71997 m .26667 .75702 L .23483 .7578 L p .707 .577 .707 r
F P
0 g
s
.73333 .75651 m .73333 .71946 L .70216 .71756 L p .707 .577 .707 r
F P
0 g
s
.73333 .71946 m .73333 .75651 L .76517 .75574 L p .707 .577 .707 r
F P
0 g
s
.76517 .75574 m .76517 .71868 L .73333 .71946 L p .707 .577 .707 r
F P
0 g
s
.3253 .81507 m .3253 .83359 L .29784 .8292 L p .707 .577 .707 r
F P
0 g
s
.29784 .8292 m .29784 .81067 L .3253 .81507 L p .707 .577 .707 r
F P
0 g
s
.76517 .71868 m .76517 .75574 L .79455 .75236 L p .707 .577 .707 r
F P
0 g
s
.79455 .75236 m .79455 .7153 L .76517 .71868 L p .707 .577 .707 r
F P
0 g
s
.70216 .75461 m .70216 .71756 L .6747 .71316 L p .707 .577 .707 r
F P
0 g
s
.70216 .71756 m .70216 .75461 L .73333 .75651 L p .707 .577 .707 r
F P
0 g
s
.8186 .60866 m .8186 .66424 L .83497 .65687 L p .707 .577 .707 r
F P
0 g
s
.83497 .65687 m .83497 .60129 L .8186 .60866 L p .707 .577 .707 r
F P
0 g
s
.20545 .83146 m .20545 .81293 L .23483 .80955 L p .707 .577 .707 r
F P
0 g
s
.65365 .60572 m .65365 .6613 L .6747 .66775 L p .707 .577 .707 r
F P
0 g
s
.59233 .34756 m .59233 .84553 L .55387 .83937 L p .707 .577 .707 r
F P
0 g
s
.55387 .83937 m .55357 .83933 L p .59233 .34756 L .707 .577 .707 r
F P
0 g
s
.55357 .83933 m .55357 .34136 L .59233 .34756 L p .707 .577 .707 r
F P
0 g
s
.23483 .80955 m .23483 .82808 L .20545 .83146 L p .707 .577 .707 r
F P
0 g
s
.79455 .7153 m .79455 .75236 L .8186 .74671 L p .707 .577 .707 r
F P
0 g
s
.8186 .74671 m .8186 .70965 L .79455 .7153 L p .707 .577 .707 r
F P
0 g
s
.29784 .81067 m .29784 .8292 L .26667 .8273 L p .707 .577 .707 r
F P
0 g
s
.26667 .8273 m .26667 .80877 L .29784 .81067 L p .707 .577 .707 r
F P
0 g
s
.6747 .71316 m .6747 .75022 L .70216 .75461 L p .707 .577 .707 r
F P
0 g
s
.65365 .6613 m .65365 .60572 L .64105 .59783 L p .707 .577 .707 r
F P
0 g
s
.23483 .82808 m .23483 .80955 L .26667 .80877 L p .707 .577 .707 r
F P
0 g
s
.42314 .84251 m .42314 .34454 L .46462 .33977 L p .707 .577 .707 r
F P
0 g
s
.42314 .34454 m .42314 .84251 L .38944 .85042 L p .707 .577 .707 r
F P
0 g
s
.38944 .85042 m .38918 .85049 L p .42314 .34454 L .707 .577 .707 r
F P
0 g
s
.6747 .75022 m .6747 .71316 L .65365 .70671 L p .707 .577 .707 r
F P
0 g
s
.26667 .80877 m .26667 .8273 L .23483 .82808 L p .707 .577 .707 r
F P
0 g
s
.73333 .82679 m .73333 .80826 L .70216 .80636 L p .707 .577 .707 r
F P
0 g
s
.73333 .80826 m .73333 .82679 L .76517 .82601 L p .707 .577 .707 r
F P
0 g
s
.76517 .82601 m .76517 .80748 L .73333 .80826 L p .707 .577 .707 r
F P
0 g
s
.76517 .80748 m .76517 .82601 L .79455 .82263 L p .707 .577 .707 r
F P
0 g
s
.79455 .82263 m .79455 .8041 L .76517 .80748 L p .707 .577 .707 r
F P
0 g
s
.70216 .80636 m .70216 .82489 L .73333 .82679 L p .707 .577 .707 r
F P
0 g
s
.70216 .82489 m .70216 .80636 L .6747 .80197 L p .707 .577 .707 r
F P
0 g
s
.55357 .34136 m .55357 .83933 L .50991 .83666 L p .707 .577 .707 r
F P
0 g
s
.50991 .83666 m .50956 .83664 L p .55357 .34136 L .707 .577 .707 r
F P
0 g
s
.50956 .83664 m .50956 .33867 L .55357 .34136 L p .707 .577 .707 r
F P
0 g
s
.65365 .70671 m .65365 .74377 L .6747 .75022 L p .707 .577 .707 r
F P
0 g
s
.64105 .59783 m .64105 .65342 L .65365 .6613 L p .707 .577 .707 r
F P
0 g
s
.83497 .60129 m .83497 .65687 L .84205 .64851 L p .707 .577 .707 r
F P
0 g
s
.84205 .64851 m .84205 .59293 L .83497 .60129 L p .707 .577 .707 r
F P
0 g
s
.8186 .70965 m .8186 .74671 L .83497 .73934 L p .707 .577 .707 r
F P
0 g
s
.83497 .73934 m .83497 .70228 L .8186 .70965 L p .707 .577 .707 r
F P
0 g
s
.6747 .80197 m .6747 .8205 L .70216 .82489 L p .707 .577 .707 r
F P
0 g
s
.46462 .83774 m .46462 .33977 L .50956 .33867 L p .707 .577 .707 r
F P
0 g
s
.46462 .33977 m .46462 .83774 L .42346 .84247 L p .707 .577 .707 r
F P
0 g
s
.42346 .84247 m .42314 .84251 L p .46462 .33977 L .707 .577 .707 r
F P
0 g
s
.79455 .8041 m .79455 .82263 L .8186 .81698 L p .707 .577 .707 r
F P
0 g
s
.8186 .81698 m .8186 .79845 L .79455 .8041 L p .707 .577 .707 r
F P
0 g
s
.50956 .33867 m .50956 .83664 L .46497 .83773 L p .707 .577 .707 r
F P
0 g
s
.46497 .83773 m .46462 .83774 L p .50956 .33867 L .707 .577 .707 r
F P
0 g
s
.65365 .74377 m .65365 .70671 L .64105 .69883 L p .707 .577 .707 r
F P
0 g
s
.64105 .65342 m .64105 .59783 L .63816 .58929 L p .707 .577 .707 r
F P
0 g
s
.6747 .8205 m .6747 .80197 L .65365 .79551 L p .707 .577 .707 r
F P
0 g
s
.65365 .79551 m .65365 .81404 L .6747 .8205 L p .707 .577 .707 r
F P
0 g
s
.64105 .69883 m .64105 .73588 L .65365 .74377 L p .707 .577 .707 r
F P
0 g
s
.8186 .79845 m .8186 .81698 L .83497 .80961 L p .707 .577 .707 r
F P
0 g
s
.83497 .80961 m .83497 .79109 L .8186 .79845 L p .707 .577 .707 r
F P
0 g
s
.63816 .58929 m .63816 .64487 L .64105 .65342 L p .707 .577 .707 r
F P
0 g
s
.83497 .70228 m .83497 .73934 L .84206 .73097 L p .707 .577 .707 r
F P
0 g
s
.84206 .73097 m .84206 .69392 L .83497 .70228 L p .707 .577 .707 r
F P
0 g
s
.84205 .59293 m .84205 .64851 L .83916 .63997 L p .707 .577 .707 r
F P
0 g
s
.83916 .63997 m .83916 .58438 L .84205 .59293 L p .707 .577 .707 r
F P
0 g
s
.65365 .81404 m .65365 .79551 L .64105 .78763 L p .707 .577 .707 r
F P
0 g
s
.64105 .73588 m .64105 .69883 L .63816 .69028 L p .707 .577 .707 r
F P
0 g
s
.64105 .78763 m .64105 .80616 L .65365 .81404 L p .707 .577 .707 r
F P
0 g
s
.63816 .64487 m .63816 .58929 L .64524 .58093 L p .707 .577 .707 r
F P
0 g
s
.63816 .69028 m .63816 .72734 L .64105 .73588 L p .707 .577 .707 r
F P
0 g
s
.83497 .79109 m .83497 .80961 L .84206 .80125 L p .707 .577 .707 r
F P
0 g
s
.84206 .80125 m .84206 .78272 L .83497 .79109 L p .707 .577 .707 r
F P
0 g
s
.84206 .69392 m .84206 .73097 L .83916 .72243 L p .707 .577 .707 r
F P
0 g
s
.83916 .72243 m .83916 .68538 L .84206 .69392 L p .707 .577 .707 r
F P
0 g
s
.64524 .58093 m .64524 .63651 L .63816 .64487 L p .707 .577 .707 r
F P
0 g
s
.83916 .58438 m .83916 .63997 L .82657 .63208 L p .707 .577 .707 r
F P
0 g
s
.82657 .63208 m .82657 .5765 L .83916 .58438 L p .707 .577 .707 r
F P
0 g
s
.64105 .80616 m .64105 .78763 L .63816 .77909 L p .707 .577 .707 r
F P
0 g
s
.63816 .77909 m .63816 .79762 L .64105 .80616 L p .707 .577 .707 r
F P
0 g
s
.39032 .63723 m .39032 .58165 L .35915 .57975 L p .707 .577 .707 r
F P
0 g
s
.39032 .58165 m .39032 .63723 L .42216 .63645 L p .707 .577 .707 r
F P
0 g
s
.42216 .63645 m .42216 .58087 L .39032 .58165 L p .707 .577 .707 r
F P
0 g
s
.63816 .72734 m .63816 .69028 L .64524 .68192 L p .707 .577 .707 r
F P
0 g
s
.64524 .63651 m .64524 .58093 L .66161 .57356 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.42216 .58087 m .42216 .63645 L .45154 .63308 L p .707 .577 .707 r
F P
0 g
s
.45154 .63308 m .45154 .57749 L .42216 .58087 L p .707 .577 .707 r
F P
0 g
s
.35915 .63533 m .35915 .57975 L .33169 .57536 L p .707 .577 .707 r
F P
0 g
s
.35915 .57975 m .35915 .63533 L .39032 .63723 L p .707 .577 .707 r
F P
0 g
s
.64524 .68192 m .64524 .71898 L .63816 .72734 L p .707 .577 .707 r
F P
0 g
s
.84206 .78272 m .84206 .80125 L .83916 .79271 L p .707 .577 .707 r
F P
0 g
s
.83916 .79271 m .83916 .77418 L .84206 .78272 L p .707 .577 .707 r
F P
0 g
s
.45154 .57749 m .45154 .63308 L .47559 .62743 L p .707 .577 .707 r
F P
0 g
s
.47559 .62743 m .47559 .57184 L .45154 .57749 L p .707 .577 .707 r
F P
0 g
s
.66161 .57356 m .66161 .62914 L .64524 .63651 L p .707 .577 .707 r
F P
0 g
s
.83916 .68538 m .83916 .72243 L .82657 .71455 L p .707 .577 .707 r
F P
0 g
s
.82657 .71455 m .82657 .67749 L .83916 .68538 L p .707 .577 .707 r
F P
0 g
s
.82657 .5765 m .82657 .63208 L .80551 .62563 L p .707 .577 .707 r
F P
0 g
s
.80551 .62563 m .80551 .57005 L .82657 .5765 L p .707 .577 .707 r
F P
0 g
s
.33169 .57536 m .33169 .63094 L .35915 .63533 L p .707 .577 .707 r
F P
0 g
s
.33169 .63094 m .33169 .57536 L .31064 .5689 L p .707 .577 .707 r
F P
0 g
s
.63816 .79762 m .63816 .77909 L .64524 .77072 L p .707 .577 .707 r
F P
0 g
s
.39032 .7197 m .39032 .68264 L .35915 .68074 L p .707 .577 .707 r
F P
0 g
s
.39032 .68264 m .39032 .7197 L .42216 .71892 L p .707 .577 .707 r
F P
0 g
s
.42216 .71892 m .42216 .68187 L .39032 .68264 L p .707 .577 .707 r
F P
0 g
s
.66161 .62914 m .66161 .57356 L .68566 .56791 L p .707 .577 .707 r
F P
0 g
s
.64524 .77072 m .64524 .78925 L .63816 .79762 L p .707 .577 .707 r
F P
0 g
s
.64524 .71898 m .64524 .68192 L .66161 .67455 L p .707 .577 .707 r
F P
0 g
s
.42216 .68187 m .42216 .71892 L .45154 .71554 L p .707 .577 .707 r
F P
0 g
s
.45154 .71554 m .45154 .67849 L .42216 .68187 L p .707 .577 .707 r
F P
0 g
s
.35915 .7178 m .35915 .68074 L .33169 .67635 L p .707 .577 .707 r
F P
0 g
s
.35915 .68074 m .35915 .7178 L .39032 .7197 L p .707 .577 .707 r
F P
0 g
s
.47559 .57184 m .47559 .62743 L .49196 .62006 L p .707 .577 .707 r
F P
0 g
s
.49196 .62006 m .49196 .56448 L .47559 .57184 L p .707 .577 .707 r
F P
0 g
s
.31064 .5689 m .31064 .62448 L .33169 .63094 L p .707 .577 .707 r
F P
0 g
s
.66161 .67455 m .66161 .71161 L .64524 .71898 L p .707 .577 .707 r
F P
0 g
s
.80551 .57005 m .80551 .62563 L .77805 .62124 L p .707 .577 .707 r
F P
0 g
s
.77805 .62124 m .77805 .56565 L .80551 .57005 L p .707 .577 .707 r
F P
0 g
s
.83916 .77418 m .83916 .79271 L .82657 .78482 L p .707 .577 .707 r
F P
0 g
s
.82657 .78482 m .82657 .7663 L .83916 .77418 L p .707 .577 .707 r
F P
0 g
s
.45154 .67849 m .45154 .71554 L .47559 .70989 L p .707 .577 .707 r
F P
0 g
s
.47559 .70989 m .47559 .67284 L .45154 .67849 L p .707 .577 .707 r
F P
0 g
s
.68566 .56791 m .68566 .62349 L .66161 .62914 L p .707 .577 .707 r
F P
0 g
s
.33169 .67635 m .33169 .7134 L .35915 .7178 L p .707 .577 .707 r
F P
0 g
s
.31064 .62448 m .31064 .5689 L .29804 .56102 L p .707 .577 .707 r
F P
0 g
s
.82657 .67749 m .82657 .71455 L .80551 .70809 L p .707 .577 .707 r
F P
0 g
s
.80551 .70809 m .80551 .67104 L .82657 .67749 L p .707 .577 .707 r
F P
0 g
s
.68566 .62349 m .68566 .56791 L .71504 .56453 L p .707 .577 .707 r
F P
0 g
s
.33169 .7134 m .33169 .67635 L .31064 .6699 L p .707 .577 .707 r
F P
0 g
s
.39032 .78997 m .39032 .77145 L .35915 .76954 L p .707 .577 .707 r
F P
0 g
s
.39032 .77145 m .39032 .78997 L .42216 .7892 L p .707 .577 .707 r
F P
0 g
s
.42216 .7892 m .42216 .77067 L .39032 .77145 L p .707 .577 .707 r
F P
0 g
s
.64524 .78925 m .64524 .77072 L .66161 .76336 L p .707 .577 .707 r
F P
0 g
s
.42216 .77067 m .42216 .7892 L .45154 .78582 L p .707 .577 .707 r
F P
0 g
s
.45154 .78582 m .45154 .76729 L .42216 .77067 L p .707 .577 .707 r
F P
0 g
s
.66161 .71161 m .66161 .67455 L .68566 .6689 L p .707 .577 .707 r
F P
0 g
s
.77805 .56565 m .77805 .62124 L .74688 .61934 L p .707 .577 .707 r
F P
0 g
s
.74688 .61934 m .74688 .56375 L .77805 .56565 L p .707 .577 .707 r
F P
0 g
s
.35915 .76954 m .35915 .78807 L .39032 .78997 L p .707 .577 .707 r
F P
0 g
s
.35915 .78807 m .35915 .76954 L .33169 .76515 L p .707 .577 .707 r
F P
0 g
s
.66161 .76336 m .66161 .78188 L .64524 .78925 L p .707 .577 .707 r
F P
0 g
s
.31064 .6699 m .31064 .70695 L .33169 .7134 L p .707 .577 .707 r
F P
0 g
s
.29804 .56102 m .29804 .6166 L .31064 .62448 L p .707 .577 .707 r
F P
0 g
s
.71504 .62011 m .71504 .56453 L .74688 .56375 L p .707 .577 .707 r
F P
0 g
s
.71504 .56453 m .71504 .62011 L .68566 .62349 L p .707 .577 .707 r
F P
0 g
s
.49196 .56448 m .49196 .62006 L .49904 .61169 L p .707 .577 .707 r
F P
0 g
s
.49904 .61169 m .49904 .55611 L .49196 .56448 L p .707 .577 .707 r
F P
0 g
s
.47559 .67284 m .47559 .70989 L .49196 .70252 L p .707 .577 .707 r
F P
0 g
s
.49196 .70252 m .49196 .66547 L .47559 .67284 L p .707 .577 .707 r
F P
0 g
s
.74688 .56375 m .74688 .61934 L .71504 .62011 L p .707 .577 .707 r
F P
0 g
s
.33169 .76515 m .33169 .78368 L .35915 .78807 L p .707 .577 .707 r
F P
0 g
s
.68566 .6689 m .68566 .70596 L .66161 .71161 L p .707 .577 .707 r
F P
0 g
s
.45154 .76729 m .45154 .78582 L .47559 .78017 L p .707 .577 .707 r
F P
0 g
s
.47559 .78017 m .47559 .76164 L .45154 .76729 L p .707 .577 .707 r
F P
0 g
s
.80551 .67104 m .80551 .70809 L .77805 .7037 L p .707 .577 .707 r
F P
0 g
s
.77805 .7037 m .77805 .66665 L .80551 .67104 L p .707 .577 .707 r
F P
0 g
s
.82657 .7663 m .82657 .78482 L .80551 .77837 L p .707 .577 .707 r
F P
0 g
s
.80551 .77837 m .80551 .75984 L .82657 .7663 L p .707 .577 .707 r
F P
0 g
s
.31064 .70695 m .31064 .6699 L .29804 .66201 L p .707 .577 .707 r
F P
0 g
s
.29804 .6166 m .29804 .56102 L .29515 .55248 L p .707 .577 .707 r
F P
0 g
s
.33169 .78368 m .33169 .76515 L .31064 .7587 L p .707 .577 .707 r
F P
0 g
s
.68566 .70596 m .68566 .6689 L .71504 .66552 L p .707 .577 .707 r
F P
0 g
s
.31064 .7587 m .31064 .77723 L .33169 .78368 L p .707 .577 .707 r
F P
0 g
s
.66161 .78188 m .66161 .76336 L .68566 .75771 L p .707 .577 .707 r
F P
0 g
s
.29804 .66201 m .29804 .69907 L .31064 .70695 L p .707 .577 .707 r
F P
0 g
s
.77805 .66665 m .77805 .7037 L .74688 .7018 L p .707 .577 .707 r
F P
0 g
s
.74688 .7018 m .74688 .66475 L .77805 .66665 L p .707 .577 .707 r
F P
0 g
s
.68566 .75771 m .68566 .77623 L .66161 .78188 L p .707 .577 .707 r
F P
0 g
s
.71504 .66552 m .71504 .70258 L .68566 .70596 L p .707 .577 .707 r
F P
0 g
s
.47559 .76164 m .47559 .78017 L .49196 .7728 L p .707 .577 .707 r
F P
0 g
s
.49196 .7728 m .49196 .75427 L .47559 .76164 L p .707 .577 .707 r
F P
0 g
s
.29515 .55248 m .29515 .60806 L .29804 .6166 L p .707 .577 .707 r
F P
0 g
s
.71504 .70258 m .71504 .66552 L .74688 .66475 L p .707 .577 .707 r
F P
0 g
s
.49196 .66547 m .49196 .70252 L .49904 .69416 L p .707 .577 .707 r
F P
0 g
s
.49904 .69416 m .49904 .6571 L .49196 .66547 L p .707 .577 .707 r
F P
0 g
s
.49904 .55611 m .49904 .61169 L .49615 .60315 L p .707 .577 .707 r
F P
0 g
s
.49615 .60315 m .49615 .54757 L .49904 .55611 L p .707 .577 .707 r
F P
0 g
s
.74688 .66475 m .74688 .7018 L .71504 .70258 L p .707 .577 .707 r
F P
0 g
s
.80551 .75984 m .80551 .77837 L .77805 .77398 L p .707 .577 .707 r
F P
0 g
s
.77805 .77398 m .77805 .75545 L .80551 .75984 L p .707 .577 .707 r
F P
0 g
s
.31064 .77723 m .31064 .7587 L .29804 .75081 L p .707 .577 .707 r
F P
0 g
s
.68566 .77623 m .68566 .75771 L .71504 .75433 L p .707 .577 .707 r
F P
0 g
s
.29804 .69907 m .29804 .66201 L .29515 .65347 L p .707 .577 .707 r
F P
0 g
s
.29804 .75081 m .29804 .76934 L .31064 .77723 L p .707 .577 .707 r
F P
0 g
s
.29515 .60806 m .29515 .55248 L .30223 .54411 L p .707 .577 .707 r
F P
0 g
s
.71504 .75433 m .71504 .77285 L .68566 .77623 L p .707 .577 .707 r
F P
0 g
s
.77805 .75545 m .77805 .77398 L .74688 .77208 L p .707 .577 .707 r
F P
0 g
s
.74688 .77208 m .74688 .75355 L .77805 .75545 L p .707 .577 .707 r
F P
0 g
s
.29515 .65347 m .29515 .69052 L .29804 .69907 L p .707 .577 .707 r
F P
0 g
s
.71504 .77285 m .71504 .75433 L .74688 .75355 L p .707 .577 .707 r
F P
0 g
s
.49196 .75427 m .49196 .7728 L .49904 .76444 L p .707 .577 .707 r
F P
0 g
s
.49904 .76444 m .49904 .74591 L .49196 .75427 L p .707 .577 .707 r
F P
0 g
s
.74688 .75355 m .74688 .77208 L .71504 .77285 L p .707 .577 .707 r
F P
0 g
s
.49904 .6571 m .49904 .69416 L .49615 .68562 L p .707 .577 .707 r
F P
0 g
s
.49615 .68562 m .49615 .64856 L .49904 .6571 L p .707 .577 .707 r
F P
0 g
s
.30223 .54411 m .30223 .59969 L .29515 .60806 L p .707 .577 .707 r
F P
0 g
s
.49615 .54757 m .49615 .60315 L .48356 .59527 L p .707 .577 .707 r
F P
0 g
s
.48356 .59527 m .48356 .53968 L .49615 .54757 L p .707 .577 .707 r
F P
0 g
s
.29804 .76934 m .29804 .75081 L .29515 .74227 L p .707 .577 .707 r
F P
0 g
s
.29515 .74227 m .29515 .7608 L .29804 .76934 L p .707 .577 .707 r
F P
0 g
s
.29515 .69052 m .29515 .65347 L .30223 .6451 L p .707 .577 .707 r
F P
0 g
s
.30223 .59969 m .30223 .54411 L .3186 .53674 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .6451 m .30223 .68216 L .29515 .69052 L p .707 .577 .707 r
F P
0 g
s
.49904 .74591 m .49904 .76444 L .49615 .75589 L p .707 .577 .707 r
F P
0 g
s
.49615 .75589 m .49615 .73737 L .49904 .74591 L p .707 .577 .707 r
F P
0 g
s
.3186 .53674 m .3186 .59233 L .30223 .59969 L p .707 .577 .707 r
F P
0 g
s
.49615 .64856 m .49615 .68562 L .48356 .67773 L p .707 .577 .707 r
F P
0 g
s
.48356 .67773 m .48356 .64068 L .49615 .64856 L p .707 .577 .707 r
F P
0 g
s
.48356 .53968 m .48356 .59527 L .4625 .58881 L p .707 .577 .707 r
F P
0 g
s
.4625 .58881 m .4625 .53323 L .48356 .53968 L p .707 .577 .707 r
F P
0 g
s
.29515 .7608 m .29515 .74227 L .30223 .73391 L p .707 .577 .707 r
F P
0 g
s
.3186 .59233 m .3186 .53674 L .34265 .53109 L p .707 .577 .707 r
F P
0 g
s
.30223 .73391 m .30223 .75244 L .29515 .7608 L p .707 .577 .707 r
F P
0 g
s
.30223 .68216 m .30223 .6451 L .3186 .63774 L p .707 .577 .707 r
F P
0 g
s
.3186 .63774 m .3186 .67479 L .30223 .68216 L p .707 .577 .707 r
F P
0 g
s
.4625 .53323 m .4625 .58881 L .43504 .58442 L p .707 .577 .707 r
F P
0 g
s
.43504 .58442 m .43504 .52884 L .4625 .53323 L p .707 .577 .707 r
F P
0 g
s
.49615 .73737 m .49615 .75589 L .48356 .74801 L p .707 .577 .707 r
F P
0 g
s
.48356 .74801 m .48356 .72948 L .49615 .73737 L p .707 .577 .707 r
F P
0 g
s
.34265 .53109 m .34265 .58668 L .3186 .59233 L p .707 .577 .707 r
F P
0 g
s
.48356 .64068 m .48356 .67773 L .4625 .67128 L p .707 .577 .707 r
F P
0 g
s
.4625 .67128 m .4625 .63422 L .48356 .64068 L p .707 .577 .707 r
F P
0 g
s
.34265 .58668 m .34265 .53109 L .37203 .52771 L p .707 .577 .707 r
F P
0 g
s
.30223 .75244 m .30223 .73391 L .3186 .72654 L p .707 .577 .707 r
F P
0 g
s
.3186 .67479 m .3186 .63774 L .34265 .63209 L p .707 .577 .707 r
F P
0 g
s
.43504 .52884 m .43504 .58442 L .40387 .58252 L p .707 .577 .707 r
F P
0 g
s
.40387 .58252 m .40387 .52694 L .43504 .52884 L p .707 .577 .707 r
F P
0 g
s
.3186 .72654 m .3186 .74507 L .30223 .75244 L p .707 .577 .707 r
F P
0 g
s
.37203 .5833 m .37203 .52771 L .40387 .52694 L p .707 .577 .707 r
F P
0 g
s
.37203 .52771 m .37203 .5833 L .34265 .58668 L p .707 .577 .707 r
F P
0 g
s
.40387 .52694 m .40387 .58252 L .37203 .5833 L p .707 .577 .707 r
F P
0 g
s
.34265 .63209 m .34265 .66914 L .3186 .67479 L p .707 .577 .707 r
F P
0 g
s
.4625 .63422 m .4625 .67128 L .43504 .66689 L p .707 .577 .707 r
F P
0 g
s
.43504 .66689 m .43504 .62983 L .4625 .63422 L p .707 .577 .707 r
F P
0 g
s
.48356 .72948 m .48356 .74801 L .4625 .74155 L p .707 .577 .707 r
F P
0 g
s
.4625 .74155 m .4625 .72303 L .48356 .72948 L p .707 .577 .707 r
F P
0 g
s
.34265 .66914 m .34265 .63209 L .37203 .62871 L p .707 .577 .707 r
F P
0 g
s
.3186 .74507 m .3186 .72654 L .34265 .72089 L p .707 .577 .707 r
F P
0 g
s
.43504 .62983 m .43504 .66689 L .40387 .66499 L p .707 .577 .707 r
F P
0 g
s
.40387 .66499 m .40387 .62793 L .43504 .62983 L p .707 .577 .707 r
F P
0 g
s
.34265 .72089 m .34265 .73942 L .3186 .74507 L p .707 .577 .707 r
F P
0 g
s
.37203 .62871 m .37203 .66576 L .34265 .66914 L p .707 .577 .707 r
F P
0 g
s
.37203 .66576 m .37203 .62871 L .40387 .62793 L p .707 .577 .707 r
F P
0 g
s
.40387 .62793 m .40387 .66499 L .37203 .66576 L p .707 .577 .707 r
F P
0 g
s
.4625 .72303 m .4625 .74155 L .43504 .73716 L p .707 .577 .707 r
F P
0 g
s
.43504 .73716 m .43504 .71863 L .4625 .72303 L p .707 .577 .707 r
F P
0 g
s
.34265 .73942 m .34265 .72089 L .37203 .71751 L p .707 .577 .707 r
F P
0 g
s
.37203 .71751 m .37203 .73604 L .34265 .73942 L p .707 .577 .707 r
F P
0 g
s
.43504 .71863 m .43504 .73716 L .40387 .73526 L p .707 .577 .707 r
F P
0 g
s
.40387 .73526 m .40387 .71673 L .43504 .71863 L p .707 .577 .707 r
F P
0 g
s
.37203 .73604 m .37203 .71751 L .40387 .71673 L p .707 .577 .707 r
F P
0 g
s
.40387 .71673 m .40387 .73526 L .37203 .73604 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00PWoo5@00QWoo001lOol60002FUH00`00
FUIJEP09FUH00`00FUIJEP04FUH<001jOol007Ioo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00=JEPL007=oo`00LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0`001eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`002EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00
K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`T000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol20000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
3goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH01000<Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`80
0003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP80035oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH8
0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo
00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
15YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03
001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP<00003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
001COol01000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=o
o`06001JEP00001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP0000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003mooaP00003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEPD0
00AJEP04001JEUYFFUH2000]Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00IJEQ400003FUH005YF00IJEP03001JEUYF00=J
EP<000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP<00003FUH005YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF2P000eYF00<005YFFUH01UYF00<005YFFUH00UYF
200000=JEP00FUH010002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000UYF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF0`000eYF0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0009JEP80
02eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4000]Ool002eoo`8000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00<goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF1@001UYF6`0000=JEP0000000P00=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH01000FUIJEUYF20000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol002aoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03001JEP00
00=JEPD000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH4
00000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH90008FUH400000eYF001JEP020004FUH60002FUH01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH00UYF1`000eYF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol002aoo`03001JEP0000AJ
EP04001JEUYFFUH90007FUH00`00FUIJEP07FUH01000FUH005YF0P0000=JEP00FUH015YF00@005YF
FUIJEPP000AJEP@0009JEPT000=JEP03001JEUYF00AJEP03001JEUYF00800005FUH005YFFUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF0`00<7oo000/Ool00`00FUH00003FUH60007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000
FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001J
EP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool01P00FUH0
0000FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP00
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
02aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04
001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00UYF200047oo20000eYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04
001JEUYFFUH2000HOol50004FUH01000FUIJEUYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000040006FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH60002FUH01000
FUIJEUYF0P006Woo1P0000=JEP00FUH00UYF0P00;Goo000`Ool30004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05
FUH900000eYF001JEP03FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`000UYF0P0027oo
0`002Woo1@001EYF0`000eYF0P00;Goo000cOol300000eYF001JEP06FUHA00000eYF001JEP06FUH0
0`00FUIJEP03FUH?0004FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP03
FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool003Ioo`T000=JEP03001J
EUYF00IJEP03001JEUYF009JEPP00003FUH005YF00D00003FUH005YF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool003Eoo`@00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH40005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
000]Ool0039oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI
0004FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJ
EP04001JEUYFFUH80002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF00@0
05YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009J
EP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF
0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YF001JEP8000=JEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P000eYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@0
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5
000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEP000005FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH50004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002FUH00`00FUIJEP04FUHN000nOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF009JEQH0009JEP<0009JEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000`000eYF2@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00>Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH6
000DOol20003FUH00`00FUH000020005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1000=Woo000/Ool00`00FUH00004FUH00`00
FUH00003000JOol20003FUH00`00FUIJEP02FUH60002FUH01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH01eYF100000=JEP00FUH00UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000<Woo000/Ool00`00FUH0
0003FUH300000eYF00000003000IOol01@00FUIJEUYF00001EYF00@005YFFUIJEPP000AJEP03001J
EUYF00MJEP03001JEUYF009JEPD000EJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00<Goo
000/Ool01000FUH005YF0P001EYF00@005YFFUIJEPP000Eoo`<000Yoo`04001JEUYF0005FUH00`00
FUIJEP05FUH01000FUIJEUYF4`000eYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo
000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP04001JEUYFFUHF0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH015YF0`000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00<005YF00000P000UYF00D005YFFUIJEP0001Uoo`D000AJEP05001JEUYFFUH0000^Ool0
02aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEP0000@000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP<000EJEP05001JEUYFFUH0000NOol300000eYF001JEP02FUH2000]Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD0009JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P0087oo0P000eYF0P00;Goo000]Ool0
1@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEQT000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP03FUH01000
FUIJEUYF0P008Woo0P0000=JEP000000;Goo000^Ool01000FUIJEP001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00=JEP04001JEUYFFUH2000ROol5000]Ool002moo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001oo`000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH00eYF00@005YF
FUIJEP80021oo`80009JEP<002eoo`00<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF0`000Woo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP0000<000AJEP04001JEUYFFUH2000LOol40004FUH0
0`00FUH0000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP04001JEUYFFUH40004Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00<005YFFUH00UYF1P000eYF0P005Goo1`000eYF00<005YFFUH00UYF0P00;Woo000fOol5
0004FUH00`00FUIJEP05FUH900000eYF001JEP03FUH70008Ool01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJ
EP03001JEUYF009JEP8002ioo`00>goo300015YF00<005YFFUH00UYF20003Goo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Mo
o`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60007Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol0039oo`D0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
008000Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40000
0eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1@00
<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000UYF00@005YFFUIJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPL003Qoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF0000200015YF
00<005YFFUH00UYF2@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF0P0017oo2@00B7oo000]Ool20004FUH0
0`00FUIJEP03FUH6000GOol40002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJEP80
05Ioo`00;7oo00<005YF000015YF00<005YF00000`008Goo1@000eYF00@005YFFUH0009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEP00001H
Ool002aoo`03001JEP0000=JEP<002Yoo`@0009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH=000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP03FUH3001JOol002aoo`04001JEP00FUH2000aOol00`00FUH00002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH9000<FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH00`00FUH00003001MOol002aoo`04001JEP00000dOol20002
FUH00`00FUIJEP03FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH00004001QOol002aoo`80009JEP<0
02moo`@0009JEP03001JEUYF00=JEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000@0065o
o`00;7oo0P000eYF00<005YF00000P00:Goo0`000UYF0P000UYF00@005YFFUIJEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<00003
FUH0000000=JEP03001JEP0000AJEP<005ioo`00;7oo0P000eYF00<005YFFUH00UYF1@0087oo1000
00=JEP00FUH00UYF0P000UYF00@005YF000000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00005FUH00`00
FUH00002001KOol002eoo`05001JEUYFFUH00005FUH01000FUIJEUYF20004goo1@001EYF00@005YF
FUIJEP80009JEP800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00005FUH00`00FUIJ
EP02FUH2001IOol002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<0
05YFFUH015YF00@005YFFUIJEP800003FUH005YF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<0
0003FUH005YF00AJEP03001JEUYF00=JEP<005Moo`00;goo0`001EYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUH007oo008000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800004FUH000000003FUH00`00FUIJEP03FUH00`00FUIJ
EP02001EOol0035oo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP<0009oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EP000002Ool50004FUH01@00FUIJEUYF0000EGoo000dOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUIJEUYF100017oo0P0015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YF000000Moo`<00003FUH005YF009JEP8005Aoo`00>Goo10000UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH00UYF1`0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF
00@005YFFUH000Yoo`8000=JEP8005Aoo`00?Goo6@0047oo00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH015YF00<005YF00003Goo0P0000=JEP000000E7oo001VOol00`00FUIJEP02FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH2000?Ool4001DOol006Moo`80009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00=JEP8000ioo`800004FUH00000001DOol006Uoo`<000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2000;Ool50003
FUH00`00FUH0001DOol006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000006Ool70003FUH00`00FUIJEP02FUH2001E
Ool006eoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP/000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00Kgoo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00LWoo100025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000100025YF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000005Qoo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH00eYF1`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo001l
OolR0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol0
09aoo`T000AJEP03001JEUYF00IJEP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]6\[InvisibleSpace]"     "\
\[InvisibleSpace]2.839469025058277`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 6, "     ", 2.839469025058277, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60298 .73754 m .59932 .68523 L .56817 .68413 L p .707 .577 .707 r
F P
0 g
s
.59932 .68523 m .60298 .73754 L .60492 .73735 L p .707 .577 .707 r
F P
0 g
s
.56817 .68413 m .57183 .73644 L .57339 .7365 L p .707 .577 .707 r
F P
0 g
s
.57339 .7365 m .60298 .73754 L p .58768 .71407 L .707 .577 .707 r
F P
0 g
s
.58768 .71407 m .56817 .68413 L .57339 .7365 L .707 .577 .707 r
F
.57183 .73644 m .56817 .68413 L .54069 .67893 L p F P
0 g
s
.54069 .67893 m .54435 .73124 L .54581 .73152 L p .707 .577 .707 r
F P
0 g
s
.54581 .73152 m .57183 .73644 L p .55729 .7096 L .707 .577 .707 r
F P
0 g
s
.55729 .7096 m .54069 .67893 L .54581 .73152 L .707 .577 .707 r
F
.54435 .73124 m .54069 .67893 L .51955 .67015 L p F P
0 g
s
.51955 .67015 m .52321 .72246 L .52453 .723 L p .707 .577 .707 r
F P
0 g
s
.52453 .723 m .54435 .73124 L p .53148 .69953 L .707 .577 .707 r
F P
0 g
s
.53148 .69953 m .51955 .67015 L .52453 .723 L .707 .577 .707 r
F
.52321 .72246 m .51955 .67015 L .50684 .65863 L p F P
0 g
s
.50684 .65863 m .5105 .71094 L .52321 .72246 L p .707 .577 .707 r
F P
0 g
s
.52364 .71325 m .51105 .706 L p .51993 .73852 L .707 .577 .707 r
F P
0 g
s
.52323 .75057 m .52349 .72649 L p .51993 .73852 L .707 .577 .707 r
F P
0 g
s
.52349 .72649 m .52364 .71325 L p .51993 .73852 L .707 .577 .707 r
F P
0 g
s
.5447 .71929 m .52364 .71325 L p .53875 .74499 L .707 .577 .707 r
F P
0 g
s
.54428 .75661 m .54454 .73395 L p .53875 .74499 L .707 .577 .707 r
F P
0 g
s
.54454 .73395 m .5447 .71929 L p .53875 .74499 L .707 .577 .707 r
F P
0 g
s
.57216 .72355 m .5447 .71929 L p .56473 .75008 L .707 .577 .707 r
F P
0 g
s
.57174 .76086 m .57199 .73869 L p .56473 .75008 L .707 .577 .707 r
F P
0 g
s
.57199 .73869 m .57216 .72355 L p .56473 .75008 L .707 .577 .707 r
F P
0 g
s
.60333 .72559 m .57216 .72355 L p .59532 .75319 L .707 .577 .707 r
F P
0 g
s
.60291 .7629 m .60317 .74025 L p .59532 .75319 L .707 .577 .707 r
F P
0 g
s
.60317 .74025 m .60333 .72559 L p .59532 .75319 L .707 .577 .707 r
F P
0 g
s
.60492 .73735 m .63473 .73443 L p .61952 .71329 L .707 .577 .707 r
F P
0 g
s
.61952 .71329 m .59932 .68523 L .60492 .73735 L .707 .577 .707 r
F
.63473 .73443 m .63107 .68212 L .59932 .68523 L p F P
0 g
s
.63107 .68212 m .63473 .73443 L .63717 .73384 L p .707 .577 .707 r
F P
0 g
s
.63516 .72522 m .60333 .72559 L p .62766 .7542 L .707 .577 .707 r
F P
0 g
s
.63475 .76253 m .63502 .73846 L p .62766 .7542 L .707 .577 .707 r
F P
0 g
s
.63502 .73846 m .63516 .72522 L p .62766 .7542 L .707 .577 .707 r
F P
0 g
s
.63717 .73384 m .66399 .72741 L p .6495 .70747 L .707 .577 .707 r
F P
0 g
s
.6495 .70747 m .63107 .68212 L .63717 .73384 L .707 .577 .707 r
F
.66399 .72741 m .66033 .6751 L .63107 .68212 L p F P
0 g
s
.66033 .6751 m .66399 .72741 L .66638 .72639 L p .707 .577 .707 r
F P
0 g
s
.66454 .72247 m .63516 .72522 L p .65889 .75354 L .707 .577 .707 r
F P
0 g
s
.66413 .75979 m .66442 .73351 L p .65889 .75354 L .707 .577 .707 r
F P
0 g
s
.66442 .73351 m .66454 .72247 L p .65889 .75354 L .707 .577 .707 r
F P
0 g
s
.66638 .72639 m .68789 .71718 L p .67455 .6968 L .707 .577 .707 r
F P
0 g
s
.67455 .6968 m .66033 .6751 L .66638 .72639 L .707 .577 .707 r
F
.68789 .71718 m .68423 .66487 L .66033 .6751 L p F P
0 g
s
.60333 .72559 m .60291 .7629 L .63475 .76253 L p .707 .577 .707 r
F P
0 g
s
.63516 .72522 m .63475 .76253 L .66413 .75979 L p .707 .577 .707 r
F P
0 g
s
.57216 .72355 m .57174 .76086 L .60291 .7629 L p .707 .577 .707 r
F P
0 g
s
.57096 .7622 m .56865 .78128 L .59973 .78481 L p .707 .577 .707 r
F P
0 g
s
.59973 .78481 m .60204 .76572 L .57096 .7622 L p .707 .577 .707 r
F P
0 g
s
.60204 .76572 m .59973 .78481 L .63127 .78874 L p .707 .577 .707 r
F P
0 g
s
.63127 .78874 m .63358 .76966 L .60204 .76572 L p .707 .577 .707 r
F P
0 g
s
.68423 .66487 m .68789 .71718 L .70409 .70473 L p .707 .577 .707 r
F P
0 g
s
.70409 .70473 m .70043 .65242 L .68423 .66487 L p .707 .577 .707 r
F P
0 g
s
.63358 .76966 m .63127 .78874 L .6602 .7927 L p .707 .577 .707 r
F P
0 g
s
.6602 .7927 m .66251 .77362 L .63358 .76966 L p .707 .577 .707 r
F P
0 g
s
.5434 .75943 m .5411 .77851 L .56865 .78128 L p .707 .577 .707 r
F P
0 g
s
.56865 .78128 m .57096 .7622 L .5434 .75943 L p .707 .577 .707 r
F P
0 g
s
.66454 .72247 m .66413 .75979 L .68818 .75494 L p .707 .577 .707 r
F P
0 g
s
.68818 .75494 m .68859 .71762 L .66454 .72247 L p .707 .577 .707 r
F P
0 g
s
.5447 .71929 m .54428 .75661 L .57174 .76086 L p .707 .577 .707 r
F P
0 g
s
.66251 .77362 m .6602 .7927 L .68369 .7963 L p .707 .577 .707 r
F P
0 g
s
.68369 .7963 m .686 .77722 L .66251 .77362 L p .707 .577 .707 r
F P
0 g
s
.52206 .75769 m .51975 .77677 L .5411 .77851 L p .707 .577 .707 r
F P
0 g
s
.5411 .77851 m .5434 .75943 L .52206 .75769 L p .707 .577 .707 r
F P
0 g
s
.52364 .71325 m .52323 .75057 L .54428 .75661 L p .707 .577 .707 r
F P
0 g
s
.70043 .65242 m .70409 .70473 L .711 .69129 L p .707 .577 .707 r
F P
0 g
s
.711 .69129 m .70734 .63898 L .70043 .65242 L p .707 .577 .707 r
F P
0 g
s
.68859 .71762 m .68818 .75494 L .70454 .74846 L p .707 .577 .707 r
F P
0 g
s
.70454 .74846 m .70495 .71114 L .68859 .71762 L p .707 .577 .707 r
F P
0 g
s
.686 .77722 m .68369 .7963 L .69943 .79919 L p .707 .577 .707 r
F P
0 g
s
.69943 .79919 m .70174 .78011 L .686 .77722 L p .707 .577 .707 r
F P
0 g
s
.5105 .71094 m .50684 .65863 L .50378 .6455 L p .707 .577 .707 r
F P
0 g
s
.50902 .75715 m .50671 .77623 L .51975 .77677 L p .707 .577 .707 r
F P
0 g
s
.51975 .77677 m .52206 .75769 L .50902 .75715 L p .707 .577 .707 r
F P
0 g
s
.48715 .82762 m .48177 .32953 L .43777 .32704 L p .707 .577 .707 r
F P
0 g
s
.51105 .706 m .51063 .74332 L .52323 .75057 L p .707 .577 .707 r
F P
0 g
s
.50378 .6455 m .50744 .69781 L .5105 .71094 L p .707 .577 .707 r
F P
0 g
s
.51063 .74332 m .51105 .706 L .50814 .69826 L p .707 .577 .707 r
F P
0 g
s
.50744 .69781 m .50378 .6455 L .5107 .63206 L p .707 .577 .707 r
F P
0 g
s
.50555 .75786 m .50324 .77694 L .50671 .77623 L p .707 .577 .707 r
F P
0 g
s
.50671 .77623 m .50902 .75715 L .50555 .75786 L p .707 .577 .707 r
F P
0 g
s
.50814 .69826 m .50773 .73557 L .51063 .74332 L p .707 .577 .707 r
F P
0 g
s
.5107 .63206 m .51436 .68437 L .50744 .69781 L p .707 .577 .707 r
F P
0 g
s
.50773 .73557 m .50814 .69826 L .51522 .69078 L p .707 .577 .707 r
F P
0 g
s
.51436 .68437 m .5107 .63206 L .52689 .61961 L p .707 .577 .707 r
F P
0 g
s
.51201 .75975 m .5097 .77883 L .50324 .77694 L p .707 .577 .707 r
F P
0 g
s
.50324 .77694 m .50555 .75786 L .51201 .75975 L p .707 .577 .707 r
F P
0 g
s
.51522 .69078 m .51481 .7281 L .50773 .73557 L p .707 .577 .707 r
F P
0 g
s
.52689 .61961 m .53055 .67192 L .51436 .68437 L p .707 .577 .707 r
F P
0 g
s
.51481 .7281 m .51522 .69078 L .53159 .6843 L p .707 .577 .707 r
F P
0 g
s
.53159 .6843 m .53117 .72162 L .51481 .7281 L p .707 .577 .707 r
F P
0 g
s
.52775 .76263 m .52544 .78171 L .5097 .77883 L p .707 .577 .707 r
F P
0 g
s
.5097 .77883 m .51201 .75975 L .52775 .76263 L p .707 .577 .707 r
F P
0 g
s
.54892 .78531 m .52544 .78171 L p .54998 .76698 L .707 .577 .707 r
F P
0 g
s
.55123 .76623 m .5508 .76981 L p .54998 .76698 L .707 .577 .707 r
F P
0 g
s
.5508 .76981 m .54892 .78531 L p .54998 .76698 L .707 .577 .707 r
F P
0 g
s
.52544 .78171 m .52775 .76263 L .54969 .766 L p .707 .577 .707 r
F P
0 g
s
.54969 .766 m .55123 .76623 L p .54998 .76698 L .707 .577 .707 r
F P
0 g
s
.52544 .78171 m .54969 .766 L .54998 .76698 L .707 .577 .707 r
F
.52672 .32789 m .48177 .32953 L p .51321 .63962 L F P
0 g
s
.53209 .82597 m .53074 .70034 L p .51321 .63962 L .707 .577 .707 r
F P
0 g
s
.53055 .67192 m .52689 .61961 L .55079 .60938 L p .707 .577 .707 r
F P
0 g
s
.53074 .70034 m .52672 .32789 L p .51321 .63962 L .707 .577 .707 r
F P
0 g
s
.48715 .82762 m .53209 .82597 L p .51321 .63962 L .707 .577 .707 r
F P
0 g
s
.48177 .32953 m .48403 .53858 L p .51321 .63962 L .707 .577 .707 r
F P
0 g
s
.48403 .53858 m .48715 .82762 L p .51321 .63962 L .707 .577 .707 r
F P
0 g
s
.61171 .77413 m .6094 .79321 L .58383 .79002 L p .707 .577 .707 r
F P
0 g
s
.58383 .79002 m .57785 .78928 L p .58453 .78629 L .707 .577 .707 r
F P
0 g
s
.58453 .78629 m .61171 .77413 L .58383 .79002 L .707 .577 .707 r
F
.64295 .60035 m .64661 .65266 L .61546 .65156 L p F P
0 g
s
.61546 .65156 m .6118 .59925 L .64295 .60035 L p .707 .577 .707 r
F P
0 g
s
.64802 .67838 m .6476 .71569 L .61643 .71365 L p .707 .577 .707 r
F P
0 g
s
.61643 .71365 m .61685 .67633 L .64802 .67838 L p .707 .577 .707 r
F P
0 g
s
.5846 .71402 m .58501 .6767 L .61685 .67633 L p .707 .577 .707 r
F P
0 g
s
.61685 .67633 m .61643 .71365 L .5846 .71402 L p .707 .577 .707 r
F P
0 g
s
.64278 .77765 m .64047 .79674 L .61281 .7936 L p .707 .577 .707 r
F P
0 g
s
.61281 .7936 m .6094 .79321 L p .61295 .79156 L .707 .577 .707 r
F P
0 g
s
.61295 .79156 m .64278 .77765 L .61281 .7936 L .707 .577 .707 r
F
.6094 .79321 m .61171 .77413 L .6141 .7744 L p F P
0 g
s
.6141 .7744 m .64278 .77765 L p .61295 .79156 L .707 .577 .707 r
F P
0 g
s
.6094 .79321 m .6141 .7744 L .61295 .79156 L .707 .577 .707 r
F
.63524 .28863 m .62525 .30162 L p .63183 .50951 L F P
0 g
s
.64062 .78671 m .63682 .43503 L p .63183 .50951 L .707 .577 .707 r
F P
0 g
s
.63682 .43503 m .63524 .28863 L p .63183 .50951 L .707 .577 .707 r
F P
0 g
s
.63062 .79971 m .64062 .78671 L p .63183 .50951 L .707 .577 .707 r
F P
0 g
s
.62525 .30162 m .62809 .56536 L p .63183 .50951 L .707 .577 .707 r
F P
0 g
s
.62809 .56536 m .63062 .79971 L p .63183 .50951 L .707 .577 .707 r
F P
0 g
s
.57785 .78928 m .58016 .77019 L .61171 .77413 L p .707 .577 .707 r
F P
0 g
s
.60752 .8113 m .63062 .79971 L p .61914 .60358 L .707 .577 .707 r
F P
0 g
s
.58371 .65467 m .58005 .60236 L .6118 .59925 L p .707 .577 .707 r
F P
0 g
s
.6118 .59925 m .61546 .65156 L .58371 .65467 L p .707 .577 .707 r
F P
0 g
s
.60214 .31322 m .60603 .67282 L p .61914 .60358 L .707 .577 .707 r
F P
0 g
s
.60603 .67282 m .60752 .8113 L p .61914 .60358 L .707 .577 .707 r
F P
0 g
s
.57357 .82035 m .60752 .8113 L p .60099 .73004 L .707 .577 .707 r
F P
0 g
s
.5644 .60611 m .58005 .60236 L p .5701 .62542 L .707 .577 .707 r
F P
0 g
s
.58416 .67678 m .58501 .6767 L p .58405 .678 L .707 .577 .707 r
F P
0 g
s
.57152 .63021 m .57276 .74571 L p .58441 .6739 L .707 .577 .707 r
F P
0 g
s
.58016 .77019 m .57785 .78928 L .54913 .78534 L p .707 .577 .707 r
F P
0 g
s
.54923 .78516 m .58016 .77019 L .54913 .78534 L .707 .577 .707 r
F
.54892 .78531 m .55123 .76623 L .55982 .76741 L p F P
0 g
s
.55982 .76741 m .58016 .77019 L p .54923 .78516 L .707 .577 .707 r
F P
0 g
s
.54892 .78531 m .55982 .76741 L .54923 .78516 L .707 .577 .707 r
F
.60099 .73004 m .59474 .70887 L .57357 .82035 L F
.58501 .6767 m .5846 .71402 L .5808 .71438 L p F P
0 g
s
.58441 .6739 m .57276 .74571 L .57892 .73539 L .707 .577 .707 r
F
.54913 .78534 m .54892 .78531 L p .54923 .78516 L F P
0 g
s
.57357 .82035 m .55576 .63319 L .54615 .71148 L .707 .577 .707 r
F
.55637 .82268 m .57357 .82035 L p .54615 .71148 L F P
0 g
s
.55564 .67945 m .55522 .71677 L .54679 .71847 L p .707 .577 .707 r
F P
0 g
s
.54679 .71847 m .53117 .72162 L p .54491 .69794 L .707 .577 .707 r
F P
0 g
s
.55576 .63319 m .5525 .6338 L .54615 .71148 L .707 .577 .707 r
F
.55079 .60938 m .5525 .6338 L p .53055 .67192 L F P
0 g
s
.54675 .66499 m .53055 .67192 L p .5525 .6338 L .707 .577 .707 r
F P
0 g
s
.5525 .6338 m .53924 .6363 L .5435 .6826 L .707 .577 .707 r
F
.5525 .6338 m .5435 .6826 L .54615 .71148 L F
.5525 .6338 m .55445 .66169 L .54675 .66499 L p F P
0 g
s
.54491 .69794 m .55564 .67945 L .54679 .71847 L .707 .577 .707 r
F
.53117 .72162 m .53159 .6843 L .54343 .68191 L p F P
0 g
s
.53117 .72162 m .54343 .68191 L .54491 .69794 L .707 .577 .707 r
F
.53006 .63803 m .53209 .82597 L p .54615 .71148 L F P
0 g
s
.53924 .6363 m .53006 .63803 L .54615 .71148 L .707 .577 .707 r
F
.53209 .82597 m .55637 .82268 L p .54615 .71148 L F P
0 g
s
.54343 .68191 m .55564 .67945 L p .54491 .69794 L .707 .577 .707 r
F P
0 g
s
.57357 .82035 m .57152 .63021 L p .55576 .63319 L .707 .577 .707 r
F P
0 g
s
.58371 .65467 m .55445 .66169 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.58005 .60236 m .58186 .62826 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.58186 .62826 m .58371 .65467 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.55079 .60938 m .5644 .60611 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.5525 .6338 m .55079 .60938 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.56819 .32226 m .52672 .32789 L p .55576 .63319 L .707 .577 .707 r
F P
0 g
s
.56772 .63093 m .5644 .60611 L .5701 .62542 L .707 .577 .707 r
F
.57152 .63021 m .56819 .32226 L p .55576 .63319 L F P
0 g
s
.5808 .71438 m .55522 .71677 L p .58405 .678 L .707 .577 .707 r
F P
0 g
s
.58405 .678 m .58501 .6767 L .5808 .71438 L .707 .577 .707 r
F
.59474 .70887 m .58441 .6739 L .57999 .73358 L F
.59474 .70887 m .57999 .73358 L .57357 .82035 L F
.57276 .74571 m .57333 .79791 L p .57892 .73539 L F P
0 g
s
.57333 .79791 m .57357 .82035 L p .58441 .6739 L .707 .577 .707 r
F P
0 g
s
.55522 .71677 m .55564 .67945 L .58416 .67678 L p .707 .577 .707 r
F P
0 g
s
.55522 .71677 m .58416 .67678 L .58405 .678 L .707 .577 .707 r
F
.56819 .32226 m .57152 .63021 L p .60099 .73004 L F P
0 g
s
.55445 .66169 m .5525 .6338 L p .56772 .63093 L .707 .577 .707 r
F P
0 g
s
.52672 .32789 m .53006 .63803 L p .55576 .63319 L .707 .577 .707 r
F P
0 g
s
.70495 .71114 m .70454 .74846 L .71162 .74098 L p .707 .577 .707 r
F P
0 g
s
.71162 .74098 m .71203 .70367 L .70495 .71114 L p .707 .577 .707 r
F P
0 g
s
.70734 .63898 m .711 .69129 L .70795 .67816 L p .707 .577 .707 r
F P
0 g
s
.70795 .67816 m .70429 .62585 L .70734 .63898 L p .707 .577 .707 r
F P
0 g
s
.44315 .82512 m .43777 .32704 L .399 .32065 L p .707 .577 .707 r
F P
0 g
s
.43777 .32704 m .44315 .82512 L .48715 .82762 L p .707 .577 .707 r
F P
0 g
s
.70174 .78011 m .69943 .79919 L .70588 .80108 L p .707 .577 .707 r
F P
0 g
s
.70588 .80108 m .70819 .782 L .70174 .78011 L p .707 .577 .707 r
F P
0 g
s
.60752 .8113 m .60214 .31322 L .56819 .32226 L p .707 .577 .707 r
F P
0 g
s
.40438 .81873 m .399 .32065 L .36927 .31099 L p .707 .577 .707 r
F P
0 g
s
.399 .32065 m .40438 .81873 L .44315 .82512 L p .707 .577 .707 r
F P
0 g
s
.70429 .62585 m .70795 .67816 L .69523 .66664 L p .707 .577 .707 r
F P
0 g
s
.69523 .66664 m .69157 .61433 L .70429 .62585 L p .707 .577 .707 r
F P
0 g
s
.71203 .70367 m .71162 .74098 L .70872 .73324 L p .707 .577 .707 r
F P
0 g
s
.70872 .73324 m .70913 .69592 L .71203 .70367 L p .707 .577 .707 r
F P
0 g
s
.63062 .79971 m .62525 .30162 L .60214 .31322 L p .707 .577 .707 r
F P
0 g
s
.70819 .782 m .70588 .80108 L .70242 .80179 L p .707 .577 .707 r
F P
0 g
s
.70242 .80179 m .70473 .78271 L .70819 .782 L p .707 .577 .707 r
F P
0 g
s
.25997 .70072 m .25631 .64841 L .22516 .64732 L p .707 .577 .707 r
F P
0 g
s
.25631 .64841 m .25997 .70072 L .26192 .70053 L p .707 .577 .707 r
F P
0 g
s
.22516 .64732 m .22882 .69963 L .23038 .69968 L p .707 .577 .707 r
F P
0 g
s
.23038 .69968 m .25997 .70072 L p .24467 .67725 L .707 .577 .707 r
F P
0 g
s
.24467 .67725 m .22516 .64732 L .23038 .69968 L .707 .577 .707 r
F
.22882 .69963 m .22516 .64732 L .19768 .64212 L p F P
0 g
s
.19768 .64212 m .20134 .69443 L .2028 .69471 L p .707 .577 .707 r
F P
0 g
s
.2028 .69471 m .22882 .69963 L p .21428 .67278 L .707 .577 .707 r
F P
0 g
s
.21428 .67278 m .19768 .64212 L .2028 .69471 L .707 .577 .707 r
F
.20134 .69443 m .19768 .64212 L .17654 .63333 L p F P
0 g
s
.17654 .63333 m .1802 .68564 L .18152 .68619 L p .707 .577 .707 r
F P
0 g
s
.18152 .68619 m .20134 .69443 L p .18847 .66271 L .707 .577 .707 r
F P
0 g
s
.18847 .66271 m .17654 .63333 L .18152 .68619 L .707 .577 .707 r
F
.1802 .68564 m .17654 .63333 L .16383 .62181 L p F P
0 g
s
.16383 .62181 m .16749 .67412 L .1802 .68564 L p .707 .577 .707 r
F P
0 g
s
.18063 .67643 m .16804 .66918 L p .17692 .7017 L .707 .577 .707 r
F P
0 g
s
.18022 .71375 m .18049 .68967 L p .17692 .7017 L .707 .577 .707 r
F P
0 g
s
.18049 .68967 m .18063 .67643 L p .17692 .7017 L .707 .577 .707 r
F P
0 g
s
.20169 .68248 m .18063 .67643 L p .19575 .70818 L .707 .577 .707 r
F P
0 g
s
.20128 .7198 m .20153 .69714 L p .19575 .70818 L .707 .577 .707 r
F P
0 g
s
.20153 .69714 m .20169 .68248 L p .19575 .70818 L .707 .577 .707 r
F P
0 g
s
.22915 .68673 m .20169 .68248 L p .22172 .71327 L .707 .577 .707 r
F P
0 g
s
.22873 .72405 m .22898 .70188 L p .22172 .71327 L .707 .577 .707 r
F P
0 g
s
.22898 .70188 m .22915 .68673 L p .22172 .71327 L .707 .577 .707 r
F P
0 g
s
.26032 .68877 m .22915 .68673 L p .25231 .71637 L .707 .577 .707 r
F P
0 g
s
.25991 .72609 m .26016 .70343 L p .25231 .71637 L .707 .577 .707 r
F P
0 g
s
.26016 .70343 m .26032 .68877 L p .25231 .71637 L .707 .577 .707 r
F P
0 g
s
.26192 .70053 m .29172 .69761 L p .27651 .67647 L .707 .577 .707 r
F P
0 g
s
.27651 .67647 m .25631 .64841 L .26192 .70053 L .707 .577 .707 r
F
.29172 .69761 m .28806 .6453 L .25631 .64841 L p F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28806 .6453 m .29172 .69761 L .29416 .69703 L p .707 .577 .707 r
F P
0 g
s
.29215 .6884 m .26032 .68877 L p .28465 .71738 L .707 .577 .707 r
F P
0 g
s
.29174 .72572 m .29201 .70164 L p .28465 .71738 L .707 .577 .707 r
F P
0 g
s
.29201 .70164 m .29215 .6884 L p .28465 .71738 L .707 .577 .707 r
F P
0 g
s
.29416 .69703 m .32098 .69059 L p .30649 .67065 L .707 .577 .707 r
F P
0 g
s
.30649 .67065 m .28806 .6453 L .29416 .69703 L .707 .577 .707 r
F
.32098 .69059 m .31732 .63828 L .28806 .6453 L p F P
0 g
s
.69157 .61433 m .69523 .66664 L .6741 .65785 L p .707 .577 .707 r
F P
0 g
s
.6741 .65785 m .67044 .60554 L .69157 .61433 L p .707 .577 .707 r
F P
0 g
s
.35742 .61561 m .36108 .66792 L .36799 .65447 L p .707 .577 .707 r
F P
0 g
s
.36799 .65447 m .36433 .60216 L .35742 .61561 L p .707 .577 .707 r
F P
0 g
s
.36861 .70417 m .36902 .66685 L .36195 .67433 L p .707 .577 .707 r
F P
0 g
s
.36433 .60216 m .36799 .65447 L .36592 .64558 L p .707 .577 .707 r
F P
0 g
s
.36481 .63348 m .36433 .60216 L .36592 .64558 L .707 .577 .707 r
F
.34122 .62805 m .34488 .68036 L .36108 .66792 L p F P
0 g
s
.36108 .66792 m .35742 .61561 L .34122 .62805 L p .707 .577 .707 r
F P
0 g
s
.34558 .68081 m .34517 .71813 L .36153 .71165 L p .707 .577 .707 r
F P
0 g
s
.36153 .71165 m .36195 .67433 L .34558 .68081 L p .707 .577 .707 r
F P
0 g
s
.35642 .76238 m .35873 .74329 L .34299 .74041 L p .707 .577 .707 r
F P
0 g
s
.36195 .67433 m .36153 .71165 L .36861 .70417 L p .707 .577 .707 r
F P
0 g
s
.35873 .74329 m .35642 .76238 L .36287 .76427 L p .707 .577 .707 r
F P
0 g
s
.36287 .76427 m .36518 .74518 L .35873 .74329 L p .707 .577 .707 r
F P
0 g
s
.36902 .66685 m .36861 .70417 L .36672 .69914 L p .707 .577 .707 r
F P
0 g
s
.36518 .74518 m .36287 .76427 L .35941 .76497 L p .707 .577 .707 r
F P
0 g
s
.35941 .76497 m .36172 .74589 L .36518 .74518 L p .707 .577 .707 r
F P
0 g
s
.36172 .74589 m .35941 .76497 L .35932 .76497 L p .707 .577 .707 r
F P
0 g
s
.34299 .74041 m .34068 .75949 L .35642 .76238 L p .707 .577 .707 r
F P
0 g
s
.35932 .76497 m .34637 .76443 L p .35818 .75016 L .707 .577 .707 r
F P
0 g
s
.35818 .75016 m .36172 .74589 L .35932 .76497 L .707 .577 .707 r
F
.3553 .71249 m .35447 .6219 L .354 .64203 L F
.35424 .63166 m .35222 .62983 L p .35452 .61945 L F P
0 g
s
.35606 .72245 m .35482 .60696 L p .3553 .71249 L .707 .577 .707 r
F P
0 g
s
.34856 .57752 m .35536 .58368 L p .35383 .60617 L .707 .577 .707 r
F P
0 g
s
.35222 .62983 m .35037 .60342 L p .35383 .60617 L .707 .577 .707 r
F P
0 g
s
.35037 .60342 m .34856 .57752 L p .35383 .60617 L .707 .577 .707 r
F P
0 g
s
.36709 .68413 m .36902 .66685 L .36672 .69914 L .707 .577 .707 r
F
.34637 .76443 m .34867 .74535 L .35784 .74573 L p F P
0 g
s
.35784 .74573 m .36172 .74589 L p .35818 .75016 L .707 .577 .707 r
F P
0 g
s
.34637 .76443 m .35784 .74573 L .35818 .75016 L .707 .577 .707 r
F
.35277 .78396 m .35687 .79709 L p .3553 .71249 L F P
0 g
s
.35222 .62983 m .35536 .58368 L .35452 .61945 L .707 .577 .707 r
F
.34856 .57752 m .35222 .62983 L .34571 .62712 L p F P
0 g
s
.34571 .62712 m .33109 .62104 L p .34381 .58935 L .707 .577 .707 r
F P
0 g
s
.34381 .58935 m .34856 .57752 L .34571 .62712 L .707 .577 .707 r
F
.3474 .28587 m .34896 .43076 L p .3553 .71249 L F P
0 g
s
.35474 .69011 m .35311 .68918 L p .35464 .68564 L .707 .577 .707 r
F P
0 g
s
.3553 .71249 m .34896 .43076 L .35522 .71138 L .707 .577 .707 r
F
.35311 .68918 m .35353 .65186 L .35389 .65207 L p F P
0 g
s
.36692 .69086 m .36299 .61346 L .3576 .77526 L .707 .577 .707 r
F
.35886 .77605 m .3576 .77526 L .35687 .79709 L F
.36692 .69086 m .3576 .77526 L .35886 .77605 L F
.36758 .66372 m .36299 .61346 L .36692 .69086 L F
.35482 .60696 m .35687 .79709 L p .36299 .61346 L F P
0 g
s
.35482 .60696 m .35447 .6219 L .3553 .71249 L .707 .577 .707 r
F
.35389 .65207 m .36612 .65911 L p .35464 .68564 L F P
0 g
s
.35311 .68918 m .35389 .65207 L .35464 .68564 L .707 .577 .707 r
F
.35353 .65186 m .35311 .68918 L .34653 .68729 L p F P
0 g
s
.31732 .63828 m .32098 .69059 L .32337 .68957 L p .707 .577 .707 r
F P
0 g
s
.32337 .68957 m .34488 .68036 L p .33154 .65999 L .707 .577 .707 r
F P
0 g
s
.33154 .65999 m .31732 .63828 L .32337 .68957 L .707 .577 .707 r
F
.32153 .68566 m .29215 .6884 L p .31588 .71673 L F P
0 g
s
.32112 .72298 m .32141 .69669 L p .31588 .71673 L .707 .577 .707 r
F P
0 g
s
.32141 .69669 m .32153 .68566 L p .31588 .71673 L .707 .577 .707 r
F P
0 g
s
.34488 .68036 m .34122 .62805 L .31732 .63828 L p .707 .577 .707 r
F P
0 g
s
.34517 .71813 m .34558 .68081 L .32153 .68566 L p .707 .577 .707 r
F P
0 g
s
.34653 .68729 m .33205 .68313 L p .34662 .66191 L .707 .577 .707 r
F P
0 g
s
.34662 .66191 m .35353 .65186 L .34653 .68729 L .707 .577 .707 r
F
.35146 .66229 m .35277 .78396 L p .35526 .71354 L F P
0 g
s
.35522 .71138 m .35146 .66229 L .35526 .71354 L .707 .577 .707 r
F
.33205 .68313 m .33247 .64581 L .34667 .64989 L p F P
0 g
s
.34667 .64989 m .35353 .65186 L p .34662 .66191 L .707 .577 .707 r
F P
0 g
s
.33205 .68313 m .34667 .64989 L .34662 .66191 L .707 .577 .707 r
F
.35522 .71138 m .34909 .43652 L .3517 .66541 L F
.34909 .43652 m .34896 .43076 L .3517 .66541 L F
.34896 .43076 m .35146 .66229 L p .3517 .66541 L F P
0 g
s
.35255 .76357 m .34784 .32739 L p .3529 .77039 L .707 .577 .707 r
F P
0 g
s
.34784 .32739 m .3474 .28587 L p .34785 .32585 L .707 .577 .707 r
F P
0 g
s
.34784 .32739 m .34785 .32585 L .3529 .77039 L .707 .577 .707 r
F
.35536 .58368 m .36128 .58904 L p .35693 .60864 L F P
0 g
s
.35452 .61945 m .35482 .60696 L .35693 .60864 L .707 .577 .707 r
F
.35482 .60696 m .35536 .58368 L .35693 .60864 L F
.36128 .58904 m .36494 .64135 L .35424 .63166 L p F P
0 g
s
.35452 .61945 m .36128 .58904 L .35424 .63166 L .707 .577 .707 r
F
.36128 .58904 m .36433 .60216 L p .36481 .63348 L F P
0 g
s
.36299 .61346 m .36128 .58904 L p .36481 .63348 L .707 .577 .707 r
F P
0 g
s
.35149 .29901 m .3538 .51296 L p .36299 .61346 L .707 .577 .707 r
F P
0 g
s
.36759 .66304 m .36902 .66685 L p .36709 .68413 L .707 .577 .707 r
F P
0 g
s
.36852 .67401 m .36587 .61576 L .36299 .61346 L .707 .577 .707 r
F
.36587 .61576 m .35149 .29901 L .36299 .61346 L F
.3538 .51296 m .35482 .60696 L p .36299 .61346 L F P
0 g
s
.35482 .60696 m .35149 .29901 L p .35447 .6219 L .707 .577 .707 r
F P
0 g
s
.35149 .29901 m .3474 .28587 L p .354 .64203 L .707 .577 .707 r
F P
0 g
s
.35447 .6219 m .35149 .29901 L .354 .64203 L .707 .577 .707 r
F
.36927 .31099 m .35149 .29901 L p .36852 .67401 L F P
0 g
s
.3529 .77039 m .34785 .32585 L .35739 .27288 L .707 .577 .707 r
F
.3474 .28587 m .348 .28509 L p .34785 .32585 L F P
0 g
s
.348 .28509 m .35739 .27288 L p .34785 .32585 L .707 .577 .707 r
F P
0 g
s
.3553 .71249 m .35522 .71138 L .35526 .71354 L .707 .577 .707 r
F
.36612 .65911 m .36571 .69643 L .35474 .69011 L p F P
0 g
s
.35464 .68564 m .36612 .65911 L .35474 .69011 L .707 .577 .707 r
F
.35277 .78396 m .35255 .76357 L p .3529 .77039 L F P
0 g
s
.36571 .69643 m .36612 .65911 L .36759 .66304 L p .707 .577 .707 r
F P
0 g
s
.36571 .69643 m .36759 .66304 L .36709 .68413 L .707 .577 .707 r
F
.36852 .67401 m .36758 .66372 L .36692 .69086 L F
.35687 .79709 m .35606 .72245 L p .3553 .71249 L F P
0 g
s
.35687 .79709 m .36424 .80206 L p .36692 .69086 L .707 .577 .707 r
F P
0 g
s
.36672 .69914 m .36571 .69643 L p .36709 .68413 L .707 .577 .707 r
F P
0 g
s
.37465 .80907 m .36852 .67401 L .36692 .69086 L .707 .577 .707 r
F
.36424 .80206 m .37465 .80907 L p .36692 .69086 L F P
0 g
s
.36494 .64135 m .36299 .61346 L p .36481 .63348 L .707 .577 .707 r
F P
0 g
s
.36592 .64558 m .36494 .64135 L p .36481 .63348 L .707 .577 .707 r
F P
0 g
s
.37465 .80907 m .37382 .73202 L p .36852 .67401 L .707 .577 .707 r
F P
0 g
s
.37382 .73202 m .36927 .31099 L p .36852 .67401 L .707 .577 .707 r
F P
0 g
s
.36927 .31099 m .37465 .80907 L .40438 .81873 L p .707 .577 .707 r
F P
0 g
s
.70913 .69592 m .70872 .73324 L .69612 .72599 L p .707 .577 .707 r
F P
0 g
s
.69612 .72599 m .69654 .68867 L .70913 .69592 L p .707 .577 .707 r
F P
0 g
s
.26032 .68877 m .25991 .72609 L .29174 .72572 L p .707 .577 .707 r
F P
0 g
s
.29215 .6884 m .29174 .72572 L .32112 .72298 L p .707 .577 .707 r
F P
0 g
s
.70473 .78271 m .70242 .80179 L .68937 .80125 L p .707 .577 .707 r
F P
0 g
s
.68937 .80125 m .69168 .78216 L .70473 .78271 L p .707 .577 .707 r
F P
0 g
s
.22915 .68673 m .22873 .72405 L .25991 .72609 L p .707 .577 .707 r
F P
0 g
s
.22795 .72538 m .22564 .74447 L .25672 .74799 L p .707 .577 .707 r
F P
0 g
s
.25672 .74799 m .25903 .72891 L .22795 .72538 L p .707 .577 .707 r
F P
0 g
s
.25903 .72891 m .25672 .74799 L .28826 .75193 L p .707 .577 .707 r
F P
0 g
s
.28826 .75193 m .29057 .73284 L .25903 .72891 L p .707 .577 .707 r
F P
0 g
s
.67044 .60554 m .6741 .65785 L .64661 .65266 L p .707 .577 .707 r
F P
0 g
s
.64661 .65266 m .64295 .60035 L .67044 .60554 L p .707 .577 .707 r
F P
0 g
s
.29057 .73284 m .28826 .75193 L .31719 .75589 L p .707 .577 .707 r
F P
0 g
s
.31719 .75589 m .3195 .73681 L .29057 .73284 L p .707 .577 .707 r
F P
0 g
s
.2004 .72262 m .19809 .7417 L .22564 .74447 L p .707 .577 .707 r
F P
0 g
s
.22564 .74447 m .22795 .72538 L .2004 .72262 L p .707 .577 .707 r
F P
0 g
s
.32153 .68566 m .32112 .72298 L .34517 .71813 L p .707 .577 .707 r
F P
0 g
s
.20169 .68248 m .20128 .7198 L .22873 .72405 L p .707 .577 .707 r
F P
0 g
s
.69654 .68867 m .69612 .72599 L .67506 .71994 L p .707 .577 .707 r
F P
0 g
s
.67506 .71994 m .67548 .68263 L .69654 .68867 L p .707 .577 .707 r
F P
0 g
s
.3195 .73681 m .31719 .75589 L .34068 .75949 L p .707 .577 .707 r
F P
0 g
s
.34068 .75949 m .34299 .74041 L .3195 .73681 L p .707 .577 .707 r
F P
0 g
s
.17905 .72088 m .17674 .73996 L .19809 .7417 L p .707 .577 .707 r
F P
0 g
s
.19809 .7417 m .2004 .72262 L .17905 .72088 L p .707 .577 .707 r
F P
0 g
s
.18063 .67643 m .18022 .71375 L .20128 .7198 L p .707 .577 .707 r
F P
0 g
s
.69168 .78216 m .68937 .80125 L .66803 .7995 L p .707 .577 .707 r
F P
0 g
s
.66803 .7995 m .67034 .78042 L .69168 .78216 L p .707 .577 .707 r
F P
0 g
s
.67548 .68263 m .67506 .71994 L .6476 .71569 L p .707 .577 .707 r
F P
0 g
s
.6476 .71569 m .64802 .67838 L .67548 .68263 L p .707 .577 .707 r
F P
0 g
s
.63524 .28863 m .64062 .78671 L .63652 .77358 L p .707 .577 .707 r
F P
0 g
s
.63652 .77358 m .63114 .27549 L .63524 .28863 L p .707 .577 .707 r
F P
0 g
s
.16749 .67412 m .16383 .62181 L .16078 .60869 L p .707 .577 .707 r
F P
0 g
s
.16601 .72033 m .1637 .73941 L .17674 .73996 L p .707 .577 .707 r
F P
0 g
s
.17674 .73996 m .17905 .72088 L .16601 .72033 L p .707 .577 .707 r
F P
0 g
s
.16804 .66918 m .16762 .7065 L .18022 .71375 L p .707 .577 .707 r
F P
0 g
s
.67034 .78042 m .66803 .7995 L .64047 .79674 L p .707 .577 .707 r
F P
0 g
s
.64047 .79674 m .64278 .77765 L .67034 .78042 L p .707 .577 .707 r
F P
0 g
s
.16078 .60869 m .16444 .661 L .16749 .67412 L p .707 .577 .707 r
F P
0 g
s
.16762 .7065 m .16804 .66918 L .16514 .66144 L p .707 .577 .707 r
F P
0 g
s
.16444 .661 m .16078 .60869 L .16769 .59524 L p .707 .577 .707 r
F P
0 g
s
.16254 .72104 m .16023 .74012 L .1637 .73941 L p .707 .577 .707 r
F P
0 g
s
.1637 .73941 m .16601 .72033 L .16254 .72104 L p .707 .577 .707 r
F P
0 g
s
.16514 .66144 m .16472 .69876 L .16762 .7065 L p .707 .577 .707 r
F P
0 g
s
.63114 .27549 m .63652 .77358 L .61874 .7616 L p .707 .577 .707 r
F P
0 g
s
.61874 .7616 m .61336 .26351 L .63114 .27549 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16769 .59524 m .17135 .64755 L .16444 .661 L p .707 .577 .707 r
F P
0 g
s
.16472 .69876 m .16514 .66144 L .17221 .65396 L p .707 .577 .707 r
F P
0 g
s
.17135 .64755 m .16769 .59524 L .18388 .58279 L p .707 .577 .707 r
F P
0 g
s
.36277 .77096 m .35739 .27288 L .38049 .26128 L p .707 .577 .707 r
F P
0 g
s
.35739 .27288 m .36277 .77096 L .35277 .78396 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.169 .72293 m .16669 .74201 L .16023 .74012 L p .707 .577 .707 r
F P
0 g
s
.16023 .74012 m .16254 .72104 L .169 .72293 L p .707 .577 .707 r
F P
0 g
s
.17221 .65396 m .1718 .69128 L .16472 .69876 L p .707 .577 .707 r
F P
0 g
s
.33109 .62104 m .32743 .56873 L .34856 .57752 L p .707 .577 .707 r
F P
0 g
s
.18388 .58279 m .18754 .63511 L .17135 .64755 L p .707 .577 .707 r
F P
0 g
s
.18754 .63511 m .18388 .58279 L .20778 .57256 L p .707 .577 .707 r
F P
0 g
s
.61336 .26351 m .61874 .7616 L .58901 .75194 L p .707 .577 .707 r
F P
0 g
s
.58901 .75194 m .58363 .25385 L .61336 .26351 L p .707 .577 .707 r
F P
0 g
s
.1718 .69128 m .17221 .65396 L .18858 .64748 L p .707 .577 .707 r
F P
0 g
s
.32743 .56873 m .33109 .62104 L .3036 .61584 L p .707 .577 .707 r
F P
0 g
s
.3036 .61584 m .29994 .56353 L .32743 .56873 L p .707 .577 .707 r
F P
0 g
s
.18858 .64748 m .18816 .6848 L .1718 .69128 L p .707 .577 .707 r
F P
0 g
s
.18474 .72582 m .18243 .7449 L .16669 .74201 L p .707 .577 .707 r
F P
0 g
s
.16669 .74201 m .169 .72293 L .18474 .72582 L p .707 .577 .707 r
F P
0 g
s
.38049 .26128 m .38587 .75937 L .36277 .77096 L p .707 .577 .707 r
F P
0 g
s
.38587 .75937 m .38049 .26128 L .41444 .25224 L p .707 .577 .707 r
F P
0 g
s
.21144 .62487 m .20778 .57256 L .23704 .56555 L p .707 .577 .707 r
F P
0 g
s
.20778 .57256 m .21144 .62487 L .18754 .63511 L p .707 .577 .707 r
F P
0 g
s
.29994 .56353 m .3036 .61584 L .27246 .61475 L p .707 .577 .707 r
F P
0 g
s
.27246 .61475 m .2688 .56244 L .29994 .56353 L p .707 .577 .707 r
F P
0 g
s
.2407 .61786 m .23704 .56555 L .2688 .56244 L p .707 .577 .707 r
F P
0 g
s
.23704 .56555 m .2407 .61786 L .21144 .62487 L p .707 .577 .707 r
F P
0 g
s
.18816 .6848 m .18858 .64748 L .21263 .64263 L p .707 .577 .707 r
F P
0 g
s
.2688 .56244 m .27246 .61475 L .2407 .61786 L p .707 .577 .707 r
F P
0 g
s
.34867 .74535 m .34637 .76443 L .32502 .76269 L p .707 .577 .707 r
F P
0 g
s
.58363 .25385 m .58901 .75194 L .55025 .74555 L p .707 .577 .707 r
F P
0 g
s
.55025 .74555 m .54487 .24746 L .58363 .25385 L p .707 .577 .707 r
F P
0 g
s
.32502 .76269 m .32733 .74361 L .34867 .74535 L p .707 .577 .707 r
F P
0 g
s
.21263 .64263 m .21221 .67995 L .18816 .6848 L p .707 .577 .707 r
F P
0 g
s
.20822 .72942 m .20591 .7485 L .18243 .7449 L p .707 .577 .707 r
F P
0 g
s
.18243 .7449 m .18474 .72582 L .20822 .72942 L p .707 .577 .707 r
F P
0 g
s
.33247 .64581 m .33205 .68313 L .30459 .67888 L p .707 .577 .707 r
F P
0 g
s
.30459 .67888 m .30501 .64156 L .33247 .64581 L p .707 .577 .707 r
F P
0 g
s
.41982 .75032 m .41444 .25224 L .45592 .24661 L p .707 .577 .707 r
F P
0 g
s
.41444 .25224 m .41982 .75032 L .38587 .75937 L p .707 .577 .707 r
F P
0 g
s
.21221 .67995 m .21263 .64263 L .242 .63989 L p .707 .577 .707 r
F P
0 g
s
.54487 .24746 m .55025 .74555 L .50624 .74306 L p .707 .577 .707 r
F P
0 g
s
.50624 .74306 m .50086 .24497 L .54487 .24746 L p .707 .577 .707 r
F P
0 g
s
.32733 .74361 m .32502 .76269 L .29746 .75992 L p .707 .577 .707 r
F P
0 g
s
.29746 .75992 m .29977 .74084 L .32733 .74361 L p .707 .577 .707 r
F P
0 g
s
.74018 .69139 m .73652 .63908 L .70538 .63798 L p .707 .577 .707 r
F P
0 g
s
.73652 .63908 m .74018 .69139 L .77194 .68827 L p .707 .577 .707 r
F P
0 g
s
.77194 .68827 m .76828 .63596 L .73652 .63908 L p .707 .577 .707 r
F P
0 g
s
.30501 .64156 m .30459 .67888 L .27342 .67684 L p .707 .577 .707 r
F P
0 g
s
.27342 .67684 m .27384 .63952 L .30501 .64156 L p .707 .577 .707 r
F P
0 g
s
.76828 .63596 m .77194 .68827 L .8012 .68126 L p .707 .577 .707 r
F P
0 g
s
.8012 .68126 m .79754 .62895 L .76828 .63596 L p .707 .577 .707 r
F P
0 g
s
.242 .63989 m .24159 .67721 L .21221 .67995 L p .707 .577 .707 r
F P
0 g
s
.4613 .7447 m .45592 .24661 L .50086 .24497 L p .707 .577 .707 r
F P
0 g
s
.45592 .24661 m .4613 .7447 L .41982 .75032 L p .707 .577 .707 r
F P
0 g
s
.23715 .73338 m .23484 .75246 L .20591 .7485 L p .707 .577 .707 r
F P
0 g
s
.20591 .7485 m .20822 .72942 L .23715 .73338 L p .707 .577 .707 r
F P
0 g
s
.24159 .67721 m .242 .63989 L .27384 .63952 L p .707 .577 .707 r
F P
0 g
s
.70904 .69029 m .70538 .63798 L .67789 .63278 L p .707 .577 .707 r
F P
0 g
s
.70538 .63798 m .70904 .69029 L .74018 .69139 L p .707 .577 .707 r
F P
0 g
s
.50086 .24497 m .50624 .74306 L .4613 .7447 L p .707 .577 .707 r
F P
0 g
s
.27384 .63952 m .27342 .67684 L .24159 .67721 L p .707 .577 .707 r
F P
0 g
s
.79754 .62895 m .8012 .68126 L .82509 .67103 L p .707 .577 .707 r
F P
0 g
s
.82509 .67103 m .82143 .61872 L .79754 .62895 L p .707 .577 .707 r
F P
0 g
s
.29977 .74084 m .29746 .75992 L .26639 .7564 L p .707 .577 .707 r
F P
0 g
s
.26639 .7564 m .2687 .73731 L .29977 .74084 L p .707 .577 .707 r
F P
0 g
s
.2687 .73731 m .26639 .7564 L .23484 .75246 L p .707 .577 .707 r
F P
0 g
s
.23484 .75246 m .23715 .73338 L .2687 .73731 L p .707 .577 .707 r
F P
0 g
s
.68155 .68509 m .67789 .63278 L .65676 .62399 L p .707 .577 .707 r
F P
0 g
s
.67789 .63278 m .68155 .68509 L .70904 .69029 L p .707 .577 .707 r
F P
0 g
s
.73693 .7602 m .73924 .74112 L .71591 .73847 L p .707 .577 .707 r
F P
0 g
s
.71591 .73847 m .70817 .7376 L p .72529 .75105 L .707 .577 .707 r
F P
0 g
s
.73693 .7602 m .71591 .73847 L .72529 .75105 L .707 .577 .707 r
F
.70817 .7376 m .70586 .75668 L .73693 .7602 L p F P
0 g
s
.70586 .75668 m .70817 .7376 L .68709 .73548 L p .707 .577 .707 r
F P
0 g
s
.68709 .73548 m .68061 .73483 L p .69255 .74516 L .707 .577 .707 r
F P
0 g
s
.70586 .75668 m .68709 .73548 L .69255 .74516 L .707 .577 .707 r
F
.68061 .73483 m .6783 .75391 L .70586 .75668 L p F P
0 g
s
.6783 .75391 m .68061 .73483 L .66409 .73348 L p .707 .577 .707 r
F P
0 g
s
.66409 .73348 m .65926 .73309 L p .66631 .7408 L .707 .577 .707 r
F P
0 g
s
.6783 .75391 m .66409 .73348 L .66631 .7408 L .707 .577 .707 r
F
.65926 .73309 m .65696 .75217 L .6783 .75391 L p F P
0 g
s
.65696 .75217 m .65926 .73309 L .64622 .73254 L p .707 .577 .707 r
F P
0 g
s
.66043 .73787 m .66061 .72198 L p .64825 .69331 L .707 .577 .707 r
F P
0 g
s
.66061 .72198 m .66085 .70056 L .65268 .69586 L p .707 .577 .707 r
F P
0 g
s
.65268 .69586 m .64825 .69331 L p .66061 .72198 L .707 .577 .707 r
F P
0 g
s
.68149 .74392 m .68169 .7259 L p .66085 .70056 L .707 .577 .707 r
F P
0 g
s
.68169 .7259 m .6819 .7066 L .66866 .7028 L p .707 .577 .707 r
F P
0 g
s
.66866 .7028 m .66085 .70056 L p .68169 .7259 L .707 .577 .707 r
F P
0 g
s
.70895 .74817 m .70916 .72942 L p .6819 .7066 L .707 .577 .707 r
F P
0 g
s
.70916 .72942 m .70936 .71085 L .69348 .7084 L p .707 .577 .707 r
F P
0 g
s
.69348 .7084 m .6819 .7066 L p .70916 .72942 L .707 .577 .707 r
F P
0 g
s
.73924 .74112 m .73693 .7602 L .76508 .76371 L p .707 .577 .707 r
F P
0 g
s
.76508 .76371 m .76848 .76414 L p .76045 .75781 L .707 .577 .707 r
F P
0 g
s
.76045 .75781 m .73924 .74112 L .76508 .76371 L .707 .577 .707 r
F
.76848 .76414 m .77079 .74506 L .73924 .74112 L p F P
0 g
s
.74012 .75021 m .74032 .73219 L p .70936 .71085 L .707 .577 .707 r
F P
0 g
s
.74032 .73219 m .74053 .7129 L .72433 .71183 L p .707 .577 .707 r
F P
0 g
s
.72433 .71183 m .70936 .71085 L p .74032 .73219 L .707 .577 .707 r
F P
0 g
s
.77079 .74506 m .76848 .76414 L .7943 .76767 L p .707 .577 .707 r
F P
0 g
s
.7943 .76767 m .79741 .7681 L p .79085 .76242 L .707 .577 .707 r
F P
0 g
s
.79085 .76242 m .77079 .74506 L .7943 .76767 L .707 .577 .707 r
F
.79741 .7681 m .79972 .74902 L .77079 .74506 L p F P
0 g
s
.77195 .74984 m .77213 .73395 L p .74053 .7129 L .707 .577 .707 r
F P
0 g
s
.77213 .73395 m .77237 .71253 L .75815 .71269 L p .707 .577 .707 r
F P
0 g
s
.75815 .71269 m .74053 .7129 L p .77213 .73395 L .707 .577 .707 r
F P
0 g
s
.74053 .7129 m .74012 .75021 L .77195 .74984 L p .707 .577 .707 r
F P
0 g
s
.82143 .61872 m .82509 .67103 L .84129 .65858 L p .707 .577 .707 r
F P
0 g
s
.84129 .65858 m .83763 .60627 L .82143 .61872 L p .707 .577 .707 r
F P
0 g
s
.77237 .71253 m .77195 .74984 L .80133 .7471 L p .707 .577 .707 r
F P
0 g
s
.80133 .7471 m .80175 .70978 L .77237 .71253 L p .707 .577 .707 r
F P
0 g
s
.70936 .71085 m .70895 .74817 L .74012 .75021 L p .707 .577 .707 r
F P
0 g
s
.66042 .6763 m .65676 .62399 L .64404 .61247 L p .707 .577 .707 r
F P
0 g
s
.65676 .62399 m .66042 .6763 L .68155 .68509 L p .707 .577 .707 r
F P
0 g
s
.80175 .70978 m .80133 .7471 L .82538 .74225 L p .707 .577 .707 r
F P
0 g
s
.82538 .74225 m .82579 .70493 L .80175 .70978 L p .707 .577 .707 r
F P
0 g
s
.6819 .7066 m .68149 .74392 L .70895 .74817 L p .707 .577 .707 r
F P
0 g
s
.79972 .74902 m .79741 .7681 L .82089 .7717 L p .707 .577 .707 r
F P
0 g
s
.82089 .7717 m .8232 .75262 L .79972 .74902 L p .707 .577 .707 r
F P
0 g
s
.83763 .60627 m .84129 .65858 L .8482 .64514 L p .707 .577 .707 r
F P
0 g
s
.8482 .64514 m .84454 .59283 L .83763 .60627 L p .707 .577 .707 r
F P
0 g
s
.66085 .70056 m .66043 .73787 L .68149 .74392 L p .707 .577 .707 r
F P
0 g
s
.82579 .70493 m .82538 .74225 L .84174 .73577 L p .707 .577 .707 r
F P
0 g
s
.84174 .73577 m .84216 .69845 L .82579 .70493 L p .707 .577 .707 r
F P
0 g
s
.64404 .61247 m .6477 .66478 L .66042 .6763 L p .707 .577 .707 r
F P
0 g
s
.6477 .66478 m .64404 .61247 L .64099 .59935 L p .707 .577 .707 r
F P
0 g
s
.8232 .75262 m .82089 .7717 L .83663 .77459 L p .707 .577 .707 r
F P
0 g
s
.83663 .77459 m .83894 .7555 L .8232 .75262 L p .707 .577 .707 r
F P
0 g
s
.64622 .73254 m .64391 .75162 L .65696 .75217 L p .707 .577 .707 r
F P
0 g
s
.84454 .59283 m .8482 .64514 L .84515 .63201 L p .707 .577 .707 r
F P
0 g
s
.84515 .63201 m .84149 .5797 L .84454 .59283 L p .707 .577 .707 r
F P
0 g
s
.64825 .69331 m .64783 .73062 L .66043 .73787 L p .707 .577 .707 r
F P
0 g
s
.84216 .69845 m .84174 .73577 L .84882 .72829 L p .707 .577 .707 r
F P
0 g
s
.84882 .72829 m .84924 .69097 L .84216 .69845 L p .707 .577 .707 r
F P
0 g
s
.64099 .59935 m .64465 .65166 L .6477 .66478 L p .707 .577 .707 r
F P
0 g
s
.83894 .7555 m .83663 .77459 L .84309 .77648 L p .707 .577 .707 r
F P
0 g
s
.64465 .65166 m .64099 .59935 L .6479 .5859 L p .707 .577 .707 r
F P
0 g
s
.84309 .77648 m .8454 .75739 L .83894 .7555 L p .707 .577 .707 r
F P
0 g
s
.64783 .73062 m .64825 .69331 L .64535 .68556 L p .707 .577 .707 r
F P
0 g
s
.64276 .73325 m .64045 .75233 L .64391 .75162 L p .707 .577 .707 r
F P
0 g
s
.64391 .75162 m .64622 .73254 L .64276 .73325 L p .707 .577 .707 r
F P
0 g
s
.84149 .5797 m .84515 .63201 L .83243 .62049 L p .707 .577 .707 r
F P
0 g
s
.83243 .62049 m .82877 .56818 L .84149 .5797 L p .707 .577 .707 r
F P
0 g
s
.64535 .68556 m .64493 .72288 L .64783 .73062 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84924 .69097 m .84882 .72829 L .84592 .72055 L p .707 .577 .707 r
F P
0 g
s
.84592 .72055 m .84634 .68323 L .84924 .69097 L p .707 .577 .707 r
F P
0 g
s
.6479 .5859 m .65156 .63822 L .64465 .65166 L p .707 .577 .707 r
F P
0 g
s
.65156 .63822 m .6479 .5859 L .6641 .57346 L p .707 .577 .707 r
F P
0 g
s
.8454 .75739 m .84309 .77648 L .83962 .77718 L p .707 .577 .707 r
F P
0 g
s
.83962 .77718 m .84193 .7581 L .8454 .75739 L p .707 .577 .707 r
F P
0 g
s
.39717 .65457 m .39351 .60226 L .36237 .60116 L p .707 .577 .707 r
F P
0 g
s
.39351 .60226 m .39717 .65457 L .42893 .65146 L p .707 .577 .707 r
F P
0 g
s
.42893 .65146 m .42527 .59915 L .39351 .60226 L p .707 .577 .707 r
F P
0 g
s
.42527 .59915 m .42893 .65146 L .45819 .64444 L p .707 .577 .707 r
F P
0 g
s
.45819 .64444 m .45453 .59213 L .42527 .59915 L p .707 .577 .707 r
F P
0 g
s
.64493 .72288 m .64535 .68556 L .65243 .67809 L p .707 .577 .707 r
F P
0 g
s
.36603 .65347 m .36237 .60116 L .33488 .59597 L p .707 .577 .707 r
F P
0 g
s
.36237 .60116 m .36603 .65347 L .39717 .65457 L p .707 .577 .707 r
F P
0 g
s
.82877 .56818 m .83243 .62049 L .8113 .6117 L p .707 .577 .707 r
F P
0 g
s
.8113 .6117 m .80764 .55939 L .82877 .56818 L p .707 .577 .707 r
F P
0 g
s
.64921 .73514 m .6469 .75422 L .64045 .75233 L p .707 .577 .707 r
F P
0 g
s
.64045 .75233 m .64276 .73325 L .64921 .73514 L p .707 .577 .707 r
F P
0 g
s
.45453 .59213 m .45819 .64444 L .48208 .63421 L p .707 .577 .707 r
F P
0 g
s
.48208 .63421 m .47842 .5819 L .45453 .59213 L p .707 .577 .707 r
F P
0 g
s
.65243 .67809 m .65201 .71541 L .64493 .72288 L p .707 .577 .707 r
F P
0 g
s
.6641 .57346 m .66776 .62577 L .65156 .63822 L p .707 .577 .707 r
F P
0 g
s
.66776 .62577 m .6641 .57346 L .68799 .56323 L p .707 .577 .707 r
F P
0 g
s
.84634 .68323 m .84592 .72055 L .83333 .7133 L p .707 .577 .707 r
F P
0 g
s
.83333 .7133 m .83374 .67598 L .84634 .68323 L p .707 .577 .707 r
F P
0 g
s
.33854 .64828 m .33488 .59597 L .31375 .58718 L p .707 .577 .707 r
F P
0 g
s
.33488 .59597 m .33854 .64828 L .36603 .65347 L p .707 .577 .707 r
F P
0 g
s
.80764 .55939 m .8113 .6117 L .78381 .60651 L p .707 .577 .707 r
F P
0 g
s
.78381 .60651 m .78015 .55419 L .80764 .55939 L p .707 .577 .707 r
F P
0 g
s
.39392 .72339 m .39623 .7043 L .3729 .70166 L p .707 .577 .707 r
F P
0 g
s
.3729 .70166 m .36516 .70078 L p .38228 .71424 L .707 .577 .707 r
F P
0 g
s
.39392 .72339 m .3729 .70166 L .38228 .71424 L .707 .577 .707 r
F
.36516 .70078 m .36285 .71986 L .39392 .72339 L p F P
0 g
s
.36285 .71986 m .36516 .70078 L .34408 .69866 L p .707 .577 .707 r
F P
0 g
s
.34408 .69866 m .3376 .69801 L p .34954 .70834 L .707 .577 .707 r
F P
0 g
s
.36285 .71986 m .34408 .69866 L .34954 .70834 L .707 .577 .707 r
F
.3376 .69801 m .33529 .71709 L .36285 .71986 L p F P
0 g
s
.33529 .71709 m .3376 .69801 L .32108 .69666 L p .707 .577 .707 r
F P
0 g
s
.32108 .69666 m .31625 .69627 L p .3233 .70398 L .707 .577 .707 r
F P
0 g
s
.33529 .71709 m .32108 .69666 L .3233 .70398 L .707 .577 .707 r
F
.31625 .69627 m .31394 .71535 L .33529 .71709 L p F P
0 g
s
.31394 .71535 m .31625 .69627 L .30321 .69573 L p .707 .577 .707 r
F P
0 g
s
.31742 .70106 m .3176 .68517 L p .30524 .65649 L .707 .577 .707 r
F P
0 g
s
.3176 .68517 m .31784 .66374 L .30967 .65904 L p .707 .577 .707 r
F P
0 g
s
.30967 .65904 m .30524 .65649 L p .3176 .68517 L .707 .577 .707 r
F P
0 g
s
.33848 .70711 m .33868 .68908 L p .31784 .66374 L .707 .577 .707 r
F P
0 g
s
.33868 .68908 m .33889 .66979 L .32565 .66599 L p .707 .577 .707 r
F P
0 g
s
.32565 .66599 m .31784 .66374 L p .33868 .68908 L .707 .577 .707 r
F P
0 g
s
.36594 .71136 m .36615 .6926 L p .33889 .66979 L .707 .577 .707 r
F P
0 g
s
.36615 .6926 m .36635 .67404 L .35047 .67158 L p .707 .577 .707 r
F P
0 g
s
.35047 .67158 m .33889 .66979 L p .36615 .6926 L .707 .577 .707 r
F P
0 g
s
.39623 .7043 m .39392 .72339 L .42207 .7269 L p .707 .577 .707 r
F P
0 g
s
.42207 .7269 m .42547 .72732 L p .41744 .721 L .707 .577 .707 r
F P
0 g
s
.41744 .721 m .39623 .7043 L .42207 .7269 L .707 .577 .707 r
F
.42547 .72732 m .42778 .70824 L .39623 .7043 L p F P
0 g
s
.39711 .7134 m .39731 .69538 L p .36635 .67404 L .707 .577 .707 r
F P
0 g
s
.39731 .69538 m .39752 .67608 L .38132 .67502 L p .707 .577 .707 r
F P
0 g
s
.38132 .67502 m .36635 .67404 L p .39731 .69538 L .707 .577 .707 r
F P
0 g
s
.42778 .70824 m .42547 .72732 L .45129 .73086 L p .707 .577 .707 r
F P
0 g
s
.45129 .73086 m .4544 .73128 L p .44784 .7256 L .707 .577 .707 r
F P
0 g
s
.44784 .7256 m .42778 .70824 L .45129 .73086 L .707 .577 .707 r
F
.4544 .73128 m .45671 .7122 L .42778 .70824 L p F P
0 g
s
.42894 .71303 m .42912 .69714 L p .39752 .67608 L .707 .577 .707 r
F P
0 g
s
.42912 .69714 m .42936 .67571 L .41514 .67588 L p .707 .577 .707 r
F P
0 g
s
.41514 .67588 m .39752 .67608 L p .42912 .69714 L .707 .577 .707 r
F P
0 g
s
.39752 .67608 m .39711 .7134 L .42894 .71303 L p .707 .577 .707 r
F P
0 g
s
.84193 .7581 m .83962 .77718 L .82658 .77664 L p .707 .577 .707 r
F P
0 g
s
.47842 .5819 m .48208 .63421 L .49828 .62176 L p .707 .577 .707 r
F P
0 g
s
.49828 .62176 m .49462 .56945 L .47842 .5819 L p .707 .577 .707 r
F P
0 g
s
.82658 .77664 m .82889 .75756 L .84193 .7581 L p .707 .577 .707 r
F P
0 g
s
.42936 .67571 m .42894 .71303 L .45832 .71028 L p .707 .577 .707 r
F P
0 g
s
.45832 .71028 m .45874 .67297 L .42936 .67571 L p .707 .577 .707 r
F P
0 g
s
.65201 .71541 m .65243 .67809 L .66879 .67161 L p .707 .577 .707 r
F P
0 g
s
.36635 .67404 m .36594 .71136 L .39711 .7134 L p .707 .577 .707 r
F P
0 g
s
.69165 .61554 m .68799 .56323 L .71725 .55621 L p .707 .577 .707 r
F P
0 g
s
.68799 .56323 m .69165 .61554 L .66776 .62577 L p .707 .577 .707 r
F P
0 g
s
.66495 .73803 m .66264 .75711 L .6469 .75422 L p .707 .577 .707 r
F P
0 g
s
.6469 .75422 m .64921 .73514 L .66495 .73803 L p .707 .577 .707 r
F P
0 g
s
.66879 .67161 m .66838 .70892 L .65201 .71541 L p .707 .577 .707 r
F P
0 g
s
.31741 .63949 m .31375 .58718 L .30103 .57566 L p .707 .577 .707 r
F P
0 g
s
.31375 .58718 m .31741 .63949 L .33854 .64828 L p .707 .577 .707 r
F P
0 g
s
.78015 .55419 m .78381 .60651 L .75267 .60541 L p .707 .577 .707 r
F P
0 g
s
.75267 .60541 m .74901 .5531 L .78015 .55419 L p .707 .577 .707 r
F P
0 g
s
.45874 .67297 m .45832 .71028 L .48237 .70543 L p .707 .577 .707 r
F P
0 g
s
.48237 .70543 m .48278 .66812 L .45874 .67297 L p .707 .577 .707 r
F P
0 g
s
.33889 .66979 m .33848 .70711 L .36594 .71136 L p .707 .577 .707 r
F P
0 g
s
.83374 .67598 m .83333 .7133 L .81227 .70725 L p .707 .577 .707 r
F P
0 g
s
.81227 .70725 m .81268 .66994 L .83374 .67598 L p .707 .577 .707 r
F P
0 g
s
.72091 .60852 m .71725 .55621 L .74901 .5531 L p .707 .577 .707 r
F P
0 g
s
.71725 .55621 m .72091 .60852 L .69165 .61554 L p .707 .577 .707 r
F P
0 g
s
.45671 .7122 m .4544 .73128 L .47788 .73488 L p .707 .577 .707 r
F P
0 g
s
.47788 .73488 m .48019 .7158 L .45671 .7122 L p .707 .577 .707 r
F P
0 g
s
.74901 .5531 m .75267 .60541 L .72091 .60852 L p .707 .577 .707 r
F P
0 g
s
.49462 .56945 m .49828 .62176 L .50519 .60832 L p .707 .577 .707 r
F P
0 g
s
.50519 .60832 m .50153 .55601 L .49462 .56945 L p .707 .577 .707 r
F P
0 g
s
.82889 .75756 m .82658 .77664 L .80523 .7749 L p .707 .577 .707 r
F P
0 g
s
.80523 .7749 m .80754 .75582 L .82889 .75756 L p .707 .577 .707 r
F P
0 g
s
.66838 .70892 m .66879 .67161 L .69284 .66676 L p .707 .577 .707 r
F P
0 g
s
.31784 .66374 m .31742 .70106 L .33848 .70711 L p .707 .577 .707 r
F P
0 g
s
.48278 .66812 m .48237 .70543 L .49873 .69895 L p .707 .577 .707 r
F P
0 g
s
.49873 .69895 m .49915 .66164 L .48278 .66812 L p .707 .577 .707 r
F P
0 g
s
.68844 .74163 m .68613 .76071 L .66264 .75711 L p .707 .577 .707 r
F P
0 g
s
.66264 .75711 m .66495 .73803 L .68844 .74163 L p .707 .577 .707 r
F P
0 g
s
.30103 .57566 m .30469 .62797 L .31741 .63949 L p .707 .577 .707 r
F P
0 g
s
.69284 .66676 m .69243 .70407 L .66838 .70892 L p .707 .577 .707 r
F P
0 g
s
.30469 .62797 m .30103 .57566 L .29798 .56253 L p .707 .577 .707 r
F P
0 g
s
.48019 .7158 m .47788 .73488 L .49362 .73777 L p .707 .577 .707 r
F P
0 g
s
.49362 .73777 m .49593 .71869 L .48019 .7158 L p .707 .577 .707 r
F P
0 g
s
.81268 .66994 m .81227 .70725 L .78481 .703 L p .707 .577 .707 r
F P
0 g
s
.78481 .703 m .78522 .66568 L .81268 .66994 L p .707 .577 .707 r
F P
0 g
s
.30321 .69573 m .3009 .71481 L .31394 .71535 L p .707 .577 .707 r
F P
0 g
s
.69243 .70407 m .69284 .66676 L .72222 .66401 L p .707 .577 .707 r
F P
0 g
s
.80754 .75582 m .80523 .7749 L .77768 .77213 L p .707 .577 .707 r
F P
0 g
s
.50153 .55601 m .50519 .60832 L .50214 .5952 L p .707 .577 .707 r
F P
0 g
s
.50214 .5952 m .49848 .54289 L .50153 .55601 L p .707 .577 .707 r
F P
0 g
s
.77768 .77213 m .77999 .75305 L .80754 .75582 L p .707 .577 .707 r
F P
0 g
s
.30524 .65649 m .30482 .69381 L .31742 .70106 L p .707 .577 .707 r
F P
0 g
s
.78522 .66568 m .78481 .703 L .75364 .70096 L p .707 .577 .707 r
F P
0 g
s
.75364 .70096 m .75405 .66364 L .78522 .66568 L p .707 .577 .707 r
F P
0 g
s
.71737 .74559 m .71506 .76467 L .68613 .76071 L p .707 .577 .707 r
F P
0 g
s
.68613 .76071 m .68844 .74163 L .71737 .74559 L p .707 .577 .707 r
F P
0 g
s
.72222 .66401 m .7218 .70133 L .69243 .70407 L p .707 .577 .707 r
F P
0 g
s
.49915 .66164 m .49873 .69895 L .50581 .69148 L p .707 .577 .707 r
F P
0 g
s
.50581 .69148 m .50623 .65416 L .49915 .66164 L p .707 .577 .707 r
F P
0 g
s
.7218 .70133 m .72222 .66401 L .75405 .66364 L p .707 .577 .707 r
F P
0 g
s
.29798 .56253 m .30164 .61484 L .30469 .62797 L p .707 .577 .707 r
F P
0 g
s
.75405 .66364 m .75364 .70096 L .7218 .70133 L p .707 .577 .707 r
F P
0 g
s
.77999 .75305 m .77768 .77213 L .7466 .76861 L p .707 .577 .707 r
F P
0 g
s
.49593 .71869 m .49362 .73777 L .50008 .73966 L p .707 .577 .707 r
F P
0 g
s
.7466 .76861 m .74891 .74953 L .77999 .75305 L p .707 .577 .707 r
F P
0 g
s
.30164 .61484 m .29798 .56253 L .30489 .54909 L p .707 .577 .707 r
F P
0 g
s
.50008 .73966 m .50239 .72058 L .49593 .71869 L p .707 .577 .707 r
F P
0 g
s
.74891 .74953 m .7466 .76861 L .71506 .76467 L p .707 .577 .707 r
F P
0 g
s
.71506 .76467 m .71737 .74559 L .74891 .74953 L p .707 .577 .707 r
F P
0 g
s
.30482 .69381 m .30524 .65649 L .30234 .64875 L p .707 .577 .707 r
F P
0 g
s
.29975 .69644 m .29744 .71552 L .3009 .71481 L p .707 .577 .707 r
F P
0 g
s
.3009 .71481 m .30321 .69573 L .29975 .69644 L p .707 .577 .707 r
F P
0 g
s
.49848 .54289 m .50214 .5952 L .48942 .58368 L p .707 .577 .707 r
F P
0 g
s
.48942 .58368 m .48576 .53136 L .49848 .54289 L p .707 .577 .707 r
F P
0 g
s
.30234 .64875 m .30192 .68607 L .30482 .69381 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50623 .65416 m .50581 .69148 L .50291 .68373 L p .707 .577 .707 r
F P
0 g
s
.50291 .68373 m .50333 .64642 L .50623 .65416 L p .707 .577 .707 r
F P
0 g
s
.30489 .54909 m .30855 .6014 L .30164 .61484 L p .707 .577 .707 r
F P
0 g
s
.30855 .6014 m .30489 .54909 L .32109 .53664 L p .707 .577 .707 r
F P
0 g
s
.50239 .72058 m .50008 .73966 L .49661 .74037 L p .707 .577 .707 r
F P
0 g
s
.49661 .74037 m .49892 .72129 L .50239 .72058 L p .707 .577 .707 r
F P
0 g
s
.30192 .68607 m .30234 .64875 L .30942 .64127 L p .707 .577 .707 r
F P
0 g
s
.48576 .53136 m .48942 .58368 L .46829 .57489 L p .707 .577 .707 r
F P
0 g
s
.46829 .57489 m .46463 .52258 L .48576 .53136 L p .707 .577 .707 r
F P
0 g
s
.3062 .69833 m .30389 .71741 L .29744 .71552 L p .707 .577 .707 r
F P
0 g
s
.29744 .71552 m .29975 .69644 L .3062 .69833 L p .707 .577 .707 r
F P
0 g
s
.30942 .64127 m .309 .67859 L .30192 .68607 L p .707 .577 .707 r
F P
0 g
s
.32109 .53664 m .32475 .58895 L .30855 .6014 L p .707 .577 .707 r
F P
0 g
s
.32475 .58895 m .32109 .53664 L .34498 .52641 L p .707 .577 .707 r
F P
0 g
s
.50333 .64642 m .50291 .68373 L .49032 .67648 L p .707 .577 .707 r
F P
0 g
s
.49032 .67648 m .49073 .63917 L .50333 .64642 L p .707 .577 .707 r
F P
0 g
s
.46463 .52258 m .46829 .57489 L .4408 .56969 L p .707 .577 .707 r
F P
0 g
s
.4408 .56969 m .43714 .51738 L .46463 .52258 L p .707 .577 .707 r
F P
0 g
s
.49892 .72129 m .49661 .74037 L .48357 .73983 L p .707 .577 .707 r
F P
0 g
s
.48357 .73983 m .48588 .72074 L .49892 .72129 L p .707 .577 .707 r
F P
0 g
s
.309 .67859 m .30942 .64127 L .32578 .63479 L p .707 .577 .707 r
F P
0 g
s
.34864 .57872 m .34498 .52641 L .37424 .51939 L p .707 .577 .707 r
F P
0 g
s
.34498 .52641 m .34864 .57872 L .32475 .58895 L p .707 .577 .707 r
F P
0 g
s
.32194 .70121 m .31963 .72029 L .30389 .71741 L p .707 .577 .707 r
F P
0 g
s
.30389 .71741 m .3062 .69833 L .32194 .70121 L p .707 .577 .707 r
F P
0 g
s
.32578 .63479 m .32537 .67211 L .309 .67859 L p .707 .577 .707 r
F P
0 g
s
.43714 .51738 m .4408 .56969 L .40966 .56859 L p .707 .577 .707 r
F P
0 g
s
.40966 .56859 m .406 .51628 L .43714 .51738 L p .707 .577 .707 r
F P
0 g
s
.49073 .63917 m .49032 .67648 L .46926 .67044 L p .707 .577 .707 r
F P
0 g
s
.46926 .67044 m .46967 .63312 L .49073 .63917 L p .707 .577 .707 r
F P
0 g
s
.3779 .57171 m .37424 .51939 L .406 .51628 L p .707 .577 .707 r
F P
0 g
s
.37424 .51939 m .3779 .57171 L .34864 .57872 L p .707 .577 .707 r
F P
0 g
s
.406 .51628 m .40966 .56859 L .3779 .57171 L p .707 .577 .707 r
F P
0 g
s
.48588 .72074 m .48357 .73983 L .46222 .73809 L p .707 .577 .707 r
F P
0 g
s
.46222 .73809 m .46453 .719 L .48588 .72074 L p .707 .577 .707 r
F P
0 g
s
.32537 .67211 m .32578 .63479 L .34983 .62994 L p .707 .577 .707 r
F P
0 g
s
.34542 .70481 m .34312 .72389 L .31963 .72029 L p .707 .577 .707 r
F P
0 g
s
.31963 .72029 m .32194 .70121 L .34542 .70481 L p .707 .577 .707 r
F P
0 g
s
.34983 .62994 m .34941 .66726 L .32537 .67211 L p .707 .577 .707 r
F P
0 g
s
.46967 .63312 m .46926 .67044 L .4418 .66619 L p .707 .577 .707 r
F P
0 g
s
.4418 .66619 m .44221 .62887 L .46967 .63312 L p .707 .577 .707 r
F P
0 g
s
.34941 .66726 m .34983 .62994 L .37921 .6272 L p .707 .577 .707 r
F P
0 g
s
.46453 .719 m .46222 .73809 L .43467 .73532 L p .707 .577 .707 r
F P
0 g
s
.43467 .73532 m .43698 .71624 L .46453 .719 L p .707 .577 .707 r
F P
0 g
s
.44221 .62887 m .4418 .66619 L .41063 .66415 L p .707 .577 .707 r
F P
0 g
s
.41063 .66415 m .41104 .62683 L .44221 .62887 L p .707 .577 .707 r
F P
0 g
s
.37436 .70877 m .37205 .72786 L .34312 .72389 L p .707 .577 .707 r
F P
0 g
s
.34312 .72389 m .34542 .70481 L .37436 .70877 L p .707 .577 .707 r
F P
0 g
s
.37921 .6272 m .37879 .66451 L .34941 .66726 L p .707 .577 .707 r
F P
0 g
s
.37879 .66451 m .37921 .6272 L .41104 .62683 L p .707 .577 .707 r
F P
0 g
s
.41104 .62683 m .41063 .66415 L .37879 .66451 L p .707 .577 .707 r
F P
0 g
s
.43698 .71624 m .43467 .73532 L .40359 .73179 L p .707 .577 .707 r
F P
0 g
s
.40359 .73179 m .4059 .71271 L .43698 .71624 L p .707 .577 .707 r
F P
0 g
s
.4059 .71271 m .40359 .73179 L .37205 .72786 L p .707 .577 .707 r
F P
0 g
s
.37205 .72786 m .37436 .70877 L .4059 .71271 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo3000RGoo001lOol<0006FUH00`00FUIJEP03FUH90020Ool007Aoo`P000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Yoo`00LGoo0`0000=JEP00FUH02UYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF1000MWoo001^Ool30004FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUH00002001cOol006]oo`<000MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<0071o
o`00JGoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF0P00KWoo001WOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001/Ool006Eo
o`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008006Yoo`00I7oo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<007ooOol0Igoo001SOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1WOol006=oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo001ROol3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0069oo`=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo0eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00J7oo001ROol3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001XOol0069oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo001ROol3FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0069oo`=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo0eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00J7oo001ROol3FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001XOol0069oo`=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<006Moo`00HWoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009J
EP<006Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo
00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<006Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00
HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo00D005YFFUIJEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP<006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Moo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00Hgoo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001S
Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`=J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo0eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001SOol3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`=JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo0eYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001SOol3FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`=JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Moo`00Hgoo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000Igoo001SOol3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001WOol006=oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Moo`00Hgoo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000Igoo001SOol3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001WOol006=oo`=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Mo
o`00Hgoo0eYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001S
Ool3FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`=J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo0eYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Igoo001SOol3FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001WOol006=oo`=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Moo`00Hgoo0eYF00<005YFFUH015YF00<0
05YF000020002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00L005YFFUIJEP00FUH0001WOol006=oo`=JEP03001JEUYF00H000AJEP03001JEUYF009JEPP0009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH0
05YF0000Igoo001SOol2FUH400000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@002UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001WOol0065o
o`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000QJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Ggoo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P001UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001MOol20003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
05]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Moo`00FWoo0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001HOol200000eYF001JEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Egoo00D005YFFUIJ
EP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00Igoo001FOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUIJEP00FUH000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00EGoo0P0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFFUH00`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P006Woo3`00?Woo
001EOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2000DOol60004FUH00`00FUIJEP06FUH00`00FUH00003000jOol004Qoo`T0
00=oo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80011oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00=JEP@003Ioo`00@Woo1P0015YF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF00000P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0037oo1000
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00<goo000nOol4
00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000aOol003Yoo`@000EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJ
EPH000IJEP03001JEUYF00P000AJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00>7oo0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH015YF00<005YFFUH0
10000eYF00<005YFFUH01UYF00<005YFFUH025YF1@001EYF00<005YFFUH00P002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo0P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002ioo`00=Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP03001JEUYF
00=JEPD000IJEP03001JEUYF00IJEP03001JEUYF00UJEP04001JEUYFFUH20003FUH00`00FUIJEP02
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005Ool20006FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;Goo000dOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP0015YF00@005YFFUIJEP800005FUH005YFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP02FUH3000015YF001JEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00<goo0P001UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP04001JEP000003FUH0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00`000UYF0P000UYF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP05001JEUYFFUH0000]Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEP0000AJEP8000EJEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH30002FUH00`00FUIJEP02FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002aoo`00
<7oo00D005YFFUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000=JEP<000EJEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00
FUIJEP02FUH4000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo0000
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;7oo000_Ool00`00FUIJEP02FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF0P000eYF1P000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH015YF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020005FUH01000FUIJEUYF20000UYF
00<005YFFUH015YF1`001UYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF4@0015YF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00;Goo00<005YF00001EYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH015YF1P004Goo1@001EYF00D005YFFUIJ
EP0002aoo`00;Goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF
2@000eYF0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`000UYF00D005YFFUIJEP0000IJEP03001JEUYF00@001aoo`8000=J
EP05001JEUYFFUH0000/Ool002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH0
00Uoo`D000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP<000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<0009JEP05001JEUYFFUH00005FUH4000QOol300000eYF001JEP02FUH0
0`00Oomoo`0ZOol002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00@0019oo`8000=J
EP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<0009JEP06001JEUYFFUH005YF100000=JEP00FUH00P007Woo0P0000=JEP00
FUH00P000eYF0P00:goo000]Ool01000FUIJEP0015YF00<005YFFUH00eYF10005goo00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30002FUH01000FUIJEUYF0P001EYF00D005YFFUIJEP0001]oo`8000=JEP05001JEUYF
FUH00002FUH2000[Ool002eoo`04001JEUYF0004FUH01000FUIJEUYF0P006goo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEQL000=JEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00004FUH005YFFUH30005FUH01@00FUIJ
EUYF000067oo0`001EYF00<005YFFUH00UYF1000:goo000]Ool01000FUIJEP0015YF00@005YF0000
01ioo`04001JEUYF0005FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030006
FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40000
15YF001JEP000eYF0`000UYF00D005YFFUIJEP0001Aoo`@00003FUH005YF00EJEP03001JEUYF009J
EP04001JEP00000[Ool002eoo`04001JEUYF0004FUH2000QOol80003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH70005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH400000eYF00000005FUH00`00FUH000030002FUH2000<
Ool70005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000[Ool002ioo`03001JEP0000=JEP<000Yo
oa4000Ioo`<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP@00003FUH0000000EJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF00=JEP<002]oo`00;Woo00@005YF001JEP8000=JEP<00003Ool00000
00@000=JEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD00003FUH005YF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEP0002]oo`00;Woo00<005YF00000P0015YF100000=JEP00FUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000:goo000^Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEPD00003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8002aoo`00;Woo1@00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEPD0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8002aoo`00;Woo0`0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00;Woo0`0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001oogoo02]oo`00;Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00Ool00002FUH00`00
FUIJEP03FUH00`00FUIJEP04FUHD0007FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002ioo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP0000AJEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03001JEP0000L000AJEP03001J
EUYF00=JEP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00Ool00002FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006
FUH3000`Ool002ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000L00003FUH005YF00AJEP03001JEUYF00MJ
EP03001JEUYF00MJEPH000AJEP03001JEUYF008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009oo`04001JEP00FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP000000<Woo000^Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH40002
FUH00`00FUIJEP03FUH90008FUH00`00FUIJEP05FUH700001UYF00000000FUH0009JEP8000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<00003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP000080
039oo`00;Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@000eYF00<005YF0000
0`001EYF00<005YFFUH01EYF00<005YFFUH015YF40000eYF00<005YFFUH015YF0`000UYF0P0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00<7oo000^Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01UYF1@000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH015YF0`0025YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH0100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@0
05YF001JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP<002ioo`00;Woo00<005YF00000eYF2@0015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00eYF1@001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YFFUH00P00;7oo000^Ool01000FUH005YF0P001EYF00@005YFFUIJEQX000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00=JEPD000IJEP8000MJEP03001JEUYF00AJEP04001JEUYF
FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP05001JEUYFFUH0000/Ool002ioo`06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00=JEPD000IJEP8000MJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00:goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`001eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00@005YFFUIJEP8002]oo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF0P0025YF00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYFFUH2000[Ool002ioo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJ
EP8000QJEP06001JEP00FUH005YF1P0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF00<005YFFUH015YF00<005YF
FUH00UYF60001EYF00<005YFFUH00eYF00@005YFFUIJEP8002]oo`00;goo00D005YFFUIJEP0000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP8000QJEP05001JEP00FUH00003FUH01000FUIJEUYF1`00
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP000eYF
00@005YFFUIJEPX001Ioo`@00003FUH005YF00AJEP04001JEUYFFUH2000[Ool0031oo`800003FUH0
05YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEP00FUH00004FUH0
0`00FUIJEP04FUH01000FUIJEUYF2@0000=JEP00FUH01eYF00<005YFFUH00UYF20002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH5
00000eYF000000020002FUH2000EOol90003FUH01000FUIJEUYF0P00:goo000bOol30004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF5P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00L005YF000005YF001JEP020004FUH00`00FUIJEP03FUHI0003FUH0
0`00FUIJEP03FUH40003FUH2000[Ool003Eoo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001J
EUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH800000eYF001JEP02FUH50005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01@00FUH00000FUH00`001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`001eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000:goo000_
Ool60003Ool50004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP090003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF400035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH015YF1@001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00:goo
000^Ool50002FUH700000goo000000060003FUH30007FUH00`00FUIJEP02FUH>0004FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00003000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH3000[Ool002ioo`04001JEP00FUH70003FUHK000=Ool00eYF000000050006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000[Ool002ioo`03001JEP0000=JEP04001JEUYFFUH700000eYF001JEP03FUH9000FOol3FUH00`00
FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP00009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00@0
05YFFUIJEPd0009JEPP000ioo`=JEP03001JEUYF00=JEP03001JEUYF00L000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000/Ool002eoo`03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT00003FUH005YF009JEPP000Ioo`=JEP03001J
EUYF00=JEP03001JEUYF00MJEPl000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000900000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Goo000]Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH800000eYF001J
EP02FUH500001GooFUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000AJEP03001J
EUYF00D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEP00000_Ool002ioo`T000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04
001JEUYFFUH;0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUHE0006FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH00eYF
00<005YF0000100025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPD0035oo`00=goo
1`0015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00FUIJEP09FUH<0005FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH00eYF1`00
0UYF00<005YFFUH01UYF00<005YFFUH00UYF1`00=Woo000nOol70006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF1P000UYF00<005YF
FUH02UYF00<005YFFUH02EYF0P002UYF1`001UYF00<005YFFUH00UYF00@005YF000000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ0000=JEP03001JEP00008003Eoo`00AGoo1000
0UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH0
0eYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02EYF0P002UYF00<005YFFUH015YF
0P0015YF00<005YFFUH00UYF00<005YF00000`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF5P00;Woo0019Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH2000:FUH00`00FUIJEP06FUH300000eYF001JEP03FUH00`00FUH00003FUH60003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP09000/
Ool0051oo`l000=JEP03001JEUYF009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00001`00
0Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002aoo`00Ggoo1P000UYF00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH0
000@Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
;7oo001TOol00`00FUIJEP040007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH20005FUH300000eYF0000000HOol90004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo0018Ool3000IOol01000FUIJEP000UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH01P006goo20000eYF00<005YFFUH00eYF00@005YF
FUIJEP8002eoo`00Agoo1@0067oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH015YF00<005YF00000P0087oo3`00;Goo0017Ool5000HOol20004FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUH0000B001EOol004Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEP000007FUH00`00FUIJEP09001COol004Qoo`<001Uoo`8000AJEP03001J
EUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYF0007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo
001TOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH015YF
00@005YFFUIJEP8005=oo`00IGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00
00=JEP00FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IGoo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF1`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00IWoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000Ioo`l005Aoo`00Igoo00@005YFFUH000MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04
001JEUYFFUH2001[Ool006Qoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00001]Ool006Yoo`8000IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@006moo`00K7oo
10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH00UYF1P00Kgoo001`Ool50008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUH0000200000goo00000003001_Ool007Eoo`H0009JEP03001JEUYF00YJEP03001JEUYF00YJ
EP04001JEUYFFUH:0004Ool5001_Ool007]oo`T000IJEP03001JEUYF00AJEPX000moo`<0071oo`00
Q7oo3@00S7oo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000
\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59034 .75993 m .594 .70271 L .56285 .69996 L p .707 .577 .707 r
F P
0 g
s
.594 .70271 m .59034 .75993 L .62209 .76159 L p .707 .577 .707 r
F P
0 g
s
.62209 .76159 m .62575 .70437 L .594 .70271 L p .707 .577 .707 r
F P
0 g
s
.62575 .70437 m .62209 .76159 L .65135 .76201 L p .707 .577 .707 r
F P
0 g
s
.65135 .76201 m .65501 .70479 L .62575 .70437 L p .707 .577 .707 r
F P
0 g
s
.56285 .69996 m .55919 .75718 L .59034 .75993 L p .707 .577 .707 r
F P
0 g
s
.55919 .75718 m .56285 .69996 L .53537 .69641 L p .707 .577 .707 r
F P
0 g
s
.53537 .69641 m .53171 .75363 L .55919 .75718 L p .707 .577 .707 r
F P
0 g
s
.65501 .70479 m .65135 .76201 L .67525 .76115 L p .707 .577 .707 r
F P
0 g
s
.67525 .76115 m .67891 .70393 L .65501 .70479 L p .707 .577 .707 r
F P
0 g
s
.58937 .85678 m .58896 .82001 L .55778 .81825 L p .707 .577 .707 r
F P
0 g
s
.58896 .82001 m .58937 .85678 L .6212 .85559 L p .707 .577 .707 r
F P
0 g
s
.6212 .85559 m .62079 .81883 L .58896 .82001 L p .707 .577 .707 r
F P
0 g
s
.62079 .81883 m .6212 .85559 L .65058 .85158 L p .707 .577 .707 r
F P
0 g
s
.65058 .85158 m .65017 .81482 L .62079 .81883 L p .707 .577 .707 r
F P
0 g
s
.53171 .75363 m .53537 .69641 L .51423 .6924 L p .707 .577 .707 r
F P
0 g
s
.5582 .85501 m .55778 .81825 L .53033 .81372 L p .707 .577 .707 r
F P
0 g
s
.55778 .81825 m .5582 .85501 L .58937 .85678 L p .707 .577 .707 r
F P
0 g
s
.51423 .6924 m .51057 .74962 L .53171 .75363 L p .707 .577 .707 r
F P
0 g
s
.65017 .81482 m .65058 .85158 L .67463 .84514 L p .707 .577 .707 r
F P
0 g
s
.67463 .84514 m .67422 .80838 L .65017 .81482 L p .707 .577 .707 r
F P
0 g
s
.67891 .70393 m .67525 .76115 L .69145 .7591 L p .707 .577 .707 r
F P
0 g
s
.69145 .7591 m .69511 .70188 L .67891 .70393 L p .707 .577 .707 r
F P
0 g
s
.53033 .81372 m .53074 .85048 L .5582 .85501 L p .707 .577 .707 r
F P
0 g
s
.53074 .85048 m .53033 .81372 L .50927 .80686 L p .707 .577 .707 r
F P
0 g
s
.51057 .74962 m .51423 .6924 L .50152 .68832 L p .707 .577 .707 r
F P
0 g
s
.50152 .68832 m .49786 .74554 L .51057 .74962 L p .707 .577 .707 r
F P
0 g
s
.50927 .80686 m .50968 .84362 L .53074 .85048 L p .707 .577 .707 r
F P
0 g
s
.67422 .80838 m .67463 .84514 L .69099 .83689 L p .707 .577 .707 r
F P
0 g
s
.69099 .83689 m .69058 .80013 L .67422 .80838 L p .707 .577 .707 r
F P
0 g
s
.5964 .91499 m .59409 .899 L .56302 .89859 L p .707 .577 .707 r
F P
0 g
s
.59409 .899 m .5964 .91499 L .62795 .90988 L p .707 .577 .707 r
F P
0 g
s
.62795 .90988 m .62564 .8939 L .59409 .899 L p .707 .577 .707 r
F P
0 g
s
.62564 .8939 m .62795 .90988 L .65688 .89977 L p .707 .577 .707 r
F P
0 g
s
.65688 .89977 m .65457 .88378 L .62564 .8939 L p .707 .577 .707 r
F P
0 g
s
.56533 .91458 m .56302 .89859 L .53546 .89271 L p .707 .577 .707 r
F P
0 g
s
.56302 .89859 m .56533 .91458 L .5964 .91499 L p .707 .577 .707 r
F P
0 g
s
.69511 .70188 m .69145 .7591 L .69836 .75604 L p .707 .577 .707 r
F P
0 g
s
.69836 .75604 m .70202 .69882 L .69511 .70188 L p .707 .577 .707 r
F P
0 g
s
.65457 .88378 m .65688 .89977 L .68037 .88563 L p .707 .577 .707 r
F P
0 g
s
.68037 .88563 m .67806 .86965 L .65457 .88378 L p .707 .577 .707 r
F P
0 g
s
.50968 .84362 m .50927 .80686 L .49667 .79835 L p .707 .577 .707 r
F P
0 g
s
.53546 .89271 m .53777 .90869 L .56533 .91458 L p .707 .577 .707 r
F P
0 g
s
.49786 .74554 m .50152 .68832 L .49847 .68457 L p .707 .577 .707 r
F P
0 g
s
.49667 .79835 m .49709 .83511 L .50968 .84362 L p .707 .577 .707 r
F P
0 g
s
.53777 .90869 m .53546 .89271 L .51412 .88193 L p .707 .577 .707 r
F P
0 g
s
.69058 .80013 m .69099 .83689 L .69807 .82765 L p .707 .577 .707 r
F P
0 g
s
.69807 .82765 m .69766 .79089 L .69058 .80013 L p .707 .577 .707 r
F P
0 g
s
.67806 .86965 m .68037 .88563 L .69611 .86885 L p .707 .577 .707 r
F P
0 g
s
.69611 .86885 m .6938 .85287 L .67806 .86965 L p .707 .577 .707 r
F P
0 g
s
.49847 .68457 m .49481 .74179 L .49786 .74554 L p .707 .577 .707 r
F P
0 g
s
.51412 .88193 m .51643 .89791 L .53777 .90869 L p .707 .577 .707 r
F P
0 g
s
.49709 .83511 m .49667 .79835 L .49377 .78901 L p .707 .577 .707 r
F P
0 g
s
.70202 .69882 m .69836 .75604 L .69531 .75229 L p .707 .577 .707 r
F P
0 g
s
.69531 .75229 m .69897 .69507 L .70202 .69882 L p .707 .577 .707 r
F P
0 g
s
.51643 .89791 m .51412 .88193 L .50108 .86731 L p .707 .577 .707 r
F P
0 g
s
.6938 .85287 m .69611 .86885 L .70256 .85108 L p .707 .577 .707 r
F P
0 g
s
.70256 .85108 m .70025 .8351 L .6938 .85287 L p .707 .577 .707 r
F P
0 g
s
.49377 .78901 m .49419 .82577 L .49709 .83511 L p .707 .577 .707 r
F P
0 g
s
.49481 .74179 m .49847 .68457 L .50538 .68151 L p .707 .577 .707 r
F P
0 g
s
.50108 .86731 m .50339 .88329 L .51643 .89791 L p .707 .577 .707 r
F P
0 g
s
.69766 .79089 m .69807 .82765 L .69517 .81831 L p .707 .577 .707 r
F P
0 g
s
.69517 .81831 m .69476 .78155 L .69766 .79089 L p .707 .577 .707 r
F P
0 g
s
.50538 .68151 m .50172 .73873 L .49481 .74179 L p .707 .577 .707 r
F P
0 g
s
.49419 .82577 m .49377 .78901 L .50085 .77977 L p .707 .577 .707 r
F P
0 g
s
.50339 .88329 m .50108 .86731 L .49761 .85028 L p .707 .578 .707 r
F P
0 g
s
.49376 .81584 m .49914 .31054 L .45513 .30766 L p .707 .577 .707 r
F P
0 g
s
.50085 .77977 m .50126 .81653 L .49419 .82577 L p .707 .577 .707 r
F P
0 g
s
.50172 .73873 m .50538 .68151 L .52157 .67945 L p .707 .577 .707 r
F P
0 g
s
.52157 .67945 m .51791 .73668 L .50172 .73873 L p .707 .577 .707 r
F P
0 g
s
.50126 .81653 m .50085 .77977 L .51721 .77152 L p .707 .577 .707 r
F P
0 g
s
.51721 .77152 m .51763 .80828 L .50126 .81653 L p .707 .577 .707 r
F P
0 g
s
.51791 .73668 m .52157 .67945 L .54547 .6786 L p .707 .577 .707 r
F P
0 g
s
.54547 .6786 m .54181 .73582 L .51791 .73668 L p .707 .577 .707 r
F P
0 g
s
.51763 .80828 m .51721 .77152 L .54126 .76508 L p .707 .577 .707 r
F P
0 g
s
.54126 .76508 m .54168 .80184 L .51763 .80828 L p .707 .577 .707 r
F P
0 g
s
.57064 .76107 m .57105 .79783 L .54168 .80184 L p .707 .577 .707 r
F P
0 g
s
.52211 .83171 m .51981 .81573 L .54329 .80159 L p .707 .577 .707 r
F P
0 g
s
.54329 .80159 m .5456 .81757 L .52211 .83171 L p .707 .577 .707 r
F P
0 g
s
.49914 .31054 m .49376 .81584 L .5387 .81529 L p .707 .577 .707 r
F P
0 g
s
.5387 .81529 m .54408 .30999 L .49914 .31054 L p .707 .577 .707 r
F P
0 g
s
.69897 .69507 m .69531 .75229 L .68259 .74821 L p .707 .577 .707 r
F P
0 g
s
.68259 .74821 m .68625 .69099 L .69897 .69507 L p .707 .577 .707 r
F P
0 g
s
.54181 .73582 m .54547 .6786 L .57473 .67902 L p .707 .577 .707 r
F P
0 g
s
.57473 .67902 m .57107 .73624 L .54181 .73582 L p .707 .577 .707 r
F P
0 g
s
.57107 .73624 m .57473 .67902 L .60649 .68068 L p .707 .577 .707 r
F P
0 g
s
.54168 .80184 m .54126 .76508 L .57064 .76107 L p .707 .577 .707 r
F P
0 g
s
.60649 .68068 m .60283 .7379 L .57107 .73624 L p .707 .577 .707 r
F P
0 g
s
.57105 .79783 m .57088 .78217 L p .60247 .75989 L .707 .577 .707 r
F P
0 g
s
.57088 .78217 m .57064 .76107 L .58486 .76054 L p .707 .577 .707 r
F P
0 g
s
.58486 .76054 m .60247 .75989 L p .57088 .78217 L .707 .577 .707 r
F P
0 g
s
.5456 .81757 m .54329 .80159 L .56272 .7948 L p .707 .577 .707 r
F P
0 g
s
.56272 .7948 m .57222 .79147 L p .55216 .81114 L .707 .577 .707 r
F P
0 g
s
.5456 .81757 m .56272 .7948 L .55216 .81114 L .707 .577 .707 r
F
.60247 .75989 m .60289 .79665 L .57105 .79783 L p F P
0 g
s
.57453 .80746 m .57222 .79147 L .5948 .78782 L p .707 .577 .707 r
F P
0 g
s
.60289 .79665 m .60269 .7789 L p .63364 .76165 L .707 .577 .707 r
F P
0 g
s
.5948 .78782 m .60377 .78637 L p .58256 .80167 L .707 .577 .707 r
F P
0 g
s
.57453 .80746 m .5948 .78782 L .58256 .80167 L .707 .577 .707 r
F
.60269 .7789 m .60247 .75989 L .61868 .7608 L p F P
0 g
s
.61868 .7608 m .63364 .76165 L p .60269 .7789 L .707 .577 .707 r
F P
0 g
s
.57222 .79147 m .57453 .80746 L .5456 .81757 L p .707 .577 .707 r
F P
0 g
s
.63364 .76165 m .63406 .79841 L .60289 .79665 L p .707 .577 .707 r
F P
0 g
s
.60377 .78637 m .60608 .80236 L .57453 .80746 L p .707 .577 .707 r
F P
0 g
s
.54408 .30999 m .5387 .81529 L .58018 .81138 L p .707 .577 .707 r
F P
0 g
s
.58018 .81138 m .58555 .30608 L .54408 .30999 L p .707 .577 .707 r
F P
0 g
s
.70025 .8351 m .70256 .85108 L .6991 .83405 L p .707 .578 .707 r
F P
0 g
s
.6991 .83405 m .69679 .81806 L .70025 .8351 L p .707 .578 .707 r
F P
0 g
s
.24733 .72311 m .25099 .66589 L .21984 .66315 L p .707 .577 .707 r
F P
0 g
s
.25099 .66589 m .24733 .72311 L .27909 .72477 L p .707 .577 .707 r
F P
0 g
s
.27909 .72477 m .28275 .66755 L .25099 .66589 L p .707 .577 .707 r
F P
0 g
s
.44975 .81297 m .45513 .30766 L .41636 .30165 L p .707 .577 .707 r
F P
0 g
s
.45513 .30766 m .44975 .81297 L .49376 .81584 L p .707 .577 .707 r
F P
0 g
s
.49761 .85028 m .49992 .86626 L .50339 .88329 L p .707 .578 .707 r
F P
0 g
s
.28275 .66755 m .27909 .72477 L .30834 .7252 L p .707 .577 .707 r
F P
0 g
s
.30834 .7252 m .312 .66798 L .28275 .66755 L p .707 .577 .707 r
F P
0 g
s
.21984 .66315 m .21618 .72037 L .24733 .72311 L p .707 .577 .707 r
F P
0 g
s
.21618 .72037 m .21984 .66315 L .19236 .6596 L p .707 .577 .707 r
F P
0 g
s
.69476 .78155 m .69517 .81831 L .68258 .8098 L p .707 .577 .707 r
F P
0 g
s
.68258 .8098 m .68216 .77304 L .69476 .78155 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19236 .6596 m .1887 .71682 L .21618 .72037 L p .707 .577 .707 r
F P
0 g
s
.63763 .68342 m .63397 .74064 L .60283 .7379 L p .707 .577 .707 r
F P
0 g
s
.60283 .7379 m .60649 .68068 L .63763 .68342 L p .707 .577 .707 r
F P
0 g
s
.6611 .76618 m .66152 .80294 L .63406 .79841 L p .707 .577 .707 r
F P
0 g
s
.63406 .79841 m .63385 .77993 L p .6611 .76618 L .707 .577 .707 r
F P
0 g
s
.63484 .78678 m .63715 .80277 L .61134 .80243 L p .707 .577 .707 r
F P
0 g
s
.61134 .80243 m .60608 .80236 L p .61772 .79605 L .707 .577 .707 r
F P
0 g
s
.61772 .79605 m .63484 .78678 L .61134 .80243 L .707 .577 .707 r
F
.63385 .77993 m .63364 .76165 L .64953 .76427 L p F P
0 g
s
.64953 .76427 m .6611 .76618 L p .63385 .77993 L .707 .577 .707 r
F P
0 g
s
.60608 .80236 m .60377 .78637 L .63484 .78678 L p .707 .577 .707 r
F P
0 g
s
.58555 .30608 m .58018 .81138 L .61413 .80448 L p .707 .577 .707 r
F P
0 g
s
.61413 .80448 m .61951 .29918 L .58555 .30608 L p .707 .577 .707 r
F P
0 g
s
.312 .66798 m .30834 .7252 L .33224 .72434 L p .707 .577 .707 r
F P
0 g
s
.33224 .72434 m .3359 .66712 L .312 .66798 L p .707 .577 .707 r
F P
0 g
s
.49992 .86626 m .49761 .85028 L .50407 .83251 L p .707 .577 .707 r
F P
0 g
s
.24636 .81996 m .24595 .7832 L .21478 .78144 L p .707 .577 .707 r
F P
0 g
s
.24595 .7832 m .24636 .81996 L .27819 .81878 L p .707 .577 .707 r
F P
0 g
s
.27819 .81878 m .27778 .78202 L .24595 .7832 L p .707 .577 .707 r
F P
0 g
s
.27778 .78202 m .27819 .81878 L .30757 .81477 L p .707 .577 .707 r
F P
0 g
s
.30757 .81477 m .30716 .77801 L .27778 .78202 L p .707 .577 .707 r
F P
0 g
s
.1887 .71682 m .19236 .6596 L .17122 .65558 L p .707 .577 .707 r
F P
0 g
s
.69679 .81806 m .6991 .83405 L .68605 .81943 L p .707 .577 .707 r
F P
0 g
s
.68605 .81943 m .68374 .80344 L .69679 .81806 L p .707 .577 .707 r
F P
0 g
s
.41099 .80695 m .41636 .30165 L .38664 .29309 L p .707 .577 .707 r
F P
0 g
s
.41636 .30165 m .41099 .80695 L .44975 .81297 L p .707 .577 .707 r
F P
0 g
s
.68625 .69099 m .68259 .74821 L .66146 .7442 L p .707 .577 .707 r
F P
0 g
s
.66146 .7442 m .66512 .68698 L .68625 .69099 L p .707 .577 .707 r
F P
0 g
s
.21519 .8182 m .21478 .78144 L .18732 .77691 L p .707 .577 .707 r
F P
0 g
s
.21478 .78144 m .21519 .8182 L .24636 .81996 L p .707 .577 .707 r
F P
0 g
s
.17122 .65558 m .16756 .7128 L .1887 .71682 L p .707 .577 .707 r
F P
0 g
s
.50407 .83251 m .50637 .84849 L .49992 .86626 L p .707 .577 .707 r
F P
0 g
s
.30716 .77801 m .30757 .81477 L .33162 .80833 L p .707 .577 .707 r
F P
0 g
s
.33162 .80833 m .33121 .77156 L .30716 .77801 L p .707 .577 .707 r
F P
0 g
s
.68216 .77304 m .68258 .8098 L .66152 .80294 L p .707 .577 .707 r
F P
0 g
s
.66152 .80294 m .66132 .78519 L p .68216 .77304 L .707 .577 .707 r
F P
0 g
s
.6624 .79267 m .66471 .80865 L .64437 .80431 L p .707 .577 .707 r
F P
0 g
s
.64437 .80431 m .63715 .80277 L p .65046 .79744 L .707 .577 .707 r
F P
0 g
s
.65046 .79744 m .6624 .79267 L .64437 .80431 L .707 .577 .707 r
F
.66132 .78519 m .6611 .76618 L .67434 .77049 L p F P
0 g
s
.67434 .77049 m .68216 .77304 L p .66132 .78519 L .707 .577 .707 r
F P
0 g
s
.3359 .66712 m .33224 .72434 L .34844 .72228 L p .707 .577 .707 r
F P
0 g
s
.34844 .72228 m .3521 .66506 L .3359 .66712 L p .707 .577 .707 r
F P
0 g
s
.18732 .77691 m .18773 .81367 L .21519 .8182 L p .707 .577 .707 r
F P
0 g
s
.18773 .81367 m .18732 .77691 L .16626 .77005 L p .707 .577 .707 r
F P
0 g
s
.66512 .68698 m .66146 .7442 L .63397 .74064 L p .707 .577 .707 r
F P
0 g
s
.63397 .74064 m .63763 .68342 L .66512 .68698 L p .707 .577 .707 r
F P
0 g
s
.63715 .80277 m .63484 .78678 L .6624 .79267 L p .707 .577 .707 r
F P
0 g
s
.61951 .29918 m .61413 .80448 L .63723 .79528 L p .707 .577 .707 r
F P
0 g
s
.63723 .79528 m .64261 .28998 L .61951 .29918 L p .707 .577 .707 r
F P
0 g
s
.50637 .84849 m .50407 .83251 L .51981 .81573 L p .707 .577 .707 r
F P
0 g
s
.16756 .7128 m .17122 .65558 L .15851 .6515 L p .707 .577 .707 r
F P
0 g
s
.68374 .80344 m .68605 .81943 L .66471 .80865 L p .707 .577 .707 r
F P
0 g
s
.66471 .80865 m .6624 .79267 L .68374 .80344 L p .707 .577 .707 r
F P
0 g
s
.15851 .6515 m .15485 .70872 L .16756 .7128 L p .707 .577 .707 r
F P
0 g
s
.16626 .77005 m .16667 .80681 L .18773 .81367 L p .707 .577 .707 r
F P
0 g
s
.33121 .77156 m .33162 .80833 L .34799 .80008 L p .707 .577 .707 r
F P
0 g
s
.34799 .80008 m .34757 .76332 L .33121 .77156 L p .707 .577 .707 r
F P
0 g
s
.51981 .81573 m .52211 .83171 L .50637 .84849 L p .707 .577 .707 r
F P
0 g
s
.25339 .87817 m .25109 .86219 L .22001 .86178 L p .707 .577 .707 r
F P
0 g
s
.25109 .86219 m .25339 .87817 L .28494 .87307 L p .707 .577 .707 r
F P
0 g
s
.28494 .87307 m .28263 .85708 L .25109 .86219 L p .707 .577 .707 r
F P
0 g
s
.28263 .85708 m .28494 .87307 L .31387 .86295 L p .707 .577 .707 r
F P
0 g
s
.31387 .86295 m .31156 .84697 L .28263 .85708 L p .707 .577 .707 r
F P
0 g
s
.38126 .79839 m .38664 .29309 L .36885 .28282 L p .707 .577 .707 r
F P
0 g
s
.38664 .29309 m .38126 .79839 L .41099 .80695 L p .707 .577 .707 r
F P
0 g
s
.22232 .87776 m .22001 .86178 L .19246 .85589 L p .707 .577 .707 r
F P
0 g
s
.22001 .86178 m .22232 .87776 L .25339 .87817 L p .707 .577 .707 r
F P
0 g
s
.3521 .66506 m .34844 .72228 L .35535 .71923 L p .707 .577 .707 r
F P
0 g
s
.35535 .71923 m .35901 .66201 L .3521 .66506 L p .707 .577 .707 r
F P
0 g
s
.31156 .84697 m .31387 .86295 L .33736 .84882 L p .707 .577 .707 r
F P
0 g
s
.33736 .84882 m .33505 .83283 L .31156 .84697 L p .707 .577 .707 r
F P
0 g
s
.16667 .80681 m .16626 .77005 L .15366 .76153 L p .707 .577 .707 r
F P
0 g
s
.19246 .85589 m .19476 .87188 L .22232 .87776 L p .707 .577 .707 r
F P
0 g
s
.15485 .70872 m .15851 .6515 L .15546 .64775 L p .707 .577 .707 r
F P
0 g
s
.15366 .76153 m .15408 .79829 L .16667 .80681 L p .707 .577 .707 r
F P
0 g
s
.19476 .87188 m .19246 .85589 L .17111 .84512 L p .707 .577 .707 r
F P
0 g
s
.64261 .28998 m .63723 .79528 L .64722 .78467 L p .707 .577 .707 r
F P
0 g
s
.6471 .77154 m .65215 .31998 L .64261 .28998 L .707 .577 .707 r
F
.6526 .27937 m .652 .28001 L p .65215 .31998 L F P
0 g
s
.652 .28001 m .64261 .28998 L p .65215 .31998 L .707 .577 .707 r
F P
0 g
s
.66794 .6791 m .66753 .64234 L .65333 .63771 L p .707 .577 .707 r
F P
0 g
s
.64744 .76398 m .65215 .32148 L p .6471 .77154 L .707 .577 .707 r
F P
0 g
s
.65215 .32148 m .6526 .27937 L p .65215 .31998 L .707 .577 .707 r
F P
0 g
s
.65215 .32148 m .65215 .31998 L .6471 .77154 L .707 .577 .707 r
F
.64722 .78467 m .64744 .76398 L p .6471 .77154 L F P
0 g
s
.6526 .27937 m .64789 .72241 L p .646 .62375 L .707 .577 .707 r
F P
0 g
s
.6461 .63523 m .63388 .62696 L p .64536 .66691 L .707 .577 .707 r
F P
0 g
s
.64789 .72241 m .64722 .78467 L p .646 .62375 L .707 .577 .707 r
F P
0 g
s
.64689 .67224 m .64647 .63548 L .6461 .63523 L p .707 .577 .707 r
F P
0 g
s
.6444 .70739 m .64609 .63569 L .64722 .78467 L .707 .577 .707 r
F
.64689 .67224 m .6461 .63523 L .64536 .66691 L F
.64722 .78467 m .64313 .77369 L p .6444 .70739 L F P
0 g
s
.63388 .62696 m .63429 .66372 L .64526 .67114 L p .707 .577 .707 r
F P
0 g
s
.64526 .67114 m .64689 .67224 L p .64536 .66691 L .707 .577 .707 r
F P
0 g
s
.64536 .66691 m .63388 .62696 L .64526 .67114 L .707 .577 .707 r
F
.64851 .26839 m .6462 .48544 L p .63412 .5758 L F P
0 g
s
.6462 .48544 m .64518 .5808 L p .63701 .57711 L .707 .577 .707 r
F P
0 g
s
.63412 .5758 m .6462 .48544 L .63701 .57711 L .707 .577 .707 r
F
.63506 .60761 m .63701 .57711 L p .63518 .59536 L F P
0 g
s
.64547 .5961 m .64518 .5808 L .64307 .57985 L .707 .577 .707 r
F
.63872 .55039 m .63506 .60761 L .64576 .61105 L p F P
0 g
s
.64851 .26839 m .6526 .27937 L p .646 .62375 L .707 .577 .707 r
F P
0 g
s
.64545 .59493 m .64851 .26839 L .646 .62375 L .707 .577 .707 r
F
.64576 .61105 m .64778 .6117 L p .64547 .5961 L F P
0 g
s
.64547 .5961 m .63872 .55039 L .64576 .61105 L .707 .577 .707 r
F
.6444 .70739 m .64545 .59493 L .646 .62375 L F
.63408 .6064 m .63506 .60761 L p .63518 .59536 L F P
0 g
s
.64518 .5808 m .64313 .77369 L p .63507 .59653 L .707 .577 .707 r
F P
0 g
s
.63412 .5758 m .63701 .57711 L .63507 .59653 L .707 .577 .707 r
F
.63701 .57711 m .64518 .5808 L .63507 .59653 L F
.64313 .77369 m .63575 .76943 L p .63412 .5758 L F P
0 g
s
.63575 .76943 m .62535 .76342 L p .63226 .61574 L .707 .577 .707 r
F P
0 g
s
.63429 .66372 m .63388 .62696 L .6324 .62223 L p .707 .577 .707 r
F P
0 g
s
.63429 .66372 m .6324 .62223 L .63291 .64456 L .707 .577 .707 r
F
.62535 .76342 m .62862 .45598 L p .63226 .61574 L F P
0 g
s
.63097 .61763 m .63139 .65439 L .63327 .66045 L p .707 .577 .707 r
F P
0 g
s
.63327 .66045 m .63429 .66372 L p .63291 .64456 L .707 .577 .707 r
F P
0 g
s
.63291 .64456 m .63097 .61763 L .63327 .66045 L .707 .577 .707 r
F
.63072 .25811 m .64851 .26839 L p .63226 .61574 L F P
0 g
s
.62862 .45598 m .63072 .25811 L p .63226 .61574 L .707 .577 .707 r
F P
0 g
s
.63226 .61574 m .63412 .5758 L .63575 .76943 L .707 .577 .707 r
F
.6324 .62223 m .63097 .61763 L p .63291 .64456 L F P
0 g
s
.63567 .54664 m .63201 .60386 L .63408 .6064 L p .707 .577 .707 r
F P
0 g
s
.63518 .59536 m .63567 .54664 L .63408 .6064 L .707 .577 .707 r
F
.63872 .55039 m .63567 .54664 L p .63518 .59536 L F P
0 g
s
.63701 .57711 m .63872 .55039 L p .63518 .59536 L .707 .577 .707 r
F P
0 g
s
.64464 .55229 m .63872 .55039 L p .64307 .57985 L .707 .577 .707 r
F P
0 g
s
.64518 .5808 m .64464 .55229 L .64307 .57985 L .707 .577 .707 r
F
.64313 .77369 m .64337 .75092 L p .6444 .70739 L F P
0 g
s
.64337 .75092 m .64393 .69797 L p .6444 .70739 L .707 .577 .707 r
F P
0 g
s
.65363 .73844 m .65132 .72246 L .64215 .71218 L p .707 .577 .707 r
F P
0 g
s
.64215 .71218 m .63828 .70784 L p .64181 .71488 L .707 .577 .707 r
F P
0 g
s
.65363 .73844 m .64215 .71218 L .64181 .71488 L .707 .577 .707 r
F
.64393 .69797 m .64851 .26839 L p .64453 .6932 L F P
0 g
s
.64393 .69797 m .64453 .6932 L .6444 .70739 L .707 .577 .707 r
F
.6444 .70739 m .646 .62375 L .64609 .63569 L F
.64778 .6117 m .65144 .55447 L .64464 .55229 L p F P
0 g
s
.64778 .6117 m .64464 .55229 L .64547 .5961 L .707 .577 .707 r
F
.64647 .63548 m .64689 .67224 L .65347 .67438 L p F P
0 g
s
.65347 .67438 m .66794 .6791 L p .65338 .6495 L .707 .577 .707 r
F P
0 g
s
.65338 .6495 m .64647 .63548 L .65347 .67438 L .707 .577 .707 r
F
.65333 .63771 m .64647 .63548 L p .65338 .6495 L F P
0 g
s
.66794 .6791 m .65333 .63771 L .65338 .6495 L .707 .577 .707 r
F
.65144 .55447 m .64778 .6117 L .65429 .61293 L p F P
0 g
s
.65429 .61293 m .66891 .61571 L p .65619 .57112 L .707 .577 .707 r
F P
0 g
s
.65619 .57112 m .65144 .55447 L .65429 .61293 L .707 .577 .707 r
F
.34757 .76332 m .34799 .80008 L .35506 .79083 L p F P
0 g
s
.35506 .79083 m .35465 .75407 L .34757 .76332 L p .707 .577 .707 r
F P
0 g
s
.33505 .83283 m .33736 .84882 L .3531 .83204 L p .707 .577 .707 r
F P
0 g
s
.3531 .83204 m .35079 .81605 L .33505 .83283 L p .707 .577 .707 r
F P
0 g
s
.15546 .64775 m .1518 .70497 L .15485 .70872 L p .707 .577 .707 r
F P
0 g
s
.17111 .84512 m .17342 .8611 L .19476 .87188 L p .707 .577 .707 r
F P
0 g
s
.15408 .79829 m .15366 .76153 L .15076 .7522 L p .707 .577 .707 r
F P
0 g
s
.35901 .66201 m .35535 .71923 L .3523 .71548 L p .707 .577 .707 r
F P
0 g
s
.3523 .71548 m .35596 .65825 L .35901 .66201 L p .707 .577 .707 r
F P
0 g
s
.36348 .78812 m .36885 .28282 L .36476 .27184 L p .707 .577 .707 r
F P
0 g
s
.36885 .28282 m .36348 .78812 L .38126 .79839 L p .707 .577 .707 r
F P
0 g
s
.17342 .8611 m .17111 .84512 L .15807 .83049 L p .707 .577 .707 r
F P
0 g
s
.35079 .81605 m .3531 .83204 L .35955 .81426 L p .707 .577 .707 r
F P
0 g
s
.35955 .81426 m .35724 .79828 L .35079 .81605 L p .707 .577 .707 r
F P
0 g
s
.15076 .7522 m .15118 .78896 L .15408 .79829 L p .707 .577 .707 r
F P
0 g
s
.1518 .70497 m .15546 .64775 L .16237 .6447 L p .707 .577 .707 r
F P
0 g
s
.15807 .83049 m .16038 .84648 L .17342 .8611 L p .707 .577 .707 r
F P
0 g
s
.35465 .75407 m .35506 .79083 L .35216 .7815 L p .707 .577 .707 r
F P
0 g
s
.35216 .7815 m .35175 .74474 L .35465 .75407 L p .707 .577 .707 r
F P
0 g
s
.16237 .6447 m .15871 .70192 L .1518 .70497 L p .707 .577 .707 r
F P
0 g
s
.15118 .78896 m .15076 .7522 L .15784 .74295 L p .707 .577 .707 r
F P
0 g
s
.16038 .84648 m .15807 .83049 L .1546 .81346 L p .707 .578 .707 r
F P
0 g
s
.35596 .65825 m .3523 .71548 L .33958 .71139 L p .707 .577 .707 r
F P
0 g
s
.33958 .71139 m .34324 .65417 L .35596 .65825 L p .707 .577 .707 r
F P
0 g
s
.35724 .79828 m .35955 .81426 L .35609 .79723 L p .707 .578 .707 r
F P
0 g
s
.35609 .79723 m .35378 .78125 L .35724 .79828 L p .707 .578 .707 r
F P
0 g
s
.1546 .81346 m .15691 .82945 L .16038 .84648 L p .707 .578 .707 r
F P
0 g
s
.15784 .74295 m .15825 .77971 L .15118 .78896 L p .707 .577 .707 r
F P
0 g
s
.15871 .70192 m .16237 .6447 L .17856 .64264 L p .707 .577 .707 r
F P
0 g
s
.35175 .74474 m .35216 .7815 L .33957 .77298 L p .707 .577 .707 r
F P
0 g
s
.33957 .77298 m .33915 .73622 L .35175 .74474 L p .707 .577 .707 r
F P
0 g
s
.36476 .27184 m .35938 .77714 L .36348 .78812 L p .707 .577 .707 r
F P
0 g
s
.35938 .77714 m .36476 .27184 L .37475 .26123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17856 .64264 m .1749 .69986 L .15871 .70192 L p .707 .577 .707 r
F P
0 g
s
.15691 .82945 m .1546 .81346 L .16106 .79569 L p .707 .577 .707 r
F P
0 g
s
.15825 .77971 m .15784 .74295 L .1742 .73471 L p .707 .577 .707 r
F P
0 g
s
.35378 .78125 m .35609 .79723 L .34304 .78261 L p .707 .577 .707 r
F P
0 g
s
.34304 .78261 m .34073 .76663 L .35378 .78125 L p .707 .577 .707 r
F P
0 g
s
.34324 .65417 m .33958 .71139 L .31845 .70738 L p .707 .577 .707 r
F P
0 g
s
.31845 .70738 m .32211 .65016 L .34324 .65417 L p .707 .577 .707 r
F P
0 g
s
.16106 .79569 m .16336 .81167 L .15691 .82945 L p .707 .577 .707 r
F P
0 g
s
.1742 .73471 m .17462 .77147 L .15825 .77971 L p .707 .577 .707 r
F P
0 g
s
.1749 .69986 m .17856 .64264 L .20246 .64178 L p .707 .577 .707 r
F P
0 g
s
.33915 .73622 m .33957 .77298 L .31851 .76612 L p .707 .577 .707 r
F P
0 g
s
.31851 .76612 m .31831 .74837 L p .33915 .73622 L .707 .577 .707 r
F P
0 g
s
.31809 .72936 m .31851 .76612 L .29105 .76159 L p .707 .577 .707 r
F P
0 g
s
.31939 .75585 m .3217 .77183 L .30136 .76749 L p .707 .577 .707 r
F P
0 g
s
.30136 .76749 m .29414 .76595 L p .30745 .76063 L .707 .577 .707 r
F P
0 g
s
.30745 .76063 m .31939 .75585 L .30136 .76749 L .707 .577 .707 r
F
.31831 .74837 m .31809 .72936 L .33133 .73368 L p F P
0 g
s
.33133 .73368 m .33915 .73622 L p .31831 .74837 L .707 .577 .707 r
F P
0 g
s
.20246 .64178 m .1988 .699 L .1749 .69986 L p .707 .577 .707 r
F P
0 g
s
.16336 .81167 m .16106 .79569 L .1768 .77891 L p .707 .577 .707 r
F P
0 g
s
.17462 .77147 m .1742 .73471 L .19825 .72826 L p .707 .577 .707 r
F P
0 g
s
.32211 .65016 m .31845 .70738 L .29096 .70383 L p .707 .577 .707 r
F P
0 g
s
.29096 .70383 m .29462 .64661 L .32211 .65016 L p .707 .577 .707 r
F P
0 g
s
.34073 .76663 m .34304 .78261 L .3217 .77183 L p .707 .577 .707 r
F P
0 g
s
.3217 .77183 m .31939 .75585 L .34073 .76663 L p .707 .577 .707 r
F P
0 g
s
.36937 .76653 m .37475 .26123 L .39785 .25202 L p .707 .577 .707 r
F P
0 g
s
.37475 .26123 m .36937 .76653 L .35938 .77714 L p .707 .577 .707 r
F P
0 g
s
.72754 .622 m .7312 .56478 L .70006 .56204 L p .707 .577 .707 r
F P
0 g
s
.7312 .56478 m .72754 .622 L .7593 .62366 L p .707 .577 .707 r
F P
0 g
s
.7593 .62366 m .76296 .56644 L .7312 .56478 L p .707 .577 .707 r
F P
0 g
s
.1988 .699 m .20246 .64178 L .23172 .6422 L p .707 .577 .707 r
F P
0 g
s
.1768 .77891 m .1791 .7949 L .16336 .81167 L p .707 .577 .707 r
F P
0 g
s
.76296 .56644 m .7593 .62366 L .78856 .62409 L p .707 .577 .707 r
F P
0 g
s
.78856 .62409 m .79222 .56687 L .76296 .56644 L p .707 .577 .707 r
F P
0 g
s
.19825 .72826 m .19867 .76502 L .17462 .77147 L p .707 .577 .707 r
F P
0 g
s
.29105 .76159 m .29084 .74312 L p .31809 .72936 L .707 .577 .707 r
F P
0 g
s
.29064 .72483 m .29105 .76159 L .25988 .75983 L p .707 .577 .707 r
F P
0 g
s
.29183 .74997 m .29414 .76595 L .26833 .76561 L p .707 .577 .707 r
F P
0 g
s
.26833 .76561 m .26307 .76554 L p .27471 .75924 L .707 .577 .707 r
F P
0 g
s
.27471 .75924 m .29183 .74997 L .26833 .76561 L .707 .577 .707 r
F
.29084 .74312 m .29064 .72483 L .30652 .72745 L p F P
0 g
s
.30652 .72745 m .31809 .72936 L p .29084 .74312 L .707 .577 .707 r
F P
0 g
s
.70006 .56204 m .6964 .61926 L .72754 .622 L p .707 .577 .707 r
F P
0 g
s
.6964 .61926 m .70006 .56204 L .67257 .55849 L p .707 .577 .707 r
F P
0 g
s
.23172 .6422 m .22806 .69942 L .1988 .699 L p .707 .577 .707 r
F P
0 g
s
.72657 .68539 m .72616 .64863 L .69499 .64687 L p .707 .577 .707 r
F P
0 g
s
.72616 .64863 m .72657 .68539 L .75841 .68421 L p .707 .577 .707 r
F P
0 g
s
.75841 .68421 m .75799 .64745 L .72616 .64863 L p .707 .577 .707 r
F P
0 g
s
.29462 .64661 m .29096 .70383 L .25982 .70109 L p .707 .577 .707 r
F P
0 g
s
.25982 .70109 m .26348 .64387 L .29462 .64661 L p .707 .577 .707 r
F P
0 g
s
.75799 .64745 m .75841 .68421 L .78779 .6802 L p .707 .577 .707 r
F P
0 g
s
.78779 .6802 m .78737 .64344 L .75799 .64745 L p .707 .577 .707 r
F P
0 g
s
.67257 .55849 m .66891 .61571 L .6964 .61926 L p .707 .577 .707 r
F P
0 g
s
.22763 .72425 m .22805 .76101 L .19867 .76502 L p .707 .577 .707 r
F P
0 g
s
.1791 .7949 m .1768 .77891 L .20028 .76478 L p .707 .577 .707 r
F P
0 g
s
.22806 .69942 m .23172 .6422 L .26348 .64387 L p .707 .577 .707 r
F P
0 g
s
.19867 .76502 m .19825 .72826 L .22763 .72425 L p .707 .577 .707 r
F P
0 g
s
.79222 .56687 m .78856 .62409 L .81246 .62323 L p .707 .577 .707 r
F P
0 g
s
.81246 .62323 m .81612 .56601 L .79222 .56687 L p .707 .577 .707 r
F P
0 g
s
.29414 .76595 m .29183 .74997 L .31939 .75585 L p .707 .577 .707 r
F P
0 g
s
.6954 .68363 m .69499 .64687 L .66753 .64234 L p .707 .577 .707 r
F P
0 g
s
.69499 .64687 m .6954 .68363 L .72657 .68539 L p .707 .577 .707 r
F P
0 g
s
.26348 .64387 m .25982 .70109 L .22806 .69942 L p .707 .577 .707 r
F P
0 g
s
.63072 .25811 m .62535 .76342 L .59562 .75486 L p .707 .577 .707 r
F P
0 g
s
.59562 .75486 m .601 .24955 L .63072 .25811 L p .707 .577 .707 r
F P
0 g
s
.22805 .76101 m .22787 .74536 L p .25946 .72307 L .707 .577 .707 r
F P
0 g
s
.22787 .74536 m .22763 .72425 L .24185 .72372 L p .707 .577 .707 r
F P
0 g
s
.24185 .72372 m .25946 .72307 L p .22787 .74536 L .707 .577 .707 r
F P
0 g
s
.20259 .78076 m .20028 .76478 L .21971 .75798 L p .707 .577 .707 r
F P
0 g
s
.21971 .75798 m .22921 .75466 L p .20915 .77433 L .707 .577 .707 r
F P
0 g
s
.20259 .78076 m .21971 .75798 L .20915 .77433 L .707 .577 .707 r
F
.25946 .72307 m .25988 .75983 L .22805 .76101 L p F P
0 g
s
.23152 .77064 m .22921 .75466 L .25179 .75101 L p .707 .577 .707 r
F P
0 g
s
.25988 .75983 m .25968 .74208 L p .29064 .72483 L .707 .577 .707 r
F P
0 g
s
.25179 .75101 m .26076 .74956 L p .23955 .76485 L .707 .577 .707 r
F P
0 g
s
.23152 .77064 m .25179 .75101 L .23955 .76485 L .707 .577 .707 r
F
.25968 .74208 m .25946 .72307 L .27567 .72399 L p F P
0 g
s
.27567 .72399 m .29064 .72483 L p .25968 .74208 L .707 .577 .707 r
F P
0 g
s
.66891 .61571 m .67257 .55849 L .65144 .55447 L p .707 .577 .707 r
F P
0 g
s
.20028 .76478 m .20259 .78076 L .1791 .7949 L p .707 .577 .707 r
F P
0 g
s
.78737 .64344 m .78779 .6802 L .81184 .67376 L p .707 .577 .707 r
F P
0 g
s
.81184 .67376 m .81142 .63699 L .78737 .64344 L p .707 .577 .707 r
F P
0 g
s
.66753 .64234 m .66794 .6791 L .6954 .68363 L p .707 .577 .707 r
F P
0 g
s
.26307 .76554 m .26076 .74956 L .29183 .74997 L p .707 .577 .707 r
F P
0 g
s
.36937 .76653 m .39686 .27003 L .3927 .73664 L .707 .577 .707 r
F
.39785 .25202 m .39741 .29414 L p .39686 .27003 L F P
0 g
s
.39741 .29414 m .3927 .73664 L p .39686 .27003 L .707 .577 .707 r
F P
0 g
s
.39248 .75733 m .39785 .25202 L .43181 .24513 L p .707 .577 .707 r
F P
0 g
s
.42643 .75043 m .39248 .75733 L p .39901 .67222 L .707 .577 .707 r
F P
0 g
s
.43181 .24513 m .42848 .55754 L p .39901 .67222 L .707 .577 .707 r
F P
0 g
s
.42093 .58692 m .44555 .58727 L p .43228 .55739 L .707 .577 .707 r
F P
0 g
s
.42848 .55754 m .43181 .24513 L p .44423 .5569 L .707 .577 .707 r
F P
0 g
s
.43228 .55739 m .4299 .55203 L .42848 .55754 L .707 .577 .707 r
F
.43228 .55739 m .42848 .55754 L .42093 .58692 L F
.43181 .24513 m .47328 .24122 L p .44423 .5569 L F P
0 g
s
.47328 .24122 m .46993 .55586 L p .4475 .55677 L .707 .577 .707 r
F P
0 g
s
.44423 .5569 m .44531 .54525 L .4475 .55677 L .707 .577 .707 r
F
.44531 .54525 m .47328 .24122 L .4475 .55677 L F
.4475 .55677 m .44555 .58727 L .45325 .587 L p F P
0 g
s
.44555 .58727 m .4475 .55677 L p .43228 .55739 L .707 .577 .707 r
F P
0 g
s
.46993 .55586 m .4679 .74652 L p .45385 .63391 L .707 .577 .707 r
F P
0 g
s
.45509 .61992 m .44436 .60662 L .45321 .64113 L .707 .577 .707 r
F
.46076 .55623 m .46993 .55586 L .45385 .63391 L F
.46883 .63694 m .46841 .60018 L .45656 .60335 L p F P
0 g
s
.45656 .60335 m .44436 .60662 L p .45509 .61992 L .707 .577 .707 r
F P
0 g
s
.46883 .63694 m .45656 .60335 L .45509 .61992 L .707 .577 .707 r
F
.44436 .60662 m .44478 .64338 L .45321 .64113 L p F P
0 g
s
.39901 .67222 m .40526 .64789 L .42643 .75043 L .707 .577 .707 r
F
.40526 .64789 m .41558 .60773 L .42 .66588 L F
.40526 .64789 m .42 .66588 L .42643 .75043 L F
.4192 .64687 m .44478 .64338 L p .41595 .6117 L F P
0 g
s
.42667 .72766 m .42643 .75043 L p .42 .66588 L .707 .577 .707 r
F P
0 g
s
.41558 .60773 m .42108 .6672 L .42 .66588 L .707 .577 .707 r
F
.42108 .6672 m .42667 .72766 L .42 .66588 L F
.44478 .64338 m .44436 .60662 L .41498 .61063 L p F P
0 g
s
.43193 .72706 m .44423 .5569 L .45385 .63391 L .707 .577 .707 r
F
.42643 .75043 m .42854 .72745 L .43193 .72706 L F
.42854 .72745 m .44423 .5569 L .43193 .72706 L F
.4679 .74652 m .44363 .74881 L p .45385 .63391 L F P
0 g
s
.44363 .74881 m .42643 .75043 L p .45385 .63391 L .707 .577 .707 r
F P
0 g
s
.45108 .70348 m .44877 .6875 L .44018 .6905 L p .707 .577 .707 r
F P
0 g
s
.42848 .55754 m .42723 .67471 L p .41558 .60773 L .707 .577 .707 r
F P
0 g
s
.42723 .67471 m .42667 .72766 L p .42108 .6672 L .707 .577 .707 r
F P
0 g
s
.41558 .60773 m .42723 .67471 L .42108 .6672 L .707 .577 .707 r
F
.42643 .75043 m .42848 .55754 L p .44423 .5569 L F P
0 g
s
.44018 .6905 m .41984 .69761 L p .45076 .70342 L .707 .577 .707 r
F P
0 g
s
.45108 .70348 m .44018 .6905 L .45076 .70342 L .707 .577 .707 r
F
.41984 .69761 m .42214 .7136 L .45087 .70355 L p F P
0 g
s
.45087 .70355 m .45108 .70348 L p .45076 .70342 L .707 .577 .707 r
F P
0 g
s
.45076 .70342 m .41984 .69761 L .45087 .70355 L .707 .577 .707 r
F
.41498 .61063 m .4154 .64739 L .4192 .64687 L p F P
0 g
s
.41595 .6117 m .41498 .61063 L .4192 .64687 L .707 .577 .707 r
F
.44423 .5569 m .46076 .55623 L .45385 .63391 L F
.45321 .64113 m .46883 .63694 L p .45509 .61992 L F P
0 g
s
.44921 .53005 m .4475 .55677 L p .46945 .58641 L .707 .577 .707 r
F P
0 g
s
.45325 .587 m .46945 .58641 L p .4475 .55677 L .707 .577 .707 r
F P
0 g
s
.44921 .53005 m .41995 .52963 L p .43228 .55739 L .707 .577 .707 r
F P
0 g
s
.4475 .55677 m .44921 .53005 L p .43228 .55739 L .707 .577 .707 r
F P
0 g
s
.41995 .52963 m .41629 .58685 L .42093 .58692 L p .707 .577 .707 r
F P
0 g
s
.4299 .55203 m .41995 .52963 L .42093 .58692 L .707 .577 .707 r
F
.38315 .61181 m .38356 .64857 L .40545 .64776 L p F P
0 g
s
.40545 .64776 m .4154 .64739 L p .40518 .63612 L .707 .577 .707 r
F P
0 g
s
.40518 .63612 m .38315 .61181 L .40545 .64776 L .707 .577 .707 r
F
.38819 .52796 m .38453 .58519 L .4065 .58634 L p F P
0 g
s
.4065 .58634 m .41629 .58685 L p .40804 .56956 L .707 .577 .707 r
F P
0 g
s
.40804 .56956 m .38819 .52796 L .4065 .58634 L .707 .577 .707 r
F
.3927 .73664 m .39248 .75733 L .39073 .75802 L p F P
0 g
s
.39073 .75802 m .36937 .76653 L p .3927 .73664 L .707 .577 .707 r
F P
0 g
s
.81612 .56601 m .81246 .62323 L .82865 .62117 L p .707 .577 .707 r
F P
0 g
s
.82865 .62117 m .83231 .56395 L .81612 .56601 L p .707 .577 .707 r
F P
0 g
s
.22921 .75466 m .23152 .77064 L .20259 .78076 L p .707 .577 .707 r
F P
0 g
s
.26076 .74956 m .26307 .76554 L .23152 .77064 L p .707 .577 .707 r
F P
0 g
s
.81142 .63699 m .81184 .67376 L .8282 .66551 L p .707 .577 .707 r
F P
0 g
s
.8282 .66551 m .82778 .62875 L .81142 .63699 L p .707 .577 .707 r
F P
0 g
s
.73361 .75551 m .7313 .73953 L .70023 .73912 L p .707 .577 .707 r
F P
0 g
s
.7313 .73953 m .73361 .75551 L .76515 .75041 L p .707 .577 .707 r
F P
0 g
s
.76515 .75041 m .76285 .73443 L .7313 .73953 L p .707 .577 .707 r
F P
0 g
s
.76285 .73443 m .76515 .75041 L .79409 .7403 L p .707 .577 .707 r
F P
0 g
s
.79409 .7403 m .79178 .72431 L .76285 .73443 L p .707 .577 .707 r
F P
0 g
s
.601 .24955 m .59562 .75486 L .55685 .74885 L p .707 .577 .707 r
F P
0 g
s
.55685 .74885 m .56223 .24354 L .601 .24955 L p .707 .577 .707 r
F P
0 g
s
.70254 .7551 m .70023 .73912 L .67267 .73324 L p .707 .577 .707 r
F P
0 g
s
.70023 .73912 m .70254 .7551 L .73361 .75551 L p .707 .577 .707 r
F P
0 g
s
.79178 .72431 m .79409 .7403 L .81757 .72616 L p .707 .577 .707 r
F P
0 g
s
.81757 .72616 m .81526 .71017 L .79178 .72431 L p .707 .577 .707 r
F P
0 g
s
.83231 .56395 m .82865 .62117 L .83556 .61812 L p .707 .577 .707 r
F P
0 g
s
.83556 .61812 m .83922 .5609 L .83231 .56395 L p .707 .577 .707 r
F P
0 g
s
.67267 .73324 m .67498 .74922 L .70254 .7551 L p .707 .577 .707 r
F P
0 g
s
.82778 .62875 m .8282 .66551 L .83528 .65626 L p .707 .577 .707 r
F P
0 g
s
.83528 .65626 m .83486 .6195 L .82778 .62875 L p .707 .577 .707 r
F P
0 g
s
.67498 .74922 m .67267 .73324 L .65132 .72246 L p .707 .577 .707 r
F P
0 g
s
.81526 .71017 m .81757 .72616 L .83331 .70938 L p .707 .577 .707 r
F P
0 g
s
.83331 .70938 m .831 .6934 L .81526 .71017 L p .707 .577 .707 r
F P
0 g
s
.56223 .24354 m .55685 .74885 L .51285 .74597 L p .707 .577 .707 r
F P
0 g
s
.51285 .74597 m .51822 .24067 L .56223 .24354 L p .707 .577 .707 r
F P
0 g
s
.65132 .72246 m .65363 .73844 L .67498 .74922 L p .707 .577 .707 r
F P
0 g
s
.47328 .24122 m .51822 .24067 L p .48679 .55664 L .707 .577 .707 r
F P
0 g
s
.47226 .70268 m .47247 .60762 L .48679 .55664 L .707 .577 .707 r
F
.47247 .60762 m .47328 .24122 L .48679 .55664 L F
.4679 .74652 m .46874 .66834 L p .47226 .70268 L F P
0 g
s
.46874 .66834 m .46926 .61907 L p .47226 .70268 L .707 .577 .707 r
F P
0 g
s
.46926 .61907 m .47328 .24122 L p .47247 .60762 L .707 .577 .707 r
F P
0 g
s
.46926 .61907 m .47247 .60762 L .47226 .70268 L .707 .577 .707 r
F
.51822 .24067 m .51285 .74597 L .4679 .74652 L p F P
0 g
s
.47456 .68934 m .47225 .67336 L .4503 .68657 L p .707 .577 .707 r
F P
0 g
s
.4503 .68657 m .44877 .6875 L p .45002 .68759 L .707 .577 .707 r
F P
0 g
s
.47456 .68934 m .4503 .68657 L .45002 .68759 L .707 .577 .707 r
F
.45108 .70348 m .47456 .68934 L p .45002 .68759 L F P
0 g
s
.44877 .6875 m .4492 .6905 L p .45002 .68759 L .707 .577 .707 r
F P
0 g
s
.4492 .6905 m .45108 .70348 L p .45002 .68759 L .707 .577 .707 r
F P
0 g
s
.46945 .58641 m .47311 .52919 L .4545 .52986 L p .707 .577 .707 r
F P
0 g
s
.4545 .52986 m .44921 .53005 L p .45666 .5508 L .707 .577 .707 r
F P
0 g
s
.46945 .58641 m .4545 .52986 L .45666 .5508 L .707 .577 .707 r
F
.83196 .61017 m .83486 .6195 L p .83301 .6399 L F P
0 g
s
.83238 .64693 m .83208 .62103 L p .83301 .6399 L .707 .577 .707 r
F P
0 g
s
.83208 .62103 m .83196 .61017 L p .83301 .6399 L .707 .577 .707 r
F P
0 g
s
.83196 .61017 m .83238 .64693 L .81978 .63841 L p .707 .577 .707 r
F P
0 g
s
.83617 .55715 m .83251 .61437 L .83174 .61412 L p .707 .577 .707 r
F P
0 g
s
.81937 .60165 m .83196 .61017 L p .82307 .63078 L .707 .577 .707 r
F P
0 g
s
.81978 .63841 m .81951 .6147 L p .82307 .63078 L .707 .577 .707 r
F P
0 g
s
.81951 .6147 m .81937 .60165 L p .82307 .63078 L .707 .577 .707 r
F P
0 g
s
.81937 .60165 m .81978 .63841 L .79872 .63155 L p .707 .577 .707 r
F P
0 g
s
.79831 .59479 m .81937 .60165 L p .80425 .62354 L .707 .577 .707 r
F P
0 g
s
.79872 .63155 m .79847 .60923 L p .80425 .62354 L .707 .577 .707 r
F P
0 g
s
.79847 .60923 m .79831 .59479 L p .80425 .62354 L .707 .577 .707 r
F P
0 g
s
.79831 .59479 m .79872 .63155 L .77126 .62702 L p .707 .577 .707 r
F P
0 g
s
.77085 .59026 m .79831 .59479 L p .77828 .61867 L .707 .577 .707 r
F P
0 g
s
.77126 .62702 m .77102 .60518 L p .77828 .61867 L .707 .577 .707 r
F P
0 g
s
.77102 .60518 m .77085 .59026 L p .77828 .61867 L .707 .577 .707 r
F P
0 g
s
.77085 .59026 m .77126 .62702 L .74009 .62526 L p .707 .577 .707 r
F P
0 g
s
.73968 .5885 m .77085 .59026 L p .74769 .61662 L .707 .577 .707 r
F P
0 g
s
.74009 .62526 m .73984 .60294 L p .74769 .61662 L .707 .577 .707 r
F P
0 g
s
.73984 .60294 m .73968 .5885 L p .74769 .61662 L .707 .577 .707 r
F P
0 g
s
.70784 .58968 m .73968 .5885 L p .71535 .61788 L .707 .577 .707 r
F P
0 g
s
.70826 .62644 m .70799 .60273 L p .71535 .61788 L .707 .577 .707 r
F P
0 g
s
.70799 .60273 m .70784 .58968 L p .71535 .61788 L .707 .577 .707 r
F P
0 g
s
.67847 .59369 m .70784 .58968 L p .68412 .62308 L .707 .577 .707 r
F P
0 g
s
.67888 .63045 m .67859 .60456 L p .68412 .62308 L .707 .577 .707 r
F P
0 g
s
.67859 .60456 m .67847 .59369 L p .68412 .62308 L .707 .577 .707 r
F P
0 g
s
.65483 .6369 m .65442 .60014 L .67847 .59369 L p .707 .577 .707 r
F P
0 g
s
.67847 .59369 m .67888 .63045 L .65483 .6369 L p .707 .577 .707 r
F P
0 g
s
.68267 .54067 m .67901 .59789 L .67662 .59798 L p .707 .577 .707 r
F P
0 g
s
.67662 .59798 m .65512 .59875 L p .66846 .57062 L .707 .577 .707 r
F P
0 g
s
.66846 .57062 m .68267 .54067 L .67662 .59798 L .707 .577 .707 r
F
.70784 .58968 m .70826 .62644 L .67888 .63045 L p F P
0 g
s
.71193 .54109 m .70827 .59831 L .70583 .59828 L p .707 .577 .707 r
F P
0 g
s
.70583 .59828 m .67901 .59789 L p .69351 .57288 L .707 .577 .707 r
F P
0 g
s
.69351 .57288 m .71193 .54109 L .70583 .59828 L .707 .577 .707 r
F
.73968 .5885 m .74009 .62526 L .70826 .62644 L p F P
0 g
s
.74369 .54276 m .74003 .59998 L .73808 .59988 L p .707 .577 .707 r
F P
0 g
s
.73808 .59988 m .70827 .59831 L p .72349 .57444 L .707 .577 .707 r
F P
0 g
s
.72349 .57444 m .74369 .54276 L .73808 .59988 L .707 .577 .707 r
F
.77484 .5455 m .77118 .60272 L .76962 .60258 L p F P
0 g
s
.76962 .60258 m .74003 .59998 L p .75533 .57604 L .707 .577 .707 r
F P
0 g
s
.75533 .57604 m .77484 .5455 L .76962 .60258 L .707 .577 .707 r
F
.80232 .54905 m .79866 .60627 L .7972 .60608 L p F P
0 g
s
.7972 .60608 m .77118 .60272 L p .78571 .57767 L .707 .577 .707 r
F P
0 g
s
.78571 .57767 m .80232 .54905 L .7972 .60608 L .707 .577 .707 r
F
.82346 .55306 m .8198 .61028 L .81848 .61003 L p F P
0 g
s
.81848 .61003 m .79866 .60627 L p .81153 .57865 L .707 .577 .707 r
F P
0 g
s
.81153 .57865 m .82346 .55306 L .81848 .61003 L .707 .577 .707 r
F
.83174 .61412 m .8198 .61028 L p .82993 .57739 L F P
0 g
s
.82993 .57739 m .83617 .55715 L .83174 .61412 L .707 .577 .707 r
F
.83922 .5609 m .83556 .61812 L .83251 .61437 L p F P
0 g
s
.83251 .61437 m .83617 .55715 L .83922 .5609 L p .707 .577 .707 r
F P
0 g
s
.831 .6934 m .83331 .70938 L .83976 .69161 L p .707 .577 .707 r
F P
0 g
s
.83976 .69161 m .83746 .67562 L .831 .6934 L p .707 .577 .707 r
F P
0 g
s
.83486 .6195 m .83528 .65626 L .83238 .64693 L p .707 .577 .707 r
F P
0 g
s
.63828 .70784 m .64059 .72382 L .65363 .73844 L p .707 .577 .707 r
F P
0 g
s
.63201 .60386 m .63567 .54664 L .64258 .54359 L p .707 .577 .707 r
F P
0 g
s
.64258 .54359 m .63892 .60081 L .63201 .60386 L p .707 .577 .707 r
F P
0 g
s
.63139 .65439 m .63097 .61763 L .63805 .60838 L p .707 .577 .707 r
F P
0 g
s
.64059 .72382 m .63828 .70784 L .63482 .69081 L p .707 .578 .707 r
F P
0 g
s
.83746 .67562 m .83976 .69161 L .8363 .67458 L p .707 .578 .707 r
F P
0 g
s
.8363 .67458 m .83399 .65859 L .83746 .67562 L p .707 .578 .707 r
F P
0 g
s
.63805 .60838 m .63847 .64514 L .63139 .65439 L p .707 .577 .707 r
F P
0 g
s
.8198 .61028 m .82346 .55306 L .83617 .55715 L p .707 .577 .707 r
F P
0 g
s
.63482 .69081 m .63712 .70679 L .64059 .72382 L p .707 .578 .707 r
F P
0 g
s
.38453 .58519 m .38819 .52796 L .35705 .52522 L p .707 .577 .707 r
F P
0 g
s
.41629 .58685 m .41995 .52963 L .38819 .52796 L p .707 .577 .707 r
F P
0 g
s
.63892 .60081 m .64258 .54359 L .65878 .54153 L p .707 .577 .707 r
F P
0 g
s
.35705 .52522 m .35339 .58244 L .38453 .58519 L p .707 .577 .707 r
F P
0 g
s
.35339 .58244 m .35705 .52522 L .32956 .52167 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38356 .64857 m .38315 .61181 L .35198 .61005 L p .707 .577 .707 r
F P
0 g
s
.4154 .64739 m .41498 .61063 L .38315 .61181 L p .707 .577 .707 r
F P
0 g
s
.63847 .64514 m .63805 .60838 L .65442 .60014 L p .707 .577 .707 r
F P
0 g
s
.65878 .54153 m .65512 .59875 L .63892 .60081 L p .707 .577 .707 r
F P
0 g
s
.63712 .70679 m .63482 .69081 L .64127 .67303 L p .707 .577 .707 r
F P
0 g
s
.32956 .52167 m .3259 .57889 L .35339 .58244 L p .707 .577 .707 r
F P
0 g
s
.35239 .64681 m .35198 .61005 L .32452 .60552 L p .707 .577 .707 r
F P
0 g
s
.35198 .61005 m .35239 .64681 L .38356 .64857 L p .707 .577 .707 r
F P
0 g
s
.83399 .65859 m .8363 .67458 L .82326 .65996 L p .707 .577 .707 r
F P
0 g
s
.82326 .65996 m .82095 .64397 L .83399 .65859 L p .707 .577 .707 r
F P
0 g
s
.3259 .57889 m .32956 .52167 L .30843 .51766 L p .707 .577 .707 r
F P
0 g
s
.64127 .67303 m .64358 .68902 L .63712 .70679 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65442 .60014 m .65483 .6369 L .63847 .64514 L p .707 .577 .707 r
F P
0 g
s
.79866 .60627 m .80232 .54905 L .82346 .55306 L p .707 .577 .707 r
F P
0 g
s
.32452 .60552 m .32493 .64228 L .35239 .64681 L p .707 .577 .707 r
F P
0 g
s
.30843 .51766 m .30477 .57488 L .3259 .57889 L p .707 .577 .707 r
F P
0 g
s
.32493 .64228 m .32452 .60552 L .30346 .59866 L p .707 .577 .707 r
F P
0 g
s
.65512 .59875 m .65878 .54153 L .68267 .54067 L p .707 .577 .707 r
F P
0 g
s
.47311 .52919 m .46945 .58641 L .48564 .58436 L p .707 .577 .707 r
F P
0 g
s
.48564 .58436 m .4893 .52714 L .47311 .52919 L p .707 .577 .707 r
F P
0 g
s
.64358 .68902 m .64127 .67303 L .65701 .65626 L p .707 .577 .707 r
F P
0 g
s
.82095 .64397 m .82326 .65996 L .80191 .64918 L p .707 .577 .707 r
F P
0 g
s
.80191 .64918 m .7996 .63319 L .82095 .64397 L p .707 .577 .707 r
F P
0 g
s
.30346 .59866 m .30388 .63542 L .32493 .64228 L p .707 .577 .707 r
F P
0 g
s
.46841 .60018 m .46883 .63694 L .48519 .62869 L p .707 .577 .707 r
F P
0 g
s
.48519 .62869 m .48477 .59193 L .46841 .60018 L p .707 .577 .707 r
F P
0 g
s
.30477 .57488 m .30843 .51766 L .29571 .51358 L p .707 .577 .707 r
F P
0 g
s
.77118 .60272 m .77484 .5455 L .80232 .54905 L p .707 .577 .707 r
F P
0 g
s
.65701 .65626 m .65932 .67224 L .64358 .68902 L p .707 .577 .707 r
F P
0 g
s
.3906 .7187 m .38829 .70271 L .35722 .7023 L p .707 .577 .707 r
F P
0 g
s
.38829 .70271 m .3906 .7187 L .42214 .7136 L p .707 .577 .707 r
F P
0 g
s
.42214 .7136 m .41984 .69761 L .38829 .70271 L p .707 .577 .707 r
F P
0 g
s
.29571 .51358 m .29205 .5708 L .30477 .57488 L p .707 .577 .707 r
F P
0 g
s
.67901 .59789 m .68267 .54067 L .71193 .54109 L p .707 .577 .707 r
F P
0 g
s
.30388 .63542 m .30346 .59866 L .29087 .59015 L p .707 .577 .707 r
F P
0 g
s
.35953 .71829 m .35722 .7023 L .32966 .69642 L p .707 .577 .707 r
F P
0 g
s
.35722 .7023 m .35953 .71829 L .3906 .7187 L p .707 .577 .707 r
F P
0 g
s
.65932 .67224 m .65701 .65626 L .68049 .64212 L p .707 .577 .707 r
F P
0 g
s
.74003 .59998 m .74369 .54276 L .77484 .5455 L p .707 .577 .707 r
F P
0 g
s
.7996 .63319 m .80191 .64918 L .77435 .64329 L p .707 .577 .707 r
F P
0 g
s
.77435 .64329 m .77205 .62731 L .7996 .63319 L p .707 .577 .707 r
F P
0 g
s
.4893 .52714 m .48564 .58436 L .49255 .5813 L p .707 .577 .707 r
F P
0 g
s
.49255 .5813 m .49621 .52408 L .4893 .52714 L p .707 .577 .707 r
F P
0 g
s
.32966 .69642 m .33197 .71241 L .35953 .71829 L p .707 .577 .707 r
F P
0 g
s
.29087 .59015 m .29128 .62691 L .30388 .63542 L p .707 .577 .707 r
F P
0 g
s
.70827 .59831 m .71193 .54109 L .74369 .54276 L p .707 .577 .707 r
F P
0 g
s
.68049 .64212 m .6828 .6581 L .65932 .67224 L p .707 .577 .707 r
F P
0 g
s
.48477 .59193 m .48519 .62869 L .49227 .61945 L p .707 .577 .707 r
F P
0 g
s
.49227 .61945 m .49185 .58269 L .48477 .59193 L p .707 .577 .707 r
F P
0 g
s
.33197 .71241 m .32966 .69642 L .30831 .68564 L p .707 .577 .707 r
F P
0 g
s
.29205 .5708 m .29571 .51358 L .29266 .50982 L p .707 .577 .707 r
F P
0 g
s
.47225 .67336 m .47456 .68934 L .4903 .67257 L p .707 .577 .707 r
F P
0 g
s
.4903 .67257 m .48799 .65658 L .47225 .67336 L p .707 .577 .707 r
F P
0 g
s
.6828 .6581 m .68049 .64212 L .70943 .632 L p .707 .577 .707 r
F P
0 g
s
.77205 .62731 m .77435 .64329 L .74328 .64288 L p .707 .577 .707 r
F P
0 g
s
.74328 .64288 m .74097 .6269 L .77205 .62731 L p .707 .577 .707 r
F P
0 g
s
.29266 .50982 m .289 .56705 L .29205 .5708 L p .707 .577 .707 r
F P
0 g
s
.30831 .68564 m .31062 .70163 L .33197 .71241 L p .707 .577 .707 r
F P
0 g
s
.29128 .62691 m .29087 .59015 L .28796 .58081 L p .707 .577 .707 r
F P
0 g
s
.71174 .64799 m .70943 .632 L .74097 .6269 L p .707 .577 .707 r
F P
0 g
s
.70943 .632 m .71174 .64799 L .6828 .6581 L p .707 .577 .707 r
F P
0 g
s
.74097 .6269 m .74328 .64288 L .71174 .64799 L p .707 .577 .707 r
F P
0 g
s
.31062 .70163 m .30831 .68564 L .29527 .67102 L p .707 .577 .707 r
F P
0 g
s
.28796 .58081 m .28838 .61757 L .29128 .62691 L p .707 .577 .707 r
F P
0 g
s
.48895 .57335 m .49185 .58269 L p .49 .60308 L .707 .577 .707 r
F P
0 g
s
.48937 .61011 m .48907 .58422 L p .49 .60308 L .707 .577 .707 r
F P
0 g
s
.48907 .58422 m .48895 .57335 L p .49 .60308 L .707 .577 .707 r
F P
0 g
s
.48895 .57335 m .48937 .61011 L .47677 .6016 L p .707 .577 .707 r
F P
0 g
s
.49316 .52033 m .4895 .57755 L .48873 .5773 L p .707 .577 .707 r
F P
0 g
s
.47636 .56484 m .48895 .57335 L p .48006 .59396 L .707 .577 .707 r
F P
0 g
s
.47677 .6016 m .4765 .57788 L p .48006 .59396 L .707 .577 .707 r
F P
0 g
s
.4765 .57788 m .47636 .56484 L p .48006 .59396 L .707 .577 .707 r
F P
0 g
s
.47636 .56484 m .47677 .6016 L .45571 .59474 L p .707 .577 .707 r
F P
0 g
s
.4553 .55798 m .47636 .56484 L p .46124 .58673 L .707 .577 .707 r
F P
0 g
s
.45571 .59474 m .45546 .57242 L p .46124 .58673 L .707 .577 .707 r
F P
0 g
s
.45546 .57242 m .4553 .55798 L p .46124 .58673 L .707 .577 .707 r
F P
0 g
s
.4553 .55798 m .45571 .59474 L .42825 .59021 L p .707 .577 .707 r
F P
0 g
s
.42784 .55345 m .4553 .55798 L p .43527 .58185 L .707 .577 .707 r
F P
0 g
s
.42825 .59021 m .42801 .56837 L p .43527 .58185 L .707 .577 .707 r
F P
0 g
s
.42801 .56837 m .42784 .55345 L p .43527 .58185 L .707 .577 .707 r
F P
0 g
s
.42784 .55345 m .42825 .59021 L .39708 .58845 L p .707 .577 .707 r
F P
0 g
s
.39667 .55168 m .42784 .55345 L p .40468 .5798 L .707 .577 .707 r
F P
0 g
s
.39708 .58845 m .39683 .56612 L p .40468 .5798 L .707 .577 .707 r
F P
0 g
s
.39683 .56612 m .39667 .55168 L p .40468 .5798 L .707 .577 .707 r
F P
0 g
s
.36483 .55287 m .39667 .55168 L p .37234 .58107 L .707 .577 .707 r
F P
0 g
s
.36525 .58963 m .36498 .56591 L p .37234 .58107 L .707 .577 .707 r
F P
0 g
s
.36498 .56591 m .36483 .55287 L p .37234 .58107 L .707 .577 .707 r
F P
0 g
s
.33545 .55688 m .36483 .55287 L p .3411 .58627 L .707 .577 .707 r
F P
0 g
s
.33587 .59364 m .33558 .56774 L p .3411 .58627 L .707 .577 .707 r
F P
0 g
s
.33558 .56774 m .33545 .55688 L p .3411 .58627 L .707 .577 .707 r
F P
0 g
s
.31182 .60008 m .31141 .56332 L .33545 .55688 L p .707 .577 .707 r
F P
0 g
s
.33545 .55688 m .33587 .59364 L .31182 .60008 L p .707 .577 .707 r
F P
0 g
s
.33966 .50385 m .336 .56108 L .33361 .56116 L p .707 .577 .707 r
F P
0 g
s
.33361 .56116 m .31211 .56193 L p .32545 .53381 L .707 .577 .707 r
F P
0 g
s
.32545 .53381 m .33966 .50385 L .33361 .56116 L .707 .577 .707 r
F
.36483 .55287 m .36525 .58963 L .33587 .59364 L p F P
0 g
s
.36892 .50428 m .36526 .5615 L .36282 .56146 L p .707 .577 .707 r
F P
0 g
s
.36282 .56146 m .336 .56108 L p .3505 .53607 L .707 .577 .707 r
F P
0 g
s
.3505 .53607 m .36892 .50428 L .36282 .56146 L .707 .577 .707 r
F
.39667 .55168 m .39708 .58845 L .36525 .58963 L p F P
0 g
s
.40068 .50594 m .39702 .56316 L .39507 .56306 L p .707 .577 .707 r
F P
0 g
s
.39507 .56306 m .36526 .5615 L p .38048 .53763 L .707 .577 .707 r
F P
0 g
s
.38048 .53763 m .40068 .50594 L .39507 .56306 L .707 .577 .707 r
F
.43182 .50868 m .42816 .5659 L .42661 .56577 L p F P
0 g
s
.42661 .56577 m .39702 .56316 L p .41232 .53922 L .707 .577 .707 r
F P
0 g
s
.41232 .53922 m .43182 .50868 L .42661 .56577 L .707 .577 .707 r
F
.45931 .51223 m .45565 .56945 L .45419 .56927 L p F P
0 g
s
.45419 .56927 m .42816 .5659 L p .4427 .54085 L .707 .577 .707 r
F P
0 g
s
.4427 .54085 m .45931 .51223 L .45419 .56927 L .707 .577 .707 r
F
.48045 .51625 m .47679 .57347 L .47547 .57322 L p F P
0 g
s
.47547 .57322 m .45565 .56945 L p .46852 .54183 L .707 .577 .707 r
F P
0 g
s
.46852 .54183 m .48045 .51625 L .47547 .57322 L .707 .577 .707 r
F
.48873 .5773 m .47679 .57347 L p .48692 .54057 L F P
0 g
s
.48692 .54057 m .49316 .52033 L .48873 .5773 L .707 .577 .707 r
F
.49621 .52408 m .49255 .5813 L .4895 .57755 L p F P
0 g
s
.4895 .57755 m .49316 .52033 L .49621 .52408 L p .707 .577 .707 r
F P
0 g
s
.48799 .65658 m .4903 .67257 L .49675 .65479 L p .707 .577 .707 r
F P
0 g
s
.49675 .65479 m .49445 .63881 L .48799 .65658 L p .707 .577 .707 r
F P
0 g
s
.49185 .58269 m .49227 .61945 L .48937 .61011 L p .707 .577 .707 r
F P
0 g
s
.29527 .67102 m .29758 .68701 L .31062 .70163 L p .707 .577 .707 r
F P
0 g
s
.289 .56705 m .29266 .50982 L .29957 .50677 L p .707 .577 .707 r
F P
0 g
s
.29957 .50677 m .29591 .56399 L .289 .56705 L p .707 .577 .707 r
F P
0 g
s
.28838 .61757 m .28796 .58081 L .29504 .57157 L p .707 .577 .707 r
F P
0 g
s
.29758 .68701 m .29527 .67102 L .29181 .65399 L p .707 .578 .707 r
F P
0 g
s
.49445 .63881 m .49675 .65479 L .49329 .63776 L p .707 .578 .707 r
F P
0 g
s
.49329 .63776 m .49098 .62178 L .49445 .63881 L p .707 .578 .707 r
F P
0 g
s
.29504 .57157 m .29546 .60833 L .28838 .61757 L p .707 .577 .707 r
F P
0 g
s
.47679 .57347 m .48045 .51625 L .49316 .52033 L p .707 .577 .707 r
F P
0 g
s
.29181 .65399 m .29411 .66998 L .29758 .68701 L p .707 .578 .707 r
F P
0 g
s
.29591 .56399 m .29957 .50677 L .31577 .50471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29546 .60833 m .29504 .57157 L .31141 .56332 L p .707 .577 .707 r
F P
0 g
s
.31577 .50471 m .31211 .56193 L .29591 .56399 L p .707 .577 .707 r
F P
0 g
s
.29411 .66998 m .29181 .65399 L .29826 .63622 L p .707 .577 .707 r
F P
0 g
s
.49098 .62178 m .49329 .63776 L .48025 .62314 L p .707 .577 .707 r
F P
0 g
s
.48025 .62314 m .47794 .60716 L .49098 .62178 L p .707 .577 .707 r
F P
0 g
s
.29826 .63622 m .30057 .6522 L .29411 .66998 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31141 .56332 m .31182 .60008 L .29546 .60833 L p .707 .577 .707 r
F P
0 g
s
.45565 .56945 m .45931 .51223 L .48045 .51625 L p .707 .577 .707 r
F P
0 g
s
.31211 .56193 m .31577 .50471 L .33966 .50385 L p .707 .577 .707 r
F P
0 g
s
.30057 .6522 m .29826 .63622 L .314 .61944 L p .707 .577 .707 r
F P
0 g
s
.47794 .60716 m .48025 .62314 L .4589 .61236 L p .707 .577 .707 r
F P
0 g
s
.4589 .61236 m .45659 .59638 L .47794 .60716 L p .707 .577 .707 r
F P
0 g
s
.42816 .5659 m .43182 .50868 L .45931 .51223 L p .707 .577 .707 r
F P
0 g
s
.314 .61944 m .31631 .63542 L .30057 .6522 L p .707 .577 .707 r
F P
0 g
s
.336 .56108 m .33966 .50385 L .36892 .50428 L p .707 .577 .707 r
F P
0 g
s
.31631 .63542 m .314 .61944 L .33748 .6053 L p .707 .577 .707 r
F P
0 g
s
.39702 .56316 m .40068 .50594 L .43182 .50868 L p .707 .577 .707 r
F P
0 g
s
.45659 .59638 m .4589 .61236 L .43134 .60648 L p .707 .577 .707 r
F P
0 g
s
.43134 .60648 m .42903 .5905 L .45659 .59638 L p .707 .577 .707 r
F P
0 g
s
.36526 .5615 m .36892 .50428 L .40068 .50594 L p .707 .577 .707 r
F P
0 g
s
.33748 .6053 m .33979 .62129 L .31631 .63542 L p .707 .577 .707 r
F P
0 g
s
.33979 .62129 m .33748 .6053 L .36642 .59519 L p .707 .577 .707 r
F P
0 g
s
.42903 .5905 m .43134 .60648 L .40027 .60607 L p .707 .577 .707 r
F P
0 g
s
.40027 .60607 m .39796 .59008 L .42903 .5905 L p .707 .577 .707 r
F P
0 g
s
.36872 .61117 m .36642 .59519 L .39796 .59008 L p .707 .577 .707 r
F P
0 g
s
.36642 .59519 m .36872 .61117 L .33979 .62129 L p .707 .577 .707 r
F P
0 g
s
.39796 .59008 m .40027 .60607 L .36872 .61117 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaP008Ao
o`00N7oo2@001EYF00<005YFFUH02UYF00<005YFFUH00eYF2@00Ngoo001dOol40002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001eOol0071oo`@000IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD0071oo`00KWoo0P0000=J
EP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01000K7oo001/Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001YOol006Yoo`8000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP<006Moo`00JGoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00IGoo001XOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00Oomoo`1ROol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00goo001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04
001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04
001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04
001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol0
06Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001SOol006Moo`04001JEUYF0005FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006Moo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00@005YFFUIJEP<006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP<006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<006=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP8000]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo
00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP8000]JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH4001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2
000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF1000Hgoo001W
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF0P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP@006=oo`00Igoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEUYFFUH4001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2
000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol0
06Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH3001SOol006Moo`04001JEUYF0005FUH00`00FUIJEP02FUH01@00FUIJEUYF0000
2eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
Hgoo001WOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001W
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000Hgoo001WOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00Hgoo001HOolN0003FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001SOol005Eo
o`<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0
06=oo`00Dgoo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPP000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP<006=oo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@0025YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00Hgoo001COol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH3001SOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001SOol005=o
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001SOol005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00008FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0`00Hgoo001COol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP8000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<006=oo`00Dgoo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<006=oo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP<000Eooa0004ioo`00DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH90003FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90015Ool0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009J
EP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEP00008000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP003eoo`00DWoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Ioo`00DWoo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05
001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YF000002moo`00DWoo00<005YF00000UYF5@0015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000^Ool0059oo`03001JEP0000D000EJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001J
EUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol200001EYF000005YF
00001UYF00<005YFFUH00UYF00@005YFFUH000QJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH0
1000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP00FUH00UYF0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YF0000
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00DWoo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000030005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<0
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000^Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001ooeYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP00;Woo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUHG0006FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0
055oo`03001JEP0000AJEP03001JEUYF00=JEPH0009oo`05001JEUYF001JEP040002FUH00`00FUIJ
EP05FUH00`00FUH000030002FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000_Ool0055oo`03001JEP0000AJEP03001JEP0000<000Qoo`D000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP@000AJEP05001JEUYFFUH00006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000_Ool0055oo`03001JEP00
00AJEP8000Yoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH0
000001l000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002moo`00DGoo00<005YF
00000UYF1@001Woo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH010000eYF00<005YFFUH015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00
0UYF10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT000AJEP03001JEUYF00=J
EP03001JEUYF008002moo`00DGoo00<005YF00000`0015YF1P001eYF00<005YFFUH00UYF3`001UYF
00@005YFFUIJEP@00003FUH005YF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`000eYF00<005YFFUH00P00;goo001AOol00`00FUH00002FUH00`00FUIJ
EP03FUH40007FUH@0002FUH00`00FUIJEP040002FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEPD00003FUH00000
02moo`00DGoo0P000eYF00<005YFFUH00eYF00@005YFFUH000EJEP8000EJEP03001JEUYF00IJEP05
001JEUYFFUH00006FUH30004FUH01@00FUH005YF00001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF0`00;goo001AOol20003
FUH01000FUIJEUYF0P0015YF00<005YF00000P001eYF00<005YFFUH01UYF00D005YFFUIJEP0000UJ
EP8000=JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20000
0eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03000_Ool0055oo`8000=JEP04001JEUYF0006
FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01@00FUIJEUYF00002eYF0P0000EJEP00FUIJ
EP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH2000_Ool0059oo`06001JEUYFFUH005YF0P0015YF0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00D005YFFUIJEP0000]JEP04001JEP000002FUH00`00FUIJEP03
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH20004FUH00`00OomJ
EP02000_Ool0059oo`04001JEUYFFUH2000015YF001JEUYF0P001UYF00<005YFFUH01EYF00<005YF
FUH00`000eYF00D005YFFUIJEP0000]JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF
6P0015YF00<005YFFUH00eYF00<007ooFUH00P00;goo001COol30003FUH40007FUH00`00FUIJEP06
FUH60003FUH01000FUIJEP002eYF00P005YFFUH005YF001JEP0015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00UYF1P000goo1P0015YF00<0
05YFFUH01UYF00<005YF00001`0015YF00<005YFFUH00P00;goo001DOol00`00FUIJEP02FUH01000
FUIJEP001eYF00<005YFFUH01UYF1P000eYF00@005YFFUH000]JEP<000=JEP8000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEP00008000Moo`80
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP<00006Ool00000001JEP000UYF0P00
;goo001DOol01000FUIJEUYF0`0000=JEP00FUH01UYF00<005YFFUH01UYF1P000eYF00@005YFFUH0
00UJEP<000IJEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00003FUH30007Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH400000eYF00000002FUH2000_Ool0035ooaD000eoo`80009JEP04001oogooOol50004FUH00`00
FUIJEP06FUH00`00FUH000020004FUH01000FUIJEP001UYF0`000UYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF001JEP00FUH20002
FUH80007FUH00`00FUIJEP04FUH=0005FUH00`00FUIJEP020002FUH4000_Ool002ioo`<00003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPh00004FUH005YF0008Ool90004FUH00`00FUIJ
EP06FUH200000eYF001JEP0:FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH005YF0`001EYF00<005YF00000P0025YF00<005YFFUH010002Goo
200000=JEP00FUH00eYF0P0000AJEP00000002moo`00;7oo0`000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH020002Goo00<005YFFUH03P000UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00=JEP80009JEP03001J
EUYF00EJEQ4000EJEP03001JEUYF008000EJEPD002moo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEP00
008000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP02FUH01000
FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF0000009JEP04
001JEUYFFUH20005FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH01@00FUH005YF0000;goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00UYF
0`000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF00@0
05YFFUH000MJEP03001JEP00008000MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP800004FUH005YFFUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00=JEP03001JEP0000<0
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYFFUH20002FUH01@00
FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP04001JEP000007
FUH200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
00000eYF00<007ooOol0;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH20006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP800003FUH005YF00AJEP80
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF
FUH00002FUH00`00Oomoo`0]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEP000UYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YF
FUH00P001EYF00<005YFFUH01UYF00<005YFFUH00`000eYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP800003FUH007oo02ioo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEP0000=JEP03
001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH30007FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH000000Woo0`00;Woo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH20006FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0P0015YF00<005YFFUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YF0000
1eYF00<005YFFUH01UYF00<005YF000010000UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001Goo
0P00;Woo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH025YF0`000eYF00<005YFFUH015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP800003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEP0000@0009JEP03001JEUYF00EJEP03001JEP0000<000Qoo`8002io
o`00:goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03
FUH30007FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800003FUH00000009oo`D000AJEP03001JEUYF
00IJEP03001JEUYF00<000=JEP03001JEUYF009JEPD000aoo`8002ioo`00:goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF
00@005YFFUH000EJEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD000IJEP03001JEUYF00EJ
EP8000=JEP03001JEP0000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH40008OolK000AOol2000^Ool002]oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP@000EJEP07001JEUYFFUH005YF
00000UYF00<005YFFUH00UYF1@001UYF00<005YFFUH00eYF0P001EYF0P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001JEP08000]Ool2000^Ool002]oo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06
001JEUYF001JEP000UYF00<005YFFUH00eYF00@005YFFUIJEP<0009JEP03001JEUYF009JEPD000IJ
EP03001JEUYF00@000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00D002Moo`03001JEP0002ioo`00:goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L0
05YFFUIJEP00FUH00002FUH20003FUH01000FUIJEUYF0`000UYF00<005YFFUH00eYF0`001eYF0`00
0eYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00P0
05YFFUH005YF001JEP0015YF00<005YFFUH00eYF00@005YF000002Eoo`03001JEP0002ioo`00:goo
00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP@0
00=JEP<0009JEP03001JEUYF00=JEP04001JEUYFFUH60006FUH01`00FUIJEUYF001JEP0000]JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<00003FUH005YF00=JEP03
001JEUYF00=JEP03001JEUYF008002=oo`<002moo`00:goo00<005YF000020001eYF00<005YFFUH0
1EYF2@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUIJEQ8000AJEP03001JEUYF00IJ
EP<0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000QOol200000eYF0000000_
Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EPP000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP<000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP02000POol01@00FUIJEUYF0000
<7oo000/Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH700000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF00<005YFFUH00P007goo00<005YFFUH00UYF00<0
07ooOol0;Woo000^Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000;FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF
00<005YFFUH00eYF00<005YFFUH00P007Goo0`000eYF00<007ooOol0;goo000bOol70004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH00`00FUIJEP040003FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00<005YFFUH015YF00<005YF
FUH00P002Goo0`0047oo00@005YFFUH0009JEP03001oogoo031oo`00>Goo2@0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF3`001eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH00eYF00@005YFFUIJEP8000Qoo`D000eoo`8000AJEP03001JEP00039o
o`00?goo4@001eYF00@005YFFUIJEPX00005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01000FUIJEP000UYF00<005YFFUH00eYF00H005YFFUH005YF0008Ool5000;Ool20006FUH2
000cOol003]oo`@00003FUH005YF00MJEP03001JEUYF00AJEP/000]oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF000000020005FUH00`00FUIJEP020009Ool50008Ool3
00000eYF001JEP05FUH00`00Oomoo`0bOol003Eoo`H000EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP<000Yoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
15YF001JEUYF0P0015YF00<005YFFUH00P002Woo0`001Woo0`0015YF00<005YFFUH00UYF0P00=Goo
000aOol40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUH000020007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
00AJEP<00004FUH005YFFUH2000?Ool40007FUH00`00FUIJEP02000gOol002moo`<000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF00<005YF0000
1@002goo10000UYF00<005YFFUH01UYF0`00>Goo000]Ool20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP8000=JEP03001JEUYF
00=JEPd000IJEP03001JEUYF00EJEP8003]oo`00;7oo00<005YFFUH00UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000040002
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000mOol002]o
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH09@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP<000MJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEP00008003moo`00:Woo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00UYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P0000Eo
o`00FUIJEP0000EJEP03001JEUYF00EJEPD000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00EJEPH0009JEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000005FUH40004FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH60012Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00EJEP04001JEUYFFUH50005FUH00`00FUIJEP0200001Goo001J
EUYF00001EYF00<005YFFUH01@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH010001UYF00<005YFFUH00UYF00@005YF000000EJEP04001JEUYFFUHB0018Ool002Yo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP<000=JEP03001JEUYF00800005Ool005YFFUH00004FUH40002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004
FUH00`00FUIJEP02FUH01000FUH000001EYF00<005YFFUH01000Egoo000ZOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP02000015YF001JEUYF0P0000Ioo`00FUIJEP00FUH30006FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03
FUH00`00FUH00009001KOol002Yoo`04001JEUYF0003FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP04FUH<0007FUH01000FUIJEUYF0P000eYF00<007oo00000UYF0P0000=JEP00FUH01UYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
00000P000eYF00<005YF00000`00HGoo000ZOol01000FUIJEP000eYF00<005YF00001@0025YF00<0
05YFFUH0100037oo10000eYF00<005YFFUH00UYF0P000UYF00D007oo001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP800004FUH005YF0002FUH3001OOol002Yoo`04001JEUYF0003FUH30000
1Goo001JEUYF00001eYF100017oo0`003Goo100015YF00H005YF001JEP00Ool20004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH200001EYF001JEUYF00000UYF1000Fgoo000ZOol01@00FUIJEP00FUH0
0P000UYF0P0015YF00<005YFFUH00UYF0P001goo1@003Goo1@000eYF0P0000=JEP00Ool00P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF0P0015YF00<005YFFUH00eYF0P00FWoo000ZOol00`00FUIJ
EP030002FUH00`00FUIJEP04FUH00`00FUH000020009Ool50007Ool60005FUH200000eYF001JEP02
00000goo00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000
FUH00000F7oo000ZOol00`00FUH00002FUH01000FUH000001UYF6P0015YF00<005YFFUH015YF00@0
05YF0000009JEP04001oo`000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000Egoo000ZOol20003FUH200000eYF001JEP03FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP00009oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03
001JEUYF00=JEP05001JEUYFFUH0001GOol002Yoo`8000=JEP04001JEUYF0002FUH20006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`000Woo
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF1@0000=JEP00FUH015YF00@005YFFUIJ
EP8005Ioo`00:Woo0P000UYF00@005YFFUIJEP@000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH40002Ool20002FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20003FUH30005FUH00`00FUIJEP02001FOol002]oo`03001JEP0000AJEP04001JEUYF
0007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=oo`00Ool00goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF0`000eYF00<005YFFUH00P00
EWoo000/Ool20003FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00D005YFFUIJEP00009oo`03001oogoo00Aoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP00
00<00003FUH005YF00EJEP03001JEUYF00800004FUH005YFFUH2001FOol002aoo`80009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000002Ool20008Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH>0002FUH00`00FUIJEP02FUH20002FUH2001F
Ool002aoo`03001JEP00008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000Aoo`03001JEP0000]oo`D000QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00D000ioo`<000EJEP800003FUH0000005Ioo`00
:goo00@005YFFUH0009oo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000<000Moo`03001JEP00011oo`H0009JEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00=JEPP000=oo`<000eoo`D000=JEP03001JEP00008005Ioo`00:goo00@005YF
FUH000Eoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD000Yoo`04001J
EUYF000FOolS0009Ool50007Ool50005FUH20002FUH01000FUH00000EWoo000[Ool00`00FUH0000;
Ool90004FUH00`00FUIJEP02FUH9000?Ool01000FUIJEP009Goo00H005YF001JEP00FUH20007FUH8
0006Ool<0003FUH00`00FUIJEP04FUH00`00FUH000020002FUH00`00Oomoo`1DOol002]oo`03001J
EP0001Aoo`T001Moo`800003FUH007oo02Eoo`80009JEP800003FUH005YF00AJEP8000=JEP03001J
EUYF009JEP/0009JEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00Oomo
o`1DOol002aoo`03001oogoo039oo`05001JEP00FUH0000VOol20002FUH20002FUH00`00FUIJEP02
0005FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0001FOol002aoo`03001oogoo035oo`05001JEUYFFUH0000WOol20002FUH0
1000FUIJEUYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YF000005Eoo`00;7oo00<007ooOol0<7oo00<005YFFUH00UYF00<0
07ooOol09Woo00<005YF000015YF00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF1000EGoo000/Ool2000_Ool30003FUH00`00
Oomoo`0WOol00`00FUH00003FUH01000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@007oo000005Eoo`00;7oo0`00;7oo0P00
0UYF00@005YFFUH002]oo`80009JEP05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002Ool2001EOol002eoo`03001JEP00
02Uoo`8000AJEP03001JEP0002aoo`800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`8005Eoo`00;Goo00@005YF
FUH002Ioo`8000IJEP8002aoo`05001JEP00001oo`0300000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006Ool2001EOol002ioo`03001JEP00
0080029oo`800003FUH005YF00EJEP03001oogoo02]oo`03001JEP0000Eoo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000Moo`03001JEP0005Eoo`00;goo
0P000UYF0P007Goo0`000eYF00<005YFFUH00UYF0P00;Woo00<005YF000027oo10000UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@002goo00<005YF0000EGoo000`Ool20003FUH3
000FOol40007FUH01000FUIJEP00<7oo00<005YF000037oo6@003goo0`00EWoo000aOol00`00FUIJ
EP02FUH00`00FUH00003000>Ool40002FUH00`00FUIJEP06FUH3000bOol00`00Oomoo`0bOol01000
FUH00000EWoo000bOol20002FUH00`00FUIJEP03FUH>0006FUH00`00FUIJEP05FUH2000dOol00`00
Oomoo`0aOol00`00FUIJEP02001FOol003Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF009JEP8003Ioo`03001oogoo031oo`05001JEUYFFUH0001GOol003Ioo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008003Qoo`80031oo`03001JEUYF009J
EP03001oogoo05Eoo`00>Goo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo00<005YF
0000;Goo0`000eYF00<007ooOol0EWoo000mOol@0012Ool00`00FUH0000[Ool01000FUIJEP000UYF
00<007ooOol0Egoo002?Ool01000FUIJEP00:7oo0P0015YF0P00FWoo002?Ool00`00FUIJEP03000T
Ool20006FUH00`00Oomoo`1IOol0091oo`03001JEP00009JEP8001moo`<00003FUH005YF00=JEP80
05aoo`00T7oo00<005YF000015YF0`006Goo0`0015YF00<005YFFUH00P00GWoo002AOol20005FUH0
0`00FUH00003000?Ool60007FUH3001POol0099oo`03001JEUYF00=JEP03001JEUYF00=JEPl000AJ
EP03001JEUYF00EJEP80069oo`00Tgoo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH00eYF0P00I7oo002EOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002001VOol009Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
06Uoo`00VWoo10000UYF00<005YFFUH01UYF00<005YFFUH01000KGoo002NOol>001aOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]13\[InvisibleSpace]"     "\
\[InvisibleSpace]5.628853194275645`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 13, "     ", 5.6288531942756448, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58015 .72774 m .59019 .67422 L .55954 .66667 L p .707 .577 .707 r
F P
0 g
s
.60861 .73166 m .61151 .73206 L p .60299 .70894 L .707 .577 .707 r
F P
0 g
s
.61151 .73206 m .62156 .67854 L .59019 .67422 L p .707 .577 .707 r
F P
0 g
s
.62156 .67854 m .62104 .68133 L p .64052 .73272 L .707 .577 .707 r
F P
0 g
s
.62104 .68133 m .61151 .73206 L .63814 .73267 L p .707 .577 .707 r
F P
0 g
s
.63814 .73267 m .64052 .73272 L p .62104 .68133 L .707 .577 .707 r
F P
0 g
s
.64052 .73272 m .65057 .6792 L .62156 .67854 L p .707 .577 .707 r
F P
0 g
s
.65057 .6792 m .64935 .68569 L p .66434 .72967 L .707 .577 .707 r
F P
0 g
s
.64935 .68569 m .64052 .73272 L .66277 .72987 L p .707 .577 .707 r
F P
0 g
s
.66277 .72987 m .66434 .72967 L p .64935 .68569 L .707 .577 .707 r
F P
0 g
s
.66434 .72967 m .67438 .67615 L .65057 .6792 L p .707 .577 .707 r
F P
0 g
s
.67438 .67615 m .67339 .68141 L p .68063 .72319 L .707 .577 .707 r
F P
0 g
s
.67339 .68141 m .66434 .72967 L .6797 .72356 L p .707 .577 .707 r
F P
0 g
s
.6797 .72356 m .68063 .72319 L p .67339 .68141 L .707 .577 .707 r
F P
0 g
s
.68063 .72319 m .69067 .66967 L .67438 .67615 L p .707 .577 .707 r
F P
0 g
s
.69067 .66967 m .68063 .72319 L .68738 .71447 L p .707 .577 .707 r
F P
0 g
s
.68738 .71447 m .68779 .71393 L p .69014 .67784 L .707 .577 .707 r
F P
0 g
s
.69014 .67784 m .69067 .66967 L .68738 .71447 L .707 .577 .707 r
F
.68019 .711 m .68008 .72609 L p .687 .73962 L F P
0 g
s
.68728 .70259 m .68019 .711 L p .68543 .73301 L .707 .577 .707 r
F P
0 g
s
.687 .73962 m .68717 .71726 L p .68543 .73301 L .707 .577 .707 r
F P
0 g
s
.68717 .71726 m .68728 .70259 L p .68543 .73301 L .707 .577 .707 r
F P
0 g
s
.68779 .71393 m .69784 .66042 L .69067 .66967 L p .707 .577 .707 r
F P
0 g
s
.69784 .66042 m .68779 .71393 L .68762 .7132 L p .707 .577 .707 r
F P
0 g
s
.68728 .70259 m .68717 .71726 L p .6841 .73097 L .707 .577 .707 r
F P
0 g
s
.68438 .69394 m .68728 .70259 L p .68477 .72504 L .707 .577 .707 r
F P
0 g
s
.6841 .73097 m .68428 .70734 L p .68477 .72504 L .707 .577 .707 r
F P
0 g
s
.68428 .70734 m .68438 .69394 L p .68477 .72504 L .707 .577 .707 r
F P
0 g
s
.68008 .72609 m .67992 .74802 L .68284 .74455 L p .707 .577 .707 r
F P
0 g
s
.68284 .74455 m .687 .73962 L p .68008 .72609 L .707 .577 .707 r
F P
0 g
s
.67992 .74802 m .68019 .711 L .66382 .71833 L p .707 .577 .707 r
F P
0 g
s
.68438 .69394 m .6841 .73097 L .67151 .72292 L p .707 .577 .707 r
F P
0 g
s
.69518 .64928 m .68513 .7028 L .68413 .70182 L p .707 .577 .707 r
F P
0 g
s
.67179 .68589 m .68438 .69394 L p .67363 .71814 L .707 .577 .707 r
F P
0 g
s
.67151 .72292 m .6717 .69731 L p .67363 .71814 L .707 .577 .707 r
F P
0 g
s
.6717 .69731 m .67179 .68589 L p .67363 .71814 L .707 .577 .707 r
F P
0 g
s
.66382 .71833 m .66372 .73299 L p .67992 .74802 L .707 .577 .707 r
F P
0 g
s
.66355 .75535 m .66382 .71833 L .63977 .72387 L p .707 .577 .707 r
F P
0 g
s
.67179 .68589 m .67151 .72292 L .65046 .71625 L p .707 .577 .707 r
F P
0 g
s
.68296 .63735 m .67291 .69087 L .67101 .6898 L p .707 .577 .707 r
F P
0 g
s
.65046 .71625 m .65073 .67922 L .67179 .68589 L p .707 .577 .707 r
F P
0 g
s
.67101 .6898 m .65233 .67932 L p .66804 .65778 L .707 .577 .707 r
F P
0 g
s
.66804 .65778 m .68296 .63735 L .67101 .6898 L .707 .577 .707 r
F
.68413 .70182 m .67291 .69087 L p .6833 .67148 L F P
0 g
s
.6833 .67148 m .69518 .64928 L .68413 .70182 L .707 .577 .707 r
F
.68762 .7132 m .68513 .7028 L p .69088 .68361 L F P
0 g
s
.69088 .68361 m .69784 .66042 L .68762 .7132 L .707 .577 .707 r
F
.68717 .71726 m .687 .73962 L .68576 .73592 L p F P
0 g
s
.68576 .73592 m .6841 .73097 L p .68717 .71726 L .707 .577 .707 r
F P
0 g
s
.66372 .73299 m .66355 .75535 L .66967 .75261 L p .707 .577 .707 r
F P
0 g
s
.66967 .75261 m .67992 .74802 L p .66372 .73299 L .707 .577 .707 r
F P
0 g
s
.63977 .72387 m .63967 .73726 L p .66355 .75535 L .707 .577 .707 r
F P
0 g
s
.63967 .73726 m .6395 .76089 L .64697 .75917 L p .707 .577 .707 r
F P
0 g
s
.64697 .75917 m .66355 .75535 L p .63967 .73726 L .707 .577 .707 r
F P
0 g
s
.61039 .72708 m .61031 .7385 L p .6395 .76089 L .707 .577 .707 r
F P
0 g
s
.61031 .7385 m .61011 .7641 L .61647 .76341 L p .707 .577 .707 r
F P
0 g
s
.61647 .76341 m .6395 .76089 L p .61031 .7385 L .707 .577 .707 r
F P
0 g
s
.59019 .67422 m .58015 .72774 L .60861 .73166 L p .707 .577 .707 r
F P
0 g
s
.60299 .70894 m .59019 .67422 L .60861 .73166 L .707 .577 .707 r
F
.5495 .72019 m .55954 .66667 L .5326 .65663 L p F P
0 g
s
.55954 .66667 m .5495 .72019 L .58015 .72774 L p .707 .577 .707 r
F P
0 g
s
.52256 .71015 m .5326 .65663 L .51202 .64509 L p .707 .577 .707 r
F P
0 g
s
.5326 .65663 m .52256 .71015 L .5495 .72019 L p .707 .577 .707 r
F P
0 g
s
.57828 .76467 m .57856 .72764 L .54738 .72551 L p .707 .577 .707 r
F P
0 g
s
.57856 .72764 m .57828 .76467 L .61011 .7641 L p .707 .577 .707 r
F P
0 g
s
.61011 .7641 m .61039 .72708 L .57856 .72764 L p .707 .577 .707 r
F P
0 g
s
.6395 .76089 m .63977 .72387 L .61039 .72708 L p .707 .577 .707 r
F P
0 g
s
.54711 .76253 m .54738 .72551 L .51993 .72088 L p .707 .577 .707 r
F P
0 g
s
.54738 .72551 m .54711 .76253 L .57828 .76467 L p .707 .577 .707 r
F P
0 g
s
.58912 .80525 m .58402 .78694 L .55407 .79386 L p .707 .577 .707 r
F P
0 g
s
.58402 .78694 m .58912 .80525 L .61985 .79652 L p .707 .577 .707 r
F P
0 g
s
.61985 .79652 m .61475 .77822 L .58402 .78694 L p .707 .577 .707 r
F P
0 g
s
.61475 .77822 m .61985 .79652 L .64836 .78683 L p .707 .577 .707 r
F P
0 g
s
.64836 .78683 m .64326 .76853 L .61475 .77822 L p .707 .577 .707 r
F P
0 g
s
.51993 .72088 m .51965 .7579 L .54711 .76253 L p .707 .577 .707 r
F P
0 g
s
.55407 .79386 m .55916 .81216 L .58912 .80525 L p .707 .577 .707 r
F P
0 g
s
.51202 .64509 m .50197 .6986 L .52256 .71015 L p .707 .577 .707 r
F P
0 g
s
.50197 .6986 m .51202 .64509 L .4998 .63316 L p .707 .577 .707 r
F P
0 g
s
.51965 .7579 m .51993 .72088 L .49887 .71421 L p .707 .577 .707 r
F P
0 g
s
.55916 .81216 m .55407 .79386 L .52783 .79828 L p .707 .577 .707 r
F P
0 g
s
.52783 .79828 m .53293 .81658 L .55916 .81216 L p .707 .577 .707 r
F P
0 g
s
.64326 .76853 m .64836 .78683 L .67185 .77713 L p .707 .577 .707 r
F P
0 g
s
.67185 .77713 m .66675 .75883 L .64326 .76853 L p .707 .577 .707 r
F P
0 g
s
.49887 .71421 m .4986 .75124 L .51965 .7579 L p .707 .577 .707 r
F P
0 g
s
.4998 .63316 m .48975 .68668 L .50197 .6986 L p .707 .577 .707 r
F P
0 g
s
.53293 .81658 m .52783 .79828 L .50787 .79978 L p .707 .577 .707 r
F P
0 g
s
.50787 .79978 m .51297 .81808 L .53293 .81658 L p .707 .577 .707 r
F P
0 g
s
.66675 .75883 m .67185 .77713 L .68803 .76837 L p .707 .577 .707 r
F P
0 g
s
.68803 .76837 m .68293 .75006 L .66675 .75883 L p .707 .577 .707 r
F P
0 g
s
.4986 .75124 m .49887 .71421 L .48628 .70616 L p .707 .577 .707 r
F P
0 g
s
.48975 .68668 m .4998 .63316 L .49714 .62202 L p .707 .577 .707 r
F P
0 g
s
.48628 .70616 m .486 .74318 L .4986 .75124 L p .707 .577 .707 r
F P
0 g
s
.51297 .81808 m .50787 .79978 L .49615 .7982 L p .707 .577 .707 r
F P
0 g
s
.49714 .62202 m .48709 .67554 L .48975 .68668 L p .707 .577 .707 r
F P
0 g
s
.49615 .7982 m .50125 .81651 L .51297 .81808 L p .707 .577 .707 r
F P
0 g
s
.68293 .75006 m .68803 .76837 L .6953 .7614 L p .707 .577 .707 r
F P
0 g
s
.6953 .7614 m .69021 .7431 L .68293 .75006 L p .707 .577 .707 r
F P
0 g
s
.486 .74318 m .48628 .70616 L .48339 .69751 L p .707 .577 .707 r
F P
0 g
s
.48709 .67554 m .49714 .62202 L .5043 .61276 L p .707 .577 .707 r
F P
0 g
s
.50125 .81651 m .49615 .7982 L .49382 .79371 L p .707 .577 .707 r
F P
0 g
s
.5043 .61276 m .49426 .66628 L .48709 .67554 L p .707 .577 .707 r
F P
0 g
s
.49382 .79371 m .49892 .81201 L .50125 .81651 L p .707 .577 .707 r
F P
0 g
s
.48339 .69751 m .48311 .73453 L .486 .74318 L p .707 .577 .707 r
F P
0 g
s
.48311 .73453 m .48339 .69751 L .49047 .68911 L p .707 .577 .707 r
F P
0 g
s
.49426 .66628 m .5043 .61276 L .52059 .60629 L p .707 .577 .707 r
F P
0 g
s
.49047 .68911 m .49019 .72613 L .48311 .73453 L p .707 .577 .707 r
F P
0 g
s
.52059 .60629 m .51055 .65981 L .49426 .66628 L p .707 .577 .707 r
F P
0 g
s
.49892 .81201 m .49382 .79371 L .50109 .78674 L p .707 .577 .707 r
F P
0 g
s
.49019 .72613 m .49047 .68911 L .50684 .68178 L p .707 .577 .707 r
F P
0 g
s
.50684 .68178 m .50656 .7188 L .49019 .72613 L p .707 .577 .707 r
F P
0 g
s
.49665 .82399 m .51548 .3245 L .4715 .32015 L p .707 .577 .707 r
F P
0 g
s
.50109 .78674 m .50619 .80505 L .49892 .81201 L p .707 .577 .707 r
F P
0 g
s
.51055 .65981 m .52059 .60629 L .5444 .60323 L p .707 .577 .707 r
F P
0 g
s
.5444 .60323 m .53436 .65675 L .51055 .65981 L p .707 .577 .707 r
F P
0 g
s
.50619 .80505 m .50109 .78674 L .51727 .77798 L p .707 .577 .707 r
F P
0 g
s
.51727 .77798 m .52237 .79628 L .50619 .80505 L p .707 .577 .707 r
F P
0 g
s
.50656 .7188 m .50684 .68178 L .53089 .67623 L p .707 .577 .707 r
F P
0 g
s
.53089 .67623 m .53061 .71326 L .50656 .7188 L p .707 .577 .707 r
F P
0 g
s
.53061 .71326 m .53089 .67623 L .53263 .67604 L p .707 .577 .707 r
F P
0 g
s
.52237 .79628 m .51727 .77798 L .54076 .76828 L p .707 .577 .707 r
F P
0 g
s
.54076 .76828 m .54586 .78658 L .52237 .79628 L p .707 .577 .707 r
F P
0 g
s
.53802 .82436 m .54157 .82439 L p .52986 .60001 L .707 .577 .707 r
F P
0 g
s
.5444 .60323 m .5613 .60362 L p .54534 .6351 L .707 .577 .707 r
F P
0 g
s
.53436 .65675 m .53838 .63531 L p .54534 .6351 L .707 .577 .707 r
F P
0 g
s
.53838 .63531 m .5444 .60323 L p .54534 .6351 L .707 .577 .707 r
F P
0 g
s
.5788 .60464 m .60478 .60822 L p .58053 .63703 L .707 .577 .707 r
F P
0 g
s
.63543 .61576 m .62539 .66928 L .59474 .66173 L p .707 .577 .707 r
F P
0 g
s
.59474 .66173 m .60478 .60822 L .63543 .61576 L p .707 .577 .707 r
F P
0 g
s
.54586 .78658 m .54076 .76828 L .56011 .7617 L p .707 .577 .707 r
F P
0 g
s
.56011 .7617 m .56927 .75859 L p .56335 .76567 L .707 .577 .707 r
F P
0 g
s
.54586 .78658 m .56011 .7617 L .56335 .76567 L .707 .577 .707 r
F
.53681 .73314 m .54871 .63499 L .53364 .67251 L F
.54157 .82439 m .54465 .74275 L p .53681 .73314 L F P
0 g
s
.54465 .74275 m .54871 .63499 L p .53681 .73314 L .707 .577 .707 r
F P
0 g
s
.56927 .75859 m .57437 .77689 L .54586 .78658 L p .707 .577 .707 r
F P
0 g
s
.57207 .70693 m .57108 .65401 L .54157 .82439 L .707 .577 .707 r
F
.57485 .67277 m .58272 .67263 L p .57306 .69475 L F P
0 g
s
.58272 .67263 m .59211 .67246 L p .58207 .68421 L .707 .577 .707 r
F P
0 g
s
.57306 .69475 m .58272 .67263 L .58207 .68421 L .707 .577 .707 r
F
.60478 .60822 m .59474 .66173 L .58175 .65995 L p F P
0 g
s
.57468 .67483 m .57108 .65401 L .57207 .70693 L .707 .577 .707 r
F
.54871 .63499 m .54157 .82439 L p .57108 .65401 L F P
0 g
s
.57025 .64924 m .58053 .63703 L .57187 .65859 L .707 .577 .707 r
F
.57341 .6039 m .5788 .60464 L p .57025 .64924 L F P
0 g
s
.57025 .64924 m .5788 .60464 L .58053 .63703 L .707 .577 .707 r
F
.56769 .63441 m .57341 .6039 L p .57025 .64924 L F P
0 g
s
.57451 .63419 m .56769 .63441 L .57108 .65401 L .707 .577 .707 r
F
.56769 .63441 m .54871 .63499 L .57108 .65401 L F
.58175 .65995 m .57187 .65859 L p .58053 .63703 L F P
0 g
s
.57187 .65859 m .56337 .65742 L p .57025 .64924 L .707 .577 .707 r
F P
0 g
s
.58053 .63703 m .60478 .60822 L .58175 .65995 L .707 .577 .707 r
F
.62328 .6746 m .623 .71162 L .59183 .70948 L p F P
0 g
s
.59183 .70948 m .59211 .67246 L .62328 .6746 L p .707 .577 .707 r
F P
0 g
s
.59211 .67246 m .59183 .70948 L .57184 .70984 L p .707 .577 .707 r
F P
0 g
s
.54157 .82439 m .56268 .82257 L p .57207 .70693 L .707 .577 .707 r
F P
0 g
s
.57184 .70984 m .55999 .71005 L p .57306 .69475 L .707 .577 .707 r
F P
0 g
s
.57306 .69475 m .59211 .67246 L .57184 .70984 L .707 .577 .707 r
F
.57437 .77689 m .57071 .76377 L p .60001 .74986 L F P
0 g
s
.57071 .76377 m .56927 .75859 L .57203 .75781 L p .707 .577 .707 r
F P
0 g
s
.57203 .75781 m .60001 .74986 L p .57071 .76377 L .707 .577 .707 r
F P
0 g
s
.62996 .74295 m .63506 .76125 L .6051 .76816 L p .707 .577 .707 r
F P
0 g
s
.6051 .76816 m .60001 .74986 L .62996 .74295 L p .707 .577 .707 r
F P
0 g
s
.60001 .74986 m .6051 .76816 L .57437 .77689 L p .707 .577 .707 r
F P
0 g
s
.61697 .81361 m .60997 .58577 L .58605 .74059 L .707 .577 .707 r
F
.60997 .58577 m .60209 .32894 L .58824 .6843 L F
.60997 .58577 m .58824 .6843 L .58605 .74059 L F
.58303 .82082 m .57697 .68807 L .57207 .70693 L F
.56268 .82257 m .58303 .82082 L p .57207 .70693 L F P
0 g
s
.60185 .32133 m .60052 .35682 L p .60209 .32894 L .707 .577 .707 r
F P
0 g
s
.60052 .35682 m .58605 .74059 L p .60209 .32894 L .707 .577 .707 r
F P
0 g
s
.57697 .68807 m .57468 .67483 L .57207 .70693 L .707 .577 .707 r
F
.57697 .68807 m .57451 .63419 L .57108 .65401 L F
.55999 .71005 m .56027 .67302 L .57485 .67277 L p F P
0 g
s
.55999 .71005 m .57485 .67277 L .57306 .69475 L .707 .577 .707 r
F
.58605 .74059 m .58303 .82082 L .59025 .81928 L p F P
0 g
s
.59025 .81928 m .61697 .81361 L p .58605 .74059 L .707 .577 .707 r
F P
0 g
s
.56337 .65742 m .56769 .63441 L p .57025 .64924 L .707 .577 .707 r
F P
0 g
s
.5613 .60362 m .57341 .6039 L p .55048 .63494 L .707 .577 .707 r
F P
0 g
s
.54665 .64012 m .54871 .63499 L .55048 .63494 L .707 .577 .707 r
F
.54871 .63499 m .5613 .60362 L .55048 .63494 L F
.57341 .6039 m .56337 .65742 L .53436 .65675 L p F P
0 g
s
.60185 .32133 m .5604 .32491 L p .57451 .63419 L .707 .577 .707 r
F P
0 g
s
.58303 .82082 m .59008 .63371 L p .57451 .63419 L .707 .577 .707 r
F P
0 g
s
.59008 .63371 m .60185 .32133 L p .57451 .63419 L .707 .577 .707 r
F P
0 g
s
.53436 .65675 m .5613 .60362 L .54665 .64012 L .707 .577 .707 r
F
.5604 .32491 m .54871 .63499 L p .57451 .63419 L F P
0 g
s
.5604 .32491 m .51548 .3245 L p .53364 .67251 L .707 .577 .707 r
F P
0 g
s
.54871 .63499 m .5604 .32491 L p .53364 .67251 L .707 .577 .707 r
F P
0 g
s
.53263 .67604 m .56027 .67302 L p .53382 .7089 L .707 .577 .707 r
F P
0 g
s
.53061 .71326 m .53263 .67604 L .53382 .7089 L .707 .577 .707 r
F
.56027 .67302 m .55999 .71005 L .53061 .71326 L p F P
0 g
s
.51548 .3245 m .49665 .82399 L .53802 .82436 L p .707 .577 .707 r
F P
0 g
s
.52986 .60001 m .51548 .3245 L .53802 .82436 L .707 .577 .707 r
F
.68513 .7028 m .69518 .64928 L .69784 .66042 L p F P
0 g
s
.45268 .81963 m .4715 .32015 L .43277 .31228 L p .707 .577 .707 r
F P
0 g
s
.4715 .32015 m .45268 .81963 L .49665 .82399 L p .707 .577 .707 r
F P
0 g
s
.61697 .81361 m .6358 .31412 L .60185 .32133 L p .707 .577 .707 r
F P
0 g
s
.69021 .7431 m .6953 .7614 L .69297 .75691 L p .707 .577 .707 r
F P
0 g
s
.69297 .75691 m .68787 .7386 L .69021 .7431 L p .707 .577 .707 r
F P
0 g
s
.67291 .69087 m .68296 .63735 L .69518 .64928 L p .707 .577 .707 r
F P
0 g
s
.41394 .81177 m .43277 .31228 L .40307 .30166 L p .707 .577 .707 r
F P
0 g
s
.43277 .31228 m .41394 .81177 L .45268 .81963 L p .707 .577 .707 r
F P
0 g
s
.66237 .6258 m .65233 .67932 L .62539 .66928 L p .707 .577 .707 r
F P
0 g
s
.62539 .66928 m .63543 .61576 L .66237 .6258 L p .707 .577 .707 r
F P
0 g
s
.65073 .67922 m .65046 .71625 L .623 .71162 L p .707 .577 .707 r
F P
0 g
s
.623 .71162 m .62328 .6746 L .65073 .67922 L p .707 .577 .707 r
F P
0 g
s
.6562 .73853 m .66129 .75683 L .63506 .76125 L p .707 .577 .707 r
F P
0 g
s
.63506 .76125 m .62996 .74295 L .6562 .73853 L p .707 .577 .707 r
F P
0 g
s
.6358 .31412 m .61697 .81361 L .64007 .80347 L p .707 .577 .707 r
F P
0 g
s
.64007 .80347 m .6589 .30398 L .6358 .31412 L p .707 .577 .707 r
F P
0 g
s
.23714 .74143 m .24718 .68791 L .21653 .68036 L p .707 .577 .707 r
F P
0 g
s
.24718 .68791 m .23714 .74143 L .26851 .74574 L p .707 .577 .707 r
F P
0 g
s
.26851 .74574 m .27855 .69223 L .24718 .68791 L p .707 .577 .707 r
F P
0 g
s
.27855 .69223 m .26851 .74574 L .29752 .74641 L p .707 .577 .707 r
F P
0 g
s
.29752 .74641 m .30756 .69289 L .27855 .69223 L p .707 .577 .707 r
F P
0 g
s
.20649 .73388 m .21653 .68036 L .18959 .67032 L p .707 .577 .707 r
F P
0 g
s
.21653 .68036 m .20649 .73388 L .23714 .74143 L p .707 .577 .707 r
F P
0 g
s
.65233 .67932 m .66237 .6258 L .68296 .63735 L p .707 .577 .707 r
F P
0 g
s
.68787 .7386 m .69297 .75691 L .68125 .75533 L p .707 .577 .707 r
F P
0 g
s
.68125 .75533 m .67615 .73703 L .68787 .7386 L p .707 .577 .707 r
F P
0 g
s
.38425 .80115 m .40307 .30166 L .38532 .28934 L p .707 .577 .707 r
F P
0 g
s
.40307 .30166 m .38425 .80115 L .41394 .81177 L p .707 .577 .707 r
F P
0 g
s
.30756 .69289 m .29752 .74641 L .32133 .74335 L p .707 .577 .707 r
F P
0 g
s
.32133 .74335 m .33137 .68984 L .30756 .69289 L p .707 .577 .707 r
F P
0 g
s
.17955 .72384 m .18959 .67032 L .16901 .65877 L p .707 .577 .707 r
F P
0 g
s
.18959 .67032 m .17955 .72384 L .20649 .73388 L p .707 .577 .707 r
F P
0 g
s
.23527 .81487 m .23555 .77785 L .20438 .77571 L p .707 .577 .707 r
F P
0 g
s
.23555 .77785 m .23527 .81487 L .2671 .81431 L p .707 .577 .707 r
F P
0 g
s
.2671 .81431 m .26738 .77729 L .23555 .77785 L p .707 .577 .707 r
F P
0 g
s
.30535 .82326 m .30025 .80496 L .28894 .8088 L p .707 .577 .707 r
F P
0 g
s
.28894 .8088 m .27174 .81465 L p .28476 .81799 L .707 .577 .707 r
F P
0 g
s
.30535 .82326 m .28894 .8088 L .28476 .81799 L .707 .577 .707 r
F
.30025 .80496 m .30535 .82326 L .32884 .81356 L p F P
0 g
s
.32884 .81356 m .32375 .79526 L .3153 .79875 L p .707 .577 .707 r
F P
0 g
s
.3153 .79875 m .30025 .80496 L p .31169 .8084 L .707 .577 .707 r
F P
0 g
s
.32884 .81356 m .3153 .79875 L .31169 .8084 L .707 .577 .707 r
F
.32375 .79526 m .32884 .81356 L .34502 .8048 L p F P
0 g
s
.34502 .8048 m .33992 .7865 L .33471 .78932 L p .707 .577 .707 r
F P
0 g
s
.33471 .78932 m .32375 .79526 L p .3329 .79936 L .707 .577 .707 r
F P
0 g
s
.34502 .8048 m .33471 .78932 L .3329 .79936 L .707 .577 .707 r
F
.33992 .7865 m .34502 .8048 L .3523 .79783 L p F P
0 g
s
.3523 .79783 m .3472 .77953 L .34503 .7816 L p .707 .577 .707 r
F P
0 g
s
.34503 .7816 m .33992 .7865 L p .34572 .79181 L .707 .577 .707 r
F P
0 g
s
.3523 .79783 m .34503 .7816 L .34572 .79181 L .707 .577 .707 r
F
.33691 .79823 m .34399 .78983 L p .33867 .76744 L F P
0 g
s
.34399 .78983 m .34427 .7528 L .33718 .7612 L p .707 .577 .707 r
F P
0 g
s
.34399 .78983 m .34109 .78117 L p .34353 .75941 L .707 .577 .707 r
F P
0 g
s
.34427 .7528 m .34415 .76858 L p .34353 .75941 L .707 .577 .707 r
F P
0 g
s
.34415 .76858 m .34399 .78983 L p .34353 .75941 L .707 .577 .707 r
F P
0 g
s
.33718 .7612 m .33707 .77626 L p .33867 .76744 L .707 .577 .707 r
F P
0 g
s
.33707 .77626 m .33691 .79823 L p .33867 .76744 L .707 .577 .707 r
F P
0 g
s
.32054 .80556 m .33691 .79823 L p .32424 .77485 L .707 .577 .707 r
F P
0 g
s
.32082 .76853 m .3207 .78432 L p .32424 .77485 L .707 .577 .707 r
F P
0 g
s
.3207 .78432 m .32054 .80556 L p .32424 .77485 L .707 .577 .707 r
F P
0 g
s
.29649 .8111 m .32054 .80556 L p .30176 .78069 L .707 .577 .707 r
F P
0 g
s
.29676 .77407 m .29663 .79195 L p .30176 .78069 L .707 .577 .707 r
F P
0 g
s
.29663 .79195 m .29649 .8111 L p .30176 .78069 L .707 .577 .707 r
F P
0 g
s
.26738 .77729 m .2671 .81431 L .29649 .8111 L p .707 .577 .707 r
F P
0 g
s
.29649 .8111 m .29676 .77407 L .26738 .77729 L p .707 .577 .707 r
F P
0 g
s
.67615 .73703 m .68125 .75533 L .66129 .75683 L p .707 .577 .707 r
F P
0 g
s
.66129 .75683 m .6562 .73853 L .67615 .73703 L p .707 .577 .707 r
F P
0 g
s
.2041 .81274 m .20438 .77571 L .17692 .77109 L p .707 .577 .707 r
F P
0 g
s
.20438 .77571 m .2041 .81274 L .23527 .81487 L p .707 .577 .707 r
F P
0 g
s
.6589 .30398 m .64007 .80347 L .65008 .7914 L p .707 .577 .707 r
F P
0 g
s
.65008 .7914 m .66891 .29191 L .6589 .30398 L p .707 .577 .707 r
F P
0 g
s
.16901 .65877 m .15896 .71229 L .17955 .72384 L p .707 .577 .707 r
F P
0 g
s
.33137 .68984 m .32133 .74335 L .33762 .73688 L p .707 .577 .707 r
F P
0 g
s
.33762 .73688 m .34766 .68336 L .33137 .68984 L p .707 .577 .707 r
F P
0 g
s
.24611 .84168 m .24101 .82338 L .21106 .83029 L p .707 .577 .707 r
F P
0 g
s
.24101 .82338 m .24611 .84168 L .27684 .83295 L p .707 .577 .707 r
F P
0 g
s
.27684 .83295 m .27174 .81465 L .24101 .82338 L p .707 .577 .707 r
F P
0 g
s
.15896 .71229 m .16901 .65877 L .15679 .64685 L p .707 .577 .707 r
F P
0 g
s
.27174 .81465 m .27684 .83295 L .30535 .82326 L p .707 .577 .707 r
F P
0 g
s
.21106 .83029 m .21615 .84859 L .24611 .84168 L p .707 .577 .707 r
F P
0 g
s
.32054 .80556 m .32082 .76853 L .29676 .77407 L p .707 .577 .707 r
F P
0 g
s
.17692 .77109 m .17664 .80811 L .2041 .81274 L p .707 .577 .707 r
F P
0 g
s
.21615 .84859 m .21106 .83029 L .18482 .83471 L p .707 .577 .707 r
F P
0 g
s
.36649 .78883 m .38532 .28934 L .38124 .27651 L p .707 .577 .707 r
F P
0 g
s
.38532 .28934 m .36649 .78883 L .38425 .80115 L p .707 .577 .707 r
F P
0 g
s
.18482 .83471 m .18992 .85302 L .21615 .84859 L p .707 .577 .707 r
F P
0 g
s
.17664 .80811 m .17692 .77109 L .15586 .76442 L p .707 .577 .707 r
F P
0 g
s
.15679 .64685 m .14674 .70037 L .15896 .71229 L p .707 .577 .707 r
F P
0 g
s
.15586 .76442 m .15559 .80144 L .17664 .80811 L p .707 .577 .707 r
F P
0 g
s
.33691 .79823 m .33718 .7612 L .32082 .76853 L p .707 .577 .707 r
F P
0 g
s
.34766 .68336 m .33762 .73688 L .34478 .72762 L p .707 .577 .707 r
F P
0 g
s
.34478 .72762 m .35483 .6741 L .34766 .68336 L p .707 .577 .707 r
F P
0 g
s
.18992 .85302 m .18482 .83471 L .16486 .83621 L p .707 .577 .707 r
F P
0 g
s
.14674 .70037 m .15679 .64685 L .15413 .63571 L p .707 .577 .707 r
F P
0 g
s
.16486 .83621 m .16996 .85451 L .18992 .85302 L p .707 .577 .707 r
F P
0 g
s
.15559 .80144 m .15586 .76442 L .14327 .75637 L p .707 .577 .707 r
F P
0 g
s
.65008 .7914 m .64687 .7813 L p .6575 .54521 L .707 .577 .707 r
F P
0 g
s
.66891 .29191 m .66188 .47834 L p .6575 .54521 L .707 .577 .707 r
F P
0 g
s
.66188 .47834 m .65008 .7914 L p .6575 .54521 L .707 .577 .707 r
F P
0 g
s
.6481 .73403 m .65567 .57318 L .64687 .7813 L .707 .577 .707 r
F
.65567 .57318 m .66891 .29191 L .6575 .54521 L F
.65567 .57318 m .6575 .54521 L .64687 .7813 L F
.6481 .73403 m .66387 .3052 L .66891 .29191 L F
.64903 .69835 m .66349 .31458 L p .6481 .73403 L F P
0 g
s
.66349 .31458 m .66483 .27908 L p .66387 .3052 L .707 .577 .707 r
F P
0 g
s
.66349 .31458 m .66387 .3052 L .6481 .73403 L .707 .577 .707 r
F
.63608 .62217 m .6358 .6592 L .64363 .66168 L p F P
0 g
s
.64442 .64796 m .63608 .62217 L .64363 .66168 L .707 .577 .707 r
F
.646 .77857 m .63729 .77252 L p .6456 .62726 L F P
0 g
s
.66349 .31458 m .64903 .69835 L p .6456 .62726 L .707 .577 .707 r
F P
0 g
s
.64903 .69835 m .646 .77857 L p .6456 .62726 L .707 .577 .707 r
F P
0 g
s
.64349 .58355 m .63918 .60656 L .64475 .60969 L p .707 .577 .707 r
F P
0 g
s
.64994 .65132 m .64484 .64059 L .64945 .66352 L .707 .577 .707 r
F
.64484 .64059 m .63608 .62217 L .64442 .64796 L F
.64484 .64059 m .64442 .64796 L .64945 .66352 L F
.65092 .62687 m .63608 .62217 L p .64994 .65132 L F P
0 g
s
.64256 .58278 m .66349 .31458 L .64789 .58719 L .707 .577 .707 r
F
.63918 .60656 m .64349 .58355 L p .63827 .57923 L F P
0 g
s
.66483 .27908 m .66349 .31458 L p .62825 .76625 L .707 .577 .707 r
F P
0 g
s
.64708 .26676 m .66483 .27908 L p .64206 .58236 L .707 .577 .707 r
F P
0 g
s
.63918 .60656 m .63827 .57923 L .63213 .58759 L .707 .577 .707 r
F
.64708 .26676 m .63539 .57685 L p .62422 .61366 L F P
0 g
s
.60701 .67038 m .62305 .50879 L .62422 .61366 L .707 .577 .707 r
F
.62305 .50879 m .64708 .26676 L .62422 .61366 L F
.6358 .6592 m .63608 .62217 L .62423 .6146 L p F P
0 g
s
.6358 .6592 m .62423 .6146 L .62426 .61694 L .707 .577 .707 r
F
.6293 .59692 m .63918 .60656 L p .63213 .58759 L F P
0 g
s
.63098 .5732 m .62695 .59464 L p .63827 .57923 L .707 .577 .707 r
F P
0 g
s
.62465 .65206 m .6358 .6592 L p .62426 .61694 L .707 .577 .707 r
F P
0 g
s
.63539 .57685 m .62825 .76625 L p .62579 .75516 L .707 .577 .707 r
F P
0 g
s
.60701 .67038 m .62422 .61366 L .62579 .75516 L .707 .577 .707 r
F
.62422 .61366 m .63539 .57685 L .62579 .75516 L F
.62349 .61412 m .62321 .65114 L .62465 .65206 L p F P
0 g
s
.62426 .61694 m .62349 .61412 L .62465 .65206 L .707 .577 .707 r
F
.62423 .6146 m .62349 .61412 L p .62426 .61694 L F P
0 g
s
.62695 .59464 m .6293 .59692 L p .63213 .58759 L .707 .577 .707 r
F P
0 g
s
.62825 .76625 m .59855 .75563 L p .60701 .67038 L .707 .577 .707 r
F P
0 g
s
.62825 .76625 m .63539 .57685 L p .64206 .58236 L .707 .577 .707 r
F P
0 g
s
.63633 .55174 m .64708 .26676 L p .64297 .52516 L .707 .577 .707 r
F P
0 g
s
.637 .54112 m .63434 .52998 L p .62807 .58484 L .707 .577 .707 r
F P
0 g
s
.62695 .59464 m .63098 .5732 L p .62807 .58484 L .707 .577 .707 r
F P
0 g
s
.63098 .5732 m .637 .54112 L p .62807 .58484 L .707 .577 .707 r
F P
0 g
s
.63539 .57685 m .63633 .55174 L p .64206 .58236 L .707 .577 .707 r
F P
0 g
s
.63633 .55174 m .64297 .52516 L .64206 .58236 L .707 .577 .707 r
F
.637 .54112 m .63098 .5732 L p .63827 .57923 L F P
0 g
s
.64922 .55305 m .637 .54112 L p .63827 .57923 L .707 .577 .707 r
F P
0 g
s
.64349 .58355 m .64922 .55305 L p .63827 .57923 L .707 .577 .707 r
F P
0 g
s
.63729 .77252 m .62825 .76625 L p .64256 .58278 L .707 .577 .707 r
F P
0 g
s
.64256 .58278 m .64789 .58719 L .63729 .77252 L .707 .577 .707 r
F
.64922 .55305 m .64349 .58355 L p .65124 .61333 L F P
0 g
s
.64475 .60969 m .65124 .61333 L p .64349 .58355 L .707 .577 .707 r
F P
0 g
s
.64363 .66168 m .64945 .66352 L p .64442 .64796 L .707 .577 .707 r
F P
0 g
s
.64945 .66352 m .65685 .66586 L p .64994 .65132 L .707 .577 .707 r
F P
0 g
s
.65685 .66586 m .65713 .62884 L .65092 .62687 L p .707 .577 .707 r
F P
0 g
s
.65685 .66586 m .65092 .62687 L .64994 .65132 L .707 .577 .707 r
F
.66483 .27908 m .66491 .27934 L p .66387 .3052 L F P
0 g
s
.66491 .27934 m .66891 .29191 L p .66387 .3052 L .707 .577 .707 r
F P
0 g
s
.646 .77857 m .64903 .69835 L p .6481 .73403 L .707 .577 .707 r
F P
0 g
s
.65124 .61333 m .65976 .61811 L p .65231 .57212 L .707 .577 .707 r
F P
0 g
s
.65231 .57212 m .64922 .55305 L .65124 .61333 L .707 .577 .707 r
F
.65017 .72604 m .67013 .72454 L p .64678 .70888 L F P
0 g
s
.64508 .70774 m .64652 .71292 L p .64678 .70888 L .707 .577 .707 r
F P
0 g
s
.64652 .71292 m .65017 .72604 L p .64678 .70888 L .707 .577 .707 r
F P
0 g
s
.67013 .72454 m .66503 .70624 L .64687 .7076 L p .707 .577 .707 r
F P
0 g
s
.64687 .7076 m .64508 .70774 L p .64678 .70888 L .707 .577 .707 r
F P
0 g
s
.67013 .72454 m .64687 .7076 L .64678 .70888 L .707 .577 .707 r
F
.65976 .61811 m .66981 .56459 L .65275 .55503 L p F P
0 g
s
.65275 .55503 m .64922 .55305 L p .65231 .57212 L .707 .577 .707 r
F P
0 g
s
.65976 .61811 m .65275 .55503 L .65231 .57212 L .707 .577 .707 r
F
.64687 .7813 m .646 .77857 L p .6481 .73403 L F P
0 g
s
.14327 .75637 m .14299 .79339 L .15559 .80144 L p .707 .577 .707 r
F P
0 g
s
.15413 .63571 m .14408 .68923 L .14674 .70037 L p .707 .577 .707 r
F P
0 g
s
.16996 .85451 m .16486 .83621 L .15314 .83463 L p .707 .577 .707 r
F P
0 g
s
.15314 .83463 m .15824 .85294 L .16996 .85451 L p .707 .577 .707 r
F P
0 g
s
.38124 .27651 m .36242 .776 L .36649 .78883 L p .707 .577 .707 r
F P
0 g
s
.36242 .776 m .38124 .27651 L .39125 .26444 L p .707 .577 .707 r
F P
0 g
s
.35483 .6741 m .34478 .72762 L .34212 .71648 L p .707 .577 .707 r
F P
0 g
s
.34212 .71648 m .35217 .66297 L .35483 .6741 L p .707 .577 .707 r
F P
0 g
s
.14408 .68923 m .15413 .63571 L .16129 .62645 L p .707 .577 .707 r
F P
0 g
s
.14299 .79339 m .14327 .75637 L .14038 .74771 L p .707 .577 .707 r
F P
0 g
s
.14038 .74771 m .1401 .78474 L .14299 .79339 L p .707 .577 .707 r
F P
0 g
s
.16129 .62645 m .15125 .67997 L .14408 .68923 L p .707 .577 .707 r
F P
0 g
s
.15824 .85294 m .15314 .83463 L .15081 .83014 L p .707 .577 .707 r
F P
0 g
s
.34137 .74415 m .34109 .78117 L .3285 .77312 L p .707 .577 .707 r
F P
0 g
s
.33824 .79177 m .33314 .77346 L .34021 .77441 L p .707 .577 .707 r
F P
0 g
s
.34109 .78117 m .34124 .76202 L p .34427 .7528 L .707 .577 .707 r
F P
0 g
s
.34021 .77441 m .34486 .77504 L p .33892 .79005 L .707 .577 .707 r
F P
0 g
s
.33824 .79177 m .34021 .77441 L .33892 .79005 L .707 .577 .707 r
F
.34124 .76202 m .34137 .74415 L .34245 .74737 L p F P
0 g
s
.34245 .74737 m .34427 .7528 L p .34124 .76202 L .707 .577 .707 r
F P
0 g
s
.15081 .83014 m .15591 .84845 L .15824 .85294 L p .707 .577 .707 r
F P
0 g
s
.35217 .66297 m .34212 .71648 L .3299 .70456 L p .707 .577 .707 r
F P
0 g
s
.3299 .70456 m .33995 .65104 L .35217 .66297 L p .707 .577 .707 r
F P
0 g
s
.15125 .67997 m .16129 .62645 L .17758 .61998 L p .707 .577 .707 r
F P
0 g
s
.3472 .77953 m .3523 .79783 L .34996 .79334 L p .707 .577 .707 r
F P
0 g
s
.34996 .79334 m .34486 .77504 L .3472 .77953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.1401 .78474 m .14038 .74771 L .14746 .73931 L p .707 .577 .707 r
F P
0 g
s
.37242 .76393 m .39125 .26444 L .41435 .2543 L p .707 .577 .707 r
F P
0 g
s
.39125 .26444 m .37242 .76393 L .36242 .776 L p .707 .577 .707 r
F P
0 g
s
.14746 .73931 m .14718 .77634 L .1401 .78474 L p .707 .577 .707 r
F P
0 g
s
.17758 .61998 m .16754 .6735 L .15125 .67997 L p .707 .577 .707 r
F P
0 g
s
.33995 .65104 m .3299 .70456 L .30932 .69301 L p .707 .577 .707 r
F P
0 g
s
.30932 .69301 m .31936 .63949 L .33995 .65104 L p .707 .577 .707 r
F P
0 g
s
.3285 .77312 m .32878 .7361 L .34137 .74415 L p .707 .577 .707 r
F P
0 g
s
.15591 .84845 m .15081 .83014 L .15808 .82317 L p .707 .577 .707 r
F P
0 g
s
.16754 .6735 m .17758 .61998 L .20139 .61692 L p .707 .577 .707 r
F P
0 g
s
.15808 .82317 m .16318 .84148 L .15591 .84845 L p .707 .577 .707 r
F P
0 g
s
.34486 .77504 m .34996 .79334 L .33824 .79177 L p .707 .577 .707 r
F P
0 g
s
.59855 .75563 m .61738 .25614 L .64708 .26676 L p .707 .577 .707 r
F P
0 g
s
.14718 .77634 m .14746 .73931 L .16383 .73198 L p .707 .577 .707 r
F P
0 g
s
.20139 .61692 m .19135 .67044 L .16754 .6735 L p .707 .577 .707 r
F P
0 g
s
.31936 .63949 m .30932 .69301 L .28238 .68297 L p .707 .577 .707 r
F P
0 g
s
.28238 .68297 m .29242 .62945 L .31936 .63949 L p .707 .577 .707 r
F P
0 g
s
.16383 .73198 m .16355 .76901 L .14718 .77634 L p .707 .577 .707 r
F P
0 g
s
.41435 .2543 m .39552 .75379 L .37242 .76393 L p .707 .577 .707 r
F P
0 g
s
.39552 .75379 m .41435 .2543 L .44829 .24709 L p .707 .577 .707 r
F P
0 g
s
.19135 .67044 m .20139 .61692 L .2304 .61759 L p .707 .577 .707 r
F P
0 g
s
.32878 .7361 m .3285 .77312 L .30745 .76646 L p .707 .577 .707 r
F P
0 g
s
.30745 .76646 m .30773 .72943 L .32878 .7361 L p .707 .577 .707 r
F P
0 g
s
.16318 .84148 m .15808 .82317 L .17426 .81441 L p .707 .577 .707 r
F P
0 g
s
.71735 .6357 m .7274 .58218 L .69674 .57463 L p .707 .577 .707 r
F P
0 g
s
.74582 .63962 m .74872 .64002 L p .7402 .61691 L .707 .577 .707 r
F P
0 g
s
.74872 .64002 m .75876 .5865 L .7274 .58218 L p .707 .577 .707 r
F P
0 g
s
.75876 .5865 m .75824 .58929 L p .77773 .64068 L .707 .577 .707 r
F P
0 g
s
.75824 .58929 m .74872 .64002 L .77534 .64063 L p .707 .577 .707 r
F P
0 g
s
.77534 .64063 m .77773 .64068 L p .75824 .58929 L .707 .577 .707 r
F P
0 g
s
.77773 .64068 m .78777 .58716 L .75876 .5865 L p .707 .577 .707 r
F P
0 g
s
.78777 .58716 m .78656 .59365 L p .80154 .63763 L .707 .577 .707 r
F P
0 g
s
.78656 .59365 m .77773 .64068 L .79997 .63783 L p .707 .577 .707 r
F P
0 g
s
.79997 .63783 m .80154 .63763 L p .78656 .59365 L .707 .577 .707 r
F P
0 g
s
.80154 .63763 m .81159 .58411 L .78777 .58716 L p .707 .577 .707 r
F P
0 g
s
.81159 .58411 m .8106 .58937 L p .81783 .63115 L .707 .577 .707 r
F P
0 g
s
.8106 .58937 m .80154 .63763 L .81691 .63152 L p .707 .577 .707 r
F P
0 g
s
.81691 .63152 m .81783 .63115 L p .8106 .58937 L .707 .577 .707 r
F P
0 g
s
.81783 .63115 m .82787 .57764 L .81159 .58411 L p .707 .577 .707 r
F P
0 g
s
.82787 .57764 m .81783 .63115 L .82458 .62243 L p .707 .577 .707 r
F P
0 g
s
.82458 .62243 m .825 .6219 L p .82734 .5858 L .707 .577 .707 r
F P
0 g
s
.82734 .5858 m .82787 .57764 L .82458 .62243 L .707 .577 .707 r
F
.8174 .61896 m .81729 .63405 L p .8242 .64758 L F P
0 g
s
.82448 .61056 m .8174 .61896 L p .82263 .64097 L .707 .577 .707 r
F P
0 g
s
.8242 .64758 m .82437 .62522 L p .82263 .64097 L .707 .577 .707 r
F P
0 g
s
.82437 .62522 m .82448 .61056 L p .82263 .64097 L .707 .577 .707 r
F P
0 g
s
.825 .6219 m .83504 .56838 L .82787 .57764 L p .707 .577 .707 r
F P
0 g
s
.83504 .56838 m .825 .6219 L .82482 .62116 L p .707 .577 .707 r
F P
0 g
s
.82448 .61056 m .82437 .62522 L p .82131 .63893 L .707 .577 .707 r
F P
0 g
s
.82159 .60191 m .82448 .61056 L p .82197 .633 L .707 .577 .707 r
F P
0 g
s
.82131 .63893 m .82149 .6153 L p .82197 .633 L .707 .577 .707 r
F P
0 g
s
.82149 .6153 m .82159 .60191 L p .82197 .633 L .707 .577 .707 r
F P
0 g
s
.81729 .63405 m .81712 .65598 L .82005 .65251 L p .707 .577 .707 r
F P
0 g
s
.82005 .65251 m .8242 .64758 L p .81729 .63405 L .707 .577 .707 r
F P
0 g
s
.81712 .65598 m .8174 .61896 L .80103 .62629 L p .707 .577 .707 r
F P
0 g
s
.82159 .60191 m .82131 .63893 L .80872 .63088 L p .707 .577 .707 r
F P
0 g
s
.83238 .55724 m .82234 .61076 L .82133 .60978 L p .707 .577 .707 r
F P
0 g
s
.80899 .59385 m .82159 .60191 L p .81084 .6261 L .707 .577 .707 r
F P
0 g
s
.80872 .63088 m .80891 .60527 L p .81084 .6261 L .707 .577 .707 r
F P
0 g
s
.80891 .60527 m .80899 .59385 L p .81084 .6261 L .707 .577 .707 r
F P
0 g
s
.80103 .62629 m .80092 .64095 L p .81712 .65598 L .707 .577 .707 r
F P
0 g
s
.80075 .66331 m .80103 .62629 L .77698 .63183 L p .707 .577 .707 r
F P
0 g
s
.80899 .59385 m .80872 .63088 L .78766 .62421 L p .707 .577 .707 r
F P
0 g
s
.82016 .54531 m .81012 .59883 L .80821 .59776 L p .707 .577 .707 r
F P
0 g
s
.78766 .62421 m .78794 .58719 L .80899 .59385 L p .707 .577 .707 r
F P
0 g
s
.80821 .59776 m .78953 .58728 L p .80525 .56575 L .707 .577 .707 r
F P
0 g
s
.80525 .56575 m .82016 .54531 L .80821 .59776 L .707 .577 .707 r
F
.82133 .60978 m .81012 .59883 L p .8205 .57944 L F P
0 g
s
.8205 .57944 m .83238 .55724 L .82133 .60978 L .707 .577 .707 r
F
.82482 .62116 m .82234 .61076 L p .82809 .59157 L F P
0 g
s
.82809 .59157 m .83504 .56838 L .82482 .62116 L .707 .577 .707 r
F
.82437 .62522 m .8242 .64758 L .82297 .64388 L p F P
0 g
s
.82297 .64388 m .82131 .63893 L p .82437 .62522 L .707 .577 .707 r
F P
0 g
s
.80092 .64095 m .80075 .66331 L .80688 .66057 L p .707 .577 .707 r
F P
0 g
s
.80688 .66057 m .81712 .65598 L p .80092 .64095 L .707 .577 .707 r
F P
0 g
s
.77698 .63183 m .77688 .64522 L p .80075 .66331 L .707 .577 .707 r
F P
0 g
s
.77688 .64522 m .7767 .66885 L .78418 .66713 L p .707 .577 .707 r
F P
0 g
s
.78418 .66713 m .80075 .66331 L p .77688 .64522 L .707 .577 .707 r
F P
0 g
s
.7476 .63504 m .74751 .64646 L p .7767 .66885 L .707 .577 .707 r
F P
0 g
s
.74751 .64646 m .74732 .67206 L .75367 .67137 L p .707 .577 .707 r
F P
0 g
s
.75367 .67137 m .7767 .66885 L p .74751 .64646 L .707 .577 .707 r
F P
0 g
s
.7274 .58218 m .71735 .6357 L .74582 .63962 L p .707 .577 .707 r
F P
0 g
s
.7402 .61691 m .7274 .58218 L .74582 .63962 L .707 .577 .707 r
F
.17426 .81441 m .17936 .83271 L .16318 .84148 L p F P
0 g
s
.29242 .62945 m .28238 .68297 L .25173 .67542 L p .707 .577 .707 r
F P
0 g
s
.25173 .67542 m .26177 .6219 L .29242 .62945 L p .707 .577 .707 r
F P
0 g
s
.22036 .67111 m .2304 .61759 L .26177 .6219 L p .707 .577 .707 r
F P
0 g
s
.2304 .61759 m .22036 .67111 L .19135 .67044 L p .707 .577 .707 r
F P
0 g
s
.33314 .77346 m .33824 .79177 L .31829 .79326 L p .707 .577 .707 r
F P
0 g
s
.31829 .79326 m .31319 .77496 L .33314 .77346 L p .707 .577 .707 r
F P
0 g
s
.6867 .62815 m .69674 .57463 L .66981 .56459 L p .707 .577 .707 r
F P
0 g
s
.69674 .57463 m .6867 .62815 L .71735 .6357 L p .707 .577 .707 r
F P
0 g
s
.16355 .76901 m .16383 .73198 L .18788 .72644 L p .707 .577 .707 r
F P
0 g
s
.26177 .6219 m .25173 .67542 L .22036 .67111 L p .707 .577 .707 r
F P
0 g
s
.61738 .25614 m .59855 .75563 L .55982 .74776 L p .707 .577 .707 r
F P
0 g
s
.55982 .74776 m .57865 .24827 L .61738 .25614 L p .707 .577 .707 r
F P
0 g
s
.18788 .72644 m .1876 .76347 L .16355 .76901 L p .707 .577 .707 r
F P
0 g
s
.66981 .56459 m .65976 .61811 L .6867 .62815 L p .707 .577 .707 r
F P
0 g
s
.42947 .74658 m .44829 .24709 L .48975 .24352 L p .707 .577 .707 r
F P
0 g
s
.44829 .24709 m .42947 .74658 L .39552 .75379 L p .707 .577 .707 r
F P
0 g
s
.30773 .72943 m .30745 .76646 L .27999 .76183 L p .707 .577 .707 r
F P
0 g
s
.27999 .76183 m .28027 .7248 L .30773 .72943 L p .707 .577 .707 r
F P
0 g
s
.71548 .67263 m .71576 .6356 L .68459 .63347 L p .707 .577 .707 r
F P
0 g
s
.71576 .6356 m .71548 .67263 L .74732 .67206 L p .707 .577 .707 r
F P
0 g
s
.74732 .67206 m .7476 .63504 L .71576 .6356 L p .707 .577 .707 r
F P
0 g
s
.7767 .66885 m .77698 .63183 L .7476 .63504 L p .707 .577 .707 r
F P
0 g
s
.17936 .83271 m .17426 .81441 L .19775 .80471 L p .707 .577 .707 r
F P
0 g
s
.68431 .67049 m .68459 .63347 L .65713 .62884 L p .707 .577 .707 r
F P
0 g
s
.68459 .63347 m .68431 .67049 L .71548 .67263 L p .707 .577 .707 r
F P
0 g
s
.1876 .76347 m .18788 .72644 L .21726 .72323 L p .707 .577 .707 r
F P
0 g
s
.19775 .80471 m .20285 .82301 L .17936 .83271 L p .707 .577 .707 r
F P
0 g
s
.31319 .77496 m .31829 .79326 L .29205 .79768 L p .707 .577 .707 r
F P
0 g
s
.29205 .79768 m .28695 .77938 L .31319 .77496 L p .707 .577 .707 r
F P
0 g
s
.57865 .24827 m .55982 .74776 L .51584 .74341 L p .707 .577 .707 r
F P
0 g
s
.51584 .74341 m .53467 .24392 L .57865 .24827 L p .707 .577 .707 r
F P
0 g
s
.72632 .71321 m .72122 .69491 L .69127 .70182 L p .707 .577 .707 r
F P
0 g
s
.72122 .69491 m .72632 .71321 L .75706 .70448 L p .707 .577 .707 r
F P
0 g
s
.75706 .70448 m .75196 .68618 L .72122 .69491 L p .707 .577 .707 r
F P
0 g
s
.75196 .68618 m .75706 .70448 L .78556 .69479 L p .707 .577 .707 r
F P
0 g
s
.78556 .69479 m .78047 .67649 L .75196 .68618 L p .707 .577 .707 r
F P
0 g
s
.28027 .7248 m .27999 .76183 L .24882 .75969 L p .707 .577 .707 r
F P
0 g
s
.24882 .75969 m .2491 .72267 L .28027 .7248 L p .707 .577 .707 r
F P
0 g
s
.65713 .62884 m .65685 .66586 L .68431 .67049 L p .707 .577 .707 r
F P
0 g
s
.47093 .743 m .48975 .24352 L .53467 .24392 L p .707 .577 .707 r
F P
0 g
s
.48975 .24352 m .47093 .743 L .42947 .74658 L p .707 .577 .707 r
F P
0 g
s
.69127 .70182 m .69637 .72012 L .72632 .71321 L p .707 .577 .707 r
F P
0 g
s
.21726 .72323 m .21698 .76026 L .1876 .76347 L p .707 .577 .707 r
F P
0 g
s
.21698 .76026 m .21726 .72323 L .2491 .72267 L p .707 .577 .707 r
F P
0 g
s
.53467 .24392 m .51584 .74341 L .47093 .743 L p .707 .577 .707 r
F P
0 g
s
.2491 .72267 m .24882 .75969 L .21698 .76026 L p .707 .577 .707 r
F P
0 g
s
.69637 .72012 m .69127 .70182 L .66503 .70624 L p .707 .577 .707 r
F P
0 g
s
.20285 .82301 m .19775 .80471 L .22626 .79502 L p .707 .577 .707 r
F P
0 g
s
.66503 .70624 m .67013 .72454 L .69637 .72012 L p .707 .577 .707 r
F P
0 g
s
.78047 .67649 m .78556 .69479 L .80906 .68509 L p .707 .577 .707 r
F P
0 g
s
.80906 .68509 m .80396 .66679 L .78047 .67649 L p .707 .577 .707 r
F P
0 g
s
.22626 .79502 m .23136 .81333 L .20285 .82301 L p .707 .577 .707 r
F P
0 g
s
.28695 .77938 m .29205 .79768 L .26209 .8046 L p .707 .577 .707 r
F P
0 g
s
.26209 .8046 m .257 .78629 L .28695 .77938 L p .707 .577 .707 r
F P
0 g
s
.23136 .81333 m .22626 .79502 L .257 .78629 L p .707 .577 .707 r
F P
0 g
s
.257 .78629 m .26209 .8046 L .23136 .81333 L p .707 .577 .707 r
F P
0 g
s
.80396 .66679 m .80906 .68509 L .82523 .67633 L p .707 .577 .707 r
F P
0 g
s
.82523 .67633 m .82014 .65803 L .80396 .66679 L p .707 .577 .707 r
F P
0 g
s
.65017 .72604 m .64508 .70774 L .63336 .70616 L p .707 .577 .707 r
F P
0 g
s
.63434 .52998 m .6243 .5835 L .62695 .59464 L p .707 .577 .707 r
F P
0 g
s
.63336 .70616 m .63846 .72447 L .65017 .72604 L p .707 .577 .707 r
F P
0 g
s
.82014 .65803 m .82523 .67633 L .83251 .66936 L p .707 .577 .707 r
F P
0 g
s
.83251 .66936 m .82741 .65106 L .82014 .65803 L p .707 .577 .707 r
F P
0 g
s
.62321 .65114 m .62349 .61412 L .62059 .60547 L p .707 .577 .707 r
F P
0 g
s
.82234 .61076 m .83238 .55724 L .83504 .56838 L p .707 .577 .707 r
F P
0 g
s
.6243 .5835 m .63434 .52998 L .64151 .52072 L p .707 .577 .707 r
F P
0 g
s
.62059 .60547 m .62031 .64249 L .62321 .65114 L p .707 .577 .707 r
F P
0 g
s
.63846 .72447 m .63336 .70616 L .63102 .70167 L p .707 .577 .707 r
F P
0 g
s
.64151 .52072 m .63146 .57424 L .6243 .5835 L p .707 .577 .707 r
F P
0 g
s
.63102 .70167 m .63612 .71998 L .63846 .72447 L p .707 .577 .707 r
F P
0 g
s
.82741 .65106 m .83251 .66936 L .83017 .66487 L p .707 .577 .707 r
F P
0 g
s
.83017 .66487 m .82508 .64657 L .82741 .65106 L p .707 .577 .707 r
F P
0 g
s
.62031 .64249 m .62059 .60547 L .62767 .59707 L p .707 .577 .707 r
F P
0 g
s
.81012 .59883 m .82016 .54531 L .83238 .55724 L p .707 .577 .707 r
F P
0 g
s
.63146 .57424 m .64151 .52072 L .65779 .51425 L p .707 .577 .707 r
F P
0 g
s
.62767 .59707 m .6274 .63409 L .62031 .64249 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.37434 .64939 m .38439 .59587 L .35373 .58832 L p .707 .577 .707 r
F P
0 g
s
.38439 .59587 m .37434 .64939 L .40571 .65371 L p .707 .577 .707 r
F P
0 g
s
.40571 .65371 m .41575 .60019 L .38439 .59587 L p .707 .577 .707 r
F P
0 g
s
.65779 .51425 m .64775 .56777 L .63146 .57424 L p .707 .577 .707 r
F P
0 g
s
.63612 .71998 m .63102 .70167 L .6383 .6947 L p .707 .577 .707 r
F P
0 g
s
.6383 .6947 m .6434 .71301 L .63612 .71998 L p .707 .577 .707 r
F P
0 g
s
.41575 .60019 m .40571 .65371 L .43472 .65437 L p .707 .577 .707 r
F P
0 g
s
.43472 .65437 m .44476 .60085 L .41575 .60019 L p .707 .577 .707 r
F P
0 g
s
.34369 .64184 m .35373 .58832 L .3268 .57828 L p .707 .577 .707 r
F P
0 g
s
.35373 .58832 m .34369 .64184 L .37434 .64939 L p .707 .577 .707 r
F P
0 g
s
.78953 .58728 m .79958 .53376 L .82016 .54531 L p .707 .577 .707 r
F P
0 g
s
.82508 .64657 m .83017 .66487 L .81845 .66329 L p .707 .577 .707 r
F P
0 g
s
.81845 .66329 m .81336 .64499 L .82508 .64657 L p .707 .577 .707 r
F P
0 g
s
.64775 .56777 m .65779 .51425 L .68161 .5112 L p .707 .577 .707 r
F P
0 g
s
.6274 .63409 m .62767 .59707 L .64404 .58974 L p .707 .577 .707 r
F P
0 g
s
.44476 .60085 m .43472 .65437 L .45853 .65132 L p .707 .577 .707 r
F P
0 g
s
.45853 .65132 m .46858 .5978 L .44476 .60085 L p .707 .577 .707 r
F P
0 g
s
.64404 .58974 m .64376 .62676 L .6274 .63409 L p .707 .577 .707 r
F P
0 g
s
.31675 .6318 m .3268 .57828 L .30621 .56674 L p .707 .577 .707 r
F P
0 g
s
.3268 .57828 m .31675 .6318 L .34369 .64184 L p .707 .577 .707 r
F P
0 g
s
.68161 .5112 m .67156 .56471 L .64775 .56777 L p .707 .577 .707 r
F P
0 g
s
.79958 .53376 m .78953 .58728 L .76259 .57724 L p .707 .577 .707 r
F P
0 g
s
.76259 .57724 m .77264 .52372 L .79958 .53376 L p .707 .577 .707 r
F P
0 g
s
.67156 .56471 m .68161 .5112 L .71062 .51186 L p .707 .577 .707 r
F P
0 g
s
.37247 .72284 m .37275 .68581 L .34158 .68367 L p .707 .577 .707 r
F P
0 g
s
.37275 .68581 m .37247 .72284 L .40431 .72227 L p .707 .577 .707 r
F P
0 g
s
.40431 .72227 m .40459 .68525 L .37275 .68581 L p .707 .577 .707 r
F P
0 g
s
.6434 .71301 m .6383 .6947 L .65447 .68594 L p .707 .577 .707 r
F P
0 g
s
.44255 .73123 m .43746 .71292 L .42615 .71677 L p .707 .577 .707 r
F P
0 g
s
.42615 .71677 m .40895 .72261 L p .42196 .72595 L .707 .577 .707 r
F P
0 g
s
.44255 .73123 m .42615 .71677 L .42196 .72595 L .707 .577 .707 r
F
.43746 .71292 m .44255 .73123 L .46605 .72153 L p F P
0 g
s
.46605 .72153 m .46095 .70322 L .4525 .70671 L p .707 .577 .707 r
F P
0 g
s
.4525 .70671 m .43746 .71292 L p .44889 .71636 L .707 .577 .707 r
F P
0 g
s
.46605 .72153 m .4525 .70671 L .44889 .71636 L .707 .577 .707 r
F
.46095 .70322 m .46605 .72153 L .48222 .71276 L p F P
0 g
s
.48222 .71276 m .47713 .69446 L .47192 .69728 L p .707 .577 .707 r
F P
0 g
s
.47192 .69728 m .46095 .70322 L p .4701 .70733 L .707 .577 .707 r
F P
0 g
s
.48222 .71276 m .47192 .69728 L .4701 .70733 L .707 .577 .707 r
F
.47713 .69446 m .48222 .71276 L .4895 .70579 L p F P
0 g
s
.4895 .70579 m .4844 .68749 L .48223 .68957 L p .707 .577 .707 r
F P
0 g
s
.48223 .68957 m .47713 .69446 L p .48292 .69977 L .707 .577 .707 r
F P
0 g
s
.4895 .70579 m .48223 .68957 L .48292 .69977 L .707 .577 .707 r
F
.47411 .70619 m .48119 .69779 L p .47587 .6754 L F P
0 g
s
.48119 .69779 m .48147 .66076 L .47439 .66916 L p .707 .577 .707 r
F P
0 g
s
.48119 .69779 m .4783 .68914 L p .48073 .66737 L .707 .577 .707 r
F P
0 g
s
.48147 .66076 m .48135 .67655 L p .48073 .66737 L .707 .577 .707 r
F P
0 g
s
.48135 .67655 m .48119 .69779 L p .48073 .66737 L .707 .577 .707 r
F P
0 g
s
.47439 .66916 m .47428 .68423 L p .47587 .6754 L .707 .577 .707 r
F P
0 g
s
.47428 .68423 m .47411 .70619 L p .47587 .6754 L .707 .577 .707 r
F P
0 g
s
.45774 .71352 m .47411 .70619 L p .46144 .68281 L .707 .577 .707 r
F P
0 g
s
.45802 .6765 m .4579 .69228 L p .46144 .68281 L .707 .577 .707 r
F P
0 g
s
.4579 .69228 m .45774 .71352 L p .46144 .68281 L .707 .577 .707 r
F P
0 g
s
.43369 .71906 m .45774 .71352 L p .43896 .68865 L .707 .577 .707 r
F P
0 g
s
.43397 .68204 m .43383 .69991 L p .43896 .68865 L .707 .577 .707 r
F P
0 g
s
.43383 .69991 m .43369 .71906 L p .43896 .68865 L .707 .577 .707 r
F P
0 g
s
.40459 .68525 m .40431 .72227 L .43369 .71906 L p .707 .577 .707 r
F P
0 g
s
.43369 .71906 m .43397 .68204 L .40459 .68525 L p .707 .577 .707 r
F P
0 g
s
.65447 .68594 m .65957 .70424 L .6434 .71301 L p .707 .577 .707 r
F P
0 g
s
.64376 .62676 m .64404 .58974 L .66809 .5842 L p .707 .577 .707 r
F P
0 g
s
.81336 .64499 m .81845 .66329 L .7985 .66479 L p .707 .577 .707 r
F P
0 g
s
.7985 .66479 m .7934 .64649 L .81336 .64499 L p .707 .577 .707 r
F P
0 g
s
.3413 .7207 m .34158 .68367 L .31412 .67905 L p .707 .577 .707 r
F P
0 g
s
.34158 .68367 m .3413 .7207 L .37247 .72284 L p .707 .577 .707 r
F P
0 g
s
.30621 .56674 m .29616 .62025 L .31675 .6318 L p .707 .577 .707 r
F P
0 g
s
.46858 .5978 m .45853 .65132 L .47482 .64484 L p .707 .577 .707 r
F P
0 g
s
.47482 .64484 m .48486 .59132 L .46858 .5978 L p .707 .577 .707 r
F P
0 g
s
.38331 .74964 m .37821 .73134 L .34826 .73825 L p .707 .577 .707 r
F P
0 g
s
.37821 .73134 m .38331 .74964 L .41405 .74091 L p .707 .577 .707 r
F P
0 g
s
.41405 .74091 m .40895 .72261 L .37821 .73134 L p .707 .577 .707 r
F P
0 g
s
.29616 .62025 m .30621 .56674 L .29399 .55481 L p .707 .577 .707 r
F P
0 g
s
.40895 .72261 m .41405 .74091 L .44255 .73123 L p .707 .577 .707 r
F P
0 g
s
.77264 .52372 m .76259 .57724 L .73194 .56969 L p .707 .577 .707 r
F P
0 g
s
.73194 .56969 m .74199 .51618 L .77264 .52372 L p .707 .577 .707 r
F P
0 g
s
.70057 .56538 m .71062 .51186 L .74199 .51618 L p .707 .577 .707 r
F P
0 g
s
.71062 .51186 m .70057 .56538 L .67156 .56471 L p .707 .577 .707 r
F P
0 g
s
.34826 .73825 m .35336 .75656 L .38331 .74964 L p .707 .577 .707 r
F P
0 g
s
.66809 .5842 m .66782 .62122 L .64376 .62676 L p .707 .577 .707 r
F P
0 g
s
.45774 .71352 m .45802 .6765 L .43397 .68204 L p .707 .577 .707 r
F P
0 g
s
.74199 .51618 m .73194 .56969 L .70057 .56538 L p .707 .577 .707 r
F P
0 g
s
.31412 .67905 m .31384 .71607 L .3413 .7207 L p .707 .577 .707 r
F P
0 g
s
.78794 .58719 m .78766 .62421 L .76021 .61958 L p .707 .577 .707 r
F P
0 g
s
.76021 .61958 m .76048 .58256 L .78794 .58719 L p .707 .577 .707 r
F P
0 g
s
.35336 .75656 m .34826 .73825 L .32202 .74267 L p .707 .577 .707 r
F P
0 g
s
.32202 .74267 m .32712 .76098 L .35336 .75656 L p .707 .577 .707 r
F P
0 g
s
.31384 .71607 m .31412 .67905 L .29307 .67238 L p .707 .577 .707 r
F P
0 g
s
.66782 .62122 m .66809 .5842 L .69748 .58099 L p .707 .577 .707 r
F P
0 g
s
.65957 .70424 m .65447 .68594 L .67797 .67624 L p .707 .577 .707 r
F P
0 g
s
.29399 .55481 m .28394 .60833 L .29616 .62025 L p .707 .577 .707 r
F P
0 g
s
.67797 .67624 m .68306 .69454 L .65957 .70424 L p .707 .577 .707 r
F P
0 g
s
.7934 .64649 m .7985 .66479 L .77226 .66921 L p .707 .577 .707 r
F P
0 g
s
.77226 .66921 m .76716 .65091 L .7934 .64649 L p .707 .577 .707 r
F P
0 g
s
.29307 .67238 m .29279 .7094 L .31384 .71607 L p .707 .577 .707 r
F P
0 g
s
.76048 .58256 m .76021 .61958 L .72903 .61745 L p .707 .577 .707 r
F P
0 g
s
.72903 .61745 m .72931 .58042 L .76048 .58256 L p .707 .577 .707 r
F P
0 g
s
.69748 .58099 m .6972 .61801 L .66782 .62122 L p .707 .577 .707 r
F P
0 g
s
.47411 .70619 m .47439 .66916 L .45802 .6765 L p .707 .577 .707 r
F P
0 g
s
.48486 .59132 m .47482 .64484 L .48199 .63558 L p .707 .577 .707 r
F P
0 g
s
.48199 .63558 m .49203 .58207 L .48486 .59132 L p .707 .577 .707 r
F P
0 g
s
.32712 .76098 m .32202 .74267 L .30207 .74417 L p .707 .577 .707 r
F P
0 g
s
.6972 .61801 m .69748 .58099 L .72931 .58042 L p .707 .577 .707 r
F P
0 g
s
.28394 .60833 m .29399 .55481 L .29133 .54367 L p .707 .577 .707 r
F P
0 g
s
.72931 .58042 m .72903 .61745 L .6972 .61801 L p .707 .577 .707 r
F P
0 g
s
.30207 .74417 m .30716 .76247 L .32712 .76098 L p .707 .577 .707 r
F P
0 g
s
.29279 .7094 m .29307 .67238 L .28047 .66433 L p .707 .577 .707 r
F P
0 g
s
.68306 .69454 m .67797 .67624 L .70648 .66655 L p .707 .577 .707 r
F P
0 g
s
.70648 .66655 m .71157 .68485 L .68306 .69454 L p .707 .577 .707 r
F P
0 g
s
.76716 .65091 m .77226 .66921 L .74231 .67613 L p .707 .577 .707 r
F P
0 g
s
.74231 .67613 m .73721 .65782 L .76716 .65091 L p .707 .577 .707 r
F P
0 g
s
.28047 .66433 m .2802 .70135 L .29279 .7094 L p .707 .577 .707 r
F P
0 g
s
.29133 .54367 m .28129 .59719 L .28394 .60833 L p .707 .577 .707 r
F P
0 g
s
.71157 .68485 m .70648 .66655 L .73721 .65782 L p .707 .577 .707 r
F P
0 g
s
.73721 .65782 m .74231 .67613 L .71157 .68485 L p .707 .577 .707 r
F P
0 g
s
.30716 .76247 m .30207 .74417 L .29035 .7426 L p .707 .577 .707 r
F P
0 g
s
.29035 .7426 m .29545 .7609 L .30716 .76247 L p .707 .577 .707 r
F P
0 g
s
.49203 .58207 m .48199 .63558 L .47933 .62445 L p .707 .577 .707 r
F P
0 g
s
.47933 .62445 m .48937 .57093 L .49203 .58207 L p .707 .577 .707 r
F P
0 g
s
.28129 .59719 m .29133 .54367 L .2985 .53441 L p .707 .577 .707 r
F P
0 g
s
.2802 .70135 m .28047 .66433 L .27758 .65568 L p .707 .577 .707 r
F P
0 g
s
.27758 .65568 m .2773 .6927 L .2802 .70135 L p .707 .577 .707 r
F P
0 g
s
.2985 .53441 m .28845 .58793 L .28129 .59719 L p .707 .577 .707 r
F P
0 g
s
.29545 .7609 m .29035 .7426 L .28801 .7381 L p .707 .577 .707 r
F P
0 g
s
.47858 .65211 m .4783 .68914 L .46571 .68108 L p .707 .577 .707 r
F P
0 g
s
.47544 .69973 m .47035 .68142 L .47742 .68237 L p .707 .577 .707 r
F P
0 g
s
.4783 .68914 m .47844 .66999 L p .48147 .66076 L .707 .577 .707 r
F P
0 g
s
.47742 .68237 m .48207 .683 L p .47612 .69801 L .707 .577 .707 r
F P
0 g
s
.47544 .69973 m .47742 .68237 L .47612 .69801 L .707 .577 .707 r
F
.47844 .66999 m .47858 .65211 L .47965 .65533 L p F P
0 g
s
.47965 .65533 m .48147 .66076 L p .47844 .66999 L .707 .577 .707 r
F P
0 g
s
.28801 .7381 m .29311 .75641 L .29545 .7609 L p .707 .577 .707 r
F P
0 g
s
.48937 .57093 m .47933 .62445 L .46711 .61252 L p .707 .577 .707 r
F P
0 g
s
.46711 .61252 m .47715 .559 L .48937 .57093 L p .707 .577 .707 r
F P
0 g
s
.28845 .58793 m .2985 .53441 L .31478 .52794 L p .707 .577 .707 r
F P
0 g
s
.4844 .68749 m .4895 .70579 L .48716 .7013 L p .707 .577 .707 r
F P
0 g
s
.48716 .7013 m .48207 .683 L .4844 .68749 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.2773 .6927 m .27758 .65568 L .28466 .64727 L p .707 .577 .707 r
F P
0 g
s
.28466 .64727 m .28438 .6843 L .2773 .6927 L p .707 .577 .707 r
F P
0 g
s
.31478 .52794 m .30474 .58146 L .28845 .58793 L p .707 .577 .707 r
F P
0 g
s
.47715 .559 m .46711 .61252 L .44652 .60097 L p .707 .577 .707 r
F P
0 g
s
.44652 .60097 m .45657 .54745 L .47715 .559 L p .707 .577 .707 r
F P
0 g
s
.46571 .68108 m .46598 .64406 L .47858 .65211 L p .707 .577 .707 r
F P
0 g
s
.29311 .75641 m .28801 .7381 L .29529 .73114 L p .707 .577 .707 r
F P
0 g
s
.30474 .58146 m .31478 .52794 L .3386 .52488 L p .707 .577 .707 r
F P
0 g
s
.29529 .73114 m .30039 .74944 L .29311 .75641 L p .707 .577 .707 r
F P
0 g
s
.48207 .683 m .48716 .7013 L .47544 .69973 L p .707 .577 .707 r
F P
0 g
s
.28438 .6843 m .28466 .64727 L .30103 .63994 L p .707 .577 .707 r
F P
0 g
s
.3386 .52488 m .32855 .5784 L .30474 .58146 L p .707 .577 .707 r
F P
0 g
s
.45657 .54745 m .44652 .60097 L .41958 .59093 L p .707 .577 .707 r
F P
0 g
s
.41958 .59093 m .42963 .53741 L .45657 .54745 L p .707 .577 .707 r
F P
0 g
s
.30103 .63994 m .30075 .67697 L .28438 .6843 L p .707 .577 .707 r
F P
0 g
s
.32855 .5784 m .3386 .52488 L .36761 .52555 L p .707 .577 .707 r
F P
0 g
s
.46598 .64406 m .46571 .68108 L .44465 .67442 L p .707 .577 .707 r
F P
0 g
s
.44465 .67442 m .44493 .63739 L .46598 .64406 L p .707 .577 .707 r
F P
0 g
s
.30039 .74944 m .29529 .73114 L .31146 .72237 L p .707 .577 .707 r
F P
0 g
s
.31146 .72237 m .31656 .74068 L .30039 .74944 L p .707 .577 .707 r
F P
0 g
s
.42963 .53741 m .41958 .59093 L .38893 .58338 L p .707 .577 .707 r
F P
0 g
s
.38893 .58338 m .39897 .52986 L .42963 .53741 L p .707 .577 .707 r
F P
0 g
s
.35756 .57907 m .36761 .52555 L .39897 .52986 L p .707 .577 .707 r
F P
0 g
s
.36761 .52555 m .35756 .57907 L .32855 .5784 L p .707 .577 .707 r
F P
0 g
s
.47035 .68142 m .47544 .69973 L .45549 .70122 L p .707 .577 .707 r
F P
0 g
s
.45549 .70122 m .45039 .68292 L .47035 .68142 L p .707 .577 .707 r
F P
0 g
s
.30075 .67697 m .30103 .63994 L .32508 .6344 L p .707 .577 .707 r
F P
0 g
s
.39897 .52986 m .38893 .58338 L .35756 .57907 L p .707 .577 .707 r
F P
0 g
s
.32508 .6344 m .32481 .67143 L .30075 .67697 L p .707 .577 .707 r
F P
0 g
s
.44493 .63739 m .44465 .67442 L .41719 .66979 L p .707 .577 .707 r
F P
0 g
s
.41719 .66979 m .41747 .63276 L .44493 .63739 L p .707 .577 .707 r
F P
0 g
s
.31656 .74068 m .31146 .72237 L .33496 .71267 L p .707 .577 .707 r
F P
0 g
s
.32481 .67143 m .32508 .6344 L .35446 .63119 L p .707 .577 .707 r
F P
0 g
s
.33496 .71267 m .34005 .73098 L .31656 .74068 L p .707 .577 .707 r
F P
0 g
s
.45039 .68292 m .45549 .70122 L .42925 .70565 L p .707 .577 .707 r
F P
0 g
s
.42925 .70565 m .42415 .68734 L .45039 .68292 L p .707 .577 .707 r
F P
0 g
s
.41747 .63276 m .41719 .66979 L .38602 .66765 L p .707 .577 .707 r
F P
0 g
s
.38602 .66765 m .3863 .63063 L .41747 .63276 L p .707 .577 .707 r
F P
0 g
s
.35446 .63119 m .35419 .66822 L .32481 .67143 L p .707 .577 .707 r
F P
0 g
s
.35419 .66822 m .35446 .63119 L .3863 .63063 L p .707 .577 .707 r
F P
0 g
s
.3863 .63063 m .38602 .66765 L .35419 .66822 L p .707 .577 .707 r
F P
0 g
s
.34005 .73098 m .33496 .71267 L .36347 .70298 L p .707 .577 .707 r
F P
0 g
s
.36347 .70298 m .36856 .72129 L .34005 .73098 L p .707 .577 .707 r
F P
0 g
s
.42415 .68734 m .42925 .70565 L .3993 .71256 L p .707 .577 .707 r
F P
0 g
s
.3993 .71256 m .3942 .69426 L .42415 .68734 L p .707 .577 .707 r
F P
0 g
s
.36856 .72129 m .36347 .70298 L .3942 .69426 L p .707 .577 .707 r
F P
0 g
s
.3942 .69426 m .3993 .71256 L .36856 .72129 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
QWoo6000Ogoo001mOol90005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH9001fOol007Qoo`D0009J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00H0071oo`00MGoo0`00
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01UYF1000K7oo001c
Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000
FUH00000JWoo001aOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00Igoo001_Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2
001UOol006ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP8006Aoo`00KGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YF0000069oo`00K7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001Q
Ool006aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1NOol006ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1NOol006aoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1MOol006aoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1MOol006aoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1LOol006aoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00Oomoo`1LOol006aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00Oomoo`1LOol006aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00goo001JEP05
FUH00`00Oomoo`1LOol006aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0005ioo`00K7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000GWoo
001/Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004FUH00`00FUH0001NOol006aoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005ioo`00K7oo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF0000GWoo001/Ool00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUH0001NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUH0001NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUH0001NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH0001NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001N
Ool006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]o
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]oo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIoo`1NOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP05FUIOOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomo
o`1MOol006]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol0
06]oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`1MOol006]oo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0005moo`00Jgoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000Ggoo001[Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001OOol006]oo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0005mo
o`00Jgoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000Ggoo001[Ool0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0001OOol006]oo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0005moo`00Jgoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH00eYF00<005YF00001EYF00<005YF0000Ggoo001[Ool00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH00`00FUH00005FUH00`00FUH0001OOol006]oo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001J
EP0000EJEP03001JEP0005moo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP0005moo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EP0005moo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05mo
o`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEWoo05moo`00JWoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP80061oo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP80061oo`00JWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80061oo`00JWoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF009JEP04001JEUYF0004FUH00`00FUH0001POol006Yoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00061oo`00JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000H7oo001ZOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001POol006Yoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00
JWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001POol006Yoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00061oo`00JWoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000H7oo001ZOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0001POol006Yoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00061oo`00JWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF001ooa0004moo`00JWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF
00<005YFFUH01EYF00<005YFFUH00UYF1`00B7oo001ZOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000A7oo001ZOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF1000@7oo001MOol@0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH30003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH00000?Woo
001HOol50003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70008FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00>goo001F
Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH2000iOol005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00AJEPD000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP<003Moo`00Dgoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00@005YF000000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000fOol0059oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH20007FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2000dOol0059oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001oogoo
035oo`00DWoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF0P00<Woo001AOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUH0000aOol0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP8000aJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH0000`Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP8000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000`
Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo001AOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
0P000eYF1@000UYF00@005YF000000Qoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP06001JEUYF001JEP00;goo001@Ool01000FUIJEP000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF
00000P001UYF00@005YFFUIJEP<000Uoo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001J
EUYF001JEP00;goo001@Ool01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF000005YF0006FUH0
0`00FUIJEP05FUH3000:Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0002moo`00D7oo00<005YF00000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00IJEP03001JEP0000<000Yoo`@0
00MJEP03001JEUYF00=JEP04001JEUYFFUH2000`Ool0051oo`03001JEP0000=JEP@0009JEP04001J
EP000009Ool70008FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0025YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00H005YF000005YF0006FUH00`00FUIJEP02FUHJ
0004FUH00`00FUIJEP04FUH01P00FUIJEUYF001JES1oo`00D7oo0UYF00<005YF00000P001EYF00@0
05YFFUIJEP<000Ioo`03001JEP0000AJEP<000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP04001JEUYF0006
FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000400000eYF001JEP05FUH01P00
FUIJEP00FUH0031oo`00Cgoo00<005YFFUH00P000UYF00<005YFFUH00eYF00<005YFFUH015YF1000
0Woo00<005YF00001UYF100000=JEP00FUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0P0025YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00D005YFFUH005YF00D0009JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000IJEP06001JEUYF001J
EP00<7oo001?Ool30004FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH01000
FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00eYF00H005YF000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000000eYF00L005YFFUIJEP00FUH0000`Ool004mo
o`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPP000IJEP@00003
FUH005YF00EJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00]JEP03001JEUYF00QJEP03
001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001JEP02FUH00`00FUIoo`0`Ool004moo`03
001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPd0
00IJEP04001JEUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH20003FUH00`00FUIoo`0`Ool004moo`03001JEUYF00=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP04001J
EUYFFUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01`00FUH005YF001JEP00035oo`00D7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009JEP03001J
EUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP03001JEUYF00800003FUH007oo031oo`00D7oo00<005YFFUH00UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0`0015YF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000aOol0055oo`04001JEUYF0006FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01P00FUIJEUYF001JES9oo`00=Woo400037oo0`001UYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00<005YF
000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
039oo`00<Goo1@000eYF00<005YFFUH01EYF00<005YFFUH00UYF1P0027oo00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YF00000P0000=JEP00FUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00UYF00<0
05YF00000eYF00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01EYF20000eYF00<005YF
FUH00eYF00@005YFFUIJEP80039oo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P001Woo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`002EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH00UYF00<005YF00000eYF00<005YF000010000Woo0`0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF1@0015YF00@005YFFUIJEP80039oo`00;Goo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`001Goo0P0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP<000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP03001JEP0000=JEPT0
00=oo`<000IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH0000000800003FUH005YF009J
EP80039oo`00;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF0`0017oo0`001EYF5`0015YF00<005YFFUH015YF00L005YFFUIJEP00FUH00009FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YF00000`00
1Goo10000UYF00<005YFFUH01eYF00@005YFFUIJEPL000=JEP<000=JEP80039oo`00:goo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
00002`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010001UYF00L005YFFUIJEP00
FUH00009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YFFUH00eYF6@000eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000<Woo000[Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUH000030003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4
0003FUH01P00FUIJEP00FUH000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<0039oo`00:goo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`000UYF0P002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00<Woo000ZOol0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF2`00<Woo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH400000eYF001JEP04FUH01000FUIJ
EP00<Woo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP03FUH00`00FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF10001EYF00<005YFFUH00eYF00<005YFFUH00P00<Goo000ZOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00002UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
10000UYF00<005YFFUH015YF00<005YFFUH015YF00@005YF0000035oo`00:Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEUYFFUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<Goo000YOol01000FUIJEP000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00`0000=JEP00FUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH01eYF00<005YFFUH015YF
00@005YFFUIJEP@00003FUH00000031oo`00:Goo00@005YFFUH0009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPH000AJEP03
001JEUYF009JEP@000IJEP03001JEUYF00MJEP04001JEUYFFUH70003FUH4000`Ool002Uoo`03001J
EP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH>
00000eYF001JEP05FUH90004FUH00`00FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF2@0000=JEP00FUH025YF
00<005YFFUH015YF1P000Woo0P0000=JEP00FUH015YF00<005YF0000<7oo000YOol00`00FUH00003
FUH40002FUH01000FUH0000027oo10000UYF00<005YFFUH015YF00<005YF000015YF00<005YF0000
0`0015YF00@005YFFUIJEP8000=oo`03001JEP0000IJEP03001JEUYF00IJEPH000AJEP04001JEUYF
000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0005FUH00`00FUH000020004FUH00`00FUIJEP06FUH00`00FUIJEP040006Ool20003FUH00`00FUIJ
EP03FUH2000aOol002Uoo`04001JEP00FUH30005FUH01000FUIJEUYF0`002Goo1@0015YF00<005YF
00000eYF1@001UYF00@005YFFUIJEP8000=oo`03001JEP0000IJEP03001JEUYF00MJEP04001JEUYF
FUH4000015YF001JEUYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P001UYF0P001eYF00<005YFFUH01EYF10001goo0`001UYF00@005YFFUIJEP80039o
o`00:Goo0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF10002Woo1@0000=JEP00FUH00P00
15YF1@0000=JEP00FUH00eYF0P000goo00<005YF000015YF0`001UYF1`000eYF100000=JEP000000
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF0`00
2EYF00<005YFFUH010002Goo0P0000=JEP00FUH01UYF00@005YF000003Aoo`00:7oo00<005YF0000
15YF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH010002Woo00H005YF000005YF0005FUH0
1000FUIJEUYF20000goo00<005YF00000eYF2P000eYF00<005YF00001@000UYF0P0000=JEP000000
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00<0
05YFFUH01EYF10002Woo0`0015YF00<005YFFUH015YF0P00=Woo000XOol30003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH01000FUIJEUYF3`000eYF1P000eYF00<005YFFUH00eYF00@005YFFUH000UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF00=JEP8000Yo
o`@000MJEP03001JEUYF009JEP8003Qoo`00:7oo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH01UYF00<005YFFUH00eYF00@005YFFUH0
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH200000eYF001J
EP06FUH00`00FUH000020008Ool40002FUH00`00FUIJEP07FUH01000FUH00000>Woo000XOol00`00
FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50006FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YFFUH02eYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP@000Ioo`@000MJEP03001JEUYF00EJEP<0
03aoo`00:Goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD0009JEP03001J
EUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF100000AJEP00Oomoo`@00003FUH005YF
00QJEP03001JEUYF00=JEP8003moo`00:Goo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH00UYF10001UYF00<005YFFUH01eYF00@005YFFUIJEPL00003FUH0000000@000IJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEP0000EJEP04001JEP000002FUH60006
FUH00`00FUIJEP07FUH00`00FUH000020011Ool002Yoo`04001JEUYF0006FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH00000FUH000EJEP03001JEUYF00EJEP03001JEUYF
00800003FUH005YF00QJEP03001JEUYF00AJEPH000AJEP07001JEUYFFUH005YF00000UYF00<005YF
FUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=JEPL000=J
EP03001JEUYF00IJEP03001JEUYF00EJEP@004Aoo`00:goo0`001UYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP<000=JEP03001JEUYF
00MJEP03001JEUYF00@000=JEP03001JEUYF00AJEP04001JEP000003FUH20007FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00`000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH01000B7oo000]Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP03FUH30006FUH00`00FUIJEP06
FUH40007FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH5001<Ool0
02ioo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000D00003FUH005YF00MJEP03001JEUYF009JEP<0009JEP03001JEUYF00IJEP03001JEP00
00<000=JEP03001JEUYF008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00@000Eoo`<004Uoo`00<7oo0P0000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03
001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF009JEPH000MJEP<000]JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH40008Ool50018Ool0039oo`<000EJEQ40009JEP03001JEUYF00EJEP03001JEP00008000IJEP03
001JEUYF00AJEQ0000IJEP03001JEUYF00=JEP<000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUH00003000<Ool50018Ool003Ao
o`H000=JEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP800003FUH005YF00IJEP03001JEUYF
00D00003FUH005YF00=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00`00003FUH0000000ao
o`D004Qoo`00<7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00AJEP@000Aoo`03001JEP0000@000IJEP03001JEUYF00EJEP<000IJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEUYF009JEP<000eoo`<004Uoo`00;Goo0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00P001EYF00@005YFFUIJEP@000Eoo`@00003FUH005YF00QJ
EP03001JEUYF009JEP8000UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP<005Uoo`00:goo0P0000=JEP00FUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH0
0UYF00<005YF00000P0000AJEP00Oomoo`@000EJEP03001JEUYF00MJEP03001JEP0000<000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
009JEP03001JEP0000D005Uoo`00:Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YF00000UYF00<005YFFUH00UYF0P000UYF1@0000=JEP00FUH0
1UYF00<005YFFUH01UYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000010000UYF00@005YF000005Uo
o`00:7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00H005YFFUH005YF0003FUH60005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00FUIJ
EP03FUHI0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001EYF
00<005YFFUH00P00F7oo000WOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YF00000P001eYF200000=JEP00FUH02eYF00<005YFFUH025YF2@0025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF000000IJEP04001JEP00001HOol002Moo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH2
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJEP050009FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUH005YF00001EYF00@005YFFUH005Qoo`009goo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH01EYF00<005YFFUH0100015YF10000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF0P000UYF00@005YFFUIJEP@0
0003FUH0000005Moo`009goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF009JEP03001JEUYF009JEPL0
0003FUH005YF009JEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEPP000=JEP@005Moo`009goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH00UYF9`0000=JEWooOol00goo00@005YF001JEP<000QJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP<00003FUH005YF00=JEP800005Ool00000FUH00005FUH00`00FUH0001GOol002Moo`03001JEP00
00AJEP04001JEUYFFUH8000IOol60004FUH00`00FUIJEP020005Ool01000FUH000000UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01UYF00@005YF000000AJEP<000=JEP03001JEUYF00=JEP8005Qoo`009goo00<005YF00000eYF
1@009goo0`0000AJEP00FUIJEP8000Eoo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH2
0005FUH01000FUIJEUYF0P00FGoo000WOol01000FUH005YF0P0015YF1@004Woo0`002goo100000=J
EP0000000P0000=JEP0000001Goo0P0015YF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000
00EJEP04001JEP00001KOol002Moo`06001JEP00001JEP001EYF00@005YFFUIJEPP000Uoo`D000Eo
o`/0009JEP800003FUH0000000Aoo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP8000QJEP03001JEUYF00=JEP@000EJEP80
05eoo`009goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEQP000=JEP03001J
EUYF00=JEP04001JEUYF0004Ool00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP09FUH20008FUH00`00FUIJEP03FUH01000FUH00000
0eYF0P00Ggoo000WOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH900000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH0000017oo00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH00eYF00D005YF000005YF0080065oo`009goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF10001UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0000Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP00008006=oo`009goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001TOol002Qo
o`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP07FUH0
1000FUIJEUYF3P0017oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Aoo`00
:Goo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0025YF00<005YFFUH015YF
1P0015YF00L005YFFUIJEP00FUH00002FUH00`00Oomoo`04Ool30007FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH0001UOol002]oo`<000AJEP03001JEUYF00EJEPD00003FUH005YF00QJEP03001JEUYF00@000=J
EP03001JEUYF00AJEP04001JEUYF0003FUH20009Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001VOol002io
o`<00003FUH005YF00=JEP@000EJEP03001JEUYF00IJEP@000MJEP03001JEUYF00AJEP<000AJEP03
001oogoo00Yoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001oogoo06Eoo`00<Goo0`0000EJEP00001JEP00
00QJEP03001JEUYF009JEP<0009JEP03001JEUYF00IJEP04001JEUYFFUH4000015YF001JEUYF0P00
3goo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00@005YFFUIJEP8006Qoo`00<goo0P000eYF00<005YFFUH01UYF00<005YF00000P001EYF
00<005YFFUH00UYF20001EYF0`0057oo0`002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00@005YF000006Yoo`00<Goo0P001EYF00<005YFFUH01EYF40001EYF
00<005YFFUH015YF0P006Goo10001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH015YF1@00K7oo000_Ool30007FUH00`00FUIJEP02FUH20009Ool300000eYF001JEP07
FUH01000FUIJEUYF0P007goo100000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YF00001000LGoo000]Ool20003FUH00`00FUIJEP04FUH00`00FUH000020008Ool30004FUH00`00
FUIJEP06FUH01000FUH000009Goo20001UYF00<005YFFUH02EYF00@005YFFUIJEPX007Ioo`00;7oo
00<005YFFUH00eYF00<005YFFUH00eYF0`0027oo0`0025YF00<005YFFUH015YF0`00;goo5P00P7oo
000[Ool20006FUH00`00FUH000020007Ool400000eYF001JEP08FUH00`00FUIJEP040038Ool002Yo
o`04001JEUYF0005FUH20004Ool60005FUH00`00FUIJEP06FUH4003<Ool002Yoo`04001JEUYF0003
FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3003@Ool002]oo`03001JEUYF00<000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000800==oo`00:goo00<005YFFUH00P001EYF00<0
05YFFUH01EYF00<005YFFUH015YF0`00eWoo000/Ool015YF001JEP001EYF00<005YFFUH01EYF00<0
05YFFUH01000fGoo000/Ool20002FUH00`00FUIJEP03FUH01000FUIJEUYF1P00gGoo000]Ool=003S
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61107 .77016 m .60102 .71448 L .57037 .71834 L p .707 .577 .707 r
F P
0 g
s
.60102 .71448 m .61107 .77016 L .64243 .76418 L p .707 .577 .707 r
F P
0 g
s
.64243 .76418 m .63239 .70851 L .60102 .71448 L p .707 .577 .707 r
F P
0 g
s
.63239 .70851 m .64243 .76418 L .67144 .75668 L p .707 .577 .707 r
F P
0 g
s
.67144 .75668 m .6614 .70101 L .63239 .70851 L p .707 .577 .707 r
F P
0 g
s
.58041 .77401 m .57037 .71834 L .54343 .71971 L p .707 .577 .707 r
F P
0 g
s
.57037 .71834 m .58041 .77401 L .61107 .77016 L p .707 .577 .707 r
F P
0 g
s
.6614 .70101 m .67144 .75668 L .69526 .74838 L p .707 .577 .707 r
F P
0 g
s
.69526 .74838 m .68521 .69271 L .6614 .70101 L p .707 .577 .707 r
F P
0 g
s
.54343 .71971 m .55348 .77538 L .58041 .77401 L p .707 .577 .707 r
F P
0 g
s
.61397 .85505 m .6137 .81796 L .58253 .8163 L p .707 .577 .707 r
F P
0 g
s
.6137 .81796 m .61397 .85505 L .64581 .85406 L p .707 .577 .707 r
F P
0 g
s
.64581 .85406 m .64553 .81697 L .6137 .81796 L p .707 .577 .707 r
F P
0 g
s
.55348 .77538 m .54343 .71971 L .52285 .71845 L p .707 .577 .707 r
F P
0 g
s
.64553 .81697 m .64581 .85406 L .67519 .85051 L p .707 .577 .707 r
F P
0 g
s
.67519 .85051 m .67491 .81343 L .64553 .81697 L p .707 .577 .707 r
F P
0 g
s
.5828 .85338 m .58253 .8163 L .55507 .81214 L p .707 .577 .707 r
F P
0 g
s
.58253 .8163 m .5828 .85338 L .61397 .85505 L p .707 .577 .707 r
F P
0 g
s
.68521 .69271 m .69526 .74838 L .71154 .74011 L p .707 .577 .707 r
F P
0 g
s
.71154 .74011 m .7015 .68443 L .68521 .69271 L p .707 .577 .707 r
F P
0 g
s
.52285 .71845 m .53289 .77412 L .55348 .77538 L p .707 .577 .707 r
F P
0 g
s
.67491 .81343 m .67519 .85051 L .69924 .84475 L p .707 .577 .707 r
F P
0 g
s
.69924 .84475 m .69897 .80767 L .67491 .81343 L p .707 .577 .707 r
F P
0 g
s
.55507 .81214 m .55535 .84923 L .5828 .85338 L p .707 .577 .707 r
F P
0 g
s
.6007 .8971 m .6058 .87989 L .57584 .86944 L p .707 .577 .707 r
F P
0 g
s
.6058 .87989 m .6007 .8971 L .63143 .90404 L p .707 .577 .707 r
F P
0 g
s
.63143 .90404 m .63653 .88683 L .6058 .87989 L p .707 .577 .707 r
F P
0 g
s
.55535 .84923 m .55507 .81214 L .53401 .8059 L p .707 .577 .707 r
F P
0 g
s
.57075 .88665 m .57584 .86944 L .54961 .8565 L p .707 .577 .707 r
F P
0 g
s
.57584 .86944 m .57075 .88665 L .6007 .8971 L p .707 .577 .707 r
F P
0 g
s
.63653 .88683 m .63143 .90404 L .65994 .90679 L p .707 .577 .707 r
F P
0 g
s
.65994 .90679 m .66504 .88958 L .63653 .88683 L p .707 .577 .707 r
F P
0 g
s
.53289 .77412 m .52285 .71845 L .51062 .71469 L p .707 .577 .707 r
F P
0 g
s
.54961 .8565 m .54451 .87371 L .57075 .88665 L p .707 .577 .707 r
F P
0 g
s
.53401 .8059 m .53429 .84299 L .55535 .84923 L p .707 .577 .707 r
F P
0 g
s
.7015 .68443 m .71154 .74011 L .71871 .73265 L p .707 .577 .707 r
F P
0 g
s
.71871 .73265 m .70866 .67698 L .7015 .68443 L p .707 .577 .707 r
F P
0 g
s
.69897 .80767 m .69924 .84475 L .71561 .83735 L p .707 .577 .707 r
F P
0 g
s
.71561 .83735 m .71533 .80026 L .69897 .80767 L p .707 .577 .707 r
F P
0 g
s
.54451 .87371 m .54961 .8565 L .52965 .84233 L p .707 .577 .707 r
F P
0 g
s
.51062 .71469 m .52067 .77036 L .53289 .77412 L p .707 .577 .707 r
F P
0 g
s
.66504 .88958 m .65994 .90679 L .68344 .90507 L p .707 .577 .707 r
F P
0 g
s
.68344 .90507 m .68853 .88786 L .66504 .88958 L p .707 .577 .707 r
F P
0 g
s
.52965 .84233 m .52455 .85954 L .54451 .87371 L p .707 .577 .707 r
F P
0 g
s
.53429 .84299 m .53401 .8059 L .52142 .79819 L p .707 .577 .707 r
F P
0 g
s
.52067 .77036 m .51062 .71469 L .50797 .70879 L p .707 .577 .707 r
F P
0 g
s
.52455 .85954 m .52965 .84233 L .52258 .83388 L p .707 .577 .707 r
F P
0 g
s
.52258 .83388 m .51793 .82832 L p .52387 .85634 L .707 .577 .707 r
F P
0 g
s
.52455 .85954 m .52258 .83388 L .52387 .85634 L .707 .577 .707 r
F
.5217 .83527 m .52156 .81609 L p .51853 .78975 L F P
0 g
s
.52156 .81609 m .52142 .79819 L .52034 .79505 L p .707 .577 .707 r
F P
0 g
s
.52034 .79505 m .51853 .78975 L p .52156 .81609 L .707 .577 .707 r
F P
0 g
s
.52142 .79819 m .5217 .83527 L .53429 .84299 L p .707 .577 .707 r
F P
0 g
s
.71533 .80026 m .71561 .83735 L .72269 .82902 L p .707 .577 .707 r
F P
0 g
s
.72269 .82902 m .72242 .79194 L .71533 .80026 L p .707 .577 .707 r
F P
0 g
s
.68853 .88786 m .68344 .90507 L .69961 .89905 L p .707 .577 .707 r
F P
0 g
s
.69961 .89905 m .70471 .88184 L .68853 .88786 L p .707 .577 .707 r
F P
0 g
s
.51793 .82832 m .51283 .84553 L .52455 .85954 L p .707 .577 .707 r
F P
0 g
s
.70866 .67698 m .71871 .73265 L .71605 .72676 L p .707 .577 .707 r
F P
0 g
s
.71605 .72676 m .70601 .67108 L .70866 .67698 L p .707 .577 .707 r
F P
0 g
s
.50797 .70879 m .51801 .76446 L .52067 .77036 L p .707 .577 .707 r
F P
0 g
s
.48416 .8193 m .46533 .31577 L .42135 .31477 L p .707 .577 .707 r
F P
0 g
s
.51283 .84553 m .51793 .82832 L .5156 .81585 L p .707 .577 .707 r
F P
0 g
s
.5188 .82684 m .5217 .83527 L p .51926 .80035 L .707 .577 .707 r
F P
0 g
s
.51853 .78975 m .51864 .80556 L p .51926 .80035 L .707 .577 .707 r
F P
0 g
s
.51864 .80556 m .5188 .82684 L p .51926 .80035 L .707 .577 .707 r
F P
0 g
s
.5156 .81585 m .5105 .83306 L .51283 .84553 L p .707 .577 .707 r
F P
0 g
s
.5105 .83306 m .5156 .81585 L .51776 .81296 L p .707 .577 .707 r
F P
0 g
s
.5188 .82684 m .51853 .78975 L .52561 .78143 L p .707 .577 .707 r
F P
0 g
s
.52589 .81851 m .5188 .82684 L p .52413 .79131 L .707 .577 .707 r
F P
0 g
s
.52561 .78143 m .52572 .79651 L p .52413 .79131 L .707 .577 .707 r
F P
0 g
s
.52572 .79651 m .52589 .81851 L p .52413 .79131 L .707 .577 .707 r
F P
0 g
s
.52589 .81851 m .52561 .78143 L .54198 .77402 L p .707 .577 .707 r
F P
0 g
s
.51777 .82334 m .52287 .80613 L .52808 .8042 L p .707 .577 .707 r
F P
0 g
s
.54225 .81111 m .52589 .81851 L p .53855 .78349 L .707 .577 .707 r
F P
0 g
s
.54198 .77402 m .5421 .78983 L p .53855 .78349 L .707 .577 .707 r
F P
0 g
s
.5421 .78983 m .54225 .81111 L p .53855 .78349 L .707 .577 .707 r
F P
0 g
s
.54225 .81111 m .54198 .77402 L .56603 .76826 L p .707 .577 .707 r
F P
0 g
s
.53395 .81733 m .53905 .80012 L .5475 .7995 L p .707 .577 .707 r
F P
0 g
s
.56631 .80535 m .54225 .81111 L p .56103 .77727 L .707 .577 .707 r
F P
0 g
s
.56603 .76826 m .56616 .78617 L p .56103 .77727 L .707 .577 .707 r
F P
0 g
s
.56616 .78617 m .56631 .80535 L p .56103 .77727 L .707 .577 .707 r
F P
0 g
s
.56631 .80535 m .56603 .76826 L .59541 .76472 L p .707 .577 .707 r
F P
0 g
s
.59541 .76472 m .59569 .8018 L .56631 .80535 L p .707 .577 .707 r
F P
0 g
s
.55744 .81561 m .56254 .7984 L .57385 .79949 L p .707 .577 .707 r
F P
0 g
s
.57385 .79949 m .59105 .80114 L p .57804 .80675 L .707 .577 .707 r
F P
0 g
s
.55744 .81561 m .57385 .79949 L .57804 .80675 L .707 .577 .707 r
F
.5475 .7995 m .56254 .7984 L p .55111 .80597 L F P
0 g
s
.53395 .81733 m .5475 .7995 L .55111 .80597 L .707 .577 .707 r
F
.52808 .8042 m .53905 .80012 L p .52989 .81011 L F P
0 g
s
.51777 .82334 m .52808 .8042 L .52989 .81011 L .707 .577 .707 r
F
.51776 .81296 m .52287 .80613 L p .51707 .81875 L F P
0 g
s
.5105 .83306 m .51776 .81296 L .51707 .81875 L .707 .577 .707 r
F
.51801 .76446 m .50797 .70879 L .51513 .70134 L p F P
0 g
s
.51513 .70134 m .52518 .75701 L .51801 .76446 L p .707 .577 .707 r
F P
0 g
s
.52287 .80613 m .51777 .82334 L .5105 .83306 L p .707 .577 .707 r
F P
0 g
s
.53905 .80012 m .53395 .81733 L .51777 .82334 L p .707 .577 .707 r
F P
0 g
s
.46533 .31577 m .48416 .8193 L .52907 .81669 L p .707 .577 .707 r
F P
0 g
s
.52518 .75701 m .51513 .70134 L .53142 .69306 L p .707 .577 .707 r
F P
0 g
s
.53142 .69306 m .54146 .74873 L .52518 .75701 L p .707 .577 .707 r
F P
0 g
s
.52907 .81669 m .51024 .31317 L .46533 .31577 L p .707 .577 .707 r
F P
0 g
s
.54146 .74873 m .53142 .69306 L .55523 .68476 L p .707 .577 .707 r
F P
0 g
s
.55523 .68476 m .56528 .74044 L .54146 .74873 L p .707 .577 .707 r
F P
0 g
s
.56528 .74044 m .55523 .68476 L .58424 .67726 L p .707 .577 .707 r
F P
0 g
s
.56254 .7984 m .55744 .81561 L .53395 .81733 L p .707 .577 .707 r
F P
0 g
s
.59105 .80114 m .58595 .81835 L .55744 .81561 L p .707 .577 .707 r
F P
0 g
s
.51024 .31317 m .52907 .81669 L .57053 .81073 L p .707 .577 .707 r
F P
0 g
s
.58424 .67726 m .59429 .73293 L .56528 .74044 L p .707 .577 .707 r
F P
0 g
s
.57053 .81073 m .5517 .3072 L .51024 .31317 L p .707 .577 .707 r
F P
0 g
s
.70471 .88184 m .69961 .89905 L .70689 .88933 L p .707 .577 .707 r
F P
0 g
s
.70689 .88933 m .71198 .87212 L .70471 .88184 L p .707 .577 .707 r
F P
0 g
s
.72242 .79194 m .72269 .82902 L .7198 .82059 L p .707 .577 .707 r
F P
0 g
s
.7198 .82059 m .71952 .7835 L .72242 .79194 L p .707 .577 .707 r
F P
0 g
s
.44018 .81829 m .42135 .31477 L .38262 .31024 L p .707 .577 .707 r
F P
0 g
s
.42135 .31477 m .44018 .81829 L .48416 .8193 L p .707 .577 .707 r
F P
0 g
s
.26806 .68284 m .25801 .62716 L .22736 .63102 L p .707 .577 .707 r
F P
0 g
s
.25801 .62716 m .26806 .68284 L .29942 .67686 L p .707 .577 .707 r
F P
0 g
s
.29942 .67686 m .28938 .62119 L .25801 .62716 L p .707 .577 .707 r
F P
0 g
s
.28938 .62119 m .29942 .67686 L .32843 .66936 L p .707 .577 .707 r
F P
0 g
s
.32843 .66936 m .31839 .61369 L .28938 .62119 L p .707 .577 .707 r
F P
0 g
s
.70601 .67108 m .71605 .72676 L .70383 .723 L p .707 .577 .707 r
F P
0 g
s
.70383 .723 m .69379 .66732 L .70601 .67108 L p .707 .577 .707 r
F P
0 g
s
.23741 .68669 m .22736 .63102 L .20042 .63239 L p .707 .577 .707 r
F P
0 g
s
.22736 .63102 m .23741 .68669 L .26806 .68284 L p .707 .577 .707 r
F P
0 g
s
.59429 .73293 m .58424 .67726 L .61561 .67129 L p .707 .577 .707 r
F P
0 g
s
.61561 .67129 m .62565 .72696 L .59429 .73293 L p .707 .577 .707 r
F P
0 g
s
.59569 .8018 m .59541 .76472 L .62725 .76373 L p .707 .577 .707 r
F P
0 g
s
.62725 .76373 m .62752 .80081 L .59569 .8018 L p .707 .577 .707 r
F P
0 g
s
.58595 .81835 m .59105 .80114 L .62178 .80808 L p .707 .577 .707 r
F P
0 g
s
.5517 .3072 m .57053 .81073 L .60447 .80198 L p .707 .577 .707 r
F P
0 g
s
.60447 .80198 m .58565 .29845 L .5517 .3072 L p .707 .577 .707 r
F P
0 g
s
.31839 .61369 m .32843 .66936 L .35225 .66107 L p .707 .577 .707 r
F P
0 g
s
.35225 .66107 m .3422 .60539 L .31839 .61369 L p .707 .577 .707 r
F P
0 g
s
.27097 .73121 m .27069 .69413 L .23952 .69246 L p .707 .577 .707 r
F P
0 g
s
.27069 .69413 m .27097 .73121 L .3028 .73022 L p .707 .577 .707 r
F P
0 g
s
.3028 .73022 m .30252 .69314 L .27069 .69413 L p .707 .577 .707 r
F P
0 g
s
.30252 .69314 m .3028 .73022 L .33218 .72667 L p .707 .577 .707 r
F P
0 g
s
.33218 .72667 m .3319 .68959 L .30252 .69314 L p .707 .577 .707 r
F P
0 g
s
.20042 .63239 m .21047 .68806 L .21264 .68795 L p .707 .577 .707 r
F P
0 g
s
.21047 .68806 m .20042 .63239 L .17984 .63113 L p .707 .577 .707 r
F P
0 g
s
.17984 .63113 m .18988 .6868 L .19179 .68692 L p .707 .577 .707 r
F P
0 g
s
.19179 .68692 m .21047 .68806 L p .19475 .65885 L .707 .577 .707 r
F P
0 g
s
.19475 .65885 m .17984 .63113 L .19179 .68692 L .707 .577 .707 r
F
.18988 .6868 m .17984 .63113 L .16762 .62737 L p F P
0 g
s
.16762 .62737 m .17766 .68304 L .17866 .68335 L p .707 .577 .707 r
F P
0 g
s
.17866 .68335 m .18988 .6868 L p .1795 .65909 L .707 .577 .707 r
F P
0 g
s
.1795 .65909 m .16762 .62737 L .17866 .68335 L .707 .577 .707 r
F
.17766 .68304 m .16762 .62737 L .16496 .62147 L p F P
0 g
s
.16496 .62147 m .175 .67715 L .17518 .67753 L p .707 .577 .707 r
F P
0 g
s
.17518 .67753 m .17766 .68304 L p .17191 .65516 L .707 .577 .707 r
F P
0 g
s
.17191 .65516 m .16496 .62147 L .17518 .67753 L .707 .577 .707 r
F
.17841 .67435 m .17552 .66592 L p .17803 .70192 L F P
0 g
s
.17851 .68777 m .17841 .67435 L p .17803 .70192 L .707 .577 .707 r
F P
0 g
s
.191 .68207 m .17841 .67435 L p .18916 .71177 L .707 .577 .707 r
F P
0 g
s
.17841 .67435 m .17869 .71143 L .19128 .71915 L p .707 .577 .707 r
F P
0 g
s
.17552 .66592 m .17563 .6806 L p .17869 .71143 L .707 .577 .707 r
F P
0 g
s
.17563 .6806 m .17579 .703 L .17703 .70661 L p .707 .577 .707 r
F P
0 g
s
.17703 .70661 m .17869 .71143 L p .17563 .6806 L .707 .577 .707 r
F P
0 g
s
.17552 .66592 m .1826 .65759 L p .17737 .69251 L .707 .577 .707 r
F P
0 g
s
.17563 .6806 m .17552 .66592 L p .17737 .69251 L .707 .577 .707 r
F P
0 g
s
.17869 .71143 m .17851 .68777 L p .17803 .70192 L .707 .577 .707 r
F P
0 g
s
.1826 .65759 m .18271 .67271 L p .17579 .703 L .707 .577 .707 r
F P
0 g
s
.18271 .67271 m .18288 .69467 L .17995 .69811 L p .707 .577 .707 r
F P
0 g
s
.17995 .69811 m .17579 .703 L p .18271 .67271 L .707 .577 .707 r
F P
0 g
s
.18288 .69467 m .1826 .65759 L .19897 .65018 L p .707 .577 .707 r
F P
0 g
s
.18841 .60574 m .1894 .61122 L p .18217 .66969 L .707 .577 .707 r
F P
0 g
s
.19109 .6935 m .191 .68207 L p .18916 .71177 L .707 .577 .707 r
F P
0 g
s
.21206 .68831 m .191 .68207 L p .21075 .72217 L .707 .577 .707 r
F P
0 g
s
.191 .68207 m .19128 .71915 L .21234 .72539 L p .707 .577 .707 r
F P
0 g
s
.19897 .65018 m .19908 .66487 L p .18288 .69467 L .707 .577 .707 r
F P
0 g
s
.19908 .66487 m .19925 .68727 L .19312 .69004 L p .707 .577 .707 r
F P
0 g
s
.19312 .69004 m .18288 .69467 L p .19908 .66487 L .707 .577 .707 r
F P
0 g
s
.21457 .65315 m .20042 .63239 L .21264 .68795 L .707 .577 .707 r
F
.21264 .68795 m .23741 .68669 L p .21457 .65315 L F P
0 g
s
.19925 .68727 m .19897 .65018 L .22302 .64443 L p .707 .577 .707 r
F P
0 g
s
.21222 .59744 m .21344 .60419 L p .19845 .66141 L .707 .577 .707 r
F P
0 g
s
.22302 .64443 m .22312 .65784 L p .19925 .68727 L .707 .577 .707 r
F P
0 g
s
.22312 .65784 m .2233 .68151 L .21582 .6833 L p .707 .577 .707 r
F P
0 g
s
.21582 .6833 m .19925 .68727 L p .22312 .65784 L .707 .577 .707 r
F P
0 g
s
.2233 .68151 m .22302 .64443 L .2524 .64088 L p .707 .577 .707 r
F P
0 g
s
.24123 .58994 m .24176 .59284 L p .22227 .65312 L .707 .577 .707 r
F P
0 g
s
.2524 .64088 m .25249 .65232 L p .2233 .68151 L .707 .577 .707 r
F P
0 g
s
.25249 .65232 m .25268 .67796 L .24633 .67873 L p .707 .577 .707 r
F P
0 g
s
.24633 .67873 m .2233 .68151 L p .25249 .65232 L .707 .577 .707 r
F P
0 g
s
.25268 .67796 m .2524 .64088 L .28424 .63989 L p .707 .577 .707 r
F P
0 g
s
.25128 .64561 m .24123 .58994 L .26824 .5848 L p .707 .577 .707 r
F P
0 g
s
.26824 .5848 m .2726 .58397 L p .2598 .62098 L .707 .577 .707 r
F P
0 g
s
.25128 .64561 m .26824 .5848 L .2598 .62098 L .707 .577 .707 r
F
.24176 .59284 m .25128 .64561 L .22465 .6525 L p F P
0 g
s
.22465 .6525 m .22227 .65312 L p .24176 .59284 L .707 .577 .707 r
F P
0 g
s
.21344 .60419 m .22227 .65312 L .20003 .66087 L p .707 .577 .707 r
F P
0 g
s
.20003 .66087 m .19845 .66141 L p .21344 .60419 L .707 .577 .707 r
F P
0 g
s
.1894 .61122 m .19845 .66141 L .18309 .66922 L p .707 .577 .707 r
F P
0 g
s
.18309 .66922 m .18217 .66969 L p .1894 .61122 L .707 .577 .707 r
F P
0 g
s
.17212 .61402 m .18217 .66969 L .17542 .67672 L p .707 .577 .707 r
F P
0 g
s
.17542 .67672 m .175 .67715 L p .17265 .62566 L .707 .577 .707 r
F P
0 g
s
.17265 .62566 m .17212 .61402 L .17542 .67672 L .707 .577 .707 r
F
.17579 .703 m .17563 .6806 L p .17737 .69251 L F P
0 g
s
.19128 .71915 m .19109 .6935 L p .18916 .71177 L .707 .577 .707 r
F P
0 g
s
.21234 .72539 m .21213 .69726 L p .21075 .72217 L .707 .577 .707 r
F P
0 g
s
.21213 .69726 m .21206 .68831 L p .21075 .72217 L .707 .577 .707 r
F P
0 g
s
.23979 .72955 m .23952 .69246 L .21206 .68831 L p .707 .577 .707 r
F P
0 g
s
.23952 .69246 m .23979 .72955 L .27097 .73121 L p .707 .577 .707 r
F P
0 g
s
.40145 .81377 m .38262 .31024 L .35292 .30264 L p .707 .577 .707 r
F P
0 g
s
.38262 .31024 m .40145 .81377 L .44018 .81829 L p .707 .577 .707 r
F P
0 g
s
.71198 .87212 m .70689 .88933 L .70455 .87686 L p .707 .577 .707 r
F P
0 g
s
.70455 .87686 m .70965 .85965 L .71198 .87212 L p .707 .577 .707 r
F P
0 g
s
.71952 .7835 m .7198 .82059 L .70721 .81287 L p .707 .577 .707 r
F P
0 g
s
.70721 .81287 m .70693 .77579 L .71952 .7835 L p .707 .577 .707 r
F P
0 g
s
.3319 .68959 m .33218 .72667 L .35623 .72091 L p .707 .577 .707 r
F P
0 g
s
.35623 .72091 m .35596 .68383 L .3319 .68959 L p .707 .577 .707 r
F P
0 g
s
.21206 .68831 m .21234 .72539 L .23979 .72955 L p .707 .577 .707 r
F P
0 g
s
.69379 .66732 m .70383 .723 L .68325 .72174 L p .707 .577 .707 r
F P
0 g
s
.68325 .72174 m .6732 .66606 L .69379 .66732 L p .707 .577 .707 r
F P
0 g
s
.3422 .60539 m .35225 .66107 L .36854 .65279 L p .707 .577 .707 r
F P
0 g
s
.36854 .65279 m .35849 .59711 L .3422 .60539 L p .707 .577 .707 r
F P
0 g
s
.62565 .72696 m .61561 .67129 L .64626 .66743 L p .707 .577 .707 r
F P
0 g
s
.62752 .80081 m .62725 .76373 L .65842 .76539 L p .707 .577 .707 r
F P
0 g
s
.58565 .29845 m .60447 .80198 L .62758 .79131 L p .707 .577 .707 r
F P
0 g
s
.62758 .79131 m .60875 .28778 L .58565 .29845 L p .707 .577 .707 r
F P
0 g
s
.25769 .78704 m .26279 .76983 L .23284 .75938 L p .707 .577 .707 r
F P
0 g
s
.26279 .76983 m .25769 .78704 L .28843 .79398 L p .707 .577 .707 r
F P
0 g
s
.28843 .79398 m .29352 .77677 L .26279 .76983 L p .707 .577 .707 r
F P
0 g
s
.22774 .77659 m .23284 .75938 L .2066 .74644 L p .707 .577 .707 r
F P
0 g
s
.23284 .75938 m .22774 .77659 L .25769 .78704 L p .707 .577 .707 r
F P
0 g
s
.29352 .77677 m .28843 .79398 L .31693 .79672 L p .707 .577 .707 r
F P
0 g
s
.31693 .79672 m .32203 .77951 L .29352 .77677 L p .707 .577 .707 r
F P
0 g
s
.35596 .68383 m .35623 .72091 L .3726 .71351 L p .707 .577 .707 r
F P
0 g
s
.3726 .71351 m .37233 .67643 L .35596 .68383 L p .707 .577 .707 r
F P
0 g
s
.2066 .74644 m .2015 .76365 L .22774 .77659 L p .707 .577 .707 r
F P
0 g
s
.70965 .85965 m .70455 .87686 L .69283 .86285 L p .707 .577 .707 r
F P
0 g
s
.69283 .86285 m .69793 .84565 L .70965 .85965 L p .707 .577 .707 r
F P
0 g
s
.2015 .76365 m .2066 .74644 L .18664 .73227 L p .707 .577 .707 r
F P
0 g
s
.35849 .59711 m .36854 .65279 L .3757 .64533 L p .707 .577 .707 r
F P
0 g
s
.3757 .64533 m .36566 .58966 L .35849 .59711 L p .707 .577 .707 r
F P
0 g
s
.363 .58376 m .36566 .58966 L p .37192 .63189 L .707 .577 .707 r
F P
0 g
s
.37304 .63944 m .36902 .61714 L p .37192 .63189 L .707 .577 .707 r
F P
0 g
s
.36902 .61714 m .363 .58376 L p .37192 .63189 L .707 .577 .707 r
F P
0 g
s
.35292 .30264 m .33517 .29271 L p .35219 .53161 L .707 .577 .707 r
F P
0 g
s
.36388 .77927 m .36898 .76206 L .3617 .77178 L p .707 .577 .707 r
F P
0 g
s
.36898 .76206 m .36388 .77927 L .36154 .7668 L p .707 .577 .707 r
F P
0 g
s
.36154 .7668 m .36664 .74959 L .36898 .76206 L p .707 .577 .707 r
F P
0 g
s
.37175 .80617 m .36461 .61523 L p .35794 .61236 L .707 .577 .707 r
F P
0 g
s
.37175 .80617 m .40145 .81377 L p .39298 .72463 L .707 .577 .707 r
F P
0 g
s
.37304 .63944 m .3707 .63872 L p .36787 .6278 L .707 .577 .707 r
F P
0 g
s
.363 .58376 m .36902 .61714 L p .36173 .61399 L .707 .577 .707 r
F P
0 g
s
.37233 .67643 m .3726 .71351 L .37969 .70518 L p .707 .577 .707 r
F P
0 g
s
.37969 .70518 m .37941 .6681 L .37233 .67643 L p .707 .577 .707 r
F P
0 g
s
.37941 .6681 m .37969 .70518 L .37679 .69675 L p .707 .577 .707 r
F P
0 g
s
.37679 .69675 m .37651 .65967 L .37941 .6681 L p .707 .577 .707 r
F P
0 g
s
.36461 .61523 m .37175 .80617 L p .37421 .79673 L .707 .577 .707 r
F P
0 g
s
.37651 .65967 m .37679 .69675 L .37535 .69587 L p .707 .577 .707 r
F P
0 g
s
.37574 .6615 m .37651 .65967 L .37535 .69587 L .707 .577 .707 r
F
.37578 .6583 m .36461 .61523 L .37421 .79673 L F
.3642 .68903 m .36392 .65195 L .37577 .65921 L p F P
0 g
s
.37577 .65921 m .37651 .65967 L p .37574 .6615 L .707 .577 .707 r
F P
0 g
s
.3642 .68903 m .37577 .65921 L .37574 .6615 L .707 .577 .707 r
F
.36902 .61714 m .37304 .63944 L p .36787 .6278 L F P
0 g
s
.36173 .61399 m .36461 .61523 L .36787 .6278 L .707 .577 .707 r
F
.36461 .61523 m .36902 .61714 L .36787 .6278 L F
.36566 .58966 m .3757 .64533 L .37304 .63944 L p F P
0 g
s
.35292 .30264 m .36461 .61523 L p .37578 .6583 L .707 .577 .707 r
F P
0 g
s
.39298 .72463 m .37695 .55568 L .37578 .6583 L .707 .577 .707 r
F
.37695 .55568 m .35292 .30264 L .37578 .6583 L F
.39298 .72463 m .37578 .6583 L .37421 .79673 L F
.37535 .69587 m .3642 .68903 L p .37574 .6615 L F P
0 g
s
.36082 .63568 m .36173 .61399 L .36787 .6278 L .707 .577 .707 r
F
.3707 .63872 m .36082 .63568 L p .36787 .6278 L F P
0 g
s
.35078 .58 m .363 .58376 L p .36173 .61399 L .707 .577 .707 r
F P
0 g
s
.34552 .77779 m .34043 .795 L .3566 .78899 L p .707 .577 .707 r
F P
0 g
s
.3566 .78899 m .3617 .77178 L .34552 .77779 L p .707 .577 .707 r
F P
0 g
s
.3617 .77178 m .3566 .78899 L .36388 .77927 L p .707 .577 .707 r
F P
0 g
s
.36664 .74959 m .36154 .7668 L .3551 .7591 L p .707 .577 .707 r
F P
0 g
s
.3551 .7591 m .34982 .75279 L p .35447 .75191 L .707 .577 .707 r
F P
0 g
s
.35447 .75191 m .36664 .74959 L .3551 .7591 L .707 .577 .707 r
F
.35637 .68671 m .35055 .68499 L p .35516 .66495 L F P
0 g
s
.35055 .68499 m .34314 .68279 L p .35006 .67253 L .707 .577 .707 r
F P
0 g
s
.35006 .67253 m .35516 .66495 L .35055 .68499 L .707 .577 .707 r
F
.35492 .73558 m .36664 .74959 L p .35447 .75191 L F P
0 g
s
.34982 .75279 m .35348 .74046 L p .35447 .75191 L .707 .577 .707 r
F P
0 g
s
.35348 .74046 m .35492 .73558 L p .35447 .75191 L .707 .577 .707 r
F P
0 g
s
.35492 .73558 m .34982 .75279 L .33709 .74375 L p .707 .577 .707 r
F P
0 g
s
.33709 .74375 m .32987 .73862 L p .33711 .73774 L .707 .577 .707 r
F P
0 g
s
.33711 .73774 m .35492 .73558 L .33709 .74375 L .707 .577 .707 r
F
.37175 .80617 m .35794 .61236 L .35635 .68643 L F
.35078 .58 m .3565 .61174 L p .34876 .63494 L F P
0 g
s
.35524 .63534 m .34876 .63494 L p .3565 .61174 L .707 .577 .707 r
F P
0 g
s
.34876 .63494 m .34024 .63442 L p .34769 .59595 L .707 .577 .707 r
F P
0 g
s
.34769 .59595 m .35078 .58 L .34876 .63494 L .707 .577 .707 r
F
.34314 .68279 m .34287 .64571 L .34907 .64755 L p F P
0 g
s
.34907 .64755 m .35428 .64909 L p .34968 .66301 L .707 .577 .707 r
F P
0 g
s
.34314 .68279 m .34907 .64755 L .34968 .66301 L .707 .577 .707 r
F
.34314 .68279 m .35428 .64909 L .35516 .66495 L F
.34024 .63442 m .33019 .57874 L .35078 .58 L p F P
0 g
s
.35073 .70882 m .3365 .32848 L p .34946 .69422 L .707 .577 .707 r
F P
0 g
s
.3365 .32848 m .33517 .29271 L p .33584 .31154 L .707 .577 .707 r
F P
0 g
s
.3365 .32848 m .33584 .31154 L .34946 .69422 L .707 .577 .707 r
F
.32987 .73862 m .33497 .72141 L .35492 .73558 L p F P
0 g
s
.34694 .60762 m .35399 .79624 L p .35635 .68643 L .707 .577 .707 r
F P
0 g
s
.35794 .61236 m .3521 .60984 L .35635 .68643 L .707 .577 .707 r
F
.3521 .60984 m .34694 .60762 L .35635 .68643 L F
.35428 .64909 m .36392 .65195 L p .35516 .66495 L F P
0 g
s
.3565 .61174 m .36082 .63568 L .35524 .63534 L p .707 .577 .707 r
F P
0 g
s
.33109 .28142 m .34432 .63515 L p .34946 .69422 L .707 .577 .707 r
F P
0 g
s
.34432 .63515 m .34992 .78495 L p .34946 .69422 L .707 .577 .707 r
F P
0 g
s
.34946 .69422 m .33584 .31154 L .33109 .28142 L .707 .577 .707 r
F
.3565 .61174 m .35078 .58 L p .36173 .61399 L F P
0 g
s
.33517 .29271 m .34694 .60762 L p .35794 .61236 L .707 .577 .707 r
F P
0 g
s
.34992 .78495 m .33812 .46935 L p .3411 .26987 L .707 .577 .707 r
F P
0 g
s
.33517 .29271 m .33509 .29248 L p .33584 .31154 L .707 .577 .707 r
F P
0 g
s
.33509 .29248 m .33109 .28142 L p .33584 .31154 L .707 .577 .707 r
F P
0 g
s
.33812 .46935 m .33109 .28142 L .33886 .27246 L p .707 .577 .707 r
F P
0 g
s
.33886 .27246 m .3411 .26987 L p .33812 .46935 L .707 .577 .707 r
F P
0 g
s
.34992 .78495 m .35399 .79624 L p .34946 .69422 L .707 .577 .707 r
F P
0 g
s
.35399 .79624 m .35073 .70882 L p .34946 .69422 L .707 .577 .707 r
F P
0 g
s
.35399 .79624 m .36271 .80111 L p .35635 .68643 L .707 .577 .707 r
F P
0 g
s
.36271 .80111 m .37175 .80617 L p .35635 .68643 L .707 .577 .707 r
F P
0 g
s
.36392 .65195 m .3642 .68903 L .35637 .68671 L p .707 .577 .707 r
F P
0 g
s
.35516 .66495 m .36392 .65195 L .35637 .68671 L .707 .577 .707 r
F
.36082 .63568 m .3565 .61174 L p .36173 .61399 L F P
0 g
s
.35794 .61236 m .36366 .58992 L .35219 .53161 L .707 .577 .707 r
F
.36461 .61523 m .36366 .58992 L p .35794 .61236 L F P
0 g
s
.36366 .58992 m .35292 .30264 L p .35219 .53161 L .707 .577 .707 r
F P
0 g
s
.6732 .66606 m .68325 .72174 L .65631 .7231 L p .707 .577 .707 r
F P
0 g
s
.65631 .7231 m .64626 .66743 L .6732 .66606 L p .707 .577 .707 r
F P
0 g
s
.70693 .77579 m .70721 .81287 L .68615 .80663 L p .707 .577 .707 r
F P
0 g
s
.68615 .80663 m .68588 .76955 L .70693 .77579 L p .707 .577 .707 r
F P
0 g
s
.32203 .77951 m .31693 .79672 L .34043 .795 L p .707 .577 .707 r
F P
0 g
s
.34043 .795 m .34552 .77779 L .32203 .77951 L p .707 .577 .707 r
F P
0 g
s
.18664 .73227 m .18154 .74948 L .2015 .76365 L p .707 .577 .707 r
F P
0 g
s
.64626 .66743 m .65631 .7231 L .62565 .72696 L p .707 .577 .707 r
F P
0 g
s
.60875 .28778 m .62758 .79131 L .63758 .77977 L p .707 .577 .707 r
F P
0 g
s
.63758 .77977 m .61875 .27624 L .60875 .28778 L p .707 .577 .707 r
F P
0 g
s
.18154 .74948 m .18664 .73227 L .17492 .71826 L p .707 .577 .707 r
F P
0 g
s
.69793 .84565 m .69283 .86285 L .67288 .84869 L p .707 .577 .707 r
F P
0 g
s
.67288 .84869 m .67797 .83148 L .69793 .84565 L p .707 .577 .707 r
F P
0 g
s
.68588 .76955 m .68615 .80663 L .6587 .80247 L p .707 .577 .707 r
F P
0 g
s
.6587 .80247 m .65842 .76539 L .68588 .76955 L p .707 .577 .707 r
F P
0 g
s
.17492 .71826 m .16982 .73547 L .18154 .74948 L p .707 .577 .707 r
F P
0 g
s
.65842 .76539 m .6587 .80247 L .62752 .80081 L p .707 .577 .707 r
F P
0 g
s
.67797 .83148 m .67288 .84869 L .64664 .83574 L p .707 .577 .707 r
F P
0 g
s
.64664 .83574 m .65174 .81853 L .67797 .83148 L p .707 .577 .707 r
F P
0 g
s
.16982 .73547 m .17492 .71826 L .17259 .70579 L p .707 .577 .707 r
F P
0 g
s
.17259 .70579 m .16749 .723 L .16982 .73547 L p .707 .577 .707 r
F P
0 g
s
.175 .67715 m .16496 .62147 L .17212 .61402 L p .707 .577 .707 r
F P
0 g
s
.65174 .81853 m .64664 .83574 L .61669 .82529 L p .707 .577 .707 r
F P
0 g
s
.61669 .82529 m .62178 .80808 L .65174 .81853 L p .707 .577 .707 r
F P
0 g
s
.62178 .80808 m .61669 .82529 L .58595 .81835 L p .707 .577 .707 r
F P
0 g
s
.61875 .27624 m .63758 .77977 L .63351 .76848 L p .707 .577 .707 r
F P
0 g
s
.63351 .76848 m .61468 .26495 L .61875 .27624 L p .707 .577 .707 r
F P
0 g
s
.16749 .723 m .17259 .70579 L .17986 .69607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.17986 .69607 m .17477 .71328 L .16749 .723 L p .707 .577 .707 r
F P
0 g
s
.18217 .66969 m .17212 .61402 L .18841 .60574 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17477 .71328 m .17986 .69607 L .19604 .69006 L p .707 .577 .707 r
F P
0 g
s
.61468 .26495 m .63351 .76848 L .61575 .75855 L p .707 .577 .707 r
F P
0 g
s
.61575 .75855 m .59692 .25502 L .61468 .26495 L p .707 .577 .707 r
F P
0 g
s
.19845 .66141 m .18841 .60574 L .21222 .59744 L p .707 .577 .707 r
F P
0 g
s
.19604 .69006 m .19094 .70727 L .17477 .71328 L p .707 .577 .707 r
F P
0 g
s
.33019 .57874 m .34024 .63442 L .3133 .63578 L p .707 .577 .707 r
F P
0 g
s
.3133 .63578 m .30325 .58011 L .33019 .57874 L p .707 .577 .707 r
F P
0 g
s
.35992 .7734 m .3411 .26987 L .3642 .25921 L p .707 .577 .707 r
F P
0 g
s
.3411 .26987 m .35992 .7734 L .34992 .78495 L p .707 .577 .707 r
F P
0 g
s
.22227 .65312 m .21222 .59744 L .24123 .58994 L p .707 .577 .707 r
F P
0 g
s
.19094 .70727 m .19604 .69006 L .21953 .68834 L p .707 .577 .707 r
F P
0 g
s
.34287 .64571 m .34314 .68279 L .31569 .67864 L p .707 .577 .707 r
F P
0 g
s
.31569 .67864 m .31541 .64155 L .34287 .64571 L p .707 .577 .707 r
F P
0 g
s
.30325 .58011 m .3133 .63578 L .28265 .63964 L p .707 .577 .707 r
F P
0 g
s
.28265 .63964 m .2726 .58397 L .30325 .58011 L p .707 .577 .707 r
F P
0 g
s
.21953 .68834 m .21443 .70555 L .19094 .70727 L p .707 .577 .707 r
F P
0 g
s
.2726 .58397 m .28265 .63964 L .25128 .64561 L p .707 .577 .707 r
F P
0 g
s
.59692 .25502 m .61575 .75855 L .58606 .75095 L p .707 .577 .707 r
F P
0 g
s
.58606 .75095 m .56723 .24742 L .59692 .25502 L p .707 .577 .707 r
F P
0 g
s
.31541 .64155 m .31569 .67864 L .28451 .67697 L p .707 .577 .707 r
F P
0 g
s
.28451 .67697 m .28424 .63989 L .31541 .64155 L p .707 .577 .707 r
F P
0 g
s
.21443 .70555 m .21953 .68834 L .24804 .69108 L p .707 .577 .707 r
F P
0 g
s
.28424 .63989 m .28451 .67697 L .25268 .67796 L p .707 .577 .707 r
F P
0 g
s
.33497 .72141 m .32987 .73862 L .30363 .72568 L p .707 .577 .707 r
F P
0 g
s
.30363 .72568 m .30873 .70847 L .33497 .72141 L p .707 .577 .707 r
F P
0 g
s
.74827 .67812 m .73823 .62244 L .70757 .6263 L p .707 .577 .707 r
F P
0 g
s
.73823 .62244 m .74827 .67812 L .77964 .67215 L p .707 .577 .707 r
F P
0 g
s
.77964 .67215 m .76959 .61647 L .73823 .62244 L p .707 .577 .707 r
F P
0 g
s
.76959 .61647 m .77964 .67215 L .80865 .66464 L p .707 .577 .707 r
F P
0 g
s
.80865 .66464 m .7986 .60897 L .76959 .61647 L p .707 .577 .707 r
F P
0 g
s
.24804 .69108 m .24294 .70829 L .21443 .70555 L p .707 .577 .707 r
F P
0 g
s
.3642 .25921 m .38303 .76274 L .35992 .7734 L p .707 .577 .707 r
F P
0 g
s
.38303 .76274 m .3642 .25921 L .39814 .25046 L p .707 .577 .707 r
F P
0 g
s
.71762 .68198 m .70757 .6263 L .68064 .62767 L p .707 .577 .707 r
F P
0 g
s
.70757 .6263 m .71762 .68198 L .74827 .67812 L p .707 .577 .707 r
F P
0 g
s
.24294 .70829 m .24804 .69108 L .27877 .69802 L p .707 .577 .707 r
F P
0 g
s
.30873 .70847 m .30363 .72568 L .27368 .71523 L p .707 .577 .707 r
F P
0 g
s
.27368 .71523 m .27877 .69802 L .30873 .70847 L p .707 .577 .707 r
F P
0 g
s
.7986 .60897 m .80865 .66464 L .83246 .65635 L p .707 .577 .707 r
F P
0 g
s
.83246 .65635 m .82242 .60067 L .7986 .60897 L p .707 .577 .707 r
F P
0 g
s
.27877 .69802 m .27368 .71523 L .24294 .70829 L p .707 .577 .707 r
F P
0 g
s
.68064 .62767 m .69068 .68334 L .71762 .68198 L p .707 .577 .707 r
F P
0 g
s
.56723 .24742 m .58606 .75095 L .54732 .74642 L p .707 .577 .707 r
F P
0 g
s
.54732 .74642 m .52849 .24289 L .56723 .24742 L p .707 .577 .707 r
F P
0 g
s
.75118 .76301 m .7509 .72593 L .71973 .72426 L p .707 .577 .707 r
F P
0 g
s
.7509 .72593 m .75118 .76301 L .78301 .76202 L p .707 .577 .707 r
F P
0 g
s
.78301 .76202 m .78274 .72494 L .7509 .72593 L p .707 .577 .707 r
F P
0 g
s
.69068 .68334 m .68064 .62767 L .66005 .62641 L p .707 .577 .707 r
F P
0 g
s
.78274 .72494 m .78301 .76202 L .81239 .75847 L p .707 .577 .707 r
F P
0 g
s
.81239 .75847 m .81212 .72139 L .78274 .72494 L p .707 .577 .707 r
F P
0 g
s
.72001 .76135 m .71973 .72426 L .69227 .72011 L p .707 .577 .707 r
F P
0 g
s
.71973 .72426 m .72001 .76135 L .75118 .76301 L p .707 .577 .707 r
F P
0 g
s
.82242 .60067 m .83246 .65635 L .84875 .64807 L p .707 .577 .707 r
F P
0 g
s
.84875 .64807 m .8387 .59239 L .82242 .60067 L p .707 .577 .707 r
F P
0 g
s
.39814 .25046 m .4396 .24449 L p .42549 .56225 L .707 .577 .707 r
F P
0 g
s
.44 .63818 m .43973 .6011 L .42515 .60155 L p .707 .577 .707 r
F P
0 g
s
.42303 .61761 m .41936 .56348 L .42201 .56295 L .707 .577 .707 r
F
.42303 .61761 m .42201 .56295 L .42424 .59036 L F
.41697 .75399 m .41395 .67311 L p .42303 .61761 L F P
0 g
s
.41395 .67311 m .39948 .28624 L p .42303 .61761 L .707 .577 .707 r
F P
0 g
s
.39948 .28624 m .39814 .25046 L p .40598 .36602 L .707 .577 .707 r
F P
0 g
s
.39948 .28624 m .40598 .36602 L .42303 .61761 L .707 .577 .707 r
F
.38303 .76274 m .39791 .25838 L .4139 .67408 L F
.39948 .28624 m .41395 .67311 L p .39791 .25838 L F P
0 g
s
.41395 .67311 m .41697 .75399 L p .4139 .67408 L .707 .577 .707 r
F P
0 g
s
.39791 .25838 m .41395 .67311 L .4139 .67408 L .707 .577 .707 r
F
.42424 .59036 m .42201 .56295 L .42549 .56225 L F
.42816 .63855 m .44 .63818 L p .42694 .6235 L F P
0 g
s
.44 .63818 m .42515 .60155 L .42694 .6235 L .707 .577 .707 r
F
.43663 .58483 m .46008 .57876 L p .44952 .55744 L F P
0 g
s
.4396 .24449 m .48452 .24188 L p .46636 .59424 L .707 .577 .707 r
F P
0 g
s
.45129 .55709 m .4396 .24449 L p .46636 .59424 L .707 .577 .707 r
F P
0 g
s
.46008 .57876 m .46564 .57732 L p .45335 .56217 L .707 .577 .707 r
F P
0 g
s
.45335 .56217 m .44952 .55744 L .46008 .57876 L .707 .577 .707 r
F
.42813 .58644 m .43663 .58483 L p .42974 .57656 L F P
0 g
s
.42303 .61761 m .42549 .56225 L .42892 .58161 L .707 .577 .707 r
F
.4396 .24449 m .45129 .55709 L p .42549 .56225 L F P
0 g
s
.43663 .58483 m .43231 .56089 L p .42974 .57656 L .707 .577 .707 r
F P
0 g
s
.46564 .57732 m .46161 .55502 L p .44952 .55744 L .707 .577 .707 r
F P
0 g
s
.43231 .56089 m .43663 .58483 L p .44952 .55744 L .707 .577 .707 r
F P
0 g
s
.43973 .6011 m .44 .63818 L .46603 .63504 L p .707 .577 .707 r
F P
0 g
s
.48452 .24188 m .50335 .74541 L .46197 .74781 L p .707 .577 .707 r
F P
0 g
s
.47014 .52084 m .48452 .24188 L .46197 .74781 L .707 .577 .707 r
F
.46603 .63504 m .46938 .63463 L p .46618 .63101 L F P
0 g
s
.46618 .63101 m .43973 .6011 L .46603 .63504 L .707 .577 .707 r
F
.46938 .63463 m .46911 .59755 L .43973 .6011 L p F P
0 g
s
.46197 .74781 m .45843 .74802 L p .47014 .52084 L .707 .577 .707 r
F P
0 g
s
.45129 .55709 m .45843 .74802 L p .42549 .56225 L .707 .577 .707 r
F P
0 g
s
.41936 .56348 m .39814 .25046 L .42549 .56225 L .707 .577 .707 r
F
.42658 .52915 m .39522 .53512 L p .42974 .57656 L F P
0 g
s
.43231 .56089 m .42658 .52915 L p .42974 .57656 L .707 .577 .707 r
F P
0 g
s
.45843 .74802 m .41697 .75399 L p .42303 .61761 L .707 .577 .707 r
F P
0 g
s
.42303 .61761 m .42892 .58161 L .45843 .74802 L .707 .577 .707 r
F
.45559 .52165 m .42658 .52915 L p .44952 .55744 L F P
0 g
s
.46161 .55502 m .45559 .52165 L p .44952 .55744 L .707 .577 .707 r
F P
0 g
s
.45843 .74802 m .45535 .66571 L p .46319 .65562 L .707 .577 .707 r
F P
0 g
s
.45414 .70468 m .45924 .68747 L .43989 .68561 L p .707 .577 .707 r
F P
0 g
s
.43989 .68561 m .43073 .68473 L p .43665 .68978 L .707 .577 .707 r
F P
0 g
s
.45414 .70468 m .43989 .68561 L .43665 .68978 L .707 .577 .707 r
F
.46319 .65562 m .45129 .55709 L .46636 .59424 L F
.45535 .66571 m .45129 .55709 L p .46319 .65562 L F P
0 g
s
.42974 .57656 m .41947 .56423 L .42813 .58644 L .707 .577 .707 r
F
.41947 .56423 m .39522 .53512 L .41906 .5723 L F
.41947 .56423 m .41906 .5723 L .42813 .58644 L F
.39522 .53512 m .40526 .5908 L .41825 .58832 L p F P
0 g
s
.41825 .58832 m .42813 .58644 L p .41906 .5723 L .707 .577 .707 r
F P
0 g
s
.41906 .5723 m .39522 .53512 L .41825 .58832 L .707 .577 .707 r
F
.41697 .75399 m .40975 .75585 L p .4139 .67408 L F P
0 g
s
.40975 .75585 m .38303 .76274 L p .4139 .67408 L .707 .577 .707 r
F P
0 g
s
.39814 .25046 m .39948 .28624 L p .39791 .25838 L .707 .577 .707 r
F P
0 g
s
.40789 .60209 m .40817 .63917 L .41937 .63882 L p .707 .577 .707 r
F P
0 g
s
.41937 .63882 m .42816 .63855 L p .41836 .62091 L .707 .577 .707 r
F P
0 g
s
.41836 .62091 m .40789 .60209 L .41937 .63882 L .707 .577 .707 r
F
.42694 .6235 m .40789 .60209 L .42816 .63855 L F
.42515 .60155 m .40789 .60209 L p .42694 .6235 L F P
0 g
s
.42658 .52915 m .43231 .56089 L p .44952 .55744 L .707 .577 .707 r
F P
0 g
s
.66005 .62641 m .67009 .68208 L .69068 .68334 L p .707 .577 .707 r
F P
0 g
s
.81212 .72139 m .81239 .75847 L .83645 .75271 L p .707 .577 .707 r
F P
0 g
s
.83645 .75271 m .83617 .71563 L .81212 .72139 L p .707 .577 .707 r
F P
0 g
s
.69227 .72011 m .69255 .75719 L .72001 .76135 L p .707 .577 .707 r
F P
0 g
s
.7379 .80507 m .743 .78786 L .71305 .7774 L p .707 .577 .707 r
F P
0 g
s
.743 .78786 m .7379 .80507 L .76864 .812 L p .707 .577 .707 r
F P
0 g
s
.76864 .812 m .77374 .79479 L .743 .78786 L p .707 .577 .707 r
F P
0 g
s
.52849 .24289 m .54732 .74642 L .50335 .74541 L p .707 .577 .707 r
F P
0 g
s
.50335 .74541 m .48452 .24188 L .52849 .24289 L p .707 .577 .707 r
F P
0 g
s
.69255 .75719 m .69227 .72011 L .67122 .71386 L p .707 .577 .707 r
F P
0 g
s
.70795 .79461 m .71305 .7774 L .68681 .76446 L p .707 .577 .707 r
F P
0 g
s
.71305 .7774 m .70795 .79461 L .7379 .80507 L p .707 .577 .707 r
F P
0 g
s
.77374 .79479 m .76864 .812 L .79715 .81475 L p .707 .577 .707 r
F P
0 g
s
.79715 .81475 m .80224 .79754 L .77374 .79479 L p .707 .577 .707 r
F P
0 g
s
.67009 .68208 m .66005 .62641 L .64783 .62265 L p .707 .577 .707 r
F P
0 g
s
.68681 .76446 m .68171 .78167 L .70795 .79461 L p .707 .577 .707 r
F P
0 g
s
.67122 .71386 m .67149 .75095 L .69255 .75719 L p .707 .577 .707 r
F P
0 g
s
.8387 .59239 m .84875 .64807 L .85591 .64061 L p .707 .577 .707 r
F P
0 g
s
.85591 .64061 m .84587 .58494 L .8387 .59239 L p .707 .577 .707 r
F P
0 g
s
.83617 .71563 m .83645 .75271 L .85282 .74531 L p .707 .577 .707 r
F P
0 g
s
.85282 .74531 m .85254 .70823 L .83617 .71563 L p .707 .577 .707 r
F P
0 g
s
.68171 .78167 m .68681 .76446 L .66685 .75029 L p .707 .577 .707 r
F P
0 g
s
.64783 .62265 m .65787 .67832 L .67009 .68208 L p .707 .577 .707 r
F P
0 g
s
.80224 .79754 m .79715 .81475 L .82064 .81303 L p .707 .577 .707 r
F P
0 g
s
.82064 .81303 m .82574 .79582 L .80224 .79754 L p .707 .577 .707 r
F P
0 g
s
.66685 .75029 m .66176 .7675 L .68171 .78167 L p .707 .577 .707 r
F P
0 g
s
.67149 .75095 m .67122 .71386 L .65863 .70615 L p .707 .577 .707 r
F P
0 g
s
.65787 .67832 m .64783 .62265 L .64517 .61675 L p .707 .577 .707 r
F P
0 g
s
.66176 .7675 m .66685 .75029 L .65978 .74184 L p .707 .577 .707 r
F P
0 g
s
.65978 .74184 m .65514 .73629 L p .66108 .7643 L .707 .577 .707 r
F P
0 g
s
.66176 .7675 m .65978 .74184 L .66108 .7643 L .707 .577 .707 r
F
.6589 .74323 m .65876 .72405 L p .65573 .69772 L F P
0 g
s
.65876 .72405 m .65863 .70615 L .65755 .70301 L p .707 .577 .707 r
F P
0 g
s
.65755 .70301 m .65573 .69772 L p .65876 .72405 L .707 .577 .707 r
F P
0 g
s
.65863 .70615 m .6589 .74323 L .67149 .75095 L p .707 .577 .707 r
F P
0 g
s
.85254 .70823 m .85282 .74531 L .8599 .73698 L p .707 .577 .707 r
F P
0 g
s
.8599 .73698 m .85962 .6999 L .85254 .70823 L p .707 .577 .707 r
F P
0 g
s
.82574 .79582 m .82064 .81303 L .83682 .80702 L p .707 .577 .707 r
F P
0 g
s
.83682 .80702 m .84191 .78981 L .82574 .79582 L p .707 .577 .707 r
F P
0 g
s
.65514 .73629 m .65004 .7535 L .66176 .7675 L p .707 .577 .707 r
F P
0 g
s
.84587 .58494 m .85591 .64061 L .85326 .63472 L p .707 .577 .707 r
F P
0 g
s
.85326 .63472 m .84321 .57904 L .84587 .58494 L p .707 .577 .707 r
F P
0 g
s
.64517 .61675 m .65522 .67243 L .65787 .67832 L p .707 .577 .707 r
F P
0 g
s
.65004 .7535 m .65514 .73629 L .6528 .72381 L p .707 .577 .707 r
F P
0 g
s
.6528 .72381 m .6477 .74102 L .65004 .7535 L p .707 .577 .707 r
F P
0 g
s
.6477 .74102 m .6528 .72381 L .65497 .72092 L p .707 .577 .707 r
F P
0 g
s
.65601 .7348 m .6589 .74323 L p .65647 .70831 L .707 .577 .707 r
F P
0 g
s
.65585 .71352 m .65601 .7348 L p .65647 .70831 L .707 .577 .707 r
F P
0 g
s
.65573 .69772 m .65585 .71352 L p .65647 .70831 L .707 .577 .707 r
F P
0 g
s
.65601 .7348 m .65573 .69772 L .66281 .68939 L p .707 .577 .707 r
F P
0 g
s
.66309 .72647 m .65601 .7348 L p .66133 .69928 L .707 .577 .707 r
F P
0 g
s
.66281 .68939 m .66293 .70447 L p .66133 .69928 L .707 .577 .707 r
F P
0 g
s
.66293 .70447 m .66309 .72647 L p .66133 .69928 L .707 .577 .707 r
F P
0 g
s
.66309 .72647 m .66281 .68939 L .67918 .68198 L p .707 .577 .707 r
F P
0 g
s
.65498 .7313 m .66008 .71409 L .66528 .71216 L p .707 .577 .707 r
F P
0 g
s
.67946 .71907 m .66309 .72647 L p .67576 .69145 L .707 .577 .707 r
F P
0 g
s
.67918 .68198 m .6793 .69779 L p .67576 .69145 L .707 .577 .707 r
F P
0 g
s
.6793 .69779 m .67946 .71907 L p .67576 .69145 L .707 .577 .707 r
F P
0 g
s
.67946 .71907 m .67918 .68198 L .70323 .67623 L p .707 .577 .707 r
F P
0 g
s
.67115 .72529 m .67625 .70808 L .6847 .70746 L p .707 .577 .707 r
F P
0 g
s
.70351 .71331 m .67946 .71907 L p .69824 .68523 L .707 .577 .707 r
F P
0 g
s
.70323 .67623 m .70337 .69413 L p .69824 .68523 L .707 .577 .707 r
F P
0 g
s
.70337 .69413 m .70351 .71331 L p .69824 .68523 L .707 .577 .707 r
F P
0 g
s
.70351 .71331 m .70323 .67623 L .73262 .67268 L p .707 .577 .707 r
F P
0 g
s
.73262 .67268 m .73289 .70976 L .70351 .71331 L p .707 .577 .707 r
F P
0 g
s
.69465 .72357 m .69974 .70636 L .71105 .70745 L p .707 .577 .707 r
F P
0 g
s
.71105 .70745 m .72825 .70911 L p .71524 .71471 L .707 .577 .707 r
F P
0 g
s
.69465 .72357 m .71105 .70745 L .71524 .71471 L .707 .577 .707 r
F
.6847 .70746 m .69974 .70636 L p .68831 .71393 L F P
0 g
s
.67115 .72529 m .6847 .70746 L .68831 .71393 L .707 .577 .707 r
F
.66528 .71216 m .67625 .70808 L p .6671 .71807 L F P
0 g
s
.65498 .7313 m .66528 .71216 L .6671 .71807 L .707 .577 .707 r
F
.65497 .72092 m .66008 .71409 L p .65428 .72671 L F P
0 g
s
.6477 .74102 m .65497 .72092 L .65428 .72671 L .707 .577 .707 r
F
.65522 .67243 m .64517 .61675 L .65234 .6093 L p F P
0 g
s
.84191 .78981 m .83682 .80702 L .84409 .7973 L p .707 .577 .707 r
F P
0 g
s
.84409 .7973 m .84919 .78009 L .84191 .78981 L p .707 .577 .707 r
F P
0 g
s
.85962 .6999 m .8599 .73698 L .857 .72855 L p .707 .577 .707 r
F P
0 g
s
.857 .72855 m .85673 .69146 L .85962 .6999 L p .707 .577 .707 r
F P
0 g
s
.40526 .5908 m .39522 .53512 L .36456 .53898 L p .707 .577 .707 r
F P
0 g
s
.84321 .57904 m .85326 .63472 L .84104 .63096 L p .707 .577 .707 r
F P
0 g
s
.84104 .63096 m .83099 .57528 L .84321 .57904 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.65234 .6093 m .66238 .66497 L .65522 .67243 L p .707 .577 .707 r
F P
0 g
s
.37461 .59466 m .36456 .53898 L .33763 .54035 L p .707 .577 .707 r
F P
0 g
s
.36456 .53898 m .37461 .59466 L .40526 .5908 L p .707 .577 .707 r
F P
0 g
s
.45559 .52165 m .46564 .57732 L .48945 .56903 L p .707 .577 .707 r
F P
0 g
s
.48945 .56903 m .47941 .51335 L .45559 .52165 L p .707 .577 .707 r
F P
0 g
s
.40817 .63917 m .40789 .60209 L .37672 .60042 L p .707 .577 .707 r
F P
0 g
s
.33763 .54035 m .34767 .59602 L .34984 .59591 L p .707 .577 .707 r
F P
0 g
s
.34767 .59602 m .33763 .54035 L .31704 .53909 L p .707 .577 .707 r
F P
0 g
s
.31704 .53909 m .32708 .59476 L .32899 .59488 L p .707 .577 .707 r
F P
0 g
s
.32899 .59488 m .34767 .59602 L p .33195 .56681 L .707 .577 .707 r
F P
0 g
s
.33195 .56681 m .31704 .53909 L .32899 .59488 L .707 .577 .707 r
F
.32708 .59476 m .31704 .53909 L .30482 .53533 L p F P
0 g
s
.30482 .53533 m .31486 .591 L .31587 .59131 L p .707 .577 .707 r
F P
0 g
s
.31587 .59131 m .32708 .59476 L p .3167 .56705 L .707 .577 .707 r
F P
0 g
s
.3167 .56705 m .30482 .53533 L .31587 .59131 L .707 .577 .707 r
F
.31486 .591 m .30482 .53533 L .30216 .52943 L p F P
0 g
s
.30216 .52943 m .31221 .58511 L .31238 .5855 L p .707 .577 .707 r
F P
0 g
s
.31238 .5855 m .31486 .591 L p .30911 .56312 L .707 .577 .707 r
F P
0 g
s
.30911 .56312 m .30216 .52943 L .31238 .5855 L .707 .577 .707 r
F
.31562 .58231 m .31272 .57388 L p .31523 .60988 L F P
0 g
s
.31572 .59573 m .31562 .58231 L p .31523 .60988 L .707 .577 .707 r
F P
0 g
s
.32821 .59003 m .31562 .58231 L p .32636 .61973 L .707 .577 .707 r
F P
0 g
s
.31562 .58231 m .31589 .61939 L .32848 .62711 L p .707 .577 .707 r
F P
0 g
s
.31272 .57388 m .31283 .58856 L p .31589 .61939 L .707 .577 .707 r
F P
0 g
s
.31283 .58856 m .313 .61096 L .31424 .61457 L p .707 .577 .707 r
F P
0 g
s
.31424 .61457 m .31589 .61939 L p .31283 .58856 L .707 .577 .707 r
F P
0 g
s
.31272 .57388 m .3198 .56555 L p .31457 .60047 L .707 .577 .707 r
F P
0 g
s
.31283 .58856 m .31272 .57388 L p .31457 .60047 L .707 .577 .707 r
F P
0 g
s
.31589 .61939 m .31572 .59573 L p .31523 .60988 L .707 .577 .707 r
F P
0 g
s
.3198 .56555 m .31992 .58067 L p .313 .61096 L .707 .577 .707 r
F P
0 g
s
.31992 .58067 m .32008 .60263 L .31715 .60607 L p .707 .577 .707 r
F P
0 g
s
.31715 .60607 m .313 .61096 L p .31992 .58067 L .707 .577 .707 r
F P
0 g
s
.32008 .60263 m .3198 .56555 L .33617 .55815 L p .707 .577 .707 r
F P
0 g
s
.32561 .5137 m .3266 .51918 L p .31937 .57765 L .707 .577 .707 r
F P
0 g
s
.32829 .60147 m .32821 .59003 L p .32636 .61973 L .707 .577 .707 r
F P
0 g
s
.34926 .59627 m .32821 .59003 L p .34795 .63013 L .707 .577 .707 r
F P
0 g
s
.32821 .59003 m .32848 .62711 L .34954 .63335 L p .707 .577 .707 r
F P
0 g
s
.33617 .55815 m .33628 .57283 L p .32008 .60263 L .707 .577 .707 r
F P
0 g
s
.33628 .57283 m .33645 .59523 L .33032 .598 L p .707 .577 .707 r
F P
0 g
s
.33032 .598 m .32008 .60263 L p .33628 .57283 L .707 .577 .707 r
F P
0 g
s
.35177 .56112 m .33763 .54035 L .34984 .59591 L .707 .577 .707 r
F
.34984 .59591 m .37461 .59466 L p .35177 .56112 L F P
0 g
s
.33645 .59523 m .33617 .55815 L .36022 .55239 L p .707 .577 .707 r
F P
0 g
s
.34943 .5054 m .35064 .51215 L p .33566 .56937 L .707 .577 .707 r
F P
0 g
s
.36022 .55239 m .36032 .5658 L p .33645 .59523 L .707 .577 .707 r
F P
0 g
s
.36032 .5658 m .3605 .58947 L .35302 .59126 L p .707 .577 .707 r
F P
0 g
s
.35302 .59126 m .33645 .59523 L p .36032 .5658 L .707 .577 .707 r
F P
0 g
s
.3605 .58947 m .36022 .55239 L .38961 .54884 L p .707 .577 .707 r
F P
0 g
s
.37844 .4979 m .37896 .5008 L p .35947 .56108 L .707 .577 .707 r
F P
0 g
s
.38961 .54884 m .38969 .56028 L p .3605 .58947 L .707 .577 .707 r
F P
0 g
s
.38969 .56028 m .38988 .58592 L .38353 .58669 L p .707 .577 .707 r
F P
0 g
s
.38353 .58669 m .3605 .58947 L p .38969 .56028 L .707 .577 .707 r
F P
0 g
s
.38988 .58592 m .38961 .54884 L .42144 .54785 L p .707 .577 .707 r
F P
0 g
s
.38848 .55358 m .37844 .4979 L .40544 .49276 L p .707 .577 .707 r
F P
0 g
s
.40544 .49276 m .4098 .49193 L p .397 .52894 L .707 .577 .707 r
F P
0 g
s
.38848 .55358 m .40544 .49276 L .397 .52894 L .707 .577 .707 r
F
.37896 .5008 m .38848 .55358 L .36186 .56046 L p F P
0 g
s
.36186 .56046 m .35947 .56108 L p .37896 .5008 L .707 .577 .707 r
F P
0 g
s
.35064 .51215 m .35947 .56108 L .33723 .56883 L p .707 .577 .707 r
F P
0 g
s
.33723 .56883 m .33566 .56937 L p .35064 .51215 L .707 .577 .707 r
F P
0 g
s
.3266 .51918 m .33566 .56937 L .32029 .57718 L p .707 .577 .707 r
F P
0 g
s
.32029 .57718 m .31937 .57765 L p .3266 .51918 L .707 .577 .707 r
F P
0 g
s
.30933 .52198 m .31937 .57765 L .31262 .58468 L p .707 .577 .707 r
F P
0 g
s
.31262 .58468 m .31221 .58511 L p .30986 .53362 L .707 .577 .707 r
F P
0 g
s
.30986 .53362 m .30933 .52198 L .31262 .58468 L .707 .577 .707 r
F
.313 .61096 m .31283 .58856 L p .31457 .60047 L F P
0 g
s
.32848 .62711 m .32829 .60147 L p .32636 .61973 L .707 .577 .707 r
F P
0 g
s
.34954 .63335 m .34933 .60522 L p .34795 .63013 L .707 .577 .707 r
F P
0 g
s
.34933 .60522 m .34926 .59627 L p .34795 .63013 L .707 .577 .707 r
F P
0 g
s
.377 .63751 m .37672 .60042 L .34926 .59627 L p .707 .577 .707 r
F P
0 g
s
.37672 .60042 m .377 .63751 L .40817 .63917 L p .707 .577 .707 r
F P
0 g
s
.66238 .66497 m .65234 .6093 L .66862 .60102 L p .707 .577 .707 r
F P
0 g
s
.84919 .78009 m .84409 .7973 L .84176 .78482 L p .707 .577 .707 r
F P
0 g
s
.84176 .78482 m .84685 .76761 L .84919 .78009 L p .707 .577 .707 r
F P
0 g
s
.66008 .71409 m .65498 .7313 L .6477 .74102 L p .707 .577 .707 r
F P
0 g
s
.85673 .69146 m .857 .72855 L .84441 .72083 L p .707 .577 .707 r
F P
0 g
s
.84441 .72083 m .84414 .68375 L .85673 .69146 L p .707 .577 .707 r
F P
0 g
s
.46911 .59755 m .46938 .63463 L .49344 .62888 L p .707 .577 .707 r
F P
0 g
s
.49344 .62888 m .49316 .59179 L .46911 .59755 L p .707 .577 .707 r
F P
0 g
s
.34926 .59627 m .34954 .63335 L .377 .63751 L p .707 .577 .707 r
F P
0 g
s
.83099 .57528 m .84104 .63096 L .82045 .6297 L p .707 .577 .707 r
F P
0 g
s
.82045 .6297 m .81041 .57402 L .83099 .57528 L p .707 .577 .707 r
F P
0 g
s
.47941 .51335 m .48945 .56903 L .50574 .56075 L p .707 .577 .707 r
F P
0 g
s
.50574 .56075 m .49569 .50507 L .47941 .51335 L p .707 .577 .707 r
F P
0 g
s
.66862 .60102 m .67867 .65669 L .66238 .66497 L p .707 .577 .707 r
F P
0 g
s
.39489 .695 m .39999 .67779 L .37004 .66734 L p .707 .577 .707 r
F P
0 g
s
.39999 .67779 m .39489 .695 L .42563 .70194 L p .707 .577 .707 r
F P
0 g
s
.42563 .70194 m .43073 .68473 L .39999 .67779 L p .707 .577 .707 r
F P
0 g
s
.36494 .68455 m .37004 .66734 L .3438 .6544 L p .707 .577 .707 r
F P
0 g
s
.37004 .66734 m .36494 .68455 L .39489 .695 L p .707 .577 .707 r
F P
0 g
s
.43073 .68473 m .42563 .70194 L .45414 .70468 L p .707 .577 .707 r
F P
0 g
s
.49316 .59179 m .49344 .62888 L .50981 .62147 L p .707 .577 .707 r
F P
0 g
s
.50981 .62147 m .50953 .58439 L .49316 .59179 L p .707 .577 .707 r
F P
0 g
s
.3438 .6544 m .3387 .67161 L .36494 .68455 L p .707 .577 .707 r
F P
0 g
s
.67867 .65669 m .66862 .60102 L .69244 .59272 L p .707 .577 .707 r
F P
0 g
s
.84685 .76761 m .84176 .78482 L .83004 .77082 L p .707 .577 .707 r
F P
0 g
s
.83004 .77082 m .83514 .75361 L .84685 .76761 L p .707 .577 .707 r
F P
0 g
s
.3387 .67161 m .3438 .6544 L .32384 .64023 L p .707 .577 .707 r
F P
0 g
s
.67625 .70808 m .67115 .72529 L .65498 .7313 L p .707 .577 .707 r
F P
0 g
s
.81041 .57402 m .82045 .6297 L .79351 .63107 L p .707 .577 .707 r
F P
0 g
s
.79351 .63107 m .78347 .57539 L .81041 .57402 L p .707 .577 .707 r
F P
0 g
s
.84414 .68375 m .84441 .72083 L .82336 .71459 L p .707 .577 .707 r
F P
0 g
s
.82336 .71459 m .82308 .67751 L .84414 .68375 L p .707 .577 .707 r
F P
0 g
s
.45924 .68747 m .45414 .70468 L .47763 .70297 L p .707 .577 .707 r
F P
0 g
s
.47763 .70297 m .48273 .68576 L .45924 .68747 L p .707 .577 .707 r
F P
0 g
s
.49569 .50507 m .50574 .56075 L .5129 .55329 L p .707 .577 .707 r
F P
0 g
s
.5129 .55329 m .50286 .49762 L .49569 .50507 L p .707 .577 .707 r
F P
0 g
s
.69244 .59272 m .70248 .6484 L .67867 .65669 L p .707 .577 .707 r
F P
0 g
s
.32384 .64023 m .31875 .65744 L .3387 .67161 L p .707 .577 .707 r
F P
0 g
s
.70248 .6484 m .69244 .59272 L .72145 .58522 L p .707 .577 .707 r
F P
0 g
s
.78347 .57539 m .79351 .63107 L .76286 .63492 L p .707 .577 .707 r
F P
0 g
s
.76286 .63492 m .75281 .57925 L .78347 .57539 L p .707 .577 .707 r
F P
0 g
s
.50953 .58439 m .50981 .62147 L .51689 .61314 L p .707 .577 .707 r
F P
0 g
s
.51689 .61314 m .51661 .57606 L .50953 .58439 L p .707 .577 .707 r
F P
0 g
s
.31875 .65744 m .32384 .64023 L .31213 .62622 L p .707 .577 .707 r
F P
0 g
s
.48273 .68576 m .47763 .70297 L .49381 .69695 L p .707 .577 .707 r
F P
0 g
s
.49381 .69695 m .4989 .67974 L .48273 .68576 L p .707 .577 .707 r
F P
0 g
s
.83514 .75361 m .83004 .77082 L .81008 .75665 L p .707 .577 .707 r
F P
0 g
s
.81008 .75665 m .81518 .73944 L .83514 .75361 L p .707 .577 .707 r
F P
0 g
s
.82308 .67751 m .82336 .71459 L .7959 .71044 L p .707 .577 .707 r
F P
0 g
s
.7959 .71044 m .79562 .67335 L .82308 .67751 L p .707 .577 .707 r
F P
0 g
s
.73149 .6409 m .72145 .58522 L .75281 .57925 L p .707 .577 .707 r
F P
0 g
s
.72145 .58522 m .73149 .6409 L .70248 .6484 L p .707 .577 .707 r
F P
0 g
s
.75281 .57925 m .76286 .63492 L .73149 .6409 L p .707 .577 .707 r
F P
0 g
s
.31213 .62622 m .30703 .64343 L .31875 .65744 L p .707 .577 .707 r
F P
0 g
s
.69974 .70636 m .69465 .72357 L .67115 .72529 L p .707 .577 .707 r
F P
0 g
s
.50286 .49762 m .5129 .55329 L .51025 .5474 L p .707 .577 .707 r
F P
0 g
s
.51025 .5474 m .5002 .49172 L .50286 .49762 L p .707 .577 .707 r
F P
0 g
s
.79562 .67335 m .7959 .71044 L .76473 .70877 L p .707 .577 .707 r
F P
0 g
s
.76473 .70877 m .76445 .67169 L .79562 .67335 L p .707 .577 .707 r
F P
0 g
s
.73289 .70976 m .73262 .67268 L .76445 .67169 L p .707 .577 .707 r
F P
0 g
s
.81518 .73944 m .81008 .75665 L .78384 .7437 L p .707 .577 .707 r
F P
0 g
s
.78384 .7437 m .78894 .72649 L .81518 .73944 L p .707 .577 .707 r
F P
0 g
s
.30703 .64343 m .31213 .62622 L .30979 .61375 L p .707 .577 .707 r
F P
0 g
s
.76445 .67169 m .76473 .70877 L .73289 .70976 L p .707 .577 .707 r
F P
0 g
s
.72825 .70911 m .72316 .72631 L .69465 .72357 L p .707 .577 .707 r
F P
0 g
s
.51661 .57606 m .51689 .61314 L .51399 .60471 L p .707 .577 .707 r
F P
0 g
s
.51399 .60471 m .51372 .56763 L .51661 .57606 L p .707 .577 .707 r
F P
0 g
s
.4989 .67974 m .49381 .69695 L .50108 .68723 L p .707 .577 .707 r
F P
0 g
s
.50108 .68723 m .50618 .67002 L .4989 .67974 L p .707 .577 .707 r
F P
0 g
s
.30979 .61375 m .30469 .63096 L .30703 .64343 L p .707 .577 .707 r
F P
0 g
s
.31221 .58511 m .30216 .52943 L .30933 .52198 L p .707 .577 .707 r
F P
0 g
s
.72316 .72631 m .72825 .70911 L .75899 .71604 L p .707 .577 .707 r
F P
0 g
s
.78894 .72649 m .78384 .7437 L .75389 .73325 L p .707 .577 .707 r
F P
0 g
s
.75389 .73325 m .75899 .71604 L .78894 .72649 L p .707 .577 .707 r
F P
0 g
s
.75899 .71604 m .75389 .73325 L .72316 .72631 L p .707 .577 .707 r
F P
0 g
s
.5002 .49172 m .51025 .5474 L .49803 .54364 L p .707 .577 .707 r
F P
0 g
s
.49803 .54364 m .48798 .48796 L .5002 .49172 L p .707 .577 .707 r
F P
0 g
s
.30469 .63096 m .30979 .61375 L .31707 .60403 L p .707 .577 .707 r
F P
0 g
s
.50618 .67002 m .50108 .68723 L .49875 .67476 L p .707 .577 .707 r
F P
0 g
s
.49875 .67476 m .50384 .65755 L .50618 .67002 L p .707 .577 .707 r
F P
0 g
s
.51372 .56763 m .51399 .60471 L .5014 .59699 L p .707 .577 .707 r
F P
0 g
s
.5014 .59699 m .50112 .55991 L .51372 .56763 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.31707 .60403 m .31197 .62124 L .30469 .63096 L p .707 .577 .707 r
F P
0 g
s
.31937 .57765 m .30933 .52198 L .32561 .5137 L p .707 .577 .707 r
F P
0 g
s
.48798 .48796 m .49803 .54364 L .47744 .54238 L p .707 .577 .707 r
F P
0 g
s
.47744 .54238 m .46739 .4867 L .48798 .48796 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31197 .62124 m .31707 .60403 L .33324 .59802 L p .707 .577 .707 r
F P
0 g
s
.50112 .55991 m .5014 .59699 L .48035 .59075 L p .707 .577 .707 r
F P
0 g
s
.48035 .59075 m .48007 .55367 L .50112 .55991 L p .707 .577 .707 r
F P
0 g
s
.50384 .65755 m .49875 .67476 L .48703 .66075 L p .707 .577 .707 r
F P
0 g
s
.48703 .66075 m .49212 .64354 L .50384 .65755 L p .707 .577 .707 r
F P
0 g
s
.33566 .56937 m .32561 .5137 L .34943 .5054 L p .707 .577 .707 r
F P
0 g
s
.33324 .59802 m .32814 .61523 L .31197 .62124 L p .707 .577 .707 r
F P
0 g
s
.46739 .4867 m .47744 .54238 L .4505 .54375 L p .707 .577 .707 r
F P
0 g
s
.4505 .54375 m .44046 .48807 L .46739 .4867 L p .707 .577 .707 r
F P
0 g
s
.35947 .56108 m .34943 .5054 L .37844 .4979 L p .707 .577 .707 r
F P
0 g
s
.32814 .61523 m .33324 .59802 L .35673 .5963 L p .707 .577 .707 r
F P
0 g
s
.48007 .55367 m .48035 .59075 L .45289 .5866 L p .707 .577 .707 r
F P
0 g
s
.45289 .5866 m .45261 .54951 L .48007 .55367 L p .707 .577 .707 r
F P
0 g
s
.44046 .48807 m .4505 .54375 L .41985 .5476 L p .707 .577 .707 r
F P
0 g
s
.41985 .5476 m .4098 .49193 L .44046 .48807 L p .707 .577 .707 r
F P
0 g
s
.49212 .64354 m .48703 .66075 L .46707 .64658 L p .707 .577 .707 r
F P
0 g
s
.46707 .64658 m .47217 .62938 L .49212 .64354 L p .707 .577 .707 r
F P
0 g
s
.35673 .5963 m .35164 .61351 L .32814 .61523 L p .707 .577 .707 r
F P
0 g
s
.4098 .49193 m .41985 .5476 L .38848 .55358 L p .707 .577 .707 r
F P
0 g
s
.45261 .54951 m .45289 .5866 L .42172 .58493 L p .707 .577 .707 r
F P
0 g
s
.42172 .58493 m .42144 .54785 L .45261 .54951 L p .707 .577 .707 r
F P
0 g
s
.35164 .61351 m .35673 .5963 L .38524 .59904 L p .707 .577 .707 r
F P
0 g
s
.42144 .54785 m .42172 .58493 L .38988 .58592 L p .707 .577 .707 r
F P
0 g
s
.47217 .62938 m .46707 .64658 L .44083 .63364 L p .707 .577 .707 r
F P
0 g
s
.44083 .63364 m .44593 .61643 L .47217 .62938 L p .707 .577 .707 r
F P
0 g
s
.38524 .59904 m .38015 .61625 L .35164 .61351 L p .707 .577 .707 r
F P
0 g
s
.38015 .61625 m .38524 .59904 L .41598 .60598 L p .707 .577 .707 r
F P
0 g
s
.44593 .61643 m .44083 .63364 L .41088 .62319 L p .707 .577 .707 r
F P
0 g
s
.41088 .62319 m .41598 .60598 L .44593 .61643 L p .707 .577 .707 r
F P
0 g
s
.41598 .60598 m .41088 .62319 L .38015 .61625 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008=oo`d008eo
o`00NWoo2@001UYF00<005YFFUH015YF3000PGoo001dOol60002FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001jOol006moo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEP0000<007Ioo`00JWoo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Lgoo001VOol40007FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001aOol0
06Aoo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF008006moo`00HWoo0P000eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<007ooOol0K7oo001POol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUI^Ool0
061oo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo06]oo`00Ggoo0P00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0Jgoo001OOol20006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP04FUI]Ool005ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVeo
o`00GWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFKGoo001NOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP04FUI]Ool005ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEVeoo`00GWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYFKGoo001N
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUI]Ool005ioo`03001JEP0000IJEP03
001JEUYF00MJEP03001ooeYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEVeoo`00GWoo00<005YF00001UYF00<005YFFUH01eYF00<007oo
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0Jgoo001NOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0Jgoo001NOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0Jgoo001NOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001NOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001NOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001NOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00K7oo001NOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001/Ool005ioo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00
GWoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH0
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001/Ool005moo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00K7oo001OOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001/Ool005mo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006aoo`00Ggoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001OOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001/Ool005moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06aoo`00Ggoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00K7oo001OOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001/Ool005moo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06]oo`00Ggoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUI/Ool005moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF
K7oo001OOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVaoo`00Ggoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0JWoo001OOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0JWoo001OOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0JWoo001OOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00Jgoo001OOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00Jgoo001POol2FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001[Ool0061o
o`9JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001[Ool0061oo`9JEP03001JEUYF
00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH2001[Ool0061oo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH2001[Ool0061oo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Uoo`00H7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Uoo`00H7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Uoo`00
H7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00=JEQ@000]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YFFUH000EJEP03001JEUYF00MJEPH0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00008000UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Yoo`00H7oo00@005YFFUH000EJEP03001JEUYF00AJEPD000QJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00009FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001ZOol0061oo`04001JEUYF0005FUH70004FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP002UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00JWoo001POol01000FUIJEP000UYF100000=JEP00FUH025YF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Yoo`00H7oo00<005YF00000`001EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00H7oo0P0000=JEP00FUH01UYF0P0025YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00GWoo0P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00Fgoo0`001EYF0P001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00FGoo0P0000=JEP00FUH0
1EYF0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00Egoo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Yoo`00EWoo0P0015YF0P001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00EGoo00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D0
05YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Yoo`00EGoo
00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001ZOol005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH20007FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP0025YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00JWoo001FOol00`00FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00JWoo001FOol00`00FUH00004FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP02FUHC0002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001ZOol005Ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EPL000IJEP03001JEUYF00EJEP04001JEUYFFUH40007FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001ZOol005Ioo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@0009JEP03001JEUYF009JEPP000IJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JWoo001FOol01000FUIJEP0015YF00<0
05YFFUH01EYF00<005YFFUH015YF10001UYF00<005YFFUH01UYF00@005YFFUIJEPL000AJEP03001J
EP0000MJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001ZOol005Ioo`04001JEUYF
0004FUH00`00FUIJEP05FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020002FUH20008FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF
0P00JWoo001GOol00`00FUH00005FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1XOol005Moo`03001JEP0000EJEP03001JEP0000<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000QJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Qoo`00Egoo00<005YF0000
1EYF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<007ooOol0J7oo001GOol01000FUIJEP000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Uoo`00Egoo00D005YFFUH005YF00800003FUH0
05YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000VOolD000_Ool005Aoo`D00003FUH0000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000POol60004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUH00000;Goo001@Ool40002FUH00`00FUH000020004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0077oo
100000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00BGoo1`00
1UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUHH0006FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P005goo1@00
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00@goo1P00
15YF00<005YFFUH01eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF1@0025YF00<005YF00000P00
25YF00<005YF00000`000UYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8001=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000/Ool003moo`@00003FUH005YF00MJEP03001J
EUYF00MJEP800003FUH005YF00=JEP03001JEUYF00@000AJEP03001JEUYF009JEPH000]JEP03001J
EUYF00=JEPD000=JEP05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2000?Ool40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP00;7oo000kOol40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH200000eYF
001JEP03FUH@0005FUH00`00FUIJEP09FUH01000FUIJEUYF1@000UYF10000eYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0037oo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo
000iOol200000eYF001JEP06FUH20008FUH00`00FUIJEP06FUH200000eYF001JEP060003FUH01000
FUIJEUYF1`0015YF00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P002Woo0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00:goo000gOol20003FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH017ooFUIJEP0025YF0P0000IJEP00000005YF0005FUH00`00FUIJEP06FUH00`00FUIJEP090007
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01000FUIJEUYF0`001eYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0027oo0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000dOol30005FUH20007
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40008FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000MJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Ioo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEP00000[Ool0039oo`800003FUH005YF00EJEP8000MJEP03001JEUYF00IJEP03001JEUYF00MJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000006FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000Eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool0
031oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF009JEP03
001JEUYF00IJEP80009JEP`000AJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP05001JEUYF
FUH00006FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000[Ool002moo`8000AJEP8000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00001JEP001EYF00<005YFFUH0
0UYF1P001eYF00<005YFFUH01EYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00@005YFFUIJEP80
00QJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=oo`03001JEP0000EJEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo00<005YF00001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH010000UYF00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF00AJEP05001JEUYF
FUH00009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool01000FUIJEP00
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH01UYF00@005YFFUIoo`EJEP03001JEUYF00EJEP800005FUH00000FUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH40008FUH01000FUIJEUYF10001UYF00@005YF000000YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=oo`04001JEUYF0004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH00000:Woo000^Ool01000FUIJEP0015YF00<005YFFUH015YF0P001eYF00<005YFFUH0
1UYF00<005YFFUH015YF10000UYF0`0015YF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001J
EP00008000AJEP03001JEUYF00EJEP8000AJEP@000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8000Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000ZOol002moo`03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEP000005FUH300000eYF001JEP06FUH00`00FUIJEP0500000eYF001JEP03FUH300000eYF001J
EP07FUH50003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUHD00000eYF001oo`0YOol002moo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF009JEP8000=JEPd000AJEP03001JEUYF00D00003FUH005YF00IJ
EP<000IJEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0017oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF
1`001UYF00<005YFFUH01EYF00<005YFFUH00UYF1000:Goo000_Ool00`00FUH00005FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70002FUH01@00FUIJEUYF00001EYF0P0000AJEP00
FUIJEQ<000EJEP8000AJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH010001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000
02Uoo`00;goo00<005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000UYF
00<005YFFUH00UYF0`0015YF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00@005YFFUIJEP<000=J
EP03001JEUYF00UJEP800003FUH005YF00AJEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01000FUIJEUYF0P0017oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0002Uoo`00;goo
00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00AJEP@000IJEP03001JEUYF00EJEP05001J
EUYF001JEP0600000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUH000001UYF
00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo009o
o`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP040004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000ZOol002moo`04001JEUYF0004FUH00`00FUIJ
EP05FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P0000=J
EP0000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP8000AJ
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
00=oo`03001JEP0000AJEP03001JEUYF00=JEPD000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP04001JEUYFFUH2000[Ool0031oo`03001JEP0000AJEP03001JEUYF00AJEP@000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00=JEP04001JEUYF0002FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUH00004FUH00`00FUH000030004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH00000;Goo
000`Ool00`00FUH00005FUH00`00FUH0000300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20006FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH30004FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004Ool00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH3000_Ool0031oo`03001JEP0000EJEP8000EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUH000020005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20004Ool01000FUIJEP000UYF00D005YFFUIJEP0000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000bOol0031oo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00UYF0`000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo
00<005YFFUH00`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YF000003Aoo`00<7oo00@005YFFUH0009JEP<000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP@000UJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF008000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPL0009J
EP8000EJEP03001JEUYF00AJEP03001JEUYF00AJEP<000UJEP03001JEUYF00AJEP<003Ioo`00<Goo
00<005YF00000P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF
00QJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009J
EP07001JEUYFFUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF1@0025YF00<005YFFUH0
1000>Goo000aOol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20005FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEP000eYF00<005YFFUH00UYF00<005YFFUH01EYF6`00=goo000aOol00`00FUH00004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUHD0006FUH40003FUH00`00FUIJEP05FUH4000=FUH00`00FUIJ
EP09FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH0
1000FUH000000UYF00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEPD0039oo`00<Goo00@005YF000000=JEP03001JEUYF00AJEPP000EJEP03001JEUYF00@000Qo
o`@0009JEP80009JEP<000MJEP<0009JEP@000UJEP03001JEUYF00UJEP8000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP04001JEUYFFUH90002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000_Ool0035oo`04001J
EP000003FUH00`00FUIJEP040004FUH00`00FUIJEP02FUH7000@Ool40002FUH01000FUH000001EYF
1@001EYF200000=JEP00FUH025YF10002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000aOol01000FUIJEP000eYF400067oo0`00
0UYF00@005YFFUIJEP<0009JEPD000MJEP03001JEUYF00=JEP/0009JEP8000]JEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<002]oo`00<Goo00D005YFFUH005YF00D000=JEP04001JEUYFFUH7000BOol50002FUH01000FUIJ
EP001EYF20001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000YOol0035oo`03001JEP0000800003FUH005YF00AJEP03001JEUYF00IJEP03
001JEUYF018000=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF0`001eYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000=JEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000Y
Ool0035oo`<000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEP@000EJEP03001J
EUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH40002FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUIJEP0300000eYF001JEP0;FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF
0P00:7oo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUH0
00000eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00QJEPL0
00AJEP04001JEUYFFUH50004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20004FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00:7oo000a
Ool20003FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH00UYF10001eYF00D005YF
FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00mJEPP000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP800003FUH005YF00=JEP04001JEUYFFUH3
0008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02000XOol0035oo`03001JEUYF00H0009JEP03001JEUYF009JEPH000MJEP03001JEUYF00EJEP80
00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP0DFUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH2000015YF001J
EUYF1P0000=JEP00FUH05P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:7oo
000`Ool40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP07
FUH30004FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH04eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF0P0000IJ
EP00000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP040009Ool80004FUH00`00FUIJEP03FUH0
0`00FUIJEP02000XOol0031oo`800005Ool00000FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH40008FUH00`00FUIJEP020002FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001EYF0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
15YF10003Goo1`000eYF00<005YFFUH00P00:7oo000_Ool30003Ool30004FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP03FUH30003FUH01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8000EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEP00008000aoo`@00003FUH000000080009JEP8002Qoo`00;goo00@005YF0000
00Eoo`<00003FUH005YF00IJEP04001JEUYFFUH30002FUH00`00FUIJEP02FUH300000eYF001JEP06
FUH20002FUH01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP800003FUH0000000<000=J
EP04001JEUYFFUH70004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30004Ool50005FUH01P00FUIJ
EUYF001JEP8002Qoo`00;goo00D005YF001JEP0000Moo`D000AJEP03001JEUYF00D00003FUH005YF
00IJEP8000QJEP@0009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH30004FUH00`00
FUIJEP050002FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH3000XOol002moo`03001JEUYF009JEP03001oogoo00UooaT000EJEP03001JEUYF
0080009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF00=JEP<00003
FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH30003FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH3000XOol0031oo`03001JEUYF009JEP03001oogoo00moo`D000eo
o`8000=JEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEUYF10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001eYF00@0
05YFFUIJEP800003FUH005YF00EJEP03001JEUYF009JEP<002Qoo`00<7oo00<005YFFUH00UYF0P00
4Goo0`0047oo0`0015YF00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EUYFFUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020005
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP02FUH00`00FUH0000XOol0035oo`04001JEUYF0002
FUH2000TOol00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P000UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP<00003FUH005YF00MJEP03001JEUYF00=JEP03001JEUYF009JEP8002Uoo`00<Goo00@0
05YFFUH000AJEP03001oogoo029oo`80009JEP05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH;0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH200001EYF001JEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1EYF0P0025YF0`000eYF00<005YFFUH00UYF00<007ooOol0:7oo000bOol20006FUH2000TOol00`00
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP07FUH:000;FUH<0005FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH30006FUH01000FUIJEP000UYF00<005YFFUH00P00:goo000cOol00`00FUIJ
EP04FUH01000FUH000008goo0P000eYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEPH0
00QJEP03001JEUYF00YJEP03001JEUYF00UJEPP000IJEP03001JEUYF009JEP80009JEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=J
EP03001JEUYF009JEPD002eoo`00=7oo0P0015YF00@005YFFUIJEP<0029oo`=JEP03001JEUYF00=J
EP03001JEUYF00AJEPL0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00EJEP@0009JEP03001JEUYF009JEP80009JEP03001JEUYF009JEPH00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00EJEP03001oogoo02eo
o`00=Woo00@005YFFUH000MJEP<001moo`=JEP03001JEUYF00=JEP03001JEUYF00@000UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEP00008000AJEP<0
009JEP05001JEUYFFUH00002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH40006FUH2000^Ool003Moo`<000QJEP04001JEP00000MOol3FUH00`00FUIJEP03
FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH20002FUH30002FUH200000eYF001JEP03FUH20005OolK0004Ool0
0`00FUIJEP02FUH00`00FUH0000^Ool003Uoo`8000IJEP03001JEUYF009JEP<001Yoo`=JEP04001J
EUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH;0006FUH00`00Oomoo`0ROol20002FUH01000FUIJEP00;Goo
000kOol20004FUH00`00FUIJEP05FUH4000FOol3FUH01000FUH000001eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@0
05YF000000EJEP8000IJEP<002Aoo`8000AJEP03001oogoo02Yoo`00?Goo0P0000=JEP00FUH01UYF
0`000UYF10004Woo0eYF0P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000EJEP03001J
EP0000AJEP04001JEUYFFUH2000SOol00`00FUIJEP02FUH00`00Oomoo`0ZOol003moo`<000EJEPD0
00EJEPH000aoo`9JEP05001JEUYFFUH00008FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YF
FUH00P000UYF00<005YFFUH00eYF0P008Woo00@005YFFUIJEP8002]oo`00@Woo0`000UYF1@001eYF
00@005YFFUIJEP`00003FUH005YF00=JEP03001JEUYF00EJEP03Ool005YF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0005
FUH00`00FUIJEP02FUH20008FUH2000QOol01@00FUH005YF0000:goo0015Ool70006FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP05FUH00goo001JEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
0006FUH00`00FUIJEP03FUH20007FUH00`00FUH00002000OOol200000eYF001oo`0ZOol004Qoo`<0
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20007FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP03FUH3000MOol2000/Ool004]oo`@0
009JEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH20007FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP07FUH5000GOol3000/Ool0
04moo`L000AJEP03001JEUYF00=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00=J
EP8000QJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEPT000aoo`800003
FUH007oo02aoo`00EWoo30000Woo0P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH<0002FUH2000]Ool006Ioo`800003FUH005YF00MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP0000T000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00@00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool006Qoo`8000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPD000Uoo`P000AJEP03001JEUYF00=JEP03001J
EUYF0080009oo`@000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF008002ioo`00JGoo
0`001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH010001EYF10003Goo1P0015YF00<005YFFUH00P001Woo10000UYF00<005YFFUH01UYF00<005YF
FUH00eYF00D005YFFUIJEP0002moo`00K7oo10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF1@000UYF00<005YFFUH01UYF00<005YF00000P0037oo1`0000AJ
EP00FUIJEP8000Yoo`H000AJEP03001JEUYF00AJEP04001JEP00000`Ool0071oo`P000EJEP03001J
EUYF00UJEP03001JEUYF00YJEP04001JEUYFFUH80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3
0004Ool50005FUH01000FUH000000UYF0P0047oo3@00<Woo001hOolS0002FUH00`00FUIJEP02FUH7
0006FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP04FUH01000FUIJEUYF1000Cgoo002BOol00eYF
001JEP030005FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH01eYF0`000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00Cgoo002AOol01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF10001eYF00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF
009JEP<004moo`00TGoo10000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00P001EYF00<005YFFUH00eYF0P001UYF00<005YFFUH00UYF00<005YF0000Cgoo002AOol0
1000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00D7oo002AOol200001EYF001J
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0025YF0`000eYF00<0
05YFFUH00UYF0P00D7oo002AOol20002FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH30006FUH01000FUIJEP000UYF00@005YFFUIJEP80055oo`00TGoo00<005YFFUH00UYF
0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<0
05YFFUH00UYF0`0000=JEP000000Dgoo002AOol00`00FUIJEP02FUH600000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH2001EOol0099oo`05
001JEUYFFUH00002FUH00`00Oomoo`050004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH40006FUH2001EOol009=oo`03001JEP0000AJEP8000Eoo`T000AJEP03001JEUYF009JEPT0
00Aoo`03001JEUYF009JEP03001JEP0005Eoo`00U7oo0P001UYF00<007ooOol02goo2@003Woo0P00
0UYF00@005YFFUH005Aoo`00UGoo00<005YFFUH015YF0`0097oo0P0015YF00<007ooOol0DGoo002F
Ool00`00FUIJEP02FUH01000FUIJEUYF0P008goo00<005YFFUH00UYF00<007ooOol0DGoo002GOol2
0002FUH00`00FUIJEP03FUH2000ROol01000FUIJEUYF0P00DWoo002IOol20008FUH2000QOol01@00
FUH005YF0000DWoo002JOol00`00FUIJEP06FUH00`00FUH00002000OOol200000eYF001oo`1AOol0
09]oo`8000IJEP03001JEUYF009JEP<001eoo`8005=oo`00WGoo0P000eYF00<005YFFUH01UYF0`00
6Goo0`00Dgoo002OOol200000eYF001JEP08FUH00`00FUH00003000COol200000eYF001oo`1COol0
0:5oo`<000MJEP03001JEUYF00AJEQ<0009JEP8005Aoo`00Y7oo0P001EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0005Eoo`00YWoo0`0000=JEP00FUH025YF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00EGoo002YOol40006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000EWoo002]Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUH00000Egoo002aOolC001IOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]14\[InvisibleSpace]"     "\
\[InvisibleSpace]5.644402753529235`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 14, "     ", 5.6444027535292349, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60389 .74779 m .60696 .69189 L .57518 .68952 L p .707 .577 .707 r
F P
0 g
s
.60696 .69189 m .60389 .74779 L .63504 .7477 L p .707 .577 .707 r
F P
0 g
s
.63504 .7477 m .63811 .6918 L .60696 .69189 L p .707 .577 .707 r
F P
0 g
s
.57211 .74542 m .57518 .68952 L .54587 .68494 L p .707 .577 .707 r
F P
0 g
s
.57518 .68952 m .57211 .74542 L .60389 .74779 L p .707 .577 .707 r
F P
0 g
s
.63811 .6918 m .63504 .7477 L .6625 .74517 L p .707 .577 .707 r
F P
0 g
s
.6625 .74517 m .66557 .68927 L .63811 .6918 L p .707 .577 .707 r
F P
0 g
s
.5428 .74084 m .54587 .68494 L .52191 .67858 L p .707 .577 .707 r
F P
0 g
s
.54587 .68494 m .5428 .74084 L .57211 .74542 L p .707 .577 .707 r
F P
0 g
s
.58685 .81396 m .58474 .77732 L .55399 .77636 L p .707 .577 .707 r
F P
0 g
s
.58474 .77732 m .58685 .81396 L .61874 .81188 L p .707 .577 .707 r
F P
0 g
s
.61874 .81188 m .61663 .77523 L .58474 .77732 L p .707 .577 .707 r
F P
0 g
s
.61663 .77523 m .61874 .81188 L .64864 .80696 L p .707 .577 .707 r
F P
0 g
s
.64864 .80696 m .64653 .77032 L .61663 .77523 L p .707 .577 .707 r
F P
0 g
s
.66557 .68927 m .6625 .74517 L .68359 .74045 L p .707 .577 .707 r
F P
0 g
s
.68359 .74045 m .68666 .68455 L .66557 .68927 L p .707 .577 .707 r
F P
0 g
s
.52191 .67858 m .51884 .73448 L .5428 .74084 L p .707 .577 .707 r
F P
0 g
s
.55609 .81301 m .55399 .77636 L .52737 .77247 L p .707 .577 .707 r
F P
0 g
s
.55399 .77636 m .55609 .81301 L .58685 .81396 L p .707 .577 .707 r
F P
0 g
s
.64653 .77032 m .64864 .80696 L .67362 .79969 L p .707 .577 .707 r
F P
0 g
s
.67362 .79969 m .67152 .76305 L .64653 .77032 L p .707 .577 .707 r
F P
0 g
s
.51884 .73448 m .52191 .67858 L .50563 .67108 L p .707 .577 .707 r
F P
0 g
s
.52737 .77247 m .52948 .80911 L .55609 .81301 L p .707 .577 .707 r
F P
0 g
s
.60097 .86357 m .5974 .84612 L .56658 .84913 L p .707 .577 .707 r
F P
0 g
s
.5974 .84612 m .60097 .86357 L .63216 .85666 L p .707 .577 .707 r
F P
0 g
s
.63216 .85666 m .62859 .83921 L .5974 .84612 L p .707 .577 .707 r
F P
0 g
s
.62859 .83921 m .63216 .85666 L .66065 .84654 L p .707 .577 .707 r
F P
0 g
s
.66065 .84654 m .65708 .82908 L .62859 .83921 L p .707 .577 .707 r
F P
0 g
s
.68666 .68455 m .68359 .74045 L .69624 .734 L p .707 .577 .707 r
F P
0 g
s
.69624 .734 m .69931 .6781 L .68666 .68455 L p .707 .577 .707 r
F P
0 g
s
.52948 .80911 m .52737 .77247 L .50751 .76601 L p .707 .577 .707 r
F P
0 g
s
.50563 .67108 m .50256 .72698 L .51884 .73448 L p .707 .577 .707 r
F P
0 g
s
.56658 .84913 m .57015 .86659 L .60097 .86357 L p .707 .577 .707 r
F P
0 g
s
.57015 .86659 m .56658 .84913 L .53913 .84796 L p .707 .577 .707 r
F P
0 g
s
.67152 .76305 m .67362 .79969 L .69125 .79078 L p .707 .577 .707 r
F P
0 g
s
.69125 .79078 m .68914 .75414 L .67152 .76305 L p .707 .577 .707 r
F P
0 g
s
.65708 .82908 m .66065 .84654 L .68366 .83419 L p .707 .577 .707 r
F P
0 g
s
.68366 .83419 m .6801 .81673 L .65708 .82908 L p .707 .577 .707 r
F P
0 g
s
.53913 .84796 m .5427 .86541 L .57015 .86659 L p .707 .577 .707 r
F P
0 g
s
.50751 .76601 m .50962 .80265 L .52948 .80911 L p .707 .577 .707 r
F P
0 g
s
.50256 .72698 m .50563 .67108 L .49864 .66317 L p .707 .577 .707 r
F P
0 g
s
.5427 .86541 m .53913 .84796 L .51775 .84271 L p .707 .577 .707 r
F P
0 g
s
.50962 .80265 m .50751 .76601 L .49634 .75762 L p .707 .577 .707 r
F P
0 g
s
.6801 .81673 m .68366 .83419 L .69894 .82082 L p .707 .577 .707 r
F P
0 g
s
.69894 .82082 m .69538 .80337 L .6801 .81673 L p .707 .577 .707 r
F P
0 g
s
.51775 .84271 m .52132 .86017 L .5427 .86541 L p .707 .577 .707 r
F P
0 g
s
.49864 .66317 m .49557 .71907 L .50256 .72698 L p .707 .577 .707 r
F P
0 g
s
.69931 .6781 m .69624 .734 L .69921 .72645 L p .707 .577 .707 r
F P
0 g
s
.69921 .72645 m .70228 .67054 L .69931 .6781 L p .707 .577 .707 r
F P
0 g
s
.68914 .75414 m .69125 .79078 L .69979 .7811 L p .707 .577 .707 r
F P
0 g
s
.69979 .7811 m .69768 .74446 L .68914 .75414 L p .707 .577 .707 r
F P
0 g
s
.49634 .75762 m .49845 .79426 L .50962 .80265 L p .707 .577 .707 r
F P
0 g
s
.52132 .86017 m .51775 .84271 L .50453 .83391 L p .707 .577 .707 r
F P
0 g
s
.49557 .71907 m .49864 .66317 L .50161 .65561 L p .707 .577 .707 r
F P
0 g
s
.50453 .83391 m .5081 .85136 L .52132 .86017 L p .707 .577 .707 r
F P
0 g
s
.69538 .80337 m .69894 .82082 L .705 .80775 L p .707 .577 .707 r
F P
0 g
s
.705 .80775 m .70143 .79029 L .69538 .80337 L p .707 .577 .707 r
F P
0 g
s
.49845 .79426 m .49634 .75762 L .49496 .74812 L p .707 .578 .707 r
F P
0 g
s
.50161 .65561 m .49854 .71151 L .49557 .71907 L p .707 .577 .707 r
F P
0 g
s
.49496 .74812 m .49706 .78476 L .49845 .79426 L p .707 .578 .707 r
F P
0 g
s
.49706 .78476 m .49496 .74812 L .5035 .73844 L p .707 .577 .707 r
F P
0 g
s
.5035 .73844 m .5056 .77508 L .49706 .78476 L p .707 .577 .707 r
F P
0 g
s
.49758 .82192 m .49758 .32003 L .45313 .31794 L p .707 .577 .707 r
F P
0 g
s
.49854 .71151 m .50161 .65561 L .51426 .64916 L p .707 .577 .707 r
F P
0 g
s
.51426 .64916 m .51119 .70506 L .49854 .71151 L p .707 .577 .707 r
F P
0 g
s
.5081 .85136 m .50453 .83391 L .50076 .8224 L p .707 .577 .707 r
F P
0 g
s
.50076 .8224 m .50433 .83986 L .5081 .85136 L p .707 .577 .707 r
F P
0 g
s
.50433 .83986 m .50076 .8224 L .50682 .80933 L p .707 .577 .707 r
F P
0 g
s
.51119 .70506 m .51426 .64916 L .53535 .64444 L p .707 .577 .707 r
F P
0 g
s
.50682 .80933 m .51038 .82678 L .50433 .83986 L p .707 .577 .707 r
F P
0 g
s
.5056 .77508 m .5035 .73844 L .52112 .72953 L p .707 .577 .707 r
F P
0 g
s
.53535 .64444 m .53228 .70034 L .51119 .70506 L p .707 .577 .707 r
F P
0 g
s
.52112 .72953 m .52323 .76617 L .5056 .77508 L p .707 .577 .707 r
F P
0 g
s
.51038 .82678 m .50682 .80933 L .5221 .79596 L p .707 .577 .707 r
F P
0 g
s
.5221 .79596 m .52566 .81342 L .51038 .82678 L p .707 .577 .707 r
F P
0 g
s
.52323 .76617 m .52112 .72953 L .54611 .72226 L p .707 .577 .707 r
F P
0 g
s
.54611 .72226 m .54821 .7589 L .52323 .76617 L p .707 .577 .707 r
F P
0 g
s
.52566 .81342 m .5221 .79596 L .54511 .78361 L p .707 .577 .707 r
F P
0 g
s
.54511 .78361 m .54868 .80107 L .52566 .81342 L p .707 .577 .707 r
F P
0 g
s
.49758 .32003 m .49758 .82192 L .54227 .82022 L p .707 .577 .707 r
F P
0 g
s
.53228 .70034 m .53535 .64444 L .56281 .64191 L p .707 .577 .707 r
F P
0 g
s
.56281 .64191 m .55974 .69781 L .53228 .70034 L p .707 .577 .707 r
F P
0 g
s
.54227 .82022 m .54227 .31834 L .49758 .32003 L p .707 .577 .707 r
F P
0 g
s
.69768 .74446 m .69979 .7811 L .6984 .7716 L p .707 .578 .707 r
F P
0 g
s
.6984 .7716 m .6963 .73496 L .69768 .74446 L p .707 .578 .707 r
F P
0 g
s
.70228 .67054 m .69921 .72645 L .69222 .71853 L p .707 .577 .707 r
F P
0 g
s
.69222 .71853 m .69529 .66263 L .70228 .67054 L p .707 .577 .707 r
F P
0 g
s
.55974 .69781 m .56281 .64191 L .59396 .64183 L p .707 .577 .707 r
F P
0 g
s
.59396 .64183 m .59089 .69773 L .55974 .69781 L p .707 .577 .707 r
F P
0 g
s
.54821 .7589 m .54611 .72226 L .57601 .71734 L p .707 .577 .707 r
F P
0 g
s
.57601 .71734 m .57811 .75399 L .54821 .7589 L p .707 .577 .707 r
F P
0 g
s
.54868 .80107 m .54511 .78361 L .5736 .77349 L p .707 .577 .707 r
F P
0 g
s
.5736 .77349 m .57717 .79094 L .54868 .80107 L p .707 .577 .707 r
F P
0 g
s
.57717 .79094 m .5736 .77349 L .60479 .76658 L p .707 .577 .707 r
F P
0 g
s
.60479 .76658 m .60836 .78404 L .57717 .79094 L p .707 .577 .707 r
F P
0 g
s
.54227 .31834 m .54227 .82022 L .58282 .81491 L p .707 .577 .707 r
F P
0 g
s
.57811 .75399 m .57601 .71734 L .6079 .71526 L p .707 .577 .707 r
F P
0 g
s
.6079 .71526 m .61 .7519 L .57811 .75399 L p .707 .577 .707 r
F P
0 g
s
.58282 .81491 m .58282 .31302 L .54227 .31834 L p .707 .577 .707 r
F P
0 g
s
.45313 .81982 m .45313 .31794 L .41327 .31226 L p .707 .577 .707 r
F P
0 g
s
.45313 .31794 m .45313 .81982 L .49758 .82192 L p .707 .577 .707 r
F P
0 g
s
.70143 .79029 m .705 .80775 L .70123 .79625 L p .707 .577 .707 r
F P
0 g
s
.70123 .79625 m .69766 .77879 L .70143 .79029 L p .707 .577 .707 r
F P
0 g
s
.62574 .64419 m .62267 .70009 L .59089 .69773 L p .707 .577 .707 r
F P
0 g
s
.59089 .69773 m .59396 .64183 L .62574 .64419 L p .707 .577 .707 r
F P
0 g
s
.63865 .71621 m .64076 .75286 L .61 .7519 L p .707 .577 .707 r
F P
0 g
s
.61 .7519 m .6079 .71526 L .63865 .71621 L p .707 .577 .707 r
F P
0 g
s
.63561 .76356 m .63918 .78102 L .60836 .78404 L p .707 .577 .707 r
F P
0 g
s
.60836 .78404 m .60479 .76658 L .63561 .76356 L p .707 .577 .707 r
F P
0 g
s
.58282 .31302 m .58282 .81491 L .61526 .80649 L p .707 .577 .707 r
F P
0 g
s
.61526 .80649 m .61526 .3046 L .58282 .31302 L p .707 .577 .707 r
F P
0 g
s
.41327 .81415 m .41327 .31226 L .3819 .30355 L p .707 .577 .707 r
F P
0 g
s
.41327 .31226 m .41327 .81415 L .45313 .81982 L p .707 .577 .707 r
F P
0 g
s
.6963 .73496 m .6984 .7716 L .68723 .76321 L p .707 .577 .707 r
F P
0 g
s
.68723 .76321 m .68513 .72657 L .6963 .73496 L p .707 .577 .707 r
F P
0 g
s
.69529 .66263 m .69222 .71853 L .67594 .71103 L p .707 .577 .707 r
F P
0 g
s
.67594 .71103 m .67901 .65513 L .69529 .66263 L p .707 .577 .707 r
F P
0 g
s
.26404 .71592 m .26541 .66114 L .23359 .65949 L p .707 .577 .707 r
F P
0 g
s
.26541 .66114 m .26404 .71592 L .29522 .71443 L p .707 .577 .707 r
F P
0 g
s
.29522 .71443 m .29659 .65965 L .26541 .66114 L p .707 .577 .707 r
F P
0 g
s
.23222 .71428 m .23359 .65949 L .20425 .65487 L p .707 .577 .707 r
F P
0 g
s
.23359 .65949 m .23222 .71428 L .26404 .71592 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29659 .65965 m .29522 .71443 L .32271 .70995 L p .707 .577 .707 r
F P
0 g
s
.32271 .70995 m .32408 .65516 L .29659 .65965 L p .707 .577 .707 r
F P
0 g
s
.20288 .70965 m .20425 .65487 L .18025 .64772 L p .707 .577 .707 r
F P
0 g
s
.20425 .65487 m .20288 .70965 L .23222 .71428 L p .707 .577 .707 r
F P
0 g
s
.69766 .77879 m .70123 .79625 L .68801 .78744 L p .707 .577 .707 r
F P
0 g
s
.68801 .78744 m .68444 .76998 L .69766 .77879 L p .707 .577 .707 r
F P
0 g
s
.65505 .64877 m .65198 .70468 L .62267 .70009 L p .707 .577 .707 r
F P
0 g
s
.62267 .70009 m .62574 .64419 L .65505 .64877 L p .707 .577 .707 r
F P
0 g
s
.61526 .3046 m .61526 .80649 L .63642 .79579 L p .707 .577 .707 r
F P
0 g
s
.63918 .78102 m .63561 .76356 L .66306 .76474 L p .707 .577 .707 r
F P
0 g
s
.63642 .79579 m .63642 .2939 L .61526 .3046 L p .707 .577 .707 r
F P
0 g
s
.32408 .65516 m .32271 .70995 L .34382 .70291 L p .707 .577 .707 r
F P
0 g
s
.34382 .70291 m .34519 .64813 L .32408 .65516 L p .707 .577 .707 r
F P
0 g
s
.24643 .76781 m .24546 .73036 L .21467 .72917 L p .707 .577 .707 r
F P
0 g
s
.24546 .73036 m .24643 .76781 L .27835 .76671 L p .707 .577 .707 r
F P
0 g
s
.27835 .76671 m .27739 .72927 L .24546 .73036 L p .707 .577 .707 r
F P
0 g
s
.3819 .80544 m .3819 .30355 L .36209 .29267 L p .707 .577 .707 r
F P
0 g
s
.3819 .30355 m .3819 .80544 L .41327 .81415 L p .707 .577 .707 r
F P
0 g
s
.27739 .72927 m .27835 .76671 L .30829 .76343 L p .707 .577 .707 r
F P
0 g
s
.30829 .76343 m .30733 .72599 L .27739 .72927 L p .707 .577 .707 r
F P
0 g
s
.67901 .65513 m .67594 .71103 L .65198 .70468 L p .707 .577 .707 r
F P
0 g
s
.65198 .70468 m .65505 .64877 L .67901 .65513 L p .707 .577 .707 r
F P
0 g
s
.68513 .72657 m .68723 .76321 L .66737 .75675 L p .707 .577 .707 r
F P
0 g
s
.66737 .75675 m .66526 .72011 L .68513 .72657 L p .707 .577 .707 r
F P
0 g
s
.21563 .76661 m .21467 .72917 L .18803 .72579 L p .707 .577 .707 r
F P
0 g
s
.21467 .72917 m .21563 .76661 L .24643 .76781 L p .707 .577 .707 r
F P
0 g
s
.18025 .64772 m .17888 .7025 L .20288 .70965 L p .707 .577 .707 r
F P
0 g
s
.25701 .80232 m .25537 .78334 L .22411 .78514 L p .707 .577 .707 r
F P
0 g
s
.25537 .78334 m .25701 .80232 L .28863 .79909 L p .707 .577 .707 r
F P
0 g
s
.28863 .79909 m .28698 .78012 L .25537 .78334 L p .707 .577 .707 r
F P
0 g
s
.17888 .7025 m .18025 .64772 L .16395 .63875 L p .707 .577 .707 r
F P
0 g
s
.30733 .72599 m .30829 .76343 L .3333 .75829 L p .707 .577 .707 r
F P
0 g
s
.3333 .75829 m .33234 .72085 L .30733 .72599 L p .707 .577 .707 r
F P
0 g
s
.22411 .78514 m .22576 .80412 L .25701 .80232 L p .707 .577 .707 r
F P
0 g
s
.28698 .78012 m .28863 .79909 L .31751 .79475 L p .707 .577 .707 r
F P
0 g
s
.31751 .79475 m .31587 .77578 L .28698 .78012 L p .707 .577 .707 r
F P
0 g
s
.22576 .80412 m .22411 .78514 L .19628 .78534 L p .707 .577 .707 r
F P
0 g
s
.18803 .72579 m .18899 .76324 L .21563 .76661 L p .707 .577 .707 r
F P
0 g
s
.19628 .78534 m .19792 .80431 L .22576 .80412 L p .707 .577 .707 r
F P
0 g
s
.34519 .64813 m .34382 .70291 L .35647 .69401 L p .707 .577 .707 r
F P
0 g
s
.35647 .69401 m .35784 .63922 L .34519 .64813 L p .707 .577 .707 r
F P
0 g
s
.68444 .76998 m .68801 .78744 L .66663 .78219 L p .707 .577 .707 r
F P
0 g
s
.66663 .78219 m .66306 .76474 L .68444 .76998 L p .707 .577 .707 r
F P
0 g
s
.18899 .76324 m .18803 .72579 L .16814 .72058 L p .707 .577 .707 r
F P
0 g
s
.31587 .77578 m .31751 .79475 L .34084 .78973 L p .707 .577 .707 r
F P
0 g
s
.34084 .78973 m .33919 .77075 L .31587 .77578 L p .707 .577 .707 r
F P
0 g
s
.66526 .72011 m .66737 .75675 L .64076 .75286 L p .707 .577 .707 r
F P
0 g
s
.64076 .75286 m .63865 .71621 L .66526 .72011 L p .707 .577 .707 r
F P
0 g
s
.16395 .63875 m .16258 .69353 L .17888 .7025 L p .707 .577 .707 r
F P
0 g
s
.33234 .72085 m .3333 .75829 L .35094 .75179 L p .707 .577 .707 r
F P
0 g
s
.35094 .75179 m .34998 .71435 L .33234 .72085 L p .707 .577 .707 r
F P
0 g
s
.19792 .80431 m .19628 .78534 L .17459 .78391 L p .707 .577 .707 r
F P
0 g
s
.17459 .78391 m .17623 .80289 L .19792 .80431 L p .707 .577 .707 r
F P
0 g
s
.16814 .72058 m .1691 .75802 L .18899 .76324 L p .707 .577 .707 r
F P
0 g
s
.66306 .76474 m .66663 .78219 L .63918 .78102 L p .707 .577 .707 r
F P
0 g
s
.63642 .2939 m .63642 .79579 L .64422 .78387 L p .707 .577 .707 r
F P
0 g
s
.64422 .78387 m .64422 .28198 L .63642 .2939 L p .707 .577 .707 r
F P
0 g
s
.16258 .69353 m .16395 .63875 L .15694 .62882 L p .707 .577 .707 r
F P
0 g
s
.35944 .68411 m .36081 .62933 L .35784 .63922 L p .707 .577 .707 r
F P
0 g
s
.35467 .76553 m .35632 .78451 L .36244 .77961 L p .707 .577 .707 r
F P
0 g
s
.36244 .77961 m .36079 .76063 L .35467 .76553 L p .707 .577 .707 r
F P
0 g
s
.35784 .63922 m .35647 .69401 L .35944 .68411 L p .707 .577 .707 r
F P
0 g
s
.36081 .62933 m .35944 .68411 L .35243 .67419 L p .707 .577 .707 r
F P
0 g
s
.35243 .67419 m .3538 .61941 L .36081 .62933 L p .707 .577 .707 r
F P
0 g
s
.36079 .76063 m .36244 .77961 L .3586 .7755 L p .707 .577 .707 r
F P
0 g
s
.36209 .79456 m .36209 .29267 L .35577 .28068 L p .707 .577 .707 r
F P
0 g
s
.36209 .29267 m .36209 .79456 L .3819 .80544 L p .707 .577 .707 r
F P
0 g
s
.33919 .77075 m .34084 .78973 L .35632 .78451 L p .707 .577 .707 r
F P
0 g
s
.35632 .78451 m .35467 .76553 L .33919 .77075 L p .707 .577 .707 r
F P
0 g
s
.1691 .75802 m .16814 .72058 L .15695 .71403 L p .707 .577 .707 r
F P
0 g
s
.15694 .62882 m .15557 .68361 L .16258 .69353 L p .707 .577 .707 r
F P
0 g
s
.17623 .80289 m .17459 .78391 L .16117 .78101 L p .707 .577 .707 r
F P
0 g
s
.34998 .71435 m .35094 .75179 L .35949 .74457 L p .707 .577 .707 r
F P
0 g
s
.35949 .74457 m .35853 .70712 L .34998 .71435 L p .707 .577 .707 r
F P
0 g
s
.16117 .78101 m .16281 .79998 L .17623 .80289 L p .707 .577 .707 r
F P
0 g
s
.15695 .71403 m .15791 .75147 L .1691 .75802 L p .707 .577 .707 r
F P
0 g
s
.15557 .68361 m .15694 .62882 L .15991 .61893 L p .707 .577 .707 r
F P
0 g
s
.64422 .28198 m .64422 .78387 L .63791 .77188 L p .707 .577 .707 r
F P
0 g
s
.63791 .77188 m .63791 .26999 L .64422 .28198 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15791 .75147 m .15695 .71403 L .15556 .70679 L p .707 .577 .707 r
F P
0 g
s
.35853 .70712 m .35949 .74457 L .3581 .73733 L p .707 .577 .707 r
F P
0 g
s
.3581 .73733 m .35714 .69988 L .35853 .70712 L p .707 .577 .707 r
F P
0 g
s
.3586 .7755 m .35695 .75653 L .36079 .76063 L p .707 .577 .707 r
F P
0 g
s
.35714 .69988 m .3581 .73733 L .34691 .73078 L p .707 .577 .707 r
F P
0 g
s
.34691 .73078 m .34595 .69333 L .35714 .69988 L p .707 .577 .707 r
F P
0 g
s
.35695 .75653 m .3586 .7755 L .34518 .77259 L p .707 .577 .707 r
F P
0 g
s
.34518 .77259 m .34353 .75362 L .35695 .75653 L p .707 .577 .707 r
F P
0 g
s
.35577 .28068 m .35577 .78257 L .36209 .79456 L p .707 .577 .707 r
F P
0 g
s
.35577 .78257 m .35577 .28068 L .36358 .26875 L p .707 .577 .707 r
F P
0 g
s
.16281 .79998 m .16117 .78101 L .15733 .7769 L p .707 .577 .707 r
F P
0 g
s
.15991 .61893 m .15854 .67371 L .15557 .68361 L p .707 .577 .707 r
F P
0 g
s
.15733 .7769 m .15897 .79587 L .16281 .79998 L p .707 .577 .707 r
F P
0 g
s
.15556 .70679 m .15652 .74423 L .15791 .75147 L p .707 .577 .707 r
F P
0 g
s
.15854 .67371 m .15991 .61893 L .17256 .61002 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.3538 .61941 m .35243 .67419 L .33613 .66521 L p .707 .577 .707 r
F P
0 g
s
.33613 .66521 m .3375 .61043 L .3538 .61941 L p .707 .577 .707 r
F P
0 g
s
.15652 .74423 m .15556 .70679 L .1641 .69956 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17256 .61002 m .17119 .66481 L .15854 .67371 L p .707 .577 .707 r
F P
0 g
s
.15897 .79587 m .15733 .7769 L .16345 .772 L p .707 .577 .707 r
F P
0 g
s
.16345 .772 m .16509 .79097 L .15897 .79587 L p .707 .577 .707 r
F P
0 g
s
.1641 .69956 m .16506 .737 L .15652 .74423 L p .707 .577 .707 r
F P
0 g
s
.63791 .26999 m .63791 .77188 L .6181 .761 L p .707 .577 .707 r
F P
0 g
s
.6181 .761 m .6181 .25911 L .63791 .26999 L p .707 .577 .707 r
F P
0 g
s
.17119 .66481 m .17256 .61002 L .19367 .60299 L p .707 .577 .707 r
F P
0 g
s
.36358 .77064 m .36358 .26875 L .38474 .25806 L p .707 .577 .707 r
F P
0 g
s
.36358 .26875 m .36358 .77064 L .35577 .78257 L p .707 .577 .707 r
F P
0 g
s
.3375 .61043 m .33613 .66521 L .31213 .65806 L p .707 .577 .707 r
F P
0 g
s
.31213 .65806 m .3135 .60328 L .3375 .61043 L p .707 .577 .707 r
F P
0 g
s
.16506 .737 m .1641 .69956 L .18175 .69306 L p .707 .577 .707 r
F P
0 g
s
.19367 .60299 m .1923 .65777 L .17119 .66481 L p .707 .577 .707 r
F P
0 g
s
.16509 .79097 m .16345 .772 L .17893 .76678 L p .707 .577 .707 r
F P
0 g
s
.34595 .69333 m .34691 .73078 L .32702 .72556 L p .707 .577 .707 r
F P
0 g
s
.32702 .72556 m .32606 .68812 L .34595 .69333 L p .707 .577 .707 r
F P
0 g
s
.1923 .65777 m .19367 .60299 L .22115 .5985 L p .707 .577 .707 r
F P
0 g
s
.17893 .76678 m .18057 .78575 L .16509 .79097 L p .707 .577 .707 r
F P
0 g
s
.18175 .69306 m .18271 .7305 L .16506 .737 L p .707 .577 .707 r
F P
0 g
s
.3135 .60328 m .31213 .65806 L .28278 .65344 L p .707 .577 .707 r
F P
0 g
s
.28278 .65344 m .28415 .59866 L .3135 .60328 L p .707 .577 .707 r
F P
0 g
s
.6181 .25911 m .6181 .761 L .58673 .75229 L p .707 .577 .707 r
F P
0 g
s
.58673 .75229 m .58673 .2504 L .6181 .25911 L p .707 .577 .707 r
F P
0 g
s
.21978 .65328 m .22115 .5985 L .25233 .59701 L p .707 .577 .707 r
F P
0 g
s
.22115 .5985 m .21978 .65328 L .1923 .65777 L p .707 .577 .707 r
F P
0 g
s
.38474 .25806 m .38474 .75995 L .36358 .77064 L p .707 .577 .707 r
F P
0 g
s
.38474 .75995 m .38474 .25806 L .41718 .24964 L p .707 .577 .707 r
F P
0 g
s
.34353 .75362 m .34518 .77259 L .32349 .77117 L p .707 .577 .707 r
F P
0 g
s
.32349 .77117 m .32184 .75219 L .34353 .75362 L p .707 .577 .707 r
F P
0 g
s
.18271 .7305 m .18175 .69306 L .20676 .68792 L p .707 .577 .707 r
F P
0 g
s
.74904 .65408 m .74767 .59785 L .71585 .59793 L p .707 .577 .707 r
F P
0 g
s
.74767 .59785 m .74904 .65408 L .78021 .6518 L p .707 .577 .707 r
F P
0 g
s
.78021 .6518 m .77884 .59557 L .74767 .59785 L p .707 .577 .707 r
F P
0 g
s
.28415 .59866 m .28278 .65344 L .25096 .65179 L p .707 .577 .707 r
F P
0 g
s
.25096 .65179 m .25233 .59701 L .28415 .59866 L p .707 .577 .707 r
F P
0 g
s
.25233 .59701 m .25096 .65179 L .21978 .65328 L p .707 .577 .707 r
F P
0 g
s
.71722 .65416 m .71585 .59793 L .6865 .59578 L p .707 .577 .707 r
F P
0 g
s
.71585 .59793 m .71722 .65416 L .74904 .65408 L p .707 .577 .707 r
F P
0 g
s
.32606 .68812 m .32702 .72556 L .30037 .72219 L p .707 .577 .707 r
F P
0 g
s
.30037 .72219 m .29941 .68474 L .32606 .68812 L p .707 .577 .707 r
F P
0 g
s
.77884 .59557 m .78021 .6518 L .8077 .64752 L p .707 .577 .707 r
F P
0 g
s
.8077 .64752 m .80633 .59129 L .77884 .59557 L p .707 .577 .707 r
F P
0 g
s
.18057 .78575 m .17893 .76678 L .20225 .76175 L p .707 .577 .707 r
F P
0 g
s
.20676 .68792 m .20772 .72536 L .18271 .7305 L p .707 .577 .707 r
F P
0 g
s
.20225 .76175 m .2039 .78073 L .18057 .78575 L p .707 .577 .707 r
F P
0 g
s
.68787 .65201 m .6865 .59578 L .6625 .59163 L p .707 .577 .707 r
F P
0 g
s
.6865 .59578 m .68787 .65201 L .71722 .65416 L p .707 .577 .707 r
F P
0 g
s
.20772 .72536 m .20676 .68792 L .23669 .68464 L p .707 .577 .707 r
F P
0 g
s
.73042 .72274 m .73138 .68616 L .70058 .68279 L p .707 .577 .707 r
F P
0 g
s
.73138 .68616 m .73042 .72274 L .76234 .72307 L p .707 .577 .707 r
F P
0 g
s
.76234 .72307 m .7633 .68649 L .73138 .68616 L p .707 .577 .707 r
F P
0 g
s
.29941 .68474 m .30037 .72219 L .26958 .72099 L p .707 .577 .707 r
F P
0 g
s
.26958 .72099 m .26862 .68355 L .29941 .68474 L p .707 .577 .707 r
F P
0 g
s
.80633 .59129 m .8077 .64752 L .82881 .64168 L p .707 .577 .707 r
F P
0 g
s
.82881 .64168 m .82744 .58545 L .80633 .59129 L p .707 .577 .707 r
F P
0 g
s
.32184 .75219 m .32349 .77117 L .29566 .77136 L p .707 .577 .707 r
F P
0 g
s
.29566 .77136 m .29401 .75239 L .32184 .75219 L p .707 .577 .707 r
F P
0 g
s
.7633 .68649 m .76234 .72307 L .79228 .72033 L p .707 .577 .707 r
F P
0 g
s
.79228 .72033 m .79324 .68375 L .7633 .68649 L p .707 .577 .707 r
F P
0 g
s
.58673 .2504 m .58673 .75229 L .54686 .74661 L p .707 .577 .707 r
F P
0 g
s
.54686 .74661 m .54686 .24472 L .58673 .2504 L p .707 .577 .707 r
F P
0 g
s
.41718 .75153 m .41718 .24964 L .45773 .24432 L p .707 .577 .707 r
F P
0 g
s
.41718 .24964 m .41718 .75153 L .38474 .75995 L p .707 .577 .707 r
F P
0 g
s
.23669 .68464 m .23765 .72208 L .20772 .72536 L p .707 .577 .707 r
F P
0 g
s
.2039 .78073 m .20225 .76175 L .23114 .75742 L p .707 .577 .707 r
F P
0 g
s
.6625 .59163 m .66387 .64786 L .68787 .65201 L p .707 .577 .707 r
F P
0 g
s
.69962 .71937 m .70058 .68279 L .67394 .67672 L p .707 .577 .707 r
F P
0 g
s
.70058 .68279 m .69962 .71937 L .73042 .72274 L p .707 .577 .707 r
F P
0 g
s
.23765 .72208 m .23669 .68464 L .26862 .68355 L p .707 .577 .707 r
F P
0 g
s
.26862 .68355 m .26958 .72099 L .23765 .72208 L p .707 .577 .707 r
F P
0 g
s
.23114 .75742 m .23278 .77639 L .2039 .78073 L p .707 .577 .707 r
F P
0 g
s
.79324 .68375 m .79228 .72033 L .81729 .71479 L p .707 .577 .707 r
F P
0 g
s
.81729 .71479 m .81825 .67821 L .79324 .68375 L p .707 .577 .707 r
F P
0 g
s
.66387 .64786 m .6625 .59163 L .6462 .58588 L p .707 .577 .707 r
F P
0 g
s
.29401 .75239 m .29566 .77136 L .2644 .77316 L p .707 .577 .707 r
F P
0 g
s
.2644 .77316 m .26275 .75419 L .29401 .75239 L p .707 .577 .707 r
F P
0 g
s
.67394 .67672 m .67298 .7133 L .69962 .71937 L p .707 .577 .707 r
F P
0 g
s
.23278 .77639 m .23114 .75742 L .26275 .75419 L p .707 .577 .707 r
F P
0 g
s
.26275 .75419 m .2644 .77316 L .23278 .77639 L p .707 .577 .707 r
F P
0 g
s
.54686 .24472 m .54686 .74661 L .50241 .74452 L p .707 .577 .707 r
F P
0 g
s
.50241 .74452 m .50241 .24263 L .54686 .24472 L p .707 .577 .707 r
F P
0 g
s
.7356 .77162 m .73724 .754 L .70599 .74912 L p .707 .577 .707 r
F P
0 g
s
.73724 .754 m .7356 .77162 L .76722 .77261 L p .707 .577 .707 r
F P
0 g
s
.76722 .77261 m .76886 .75498 L .73724 .754 L p .707 .577 .707 r
F P
0 g
s
.67298 .7133 m .67394 .67672 L .65405 .66853 L p .707 .577 .707 r
F P
0 g
s
.82744 .58545 m .82881 .64168 L .84146 .63484 L p .707 .577 .707 r
F P
0 g
s
.84146 .63484 m .84009 .57861 L .82744 .58545 L p .707 .577 .707 r
F P
0 g
s
.45773 .74621 m .45773 .24432 L .50241 .24263 L p .707 .577 .707 r
F P
0 g
s
.45773 .24432 m .45773 .74621 L .41718 .75153 L p .707 .577 .707 r
F P
0 g
s
.6462 .58588 m .64757 .64211 L .66387 .64786 L p .707 .577 .707 r
F P
0 g
s
.70434 .76674 m .70599 .74912 L .67815 .74082 L p .707 .577 .707 r
F P
0 g
s
.70599 .74912 m .70434 .76674 L .7356 .77162 L p .707 .577 .707 r
F P
0 g
s
.76886 .75498 m .76722 .77261 L .7961 .76961 L p .707 .577 .707 r
F P
0 g
s
.7961 .76961 m .79775 .75198 L .76886 .75498 L p .707 .577 .707 r
F P
0 g
s
.50241 .24263 m .50241 .74452 L .45773 .74621 L p .707 .577 .707 r
F P
0 g
s
.81825 .67821 m .81729 .71479 L .83493 .70699 L p .707 .577 .707 r
F P
0 g
s
.83493 .70699 m .83589 .67041 L .81825 .67821 L p .707 .577 .707 r
F P
0 g
s
.65405 .66853 m .65309 .70511 L .67298 .7133 L p .707 .577 .707 r
F P
0 g
s
.67815 .74082 m .67651 .75845 L .70434 .76674 L p .707 .577 .707 r
F P
0 g
s
.64757 .64211 m .6462 .58588 L .63919 .57908 L p .707 .577 .707 r
F P
0 g
s
.67651 .75845 m .67815 .74082 L .65646 .72993 L p .707 .577 .707 r
F P
0 g
s
.79775 .75198 m .7961 .76961 L .81942 .76291 L p .707 .577 .707 r
F P
0 g
s
.81942 .76291 m .82107 .74528 L .79775 .75198 L p .707 .577 .707 r
F P
0 g
s
.65309 .70511 m .65405 .66853 L .64286 .65903 L p .707 .577 .707 r
F P
0 g
s
.65646 .72993 m .65482 .74755 L .67651 .75845 L p .707 .577 .707 r
F P
0 g
s
.84009 .57861 m .84146 .63484 L .84443 .62767 L p .707 .577 .707 r
F P
0 g
s
.84443 .62767 m .84306 .57144 L .84009 .57861 L p .707 .577 .707 r
F P
0 g
s
.63919 .57908 m .64056 .63531 L .64757 .64211 L p .707 .577 .707 r
F P
0 g
s
.83589 .67041 m .83493 .70699 L .84348 .69769 L p .707 .577 .707 r
F P
0 g
s
.84348 .69769 m .84444 .66111 L .83589 .67041 L p .707 .577 .707 r
F P
0 g
s
.64286 .65903 m .6419 .69561 L .65309 .70511 L p .707 .577 .707 r
F P
0 g
s
.65482 .74755 m .65646 .72993 L .64304 .71749 L p .707 .577 .707 r
F P
0 g
s
.82107 .74528 m .81942 .76291 L .8349 .75317 L p .707 .577 .707 r
F P
0 g
s
.8349 .75317 m .83655 .73554 L .82107 .74528 L p .707 .577 .707 r
F P
0 g
s
.64304 .71749 m .6414 .73512 L .65482 .74755 L p .707 .577 .707 r
F P
0 g
s
.64056 .63531 m .63919 .57908 L .64216 .57191 L p .707 .577 .707 r
F P
0 g
s
.6419 .69561 m .64286 .65903 L .64147 .64915 L p .707 .577 .707 r
F P
0 g
s
.84306 .57144 m .84443 .62767 L .83742 .62088 L p .707 .577 .707 r
F P
0 g
s
.83742 .62088 m .83605 .56465 L .84306 .57144 L p .707 .577 .707 r
F P
0 g
s
.64216 .57191 m .64353 .62814 L .64056 .63531 L p .707 .577 .707 r
F P
0 g
s
.84444 .66111 m .84348 .69769 L .84209 .68781 L p .707 .577 .707 r
F P
0 g
s
.84209 .68781 m .84305 .65123 L .84444 .66111 L p .707 .577 .707 r
F P
0 g
s
.64147 .64915 m .64051 .68573 L .6419 .69561 L p .707 .577 .707 r
F P
0 g
s
.6414 .73512 m .64304 .71749 L .63921 .70474 L p .707 .577 .707 r
F P
0 g
s
.83655 .73554 m .8349 .75317 L .84102 .74135 L p .707 .577 .707 r
F P
0 g
s
.84102 .74135 m .84267 .72372 L .83655 .73554 L p .707 .577 .707 r
F P
0 g
s
.63921 .70474 m .63756 .72236 L .6414 .73512 L p .707 .577 .707 r
F P
0 g
s
.64353 .62814 m .64216 .57191 L .65481 .56507 L p .707 .577 .707 r
F P
0 g
s
.64051 .68573 m .64147 .64915 L .65002 .63985 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83605 .56465 m .83742 .62088 L .82112 .61512 L p .707 .577 .707 r
F P
0 g
s
.82112 .61512 m .81975 .5589 L .83605 .56465 L p .707 .577 .707 r
F P
0 g
s
.65481 .56507 m .65618 .6213 L .64353 .62814 L p .707 .577 .707 r
F P
0 g
s
.40911 .62225 m .40604 .56718 L .37426 .56792 L p .707 .577 .707 r
F P
0 g
s
.40604 .56718 m .40911 .62225 L .44026 .6186 L p .707 .577 .707 r
F P
0 g
s
.44026 .6186 m .43719 .56353 L .40604 .56718 L p .707 .577 .707 r
F P
0 g
s
.84305 .65123 m .84209 .68781 L .8309 .67831 L p .707 .577 .707 r
F P
0 g
s
.8309 .67831 m .83186 .64173 L .84305 .65123 L p .707 .577 .707 r
F P
0 g
s
.63756 .72236 m .63921 .70474 L .64533 .69291 L p .707 .577 .707 r
F P
0 g
s
.84267 .72372 m .84102 .74135 L .83719 .72859 L p .707 .577 .707 r
F P
0 g
s
.83719 .72859 m .83883 .71097 L .84267 .72372 L p .707 .577 .707 r
F P
0 g
s
.65002 .63985 m .64906 .67643 L .64051 .68573 L p .707 .577 .707 r
F P
0 g
s
.37733 .62299 m .37426 .56792 L .34495 .56569 L p .707 .577 .707 r
F P
0 g
s
.37426 .56792 m .37733 .62299 L .40911 .62225 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.43719 .56353 m .44026 .6186 L .46772 .6124 L p .707 .577 .707 r
F P
0 g
s
.46772 .6124 m .46465 .55734 L .43719 .56353 L p .707 .577 .707 r
F P
0 g
s
.64533 .69291 m .64368 .71054 L .63756 .72236 L p .707 .577 .707 r
F P
0 g
s
.65618 .6213 m .65481 .56507 L .67592 .55923 L p .707 .577 .707 r
F P
0 g
s
.34802 .62075 m .34495 .56569 L .32098 .5607 L p .707 .577 .707 r
F P
0 g
s
.34495 .56569 m .34802 .62075 L .37733 .62299 L p .707 .577 .707 r
F P
0 g
s
.64906 .67643 m .65002 .63985 L .66766 .63205 L p .707 .577 .707 r
F P
0 g
s
.46465 .55734 m .46772 .6124 L .48881 .60427 L p .707 .577 .707 r
F P
0 g
s
.48881 .60427 m .48573 .5492 L .46465 .55734 L p .707 .577 .707 r
F P
0 g
s
.38999 .67655 m .3921 .63924 L .36134 .63557 L p .707 .577 .707 r
F P
0 g
s
.3921 .63924 m .38999 .67655 L .42188 .67792 L p .707 .577 .707 r
F P
0 g
s
.42188 .67792 m .42399 .64061 L .3921 .63924 L p .707 .577 .707 r
F P
0 g
s
.42399 .64061 m .42188 .67792 L .45178 .67687 L p .707 .577 .707 r
F P
0 g
s
.45178 .67687 m .45389 .63955 L .42399 .64061 L p .707 .577 .707 r
F P
0 g
s
.81975 .5589 m .82112 .61512 L .79712 .61097 L p .707 .577 .707 r
F P
0 g
s
.79712 .61097 m .79575 .55474 L .81975 .5589 L p .707 .577 .707 r
F P
0 g
s
.67592 .55923 m .67729 .61546 L .65618 .6213 L p .707 .577 .707 r
F P
0 g
s
.83186 .64173 m .8309 .67831 L .81101 .67012 L p .707 .577 .707 r
F P
0 g
s
.81101 .67012 m .81197 .63354 L .83186 .64173 L p .707 .577 .707 r
F P
0 g
s
.35924 .67289 m .36134 .63557 L .33473 .62998 L p .707 .577 .707 r
F P
0 g
s
.36134 .63557 m .35924 .67289 L .38999 .67655 L p .707 .577 .707 r
F P
0 g
s
.64368 .71054 m .64533 .69291 L .66081 .68317 L p .707 .577 .707 r
F P
0 g
s
.83883 .71097 m .83719 .72859 L .82377 .71616 L p .707 .577 .707 r
F P
0 g
s
.82377 .71616 m .82541 .69853 L .83883 .71097 L p .707 .577 .707 r
F P
0 g
s
.66766 .63205 m .6667 .66863 L .64906 .67643 L p .707 .577 .707 r
F P
0 g
s
.32098 .5607 m .32405 .61576 L .34802 .62075 L p .707 .577 .707 r
F P
0 g
s
.39164 .71014 m .39521 .69145 L .36438 .68478 L p .707 .577 .707 r
F P
0 g
s
.39521 .69145 m .39164 .71014 L .42282 .71538 L p .707 .577 .707 r
F P
0 g
s
.42282 .71538 m .42639 .6967 L .39521 .69145 L p .707 .577 .707 r
F P
0 g
s
.45389 .63955 m .45178 .67687 L .47677 .67349 L p .707 .577 .707 r
F P
0 g
s
.47677 .67349 m .47888 .63618 L .45389 .63955 L p .707 .577 .707 r
F P
0 g
s
.32405 .61576 m .32098 .5607 L .30471 .55343 L p .707 .577 .707 r
F P
0 g
s
.36438 .68478 m .36082 .70346 L .39164 .71014 L p .707 .577 .707 r
F P
0 g
s
.66081 .68317 m .65916 .7008 L .64368 .71054 L p .707 .577 .707 r
F P
0 g
s
.67729 .61546 m .67592 .55923 L .70341 .55496 L p .707 .577 .707 r
F P
0 g
s
.33473 .62998 m .33263 .66729 L .35924 .67289 L p .707 .577 .707 r
F P
0 g
s
.42639 .6967 m .42282 .71538 L .45132 .71869 L p .707 .577 .707 r
F P
0 g
s
.45132 .71869 m .45489 .70001 L .42639 .6967 L p .707 .577 .707 r
F P
0 g
s
.36082 .70346 m .36438 .68478 L .33694 .67733 L p .707 .577 .707 r
F P
0 g
s
.33694 .67733 m .33337 .69602 L .36082 .70346 L p .707 .577 .707 r
F P
0 g
s
.48573 .5492 m .48881 .60427 L .50146 .59498 L p .707 .577 .707 r
F P
0 g
s
.50146 .59498 m .49838 .53992 L .48573 .5492 L p .707 .577 .707 r
F P
0 g
s
.6667 .66863 m .66766 .63205 L .69267 .62651 L p .707 .577 .707 r
F P
0 g
s
.79575 .55474 m .79712 .61097 L .76777 .60883 L p .707 .577 .707 r
F P
0 g
s
.76777 .60883 m .7664 .5526 L .79575 .55474 L p .707 .577 .707 r
F P
0 g
s
.33263 .66729 m .33473 .62998 L .31487 .623 L p .707 .577 .707 r
F P
0 g
s
.70341 .55496 m .70478 .61119 L .67729 .61546 L p .707 .577 .707 r
F P
0 g
s
.81197 .63354 m .81101 .67012 L .78437 .66405 L p .707 .577 .707 r
F P
0 g
s
.78437 .66405 m .78533 .62747 L .81197 .63354 L p .707 .577 .707 r
F P
0 g
s
.30471 .55343 m .30778 .6085 L .32405 .61576 L p .707 .577 .707 r
F P
0 g
s
.45489 .70001 m .45132 .71869 L .47433 .71973 L p .707 .577 .707 r
F P
0 g
s
.47433 .71973 m .4779 .70105 L .45489 .70001 L p .707 .577 .707 r
F P
0 g
s
.70478 .61119 m .70341 .55496 L .73458 .55267 L p .707 .577 .707 r
F P
0 g
s
.33337 .69602 m .33694 .67733 L .31556 .66984 L p .707 .577 .707 r
F P
0 g
s
.47888 .63618 m .47677 .67349 L .49439 .66812 L p .707 .577 .707 r
F P
0 g
s
.49439 .66812 m .4965 .63081 L .47888 .63618 L p .707 .577 .707 r
F P
0 g
s
.31487 .623 m .31276 .66031 L .33263 .66729 L p .707 .577 .707 r
F P
0 g
s
.69267 .62651 m .69171 .66309 L .6667 .66863 L p .707 .577 .707 r
F P
0 g
s
.65916 .7008 m .66081 .68317 L .68413 .67648 L p .707 .577 .707 r
F P
0 g
s
.82541 .69853 m .82377 .71616 L .80208 .70526 L p .707 .577 .707 r
F P
0 g
s
.80208 .70526 m .80372 .68763 L .82541 .69853 L p .707 .577 .707 r
F P
0 g
s
.31556 .66984 m .31199 .68852 L .33337 .69602 L p .707 .577 .707 r
F P
0 g
s
.7664 .5526 m .76777 .60883 L .73595 .6089 L p .707 .577 .707 r
F P
0 g
s
.73595 .6089 m .73458 .55267 L .7664 .5526 L p .707 .577 .707 r
F P
0 g
s
.73458 .55267 m .73595 .6089 L .70478 .61119 L p .707 .577 .707 r
F P
0 g
s
.30778 .6085 m .30471 .55343 L .29771 .54461 L p .707 .577 .707 r
F P
0 g
s
.69171 .66309 m .69267 .62651 L .72261 .62377 L p .707 .577 .707 r
F P
0 g
s
.68413 .67648 m .68248 .6941 L .65916 .7008 L p .707 .577 .707 r
F P
0 g
s
.78533 .62747 m .78437 .66405 L .75357 .66068 L p .707 .577 .707 r
F P
0 g
s
.75357 .66068 m .75453 .6241 L .78533 .62747 L p .707 .577 .707 r
F P
0 g
s
.31276 .66031 m .31487 .623 L .3037 .61531 L p .707 .577 .707 r
F P
0 g
s
.49838 .53992 m .50146 .59498 L .50443 .58547 L p .707 .577 .707 r
F P
0 g
s
.50443 .58547 m .50136 .5304 L .49838 .53992 L p .707 .577 .707 r
F P
0 g
s
.72165 .66035 m .72261 .62377 L .75453 .6241 L p .707 .577 .707 r
F P
0 g
s
.72261 .62377 m .72165 .66035 L .69171 .66309 L p .707 .577 .707 r
F P
0 g
s
.4779 .70105 m .47433 .71973 L .48961 .71841 L p .707 .577 .707 r
F P
0 g
s
.48961 .71841 m .49318 .69972 L .4779 .70105 L p .707 .577 .707 r
F P
0 g
s
.75453 .6241 m .75357 .66068 L .72165 .66035 L p .707 .577 .707 r
F P
0 g
s
.31199 .68852 m .31556 .66984 L .30234 .66303 L p .707 .577 .707 r
F P
0 g
s
.68248 .6941 m .68413 .67648 L .71301 .67347 L p .707 .577 .707 r
F P
0 g
s
.80372 .68763 m .80208 .70526 L .77424 .69696 L p .707 .577 .707 r
F P
0 g
s
.77424 .69696 m .77589 .67934 L .80372 .68763 L p .707 .577 .707 r
F P
0 g
s
.29771 .54461 m .30079 .59967 L .30778 .6085 L p .707 .577 .707 r
F P
0 g
s
.3037 .61531 m .30159 .65263 L .31276 .66031 L p .707 .577 .707 r
F P
0 g
s
.30234 .66303 m .29877 .68172 L .31199 .68852 L p .707 .577 .707 r
F P
0 g
s
.4965 .63081 m .49439 .66812 L .50293 .66129 L p .707 .577 .707 r
F P
0 g
s
.50293 .66129 m .50504 .62397 L .4965 .63081 L p .707 .577 .707 r
F P
0 g
s
.71301 .67347 m .71137 .6911 L .68248 .6941 L p .707 .577 .707 r
F P
0 g
s
.71137 .6911 m .71301 .67347 L .74463 .67446 L p .707 .577 .707 r
F P
0 g
s
.77589 .67934 m .77424 .69696 L .74299 .69209 L p .707 .577 .707 r
F P
0 g
s
.74299 .69209 m .74463 .67446 L .77589 .67934 L p .707 .577 .707 r
F P
0 g
s
.30079 .59967 m .29771 .54461 L .30069 .53509 L p .707 .577 .707 r
F P
0 g
s
.74463 .67446 m .74299 .69209 L .71137 .6911 L p .707 .577 .707 r
F P
0 g
s
.30159 .65263 m .3037 .61531 L .30232 .60768 L p .707 .577 .707 r
F P
0 g
s
.50136 .5304 m .50443 .58547 L .49744 .57664 L p .707 .577 .707 r
F P
0 g
s
.49744 .57664 m .49436 .52158 L .50136 .5304 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49318 .69972 m .48961 .71841 L .49567 .71485 L p .707 .577 .707 r
F P
0 g
s
.49567 .71485 m .49923 .69616 L .49318 .69972 L p .707 .577 .707 r
F P
0 g
s
.29877 .68172 m .30234 .66303 L .29857 .65758 L p .707 .577 .707 r
F P
0 g
s
.29857 .65758 m .295 .67627 L .29877 .68172 L p .707 .577 .707 r
F P
0 g
s
.30232 .60768 m .30021 .645 L .30159 .65263 L p .707 .577 .707 r
F P
0 g
s
.30069 .53509 m .30376 .59016 L .30079 .59967 L p .707 .577 .707 r
F P
0 g
s
.50504 .62397 m .50293 .66129 L .50155 .65366 L p .707 .577 .707 r
F P
0 g
s
.50155 .65366 m .50366 .61634 L .50504 .62397 L p .707 .577 .707 r
F P
0 g
s
.30376 .59016 m .30069 .53509 L .31334 .52581 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30021 .645 m .30232 .60768 L .31085 .60085 L p .707 .577 .707 r
F P
0 g
s
.49436 .52158 m .49744 .57664 L .48116 .56938 L p .707 .577 .707 r
F P
0 g
s
.48116 .56938 m .47809 .51431 L .49436 .52158 L p .707 .577 .707 r
F P
0 g
s
.49923 .69616 m .49567 .71485 L .4919 .7094 L p .707 .577 .707 r
F P
0 g
s
.4919 .7094 m .49546 .69072 L .49923 .69616 L p .707 .577 .707 r
F P
0 g
s
.295 .67627 m .29857 .65758 L .30462 .65402 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31334 .52581 m .31641 .58087 L .30376 .59016 L p .707 .577 .707 r
F P
0 g
s
.30462 .65402 m .30105 .67271 L .295 .67627 L p .707 .577 .707 r
F P
0 g
s
.31085 .60085 m .30875 .63816 L .30021 .645 L p .707 .577 .707 r
F P
0 g
s
.50366 .61634 m .50155 .65366 L .49038 .64597 L p .707 .577 .707 r
F P
0 g
s
.49038 .64597 m .49249 .60866 L .50366 .61634 L p .707 .577 .707 r
F P
0 g
s
.31641 .58087 m .31334 .52581 L .33443 .51767 L p .707 .577 .707 r
F P
0 g
s
.47809 .51431 m .48116 .56938 L .4572 .56439 L p .707 .577 .707 r
F P
0 g
s
.4572 .56439 m .45412 .50932 L .47809 .51431 L p .707 .577 .707 r
F P
0 g
s
.30875 .63816 m .31085 .60085 L .32848 .59548 L p .707 .577 .707 r
F P
0 g
s
.49546 .69072 m .4919 .7094 L .47867 .7026 L p .707 .577 .707 r
F P
0 g
s
.47867 .7026 m .48224 .68391 L .49546 .69072 L p .707 .577 .707 r
F P
0 g
s
.33443 .51767 m .3375 .57274 L .31641 .58087 L p .707 .577 .707 r
F P
0 g
s
.30105 .67271 m .30462 .65402 L .3199 .6527 L p .707 .577 .707 r
F P
0 g
s
.32848 .59548 m .32637 .6328 L .30875 .63816 L p .707 .577 .707 r
F P
0 g
s
.3199 .6527 m .31633 .67139 L .30105 .67271 L p .707 .577 .707 r
F P
0 g
s
.49249 .60866 m .49038 .64597 L .47052 .63899 L p .707 .577 .707 r
F P
0 g
s
.47052 .63899 m .47262 .60168 L .49249 .60866 L p .707 .577 .707 r
F P
0 g
s
.3375 .57274 m .33443 .51767 L .36189 .51148 L p .707 .577 .707 r
F P
0 g
s
.45412 .50932 m .4572 .56439 L .42789 .56215 L p .707 .577 .707 r
F P
0 g
s
.42789 .56215 m .42482 .50709 L .45412 .50932 L p .707 .577 .707 r
F P
0 g
s
.32637 .6328 m .32848 .59548 L .35347 .5921 L p .707 .577 .707 r
F P
0 g
s
.36496 .56654 m .36189 .51148 L .39303 .50783 L p .707 .577 .707 r
F P
0 g
s
.36189 .51148 m .36496 .56654 L .3375 .57274 L p .707 .577 .707 r
F P
0 g
s
.42482 .50709 m .42789 .56215 L .3961 .56289 L p .707 .577 .707 r
F P
0 g
s
.3961 .56289 m .39303 .50783 L .42482 .50709 L p .707 .577 .707 r
F P
0 g
s
.39303 .50783 m .3961 .56289 L .36496 .56654 L p .707 .577 .707 r
F P
0 g
s
.48224 .68391 m .47867 .7026 L .4573 .69511 L p .707 .577 .707 r
F P
0 g
s
.4573 .69511 m .46086 .67642 L .48224 .68391 L p .707 .577 .707 r
F P
0 g
s
.47262 .60168 m .47052 .63899 L .44391 .6334 L p .707 .577 .707 r
F P
0 g
s
.44391 .6334 m .44601 .59608 L .47262 .60168 L p .707 .577 .707 r
F P
0 g
s
.35347 .5921 m .35136 .62942 L .32637 .6328 L p .707 .577 .707 r
F P
0 g
s
.31633 .67139 m .3199 .6527 L .34291 .65374 L p .707 .577 .707 r
F P
0 g
s
.34291 .65374 m .33935 .67243 L .31633 .67139 L p .707 .577 .707 r
F P
0 g
s
.35136 .62942 m .35347 .5921 L .38337 .59105 L p .707 .577 .707 r
F P
0 g
s
.44601 .59608 m .44391 .6334 L .41315 .62974 L p .707 .577 .707 r
F P
0 g
s
.41315 .62974 m .41526 .59242 L .44601 .59608 L p .707 .577 .707 r
F P
0 g
s
.38337 .59105 m .38126 .62836 L .35136 .62942 L p .707 .577 .707 r
F P
0 g
s
.46086 .67642 m .4573 .69511 L .42985 .68766 L p .707 .577 .707 r
F P
0 g
s
.42985 .68766 m .43342 .66897 L .46086 .67642 L p .707 .577 .707 r
F P
0 g
s
.38126 .62836 m .38337 .59105 L .41526 .59242 L p .707 .577 .707 r
F P
0 g
s
.33935 .67243 m .34291 .65374 L .37141 .65705 L p .707 .577 .707 r
F P
0 g
s
.41526 .59242 m .41315 .62974 L .38126 .62836 L p .707 .577 .707 r
F P
0 g
s
.37141 .65705 m .36784 .67574 L .33935 .67243 L p .707 .577 .707 r
F P
0 g
s
.43342 .66897 m .42985 .68766 L .39903 .68098 L p .707 .577 .707 r
F P
0 g
s
.39903 .68098 m .40259 .6623 L .43342 .66897 L p .707 .577 .707 r
F P
0 g
s
.36784 .67574 m .37141 .65705 L .40259 .6623 L p .707 .577 .707 r
F P
0 g
s
.40259 .6623 m .39903 .68098 L .36784 .67574 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo7P00Ogoo001jOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001iOol0
07Aoo`H000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Aoo`00L7oo1000
0UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000L7oo001]Ool30006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001]Ool006]oo`<000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00JGoo0P000UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JGoo001WOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0
06Ioo`8000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001oogoo06Eoo`00IWoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00IGoo00<005YF0000
0eYF60002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF0000IGoo001UOol60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol0
065oo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eo
o`00GWoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP0006Eoo`00Fgoo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00FGoo0P0015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001HOol20005
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUH0001UOol005Ioo`800003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0006Eoo`00EGoo00D005YFFUIJ
EP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol2
0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0006Eoo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00
FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0001UOol005Ao
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF000035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF0000IGoo001DOol20003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000>OolO000h
Ool005Aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP0000Yoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00D003=oo`00E7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00001Woo10001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000035o
o`00E7oo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=J
EP00FUH03@000eYF00<005YFFUH00UYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000Woo10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8002moo`00E7oo00<005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH00UYF500015YF00<005YFFUH01EYF1@0015YF00<005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`001EYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
FUH00UYF0P00;Woo001DOol00`00FUH00002FUH00`00FUIJEP03FUH50006FUH01000FUIJEUYF1P00
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000
;Goo001EOol01EYF001JEUYF00000eYF0P000eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=J
EP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF100000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
0000;Goo001EOol01UYF001JEUYF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
0000;Goo001EOol015YF001JEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP03001JEP0002eo
o`00EGoo00AJEP000000009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
000]Ool005Eoo`03FUH0000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
02eoo`00EGoo00=JEP00000015YF00<005YFFUH00UYF6@000eYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF0000;Goo0013Ool90009Ool00`00FUH00003FUH60003
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF1P0015YF00<005YFFUH00eYF00D005YF
FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP8002eoo`00>goo200015YF00<005YFFUH00UYF2P0000=JEP0000000P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
10001EYF00<005YF00000P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Goo000fOol50003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUH0000/Ool003=oo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;7oo
000aOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEQl000=JEP03001JEUYF
009JEP03001JEP0002aoo`00<7oo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000aJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=JEP03001JEUYF00@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000=JEP03001JEP0002aoo`00;Woo0P0000=J
EP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=JEP04001JEUYFFUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP00;7oo000]Ool01@00FUIJEUYF00001EYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP8000=JEP@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP06001JEP00001JEP00;7oo000/Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0P0000=JEP0000000UYF00<005YFFUH015YF00<005YFFUH00eYF4P000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF
00<005YFFUH00UYF2@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@000=JEP03001JEUYF
009JEPP000AJEP03001JEUYF00IJEP03001JEUYF009JEPH000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000/Ool002aoo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000=JEPd000EJEPd000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
00000eYF001JEP02FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUH000040005FUH01@00FUIJEUYF0000;Goo000/Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YF
FUIJEPP0009JEPH000=JEP04001JEUYFFUH80003FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP0200000eYF001JEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH01@00
FUIJEUYF0000;Goo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH90002FUH00`00FUIJEP04FUH:0004FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000300000eYF0000000^Ool002ao
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEP800003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF00IJEP<0009JEPT000AJEP03
001JEUYF00=JEP<00004FUH005YFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<7oo000/Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000_Ool002aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YF0000;Woo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04
FUHE0003FUH@00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool002aoo`80009JEP03001JEUYF00=JEP03
001JEUYF00D000Uoo`D000Ioo`D000=JEP03001JEUYF00AJEP04001JEUYFFUH70003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP00;Goo000/Ool20002FUH00`00FUIJEP02FUH400000eYF001JEP02FUH>0004Ool500000eYF
001JEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP040007FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002aoo`80009JEP03001JEP00008000EJ
EP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00=JEP03
001JEUYF00=JEPH0015oo`H000IJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;7oo0P000UYF
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF100025YF0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001eYF00<005YFFUH015YF00<005YF
FUH00UYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00<005YF00000`000UYF0P002Woo0`0037oo10000UYF00<005YFFUH00eYF00<005YFFUH00P00
;7oo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003
FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH200000eYF001JEP02FUH30002FUH01`00FUIJEUYF001JEP0000Qoo`D000mo
o`@000AJEP03001JEUYF008002aoo`00;7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH02@0015YF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000`000eYF1P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH010000eYF00H005YFFUIJEP00FUH?000BOol3
000015YF001JEUYF0P00;7oo000/Ool30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP02FUH40002FUH90004FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH40009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH200000eYF00000004FUH90003FUH00`00FUIJEP06FUH00`00FUIJEP04000=Ool300000eYF
00000002FUH2000/Ool002aoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00006FUH00`00FUH0000400000eYF001JEP04FUH7
0006FUH00`00FUIJEP06FUH00`00FUH000020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH300000eYF001JEP02FUH400000eYF001JEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH40005Ool400000eYF001JEP03FUH00`00FUH0000]Ool002aoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00=JEQP00003FUH005YF00EJEP03001JEUYF00=JEPD000=J
EPH00003FUH000000080009JEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF008000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000@000EJEP03001JEUYF009JEP<0
02eoo`00;Goo0P000eYF00<005YFFUH015YF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000P0015YF00<005YFFUH01UYF00<005YFFUH02@000eYF00<005YF00000`001UYF00<005YF
FUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0P000UYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF
0`000eYF00<005YFFUH00UYF00<005YF0000;Goo000]Ool20003FUH00`00FUIJEP0400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00
FUIJEP04FUH50003FUH00`00FUIJEP03FUH400000eYF001JEP06FUH01P00FUIJEP00FUH000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH00000FUH00005FUH00`00FUIJ
EP02FUH@0006FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH0000]Ool002ioo`03001J
EUYF00@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@0
00IJEP03001JEUYF00IJEP<00003FUH00000008000UJEP<000EJEP04001JEUYFFUH3000<FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH600000eYF001J
EP06FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUH0000]
Ool002ioo`<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH5
00000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003
FUH00`00FUH000020007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00
FUIJEP03FUH20002FUH00`00FUH0000]Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00003FUH005YF
00MJEP03001JEUYF00MJEP04001JEUYFFUH<0002FUH01000FUH0000035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0`000eYF0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH01EYF0P0000=JEP000000;Woo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP060004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUH0000300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH20002FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH40005FUH00`00FUH00002000^Ool002aoo`03001JEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP06001JEUYF001JEP000eYF1`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP<00003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003
FUH01000FUIJEP00;goo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP@000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF009J
EP03001oogoo02aoo`00;7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF0005FUH0
0`00FUIJEP06FUH60004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH200000eYF001JEP0;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH01000FUIJEUYF100000=JEP00FUH0
1eYF00<005YF00000P0015YF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP03001oogoo02aoo`00
;7oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH@0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH300000eYF000000040003FUH90004FUH60003FUH00`00FUIJEP02FUH80006Ool00`00FUIJEP02
000]Ool002aoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF009JEQT000=JEP03001JEUYF
00=JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`001EYF00H005YF0000
05YF0002FUH20004OolB000>Ool01@00FUH005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP02FUH80007Ool50007Ool<0003FUH01P00FUIJEP00FUH000EJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP800003FUH0000000=JEP04001JEUYFFUH20002FUH20009Ool5000GOol200000eYF001oo`0/
Ool002aoo`03001JEP0000=JEPH00003FUH0000001P000AJEP03001JEUYF00AJEPD0009JEP03001J
EP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP04001JEUYF0004FUH4000;Ool3000I
Ool00`00FUH0000]Ool002aoo`04001JEP00FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUH000040002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF001J
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH40004FUH01000FUIJEP009goo0`00;Goo
000/Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`000eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=JEP03001JEUYF008000=JEP04001JEUYF000WOol3000]Ool002aoo`80
009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH40002FUH2000TOol300000eYF001oo`0/Ool0
02aoo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000`001EYF00D005YF000005YF0080025oo`<0009JEP8002ioo`00;7oo00D0
05YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEP`000AJEP03001JEUYF00EJEP`000EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00
009JEP03001JEUYF00=JEP04001JEUYFFUH3000MOol400000eYF001JEP02FUH2000^Ool002aoo`05
001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH@0003FUH20000
17oo001JEP001EYF00<005YFFUH01EYF20000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH015YF1`001eYF00<005YFFUH00eYF00<005YF00000eYF0P000eYF00<005YFFUH015YF1P004Woo
1@001EYF00D005YFFUIJEP0002moo`00;Goo0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF2@0015YF00<005YFFUH01EYF00<005YFFUH01@000Woo00<005YF00001EYF00<005YFFUH0
0UYF10002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00`0015YF
00<005YFFUH00eYF00<005YF00000P000eYF0P0000=JEP00FUH01UYF00<005YFFUH00UYF4P000eYF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;goo0`000eYF00<005YFFUH01EYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH015YF00<0
05YF00000P000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00eYF0`0000=JEP00FUH015YF00<005YF00000Woo20001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000035oo`00<Woo0P0000AJEP00
FUIJEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP07
001JEUYFFUH005YF00001EYF0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF0P001EYF00<005YF00001Goo1`0015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<goo000dOol400000eYF001JEP06
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01P00FUIJEP00
FUH000=JEP8000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP04001JEP000003FUH00`00FUH000070003FUH500000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000fOol0035oo`<000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP07001JEUYF001JEP00
FUH00P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP800004FUH005YF0004FUH00`00FUIJEP0>0004FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH5000iOol002ioo`<00003FUH005YF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEQd00003FUH005YF008000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003
FUH005YF00=JEP03001JEUYF00=JEP80009JEP03001oogoo00Aooa8003ioo`00;7oo0`000eYF00<0
05YFFUH015YF00<005YFFUH015YF30002Woo1`000eYF00@005YFFUIJEP<000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEP000005FUH00`00FUIJEP02FUH00`00FUH00002001FOol002aoo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00@000Moo`D00003Ool0000000L000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000005
FUH00`00FUIJEP03FUH01000FUIJEP00EWoo000/Ool00`00FUH00004FUH01000FUIJEUYF1@0027oo
2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YFFUH02@000eYF00@005YFFUH005Ioo`00;7oo00<005YF00000UYF4`00
15YF0`001UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH010001EYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000000MJEPD0009JEP8005Eoo`00;Goo1@001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000=oo`03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH005YF00IJEP03001JEUYF009JEP04001J
EUYF001EOol002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEPD000Qoo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP80009JEP03001JEUYF00AJEP03001JEUYF00800004Ool00000001EOol002eoo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000ioo`80
00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00006FUH30004Ool2001EOol002io
o`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPL001Ao
o`04001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF0P001Goo00@005YF000005Ao
o`00<7oo7P0077oo0`0025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YF000000IJEP03001JEP0000<000Moo`04001JEUYF001DOol0
06aoo`<000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00AJEP@000AJEPH000Yoo`80009JEP03001oogoo059oo`00Kgoo10000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH030003goo00D005YF
001JEP0005Eoo`00Lgoo1@0025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF2`00
57oo00@005YFFUIJEP8005Eoo`00N7oo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P001Woo1@004Woo0P0015YF00<007ooOol0E7oo001nOolO000<Ool5000@Ool200000eYF001J
EP03FUH00`00Oomoo`1DOol008ioo`03001JEUYF008001Moo`<000moo`8000=JEP05001JEUYFFUH0
001GOol008ioo`04001JEUYF000WOol30006FUH00`00FUH0001HOol008moo`8002Ioo`800003FUH0
05YF00IJEP8005Uoo`00Sgoo0P008goo0`000eYF00<005YFFUH015YF0P00FWoo002?Ool3000NOol4
0007FUH01000FUIJEUYF0P00G7oo002?Ool00`00FUIJEP03000GOol40002FUH00`00FUIJEP06FUH0
1000FUH00000GWoo002?Ool20002FUH00`00FUH00002000>Ool60006FUH00`00FUIJEP05FUH3001P
Ool0091oo`04001JEUYF0004FUH>0003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001SOol0091o
o`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
0002001UOol0095oo`800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00AJEP@006Qoo`00Tgoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01000K7oo
002FOol300000eYF001JEP06FUH00`00FUIJEP02FUH6001`Ool009Uoo`h007Ioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.62024 .74987 m .61739 .69464 L .58549 .69579 L p .707 .577 .707 r
F P
0 g
s
.61739 .69464 m .62024 .74987 L .65098 .74595 L p .707 .577 .707 r
F P
0 g
s
.65098 .74595 m .64813 .69071 L .61739 .69464 L p .707 .577 .707 r
F P
0 g
s
.58834 .75102 m .58549 .69579 L .55554 .69405 L p .707 .577 .707 r
F P
0 g
s
.58549 .69579 m .58834 .75102 L .62024 .74987 L p .707 .577 .707 r
F P
0 g
s
.64813 .69071 m .65098 .74595 L .67753 .73963 L p .707 .577 .707 r
F P
0 g
s
.67753 .73963 m .67468 .68439 L .64813 .69071 L p .707 .577 .707 r
F P
0 g
s
.55839 .74928 m .55554 .69405 L .53048 .68959 L p .707 .577 .707 r
F P
0 g
s
.55554 .69405 m .55839 .74928 L .58834 .75102 L p .707 .577 .707 r
F P
0 g
s
.60556 .80795 m .60736 .7708 L .57593 .76794 L p .707 .577 .707 r
F P
0 g
s
.60736 .7708 m .60556 .80795 L .63719 .80826 L p .707 .577 .707 r
F P
0 g
s
.63719 .80826 m .63899 .77111 L .60736 .7708 L p .707 .577 .707 r
F P
0 g
s
.67468 .68439 m .67753 .73963 L .69731 .73154 L p .707 .577 .707 r
F P
0 g
s
.69731 .73154 m .69446 .6763 L .67468 .68439 L p .707 .577 .707 r
F P
0 g
s
.63899 .77111 m .63719 .80826 L .66591 .80599 L p .707 .577 .707 r
F P
0 g
s
.66591 .80599 m .66772 .76885 L .63899 .77111 L p .707 .577 .707 r
F P
0 g
s
.57412 .80508 m .57593 .76794 L .54776 .76281 L p .707 .577 .707 r
F P
0 g
s
.57593 .76794 m .57412 .80508 L .60556 .80795 L p .707 .577 .707 r
F P
0 g
s
.53048 .68959 m .53333 .74483 L .55839 .74928 L p .707 .577 .707 r
F P
0 g
s
.53333 .74483 m .53048 .68959 L .51275 .68285 L p .707 .577 .707 r
F P
0 g
s
.59145 .84655 m .59437 .82807 L .56381 .8216 L p .707 .577 .707 r
F P
0 g
s
.59437 .82807 m .59145 .84655 L .62299 .85084 L p .707 .577 .707 r
F P
0 g
s
.62299 .85084 m .62592 .83235 L .59437 .82807 L p .707 .577 .707 r
F P
0 g
s
.54776 .76281 m .54595 .79995 L .57412 .80508 L p .707 .577 .707 r
F P
0 g
s
.62592 .83235 m .62299 .85084 L .65243 .85253 L p .707 .577 .707 r
F P
0 g
s
.65243 .85253 m .65535 .83405 L .62592 .83235 L p .707 .577 .707 r
F P
0 g
s
.66772 .76885 m .66591 .80599 L .68892 .80137 L p .707 .577 .707 r
F P
0 g
s
.68892 .80137 m .69073 .76423 L .66772 .76885 L p .707 .577 .707 r
F P
0 g
s
.56381 .8216 m .56089 .84009 L .59145 .84655 L p .707 .577 .707 r
F P
0 g
s
.54595 .79995 m .54776 .76281 L .52562 .75591 L p .707 .577 .707 r
F P
0 g
s
.56089 .84009 m .56381 .8216 L .53722 .81359 L p .707 .577 .707 r
F P
0 g
s
.53722 .81359 m .5343 .83208 L .56089 .84009 L p .707 .577 .707 r
F P
0 g
s
.69446 .6763 m .69731 .73154 L .70838 .72246 L p .707 .577 .707 r
F P
0 g
s
.70838 .72246 m .70553 .66723 L .69446 .6763 L p .707 .577 .707 r
F P
0 g
s
.51275 .68285 m .5156 .73809 L .53333 .74483 L p .707 .577 .707 r
F P
0 g
s
.52562 .75591 m .52382 .79306 L .54595 .79995 L p .707 .577 .707 r
F P
0 g
s
.65535 .83405 m .65243 .85253 L .67687 .85146 L p .707 .577 .707 r
F P
0 g
s
.67687 .85146 m .6798 .83298 L .65535 .83405 L p .707 .577 .707 r
F P
0 g
s
.5156 .73809 m .51275 .68285 L .5041 .67449 L p .707 .577 .707 r
F P
0 g
s
.5343 .83208 m .53722 .81359 L .5172 .80482 L p .707 .577 .707 r
F P
0 g
s
.69073 .76423 m .68892 .80137 L .70397 .79484 L p .707 .577 .707 r
F P
0 g
s
.70397 .79484 m .70577 .7577 L .69073 .76423 L p .707 .577 .707 r
F P
0 g
s
.5172 .80482 m .51428 .82331 L .5343 .83208 L p .707 .577 .707 r
F P
0 g
s
.52382 .79306 m .52562 .75591 L .51168 .74793 L p .707 .577 .707 r
F P
0 g
s
.6798 .83298 m .67687 .85146 L .69394 .84773 L p .707 .577 .707 r
F P
0 g
s
.69394 .84773 m .69686 .82925 L .6798 .83298 L p .707 .577 .707 r
F P
0 g
s
.51168 .74793 m .50987 .78507 L .52382 .79306 L p .707 .577 .707 r
F P
0 g
s
.5041 .67449 m .50695 .72972 L .5156 .73809 L p .707 .577 .707 r
F P
0 g
s
.70553 .66723 m .70838 .72246 L .70965 .7133 L p .707 .577 .707 r
F P
0 g
s
.70965 .7133 m .7068 .65806 L .70553 .66723 L p .707 .577 .707 r
F P
0 g
s
.51428 .82331 m .5172 .80482 L .50572 .79615 L p .707 .577 .707 r
F P
0 g
s
.50572 .79615 m .5028 .81464 L .51428 .82331 L p .707 .577 .707 r
F P
0 g
s
.50695 .72972 m .5041 .67449 L .50538 .66532 L p .707 .577 .707 r
F P
0 g
s
.70577 .7577 m .70397 .79484 L .70957 .78705 L p .707 .577 .707 r
F P
0 g
s
.70957 .78705 m .71137 .7499 L .70577 .7577 L p .707 .577 .707 r
F P
0 g
s
.50987 .78507 m .51168 .74793 L .50729 .73963 L p .707 .577 .707 r
F P
0 g
s
.69686 .82925 m .69394 .84773 L .70195 .84171 L p .707 .577 .707 r
F P
0 g
s
.70195 .84171 m .70487 .82323 L .69686 .82925 L p .707 .577 .707 r
F P
0 g
s
.48331 .82166 m .48331 .31977 L .43985 .31651 L p .707 .577 .707 r
F P
0 g
s
.50729 .73963 m .50549 .77677 L .50987 .78507 L p .707 .577 .707 r
F P
0 g
s
.50538 .66532 m .50823 .72056 L .50695 .72972 L p .707 .577 .707 r
F P
0 g
s
.5028 .81464 m .50572 .79615 L .5039 .78843 L p .707 .577 .707 r
F P
0 g
s
.5039 .78843 m .50097 .80691 L .5028 .81464 L p .707 .577 .707 r
F P
0 g
s
.50823 .72056 m .50538 .66532 L .51644 .65625 L p .707 .577 .707 r
F P
0 g
s
.50549 .77677 m .50729 .73963 L .51289 .73184 L p .707 .577 .707 r
F P
0 g
s
.51289 .73184 m .51109 .76898 L .50549 .77677 L p .707 .577 .707 r
F P
0 g
s
.51644 .65625 m .51929 .71148 L .50823 .72056 L p .707 .577 .707 r
F P
0 g
s
.50097 .80691 m .5039 .78843 L .51191 .78241 L p .707 .577 .707 r
F P
0 g
s
.51191 .78241 m .50898 .80089 L .50097 .80691 L p .707 .577 .707 r
F P
0 g
s
.51109 .76898 m .51289 .73184 L .52794 .72531 L p .707 .577 .707 r
F P
0 g
s
.52794 .72531 m .52613 .76245 L .51109 .76898 L p .707 .577 .707 r
F P
0 g
s
.50898 .80089 m .51191 .78241 L .52897 .77868 L p .707 .577 .707 r
F P
0 g
s
.52897 .77868 m .52605 .79717 L .50898 .80089 L p .707 .577 .707 r
F P
0 g
s
.52605 .79717 m .52897 .77868 L .55342 .77761 L p .707 .577 .707 r
F P
0 g
s
.55342 .77761 m .55049 .7961 L .52605 .79717 L p .707 .577 .707 r
F P
0 g
s
.48331 .31977 m .48331 .82166 L .5284 .82117 L p .707 .577 .707 r
F P
0 g
s
.51929 .71148 m .51644 .65625 L .53622 .64815 L p .707 .577 .707 r
F P
0 g
s
.53622 .64815 m .53907 .70339 L .51929 .71148 L p .707 .577 .707 r
F P
0 g
s
.52613 .76245 m .52794 .72531 L .55095 .72068 L p .707 .577 .707 r
F P
0 g
s
.55095 .72068 m .54914 .75783 L .52613 .76245 L p .707 .577 .707 r
F P
0 g
s
.5284 .82117 m .5284 .31928 L .48331 .31977 L p .707 .577 .707 r
F P
0 g
s
.53907 .70339 m .53622 .64815 L .56278 .64184 L p .707 .577 .707 r
F P
0 g
s
.56278 .64184 m .56563 .69707 L .53907 .70339 L p .707 .577 .707 r
F P
0 g
s
.54914 .75783 m .55095 .72068 L .57968 .71842 L p .707 .577 .707 r
F P
0 g
s
.57968 .71842 m .57787 .75556 L .54914 .75783 L p .707 .577 .707 r
F P
0 g
s
.55049 .7961 m .55342 .77761 L .58285 .7793 L p .707 .577 .707 r
F P
0 g
s
.58285 .7793 m .57993 .79779 L .55049 .7961 L p .707 .577 .707 r
F P
0 g
s
.5284 .31928 m .5284 .82117 L .57071 .81695 L p .707 .577 .707 r
F P
0 g
s
.56563 .69707 m .56278 .64184 L .59351 .63791 L p .707 .577 .707 r
F P
0 g
s
.59351 .63791 m .59636 .69315 L .56563 .69707 L p .707 .577 .707 r
F P
0 g
s
.57071 .81695 m .57071 .31506 L .5284 .31928 L p .707 .577 .707 r
F P
0 g
s
.7068 .65806 m .70965 .7133 L .701 .70493 L p .707 .577 .707 r
F P
0 g
s
.701 .70493 m .69815 .6497 L .7068 .65806 L p .707 .577 .707 r
F P
0 g
s
.43985 .8184 m .43985 .31651 L .40228 .3098 L p .707 .577 .707 r
F P
0 g
s
.43985 .31651 m .43985 .8184 L .48331 .82166 L p .707 .577 .707 r
F P
0 g
s
.62542 .63676 m .62827 .692 L .59636 .69315 L p .707 .577 .707 r
F P
0 g
s
.59636 .69315 m .59351 .63791 L .62542 .63676 L p .707 .577 .707 r
F P
0 g
s
.57787 .75556 m .57968 .71842 L .6113 .71873 L p .707 .577 .707 r
F P
0 g
s
.6113 .71873 m .6095 .75588 L .57787 .75556 L p .707 .577 .707 r
F P
0 g
s
.57993 .79779 m .58285 .7793 L .6144 .78359 L p .707 .577 .707 r
F P
0 g
s
.6144 .78359 m .61147 .80208 L .57993 .79779 L p .707 .577 .707 r
F P
0 g
s
.57071 .31506 m .57071 .81695 L .6061 .80944 L p .707 .577 .707 r
F P
0 g
s
.6061 .80944 m .6061 .30755 L .57071 .31506 L p .707 .577 .707 r
F P
0 g
s
.71137 .7499 m .70957 .78705 L .70519 .77875 L p .707 .577 .707 r
F P
0 g
s
.70519 .77875 m .70699 .74161 L .71137 .7499 L p .707 .577 .707 r
F P
0 g
s
.27418 .70823 m .27303 .65187 L .2411 .65223 L p .707 .577 .707 r
F P
0 g
s
.27303 .65187 m .27418 .70823 L .30494 .70577 L p .707 .577 .707 r
F P
0 g
s
.30494 .70577 m .30379 .64942 L .27303 .65187 L p .707 .577 .707 r
F P
0 g
s
.24225 .70858 m .2411 .65223 L .21111 .65044 L p .707 .577 .707 r
F P
0 g
s
.2411 .65223 m .24225 .70858 L .27418 .70823 L p .707 .577 .707 r
F P
0 g
s
.70487 .82323 m .70195 .84171 L .70012 .83399 L p .707 .577 .707 r
F P
0 g
s
.70012 .83399 m .70305 .8155 L .70487 .82323 L p .707 .577 .707 r
F P
0 g
s
.30379 .64942 m .30494 .70577 L .33152 .70146 L p .707 .577 .707 r
F P
0 g
s
.33152 .70146 m .33037 .64511 L .30379 .64942 L p .707 .577 .707 r
F P
0 g
s
.40228 .81169 m .40228 .3098 L .37428 .3003 L p .707 .577 .707 r
F P
0 g
s
.40228 .3098 m .40228 .81169 L .43985 .8184 L p .707 .577 .707 r
F P
0 g
s
.69815 .6497 m .701 .70493 L .68328 .69819 L p .707 .577 .707 r
F P
0 g
s
.68328 .69819 m .68043 .64296 L .69815 .6497 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.21226 .7068 m .21111 .65044 L .18601 .6467 L p .707 .577 .707 r
F P
0 g
s
.21111 .65044 m .21226 .7068 L .24225 .70858 L p .707 .577 .707 r
F P
0 g
s
.64274 .72159 m .64094 .75874 L .6095 .75588 L p .707 .577 .707 r
F P
0 g
s
.6095 .75588 m .6113 .71873 L .64274 .72159 L p .707 .577 .707 r
F P
0 g
s
.64496 .79006 m .64203 .80854 L .61147 .80208 L p .707 .577 .707 r
F P
0 g
s
.61147 .80208 m .6144 .78359 L .64496 .79006 L p .707 .577 .707 r
F P
0 g
s
.6061 .30755 m .6061 .80944 L .63111 .79936 L p .707 .577 .707 r
F P
0 g
s
.65536 .6385 m .65821 .69374 L .62827 .692 L p .707 .577 .707 r
F P
0 g
s
.62827 .692 m .62542 .63676 L .65536 .6385 L p .707 .577 .707 r
F P
0 g
s
.63111 .79936 m .63111 .29747 L .6061 .30755 L p .707 .577 .707 r
F P
0 g
s
.26003 .78019 m .26069 .74384 L .22922 .74151 L p .707 .577 .707 r
F P
0 g
s
.26069 .74384 m .26003 .78019 L .29169 .77926 L p .707 .577 .707 r
F P
0 g
s
.29169 .77926 m .29235 .74291 L .26069 .74384 L p .707 .577 .707 r
F P
0 g
s
.70699 .74161 m .70519 .77875 L .69124 .77077 L p .707 .577 .707 r
F P
0 g
s
.69124 .77077 m .69305 .73362 L .70699 .74161 L p .707 .577 .707 r
F P
0 g
s
.18601 .6467 m .18716 .70306 L .21226 .7068 L p .707 .577 .707 r
F P
0 g
s
.29235 .74291 m .29169 .77926 L .32043 .77515 L p .707 .577 .707 r
F P
0 g
s
.32043 .77515 m .32109 .73881 L .29235 .74291 L p .707 .577 .707 r
F P
0 g
s
.22856 .77785 m .22922 .74151 L .20102 .73613 L p .707 .577 .707 r
F P
0 g
s
.22922 .74151 m .22856 .77785 L .26003 .78019 L p .707 .577 .707 r
F P
0 g
s
.33037 .64511 m .33152 .70146 L .3513 .69571 L p .707 .577 .707 r
F P
0 g
s
.3513 .69571 m .35015 .63936 L .33037 .64511 L p .707 .577 .707 r
F P
0 g
s
.18716 .70306 m .18601 .6467 L .16825 .64137 L p .707 .577 .707 r
F P
0 g
s
.70305 .8155 m .70012 .83399 L .68864 .82532 L p .707 .577 .707 r
F P
0 g
s
.68864 .82532 m .69157 .80683 L .70305 .8155 L p .707 .577 .707 r
F P
0 g
s
.68043 .64296 m .68328 .69819 L .65821 .69374 L p .707 .577 .707 r
F P
0 g
s
.65821 .69374 m .65536 .6385 L .68043 .64296 L p .707 .577 .707 r
F P
0 g
s
.20102 .73613 m .20036 .77248 L .22856 .77785 L p .707 .577 .707 r
F P
0 g
s
.32109 .73881 m .32043 .77515 L .34345 .76827 L p .707 .577 .707 r
F P
0 g
s
.34345 .76827 m .34411 .73193 L .32109 .73881 L p .707 .577 .707 r
F P
0 g
s
.20036 .77248 m .20102 .73613 L .17884 .72825 L p .707 .577 .707 r
F P
0 g
s
.37428 .80219 m .37428 .3003 L .35858 .28895 L p .707 .577 .707 r
F P
0 g
s
.37428 .3003 m .37428 .80219 L .40228 .81169 L p .707 .577 .707 r
F P
0 g
s
.16825 .64137 m .1694 .69772 L .18716 .70306 L p .707 .577 .707 r
F P
0 g
s
.25021 .83402 m .25121 .81706 L .22026 .81196 L p .707 .577 .707 r
F P
0 g
s
.25121 .81706 m .25021 .83402 L .28206 .83449 L p .707 .577 .707 r
F P
0 g
s
.28206 .83449 m .28307 .81752 L .25121 .81706 L p .707 .577 .707 r
F P
0 g
s
.35015 .63936 m .3513 .69571 L .36236 .68909 L p .707 .577 .707 r
F P
0 g
s
.36236 .68909 m .36121 .63273 L .35015 .63936 L p .707 .577 .707 r
F P
0 g
s
.28307 .81752 m .28206 .83449 L .3117 .83028 L p .707 .577 .707 r
F P
0 g
s
.3117 .83028 m .3127 .81332 L .28307 .81752 L p .707 .577 .707 r
F P
0 g
s
.69305 .73362 m .69124 .77077 L .6691 .76387 L p .707 .577 .707 r
F P
0 g
s
.6691 .76387 m .67091 .72672 L .69305 .73362 L p .707 .577 .707 r
F P
0 g
s
.17884 .72825 m .17818 .76459 L .20036 .77248 L p .707 .577 .707 r
F P
0 g
s
.67091 .72672 m .6691 .76387 L .64094 .75874 L p .707 .577 .707 r
F P
0 g
s
.64094 .75874 m .64274 .72159 L .67091 .72672 L p .707 .577 .707 r
F P
0 g
s
.63111 .29747 m .63111 .79936 L .64328 .7877 L p .707 .577 .707 r
F P
0 g
s
.64328 .7877 m .64328 .28581 L .63111 .29747 L p .707 .577 .707 r
F P
0 g
s
.21926 .82893 m .22026 .81196 L .19324 .80274 L p .707 .577 .707 r
F P
0 g
s
.22026 .81196 m .21926 .82893 L .25021 .83402 L p .707 .577 .707 r
F P
0 g
s
.1694 .69772 m .16825 .64137 L .15958 .63496 L p .707 .577 .707 r
F P
0 g
s
.34411 .73193 m .34345 .76827 L .35849 .75929 L p .707 .577 .707 r
F P
0 g
s
.35849 .75929 m .35915 .72295 L .34411 .73193 L p .707 .577 .707 r
F P
0 g
s
.17818 .76459 m .17884 .72825 L .16486 .71862 L p .707 .577 .707 r
F P
0 g
s
.69157 .80683 m .68864 .82532 L .66862 .81655 L p .707 .577 .707 r
F P
0 g
s
.66862 .81655 m .67155 .79807 L .69157 .80683 L p .707 .577 .707 r
F P
0 g
s
.3127 .81332 m .3117 .83028 L .33621 .82181 L p .707 .577 .707 r
F P
0 g
s
.33621 .82181 m .33721 .80485 L .3127 .81332 L p .707 .577 .707 r
F P
0 g
s
.19324 .80274 m .19224 .8197 L .21926 .82893 L p .707 .577 .707 r
F P
0 g
s
.19224 .8197 m .19324 .80274 L .17279 .79029 L p .707 .577 .707 r
F P
0 g
s
.15958 .63496 m .16073 .69132 L .1694 .69772 L p .707 .577 .707 r
F P
0 g
s
.16486 .71862 m .1642 .75497 L .17818 .76459 L p .707 .577 .707 r
F P
0 g
s
.17279 .79029 m .17179 .80725 L .19224 .8197 L p .707 .577 .707 r
F P
0 g
s
.36121 .63273 m .36236 .68909 L .36362 .68224 L p .707 .577 .707 r
F P
0 g
s
.36362 .68224 m .36247 .62588 L .36121 .63273 L p .707 .577 .707 r
F P
0 g
s
.33721 .80485 m .33621 .82181 L .35321 .80991 L p .707 .577 .707 r
F P
0 g
s
.35321 .80991 m .35421 .79295 L .33721 .80485 L p .707 .577 .707 r
F P
0 g
s
.35915 .72295 m .35849 .75929 L .36407 .74909 L p .707 .577 .707 r
F P
0 g
s
.36102 .79575 m .36202 .77878 L .35421 .79295 L p .707 .577 .707 r
F P
0 g
s
.36247 .62588 m .36362 .68224 L .35494 .67583 L p .707 .577 .707 r
F P
0 g
s
.35494 .67583 m .35379 .61948 L .36247 .62588 L p .707 .577 .707 r
F P
0 g
s
.36407 .74909 m .36473 .71275 L .35915 .72295 L p .707 .577 .707 r
F P
0 g
s
.36032 .70232 m .35966 .73867 L .34568 .72904 L p .707 .577 .707 r
F P
0 g
s
.34568 .72904 m .34634 .69269 L .36032 .70232 L p .707 .577 .707 r
F P
0 g
s
.35989 .76373 m .35889 .7807 L .34701 .76624 L p .707 .577 .707 r
F P
0 g
s
.34701 .76624 m .34802 .74927 L .35989 .76373 L p .707 .577 .707 r
F P
0 g
s
.35858 .79084 m .35858 .28895 L .35672 .27685 L p .707 .577 .707 r
F P
0 g
s
.36473 .71275 m .36407 .74909 L .35966 .73867 L p .707 .577 .707 r
F P
0 g
s
.35966 .73867 m .36032 .70232 L .36473 .71275 L p .707 .577 .707 r
F P
0 g
s
.36202 .77878 m .36102 .79575 L .35889 .7807 L p .707 .577 .707 r
F P
0 g
s
.35889 .7807 m .35989 .76373 L .36202 .77878 L p .707 .577 .707 r
F P
0 g
s
.35858 .28895 m .35858 .79084 L .37428 .80219 L p .707 .577 .707 r
F P
0 g
s
.67155 .79807 m .66862 .81655 L .64203 .80854 L p .707 .577 .707 r
F P
0 g
s
.64203 .80854 m .64496 .79006 L .67155 .79807 L p .707 .577 .707 r
F P
0 g
s
.16073 .69132 m .15958 .63496 L .16083 .62811 L p .707 .577 .707 r
F P
0 g
s
.1642 .75497 m .16486 .71862 L .16045 .7082 L p .707 .577 .707 r
F P
0 g
s
.17179 .80725 m .17279 .79029 L .16092 .77583 L p .707 .577 .707 r
F P
0 g
s
.64328 .28581 m .64328 .7877 L .64142 .7756 L p .707 .577 .707 r
F P
0 g
s
.64142 .7756 m .64142 .27371 L .64328 .28581 L p .707 .577 .707 r
F P
0 g
s
.16092 .77583 m .15991 .7928 L .17179 .80725 L p .707 .577 .707 r
F P
0 g
s
.16083 .62811 m .16198 .68447 L .16073 .69132 L p .707 .577 .707 r
F P
0 g
s
.16045 .7082 m .15979 .74454 L .1642 .75497 L p .707 .577 .707 r
F P
0 g
s
.35421 .79295 m .35321 .80991 L .36102 .79575 L p .707 .577 .707 r
F P
0 g
s
.15991 .7928 m .16092 .77583 L .15878 .76078 L p .707 .577 .707 r
F P
0 g
s
.15979 .74454 m .16045 .7082 L .16604 .69799 L p .707 .577 .707 r
F P
0 g
s
.16198 .68447 m .16083 .62811 L .17189 .62149 L p .707 .577 .707 r
F P
0 g
s
.15878 .76078 m .15778 .77775 L .15991 .7928 L p .707 .577 .707 r
F P
0 g
s
.35672 .27685 m .35672 .77874 L .35858 .79084 L p .707 .577 .707 r
F P
0 g
s
.35672 .77874 m .35672 .27685 L .36889 .26519 L p .707 .577 .707 r
F P
0 g
s
.16604 .69799 m .16538 .73434 L .15979 .74454 L p .707 .577 .707 r
F P
0 g
s
.17189 .62149 m .17304 .67784 L .16198 .68447 L p .707 .577 .707 r
F P
0 g
s
.64142 .27371 m .64142 .7756 L .62572 .76424 L p .707 .577 .707 r
F P
0 g
s
.62572 .76424 m .62572 .26235 L .64142 .27371 L p .707 .577 .707 r
F P
0 g
s
.35379 .61948 m .35494 .67583 L .33718 .6705 L p .707 .577 .707 r
F P
0 g
s
.33718 .6705 m .33603 .61414 L .35379 .61948 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15778 .77775 m .15878 .76078 L .1666 .74661 L p .707 .577 .707 r
F P
0 g
s
.16538 .73434 m .16604 .69799 L .18107 .68901 L p .707 .577 .707 r
F P
0 g
s
.17304 .67784 m .17189 .62149 L .19168 .61574 L p .707 .577 .707 r
F P
0 g
s
.1666 .74661 m .16559 .76358 L .15778 .77775 L p .707 .577 .707 r
F P
0 g
s
.18107 .68901 m .18042 .72536 L .16538 .73434 L p .707 .577 .707 r
F P
0 g
s
.19168 .61574 m .19283 .6721 L .17304 .67784 L p .707 .577 .707 r
F P
0 g
s
.33603 .61414 m .33718 .6705 L .31208 .66676 L p .707 .577 .707 r
F P
0 g
s
.31208 .66676 m .31093 .6104 L .33603 .61414 L p .707 .577 .707 r
F P
0 g
s
.36889 .76708 m .36889 .26519 L .39389 .25511 L p .707 .577 .707 r
F P
0 g
s
.36889 .26519 m .36889 .76708 L .35672 .77874 L p .707 .577 .707 r
F P
0 g
s
.16559 .76358 m .1666 .74661 L .18359 .73471 L p .707 .577 .707 r
F P
0 g
s
.34634 .69269 m .34568 .72904 L .32351 .72115 L p .707 .577 .707 r
F P
0 g
s
.32351 .72115 m .32417 .68481 L .34634 .69269 L p .707 .577 .707 r
F P
0 g
s
.19283 .6721 m .19168 .61574 L .21825 .61143 L p .707 .577 .707 r
F P
0 g
s
.18042 .72536 m .18107 .68901 L .20409 .68213 L p .707 .577 .707 r
F P
0 g
s
.62572 .26235 m .62572 .76424 L .59772 .75475 L p .707 .577 .707 r
F P
0 g
s
.59772 .75475 m .59772 .25286 L .62572 .26235 L p .707 .577 .707 r
F P
0 g
s
.18359 .73471 m .18259 .75168 L .16559 .76358 L p .707 .577 .707 r
F P
0 g
s
.21825 .61143 m .2194 .66778 L .19283 .6721 L p .707 .577 .707 r
F P
0 g
s
.31093 .6104 m .31208 .66676 L .2821 .66498 L p .707 .577 .707 r
F P
0 g
s
.2821 .66498 m .28095 .60862 L .31093 .6104 L p .707 .577 .707 r
F P
0 g
s
.34802 .74927 m .34701 .76624 L .32656 .75379 L p .707 .577 .707 r
F P
0 g
s
.32656 .75379 m .32757 .73683 L .34802 .74927 L p .707 .577 .707 r
F P
0 g
s
.20409 .68213 m .20343 .71848 L .18042 .72536 L p .707 .577 .707 r
F P
0 g
s
.2194 .66778 m .21825 .61143 L .24901 .60898 L p .707 .577 .707 r
F P
0 g
s
.32417 .68481 m .32351 .72115 L .2953 .71578 L p .707 .577 .707 r
F P
0 g
s
.2953 .71578 m .29596 .67943 L .32417 .68481 L p .707 .577 .707 r
F P
0 g
s
.20343 .71848 m .20409 .68213 L .23283 .67803 L p .707 .577 .707 r
F P
0 g
s
.18259 .75168 m .18359 .73471 L .2081 .72625 L p .707 .577 .707 r
F P
0 g
s
.28095 .60862 m .2821 .66498 L .25016 .66533 L p .707 .577 .707 r
F P
0 g
s
.25016 .66533 m .24901 .60898 L .28095 .60862 L p .707 .577 .707 r
F P
0 g
s
.24901 .60898 m .25016 .66533 L .2194 .66778 L p .707 .577 .707 r
F P
0 g
s
.2081 .72625 m .2071 .74321 L .18259 .75168 L p .707 .577 .707 r
F P
0 g
s
.39389 .25511 m .39389 .757 L .36889 .76708 L p .707 .577 .707 r
F P
0 g
s
.39389 .757 m .39389 .25511 L .42928 .24759 L p .707 .577 .707 r
F P
0 g
s
.74984 .66146 m .75099 .60685 L .71905 .60584 L p .707 .577 .707 r
F P
0 g
s
.75099 .60685 m .74984 .66146 L .7806 .65924 L p .707 .577 .707 r
F P
0 g
s
.7806 .65924 m .78175 .60463 L .75099 .60685 L p .707 .577 .707 r
F P
0 g
s
.7179 .66045 m .71905 .60584 L .68906 .60171 L p .707 .577 .707 r
F P
0 g
s
.71905 .60584 m .7179 .66045 L .74984 .66146 L p .707 .577 .707 r
F P
0 g
s
.32757 .73683 m .32656 .75379 L .29954 .74457 L p .707 .577 .707 r
F P
0 g
s
.29954 .74457 m .30054 .7276 L .32757 .73683 L p .707 .577 .707 r
F P
0 g
s
.23283 .67803 m .23218 .71437 L .20343 .71848 L p .707 .577 .707 r
F P
0 g
s
.29596 .67943 m .2953 .71578 L .26383 .71344 L p .707 .577 .707 r
F P
0 g
s
.26383 .71344 m .26449 .6771 L .29596 .67943 L p .707 .577 .707 r
F P
0 g
s
.23218 .71437 m .23283 .67803 L .26449 .6771 L p .707 .577 .707 r
F P
0 g
s
.59772 .25286 m .59772 .75475 L .56015 .74804 L p .707 .577 .707 r
F P
0 g
s
.56015 .74804 m .56015 .24615 L .59772 .25286 L p .707 .577 .707 r
F P
0 g
s
.26449 .6771 m .26383 .71344 L .23218 .71437 L p .707 .577 .707 r
F P
0 g
s
.78175 .60463 m .7806 .65924 L .80717 .65402 L p .707 .577 .707 r
F P
0 g
s
.80717 .65402 m .80832 .59941 L .78175 .60463 L p .707 .577 .707 r
F P
0 g
s
.2071 .74321 m .2081 .72625 L .23774 .72204 L p .707 .577 .707 r
F P
0 g
s
.68792 .65632 m .68906 .60171 L .66396 .59486 L p .707 .577 .707 r
F P
0 g
s
.68906 .60171 m .68792 .65632 L .7179 .66045 L p .707 .577 .707 r
F P
0 g
s
.30054 .7276 m .29954 .74457 L .26859 .73947 L p .707 .577 .707 r
F P
0 g
s
.26859 .73947 m .26959 .72251 L .30054 .7276 L p .707 .577 .707 r
F P
0 g
s
.23774 .72204 m .23674 .73901 L .2071 .74321 L p .707 .577 .707 r
F P
0 g
s
.23674 .73901 m .23774 .72204 L .26959 .72251 L p .707 .577 .707 r
F P
0 g
s
.73617 .71061 m .73551 .67299 L .70404 .67235 L p .707 .577 .707 r
F P
0 g
s
.73551 .67299 m .73617 .71061 L .76782 .70916 L p .707 .577 .707 r
F P
0 g
s
.76782 .70916 m .76716 .67154 L .73551 .67299 L p .707 .577 .707 r
F P
0 g
s
.26959 .72251 m .26859 .73947 L .23674 .73901 L p .707 .577 .707 r
F P
0 g
s
.80832 .59941 m .80717 .65402 L .82696 .64631 L p .707 .577 .707 r
F P
0 g
s
.82696 .64631 m .82811 .5917 L .80832 .59941 L p .707 .577 .707 r
F P
0 g
s
.42928 .74948 m .42928 .24759 L .4716 .24338 L p .707 .577 .707 r
F P
0 g
s
.42928 .24759 m .42928 .74948 L .39389 .757 L p .707 .577 .707 r
F P
0 g
s
.76716 .67154 m .76782 .70916 L .79657 .70576 L p .707 .577 .707 r
F P
0 g
s
.79657 .70576 m .79591 .66814 L .76716 .67154 L p .707 .577 .707 r
F P
0 g
s
.7047 .70997 m .70404 .67235 L .67583 .66969 L p .707 .577 .707 r
F P
0 g
s
.70404 .67235 m .7047 .70997 L .73617 .71061 L p .707 .577 .707 r
F P
0 g
s
.66282 .64948 m .66396 .59486 L .64621 .58597 L p .707 .577 .707 r
F P
0 g
s
.66396 .59486 m .66282 .64948 L .68792 .65632 L p .707 .577 .707 r
F P
0 g
s
.56015 .24615 m .56015 .74804 L .51669 .74477 L p .707 .577 .707 r
F P
0 g
s
.51669 .74477 m .51669 .24288 L .56015 .24615 L p .707 .577 .707 r
F P
0 g
s
.73141 .73874 m .73041 .71956 L .69945 .72074 L p .707 .577 .707 r
F P
0 g
s
.73041 .71956 m .73141 .73874 L .76326 .73696 L p .707 .577 .707 r
F P
0 g
s
.76326 .73696 m .76226 .71778 L .73041 .71956 L p .707 .577 .707 r
F P
0 g
s
.69945 .72074 m .70046 .73992 L .73141 .73874 L p .707 .577 .707 r
F P
0 g
s
.76226 .71778 m .76326 .73696 L .7929 .73475 L p .707 .577 .707 r
F P
0 g
s
.7929 .73475 m .79189 .71558 L .76226 .71778 L p .707 .577 .707 r
F P
0 g
s
.67583 .66969 m .67649 .7073 L .7047 .70997 L p .707 .577 .707 r
F P
0 g
s
.79591 .66814 m .79657 .70576 L .81958 .70074 L p .707 .577 .707 r
F P
0 g
s
.81958 .70074 m .81892 .66313 L .79591 .66814 L p .707 .577 .707 r
F P
0 g
s
.70046 .73992 m .69945 .72074 L .67243 .72121 L p .707 .577 .707 r
F P
0 g
s
.4716 .74527 m .4716 .24338 L .51669 .24288 L p .707 .577 .707 r
F P
0 g
s
.4716 .24338 m .4716 .74527 L .42928 .74948 L p .707 .577 .707 r
F P
0 g
s
.67243 .72121 m .67343 .74038 L .70046 .73992 L p .707 .577 .707 r
F P
0 g
s
.67649 .7073 m .67583 .66969 L .65366 .66526 L p .707 .577 .707 r
F P
0 g
s
.51669 .24288 m .51669 .74477 L .4716 .74527 L p .707 .577 .707 r
F P
0 g
s
.79189 .71558 m .7929 .73475 L .81741 .73234 L p .707 .577 .707 r
F P
0 g
s
.81741 .73234 m .81641 .71316 L .79189 .71558 L p .707 .577 .707 r
F P
0 g
s
.64621 .58597 m .64506 .64058 L .66282 .64948 L p .707 .577 .707 r
F P
0 g
s
.82811 .5917 m .82696 .64631 L .83802 .63686 L p .707 .577 .707 r
F P
0 g
s
.83802 .63686 m .83917 .58225 L .82811 .5917 L p .707 .577 .707 r
F P
0 g
s
.65366 .66526 m .65431 .70287 L .67649 .7073 L p .707 .577 .707 r
F P
0 g
s
.64506 .64058 m .64621 .58597 L .63753 .57589 L p .707 .577 .707 r
F P
0 g
s
.67343 .74038 m .67243 .72121 L .65198 .72091 L p .707 .577 .707 r
F P
0 g
s
.65198 .72091 m .65298 .74009 L .67343 .74038 L p .707 .577 .707 r
F P
0 g
s
.81892 .66313 m .81958 .70074 L .83462 .69461 L p .707 .577 .707 r
F P
0 g
s
.83462 .69461 m .83396 .65699 L .81892 .66313 L p .707 .577 .707 r
F P
0 g
s
.65431 .70287 m .65366 .66526 L .63968 .65949 L p .707 .577 .707 r
F P
0 g
s
.81641 .71316 m .81741 .73234 L .83441 .72996 L p .707 .577 .707 r
F P
0 g
s
.83441 .72996 m .8334 .71078 L .81641 .71316 L p .707 .577 .707 r
F P
0 g
s
.63968 .65949 m .64034 .69711 L .65431 .70287 L p .707 .577 .707 r
F P
0 g
s
.63753 .57589 m .63638 .63051 L .64506 .64058 L p .707 .577 .707 r
F P
0 g
s
.83917 .58225 m .83802 .63686 L .83927 .62659 L p .707 .577 .707 r
F P
0 g
s
.83927 .62659 m .84042 .57198 L .83917 .58225 L p .707 .577 .707 r
F P
0 g
s
.65298 .74009 m .65198 .72091 L .64011 .71989 L p .707 .577 .707 r
F P
0 g
s
.64011 .71989 m .64111 .73906 L .65298 .74009 L p .707 .577 .707 r
F P
0 g
s
.63638 .63051 m .63753 .57589 L .63878 .56563 L p .707 .577 .707 r
F P
0 g
s
.83396 .65699 m .83462 .69461 L .84021 .68795 L p .707 .577 .707 r
F P
0 g
s
.84021 .68795 m .83955 .65033 L .83396 .65699 L p .707 .577 .707 r
F P
0 g
s
.64034 .69711 m .63968 .65949 L .63527 .65296 L p .707 .577 .707 r
F P
0 g
s
.8334 .71078 m .83441 .72996 L .84222 .72783 L p .707 .577 .707 r
F P
0 g
s
.84222 .72783 m .84122 .70865 L .8334 .71078 L p .707 .577 .707 r
F P
0 g
s
.63527 .65296 m .63592 .69057 L .64034 .69711 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63878 .56563 m .63764 .62024 L .63638 .63051 L p .707 .577 .707 r
F P
0 g
s
.84042 .57198 m .83927 .62659 L .8306 .61652 L p .707 .577 .707 r
F P
0 g
s
.8306 .61652 m .83175 .56191 L .84042 .57198 L p .707 .577 .707 r
F P
0 g
s
.64111 .73906 m .64011 .71989 L .63798 .71823 L p .707 .577 .707 r
F P
0 g
s
.63798 .71823 m .63898 .73741 L .64111 .73906 L p .707 .577 .707 r
F P
0 g
s
.63764 .62024 m .63878 .56563 L .64985 .55618 L p .707 .577 .707 r
F P
0 g
s
.83955 .65033 m .84021 .68795 L .83579 .68141 L p .707 .577 .707 r
F P
0 g
s
.83579 .68141 m .83514 .6438 L .83955 .65033 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63592 .69057 m .63527 .65296 L .64085 .6463 L p .707 .577 .707 r
F P
0 g
s
.84122 .70865 m .84222 .72783 L .84008 .72617 L p .707 .577 .707 r
F P
0 g
s
.84008 .72617 m .83908 .707 L .84122 .70865 L p .707 .577 .707 r
F P
0 g
s
.40363 .61993 m .40648 .56415 L .37458 .56231 L p .707 .577 .707 r
F P
0 g
s
.40648 .56415 m .40363 .61993 L .43437 .61922 L p .707 .577 .707 r
F P
0 g
s
.43437 .61922 m .43722 .56345 L .40648 .56415 L p .707 .577 .707 r
F P
0 g
s
.37173 .61808 m .37458 .56231 L .34463 .55809 L p .707 .577 .707 r
F P
0 g
s
.37458 .56231 m .37173 .61808 L .40363 .61993 L p .707 .577 .707 r
F P
0 g
s
.64085 .6463 m .64151 .68391 L .63592 .69057 L p .707 .577 .707 r
F P
0 g
s
.64985 .55618 m .6487 .61079 L .63764 .62024 L p .707 .577 .707 r
F P
0 g
s
.43722 .56345 m .43437 .61922 L .46092 .61603 L p .707 .577 .707 r
F P
0 g
s
.46092 .61603 m .46377 .56025 L .43722 .56345 L p .707 .577 .707 r
F P
0 g
s
.83175 .56191 m .8306 .61652 L .81284 .60762 L p .707 .577 .707 r
F P
0 g
s
.81284 .60762 m .81399 .55301 L .83175 .56191 L p .707 .577 .707 r
F P
0 g
s
.34178 .61386 m .34463 .55809 L .31957 .55191 L p .707 .577 .707 r
F P
0 g
s
.34463 .55809 m .34178 .61386 L .37173 .61808 L p .707 .577 .707 r
F P
0 g
s
.6487 .61079 m .64985 .55618 L .66963 .54846 L p .707 .577 .707 r
F P
0 g
s
.63898 .73741 m .63798 .71823 L .64579 .7161 L p .707 .577 .707 r
F P
0 g
s
.64579 .7161 m .64679 .73528 L .63898 .73741 L p .707 .577 .707 r
F P
0 g
s
.3905 .68298 m .38869 .6461 L .35726 .64594 L p .707 .577 .707 r
F P
0 g
s
.38869 .6461 m .3905 .68298 L .42213 .68032 L p .707 .577 .707 r
F P
0 g
s
.42213 .68032 m .42032 .64344 L .38869 .6461 L p .707 .577 .707 r
F P
0 g
s
.83514 .6438 m .83579 .68141 L .82182 .67565 L p .707 .577 .707 r
F P
0 g
s
.82182 .67565 m .82116 .63804 L .83514 .6438 L p .707 .577 .707 r
F P
0 g
s
.42032 .64344 m .42213 .68032 L .45085 .6751 L p .707 .577 .707 r
F P
0 g
s
.45085 .6751 m .44905 .63823 L .42032 .64344 L p .707 .577 .707 r
F P
0 g
s
.31957 .55191 m .31672 .60768 L .34178 .61386 L p .707 .577 .707 r
F P
0 g
s
.46377 .56025 m .46092 .61603 L .4807 .61067 L p .707 .577 .707 r
F P
0 g
s
.4807 .61067 m .48356 .55489 L .46377 .56025 L p .707 .577 .707 r
F P
0 g
s
.35906 .68282 m .35726 .64594 L .32909 .64298 L p .707 .577 .707 r
F P
0 g
s
.35726 .64594 m .35906 .68282 L .3905 .68298 L p .707 .577 .707 r
F P
0 g
s
.64151 .68391 m .64085 .6463 L .65589 .64016 L p .707 .577 .707 r
F P
0 g
s
.31672 .60768 m .31957 .55191 L .30185 .54437 L p .707 .577 .707 r
F P
0 g
s
.83908 .707 m .84008 .72617 L .82821 .72515 L p .707 .577 .707 r
F P
0 g
s
.82821 .72515 m .82721 .70597 L .83908 .707 L p .707 .577 .707 r
F P
0 g
s
.66963 .54846 m .66848 .60307 L .6487 .61079 L p .707 .577 .707 r
F P
0 g
s
.81399 .55301 m .81284 .60762 L .78774 .60077 L p .707 .577 .707 r
F P
0 g
s
.78774 .60077 m .78889 .54616 L .81399 .55301 L p .707 .577 .707 r
F P
0 g
s
.65589 .64016 m .65655 .67778 L .64151 .68391 L p .707 .577 .707 r
F P
0 g
s
.32909 .64298 m .33089 .67986 L .35906 .68282 L p .707 .577 .707 r
F P
0 g
s
.44905 .63823 m .45085 .6751 L .47386 .66784 L p .707 .577 .707 r
F P
0 g
s
.47386 .66784 m .47206 .63096 L .44905 .63823 L p .707 .577 .707 r
F P
0 g
s
.66848 .60307 m .66963 .54846 L .69621 .54324 L p .707 .577 .707 r
F P
0 g
s
.38853 .72754 m .3856 .70942 L .35504 .71145 L p .707 .577 .707 r
F P
0 g
s
.3856 .70942 m .38853 .72754 L .42007 .72236 L p .707 .577 .707 r
F P
0 g
s
.42007 .72236 m .41714 .70424 L .3856 .70942 L p .707 .577 .707 r
F P
0 g
s
.33089 .67986 m .32909 .64298 L .30695 .63751 L p .707 .577 .707 r
F P
0 g
s
.41714 .70424 m .42007 .72236 L .4495 .71452 L p .707 .577 .707 r
F P
0 g
s
.4495 .71452 m .44658 .6964 L .41714 .70424 L p .707 .577 .707 r
F P
0 g
s
.30185 .54437 m .299 .60015 L .31672 .60768 L p .707 .577 .707 r
F P
0 g
s
.35504 .71145 m .35796 .72957 L .38853 .72754 L p .707 .577 .707 r
F P
0 g
s
.64679 .73528 m .64579 .7161 L .66278 .71372 L p .707 .577 .707 r
F P
0 g
s
.66278 .71372 m .66379 .73289 L .64679 .73528 L p .707 .577 .707 r
F P
0 g
s
.35796 .72957 m .35504 .71145 L .32845 .71012 L p .707 .577 .707 r
F P
0 g
s
.48356 .55489 m .4807 .61067 L .49177 .60366 L p .707 .577 .707 r
F P
0 g
s
.49177 .60366 m .49462 .54788 L .48356 .55489 L p .707 .577 .707 r
F P
0 g
s
.44658 .6964 m .4495 .71452 L .47395 .7048 L p .707 .577 .707 r
F P
0 g
s
.47395 .7048 m .47102 .68669 L .44658 .6964 L p .707 .577 .707 r
F P
0 g
s
.30695 .63751 m .30876 .67439 L .33089 .67986 L p .707 .577 .707 r
F P
0 g
s
.82116 .63804 m .82182 .67565 L .79964 .67122 L p .707 .577 .707 r
F P
0 g
s
.79964 .67122 m .79898 .6336 L .82116 .63804 L p .707 .577 .707 r
F P
0 g
s
.78889 .54616 m .78774 .60077 L .75775 .59665 L p .707 .577 .707 r
F P
0 g
s
.75775 .59665 m .7589 .54203 L .78889 .54616 L p .707 .577 .707 r
F P
0 g
s
.299 .60015 m .30185 .54437 L .2932 .53622 L p .707 .577 .707 r
F P
0 g
s
.65655 .67778 m .65589 .64016 L .67891 .63515 L p .707 .577 .707 r
F P
0 g
s
.32845 .71012 m .33137 .72824 L .35796 .72957 L p .707 .577 .707 r
F P
0 g
s
.69506 .59785 m .69621 .54324 L .72697 .54103 L p .707 .577 .707 r
F P
0 g
s
.69621 .54324 m .69506 .59785 L .66848 .60307 L p .707 .577 .707 r
F P
0 g
s
.47206 .63096 m .47386 .66784 L .48891 .65924 L p .707 .577 .707 r
F P
0 g
s
.48891 .65924 m .4871 .62237 L .47206 .63096 L p .707 .577 .707 r
F P
0 g
s
.82721 .70597 m .82821 .72515 L .80776 .72485 L p .707 .577 .707 r
F P
0 g
s
.80776 .72485 m .80676 .70568 L .82721 .70597 L p .707 .577 .707 r
F P
0 g
s
.30876 .67439 m .30695 .63751 L .29301 .63006 L p .707 .577 .707 r
F P
0 g
s
.67891 .63515 m .67957 .67276 L .65655 .67778 L p .707 .577 .707 r
F P
0 g
s
.7589 .54203 m .75775 .59665 L .72582 .59564 L p .707 .577 .707 r
F P
0 g
s
.72582 .59564 m .72697 .54103 L .7589 .54203 L p .707 .577 .707 r
F P
0 g
s
.72697 .54103 m .72582 .59564 L .69506 .59785 L p .707 .577 .707 r
F P
0 g
s
.33137 .72824 m .32845 .71012 L .30843 .70556 L p .707 .577 .707 r
F P
0 g
s
.47102 .68669 m .47395 .7048 L .49101 .69415 L p .707 .577 .707 r
F P
0 g
s
.49101 .69415 m .48809 .67604 L .47102 .68669 L p .707 .577 .707 r
F P
0 g
s
.2932 .53622 m .29035 .59199 L .299 .60015 L p .707 .577 .707 r
F P
0 g
s
.30843 .70556 m .31136 .72368 L .33137 .72824 L p .707 .577 .707 r
F P
0 g
s
.29301 .63006 m .29481 .66694 L .30876 .67439 L p .707 .577 .707 r
F P
0 g
s
.79898 .6336 m .79964 .67122 L .77144 .66855 L p .707 .577 .707 r
F P
0 g
s
.77144 .66855 m .77078 .63094 L .79898 .6336 L p .707 .577 .707 r
F P
0 g
s
.66379 .73289 m .66278 .71372 L .6873 .71131 L p .707 .577 .707 r
F P
0 g
s
.6873 .71131 m .6883 .73048 L .66379 .73289 L p .707 .577 .707 r
F P
0 g
s
.67957 .67276 m .67891 .63515 L .70765 .63175 L p .707 .577 .707 r
F P
0 g
s
.49462 .54788 m .49177 .60366 L .49304 .59569 L p .707 .577 .707 r
F P
0 g
s
.49304 .59569 m .49589 .53991 L .49462 .54788 L p .707 .577 .707 r
F P
0 g
s
.80676 .70568 m .80776 .72485 L .78074 .72532 L p .707 .577 .707 r
F P
0 g
s
.78074 .72532 m .77974 .70614 L .80676 .70568 L p .707 .577 .707 r
F P
0 g
s
.29035 .59199 m .2932 .53622 L .29447 .52825 L p .707 .577 .707 r
F P
0 g
s
.4871 .62237 m .48891 .65924 L .49451 .65015 L p .707 .577 .707 r
F P
0 g
s
.49451 .65015 m .49271 .61327 L .4871 .62237 L p .707 .577 .707 r
F P
0 g
s
.70765 .63175 m .70831 .66936 L .67957 .67276 L p .707 .577 .707 r
F P
0 g
s
.77078 .63094 m .77144 .66855 L .73997 .66791 L p .707 .577 .707 r
F P
0 g
s
.73997 .66791 m .73931 .6303 L .77078 .63094 L p .707 .577 .707 r
F P
0 g
s
.70831 .66936 m .70765 .63175 L .73931 .6303 L p .707 .577 .707 r
F P
0 g
s
.29481 .66694 m .29301 .63006 L .28862 .62136 L p .707 .577 .707 r
F P
0 g
s
.31136 .72368 m .30843 .70556 L .29695 .69823 L p .707 .577 .707 r
F P
0 g
s
.48809 .67604 m .49101 .69415 L .49903 .68361 L p .707 .577 .707 r
F P
0 g
s
.49903 .68361 m .4961 .6655 L .48809 .67604 L p .707 .577 .707 r
F P
0 g
s
.73931 .6303 m .73997 .66791 L .70831 .66936 L p .707 .577 .707 r
F P
0 g
s
.6883 .73048 m .6873 .71131 L .71693 .7091 L p .707 .577 .707 r
F P
0 g
s
.71693 .7091 m .71793 .72828 L .6883 .73048 L p .707 .577 .707 r
F P
0 g
s
.29695 .69823 m .29987 .71635 L .31136 .72368 L p .707 .577 .707 r
F P
0 g
s
.29447 .52825 m .29162 .58402 L .29035 .59199 L p .707 .577 .707 r
F P
0 g
s
.77974 .70614 m .78074 .72532 L .74979 .7265 L p .707 .577 .707 r
F P
0 g
s
.74979 .7265 m .74878 .70732 L .77974 .70614 L p .707 .577 .707 r
F P
0 g
s
.28862 .62136 m .29043 .65824 L .29481 .66694 L p .707 .577 .707 r
F P
0 g
s
.71793 .72828 m .71693 .7091 L .74878 .70732 L p .707 .577 .707 r
F P
0 g
s
.74878 .70732 m .74979 .7265 L .71793 .72828 L p .707 .577 .707 r
F P
0 g
s
.49589 .53991 m .49304 .59569 L .48439 .58753 L p .707 .577 .707 r
F P
0 g
s
.48439 .58753 m .48724 .53176 L .49589 .53991 L p .707 .577 .707 r
F P
0 g
s
.49271 .61327 m .49451 .65015 L .49013 .64145 L p .707 .577 .707 r
F P
0 g
s
.49013 .64145 m .48832 .60458 L .49271 .61327 L p .707 .577 .707 r
F P
0 g
s
.29162 .58402 m .29447 .52825 L .30553 .52124 L p .707 .577 .707 r
F P
0 g
s
.29987 .71635 m .29695 .69823 L .29512 .68883 L p .708 .578 .707 r
F P
0 g
s
.29043 .65824 m .28862 .62136 L .29423 .61227 L p .707 .577 .707 r
F P
0 g
s
.4961 .6655 m .49903 .68361 L .4972 .67422 L p .708 .578 .707 r
F P
0 g
s
.4972 .67422 m .49428 .6561 L .4961 .6655 L p .708 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29512 .68883 m .29805 .70695 L .29987 .71635 L p .708 .578 .707 r
F P
0 g
s
.30553 .52124 m .30268 .57701 L .29162 .58402 L p .707 .577 .707 r
F P
0 g
s
.29423 .61227 m .29603 .64915 L .29043 .65824 L p .707 .577 .707 r
F P
0 g
s
.48724 .53176 m .48439 .58753 L .46667 .58 L p .707 .577 .707 r
F P
0 g
s
.46667 .58 m .46952 .52422 L .48724 .53176 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30268 .57701 m .30553 .52124 L .32531 .51587 L p .707 .577 .707 r
F P
0 g
s
.48832 .60458 m .49013 .64145 L .47618 .63401 L p .707 .577 .707 r
F P
0 g
s
.47618 .63401 m .47438 .59713 L .48832 .60458 L p .707 .577 .707 r
F P
0 g
s
.29805 .70695 m .29512 .68883 L .30314 .67829 L p .707 .577 .707 r
F P
0 g
s
.29603 .64915 m .29423 .61227 L .30927 .60367 L p .707 .577 .707 r
F P
0 g
s
.49428 .6561 m .4972 .67422 L .48572 .66688 L p .707 .577 .707 r
F P
0 g
s
.48572 .66688 m .48279 .64876 L .49428 .6561 L p .707 .577 .707 r
F P
0 g
s
.30314 .67829 m .30606 .69641 L .29805 .70695 L p .707 .577 .707 r
F P
0 g
s
.32531 .51587 m .32246 .57165 L .30268 .57701 L p .707 .577 .707 r
F P
0 g
s
.30927 .60367 m .31107 .64055 L .29603 .64915 L p .707 .577 .707 r
F P
0 g
s
.46952 .52422 m .46667 .58 L .44161 .57382 L p .707 .577 .707 r
F P
0 g
s
.44161 .57382 m .44446 .51804 L .46952 .52422 L p .707 .577 .707 r
F P
0 g
s
.32246 .57165 m .32531 .51587 L .35187 .51268 L p .707 .577 .707 r
F P
0 g
s
.47438 .59713 m .47618 .63401 L .45404 .62853 L p .707 .577 .707 r
F P
0 g
s
.45404 .62853 m .45224 .59166 L .47438 .59713 L p .707 .577 .707 r
F P
0 g
s
.31107 .64055 m .30927 .60367 L .33228 .59641 L p .707 .577 .707 r
F P
0 g
s
.30606 .69641 m .30314 .67829 L .3202 .66764 L p .707 .577 .707 r
F P
0 g
s
.48279 .64876 m .48572 .66688 L .4657 .66232 L p .707 .577 .707 r
F P
0 g
s
.4657 .66232 m .46278 .64421 L .48279 .64876 L p .707 .577 .707 r
F P
0 g
s
.35187 .51268 m .34902 .56846 L .32246 .57165 L p .707 .577 .707 r
F P
0 g
s
.44446 .51804 m .44161 .57382 L .41166 .5696 L p .707 .577 .707 r
F P
0 g
s
.41166 .5696 m .41451 .51382 L .44446 .51804 L p .707 .577 .707 r
F P
0 g
s
.3202 .66764 m .32312 .68576 L .30606 .69641 L p .707 .577 .707 r
F P
0 g
s
.34902 .56846 m .35187 .51268 L .3826 .51198 L p .707 .577 .707 r
F P
0 g
s
.33228 .59641 m .33408 .63329 L .31107 .64055 L p .707 .577 .707 r
F P
0 g
s
.41451 .51382 m .41166 .5696 L .37975 .56775 L p .707 .577 .707 r
F P
0 g
s
.37975 .56775 m .3826 .51198 L .41451 .51382 L p .707 .577 .707 r
F P
0 g
s
.45224 .59166 m .45404 .62853 L .42588 .62557 L p .707 .577 .707 r
F P
0 g
s
.42588 .62557 m .42407 .5887 L .45224 .59166 L p .707 .577 .707 r
F P
0 g
s
.3826 .51198 m .37975 .56775 L .34902 .56846 L p .707 .577 .707 r
F P
0 g
s
.33408 .63329 m .33228 .59641 L .36101 .5912 L p .707 .577 .707 r
F P
0 g
s
.32312 .68576 m .3202 .66764 L .34465 .65792 L p .707 .577 .707 r
F P
0 g
s
.46278 .64421 m .4657 .66232 L .43911 .661 L p .707 .577 .707 r
F P
0 g
s
.43911 .661 m .43619 .64288 L .46278 .64421 L p .707 .577 .707 r
F P
0 g
s
.36101 .5912 m .36281 .62807 L .33408 .63329 L p .707 .577 .707 r
F P
0 g
s
.42407 .5887 m .42588 .62557 L .39444 .62541 L p .707 .577 .707 r
F P
0 g
s
.39444 .62541 m .39264 .58854 L .42407 .5887 L p .707 .577 .707 r
F P
0 g
s
.34465 .65792 m .34757 .67604 L .32312 .68576 L p .707 .577 .707 r
F P
0 g
s
.36281 .62807 m .36101 .5912 L .39264 .58854 L p .707 .577 .707 r
F P
0 g
s
.39264 .58854 m .39444 .62541 L .36281 .62807 L p .707 .577 .707 r
F P
0 g
s
.34757 .67604 m .34465 .65792 L .37408 .65009 L p .707 .577 .707 r
F P
0 g
s
.43619 .64288 m .43911 .661 L .40855 .66302 L p .707 .577 .707 r
F P
0 g
s
.40855 .66302 m .40562 .64491 L .43619 .64288 L p .707 .577 .707 r
F P
0 g
s
.37408 .65009 m .377 .66821 L .34757 .67604 L p .707 .577 .707 r
F P
0 g
s
.377 .66821 m .37408 .65009 L .40562 .64491 L p .707 .577 .707 r
F P
0 g
s
.40562 .64491 m .40855 .66302 L .377 .66821 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo6000Q7oo001hOol90005FUH00`00FUIJEP09FUH00`00FUIJEP04FUH;001iOol0079oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009JEPL0079oo`00KWoo
100025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001QOol@0009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005]oo`H0
00=JEP03001JEUYF00EJEP03001JEUYF009JEPX000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00F7oo0`0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001FOol20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000]JEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00Dgoo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol005=oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001COol01000FUIJEP001EYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF
00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool04Goo2@00BWoo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol02Goo200015YF
00<005YFFUH00UYF2@00@Goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol01Goo
10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>goo001COol01000FUIJ
EP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol00goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YF00000`00=goo001COol01000FUIJEP0015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00@0
07ooOomoo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<003Aoo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP04001oo`00
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH01000FUH00000<Woo001BOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH0
00EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04
001JEUYFFUH2000`Ool0059oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP8002moo`00DWoo00D005YFFUIJEP0000AJEP03001JEUYF009JEQ0000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF0P00;goo001BOol01@00FUIJEUYF00000eYF1P0000=JEP00FUH01eYF00<005YFFUH00eYF
2@0015YF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH0000^Ool0059oo`06001JEUYFFUH005YF0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF20000eYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000^Ool0059oo`04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40004FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0002ioo`00DWoo00@005YF000000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH01000FUIJEP00
1EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0002ioo`00DWoo0P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000^Ool0059oo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUH0000A0006FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000;Woo001BOol01000FUIJEP0015YF
00<005YFFUH015YF00<005YF00001`0015YF00<005YFFUH01UYF00@005YFFUIJEPP000AJEP03001J
EP00008000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000^Ool005=oo`<000AJEP03001JEUYF00H0
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF
FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF
00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000;Woo001EOol20002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00@005YF
FUIJEPP000Ioo`D000Ioo`H000IJEP03001JEUYF009JEP03001JEP0002ioo`00Egoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00`001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P00
0UYF00<005YFFUH00UYF2`0027oo1@001Goo2`000UYF00<005YFFUH00UYF00<005YF0000;Woo001F
Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00P000UYF00<005YF00000P001UYF00<005YFFUH00UYF4P0015YF00<005YFFUH015YF
0`0015YF00<005YF0000;Woo000mOolI00000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YF
FUH00P000UYF00<005YF0000;Woo000iOol400000eYF001JEP06FUH00`00FUIJEP06FUH01@00FUIJ
EUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH300000eYF
001oo`0]Ool003Aoo`D000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000=JEP00Ool0;Goo000`Ool40002FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool002ioo`<000EJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP04001JEUYFFUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUH00000;Woo000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF1`000eYF0`00
25YF00<005YFFUH01P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03
001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
000]Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00P0015YF00<005YFFUH00eYF00<005YFFUH01@000UYF00<005YFFUH00eYF1@001eYF00<005YF
FUH01UYF0`0000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEP0001T000IJEP03001J
EUYF00=JEP04001JEUYF000^Ool002eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF009JEP@000=JEP80009JEP03001J
EUYF00=JEPD000MJEP03001JEUYF00AJEP@00003FUH0000000=JEP8000EJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH01P0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL000EJEP04001JEUYF000^Ool002eoo`04001J
EUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=J
EP03001JEP000080009JEP03001JEUYF009JEP80009JEP03001JEUYF00=JEPD000MJEP03001JEP00
00@000EJEP05001JEP00001JEP020005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20004FUH300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP0400001EYF001JEUYF0000;Woo000]Ool01000FUIJEP001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001JEP0000=JEPT000=JEP80009J
EP03001JEUYF00AJEP<00003FUH0000000/000IJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH5000_Ool002eoo`04001JEUYF
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01P00FUH005YF001JEP8000EJ
EP04001JEUYFFUHG0003FUH01000FUIJEUYF20000eYF0`001EYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;goo000]
Ool01000FUIJEP001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF001J
EP800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH60004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP0500000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00D0
05YFFUIJEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05001JEUYFFUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH00eYF0`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00EJEP00FUIJ
EP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000003FUH00`00
FUIJEP03FUH00`00FUIJEP030007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH70004FUH00`00FUIJ
EP03FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05FUH005YFFUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH000000eYF00<005YFFUH00eYF
0`0000=JEP00FUH025YF00<005YFFUH015YF1`001eYF1`000eYF00@005YF000000AJEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00;Goo00EJEP00FUIJEP0000AJEP03001JEUYF00AJEQL000=JEP04001JEUYF
FUH20004FUH00`00FUIJEP07FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH6
0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`05FUH005YFFUH00004FUH00`00FUIJ
EP040007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP030006FUH00`00FUIJEP04
FUH500000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP03FUH30004FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00AJEP03001JEUYF009JEPP0009oo`D00003Ool0000000d000AJEP04001JEUYFFUH2000^Ool002eo
o`05FUH005YFFUH00002FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
0002FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40004
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH000=JEP04001JEUYFFUHH0004FUH00`00FUIJEP05FUH00`00FUIJEP030000
0eYF001JEP02FUH2000^Ool002eoo`04FUH005YFFUH300000eYF001JEP05FUH00`00FUIJEP0A0006
FUH00`00FUIJEP02FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP040008FUH01@00FUIJEUYF00000UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH01eYF
00<005YFFUH01EYF00H005YFFUH005YF0003FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH2000^Ool002eoo`04FUH000000004FUH0
1000FUIJEUYF1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF00@005YFFUIJEP<000AJ
EP03001JEUYF00IJEP<0009JEPL000]JEP03001JEP000080009JEP03001JEUYF009JEP03001JEUYF
00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH00P001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH01000;Woo
000]Ool015YF001JEP0015YF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF000015YF00@005YF000000=JEQ8000IJEP03001JEUYF00UJEP80009JEP04001JEUYF0004FUH0
0`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P0000=JEP00FUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF0P00;Woo000]Ool01000FUIJEP000UYF0P001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH000AJEP800004FUH000000002FUH00`00FUH00002
FUH00`00FUIJEP03FUH50007FUH00`00FUIJEP07FUH20005FUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000^Ool002eoo`05001JEUYF001JEP020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01@00FUIJEUYF00000UYF00<005YF000015YF0`0000EJEP00FUIJEP0000EJEPD000MJEP03
001JEUYF00EJEP800003FUH005YF00AJEP8000EJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP06001JEUYF001JEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Goo
000^Ool400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF0`000UYF00<005YFFUH00eYF10000UYF00<005YFFUH015YF0`0025YF00<005YFFUH00eYF
0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002moo`05001J
EUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
15YF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF
00<000IJEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000aOol002ioo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00AJEP03001JEUYF
00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH400000eYF001JEP06FUH30009
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF1000<goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH300001UYF00000000FUH000IJEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJ
EP070005FUH00`00FUIJEP04FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUHD000`Ool002eoo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00004FUH005YFFUH700001EYF001JEUYF00000UYF2P0015YF00<005YF
FUH01UYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000IJEQX000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008002eoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF0`0000=JEP00FUH015YF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF3P000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH90008Ool70002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEUYF009JEPH001Moo`@000AJEP03001J
EUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH30004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000=JEP03001JEP00008000Qooa4000Moo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPP000]JEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00003FUH20005Ool60003FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60003Ool300000eYF001JEP05FUH00`00FUIJEP02FUH90007FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEQl002eoo`00;Goo00@0
05YF001JEP<0009oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0004Ool=0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP04001JEUYFFUHA0007FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000^Ool002eoo`07001JEP00001JEP00FUH0
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000Aoo`80
0004FUH005YF0002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00009JEPH0
00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPh0039oo`00;Goo0P000eYF0`00
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUIJEP80009JEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH50005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90010Ool002eoo`80009JEP800003FUH005YF00AJEP03
001JEUYF009JEQ8000AJEP03001JEUYF00EJEP80009JEP05001JEUYFFUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHN0019Ool002eoo`800005FUH005YFFUH00005FUH60002
FUH00`00FUIJEP02FUHA0006FUH00`00FUH000020003FUH01000FUIJEP001UYF00<005YFFUH025YF
00<005YFFUH01eYF5@001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8005=oo`00;Goo0`000eYF00<005YF000010001eYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF009JEP05001JEUYF
FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP08FUH01000FUIJEUYF1P001EYF00<005YFFUH02UYF
00<005YFFUH02@001eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005=oo`00;Woo0P000eYF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00FUH015YF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00IJEPH000]JEP03001JEUYF00YJEP03001JEUYF00UJEPD0009JEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000DWoo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20005FUH200001EYF001JEUYF00001UYF00<005YFFUH01P001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF10001UYF00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0001BOol002eoo`04001JEP00FUH20005
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000
0eYF00@005YF0000009JEP03001JEUYF00=JEPD000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP8000AJEP03001JEUYF009JEP8000IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF0000DWoo000]Ool00`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P0000EJEP00FUIJEP00009JEP04001J
EUYFFUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH400000eYF001JEP03FUH00`00Ool000030002FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP00059oo`00;Goo00<005YF00000Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00D005YFFUH005YF008000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYFFUH20004FUH00`00Oomoo`03Ool40004FUH01`00FUIJEUYF001JEP00059oo`00;Goo
00=JEP00Ool017oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000Aoo`00FUH0009JEP<000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP04001o
ogooOol900000eYF001JEP02FUH2001COol002aoo`8000Uoo`<000IJEP03001JEUYF00EJEP<000MJ
EP03001JEUYF00IJEP03001JEP00008000Aoo`800005FUH005YFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH7
0003FUH00`00FUIJEP03FUH20003FUH2001COol002aoo`8000aoo`@0009JEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPH000Qoo`8000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
0006FUH00`00FUIJEP04FUH300000eYF0000001COol002aoo`<000mooaT000ioo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP03
001COol002aoo`800003FUH007oo01Ioo`D001Uoo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP04001JEUYF0006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol002aoo`80009J
EP03001oogoo01Eoo`<001Yoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2001COol002eoo`05001JEUYFFUH0000bOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030004FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH2001COol002eoo`04001JEUYFFUH2000aOol00`00FUH00003FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH20002FUH00`00FUH000040005FUH00`00FUIJEP02FUH00`00Oomoo`1BOol002io
o`05001JEUYF001JEP02000]Ool300001UYF00000000FUH000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP03
001JEUYF00=JEP8000AJEP03001JEUYF00<005Aoo`00;Woo00<005YF000015YF00<007ooOol0:7oo
0P000UYF0P000goo0P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF00<005YFFUH01EYF0`0000=JEP000000
0P00Egoo000_Ool20005FUH2000VOol20004FUH20004Ool20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P0015YF00<0
05YFFUH01EYF00<005YFFUH00P00FWoo000`Ool00`00FUIJEP03FUH00`00FUH00003000POol20000
0eYF001JEP03FUH00`00Oomoo`05Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000090006FUH00`00FUIJEP02FUH2001H
Ool0035oo`8000=JEP03001JEUYF00=JEPD001Uoo`8000=JEP03001JEUYF009JEP03001oogoo00Uo
o`D000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP@000Yo
o`8000AJEP03001JEUYF00=JEP<005Ioo`00<goo00@005YFFUH000MJEP03001JEUYF00@0011oo`D0
00EJEP03001JEUYF0080015oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00T000aoo`<00003FUH005YF00AJEP04001JEUYF001EOol003Aoo`<000MJEP03001J
EUYF00AJEQ0000=JEP03001JEUYF00AJEP<001Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJ
EPP000Aoo`D000moo`<000=JEP05001JEUYFFUH0001EOol003Ioo`8000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002=ooaX00003FUH00000008000Moo`D0
019oo`800003FUH005YF009JEP8005Aoo`00>7oo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEP8003Aoo`8000=JEP03001JEUYF00IJEP03001JEP0000<000Ao
o`<001Eoo`8000=JEP8005Aoo`00?7oo1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
000003Qoo`800003FUH005YF00MJEP03001JEUYF00=JEPL001Moo`03001JEUYF008005Aoo`00@Goo
10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00?7oo0`001UYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0027oo1P0000=JEP0000000P00E7oo0015Ool@0014Ool40002FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP02FUH2001EOol009eoo`D000IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000EGoo002ROol4
0002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0
001EOol00:Ioo`L000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8005Ioo`00
[Goo200015YF00<005YFFUH015YF00<005YFFUH00`00Egoo002eOol>001JOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]15\[InvisibleSpace]"     "\
\[InvisibleSpace]6.308757524070883`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 15, "     ", 6.3087575240708826, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70324 m .59613 .64766 L .56496 .64576 L p .707 .577 .707 r
F P
0 g
s
.59613 .64766 m .59613 .70324 L .62796 .70247 L p .707 .577 .707 r
F P
0 g
s
.62796 .70247 m .62796 .64688 L .59613 .64766 L p .707 .577 .707 r
F P
0 g
s
.62796 .64688 m .62796 .70247 L .65734 .69909 L p .707 .577 .707 r
F P
0 g
s
.65734 .69909 m .65734 .6435 L .62796 .64688 L p .707 .577 .707 r
F P
0 g
s
.56496 .70134 m .56496 .64576 L .5375 .64137 L p .707 .577 .707 r
F P
0 g
s
.56496 .64576 m .56496 .70134 L .59613 .70324 L p .707 .577 .707 r
F P
0 g
s
.65734 .6435 m .65734 .69909 L .6814 .69344 L p .707 .577 .707 r
F P
0 g
s
.6814 .69344 m .6814 .63785 L .65734 .6435 L p .707 .577 .707 r
F P
0 g
s
.59613 .74149 m .59613 .70444 L .56496 .70254 L p .707 .577 .707 r
F P
0 g
s
.59613 .70444 m .59613 .74149 L .62796 .74072 L p .707 .577 .707 r
F P
0 g
s
.62796 .74072 m .62796 .70366 L .59613 .70444 L p .707 .577 .707 r
F P
0 g
s
.62796 .70366 m .62796 .74072 L .65734 .73734 L p .707 .577 .707 r
F P
0 g
s
.65734 .73734 m .65734 .70028 L .62796 .70366 L p .707 .577 .707 r
F P
0 g
s
.5375 .64137 m .5375 .69695 L .56496 .70134 L p .707 .577 .707 r
F P
0 g
s
.5375 .69695 m .5375 .64137 L .51644 .63491 L p .707 .577 .707 r
F P
0 g
s
.56496 .73959 m .56496 .70254 L .5375 .69815 L p .707 .577 .707 r
F P
0 g
s
.56496 .70254 m .56496 .73959 L .59613 .74149 L p .707 .577 .707 r
F P
0 g
s
.65734 .70028 m .65734 .73734 L .6814 .73169 L p .707 .577 .707 r
F P
0 g
s
.6814 .73169 m .6814 .69463 L .65734 .70028 L p .707 .577 .707 r
F P
0 g
s
.5375 .69815 m .5375 .7352 L .56496 .73959 L p .707 .577 .707 r
F P
0 g
s
.6814 .63785 m .6814 .69344 L .69777 .68607 L p .707 .577 .707 r
F P
0 g
s
.69777 .68607 m .69777 .63049 L .6814 .63785 L p .707 .577 .707 r
F P
0 g
s
.51644 .63491 m .51644 .6905 L .5375 .69695 L p .707 .577 .707 r
F P
0 g
s
.5375 .7352 m .5375 .69815 L .51644 .69169 L p .707 .577 .707 r
F P
0 g
s
.59613 .82144 m .59613 .80292 L .56496 .80102 L p .707 .577 .707 r
F P
0 g
s
.59613 .80292 m .59613 .82144 L .62796 .82067 L p .707 .577 .707 r
F P
0 g
s
.62796 .82067 m .62796 .80214 L .59613 .80292 L p .707 .577 .707 r
F P
0 g
s
.51644 .6905 m .51644 .63491 L .50385 .62703 L p .707 .577 .707 r
F P
0 g
s
.62796 .80214 m .62796 .82067 L .65735 .81729 L p .707 .577 .707 r
F P
0 g
s
.65735 .81729 m .65735 .79876 L .62796 .80214 L p .707 .577 .707 r
F P
0 g
s
.56496 .80102 m .56496 .81954 L .59613 .82144 L p .707 .577 .707 r
F P
0 g
s
.51644 .69169 m .51644 .72875 L .5375 .7352 L p .707 .577 .707 r
F P
0 g
s
.56496 .81954 m .56496 .80102 L .5375 .79662 L p .707 .577 .707 r
F P
0 g
s
.6814 .69463 m .6814 .73169 L .69777 .72432 L p .707 .577 .707 r
F P
0 g
s
.69777 .72432 m .69777 .68727 L .6814 .69463 L p .707 .577 .707 r
F P
0 g
s
.5375 .79662 m .5375 .81515 L .56496 .81954 L p .707 .577 .707 r
F P
0 g
s
.65735 .79876 m .65735 .81729 L .6814 .81164 L p .707 .577 .707 r
F P
0 g
s
.6814 .81164 m .6814 .79311 L .65735 .79876 L p .707 .577 .707 r
F P
0 g
s
.50385 .62703 m .50385 .68261 L .51644 .6905 L p .707 .577 .707 r
F P
0 g
s
.51644 .72875 m .51644 .69169 L .50385 .68381 L p .707 .577 .707 r
F P
0 g
s
.69777 .63049 m .69777 .68607 L .70485 .6777 L p .707 .577 .707 r
F P
0 g
s
.70485 .6777 m .70485 .62212 L .69777 .63049 L p .707 .577 .707 r
F P
0 g
s
.5375 .81515 m .5375 .79662 L .51644 .79017 L p .707 .577 .707 r
F P
0 g
s
.51644 .79017 m .51644 .8087 L .5375 .81515 L p .707 .577 .707 r
F P
0 g
s
.50385 .68381 m .50385 .72086 L .51644 .72875 L p .707 .577 .707 r
F P
0 g
s
.50385 .68261 m .50385 .62703 L .50095 .61849 L p .707 .577 .707 r
F P
0 g
s
.69777 .68727 m .69777 .72432 L .70485 .71596 L p .707 .577 .707 r
F P
0 g
s
.70485 .71596 m .70485 .6789 L .69777 .68727 L p .707 .577 .707 r
F P
0 g
s
.6814 .79311 m .6814 .81164 L .69777 .80427 L p .707 .577 .707 r
F P
0 g
s
.69777 .80427 m .69777 .78574 L .6814 .79311 L p .707 .577 .707 r
F P
0 g
s
.51644 .8087 m .51644 .79017 L .50385 .78229 L p .707 .577 .707 r
F P
0 g
s
.50095 .61849 m .50095 .67407 L .50385 .68261 L p .707 .577 .707 r
F P
0 g
s
.50385 .72086 m .50385 .68381 L .50095 .67527 L p .707 .577 .707 r
F P
0 g
s
.70485 .62212 m .70485 .6777 L .70195 .66916 L p .707 .577 .707 r
F P
0 g
s
.70195 .66916 m .70195 .61358 L .70485 .62212 L p .707 .577 .707 r
F P
0 g
s
.50385 .78229 m .50385 .80081 L .51644 .8087 L p .707 .577 .707 r
F P
0 g
s
.50095 .67527 m .50095 .71232 L .50385 .72086 L p .707 .577 .707 r
F P
0 g
s
.50095 .67407 m .50095 .61849 L .50804 .61012 L p .707 .577 .707 r
F P
0 g
s
.69777 .78574 m .69777 .80427 L .70485 .79591 L p .707 .577 .707 r
F P
0 g
s
.70485 .79591 m .70485 .77738 L .69777 .78574 L p .707 .577 .707 r
F P
0 g
s
.70485 .6789 m .70485 .71596 L .70195 .70741 L p .707 .577 .707 r
F P
0 g
s
.70195 .70741 m .70195 .67036 L .70485 .6789 L p .707 .577 .707 r
F P
0 g
s
.50385 .80081 m .50385 .78229 L .50095 .77374 L p .707 .577 .707 r
F P
0 g
s
.50804 .61012 m .50804 .66571 L .50095 .67407 L p .707 .577 .707 r
F P
0 g
s
.50095 .71232 m .50095 .67527 L .50804 .6669 L p .707 .577 .707 r
F P
0 g
s
.70195 .61358 m .70195 .66916 L .68936 .66128 L p .707 .577 .707 r
F P
0 g
s
.68936 .66128 m .68936 .6057 L .70195 .61358 L p .707 .577 .707 r
F P
0 g
s
.50095 .77374 m .50095 .79227 L .50385 .80081 L p .707 .577 .707 r
F P
0 g
s
.49044 .88025 m .49044 .37836 L .44643 .37567 L p .707 .577 .707 r
F P
0 g
s
.50804 .6669 m .50804 .70396 L .50095 .71232 L p .707 .577 .707 r
F P
0 g
s
.50804 .66571 m .50804 .61012 L .5244 .60276 L p .707 .577 .707 r
F P
0 g
s
.50095 .79227 m .50095 .77374 L .50804 .76538 L p .707 .577 .707 r
F P
0 g
s
.5244 .60276 m .5244 .65834 L .50804 .66571 L p .707 .577 .707 r
F P
0 g
s
.50804 .70396 m .50804 .6669 L .5244 .65953 L p .707 .577 .707 r
F P
0 g
s
.50804 .76538 m .50804 .78391 L .50095 .79227 L p .707 .577 .707 r
F P
0 g
s
.5244 .65953 m .5244 .69659 L .50804 .70396 L p .707 .577 .707 r
F P
0 g
s
.50804 .78391 m .50804 .76538 L .5244 .75801 L p .707 .577 .707 r
F P
0 g
s
.5244 .75801 m .5244 .77654 L .50804 .78391 L p .707 .577 .707 r
F P
0 g
s
.5244 .77654 m .5244 .75801 L .54846 .75236 L p .707 .577 .707 r
F P
0 g
s
.54846 .75236 m .54846 .77089 L .5244 .77654 L p .707 .577 .707 r
F P
0 g
s
.49044 .37836 m .49044 .88025 L .53538 .87915 L p .707 .577 .707 r
F P
0 g
s
.5244 .65834 m .5244 .60276 L .54846 .59711 L p .707 .577 .707 r
F P
0 g
s
.54846 .59711 m .54846 .65269 L .5244 .65834 L p .707 .577 .707 r
F P
0 g
s
.5244 .69659 m .5244 .65953 L .54846 .65388 L p .707 .577 .707 r
F P
0 g
s
.54846 .65388 m .54846 .69094 L .5244 .69659 L p .707 .577 .707 r
F P
0 g
s
.53538 .87915 m .53538 .37726 L .49044 .37836 L p .707 .577 .707 r
F P
0 g
s
.25312 .66643 m .25312 .61085 L .22195 .60894 L p .707 .577 .707 r
F P
0 g
s
.25312 .61085 m .25312 .66643 L .28495 .66565 L p .707 .577 .707 r
F P
0 g
s
.28495 .66565 m .28495 .61007 L .25312 .61085 L p .707 .577 .707 r
F P
0 g
s
.54846 .65269 m .54846 .59711 L .57784 .59373 L p .707 .577 .707 r
F P
0 g
s
.57784 .59373 m .57784 .64931 L .54846 .65269 L p .707 .577 .707 r
F P
0 g
s
.54846 .69094 m .54846 .65388 L .57784 .6505 L p .707 .577 .707 r
F P
0 g
s
.57784 .6505 m .57784 .68756 L .54846 .69094 L p .707 .577 .707 r
F P
0 g
s
.54846 .77089 m .54846 .75236 L .57784 .74898 L p .707 .577 .707 r
F P
0 g
s
.57784 .74898 m .57784 .76751 L .54846 .77089 L p .707 .577 .707 r
F P
0 g
s
.53538 .37726 m .53538 .87915 L .57686 .87438 L p .707 .577 .707 r
F P
0 g
s
.57686 .87438 m .57686 .37249 L .53538 .37726 L p .707 .577 .707 r
F P
0 g
s
.70485 .77738 m .70485 .79591 L .70195 .78736 L p .707 .577 .707 r
F P
0 g
s
.70195 .78736 m .70195 .76884 L .70485 .77738 L p .707 .577 .707 r
F P
0 g
s
.28495 .61007 m .28495 .66565 L .31434 .66227 L p .707 .577 .707 r
F P
0 g
s
.31434 .66227 m .31434 .60669 L .28495 .61007 L p .707 .577 .707 r
F P
0 g
s
.70195 .67036 m .70195 .70741 L .68936 .69953 L p .707 .577 .707 r
F P
0 g
s
.68936 .69953 m .68936 .66247 L .70195 .67036 L p .707 .577 .707 r
F P
0 g
s
.22195 .66453 m .22195 .60894 L .19449 .60455 L p .707 .577 .707 r
F P
0 g
s
.22195 .60894 m .22195 .66453 L .25312 .66643 L p .707 .577 .707 r
F P
0 g
s
.44643 .87756 m .44643 .37567 L .40766 .36947 L p .707 .577 .707 r
F P
0 g
s
.44643 .37567 m .44643 .87756 L .49044 .88025 L p .707 .577 .707 r
F P
0 g
s
.31434 .60669 m .31434 .66227 L .33839 .65662 L p .707 .577 .707 r
F P
0 g
s
.33839 .65662 m .33839 .60104 L .31434 .60669 L p .707 .577 .707 r
F P
0 g
s
.25312 .70468 m .25312 .66762 L .22195 .66572 L p .707 .577 .707 r
F P
0 g
s
.25312 .66762 m .25312 .70468 L .28495 .7039 L p .707 .577 .707 r
F P
0 g
s
.28495 .7039 m .28495 .66685 L .25312 .66762 L p .707 .577 .707 r
F P
0 g
s
.68936 .6057 m .68936 .66128 L .66831 .65482 L p .707 .577 .707 r
F P
0 g
s
.66831 .65482 m .66831 .59924 L .68936 .6057 L p .707 .577 .707 r
F P
0 g
s
.28495 .66685 m .28495 .7039 L .31434 .70052 L p .707 .577 .707 r
F P
0 g
s
.31434 .70052 m .31434 .66347 L .28495 .66685 L p .707 .577 .707 r
F P
0 g
s
.57784 .64931 m .57784 .59373 L .60968 .59295 L p .707 .577 .707 r
F P
0 g
s
.60968 .59295 m .60968 .64853 L .57784 .64931 L p .707 .577 .707 r
F P
0 g
s
.57784 .68756 m .57784 .6505 L .60968 .64973 L p .707 .577 .707 r
F P
0 g
s
.60968 .64973 m .60968 .68678 L .57784 .68756 L p .707 .577 .707 r
F P
0 g
s
.57784 .76751 m .57784 .74898 L .60968 .74821 L p .707 .577 .707 r
F P
0 g
s
.60968 .74821 m .60968 .76673 L .57784 .76751 L p .707 .577 .707 r
F P
0 g
s
.57686 .37249 m .57686 .87438 L .61082 .8664 L p .707 .577 .707 r
F P
0 g
s
.64085 .59485 m .64085 .65043 L .60968 .64853 L p .707 .577 .707 r
F P
0 g
s
.60968 .64853 m .60968 .59295 L .64085 .59485 L p .707 .577 .707 r
F P
0 g
s
.64085 .65163 m .64085 .68868 L .60968 .68678 L p .707 .577 .707 r
F P
0 g
s
.60968 .68678 m .60968 .64973 L .64085 .65163 L p .707 .577 .707 r
F P
0 g
s
.64085 .75011 m .64085 .76863 L .60968 .76673 L p .707 .577 .707 r
F P
0 g
s
.60968 .76673 m .60968 .74821 L .64085 .75011 L p .707 .577 .707 r
F P
0 g
s
.61082 .8664 m .61082 .36451 L .57686 .37249 L p .707 .577 .707 r
F P
0 g
s
.19449 .60455 m .19449 .66013 L .22195 .66453 L p .707 .577 .707 r
F P
0 g
s
.19449 .66013 m .19449 .60455 L .17343 .5981 L p .707 .577 .707 r
F P
0 g
s
.22195 .70278 m .22195 .66572 L .19449 .66133 L p .707 .577 .707 r
F P
0 g
s
.22195 .66572 m .22195 .70278 L .25312 .70468 L p .707 .577 .707 r
F P
0 g
s
.40766 .87136 m .40766 .36947 L .37794 .36036 L p .707 .577 .707 r
F P
0 g
s
.40766 .36947 m .40766 .87136 L .44643 .87756 L p .707 .577 .707 r
F P
0 g
s
.31434 .66347 m .31434 .70052 L .33839 .69487 L p .707 .577 .707 r
F P
0 g
s
.33839 .69487 m .33839 .65782 L .31434 .66347 L p .707 .577 .707 r
F P
0 g
s
.19449 .66133 m .19449 .69839 L .22195 .70278 L p .707 .577 .707 r
F P
0 g
s
.70195 .76884 m .70195 .78736 L .68936 .77948 L p .707 .577 .707 r
F P
0 g
s
.68936 .77948 m .68936 .76095 L .70195 .76884 L p .707 .577 .707 r
F P
0 g
s
.68936 .66247 m .68936 .69953 L .66831 .69308 L p .707 .577 .707 r
F P
0 g
s
.66831 .69308 m .66831 .65602 L .68936 .66247 L p .707 .577 .707 r
F P
0 g
s
.33839 .60104 m .33839 .65662 L .35476 .64925 L p .707 .577 .707 r
F P
0 g
s
.35476 .64925 m .35476 .59367 L .33839 .60104 L p .707 .577 .707 r
F P
0 g
s
.17343 .5981 m .17343 .65368 L .19449 .66013 L p .707 .577 .707 r
F P
0 g
s
.19449 .69839 m .19449 .66133 L .17343 .65488 L p .707 .577 .707 r
F P
0 g
s
.66831 .59924 m .66831 .65482 L .64085 .65043 L p .707 .577 .707 r
F P
0 g
s
.64085 .65043 m .64085 .59485 L .66831 .59924 L p .707 .577 .707 r
F P
0 g
s
.25312 .78463 m .25312 .7661 L .22195 .7642 L p .707 .577 .707 r
F P
0 g
s
.25312 .7661 m .25312 .78463 L .28495 .78385 L p .707 .577 .707 r
F P
0 g
s
.28495 .78385 m .28495 .76532 L .25312 .7661 L p .707 .577 .707 r
F P
0 g
s
.17343 .65368 m .17343 .5981 L .16084 .59021 L p .707 .577 .707 r
F P
0 g
s
.28495 .76532 m .28495 .78385 L .31434 .78047 L p .707 .577 .707 r
F P
0 g
s
.31434 .78047 m .31434 .76195 L .28495 .76532 L p .707 .577 .707 r
F P
0 g
s
.61082 .36451 m .61082 .8664 L .63393 .856 L p .707 .577 .707 r
F P
0 g
s
.63393 .856 m .63393 .35411 L .61082 .36451 L p .707 .577 .707 r
F P
0 g
s
.22195 .7642 m .22195 .78273 L .25312 .78463 L p .707 .577 .707 r
F P
0 g
s
.17343 .65488 m .17343 .69193 L .19449 .69839 L p .707 .577 .707 r
F P
0 g
s
.22195 .78273 m .22195 .7642 L .19449 .75981 L p .707 .577 .707 r
F P
0 g
s
.33839 .65782 m .33839 .69487 L .35476 .6875 L p .707 .577 .707 r
F P
0 g
s
.35476 .6875 m .35476 .65045 L .33839 .65782 L p .707 .577 .707 r
F P
0 g
s
.19449 .75981 m .19449 .77834 L .22195 .78273 L p .707 .577 .707 r
F P
0 g
s
.66831 .65602 m .66831 .69308 L .64085 .68868 L p .707 .577 .707 r
F P
0 g
s
.64085 .68868 m .64085 .65163 L .66831 .65602 L p .707 .577 .707 r
F P
0 g
s
.31434 .76195 m .31434 .78047 L .33839 .77482 L p .707 .577 .707 r
F P
0 g
s
.33839 .77482 m .33839 .7563 L .31434 .76195 L p .707 .577 .707 r
F P
0 g
s
.16084 .59021 m .16084 .6458 L .17343 .65368 L p .707 .577 .707 r
F P
0 g
s
.17343 .69193 m .17343 .65488 L .16084 .64699 L p .707 .577 .707 r
F P
0 g
s
.35476 .59367 m .35476 .64925 L .36184 .64089 L p .707 .577 .707 r
F P
0 g
s
.36184 .64089 m .36184 .58531 L .35476 .59367 L p .707 .577 .707 r
F P
0 g
s
.68936 .76095 m .68936 .77948 L .66831 .77303 L p .707 .577 .707 r
F P
0 g
s
.66831 .77303 m .66831 .7545 L .68936 .76095 L p .707 .577 .707 r
F P
0 g
s
.37794 .86225 m .37794 .36036 L .36016 .34923 L p .707 .577 .707 r
F P
0 g
s
.37794 .36036 m .37794 .86225 L .40766 .87136 L p .707 .577 .707 r
F P
0 g
s
.19449 .77834 m .19449 .75981 L .17343 .75336 L p .707 .577 .707 r
F P
0 g
s
.17343 .75336 m .17343 .77188 L .19449 .77834 L p .707 .577 .707 r
F P
0 g
s
.16084 .64699 m .16084 .68405 L .17343 .69193 L p .707 .577 .707 r
F P
0 g
s
.16084 .6458 m .16084 .59021 L .15794 .58167 L p .707 .577 .707 r
F P
0 g
s
.35476 .65045 m .35476 .6875 L .36184 .67914 L p .707 .577 .707 r
F P
0 g
s
.36184 .67914 m .36184 .64209 L .35476 .65045 L p .707 .577 .707 r
F P
0 g
s
.33839 .7563 m .33839 .77482 L .35476 .76746 L p .707 .577 .707 r
F P
0 g
s
.35476 .76746 m .35476 .74893 L .33839 .7563 L p .707 .577 .707 r
F P
0 g
s
.66831 .7545 m .66831 .77303 L .64085 .76863 L p .707 .577 .707 r
F P
0 g
s
.64085 .76863 m .64085 .75011 L .66831 .7545 L p .707 .577 .707 r
F P
0 g
s
.63393 .35411 m .63393 .856 L .64393 .84419 L p .707 .577 .707 r
F P
0 g
s
.64393 .84419 m .64393 .3423 L .63393 .35411 L p .707 .577 .707 r
F P
0 g
s
.17343 .77188 m .17343 .75336 L .16084 .74547 L p .707 .577 .707 r
F P
0 g
s
.15794 .58167 m .15794 .63725 L .16084 .6458 L p .707 .577 .707 r
F P
0 g
s
.16084 .68405 m .16084 .64699 L .15794 .63845 L p .707 .577 .707 r
F P
0 g
s
.36184 .58531 m .36184 .64089 L .35894 .63235 L p .707 .577 .707 r
F P
0 g
s
.35894 .63235 m .35894 .57676 L .36184 .58531 L p .707 .577 .707 r
F P
0 g
s
.16084 .74547 m .16084 .764 L .17343 .77188 L p .707 .577 .707 r
F P
0 g
s
.15794 .63845 m .15794 .6755 L .16084 .68405 L p .707 .577 .707 r
F P
0 g
s
.35476 .74893 m .35476 .76746 L .36184 .75909 L p .707 .577 .707 r
F P
0 g
s
.36184 .75909 m .36184 .74056 L .35476 .74893 L p .707 .577 .707 r
F P
0 g
s
.36184 .64209 m .36184 .67914 L .35894 .6706 L p .707 .577 .707 r
F P
0 g
s
.35894 .6706 m .35894 .63354 L .36184 .64209 L p .707 .577 .707 r
F P
0 g
s
.35894 .57676 m .35894 .63235 L .34635 .62446 L p .707 .577 .707 r
F P
0 g
s
.34635 .62446 m .34635 .56888 L .35894 .57676 L p .707 .577 .707 r
F P
0 g
s
.36184 .74056 m .36184 .75909 L .35894 .75055 L p .707 .577 .707 r
F P
0 g
s
.35894 .75055 m .35894 .73202 L .36184 .74056 L p .707 .577 .707 r
F P
0 g
s
.35894 .63354 m .35894 .6706 L .34635 .66271 L p .707 .577 .707 r
F P
0 g
s
.34635 .66271 m .34635 .62566 L .35894 .63354 L p .707 .577 .707 r
F P
0 g
s
.36016 .85112 m .36016 .34923 L .35607 .33717 L p .707 .577 .707 r
F P
0 g
s
.36016 .34923 m .36016 .85112 L .37794 .86225 L p .707 .577 .707 r
F P
0 g
s
.15794 .63725 m .15794 .58167 L .16503 .57331 L p .707 .577 .707 r
F P
0 g
s
.16084 .764 m .16084 .74547 L .15794 .73693 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .57331 m .16503 .62889 L .15794 .63725 L p .707 .577 .707 r
F P
0 g
s
.15794 .6755 m .15794 .63845 L .16503 .63009 L p .707 .577 .707 r
F P
0 g
s
.15794 .73693 m .15794 .75546 L .16084 .764 L p .707 .577 .707 r
F P
0 g
s
.64393 .3423 m .64393 .84419 L .63984 .83213 L p .707 .577 .707 r
F P
0 g
s
.63984 .83213 m .63984 .33024 L .64393 .3423 L p .707 .577 .707 r
F P
0 g
s
.16503 .63009 m .16503 .66714 L .15794 .6755 L p .707 .577 .707 r
F P
0 g
s
.16503 .62889 m .16503 .57331 L .1814 .56594 L p .707 .577 .707 r
F P
0 g
s
.35894 .73202 m .35894 .75055 L .34635 .74267 L p .707 .577 .707 r
F P
0 g
s
.34635 .74267 m .34635 .72414 L .35894 .73202 L p .707 .577 .707 r
F P
0 g
s
.35607 .33717 m .35607 .83906 L .36016 .85112 L p .707 .577 .707 r
F P
0 g
s
.35607 .83906 m .35607 .33717 L .36607 .32536 L p .707 .577 .707 r
F P
0 g
s
.15794 .75546 m .15794 .73693 L .16503 .72856 L p .707 .577 .707 r
F P
0 g
s
.1814 .56594 m .1814 .62152 L .16503 .62889 L p .707 .577 .707 r
F P
0 g
s
.16503 .66714 m .16503 .63009 L .1814 .62272 L p .707 .577 .707 r
F P
0 g
s
.34635 .56888 m .34635 .62446 L .3253 .61801 L p .707 .577 .707 r
F P
0 g
s
.3253 .61801 m .3253 .56243 L .34635 .56888 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72856 m .16503 .74709 L .15794 .75546 L p .707 .577 .707 r
F P
0 g
s
.1814 .62272 m .1814 .65977 L .16503 .66714 L p .707 .577 .707 r
F P
0 g
s
.1814 .62152 m .1814 .56594 L .20545 .56029 L p .707 .577 .707 r
F P
0 g
s
.34635 .62566 m .34635 .66271 L .3253 .65626 L p .707 .577 .707 r
F P
0 g
s
.3253 .65626 m .3253 .6192 L .34635 .62566 L p .707 .577 .707 r
F P
0 g
s
.63984 .33024 m .63984 .83213 L .62206 .821 L p .707 .577 .707 r
F P
0 g
s
.62206 .821 m .62206 .31911 L .63984 .33024 L p .707 .577 .707 r
F P
0 g
s
.3253 .56243 m .3253 .61801 L .29784 .61362 L p .707 .577 .707 r
F P
0 g
s
.29784 .61362 m .29784 .55803 L .3253 .56243 L p .707 .577 .707 r
F P
0 g
s
.20545 .56029 m .20545 .61587 L .1814 .62152 L p .707 .577 .707 r
F P
0 g
s
.1814 .65977 m .1814 .62272 L .20545 .61707 L p .707 .577 .707 r
F P
0 g
s
.16503 .74709 m .16503 .72856 L .1814 .7212 L p .707 .577 .707 r
F P
0 g
s
.20545 .61587 m .20545 .56029 L .23483 .55691 L p .707 .577 .707 r
F P
0 g
s
.1814 .7212 m .1814 .73972 L .16503 .74709 L p .707 .577 .707 r
F P
0 g
s
.20545 .61707 m .20545 .65412 L .1814 .65977 L p .707 .577 .707 r
F P
0 g
s
.36607 .82725 m .36607 .32536 L .38918 .31496 L p .707 .577 .707 r
F P
0 g
s
.36607 .32536 m .36607 .82725 L .35607 .83906 L p .707 .577 .707 r
F P
0 g
s
.29784 .55803 m .29784 .61362 L .26667 .61172 L p .707 .577 .707 r
F P
0 g
s
.26667 .61172 m .26667 .55613 L .29784 .55803 L p .707 .577 .707 r
F P
0 g
s
.3253 .6192 m .3253 .65626 L .29784 .65187 L p .707 .577 .707 r
F P
0 g
s
.29784 .65187 m .29784 .61481 L .3253 .6192 L p .707 .577 .707 r
F P
0 g
s
.23483 .61249 m .23483 .55691 L .26667 .55613 L p .707 .577 .707 r
F P
0 g
s
.23483 .55691 m .23483 .61249 L .20545 .61587 L p .707 .577 .707 r
F P
0 g
s
.34635 .72414 m .34635 .74267 L .3253 .73621 L p .707 .577 .707 r
F P
0 g
s
.3253 .73621 m .3253 .71768 L .34635 .72414 L p .707 .577 .707 r
F P
0 g
s
.26667 .55613 m .26667 .61172 L .23483 .61249 L p .707 .577 .707 r
F P
0 g
s
.20545 .65412 m .20545 .61707 L .23483 .61369 L p .707 .577 .707 r
F P
0 g
s
.73333 .6112 m .73333 .55562 L .70216 .55372 L p .707 .577 .707 r
F P
0 g
s
.73333 .55562 m .73333 .6112 L .76517 .61043 L p .707 .577 .707 r
F P
0 g
s
.76517 .61043 m .76517 .55484 L .73333 .55562 L p .707 .577 .707 r
F P
0 g
s
.76517 .55484 m .76517 .61043 L .79455 .60705 L p .707 .577 .707 r
F P
0 g
s
.79455 .60705 m .79455 .55147 L .76517 .55484 L p .707 .577 .707 r
F P
0 g
s
.1814 .73972 m .1814 .7212 L .20545 .71555 L p .707 .577 .707 r
F P
0 g
s
.70216 .6093 m .70216 .55372 L .6747 .54933 L p .707 .577 .707 r
F P
0 g
s
.70216 .55372 m .70216 .6093 L .73333 .6112 L p .707 .577 .707 r
F P
0 g
s
.29784 .61481 m .29784 .65187 L .26667 .64997 L p .707 .577 .707 r
F P
0 g
s
.26667 .64997 m .26667 .61291 L .29784 .61481 L p .707 .577 .707 r
F P
0 g
s
.23483 .61369 m .23483 .65074 L .20545 .65412 L p .707 .577 .707 r
F P
0 g
s
.23483 .65074 m .23483 .61369 L .26667 .61291 L p .707 .577 .707 r
F P
0 g
s
.20545 .71555 m .20545 .73407 L .1814 .73972 L p .707 .577 .707 r
F P
0 g
s
.62206 .31911 m .62206 .821 L .59233 .81189 L p .707 .577 .707 r
F P
0 g
s
.59233 .81189 m .59233 .31 L .62206 .31911 L p .707 .577 .707 r
F P
0 g
s
.26667 .61291 m .26667 .64997 L .23483 .65074 L p .707 .577 .707 r
F P
0 g
s
.79455 .55147 m .79455 .60705 L .8186 .6014 L p .707 .577 .707 r
F P
0 g
s
.8186 .6014 m .8186 .54582 L .79455 .55147 L p .707 .577 .707 r
F P
0 g
s
.73333 .64945 m .73333 .6124 L .70216 .6105 L p .707 .577 .707 r
F P
0 g
s
.73333 .6124 m .73333 .64945 L .76517 .64868 L p .707 .577 .707 r
F P
0 g
s
.76517 .64868 m .76517 .61162 L .73333 .6124 L p .707 .577 .707 r
F P
0 g
s
.76517 .61162 m .76517 .64868 L .79455 .6453 L p .707 .577 .707 r
F P
0 g
s
.79455 .6453 m .79455 .60824 L .76517 .61162 L p .707 .577 .707 r
F P
0 g
s
.3253 .71768 m .3253 .73621 L .29784 .73182 L p .707 .577 .707 r
F P
0 g
s
.29784 .73182 m .29784 .71329 L .3253 .71768 L p .707 .577 .707 r
F P
0 g
s
.6747 .54933 m .6747 .60491 L .70216 .6093 L p .707 .577 .707 r
F P
0 g
s
.6747 .60491 m .6747 .54933 L .65365 .54288 L p .707 .577 .707 r
F P
0 g
s
.70216 .64755 m .70216 .6105 L .6747 .60611 L p .707 .577 .707 r
F P
0 g
s
.70216 .6105 m .70216 .64755 L .73333 .64945 L p .707 .577 .707 r
F P
0 g
s
.20545 .73407 m .20545 .71555 L .23483 .71217 L p .707 .577 .707 r
F P
0 g
s
.38918 .31496 m .38918 .81685 L .36607 .82725 L p .707 .577 .707 r
F P
0 g
s
.38918 .81685 m .38918 .31496 L .42314 .30698 L p .707 .577 .707 r
F P
0 g
s
.79455 .60824 m .79455 .6453 L .8186 .63965 L p .707 .577 .707 r
F P
0 g
s
.8186 .63965 m .8186 .60259 L .79455 .60824 L p .707 .577 .707 r
F P
0 g
s
.23483 .71217 m .23483 .7307 L .20545 .73407 L p .707 .577 .707 r
F P
0 g
s
.6747 .60611 m .6747 .64316 L .70216 .64755 L p .707 .577 .707 r
F P
0 g
s
.29784 .71329 m .29784 .73182 L .26667 .72992 L p .707 .577 .707 r
F P
0 g
s
.26667 .72992 m .26667 .71139 L .29784 .71329 L p .707 .577 .707 r
F P
0 g
s
.8186 .54582 m .8186 .6014 L .83497 .59403 L p .707 .577 .707 r
F P
0 g
s
.83497 .59403 m .83497 .53845 L .8186 .54582 L p .707 .577 .707 r
F P
0 g
s
.65365 .54288 m .65365 .59846 L .6747 .60491 L p .707 .577 .707 r
F P
0 g
s
.6747 .64316 m .6747 .60611 L .65365 .59965 L p .707 .577 .707 r
F P
0 g
s
.23483 .7307 m .23483 .71217 L .26667 .71139 L p .707 .577 .707 r
F P
0 g
s
.26667 .71139 m .26667 .72992 L .23483 .7307 L p .707 .577 .707 r
F P
0 g
s
.73333 .72941 m .73333 .71088 L .70216 .70898 L p .707 .577 .707 r
F P
0 g
s
.73333 .71088 m .73333 .72941 L .76517 .72863 L p .707 .577 .707 r
F P
0 g
s
.76517 .72863 m .76517 .7101 L .73333 .71088 L p .707 .577 .707 r
F P
0 g
s
.59233 .31 m .59233 .81189 L .55357 .80569 L p .707 .577 .707 r
F P
0 g
s
.55357 .80569 m .55357 .3038 L .59233 .31 L p .707 .577 .707 r
F P
0 g
s
.65365 .59846 m .65365 .54288 L .64105 .53499 L p .707 .577 .707 r
F P
0 g
s
.76517 .7101 m .76517 .72863 L .79455 .72525 L p .707 .577 .707 r
F P
0 g
s
.79455 .72525 m .79455 .70672 L .76517 .7101 L p .707 .577 .707 r
F P
0 g
s
.70216 .70898 m .70216 .72751 L .73333 .72941 L p .707 .577 .707 r
F P
0 g
s
.65365 .59965 m .65365 .63671 L .6747 .64316 L p .707 .577 .707 r
F P
0 g
s
.70216 .72751 m .70216 .70898 L .6747 .70459 L p .707 .577 .707 r
F P
0 g
s
.8186 .60259 m .8186 .63965 L .83497 .63228 L p .707 .577 .707 r
F P
0 g
s
.83497 .63228 m .83497 .59523 L .8186 .60259 L p .707 .577 .707 r
F P
0 g
s
.6747 .70459 m .6747 .72311 L .70216 .72751 L p .707 .577 .707 r
F P
0 g
s
.42314 .80887 m .42314 .30698 L .46462 .30221 L p .707 .577 .707 r
F P
0 g
s
.42314 .30698 m .42314 .80887 L .38918 .81685 L p .707 .577 .707 r
F P
0 g
s
.79455 .70672 m .79455 .72525 L .8186 .7196 L p .707 .577 .707 r
F P
0 g
s
.8186 .7196 m .8186 .70107 L .79455 .70672 L p .707 .577 .707 r
F P
0 g
s
.64105 .53499 m .64105 .59057 L .65365 .59846 L p .707 .577 .707 r
F P
0 g
s
.65365 .63671 m .65365 .59965 L .64105 .59177 L p .707 .577 .707 r
F P
0 g
s
.83497 .53845 m .83497 .59403 L .84205 .58567 L p .707 .577 .707 r
F P
0 g
s
.84205 .58567 m .84205 .53008 L .83497 .53845 L p .707 .577 .707 r
F P
0 g
s
.6747 .72311 m .6747 .70459 L .65365 .69813 L p .707 .577 .707 r
F P
0 g
s
.55357 .3038 m .55357 .80569 L .50956 .80301 L p .707 .577 .707 r
F P
0 g
s
.50956 .80301 m .50956 .30112 L .55357 .3038 L p .707 .577 .707 r
F P
0 g
s
.65365 .69813 m .65365 .71666 L .6747 .72311 L p .707 .577 .707 r
F P
0 g
s
.64105 .59177 m .64105 .62882 L .65365 .63671 L p .707 .577 .707 r
F P
0 g
s
.46462 .8041 m .46462 .30221 L .50956 .30112 L p .707 .577 .707 r
F P
0 g
s
.46462 .30221 m .46462 .8041 L .42314 .80887 L p .707 .577 .707 r
F P
0 g
s
.64105 .59057 m .64105 .53499 L .63816 .52645 L p .707 .577 .707 r
F P
0 g
s
.83497 .59523 m .83497 .63228 L .84205 .62392 L p .707 .577 .707 r
F P
0 g
s
.84205 .62392 m .84205 .58686 L .83497 .59523 L p .707 .577 .707 r
F P
0 g
s
.50956 .30112 m .50956 .80301 L .46462 .8041 L p .707 .577 .707 r
F P
0 g
s
.8186 .70107 m .8186 .7196 L .83497 .71223 L p .707 .577 .707 r
F P
0 g
s
.83497 .71223 m .83497 .69371 L .8186 .70107 L p .707 .577 .707 r
F P
0 g
s
.65365 .71666 m .65365 .69813 L .64105 .69025 L p .707 .577 .707 r
F P
0 g
s
.63816 .52645 m .63816 .58203 L .64105 .59057 L p .707 .577 .707 r
F P
0 g
s
.64105 .62882 m .64105 .59177 L .63816 .58323 L p .707 .577 .707 r
F P
0 g
s
.84205 .53008 m .84205 .58567 L .83916 .57712 L p .707 .577 .707 r
F P
0 g
s
.83916 .57712 m .83916 .52154 L .84205 .53008 L p .707 .577 .707 r
F P
0 g
s
.64105 .69025 m .64105 .70878 L .65365 .71666 L p .707 .577 .707 r
F P
0 g
s
.63816 .58323 m .63816 .62028 L .64105 .62882 L p .707 .577 .707 r
F P
0 g
s
.63816 .58203 m .63816 .52645 L .64524 .51808 L p .707 .577 .707 r
F P
0 g
s
.83497 .69371 m .83497 .71223 L .84206 .70387 L p .707 .577 .707 r
F P
0 g
s
.84206 .70387 m .84206 .68534 L .83497 .69371 L p .707 .577 .707 r
F P
0 g
s
.84205 .58686 m .84205 .62392 L .83916 .61537 L p .707 .577 .707 r
F P
0 g
s
.83916 .61537 m .83916 .57832 L .84205 .58686 L p .707 .577 .707 r
F P
0 g
s
.64105 .70878 m .64105 .69025 L .63816 .68171 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .51808 m .64524 .57367 L .63816 .58203 L p .707 .577 .707 r
F P
0 g
s
.63816 .62028 m .63816 .58323 L .64524 .57486 L p .707 .577 .707 r
F P
0 g
s
.83916 .52154 m .83916 .57712 L .82657 .56924 L p .707 .577 .707 r
F P
0 g
s
.82657 .56924 m .82657 .51366 L .83916 .52154 L p .707 .577 .707 r
F P
0 g
s
.63816 .68171 m .63816 .70023 L .64105 .70878 L p .707 .577 .707 r
F P
0 g
s
.64524 .57486 m .64524 .61192 L .63816 .62028 L p .707 .577 .707 r
F P
0 g
s
.39032 .57439 m .39032 .51881 L .35915 .51691 L p .707 .577 .707 r
F P
0 g
s
.39032 .51881 m .39032 .57439 L .42216 .57361 L p .707 .577 .707 r
F P
0 g
s
.42216 .57361 m .42216 .51803 L .39032 .51881 L p .707 .577 .707 r
F P
0 g
s
.64524 .57367 m .64524 .51808 L .66161 .51072 L p .707 .577 .707 r
F P
0 g
s
.84206 .68534 m .84206 .70387 L .83916 .69533 L p .707 .577 .707 r
F P
0 g
s
.83916 .69533 m .83916 .6768 L .84206 .68534 L p .707 .577 .707 r
F P
0 g
s
.42216 .51803 m .42216 .57361 L .45154 .57023 L p .707 .577 .707 r
F P
0 g
s
.45154 .57023 m .45154 .51465 L .42216 .51803 L p .707 .577 .707 r
F P
0 g
s
.83916 .57832 m .83916 .61537 L .82657 .60749 L p .707 .577 .707 r
F P
0 g
s
.82657 .60749 m .82657 .57044 L .83916 .57832 L p .707 .577 .707 r
F P
0 g
s
.35915 .57249 m .35915 .51691 L .33169 .51251 L p .707 .577 .707 r
F P
0 g
s
.35915 .51691 m .35915 .57249 L .39032 .57439 L p .707 .577 .707 r
F P
0 g
s
.45154 .51465 m .45154 .57023 L .47559 .56458 L p .707 .577 .707 r
F P
0 g
s
.47559 .56458 m .47559 .509 L .45154 .51465 L p .707 .577 .707 r
F P
0 g
s
.63816 .70023 m .63816 .68171 L .64524 .67334 L p .707 .577 .707 r
F P
0 g
s
.39032 .61264 m .39032 .57558 L .35915 .57368 L p .707 .577 .707 r
F P
0 g
s
.39032 .57558 m .39032 .61264 L .42216 .61186 L p .707 .577 .707 r
F P
0 g
s
.42216 .61186 m .42216 .57481 L .39032 .57558 L p .707 .577 .707 r
F P
0 g
s
.66161 .51072 m .66161 .5663 L .64524 .57367 L p .707 .577 .707 r
F P
0 g
s
.64524 .61192 m .64524 .57486 L .66161 .56749 L p .707 .577 .707 r
F P
0 g
s
.82657 .51366 m .82657 .56924 L .80551 .56279 L p .707 .577 .707 r
F P
0 g
s
.80551 .56279 m .80551 .5072 L .82657 .51366 L p .707 .577 .707 r
F P
0 g
s
.42216 .57481 m .42216 .61186 L .45154 .60848 L p .707 .577 .707 r
F P
0 g
s
.45154 .60848 m .45154 .57143 L .42216 .57481 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64524 .67334 m .64524 .69187 L .63816 .70023 L p .707 .577 .707 r
F P
0 g
s
.33169 .51251 m .33169 .5681 L .35915 .57249 L p .707 .577 .707 r
F P
0 g
s
.33169 .5681 m .33169 .51251 L .31064 .50606 L p .707 .577 .707 r
F P
0 g
s
.35915 .61074 m .35915 .57368 L .33169 .56929 L p .707 .577 .707 r
F P
0 g
s
.35915 .57368 m .35915 .61074 L .39032 .61264 L p .707 .577 .707 r
F P
0 g
s
.66161 .56749 m .66161 .60455 L .64524 .61192 L p .707 .577 .707 r
F P
0 g
s
.66161 .5663 m .66161 .51072 L .68566 .50507 L p .707 .577 .707 r
F P
0 g
s
.45154 .57143 m .45154 .60848 L .47559 .60283 L p .707 .577 .707 r
F P
0 g
s
.47559 .60283 m .47559 .56578 L .45154 .57143 L p .707 .577 .707 r
F P
0 g
s
.33169 .56929 m .33169 .60635 L .35915 .61074 L p .707 .577 .707 r
F P
0 g
s
.83916 .6768 m .83916 .69533 L .82657 .68744 L p .707 .577 .707 r
F P
0 g
s
.82657 .68744 m .82657 .66891 L .83916 .6768 L p .707 .577 .707 r
F P
0 g
s
.82657 .57044 m .82657 .60749 L .80551 .60104 L p .707 .577 .707 r
F P
0 g
s
.80551 .60104 m .80551 .56398 L .82657 .57044 L p .707 .577 .707 r
F P
0 g
s
.47559 .509 m .47559 .56458 L .49196 .55722 L p .707 .577 .707 r
F P
0 g
s
.49196 .55722 m .49196 .50163 L .47559 .509 L p .707 .577 .707 r
F P
0 g
s
.31064 .50606 m .31064 .56164 L .33169 .5681 L p .707 .577 .707 r
F P
0 g
s
.33169 .60635 m .33169 .56929 L .31064 .56284 L p .707 .577 .707 r
F P
0 g
s
.80551 .5072 m .80551 .56279 L .77805 .55839 L p .707 .577 .707 r
F P
0 g
s
.77805 .55839 m .77805 .50281 L .80551 .5072 L p .707 .577 .707 r
F P
0 g
s
.39032 .69259 m .39032 .67406 L .35915 .67216 L p .707 .577 .707 r
F P
0 g
s
.39032 .67406 m .39032 .69259 L .42216 .69181 L p .707 .577 .707 r
F P
0 g
s
.42216 .69181 m .42216 .67329 L .39032 .67406 L p .707 .577 .707 r
F P
0 g
s
.68566 .50507 m .68566 .56065 L .66161 .5663 L p .707 .577 .707 r
F P
0 g
s
.66161 .60455 m .66161 .56749 L .68566 .56184 L p .707 .577 .707 r
F P
0 g
s
.31064 .56164 m .31064 .50606 L .29804 .49818 L p .707 .577 .707 r
F P
0 g
s
.64524 .69187 m .64524 .67334 L .66161 .66597 L p .707 .577 .707 r
F P
0 g
s
.42216 .67329 m .42216 .69181 L .45154 .68843 L p .707 .577 .707 r
F P
0 g
s
.45154 .68843 m .45154 .66991 L .42216 .67329 L p .707 .577 .707 r
F P
0 g
s
.35915 .67216 m .35915 .69069 L .39032 .69259 L p .707 .577 .707 r
F P
0 g
s
.31064 .56284 m .31064 .59989 L .33169 .60635 L p .707 .577 .707 r
F P
0 g
s
.68566 .56065 m .68566 .50507 L .71504 .50169 L p .707 .577 .707 r
F P
0 g
s
.35915 .69069 m .35915 .67216 L .33169 .66777 L p .707 .577 .707 r
F P
0 g
s
.66161 .66597 m .66161 .6845 L .64524 .69187 L p .707 .577 .707 r
F P
0 g
s
.47559 .56578 m .47559 .60283 L .49196 .59547 L p .707 .577 .707 r
F P
0 g
s
.49196 .59547 m .49196 .55841 L .47559 .56578 L p .707 .577 .707 r
F P
0 g
s
.68566 .56184 m .68566 .5989 L .66161 .60455 L p .707 .577 .707 r
F P
0 g
s
.33169 .66777 m .33169 .6863 L .35915 .69069 L p .707 .577 .707 r
F P
0 g
s
.77805 .50281 m .77805 .55839 L .74688 .55649 L p .707 .577 .707 r
F P
0 g
s
.74688 .55649 m .74688 .50091 L .77805 .50281 L p .707 .577 .707 r
F P
0 g
s
.80551 .56398 m .80551 .60104 L .77805 .59664 L p .707 .577 .707 r
F P
0 g
s
.77805 .59664 m .77805 .55959 L .80551 .56398 L p .707 .577 .707 r
F P
0 g
s
.45154 .66991 m .45154 .68843 L .47559 .68279 L p .707 .577 .707 r
F P
0 g
s
.47559 .68279 m .47559 .66426 L .45154 .66991 L p .707 .577 .707 r
F P
0 g
s
.29804 .49818 m .29804 .55376 L .31064 .56164 L p .707 .577 .707 r
F P
0 g
s
.71504 .55727 m .71504 .50169 L .74688 .50091 L p .707 .577 .707 r
F P
0 g
s
.71504 .50169 m .71504 .55727 L .68566 .56065 L p .707 .577 .707 r
F P
0 g
s
.31064 .59989 m .31064 .56284 L .29804 .55495 L p .707 .577 .707 r
F P
0 g
s
.49196 .50163 m .49196 .55722 L .49904 .54885 L p .707 .577 .707 r
F P
0 g
s
.49904 .54885 m .49904 .49327 L .49196 .50163 L p .707 .577 .707 r
F P
0 g
s
.82657 .66891 m .82657 .68744 L .80551 .68099 L p .707 .577 .707 r
F P
0 g
s
.80551 .68099 m .80551 .66246 L .82657 .66891 L p .707 .577 .707 r
F P
0 g
s
.74688 .50091 m .74688 .55649 L .71504 .55727 L p .707 .577 .707 r
F P
0 g
s
.68566 .5989 m .68566 .56184 L .71504 .55847 L p .707 .577 .707 r
F P
0 g
s
.33169 .6863 m .33169 .66777 L .31064 .66132 L p .707 .577 .707 r
F P
0 g
s
.31064 .66132 m .31064 .67984 L .33169 .6863 L p .707 .577 .707 r
F P
0 g
s
.29804 .55495 m .29804 .59201 L .31064 .59989 L p .707 .577 .707 r
F P
0 g
s
.66161 .6845 m .66161 .66597 L .68566 .66032 L p .707 .577 .707 r
F P
0 g
s
.77805 .55959 m .77805 .59664 L .74688 .59474 L p .707 .577 .707 r
F P
0 g
s
.74688 .59474 m .74688 .55769 L .77805 .55959 L p .707 .577 .707 r
F P
0 g
s
.29804 .55376 m .29804 .49818 L .29515 .48963 L p .707 .577 .707 r
F P
0 g
s
.71504 .55847 m .71504 .59552 L .68566 .5989 L p .707 .577 .707 r
F P
0 g
s
.71504 .59552 m .71504 .55847 L .74688 .55769 L p .707 .577 .707 r
F P
0 g
s
.68566 .66032 m .68566 .67885 L .66161 .6845 L p .707 .577 .707 r
F P
0 g
s
.49196 .55841 m .49196 .59547 L .49904 .5871 L p .707 .577 .707 r
F P
0 g
s
.49904 .5871 m .49904 .55005 L .49196 .55841 L p .707 .577 .707 r
F P
0 g
s
.47559 .66426 m .47559 .68279 L .49196 .67542 L p .707 .577 .707 r
F P
0 g
s
.49196 .67542 m .49196 .65689 L .47559 .66426 L p .707 .577 .707 r
F P
0 g
s
.74688 .55769 m .74688 .59474 L .71504 .59552 L p .707 .577 .707 r
F P
0 g
s
.80551 .66246 m .80551 .68099 L .77805 .6766 L p .707 .577 .707 r
F P
0 g
s
.77805 .6766 m .77805 .65807 L .80551 .66246 L p .707 .577 .707 r
F P
0 g
s
.31064 .67984 m .31064 .66132 L .29804 .65343 L p .707 .577 .707 r
F P
0 g
s
.29515 .48963 m .29515 .54522 L .29804 .55376 L p .707 .577 .707 r
F P
0 g
s
.29804 .59201 m .29804 .55495 L .29515 .54641 L p .707 .577 .707 r
F P
0 g
s
.49904 .49327 m .49904 .54885 L .49615 .54031 L p .707 .577 .707 r
F P
0 g
s
.49615 .54031 m .49615 .48473 L .49904 .49327 L p .707 .577 .707 r
F P
0 g
s
.68566 .67885 m .68566 .66032 L .71504 .65694 L p .707 .577 .707 r
F P
0 g
s
.29804 .65343 m .29804 .67196 L .31064 .67984 L p .707 .577 .707 r
F P
0 g
s
.71504 .65694 m .71504 .67547 L .68566 .67885 L p .707 .577 .707 r
F P
0 g
s
.29515 .54641 m .29515 .58347 L .29804 .59201 L p .707 .577 .707 r
F P
0 g
s
.77805 .65807 m .77805 .6766 L .74688 .6747 L p .707 .577 .707 r
F P
0 g
s
.74688 .6747 m .74688 .65617 L .77805 .65807 L p .707 .577 .707 r
F P
0 g
s
.71504 .67547 m .71504 .65694 L .74688 .65617 L p .707 .577 .707 r
F P
0 g
s
.29515 .54522 m .29515 .48963 L .30223 .48127 L p .707 .577 .707 r
F P
0 g
s
.49196 .65689 m .49196 .67542 L .49904 .66705 L p .707 .577 .707 r
F P
0 g
s
.49904 .66705 m .49904 .64853 L .49196 .65689 L p .707 .577 .707 r
F P
0 g
s
.74688 .65617 m .74688 .6747 L .71504 .67547 L p .707 .577 .707 r
F P
0 g
s
.49904 .55005 m .49904 .5871 L .49615 .57856 L p .707 .577 .707 r
F P
0 g
s
.49615 .57856 m .49615 .5415 L .49904 .55005 L p .707 .577 .707 r
F P
0 g
s
.29804 .67196 m .29804 .65343 L .29515 .64489 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .48127 m .30223 .53685 L .29515 .54522 L p .707 .577 .707 r
F P
0 g
s
.29515 .58347 m .29515 .54641 L .30223 .53805 L p .707 .577 .707 r
F P
0 g
s
.49615 .48473 m .49615 .54031 L .48356 .53242 L p .707 .577 .707 r
F P
0 g
s
.48356 .53242 m .48356 .47684 L .49615 .48473 L p .707 .577 .707 r
F P
0 g
s
.29515 .64489 m .29515 .66342 L .29804 .67196 L p .707 .577 .707 r
F P
0 g
s
.30223 .53805 m .30223 .5751 L .29515 .58347 L p .707 .577 .707 r
F P
0 g
s
.30223 .53685 m .30223 .48127 L .3186 .4739 L p .707 .577 .707 r
F P
0 g
s
.49904 .64853 m .49904 .66705 L .49615 .65851 L p .707 .577 .707 r
F P
0 g
s
.49615 .65851 m .49615 .63998 L .49904 .64853 L p .707 .577 .707 r
F P
0 g
s
.49615 .5415 m .49615 .57856 L .48356 .57067 L p .707 .577 .707 r
F P
0 g
s
.48356 .57067 m .48356 .53362 L .49615 .5415 L p .707 .577 .707 r
F P
0 g
s
.29515 .66342 m .29515 .64489 L .30223 .63653 L p .707 .577 .707 r
F P
0 g
s
.3186 .4739 m .3186 .52948 L .30223 .53685 L p .707 .577 .707 r
F P
0 g
s
.30223 .5751 m .30223 .53805 L .3186 .53068 L p .707 .577 .707 r
F P
0 g
s
.48356 .47684 m .48356 .53242 L .4625 .52597 L p .707 .577 .707 r
F P
0 g
s
.4625 .52597 m .4625 .47039 L .48356 .47684 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .63653 m .30223 .65505 L .29515 .66342 L p .707 .577 .707 r
F P
0 g
s
.3186 .53068 m .3186 .56773 L .30223 .5751 L p .707 .577 .707 r
F P
0 g
s
.3186 .52948 m .3186 .4739 L .34265 .46825 L p .707 .577 .707 r
F P
0 g
s
.49615 .63998 m .49615 .65851 L .48356 .65063 L p .707 .577 .707 r
F P
0 g
s
.48356 .65063 m .48356 .6321 L .49615 .63998 L p .707 .577 .707 r
F P
0 g
s
.48356 .53362 m .48356 .57067 L .4625 .56422 L p .707 .577 .707 r
F P
0 g
s
.4625 .56422 m .4625 .52717 L .48356 .53362 L p .707 .577 .707 r
F P
0 g
s
.4625 .47039 m .4625 .52597 L .43504 .52158 L p .707 .577 .707 r
F P
0 g
s
.43504 .52158 m .43504 .466 L .4625 .47039 L p .707 .577 .707 r
F P
0 g
s
.34265 .46825 m .34265 .52383 L .3186 .52948 L p .707 .577 .707 r
F P
0 g
s
.3186 .56773 m .3186 .53068 L .34265 .52503 L p .707 .577 .707 r
F P
0 g
s
.30223 .65505 m .30223 .63653 L .3186 .62916 L p .707 .577 .707 r
F P
0 g
s
.34265 .52383 m .34265 .46825 L .37203 .46487 L p .707 .577 .707 r
F P
0 g
s
.3186 .62916 m .3186 .64769 L .30223 .65505 L p .707 .577 .707 r
F P
0 g
s
.34265 .52503 m .34265 .56208 L .3186 .56773 L p .707 .577 .707 r
F P
0 g
s
.43504 .466 m .43504 .52158 L .40387 .51968 L p .707 .577 .707 r
F P
0 g
s
.40387 .51968 m .40387 .46409 L .43504 .466 L p .707 .577 .707 r
F P
0 g
s
.4625 .52717 m .4625 .56422 L .43504 .55983 L p .707 .577 .707 r
F P
0 g
s
.43504 .55983 m .43504 .52277 L .4625 .52717 L p .707 .577 .707 r
F P
0 g
s
.37203 .52045 m .37203 .46487 L .40387 .46409 L p .707 .577 .707 r
F P
0 g
s
.37203 .46487 m .37203 .52045 L .34265 .52383 L p .707 .577 .707 r
F P
0 g
s
.48356 .6321 m .48356 .65063 L .4625 .64417 L p .707 .577 .707 r
F P
0 g
s
.4625 .64417 m .4625 .62565 L .48356 .6321 L p .707 .577 .707 r
F P
0 g
s
.40387 .46409 m .40387 .51968 L .37203 .52045 L p .707 .577 .707 r
F P
0 g
s
.34265 .56208 m .34265 .52503 L .37203 .52165 L p .707 .577 .707 r
F P
0 g
s
.3186 .64769 m .3186 .62916 L .34265 .62351 L p .707 .577 .707 r
F P
0 g
s
.43504 .52277 m .43504 .55983 L .40387 .55793 L p .707 .577 .707 r
F P
0 g
s
.40387 .55793 m .40387 .52087 L .43504 .52277 L p .707 .577 .707 r
F P
0 g
s
.37203 .52165 m .37203 .55871 L .34265 .56208 L p .707 .577 .707 r
F P
0 g
s
.37203 .55871 m .37203 .52165 L .40387 .52087 L p .707 .577 .707 r
F P
0 g
s
.34265 .62351 m .34265 .64204 L .3186 .64769 L p .707 .577 .707 r
F P
0 g
s
.40387 .52087 m .40387 .55793 L .37203 .55871 L p .707 .577 .707 r
F P
0 g
s
.4625 .62565 m .4625 .64417 L .43504 .63978 L p .707 .577 .707 r
F P
0 g
s
.43504 .63978 m .43504 .62125 L .4625 .62565 L p .707 .577 .707 r
F P
0 g
s
.34265 .64204 m .34265 .62351 L .37203 .62013 L p .707 .577 .707 r
F P
0 g
s
.37203 .62013 m .37203 .63866 L .34265 .64204 L p .707 .577 .707 r
F P
0 g
s
.43504 .62125 m .43504 .63978 L .40387 .63788 L p .707 .577 .707 r
F P
0 g
s
.40387 .63788 m .40387 .61935 L .43504 .62125 L p .707 .577 .707 r
F P
0 g
s
.37203 .63866 m .37203 .62013 L .40387 .61935 L p .707 .577 .707 r
F P
0 g
s
.40387 .61935 m .40387 .63788 L .37203 .63866 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo002;Ool<0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo
0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH00eYF0`00K7oo001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006EooaX000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00GWoo20000eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00FGoo1@000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001GOol200000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00003goo4P00A7oo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YF
FUH00UYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`00
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH0
0004FUH00`00FUIJEP03FUHO0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUH000090003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF
FUH0000^Ool005=oo`03001JEP0000=JEPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000800003FUH005YF009JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo001COol01000FUH005YF10001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YFFUH000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH2000]Ool005=oo`03001JEP000080009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00005FUH005YFFUH0000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P00;Goo001COol30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00?goo5@0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009J
EQP000EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEPL000MJEP@000EJEPP000AJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH:00000eYF001JEP04FUH01000FUIJEUYF0P00;Goo000cOol40003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH5
0005FUH00`00FUIJEP04FUH60004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF00000P0000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP04001JEUYFFUH2000]Ool0
035oo`<000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEPT0
00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEP0000D00003FUH005YF009JEP04
001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH3
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0
00040003FUH2000]Ool002moo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00FUH20005FUH00`00FUH000090004FUH50005FUH00`00FUIJEP02
FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF009JEP<0009JEP8002eoo`00;Woo00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005
FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EPH002eoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00<002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01EYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJ
EUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH80008FUH50004
FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH300000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH40007FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH0
0UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUH00003000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00002FUH20002FUH50004FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH70003FUH30003FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEPP000AJEP03001JEUYF
00MJEP03001JEUYF009JEPD0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP04001JEUYFFUHK0003FUH00`00FUIJ
EP04FUH01000FUIJEP000UYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUHI0004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF00004P001eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001J
EP0000EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP04001JEUYFFUH4000]Ool002aoo`03001JEP0000AJEP04001JEUYFFUH80003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH000070004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool0
0`00FUH00003FUH700000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH7000015YF001JEUYF6P001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/
Ool01000FUH005YF1@001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YF00001`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF00000`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo000/Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_
Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEP000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001JEP<000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
03=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0015YF00<005YFFUH00eYF1P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH00UYF10000UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<0
05YF00000`000UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJ
EP@000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00005FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH90003FUH00`00FUH00003FUH40005FUH01000FUIJEP000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF100000=JEP00FUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP03001J
EP0001P003moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF30001EYF1000
00=JEP00FUH00P000eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP04001JEUYFFUH20003FUH01000FUIJEP0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJEP8005Ao
o`00;7oo00<005YF000015YF00@005YFFUIJEPT000MJEPD000EJEP04001JEP00FUH200000eYF0000
00040004FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH00eYF0P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEPD000AJEP04001JEUYFFUHB0014Ool002aoo`03001JEP0000=JEPT000AJ
EP03001JEUYF00EJEPD000EJEP05001JEP00001JEP0200000eYF001JEP0600001EYF001JEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00UYF1@000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YF00001`0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo000/Ool01000FUH005YF0P00
15YF3@0015YF1@001EYF00@005YF000000=JEPD000=JEP<0009JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH400000eYF001JEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo000/Ool01P00FUH00000FUH000EJ
EP04001JEUYFFUHJ0003FUH00`00FUIJEP060002FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP07FUH400000eYF001JEP02FUH00`00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol002aoo`8000=J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003
FUH00`00FUIJEP03FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH50005FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH0
0eYF0`00<7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001J
EUYF009JEPT000Uoo`P000=JEP03001JEUYF00=JEP03001JEUYF008002ioo`00;7oo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0`00
15YF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP04001JEUYFFUH9000HOol50004FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF1000
00=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD0
00=JEP04001JEUYFFUH2000MOol300000eYF001JEP02FUH2000]Ool002ioo`800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH5
0004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP02FUH8000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P000UYF00<005YFFUH00eYF00@0
05YFFUIJEP80021oo`8000=JEP8002eoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00006P001eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
100000=JEP00FUH015YF00@005YFFUIJEP80029oo`800003FUH0000002eoo`00<goo0`0000=JEP00
FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo
00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00@000=JEP04001JEUYFFUH2
000SOol4000]Ool003Ioo`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEP0000<000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH;0003
FUH2000QOol2000015YF00000000;Goo000kOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5
000:Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF00000P00
0eYF00@005YFFUH0009JEP8001aoo`D000=JEP03001JEP0002eoo`00@goo4`003goo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF009JEPD0009JEP@001Eoo`L0
00=JEP03001JEUYF009JEP03001JEP0002eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP04001JEUYFFUH90009Ool90003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool003mooaL000moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000iOol60003FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUH00003000;Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD000Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH3000cOol0039oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00@0009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YF00000`00=Woo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200001Goo001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00002000
15YF1@0015YF00<005YFFUH00UYF1@00>Woo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF0`0027oo4P00?goo000]
Ool20004FUH00`00FUIJEP03FUH6000AOol80004FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP@005]o
o`00;7oo00<005YF000015YF00<005YF00000`007goo1P0015YF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000H005moo`00;7oo00<005YF00000eYF
0`00:Goo0`0000EJEP00FUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00;7oo00@005YF001JEP8002moo`80009JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`04001JEP00000cOol30002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol002aoo`800003FUH00000039o
o`<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008006=oo`00
;7oo0P000eYF0P00;Woo0P0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000UYF1@00GWoo000/Ool20003FUH00`00FUH00002000WOol40003FUH20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH00002
001KOol002eoo`05001JEUYFFUH00004FUH5000KOol70003FUH01000FUIJEUYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00UYF0P00FGoo
000]Ool01@00FUIJEUYF00001EYF00@005YFFUIJEQ/000=JEP03001JEUYF00AJEP04001JEUYFFUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJ
EP03FUH3001GOol002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP02
001EOol0031oo`<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03
001JEUYF00AJEP06001JEP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000Woo1@0015YF00D005YFFUIJEP0005Eoo`00<goo0`0000=JEP00FUH01UYF00<0
05YFFUH01EYF1@001EYF00<005YFFUH01EYF00@005YFFUIJEPD000=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00007Ool300000eYF001JEP02FUH2001DOol003Ioo`D0
00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF009JEPL000Qoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool20003FUH2001DOol003]oo`P000AJEPD00003FUH0
000000L000moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000<Ool2
00000eYF0000001DOol004=oo`X001Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000=Ool4001DOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0000;Ool2000015YF00000000E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000027oo0`000eYF00<005YF0000E7oo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000017oo100000=JEP00FUH00eYF00<005YF0000
E7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000010001EYF
00<005YFFUH00UYF0P00EGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01eYF
5@001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YF
FUH015YF00@005YFFUIJEP8005Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYF
FUH60009FUH00`00FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002
FUH00`00FUIJEP04FUH01000FUH00000F7oo001UOol01000FUIJEP001EYF00<005YFFUH01EYF1P00
0UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF00<0
05YF00000UYF00<005YFFUH00eYF0`00FWoo001UOol01000FUIJEP001EYF00<005YFFUH01@0025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P0015YF00<005YF
FUH00UYF00<005YF00000UYF00<005YF00000`00GGoo001UOol01000FUIJEP001EYF0`000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`00
00=JEP00FUH00eYF00<005YF00001000HGoo001UOol01000FUIJEP000eYF0P001EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF0000
00AJEP03001JEP0006Eoo`00IGoo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00
FUH0001UOol006Eoo`03001JEUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH007oo
06Aoo`00IGoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo
001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001oo`1TOol006Eoo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP04001JEP00001UOol006Eoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF001UOol006Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EP0006Ioo`00IWoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P00Igoo001WOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001XOol006Uoo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH2001Z
Ool006]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEP00001/Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00LGoo1@0025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@00LWoo001fOol60002FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH8001gOol007aoo`T000IJEP03001JEUYF00AJ
EP`007moo`00QGoo3@00Rgoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79575 m .59613 .74017 L .56496 .73827 L p .707 .577 .707 r
F P
0 g
s
.59613 .74017 m .59613 .79575 L .62796 .79497 L p .707 .577 .707 r
F P
0 g
s
.62796 .79497 m .62796 .73939 L .59613 .74017 L p .707 .577 .707 r
F P
0 g
s
.62796 .73939 m .62796 .79497 L .65735 .79159 L p .707 .577 .707 r
F P
0 g
s
.65735 .79159 m .65734 .73601 L .62796 .73939 L p .707 .577 .707 r
F P
0 g
s
.56496 .79385 m .56496 .73827 L .5375 .73387 L p .707 .577 .707 r
F P
0 g
s
.56496 .73827 m .56496 .79385 L .59613 .79575 L p .707 .577 .707 r
F P
0 g
s
.65734 .73601 m .65735 .79159 L .6814 .78594 L p .707 .577 .707 r
F P
0 g
s
.6814 .78594 m .6814 .73036 L .65734 .73601 L p .707 .577 .707 r
F P
0 g
s
.5375 .73387 m .5375 .78946 L .56496 .79385 L p .707 .577 .707 r
F P
0 g
s
.5375 .78946 m .5375 .73387 L .51644 .72742 L p .707 .577 .707 r
F P
0 g
s
.59613 .87822 m .59613 .84117 L .56496 .83927 L p .707 .577 .707 r
F P
0 g
s
.59613 .84117 m .59613 .87822 L .62796 .87745 L p .707 .577 .707 r
F P
0 g
s
.62796 .87745 m .62796 .84039 L .59613 .84117 L p .707 .577 .707 r
F P
0 g
s
.62796 .84039 m .62796 .87745 L .65735 .87407 L p .707 .577 .707 r
F P
0 g
s
.65735 .87407 m .65735 .83701 L .62796 .84039 L p .707 .577 .707 r
F P
0 g
s
.59613 .88194 m .59613 .86341 L .56496 .86151 L p .707 .577 .707 r
F P
0 g
s
.59613 .86341 m .59613 .88194 L .62796 .88116 L p .707 .577 .707 r
F P
0 g
s
.62796 .88116 m .62796 .86264 L .59613 .86341 L p .707 .577 .707 r
F P
0 g
s
.56496 .87632 m .56496 .83927 L .5375 .83487 L p .707 .577 .707 r
F P
0 g
s
.56496 .83927 m .56496 .87632 L .59613 .87822 L p .707 .577 .707 r
F P
0 g
s
.6814 .73036 m .6814 .78594 L .69777 .77858 L p .707 .577 .707 r
F P
0 g
s
.69777 .77858 m .69777 .72299 L .6814 .73036 L p .707 .577 .707 r
F P
0 g
s
.62796 .86264 m .62796 .88116 L .65735 .87778 L p .707 .577 .707 r
F P
0 g
s
.65735 .87778 m .65735 .85926 L .62796 .86264 L p .707 .577 .707 r
F P
0 g
s
.51644 .72742 m .51644 .783 L .5375 .78946 L p .707 .577 .707 r
F P
0 g
s
.56496 .86151 m .56496 .88004 L .59613 .88194 L p .707 .577 .707 r
F P
0 g
s
.56496 .88004 m .56496 .86151 L .5375 .85712 L p .707 .577 .707 r
F P
0 g
s
.65735 .83701 m .65735 .87407 L .6814 .86842 L p .707 .577 .707 r
F P
0 g
s
.6814 .86842 m .6814 .83136 L .65735 .83701 L p .707 .577 .707 r
F P
0 g
s
.5375 .83487 m .5375 .87193 L .56496 .87632 L p .707 .577 .707 r
F P
0 g
s
.51644 .783 m .51644 .72742 L .50385 .71954 L p .707 .577 .707 r
F P
0 g
s
.5375 .85712 m .5375 .87565 L .56496 .88004 L p .707 .577 .707 r
F P
0 g
s
.65735 .85926 m .65735 .87778 L .6814 .87214 L p .707 .577 .707 r
F P
0 g
s
.6814 .87214 m .6814 .85361 L .65735 .85926 L p .707 .577 .707 r
F P
0 g
s
.5375 .87193 m .5375 .83487 L .51644 .82842 L p .707 .577 .707 r
F P
0 g
s
.5375 .87565 m .5375 .85712 L .51644 .85067 L p .707 .577 .707 r
F P
0 g
s
.51644 .82842 m .51644 .86548 L .5375 .87193 L p .707 .577 .707 r
F P
0 g
s
.50385 .71954 m .50385 .77512 L .51644 .783 L p .707 .577 .707 r
F P
0 g
s
.69777 .72299 m .69777 .77858 L .70485 .77021 L p .707 .577 .707 r
F P
0 g
s
.70485 .77021 m .70485 .71463 L .69777 .72299 L p .707 .577 .707 r
F P
0 g
s
.51644 .85067 m .51644 .86919 L .5375 .87565 L p .707 .577 .707 r
F P
0 g
s
.6814 .83136 m .6814 .86842 L .69777 .86105 L p .707 .577 .707 r
F P
0 g
s
.69777 .86105 m .69777 .82399 L .6814 .83136 L p .707 .577 .707 r
F P
0 g
s
.6814 .85361 m .6814 .87214 L .69777 .86477 L p .707 .577 .707 r
F P
0 g
s
.69777 .86477 m .69777 .84624 L .6814 .85361 L p .707 .577 .707 r
F P
0 g
s
.49044 .76343 m .49044 .26154 L .44643 .25886 L p .707 .577 .707 r
F P
0 g
s
.50385 .77512 m .50385 .71954 L .50095 .71099 L p .707 .577 .707 r
F P
0 g
s
.50095 .71099 m .50095 .76658 L .50385 .77512 L p .707 .577 .707 r
F P
0 g
s
.50095 .76658 m .50095 .71099 L .50804 .70263 L p .707 .577 .707 r
F P
0 g
s
.50804 .70263 m .50804 .75821 L .50095 .76658 L p .707 .577 .707 r
F P
0 g
s
.50804 .75821 m .50804 .70263 L .5244 .69526 L p .707 .577 .707 r
F P
0 g
s
.5244 .69526 m .5244 .75084 L .50804 .75821 L p .707 .577 .707 r
F P
0 g
s
.5244 .75084 m .5244 .69526 L .54846 .68961 L p .707 .577 .707 r
F P
0 g
s
.54846 .68961 m .54846 .74519 L .5244 .75084 L p .707 .577 .707 r
F P
0 g
s
.49044 .26154 m .49044 .76343 L .53538 .76233 L p .707 .577 .707 r
F P
0 g
s
.53538 .76233 m .53538 .26044 L .49044 .26154 L p .707 .577 .707 r
F P
0 g
s
.51644 .86548 m .51644 .82842 L .50385 .82054 L p .707 .577 .707 r
F P
0 g
s
.54846 .74519 m .54846 .68961 L .57784 .68623 L p .707 .577 .707 r
F P
0 g
s
.57784 .68623 m .57784 .74182 L .54846 .74519 L p .707 .577 .707 r
F P
0 g
s
.53538 .26044 m .53538 .76233 L .57686 .75756 L p .707 .577 .707 r
F P
0 g
s
.57686 .75756 m .57686 .25567 L .53538 .26044 L p .707 .577 .707 r
F P
0 g
s
.51644 .86919 m .51644 .85067 L .50385 .84278 L p .707 .577 .707 r
F P
0 g
s
.44643 .76075 m .44643 .25886 L .40766 .25266 L p .707 .577 .707 r
F P
0 g
s
.44643 .25886 m .44643 .76075 L .49044 .76343 L p .707 .577 .707 r
F P
0 g
s
.50385 .82054 m .50385 .85759 L .51644 .86548 L p .707 .577 .707 r
F P
0 g
s
.50385 .84278 m .50385 .86131 L .51644 .86919 L p .707 .577 .707 r
F P
0 g
s
.69777 .82399 m .69777 .86105 L .70485 .85268 L p .707 .577 .707 r
F P
0 g
s
.70485 .85268 m .70485 .81563 L .69777 .82399 L p .707 .577 .707 r
F P
0 g
s
.70485 .71463 m .70485 .77021 L .70195 .76167 L p .707 .577 .707 r
F P
0 g
s
.70195 .76167 m .70195 .70609 L .70485 .71463 L p .707 .577 .707 r
F P
0 g
s
.64085 .68736 m .64085 .74294 L .60968 .74104 L p .707 .577 .707 r
F P
0 g
s
.60968 .74104 m .60968 .68546 L .64085 .68736 L p .707 .577 .707 r
F P
0 g
s
.57784 .74182 m .57784 .68623 L .60968 .68546 L p .707 .577 .707 r
F P
0 g
s
.60968 .68546 m .60968 .74104 L .57784 .74182 L p .707 .577 .707 r
F P
0 g
s
.57686 .25567 m .57686 .75756 L .61082 .74959 L p .707 .577 .707 r
F P
0 g
s
.61082 .74959 m .61082 .2477 L .57686 .25567 L p .707 .577 .707 r
F P
0 g
s
.69777 .84624 m .69777 .86477 L .70485 .8564 L p .707 .577 .707 r
F P
0 g
s
.70485 .8564 m .70485 .83788 L .69777 .84624 L p .707 .577 .707 r
F P
0 g
s
.50385 .85759 m .50385 .82054 L .50095 .81199 L p .707 .577 .707 r
F P
0 g
s
.40766 .75455 m .40766 .25266 L .37794 .24355 L p .707 .577 .707 r
F P
0 g
s
.40766 .25266 m .40766 .75455 L .44643 .76075 L p .707 .577 .707 r
F P
0 g
s
.50385 .86131 m .50385 .84278 L .50095 .83424 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .76398 Mdot
.5 Mabswid
.50095 .81199 m .50095 .84905 L .50385 .85759 L p .707 .577 .707 r
F P
0 g
s
.50095 .83424 m .50095 .85277 L .50385 .86131 L p .707 .577 .707 r
F P
0 g
s
.70485 .81563 m .70485 .85268 L .70195 .84414 L p .707 .577 .707 r
F P
0 g
s
.70195 .84414 m .70195 .80709 L .70485 .81563 L p .707 .577 .707 r
F P
0 g
s
.61082 .2477 m .61082 .74959 L .63393 .73918 L p .707 .577 .707 r
F P
0 g
s
.63393 .73918 m .63393 .2373 L .61082 .2477 L p .707 .577 .707 r
F P
0 g
s
.70195 .70609 m .70195 .76167 L .68936 .75378 L p .707 .577 .707 r
F P
0 g
s
.68936 .75378 m .68936 .6982 L .70195 .70609 L p .707 .577 .707 r
F P
0 g
s
.70485 .83788 m .70485 .8564 L .70195 .84786 L p .707 .577 .707 r
F P
0 g
s
.70195 .84786 m .70195 .82933 L .70485 .83788 L p .707 .577 .707 r
F P
0 g
s
.25312 .75893 m .25312 .70335 L .22195 .70145 L p .707 .577 .707 r
F P
0 g
s
.25312 .70335 m .25312 .75893 L .28495 .75816 L p .707 .577 .707 r
F P
0 g
s
.28495 .75816 m .28495 .70257 L .25312 .70335 L p .707 .577 .707 r
F P
0 g
s
.50095 .84905 m .50095 .81199 L .50804 .80363 L p .707 .577 .707 r
F P
0 g
s
.28495 .70257 m .28495 .75816 L .31434 .75478 L p .707 .577 .707 r
F P
0 g
s
.31434 .75478 m .31434 .6992 L .28495 .70257 L p .707 .577 .707 r
F P
0 g
s
.37794 .74543 m .37794 .24355 L .36016 .23242 L p .707 .577 .707 r
F P
0 g
s
.37794 .24355 m .37794 .74543 L .40766 .75455 L p .707 .577 .707 r
F P
0 g
s
.22195 .75703 m .22195 .70145 L .19449 .69706 L p .707 .577 .707 r
F P
0 g
s
.22195 .70145 m .22195 .75703 L .25312 .75893 L p .707 .577 .707 r
F P
0 g
s
.50095 .85277 m .50095 .83424 L .50804 .82588 L p .707 .577 .707 r
F P
0 g
s
.50804 .80363 m .50804 .84069 L .50095 .84905 L p .707 .577 .707 r
F P
0 g
s
.50804 .82588 m .50804 .8444 L .50095 .85277 L p .707 .577 .707 r
F P
0 g
s
.31434 .6992 m .31434 .75478 L .33839 .74913 L p .707 .577 .707 r
F P
0 g
s
.33839 .74913 m .33839 .69355 L .31434 .6992 L p .707 .577 .707 r
F P
0 g
s
.70195 .80709 m .70195 .84414 L .68936 .83626 L p .707 .577 .707 r
F P
0 g
s
.68936 .83626 m .68936 .7992 L .70195 .80709 L p .707 .577 .707 r
F P
0 g
s
.68936 .6982 m .68936 .75378 L .66831 .74733 L p .707 .577 .707 r
F P
0 g
s
.66831 .74733 m .66831 .69175 L .68936 .6982 L p .707 .577 .707 r
F P
0 g
s
.19449 .69706 m .19449 .75264 L .22195 .75703 L p .707 .577 .707 r
F P
0 g
s
.19449 .75264 m .19449 .69706 L .17343 .6906 L p .707 .577 .707 r
F P
0 g
s
.70195 .82933 m .70195 .84786 L .68936 .83998 L p .707 .577 .707 r
F P
0 g
s
.68936 .83998 m .68936 .82145 L .70195 .82933 L p .707 .577 .707 r
F P
0 g
s
.64085 .74294 m .64085 .68736 L .66831 .69175 L p .707 .577 .707 r
F P
0 g
s
.63393 .2373 m .63393 .73918 L .64393 .72738 L p .707 .577 .707 r
F P
0 g
s
.64393 .72738 m .64393 .22549 L .63393 .2373 L p .707 .577 .707 r
F P
0 g
s
.25312 .84141 m .25312 .80435 L .22195 .80245 L p .707 .577 .707 r
F P
0 g
s
.25312 .80435 m .25312 .84141 L .28495 .84063 L p .707 .577 .707 r
F P
0 g
s
.28495 .84063 m .28495 .80358 L .25312 .80435 L p .707 .577 .707 r
F P
0 g
s
.50804 .84069 m .50804 .80363 L .5244 .79626 L p .707 .577 .707 r
F P
0 g
s
.28495 .80358 m .28495 .84063 L .31434 .83725 L p .707 .577 .707 r
F P
0 g
s
.31434 .83725 m .31434 .8002 L .28495 .80358 L p .707 .577 .707 r
F P
0 g
s
.25312 .84513 m .25312 .8266 L .22195 .8247 L p .707 .577 .707 r
F P
0 g
s
.25312 .8266 m .25312 .84513 L .28495 .84435 L p .707 .577 .707 r
F P
0 g
s
.28495 .84435 m .28495 .82582 L .25312 .8266 L p .707 .577 .707 r
F P
0 g
s
.22195 .83951 m .22195 .80245 L .19449 .79806 L p .707 .577 .707 r
F P
0 g
s
.22195 .80245 m .22195 .83951 L .25312 .84141 L p .707 .577 .707 r
F P
0 g
s
.33839 .69355 m .33839 .74913 L .35476 .74176 L p .707 .577 .707 r
F P
0 g
s
.35476 .74176 m .35476 .68618 L .33839 .69355 L p .707 .577 .707 r
F P
0 g
s
.50804 .8444 m .50804 .82588 L .5244 .81851 L p .707 .577 .707 r
F P
0 g
s
.28495 .82582 m .28495 .84435 L .31434 .84097 L p .707 .577 .707 r
F P
0 g
s
.31434 .84097 m .31434 .82244 L .28495 .82582 L p .707 .577 .707 r
F P
0 g
s
.17343 .6906 m .17343 .74619 L .19449 .75264 L p .707 .577 .707 r
F P
0 g
s
.22195 .8247 m .22195 .84323 L .25312 .84513 L p .707 .577 .707 r
F P
0 g
s
.5244 .79626 m .5244 .83332 L .50804 .84069 L p .707 .577 .707 r
F P
0 g
s
.22195 .84323 m .22195 .8247 L .19449 .82031 L p .707 .577 .707 r
F P
0 g
s
.66831 .69175 m .66831 .74733 L .64085 .74294 L p .707 .577 .707 r
F P
0 g
s
.5244 .81851 m .5244 .83704 L .50804 .8444 L p .707 .577 .707 r
F P
0 g
s
.31434 .8002 m .31434 .83725 L .33839 .8316 L p .707 .577 .707 r
F P
0 g
s
.33839 .8316 m .33839 .79455 L .31434 .8002 L p .707 .577 .707 r
F P
0 g
s
.35476 .68618 m .35476 .74176 L .36184 .7334 L p .707 .577 .707 r
F P
0 g
s
.36184 .7334 m .36184 .67781 L .35476 .68618 L p .707 .577 .707 r
F P
0 g
s
.36184 .67781 m .36184 .7334 L .35894 .72485 L p .707 .577 .707 r
F P
0 g
s
.35894 .72485 m .35894 .66927 L .36184 .67781 L p .707 .577 .707 r
F P
0 g
s
.36016 .7343 m .36016 .23242 L .35607 .22036 L p .707 .577 .707 r
F P
0 g
s
.36016 .23242 m .36016 .7343 L .37794 .74543 L p .707 .577 .707 r
F P
0 g
s
.19449 .79806 m .19449 .83511 L .22195 .83951 L p .707 .577 .707 r
F P
0 g
s
.17343 .74619 m .17343 .6906 L .16084 .68272 L p .707 .577 .707 r
F P
0 g
s
.19449 .82031 m .19449 .83883 L .22195 .84323 L p .707 .577 .707 r
F P
0 g
s
.68936 .7992 m .68936 .83626 L .66831 .8298 L p .707 .577 .707 r
F P
0 g
s
.66831 .8298 m .66831 .79275 L .68936 .7992 L p .707 .577 .707 r
F P
0 g
s
.31434 .82244 m .31434 .84097 L .33839 .83532 L p .707 .577 .707 r
F P
0 g
s
.33839 .83532 m .33839 .81679 L .31434 .82244 L p .707 .577 .707 r
F P
0 g
s
.19449 .83511 m .19449 .79806 L .17343 .79161 L p .707 .577 .707 r
F P
0 g
s
.68936 .82145 m .68936 .83998 L .66831 .83352 L p .707 .577 .707 r
F P
0 g
s
.66831 .83352 m .66831 .815 L .68936 .82145 L p .707 .577 .707 r
F P
0 g
s
.19449 .83883 m .19449 .82031 L .17343 .81385 L p .707 .577 .707 r
F P
0 g
s
.5244 .83332 m .5244 .79626 L .54846 .79061 L p .707 .577 .707 r
F P
0 g
s
.17343 .79161 m .17343 .82866 L .19449 .83511 L p .707 .577 .707 r
F P
0 g
s
.16084 .68272 m .16084 .7383 L .17343 .74619 L p .707 .577 .707 r
F P
0 g
s
.17343 .81385 m .17343 .83238 L .19449 .83883 L p .707 .577 .707 r
F P
0 g
s
.33839 .79455 m .33839 .8316 L .35476 .82423 L p .707 .577 .707 r
F P
0 g
s
.35476 .82423 m .35476 .78718 L .33839 .79455 L p .707 .577 .707 r
F P
0 g
s
.5244 .83704 m .5244 .81851 L .54846 .81286 L p .707 .577 .707 r
F P
0 g
s
.54846 .79061 m .54846 .82767 L .5244 .83332 L p .707 .577 .707 r
F P
0 g
s
.54846 .81286 m .54846 .83139 L .5244 .83704 L p .707 .577 .707 r
F P
0 g
s
.33839 .81679 m .33839 .83532 L .35476 .82795 L p .707 .577 .707 r
F P
0 g
s
.35476 .82795 m .35476 .80942 L .33839 .81679 L p .707 .577 .707 r
F P
0 g
s
.64393 .22549 m .64393 .72738 L .63984 .71532 L p .707 .577 .707 r
F P
0 g
s
.63984 .71532 m .63984 .21343 L .64393 .22549 L p .707 .577 .707 r
F P
0 g
s
.66831 .79275 m .66831 .8298 L .64085 .82541 L p .707 .577 .707 r
F P
0 g
s
.64085 .82541 m .64085 .78836 L .66831 .79275 L p .707 .577 .707 r
F P
0 g
s
.17343 .82866 m .17343 .79161 L .16084 .78372 L p .707 .577 .707 r
F P
0 g
s
.16084 .7383 m .16084 .68272 L .15794 .67418 L p .707 .577 .707 r
F P
0 g
s
.66831 .815 m .66831 .83352 L .64085 .82913 L p .707 .577 .707 r
F P
0 g
s
.64085 .82913 m .64085 .8106 L .66831 .815 L p .707 .577 .707 r
F P
0 g
s
.54846 .82767 m .54846 .79061 L .57784 .78723 L p .707 .577 .707 r
F P
0 g
s
.17343 .83238 m .17343 .81385 L .16084 .80597 L p .707 .577 .707 r
F P
0 g
s
.54846 .83139 m .54846 .81286 L .57784 .80948 L p .707 .577 .707 r
F P
0 g
s
.16084 .78372 m .16084 .82078 L .17343 .82866 L p .707 .577 .707 r
F P
0 g
s
.16084 .80597 m .16084 .8245 L .17343 .83238 L p .707 .577 .707 r
F P
0 g
s
.64085 .78836 m .64085 .82541 L .60968 .82351 L p .707 .577 .707 r
F P
0 g
s
.60968 .82351 m .60968 .78646 L .64085 .78836 L p .707 .577 .707 r
F P
0 g
s
.57784 .78723 m .57784 .82429 L .54846 .82767 L p .707 .577 .707 r
F P
0 g
s
.35894 .66927 m .35894 .72485 L .34635 .71697 L p .707 .577 .707 r
F P
0 g
s
.34635 .71697 m .34635 .66139 L .35894 .66927 L p .707 .577 .707 r
F P
0 g
s
.35607 .22036 m .35607 .72224 L .36016 .7343 L p .707 .577 .707 r
F P
0 g
s
.35607 .72224 m .35607 .22036 L .36607 .20855 L p .707 .577 .707 r
F P
0 g
s
.57784 .80948 m .57784 .82801 L .54846 .83139 L p .707 .577 .707 r
F P
0 g
s
.15794 .67418 m .15794 .72976 L .16084 .7383 L p .707 .577 .707 r
F P
0 g
s
.57784 .82429 m .57784 .78723 L .60968 .78646 L p .707 .577 .707 r
F P
0 g
s
.35476 .78718 m .35476 .82423 L .36184 .81587 L p .707 .577 .707 r
F P
0 g
s
.36184 .81587 m .36184 .77881 L .35476 .78718 L p .707 .577 .707 r
F P
0 g
s
.64085 .8106 m .64085 .82913 L .60968 .82723 L p .707 .577 .707 r
F P
0 g
s
.60968 .82723 m .60968 .8087 L .64085 .8106 L p .707 .577 .707 r
F P
0 g
s
.60968 .78646 m .60968 .82351 L .57784 .82429 L p .707 .577 .707 r
F P
0 g
s
.57784 .82801 m .57784 .80948 L .60968 .8087 L p .707 .577 .707 r
F P
0 g
s
.35476 .80942 m .35476 .82795 L .36184 .81959 L p .707 .577 .707 r
F P
0 g
s
.36184 .81959 m .36184 .80106 L .35476 .80942 L p .707 .577 .707 r
F P
0 g
s
.60968 .8087 m .60968 .82723 L .57784 .82801 L p .707 .577 .707 r
F P
0 g
s
.16084 .82078 m .16084 .78372 L .15794 .77518 L p .707 .577 .707 r
F P
0 g
s
.15794 .72976 m .15794 .67418 L .16503 .66581 L p .707 .577 .707 r
F P
0 g
s
.16084 .8245 m .16084 .80597 L .15794 .79743 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .77518 m .15794 .81223 L .16084 .82078 L p .707 .577 .707 r
F P
0 g
s
.63984 .21343 m .63984 .71532 L .62206 .70419 L p .707 .577 .707 r
F P
0 g
s
.62206 .70419 m .62206 .2023 L .63984 .21343 L p .707 .577 .707 r
F P
0 g
s
.15794 .79743 m .15794 .81595 L .16084 .8245 L p .707 .577 .707 r
F P
0 g
s
.36184 .77881 m .36184 .81587 L .35894 .80733 L p .707 .577 .707 r
F P
0 g
s
.35894 .80733 m .35894 .77027 L .36184 .77881 L p .707 .577 .707 r
F P
0 g
s
.16503 .66581 m .16503 .7214 L .15794 .72976 L p .707 .577 .707 r
F P
0 g
s
.36184 .80106 m .36184 .81959 L .35894 .81105 L p .707 .577 .707 r
F P
0 g
s
.35894 .81105 m .35894 .79252 L .36184 .80106 L p .707 .577 .707 r
F P
0 g
s
.36607 .71044 m .36607 .20855 L .38918 .19815 L p .707 .577 .707 r
F P
0 g
s
.36607 .20855 m .36607 .71044 L .35607 .72224 L p .707 .577 .707 r
F P
0 g
s
.15794 .81223 m .15794 .77518 L .16503 .76682 L p .707 .577 .707 r
F P
0 g
s
.16503 .7214 m .16503 .66581 L .1814 .65845 L p .707 .577 .707 r
F P
0 g
s
.15794 .81595 m .15794 .79743 L .16503 .78906 L p .707 .577 .707 r
F P
0 g
s
.16503 .76682 m .16503 .80387 L .15794 .81223 L p .707 .577 .707 r
F P
0 g
s
.16503 .78906 m .16503 .80759 L .15794 .81595 L p .707 .577 .707 r
F P
0 g
s
.1814 .65845 m .1814 .71403 L .16503 .7214 L p .707 .577 .707 r
F P
0 g
s
.35894 .77027 m .35894 .80733 L .34635 .79944 L p .707 .577 .707 r
F P
0 g
s
.34635 .79944 m .34635 .76239 L .35894 .77027 L p .707 .577 .707 r
F P
0 g
s
.34635 .66139 m .34635 .71697 L .3253 .71052 L p .707 .577 .707 r
F P
0 g
s
.3253 .71052 m .3253 .65493 L .34635 .66139 L p .707 .577 .707 r
F P
0 g
s
.62206 .2023 m .62206 .70419 L .59233 .69507 L p .707 .577 .707 r
F P
0 g
s
.59233 .69507 m .59233 .19319 L .62206 .2023 L p .707 .577 .707 r
F P
0 g
s
.35894 .79252 m .35894 .81105 L .34635 .80316 L p .707 .577 .707 r
F P
0 g
s
.34635 .80316 m .34635 .78463 L .35894 .79252 L p .707 .577 .707 r
F P
0 g
s
.1814 .71403 m .1814 .65845 L .20545 .6528 L p .707 .577 .707 r
F P
0 g
s
.16503 .80387 m .16503 .76682 L .1814 .75945 L p .707 .577 .707 r
F P
0 g
s
.38918 .19815 m .38918 .70003 L .36607 .71044 L p .707 .577 .707 r
F P
0 g
s
.38918 .70003 m .38918 .19815 L .42314 .19017 L p .707 .577 .707 r
F P
0 g
s
.16503 .80759 m .16503 .78906 L .1814 .78169 L p .707 .577 .707 r
F P
0 g
s
.1814 .75945 m .1814 .7965 L .16503 .80387 L p .707 .577 .707 r
F P
0 g
s
.3253 .65493 m .3253 .71052 L .29784 .70612 L p .707 .577 .707 r
F P
0 g
s
.29784 .70612 m .29784 .65054 L .3253 .65493 L p .707 .577 .707 r
F P
0 g
s
.1814 .78169 m .1814 .80022 L .16503 .80759 L p .707 .577 .707 r
F P
0 g
s
.20545 .6528 m .20545 .70838 L .1814 .71403 L p .707 .577 .707 r
F P
0 g
s
.34635 .76239 m .34635 .79944 L .3253 .79299 L p .707 .577 .707 r
F P
0 g
s
.3253 .79299 m .3253 .75593 L .34635 .76239 L p .707 .577 .707 r
F P
0 g
s
.20545 .70838 m .20545 .6528 L .23483 .64942 L p .707 .577 .707 r
F P
0 g
s
.34635 .78463 m .34635 .80316 L .3253 .79671 L p .707 .577 .707 r
F P
0 g
s
.3253 .79671 m .3253 .77818 L .34635 .78463 L p .707 .577 .707 r
F P
0 g
s
.59233 .19319 m .59233 .69507 L .55357 .68887 L p .707 .577 .707 r
F P
0 g
s
.55357 .68887 m .55357 .18698 L .59233 .19319 L p .707 .577 .707 r
F P
0 g
s
.1814 .7965 m .1814 .75945 L .20545 .7538 L p .707 .577 .707 r
F P
0 g
s
.29784 .65054 m .29784 .70612 L .26667 .70422 L p .707 .577 .707 r
F P
0 g
s
.26667 .70422 m .26667 .64864 L .29784 .65054 L p .707 .577 .707 r
F P
0 g
s
.23483 .705 m .23483 .64942 L .26667 .64864 L p .707 .577 .707 r
F P
0 g
s
.23483 .64942 m .23483 .705 L .20545 .70838 L p .707 .577 .707 r
F P
0 g
s
.1814 .80022 m .1814 .78169 L .20545 .77604 L p .707 .577 .707 r
F P
0 g
s
.42314 .69206 m .42314 .19017 L .46462 .1854 L p .707 .577 .707 r
F P
0 g
s
.42314 .19017 m .42314 .69206 L .38918 .70003 L p .707 .577 .707 r
F P
0 g
s
.26667 .64864 m .26667 .70422 L .23483 .705 L p .707 .577 .707 r
F P
0 g
s
.73333 .70371 m .73333 .64813 L .70216 .64623 L p .707 .577 .707 r
F P
0 g
s
.73333 .64813 m .73333 .70371 L .76517 .70293 L p .707 .577 .707 r
F P
0 g
s
.76517 .70293 m .76517 .64735 L .73333 .64813 L p .707 .577 .707 r
F P
0 g
s
.20545 .7538 m .20545 .79085 L .1814 .7965 L p .707 .577 .707 r
F P
0 g
s
.20545 .77604 m .20545 .79457 L .1814 .80022 L p .707 .577 .707 r
F P
0 g
s
.76517 .64735 m .76517 .70293 L .79455 .69955 L p .707 .577 .707 r
F P
0 g
s
.79455 .69955 m .79455 .64397 L .76517 .64735 L p .707 .577 .707 r
F P
0 g
s
.3253 .75593 m .3253 .79299 L .29784 .7886 L p .707 .577 .707 r
F P
0 g
s
.29784 .7886 m .29784 .75154 L .3253 .75593 L p .707 .577 .707 r
F P
0 g
s
.70216 .70181 m .70216 .64623 L .6747 .64184 L p .707 .577 .707 r
F P
0 g
s
.70216 .64623 m .70216 .70181 L .73333 .70371 L p .707 .577 .707 r
F P
0 g
s
.55357 .18698 m .55357 .68887 L .50956 .68619 L p .707 .577 .707 r
F P
0 g
s
.50956 .68619 m .50956 .1843 L .55357 .18698 L p .707 .577 .707 r
F P
0 g
s
.3253 .77818 m .3253 .79671 L .29784 .79232 L p .707 .577 .707 r
F P
0 g
s
.29784 .79232 m .29784 .77379 L .3253 .77818 L p .707 .577 .707 r
F P
0 g
s
.20545 .79085 m .20545 .7538 L .23483 .75042 L p .707 .577 .707 r
F P
0 g
s
.79455 .64397 m .79455 .69955 L .8186 .6939 L p .707 .577 .707 r
F P
0 g
s
.8186 .6939 m .8186 .63832 L .79455 .64397 L p .707 .577 .707 r
F P
0 g
s
.46462 .68729 m .46462 .1854 L .50956 .1843 L p .707 .577 .707 r
F P
0 g
s
.46462 .1854 m .46462 .68729 L .42314 .69206 L p .707 .577 .707 r
F P
0 g
s
.20545 .79457 m .20545 .77604 L .23483 .77266 L p .707 .577 .707 r
F P
0 g
s
.50956 .1843 m .50956 .68619 L .46462 .68729 L p .707 .577 .707 r
F P
0 g
s
.29784 .75154 m .29784 .7886 L .26667 .7867 L p .707 .577 .707 r
F P
0 g
s
.26667 .7867 m .26667 .74964 L .29784 .75154 L p .707 .577 .707 r
F P
0 g
s
.23483 .75042 m .23483 .78747 L .20545 .79085 L p .707 .577 .707 r
F P
0 g
s
.6747 .64184 m .6747 .69742 L .70216 .70181 L p .707 .577 .707 r
F P
0 g
s
.6747 .69742 m .6747 .64184 L .65365 .63538 L p .707 .577 .707 r
F P
0 g
s
.23483 .77266 m .23483 .79119 L .20545 .79457 L p .707 .577 .707 r
F P
0 g
s
.23483 .78747 m .23483 .75042 L .26667 .74964 L p .707 .577 .707 r
F P
0 g
s
.29784 .77379 m .29784 .79232 L .26667 .79041 L p .707 .577 .707 r
F P
0 g
s
.26667 .79041 m .26667 .77189 L .29784 .77379 L p .707 .577 .707 r
F P
0 g
s
.26667 .74964 m .26667 .7867 L .23483 .78747 L p .707 .577 .707 r
F P
0 g
s
.73333 .78618 m .73333 .74913 L .70216 .74723 L p .707 .577 .707 r
F P
0 g
s
.73333 .74913 m .73333 .78618 L .76517 .78541 L p .707 .577 .707 r
F P
0 g
s
.76517 .78541 m .76517 .74835 L .73333 .74913 L p .707 .577 .707 r
F P
0 g
s
.23483 .79119 m .23483 .77266 L .26667 .77189 L p .707 .577 .707 r
F P
0 g
s
.76517 .74835 m .76517 .78541 L .79455 .78203 L p .707 .577 .707 r
F P
0 g
s
.79455 .78203 m .79455 .74497 L .76517 .74835 L p .707 .577 .707 r
F P
0 g
s
.26667 .77189 m .26667 .79041 L .23483 .79119 L p .707 .577 .707 r
F P
0 g
s
.73333 .7899 m .73333 .77138 L .70216 .76948 L p .707 .577 .707 r
F P
0 g
s
.73333 .77138 m .73333 .7899 L .76517 .78913 L p .707 .577 .707 r
F P
0 g
s
.76517 .78913 m .76517 .7706 L .73333 .77138 L p .707 .577 .707 r
F P
0 g
s
.70216 .78428 m .70216 .74723 L .6747 .74284 L p .707 .577 .707 r
F P
0 g
s
.70216 .74723 m .70216 .78428 L .73333 .78618 L p .707 .577 .707 r
F P
0 g
s
.8186 .63832 m .8186 .6939 L .83497 .68654 L p .707 .577 .707 r
F P
0 g
s
.83497 .68654 m .83497 .63095 L .8186 .63832 L p .707 .577 .707 r
F P
0 g
s
.76517 .7706 m .76517 .78913 L .79455 .78575 L p .707 .577 .707 r
F P
0 g
s
.79455 .78575 m .79455 .76722 L .76517 .7706 L p .707 .577 .707 r
F P
0 g
s
.65365 .63538 m .65365 .69096 L .6747 .69742 L p .707 .577 .707 r
F P
0 g
s
.70216 .76948 m .70216 .788 L .73333 .7899 L p .707 .577 .707 r
F P
0 g
s
.70216 .788 m .70216 .76948 L .6747 .76508 L p .707 .577 .707 r
F P
0 g
s
.79455 .74497 m .79455 .78203 L .8186 .77638 L p .707 .577 .707 r
F P
0 g
s
.8186 .77638 m .8186 .73932 L .79455 .74497 L p .707 .577 .707 r
F P
0 g
s
.6747 .74284 m .6747 .77989 L .70216 .78428 L p .707 .577 .707 r
F P
0 g
s
.65365 .69096 m .65365 .63538 L .64105 .6275 L p .707 .577 .707 r
F P
0 g
s
.6747 .76508 m .6747 .78361 L .70216 .788 L p .707 .577 .707 r
F P
0 g
s
.79455 .76722 m .79455 .78575 L .8186 .7801 L p .707 .577 .707 r
F P
0 g
s
.8186 .7801 m .8186 .76157 L .79455 .76722 L p .707 .577 .707 r
F P
0 g
s
.6747 .77989 m .6747 .74284 L .65365 .73638 L p .707 .577 .707 r
F P
0 g
s
.6747 .78361 m .6747 .76508 L .65365 .75863 L p .707 .577 .707 r
F P
0 g
s
.65365 .73638 m .65365 .77344 L .6747 .77989 L p .707 .577 .707 r
F P
0 g
s
.64105 .6275 m .64105 .68308 L .65365 .69096 L p .707 .577 .707 r
F P
0 g
s
.83497 .63095 m .83497 .68654 L .84206 .67817 L p .707 .577 .707 r
F P
0 g
s
.84206 .67817 m .84205 .62259 L .83497 .63095 L p .707 .577 .707 r
F P
0 g
s
.65365 .75863 m .65365 .77716 L .6747 .78361 L p .707 .577 .707 r
F P
0 g
s
.8186 .73932 m .8186 .77638 L .83497 .76901 L p .707 .577 .707 r
F P
0 g
s
.83497 .76901 m .83497 .73196 L .8186 .73932 L p .707 .577 .707 r
F P
0 g
s
.8186 .76157 m .8186 .7801 L .83497 .77273 L p .707 .577 .707 r
F P
0 g
s
.83497 .77273 m .83497 .7542 L .8186 .76157 L p .707 .577 .707 r
F P
0 g
s
.65365 .77344 m .65365 .73638 L .64105 .7285 L p .707 .577 .707 r
F P
0 g
s
.64105 .68308 m .64105 .6275 L .63816 .61896 L p .707 .577 .707 r
F P
0 g
s
.65365 .77716 m .65365 .75863 L .64105 .75074 L p .707 .577 .707 r
F P
0 g
s
.64105 .7285 m .64105 .76555 L .65365 .77344 L p .707 .577 .707 r
F P
0 g
s
.64105 .75074 m .64105 .76927 L .65365 .77716 L p .707 .577 .707 r
F P
0 g
s
.63816 .61896 m .63816 .67454 L .64105 .68308 L p .707 .577 .707 r
F P
0 g
s
.83497 .73196 m .83497 .76901 L .84206 .76065 L p .707 .577 .707 r
F P
0 g
s
.84206 .76065 m .84206 .72359 L .83497 .73196 L p .707 .577 .707 r
F P
0 g
s
.84205 .62259 m .84206 .67817 L .83916 .66963 L p .707 .577 .707 r
F P
0 g
s
.83916 .66963 m .83916 .61405 L .84205 .62259 L p .707 .577 .707 r
F P
0 g
s
.83497 .7542 m .83497 .77273 L .84206 .76437 L p .707 .577 .707 r
F P
0 g
s
.84206 .76437 m .84206 .74584 L .83497 .7542 L p .707 .577 .707 r
F P
0 g
s
.64105 .76555 m .64105 .7285 L .63816 .71996 L p .707 .577 .707 r
F P
0 g
s
.63816 .67454 m .63816 .61896 L .64524 .61059 L p .707 .577 .707 r
F P
0 g
s
.64105 .76927 m .64105 .75074 L .63816 .7422 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63816 .71996 m .63816 .75701 L .64105 .76555 L p .707 .577 .707 r
F P
0 g
s
.63816 .7422 m .63816 .76073 L .64105 .76927 L p .707 .577 .707 r
F P
0 g
s
.84206 .72359 m .84206 .76065 L .83916 .7521 L p .707 .577 .707 r
F P
0 g
s
.83916 .7521 m .83916 .71505 L .84206 .72359 L p .707 .577 .707 r
F P
0 g
s
.64524 .61059 m .64524 .66617 L .63816 .67454 L p .707 .577 .707 r
F P
0 g
s
.83916 .61405 m .83916 .66963 L .82657 .66175 L p .707 .577 .707 r
F P
0 g
s
.82657 .66175 m .82657 .60616 L .83916 .61405 L p .707 .577 .707 r
F P
0 g
s
.84206 .74584 m .84206 .76437 L .83916 .75582 L p .707 .577 .707 r
F P
0 g
s
.83916 .75582 m .83916 .7373 L .84206 .74584 L p .707 .577 .707 r
F P
0 g
s
.39032 .6669 m .39032 .61131 L .35915 .60941 L p .707 .577 .707 r
F P
0 g
s
.39032 .61131 m .39032 .6669 L .42216 .66612 L p .707 .577 .707 r
F P
0 g
s
.42216 .66612 m .42216 .61054 L .39032 .61131 L p .707 .577 .707 r
F P
0 g
s
.63816 .75701 m .63816 .71996 L .64524 .71159 L p .707 .577 .707 r
F P
0 g
s
.64524 .66617 m .64524 .61059 L .66161 .60322 L p .707 .577 .707 r
F P
0 g
s
.42216 .61054 m .42216 .66612 L .45154 .66274 L p .707 .577 .707 r
F P
0 g
s
.45154 .66274 m .45154 .60716 L .42216 .61054 L p .707 .577 .707 r
F P
0 g
s
.35915 .66499 m .35915 .60941 L .33169 .60502 L p .707 .577 .707 r
F P
0 g
s
.35915 .60941 m .35915 .66499 L .39032 .6669 L p .707 .577 .707 r
F P
0 g
s
.63816 .76073 m .63816 .7422 L .64524 .73384 L p .707 .577 .707 r
F P
0 g
s
.64524 .71159 m .64524 .74865 L .63816 .75701 L p .707 .577 .707 r
F P
0 g
s
.64524 .73384 m .64524 .75237 L .63816 .76073 L p .707 .577 .707 r
F P
0 g
s
.45154 .60716 m .45154 .66274 L .47559 .65709 L p .707 .577 .707 r
F P
0 g
s
.47559 .65709 m .47559 .60151 L .45154 .60716 L p .707 .577 .707 r
F P
0 g
s
.66161 .60322 m .66161 .65881 L .64524 .66617 L p .707 .577 .707 r
F P
0 g
s
.83916 .71505 m .83916 .7521 L .82657 .74422 L p .707 .577 .707 r
F P
0 g
s
.82657 .74422 m .82657 .70717 L .83916 .71505 L p .707 .577 .707 r
F P
0 g
s
.82657 .60616 m .82657 .66175 L .80551 .65529 L p .707 .577 .707 r
F P
0 g
s
.80551 .65529 m .80551 .59971 L .82657 .60616 L p .707 .577 .707 r
F P
0 g
s
.33169 .60502 m .33169 .6606 L .35915 .66499 L p .707 .577 .707 r
F P
0 g
s
.33169 .6606 m .33169 .60502 L .31064 .59857 L p .707 .577 .707 r
F P
0 g
s
.83916 .7373 m .83916 .75582 L .82657 .74794 L p .707 .577 .707 r
F P
0 g
s
.82657 .74794 m .82657 .72941 L .83916 .7373 L p .707 .577 .707 r
F P
0 g
s
.39032 .74937 m .39032 .71231 L .35915 .71041 L p .707 .577 .707 r
F P
0 g
s
.39032 .71231 m .39032 .74937 L .42216 .74859 L p .707 .577 .707 r
F P
0 g
s
.42216 .74859 m .42216 .71154 L .39032 .71231 L p .707 .577 .707 r
F P
0 g
s
.66161 .65881 m .66161 .60322 L .68566 .59757 L p .707 .577 .707 r
F P
0 g
s
.64524 .74865 m .64524 .71159 L .66161 .70422 L p .707 .577 .707 r
F P
0 g
s
.42216 .71154 m .42216 .74859 L .45154 .74521 L p .707 .577 .707 r
F P
0 g
s
.45154 .74521 m .45154 .70816 L .42216 .71154 L p .707 .577 .707 r
F P
0 g
s
.39032 .75309 m .39032 .73456 L .35915 .73266 L p .707 .577 .707 r
F P
0 g
s
.39032 .73456 m .39032 .75309 L .42216 .75231 L p .707 .577 .707 r
F P
0 g
s
.42216 .75231 m .42216 .73378 L .39032 .73456 L p .707 .577 .707 r
F P
0 g
s
.35915 .74747 m .35915 .71041 L .33169 .70602 L p .707 .577 .707 r
F P
0 g
s
.35915 .71041 m .35915 .74747 L .39032 .74937 L p .707 .577 .707 r
F P
0 g
s
.47559 .60151 m .47559 .65709 L .49196 .64972 L p .707 .577 .707 r
F P
0 g
s
.49196 .64972 m .49196 .59414 L .47559 .60151 L p .707 .577 .707 r
F P
0 g
s
.64524 .75237 m .64524 .73384 L .66161 .72647 L p .707 .577 .707 r
F P
0 g
s
.42216 .73378 m .42216 .75231 L .45154 .74893 L p .707 .577 .707 r
F P
0 g
s
.45154 .74893 m .45154 .7304 L .42216 .73378 L p .707 .577 .707 r
F P
0 g
s
.31064 .59857 m .31064 .65415 L .33169 .6606 L p .707 .577 .707 r
F P
0 g
s
.35915 .73266 m .35915 .75119 L .39032 .75309 L p .707 .577 .707 r
F P
0 g
s
.66161 .70422 m .66161 .74128 L .64524 .74865 L p .707 .577 .707 r
F P
0 g
s
.35915 .75119 m .35915 .73266 L .33169 .72827 L p .707 .577 .707 r
F P
0 g
s
.80551 .59971 m .80551 .65529 L .77805 .6509 L p .707 .577 .707 r
F P
0 g
s
.77805 .6509 m .77805 .59532 L .80551 .59971 L p .707 .577 .707 r
F P
0 g
s
.66161 .72647 m .66161 .745 L .64524 .75237 L p .707 .577 .707 r
F P
0 g
s
.45154 .70816 m .45154 .74521 L .47559 .73956 L p .707 .577 .707 r
F P
0 g
s
.47559 .73956 m .47559 .70251 L .45154 .70816 L p .707 .577 .707 r
F P
0 g
s
.68566 .59757 m .68566 .65316 L .66161 .65881 L p .707 .577 .707 r
F P
0 g
s
.33169 .70602 m .33169 .74308 L .35915 .74747 L p .707 .577 .707 r
F P
0 g
s
.31064 .65415 m .31064 .59857 L .29804 .59068 L p .707 .577 .707 r
F P
0 g
s
.33169 .72827 m .33169 .74679 L .35915 .75119 L p .707 .577 .707 r
F P
0 g
s
.82657 .70717 m .82657 .74422 L .80551 .73777 L p .707 .577 .707 r
F P
0 g
s
.80551 .73777 m .80551 .70071 L .82657 .70717 L p .707 .577 .707 r
F P
0 g
s
.45154 .7304 m .45154 .74893 L .47559 .74328 L p .707 .577 .707 r
F P
0 g
s
.47559 .74328 m .47559 .72475 L .45154 .7304 L p .707 .577 .707 r
F P
0 g
s
.68566 .65316 m .68566 .59757 L .71504 .59419 L p .707 .577 .707 r
F P
0 g
s
.33169 .74308 m .33169 .70602 L .31064 .69957 L p .707 .577 .707 r
F P
0 g
s
.82657 .72941 m .82657 .74794 L .80551 .74148 L p .707 .577 .707 r
F P
0 g
s
.80551 .74148 m .80551 .72296 L .82657 .72941 L p .707 .577 .707 r
F P
0 g
s
.33169 .74679 m .33169 .72827 L .31064 .72181 L p .707 .577 .707 r
F P
0 g
s
.66161 .74128 m .66161 .70422 L .68566 .69857 L p .707 .577 .707 r
F P
0 g
s
.77805 .59532 m .77805 .6509 L .74688 .649 L p .707 .577 .707 r
F P
0 g
s
.74688 .649 m .74688 .59342 L .77805 .59532 L p .707 .577 .707 r
F P
0 g
s
.31064 .69957 m .31064 .73662 L .33169 .74308 L p .707 .577 .707 r
F P
0 g
s
.29804 .59068 m .29804 .64626 L .31064 .65415 L p .707 .577 .707 r
F P
0 g
s
.71504 .64978 m .71504 .59419 L .74688 .59342 L p .707 .577 .707 r
F P
0 g
s
.71504 .59419 m .71504 .64978 L .68566 .65316 L p .707 .577 .707 r
F P
0 g
s
.49196 .59414 m .49196 .64972 L .49904 .64136 L p .707 .577 .707 r
F P
0 g
s
.49904 .64136 m .49904 .58577 L .49196 .59414 L p .707 .577 .707 r
F P
0 g
s
.31064 .72181 m .31064 .74034 L .33169 .74679 L p .707 .577 .707 r
F P
0 g
s
.47559 .70251 m .47559 .73956 L .49196 .7322 L p .707 .577 .707 r
F P
0 g
s
.49196 .7322 m .49196 .69514 L .47559 .70251 L p .707 .577 .707 r
F P
0 g
s
.66161 .745 m .66161 .72647 L .68566 .72082 L p .707 .577 .707 r
F P
0 g
s
.74688 .59342 m .74688 .649 L .71504 .64978 L p .707 .577 .707 r
F P
0 g
s
.68566 .69857 m .68566 .73563 L .66161 .74128 L p .707 .577 .707 r
F P
0 g
s
.68566 .72082 m .68566 .73935 L .66161 .745 L p .707 .577 .707 r
F P
0 g
s
.47559 .72475 m .47559 .74328 L .49196 .73591 L p .707 .577 .707 r
F P
0 g
s
.49196 .73591 m .49196 .71739 L .47559 .72475 L p .707 .577 .707 r
F P
0 g
s
.80551 .70071 m .80551 .73777 L .77805 .73337 L p .707 .577 .707 r
F P
0 g
s
.77805 .73337 m .77805 .69632 L .80551 .70071 L p .707 .577 .707 r
F P
0 g
s
.31064 .73662 m .31064 .69957 L .29804 .69168 L p .707 .577 .707 r
F P
0 g
s
.29804 .64626 m .29804 .59068 L .29515 .58214 L p .707 .577 .707 r
F P
0 g
s
.80551 .72296 m .80551 .74148 L .77805 .73709 L p .707 .577 .707 r
F P
0 g
s
.77805 .73709 m .77805 .71857 L .80551 .72296 L p .707 .577 .707 r
F P
0 g
s
.68566 .73563 m .68566 .69857 L .71504 .6952 L p .707 .577 .707 r
F P
0 g
s
.31064 .74034 m .31064 .72181 L .29804 .71393 L p .707 .577 .707 r
F P
0 g
s
.68566 .73935 m .68566 .72082 L .71504 .71744 L p .707 .577 .707 r
F P
0 g
s
.29804 .69168 m .29804 .72874 L .31064 .73662 L p .707 .577 .707 r
F P
0 g
s
.29804 .71393 m .29804 .73246 L .31064 .74034 L p .707 .577 .707 r
F P
0 g
s
.77805 .69632 m .77805 .73337 L .74688 .73147 L p .707 .577 .707 r
F P
0 g
s
.74688 .73147 m .74688 .69442 L .77805 .69632 L p .707 .577 .707 r
F P
0 g
s
.71504 .6952 m .71504 .73225 L .68566 .73563 L p .707 .577 .707 r
F P
0 g
s
.71504 .71744 m .71504 .73597 L .68566 .73935 L p .707 .577 .707 r
F P
0 g
s
.29515 .58214 m .29515 .63772 L .29804 .64626 L p .707 .577 .707 r
F P
0 g
s
.71504 .73225 m .71504 .6952 L .74688 .69442 L p .707 .577 .707 r
F P
0 g
s
.49196 .69514 m .49196 .7322 L .49904 .72383 L p .707 .577 .707 r
F P
0 g
s
.49904 .72383 m .49904 .68678 L .49196 .69514 L p .707 .577 .707 r
F P
0 g
s
.49904 .58577 m .49904 .64136 L .49615 .63281 L p .707 .577 .707 r
F P
0 g
s
.49615 .63281 m .49615 .57723 L .49904 .58577 L p .707 .577 .707 r
F P
0 g
s
.77805 .71857 m .77805 .73709 L .74688 .73519 L p .707 .577 .707 r
F P
0 g
s
.74688 .73519 m .74688 .71666 L .77805 .71857 L p .707 .577 .707 r
F P
0 g
s
.74688 .69442 m .74688 .73147 L .71504 .73225 L p .707 .577 .707 r
F P
0 g
s
.71504 .73597 m .71504 .71744 L .74688 .71666 L p .707 .577 .707 r
F P
0 g
s
.49196 .71739 m .49196 .73591 L .49904 .72755 L p .707 .577 .707 r
F P
0 g
s
.49904 .72755 m .49904 .70902 L .49196 .71739 L p .707 .577 .707 r
F P
0 g
s
.74688 .71666 m .74688 .73519 L .71504 .73597 L p .707 .577 .707 r
F P
0 g
s
.29804 .72874 m .29804 .69168 L .29515 .68314 L p .707 .577 .707 r
F P
0 g
s
.29515 .63772 m .29515 .58214 L .30223 .57378 L p .707 .577 .707 r
F P
0 g
s
.29804 .73246 m .29804 .71393 L .29515 .70539 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .68314 m .29515 .7202 L .29804 .72874 L p .707 .577 .707 r
F P
0 g
s
.29515 .70539 m .29515 .72391 L .29804 .73246 L p .707 .577 .707 r
F P
0 g
s
.49904 .68678 m .49904 .72383 L .49615 .71529 L p .707 .577 .707 r
F P
0 g
s
.49615 .71529 m .49615 .67823 L .49904 .68678 L p .707 .577 .707 r
F P
0 g
s
.30223 .57378 m .30223 .62936 L .29515 .63772 L p .707 .577 .707 r
F P
0 g
s
.49615 .57723 m .49615 .63281 L .48356 .62493 L p .707 .577 .707 r
F P
0 g
s
.48356 .62493 m .48356 .56935 L .49615 .57723 L p .707 .577 .707 r
F P
0 g
s
.49904 .70902 m .49904 .72755 L .49615 .71901 L p .707 .577 .707 r
F P
0 g
s
.49615 .71901 m .49615 .70048 L .49904 .70902 L p .707 .577 .707 r
F P
0 g
s
.29515 .7202 m .29515 .68314 L .30223 .67478 L p .707 .577 .707 r
F P
0 g
s
.30223 .62936 m .30223 .57378 L .3186 .56641 L p .707 .577 .707 r
F P
0 g
s
.29515 .72391 m .29515 .70539 L .30223 .69702 L p .707 .577 .707 r
F P
0 g
s
.30223 .67478 m .30223 .71183 L .29515 .7202 L p .707 .577 .707 r
F P
0 g
s
.30223 .69702 m .30223 .71555 L .29515 .72391 L p .707 .577 .707 r
F P
0 g
s
.3186 .56641 m .3186 .62199 L .30223 .62936 L p .707 .577 .707 r
F P
0 g
s
.49615 .67823 m .49615 .71529 L .48356 .70741 L p .707 .577 .707 r
F P
0 g
s
.48356 .70741 m .48356 .67035 L .49615 .67823 L p .707 .577 .707 r
F P
0 g
s
.48356 .56935 m .48356 .62493 L .4625 .61848 L p .707 .577 .707 r
F P
0 g
s
.4625 .61848 m .4625 .56289 L .48356 .56935 L p .707 .577 .707 r
F P
0 g
s
.49615 .70048 m .49615 .71901 L .48356 .71112 L p .707 .577 .707 r
F P
0 g
s
.48356 .71112 m .48356 .6926 L .49615 .70048 L p .707 .577 .707 r
F P
0 g
s
.3186 .62199 m .3186 .56641 L .34265 .56076 L p .707 .577 .707 r
F P
0 g
s
.30223 .71183 m .30223 .67478 L .3186 .66741 L p .707 .577 .707 r
F P
0 g
s
.30223 .71555 m .30223 .69702 L .3186 .68965 L p .707 .577 .707 r
F P
0 g
s
.3186 .66741 m .3186 .70446 L .30223 .71183 L p .707 .577 .707 r
F P
0 g
s
.4625 .56289 m .4625 .61848 L .43504 .61408 L p .707 .577 .707 r
F P
0 g
s
.43504 .61408 m .43504 .5585 L .4625 .56289 L p .707 .577 .707 r
F P
0 g
s
.3186 .68965 m .3186 .70818 L .30223 .71555 L p .707 .577 .707 r
F P
0 g
s
.34265 .56076 m .34265 .61634 L .3186 .62199 L p .707 .577 .707 r
F P
0 g
s
.48356 .67035 m .48356 .70741 L .4625 .70095 L p .707 .577 .707 r
F P
0 g
s
.4625 .70095 m .4625 .6639 L .48356 .67035 L p .707 .577 .707 r
F P
0 g
s
.34265 .61634 m .34265 .56076 L .37203 .55738 L p .707 .577 .707 r
F P
0 g
s
.48356 .6926 m .48356 .71112 L .4625 .70467 L p .707 .577 .707 r
F P
0 g
s
.4625 .70467 m .4625 .68614 L .48356 .6926 L p .707 .577 .707 r
F P
0 g
s
.3186 .70446 m .3186 .66741 L .34265 .66176 L p .707 .577 .707 r
F P
0 g
s
.43504 .5585 m .43504 .61408 L .40387 .61218 L p .707 .577 .707 r
F P
0 g
s
.40387 .61218 m .40387 .5566 L .43504 .5585 L p .707 .577 .707 r
F P
0 g
s
.37203 .61296 m .37203 .55738 L .40387 .5566 L p .707 .577 .707 r
F P
0 g
s
.37203 .55738 m .37203 .61296 L .34265 .61634 L p .707 .577 .707 r
F P
0 g
s
.3186 .70818 m .3186 .68965 L .34265 .68401 L p .707 .577 .707 r
F P
0 g
s
.40387 .5566 m .40387 .61218 L .37203 .61296 L p .707 .577 .707 r
F P
0 g
s
.34265 .66176 m .34265 .69881 L .3186 .70446 L p .707 .577 .707 r
F P
0 g
s
.34265 .68401 m .34265 .70253 L .3186 .70818 L p .707 .577 .707 r
F P
0 g
s
.4625 .6639 m .4625 .70095 L .43504 .69656 L p .707 .577 .707 r
F P
0 g
s
.43504 .69656 m .43504 .6595 L .4625 .6639 L p .707 .577 .707 r
F P
0 g
s
.4625 .68614 m .4625 .70467 L .43504 .70028 L p .707 .577 .707 r
F P
0 g
s
.43504 .70028 m .43504 .68175 L .4625 .68614 L p .707 .577 .707 r
F P
0 g
s
.34265 .69881 m .34265 .66176 L .37203 .65838 L p .707 .577 .707 r
F P
0 g
s
.34265 .70253 m .34265 .68401 L .37203 .68063 L p .707 .577 .707 r
F P
0 g
s
.43504 .6595 m .43504 .69656 L .40387 .69466 L p .707 .577 .707 r
F P
0 g
s
.40387 .69466 m .40387 .6576 L .43504 .6595 L p .707 .577 .707 r
F P
0 g
s
.37203 .65838 m .37203 .69544 L .34265 .69881 L p .707 .577 .707 r
F P
0 g
s
.37203 .68063 m .37203 .69915 L .34265 .70253 L p .707 .577 .707 r
F P
0 g
s
.37203 .69544 m .37203 .65838 L .40387 .6576 L p .707 .577 .707 r
F P
0 g
s
.43504 .68175 m .43504 .70028 L .40387 .69838 L p .707 .577 .707 r
F P
0 g
s
.40387 .69838 m .40387 .67985 L .43504 .68175 L p .707 .577 .707 r
F P
0 g
s
.40387 .6576 m .40387 .69466 L .37203 .69544 L p .707 .577 .707 r
F P
0 g
s
.37203 .69915 m .37203 .68063 L .40387 .67985 L p .707 .577 .707 r
F P
0 g
s
.40387 .67985 m .40387 .69838 L .37203 .69915 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE0026Ool007aoo`H0
009JEP03001JEUYF00UJEP03001JEUYF00AJEPT007eoo`00MWoo1P0025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06EooaP000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YF00000`000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH5000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00003goo4P00A7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00002Goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF2000?7oo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000=oo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00008003Aoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EP00Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01eYF00<005YFFUH0
15YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`03001JEP00
00=JEPH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol01000FUH005YF0P00
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF0`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00001JEP001EYF
00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol0
1@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0
03mooa4000Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
0UYF4P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF2@001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF009JEPL000QJ
EP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUH0
00020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF
0P00;Goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH50006FUHI00000eYF001JEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031oo`80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
0`000eYF0P00;Goo000^Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH4
0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000]Ool002eoo`80
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEQ@000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEP0000AJEP03001JEUYF00AJEP<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP0000<0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEPD000=JEP04001JEUYFFUHC0008FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH20005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040003
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF
00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH010001UYF00<005YFFUH00UYF00<005YF0000
0eYF0`0000=JEP00FUH01UYF4`001eYF00@005YFFUIJEPD003=oo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000=JEP03
001JEUYF00AJEP8000=JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP0000EJEPX000AJ
EP03001JEUYF00IJEP03001JEUYF009JEP`003Qoo`00;7oo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF
1P000UYF00<005YFFUH00eYF0P000eYF00@005YFFUIJEPP000AJEP03001JEUYF00=JEP05001JEUYF
FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001JEP03FUH00`00FUH00005FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@00=goo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHE00000eYF001JEP03FUH00`00FUH00003
0002FUH01000FUIJEP000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEPL000AJEP05001JEUYF
FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YF00000eYF0`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000
0P00=7oo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP07FUH01@00FUH0
05YF00000eYF0`000UYF00<005YF00000`0000IJEP00FUIJEP00FUH20007FUH00`00FUIJEP07FUH5
0003FUH300000eYF001JEP02FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000
FUIJEUYF0P000UYF00@005YF001JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP80039oo`00;7oo00<005YF000015YF
00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00FUH20005FUH0
0`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002ao
o`03001JEP0000=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001J
EP00FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP09FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`04001JEP00
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJ
EP800003FUH005YF00=JEP03001JEUYF00=JEP@000EJEPD000AJEP03001JEUYF009JEPP000=JEP03
001JEUYF00=JEP05001JEUYFFUH0000^Ool002aoo`06001JEP00001JEP001EYF00<005YFFUH01EYF
00<005YFFUH01EYF10001UYF00@005YF0000009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF00UJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00=JEP03001JEP00
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH01000
FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH5
0005FUH01000FUH000000eYF00L005YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEUYF1@000UYF00<005YF00002UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00;Goo000/
Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01000FUIJEP00
0eYF00<005YFFUH00UYF0P001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1`00
0eYF00@005YFFUIJEP8000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP800004
FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH20003FUH2000]Ool002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEPD000EJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJ
EP03FUH30004FUHB0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0000=JEP000000
;Goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF10001UYF00@005YF
FUIJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH200000eYF001JEP03FUH00`00FUIJEP03FUH20003FUHJ0003FUH00`00FUIJEP03
FUH00`00FUIJEP03000]Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH300000eYF001JEP03FUH01000FUIJEUYF2@0067oo1@0015YF00@0
05YFFUIJEP8002eoo`00;goo0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF100000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH500000eYF001JEP02FUH90003FUH2000EOol700001UYF00000000FUH000=JEP8002eoo`00
<Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUIJEPD000=JEP8000MJEP03001JEUYF00MJEP03001JEUYF009JEPL000MJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP06001JEP00001JEP000UYF00@005YF001JEP8000AJEP04
001JEUYFFUH90009Ool90003FUH00`00FUIJEP04FUH30003FUH2000]Ool003=oo`<00003FUH005YF
00IJEQT00003FUH005YF009JEP@00003Ool0000000H000=JEP8000EJEPT00003FUH005YF00]JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000=JEP05001JEUYF001JEP030005FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP0200000eYF0000000]Ool003Ioo`T000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH6000<Ool<0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
0007FUH00`00FUIJEP0200000eYF00000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000;Goo000cOol40003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000EOol6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH80003FUH40005FUH00`00FUIJ
EP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00;Goo000aOol30006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000IOol90006
FUH00`00FUIJEP04FUH<0002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP020002FUH01`00FUIJ
EUYF001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP<000=JEP03001JEP0002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P008Goo3P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH00P000UYF00<005YFFUH00UYF0P001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00eYF00<0
05YF0000;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000:7oo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00D005YFFUIJEP00009JEP03001J
EUYF00=JEP03001JEUYF009JEP@000QJEP03001JEUYF00IJEP03001JEUYF009JEPD000EJEP03001J
EUYF009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF3P0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002Qoo`04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHA
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000/Ool00`00FUH00004FUH00`00FUIJEP04
FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000:7oo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH01@00FUIJEUYF0000
:Goo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1000
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
0`00<goo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP02FUH00`00Oomoo`0YOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`00
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00=Woo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00Oomoo`0[Ool300000eYF001JEP06FUHC0007
FUH00`00FUIJEP03FUH500000eYF00000007FUH20008FUH00`00FUIJEP02FUH5000jOol002aoo`04
001JEP000003FUH00`00FUIJEP04FUH20003FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
00000eYF001oo`0_Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH900000eYF000000020005
OolI000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPH0015oo`P000AJEP03001JEUYF00=J
EP03001JEUYF0080031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH5001NOol002aoo`03001JEP0000AJEP03001JEP0000<001moo`H000AJEP05001JEUYFFUH0
000]Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUH00002001KOol002aoo`03001JEP0000=JEP<0009JEP03001JEP0000<001Uoo`D000=JEP<0
0003FUH005YF009JEP03001oogoo02Uoo`800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8005Uoo`00;7oo00@005YF001J
EP8000EJEP03001JEUYF00=JEQT000=JEP03001JEUYF00AJEP<000=JEP03001oogoo02Moo`8000=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP<005Moo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF001o
o`0WOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol002aoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH3000WOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP02FUH80003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20002FUH20005FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUH0000200000eYF001oo`0VOol00`00FUH00004FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00L0
05YFFUIJEP00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@000UYF00<005YF00009goo00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF0P00E7oo000/
Ool20003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02
FUH70003FUH01`00FUIJEUYF001JEP0002Moo`05001JEP00FUH00002FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20003
FUH2001DOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP03FUH9
0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P00:7oo00@005YF000000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<0
0003FUH0000005Aoo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH00eYF2000
15YF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002Uoo`03001JEP0000AJEP03001J
EUYF00=JEP8000=JEQP000EJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00<7oo0`0015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YF000002Yoo`03001JEP0000AJEP8000=JEPH001Qoo`@00003FUH005YF00AJEP04001JEUYFFUH2
001DOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<002aoo`03001JEP0000AJEP03001JEP0000@001]oo`T000=JEP04001JEUYF
FUH2001DOol003Ioo`D000=JEP8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<0
02moo`04001JEP000002FUH300000eYF001JEP02FUH90009Ool90003FUH00`00FUIJEP03FUH40003
FUH2001DOol003]oo`P000=JEP8000UJEP03001JEUYF009JEPD003=oo`04001JEP00FUH20004FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP000UYF0P00E7oo0013OolC000hOol00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF1000E7oo002>Ool2
0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00E7oo002>Ool20002FUH01`00FUIJEUYF001J
EP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=J
EP<005Aoo`00SWoo0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YF00000`0000=JEP00FUH00eYF00<005YF0000E7oo002?Ool01000FUIJ
EP001EYF00<005YFFUH00UYF100025YF00<005YFFUH01UYF00<005YFFUH00UYF1@001EYF00<005YF
FUH00UYF0P00EGoo002@Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP03FUHA0003FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002AOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000F7oo002BOol30003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH3001JOol009Eoo`D000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EP0000<005eoo`00VWoo100000=JEP0000001eYF0P0025YF00<005YFFUH00UYF1@00HGoo002NOolI
001VOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]16\[InvisibleSpace]"     "\
\[InvisibleSpace]6.382330995002581`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 16, "     ", 6.3823309950025813, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60018 .75646 m .59886 .70187 L .56769 .70026 L p .707 .577 .707 r
F P
0 g
s
.59886 .70187 m .60018 .75646 L .632 .75483 L p .707 .577 .707 r
F P
0 g
s
.632 .75483 m .63068 .70024 L .59886 .70187 L p .707 .577 .707 r
F P
0 g
s
.63068 .70024 m .632 .75483 L .66137 .75012 L p .707 .577 .707 r
F P
0 g
s
.66137 .75012 m .66005 .69553 L .63068 .70024 L p .707 .577 .707 r
F P
0 g
s
.56901 .75485 m .56769 .70026 L .54023 .69557 L p .707 .577 .707 r
F P
0 g
s
.56769 .70026 m .56901 .75485 L .60018 .75646 L p .707 .577 .707 r
F P
0 g
s
.66005 .69553 m .66137 .75012 L .6854 .7428 L p .707 .577 .707 r
F P
0 g
s
.6854 .7428 m .68408 .6882 L .66005 .69553 L p .707 .577 .707 r
F P
0 g
s
.54155 .75017 m .54023 .69557 L .51916 .68827 L p .707 .577 .707 r
F P
0 g
s
.54023 .69557 m .54155 .75017 L .56901 .75485 L p .707 .577 .707 r
F P
0 g
s
.59892 .7951 m .60168 .75689 L .57055 .75403 L p .707 .577 .707 r
F P
0 g
s
.60168 .75689 m .59892 .7951 L .60454 .79545 L p .707 .577 .707 r
F P
0 g
s
.57055 .75403 m .56778 .79224 L .57262 .79269 L p .707 .577 .707 r
F P
0 g
s
.57262 .79269 m .59892 .7951 L p .58681 .77757 L .707 .577 .707 r
F P
0 g
s
.58681 .77757 m .57055 .75403 L .57262 .79269 L .707 .577 .707 r
F
.56778 .79224 m .57055 .75403 L .54305 .7506 L p F P
0 g
s
.54305 .7506 m .54029 .78881 L .54442 .78932 L p .707 .577 .707 r
F P
0 g
s
.54442 .78932 m .56778 .79224 L p .55646 .77318 L .707 .577 .707 r
F P
0 g
s
.55646 .77318 m .54305 .7506 L .54442 .78932 L .707 .577 .707 r
F
.54029 .78881 m .54305 .7506 L .5219 .74692 L p F P
0 g
s
.5219 .74692 m .51913 .78513 L .54029 .78881 L p .707 .577 .707 r
F P
0 g
s
.54124 .78678 m .51965 .78674 L p .53482 .80218 L .707 .577 .707 r
F P
0 g
s
.53815 .80555 m .5398 .79551 L p .53482 .80218 L .707 .577 .707 r
F P
0 g
s
.5398 .79551 m .54124 .78678 L p .53482 .80218 L .707 .577 .707 r
F P
0 g
s
.56888 .78896 m .54124 .78678 L p .56174 .80428 L .707 .577 .707 r
F P
0 g
s
.56579 .80774 m .56734 .79831 L p .56174 .80428 L .707 .577 .707 r
F P
0 g
s
.56734 .79831 m .56888 .78896 L p .56174 .80428 L .707 .577 .707 r
F P
0 g
s
.59987 .79307 m .56888 .78896 L p .5923 .80817 L .707 .577 .707 r
F P
0 g
s
.59678 .81185 m .59843 .8018 L p .5923 .80817 L .707 .577 .707 r
F P
0 g
s
.59843 .8018 m .59987 .79307 L p .5923 .80817 L .707 .577 .707 r
F P
0 g
s
.60454 .79545 m .63065 .7971 L p .61879 .78064 L .707 .577 .707 r
F P
0 g
s
.61879 .78064 m .60168 .75689 L .60454 .79545 L .707 .577 .707 r
F
.63065 .7971 m .63342 .75889 L .60168 .75689 L p F P
0 g
s
.56888 .78896 m .56579 .80774 L .59678 .81185 L p .707 .577 .707 r
F P
0 g
s
.59987 .79307 m .59678 .81185 L .62808 .81748 L p .707 .577 .707 r
F P
0 g
s
.63342 .75889 m .63065 .7971 L .65987 .79804 L p .707 .577 .707 r
F P
0 g
s
.65987 .79804 m .66264 .75983 L .63342 .75889 L p .707 .577 .707 r
F P
0 g
s
.62808 .81748 m .63117 .79871 L .59987 .79307 L p .707 .577 .707 r
F P
0 g
s
.63117 .79871 m .62808 .81748 L .65663 .8241 L p .707 .577 .707 r
F P
0 g
s
.65663 .8241 m .65973 .80532 L .63117 .79871 L p .707 .577 .707 r
F P
0 g
s
.54124 .78678 m .53815 .80555 L .56579 .80774 L p .707 .577 .707 r
F P
0 g
s
.68408 .6882 m .6854 .7428 L .70175 .73357 L p .707 .577 .707 r
F P
0 g
s
.70175 .73357 m .70043 .67898 L .68408 .6882 L p .707 .577 .707 r
F P
0 g
s
.66264 .75983 m .65987 .79804 L .68373 .79784 L p .707 .577 .707 r
F P
0 g
s
.68373 .79784 m .68649 .75963 L .66264 .75983 L p .707 .577 .707 r
F P
0 g
s
.65973 .80532 m .65663 .8241 L .67964 .83103 L p .707 .577 .707 r
F P
0 g
s
.51916 .68827 m .52048 .74286 L .54155 .75017 L p .707 .577 .707 r
F P
0 g
s
.67964 .83103 m .68274 .81226 L .65973 .80532 L p .707 .577 .707 r
F P
0 g
s
.52048 .74286 m .51916 .68827 L .50655 .67905 L p .707 .577 .707 r
F P
0 g
s
.51965 .78674 m .51656 .80552 L .53815 .80555 L p .707 .577 .707 r
F P
0 g
s
.70043 .67898 m .70175 .73357 L .70881 .72335 L p .707 .577 .707 r
F P
0 g
s
.70881 .72335 m .70749 .66876 L .70043 .67898 L p .707 .577 .707 r
F P
0 g
s
.68649 .75963 m .68373 .79784 L .69987 .79651 L p .707 .577 .707 r
F P
0 g
s
.69987 .79651 m .70264 .75831 L .68649 .75963 L p .707 .577 .707 r
F P
0 g
s
.68274 .81226 m .67964 .83103 L .69485 .83762 L p .707 .577 .707 r
F P
0 g
s
.50655 .67905 m .50787 .73365 L .52048 .74286 L p .707 .577 .707 r
F P
0 g
s
.69485 .83762 m .69795 .81885 L .68274 .81226 L p .707 .577 .707 r
F P
0 g
s
.51913 .78513 m .5219 .74692 L .50914 .74336 L p .707 .577 .707 r
F P
0 g
s
.50623 .78885 m .50314 .80762 L .51656 .80552 L p .707 .577 .707 r
F P
0 g
s
.51656 .80552 m .51965 .78674 L .50623 .78885 L p .707 .577 .707 r
F P
0 g
s
.50914 .74336 m .50638 .78157 L .51913 .78513 L p .707 .577 .707 r
F P
0 g
s
.50787 .73365 m .50655 .67905 L .50364 .66884 L p .707 .577 .707 r
F P
0 g
s
.70264 .75831 m .69987 .79651 L .70673 .79419 L p .707 .577 .707 r
F P
0 g
s
.70673 .79419 m .7095 .75598 L .70264 .75831 L p .707 .577 .707 r
F P
0 g
s
.70749 .66876 m .70881 .72335 L .70589 .71313 L p .707 .577 .707 r
F P
0 g
s
.70589 .71313 m .70457 .65854 L .70749 .66876 L p .707 .577 .707 r
F P
0 g
s
.69795 .81885 m .69485 .83762 L .70078 .84321 L p .707 .577 .707 r
F P
0 g
s
.50364 .66884 m .50496 .72343 L .50787 .73365 L p .707 .577 .707 r
F P
0 g
s
.70078 .84321 m .70387 .82444 L .69795 .81885 L p .707 .577 .707 r
F P
0 g
s
.50638 .78157 m .50914 .74336 L .50605 .74027 L p .707 .577 .707 r
F P
0 g
s
.50229 .79289 m .4992 .81167 L .50314 .80762 L p .707 .577 .707 r
F P
0 g
s
.50314 .80762 m .50623 .78885 L .50229 .79289 L p .707 .577 .707 r
F P
0 g
s
.48346 .81815 m .49505 .30939 L .45105 .30629 L p .707 .577 .707 r
F P
0 g
s
.50605 .74027 m .50328 .77848 L .50638 .78157 L p .707 .577 .707 r
F P
0 g
s
.50496 .72343 m .50364 .66884 L .5107 .65861 L p .707 .577 .707 r
F P
0 g
s
.5107 .65861 m .51202 .71321 L .50496 .72343 L p .707 .577 .707 r
F P
0 g
s
.50328 .77848 m .50605 .74027 L .51291 .73794 L p .707 .577 .707 r
F P
0 g
s
.50822 .79848 m .50512 .81726 L .4992 .81167 L p .707 .577 .707 r
F P
0 g
s
.4992 .81167 m .50229 .79289 L .50822 .79848 L p .707 .577 .707 r
F P
0 g
s
.51202 .71321 m .5107 .65861 L .52705 .64939 L p .707 .577 .707 r
F P
0 g
s
.51291 .73794 m .51014 .77615 L .50328 .77848 L p .707 .577 .707 r
F P
0 g
s
.52705 .64939 m .52836 .70398 L .51202 .71321 L p .707 .577 .707 r
F P
0 g
s
.51014 .77615 m .51291 .73794 L .52906 .73661 L p .707 .577 .707 r
F P
0 g
s
.52343 .80507 m .52033 .82384 L .50512 .81726 L p .707 .577 .707 r
F P
0 g
s
.50512 .81726 m .50822 .79848 L .52343 .80507 L p .707 .577 .707 r
F P
0 g
s
.52906 .73661 m .52629 .77482 L .51014 .77615 L p .707 .577 .707 r
F P
0 g
s
.52033 .82384 m .52343 .80507 L .54644 .81201 L p .707 .577 .707 r
F P
0 g
s
.49505 .30939 m .48346 .81815 L .52839 .81824 L p .707 .577 .707 r
F P
0 g
s
.52836 .70398 m .52705 .64939 L .55108 .64206 L p .707 .577 .707 r
F P
0 g
s
.55108 .64206 m .5524 .69666 L .52836 .70398 L p .707 .577 .707 r
F P
0 g
s
.52629 .77482 m .52906 .73661 L .54243 .7365 L p .707 .577 .707 r
F P
0 g
s
.5524 .69666 m .55108 .64206 L .55632 .64122 L p .707 .577 .707 r
F P
0 g
s
.55632 .64122 m .58044 .63736 L p .56297 .67429 L .707 .577 .707 r
F P
0 g
s
.5524 .69666 m .55632 .64122 L .56297 .67429 L .707 .577 .707 r
F
.58176 .69195 m .58044 .63736 L .61227 .63573 L p F P
0 g
s
.58044 .63736 m .58176 .69195 L .5524 .69666 L p .707 .577 .707 r
F P
0 g
s
.61227 .63573 m .61359 .69032 L .58176 .69195 L p .707 .577 .707 r
F P
0 g
s
.57257 .73705 m .58213 .73736 L p .57907 .74093 L .707 .577 .707 r
F P
0 g
s
.56843 .75332 m .57154 .74107 L .57907 .74093 L .707 .577 .707 r
F
.57154 .74107 m .57257 .73705 L .57907 .74093 L F
.58144 .30657 m .53998 .30948 L p .56547 .74119 L F P
0 g
s
.57154 .74107 m .58144 .30657 L p .56547 .74119 L .707 .577 .707 r
F P
0 g
s
.53998 .30948 m .53288 .62124 L p .55577 .74138 L .707 .577 .707 r
F P
0 g
s
.57936 .77557 m .56291 .77504 L p .58032 .7409 L .707 .577 .707 r
F P
0 g
s
.56291 .77504 m .55014 .77462 L p .56843 .75332 L .707 .577 .707 r
F P
0 g
s
.56843 .75332 m .58213 .73736 L .56291 .77504 L .707 .577 .707 r
F
.56547 .74119 m .53998 .30948 L .55577 .74138 L F
.57204 .71933 m .57154 .74107 L p .57426 .73037 L F P
0 g
s
.55014 .77462 m .55254 .74144 L p .57015 .7411 L .707 .577 .707 r
F P
0 g
s
.55014 .77462 m .57015 .7411 L .56843 .75332 L .707 .577 .707 r
F
.56469 .81569 m .56985 .81533 L p .55577 .74138 L F P
0 g
s
.55577 .74138 m .53288 .62124 L .55254 .74144 L .707 .577 .707 r
F
.55577 .74138 m .55254 .74144 L .56469 .81569 L F
.57015 .7411 m .57257 .73705 L .57154 .74107 L F
.57015 .7411 m .57154 .74107 L .56843 .75332 L F
.55291 .73641 m .57257 .73705 L p .57015 .7411 L F P
0 g
s
.55254 .74144 m .55291 .73641 L p .57015 .7411 L .707 .577 .707 r
F P
0 g
s
.54644 .81201 m .54334 .83078 L .52033 .82384 L p .707 .577 .707 r
F P
0 g
s
.55291 .73641 m .55014 .77462 L .52629 .77482 L p .707 .577 .707 r
F P
0 g
s
.54334 .83078 m .54644 .81201 L .57499 .81862 L p .707 .577 .707 r
F P
0 g
s
.52839 .81824 m .56469 .81569 L p .55254 .74144 L .707 .577 .707 r
F P
0 g
s
.54243 .7365 m .55172 .73642 L p .54354 .74993 L .707 .577 .707 r
F P
0 g
s
.54354 .74993 m .55172 .73642 L .55195 .7378 L .707 .577 .707 r
F
.52629 .77482 m .54243 .7365 L .54354 .74993 L F
.53288 .62124 m .53013 .74188 L p .55254 .74144 L F P
0 g
s
.53013 .74188 m .52839 .81824 L p .55254 .74144 L .707 .577 .707 r
F P
0 g
s
.56985 .81533 m .56547 .74119 L .55577 .74138 L .707 .577 .707 r
F
.58213 .73736 m .58188 .74087 L p .58032 .7409 L F P
0 g
s
.58188 .74087 m .57936 .77557 L p .58032 .7409 L .707 .577 .707 r
F P
0 g
s
.57936 .77557 m .58213 .73736 L .59121 .73793 L p .707 .577 .707 r
F P
0 g
s
.59121 .73793 m .61387 .73936 L p .58843 .76605 L .707 .577 .707 r
F P
0 g
s
.57936 .77557 m .59121 .73793 L .58843 .76605 L .707 .577 .707 r
F
.64344 .63733 m .64476 .69192 L .61359 .69032 L p F P
0 g
s
.61359 .69032 m .61227 .63573 L .64344 .63733 L p .707 .577 .707 r
F P
0 g
s
.645 .74221 m .64224 .78042 L .6111 .77757 L p .707 .577 .707 r
F P
0 g
s
.6111 .77757 m .61387 .73936 L .645 .74221 L p .707 .577 .707 r
F P
0 g
s
.61387 .73936 m .6111 .77757 L .57936 .77557 L p .707 .577 .707 r
F P
0 g
s
.60378 .80969 m .62686 .80188 L p .61894 .45651 L .707 .577 .707 r
F P
0 g
s
.61537 .30093 m .60969 .55038 L p .61894 .45651 L .707 .577 .707 r
F P
0 g
s
.60969 .55038 m .60378 .80969 L p .61894 .45651 L .707 .577 .707 r
F P
0 g
s
.59067 .81187 m .60378 .80969 L p .57496 .72764 L .707 .577 .707 r
F P
0 g
s
.57496 .72764 m .57204 .71933 L .57426 .73037 L .707 .577 .707 r
F
.57496 .72764 m .57426 .73037 L .59067 .81187 L F
.56985 .81533 m .59067 .81187 L p .57426 .73037 L F P
0 g
s
.57154 .74107 m .56985 .81533 L p .57426 .73037 L .707 .577 .707 r
F P
0 g
s
.56985 .81533 m .57154 .74107 L p .56547 .74119 L .707 .577 .707 r
F P
0 g
s
.58144 .30657 m .57204 .71933 L p .57496 .72764 L .707 .577 .707 r
F P
0 g
s
.60378 .80969 m .59639 .64329 L .57496 .72764 L .707 .577 .707 r
F
.59639 .64329 m .58144 .30657 L .57496 .72764 L F
.55172 .73642 m .55291 .73641 L p .55195 .7378 L F P
0 g
s
.52839 .81824 m .53288 .62124 L p .49505 .30939 L .707 .577 .707 r
F P
0 g
s
.53288 .62124 m .53998 .30948 L .50705 .30941 L p .707 .577 .707 r
F P
0 g
s
.50705 .30941 m .49505 .30939 L p .53288 .62124 L .707 .577 .707 r
F P
0 g
s
.43946 .81505 m .45105 .30629 L .41228 .3005 L p .707 .577 .707 r
F P
0 g
s
.45105 .30629 m .43946 .81505 L .48346 .81815 L p .707 .577 .707 r
F P
0 g
s
.7095 .75598 m .70673 .79419 L .70364 .7911 L p .707 .577 .707 r
F P
0 g
s
.70364 .7911 m .7064 .75289 L .7095 .75598 L p .707 .577 .707 r
F P
0 g
s
.70457 .65854 m .70589 .71313 L .69328 .70392 L p .707 .577 .707 r
F P
0 g
s
.69328 .70392 m .69197 .64933 L .70457 .65854 L p .707 .577 .707 r
F P
0 g
s
.70387 .82444 m .70078 .84321 L .69684 .84726 L p .707 .577 .707 r
F P
0 g
s
.60378 .80969 m .61537 .30093 L .58144 .30657 L p .707 .577 .707 r
F P
0 g
s
.69684 .84726 m .69993 .82848 L .70387 .82444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25717 .71964 m .25585 .66505 L .22468 .66344 L p .707 .577 .707 r
F P
0 g
s
.25585 .66505 m .25717 .71964 L .28899 .71801 L p .707 .577 .707 r
F P
0 g
s
.28899 .71801 m .28767 .66342 L .25585 .66505 L p .707 .577 .707 r
F P
0 g
s
.40069 .80926 m .41228 .3005 L .38254 .29258 L p .707 .577 .707 r
F P
0 g
s
.41228 .3005 m .40069 .80926 L .43946 .81505 L p .707 .577 .707 r
F P
0 g
s
.28767 .66342 m .28899 .71801 L .31836 .7133 L p .707 .577 .707 r
F P
0 g
s
.31836 .7133 m .31704 .65871 L .28767 .66342 L p .707 .577 .707 r
F P
0 g
s
.226 .71804 m .22468 .66344 L .19722 .65876 L p .707 .577 .707 r
F P
0 g
s
.22468 .66344 m .226 .71804 L .25717 .71964 L p .707 .577 .707 r
F P
0 g
s
.31704 .65871 m .31836 .7133 L .34239 .70598 L p .707 .577 .707 r
F P
0 g
s
.34239 .70598 m .34107 .65139 L .31704 .65871 L p .707 .577 .707 r
F P
0 g
s
.69197 .64933 m .69328 .70392 L .67222 .69661 L p .707 .577 .707 r
F P
0 g
s
.67222 .69661 m .6709 .64202 L .69197 .64933 L p .707 .577 .707 r
F P
0 g
s
.7064 .75289 m .70364 .7911 L .69089 .78754 L p .707 .577 .707 r
F P
0 g
s
.69089 .78754 m .69365 .74933 L .7064 .75289 L p .707 .577 .707 r
F P
0 g
s
.69993 .82848 m .69684 .84726 L .68342 .84936 L p .707 .577 .707 r
F P
0 g
s
.62686 .80188 m .63845 .29312 L .61537 .30093 L p .707 .577 .707 r
F P
0 g
s
.19854 .71335 m .19722 .65876 L .17615 .65145 L p .707 .577 .707 r
F P
0 g
s
.19722 .65876 m .19854 .71335 L .226 .71804 L p .707 .577 .707 r
F P
0 g
s
.68342 .84936 m .68651 .83059 L .69993 .82848 L p .707 .577 .707 r
F P
0 g
s
.25591 .75828 m .25868 .72007 L .22754 .71722 L p .707 .577 .707 r
F P
0 g
s
.25868 .72007 m .25591 .75828 L .26153 .75864 L p .707 .577 .707 r
F P
0 g
s
.22754 .71722 m .22477 .75543 L .22961 .75587 L p .707 .577 .707 r
F P
0 g
s
.22961 .75587 m .25591 .75828 L p .2438 .74076 L .707 .577 .707 r
F P
0 g
s
.2438 .74076 m .22754 .71722 L .22961 .75587 L .707 .577 .707 r
F
.22477 .75543 m .22754 .71722 L .20004 .71378 L p F P
0 g
s
.20004 .71378 m .19728 .75199 L .20141 .75251 L p .707 .577 .707 r
F P
0 g
s
.20141 .75251 m .22477 .75543 L p .21345 .73637 L .707 .577 .707 r
F P
0 g
s
.21345 .73637 m .20004 .71378 L .20141 .75251 L .707 .577 .707 r
F
.19728 .75199 m .20004 .71378 L .17889 .7101 L p F P
0 g
s
.17889 .7101 m .17612 .74831 L .19728 .75199 L p .707 .577 .707 r
F P
0 g
s
.19823 .74997 m .17664 .74993 L p .19181 .76536 L .707 .577 .707 r
F P
0 g
s
.19514 .76874 m .19679 .75869 L p .19181 .76536 L .707 .577 .707 r
F P
0 g
s
.19679 .75869 m .19823 .74997 L p .19181 .76536 L .707 .577 .707 r
F P
0 g
s
.22587 .75215 m .19823 .74997 L p .21873 .76746 L .707 .577 .707 r
F P
0 g
s
.22278 .77092 m .22433 .76149 L p .21873 .76746 L .707 .577 .707 r
F P
0 g
s
.22433 .76149 m .22587 .75215 L p .21873 .76746 L .707 .577 .707 r
F P
0 g
s
.25686 .75626 m .22587 .75215 L p .24929 .77136 L .707 .577 .707 r
F P
0 g
s
.25377 .77503 m .25542 .76498 L p .24929 .77136 L .707 .577 .707 r
F P
0 g
s
.25542 .76498 m .25686 .75626 L p .24929 .77136 L .707 .577 .707 r
F P
0 g
s
.26153 .75864 m .28764 .76028 L p .27578 .74382 L .707 .577 .707 r
F P
0 g
s
.27578 .74382 m .25868 .72007 L .26153 .75864 L .707 .577 .707 r
F
.28764 .76028 m .29041 .72207 L .25868 .72007 L p F P
0 g
s
.22587 .75215 m .22278 .77092 L .25377 .77503 L p .707 .577 .707 r
F P
0 g
s
.25686 .75626 m .25377 .77503 L .28507 .78067 L p .707 .577 .707 r
F P
0 g
s
.29041 .72207 m .28764 .76028 L .31686 .76123 L p .707 .577 .707 r
F P
0 g
s
.31686 .76123 m .31963 .72302 L .29041 .72207 L p .707 .577 .707 r
F P
0 g
s
.28507 .78067 m .28816 .7619 L .25686 .75626 L p .707 .577 .707 r
F P
0 g
s
.28816 .7619 m .28507 .78067 L .31362 .78728 L p .707 .577 .707 r
F P
0 g
s
.31362 .78728 m .31672 .76851 L .28816 .7619 L p .707 .577 .707 r
F P
0 g
s
.19823 .74997 m .19514 .76874 L .22278 .77092 L p .707 .577 .707 r
F P
0 g
s
.37095 .80134 m .38254 .29258 L .36474 .28331 L p .707 .577 .707 r
F P
0 g
s
.38254 .29258 m .37095 .80134 L .40069 .80926 L p .707 .577 .707 r
F P
0 g
s
.34107 .65139 m .34239 .70598 L .35874 .69676 L p .707 .577 .707 r
F P
0 g
s
.35874 .69676 m .35742 .64216 L .34107 .65139 L p .707 .577 .707 r
F P
0 g
s
.6709 .64202 m .67222 .69661 L .64476 .69192 L p .707 .577 .707 r
F P
0 g
s
.64476 .69192 m .64344 .63733 L .6709 .64202 L p .707 .577 .707 r
F P
0 g
s
.31963 .72302 m .31686 .76123 L .34072 .76103 L p .707 .577 .707 r
F P
0 g
s
.34072 .76103 m .34348 .72282 L .31963 .72302 L p .707 .577 .707 r
F P
0 g
s
.31672 .76851 m .31362 .78728 L .33663 .79422 L p .707 .577 .707 r
F P
0 g
s
.17615 .65145 m .17747 .70604 L .19854 .71335 L p .707 .577 .707 r
F P
0 g
s
.33663 .79422 m .33973 .77545 L .31672 .76851 L p .707 .577 .707 r
F P
0 g
s
.17747 .70604 m .17615 .65145 L .16354 .64224 L p .707 .577 .707 r
F P
0 g
s
.69365 .74933 m .69089 .78754 L .66973 .78386 L p .707 .577 .707 r
F P
0 g
s
.66973 .78386 m .6725 .74565 L .69365 .74933 L p .707 .577 .707 r
F P
0 g
s
.17664 .74993 m .17355 .7687 L .19514 .76874 L p .707 .577 .707 r
F P
0 g
s
.68651 .83059 m .68342 .84936 L .66183 .84932 L p .707 .577 .707 r
F P
0 g
s
.66183 .84932 m .66492 .83055 L .68651 .83059 L p .707 .577 .707 r
F P
0 g
s
.63845 .29312 m .62686 .80188 L .63683 .79267 L p .707 .577 .707 r
F P
0 g
s
.63683 .79267 m .64842 .2839 L .63845 .29312 L p .707 .577 .707 r
F P
0 g
s
.35742 .64216 m .35874 .69676 L .3658 .68653 L p .707 .577 .707 r
F P
0 g
s
.3658 .68653 m .36448 .63194 L .35742 .64216 L p .707 .577 .707 r
F P
0 g
s
.34348 .72282 m .34072 .76103 L .35686 .7597 L p .707 .577 .707 r
F P
0 g
s
.35686 .7597 m .35963 .72149 L .34348 .72282 L p .707 .577 .707 r
F P
0 g
s
.33973 .77545 m .33663 .79422 L .35184 .80081 L p .707 .577 .707 r
F P
0 g
s
.16354 .64224 m .16486 .69683 L .17747 .70604 L p .707 .577 .707 r
F P
0 g
s
.35184 .80081 m .35494 .78203 L .33973 .77545 L p .707 .577 .707 r
F P
0 g
s
.17612 .74831 m .17889 .7101 L .16614 .70654 L p .707 .577 .707 r
F P
0 g
s
.6725 .74565 m .66973 .78386 L .64224 .78042 L p .707 .577 .707 r
F P
0 g
s
.64224 .78042 m .645 .74221 L .6725 .74565 L p .707 .577 .707 r
F P
0 g
s
.16322 .75203 m .16013 .77081 L .17355 .7687 L p .707 .577 .707 r
F P
0 g
s
.17355 .7687 m .17664 .74993 L .16322 .75203 L p .707 .577 .707 r
F P
0 g
s
.66492 .83055 m .66183 .84932 L .63419 .84714 L p .707 .577 .707 r
F P
0 g
s
.16614 .70654 m .16337 .74475 L .17612 .74831 L p .707 .577 .707 r
F P
0 g
s
.16486 .69683 m .16354 .64224 L .16063 .63202 L p .707 .577 .707 r
F P
0 g
s
.36157 .62172 m .36288 .67632 L .35661 .67173 L p .707 .577 .707 r
F P
0 g
s
.35661 .67173 m .35028 .6671 L p .35861 .63361 L .707 .577 .707 r
F P
0 g
s
.35861 .63361 m .36157 .62172 L .35661 .67173 L .707 .577 .707 r
F
.35028 .6671 m .34896 .61251 L .35932 .62008 L p F P
0 g
s
.35932 .62008 m .36157 .62172 L p .35861 .63361 L .707 .577 .707 r
F P
0 g
s
.35028 .6671 m .35932 .62008 L .35861 .63361 L .707 .577 .707 r
F
.35963 .72149 m .35686 .7597 L .36373 .75738 L p F P
0 g
s
.36373 .75738 m .36649 .71917 L .35963 .72149 L p .707 .577 .707 r
F P
0 g
s
.35494 .78203 m .35184 .80081 L .35777 .8064 L p .707 .577 .707 r
F P
0 g
s
.35777 .8064 m .36086 .78762 L .35494 .78203 L p .707 .577 .707 r
F P
0 g
s
.36649 .71917 m .36373 .75738 L .36063 .75428 L p .707 .577 .707 r
F P
0 g
s
.36086 .78762 m .35777 .8064 L .35383 .81044 L p .707 .577 .707 r
F P
0 g
s
.35383 .81044 m .35692 .79167 L .36086 .78762 L p .707 .577 .707 r
F P
0 g
s
.35692 .79167 m .35383 .81044 L .34041 .81255 L p .707 .577 .707 r
F P
0 g
s
.34041 .81255 m .3435 .79378 L .35692 .79167 L p .707 .577 .707 r
F P
0 g
s
.35315 .79207 m .37095 .80134 L p .37002 .72391 L .707 .577 .707 r
F P
0 g
s
.36448 .63194 m .3658 .68653 L .36288 .67632 L p .707 .577 .707 r
F P
0 g
s
.36288 .67632 m .36157 .62172 L .36448 .63194 L p .707 .577 .707 r
F P
0 g
s
.36063 .75428 m .36303 .7211 L p .36649 .71917 L .707 .577 .707 r
F P
0 g
s
.36928 .66226 m .36474 .28331 L .36303 .7211 L .707 .577 .707 r
F
.36303 .7211 m .3634 .71607 L .36355 .71623 L p F P
0 g
s
.36355 .71623 m .36649 .71917 L p .36303 .7211 L .707 .577 .707 r
F P
0 g
s
.36474 .28331 m .35484 .71782 L p .36303 .7211 L .707 .577 .707 r
F P
0 g
s
.37002 .72391 m .36928 .66226 L .36303 .7211 L .707 .577 .707 r
F
.36063 .75428 m .35506 .75273 L p .36232 .72082 L F P
0 g
s
.36303 .7211 m .36063 .75428 L p .36232 .72082 L .707 .577 .707 r
F P
0 g
s
.35506 .75273 m .34788 .75072 L p .35495 .73494 L .707 .577 .707 r
F P
0 g
s
.35495 .73494 m .3634 .71607 L .35506 .75273 L .707 .577 .707 r
F
.34788 .75072 m .35064 .71251 L .35482 .71368 L p F P
0 g
s
.34788 .75072 m .35482 .71368 L .35495 .73494 L .707 .577 .707 r
F
.35315 .79207 m .35534 .69607 L p .35423 .71725 L F P
0 g
s
.35482 .71368 m .3634 .71607 L p .35495 .73494 L .707 .577 .707 r
F P
0 g
s
.35423 .71725 m .35466 .68753 L .35063 .78611 L .707 .577 .707 r
F
.35466 .68753 m .36063 .27359 L .35416 .60518 L F
.35466 .68753 m .35416 .60518 L .35063 .78611 L F
.35484 .71782 m .35315 .79207 L p .37002 .72391 L F P
0 g
s
.3634 .71607 m .36303 .7211 L p .36232 .72082 L .707 .577 .707 r
F P
0 g
s
.34904 .78235 m .35063 .78611 L p .35416 .60518 L .707 .577 .707 r
F P
0 g
s
.36063 .27359 m .35393 .56762 L p .35416 .60518 L .707 .577 .707 r
F P
0 g
s
.35064 .71251 m .34788 .75072 L .34249 .74979 L p .707 .577 .707 r
F P
0 g
s
.34249 .74979 m .32672 .74704 L p .34401 .72209 L .707 .577 .707 r
F P
0 g
s
.34401 .72209 m .35064 .71251 L .34249 .74979 L .707 .577 .707 r
F
.32672 .74704 m .32949 .70883 L .35064 .71251 L p F P
0 g
s
.35393 .56762 m .34904 .78235 L p .35416 .60518 L .707 .577 .707 r
F P
0 g
s
.36474 .28331 m .36063 .27359 L p .35423 .71725 L .707 .577 .707 r
F P
0 g
s
.35534 .69607 m .36474 .28331 L p .35423 .71725 L .707 .577 .707 r
F P
0 g
s
.34904 .78235 m .35494 .52304 L p .3706 .26437 L .707 .577 .707 r
F P
0 g
s
.35494 .52304 m .36063 .27359 L .36907 .26578 L p .707 .577 .707 r
F P
0 g
s
.36907 .26578 m .3706 .26437 L p .35494 .52304 L .707 .577 .707 r
F P
0 g
s
.35063 .78611 m .35315 .79207 L p .35423 .71725 L .707 .577 .707 r
F P
0 g
s
.63419 .84714 m .63728 .82837 L .66492 .83055 L p .707 .577 .707 r
F P
0 g
s
.57499 .81862 m .57189 .8374 L .54334 .83078 L p .707 .577 .707 r
F P
0 g
s
.63728 .82837 m .63419 .84714 L .6032 .84303 L p .707 .577 .707 r
F P
0 g
s
.6032 .84303 m .60629 .82426 L .63728 .82837 L p .707 .577 .707 r
F P
0 g
s
.60629 .82426 m .6032 .84303 L .57189 .8374 L p .707 .577 .707 r
F P
0 g
s
.57189 .8374 m .57499 .81862 L .60629 .82426 L p .707 .577 .707 r
F P
0 g
s
.16063 .63202 m .16195 .68661 L .16486 .69683 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16337 .74475 m .16614 .70654 L .16304 .70345 L p .707 .577 .707 r
F P
0 g
s
.15928 .75608 m .15619 .77485 L .16013 .77081 L p .707 .577 .707 r
F P
0 g
s
.16013 .77081 m .16322 .75203 L .15928 .75608 L p .707 .577 .707 r
F P
0 g
s
.64842 .2839 m .63683 .79267 L .63272 .78294 L p .707 .577 .707 r
F P
0 g
s
.63272 .78294 m .64431 .27418 L .64842 .2839 L p .707 .577 .707 r
F P
0 g
s
.16304 .70345 m .16027 .74166 L .16337 .74475 L p .707 .577 .707 r
F P
0 g
s
.16195 .68661 m .16063 .63202 L .16769 .6218 L p .707 .577 .707 r
F P
0 g
s
.16769 .6218 m .16901 .67639 L .16195 .68661 L p .707 .577 .707 r
F P
0 g
s
.16027 .74166 m .16304 .70345 L .1699 .70113 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16521 .76167 m .16211 .78044 L .15619 .77485 L p .707 .577 .707 r
F P
0 g
s
.15619 .77485 m .15928 .75608 L .16521 .76167 L p .707 .577 .707 r
F P
0 g
s
.16901 .67639 m .16769 .6218 L .18404 .61257 L p .707 .577 .707 r
F P
0 g
s
.1699 .70113 m .16713 .73934 L .16027 .74166 L p .707 .577 .707 r
F P
0 g
s
.64431 .27418 m .63272 .78294 L .61492 .77367 L p .707 .577 .707 r
F P
0 g
s
.61492 .77367 m .62651 .26491 L .64431 .27418 L p .707 .577 .707 r
F P
0 g
s
.34896 .61251 m .35028 .6671 L .32921 .6598 L p .707 .577 .707 r
F P
0 g
s
.32921 .6598 m .32789 .6052 L .34896 .61251 L p .707 .577 .707 r
F P
0 g
s
.18404 .61257 m .18535 .66717 L .16901 .67639 L p .707 .577 .707 r
F P
0 g
s
.18535 .66717 m .18404 .61257 L .20807 .60525 L p .707 .577 .707 r
F P
0 g
s
.16713 .73934 m .1699 .70113 L .18605 .6998 L p .707 .577 .707 r
F P
0 g
s
.359 .77313 m .3706 .26437 L .39368 .25656 L p .707 .577 .707 r
F P
0 g
s
.3706 .26437 m .359 .77313 L .34904 .78235 L p .707 .577 .707 r
F P
0 g
s
.18042 .76826 m .17732 .78703 L .16211 .78044 L p .707 .577 .707 r
F P
0 g
s
.16211 .78044 m .16521 .76167 L .18042 .76826 L p .707 .577 .707 r
F P
0 g
s
.18605 .6998 m .18328 .73801 L .16713 .73934 L p .707 .577 .707 r
F P
0 g
s
.32789 .6052 m .32921 .6598 L .30175 .65511 L p .707 .577 .707 r
F P
0 g
s
.30175 .65511 m .30043 .60052 L .32789 .6052 L p .707 .577 .707 r
F P
0 g
s
.20807 .60525 m .20939 .65984 L .18535 .66717 L p .707 .577 .707 r
F P
0 g
s
.20939 .65984 m .20807 .60525 L .23744 .60054 L p .707 .577 .707 r
F P
0 g
s
.3435 .79378 m .34041 .81255 L .31882 .81251 L p .707 .577 .707 r
F P
0 g
s
.31882 .81251 m .32191 .79374 L .3435 .79378 L p .707 .577 .707 r
F P
0 g
s
.62651 .26491 m .61492 .77367 L .58518 .76575 L p .707 .577 .707 r
F P
0 g
s
.58518 .76575 m .59677 .25699 L .62651 .26491 L p .707 .577 .707 r
F P
0 g
s
.30043 .60052 m .30175 .65511 L .27058 .6535 L p .707 .577 .707 r
F P
0 g
s
.27058 .6535 m .26926 .59891 L .30043 .60052 L p .707 .577 .707 r
F P
0 g
s
.18328 .73801 m .18605 .6998 L .2099 .6996 L p .707 .577 .707 r
F P
0 g
s
.20343 .77519 m .20033 .79397 L .17732 .78703 L p .707 .577 .707 r
F P
0 g
s
.17732 .78703 m .18042 .76826 L .20343 .77519 L p .707 .577 .707 r
F P
0 g
s
.23875 .65513 m .23744 .60054 L .26926 .59891 L p .707 .577 .707 r
F P
0 g
s
.23744 .60054 m .23875 .65513 L .20939 .65984 L p .707 .577 .707 r
F P
0 g
s
.2099 .6996 m .20713 .73781 L .18328 .73801 L p .707 .577 .707 r
F P
0 g
s
.26926 .59891 m .27058 .6535 L .23875 .65513 L p .707 .577 .707 r
F P
0 g
s
.73738 .65648 m .73606 .60188 L .70489 .60028 L p .707 .577 .707 r
F P
0 g
s
.73606 .60188 m .73738 .65648 L .76921 .65485 L p .707 .577 .707 r
F P
0 g
s
.76921 .65485 m .76789 .60025 L .73606 .60188 L p .707 .577 .707 r
F P
0 g
s
.76789 .60025 m .76921 .65485 L .79857 .65014 L p .707 .577 .707 r
F P
0 g
s
.79857 .65014 m .79725 .59555 L .76789 .60025 L p .707 .577 .707 r
F P
0 g
s
.39368 .25656 m .38208 .76532 L .359 .77313 L p .707 .577 .707 r
F P
0 g
s
.38208 .76532 m .39368 .25656 L .42761 .25092 L p .707 .577 .707 r
F P
0 g
s
.70621 .65487 m .70489 .60028 L .67743 .59559 L p .707 .577 .707 r
F P
0 g
s
.70489 .60028 m .70621 .65487 L .73738 .65648 L p .707 .577 .707 r
F P
0 g
s
.32949 .70883 m .32672 .74704 L .29923 .74361 L p .707 .577 .707 r
F P
0 g
s
.29923 .74361 m .30199 .7054 L .32949 .70883 L p .707 .577 .707 r
F P
0 g
s
.32191 .79374 m .31882 .81251 L .29118 .81033 L p .707 .577 .707 r
F P
0 g
s
.29118 .81033 m .29427 .79155 L .32191 .79374 L p .707 .577 .707 r
F P
0 g
s
.20713 .73781 m .2099 .6996 L .23912 .70054 L p .707 .577 .707 r
F P
0 g
s
.79725 .59555 m .79857 .65014 L .82261 .64281 L p .707 .577 .707 r
F P
0 g
s
.82261 .64281 m .82129 .58822 L .79725 .59555 L p .707 .577 .707 r
F P
0 g
s
.23198 .78181 m .22888 .80058 L .20033 .79397 L p .707 .577 .707 r
F P
0 g
s
.20033 .79397 m .20343 .77519 L .23198 .78181 L p .707 .577 .707 r
F P
0 g
s
.23912 .70054 m .23636 .73875 L .20713 .73781 L p .707 .577 .707 r
F P
0 g
s
.73612 .69187 m .73889 .65366 L .70775 .65081 L p .707 .577 .707 r
F P
0 g
s
.73889 .65366 m .73612 .69187 L .76785 .69387 L p .707 .577 .707 r
F P
0 g
s
.76785 .69387 m .77062 .65566 L .73889 .65366 L p .707 .577 .707 r
F P
0 g
s
.59677 .25699 m .58518 .76575 L .54641 .75996 L p .707 .577 .707 r
F P
0 g
s
.54641 .75996 m .558 .2512 L .59677 .25699 L p .707 .577 .707 r
F P
0 g
s
.67875 .65018 m .67743 .59559 L .65637 .58828 L p .707 .577 .707 r
F P
0 g
s
.67743 .59559 m .67875 .65018 L .70621 .65487 L p .707 .577 .707 r
F P
0 g
s
.30199 .7054 m .29923 .74361 L .26809 .74075 L p .707 .577 .707 r
F P
0 g
s
.26809 .74075 m .27086 .70254 L .30199 .7054 L p .707 .577 .707 r
F P
0 g
s
.29427 .79155 m .29118 .81033 L .26019 .80622 L p .707 .577 .707 r
F P
0 g
s
.77062 .65566 m .76785 .69387 L .79708 .69482 L p .707 .577 .707 r
F P
0 g
s
.79708 .69482 m .79984 .65661 L .77062 .65566 L p .707 .577 .707 r
F P
0 g
s
.70775 .65081 m .70498 .68902 L .73612 .69187 L p .707 .577 .707 r
F P
0 g
s
.70609 .6928 m .70299 .71158 L .73398 .71569 L p .707 .577 .707 r
F P
0 g
s
.73398 .71569 m .73707 .69691 L .70609 .6928 L p .707 .577 .707 r
F P
0 g
s
.73707 .69691 m .73398 .71569 L .76528 .72132 L p .707 .577 .707 r
F P
0 g
s
.23636 .73875 m .23912 .70054 L .27086 .70254 L p .707 .577 .707 r
F P
0 g
s
.26019 .80622 m .26328 .78744 L .29427 .79155 L p .707 .577 .707 r
F P
0 g
s
.26328 .78744 m .26019 .80622 L .22888 .80058 L p .707 .577 .707 r
F P
0 g
s
.22888 .80058 m .23198 .78181 L .26328 .78744 L p .707 .577 .707 r
F P
0 g
s
.70498 .68902 m .70775 .65081 L .68026 .64737 L p .707 .577 .707 r
F P
0 g
s
.76528 .72132 m .76838 .70255 L .73707 .69691 L p .707 .577 .707 r
F P
0 g
s
.76838 .70255 m .76528 .72132 L .79384 .72793 L p .707 .577 .707 r
F P
0 g
s
.27086 .70254 m .26809 .74075 L .23636 .73875 L p .707 .577 .707 r
F P
0 g
s
.68026 .64737 m .67749 .68558 L .70498 .68902 L p .707 .577 .707 r
F P
0 g
s
.79384 .72793 m .79693 .70916 L .76838 .70255 L p .707 .577 .707 r
F P
0 g
s
.41601 .75969 m .42761 .25092 L .46907 .24801 L p .707 .577 .707 r
F P
0 g
s
.42761 .25092 m .41601 .75969 L .38208 .76532 L p .707 .577 .707 r
F P
0 g
s
.67844 .69062 m .67535 .70939 L .70299 .71158 L p .707 .577 .707 r
F P
0 g
s
.70299 .71158 m .70609 .6928 L .67844 .69062 L p .707 .577 .707 r
F P
0 g
s
.82129 .58822 m .82261 .64281 L .83895 .63359 L p .707 .577 .707 r
F P
0 g
s
.83895 .63359 m .83763 .579 L .82129 .58822 L p .707 .577 .707 r
F P
0 g
s
.79984 .65661 m .79708 .69482 L .82093 .69462 L p .707 .577 .707 r
F P
0 g
s
.82093 .69462 m .8237 .65641 L .79984 .65661 L p .707 .577 .707 r
F P
0 g
s
.65637 .58828 m .65769 .64288 L .67875 .65018 L p .707 .577 .707 r
F P
0 g
s
.79693 .70916 m .79384 .72793 L .81685 .73487 L p .707 .577 .707 r
F P
0 g
s
.67749 .68558 m .68026 .64737 L .6591 .64369 L p .707 .577 .707 r
F P
0 g
s
.558 .2512 m .54641 .75996 L .50241 .75687 L p .707 .577 .707 r
F P
0 g
s
.50241 .75687 m .514 .2481 L .558 .2512 L p .707 .577 .707 r
F P
0 g
s
.81685 .73487 m .81994 .7161 L .79693 .70916 L p .707 .577 .707 r
F P
0 g
s
.65769 .64288 m .65637 .58828 L .64376 .57907 L p .707 .577 .707 r
F P
0 g
s
.6591 .64369 m .65633 .6819 L .67749 .68558 L p .707 .577 .707 r
F P
0 g
s
.65686 .69058 m .65376 .70935 L .67535 .70939 L p .707 .577 .707 r
F P
0 g
s
.67535 .70939 m .67844 .69062 L .65686 .69058 L p .707 .577 .707 r
F P
0 g
s
.45747 .75677 m .46907 .24801 L .514 .2481 L p .707 .577 .707 r
F P
0 g
s
.46907 .24801 m .45747 .75677 L .41601 .75969 L p .707 .577 .707 r
F P
0 g
s
.514 .2481 m .50241 .75687 L .45747 .75677 L p .707 .577 .707 r
F P
0 g
s
.8237 .65641 m .82093 .69462 L .83708 .69329 L p .707 .577 .707 r
F P
0 g
s
.83708 .69329 m .83984 .65508 L .8237 .65641 L p .707 .577 .707 r
F P
0 g
s
.83763 .579 m .83895 .63359 L .84601 .62337 L p .707 .577 .707 r
F P
0 g
s
.84601 .62337 m .8447 .56878 L .83763 .579 L p .707 .577 .707 r
F P
0 g
s
.81994 .7161 m .81685 .73487 L .83206 .74146 L p .707 .577 .707 r
F P
0 g
s
.64376 .57907 m .64508 .63366 L .65769 .64288 L p .707 .577 .707 r
F P
0 g
s
.83206 .74146 m .83515 .72269 L .81994 .7161 L p .707 .577 .707 r
F P
0 g
s
.65633 .6819 m .6591 .64369 L .64635 .64013 L p .707 .577 .707 r
F P
0 g
s
.64635 .64013 m .64358 .67834 L .65633 .6819 L p .707 .577 .707 r
F P
0 g
s
.64343 .69269 m .64034 .71146 L .65376 .70935 L p .707 .577 .707 r
F P
0 g
s
.65376 .70935 m .65686 .69058 L .64343 .69269 L p .707 .577 .707 r
F P
0 g
s
.64508 .63366 m .64376 .57907 L .64084 .56885 L p .707 .577 .707 r
F P
0 g
s
.83984 .65508 m .83708 .69329 L .84394 .69096 L p .707 .577 .707 r
F P
0 g
s
.84394 .69096 m .84671 .65275 L .83984 .65508 L p .707 .577 .707 r
F P
0 g
s
.8447 .56878 m .84601 .62337 L .8431 .61315 L p .707 .577 .707 r
F P
0 g
s
.8431 .61315 m .84178 .55856 L .8447 .56878 L p .707 .577 .707 r
F P
0 g
s
.83515 .72269 m .83206 .74146 L .83798 .74705 L p .707 .577 .707 r
F P
0 g
s
.64084 .56885 m .64216 .62345 L .64508 .63366 L p .707 .577 .707 r
F P
0 g
s
.83798 .74705 m .84108 .72828 L .83515 .72269 L p .707 .577 .707 r
F P
0 g
s
.64358 .67834 m .64635 .64013 L .64325 .63704 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64325 .63704 m .64048 .67525 L .64358 .67834 L p .707 .577 .707 r
F P
0 g
s
.63949 .69673 m .6364 .71551 L .64034 .71146 L p .707 .577 .707 r
F P
0 g
s
.64034 .71146 m .64343 .69269 L .63949 .69673 L p .707 .577 .707 r
F P
0 g
s
.64216 .62345 m .64084 .56885 L .6479 .55863 L p .707 .577 .707 r
F P
0 g
s
.84671 .65275 m .84394 .69096 L .84084 .68787 L p .707 .577 .707 r
F P
0 g
s
.84084 .68787 m .84361 .64966 L .84671 .65275 L p .707 .577 .707 r
F P
0 g
s
.84178 .55856 m .8431 .61315 L .83049 .60394 L p .707 .577 .707 r
F P
0 g
s
.83049 .60394 m .82917 .54934 L .84178 .55856 L p .707 .577 .707 r
F P
0 g
s
.84108 .72828 m .83798 .74705 L .83404 .7511 L p .707 .577 .707 r
F P
0 g
s
.6479 .55863 m .64922 .61322 L .64216 .62345 L p .707 .577 .707 r
F P
0 g
s
.83404 .7511 m .83714 .73232 L .84108 .72828 L p .707 .577 .707 r
F P
0 g
s
.64048 .67525 m .64325 .63704 L .65011 .63471 L p .707 .577 .707 r
F P
0 g
s
.39437 .61966 m .39305 .56507 L .36188 .56346 L p .707 .577 .707 r
F P
0 g
s
.39305 .56507 m .39437 .61966 L .4262 .61803 L p .707 .577 .707 r
F P
0 g
s
.4262 .61803 m .42488 .56344 L .39305 .56507 L p .707 .577 .707 r
F P
0 g
s
.65011 .63471 m .64735 .67292 L .64048 .67525 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64542 .70232 m .64232 .7211 L .6364 .71551 L p .707 .577 .707 r
F P
0 g
s
.6364 .71551 m .63949 .69673 L .64542 .70232 L p .707 .577 .707 r
F P
0 g
s
.64922 .61322 m .6479 .55863 L .66425 .54941 L p .707 .577 .707 r
F P
0 g
s
.42488 .56344 m .4262 .61803 L .45556 .61332 L p .707 .577 .707 r
F P
0 g
s
.45556 .61332 m .45424 .55873 L .42488 .56344 L p .707 .577 .707 r
F P
0 g
s
.3632 .61806 m .36188 .56346 L .33442 .55878 L p .707 .577 .707 r
F P
0 g
s
.36188 .56346 m .3632 .61806 L .39437 .61966 L p .707 .577 .707 r
F P
0 g
s
.45424 .55873 m .45556 .61332 L .4796 .606 L p .707 .577 .707 r
F P
0 g
s
.4796 .606 m .47828 .55141 L .45424 .55873 L p .707 .577 .707 r
F P
0 g
s
.82917 .54934 m .83049 .60394 L .80942 .59663 L p .707 .577 .707 r
F P
0 g
s
.80942 .59663 m .8081 .54204 L .82917 .54934 L p .707 .577 .707 r
F P
0 g
s
.84361 .64966 m .84084 .68787 L .82809 .68431 L p .707 .577 .707 r
F P
0 g
s
.82809 .68431 m .83086 .6461 L .84361 .64966 L p .707 .577 .707 r
F P
0 g
s
.66425 .54941 m .66557 .604 L .64922 .61322 L p .707 .577 .707 r
F P
0 g
s
.83714 .73232 m .83404 .7511 L .82062 .7532 L p .707 .577 .707 r
F P
0 g
s
.39311 .65506 m .39588 .61685 L .36474 .61399 L p .707 .577 .707 r
F P
0 g
s
.39588 .61685 m .39311 .65506 L .42484 .65706 L p .707 .577 .707 r
F P
0 g
s
.42484 .65706 m .42761 .61885 L .39588 .61685 L p .707 .577 .707 r
F P
0 g
s
.33574 .61337 m .33442 .55878 L .31336 .55147 L p .707 .577 .707 r
F P
0 g
s
.33442 .55878 m .33574 .61337 L .3632 .61806 L p .707 .577 .707 r
F P
0 g
s
.82062 .7532 m .82371 .73443 L .83714 .73232 L p .707 .577 .707 r
F P
0 g
s
.42761 .61885 m .42484 .65706 L .45407 .658 L p .707 .577 .707 r
F P
0 g
s
.45407 .658 m .45684 .61979 L .42761 .61885 L p .707 .577 .707 r
F P
0 g
s
.36474 .61399 m .36197 .6522 L .39311 .65506 L p .707 .577 .707 r
F P
0 g
s
.36308 .65599 m .35998 .67476 L .39097 .67887 L p .707 .577 .707 r
F P
0 g
s
.39097 .67887 m .39406 .6601 L .36308 .65599 L p .707 .577 .707 r
F P
0 g
s
.39406 .6601 m .39097 .67887 L .42227 .68451 L p .707 .577 .707 r
F P
0 g
s
.66557 .604 m .66425 .54941 L .68828 .54208 L p .707 .577 .707 r
F P
0 g
s
.64735 .67292 m .65011 .63471 L .66626 .63339 L p .707 .577 .707 r
F P
0 g
s
.36197 .6522 m .36474 .61399 L .33725 .61056 L p .707 .577 .707 r
F P
0 g
s
.42227 .68451 m .42537 .66573 L .39406 .6601 L p .707 .577 .707 r
F P
0 g
s
.42537 .66573 m .42227 .68451 L .45083 .69112 L p .707 .577 .707 r
F P
0 g
s
.66626 .63339 m .66349 .6716 L .64735 .67292 L p .707 .577 .707 r
F P
0 g
s
.66063 .70891 m .65754 .72768 L .64232 .7211 L p .707 .577 .707 r
F P
0 g
s
.64232 .7211 m .64542 .70232 L .66063 .70891 L p .707 .577 .707 r
F P
0 g
s
.33725 .61056 m .33448 .64876 L .36197 .6522 L p .707 .577 .707 r
F P
0 g
s
.45083 .69112 m .45392 .67235 L .42537 .66573 L p .707 .577 .707 r
F P
0 g
s
.33543 .6538 m .33234 .67258 L .35998 .67476 L p .707 .577 .707 r
F P
0 g
s
.35998 .67476 m .36308 .65599 L .33543 .6538 L p .707 .577 .707 r
F P
0 g
s
.47828 .55141 m .4796 .606 L .49594 .59677 L p .707 .577 .707 r
F P
0 g
s
.49594 .59677 m .49462 .54218 L .47828 .55141 L p .707 .577 .707 r
F P
0 g
s
.45684 .61979 m .45407 .658 L .47792 .6578 L p .707 .577 .707 r
F P
0 g
s
.47792 .6578 m .48069 .61959 L .45684 .61979 L p .707 .577 .707 r
F P
0 g
s
.8081 .54204 m .80942 .59663 L .78196 .59194 L p .707 .577 .707 r
F P
0 g
s
.78196 .59194 m .78064 .53735 L .8081 .54204 L p .707 .577 .707 r
F P
0 g
s
.31336 .55147 m .31467 .60606 L .33574 .61337 L p .707 .577 .707 r
F P
0 g
s
.45392 .67235 m .45083 .69112 L .47384 .69806 L p .707 .577 .707 r
F P
0 g
s
.33448 .64876 m .33725 .61056 L .31609 .60688 L p .707 .577 .707 r
F P
0 g
s
.47384 .69806 m .47693 .67928 L .45392 .67235 L p .707 .577 .707 r
F P
0 g
s
.68828 .54208 m .6896 .59667 L .66557 .604 L p .707 .577 .707 r
F P
0 g
s
.31467 .60606 m .31336 .55147 L .30075 .54226 L p .707 .577 .707 r
F P
0 g
s
.6896 .59667 m .68828 .54208 L .71765 .53737 L p .707 .577 .707 r
F P
0 g
s
.83086 .6461 m .82809 .68431 L .80693 .68063 L p .707 .577 .707 r
F P
0 g
s
.80693 .68063 m .8097 .64242 L .83086 .6461 L p .707 .577 .707 r
F P
0 g
s
.31609 .60688 m .31332 .64509 L .33448 .64876 L p .707 .577 .707 r
F P
0 g
s
.31385 .65376 m .31075 .67254 L .33234 .67258 L p .707 .577 .707 r
F P
0 g
s
.33234 .67258 m .33543 .6538 L .31385 .65376 L p .707 .577 .707 r
F P
0 g
s
.82371 .73443 m .82062 .7532 L .79903 .75316 L p .707 .577 .707 r
F P
0 g
s
.79903 .75316 m .80213 .73439 L .82371 .73443 L p .707 .577 .707 r
F P
0 g
s
.78064 .53735 m .78196 .59194 L .75079 .59034 L p .707 .577 .707 r
F P
0 g
s
.75079 .59034 m .74947 .53574 L .78064 .53735 L p .707 .577 .707 r
F P
0 g
s
.66349 .6716 m .66626 .63339 L .69011 .63319 L p .707 .577 .707 r
F P
0 g
s
.71897 .59197 m .71765 .53737 L .74947 .53574 L p .707 .577 .707 r
F P
0 g
s
.71765 .53737 m .71897 .59197 L .6896 .59667 L p .707 .577 .707 r
F P
0 g
s
.69011 .63319 m .68735 .6714 L .66349 .6716 L p .707 .577 .707 r
F P
0 g
s
.68364 .71585 m .68054 .73462 L .65754 .72768 L p .707 .577 .707 r
F P
0 g
s
.65754 .72768 m .66063 .70891 L .68364 .71585 L p .707 .577 .707 r
F P
0 g
s
.48069 .61959 m .47792 .6578 L .49407 .65647 L p .707 .577 .707 r
F P
0 g
s
.49407 .65647 m .49683 .61826 L .48069 .61959 L p .707 .577 .707 r
F P
0 g
s
.49462 .54218 m .49594 .59677 L .503 .58655 L p .707 .577 .707 r
F P
0 g
s
.503 .58655 m .50169 .53196 L .49462 .54218 L p .707 .577 .707 r
F P
0 g
s
.74947 .53574 m .75079 .59034 L .71897 .59197 L p .707 .577 .707 r
F P
0 g
s
.47693 .67928 m .47384 .69806 L .48905 .70465 L p .707 .577 .707 r
F P
0 g
s
.30075 .54226 m .30207 .59685 L .31467 .60606 L p .707 .577 .707 r
F P
0 g
s
.48905 .70465 m .49214 .68587 L .47693 .67928 L p .707 .577 .707 r
F P
0 g
s
.31332 .64509 m .31609 .60688 L .30334 .60332 L p .707 .577 .707 r
F P
0 g
s
.8097 .64242 m .80693 .68063 L .77944 .6772 L p .707 .577 .707 r
F P
0 g
s
.77944 .6772 m .78221 .63899 L .8097 .64242 L p .707 .577 .707 r
F P
0 g
s
.30334 .60332 m .30057 .64153 L .31332 .64509 L p .707 .577 .707 r
F P
0 g
s
.30042 .65587 m .29733 .67464 L .31075 .67254 L p .707 .577 .707 r
F P
0 g
s
.31075 .67254 m .31385 .65376 L .30042 .65587 L p .707 .577 .707 r
F P
0 g
s
.80213 .73439 m .79903 .75316 L .77139 .75098 L p .707 .577 .707 r
F P
0 g
s
.30207 .59685 m .30075 .54226 L .29783 .53204 L p .707 .577 .707 r
F P
0 g
s
.77139 .75098 m .77449 .73221 L .80213 .73439 L p .707 .577 .707 r
F P
0 g
s
.68735 .6714 m .69011 .63319 L .71934 .63413 L p .707 .577 .707 r
F P
0 g
s
.71219 .72246 m .7091 .74123 L .68054 .73462 L p .707 .577 .707 r
F P
0 g
s
.68054 .73462 m .68364 .71585 L .71219 .72246 L p .707 .577 .707 r
F P
0 g
s
.71934 .63413 m .71657 .67234 L .68735 .6714 L p .707 .577 .707 r
F P
0 g
s
.78221 .63899 m .77944 .6772 L .7483 .67434 L p .707 .577 .707 r
F P
0 g
s
.7483 .67434 m .75107 .63613 L .78221 .63899 L p .707 .577 .707 r
F P
0 g
s
.49683 .61826 m .49407 .65647 L .50093 .65415 L p .707 .577 .707 r
F P
0 g
s
.50093 .65415 m .5037 .61594 L .49683 .61826 L p .707 .577 .707 r
F P
0 g
s
.77449 .73221 m .77139 .75098 L .7404 .74687 L p .707 .577 .707 r
F P
0 g
s
.50169 .53196 m .503 .58655 L .50009 .57633 L p .707 .577 .707 r
F P
0 g
s
.50009 .57633 m .49877 .52174 L .50169 .53196 L p .707 .577 .707 r
F P
0 g
s
.71657 .67234 m .71934 .63413 L .75107 .63613 L p .707 .577 .707 r
F P
0 g
s
.49214 .68587 m .48905 .70465 L .49497 .71024 L p .707 .577 .707 r
F P
0 g
s
.29783 .53204 m .29915 .58663 L .30207 .59685 L p .707 .577 .707 r
F P
0 g
s
.7404 .74687 m .7435 .7281 L .77449 .73221 L p .707 .577 .707 r
F P
0 g
s
.7435 .7281 m .7404 .74687 L .7091 .74123 L p .707 .577 .707 r
F P
0 g
s
.7091 .74123 m .71219 .72246 L .7435 .7281 L p .707 .577 .707 r
F P
0 g
s
.75107 .63613 m .7483 .67434 L .71657 .67234 L p .707 .577 .707 r
F P
0 g
s
.49497 .71024 m .49807 .69146 L .49214 .68587 L p .707 .577 .707 r
F P
0 g
s
.30057 .64153 m .30334 .60332 L .30024 .60022 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30024 .60022 m .29747 .63843 L .30057 .64153 L p .707 .577 .707 r
F P
0 g
s
.29648 .65992 m .29339 .67869 L .29733 .67464 L p .707 .577 .707 r
F P
0 g
s
.29733 .67464 m .30042 .65587 L .29648 .65992 L p .707 .577 .707 r
F P
0 g
s
.29915 .58663 m .29783 .53204 L .30489 .52182 L p .707 .577 .707 r
F P
0 g
s
.5037 .61594 m .50093 .65415 L .49783 .65105 L p .707 .577 .707 r
F P
0 g
s
.49783 .65105 m .5006 .61285 L .5037 .61594 L p .707 .577 .707 r
F P
0 g
s
.49877 .52174 m .50009 .57633 L .48748 .56712 L p .707 .577 .707 r
F P
0 g
s
.48748 .56712 m .48616 .51253 L .49877 .52174 L p .707 .577 .707 r
F P
0 g
s
.49807 .69146 m .49497 .71024 L .49103 .71428 L p .707 .577 .707 r
F P
0 g
s
.30489 .52182 m .30621 .57641 L .29915 .58663 L p .707 .577 .707 r
F P
0 g
s
.49103 .71428 m .49413 .69551 L .49807 .69146 L p .707 .577 .707 r
F P
0 g
s
.29747 .63843 m .30024 .60022 L .3071 .5979 L p .707 .577 .707 r
F P
0 g
s
.3071 .5979 m .30434 .63611 L .29747 .63843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30241 .66551 m .29931 .68428 L .29339 .67869 L p .707 .577 .707 r
F P
0 g
s
.29339 .67869 m .29648 .65992 L .30241 .66551 L p .707 .577 .707 r
F P
0 g
s
.30621 .57641 m .30489 .52182 L .32124 .51259 L p .707 .577 .707 r
F P
0 g
s
.48616 .51253 m .48748 .56712 L .46641 .55981 L p .707 .577 .707 r
F P
0 g
s
.46641 .55981 m .46509 .50522 L .48616 .51253 L p .707 .577 .707 r
F P
0 g
s
.5006 .61285 m .49783 .65105 L .48508 .64749 L p .707 .577 .707 r
F P
0 g
s
.48508 .64749 m .48785 .60929 L .5006 .61285 L p .707 .577 .707 r
F P
0 g
s
.32124 .51259 m .32256 .56718 L .30621 .57641 L p .707 .577 .707 r
F P
0 g
s
.49413 .69551 m .49103 .71428 L .47761 .71639 L p .707 .577 .707 r
F P
0 g
s
.47761 .71639 m .4807 .69761 L .49413 .69551 L p .707 .577 .707 r
F P
0 g
s
.32256 .56718 m .32124 .51259 L .34527 .50527 L p .707 .577 .707 r
F P
0 g
s
.30434 .63611 m .3071 .5979 L .32325 .59657 L p .707 .577 .707 r
F P
0 g
s
.32325 .59657 m .32048 .63478 L .30434 .63611 L p .707 .577 .707 r
F P
0 g
s
.31762 .67209 m .31453 .69087 L .29931 .68428 L p .707 .577 .707 r
F P
0 g
s
.29931 .68428 m .30241 .66551 L .31762 .67209 L p .707 .577 .707 r
F P
0 g
s
.46509 .50522 m .46641 .55981 L .43895 .55513 L p .707 .577 .707 r
F P
0 g
s
.43895 .55513 m .43763 .50053 L .46509 .50522 L p .707 .577 .707 r
F P
0 g
s
.34527 .50527 m .34659 .55986 L .32256 .56718 L p .707 .577 .707 r
F P
0 g
s
.34659 .55986 m .34527 .50527 L .37464 .50056 L p .707 .577 .707 r
F P
0 g
s
.48785 .60929 m .48508 .64749 L .46392 .64382 L p .707 .577 .707 r
F P
0 g
s
.46392 .64382 m .46669 .60561 L .48785 .60929 L p .707 .577 .707 r
F P
0 g
s
.4807 .69761 m .47761 .71639 L .45602 .71635 L p .707 .577 .707 r
F P
0 g
s
.45602 .71635 m .45912 .69757 L .4807 .69761 L p .707 .577 .707 r
F P
0 g
s
.43763 .50053 m .43895 .55513 L .40778 .55352 L p .707 .577 .707 r
F P
0 g
s
.40778 .55352 m .40646 .49893 L .43763 .50053 L p .707 .577 .707 r
F P
0 g
s
.32048 .63478 m .32325 .59657 L .3471 .59637 L p .707 .577 .707 r
F P
0 g
s
.37596 .55515 m .37464 .50056 L .40646 .49893 L p .707 .577 .707 r
F P
0 g
s
.37464 .50056 m .37596 .55515 L .34659 .55986 L p .707 .577 .707 r
F P
0 g
s
.3471 .59637 m .34434 .63458 L .32048 .63478 L p .707 .577 .707 r
F P
0 g
s
.34063 .67903 m .33753 .69781 L .31453 .69087 L p .707 .577 .707 r
F P
0 g
s
.31453 .69087 m .31762 .67209 L .34063 .67903 L p .707 .577 .707 r
F P
0 g
s
.40646 .49893 m .40778 .55352 L .37596 .55515 L p .707 .577 .707 r
F P
0 g
s
.46669 .60561 m .46392 .64382 L .43643 .64038 L p .707 .577 .707 r
F P
0 g
s
.43643 .64038 m .4392 .60217 L .46669 .60561 L p .707 .577 .707 r
F P
0 g
s
.45912 .69757 m .45602 .71635 L .42838 .71417 L p .707 .577 .707 r
F P
0 g
s
.42838 .71417 m .43147 .69539 L .45912 .69757 L p .707 .577 .707 r
F P
0 g
s
.34434 .63458 m .3471 .59637 L .37633 .59732 L p .707 .577 .707 r
F P
0 g
s
.36918 .68564 m .36609 .70442 L .33753 .69781 L p .707 .577 .707 r
F P
0 g
s
.33753 .69781 m .34063 .67903 L .36918 .68564 L p .707 .577 .707 r
F P
0 g
s
.37633 .59732 m .37356 .63553 L .34434 .63458 L p .707 .577 .707 r
F P
0 g
s
.4392 .60217 m .43643 .64038 L .40529 .63752 L p .707 .577 .707 r
F P
0 g
s
.40529 .63752 m .40806 .59931 L .4392 .60217 L p .707 .577 .707 r
F P
0 g
s
.43147 .69539 m .42838 .71417 L .39739 .71006 L p .707 .577 .707 r
F P
0 g
s
.37356 .63553 m .37633 .59732 L .40806 .59931 L p .707 .577 .707 r
F P
0 g
s
.39739 .71006 m .40049 .69128 L .43147 .69539 L p .707 .577 .707 r
F P
0 g
s
.40049 .69128 m .39739 .71006 L .36609 .70442 L p .707 .577 .707 r
F P
0 g
s
.36609 .70442 m .36918 .68564 L .40049 .69128 L p .707 .577 .707 r
F P
0 g
s
.40806 .59931 m .40529 .63752 L .37356 .63553 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0020OolH0025Ool007Moo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEPT007aoo`00
LWoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P00MWoo
001^Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001aOol006]oo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00@006eoo`00J7oo0`0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0`00JWoo001W
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001XOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02001VOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001TOol006Eoo`05001JEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Eo
o`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`05
001JEUYFFUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`05001J
EUYFFUH00004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIo
o`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`=JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP8006Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo
00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00D0
05YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00D005YF
FUIJEP0000EJEP/000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00<005YFFUH0200015YF00<005YFFUH00UYF
200015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001QOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001MOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol005]oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001GOol2
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000BOolE000nOol005Aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000moo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEP00
00<003Yoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo10001EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00eYF1000=Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP0200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0007Ool400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUH00002000cOol005Aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`8000EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP80035oo`00E7oo
00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00AJEQD000IJEP03001JEUYF00=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0`00
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00;goo001DOol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF
FUH01eYF00<005YFFUH015YF10000UYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo00000002FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000]Ool005Eoo`03001JEP0000=JEP03001JEUYF00=JEP@0009JEP03001JEUYF00=J
EP03001JEP00008000EJEP04001JEUYFFUH40002FUH50004FUH01`00FUIJEUYF001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool005Eoo`03001JEP0000=JEP03001JEP0000<000AJEQH000IJEP03001JEUYF009JEP<0
0003FUH005YF009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Eoo`03001JEP0000=JEP80009JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00
0003FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001EOol01000FUH005YF0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH0000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYFFUH2000/Ool005Eoo`03001JEP00008000EJEP03001JEUYF00AJ
EP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP@000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYFFUH2000/Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP04001J
EP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`80009JEP03001JEUYF00=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP06001JEUYFFUH0
05YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUIJEP00
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP02000/Ool005Eoo`05001JEUYFFUH00005FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
00=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;7oo001EOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80009Ool80004FUH00`00FUIJEP03FUH00`00FUIJEP02
000/Ool005Eoo`04001JEUYFFUHF00000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00D005YF001JEP0000AJEP03001JEUYF00=JEPH000Qoo`<000]oo`T000AJEP03001JEUYF0080
02aoo`00@Woo600000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0000=JEP00FUH0
1UYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH00`00FUH0000300000eYF000000070003Ool5
00000goo000000070003FUH00`00FUIJEP03FUH3000015YF001JEUYF0P00;7oo000nOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH800000eYF001JEP05FUH30004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF0P0000=JEP00FUH01UYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8002ao
o`00>Woo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPT000IJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH20003
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00
FUIJEUYF001JEP8002aoo`00=Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01@000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YF001JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002aoo`00<goo0`001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00L005YF001JEP00FUH0
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH3000/Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEP0002aoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000H0004FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0002@000MJEP03001JEUYF00AJEP04001JEUYFFUH2000^Ool0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00EJEP8000=JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEPT000AJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH90006FUH01000FUH00000<7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0`00
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH9000bOol0
02eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP0000@000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPH000=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00;goo000]Ool00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH3000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YF000002eoo`00;Goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF009JEPT000AJEP03001JEUYF01<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYFFUH5000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;7oo000]Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH00UYF30001Goo1`0000=JEP00FUH015YF00@005YFFUIJEQX000AJ
EP03001JEUYF00=JEP03001JEUYF00H000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool002eoo`04001JEUYF
0003FUH00`00FUIJEP03FUH60007Ool50008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH60005FUH00`00FUIJEP03FUH=0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0P00;7oo000^Ool00`00FUH00003FUH00`00FUH000030002FUH80003Ool500000goo000000070002
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;7oo000^Ool00`00FUH00003
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP0300000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo00<005YF00000UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF001JEP00FUH20005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00000UYF
300015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YF
FUH005YF000/Ool002ioo`03001JEP00008000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP05001JEP00FUH00003FUH@0006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0`00
1EYF00<005YFFUH015YF4P0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo
000^Ool01@00FUH005YF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00D0
05YF001JEP0000AJEP03001JEP0000800005FUH005YFFUH00003FUH00`00FUH000030002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000^
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUH005YF000015YF00<005YFFUH00UYF1@000eYF00<005YFFUH00UYF200015YF00<005YFFUH01UYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00001P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF1`000eYF00<005YFFUH00P00;Goo000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH01000
FUIJEUYF1`0000=JEP00FUH01@0000=JEP00000010001UYF00<005YFFUH015YF0`001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF000000EJEPL000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPD00003FUH00000
02eoo`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00P000=JEP04001J
EUYFFUH40002FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000001eYF00<005YFFUH00UYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<002eoo`00;Woo00D005YF
FUIJEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEPP000MJEP@000AJEP03001JEUYF009JEP<00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000d00004FUH0
05YFFUH20003Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002eo
o`00;Woo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP<00003
FUH005YF00=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03
001JEUYF00=JEP04001JEUYFFUH90009OolI000^Ool002ioo`05001JEUYFFUH00005FUH700000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPd00004FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90017
Ool002moo`T000=JEP04001JEUYFFUHB00000eYF001JEP06FUH00`00FUIJEP04FUH50002FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH0045oo`00;Woo0`000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEPP00003FUH005YF00AJEP@0009JEPH000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH000000005FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000mOol002ioo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH7
0003Ool01000FUIJEP001EYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
0003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH4000iOol002ioo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00@0009JEP03001JEUYF00=JEP03001JEUYF00AJEP@0009JEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUH0000300000eYF000000080004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000eOol002ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUHF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP03FUH30003FUH30002
Ool80005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000cOol002ioo`03001JEP0000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<0
05YFFUH01EYF00<005YF00000`0000=JEP00Ool01Goo1`000UYF00<005YFFUH01EYF00<005YFFUH0
1EYF0`00<Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH01EYF00<005YFFUH00eYF1@000goo
1@000Woo1P0015YF00<005YFFUH01EYF00<005YFFUH00P00;goo000]Ool00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF1000
1EYF00<005YFFUH01UYF00<005YFFUH0200027oo1P001EYF00<005YFFUH00UYF0P00;Woo000]Ool0
0`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF1@0000=JEP00FUH01eYF00<005YFFUH015YF1`002goo100000=JEP00FUH00eYF
00<005YF0000;Goo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH30006FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUHH000]Ool002eoo`03001JEP00009JEPd000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEPD0009JEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP06001JEUYF001JEP00;Goo000]Ool60005
FUH00`00FUIJEP04FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH30002Ool50006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP02000^Ool002ioo`80
009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEPP000=JEP03
001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00H000EJEP8000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH2000^Ool0031oo`D000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEPH000=JEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00003FUH7000>Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000^OolE0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002FUH0
0`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH005YF00001eYF00<005YFFUH0
1@0047oo200015YF00<005YFFUH00eYF00<005YFFUH00P00;goo000]Ool20003FUH00`00FUIJEP02
FUH20007FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000MJ
EP03001JEUYF00=JEP03001JEP00008001Eoo`d0035oo`00;Goo0P000eYF00<005YFFUH00UYF0P00
1UYF0P001UYF1`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEP00FUH00007FUH00`00FUIJEP03FUH00`00FUIJEP02001COol002eoo`<0
0003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP8000=JEQL0009JEP03001JEUYF00=J
EP03001JEUYF00=JEP/000aJEP03001JEUYF00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000008FUH00`00FUIJEP03FUH00`00FUIJEP02001COol002aoo`04001JEP00FUH20005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20007FUH00`00FUIJEP04000;Ool01000FUIJEP0015YF
1`002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF1`001UYF00<005YFFUH00UYF
00@005YF000000MJEP03001JEUYF00AJEP03001JEUYF008005=oo`00;7oo00<005YF00000eYF2@00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10001goo00D005YFFUH005YF00<0
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP8000]JEP03001JEUYF00=JEP@0
009JEP03001JEUYF009JEP04001JEP000007FUH00`00FUIJEP03FUH01000FUIJEUYF0P00Dgoo000/
Ool00`00FUH00004FUH00`00FUH000020003Ool90004FUH30006FUH00`00FUIJEP06FUH00`00FUH0
00020004Ool00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH2000;FUH00`00FUIJEP06FUH40004FUH01000FUH000001eYF00<005YFFUH00eYF00@0
05YFFUIJEP8005=oo`00;7oo00<005YF000015YF00<005YFFUH00UYF0`002Goo2@0015YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000Woo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF0P002eYF00<005YFFUH01UYF00@005YFFUIJEP80009JEP04
001JEP000007FUH00`00FUIJEP03FUH01@00FUIJEUYF0000E7oo000]Ool20003FUH00`00FUIJEP04
FUH00`00FUH000030008Ool500000goo000000040006FUH00`00FUIJEP04FUH50004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH300000eYF000000030004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
E7oo000_Ool200000eYF001JEP05FUH00`00FUIJEP03FUH700000goo000000030007Ool40002FUH0
0`00FUIJEP04FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001J
EP03FUH70003FUH01@00FUIJEUYF0000E7oo000aOol30004FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000:Ool40004FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF
000000EJEP03001JEUYF00=JEPD0009JEP03001oogoo059oo`00=7oo0`0000=JEP00FUH01eYF00<0
05YFFUH01UYF00<005YFFUH010002Woo0`0000=JEP00FUH00UYF0P0015YF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF00@005YF000000EJEP03001JEUYF00AJEP04001JEUYFFUH3001DOol003Moo`@000IJ
EP03001JEUYF00IJEP03001JEUYF00AJEQD000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0005FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Aoo`00>goo10000UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<00003FUH005YF
00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF00AJEP03001JEP0001<005Eoo`00?goo10001UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009oo`<000IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEPD006Ioo`00
@goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000Eo
o`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP<000=JEPH0061oo`00Agoo1`0015YF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000Moo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEP00
00<005aoo`00CWoo200015YF00<005YFFUH00eYF00<005YFFUH00P002goo1`001EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEPP000EJEP03001JEUYF00IJEP03001J
EUYF00=JEP8005Yoo`00EWoo3@0057oo30001UYF00<005YFFUH02UYF00<005YFFUH00eYF2@0017oo
1`000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`00F7oo0023OolI0005FUH50003Ool50002Ool4
0006FUH00`00FUIJEP05FUH00`00FUIJEP02001FOol0091oo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00P000Ioo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00TWoo
0`001EYF00<005YFFUH01UYF00<005YFFUH015YF1`001goo10001EYF00<005YFFUH00UYF00<005YF
0000E7oo002EOol400000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH80003Ool40000
0eYF001JEP02FUH4001DOol009Uoo`<000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF
FUH<000015YF001JEP00E7oo002LOol40002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUIJEP04FUH00`00FUIJEP02001EOol00:1oo`L000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Eoo`00Ygoo2@0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Eoo`00/7oo200015YF00<005YFFUH00eYF00<005YFFUH00P00
EWoo002hOol=001HOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59221 .74234 m .59353 .68597 L .56236 .68377 L p .707 .577 .707 r
F P
0 g
s
.59353 .68597 m .59221 .74234 L .62404 .74243 L p .707 .577 .707 r
F P
0 g
s
.62404 .74243 m .62536 .68606 L .59353 .68597 L p .707 .577 .707 r
F P
0 g
s
.62536 .68606 m .62404 .74243 L .65341 .7404 L p .707 .577 .707 r
F P
0 g
s
.65341 .7404 m .65472 .68404 L .62536 .68606 L p .707 .577 .707 r
F P
0 g
s
.56105 .74014 m .56236 .68377 L .5349 .67968 L p .707 .577 .707 r
F P
0 g
s
.56236 .68377 m .56105 .74014 L .59221 .74234 L p .707 .577 .707 r
F P
0 g
s
.65472 .68404 m .65341 .7404 L .67744 .73645 L p .707 .577 .707 r
F P
0 g
s
.67744 .73645 m .67876 .68009 L .65472 .68404 L p .707 .577 .707 r
F P
0 g
s
.5349 .67968 m .53358 .73604 L .56105 .74014 L p .707 .577 .707 r
F P
0 g
s
.53358 .73604 m .5349 .67968 L .51384 .67409 L p .707 .577 .707 r
F P
0 g
s
.5947 .823 m .59194 .7885 L .5608 .78751 L p .707 .577 .707 r
F P
0 g
s
.59194 .7885 m .5947 .823 L .62644 .81958 L p .707 .577 .707 r
F P
0 g
s
.62644 .81958 m .62367 .78508 L .59194 .7885 L p .707 .577 .707 r
F P
0 g
s
.62367 .78508 m .62644 .81958 L .65566 .81209 L p .707 .577 .707 r
F P
0 g
s
.65566 .81209 m .65289 .77759 L .62367 .78508 L p .707 .577 .707 r
F P
0 g
s
.56357 .82201 m .5608 .78751 L .53331 .78221 L p .707 .577 .707 r
F P
0 g
s
.5608 .78751 m .56357 .82201 L .5947 .823 L p .707 .577 .707 r
F P
0 g
s
.51384 .67409 m .51252 .73046 L .53358 .73604 L p .707 .577 .707 r
F P
0 g
s
.67876 .68009 m .67744 .73645 L .69379 .73097 L p .707 .577 .707 r
F P
0 g
s
.69379 .73097 m .6951 .67461 L .67876 .68009 L p .707 .577 .707 r
F P
0 g
s
.65289 .77759 m .65566 .81209 L .67951 .80126 L p .707 .577 .707 r
F P
0 g
s
.67951 .80126 m .67675 .76676 L .65289 .77759 L p .707 .577 .707 r
F P
0 g
s
.51252 .73046 m .51384 .67409 L .50123 .66756 L p .707 .577 .707 r
F P
0 g
s
.53607 .81671 m .53331 .78221 L .51215 .77311 L p .707 .577 .707 r
F P
0 g
s
.53331 .78221 m .53607 .81671 L .56357 .82201 L p .707 .577 .707 r
F P
0 g
s
.67675 .76676 m .67951 .80126 L .69566 .78815 L p .707 .577 .707 r
F P
0 g
s
.69566 .78815 m .69289 .75366 L .67675 .76676 L p .707 .577 .707 r
F P
0 g
s
.50123 .66756 m .49991 .72392 L .51252 .73046 L p .707 .577 .707 r
F P
0 g
s
.6951 .67461 m .69379 .73097 L .70085 .72449 L p .707 .577 .707 r
F P
0 g
s
.70085 .72449 m .70217 .66813 L .6951 .67461 L p .707 .577 .707 r
F P
0 g
s
.51215 .77311 m .51492 .80761 L .53607 .81671 L p .707 .577 .707 r
F P
0 g
s
.63391 .87845 m .63081 .86383 L .59951 .87031 L p .707 .577 .707 r
F P
0 g
s
.63081 .86383 m .63391 .87845 L .66246 .86619 L p .707 .577 .707 r
F P
0 g
s
.66246 .86619 m .65937 .85157 L .63081 .86383 L p .707 .577 .707 r
F P
0 g
s
.60261 .88493 m .59951 .87031 L .56852 .87037 L p .707 .577 .707 r
F P
0 g
s
.59951 .87031 m .60261 .88493 L .63391 .87845 L p .707 .577 .707 r
F P
0 g
s
.51492 .80761 m .51215 .77311 L .4994 .76112 L p .707 .577 .707 r
F P
0 g
s
.65937 .85157 m .66246 .86619 L .68547 .84936 L p .707 .577 .707 r
F P
0 g
s
.68547 .84936 m .68238 .83473 L .65937 .85157 L p .707 .577 .707 r
F P
0 g
s
.49991 .72392 m .50123 .66756 L .49831 .66072 L p .707 .577 .707 r
F P
0 g
s
.57162 .88499 m .56852 .87037 L .54088 .86401 L p .707 .577 .707 r
F P
0 g
s
.56852 .87037 m .57162 .88499 L .60261 .88493 L p .707 .577 .707 r
F P
0 g
s
.69289 .75366 m .69566 .78815 L .70252 .77405 L p .707 .577 .707 r
F P
0 g
s
.70252 .77405 m .69976 .73955 L .69289 .75366 L p .707 .577 .707 r
F P
0 g
s
.4994 .76112 m .50217 .79562 L .51492 .80761 L p .707 .577 .707 r
F P
0 g
s
.54088 .86401 m .54398 .87864 L .57162 .88499 L p .707 .577 .707 r
F P
0 g
s
.49831 .66072 m .49699 .71708 L .49991 .72392 L p .707 .577 .707 r
F P
0 g
s
.68238 .83473 m .68547 .84936 L .70068 .82959 L p .707 .577 .707 r
F P
0 g
s
.70068 .82959 m .69759 .81497 L .68238 .83473 L p .707 .577 .707 r
F P
0 g
s
.54398 .87864 m .54088 .86401 L .51929 .85186 L p .707 .577 .707 r
F P
0 g
s
.70217 .66813 m .70085 .72449 L .69793 .71765 L p .707 .577 .707 r
F P
0 g
s
.69793 .71765 m .69925 .66129 L .70217 .66813 L p .707 .577 .707 r
F P
0 g
s
.50217 .79562 m .4994 .76112 L .4963 .7474 L p .707 .577 .707 r
F P
0 g
s
.51929 .85186 m .52239 .86648 L .54398 .87864 L p .707 .577 .707 r
F P
0 g
s
.49759 .8245 m .486 .33129 L .442 .32901 L p .707 .577 .707 r
F P
0 g
s
.49699 .71708 m .49831 .66072 L .50537 .65424 L p .707 .577 .707 r
F P
0 g
s
.4963 .7474 m .49907 .78189 L .50217 .79562 L p .707 .577 .707 r
F P
0 g
s
.50537 .65424 m .50405 .7106 L .49699 .71708 L p .707 .577 .707 r
F P
0 g
s
.49907 .78189 m .4963 .7474 L .50316 .73329 L p .707 .577 .707 r
F P
0 g
s
.52239 .86648 m .51929 .85186 L .50587 .8351 L p .707 .577 .707 r
F P
0 g
s
.50587 .8351 m .50897 .84972 L .52239 .86648 L p .707 .577 .707 r
F P
0 g
s
.50897 .84972 m .50587 .8351 L .50193 .81537 L p .706 .577 .707 r
F P
0 g
s
.50405 .7106 m .50537 .65424 L .52172 .64876 L p .707 .577 .707 r
F P
0 g
s
.50316 .73329 m .50593 .76779 L .49907 .78189 L p .707 .577 .707 r
F P
0 g
s
.50193 .81537 m .50503 .82999 L .50897 .84972 L p .706 .577 .707 r
F P
0 g
s
.52172 .64876 m .5204 .70512 L .50405 .7106 L p .707 .577 .707 r
F P
0 g
s
.50593 .76779 m .50316 .73329 L .51931 .72018 L p .707 .577 .707 r
F P
0 g
s
.50503 .82999 m .50193 .81537 L .50786 .7946 L p .707 .577 .707 r
F P
0 g
s
.5204 .70512 m .52172 .64876 L .54575 .64481 L p .707 .577 .707 r
F P
0 g
s
.51931 .72018 m .52208 .75468 L .50593 .76779 L p .707 .577 .707 r
F P
0 g
s
.50786 .7946 m .51095 .80922 L .50503 .82999 L p .707 .577 .707 r
F P
0 g
s
.54575 .64481 m .54443 .70118 L .5204 .70512 L p .707 .577 .707 r
F P
0 g
s
.52208 .75468 m .51931 .72018 L .54316 .70935 L p .707 .577 .707 r
F P
0 g
s
.51095 .80922 m .50786 .7946 L .52307 .77483 L p .707 .577 .707 r
F P
0 g
s
.54316 .70935 m .54593 .74385 L .52208 .75468 L p .707 .577 .707 r
F P
0 g
s
.52307 .77483 m .52616 .78945 L .51095 .80922 L p .707 .577 .707 r
F P
0 g
s
.52616 .78945 m .52307 .77483 L .54608 .758 L p .707 .577 .707 r
F P
0 g
s
.54608 .758 m .54917 .77262 L .52616 .78945 L p .707 .577 .707 r
F P
0 g
s
.486 .33129 m .49759 .8245 L .54252 .82223 L p .707 .577 .707 r
F P
0 g
s
.54252 .82223 m .53093 .32902 L .486 .33129 L p .707 .577 .707 r
F P
0 g
s
.54443 .70118 m .54575 .64481 L .57512 .64279 L p .707 .577 .707 r
F P
0 g
s
.54593 .74385 m .54316 .70935 L .57239 .70186 L p .707 .577 .707 r
F P
0 g
s
.57512 .64279 m .5738 .69915 L .54443 .70118 L p .707 .577 .707 r
F P
0 g
s
.57515 .73636 m .57239 .70186 L .60412 .69845 L p .707 .577 .707 r
F P
0 g
s
.57239 .70186 m .57515 .73636 L .54593 .74385 L p .707 .577 .707 r
F P
0 g
s
.60412 .69845 m .60689 .73294 L .57515 .73636 L p .707 .577 .707 r
F P
0 g
s
.54917 .77262 m .54608 .758 L .57463 .74574 L p .707 .577 .707 r
F P
0 g
s
.60593 .73926 m .60903 .75388 L .57772 .76036 L p .707 .577 .707 r
F P
0 g
s
.57772 .76036 m .57463 .74574 L .60593 .73926 L p .707 .577 .707 r
F P
0 g
s
.57463 .74574 m .57772 .76036 L .54917 .77262 L p .707 .577 .707 r
F P
0 g
s
.53093 .32902 m .54252 .82223 L .58398 .81564 L p .707 .577 .707 r
F P
0 g
s
.5738 .69915 m .57512 .64279 L .60694 .64288 L p .707 .577 .707 r
F P
0 g
s
.60412 .69845 m .63526 .69944 L p .61444 .72402 L .707 .577 .707 r
F P
0 g
s
.6053 .71317 m .60412 .69845 L p .61444 .72402 L .707 .577 .707 r
F P
0 g
s
.60694 .64288 m .60563 .69924 L .59354 .6992 L p .707 .577 .707 r
F P
0 g
s
.59354 .6992 m .5738 .69915 L p .58191 .68539 L .707 .577 .707 r
F P
0 g
s
.58191 .68539 m .60694 .64288 L .59354 .6992 L .707 .577 .707 r
F
.60689 .73294 m .6053 .71317 L p .61444 .72402 L F P
0 g
s
.58398 .81564 m .57239 .32242 L .53093 .32902 L p .707 .577 .707 r
F P
0 g
s
.69976 .73955 m .70252 .77405 L .69943 .76032 L p .707 .577 .707 r
F P
0 g
s
.69943 .76032 m .69666 .72583 L .69976 .73955 L p .707 .577 .707 r
F P
0 g
s
.69759 .81497 m .70068 .82959 L .70661 .80882 L p .707 .577 .707 r
F P
0 g
s
.70661 .80882 m .70351 .7942 L .69759 .81497 L p .707 .577 .707 r
F P
0 g
s
.45359 .82222 m .442 .32901 L .40323 .32241 L p .707 .577 .707 r
F P
0 g
s
.442 .32901 m .45359 .82222 L .49759 .8245 L p .707 .577 .707 r
F P
0 g
s
.63526 .69944 m .66275 .70474 L p .64488 .72584 L .707 .577 .707 r
F P
0 g
s
.63648 .71474 m .63526 .69944 L p .64488 .72584 L .707 .577 .707 r
F P
0 g
s
.63526 .69944 m .63802 .73393 L .60689 .73294 L p .707 .577 .707 r
F P
0 g
s
.63811 .64508 m .63679 .70144 L .62585 .70066 L p .707 .577 .707 r
F P
0 g
s
.62585 .70066 m .60563 .69924 L p .6141 .68511 L .707 .577 .707 r
F P
0 g
s
.6141 .68511 m .63811 .64508 L .62585 .70066 L .707 .577 .707 r
F
.63802 .73393 m .63648 .71474 L p .64488 .72584 L F P
0 g
s
.60563 .69924 m .60694 .64288 L .63811 .64508 L p .707 .577 .707 r
F P
0 g
s
.63692 .7392 m .64002 .75382 L .60903 .75388 L p .707 .577 .707 r
F P
0 g
s
.60903 .75388 m .60593 .73926 L .63692 .7392 L p .707 .577 .707 r
F P
0 g
s
.57239 .32242 m .58398 .81564 L .61791 .80536 L p .707 .577 .707 r
F P
0 g
s
.61791 .80536 m .60632 .31215 L .57239 .32242 L p .707 .577 .707 r
F P
0 g
s
.69925 .66129 m .69793 .71765 L .68532 .71112 L p .707 .577 .707 r
F P
0 g
s
.68532 .71112 m .68664 .65476 L .69925 .66129 L p .707 .577 .707 r
F P
0 g
s
.24921 .70552 m .25052 .64916 L .21936 .64696 L p .707 .577 .707 r
F P
0 g
s
.25052 .64916 m .24921 .70552 L .28103 .70561 L p .707 .577 .707 r
F P
0 g
s
.28103 .70561 m .28235 .64925 L .25052 .64916 L p .707 .577 .707 r
F P
0 g
s
.70351 .7942 m .70661 .80882 L .70267 .78909 L p .706 .577 .707 r
F P
0 g
s
.70267 .78909 m .69957 .77447 L .70351 .7942 L p .706 .577 .707 r
F P
0 g
s
.41482 .81562 m .40323 .32241 L .37349 .31212 L p .707 .577 .707 r
F P
0 g
s
.40323 .32241 m .41482 .81562 L .45359 .82222 L p .707 .577 .707 r
F P
0 g
s
.28235 .64925 m .28103 .70561 L .3104 .70358 L p .707 .577 .707 r
F P
0 g
s
.3104 .70358 m .31172 .64722 L .28235 .64925 L p .707 .577 .707 r
F P
0 g
s
.69666 .72583 m .69943 .76032 L .68667 .74833 L p .707 .577 .707 r
F P
0 g
s
.68667 .74833 m .68391 .71383 L .69666 .72583 L p .707 .577 .707 r
F P
0 g
s
.21804 .70332 m .21936 .64696 L .19189 .64287 L p .707 .577 .707 r
F P
0 g
s
.21936 .64696 m .21804 .70332 L .24921 .70552 L p .707 .577 .707 r
F P
0 g
s
.31172 .64722 m .3104 .70358 L .33443 .69963 L p .707 .577 .707 r
F P
0 g
s
.33443 .69963 m .33575 .64327 L .31172 .64722 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.64002 .75382 m .63692 .7392 L .66456 .74555 L p .707 .577 .707 r
F P
0 g
s
.60632 .31215 m .61791 .80536 L .64099 .7924 L p .707 .577 .707 r
F P
0 g
s
.66275 .70474 m .68391 .71383 L p .67085 .73187 L .707 .577 .707 r
F P
0 g
s
.66393 .71946 m .66275 .70474 L p .67085 .73187 L .707 .577 .707 r
F P
0 g
s
.66275 .70474 m .66552 .73924 L .63802 .73393 L p .707 .577 .707 r
F P
0 g
s
.66557 .64917 m .66426 .70553 L .65543 .70421 L p .707 .577 .707 r
F P
0 g
s
.65543 .70421 m .63679 .70144 L p .64528 .68603 L .707 .577 .707 r
F P
0 g
s
.64528 .68603 m .66557 .64917 L .65543 .70421 L .707 .577 .707 r
F
.66552 .73924 m .66393 .71946 L p .67085 .73187 L F P
0 g
s
.63679 .70144 m .63811 .64508 L .66557 .64917 L p .707 .577 .707 r
F P
0 g
s
.66456 .74555 m .66766 .76018 L .64002 .75382 L p .707 .577 .707 r
F P
0 g
s
.64099 .7924 m .6294 .29919 L .60632 .31215 L p .707 .577 .707 r
F P
0 g
s
.19189 .64287 m .19058 .69923 L .21804 .70332 L p .707 .577 .707 r
F P
0 g
s
.68664 .65476 m .68532 .71112 L .66426 .70553 L p .707 .577 .707 r
F P
0 g
s
.66426 .70553 m .66557 .64917 L .68664 .65476 L p .707 .577 .707 r
F P
0 g
s
.19058 .69923 m .19189 .64287 L .17083 .63728 L p .707 .577 .707 r
F P
0 g
s
.2517 .78618 m .24893 .75169 L .21779 .75069 L p .707 .577 .707 r
F P
0 g
s
.24893 .75169 m .2517 .78618 L .28343 .78277 L p .707 .577 .707 r
F P
0 g
s
.28343 .78277 m .28066 .74827 L .24893 .75169 L p .707 .577 .707 r
F P
0 g
s
.69957 .77447 m .70267 .78909 L .68925 .77233 L p .707 .577 .707 r
F P
0 g
s
.68925 .77233 m .68615 .75771 L .69957 .77447 L p .707 .577 .707 r
F P
0 g
s
.28066 .74827 m .28343 .78277 L .31265 .77528 L p .707 .577 .707 r
F P
0 g
s
.31265 .77528 m .30989 .74078 L .28066 .74827 L p .707 .577 .707 r
F P
0 g
s
.68391 .71383 m .68667 .74833 L .66552 .73924 L p .707 .577 .707 r
F P
0 g
s
.22056 .78519 m .21779 .75069 L .1903 .74539 L p .707 .577 .707 r
F P
0 g
s
.21779 .75069 m .22056 .78519 L .2517 .78618 L p .707 .577 .707 r
F P
0 g
s
.38508 .80533 m .37349 .31212 L .35569 .29917 L p .707 .577 .707 r
F P
0 g
s
.37349 .31212 m .38508 .80533 L .41482 .81562 L p .707 .577 .707 r
F P
0 g
s
.17083 .63728 m .16951 .69364 L .19058 .69923 L p .707 .577 .707 r
F P
0 g
s
.33575 .64327 m .33443 .69963 L .35078 .69415 L p .707 .577 .707 r
F P
0 g
s
.35078 .69415 m .3521 .63779 L .33575 .64327 L p .707 .577 .707 r
F P
0 g
s
.30989 .74078 m .31265 .77528 L .33651 .76445 L p .707 .577 .707 r
F P
0 g
s
.33651 .76445 m .33374 .72995 L .30989 .74078 L p .707 .577 .707 r
F P
0 g
s
.16951 .69364 m .17083 .63728 L .15822 .63075 L p .707 .577 .707 r
F P
0 g
s
.19307 .77989 m .1903 .74539 L .16914 .7363 L p .707 .577 .707 r
F P
0 g
s
.1903 .74539 m .19307 .77989 L .22056 .78519 L p .707 .577 .707 r
F P
0 g
s
.68615 .75771 m .68925 .77233 L .66766 .76018 L p .707 .577 .707 r
F P
0 g
s
.66766 .76018 m .66456 .74555 L .68615 .75771 L p .707 .577 .707 r
F P
0 g
s
.6294 .29919 m .64099 .7924 L .65096 .77804 L p .707 .577 .707 r
F P
0 g
s
.65096 .77804 m .63937 .28483 L .6294 .29919 L p .707 .577 .707 r
F P
0 g
s
.33374 .72995 m .33651 .76445 L .35265 .75134 L p .707 .577 .707 r
F P
0 g
s
.35265 .75134 m .34989 .71684 L .33374 .72995 L p .707 .577 .707 r
F P
0 g
s
.15822 .63075 m .1569 .68711 L .16951 .69364 L p .707 .577 .707 r
F P
0 g
s
.3521 .63779 m .35078 .69415 L .35784 .68768 L p .707 .577 .707 r
F P
0 g
s
.35784 .68768 m .35916 .63131 L .3521 .63779 L p .707 .577 .707 r
F P
0 g
s
.16914 .7363 m .17191 .7708 L .19307 .77989 L p .707 .577 .707 r
F P
0 g
s
.2909 .84164 m .28781 .82701 L .2565 .83349 L p .707 .577 .707 r
F P
0 g
s
.28781 .82701 m .2909 .84164 L .31945 .82938 L p .707 .577 .707 r
F P
0 g
s
.31945 .82938 m .31636 .81476 L .28781 .82701 L p .707 .577 .707 r
F P
0 g
s
.2596 .84811 m .2565 .83349 L .22551 .83355 L p .707 .577 .707 r
F P
0 g
s
.2565 .83349 m .2596 .84811 L .2909 .84164 L p .707 .577 .707 r
F P
0 g
s
.17191 .7708 m .16914 .7363 L .15639 .7243 L p .707 .577 .707 r
F P
0 g
s
.36728 .79238 m .35569 .29917 L .35157 .2848 L p .707 .577 .707 r
F P
0 g
s
.35569 .29917 m .36728 .79238 L .38508 .80533 L p .707 .577 .707 r
F P
0 g
s
.31636 .81476 m .31945 .82938 L .34246 .81254 L p .707 .577 .707 r
F P
0 g
s
.34246 .81254 m .33937 .79792 L .31636 .81476 L p .707 .577 .707 r
F P
0 g
s
.1569 .68711 m .15822 .63075 L .1553 .62391 L p .707 .577 .707 r
F P
0 g
s
.22861 .84818 m .22551 .83355 L .19787 .8272 L p .707 .577 .707 r
F P
0 g
s
.22551 .83355 m .22861 .84818 L .2596 .84811 L p .707 .577 .707 r
F P
0 g
s
.34989 .71684 m .35265 .75134 L .35951 .73723 L p .707 .577 .707 r
F P
0 g
s
.35951 .73723 m .35675 .70273 L .34989 .71684 L p .707 .577 .707 r
F P
0 g
s
.15639 .7243 m .15916 .7588 L .17191 .7708 L p .707 .577 .707 r
F P
0 g
s
.19787 .8272 m .20097 .84182 L .22861 .84818 L p .707 .577 .707 r
F P
0 g
s
.1553 .62391 m .15398 .68027 L .1569 .68711 L p .707 .577 .707 r
F P
0 g
s
.33937 .79792 m .34246 .81254 L .35767 .79277 L p .707 .577 .707 r
F P
0 g
s
.35767 .79277 m .35458 .77815 L .33937 .79792 L p .707 .577 .707 r
F P
0 g
s
.20097 .84182 m .19787 .8272 L .17628 .81504 L p .707 .577 .707 r
F P
0 g
s
.35916 .63131 m .35784 .68768 L .35492 .68084 L p .707 .577 .707 r
F P
0 g
s
.35492 .68084 m .35624 .62447 L .35916 .63131 L p .707 .577 .707 r
F P
0 g
s
.15916 .7588 m .15639 .7243 L .15329 .71058 L p .707 .577 .707 r
F P
0 g
s
.65096 .77804 m .64937 .77249 L p .64584 .60034 L .707 .577 .707 r
F P
0 g
s
.63937 .28483 m .64607 .56988 L p .64584 .60034 L .707 .577 .707 r
F P
0 g
s
.64607 .56988 m .65096 .77804 L p .64584 .60034 L .707 .577 .707 r
F P
0 g
s
.64577 .69458 m .63937 .28483 L .64937 .77249 L .707 .577 .707 r
F
.64518 .68834 m .6366 .68027 L p .63857 .68616 L F P
0 g
s
.64515 .69169 m .64685 .76368 L p .64275 .74309 L .707 .577 .707 r
F P
0 g
s
.62998 .67894 m .63697 .68481 L .64275 .74309 L .707 .577 .707 r
F
.63697 .68481 m .64515 .69169 L .64275 .74309 L F
.63697 .68481 m .6366 .68027 L .63645 .67959 L p F P
0 g
s
.64515 .69169 m .64518 .68834 L .63857 .68616 L .707 .577 .707 r
F
.63525 .27047 m .63937 .28483 L p .64534 .66713 L F P
0 g
s
.64685 .76368 m .64515 .69169 L p .64534 .66713 L .707 .577 .707 r
F P
0 g
s
.6366 .68027 m .63937 .71477 L .64494 .72001 L p .707 .577 .707 r
F P
0 g
s
.64505 .70558 m .6366 .68027 L .64494 .72001 L .707 .577 .707 r
F
.62998 .67894 m .6302 .66156 L .64515 .69169 L F
.63525 .27047 m .64466 .67061 L p .6302 .66156 L F P
0 g
s
.64466 .67061 m .64515 .69169 L p .6302 .66156 L .707 .577 .707 r
F P
0 g
s
.63843 .58347 m .63711 .63983 L .64339 .64308 L p .707 .577 .707 r
F P
0 g
s
.64522 .68277 m .63525 .27047 L .64534 .66713 L .707 .577 .707 r
F
.64466 .67061 m .63525 .27047 L p .64522 .68277 L F P
0 g
s
.64339 .64308 m .64972 .64636 L p .64139 .59995 L .707 .577 .707 r
F P
0 g
s
.64139 .59995 m .63843 .58347 L .64339 .64308 L .707 .577 .707 r
F
.64515 .69169 m .64466 .67061 L p .64522 .68277 L F P
0 g
s
.64937 .77249 m .64685 .76368 L p .64577 .69458 L .707 .577 .707 r
F P
0 g
s
.64494 .72001 m .65212 .72676 L p .64505 .70558 L .707 .577 .707 r
F P
0 g
s
.63937 .71477 m .63697 .68481 L p .63351 .66655 L .707 .577 .707 r
F P
0 g
s
.63645 .67959 m .63351 .66655 L p .63697 .68481 L .707 .577 .707 r
F P
0 g
s
.64505 .70558 m .64515 .69169 L .63857 .68616 L .707 .577 .707 r
F
.64685 .76368 m .62905 .75072 L p .62998 .67894 L F P
0 g
s
.65212 .72676 m .64935 .69226 L .64518 .68834 L p .707 .577 .707 r
F P
0 g
s
.65212 .72676 m .64518 .68834 L .64505 .70558 L .707 .577 .707 r
F
.64972 .64636 m .65104 .59 L .64068 .58463 L p F P
0 g
s
.64068 .58463 m .63843 .58347 L p .64139 .59995 L .707 .577 .707 r
F P
0 g
s
.64972 .64636 m .64068 .58463 L .64139 .59995 L .707 .577 .707 r
F
.17628 .81504 m .17938 .82967 L .20097 .84182 L p F P
0 g
s
.15398 .68027 m .1553 .62391 L .16236 .61743 L p .707 .577 .707 r
F P
0 g
s
.35675 .70273 m .35951 .73723 L .35642 .72351 L p .707 .577 .707 r
F P
0 g
s
.35642 .72351 m .35365 .68901 L .35675 .70273 L p .707 .577 .707 r
F P
0 g
s
.35458 .77815 m .35767 .79277 L .3636 .77201 L p .707 .577 .707 r
F P
0 g
s
.3636 .77201 m .3605 .75738 L .35458 .77815 L p .707 .577 .707 r
F P
0 g
s
.17938 .82967 m .17628 .81504 L .16286 .79828 L p .707 .577 .707 r
F P
0 g
s
.15329 .71058 m .15606 .74508 L .15916 .7588 L p .707 .577 .707 r
F P
0 g
s
.3605 .75738 m .3636 .77201 L .35966 .75228 L p .706 .577 .707 r
F P
0 g
s
.35157 .2848 m .36317 .77801 L .36728 .79238 L p .707 .577 .707 r
F P
0 g
s
.36317 .77801 m .35157 .2848 L .36154 .27044 L p .707 .577 .707 r
F P
0 g
s
.16236 .61743 m .16104 .67379 L .15398 .68027 L p .707 .577 .707 r
F P
0 g
s
.16286 .79828 m .16596 .8129 L .17938 .82967 L p .707 .577 .707 r
F P
0 g
s
.15606 .74508 m .15329 .71058 L .16015 .69648 L p .707 .577 .707 r
F P
0 g
s
.35624 .62447 m .35492 .68084 L .34231 .6743 L p .707 .577 .707 r
F P
0 g
s
.34231 .6743 m .34363 .61794 L .35624 .62447 L p .707 .577 .707 r
F P
0 g
s
.35966 .75228 m .35656 .73765 L .3605 .75738 L p .706 .577 .707 r
F P
0 g
s
.16596 .8129 m .16286 .79828 L .15892 .77855 L p .706 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35365 .68901 m .35642 .72351 L .34366 .71151 L p .707 .577 .707 r
F P
0 g
s
.34366 .71151 m .3409 .67702 L .35365 .68901 L p .707 .577 .707 r
F P
0 g
s
.16104 .67379 m .16236 .61743 L .17871 .61195 L p .707 .577 .707 r
F P
0 g
s
.62905 .75072 m .61746 .25751 L .63525 .27047 L p .707 .577 .707 r
F P
0 g
s
.16015 .69648 m .16292 .73097 L .15606 .74508 L p .707 .577 .707 r
F P
0 g
s
.15892 .77855 m .16202 .79317 L .16596 .8129 L p .706 .577 .707 r
F P
0 g
s
.17871 .61195 m .17739 .66831 L .16104 .67379 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16292 .73097 m .16015 .69648 L .1763 .68337 L p .707 .577 .707 r
F P
0 g
s
.31974 .66792 m .3409 .67702 L p .32784 .69505 L .707 .577 .707 r
F P
0 g
s
.32251 .70242 m .32092 .68264 L p .32784 .69505 L .707 .577 .707 r
F P
0 g
s
.32092 .68264 m .31974 .66792 L p .32784 .69505 L .707 .577 .707 r
F P
0 g
s
.31974 .66792 m .32251 .70242 L .29501 .69712 L p .707 .577 .707 r
F P
0 g
s
.29225 .66262 m .31974 .66792 L p .30187 .68903 L .707 .577 .707 r
F P
0 g
s
.29501 .69712 m .29347 .67792 L p .30187 .68903 L .707 .577 .707 r
F P
0 g
s
.29347 .67792 m .29225 .66262 L p .30187 .68903 L .707 .577 .707 r
F P
0 g
s
.29225 .66262 m .29501 .69712 L .26388 .69613 L p .707 .577 .707 r
F P
0 g
s
.26111 .66163 m .29225 .66262 L p .27143 .68721 L .707 .577 .707 r
F P
0 g
s
.26388 .69613 m .26229 .67635 L p .27143 .68721 L .707 .577 .707 r
F P
0 g
s
.26229 .67635 m .26111 .66163 L p .27143 .68721 L .707 .577 .707 r
F P
0 g
s
.23214 .69954 m .22938 .66505 L .26111 .66163 L p .707 .577 .707 r
F P
0 g
s
.26111 .66163 m .26388 .69613 L .23214 .69954 L p .707 .577 .707 r
F P
0 g
s
.26393 .60606 m .26262 .66242 L .25053 .66239 L p .707 .577 .707 r
F P
0 g
s
.25053 .66239 m .23079 .66233 L p .2389 .64857 L .707 .577 .707 r
F P
0 g
s
.2389 .64857 m .26393 .60606 L .25053 .66239 L .707 .577 .707 r
F
.2951 .60826 m .29379 .66462 L .28284 .66385 L p F P
0 g
s
.28284 .66385 m .26262 .66242 L p .27109 .64829 L .707 .577 .707 r
F P
0 g
s
.27109 .64829 m .2951 .60826 L .28284 .66385 L .707 .577 .707 r
F
.32257 .61235 m .32125 .66872 L .31242 .6674 L p F P
0 g
s
.31242 .6674 m .29379 .66462 L p .30227 .64921 L .707 .577 .707 r
F P
0 g
s
.30227 .64921 m .32257 .61235 L .31242 .6674 L .707 .577 .707 r
F
.34363 .61794 m .34231 .6743 L .32125 .66872 L p F P
0 g
s
.32125 .66872 m .32257 .61235 L .34363 .61794 L p .707 .577 .707 r
F P
0 g
s
.35656 .73765 m .35966 .75228 L .34624 .73551 L p .707 .577 .707 r
F P
0 g
s
.34624 .73551 m .34314 .72089 L .35656 .73765 L p .707 .577 .707 r
F P
0 g
s
.37314 .76365 m .36154 .27044 L .38462 .25749 L p .707 .577 .707 r
F P
0 g
s
.36154 .27044 m .37314 .76365 L .36317 .77801 L p .707 .577 .707 r
F P
0 g
s
.16202 .79317 m .15892 .77855 L .16485 .75779 L p .707 .577 .707 r
F P
0 g
s
.3409 .67702 m .34366 .71151 L .32251 .70242 L p .707 .577 .707 r
F P
0 g
s
.17739 .66831 m .17871 .61195 L .20274 .608 L p .707 .577 .707 r
F P
0 g
s
.1763 .68337 m .17907 .71786 L .16292 .73097 L p .707 .577 .707 r
F P
0 g
s
.16485 .75779 m .16794 .77241 L .16202 .79317 L p .707 .577 .707 r
F P
0 g
s
.20274 .608 m .20142 .66436 L .17739 .66831 L p .707 .577 .707 r
F P
0 g
s
.29379 .66462 m .2951 .60826 L .32257 .61235 L p .707 .577 .707 r
F P
0 g
s
.17907 .71786 m .1763 .68337 L .20015 .67254 L p .707 .577 .707 r
F P
0 g
s
.61746 .25751 m .62905 .75072 L .59931 .74044 L p .707 .577 .707 r
F P
0 g
s
.59931 .74044 m .58772 .24722 L .61746 .25751 L p .707 .577 .707 r
F P
0 g
s
.34314 .72089 m .34624 .73551 L .32465 .72336 L p .707 .577 .707 r
F P
0 g
s
.32465 .72336 m .32155 .70874 L .34314 .72089 L p .707 .577 .707 r
F P
0 g
s
.16794 .77241 m .16485 .75779 L .18006 .73802 L p .707 .577 .707 r
F P
0 g
s
.20142 .66436 m .20274 .608 L .23211 .60597 L p .707 .577 .707 r
F P
0 g
s
.26262 .66242 m .26393 .60606 L .2951 .60826 L p .707 .577 .707 r
F P
0 g
s
.20015 .67254 m .20292 .70703 L .17907 .71786 L p .707 .577 .707 r
F P
0 g
s
.18006 .73802 m .18315 .75264 L .16794 .77241 L p .707 .577 .707 r
F P
0 g
s
.39622 .7507 m .37314 .76365 L p .38106 .41469 L .707 .577 .707 r
F P
0 g
s
.39031 .49932 m .39622 .7507 L p .38106 .41469 L .707 .577 .707 r
F P
0 g
s
.39622 .7507 m .38462 .25749 L .41855 .24721 L p .707 .577 .707 r
F P
0 g
s
.39622 .7507 m .4036 .58418 L .42504 .65686 L .707 .577 .707 r
F
.43015 .74042 m .40933 .74673 L p .42573 .65922 L F P
0 g
s
.44709 .65993 m .42743 .66497 L p .42985 .66814 L .707 .577 .707 r
F P
0 g
s
.43015 .74042 m .42845 .66844 L p .43452 .66717 L .707 .577 .707 r
F P
0 g
s
.44745 .66447 m .44709 .65993 L p .42985 .66814 L .707 .577 .707 r
F P
0 g
s
.47161 .73382 m .43015 .74042 L p .43452 .66717 L .707 .577 .707 r
F P
0 g
s
.46712 .54284 m .46987 .6598 L p .44745 .66447 L .707 .577 .707 r
F P
0 g
s
.46987 .6598 m .47161 .73382 L p .4442 .68457 L .707 .577 .707 r
F P
0 g
s
.43452 .66717 m .44745 .66447 L .4442 .68457 L .707 .577 .707 r
F
.44745 .66447 m .46987 .6598 L .4442 .68457 L F
.47161 .73382 m .46712 .54284 L p .50494 .23834 L F P
0 g
s
.46712 .54284 m .46001 .24061 L .49294 .23895 L p .707 .577 .707 r
F P
0 g
s
.49294 .23895 m .50494 .23834 L p .46712 .54284 L .707 .577 .707 r
F P
0 g
s
.47371 .6836 m .47094 .6491 L .45757 .65517 L p .707 .577 .707 r
F P
0 g
s
.45757 .65517 m .44827 .65939 L p .45654 .66726 L .707 .577 .707 r
F P
0 g
s
.47371 .6836 m .45757 .65517 L .45654 .66726 L .707 .577 .707 r
F
.44827 .65939 m .44709 .65993 L p .44805 .66078 L F P
0 g
s
.47371 .6836 m .44827 .65939 L .44805 .66078 L .707 .577 .707 r
F
.44986 .69443 m .47371 .6836 L p .44805 .66078 L F P
0 g
s
.44709 .65993 m .44745 .66447 L p .44805 .66078 L .707 .577 .707 r
F P
0 g
s
.44745 .66447 m .44986 .69443 L p .44805 .66078 L .707 .577 .707 r
F P
0 g
s
.46001 .24061 m .46712 .54284 L p .43452 .66717 L .707 .577 .707 r
F P
0 g
s
.43452 .66717 m .46712 .54284 L .44745 .66447 L .707 .577 .707 r
F
.44986 .69443 m .42985 .66814 L .43156 .67898 L F
.42985 .66814 m .42743 .66497 L .42845 .66844 L F
.42985 .66814 m .42845 .66844 L .43156 .67898 L F
.44986 .69443 m .44745 .66447 L p .42985 .66814 L F P
0 g
s
.41855 .24721 m .46001 .24061 L p .43452 .66717 L .707 .577 .707 r
F P
0 g
s
.42845 .66844 m .41855 .24721 L p .43452 .66717 L .707 .577 .707 r
F P
0 g
s
.42796 .64735 m .42845 .66844 L p .42573 .65922 L .707 .577 .707 r
F P
0 g
s
.42845 .66844 m .43015 .74042 L p .42573 .65922 L .707 .577 .707 r
F P
0 g
s
.40933 .74673 m .39622 .7507 L p .42796 .64735 L .707 .577 .707 r
F P
0 g
s
.42743 .66497 m .41787 .66742 L p .43156 .67898 L .707 .577 .707 r
F P
0 g
s
.41787 .66742 m .42063 .70192 L .43708 .6977 L p .707 .577 .707 r
F P
0 g
s
.43708 .6977 m .44986 .69443 L p .43156 .67898 L .707 .577 .707 r
F P
0 g
s
.43156 .67898 m .41787 .66742 L .43708 .6977 L .707 .577 .707 r
F
.41855 .24721 m .42796 .64735 L p .42504 .65686 L F P
0 g
s
.4036 .58418 m .41855 .24721 L .42504 .65686 L .707 .577 .707 r
F
.41955 .56515 m .41823 .62152 L .43299 .6205 L p F P
0 g
s
.43299 .6205 m .4476 .61949 L p .43702 .599 L .707 .577 .707 r
F P
0 g
s
.43702 .599 m .41955 .56515 L .43299 .6205 L .707 .577 .707 r
F
.38613 .67084 m .3889 .70533 L .41255 .70279 L p F P
0 g
s
.41255 .70279 m .42063 .70192 L p .41156 .69375 L .707 .577 .707 r
F P
0 g
s
.41156 .69375 m .38613 .67084 L .41255 .70279 L .707 .577 .707 r
F
.38462 .25749 m .39031 .49932 L p .38106 .41469 L F P
0 g
s
.20292 .70703 m .20015 .67254 L .22938 .66505 L p .707 .577 .707 r
F P
0 g
s
.23211 .60597 m .23079 .66233 L .20142 .66436 L p .707 .577 .707 r
F P
0 g
s
.23079 .66233 m .23211 .60597 L .26393 .60606 L p .707 .577 .707 r
F P
0 g
s
.72942 .65824 m .73074 .60188 L .69957 .59968 L p .707 .577 .707 r
F P
0 g
s
.73074 .60188 m .72942 .65824 L .76124 .65833 L p .707 .577 .707 r
F P
0 g
s
.76124 .65833 m .76256 .60197 L .73074 .60188 L p .707 .577 .707 r
F P
0 g
s
.32155 .70874 m .32465 .72336 L .29701 .717 L p .707 .577 .707 r
F P
0 g
s
.29701 .717 m .29391 .70238 L .32155 .70874 L p .707 .577 .707 r
F P
0 g
s
.18315 .75264 m .18006 .73802 L .20307 .72118 L p .707 .577 .707 r
F P
0 g
s
.76256 .60197 m .76124 .65833 L .79061 .6563 L p .707 .577 .707 r
F P
0 g
s
.79061 .6563 m .79193 .59994 L .76256 .60197 L p .707 .577 .707 r
F P
0 g
s
.22938 .66505 m .23214 .69954 L .20292 .70703 L p .707 .577 .707 r
F P
0 g
s
.69825 .65604 m .69957 .59968 L .67211 .59559 L p .707 .577 .707 r
F P
0 g
s
.69957 .59968 m .69825 .65604 L .72942 .65824 L p .707 .577 .707 r
F P
0 g
s
.58772 .24722 m .59931 .74044 L .56054 .73383 L p .707 .577 .707 r
F P
0 g
s
.56054 .73383 m .54895 .24062 L .58772 .24722 L p .707 .577 .707 r
F P
0 g
s
.20307 .72118 m .20616 .7358 L .18315 .75264 L p .707 .577 .707 r
F P
0 g
s
.29391 .70238 m .29701 .717 L .26602 .71707 L p .707 .577 .707 r
F P
0 g
s
.26602 .71707 m .26292 .70245 L .29391 .70238 L p .707 .577 .707 r
F P
0 g
s
.79193 .59994 m .79061 .6563 L .81464 .65235 L p .707 .577 .707 r
F P
0 g
s
.81464 .65235 m .81596 .59599 L .79193 .59994 L p .707 .577 .707 r
F P
0 g
s
.20616 .7358 m .20307 .72118 L .23162 .70892 L p .707 .577 .707 r
F P
0 g
s
.67211 .59559 m .67079 .65195 L .69825 .65604 L p .707 .577 .707 r
F P
0 g
s
.67079 .65195 m .67211 .59559 L .65104 .59 L p .707 .577 .707 r
F P
0 g
s
.26292 .70245 m .26602 .71707 L .23471 .72354 L p .707 .577 .707 r
F P
0 g
s
.23471 .72354 m .23162 .70892 L .26292 .70245 L p .707 .577 .707 r
F P
0 g
s
.23162 .70892 m .23471 .72354 L .20616 .7358 L p .707 .577 .707 r
F P
0 g
s
.73191 .74215 m .72914 .70765 L .698 .70666 L p .707 .577 .707 r
F P
0 g
s
.72914 .70765 m .73191 .74215 L .76364 .73873 L p .707 .577 .707 r
F P
0 g
s
.76364 .73873 m .76088 .70423 L .72914 .70765 L p .707 .577 .707 r
F P
0 g
s
.76088 .70423 m .76364 .73873 L .79287 .73124 L p .707 .577 .707 r
F P
0 g
s
.79287 .73124 m .7901 .69674 L .76088 .70423 L p .707 .577 .707 r
F P
0 g
s
.54895 .24062 m .56054 .73383 L .51654 .73155 L p .707 .577 .707 r
F P
0 g
s
.51654 .73155 m .50494 .23834 L .54895 .24062 L p .707 .577 .707 r
F P
0 g
s
.70077 .74116 m .698 .70666 L .67051 .70136 L p .707 .577 .707 r
F P
0 g
s
.698 .70666 m .70077 .74116 L .73191 .74215 L p .707 .577 .707 r
F P
0 g
s
.65104 .59 m .64972 .64636 L .67079 .65195 L p .707 .577 .707 r
F P
0 g
s
.81596 .59599 m .81464 .65235 L .83099 .64687 L p .707 .577 .707 r
F P
0 g
s
.83099 .64687 m .83231 .59051 L .81596 .59599 L p .707 .577 .707 r
F P
0 g
s
.7901 .69674 m .79287 .73124 L .81672 .72041 L p .707 .577 .707 r
F P
0 g
s
.81672 .72041 m .81395 .68592 L .7901 .69674 L p .707 .577 .707 r
F P
0 g
s
.50494 .23834 m .51654 .73155 L .47161 .73382 L p .707 .577 .707 r
F P
0 g
s
.67328 .73586 m .67051 .70136 L .64935 .69226 L p .707 .577 .707 r
F P
0 g
s
.67051 .70136 m .67328 .73586 L .70077 .74116 L p .707 .577 .707 r
F P
0 g
s
.81395 .68592 m .81672 .72041 L .83287 .7073 L p .707 .577 .707 r
F P
0 g
s
.83287 .7073 m .8301 .67281 L .81395 .68592 L p .707 .577 .707 r
F P
0 g
s
.83231 .59051 m .83099 .64687 L .83805 .6404 L p .707 .577 .707 r
F P
0 g
s
.83805 .6404 m .83937 .58403 L .83231 .59051 L p .707 .577 .707 r
F P
0 g
s
.64935 .69226 m .65212 .72676 L .67328 .73586 L p .707 .577 .707 r
F P
0 g
s
.77111 .79054 m .76802 .77591 L .73672 .78239 L p .707 .577 .707 r
F P
0 g
s
.76802 .77591 m .77111 .79054 L .79967 .77828 L p .707 .577 .707 r
F P
0 g
s
.79967 .77828 m .79657 .76366 L .76802 .77591 L p .707 .577 .707 r
F P
0 g
s
.73981 .79701 m .73672 .78239 L .70573 .78245 L p .707 .577 .707 r
F P
0 g
s
.73672 .78239 m .73981 .79701 L .77111 .79054 L p .707 .577 .707 r
F P
0 g
s
.79657 .76366 m .79967 .77828 L .82268 .76144 L p .707 .577 .707 r
F P
0 g
s
.82268 .76144 m .81958 .74682 L .79657 .76366 L p .707 .577 .707 r
F P
0 g
s
.70882 .79708 m .70573 .78245 L .67809 .7761 L p .707 .577 .707 r
F P
0 g
s
.70573 .78245 m .70882 .79708 L .73981 .79701 L p .707 .577 .707 r
F P
0 g
s
.63711 .63983 m .63843 .58347 L .63552 .57663 L p .707 .577 .707 r
F P
0 g
s
.8301 .67281 m .83287 .7073 L .83973 .6932 L p .707 .577 .707 r
F P
0 g
s
.83973 .6932 m .83696 .6587 L .8301 .67281 L p .707 .577 .707 r
F P
0 g
s
.67809 .7761 m .68118 .79072 L .70882 .79708 L p .707 .577 .707 r
F P
0 g
s
.63552 .57663 m .6342 .63299 L .63711 .63983 L p .707 .577 .707 r
F P
0 g
s
.81958 .74682 m .82268 .76144 L .83789 .74167 L p .707 .577 .707 r
F P
0 g
s
.83789 .74167 m .83479 .72705 L .81958 .74682 L p .707 .577 .707 r
F P
0 g
s
.68118 .79072 m .67809 .7761 L .6565 .76394 L p .707 .577 .707 r
F P
0 g
s
.83937 .58403 m .83805 .6404 L .83513 .63356 L p .707 .577 .707 r
F P
0 g
s
.83513 .63356 m .83645 .57719 L .83937 .58403 L p .707 .577 .707 r
F P
0 g
s
.6565 .76394 m .65959 .77857 L .68118 .79072 L p .707 .577 .707 r
F P
0 g
s
.6342 .63299 m .63552 .57663 L .64258 .57015 L p .707 .577 .707 r
F P
0 g
s
.83479 .72705 m .83789 .74167 L .84381 .72091 L p .707 .577 .707 r
F P
0 g
s
.84381 .72091 m .84072 .70628 L .83479 .72705 L p .707 .577 .707 r
F P
0 g
s
.83696 .6587 m .83973 .6932 L .83663 .67947 L p .707 .577 .707 r
F P
0 g
s
.83663 .67947 m .83386 .64498 L .83696 .6587 L p .707 .577 .707 r
F P
0 g
s
.65959 .77857 m .6565 .76394 L .64308 .74718 L p .707 .577 .707 r
F P
0 g
s
.63351 .66655 m .63627 .70104 L .63937 .71477 L p .707 .577 .707 r
F P
0 g
s
.64258 .57015 m .64126 .62651 L .6342 .63299 L p .707 .577 .707 r
F P
0 g
s
.64308 .74718 m .64617 .7618 L .65959 .77857 L p .707 .577 .707 r
F P
0 g
s
.83645 .57719 m .83513 .63356 L .82253 .62702 L p .707 .577 .707 r
F P
0 g
s
.82253 .62702 m .82385 .57066 L .83645 .57719 L p .707 .577 .707 r
F P
0 g
s
.63627 .70104 m .63351 .66655 L .64037 .65244 L p .707 .577 .707 r
F P
0 g
s
.84072 .70628 m .84381 .72091 L .83987 .70118 L p .706 .577 .707 r
F P
0 g
s
.83987 .70118 m .83678 .68656 L .84072 .70628 L p .706 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.38641 .62143 m .38773 .56506 L .35656 .56286 L p .707 .577 .707 r
F P
0 g
s
.38773 .56506 m .38641 .62143 L .41823 .62152 L p .707 .577 .707 r
F P
0 g
s
.41823 .62152 m .41955 .56515 L .38773 .56506 L p .707 .577 .707 r
F P
0 g
s
.64617 .7618 m .64308 .74718 L .63914 .72745 L p .706 .577 .707 r
F P
0 g
s
.4476 .61949 m .44892 .56313 L .41955 .56515 L p .707 .577 .707 r
F P
0 g
s
.64126 .62651 m .64258 .57015 L .65892 .56467 L p .707 .577 .707 r
F P
0 g
s
.83386 .64498 m .83663 .67947 L .82388 .66748 L p .707 .577 .707 r
F P
0 g
s
.82388 .66748 m .82111 .63298 L .83386 .64498 L p .707 .577 .707 r
F P
0 g
s
.35524 .61923 m .35656 .56286 L .3291 .55877 L p .707 .577 .707 r
F P
0 g
s
.35656 .56286 m .35524 .61923 L .38641 .62143 L p .707 .577 .707 r
F P
0 g
s
.64037 .65244 m .64313 .68694 L .63627 .70104 L p .707 .577 .707 r
F P
0 g
s
.63914 .72745 m .64223 .74207 L .64617 .7618 L p .706 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.44892 .56313 m .4476 .61949 L .47163 .61554 L p .707 .577 .707 r
F P
0 g
s
.47163 .61554 m .47295 .55918 L .44892 .56313 L p .707 .577 .707 r
F P
0 g
s
.65892 .56467 m .65761 .62103 L .64126 .62651 L p .707 .577 .707 r
F P
0 g
s
.3291 .55877 m .32778 .61513 L .35524 .61923 L p .707 .577 .707 r
F P
0 g
s
.82385 .57066 m .82253 .62702 L .80146 .62144 L p .707 .577 .707 r
F P
0 g
s
.80146 .62144 m .80278 .56507 L .82385 .57066 L p .707 .577 .707 r
F P
0 g
s
.64313 .68694 m .64037 .65244 L .65651 .63933 L p .707 .577 .707 r
F P
0 g
s
.32778 .61513 m .3291 .55877 L .30803 .55318 L p .707 .577 .707 r
F P
0 g
s
.83678 .68656 m .83987 .70118 L .82645 .68441 L p .707 .577 .707 r
F P
0 g
s
.82645 .68441 m .82336 .66979 L .83678 .68656 L p .707 .577 .707 r
F P
0 g
s
.64223 .74207 m .63914 .72745 L .64506 .70669 L p .707 .577 .707 r
F P
0 g
s
.3889 .70533 m .38613 .67084 L .35499 .66984 L p .707 .577 .707 r
F P
0 g
s
.42063 .70192 m .41787 .66742 L .38613 .67084 L p .707 .577 .707 r
F P
0 g
s
.65761 .62103 m .65892 .56467 L .68296 .56072 L p .707 .577 .707 r
F P
0 g
s
.80177 .65764 m .82336 .66979 L p .80818 .67182 L .707 .577 .707 r
F P
0 g
s
.80486 .67226 m .80321 .66443 L p .80818 .67182 L .707 .577 .707 r
F P
0 g
s
.80321 .66443 m .80177 .65764 L p .80818 .67182 L .707 .577 .707 r
F P
0 g
s
.80177 .65764 m .80486 .67226 L .77722 .6659 L p .707 .577 .707 r
F P
0 g
s
.77413 .65128 m .80177 .65764 L p .78127 .66454 L .707 .577 .707 r
F P
0 g
s
.77722 .6659 m .77567 .65856 L p .78127 .66454 L .707 .577 .707 r
F P
0 g
s
.77567 .65856 m .77413 .65128 L p .78127 .66454 L .707 .577 .707 r
F P
0 g
s
.77413 .65128 m .77722 .6659 L .74623 .66597 L p .707 .577 .707 r
F P
0 g
s
.74314 .65135 m .77413 .65128 L p .75071 .66361 L .707 .577 .707 r
F P
0 g
s
.74623 .66597 m .74458 .65814 L p .75071 .66361 L .707 .577 .707 r
F P
0 g
s
.74458 .65814 m .74314 .65135 L p .75071 .66361 L .707 .577 .707 r
F P
0 g
s
.74314 .65135 m .74623 .66597 L .71493 .67245 L p .707 .577 .707 r
F P
0 g
s
.71493 .67245 m .71183 .65782 L .74314 .65135 L p .707 .577 .707 r
F P
0 g
s
.74132 .6176 m .74409 .65209 L .73847 .6527 L p .707 .577 .707 r
F P
0 g
s
.73847 .6527 m .71236 .65551 L p .72422 .63999 L .707 .577 .707 r
F P
0 g
s
.72422 .63999 m .74132 .6176 L .73847 .6527 L .707 .577 .707 r
F
.77246 .61859 m .77523 .65308 L .77039 .65293 L p F P
0 g
s
.77039 .65293 m .74409 .65209 L p .7562 .63779 L .707 .577 .707 r
F P
0 g
s
.7562 .63779 m .77246 .61859 L .77039 .65293 L .707 .577 .707 r
F
.79995 .62389 m .80272 .65839 L .79859 .65759 L p F P
0 g
s
.79859 .65759 m .77523 .65308 L p .78654 .63972 L .707 .577 .707 r
F P
0 g
s
.78654 .63972 m .79995 .62389 L .79859 .65759 L .707 .577 .707 r
F
.82111 .63298 m .82388 .66748 L .80272 .65839 L p F P
0 g
s
.80272 .65839 m .79995 .62389 L .82111 .63298 L p .707 .577 .707 r
F P
0 g
s
.35776 .70434 m .35499 .66984 L .3275 .66454 L p .707 .577 .707 r
F P
0 g
s
.35499 .66984 m .35776 .70434 L .3889 .70533 L p .707 .577 .707 r
F P
0 g
s
.30803 .55318 m .30671 .60955 L .32778 .61513 L p .707 .577 .707 r
F P
0 g
s
.47295 .55918 m .47163 .61554 L .48798 .61006 L p .707 .577 .707 r
F P
0 g
s
.48798 .61006 m .4893 .5537 L .47295 .55918 L p .707 .577 .707 r
F P
0 g
s
.64506 .70669 m .64816 .72131 L .64223 .74207 L p .707 .577 .707 r
F P
0 g
s
.65651 .63933 m .65928 .67383 L .64313 .68694 L p .707 .577 .707 r
F P
0 g
s
.68296 .56072 m .68164 .61708 L .65761 .62103 L p .707 .577 .707 r
F P
0 g
s
.80278 .56507 m .80146 .62144 L .774 .61734 L p .707 .577 .707 r
F P
0 g
s
.774 .61734 m .77532 .56098 L .80278 .56507 L p .707 .577 .707 r
F P
0 g
s
.65928 .67383 m .65651 .63933 L .68037 .6285 L p .707 .577 .707 r
F P
0 g
s
.30671 .60955 m .30803 .55318 L .29542 .54665 L p .707 .577 .707 r
F P
0 g
s
.82336 .66979 m .82645 .68441 L .80486 .67226 L p .707 .577 .707 r
F P
0 g
s
.33027 .69904 m .3275 .66454 L .30634 .65545 L p .707 .577 .707 r
F P
0 g
s
.3275 .66454 m .33027 .69904 L .35776 .70434 L p .707 .577 .707 r
F P
0 g
s
.64816 .72131 m .64506 .70669 L .66027 .68692 L p .707 .577 .707 r
F P
0 g
s
.68164 .61708 m .68296 .56072 L .71232 .55869 L p .707 .577 .707 r
F P
0 g
s
.77523 .65308 m .77246 .61859 L .79995 .62389 L p .707 .577 .707 r
F P
0 g
s
.47094 .6491 m .47371 .6836 L .48986 .67049 L p .707 .577 .707 r
F P
0 g
s
.48986 .67049 m .48709 .63599 L .47094 .6491 L p .707 .577 .707 r
F P
0 g
s
.29542 .54665 m .2941 .60301 L .30671 .60955 L p .707 .577 .707 r
F P
0 g
s
.77532 .56098 m .774 .61734 L .74283 .61514 L p .707 .577 .707 r
F P
0 g
s
.74283 .61514 m .74415 .55878 L .77532 .56098 L p .707 .577 .707 r
F P
0 g
s
.66027 .68692 m .66337 .70154 L .64816 .72131 L p .707 .577 .707 r
F P
0 g
s
.68037 .6285 m .68313 .663 L .65928 .67383 L p .707 .577 .707 r
F P
0 g
s
.4893 .5537 m .48798 .61006 L .49504 .60358 L p .707 .577 .707 r
F P
0 g
s
.49504 .60358 m .49636 .54722 L .4893 .5537 L p .707 .577 .707 r
F P
0 g
s
.68313 .663 m .68037 .6285 L .70959 .62101 L p .707 .577 .707 r
F P
0 g
s
.71232 .55869 m .711 .61505 L .68164 .61708 L p .707 .577 .707 r
F P
0 g
s
.711 .61505 m .71232 .55869 L .74415 .55878 L p .707 .577 .707 r
F P
0 g
s
.30634 .65545 m .30911 .68995 L .33027 .69904 L p .707 .577 .707 r
F P
0 g
s
.4281 .75372 m .42501 .7391 L .39371 .74558 L p .707 .577 .707 r
F P
0 g
s
.42501 .7391 m .4281 .75372 L .45666 .74146 L p .707 .577 .707 r
F P
0 g
s
.45666 .74146 m .45356 .72684 L .42501 .7391 L p .707 .577 .707 r
F P
0 g
s
.3968 .7602 m .39371 .74558 L .36272 .74564 L p .707 .577 .707 r
F P
0 g
s
.39371 .74558 m .3968 .7602 L .4281 .75372 L p .707 .577 .707 r
F P
0 g
s
.74415 .55878 m .74283 .61514 L .711 .61505 L p .707 .577 .707 r
F P
0 g
s
.66337 .70154 m .66027 .68692 L .68328 .67008 L p .707 .577 .707 r
F P
0 g
s
.74409 .65209 m .74132 .6176 L .77246 .61859 L p .707 .577 .707 r
F P
0 g
s
.30911 .68995 m .30634 .65545 L .29359 .64345 L p .707 .577 .707 r
F P
0 g
s
.45356 .72684 m .45666 .74146 L .47967 .72463 L p .707 .577 .707 r
F P
0 g
s
.47967 .72463 m .47657 .71 L .45356 .72684 L p .707 .577 .707 r
F P
0 g
s
.36581 .76026 m .36272 .74564 L .33507 .73928 L p .707 .577 .707 r
F P
0 g
s
.36272 .74564 m .36581 .76026 L .3968 .7602 L p .707 .577 .707 r
F P
0 g
s
.71236 .65551 m .70959 .62101 L .74132 .6176 L p .707 .577 .707 r
F P
0 g
s
.70959 .62101 m .71236 .65551 L .68313 .663 L p .707 .577 .707 r
F P
0 g
s
.2941 .60301 m .29542 .54665 L .29251 .53981 L p .707 .577 .707 r
F P
0 g
s
.48709 .63599 m .48986 .67049 L .49672 .65638 L p .707 .577 .707 r
F P
0 g
s
.49672 .65638 m .49395 .62188 L .48709 .63599 L p .707 .577 .707 r
F P
0 g
s
.68328 .67008 m .68638 .6847 L .66337 .70154 L p .707 .577 .707 r
F P
0 g
s
.68638 .6847 m .68328 .67008 L .71183 .65782 L p .707 .577 .707 r
F P
0 g
s
.33507 .73928 m .33817 .75391 L .36581 .76026 L p .707 .577 .707 r
F P
0 g
s
.29359 .64345 m .29636 .67795 L .30911 .68995 L p .707 .577 .707 r
F P
0 g
s
.29251 .53981 m .29119 .59617 L .2941 .60301 L p .707 .577 .707 r
F P
0 g
s
.47657 .71 m .47967 .72463 L .49488 .70486 L p .707 .577 .707 r
F P
0 g
s
.49488 .70486 m .49178 .69024 L .47657 .71 L p .707 .577 .707 r
F P
0 g
s
.33817 .75391 m .33507 .73928 L .31349 .72713 L p .707 .577 .707 r
F P
0 g
s
.71183 .65782 m .71493 .67245 L .68638 .6847 L p .707 .577 .707 r
F P
0 g
s
.49636 .54722 m .49504 .60358 L .49212 .59674 L p .707 .577 .707 r
F P
0 g
s
.49212 .59674 m .49344 .54038 L .49636 .54722 L p .707 .577 .707 r
F P
0 g
s
.29636 .67795 m .29359 .64345 L .2905 .62973 L p .707 .577 .707 r
F P
0 g
s
.31349 .72713 m .31658 .74175 L .33817 .75391 L p .707 .577 .707 r
F P
0 g
s
.29119 .59617 m .29251 .53981 L .29957 .53333 L p .707 .577 .707 r
F P
0 g
s
.49178 .69024 m .49488 .70486 L .5008 .68409 L p .707 .577 .707 r
F P
0 g
s
.5008 .68409 m .49771 .66947 L .49178 .69024 L p .707 .577 .707 r
F P
0 g
s
.49395 .62188 m .49672 .65638 L .49362 .64266 L p .707 .577 .707 r
F P
0 g
s
.49362 .64266 m .49085 .60816 L .49395 .62188 L p .707 .577 .707 r
F P
0 g
s
.31658 .74175 m .31349 .72713 L .30007 .71037 L p .707 .577 .707 r
F P
0 g
s
.2905 .62973 m .29326 .66423 L .29636 .67795 L p .707 .577 .707 r
F P
0 g
s
.29957 .53333 m .29825 .58969 L .29119 .59617 L p .707 .577 .707 r
F P
0 g
s
.30007 .71037 m .30316 .72499 L .31658 .74175 L p .707 .577 .707 r
F P
0 g
s
.49344 .54038 m .49212 .59674 L .47952 .59021 L p .707 .577 .707 r
F P
0 g
s
.47952 .59021 m .48084 .53385 L .49344 .54038 L p .707 .577 .707 r
F P
0 g
s
.29326 .66423 m .2905 .62973 L .29736 .61563 L p .707 .577 .707 r
F P
0 g
s
.49771 .66947 m .5008 .68409 L .49686 .66436 L p .706 .577 .707 r
F P
0 g
s
.49686 .66436 m .49377 .64974 L .49771 .66947 L p .706 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30316 .72499 m .30007 .71037 L .29612 .69064 L p .706 .577 .707 r
F P
0 g
s
.29825 .58969 m .29957 .53333 L .31591 .52785 L p .707 .577 .707 r
F P
0 g
s
.49085 .60816 m .49362 .64266 L .48087 .63066 L p .707 .577 .707 r
F P
0 g
s
.48087 .63066 m .4781 .59617 L .49085 .60816 L p .707 .577 .707 r
F P
0 g
s
.29736 .61563 m .30012 .65012 L .29326 .66423 L p .707 .577 .707 r
F P
0 g
s
.29612 .69064 m .29922 .70526 L .30316 .72499 L p .706 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31591 .52785 m .31459 .58421 L .29825 .58969 L p .707 .577 .707 r
F P
0 g
s
.48084 .53385 m .47952 .59021 L .45845 .58462 L p .707 .577 .707 r
F P
0 g
s
.45845 .58462 m .45977 .52826 L .48084 .53385 L p .707 .577 .707 r
F P
0 g
s
.30012 .65012 m .29736 .61563 L .3135 .60252 L p .707 .577 .707 r
F P
0 g
s
.49377 .64974 m .49686 .66436 L .48344 .6476 L p .707 .577 .707 r
F P
0 g
s
.48344 .6476 m .48035 .63298 L .49377 .64974 L p .707 .577 .707 r
F P
0 g
s
.29922 .70526 m .29612 .69064 L .30205 .66987 L p .707 .577 .707 r
F P
0 g
s
.31459 .58421 m .31591 .52785 L .33995 .5239 L p .707 .577 .707 r
F P
0 g
s
.45876 .62082 m .48035 .63298 L p .46517 .635 L .707 .577 .707 r
F P
0 g
s
.46185 .63544 m .4602 .62762 L p .46517 .635 L .707 .577 .707 r
F P
0 g
s
.4602 .62762 m .45876 .62082 L p .46517 .635 L .707 .577 .707 r
F P
0 g
s
.45876 .62082 m .46185 .63544 L .43421 .62909 L p .707 .577 .707 r
F P
0 g
s
.43112 .61447 m .45876 .62082 L p .43826 .62772 L .707 .577 .707 r
F P
0 g
s
.43421 .62909 m .43266 .62175 L p .43826 .62772 L .707 .577 .707 r
F P
0 g
s
.43266 .62175 m .43112 .61447 L p .43826 .62772 L .707 .577 .707 r
F P
0 g
s
.43112 .61447 m .43421 .62909 L .40322 .62915 L p .707 .577 .707 r
F P
0 g
s
.40013 .61453 m .43112 .61447 L p .4077 .62679 L .707 .577 .707 r
F P
0 g
s
.40322 .62915 m .40157 .62133 L p .4077 .62679 L .707 .577 .707 r
F P
0 g
s
.40157 .62133 m .40013 .61453 L p .4077 .62679 L .707 .577 .707 r
F P
0 g
s
.40013 .61453 m .40322 .62915 L .37192 .63563 L p .707 .577 .707 r
F P
0 g
s
.37192 .63563 m .36882 .62101 L .40013 .61453 L p .707 .577 .707 r
F P
0 g
s
.39831 .58078 m .40108 .61528 L .39546 .61588 L p .707 .577 .707 r
F P
0 g
s
.39546 .61588 m .36935 .61869 L p .3812 .60317 L .707 .577 .707 r
F P
0 g
s
.3812 .60317 m .39831 .58078 L .39546 .61588 L .707 .577 .707 r
F
.42945 .58177 m .43222 .61627 L .42738 .61611 L p F P
0 g
s
.42738 .61611 m .40108 .61528 L p .41319 .60098 L .707 .577 .707 r
F P
0 g
s
.41319 .60098 m .42945 .58177 L .42738 .61611 L .707 .577 .707 r
F
.45694 .58707 m .45971 .62157 L .45558 .62077 L p F P
0 g
s
.45558 .62077 m .43222 .61627 L p .44353 .60291 L .707 .577 .707 r
F P
0 g
s
.44353 .60291 m .45694 .58707 L .45558 .62077 L .707 .577 .707 r
F
.4781 .59617 m .48087 .63066 L .45971 .62157 L p F P
0 g
s
.45971 .62157 m .45694 .58707 L .4781 .59617 L p .707 .577 .707 r
F P
0 g
s
.30205 .66987 m .30514 .68449 L .29922 .70526 L p .707 .577 .707 r
F P
0 g
s
.3135 .60252 m .31627 .63701 L .30012 .65012 L p .707 .577 .707 r
F P
0 g
s
.33995 .5239 m .33863 .58027 L .31459 .58421 L p .707 .577 .707 r
F P
0 g
s
.45977 .52826 m .45845 .58462 L .43099 .58053 L p .707 .577 .707 r
F P
0 g
s
.43099 .58053 m .43231 .52416 L .45977 .52826 L p .707 .577 .707 r
F P
0 g
s
.31627 .63701 m .3135 .60252 L .33736 .59169 L p .707 .577 .707 r
F P
0 g
s
.48035 .63298 m .48344 .6476 L .46185 .63544 L p .707 .577 .707 r
F P
0 g
s
.30514 .68449 m .30205 .66987 L .31726 .6501 L p .707 .577 .707 r
F P
0 g
s
.33863 .58027 m .33995 .5239 L .36931 .52188 L p .707 .577 .707 r
F P
0 g
s
.43222 .61627 m .42945 .58177 L .45694 .58707 L p .707 .577 .707 r
F P
0 g
s
.43231 .52416 m .43099 .58053 L .39982 .57833 L p .707 .577 .707 r
F P
0 g
s
.39982 .57833 m .40114 .52197 L .43231 .52416 L p .707 .577 .707 r
F P
0 g
s
.31726 .6501 m .32036 .66472 L .30514 .68449 L p .707 .577 .707 r
F P
0 g
s
.33736 .59169 m .34012 .62618 L .31627 .63701 L p .707 .577 .707 r
F P
0 g
s
.34012 .62618 m .33736 .59169 L .36658 .5842 L p .707 .577 .707 r
F P
0 g
s
.36931 .52188 m .36799 .57824 L .33863 .58027 L p .707 .577 .707 r
F P
0 g
s
.36799 .57824 m .36931 .52188 L .40114 .52197 L p .707 .577 .707 r
F P
0 g
s
.40114 .52197 m .39982 .57833 L .36799 .57824 L p .707 .577 .707 r
F P
0 g
s
.32036 .66472 m .31726 .6501 L .34027 .63326 L p .707 .577 .707 r
F P
0 g
s
.40108 .61528 m .39831 .58078 L .42945 .58177 L p .707 .577 .707 r
F P
0 g
s
.36935 .61869 m .36658 .5842 L .39831 .58078 L p .707 .577 .707 r
F P
0 g
s
.36658 .5842 m .36935 .61869 L .34012 .62618 L p .707 .577 .707 r
F P
0 g
s
.34027 .63326 m .34336 .64789 L .32036 .66472 L p .707 .577 .707 r
F P
0 g
s
.34336 .64789 m .34027 .63326 L .36882 .62101 L p .707 .577 .707 r
F P
0 g
s
.36882 .62101 m .37192 .63563 L .34336 .64789 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002>Ool80027Ool0081oo`h0
0003FUH005YF00EJEPT007ioo`00NWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01P00N7oo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH4001d
Ool0079oo`<000eJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001b
Ool006moo`<0011JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3
001_Ool006aoo`<001=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00AJEP8006eoo`00JWoo0P0000=JEP00FUH04eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF0`00Jgoo001XOol20003FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02001YOol006Ioo`8000EJ
EP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P001UYF00<005YFFUH04UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IWoo
001UOol20006FUH00`00FUIJEP0BFUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1VOol006Aoo`03001JEP0000IJEP03001JEUYF
019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Moo`00I7oo00<005YF00001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP00
1UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH04UYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000FUIJEP00
1UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH04UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000
FUIJEP001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH0
4UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<005YFFUH04UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001S
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000
FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH015YF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFOol0IWoo001SOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF
00<005YFFUH00eYF00<007ooOol0IGoo001SOol01@00FUIJEUYF00001EYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<007ooOol0IGoo001SOol01@00FUIJEUYF00001EYF0P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001TOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF0P0025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF0P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF
0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<0
05YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOolA0002
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005eoo`P000=JEP03001JEUYF00MJEP04001JEUYFFUH80006FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Qoo`D000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH7000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool005Eoo`<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00@000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=o
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000?OolA0015Ool005=oo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20007Ool80003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000mOol005=oo`8000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH20002Ool50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUIJEUYF1P00=goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00
FUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEP00008003Aoo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2000bOol0059oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
031oo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001BOol00`00FUH0
0004FUH01000FUIJEUYF2@001eYF4@0015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEP00;goo001BOol00`00FUH00002FUH70007FUH80004FUH00`00FUIJEP06FUH01000FUIJ
EUYF1`000eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool0059oo`03001JEP0000<0
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0
0003FUH000000080009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001BOol20003FUH00`00FUIJ
EP03FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP030002FUH40004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008002ioo`00DWoo0P000eYF00<005YFFUH00eYF
0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF0P000UYF
0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02000^Ool0059oo`8000=JEP04001JEUYFFUH20002FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000015YF
0000000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo001COol01P00FUIJEUYF001JEP8000AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP06001J
EP00001JEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000hOolN000015YF000000001EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
FUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00=7oo100000=JEP00FUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00<Goo0`001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF100015YF00<0
05YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Woo0`0000=JEP00FUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YF
FUH015YF2`0015YF200015YF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH01000FUIJEUYF2@001eYF4@0015YF
00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF1P00
1UYF0P001eYF00@005YFFUIJEPD000EJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF100000=JEP00FUH01EYF00<005YF00001@00
15YF00<005YFFUH01UYF00<005YF00001`0015YF00@005YFFUIJEP8002ioo`00;7oo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF00<0
05YFFUH015YF00<005YF00001P002EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF00<005YF
FUH00P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUH005YF001J
EP020004FUH00`00FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
00001UYF00000000FUH000=JEP8002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH00eYF0`000UYF
0P000UYF00<005YFFUH01EYF3@001EYF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH00UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00<000EJEP03001J
EP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00004FUH000000003
FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH20002FUH30005FUH00`00FUIJEP070006
FUH01000FUIJEUYF10000UYF00<005YFFUH00`000eYF00<005YFFUH00UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000UYF00<005YFFUH00eYF0P0000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P000UYF0P0000=J
EP000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH01000FUIJEP000eYF00@005YF000000=JEP8000MJEP<0009JEPD000IJEP03
001JEUYF00EJEP<000AJEP80009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF0080009JEP04001JEUYFFUH20003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH3000^Ool002aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP05001JEUYFFUIoo`03
FUH01000FUIJEP000eYF0`000UYF0`001UYF0`0015YF1@001UYF00<005YFFUH025YF0P000UYF1@00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH2000015YF00000000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000UYF00H005YFFUH005YF0002FUH0
0`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP09FUH200001EYF001JEP00
FUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00H005YF000005YF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP04001JEUYFOol4FUH00`00FUIJEP030003FUH20004FUH00`00FUH00003
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH5000015YF000000000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YFFUIJEP0002moo`00;7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF000015YF00<005YFFUH015YF0P000UYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP00009JEP8000=JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF
0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH2000015YF001JEUYF0P001EYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH01eYF0`0015YF00@005YF000000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00007FUH00`00FUIJEP05FUH0
1000FUIJEUYF40001UYF00<005YFFUH00eYF00@005YFFUH002moo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF0P0000=JEP00
FUH00eYF00<005YF00000UYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH01EYF0P000UYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF
00IJEP03001JEP00008000=JEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH0
0003FUH01000FUH000000UYF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00UYF00<005YFFUH00eYF0`0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00AJEP03001JEUYF00P000IJEP03
001JEUYF00IJEP03001JEUYF009JEPD000AJEP04001JEUYF000_Ool002]oo`03001JEP0000AJEP03
001JEUYF00=JEQX00003FUH00000009JEP04001JEUYFFUH40002FUH00`00FUIJEP030002FUH00`00
FUIJEP03FUH00`00FUIJEP0=FUH00`00FUIJEP03FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP@00006
FUH00000001JEP002EYF00<007ooFUH01EYF00@005YFOomoo`=JEPH00005FUH005YFFUH0000_Ool0
02]oo`03001JEP0000AJEP03001JEP0000<000IJEPP000AJEP03001JEUYF00EJEP<00003FUH005YF
00=JEP04001JEP00FUH4000015YF000000000UYF00<005YFFUH00eYF00<005YFFUH020001EYF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH01000FUIJEUYF0P000UYF10000eYF00<005YFFUH01EYF
30001EYF00@005YFFUIJEP@0009JEP03001oogoo02eoo`00:goo00<005YF00000UYF10000UYF00<0
05YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00@005YFFUH000EJEPl0
00AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH01000FUH000000eYF0P00
1eYF00<005YFFUH01`002Goo10000UYF00<005YFFUH00UYF0`0000=JEP00Ool0;Woo000[Ool00`00
FUH000030005FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH01@00
FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00D005YFFUIJEP00009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEP00FUH00004FUH30002FUH30007FUH40002Ool5000=Ool30005FUH200000eYF001o
o`0^Ool002]oo`8000=JEP03001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP<0
009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEP000002FUH30003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YF00000UYF00@005YFFUH000EJEP8000Ioo`D0
011oo`8000=JEP@002moo`00:goo0P000eYF00@005YFFUIJEP80009JEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP800003FUH0000000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEP0000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00FUH005YF0P000UYF00<005YF0000
15YF00<005YF00000P002Goo0`004goo0P0000=JEP00FUH00`00;Woo000[Ool20003FUH01000FUH0
000015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP0000001EYF00<0
05YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF00<0
05YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP<000=J
EP8000EJEP800003FUH00000021oo`<00004FUH00000000^Ool002aoo`04001JEUYFFUH30005FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF00000005FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH60004FUH00`00FUIJEP05FUH01000FUIJEUYF100015YF00@005YFFUH000=J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00FUH30002FUH00`00FUIJ
EP03FUH20003FUH2000NOol20003FUH01000FUH00000;Woo000]Ool400000eYF001JEP04FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000015YF0000000015YF00<005YFFUH01EYF
00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00@005YF0000009JEP8000AJEP03001JEP0000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000002FUH01000FUH00000
15YF00<005YF00000eYF0P0077oo0P0000=JEP00FUH00UYF1000;Woo000^Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF0`000eYF0`0000=JEP00FUH01UYF00<005YF
FUH01UYF10001EYF00<005YFFUH015YF0`0015YF0P000eYF0P0000=JEP00FUH00eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF0000009JEP800003FUH005YF009JEP04001J
EUYF0003FUH2000JOol20003FUH00`00FUIJEP02FUH3000^Ool002eoo`03001JEUYF009JEP03001J
EUYF00AJEP03001JEUYF00EJEPH000QJEPP000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00@000QJEP08001JEUYF001JEP00FUH000AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP04001JEP000002FUH20002FUH30003FUH01000FUIJEUYF0P005goo0`001EYF
00<005YFFUH00UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30005FUH0
0`00FUH0000=00000eYF000000030003FUH40002FUH00`00FUIJEP06FUH01000FUIJEUYF200035YF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP04001JEP000002FUH01000FUIJEUYF1`000eYF0P004goo100000=JEP00FUH01EYF00<005YFFUH0
0UYF0`00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUH0000<0002FUH00`00FUIJEP06FUH0
0`00FUH000040002Ool20003FUH00`00FUH0000>0002FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH0
0`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUH00000FUH000=JEP04001JEUYF0003FUH90009Ool70005FUH00`00FUIJEP05FUH01`00FUIJ
EUYF001oo`0002ioo`00:goo00<005YF000015YF00<005YFFUH00eYF0`001Woo0`001UYF00<005YF
FUH01UYF00<005YF00000eYF0`000Woo0P0000=JEP00FUH00UYF0P000eYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF0P000eYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YF000005YF0003FUH01000FUIJEP001eYF00<005YFFUH00UYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00Ool0000^Ool002]oo`03001JEP00
00AJEP04001JEUYFFUH20007Ool30009FUH00`00FUIJEP06FUH20005FUH30002Ool20003FUH20003
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP08FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030002FUH01@00FUIJEUYF0000
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUH0
009oo`03001oogoo02aoo`00:goo00@005YFFUH000=JEP04001JEP000007Ool20002FUH00`00FUIJ
EP05FUH>0004FUH00`00FUIJEP020002Ool00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH01000FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00P0000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YF00000P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`000Woo00<005YF0000
;Goo000[Ool01000FUIJEP000eYF0P001goo0P001EYF00<005YFFUH0100037oo1@000UYF00@005YF
FUIJEPH00005OomJEUYFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP8000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00IJEP03001JEUYF00=JEP8000Ao
o`03001JEP0002eoo`00:goo00@005YFFUH0009JEP03001oogoo00Eoo`8000MJEP<000=oo`<000]o
o`04001JEP00Ool30004FUH300000eYF00000003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20005FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000
FUIJEP000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF1P000eYF00<005YFFUH01UYF00@0
05YFFUIJEP8000Ioo`03001JEP0002eoo`00:goo00<005YFFUH00`001Woo0`001UYF0P001Goo1@00
2Woo00@005YFFUH000=oo`80009JEP04001JEP00FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP000UYF0P001EYF00<005YFFUH01EYF00<005YFFUH01EYF1P00
15YF00<005YFFUH01EYF00@005YF000000Qoo`03001JEP0002eoo`00;7oo00<005YF00001goo00@0
05YFFUH000AJEP8000Moo`D000]oo`03001JEP000080009oo`80009JEP800003FUH0000000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP04001JEUYFFUH30005FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEP00FUH005YF00<000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00AJEP<000Uoo`800003FUH007oo02aoo`00;7oo0P0000=JEP00
Ool00goo0P0015YF00@005YF000000Uoo`D000]oo`03001JEP00009JEP<00008FUH00000001JEP00
FUH000=JEP03001JEUYF00=JEP03001JEUYF00MJEP04001JEP000002FUH01000FUIJEUYF7P0025YF
00<005YFFUH01EYF00P005YFFUH005YF001JEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P002goo00@005YF000002ioo`00;7oo0P000UYF0P0000=o
o`00FUH01EYF0P0037oo0`003Goo0P000eYF0P000eYF00<005YFFUH00P000eYF00<005YFFUH00eYF
00<005YFFUH01eYF0P001EYF0`0025YF00<005YFFUH02UYF00<005YFFUH01UYF1P000UYF00<005YF
FUH01EYF00<005YFFUH00`0000=JEP0000000UYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YF00000P0037oo00D005YFFUIJEP0002ioo`00;7oo00H005YFFUIJEP00FUH20005FUH00`00
Oomoo`0JOol40005FUH20002FUH01000FUH007oo0eYF00<005YFFUH00eYF00<005YFFUH00eYF1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH010001UYF00D005YF
FUIJEP00009JEPH000AJEPT000AJEP03001JEUYF009JEPH000moo`05001JEUYFFUH0000^Ool002ao
o`80009JEP800003FUH005YF00=JEP03001oogoo01Moo`@0009JEP04001JEP000003FUH00`00FUH0
000400001GooFUIJEUYF00001EYF00<005YF00000`000UYF00<005YFFUH015YF0P0035YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH015YF0P0015YF00D005YFFUIJEP00009JEP8000Aoo`<0
0005FUH005YFFUH00005Ool9000DOol01@00FUIJEUYF0000;goo000/Ool20002FUH01P00FUIJEUYF
001JEPH000moo`L000IJEP04001JEUYFFUH200000eYF001JEP04FUH=0006FUH00`00FUIJEP02FUH2
00000eYF001JEP0;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF001J
EP02FUH01@00FUIJEP00FUH00`0017oo0P000UYF00<007ooOol07goo00D005YFFUIJEP00031oo`00
;7oo0P000UYF00@005YFFUIJEP<000EJEPl000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<000IJ
EP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000000eYF0P0000IJEP00FUIJEP00FUH20004
Ool00`00FUH0000POol20002FUH00`00Oomoo`0_Ool002eoo`03001JEP0000AJEP03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP05001JEUYFFUH00002FUH40002FUH01000FUIJEUYF0P000Woo00<005YF0000
7goo00<005YF00000UYF00<007ooOol0;goo000]Ool20004FUH01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF0000100000=JEP00FUH0
1eYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00UYF0P0000=JEP0000000P000UYF00<005YFFUH00UYF1@007Goo0P000eYF
0P00<Woo000^Ool01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo3@000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00
Ool00`001EYF0P0000=JEP0000006goo00<005YFFUH00eYF00<007ooOol0<Goo000^Ool01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH00eYF0P001Goo0P000eYF00@005YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<00003FUH007oo009oo`80
00=JEP800003FUH0000001Uoo`8000EJEP03001oogoo039oo`00;Goo00@005YF000000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH20007Ool0
1@00FUIJEUYF00000eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP0000000P000Woo0`00
00=JEP00FUH00`005goo0P0000=JEP00FUH00eYF00<007ooOol0<goo000]Ool00`00FUH000020004
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH01000FUH000002Goo00@0
05YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP000080009JEP800003FUH005YF
00800004FUH005YF000DOol30003FUH00`00FUIJEP02000fOol002eoo`03001JEP00009oo`<00003
FUH005YF00IJEP03001JEUYF00IJEPD000AJEP03001JEUYF00AJEP<000Yoo`05001JEUYFFUH00004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH000030003FUH30002FUH01000FUH0000047oo
10001eYF0P00>7oo000]Ool00`00FUH00005Ool30006FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP04000=Ool00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP030004
FUH00`00FUH00004000=Ool40002FUH00`00FUIJEP05FUH2000iOol002eoo`8000Uoo`@0009JEP03
001JEUYF00IJEP`0011oo`800004FUH000000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000
FUH000000UYF0P000UYF00<005YFFUH00eYF3P001UYF00<005YFFUH00eYF0P00>goo000]Ool2000=
Ool@000FOol01000FUH005YF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH0
0eYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P00?Goo000^
Ool00`00Oomoo`0aOol01000FUIJEP000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF0P0000=JEP00FUH01EYF0`001EYF00<005YFFUH01UYF00<005YFFUH01EYF1000@7oo000^Ool0
0`00Oomoo`0`Ool01@00FUIJEUYF00000Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00@005YFFUH000MJEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF00@004Aoo`00
;Woo00<007ooOol0;goo00D005YFFUIJEP0000Aoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009J
EP8000AJEP03001JEUYF00AJEP<000=oo`h004Qoo`00;Woo0P00;Woo0`000eYF00<007ooOol017oo
0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00P001UYF00<005YFFUH00eYF0P001Goo0P00E7oo000^Ool00`00FUH0000/
Ool01000FUIJEP000UYF00<007ooOol01goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF0`0025YF00@005YFFUIJEP8000Ioo`03001J
EP0005Aoo`00;goo0P00:goo00<005YFFUH00UYF0P0037oo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`000UYF00<005YFFUH01EYF
00@005YF000000Qoo`03001JEP0005Aoo`00;goo00<005YF0000:7oo0P001EYF0P003Woo0`0000=J
EP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01@001EYF
00<005YFFUH015YF0`002Woo00<005YF0000E7oo000_Ool01000FUIJEP009Woo00<005YFFUH01EYF
00<007ooOol047oo100025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1@0000=J
EP0000000`0015YF00<005YFFUH00UYF0P003Goo00<005YF0000E7oo000`Ool00`00FUH00002000R
Ool30005FUH2000GOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060006FUH5
0004FUH00`00FUH00002000>Ool3001EOol0035oo`80009JEP03001oogoo01eoo`80009JEP04001J
EUYFFUH2000OOol90006FUH00`00FUIJEP04FUHA0004FUH;000@Ool01000FUH00000EGoo000bOol2
0002FUH2000KOol20005FUH3000ZOol=000AOol9000EOol01@00FUIJEUYF0000EGoo000cOol00`00
FUIJEP02FUH2000COol60007FUH00`00Oomoo`0bOol00`00Oomoo`0aOol01@00FUIJEUYF0000EGoo
000dOol20002FUH00`00FUH000030007Ool80004FUH00`00FUIJEP04FUH2000eOol00`00Oomoo`0`
Ool01@00FUIJEUYF0000EWoo000fOol00`00FUH00005FUH70003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2000gOol00`00Oomoo`0_Ool01@00FUIJEUYF0000Egoo000gOol30006FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUH00000>Goo0P00;goo0P000UYF00<007ooOol0EWoo000iOol20005
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000kOol3000]Ool00`00FUH00002FUH00`00Oomoo`1F
Ool003]oo`@00003FUH005YF00MJEP03001JEUYF00@0041oo`8002]oo`8000=JEP8005Uoo`00?goo
3@00A7oo00<005YF0000:Goo00<005YFFUH00eYF00<007ooOol0F7oo002AOol00`00FUH0000VOol2
0005FUH00`00Oomoo`1IOol0099oo`@0029oo`800003FUH005YF00=JEP03001oogoo05Yoo`00TWoo
0P000UYF0P007Goo0`000eYF00<005YFFUH00P00GGoo002COol20003FUH3000FOol40007FUH2001O
Ool009Aoo`03001JEUYF009JEP03001JEP0000<000ioo`@0009JEP03001JEUYF00EJEP80061oo`00
UGoo0P000UYF00<005YFFUH00eYF3P001UYF00<005YFFUH00eYF0P00HWoo002GOol200000eYF001J
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002001TOol009Uoo`<000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP@006Moo`00W7oo10000UYF00<005YFFUH01UYF00<005YFFUH01000
Jgoo002POol>001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]20\[InvisibleSpace]"     "\
\[InvisibleSpace]6.435172469202728`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 20, "     ", 6.4351724692027279, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60605 .74455 m .60192 .68869 L .57083 .68914 L p .707 .577 .707 r
F P
0 g
s
.60192 .68869 m .60605 .74455 L .63781 .74164 L p .707 .577 .707 r
F P
0 g
s
.63781 .74164 m .63367 .68578 L .60192 .68869 L p .707 .577 .707 r
F P
0 g
s
.63367 .68578 m .63781 .74164 L .66713 .73657 L p .707 .577 .707 r
F P
0 g
s
.66713 .73657 m .66299 .68071 L .63367 .68578 L p .707 .577 .707 r
F P
0 g
s
.57497 .745 m .57083 .68914 L .54346 .68711 L p .707 .577 .707 r
F P
0 g
s
.57083 .68914 m .57497 .745 L .60605 .74455 L p .707 .577 .707 r
F P
0 g
s
.66299 .68071 m .66713 .73657 L .69114 .72984 L p .707 .577 .707 r
F P
0 g
s
.69114 .72984 m .68701 .67398 L .66299 .68071 L p .707 .577 .707 r
F P
0 g
s
.54346 .68711 m .5476 .74297 L .57497 .745 L p .707 .577 .707 r
F P
0 g
s
.60154 .81078 m .60801 .77503 L .57732 .76767 L p .707 .577 .707 r
F P
0 g
s
.60801 .77503 m .60154 .81078 L .63293 .81493 L p .707 .577 .707 r
F P
0 g
s
.63293 .81493 m .63941 .77918 L .60801 .77503 L p .707 .577 .707 r
F P
0 g
s
.5476 .74297 m .54346 .68711 L .52249 .68278 L p .707 .577 .707 r
F P
0 g
s
.63941 .77918 m .63293 .81493 L .66197 .81546 L p .707 .577 .707 r
F P
0 g
s
.66197 .81546 m .66844 .77972 L .63941 .77918 L p .707 .577 .707 r
F P
0 g
s
.57085 .80341 m .57732 .76767 L .55035 .75781 L p .707 .577 .707 r
F P
0 g
s
.57732 .76767 m .57085 .80341 L .60154 .81078 L p .707 .577 .707 r
F P
0 g
s
.68701 .67398 m .69114 .72984 L .7075 .7221 L p .707 .577 .707 r
F P
0 g
s
.7075 .7221 m .70336 .66624 L .68701 .67398 L p .707 .577 .707 r
F P
0 g
s
.52249 .68278 m .52662 .73864 L .5476 .74297 L p .707 .577 .707 r
F P
0 g
s
.66844 .77972 m .66197 .81546 L .6858 .81232 L p .707 .577 .707 r
F P
0 g
s
.6858 .81232 m .69227 .77658 L .66844 .77972 L p .707 .577 .707 r
F P
0 g
s
.55035 .75781 m .54388 .79356 L .57085 .80341 L p .707 .577 .707 r
F P
0 g
s
.54388 .79356 m .55035 .75781 L .52974 .74643 L p .707 .577 .707 r
F P
0 g
s
.58625 .86158 m .59404 .84575 L .5658 .83089 L p .707 .577 .707 r
F P
0 g
s
.59404 .84575 m .58625 .86158 L .61543 .87249 L p .707 .577 .707 r
F P
0 g
s
.61543 .87249 m .62322 .85666 L .59404 .84575 L p .707 .577 .707 r
F P
0 g
s
.52662 .73864 m .52249 .68278 L .50996 .67659 L p .707 .577 .707 r
F P
0 g
s
.55801 .84673 m .5658 .83089 L .54128 .81355 L p .707 .577 .707 r
F P
0 g
s
.5658 .83089 m .55801 .84673 L .58625 .86158 L p .707 .577 .707 r
F P
0 g
s
.52974 .74643 m .52326 .78218 L .54388 .79356 L p .707 .577 .707 r
F P
0 g
s
.62322 .85666 m .61543 .87249 L .64271 .87839 L p .707 .577 .707 r
F P
0 g
s
.64271 .87839 m .6505 .86255 L .62322 .85666 L p .707 .577 .707 r
F P
0 g
s
.54128 .81355 m .53349 .82938 L .55801 .84673 L p .707 .577 .707 r
F P
0 g
s
.53349 .82938 m .54128 .81355 L .52287 .79541 L p .707 .577 .707 r
F P
0 g
s
.70336 .66624 m .7075 .7221 L .7146 .71411 L p .707 .577 .707 r
F P
0 g
s
.7146 .71411 m .71046 .65825 L .70336 .66624 L p .707 .577 .707 r
F P
0 g
s
.69227 .77658 m .6858 .81232 L .70209 .80582 L p .707 .577 .707 r
F P
0 g
s
.70209 .80582 m .70856 .77007 L .69227 .77658 L p .707 .577 .707 r
F P
0 g
s
.50996 .67659 m .51409 .73245 L .51888 .73481 L p .707 .577 .707 r
F P
0 g
s
.51749 .73464 m .51482 .72358 L p .51201 .75813 L .707 .577 .707 r
F P
0 g
s
.51102 .77038 m .51519 .74732 L p .51201 .75813 L .707 .577 .707 r
F P
0 g
s
.51519 .74732 m .51749 .73464 L p .51201 .75813 L .707 .577 .707 r
F P
0 g
s
.51888 .73481 m .52662 .73864 L p .52239 .72288 L .707 .577 .707 r
F P
0 g
s
.52239 .72288 m .50996 .67659 L .51888 .73481 L .707 .577 .707 r
F
.52326 .78218 m .52974 .74643 L .51749 .73464 L p F P
0 g
s
.52287 .79541 m .51508 .81124 L .53349 .82938 L p .707 .577 .707 r
F P
0 g
s
.6505 .86255 m .64271 .87839 L .66542 .87869 L p .707 .577 .707 r
F P
0 g
s
.66542 .87869 m .67321 .86286 L .6505 .86255 L p .707 .577 .707 r
F P
0 g
s
.51749 .73464 m .51102 .77038 L .52326 .78218 L p .707 .577 .707 r
F P
0 g
s
.51409 .73245 m .50996 .67659 L .5071 .66913 L p .707 .577 .707 r
F P
0 g
s
.51508 .81124 m .52287 .79541 L .51238 .77825 L p .707 .577 .707 r
F P
0 g
s
.51238 .77825 m .50459 .79408 L .51508 .81124 L p .707 .577 .707 r
F P
0 g
s
.70856 .77007 m .70209 .80582 L .70925 .79659 L p .707 .577 .707 r
F P
0 g
s
.70925 .79659 m .71572 .76084 L .70856 .77007 L p .707 .577 .707 r
F P
0 g
s
.51227 .7277 m .51409 .73245 L p .51235 .71668 L .707 .577 .707 r
F P
0 g
s
.51482 .72358 m .50834 .75933 L .51102 .77038 L p .707 .577 .707 r
F P
0 g
s
.51482 .72358 m .52198 .71435 L p .51214 .7468 L .707 .577 .707 r
F P
0 g
s
.50834 .75933 m .5122 .73802 L p .51214 .7468 L .707 .577 .707 r
F P
0 g
s
.5122 .73802 m .51482 .72358 L p .51214 .7468 L .707 .577 .707 r
F P
0 g
s
.5071 .66913 m .51124 .72499 L .51227 .7277 L p .707 .577 .707 r
F P
0 g
s
.51235 .71668 m .5071 .66913 L .51227 .7277 L .707 .577 .707 r
F
.71046 .65825 m .7146 .71411 L .71174 .70665 L p F P
0 g
s
.71174 .70665 m .7076 .65079 L .71046 .65825 L p .707 .577 .707 r
F P
0 g
s
.67321 .86286 m .66542 .87869 L .68132 .87337 L p .707 .577 .707 r
F P
0 g
s
.68132 .87337 m .68911 .85754 L .67321 .86286 L p .707 .577 .707 r
F P
0 g
s
.47262 .82203 m .50122 .32409 L .45728 .31887 L p .707 .577 .707 r
F P
0 g
s
.50459 .79408 m .51238 .77825 L .51084 .76375 L p .707 .577 .707 r
F P
0 g
s
.51124 .72499 m .5071 .66913 L .5142 .66114 L p .707 .577 .707 r
F P
0 g
s
.51084 .76375 m .50305 .77959 L .50459 .79408 L p .707 .577 .707 r
F P
0 g
s
.5142 .66114 m .51833 .717 L .51124 .72499 L p .707 .577 .707 r
F P
0 g
s
.52198 .71435 m .51925 .7294 L p .50834 .75933 L .707 .577 .707 r
F P
0 g
s
.51925 .7294 m .5155 .7501 L .51134 .75547 L p .707 .577 .707 r
F P
0 g
s
.51134 .75547 m .50834 .75933 L p .51925 .7294 L .707 .577 .707 r
F P
0 g
s
.53055 .6534 m .53286 .68457 L p .51833 .717 L .707 .577 .707 r
F P
0 g
s
.5155 .7501 m .52198 .71435 L .53827 .70785 L p .707 .577 .707 r
F P
0 g
s
.53286 .68457 m .53469 .70926 L .5238 .71441 L p .707 .577 .707 r
F P
0 g
s
.5238 .71441 m .51833 .717 L p .53286 .68457 L .707 .577 .707 r
F P
0 g
s
.50305 .77959 m .51084 .76375 L .51839 .75334 L p .707 .577 .707 r
F P
0 g
s
.51839 .75334 m .5106 .76917 L .50305 .77959 L p .707 .577 .707 r
F P
0 g
s
.5106 .76917 m .51839 .75334 L .53429 .74802 L p .707 .577 .707 r
F P
0 g
s
.53429 .74802 m .5265 .76386 L .5106 .76917 L p .707 .577 .707 r
F P
0 g
s
.50122 .32409 m .47262 .82203 L .5175 .82321 L p .707 .577 .707 r
F P
0 g
s
.51833 .717 m .5142 .66114 L .53055 .6534 L p .707 .577 .707 r
F P
0 g
s
.53827 .70785 m .53565 .72229 L p .5155 .7501 L .707 .577 .707 r
F P
0 g
s
.53565 .72229 m .53179 .7436 L .52327 .747 L p .707 .577 .707 r
F P
0 g
s
.52327 .747 m .5155 .7501 L p .53565 .72229 L .707 .577 .707 r
F P
0 g
s
.55456 .64666 m .55701 .67967 L p .53469 .70926 L .707 .577 .707 r
F P
0 g
s
.55701 .67967 m .5587 .70252 L .54341 .70681 L p .707 .577 .707 r
F P
0 g
s
.53179 .7436 m .53827 .70785 L .5621 .70471 L p .707 .577 .707 r
F P
0 g
s
.54341 .70681 m .53469 .70926 L p .55701 .67967 L .707 .577 .707 r
F P
0 g
s
.5175 .82321 m .5461 .32527 L .50122 .32409 L p .707 .577 .707 r
F P
0 g
s
.53469 .70926 m .53055 .6534 L .55456 .64666 L p .707 .577 .707 r
F P
0 g
s
.5621 .70471 m .55562 .74046 L .53179 .7436 L p .707 .577 .707 r
F P
0 g
s
.5265 .76386 m .53429 .74802 L .55699 .74832 L p .707 .577 .707 r
F P
0 g
s
.55699 .74832 m .5492 .76416 L .5265 .76386 L p .707 .577 .707 r
F P
0 g
s
.55562 .74046 m .5621 .70471 L .59113 .70525 L p .707 .577 .707 r
F P
0 g
s
.59113 .70525 m .58466 .74099 L .55562 .74046 L p .707 .577 .707 r
F P
0 g
s
.5492 .76416 m .55699 .74832 L .58427 .75422 L p .707 .577 .707 r
F P
0 g
s
.58427 .75422 m .57648 .77005 L .5492 .76416 L p .707 .577 .707 r
F P
0 g
s
.5461 .32527 m .5175 .82321 L .55892 .82025 L p .707 .577 .707 r
F P
0 g
s
.5587 .70252 m .55456 .64666 L .58388 .6416 L p .707 .577 .707 r
F P
0 g
s
.58388 .6416 m .58802 .69746 L .5587 .70252 L p .707 .577 .707 r
F P
0 g
s
.55892 .82025 m .58753 .32231 L .5461 .32527 L p .707 .577 .707 r
F P
0 g
s
.42868 .81681 m .45728 .31887 L .41859 .31014 L p .707 .577 .707 r
F P
0 g
s
.45728 .31887 m .42868 .81681 L .47262 .82203 L p .707 .577 .707 r
F P
0 g
s
.71572 .76084 m .70925 .79659 L .70658 .78554 L p .707 .577 .707 r
F P
0 g
s
.70658 .78554 m .71305 .74979 L .71572 .76084 L p .707 .577 .707 r
F P
0 g
s
.68911 .85754 m .68132 .87337 L .68887 .86296 L p .707 .577 .707 r
F P
0 g
s
.68887 .86296 m .69666 .84712 L .68911 .85754 L p .707 .577 .707 r
F P
0 g
s
.7076 .65079 m .71174 .70665 L .69921 .70046 L p .707 .577 .707 r
F P
0 g
s
.69921 .70046 m .69507 .64459 L .7076 .65079 L p .707 .577 .707 r
F P
0 g
s
.58802 .69746 m .58388 .6416 L .61564 .63869 L p .707 .577 .707 r
F P
0 g
s
.61564 .63869 m .61978 .69455 L .58802 .69746 L p .707 .577 .707 r
F P
0 g
s
.58466 .74099 m .59113 .70525 L .62253 .7094 L p .707 .577 .707 r
F P
0 g
s
.62253 .7094 m .61606 .74514 L .58466 .74099 L p .707 .577 .707 r
F P
0 g
s
.57648 .77005 m .58427 .75422 L .61346 .76513 L p .707 .577 .707 r
F P
0 g
s
.61346 .76513 m .60567 .78096 L .57648 .77005 L p .707 .577 .707 r
F P
0 g
s
.58753 .32231 m .55892 .82025 L .59285 .81344 L p .707 .577 .707 r
F P
0 g
s
.59285 .81344 m .62145 .3155 L .58753 .32231 L p .707 .577 .707 r
F P
0 g
s
.38999 .80808 m .41859 .31014 L .38893 .29874 L p .707 .577 .707 r
F P
0 g
s
.41859 .31014 m .38999 .80808 L .42868 .81681 L p .707 .577 .707 r
F P
0 g
s
.26305 .7149 m .25891 .65904 L .22782 .65949 L p .707 .577 .707 r
F P
0 g
s
.25891 .65904 m .26305 .7149 L .2948 .71199 L p .707 .577 .707 r
F P
0 g
s
.2948 .71199 m .29066 .65613 L .25891 .65904 L p .707 .577 .707 r
F P
0 g
s
.29066 .65613 m .2948 .71199 L .32412 .70692 L p .707 .577 .707 r
F P
0 g
s
.32412 .70692 m .31998 .65106 L .29066 .65613 L p .707 .577 .707 r
F P
0 g
s
.23196 .71535 m .22782 .65949 L .20045 .65746 L p .707 .577 .707 r
F P
0 g
s
.22782 .65949 m .23196 .71535 L .26305 .7149 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71305 .74979 m .70658 .78554 L .69433 .77374 L p .707 .577 .707 r
F P
0 g
s
.69433 .77374 m .70081 .738 L .71305 .74979 L p .707 .577 .707 r
F P
0 g
s
.31998 .65106 m .32412 .70692 L .34813 .70019 L p .707 .577 .707 r
F P
0 g
s
.34813 .70019 m .344 .64433 L .31998 .65106 L p .707 .577 .707 r
F P
0 g
s
.69666 .84712 m .68887 .86296 L .68732 .84846 L p .707 .577 .707 r
F P
0 g
s
.68732 .84846 m .69511 .83263 L .69666 .84712 L p .707 .577 .707 r
F P
0 g
s
.69507 .64459 m .69921 .70046 L .67823 .69613 L p .707 .577 .707 r
F P
0 g
s
.67823 .69613 m .6741 .64027 L .69507 .64459 L p .707 .577 .707 r
F P
0 g
s
.61978 .69455 m .61564 .63869 L .64673 .63823 L p .707 .577 .707 r
F P
0 g
s
.65322 .71676 m .64674 .75251 L .61606 .74514 L p .707 .577 .707 r
F P
0 g
s
.61606 .74514 m .62253 .7094 L .65322 .71676 L p .707 .577 .707 r
F P
0 g
s
.6417 .77998 m .6339 .79582 L .60567 .78096 L p .707 .577 .707 r
F P
0 g
s
.60567 .78096 m .61346 .76513 L .6417 .77998 L p .707 .577 .707 r
F P
0 g
s
.62145 .3155 m .59285 .81344 L .61595 .80344 L p .707 .577 .707 r
F P
0 g
s
.64673 .63823 m .65086 .69409 L .61978 .69455 L p .707 .577 .707 r
F P
0 g
s
.61595 .80344 m .64455 .3055 L .62145 .3155 L p .707 .577 .707 r
F P
0 g
s
.20045 .65746 m .20459 .71332 L .23196 .71535 L p .707 .577 .707 r
F P
0 g
s
.25853 .7837 m .265 .74795 L .23432 .74059 L p .707 .577 .707 r
F P
0 g
s
.265 .74795 m .25853 .7837 L .28992 .78785 L p .707 .577 .707 r
F P
0 g
s
.28992 .78785 m .2964 .7521 L .265 .74795 L p .707 .577 .707 r
F P
0 g
s
.20459 .71332 m .20045 .65746 L .17948 .65313 L p .707 .577 .707 r
F P
0 g
s
.2964 .7521 m .28992 .78785 L .31896 .78838 L p .707 .577 .707 r
F P
0 g
s
.31896 .78838 m .32543 .75264 L .2964 .7521 L p .707 .577 .707 r
F P
0 g
s
.22784 .77634 m .23432 .74059 L .20734 .73073 L p .707 .577 .707 r
F P
0 g
s
.23432 .74059 m .22784 .77634 L .25853 .7837 L p .707 .577 .707 r
F P
0 g
s
.344 .64433 m .34813 .70019 L .36449 .69245 L p .707 .577 .707 r
F P
0 g
s
.36449 .69245 m .36035 .63659 L .344 .64433 L p .707 .577 .707 r
F P
0 g
s
.36035 .63659 m .36449 .69245 L .37159 .68446 L p .707 .577 .707 r
F P
0 g
s
.37159 .68446 m .36745 .6286 L .36035 .63659 L p .707 .577 .707 r
F P
0 g
s
.35908 .77874 m .36556 .74299 L .34926 .7495 L p .707 .577 .707 r
F P
0 g
s
.36556 .74299 m .35908 .77874 L .36624 .76951 L p .707 .577 .707 r
F P
0 g
s
.36745 .6286 m .37159 .68446 L .36873 .677 L p .707 .577 .707 r
F P
0 g
s
.36873 .677 m .36459 .62114 L .36745 .6286 L p .707 .577 .707 r
F P
0 g
s
.36459 .62114 m .36873 .677 L .36248 .67391 L p .707 .577 .707 r
F P
0 g
s
.36248 .67391 m .3562 .6708 L p .3593 .65247 L .707 .577 .707 r
F P
0 g
s
.3593 .65247 m .36459 .62114 L .36248 .67391 L .707 .577 .707 r
F
.38893 .29874 m .36601 .69773 L p .38999 .80808 L F P
0 g
s
.36624 .76951 m .37272 .73377 L .36556 .74299 L p .707 .577 .707 r
F P
0 g
s
.37272 .73377 m .36624 .76951 L .36357 .75846 L p .707 .577 .707 r
F P
0 g
s
.36357 .75846 m .37004 .72271 L .37272 .73377 L p .707 .577 .707 r
F P
0 g
s
.3562 .6708 m .35336 .63247 L p .36459 .62114 L .707 .577 .707 r
F P
0 g
s
.35336 .63247 m .35206 .61494 L .3549 .61635 L p .707 .577 .707 r
F P
0 g
s
.3549 .61635 m .36459 .62114 L p .35336 .63247 L .707 .577 .707 r
F P
0 g
s
.35206 .61494 m .3562 .6708 L .33522 .66648 L p .707 .577 .707 r
F P
0 g
s
.33522 .66648 m .33109 .61062 L .35206 .61494 L p .707 .577 .707 r
F P
0 g
s
.3307 .73528 m .33718 .69954 L .34836 .70571 L p .707 .577 .707 r
F P
0 g
s
.36357 .75846 m .35716 .75228 L p .3675 .72854 L .707 .577 .707 r
F P
0 g
s
.35716 .75228 m .35132 .74666 L p .3627 .73211 L .707 .577 .707 r
F P
0 g
s
.3627 .73211 m .36629 .72752 L .35716 .75228 L .707 .577 .707 r
F
.36629 .72752 m .37004 .72271 L .3675 .72854 L F
.36629 .72752 m .3675 .72854 L .35716 .75228 L F
.37121 .2858 m .35421 .58176 L p .35816 .72068 L F P
0 g
s
.36188 .72381 m .37121 .2858 L .35816 .72068 L .707 .577 .707 r
F
.35132 .74666 m .35631 .71912 L p .36629 .72752 L F P
0 g
s
.34926 .7495 m .34279 .78524 L .35908 .77874 L p .707 .577 .707 r
F P
0 g
s
.35747 .79459 m .36033 .79668 L p .35421 .58176 L .707 .577 .707 r
F P
0 g
s
.38893 .29874 m .37121 .2858 L p .36188 .72381 L .707 .577 .707 r
F P
0 g
s
.36439 .72592 m .38893 .29874 L p .36188 .72381 L .707 .577 .707 r
F P
0 g
s
.36601 .69773 m .36439 .72592 L p .36816 .7122 L .707 .577 .707 r
F P
0 g
s
.38192 .80498 m .38999 .80808 L p .36872 .71018 L .707 .577 .707 r
F P
0 g
s
.36872 .71018 m .36601 .69773 L .36816 .7122 L .707 .577 .707 r
F
.36629 .72752 m .36477 .72455 L .37004 .72271 L F
.36627 .71908 m .37004 .72271 L p .36477 .72455 L F P
0 g
s
.37004 .72271 m .36879 .72962 L p .3675 .72854 L .707 .577 .707 r
F P
0 g
s
.36872 .71018 m .36816 .7122 L .38192 .80498 L .707 .577 .707 r
F
.3578 .71092 m .36627 .71908 L p .36477 .72455 L F P
0 g
s
.35631 .71912 m .3578 .71092 L p .36629 .72752 L .707 .577 .707 r
F P
0 g
s
.34279 .78524 m .34926 .7495 L .32543 .75264 L p .707 .577 .707 r
F P
0 g
s
.3578 .71092 m .35132 .74666 L .3307 .73528 L p .707 .577 .707 r
F P
0 g
s
.32543 .75264 m .31896 .78838 L .34279 .78524 L p .707 .577 .707 r
F P
0 g
s
.33382 .79727 m .34161 .78144 L .34543 .78768 L p .707 .577 .707 r
F P
0 g
s
.34543 .78768 m .3521 .79859 L p .34559 .79812 L .707 .577 .707 r
F P
0 g
s
.33382 .79727 m .34543 .78768 L .34559 .79812 L .707 .577 .707 r
F
.3307 .73528 m .34836 .70571 L .34768 .72001 L F
.34471 .73986 m .34817 .68687 L .34633 .70611 L F
.3426 .78374 m .3448 .74556 L p .34471 .73986 L F P
0 g
s
.3448 .74556 m .34817 .68687 L p .34471 .73986 L .707 .577 .707 r
F P
0 g
s
.3426 .78374 m .35747 .79459 L p .35631 .71912 L .707 .577 .707 r
F P
0 g
s
.34836 .70571 m .35617 .71002 L p .34768 .72001 L .707 .577 .707 r
F P
0 g
s
.34768 .72001 m .35617 .71002 L .35621 .71235 L .707 .577 .707 r
F
.35421 .58176 m .34678 .7111 L p .35631 .71912 L F P
0 g
s
.34678 .7111 m .3426 .78374 L p .35631 .71912 L .707 .577 .707 r
F P
0 g
s
.36033 .79668 m .36188 .72381 L .35816 .72068 L .707 .577 .707 r
F
.35617 .71002 m .3578 .71092 L p .35621 .71235 L F P
0 g
s
.34633 .70611 m .35623 .53888 L .36715 .27258 L .707 .577 .707 r
F
.37121 .2858 m .36857 .27721 L p .35623 .53888 L F P
0 g
s
.36857 .27721 m .36715 .27258 L p .35623 .53888 L .707 .577 .707 r
F P
0 g
s
.34817 .68687 m .37121 .2858 L p .34633 .70611 L .707 .577 .707 r
F P
0 g
s
.36033 .79668 m .36439 .72592 L p .36188 .72381 L .707 .577 .707 r
F P
0 g
s
.36879 .72962 m .36357 .75846 L p .3675 .72854 L .707 .577 .707 r
F P
0 g
s
.36033 .79668 m .38192 .80498 L p .36816 .7122 L .707 .577 .707 r
F P
0 g
s
.36439 .72592 m .36033 .79668 L p .36816 .7122 L .707 .577 .707 r
F P
0 g
s
.17948 .65313 m .18361 .70899 L .20459 .71332 L p .707 .577 .707 r
F P
0 g
s
.70081 .738 m .69433 .77374 L .67371 .76236 L p .707 .577 .707 r
F P
0 g
s
.67371 .76236 m .68019 .72661 L .70081 .738 L p .707 .577 .707 r
F P
0 g
s
.6741 .64027 m .67823 .69613 L .65086 .69409 L p .707 .577 .707 r
F P
0 g
s
.65086 .69409 m .64673 .63823 L .6741 .64027 L p .707 .577 .707 r
F P
0 g
s
.20734 .73073 m .20087 .76648 L .22784 .77634 L p .707 .577 .707 r
F P
0 g
s
.20087 .76648 m .20734 .73073 L .18673 .71935 L p .707 .577 .707 r
F P
0 g
s
.69511 .83263 m .68732 .84846 L .67683 .8313 L p .707 .577 .707 r
F P
0 g
s
.67683 .8313 m .68462 .81547 L .69511 .83263 L p .707 .577 .707 r
F P
0 g
s
.24324 .82755 m .25103 .81171 L .22279 .79686 L p .707 .577 .707 r
F P
0 g
s
.25103 .81171 m .24324 .82755 L .27242 .83846 L p .707 .577 .707 r
F P
0 g
s
.27242 .83846 m .28021 .82262 L .25103 .81171 L p .707 .577 .707 r
F P
0 g
s
.18361 .70899 m .17948 .65313 L .16695 .64694 L p .707 .577 .707 r
F P
0 g
s
.215 .81269 m .22279 .79686 L .19827 .77951 L p .707 .577 .707 r
F P
0 g
s
.22279 .79686 m .215 .81269 L .24324 .82755 L p .707 .577 .707 r
F P
0 g
s
.28021 .82262 m .27242 .83846 L .2997 .84435 L p .707 .577 .707 r
F P
0 g
s
.2997 .84435 m .30749 .82852 L .28021 .82262 L p .707 .577 .707 r
F P
0 g
s
.18673 .71935 m .18025 .7551 L .20087 .76648 L p .707 .577 .707 r
F P
0 g
s
.19827 .77951 m .19048 .79535 L .215 .81269 L p .707 .577 .707 r
F P
0 g
s
.64455 .3055 m .61595 .80344 L .62596 .79123 L p .707 .577 .707 r
F P
0 g
s
.62596 .79123 m .65456 .29329 L .64455 .3055 L p .707 .577 .707 r
F P
0 g
s
.19048 .79535 m .19827 .77951 L .17987 .76137 L p .707 .577 .707 r
F P
0 g
s
.68019 .72661 m .67371 .76236 L .64674 .75251 L p .707 .577 .707 r
F P
0 g
s
.64674 .75251 m .65322 .71676 L .68019 .72661 L p .707 .577 .707 r
F P
0 g
s
.16695 .64694 m .17108 .7028 L .17645 .70545 L p .707 .577 .707 r
F P
0 g
s
.17448 .70756 m .17181 .6965 L p .16903 .73065 L .707 .577 .707 r
F P
0 g
s
.16801 .7433 m .17232 .71949 L p .16903 .73065 L .707 .577 .707 r
F P
0 g
s
.17232 .71949 m .17448 .70756 L p .16903 .73065 L .707 .577 .707 r
F P
0 g
s
.17645 .70545 m .18361 .70899 L p .1797 .69442 L .707 .577 .707 r
F P
0 g
s
.1797 .69442 m .16695 .64694 L .17645 .70545 L .707 .577 .707 r
F
.18025 .7551 m .18673 .71935 L .17448 .70756 L p F P
0 g
s
.17987 .76137 m .17208 .77721 L .19048 .79535 L p .707 .577 .707 r
F P
0 g
s
.68462 .81547 m .67683 .8313 L .65843 .81316 L p .707 .577 .707 r
F P
0 g
s
.65843 .81316 m .66622 .79733 L .68462 .81547 L p .707 .577 .707 r
F P
0 g
s
.30749 .82852 m .2997 .84435 L .32241 .84466 L p .707 .577 .707 r
F P
0 g
s
.32241 .84466 m .3302 .82882 L .30749 .82852 L p .707 .577 .707 r
F P
0 g
s
.17448 .70756 m .16801 .7433 L .17 .74523 L p .707 .577 .707 r
F P
0 g
s
.17108 .7028 m .16695 .64694 L .16409 .63948 L p .707 .577 .707 r
F P
0 g
s
.16409 .63948 m .16823 .69534 L .16941 .69843 L p .707 .577 .707 r
F P
0 g
s
.16941 .69843 m .17108 .7028 L p .16948 .68829 L .707 .577 .707 r
F P
0 g
s
.16948 .68829 m .16409 .63948 L .16941 .69843 L .707 .577 .707 r
F
.16566 .73359 m .16801 .7433 L p .16961 .72353 L F P
0 g
s
.16938 .74422 m .16783 .72972 L p .16271 .75461 L .707 .577 .707 r
F P
0 g
s
.17783 .73516 m .17448 .70756 L .17 .74523 L .707 .577 .707 r
F
.16783 .72972 m .16004 .74555 L .16159 .76005 L p F P
0 g
s
.16783 .72972 m .17538 .7193 L p .16284 .74075 L .707 .577 .707 r
F P
0 g
s
.16004 .74555 m .1646 .73628 L p .16284 .74075 L .707 .577 .707 r
F P
0 g
s
.1646 .73628 m .16783 .72972 L p .16284 .74075 L .707 .577 .707 r
F P
0 g
s
.17181 .6965 m .16533 .73225 L .16566 .73359 L p .707 .577 .707 r
F P
0 g
s
.16961 .72353 m .17181 .6965 L .16566 .73359 L .707 .577 .707 r
F
.16926 .71928 m .17181 .6965 L .17021 .71616 L F
.17181 .6965 m .17897 .68727 L p .17021 .71616 L F P
0 g
s
.16533 .73225 m .16933 .7102 L p .16926 .71928 L .707 .577 .707 r
F P
0 g
s
.16933 .7102 m .17181 .6965 L p .16926 .71928 L .707 .577 .707 r
F P
0 g
s
.16159 .76005 m .16695 .74915 L p .16271 .75461 L .707 .577 .707 r
F P
0 g
s
.16695 .74915 m .16938 .74422 L p .16271 .75461 L .707 .577 .707 r
F P
0 g
s
.17 .74523 m .18025 .7551 L p .17783 .73516 L .707 .577 .707 r
F P
0 g
s
.17208 .77721 m .17987 .76137 L .16938 .74422 L p .707 .577 .707 r
F P
0 g
s
.16938 .74422 m .16159 .76005 L .17208 .77721 L p .707 .577 .707 r
F P
0 g
s
.66622 .79733 m .65843 .81316 L .6339 .79582 L p .707 .577 .707 r
F P
0 g
s
.6339 .79582 m .6417 .77998 L .66622 .79733 L p .707 .577 .707 r
F P
0 g
s
.3302 .82882 m .32241 .84466 L .33831 .83934 L p .707 .577 .707 r
F P
0 g
s
.33831 .83934 m .3461 .82351 L .3302 .82882 L p .707 .577 .707 r
F P
0 g
s
.65456 .29329 m .62596 .79123 L .6219 .77801 L p .707 .577 .707 r
F P
0 g
s
.6219 .77801 m .65051 .28007 L .65456 .29329 L p .707 .577 .707 r
F P
0 g
s
.16823 .69534 m .16409 .63948 L .17119 .63149 L p .707 .577 .707 r
F P
0 g
s
.36715 .27258 m .33855 .77052 L .3426 .78374 L p .707 .577 .707 r
F P
0 g
s
.33855 .77052 m .36715 .27258 L .37716 .26037 L p .707 .577 .707 r
F P
0 g
s
.3461 .82351 m .33831 .83934 L .34586 .82893 L p .707 .577 .707 r
F P
0 g
s
.34586 .82893 m .35365 .81309 L .3461 .82351 L p .707 .577 .707 r
F P
0 g
s
.17119 .63149 m .17532 .68735 L .16823 .69534 L p .707 .577 .707 r
F P
0 g
s
.17897 .68727 m .17249 .72302 L .16533 .73225 L p .707 .577 .707 r
F P
0 g
s
.17532 .68735 m .17119 .63149 L .18754 .62375 L p .707 .577 .707 r
F P
0 g
s
.19526 .68077 m .19439 .68559 L p .17249 .72302 L .707 .577 .707 r
F P
0 g
s
.16759 .73514 m .17538 .7193 L .19128 .71399 L p .707 .577 .707 r
F P
0 g
s
.19128 .71399 m .18806 .72054 L p .16759 .73514 L .707 .577 .707 r
F P
0 g
s
.18806 .72054 m .18349 .72982 L .17926 .73124 L p .707 .577 .707 r
F P
0 g
s
.17926 .73124 m .16759 .73514 L p .18806 .72054 L .707 .577 .707 r
F P
0 g
s
.21909 .67763 m .21789 .68427 L p .18878 .71652 L .707 .577 .707 r
F P
0 g
s
.18349 .72982 m .19128 .71399 L .21398 .71429 L p .707 .577 .707 r
F P
0 g
s
.21789 .68427 m .21261 .71338 L .19168 .71614 L p .707 .577 .707 r
F P
0 g
s
.19168 .71614 m .18878 .71652 L p .21789 .68427 L .707 .577 .707 r
F P
0 g
s
.19439 .68559 m .18878 .71652 L .1741 .72238 L p .707 .577 .707 r
F P
0 g
s
.17538 .7193 m .17188 .72642 L p .16004 .74555 L .707 .577 .707 r
F P
0 g
s
.1741 .72238 m .17249 .72302 L p .19439 .68559 L .707 .577 .707 r
F P
0 g
s
.17188 .72642 m .16759 .73514 L .16542 .73812 L p .707 .577 .707 r
F P
0 g
s
.16542 .73812 m .16004 .74555 L p .17188 .72642 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.65051 .28007 m .6219 .77801 L .60418 .76507 L p .707 .577 .707 r
F P
0 g
s
.60418 .76507 m .63278 .26712 L .65051 .28007 L p .707 .577 .707 r
F P
0 g
s
.35365 .81309 m .34586 .82893 L .34431 .81443 L p .707 .577 .707 r
F P
0 g
s
.34431 .81443 m .3521 .79859 L .35365 .81309 L p .707 .577 .707 r
F P
0 g
s
.17249 .72302 m .17897 .68727 L .19526 .68077 L p .707 .577 .707 r
F P
0 g
s
.18754 .62375 m .19168 .67961 L .17532 .68735 L p .707 .577 .707 r
F P
0 g
s
.34856 .75831 m .37716 .26037 L .40026 .25037 L p .707 .577 .707 r
F P
0 g
s
.37716 .26037 m .34856 .75831 L .33855 .77052 L p .707 .577 .707 r
F P
0 g
s
.19168 .67961 m .18754 .62375 L .21155 .61701 L p .707 .577 .707 r
F P
0 g
s
.33109 .61062 m .33522 .66648 L .30785 .66444 L p .707 .577 .707 r
F P
0 g
s
.30785 .66444 m .30372 .60858 L .33109 .61062 L p .707 .577 .707 r
F P
0 g
s
.3521 .79859 m .34431 .81443 L .33382 .79727 L p .707 .577 .707 r
F P
0 g
s
.18878 .71652 m .19526 .68077 L .21909 .67763 L p .707 .577 .707 r
F P
0 g
s
.21155 .61701 m .21569 .67287 L .19168 .67961 L p .707 .577 .707 r
F P
0 g
s
.63278 .26712 m .60418 .76507 L .57452 .75367 L p .707 .577 .707 r
F P
0 g
s
.57452 .75367 m .60312 .25573 L .63278 .26712 L p .707 .577 .707 r
F P
0 g
s
.21569 .67287 m .21155 .61701 L .24087 .61195 L p .707 .577 .707 r
F P
0 g
s
.30372 .60858 m .30785 .66444 L .27677 .6649 L p .707 .577 .707 r
F P
0 g
s
.27677 .6649 m .27263 .60904 L .30372 .60858 L p .707 .577 .707 r
F P
0 g
s
.40026 .25037 m .37166 .74831 L .34856 .75831 L p .707 .577 .707 r
F P
0 g
s
.37166 .74831 m .40026 .25037 L .43418 .24355 L p .707 .577 .707 r
F P
0 g
s
.21398 .71429 m .20619 .73013 L .18349 .72982 L p .707 .577 .707 r
F P
0 g
s
.24501 .66781 m .24087 .61195 L .27263 .60904 L p .707 .577 .707 r
F P
0 g
s
.24087 .61195 m .24501 .66781 L .21569 .67287 L p .707 .577 .707 r
F P
0 g
s
.33718 .69954 m .3307 .73528 L .30373 .72543 L p .707 .577 .707 r
F P
0 g
s
.30373 .72543 m .31021 .68968 L .33718 .69954 L p .707 .577 .707 r
F P
0 g
s
.74326 .65251 m .73912 .59665 L .70804 .59711 L p .707 .577 .707 r
F P
0 g
s
.73912 .59665 m .74326 .65251 L .77502 .6496 L p .707 .577 .707 r
F P
0 g
s
.77502 .6496 m .77088 .59374 L .73912 .59665 L p .707 .577 .707 r
F P
0 g
s
.21261 .71338 m .21909 .67763 L .24812 .67817 L p .707 .577 .707 r
F P
0 g
s
.27263 .60904 m .27677 .6649 L .24501 .66781 L p .707 .577 .707 r
F P
0 g
s
.77088 .59374 m .77502 .6496 L .80433 .64454 L p .707 .577 .707 r
F P
0 g
s
.80433 .64454 m .8002 .58868 L .77088 .59374 L p .707 .577 .707 r
F P
0 g
s
.34161 .78144 m .33382 .79727 L .31542 .77913 L p .707 .577 .707 r
F P
0 g
s
.31542 .77913 m .32321 .7633 L .34161 .78144 L p .707 .577 .707 r
F P
0 g
s
.71217 .65297 m .70804 .59711 L .68067 .59507 L p .707 .577 .707 r
F P
0 g
s
.70804 .59711 m .71217 .65297 L .74326 .65251 L p .707 .577 .707 r
F P
0 g
s
.20619 .73013 m .21398 .71429 L .24126 .72019 L p .707 .577 .707 r
F P
0 g
s
.31021 .68968 m .30373 .72543 L .27305 .71806 L p .707 .577 .707 r
F P
0 g
s
.27305 .71806 m .27952 .68232 L .31021 .68968 L p .707 .577 .707 r
F P
0 g
s
.24812 .67817 m .24165 .71391 L .21261 .71338 L p .707 .577 .707 r
F P
0 g
s
.8002 .58868 m .80433 .64454 L .82835 .6378 L p .707 .577 .707 r
F P
0 g
s
.82835 .6378 m .82421 .58194 L .8002 .58868 L p .707 .577 .707 r
F P
0 g
s
.24165 .71391 m .24812 .67817 L .27952 .68232 L p .707 .577 .707 r
F P
0 g
s
.60312 .25573 m .57452 .75367 L .53582 .74494 L p .707 .577 .707 r
F P
0 g
s
.53582 .74494 m .56443 .247 L .60312 .25573 L p .707 .577 .707 r
F P
0 g
s
.27952 .68232 m .27305 .71806 L .24165 .71391 L p .707 .577 .707 r
F P
0 g
s
.24126 .72019 m .23347 .73602 L .20619 .73013 L p .707 .577 .707 r
F P
0 g
s
.68067 .59507 m .6848 .65093 L .71217 .65297 L p .707 .577 .707 r
F P
0 g
s
.73874 .71874 m .74522 .68299 L .71453 .67563 L p .707 .577 .707 r
F P
0 g
s
.74522 .68299 m .73874 .71874 L .77014 .72289 L p .707 .577 .707 r
F P
0 g
s
.77014 .72289 m .77661 .68715 L .74522 .68299 L p .707 .577 .707 r
F P
0 g
s
.32321 .7633 m .31542 .77913 L .2909 .76178 L p .707 .577 .707 r
F P
0 g
s
.2909 .76178 m .29869 .74595 L .32321 .7633 L p .707 .577 .707 r
F P
0 g
s
.6848 .65093 m .68067 .59507 L .65969 .59075 L p .707 .577 .707 r
F P
0 g
s
.40558 .7415 m .41718 .53952 L p .42473 .60456 L .707 .577 .707 r
F P
0 g
s
.40558 .7415 m .37166 .74831 L p .41478 .40019 L .707 .577 .707 r
F P
0 g
s
.43418 .24355 m .41718 .53952 L p .41478 .40019 L .707 .577 .707 r
F P
0 g
s
.41718 .53952 m .40558 .7415 L p .41478 .40019 L .707 .577 .707 r
F P
0 g
s
.43212 .66827 m .4336 .66007 L .43113 .65974 L p .707 .577 .707 r
F P
0 g
s
.44701 .73854 m .40558 .7415 L p .41576 .6687 L .707 .577 .707 r
F P
0 g
s
.4336 .66007 m .43212 .66827 L p .4386 .6681 L .707 .577 .707 r
F P
0 g
s
.45107 .66778 m .44701 .73854 L p .41576 .6687 L .707 .577 .707 r
F P
0 g
s
.44701 .73854 m .45107 .66778 L p .462 .6372 L .707 .577 .707 r
F P
0 g
s
.49189 .73972 m .44701 .73854 L p .462 .6372 L .707 .577 .707 r
F P
0 g
s
.52049 .24178 m .50463 .5179 L p .462 .6372 L .707 .577 .707 r
F P
0 g
s
.50463 .5179 m .49189 .73972 L p .462 .6372 L .707 .577 .707 r
F P
0 g
s
.42713 .69581 m .44097 .69607 L p .4386 .6681 L .707 .577 .707 r
F P
0 g
s
.44097 .69607 m .45616 .69634 L p .44645 .68072 L .707 .577 .707 r
F P
0 g
s
.44645 .68072 m .4386 .6681 L .44097 .69607 L .707 .577 .707 r
F
.45616 .69634 m .46264 .6606 L .4537 .66043 L p F P
0 g
s
.4537 .66043 m .4336 .66007 L p .44645 .68072 L .707 .577 .707 r
F P
0 g
s
.45616 .69634 m .4537 .66043 L .44645 .68072 L .707 .577 .707 r
F
.47561 .2406 m .52049 .24178 L p .462 .6372 L F P
0 g
s
.47561 .2406 m .45107 .66778 L p .41576 .6687 L .707 .577 .707 r
F P
0 g
s
.43418 .24355 m .47561 .2406 L p .42473 .60456 L .707 .577 .707 r
F P
0 g
s
.42787 .56409 m .43201 .61995 L .4467 .61741 L p .707 .577 .707 r
F P
0 g
s
.45633 .65305 m .47561 .2406 L .462 .6372 L .707 .577 .707 r
F
.45269 .63959 m .47561 .2406 L p .45633 .65305 L F P
0 g
s
.4467 .61741 m .46133 .61489 L p .43536 .57546 L .707 .577 .707 r
F P
0 g
s
.43536 .57546 m .42787 .56409 L .4467 .61741 L .707 .577 .707 r
F
.45107 .66778 m .45269 .63959 L p .45633 .65305 L F P
0 g
s
.43212 .66827 m .42713 .69581 L p .4386 .6681 L .707 .577 .707 r
F P
0 g
s
.42713 .69581 m .43212 .66827 L p .41931 .66298 L .707 .577 .707 r
F P
0 g
s
.41967 .68388 m .41931 .66298 L .40221 .65591 L .707 .577 .707 r
F
.42713 .69581 m .41931 .66298 L .41967 .68388 L F
.43113 .65974 m .40221 .65591 L p .43212 .66827 L F P
0 g
s
.41718 .53952 m .43418 .24355 L p .42473 .60456 L .707 .577 .707 r
F P
0 g
s
.77661 .68715 m .77014 .72289 L .79917 .72342 L p .707 .577 .707 r
F P
0 g
s
.79917 .72342 m .80565 .68768 L .77661 .68715 L p .707 .577 .707 r
F P
0 g
s
.70805 .71138 m .71453 .67563 L .68756 .66578 L p .707 .577 .707 r
F P
0 g
s
.71453 .67563 m .70805 .71138 L .73874 .71874 L p .707 .577 .707 r
F P
0 g
s
.23347 .73602 m .24126 .72019 L .27045 .7311 L p .707 .577 .707 r
F P
0 g
s
.82421 .58194 m .82835 .6378 L .8447 .63006 L p .707 .577 .707 r
F P
0 g
s
.8447 .63006 m .84057 .5742 L .82421 .58194 L p .707 .577 .707 r
F P
0 g
s
.29869 .74595 m .2909 .76178 L .26266 .74693 L p .707 .577 .707 r
F P
0 g
s
.26266 .74693 m .27045 .7311 L .29869 .74595 L p .707 .577 .707 r
F P
0 g
s
.27045 .7311 m .26266 .74693 L .23347 .73602 L p .707 .577 .707 r
F P
0 g
s
.65969 .59075 m .66383 .64661 L .6848 .65093 L p .707 .577 .707 r
F P
0 g
s
.56443 .247 m .53582 .74494 L .49189 .73972 L p .707 .577 .707 r
F P
0 g
s
.49189 .73972 m .52049 .24178 L .56443 .247 L p .707 .577 .707 r
F P
0 g
s
.80565 .68768 m .79917 .72342 L .823 .72028 L p .707 .577 .707 r
F P
0 g
s
.823 .72028 m .82948 .68454 L .80565 .68768 L p .707 .577 .707 r
F P
0 g
s
.68756 .66578 m .68108 .70152 L .70805 .71138 L p .707 .577 .707 r
F P
0 g
s
.68108 .70152 m .68756 .66578 L .66694 .65439 L p .707 .577 .707 r
F P
0 g
s
.72345 .76954 m .73124 .75371 L .70301 .73885 L p .707 .577 .707 r
F P
0 g
s
.73124 .75371 m .72345 .76954 L .75264 .78045 L p .707 .577 .707 r
F P
0 g
s
.75264 .78045 m .76043 .76462 L .73124 .75371 L p .707 .577 .707 r
F P
0 g
s
.66383 .64661 m .65969 .59075 L .64716 .58455 L p .707 .577 .707 r
F P
0 g
s
.69522 .75469 m .70301 .73885 L .67849 .72151 L p .707 .577 .707 r
F P
0 g
s
.70301 .73885 m .69522 .75469 L .72345 .76954 L p .707 .577 .707 r
F P
0 g
s
.66694 .65439 m .66046 .69014 L .68108 .70152 L p .707 .577 .707 r
F P
0 g
s
.76043 .76462 m .75264 .78045 L .77992 .78635 L p .707 .577 .707 r
F P
0 g
s
.77992 .78635 m .78771 .77051 L .76043 .76462 L p .707 .577 .707 r
F P
0 g
s
.67849 .72151 m .67069 .73734 L .69522 .75469 L p .707 .577 .707 r
F P
0 g
s
.67069 .73734 m .67849 .72151 L .66008 .70337 L p .707 .577 .707 r
F P
0 g
s
.84057 .5742 m .8447 .63006 L .8518 .62207 L p .707 .577 .707 r
F P
0 g
s
.8518 .62207 m .84766 .56621 L .84057 .5742 L p .707 .577 .707 r
F P
0 g
s
.82948 .68454 m .823 .72028 L .83929 .71378 L p .707 .577 .707 r
F P
0 g
s
.83929 .71378 m .84577 .67804 L .82948 .68454 L p .707 .577 .707 r
F P
0 g
s
.64716 .58455 m .6513 .64041 L .65608 .64277 L p .707 .577 .707 r
F P
0 g
s
.65469 .6426 m .65202 .63155 L p .64922 .66609 L .707 .577 .707 r
F P
0 g
s
.64822 .67834 m .6524 .65528 L p .64922 .66609 L .707 .577 .707 r
F P
0 g
s
.6524 .65528 m .65469 .6426 L p .64922 .66609 L .707 .577 .707 r
F P
0 g
s
.65608 .64277 m .66383 .64661 L p .65959 .63084 L .707 .577 .707 r
F P
0 g
s
.65959 .63084 m .64716 .58455 L .65608 .64277 L .707 .577 .707 r
F
.66046 .69014 m .66694 .65439 L .65469 .6426 L p F P
0 g
s
.66008 .70337 m .65229 .7192 L .67069 .73734 L p .707 .577 .707 r
F P
0 g
s
.78771 .77051 m .77992 .78635 L .80262 .78665 L p .707 .577 .707 r
F P
0 g
s
.80262 .78665 m .81041 .77082 L .78771 .77051 L p .707 .577 .707 r
F P
0 g
s
.65469 .6426 m .64822 .67834 L .66046 .69014 L p .707 .577 .707 r
F P
0 g
s
.6513 .64041 m .64716 .58455 L .6443 .57709 L p .707 .577 .707 r
F P
0 g
s
.65229 .7192 m .66008 .70337 L .64959 .68621 L p .707 .577 .707 r
F P
0 g
s
.64959 .68621 m .6418 .70205 L .65229 .7192 L p .707 .577 .707 r
F P
0 g
s
.84577 .67804 m .83929 .71378 L .84645 .70455 L p .707 .577 .707 r
F P
0 g
s
.84645 .70455 m .85293 .66881 L .84577 .67804 L p .707 .577 .707 r
F P
0 g
s
.64948 .63566 m .6513 .64041 L p .64956 .62464 L .707 .577 .707 r
F P
0 g
s
.65202 .63155 m .64555 .66729 L .64822 .67834 L p .707 .577 .707 r
F P
0 g
s
.65202 .63155 m .65918 .62232 L p .64934 .65476 L .707 .577 .707 r
F P
0 g
s
.64555 .66729 m .64941 .64598 L p .64934 .65476 L .707 .577 .707 r
F P
0 g
s
.64941 .64598 m .65202 .63155 L p .64934 .65476 L .707 .577 .707 r
F P
0 g
s
.6443 .57709 m .64844 .63295 L .64948 .63566 L p .707 .577 .707 r
F P
0 g
s
.64956 .62464 m .6443 .57709 L .64948 .63566 L .707 .577 .707 r
F
.84766 .56621 m .8518 .62207 L .84894 .61461 L p F P
0 g
s
.84894 .61461 m .84481 .55875 L .84766 .56621 L p .707 .577 .707 r
F P
0 g
s
.81041 .77082 m .80262 .78665 L .81852 .78134 L p .707 .577 .707 r
F P
0 g
s
.81852 .78134 m .82632 .7655 L .81041 .77082 L p .707 .577 .707 r
F P
0 g
s
.6418 .70205 m .64959 .68621 L .64804 .67171 L p .707 .577 .707 r
F P
0 g
s
.64844 .63295 m .6443 .57709 L .6514 .5691 L p .707 .577 .707 r
F P
0 g
s
.64804 .67171 m .64025 .68755 L .6418 .70205 L p .707 .577 .707 r
F P
0 g
s
.85293 .66881 m .84645 .70455 L .84378 .6935 L p .707 .577 .707 r
F P
0 g
s
.84378 .6935 m .85026 .65775 L .85293 .66881 L p .707 .577 .707 r
F P
0 g
s
.82632 .7655 m .81852 .78134 L .82607 .77092 L p .707 .577 .707 r
F P
0 g
s
.82607 .77092 m .83386 .75509 L .82632 .7655 L p .707 .577 .707 r
F P
0 g
s
.6514 .5691 m .65554 .62496 L .64844 .63295 L p .707 .577 .707 r
F P
0 g
s
.84481 .55875 m .84894 .61461 L .83641 .60842 L p .707 .577 .707 r
F P
0 g
s
.83641 .60842 m .83228 .55256 L .84481 .55875 L p .707 .577 .707 r
F P
0 g
s
.66776 .56136 m .67006 .59254 L p .65554 .62496 L .707 .577 .707 r
F P
0 g
s
.65271 .65806 m .65918 .62232 L .67547 .61581 L p .707 .577 .707 r
F P
0 g
s
.67006 .59254 m .67189 .61722 L .66101 .62237 L p .707 .577 .707 r
F P
0 g
s
.65918 .62232 m .65646 .63736 L p .64555 .66729 L .707 .577 .707 r
F P
0 g
s
.66101 .62237 m .65554 .62496 L p .67006 .59254 L .707 .577 .707 r
F P
0 g
s
.65646 .63736 m .65271 .65806 L .64854 .66343 L p .707 .577 .707 r
F P
0 g
s
.64854 .66343 m .64555 .66729 L p .65646 .63736 L .707 .577 .707 r
F P
0 g
s
.64025 .68755 m .64804 .67171 L .65559 .6613 L p .707 .577 .707 r
F P
0 g
s
.40025 .62286 m .39611 .567 L .36503 .56746 L p .707 .577 .707 r
F P
0 g
s
.39611 .567 m .40025 .62286 L .43201 .61995 L p .707 .577 .707 r
F P
0 g
s
.43201 .61995 m .42787 .56409 L .39611 .567 L p .707 .577 .707 r
F P
0 g
s
.46133 .61489 m .45719 .55903 L .42787 .56409 L p .707 .577 .707 r
F P
0 g
s
.65554 .62496 m .6514 .5691 L .66776 .56136 L p .707 .577 .707 r
F P
0 g
s
.65559 .6613 m .6478 .67713 L .64025 .68755 L p .707 .577 .707 r
F P
0 g
s
.36916 .62332 m .36503 .56746 L .33766 .56542 L p .707 .577 .707 r
F P
0 g
s
.36503 .56746 m .36916 .62332 L .40025 .62286 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.85026 .65775 m .84378 .6935 L .83154 .6817 L p .707 .577 .707 r
F P
0 g
s
.83154 .6817 m .83801 .64596 L .85026 .65775 L p .707 .577 .707 r
F P
0 g
s
.45719 .55903 m .46133 .61489 L .48534 .60815 L p .707 .577 .707 r
F P
0 g
s
.48534 .60815 m .4812 .55229 L .45719 .55903 L p .707 .577 .707 r
F P
0 g
s
.83386 .75509 m .82607 .77092 L .82453 .75642 L p .707 .577 .707 r
F P
0 g
s
.82453 .75642 m .83232 .74059 L .83386 .75509 L p .707 .577 .707 r
F P
0 g
s
.83228 .55256 m .83641 .60842 L .81544 .60409 L p .707 .577 .707 r
F P
0 g
s
.81544 .60409 m .8113 .54823 L .83228 .55256 L p .707 .577 .707 r
F P
0 g
s
.33766 .56542 m .34179 .62128 L .36916 .62332 L p .707 .577 .707 r
F P
0 g
s
.39573 .69166 m .40221 .65591 L .37152 .64855 L p .707 .577 .707 r
F P
0 g
s
.40221 .65591 m .39573 .69166 L .42713 .69581 L p .707 .577 .707 r
F P
0 g
s
.34179 .62128 m .33766 .56542 L .31668 .56109 L p .707 .577 .707 r
F P
0 g
s
.6478 .67713 m .65559 .6613 L .67149 .65598 L p .707 .577 .707 r
F P
0 g
s
.36504 .6843 m .37152 .64855 L .34455 .6387 L p .707 .577 .707 r
F P
0 g
s
.37152 .64855 m .36504 .6843 L .39573 .69166 L p .707 .577 .707 r
F P
0 g
s
.69177 .55463 m .69421 .58764 L p .67189 .61722 L .707 .577 .707 r
F P
0 g
s
.69421 .58764 m .69591 .61049 L .68061 .61477 L p .707 .577 .707 r
F P
0 g
s
.67547 .61581 m .67286 .63025 L p .65271 .65806 L .707 .577 .707 r
F P
0 g
s
.669 .65156 m .67547 .61581 L .6993 .61267 L p .707 .577 .707 r
F P
0 g
s
.68061 .61477 m .67189 .61722 L p .69421 .58764 L .707 .577 .707 r
F P
0 g
s
.67286 .63025 m .669 .65156 L .66048 .65496 L p .707 .577 .707 r
F P
0 g
s
.66048 .65496 m .65271 .65806 L p .67286 .63025 L .707 .577 .707 r
F P
0 g
s
.67189 .61722 m .66776 .56136 L .69177 .55463 L p .707 .577 .707 r
F P
0 g
s
.4812 .55229 m .48534 .60815 L .50169 .60041 L p .707 .577 .707 r
F P
0 g
s
.50169 .60041 m .49756 .54455 L .4812 .55229 L p .707 .577 .707 r
F P
0 g
s
.67149 .65598 m .6637 .67182 L .6478 .67713 L p .707 .577 .707 r
F P
0 g
s
.31668 .56109 m .32082 .61696 L .34179 .62128 L p .707 .577 .707 r
F P
0 g
s
.83801 .64596 m .83154 .6817 L .81092 .67032 L p .707 .577 .707 r
F P
0 g
s
.81092 .67032 m .81739 .63458 L .83801 .64596 L p .707 .577 .707 r
F P
0 g
s
.8113 .54823 m .81544 .60409 L .78807 .60206 L p .707 .577 .707 r
F P
0 g
s
.78807 .60206 m .78393 .5462 L .8113 .54823 L p .707 .577 .707 r
F P
0 g
s
.46264 .6606 m .45616 .69634 L .47999 .6932 L p .707 .577 .707 r
F P
0 g
s
.47999 .6932 m .48647 .65746 L .46264 .6606 L p .707 .577 .707 r
F P
0 g
s
.34455 .6387 m .33807 .67444 L .36504 .6843 L p .707 .577 .707 r
F P
0 g
s
.33807 .67444 m .34455 .6387 L .32393 .62731 L p .707 .577 .707 r
F P
0 g
s
.83232 .74059 m .82453 .75642 L .81404 .73927 L p .707 .577 .707 r
F P
0 g
s
.81404 .73927 m .82183 .72343 L .83232 .74059 L p .707 .577 .707 r
F P
0 g
s
.38044 .73551 m .38823 .71968 L .36 .70482 L p .707 .577 .707 r
F P
0 g
s
.38823 .71968 m .38044 .73551 L .40963 .74642 L p .707 .577 .707 r
F P
0 g
s
.40963 .74642 m .41742 .73058 L .38823 .71968 L p .707 .577 .707 r
F P
0 g
s
.32082 .61696 m .31668 .56109 L .30415 .5549 L p .707 .577 .707 r
F P
0 g
s
.35221 .72066 m .36 .70482 L .33548 .68747 L p .707 .577 .707 r
F P
0 g
s
.36 .70482 m .35221 .72066 L .38044 .73551 L p .707 .577 .707 r
F P
0 g
s
.69591 .61049 m .69177 .55463 L .72109 .54956 L p .707 .577 .707 r
F P
0 g
s
.41742 .73058 m .40963 .74642 L .43691 .75232 L p .707 .577 .707 r
F P
0 g
s
.43691 .75232 m .4447 .73648 L .41742 .73058 L p .707 .577 .707 r
F P
0 g
s
.32393 .62731 m .31745 .66306 L .33807 .67444 L p .707 .577 .707 r
F P
0 g
s
.6993 .61267 m .69283 .64842 L .669 .65156 L p .707 .577 .707 r
F P
0 g
s
.6637 .67182 m .67149 .65598 L .6942 .65629 L p .707 .577 .707 r
F P
0 g
s
.33548 .68747 m .32768 .70331 L .35221 .72066 L p .707 .577 .707 r
F P
0 g
s
.78393 .5462 m .78807 .60206 L .75698 .60251 L p .707 .577 .707 r
F P
0 g
s
.75698 .60251 m .75284 .54665 L .78393 .5462 L p .707 .577 .707 r
F P
0 g
s
.32768 .70331 m .33548 .68747 L .31707 .66933 L p .707 .577 .707 r
F P
0 g
s
.49756 .54455 m .50169 .60041 L .50879 .59242 L p .707 .577 .707 r
F P
0 g
s
.50879 .59242 m .50465 .53656 L .49756 .54455 L p .707 .577 .707 r
F P
0 g
s
.48647 .65746 m .47999 .6932 L .49628 .6867 L p .707 .577 .707 r
F P
0 g
s
.49628 .6867 m .50276 .65096 L .48647 .65746 L p .707 .577 .707 r
F P
0 g
s
.81739 .63458 m .81092 .67032 L .78395 .66047 L p .707 .577 .707 r
F P
0 g
s
.78395 .66047 m .79042 .62472 L .81739 .63458 L p .707 .577 .707 r
F P
0 g
s
.72523 .60542 m .72109 .54956 L .75284 .54665 L p .707 .577 .707 r
F P
0 g
s
.72109 .54956 m .72523 .60542 L .69591 .61049 L p .707 .577 .707 r
F P
0 g
s
.30415 .5549 m .30829 .61076 L .31366 .61341 L p .707 .577 .707 r
F P
0 g
s
.31168 .61552 m .30901 .60447 L p .30624 .63861 L .707 .577 .707 r
F P
0 g
s
.30521 .65126 m .30952 .62745 L p .30624 .63861 L .707 .577 .707 r
F P
0 g
s
.30952 .62745 m .31168 .61552 L p .30624 .63861 L .707 .577 .707 r
F P
0 g
s
.31366 .61341 m .32082 .61696 L p .3169 .60239 L .707 .577 .707 r
F P
0 g
s
.3169 .60239 m .30415 .5549 L .31366 .61341 L .707 .577 .707 r
F
.6942 .65629 m .68641 .67212 L .6637 .67182 L p F P
0 g
s
.69283 .64842 m .6993 .61267 L .72834 .61321 L p .707 .577 .707 r
F P
0 g
s
.31745 .66306 m .32393 .62731 L .31168 .61552 L p .707 .577 .707 r
F P
0 g
s
.75284 .54665 m .75698 .60251 L .72523 .60542 L p .707 .577 .707 r
F P
0 g
s
.31707 .66933 m .30928 .68517 L .32768 .70331 L p .707 .577 .707 r
F P
0 g
s
.82183 .72343 m .81404 .73927 L .79563 .72113 L p .707 .577 .707 r
F P
0 g
s
.79563 .72113 m .80342 .70529 L .82183 .72343 L p .707 .577 .707 r
F P
0 g
s
.4447 .73648 m .43691 .75232 L .45961 .75262 L p .707 .577 .707 r
F P
0 g
s
.45961 .75262 m .4674 .73678 L .4447 .73648 L p .707 .577 .707 r
F P
0 g
s
.79042 .62472 m .78395 .66047 L .75326 .6531 L p .707 .577 .707 r
F P
0 g
s
.75326 .6531 m .75974 .61736 L .79042 .62472 L p .707 .577 .707 r
F P
0 g
s
.72834 .61321 m .72186 .64895 L .69283 .64842 L p .707 .577 .707 r
F P
0 g
s
.31168 .61552 m .30521 .65126 L .3072 .65319 L p .707 .577 .707 r
F P
0 g
s
.30829 .61076 m .30415 .5549 L .30129 .54744 L p .707 .577 .707 r
F P
0 g
s
.30129 .54744 m .30543 .6033 L .30661 .60639 L p .707 .577 .707 r
F P
0 g
s
.30661 .60639 m .30829 .61076 L p .30668 .59625 L .707 .577 .707 r
F P
0 g
s
.30668 .59625 m .30129 .54744 L .30661 .60639 L .707 .577 .707 r
F
.30286 .64155 m .30521 .65126 L p .30682 .63149 L F P
0 g
s
.30658 .65218 m .30503 .63768 L p .29991 .66257 L .707 .577 .707 r
F P
0 g
s
.31503 .64312 m .31168 .61552 L .3072 .65319 L .707 .577 .707 r
F
.30503 .63768 m .29724 .65352 L .29879 .66801 L p F P
0 g
s
.30503 .63768 m .31258 .62726 L p .30005 .64871 L .707 .577 .707 r
F P
0 g
s
.29724 .65352 m .30181 .64424 L p .30005 .64871 L .707 .577 .707 r
F P
0 g
s
.30181 .64424 m .30503 .63768 L p .30005 .64871 L .707 .577 .707 r
F P
0 g
s
.30901 .60447 m .30254 .64021 L .30286 .64155 L p .707 .577 .707 r
F P
0 g
s
.30682 .63149 m .30901 .60447 L .30286 .64155 L .707 .577 .707 r
F
.30647 .62724 m .30901 .60447 L .30741 .62412 L F
.30901 .60447 m .31617 .59524 L p .30741 .62412 L F P
0 g
s
.30254 .64021 m .30653 .61816 L p .30647 .62724 L .707 .577 .707 r
F P
0 g
s
.30653 .61816 m .30901 .60447 L p .30647 .62724 L .707 .577 .707 r
F P
0 g
s
.29879 .66801 m .30415 .65712 L p .29991 .66257 L .707 .577 .707 r
F P
0 g
s
.30415 .65712 m .30658 .65218 L p .29991 .66257 L .707 .577 .707 r
F P
0 g
s
.3072 .65319 m .31745 .66306 L p .31503 .64312 L .707 .577 .707 r
F P
0 g
s
.72186 .64895 m .72834 .61321 L .75974 .61736 L p .707 .577 .707 r
F P
0 g
s
.68641 .67212 m .6942 .65629 L .72148 .66218 L p .707 .577 .707 r
F P
0 g
s
.30928 .68517 m .31707 .66933 L .30658 .65218 L p .707 .577 .707 r
F P
0 g
s
.75974 .61736 m .75326 .6531 L .72186 .64895 L p .707 .577 .707 r
F P
0 g
s
.72148 .66218 m .71369 .67802 L .68641 .67212 L p .707 .577 .707 r
F P
0 g
s
.30658 .65218 m .29879 .66801 L .30928 .68517 L p .707 .577 .707 r
F P
0 g
s
.80342 .70529 m .79563 .72113 L .77111 .70378 L p .707 .577 .707 r
F P
0 g
s
.77111 .70378 m .7789 .68794 L .80342 .70529 L p .707 .577 .707 r
F P
0 g
s
.50276 .65096 m .49628 .6867 L .50344 .67747 L p .707 .577 .707 r
F P
0 g
s
.50344 .67747 m .50992 .64173 L .50276 .65096 L p .707 .577 .707 r
F P
0 g
s
.50465 .53656 m .50879 .59242 L .50593 .58496 L p .707 .577 .707 r
F P
0 g
s
.50593 .58496 m .5018 .5291 L .50465 .53656 L p .707 .577 .707 r
F P
0 g
s
.4674 .73678 m .45961 .75262 L .47551 .7473 L p .707 .577 .707 r
F P
0 g
s
.47551 .7473 m .48331 .73147 L .4674 .73678 L p .707 .577 .707 r
F P
0 g
s
.71369 .67802 m .72148 .66218 L .75066 .67309 L p .707 .577 .707 r
F P
0 g
s
.7789 .68794 m .77111 .70378 L .74287 .68893 L p .707 .577 .707 r
F P
0 g
s
.74287 .68893 m .75066 .67309 L .7789 .68794 L p .707 .577 .707 r
F P
0 g
s
.75066 .67309 m .74287 .68893 L .71369 .67802 L p .707 .577 .707 r
F P
0 g
s
.30543 .6033 m .30129 .54744 L .30839 .53945 L p .707 .577 .707 r
F P
0 g
s
.50992 .64173 m .50344 .67747 L .50077 .66642 L p .707 .577 .707 r
F P
0 g
s
.50077 .66642 m .50725 .63067 L .50992 .64173 L p .707 .577 .707 r
F P
0 g
s
.48331 .73147 m .47551 .7473 L .48306 .73689 L p .707 .577 .707 r
F P
0 g
s
.48306 .73689 m .49085 .72105 L .48331 .73147 L p .707 .577 .707 r
F P
0 g
s
.30839 .53945 m .31253 .59531 L .30543 .6033 L p .707 .577 .707 r
F P
0 g
s
.5018 .5291 m .50593 .58496 L .4934 .57877 L p .707 .577 .707 r
F P
0 g
s
.4934 .57877 m .48927 .52291 L .5018 .5291 L p .707 .577 .707 r
F P
0 g
s
.31617 .59524 m .3097 .63098 L .30254 .64021 L p .707 .577 .707 r
F P
0 g
s
.31253 .59531 m .30839 .53945 L .32475 .53171 L p .707 .577 .707 r
F P
0 g
s
.33246 .58873 m .33159 .59355 L p .3097 .63098 L .707 .577 .707 r
F P
0 g
s
.30479 .6431 m .31258 .62726 L .32848 .62195 L p .707 .577 .707 r
F P
0 g
s
.32848 .62195 m .32526 .6285 L p .30479 .6431 L .707 .577 .707 r
F P
0 g
s
.32526 .6285 m .32069 .63778 L .31646 .6392 L p .707 .577 .707 r
F P
0 g
s
.31646 .6392 m .30479 .6431 L p .32526 .6285 L .707 .577 .707 r
F P
0 g
s
.35629 .58559 m .35509 .59223 L p .32599 .62448 L .707 .577 .707 r
F P
0 g
s
.32069 .63778 m .32848 .62195 L .35119 .62225 L p .707 .577 .707 r
F P
0 g
s
.35509 .59223 m .34982 .62134 L .32888 .6241 L p .707 .577 .707 r
F P
0 g
s
.32888 .6241 m .32599 .62448 L p .35509 .59223 L .707 .577 .707 r
F P
0 g
s
.33159 .59355 m .32599 .62448 L .31131 .63034 L p .707 .577 .707 r
F P
0 g
s
.31258 .62726 m .30908 .63438 L p .29724 .65352 L .707 .577 .707 r
F P
0 g
s
.31131 .63034 m .3097 .63098 L p .33159 .59355 L .707 .577 .707 r
F P
0 g
s
.30908 .63438 m .30479 .6431 L .30263 .64609 L p .707 .577 .707 r
F P
0 g
s
.30263 .64609 m .29724 .65352 L p .30908 .63438 L .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50725 .63067 m .50077 .66642 L .48853 .65462 L p .707 .577 .707 r
F P
0 g
s
.48853 .65462 m .495 .61888 L .50725 .63067 L p .707 .577 .707 r
F P
0 g
s
.49085 .72105 m .48306 .73689 L .48152 .72239 L p .707 .577 .707 r
F P
0 g
s
.48152 .72239 m .48931 .70656 L .49085 .72105 L p .707 .577 .707 r
F P
0 g
s
.3097 .63098 m .31617 .59524 L .33246 .58873 L p .707 .577 .707 r
F P
0 g
s
.48927 .52291 m .4934 .57877 L .47243 .57444 L p .707 .577 .707 r
F P
0 g
s
.47243 .57444 m .46829 .51858 L .48927 .52291 L p .707 .577 .707 r
F P
0 g
s
.32475 .53171 m .32888 .58757 L .31253 .59531 L p .707 .577 .707 r
F P
0 g
s
.32888 .58757 m .32475 .53171 L .34876 .52497 L p .707 .577 .707 r
F P
0 g
s
.46829 .51858 m .47243 .57444 L .44506 .57241 L p .707 .577 .707 r
F P
0 g
s
.44506 .57241 m .44092 .51654 L .46829 .51858 L p .707 .577 .707 r
F P
0 g
s
.495 .61888 m .48853 .65462 L .46791 .64324 L p .707 .577 .707 r
F P
0 g
s
.46791 .64324 m .47438 .6075 L .495 .61888 L p .707 .577 .707 r
F P
0 g
s
.48931 .70656 m .48152 .72239 L .47103 .70523 L p .707 .577 .707 r
F P
0 g
s
.47103 .70523 m .47882 .6894 L .48931 .70656 L p .707 .577 .707 r
F P
0 g
s
.32599 .62448 m .33246 .58873 L .35629 .58559 L p .707 .577 .707 r
F P
0 g
s
.34876 .52497 m .3529 .58084 L .32888 .58757 L p .707 .577 .707 r
F P
0 g
s
.3529 .58084 m .34876 .52497 L .37808 .51991 L p .707 .577 .707 r
F P
0 g
s
.44092 .51654 m .44506 .57241 L .41397 .57286 L p .707 .577 .707 r
F P
0 g
s
.41397 .57286 m .40983 .517 L .44092 .51654 L p .707 .577 .707 r
F P
0 g
s
.35119 .62225 m .3434 .63809 L .32069 .63778 L p .707 .577 .707 r
F P
0 g
s
.38222 .57577 m .37808 .51991 L .40983 .517 L p .707 .577 .707 r
F P
0 g
s
.37808 .51991 m .38222 .57577 L .3529 .58084 L p .707 .577 .707 r
F P
0 g
s
.47438 .6075 m .46791 .64324 L .44094 .63339 L p .707 .577 .707 r
F P
0 g
s
.44094 .63339 m .44741 .59764 L .47438 .6075 L p .707 .577 .707 r
F P
0 g
s
.34982 .62134 m .35629 .58559 L .38533 .58613 L p .707 .577 .707 r
F P
0 g
s
.40983 .517 m .41397 .57286 L .38222 .57577 L p .707 .577 .707 r
F P
0 g
s
.47882 .6894 m .47103 .70523 L .45262 .68709 L p .707 .577 .707 r
F P
0 g
s
.45262 .68709 m .46041 .67126 L .47882 .6894 L p .707 .577 .707 r
F P
0 g
s
.3434 .63809 m .35119 .62225 L .37847 .62815 L p .707 .577 .707 r
F P
0 g
s
.44741 .59764 m .44094 .63339 L .41025 .62602 L p .707 .577 .707 r
F P
0 g
s
.41025 .62602 m .41672 .59028 L .44741 .59764 L p .707 .577 .707 r
F P
0 g
s
.38533 .58613 m .37885 .62187 L .34982 .62134 L p .707 .577 .707 r
F P
0 g
s
.37885 .62187 m .38533 .58613 L .41672 .59028 L p .707 .577 .707 r
F P
0 g
s
.41672 .59028 m .41025 .62602 L .37885 .62187 L p .707 .577 .707 r
F P
0 g
s
.37847 .62815 m .37068 .64398 L .3434 .63809 L p .707 .577 .707 r
F P
0 g
s
.46041 .67126 m .45262 .68709 L .4281 .66975 L p .707 .577 .707 r
F P
0 g
s
.4281 .66975 m .43589 .65391 L .46041 .67126 L p .707 .577 .707 r
F P
0 g
s
.37068 .64398 m .37847 .62815 L .40765 .63906 L p .707 .577 .707 r
F P
0 g
s
.43589 .65391 m .4281 .66975 L .39986 .65489 L p .707 .577 .707 r
F P
0 g
s
.39986 .65489 m .40765 .63906 L .43589 .65391 L p .707 .577 .707 r
F P
0 g
s
.40765 .63906 m .39986 .65489 L .37068 .64398 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@001EYF00<005YFFUH02EYF00@005YFFUIJEPH0081oo`00M7oo1@000UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF1P00NWoo001aOol30007FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001dOol006moo`<000UJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP<0075oo`00KGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF0`00Kgoo001[
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP02001]Ool006Yoo`8000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
Ool005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF009JEP8006]oo`00JGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH015YF0P00JGoo001XOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF0`00
Igoo001XOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00IGoo001XOol01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0HWoo001XOol01000FUIJEP0015YF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0HWoo001XOol01000FUIJEP0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00Hgoo001XOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YF
FUH025YF00=oo`00FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00Hgoo001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001ROol006Qoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00069oo`00
J7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001WOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001WOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF0000HWoo001WOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<007ooOol0H7oo001WOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<007ooOol0H7oo001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00@005YFFUH0069oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEUYF06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF
06=oo`00Igoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06=oo`00
Igoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06=oo`00Igoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF06=oo`00Igoo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000AJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006=oo`00Igoo00@005YFFUH000AJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006=oo`00Igoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000Hgoo001WOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Moo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=o
o`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0006=oo`00IWoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF001SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIJEP1TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Io
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001J
EUYF0004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`04001JEUYF0004FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000I7oo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIJEP1UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF000035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP0015YF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP0015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol01000FUIJEP0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFOol0IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP0800000eYF001JEP0;FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006Aoo`04001JEUYF
0002FUH?0004FUH01000FUIJEUYF1`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol00`00FUH0000300000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol0069oo`@000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@000eJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00GWoo100000=JEP00FUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Fgoo0`001EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000aJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00FGoo0P0000=J
EP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001GOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00
EGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P006goo5`00=Goo001EOol00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000COol80004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000bOol005Eoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
000=Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
000_Ool005Eoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20009Ool400000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002000/Ool005Eoo`03001JEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00007Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;7oo001EOol00`00FUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001Goo0`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00EGoo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P002UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002aoo`00EGoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP03001JEUYF0080
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP05001JEUYFFUH0000/Ool005Eoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60008FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP02000:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002Ool20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000;7oo001FOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP040005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH50002FUH2000:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01`00FUH007oo001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0
000/Ool005Ioo`03001JEP0000AJEP03001JEUYF00=JEPD000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH4000:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01`00FUH007oo001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000[Ool005Io
o`03001JEP0000AJEP03001JEP00018000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP<000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEP00Ool005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P00:goo001FOol00`00FUH00003FUH60003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80008FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30009FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH007oo001JEP0000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000[Ool005Ioo`04001JEP00FUH300000eYF001JEP04FUH20007FUH00`00
FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00009FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH007oo001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP05001JEUYFFUH0000[Ool005Ioo`03001JEP00008000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@00003FUH005YF00EJEP03001JEUYF009JEP80
00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP07001JEP00Ool005YF000015YF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002]oo`00EWoo10000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000000IJEP04001JEUYFFUH2000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUIJEP0002]oo`00EWoo0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001JEP00008000aJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`04001JEUYF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF0004FUH01@00FUIJEUYF0000:goo001GOol00`00
FUH00003FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000015YF000000000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000Woo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEP03001J
EUYF00EJEP03001JEUYF00=JEP<00003FUH005YF009JEP03001oogoo02Uoo`00BGoo3`0000=JEP00
FUH00UYF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000goo
00<005YF00000eYF00<005YFFUH00eYF1P0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YF00000P000UYF0P00:Woo0011Ool80004FUH00`00FUIJEP06FUH30004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0goo00<005YF00000eYF00<005YF00004P0025YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF
FUIJEP@002Yoo`00>goo1P000eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=oo`03
001JEP00009JEPH000=JEP03001JEUYF00IJEP04001JEUYFFUH700000eYF001JEP06FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEP8002Yoo`00=goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000eYF00<005YFFUH00UYF3@001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
0goo00<005YF00000`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
10001UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000:Woo000dOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003FUH50002FUH00`00FUH0000<0002
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003Ool01000FUH000000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P00:goo000bOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH01000FUH005YF0`001EYF00<005YFFUH015YF10001EYF1@001UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`@000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEP00008000IJEP03001JEUYF009JEP8002]oo`00<7oo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00@005YF000000IJEP03001JEP0000<0009JEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=oo`<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH30004FUH01000FUIJEUYF0P00;7oo000_Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0003Ool30003FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH20002FUH01000FUH00000;Woo000^Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000:0007FUH00`00FUIJEP05FUH20000
0eYF001JEP08FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000400000eYF001JEP03FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH5000`Ool0
02ioo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00MJEP<000YJ
EP03001JEUYF00<000EJEP04001JEUYFFUH20009FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00002FUH200000eYF001JEP02FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02000`Ool002ioo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP04001JEUYFFUH60007FUH01000FUIJEUYF0P0025YF00<005YFFUH00eYF00<0
05YFFUH00UYF00@005YFFUIJEP8000UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8002ioo`00;Woo00<005YF0000
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0000=JEP00
FUH00UYF00<005YFFUH00eYF00<005YFFUH015YF1@001EYF00<005YFFUH00eYF0P001UYF00<005YF
FUH015YF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000UYF00@005YFFUH000=JEP04001JEUYFFUH@0004FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP0400000eYF001JEP07FUH20004FUH00`00FUIJEP06FUH20004FUH20008
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUH00003FUHK0006
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000]Ool002ioo`03001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP07001JEP00FUH005YF00001EYF00<0
05YFFUH01UYF00<005YFFUH015YF0P002EYF0`000UYF00<005YFFUH015YF100015YF0P0025YF00<0
05YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00@005YF001JEP`0009JEP03001o
ogoo00aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000/Ool002ioo`03001J
EP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP80009J
EP<000EJEP03001JEUYF00EJEP03001JEUYF00MJEP8000IJEP06001JEUYFFUH005YF1`000eYF0P00
0UYF0P002EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00P005YF0000
05YF001JEP001UYF00<005YF00000`004Goo10001eYF00<005YFFUH00eYF00D005YFFUIJEP0002]o
o`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP<000=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000004FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUH000030009FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20003FUH500000eYF001JEP05FUH00`00FUIJEP04FUH4000AOol20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo000^Ool01000FUIJEP0015YF00<005YFFUH015YF
00<005YFFUH015YF3`0000=JEP00FUH00eYF10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000=JEP00FUH01EYF0P0000=JEP00FUH015YF00<005YFFUH00UYF0P002EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH00P004Goo0`0000=JEP00FUH01EYF00@005YFFUIJEP8002Yo
o`00;goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH010001EYF00<005YFFUH01UYF00@0
05YFFUH000AJEP800005FUH00000FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20008FUH0
0`00FUIJEP04FUH01000FUIJEUYF0`002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00eYF0`00
4Goo0P001UYF00H005YFFUH005YF000ZOol002moo`03001JEP0000AJEP03001JEUYF00=JEPD000QJ
EP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUH00003FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH20006FUH20005FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00`000AJEP03001JEUYF00IJEP80015oo`8000=J
EP07001JEUYFFUH005YF0000:Woo000_Ool00`00FUH00004FUH00`00FUH0000A0008FUH01`00FUIJ
EUYF001JEP0000=JEP03001JEUYF00=JEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EP0000AJEP04001JEUYF0004FUH01`00FUIJEUYF001JEP0000UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000=JEP@00003FUH005YF00AJEP03001JEUYF009JEPD000QJEP04001J
EP00000AOol200000eYF001JEP02FUH00`00FUH0000ZOol002moo`03001JEP0000=JEPH000=JEP03
001JEUYF00EJEP03001JEUYF00@000EJEP07001JEUYFFUH005YF000015YF00D005YFFUIJEP00009J
EP800003FUH005YF00IJEP<000QJEP04001JEUYF0003FUH01@00FUIJEUYF00000eYF00@005YFFUIJ
EP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@0009JEP03001J
EUYF00=JEP03001JEUYF00IJEP@000EJEP04001JEUYFFUH2000AOol20003FUH2000[Ool002moo`04
001JEP00FUH300000eYF001JEP04FUH20007FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP04FUH0
1000FUIJEP000UYF00<005YF00000`0015YF1@001UYF00<005YFFUH00UYF0`001EYF00@005YFFUH0
00=JEP8000YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP06001JEP00
001JEP001UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00EJEP8000aoo`H0009JEP80
02]oo`00;goo00<005YF00000P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH010000UYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH00eYF2@001UYF00<0
05YFFUH015YF00<005YFFUH015YF0P000eYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP@000IJEP03001JEUYF00EJEP03001JEUYF00EJEP8000QJ
EP`000=JEP07001JEP00FUH005YF0000:goo000_Ool40003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40005FUH30002FUH00`00FUIJEP03FUH01000FUIJEUYF
1`0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000P0035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00/005YF001JEP00FUH005YF001JEP0000IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP<000MJEP<000AJEP03001JEUYF00AJEP03001JEUYF00800003FUH007oo02Yo
o`00;goo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEP0000=JEP07001JEUYFFUH005YF00001EYF00<005YFFUH00UYF0`000UYF2`00
0UYF0P0015YF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00000P0000=JEP00FUH01@000eYF00<005YFFUH01UYF00<005YFFUH01EYF
00D005YFFUIJEP0000EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUH0000[Ool0031oo`03001JEP0000=JEP03001JEUYF00=JEP8000MJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEUYF0002FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH50002FUH01000FUIJEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00H005YF000005YF0003FUH01000FUH005YF0P0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF009JEP80
02aoo`00<7oo00<005YF00000eYF00<005YFFUH00eYF0P001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P001UYF0P0015YF00<005YFFUH01eYF00<005YFFUH02EYF00L005YFFUIJ
EP00FUH00003FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH00000FUH000=JEP03001JEP0000=JEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP<0
00IJEP<000EJEP03001JEUYF009JEP8002aoo`00<7oo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH01UYF00D005YFFUIJ
EP0000UJEP03001JEUYF00QJEP03001JEUYF00=JEP03001JEUYF00=JEP8000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH01000FUIJEUYF0P001UYF0P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00L005YFFUIJEP00
FUH0000/Ool0031oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000EJEP06001JEP00001JEP0025YF00<005YFFUH02EYF00<005YF
FUH015YF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
0005FUH005YFFUH00002FUH00`00FUH00007FUH400000eYF001JEP07FUH00`00FUIJEP06FUH30006
FUH20004FUH01000FUIJEUYF0P00;Goo000`Ool00eYF001JEP02FUH00`00FUIJEP02FUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH01000FUIJEUYF0P0025YF00<0
05YFFUH02EYF00<005YFFUH015YF00@005YFFUIJEP8000eJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEPH00004FUH005YF0002FUH00`00FUIJEP04FUH01000FUIJEUYF0`001UYF00<0
05YFFUH01eYF00@005YFFUH000AJEP04001JEUYF0002FUH01000FUIJEUYF0P00;Woo000_Ool00`00
FUH00003FUHD0004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000030006FUH20006FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH01@00FUH005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0015YF0`0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000
0`000UYF0`001UYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP04001JEP00FUH2000`Ool002mo
o`04001JEP00FUH30005FUH00`00FUIJEP02FUH60003Ool70006FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH01UYF0`000eYF00<005YFFUH02EYF00<005YFFUH01EYF00D005YF001JEP00
00aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEUYF009JEP8000Aoo`L000AJEP03001JEUYF00=JEP<000EJEP<0039oo`00
;goo10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00@005YF000000Qoo`@0009JEP03001JEUYF
00EJEP04001JEUYF0003FUH20007FUH01P00FUH00000FUH000]JEP03001JEUYF00IJEP04001JEUYF
000<FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH20005FUH01@00FUIJ
EUYF00000eYF0P001Woo1@0000=oo`0000002`001UYF00<007ooOol0<Goo000_Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30009Ool40006FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP06FUH01000FUH0000035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00@005YFFUH000=JEP07001JEP00001JEP00
FUH00P0027oo1@003Woo00<005YFFUH00eYF0P00<Woo000_Ool200000eYF000000080007FUH00`00
FUIJEP05FUH2000;Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05
FUH30007FUH00`00FUIJEP06FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P001EYF00D005YFFUIJEP00009JEP04001JEUYFFUH3000;Ool3000@Ool01`00FUIJ
EUYF001JEP00039oo`00;Woo00L005YF000007ooFUH00005FUH00`00FUH000030002FUH00`00FUIJ
EP07FUH3000;Ool300000eYF001JEP03FUH00`00FUIJEP03FUH40009FUH00`00FUH000030003FUH0
0`00FUIJEP05FUH300000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP02FUH20005FUH2000OOol01000FUIJEP000UYF00<007ooOol0;goo000^
Ool20002FUH00gooFUH00005FUH01000FUIJEUYF1P001eYF00D005YFFUIJEP0000eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00AJEP/00005FUH00000FUH0000<FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH00`00FUIJEP04
FUH3000NOol20003FUH00`00Oomoo`0_Ool002ioo`03001JEP0000=JEP03001JEUYF00=JEP03001J
EUYF00AJEPD000EJEP03001JEUYF009JEP8000eoo`80009JEP03001JEUYF00=JEP03001JEUYF009J
EP8000EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH:0006FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP04FUH20006FUH2000NOol00`00FUIJ
EP02FUH00`00Oomoo`0^Ool002eoo`800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00@00003FUH005YF00IJEP8000aoo`04001JEUYF0005FUH00`00FUIJEP0700000eYF
001JEP07FUH00`00FUIJEP03FUH01000FUIJEUYF0P002EYF20002EYF00<005YFFUH01EYF00<005YF
FUH00eYF0P0015YF00<005YFFUH01UYF0P0015YF00@005YF000001ioo`05001JEUYFFUH0000`Ool0
02eoo`07001oo`00FUH005YF00001EYF00<005YFFUH01UYF00<005YFFUH015YF0P002EYF00<007oo
Ool02Goo00@005YFFUH000EJEP<000=JEP04001JEUYFFUH50004FUH00`00FUIJEP04FUH00`00FUIJ
EP02000<FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP06FUH00`00FUH00003FUH01000FUIJEUYF0P0077oo00<005YFFUH00P00<7oo000]Ool01000
Ool005YF0`001EYF00<005YFFUH01EYF00<005YFFUH01eYF0P001UYF00<005YF00000P0027oo00@0
05YFFUH000=JEP8000IJEP03001JEUYF00IJEPL000=JEP06001JEP00001JEP002UYF00<005YF0000
2EYF100000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF00000Woo10001eYF00<005YFFUH00`00
1UYF0P006goo00D005YF001JEP0002moo`00;Goo0P000eYF0P001EYF00<005YFFUH01EYF00<005YF
FUH01eYF00@005YF000000AJEP04001JEUYFFUH:0002FUH00`00FUH000020003FUH01GooFUIJEUYF
00002UYF00<005YFFUH00UYF1@000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00`00
1UYF00<005YFFUH00UYF00<005YF00001Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF0`00
67oo0P000UYF00<007ooOol0;Goo000]Ool20003FUH01000Ool000000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF00D005YFFUIJEP0000=JEP03001JEUYF
0080009JEP05001JEUYFFUIoo`03FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP02FUH00`00FUH00008Ool300000eYF
001JEP05FUH20006FUH00`00FUIJEP03000FOol00`00FUH0000`Ool002eoo`03001JEUYF00=JEP03
001oogoo00800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP800003FUH0
05YF009JEP03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEP0000]oo`80
00IJEP04001JEP000004FUH00`00FUIJEP03FUH3000COol00`00FUH0000`Ool002ioo`07001JEUYF
FUH005YF00000goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001UYF00<005YFFUH00UYF
0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF0`0015YF0P003Woo0P0015YF00<005YFFUH00`0000=JEP00FUH025YF
0`0047oo0P00<Goo000^Ool01@00FUIJEUYF00000UYF00<007ooOol00goo0P000eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF000015YF00<005YF00000eYF0P0015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUH000=JEP80011oo`04001JEUYF0003FUH00`00FUH000030008FUH00`00FUIJEP04000:Ool4
000aOol002moo`03001JEP0000AJEP03001oogoo00Aoo`800003FUH005YF00IJEP<000QJEP04001J
EUYF0003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH00eYF00AooeYFFUH000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20000
15YF0000000047oo0`000eYF0P0017oo0P001EYF00<005YFFUH01EYF2P0000=JEP000000<Woo000_
Ool00`00FUH00005FUH00`00Oomoo`05Ool40004FUH50007FUH01000FUIJEUYF0`0015YF0`001EYF
00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP00000037oo1@000eYF0P001Woo0`000UYF00<0
05YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0003=oo`00<7oo00<005YFFUH01EYF00<007oo
Ool027oo2@001eYF00<005YFFUH00eYF00<005YFFUH015YF0P0015YF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0`000eYF30000eYF00L005YF001JEP00FUH00009Ool30007FUH00`00FUIJEP04FUH00`00
FUIJEP02000cOol0035oo`03001JEUYF00AJEP<000aoo`D000IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<000AJEP<000AJEP03001JEUYF
00AJEP03001JEUYF00800003FUH007oo00]oo`@0009JEP03001JEUYF00AJEP03001JEUYF008003Ao
o`00<Woo00<005YFFUH00UYF00D005YFFUIJEP0000aoo`<00003Ool000000080009JEP03001JEUYF
00EJEP8000AJEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEP05
001JEUYFFUH00003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00FUH0000@Ool<000fOol003=o
o`80009JEP03001JEUYF009JEP03001oogoo015oo`d0009JEP03001JEUYF00<00003FUH005YF00EJ
EP03Ool005YF00UJEP03001JEUYF00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP02
FUH2001COol003Eoo`8000IJEP8001ioo`03001JEP0000=JEP04001oo`000007FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH400000eYF001JEP05FUH30005FUH00`00FUIJEP02FUH2001COol003Ioo`03001JEUYF00IJEP03
001oogoo01aoo`03001JEUYF009JEP03001oogoo008000IJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP80009JEP8000QJ
EP03001JEUYF00=JEP03001JEUYF009JEP8005=oo`00=goo0P001UYF0`007Goo00<005YFFUH00UYF
00@007ooOomoo`<000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000IJEP8000AJEP04001JEUYF
FUH2001DOol003Uoo`03001JEUYF009JEP04001JEUYFFUH2000KOol01000FUIJEUYF0P001Woo0P00
00=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00eYF0P0015YF00@005YFFUH000AJEP04001JEUYF0002FUH00`00FUIJEP02FUH2001D
Ool003Yoo`05001JEUYFFUH00005FUH2000JOol01@00FUH005YF000027oo0`002EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000EJEP03001J
EUYF009JEP05001JEUYFFUH00003FUH00`00FUH00002FUH3001EOol003]oo`<000QJEP<001Moo`05
001JEP00FUH0000;Ool40005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUH000040004FUH00`00FUIJEP03FUH30005FUH4001HOol003eoo`03001JEUYF
00MJEP04001JEP00000FOol01000FUIJEP003goo100000=JEP00FUH02eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF200000=oo`0000002`001UYF00<007ooOol0F7oo000nOol20006
FUH00`00FUIJEP02FUH3000COol00`00FUH0000DOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP050003Ool5000>Ool00`00FUIJEP03FUH2001IOol0041oo`8000AJEP03001JEUYF
00EJEP<0011oo`03001JEP0001aoo`d000IJEP03001JEUYF00=JEPP000Qoo`D000moo`07001JEUYF
FUH005YF0000FGoo0012Ool200000eYF001JEP08FUH00`00FUH00003000;Ool3000ZOol<0004FUH0
0`00Oomoo`0:Ool3000AOol01000FUIJEP000UYF00<007ooOol0EWoo0014Ool30007FUH00`00FUIJ
EP04FUH;00000eYF0000000dOol00`00FUIJEP04FUH2000OOol20003FUH00`00Oomoo`1FOol004Mo
o`8000EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000fOol20006FUH00`00Oomo
o`0MOol00`00FUIJEP02FUH00`00Oomoo`1EOol004Uoo`<00003FUH005YF00MJEP03001JEUYF00=J
EP04001JEUYFFUH2000hOol00`00FUIJEP02FUH01000FUH000007Woo00D005YFFUIJEP0005Moo`00
C7oo0`001eYF00<005YFFUH00eYF00<005YFFUH00P00>Woo00D005YFFUIJEP0000=JEP8001aoo`03
001JEUYF008005Moo`00Cgoo10000UYF00<005YFFUH00eYF00@005YF000003eoo`<000IJEP8001]o
o`05001JEP00FUH0001FOol005=oo`X0045oo`03001JEUYF00IJEP<001Qoo`80009JEP03001oogoo
05Aoo`00Wgoo0P001UYF00<005YFFUH00`005Woo00<005YF0000Egoo002QOol20004FUH00`00FUIJ
EP03FUH3000COol00`00FUH0001GOol00:=oo`800003FUH005YF00QJEP<0011oo`8005Qoo`00YGoo
0P002EYF00<005YFFUH010002Woo1000F7oo002WOol20007FUH00`00FUIJEP04FUH:00000eYF0000
001IOol00:Uoo`8000AJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0001JOol00:]o
o`80009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008005Yoo`00[Goo1@0015YF00<0
05YFFUH015YF00<005YFFUH00P00Fgoo002bOol>001MOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58603 .75426 m .59016 .69929 L .55908 .69505 L p .707 .577 .707 r
F P
0 g
s
.59016 .69929 m .58603 .75426 L .61778 .75559 L p .707 .577 .707 r
F P
0 g
s
.61778 .75559 m .62192 .70062 L .59016 .69929 L p .707 .577 .707 r
F P
0 g
s
.62192 .70062 m .61778 .75559 L .6471 .75389 L p .707 .577 .707 r
F P
0 g
s
.6471 .75389 m .65124 .69892 L .62192 .70062 L p .707 .577 .707 r
F P
0 g
s
.55494 .75002 m .55908 .69505 L .53171 .68832 L p .707 .577 .707 r
F P
0 g
s
.55908 .69505 m .55494 .75002 L .58603 .75426 L p .707 .577 .707 r
F P
0 g
s
.65124 .69892 m .6471 .75389 L .67111 .74931 L p .707 .577 .707 r
F P
0 g
s
.67111 .74931 m .67525 .69434 L .65124 .69892 L p .707 .577 .707 r
F P
0 g
s
.52757 .74329 m .53171 .68832 L .51073 .67975 L p .707 .577 .707 r
F P
0 g
s
.53171 .68832 m .52757 .74329 L .55494 .75002 L p .707 .577 .707 r
F P
0 g
s
.58975 .80822 m .58327 .77108 L .55259 .77475 L p .707 .577 .707 r
F P
0 g
s
.58327 .77108 m .58975 .80822 L .62114 .80242 L p .707 .577 .707 r
F P
0 g
s
.62114 .80242 m .61467 .76528 L .58327 .77108 L p .707 .577 .707 r
F P
0 g
s
.61467 .76528 m .62114 .80242 L .65018 .79506 L p .707 .577 .707 r
F P
0 g
s
.65018 .79506 m .6437 .75792 L .61467 .76528 L p .707 .577 .707 r
F P
0 g
s
.55259 .77475 m .55906 .81189 L .58975 .80822 L p .707 .577 .707 r
F P
0 g
s
.55906 .81189 m .55259 .77475 L .52561 .77592 L p .707 .577 .707 r
F P
0 g
s
.60013 .83932 m .59234 .82181 L .56411 .83349 L p .707 .577 .707 r
F P
0 g
s
.59234 .82181 m .60013 .83932 L .62932 .82628 L p .707 .577 .707 r
F P
0 g
s
.62932 .82628 m .62153 .80878 L .59234 .82181 L p .707 .577 .707 r
F P
0 g
s
.62153 .80878 m .62932 .82628 L .6566 .81318 L p .707 .577 .707 r
F P
0 g
s
.6566 .81318 m .64881 .79567 L .62153 .80878 L p .707 .577 .707 r
F P
0 g
s
.56411 .83349 m .5719 .851 L .60013 .83932 L p .707 .577 .707 r
F P
0 g
s
.6437 .75792 m .65018 .79506 L .67401 .78685 L p .707 .577 .707 r
F P
0 g
s
.67401 .78685 m .66753 .74971 L .6437 .75792 L p .707 .577 .707 r
F P
0 g
s
.67525 .69434 m .67111 .74931 L .68747 .74232 L p .707 .577 .707 r
F P
0 g
s
.68747 .74232 m .69161 .68735 L .67525 .69434 L p .707 .577 .707 r
F P
0 g
s
.51073 .67975 m .50659 .73472 L .52757 .74329 L p .707 .577 .707 r
F P
0 g
s
.52561 .77592 m .53209 .81306 L .55906 .81189 L p .707 .577 .707 r
F P
0 g
s
.5719 .851 m .56411 .83349 L .53959 .84268 L p .707 .577 .707 r
F P
0 g
s
.50659 .73472 m .51073 .67975 L .4982 .67019 L p .707 .577 .707 r
F P
0 g
s
.64881 .79567 m .6566 .81318 L .6793 .80129 L p .707 .577 .707 r
F P
0 g
s
.6793 .80129 m .67151 .78378 L .64881 .79567 L p .707 .577 .707 r
F P
0 g
s
.53959 .84268 m .54738 .86019 L .5719 .851 L p .707 .577 .707 r
F P
0 g
s
.53209 .81306 m .52561 .77592 L .505 .77449 L p .707 .577 .707 r
F P
0 g
s
.66753 .74971 m .66841 .75471 L p .6903 .7786 L .707 .577 .707 r
F P
0 g
s
.68869 .77941 m .6903 .7786 L p .66841 .75471 L .707 .577 .707 r
F P
0 g
s
.6903 .7786 m .68383 .74146 L .66753 .74971 L p .707 .577 .707 r
F P
0 g
s
.68383 .74146 m .6903 .7786 L .69746 .77111 L p .707 .577 .707 r
F P
0 g
s
.68742 .77426 m .69092 .78213 L p .70275 .78555 L .707 .577 .707 r
F P
0 g
s
.69092 .78213 m .69521 .79177 L .69737 .78999 L p .707 .577 .707 r
F P
0 g
s
.69737 .78999 m .70275 .78555 L p .69092 .78213 L .707 .577 .707 r
F P
0 g
s
.66841 .75471 m .67401 .78685 L .68869 .77941 L p .707 .577 .707 r
F P
0 g
s
.505 .77449 m .51147 .81163 L .53209 .81306 L p .707 .577 .707 r
F P
0 g
s
.4982 .67019 m .49406 .72516 L .50659 .73472 L p .707 .577 .707 r
F P
0 g
s
.54738 .86019 m .53959 .84268 L .52118 .84849 L p .707 .577 .707 r
F P
0 g
s
.52118 .84849 m .52897 .86599 L .54738 .86019 L p .707 .577 .707 r
F P
0 g
s
.67151 .78378 m .6793 .80129 L .69521 .79177 L p .707 .577 .707 r
F P
0 g
s
.69521 .79177 m .68742 .77426 L .67151 .78378 L p .707 .577 .707 r
F P
0 g
s
.69161 .68735 m .68747 .74232 L .69457 .73358 L p .707 .577 .707 r
F P
0 g
s
.69457 .73358 m .6987 .67861 L .69161 .68735 L p .707 .577 .707 r
F P
0 g
s
.49406 .72516 m .4982 .67019 L .49534 .66057 L p .707 .577 .707 r
F P
0 g
s
.51147 .81163 m .505 .77449 L .49275 .77059 L p .707 .577 .707 r
F P
0 g
s
.49275 .77059 m .49923 .80773 L .51147 .81163 L p .707 .577 .707 r
F P
0 g
s
.69746 .77111 m .69099 .73398 L .68383 .74146 L p .707 .577 .707 r
F P
0 g
s
.52897 .86599 m .52118 .84849 L .51069 .85033 L p .707 .577 .707 r
F P
0 g
s
.51069 .85033 m .51848 .86783 L .52897 .86599 L p .707 .577 .707 r
F P
0 g
s
.49534 .66057 m .49121 .71555 L .49406 .72516 L p .707 .577 .707 r
F P
0 g
s
.70275 .78555 m .69496 .76805 L .68742 .77426 L p .707 .577 .707 r
F P
0 g
s
.6987 .67861 m .69457 .73358 L .69171 .72397 L p .707 .577 .707 r
F P
0 g
s
.69171 .72397 m .69585 .66899 L .6987 .67861 L p .707 .577 .707 r
F P
0 g
s
.49121 .71555 m .49534 .66057 L .50244 .65184 L p .707 .577 .707 r
F P
0 g
s
.50244 .65184 m .4983 .70681 L .49121 .71555 L p .707 .577 .707 r
F P
0 g
s
.4983 .70681 m .50244 .65184 L .5188 .64484 L p .707 .577 .707 r
F P
0 g
s
.5188 .64484 m .51466 .69981 L .4983 .70681 L p .707 .577 .707 r
F P
0 g
s
.50371 .79426 m .49724 .75713 L .51353 .74888 L p .707 .577 .707 r
F P
0 g
s
.51353 .74888 m .52001 .78601 L .50371 .79426 L p .707 .577 .707 r
F P
0 g
s
.50811 .82076 m .47951 .31668 L .43557 .31654 L p .707 .577 .707 r
F P
0 g
s
.51466 .69981 m .5188 .64484 L .54281 .64027 L p .707 .577 .707 r
F P
0 g
s
.54281 .64027 m .53867 .69524 L .51466 .69981 L p .707 .577 .707 r
F P
0 g
s
.52001 .78601 m .51353 .74888 L .53736 .74067 L p .707 .577 .707 r
F P
0 g
s
.53736 .74067 m .54384 .77781 L .52001 .78601 L p .707 .577 .707 r
F P
0 g
s
.54384 .77781 m .53736 .74067 L .5463 .7384 L p .707 .577 .707 r
F P
0 g
s
.54384 .77781 m .5458 .74637 L .55355 .75865 L .707 .577 .707 r
F
.5458 .74637 m .5463 .7384 L .54892 .74573 L F
.5458 .74637 m .54892 .74573 L .55355 .75865 L F
.53867 .69524 m .54281 .64027 L .56791 .63881 L p F P
0 g
s
.53867 .69524 m .56791 .63881 L .56464 .65125 L .707 .577 .707 r
F
.57213 .63856 m .56799 .69354 L .53867 .69524 L p F P
0 g
s
.52438 .31328 m .47951 .31668 L p .54152 .7392 L .707 .577 .707 r
F P
0 g
s
.56791 .63881 m .57213 .63856 L p .56464 .65125 L .707 .577 .707 r
F P
0 g
s
.56799 .69354 m .57213 .63856 L .60389 .6399 L p .707 .577 .707 r
F P
0 g
s
.60389 .6399 m .59975 .69487 L .56799 .69354 L p .707 .577 .707 r
F P
0 g
s
.58033 .7576 m .58069 .7357 L .59779 .72751 L .707 .577 .707 r
F
.56887 .73285 m .59779 .72751 L p .56788 .74183 L F P
0 g
s
.63497 .64414 m .63083 .69911 L .59975 .69487 L p .707 .577 .707 r
F P
0 g
s
.59975 .69487 m .60389 .6399 L .63497 .64414 L p .707 .577 .707 r
F P
0 g
s
.62848 .72384 m .63495 .76098 L .60427 .76464 L p .707 .577 .707 r
F P
0 g
s
.60427 .76464 m .59779 .72751 L .62848 .72384 L p .707 .577 .707 r
F P
0 g
s
.59779 .72751 m .60427 .76464 L .57287 .77044 L p .707 .577 .707 r
F P
0 g
s
.64 .78258 m .64779 .80009 L .61956 .81177 L p .707 .577 .707 r
F P
0 g
s
.61956 .81177 m .61177 .79427 L .64 .78258 L p .707 .577 .707 r
F P
0 g
s
.59037 .82481 m .58258 .8073 L .61177 .79427 L p .707 .577 .707 r
F P
0 g
s
.61177 .79427 m .61956 .81177 L .59037 .82481 L p .707 .577 .707 r
F P
0 g
s
.59442 .81077 m .62834 .80162 L p .58522 .46028 L .707 .577 .707 r
F P
0 g
s
.56581 .30669 m .58282 .6063 L p .58522 .46028 L .707 .577 .707 r
F P
0 g
s
.58282 .6063 m .59442 .81077 L p .58522 .46028 L .707 .577 .707 r
F P
0 g
s
.57287 .77044 m .56788 .74183 L p .58069 .7357 L .707 .577 .707 r
F P
0 g
s
.57287 .77044 m .58069 .7357 L .58033 .7576 L .707 .577 .707 r
F
.52438 .31328 m .54892 .74573 L p .56788 .74183 L F P
0 g
s
.57527 .67476 m .52438 .31328 L .56788 .74183 L .707 .577 .707 r
F
.56788 .74183 m .56639 .73331 L .56887 .73285 L p F P
0 g
s
.58424 .73847 m .57527 .67476 L .56788 .74183 L .707 .577 .707 r
F
.57287 .77044 m .55903 .77395 L p .56473 .74248 L F P
0 g
s
.56639 .73331 m .56788 .74183 L p .56473 .74248 L .707 .577 .707 r
F P
0 g
s
.56788 .74183 m .57287 .77044 L p .56473 .74248 L .707 .577 .707 r
F P
0 g
s
.55903 .77395 m .54384 .77781 L p .55355 .75865 L .707 .577 .707 r
F P
0 g
s
.55355 .75865 m .56639 .73331 L .55903 .77395 L .707 .577 .707 r
F
.55299 .81736 m .54892 .74573 L p .54152 .7392 L F P
0 g
s
.54892 .74573 m .5473 .71719 L p .54366 .73104 L .707 .577 .707 r
F P
0 g
s
.54892 .74573 m .54366 .73104 L .54152 .7392 L .707 .577 .707 r
F
.5473 .71719 m .52438 .31328 L p .54152 .7392 L F P
0 g
s
.56309 .83791 m .5553 .8204 L .58258 .8073 L p .707 .577 .707 r
F P
0 g
s
.58258 .8073 m .59037 .82481 L .56309 .83791 L p .707 .577 .707 r
F P
0 g
s
.55299 .81736 m .59442 .81077 L p .58424 .73847 L .707 .577 .707 r
F P
0 g
s
.5463 .7384 m .56639 .73331 L p .55355 .75865 L .707 .577 .707 r
F P
0 g
s
.54892 .74573 m .55299 .81736 L p .58424 .73847 L .707 .577 .707 r
F P
0 g
s
.50811 .82076 m .55299 .81736 L p .538 .71523 L .707 .577 .707 r
F P
0 g
s
.47951 .31668 m .49537 .5962 L p .538 .71523 L .707 .577 .707 r
F P
0 g
s
.49537 .5962 m .50811 .82076 L p .538 .71523 L .707 .577 .707 r
F P
0 g
s
.49923 .80773 m .49275 .77059 L .49008 .76461 L p .707 .577 .707 r
F P
0 g
s
.59442 .81077 m .56581 .30669 L .52438 .31328 L p .707 .577 .707 r
F P
0 g
s
.49008 .76461 m .49655 .80175 L .49923 .80773 L p .707 .577 .707 r
F P
0 g
s
.46417 .82062 m .43557 .31654 L .39688 .31289 L p .707 .577 .707 r
F P
0 g
s
.49655 .80175 m .49008 .76461 L .49724 .75713 L p .707 .577 .707 r
F P
0 g
s
.49724 .75713 m .50371 .79426 L .49655 .80175 L p .707 .577 .707 r
F P
0 g
s
.43557 .31654 m .46417 .82062 L .50811 .82076 L p .707 .577 .707 r
F P
0 g
s
.69099 .73398 m .69746 .77111 L .69479 .76513 L p .707 .577 .707 r
F P
0 g
s
.69479 .76513 m .68831 .728 L .69099 .73398 L p .707 .577 .707 r
F P
0 g
s
.51848 .86783 m .51069 .85033 L .50914 .84803 L p .707 .578 .707 r
F P
0 g
s
.50914 .84803 m .51693 .86554 L .51848 .86783 L p .707 .578 .707 r
F P
0 g
s
.69496 .76805 m .70275 .78555 L .70121 .78326 L p .707 .578 .707 r
F P
0 g
s
.70121 .78326 m .69342 .76575 L .69496 .76805 L p .707 .578 .707 r
F P
0 g
s
.62834 .80162 m .59974 .29754 L .56581 .30669 L p .707 .577 .707 r
F P
0 g
s
.69585 .66899 m .69171 .72397 L .67918 .71441 L p .707 .577 .707 r
F P
0 g
s
.67918 .71441 m .68332 .65943 L .69585 .66899 L p .707 .577 .707 r
F P
0 g
s
.24302 .71028 m .24715 .65531 L .21607 .65107 L p .707 .577 .707 r
F P
0 g
s
.24715 .65531 m .24302 .71028 L .27477 .71161 L p .707 .577 .707 r
F P
0 g
s
.27477 .71161 m .27891 .65664 L .24715 .65531 L p .707 .577 .707 r
F P
0 g
s
.27891 .65664 m .27477 .71161 L .30409 .70991 L p .707 .577 .707 r
F P
0 g
s
.30409 .70991 m .30823 .65494 L .27891 .65664 L p .707 .577 .707 r
F P
0 g
s
.42548 .81697 m .39688 .31289 L .36722 .30607 L p .707 .577 .707 r
F P
0 g
s
.39688 .31289 m .42548 .81697 L .46417 .82062 L p .707 .577 .707 r
F P
0 g
s
.21193 .70604 m .21607 .65107 L .1887 .64434 L p .707 .577 .707 r
F P
0 g
s
.21607 .65107 m .21193 .70604 L .24302 .71028 L p .707 .577 .707 r
F P
0 g
s
.68831 .728 m .69479 .76513 L .68254 .76123 L p .707 .577 .707 r
F P
0 g
s
.68254 .76123 m .67607 .7241 L .68831 .728 L p .707 .577 .707 r
F P
0 g
s
.30823 .65494 m .30409 .70991 L .32811 .70533 L p .707 .577 .707 r
F P
0 g
s
.32811 .70533 m .33224 .65036 L .30823 .65494 L p .707 .577 .707 r
F P
0 g
s
.51693 .86554 m .50914 .84803 L .51669 .84182 L p .707 .577 .707 r
F P
0 g
s
.66234 .65087 m .6582 .70584 L .63083 .69911 L p .707 .577 .707 r
F P
0 g
s
.63083 .69911 m .63497 .64414 L .66234 .65087 L p .707 .577 .707 r
F P
0 g
s
.65545 .72267 m .66193 .7598 L .63495 .76098 L p .707 .577 .707 r
F P
0 g
s
.63495 .76098 m .62848 .72384 L .65545 .72267 L p .707 .577 .707 r
F P
0 g
s
.64779 .80009 m .64 .78258 L .66452 .77339 L p .707 .577 .707 r
F P
0 g
s
.59974 .29754 m .62834 .80162 L .65144 .79082 L p .707 .577 .707 r
F P
0 g
s
.65144 .79082 m .62284 .28674 L .59974 .29754 L p .707 .577 .707 r
F P
0 g
s
.51669 .84182 m .52448 .85932 L .51693 .86554 L p .707 .577 .707 r
F P
0 g
s
.68332 .65943 m .67918 .71441 L .6582 .70584 L p .707 .577 .707 r
F P
0 g
s
.6582 .70584 m .66234 .65087 L .68332 .65943 L p .707 .577 .707 r
F P
0 g
s
.18456 .69931 m .1887 .64434 L .16772 .63577 L p .707 .577 .707 r
F P
0 g
s
.1887 .64434 m .18456 .69931 L .21193 .70604 L p .707 .577 .707 r
F P
0 g
s
.69342 .76575 m .70121 .78326 L .69072 .7851 L p .707 .577 .707 r
F P
0 g
s
.69072 .7851 m .68293 .76759 L .69342 .76575 L p .707 .577 .707 r
F P
0 g
s
.24674 .76167 m .24026 .72453 L .20958 .7282 L p .707 .577 .707 r
F P
0 g
s
.24026 .72453 m .24674 .76167 L .27814 .75587 L p .707 .577 .707 r
F P
0 g
s
.27814 .75587 m .27166 .71873 L .24026 .72453 L p .707 .577 .707 r
F P
0 g
s
.27166 .71873 m .27814 .75587 L .30717 .7485 L p .707 .577 .707 r
F P
0 g
s
.30717 .7485 m .30069 .71137 L .27166 .71873 L p .707 .577 .707 r
F P
0 g
s
.20958 .7282 m .21605 .76533 L .24674 .76167 L p .707 .577 .707 r
F P
0 g
s
.21605 .76533 m .20958 .7282 L .1826 .72937 L p .707 .577 .707 r
F P
0 g
s
.25712 .79972 m .24933 .78221 L .2211 .7939 L p .707 .577 .707 r
F P
0 g
s
.24933 .78221 m .25712 .79972 L .28631 .78669 L p .707 .577 .707 r
F P
0 g
s
.28631 .78669 m .27852 .76918 L .24933 .78221 L p .707 .577 .707 r
F P
0 g
s
.30069 .71137 m .30717 .7485 L .331 .7403 L p .707 .577 .707 r
F P
0 g
s
.331 .7403 m .32452 .70316 L .30069 .71137 L p .707 .577 .707 r
F P
0 g
s
.27852 .76918 m .28631 .78669 L .31359 .77358 L p .707 .577 .707 r
F P
0 g
s
.31359 .77358 m .3058 .75608 L .27852 .76918 L p .707 .577 .707 r
F P
0 g
s
.2211 .7939 m .22889 .8114 L .25712 .79972 L p .707 .577 .707 r
F P
0 g
s
.33224 .65036 m .32811 .70533 L .34446 .69834 L p .707 .577 .707 r
F P
0 g
s
.34446 .69834 m .3486 .64337 L .33224 .65036 L p .707 .577 .707 r
F P
0 g
s
.39582 .81015 m .36722 .30607 L .34949 .29676 L p .707 .577 .707 r
F P
0 g
s
.36722 .30607 m .39582 .81015 L .42548 .81697 L p .707 .577 .707 r
F P
0 g
s
.1826 .72937 m .18908 .76651 L .21605 .76533 L p .707 .577 .707 r
F P
0 g
s
.16772 .63577 m .16358 .69074 L .18456 .69931 L p .707 .577 .707 r
F P
0 g
s
.67607 .7241 m .68254 .76123 L .66193 .7598 L p .707 .577 .707 r
F P
0 g
s
.66193 .7598 m .65545 .72267 L .67607 .7241 L p .707 .577 .707 r
F P
0 g
s
.16358 .69074 m .16772 .63577 L .15519 .62621 L p .707 .577 .707 r
F P
0 g
s
.22889 .8114 m .2211 .7939 L .19658 .80309 L p .707 .577 .707 r
F P
0 g
s
.3058 .75608 m .31359 .77358 L .33629 .76169 L p .707 .577 .707 r
F P
0 g
s
.33629 .76169 m .3285 .74418 L .3058 .75608 L p .707 .577 .707 r
F P
0 g
s
.19658 .80309 m .20437 .8206 L .22889 .8114 L p .707 .577 .707 r
F P
0 g
s
.18908 .76651 m .1826 .72937 L .16199 .72794 L p .707 .577 .707 r
F P
0 g
s
.52448 .85932 m .51669 .84182 L .5326 .8323 L p .707 .577 .707 r
F P
0 g
s
.5326 .8323 m .54039 .8498 L .52448 .85932 L p .707 .577 .707 r
F P
0 g
s
.68293 .76759 m .69072 .7851 L .67231 .7909 L p .707 .577 .707 r
F P
0 g
s
.67231 .7909 m .66452 .77339 L .68293 .76759 L p .707 .577 .707 r
F P
0 g
s
.32452 .70316 m .331 .7403 L .34729 .73205 L p .707 .577 .707 r
F P
0 g
s
.34729 .73205 m .34082 .69491 L .32452 .70316 L p .707 .577 .707 r
F P
0 g
s
.16199 .72794 m .16846 .76508 L .18908 .76651 L p .707 .577 .707 r
F P
0 g
s
.66452 .77339 m .67231 .7909 L .64779 .80009 L p .707 .577 .707 r
F P
0 g
s
.62284 .28674 m .65144 .79082 L .66145 .77941 L p .707 .577 .707 r
F P
0 g
s
.66145 .77941 m .63285 .27533 L .62284 .28674 L p .707 .577 .707 r
F P
0 g
s
.15519 .62621 m .15105 .68118 L .16358 .69074 L p .707 .577 .707 r
F P
0 g
s
.20437 .8206 m .19658 .80309 L .17817 .80889 L p .707 .577 .707 r
F P
0 g
s
.3486 .64337 m .34446 .69834 L .35156 .6896 L p .707 .577 .707 r
F P
0 g
s
.35156 .6896 m .35569 .63463 L .3486 .64337 L p .707 .577 .707 r
F P
0 g
s
.17817 .80889 m .18596 .8264 L .20437 .8206 L p .707 .577 .707 r
F P
0 g
s
.3285 .74418 m .33629 .76169 L .3522 .75217 L p .707 .577 .707 r
F P
0 g
s
.3522 .75217 m .34441 .73466 L .3285 .74418 L p .707 .577 .707 r
F P
0 g
s
.15105 .68118 m .15519 .62621 L .15234 .61659 L p .707 .577 .707 r
F P
0 g
s
.16846 .76508 m .16199 .72794 L .14974 .72404 L p .707 .577 .707 r
F P
0 g
s
.54039 .8498 m .5326 .8323 L .5553 .8204 L p .707 .577 .707 r
F P
0 g
s
.5553 .8204 m .56309 .83791 L .54039 .8498 L p .707 .577 .707 r
F P
0 g
s
.3781 .80085 m .34949 .29676 L .34544 .28588 L p .707 .577 .707 r
F P
0 g
s
.34949 .29676 m .3781 .80085 L .39582 .81015 L p .707 .577 .707 r
F P
0 g
s
.14974 .72404 m .15622 .76118 L .16846 .76508 L p .707 .577 .707 r
F P
0 g
s
.34082 .69491 m .34729 .73205 L .35445 .72456 L p .707 .577 .707 r
F P
0 g
s
.35445 .72456 m .34798 .68743 L .34082 .69491 L p .707 .577 .707 r
F P
0 g
s
.18596 .8264 m .17817 .80889 L .16768 .81073 L p .707 .577 .707 r
F P
0 g
s
.15234 .61659 m .1482 .67157 L .15105 .68118 L p .707 .577 .707 r
F P
0 g
s
.16768 .81073 m .17547 .82824 L .18596 .8264 L p .707 .577 .707 r
F P
0 g
s
.34441 .73466 m .3522 .75217 L .35975 .74596 L p .707 .577 .707 r
F P
0 g
s
.35975 .74596 m .35196 .72845 L .34441 .73466 L p .707 .577 .707 r
F P
0 g
s
.35569 .63463 m .35156 .6896 L .3487 .67999 L p .707 .577 .707 r
F P
0 g
s
.3487 .67999 m .35284 .62501 L .35569 .63463 L p .707 .577 .707 r
F P
0 g
s
.63285 .27533 m .66145 .77941 L .65739 .76852 L p .707 .577 .707 r
F P
0 g
s
.63967 .75922 m .61001 .7524 L p .61037 .58244 L .707 .577 .707 r
F P
0 g
s
.6422 .68245 m .63373 .67976 L p .63523 .68601 L .707 .577 .707 r
F P
0 g
s
.6356 .68758 m .63967 .75922 L p .61037 .58244 L .707 .577 .707 r
F P
0 g
s
.64369 .69098 m .6422 .68245 L p .63371 .68679 L .707 .577 .707 r
F P
0 g
s
.61107 .25513 m .63398 .65904 L p .61037 .58244 L .707 .577 .707 r
F P
0 g
s
.63812 .68864 m .62879 .26444 L .64183 .6902 L .707 .577 .707 r
F
.61107 .25513 m .62879 .26444 L p .63812 .68864 L F P
0 g
s
.63967 .75922 m .6356 .68758 L p .63812 .68864 L .707 .577 .707 r
F P
0 g
s
.6356 .68758 m .61107 .25513 L p .63812 .68864 L .707 .577 .707 r
F P
0 g
s
.63967 .75922 m .63812 .68864 L .64183 .6902 L .707 .577 .707 r
F
.64579 .56406 m .65739 .76852 L .64253 .76072 L p F P
0 g
s
.64383 .68257 m .6422 .68245 L p .64379 .68472 L .707 .577 .707 r
F P
0 g
s
.65739 .76852 m .65183 .67046 L p .65367 .69362 L .707 .577 .707 r
F P
0 g
s
.6422 .68245 m .64868 .71959 L .66929 .72102 L p .707 .577 .707 r
F P
0 g
s
.64253 .76072 m .63967 .75922 L p .64579 .56406 L .707 .577 .707 r
F P
0 g
s
.63643 .71569 m .64868 .71959 L p .63371 .68679 L .707 .577 .707 r
F P
0 g
s
.62996 .67856 m .63121 .68574 L p .63371 .68679 L .707 .577 .707 r
F P
0 g
s
.63121 .68574 m .63643 .71569 L p .63371 .68679 L .707 .577 .707 r
F P
0 g
s
.63541 .57815 m .63127 .63313 L .63752 .63789 L p .707 .577 .707 r
F P
0 g
s
.62879 .26444 m .64579 .56406 L p .64183 .6902 L .707 .577 .707 r
F P
0 g
s
.63752 .63789 m .6438 .64269 L p .6407 .61886 L .707 .577 .707 r
F P
0 g
s
.6407 .61886 m .63541 .57815 L .63752 .63789 L .707 .577 .707 r
F
.63398 .65904 m .6356 .68758 L p .63184 .67189 L F P
0 g
s
.61037 .58244 m .63398 .65904 L .63184 .67189 L .707 .577 .707 r
F
.63371 .68679 m .63523 .68601 L .62996 .67856 L F
.63373 .67976 m .62996 .67856 L p .63523 .68601 L F P
0 g
s
.64868 .71959 m .64369 .69098 L p .63371 .68679 L .707 .577 .707 r
F P
0 g
s
.62879 .26444 m .63285 .27533 L p .65367 .69362 L .707 .577 .707 r
F P
0 g
s
.65183 .67046 m .62879 .26444 L p .65367 .69362 L .707 .577 .707 r
F P
0 g
s
.66929 .72102 m .66282 .68389 L .64383 .68257 L p .707 .577 .707 r
F P
0 g
s
.66929 .72102 m .64383 .68257 L .64379 .68472 L .707 .577 .707 r
F
.6438 .64269 m .64664 .60496 L p .63541 .57815 L F P
0 g
s
.64664 .60496 m .64793 .58771 L .6451 .58555 L p .707 .577 .707 r
F P
0 g
s
.6451 .58555 m .63541 .57815 L p .64664 .60496 L .707 .577 .707 r
F P
0 g
s
.15622 .76118 m .14974 .72404 L .14707 .71806 L p .707 .577 .707 r
F P
0 g
s
.1482 .67157 m .15234 .61659 L .15943 .60786 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.14707 .71806 m .15355 .7552 L .15622 .76118 L p .707 .577 .707 r
F P
0 g
s
.34798 .68743 m .35445 .72456 L .35178 .71858 L p .707 .577 .707 r
F P
0 g
s
.35178 .71858 m .3453 .68144 L .34798 .68743 L p .707 .577 .707 r
F P
0 g
s
.17547 .82824 m .16768 .81073 L .16613 .80843 L p .707 .578 .707 r
F P
0 g
s
.15943 .60786 m .1553 .66283 L .1482 .67157 L p .707 .577 .707 r
F P
0 g
s
.16613 .80843 m .17393 .82594 L .17547 .82824 L p .707 .578 .707 r
F P
0 g
s
.35196 .72845 m .35975 .74596 L .3582 .74366 L p .707 .578 .707 r
F P
0 g
s
.3582 .74366 m .35041 .72615 L .35196 .72845 L p .707 .578 .707 r
F P
0 g
s
.34544 .28588 m .37404 .78996 L .3781 .80085 L p .707 .577 .707 r
F P
0 g
s
.37404 .78996 m .34544 .28588 L .35545 .27447 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35284 .62501 m .3487 .67999 L .33617 .67043 L p .707 .577 .707 r
F P
0 g
s
.33617 .67043 m .34031 .61545 L .35284 .62501 L p .707 .577 .707 r
F P
0 g
s
.1553 .66283 m .15943 .60786 L .17579 .60086 L p .707 .577 .707 r
F P
0 g
s
.15355 .7552 m .14707 .71806 L .15423 .71058 L p .707 .577 .707 r
F P
0 g
s
.15423 .71058 m .1607 .74771 L .15355 .7552 L p .707 .577 .707 r
F P
0 g
s
.3453 .68144 m .35178 .71858 L .33953 .71468 L p .707 .577 .707 r
F P
0 g
s
.33953 .71468 m .33306 .67755 L .3453 .68144 L p .707 .577 .707 r
F P
0 g
s
.17579 .60086 m .17165 .65583 L .1553 .66283 L p .707 .577 .707 r
F P
0 g
s
.17393 .82594 m .16613 .80843 L .17368 .80222 L p .707 .577 .707 r
F P
0 g
s
.17368 .80222 m .18147 .81973 L .17393 .82594 L p .707 .577 .707 r
F P
0 g
s
.34031 .61545 m .33617 .67043 L .31519 .66186 L p .707 .577 .707 r
F P
0 g
s
.31519 .66186 m .31933 .60689 L .34031 .61545 L p .707 .577 .707 r
F P
0 g
s
.35041 .72615 m .3582 .74366 L .34771 .7455 L p .707 .577 .707 r
F P
0 g
s
.34771 .7455 m .33992 .72799 L .35041 .72615 L p .707 .577 .707 r
F P
0 g
s
.17165 .65583 m .17579 .60086 L .1998 .59629 L p .707 .577 .707 r
F P
0 g
s
.1607 .74771 m .15423 .71058 L .17052 .70233 L p .707 .577 .707 r
F P
0 g
s
.38405 .77855 m .35545 .27447 L .37855 .26367 L p .707 .577 .707 r
F P
0 g
s
.35545 .27447 m .38405 .77855 L .37404 .78996 L p .707 .577 .707 r
F P
0 g
s
.17052 .70233 m .177 .73946 L .1607 .74771 L p .707 .577 .707 r
F P
0 g
s
.33306 .67755 m .33953 .71468 L .31892 .71325 L p .707 .577 .707 r
F P
0 g
s
.31892 .71325 m .31244 .67611 L .33306 .67755 L p .707 .577 .707 r
F P
0 g
s
.31933 .60689 m .31519 .66186 L .28782 .65513 L p .707 .577 .707 r
F P
0 g
s
.28782 .65513 m .29196 .60016 L .31933 .60689 L p .707 .577 .707 r
F P
0 g
s
.1998 .59629 m .19566 .65126 L .17165 .65583 L p .707 .577 .707 r
F P
0 g
s
.19566 .65126 m .1998 .59629 L .22912 .59458 L p .707 .577 .707 r
F P
0 g
s
.18147 .81973 m .17368 .80222 L .18959 .7927 L p .707 .577 .707 r
F P
0 g
s
.18959 .7927 m .19738 .81021 L .18147 .81973 L p .707 .577 .707 r
F P
0 g
s
.33992 .72799 m .34771 .7455 L .3293 .7513 L p .707 .577 .707 r
F P
0 g
s
.3293 .7513 m .32151 .73379 L .33992 .72799 L p .707 .577 .707 r
F P
0 g
s
.61001 .7524 m .5814 .24832 L .61107 .25513 L p .707 .577 .707 r
F P
0 g
s
.177 .73946 m .17052 .70233 L .19435 .69412 L p .707 .577 .707 r
F P
0 g
s
.29196 .60016 m .28782 .65513 L .25674 .65089 L p .707 .577 .707 r
F P
0 g
s
.25674 .65089 m .26088 .59592 L .29196 .60016 L p .707 .577 .707 r
F P
0 g
s
.22498 .64956 m .22912 .59458 L .26088 .59592 L p .707 .577 .707 r
F P
0 g
s
.22912 .59458 m .22498 .64956 L .19566 .65126 L p .707 .577 .707 r
F P
0 g
s
.26088 .59592 m .25674 .65089 L .22498 .64956 L p .707 .577 .707 r
F P
0 g
s
.31244 .67611 m .31892 .71325 L .29194 .71442 L p .707 .577 .707 r
F P
0 g
s
.29194 .71442 m .28547 .67729 L .31244 .67611 L p .707 .577 .707 r
F P
0 g
s
.19435 .69412 m .20083 .73126 L .177 .73946 L p .707 .577 .707 r
F P
0 g
s
.72323 .66222 m .72737 .60725 L .69628 .60301 L p .707 .577 .707 r
F P
0 g
s
.72737 .60725 m .72323 .66222 L .75499 .66356 L p .707 .577 .707 r
F P
0 g
s
.75499 .66356 m .75912 .60858 L .72737 .60725 L p .707 .577 .707 r
F P
0 g
s
.37855 .26367 m .40715 .76775 L .38405 .77855 L p .707 .577 .707 r
F P
0 g
s
.40715 .76775 m .37855 .26367 L .41247 .25452 L p .707 .577 .707 r
F P
0 g
s
.75912 .60858 m .75499 .66356 L .78431 .66185 L p .707 .577 .707 r
F P
0 g
s
.78431 .66185 m .78844 .60688 L .75912 .60858 L p .707 .577 .707 r
F P
0 g
s
.19738 .81021 m .18959 .7927 L .21229 .78081 L p .707 .577 .707 r
F P
0 g
s
.69214 .65798 m .69628 .60301 L .66891 .59628 L p .707 .577 .707 r
F P
0 g
s
.69628 .60301 m .69214 .65798 L .72323 .66222 L p .707 .577 .707 r
F P
0 g
s
.21229 .78081 m .22008 .79831 L .19738 .81021 L p .707 .577 .707 r
F P
0 g
s
.32151 .73379 m .3293 .7513 L .30478 .76049 L p .707 .577 .707 r
F P
0 g
s
.30478 .76049 m .29699 .74299 L .32151 .73379 L p .707 .577 .707 r
F P
0 g
s
.20083 .73126 m .19435 .69412 L .22339 .68676 L p .707 .577 .707 r
F P
0 g
s
.28547 .67729 m .29194 .71442 L .26126 .71809 L p .707 .577 .707 r
F P
0 g
s
.26126 .71809 m .25478 .68096 L .28547 .67729 L p .707 .577 .707 r
F P
0 g
s
.22339 .68676 m .22986 .72389 L .20083 .73126 L p .707 .577 .707 r
F P
0 g
s
.78844 .60688 m .78431 .66185 L .80832 .65728 L p .707 .577 .707 r
F P
0 g
s
.80832 .65728 m .81246 .6023 L .78844 .60688 L p .707 .577 .707 r
F P
0 g
s
.5814 .24832 m .61001 .7524 L .57132 .74875 L p .707 .577 .707 r
F P
0 g
s
.57132 .74875 m .54271 .24467 L .5814 .24832 L p .707 .577 .707 r
F P
0 g
s
.22986 .72389 m .22339 .68676 L .25478 .68096 L p .707 .577 .707 r
F P
0 g
s
.25478 .68096 m .26126 .71809 L .22986 .72389 L p .707 .577 .707 r
F P
0 g
s
.66477 .65125 m .66891 .59628 L .64793 .58771 L p .707 .577 .707 r
F P
0 g
s
.66891 .59628 m .66477 .65125 L .69214 .65798 L p .707 .577 .707 r
F P
0 g
s
.72695 .71618 m .72048 .67905 L .68979 .68271 L p .707 .577 .707 r
F P
0 g
s
.72048 .67905 m .72695 .71618 L .75835 .71038 L p .707 .577 .707 r
F P
0 g
s
.75835 .71038 m .75187 .67325 L .72048 .67905 L p .707 .577 .707 r
F P
0 g
s
.75187 .67325 m .75835 .71038 L .78738 .70302 L p .707 .577 .707 r
F P
0 g
s
.78738 .70302 m .78091 .66588 L .75187 .67325 L p .707 .577 .707 r
F P
0 g
s
.22008 .79831 m .21229 .78081 L .23957 .7677 L p .707 .577 .707 r
F P
0 g
s
.29699 .74299 m .30478 .76049 L .27655 .77218 L p .707 .577 .707 r
F P
0 g
s
.27655 .77218 m .26876 .75467 L .29699 .74299 L p .707 .577 .707 r
F P
0 g
s
.23957 .7677 m .24736 .78521 L .22008 .79831 L p .707 .577 .707 r
F P
0 g
s
.44107 .7586 m .41247 .25452 L .4539 .24792 L p .707 .577 .707 r
F P
0 g
s
.41247 .25452 m .44107 .7586 L .40715 .76775 L p .707 .577 .707 r
F P
0 g
s
.68979 .68271 m .69627 .71985 L .72695 .71618 L p .707 .577 .707 r
F P
0 g
s
.69627 .71985 m .68979 .68271 L .66282 .68389 L p .707 .577 .707 r
F P
0 g
s
.73734 .74728 m .72955 .72977 L .70131 .74145 L p .707 .577 .707 r
F P
0 g
s
.72955 .72977 m .73734 .74728 L .76652 .73425 L p .707 .577 .707 r
F P
0 g
s
.76652 .73425 m .75873 .71674 L .72955 .72977 L p .707 .577 .707 r
F P
0 g
s
.75873 .71674 m .76652 .73425 L .7938 .72114 L p .707 .577 .707 r
F P
0 g
s
.7938 .72114 m .78601 .70363 L .75873 .71674 L p .707 .577 .707 r
F P
0 g
s
.70131 .74145 m .7091 .75896 L .73734 .74728 L p .707 .577 .707 r
F P
0 g
s
.24736 .78521 m .23957 .7677 L .26876 .75467 L p .707 .577 .707 r
F P
0 g
s
.78091 .66588 m .78738 .70302 L .81121 .69481 L p .707 .577 .707 r
F P
0 g
s
.81121 .69481 m .80474 .65767 L .78091 .66588 L p .707 .577 .707 r
F P
0 g
s
.26876 .75467 m .27655 .77218 L .24736 .78521 L p .707 .577 .707 r
F P
0 g
s
.81246 .6023 m .80832 .65728 L .82467 .65028 L p .707 .577 .707 r
F P
0 g
s
.82467 .65028 m .82881 .59531 L .81246 .6023 L p .707 .577 .707 r
F P
0 g
s
.64793 .58771 m .6438 .64269 L .66477 .65125 L p .707 .577 .707 r
F P
0 g
s
.66282 .68389 m .66929 .72102 L .69627 .71985 L p .707 .577 .707 r
F P
0 g
s
.54271 .24467 m .57132 .74875 L .52738 .74861 L p .707 .577 .707 r
F P
0 g
s
.52738 .74861 m .49878 .24453 L .54271 .24467 L p .707 .577 .707 r
F P
0 g
s
.7091 .75896 m .70131 .74145 L .67679 .75065 L p .707 .577 .707 r
F P
0 g
s
.78601 .70363 m .7938 .72114 L .81651 .70925 L p .707 .577 .707 r
F P
0 g
s
.81651 .70925 m .80872 .69174 L .78601 .70363 L p .707 .577 .707 r
F P
0 g
s
.67679 .75065 m .68458 .76815 L .7091 .75896 L p .707 .577 .707 r
F P
0 g
s
.4825 .75201 m .4539 .24792 L .49878 .24453 L p .707 .577 .707 r
F P
0 g
s
.4539 .24792 m .4825 .75201 L .44107 .7586 L p .707 .577 .707 r
F P
0 g
s
.49878 .24453 m .52738 .74861 L .4825 .75201 L p .707 .577 .707 r
F P
0 g
s
.80474 .65767 m .80561 .66267 L p .82751 .68656 L .707 .577 .707 r
F P
0 g
s
.82589 .68737 m .82751 .68656 L p .80561 .66267 L .707 .577 .707 r
F P
0 g
s
.82751 .68656 m .82103 .64942 L .80474 .65767 L p .707 .577 .707 r
F P
0 g
s
.82103 .64942 m .82751 .68656 L .83467 .67908 L p .707 .577 .707 r
F P
0 g
s
.82462 .68222 m .82812 .69009 L p .83996 .69352 L .707 .577 .707 r
F P
0 g
s
.82812 .69009 m .83241 .69973 L .83458 .69795 L p .707 .577 .707 r
F P
0 g
s
.83458 .69795 m .83996 .69352 L p .82812 .69009 L .707 .577 .707 r
F P
0 g
s
.80561 .66267 m .81121 .69481 L .82589 .68737 L p .707 .577 .707 r
F P
0 g
s
.68458 .76815 m .67679 .75065 L .65838 .75645 L p .707 .577 .707 r
F P
0 g
s
.65838 .75645 m .66618 .77396 L .68458 .76815 L p .707 .577 .707 r
F P
0 g
s
.80872 .69174 m .81651 .70925 L .83241 .69973 L p .707 .577 .707 r
F P
0 g
s
.83241 .69973 m .82462 .68222 L .80872 .69174 L p .707 .577 .707 r
F P
0 g
s
.82881 .59531 m .82467 .65028 L .83177 .64154 L p .707 .577 .707 r
F P
0 g
s
.83177 .64154 m .83591 .58657 L .82881 .59531 L p .707 .577 .707 r
F P
0 g
s
.63127 .63313 m .63541 .57815 L .63255 .56854 L p .707 .577 .707 r
F P
0 g
s
.83467 .67908 m .82819 .64194 L .82103 .64942 L p .707 .577 .707 r
F P
0 g
s
.66618 .77396 m .65838 .75645 L .64789 .75829 L p .707 .577 .707 r
F P
0 g
s
.64789 .75829 m .65569 .7758 L .66618 .77396 L p .707 .577 .707 r
F P
0 g
s
.63255 .56854 m .62841 .62351 L .63127 .63313 L p .707 .577 .707 r
F P
0 g
s
.83996 .69352 m .83217 .67601 L .82462 .68222 L p .707 .577 .707 r
F P
0 g
s
.83591 .58657 m .83177 .64154 L .82891 .63193 L p .707 .577 .707 r
F P
0 g
s
.82891 .63193 m .83305 .57695 L .83591 .58657 L p .707 .577 .707 r
F P
0 g
s
.63643 .71569 m .62996 .67856 L .62728 .67257 L p .707 .577 .707 r
F P
0 g
s
.62841 .62351 m .63255 .56854 L .63965 .5598 L p .707 .577 .707 r
F P
0 g
s
.62728 .67257 m .63376 .70971 L .63643 .71569 L p .707 .577 .707 r
F P
0 g
s
.82819 .64194 m .83467 .67908 L .83199 .67309 L p .707 .577 .707 r
F P
0 g
s
.83199 .67309 m .82552 .63596 L .82819 .64194 L p .707 .577 .707 r
F P
0 g
s
.65569 .7758 m .64789 .75829 L .64635 .75599 L p .707 .578 .707 r
F P
0 g
s
.64635 .75599 m .65414 .7735 L .65569 .7758 L p .707 .578 .707 r
F P
0 g
s
.63965 .5598 m .63551 .61477 L .62841 .62351 L p .707 .577 .707 r
F P
0 g
s
.83217 .67601 m .83996 .69352 L .83841 .69122 L p .707 .578 .707 r
F P
0 g
s
.83841 .69122 m .83062 .67371 L .83217 .67601 L p .707 .578 .707 r
F P
0 g
s
.83305 .57695 m .82891 .63193 L .81639 .62237 L p .707 .577 .707 r
F P
0 g
s
.81639 .62237 m .82052 .5674 L .83305 .57695 L p .707 .577 .707 r
F P
0 g
s
.38022 .61824 m .38436 .56327 L .35327 .55903 L p .707 .577 .707 r
F P
0 g
s
.38436 .56327 m .38022 .61824 L .41198 .61957 L p .707 .577 .707 r
F P
0 g
s
.41198 .61957 m .41611 .5646 L .38436 .56327 L p .707 .577 .707 r
F P
0 g
s
.63551 .61477 m .63965 .5598 L .656 .5528 L p .707 .577 .707 r
F P
0 g
s
.63376 .70971 m .62728 .67257 L .63444 .66509 L p .707 .577 .707 r
F P
0 g
s
.41611 .5646 m .41198 .61957 L .4413 .61787 L p .707 .577 .707 r
F P
0 g
s
.4413 .61787 m .44543 .5629 L .41611 .5646 L p .707 .577 .707 r
F P
0 g
s
.34913 .614 m .35327 .55903 L .3259 .5523 L p .707 .577 .707 r
F P
0 g
s
.35327 .55903 m .34913 .614 L .38022 .61824 L p .707 .577 .707 r
F P
0 g
s
.63444 .66509 m .64092 .70223 L .63376 .70971 L p .707 .577 .707 r
F P
0 g
s
.82552 .63596 m .83199 .67309 L .81975 .66919 L p .707 .577 .707 r
F P
0 g
s
.81975 .66919 m .81327 .63206 L .82552 .63596 L p .707 .577 .707 r
F P
0 g
s
.44543 .5629 m .4413 .61787 L .46531 .6133 L p .707 .577 .707 r
F P
0 g
s
.46531 .6133 m .46945 .55832 L .44543 .5629 L p .707 .577 .707 r
F P
0 g
s
.65414 .7735 m .64635 .75599 L .6539 .74978 L p .707 .577 .707 r
F P
0 g
s
.656 .5528 m .65186 .60778 L .63551 .61477 L p .707 .577 .707 r
F P
0 g
s
.6539 .74978 m .66169 .76729 L .65414 .7735 L p .707 .577 .707 r
F P
0 g
s
.82052 .5674 m .81639 .62237 L .79541 .6138 L p .707 .577 .707 r
F P
0 g
s
.79541 .6138 m .79955 .55883 L .82052 .5674 L p .707 .577 .707 r
F P
0 g
s
.32176 .60727 m .3259 .5523 L .30492 .54373 L p .707 .577 .707 r
F P
0 g
s
.3259 .5523 m .32176 .60727 L .34913 .614 L p .707 .577 .707 r
F P
0 g
s
.83062 .67371 m .83841 .69122 L .82792 .69306 L p .707 .577 .707 r
F P
0 g
s
.82792 .69306 m .82013 .67555 L .83062 .67371 L p .707 .577 .707 r
F P
0 g
s
.38394 .66963 m .37747 .63249 L .34678 .63616 L p .707 .577 .707 r
F P
0 g
s
.37747 .63249 m .38394 .66963 L .41534 .66383 L p .707 .577 .707 r
F P
0 g
s
.41534 .66383 m .40886 .62669 L .37747 .63249 L p .707 .577 .707 r
F P
0 g
s
.40886 .62669 m .41534 .66383 L .44437 .65647 L p .707 .577 .707 r
F P
0 g
s
.44437 .65647 m .4379 .61933 L .40886 .62669 L p .707 .577 .707 r
F P
0 g
s
.65186 .60778 m .656 .5528 L .68001 .54823 L p .707 .577 .707 r
F P
0 g
s
.34678 .63616 m .35326 .6733 L .38394 .66963 L p .707 .577 .707 r
F P
0 g
s
.35326 .6733 m .34678 .63616 L .31981 .63734 L p .707 .577 .707 r
F P
0 g
s
.64092 .70223 m .63444 .66509 L .65074 .65684 L p .707 .577 .707 r
F P
0 g
s
.39433 .70768 m .38654 .69017 L .3583 .70186 L p .707 .577 .707 r
F P
0 g
s
.38654 .69017 m .39433 .70768 L .42351 .69465 L p .707 .577 .707 r
F P
0 g
s
.42351 .69465 m .41572 .67714 L .38654 .69017 L p .707 .577 .707 r
F P
0 g
s
.4379 .61933 m .44437 .65647 L .4682 .64826 L p .707 .577 .707 r
F P
0 g
s
.4682 .64826 m .46173 .61112 L .4379 .61933 L p .707 .577 .707 r
F P
0 g
s
.41572 .67714 m .42351 .69465 L .45079 .68155 L p .707 .577 .707 r
F P
0 g
s
.45079 .68155 m .443 .66404 L .41572 .67714 L p .707 .577 .707 r
F P
0 g
s
.3583 .70186 m .36609 .71937 L .39433 .70768 L p .707 .577 .707 r
F P
0 g
s
.46945 .55832 m .46531 .6133 L .48166 .6063 L p .707 .577 .707 r
F P
0 g
s
.48166 .6063 m .4858 .55133 L .46945 .55832 L p .707 .577 .707 r
F P
0 g
s
.31981 .63734 m .32628 .67447 L .35326 .6733 L p .707 .577 .707 r
F P
0 g
s
.30492 .54373 m .30079 .5987 L .32176 .60727 L p .707 .577 .707 r
F P
0 g
s
.65074 .65684 m .65721 .69398 L .64092 .70223 L p .707 .577 .707 r
F P
0 g
s
.81327 .63206 m .81975 .66919 L .79913 .66776 L p .707 .577 .707 r
F P
0 g
s
.79913 .66776 m .79266 .63063 L .81327 .63206 L p .707 .577 .707 r
F P
0 g
s
.79955 .55883 m .79541 .6138 L .76804 .60707 L p .707 .577 .707 r
F P
0 g
s
.76804 .60707 m .77218 .5521 L .79955 .55883 L p .707 .577 .707 r
F P
0 g
s
.30079 .5987 m .30492 .54373 L .29239 .53417 L p .707 .577 .707 r
F P
0 g
s
.36609 .71937 m .3583 .70186 L .33378 .71105 L p .707 .577 .707 r
F P
0 g
s
.443 .66404 m .45079 .68155 L .4735 .66965 L p .707 .577 .707 r
F P
0 g
s
.4735 .66965 m .46571 .65214 L .443 .66404 L p .707 .577 .707 r
F P
0 g
s
.68001 .54823 m .67588 .6032 L .65186 .60778 L p .707 .577 .707 r
F P
0 g
s
.33378 .71105 m .34157 .72856 L .36609 .71937 L p .707 .577 .707 r
F P
0 g
s
.32628 .67447 m .31981 .63734 L .29919 .6359 L p .707 .577 .707 r
F P
0 g
s
.66169 .76729 m .6539 .74978 L .6698 .74026 L p .707 .577 .707 r
F P
0 g
s
.67588 .6032 m .68001 .54823 L .70933 .54653 L p .707 .577 .707 r
F P
0 g
s
.6698 .74026 m .67759 .75777 L .66169 .76729 L p .707 .577 .707 r
F P
0 g
s
.82013 .67555 m .82792 .69306 L .80952 .69886 L p .707 .577 .707 r
F P
0 g
s
.80952 .69886 m .80173 .68135 L .82013 .67555 L p .707 .577 .707 r
F P
0 g
s
.46173 .61112 m .4682 .64826 L .4845 .64001 L p .707 .577 .707 r
F P
0 g
s
.4845 .64001 m .47802 .60287 L .46173 .61112 L p .707 .577 .707 r
F P
0 g
s
.29919 .6359 m .30567 .67304 L .32628 .67447 L p .707 .577 .707 r
F P
0 g
s
.77218 .5521 m .76804 .60707 L .73695 .60283 L p .707 .577 .707 r
F P
0 g
s
.73695 .60283 m .74109 .54786 L .77218 .5521 L p .707 .577 .707 r
F P
0 g
s
.65721 .69398 m .65074 .65684 L .67456 .64863 L p .707 .577 .707 r
F P
0 g
s
.29239 .53417 m .28826 .58915 L .30079 .5987 L p .707 .577 .707 r
F P
0 g
s
.7052 .6015 m .70933 .54653 L .74109 .54786 L p .707 .577 .707 r
F P
0 g
s
.70933 .54653 m .7052 .6015 L .67588 .6032 L p .707 .577 .707 r
F P
0 g
s
.34157 .72856 m .33378 .71105 L .31537 .71685 L p .707 .577 .707 r
F P
0 g
s
.4858 .55133 m .48166 .6063 L .48876 .59756 L p .707 .577 .707 r
F P
0 g
s
.48876 .59756 m .4929 .54259 L .4858 .55133 L p .707 .577 .707 r
F P
0 g
s
.31537 .71685 m .32316 .73436 L .34157 .72856 L p .707 .577 .707 r
F P
0 g
s
.46571 .65214 m .4735 .66965 L .4894 .66013 L p .707 .577 .707 r
F P
0 g
s
.4894 .66013 m .48161 .64262 L .46571 .65214 L p .707 .577 .707 r
F P
0 g
s
.74109 .54786 m .73695 .60283 L .7052 .6015 L p .707 .577 .707 r
F P
0 g
s
.79266 .63063 m .79913 .66776 L .77216 .66894 L p .707 .577 .707 r
F P
0 g
s
.77216 .66894 m .76568 .6318 L .79266 .63063 L p .707 .577 .707 r
F P
0 g
s
.67456 .64863 m .68104 .68577 L .65721 .69398 L p .707 .577 .707 r
F P
0 g
s
.28826 .58915 m .29239 .53417 L .28954 .52456 L p .707 .577 .707 r
F P
0 g
s
.30567 .67304 m .29919 .6359 L .28695 .63201 L p .707 .577 .707 r
F P
0 g
s
.67759 .75777 m .6698 .74026 L .6925 .72836 L p .707 .577 .707 r
F P
0 g
s
.6925 .72836 m .70029 .74587 L .67759 .75777 L p .707 .577 .707 r
F P
0 g
s
.80173 .68135 m .80952 .69886 L .785 .70805 L p .707 .577 .707 r
F P
0 g
s
.785 .70805 m .77721 .69054 L .80173 .68135 L p .707 .577 .707 r
F P
0 g
s
.68104 .68577 m .67456 .64863 L .7036 .64127 L p .707 .577 .707 r
F P
0 g
s
.28695 .63201 m .29342 .66914 L .30567 .67304 L p .707 .577 .707 r
F P
0 g
s
.47802 .60287 m .4845 .64001 L .49166 .63252 L p .707 .577 .707 r
F P
0 g
s
.49166 .63252 m .48518 .59539 L .47802 .60287 L p .707 .577 .707 r
F P
0 g
s
.76568 .6318 m .77216 .66894 L .74147 .6726 L p .707 .577 .707 r
F P
0 g
s
.74147 .6726 m .735 .63547 L .76568 .6318 L p .707 .577 .707 r
F P
0 g
s
.7036 .64127 m .71008 .6784 L .68104 .68577 L p .707 .577 .707 r
F P
0 g
s
.32316 .73436 m .31537 .71685 L .30488 .71869 L p .707 .577 .707 r
F P
0 g
s
.28954 .52456 m .2854 .57953 L .28826 .58915 L p .707 .577 .707 r
F P
0 g
s
.30488 .71869 m .31267 .7362 L .32316 .73436 L p .707 .577 .707 r
F P
0 g
s
.71008 .6784 m .7036 .64127 L .735 .63547 L p .707 .577 .707 r
F P
0 g
s
.48161 .64262 m .4894 .66013 L .49695 .65392 L p .707 .577 .707 r
F P
0 g
s
.49695 .65392 m .48916 .63641 L .48161 .64262 L p .707 .577 .707 r
F P
0 g
s
.735 .63547 m .74147 .6726 L .71008 .6784 L p .707 .577 .707 r
F P
0 g
s
.4929 .54259 m .48876 .59756 L .4859 .58795 L p .707 .577 .707 r
F P
0 g
s
.4859 .58795 m .49004 .53297 L .4929 .54259 L p .707 .577 .707 r
F P
0 g
s
.70029 .74587 m .6925 .72836 L .71978 .71526 L p .707 .577 .707 r
F P
0 g
s
.77721 .69054 m .785 .70805 L .75676 .71974 L p .707 .577 .707 r
F P
0 g
s
.75676 .71974 m .74897 .70223 L .77721 .69054 L p .707 .577 .707 r
F P
0 g
s
.71978 .71526 m .72757 .73277 L .70029 .74587 L p .707 .577 .707 r
F P
0 g
s
.29342 .66914 m .28695 .63201 L .28427 .62602 L p .707 .577 .707 r
F P
0 g
s
.2854 .57953 m .28954 .52456 L .29664 .51582 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.72757 .73277 m .71978 .71526 L .74897 .70223 L p .707 .577 .707 r
F P
0 g
s
.74897 .70223 m .75676 .71974 L .72757 .73277 L p .707 .577 .707 r
F P
0 g
s
.28427 .62602 m .29075 .66316 L .29342 .66914 L p .707 .577 .707 r
F P
0 g
s
.48518 .59539 m .49166 .63252 L .48898 .62654 L p .707 .577 .707 r
F P
0 g
s
.48898 .62654 m .48251 .58941 L .48518 .59539 L p .707 .577 .707 r
F P
0 g
s
.31267 .7362 m .30488 .71869 L .30334 .71639 L p .707 .578 .707 r
F P
0 g
s
.29664 .51582 m .2925 .57079 L .2854 .57953 L p .707 .577 .707 r
F P
0 g
s
.30334 .71639 m .31113 .7339 L .31267 .7362 L p .707 .578 .707 r
F P
0 g
s
.48916 .63641 m .49695 .65392 L .4954 .65162 L p .707 .578 .707 r
F P
0 g
s
.4954 .65162 m .48761 .63411 L .48916 .63641 L p .707 .578 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49004 .53297 m .4859 .58795 L .47337 .57839 L p .707 .577 .707 r
F P
0 g
s
.47337 .57839 m .47751 .52341 L .49004 .53297 L p .707 .577 .707 r
F P
0 g
s
.2925 .57079 m .29664 .51582 L .31299 .50882 L p .707 .577 .707 r
F P
0 g
s
.29075 .66316 m .28427 .62602 L .29143 .61854 L p .707 .577 .707 r
F P
0 g
s
.29143 .61854 m .29791 .65567 L .29075 .66316 L p .707 .577 .707 r
F P
0 g
s
.48251 .58941 m .48898 .62654 L .47674 .62264 L p .707 .577 .707 r
F P
0 g
s
.47674 .62264 m .47026 .58551 L .48251 .58941 L p .707 .577 .707 r
F P
0 g
s
.31299 .50882 m .30885 .5638 L .2925 .57079 L p .707 .577 .707 r
F P
0 g
s
.31113 .7339 m .30334 .71639 L .31089 .71018 L p .707 .577 .707 r
F P
0 g
s
.31089 .71018 m .31868 .72769 L .31113 .7339 L p .707 .577 .707 r
F P
0 g
s
.47751 .52341 m .47337 .57839 L .4524 .56982 L p .707 .577 .707 r
F P
0 g
s
.4524 .56982 m .45654 .51485 L .47751 .52341 L p .707 .577 .707 r
F P
0 g
s
.48761 .63411 m .4954 .65162 L .48491 .65346 L p .707 .577 .707 r
F P
0 g
s
.48491 .65346 m .47712 .63595 L .48761 .63411 L p .707 .577 .707 r
F P
0 g
s
.30885 .5638 m .31299 .50882 L .337 .50425 L p .707 .577 .707 r
F P
0 g
s
.29791 .65567 m .29143 .61854 L .30772 .61029 L p .707 .577 .707 r
F P
0 g
s
.30772 .61029 m .3142 .64743 L .29791 .65567 L p .707 .577 .707 r
F P
0 g
s
.47026 .58551 m .47674 .62264 L .45612 .62121 L p .707 .577 .707 r
F P
0 g
s
.45612 .62121 m .44964 .58408 L .47026 .58551 L p .707 .577 .707 r
F P
0 g
s
.45654 .51485 m .4524 .56982 L .42503 .56309 L p .707 .577 .707 r
F P
0 g
s
.42503 .56309 m .42916 .50812 L .45654 .51485 L p .707 .577 .707 r
F P
0 g
s
.337 .50425 m .33287 .55922 L .30885 .5638 L p .707 .577 .707 r
F P
0 g
s
.33287 .55922 m .337 .50425 L .36632 .50254 L p .707 .577 .707 r
F P
0 g
s
.31868 .72769 m .31089 .71018 L .32679 .70066 L p .707 .577 .707 r
F P
0 g
s
.32679 .70066 m .33458 .71817 L .31868 .72769 L p .707 .577 .707 r
F P
0 g
s
.47712 .63595 m .48491 .65346 L .46651 .65926 L p .707 .577 .707 r
F P
0 g
s
.46651 .65926 m .45872 .64176 L .47712 .63595 L p .707 .577 .707 r
F P
0 g
s
.3142 .64743 m .30772 .61029 L .33155 .60208 L p .707 .577 .707 r
F P
0 g
s
.42916 .50812 m .42503 .56309 L .39394 .55885 L p .707 .577 .707 r
F P
0 g
s
.39394 .55885 m .39808 .50388 L .42916 .50812 L p .707 .577 .707 r
F P
0 g
s
.36219 .55752 m .36632 .50254 L .39808 .50388 L p .707 .577 .707 r
F P
0 g
s
.36632 .50254 m .36219 .55752 L .33287 .55922 L p .707 .577 .707 r
F P
0 g
s
.39808 .50388 m .39394 .55885 L .36219 .55752 L p .707 .577 .707 r
F P
0 g
s
.44964 .58408 m .45612 .62121 L .42915 .62239 L p .707 .577 .707 r
F P
0 g
s
.42915 .62239 m .42267 .58525 L .44964 .58408 L p .707 .577 .707 r
F P
0 g
s
.33155 .60208 m .33803 .63922 L .3142 .64743 L p .707 .577 .707 r
F P
0 g
s
.33458 .71817 m .32679 .70066 L .34949 .68877 L p .707 .577 .707 r
F P
0 g
s
.34949 .68877 m .35728 .70628 L .33458 .71817 L p .707 .577 .707 r
F P
0 g
s
.45872 .64176 m .46651 .65926 L .44199 .66845 L p .707 .577 .707 r
F P
0 g
s
.44199 .66845 m .43419 .65095 L .45872 .64176 L p .707 .577 .707 r
F P
0 g
s
.33803 .63922 m .33155 .60208 L .36059 .59472 L p .707 .577 .707 r
F P
0 g
s
.42267 .58525 m .42915 .62239 L .39846 .62605 L p .707 .577 .707 r
F P
0 g
s
.39846 .62605 m .39199 .58892 L .42267 .58525 L p .707 .577 .707 r
F P
0 g
s
.36059 .59472 m .36706 .63185 L .33803 .63922 L p .707 .577 .707 r
F P
0 g
s
.36706 .63185 m .36059 .59472 L .39199 .58892 L p .707 .577 .707 r
F P
0 g
s
.39199 .58892 m .39846 .62605 L .36706 .63185 L p .707 .577 .707 r
F P
0 g
s
.35728 .70628 m .34949 .68877 L .37677 .67566 L p .707 .577 .707 r
F P
0 g
s
.43419 .65095 m .44199 .66845 L .41375 .68014 L p .707 .577 .707 r
F P
0 g
s
.41375 .68014 m .40596 .66263 L .43419 .65095 L p .707 .577 .707 r
F P
0 g
s
.37677 .67566 m .38456 .69317 L .35728 .70628 L p .707 .577 .707 r
F P
0 g
s
.38456 .69317 m .37677 .67566 L .40596 .66263 L p .707 .577 .707 r
F P
0 g
s
.40596 .66263 m .41375 .68014 L .38456 .69317 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
R7oo6000OGoo001oOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Uoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1@00
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH3001]Ool006eoo`@000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008006]oo`00Jgoo0P0025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0J7oo001YOol30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1XOol006Moo`80009JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Uoo`00IGoo0P0015YF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00JGoo001TOol20005FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIoo`1XOol006=o
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Qoo`00HWoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJGoo001ROol01000FUIJEP001EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUIJEP00FUIYOol0069oo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EUYF001JEVUoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Moo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00D005YFFUIJ
EP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00D005YFFUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Qoo`00Hgoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP03001JEUYF009JEP03001JEWoo06Moo`00Hgoo00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP06001JEUYFFUH005YFJ7oo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUIJEP8006Qoo`00Hgoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo
06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Moo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Moo`00Hgoo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00AJEP03001JEUYF009JEP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EUYFFUH2001WOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P00Igoo001T
Ool01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP00
1EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0P00IWoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00D005YFFUIJEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Eoo`00I7oo2@000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001LOol80004FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`@000=JEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Ioo`<000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<000IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00E7oo0P00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF10000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IGoo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005=oo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
DWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IGoo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUH000001eYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001BOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00UYF0`00I7oo001BOol00`00FUH00002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00I7oo001BOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo
001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001BOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P001goo5@00B7oo001BOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP040014Ool0055oo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF009JEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEPD000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPH003ioo`00DGoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD003Uoo`00DGoo00<005YF00000eYF00@005YFFUIJEPP00004FUH005YF
FUH40004FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`00=goo001AOol00`00
FUH00003FUH400000eYF001JEP06FUH00`00FUIJEP04FUH?0006FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF000000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF008003Eoo`00DGoo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEPH0
00=JEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<goo001A
Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP05FUH4
0004FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF0P00<Woo001AOol20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF0000<Goo001AOol01@00FUIJEUYF00001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF0P00
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP00FUH00eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH0031oo`00DGoo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP00009JEP8000IJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYF000`Ool0055oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUHC000015YF000000001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;goo001AOol01@00FUIJEUYF
00001EYF00<005YFFUH01EYF00<005YFFUH01eYF1`0015YF00<005YFFUH015YF00<005YFFUH00eYF
00<005YF00000`001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00<005YFFUH00P00;goo001BOol01000FUIJEP001EYF00<005YFFUH01EYF00<005YF
FUH00eYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
00QJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008002moo`00=Goo6P0017oo0`001EYF00<005YFFUH01EYF00<005YF00000`001UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P0025YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02moo`00<Goo10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<0
05YFFUH00eYF100000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002moo`<000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000@00003FUH005YF00@000EJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0009FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP04FUH00`00FUH00004FUH01000FUIJEUYF6@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF100000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P0025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF00000eYF1@0000=JEP00FUH01EYF
00<005YFFUH00UYF2@000goo1P001UYF00<005YFFUH00eYF00H005YFFUH005YF000_Ool002aoo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH0
1000FUH005YF0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF3@000UYF00<0
05YFFUH00eYF00H005YFFUH005YF000_Ool002aoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP06001JEP00001JEP001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000QJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP06001JEP00001JEP001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF100015YF00<005YFFUH00P00<7oo
000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH015YF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00004FUH005YFFUH2000`Ool002]oo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEPH0
00=JEP04001JEUYF0008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH30002FUH2000`Ool002]oo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPP000IJEPD00003FUH0000000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00AJEP80009JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYF001JEP02000`Ool002]oo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0005FUH00`00FUIJEP05
FUH01000FUIJEUYF10001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P000UYF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP<0031oo`00:goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP`00003FUH005YF00MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP001UYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH015YF500000AJEP000000031oo`00:goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF
00EJEP03001JEUYF00@000AJEP03001JEUYF00D00003FUH005YF00MJEP03001JEUYF00AJEP03001J
EP0000D000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0006FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH80004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
0003000`Ool002]oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP@000QJEP03001JEUYF00D0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP800005FUH005YFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0031oo`00:goo0P000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00@005YFFUIJ
EP8000=JEP03001JEUYF00MJEP03001JEUYF00<000=JEP03001JEUYF00EJEP04001JEUYFFUH30004
FUH00`00FUIJEP020006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YF00000`001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFFUH00`00<7oo000ZOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH01000FUH000001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00H005YF000005YF0005FUH00`00FUIJEP020006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF100000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP00035oo`00:Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF200015YF
00<005YFFUH01UYF00@005YFFUH000=JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEUYF008000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00YJEP<00003FUH005YF00@000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000aOol002Yoo`03001JEP0000=JEP04001J
EUYFFUH>0002Ool90004FUH01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<005YFFUH00UYF1P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH02UYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00<7oo000ZOol00`00FUH00003FUH4
00000eYF001JEP06FUH00`00FUIJEP02FUH@0002FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH01P00FUH00000FUH000QJEP04001JEP000002FUH00`00FUH00007FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool002Yoo`04
001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH60003FUH01@00FUIJEUYF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0015YF00<005YF
FUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFFUH00P00<7oo000ZOol00`00FUH000020006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP020002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP02FUH20002FUH01000FUIJEUYF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P00<7oo000ZOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH000020004FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP040009FUH01000FUH000001EYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF1P000UYF00D005YFFUIJEP00031oo`00:Woo00D005YFFUIJ
EP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05FUH30007FUH00`00
FUH0000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUH000030002FUH0
0`00Oomoo`0^Ool002Yoo`05001JEUYFFUH00005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUHD0002FUH01000FUH000001EYF00<005YFFUH00eYF0P000eYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0eYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2P001EYF00<0
05YFFUH01EYF00<005YFFUH00UYF1000;goo000ZOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF4`0000AJEP00000000Aoo`03001JEP00008000QJEP03001J
EP00008000EJEP03001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH600000goo0000
00020002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH0000300000eYF0000000_Ool002Yo
o`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH70004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH00`00FUH000030004Ool200000eYF001JEP08FUH20009FUH20006FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=oo`00000010001UYF00<005YFFUH01UYF00@005YFFUIJEPD0
009JEP05001JEUYFFUH0000_Ool002]oo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000Ao
o`00000000AJEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP8000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000=JEP03001JEUYF00EJEP03
001JEP0000D000=JEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03
FUH01000FUIJEP00;goo000/Ool30005FUH00`00FUIJEP05FUH00`00FUH000030006FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP030007FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP04FUH00`00FUH00004FUH00`00FUIJEP03FUH300000eYF001JEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000^Ool20004FUH00`00
FUIJEP03FUH400000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH000020009FUH01000FUH000001eYF00<005YF00000P002eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH015YF00<005YF000015YF00<005YF00000`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00eYF00@005YF0000
02ioo`00<7oo0`0000=JEP00FUH010001EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF0`002EYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF00@005YFFUH000=JEP80
0003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF
00EJEP04001JEUYFFUH400000eYF001oo`0]Ool0039oo`@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP03FUH20002FUH0
0`00FUIJEP05FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH01@00FUIJEP00FUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF0`0015YF00<005YFFUH01EYF10000eYF0P00;goo000`Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0025YF00<005YF
00000P001EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF00<005YFFUH00P001EYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH015YF0P0025YF00<005YFFUH00UYF0P000UYF00D005YFFUIJEP00035oo`00
;Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P00
00=JEP00FUH01UYF0P0025YF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH01eYF00<005YFFUH00P0015YF00@005YF0000
039oo`00;7oo0P000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF0P0000=JEP00FUH01eYF10002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP04001JEP000003FUH00`00FUIJEP06FUH30007
FUH00`00Oomoo`0bOol002]oo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP05001JEUYFFUH00004FUH00`00FUIJ
EP03FUH20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH20006FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH2000eOol002Yoo`8000EJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF009J
EP04001JEP000005FUH00`00FUIJEP030005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP030004FUH01000FUIJEUYF0P00=goo
000YOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH:0005FUH2
0002FUH00`00FUIJEP02FUH20007FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0
00040003FUH01000FUIJEUYF2`002EYF0`0025YF0`00>Goo000YOol01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH015YF1P0000=oo`0000000P000UYF00<005YFFUH01UYF0P000UYF00@005YF
0000009JEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH9000015YF000000000Woo0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH01EYF0P00>goo
000YOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0400000=JEP00FUH01eYF0P000UYF
0P0015YF00<005YFFUH00P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00UJEP<000AJEPP000EJEP03
001JEUYF009JEP8000AJEP03001JEUYF00=JEP8003eoo`00:Woo00<005YF000015YF00<005YFFUH0
15YF200015YF00<005YFFUH01@000UYF00<005YFFUH01EYF0P0000AJEP00FUH000=JEPH000Aoo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH30004FUH00`00FUIJEP030008FUH01000FUH000001eYF00<0
05YF00000P00?goo000ZOol00`00FUH00005FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH01@000UYF00<005YFFUH01EYF00@005YF001JEPD00003FUH005YF009JEP03001oogoo009o
o`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH30005FUH300000eYF001JEP07FUH20009FUH20012Ool0
02Yoo`03001JEP0000EJEP04001JEP000005FUH00`00FUIJEP07FUH00`00FUIJEP030003FUH00`00
FUIJEP05FUH01P00FUH00000FUH000EJEP03001JEUYF008000=oo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH20004FUH20003FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH20014Ool002Yoo`04
001JEUYF0003FUH40007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH0
0`00FUIJEP02FUH01@00FUIJEUYF00000goo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00YJEP80009JEP80
00IJEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH20016Ool002Yoo`05001JEUYF001JEP020003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00
FUIJEP02FUH60002Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF1@001eYF00@005YF000000MJEP04
001JEP000018Ool002]oo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP06001JEP00001JEP0025YF00@005YF0000009JEP04001JEUYF0002Ool01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF60001EYF00<005YFFUH02UYF0P000eYF00<0
05YFFUH015YF0`001eYF0`00BWoo000[Ool01EYF001JEUYF000015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`0015YF00<005YFFUH015YF0`001EYF0P000goo00<005YFFUH01eYF
00<005YFFUH01eYF00<005YFFUH01eYF2@0035YF00<005YFFUH025YF20002UYF00<005YFFUH00eYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00CGoo000[Ool20002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP02FUH20002FUH0
1000FUIJEUYF0P001Goo00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEPH000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@000AJEP800003FUH005YF00AJEP04001JEP00
0005FUH00`00FUH00002001?Ool002]oo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00@000UJEP04001JEP000005FUH30007Ool00`00FUIJEP07FUH00`00FUIJ
EP06FUH500000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUH0000200001EYF001JEUYF00001EYF0P001UYF0`00DWoo000/Ool200000eYF001JEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP05FUH30007FUH00`00Oomoo`08Ool9FUH0
0`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH00`00FUH00002FUH01`00FUIJEUYF001JEP0000AJEP8005Eoo`00;Woo
500017oo0P001EYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF0P002goo2EYF00<005YF0000
0`002EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00@005YF000000=JEP03001JEP00008005Ioo`00A7oo0P0025YF00<005YF0000
0P001EYF00<005YFFUH00P003Goo2EYF0P000UYF00<005YFFUH025YF00<005YFFUH02EYF0P0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH01eYF0P0015YF0`0000=JEP000000EWoo0012
Ool30009FUH20009FUH2000?Ool7FUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20002FUH01P00FUH00000FUH000=JEP03
001oogoo05Aoo`00@7oo0P000eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF0P004Goo1EYF
0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH015YF1P0015YF00@005YFFUH005Ioo`00?Woo0P001EYF00<005YFFUH00UYF
0P0015YF00<005YFFUH00UYF0P004goo0eYF0P0025YF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF0P002EYF00<005YFFUH015YF00<005YFFUH00P001EYF00D005YF
FUIJEP0005Eoo`00>goo0`0025YF00@005YF000000MJEP04001JEP00000EOol2FUH01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00<005YF00000UYF00<005YFFUH00eYF00@005YF000005Eoo`00>Goo
0P0000=JEP00FUH025YF0P002EYF0P005goo00=JEP00FUH00eYF00<005YFFUH03eYF00<005YFFUH0
2UYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00@0
05YFFUIJEP@00003FUH007oo05Aoo`00=goo0P0015YF00<005YFFUH015YF0P0000=JEP00FUH01UYF
0P006Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02eYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF10000eYF0P00EWoo000eOol2
0006FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2000KOol20004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
1000FUIJEUYF0P0015YF0P000UYF00<005YFFUH00UYF00<007ooOol0EGoo000dOol00`00FUH00007
FUH01000FUH000001UYF00<005YFFUH00P007Woo00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00H005YF
000005YF0002FUH20004FUH00`00FUIJEP02001HOol0039oo`80009JEP03001JEUYF00EJEP8000QJ
EP<0021oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<000=JEP<000MJEP8005Yoo`00<Goo00<005YF
FUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P0097oo0P000UYF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
0`0015YF0P000UYF00<005YFFUH00eYF0P00G7oo000_Ool30005FUH00`00FUIJEP020004FUH00`00
FUIJEP03000XOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUH00003000015YF001JEUYF0`0015YF00@005YFFUIJEP8005ioo`00;goo00@005YF
FUH000EJEP8000IJEP<002eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00IJEP@000EJEP<000QJEP<0061oo`00;goo0P0000=JEP00FUH00UYF0P0000=JEP00
FUH00eYF0P00<Woo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01`001UYF0P000UYF00<005YFFUH01EYF0P00HWoo000`Ool00`00FUIJEP030003FUH00`00FUIJ
EP02000hOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH:0005FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP03FUH2001TOol0031oo`04001JEUYF0004FUH40012OolI0006Ool20008FUH01000
FUH000001eYF00<005YF00000P00IWoo000aOol7001SOol200000eYF001JEP07FUH20009FUH2001Y
Ool0035oo`8006Ioo`8000=JEP03001JEUYF00AJEP80009JEP03001JEUYF00AJEP8006]oo`00Ugoo
0P001UYF00@005YFFUIJEP8000AJEP03001JEUYF009JEP8006eoo`00UGoo0`001eYF00@005YF0000
00MJEP04001JEP00001_Ool009=oo`8000=JEP03001JEUYF00AJEP<000MJEP<0075oo`00TWoo00<0
05YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0P00M7oo002AOol00`00FUH00005
FUH01000FUH000001EYF00<005YF00000P00MWoo002@Ool01000FUIJEP001EYF0P001UYF0`00NGoo
002@Ool01@00FUIJEUYF00000eYF00<005YF000015YF0P00O7oo002AOol01@00FUIJEP00FUH00P00
0eYF00@005YF000007ioo`00TGoo00D005YFFUIJEP0000AJEP<0081oo`00TWoo00IJEP00001JEP00
FUH20023Ool0099oo`H008Eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]21\[InvisibleSpace]"     "\
\[InvisibleSpace]6.548198516685221`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 21, "     ", 6.548198516685221, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61418 .75146 m .61036 .69653 L .57872 .69732 L p .707 .577 .707 r
F P
0 g
s
.61036 .69653 m .61418 .75146 L .64552 .74769 L p .707 .577 .707 r
F P
0 g
s
.64552 .74769 m .6417 .69276 L .61036 .69653 L p .707 .577 .707 r
F P
0 g
s
.58254 .75226 m .57872 .69732 L .54987 .69507 L p .707 .577 .707 r
F P
0 g
s
.57872 .69732 m .58254 .75226 L .61418 .75146 L p .707 .577 .707 r
F P
0 g
s
.6417 .69276 m .64552 .74769 L .67348 .74132 L p .707 .577 .707 r
F P
0 g
s
.67348 .74132 m .66966 .68639 L .6417 .69276 L p .707 .577 .707 r
F P
0 g
s
.55369 .75 m .54987 .69507 L .52664 .68998 L p .707 .577 .707 r
F P
0 g
s
.54987 .69507 m .55369 .75 L .58254 .75226 L p .707 .577 .707 r
F P
0 g
s
.66966 .68639 m .67348 .74132 L .69534 .73297 L p .707 .577 .707 r
F P
0 g
s
.69534 .73297 m .69152 .67804 L .66966 .68639 L p .707 .577 .707 r
F P
0 g
s
.62075 .80367 m .62567 .76629 L .59398 .76208 L p .707 .577 .707 r
F P
0 g
s
.62567 .76629 m .62075 .80367 L .6512 .80573 L p .707 .577 .707 r
F P
0 g
s
.6512 .80573 m .65612 .76835 L .62567 .76629 L p .707 .577 .707 r
F P
0 g
s
.58906 .79946 m .59398 .76208 L .56415 .75614 L p .707 .577 .707 r
F P
0 g
s
.59398 .76208 m .58906 .79946 L .62075 .80367 L p .707 .577 .707 r
F P
0 g
s
.56415 .75614 m .55923 .79352 L .58906 .79946 L p .707 .577 .707 r
F P
0 g
s
.65612 .76835 m .6512 .80573 L .67742 .80545 L p .707 .577 .707 r
F P
0 g
s
.67742 .80545 m .68234 .76807 L .65612 .76835 L p .707 .577 .707 r
F P
0 g
s
.55923 .79352 m .56415 .75614 L .53911 .74906 L p .707 .577 .707 r
F P
0 g
s
.58353 .82715 m .58989 .80906 L .56111 .79826 L p .707 .577 .707 r
F P
0 g
s
.58989 .80906 m .58353 .82715 L .61369 .83767 L p .707 .577 .707 r
F P
0 g
s
.61369 .83767 m .62005 .81957 L .58989 .80906 L p .707 .577 .707 r
F P
0 g
s
.52664 .68998 m .53046 .74492 L .55369 .75 L p .707 .577 .707 r
F P
0 g
s
.62005 .81957 m .61369 .83767 L .6423 .84688 L p .707 .577 .707 r
F P
0 g
s
.6423 .84688 m .64866 .82878 L .62005 .81957 L p .707 .577 .707 r
F P
0 g
s
.56111 .79826 m .55475 .81636 L .58353 .82715 L p .707 .577 .707 r
F P
0 g
s
.53046 .74492 m .52664 .68998 L .5113 .68257 L p .707 .577 .707 r
F P
0 g
s
.53911 .74906 m .53419 .78644 L .55923 .79352 L p .707 .577 .707 r
F P
0 g
s
.69152 .67804 m .69534 .73297 L .70894 .72346 L p .707 .577 .707 r
F P
0 g
s
.70894 .72346 m .70512 .66853 L .69152 .67804 L p .707 .577 .707 r
F P
0 g
s
.55475 .81636 m .56111 .79826 L .53654 .78826 L p .707 .577 .707 r
F P
0 g
s
.53654 .78826 m .53018 .80635 L .55475 .81636 L p .707 .577 .707 r
F P
0 g
s
.64866 .82878 m .6423 .84688 L .66654 .85389 L p .707 .577 .707 r
F P
0 g
s
.66654 .85389 m .6729 .83579 L .64866 .82878 L p .707 .577 .707 r
F P
0 g
s
.68234 .76807 m .67742 .80545 L .69686 .80286 L p .707 .577 .707 r
F P
0 g
s
.69686 .80286 m .70178 .76548 L .68234 .76807 L p .707 .577 .707 r
F P
0 g
s
.53419 .78644 m .53911 .74906 L .52129 .74152 L p .707 .577 .707 r
F P
0 g
s
.5113 .68257 m .51511 .7375 L .52436 .74197 L p .707 .577 .707 r
F P
0 g
s
.51511 .7375 m .5113 .68257 L .50535 .67355 L p .707 .577 .707 r
F P
0 g
s
.50535 .67355 m .50916 .72848 L .5125 .73353 L p .707 .577 .707 r
F P
0 g
s
.5125 .73353 m .51511 .7375 L p .5134 .72628 L .707 .577 .707 r
F P
0 g
s
.5134 .72628 m .50535 .67355 L .5125 .73353 L .707 .577 .707 r
F
.52129 .74152 m .51246 .73426 L p .51468 .75961 L F P
0 g
s
.51246 .73426 m .50754 .77164 L .51637 .7789 L p .707 .577 .707 r
F P
0 g
s
.51246 .73426 m .51346 .728 L p .51016 .75228 L .706 .576 .707 r
F P
0 g
s
.50754 .77164 m .51154 .74123 L p .51016 .75228 L .706 .576 .707 r
F P
0 g
s
.51154 .74123 m .51246 .73426 L p .51016 .75228 L .706 .576 .707 r
F P
0 g
s
.51637 .7789 m .52025 .74946 L p .51468 .75961 L .707 .577 .707 r
F P
0 g
s
.52025 .74946 m .52129 .74152 L p .51468 .75961 L .707 .577 .707 r
F P
0 g
s
.52436 .74197 m .53046 .74492 L p .52768 .7359 L .707 .577 .707 r
F P
0 g
s
.52768 .7359 m .5113 .68257 L .52436 .74197 L .707 .577 .707 r
F
.52129 .74152 m .51637 .7789 L .53419 .78644 L p F P
0 g
s
.53018 .80635 m .53654 .78826 L .51858 .78001 L p .707 .577 .707 r
F P
0 g
s
.51858 .78001 m .51222 .79811 L .53018 .80635 L p .707 .577 .707 r
F P
0 g
s
.6729 .83579 m .66654 .85389 L .68405 .858 L p .707 .577 .707 r
F P
0 g
s
.68405 .858 m .69041 .83991 L .6729 .83579 L p .707 .577 .707 r
F P
0 g
s
.70512 .66853 m .70894 .72346 L .71297 .71371 L p .707 .577 .707 r
F P
0 g
s
.71297 .71371 m .70915 .65878 L .70512 .66853 L p .707 .577 .707 r
F P
0 g
s
.70178 .76548 m .69686 .80286 L .70761 .7982 L p .707 .577 .707 r
F P
0 g
s
.70761 .7982 m .71253 .76082 L .70178 .76548 L p .707 .577 .707 r
F P
0 g
s
.51222 .79811 m .51858 .78001 L .509 .77433 L p .707 .577 .707 r
F P
0 g
s
.509 .77433 m .50264 .79243 L .51222 .79811 L p .707 .577 .707 r
F P
0 g
s
.69041 .83991 m .68405 .858 L .69311 .85883 L p .707 .577 .707 r
F P
0 g
s
.69311 .85883 m .69947 .84073 L .69041 .83991 L p .707 .577 .707 r
F P
0 g
s
.50916 .72848 m .50535 .67355 L .50937 .6638 L p .707 .577 .707 r
F P
0 g
s
.70915 .65878 m .71297 .71371 L .70702 .70469 L p .707 .577 .707 r
F P
0 g
s
.70702 .70469 m .7032 .64976 L .70915 .65878 L p .707 .577 .707 r
F P
0 g
s
.47869 .8215 m .47869 .31961 L .43565 .31597 L p .707 .577 .707 r
F P
0 g
s
.50937 .6638 m .51319 .71873 L .50916 .72848 L p .707 .577 .707 r
F P
0 g
s
.51346 .728 m .50854 .76537 L .50754 .77164 L p .706 .576 .707 r
F P
0 g
s
.50264 .79243 m .509 .77433 L .50872 .77178 L p .707 .578 .707 r
F P
0 g
s
.50872 .77178 m .50236 .78987 L .50264 .79243 L p .707 .578 .707 r
F P
0 g
s
.51319 .71873 m .50937 .6638 L .52298 .65429 L p .707 .577 .707 r
F P
0 g
s
.50854 .76537 m .51346 .728 L .52421 .72334 L p .707 .577 .707 r
F P
0 g
s
.52298 .65429 m .52679 .70922 L .51319 .71873 L p .707 .577 .707 r
F P
0 g
s
.52421 .72334 m .51929 .76072 L .50854 .76537 L p .707 .577 .707 r
F P
0 g
s
.50236 .78987 m .50872 .77178 L .51778 .7726 L p .707 .577 .707 r
F P
0 g
s
.51778 .7726 m .51142 .7907 L .50236 .78987 L p .707 .577 .707 r
F P
0 g
s
.51142 .7907 m .51778 .7726 L .53529 .77672 L p .707 .577 .707 r
F P
0 g
s
.53529 .77672 m .52893 .79481 L .51142 .7907 L p .707 .577 .707 r
F P
0 g
s
.47869 .31961 m .47869 .8215 L .52382 .82139 L p .707 .577 .707 r
F P
0 g
s
.52679 .70922 m .52298 .65429 L .54483 .64594 L p .707 .577 .707 r
F P
0 g
s
.51929 .76072 m .52421 .72334 L .54365 .72074 L p .707 .577 .707 r
F P
0 g
s
.54365 .72074 m .53873 .75812 L .51929 .76072 L p .707 .577 .707 r
F P
0 g
s
.52382 .82139 m .52382 .3195 L .47869 .31961 L p .707 .577 .707 r
F P
0 g
s
.54483 .64594 m .54865 .70087 L .52679 .70922 L p .707 .577 .707 r
F P
0 g
s
.54865 .70087 m .54483 .64594 L .5728 .63956 L p .707 .577 .707 r
F P
0 g
s
.5728 .63956 m .57661 .6945 L .54865 .70087 L p .707 .577 .707 r
F P
0 g
s
.53873 .75812 m .54365 .72074 L .56987 .72046 L p .707 .577 .707 r
F P
0 g
s
.56987 .72046 m .56495 .75784 L .53873 .75812 L p .707 .577 .707 r
F P
0 g
s
.52893 .79481 m .53529 .77672 L .55953 .78372 L p .707 .577 .707 r
F P
0 g
s
.55953 .78372 m .55317 .80182 L .52893 .79481 L p .707 .577 .707 r
F P
0 g
s
.55317 .80182 m .55953 .78372 L .58813 .79294 L p .707 .577 .707 r
F P
0 g
s
.58813 .79294 m .58177 .81103 L .55317 .80182 L p .707 .577 .707 r
F P
0 g
s
.52382 .3195 m .52382 .82139 L .56662 .81755 L p .707 .577 .707 r
F P
0 g
s
.56495 .75784 m .56987 .72046 L .60032 .72253 L p .707 .577 .707 r
F P
0 g
s
.60032 .72253 m .5954 .75991 L .56495 .75784 L p .707 .577 .707 r
F P
0 g
s
.56662 .81755 m .56662 .31566 L .52382 .3195 L p .707 .577 .707 r
F P
0 g
s
.71253 .76082 m .70761 .7982 L .70861 .79193 L p .706 .576 .707 r
F P
0 g
s
.70861 .79193 m .71353 .75456 L .71253 .76082 L p .706 .576 .707 r
F P
0 g
s
.43565 .81786 m .43565 .31597 L .39891 .30894 L p .707 .577 .707 r
F P
0 g
s
.43565 .31597 m .43565 .81786 L .47869 .8215 L p .707 .577 .707 r
F P
0 g
s
.57661 .6945 m .5728 .63956 L .60413 .6358 L p .707 .577 .707 r
F P
0 g
s
.60413 .6358 m .60795 .69073 L .57661 .6945 L p .707 .577 .707 r
F P
0 g
s
.63201 .72674 m .62709 .76411 L .5954 .75991 L p .707 .577 .707 r
F P
0 g
s
.5954 .75991 m .60032 .72253 L .63201 .72674 L p .707 .577 .707 r
F P
0 g
s
.58177 .81103 m .58813 .79294 L .6183 .80345 L p .707 .577 .707 r
F P
0 g
s
.6183 .80345 m .61194 .82155 L .58177 .81103 L p .707 .577 .707 r
F P
0 g
s
.56662 .31566 m .56662 .81755 L .60289 .81034 L p .707 .577 .707 r
F P
0 g
s
.60289 .81034 m .60289 .30846 L .56662 .31566 L p .707 .577 .707 r
F P
0 g
s
.69947 .84073 m .69311 .85883 L .69283 .85627 L p .707 .578 .707 r
F P
0 g
s
.69283 .85627 m .69919 .83818 L .69947 .84073 L p .707 .578 .707 r
F P
0 g
s
.26659 .70876 m .2649 .65237 L .2332 .65244 L p .707 .577 .707 r
F P
0 g
s
.2649 .65237 m .26659 .70876 L .29798 .70661 L p .707 .577 .707 r
F P
0 g
s
.29798 .70661 m .29629 .65022 L .2649 .65237 L p .707 .577 .707 r
F P
0 g
s
.23489 .70883 m .2332 .65244 L .20429 .65041 L p .707 .577 .707 r
F P
0 g
s
.2332 .65244 m .23489 .70883 L .26659 .70876 L p .707 .577 .707 r
F P
0 g
s
.7032 .64976 m .70702 .70469 L .69168 .69728 L p .707 .577 .707 r
F P
0 g
s
.69168 .69728 m .68786 .64234 L .7032 .64976 L p .707 .577 .707 r
F P
0 g
s
.29629 .65022 m .29798 .70661 L .32599 .70257 L p .707 .577 .707 r
F P
0 g
s
.32599 .70257 m .3243 .64619 L .29629 .65022 L p .707 .577 .707 r
F P
0 g
s
.71353 .75456 m .70861 .79193 L .69978 .78468 L p .707 .577 .707 r
F P
0 g
s
.69978 .78468 m .7047 .7473 L .71353 .75456 L p .707 .577 .707 r
F P
0 g
s
.39891 .81083 m .39891 .30894 L .37206 .29921 L p .707 .577 .707 r
F P
0 g
s
.39891 .30894 m .39891 .81083 L .43565 .81786 L p .707 .577 .707 r
F P
0 g
s
.20429 .65041 m .20598 .70679 L .23489 .70883 L p .707 .577 .707 r
F P
0 g
s
.63578 .635 m .63959 .68994 L .60795 .69073 L p .707 .577 .707 r
F P
0 g
s
.60795 .69073 m .60413 .6358 L .63578 .635 L p .707 .577 .707 r
F P
0 g
s
.66184 .73267 m .65692 .77005 L .62709 .76411 L p .707 .577 .707 r
F P
0 g
s
.62709 .76411 m .63201 .72674 L .66184 .73267 L p .707 .577 .707 r
F P
0 g
s
.61194 .82155 m .6183 .80345 L .64708 .81424 L p .707 .577 .707 r
F P
0 g
s
.60289 .30846 m .60289 .81034 L .6291 .80048 L p .707 .577 .707 r
F P
0 g
s
.6291 .80048 m .6291 .2986 L .60289 .30846 L p .707 .577 .707 r
F P
0 g
s
.20598 .70679 m .20429 .65041 L .18101 .64648 L p .707 .577 .707 r
F P
0 g
s
.3243 .64619 m .32599 .70257 L .34787 .69705 L p .707 .577 .707 r
F P
0 g
s
.34787 .69705 m .34618 .64067 L .3243 .64619 L p .707 .577 .707 r
F P
0 g
s
.27493 .7851 m .27716 .7494 L .24526 .74732 L p .707 .577 .707 r
F P
0 g
s
.27716 .7494 m .27493 .7851 L .30557 .78345 L p .707 .577 .707 r
F P
0 g
s
.30557 .78345 m .3078 .74775 L .27716 .7494 L p .707 .577 .707 r
F P
0 g
s
.24304 .78302 m .24526 .74732 L .21523 .74172 L p .707 .577 .707 r
F P
0 g
s
.24526 .74732 m .24304 .78302 L .27493 .7851 L p .707 .577 .707 r
F P
0 g
s
.18101 .64648 m .1827 .70286 L .20598 .70679 L p .707 .577 .707 r
F P
0 g
s
.69919 .83818 m .69283 .85627 L .68324 .8506 L p .707 .577 .707 r
F P
0 g
s
.68324 .8506 m .6896 .8325 L .69919 .83818 L p .707 .577 .707 r
F P
0 g
s
.68786 .64234 m .69168 .69728 L .66844 .69219 L p .707 .577 .707 r
F P
0 g
s
.66844 .69219 m .66462 .63726 L .68786 .64234 L p .707 .577 .707 r
F P
0 g
s
.3078 .74775 m .30557 .78345 L .33195 .77825 L p .707 .577 .707 r
F P
0 g
s
.33195 .77825 m .33418 .74255 L .3078 .74775 L p .707 .577 .707 r
F P
0 g
s
.213 .77742 m .21523 .74172 L .18999 .73315 L p .707 .577 .707 r
F P
0 g
s
.21523 .74172 m .213 .77742 L .24304 .78302 L p .707 .577 .707 r
F P
0 g
s
.1827 .70286 m .18101 .64648 L .16562 .64103 L p .707 .577 .707 r
F P
0 g
s
.34618 .64067 m .34787 .69705 L .36148 .69059 L p .707 .577 .707 r
F P
0 g
s
.36148 .69059 m .35979 .6342 L .34618 .64067 L p .707 .577 .707 r
F P
0 g
s
.7047 .7473 m .69978 .78468 L .68196 .77714 L p .707 .577 .707 r
F P
0 g
s
.68196 .77714 m .68688 .73976 L .7047 .7473 L p .707 .577 .707 r
F P
0 g
s
.18999 .73315 m .18776 .76885 L .213 .77742 L p .707 .577 .707 r
F P
0 g
s
.33418 .74255 m .33195 .77825 L .35148 .76999 L p .707 .577 .707 r
F P
0 g
s
.35148 .76999 m .35371 .73429 L .33418 .74255 L p .707 .577 .707 r
F P
0 g
s
.37206 .80109 m .37206 .29921 L .35773 .28772 L p .707 .577 .707 r
F P
0 g
s
.37206 .29921 m .37206 .80109 L .39891 .81083 L p .707 .577 .707 r
F P
0 g
s
.18776 .76885 m .18999 .73315 L .17203 .72244 L p .707 .577 .707 r
F P
0 g
s
.16562 .64103 m .16731 .69742 L .1827 .70286 L p .707 .577 .707 r
F P
0 g
s
.66462 .63726 m .66844 .69219 L .63959 .68994 L p .707 .577 .707 r
F P
0 g
s
.63959 .68994 m .63578 .635 L .66462 .63726 L p .707 .577 .707 r
F P
0 g
s
.6291 .2986 m .6291 .80048 L .64266 .78893 L p .707 .577 .707 r
F P
0 g
s
.64266 .78893 m .64266 .28705 L .6291 .2986 L p .707 .577 .707 r
F P
0 g
s
.24335 .83578 m .24631 .81945 L .21612 .81061 L p .707 .577 .707 r
F P
0 g
s
.24631 .81945 m .24335 .83578 L .27494 .83974 L p .707 .577 .707 r
F P
0 g
s
.27494 .83974 m .27789 .82342 L .24631 .81945 L p .707 .577 .707 r
F P
0 g
s
.27789 .82342 m .27494 .83974 L .30482 .83843 L p .707 .577 .707 r
F P
0 g
s
.30482 .83843 m .30778 .82211 L .27789 .82342 L p .707 .577 .707 r
F P
0 g
s
.21316 .82693 m .21612 .81061 L .19027 .79774 L p .707 .577 .707 r
F P
0 g
s
.21612 .81061 m .21316 .82693 L .24335 .83578 L p .707 .577 .707 r
F P
0 g
s
.6896 .8325 m .68324 .8506 L .66529 .84235 L p .707 .577 .707 r
F P
0 g
s
.66529 .84235 m .67165 .82425 L .6896 .8325 L p .707 .577 .707 r
F P
0 g
s
.17203 .72244 m .1698 .75814 L .18776 .76885 L p .707 .577 .707 r
F P
0 g
s
.16731 .69742 m .16562 .64103 L .15965 .63461 L p .707 .577 .707 r
F P
0 g
s
.30778 .82211 m .30482 .83843 L .33007 .83198 L p .707 .577 .707 r
F P
0 g
s
.33007 .83198 m .33303 .81565 L .30778 .82211 L p .707 .577 .707 r
F P
0 g
s
.68688 .73976 m .68196 .77714 L .65692 .77005 L p .707 .577 .707 r
F P
0 g
s
.65692 .77005 m .66184 .73267 L .68688 .73976 L p .707 .577 .707 r
F P
0 g
s
.19027 .79774 m .18732 .81407 L .21316 .82693 L p .707 .577 .707 r
F P
0 g
s
.35979 .6342 m .36148 .69059 L .3655 .68382 L p .707 .577 .707 r
F P
0 g
s
.3655 .68382 m .36381 .62743 L .35979 .6342 L p .707 .577 .707 r
F P
0 g
s
.35371 .73429 m .35148 .76999 L .36226 .75948 L p .707 .577 .707 r
F P
0 g
s
.36226 .75948 m .36449 .72378 L .35371 .73429 L p .707 .577 .707 r
F P
0 g
s
.18732 .81407 m .19027 .79774 L .1713 .78212 L p .707 .577 .707 r
F P
0 g
s
.1698 .75814 m .17203 .72244 L .16309 .71065 L p .707 .577 .707 r
F P
0 g
s
.15965 .63461 m .16134 .691 L .16731 .69742 L p .707 .577 .707 r
F P
0 g
s
.1713 .78212 m .16835 .79844 L .18732 .81407 L p .707 .577 .707 r
F P
0 g
s
.67165 .82425 m .66529 .84235 L .64072 .83234 L p .707 .577 .707 r
F P
0 g
s
.64072 .83234 m .64708 .81424 L .67165 .82425 L p .707 .577 .707 r
F P
0 g
s
.33303 .81565 m .33007 .83198 L .34823 .82102 L p .707 .577 .707 r
F P
0 g
s
.34823 .82102 m .35119 .80469 L .33303 .81565 L p .707 .577 .707 r
F P
0 g
s
.16309 .71065 m .16086 .74635 L .1698 .75814 L p .707 .577 .707 r
F P
0 g
s
.36449 .72378 m .36226 .75948 L .36323 .74776 L p .706 .577 .707 r
F P
0 g
s
.36323 .74776 m .36546 .71206 L .36449 .72378 L p .706 .577 .707 r
F P
0 g
s
.36546 .71206 m .36323 .74776 L .3543 .73597 L p .707 .577 .707 r
F P
0 g
s
.3543 .73597 m .35653 .70027 L .36546 .71206 L p .707 .577 .707 r
F P
0 g
s
.35783 .621 m .35952 .67739 L .34414 .67195 L p .707 .577 .707 r
F P
0 g
s
.34414 .67195 m .34245 .61556 L .35783 .621 L p .707 .577 .707 r
F P
0 g
s
.35997 .77386 m .36047 .79029 L p .35833 .79022 L .707 .577 .707 r
F P
0 g
s
.35701 .79018 m .35823 .78349 L p .35833 .79022 L .707 .577 .707 r
F P
0 g
s
.35823 .78349 m .35997 .77386 L p .35833 .79022 L .707 .577 .707 r
F P
0 g
s
.35773 .28772 m .35734 .27561 L p .3577 .74904 L .708 .578 .707 r
F P
0 g
s
.35997 .77386 m .35701 .79018 L .34678 .77333 L p .707 .577 .707 r
F P
0 g
s
.34678 .77333 m .34973 .75701 L .35997 .77386 L p .707 .577 .707 r
F P
0 g
s
.35773 .78961 m .35773 .75111 L p .3577 .74904 L .708 .578 .707 r
F P
0 g
s
.35773 .75111 m .35773 .28772 L p .3577 .74904 L .708 .578 .707 r
F P
0 g
s
.36381 .62743 m .3655 .68382 L .35952 .67739 L p .707 .577 .707 r
F P
0 g
s
.35952 .67739 m .35783 .621 L .36381 .62743 L p .707 .577 .707 r
F P
0 g
s
.35751 .80661 m .36047 .79029 L .35119 .80469 L p .707 .577 .707 r
F P
0 g
s
.36047 .79029 m .35751 .80661 L .35701 .79018 L p .707 .577 .707 r
F P
0 g
s
.35773 .28772 m .35773 .78961 L .37206 .80109 L p .707 .577 .707 r
F P
0 g
s
.64266 .28705 m .64266 .78893 L .64226 .77683 L p .708 .578 .707 r
F P
0 g
s
.64226 .77683 m .64226 .27494 L .64266 .28705 L p .708 .578 .707 r
F P
0 g
s
.16835 .79844 m .1713 .78212 L .16107 .76527 L p .707 .577 .707 r
F P
0 g
s
.16134 .691 m .15965 .63461 L .16366 .62783 L p .707 .577 .707 r
F P
0 g
s
.16086 .74635 m .16309 .71065 L .16406 .69893 L p .706 .577 .707 r
F P
0 g
s
.16107 .76527 m .15811 .78159 L .16835 .79844 L p .707 .577 .707 r
F P
0 g
s
.64708 .81424 m .64072 .83234 L .61194 .82155 L p .707 .577 .707 r
F P
0 g
s
.16366 .62783 m .16535 .68422 L .16134 .691 L p .707 .577 .707 r
F P
0 g
s
.35119 .80469 m .34823 .82102 L .35751 .80661 L p .707 .577 .707 r
F P
0 g
s
.16406 .69893 m .16183 .73463 L .16086 .74635 L p .706 .577 .707 r
F P
0 g
s
.15811 .78159 m .16107 .76527 L .16057 .74884 L p .707 .577 .707 r
F P
0 g
s
.16535 .68422 m .16366 .62783 L .17728 .62137 L p .707 .577 .707 r
F P
0 g
s
.16057 .74884 m .15761 .76516 L .15811 .78159 L p .707 .577 .707 r
F P
0 g
s
.16183 .73463 m .16406 .69893 L .17484 .68843 L p .707 .577 .707 r
F P
0 g
s
.35734 .27561 m .35734 .7775 L .35773 .78961 L p .708 .578 .707 r
F P
0 g
s
.35734 .7775 m .35734 .27561 L .3709 .26406 L p .707 .577 .707 r
F P
0 g
s
.64226 .27494 m .64226 .77683 L .62794 .76534 L p .707 .577 .707 r
F P
0 g
s
.62794 .76534 m .62794 .26345 L .64226 .27494 L p .707 .577 .707 r
F P
0 g
s
.17728 .62137 m .17897 .67776 L .16535 .68422 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17484 .68843 m .17262 .72413 L .16183 .73463 L p .707 .577 .707 r
F P
0 g
s
.15761 .76516 m .16057 .74884 L .16985 .73443 L p .707 .577 .707 r
F P
0 g
s
.17897 .67776 m .17728 .62137 L .19916 .61585 L p .707 .577 .707 r
F P
0 g
s
.16985 .73443 m .16689 .75076 L .15761 .76516 L p .707 .577 .707 r
F P
0 g
s
.35653 .70027 m .3543 .73597 L .33634 .72527 L p .707 .577 .707 r
F P
0 g
s
.33634 .72527 m .33856 .68957 L .35653 .70027 L p .707 .577 .707 r
F P
0 g
s
.34245 .61556 m .34414 .67195 L .32085 .66802 L p .707 .577 .707 r
F P
0 g
s
.32085 .66802 m .31916 .61163 L .34245 .61556 L p .707 .577 .707 r
F P
0 g
s
.17262 .72413 m .17484 .68843 L .19438 .68017 L p .707 .577 .707 r
F P
0 g
s
.19916 .61585 m .20085 .67224 L .17897 .67776 L p .707 .577 .707 r
F P
0 g
s
.16689 .75076 m .16985 .73443 L .18801 .72347 L p .707 .577 .707 r
F P
0 g
s
.19438 .68017 m .19215 .71587 L .17262 .72413 L p .707 .577 .707 r
F P
0 g
s
.3709 .76595 m .3709 .26406 L .3971 .2542 L p .707 .577 .707 r
F P
0 g
s
.3709 .26406 m .3709 .76595 L .35734 .7775 L p .707 .577 .707 r
F P
0 g
s
.62794 .26345 m .62794 .76534 L .60109 .75561 L p .707 .577 .707 r
F P
0 g
s
.60109 .75561 m .60109 .25372 L .62794 .26345 L p .707 .577 .707 r
F P
0 g
s
.20085 .67224 m .19916 .61585 L .22717 .61182 L p .707 .577 .707 r
F P
0 g
s
.31916 .61163 m .32085 .66802 L .29195 .66599 L p .707 .577 .707 r
F P
0 g
s
.29195 .66599 m .29026 .6096 L .31916 .61163 L p .707 .577 .707 r
F P
0 g
s
.33856 .68957 m .33634 .72527 L .3111 .7167 L p .707 .577 .707 r
F P
0 g
s
.3111 .7167 m .31333 .681 L .33856 .68957 L p .707 .577 .707 r
F P
0 g
s
.18801 .72347 m .18505 .7398 L .16689 .75076 L p .707 .577 .707 r
F P
0 g
s
.19215 .71587 m .19438 .68017 L .22076 .67496 L p .707 .577 .707 r
F P
0 g
s
.34973 .75701 m .34678 .77333 L .32781 .75771 L p .707 .577 .707 r
F P
0 g
s
.32781 .75771 m .33076 .74138 L .34973 .75701 L p .707 .577 .707 r
F P
0 g
s
.22717 .61182 m .22886 .6682 L .20085 .67224 L p .707 .577 .707 r
F P
0 g
s
.22886 .6682 m .22717 .61182 L .25856 .60966 L p .707 .577 .707 r
F P
0 g
s
.29026 .6096 m .29195 .66599 L .26025 .66605 L p .707 .577 .707 r
F P
0 g
s
.26025 .66605 m .25856 .60966 L .29026 .6096 L p .707 .577 .707 r
F P
0 g
s
.18505 .7398 m .18801 .72347 L .21326 .71702 L p .707 .577 .707 r
F P
0 g
s
.22076 .67496 m .21853 .71066 L .19215 .71587 L p .707 .577 .707 r
F P
0 g
s
.25856 .60966 m .26025 .66605 L .22886 .6682 L p .707 .577 .707 r
F P
0 g
s
.31333 .681 m .3111 .7167 L .28106 .7111 L p .707 .577 .707 r
F P
0 g
s
.28106 .7111 m .28329 .6754 L .31333 .681 L p .707 .577 .707 r
F P
0 g
s
.21853 .71066 m .22076 .67496 L .25139 .67332 L p .707 .577 .707 r
F P
0 g
s
.21326 .71702 m .2103 .73334 L .18505 .7398 L p .707 .577 .707 r
F P
0 g
s
.73975 .66124 m .74144 .60672 L .70974 .60453 L p .707 .577 .707 r
F P
0 g
s
.74144 .60672 m .73975 .66124 L .77114 .66017 L p .707 .577 .707 r
F P
0 g
s
.77114 .66017 m .77283 .60564 L .74144 .60672 L p .707 .577 .707 r
F P
0 g
s
.28329 .6754 m .28106 .7111 L .24916 .70902 L p .707 .577 .707 r
F P
0 g
s
.24916 .70902 m .25139 .67332 L .28329 .6754 L p .707 .577 .707 r
F P
0 g
s
.25139 .67332 m .24916 .70902 L .21853 .71066 L p .707 .577 .707 r
F P
0 g
s
.33076 .74138 m .32781 .75771 L .30196 .74484 L p .707 .577 .707 r
F P
0 g
s
.30196 .74484 m .30492 .72852 L .33076 .74138 L p .707 .577 .707 r
F P
0 g
s
.3971 .2542 m .3971 .75609 L .3709 .76595 L p .707 .577 .707 r
F P
0 g
s
.3971 .75609 m .3971 .2542 L .43338 .247 L p .707 .577 .707 r
F P
0 g
s
.60109 .25372 m .60109 .75561 L .56435 .74858 L p .707 .577 .707 r
F P
0 g
s
.56435 .74858 m .56435 .24669 L .60109 .25372 L p .707 .577 .707 r
F P
0 g
s
.70805 .65906 m .70974 .60453 L .68083 .59929 L p .707 .577 .707 r
F P
0 g
s
.70974 .60453 m .70805 .65906 L .73975 .66124 L p .707 .577 .707 r
F P
0 g
s
.77283 .60564 m .77114 .66017 L .79915 .65593 L p .707 .577 .707 r
F P
0 g
s
.79915 .65593 m .80084 .6014 L .77283 .60564 L p .707 .577 .707 r
F P
0 g
s
.2103 .73334 m .21326 .71702 L .24314 .71571 L p .707 .577 .707 r
F P
0 g
s
.30492 .72852 m .30196 .74484 L .27177 .736 L p .707 .577 .707 r
F P
0 g
s
.27177 .736 m .27473 .71967 L .30492 .72852 L p .707 .577 .707 r
F P
0 g
s
.24314 .71571 m .24019 .73203 L .2103 .73334 L p .707 .577 .707 r
F P
0 g
s
.67914 .65382 m .68083 .59929 L .65755 .59152 L p .707 .577 .707 r
F P
0 g
s
.68083 .59929 m .67914 .65382 L .70805 .65906 L p .707 .577 .707 r
F P
0 g
s
.24019 .73203 m .24314 .71571 L .27473 .71967 L p .707 .577 .707 r
F P
0 g
s
.27473 .71967 m .27177 .736 L .24019 .73203 L p .707 .577 .707 r
F P
0 g
s
.80084 .6014 m .79915 .65593 L .82103 .64895 L p .707 .577 .707 r
F P
0 g
s
.82103 .64895 m .82272 .59442 L .80084 .6014 L p .707 .577 .707 r
F P
0 g
s
.75083 .70483 m .7486 .66696 L .71671 .66862 L p .707 .577 .707 r
F P
0 g
s
.7486 .66696 m .75083 .70483 L .78147 .7016 L p .707 .577 .707 r
F P
0 g
s
.78147 .7016 m .77924 .66373 L .7486 .66696 L p .707 .577 .707 r
F P
0 g
s
.71893 .7065 m .71671 .66862 L .68667 .66856 L p .707 .577 .707 r
F P
0 g
s
.71671 .66862 m .71893 .7065 L .75083 .70483 L p .707 .577 .707 r
F P
0 g
s
.43338 .74889 m .43338 .247 L .47618 .24316 L p .707 .577 .707 r
F P
0 g
s
.43338 .247 m .43338 .74889 L .3971 .75609 L p .707 .577 .707 r
F P
0 g
s
.56435 .24669 m .56435 .74858 L .5213 .74494 L p .707 .577 .707 r
F P
0 g
s
.5213 .74494 m .5213 .24305 L .56435 .24669 L p .707 .577 .707 r
F P
0 g
s
.72823 .73587 m .72527 .71687 L .69508 .72151 L p .707 .577 .707 r
F P
0 g
s
.72527 .71687 m .72823 .73587 L .75981 .73095 L p .707 .577 .707 r
F P
0 g
s
.75981 .73095 m .75685 .71195 L .72527 .71687 L p .707 .577 .707 r
F P
0 g
s
.69508 .72151 m .69804 .74052 L .72823 .73587 L p .707 .577 .707 r
F P
0 g
s
.75685 .71195 m .75981 .73095 L .78969 .72624 L p .707 .577 .707 r
F P
0 g
s
.78969 .72624 m .78674 .70724 L .75685 .71195 L p .707 .577 .707 r
F P
0 g
s
.68667 .66856 m .6889 .70643 L .71893 .7065 L p .707 .577 .707 r
F P
0 g
s
.77924 .66373 m .78147 .7016 L .80785 .69712 L p .707 .577 .707 r
F P
0 g
s
.80785 .69712 m .80562 .65925 L .77924 .66373 L p .707 .577 .707 r
F P
0 g
s
.65755 .59152 m .65586 .64605 L .67914 .65382 L p .707 .577 .707 r
F P
0 g
s
.6889 .70643 m .68667 .66856 L .66143 .66677 L p .707 .577 .707 r
F P
0 g
s
.65586 .64605 m .65755 .59152 L .64217 .58197 L p .707 .577 .707 r
F P
0 g
s
.69804 .74052 m .69508 .72151 L .66923 .72543 L p .707 .577 .707 r
F P
0 g
s
.66923 .72543 m .67219 .74443 L .69804 .74052 L p .707 .577 .707 r
F P
0 g
s
.47618 .74505 m .47618 .24316 L .5213 .24305 L p .707 .577 .707 r
F P
0 g
s
.47618 .24316 m .47618 .74505 L .43338 .74889 L p .707 .577 .707 r
F P
0 g
s
.5213 .24305 m .5213 .74494 L .47618 .74505 L p .707 .577 .707 r
F P
0 g
s
.78674 .70724 m .78969 .72624 L .81495 .7222 L p .707 .577 .707 r
F P
0 g
s
.81495 .7222 m .81199 .7032 L .78674 .70724 L p .707 .577 .707 r
F P
0 g
s
.66143 .66677 m .66366 .70464 L .6889 .70643 L p .707 .577 .707 r
F P
0 g
s
.82272 .59442 m .82103 .64895 L .83465 .63991 L p .707 .577 .707 r
F P
0 g
s
.83465 .63991 m .83633 .58538 L .82272 .59442 L p .707 .577 .707 r
F P
0 g
s
.80562 .65925 m .80785 .69712 L .82738 .69182 L p .707 .577 .707 r
F P
0 g
s
.82738 .69182 m .82515 .65395 L .80562 .65925 L p .707 .577 .707 r
F P
0 g
s
.66366 .70464 m .66143 .66677 L .64347 .66343 L p .707 .577 .707 r
F P
0 g
s
.64217 .58197 m .64048 .6365 L .65586 .64605 L p .707 .577 .707 r
F P
0 g
s
.67219 .74443 m .66923 .72543 L .65026 .72823 L p .707 .577 .707 r
F P
0 g
s
.65026 .72823 m .65322 .74724 L .67219 .74443 L p .707 .577 .707 r
F P
0 g
s
.81199 .7032 m .81495 .7222 L .83311 .71922 L p .707 .577 .707 r
F P
0 g
s
.83311 .71922 m .83015 .70022 L .81199 .7032 L p .707 .577 .707 r
F P
0 g
s
.64347 .66343 m .6457 .70131 L .66366 .70464 L p .707 .577 .707 r
F P
0 g
s
.64048 .6365 m .64217 .58197 L .63619 .57157 L p .707 .577 .707 r
F P
0 g
s
.83633 .58538 m .83465 .63991 L .83866 .62969 L p .707 .577 .707 r
F P
0 g
s
.83866 .62969 m .84035 .57516 L .83633 .58538 L p .707 .577 .707 r
F P
0 g
s
.82515 .65395 m .82738 .69182 L .83816 .68624 L p .707 .577 .707 r
F P
0 g
s
.83816 .68624 m .83593 .64836 L .82515 .65395 L p .707 .577 .707 r
F P
0 g
s
.6457 .70131 m .64347 .66343 L .63454 .65888 L p .707 .577 .707 r
F P
0 g
s
.63619 .57157 m .6345 .6261 L .64048 .6365 L p .707 .577 .707 r
F P
0 g
s
.65322 .74724 m .65026 .72823 L .64003 .72965 L p .707 .577 .707 r
F P
0 g
s
.64003 .72965 m .64298 .74865 L .65322 .74724 L p .707 .577 .707 r
F P
0 g
s
.83015 .70022 m .83311 .71922 L .84239 .7176 L p .707 .577 .707 r
F P
0 g
s
.84239 .7176 m .83943 .69859 L .83015 .70022 L p .707 .577 .707 r
F P
0 g
s
.63454 .65888 m .63676 .69675 L .6457 .70131 L p .707 .577 .707 r
F P
0 g
s
.6345 .6261 m .63619 .57157 L .64021 .56136 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84035 .57516 m .83866 .62969 L .83268 .6193 L p .707 .577 .707 r
F P
0 g
s
.83268 .6193 m .83437 .56477 L .84035 .57516 L p .707 .577 .707 r
F P
0 g
s
.83593 .64836 m .83816 .68624 L .83913 .6809 L p .707 .577 .707 r
F P
0 g
s
.83913 .6809 m .83691 .64303 L .83593 .64836 L p .707 .577 .707 r
F P
0 g
s
.64021 .56136 m .63852 .61589 L .6345 .6261 L p .707 .577 .707 r
F P
0 g
s
.63676 .69675 m .63454 .65888 L .63551 .65354 L p .707 .577 .707 r
F P
0 g
s
.64298 .74865 m .64003 .72965 L .63953 .72954 L p .708 .578 .707 r
F P
0 g
s
.63953 .72954 m .64248 .74854 L .64298 .74865 L p .708 .578 .707 r
F P
0 g
s
.83943 .69859 m .84239 .7176 L .84189 .71749 L p .708 .578 .707 r
F P
0 g
s
.84189 .71749 m .83893 .69848 L .83943 .69859 L p .708 .578 .707 r
F P
0 g
s
.63551 .65354 m .63773 .69141 L .63676 .69675 L p .707 .577 .707 r
F P
0 g
s
.63852 .61589 m .64021 .56136 L .65382 .55231 L p .707 .577 .707 r
F P
0 g
s
.39205 .6186 m .39586 .56267 L .36422 .55967 L p .707 .577 .707 r
F P
0 g
s
.39586 .56267 m .39205 .6186 L .42338 .6192 L p .707 .577 .707 r
F P
0 g
s
.42338 .6192 m .4272 .56327 L .39586 .56267 L p .707 .577 .707 r
F P
0 g
s
.3604 .6156 m .36422 .55967 L .33537 .55458 L p .707 .577 .707 r
F P
0 g
s
.36422 .55967 m .3604 .6156 L .39205 .6186 L p .707 .577 .707 r
F P
0 g
s
.4272 .56327 m .42338 .6192 L .45135 .61736 L p .707 .577 .707 r
F P
0 g
s
.45135 .61736 m .45517 .56143 L .4272 .56327 L p .707 .577 .707 r
F P
0 g
s
.83437 .56477 m .83268 .6193 L .8173 .60975 L p .707 .577 .707 r
F P
0 g
s
.8173 .60975 m .81899 .55522 L .83437 .56477 L p .707 .577 .707 r
F P
0 g
s
.83691 .64303 m .83913 .6809 L .8302 .67634 L p .707 .577 .707 r
F P
0 g
s
.8302 .67634 m .82797 .63847 L .83691 .64303 L p .707 .577 .707 r
F P
0 g
s
.33155 .61051 m .33537 .55458 L .31214 .54789 L p .707 .577 .707 r
F P
0 g
s
.33537 .55458 m .33155 .61051 L .3604 .6156 L p .707 .577 .707 r
F P
0 g
s
.65382 .55231 m .65213 .60684 L .63852 .61589 L p .707 .577 .707 r
F P
0 g
s
.63773 .69141 m .63551 .65354 L .64629 .64795 L p .707 .577 .707 r
F P
0 g
s
.45517 .56143 m .45135 .61736 L .4732 .61324 L p .707 .577 .707 r
F P
0 g
s
.4732 .61324 m .47702 .55731 L .45517 .56143 L p .707 .577 .707 r
F P
0 g
s
.4046 .68642 m .39968 .65048 L .36799 .65399 L p .707 .577 .707 r
F P
0 g
s
.39968 .65048 m .4046 .68642 L .43505 .67973 L p .707 .577 .707 r
F P
0 g
s
.43505 .67973 m .43013 .64379 L .39968 .65048 L p .707 .577 .707 r
F P
0 g
s
.64248 .74854 m .63953 .72954 L .64881 .72792 L p .707 .577 .707 r
F P
0 g
s
.64881 .72792 m .65177 .74692 L .64248 .74854 L p .707 .577 .707 r
F P
0 g
s
.37291 .68993 m .36799 .65399 L .33816 .65398 L p .707 .577 .707 r
F P
0 g
s
.36799 .65399 m .37291 .68993 L .4046 .68642 L p .707 .577 .707 r
F P
0 g
s
.83893 .69848 m .84189 .71749 L .83165 .71891 L p .707 .577 .707 r
F P
0 g
s
.83165 .71891 m .82869 .6999 L .83893 .69848 L p .707 .577 .707 r
F P
0 g
s
.64629 .64795 m .64851 .68583 L .63773 .69141 L p .707 .577 .707 r
F P
0 g
s
.65213 .60684 m .65382 .55231 L .6757 .54533 L p .707 .577 .707 r
F P
0 g
s
.43013 .64379 m .43505 .67973 L .46127 .67052 L p .707 .577 .707 r
F P
0 g
s
.46127 .67052 m .45635 .63458 L .43013 .64379 L p .707 .577 .707 r
F P
0 g
s
.31214 .54789 m .30832 .60382 L .33155 .61051 L p .707 .577 .707 r
F P
0 g
s
.81899 .55522 m .8173 .60975 L .79402 .60197 L p .707 .577 .707 r
F P
0 g
s
.79402 .60197 m .79571 .54744 L .81899 .55522 L p .707 .577 .707 r
F P
0 g
s
.34308 .68992 m .33816 .65398 L .31312 .65045 L p .707 .577 .707 r
F P
0 g
s
.33816 .65398 m .34308 .68992 L .37291 .68993 L p .707 .577 .707 r
F P
0 g
s
.30832 .60382 m .31214 .54789 L .2968 .54025 L p .707 .577 .707 r
F P
0 g
s
.82797 .63847 m .8302 .67634 L .81224 .67301 L p .707 .577 .707 r
F P
0 g
s
.81224 .67301 m .81001 .63513 L .82797 .63847 L p .707 .577 .707 r
F P
0 g
s
.47702 .55731 m .4732 .61324 L .48681 .60726 L p .707 .577 .707 r
F P
0 g
s
.48681 .60726 m .49063 .55133 L .47702 .55731 L p .707 .577 .707 r
F P
0 g
s
.45635 .63458 m .46127 .67052 L .48071 .65969 L p .707 .577 .707 r
F P
0 g
s
.48071 .65969 m .47579 .62375 L .45635 .63458 L p .707 .577 .707 r
F P
0 g
s
.6757 .54533 m .67401 .59986 L .65213 .60684 L p .707 .577 .707 r
F P
0 g
s
.41822 .73441 m .41186 .7182 L .3817 .72778 L p .707 .577 .707 r
F P
0 g
s
.41186 .7182 m .41822 .73441 L .44683 .72089 L p .707 .577 .707 r
F P
0 g
s
.44683 .72089 m .44047 .70468 L .41186 .7182 L p .707 .577 .707 r
F P
0 g
s
.67401 .59986 m .6757 .54533 L .70371 .5411 L p .707 .577 .707 r
F P
0 g
s
.31312 .65045 m .31804 .68639 L .34308 .68992 L p .707 .577 .707 r
F P
0 g
s
.64851 .68583 m .64629 .64795 L .66582 .64266 L p .707 .577 .707 r
F P
0 g
s
.2968 .54025 m .29298 .59618 L .30832 .60382 L p .707 .577 .707 r
F P
0 g
s
.38806 .74399 m .3817 .72778 L .35292 .73247 L p .707 .577 .707 r
F P
0 g
s
.3817 .72778 m .38806 .74399 L .41822 .73441 L p .707 .577 .707 r
F P
0 g
s
.44047 .70468 m .44683 .72089 L .47107 .70475 L p .707 .577 .707 r
F P
0 g
s
.47107 .70475 m .46471 .68854 L .44047 .70468 L p .707 .577 .707 r
F P
0 g
s
.65177 .74692 m .64881 .72792 L .66697 .72494 L p .707 .577 .707 r
F P
0 g
s
.66697 .72494 m .66992 .74394 L .65177 .74692 L p .707 .577 .707 r
F P
0 g
s
.79571 .54744 m .79402 .60197 L .76511 .59674 L p .707 .577 .707 r
F P
0 g
s
.76511 .59674 m .7668 .54221 L .79571 .54744 L p .707 .577 .707 r
F P
0 g
s
.66582 .64266 m .66805 .68053 L .64851 .68583 L p .707 .577 .707 r
F P
0 g
s
.31804 .68639 m .31312 .65045 L .2953 .64375 L p .707 .577 .707 r
F P
0 g
s
.82869 .6999 m .83165 .71891 L .81268 .72171 L p .707 .577 .707 r
F P
0 g
s
.81268 .72171 m .80972 .70271 L .82869 .6999 L p .707 .577 .707 r
F P
0 g
s
.35292 .73247 m .35928 .74868 L .38806 .74399 L p .707 .577 .707 r
F P
0 g
s
.70202 .59563 m .70371 .5411 L .7351 .54002 L p .707 .577 .707 r
F P
0 g
s
.70371 .5411 m .70202 .59563 L .67401 .59986 L p .707 .577 .707 r
F P
0 g
s
.35928 .74868 m .35292 .73247 L .32835 .73181 L p .707 .577 .707 r
F P
0 g
s
.29298 .59618 m .2968 .54025 L .29085 .53242 L p .707 .577 .707 r
F P
0 g
s
.46471 .68854 m .47107 .70475 L .48858 .68756 L p .707 .577 .707 r
F P
0 g
s
.48858 .68756 m .48222 .67135 L .46471 .68854 L p .707 .577 .707 r
F P
0 g
s
.7668 .54221 m .76511 .59674 L .73341 .59455 L p .707 .577 .707 r
F P
0 g
s
.73341 .59455 m .7351 .54002 L .7668 .54221 L p .707 .577 .707 r
F P
0 g
s
.47579 .62375 m .48071 .65969 L .49146 .6483 L p .707 .577 .707 r
F P
0 g
s
.49146 .6483 m .48654 .61236 L .47579 .62375 L p .707 .577 .707 r
F P
0 g
s
.81001 .63513 m .81224 .67301 L .787 .67122 L p .707 .577 .707 r
F P
0 g
s
.787 .67122 m .78477 .63334 L .81001 .63513 L p .707 .577 .707 r
F P
0 g
s
.2953 .64375 m .30022 .67969 L .31804 .68639 L p .707 .577 .707 r
F P
0 g
s
.7351 .54002 m .73341 .59455 L .70202 .59563 L p .707 .577 .707 r
F P
0 g
s
.32835 .73181 m .33471 .74802 L .35928 .74868 L p .707 .577 .707 r
F P
0 g
s
.49063 .55133 m .48681 .60726 L .49083 .6 L p .707 .577 .707 r
F P
0 g
s
.49083 .6 m .49465 .54407 L .49063 .55133 L p .707 .577 .707 r
F P
0 g
s
.66805 .68053 m .66582 .64266 L .6922 .63818 L p .707 .577 .707 r
F P
0 g
s
.29085 .53242 m .28703 .58835 L .29298 .59618 L p .707 .577 .707 r
F P
0 g
s
.66992 .74394 m .66697 .72494 L .69222 .7209 L p .707 .577 .707 r
F P
0 g
s
.69222 .7209 m .69518 .7399 L .66992 .74394 L p .707 .577 .707 r
F P
0 g
s
.6922 .63818 m .69443 .67605 L .66805 .68053 L p .707 .577 .707 r
F P
0 g
s
.80972 .70271 m .81268 .72171 L .78684 .72562 L p .707 .577 .707 r
F P
0 g
s
.78684 .72562 m .78388 .70662 L .80972 .70271 L p .707 .577 .707 r
F P
0 g
s
.30022 .67969 m .2953 .64375 L .28646 .63453 L p .707 .577 .707 r
F P
0 g
s
.33471 .74802 m .32835 .73181 L .31039 .72588 L p .707 .577 .707 r
F P
0 g
s
.48222 .67135 m .48858 .68756 L .49764 .67102 L p .707 .577 .707 r
F P
0 g
s
.49764 .67102 m .49128 .65481 L .48222 .67135 L p .707 .577 .707 r
F P
0 g
s
.78477 .63334 m .787 .67122 L .75696 .67115 L p .707 .577 .707 r
F P
0 g
s
.75696 .67115 m .75473 .63328 L .78477 .63334 L p .707 .577 .707 r
F P
0 g
s
.69443 .67605 m .6922 .63818 L .72284 .63494 L p .707 .577 .707 r
F P
0 g
s
.31039 .72588 m .31675 .74209 L .33471 .74802 L p .707 .577 .707 r
F P
0 g
s
.28646 .63453 m .29138 .67047 L .30022 .67969 L p .707 .577 .707 r
F P
0 g
s
.28703 .58835 m .29085 .53242 L .29487 .52516 L p .707 .577 .707 r
F P
0 g
s
.48654 .61236 m .49146 .6483 L .49246 .63747 L p .707 .577 .707 r
F P
0 g
s
.49246 .63747 m .48754 .60153 L .48654 .61236 L p .707 .577 .707 r
F P
0 g
s
.72284 .63494 m .72506 .67282 L .69443 .67605 L p .707 .577 .707 r
F P
0 g
s
.69518 .7399 m .69222 .7209 L .7221 .71618 L p .707 .577 .707 r
F P
0 g
s
.7221 .71618 m .72506 .73519 L .69518 .7399 L p .707 .577 .707 r
F P
0 g
s
.75473 .63328 m .75696 .67115 L .72506 .67282 L p .707 .577 .707 r
F P
0 g
s
.72506 .67282 m .72284 .63494 L .75473 .63328 L p .707 .577 .707 r
F P
0 g
s
.78388 .70662 m .78684 .72562 L .75665 .73027 L p .707 .577 .707 r
F P
0 g
s
.75665 .73027 m .75369 .71127 L .78388 .70662 L p .707 .577 .707 r
F P
0 g
s
.49465 .54407 m .49083 .6 L .48488 .59217 L p .707 .577 .707 r
F P
0 g
s
.48488 .59217 m .4887 .53624 L .49465 .54407 L p .707 .577 .707 r
F P
0 g
s
.29487 .52516 m .29105 .5811 L .28703 .58835 L p .707 .577 .707 r
F P
0 g
s
.72506 .73519 m .7221 .71618 L .75369 .71127 L p .707 .577 .707 r
F P
0 g
s
.75369 .71127 m .75665 .73027 L .72506 .73519 L p .707 .577 .707 r
F P
0 g
s
.31675 .74209 m .31039 .72588 L .30081 .71525 L p .707 .577 .707 r
F P
0 g
s
.49128 .65481 m .49764 .67102 L .49736 .65673 L p .707 .577 .707 r
F P
0 g
s
.49736 .65673 m .491 .64052 L .49128 .65481 L p .707 .577 .707 r
F P
0 g
s
.29138 .67047 m .28646 .63453 L .28747 .62369 L p .707 .577 .707 r
F P
0 g
s
.30081 .71525 m .30717 .73146 L .31675 .74209 L p .707 .577 .707 r
F P
0 g
s
.28747 .62369 m .29239 .65964 L .29138 .67047 L p .707 .577 .707 r
F P
0 g
s
.29105 .5811 m .29487 .52516 L .30848 .51919 L p .707 .577 .707 r
F P
0 g
s
.48754 .60153 m .49246 .63747 L .48362 .62825 L p .707 .577 .707 r
F P
0 g
s
.48362 .62825 m .4787 .59231 L .48754 .60153 L p .707 .577 .707 r
F P
0 g
s
.4887 .53624 m .48488 .59217 L .46954 .58454 L p .707 .577 .707 r
F P
0 g
s
.46954 .58454 m .47336 .52861 L .4887 .53624 L p .707 .577 .707 r
F P
0 g
s
.30717 .73146 m .30081 .71525 L .30053 .70096 L p .707 .577 .707 r
F P
0 g
s
.30848 .51919 m .30466 .57512 L .29105 .5811 L p .707 .577 .707 r
F P
0 g
s
.491 .64052 m .49736 .65673 L .48777 .6461 L p .707 .577 .707 r
F P
0 g
s
.48777 .6461 m .48141 .62989 L .491 .64052 L p .707 .577 .707 r
F P
0 g
s
.29239 .65964 m .28747 .62369 L .29821 .6123 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30053 .70096 m .30689 .71718 L .30717 .73146 L p .707 .577 .707 r
F P
0 g
s
.29821 .6123 m .30313 .64825 L .29239 .65964 L p .707 .577 .707 r
F P
0 g
s
.30466 .57512 m .30848 .51919 L .33033 .51507 L p .707 .577 .707 r
F P
0 g
s
.4787 .59231 m .48362 .62825 L .46581 .62155 L p .707 .577 .707 r
F P
0 g
s
.46581 .62155 m .46089 .58561 L .4787 .59231 L p .707 .577 .707 r
F P
0 g
s
.47336 .52861 m .46954 .58454 L .44631 .57785 L p .707 .577 .707 r
F P
0 g
s
.44631 .57785 m .45013 .52192 L .47336 .52861 L p .707 .577 .707 r
F P
0 g
s
.33033 .51507 m .32652 .571 L .30466 .57512 L p .707 .577 .707 r
F P
0 g
s
.30689 .71718 m .30053 .70096 L .30959 .68442 L p .707 .577 .707 r
F P
0 g
s
.48141 .62989 m .48777 .6461 L .46982 .64017 L p .707 .577 .707 r
F P
0 g
s
.46982 .64017 m .46346 .62396 L .48141 .62989 L p .707 .577 .707 r
F P
0 g
s
.30313 .64825 m .29821 .6123 L .31765 .60148 L p .707 .577 .707 r
F P
0 g
s
.30959 .68442 m .31595 .70063 L .30689 .71718 L p .707 .577 .707 r
F P
0 g
s
.32652 .571 m .33033 .51507 L .3583 .51323 L p .707 .577 .707 r
F P
0 g
s
.46089 .58561 m .46581 .62155 L .44076 .61802 L p .707 .577 .707 r
F P
0 g
s
.44076 .61802 m .43584 .58208 L .46089 .58561 L p .707 .577 .707 r
F P
0 g
s
.31765 .60148 m .32257 .63742 L .30313 .64825 L p .707 .577 .707 r
F P
0 g
s
.45013 .52192 m .44631 .57785 L .41746 .57276 L p .707 .577 .707 r
F P
0 g
s
.41746 .57276 m .42128 .51683 L .45013 .52192 L p .707 .577 .707 r
F P
0 g
s
.3583 .51323 m .35448 .56916 L .32652 .571 L p .707 .577 .707 r
F P
0 g
s
.32257 .63742 m .31765 .60148 L .34388 .59227 L p .707 .577 .707 r
F P
0 g
s
.35448 .56916 m .3583 .51323 L .38963 .51383 L p .707 .577 .707 r
F P
0 g
s
.31595 .70063 m .30959 .68442 L .3271 .66723 L p .707 .577 .707 r
F P
0 g
s
.46346 .62396 m .46982 .64017 L .44525 .63952 L p .707 .577 .707 r
F P
0 g
s
.44525 .63952 m .43889 .62331 L .46346 .62396 L p .707 .577 .707 r
F P
0 g
s
.42128 .51683 m .41746 .57276 L .38582 .56976 L p .707 .577 .707 r
F P
0 g
s
.38582 .56976 m .38963 .51383 L .42128 .51683 L p .707 .577 .707 r
F P
0 g
s
.38963 .51383 m .38582 .56976 L .35448 .56916 L p .707 .577 .707 r
F P
0 g
s
.43584 .58208 m .44076 .61802 L .41094 .61801 L p .707 .577 .707 r
F P
0 g
s
.41094 .61801 m .40602 .58207 L .43584 .58208 L p .707 .577 .707 r
F P
0 g
s
.3271 .66723 m .33346 .68344 L .31595 .70063 L p .707 .577 .707 r
F P
0 g
s
.34388 .59227 m .3488 .62821 L .32257 .63742 L p .707 .577 .707 r
F P
0 g
s
.3488 .62821 m .34388 .59227 L .37433 .58558 L p .707 .577 .707 r
F P
0 g
s
.40602 .58207 m .41094 .61801 L .37925 .62152 L p .707 .577 .707 r
F P
0 g
s
.37925 .62152 m .37433 .58558 L .40602 .58207 L p .707 .577 .707 r
F P
0 g
s
.33346 .68344 m .3271 .66723 L .35134 .65109 L p .707 .577 .707 r
F P
0 g
s
.43889 .62331 m .44525 .63952 L .41647 .64421 L p .707 .577 .707 r
F P
0 g
s
.41647 .64421 m .41011 .628 L .43889 .62331 L p .707 .577 .707 r
F P
0 g
s
.37433 .58558 m .37925 .62152 L .3488 .62821 L p .707 .577 .707 r
F P
0 g
s
.35134 .65109 m .3577 .6673 L .33346 .68344 L p .707 .577 .707 r
F P
0 g
s
.3577 .6673 m .35134 .65109 L .37994 .63757 L p .707 .577 .707 r
F P
0 g
s
.41011 .628 m .41647 .64421 L .3863 .65378 L p .707 .577 .707 r
F P
0 g
s
.3863 .65378 m .37994 .63757 L .41011 .628 L p .707 .577 .707 r
F P
0 g
s
.37994 .63757 m .3863 .65378 L .3577 .6673 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PWoo6000Pgoo001iOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001jOol007=oo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Eoo`00Kgoo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000LGoo001]
Ool200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH00003001]Ool006]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<006Yoo`00JGoo0P001EYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF0P00JGoo001XOol20006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH0001XOol006Ioo`80
0003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001WOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF0000IWoo001ROol80006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo
001KOol70003FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001GOol40002FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9000;FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF0000IWoo001EOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00Dgoo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000`000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0035YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF0`002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0006Io
o`00DWoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0006Ioo`00DWoo0P000eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0000@
Ool>0018Ool0059oo`8000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001eYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000aoo`@00003FUH005YF00IJEP03
001JEUYF009JEPT003moo`00DWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF000027oo10001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF1P00>Goo001BOol20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05
001JEUYFFUH00004Ool400000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00002000fOol0059oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002Ool20005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000dOol0059oo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF10001UYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00<Woo001AOol20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02000`Ool0055oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<0
07ooOol0;Goo001AOol20003FUH00`00FUIJEP03FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EUYF009JEP03001oogoo02eoo`00DGoo0P000eYF00@005YFFUIJEPL000IJEP03001JEP0000h000IJ
EP03001JEUYF00AJEP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8002ioo`00DGoo0P00
0eYF10001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF10000UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUH000000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol200001EYF000005YF
00001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001EYF00L0
05YFFUIJEP00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH0
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo001AOol30003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH@00000eYF0000000200000eYF001JEP02FUH00`00FUH00008
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00;Woo001AOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH80004FUH00`00FUIJEP05FUH01000FUIJEUYF1`000eYF00<005YF000025YF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009J
EP8002ioo`00DGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00eYF10000UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P0000AJEP00FUH000QJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH2000^Ool0059oo`8000=JEP03001JEUYF00AJEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH0000^Ool005=oo`05001JEUYFFUH00006FUH200000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40008FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH00eYF00<005YFFUH00UYF5`00
1UYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000^Ool005Aoo`800003FUH005YF00=JEP8000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP@000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000003FUH00`00
FUIJEP02FUH7000;Ool50006Ool40002FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002ioo`00
EWoo0`0000=JEP0000001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YF000000=JEP03001JEP00008000=JEP04001JEUYFFUH90002Ool5000:Ool40005
FUH01`00FUIJEUYF001JEP0002ioo`00F7oo0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00L005YFFUIJEP00FUH00009FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH01000FUH000000eYF0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF
4P000eYF100000=JEP00FUH00UYF00<005YF0000;Woo0015OolC0002FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEP000002FUH00`00FUH0
0006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
0eYF00<005YF0000;Woo000mOol80004FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0UYF0P002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF00000`000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00H005YFFUH005YF000^Ool003Ioo`L000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEQ4000=JEP03001JEUYF
009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP00008000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP@00003FUH007oo02eoo`00<Woo10000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH01UYF00<005YFFUH015YF1`000eYF2@00
15YF1@000eYF0P002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF0000
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000^Ool0031oo`<000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04
0006FUH00`00FUIJEP06FUH<00001eYF000005YF001JEP0000QJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000^Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00001EYF00<005YFFUH015YF10000eYF00<005YFFUH015YF00<005YFFUH01P000eYF
00<005YFFUH015YF00<005YF0000100000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eo
o`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUIJEP02FUH20003FUH01@00FUIJEUYF00001UYF0`0000=JEP00FUH01eYF
00<005YFFUH015YF00<005YFFUH00P0000=JEP00000025YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo
0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000UYF
00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH00UYF00D005YFFUIJEP0000AJEP<000AJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH40008FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUHQ0003FUH0
0`00Oomoo`0]Ool002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEP03001JEUYF00=JEP8000AJEP05001JEUYFFUH00003FUH00`00FUH00002
0007FUH00`00FUIJEP05FUH50003FUH01000FUIJEUYF0`0025YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00<00003FUH007oo02ioo`00;Goo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YF
FUH00`001EYF00D005YFFUIJEP0000=JEP800003FUH005YF00QJEP03001JEUYF00D000=JEPL00004
FUH005YF0008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0`00
00=JEP00FUH01@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0`00;goo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH20003FUH30002FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP80
00=JEP03001JEUYF00EJEPP000IJEP03001JEUYF00=JEP@000QJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH300000eYF001JEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000_Ool0
02eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00EJEP80
00=JEPL000AJEP04001JEUYFFUH20006FUH00`00FUIJEP060004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000
FUIJEUYF0`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00@005YFFUIJ
EPP000QJEP<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000MJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00UYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH20004FUH00`00FUIJEP04FUH40007FUH20004FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH2000015YF001JEP001UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
;goo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH20004FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUH00000FUH000IJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0002moo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF0P0015YF00@005YFFUIJEP8000EJEP03001JEUYF00<000QJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF0080009JEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP00;Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH=
00000eYF001JEP03FUH01000FUIJEP0025YF0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000AJEP00FUH0009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000^Ool002eo
o`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEPP000EJEP03001JEUYF00AJEP03001J
EUYF00EJEP<000IJEP8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=J
EP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEP0000=JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EQ0000=JEP03001JEUYF009JEP04001JEUYF000^Ool002eoo`03001JEP00009JEP04001JEUYFFUHF
0007FUH00`00FUH00004FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF0P001EYF0`000UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF009JEPT00003FUH005YF00MJEP03001JEUYF00=JEPH0009JEP04001JEUYF000^Ool002eoo`03
001JEP00009JEP@000=JEP@00003FUH005YF00MJEP03001JEUYF009JEPX000AJEP04001JEUYF0003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020007FUH00`00FUH0
0002FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EP000UYF00<005YFFUH00UYF00<005YFFUH00UYF200000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF100000=JEP00Ool0;Goo000]Ool00`00FUH00002000015YF001J
EUYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH0
0UYF10001eYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF0`002EYF00@005YFFUIJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0002FUH01000FUIJEUYF1P00
00=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000002ioo`00;Goo00<005YF00000eYF0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF0P001EYF00@005YFFUH000QJEP04001JEUYFFUH60002FUH40000
0eYF001JEP08FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01000FUIJEP000UYF00<005YF00000P001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002ioo`00;Goo0`0000=JEP00
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0015YF
00D005YFFUIJEP0000QJEP04001JEUYFFUH80005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YF000002ioo`00;Goo00<005YF00000P001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF00<005YF0000500025YF00<0
05YFFUH015YF0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00`0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`00<7oo000^Ool200000eYF001JEP04FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01P00FUIJEP00FUH000AJ
EP<00003FUH0000000=JEP03001JEUYF00=JEP<000UJEP03001JEUYF00=JEP04001JEUYF0003FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00002FUH0
0`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000cOol002ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020005FUH00`00FUIJEP030003
FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUH0000<
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUH00000FUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50006Ool2
000^Ool002ioo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001J
EUYF00QJEP03001JEUYF008000EJEP<000aJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH800000goo0000000800000eYF001oo`0]Ool002ioo`04001JEUYF0004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YF
FUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEP0000MJEP03001JEP0000aJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00003FUHP0003Ool60003
FUH00`00FUIJEP02FUH01000FUIJEP00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH01EYF00<0
05YFFUH00UYF200015YF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP0000IJEP03001JEUYF00QJEP<000EJEP80009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00007FUH00`00FUIJEP04FUH01000FUIJEUYF
0P003Woo100000=JEP00FUH01UYF00<005YFFUH00UYF00@005YFFUH002ioo`00;Woo00@005YFFUH0
00AJEP03001JEUYF009JEPP000Qoo`T00003FUH00000008000IJEP03001JEUYF00=JEP05001JEUYF
FUH00006FUH00`00FUIJEP06FUH20003FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP04
001JEUYFFUH20007Ool70005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^
Ool01000FUIJEP000eYF5@002Woo0P0000AJEP00000000EJEP03001JEUYF00=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP04FUH20005FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000QJEP03001JEUYF00=JEP04001JEUYF
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Goo000^
Ool01@00FUIJEP00FUH00P000Woo100000=JEP00FUH01eYF00<005YFFUH00UYF1P001Goo00<005YF
00000Woo0P000eYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH0100025YF00<0
05YFFUH01EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D0
05YFFUIJEP0000QJEP03001JEUYF00=JEP03001JEP0000<0009JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH6000]Ool002ioo`03001JEUYF0080009oo`8000EJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004Ool20004Ool200000eYF001JEP03FUH20003
FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP04FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P001eYF00<005YF00001@001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL003=oo`00;Woo00<005YF00001@001EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP<00003Ool00000008000Aoo`8000AJEP8000=J
EP03001JEP0000<000IJEP03001JEUYF009JEP8000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH;0003FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH8000iOol002eoo`H0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP@00003FUH0000000Aoo`80009JEP800003FUH0000000800003FUH0
05YF00QJEP06001JEP00001JEP002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF
00<005YFFUH015YF1`00@Goo000]Ool200000eYF001JEP02FUH00`00FUIJEP03FUH?0004FUH00`00
FUIJEP06FUH2000015YF001JEUYF2`001UYF00<005YFFUH01EYF0`000eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH0009JEP03
001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@004Qoo`00;Goo10000eYF
00<005YF00001@003Goo1P001UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001J
EUYF009JEPL004aoo`00;Goo0P0000=JEP00FUH00UYF0`001EYF0`0047oo10000UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP00008000QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00002
FUH00`00FUIJEP02FUH01000FUIJEUYF2@00DWoo000]Ool30002FUH20002FUH00`00FUIJEP04FUH0
0`00FUH00003000@Ool30004FUH300000eYF001JEP05FUH00`00FUIJEP03FUH6000:FUH00`00FUIJ
EP04FUHH0006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH0
200000=JEP000000EWoo000]Ool00`00FUH000020004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH7
0009Ool50005FUH>0005FUH00`00FUIJEP07FUH80006FUH00`00FUIJEP09FUH00`00FUIJEP03FUH9
0007FUH00`00FUIJEP05FUH01000FUIJEUYF1`001UYF00@005YFFUIJEP8005Aoo`00;Goo00@005YF
000000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP<000=JEP09001J
EUYFFUH005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00=JEP@00003FUH005YF00]JEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEP0000@0009JEP03001JEUYF00EJEP05001JEUYFFUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2001COol002eoo`@000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003FUH005YF00=JEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEP0000<000EJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00AJEP@000IJEP05001JEUYFFUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH00`00FUH0001BOol002aoo`80009oo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001J
EP0000=JEP03001JEUYF00=JEP<000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP<000AJEP05001JEUYFFUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
1000FUIJEP00DWoo000/Ool20003Ool20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30003FUH00`00FUH000030002
FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP0300000eYF001JEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH00UYF00@005YF
FUH0059oo`00;7oo0P001Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF0`0000=JEP00FUH00P000eYF0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00D005YF
FUIJEP0000MJEP03001JEUYF009JEP04001JEUYF001BOol002aoo`<000Ioo`8000EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF0080009JEP03001J
EUYF008000MJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00AJEP80009JEPH000EJEP03001JEUYF00=JEP04001JEUYF001BOol0
02aoo`<000Qoo`8000=JEP03001JEUYF00IJEP03001JEUYF00<000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF0080009JEP05001JEP00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00002
0003FUH00`00FUH0000300000eYF001JEP04FUH01000FUIJEP00DWoo000/Ool01000FUIJEP002Goo
0P0000=JEP00FUH01eYF00<005YF000010000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`000Woo
00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH00003FUH00`00FUIJ
EP03FUH20005FUH01000FUH00000DWoo000/Ool01000FUIJEP002goo1P0015YF00<005YF00001000
0UYF00<005YFFUH01EYF00<005YFFUH00UYF100017oo00<005YF00000eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP<0009JEP04001JEUYF001COol002ao
o`05001JEUYFFUH0000@Ool;0002FUH00`00FUIJEP02FUH80009Ool20003FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH00`000UYF00<007oo
Ool0DGoo000]Ool00`00FUIJEP03000EOol;000AOol20003FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00000eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH005=oo`00;Goo
00@005YFFUH0009JEP03001oogoo02moo`05001JEUYFFUH00007FUH00`00FUIJEP07FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF00000UYF00<005YFFUH015YF00<005YFFUH00eYF1000Dgoo000^Ool20004FUH2000_Ool20002
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUH005=oo`00;Woo0P001UYF00<007ooOol0:goo1P001eYF00<005YFFUH01eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0`00
15YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH005=oo`00;goo00<005YFFUH015YF0`00
:goo0P000goo0P001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH01eYF00<005YFFUH00eYF0P001UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
E7oo000`Ool20004FUH00`00FUIJEP02000XOol00`00FUH00005Ool20004FUH00`00FUIJEP07FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH01000FUIJEUYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<005Ioo`00<Woo00@005YFFUH000EJEP8002Aoo`<00003
FUH007oo00Ioo`<00003FUH005YF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEP0000800003FUH00000009oo`l005Uoo`00<goo0`001eYF0P0087oo
0P000UYF0P002goo10001eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH01EYF100000=JEP00FUH00eYF0`00Igoo000eOol00`00FUIJEP05FUH00`00FUH00002000KOol2
0003FUH2000@Ool50002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP050005FUH00`00FUIJEP05FUH3001TOol003Ioo`8000EJEP03001JEUYF009JEP<001Aoo`@00003
FUH005YF009JEP8001Eoo`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEPT0009JEP03001JEUYF
00<00003FUH005YF00QJEP04001JEP00001ROol003Qoo`80009JEP03001JEUYF00IJEPH000Uoo`D0
00EJEP05001JEUYFFUH0000OOolI0004Ool20005FUH00`00FUIJEP03FUH30008FUH01000FUIJEUYF
0P00H7oo000jOol30009FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP03FUH00`00FUIJEP02000o
Ool300000eYF001JEP08FUH30004FUH00`00FUIJEP04FUH3001MOol003aoo`<000IJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<004Aoo`<000QJEP03001JEUYF00<00003FUH005YF
00IJEP03001JEP00008005Yoo`00?goo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P00BGoo0`001EYF00<005YFFUH00eYF0`001UYF00<005YFFUH00UYF0P00F7oo0013Ool7
0004FUH00`00FUIJEP05FUH00`00FUH00003001>Ool300000eYF001JEP07FUH30003FUH00`00FUIJ
EP04FUH2001GOol004Yoo`h005Eoo`<000MJEP03001JEUYF00800003FUH005YF00AJEP04001JEUYF
001FOol00;1oo`@0009JEP03001JEUYF00=JEP<000AJEP04001JEUYF001FOol00;Aoo`@000IJEP<0
0004FUH005YFFUH2001FOol00;Qoo`@00003FUH005YF009JEP80009JEP8005Ioo`00_7oo10000UYF
1000Egoo0030Ool6001GOol00<Aoo`8005Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5782 .74674 m .58181 .69093 L .55154 .68661 L p .707 .577 .707 r
F P
0 g
s
.58181 .69093 m .5782 .74674 L .6101 .74874 L p .707 .577 .707 r
F P
0 g
s
.6101 .74874 m .61372 .69292 L .58181 .69093 L p .707 .577 .707 r
F P
0 g
s
.61372 .69292 m .6101 .74874 L .64051 .74821 L p .707 .577 .707 r
F P
0 g
s
.64051 .74821 m .64413 .69239 L .61372 .69292 L p .707 .577 .707 r
F P
0 g
s
.54793 .74242 m .55154 .68661 L .52586 .68038 L p .707 .577 .707 r
F P
0 g
s
.55154 .68661 m .54793 .74242 L .5782 .74674 L p .707 .577 .707 r
F P
0 g
s
.64413 .69239 m .64051 .74821 L .66645 .74521 L p .707 .577 .707 r
F P
0 g
s
.66645 .74521 m .67006 .68939 L .64413 .69239 L p .707 .577 .707 r
F P
0 g
s
.60293 .81341 m .59853 .777 L .56694 .77947 L p .707 .577 .707 r
F P
0 g
s
.59853 .777 m .60293 .81341 L .63399 .80796 L p .707 .577 .707 r
F P
0 g
s
.63399 .80796 m .62958 .77155 L .59853 .777 L p .707 .577 .707 r
F P
0 g
s
.52586 .68038 m .52224 .7362 L .54793 .74242 L p .707 .577 .707 r
F P
0 g
s
.57135 .81588 m .56694 .77947 L .53791 .77873 L p .707 .577 .707 r
F P
0 g
s
.56694 .77947 m .57135 .81588 L .60293 .81341 L p .707 .577 .707 r
F P
0 g
s
.62958 .77155 m .63399 .80796 L .66147 .80008 L p .707 .577 .707 r
F P
0 g
s
.66147 .80008 m .65706 .76367 L .62958 .77155 L p .707 .577 .707 r
F P
0 g
s
.52224 .7362 m .52586 .68038 L .50728 .67287 L p .707 .577 .707 r
F P
0 g
s
.67006 .68939 m .66645 .74521 L .68538 .74004 L p .707 .577 .707 r
F P
0 g
s
.68538 .74004 m .68899 .68422 L .67006 .68939 L p .707 .577 .707 r
F P
0 g
s
.53791 .77873 m .54232 .81514 L .57135 .81588 L p .707 .577 .707 r
F P
0 g
s
.54232 .81514 m .53791 .77873 L .51428 .77485 L p .707 .577 .707 r
F P
0 g
s
.65706 .76367 m .66147 .80008 L .68268 .79054 L p .707 .577 .707 r
F P
0 g
s
.68268 .79054 m .67827 .75412 L .65706 .76367 L p .707 .577 .707 r
F P
0 g
s
.50728 .67287 m .50367 .72868 L .52224 .7362 L p .707 .577 .707 r
F P
0 g
s
.60774 .85919 m .60215 .84195 L .57193 .8488 L p .707 .577 .707 r
F P
0 g
s
.60215 .84195 m .60774 .85919 L .63795 .84885 L p .707 .577 .707 r
F P
0 g
s
.63795 .84885 m .63236 .8316 L .60215 .84195 L p .707 .577 .707 r
F P
0 g
s
.63236 .8316 m .63795 .84885 L .66519 .83602 L p .707 .577 .707 r
F P
0 g
s
.66519 .83602 m .65961 .81878 L .63236 .8316 L p .707 .577 .707 r
F P
0 g
s
.57193 .8488 m .57752 .86604 L .60774 .85919 L p .707 .577 .707 r
F P
0 g
s
.51428 .77485 m .51869 .81126 L .54232 .81514 L p .707 .577 .707 r
F P
0 g
s
.57752 .86604 m .57193 .8488 L .54467 .85148 L p .707 .577 .707 r
F P
0 g
s
.50367 .72868 m .50728 .67287 L .49763 .66479 L p .707 .577 .707 r
F P
0 g
s
.68899 .68422 m .68538 .74004 L .69545 .73319 L p .707 .577 .707 r
F P
0 g
s
.69545 .73319 m .69906 .67737 L .68899 .68422 L p .707 .577 .707 r
F P
0 g
s
.65961 .81878 m .66519 .83602 L .68681 .82196 L p .707 .577 .707 r
F P
0 g
s
.68681 .82196 m .68123 .80472 L .65961 .81878 L p .707 .577 .707 r
F P
0 g
s
.54467 .85148 m .55026 .86872 L .57752 .86604 L p .707 .577 .707 r
F P
0 g
s
.51869 .81126 m .51428 .77485 L .49836 .76821 L p .707 .577 .707 r
F P
0 g
s
.67827 .75412 m .68268 .79054 L .69555 .78026 L p .707 .577 .707 r
F P
0 g
s
.69555 .78026 m .69115 .74385 L .67827 .75412 L p .707 .577 .707 r
F P
0 g
s
.49763 .66479 m .49402 .72061 L .50367 .72868 L p .707 .577 .707 r
F P
0 g
s
.55026 .86872 m .54467 .85148 L .52303 .84973 L p .707 .577 .707 r
F P
0 g
s
.49836 .76821 m .50277 .80462 L .51869 .81126 L p .707 .577 .707 r
F P
0 g
s
.52303 .84973 m .52861 .86697 L .55026 .86872 L p .707 .577 .707 r
F P
0 g
s
.68123 .80472 m .68681 .82196 L .70068 .80805 L p .707 .577 .707 r
F P
0 g
s
.70068 .80805 m .6951 .79081 L .68123 .80472 L p .707 .577 .707 r
F P
0 g
s
.49402 .72061 m .49763 .66479 L .49785 .65695 L p .708 .578 .707 r
F P
0 g
s
.69906 .67737 m .69545 .73319 L .69566 .72535 L p .708 .578 .707 r
F P
0 g
s
.69566 .72535 m .69928 .66953 L .69906 .67737 L p .708 .578 .707 r
F P
0 g
s
.50277 .80462 m .49836 .76821 L .49171 .75945 L p .707 .577 .707 r
F P
0 g
s
.69184 .74962 m .69555 .78026 L .69807 .77256 L p .707 .577 .707 r
F P
0 g
s
.70545 .79565 m .69987 .77841 L .6951 .79081 L p .707 .577 .707 r
F P
0 g
s
.70065 .78597 m .69507 .76873 L .6994 .77747 L p .707 .577 .707 r
F P
0 g
s
.6994 .77747 m .69987 .77841 L p .7 .77967 L .707 .577 .707 r
F P
0 g
s
.70065 .78597 m .6994 .77747 L .7 .77967 L .707 .577 .707 r
F
.69115 .74385 m .69184 .74962 L p .69883 .77025 L F P
0 g
s
.69807 .77256 m .69883 .77025 L p .69184 .74962 L .707 .577 .707 r
F P
0 g
s
.69883 .77025 m .69442 .73384 L .69115 .74385 L p .707 .577 .707 r
F P
0 g
s
.52861 .86697 m .52303 .84973 L .50913 .84372 L p .707 .577 .707 r
F P
0 g
s
.49785 .65695 m .49423 .71276 L .49402 .72061 L p .708 .578 .707 r
F P
0 g
s
.50913 .84372 m .51471 .86096 L .52861 .86697 L p .707 .577 .707 r
F P
0 g
s
.49171 .75945 m .49612 .79587 L .50277 .80462 L p .707 .577 .707 r
F P
0 g
s
.6951 .79081 m .70068 .80805 L .70545 .79565 L p .707 .577 .707 r
F P
0 g
s
.49423 .71276 m .49785 .65695 L .50791 .6501 L p .707 .577 .707 r
F P
0 g
s
.50791 .6501 m .5043 .70592 L .49423 .71276 L p .707 .577 .707 r
F P
0 g
s
.49498 .74945 m .49939 .78586 L .49612 .79587 L p .707 .577 .707 r
F P
0 g
s
.49939 .78586 m .49498 .74945 L .50786 .73917 L p .707 .577 .707 r
F P
0 g
s
.50786 .73917 m .51226 .77558 L .49939 .78586 L p .707 .577 .707 r
F P
0 g
s
.50224 .82192 m .50224 .32003 L .45756 .31832 L p .707 .577 .707 r
F P
0 g
s
.5043 .70592 m .50791 .6501 L .52684 .64493 L p .707 .577 .707 r
F P
0 g
s
.52684 .64493 m .52323 .70074 L .5043 .70592 L p .707 .577 .707 r
F P
0 g
s
.52323 .70074 m .52684 .64493 L .55278 .64193 L p .707 .577 .707 r
F P
0 g
s
.51226 .77558 m .50786 .73917 L .52907 .72962 L p .707 .577 .707 r
F P
0 g
s
.51468 .83888 m .50909 .82164 L .52297 .80773 L p .707 .577 .707 r
F P
0 g
s
.55278 .64193 m .54917 .69775 L .52323 .70074 L p .707 .577 .707 r
F P
0 g
s
.52297 .80773 m .52855 .82497 L .51468 .83888 L p .707 .577 .707 r
F P
0 g
s
.52907 .72962 m .53348 .76603 L .51226 .77558 L p .707 .577 .707 r
F P
0 g
s
.53348 .76603 m .52907 .72962 L .55655 .72174 L p .707 .577 .707 r
F P
0 g
s
.52855 .82497 m .52297 .80773 L .54459 .79367 L p .707 .577 .707 r
F P
0 g
s
.55655 .72174 m .56096 .75815 L .53348 .76603 L p .707 .577 .707 r
F P
0 g
s
.54459 .79367 m .55017 .81091 L .52855 .82497 L p .707 .577 .707 r
F P
0 g
s
.50224 .32003 m .50224 .82192 L .5467 .81984 L p .707 .577 .707 r
F P
0 g
s
.55017 .81091 m .54459 .79367 L .57183 .78084 L p .707 .577 .707 r
F P
0 g
s
.5467 .81984 m .5467 .31795 L .50224 .32003 L p .707 .577 .707 r
F P
0 g
s
.45756 .82021 m .45756 .31832 L .41704 .31299 L p .707 .577 .707 r
F P
0 g
s
.49612 .79587 m .49171 .75945 L .49498 .74945 L p .707 .577 .707 r
F P
0 g
s
.45756 .31832 m .45756 .82021 L .50224 .82192 L p .707 .577 .707 r
F P
0 g
s
.54917 .69775 m .55278 .64193 L .58319 .6414 L p .707 .577 .707 r
F P
0 g
s
.58319 .6414 m .57958 .69722 L .54917 .69775 L p .707 .577 .707 r
F P
0 g
s
.56096 .75815 m .55655 .72174 L .5876 .7163 L p .707 .577 .707 r
F P
0 g
s
.5876 .7163 m .59201 .75271 L .56096 .75815 L p .707 .577 .707 r
F P
0 g
s
.57183 .78084 m .57742 .79809 L .55017 .81091 L p .707 .577 .707 r
F P
0 g
s
.57742 .79809 m .57183 .78084 L .60204 .7705 L p .707 .577 .707 r
F P
0 g
s
.60204 .7705 m .60763 .78774 L .57742 .79809 L p .707 .577 .707 r
F P
0 g
s
.5467 .31795 m .5467 .81984 L .58659 .81417 L p .707 .577 .707 r
F P
0 g
s
.57958 .69722 m .58319 .6414 L .61509 .64339 L p .707 .577 .707 r
F P
0 g
s
.61509 .64339 m .61148 .69921 L .57958 .69722 L p .707 .577 .707 r
F P
0 g
s
.58659 .81417 m .58659 .31229 L .5467 .31795 L p .707 .577 .707 r
F P
0 g
s
.69928 .66953 m .69566 .72535 L .68601 .71727 L p .707 .577 .707 r
F P
0 g
s
.68601 .71727 m .68963 .66145 L .69928 .66953 L p .707 .577 .707 r
F P
0 g
s
.51471 .86096 m .50913 .84372 L .50433 .83404 L p .707 .577 .707 r
F P
0 g
s
.69442 .73384 m .69883 .77025 L .69218 .7615 L p .707 .577 .707 r
F P
0 g
s
.69218 .7615 m .68777 .72509 L .69442 .73384 L p .707 .577 .707 r
F P
0 g
s
.50433 .83404 m .50991 .85128 L .51471 .86096 L p .707 .577 .707 r
F P
0 g
s
.41704 .81488 m .41704 .31299 L .38463 .30456 L p .707 .577 .707 r
F P
0 g
s
.41704 .31299 m .41704 .81488 L .45756 .82021 L p .707 .577 .707 r
F P
0 g
s
.69987 .77841 m .70545 .79565 L .70065 .78597 L p .707 .577 .707 r
F P
0 g
s
.61919 .71383 m .6236 .75024 L .59201 .75271 L p .707 .577 .707 r
F P
0 g
s
.59201 .75271 m .5876 .7163 L .61919 .71383 L p .707 .577 .707 r
F P
0 g
s
.63226 .76365 m .63784 .78089 L .60763 .78774 L p .707 .577 .707 r
F P
0 g
s
.60763 .78774 m .60204 .7705 L .63226 .76365 L p .707 .577 .707 r
F P
0 g
s
.58659 .31229 m .58659 .81417 L .618 .80548 L p .707 .577 .707 r
F P
0 g
s
.64537 .64771 m .64176 .70353 L .61148 .69921 L p .707 .577 .707 r
F P
0 g
s
.61148 .69921 m .61509 .64339 L .64537 .64771 L p .707 .577 .707 r
F P
0 g
s
.618 .80548 m .618 .30359 L .58659 .31229 L p .707 .577 .707 r
F P
0 g
s
.23989 .71632 m .24137 .66196 L .21104 .65786 L p .707 .577 .707 r
F P
0 g
s
.24137 .66196 m .23989 .71632 L .27184 .71716 L p .707 .577 .707 r
F P
0 g
s
.27184 .71716 m .27333 .6628 L .24137 .66196 L p .707 .577 .707 r
F P
0 g
s
.27333 .6628 m .27184 .71716 L .30229 .71466 L p .707 .577 .707 r
F P
0 g
s
.30229 .71466 m .30378 .66029 L .27333 .6628 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68963 .66145 m .68601 .71727 L .66744 .70975 L p .707 .577 .707 r
F P
0 g
s
.66744 .70975 m .67105 .65394 L .68963 .66145 L p .707 .577 .707 r
F P
0 g
s
.50991 .85128 m .50433 .83404 L .50909 .82164 L p .707 .577 .707 r
F P
0 g
s
.68777 .72509 m .69218 .7615 L .67626 .75486 L p .707 .577 .707 r
F P
0 g
s
.67626 .75486 m .67185 .71845 L .68777 .72509 L p .707 .577 .707 r
F P
0 g
s
.20956 .71222 m .21104 .65786 L .1853 .65091 L p .707 .577 .707 r
F P
0 g
s
.21104 .65786 m .20956 .71222 L .23989 .71632 L p .707 .577 .707 r
F P
0 g
s
.30378 .66029 m .30229 .71466 L .32826 .70906 L p .707 .577 .707 r
F P
0 g
s
.32826 .70906 m .32974 .6547 L .30378 .66029 L p .707 .577 .707 r
F P
0 g
s
.50909 .82164 m .51468 .83888 L .50991 .85128 L p .707 .577 .707 r
F P
0 g
s
.38463 .80645 m .38463 .30456 L .36352 .29386 L p .707 .577 .707 r
F P
0 g
s
.38463 .30456 m .38463 .80645 L .41704 .81488 L p .707 .577 .707 r
F P
0 g
s
.69507 .76873 m .70065 .78597 L .68675 .77996 L p .707 .577 .707 r
F P
0 g
s
.68675 .77996 m .68116 .76272 L .69507 .76873 L p .707 .577 .707 r
F P
0 g
s
.64822 .71457 m .65263 .75098 L .6236 .75024 L p .707 .577 .707 r
F P
0 g
s
.6236 .75024 m .61919 .71383 L .64822 .71457 L p .707 .577 .707 r
F P
0 g
s
.63784 .78089 m .63226 .76365 L .65952 .76097 L p .707 .577 .707 r
F P
0 g
s
.618 .30359 m .618 .80548 L .63786 .7946 L p .707 .577 .707 r
F P
0 g
s
.65952 .76097 m .66511 .77821 L .63784 .78089 L p .707 .577 .707 r
F P
0 g
s
.63786 .7946 m .63786 .29272 L .618 .30359 L p .707 .577 .707 r
F P
0 g
s
.26334 .75737 m .26163 .71928 L .22985 .72026 L p .707 .577 .707 r
F P
0 g
s
.26163 .71928 m .26334 .75737 L .29454 .75509 L p .707 .577 .707 r
F P
0 g
s
.29454 .75509 m .29283 .717 L .26163 .71928 L p .707 .577 .707 r
F P
0 g
s
.23156 .75835 m .22985 .72026 L .20061 .71986 L p .707 .577 .707 r
F P
0 g
s
.22985 .72026 m .23156 .75835 L .26334 .75737 L p .707 .577 .707 r
F P
0 g
s
.18382 .70527 m .1853 .65091 L .16667 .64178 L p .707 .577 .707 r
F P
0 g
s
.1853 .65091 m .18382 .70527 L .20956 .71222 L p .707 .577 .707 r
F P
0 g
s
.32974 .6547 m .32826 .70906 L .3472 .70092 L p .707 .577 .707 r
F P
0 g
s
.3472 .70092 m .34868 .64655 L .32974 .6547 L p .707 .577 .707 r
F P
0 g
s
.67105 .65394 m .66744 .70975 L .64176 .70353 L p .707 .577 .707 r
F P
0 g
s
.64176 .70353 m .64537 .64771 L .67105 .65394 L p .707 .577 .707 r
F P
0 g
s
.23091 .76282 m .23309 .78184 L .26458 .77785 L p .707 .577 .707 r
F P
0 g
s
.26458 .77785 m .2624 .75883 L .23091 .76282 L p .707 .577 .707 r
F P
0 g
s
.2624 .75883 m .26458 .77785 L .2958 .77488 L p .707 .577 .707 r
F P
0 g
s
.29283 .717 m .29454 .75509 L .32212 .75174 L p .707 .577 .707 r
F P
0 g
s
.32212 .75174 m .3204 .71365 L .29283 .717 L p .707 .577 .707 r
F P
0 g
s
.2958 .77488 m .29362 .75586 L .2624 .75883 L p .707 .577 .707 r
F P
0 g
s
.20061 .71986 m .20232 .75795 L .23156 .75835 L p .707 .577 .707 r
F P
0 g
s
.20223 .76745 m .20441 .78646 L .23309 .78184 L p .707 .577 .707 r
F P
0 g
s
.23309 .78184 m .23091 .76282 L .20223 .76745 L p .707 .577 .707 r
F P
0 g
s
.29362 .75586 m .2958 .77488 L .3237 .77322 L p .707 .577 .707 r
F P
0 g
s
.67185 .71845 m .67626 .75486 L .65263 .75098 L p .707 .577 .707 r
F P
0 g
s
.65263 .75098 m .64822 .71457 L .67185 .71845 L p .707 .577 .707 r
F P
0 g
s
.3237 .77322 m .32152 .75421 L .29362 .75586 L p .707 .577 .707 r
F P
0 g
s
.20232 .75795 m .20061 .71986 L .17677 .71811 L p .707 .577 .707 r
F P
0 g
s
.17677 .71811 m .17848 .7562 L .20232 .75795 L p .707 .577 .707 r
F P
0 g
s
.3204 .71365 m .32212 .75174 L .34337 .74765 L p .707 .577 .707 r
F P
0 g
s
.34337 .74765 m .34165 .70956 L .3204 .71365 L p .707 .577 .707 r
F P
0 g
s
.17917 .77225 m .18135 .79127 L .20441 .78646 L p .707 .577 .707 r
F P
0 g
s
.20441 .78646 m .20223 .76745 L .17917 .77225 L p .707 .577 .707 r
F P
0 g
s
.68116 .76272 m .68675 .77996 L .66511 .77821 L p .707 .577 .707 r
F P
0 g
s
.66511 .77821 m .65952 .76097 L .68116 .76272 L p .707 .577 .707 r
F P
0 g
s
.16667 .64178 m .16519 .69614 L .18382 .70527 L p .707 .577 .707 r
F P
0 g
s
.32152 .75421 m .3237 .77322 L .34555 .77304 L p .707 .577 .707 r
F P
0 g
s
.16519 .69614 m .16667 .64178 L .15698 .63136 L p .707 .577 .707 r
F P
0 g
s
.34555 .77304 m .34336 .75403 L .32152 .75421 L p .707 .577 .707 r
F P
0 g
s
.34868 .64655 m .3472 .70092 L .35725 .69102 L p .707 .577 .707 r
F P
0 g
s
.35725 .69102 m .35874 .63666 L .34868 .64655 L p .707 .577 .707 r
F P
0 g
s
.35701 .75534 m .35919 .77436 L .36331 .77704 L p .707 .577 .707 r
F P
0 g
s
.36331 .77704 m .36113 .75802 L .35701 .75534 L p .707 .577 .707 r
F P
0 g
s
.34336 .75403 m .34555 .77304 L .35919 .77436 L p .707 .577 .707 r
F P
0 g
s
.35919 .77436 m .35701 .75534 L .34336 .75403 L p .707 .577 .707 r
F P
0 g
s
.36113 .75802 m .36331 .77704 L .3575 .78082 L p .707 .577 .707 r
F P
0 g
s
.36352 .79575 m .36352 .29386 L .35577 .28193 L p .707 .577 .707 r
F P
0 g
s
.36352 .29386 m .36352 .79575 L .38463 .80645 L p .707 .577 .707 r
F P
0 g
s
.17848 .7562 m .17677 .71811 L .16066 .71517 L p .707 .577 .707 r
F P
0 g
s
.63786 .29272 m .63786 .7946 L .64423 .78262 L p .707 .577 .707 r
F P
0 g
s
.64423 .78262 m .64423 .28073 L .63786 .29272 L p .707 .577 .707 r
F P
0 g
s
.16066 .71517 m .16237 .75327 L .17848 .7562 L p .707 .577 .707 r
F P
0 g
s
.16399 .77677 m .16617 .79578 L .18135 .79127 L p .707 .577 .707 r
F P
0 g
s
.18135 .79127 m .17917 .77225 L .16399 .77677 L p .707 .577 .707 r
F P
0 g
s
.34165 .70956 m .34337 .74765 L .35621 .74321 L p .707 .577 .707 r
F P
0 g
s
.35621 .74321 m .35449 .70512 L .34165 .70956 L p .707 .577 .707 r
F P
0 g
s
.15698 .63136 m .15549 .68573 L .16519 .69614 L p .707 .577 .707 r
F P
0 g
s
.15549 .68573 m .15698 .63136 L .15717 .62069 L p .709 .579 .707 r
F P
0 g
s
.35874 .63666 m .35725 .69102 L .35745 .68035 L p .709 .579 .707 r
F P
0 g
s
.35745 .68035 m .35893 .62598 L .35874 .63666 L p .709 .579 .707 r
F P
0 g
s
.16237 .75327 m .16066 .71517 L .15386 .71135 L p .707 .577 .707 r
F P
0 g
s
.15386 .71135 m .15558 .74944 L .16237 .75327 L p .707 .577 .707 r
F P
0 g
s
.15818 .78055 m .16036 .79956 L .16617 .79578 L p .707 .577 .707 r
F P
0 g
s
.16617 .79578 m .16399 .77677 L .15818 .78055 L p .707 .577 .707 r
F P
0 g
s
.35449 .70512 m .35621 .74321 L .35938 .73887 L p .707 .577 .707 r
F P
0 g
s
.35938 .73887 m .35767 .70078 L .35449 .70512 L p .707 .577 .707 r
F P
0 g
s
.35893 .62598 m .35745 .68035 L .34775 .66993 L p .707 .577 .707 r
F P
0 g
s
.34775 .66993 m .34924 .61557 L .35893 .62598 L p .707 .577 .707 r
F P
0 g
s
.35767 .70078 m .35938 .73887 L .35258 .73505 L p .707 .577 .707 r
F P
0 g
s
.35258 .73505 m .35087 .69696 L .35767 .70078 L p .707 .577 .707 r
F P
0 g
s
.3575 .78082 m .35531 .7618 L .36113 .75802 L p .707 .577 .707 r
F P
0 g
s
.35531 .7618 m .3575 .78082 L .34803 .78363 L p .707 .577 .707 r
F P
0 g
s
.34803 .78363 m .34232 .78533 L p .3482 .77469 L .707 .577 .707 r
F P
0 g
s
.3482 .77469 m .35531 .7618 L .34803 .78363 L .707 .577 .707 r
F
.35919 .50823 m .35577 .78382 L .36352 .79575 L p F P
0 g
s
.35577 .37445 m .35689 .35608 L p .35577 .28193 L .707 .577 .707 r
F P
0 g
s
.35577 .78382 m .35577 .37445 L p .36214 .26994 L .707 .577 .707 r
F P
0 g
s
.35577 .37445 m .35577 .28193 L .35759 .27851 L p .707 .577 .707 r
F P
0 g
s
.35759 .27851 m .36214 .26994 L p .35577 .37445 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15717 .62069 m .15568 .67505 L .15549 .68573 L p .709 .579 .707 r
F P
0 g
s
.64423 .28073 m .64423 .78262 L .63647 .77069 L p .707 .577 .707 r
F P
0 g
s
.63647 .77069 m .63647 .2688 L .64423 .28073 L p .707 .577 .707 r
F P
0 g
s
.15568 .67505 m .15717 .62069 L .16723 .61079 L p .707 .577 .707 r
F P
0 g
s
.15558 .74944 m .15386 .71135 L .15704 .70701 L p .707 .577 .707 r
F P
0 g
s
.15704 .70701 m .15875 .7451 L .15558 .74944 L p .707 .577 .707 r
F P
0 g
s
.16229 .78323 m .16448 .80224 L .16036 .79956 L p .707 .577 .707 r
F P
0 g
s
.16036 .79956 m .15818 .78055 L .16229 .78323 L p .707 .577 .707 r
F P
0 g
s
.16723 .61079 m .16574 .66516 L .15568 .67505 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16574 .66516 m .16723 .61079 L .18616 .60265 L p .707 .577 .707 r
F P
0 g
s
.34924 .61557 m .34775 .66993 L .32912 .6608 L p .707 .577 .707 r
F P
0 g
s
.32912 .6608 m .33061 .60644 L .34924 .61557 L p .707 .577 .707 r
F P
0 g
s
.36214 .77183 m .36214 .26994 L .382 .25907 L p .707 .577 .707 r
F P
0 g
s
.36214 .26994 m .36214 .77183 L .35577 .78382 L p .707 .577 .707 r
F P
0 g
s
.63647 .2688 m .63647 .77069 L .61536 .75998 L p .707 .577 .707 r
F P
0 g
s
.61536 .75998 m .61536 .25809 L .63647 .2688 L p .707 .577 .707 r
F P
0 g
s
.15875 .7451 m .15704 .70701 L .16988 .70258 L p .707 .577 .707 r
F P
0 g
s
.16988 .70258 m .17159 .74067 L .15875 .7451 L p .707 .577 .707 r
F P
0 g
s
.17594 .78454 m .17813 .80355 L .16448 .80224 L p .707 .577 .707 r
F P
0 g
s
.16448 .80224 m .16229 .78323 L .17594 .78454 L p .707 .577 .707 r
F P
0 g
s
.18616 .60265 m .18468 .65701 L .16574 .66516 L p .707 .577 .707 r
F P
0 g
s
.35087 .69696 m .35258 .73505 L .33647 .73212 L p .707 .577 .707 r
F P
0 g
s
.33647 .73212 m .33476 .69403 L .35087 .69696 L p .707 .577 .707 r
F P
0 g
s
.18468 .65701 m .18616 .60265 L .21213 .59705 L p .707 .577 .707 r
F P
0 g
s
.33061 .60644 m .32912 .6608 L .30338 .65385 L p .707 .577 .707 r
F P
0 g
s
.30338 .65385 m .30487 .59949 L .33061 .60644 L p .707 .577 .707 r
F P
0 g
s
.34232 .78533 m .34013 .76632 L .35531 .7618 L p .707 .577 .707 r
F P
0 g
s
.17159 .74067 m .16988 .70258 L .19112 .69849 L p .707 .577 .707 r
F P
0 g
s
.382 .25907 m .382 .76096 L .36214 .77183 L p .707 .577 .707 r
F P
0 g
s
.382 .76096 m .382 .25907 L .41341 .25037 L p .707 .577 .707 r
F P
0 g
s
.21064 .65142 m .21213 .59705 L .24258 .59455 L p .707 .577 .707 r
F P
0 g
s
.21213 .59705 m .21064 .65142 L .18468 .65701 L p .707 .577 .707 r
F P
0 g
s
.30487 .59949 m .30338 .65385 L .27305 .64975 L p .707 .577 .707 r
F P
0 g
s
.27305 .64975 m .27453 .59539 L .30487 .59949 L p .707 .577 .707 r
F P
0 g
s
.19112 .69849 m .19284 .73658 L .17159 .74067 L p .707 .577 .707 r
F P
0 g
s
.61536 .25809 m .61536 .75998 L .58296 .75156 L p .707 .577 .707 r
F P
0 g
s
.58296 .75156 m .58296 .24967 L .61536 .25809 L p .707 .577 .707 r
F P
0 g
s
.19779 .78436 m .19997 .80337 L .17813 .80355 L p .707 .577 .707 r
F P
0 g
s
.17813 .80355 m .17594 .78454 L .19779 .78436 L p .707 .577 .707 r
F P
0 g
s
.7589 .65218 m .75742 .59568 L .72546 .59645 L p .707 .577 .707 r
F P
0 g
s
.75742 .59568 m .7589 .65218 L .78935 .64946 L p .707 .577 .707 r
F P
0 g
s
.78935 .64946 m .78787 .59296 L .75742 .59568 L p .707 .577 .707 r
F P
0 g
s
.72695 .65295 m .72546 .59645 L .69513 .59519 L p .707 .577 .707 r
F P
0 g
s
.72546 .59645 m .72695 .65295 L .7589 .65218 L p .707 .577 .707 r
F P
0 g
s
.33476 .69403 m .33647 .73212 L .31263 .73036 L p .707 .577 .707 r
F P
0 g
s
.31263 .73036 m .31092 .69227 L .33476 .69403 L p .707 .577 .707 r
F P
0 g
s
.2411 .64891 m .24258 .59455 L .27453 .59539 L p .707 .577 .707 r
F P
0 g
s
.24258 .59455 m .2411 .64891 L .21064 .65142 L p .707 .577 .707 r
F P
0 g
s
.27453 .59539 m .27305 .64975 L .2411 .64891 L p .707 .577 .707 r
F P
0 g
s
.34013 .76632 m .34232 .78533 L .31926 .79014 L p .707 .577 .707 r
F P
0 g
s
.31926 .79014 m .31708 .77112 L .34013 .76632 L p .707 .577 .707 r
F P
0 g
s
.78787 .59296 m .78935 .64946 L .81532 .64506 L p .707 .577 .707 r
F P
0 g
s
.81532 .64506 m .81383 .58856 L .78787 .59296 L p .707 .577 .707 r
F P
0 g
s
.69661 .65169 m .69513 .59519 L .66939 .59202 L p .707 .577 .707 r
F P
0 g
s
.69513 .59519 m .69661 .65169 L .72695 .65295 L p .707 .577 .707 r
F P
0 g
s
.19284 .73658 m .19112 .69849 L .2187 .69514 L p .707 .577 .707 r
F P
0 g
s
.2187 .69514 m .22041 .73323 L .19284 .73658 L p .707 .577 .707 r
F P
0 g
s
.31092 .69227 m .31263 .73036 L .28339 .72996 L p .707 .577 .707 r
F P
0 g
s
.28339 .72996 m .28168 .69187 L .31092 .69227 L p .707 .577 .707 r
F P
0 g
s
.74838 .73258 m .7501 .69735 L .71832 .69478 L p .707 .577 .707 r
F P
0 g
s
.7501 .69735 m .74838 .73258 L .77958 .73114 L p .707 .577 .707 r
F P
0 g
s
.77958 .73114 m .7813 .69591 L .7501 .69735 L p .707 .577 .707 r
F P
0 g
s
.66939 .59202 m .67087 .64852 L .69661 .65169 L p .707 .577 .707 r
F P
0 g
s
.22568 .78271 m .22787 .80172 L .19997 .80337 L p .707 .577 .707 r
F P
0 g
s
.19997 .80337 m .19779 .78436 L .22568 .78271 L p .707 .577 .707 r
F P
0 g
s
.7166 .73001 m .71832 .69478 L .68908 .68845 L p .707 .577 .707 r
F P
0 g
s
.71832 .69478 m .7166 .73001 L .74838 .73258 L p .707 .577 .707 r
F P
0 g
s
.41341 .75226 m .41341 .25037 L .4533 .24471 L p .707 .577 .707 r
F P
0 g
s
.41341 .25037 m .41341 .75226 L .382 .76096 L p .707 .577 .707 r
F P
0 g
s
.81383 .58856 m .81532 .64506 L .83426 .6394 L p .707 .577 .707 r
F P
0 g
s
.83426 .6394 m .83277 .5829 L .81383 .58856 L p .707 .577 .707 r
F P
0 g
s
.31708 .77112 m .31926 .79014 L .29058 .79476 L p .707 .577 .707 r
F P
0 g
s
.58296 .24967 m .58296 .75156 L .54244 .74623 L p .707 .577 .707 r
F P
0 g
s
.54244 .74623 m .54244 .24434 L .58296 .24967 L p .707 .577 .707 r
F P
0 g
s
.7813 .69591 m .77958 .73114 L .80716 .72583 L p .707 .577 .707 r
F P
0 g
s
.80716 .72583 m .80887 .6906 L .7813 .69591 L p .707 .577 .707 r
F P
0 g
s
.67087 .64852 m .66939 .59202 L .65076 .58726 L p .707 .577 .707 r
F P
0 g
s
.29058 .79476 m .2884 .77575 L .31708 .77112 L p .707 .577 .707 r
F P
0 g
s
.22041 .73323 m .2187 .69514 L .2499 .69286 L p .707 .577 .707 r
F P
0 g
s
.28168 .69187 m .28339 .72996 L .25162 .73095 L p .707 .577 .707 r
F P
0 g
s
.25162 .73095 m .2499 .69286 L .28168 .69187 L p .707 .577 .707 r
F P
0 g
s
.68736 .72368 m .68908 .68845 L .66524 .67898 L p .707 .577 .707 r
F P
0 g
s
.68908 .68845 m .68736 .72368 L .7166 .73001 L p .707 .577 .707 r
F P
0 g
s
.2499 .69286 m .25162 .73095 L .22041 .73323 L p .707 .577 .707 r
F P
0 g
s
.25691 .77974 m .25909 .79875 L .22787 .80172 L p .707 .577 .707 r
F P
0 g
s
.22787 .80172 m .22568 .78271 L .25691 .77974 L p .707 .577 .707 r
F P
0 g
s
.65076 .58726 m .65224 .64376 L .67087 .64852 L p .707 .577 .707 r
F P
0 g
s
.2884 .77575 m .29058 .79476 L .25909 .79875 L p .707 .577 .707 r
F P
0 g
s
.25909 .79875 m .25691 .77974 L .2884 .77575 L p .707 .577 .707 r
F P
0 g
s
.80887 .6906 m .80716 .72583 L .82841 .71717 L p .707 .577 .707 r
F P
0 g
s
.82841 .71717 m .83012 .68194 L .80887 .6906 L p .707 .577 .707 r
F P
0 g
s
.4533 .7466 m .4533 .24471 L .49776 .24263 L p .707 .577 .707 r
F P
0 g
s
.4533 .24471 m .4533 .7466 L .41341 .75226 L p .707 .577 .707 r
F P
0 g
s
.54244 .24434 m .54244 .74623 L .49776 .74452 L p .707 .577 .707 r
F P
0 g
s
.49776 .74452 m .49776 .24263 L .54244 .24434 L p .707 .577 .707 r
F P
0 g
s
.66524 .67898 m .66352 .71421 L .68736 .72368 L p .707 .577 .707 r
F P
0 g
s
.83277 .5829 m .83426 .6394 L .84431 .63304 L p .707 .577 .707 r
F P
0 g
s
.84431 .63304 m .84283 .57654 L .83277 .5829 L p .707 .577 .707 r
F P
0 g
s
.49776 .24263 m .49776 .74452 L .4533 .7466 L p .707 .577 .707 r
F P
0 g
s
.66352 .71421 m .66524 .67898 L .64913 .6673 L p .707 .577 .707 r
F P
0 g
s
.65224 .64376 m .65076 .58726 L .64107 .58138 L p .707 .577 .707 r
F P
0 g
s
.74091 .79162 m .74309 .77633 L .7116 .77096 L p .707 .577 .707 r
F P
0 g
s
.74309 .77633 m .74091 .79162 L .77213 .79097 L p .707 .577 .707 r
F P
0 g
s
.77213 .79097 m .77431 .77567 L .74309 .77633 L p .707 .577 .707 r
F P
0 g
s
.70942 .78626 m .7116 .77096 L .68292 .76011 L p .707 .577 .707 r
F P
0 g
s
.7116 .77096 m .70942 .78626 L .74091 .79162 L p .707 .577 .707 r
F P
0 g
s
.77431 .77567 m .77213 .79097 L .80003 .78436 L p .707 .577 .707 r
F P
0 g
s
.80003 .78436 m .80221 .76907 L .77431 .77567 L p .707 .577 .707 r
F P
0 g
s
.83012 .68194 m .82841 .71717 L .84125 .706 L p .707 .577 .707 r
F P
0 g
s
.84125 .706 m .84296 .67077 L .83012 .68194 L p .707 .577 .707 r
F P
0 g
s
.64107 .58138 m .64255 .63788 L .65224 .64376 L p .707 .577 .707 r
F P
0 g
s
.68074 .7754 m .68292 .76011 L .65986 .74482 L p .707 .577 .707 r
F P
0 g
s
.68292 .76011 m .68074 .7754 L .70942 .78626 L p .707 .577 .707 r
F P
0 g
s
.64913 .6673 m .64741 .70253 L .66352 .71421 L p .707 .577 .707 r
F P
0 g
s
.64741 .70253 m .64913 .6673 L .64233 .65454 L p .707 .577 .707 r
F P
0 g
s
.80221 .76907 m .80003 .78436 L .82187 .77245 L p .707 .577 .707 r
F P
0 g
s
.82187 .77245 m .82406 .75715 L .80221 .76907 L p .707 .577 .707 r
F P
0 g
s
.65986 .74482 m .65768 .76011 L .68074 .7754 L p .707 .577 .707 r
F P
0 g
s
.84283 .57654 m .84431 .63304 L .8445 .6266 L p .707 .577 .707 r
F P
0 g
s
.8445 .6266 m .84302 .5701 L .84283 .57654 L p .707 .577 .707 r
F P
0 g
s
.64255 .63788 m .64107 .58138 L .64126 .57494 L p .707 .577 .707 r
F P
0 g
s
.65768 .76011 m .65986 .74482 L .64468 .7266 L p .707 .577 .707 r
F P
0 g
s
.84296 .67077 m .84125 .706 L .84442 .69343 L p .707 .577 .707 r
F P
0 g
s
.84442 .69343 m .84614 .6582 L .84296 .67077 L p .707 .577 .707 r
F P
0 g
s
.64233 .65454 m .64062 .68977 L .64741 .70253 L p .707 .577 .707 r
F P
0 g
s
.64126 .57494 m .64274 .63144 L .64255 .63788 L p .707 .577 .707 r
F P
0 g
s
.64468 .7266 m .6425 .7419 L .65768 .76011 L p .707 .577 .707 r
F P
0 g
s
.82406 .75715 m .82187 .77245 L .83552 .7564 L p .707 .577 .707 r
F P
0 g
s
.83552 .7564 m .8377 .7411 L .82406 .75715 L p .707 .577 .707 r
F P
0 g
s
.6425 .7419 m .64468 .7266 L .63887 .70723 L p .707 .577 .707 r
F P
0 g
s
.64062 .68977 m .64233 .65454 L .64551 .64197 L p .707 .577 .707 r
F P
0 g
s
.84302 .5701 m .8445 .6266 L .83481 .62071 L p .707 .577 .707 r
F P
0 g
s
.83481 .62071 m .83333 .56421 L .84302 .5701 L p .707 .577 .707 r
F P
0 g
s
.64274 .63144 m .64126 .57494 L .65132 .56858 L p .707 .577 .707 r
F P
0 g
s
.63887 .70723 m .63669 .72253 L .6425 .7419 L p .707 .577 .707 r
F P
0 g
s
.84614 .6582 m .84442 .69343 L .83762 .68067 L p .707 .577 .707 r
F P
0 g
s
.83762 .68067 m .83934 .64544 L .84614 .6582 L p .707 .577 .707 r
F P
0 g
s
.64551 .64197 m .64379 .6772 L .64062 .68977 L p .707 .577 .707 r
F P
0 g
s
.8377 .7411 m .83552 .7564 L .83964 .73777 L p .707 .577 .707 r
F P
0 g
s
.83964 .73777 m .84182 .72248 L .8377 .7411 L p .707 .577 .707 r
F P
0 g
s
.65132 .56858 m .6528 .62508 L .64274 .63144 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63669 .72253 m .63887 .70723 L .64299 .68861 L p .707 .577 .707 r
F P
0 g
s
.64379 .6772 m .64551 .64197 L .65835 .6308 L p .707 .577 .707 r
F P
0 g
s
.42042 .62078 m .41681 .56568 L .38491 .56753 L p .707 .577 .707 r
F P
0 g
s
.41681 .56568 m .42042 .62078 L .45083 .61614 L p .707 .577 .707 r
F P
0 g
s
.45083 .61614 m .44722 .56104 L .41681 .56568 L p .707 .577 .707 r
F P
0 g
s
.38852 .62263 m .38491 .56753 L .35463 .56641 L p .707 .577 .707 r
F P
0 g
s
.38491 .56753 m .38852 .62263 L .42042 .62078 L p .707 .577 .707 r
F P
0 g
s
.64299 .68861 m .6408 .7039 L .63669 .72253 L p .707 .577 .707 r
F P
0 g
s
.83333 .56421 m .83481 .62071 L .81618 .61596 L p .707 .577 .707 r
F P
0 g
s
.81618 .61596 m .8147 .55946 L .83333 .56421 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.6528 .62508 m .65132 .56858 L .67025 .56292 L p .707 .577 .707 r
F P
0 g
s
.44722 .56104 m .45083 .61614 L .47677 .60917 L p .707 .577 .707 r
F P
0 g
s
.47677 .60917 m .47316 .55408 L .44722 .56104 L p .707 .577 .707 r
F P
0 g
s
.84182 .72248 m .83964 .73777 L .83382 .7184 L p .707 .577 .707 r
F P
0 g
s
.83382 .7184 m .83601 .70311 L .84182 .72248 L p .707 .577 .707 r
F P
0 g
s
.83934 .64544 m .83762 .68067 L .82152 .66899 L p .707 .577 .707 r
F P
0 g
s
.82152 .66899 m .82323 .63376 L .83934 .64544 L p .707 .577 .707 r
F P
0 g
s
.35824 .62151 m .35463 .56641 L .32895 .56244 L p .707 .577 .707 r
F P
0 g
s
.35463 .56641 m .35824 .62151 L .38852 .62263 L p .707 .577 .707 r
F P
0 g
s
.65835 .6308 m .65663 .66603 L .64379 .6772 L p .707 .577 .707 r
F P
0 g
s
.67025 .56292 m .67174 .61942 L .6528 .62508 L p .707 .577 .707 r
F P
0 g
s
.6408 .7039 m .64299 .68861 L .65664 .67255 L p .707 .577 .707 r
F P
0 g
s
.40799 .6772 m .41239 .64004 L .38081 .63573 L p .707 .577 .707 r
F P
0 g
s
.41239 .64004 m .40799 .6772 L .43904 .67913 L p .707 .577 .707 r
F P
0 g
s
.43904 .67913 m .44345 .64197 L .41239 .64004 L p .707 .577 .707 r
F P
0 g
s
.65663 .66603 m .65835 .6308 L .6796 .62214 L p .707 .577 .707 r
F P
0 g
s
.3764 .67289 m .38081 .63573 L .35178 .62946 L p .707 .577 .707 r
F P
0 g
s
.38081 .63573 m .3764 .67289 L .40799 .6772 L p .707 .577 .707 r
F P
0 g
s
.47316 .55408 m .47677 .60917 L .4957 .60056 L p .707 .577 .707 r
F P
0 g
s
.4957 .60056 m .49209 .54546 L .47316 .55408 L p .707 .577 .707 r
F P
0 g
s
.32895 .56244 m .33256 .61754 L .35824 .62151 L p .707 .577 .707 r
F P
0 g
s
.65664 .67255 m .65445 .68785 L .6408 .7039 L p .707 .577 .707 r
F P
0 g
s
.8147 .55946 m .81618 .61596 L .79044 .61279 L p .707 .577 .707 r
F P
0 g
s
.79044 .61279 m .78896 .55629 L .8147 .55946 L p .707 .577 .707 r
F P
0 g
s
.44345 .64197 m .43904 .67913 L .46652 .67848 L p .707 .577 .707 r
F P
0 g
s
.46652 .67848 m .47093 .64132 L .44345 .64197 L p .707 .577 .707 r
F P
0 g
s
.33256 .61754 m .32895 .56244 L .31037 .556 L p .707 .577 .707 r
F P
0 g
s
.67174 .61942 m .67025 .56292 L .69622 .55852 L p .707 .577 .707 r
F P
0 g
s
.35178 .62946 m .34737 .66662 L .3764 .67289 L p .707 .577 .707 r
F P
0 g
s
.39237 .7144 m .39795 .69631 L .36774 .68638 L p .707 .577 .707 r
F P
0 g
s
.39795 .69631 m .39237 .7144 L .42258 .72248 L p .707 .577 .707 r
F P
0 g
s
.42258 .72248 m .42816 .70439 L .39795 .69631 L p .707 .577 .707 r
F P
0 g
s
.83601 .70311 m .83382 .7184 L .81865 .70018 L p .707 .577 .707 r
F P
0 g
s
.81865 .70018 m .82083 .68489 L .83601 .70311 L p .707 .577 .707 r
F P
0 g
s
.82323 .63376 m .82152 .66899 L .79767 .65952 L p .707 .577 .707 r
F P
0 g
s
.79767 .65952 m .79939 .62429 L .82323 .63376 L p .707 .577 .707 r
F P
0 g
s
.34737 .66662 m .35178 .62946 L .32815 .62183 L p .707 .577 .707 r
F P
0 g
s
.36215 .70447 m .36774 .68638 L .34048 .67557 L p .707 .577 .707 r
F P
0 g
s
.36774 .68638 m .36215 .70447 L .39237 .7144 L p .707 .577 .707 r
F P
0 g
s
.6796 .62214 m .67788 .65737 L .65663 .66603 L p .707 .577 .707 r
F P
0 g
s
.34048 .67557 m .33489 .69365 L .36215 .70447 L p .707 .577 .707 r
F P
0 g
s
.42816 .70439 m .42258 .72248 L .44983 .72792 L p .707 .577 .707 r
F P
0 g
s
.44983 .72792 m .45541 .70983 L .42816 .70439 L p .707 .577 .707 r
F P
0 g
s
.65445 .68785 m .65664 .67255 L .67848 .66064 L p .707 .577 .707 r
F P
0 g
s
.69622 .55852 m .6977 .61502 L .67174 .61942 L p .707 .577 .707 r
F P
0 g
s
.32815 .62183 m .32374 .65899 L .34737 .66662 L p .707 .577 .707 r
F P
0 g
s
.47093 .64132 m .46652 .67848 L .48773 .67531 L p .707 .577 .707 r
F P
0 g
s
.48773 .67531 m .49214 .63815 L .47093 .64132 L p .707 .577 .707 r
F P
0 g
s
.67788 .65737 m .6796 .62214 L .70717 .61683 L p .707 .577 .707 r
F P
0 g
s
.31037 .556 m .31398 .6111 L .33256 .61754 L p .707 .577 .707 r
F P
0 g
s
.78896 .55629 m .79044 .61279 L .76011 .61153 L p .707 .577 .707 r
F P
0 g
s
.76011 .61153 m .75863 .55503 L .78896 .55629 L p .707 .577 .707 r
F P
0 g
s
.6977 .61502 m .69622 .55852 L .72667 .5558 L p .707 .577 .707 r
F P
0 g
s
.33489 .69365 m .34048 .67557 L .31883 .66494 L p .707 .577 .707 r
F P
0 g
s
.49209 .54546 m .4957 .60056 L .50576 .59113 L p .707 .577 .707 r
F P
0 g
s
.50576 .59113 m .50215 .53604 L .49209 .54546 L p .707 .577 .707 r
F P
0 g
s
.67848 .66064 m .6763 .67594 L .65445 .68785 L p .707 .577 .707 r
F P
0 g
s
.31883 .66494 m .31325 .68302 L .33489 .69365 L p .707 .577 .707 r
F P
0 g
s
.79939 .62429 m .79767 .65952 L .76843 .65319 L p .707 .577 .707 r
F P
0 g
s
.76843 .65319 m .77015 .61796 L .79939 .62429 L p .707 .577 .707 r
F P
0 g
s
.31398 .6111 m .31037 .556 L .30072 .54772 L p .707 .577 .707 r
F P
0 g
s
.82083 .68489 m .81865 .70018 L .79559 .6849 L p .707 .577 .707 r
F P
0 g
s
.79559 .6849 m .79777 .6696 L .82083 .68489 L p .707 .577 .707 r
F P
0 g
s
.45541 .70983 m .44983 .72792 L .47145 .73019 L p .707 .577 .707 r
F P
0 g
s
.47145 .73019 m .47703 .7121 L .45541 .70983 L p .707 .577 .707 r
F P
0 g
s
.32374 .65899 m .32815 .62183 L .31223 .6136 L p .707 .577 .707 r
F P
0 g
s
.75863 .55503 m .76011 .61153 L .72815 .6123 L p .707 .577 .707 r
F P
0 g
s
.72815 .6123 m .72667 .5558 L .75863 .55503 L p .707 .577 .707 r
F P
0 g
s
.72667 .5558 m .72815 .6123 L .6977 .61502 L p .707 .577 .707 r
F P
0 g
s
.6763 .67594 m .67848 .66064 L .70638 .65403 L p .707 .577 .707 r
F P
0 g
s
.70545 .65206 m .70717 .61683 L .73837 .61539 L p .707 .577 .707 r
F P
0 g
s
.70717 .61683 m .70545 .65206 L .67788 .65737 L p .707 .577 .707 r
F P
0 g
s
.31223 .6136 m .30782 .65076 L .32374 .65899 L p .707 .577 .707 r
F P
0 g
s
.77015 .61796 m .76843 .65319 L .73666 .65062 L p .707 .577 .707 r
F P
0 g
s
.73666 .65062 m .73837 .61539 L .77015 .61796 L p .707 .577 .707 r
F P
0 g
s
.73837 .61539 m .73666 .65062 L .70545 .65206 L p .707 .577 .707 r
F P
0 g
s
.49214 .63815 m .48773 .67531 L .50061 .66995 L p .707 .577 .707 r
F P
0 g
s
.50061 .66995 m .50501 .63279 L .49214 .63815 L p .707 .577 .707 r
F P
0 g
s
.31325 .68302 m .31883 .66494 L .30493 .65553 L p .707 .577 .707 r
F P
0 g
s
.30072 .54772 m .30433 .60282 L .31398 .6111 L p .707 .577 .707 r
F P
0 g
s
.79777 .6696 m .79559 .6849 L .76691 .67404 L p .707 .577 .707 r
F P
0 g
s
.76691 .67404 m .76909 .65875 L .79777 .6696 L p .707 .577 .707 r
F P
0 g
s
.70638 .65403 m .70419 .66933 L .6763 .67594 L p .707 .577 .707 r
F P
0 g
s
.30493 .65553 m .29935 .67361 L .31325 .68302 L p .707 .577 .707 r
F P
0 g
s
.70419 .66933 m .70638 .65403 L .7376 .65338 L p .707 .577 .707 r
F P
0 g
s
.50215 .53604 m .50576 .59113 L .50598 .58183 L p .707 .577 .707 r
F P
0 g
s
.50598 .58183 m .50237 .52673 L .50215 .53604 L p .707 .577 .707 r
F P
0 g
s
.47703 .7121 m .47145 .73019 L .48532 .72906 L p .707 .577 .707 r
F P
0 g
s
.48532 .72906 m .4909 .71097 L .47703 .7121 L p .707 .577 .707 r
F P
0 g
s
.76909 .65875 m .76691 .67404 L .73542 .66868 L p .707 .577 .707 r
F P
0 g
s
.73542 .66868 m .7376 .65338 L .76909 .65875 L p .707 .577 .707 r
F P
0 g
s
.7376 .65338 m .73542 .66868 L .70419 .66933 L p .707 .577 .707 r
F P
0 g
s
.30782 .65076 m .31223 .6136 L .30558 .60558 L p .707 .577 .707 r
F P
0 g
s
.30433 .60282 m .30072 .54772 L .30094 .53842 L p .707 .577 .707 r
F P
0 g
s
.30558 .60558 m .30117 .64274 L .30782 .65076 L p .707 .577 .707 r
F P
0 g
s
.29935 .67361 m .30493 .65553 L .30013 .64826 L p .707 .577 .707 r
F P
0 g
s
.50501 .63279 m .50061 .66995 L .50388 .66291 L p .707 .577 .707 r
F P
0 g
s
.50388 .66291 m .50829 .62575 L .50501 .63279 L p .707 .577 .707 r
F P
0 g
s
.30094 .53842 m .30455 .59352 L .30433 .60282 L p .707 .577 .707 r
F P
0 g
s
.30013 .64826 m .29454 .66634 L .29935 .67361 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4909 .71097 m .48532 .72906 L .49009 .72464 L p .707 .577 .707 r
F P
0 g
s
.49009 .72464 m .49567 .70655 L .4909 .71097 L p .707 .577 .707 r
F P
0 g
s
.50237 .52673 m .50598 .58183 L .49633 .57355 L p .707 .577 .707 r
F P
0 g
s
.49633 .57355 m .49272 .51845 L .50237 .52673 L p .707 .577 .707 r
F P
0 g
s
.30117 .64274 m .30558 .60558 L .30885 .59854 L p .707 .577 .707 r
F P
0 g
s
.30455 .59352 m .30094 .53842 L .311 .52899 L p .707 .577 .707 r
F P
0 g
s
.30885 .59854 m .30444 .6357 L .30117 .64274 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29454 .66634 m .30013 .64826 L .3049 .64384 L p .707 .577 .707 r
F P
0 g
s
.50829 .62575 m .50388 .66291 L .49723 .65488 L p .707 .577 .707 r
F P
0 g
s
.49723 .65488 m .50164 .61772 L .50829 .62575 L p .707 .577 .707 r
F P
0 g
s
.311 .52899 m .31462 .58409 L .30455 .59352 L p .707 .577 .707 r
F P
0 g
s
.3049 .64384 m .29931 .66193 L .29454 .66634 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49272 .51845 m .49633 .57355 L .47775 .56711 L p .707 .577 .707 r
F P
0 g
s
.47775 .56711 m .47414 .51201 L .49272 .51845 L p .707 .577 .707 r
F P
0 g
s
.49567 .70655 m .49009 .72464 L .48528 .71737 L p .707 .577 .707 r
F P
0 g
s
.48528 .71737 m .49087 .69928 L .49567 .70655 L p .707 .577 .707 r
F P
0 g
s
.31462 .58409 m .311 .52899 L .32993 .52038 L p .707 .577 .707 r
F P
0 g
s
.30444 .6357 m .30885 .59854 L .32172 .59317 L p .707 .577 .707 r
F P
0 g
s
.32172 .59317 m .31732 .63033 L .30444 .6357 L p .707 .577 .707 r
F P
0 g
s
.50164 .61772 m .49723 .65488 L .48131 .64666 L p .707 .577 .707 r
F P
0 g
s
.48131 .64666 m .48572 .60949 L .50164 .61772 L p .707 .577 .707 r
F P
0 g
s
.29931 .66193 m .3049 .64384 L .31877 .64271 L p .707 .577 .707 r
F P
0 g
s
.32993 .52038 m .33354 .57548 L .31462 .58409 L p .707 .577 .707 r
F P
0 g
s
.31877 .64271 m .31319 .6608 L .29931 .66193 L p .707 .577 .707 r
F P
0 g
s
.47414 .51201 m .47775 .56711 L .45207 .56314 L p .707 .577 .707 r
F P
0 g
s
.45207 .56314 m .44846 .50804 L .47414 .51201 L p .707 .577 .707 r
F P
0 g
s
.33354 .57548 m .32993 .52038 L .35587 .51341 L p .707 .577 .707 r
F P
0 g
s
.49087 .69928 m .48528 .71737 L .47138 .70796 L p .707 .577 .707 r
F P
0 g
s
.47138 .70796 m .47697 .68987 L .49087 .69928 L p .707 .577 .707 r
F P
0 g
s
.31732 .63033 m .32172 .59317 L .34294 .59001 L p .707 .577 .707 r
F P
0 g
s
.34294 .59001 m .33853 .62717 L .31732 .63033 L p .707 .577 .707 r
F P
0 g
s
.44846 .50804 m .45207 .56314 L .4218 .56202 L p .707 .577 .707 r
F P
0 g
s
.4218 .56202 m .41818 .50692 L .44846 .50804 L p .707 .577 .707 r
F P
0 g
s
.35587 .51341 m .35948 .56851 L .33354 .57548 L p .707 .577 .707 r
F P
0 g
s
.35948 .56851 m .35587 .51341 L .38628 .50877 L p .707 .577 .707 r
F P
0 g
s
.48572 .60949 m .48131 .64666 L .45768 .63903 L p .707 .577 .707 r
F P
0 g
s
.45768 .63903 m .46209 .60187 L .48572 .60949 L p .707 .577 .707 r
F P
0 g
s
.31319 .6608 m .31877 .64271 L .34039 .64498 L p .707 .577 .707 r
F P
0 g
s
.34039 .64498 m .3348 .66306 L .31319 .6608 L p .707 .577 .707 r
F P
0 g
s
.41818 .50692 m .4218 .56202 L .38989 .56387 L p .707 .577 .707 r
F P
0 g
s
.38989 .56387 m .38628 .50877 L .41818 .50692 L p .707 .577 .707 r
F P
0 g
s
.38628 .50877 m .38989 .56387 L .35948 .56851 L p .707 .577 .707 r
F P
0 g
s
.33853 .62717 m .34294 .59001 L .37042 .58936 L p .707 .577 .707 r
F P
0 g
s
.47697 .68987 m .47138 .70796 L .44974 .69733 L p .707 .577 .707 r
F P
0 g
s
.44974 .69733 m .45533 .67924 L .47697 .68987 L p .707 .577 .707 r
F P
0 g
s
.37042 .58936 m .36601 .62652 L .33853 .62717 L p .707 .577 .707 r
F P
0 g
s
.46209 .60187 m .45768 .63903 L .42865 .63276 L p .707 .577 .707 r
F P
0 g
s
.42865 .63276 m .43306 .59559 L .46209 .60187 L p .707 .577 .707 r
F P
0 g
s
.3348 .66306 m .34039 .64498 L .36764 .65042 L p .707 .577 .707 r
F P
0 g
s
.36601 .62652 m .37042 .58936 L .40147 .59128 L p .707 .577 .707 r
F P
0 g
s
.36764 .65042 m .36205 .6685 L .3348 .66306 L p .707 .577 .707 r
F P
0 g
s
.43306 .59559 m .42865 .63276 L .39706 .62845 L p .707 .577 .707 r
F P
0 g
s
.39706 .62845 m .40147 .59128 L .43306 .59559 L p .707 .577 .707 r
F P
0 g
s
.45533 .67924 m .44974 .69733 L .42248 .68652 L p .707 .577 .707 r
F P
0 g
s
.42248 .68652 m .42806 .66843 L .45533 .67924 L p .707 .577 .707 r
F P
0 g
s
.40147 .59128 m .39706 .62845 L .36601 .62652 L p .707 .577 .707 r
F P
0 g
s
.36205 .6685 m .36764 .65042 L .39785 .6585 L p .707 .577 .707 r
F P
0 g
s
.39785 .6585 m .39226 .67658 L .36205 .6685 L p .707 .577 .707 r
F P
0 g
s
.42806 .66843 m .42248 .68652 L .39226 .67658 L p .707 .577 .707 r
F P
0 g
s
.39226 .67658 m .39785 .6585 L .42806 .66843 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo7`00P7oo001hOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001jOol0
07=oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007Eoo`00Kgoo1000
0UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1000LGoo001/Ool30006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001^Ool006Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006aoo`00J7oo0P000UYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00JWoo001VOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Moo`00IGoo0P001EYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool00eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol00eYF
001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001U
Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001UOol20005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP00IGoo001UOol20005FUHG000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol200000eYF0000000200000eYF001JEP07FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00I7oo10001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YF00000P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00H7oo100000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00G7oo10001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FWoo0P0000=JEP00FUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF
00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eo
o`00F7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUH006Eoo`00Egoo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EWoo00<005YF
000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF001UOol005Eoo`04001J
EUYF0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEP00IGoo001EOol01000FUIJEP0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH006Eoo`00EGoo00@0
05YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00=JEP04001JEUYF001UOol005Eoo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP006goo2@00@Goo001EOol01000FUIJ
EP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00@005YFFUH000aoo`l000AJEP03001JEUYF009JEPP003Uoo`00EGoo00D005YFFUIJEP00
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04
001JEUYF0008Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1P00<goo001EOol01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH00UYF400000=JEP00
00001P000eYF00<005YFFUH00eYF00<005YF00002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH000Aoo`@000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00<0031oo`00EGoo0P000UYF00<005YFFUH00UYF00<005YF
FUH015YF3P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1@0015YF00<005YF00002UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUH007oo00<0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002ioo`00EGoo0P000UYF00<005YFFUH00UYF00<005YFFUH0100025YF1P000eYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00`0000AJEP00FUH000YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF000]Ool005Eo
o`80009JEP03001JEUYF009JEP<000=JEP03001JEUYF00IJEP03001JEP00008000AJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH005YF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP04001J
EUYF000]Ool005Ioo`04001JEUYF0002FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH000002UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH002eoo`00EWoo00<005YFFUH00`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP04001JEUYF000]Ool005Ioo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP002UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF00@005YFFUH002eoo`00EWoo10000eYF00<005YF00003P0025YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP04001JEUYF
000]Ool005Ioo`05001JEUYF001JEP040002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH002eo
o`00>goo5`0017oo00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH015YF00<005YFFUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000
;Goo000gOol400000eYF001JEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YF
FUH00UYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF0000;Goo000cOol40005FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP0200000eYF001JEP0;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP00;7oo000aOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01000FUIJEP00;7oo000_Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP00;7oo000^Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH?0003FUH00`00FUIJ
EP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUIJEUYF00001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF
00<005YFFUH00UYF00<005YFFUH070000UYF00<005YFFUH00UYF1P000eYF00@005YFFUH002aoo`00
;7oo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP0:0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP040006FUH00`00FUIJEP040002FUH00`00Oomoo`0ZOol002aoo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00002FUH30002FUH40007FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30003FUH00`00FUIJEP03FUH4000/Ool002aoo`04001JEUYF0004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH01000FUIJEUYF5`00
15YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF00002EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000`000eYF0P000UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00@005YF0000
02aoo`00;7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP80009JEPD000EJEPD000AJEP03001JEP0000@0009JEPL000IJEP03001JEUYF00AJ
EP03001JEUYF009JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=J
EP03001JEP00009JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP020005FUH00`00FUH0000]Ool002aoo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH00`00FUIJ
EP04FUH01000FUIJEUYF2`000UYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF00002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000
0UYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000eYF00<005YF0000;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YF000010000UYF00<005YFFUH025YF100015YF00<005YFFUH00UYF00@005YF
FUH000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00FUH200000eYF
001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH6000^Ool002aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUH005YF10001UYF00<005YFFUH01UYF00<005YFFUH00`00
00=JEP0000004P0000=JEP00FUH00eYF00@005YFFUH000UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000_Ool002aoo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3
000015YF001JEUYF1`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF
000000AJEP03001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0003FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHB0003FUH20003FUH00`00FUIJEP03FUH01000FUIJEUYF
1P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03
001JEP0000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`04001JEUYF0004FUH01000FUIJ
EUYF200027oo0`001goo0`0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEP00008000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH005YF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUHG0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000]Ool002aoo`04001JEUYF0004FUH6
000=Ool50008Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUH005YF00002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEPL00003FUH0
05YF00MJEP03001JEUYF00@000Aoo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP8002eoo`00
;7oo00@005YFFUH0009JEP<000EJEPH000Moo`D000Ioo`800004FUH005YFFUH40003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00@005YFFUIJEPD000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000Aoo`@000EJEP03001JEUYF
009JEP03001JEP0002aoo`00;7oo00<005YFFUH00`000UYF00<005YFFUH01EYF00@005YFFUIJEQ80
0003FUH005YF00D0009JEPD000IJEP03001JEUYF00MJEP04001JEP000008FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000eYF00<005YF000010001eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000Ioo`8000=JEP03001JEUYF009JEP03001JEP0002aoo`00;7oo00@005YFFUH000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH30002FUH00`00FUIJEP03FUH30004FUH01000FUIJ
EP000UYF1@0000=JEP00FUH025YF00<005YFFUH00UYF0`001EYF00<005YFFUH015YF00<005YFFUH0
0eYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001J
EP0000=JEP800005FUH005YFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30005Ool200000eYF001JEP03FUH00`00FUH0000/Ool002aoo`<000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP@000AJEP03001JEUYF00@000MJ
EP03001JEUYF00EJEP<0009JEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002FUH01000FUH000000eYF
00<005YFFUH015YF3P0015YF00<005YFFUH01EYF0P001Goo0P0015YF00<005YF0000;7oo000/Ool0
0`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP020003FUH200000eYF00000002FUH40002FUH00`00FUIJEP07FUH0
1000FUH000001eYF00<005YFFUH00eYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP0000800003FUH005YF00AJEP03001JEUYF00@000Uoo`/000MJEP<0
00Eoo`80009JEP03001JEP0002aoo`00;7oo00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000EJEP@00004FUH000000005FUH50008
FUH01000FUIJEUYF0`0000=JEP0000002@0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF001JEP<000EJEP@0009JEP03001oogoo00Moo`D000Ioo`<000AJ
EP03001JEUYF008000Eoo`<00003FUH007oo02]oo`00;7oo00<005YF00001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF10001UYF00D005YF000005YF008000EJ
EP03001JEUYF00D000AJEP03001JEUYF00EJEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP07001JEP00FUH005YF00000eYF0P000eYF00@005YFFUH000Yo
o`<000Yoo`<00003FUH005YF00=JEP80009oo`06001JEUYF001JEP00;7oo000/Ool00`00FUH00005
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP00
1UYF00@005YFFUIJEP<000EJEP03001JEP0000@00006FUH00000001JEP0025YF0`002EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YF0000009JEP05001J
EP00001JEP0300001EYF001JEUYF00006Woo0P001UYF0`000UYF00<005YF0000;7oo000/Ool00`00
FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20003FUH00`00FUIJEP05FUH30002FUH00`00FUH000040002FUH00`00FUH000020006
FUH01000FUIJEUYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00eYF00<005YF00000eYF0P0000=JEP00FUH00eYF1@0077oo00<005YFFUH00eYF0`000eYF0P00
;7oo000]Ool20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUHB00000eYF001J
EP07FUH00`00FUH0000200000eYF000000030002FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00
FUH00002FUH01@00FUIJEUYF00001EYF00<005YFFUH0100067oo0`0015YF00<005YF00000eYF0P00
;7oo000^Ool00`00FUIJEP03FUH00`00FUIJEP04FUHA0004FUH00`00FUIJEP05FUH01000FUIJEUYF
1@001UYF00<005YFFUH00eYF1@000eYF00<005YFFUH015YF0P0000=JEP00FUH01UYF0`000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00D005YF001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00AJEPL000Uoo`P000=JEP800005FUH005YFFUH00003FUH2000/
Ool002moo`8000=JEPL000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEP000004FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP06FUH20006FUH01000
FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YF
FUH015YF00@005YF000000=JEP03001JEUYF008002aoo`00<7oo10000UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003
FUH005YF00UJEP03001JEP0000<000UJEP8000AJEP03001JEUYF009JEP03001JEP0000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEPD000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00FUH0000]
Ool002ioo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP06001JEUYFFUH005YF0`0025YF00<005YFFUH015YF1P000eYF00H005YF0000
05YF0004FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<0
05YF00000`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEP0002eoo`00;7oo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00H005YFFUIJEP00FUH2000015YF000000001EYF00<005YFFUH01UYF00@005YFFUIJEPT000AJ
EP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0UYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF00<005YFFUH00P00;Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJ
EUYF001JEP8000AJEP<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00@00004FUH005YF
FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH01@00FUH005YF0000;Woo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01P00FUIJEUYF001JEP80
00EJEP03001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<00004FUH005YF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH700000eYF00000005FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH40008FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001oo`0]Ool0
02]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00=JEP@0009JEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEP000080009JEPL00003FUH005YF00IJEP03001JEUYF
009JEPD000QJEP03001JEUYF00EJEP04001JEUYFFUH200001Goo001JEUYF0000;Goo000[Ool20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP06FUH70003FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YFFUH00P001EYF00<005YF000010001UYF00<005YFFUH00UYF1@0025YF00<005YFFUH0
1EYF00@005YF000000=oo`04001JEUYF000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP08001JEUYF001JEP00FUH000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000EJEP04001JEUYF
FUH200000eYF000000020002FUH00`00FUIJEP02FUH50008FUH00`00FUIJEP02FUH50006Ool00`00
FUH0000]Ool002]oo`03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009J
EQT000=JEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00P0
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003FUH0
000000IJEP04001JEUYFFUH30003Ool700000eYF000000020004FUH9000;Ool3000]Ool002aoo`05
FUH005YFFUH00005FUH00`00FUIJEP02FUH80007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70002
FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000Yoo`T001Eoo`03001oogoo02aoo`00;7oo00EJEP00FUIJEP0000=JEPL000IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEPH000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP07001JEUYFFUH005YF0000:7oo00<0
07ooOol0;7oo000/Ool00eYF001JEP050005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF00<005YF00000eYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000XOol00`00Oomo
o`0/Ool002aoo`03FUH0000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000EJEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP04001JEUYF0003FUH01@00FUIJEUYF00000eYF00<005YF00009goo0P00;Woo000/Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH01000FUIJEUYF1@0000=oo`0000001EYF00<005YFFUH01UYF00<005YFFUH00eYF
30001eYF00<005YFFUH00eYF30001EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=J
EP<0009JEP04001JEUYFFUH2000VOol3000^Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000Ioo`8000EJEP03
001JEUYF00EJEPL000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF009JEPL000MJEP03
001JEUYF00=JEP03001JEUYF0080009JEP06001JEUYF001JEP000eYF0P009Woo0P00;goo000]Ool3
0002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHH0005FUH0
0`00FUIJEP02FUH30002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH40004FUH00`00FUIJEP03FUH01@00FUIJEP00Ool00P0015YF0P000eYF00<005YF000097oo
00<005YF0000;goo000`OolO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
1EYF00<005YF00000P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00@005YFFUIJEP<00003FUH005YF00AJEP05001JEUYF001oo`020005FUH3000015YF001J
EP008goo00@005YFFUH002moo`00@7oo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000`001EYF0P0025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH015YF0P001EYF00<005YFFUH010001eYF0`0000=JEP00Ool0
87oo0`0000=JEP00Ool0;goo000lOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH20003FUH200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH20003FUH01000FUIJEP000eYF0P00
1EYF00<005YF00000P007goo0P0000AJEP00FUH0035oo`00=Woo1P001EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF0P0000=JEP0000000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YF000005YF0002FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH3000JOol30003
FUH2000bOol0035oo`D000=JEP03001JEUYF00EJEP03001JEUYF00AJEP@000QJEP03001JEP0000D0
00AJEP03001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002FUH00`00FUIJEP02
FUH00`00FUIJEP030007FUH6000@Ool400000eYF001JEP03FUH00`00Oomoo`0aOol002ioo`<00003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF009JEPD0009JEPP000AJEP03001JEUYF00=JEP03
001JEUYF009JEP<000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000EJEP04001JEUYF
FUH20007FUH00`00FUIJEP02FUH@0005FUH00`00FUIJEP02000dOol002aoo`<000=JEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00T000=JEP03001JEUYF00IJEP03001JEUYF00AJEP07001J
EUYFFUH005YF00001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`000UYF2`0015YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH003Ioo`00;7oo10000eYF00<005YFFUH0
15YF00<005YFFUH0200015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@0000=J
EP00FUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000P0000=JEP00FUH01EYF00<0
05YF00000`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH01EYF0`00=goo000/Ool01000
FUH005YF3@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP@0
00=oo`03001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00AJEP80
0003Ool0000000D000IJEP03001JEUYF00IJEP03001JEUYF009JEP@003Uoo`00;7oo00<005YF0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0UYF1`0027oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH015YF00H0
07ooOol005YF0004Ool40002FUH00`00FUIJEP02FUH9000mOol002eoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPL000moo`8000EJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00UJEP8000YJEP03001JEUYF00IJEP03001J
EUYF00=JEP03001JEUYF00AJEP04001JEUYFFUH20002Ool20002FUH00`00Oomoo`05Ool70016Ool0
02eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@001Mo
o`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00UJ
EP8000YJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH01000FUH000000goo00H005YFFUH005YF
001DOol002eoo`8000=JEP03001JEUYF00=JEP03001JEUYF009JEPl001aoo`8000=JEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYF001JEP001UYF0`0017oo00L005YFFUIJEP00FUH0001DOol002ioo`l002eoo`80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP<0009JEP03001JEUYF00@000Ioo`03001JEUYF00=JEP03001oogoo05=oo`00
K7oo10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH015YF0`000UYF1@0027oo0`001EYF00<007ooOol0Dgoo001`Ool40002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0400000eYF00000002
000<Ool01@00FUIJEUYF00000eYF00<007ooOol0E7oo001dOol50009FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP06FUH:000>Ool20004FUH01000FUIJEP00Egoo001iOol60003FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP060005Ool5000=Ool00`00FUIJEP05FUH2001HOol0
07mooal000]oo`D000]oo`<000MJEP03001oogoo05Moo`00T7oo00<005YFFUH00eYF00<007ooOol0
4Goo0`002Woo0P000eYF00<005YFFUH00UYF0P00FWoo002?Ool00`00FUH00003FUH00`00Oomoo`0M
Ool20005FUH01@00FUIJEUYF0000G7oo002?Ool00`00FUH00002FUH00`00Oomoo`0KOol30008FUH3
001MOol008moo`03001JEUYF008001aoo`800003FUH005YF00QJEP03001oogoo05eoo`00Sgoo00@0
05YFFUH001Yoo`<000AJEP03001JEUYF00AJEP80061oo`00Sgoo00<005YF00005goo10001eYF00<0
05YFFUH00UYF0P00HWoo002@Ool00eYF0000000BOol40002FUH00`00FUIJEP07FUH01000FUH00000
I7oo002@Ool200000eYF000000020008Ool60006FUH00`00FUIJEP06FUH3001VOol0091oo`05001J
EUYFFUH00002FUH80003FUH00`00FUIJEP07FUH00`00FUIJEP02FUH3001YOol0095oo`80009JEP03
001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008006aoo`00TWoo00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00EJEP<006moo`00Tgoo0P0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH01000LWoo002EOol40003FUH00`00FUIJEP02FUH6001fOol009Uoo`P0
07aoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]22\[InvisibleSpace]"     "\
\[InvisibleSpace]6.577070071926744`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 22, "     ", 6.5770700719267436, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59628 .72206 m .59943 .66497 L .56828 .66235 L p .707 .577 .707 r
F P
0 g
s
.59943 .66497 m .59628 .72206 L .62806 .72338 L p .707 .577 .707 r
F P
0 g
s
.62806 .72338 m .63121 .66629 L .59943 .66497 L p .707 .577 .707 r
F P
0 g
s
.63121 .66629 m .62806 .72338 L .65735 .72327 L p .707 .577 .707 r
F P
0 g
s
.65735 .72327 m .6605 .66618 L .63121 .66629 L p .707 .577 .707 r
F P
0 g
s
.56513 .71944 m .56828 .66235 L .5408 .65868 L p .707 .577 .707 r
F P
0 g
s
.56828 .66235 m .56513 .71944 L .59628 .72206 L p .707 .577 .707 r
F P
0 g
s
.5408 .65868 m .53765 .71577 L .56513 .71944 L p .707 .577 .707 r
F P
0 g
s
.6605 .66618 m .65735 .72327 L .68129 .72173 L p .707 .577 .707 r
F P
0 g
s
.68129 .72173 m .68444 .66464 L .6605 .66618 L p .707 .577 .707 r
F P
0 g
s
.56844 .73465 m .56351 .77274 L .59457 .77638 L p .707 .577 .707 r
F P
0 g
s
.59457 .77638 m .5995 .73829 L .56844 .73465 L p .707 .577 .707 r
F P
0 g
s
.5995 .73829 m .59457 .77638 L .62607 .78065 L p .707 .577 .707 r
F P
0 g
s
.62607 .78065 m .631 .74256 L .5995 .73829 L p .707 .577 .707 r
F P
0 g
s
.631 .74256 m .62607 .78065 L .65494 .78513 L p .707 .577 .707 r
F P
0 g
s
.53765 .71577 m .5408 .65868 L .51969 .65432 L p .707 .577 .707 r
F P
0 g
s
.65494 .78513 m .65987 .74704 L .631 .74256 L p .707 .577 .707 r
F P
0 g
s
.54087 .732 m .53594 .77008 L .56351 .77274 L p .707 .577 .707 r
F P
0 g
s
.56351 .77274 m .56844 .73465 L .54087 .732 L p .707 .577 .707 r
F P
0 g
s
.51969 .65432 m .51654 .71141 L .53765 .71577 L p .707 .577 .707 r
F P
0 g
s
.65987 .74704 m .65494 .78513 L .67834 .78939 L p .707 .577 .707 r
F P
0 g
s
.67834 .78939 m .68327 .7513 L .65987 .74704 L p .707 .577 .707 r
F P
0 g
s
.68444 .66464 m .68129 .72173 L .69753 .71892 L p .707 .577 .707 r
F P
0 g
s
.69753 .71892 m .70068 .66183 L .68444 .66464 L p .707 .577 .707 r
F P
0 g
s
.59552 .84706 m .59755 .82794 L .56645 .82461 L p .707 .577 .707 r
F P
0 g
s
.59755 .82794 m .59552 .84706 L .62713 .85041 L p .707 .577 .707 r
F P
0 g
s
.62713 .85041 m .62916 .83128 L .59755 .82794 L p .707 .577 .707 r
F P
0 g
s
.56645 .82461 m .56442 .84374 L .59552 .84706 L p .707 .577 .707 r
F P
0 g
s
.51948 .73059 m .51455 .76868 L .53594 .77008 L p .707 .577 .707 r
F P
0 g
s
.53594 .77008 m .54087 .732 L .51948 .73059 L p .707 .577 .707 r
F P
0 g
s
.62916 .83128 m .62713 .85041 L .65617 .85346 L p .707 .577 .707 r
F P
0 g
s
.65617 .85346 m .6582 .83433 L .62916 .83128 L p .707 .577 .707 r
F P
0 g
s
.51654 .71141 m .51969 .65432 L .50701 .6497 L p .707 .577 .707 r
F P
0 g
s
.56442 .84374 m .56645 .82461 L .53892 .82164 L p .707 .577 .707 r
F P
0 g
s
.53892 .82164 m .53689 .84077 L .56442 .84374 L p .707 .577 .707 r
F P
0 g
s
.50701 .6497 m .50386 .70679 L .51654 .71141 L p .707 .577 .707 r
F P
0 g
s
.68327 .7513 m .67834 .78939 L .69399 .793 L p .707 .577 .707 r
F P
0 g
s
.6582 .83433 m .65617 .85346 L .67978 .8559 L p .707 .577 .707 r
F P
0 g
s
.67978 .8559 m .68181 .83678 L .6582 .83433 L p .707 .577 .707 r
F P
0 g
s
.69399 .793 m .69892 .75491 L .68327 .7513 L p .707 .577 .707 r
F P
0 g
s
.53689 .84077 m .53892 .82164 L .51764 .81932 L p .707 .577 .707 r
F P
0 g
s
.51764 .81932 m .51561 .83844 L .53689 .84077 L p .707 .577 .707 r
F P
0 g
s
.70068 .66183 m .69753 .71892 L .70449 .71511 L p .707 .577 .707 r
F P
0 g
s
.70449 .71511 m .70764 .65802 L .70068 .66183 L p .707 .577 .707 r
F P
0 g
s
.50638 .73057 m .50144 .76865 L .51455 .76868 L p .707 .577 .707 r
F P
0 g
s
.51455 .76868 m .51948 .73059 L .50638 .73057 L p .707 .577 .707 r
F P
0 g
s
.50386 .70679 m .50701 .6497 L .50399 .64527 L p .707 .577 .707 r
F P
0 g
s
.68181 .83678 m .67978 .8559 L .69567 .85751 L p .707 .577 .707 r
F P
0 g
s
.69567 .85751 m .6977 .83839 L .68181 .83678 L p .707 .577 .707 r
F P
0 g
s
.50399 .64527 m .50084 .70236 L .50386 .70679 L p .707 .577 .707 r
F P
0 g
s
.69892 .75491 m .69399 .793 L .70035 .79562 L p .707 .577 .707 r
F P
0 g
s
.70035 .79562 m .70529 .75753 L .69892 .75491 L p .707 .577 .707 r
F P
0 g
s
.51561 .83844 m .51764 .81932 L .5047 .81786 L p .707 .577 .707 r
F P
0 g
s
.5047 .81786 m .50267 .83698 L .51561 .83844 L p .707 .577 .707 r
F P
0 g
s
.50283 .73193 m .4979 .77002 L .50144 .76865 L p .707 .577 .707 r
F P
0 g
s
.50144 .76865 m .50638 .73057 L .50283 .73193 L p .707 .577 .707 r
F P
0 g
s
.70764 .65802 m .70449 .71511 L .70148 .71068 L p .707 .577 .707 r
F P
0 g
s
.70148 .71068 m .70463 .65359 L .70764 .65802 L p .707 .577 .707 r
F P
0 g
s
.49685 .82255 m .48922 .32617 L .44521 .32376 L p .707 .577 .707 r
F P
0 g
s
.50084 .70236 m .50399 .64527 L .51095 .64146 L p .707 .577 .707 r
F P
0 g
s
.51095 .64146 m .5078 .69855 L .50084 .70236 L p .707 .577 .707 r
F P
0 g
s
.50267 .83698 m .5047 .81786 L .50137 .81741 L p .707 .577 .707 r
F P
0 g
s
.50137 .81741 m .49934 .83654 L .50267 .83698 L p .707 .577 .707 r
F P
0 g
s
.50919 .73455 m .50426 .77264 L .4979 .77002 L p .707 .577 .707 r
F P
0 g
s
.4979 .77002 m .50283 .73193 L .50919 .73455 L p .707 .577 .707 r
F P
0 g
s
.5078 .69855 m .51095 .64146 L .52719 .63865 L p .707 .577 .707 r
F P
0 g
s
.52719 .63865 m .52404 .69574 L .5078 .69855 L p .707 .577 .707 r
F P
0 g
s
.49934 .83654 m .50137 .81741 L .50797 .81802 L p .707 .577 .707 r
F P
0 g
s
.50797 .81802 m .50594 .83715 L .49934 .83654 L p .707 .577 .707 r
F P
0 g
s
.52484 .73816 m .51991 .77625 L .50426 .77264 L p .707 .577 .707 r
F P
0 g
s
.50426 .77264 m .50919 .73455 L .52484 .73816 L p .707 .577 .707 r
F P
0 g
s
.52404 .69574 m .52719 .63865 L .55113 .63711 L p .707 .577 .707 r
F P
0 g
s
.55113 .63711 m .54798 .69421 L .52404 .69574 L p .707 .577 .707 r
F P
0 g
s
.50594 .83715 m .50797 .81802 L .52385 .81963 L p .707 .577 .707 r
F P
0 g
s
.52385 .81963 m .52182 .83875 L .50594 .83715 L p .707 .577 .707 r
F P
0 g
s
.54824 .74242 m .54331 .78051 L .51991 .77625 L p .707 .577 .707 r
F P
0 g
s
.51991 .77625 m .52484 .73816 L .54824 .74242 L p .707 .577 .707 r
F P
0 g
s
.52182 .83875 m .52385 .81963 L .54747 .82208 L p .707 .577 .707 r
F P
0 g
s
.48922 .32617 m .49685 .82255 L .54179 .82068 L p .707 .577 .707 r
F P
0 g
s
.54179 .82068 m .53416 .3243 L .48922 .32617 L p .707 .577 .707 r
F P
0 g
s
.54798 .69421 m .55113 .63711 L .58042 .637 L p .707 .577 .707 r
F P
0 g
s
.58042 .637 m .57727 .69409 L .54798 .69421 L p .707 .577 .707 r
F P
0 g
s
.57711 .7469 m .57218 .78499 L .54331 .78051 L p .707 .577 .707 r
F P
0 g
s
.54331 .78051 m .54824 .74242 L .57711 .7469 L p .707 .577 .707 r
F P
0 g
s
.60861 .75117 m .60368 .78926 L .57218 .78499 L p .707 .577 .707 r
F P
0 g
s
.57218 .78499 m .57711 .7469 L .60861 .75117 L p .707 .577 .707 r
F P
0 g
s
.53416 .3243 m .54179 .82068 L .58326 .8147 L p .707 .577 .707 r
F P
0 g
s
.57727 .69409 m .58042 .637 L .6122 .63832 L p .707 .577 .707 r
F P
0 g
s
.6122 .63832 m .60905 .69541 L .57727 .69409 L p .707 .577 .707 r
F P
0 g
s
.58326 .8147 m .57563 .31833 L .53416 .3243 L p .707 .577 .707 r
F P
0 g
s
.6977 .83839 m .69567 .85751 L .70227 .85812 L p .707 .577 .707 r
F P
0 g
s
.70227 .85812 m .7043 .839 L .6977 .83839 L p .707 .577 .707 r
F P
0 g
s
.45285 .82013 m .44521 .32376 L .40645 .31729 L p .707 .577 .707 r
F P
0 g
s
.44521 .32376 m .45285 .82013 L .49685 .82255 L p .707 .577 .707 r
F P
0 g
s
.70529 .75753 m .70035 .79562 L .69681 .79698 L p .707 .577 .707 r
F P
0 g
s
.69681 .79698 m .70174 .7589 L .70529 .75753 L p .707 .577 .707 r
F P
0 g
s
.63967 .75481 m .63474 .7929 L .60368 .78926 L p .707 .577 .707 r
F P
0 g
s
.60368 .78926 m .60861 .75117 L .63967 .75481 L p .707 .577 .707 r
F P
0 g
s
.57563 .31833 m .58326 .8147 L .61721 .80521 L p .707 .577 .707 r
F P
0 g
s
.64335 .64094 m .6402 .69803 L .60905 .69541 L p .707 .577 .707 r
F P
0 g
s
.60905 .69541 m .6122 .63832 L .64335 .64094 L p .707 .577 .707 r
F P
0 g
s
.61721 .80521 m .60957 .30883 L .57563 .31833 L p .707 .577 .707 r
F P
0 g
s
.70463 .65359 m .70148 .71068 L .68879 .70606 L p .707 .577 .707 r
F P
0 g
s
.68879 .70606 m .69194 .64897 L .70463 .65359 L p .707 .577 .707 r
F P
0 g
s
.41408 .81367 m .40645 .31729 L .37672 .3074 L p .707 .577 .707 r
F P
0 g
s
.40645 .31729 m .41408 .81367 L .45285 .82013 L p .707 .577 .707 r
F P
0 g
s
.25327 .68525 m .25643 .62816 L .22527 .62554 L p .707 .577 .707 r
F P
0 g
s
.25643 .62816 m .25327 .68525 L .28505 .68657 L p .707 .577 .707 r
F P
0 g
s
.28505 .68657 m .2882 .62948 L .25643 .62816 L p .707 .577 .707 r
F P
0 g
s
.2882 .62948 m .28505 .68657 L .31434 .68645 L p .707 .577 .707 r
F P
0 g
s
.31434 .68645 m .31749 .62936 L .2882 .62948 L p .707 .577 .707 r
F P
0 g
s
.7043 .839 m .70227 .85812 L .69893 .85767 L p .707 .577 .707 r
F P
0 g
s
.69893 .85767 m .70096 .83855 L .7043 .839 L p .707 .577 .707 r
F P
0 g
s
.22212 .68263 m .22527 .62554 L .1978 .62187 L p .707 .577 .707 r
F P
0 g
s
.22527 .62554 m .22212 .68263 L .25327 .68525 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.1978 .62187 m .19464 .67896 L .22212 .68263 L p .707 .577 .707 r
F P
0 g
s
.70174 .7589 m .69681 .79698 L .6837 .79696 L p .707 .577 .707 r
F P
0 g
s
.31749 .62936 m .31434 .68645 L .33828 .68491 L p .707 .577 .707 r
F P
0 g
s
.33828 .68491 m .34143 .62782 L .31749 .62936 L p .707 .577 .707 r
F P
0 g
s
.66724 .75747 m .66231 .79555 L .63474 .7929 L p .707 .577 .707 r
F P
0 g
s
.63474 .7929 m .63967 .75481 L .66724 .75747 L p .707 .577 .707 r
F P
0 g
s
.60957 .30883 m .61721 .80521 L .64031 .79312 L p .707 .577 .707 r
F P
0 g
s
.64031 .79312 m .63267 .29674 L .60957 .30883 L p .707 .577 .707 r
F P
0 g
s
.6837 .79696 m .68863 .75887 L .70174 .7589 L p .707 .577 .707 r
F P
0 g
s
.22543 .69784 m .2205 .73592 L .25156 .73956 L p .707 .577 .707 r
F P
0 g
s
.25156 .73956 m .25649 .70148 L .22543 .69784 L p .707 .577 .707 r
F P
0 g
s
.25649 .70148 m .25156 .73956 L .28307 .74383 L p .707 .577 .707 r
F P
0 g
s
.28307 .74383 m .288 .70575 L .25649 .70148 L p .707 .577 .707 r
F P
0 g
s
.288 .70575 m .28307 .74383 L .31193 .74831 L p .707 .577 .707 r
F P
0 g
s
.19464 .67896 m .1978 .62187 L .17668 .61751 L p .707 .577 .707 r
F P
0 g
s
.69194 .64897 m .68879 .70606 L .66768 .7017 L p .707 .577 .707 r
F P
0 g
s
.66768 .7017 m .67083 .64461 L .69194 .64897 L p .707 .577 .707 r
F P
0 g
s
.31193 .74831 m .31686 .71023 L .288 .70575 L p .707 .577 .707 r
F P
0 g
s
.19786 .69518 m .19293 .73327 L .2205 .73592 L p .707 .577 .707 r
F P
0 g
s
.2205 .73592 m .22543 .69784 L .19786 .69518 L p .707 .577 .707 r
F P
0 g
s
.17668 .61751 m .17353 .6746 L .19464 .67896 L p .707 .577 .707 r
F P
0 g
s
.38435 .80378 m .37672 .3074 L .35893 .29507 L p .707 .577 .707 r
F P
0 g
s
.37672 .3074 m .38435 .80378 L .41408 .81367 L p .707 .577 .707 r
F P
0 g
s
.31686 .71023 m .31193 .74831 L .33533 .75257 L p .707 .577 .707 r
F P
0 g
s
.70096 .83855 m .69893 .85767 L .68599 .85622 L p .707 .577 .707 r
F P
0 g
s
.68599 .85622 m .68803 .83709 L .70096 .83855 L p .707 .577 .707 r
F P
0 g
s
.33533 .75257 m .34027 .71449 L .31686 .71023 L p .707 .577 .707 r
F P
0 g
s
.34143 .62782 m .33828 .68491 L .35452 .6821 L p .707 .577 .707 r
F P
0 g
s
.35452 .6821 m .35767 .62501 L .34143 .62782 L p .707 .577 .707 r
F P
0 g
s
.25251 .81025 m .25454 .79112 L .22345 .7878 L p .707 .577 .707 r
F P
0 g
s
.25454 .79112 m .25251 .81025 L .28412 .81359 L p .707 .577 .707 r
F P
0 g
s
.28412 .81359 m .28615 .79447 L .25454 .79112 L p .707 .577 .707 r
F P
0 g
s
.22345 .7878 m .22141 .80692 L .25251 .81025 L p .707 .577 .707 r
F P
0 g
s
.17647 .69378 m .17154 .73186 L .19293 .73327 L p .707 .577 .707 r
F P
0 g
s
.19293 .73327 m .19786 .69518 L .17647 .69378 L p .707 .577 .707 r
F P
0 g
s
.68863 .75887 m .6837 .79696 L .66231 .79555 L p .707 .577 .707 r
F P
0 g
s
.28615 .79447 m .28412 .81359 L .31316 .81664 L p .707 .577 .707 r
F P
0 g
s
.31316 .81664 m .31519 .79752 L .28615 .79447 L p .707 .577 .707 r
F P
0 g
s
.66231 .79555 m .66724 .75747 L .68863 .75887 L p .707 .577 .707 r
F P
0 g
s
.17353 .6746 m .17668 .61751 L .164 .61288 L p .707 .577 .707 r
F P
0 g
s
.22141 .80692 m .22345 .7878 L .19591 .78483 L p .707 .577 .707 r
F P
0 g
s
.19591 .78483 m .19388 .80395 L .22141 .80692 L p .707 .577 .707 r
F P
0 g
s
.67083 .64461 m .66768 .7017 L .6402 .69803 L p .707 .577 .707 r
F P
0 g
s
.6402 .69803 m .64335 .64094 L .67083 .64461 L p .707 .577 .707 r
F P
0 g
s
.63267 .29674 m .64031 .79312 L .65029 .77962 L p .707 .577 .707 r
F P
0 g
s
.65029 .77962 m .64266 .28325 L .63267 .29674 L p .707 .577 .707 r
F P
0 g
s
.164 .61288 m .16085 .66998 L .17353 .6746 L p .707 .577 .707 r
F P
0 g
s
.34027 .71449 m .33533 .75257 L .35098 .75618 L p .707 .577 .707 r
F P
0 g
s
.31519 .79752 m .31316 .81664 L .33677 .81909 L p .707 .577 .707 r
F P
0 g
s
.33677 .81909 m .33881 .79996 L .31519 .79752 L p .707 .577 .707 r
F P
0 g
s
.35098 .75618 m .35591 .7181 L .34027 .71449 L p .707 .577 .707 r
F P
0 g
s
.19388 .80395 m .19591 .78483 L .17463 .7825 L p .707 .577 .707 r
F P
0 g
s
.17463 .7825 m .1726 .80163 L .19388 .80395 L p .707 .577 .707 r
F P
0 g
s
.35767 .62501 m .35452 .6821 L .36148 .6783 L p .707 .577 .707 r
F P
0 g
s
.36148 .6783 m .36463 .6212 L .35767 .62501 L p .707 .577 .707 r
F P
0 g
s
.16337 .69375 m .15844 .73184 L .17154 .73186 L p .707 .577 .707 r
F P
0 g
s
.17154 .73186 m .17647 .69378 L .16337 .69375 L p .707 .577 .707 r
F P
0 g
s
.68803 .83709 m .68599 .85622 L .66472 .85389 L p .707 .577 .707 r
F P
0 g
s
.66472 .85389 m .66675 .83476 L .68803 .83709 L p .707 .577 .707 r
F P
0 g
s
.36463 .6212 m .36148 .6783 L .35847 .67386 L p .707 .577 .707 r
F P
0 g
s
.35847 .67386 m .36162 .61677 L .36463 .6212 L p .707 .577 .707 r
F P
0 g
s
.36656 .79144 m .35893 .29507 L .35483 .28149 L p .707 .577 .707 r
F P
0 g
s
.35893 .29507 m .36656 .79144 L .38435 .80378 L p .707 .577 .707 r
F P
0 g
s
.54747 .82208 m .54544 .8412 L .52182 .83875 L p .707 .577 .707 r
F P
0 g
s
.16085 .66998 m .164 .61288 L .16099 .60845 L p .707 .577 .707 r
F P
0 g
s
.33881 .79996 m .33677 .81909 L .35266 .8207 L p .707 .577 .707 r
F P
0 g
s
.35266 .8207 m .35469 .80157 L .33881 .79996 L p .707 .577 .707 r
F P
0 g
s
.16099 .60845 m .15783 .66555 L .16085 .66998 L p .707 .577 .707 r
F P
0 g
s
.35591 .7181 m .35098 .75618 L .35735 .7588 L p .707 .577 .707 r
F P
0 g
s
.35735 .7588 m .36228 .72072 L .35591 .7181 L p .707 .577 .707 r
F P
0 g
s
.1726 .80163 m .17463 .7825 L .16169 .78104 L p .707 .577 .707 r
F P
0 g
s
.16169 .78104 m .15966 .80017 L .1726 .80163 L p .707 .577 .707 r
F P
0 g
s
.66675 .83476 m .66472 .85389 L .63718 .85092 L p .707 .577 .707 r
F P
0 g
s
.63718 .85092 m .63921 .83179 L .66675 .83476 L p .707 .577 .707 r
F P
0 g
s
.15982 .69512 m .15489 .7332 L .15844 .73184 L p .707 .577 .707 r
F P
0 g
s
.15844 .73184 m .16337 .69375 L .15982 .69512 L p .707 .577 .707 r
F P
0 g
s
.65029 .77962 m .64836 .77323 L p .64781 .72627 L .707 .577 .707 r
F P
0 g
s
.64266 .28325 m .64983 .74977 L p .64781 .72627 L .707 .577 .707 r
F P
0 g
s
.64983 .74977 m .65029 .77962 L p .64781 .72627 L .707 .577 .707 r
F P
0 g
s
.64588 .72414 m .64266 .28325 L .64823 .76241 L .707 .577 .707 r
F
.64694 .74513 m .64823 .76241 L .64836 .77323 L F
.64588 .72414 m .64823 .76241 L .64694 .74513 L F
.64452 .64286 m .63856 .26967 L .6453 .64479 L F
.64559 .72704 m .63856 .26967 L p .64594 .7317 L F P
0 g
s
.63856 .26967 m .64619 .76604 L .6284 .75371 L p .707 .577 .707 r
F P
0 g
s
.64421 .58418 m .6412 .57975 L p .64108 .63435 L .707 .577 .707 r
F P
0 g
s
.64106 .64127 m .6414 .63515 L p .64108 .63435 L .707 .577 .707 r
F P
0 g
s
.6414 .63515 m .64421 .58418 L p .64108 .63435 L .707 .577 .707 r
F P
0 g
s
.63856 .26967 m .64266 .28325 L p .6453 .64479 L .707 .577 .707 r
F P
0 g
s
.64594 .7317 m .64452 .64286 L .6453 .64479 L .707 .577 .707 r
F
.64619 .76604 m .64559 .72704 L p .64594 .7317 L F P
0 g
s
.64191 .68189 m .63987 .70101 L .64368 .70144 L p .707 .577 .707 r
F P
0 g
s
.64368 .70144 m .65281 .70247 L p .64227 .68257 L .707 .577 .707 r
F P
0 g
s
.64227 .68257 m .64191 .68189 L .64368 .70144 L .707 .577 .707 r
F
.65281 .70247 m .65485 .68335 L .64222 .68192 L p F P
0 g
s
.64222 .68192 m .64191 .68189 L p .64227 .68257 L .707 .577 .707 r
F P
0 g
s
.65281 .70247 m .64222 .68192 L .64227 .68257 L .707 .577 .707 r
F
.64172 .64151 m .65374 .6459 L p .6414 .63515 L F P
0 g
s
.64358 .64069 m .64171 .65516 L p .65176 .6788 L .707 .577 .707 r
F P
0 g
s
.64171 .65516 m .63865 .67877 L .64373 .67878 L p .707 .577 .707 r
F P
0 g
s
.64373 .67878 m .65176 .6788 L p .64171 .65516 L .707 .577 .707 r
F P
0 g
s
.64421 .58418 m .6414 .63515 L p .65374 .6459 L .707 .577 .707 r
F P
0 g
s
.6414 .63515 m .64106 .64127 L .64172 .64151 L p .707 .577 .707 r
F P
0 g
s
.64836 .77323 m .64619 .76604 L p .64588 .72414 L .707 .577 .707 r
F P
0 g
s
.54544 .8412 m .54747 .82208 L .5765 .82512 L p .707 .577 .707 r
F P
0 g
s
.5765 .82512 m .57447 .84425 L .54544 .8412 L p .707 .577 .707 r
F P
0 g
s
.63921 .83179 m .63718 .85092 L .60609 .84759 L p .707 .577 .707 r
F P
0 g
s
.60609 .84759 m .60812 .82847 L .63921 .83179 L p .707 .577 .707 r
F P
0 g
s
.35469 .80157 m .35266 .8207 L .35926 .82131 L p .707 .577 .707 r
F P
0 g
s
.35926 .82131 m .36129 .80218 L .35469 .80157 L p .707 .577 .707 r
F P
0 g
s
.15783 .66555 m .16099 .60845 L .16794 .60465 L p .707 .577 .707 r
F P
0 g
s
.57447 .84425 m .5765 .82512 L .60812 .82847 L p .707 .577 .707 r
F P
0 g
s
.60812 .82847 m .60609 .84759 L .57447 .84425 L p .707 .577 .707 r
F P
0 g
s
.36228 .72072 m .35735 .7588 L .3538 .76017 L p .707 .577 .707 r
F P
0 g
s
.3538 .76017 m .35873 .72208 L .36228 .72072 L p .707 .577 .707 r
F P
0 g
s
.36162 .61677 m .35847 .67386 L .34578 .66924 L p .707 .577 .707 r
F P
0 g
s
.34578 .66924 m .34893 .61215 L .36162 .61677 L p .707 .577 .707 r
F P
0 g
s
.35483 .28149 m .36246 .77786 L .36656 .79144 L p .707 .577 .707 r
F P
0 g
s
.36246 .77786 m .35483 .28149 L .36481 .26799 L p .707 .577 .707 r
F P
0 g
s
.16794 .60465 m .16479 .66174 L .15783 .66555 L p .707 .577 .707 r
F P
0 g
s
.15966 .80017 m .16169 .78104 L .15836 .7806 L p .707 .577 .707 r
F P
0 g
s
.15836 .7806 m .15633 .79972 L .15966 .80017 L p .707 .577 .707 r
F P
0 g
s
.16618 .69773 m .16125 .73582 L .15489 .7332 L p .707 .577 .707 r
F P
0 g
s
.15489 .7332 m .15982 .69512 L .16618 .69773 L p .707 .577 .707 r
F P
0 g
s
.36129 .80218 m .35926 .82131 L .35592 .82086 L p .707 .577 .707 r
F P
0 g
s
.35592 .82086 m .35796 .80173 L .36129 .80218 L p .707 .577 .707 r
F P
0 g
s
.6284 .75371 m .62077 .25733 L .63856 .26967 L p .707 .577 .707 r
F P
0 g
s
.16479 .66174 m .16794 .60465 L .18418 .60184 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18418 .60184 m .18103 .65893 L .16479 .66174 L p .707 .577 .707 r
F P
0 g
s
.35873 .72208 m .3538 .76017 L .34069 .76014 L p .707 .577 .707 r
F P
0 g
s
.15633 .79972 m .15836 .7806 L .16496 .78121 L p .707 .577 .707 r
F P
0 g
s
.16496 .78121 m .16293 .80033 L .15633 .79972 L p .707 .577 .707 r
F P
0 g
s
.34069 .76014 m .34562 .72206 L .35873 .72208 L p .707 .577 .707 r
F P
0 g
s
.34893 .61215 m .34578 .66924 L .32467 .66488 L p .707 .577 .707 r
F P
0 g
s
.32467 .66488 m .32782 .60779 L .34893 .61215 L p .707 .577 .707 r
F P
0 g
s
.37245 .76437 m .36481 .26799 L .38791 .25591 L p .707 .577 .707 r
F P
0 g
s
.36481 .26799 m .37245 .76437 L .36246 .77786 L p .707 .577 .707 r
F P
0 g
s
.18183 .70135 m .1769 .73943 L .16125 .73582 L p .707 .577 .707 r
F P
0 g
s
.16125 .73582 m .16618 .69773 L .18183 .70135 L p .707 .577 .707 r
F P
0 g
s
.18103 .65893 m .18418 .60184 L .20812 .6003 L p .707 .577 .707 r
F P
0 g
s
.35796 .80173 m .35592 .82086 L .34299 .8194 L p .707 .577 .707 r
F P
0 g
s
.34299 .8194 m .34502 .80028 L .35796 .80173 L p .707 .577 .707 r
F P
0 g
s
.20812 .6003 m .20497 .65739 L .18103 .65893 L p .707 .577 .707 r
F P
0 g
s
.34562 .72206 m .34069 .76014 L .3193 .75874 L p .707 .577 .707 r
F P
0 g
s
.62077 .25733 m .6284 .75371 L .59867 .74382 L p .707 .577 .707 r
F P
0 g
s
.59867 .74382 m .59104 .24744 L .62077 .25733 L p .707 .577 .707 r
F P
0 g
s
.3193 .75874 m .32423 .72065 L .34562 .72206 L p .707 .577 .707 r
F P
0 g
s
.16293 .80033 m .16496 .78121 L .18084 .78281 L p .707 .577 .707 r
F P
0 g
s
.18084 .78281 m .17881 .80194 L .16293 .80033 L p .707 .577 .707 r
F P
0 g
s
.32782 .60779 m .32467 .66488 L .29719 .66121 L p .707 .577 .707 r
F P
0 g
s
.29719 .66121 m .30034 .60412 L .32782 .60779 L p .707 .577 .707 r
F P
0 g
s
.20523 .7056 m .2003 .74369 L .1769 .73943 L p .707 .577 .707 r
F P
0 g
s
.1769 .73943 m .18183 .70135 L .20523 .7056 L p .707 .577 .707 r
F P
0 g
s
.20497 .65739 m .20812 .6003 L .23741 .60018 L p .707 .577 .707 r
F P
0 g
s
.38791 .25591 m .39532 .73776 L p .37245 .76437 L .707 .577 .707 r
F P
0 g
s
.39555 .75228 m .38791 .25591 L .42186 .24641 L p .707 .577 .707 r
F P
0 g
s
.42186 .24641 m .42839 .67134 L p .39727 .71908 L .707 .577 .707 r
F P
0 g
s
.42949 .74279 m .42186 .24641 L .46333 .24043 L p .707 .577 .707 r
F P
0 g
s
.46333 .24043 m .47096 .73681 L .42949 .74279 L p .707 .577 .707 r
F P
0 g
s
.42541 .56396 m .42225 .62105 L .43962 .62098 L p .707 .577 .707 r
F P
0 g
s
.43962 .62098 m .45002 .62094 L p .44577 .61108 L .707 .577 .707 r
F P
0 g
s
.44577 .61108 m .42541 .56396 L .43962 .62098 L .707 .577 .707 r
F
.39363 .56264 m .39048 .61973 L .42225 .62105 L p F P
0 g
s
.42225 .62105 m .42541 .56396 L .39363 .56264 L p .707 .577 .707 r
F P
0 g
s
.4252 .61587 m .3937 .61159 L p .4197 .65305 L .707 .577 .707 r
F P
0 g
s
.42027 .65395 m .42057 .65166 L p .4197 .65305 L .707 .577 .707 r
F P
0 g
s
.42057 .65166 m .4252 .61587 L p .4197 .65305 L .707 .577 .707 r
F P
0 g
s
.4252 .61587 m .42027 .65395 L .43794 .65669 L p .707 .577 .707 r
F P
0 g
s
.43794 .65669 m .44914 .65843 L p .44342 .64828 L .707 .577 .707 r
F P
0 g
s
.44342 .64828 m .4252 .61587 L .43794 .65669 L .707 .577 .707 r
F
.39555 .75228 m .39727 .71908 L .4287 .69124 L F
.42839 .67134 m .4287 .69124 L p .39727 .71908 L F P
0 g
s
.4287 .69124 m .42949 .74279 L .41154 .74781 L p .707 .577 .707 r
F P
0 g
s
.41154 .74781 m .39555 .75228 L p .4287 .69124 L .707 .577 .707 r
F P
0 g
s
.45002 .62094 m .45155 .62093 L p .45063 .61894 L .707 .577 .707 r
F P
0 g
s
.45063 .61894 m .42541 .56396 L .45002 .62094 L .707 .577 .707 r
F
.3937 .61159 m .38876 .64968 L .41267 .65292 L p F P
0 g
s
.41267 .65292 m .42027 .65395 L p .41438 .64456 L .707 .577 .707 r
F P
0 g
s
.41438 .64456 m .3937 .61159 L .41267 .65292 L .707 .577 .707 r
F
.39532 .73776 m .39555 .75228 L .39197 .75415 L p F P
0 g
s
.39197 .75415 m .37245 .76437 L p .39532 .73776 L .707 .577 .707 r
F P
0 g
s
.23741 .60018 m .23426 .65727 L .20497 .65739 L p .707 .577 .707 r
F P
0 g
s
.30034 .60412 m .29719 .66121 L .26604 .65859 L p .707 .577 .707 r
F P
0 g
s
.26604 .65859 m .26919 .6015 L .30034 .60412 L p .707 .577 .707 r
F P
0 g
s
.34502 .80028 m .34299 .8194 L .32171 .81707 L p .707 .577 .707 r
F P
0 g
s
.32171 .81707 m .32374 .79795 L .34502 .80028 L p .707 .577 .707 r
F P
0 g
s
.23426 .65727 m .23741 .60018 L .26919 .6015 L p .707 .577 .707 r
F P
0 g
s
.32423 .72065 m .3193 .75874 L .29173 .75608 L p .707 .577 .707 r
F P
0 g
s
.29173 .75608 m .29666 .718 L .32423 .72065 L p .707 .577 .707 r
F P
0 g
s
.26919 .6015 m .26604 .65859 L .23426 .65727 L p .707 .577 .707 r
F P
0 g
s
.73349 .65655 m .73664 .59946 L .70549 .59683 L p .707 .577 .707 r
F P
0 g
s
.73664 .59946 m .73349 .65655 L .76526 .65787 L p .707 .577 .707 r
F P
0 g
s
.76526 .65787 m .76842 .60077 L .73664 .59946 L p .707 .577 .707 r
F P
0 g
s
.2341 .71009 m .22917 .74817 L .2003 .74369 L p .707 .577 .707 r
F P
0 g
s
.2003 .74369 m .20523 .7056 L .2341 .71009 L p .707 .577 .707 r
F P
0 g
s
.17881 .80194 m .18084 .78281 L .20446 .78526 L p .707 .577 .707 r
F P
0 g
s
.20446 .78526 m .20243 .80439 L .17881 .80194 L p .707 .577 .707 r
F P
0 g
s
.76842 .60077 m .76526 .65787 L .78263 .6578 L p .707 .577 .707 r
F P
0 g
s
.76821 .65268 m .73671 .64841 L p .76271 .68986 L .707 .577 .707 r
F P
0 g
s
.76328 .69077 m .76358 .68847 L p .76271 .68986 L .707 .577 .707 r
F P
0 g
s
.76358 .68847 m .76821 .65268 L p .76271 .68986 L .707 .577 .707 r
F P
0 g
s
.78263 .6578 m .79456 .65775 L p .7895 .64673 L .707 .577 .707 r
F P
0 g
s
.7895 .64673 m .76842 .60077 L .78263 .6578 L .707 .577 .707 r
F
.79456 .65775 m .79771 .60066 L .76842 .60077 L p F P
0 g
s
.59104 .24744 m .59867 .74382 L .55991 .73735 L p .707 .577 .707 r
F P
0 g
s
.55991 .73735 m .55227 .24098 L .59104 .24744 L p .707 .577 .707 r
F P
0 g
s
.70234 .65393 m .70549 .59683 L .67801 .59316 L p .707 .577 .707 r
F P
0 g
s
.70549 .59683 m .70234 .65393 L .73349 .65655 L p .707 .577 .707 r
F P
0 g
s
.29666 .718 m .29173 .75608 L .26067 .75244 L p .707 .577 .707 r
F P
0 g
s
.70565 .64477 m .70072 .68286 L .73177 .6865 L p .707 .577 .707 r
F P
0 g
s
.73177 .6865 m .73671 .64841 L .70565 .64477 L p .707 .577 .707 r
F P
0 g
s
.73671 .64841 m .73177 .6865 L .76328 .69077 L p .707 .577 .707 r
F P
0 g
s
.26067 .75244 m .2656 .71436 L .29666 .718 L p .707 .577 .707 r
F P
0 g
s
.2656 .71436 m .26067 .75244 L .22917 .74817 L p .707 .577 .707 r
F P
0 g
s
.22917 .74817 m .2341 .71009 L .2656 .71436 L p .707 .577 .707 r
F P
0 g
s
.67801 .59316 m .67486 .65026 L .70234 .65393 L p .707 .577 .707 r
F P
0 g
s
.76821 .65268 m .76328 .69077 L .79215 .69525 L p .707 .577 .707 r
F P
0 g
s
.79771 .60066 m .79456 .65775 L .80666 .65697 L p .707 .577 .707 r
F P
0 g
s
.79708 .65716 m .76821 .65268 L p .79139 .69391 L .707 .577 .707 r
F P
0 g
s
.79215 .69525 m .79274 .69065 L p .79139 .69391 L .707 .577 .707 r
F P
0 g
s
.79274 .69065 m .79708 .65716 L p .79139 .69391 L .707 .577 .707 r
F P
0 g
s
.80666 .65697 m .81849 .65621 L p .81302 .64159 L .707 .577 .707 r
F P
0 g
s
.81302 .64159 m .79771 .60066 L .80666 .65697 L .707 .577 .707 r
F
.81849 .65621 m .82164 .59912 L .79771 .60066 L p F P
0 g
s
.32374 .79795 m .32171 .81707 L .29417 .8141 L p .707 .577 .707 r
F P
0 g
s
.29417 .8141 m .2962 .79498 L .32374 .79795 L p .707 .577 .707 r
F P
0 g
s
.67807 .64212 m .67314 .6802 L .70072 .68286 L p .707 .577 .707 r
F P
0 g
s
.70072 .68286 m .70565 .64477 L .67807 .64212 L p .707 .577 .707 r
F P
0 g
s
.73272 .71109 m .73475 .69197 L .70366 .68865 L p .707 .577 .707 r
F P
0 g
s
.73475 .69197 m .73272 .71109 L .76434 .71444 L p .707 .577 .707 r
F P
0 g
s
.76434 .71444 m .76637 .69532 L .73475 .69197 L p .707 .577 .707 r
F P
0 g
s
.70366 .68865 m .70163 .70777 L .73272 .71109 L p .707 .577 .707 r
F P
0 g
s
.20243 .80439 m .20446 .78526 L .23349 .78831 L p .707 .577 .707 r
F P
0 g
s
.67486 .65026 m .67801 .59316 L .65689 .5888 L p .707 .577 .707 r
F P
0 g
s
.23349 .78831 m .23146 .80743 L .20243 .80439 L p .707 .577 .707 r
F P
0 g
s
.76637 .69532 m .76434 .71444 L .79337 .71749 L p .707 .577 .707 r
F P
0 g
s
.79337 .71749 m .7954 .69836 L .76637 .69532 L p .707 .577 .707 r
F P
0 g
s
.55227 .24098 m .55991 .73735 L .5159 .73494 L p .707 .577 .707 r
F P
0 g
s
.5159 .73494 m .50827 .23856 L .55227 .24098 L p .707 .577 .707 r
F P
0 g
s
.70163 .70777 m .70366 .68865 L .67612 .68568 L p .707 .577 .707 r
F P
0 g
s
.67612 .68568 m .67409 .7048 L .70163 .70777 L p .707 .577 .707 r
F P
0 g
s
.79708 .65716 m .79215 .69525 L .81555 .69951 L p .707 .577 .707 r
F P
0 g
s
.81555 .69951 m .82048 .66142 L .79708 .65716 L p .707 .577 .707 r
F P
0 g
s
.65689 .5888 m .65374 .6459 L .67486 .65026 L p .707 .577 .707 r
F P
0 g
s
.46333 .24043 m .50827 .23856 L p .47234 .71834 L .707 .577 .707 r
F P
0 g
s
.47059 .71287 m .46333 .24043 L p .47234 .71834 L .707 .577 .707 r
F P
0 g
s
.4547 .56384 m .45155 .62093 L .46365 .62016 L p .707 .577 .707 r
F P
0 g
s
.46365 .62016 m .47548 .6194 L p .47001 .60477 L .707 .577 .707 r
F P
0 g
s
.47001 .60477 m .4547 .56384 L .46365 .62016 L .707 .577 .707 r
F
.45155 .62093 m .4547 .56384 L .42541 .56396 L p F P
0 g
s
.45407 .62035 m .4252 .61587 L p .44838 .6571 L .707 .577 .707 r
F P
0 g
s
.44914 .65843 m .44973 .65384 L p .44838 .6571 L .707 .577 .707 r
F P
0 g
s
.44973 .65384 m .45407 .62035 L p .44838 .6571 L .707 .577 .707 r
F P
0 g
s
.45407 .62035 m .4503 .6494 L p .47254 .66269 L .707 .577 .707 r
F P
0 g
s
.4503 .6494 m .44914 .65843 L .45344 .65922 L p .707 .577 .707 r
F P
0 g
s
.45344 .65922 m .47254 .66269 L p .4503 .6494 L .707 .577 .707 r
F P
0 g
s
.47096 .73681 m .47059 .71287 L p .47234 .71834 L .707 .577 .707 r
F P
0 g
s
.2962 .79498 m .29417 .8141 L .26308 .81078 L p .707 .577 .707 r
F P
0 g
s
.26308 .81078 m .26511 .79165 L .2962 .79498 L p .707 .577 .707 r
F P
0 g
s
.65669 .64071 m .65176 .6788 L .67314 .6802 L p .707 .577 .707 r
F P
0 g
s
.67314 .6802 m .67807 .64212 L .65669 .64071 L p .707 .577 .707 r
F P
0 g
s
.23146 .80743 m .23349 .78831 L .26511 .79165 L p .707 .577 .707 r
F P
0 g
s
.26511 .79165 m .26308 .81078 L .23146 .80743 L p .707 .577 .707 r
F P
0 g
s
.50827 .23856 m .5159 .73494 L .47096 .73681 L p .707 .577 .707 r
F P
0 g
s
.82164 .59912 m .81849 .65621 L .83474 .6534 L p .707 .577 .707 r
F P
0 g
s
.83474 .6534 m .83789 .59631 L .82164 .59912 L p .707 .577 .707 r
F P
0 g
s
.7954 .69836 m .79337 .71749 L .81699 .71993 L p .707 .577 .707 r
F P
0 g
s
.81699 .71993 m .81902 .70081 L .7954 .69836 L p .707 .577 .707 r
F P
0 g
s
.67409 .7048 m .67612 .68568 L .65485 .68335 L p .707 .577 .707 r
F P
0 g
s
.65485 .68335 m .65281 .70247 L .67409 .7048 L p .707 .577 .707 r
F P
0 g
s
.65374 .6459 m .65689 .5888 L .64421 .58418 L p .707 .577 .707 r
F P
0 g
s
.82048 .66142 m .81555 .69951 L .8312 .70312 L p .707 .577 .707 r
F P
0 g
s
.8312 .70312 m .83613 .66503 L .82048 .66142 L p .707 .577 .707 r
F P
0 g
s
.65176 .6788 m .65669 .64071 L .64358 .64069 L p .707 .577 .707 r
F P
0 g
s
.81902 .70081 m .81699 .71993 L .83287 .72154 L p .707 .577 .707 r
F P
0 g
s
.83613 .66503 m .8312 .70312 L .83222 .70354 L p .707 .577 .707 r
F P
0 g
s
.83287 .72154 m .8349 .70242 L .83238 .70216 L p .707 .577 .707 r
F P
0 g
s
.83287 .72154 m .83238 .70216 L .83045 .71792 L .707 .577 .707 r
F
.8349 .70242 m .83287 .72154 L .83947 .72215 L p F P
0 g
s
.83947 .72215 m .8415 .70303 L .8349 .70242 L p .707 .577 .707 r
F P
0 g
s
.83222 .70354 m .83756 .70574 L p .83631 .67016 L .707 .577 .707 r
F P
0 g
s
.83631 .67016 m .83613 .66503 L .83222 .70354 L .707 .577 .707 r
F
.83238 .70216 m .81902 .70081 L p .83045 .71792 L F P
0 g
s
.83789 .59631 m .83474 .6534 L .84169 .64959 L p .707 .577 .707 r
F P
0 g
s
.84169 .64959 m .84484 .5925 L .83789 .59631 L p .707 .577 .707 r
F P
0 g
s
.83756 .70574 m .84249 .66765 L .83613 .66503 L p .707 .577 .707 r
F P
0 g
s
.6412 .57975 m .63805 .63684 L .64106 .64127 L p .707 .577 .707 r
F P
0 g
s
.64003 .64205 m .6351 .68014 L .63865 .67877 L p .707 .577 .707 r
F P
0 g
s
.63865 .67877 m .64358 .64069 L .64003 .64205 L p .707 .577 .707 r
F P
0 g
s
.84484 .5925 m .84169 .64959 L .83868 .64516 L p .707 .577 .707 r
F P
0 g
s
.83868 .64516 m .84183 .58807 L .84484 .5925 L p .707 .577 .707 r
F P
0 g
s
.63987 .70101 m .64191 .68189 L .63857 .68144 L p .707 .577 .707 r
F P
0 g
s
.63857 .68144 m .63654 .70057 L .63987 .70101 L p .707 .577 .707 r
F P
0 g
s
.63805 .63684 m .6412 .57975 L .64815 .57595 L p .707 .577 .707 r
F P
0 g
s
.84249 .66765 m .83756 .70574 L .83401 .7071 L p .707 .577 .707 r
F P
0 g
s
.83401 .7071 m .83894 .66901 L .84249 .66765 L p .707 .577 .707 r
F P
0 g
s
.64815 .57595 m .645 .63304 L .63805 .63684 L p .707 .577 .707 r
F P
0 g
s
.8415 .70303 m .83947 .72215 L .83614 .72171 L p .707 .577 .707 r
F P
0 g
s
.83614 .72171 m .83817 .70258 L .8415 .70303 L p .707 .577 .707 r
F P
0 g
s
.63654 .70057 m .63857 .68144 L .64412 .68196 L p .707 .577 .707 r
F P
0 g
s
.66204 .64828 m .65711 .68637 L .64397 .68333 L p .707 .577 .707 r
F P
0 g
s
.64463 .67745 m .66204 .64828 L .64397 .68333 L .707 .577 .707 r
F
.64412 .68196 m .64517 .68205 L p .64378 .68505 L F P
0 g
s
.63654 .70057 m .64412 .68196 L .64378 .68505 L .707 .577 .707 r
F
.64397 .68333 m .64146 .68276 L p .64463 .67745 L F P
0 g
s
.6464 .64467 m .64146 .68276 L .6351 .68014 L p .707 .577 .707 r
F P
0 g
s
.6351 .68014 m .64003 .64205 L .6464 .64467 L p .707 .577 .707 r
F P
0 g
s
.84183 .58807 m .83868 .64516 L .826 .64054 L p .707 .577 .707 r
F P
0 g
s
.826 .64054 m .82915 .58345 L .84183 .58807 L p .707 .577 .707 r
F P
0 g
s
.64517 .68205 m .64314 .70118 L .63654 .70057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39048 .61973 m .39363 .56264 L .36248 .56002 L p .707 .577 .707 r
F P
0 g
s
.645 .63304 m .64815 .57595 L .6644 .57313 L p .707 .577 .707 r
F P
0 g
s
.35933 .61711 m .36248 .56002 L .335 .55635 L p .707 .577 .707 r
F P
0 g
s
.36248 .56002 m .35933 .61711 L .39048 .61973 L p .707 .577 .707 r
F P
0 g
s
.83894 .66901 m .83401 .7071 L .8209 .70708 L p .707 .577 .707 r
F P
0 g
s
.8209 .70708 m .82584 .66899 L .83894 .66901 L p .707 .577 .707 r
F P
0 g
s
.36264 .60795 m .35771 .64604 L .38876 .64968 L p .707 .577 .707 r
F P
0 g
s
.38876 .64968 m .3937 .61159 L .36264 .60795 L p .707 .577 .707 r
F P
0 g
s
.6644 .57313 m .66125 .63023 L .645 .63304 L p .707 .577 .707 r
F P
0 g
s
.335 .55635 m .33185 .61344 L .35933 .61711 L p .707 .577 .707 r
F P
0 g
s
.47548 .6194 m .47863 .5623 L .4547 .56384 L p .707 .577 .707 r
F P
0 g
s
.83817 .70258 m .83614 .72171 L .8232 .72025 L p .707 .577 .707 r
F P
0 g
s
.8232 .72025 m .82523 .70112 L .83817 .70258 L p .707 .577 .707 r
F P
0 g
s
.64146 .68276 m .6464 .64467 L .66204 .64828 L p .707 .577 .707 r
F P
0 g
s
.33506 .6053 m .33013 .64339 L .35771 .64604 L p .707 .577 .707 r
F P
0 g
s
.35771 .64604 m .36264 .60795 L .33506 .6053 L p .707 .577 .707 r
F P
0 g
s
.38971 .67428 m .39174 .65515 L .36065 .65183 L p .707 .577 .707 r
F P
0 g
s
.39174 .65515 m .38971 .67428 L .42133 .67763 L p .707 .577 .707 r
F P
0 g
s
.42133 .67763 m .42336 .6585 L .39174 .65515 L p .707 .577 .707 r
F P
0 g
s
.36065 .65183 m .35862 .67096 L .38971 .67428 L p .707 .577 .707 r
F P
0 g
s
.33185 .61344 m .335 .55635 L .31388 .55199 L p .707 .577 .707 r
F P
0 g
s
.82915 .58345 m .826 .64054 L .80488 .63618 L p .707 .577 .707 r
F P
0 g
s
.80488 .63618 m .80803 .57909 L .82915 .58345 L p .707 .577 .707 r
F P
0 g
s
.42336 .6585 m .42133 .67763 L .45036 .68067 L p .707 .577 .707 r
F P
0 g
s
.45036 .68067 m .45239 .66155 L .42336 .6585 L p .707 .577 .707 r
F P
0 g
s
.68545 .65254 m .68052 .69063 L .65711 .68637 L p .707 .577 .707 r
F P
0 g
s
.65711 .68637 m .66204 .64828 L .68545 .65254 L p .707 .577 .707 r
F P
0 g
s
.64314 .70118 m .64517 .68205 L .66106 .68366 L p .707 .577 .707 r
F P
0 g
s
.66106 .68366 m .65903 .70278 L .64314 .70118 L p .707 .577 .707 r
F P
0 g
s
.35862 .67096 m .36065 .65183 L .33311 .64886 L p .707 .577 .707 r
F P
0 g
s
.33311 .64886 m .33108 .66799 L .35862 .67096 L p .707 .577 .707 r
F P
0 g
s
.47254 .66269 m .47747 .6246 L .45407 .62035 L p .707 .577 .707 r
F P
0 g
s
.31388 .55199 m .31073 .60908 L .33185 .61344 L p .707 .577 .707 r
F P
0 g
s
.66125 .63023 m .6644 .57313 L .68833 .5716 L p .707 .577 .707 r
F P
0 g
s
.31368 .6039 m .30875 .64198 L .33013 .64339 L p .707 .577 .707 r
F P
0 g
s
.33013 .64339 m .33506 .6053 L .31368 .6039 L p .707 .577 .707 r
F P
0 g
s
.82584 .66899 m .8209 .70708 L .79952 .70567 L p .707 .577 .707 r
F P
0 g
s
.47863 .5623 m .47548 .6194 L .49173 .61659 L p .707 .577 .707 r
F P
0 g
s
.49173 .61659 m .49488 .55949 L .47863 .5623 L p .707 .577 .707 r
F P
0 g
s
.45239 .66155 m .45036 .68067 L .47398 .68312 L p .707 .577 .707 r
F P
0 g
s
.47398 .68312 m .47601 .66399 L .45239 .66155 L p .707 .577 .707 r
F P
0 g
s
.79952 .70567 m .80445 .66759 L .82584 .66899 L p .707 .577 .707 r
F P
0 g
s
.68833 .5716 m .68518 .62869 L .66125 .63023 L p .707 .577 .707 r
F P
0 g
s
.33108 .66799 m .33311 .64886 L .31184 .64653 L p .707 .577 .707 r
F P
0 g
s
.31184 .64653 m .3098 .66566 L .33108 .66799 L p .707 .577 .707 r
F P
0 g
s
.31073 .60908 m .31388 .55199 L .3012 .54737 L p .707 .577 .707 r
F P
0 g
s
.82523 .70112 m .8232 .72025 L .80192 .71792 L p .707 .577 .707 r
F P
0 g
s
.80192 .71792 m .80395 .69879 L .82523 .70112 L p .707 .577 .707 r
F P
0 g
s
.80803 .57909 m .80488 .63618 L .7774 .63251 L p .707 .577 .707 r
F P
0 g
s
.7774 .63251 m .78055 .57542 L .80803 .57909 L p .707 .577 .707 r
F P
0 g
s
.47747 .6246 m .47254 .66269 L .48819 .6663 L p .707 .577 .707 r
F P
0 g
s
.48819 .6663 m .49312 .62822 L .47747 .6246 L p .707 .577 .707 r
F P
0 g
s
.3012 .54737 m .29805 .60446 L .31073 .60908 L p .707 .577 .707 r
F P
0 g
s
.68518 .62869 m .68833 .5716 L .71763 .57148 L p .707 .577 .707 r
F P
0 g
s
.68052 .69063 m .68545 .65254 L .71431 .65702 L p .707 .577 .707 r
F P
0 g
s
.65903 .70278 m .66106 .68366 L .68467 .68611 L p .707 .577 .707 r
F P
0 g
s
.71431 .65702 m .70938 .69511 L .68052 .69063 L p .707 .577 .707 r
F P
0 g
s
.68467 .68611 m .68264 .70523 L .65903 .70278 L p .707 .577 .707 r
F P
0 g
s
.30057 .60387 m .29564 .64196 L .30875 .64198 L p .707 .577 .707 r
F P
0 g
s
.30875 .64198 m .31368 .6039 L .30057 .60387 L p .707 .577 .707 r
F P
0 g
s
.47601 .66399 m .47398 .68312 L .48986 .68473 L p .707 .577 .707 r
F P
0 g
s
.49312 .62822 m .48819 .6663 L .48921 .66672 L p .707 .577 .707 r
F P
0 g
s
.48986 .68473 m .49189 .6656 L .48937 .66535 L p .707 .577 .707 r
F P
0 g
s
.48986 .68473 m .48937 .66535 L .48744 .6811 L .707 .577 .707 r
F
.49189 .6656 m .48986 .68473 L .49646 .68534 L p F P
0 g
s
.49646 .68534 m .49849 .66621 L .49189 .6656 L p .707 .577 .707 r
F P
0 g
s
.48921 .66672 m .49455 .66892 L p .4933 .63334 L .707 .577 .707 r
F P
0 g
s
.4933 .63334 m .49312 .62822 L .48921 .66672 L .707 .577 .707 r
F
.48937 .66535 m .47601 .66399 L p .48744 .6811 L F P
0 g
s
.80445 .66759 m .79952 .70567 L .77195 .70302 L p .707 .577 .707 r
F P
0 g
s
.71763 .57148 m .71447 .62857 L .68518 .62869 L p .707 .577 .707 r
F P
0 g
s
.77195 .70302 m .77688 .66493 L .80445 .66759 L p .707 .577 .707 r
F P
0 g
s
.78055 .57542 m .7774 .63251 L .74625 .62989 L p .707 .577 .707 r
F P
0 g
s
.74625 .62989 m .7494 .5728 L .78055 .57542 L p .707 .577 .707 r
F P
0 g
s
.49488 .55949 m .49173 .61659 L .49868 .61278 L p .707 .577 .707 r
F P
0 g
s
.49868 .61278 m .50183 .55569 L .49488 .55949 L p .707 .577 .707 r
F P
0 g
s
.71447 .62857 m .71763 .57148 L .7494 .5728 L p .707 .577 .707 r
F P
0 g
s
.3098 .66566 m .31184 .64653 L .2989 .64507 L p .707 .577 .707 r
F P
0 g
s
.2989 .64507 m .29686 .6642 L .3098 .66566 L p .707 .577 .707 r
F P
0 g
s
.7494 .5728 m .74625 .62989 L .71447 .62857 L p .707 .577 .707 r
F P
0 g
s
.80395 .69879 m .80192 .71792 L .77439 .71495 L p .707 .577 .707 r
F P
0 g
s
.77439 .71495 m .77642 .69582 L .80395 .69879 L p .707 .577 .707 r
F P
0 g
s
.29805 .60446 m .3012 .54737 L .29819 .54294 L p .707 .577 .707 r
F P
0 g
s
.70938 .69511 m .71431 .65702 L .74582 .66129 L p .707 .577 .707 r
F P
0 g
s
.68264 .70523 m .68467 .68611 L .71371 .68915 L p .707 .577 .707 r
F P
0 g
s
.74582 .66129 m .74089 .69938 L .70938 .69511 L p .707 .577 .707 r
F P
0 g
s
.71371 .68915 m .71168 .70828 L .68264 .70523 L p .707 .577 .707 r
F P
0 g
s
.77688 .66493 m .77195 .70302 L .74089 .69938 L p .707 .577 .707 r
F P
0 g
s
.74089 .69938 m .74582 .66129 L .77688 .66493 L p .707 .577 .707 r
F P
0 g
s
.49455 .66892 m .49948 .63084 L .49312 .62822 L p .707 .577 .707 r
F P
0 g
s
.29819 .54294 m .29504 .60003 L .29805 .60446 L p .707 .577 .707 r
F P
0 g
s
.77642 .69582 m .77439 .71495 L .74329 .71163 L p .707 .577 .707 r
F P
0 g
s
.74329 .71163 m .74532 .6925 L .77642 .69582 L p .707 .577 .707 r
F P
0 g
s
.29702 .60524 m .29209 .64332 L .29564 .64196 L p .707 .577 .707 r
F P
0 g
s
.29564 .64196 m .30057 .60387 L .29702 .60524 L p .707 .577 .707 r
F P
0 g
s
.71168 .70828 m .71371 .68915 L .74532 .6925 L p .707 .577 .707 r
F P
0 g
s
.74532 .6925 m .74329 .71163 L .71168 .70828 L p .707 .577 .707 r
F P
0 g
s
.50183 .55569 m .49868 .61278 L .49567 .60835 L p .707 .577 .707 r
F P
0 g
s
.49567 .60835 m .49882 .55126 L .50183 .55569 L p .707 .577 .707 r
F P
0 g
s
.29686 .6642 m .2989 .64507 L .29556 .64463 L p .707 .577 .707 r
F P
0 g
s
.29556 .64463 m .29353 .66375 L .29686 .6642 L p .707 .577 .707 r
F P
0 g
s
.29504 .60003 m .29819 .54294 L .30514 .53913 L p .707 .577 .707 r
F P
0 g
s
.49948 .63084 m .49455 .66892 L .491 .67028 L p .707 .577 .707 r
F P
0 g
s
.491 .67028 m .49593 .6322 L .49948 .63084 L p .707 .577 .707 r
F P
0 g
s
.30514 .53913 m .30199 .59622 L .29504 .60003 L p .707 .577 .707 r
F P
0 g
s
.49849 .66621 m .49646 .68534 L .49313 .68489 L p .707 .577 .707 r
F P
0 g
s
.49313 .68489 m .49516 .66577 L .49849 .66621 L p .707 .577 .707 r
F P
0 g
s
.29353 .66375 m .29556 .64463 L .30111 .64514 L p .707 .577 .707 r
F P
0 g
s
.31903 .61147 m .3141 .64955 L .30096 .64652 L p .707 .577 .707 r
F P
0 g
s
.30162 .64063 m .31903 .61147 L .30096 .64652 L .707 .577 .707 r
F
.30111 .64514 m .30216 .64524 L p .30076 .64823 L F P
0 g
s
.29353 .66375 m .30111 .64514 L .30076 .64823 L .707 .577 .707 r
F
.30096 .64652 m .29845 .64594 L p .30162 .64063 L F P
0 g
s
.30338 .60785 m .29845 .64594 L .29209 .64332 L p .707 .577 .707 r
F P
0 g
s
.29209 .64332 m .29702 .60524 L .30338 .60785 L p .707 .577 .707 r
F P
0 g
s
.49882 .55126 m .49567 .60835 L .48299 .60373 L p .707 .577 .707 r
F P
0 g
s
.48299 .60373 m .48614 .54663 L .49882 .55126 L p .707 .577 .707 r
F P
0 g
s
.30216 .64524 m .30013 .66436 L .29353 .66375 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30199 .59622 m .30514 .53913 L .32139 .53632 L p .707 .577 .707 r
F P
0 g
s
.49593 .6322 m .491 .67028 L .47789 .67026 L p .707 .577 .707 r
F P
0 g
s
.47789 .67026 m .48283 .63218 L .49593 .6322 L p .707 .577 .707 r
F P
0 g
s
.32139 .53632 m .31823 .59341 L .30199 .59622 L p .707 .577 .707 r
F P
0 g
s
.49516 .66577 m .49313 .68489 L .48019 .68343 L p .707 .577 .707 r
F P
0 g
s
.48019 .68343 m .48222 .66431 L .49516 .66577 L p .707 .577 .707 r
F P
0 g
s
.29845 .64594 m .30338 .60785 L .31903 .61147 L p .707 .577 .707 r
F P
0 g
s
.48614 .54663 m .48299 .60373 L .46187 .59937 L p .707 .577 .707 r
F P
0 g
s
.46187 .59937 m .46502 .54228 L .48614 .54663 L p .707 .577 .707 r
F P
0 g
s
.34244 .61572 m .33751 .65381 L .3141 .64955 L p .707 .577 .707 r
F P
0 g
s
.3141 .64955 m .31903 .61147 L .34244 .61572 L p .707 .577 .707 r
F P
0 g
s
.30013 .66436 m .30216 .64524 L .31805 .64684 L p .707 .577 .707 r
F P
0 g
s
.31805 .64684 m .31601 .66597 L .30013 .66436 L p .707 .577 .707 r
F P
0 g
s
.31823 .59341 m .32139 .53632 L .34532 .53478 L p .707 .577 .707 r
F P
0 g
s
.48283 .63218 m .47789 .67026 L .45651 .66886 L p .707 .577 .707 r
F P
0 g
s
.45651 .66886 m .46144 .63077 L .48283 .63218 L p .707 .577 .707 r
F P
0 g
s
.34532 .53478 m .34217 .59187 L .31823 .59341 L p .707 .577 .707 r
F P
0 g
s
.48222 .66431 m .48019 .68343 L .45891 .6811 L p .707 .577 .707 r
F P
0 g
s
.45891 .6811 m .46094 .66198 L .48222 .66431 L p .707 .577 .707 r
F P
0 g
s
.46502 .54228 m .46187 .59937 L .43439 .5957 L p .707 .577 .707 r
F P
0 g
s
.43439 .5957 m .43754 .5386 L .46502 .54228 L p .707 .577 .707 r
F P
0 g
s
.34217 .59187 m .34532 .53478 L .37461 .53466 L p .707 .577 .707 r
F P
0 g
s
.33751 .65381 m .34244 .61572 L .3713 .62021 L p .707 .577 .707 r
F P
0 g
s
.31601 .66597 m .31805 .64684 L .34166 .64929 L p .707 .577 .707 r
F P
0 g
s
.3713 .62021 m .36637 .65829 L .33751 .65381 L p .707 .577 .707 r
F P
0 g
s
.34166 .64929 m .33963 .66842 L .31601 .66597 L p .707 .577 .707 r
F P
0 g
s
.46144 .63077 m .45651 .66886 L .42894 .6662 L p .707 .577 .707 r
F P
0 g
s
.37461 .53466 m .37146 .59176 L .34217 .59187 L p .707 .577 .707 r
F P
0 g
s
.42894 .6662 m .43387 .62812 L .46144 .63077 L p .707 .577 .707 r
F P
0 g
s
.43754 .5386 m .43439 .5957 L .40324 .59307 L p .707 .577 .707 r
F P
0 g
s
.40324 .59307 m .40639 .53598 L .43754 .5386 L p .707 .577 .707 r
F P
0 g
s
.37146 .59176 m .37461 .53466 L .40639 .53598 L p .707 .577 .707 r
F P
0 g
s
.40639 .53598 m .40324 .59307 L .37146 .59176 L p .707 .577 .707 r
F P
0 g
s
.46094 .66198 m .45891 .6811 L .43138 .67813 L p .707 .577 .707 r
F P
0 g
s
.43138 .67813 m .43341 .65901 L .46094 .66198 L p .707 .577 .707 r
F P
0 g
s
.36637 .65829 m .3713 .62021 L .40281 .62448 L p .707 .577 .707 r
F P
0 g
s
.33963 .66842 m .34166 .64929 L .3707 .65234 L p .707 .577 .707 r
F P
0 g
s
.40281 .62448 m .39788 .66256 L .36637 .65829 L p .707 .577 .707 r
F P
0 g
s
.3707 .65234 m .36867 .67146 L .33963 .66842 L p .707 .577 .707 r
F P
0 g
s
.43387 .62812 m .42894 .6662 L .39788 .66256 L p .707 .577 .707 r
F P
0 g
s
.39788 .66256 m .40281 .62448 L .43387 .62812 L p .707 .577 .707 r
F P
0 g
s
.43341 .65901 m .43138 .67813 L .40028 .67481 L p .707 .577 .707 r
F P
0 g
s
.40028 .67481 m .40231 .65569 L .43341 .65901 L p .707 .577 .707 r
F P
0 g
s
.36867 .67146 m .3707 .65234 L .40231 .65569 L p .707 .577 .707 r
F P
0 g
s
.40231 .65569 m .40028 .67481 L .36867 .67146 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002:Ool<0027Ool0085oo`T0
00IJEP03001JEUYF00=JEPT007ioo`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01P00N7oo001eOol60008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH5
001cOol0075oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP04001JEP00001aOol006ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP04001JEUYFFUH3001^Ool006aoo`<000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF0`00JWoo001XOol20004FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Mo
o`03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP80
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP8000aJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH015YF
00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP06001JEUYFFUH005YF
IWoo001UOol00`00FUH00007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF
00001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00H005YFFUIJEP00FUIVOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUIVOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03
FUIVOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomo
o`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00Oomoo`1SOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2
000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Aoo`00FGoo8@002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001FOol30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Ao
o`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH7000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000EJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00E7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001DOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolI0014Ool005=oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000070003FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
1000FUIJEUYF2000?7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPL003Eoo`00
Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP<002mo
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P00;Goo001COol00`00FUH00002FUHO0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo001COol00`00FUH000030005
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH80004FUH00`00FUIJEP03FUH00`00
FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000hOol@000;Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003
FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000_Ool90003FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHD0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH4000015YF001JEUYF3`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH010000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002aoo`00;Goo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF001JEP@000=JEP03
001JEUYF00EJEP04001JEUYFFUH70006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUH000030007
FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;7oo000]Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP03
FUH500000eYF001JEP07FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP04FUH00`00FUIJEP030005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH01000FUIJ
EUYF2@0000=JEP00FUH01eYF00<005YFFUH00UYF3@0025YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH900000eYF
001JEP07FUH00`00FUIJEP060008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03
001JEUYF00=JEP03001JEUYF00<000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF00000eYF00@005YFFUIJEQ4000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH?0004FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEPH000MJEP03001JEUYF00IJ
EQ0000AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP05001JEUYF001J
EP030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60004
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
00000eYF001JEP02FUH2000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP0?0003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH40002FUH2000]Ool002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEPX00003
FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP06
0005FUH01000FUIJEUYF2@000eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@0
05YFFUIJEP@002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0P0015YF00@005YFFUIJEPL000=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP05FUH01P00FUIJEP00FUH0009JEPD00003FUH005YF00IJEP03001JEUYF
009JEPT000=JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF0P0015YF00<005YFFUH00UYF00<005YF00000eYF2@000eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP0800000eYF001JEP07FUH00`00FUIJEP02FUH8
0003FUH00`00FUIJEP04FUH00`00FUIJEP04000^Ool002aoo`03001JEP0000AJEP04001JEUYFFUH@
0004FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH90003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03001J
EUYF009JEPH000AJEP03001JEUYF00IJEP04001JEUYFFUH=000bOol002aoo`03001JEP00009JEPL0
00MJEP03001JEUYF00EJEPT000=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00=JEP03001JEUYF008000EJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YF00000`002EYF00<005YFFUH01EYF00<005YF00000`00=Goo000/Ool0
0`00FUH000030005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH70002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF3P001EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00D005YFFUIJEP00
00IJEP03001JEUYF00IJEP03001JEUYF00=JEPL00003FUH005YF00MJEP03001JEUYF00=JEP<0039o
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF1`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF009JEPl0009JEP03001JEP0000@002eoo`00;Goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEQ0000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP09000]Ool0
02moo`@000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEUYFFUH30002FUH=0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003=oo`<00003FUH005YF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF
00<005YFFUH015YF00<005YFFUH02`0015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo000fOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH30007FUH200000eYF00000007
0003FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YF001JEP<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003]ooa8000AJEP03001JEUYF00EJ
EP04001JEUYFFUH60003Ool01000FUIJEP0015YF1@001UYF0P0025YF2`0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00`0000=JEP00000010000UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00CGoo40002Goo00@005YFFUH000AJEPD000IJEP8000YJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00@005YFFUIJEQ00
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000^Ool006Io
o`04001JEUYF0004FUH50006FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@000eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo3`00
:Woo00@005YFFUH000EJEP<000MJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool4
00000eYF001JEP04FUH01000FUIJEUYF20008goo0UYF00<005YFFUH015YF00<005YFFUH01UYF0P00
2UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EUYFFUH70002FUH01000FUIJEUYF0P00;Woo000]Ool01000FUH005YF1P0000=JEP00FUH01UYF00@0
05YFFUIJEPT001Yoo`9JEP03001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000X000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00T002eoo`00;Goo00<0
05YF00000eYF00@005YFFUIJEPL0009JEP03001JEUYF00EJEP03001JEUYF009JEPT0015oo`9JEP03
001JEUYF00AJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00FUH:0004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000]Ool20004FUH0
0`00FUIJEP04FUH01000FUIJEUYF1`000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P002goo0UYF
00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YF00002`0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00;Goo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0100025YF00<005YFFUH01UYF00<005YF0000
0P0027oo0UYF00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH0
0UYF0`000goo300015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;7oo
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH015YF1`0000=JEP00FUH0
1eYF00<005YFFUH00UYF100017oo0UYF00<005YFFUH015YF00<005YFFUH01UYF0P002UYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00001UYF00<005YFFUH00UYF00<005YF000027oo0`0000=oo`0000002@000eYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF3`0000AJEP00FUIJEP@0009JEP03001JEUYF00iJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP0000IJEP03001JEUYF00@000Qoo`D000Qoo`h0009JEP8002ioo`00;7oo00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH020000UYF00<005YFFUH03UYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF300037oo1@005Goo1@00
;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0>FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUHGOol50018Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009JEP03
001JEUYF00iJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00AJEQQoo`<004Uoo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP80009JEP03001JEUYF00iJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF00AJEVAoo`00;Goo0`000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUIJEP80009JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEPT00003FUH005YF00YJ
EPT000QJEP03001JEUYF00EJEP03001JEUYF00AJEVAoo`00<7oo1@000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUIJEP00Ool2
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP04FUITOol003Eoo`P000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00800004OomJEUYF0006
FUH00`00FUIJEP05FUH50003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP040006FUH00`00FUIJEP04FUITOol003eoo`T000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP03001JEUYF00800004OomJEUYF0006FUH00`00FUIJEP050008FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP04FUH6
001NOol004Ioo`P000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800004OomJEUYF
0006FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH300000eYF001JEP04FUH01000FUIJEP000eYF1@00FGoo001>Ool80004FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000EJEP03001JEUYF00=JEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH0
1000FUIJEP001UYF00<005YF00000P00EWoo001FOol70003FUH01000FUIJEUYF0P0000AooeYFFUH0
00=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP04001JEUYFFUH20003FUHA001DOol005eoo`P0009oo`9JEP03001JEP00008000MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol006Mo
o`9JEP80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001JEUYF00=JEP04001JEUYF
FUH2001DOol006Moo`03FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJEP03001J
EUYF00=JEP04001JEUYFFUH2001DOol004Qoo`<001aoo`03FUH005YF00=JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol004Moo`D001]o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP03001JEUYF00=JEP04001J
EUYFFUH2001DOol002eoo`03001oogoo01Moo`D001]oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEP0000=JEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`X0011oo`D001]o
o`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol002eoo`8000AJEP04001JEUYFFUH7000:Ool3000LOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUH00004FUH0
0`00FUIJEP04FUH01000FUIJEUYF3`006goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<005YF00000eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3P004goo00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF3`00
2Woo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000=ooa0005Eoo`00;7oo10000UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01`001Goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00@005YF000006Yoo`00<7oo3@0015YF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P001Woo0P001UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`00K7oo000kOol;
0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020008Ool20004
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03
FUH3001_Ool004=oo``000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool3
00000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00005
001`Ool004aoo`/000AJEP03001JEUYF00=JEP04001JEUYFFUH2000=Ool40008FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH40002Ool5001_Ool005Eoo`h0009JEP80015oo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H000Ioo`D006moo`00HWoo1@005goo8@00
2Woo1@00Kgoo002>Ool00`00FUH00003FUH00`00FUIJEP04FUH01000FUIJEUYF2@000Woo0`00L7oo
002=Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9001/Ool0
08eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPP006Aoo`00SGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP/005Uoo`00SWoo2P000eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH02@00E7oo002EOol:0004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo
002OOol90004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
E7oo002XOolA0003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo002fOol90003FUH01000FUIJ
EUYF0P00EGoo002nOol:001EOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59676 .7758 m .59361 .72293 L .56245 .72173 L p .707 .577 .707 r
F P
0 g
s
.59361 .72293 m .59676 .7758 L .62853 .773 L p .707 .577 .707 r
F P
0 g
s
.62853 .773 m .62538 .72014 L .59361 .72293 L p .707 .577 .707 r
F P
0 g
s
.62538 .72014 m .62853 .773 L .65782 .76648 L p .707 .577 .707 r
F P
0 g
s
.65782 .76648 m .65467 .71362 L .62538 .72014 L p .707 .577 .707 r
F P
0 g
s
.5656 .77459 m .56245 .72173 L .53497 .71664 L p .707 .577 .707 r
F P
0 g
s
.56245 .72173 m .5656 .77459 L .59676 .7758 L p .707 .577 .707 r
F P
0 g
s
.65467 .71362 m .65782 .76648 L .68176 .75688 L p .707 .577 .707 r
F P
0 g
s
.68176 .75688 m .67861 .70401 L .65467 .71362 L p .707 .577 .707 r
F P
0 g
s
.53813 .7695 m .53497 .71664 L .51386 .70817 L p .707 .577 .707 r
F P
0 g
s
.53497 .71664 m .53813 .7695 L .5656 .77459 L p .707 .577 .707 r
F P
0 g
s
.67861 .70401 m .68176 .75688 L .698 .74512 L p .707 .577 .707 r
F P
0 g
s
.698 .74512 m .69485 .69226 L .67861 .70401 L p .707 .577 .707 r
F P
0 g
s
.63133 .84896 m .6293 .83256 L .59769 .83716 L p .707 .577 .707 r
F P
0 g
s
.60212 .83809 m .59719 .80662 L .56613 .8063 L p .707 .577 .707 r
F P
0 g
s
.6293 .83256 m .63133 .84896 L .66037 .83962 L p .707 .577 .707 r
F P
0 g
s
.66037 .83962 m .65833 .82322 L .6293 .83256 L p .707 .577 .707 r
F P
0 g
s
.59719 .80662 m .60212 .83809 L .63362 .83271 L p .707 .577 .707 r
F P
0 g
s
.63362 .83271 m .62869 .80124 L .59719 .80662 L p .707 .577 .707 r
F P
0 g
s
.65833 .82322 m .66037 .83962 L .68398 .82646 L p .707 .577 .707 r
F P
0 g
s
.68398 .82646 m .68195 .81006 L .65833 .82322 L p .707 .577 .707 r
F P
0 g
s
.62869 .80124 m .63362 .83271 L .66249 .82216 L p .707 .577 .707 r
F P
0 g
s
.66249 .82216 m .65756 .79069 L .62869 .80124 L p .707 .577 .707 r
F P
0 g
s
.59972 .85356 m .59769 .83716 L .56659 .83658 L p .707 .577 .707 r
F P
0 g
s
.57106 .83777 m .56613 .8063 L .53856 .80032 L p .707 .577 .707 r
F P
0 g
s
.59769 .83716 m .59972 .85356 L .63133 .84896 L p .707 .577 .707 r
F P
0 g
s
.56613 .8063 m .57106 .83777 L .60212 .83809 L p .707 .577 .707 r
F P
0 g
s
.69987 .81076 m .69784 .79436 L .68195 .81006 L p .707 .577 .707 r
F P
0 g
s
.65756 .79069 m .66249 .82216 L .68589 .80747 L p .707 .577 .707 r
F P
0 g
s
.68589 .80747 m .68096 .776 L .65756 .79069 L p .707 .577 .707 r
F P
0 g
s
.51701 .76103 m .51386 .70817 L .50118 .69714 L p .707 .577 .707 r
F P
0 g
s
.51386 .70817 m .51701 .76103 L .53813 .7695 L p .707 .577 .707 r
F P
0 g
s
.56862 .85298 m .56659 .83658 L .53906 .83087 L p .707 .577 .707 r
F P
0 g
s
.56659 .83658 m .56862 .85298 L .59972 .85356 L p .707 .577 .707 r
F P
0 g
s
.54349 .83179 m .53856 .80032 L .51717 .78927 L p .707 .577 .707 r
F P
0 g
s
.53856 .80032 m .54349 .83179 L .57106 .83777 L p .707 .577 .707 r
F P
0 g
s
.69485 .69226 m .698 .74512 L .70496 .73237 L p .707 .577 .707 r
F P
0 g
s
.70496 .73237 m .70181 .67951 L .69485 .69226 L p .707 .577 .707 r
F P
0 g
s
.69904 .79287 m .70154 .79009 L p .69837 .78792 L .707 .577 .707 r
F P
0 g
s
.70154 .79009 m .69661 .75862 L .68096 .776 L p .707 .577 .707 r
F P
0 g
s
.69661 .75862 m .70154 .79009 L .7079 .77171 L p .707 .577 .707 r
F P
0 g
s
.70647 .79407 m .70443 .77767 L .69888 .79172 L p .707 .577 .707 r
F P
0 g
s
.69888 .79172 m .69784 .79436 L p .69923 .79432 L .707 .577 .707 r
F P
0 g
s
.70647 .79407 m .69888 .79172 L .69923 .79432 L .707 .577 .707 r
F
.68096 .776 m .68589 .80747 L .69904 .79287 L p F P
0 g
s
.69837 .78792 m .68096 .776 L .69904 .79287 L .707 .577 .707 r
F
.53906 .83087 m .54109 .84727 L .56862 .85298 L p F P
0 g
s
.54109 .84727 m .53906 .83087 L .51778 .82059 L p .707 .577 .707 r
F P
0 g
s
.50118 .69714 m .50433 .75001 L .51701 .76103 L p .707 .577 .707 r
F P
0 g
s
.68195 .81006 m .68398 .82646 L .69987 .81076 L p .707 .577 .707 r
F P
0 g
s
.50433 .75001 m .50118 .69714 L .49817 .68464 L p .707 .577 .707 r
F P
0 g
s
.51778 .82059 m .51981 .83699 L .54109 .84727 L p .707 .577 .707 r
F P
0 g
s
.5221 .82074 m .51717 .78927 L .50406 .77421 L p .707 .577 .707 r
F P
0 g
s
.51717 .78927 m .5221 .82074 L .54349 .83179 L p .707 .577 .707 r
F P
0 g
s
.7079 .77171 m .70297 .74024 L .69661 .75862 L p .707 .577 .707 r
F P
0 g
s
.70181 .67951 m .70496 .73237 L .70195 .71987 L p .707 .577 .707 r
F P
0 g
s
.70195 .71987 m .6988 .66701 L .70181 .67951 L p .707 .577 .707 r
F P
0 g
s
.51981 .83699 m .51778 .82059 L .50484 .80674 L p .707 .577 .707 r
F P
0 g
s
.69784 .79436 m .69987 .81076 L .70647 .79407 L p .707 .577 .707 r
F P
0 g
s
.49817 .68464 m .50132 .73751 L .50433 .75001 L p .707 .577 .707 r
F P
0 g
s
.50484 .80674 m .50687 .82314 L .51981 .83699 L p .707 .577 .707 r
F P
0 g
s
.50406 .77421 m .50899 .80568 L .5221 .82074 L p .707 .577 .707 r
F P
0 g
s
.50899 .80568 m .50406 .77421 L .50052 .75664 L p .707 .578 .707 r
F P
0 g
s
.50132 .73751 m .49817 .68464 L .50512 .67189 L p .707 .577 .707 r
F P
0 g
s
.4841 .82068 m .49173 .31406 L .44772 .31111 L p .707 .577 .707 r
F P
0 g
s
.50687 .82314 m .50484 .80674 L .5015 .79069 L p .707 .577 .707 r
F P
0 g
s
.5015 .79069 m .50354 .80709 L .50687 .82314 L p .707 .577 .707 r
F P
0 g
s
.50052 .75664 m .50545 .78811 L .50899 .80568 L p .707 .578 .707 r
F P
0 g
s
.50512 .67189 m .50827 .72476 L .50132 .73751 L p .707 .577 .707 r
F P
0 g
s
.50545 .78811 m .50052 .75664 L .50688 .73826 L p .707 .577 .707 r
F P
0 g
s
.50827 .72476 m .50512 .67189 L .52136 .66014 L p .707 .577 .707 r
F P
0 g
s
.51062 .77151 m .52399 .75831 L p .51256 .78479 L .707 .577 .707 r
F P
0 g
s
.50688 .73826 m .51181 .76973 L .51079 .77267 L p .707 .577 .707 r
F P
0 g
s
.51079 .77267 m .50545 .78811 L p .5067 .74454 L .707 .577 .707 r
F P
0 g
s
.5067 .74454 m .50688 .73826 L .51079 .77267 L .707 .577 .707 r
F
.51014 .7904 m .5081 .774 L .51062 .77151 L p F P
0 g
s
.51014 .7904 m .51062 .77151 L .51256 .78479 L .707 .577 .707 r
F
.50354 .80709 m .5015 .79069 L .5081 .774 L p F P
0 g
s
.5081 .774 m .51014 .7904 L .50354 .80709 L p .707 .577 .707 r
F P
0 g
s
.52136 .66014 m .52451 .713 L .50827 .72476 L p .707 .577 .707 r
F P
0 g
s
.51181 .76973 m .50688 .73826 L .52253 .72088 L p .707 .577 .707 r
F P
0 g
s
.52253 .72088 m .52746 .75235 L .51181 .76973 L p .707 .577 .707 r
F P
0 g
s
.52399 .75831 m .52602 .77471 L .51014 .7904 L p .707 .577 .707 r
F P
0 g
s
.52602 .77471 m .52399 .75831 L .5476 .74515 L p .707 .577 .707 r
F P
0 g
s
.49173 .31406 m .4841 .82068 L .52904 .82037 L p .707 .577 .707 r
F P
0 g
s
.52451 .713 m .52136 .66014 L .5453 .65053 L p .707 .577 .707 r
F P
0 g
s
.5453 .65053 m .54845 .7034 L .52451 .713 L p .707 .577 .707 r
F P
0 g
s
.52746 .75235 m .52253 .72088 L .54593 .70619 L p .707 .577 .707 r
F P
0 g
s
.54593 .70619 m .54969 .7302 L p .52746 .75235 L .707 .577 .707 r
F P
0 g
s
.54969 .7302 m .55086 .73766 L .54655 .74036 L p .707 .577 .707 r
F P
0 g
s
.54655 .74036 m .52746 .75235 L p .54969 .7302 L .707 .577 .707 r
F P
0 g
s
.5476 .74515 m .54964 .76155 L .52602 .77471 L p .707 .577 .707 r
F P
0 g
s
.53667 .31375 m .49173 .31406 L p .52765 .8016 L .707 .577 .707 r
F P
0 g
s
.52904 .82037 m .5294 .79593 L p .52765 .8016 L .707 .577 .707 r
F P
0 g
s
.5294 .79593 m .53667 .31375 L p .52765 .8016 L .707 .577 .707 r
F P
0 g
s
.70297 .74024 m .7079 .77171 L .70436 .75414 L p .707 .578 .707 r
F P
0 g
s
.70436 .75414 m .69943 .72267 L .70297 .74024 L p .707 .578 .707 r
F P
0 g
s
.5453 .65053 m .57459 .64401 L p .54937 .70132 L .707 .577 .707 r
F P
0 g
s
.54845 .7034 m .54811 .69773 L p .54937 .70132 L .707 .577 .707 r
F P
0 g
s
.54811 .69773 m .5453 .65053 L p .54937 .70132 L .707 .577 .707 r
F P
0 g
s
.5748 .69564 m .57961 .69482 L p .57972 .72559 L .707 .577 .707 r
F P
0 g
s
.57943 .72522 m .5748 .69564 L p .57972 .72559 L .707 .577 .707 r
F P
0 g
s
.54593 .70619 m .5748 .69564 L p .55657 .72764 L .707 .577 .707 r
F P
0 g
s
.55086 .73766 m .54781 .71815 L p .55657 .72764 L .707 .577 .707 r
F P
0 g
s
.54781 .71815 m .54593 .70619 L p .55657 .72764 L .707 .577 .707 r
F P
0 g
s
.60445 .81037 m .60273 .77754 L .5713 .76421 L .707 .577 .707 r
F
.5748 .69564 m .57973 .72711 L .55086 .73766 L p F P
0 g
s
.57459 .64401 m .57774 .69688 L .56038 .70074 L p .707 .577 .707 r
F P
0 g
s
.55351 .69191 m .57459 .64401 L .56038 .70074 L .707 .577 .707 r
F
.57973 .72711 m .57943 .72522 L p .57972 .72559 L F P
0 g
s
.57961 .69482 m .6063 .69026 L p .58562 .71895 L .707 .577 .707 r
F P
0 g
s
.57973 .72711 m .57961 .69482 L .58562 .71895 L .707 .577 .707 r
F
.57774 .69688 m .57459 .64401 L .60637 .64122 L p F P
0 g
s
.6063 .69026 m .63736 .69058 L p .61146 .72146 L .707 .577 .707 r
F P
0 g
s
.61113 .72106 m .6063 .69026 L p .61146 .72146 L .707 .577 .707 r
F P
0 g
s
.6063 .69026 m .61123 .72173 L .57973 .72711 L p .707 .577 .707 r
F P
0 g
s
.60637 .64122 m .60952 .69408 L .5899 .69581 L p .707 .577 .707 r
F P
0 g
s
.5899 .69581 m .57774 .69688 L p .5827 .68724 L .707 .577 .707 r
F P
0 g
s
.5827 .68724 m .60637 .64122 L .5899 .69581 L .707 .577 .707 r
F
.61123 .72173 m .61113 .72106 L p .61146 .72146 L F P
0 g
s
.54964 .76155 m .5476 .74515 L .57664 .73581 L p .707 .577 .707 r
F P
0 g
s
.57867 .75221 m .57664 .73581 L .60825 .7312 L p .707 .577 .707 r
F P
0 g
s
.57664 .73581 m .57867 .75221 L .54964 .76155 L p .707 .577 .707 r
F P
0 g
s
.60825 .7312 m .61028 .7476 L .57867 .75221 L p .707 .577 .707 r
F P
0 g
s
.57814 .3102 m .57161 .74378 L p .60273 .77754 L .707 .577 .707 r
F P
0 g
s
.57161 .74378 m .57161 .74389 L p .57164 .74393 L .707 .577 .707 r
F P
0 g
s
.60273 .77754 m .57161 .74378 L .57164 .74393 L .707 .577 .707 r
F
.57161 .74389 m .5713 .76421 L p .60273 .77754 L F P
0 g
s
.56038 .70074 m .54845 .7034 L p .55351 .69191 L .707 .577 .707 r
F P
0 g
s
.63736 .69058 m .66493 .69656 L p .64237 .72196 L .707 .577 .707 r
F P
0 g
s
.64225 .72179 m .63736 .69058 L p .64237 .72196 L .707 .577 .707 r
F P
0 g
s
.63736 .69058 m .64229 .72205 L .61123 .72173 L p .707 .577 .707 r
F P
0 g
s
.63752 .64243 m .64067 .69529 L .62215 .69457 L p .707 .577 .707 r
F P
0 g
s
.62215 .69457 m .60952 .69408 L p .61471 .6845 L .707 .577 .707 r
F P
0 g
s
.61471 .6845 m .63752 .64243 L .62215 .69457 L .707 .577 .707 r
F
.64229 .72205 m .64225 .72179 L p .64237 .72196 L F P
0 g
s
.60952 .69408 m .60637 .64122 L .63752 .64243 L p .707 .577 .707 r
F P
0 g
s
.63935 .73179 m .64138 .74819 L .61028 .7476 L p .707 .577 .707 r
F P
0 g
s
.61028 .7476 m .60825 .7312 L .63935 .73179 L p .707 .577 .707 r
F P
0 g
s
.61209 .30376 m .60468 .79555 L p .62755 .80168 L .707 .577 .707 r
F P
0 g
s
.60468 .79555 m .60445 .81037 L .60803 .80903 L p .707 .577 .707 r
F P
0 g
s
.60803 .80903 m .62755 .80168 L p .60468 .79555 L .707 .577 .707 r
F P
0 g
s
.5713 .76421 m .57051 .81681 L .58846 .81341 L p .707 .577 .707 r
F P
0 g
s
.58846 .81341 m .60445 .81037 L p .5713 .76421 L .707 .577 .707 r
F P
0 g
s
.53667 .31375 m .52904 .82037 L .57051 .81681 L p .707 .577 .707 r
F P
0 g
s
.57051 .81681 m .57814 .3102 L .53667 .31375 L p .707 .577 .707 r
F P
0 g
s
.44009 .81773 m .44772 .31111 L .40896 .30518 L p .707 .577 .707 r
F P
0 g
s
.44772 .31111 m .44009 .81773 L .4841 .82068 L p .707 .577 .707 r
F P
0 g
s
.6988 .66701 m .70195 .71987 L .68926 .70885 L p .707 .577 .707 r
F P
0 g
s
.68926 .70885 m .68611 .65598 L .6988 .66701 L p .707 .577 .707 r
F P
0 g
s
.70443 .77767 m .70647 .79407 L .70313 .77802 L p .707 .577 .707 r
F P
0 g
s
.70313 .77802 m .7011 .76162 L .70443 .77767 L p .707 .577 .707 r
F P
0 g
s
.60445 .81037 m .61209 .30376 L .57814 .3102 L p .707 .577 .707 r
F P
0 g
s
.69943 .72267 m .70436 .75414 L .69125 .73908 L p .707 .577 .707 r
F P
0 g
s
.68632 .70761 m .69943 .72267 L p .69146 .73866 L .707 .577 .707 r
F P
0 g
s
.69095 .73719 m .68632 .70761 L p .69146 .73866 L .707 .577 .707 r
F P
0 g
s
.68632 .70761 m .69125 .73908 L .66986 .72803 L p .707 .577 .707 r
F P
0 g
s
.66493 .69656 m .68632 .70761 L p .67002 .72783 L .707 .577 .707 r
F P
0 g
s
.66986 .72803 m .66976 .72735 L p .67002 .72783 L .707 .577 .707 r
F P
0 g
s
.66976 .72735 m .66493 .69656 L p .67002 .72783 L .707 .577 .707 r
F P
0 g
s
.66493 .69656 m .66986 .72803 L .64229 .72205 L p .707 .577 .707 r
F P
0 g
s
.665 .64751 m .66815 .70038 L .65345 .69766 L p .707 .577 .707 r
F P
0 g
s
.65345 .69766 m .64067 .69529 L p .64619 .68445 L .707 .577 .707 r
F P
0 g
s
.64619 .68445 m .665 .64751 L .65345 .69766 L .707 .577 .707 r
F
.68611 .65598 m .68926 .70885 L .67996 .70511 L p F P
0 g
s
.67996 .70511 m .66815 .70038 L p .67366 .68675 L .707 .577 .707 r
F P
0 g
s
.67366 .68675 m .68611 .65598 L .67996 .70511 L .707 .577 .707 r
F
.69125 .73908 m .69095 .73719 L p .69146 .73866 L F P
0 g
s
.25375 .73898 m .2506 .68612 L .21944 .68491 L p .707 .577 .707 r
F P
0 g
s
.2506 .68612 m .25375 .73898 L .28552 .73619 L p .707 .577 .707 r
F P
0 g
s
.28552 .73619 m .28237 .68332 L .2506 .68612 L p .707 .577 .707 r
F P
0 g
s
.40132 .8118 m .40896 .30518 L .37923 .29685 L p .707 .577 .707 r
F P
0 g
s
.40896 .30518 m .40132 .8118 L .44009 .81773 L p .707 .577 .707 r
F P
0 g
s
.28237 .68332 m .28552 .73619 L .31481 .72967 L p .707 .577 .707 r
F P
0 g
s
.31481 .72967 m .31166 .6768 L .28237 .68332 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22259 .73778 m .21944 .68491 L .19197 .67982 L p .707 .577 .707 r
F P
0 g
s
.21944 .68491 m .22259 .73778 L .25375 .73898 L p .707 .577 .707 r
F P
0 g
s
.66815 .70038 m .665 .64751 L .68611 .65598 L p .707 .577 .707 r
F P
0 g
s
.31166 .6768 m .31481 .72967 L .33875 .72006 L p .707 .577 .707 r
F P
0 g
s
.33875 .72006 m .3356 .6672 L .31166 .6768 L p .707 .577 .707 r
F P
0 g
s
.7011 .76162 m .70313 .77802 L .69019 .76418 L p .707 .577 .707 r
F P
0 g
s
.69019 .76418 m .68816 .74778 L .7011 .76162 L p .707 .577 .707 r
F P
0 g
s
.62755 .80168 m .63518 .29506 L .61209 .30376 L p .707 .577 .707 r
F P
0 g
s
.19512 .73269 m .19197 .67982 L .17085 .67135 L p .707 .577 .707 r
F P
0 g
s
.19197 .67982 m .19512 .73269 L .22259 .73778 L p .707 .577 .707 r
F P
0 g
s
.3356 .6672 m .33875 .72006 L .35499 .70831 L p .707 .577 .707 r
F P
0 g
s
.35499 .70831 m .35184 .65544 L .3356 .6672 L p .707 .577 .707 r
F P
0 g
s
.64067 .69529 m .63752 .64243 L .665 .64751 L p .707 .577 .707 r
F P
0 g
s
.28832 .81214 m .28629 .79574 L .25468 .80034 L p .707 .577 .707 r
F P
0 g
s
.25911 .80127 m .25418 .7698 L .22312 .76949 L p .707 .577 .707 r
F P
0 g
s
.28629 .79574 m .28832 .81214 L .31736 .8028 L p .707 .577 .707 r
F P
0 g
s
.31736 .8028 m .31533 .7864 L .28629 .79574 L p .707 .577 .707 r
F P
0 g
s
.25418 .7698 m .25911 .80127 L .29062 .79589 L p .707 .577 .707 r
F P
0 g
s
.29062 .79589 m .28568 .76442 L .25418 .7698 L p .707 .577 .707 r
F P
0 g
s
.31533 .7864 m .31736 .8028 L .34097 .78964 L p .707 .577 .707 r
F P
0 g
s
.34097 .78964 m .33894 .77324 L .31533 .7864 L p .707 .577 .707 r
F P
0 g
s
.28568 .76442 m .29062 .79589 L .31948 .78534 L p .707 .577 .707 r
F P
0 g
s
.31948 .78534 m .31455 .75387 L .28568 .76442 L p .707 .577 .707 r
F P
0 g
s
.37159 .80347 m .37923 .29685 L .36144 .28694 L p .707 .577 .707 r
F P
0 g
s
.37923 .29685 m .37159 .80347 L .40132 .8118 L p .707 .577 .707 r
F P
0 g
s
.25671 .81674 m .25468 .80034 L .22358 .79976 L p .707 .577 .707 r
F P
0 g
s
.22805 .80096 m .22312 .76949 L .19555 .76351 L p .707 .577 .707 r
F P
0 g
s
.25468 .80034 m .25671 .81674 L .28832 .81214 L p .707 .577 .707 r
F P
0 g
s
.22312 .76949 m .22805 .80096 L .25911 .80127 L p .707 .577 .707 r
F P
0 g
s
.68816 .74778 m .69019 .76418 L .66892 .7539 L p .707 .577 .707 r
F P
0 g
s
.66892 .7539 m .66688 .7375 L .68816 .74778 L p .707 .577 .707 r
F P
0 g
s
.35686 .77395 m .35483 .75755 L .33894 .77324 L p .707 .577 .707 r
F P
0 g
s
.31455 .75387 m .31948 .78534 L .34288 .77066 L p .707 .577 .707 r
F P
0 g
s
.34288 .77066 m .33795 .73919 L .31455 .75387 L p .707 .577 .707 r
F P
0 g
s
.174 .72422 m .17085 .67135 L .15817 .66033 L p .707 .577 .707 r
F P
0 g
s
.17085 .67135 m .174 .72422 L .19512 .73269 L p .707 .577 .707 r
F P
0 g
s
.22561 .81616 m .22358 .79976 L .19605 .79405 L p .707 .577 .707 r
F P
0 g
s
.22358 .79976 m .22561 .81616 L .25671 .81674 L p .707 .577 .707 r
F P
0 g
s
.20048 .79498 m .19555 .76351 L .17416 .75245 L p .707 .577 .707 r
F P
0 g
s
.19555 .76351 m .20048 .79498 L .22805 .80096 L p .707 .577 .707 r
F P
0 g
s
.35184 .65544 m .35499 .70831 L .36195 .69556 L p .707 .577 .707 r
F P
0 g
s
.36195 .69556 m .3588 .64269 L .35184 .65544 L p .707 .577 .707 r
F P
0 g
s
.63518 .29506 m .62755 .80168 L .63754 .79157 L p .707 .577 .707 r
F P
0 g
s
.63754 .79157 m .64517 .28495 L .63518 .29506 L p .707 .577 .707 r
F P
0 g
s
.35603 .75606 m .35853 .75328 L p .35536 .75111 L .707 .577 .707 r
F P
0 g
s
.35853 .75328 m .3536 .72181 L .33795 .73919 L p .707 .577 .707 r
F P
0 g
s
.3536 .72181 m .35853 .75328 L .36119 .74559 L p .707 .577 .707 r
F P
0 g
s
.36119 .74559 m .3649 .7349 L p .36116 .73057 L .707 .577 .707 r
F P
0 g
s
.36116 .73057 m .3536 .72181 L .36119 .74559 L .707 .577 .707 r
F
.35587 .7549 m .35483 .75755 L p .35622 .7575 L F P
0 g
s
.33795 .73919 m .34288 .77066 L .35603 .75606 L p .707 .577 .707 r
F P
0 g
s
.35536 .75111 m .33795 .73919 L .35603 .75606 L .707 .577 .707 r
F
.33894 .77324 m .34097 .78964 L .35686 .77395 L p F P
0 g
s
.3649 .7349 m .35996 .70343 L .3536 .72181 L p .707 .577 .707 r
F P
0 g
s
.35579 .63019 m .3588 .64269 L p .35892 .67852 L .707 .577 .707 r
F P
0 g
s
.35894 .68306 m .3586 .67739 L p .35892 .67852 L .707 .577 .707 r
F P
0 g
s
.3586 .67739 m .35579 .63019 L p .35892 .67852 L .707 .577 .707 r
F P
0 g
s
.35579 .63019 m .3586 .67739 L p .34625 .67203 L .707 .577 .707 r
F P
0 g
s
.3586 .67739 m .35894 .68306 L .35828 .68248 L p .707 .577 .707 r
F P
0 g
s
.35828 .68248 m .34625 .67203 L p .3586 .67739 L .707 .577 .707 r
F P
0 g
s
.34625 .67203 m .3431 .61917 L .35579 .63019 L p .707 .577 .707 r
F P
0 g
s
.35642 .68585 m .35829 .69781 L p .34824 .70227 L .707 .577 .707 r
F P
0 g
s
.35829 .69781 m .36135 .71732 L .35626 .71148 L p .707 .577 .707 r
F P
0 g
s
.35626 .71148 m .34824 .70227 L p .35829 .69781 L .707 .577 .707 r
F P
0 g
s
.34971 .78303 m .35164 .78799 L p .35218 .73896 L .707 .577 .707 r
F P
0 g
s
.34331 .6708 m .35642 .68585 L p .34845 .70185 L .707 .577 .707 r
F P
0 g
s
.34824 .70227 m .34794 .70037 L p .34845 .70185 L .707 .577 .707 r
F P
0 g
s
.34794 .70037 m .34331 .6708 L p .34845 .70185 L .707 .577 .707 r
F P
0 g
s
.34331 .6708 m .34824 .70227 L .32685 .69121 L p .707 .577 .707 r
F P
0 g
s
.32192 .65974 m .34331 .6708 L p .32701 .69102 L .707 .577 .707 r
F P
0 g
s
.32685 .69121 m .32675 .69054 L p .32701 .69102 L .707 .577 .707 r
F P
0 g
s
.32675 .69054 m .32192 .65974 L p .32701 .69102 L .707 .577 .707 r
F P
0 g
s
.32192 .65974 m .32685 .69121 L .29928 .68523 L p .707 .577 .707 r
F P
0 g
s
.29435 .65376 m .32192 .65974 L p .29936 .68514 L .707 .577 .707 r
F P
0 g
s
.29928 .68523 m .29924 .68498 L p .29936 .68514 L .707 .577 .707 r
F P
0 g
s
.29924 .68498 m .29435 .65376 L p .29936 .68514 L .707 .577 .707 r
F P
0 g
s
.29435 .65376 m .29928 .68523 L .26822 .68492 L p .707 .577 .707 r
F P
0 g
s
.26329 .65345 m .29435 .65376 L p .26845 .68464 L .707 .577 .707 r
F P
0 g
s
.26822 .68492 m .26812 .68424 L p .26845 .68464 L .707 .577 .707 r
F P
0 g
s
.26812 .68424 m .26329 .65345 L p .26845 .68464 L .707 .577 .707 r
F P
0 g
s
.23179 .65883 m .26329 .65345 L p .23729 .68951 L .707 .577 .707 r
F P
0 g
s
.23672 .6903 m .23642 .6884 L p .23729 .68951 L .707 .577 .707 r
F P
0 g
s
.23642 .6884 m .23179 .65883 L p .23729 .68951 L .707 .577 .707 r
F P
0 g
s
.20785 .70085 m .20292 .66938 L .23179 .65883 L p .707 .577 .707 r
F P
0 g
s
.23179 .65883 m .23672 .6903 L .20785 .70085 L p .707 .577 .707 r
F P
0 g
s
.23158 .6072 m .23473 .66006 L .21737 .66393 L p .707 .577 .707 r
F P
0 g
s
.21737 .66393 m .20544 .66658 L p .2105 .6551 L .707 .577 .707 r
F P
0 g
s
.2105 .6551 m .23158 .6072 L .21737 .66393 L .707 .577 .707 r
F
.26329 .65345 m .26822 .68492 L .23672 .6903 L p F P
0 g
s
.26336 .6044 m .26651 .65727 L .24689 .65899 L p .707 .577 .707 r
F P
0 g
s
.24689 .65899 m .23473 .66006 L p .23969 .65043 L .707 .577 .707 r
F P
0 g
s
.23969 .65043 m .26336 .6044 L .24689 .65899 L .707 .577 .707 r
F
.29451 .60561 m .29766 .65848 L .27914 .65776 L p F P
0 g
s
.27914 .65776 m .26651 .65727 L p .2717 .64769 L .707 .577 .707 r
F P
0 g
s
.2717 .64769 m .29451 .60561 L .27914 .65776 L .707 .577 .707 r
F
.32199 .6107 m .32514 .66356 L .31044 .66084 L p F P
0 g
s
.31044 .66084 m .29766 .65848 L p .30318 .64763 L .707 .577 .707 r
F P
0 g
s
.30318 .64763 m .32199 .6107 L .31044 .66084 L .707 .577 .707 r
F
.3431 .61917 m .34625 .67203 L .33695 .6683 L p F P
0 g
s
.33695 .6683 m .32514 .66356 L p .33065 .64994 L .707 .577 .707 r
F P
0 g
s
.33065 .64994 m .3431 .61917 L .33695 .6683 L .707 .577 .707 r
F
.35809 .72481 m .36012 .74121 L .35632 .73713 L p F P
0 g
s
.35632 .73713 m .34718 .72736 L p .35773 .72489 L .707 .577 .707 r
F P
0 g
s
.35773 .72489 m .35809 .72481 L .35632 .73713 L .707 .577 .707 r
F
.34718 .72736 m .34515 .71096 L .35778 .72447 L p F P
0 g
s
.35778 .72447 m .35809 .72481 L p .35773 .72489 L .707 .577 .707 r
F P
0 g
s
.34718 .72736 m .35778 .72447 L .35773 .72489 L .707 .577 .707 r
F
.35406 .75677 m .35571 .66724 L .35469 .66368 L F
.35381 .79356 m .35441 .75374 L p .35406 .75677 L F P
0 g
s
.35441 .75374 m .35571 .66724 L p .35406 .75677 L .707 .577 .707 r
F P
0 g
s
.35411 .74867 m .35734 .27641 L .35176 .7767 L .707 .577 .707 r
F
.35305 .76549 m .35176 .7767 L .35164 .78799 L F
.35411 .74867 m .35176 .7767 L .35305 .76549 L F
.35734 .27641 m .35016 .75256 L p .35218 .73896 L F P
0 g
s
.35016 .75256 m .34971 .78303 L p .35218 .73896 L .707 .577 .707 r
F P
0 g
s
.35164 .78799 m .35381 .79356 L p .35411 .74867 L .707 .577 .707 r
F P
0 g
s
.35469 .66368 m .36031 .36176 L .35734 .27641 L .707 .577 .707 r
F
.35571 .66724 m .36031 .36176 L p .35469 .66368 L F P
0 g
s
.36031 .36176 m .36144 .28694 L .36013 .28358 L p .707 .577 .707 r
F P
0 g
s
.36013 .28358 m .35734 .27641 L p .36031 .36176 L .707 .577 .707 r
F P
0 g
s
.36346 .75726 m .36143 .74086 L .35587 .7549 L p .707 .577 .707 r
F P
0 g
s
.36346 .75726 m .35587 .7549 L .35622 .7575 L .707 .577 .707 r
F
.19605 .79405 m .19808 .81045 L .22561 .81616 L p F P
0 g
s
.66688 .7375 m .66892 .7539 L .64138 .74819 L p .707 .577 .707 r
F P
0 g
s
.64138 .74819 m .63935 .73179 L .66688 .7375 L p .707 .577 .707 r
F P
0 g
s
.19808 .81045 m .19605 .79405 L .17477 .78377 L p .707 .577 .707 r
F P
0 g
s
.15817 .66033 m .16132 .71319 L .174 .72422 L p .707 .577 .707 r
F P
0 g
s
.16132 .71319 m .15817 .66033 L .15516 .64783 L p .707 .577 .707 r
F P
0 g
s
.3588 .64269 m .36195 .69556 L .35894 .68306 L p .707 .577 .707 r
F P
0 g
s
.35483 .75755 m .35686 .77395 L .36346 .75726 L p .707 .577 .707 r
F P
0 g
s
.35996 .70343 m .3649 .7349 L .36135 .71732 L p .707 .578 .707 r
F P
0 g
s
.36135 .71732 m .35642 .68585 L .35996 .70343 L p .707 .578 .707 r
F P
0 g
s
.36143 .74086 m .36346 .75726 L .36012 .74121 L p .707 .577 .707 r
F P
0 g
s
.36012 .74121 m .35809 .72481 L .36143 .74086 L p .707 .577 .707 r
F P
0 g
s
.36144 .28694 m .35381 .79356 L .37159 .80347 L p .707 .577 .707 r
F P
0 g
s
.17477 .78377 m .1768 .80017 L .19808 .81045 L p .707 .577 .707 r
F P
0 g
s
.17909 .78392 m .17416 .75245 L .16105 .7374 L p .707 .577 .707 r
F P
0 g
s
.17416 .75245 m .17909 .78392 L .20048 .79498 L p .707 .577 .707 r
F P
0 g
s
.1768 .80017 m .17477 .78377 L .16183 .76993 L p .707 .577 .707 r
F P
0 g
s
.15516 .64783 m .15831 .70069 L .16132 .71319 L p .707 .577 .707 r
F P
0 g
s
.16183 .76993 m .16386 .78633 L .1768 .80017 L p .707 .577 .707 r
F P
0 g
s
.16105 .7374 m .16599 .76887 L .17909 .78392 L p .707 .577 .707 r
F P
0 g
s
.64517 .28495 m .63754 .79157 L .63343 .78105 L p .707 .577 .707 r
F P
0 g
s
.63343 .78105 m .64107 .27443 L .64517 .28495 L p .707 .577 .707 r
F P
0 g
s
.16599 .76887 m .16105 .7374 L .15751 .71982 L p .707 .578 .707 r
F P
0 g
s
.15831 .70069 m .15516 .64783 L .16211 .63508 L p .707 .577 .707 r
F P
0 g
s
.16386 .78633 m .16183 .76993 L .1585 .75387 L p .707 .577 .707 r
F P
0 g
s
.34971 .78303 m .35734 .27641 L .36733 .26631 L p .707 .577 .707 r
F P
0 g
s
.1585 .75387 m .16053 .77027 L .16386 .78633 L p .707 .577 .707 r
F P
0 g
s
.15751 .71982 m .16244 .75129 L .16599 .76887 L p .707 .578 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16211 .63508 m .16526 .68794 L .15831 .70069 L p .707 .577 .707 r
F P
0 g
s
.16244 .75129 m .15751 .71982 L .16387 .70144 L p .707 .577 .707 r
F P
0 g
s
.16526 .68794 m .16211 .63508 L .17835 .62332 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16761 .73469 m .18098 .72149 L p .16955 .74798 L .707 .577 .707 r
F P
0 g
s
.16387 .70144 m .1688 .73291 L .16778 .73585 L p .707 .577 .707 r
F P
0 g
s
.16778 .73585 m .16244 .75129 L p .16369 .70772 L .707 .577 .707 r
F P
0 g
s
.16369 .70772 m .16387 .70144 L .16778 .73585 L .707 .577 .707 r
F
.16713 .75358 m .16509 .73718 L .16761 .73469 L p F P
0 g
s
.16713 .75358 m .16761 .73469 L .16955 .74798 L .707 .577 .707 r
F
.16053 .77027 m .1585 .75387 L .16509 .73718 L p F P
0 g
s
.32514 .66356 m .32199 .6107 L .3431 .61917 L p .707 .577 .707 r
F P
0 g
s
.64107 .27443 m .63343 .78105 L .61565 .77114 L p .707 .577 .707 r
F P
0 g
s
.61565 .77114 m .62328 .26452 L .64107 .27443 L p .707 .577 .707 r
F P
0 g
s
.16509 .73718 m .16713 .75358 L .16053 .77027 L p .707 .577 .707 r
F P
0 g
s
.17835 .62332 m .1815 .67619 L .16526 .68794 L p .707 .577 .707 r
F P
0 g
s
.1688 .73291 m .16387 .70144 L .17952 .68406 L p .707 .577 .707 r
F P
0 g
s
.1815 .67619 m .17835 .62332 L .20229 .61372 L p .707 .577 .707 r
F P
0 g
s
.35969 .77293 m .36733 .26631 L .39042 .25761 L p .707 .577 .707 r
F P
0 g
s
.36733 .26631 m .35969 .77293 L .34971 .78303 L p .707 .577 .707 r
F P
0 g
s
.29766 .65848 m .29451 .60561 L .32199 .6107 L p .707 .577 .707 r
F P
0 g
s
.34515 .71096 m .34718 .72736 L .32591 .71708 L p .707 .577 .707 r
F P
0 g
s
.32591 .71708 m .32387 .70068 L .34515 .71096 L p .707 .577 .707 r
F P
0 g
s
.20544 .66658 m .20229 .61372 L .23158 .6072 L p .707 .577 .707 r
F P
0 g
s
.20229 .61372 m .20544 .66658 L .1815 .67619 L p .707 .577 .707 r
F P
0 g
s
.17952 .68406 m .18445 .71553 L .1688 .73291 L p .707 .577 .707 r
F P
0 g
s
.18445 .71553 m .17952 .68406 L .20292 .66938 L p .707 .577 .707 r
F P
0 g
s
.18098 .72149 m .18301 .73789 L .16713 .75358 L p .707 .577 .707 r
F P
0 g
s
.26651 .65727 m .26336 .6044 L .29451 .60561 L p .707 .577 .707 r
F P
0 g
s
.62328 .26452 m .61565 .77114 L .58592 .76281 L p .707 .577 .707 r
F P
0 g
s
.58592 .76281 m .59355 .25619 L .62328 .26452 L p .707 .577 .707 r
F P
0 g
s
.23473 .66006 m .23158 .6072 L .26336 .6044 L p .707 .577 .707 r
F P
0 g
s
.18301 .73789 m .18098 .72149 L .2046 .70833 L p .707 .577 .707 r
F P
0 g
s
.73396 .65724 m .73081 .60437 L .69966 .60317 L p .707 .577 .707 r
F P
0 g
s
.73081 .60437 m .73396 .65724 L .76574 .65444 L p .707 .577 .707 r
F P
0 g
s
.76574 .65444 m .76259 .60158 L .73081 .60437 L p .707 .577 .707 r
F P
0 g
s
.20292 .66938 m .20785 .70085 L .18445 .71553 L p .707 .577 .707 r
F P
0 g
s
.76259 .60158 m .76574 .65444 L .79503 .64792 L p .707 .577 .707 r
F P
0 g
s
.79503 .64792 m .79188 .59506 L .76259 .60158 L p .707 .577 .707 r
F P
0 g
s
.32387 .70068 m .32591 .71708 L .29837 .71137 L p .707 .577 .707 r
F P
0 g
s
.29837 .71137 m .29634 .69497 L .32387 .70068 L p .707 .577 .707 r
F P
0 g
s
.70281 .65603 m .69966 .60317 L .67218 .59808 L p .707 .577 .707 r
F P
0 g
s
.69966 .60317 m .70281 .65603 L .73396 .65724 L p .707 .577 .707 r
F P
0 g
s
.2046 .70833 m .20663 .72473 L .18301 .73789 L p .707 .577 .707 r
F P
0 g
s
.39042 .25761 m .38279 .76423 L .35969 .77293 L p .707 .577 .707 r
F P
0 g
s
.38279 .76423 m .39042 .25761 L .42437 .25117 L p .707 .577 .707 r
F P
0 g
s
.79188 .59506 m .79503 .64792 L .81897 .63832 L p .707 .577 .707 r
F P
0 g
s
.81897 .63832 m .81582 .58545 L .79188 .59506 L p .707 .577 .707 r
F P
0 g
s
.20663 .72473 m .2046 .70833 L .23363 .69899 L p .707 .577 .707 r
F P
0 g
s
.29634 .69497 m .29837 .71137 L .26728 .71079 L p .707 .577 .707 r
F P
0 g
s
.26728 .71079 m .26524 .69439 L .29634 .69497 L p .707 .577 .707 r
F P
0 g
s
.67533 .65094 m .67218 .59808 L .65106 .58961 L p .707 .577 .707 r
F P
0 g
s
.67218 .59808 m .67533 .65094 L .70281 .65603 L p .707 .577 .707 r
F P
0 g
s
.23566 .71539 m .23363 .69899 L .26524 .69439 L p .707 .577 .707 r
F P
0 g
s
.23363 .69899 m .23566 .71539 L .20663 .72473 L p .707 .577 .707 r
F P
0 g
s
.26524 .69439 m .26728 .71079 L .23566 .71539 L p .707 .577 .707 r
F P
0 g
s
.59355 .25619 m .58592 .76281 L .54715 .75688 L p .707 .577 .707 r
F P
0 g
s
.54715 .75688 m .55478 .25026 L .59355 .25619 L p .707 .577 .707 r
F P
0 g
s
.81582 .58545 m .81897 .63832 L .83521 .62656 L p .707 .577 .707 r
F P
0 g
s
.83521 .62656 m .83206 .5737 L .81582 .58545 L p .707 .577 .707 r
F P
0 g
s
.41673 .75779 m .42437 .25117 L .46584 .24762 L p .707 .577 .707 r
F P
0 g
s
.42437 .25117 m .41673 .75779 L .38279 .76423 L p .707 .577 .707 r
F P
0 g
s
.73932 .74389 m .73439 .71242 L .70334 .71211 L p .707 .577 .707 r
F P
0 g
s
.73439 .71242 m .73932 .74389 L .77083 .73851 L p .707 .577 .707 r
F P
0 g
s
.77083 .73851 m .7659 .70704 L .73439 .71242 L p .707 .577 .707 r
F P
0 g
s
.7659 .70704 m .77083 .73851 L .7997 .72796 L p .707 .577 .707 r
F P
0 g
s
.7997 .72796 m .79476 .69649 L .7659 .70704 L p .707 .577 .707 r
F P
0 g
s
.65422 .64247 m .65106 .58961 L .63838 .57858 L p .707 .577 .707 r
F P
0 g
s
.65106 .58961 m .65422 .64247 L .67533 .65094 L p .707 .577 .707 r
F P
0 g
s
.70827 .74358 m .70334 .71211 L .67576 .70613 L p .707 .577 .707 r
F P
0 g
s
.70334 .71211 m .70827 .74358 L .73932 .74389 L p .707 .577 .707 r
F P
0 g
s
.79476 .69649 m .7997 .72796 L .8231 .71328 L p .707 .577 .707 r
F P
0 g
s
.8231 .71328 m .81817 .68181 L .79476 .69649 L p .707 .577 .707 r
F P
0 g
s
.55478 .25026 m .54715 .75688 L .50314 .75392 L p .707 .577 .707 r
F P
0 g
s
.50314 .75392 m .51078 .2473 L .55478 .25026 L p .707 .577 .707 r
F P
0 g
s
.45821 .75424 m .46584 .24762 L .51078 .2473 L p .707 .577 .707 r
F P
0 g
s
.46584 .24762 m .45821 .75424 L .41673 .75779 L p .707 .577 .707 r
F P
0 g
s
.83206 .5737 m .83521 .62656 L .84216 .61381 L p .707 .577 .707 r
F P
0 g
s
.84216 .61381 m .83901 .56095 L .83206 .5737 L p .707 .577 .707 r
F P
0 g
s
.51078 .2473 m .50314 .75392 L .45821 .75424 L p .707 .577 .707 r
F P
0 g
s
.68069 .7376 m .67576 .70613 L .65438 .69507 L p .707 .577 .707 r
F P
0 g
s
.67576 .70613 m .68069 .7376 L .70827 .74358 L p .707 .577 .707 r
F P
0 g
s
.73692 .80545 m .73489 .78905 L .70379 .78847 L p .707 .577 .707 r
F P
0 g
s
.73489 .78905 m .73692 .80545 L .76853 .80085 L p .707 .577 .707 r
F P
0 g
s
.76853 .80085 m .7665 .78445 L .73489 .78905 L p .707 .577 .707 r
F P
0 g
s
.7665 .78445 m .76853 .80085 L .79757 .79151 L p .707 .577 .707 r
F P
0 g
s
.79757 .79151 m .79554 .77511 L .7665 .78445 L p .707 .577 .707 r
F P
0 g
s
.81817 .68181 m .8231 .71328 L .83875 .6959 L p .707 .577 .707 r
F P
0 g
s
.83875 .6959 m .83382 .66443 L .81817 .68181 L p .707 .577 .707 r
F P
0 g
s
.63838 .57858 m .64153 .63145 L .65422 .64247 L p .707 .577 .707 r
F P
0 g
s
.70583 .80487 m .70379 .78847 L .67626 .78276 L p .707 .577 .707 r
F P
0 g
s
.70379 .78847 m .70583 .80487 L .73692 .80545 L p .707 .577 .707 r
F P
0 g
s
.64153 .63145 m .63838 .57858 L .63537 .56608 L p .707 .577 .707 r
F P
0 g
s
.79554 .77511 m .79757 .79151 L .82119 .77835 L p .707 .577 .707 r
F P
0 g
s
.82119 .77835 m .81915 .76195 L .79554 .77511 L p .707 .577 .707 r
F P
0 g
s
.67626 .78276 m .67829 .79916 L .70583 .80487 L p .707 .577 .707 r
F P
0 g
s
.65931 .72654 m .65438 .69507 L .64127 .68002 L p .707 .577 .707 r
F P
0 g
s
.65438 .69507 m .65931 .72654 L .68069 .7376 L p .707 .577 .707 r
F P
0 g
s
.67829 .79916 m .67626 .78276 L .65498 .77248 L p .707 .577 .707 r
F P
0 g
s
.83901 .56095 m .84216 .61381 L .83915 .60131 L p .707 .577 .707 r
F P
0 g
s
.83915 .60131 m .836 .54845 L .83901 .56095 L p .707 .577 .707 r
F P
0 g
s
.83382 .66443 m .83875 .6959 L .84511 .67752 L p .707 .577 .707 r
F P
0 g
s
.84511 .67752 m .84018 .64605 L .83382 .66443 L p .707 .577 .707 r
F P
0 g
s
.81915 .76195 m .82119 .77835 L .83707 .76266 L p .707 .577 .707 r
F P
0 g
s
.83707 .76266 m .83504 .74626 L .81915 .76195 L p .707 .577 .707 r
F P
0 g
s
.65498 .77248 m .65701 .78888 L .67829 .79916 L p .707 .577 .707 r
F P
0 g
s
.63537 .56608 m .63852 .61895 L .64153 .63145 L p .707 .577 .707 r
F P
0 g
s
.63852 .61895 m .63537 .56608 L .64233 .55333 L p .707 .577 .707 r
F P
0 g
s
.64127 .68002 m .6462 .71149 L .65931 .72654 L p .707 .577 .707 r
F P
0 g
s
.65701 .78888 m .65498 .77248 L .64204 .75863 L p .707 .577 .707 r
F P
0 g
s
.6462 .71149 m .64127 .68002 L .63772 .66244 L p .707 .578 .707 r
F P
0 g
s
.84018 .64605 m .84511 .67752 L .84156 .65994 L p .707 .578 .707 r
F P
0 g
s
.84156 .65994 m .83663 .62847 L .84018 .64605 L p .707 .578 .707 r
F P
0 g
s
.83504 .74626 m .83707 .76266 L .84367 .74597 L p .707 .577 .707 r
F P
0 g
s
.84367 .74597 m .84164 .72957 L .83504 .74626 L p .707 .577 .707 r
F P
0 g
s
.836 .54845 m .83915 .60131 L .82647 .59029 L p .707 .577 .707 r
F P
0 g
s
.82647 .59029 m .82332 .53742 L .836 .54845 L p .707 .577 .707 r
F P
0 g
s
.64204 .75863 m .64407 .77503 L .65701 .78888 L p .707 .577 .707 r
F P
0 g
s
.64233 .55333 m .64548 .6062 L .63852 .61895 L p .707 .577 .707 r
F P
0 g
s
.63772 .66244 m .64265 .69391 L .6462 .71149 L p .707 .578 .707 r
F P
0 g
s
.64548 .6062 m .64233 .55333 L .65857 .54158 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64407 .77503 m .64204 .75863 L .63871 .74258 L p .707 .577 .707 r
F P
0 g
s
.39095 .62042 m .3878 .56756 L .35665 .56635 L p .707 .577 .707 r
F P
0 g
s
.3878 .56756 m .39095 .62042 L .42273 .61763 L p .707 .577 .707 r
F P
0 g
s
.42273 .61763 m .41958 .56476 L .3878 .56756 L p .707 .577 .707 r
F P
0 g
s
.41958 .56476 m .42273 .61763 L .45202 .61111 L p .707 .577 .707 r
F P
0 g
s
.45202 .61111 m .44887 .55824 L .41958 .56476 L p .707 .577 .707 r
F P
0 g
s
.64265 .69391 m .63772 .66244 L .64408 .64406 L p .707 .577 .707 r
F P
0 g
s
.83663 .62847 m .84156 .65994 L .82845 .64489 L p .707 .577 .707 r
F P
0 g
s
.82845 .64489 m .82352 .61342 L .83663 .62847 L p .707 .577 .707 r
F P
0 g
s
.84164 .72957 m .84367 .74597 L .84034 .72991 L p .707 .577 .707 r
F P
0 g
s
.84034 .72991 m .83831 .71351 L .84164 .72957 L p .707 .577 .707 r
F P
0 g
s
.3598 .61922 m .35665 .56635 L .32917 .56126 L p .707 .577 .707 r
F P
0 g
s
.35665 .56635 m .3598 .61922 L .39095 .62042 L p .707 .577 .707 r
F P
0 g
s
.63871 .74258 m .64074 .75898 L .64407 .77503 L p .707 .577 .707 r
F P
0 g
s
.82332 .53742 m .82647 .59029 L .80535 .58182 L p .707 .577 .707 r
F P
0 g
s
.80535 .58182 m .8022 .52895 L .82332 .53742 L p .707 .577 .707 r
F P
0 g
s
.44887 .55824 m .45202 .61111 L .47596 .6015 L p .707 .577 .707 r
F P
0 g
s
.47596 .6015 m .47281 .54864 L .44887 .55824 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65857 .54158 m .66172 .59444 L .64548 .6062 L p .707 .577 .707 r
F P
0 g
s
.33232 .61413 m .32917 .56126 L .30805 .55279 L p .707 .577 .707 r
F P
0 g
s
.32917 .56126 m .33232 .61413 L .3598 .61922 L p .707 .577 .707 r
F P
0 g
s
.66172 .59444 m .65857 .54158 L .68251 .53197 L p .707 .577 .707 r
F P
0 g
s
.64408 .64406 m .64901 .67553 L .64265 .69391 L p .707 .577 .707 r
F P
0 g
s
.64074 .75898 m .63871 .74258 L .64531 .72589 L p .707 .577 .707 r
F P
0 g
s
.64901 .67553 m .64408 .64406 L .65973 .62668 L p .707 .577 .707 r
F P
0 g
s
.82352 .61342 m .82845 .64489 L .80707 .63383 L p .707 .577 .707 r
F P
0 g
s
.80707 .63383 m .80214 .60236 L .82352 .61342 L p .707 .577 .707 r
F P
0 g
s
.47281 .54864 m .47596 .6015 L .4922 .58975 L p .707 .577 .707 r
F P
0 g
s
.4922 .58975 m .48905 .53688 L .47281 .54864 L p .707 .577 .707 r
F P
0 g
s
.8022 .52895 m .80535 .58182 L .77788 .57673 L p .707 .577 .707 r
F P
0 g
s
.77788 .57673 m .77473 .52387 L .8022 .52895 L p .707 .577 .707 r
F P
0 g
s
.83831 .71351 m .84034 .72991 L .8274 .71607 L p .707 .577 .707 r
F P
0 g
s
.8274 .71607 m .82537 .69967 L .83831 .71351 L p .707 .577 .707 r
F P
0 g
s
.64531 .72589 m .64734 .74229 L .64074 .75898 L p .707 .577 .707 r
F P
0 g
s
.39631 .70708 m .39138 .67561 L .36033 .67529 L p .707 .577 .707 r
F P
0 g
s
.39138 .67561 m .39631 .70708 L .42782 .7017 L p .707 .577 .707 r
F P
0 g
s
.42782 .7017 m .42289 .67023 L .39138 .67561 L p .707 .577 .707 r
F P
0 g
s
.42289 .67023 m .42782 .7017 L .45669 .69115 L p .707 .577 .707 r
F P
0 g
s
.45669 .69115 m .45175 .65968 L .42289 .67023 L p .707 .577 .707 r
F P
0 g
s
.68566 .58484 m .68251 .53197 L .7118 .52545 L p .707 .577 .707 r
F P
0 g
s
.68251 .53197 m .68566 .58484 L .66172 .59444 L p .707 .577 .707 r
F P
0 g
s
.31121 .60566 m .30805 .55279 L .29537 .54177 L p .707 .577 .707 r
F P
0 g
s
.30805 .55279 m .31121 .60566 L .33232 .61413 L p .707 .577 .707 r
F P
0 g
s
.36526 .70676 m .36033 .67529 L .33275 .66931 L p .707 .577 .707 r
F P
0 g
s
.36033 .67529 m .36526 .70676 L .39631 .70708 L p .707 .577 .707 r
F P
0 g
s
.77473 .52387 m .77788 .57673 L .74672 .57552 L p .707 .577 .707 r
F P
0 g
s
.74672 .57552 m .74357 .52266 L .77473 .52387 L p .707 .577 .707 r
F P
0 g
s
.45175 .65968 m .45669 .69115 L .48009 .67646 L p .707 .577 .707 r
F P
0 g
s
.48009 .67646 m .47516 .64499 L .45175 .65968 L p .707 .577 .707 r
F P
0 g
s
.65973 .62668 m .66466 .65815 L .64901 .67553 L p .707 .577 .707 r
F P
0 g
s
.66466 .65815 m .65973 .62668 L .68314 .612 L p .707 .577 .707 r
F P
0 g
s
.80214 .60236 m .80707 .63383 L .7795 .62785 L p .707 .577 .707 r
F P
0 g
s
.7795 .62785 m .77457 .59638 L .80214 .60236 L p .707 .577 .707 r
F P
0 g
s
.71495 .57832 m .7118 .52545 L .74357 .52266 L p .707 .577 .707 r
F P
0 g
s
.7118 .52545 m .71495 .57832 L .68566 .58484 L p .707 .577 .707 r
F P
0 g
s
.64734 .74229 m .64531 .72589 L .66119 .7102 L p .707 .577 .707 r
F P
0 g
s
.74357 .52266 m .74672 .57552 L .71495 .57832 L p .707 .577 .707 r
F P
0 g
s
.48905 .53688 m .4922 .58975 L .49915 .577 L p .707 .577 .707 r
F P
0 g
s
.49915 .577 m .496 .52413 L .48905 .53688 L p .707 .577 .707 r
F P
0 g
s
.82537 .69967 m .8274 .71607 L .80612 .70579 L p .707 .577 .707 r
F P
0 g
s
.80612 .70579 m .80409 .68939 L .82537 .69967 L p .707 .577 .707 r
F P
0 g
s
.33768 .70078 m .33275 .66931 L .31137 .65826 L p .707 .577 .707 r
F P
0 g
s
.33275 .66931 m .33768 .70078 L .36526 .70676 L p .707 .577 .707 r
F P
0 g
s
.39391 .76864 m .39188 .75224 L .36078 .75165 L p .707 .577 .707 r
F P
0 g
s
.39188 .75224 m .39391 .76864 L .42552 .76403 L p .707 .577 .707 r
F P
0 g
s
.42552 .76403 m .42349 .74763 L .39188 .75224 L p .707 .577 .707 r
F P
0 g
s
.42349 .74763 m .42552 .76403 L .45456 .75469 L p .707 .577 .707 r
F P
0 g
s
.45456 .75469 m .45253 .73829 L .42349 .74763 L p .707 .577 .707 r
F P
0 g
s
.66119 .7102 m .66322 .7266 L .64734 .74229 L p .707 .577 .707 r
F P
0 g
s
.47516 .64499 m .48009 .67646 L .49574 .65908 L p .707 .577 .707 r
F P
0 g
s
.49574 .65908 m .49081 .62761 L .47516 .64499 L p .707 .577 .707 r
F P
0 g
s
.68807 .64347 m .68314 .612 L .712 .60145 L p .707 .577 .707 r
F P
0 g
s
.68314 .612 m .68807 .64347 L .66466 .65815 L p .707 .577 .707 r
F P
0 g
s
.77457 .59638 m .7795 .62785 L .74844 .62754 L p .707 .577 .707 r
F P
0 g
s
.74844 .62754 m .74351 .59607 L .77457 .59638 L p .707 .577 .707 r
F P
0 g
s
.29537 .54177 m .29852 .59463 L .31121 .60566 L p .707 .577 .707 r
F P
0 g
s
.36282 .76805 m .36078 .75165 L .33325 .74594 L p .707 .577 .707 r
F P
0 g
s
.36078 .75165 m .36282 .76805 L .39391 .76864 L p .707 .577 .707 r
F P
0 g
s
.29852 .59463 m .29537 .54177 L .29236 .52927 L p .707 .577 .707 r
F P
0 g
s
.45253 .73829 m .45456 .75469 L .47818 .74153 L p .707 .577 .707 r
F P
0 g
s
.47818 .74153 m .47614 .72513 L .45253 .73829 L p .707 .577 .707 r
F P
0 g
s
.71693 .63292 m .712 .60145 L .74351 .59607 L p .707 .577 .707 r
F P
0 g
s
.712 .60145 m .71693 .63292 L .68807 .64347 L p .707 .577 .707 r
F P
0 g
s
.74351 .59607 m .74844 .62754 L .71693 .63292 L p .707 .577 .707 r
F P
0 g
s
.66322 .7266 m .66119 .7102 L .68481 .69704 L p .707 .577 .707 r
F P
0 g
s
.33325 .74594 m .33528 .76234 L .36282 .76805 L p .707 .577 .707 r
F P
0 g
s
.80409 .68939 m .80612 .70579 L .77859 .70008 L p .707 .577 .707 r
F P
0 g
s
.77859 .70008 m .77655 .68368 L .80409 .68939 L p .707 .577 .707 r
F P
0 g
s
.3163 .68973 m .31137 .65826 L .29826 .6432 L p .707 .577 .707 r
F P
0 g
s
.31137 .65826 m .3163 .68973 L .33768 .70078 L p .707 .577 .707 r
F P
0 g
s
.33528 .76234 m .33325 .74594 L .31197 .73566 L p .707 .577 .707 r
F P
0 g
s
.496 .52413 m .49915 .577 L .49614 .5645 L p .707 .577 .707 r
F P
0 g
s
.49614 .5645 m .49299 .51163 L .496 .52413 L p .707 .577 .707 r
F P
0 g
s
.68481 .69704 m .68684 .71344 L .66322 .7266 L p .707 .577 .707 r
F P
0 g
s
.49081 .62761 m .49574 .65908 L .5021 .6407 L p .707 .577 .707 r
F P
0 g
s
.5021 .6407 m .49717 .60923 L .49081 .62761 L p .707 .577 .707 r
F P
0 g
s
.47614 .72513 m .47818 .74153 L .49406 .72584 L p .707 .577 .707 r
F P
0 g
s
.49406 .72584 m .49203 .70944 L .47614 .72513 L p .707 .577 .707 r
F P
0 g
s
.68684 .71344 m .68481 .69704 L .71384 .6877 L p .707 .577 .707 r
F P
0 g
s
.31197 .73566 m .314 .75206 L .33528 .76234 L p .707 .577 .707 r
F P
0 g
s
.29236 .52927 m .29551 .58213 L .29852 .59463 L p .707 .577 .707 r
F P
0 g
s
.77655 .68368 m .77859 .70008 L .74749 .6995 L p .707 .577 .707 r
F P
0 g
s
.74749 .6995 m .74546 .6831 L .77655 .68368 L p .707 .577 .707 r
F P
0 g
s
.29551 .58213 m .29236 .52927 L .29931 .51652 L p .707 .577 .707 r
F P
0 g
s
.71588 .7041 m .71384 .6877 L .74546 .6831 L p .707 .577 .707 r
F P
0 g
s
.71384 .6877 m .71588 .7041 L .68684 .71344 L p .707 .577 .707 r
F P
0 g
s
.74546 .6831 m .74749 .6995 L .71588 .7041 L p .707 .577 .707 r
F P
0 g
s
.29826 .6432 m .30319 .67467 L .3163 .68973 L p .707 .577 .707 r
F P
0 g
s
.314 .75206 m .31197 .73566 L .29903 .72182 L p .707 .577 .707 r
F P
0 g
s
.30319 .67467 m .29826 .6432 L .29471 .62563 L p .707 .578 .707 r
F P
0 g
s
.49717 .60923 m .5021 .6407 L .49855 .62313 L p .707 .578 .707 r
F P
0 g
s
.49855 .62313 m .49362 .59165 L .49717 .60923 L p .707 .578 .707 r
F P
0 g
s
.49203 .70944 m .49406 .72584 L .50066 .70915 L p .707 .577 .707 r
F P
0 g
s
.50066 .70915 m .49863 .69275 L .49203 .70944 L p .707 .577 .707 r
F P
0 g
s
.49299 .51163 m .49614 .5645 L .48346 .55347 L p .707 .577 .707 r
F P
0 g
s
.48346 .55347 m .48031 .50061 L .49299 .51163 L p .707 .577 .707 r
F P
0 g
s
.29903 .72182 m .30106 .73822 L .314 .75206 L p .707 .577 .707 r
F P
0 g
s
.29931 .51652 m .30247 .56938 L .29551 .58213 L p .707 .577 .707 r
F P
0 g
s
.29471 .62563 m .29964 .6571 L .30319 .67467 L p .707 .578 .707 r
F P
0 g
s
.30247 .56938 m .29931 .51652 L .31556 .50476 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30106 .73822 m .29903 .72182 L .2957 .70577 L p .707 .577 .707 r
F P
0 g
s
.29964 .6571 m .29471 .62563 L .30107 .60725 L p .707 .577 .707 r
F P
0 g
s
.49362 .59165 m .49855 .62313 L .48544 .60807 L p .707 .577 .707 r
F P
0 g
s
.48544 .60807 m .48051 .5766 L .49362 .59165 L p .707 .577 .707 r
F P
0 g
s
.49863 .69275 m .50066 .70915 L .49733 .6931 L p .707 .577 .707 r
F P
0 g
s
.49733 .6931 m .4953 .6767 L .49863 .69275 L p .707 .577 .707 r
F P
0 g
s
.2957 .70577 m .29773 .72217 L .30106 .73822 L p .707 .577 .707 r
F P
0 g
s
.48031 .50061 m .48346 .55347 L .46234 .545 L p .707 .577 .707 r
F P
0 g
s
.46234 .545 m .45919 .49214 L .48031 .50061 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31556 .50476 m .31871 .55763 L .30247 .56938 L p .707 .577 .707 r
F P
0 g
s
.31871 .55763 m .31556 .50476 L .33949 .49516 L p .707 .577 .707 r
F P
0 g
s
.30107 .60725 m .306 .63872 L .29964 .6571 L p .707 .577 .707 r
F P
0 g
s
.29773 .72217 m .2957 .70577 L .3023 .68908 L p .707 .577 .707 r
F P
0 g
s
.306 .63872 m .30107 .60725 L .31672 .58986 L p .707 .577 .707 r
F P
0 g
s
.48051 .5766 m .48544 .60807 L .46406 .59701 L p .707 .577 .707 r
F P
0 g
s
.46406 .59701 m .45913 .56554 L .48051 .5766 L p .707 .577 .707 r
F P
0 g
s
.45919 .49214 m .46234 .545 L .43487 .53991 L p .707 .577 .707 r
F P
0 g
s
.43487 .53991 m .43172 .48705 L .45919 .49214 L p .707 .577 .707 r
F P
0 g
s
.4953 .6767 m .49733 .6931 L .48439 .67925 L p .707 .577 .707 r
F P
0 g
s
.48439 .67925 m .48236 .66285 L .4953 .6767 L p .707 .577 .707 r
F P
0 g
s
.3023 .68908 m .30433 .70548 L .29773 .72217 L p .707 .577 .707 r
F P
0 g
s
.34265 .54802 m .33949 .49516 L .36879 .48864 L p .707 .577 .707 r
F P
0 g
s
.33949 .49516 m .34265 .54802 L .31871 .55763 L p .707 .577 .707 r
F P
0 g
s
.43172 .48705 m .43487 .53991 L .40371 .53871 L p .707 .577 .707 r
F P
0 g
s
.40371 .53871 m .40056 .48584 L .43172 .48705 L p .707 .577 .707 r
F P
0 g
s
.31672 .58986 m .32165 .62133 L .306 .63872 L p .707 .577 .707 r
F P
0 g
s
.32165 .62133 m .31672 .58986 L .34013 .57518 L p .707 .577 .707 r
F P
0 g
s
.45913 .56554 m .46406 .59701 L .43649 .59104 L p .707 .577 .707 r
F P
0 g
s
.43649 .59104 m .43155 .55957 L .45913 .56554 L p .707 .577 .707 r
F P
0 g
s
.37194 .5415 m .36879 .48864 L .40056 .48584 L p .707 .577 .707 r
F P
0 g
s
.36879 .48864 m .37194 .5415 L .34265 .54802 L p .707 .577 .707 r
F P
0 g
s
.30433 .70548 m .3023 .68908 L .31818 .67338 L p .707 .577 .707 r
F P
0 g
s
.40056 .48584 m .40371 .53871 L .37194 .5415 L p .707 .577 .707 r
F P
0 g
s
.48236 .66285 m .48439 .67925 L .46311 .66897 L p .707 .577 .707 r
F P
0 g
s
.46311 .66897 m .46108 .65257 L .48236 .66285 L p .707 .577 .707 r
F P
0 g
s
.31818 .67338 m .32021 .68978 L .30433 .70548 L p .707 .577 .707 r
F P
0 g
s
.34506 .60665 m .34013 .57518 L .36899 .56463 L p .707 .577 .707 r
F P
0 g
s
.34013 .57518 m .34506 .60665 L .32165 .62133 L p .707 .577 .707 r
F P
0 g
s
.43155 .55957 m .43649 .59104 L .40543 .59072 L p .707 .577 .707 r
F P
0 g
s
.40543 .59072 m .4005 .55925 L .43155 .55957 L p .707 .577 .707 r
F P
0 g
s
.37392 .5961 m .36899 .56463 L .4005 .55925 L p .707 .577 .707 r
F P
0 g
s
.36899 .56463 m .37392 .5961 L .34506 .60665 L p .707 .577 .707 r
F P
0 g
s
.4005 .55925 m .40543 .59072 L .37392 .5961 L p .707 .577 .707 r
F P
0 g
s
.32021 .68978 m .31818 .67338 L .3418 .66022 L p .707 .577 .707 r
F P
0 g
s
.46108 .65257 m .46311 .66897 L .43557 .66326 L p .707 .577 .707 r
F P
0 g
s
.43557 .66326 m .43354 .64686 L .46108 .65257 L p .707 .577 .707 r
F P
0 g
s
.3418 .66022 m .34383 .67662 L .32021 .68978 L p .707 .577 .707 r
F P
0 g
s
.34383 .67662 m .3418 .66022 L .37083 .65088 L p .707 .577 .707 r
F P
0 g
s
.43354 .64686 m .43557 .66326 L .40448 .66268 L p .707 .577 .707 r
F P
0 g
s
.40448 .66268 m .40245 .64628 L .43354 .64686 L p .707 .577 .707 r
F P
0 g
s
.37287 .66728 m .37083 .65088 L .40245 .64628 L p .707 .577 .707 r
F P
0 g
s
.37083 .65088 m .37287 .66728 L .34383 .67662 L p .707 .577 .707 r
F P
0 g
s
.40245 .64628 m .40448 .66268 L .37287 .66728 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo001oOolH0026Ool007Ioo`T000EJEP03001JEUYF00YJEP03001JEUYF00=JEP`007Yoo`00
LGoo1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF1`00
Lgoo001]Ool40007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUH00002001`Ool006Yoo`<00003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00J7oo0P0015YF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P00Jgoo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF008006Moo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00=JEP8006Eoo`00IGoo00@005YFFUH000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IGoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00I7oo00<005YFFUH05`001EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06
FUH01000FUIJEUYF1P0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001OOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3
000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05eoo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Ioo`00Fgoo0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001IOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Ioo`800003FUH005YF
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001VOol005Eoo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001DOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0067oo2@00AGoo001C
Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P004Goo1`0015YF00<005YFFUH00UYF2000?Goo
001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P003Goo10000UYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPH003Moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Yoo`<0
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008003Aoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Qoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000Ioo`80009JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
035oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF20002EYF00<005YFFUH0
0eYF10000UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8000Aoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00Dgoo00<005YF
000015YF00<005YFFUH00eYF1P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH01eYF1000
15YF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP80009oo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001JEP0000AJEP04001JEUYFFUH2
0004Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF00000P0000=JEP00
FUH00UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF000_Ool005=oo`03001JEP0000AJEP04001JEP000006Ool01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01eYF100000=JEP00FUH00P000eYF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF000_Ool005=oo`<000AJEP8000Qoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH30005FUH01@00FUIJEUYF00000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00Dgoo0`000UYF
0P000UYF0`001Goo00@005YFFUH000EJEQ400003FUH005YF00EJEP03001JEUYF009JEP<0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF008002ioo`00Dgoo1@001EYF00<005YF00000`0000Aoo`00FUIJEPH000AJEP03
001JEUYF00IJEP04001JEUYFFUH50003FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`<00003FUH005YF00AJEP03001JEUYF00=JEP@00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00=JEP03001JEP00009JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00E7oo0P0000=JEP00FUH015YF00<005YFFUH00UYF0`000eYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YF0000
0UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP001EYF00<005YFFUH00P00
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<0
05YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH0
15YF00<005YFFUH00eYF00<005YFFUH00P00;Woo001DOol01000FUIJEP001EYF100025YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P0000AJEP00FUH0009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03
001JEUYF00=JEP03001JEUYF00AJEPL000Uoo`P000=JEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool005Aoo`05001JEUYFFUH00004FUH01000FUIJEP0025YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00=JEP03001JEUYF
00@001Qoo`D000AJEP05001JEUYFFUH0000^Ool005Aoo`05001JEUYFFUH00002FUH20004FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEP0015YF00<005YFFUH00eYF0`008Goo0`0000=JEP00FUH00UYF00<007ooOol0;7oo001D
Ool01`00FUIJEUYF001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YFFUIJEP8002=oo`<00003FUH0
000000=JEP8002eoo`00E7oo00@005YFFUIJEP<000IJEP03001JEUYF00IJEP03001JEUYF009JEQ40
00=JEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF00@005YF000002=oo`80009JEP05001JEUYFFUH0
0002FUH2000]Ool005Aoo`07001JEUYFFUH005YF00001UYF00<005YFFUH01EYF1`0025YF00<005YF
FUH01EYF10001EYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000AJEP8001=oo`d00003Ool00000008000AJEP03001JEUYF009J
EP04001JEP00000]Ool005Eoo`03001JEP00009JEP03001JEUYF00EJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH01000FUIJEP000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000UYF0P000UYF
1@002Woo10000UYF00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH00UYF1000;Goo0016
Ool90007Ool01@00FUIJEUYF00001eYF00<005YF00000P0025YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P0000AJEP00FUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEP00008000EJEP04001JEUYFFUH:0006FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP03FUH3000]Ool0041oo`H000AJEP03001JEUYF
009JEPL000EJEP03001JEUYF00AJEP80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP0000<0009JEP80009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP05001JEP00FUH00005FUH00`00FUIJEP04FUH300000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020005FUH3000]Ool003aoo`@00003FUH0
05YF00IJEP03Ool005YF00MJEP03001JEP0000EJEP03001JEUYF009JEP8000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<00003FUH005YF00EJEP04001JEUYF0002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0015YF00<005YF0000;Goo000hOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30005
FUH00`00FUIJEP020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040004FUH00`00
FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUH0000]Ool003Ioo`800003FUH0
05YF00IJEP03001JEUYF00AJEP03OomJEP0000QJEP<000EJEPT0009JEP03001JEUYF00IJEP03001J
EUYF009JEPL000QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP@000MJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH0000002ioo`00=7oo0P00
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH0
0UYF0P000Woo40000eYF00<005YFFUH02EYF00<005YFFUH01UYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00
00=JEP000000;Woo000bOol20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH017ooFUIJEP0025YF
00@005YFFUH000=JEP8000EJEP800005Ool005YFFUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUH00000;goo000aOol20006FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000UYF00<005YF00001EYF
00@005YF0000009JEP03001JEUYF00=JEP03001JEP00008000EJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEP00008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009J
EP03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF009JEPl000IJEP03001JEUYF009JEP04001J
EUYF000_Ool002moo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEP03OomJEUYF
009JEP05001JEUYFFUIoo`03FUH01P00FUIJEP00FUH0009JEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2000015YF000000002eYF
00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF0`001eYF00<005YFFUH015YF
1`0025YF00<005YFFUH00eYF10000UYF00<005YFFUH00eYF00<005YF0000;goo000^Ool01@00FUIJ
EUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000=JEP03
001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH00`00FUH00002FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3
000015YF001JEP001eYF00<005YFFUH00UYF0P001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YF00000P001EYF00<005YF0000;goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
1000FUIJEWoo1EYF00@005YFFUIoo`EJEP04001JEP00Ool4FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YFFUH00UYF00<005YF000010000eYF00<005YFFUH02EYF00<005YFFUH015YF00<005YF
00000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000Eoo`00001J
EP0000MJEP03001JEP00008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
00=JEP04001JEUYF000^Ool002eoo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJ
EP02FUH00`00FUIJEP030004FUH00`00FUIJEP09FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P00
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000Eoo`00FUIJEP0000MJEP80
009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH200001Goo0000
05YF00000UYF00<007ooOol0;7oo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIoo`06FUH00`00FUIoo`06FUH00`00FUH00005FUH00`00FUIJEP02FUH01P00FUH00000
FUH000EJEP04001JEUYFFUH=0005FUH00`00FUIJEP02FUH00`00FUIJEP02FUH01000FUH000002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF0P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000Eoo`80009JEP03001o
ogoo02aoo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF0`0000=JEP00FUH015YF10000UYF00<005YFFUH0
1UYF00<005YF00000`0000AJEP00FUIJEP<000AJEP800003FUH005YF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF00=JEP<000AJEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30009Ool00`00FUH0000^Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001ooeYF00IJEP03001JEUYF00IJEP<000EJEP03001JEUYF00=J
EP<00003FUH005YF00@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF009J
EP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03
001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@000eoo`03001JEP00
02eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH015YF1000
1eYF0P0000=JEP00FUH00eYF00<005YFFUH00eYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0000=JEP00FUH00eYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP04001JEP000004FUH30003FUHJ000AOol3000]Ool002aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEPT00004FUH005YFFUH90002FUH20002FUH00`00FUIJEP02
FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP020004FUH0
1000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF0P001EYF0P009goo00@005YFFUH002eoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YF00000`0000=JEP00FUH025YF00<005YFFUH01UYF0P000UYF1@000UYF0`001eYF00<005YFFUH0
0UYF3`001UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0005FUH00`00FUH0000VOol0
1000FUIJEP00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH50003FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH01@00FUH005YF00000UYF10000UYF00<005YFFUH015YF1P0025YF00@005YFFUIJ
EPL0009JEP03001JEUYF00=JEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP80009JEP03001JEP00009JEP03001JEUYF00=JEP04001JEUYF000:Ool3000G
Ool20002FUH00`00Oomoo`0[Ool002aoo`03001JEP0000AJEP04001JEUYFFUH40007FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01@00FUH005YF00000UYF0P0015YF00<005YFFUH00UYF0P0015YF00<0
05YFFUH01eYF10001UYF10001EYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00<005YFFUH00eYF00@005YFFUH000Uoo`D0
01Eoo`03001JEP0000=JEP03001oogoo02Yoo`00;7oo00<005YF000015YF00<005YF0000100025YF
00<005YFFUH01UYF00<005YFFUH01UYF00L005YF001JEP00FUH00006FUH00`00FUH000030005FUH0
0`00FUIJEP03FUH40002FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YF00000eYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P000eYF00<0
05YFFUH00eYF00@005YFFUH000Uoo`D001Eoo`04001JEUYF0002FUH00`00Oomoo`0ZOol002aoo`<0
00AJEP800005Ool005YFFUH00008FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH005YF0P00
1UYF0P0000=JEP00000030001UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP00
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03
001JEUYF009JEP03001JEUYF00=JEP03001JEUYF008000Qoo`D001Aoo`05001JEUYFFUH00002FUH0
0`00Oomoo`0ZOol002aoo`<0009JEP800003FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP06001JEP00001JEP0015YF0P001EYF00<005YFFUH01UYF0`001UYF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF008000Uoo`<001Ao
o`03001JEUYF009JEP04001JEUYF000/Ool002aoo`D0009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00AJEPd000AJEP04001JEUYF0007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06
FUH00`00FUIJEP020004FUH00`00FUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP03FUH00`00FUIJEP020007Ool?0008Ool30004
FUH00`00FUH0000]Ool002eoo`800003FUH005YF008000IJEP03001JEUYF00IJEP03001JEUYF00H0
00AJEP03001JEUYF009JEP03001JEUYF00=JEP<00003FUH005YF00EJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP<000MJEP05001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH50004FUH00`00FUIJEP03FUH00`00FUIJEP0200000goo000000040004FUH00`00
FUIJEP06FUH00`00FUH000030003Ool01000FUIJEP001EYF0P00;Goo000]Ool200001EYF000005YF
00001UYF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH00UYF00<005YFFUH00eYF00D0
05YFFUIJEP0000IJEP03001JEUYF00EJEPD000IJEP03001JEUYF00AJEP<000UJEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009JEP05001JEUYFFUH00005
FUH00`00FUIJEP0300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH00`00
FUIJEP03FUH00`00Oomoo`0/Ool002eoo`04001JEUYF0002FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20005FUH?0004FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP08FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH30003FUH01000FUIJEP001EYF10000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000P001EYF00<007ooOol0;7oo000]Ool00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUH0000200000eYF000000040004FUH00`00FUIJEP06FUH01000FUH005YF0P000UYF
0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YF
FUH01eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF1000
0UYF10000eYF0`001eYF00<005YFFUH015YF1`0015YF00<005YFFUH015YF00<005YFFUH00UYF0P00
0UYF00<007ooOol0;Goo000]Ool20005FUH00`00FUIJEP04FUH200001UYF00000000FUH000QJEP03
001JEUYF00IJEP04001JEP000002FUH300000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40007FUH00`00FUIJEP07FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP0400000eYF001JEP07FUH00`00FUIJEP040007Ool8
0004FUH00`00FUIJEP02FUH3000`Ool002eoo`8000EJEP03001JEUYF009JEP800004FUH000000003
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH3000015YF001JEUYF2@0015YF00<0
05YFFUH010002eYF00<005YFFUH01UYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P0000EJEP00FUIJEP00009JEP8000=JEP03001JEUYF00EJEP@000eoo`<0
00=JEPD000AJEP03001JEP00031oo`00;Goo0P001EYF00<005YFFUH00P0000=JEP0000001eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00P000UYF00@005YFFUH000EJ
EPL000=JEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP@0009JEP<000IJEP03001JEUYF00@000]oo`H000MJEP04001J
EUYFFUH20003FUH00`00FUH0000_Ool002eoo`03001JEP0000AJEPL000QJEP03001JEUYF009JEQ00
00AJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00EJEP80009JEP8000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP@0
009JEP8000MJEQ8000AJEP03001JEUYF00IJEP03001JEUYF00=JEP800005FUH005YFFUH0000^Ool0
02aoo`04001JEUYF0004FUH01000FUH000000UYF00<005YFFUH01EYF1`0025YF00<005YFFUH00P00
0UYF1@001EYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
15YF00L005YF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3
00001EYF000005YF00001EYF0P0015YF00<005YFFUH01UYF10001EYF00<005YFFUH01UYF00<005YF
FUH00eYF00@007oo0000009JEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP<000AJEP03001J
EUYF009JEP<000IJEP03001JEUYF00IJEP03001JEUYF008000=JEP04001JEUYFFUH20003FUH20002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH01000
FUIJEP000UYF0P001UYF00<005YFFUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol00Woo00<005YF0000;Woo000/Ool01000FUIJEP000UYF0P001UYF00<005YF00000`0025YF
0`001UYF00<005YFFUH00P000eYF00@005YFFUIJEP@00003FUH00000009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50003FUH30002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP06FUH01000FUH000001Goo00@005YF000002eoo`00
;7oo00H005YFFUIJEP00FUH20006FUH20003FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP030002
FUH01000FUH0000017oo0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00@0
05YFFUIJEP8000AJEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF001JEP03FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH0
0`00FUIJEP06FUH20008Ool3000]Ool002eoo`03001JEUYF00800003FUH005YF00=JEP8000EJEP03
001JEUYF00EJEPD000EJEP03001JEUYF00<00004FUH000000007Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH01P00FUH00000FUH000=JEP05001JEUYFFUH0000;FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP02FUH30003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH30006FUH00`00FUIJEP05FUH2000:Ool2000]Ool002eoo`04001JEP00
0003FUH00`00FUH000040004FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP0200000eYF001oo`09
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH20003FUH01000FUH00000
15YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00@0
05YFFUIJEP800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP80
00aoo`8002eoo`00;Goo0P001EYF0P001Goo2@0015YF0`000UYF1`0000Eoo`00FUIJEP0000Qoo`03
001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJEP<000EJEP8000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP<00003FUH005YF00@0
009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000ioo`8002eoo`00;Goo
0P0015YF00<007ooOol03Woo2@002Goo00<005YF00000P001Goo00@005YFFUH0009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP8000=JEP<00003
FUH005YF00@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH0015oo`8002eoo`00;Goo0P000eYF
00<007ooOol08Woo0P000UYF0P0000Aoo`000000009JEP04001JEUYF0005FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`000eYF00<005YFFUH00UYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YF
00003`005Woo00<005YF0000;Goo000]Ool01@00FUH005YF00009Woo0P000eYF1@0000EJEP00FUIJ
EP0000EJEP03001JEUYF00EJEPH000MJEP04001JEUYF000:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP05FUH01000FUIJEUYF0P0000EJEP00
001JEP0002Aoo`03001JEP0002eoo`00;Goo00<005YF00000P009goo00<005YFFUH00UYF00@005YF
FUIJEQ8000AJEP03001JEUYF00IJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEP800003FUH0000000<0009JEP03001JEUYF009JEP800004Ool00000000S
Ool3000^Ool002eoo`04001JEP00FUH3000TOol40002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUHE0006FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30003FUH00`00FUH000020004FUH01P00FUH00000FUH0025oo`800003FUH0000002ioo`00
;Goo00D005YF001JEP00009JEP03001oogoo01moo`800004FUH005YFFUH200000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30009FUH00`00FUIJEP09FUH<0005FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP02FUH20003FUH01@00FUH005YF0000
87oo00D005YFFUIJEP0002moo`00;Goo0`0000=JEP00FUH00UYF0P0077oo0`000eYF00<005YFFUH0
0UYF0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000`002eYF00<005YFFUH02UYF
00<005YFFUH025YF1`001UYF00<005YFFUH00eYF10000UYF00<005YF00000`0000Eoo`00001JEP00
009JEP8001moo`03001JEUYF009JEP03001oogoo02eoo`00;Goo0`0000=JEP00FUH015YF10004Woo
1P001UYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YFFUH00UYF1P000eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF
0`0000=JEP0000000P001goo0P000UYF00<005YF000077oo0`000eYF00<007ooOol0;Woo000]Ool3
0002FUH00`00FUIJEP02FUH01000FUIJEUYF4P0015YF00<005YFFUH01EYF00<005YFFUH01EYF0`00
00=JEP0000003@002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF0`0000=JEP00FUH015YF100000=JEP00Ool027oo00L005YF001JEP00FUH0000KOol01000FUIJ
EP000UYF00<007ooOol0;goo000]Ool400000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000015YF001JEUYF0P0000=JEP00FUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00@005YF000000EJEP800005Ool005YFFUH00007Ool01@00FUIJEP00FUH00`006Goo0P0015YF00<0
05YF0000<Goo000]Ool400000eYF001JEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00FUH00003FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P000eYF0P0000Aoo`00FUIJEP<000Aoo`03001JEUYF009JEP@001Moo`8000IJEP80039oo`00
;Goo0P0000AJEP00000000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJ
EP03001JEUYF00800004FUH005YFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF
00000002Ool00`00FUH00002FUH50005FUH2000EOol300000eYF001JEP05FUH00`00Oomoo`0aOol0
02ioo`03001JEUYF008000EJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00EJ
EP<000=JEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@0009oo`03001JEP00
00AJEP<000EJEP80019oo`<000AJEP03001JEUYF009JEP8003Aoo`00;Woo00<005YFFUH010000eYF
00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH015YF0P001EYF0P0000=ooeYF0000
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF000000=oo`8000EJEP03001JEP0000<00003
FUH0000000aoo`H000MJEP03001JEUYF008003Ioo`00;goo00<005YF00000UYF0`000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001UYF00<007ooOol00P00
15YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH000=oo`8000EJEP03001JEUYF00=JEPl0
00AJEP03001JEUYF00IJEP<003Qoo`00<7oo00<005YF00000eYF10001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000P000UYF00<005YFFUH00UYF0P0017oo00<005YFFUH00UYF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH015YF00D005YFFUH007oo00800004FUH000000003FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2000jOol0035oo`8000AJEP03001JEP00
00<000=JEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP04001JEUYF0007Ool20002FUH00`00
FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP0200000eYF001JEP06FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04000lOol0039oo`03001JEUYF009JEP03001JEUYF00=JEQ40
00=JEP03001JEUYF00IJEP<000Yoo`<000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000MJEP04001JEUYFFUH50004
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH50010Ool003=oo`8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000ioo`<000IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP<000QJ
EP03001JEUYF00AJEP/000AJEP03001JEUYF00@004Eoo`00=Goo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH0100057oo10000UYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF
FUH01UYF00<005YFFUH015YF00D005YFFUIJEP0000Ioo`L004Uoo`00=goo0`001UYF00<005YFFUH0
1EYF00<005YFFUH015YF1@0077oo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<007ooOol0
E7oo000jOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04000VOol60002FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP090005FUH00`00FUIJEP06FUH00`00FUIJEP03
0003FUH00`00Oomoo`1EOol003ioo`d0031oo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP0
00AJEPD000EJEP03001JEUYF00IJEP<0009JEP04001JEUYF001HOol008=ooaX000AJEP03001JEUYF
00EJEPD000EJEP03001JEUYF00EJEP<000AJEP03001JEP0005Qoo`00T7oo00<005YFFUH010000eYF
00<005YFFUH015YF00<005YFFUH01UYF0`001eYF00<005YFFUH00UYF0`001UYF0P00FGoo002AOol0
0`00FUH00002FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
0002FUH00`00FUIJEP03FUH2001JOol0099oo`8000AJEP@000IJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000EJEP04001JEUYFFUH2001LOol009=oo`03001JEUYF00=JEP03001JEUYF00@0009JEP03
001JEUYF00IJEP03001JEUYF00D000QJEP04001JEP00001NOol009Aoo`8000=JEP03001JEUYF00AJ
EPh000AJEP03001JEUYF00EJEP<0061oo`00UWoo0P0000=JEP00FUH01UYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00UYF0P00Hgoo002HOol30006FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH00002001UOol009]oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH006Qoo`00
Wgoo4000KWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]28\[InvisibleSpace]"     "\
\[InvisibleSpace]9.714617314885999`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 28, "     ", 9.7146173148859987, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59548 .76607 m .60134 .71145 L .57035 .70624 L p .707 .577 .707 r
F P
0 g
s
.60134 .71145 m .59548 .76607 L .62716 .76828 L p .707 .577 .707 r
F P
0 g
s
.62716 .76828 m .63302 .71366 L .60134 .71145 L p .707 .577 .707 r
F P
0 g
s
.63302 .71366 m .62716 .76828 L .65641 .76727 L p .707 .577 .707 r
F P
0 g
s
.65641 .76727 m .66228 .71265 L .63302 .71366 L p .707 .577 .707 r
F P
0 g
s
.56448 .76086 m .57035 .70624 L .54306 .69854 L p .707 .577 .707 r
F P
0 g
s
.57035 .70624 m .56448 .76086 L .59548 .76607 L p .707 .577 .707 r
F P
0 g
s
.66228 .71265 m .65641 .76727 L .68039 .76314 L p .707 .577 .707 r
F P
0 g
s
.68039 .76314 m .68625 .70852 L .66228 .71265 L p .707 .577 .707 r
F P
0 g
s
.5372 .75316 m .54306 .69854 L .52217 .6891 L p .707 .577 .707 r
F P
0 g
s
.54306 .69854 m .5372 .75316 L .56448 .76086 L p .707 .577 .707 r
F P
0 g
s
.58911 .83804 m .59498 .82117 L .56543 .80944 L p .707 .577 .707 r
F P
0 g
s
.58682 .81839 m .59819 .78448 L .56854 .77307 L p .707 .577 .707 r
F P
0 g
s
.59819 .78448 m .58682 .81839 L .61729 .82619 L p .707 .577 .707 r
F P
0 g
s
.61729 .82619 m .62865 .79228 L .59819 .78448 L p .707 .577 .707 r
F P
0 g
s
.55718 .80698 m .56854 .77307 L .5426 .75916 L p .707 .577 .707 r
F P
0 g
s
.55956 .82631 m .56543 .80944 L .56177 .80743 L p .707 .577 .707 r
F P
0 g
s
.56854 .77307 m .55718 .80698 L .56137 .80859 L p .707 .577 .707 r
F P
0 g
s
.57123 .77975 m .56854 .77307 L .56137 .80859 L .707 .577 .707 r
F
.5426 .75916 m .53124 .79307 L .55718 .80698 L p F P
0 g
s
.56177 .80743 m .53961 .79523 L p .55679 .82199 L .707 .577 .707 r
F P
0 g
s
.55956 .82631 m .56177 .80743 L .55679 .82199 L .707 .577 .707 r
F
.56543 .80944 m .55956 .82631 L .58911 .83804 L p F P
0 g
s
.56137 .80859 m .58682 .81839 L p .57123 .77975 L .707 .577 .707 r
F P
0 g
s
.62865 .79228 m .61729 .82619 L .64558 .82962 L p .707 .577 .707 r
F P
0 g
s
.64558 .82962 m .65694 .79571 L .62865 .79228 L p .707 .577 .707 r
F P
0 g
s
.59498 .82117 m .58911 .83804 L .61947 .84612 L p .707 .577 .707 r
F P
0 g
s
.61947 .84612 m .62534 .82926 L .59498 .82117 L p .707 .577 .707 r
F P
0 g
s
.68625 .70852 m .68039 .76314 L .69673 .7563 L p .707 .577 .707 r
F P
0 g
s
.69673 .7563 m .70259 .70168 L .68625 .70852 L p .707 .577 .707 r
F P
0 g
s
.52217 .6891 m .51631 .74372 L .52674 .74844 L p .707 .577 .707 r
F P
0 g
s
.52674 .74844 m .5372 .75316 L p .53328 .73646 L .707 .577 .707 r
F P
0 g
s
.53328 .73646 m .52217 .6891 L .52674 .74844 L .707 .577 .707 r
F
.51631 .74372 m .52217 .6891 L .5097 .67885 L p F P
0 g
s
.5097 .67885 m .50384 .73347 L .51108 .73942 L p .707 .577 .707 r
F P
0 g
s
.51108 .73942 m .51631 .74372 L p .51502 .73112 L .707 .577 .707 r
F P
0 g
s
.51502 .73112 m .5097 .67885 L .51108 .73942 L .707 .577 .707 r
F
.51142 .72943 m .50922 .71652 L p .50031 .76207 L F P
0 g
s
.50006 .76334 m .50091 .76081 L p .50031 .76207 L .707 .577 .707 r
F P
0 g
s
.50091 .76081 m .51142 .72943 L p .50031 .76207 L .707 .577 .707 r
F P
0 g
s
.52292 .74413 m .51142 .72943 L p .51155 .77624 L .707 .577 .707 r
F P
0 g
s
.51156 .77804 m .51312 .77336 L p .51155 .77624 L .707 .577 .707 r
F P
0 g
s
.51312 .77336 m .52292 .74413 L p .51155 .77624 L .707 .577 .707 r
F P
0 g
s
.53124 .79307 m .5426 .75916 L .52292 .74413 L p .707 .577 .707 r
F P
0 g
s
.62534 .82926 m .61947 .84612 L .64769 .84978 L p .707 .577 .707 r
F P
0 g
s
.64769 .84978 m .65356 .83291 L .62534 .82926 L p .707 .577 .707 r
F P
0 g
s
.65694 .79571 m .64558 .82962 L .66893 .82835 L p .707 .577 .707 r
F P
0 g
s
.66893 .82835 m .68029 .79444 L .65694 .79571 L p .707 .577 .707 r
F P
0 g
s
.53961 .79523 m .53374 .81209 L .55956 .82631 L p .707 .577 .707 r
F P
0 g
s
.52292 .74413 m .51156 .77804 L .53124 .79307 L p .707 .577 .707 r
F P
0 g
s
.53374 .81209 m .53961 .79523 L .52002 .77991 L p .707 .577 .707 r
F P
0 g
s
.65356 .83291 m .64769 .84978 L .67099 .84864 L p .707 .577 .707 r
F P
0 g
s
.67099 .84864 m .67686 .83178 L .65356 .83291 L p .707 .577 .707 r
F P
0 g
s
.52002 .77991 m .51415 .79678 L .53374 .81209 L p .707 .577 .707 r
F P
0 g
s
.68029 .79444 m .66893 .82835 L .68506 .82249 L p .707 .577 .707 r
F P
0 g
s
.68506 .82249 m .69642 .78858 L .68029 .79444 L p .707 .577 .707 r
F P
0 g
s
.70259 .70168 m .69673 .7563 L .70384 .74741 L p .707 .577 .707 r
F P
0 g
s
.70384 .74741 m .7097 .69279 L .70259 .70168 L p .707 .577 .707 r
F P
0 g
s
.51142 .72943 m .50006 .76334 L .51156 .77804 L p .707 .577 .707 r
F P
0 g
s
.51415 .79678 m .52002 .77991 L .5086 .76499 L p .707 .577 .707 r
F P
0 g
s
.50384 .73347 m .5097 .67885 L .50689 .66879 L p .707 .577 .707 r
F P
0 g
s
.67686 .83178 m .67099 .84864 L .6871 .84283 L p .707 .577 .707 r
F P
0 g
s
.6871 .84283 m .69297 .82597 L .67686 .83178 L p .707 .577 .707 r
F P
0 g
s
.5086 .76499 m .50272 .78186 L .51415 .79678 L p .707 .577 .707 r
F P
0 g
s
.50271 .72945 m .50384 .73347 L p .50438 .72207 L .707 .577 .707 r
F P
0 g
s
.50922 .71652 m .49786 .75043 L .50006 .76334 L p .707 .577 .707 r
F P
0 g
s
.50922 .71652 m .51654 .70665 L p .49813 .7498 L .707 .577 .707 r
F P
0 g
s
.49786 .75043 m .49825 .74927 L p .49813 .7498 L .707 .577 .707 r
F P
0 g
s
.49825 .74927 m .50922 .71652 L p .49813 .7498 L .707 .577 .707 r
F P
0 g
s
.50689 .66879 m .50102 .72341 L .50271 .72945 L p .707 .577 .707 r
F P
0 g
s
.50438 .72207 m .50689 .66879 L .50271 .72945 L .707 .577 .707 r
F
.69642 .78858 m .68506 .82249 L .69238 .81261 L p F P
0 g
s
.69238 .81261 m .70374 .7787 L .69642 .78858 L p .707 .577 .707 r
F P
0 g
s
.7097 .69279 m .70384 .74741 L .70102 .73735 L p .707 .577 .707 r
F P
0 g
s
.70102 .73735 m .70688 .68273 L .7097 .69279 L p .707 .577 .707 r
F P
0 g
s
.50272 .78186 m .5086 .76499 L .50645 .75193 L p .707 .577 .707 r
F P
0 g
s
.50645 .75193 m .50058 .7688 L .50272 .78186 L p .707 .577 .707 r
F P
0 g
s
.50058 .7688 m .50645 .75193 L .51379 .74201 L p .707 .577 .707 r
F P
0 g
s
.51654 .70665 m .50541 .73987 L p .49786 .75043 L .707 .577 .707 r
F P
0 g
s
.50541 .73987 m .50518 .74056 L .50506 .74072 L p .707 .577 .707 r
F P
0 g
s
.50506 .74072 m .49786 .75043 L p .50541 .73987 L .707 .577 .707 r
F P
0 g
s
.53034 .65305 m .52648 .68898 L p .50813 .71452 L .707 .577 .707 r
F P
0 g
s
.50518 .74056 m .51654 .70665 L .53267 .70079 L p .707 .577 .707 r
F P
0 g
s
.52648 .68898 m .52448 .70767 L .51754 .71058 L p .707 .577 .707 r
F P
0 g
s
.51754 .71058 m .50813 .71452 L p .52648 .68898 L .707 .577 .707 r
F P
0 g
s
.51379 .74201 m .50792 .75888 L .50058 .7688 L p .707 .577 .707 r
F P
0 g
s
.50365 .82181 m .48872 .31856 L .44473 .3172 L p .707 .577 .707 r
F P
0 g
s
.50102 .72341 m .50689 .66879 L .514 .6599 L p .707 .577 .707 r
F P
0 g
s
.514 .6599 m .50813 .71452 L .50102 .72341 L p .707 .577 .707 r
F P
0 g
s
.50813 .71452 m .514 .6599 L .53034 .65305 L p .707 .577 .707 r
F P
0 g
s
.50792 .75888 m .51379 .74201 L .5299 .7362 L p .707 .577 .707 r
F P
0 g
s
.53267 .70079 m .5217 .73354 L p .50518 .74056 L .707 .577 .707 r
F P
0 g
s
.5217 .73354 m .52131 .7347 L .52091 .73484 L p .707 .577 .707 r
F P
0 g
s
.52091 .73484 m .50518 .74056 L p .5217 .73354 L .707 .577 .707 r
F P
0 g
s
.52131 .7347 m .53267 .70079 L .55603 .69951 L p .707 .577 .707 r
F P
0 g
s
.55431 .64893 m .5503 .68632 L p .52448 .70767 L .707 .577 .707 r
F P
0 g
s
.5503 .68632 m .54845 .70354 L .53887 .70519 L p .707 .577 .707 r
F P
0 g
s
.53887 .70519 m .52448 .70767 L p .5503 .68632 L .707 .577 .707 r
F P
0 g
s
.52448 .70767 m .53034 .65305 L .55431 .64893 L p .707 .577 .707 r
F P
0 g
s
.5299 .7362 m .52403 .75307 L .50792 .75888 L p .707 .577 .707 r
F P
0 g
s
.52403 .75307 m .5299 .7362 L .5532 .73507 L p .707 .577 .707 r
F P
0 g
s
.55603 .69951 m .54551 .73089 L p .52131 .7347 L .707 .577 .707 r
F P
0 g
s
.54551 .73089 m .54466 .73342 L .54367 .73348 L p .707 .577 .707 r
F P
0 g
s
.54367 .73348 m .52131 .7347 L p .54551 .73089 L .707 .577 .707 r
F P
0 g
s
.58357 .64792 m .57982 .68278 L p .54845 .70354 L .707 .577 .707 r
F P
0 g
s
.54466 .73342 m .55603 .69951 L .58432 .70294 L p .707 .577 .707 r
F P
0 g
s
.57982 .68278 m .5777 .70253 L .56543 .70296 L p .707 .577 .707 r
F P
0 g
s
.56543 .70296 m .54845 .70354 L p .57982 .68278 L .707 .577 .707 r
F P
0 g
s
.5532 .73507 m .54733 .75193 L .52403 .75307 L p .707 .577 .707 r
F P
0 g
s
.48872 .31856 m .50365 .82181 L .54857 .81952 L p .707 .577 .707 r
F P
0 g
s
.58432 .70294 m .57784 .72227 L p .54466 .73342 L .707 .577 .707 r
F P
0 g
s
.57784 .72227 m .57296 .73685 L .56594 .736 L p .707 .577 .707 r
F P
0 g
s
.56594 .736 m .54466 .73342 L p .57784 .72227 L .707 .577 .707 r
F P
0 g
s
.53364 .31626 m .48872 .31856 L p .54191 .76374 L .707 .577 .707 r
F P
0 g
s
.54857 .81952 m .54675 .75815 L p .54191 .76374 L .707 .577 .707 r
F P
0 g
s
.54675 .75815 m .53364 .31626 L p .54191 .76374 L .707 .577 .707 r
F P
0 g
s
.69297 .82597 m .6871 .84283 L .69444 .83291 L p .707 .577 .707 r
F P
0 g
s
.69444 .83291 m .70031 .81605 L .69297 .82597 L p .707 .577 .707 r
F P
0 g
s
.54845 .70354 m .55431 .64893 L .58357 .64792 L p .707 .577 .707 r
F P
0 g
s
.54733 .75193 m .5532 .73507 L .58142 .73872 L p .707 .577 .707 r
F P
0 g
s
.58432 .70294 m .61478 .71074 L p .57311 .73676 L .707 .577 .707 r
F P
0 g
s
.57296 .73685 m .57306 .73655 L p .57311 .73676 L .707 .577 .707 r
F P
0 g
s
.57306 .73655 m .58432 .70294 L p .57311 .73676 L .707 .577 .707 r
F P
0 g
s
.64624 .65533 m .64038 .70995 L .60938 .70474 L p .707 .577 .707 r
F P
0 g
s
.60938 .70474 m .61524 .65012 L .64624 .65533 L p .707 .577 .707 r
F P
0 g
s
.5777 .70253 m .58357 .64792 L .61524 .65012 L p .707 .577 .707 r
F P
0 g
s
.61524 .65012 m .60938 .70474 L .5777 .70253 L p .707 .577 .707 r
F P
0 g
s
.57555 .75559 m .58142 .73872 L .61178 .74681 L p .707 .577 .707 r
F P
0 g
s
.60591 .76368 m .61178 .74681 L .63714 .75687 L p .707 .577 .707 r
F P
0 g
s
.67036 .73606 m .659 .76997 L .63674 .75804 L p .707 .577 .707 r
F P
0 g
s
.63839 .75322 m .67036 .73606 L .63674 .75804 L .707 .577 .707 r
F
.63714 .75687 m .64133 .75853 L p .63632 .75926 L F P
0 g
s
.60591 .76368 m .63714 .75687 L .63632 .75926 L .707 .577 .707 r
F
.63674 .75804 m .63307 .75607 L p .63839 .75322 L F P
0 g
s
.61178 .74681 m .60591 .76368 L .57555 .75559 L p .707 .577 .707 r
F P
0 g
s
.64443 .72216 m .63307 .75607 L .60342 .74466 L p .707 .577 .707 r
F P
0 g
s
.60342 .74466 m .61478 .71074 L .64443 .72216 L p .707 .577 .707 r
F P
0 g
s
.58142 .73872 m .57555 .75559 L .54733 .75193 L p .707 .577 .707 r
F P
0 g
s
.61478 .71074 m .60342 .74466 L .57296 .73685 L p .707 .577 .707 r
F P
0 g
s
.64133 .75853 m .63546 .7754 L .60591 .76368 L p .707 .577 .707 r
F P
0 g
s
.57511 .31054 m .58975 .8042 L p .62399 .80521 L .707 .577 .707 r
F P
0 g
s
.58975 .8042 m .59004 .8138 L .592 .8133 L p .707 .577 .707 r
F P
0 g
s
.592 .8133 m .62399 .80521 L p .58975 .8042 L .707 .577 .707 r
F P
0 g
s
.53364 .31626 m .54857 .81952 L .59004 .8138 L p .707 .577 .707 r
F P
0 g
s
.59004 .8138 m .57511 .31054 L .53364 .31626 L p .707 .577 .707 r
F P
0 g
s
.45966 .82045 m .44473 .3172 L .40598 .31233 L p .707 .577 .707 r
F P
0 g
s
.44473 .3172 m .45966 .82045 L .50365 .82181 L p .707 .577 .707 r
F P
0 g
s
.62399 .80521 m .60906 .30196 L .57511 .31054 L p .707 .577 .707 r
F P
0 g
s
.70374 .7787 m .69238 .81261 L .69019 .7997 L p .707 .577 .707 r
F P
0 g
s
.69019 .7997 m .70155 .76579 L .70374 .7787 L p .707 .577 .707 r
F P
0 g
s
.70688 .68273 m .70102 .73735 L .68856 .72709 L p .707 .577 .707 r
F P
0 g
s
.68856 .72709 m .69442 .67247 L .70688 .68273 L p .707 .577 .707 r
F P
0 g
s
.25247 .70229 m .25833 .64767 L .22734 .64246 L p .707 .577 .707 r
F P
0 g
s
.25833 .64767 m .25247 .70229 L .28415 .7045 L p .707 .577 .707 r
F P
0 g
s
.28415 .7045 m .29001 .64988 L .25833 .64767 L p .707 .577 .707 r
F P
0 g
s
.29001 .64988 m .28415 .7045 L .31341 .70349 L p .707 .577 .707 r
F P
0 g
s
.31341 .70349 m .31927 .64887 L .29001 .64988 L p .707 .577 .707 r
F P
0 g
s
.22148 .69708 m .22734 .64246 L .20006 .63476 L p .707 .577 .707 r
F P
0 g
s
.22734 .64246 m .22148 .69708 L .25247 .70229 L p .707 .577 .707 r
F P
0 g
s
.42091 .81558 m .40598 .31233 L .37628 .30442 L p .707 .577 .707 r
F P
0 g
s
.40598 .31233 m .42091 .81558 L .45966 .82045 L p .707 .577 .707 r
F P
0 g
s
.70031 .81605 m .69444 .83291 L .6923 .81985 L p .707 .577 .707 r
F P
0 g
s
.6923 .81985 m .69817 .80299 L .70031 .81605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31927 .64887 m .31341 .70349 L .33738 .69936 L p .707 .577 .707 r
F P
0 g
s
.33738 .69936 m .34324 .64474 L .31927 .64887 L p .707 .577 .707 r
F P
0 g
s
.19419 .68938 m .20006 .63476 L .17916 .62532 L p .707 .577 .707 r
F P
0 g
s
.20006 .63476 m .19419 .68938 L .22148 .69708 L p .707 .577 .707 r
F P
0 g
s
.67352 .66303 m .66766 .71765 L .64038 .70995 L p .707 .577 .707 r
F P
0 g
s
.64038 .70995 m .64624 .65533 L .67352 .66303 L p .707 .577 .707 r
F P
0 g
s
.63307 .75607 m .64443 .72216 L .67036 .73606 L p .707 .577 .707 r
F P
0 g
s
.69005 .7511 m .67869 .78501 L .659 .76997 L p .707 .577 .707 r
F P
0 g
s
.66716 .77275 m .66128 .78962 L .63546 .7754 L p .707 .577 .707 r
F P
0 g
s
.659 .76997 m .67036 .73606 L .69005 .7511 L p .707 .577 .707 r
F P
0 g
s
.63546 .7754 m .64133 .75853 L .66716 .77275 L p .707 .577 .707 r
F P
0 g
s
.60906 .30196 m .62399 .80521 L .64709 .7946 L p .707 .577 .707 r
F P
0 g
s
.64709 .7946 m .63216 .29135 L .60906 .30196 L p .707 .577 .707 r
F P
0 g
s
.70155 .76579 m .69019 .7997 L .67869 .78501 L p .707 .577 .707 r
F P
0 g
s
.67869 .78501 m .69005 .7511 L .70155 .76579 L p .707 .577 .707 r
F P
0 g
s
.69442 .67247 m .68856 .72709 L .66766 .71765 L p .707 .577 .707 r
F P
0 g
s
.66766 .71765 m .67352 .66303 L .69442 .67247 L p .707 .577 .707 r
F P
0 g
s
.24382 .77994 m .25518 .74603 L .22553 .73462 L p .707 .577 .707 r
F P
0 g
s
.25518 .74603 m .24382 .77994 L .27428 .78774 L p .707 .577 .707 r
F P
0 g
s
.27428 .78774 m .28564 .75383 L .25518 .74603 L p .707 .577 .707 r
F P
0 g
s
.21417 .76853 m .22553 .73462 L .19959 .72071 L p .707 .577 .707 r
F P
0 g
s
.22553 .73462 m .21417 .76853 L .24382 .77994 L p .707 .577 .707 r
F P
0 g
s
.28564 .75383 m .27428 .78774 L .30257 .79117 L p .707 .577 .707 r
F P
0 g
s
.30257 .79117 m .31393 .75726 L .28564 .75383 L p .707 .577 .707 r
F P
0 g
s
.69817 .80299 m .6923 .81985 L .68087 .80494 L p .707 .577 .707 r
F P
0 g
s
.68087 .80494 m .68674 .78807 L .69817 .80299 L p .707 .577 .707 r
F P
0 g
s
.34324 .64474 m .33738 .69936 L .35372 .69251 L p .707 .577 .707 r
F P
0 g
s
.35372 .69251 m .35958 .63789 L .34324 .64474 L p .707 .577 .707 r
F P
0 g
s
.17916 .62532 m .1733 .67994 L .19419 .68938 L p .707 .577 .707 r
F P
0 g
s
.39121 .80767 m .37628 .30442 L .35851 .29424 L p .707 .577 .707 r
F P
0 g
s
.37628 .30442 m .39121 .80767 L .42091 .81558 L p .707 .577 .707 r
F P
0 g
s
.1733 .67994 m .17916 .62532 L .16669 .61506 L p .707 .577 .707 r
F P
0 g
s
.18823 .75462 m .19959 .72071 L .17991 .70568 L p .707 .577 .707 r
F P
0 g
s
.19959 .72071 m .18823 .75462 L .21417 .76853 L p .707 .577 .707 r
F P
0 g
s
.31393 .75726 m .30257 .79117 L .32592 .7899 L p .707 .577 .707 r
F P
0 g
s
.32592 .7899 m .33728 .75599 L .31393 .75726 L p .707 .577 .707 r
F P
0 g
s
.2461 .846 m .25197 .82913 L .22243 .8174 L p .707 .577 .707 r
F P
0 g
s
.25197 .82913 m .2461 .846 L .27646 .85408 L p .707 .577 .707 r
F P
0 g
s
.27646 .85408 m .28233 .83722 L .25197 .82913 L p .707 .577 .707 r
F P
0 g
s
.21655 .83427 m .22243 .8174 L .1966 .80319 L p .707 .577 .707 r
F P
0 g
s
.22243 .8174 m .21655 .83427 L .2461 .846 L p .707 .577 .707 r
F P
0 g
s
.17991 .70568 m .16855 .73959 L .18823 .75462 L p .707 .577 .707 r
F P
0 g
s
.28233 .83722 m .27646 .85408 L .30468 .85774 L p .707 .577 .707 r
F P
0 g
s
.30468 .85774 m .31055 .84087 L .28233 .83722 L p .707 .577 .707 r
F P
0 g
s
.16669 .61506 m .16083 .66968 L .1733 .67994 L p .707 .577 .707 r
F P
0 g
s
.63216 .29135 m .64709 .7946 L .6571 .783 L p .707 .577 .707 r
F P
0 g
s
.6571 .783 m .64217 .27975 L .63216 .29135 L p .707 .577 .707 r
F P
0 g
s
.68674 .78807 m .68087 .80494 L .66128 .78962 L p .707 .577 .707 r
F P
0 g
s
.66128 .78962 m .66716 .77275 L .68674 .78807 L p .707 .577 .707 r
F P
0 g
s
.1966 .80319 m .19073 .82005 L .21655 .83427 L p .707 .577 .707 r
F P
0 g
s
.35958 .63789 m .35372 .69251 L .36083 .68363 L p .707 .577 .707 r
F P
0 g
s
.36083 .68363 m .36669 .62901 L .35958 .63789 L p .707 .577 .707 r
F P
0 g
s
.16855 .73959 m .17991 .70568 L .16841 .69098 L p .707 .577 .707 r
F P
0 g
s
.19073 .82005 m .1966 .80319 L .17701 .78787 L p .707 .577 .707 r
F P
0 g
s
.16083 .66968 m .16669 .61506 L .16388 .605 L p .707 .577 .707 r
F P
0 g
s
.33728 .75599 m .32592 .7899 L .34205 .78404 L p .707 .577 .707 r
F P
0 g
s
.34205 .78404 m .35341 .75012 L .33728 .75599 L p .707 .577 .707 r
F P
0 g
s
.31055 .84087 m .30468 .85774 L .32798 .8566 L p .707 .577 .707 r
F P
0 g
s
.32798 .8566 m .33385 .83974 L .31055 .84087 L p .707 .577 .707 r
F P
0 g
s
.17701 .78787 m .17114 .80474 L .19073 .82005 L p .707 .577 .707 r
F P
0 g
s
.16841 .69098 m .15705 .72489 L .16855 .73959 L p .707 .577 .707 r
F P
0 g
s
.37344 .79749 m .35851 .29424 L .35443 .28279 L p .707 .577 .707 r
F P
0 g
s
.35851 .29424 m .37344 .79749 L .39121 .80767 L p .707 .577 .707 r
F P
0 g
s
.16388 .605 m .15801 .65962 L .16083 .66968 L p .707 .577 .707 r
F P
0 g
s
.17114 .80474 m .17701 .78787 L .16559 .77295 L p .707 .577 .707 r
F P
0 g
s
.15705 .72489 m .16841 .69098 L .16621 .67807 L p .707 .577 .707 r
F P
0 g
s
.36669 .62901 m .36083 .68363 L .35801 .67356 L p .707 .577 .707 r
F P
0 g
s
.35801 .67356 m .36388 .61894 L .36669 .62901 L p .707 .577 .707 r
F P
0 g
s
.33385 .83974 m .32798 .8566 L .34409 .85079 L p .707 .577 .707 r
F P
0 g
s
.34409 .85079 m .34996 .83393 L .33385 .83974 L p .707 .577 .707 r
F P
0 g
s
.16559 .77295 m .15972 .78982 L .17114 .80474 L p .707 .577 .707 r
F P
0 g
s
.35341 .75012 m .34205 .78404 L .34937 .77416 L p .707 .577 .707 r
F P
0 g
s
.34937 .77416 m .36074 .74025 L .35341 .75012 L p .707 .577 .707 r
F P
0 g
s
.15801 .65962 m .16388 .605 L .17099 .59611 L p .707 .577 .707 r
F P
0 g
s
.64217 .27975 m .6571 .783 L .65692 .7825 L p .707 .577 .707 r
F P
0 g
s
.65692 .7825 m .65325 .77221 L p .65221 .72593 L .707 .577 .707 r
F P
0 g
s
.65221 .72593 m .64217 .27975 L .65692 .7825 L .707 .577 .707 r
F
.65286 .7645 m .65277 .76031 L .65325 .77221 L F
.65239 .74315 m .64217 .27975 L .65267 .74651 L F
.65302 .77155 m .63809 .2683 L .64217 .27975 L p F P
0 g
s
.63809 .2683 m .65302 .77155 L .63525 .76137 L p .707 .577 .707 r
F P
0 g
s
.64691 .58681 m .64449 .60928 L p .65351 .65168 L .707 .577 .707 r
F P
0 g
s
.6465 .64592 m .65351 .65168 L p .64449 .60928 L .707 .577 .707 r
F P
0 g
s
.65937 .59706 m .65351 .65168 L .66395 .6564 L p .707 .577 .707 r
F P
0 g
s
.65351 .65168 m .65937 .59706 L .64691 .58681 L p .707 .577 .707 r
F P
0 g
s
.66012 .65209 m .64862 .6374 L p .64876 .6842 L .707 .577 .707 r
F P
0 g
s
.64876 .68443 m .64899 .68378 L .64876 .6842 L .707 .577 .707 r
F
.64899 .68378 m .66012 .65209 L .64876 .6842 L F
.66395 .6564 m .67441 .66112 L p .67049 .64442 L F P
0 g
s
.67049 .64442 m .65937 .59706 L .66395 .6564 L .707 .577 .707 r
F
.64876 .686 m .64886 .6857 L p .64876 .68443 L F P
0 g
s
.64886 .6857 m .66012 .65209 L p .64876 .68443 L .707 .577 .707 r
F P
0 g
s
.66012 .65209 m .64886 .6857 L p .66844 .70104 L .707 .577 .707 r
F P
0 g
s
.64886 .6857 m .64876 .686 L .64888 .68609 L p .707 .577 .707 r
F P
0 g
s
.64888 .68609 m .66844 .70104 L p .64886 .6857 L .707 .577 .707 r
F P
0 g
s
.64449 .60928 m .64104 .64143 L .6465 .64592 L p .707 .577 .707 r
F P
0 g
s
.64862 .6374 m .63726 .67131 L .64876 .686 L p .707 .577 .707 r
F P
0 g
s
.65135 .70474 m .65723 .68787 L .64655 .67393 L p .707 .577 .707 r
F P
0 g
s
.64655 .67393 m .6458 .67295 L p .64709 .68033 L .707 .577 .707 r
F P
0 g
s
.65135 .70474 m .64655 .67393 L .64709 .68033 L .707 .577 .707 r
F
.65277 .76031 m .65239 .74315 L .65313 .767 L F
.65239 .74315 m .65267 .74651 L .65313 .767 L F
.65277 .76031 m .65313 .767 L .65325 .77221 L F
.65325 .77221 m .65302 .77155 L p .65286 .7645 L F P
0 g
s
.16621 .67807 m .15485 .71198 L .15705 .72489 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15972 .78982 m .16559 .77295 L .16344 .75989 L p .707 .577 .707 r
F P
0 g
s
.17099 .59611 m .16513 .65073 L .15801 .65962 L p .707 .577 .707 r
F P
0 g
s
.15485 .71198 m .16621 .67807 L .17354 .6682 L p .707 .577 .707 r
F P
0 g
s
.16344 .75989 m .15757 .77676 L .15972 .78982 L p .707 .577 .707 r
F P
0 g
s
.34996 .83393 m .34409 .85079 L .35143 .84087 L p .707 .577 .707 r
F P
0 g
s
.35143 .84087 m .3573 .82401 L .34996 .83393 L p .707 .577 .707 r
F P
0 g
s
.35443 .28279 m .36936 .78604 L .37344 .79749 L p .707 .577 .707 r
F P
0 g
s
.36936 .78604 m .35443 .28279 L .36443 .27119 L p .707 .577 .707 r
F P
0 g
s
.36388 .61894 m .35801 .67356 L .34555 .66331 L p .707 .577 .707 r
F P
0 g
s
.34555 .66331 m .35141 .60869 L .36388 .61894 L p .707 .577 .707 r
F P
0 g
s
.36074 .74025 m .34937 .77416 L .34718 .76125 L p .707 .577 .707 r
F P
0 g
s
.34718 .76125 m .35854 .72734 L .36074 .74025 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16513 .65073 m .17099 .59611 L .18733 .58927 L p .707 .577 .707 r
F P
0 g
s
.17354 .6682 m .16217 .70211 L .15485 .71198 L p .707 .577 .707 r
F P
0 g
s
.15757 .77676 m .16344 .75989 L .17078 .74997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63525 .76137 m .62032 .25812 L .63809 .2683 L p .707 .577 .707 r
F P
0 g
s
.18733 .58927 m .18147 .64389 L .16513 .65073 L p .707 .577 .707 r
F P
0 g
s
.16217 .70211 m .17354 .6682 L .18966 .66234 L p .707 .577 .707 r
F P
0 g
s
.17078 .74997 m .16491 .76684 L .15757 .77676 L p .707 .577 .707 r
F P
0 g
s
.35141 .60869 m .34555 .66331 L .32465 .65387 L p .707 .577 .707 r
F P
0 g
s
.32465 .65387 m .33051 .59925 L .35141 .60869 L p .707 .577 .707 r
F P
0 g
s
.3573 .82401 m .35143 .84087 L .34929 .82781 L p .707 .577 .707 r
F P
0 g
s
.34929 .82781 m .35516 .81095 L .3573 .82401 L p .707 .577 .707 r
F P
0 g
s
.35854 .72734 m .34718 .76125 L .33568 .74656 L p .707 .577 .707 r
F P
0 g
s
.33568 .74656 m .34704 .71265 L .35854 .72734 L p .707 .577 .707 r
F P
0 g
s
.18147 .64389 m .18733 .58927 L .2113 .58514 L p .707 .577 .707 r
F P
0 g
s
.18966 .66234 m .1783 .69625 L .16217 .70211 L p .707 .577 .707 r
F P
0 g
s
.37936 .77444 m .36443 .27119 L .38754 .26058 L p .707 .577 .707 r
F P
0 g
s
.36443 .27119 m .37936 .77444 L .36936 .78604 L p .707 .577 .707 r
F P
0 g
s
.16491 .76684 m .17078 .74997 L .18689 .74416 L p .707 .577 .707 r
F P
0 g
s
.33051 .59925 m .32465 .65387 L .29737 .64617 L p .707 .577 .707 r
F P
0 g
s
.29737 .64617 m .30323 .59155 L .33051 .59925 L p .707 .577 .707 r
F P
0 g
s
.2113 .58514 m .20544 .63976 L .18147 .64389 L p .707 .577 .707 r
F P
0 g
s
.1783 .69625 m .18966 .66234 L .21302 .66106 L p .707 .577 .707 r
F P
0 g
s
.20544 .63976 m .2113 .58514 L .24056 .58413 L p .707 .577 .707 r
F P
0 g
s
.18689 .74416 m .18102 .76103 L .16491 .76684 L p .707 .577 .707 r
F P
0 g
s
.35516 .81095 m .34929 .82781 L .33786 .8129 L p .707 .577 .707 r
F P
0 g
s
.33786 .8129 m .34373 .79603 L .35516 .81095 L p .707 .577 .707 r
F P
0 g
s
.34704 .71265 m .33568 .74656 L .31599 .73152 L p .707 .577 .707 r
F P
0 g
s
.31599 .73152 m .32735 .69761 L .34704 .71265 L p .707 .577 .707 r
F P
0 g
s
.62032 .25812 m .63525 .76137 L .60555 .75346 L p .707 .577 .707 r
F P
0 g
s
.60555 .75346 m .59061 .2502 L .62032 .25812 L p .707 .577 .707 r
F P
0 g
s
.30323 .59155 m .29737 .64617 L .26637 .64096 L p .707 .577 .707 r
F P
0 g
s
.26637 .64096 m .27223 .58634 L .30323 .59155 L p .707 .577 .707 r
F P
0 g
s
.21302 .66106 m .20166 .69497 L .1783 .69625 L p .707 .577 .707 r
F P
0 g
s
.23469 .63875 m .24056 .58413 L .27223 .58634 L p .707 .577 .707 r
F P
0 g
s
.24056 .58413 m .23469 .63875 L .20544 .63976 L p .707 .577 .707 r
F P
0 g
s
.27223 .58634 m .26637 .64096 L .23469 .63875 L p .707 .577 .707 r
F P
0 g
s
.20166 .69497 m .21302 .66106 L .24131 .66449 L p .707 .577 .707 r
F P
0 g
s
.18102 .76103 m .18689 .74416 L .21019 .74303 L p .707 .577 .707 r
F P
0 g
s
.32735 .69761 m .31599 .73152 L .29006 .71762 L p .707 .577 .707 r
F P
0 g
s
.29006 .71762 m .30142 .68371 L .32735 .69761 L p .707 .577 .707 r
F P
0 g
s
.38754 .26058 m .40247 .76383 L .37936 .77444 L p .707 .577 .707 r
F P
0 g
s
.40247 .76383 m .38754 .26058 L .42149 .25199 L p .707 .577 .707 r
F P
0 g
s
.73269 .67403 m .73855 .61941 L .70755 .6142 L p .707 .577 .707 r
F P
0 g
s
.73855 .61941 m .73269 .67403 L .76436 .67624 L p .707 .577 .707 r
F P
0 g
s
.76436 .67624 m .77022 .62162 L .73855 .61941 L p .707 .577 .707 r
F P
0 g
s
.34373 .79603 m .33786 .8129 L .31828 .79758 L p .707 .577 .707 r
F P
0 g
s
.31828 .79758 m .32415 .78071 L .34373 .79603 L p .707 .577 .707 r
F P
0 g
s
.21019 .74303 m .20432 .75989 L .18102 .76103 L p .707 .577 .707 r
F P
0 g
s
.77022 .62162 m .76436 .67624 L .79362 .67523 L p .707 .577 .707 r
F P
0 g
s
.79362 .67523 m .79948 .62061 L .77022 .62162 L p .707 .577 .707 r
F P
0 g
s
.70169 .66882 m .70755 .6142 L .68027 .6065 L p .707 .577 .707 r
F P
0 g
s
.70755 .6142 m .70169 .66882 L .73269 .67403 L p .707 .577 .707 r
F P
0 g
s
.24131 .66449 m .22995 .6984 L .20166 .69497 L p .707 .577 .707 r
F P
0 g
s
.22995 .6984 m .24131 .66449 L .27177 .67229 L p .707 .577 .707 r
F P
0 g
s
.30142 .68371 m .29006 .71762 L .26041 .7062 L p .707 .577 .707 r
F P
0 g
s
.26041 .7062 m .27177 .67229 L .30142 .68371 L p .707 .577 .707 r
F P
0 g
s
.27177 .67229 m .26041 .7062 L .22995 .6984 L p .707 .577 .707 r
F P
0 g
s
.59061 .2502 m .60555 .75346 L .5668 .74858 L p .707 .577 .707 r
F P
0 g
s
.5668 .74858 m .55187 .24533 L .59061 .2502 L p .707 .577 .707 r
F P
0 g
s
.79948 .62061 m .79362 .67523 L .81759 .6711 L p .707 .577 .707 r
F P
0 g
s
.81759 .6711 m .82345 .61648 L .79948 .62061 L p .707 .577 .707 r
F P
0 g
s
.20432 .75989 m .21019 .74303 L .23841 .74668 L p .707 .577 .707 r
F P
0 g
s
.67441 .66112 m .68027 .6065 L .65937 .59706 L p .707 .577 .707 r
F P
0 g
s
.68027 .6065 m .67441 .66112 L .70169 .66882 L p .707 .577 .707 r
F P
0 g
s
.32415 .78071 m .31828 .79758 L .29245 .78336 L p .707 .577 .707 r
F P
0 g
s
.29245 .78336 m .29832 .76649 L .32415 .78071 L p .707 .577 .707 r
F P
0 g
s
.72631 .746 m .73218 .72913 L .70264 .71741 L p .707 .577 .707 r
F P
0 g
s
.72403 .72635 m .73539 .69244 L .70574 .68103 L p .707 .577 .707 r
F P
0 g
s
.73539 .69244 m .72403 .72635 L .75449 .73416 L p .707 .577 .707 r
F P
0 g
s
.75449 .73416 m .76585 .70024 L .73539 .69244 L p .707 .577 .707 r
F P
0 g
s
.23841 .74668 m .23254 .76355 L .20432 .75989 L p .707 .577 .707 r
F P
0 g
s
.69438 .71494 m .70574 .68103 L .67981 .66712 L p .707 .577 .707 r
F P
0 g
s
.69677 .73427 m .70264 .71741 L .69898 .71539 L p .707 .577 .707 r
F P
0 g
s
.70574 .68103 m .69438 .71494 L .69858 .71656 L p .707 .577 .707 r
F P
0 g
s
.70844 .68771 m .70574 .68103 L .69858 .71656 L .707 .577 .707 r
F
.67981 .66712 m .66844 .70104 L .69438 .71494 L p F P
0 g
s
.69898 .71539 m .67681 .70319 L p .694 .72996 L .707 .577 .707 r
F P
0 g
s
.69677 .73427 m .69898 .71539 L .694 .72996 L .707 .577 .707 r
F
.70264 .71741 m .69677 .73427 L .72631 .746 L p F P
0 g
s
.69858 .71656 m .72403 .72635 L p .70844 .68771 L .707 .577 .707 r
F P
0 g
s
.43642 .75524 m .42149 .25199 L .46296 .24627 L p .707 .577 .707 r
F P
0 g
s
.42149 .25199 m .43642 .75524 L .40247 .76383 L p .707 .577 .707 r
F P
0 g
s
.76585 .70024 m .75449 .73416 L .78278 .73759 L p .707 .577 .707 r
F P
0 g
s
.78278 .73759 m .79414 .70368 L .76585 .70024 L p .707 .577 .707 r
F P
0 g
s
.23254 .76355 m .23841 .74668 L .26878 .75477 L p .707 .577 .707 r
F P
0 g
s
.73218 .72913 m .72631 .746 L .75668 .75409 L p .707 .577 .707 r
F P
0 g
s
.75668 .75409 m .76255 .73722 L .73218 .72913 L p .707 .577 .707 r
F P
0 g
s
.29832 .76649 m .29245 .78336 L .2629 .77164 L p .707 .577 .707 r
F P
0 g
s
.2629 .77164 m .26878 .75477 L .29832 .76649 L p .707 .577 .707 r
F P
0 g
s
.55187 .24533 m .5668 .74858 L .52281 .74723 L p .707 .577 .707 r
F P
0 g
s
.52281 .74723 m .50788 .24397 L .55187 .24533 L p .707 .577 .707 r
F P
0 g
s
.26878 .75477 m .2629 .77164 L .23254 .76355 L p .707 .577 .707 r
F P
0 g
s
.82345 .61648 m .81759 .6711 L .83393 .66426 L p .707 .577 .707 r
F P
0 g
s
.83393 .66426 m .83979 .60964 L .82345 .61648 L p .707 .577 .707 r
F P
0 g
s
.66844 .70104 m .67981 .66712 L .66012 .65209 L p .707 .577 .707 r
F P
0 g
s
.76255 .73722 m .75668 .75409 L .78489 .75774 L p .707 .577 .707 r
F P
0 g
s
.78489 .75774 m .79076 .74087 L .76255 .73722 L p .707 .577 .707 r
F P
0 g
s
.79414 .70368 m .78278 .73759 L .80614 .73631 L p .707 .577 .707 r
F P
0 g
s
.80614 .73631 m .8175 .7024 L .79414 .70368 L p .707 .577 .707 r
F P
0 g
s
.47789 .74952 m .46296 .24627 L .50788 .24397 L p .707 .577 .707 r
F P
0 g
s
.46296 .24627 m .47789 .74952 L .43642 .75524 L p .707 .577 .707 r
F P
0 g
s
.67681 .70319 m .67094 .72006 L .69677 .73427 L p .707 .577 .707 r
F P
0 g
s
.50788 .24397 m .52281 .74723 L .47789 .74952 L p .707 .577 .707 r
F P
0 g
s
.67094 .72006 m .67681 .70319 L .65723 .68787 L p .707 .577 .707 r
F P
0 g
s
.79076 .74087 m .78489 .75774 L .8082 .75661 L p .707 .577 .707 r
F P
0 g
s
.8082 .75661 m .81407 .73974 L .79076 .74087 L p .707 .577 .707 r
F P
0 g
s
.65723 .68787 m .65135 .70474 L .67094 .72006 L p .707 .577 .707 r
F P
0 g
s
.8175 .7024 m .80614 .73631 L .82226 .73045 L p .707 .577 .707 r
F P
0 g
s
.82226 .73045 m .83363 .69654 L .8175 .7024 L p .707 .577 .707 r
F P
0 g
s
.83979 .60964 m .83393 .66426 L .84104 .65537 L p .707 .577 .707 r
F P
0 g
s
.84104 .65537 m .8469 .60075 L .83979 .60964 L p .707 .577 .707 r
F P
0 g
s
.64104 .64143 m .64691 .58681 L .64409 .57675 L p .707 .577 .707 r
F P
0 g
s
.81407 .73974 m .8082 .75661 L .82431 .7508 L p .707 .577 .707 r
F P
0 g
s
.82431 .7508 m .83018 .73393 L .81407 .73974 L p .707 .577 .707 r
F P
0 g
s
.6458 .67295 m .63993 .68982 L .65135 .70474 L p .707 .577 .707 r
F P
0 g
s
.63726 .67131 m .64862 .6374 L .64642 .62448 L p .707 .577 .707 r
F P
0 g
s
.63992 .63741 m .64104 .64143 L p .64158 .63003 L .707 .577 .707 r
F P
0 g
s
.64642 .62448 m .63506 .65839 L .63726 .67131 L p .707 .577 .707 r
F P
0 g
s
.64642 .62448 m .65375 .61461 L p .63533 .65776 L .707 .577 .707 r
F P
0 g
s
.63506 .65839 m .63545 .65723 L p .63533 .65776 L .707 .577 .707 r
F P
0 g
s
.63545 .65723 m .64642 .62448 L p .63533 .65776 L .707 .577 .707 r
F P
0 g
s
.64409 .57675 m .63823 .63137 L .63992 .63741 L p .707 .577 .707 r
F P
0 g
s
.64158 .63003 m .64409 .57675 L .63992 .63741 L .707 .577 .707 r
F
.83363 .69654 m .82226 .73045 L .82959 .72058 L p F P
0 g
s
.82959 .72058 m .84095 .68667 L .83363 .69654 L p .707 .577 .707 r
F P
0 g
s
.8469 .60075 m .84104 .65537 L .83823 .64531 L p .707 .577 .707 r
F P
0 g
s
.83823 .64531 m .84409 .59069 L .8469 .60075 L p .707 .577 .707 r
F P
0 g
s
.63993 .68982 m .6458 .67295 L .64365 .65989 L p .707 .577 .707 r
F P
0 g
s
.63823 .63137 m .64409 .57675 L .6512 .56786 L p .707 .577 .707 r
F P
0 g
s
.64365 .65989 m .63778 .67676 L .63993 .68982 L p .707 .577 .707 r
F P
0 g
s
.83018 .73393 m .82431 .7508 L .83165 .74087 L p .707 .577 .707 r
F P
0 g
s
.83165 .74087 m .83752 .72401 L .83018 .73393 L p .707 .577 .707 r
F P
0 g
s
.6512 .56786 m .64534 .62248 L .63823 .63137 L p .707 .577 .707 r
F P
0 g
s
.84095 .68667 m .82959 .72058 L .82739 .70766 L p .707 .577 .707 r
F P
0 g
s
.82739 .70766 m .83875 .67375 L .84095 .68667 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84409 .59069 m .83823 .64531 L .82576 .63505 L p .707 .577 .707 r
F P
0 g
s
.82576 .63505 m .83162 .58044 L .84409 .59069 L p .707 .577 .707 r
F P
0 g
s
.63778 .67676 m .64365 .65989 L .65099 .64997 L p .707 .577 .707 r
F P
0 g
s
.38968 .61025 m .39554 .55563 L .36454 .55042 L p .707 .577 .707 r
F P
0 g
s
.39554 .55563 m .38968 .61025 L .42135 .61246 L p .707 .577 .707 r
F P
0 g
s
.42135 .61246 m .42721 .55784 L .39554 .55563 L p .707 .577 .707 r
F P
0 g
s
.66754 .56102 m .66369 .59694 L p .64534 .62248 L .707 .577 .707 r
F P
0 g
s
.64239 .64852 m .65375 .61461 L .66988 .60875 L p .707 .577 .707 r
F P
0 g
s
.66369 .59694 m .66168 .61563 L .65474 .61854 L p .707 .577 .707 r
F P
0 g
s
.65375 .61461 m .64262 .64783 L p .63506 .65839 L .707 .577 .707 r
F P
0 g
s
.65474 .61854 m .64534 .62248 L p .66369 .59694 L .707 .577 .707 r
F P
0 g
s
.64262 .64783 m .64239 .64852 L .64227 .64869 L p .707 .577 .707 r
F P
0 g
s
.64227 .64869 m .63506 .65839 L p .64262 .64783 L .707 .577 .707 r
F P
0 g
s
.42721 .55784 m .42135 .61246 L .45061 .61145 L p .707 .577 .707 r
F P
0 g
s
.45061 .61145 m .45647 .55683 L .42721 .55784 L p .707 .577 .707 r
F P
0 g
s
.35868 .60504 m .36454 .55042 L .33726 .54272 L p .707 .577 .707 r
F P
0 g
s
.36454 .55042 m .35868 .60504 L .38968 .61025 L p .707 .577 .707 r
F P
0 g
s
.64534 .62248 m .6512 .56786 L .66754 .56102 L p .707 .577 .707 r
F P
0 g
s
.65099 .64997 m .64512 .66684 L .63778 .67676 L p .707 .577 .707 r
F P
0 g
s
.83752 .72401 m .83165 .74087 L .8295 .72782 L p .707 .577 .707 r
F P
0 g
s
.8295 .72782 m .83537 .71095 L .83752 .72401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.45647 .55683 m .45061 .61145 L .47458 .60732 L p .707 .577 .707 r
F P
0 g
s
.47458 .60732 m .48044 .5527 L .45647 .55683 L p .707 .577 .707 r
F P
0 g
s
.3314 .59734 m .33726 .54272 L .31636 .53328 L p .707 .577 .707 r
F P
0 g
s
.33726 .54272 m .3314 .59734 L .35868 .60504 L p .707 .577 .707 r
F P
0 g
s
.83875 .67375 m .82739 .70766 L .81589 .69297 L p .707 .577 .707 r
F P
0 g
s
.81589 .69297 m .82725 .65906 L .83875 .67375 L p .707 .577 .707 r
F P
0 g
s
.83162 .58044 m .82576 .63505 L .80486 .62562 L p .707 .577 .707 r
F P
0 g
s
.80486 .62562 m .81073 .571 L .83162 .58044 L p .707 .577 .707 r
F P
0 g
s
.38102 .6879 m .39238 .65399 L .36273 .64258 L p .707 .577 .707 r
F P
0 g
s
.39238 .65399 m .38102 .6879 L .41148 .6957 L p .707 .577 .707 r
F P
0 g
s
.41148 .6957 m .42284 .66179 L .39238 .65399 L p .707 .577 .707 r
F P
0 g
s
.64512 .66684 m .65099 .64997 L .6671 .64416 L p .707 .577 .707 r
F P
0 g
s
.66988 .60875 m .6589 .6415 L p .64239 .64852 L .707 .577 .707 r
F P
0 g
s
.65852 .64266 m .66988 .60875 L .69323 .60747 L p .707 .577 .707 r
F P
0 g
s
.69151 .55689 m .6875 .59428 L p .66168 .61563 L .707 .577 .707 r
F P
0 g
s
.6875 .59428 m .68565 .61151 L .67607 .61316 L p .707 .577 .707 r
F P
0 g
s
.67607 .61316 m .66168 .61563 L p .6875 .59428 L .707 .577 .707 r
F P
0 g
s
.6589 .6415 m .65852 .64266 L .65811 .64281 L p .707 .577 .707 r
F P
0 g
s
.65811 .64281 m .64239 .64852 L p .6589 .6415 L .707 .577 .707 r
F P
0 g
s
.35137 .67649 m .36273 .64258 L .3368 .62867 L p .707 .577 .707 r
F P
0 g
s
.36273 .64258 m .35137 .67649 L .38102 .6879 L p .707 .577 .707 r
F P
0 g
s
.66168 .61563 m .66754 .56102 L .69151 .55689 L p .707 .577 .707 r
F P
0 g
s
.42284 .66179 m .41148 .6957 L .43977 .69914 L p .707 .577 .707 r
F P
0 g
s
.43977 .69914 m .45113 .66523 L .42284 .66179 L p .707 .577 .707 r
F P
0 g
s
.6671 .64416 m .66123 .66103 L .64512 .66684 L p .707 .577 .707 r
F P
0 g
s
.83537 .71095 m .8295 .72782 L .81807 .7129 L p .707 .577 .707 r
F P
0 g
s
.81807 .7129 m .82395 .69603 L .83537 .71095 L p .707 .577 .707 r
F P
0 g
s
.48044 .5527 m .47458 .60732 L .49092 .60048 L p .707 .577 .707 r
F P
0 g
s
.49092 .60048 m .49678 .54586 L .48044 .5527 L p .707 .577 .707 r
F P
0 g
s
.31636 .53328 m .3105 .5879 L .3314 .59734 L p .707 .577 .707 r
F P
0 g
s
.3105 .5879 m .31636 .53328 L .3039 .52303 L p .707 .577 .707 r
F P
0 g
s
.32543 .66258 m .3368 .62867 L .31711 .61364 L p .707 .577 .707 r
F P
0 g
s
.3368 .62867 m .32543 .66258 L .35137 .67649 L p .707 .577 .707 r
F P
0 g
s
.45113 .66523 m .43977 .69914 L .46313 .69786 L p .707 .577 .707 r
F P
0 g
s
.46313 .69786 m .47449 .66395 L .45113 .66523 L p .707 .577 .707 r
F P
0 g
s
.81073 .571 m .80486 .62562 L .77758 .61791 L p .707 .577 .707 r
F P
0 g
s
.77758 .61791 m .78344 .56329 L .81073 .571 L p .707 .577 .707 r
F P
0 g
s
.82725 .65906 m .81589 .69297 L .79621 .67793 L p .707 .577 .707 r
F P
0 g
s
.79621 .67793 m .80757 .64402 L .82725 .65906 L p .707 .577 .707 r
F P
0 g
s
.3833 .75396 m .38917 .73709 L .35963 .72537 L p .707 .577 .707 r
F P
0 g
s
.38917 .73709 m .3833 .75396 L .41367 .76204 L p .707 .577 .707 r
F P
0 g
s
.41367 .76204 m .41954 .74518 L .38917 .73709 L p .707 .577 .707 r
F P
0 g
s
.68565 .61151 m .69151 .55689 L .72077 .55588 L p .707 .577 .707 r
F P
0 g
s
.66123 .66103 m .6671 .64416 L .69041 .64303 L p .707 .577 .707 r
F P
0 g
s
.35376 .74223 m .35963 .72537 L .3338 .71115 L p .707 .577 .707 r
F P
0 g
s
.35963 .72537 m .35376 .74223 L .3833 .75396 L p .707 .577 .707 r
F P
0 g
s
.31711 .61364 m .30575 .64755 L .32543 .66258 L p .707 .577 .707 r
F P
0 g
s
.72077 .55588 m .71703 .59074 L p .68565 .61151 L .707 .577 .707 r
F P
0 g
s
.68187 .64138 m .69323 .60747 L .72152 .6109 L p .707 .577 .707 r
F P
0 g
s
.71703 .59074 m .71491 .6105 L .70264 .61092 L p .707 .577 .707 r
F P
0 g
s
.69323 .60747 m .68272 .63885 L p .65852 .64266 L .707 .577 .707 r
F P
0 g
s
.70264 .61092 m .68565 .61151 L p .71703 .59074 L .707 .577 .707 r
F P
0 g
s
.68272 .63885 m .68187 .64138 L .68087 .64144 L p .707 .577 .707 r
F P
0 g
s
.68087 .64144 m .65852 .64266 L p .68272 .63885 L .707 .577 .707 r
F P
0 g
s
.41954 .74518 m .41367 .76204 L .44188 .7657 L p .707 .577 .707 r
F P
0 g
s
.44188 .7657 m .44775 .74883 L .41954 .74518 L p .707 .577 .707 r
F P
0 g
s
.3039 .52303 m .29803 .57765 L .3105 .5879 L p .707 .577 .707 r
F P
0 g
s
.82395 .69603 m .81807 .7129 L .79849 .69758 L p .707 .577 .707 r
F P
0 g
s
.79849 .69758 m .80436 .68071 L .82395 .69603 L p .707 .577 .707 r
F P
0 g
s
.69041 .64303 m .68454 .6599 L .66123 .66103 L p .707 .577 .707 r
F P
0 g
s
.3338 .71115 m .32793 .72802 L .35376 .74223 L p .707 .577 .707 r
F P
0 g
s
.49678 .54586 m .49092 .60048 L .49803 .59159 L p .707 .577 .707 r
F P
0 g
s
.49803 .59159 m .50389 .53697 L .49678 .54586 L p .707 .577 .707 r
F P
0 g
s
.78344 .56329 m .77758 .61791 L .74659 .6127 L p .707 .577 .707 r
F P
0 g
s
.74659 .6127 m .75245 .55808 L .78344 .56329 L p .707 .577 .707 r
F P
0 g
s
.30575 .64755 m .31711 .61364 L .30561 .59895 L p .707 .577 .707 r
F P
0 g
s
.71491 .6105 m .72077 .55588 L .75245 .55808 L p .707 .577 .707 r
F P
0 g
s
.32793 .72802 m .3338 .71115 L .31422 .69583 L p .707 .577 .707 r
F P
0 g
s
.72152 .6109 m .71173 .64014 L p .68187 .64138 L .707 .577 .707 r
F P
0 g
s
.71173 .64014 m .71016 .64481 L .70873 .64464 L p .707 .577 .707 r
F P
0 g
s
.70873 .64464 m .68187 .64138 L p .71173 .64014 L .707 .577 .707 r
F P
0 g
s
.75245 .55808 m .74977 .583 L p .71491 .6105 L .707 .577 .707 r
F P
0 g
s
.74977 .583 m .74659 .6127 L .73073 .6116 L p .707 .577 .707 r
F P
0 g
s
.71016 .64481 m .72152 .6109 L .75198 .61871 L p .707 .577 .707 r
F P
0 g
s
.73073 .6116 m .71491 .6105 L p .74977 .583 L .707 .577 .707 r
F P
0 g
s
.29803 .57765 m .3039 .52303 L .30108 .51296 L p .707 .577 .707 r
F P
0 g
s
.47449 .66395 m .46313 .69786 L .47925 .692 L p .707 .577 .707 r
F P
0 g
s
.47925 .692 m .49062 .65809 L .47449 .66395 L p .707 .577 .707 r
F P
0 g
s
.80757 .64402 m .79621 .67793 L .77394 .666 L p .707 .577 .707 r
F P
0 g
s
.77853 .6665 m .77266 .68336 L .76857 .68174 L p .707 .577 .707 r
F P
0 g
s
.76857 .68174 m .74312 .67164 L p .77353 .66722 L .707 .577 .707 r
F P
0 g
s
.77353 .66722 m .77853 .6665 L .76857 .68174 L .707 .577 .707 r
F
.77559 .66118 m .80757 .64402 L .77394 .666 L F
.74312 .67164 m .74899 .65477 L .77434 .66483 L p F P
0 g
s
.77434 .66483 m .77853 .6665 L p .77353 .66722 L .707 .577 .707 r
F P
0 g
s
.74312 .67164 m .77434 .66483 L .77353 .66722 L .707 .577 .707 r
F
.77027 .66403 m .78163 .63012 L .78548 .63218 L p F P
0 g
s
.78548 .63218 m .80757 .64402 L p .77559 .66118 L .707 .577 .707 r
F P
0 g
s
.77027 .66403 m .78548 .63218 L .77559 .66118 L .707 .577 .707 r
F
.77394 .666 m .77027 .66403 L p .77559 .66118 L F P
0 g
s
.44775 .74883 m .44188 .7657 L .46519 .76457 L p .707 .577 .707 r
F P
0 g
s
.46519 .76457 m .47106 .7477 L .44775 .74883 L p .707 .577 .707 r
F P
0 g
s
.31422 .69583 m .30834 .7127 L .32793 .72802 L p .707 .577 .707 r
F P
0 g
s
.68454 .6599 m .69041 .64303 L .71862 .64668 L p .707 .577 .707 r
F P
0 g
s
.30561 .59895 m .29425 .63286 L .30575 .64755 L p .707 .577 .707 r
F P
0 g
s
.80436 .68071 m .79849 .69758 L .77266 .68336 L p .707 .577 .707 r
F P
0 g
s
.77266 .68336 m .77853 .6665 L .80436 .68071 L p .707 .577 .707 r
F P
0 g
s
.71275 .66355 m .71862 .64668 L .74899 .65477 L p .707 .577 .707 r
F P
0 g
s
.74899 .65477 m .74312 .67164 L .71275 .66355 L p .707 .577 .707 r
F P
0 g
s
.78163 .63012 m .77027 .66403 L .74062 .65262 L p .707 .577 .707 r
F P
0 g
s
.74062 .65262 m .75198 .61871 L .78163 .63012 L p .707 .577 .707 r
F P
0 g
s
.71862 .64668 m .71275 .66355 L .68454 .6599 L p .707 .577 .707 r
F P
0 g
s
.75198 .61871 m .74062 .65262 L .71016 .64481 L p .707 .577 .707 r
F P
0 g
s
.30108 .51296 m .29522 .56758 L .29803 .57765 L p .707 .577 .707 r
F P
0 g
s
.30834 .7127 m .31422 .69583 L .30279 .68091 L p .707 .577 .707 r
F P
0 g
s
.29425 .63286 m .30561 .59895 L .30341 .58603 L p .707 .577 .707 r
F P
0 g
s
.50389 .53697 m .49803 .59159 L .49522 .58152 L p .707 .577 .707 r
F P
0 g
s
.49522 .58152 m .50108 .5269 L .50389 .53697 L p .707 .577 .707 r
F P
0 g
s
.47106 .7477 m .46519 .76457 L .4813 .75876 L p .707 .577 .707 r
F P
0 g
s
.4813 .75876 m .48717 .74189 L .47106 .7477 L p .707 .577 .707 r
F P
0 g
s
.30279 .68091 m .29692 .69778 L .30834 .7127 L p .707 .577 .707 r
F P
0 g
s
.49062 .65809 m .47925 .692 L .48658 .68213 L p .707 .577 .707 r
F P
0 g
s
.48658 .68213 m .49794 .64822 L .49062 .65809 L p .707 .577 .707 r
F P
0 g
s
.29522 .56758 m .30108 .51296 L .30819 .50407 L p .707 .577 .707 r
F P
0 g
s
.30341 .58603 m .29205 .61994 L .29425 .63286 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29692 .69778 m .30279 .68091 L .30064 .66785 L p .707 .577 .707 r
F P
0 g
s
.30819 .50407 m .30233 .55869 L .29522 .56758 L p .707 .577 .707 r
F P
0 g
s
.29205 .61994 m .30341 .58603 L .31074 .57616 L p .707 .577 .707 r
F P
0 g
s
.30064 .66785 m .29477 .68472 L .29692 .69778 L p .707 .577 .707 r
F P
0 g
s
.48717 .74189 m .4813 .75876 L .48864 .74883 L p .707 .577 .707 r
F P
0 g
s
.48864 .74883 m .49451 .73197 L .48717 .74189 L p .707 .577 .707 r
F P
0 g
s
.50108 .5269 m .49522 .58152 L .48275 .57127 L p .707 .577 .707 r
F P
0 g
s
.48275 .57127 m .48861 .51665 L .50108 .5269 L p .707 .577 .707 r
F P
0 g
s
.49794 .64822 m .48658 .68213 L .48438 .66921 L p .707 .577 .707 r
F P
0 g
s
.48438 .66921 m .49574 .6353 L .49794 .64822 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30233 .55869 m .30819 .50407 L .32453 .49723 L p .707 .577 .707 r
F P
0 g
s
.31074 .57616 m .29938 .61007 L .29205 .61994 L p .707 .577 .707 r
F P
0 g
s
.29477 .68472 m .30064 .66785 L .30798 .65793 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32453 .49723 m .31867 .55185 L .30233 .55869 L p .707 .577 .707 r
F P
0 g
s
.29938 .61007 m .31074 .57616 L .32687 .5703 L p .707 .577 .707 r
F P
0 g
s
.30798 .65793 m .30211 .6748 L .29477 .68472 L p .707 .577 .707 r
F P
0 g
s
.48861 .51665 m .48275 .57127 L .46185 .56183 L p .707 .577 .707 r
F P
0 g
s
.46185 .56183 m .46772 .50721 L .48861 .51665 L p .707 .577 .707 r
F P
0 g
s
.49451 .73197 m .48864 .74883 L .48649 .73578 L p .707 .577 .707 r
F P
0 g
s
.48649 .73578 m .49236 .71891 L .49451 .73197 L p .707 .577 .707 r
F P
0 g
s
.49574 .6353 m .48438 .66921 L .47288 .65452 L p .707 .577 .707 r
F P
0 g
s
.47288 .65452 m .48424 .62061 L .49574 .6353 L p .707 .577 .707 r
F P
0 g
s
.31867 .55185 m .32453 .49723 L .3485 .4931 L p .707 .577 .707 r
F P
0 g
s
.32687 .5703 m .31551 .60421 L .29938 .61007 L p .707 .577 .707 r
F P
0 g
s
.30211 .6748 m .30798 .65793 L .32409 .65212 L p .707 .577 .707 r
F P
0 g
s
.46772 .50721 m .46185 .56183 L .43457 .55413 L p .707 .577 .707 r
F P
0 g
s
.43457 .55413 m .44043 .49951 L .46772 .50721 L p .707 .577 .707 r
F P
0 g
s
.3485 .4931 m .34264 .54772 L .31867 .55185 L p .707 .577 .707 r
F P
0 g
s
.31551 .60421 m .32687 .5703 L .35022 .56902 L p .707 .577 .707 r
F P
0 g
s
.34264 .54772 m .3485 .4931 L .37776 .49209 L p .707 .577 .707 r
F P
0 g
s
.32409 .65212 m .31822 .66899 L .30211 .6748 L p .707 .577 .707 r
F P
0 g
s
.49236 .71891 m .48649 .73578 L .47506 .72086 L p .707 .577 .707 r
F P
0 g
s
.47506 .72086 m .48094 .70399 L .49236 .71891 L p .707 .577 .707 r
F P
0 g
s
.48424 .62061 m .47288 .65452 L .4532 .63948 L p .707 .577 .707 r
F P
0 g
s
.4532 .63948 m .46456 .60557 L .48424 .62061 L p .707 .577 .707 r
F P
0 g
s
.44043 .49951 m .43457 .55413 L .40358 .54892 L p .707 .577 .707 r
F P
0 g
s
.40358 .54892 m .40944 .4943 L .44043 .49951 L p .707 .577 .707 r
F P
0 g
s
.35022 .56902 m .33886 .60293 L .31551 .60421 L p .707 .577 .707 r
F P
0 g
s
.3719 .54671 m .37776 .49209 L .40944 .4943 L p .707 .577 .707 r
F P
0 g
s
.37776 .49209 m .3719 .54671 L .34264 .54772 L p .707 .577 .707 r
F P
0 g
s
.40944 .4943 m .40358 .54892 L .3719 .54671 L p .707 .577 .707 r
F P
0 g
s
.33886 .60293 m .35022 .56902 L .37851 .57245 L p .707 .577 .707 r
F P
0 g
s
.31822 .66899 m .32409 .65212 L .3474 .65099 L p .707 .577 .707 r
F P
0 g
s
.46456 .60557 m .4532 .63948 L .42726 .62558 L p .707 .577 .707 r
F P
0 g
s
.42726 .62558 m .43862 .59167 L .46456 .60557 L p .707 .577 .707 r
F P
0 g
s
.48094 .70399 m .47506 .72086 L .45548 .70554 L p .707 .577 .707 r
F P
0 g
s
.45548 .70554 m .46135 .68867 L .48094 .70399 L p .707 .577 .707 r
F P
0 g
s
.3474 .65099 m .34153 .66786 L .31822 .66899 L p .707 .577 .707 r
F P
0 g
s
.37851 .57245 m .36715 .60636 L .33886 .60293 L p .707 .577 .707 r
F P
0 g
s
.36715 .60636 m .37851 .57245 L .40897 .58026 L p .707 .577 .707 r
F P
0 g
s
.43862 .59167 m .42726 .62558 L .39761 .61417 L p .707 .577 .707 r
F P
0 g
s
.39761 .61417 m .40897 .58026 L .43862 .59167 L p .707 .577 .707 r
F P
0 g
s
.40897 .58026 m .39761 .61417 L .36715 .60636 L p .707 .577 .707 r
F P
0 g
s
.34153 .66786 m .3474 .65099 L .37561 .65464 L p .707 .577 .707 r
F P
0 g
s
.46135 .68867 m .45548 .70554 L .42965 .69132 L p .707 .577 .707 r
F P
0 g
s
.42965 .69132 m .43552 .67446 L .46135 .68867 L p .707 .577 .707 r
F P
0 g
s
.37561 .65464 m .36974 .67151 L .34153 .66786 L p .707 .577 .707 r
F P
0 g
s
.36974 .67151 m .37561 .65464 L .40598 .66273 L p .707 .577 .707 r
F P
0 g
s
.43552 .67446 m .42965 .69132 L .40011 .6796 L p .707 .577 .707 r
F P
0 g
s
.40011 .6796 m .40598 .66273 L .43552 .67446 L p .707 .577 .707 r
F P
0 g
s
.40598 .66273 m .40011 .6796 L .36974 .67151 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo001nOol<0006FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol007Ioo`P000EJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00Lgoo0`0000=JEP00FUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01000Kgoo001`Ool30004
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04
FUH3001/Ool006eoo`<000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP<006Yoo`00Jgoo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00J7oo
001YOol20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Moo`8000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001V
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Ao
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVEoo`00IGoo00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYFFUH005YFIGoo001UOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIUOol006Eoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
Oomoo`1SOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1SOol006Eoo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Io
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001TOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Io
o`03001JEP0000P000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00H7oo20000eYF00<005YFFUH00UYF1`00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00I7oo001KOol50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001TOol005Uoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Aoo`00Egoo0P000eYF00<005YFFUH015YF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001FOol20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH3000<
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEP00008000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Aoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001EOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001TOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol005Aoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001TOol005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001T
Ool005Aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1SOol005Aoo`03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1SOol005Aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJ
EP06001JEUYF001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0Hgoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06=oo`00E7oo0P0015YF00@005YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0Hgoo001DOol20003FUH500000eYF001JEP04FUH50004
FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0Hgoo001COol01000FUH0
05YF0`001EYF00<005YFFUH01EYF00<005YFFUH010000UYF00<005YFFUH015YF1P001UYF00<005YF
FUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06=oo`00Dgoo00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00AJEQ<0009JEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`07OolG0015Ool005=o
o`<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJEP03001JEUYF00EJ
EP<000EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`03Ool40003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP040011Ool005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJ
EP03001JEUYF00EJEP03001JEUYF008000=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIoogoo0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH015YF1000?Goo001COol00`00FUIJEP02FUH00`00FUIJEP04FUH8
0007FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001eYF001JEUYF001JEP0000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000i
Ool005=oo`03001JEUYF009JEP03001JEUYF00D000=JEP04001JEUYFFUH600000eYF000000030005
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUH00004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000fOol005Aoo`04001JEUYFFUH3
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUH000040006FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01000FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF0P0025YF00<005YFFUH01UYF
00<005YFFUH01EYF0`00=7oo001DOol00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`001EYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH20005
FUH00`00FUIJEP05FUH20008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02000bOol0
05Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<0009JEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH20005FUH00`00FUIJEP05FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000`Ool003UooaL000Ioo`8000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000MJEP03001JEUYF00AJEP03
001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH20003FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH3000^Ool003Aoo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00@0009oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
009JEP<000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000]Ool0
039oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP03001J
EUYF00AJEP07001JEUYFFUH005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00;Goo000`Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH300000eYF001JEP04FUH00`00FUIJ
EP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`8000AJEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH01000FUIJEUYF0P001eYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;7oo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUH00002FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH20003FUH01000FUH000002EYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20000
0eYF00000004FUH00`00FUIJEP020002Ool70007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH5000;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000/Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP<0009JEP05001JEUYFFUH00004FUH20003Ool00`00FUIJEP05
0002FUH00`00FUIJEP06FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH@0002FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20004FUH01000FUIJEP001EYF0P000Woo
00@005YFFUH000AJEP@000MJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF00<0009JEP03001JEUYF
00IJEP03001JEP0000T000AJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYFFUH2000/Ool0
02ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP80
00EJEP800003FUH005YF00AJEP03001JEP000080009JEP03001JEUYF00AJEP04001JEP000005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEUYF00000UYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF1000
0Woo1P001EYF00<005YFFUH015YF00H005YFFUH005YF000/Ool002eoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF0080
00EJEP05001JEUYFFUH00002FUH00`00FUIJEP04FUH01000FUIJEUYF0`0000=JEP00FUH01eYF00<0
05YFFUH015YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YF001JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000/0
0003FUH005YF00EJEP06001JEUYF001JEP00;7oo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUIJ
EP02FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH015YF0P0025YF00<005YFFUH0
15YF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YF001JEP8000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP8000QJEP8000EJ
EP07001JEUYFFUH005YF0000;7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH01@00FUIJEUYF
00000eYF00@005YFFUH000AJEP<000QJEP8000EJEP03001JEUYF00AJEP03001JEP0000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP8000IJEP04001JEP000003FUH01000FUIJ
EUYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01000FUIJ
EP000eYF1@0025YF0`000eYF00<005YFFUH015YF00@005YFFUH000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP<000=JEP04001JEUYFFUH200000eYF001JEP02FUH2000]Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH01000FUIJEUYF0P000UYF0P000UYF00@005YFFUIJEPD000QJEP03
001JEUYF00<000MJEP05001JEUYFFUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUH000020004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUH000020006FUH20003FUH2000]Ool002eoo`8000AJEP03001JEUYF00=JEPh0
00AJEP03001JEUYF00IJEP04001JEUYF0006FUH00`00FUIJEP03FUH40002FUH01000FUIJEUYF1@00
25YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YFFUH015YF00<005YF
00000UYF0P00;Goo000]Ool20004FUH00`00FUH000030005FUH50004Ool90004FUH200000eYF001J
EP05FUH00`00FUIJEP05FUH300000eYF001JEP03FUH30009FUH00`00FUIJEP03FUH00`00FUIJEP03
FUH01000FUIJEUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF
001JEP00009JEPh00003FUH005YF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001J
EUYF00@002eoo`00;Goo00=JEP00FUH00UYF0`000eYF00<005YFFUH01EYF00<005YFFUH010002Goo
1`001UYF00<005YFFUH01eYF00@005YF000000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF009JEP07001JEUYFFUH005YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00D005YF000005YF0080009JEPD000=JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01@00FUIJEUYF00000eYF0`00;Goo000/Ool01000FUH005YF0`001EYF00<005YFFUH0
1EYF00<005YFFUH015YF40001UYF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH0
1eYF00<005YFFUH01EYF0P000UYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUH0000200000eYF000000020006FUH00`00FUIJEP06FUH40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH300000eYF001JEP02FUH3000]Ool002aoo`06001JEP00
001JEP001UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH00UYF0P000UYF3000
1eYF10002EYF00<005YFFUH01eYF0P000eYF00@005YFFUH000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP<00004FUH000000002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40007FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YF0000;Goo000/Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP04FUH2
00000eYF001JEP04FUH01000FUIJEUYF1`000UYF00<005YF00000P001eYF00<005YFFUH025YF00L0
05YFFUIJEP00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH60002FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUH0000]Ool002aoo`03001JEUYF009JEP03001JEUYF00AJEPP000MJEPD0
00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00@000=J
EP<000AJEP03001JEUYF00QJEP80009JEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP800004FUH005YF0002FUH;0004FUH00`00FUIJEP07FUH00`00FUH000020000
0eYF001JEP08FUH00`00FUIJEP04FUH01000FUH00000;Woo000/Ool00`00FUIJEP02FUH01000FUIJ
EUYF10000eYF00@005YFFUIJEPH00003FUH0000000<000EJEP03001JEUYF009JEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@0009JEPD000QJEP@0009JEP03001J
EP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800004FUH00000FUH20004
FUH20005FUH60008FUH01000FUIJEUYF0`0025YF00<005YFFUH01EYF0`00;goo000]Ool01P00FUIJ
EUYF001JEP<000EJEP03001JEUYF00IJEP03001JEP0000@000IJEP04001JEUYFFUH20003FUH01000
FUIJEUYF1`0015YF00<005YFFUH01eYF00H005YF000005YF0003FUH80002FUH01P00FUH00000FUH0
00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF
00EJEP@0009JEP03001JEUYF009JEP<000AJEP03001JEUYF00EJEP<000EJEP03001JEUYF00AJEP03
001JEP00031oo`00;Goo00@005YFFUIJEP800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP<000EJEP05001JEUYFFUH00002FUH600000eYF00000003FUH70007FUH00`00FUIJEP02FUH3
0006FUH00`00FUIJEP02FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF00IJEP<00003Ool0000000D000=JEP<00003
FUH005YF00QJEP<000=JEP03001JEUYF00AJEP04001JEUYF000_Ool002ioo`04001JEP000002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP040002FUH00`00
FUIJEP03FUH40007FUH20005FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000800003
FUH005YF00EJEP04001JEUYFFUH20006Ool90007FUH01000FUIJEUYF0`001UYF00<005YFFUH00UYF
00<007ooOol0;7oo000_Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUH000020002FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP020008FUH300000eYF
001JEP08FUH300000eYF001JEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF001JEP<000IJEP03001JEUYF00=JEP8000Qoo`T000=JEP03001J
EUYF00=JEP8000EJEP03001JEUYF009JEP03001oogoo02aoo`00;goo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF100000EJEP00FUIJEP0000IJEP04001J
EUYFFUH40005FUH00`00FUH000030008FUH00`00FUIJEP020004FUH00`00FUIJEP02FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUH00000FUH000IJEP03001JEUYF
00IJEP8000Moo`<000Eoo`<000QJEP03001JEUYF009JEP04001JEUYFFUH2000^Ool002ioo`03001J
EP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001J
EUYF00800003FUH005YF00EJEP06001JEUYFFUH005YF1@0000=JEP00FUH0200015YF00<005YFFUH0
0eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00QJEP<000ioo`03001JEUYF
00IJEP<00003FUH005YF00=JEP03001JEP0002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00005FUH00`00FUIJEP02
FUH2000017oo001JEUYF2@000UYF100000=JEP00FUH01UYF0`000eYF0P002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH00UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0037oo0P001EYF00@005YFFUIJEP8000AJEP03001JEP0002eoo`00;Woo0P00
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0UYF0P001EYF00@005YFFUIJEP80009oo`04001JEUYF0003FUH500000eYF001JEP03FUH20008FUH2
0002FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH3000;Ool20003FUH00`00FUIJEP02FUH20002FUH01000
FUIJEP00;Goo000]Ool00`00FUH00002FUH;0004FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH30003FUH01000FUH0000017oo00@005YFFUH000AJEPX0009JEP8000EJEP03001JEUYF
00<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003FUH00`00
FUIJEP020008FUH00`00FUIJEP07FUH01000FUH000002goo0`001eYF00D005YF001JEP0002ioo`00
;Goo0P0000=JEP0000002goo1`001eYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP000000
0`001Woo00@005YFFUH000IJEP03001JEUYF00EJEPH000=JEP04001JEUYFFUH2000<FUH00`00FUIJ
EP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP8000IJEP03001J
EUYF00MJEP03001JEUYF009JEP<000Yoo`03001JEUYF00EJEP<00003FUH007oo02eoo`00;Goo0`00
0UYF00<007ooOol03Woo1@000UYF00<005YFFUH01UYF00<005YF00000UYF00D005YFFUH005YF0080
00Qoo`04001JEUYF0006FUH00`00FUIJEP07FUH01000FUIJEUYF0`001EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00EJEPD000Ioo`8000AJEP03001JEP00008002moo`00;Goo0P00
15YF00<007ooOol04Woo0`0025YF00<005YF00000UYF00D005YFFUIJEP00009JEP8000Ioo`04001J
EUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF0`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEPT000=JEP03001JEUYF008002moo`00;7oo0P001EYF
0P005Woo0P001UYF00<005YFFUH00P001EYF00D005YFFUIJEP0000Eoo`04001JEUYF0007FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH20004FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000AJEP05001JEUYFFUH00002FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00Oomoo`0^Ool002aoo`8000AJ
EP03001JEUYF008001Ioo`8000AJEP05001JEUYFFUH00006FUH01@00FUIJEUYF000017oo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF009J
EP8000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000AJEP03001oogoo02eo
o`00;7oo0P0015YF00<005YFFUH00UYF00<007ooOol05Goo0P0000=JEP00FUH015YF00<005YFFUH0
0eYF0`0000=JEP0000000goo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF00IJEP<0
009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<00003FUH0000000MJEP8000IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEP00009JEP8002moo`00;7oo0P000eYF00<005YFFUH015YF00<007ooOol05Woo0P00
1UYF00<005YFFUH00UYF00<005YFFUH00`000goo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP05001JEUYFFUH00008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP030008FUH30004FUH00`00FUH000040002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF0000;Woo000/Ool00`00FUIJEP02FUH00`00
FUIJEP04FUH3000=Ool30008Ool20005FUH200000eYF001JEP04FUH20002Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF0P000UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000AJEP00FUIJEP8000IJEP03001JEP00
00800004FUH005YFFUH50002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF
00<007ooOol0;7oo000/Ool00`00FUIJEP02FUH00`00FUIJEP03FUH01000FUIJEUYF0P002Woo1@00
2Goo0P000eYF00@005YF000000MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP80009JEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<000EJEP8000=JEP03001JEUYF00=JEPT0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF00<0009JEP03001oogoo02aoo`00;Goo00@005YFFUH000IJEP03001JEUYF00=J
EP8000Qoo`D000]oo`<000=JEP03001JEUYF00IJEP06001JEP00001JEP001UYF00<005YFFUH01eYF
00<005YFFUH025YF00H005YF000005YF0007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH30006FUH300000eYF001JEP07FUH50002FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH02000FUIJEP00Ool005YF000_Ool002eoo`04001JEUYF0006FUH00`00FUIJEP05FUH2
0006Ool5000=Ool00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH01P00FUH00000FUH000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH0000000AJEP03001JEUYF008000UJEP03001JEP0000L000AJ
EP03001JEUYF00AJEP04001JEP000002Ool00`00FUH0000_Ool002ioo`8000IJEP03001JEUYF00MJ
EP<000Eoo`<000moo`8000AJEP8000=JEP03001JEUYF00EJEP@00003FUH005YF00QJEP03001JEUYF
00QJEP03001JEUYF008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000=JEP05001JEUYFFUH00003FUH30006FUH00`00FUIJEP04FUHA0002Ool4000`Ool0
02moo`03001JEUYF00AJEP03001JEUYF00IJEP04001JEUYFFUH2000GOol01P00FUIJEUYF001JEP<0
00UJEP03001JEUYF00@000MJEP03001JEUYF00QJEP03001JEP00008000QJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP<00003FUH005YF009JEPD000AJ
EP03001JEUYF00IJEP04001JEUYFFUH=0002FUH2000`Ool0031oo`80009JEP`000EJEP8001Ioo`<0
00=JEP<000MJEP03001JEUYF00EJEPH00003FUH005YF00UJEP800003FUH005YF00QJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH20003FUH0
0`00FUH00002Ool200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
000aOol0039oo`800003FUH005YF00AJEP04001JEUYFFUH700000eYF00000002000DOol01P00FUIJ
EUYF001JEP<000EJEP03001JEUYF00MJEP04001JEUYFFUH<0002FUH20003FUHF0008FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF0P000UYF00<005YF000017oo10001UYF00<005YF
FUH01UYF00<005YFFUH00eYF00@005YFFUIJEP80035oo`00<7oo0P000UYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH0100000=JEP0000000P004Goo00H005YFFUH005YF0002Ool300000eYF
001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF1P002UYF0P002EYF1P000UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000IJEP04001JEP000009Ool40002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000bOol002moo`8000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEP@00003FUH0000000@000Qoo`@0009JEP03001JEP00009oo`=J
EP@000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00QJEP80
00aJEP03001JEUYF00@000IJEP03001JEUYF00=JEP03001JEP0000MJEP@000eoo`H000AJEP03001J
EUYF00=JEP04001JEP00000dOol002moo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01P00FUH00000FUH000=JEPP0009JEP06001JEP00001JEP000goo0eYF00@005YFFUIJEP@0
009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP03FUH00`00FUH00006FUH01000FUH00000
57oo3000=Woo000^Ool20002FUH<0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006FUH00`00
FUIJEP02FUH01`00FUIJEUYF001JEP0000=oo`=JEP03001JEUYF00AJEPL000AJEP03001JEUYF00AJ
EP04001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40005FUH00`00
FUH00006FUH01000FUIJEP00EWoo000]Ool200000eYF00000008Ool300000eYF000000040007FUH0
0`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=oo`=JEP03001JEUYF
00=JEP<000=JEP03001JEP0000`000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP04001JEUYFFUH20003FUH20006FUH00`00FUIJEP02FUH00`00Oomoo`1COol002eoo`<000aoo`80
00IJEP@0009JEP03001JEUYF00MJEP<00003FUH005YF00AJEP07001JEUYFFUH005YF00000goo0eYF
00@005YFFUIJEP8000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP800004FUH000000005FUH00`00FUIJEP02FUH00`00
Oomoo`1COol002aoo`800003FUH007oo00eoo`<000EJEP03001JEP0000<000QJEP03001JEUYF0080
00AJEP03001JEUYF009JEP8000Aoo`=JEP03001JEP00008000MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEP00
0002FUH00`00FUIJEP02FUH01000FUIJEUYF0P00EGoo000/Ool00`00FUIJEP02000@Ool300000eYF
001JEP080004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH20004Ool3FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH01000FUH000000UYF0P000UYF00<005YFFUH00UYF00<005YF0000
E7oo000/Ool01@00FUH005YF00004goo20000UYF100000=JEP00FUH01UYF0`000eYF0P001Goo0UYF
00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0002FUH00`00FUH0
0004FUH00`00FUH0001DOol002aoo`03001JEP00009JEP03001oogoo01=oo`D00003FUH005YF00=J
EP8000QJEP80009JEP8000Ioo`03FUH0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP06001J
EUYF001JEP000eYF0P000eYF00@005YFFUH005Aoo`00;Goo00D005YFFUIJEP0001Ioo`X0009JEP80
00EJEP03001JEUYF008000Qoo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001J
EP00008000IJEP06001JEUYF001JEP00EGoo000]Ool00`00FUIJEP02FUH00`00Oomoo`0MOol60003
FUH01@00FUIJEUYF00002Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000Woo00<005YF
FUH01EYF00D005YF001JEP0005Eoo`00;Woo00H005YFFUH005YF000TOol30005FUH00`00Oomoo`06
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`02Ool20004FUH00`00FUH00002
001FOol002ioo`04001JEUYF0002FUH2000TOol00`00FUIJEP04FUH00`00Oomoo`06Ool00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH01000FUIJEUYF2P000eYF00D005YF001JEP0005Ioo`00;goo0P001EYF
00<007ooOol08Woo00<005YFFUH00eYF0P0027oo0P000UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YF000000EJ
EP03001JEUYF009JEP<000=JEP8005Ioo`00<7oo00<005YFFUH015YF00<007ooOol08Woo00<005YF
FUH00UYF0P002Woo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF0`001UYF00<005YFFUH015YF0P0015YF00<007ooOol0E7oo000aOol0
0`00FUIJEP03FUH3000SOol200001EYF001JEUYF00002goo0P001UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<0
05YFFUH015YF00<005YF00000eYF00<007ooOol0E7oo000bOol00`00FUIJEP02FUH00`00FUIJEP02
000SOol20003FUH00`00Oomoo`0:Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEP000UYF0P00EWoo000cOol200000eYF001JEP04FUH2000ROol01@00FUIJEUYF000047oo1@00
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF2@000UYF00<005YFFUH01EYF00<0
05YFFUH015YF00T005YFFUIJEP00FUH005YF0000EGoo000eOol20007FUH3000POol01000FUIJEP00
5Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUIJEPl0009JEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF00<0009JEP03001oogoo05=oo`00=Woo00<005YFFUH01UYF00@0
05YF000001ioo`05001JEP00FUH0000JOolP0008FUH600000eYF001JEP07FUH00`00FUIJEP04FUH0
2000FUIJEP00Ool005YF001FOol003Moo`8000EJEP03001JEUYF009JEP<001aoo`800003FUH007oo
03Moo`8000UJEPX000AJEP03001JEUYF00AJEP04001JEP000002Ool00`00FUH0001FOol003Uoo`80
00=JEP03001JEUYF00EJEP<001Yoo`03001JEP0003Yoo`8000IJEP03001JEUYF00AJEQ40009oo`@0
05Moo`00>goo0`002EYF00<005YF00000P005goo0P00?Goo0P0015YF00<005YFFUH01UYF00@005YF
FUIJEPd0009JEP8005Moo`00?Goo0P001eYF00<005YFFUH00eYF0`004Woo1000?goo0P0000=JEP00
FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00F7oo000oOol20005FUH00`00
FUIJEP06FUH50008Ool500000eYF00000012Ool40006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00F7oo0011Ool300000eYF001JEP08FUH00`00FUIJEP02FUH80002FUH01000FUIJ
EUYF0P00AWoo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00FGoo0014Ool4
0007FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02001;Ool60004FUH00`00FUIJEP03
FUH01000FUH00000Fgoo0018Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000DWoo3000GGoo001<Ool60004FUH00`00FUIJEP04FUH01000FUH00000_7oo001BOol=002nOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59642 .73255 m .59056 .67667 L .55956 .67812 L p .707 .577 .707 r
F P
0 g
s
.59056 .67667 m .59642 .73255 L .6281 .72875 L p .707 .577 .707 r
F P
0 g
s
.6281 .72875 m .62224 .67287 L .59056 .67667 L p .707 .577 .707 r
F P
0 g
s
.62224 .67287 m .6281 .72875 L .65735 .72298 L p .707 .577 .707 r
F P
0 g
s
.65735 .72298 m .65149 .6671 L .62224 .67287 L p .707 .577 .707 r
F P
0 g
s
.56543 .73399 m .55956 .67812 L .53228 .67707 L p .707 .577 .707 r
F P
0 g
s
.55956 .67812 m .56543 .73399 L .59642 .73255 L p .707 .577 .707 r
F P
0 g
s
.65149 .6671 m .65735 .72298 L .68133 .71579 L p .707 .577 .707 r
F P
0 g
s
.68133 .71579 m .67546 .65991 L .65149 .6671 L p .707 .577 .707 r
F P
0 g
s
.53228 .67707 m .53814 .73295 L .56543 .73399 L p .707 .577 .707 r
F P
0 g
s
.60238 .79907 m .59102 .76272 L .56137 .77066 L p .707 .577 .707 r
F P
0 g
s
.59102 .76272 m .60238 .79907 L .63285 .78942 L p .707 .577 .707 r
F P
0 g
s
.63285 .78942 m .62149 .75307 L .59102 .76272 L p .707 .577 .707 r
F P
0 g
s
.53814 .73295 m .53228 .67707 L .51138 .67364 L p .707 .577 .707 r
F P
0 g
s
.62149 .75307 m .63285 .78942 L .66114 .779 L p .707 .577 .707 r
F P
0 g
s
.66114 .779 m .64978 .74265 L .62149 .75307 L p .707 .577 .707 r
F P
0 g
s
.56137 .77066 m .57273 .80701 L .60238 .79907 L p .707 .577 .707 r
F P
0 g
s
.57273 .80701 m .56137 .77066 L .53544 .77611 L p .707 .577 .707 r
F P
0 g
s
.67546 .65991 m .68133 .71579 L .69767 .70789 L p .707 .577 .707 r
F P
0 g
s
.69767 .70789 m .69181 .65201 L .67546 .65991 L p .707 .577 .707 r
F P
0 g
s
.64978 .74265 m .66114 .779 L .68449 .76883 L p .707 .577 .707 r
F P
0 g
s
.68449 .76883 m .67313 .73248 L .64978 .74265 L p .707 .577 .707 r
F P
0 g
s
.51138 .67364 m .51725 .72951 L .53814 .73295 L p .707 .577 .707 r
F P
0 g
s
.53544 .77611 m .5468 .81246 L .57273 .80701 L p .707 .577 .707 r
F P
0 g
s
.59989 .86397 m .59402 .84584 L .56448 .85412 L p .707 .577 .707 r
F P
0 g
s
.59402 .84584 m .59989 .86397 L .63025 .85401 L p .707 .577 .707 r
F P
0 g
s
.63025 .85401 m .62438 .83588 L .59402 .84584 L p .707 .577 .707 r
F P
0 g
s
.62438 .83588 m .63025 .85401 L .65847 .84335 L p .707 .577 .707 r
F P
0 g
s
.65847 .84335 m .6526 .82522 L .62438 .83588 L p .707 .577 .707 r
F P
0 g
s
.51725 .72951 m .51138 .67364 L .49892 .66815 L p .707 .577 .707 r
F P
0 g
s
.56448 .85412 m .57035 .87224 L .59989 .86397 L p .707 .577 .707 r
F P
0 g
s
.5468 .81246 m .53544 .77611 L .51576 .77853 L p .707 .577 .707 r
F P
0 g
s
.67313 .73248 m .68449 .76883 L .70062 .7599 L p .707 .577 .707 r
F P
0 g
s
.70062 .7599 m .68926 .72355 L .67313 .73248 L p .707 .577 .707 r
F P
0 g
s
.57035 .87224 m .56448 .85412 L .53865 .8599 L p .707 .577 .707 r
F P
0 g
s
.51576 .77853 m .52712 .81488 L .5468 .81246 L p .707 .577 .707 r
F P
0 g
s
.6526 .82522 m .65847 .84335 L .68177 .83302 L p .707 .577 .707 r
F P
0 g
s
.68177 .83302 m .6759 .81489 L .6526 .82522 L p .707 .577 .707 r
F P
0 g
s
.53865 .8599 m .54452 .87803 L .57035 .87224 L p .707 .577 .707 r
F P
0 g
s
.69181 .65201 m .69767 .70789 L .70478 .70006 L p .707 .577 .707 r
F P
0 g
s
.70478 .70006 m .69892 .64418 L .69181 .65201 L p .707 .577 .707 r
F P
0 g
s
.49892 .66815 m .50478 .72403 L .51725 .72951 L p .707 .577 .707 r
F P
0 g
s
.54452 .87803 m .53865 .8599 L .51906 .86262 L p .707 .577 .707 r
F P
0 g
s
.51906 .86262 m .52493 .88075 L .54452 .87803 L p .707 .577 .707 r
F P
0 g
s
.52712 .81488 m .51576 .77853 L .50425 .77769 L p .707 .577 .707 r
F P
0 g
s
.6759 .81489 m .68177 .83302 L .69788 .82404 L p .707 .577 .707 r
F P
0 g
s
.69788 .82404 m .69201 .80592 L .6759 .81489 L p .707 .577 .707 r
F P
0 g
s
.50478 .72403 m .49892 .66815 L .4961 .66114 L p .707 .577 .707 r
F P
0 g
s
.68926 .72355 m .70062 .7599 L .70794 .75309 L p .707 .577 .707 r
F P
0 g
s
.70794 .75309 m .69658 .71675 L .68926 .72355 L p .707 .577 .707 r
F P
0 g
s
.50425 .77769 m .51562 .81404 L .52712 .81488 L p .707 .577 .707 r
F P
0 g
s
.69892 .64418 m .70478 .70006 L .70196 .69305 L p .707 .577 .707 r
F P
0 g
s
.70196 .69305 m .6961 .63717 L .69892 .64418 L p .707 .577 .707 r
F P
0 g
s
.4961 .66114 m .50196 .71702 L .50478 .72403 L p .707 .577 .707 r
F P
0 g
s
.52493 .88075 m .51906 .86262 L .50764 .86202 L p .707 .577 .707 r
F P
0 g
s
.50764 .86202 m .51351 .88015 L .52493 .88075 L p .707 .577 .707 r
F P
0 g
s
.69201 .80592 m .69788 .82404 L .70523 .81729 L p .707 .577 .707 r
F P
0 g
s
.70523 .81729 m .69935 .79916 L .69201 .80592 L p .707 .577 .707 r
F P
0 g
s
.47719 .82162 m .49212 .32157 L .44813 .31757 L p .707 .577 .707 r
F P
0 g
s
.51562 .81404 m .50425 .77769 L .50206 .77367 L p .707 .577 .707 r
F P
0 g
s
.50196 .71702 m .4961 .66114 L .50321 .65331 L p .707 .577 .707 r
F P
0 g
s
.50206 .77367 m .51342 .81002 L .51562 .81404 L p .707 .577 .707 r
F P
0 g
s
.50321 .65331 m .50908 .70919 L .50196 .71702 L p .707 .577 .707 r
F P
0 g
s
.51342 .81002 m .50206 .77367 L .50938 .76686 L p .707 .577 .707 r
F P
0 g
s
.50908 .70919 m .50321 .65331 L .51956 .64541 L p .707 .577 .707 r
F P
0 g
s
.50938 .76686 m .52074 .80321 L .51342 .81002 L p .707 .577 .707 r
F P
0 g
s
.51956 .64541 m .52542 .70129 L .50908 .70919 L p .707 .577 .707 r
F P
0 g
s
.52074 .80321 m .50938 .76686 L .52551 .75794 L p .707 .577 .707 r
F P
0 g
s
.52551 .75794 m .53687 .79429 L .52074 .80321 L p .707 .577 .707 r
F P
0 g
s
.49212 .32157 m .47719 .82162 L .52211 .82172 L p .707 .577 .707 r
F P
0 g
s
.52542 .70129 m .51956 .64541 L .54353 .63822 L p .707 .577 .707 r
F P
0 g
s
.54353 .63822 m .54939 .6941 L .52542 .70129 L p .707 .577 .707 r
F P
0 g
s
.52211 .82172 m .53704 .32167 L .49212 .32157 L p .707 .577 .707 r
F P
0 g
s
.54939 .6941 m .54353 .63822 L .57278 .63245 L p .707 .577 .707 r
F P
0 g
s
.53687 .79429 m .52551 .75794 L .54886 .74777 L p .707 .577 .707 r
F P
0 g
s
.57278 .63245 m .57865 .68833 L .54939 .6941 L p .707 .577 .707 r
F P
0 g
s
.54886 .74777 m .56022 .78412 L .53687 .79429 L p .707 .577 .707 r
F P
0 g
s
.56022 .78412 m .54886 .74777 L .57716 .73734 L p .707 .577 .707 r
F P
0 g
s
.57716 .73734 m .58852 .77369 L .56022 .78412 L p .707 .577 .707 r
F P
0 g
s
.53704 .32167 m .52211 .82172 L .56358 .81789 L p .707 .577 .707 r
F P
0 g
s
.56358 .81789 m .57851 .31785 L .53704 .32167 L p .707 .577 .707 r
F P
0 g
s
.69658 .71675 m .70794 .75309 L .70575 .74907 L p .707 .577 .707 r
F P
0 g
s
.70575 .74907 m .69439 .71273 L .69658 .71675 L p .707 .577 .707 r
F P
0 g
s
.4332 .81761 m .44813 .31757 L .40938 .31004 L p .707 .577 .707 r
F P
0 g
s
.44813 .31757 m .4332 .81761 L .47719 .82162 L p .707 .577 .707 r
F P
0 g
s
.6961 .63717 m .70196 .69305 L .6895 .68756 L p .707 .577 .707 r
F P
0 g
s
.6895 .68756 m .68364 .63169 L .6961 .63717 L p .707 .577 .707 r
F P
0 g
s
.57865 .68833 m .57278 .63245 L .60446 .62865 L p .707 .577 .707 r
F P
0 g
s
.60446 .62865 m .61032 .68453 L .57865 .68833 L p .707 .577 .707 r
F P
0 g
s
.58852 .77369 m .57716 .73734 L .60762 .72769 L p .707 .577 .707 r
F P
0 g
s
.60762 .72769 m .61898 .76404 L .58852 .77369 L p .707 .577 .707 r
F P
0 g
s
.57851 .31785 m .56358 .81789 L .59753 .81053 L p .707 .577 .707 r
F P
0 g
s
.59753 .81053 m .61246 .31048 L .57851 .31785 L p .707 .577 .707 r
F P
0 g
s
.51351 .88015 m .50764 .86202 L .50549 .85816 L p .707 .577 .707 r
F P
0 g
s
.50549 .85816 m .51136 .87629 L .51351 .88015 L p .707 .577 .707 r
F P
0 g
s
.69935 .79916 m .70523 .81729 L .70308 .81343 L p .707 .577 .707 r
F P
0 g
s
.70308 .81343 m .69721 .7953 L .69935 .79916 L p .707 .577 .707 r
F P
0 g
s
.39445 .81009 m .40938 .31004 L .37968 .29974 L p .707 .577 .707 r
F P
0 g
s
.40938 .31004 m .39445 .81009 L .4332 .81761 L p .707 .577 .707 r
F P
0 g
s
.25341 .7227 m .24755 .66682 L .21655 .66827 L p .707 .577 .707 r
F P
0 g
s
.24755 .66682 m .25341 .7227 L .28509 .71891 L p .707 .577 .707 r
F P
0 g
s
.28509 .71891 m .27923 .66303 L .24755 .66682 L p .707 .577 .707 r
F P
0 g
s
.27923 .66303 m .28509 .71891 L .31435 .71313 L p .707 .577 .707 r
F P
0 g
s
.31435 .71313 m .30848 .65725 L .27923 .66303 L p .707 .577 .707 r
F P
0 g
s
.69439 .71273 m .70575 .74907 L .69424 .74823 L p .707 .577 .707 r
F P
0 g
s
.69424 .74823 m .68288 .71189 L .69439 .71273 L p .707 .577 .707 r
F P
0 g
s
.22242 .72415 m .21655 .66827 L .18927 .66723 L p .707 .577 .707 r
F P
0 g
s
.21655 .66827 m .22242 .72415 L .25341 .7227 L p .707 .577 .707 r
F P
0 g
s
.68364 .63169 m .6895 .68756 L .6686 .68413 L p .707 .577 .707 r
F P
0 g
s
.6686 .68413 m .66274 .62825 L .68364 .63169 L p .707 .577 .707 r
F P
0 g
s
.30848 .65725 m .31435 .71313 L .33832 .70594 L p .707 .577 .707 r
F P
0 g
s
.33832 .70594 m .33246 .65006 L .30848 .65725 L p .707 .577 .707 r
F P
0 g
s
.63546 .62721 m .64132 .68308 L .61032 .68453 L p .707 .577 .707 r
F P
0 g
s
.61032 .68453 m .60446 .62865 L .63546 .62721 L p .707 .577 .707 r
F P
0 g
s
.63727 .71975 m .64863 .7561 L .61898 .76404 L p .707 .577 .707 r
F P
0 g
s
.61898 .76404 m .60762 .72769 L .63727 .71975 L p .707 .577 .707 r
F P
0 g
s
.61246 .31048 m .59753 .81053 L .62063 .80034 L p .707 .577 .707 r
F P
0 g
s
.62063 .80034 m .63556 .30029 L .61246 .31048 L p .707 .577 .707 r
F P
0 g
s
.25938 .76389 m .24801 .72754 L .21837 .73548 L p .707 .577 .707 r
F P
0 g
s
.24801 .72754 m .25938 .76389 L .28984 .75424 L p .707 .577 .707 r
F P
0 g
s
.28984 .75424 m .27848 .71789 L .24801 .72754 L p .707 .577 .707 r
F P
0 g
s
.27848 .71789 m .28984 .75424 L .31813 .74382 L p .707 .577 .707 r
F P
0 g
s
.31813 .74382 m .30677 .70747 L .27848 .71789 L p .707 .577 .707 r
F P
0 g
s
.51136 .87629 m .50549 .85816 L .51283 .85141 L p .707 .577 .707 r
F P
0 g
s
.18927 .66723 m .19513 .7231 L .22242 .72415 L p .707 .577 .707 r
F P
0 g
s
.21837 .73548 m .22973 .77183 L .25938 .76389 L p .707 .577 .707 r
F P
0 g
s
.51283 .85141 m .5187 .86953 L .51136 .87629 L p .707 .577 .707 r
F P
0 g
s
.19513 .7231 m .18927 .66723 L .16838 .66379 L p .707 .577 .707 r
F P
0 g
s
.69721 .7953 m .70308 .81343 L .69165 .81283 L p .707 .577 .707 r
F P
0 g
s
.69165 .81283 m .68578 .7947 L .69721 .7953 L p .707 .577 .707 r
F P
0 g
s
.22973 .77183 m .21837 .73548 L .21451 .73629 L p .707 .577 .707 r
F P
0 g
s
.22973 .77183 m .21451 .73629 L .22441 .76743 L .707 .577 .707 r
F
.22566 .77135 m .22147 .77253 L p .22647 .77392 L F P
0 g
s
.22147 .77253 m .22734 .79065 L .23143 .78951 L p .707 .577 .707 r
F P
0 g
s
.22647 .77392 m .22147 .77253 L .23143 .78951 L .707 .577 .707 r
F
.22734 .79065 m .22147 .77253 L .19564 .77831 L p F P
0 g
s
.19243 .74093 m .20379 .77728 L .22605 .7726 L p .707 .577 .707 r
F P
0 g
s
.22605 .7726 m .22973 .77183 L p .22441 .76743 L .707 .577 .707 r
F P
0 g
s
.22441 .76743 m .19243 .74093 L .22605 .7726 L .707 .577 .707 r
F
.23143 .78951 m .25688 .78238 L p .22647 .77392 L F P
0 g
s
.25688 .78238 m .25101 .76425 L .22566 .77135 L p .707 .577 .707 r
F P
0 g
s
.25688 .78238 m .22566 .77135 L .22647 .77392 L .707 .577 .707 r
F
.21451 .73629 m .19243 .74093 L p .22441 .76743 L F P
0 g
s
.25101 .76425 m .25688 .78238 L .28725 .77242 L p .707 .577 .707 r
F P
0 g
s
.28725 .77242 m .28137 .75429 L .25101 .76425 L p .707 .577 .707 r
F P
0 g
s
.28137 .75429 m .28725 .77242 L .31546 .76176 L p .707 .577 .707 r
F P
0 g
s
.31546 .76176 m .30959 .74363 L .28137 .75429 L p .707 .577 .707 r
F P
0 g
s
.33246 .65006 m .33832 .70594 L .35466 .69804 L p .707 .577 .707 r
F P
0 g
s
.34625 .68837 m .35761 .72472 L .35922 .72323 L p .707 .577 .707 r
F P
0 g
s
.35922 .72323 m .36493 .71791 L p .35822 .7073 L .707 .577 .707 r
F P
0 g
s
.35822 .7073 m .34625 .68837 L .35922 .72323 L .707 .577 .707 r
F
.36191 .28766 m .35783 .27499 L p .35109 .59356 L F P
0 g
s
.35466 .69804 m .3488 .64217 L .33246 .65006 L p .707 .577 .707 r
F P
0 g
s
.33012 .6973 m .34148 .73365 L .35761 .72472 L p .707 .577 .707 r
F P
0 g
s
.35761 .72472 m .34625 .68837 L .33012 .6973 L p .707 .577 .707 r
F P
0 g
s
.30677 .70747 m .31813 .74382 L .34148 .73365 L p .707 .577 .707 r
F P
0 g
s
.33289 .7333 m .33876 .75143 L .35488 .74245 L p .707 .577 .707 r
F P
0 g
s
.34148 .73365 m .33012 .6973 L .30677 .70747 L p .707 .577 .707 r
F P
0 g
s
.35488 .74245 m .349 .72433 L .33289 .7333 L p .707 .577 .707 r
F P
0 g
s
.3488 .64217 m .35466 .69804 L .36177 .69021 L p .707 .577 .707 r
F P
0 g
s
.36177 .69021 m .35591 .63433 L .3488 .64217 L p .707 .577 .707 r
F P
0 g
s
.36493 .71791 m .35357 .68157 L .34625 .68837 L p .707 .577 .707 r
F P
0 g
s
.33987 .6767 m .35138 .67755 L p .35124 .71174 L .707 .577 .707 r
F P
0 g
s
.34063 .62184 m .34649 .67772 L .33605 .676 L p .707 .577 .707 r
F P
0 g
s
.33605 .676 m .32559 .67428 L p .32951 .66061 L .707 .577 .707 r
F P
0 g
s
.32951 .66061 m .34063 .62184 L .33605 .676 L .707 .577 .707 r
F
.35124 .71191 m .35101 .7112 L .35124 .71174 L F
.35101 .7112 m .33987 .6767 L .35124 .71174 L F
.35124 .71305 m .35113 .71273 L p .35124 .71191 L F P
0 g
s
.35113 .71273 m .33987 .6767 L p .35124 .71191 L .707 .577 .707 r
F P
0 g
s
.35309 .62733 m .3555 .65032 L p .34649 .67772 L .707 .577 .707 r
F P
0 g
s
.35138 .67755 m .35357 .68157 L p .36249 .71302 L .707 .577 .707 r
F P
0 g
s
.36189 .71118 m .35138 .67755 L p .36249 .71302 L .707 .577 .707 r
F P
0 g
s
.35138 .67755 m .36274 .71389 L .35124 .71305 L p .707 .577 .707 r
F P
0 g
s
.3535 .6808 m .35172 .68002 L p .3555 .65032 L .707 .577 .707 r
F P
0 g
s
.35172 .68002 m .34649 .67772 L p .34874 .67089 L .707 .577 .707 r
F P
0 g
s
.34874 .67089 m .3555 .65032 L .35172 .68002 L .707 .577 .707 r
F
.36274 .71389 m .36189 .71118 L p .36249 .71302 L F P
0 g
s
.34649 .67772 m .34063 .62184 L .35309 .62733 L p .707 .577 .707 r
F P
0 g
s
.349 .72433 m .35488 .74245 L .36222 .7357 L p .707 .577 .707 r
F P
0 g
s
.36222 .7357 m .35635 .71757 L .349 .72433 L p .707 .577 .707 r
F P
0 g
s
.34864 .73124 m .34277 .71311 L .35345 .71367 L p .707 .577 .707 r
F P
0 g
s
.35345 .71367 m .3542 .71371 L p .35291 .71778 L .707 .577 .707 r
F P
0 g
s
.34864 .73124 m .35345 .71367 L .35291 .71778 L .707 .577 .707 r
F
.34742 .77317 m .34794 .75556 L p .34723 .776 L F P
0 g
s
.3542 .71371 m .36007 .73183 L .34864 .73124 L p .707 .577 .707 r
F P
0 g
s
.33876 .75143 m .33289 .7333 L .30959 .74363 L p .707 .577 .707 r
F P
0 g
s
.34277 .71311 m .34864 .73124 L .32906 .73396 L p .707 .577 .707 r
F P
0 g
s
.32906 .73396 m .32319 .71583 L .34277 .71311 L p .707 .577 .707 r
F P
0 g
s
.33987 .6767 m .35113 .71273 L p .33155 .71548 L .707 .577 .707 r
F P
0 g
s
.35113 .71273 m .35124 .71305 L .35111 .71307 L p .707 .577 .707 r
F P
0 g
s
.35111 .71307 m .33155 .71548 L p .35113 .71273 L .707 .577 .707 r
F P
0 g
s
.35783 .27499 m .3429 .77504 L .34675 .78698 L p .707 .577 .707 r
F P
0 g
s
.34675 .78698 m .34698 .78771 L p .34714 .78036 L .707 .577 .707 r
F P
0 g
s
.34714 .78036 m .35783 .27499 L .34675 .78698 L .707 .577 .707 r
F
.34794 .75556 m .35223 .61181 L p .34782 .75644 L F P
0 g
s
.34794 .75556 m .34782 .75644 L .34723 .776 L .707 .577 .707 r
F
.34806 .73673 m .35223 .61181 L .35109 .59356 L F
.34723 .776 m .34854 .73298 L .34806 .73673 L F
.34854 .73298 m .35223 .61181 L .34806 .73673 L F
.3555 .65032 m .35895 .68321 L .3535 .6808 L p F P
0 g
s
.34698 .78771 m .34742 .77317 L p .34723 .776 L .707 .577 .707 r
F P
0 g
s
.35223 .61181 m .36191 .28766 L p .35109 .59356 L .707 .577 .707 r
F P
0 g
s
.35357 .68157 m .36493 .71791 L .36274 .71389 L p .707 .577 .707 r
F P
0 g
s
.36474 .79979 m .37968 .29974 L .36191 .28766 L p .707 .577 .707 r
F P
0 g
s
.37968 .29974 m .36474 .79979 L .39445 .81009 L p .707 .577 .707 r
F P
0 g
s
.68288 .71189 m .69424 .74823 L .67456 .75066 L p .707 .577 .707 r
F P
0 g
s
.67456 .75066 m .6632 .71431 L .68288 .71189 L p .707 .577 .707 r
F P
0 g
s
.66274 .62825 m .6686 .68413 L .64132 .68308 L p .707 .577 .707 r
F P
0 g
s
.64132 .68308 m .63546 .62721 L .66274 .62825 L p .707 .577 .707 r
F P
0 g
s
.30959 .74363 m .31546 .76176 L .33876 .75143 L p .707 .577 .707 r
F P
0 g
s
.19564 .77831 m .20151 .79644 L .22734 .79065 L p .707 .577 .707 r
F P
0 g
s
.16838 .66379 m .17424 .71967 L .19513 .7231 L p .707 .577 .707 r
F P
0 g
s
.20379 .77728 m .19243 .74093 L .17275 .74335 L p .707 .577 .707 r
F P
0 g
s
.17424 .71967 m .16838 .66379 L .15591 .6583 L p .707 .577 .707 r
F P
0 g
s
.17275 .74335 m .18411 .7797 L .20379 .77728 L p .707 .577 .707 r
F P
0 g
s
.5187 .86953 m .51283 .85141 L .52894 .84243 L p .707 .577 .707 r
F P
0 g
s
.63556 .30029 m .62063 .80034 L .63064 .78832 L p .707 .577 .707 r
F P
0 g
s
.63064 .78832 m .64557 .28827 L .63556 .30029 L p .707 .577 .707 r
F P
0 g
s
.52894 .84243 m .53481 .86055 L .5187 .86953 L p .707 .577 .707 r
F P
0 g
s
.20151 .79644 m .19564 .77831 L .17605 .78103 L p .707 .577 .707 r
F P
0 g
s
.68578 .7947 m .69165 .81283 L .67207 .81555 L p .707 .577 .707 r
F P
0 g
s
.67207 .81555 m .6662 .79742 L .68578 .7947 L p .707 .577 .707 r
F P
0 g
s
.17605 .78103 m .18192 .79916 L .20151 .79644 L p .707 .577 .707 r
F P
0 g
s
.6632 .71431 m .67456 .75066 L .64863 .7561 L p .707 .577 .707 r
F P
0 g
s
.64863 .7561 m .63727 .71975 L .6632 .71431 L p .707 .577 .707 r
F P
0 g
s
.15591 .6583 m .16177 .71418 L .17424 .71967 L p .707 .577 .707 r
F P
0 g
s
.35591 .63433 m .36177 .69021 L .35895 .68321 L p .707 .577 .707 r
F P
0 g
s
.35895 .68321 m .35309 .62733 L .35591 .63433 L p .707 .577 .707 r
F P
0 g
s
.35635 .71757 m .36222 .7357 L .36007 .73183 L p .707 .577 .707 r
F P
0 g
s
.36007 .73183 m .3542 .71371 L .35635 .71757 L p .707 .577 .707 r
F P
0 g
s
.36191 .28766 m .34698 .78771 L .36474 .79979 L p .707 .577 .707 r
F P
0 g
s
.18411 .7797 m .17275 .74335 L .16125 .74251 L p .707 .577 .707 r
F P
0 g
s
.16125 .74251 m .17261 .77886 L .18411 .7797 L p .707 .577 .707 r
F P
0 g
s
.53481 .86055 m .52894 .84243 L .55224 .8321 L p .707 .577 .707 r
F P
0 g
s
.16177 .71418 m .15591 .6583 L .15309 .6513 L p .707 .577 .707 r
F P
0 g
s
.18192 .79916 m .17605 .78103 L .16463 .78043 L p .707 .577 .707 r
F P
0 g
s
.55224 .8321 m .55812 .85023 L .53481 .86055 L p .707 .577 .707 r
F P
0 g
s
.6662 .79742 m .67207 .81555 L .64624 .82133 L p .707 .577 .707 r
F P
0 g
s
.64624 .82133 m .64037 .80321 L .6662 .79742 L p .707 .577 .707 r
F P
0 g
s
.16463 .78043 m .1705 .79856 L .18192 .79916 L p .707 .577 .707 r
F P
0 g
s
.15309 .6513 m .15896 .70718 L .16177 .71418 L p .707 .577 .707 r
F P
0 g
s
.64557 .28827 m .63064 .78832 L .62656 .77565 L p .707 .577 .707 r
F P
0 g
s
.62656 .77565 m .64149 .2756 L .64557 .28827 L p .707 .577 .707 r
F P
0 g
s
.55812 .85023 m .55224 .8321 L .58046 .82144 L p .707 .577 .707 r
F P
0 g
s
.64037 .80321 m .64624 .82133 L .6167 .82961 L p .707 .577 .707 r
F P
0 g
s
.6167 .82961 m .61083 .81148 L .64037 .80321 L p .707 .577 .707 r
F P
0 g
s
.58046 .82144 m .58633 .83956 L .55812 .85023 L p .707 .577 .707 r
F P
0 g
s
.17261 .77886 m .16125 .74251 L .15905 .73849 L p .707 .577 .707 r
F P
0 g
s
.15905 .73849 m .17041 .77484 L .17261 .77886 L p .707 .577 .707 r
F P
0 g
s
.58633 .83956 m .58046 .82144 L .61083 .81148 L p .707 .577 .707 r
F P
0 g
s
.61083 .81148 m .6167 .82961 L .58633 .83956 L p .707 .577 .707 r
F P
0 g
s
.1705 .79856 m .16463 .78043 L .16248 .77657 L p .707 .577 .707 r
F P
0 g
s
.15896 .70718 m .15309 .6513 L .1602 .64346 L p .707 .577 .707 r
F P
0 g
s
.16248 .77657 m .16835 .7947 L .1705 .79856 L p .707 .577 .707 r
F P
0 g
s
.3429 .77504 m .35783 .27499 L .36783 .26297 L p .707 .577 .707 r
F P
0 g
s
.1602 .64346 m .16607 .69934 L .15896 .70718 L p .707 .577 .707 r
F P
0 g
s
.17041 .77484 m .15905 .73849 L .16637 .73168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16637 .73168 m .17773 .76803 L .17041 .77484 L p .707 .577 .707 r
F P
0 g
s
.64149 .2756 m .62656 .77565 L .60879 .76357 L p .707 .577 .707 r
F P
0 g
s
.60879 .76357 m .62372 .26352 L .64149 .2756 L p .707 .577 .707 r
F P
0 g
s
.16607 .69934 m .1602 .64346 L .17655 .63557 L p .707 .577 .707 r
F P
0 g
s
.16835 .7947 m .16248 .77657 L .16982 .76982 L p .707 .577 .707 r
F P
0 g
s
.16982 .76982 m .17569 .78794 L .16835 .7947 L p .707 .577 .707 r
F P
0 g
s
.32559 .67428 m .31973 .61841 L .34063 .62184 L p .707 .577 .707 r
F P
0 g
s
.17655 .63557 m .18241 .69144 L .16607 .69934 L p .707 .577 .707 r
F P
0 g
s
.3529 .76302 m .36783 .26297 L .39094 .25278 L p .707 .577 .707 r
F P
0 g
s
.36783 .26297 m .3529 .76302 L .3429 .77504 L p .707 .577 .707 r
F P
0 g
s
.17773 .76803 m .16637 .73168 L .1825 .72276 L p .707 .577 .707 r
F P
0 g
s
.18241 .69144 m .17655 .63557 L .20052 .62838 L p .707 .577 .707 r
F P
0 g
s
.33155 .71548 m .32019 .67913 L .33987 .6767 L p .707 .577 .707 r
F P
0 g
s
.1825 .72276 m .19386 .75911 L .17773 .76803 L p .707 .577 .707 r
F P
0 g
s
.17569 .78794 m .16982 .76982 L .18593 .76084 L p .707 .577 .707 r
F P
0 g
s
.18593 .76084 m .1918 .77896 L .17569 .78794 L p .707 .577 .707 r
F P
0 g
s
.31973 .61841 m .32559 .67428 L .29831 .67324 L p .707 .577 .707 r
F P
0 g
s
.29831 .67324 m .29245 .61736 L .31973 .61841 L p .707 .577 .707 r
F P
0 g
s
.62372 .26352 m .60879 .76357 L .57908 .75327 L p .707 .577 .707 r
F P
0 g
s
.57908 .75327 m .59401 .25322 L .62372 .26352 L p .707 .577 .707 r
F P
0 g
s
.20052 .62838 m .20638 .68426 L .18241 .69144 L p .707 .577 .707 r
F P
0 g
s
.20638 .68426 m .20052 .62838 L .22977 .6226 L p .707 .577 .707 r
F P
0 g
s
.19386 .75911 m .1825 .72276 L .20585 .71259 L p .707 .577 .707 r
F P
0 g
s
.39094 .25278 m .37601 .75283 L .3529 .76302 L p .707 .577 .707 r
F P
0 g
s
.37601 .75283 m .39094 .25278 L .42489 .24541 L p .707 .577 .707 r
F P
0 g
s
.29245 .61736 m .29831 .67324 L .26731 .67468 L p .707 .577 .707 r
F P
0 g
s
.26731 .67468 m .26145 .61881 L .29245 .61736 L p .707 .577 .707 r
F P
0 g
s
.32319 .71583 m .32906 .73396 L .30323 .73974 L p .707 .577 .707 r
F P
0 g
s
.30142 .72205 m .27597 .72886 L p .29156 .6911 L .707 .577 .707 r
F P
0 g
s
.30323 .73974 m .29736 .72162 L .30102 .7208 L p .707 .577 .707 r
F P
0 g
s
.30102 .7208 m .32319 .71583 L p .306 .73642 L .707 .577 .707 r
F P
0 g
s
.30323 .73974 m .30102 .7208 L .306 .73642 L .707 .577 .707 r
F
.29426 .68457 m .30562 .72092 L .30142 .72205 L p F P
0 g
s
.29156 .6911 m .29426 .68457 L .30142 .72205 L .707 .577 .707 r
F
.32019 .67913 m .33155 .71548 L .30562 .72092 L p F P
0 g
s
.30562 .72092 m .29426 .68457 L .32019 .67913 L p .707 .577 .707 r
F P
0 g
s
.73363 .64051 m .72776 .58463 L .69677 .58608 L p .707 .577 .707 r
F P
0 g
s
.72776 .58463 m .73363 .64051 L .7653 .63671 L p .707 .577 .707 r
F P
0 g
s
.7653 .63671 m .75944 .58084 L .72776 .58463 L p .707 .577 .707 r
F P
0 g
s
.20585 .71259 m .21721 .74894 L .19386 .75911 L p .707 .577 .707 r
F P
0 g
s
.75944 .58084 m .7653 .63671 L .79456 .63094 L p .707 .577 .707 r
F P
0 g
s
.79456 .63094 m .7887 .57506 L .75944 .58084 L p .707 .577 .707 r
F P
0 g
s
.1918 .77896 m .18593 .76084 L .20924 .75051 L p .707 .577 .707 r
F P
0 g
s
.23564 .67848 m .22977 .6226 L .26145 .61881 L p .707 .577 .707 r
F P
0 g
s
.22977 .6226 m .23564 .67848 L .20638 .68426 L p .707 .577 .707 r
F P
0 g
s
.26145 .61881 m .26731 .67468 L .23564 .67848 L p .707 .577 .707 r
F P
0 g
s
.20924 .75051 m .21511 .76864 L .1918 .77896 L p .707 .577 .707 r
F P
0 g
s
.70263 .64196 m .69677 .58608 L .66949 .58503 L p .707 .577 .707 r
F P
0 g
s
.69677 .58608 m .70263 .64196 L .73363 .64051 L p .707 .577 .707 r
F P
0 g
s
.7887 .57506 m .79456 .63094 L .81853 .62375 L p .707 .577 .707 r
F P
0 g
s
.81853 .62375 m .81267 .56787 L .7887 .57506 L p .707 .577 .707 r
F P
0 g
s
.21721 .74894 m .20585 .71259 L .23415 .70216 L p .707 .577 .707 r
F P
0 g
s
.27597 .72886 m .26461 .69251 L .29426 .68457 L p .707 .577 .707 r
F P
0 g
s
.59401 .25322 m .57908 .75327 L .54034 .74574 L p .707 .577 .707 r
F P
0 g
s
.54034 .74574 m .55527 .24569 L .59401 .25322 L p .707 .577 .707 r
F P
0 g
s
.23415 .70216 m .24551 .73851 L .21721 .74894 L p .707 .577 .707 r
F P
0 g
s
.66949 .58503 m .67535 .64091 L .70263 .64196 L p .707 .577 .707 r
F P
0 g
s
.73959 .70704 m .72823 .67069 L .69858 .67862 L p .707 .577 .707 r
F P
0 g
s
.72823 .67069 m .73959 .70704 L .77005 .69738 L p .707 .577 .707 r
F P
0 g
s
.77005 .69738 m .75869 .66103 L .72823 .67069 L p .707 .577 .707 r
F P
0 g
s
.21511 .76864 m .20924 .75051 L .23745 .73985 L p .707 .577 .707 r
F P
0 g
s
.67535 .64091 m .66949 .58503 L .64859 .5816 L p .707 .577 .707 r
F P
0 g
s
.75869 .66103 m .77005 .69738 L .79834 .68696 L p .707 .577 .707 r
F P
0 g
s
.79834 .68696 m .78698 .65061 L .75869 .66103 L p .707 .577 .707 r
F P
0 g
s
.24551 .73851 m .23415 .70216 L .26461 .69251 L p .707 .577 .707 r
F P
0 g
s
.26461 .69251 m .27597 .72886 L .24551 .73851 L p .707 .577 .707 r
F P
0 g
s
.29736 .72162 m .30323 .73974 L .27369 .74802 L p .707 .577 .707 r
F P
0 g
s
.27369 .74802 m .26782 .72989 L .29736 .72162 L p .707 .577 .707 r
F P
0 g
s
.23745 .73985 m .24332 .75797 L .21511 .76864 L p .707 .577 .707 r
F P
0 g
s
.40996 .74546 m .42489 .24541 L .46636 .24159 L p .707 .577 .707 r
F P
0 g
s
.42489 .24541 m .41024 .73593 L p .37601 .75283 L .707 .577 .707 r
F P
0 g
s
.46636 .24159 m .45142 .74164 L .40996 .74546 L p .707 .577 .707 r
F P
0 g
s
.38522 .63551 m .39658 .67186 L .42685 .66226 L p .707 .577 .707 r
F P
0 g
s
.42685 .66226 m .42704 .6622 L p .42689 .66211 L .707 .577 .707 r
F P
0 g
s
.42689 .66211 m .38522 .63551 L .42685 .66226 L .707 .577 .707 r
F
.41024 .73593 m .40996 .74546 L .408 .74589 L p F P
0 g
s
.408 .74589 m .37601 .75283 L p .41024 .73593 L .707 .577 .707 r
F P
0 g
s
.69858 .67862 m .70994 .71497 L .73959 .70704 L p .707 .577 .707 r
F P
0 g
s
.70994 .71497 m .69858 .67862 L .67264 .68407 L p .707 .577 .707 r
F P
0 g
s
.81267 .56787 m .81853 .62375 L .83487 .61585 L p .707 .577 .707 r
F P
0 g
s
.83487 .61585 m .82901 .55997 L .81267 .56787 L p .707 .577 .707 r
F P
0 g
s
.24332 .75797 m .23745 .73985 L .26782 .72989 L p .707 .577 .707 r
F P
0 g
s
.78698 .65061 m .79834 .68696 L .8217 .67679 L p .707 .577 .707 r
F P
0 g
s
.8217 .67679 m .81033 .64044 L .78698 .65061 L p .707 .577 .707 r
F P
0 g
s
.26782 .72989 m .27369 .74802 L .24332 .75797 L p .707 .577 .707 r
F P
0 g
s
.64859 .5816 m .65445 .63748 L .67535 .64091 L p .707 .577 .707 r
F P
0 g
s
.67264 .68407 m .684 .72042 L .70994 .71497 L p .707 .577 .707 r
F P
0 g
s
.55527 .24569 m .54034 .74574 L .49635 .74174 L p .707 .577 .707 r
F P
0 g
s
.49635 .74174 m .51128 .24169 L .55527 .24569 L p .707 .577 .707 r
F P
0 g
s
.45325 .68066 m .46636 .24159 L p .45809 .68597 L .707 .577 .707 r
F P
0 g
s
.38475 .57479 m .39062 .63066 L .42229 .62687 L p .707 .577 .707 r
F P
0 g
s
.41568 .62585 m .42216 .64658 L p .45533 .65178 L .707 .577 .707 r
F P
0 g
s
.42216 .64658 m .42704 .6622 L .43405 .65962 L p .707 .577 .707 r
F P
0 g
s
.43405 .65962 m .45533 .65178 L p .42216 .64658 L .707 .577 .707 r
F P
0 g
s
.46636 .24159 m .51128 .24169 L p .45809 .68597 L .707 .577 .707 r
F P
0 g
s
.45142 .74164 m .45325 .68066 L p .45809 .68597 L .707 .577 .707 r
F P
0 g
s
.73709 .77193 m .73122 .7538 L .70168 .76208 L p .707 .577 .707 r
F P
0 g
s
.73122 .7538 m .73709 .77193 L .76746 .76197 L p .707 .577 .707 r
F P
0 g
s
.76746 .76197 m .76159 .74385 L .73122 .7538 L p .707 .577 .707 r
F P
0 g
s
.76159 .74385 m .76746 .76197 L .79567 .75131 L p .707 .577 .707 r
F P
0 g
s
.79567 .75131 m .7898 .73318 L .76159 .74385 L p .707 .577 .707 r
F P
0 g
s
.65445 .63748 m .64859 .5816 L .63612 .57611 L p .707 .577 .707 r
F P
0 g
s
.70168 .76208 m .70755 .78021 L .73709 .77193 L p .707 .577 .707 r
F P
0 g
s
.51128 .24169 m .49635 .74174 L .45142 .74164 L p .707 .577 .707 r
F P
0 g
s
.684 .72042 m .67264 .68407 L .65296 .68649 L p .707 .577 .707 r
F P
0 g
s
.81033 .64044 m .8217 .67679 L .83782 .66786 L p .707 .577 .707 r
F P
0 g
s
.83782 .66786 m .82646 .63151 L .81033 .64044 L p .707 .577 .707 r
F P
0 g
s
.70755 .78021 m .70168 .76208 L .67585 .76786 L p .707 .577 .707 r
F P
0 g
s
.65296 .68649 m .66432 .72284 L .684 .72042 L p .707 .577 .707 r
F P
0 g
s
.7898 .73318 m .79567 .75131 L .81898 .74098 L p .707 .577 .707 r
F P
0 g
s
.81898 .74098 m .81311 .72286 L .7898 .73318 L p .707 .577 .707 r
F P
0 g
s
.67585 .76786 m .68172 .78599 L .70755 .78021 L p .707 .577 .707 r
F P
0 g
s
.82901 .55997 m .83487 .61585 L .84198 .60802 L p .707 .577 .707 r
F P
0 g
s
.84198 .60802 m .83612 .55214 L .82901 .55997 L p .707 .577 .707 r
F P
0 g
s
.63612 .57611 m .64198 .63199 L .65445 .63748 L p .707 .577 .707 r
F P
0 g
s
.68172 .78599 m .67585 .76786 L .65627 .77059 L p .707 .577 .707 r
F P
0 g
s
.65627 .77059 m .66214 .78871 L .68172 .78599 L p .707 .577 .707 r
F P
0 g
s
.66432 .72284 m .65296 .68649 L .64146 .68565 L p .707 .577 .707 r
F P
0 g
s
.81311 .72286 m .81898 .74098 L .83509 .732 L p .707 .577 .707 r
F P
0 g
s
.83509 .732 m .82922 .71388 L .81311 .72286 L p .707 .577 .707 r
F P
0 g
s
.64198 .63199 m .63612 .57611 L .63331 .56911 L p .707 .577 .707 r
F P
0 g
s
.82646 .63151 m .83782 .66786 L .84515 .66106 L p .707 .577 .707 r
F P
0 g
s
.84515 .66106 m .83379 .62471 L .82646 .63151 L p .707 .577 .707 r
F P
0 g
s
.64146 .68565 m .65282 .722 L .66432 .72284 L p .707 .577 .707 r
F P
0 g
s
.83612 .55214 m .84198 .60802 L .83917 .60101 L p .707 .577 .707 r
F P
0 g
s
.83917 .60101 m .83331 .54514 L .83612 .55214 L p .707 .577 .707 r
F P
0 g
s
.63331 .56911 m .63917 .62498 L .64198 .63199 L p .707 .577 .707 r
F P
0 g
s
.66214 .78871 m .65627 .77059 L .64484 .76999 L p .707 .577 .707 r
F P
0 g
s
.64484 .76999 m .65071 .78811 L .66214 .78871 L p .707 .577 .707 r
F P
0 g
s
.82922 .71388 m .83509 .732 L .84243 .72525 L p .707 .577 .707 r
F P
0 g
s
.84243 .72525 m .83656 .70712 L .82922 .71388 L p .707 .577 .707 r
F P
0 g
s
.65282 .722 m .64146 .68565 L .63926 .68163 L p .707 .577 .707 r
F P
0 g
s
.63917 .62498 m .63331 .56911 L .64042 .56127 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.63926 .68163 m .65062 .71798 L .65282 .722 L p .707 .577 .707 r
F P
0 g
s
.83379 .62471 m .84515 .66106 L .84295 .65704 L p .707 .577 .707 r
F P
0 g
s
.84295 .65704 m .83159 .62069 L .83379 .62471 L p .707 .577 .707 r
F P
0 g
s
.83331 .54514 m .83917 .60101 L .8267 .59553 L p .707 .577 .707 r
F P
0 g
s
.8267 .59553 m .82084 .53965 L .83331 .54514 L p .707 .577 .707 r
F P
0 g
s
.64042 .56127 m .64628 .61715 L .63917 .62498 L p .707 .577 .707 r
F P
0 g
s
.65071 .78811 m .64484 .76999 L .64269 .76612 L p .707 .577 .707 r
F P
0 g
s
.64269 .76612 m .64856 .78425 L .65071 .78811 L p .707 .577 .707 r
F P
0 g
s
.83656 .70712 m .84243 .72525 L .84028 .72139 L p .707 .577 .707 r
F P
0 g
s
.84028 .72139 m .83441 .70326 L .83656 .70712 L p .707 .577 .707 r
F P
0 g
s
.65062 .71798 m .63926 .68163 L .64659 .67483 L p .707 .577 .707 r
F P
0 g
s
.64628 .61715 m .64042 .56127 L .65676 .55337 L p .707 .577 .707 r
F P
0 g
s
.39062 .63066 m .38475 .57479 L .35376 .57623 L p .707 .577 .707 r
F P
0 g
s
.42229 .62687 m .41643 .57099 L .38475 .57479 L p .707 .577 .707 r
F P
0 g
s
.41643 .57099 m .42229 .62687 L .45155 .62109 L p .707 .577 .707 r
F P
0 g
s
.45155 .62109 m .44569 .56521 L .41643 .57099 L p .707 .577 .707 r
F P
0 g
s
.64659 .67483 m .65795 .71118 L .65062 .71798 L p .707 .577 .707 r
F P
0 g
s
.83159 .62069 m .84295 .65704 L .83145 .6562 L p .707 .577 .707 r
F P
0 g
s
.83145 .6562 m .82009 .61985 L .83159 .62069 L p .707 .577 .707 r
F P
0 g
s
.35962 .63211 m .35376 .57623 L .32648 .57519 L p .707 .577 .707 r
F P
0 g
s
.35376 .57623 m .35962 .63211 L .39062 .63066 L p .707 .577 .707 r
F P
0 g
s
.82084 .53965 m .8267 .59553 L .8058 .59209 L p .707 .577 .707 r
F P
0 g
s
.8058 .59209 m .79994 .53621 L .82084 .53965 L p .707 .577 .707 r
F P
0 g
s
.65676 .55337 m .66262 .60925 L .64628 .61715 L p .707 .577 .707 r
F P
0 g
s
.44569 .56521 m .45155 .62109 L .47552 .6139 L p .707 .577 .707 r
F P
0 g
s
.47552 .6139 m .46966 .55803 L .44569 .56521 L p .707 .577 .707 r
F P
0 g
s
.39658 .67186 m .38522 .63551 L .35557 .64344 L p .707 .577 .707 r
F P
0 g
s
.42704 .6622 m .41568 .62585 L .38522 .63551 L p .707 .577 .707 r
F P
0 g
s
.45533 .65178 m .44397 .61543 L .41568 .62585 L p .707 .577 .707 r
F P
0 g
s
.64856 .78425 m .64269 .76612 L .65003 .75937 L p .707 .577 .707 r
F P
0 g
s
.32648 .57519 m .33234 .63106 L .35962 .63211 L p .707 .577 .707 r
F P
0 g
s
.35557 .64344 m .36693 .67979 L .39658 .67186 L p .707 .577 .707 r
F P
0 g
s
.65003 .75937 m .65591 .7775 L .64856 .78425 L p .707 .577 .707 r
F P
0 g
s
.33234 .63106 m .32648 .57519 L .30558 .57175 L p .707 .577 .707 r
F P
0 g
s
.83441 .70326 m .84028 .72139 L .82886 .72079 L p .707 .577 .707 r
F P
0 g
s
.82886 .72079 m .82299 .70266 L .83441 .70326 L p .707 .577 .707 r
F P
0 g
s
.66262 .60925 m .65676 .55337 L .68073 .54619 L p .707 .577 .707 r
F P
0 g
s
.36693 .67979 m .35557 .64344 L .35172 .64425 L p .707 .577 .707 r
F P
0 g
s
.36693 .67979 m .35172 .64425 L .36161 .67539 L .707 .577 .707 r
F
.36286 .67931 m .35867 .68049 L p .36367 .68188 L F P
0 g
s
.35867 .68049 m .36454 .69861 L .36863 .69747 L p .707 .577 .707 r
F P
0 g
s
.36367 .68188 m .35867 .68049 L .36863 .69747 L .707 .577 .707 r
F
.36454 .69861 m .35867 .68049 L .33284 .68627 L p F P
0 g
s
.32963 .64889 m .34099 .68524 L .36326 .68057 L p .707 .577 .707 r
F P
0 g
s
.36326 .68057 m .36693 .67979 L p .36161 .67539 L .707 .577 .707 r
F P
0 g
s
.36161 .67539 m .32963 .64889 L .36326 .68057 L .707 .577 .707 r
F
.36863 .69747 m .39408 .69034 L p .36367 .68188 L F P
0 g
s
.39408 .69034 m .38821 .67221 L .36286 .67931 L p .707 .577 .707 r
F P
0 g
s
.39408 .69034 m .36286 .67931 L .36367 .68188 L .707 .577 .707 r
F
.35172 .64425 m .32963 .64889 L p .36161 .67539 L F P
0 g
s
.38821 .67221 m .39408 .69034 L .42445 .68038 L p .707 .577 .707 r
F P
0 g
s
.42445 .68038 m .41858 .66226 L .38821 .67221 L p .707 .577 .707 r
F P
0 g
s
.41858 .66226 m .42445 .68038 L .45266 .66972 L p .707 .577 .707 r
F P
0 g
s
.45266 .66972 m .44679 .65159 L .41858 .66226 L p .707 .577 .707 r
F P
0 g
s
.65795 .71118 m .64659 .67483 L .66271 .6659 L p .707 .577 .707 r
F P
0 g
s
.44397 .61543 m .45533 .65178 L .47869 .64161 L p .707 .577 .707 r
F P
0 g
s
.47869 .64161 m .46732 .60526 L .44397 .61543 L p .707 .577 .707 r
F P
0 g
s
.82009 .61985 m .83145 .6562 L .81177 .65862 L p .707 .577 .707 r
F P
0 g
s
.81177 .65862 m .80041 .62227 L .82009 .61985 L p .707 .577 .707 r
F P
0 g
s
.66271 .6659 m .67408 .70225 L .65795 .71118 L p .707 .577 .707 r
F P
0 g
s
.46966 .55803 m .47552 .6139 L .49186 .60601 L p .707 .577 .707 r
F P
0 g
s
.49186 .60601 m .486 .55013 L .46966 .55803 L p .707 .577 .707 r
F P
0 g
s
.79994 .53621 m .8058 .59209 L .77852 .59105 L p .707 .577 .707 r
F P
0 g
s
.77852 .59105 m .77266 .53517 L .79994 .53621 L p .707 .577 .707 r
F P
0 g
s
.44679 .65159 m .45266 .66972 L .47597 .65939 L p .707 .577 .707 r
F P
0 g
s
.47597 .65939 m .4701 .64127 L .44679 .65159 L p .707 .577 .707 r
F P
0 g
s
.33284 .68627 m .33871 .7044 L .36454 .69861 L p .707 .577 .707 r
F P
0 g
s
.30558 .57175 m .31144 .62763 L .33234 .63106 L p .707 .577 .707 r
F P
0 g
s
.68073 .54619 m .68659 .60206 L .66262 .60925 L p .707 .577 .707 r
F P
0 g
s
.34099 .68524 m .32963 .64889 L .30995 .65131 L p .707 .577 .707 r
F P
0 g
s
.68659 .60206 m .68073 .54619 L .70999 .54041 L p .707 .577 .707 r
F P
0 g
s
.46732 .60526 m .47869 .64161 L .49481 .63268 L p .707 .577 .707 r
F P
0 g
s
.49481 .63268 m .48345 .59633 L .46732 .60526 L p .707 .577 .707 r
F P
0 g
s
.31144 .62763 m .30558 .57175 L .29311 .56626 L p .707 .577 .707 r
F P
0 g
s
.30995 .65131 m .32131 .68766 L .34099 .68524 L p .707 .577 .707 r
F P
0 g
s
.65591 .7775 m .65003 .75937 L .66615 .75039 L p .707 .577 .707 r
F P
0 g
s
.77266 .53517 m .77852 .59105 L .74753 .59249 L p .707 .577 .707 r
F P
0 g
s
.74753 .59249 m .74166 .53661 L .77266 .53517 L p .707 .577 .707 r
F P
0 g
s
.66615 .75039 m .67202 .76852 L .65591 .7775 L p .707 .577 .707 r
F P
0 g
s
.33871 .7044 m .33284 .68627 L .31326 .689 L p .707 .577 .707 r
F P
0 g
s
.67408 .70225 m .66271 .6659 L .68607 .65573 L p .707 .577 .707 r
F P
0 g
s
.82299 .70266 m .82886 .72079 L .80927 .72351 L p .707 .577 .707 r
F P
0 g
s
.80927 .72351 m .8034 .70538 L .82299 .70266 L p .707 .577 .707 r
F P
0 g
s
.31326 .689 m .31913 .70712 L .33871 .7044 L p .707 .577 .707 r
F P
0 g
s
.4701 .64127 m .47597 .65939 L .49208 .65041 L p .707 .577 .707 r
F P
0 g
s
.49208 .65041 m .48621 .63229 L .4701 .64127 L p .707 .577 .707 r
F P
0 g
s
.71585 .59629 m .70999 .54041 L .74166 .53661 L p .707 .577 .707 r
F P
0 g
s
.70999 .54041 m .71585 .59629 L .68659 .60206 L p .707 .577 .707 r
F P
0 g
s
.80041 .62227 m .81177 .65862 L .78583 .66406 L p .707 .577 .707 r
F P
0 g
s
.78583 .66406 m .77447 .62771 L .80041 .62227 L p .707 .577 .707 r
F P
0 g
s
.74166 .53661 m .74753 .59249 L .71585 .59629 L p .707 .577 .707 r
F P
0 g
s
.68607 .65573 m .69743 .69208 L .67408 .70225 L p .707 .577 .707 r
F P
0 g
s
.486 .55013 m .49186 .60601 L .49897 .59817 L p .707 .577 .707 r
F P
0 g
s
.49897 .59817 m .49311 .54229 L .486 .55013 L p .707 .577 .707 r
F P
0 g
s
.29311 .56626 m .29897 .62214 L .31144 .62763 L p .707 .577 .707 r
F P
0 g
s
.32131 .68766 m .30995 .65131 L .29845 .65047 L p .707 .577 .707 r
F P
0 g
s
.69743 .69208 m .68607 .65573 L .71436 .64531 L p .707 .577 .707 r
F P
0 g
s
.48345 .59633 m .49481 .63268 L .50214 .62588 L p .707 .577 .707 r
F P
0 g
s
.50214 .62588 m .49078 .58953 L .48345 .59633 L p .707 .577 .707 r
F P
0 g
s
.29845 .65047 m .30981 .68682 L .32131 .68766 L p .707 .577 .707 r
F P
0 g
s
.77447 .62771 m .78583 .66406 L .75618 .672 L p .707 .577 .707 r
F P
0 g
s
.75618 .672 m .74482 .63565 L .77447 .62771 L p .707 .577 .707 r
F P
0 g
s
.67202 .76852 m .66615 .75039 L .68945 .74006 L p .707 .577 .707 r
F P
0 g
s
.29897 .62214 m .29311 .56626 L .2903 .55926 L p .707 .577 .707 r
F P
0 g
s
.31913 .70712 m .31326 .689 L .30183 .6884 L p .707 .577 .707 r
F P
0 g
s
.68945 .74006 m .69532 .75819 L .67202 .76852 L p .707 .577 .707 r
F P
0 g
s
.71436 .64531 m .72572 .68166 L .69743 .69208 L p .707 .577 .707 r
F P
0 g
s
.8034 .70538 m .80927 .72351 L .78344 .7293 L p .707 .577 .707 r
F P
0 g
s
.78344 .7293 m .77757 .71117 L .8034 .70538 L p .707 .577 .707 r
F P
0 g
s
.30183 .6884 m .3077 .70652 L .31913 .70712 L p .707 .577 .707 r
F P
0 g
s
.48621 .63229 m .49208 .65041 L .49942 .64366 L p .707 .577 .707 r
F P
0 g
s
.49942 .64366 m .49355 .62553 L .48621 .63229 L p .707 .577 .707 r
F P
0 g
s
.72572 .68166 m .71436 .64531 L .74482 .63565 L p .707 .577 .707 r
F P
0 g
s
.74482 .63565 m .75618 .672 L .72572 .68166 L p .707 .577 .707 r
F P
0 g
s
.49311 .54229 m .49897 .59817 L .49616 .59117 L p .707 .577 .707 r
F P
0 g
s
.49616 .59117 m .4903 .53529 L .49311 .54229 L p .707 .577 .707 r
F P
0 g
s
.2903 .55926 m .29616 .61514 L .29897 .62214 L p .707 .577 .707 r
F P
0 g
s
.69532 .75819 m .68945 .74006 L .71767 .7294 L p .707 .577 .707 r
F P
0 g
s
.77757 .71117 m .78344 .7293 L .7539 .73757 L p .707 .577 .707 r
F P
0 g
s
.7539 .73757 m .74803 .71944 L .77757 .71117 L p .707 .577 .707 r
F P
0 g
s
.71767 .7294 m .72354 .74753 L .69532 .75819 L p .707 .577 .707 r
F P
0 g
s
.30981 .68682 m .29845 .65047 L .29625 .64645 L p .707 .577 .707 r
F P
0 g
s
.29625 .64645 m .30761 .6828 L .30981 .68682 L p .707 .577 .707 r
F P
0 g
s
.49078 .58953 m .50214 .62588 L .49994 .62186 L p .707 .577 .707 r
F P
0 g
s
.48858 .58551 m .49078 .58953 L p .49969 .62098 L .707 .577 .707 r
F P
0 g
s
.49909 .61914 m .48858 .58551 L p .49969 .62098 L .707 .577 .707 r
F P
0 g
s
.48858 .58551 m .49994 .62186 L .48844 .62102 L p .707 .577 .707 r
F P
0 g
s
.4903 .53529 m .49616 .59117 L .48892 .58798 L p .707 .577 .707 r
F P
0 g
s
.47708 .58467 m .48858 .58551 L p .48844 .6197 L .707 .577 .707 r
F P
0 g
s
.48844 .62102 m .48687 .616 L p .48844 .6197 L .707 .577 .707 r
F P
0 g
s
.48687 .616 m .47708 .58467 L p .48844 .6197 L .707 .577 .707 r
F P
0 g
s
.47783 .5298 m .48369 .58568 L .47325 .58396 L p .707 .577 .707 r
F P
0 g
s
.47325 .58396 m .46279 .58224 L p .46671 .56857 L .707 .577 .707 r
F P
0 g
s
.46671 .56857 m .47783 .5298 L .47325 .58396 L .707 .577 .707 r
F
.48892 .58798 m .48369 .58568 L p .48497 .57589 L F P
0 g
s
.48497 .57589 m .4903 .53529 L .48892 .58798 L .707 .577 .707 r
F
.49994 .62186 m .49909 .61914 L p .49969 .62098 L F P
0 g
s
.72354 .74753 m .71767 .7294 L .74803 .71944 L p .707 .577 .707 r
F P
0 g
s
.74803 .71944 m .7539 .73757 L .72354 .74753 L p .707 .577 .707 r
F P
0 g
s
.3077 .70652 m .30183 .6884 L .29968 .68453 L p .707 .577 .707 r
F P
0 g
s
.29616 .61514 m .2903 .55926 L .29741 .55143 L p .707 .577 .707 r
F P
0 g
s
.29968 .68453 m .30555 .70266 L .3077 .70652 L p .707 .577 .707 r
F P
0 g
s
.49355 .62553 m .49942 .64366 L .49727 .6398 L p .707 .577 .707 r
F P
0 g
s
.49727 .6398 m .4914 .62167 L .49355 .62553 L p .707 .577 .707 r
F P
0 g
s
.48369 .58568 m .47783 .5298 L .4903 .53529 L p .707 .577 .707 r
F P
0 g
s
.29741 .55143 m .30327 .6073 L .29616 .61514 L p .707 .577 .707 r
F P
0 g
s
.30761 .6828 m .29625 .64645 L .30358 .63965 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30358 .63965 m .31494 .676 L .30761 .6828 L p .707 .577 .707 r
F P
0 g
s
.30327 .6073 m .29741 .55143 L .31375 .54353 L p .707 .577 .707 r
F P
0 g
s
.30555 .70266 m .29968 .68453 L .30702 .67778 L p .707 .577 .707 r
F P
0 g
s
.30702 .67778 m .31289 .69591 L .30555 .70266 L p .707 .577 .707 r
F P
0 g
s
.4914 .62167 m .49727 .6398 L .48585 .6392 L p .707 .577 .707 r
F P
0 g
s
.48585 .6392 m .47998 .62107 L .4914 .62167 L p .707 .577 .707 r
F P
0 g
s
.46279 .58224 m .45693 .52637 L .47783 .5298 L p .707 .577 .707 r
F P
0 g
s
.31375 .54353 m .31961 .59941 L .30327 .6073 L p .707 .577 .707 r
F P
0 g
s
.31494 .676 m .30358 .63965 L .3197 .63072 L p .707 .577 .707 r
F P
0 g
s
.31961 .59941 m .31375 .54353 L .33772 .53634 L p .707 .577 .707 r
F P
0 g
s
.47998 .62107 m .48585 .6392 L .46626 .64192 L p .707 .577 .707 r
F P
0 g
s
.46626 .64192 m .46039 .62379 L .47998 .62107 L p .707 .577 .707 r
F P
0 g
s
.47708 .58467 m .48844 .62102 L .46876 .62344 L p .707 .577 .707 r
F P
0 g
s
.46876 .62344 m .4574 .58709 L .47708 .58467 L p .707 .577 .707 r
F P
0 g
s
.3197 .63072 m .33106 .66707 L .31494 .676 L p .707 .577 .707 r
F P
0 g
s
.31289 .69591 m .30702 .67778 L .32313 .6688 L p .707 .577 .707 r
F P
0 g
s
.32313 .6688 m .32901 .68693 L .31289 .69591 L p .707 .577 .707 r
F P
0 g
s
.45693 .52637 m .46279 .58224 L .43551 .5812 L p .707 .577 .707 r
F P
0 g
s
.43551 .5812 m .42965 .52532 L .45693 .52637 L p .707 .577 .707 r
F P
0 g
s
.33772 .53634 m .34358 .59222 L .31961 .59941 L p .707 .577 .707 r
F P
0 g
s
.34358 .59222 m .33772 .53634 L .36698 .53056 L p .707 .577 .707 r
F P
0 g
s
.33106 .66707 m .3197 .63072 L .34306 .62055 L p .707 .577 .707 r
F P
0 g
s
.42965 .52532 m .43551 .5812 L .40452 .58265 L p .707 .577 .707 r
F P
0 g
s
.40452 .58265 m .39865 .52677 L .42965 .52532 L p .707 .577 .707 r
F P
0 g
s
.46039 .62379 m .46626 .64192 L .44043 .6477 L p .707 .577 .707 r
F P
0 g
s
.43862 .63001 m .41317 .63682 L p .42876 .59906 L .707 .577 .707 r
F P
0 g
s
.44043 .6477 m .43456 .62958 L .43823 .62876 L p .707 .577 .707 r
F P
0 g
s
.43823 .62876 m .46039 .62379 L p .4432 .64438 L .707 .577 .707 r
F P
0 g
s
.44043 .6477 m .43823 .62876 L .4432 .64438 L .707 .577 .707 r
F
.43146 .59253 m .44282 .62888 L .43862 .63001 L p F P
0 g
s
.42876 .59906 m .43146 .59253 L .43862 .63001 L .707 .577 .707 r
F
.4574 .58709 m .46876 .62344 L .44282 .62888 L p F P
0 g
s
.44282 .62888 m .43146 .59253 L .4574 .58709 L p .707 .577 .707 r
F P
0 g
s
.34306 .62055 m .35442 .6569 L .33106 .66707 L p .707 .577 .707 r
F P
0 g
s
.32901 .68693 m .32313 .6688 L .34644 .65847 L p .707 .577 .707 r
F P
0 g
s
.37284 .58644 m .36698 .53056 L .39865 .52677 L p .707 .577 .707 r
F P
0 g
s
.36698 .53056 m .37284 .58644 L .34358 .59222 L p .707 .577 .707 r
F P
0 g
s
.39865 .52677 m .40452 .58265 L .37284 .58644 L p .707 .577 .707 r
F P
0 g
s
.34644 .65847 m .35231 .6766 L .32901 .68693 L p .707 .577 .707 r
F P
0 g
s
.35442 .6569 m .34306 .62055 L .37135 .61013 L p .707 .577 .707 r
F P
0 g
s
.41317 .63682 m .40181 .60047 L .43146 .59253 L p .707 .577 .707 r
F P
0 g
s
.37135 .61013 m .38271 .64647 L .35442 .6569 L p .707 .577 .707 r
F P
0 g
s
.35231 .6766 m .34644 .65847 L .37465 .64781 L p .707 .577 .707 r
F P
0 g
s
.38271 .64647 m .37135 .61013 L .40181 .60047 L p .707 .577 .707 r
F P
0 g
s
.40181 .60047 m .41317 .63682 L .38271 .64647 L p .707 .577 .707 r
F P
0 g
s
.43456 .62958 m .44043 .6477 L .41089 .65598 L p .707 .577 .707 r
F P
0 g
s
.41089 .65598 m .40502 .63785 L .43456 .62958 L p .707 .577 .707 r
F P
0 g
s
.37465 .64781 m .38053 .66594 L .35231 .6766 L p .707 .577 .707 r
F P
0 g
s
.38053 .66594 m .37465 .64781 L .40502 .63785 L p .707 .577 .707 r
F P
0 g
s
.40502 .63785 m .41089 .65598 L .38053 .66594 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007mooaP008Io
o`00MWoo2@004UYF00<005YFFUH00eYF2000OWoo001bOol40002FUH00`00FUIJEP0FFUH00`00FUIJ
EP09FUH00`00FUH00003001jOol006ioo`@000IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001J
EUYF00=JEP@007Ioo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<0
05YFFUH01eYF0`00Lgoo001ZOol20003FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUH00002001`Ool006Qoo`8000EJEP03001JEUYF00IJEP03001JEUYF
01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006eoo`00Igoo0P001UYF00<0
05YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00
Jgoo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH3001YOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008006Moo`00
IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF01IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P00IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P00IWoo001TOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2
001VOol006Aoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8006Ioo`00I7oo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001TOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH2001VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001VOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001V
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006=o
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1VOol006=oo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0005FUHH000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=o
o`03001JEUYF00L000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo100000=J
EP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`001EYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001OOol40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOolH000gOol0
05]oo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000BOol60004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04000c
Ool005Qoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2000>Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000aOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<7oo001DOol2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P001Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00Dgoo0P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIJEP02000_Ool005=oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH0
05YF000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000Woo0`001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUH005YF02moo`00DWoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000;
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;goo001BOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001J
EUYFFUH0000_Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]J
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYFFUH2000^Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0`002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEQL000AJEP04001JEUYFFUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool005=oo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000QJEP03001JEUYF00IJEP03001JEP0000P0
00=JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF008002ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH00eYF00<005YFFUH00P00
00=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00<005YFFUH00eYF
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF
FUH010002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00D005YFFUIJ
EP0000MJEP03001JEUYF00EJEP03001JEUYF009JEQP0009JEP05001JEUYFFUH0000^Ool005=oo`04
001JEUYF0003FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH400000eYF001J
EP07FUH00`00FUIJEP02FUH00`00FUIJEP04000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YFFUH015YF1P0000AJEP00000000=JEP03
001JEUYF00IJEP03001JEUYF00AJEPD0009JEP8002eoo`00Dgoo00@005YFFUH000=JEP800003FUH0
05YF00IJEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH005YF
000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF000010000eYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YFFUH00UYF1000;Goo001DOol2FUH01000FUH000000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF
00<005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH0
0eYF00<005YFFUH00eYF1@0025YF1P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0UYF00@005YF000002eoo`00E7oo0UYF0P001EYF00<005YFFUH01EYF00<005YFFUH00eYF0`001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00H005YFFUH005YF000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUH000030004FUH0
0`00FUIJEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0
000]Ool005Aoo`04FUH005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP030008FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF10001eYF00<005YFFUH01UYF00<005YF0000
0P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF0P00;Woo001DOol01000FUIJ
EP001EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00UYF0P00;Woo0018Ool=0003FUH00`00FUIJEP02FUH00`00
FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000AJ
EP00000000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP04001JEUYFFUH2000_Ool004Aoo`@0009JEP03001JEUYF00IJEP8000=JEP03001J
EUYF00=JEP03001JEP00008000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00L000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP`0031o
o`00?Woo1P001UYF00<005YFFUH01UYF00H005YF000005YF0005FUH200000eYF001JEP07FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH200000eYF001JEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP04FUH01000FUIJEP00
<7oo000hOol60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP000000
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF1P001UYF00<005YFFUH00`002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF1@001UYF00<005YFFUH00eYF00@005YFFUH002mo
o`00=7oo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P00
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`001UYF00<005YFFUH00eYF00H0
05YFFUH005YF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH40002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo000aOol30005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH500000eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo
000_Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40006FUH00`00FUIJ
EP05FUH01000FUIJEUYF1`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
15YF10000UYF00<005YFFUH01EYF00<005YFFUH01UYF0P0000=JEP00FUH025YF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH015YF1@000eYF00@005YF000000]JEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000MJEQ@000AJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002aoo`8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP03001JEUYF
00AJEP03001JEUYF00EJEP@000AJEP03001JEUYF00MJEP03001JEP0000H000EJEP04001JEP00000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH00`00
FUIJEP020003Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;Woo000/Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00eYF0`0025YF00<005YFFUH015YF
10000UYF0P000eYF00<005YFFUH00UYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`001eYF00<005YFFUH00UYF00H005YFFUH005YFOol200000eYF001JEP07
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP80
0003FUH005YF00=JEP03001JEUYF00EJEP03001JEP0000800003FUH005YF00QJEP03001JEUYF00@0
00=JEP<000EJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Goo000[Ool00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF
001JEP04FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP05FUH4000015YF000005YF0`0000=JEP00
FUH01UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0`001eYF00<005YFFUH00UYF0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUIJEPL002aoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP04001JEUYFFUH30007FUH00`00
FUIJEP03FUH20005FUH30004FUH00`00FUIJEP04FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP0200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF1`000eYF00@005YFFUH002aoo`00:goo00@005YF
FUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP80009J
EP03001JEUYF00=JEP<00003FUH005YF00QJEP03001JEP00008000AJEP<000QJEP04001JEUYFFUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH3
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP03FUH2
000]Ool002]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUH005YF000015YF0P0015YF00<005YFFUH01EYF0`0000=JEP00FUH00UYF
0P0000=JEP00FUH025YF00@005YF000000YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000EJEP<000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP<0009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo02aoo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YF001J
EP00009JEP8000IJEP03001JEUYF00=JEP8000EJEP<000AJEP03001JEUYF00EJEP<000aJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00EJEP04001J
EUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
009JEQ00009JEP<000QJEP03001JEP00008000AJEP<000MJEP03001JEUYF00=JEP800003FUH005YF
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004FUH0
00000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05
FUH3000aOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00AJEPH000QJEP03001J
EUYF00AJEP<000=JEP03001JEUYF00AJEP<0009JEPD00003FUH005YF00QJEP03001JEP00008000=J
EP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH0000000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000=JEP03001J
EUYF00IJEP03001JEUYF00AJEP8003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH010001EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF0P0000=JEP00
00000`001UYF0`001EYF0`001UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
1EYF100025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00=Goo000/Ool00`00FUH00004FUH00`00
FUIJEP03FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP04FUH0
0`00FUH0000400000eYF001JEP07FUH50002FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH00000=goo
000/Ool01000FUIJEP000eYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH015YF1000
00AJEP00FUH0009JEP04001JEUYFFUH40006FUH00`00FUIJEP05FUH7000;FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
1EYF00<005YFFUH01EYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH01EYF0`00>Goo
000/Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF
0P000UYF00@005YF0000009JEP03001JEUYF00EJEP03001JEUYF00EJEPD00003FUH005YF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80
0005FUH005YFFUH00004FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
000lOol002aoo`05001JEUYF001JEP020003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH300000eYF
001JEP07FUH01000FUH005YF0P001EYF00<005YFFUH01EYF00@005YFFUIJEPL0009JEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP800005FUH005YFFUH00004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUH00002000nOol002eoo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0
00EJEP03001JEUYF00EJEP06001JEP00001JEP001EYF00<005YFFUH015YF1P0025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0UYF0P0000=JEP00FUH00UYF00<005YFFUH00UYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00EJEP<0045oo`00;Goo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00<000QJEP03
001JEUYF00EJEP04001JEP000002FUH00`00FUIJEP03FUH00`00FUH000030005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH20002FUH01000FUIJEP0015YF0P001eYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P003Woo1`00;goo000]Ool015YF001JEP001EYF00<005YFFUH01EYF0`0000=JEP00FUH025YF
00<005YFFUH01UYF00H005YF000005YF0003FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH20002FUH01000FUIJEP000eYF00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EP00008000aoo`@0009JEP05001JEUYFFUH0000_Ool002eoo`80009JEP03001JEUYF009JEP03001J
EUYF00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH50006FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEUYF0`000eYF00<005YFFUH0
15YF00<005YFFUH01EYF10002goo100000=JEP00FUH015YF00@005YFFUH002moo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YF00000P001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP04000;Ool40006FUH00`00FUIJEP02FUH0
1000FUIJEP00;goo000^Ool200000eYF001JEP04FUH200000eYF001JEP07FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH50002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH00004FUH30006FUH01000FUIJEUYF1P002goo10000UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH002ioo`00<7oo100000=JEP00000015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH0100015YF00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000D0009JEP04001JEUYFFUH7000<Ool40006FUH00`00FUIJEP06FUH0
0`00FUIJEP0400000eYF001oo`0]Ool003=oo`8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEPH000=JEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH01000FUH000000eYF1`000eYF00@005YFFUH000Uoo`<00003FUH005YF00QJEP03001JEUYF
00AJEP@000=JEP@002eoo`00<Woo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF1@0000=JEP00
FUH01UYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001J
EP00FUH00006FUH00`00FUIJEP03FUH01000FUIJEP001Woo0`001EYF00<005YFFUH01UYF00<005YF
FUH01@0000=JEP00FUH00eYF00@005YFFUH002eoo`00<7oo0P000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH015YF10001UYF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP03001JEUYF00AJEP03001JEUYF00=JEP04
001JEUYF0003Ool30008FUH00`00FUIJEP05FUH400000goo00000003FUH00`00FUIJEP03FUH2000^
Ool002moo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF
001JEP07FUH00`00FUIJEP04FUH60002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP09FUH00`00
FUIJEP040002Ool30006FUH01000FUIJEUYF0P00;goo000]Ool30005FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH30004FUH00`00FUIJEP07FUH00`00FUH000060002FUH01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH01EYF00<005YFFUH00eYF100015YF00<005YF
FUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF0000035oo`00;Goo00@005YFFUH000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP<000QJEP03001JEUYF00AJEP@0009JEP8000=JEP03001JEP00
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEQD000UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF009JEP8000MJEP03
001JEUYF00=JEP<000Eoo`<000AJEP03001JEUYF00AJEP8003=oo`00;Goo0P0000=JEP00FUH00eYF
00<005YFFUH01EYF00<005YFFUH00P0000=JEP00FUH025YF00<005YFFUH010000eYF0`001EYF00<0
05YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF1`0000=JEP00FUH02UYF00<005YFFUH01EYF
1P000eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF
00<005YFFUH00`002EYF00<005YF00000P001Goo0`001eYF00<005YFFUH00UYF0P00=Goo000]Ool2
00000eYF001JEP04FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP05FUH4000015YF001JEUYF0`00
00=JEP00FUH01UYF0P000UYF00<005YFFUH00eYF00<005YFFUH015YF0`0025YF00<005YFFUH02EYF
00<005YFFUH02UYF1`0025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01EYF
0P000eYF00<005YFFUH01EYF0`001Goo0`0000=JEP00FUH025YF00@005YF000003Moo`00;Woo00<0
05YF00001EYF00@005YFFUIJEP<000MJEP03001JEUYF00=JEP8000EJEP<000AJEP03001JEUYF00AJ
EP<0009JEP03001JEUYF00=JEP03001JEUYF00@000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP<0
00EJEP03001JEUYF00=JEP8000Eoo`<000EJEP03001JEUYF00EJEP<003Uoo`00;Woo00@005YFFUH0
00EJEP<00003FUH005YF00QJEP03001JEP00008000AJEP<000QJEP04001JEUYFFUH20002Ool01000
FUIJEP0015YF10000eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF1@001eYF00<005YFFUH00UYF0P0015YF00H005YF000005YF0007FUH00`00FUH000020004Ool3
0008FUH00`00FUIJEP03FUH2000lOol002moo`03001JEP0000AJEP8000AJEP03001JEUYF00EJEP<0
0003FUH005YF009JEP800003FUH005YF00QJEP04001JEP000004Ool01@00FUIJEP00FUH00`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF
0`0015YF00<005YFFUH00UYF0P000UYF100015YF00<005YFFUH015YF100000=oo`0000000P0000=J
EP00FUH02EYF00<005YF00000P00?Woo000_Ool00`00FUH00002FUH20006FUH00`00FUIJEP03FUH2
0005FUH30004FUH00`00FUIJEP05FUH30006Ool00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH300000eYF
001JEP03FUH400000eYF00000005FUH00`00FUIJEP02FUH200000eYF000000020006FUH00`00FUIJ
EP06FUH30011Ool002moo`03001JEUYF00<000QJEP03001JEP00008000AJEP<000MJEP03001JEUYF
00=JEP8000Uoo`03001JEP0000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008000AJEP80009JEP04001J
EUYF0005FUH00`00FUH0000400000eYF001JEP07FUH00`00FUIJEP03FUH30014Ool002moo`<000=J
EP03001JEUYF00AJEP<0009JEPD00003FUH005YF00QJEP03001JEP00008000]oo`8000AJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP80009JEP04001JEUYF0005FUH30006FUH00`00FUIJEP06
FUH00`00FUH000020017Ool002moo`8000AJEP03001JEUYF009JEP8000=JEP<000IJEP<000EJEP<0
00ioo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@000=JEP03001JEP0000=JEP800003FUH0
05YF00IJEP03001JEUYF00EJEP<004Yoo`00;Woo00<005YF00001EYF00D005YF000005YF00@000QJ
EPD0009JEP80015oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003FUH00`00
FUIJEP030003FUH00`00FUIJEP06FUH00`00FUIJEP04001=Ool002ioo`03001JEP0000EJEPD000AJ
EP03001JEUYF00EJEPL001=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000003
FUH00`00FUIJEP020005FUH00`00FUIJEP04FUH4001AOol002ioo`04001JEUYF0002FUH200000eYF
001JEP06FUH00`00FUIJEP05FUH5000FOol00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH000001EYF00<005YF00001EYF00<005YFFUH01000EGoo000_Ool00`00FUH000020004
FUH00`00FUIJEP05FUH01000FUIJEUYF1`005goo00<005YFFUH00UYF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH015YF00D005YFFUH005YF00@000=JEP03001JEUYF00D005Uoo`00;goo00@005YF000000EJEP03
001JEUYF00AJEPD001moo`05001JEUYFFUH00008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP020003Ool7
001NOol002moo`80009JEP03001JEUYF00=JEP03001JEP0000<002Eoo`800003FUH005YF00MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP0000eoo`@005Uoo`00;goo0P000UYF00@005YFFUIJEP@002]oo`8000QJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP8000Yoo`@0009JEP03001JEP00008005Ioo`00<7oo1`00<7oo0P001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001goo100000=JEP00FUH015YF00@005YFFUH005Ioo`00JGoo0`0015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF
FUIJEP8000Eoo`@000IJEP03001JEUYF009JEP04001JEUYF001FOol006aoo`<00003FUH005YF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000003
Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000EGoo001_Ool40008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH400000goo00000002
0006FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00EGoo001cOol60002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP040002Ool300000eYF001JEP08FUH0
0`00FUIJEP04FUH;001DOol007Uoo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000=oo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH005YF00=JEP04001JEUYF001DOol0085ooaX0
00Qoo`<000QJEP03001JEUYF00EJEP@00003Ool0000000=JEP03001JEUYF00=JEP8005Eoo`00XGoo
0P0000=JEP00FUH02EYF00<005YFFUH010000Woo0`001UYF00@005YFFUIJEP8005Ioo`00WWoo0`00
15YF00<005YFFUH01UYF100017oo0P0000=JEP00FUH01UYF00@005YF000005Qoo`00W7oo0P001eYF
00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0P00FWoo002JOol30009FUH00`00FUH0
00020005Ool30007FUH00`00FUIJEP02FUH2001LOol009Qoo`8000=JEP03001JEUYF00EJEP<000Eo
o`<00003FUH005YF00QJEP04001JEP00001NOol009Ioo`8000EJEP03001JEUYF00=JEP8000Eoo`<0
00EJEP03001JEUYF00EJEP<0061oo`00U7oo0`001eYF00<005YF00000P0017oo0`0025YF00<005YF
FUH00eYF0P00Hgoo002BOol20003FUH00`00FUIJEP04FUH20003Ool400000eYF001JEP09FUH00`00
FUH00002001UOol0095oo`03001JEUYF00=JEP03001JEUYF009JEP800003Ool00000008000IJEP03
001JEUYF00IJEP<006Qoo`00T7oo0P001UYF00<005YF0000100000=JEP00FUH01eYF00<005YFFUH0
0eYF0`00Jgoo002?Ool01000FUIJEP001EYF0`001UYF00<005YFFUH01UYF00<005YF00000P00KWoo
002?Ool01000FUIJEP000eYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`00LGoo002@Ool00`00
FUIJEP030003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001dOol0091oo`03001JEUYF008000EJ
EP03001JEUYF00EJEP03001JEP00008007Ioo`00TGoo00AJEP00FUH000EJEP03001JEUYF009JEPD0
07Uoo`00TGoo00D005YFFUIJEP00009JEPL007ioo`00TGoo1`00QGoo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {499.25, 270}} -> {-0.291303, 1.17775, \
0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]29\[InvisibleSpace]"     "\
\[InvisibleSpace]9.752535240165791`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 29, "     ", 9.7525352401657912, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .70198 m .59613 .6464 L .56496 .6445 L p .707 .577 .707 r
F P
0 g
s
.59613 .6464 m .59613 .70198 L .62796 .70121 L p .707 .577 .707 r
F P
0 g
s
.62796 .70121 m .62796 .64562 L .59613 .6464 L p .707 .577 .707 r
F P
0 g
s
.62796 .64562 m .62796 .70121 L .65734 .69783 L p .707 .577 .707 r
F P
0 g
s
.65734 .69783 m .65734 .64225 L .62796 .64562 L p .707 .577 .707 r
F P
0 g
s
.56496 .70008 m .56496 .6445 L .5375 .64011 L p .707 .577 .707 r
F P
0 g
s
.56496 .6445 m .56496 .70008 L .59613 .70198 L p .707 .577 .707 r
F P
0 g
s
.65734 .64225 m .65734 .69783 L .6814 .69218 L p .707 .577 .707 r
F P
0 g
s
.6814 .69218 m .6814 .6366 L .65734 .64225 L p .707 .577 .707 r
F P
0 g
s
.5375 .64011 m .5375 .69569 L .56496 .70008 L p .707 .577 .707 r
F P
0 g
s
.5375 .69569 m .5375 .64011 L .51644 .63365 L p .707 .577 .707 r
F P
0 g
s
.6814 .6366 m .6814 .69218 L .69777 .68481 L p .707 .577 .707 r
F P
0 g
s
.69777 .68481 m .69777 .62923 L .6814 .6366 L p .707 .577 .707 r
F P
0 g
s
.59613 .81891 m .59613 .78185 L .56496 .77995 L p .707 .577 .707 r
F P
0 g
s
.59613 .78185 m .59613 .81891 L .62796 .81813 L p .707 .577 .707 r
F P
0 g
s
.62796 .81813 m .62796 .78107 L .59613 .78185 L p .707 .577 .707 r
F P
0 g
s
.51644 .63365 m .51644 .68924 L .5375 .69569 L p .707 .577 .707 r
F P
0 g
s
.62796 .78107 m .62796 .81813 L .65735 .81475 L p .707 .577 .707 r
F P
0 g
s
.65735 .81475 m .65735 .77769 L .62796 .78107 L p .707 .577 .707 r
F P
0 g
s
.56496 .817 m .56496 .77995 L .5375 .77556 L p .707 .577 .707 r
F P
0 g
s
.56496 .77995 m .56496 .817 L .59613 .81891 L p .707 .577 .707 r
F P
0 g
s
.51644 .68924 m .51644 .63365 L .50385 .62577 L p .707 .577 .707 r
F P
0 g
s
.65735 .77769 m .65735 .81475 L .6814 .8091 L p .707 .577 .707 r
F P
0 g
s
.6814 .8091 m .6814 .77204 L .65735 .77769 L p .707 .577 .707 r
F P
0 g
s
.5375 .77556 m .5375 .81261 L .56496 .817 L p .707 .577 .707 r
F P
0 g
s
.5375 .81261 m .5375 .77556 L .51644 .7691 L p .707 .577 .707 r
F P
0 g
s
.50385 .62577 m .50385 .68135 L .51644 .68924 L p .707 .577 .707 r
F P
0 g
s
.69777 .62923 m .69777 .68481 L .70485 .67645 L p .707 .577 .707 r
F P
0 g
s
.70485 .67645 m .70485 .62086 L .69777 .62923 L p .707 .577 .707 r
F P
0 g
s
.51644 .7691 m .51644 .80616 L .5375 .81261 L p .707 .577 .707 r
F P
0 g
s
.6814 .77204 m .6814 .8091 L .69777 .80173 L p .707 .577 .707 r
F P
0 g
s
.69777 .80173 m .69777 .76468 L .6814 .77204 L p .707 .577 .707 r
F P
0 g
s
.59613 .92954 m .59613 .91102 L .56496 .90912 L p .707 .577 .707 r
F P
0 g
s
.59613 .91102 m .59613 .92954 L .62796 .92877 L p .707 .577 .707 r
F P
0 g
s
.62796 .92877 m .62796 .91024 L .59613 .91102 L p .707 .577 .707 r
F P
0 g
s
.50385 .68135 m .50385 .62577 L .50095 .61723 L p .707 .577 .707 r
F P
0 g
s
.62796 .91024 m .62796 .92877 L .65735 .92539 L p .707 .577 .707 r
F P
0 g
s
.65735 .92539 m .65735 .90686 L .62796 .91024 L p .707 .577 .707 r
F P
0 g
s
.56496 .90912 m .56496 .92764 L .59613 .92954 L p .707 .577 .707 r
F P
0 g
s
.56496 .92764 m .56496 .90912 L .5375 .90472 L p .707 .577 .707 r
F P
0 g
s
.51644 .80616 m .51644 .7691 L .50385 .76122 L p .707 .577 .707 r
F P
0 g
s
.5375 .90472 m .5375 .92325 L .56496 .92764 L p .707 .577 .707 r
F P
0 g
s
.65735 .90686 m .65735 .92539 L .6814 .91974 L p .707 .577 .707 r
F P
0 g
s
.6814 .91974 m .6814 .90121 L .65735 .90686 L p .707 .577 .707 r
F P
0 g
s
.50095 .61723 m .50095 .67281 L .50385 .68135 L p .707 .577 .707 r
F P
0 g
s
.70485 .62086 m .70485 .67645 L .70195 .6679 L p .707 .577 .707 r
F P
0 g
s
.70195 .6679 m .70195 .61232 L .70485 .62086 L p .707 .577 .707 r
F P
0 g
s
.50385 .76122 m .50385 .79827 L .51644 .80616 L p .707 .577 .707 r
F P
0 g
s
.5375 .92325 m .5375 .90472 L .51644 .89827 L p .707 .577 .707 r
F P
0 g
s
.69777 .76468 m .69777 .80173 L .70485 .79337 L p .707 .577 .707 r
F P
0 g
s
.70485 .79337 m .70485 .75631 L .69777 .76468 L p .707 .577 .707 r
F P
0 g
s
.51644 .89827 m .51644 .9168 L .5375 .92325 L p .707 .577 .707 r
F P
0 g
s
.50095 .67281 m .50095 .61723 L .50804 .60886 L p .707 .577 .707 r
F P
0 g
s
.49044 .79495 m .49044 .29306 L .44643 .29038 L p .707 .577 .707 r
F P
0 g
s
.50385 .79827 m .50385 .76122 L .50095 .75268 L p .707 .577 .707 r
F P
0 g
s
.50804 .60886 m .50804 .66445 L .50095 .67281 L p .707 .577 .707 r
F P
0 g
s
.50095 .75268 m .50095 .78973 L .50385 .79827 L p .707 .577 .707 r
F P
0 g
s
.50804 .66445 m .50804 .60886 L .5244 .6015 L p .707 .577 .707 r
F P
0 g
s
.50095 .78973 m .50095 .75268 L .50804 .74431 L p .707 .577 .707 r
F P
0 g
s
.5244 .6015 m .5244 .65708 L .50804 .66445 L p .707 .577 .707 r
F P
0 g
s
.50804 .74431 m .50804 .78137 L .50095 .78973 L p .707 .577 .707 r
F P
0 g
s
.50804 .78137 m .50804 .74431 L .5244 .73695 L p .707 .577 .707 r
F P
0 g
s
.5244 .73695 m .5244 .774 L .50804 .78137 L p .707 .577 .707 r
F P
0 g
s
.5244 .774 m .5244 .73695 L .54846 .7313 L p .707 .577 .707 r
F P
0 g
s
.54846 .7313 m .54846 .76835 L .5244 .774 L p .707 .577 .707 r
F P
0 g
s
.49044 .29306 m .49044 .79495 L .53538 .79385 L p .707 .577 .707 r
F P
0 g
s
.5244 .65708 m .5244 .6015 L .54846 .59585 L p .707 .577 .707 r
F P
0 g
s
.54846 .59585 m .54846 .65143 L .5244 .65708 L p .707 .577 .707 r
F P
0 g
s
.53538 .79385 m .53538 .29197 L .49044 .29306 L p .707 .577 .707 r
F P
0 g
s
.6814 .90121 m .6814 .91974 L .69777 .91237 L p .707 .577 .707 r
F P
0 g
s
.69777 .91237 m .69777 .89384 L .6814 .90121 L p .707 .577 .707 r
F P
0 g
s
.54846 .65143 m .54846 .59585 L .57784 .59247 L p .707 .577 .707 r
F P
0 g
s
.57784 .59247 m .57784 .64805 L .54846 .65143 L p .707 .577 .707 r
F P
0 g
s
.54846 .76835 m .54846 .7313 L .57784 .72792 L p .707 .577 .707 r
F P
0 g
s
.57784 .72792 m .57784 .76497 L .54846 .76835 L p .707 .577 .707 r
F P
0 g
s
.53538 .29197 m .53538 .79385 L .57686 .78908 L p .707 .577 .707 r
F P
0 g
s
.57686 .78908 m .57686 .2872 L .53538 .29197 L p .707 .577 .707 r
F P
0 g
s
.44643 .79227 m .44643 .29038 L .40766 .28418 L p .707 .577 .707 r
F P
0 g
s
.44643 .29038 m .44643 .79227 L .49044 .79495 L p .707 .577 .707 r
F P
0 g
s
.51644 .9168 m .51644 .89827 L .50385 .89039 L p .707 .577 .707 r
F P
0 g
s
.70195 .61232 m .70195 .6679 L .68936 .66002 L p .707 .577 .707 r
F P
0 g
s
.68936 .66002 m .68936 .60444 L .70195 .61232 L p .707 .577 .707 r
F P
0 g
s
.50385 .89039 m .50385 .90891 L .51644 .9168 L p .707 .577 .707 r
F P
0 g
s
.57784 .64805 m .57784 .59247 L .60968 .59169 L p .707 .577 .707 r
F P
0 g
s
.60968 .59169 m .60968 .64727 L .57784 .64805 L p .707 .577 .707 r
F P
0 g
s
.57784 .76497 m .57784 .72792 L .60968 .72714 L p .707 .577 .707 r
F P
0 g
s
.60968 .72714 m .60968 .76419 L .57784 .76497 L p .707 .577 .707 r
F P
0 g
s
.57686 .2872 m .57686 .78908 L .61082 .78111 L p .707 .577 .707 r
F P
0 g
s
.64085 .59359 m .64085 .64917 L .60968 .64727 L p .707 .577 .707 r
F P
0 g
s
.60968 .64727 m .60968 .59169 L .64085 .59359 L p .707 .577 .707 r
F P
0 g
s
.64085 .72904 m .64085 .7661 L .60968 .76419 L p .707 .577 .707 r
F P
0 g
s
.60968 .76419 m .60968 .72714 L .64085 .72904 L p .707 .577 .707 r
F P
0 g
s
.61082 .78111 m .61082 .27922 L .57686 .2872 L p .707 .577 .707 r
F P
0 g
s
.70485 .75631 m .70485 .79337 L .70195 .78483 L p .707 .577 .707 r
F P
0 g
s
.70195 .78483 m .70195 .74777 L .70485 .75631 L p .707 .577 .707 r
F P
0 g
s
.25312 .66517 m .25312 .60959 L .22195 .60769 L p .707 .577 .707 r
F P
0 g
s
.25312 .60959 m .25312 .66517 L .28495 .66439 L p .707 .577 .707 r
F P
0 g
s
.28495 .66439 m .28495 .60881 L .25312 .60959 L p .707 .577 .707 r
F P
0 g
s
.28495 .60881 m .28495 .66439 L .31434 .66101 L p .707 .577 .707 r
F P
0 g
s
.31434 .66101 m .31434 .60543 L .28495 .60881 L p .707 .577 .707 r
F P
0 g
s
.69777 .89384 m .69777 .91237 L .70485 .90401 L p .707 .577 .707 r
F P
0 g
s
.70485 .90401 m .70485 .88548 L .69777 .89384 L p .707 .577 .707 r
F P
0 g
s
.22195 .66327 m .22195 .60769 L .19449 .60329 L p .707 .577 .707 r
F P
0 g
s
.22195 .60769 m .22195 .66327 L .25312 .66517 L p .707 .577 .707 r
F P
0 g
s
.40766 .78607 m .40766 .28418 L .37794 .27507 L p .707 .577 .707 r
F P
0 g
s
.40766 .28418 m .40766 .78607 L .44643 .79227 L p .707 .577 .707 r
F P
0 g
s
.31434 .60543 m .31434 .66101 L .33839 .65536 L p .707 .577 .707 r
F P
0 g
s
.33839 .65536 m .33839 .59978 L .31434 .60543 L p .707 .577 .707 r
F P
0 g
s
.50385 .90891 m .50385 .89039 L .50095 .88184 L p .707 .577 .707 r
F P
0 g
s
.68936 .60444 m .68936 .66002 L .66831 .65357 L p .707 .577 .707 r
F P
0 g
s
.66831 .65357 m .66831 .59798 L .68936 .60444 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.50095 .88184 m .50095 .90037 L .50385 .90891 L p .707 .577 .707 r
F P
0 g
s
.19449 .60329 m .19449 .65888 L .22195 .66327 L p .707 .577 .707 r
F P
0 g
s
.19449 .65888 m .19449 .60329 L .17343 .59684 L p .707 .577 .707 r
F P
0 g
s
.61082 .27922 m .61082 .78111 L .63393 .77071 L p .707 .577 .707 r
F P
0 g
s
.63393 .77071 m .63393 .26882 L .61082 .27922 L p .707 .577 .707 r
F P
0 g
s
.70195 .74777 m .70195 .78483 L .68936 .77694 L p .707 .577 .707 r
F P
0 g
s
.68936 .77694 m .68936 .73989 L .70195 .74777 L p .707 .577 .707 r
F P
0 g
s
.70485 .88548 m .70485 .90401 L .70195 .89546 L p .707 .577 .707 r
F P
0 g
s
.70195 .89546 m .70195 .87694 L .70485 .88548 L p .707 .577 .707 r
F P
0 g
s
.33839 .59978 m .33839 .65536 L .35476 .64799 L p .707 .577 .707 r
F P
0 g
s
.35476 .64799 m .35476 .59241 L .33839 .59978 L p .707 .577 .707 r
F P
0 g
s
.25312 .78209 m .25312 .74504 L .22195 .74313 L p .707 .577 .707 r
F P
0 g
s
.25312 .74504 m .25312 .78209 L .28495 .78131 L p .707 .577 .707 r
F P
0 g
s
.28495 .78131 m .28495 .74426 L .25312 .74504 L p .707 .577 .707 r
F P
0 g
s
.17343 .59684 m .17343 .65242 L .19449 .65888 L p .707 .577 .707 r
F P
0 g
s
.37794 .77696 m .37794 .27507 L .36016 .26394 L p .707 .577 .707 r
F P
0 g
s
.37794 .27507 m .37794 .77696 L .40766 .78607 L p .707 .577 .707 r
F P
0 g
s
.28495 .74426 m .28495 .78131 L .31434 .77793 L p .707 .577 .707 r
F P
0 g
s
.31434 .77793 m .31434 .74088 L .28495 .74426 L p .707 .577 .707 r
F P
0 g
s
.66831 .59798 m .66831 .65357 L .64085 .64917 L p .707 .577 .707 r
F P
0 g
s
.64085 .64917 m .64085 .59359 L .66831 .59798 L p .707 .577 .707 r
F P
0 g
s
.22195 .78019 m .22195 .74313 L .19449 .73874 L p .707 .577 .707 r
F P
0 g
s
.22195 .74313 m .22195 .78019 L .25312 .78209 L p .707 .577 .707 r
F P
0 g
s
.17343 .65242 m .17343 .59684 L .16084 .58896 L p .707 .577 .707 r
F P
0 g
s
.50095 .90037 m .50095 .88184 L .50804 .87348 L p .707 .577 .707 r
F P
0 g
s
.50804 .87348 m .50804 .89201 L .50095 .90037 L p .707 .577 .707 r
F P
0 g
s
.31434 .74088 m .31434 .77793 L .33839 .77228 L p .707 .577 .707 r
F P
0 g
s
.33839 .77228 m .33839 .73523 L .31434 .74088 L p .707 .577 .707 r
F P
0 g
s
.19449 .73874 m .19449 .7758 L .22195 .78019 L p .707 .577 .707 r
F P
0 g
s
.68936 .73989 m .68936 .77694 L .66831 .77049 L p .707 .577 .707 r
F P
0 g
s
.66831 .77049 m .66831 .73343 L .68936 .73989 L p .707 .577 .707 r
F P
0 g
s
.19449 .7758 m .19449 .73874 L .17343 .73229 L p .707 .577 .707 r
F P
0 g
s
.16084 .58896 m .16084 .64454 L .17343 .65242 L p .707 .577 .707 r
F P
0 g
s
.35476 .59241 m .35476 .64799 L .36184 .63963 L p .707 .577 .707 r
F P
0 g
s
.36184 .63963 m .36184 .58405 L .35476 .59241 L p .707 .577 .707 r
F P
0 g
s
.64085 .7661 m .64085 .72904 L .66831 .73343 L p .707 .577 .707 r
F P
0 g
s
.63393 .26882 m .63393 .77071 L .64393 .7589 L p .707 .577 .707 r
F P
0 g
s
.64393 .7589 m .64393 .25701 L .63393 .26882 L p .707 .577 .707 r
F P
0 g
s
.70195 .87694 m .70195 .89546 L .68936 .88758 L p .707 .577 .707 r
F P
0 g
s
.68936 .88758 m .68936 .86905 L .70195 .87694 L p .707 .577 .707 r
F P
0 g
s
.17343 .73229 m .17343 .76934 L .19449 .7758 L p .707 .577 .707 r
F P
0 g
s
.33839 .73523 m .33839 .77228 L .35476 .76492 L p .707 .577 .707 r
F P
0 g
s
.35476 .76492 m .35476 .72786 L .33839 .73523 L p .707 .577 .707 r
F P
0 g
s
.25312 .89273 m .25312 .8742 L .22195 .8723 L p .707 .577 .707 r
F P
0 g
s
.25312 .8742 m .25312 .89273 L .28495 .89195 L p .707 .577 .707 r
F P
0 g
s
.28495 .89195 m .28495 .87342 L .25312 .8742 L p .707 .577 .707 r
F P
0 g
s
.16084 .64454 m .16084 .58896 L .15794 .58041 L p .707 .577 .707 r
F P
0 g
s
.50804 .89201 m .50804 .87348 L .5244 .86611 L p .707 .577 .707 r
F P
0 g
s
.28495 .87342 m .28495 .89195 L .31434 .88857 L p .707 .577 .707 r
F P
0 g
s
.31434 .88857 m .31434 .87005 L .28495 .87342 L p .707 .577 .707 r
F P
0 g
s
.22195 .8723 m .22195 .89083 L .25312 .89273 L p .707 .577 .707 r
F P
0 g
s
.66831 .73343 m .66831 .77049 L .64085 .7661 L p .707 .577 .707 r
F P
0 g
s
.36184 .58405 m .36184 .63963 L .35894 .63109 L p .707 .577 .707 r
F P
0 g
s
.35894 .63109 m .35894 .57551 L .36184 .58405 L p .707 .577 .707 r
F P
0 g
s
.35476 .72786 m .35476 .76492 L .36184 .75655 L p .707 .577 .707 r
F P
0 g
s
.36184 .75655 m .36184 .7195 L .35476 .72786 L p .707 .577 .707 r
F P
0 g
s
.35894 .57551 m .35894 .63109 L .34635 .6232 L p .707 .577 .707 r
F P
0 g
s
.34635 .6232 m .34635 .56762 L .35894 .57551 L p .707 .577 .707 r
F P
0 g
s
.36184 .7195 m .36184 .75655 L .35894 .74801 L p .707 .577 .707 r
F P
0 g
s
.35894 .74801 m .35894 .71096 L .36184 .7195 L p .707 .577 .707 r
F P
0 g
s
.36016 .76582 m .36016 .26394 L .35607 .25188 L p .707 .577 .707 r
F P
0 g
s
.36016 .26394 m .36016 .76582 L .37794 .77696 L p .707 .577 .707 r
F P
0 g
s
.22195 .89083 m .22195 .8723 L .19449 .86791 L p .707 .577 .707 r
F P
0 g
s
.5244 .86611 m .5244 .88464 L .50804 .89201 L p .707 .577 .707 r
F P
0 g
s
.17343 .76934 m .17343 .73229 L .16084 .7244 L p .707 .577 .707 r
F P
0 g
s
.19449 .86791 m .19449 .88644 L .22195 .89083 L p .707 .577 .707 r
F P
0 g
s
.31434 .87005 m .31434 .88857 L .33839 .88292 L p .707 .577 .707 r
F P
0 g
s
.33839 .88292 m .33839 .8644 L .31434 .87005 L p .707 .577 .707 r
F P
0 g
s
.15794 .58041 m .15794 .63599 L .16084 .64454 L p .707 .577 .707 r
F P
0 g
s
.68936 .86905 m .68936 .88758 L .66831 .88113 L p .707 .577 .707 r
F P
0 g
s
.66831 .88113 m .66831 .8626 L .68936 .86905 L p .707 .577 .707 r
F P
0 g
s
.16084 .7244 m .16084 .76146 L .17343 .76934 L p .707 .577 .707 r
F P
0 g
s
.19449 .88644 m .19449 .86791 L .17343 .86145 L p .707 .577 .707 r
F P
0 g
s
.17343 .86145 m .17343 .87998 L .19449 .88644 L p .707 .577 .707 r
F P
0 g
s
.5244 .88464 m .5244 .86611 L .54846 .86046 L p .707 .577 .707 r
F P
0 g
s
.64393 .25701 m .64393 .7589 L .63984 .74684 L p .707 .577 .707 r
F P
0 g
s
.63984 .74684 m .63984 .24495 L .64393 .25701 L p .707 .577 .707 r
F P
0 g
s
.15794 .63599 m .15794 .58041 L .16503 .57205 L p .707 .577 .707 r
F P
0 g
s
.54846 .86046 m .54846 .87899 L .5244 .88464 L p .707 .577 .707 r
F P
0 g
s
.33839 .8644 m .33839 .88292 L .35476 .87556 L p .707 .577 .707 r
F P
0 g
s
.35476 .87556 m .35476 .85703 L .33839 .8644 L p .707 .577 .707 r
F P
0 g
s
.16084 .76146 m .16084 .7244 L .15794 .71586 L p .707 .577 .707 r
F P
0 g
s
.66831 .8626 m .66831 .88113 L .64085 .87673 L p .707 .577 .707 r
F P
0 g
s
.64085 .87673 m .64085 .85821 L .66831 .8626 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.17343 .87998 m .17343 .86145 L .16084 .85357 L p .707 .577 .707 r
F P
0 g
s
.16503 .57205 m .16503 .62763 L .15794 .63599 L p .707 .577 .707 r
F P
0 g
s
.15794 .71586 m .15794 .75292 L .16084 .76146 L p .707 .577 .707 r
F P
0 g
s
.35894 .71096 m .35894 .74801 L .34635 .74013 L p .707 .577 .707 r
F P
0 g
s
.34635 .74013 m .34635 .70307 L .35894 .71096 L p .707 .577 .707 r
F P
0 g
s
.35607 .25188 m .35607 .75377 L .36016 .76582 L p .707 .577 .707 r
F P
0 g
s
.35607 .75377 m .35607 .25188 L .36607 .24007 L p .707 .577 .707 r
F P
0 g
s
.54846 .87899 m .54846 .86046 L .57784 .85708 L p .707 .577 .707 r
F P
0 g
s
.16084 .85357 m .16084 .8721 L .17343 .87998 L p .707 .577 .707 r
F P
0 g
s
.57784 .85708 m .57784 .87561 L .54846 .87899 L p .707 .577 .707 r
F P
0 g
s
.64085 .85821 m .64085 .87673 L .60968 .87483 L p .707 .577 .707 r
F P
0 g
s
.60968 .87483 m .60968 .85631 L .64085 .85821 L p .707 .577 .707 r
F P
0 g
s
.16503 .62763 m .16503 .57205 L .1814 .56468 L p .707 .577 .707 r
F P
0 g
s
.57784 .87561 m .57784 .85708 L .60968 .85631 L p .707 .577 .707 r
F P
0 g
s
.35476 .85703 m .35476 .87556 L .36184 .86719 L p .707 .577 .707 r
F P
0 g
s
.36184 .86719 m .36184 .84866 L .35476 .85703 L p .707 .577 .707 r
F P
0 g
s
.60968 .85631 m .60968 .87483 L .57784 .87561 L p .707 .577 .707 r
F P
0 g
s
.15794 .75292 m .15794 .71586 L .16503 .7075 L p .707 .577 .707 r
F P
0 g
s
.16084 .8721 m .16084 .85357 L .15794 .84503 L p .707 .577 .707 r
F P
0 g
s
.63984 .24495 m .63984 .74684 L .62206 .73571 L p .707 .577 .707 r
F P
0 g
s
.62206 .73571 m .62206 .23382 L .63984 .24495 L p .707 .577 .707 r
F P
0 g
s
.1814 .56468 m .1814 .62026 L .16503 .62763 L p .707 .577 .707 r
F P
0 g
s
.34635 .56762 m .34635 .6232 L .3253 .61675 L p .707 .577 .707 r
F P
0 g
s
.3253 .61675 m .3253 .56117 L .34635 .56762 L p .707 .577 .707 r
F P
0 g
s
.16503 .7075 m .16503 .74455 L .15794 .75292 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15794 .84503 m .15794 .86356 L .16084 .8721 L p .707 .577 .707 r
F P
0 g
s
.1814 .62026 m .1814 .56468 L .20545 .55903 L p .707 .577 .707 r
F P
0 g
s
.36607 .74196 m .36607 .24007 L .38918 .22967 L p .707 .577 .707 r
F P
0 g
s
.36607 .24007 m .36607 .74196 L .35607 .75377 L p .707 .577 .707 r
F P
0 g
s
.36184 .84866 m .36184 .86719 L .35894 .85865 L p .707 .577 .707 r
F P
0 g
s
.35894 .85865 m .35894 .84012 L .36184 .84866 L p .707 .577 .707 r
F P
0 g
s
.16503 .74455 m .16503 .7075 L .1814 .70013 L p .707 .577 .707 r
F P
0 g
s
.3253 .56117 m .3253 .61675 L .29784 .61236 L p .707 .577 .707 r
F P
0 g
s
.29784 .61236 m .29784 .55678 L .3253 .56117 L p .707 .577 .707 r
F P
0 g
s
.20545 .55903 m .20545 .61461 L .1814 .62026 L p .707 .577 .707 r
F P
0 g
s
.15794 .86356 m .15794 .84503 L .16503 .83666 L p .707 .577 .707 r
F P
0 g
s
.20545 .61461 m .20545 .55903 L .23483 .55565 L p .707 .577 .707 r
F P
0 g
s
.1814 .70013 m .1814 .73719 L .16503 .74455 L p .707 .577 .707 r
F P
0 g
s
.16503 .83666 m .16503 .85519 L .15794 .86356 L p .707 .577 .707 r
F P
0 g
s
.62206 .23382 m .62206 .73571 L .59233 .7266 L p .707 .577 .707 r
F P
0 g
s
.59233 .7266 m .59233 .22471 L .62206 .23382 L p .707 .577 .707 r
F P
0 g
s
.34635 .70307 m .34635 .74013 L .3253 .73367 L p .707 .577 .707 r
F P
0 g
s
.3253 .73367 m .3253 .69662 L .34635 .70307 L p .707 .577 .707 r
F P
0 g
s
.29784 .55678 m .29784 .61236 L .26667 .61046 L p .707 .577 .707 r
F P
0 g
s
.26667 .61046 m .26667 .55487 L .29784 .55678 L p .707 .577 .707 r
F P
0 g
s
.23483 .61123 m .23483 .55565 L .26667 .55487 L p .707 .577 .707 r
F P
0 g
s
.23483 .55565 m .23483 .61123 L .20545 .61461 L p .707 .577 .707 r
F P
0 g
s
.35894 .84012 m .35894 .85865 L .34635 .85077 L p .707 .577 .707 r
F P
0 g
s
.34635 .85077 m .34635 .83224 L .35894 .84012 L p .707 .577 .707 r
F P
0 g
s
.26667 .55487 m .26667 .61046 L .23483 .61123 L p .707 .577 .707 r
F P
0 g
s
.73333 .60994 m .73333 .55436 L .70216 .55246 L p .707 .577 .707 r
F P
0 g
s
.73333 .55436 m .73333 .60994 L .76517 .60917 L p .707 .577 .707 r
F P
0 g
s
.76517 .60917 m .76517 .55359 L .73333 .55436 L p .707 .577 .707 r
F P
0 g
s
.1814 .73719 m .1814 .70013 L .20545 .69448 L p .707 .577 .707 r
F P
0 g
s
.76517 .55359 m .76517 .60917 L .79455 .60579 L p .707 .577 .707 r
F P
0 g
s
.79455 .60579 m .79455 .55021 L .76517 .55359 L p .707 .577 .707 r
F P
0 g
s
.38918 .22967 m .38918 .73156 L .36607 .74196 L p .707 .577 .707 r
F P
0 g
s
.38918 .73156 m .38918 .22967 L .42314 .22169 L p .707 .577 .707 r
F P
0 g
s
.70216 .60804 m .70216 .55246 L .6747 .54807 L p .707 .577 .707 r
F P
0 g
s
.70216 .55246 m .70216 .60804 L .73333 .60994 L p .707 .577 .707 r
F P
0 g
s
.16503 .85519 m .16503 .83666 L .1814 .8293 L p .707 .577 .707 r
F P
0 g
s
.20545 .69448 m .20545 .73154 L .1814 .73719 L p .707 .577 .707 r
F P
0 g
s
.3253 .69662 m .3253 .73367 L .29784 .72928 L p .707 .577 .707 r
F P
0 g
s
.29784 .72928 m .29784 .69222 L .3253 .69662 L p .707 .577 .707 r
F P
0 g
s
.79455 .55021 m .79455 .60579 L .8186 .60014 L p .707 .577 .707 r
F P
0 g
s
.8186 .60014 m .8186 .54456 L .79455 .55021 L p .707 .577 .707 r
F P
0 g
s
.1814 .8293 m .1814 .84782 L .16503 .85519 L p .707 .577 .707 r
F P
0 g
s
.20545 .73154 m .20545 .69448 L .23483 .6911 L p .707 .577 .707 r
F P
0 g
s
.59233 .22471 m .59233 .7266 L .55357 .72039 L p .707 .577 .707 r
F P
0 g
s
.55357 .72039 m .55357 .21851 L .59233 .22471 L p .707 .577 .707 r
F P
0 g
s
.6747 .54807 m .6747 .60365 L .70216 .60804 L p .707 .577 .707 r
F P
0 g
s
.6747 .60365 m .6747 .54807 L .65365 .54162 L p .707 .577 .707 r
F P
0 g
s
.34635 .83224 m .34635 .85077 L .3253 .84431 L p .707 .577 .707 r
F P
0 g
s
.3253 .84431 m .3253 .82578 L .34635 .83224 L p .707 .577 .707 r
F P
0 g
s
.29784 .69222 m .29784 .72928 L .26667 .72738 L p .707 .577 .707 r
F P
0 g
s
.26667 .72738 m .26667 .69032 L .29784 .69222 L p .707 .577 .707 r
F P
0 g
s
.23483 .6911 m .23483 .72816 L .20545 .73154 L p .707 .577 .707 r
F P
0 g
s
.42314 .72358 m .42314 .22169 L .46462 .21692 L p .707 .577 .707 r
F P
0 g
s
.42314 .22169 m .42314 .72358 L .38918 .73156 L p .707 .577 .707 r
F P
0 g
s
.23483 .72816 m .23483 .6911 L .26667 .69032 L p .707 .577 .707 r
F P
0 g
s
.8186 .54456 m .8186 .60014 L .83497 .59277 L p .707 .577 .707 r
F P
0 g
s
.83497 .59277 m .83497 .53719 L .8186 .54456 L p .707 .577 .707 r
F P
0 g
s
.26667 .69032 m .26667 .72738 L .23483 .72816 L p .707 .577 .707 r
F P
0 g
s
.1814 .84782 m .1814 .8293 L .20545 .82365 L p .707 .577 .707 r
F P
0 g
s
.73333 .72687 m .73333 .68981 L .70216 .68791 L p .707 .577 .707 r
F P
0 g
s
.73333 .68981 m .73333 .72687 L .76517 .72609 L p .707 .577 .707 r
F P
0 g
s
.76517 .72609 m .76517 .68904 L .73333 .68981 L p .707 .577 .707 r
F P
0 g
s
.65365 .54162 m .65365 .5972 L .6747 .60365 L p .707 .577 .707 r
F P
0 g
s
.76517 .68904 m .76517 .72609 L .79455 .72271 L p .707 .577 .707 r
F P
0 g
s
.79455 .72271 m .79455 .68566 L .76517 .68904 L p .707 .577 .707 r
F P
0 g
s
.20545 .82365 m .20545 .84217 L .1814 .84782 L p .707 .577 .707 r
F P
0 g
s
.55357 .21851 m .55357 .72039 L .50956 .71771 L p .707 .577 .707 r
F P
0 g
s
.50956 .71771 m .50956 .21582 L .55357 .21851 L p .707 .577 .707 r
F P
0 g
s
.70216 .72497 m .70216 .68791 L .6747 .68352 L p .707 .577 .707 r
F P
0 g
s
.70216 .68791 m .70216 .72497 L .73333 .72687 L p .707 .577 .707 r
F P
0 g
s
.65365 .5972 m .65365 .54162 L .64105 .53373 L p .707 .577 .707 r
F P
0 g
s
.3253 .82578 m .3253 .84431 L .29784 .83992 L p .707 .577 .707 r
F P
0 g
s
.29784 .83992 m .29784 .82139 L .3253 .82578 L p .707 .577 .707 r
F P
0 g
s
.46462 .71881 m .46462 .21692 L .50956 .21582 L p .707 .577 .707 r
F P
0 g
s
.46462 .21692 m .46462 .71881 L .42314 .72358 L p .707 .577 .707 r
F P
0 g
s
.79455 .68566 m .79455 .72271 L .8186 .71706 L p .707 .577 .707 r
F P
0 g
s
.8186 .71706 m .8186 .68001 L .79455 .68566 L p .707 .577 .707 r
F P
0 g
s
.50956 .21582 m .50956 .71771 L .46462 .71881 L p .707 .577 .707 r
F P
0 g
s
.6747 .68352 m .6747 .72057 L .70216 .72497 L p .707 .577 .707 r
F P
0 g
s
.20545 .84217 m .20545 .82365 L .23483 .82027 L p .707 .577 .707 r
F P
0 g
s
.6747 .72057 m .6747 .68352 L .65365 .67707 L p .707 .577 .707 r
F P
0 g
s
.64105 .53373 m .64105 .58931 L .65365 .5972 L p .707 .577 .707 r
F P
0 g
s
.83497 .53719 m .83497 .59277 L .84205 .58441 L p .707 .577 .707 r
F P
0 g
s
.84205 .58441 m .84205 .52882 L .83497 .53719 L p .707 .577 .707 r
F P
0 g
s
.23483 .82027 m .23483 .8388 L .20545 .84217 L p .707 .577 .707 r
F P
0 g
s
.29784 .82139 m .29784 .83992 L .26667 .83802 L p .707 .577 .707 r
F P
0 g
s
.26667 .83802 m .26667 .81949 L .29784 .82139 L p .707 .577 .707 r
F P
0 g
s
.23483 .8388 m .23483 .82027 L .26667 .81949 L p .707 .577 .707 r
F P
0 g
s
.65365 .67707 m .65365 .71412 L .6747 .72057 L p .707 .577 .707 r
F P
0 g
s
.26667 .81949 m .26667 .83802 L .23483 .8388 L p .707 .577 .707 r
F P
0 g
s
.8186 .68001 m .8186 .71706 L .83497 .70969 L p .707 .577 .707 r
F P
0 g
s
.83497 .70969 m .83497 .67264 L .8186 .68001 L p .707 .577 .707 r
F P
0 g
s
.73333 .83751 m .73333 .81898 L .70216 .81708 L p .707 .577 .707 r
F P
0 g
s
.73333 .81898 m .73333 .83751 L .76517 .83673 L p .707 .577 .707 r
F P
0 g
s
.76517 .83673 m .76517 .8182 L .73333 .81898 L p .707 .577 .707 r
F P
0 g
s
.64105 .58931 m .64105 .53373 L .63816 .52519 L p .707 .577 .707 r
F P
0 g
s
.76517 .8182 m .76517 .83673 L .79455 .83335 L p .707 .577 .707 r
F P
0 g
s
.79455 .83335 m .79455 .81482 L .76517 .8182 L p .707 .577 .707 r
F P
0 g
s
.70216 .81708 m .70216 .83561 L .73333 .83751 L p .707 .577 .707 r
F P
0 g
s
.70216 .83561 m .70216 .81708 L .6747 .81269 L p .707 .577 .707 r
F P
0 g
s
.65365 .71412 m .65365 .67707 L .64105 .66918 L p .707 .577 .707 r
F P
0 g
s
.6747 .81269 m .6747 .83121 L .70216 .83561 L p .707 .577 .707 r
F P
0 g
s
.79455 .81482 m .79455 .83335 L .8186 .8277 L p .707 .577 .707 r
F P
0 g
s
.8186 .8277 m .8186 .80917 L .79455 .81482 L p .707 .577 .707 r
F P
0 g
s
.63816 .52519 m .63816 .58077 L .64105 .58931 L p .707 .577 .707 r
F P
0 g
s
.84205 .52882 m .84205 .58441 L .83916 .57586 L p .707 .577 .707 r
F P
0 g
s
.83916 .57586 m .83916 .52028 L .84205 .52882 L p .707 .577 .707 r
F P
0 g
s
.64105 .66918 m .64105 .70624 L .65365 .71412 L p .707 .577 .707 r
F P
0 g
s
.6747 .83121 m .6747 .81269 L .65365 .80623 L p .707 .577 .707 r
F P
0 g
s
.83497 .67264 m .83497 .70969 L .84206 .70133 L p .707 .577 .707 r
F P
0 g
s
.84206 .70133 m .84205 .66427 L .83497 .67264 L p .707 .577 .707 r
F P
0 g
s
.65365 .80623 m .65365 .82476 L .6747 .83121 L p .707 .577 .707 r
F P
0 g
s
.63816 .58077 m .63816 .52519 L .64524 .51682 L p .707 .577 .707 r
F P
0 g
s
.8186 .80917 m .8186 .8277 L .83497 .82033 L p .707 .577 .707 r
F P
0 g
s
.83497 .82033 m .83497 .80181 L .8186 .80917 L p .707 .577 .707 r
F P
0 g
s
.64105 .70624 m .64105 .66918 L .63816 .66064 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.65365 .82476 m .65365 .80623 L .64105 .79835 L p .707 .577 .707 r
F P
0 g
s
.64524 .51682 m .64524 .57241 L .63816 .58077 L p .707 .577 .707 r
F P
0 g
s
.63816 .66064 m .63816 .69769 L .64105 .70624 L p .707 .577 .707 r
F P
0 g
s
.83916 .52028 m .83916 .57586 L .82657 .56798 L p .707 .577 .707 r
F P
0 g
s
.82657 .56798 m .82657 .5124 L .83916 .52028 L p .707 .577 .707 r
F P
0 g
s
.64105 .79835 m .64105 .81688 L .65365 .82476 L p .707 .577 .707 r
F P
0 g
s
.84205 .66427 m .84206 .70133 L .83916 .69279 L p .707 .577 .707 r
F P
0 g
s
.83916 .69279 m .83916 .65573 L .84205 .66427 L p .707 .577 .707 r
F P
0 g
s
.39032 .57313 m .39032 .51755 L .35915 .51565 L p .707 .577 .707 r
F P
0 g
s
.39032 .51755 m .39032 .57313 L .42216 .57235 L p .707 .577 .707 r
F P
0 g
s
.42216 .57235 m .42216 .51677 L .39032 .51755 L p .707 .577 .707 r
F P
0 g
s
.64524 .57241 m .64524 .51682 L .66161 .50946 L p .707 .577 .707 r
F P
0 g
s
.42216 .51677 m .42216 .57235 L .45154 .56897 L p .707 .577 .707 r
F P
0 g
s
.45154 .56897 m .45154 .51339 L .42216 .51677 L p .707 .577 .707 r
F P
0 g
s
.83497 .80181 m .83497 .82033 L .84206 .81197 L p .707 .577 .707 r
F P
0 g
s
.84206 .81197 m .84206 .79344 L .83497 .80181 L p .707 .577 .707 r
F P
0 g
s
.35915 .57123 m .35915 .51565 L .33169 .51125 L p .707 .577 .707 r
F P
0 g
s
.35915 .51565 m .35915 .57123 L .39032 .57313 L p .707 .577 .707 r
F P
0 g
s
.63816 .69769 m .63816 .66064 L .64524 .65227 L p .707 .577 .707 r
F P
0 g
s
.45154 .51339 m .45154 .56897 L .47559 .56332 L p .707 .577 .707 r
F P
0 g
s
.47559 .56332 m .47559 .50774 L .45154 .51339 L p .707 .577 .707 r
F P
0 g
s
.64105 .81688 m .64105 .79835 L .63816 .78981 L p .707 .577 .707 r
F P
0 g
s
.66161 .50946 m .66161 .56504 L .64524 .57241 L p .707 .577 .707 r
F P
0 g
s
.82657 .5124 m .82657 .56798 L .80551 .56153 L p .707 .577 .707 r
F P
0 g
s
.80551 .56153 m .80551 .50594 L .82657 .5124 L p .707 .577 .707 r
F P
0 g
s
.64524 .65227 m .64524 .68933 L .63816 .69769 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.63816 .78981 m .63816 .80833 L .64105 .81688 L p .707 .577 .707 r
F P
0 g
s
.33169 .51125 m .33169 .56684 L .35915 .57123 L p .707 .577 .707 r
F P
0 g
s
.33169 .56684 m .33169 .51125 L .31064 .5048 L p .707 .577 .707 r
F P
0 g
s
.83916 .65573 m .83916 .69279 L .82657 .6849 L p .707 .577 .707 r
F P
0 g
s
.82657 .6849 m .82657 .64785 L .83916 .65573 L p .707 .577 .707 r
F P
0 g
s
.66161 .56504 m .66161 .50946 L .68566 .50381 L p .707 .577 .707 r
F P
0 g
s
.84206 .79344 m .84206 .81197 L .83916 .80343 L p .707 .577 .707 r
F P
0 g
s
.83916 .80343 m .83916 .7849 L .84206 .79344 L p .707 .577 .707 r
F P
0 g
s
.47559 .50774 m .47559 .56332 L .49196 .55596 L p .707 .577 .707 r
F P
0 g
s
.49196 .55596 m .49196 .50037 L .47559 .50774 L p .707 .577 .707 r
F P
0 g
s
.39032 .69005 m .39032 .653 L .35915 .6511 L p .707 .577 .707 r
F P
0 g
s
.39032 .653 m .39032 .69005 L .42216 .68927 L p .707 .577 .707 r
F P
0 g
s
.42216 .68927 m .42216 .65222 L .39032 .653 L p .707 .577 .707 r
F P
0 g
s
.31064 .5048 m .31064 .56038 L .33169 .56684 L p .707 .577 .707 r
F P
0 g
s
.64524 .68933 m .64524 .65227 L .66161 .64491 L p .707 .577 .707 r
F P
0 g
s
.42216 .65222 m .42216 .68927 L .45154 .6859 L p .707 .577 .707 r
F P
0 g
s
.45154 .6859 m .45154 .64884 L .42216 .65222 L p .707 .577 .707 r
F P
0 g
s
.80551 .50594 m .80551 .56153 L .77805 .55713 L p .707 .577 .707 r
F P
0 g
s
.77805 .55713 m .77805 .50155 L .80551 .50594 L p .707 .577 .707 r
F P
0 g
s
.68566 .50381 m .68566 .55939 L .66161 .56504 L p .707 .577 .707 r
F P
0 g
s
.35915 .68815 m .35915 .6511 L .33169 .6467 L p .707 .577 .707 r
F P
0 g
s
.35915 .6511 m .35915 .68815 L .39032 .69005 L p .707 .577 .707 r
F P
0 g
s
.31064 .56038 m .31064 .5048 L .29804 .49692 L p .707 .577 .707 r
F P
0 g
s
.63816 .80833 m .63816 .78981 L .64524 .78144 L p .707 .577 .707 r
F P
0 g
s
.68566 .55939 m .68566 .50381 L .71504 .50043 L p .707 .577 .707 r
F P
0 g
s
.66161 .64491 m .66161 .68196 L .64524 .68933 L p .707 .577 .707 r
F P
0 g
s
.64524 .78144 m .64524 .79997 L .63816 .80833 L p .707 .577 .707 r
F P
0 g
s
.45154 .64884 m .45154 .6859 L .47559 .68025 L p .707 .577 .707 r
F P
0 g
s
.47559 .68025 m .47559 .64319 L .45154 .64884 L p .707 .577 .707 r
F P
0 g
s
.33169 .6467 m .33169 .68376 L .35915 .68815 L p .707 .577 .707 r
F P
0 g
s
.82657 .64785 m .82657 .6849 L .80551 .67845 L p .707 .577 .707 r
F P
0 g
s
.80551 .67845 m .80551 .64139 L .82657 .64785 L p .707 .577 .707 r
F P
0 g
s
.77805 .50155 m .77805 .55713 L .74688 .55523 L p .707 .577 .707 r
F P
0 g
s
.74688 .55523 m .74688 .49965 L .77805 .50155 L p .707 .577 .707 r
F P
0 g
s
.33169 .68376 m .33169 .6467 L .31064 .64025 L p .707 .577 .707 r
F P
0 g
s
.29804 .49692 m .29804 .5525 L .31064 .56038 L p .707 .577 .707 r
F P
0 g
s
.71504 .55601 m .71504 .50043 L .74688 .49965 L p .707 .577 .707 r
F P
0 g
s
.71504 .50043 m .71504 .55601 L .68566 .55939 L p .707 .577 .707 r
F P
0 g
s
.49196 .50037 m .49196 .55596 L .49904 .54759 L p .707 .577 .707 r
F P
0 g
s
.49904 .54759 m .49904 .49201 L .49196 .50037 L p .707 .577 .707 r
F P
0 g
s
.83916 .7849 m .83916 .80343 L .82657 .79554 L p .707 .577 .707 r
F P
0 g
s
.82657 .79554 m .82657 .77701 L .83916 .7849 L p .707 .577 .707 r
F P
0 g
s
.74688 .49965 m .74688 .55523 L .71504 .55601 L p .707 .577 .707 r
F P
0 g
s
.66161 .68196 m .66161 .64491 L .68566 .63926 L p .707 .577 .707 r
F P
0 g
s
.31064 .64025 m .31064 .67731 L .33169 .68376 L p .707 .577 .707 r
F P
0 g
s
.47559 .64319 m .47559 .68025 L .49196 .67288 L p .707 .577 .707 r
F P
0 g
s
.49196 .67288 m .49196 .63582 L .47559 .64319 L p .707 .577 .707 r
F P
0 g
s
.39032 .80069 m .39032 .78216 L .35915 .78026 L p .707 .577 .707 r
F P
0 g
s
.39032 .78216 m .39032 .80069 L .42216 .79991 L p .707 .577 .707 r
F P
0 g
s
.42216 .79991 m .42216 .78139 L .39032 .78216 L p .707 .577 .707 r
F P
0 g
s
.29804 .5525 m .29804 .49692 L .29515 .48837 L p .707 .577 .707 r
F P
0 g
s
.64524 .79997 m .64524 .78144 L .66161 .77407 L p .707 .577 .707 r
F P
0 g
s
.42216 .78139 m .42216 .79991 L .45154 .79654 L p .707 .577 .707 r
F P
0 g
s
.45154 .79654 m .45154 .77801 L .42216 .78139 L p .707 .577 .707 r
F P
0 g
s
.68566 .63926 m .68566 .67631 L .66161 .68196 L p .707 .577 .707 r
F P
0 g
s
.35915 .78026 m .35915 .79879 L .39032 .80069 L p .707 .577 .707 r
F P
0 g
s
.80551 .64139 m .80551 .67845 L .77805 .67406 L p .707 .577 .707 r
F P
0 g
s
.77805 .67406 m .77805 .637 L .80551 .64139 L p .707 .577 .707 r
F P
0 g
s
.35915 .79879 m .35915 .78026 L .33169 .77587 L p .707 .577 .707 r
F P
0 g
s
.66161 .77407 m .66161 .7926 L .64524 .79997 L p .707 .577 .707 r
F P
0 g
s
.31064 .67731 m .31064 .64025 L .29804 .63237 L p .707 .577 .707 r
F P
0 g
s
.33169 .77587 m .33169 .7944 L .35915 .79879 L p .707 .577 .707 r
F P
0 g
s
.68566 .67631 m .68566 .63926 L .71504 .63588 L p .707 .577 .707 r
F P
0 g
s
.45154 .77801 m .45154 .79654 L .47559 .79089 L p .707 .577 .707 r
F P
0 g
s
.47559 .79089 m .47559 .77236 L .45154 .77801 L p .707 .577 .707 r
F P
0 g
s
.29515 .48837 m .29515 .54396 L .29804 .5525 L p .707 .577 .707 r
F P
0 g
s
.49904 .49201 m .49904 .54759 L .49615 .53905 L p .707 .577 .707 r
F P
0 g
s
.49615 .53905 m .49615 .48347 L .49904 .49201 L p .707 .577 .707 r
F P
0 g
s
.82657 .77701 m .82657 .79554 L .80551 .78909 L p .707 .577 .707 r
F P
0 g
s
.80551 .78909 m .80551 .77056 L .82657 .77701 L p .707 .577 .707 r
F P
0 g
s
.29804 .63237 m .29804 .66942 L .31064 .67731 L p .707 .577 .707 r
F P
0 g
s
.77805 .637 m .77805 .67406 L .74688 .67216 L p .707 .577 .707 r
F P
0 g
s
.74688 .67216 m .74688 .6351 L .77805 .637 L p .707 .577 .707 r
F P
0 g
s
.33169 .7944 m .33169 .77587 L .31064 .76942 L p .707 .577 .707 r
F P
0 g
s
.71504 .63588 m .71504 .67293 L .68566 .67631 L p .707 .577 .707 r
F P
0 g
s
.71504 .67293 m .71504 .63588 L .74688 .6351 L p .707 .577 .707 r
F P
0 g
s
.49196 .63582 m .49196 .67288 L .49904 .66451 L p .707 .577 .707 r
F P
0 g
s
.49904 .66451 m .49904 .62746 L .49196 .63582 L p .707 .577 .707 r
F P
0 g
s
.31064 .76942 m .31064 .78794 L .33169 .7944 L p .707 .577 .707 r
F P
0 g
s
.74688 .6351 m .74688 .67216 L .71504 .67293 L p .707 .577 .707 r
F P
0 g
s
.66161 .7926 m .66161 .77407 L .68566 .76842 L p .707 .577 .707 r
F P
0 g
s
.29515 .54396 m .29515 .48837 L .30223 .48001 L p .707 .577 .707 r
F P
0 g
s
.68566 .76842 m .68566 .78695 L .66161 .7926 L p .707 .577 .707 r
F P
0 g
s
.47559 .77236 m .47559 .79089 L .49196 .78352 L p .707 .577 .707 r
F P
0 g
s
.49196 .78352 m .49196 .76499 L .47559 .77236 L p .707 .577 .707 r
F P
0 g
s
.29804 .66942 m .29804 .63237 L .29515 .62382 L p .707 .577 .707 r
F P
0 g
s
.80551 .77056 m .80551 .78909 L .77805 .7847 L p .707 .577 .707 r
F P
0 g
s
.77805 .7847 m .77805 .76617 L .80551 .77056 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.31064 .78794 m .31064 .76942 L .29804 .76153 L p .707 .577 .707 r
F P
0 g
s
.30223 .48001 m .30223 .53559 L .29515 .54396 L p .707 .577 .707 r
F P
0 g
s
.29515 .62382 m .29515 .66088 L .29804 .66942 L p .707 .577 .707 r
F P
0 g
s
.49615 .48347 m .49615 .53905 L .48356 .53116 L p .707 .577 .707 r
F P
0 g
s
.48356 .53116 m .48356 .47558 L .49615 .48347 L p .707 .577 .707 r
F P
0 g
s
.68566 .78695 m .68566 .76842 L .71504 .76505 L p .707 .577 .707 r
F P
0 g
s
.29804 .76153 m .29804 .78006 L .31064 .78794 L p .707 .577 .707 r
F P
0 g
s
.71504 .76505 m .71504 .78357 L .68566 .78695 L p .707 .577 .707 r
F P
0 g
s
.49904 .62746 m .49904 .66451 L .49615 .65597 L p .707 .577 .707 r
F P
0 g
s
.49615 .65597 m .49615 .61892 L .49904 .62746 L p .707 .577 .707 r
F P
0 g
s
.77805 .76617 m .77805 .7847 L .74688 .7828 L p .707 .577 .707 r
F P
0 g
s
.74688 .7828 m .74688 .76427 L .77805 .76617 L p .707 .577 .707 r
F P
0 g
s
.30223 .53559 m .30223 .48001 L .3186 .47264 L p .707 .577 .707 r
F P
0 g
s
.71504 .78357 m .71504 .76505 L .74688 .76427 L p .707 .577 .707 r
F P
0 g
s
.49196 .76499 m .49196 .78352 L .49904 .77515 L p .707 .577 .707 r
F P
0 g
s
.49904 .77515 m .49904 .75663 L .49196 .76499 L p .707 .577 .707 r
F P
0 g
s
.74688 .76427 m .74688 .7828 L .71504 .78357 L p .707 .577 .707 r
F P
0 g
s
.29515 .66088 m .29515 .62382 L .30223 .61546 L p .707 .577 .707 r
F P
0 g
s
.29804 .78006 m .29804 .76153 L .29515 .75299 L p .707 .577 .707 r
F P
0 g
s
.3186 .47264 m .3186 .52822 L .30223 .53559 L p .707 .577 .707 r
F P
0 g
s
.48356 .47558 m .48356 .53116 L .4625 .52471 L p .707 .577 .707 r
F P
0 g
s
.4625 .52471 m .4625 .46913 L .48356 .47558 L p .707 .577 .707 r
F P
0 g
s
.30223 .61546 m .30223 .65251 L .29515 .66088 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29515 .75299 m .29515 .77152 L .29804 .78006 L p .707 .577 .707 r
F P
0 g
s
.49615 .61892 m .49615 .65597 L .48356 .64809 L p .707 .577 .707 r
F P
0 g
s
.48356 .64809 m .48356 .61103 L .49615 .61892 L p .707 .577 .707 r
F P
0 g
s
.3186 .52822 m .3186 .47264 L .34265 .46699 L p .707 .577 .707 r
F P
0 g
s
.49904 .75663 m .49904 .77515 L .49615 .76661 L p .707 .577 .707 r
F P
0 g
s
.49615 .76661 m .49615 .74808 L .49904 .75663 L p .707 .577 .707 r
F P
0 g
s
.30223 .65251 m .30223 .61546 L .3186 .60809 L p .707 .577 .707 r
F P
0 g
s
.4625 .46913 m .4625 .52471 L .43504 .52032 L p .707 .577 .707 r
F P
0 g
s
.43504 .52032 m .43504 .46474 L .4625 .46913 L p .707 .577 .707 r
F P
0 g
s
.34265 .46699 m .34265 .52257 L .3186 .52822 L p .707 .577 .707 r
F P
0 g
s
.29515 .77152 m .29515 .75299 L .30223 .74463 L p .707 .577 .707 r
F P
0 g
s
.34265 .52257 m .34265 .46699 L .37203 .46361 L p .707 .577 .707 r
F P
0 g
s
.3186 .60809 m .3186 .64515 L .30223 .65251 L p .707 .577 .707 r
F P
0 g
s
.30223 .74463 m .30223 .76315 L .29515 .77152 L p .707 .577 .707 r
F P
0 g
s
.48356 .61103 m .48356 .64809 L .4625 .64163 L p .707 .577 .707 r
F P
0 g
s
.4625 .64163 m .4625 .60458 L .48356 .61103 L p .707 .577 .707 r
F P
0 g
s
.43504 .46474 m .43504 .52032 L .40387 .51842 L p .707 .577 .707 r
F P
0 g
s
.40387 .51842 m .40387 .46284 L .43504 .46474 L p .707 .577 .707 r
F P
0 g
s
.37203 .51919 m .37203 .46361 L .40387 .46284 L p .707 .577 .707 r
F P
0 g
s
.37203 .46361 m .37203 .51919 L .34265 .52257 L p .707 .577 .707 r
F P
0 g
s
.49615 .74808 m .49615 .76661 L .48356 .75873 L p .707 .577 .707 r
F P
0 g
s
.48356 .75873 m .48356 .7402 L .49615 .74808 L p .707 .577 .707 r
F P
0 g
s
.40387 .46284 m .40387 .51842 L .37203 .51919 L p .707 .577 .707 r
F P
0 g
s
.3186 .64515 m .3186 .60809 L .34265 .60244 L p .707 .577 .707 r
F P
0 g
s
.30223 .76315 m .30223 .74463 L .3186 .73726 L p .707 .577 .707 r
F P
0 g
s
.34265 .60244 m .34265 .6395 L .3186 .64515 L p .707 .577 .707 r
F P
0 g
s
.4625 .60458 m .4625 .64163 L .43504 .63724 L p .707 .577 .707 r
F P
0 g
s
.43504 .63724 m .43504 .60019 L .4625 .60458 L p .707 .577 .707 r
F P
0 g
s
.3186 .73726 m .3186 .75579 L .30223 .76315 L p .707 .577 .707 r
F P
0 g
s
.34265 .6395 m .34265 .60244 L .37203 .59906 L p .707 .577 .707 r
F P
0 g
s
.48356 .7402 m .48356 .75873 L .4625 .75227 L p .707 .577 .707 r
F P
0 g
s
.4625 .75227 m .4625 .73375 L .48356 .7402 L p .707 .577 .707 r
F P
0 g
s
.43504 .60019 m .43504 .63724 L .40387 .63534 L p .707 .577 .707 r
F P
0 g
s
.40387 .63534 m .40387 .59829 L .43504 .60019 L p .707 .577 .707 r
F P
0 g
s
.37203 .59906 m .37203 .63612 L .34265 .6395 L p .707 .577 .707 r
F P
0 g
s
.37203 .63612 m .37203 .59906 L .40387 .59829 L p .707 .577 .707 r
F P
0 g
s
.40387 .59829 m .40387 .63534 L .37203 .63612 L p .707 .577 .707 r
F P
0 g
s
.3186 .75579 m .3186 .73726 L .34265 .73161 L p .707 .577 .707 r
F P
0 g
s
.34265 .73161 m .34265 .75014 L .3186 .75579 L p .707 .577 .707 r
F P
0 g
s
.4625 .73375 m .4625 .75227 L .43504 .74788 L p .707 .577 .707 r
F P
0 g
s
.43504 .74788 m .43504 .72935 L .4625 .73375 L p .707 .577 .707 r
F P
0 g
s
.34265 .75014 m .34265 .73161 L .37203 .72823 L p .707 .577 .707 r
F P
0 g
s
.37203 .72823 m .37203 .74676 L .34265 .75014 L p .707 .577 .707 r
F P
0 g
s
.43504 .72935 m .43504 .74788 L .40387 .74598 L p .707 .577 .707 r
F P
0 g
s
.40387 .74598 m .40387 .72745 L .43504 .72935 L p .707 .577 .707 r
F P
0 g
s
.37203 .74676 m .37203 .72823 L .40387 .72745 L p .707 .577 .707 r
F P
0 g
s
.40387 .72745 m .40387 .74598 L .37203 .74676 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0022OolE
0026Ool007aoo`H0009JEP03001JEUYF00UJEP03001JEUYF00AJEP`007Yoo`00MWoo1P0025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1`00Lgoo001aOol50002FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000LGoo001^Ool30007
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF
0`00KWoo001/Ool30009FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH2001/Ool006Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<006Yoo`00J7oo0P00
15YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00Oomoo`1UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001J
EUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000mooaX003ao
o`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Qoo`L000AJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH5000gOol005=oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUH00002000dOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00002Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH000020002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF009JEQL000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00MJEP03
001JEUYF009JEP@0009JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo001COol00`00FUH00004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH50004FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000]Ool005=oo`04001JEP00FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH01000FUIJEP0035YF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00Dgoo00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF000035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005=oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YF
FUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001DOol01@00FUIJEUYF0000
1EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004Moo`T000Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00>Goo3P00
15YF00<005YFFUH00UYF1`0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF009JEPX000QJEPP000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003Eoo`@00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000
FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00
<Woo0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPD0
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH0
05YF009JEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF1P0015YF00<005YFFUH01EYF1@001EYF00<005YFFUH00UYF2000
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001J
EP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<000=JEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF200015YF1@0000=JEP000000
1`001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000;Goo000]Ool20004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YF00002@0015YF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0P00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF01X000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEPD0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP<003=oo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
1`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEPH000AJEP03001JEUYF
00IJEPD000AJEP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
25YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
1EYF00<005YFFUH00eYF2@0015YF1@0015YF00<005YFFUH00UYF1@00>Woo000/Ool00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH01000FUIJEUYF0`001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH00eYF00@005YF000000Eooa8003moo`00;7oo00<005YF000015YF00<005YFFUH00eYF1`001eYF
00<005YFFUH01UYF20000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00D005YFFUIJEP00
05Eoo`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF
00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJ
EUYF0000EGoo000/Ool00`00FUH00003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF
00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo00H005YF000005YF0005FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP05001JEP00FUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF4P00A7oo000/Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF000015YF00<0
05YFFUH00eYF1P000UYF00<005YFFUH00eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP04001JEUYFFUH60004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH8000lOol0
02eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01@00
FUH005YF000015YF00<005YF000010000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH015YF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH5000gOol002eoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01@00FUH005YF00000eYF20000eYF0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH01eYF1P0000=JEP00FUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00008003Aoo`00;Woo0P00
00=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF001JEP00
FUH20005FUH00`00FUH000050002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP02FUH5
0005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH40006FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH00eYF6@000eYF00<005YF
FUH015YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000`Ool003=oo`<00003FUH005YF00IJ
EP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00<005YFFUH00P00;Woo000fOol50004FUH00`00FUIJEP05FUH50005FUH01000FUH00000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000kOol80004FUH500000eYF000000060003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool004=oo`X000Moo`05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00E7oo00D005YFFUIJEP00
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol200000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Egoo0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP04001JEUYFFUH70000
0eYF001oo`0GOol50004FUH01000FUIJEUYF0P00;Goo001JOol300000eYF001JEP06FUH00`00FUIJ
EP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH400000eYF001JEP03FUH2000M
Ool400000eYF001JEP02FUH2000]Ool005eoo`D000AJEP03001JEUYF00EJEPD000EJEP03001JEUYF
00EJEP03001JEP0000<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP00009JEP80009JEPD0009JEP8001Moo`L000=JEP<000=JEP8002eoo`00HWoo
200015YF1@001EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00@005YFFUIJEPT000Uo
o`T000=JEP03001JEUYF00AJEP04001JEUYF0002FUH2000]Ool003mooaL000moo`05001JEUYF001J
EP0C0007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF00001EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUIJEP@002eoo`00>Goo1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000`002goo00@005YFFUH000EJEP@000IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF1@001Woo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00<Woo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010000Woo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P0000Eoo`00FUIJEP0000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00
;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF0000035oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool30003FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000cOol002ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07
FUH00`00FUIJEP04FUHQ0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool50006
FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH8000<FUH0
0`00FUIJEP0:FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0009Ool40002FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP02FUH5000jOol002aoo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH90007FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP040006FUH00`00FUIJEP02FUH00`00FUH0000=OolI000o
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000Uoo`P000AJEP03001J
EUYF00=JEP03001JEUYF00T000AJEP03001JEUYF009JEPP000aJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP03001JEP00008001Moo`<004Uoo`00;7oo
00<005YF000015YF00@005YFFUIJEPP001Uoo`h000=JEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEUYFFUH60006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300000eYF001J
EP03FUH00`00FUH00002FUH5001NOol002aoo`03001JEP0000=JEPD0029oo`D000=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000004FUH00`00FUH00005FUH00`00
FUH00002001KOol002aoo`04001JEP00FUH20004FUH5000KOol300000eYF001JEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF
001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P000UYF00<005YF00001EYF
00<005YFFUH00UYF0P00FGoo000/Ool01P00FUH00000FUH000EJEP04001JEUYFFUHL0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF001J
EP04FUH00`00FUIJEP03FUH3001GOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF009J
EQT000AJEP03001JEUYF00=JEP03001JEUYF008000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP03001JEUYF008005Eoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0P0015YF00@005YFFUIJEPT000AJEP03001JEUYF00EJEP03001JEUYF00QJEPL000AJEP05001JEUYF
FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<0
05YFFUH00eYF00D005YFFUIJEP0005Eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP0000AJEP@0009JEP04001JEUYFFUH30004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP04FUH300000eYF001JEP02FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF00<005YF
FUH00eYF00@005YFFUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00D005YF001JEP00009JEP8000IJEP04001JEUYFFUH30004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP07FUH20003FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP04001JEP00FUH300000eYF001JEP05FUH01000FUIJEUYF0`0015YF00<005YFFUH01EYF
00<005YFFUH025YF00<005YFFUH02EYF0P0000=JEP00FUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Woo
0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YF001J
EP80009JEP03001JEUYF00AJEP07001JEUYFFUH007oo000015YF00<005YFFUH01EYF00<005YFFUH0
25YF00<005YFFUH02UYF0`002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF1000
1EYF00<005YFFUH00eYF00@005YFFUIJEQP003ioo`00<7oo0`0015YF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00@005YF0000009JEP<000IJEP04001JEP000003Ool20002FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP08FUH300000eYF001JEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH20002Ool400000eYF001JEP02FUH60004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH00003000jOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJ
EP@000IJEP04001JEP000003FUH00`00FUH000020002FUH30007Ool30007FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH30002FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH20007Ool500000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH4000fOol003Ioo`D000AJEP03001JEUYF00EJEPD000EJEP04001JEP000003FUH00`00FUIJEP02
FUH50009Ool20006FUH00`00FUIJEP08FUH01000FUIJEUYF100000=JEP00FUH00UYF00<005YF0000
2UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8000Qoo`<000AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@0039oo`00>goo2000
15YF1@001EYF00@005YFFUH000=JEP03001JEUYF00=JEP04001JEUYFFUH80003Ool20004FUH00`00
FUIJEP07FUH50005FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF
000000Ioo`@00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP80035oo`00@goo4`000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00@005YFFUIJEQ<000=JEP03001JEUYF00AJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH>0003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUH00000;goo0018Ool3000;Ool30005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00
FUIJEP08FUH00`00FUIJEP050007FUH01000FUIJEUYF0P0015YF00<005YFFUH00UYF200047oo2000
0eYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00F7oo0`000eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02UYF
00<005YFFUH00eYF20000eYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUH000030004
FUH3000HOol50004FUH01@00FUIJEUYF0000;Woo001KOol50006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH000030005FUH00`00FUIJEP04FUH<0002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP<000=JEP03001JEUYF009JEP03001JEP0001eo
o`<00003FUH005YF009JEP8002eoo`00H7oo10000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH00UYF1@000goo3P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L0
05YFFUH005YF001JEP020006FUH00`00FUIJEP02FUH2000QOol20003FUH2000]Ool006AooaT001=o
o`03001JEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001J
EP0200000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`0ROol200000eYF0000000]Ool0095o
o`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00003FUH0
05YF00EJEP03001JEUYF008002Eoo`D002eoo`00TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00P000UYF0P001UYF0`009Goo0P000UYF0`00;Goo002DOol3
00000eYF001JEP06FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP020002FUH00`00FUH00006000S
Ool40004FUH00`00FUH0000]Ool009Moo`D000AJEP03001JEUYF00IJEPD000AJEP05001JEUYFFUH0
0002FUH00`00FUIJEP02FUH5000KOol70003FUH00`00FUIJEP02FUH2000^Ool009aooa/0009JEP03
001JEUYF00=JEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool003mo
oaT0055oo`D000Uoo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH6001<Ool3000<Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000bOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002
001JOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF1@00<goo000`Ool200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001KOol50004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH7000hOol002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<005ioo`T000AJ
EP03001JEUYF009JEPT003moo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH00UYF5`001UYF
00<005YFFUH00eYF00<005YFFUH00P00IGoo2@00B7oo000]Ool20004FUH00`00FUIJEP03FUH6000G
Ool40002FUH00`00FUIJEP03FUH01@00FUIJEUYF0000]Woo000/Ool00`00FUH00004FUH00`00FUH0
0003000QOol50003FUH01@00FUIJEUYF0000]Woo000/Ool00`00FUH00003FUH3000ZOol40003FUH0
0`00Oomoo`2dOol002aoo`04001JEP00FUH2000aOol01000FUIJEP00]Woo000/Ool01000FUH00000
=7oo0`00>Goo4P00Jgoo000/Ool20002FUH3000_Ool300000eYF001oo`0bOol60004FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH8001SOol002aoo`8000=JEP03001JEP00008002Uoo`<0009JEP03001J
EP00031oo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH5001N
Ool002aoo`8000=JEP03001JEUYF009JEP<0029oo`@00003FUH005YF009JEP03001JEP0002eoo`<0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP00
008005]oo`00;Goo00D005YFFUIJEP0000EJEP03001JEP0000<001Uoo`D000EJEP04001JEUYFFUH2
000/Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001IOol002ioo`04001JEUYF0005FUH00`00FUIJEP03FUHI0003
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:goo0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF
4P0015YF00<005YFFUH015YF00<005YFFUH00eYF0`00Egoo000_Ool30005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP00:goo
0P0015YF00<005YFFUH00UYF1P004Woo20000eYF00<005YFFUH00eYF00<005YFFUH00P00EGoo000a
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH3000[Ool00`00FUH00004FUH00`00FUH00002000POol50004FUH01@00FUIJEUYF0000
EGoo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUIJEUYF1000;Goo00<005YF00000eYF0`00:7oo0`0000=JEP00FUH00UYF0P00E7oo000fOol5
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH7000aOol01000FUH005YF0P00
;Woo0P000eYF0P00E7oo000kOolK000hOol01000FUH00000<Woo0P0000=JEP000000E7oo002>Ool4
000cOol4001DOol008ioo`80009JEP8002moo`800004FUH00000001DOol008ioo`80009JEP03001J
EP00008002Moo`D000=JEP03001JEP0005Aoo`00SWoo0P000UYF00<005YFFUH00UYF1@006goo1`00
0eYF00<005YFFUH00UYF00<005YF0000E7oo002?Ool01000FUIJEP001EYF00@005YFFUIJEPT000Uo
o`T000=JEP03001JEUYF00AJEP03001JEUYF009JEP8005Eoo`00T7oo0`001EYF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00
TWoo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YF000005Qoo`00U7oo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00FWoo002GOol50004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003001MOol009aoo`T000AJEP03001JEUYF00IJ
EP03001JEUYF009JEPD0065oo`00YGoo4P00IWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .79701 m .59613 .74143 L .56496 .73953 L p .707 .577 .707 r
F P
0 g
s
.59613 .74143 m .59613 .79701 L .62796 .79623 L p .707 .577 .707 r
F P
0 g
s
.62796 .79623 m .62796 .74065 L .59613 .74143 L p .707 .577 .707 r
F P
0 g
s
.62796 .74065 m .62796 .79623 L .65735 .79285 L p .707 .577 .707 r
F P
0 g
s
.65735 .79285 m .65734 .73727 L .62796 .74065 L p .707 .577 .707 r
F P
0 g
s
.59613 .77384 m .59613 .75531 L .56496 .75341 L p .707 .577 .707 r
F P
0 g
s
.59613 .75531 m .59613 .77384 L .62796 .77306 L p .707 .577 .707 r
F P
0 g
s
.62796 .77306 m .62796 .75454 L .59613 .75531 L p .707 .577 .707 r
F P
0 g
s
.59613 .80081 m .59613 .76376 L .56496 .76186 L p .707 .577 .707 r
F P
0 g
s
.59613 .76376 m .59613 .80081 L .62796 .80003 L p .707 .577 .707 r
F P
0 g
s
.62796 .80003 m .62796 .76298 L .59613 .76376 L p .707 .577 .707 r
F P
0 g
s
.62796 .75454 m .62796 .77306 L .65735 .76969 L p .707 .577 .707 r
F P
0 g
s
.65735 .76969 m .65735 .75116 L .62796 .75454 L p .707 .577 .707 r
F P
0 g
s
.56496 .79511 m .56496 .73953 L .5375 .73513 L p .707 .577 .707 r
F P
0 g
s
.56496 .73953 m .56496 .79511 L .59613 .79701 L p .707 .577 .707 r
F P
0 g
s
.62796 .76298 m .62796 .80003 L .65735 .79665 L p .707 .577 .707 r
F P
0 g
s
.65735 .79665 m .65735 .7596 L .62796 .76298 L p .707 .577 .707 r
F P
0 g
s
.56496 .75341 m .56496 .77194 L .59613 .77384 L p .707 .577 .707 r
F P
0 g
s
.56496 .77194 m .56496 .75341 L .5375 .74902 L p .707 .577 .707 r
F P
0 g
s
.56496 .79891 m .56496 .76186 L .5375 .75746 L p .707 .577 .707 r
F P
0 g
s
.56496 .76186 m .56496 .79891 L .59613 .80081 L p .707 .577 .707 r
F P
0 g
s
.65734 .73727 m .65735 .79285 L .6814 .7872 L p .707 .577 .707 r
F P
0 g
s
.6814 .7872 m .6814 .73162 L .65734 .73727 L p .707 .577 .707 r
F P
0 g
s
.5375 .74902 m .5375 .76755 L .56496 .77194 L p .707 .577 .707 r
F P
0 g
s
.65735 .75116 m .65735 .76969 L .6814 .76404 L p .707 .577 .707 r
F P
0 g
s
.6814 .76404 m .6814 .74551 L .65735 .75116 L p .707 .577 .707 r
F P
0 g
s
.65735 .7596 m .65735 .79665 L .6814 .791 L p .707 .577 .707 r
F P
0 g
s
.6814 .791 m .6814 .75395 L .65735 .7596 L p .707 .577 .707 r
F P
0 g
s
.5375 .73513 m .5375 .79072 L .56496 .79511 L p .707 .577 .707 r
F P
0 g
s
.5375 .79072 m .5375 .73513 L .51644 .72868 L p .707 .577 .707 r
F P
0 g
s
.5375 .75746 m .5375 .79452 L .56496 .79891 L p .707 .577 .707 r
F P
0 g
s
.5375 .76755 m .5375 .74902 L .51644 .74257 L p .707 .577 .707 r
F P
0 g
s
.5375 .79452 m .5375 .75746 L .51644 .75101 L p .707 .577 .707 r
F P
0 g
s
.51644 .74257 m .51644 .76109 L .5375 .76755 L p .707 .577 .707 r
F P
0 g
s
.6814 .73162 m .6814 .7872 L .69777 .77983 L p .707 .577 .707 r
F P
0 g
s
.69777 .77983 m .69777 .72425 L .6814 .73162 L p .707 .577 .707 r
F P
0 g
s
.51644 .72868 m .51644 .78426 L .5375 .79072 L p .707 .577 .707 r
F P
0 g
s
.6814 .74551 m .6814 .76404 L .69777 .75667 L p .707 .577 .707 r
F P
0 g
s
.69777 .75667 m .69777 .73814 L .6814 .74551 L p .707 .577 .707 r
F P
0 g
s
.51644 .75101 m .51644 .78806 L .5375 .79452 L p .707 .577 .707 r
F P
0 g
s
.6814 .75395 m .6814 .791 L .69777 .78364 L p .707 .577 .707 r
F P
0 g
s
.69777 .78364 m .69777 .74658 L .6814 .75395 L p .707 .577 .707 r
F P
0 g
s
.51644 .78426 m .51644 .72868 L .50385 .7208 L p .707 .577 .707 r
F P
0 g
s
.51644 .76109 m .51644 .74257 L .50385 .73468 L p .707 .577 .707 r
F P
0 g
s
.51644 .78806 m .51644 .75101 L .50385 .74312 L p .707 .577 .707 r
F P
0 g
s
.50385 .73468 m .50385 .75321 L .51644 .76109 L p .707 .577 .707 r
F P
0 g
s
.50385 .7208 m .50385 .77638 L .51644 .78426 L p .707 .577 .707 r
F P
0 g
s
.69777 .72425 m .69777 .77983 L .70485 .77147 L p .707 .577 .707 r
F P
0 g
s
.70485 .77147 m .70485 .71589 L .69777 .72425 L p .707 .577 .707 r
F P
0 g
s
.50385 .74312 m .50385 .78018 L .51644 .78806 L p .707 .577 .707 r
F P
0 g
s
.69777 .73814 m .69777 .75667 L .70485 .7483 L p .707 .577 .707 r
F P
0 g
s
.70485 .7483 m .70485 .72978 L .69777 .73814 L p .707 .577 .707 r
F P
0 g
s
.69777 .74658 m .69777 .78364 L .70485 .77527 L p .707 .577 .707 r
F P
0 g
s
.70485 .77527 m .70485 .73822 L .69777 .74658 L p .707 .577 .707 r
F P
0 g
s
.50385 .77638 m .50385 .7208 L .50095 .71225 L p .707 .577 .707 r
F P
0 g
s
.50385 .75321 m .50385 .73468 L .50095 .72614 L p .707 .577 .707 r
F P
0 g
s
.50385 .78018 m .50385 .74312 L .50095 .73458 L p .707 .577 .707 r
F P
0 g
s
.50095 .72614 m .50095 .74467 L .50385 .75321 L p .707 .577 .707 r
F P
0 g
s
.50095 .71225 m .50095 .76784 L .50385 .77638 L p .707 .577 .707 r
F P
0 g
s
.50095 .73458 m .50095 .77164 L .50385 .78018 L p .707 .577 .707 r
F P
0 g
s
.70485 .71589 m .70485 .77147 L .70195 .76293 L p .707 .577 .707 r
F P
0 g
s
.70195 .76293 m .70195 .70735 L .70485 .71589 L p .707 .577 .707 r
F P
0 g
s
.70485 .72978 m .70485 .7483 L .70195 .73976 L p .707 .577 .707 r
F P
0 g
s
.70195 .73976 m .70195 .72123 L .70485 .72978 L p .707 .577 .707 r
F P
0 g
s
.49044 .84872 m .49044 .34684 L .44643 .34415 L p .707 .577 .707 r
F P
0 g
s
.50095 .76784 m .50095 .71225 L .50804 .70389 L p .707 .577 .707 r
F P
0 g
s
.50095 .74467 m .50095 .72614 L .50804 .71778 L p .707 .577 .707 r
F P
0 g
s
.50095 .77164 m .50095 .73458 L .50804 .72622 L p .707 .577 .707 r
F P
0 g
s
.50804 .71778 m .50804 .7363 L .50095 .74467 L p .707 .577 .707 r
F P
0 g
s
.50804 .70389 m .50804 .75947 L .50095 .76784 L p .707 .577 .707 r
F P
0 g
s
.50804 .72622 m .50804 .76327 L .50095 .77164 L p .707 .577 .707 r
F P
0 g
s
.50804 .75947 m .50804 .70389 L .5244 .69652 L p .707 .577 .707 r
F P
0 g
s
.50804 .7363 m .50804 .71778 L .5244 .71041 L p .707 .577 .707 r
F P
0 g
s
.50804 .76327 m .50804 .72622 L .5244 .71885 L p .707 .577 .707 r
F P
0 g
s
.5244 .71041 m .5244 .72894 L .50804 .7363 L p .707 .577 .707 r
F P
0 g
s
.5244 .69652 m .5244 .7521 L .50804 .75947 L p .707 .577 .707 r
F P
0 g
s
.5244 .71885 m .5244 .75591 L .50804 .76327 L p .707 .577 .707 r
F P
0 g
s
.5244 .7521 m .5244 .69652 L .54846 .69087 L p .707 .577 .707 r
F P
0 g
s
.5244 .72894 m .5244 .71041 L .54846 .70476 L p .707 .577 .707 r
F P
0 g
s
.5244 .75591 m .5244 .71885 L .54846 .7132 L p .707 .577 .707 r
F P
0 g
s
.54846 .70476 m .54846 .72329 L .5244 .72894 L p .707 .577 .707 r
F P
0 g
s
.54846 .69087 m .54846 .74645 L .5244 .7521 L p .707 .577 .707 r
F P
0 g
s
.54846 .7132 m .54846 .75026 L .5244 .75591 L p .707 .577 .707 r
F P
0 g
s
.49044 .34684 m .49044 .84872 L .53538 .84763 L p .707 .577 .707 r
F P
0 g
s
.53538 .84763 m .53538 .34574 L .49044 .34684 L p .707 .577 .707 r
F P
0 g
s
.70485 .73822 m .70485 .77527 L .70195 .76673 L p .707 .577 .707 r
F P
0 g
s
.70195 .76673 m .70195 .72968 L .70485 .73822 L p .707 .577 .707 r
F P
0 g
s
.54846 .74645 m .54846 .69087 L .57784 .68749 L p .707 .577 .707 r
F P
0 g
s
.54846 .72329 m .54846 .70476 L .57784 .70138 L p .707 .577 .707 r
F P
0 g
s
.54846 .75026 m .54846 .7132 L .57784 .70982 L p .707 .577 .707 r
F P
0 g
s
.57784 .70138 m .57784 .71991 L .54846 .72329 L p .707 .577 .707 r
F P
0 g
s
.57784 .68749 m .57784 .74307 L .54846 .74645 L p .707 .577 .707 r
F P
0 g
s
.57784 .70982 m .57784 .74688 L .54846 .75026 L p .707 .577 .707 r
F P
0 g
s
.53538 .34574 m .53538 .84763 L .57686 .84286 L p .707 .577 .707 r
F P
0 g
s
.57686 .84286 m .57686 .34097 L .53538 .34574 L p .707 .577 .707 r
F P
0 g
s
.44643 .84604 m .44643 .34415 L .40766 .33795 L p .707 .577 .707 r
F P
0 g
s
.44643 .34415 m .44643 .84604 L .49044 .84872 L p .707 .577 .707 r
F P
0 g
s
.57784 .74307 m .57784 .68749 L .60968 .68672 L p .707 .577 .707 r
F P
0 g
s
.60968 .68672 m .60968 .7423 L .57784 .74307 L p .707 .577 .707 r
F P
0 g
s
.57784 .71991 m .57784 .70138 L .60968 .7006 L p .707 .577 .707 r
F P
0 g
s
.57784 .74688 m .57784 .70982 L .60968 .70904 L p .707 .577 .707 r
F P
0 g
s
.60968 .7006 m .60968 .71913 L .57784 .71991 L p .707 .577 .707 r
F P
0 g
s
.60968 .70904 m .60968 .7461 L .57784 .74688 L p .707 .577 .707 r
F P
0 g
s
.57686 .34097 m .57686 .84286 L .61082 .83488 L p .707 .577 .707 r
F P
0 g
s
.64085 .68862 m .64085 .7442 L .60968 .7423 L p .707 .577 .707 r
F P
0 g
s
.60968 .7423 m .60968 .68672 L .64085 .68862 L p .707 .577 .707 r
F P
0 g
s
.64085 .7025 m .64085 .72103 L .60968 .71913 L p .707 .577 .707 r
F P
0 g
s
.60968 .71913 m .60968 .7006 L .64085 .7025 L p .707 .577 .707 r
F P
0 g
s
.64085 .71095 m .64085 .748 L .60968 .7461 L p .707 .577 .707 r
F P
0 g
s
.60968 .7461 m .60968 .70904 L .64085 .71095 L p .707 .577 .707 r
F P
0 g
s
.61082 .83488 m .61082 .33299 L .57686 .34097 L p .707 .577 .707 r
F P
0 g
s
.70195 .70735 m .70195 .76293 L .68936 .75504 L p .707 .577 .707 r
F P
0 g
s
.68936 .75504 m .68936 .69946 L .70195 .70735 L p .707 .577 .707 r
F P
0 g
s
.70195 .72123 m .70195 .73976 L .68936 .73188 L p .707 .577 .707 r
F P
0 g
s
.68936 .73188 m .68936 .71335 L .70195 .72123 L p .707 .577 .707 r
F P
0 g
s
.40766 .83984 m .40766 .33795 L .37794 .32884 L p .707 .577 .707 r
F P
0 g
s
.40766 .33795 m .40766 .83984 L .44643 .84604 L p .707 .577 .707 r
F P
0 g
s
.70195 .72968 m .70195 .76673 L .68936 .75885 L p .707 .577 .707 r
F P
0 g
s
.68936 .75885 m .68936 .72179 L .70195 .72968 L p .707 .577 .707 r
F P
0 g
s
.25312 .76019 m .25312 .70461 L .22195 .70271 L p .707 .577 .707 r
F P
0 g
s
.25312 .70461 m .25312 .76019 L .28495 .75942 L p .707 .577 .707 r
F P
0 g
s
.28495 .75942 m .28495 .70383 L .25312 .70461 L p .707 .577 .707 r
F P
0 g
s
.28495 .70383 m .28495 .75942 L .31434 .75604 L p .707 .577 .707 r
F P
0 g
s
.31434 .75604 m .31434 .70045 L .28495 .70383 L p .707 .577 .707 r
F P
0 g
s
.25312 .73703 m .25312 .7185 L .22195 .7166 L p .707 .577 .707 r
F P
0 g
s
.25312 .7185 m .25312 .73703 L .28495 .73625 L p .707 .577 .707 r
F P
0 g
s
.28495 .73625 m .28495 .71772 L .25312 .7185 L p .707 .577 .707 r
F P
0 g
s
.25312 .764 m .25312 .72694 L .22195 .72504 L p .707 .577 .707 r
F P
0 g
s
.25312 .72694 m .25312 .764 L .28495 .76322 L p .707 .577 .707 r
F P
0 g
s
.28495 .76322 m .28495 .72616 L .25312 .72694 L p .707 .577 .707 r
F P
0 g
s
.28495 .71772 m .28495 .73625 L .31434 .73287 L p .707 .577 .707 r
F P
0 g
s
.31434 .73287 m .31434 .71434 L .28495 .71772 L p .707 .577 .707 r
F P
0 g
s
.22195 .75829 m .22195 .70271 L .19449 .69832 L p .707 .577 .707 r
F P
0 g
s
.22195 .70271 m .22195 .75829 L .25312 .76019 L p .707 .577 .707 r
F P
0 g
s
.28495 .72616 m .28495 .76322 L .31434 .75984 L p .707 .577 .707 r
F P
0 g
s
.31434 .75984 m .31434 .72278 L .28495 .72616 L p .707 .577 .707 r
F P
0 g
s
.22195 .7166 m .22195 .73513 L .25312 .73703 L p .707 .577 .707 r
F P
0 g
s
.22195 .73513 m .22195 .7166 L .19449 .71221 L p .707 .577 .707 r
F P
0 g
s
.22195 .76209 m .22195 .72504 L .19449 .72065 L p .707 .577 .707 r
F P
0 g
s
.22195 .72504 m .22195 .76209 L .25312 .764 L p .707 .577 .707 r
F P
0 g
s
.61082 .33299 m .61082 .83488 L .63393 .82448 L p .707 .577 .707 r
F P
0 g
s
.63393 .82448 m .63393 .32259 L .61082 .33299 L p .707 .577 .707 r
F P
0 g
s
.31434 .70045 m .31434 .75604 L .33839 .75039 L p .707 .577 .707 r
F P
0 g
s
.33839 .75039 m .33839 .6948 L .31434 .70045 L p .707 .577 .707 r
F P
0 g
s
.19449 .71221 m .19449 .73073 L .22195 .73513 L p .707 .577 .707 r
F P
0 g
s
.68936 .69946 m .68936 .75504 L .66831 .74859 L p .707 .577 .707 r
F P
0 g
s
.66831 .74859 m .66831 .69301 L .68936 .69946 L p .707 .577 .707 r
F P
0 g
s
.31434 .71434 m .31434 .73287 L .33839 .72722 L p .707 .577 .707 r
F P
0 g
s
.33839 .72722 m .33839 .70869 L .31434 .71434 L p .707 .577 .707 r
F P
0 g
s
.31434 .72278 m .31434 .75984 L .33839 .75419 L p .707 .577 .707 r
F P
0 g
s
.33839 .75419 m .33839 .71713 L .31434 .72278 L p .707 .577 .707 r
F P
0 g
s
.19449 .69832 m .19449 .7539 L .22195 .75829 L p .707 .577 .707 r
F P
0 g
s
.68936 .71335 m .68936 .73188 L .66831 .72542 L p .707 .577 .707 r
F P
0 g
s
.66831 .72542 m .66831 .7069 L .68936 .71335 L p .707 .577 .707 r
F P
0 g
s
.19449 .7539 m .19449 .69832 L .17343 .69186 L p .707 .577 .707 r
F P
0 g
s
.19449 .72065 m .19449 .7577 L .22195 .76209 L p .707 .577 .707 r
F P
0 g
s
.68936 .72179 m .68936 .75885 L .66831 .75239 L p .707 .577 .707 r
F P
0 g
s
.66831 .75239 m .66831 .71534 L .68936 .72179 L p .707 .577 .707 r
F P
0 g
s
.19449 .73073 m .19449 .71221 L .17343 .70575 L p .707 .577 .707 r
F P
0 g
s
.37794 .83073 m .37794 .32884 L .36016 .31771 L p .707 .577 .707 r
F P
0 g
s
.37794 .32884 m .37794 .83073 L .40766 .83984 L p .707 .577 .707 r
F P
0 g
s
.19449 .7577 m .19449 .72065 L .17343 .71419 L p .707 .577 .707 r
F P
0 g
s
.17343 .70575 m .17343 .72428 L .19449 .73073 L p .707 .577 .707 r
F P
0 g
s
.33839 .6948 m .33839 .75039 L .35476 .74302 L p .707 .577 .707 r
F P
0 g
s
.35476 .74302 m .35476 .68744 L .33839 .6948 L p .707 .577 .707 r
F P
0 g
s
.17343 .69186 m .17343 .74745 L .19449 .7539 L p .707 .577 .707 r
F P
0 g
s
.33839 .70869 m .33839 .72722 L .35476 .71985 L p .707 .577 .707 r
F P
0 g
s
.35476 .71985 m .35476 .70133 L .33839 .70869 L p .707 .577 .707 r
F P
0 g
s
.17343 .71419 m .17343 .75125 L .19449 .7577 L p .707 .577 .707 r
F P
0 g
s
.33839 .71713 m .33839 .75419 L .35476 .74682 L p .707 .577 .707 r
F P
0 g
s
.35476 .74682 m .35476 .70977 L .33839 .71713 L p .707 .577 .707 r
F P
0 g
s
.66831 .69301 m .66831 .74859 L .64085 .7442 L p .707 .577 .707 r
F P
0 g
s
.64085 .7442 m .64085 .68862 L .66831 .69301 L p .707 .577 .707 r
F P
0 g
s
.66831 .7069 m .66831 .72542 L .64085 .72103 L p .707 .577 .707 r
F P
0 g
s
.64085 .72103 m .64085 .7025 L .66831 .7069 L p .707 .577 .707 r
F P
0 g
s
.17343 .74745 m .17343 .69186 L .16084 .68398 L p .707 .577 .707 r
F P
0 g
s
.66831 .71534 m .66831 .75239 L .64085 .748 L p .707 .577 .707 r
F P
0 g
s
.64085 .748 m .64085 .71095 L .66831 .71534 L p .707 .577 .707 r
F P
0 g
s
.17343 .72428 m .17343 .70575 L .16084 .69787 L p .707 .577 .707 r
F P
0 g
s
.63393 .32259 m .63393 .82448 L .64393 .81267 L p .707 .577 .707 r
F P
0 g
s
.64393 .81267 m .64393 .31078 L .63393 .32259 L p .707 .577 .707 r
F P
0 g
s
.17343 .75125 m .17343 .71419 L .16084 .70631 L p .707 .577 .707 r
F P
0 g
s
.16084 .69787 m .16084 .7164 L .17343 .72428 L p .707 .577 .707 r
F P
0 g
s
.16084 .68398 m .16084 .73956 L .17343 .74745 L p .707 .577 .707 r
F P
0 g
s
.35476 .68744 m .35476 .74302 L .36184 .73466 L p .707 .577 .707 r
F P
0 g
s
.36184 .73466 m .36184 .67907 L .35476 .68744 L p .707 .577 .707 r
F P
0 g
s
.16084 .70631 m .16084 .74336 L .17343 .75125 L p .707 .577 .707 r
F P
0 g
s
.35476 .70133 m .35476 .71985 L .36184 .71149 L p .707 .577 .707 r
F P
0 g
s
.36184 .71149 m .36184 .69296 L .35476 .70133 L p .707 .577 .707 r
F P
0 g
s
.35476 .70977 m .35476 .74682 L .36184 .73846 L p .707 .577 .707 r
F P
0 g
s
.36184 .73846 m .36184 .7014 L .35476 .70977 L p .707 .577 .707 r
F P
0 g
s
.36184 .67907 m .36184 .73466 L .35894 .72611 L p .707 .577 .707 r
F P
0 g
s
.35894 .72611 m .35894 .67053 L .36184 .67907 L p .707 .577 .707 r
F P
0 g
s
.36184 .69296 m .36184 .71149 L .35894 .70295 L p .707 .577 .707 r
F P
0 g
s
.35894 .70295 m .35894 .68442 L .36184 .69296 L p .707 .577 .707 r
F P
0 g
s
.36184 .7014 m .36184 .73846 L .35894 .72992 L p .707 .577 .707 r
F P
0 g
s
.35894 .72992 m .35894 .69286 L .36184 .7014 L p .707 .577 .707 r
F P
0 g
s
.36016 .8196 m .36016 .31771 L .35607 .30565 L p .707 .577 .707 r
F P
0 g
s
.36016 .31771 m .36016 .8196 L .37794 .83073 L p .707 .577 .707 r
F P
0 g
s
.16084 .73956 m .16084 .68398 L .15794 .67544 L p .707 .577 .707 r
F P
0 g
s
.16084 .7164 m .16084 .69787 L .15794 .68933 L p .707 .577 .707 r
F P
0 g
s
.16084 .74336 m .16084 .70631 L .15794 .69777 L p .707 .577 .707 r
F P
0 g
s
.15794 .68933 m .15794 .70785 L .16084 .7164 L p .707 .577 .707 r
F P
0 g
s
.15794 .67544 m .15794 .73102 L .16084 .73956 L p .707 .577 .707 r
F P
0 g
s
.15794 .69777 m .15794 .73482 L .16084 .74336 L p .707 .577 .707 r
F P
0 g
s
.64393 .31078 m .64393 .81267 L .63984 .80061 L p .707 .577 .707 r
F P
0 g
s
.63984 .80061 m .63984 .29872 L .64393 .31078 L p .707 .577 .707 r
F P
0 g
s
.15794 .73102 m .15794 .67544 L .16503 .66707 L p .707 .577 .707 r
F P
0 g
s
.15794 .70785 m .15794 .68933 L .16503 .68096 L p .707 .577 .707 r
F P
0 g
s
.15794 .73482 m .15794 .69777 L .16503 .6894 L p .707 .577 .707 r
F P
0 g
s
.35894 .67053 m .35894 .72611 L .34635 .71823 L p .707 .577 .707 r
F P
0 g
s
.34635 .71823 m .34635 .66265 L .35894 .67053 L p .707 .577 .707 r
F P
0 g
s
.35894 .68442 m .35894 .70295 L .34635 .69506 L p .707 .577 .707 r
F P
0 g
s
.34635 .69506 m .34635 .67653 L .35894 .68442 L p .707 .577 .707 r
F P
0 g
s
.35894 .69286 m .35894 .72992 L .34635 .72203 L p .707 .577 .707 r
F P
0 g
s
.34635 .72203 m .34635 .68498 L .35894 .69286 L p .707 .577 .707 r
F P
0 g
s
.35607 .30565 m .35607 .80754 L .36016 .8196 L p .707 .577 .707 r
F P
0 g
s
.35607 .80754 m .35607 .30565 L .36607 .29384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16503 .68096 m .16503 .69949 L .15794 .70785 L p .707 .577 .707 r
F P
0 g
s
.16503 .66707 m .16503 .72266 L .15794 .73102 L p .707 .577 .707 r
F P
0 g
s
.16503 .6894 m .16503 .72646 L .15794 .73482 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .72266 m .16503 .66707 L .1814 .65971 L p .707 .577 .707 r
F P
0 g
s
.63984 .29872 m .63984 .80061 L .62206 .78948 L p .707 .577 .707 r
F P
0 g
s
.62206 .78948 m .62206 .28759 L .63984 .29872 L p .707 .577 .707 r
F P
0 g
s
.16503 .69949 m .16503 .68096 L .1814 .67359 L p .707 .577 .707 r
F P
0 g
s
.16503 .72646 m .16503 .6894 L .1814 .68204 L p .707 .577 .707 r
F P
0 g
s
.1814 .67359 m .1814 .69212 L .16503 .69949 L p .707 .577 .707 r
F P
0 g
s
.1814 .65971 m .1814 .71529 L .16503 .72266 L p .707 .577 .707 r
F P
0 g
s
.34635 .66265 m .34635 .71823 L .3253 .71177 L p .707 .577 .707 r
F P
0 g
s
.3253 .71177 m .3253 .65619 L .34635 .66265 L p .707 .577 .707 r
F P
0 g
s
.1814 .68204 m .1814 .71909 L .16503 .72646 L p .707 .577 .707 r
F P
0 g
s
.36607 .79573 m .36607 .29384 L .38918 .28344 L p .707 .577 .707 r
F P
0 g
s
.36607 .29384 m .36607 .79573 L .35607 .80754 L p .707 .577 .707 r
F P
0 g
s
.34635 .67653 m .34635 .69506 L .3253 .68861 L p .707 .577 .707 r
F P
0 g
s
.3253 .68861 m .3253 .67008 L .34635 .67653 L p .707 .577 .707 r
F P
0 g
s
.34635 .68498 m .34635 .72203 L .3253 .71558 L p .707 .577 .707 r
F P
0 g
s
.3253 .71558 m .3253 .67852 L .34635 .68498 L p .707 .577 .707 r
F P
0 g
s
.1814 .71529 m .1814 .65971 L .20545 .65406 L p .707 .577 .707 r
F P
0 g
s
.1814 .69212 m .1814 .67359 L .20545 .66794 L p .707 .577 .707 r
F P
0 g
s
.1814 .71909 m .1814 .68204 L .20545 .67639 L p .707 .577 .707 r
F P
0 g
s
.20545 .66794 m .20545 .68647 L .1814 .69212 L p .707 .577 .707 r
F P
0 g
s
.3253 .65619 m .3253 .71177 L .29784 .70738 L p .707 .577 .707 r
F P
0 g
s
.29784 .70738 m .29784 .6518 L .3253 .65619 L p .707 .577 .707 r
F P
0 g
s
.62206 .28759 m .62206 .78948 L .59233 .78037 L p .707 .577 .707 r
F P
0 g
s
.59233 .78037 m .59233 .27848 L .62206 .28759 L p .707 .577 .707 r
F P
0 g
s
.20545 .65406 m .20545 .70964 L .1814 .71529 L p .707 .577 .707 r
F P
0 g
s
.3253 .67008 m .3253 .68861 L .29784 .68422 L p .707 .577 .707 r
F P
0 g
s
.29784 .68422 m .29784 .66569 L .3253 .67008 L p .707 .577 .707 r
F P
0 g
s
.20545 .67639 m .20545 .71344 L .1814 .71909 L p .707 .577 .707 r
F P
0 g
s
.3253 .67852 m .3253 .71558 L .29784 .71118 L p .707 .577 .707 r
F P
0 g
s
.29784 .71118 m .29784 .67413 L .3253 .67852 L p .707 .577 .707 r
F P
0 g
s
.20545 .70964 m .20545 .65406 L .23483 .65068 L p .707 .577 .707 r
F P
0 g
s
.20545 .68647 m .20545 .66794 L .23483 .66456 L p .707 .577 .707 r
F P
0 g
s
.20545 .71344 m .20545 .67639 L .23483 .67301 L p .707 .577 .707 r
F P
0 g
s
.29784 .6518 m .29784 .70738 L .26667 .70548 L p .707 .577 .707 r
F P
0 g
s
.26667 .70548 m .26667 .6499 L .29784 .6518 L p .707 .577 .707 r
F P
0 g
s
.23483 .66456 m .23483 .68309 L .20545 .68647 L p .707 .577 .707 r
F P
0 g
s
.38918 .28344 m .38918 .78533 L .36607 .79573 L p .707 .577 .707 r
F P
0 g
s
.38918 .78533 m .38918 .28344 L .42314 .27546 L p .707 .577 .707 r
F P
0 g
s
.29784 .66569 m .29784 .68422 L .26667 .68232 L p .707 .577 .707 r
F P
0 g
s
.26667 .68232 m .26667 .66379 L .29784 .66569 L p .707 .577 .707 r
F P
0 g
s
.23483 .70626 m .23483 .65068 L .26667 .6499 L p .707 .577 .707 r
F P
0 g
s
.23483 .65068 m .23483 .70626 L .20545 .70964 L p .707 .577 .707 r
F P
0 g
s
.29784 .67413 m .29784 .71118 L .26667 .70928 L p .707 .577 .707 r
F P
0 g
s
.26667 .70928 m .26667 .67223 L .29784 .67413 L p .707 .577 .707 r
F P
0 g
s
.26667 .6499 m .26667 .70548 L .23483 .70626 L p .707 .577 .707 r
F P
0 g
s
.23483 .68309 m .23483 .66456 L .26667 .66379 L p .707 .577 .707 r
F P
0 g
s
.23483 .67301 m .23483 .71006 L .20545 .71344 L p .707 .577 .707 r
F P
0 g
s
.73333 .70497 m .73333 .64939 L .70216 .64749 L p .707 .577 .707 r
F P
0 g
s
.73333 .64939 m .73333 .70497 L .76517 .70419 L p .707 .577 .707 r
F P
0 g
s
.76517 .70419 m .76517 .64861 L .73333 .64939 L p .707 .577 .707 r
F P
0 g
s
.23483 .71006 m .23483 .67301 L .26667 .67223 L p .707 .577 .707 r
F P
0 g
s
.26667 .66379 m .26667 .68232 L .23483 .68309 L p .707 .577 .707 r
F P
0 g
s
.76517 .64861 m .76517 .70419 L .79455 .70081 L p .707 .577 .707 r
F P
0 g
s
.79455 .70081 m .79455 .64523 L .76517 .64861 L p .707 .577 .707 r
F P
0 g
s
.73333 .6818 m .73333 .66328 L .70216 .66138 L p .707 .577 .707 r
F P
0 g
s
.73333 .66328 m .73333 .6818 L .76517 .68103 L p .707 .577 .707 r
F P
0 g
s
.76517 .68103 m .76517 .6625 L .73333 .66328 L p .707 .577 .707 r
F P
0 g
s
.26667 .67223 m .26667 .70928 L .23483 .71006 L p .707 .577 .707 r
F P
0 g
s
.73333 .70877 m .73333 .67172 L .70216 .66982 L p .707 .577 .707 r
F P
0 g
s
.73333 .67172 m .73333 .70877 L .76517 .708 L p .707 .577 .707 r
F P
0 g
s
.76517 .708 m .76517 .67094 L .73333 .67172 L p .707 .577 .707 r
F P
0 g
s
.76517 .6625 m .76517 .68103 L .79455 .67765 L p .707 .577 .707 r
F P
0 g
s
.79455 .67765 m .79455 .65912 L .76517 .6625 L p .707 .577 .707 r
F P
0 g
s
.70216 .70307 m .70216 .64749 L .6747 .64309 L p .707 .577 .707 r
F P
0 g
s
.70216 .64749 m .70216 .70307 L .73333 .70497 L p .707 .577 .707 r
F P
0 g
s
.76517 .67094 m .76517 .708 L .79455 .70462 L p .707 .577 .707 r
F P
0 g
s
.79455 .70462 m .79455 .66756 L .76517 .67094 L p .707 .577 .707 r
F P
0 g
s
.70216 .66138 m .70216 .6799 L .73333 .6818 L p .707 .577 .707 r
F P
0 g
s
.70216 .6799 m .70216 .66138 L .6747 .65698 L p .707 .577 .707 r
F P
0 g
s
.59233 .27848 m .59233 .78037 L .55357 .77417 L p .707 .577 .707 r
F P
0 g
s
.55357 .77417 m .55357 .27228 L .59233 .27848 L p .707 .577 .707 r
F P
0 g
s
.70216 .70687 m .70216 .66982 L .6747 .66542 L p .707 .577 .707 r
F P
0 g
s
.70216 .66982 m .70216 .70687 L .73333 .70877 L p .707 .577 .707 r
F P
0 g
s
.79455 .64523 m .79455 .70081 L .8186 .69516 L p .707 .577 .707 r
F P
0 g
s
.8186 .69516 m .8186 .63958 L .79455 .64523 L p .707 .577 .707 r
F P
0 g
s
.6747 .65698 m .6747 .67551 L .70216 .6799 L p .707 .577 .707 r
F P
0 g
s
.79455 .65912 m .79455 .67765 L .8186 .672 L p .707 .577 .707 r
F P
0 g
s
.8186 .672 m .8186 .65347 L .79455 .65912 L p .707 .577 .707 r
F P
0 g
s
.79455 .66756 m .79455 .70462 L .8186 .69897 L p .707 .577 .707 r
F P
0 g
s
.8186 .69897 m .8186 .66191 L .79455 .66756 L p .707 .577 .707 r
F P
0 g
s
.42314 .77735 m .42314 .27546 L .46462 .27069 L p .707 .577 .707 r
F P
0 g
s
.42314 .27546 m .42314 .77735 L .38918 .78533 L p .707 .577 .707 r
F P
0 g
s
.6747 .64309 m .6747 .69868 L .70216 .70307 L p .707 .577 .707 r
F P
0 g
s
.6747 .69868 m .6747 .64309 L .65365 .63664 L p .707 .577 .707 r
F P
0 g
s
.6747 .66542 m .6747 .70248 L .70216 .70687 L p .707 .577 .707 r
F P
0 g
s
.6747 .67551 m .6747 .65698 L .65365 .65053 L p .707 .577 .707 r
F P
0 g
s
.6747 .70248 m .6747 .66542 L .65365 .65897 L p .707 .577 .707 r
F P
0 g
s
.65365 .65053 m .65365 .66906 L .6747 .67551 L p .707 .577 .707 r
F P
0 g
s
.55357 .27228 m .55357 .77417 L .50956 .77149 L p .707 .577 .707 r
F P
0 g
s
.50956 .77149 m .50956 .2696 L .55357 .27228 L p .707 .577 .707 r
F P
0 g
s
.8186 .63958 m .8186 .69516 L .83497 .6878 L p .707 .577 .707 r
F P
0 g
s
.83497 .6878 m .83497 .63221 L .8186 .63958 L p .707 .577 .707 r
F P
0 g
s
.65365 .63664 m .65365 .69222 L .6747 .69868 L p .707 .577 .707 r
F P
0 g
s
.46462 .77258 m .46462 .27069 L .50956 .2696 L p .707 .577 .707 r
F P
0 g
s
.46462 .27069 m .46462 .77258 L .42314 .77735 L p .707 .577 .707 r
F P
0 g
s
.8186 .65347 m .8186 .672 L .83497 .66463 L p .707 .577 .707 r
F P
0 g
s
.83497 .66463 m .83497 .6461 L .8186 .65347 L p .707 .577 .707 r
F P
0 g
s
.65365 .65897 m .65365 .69603 L .6747 .70248 L p .707 .577 .707 r
F P
0 g
s
.8186 .66191 m .8186 .69897 L .83497 .6916 L p .707 .577 .707 r
F P
0 g
s
.83497 .6916 m .83497 .65454 L .8186 .66191 L p .707 .577 .707 r
F P
0 g
s
.50956 .2696 m .50956 .77149 L .46462 .77258 L p .707 .577 .707 r
F P
0 g
s
.65365 .69222 m .65365 .63664 L .64105 .62876 L p .707 .577 .707 r
F P
0 g
s
.65365 .66906 m .65365 .65053 L .64105 .64264 L p .707 .577 .707 r
F P
0 g
s
.65365 .69603 m .65365 .65897 L .64105 .65109 L p .707 .577 .707 r
F P
0 g
s
.64105 .64264 m .64105 .66117 L .65365 .66906 L p .707 .577 .707 r
F P
0 g
s
.64105 .62876 m .64105 .68434 L .65365 .69222 L p .707 .577 .707 r
F P
0 g
s
.83497 .63221 m .83497 .6878 L .84206 .67943 L p .707 .577 .707 r
F P
0 g
s
.84206 .67943 m .84205 .62385 L .83497 .63221 L p .707 .577 .707 r
F P
0 g
s
.64105 .65109 m .64105 .68814 L .65365 .69603 L p .707 .577 .707 r
F P
0 g
s
.83497 .6461 m .83497 .66463 L .84205 .65627 L p .707 .577 .707 r
F P
0 g
s
.84205 .65627 m .84205 .63774 L .83497 .6461 L p .707 .577 .707 r
F P
0 g
s
.83497 .65454 m .83497 .6916 L .84206 .68323 L p .707 .577 .707 r
F P
0 g
s
.84206 .68323 m .84205 .64618 L .83497 .65454 L p .707 .577 .707 r
F P
0 g
s
.64105 .68434 m .64105 .62876 L .63816 .62021 L p .707 .577 .707 r
F P
0 g
s
.64105 .66117 m .64105 .64264 L .63816 .6341 L p .707 .577 .707 r
F P
0 g
s
.64105 .68814 m .64105 .65109 L .63816 .64254 L p .707 .577 .707 r
F P
0 g
s
.63816 .6341 m .63816 .65263 L .64105 .66117 L p .707 .577 .707 r
F P
0 g
s
.63816 .62021 m .63816 .6758 L .64105 .68434 L p .707 .577 .707 r
F P
0 g
s
.63816 .64254 m .63816 .6796 L .64105 .68814 L p .707 .577 .707 r
F P
0 g
s
.84205 .62385 m .84206 .67943 L .83916 .67089 L p .707 .577 .707 r
F P
0 g
s
.83916 .67089 m .83916 .61531 L .84205 .62385 L p .707 .577 .707 r
F P
0 g
s
.84205 .63774 m .84205 .65627 L .83916 .64772 L p .707 .577 .707 r
F P
0 g
s
.83916 .64772 m .83916 .6292 L .84205 .63774 L p .707 .577 .707 r
F P
0 g
s
.84205 .64618 m .84206 .68323 L .83916 .67469 L p .707 .577 .707 r
F P
0 g
s
.83916 .67469 m .83916 .63764 L .84205 .64618 L p .707 .577 .707 r
F P
0 g
s
.63816 .6758 m .63816 .62021 L .64524 .61185 L p .707 .577 .707 r
F P
0 g
s
.63816 .65263 m .63816 .6341 L .64524 .62574 L p .707 .577 .707 r
F P
0 g
s
.63816 .6796 m .63816 .64254 L .64524 .63418 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64524 .62574 m .64524 .64427 L .63816 .65263 L p .707 .577 .707 r
F P
0 g
s
.64524 .61185 m .64524 .66743 L .63816 .6758 L p .707 .577 .707 r
F P
0 g
s
.64524 .63418 m .64524 .67123 L .63816 .6796 L p .707 .577 .707 r
F P
0 g
s
.83916 .61531 m .83916 .67089 L .82657 .66301 L p .707 .577 .707 r
F P
0 g
s
.82657 .66301 m .82657 .60742 L .83916 .61531 L p .707 .577 .707 r
F P
0 g
s
.83916 .6292 m .83916 .64772 L .82657 .63984 L p .707 .577 .707 r
F P
0 g
s
.82657 .63984 m .82657 .62131 L .83916 .6292 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83916 .63764 m .83916 .67469 L .82657 .66681 L p .707 .577 .707 r
F P
0 g
s
.82657 .66681 m .82657 .62975 L .83916 .63764 L p .707 .577 .707 r
F P
0 g
s
.39032 .66815 m .39032 .61257 L .35915 .61067 L p .707 .577 .707 r
F P
0 g
s
.39032 .61257 m .39032 .66815 L .42216 .66738 L p .707 .577 .707 r
F P
0 g
s
.42216 .66738 m .42216 .6118 L .39032 .61257 L p .707 .577 .707 r
F P
0 g
s
.64524 .66743 m .64524 .61185 L .66161 .60448 L p .707 .577 .707 r
F P
0 g
s
.42216 .6118 m .42216 .66738 L .45154 .664 L p .707 .577 .707 r
F P
0 g
s
.45154 .664 m .45154 .60842 L .42216 .6118 L p .707 .577 .707 r
F P
0 g
s
.39032 .64499 m .39032 .62646 L .35915 .62456 L p .707 .577 .707 r
F P
0 g
s
.39032 .62646 m .39032 .64499 L .42216 .64421 L p .707 .577 .707 r
F P
0 g
s
.42216 .64421 m .42216 .62568 L .39032 .62646 L p .707 .577 .707 r
F P
0 g
s
.39032 .67196 m .39032 .6349 L .35915 .633 L p .707 .577 .707 r
F P
0 g
s
.39032 .6349 m .39032 .67196 L .42216 .67118 L p .707 .577 .707 r
F P
0 g
s
.42216 .67118 m .42216 .63412 L .39032 .6349 L p .707 .577 .707 r
F P
0 g
s
.64524 .64427 m .64524 .62574 L .66161 .61837 L p .707 .577 .707 r
F P
0 g
s
.42216 .62568 m .42216 .64421 L .45154 .64083 L p .707 .577 .707 r
F P
0 g
s
.45154 .64083 m .45154 .6223 L .42216 .62568 L p .707 .577 .707 r
F P
0 g
s
.35915 .66625 m .35915 .61067 L .33169 .60628 L p .707 .577 .707 r
F P
0 g
s
.35915 .61067 m .35915 .66625 L .39032 .66815 L p .707 .577 .707 r
F P
0 g
s
.64524 .67123 m .64524 .63418 L .66161 .62681 L p .707 .577 .707 r
F P
0 g
s
.42216 .63412 m .42216 .67118 L .45154 .6678 L p .707 .577 .707 r
F P
0 g
s
.45154 .6678 m .45154 .63075 L .42216 .63412 L p .707 .577 .707 r
F P
0 g
s
.35915 .62456 m .35915 .64309 L .39032 .64499 L p .707 .577 .707 r
F P
0 g
s
.35915 .64309 m .35915 .62456 L .33169 .62017 L p .707 .577 .707 r
F P
0 g
s
.66161 .61837 m .66161 .6369 L .64524 .64427 L p .707 .577 .707 r
F P
0 g
s
.35915 .67006 m .35915 .633 L .33169 .62861 L p .707 .577 .707 r
F P
0 g
s
.35915 .633 m .35915 .67006 L .39032 .67196 L p .707 .577 .707 r
F P
0 g
s
.45154 .60842 m .45154 .664 L .47559 .65835 L p .707 .577 .707 r
F P
0 g
s
.47559 .65835 m .47559 .60277 L .45154 .60842 L p .707 .577 .707 r
F P
0 g
s
.33169 .62017 m .33169 .63869 L .35915 .64309 L p .707 .577 .707 r
F P
0 g
s
.66161 .60448 m .66161 .66006 L .64524 .66743 L p .707 .577 .707 r
F P
0 g
s
.82657 .60742 m .82657 .66301 L .80551 .65655 L p .707 .577 .707 r
F P
0 g
s
.80551 .65655 m .80551 .60097 L .82657 .60742 L p .707 .577 .707 r
F P
0 g
s
.45154 .6223 m .45154 .64083 L .47559 .63518 L p .707 .577 .707 r
F P
0 g
s
.47559 .63518 m .47559 .61665 L .45154 .6223 L p .707 .577 .707 r
F P
0 g
s
.66161 .62681 m .66161 .66387 L .64524 .67123 L p .707 .577 .707 r
F P
0 g
s
.45154 .63075 m .45154 .6678 L .47559 .66215 L p .707 .577 .707 r
F P
0 g
s
.47559 .66215 m .47559 .6251 L .45154 .63075 L p .707 .577 .707 r
F P
0 g
s
.33169 .60628 m .33169 .66186 L .35915 .66625 L p .707 .577 .707 r
F P
0 g
s
.82657 .62131 m .82657 .63984 L .80551 .63338 L p .707 .577 .707 r
F P
0 g
s
.80551 .63338 m .80551 .61486 L .82657 .62131 L p .707 .577 .707 r
F P
0 g
s
.33169 .66186 m .33169 .60628 L .31064 .59983 L p .707 .577 .707 r
F P
0 g
s
.33169 .62861 m .33169 .66566 L .35915 .67006 L p .707 .577 .707 r
F P
0 g
s
.82657 .62975 m .82657 .66681 L .80551 .66035 L p .707 .577 .707 r
F P
0 g
s
.80551 .66035 m .80551 .6233 L .82657 .62975 L p .707 .577 .707 r
F P
0 g
s
.33169 .63869 m .33169 .62017 L .31064 .61371 L p .707 .577 .707 r
F P
0 g
s
.33169 .66566 m .33169 .62861 L .31064 .62216 L p .707 .577 .707 r
F P
0 g
s
.66161 .66006 m .66161 .60448 L .68566 .59883 L p .707 .577 .707 r
F P
0 g
s
.31064 .61371 m .31064 .63224 L .33169 .63869 L p .707 .577 .707 r
F P
0 g
s
.66161 .6369 m .66161 .61837 L .68566 .61272 L p .707 .577 .707 r
F P
0 g
s
.47559 .60277 m .47559 .65835 L .49196 .65098 L p .707 .577 .707 r
F P
0 g
s
.49196 .65098 m .49196 .5954 L .47559 .60277 L p .707 .577 .707 r
F P
0 g
s
.66161 .66387 m .66161 .62681 L .68566 .62116 L p .707 .577 .707 r
F P
0 g
s
.68566 .61272 m .68566 .63125 L .66161 .6369 L p .707 .577 .707 r
F P
0 g
s
.31064 .59983 m .31064 .65541 L .33169 .66186 L p .707 .577 .707 r
F P
0 g
s
.47559 .61665 m .47559 .63518 L .49196 .62781 L p .707 .577 .707 r
F P
0 g
s
.49196 .62781 m .49196 .60929 L .47559 .61665 L p .707 .577 .707 r
F P
0 g
s
.31064 .62216 m .31064 .65921 L .33169 .66566 L p .707 .577 .707 r
F P
0 g
s
.47559 .6251 m .47559 .66215 L .49196 .65478 L p .707 .577 .707 r
F P
0 g
s
.49196 .65478 m .49196 .61773 L .47559 .6251 L p .707 .577 .707 r
F P
0 g
s
.80551 .60097 m .80551 .65655 L .77805 .65216 L p .707 .577 .707 r
F P
0 g
s
.77805 .65216 m .77805 .59658 L .80551 .60097 L p .707 .577 .707 r
F P
0 g
s
.68566 .59883 m .68566 .65441 L .66161 .66006 L p .707 .577 .707 r
F P
0 g
s
.80551 .61486 m .80551 .63338 L .77805 .62899 L p .707 .577 .707 r
F P
0 g
s
.77805 .62899 m .77805 .61047 L .80551 .61486 L p .707 .577 .707 r
F P
0 g
s
.68566 .62116 m .68566 .65822 L .66161 .66387 L p .707 .577 .707 r
F P
0 g
s
.31064 .65541 m .31064 .59983 L .29804 .59194 L p .707 .577 .707 r
F P
0 g
s
.80551 .6233 m .80551 .66035 L .77805 .65596 L p .707 .577 .707 r
F P
0 g
s
.77805 .65596 m .77805 .61891 L .80551 .6233 L p .707 .577 .707 r
F P
0 g
s
.68566 .65441 m .68566 .59883 L .71504 .59545 L p .707 .577 .707 r
F P
0 g
s
.31064 .63224 m .31064 .61371 L .29804 .60583 L p .707 .577 .707 r
F P
0 g
s
.31064 .65921 m .31064 .62216 L .29804 .61427 L p .707 .577 .707 r
F P
0 g
s
.68566 .63125 m .68566 .61272 L .71504 .60934 L p .707 .577 .707 r
F P
0 g
s
.29804 .60583 m .29804 .62436 L .31064 .63224 L p .707 .577 .707 r
F P
0 g
s
.68566 .65822 m .68566 .62116 L .71504 .61778 L p .707 .577 .707 r
F P
0 g
s
.77805 .59658 m .77805 .65216 L .74688 .65026 L p .707 .577 .707 r
F P
0 g
s
.74688 .65026 m .74688 .59468 L .77805 .59658 L p .707 .577 .707 r
F P
0 g
s
.71504 .60934 m .71504 .62787 L .68566 .63125 L p .707 .577 .707 r
F P
0 g
s
.29804 .59194 m .29804 .64752 L .31064 .65541 L p .707 .577 .707 r
F P
0 g
s
.77805 .61047 m .77805 .62899 L .74688 .62709 L p .707 .577 .707 r
F P
0 g
s
.74688 .62709 m .74688 .60856 L .77805 .61047 L p .707 .577 .707 r
F P
0 g
s
.71504 .65104 m .71504 .59545 L .74688 .59468 L p .707 .577 .707 r
F P
0 g
s
.71504 .59545 m .71504 .65104 L .68566 .65441 L p .707 .577 .707 r
F P
0 g
s
.49196 .5954 m .49196 .65098 L .49904 .64262 L p .707 .577 .707 r
F P
0 g
s
.49904 .64262 m .49904 .58703 L .49196 .5954 L p .707 .577 .707 r
F P
0 g
s
.29804 .61427 m .29804 .65133 L .31064 .65921 L p .707 .577 .707 r
F P
0 g
s
.77805 .61891 m .77805 .65596 L .74688 .65406 L p .707 .577 .707 r
F P
0 g
s
.74688 .65406 m .74688 .61701 L .77805 .61891 L p .707 .577 .707 r
F P
0 g
s
.74688 .59468 m .74688 .65026 L .71504 .65104 L p .707 .577 .707 r
F P
0 g
s
.71504 .62787 m .71504 .60934 L .74688 .60856 L p .707 .577 .707 r
F P
0 g
s
.49196 .60929 m .49196 .62781 L .49904 .61945 L p .707 .577 .707 r
F P
0 g
s
.49904 .61945 m .49904 .60092 L .49196 .60929 L p .707 .577 .707 r
F P
0 g
s
.71504 .61778 m .71504 .65484 L .68566 .65822 L p .707 .577 .707 r
F P
0 g
s
.71504 .65484 m .71504 .61778 L .74688 .61701 L p .707 .577 .707 r
F P
0 g
s
.49196 .61773 m .49196 .65478 L .49904 .64642 L p .707 .577 .707 r
F P
0 g
s
.49904 .64642 m .49904 .60936 L .49196 .61773 L p .707 .577 .707 r
F P
0 g
s
.74688 .60856 m .74688 .62709 L .71504 .62787 L p .707 .577 .707 r
F P
0 g
s
.74688 .61701 m .74688 .65406 L .71504 .65484 L p .707 .577 .707 r
F P
0 g
s
.29804 .64752 m .29804 .59194 L .29515 .5834 L p .707 .577 .707 r
F P
0 g
s
.29804 .62436 m .29804 .60583 L .29515 .59729 L p .707 .577 .707 r
F P
0 g
s
.29804 .65133 m .29804 .61427 L .29515 .60573 L p .707 .577 .707 r
F P
0 g
s
.29515 .59729 m .29515 .61581 L .29804 .62436 L p .707 .577 .707 r
F P
0 g
s
.29515 .5834 m .29515 .63898 L .29804 .64752 L p .707 .577 .707 r
F P
0 g
s
.29515 .60573 m .29515 .64278 L .29804 .65133 L p .707 .577 .707 r
F P
0 g
s
.49904 .58703 m .49904 .64262 L .49615 .63407 L p .707 .577 .707 r
F P
0 g
s
.49615 .63407 m .49615 .57849 L .49904 .58703 L p .707 .577 .707 r
F P
0 g
s
.49904 .60092 m .49904 .61945 L .49615 .61091 L p .707 .577 .707 r
F P
0 g
s
.49615 .61091 m .49615 .59238 L .49904 .60092 L p .707 .577 .707 r
F P
0 g
s
.49904 .60936 m .49904 .64642 L .49615 .63788 L p .707 .577 .707 r
F P
0 g
s
.49615 .63788 m .49615 .60082 L .49904 .60936 L p .707 .577 .707 r
F P
0 g
s
.29515 .63898 m .29515 .5834 L .30223 .57503 L p .707 .577 .707 r
F P
0 g
s
.29515 .61581 m .29515 .59729 L .30223 .58892 L p .707 .577 .707 r
F P
0 g
s
.29515 .64278 m .29515 .60573 L .30223 .59736 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30223 .58892 m .30223 .60745 L .29515 .61581 L p .707 .577 .707 r
F P
0 g
s
.30223 .57503 m .30223 .63062 L .29515 .63898 L p .707 .577 .707 r
F P
0 g
s
.30223 .59736 m .30223 .63442 L .29515 .64278 L p .707 .577 .707 r
F P
0 g
s
.49615 .57849 m .49615 .63407 L .48356 .62619 L p .707 .577 .707 r
F P
0 g
s
.48356 .62619 m .48356 .57061 L .49615 .57849 L p .707 .577 .707 r
F P
0 g
s
.49615 .59238 m .49615 .61091 L .48356 .60302 L p .707 .577 .707 r
F P
0 g
s
.48356 .60302 m .48356 .5845 L .49615 .59238 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49615 .60082 m .49615 .63788 L .48356 .62999 L p .707 .577 .707 r
F P
0 g
s
.48356 .62999 m .48356 .59294 L .49615 .60082 L p .707 .577 .707 r
F P
0 g
s
.30223 .63062 m .30223 .57503 L .3186 .56767 L p .707 .577 .707 r
F P
0 g
s
.30223 .60745 m .30223 .58892 L .3186 .58155 L p .707 .577 .707 r
F P
0 g
s
.30223 .63442 m .30223 .59736 L .3186 .59 L p .707 .577 .707 r
F P
0 g
s
.3186 .58155 m .3186 .60008 L .30223 .60745 L p .707 .577 .707 r
F P
0 g
s
.3186 .56767 m .3186 .62325 L .30223 .63062 L p .707 .577 .707 r
F P
0 g
s
.48356 .57061 m .48356 .62619 L .4625 .61974 L p .707 .577 .707 r
F P
0 g
s
.4625 .61974 m .4625 .56415 L .48356 .57061 L p .707 .577 .707 r
F P
0 g
s
.3186 .59 m .3186 .62705 L .30223 .63442 L p .707 .577 .707 r
F P
0 g
s
.48356 .5845 m .48356 .60302 L .4625 .59657 L p .707 .577 .707 r
F P
0 g
s
.4625 .59657 m .4625 .57804 L .48356 .5845 L p .707 .577 .707 r
F P
0 g
s
.48356 .59294 m .48356 .62999 L .4625 .62354 L p .707 .577 .707 r
F P
0 g
s
.4625 .62354 m .4625 .58648 L .48356 .59294 L p .707 .577 .707 r
F P
0 g
s
.3186 .62325 m .3186 .56767 L .34265 .56202 L p .707 .577 .707 r
F P
0 g
s
.3186 .60008 m .3186 .58155 L .34265 .5759 L p .707 .577 .707 r
F P
0 g
s
.3186 .62705 m .3186 .59 L .34265 .58435 L p .707 .577 .707 r
F P
0 g
s
.34265 .5759 m .34265 .59443 L .3186 .60008 L p .707 .577 .707 r
F P
0 g
s
.4625 .56415 m .4625 .61974 L .43504 .61534 L p .707 .577 .707 r
F P
0 g
s
.43504 .61534 m .43504 .55976 L .4625 .56415 L p .707 .577 .707 r
F P
0 g
s
.34265 .56202 m .34265 .6176 L .3186 .62325 L p .707 .577 .707 r
F P
0 g
s
.4625 .57804 m .4625 .59657 L .43504 .59218 L p .707 .577 .707 r
F P
0 g
s
.43504 .59218 m .43504 .57365 L .4625 .57804 L p .707 .577 .707 r
F P
0 g
s
.34265 .58435 m .34265 .6214 L .3186 .62705 L p .707 .577 .707 r
F P
0 g
s
.4625 .58648 m .4625 .62354 L .43504 .61915 L p .707 .577 .707 r
F P
0 g
s
.43504 .61915 m .43504 .58209 L .4625 .58648 L p .707 .577 .707 r
F P
0 g
s
.34265 .6176 m .34265 .56202 L .37203 .55864 L p .707 .577 .707 r
F P
0 g
s
.34265 .59443 m .34265 .5759 L .37203 .57253 L p .707 .577 .707 r
F P
0 g
s
.34265 .6214 m .34265 .58435 L .37203 .58097 L p .707 .577 .707 r
F P
0 g
s
.43504 .55976 m .43504 .61534 L .40387 .61344 L p .707 .577 .707 r
F P
0 g
s
.40387 .61344 m .40387 .55786 L .43504 .55976 L p .707 .577 .707 r
F P
0 g
s
.37203 .57253 m .37203 .59105 L .34265 .59443 L p .707 .577 .707 r
F P
0 g
s
.43504 .57365 m .43504 .59218 L .40387 .59028 L p .707 .577 .707 r
F P
0 g
s
.40387 .59028 m .40387 .57175 L .43504 .57365 L p .707 .577 .707 r
F P
0 g
s
.37203 .61422 m .37203 .55864 L .40387 .55786 L p .707 .577 .707 r
F P
0 g
s
.37203 .55864 m .37203 .61422 L .34265 .6176 L p .707 .577 .707 r
F P
0 g
s
.43504 .58209 m .43504 .61915 L .40387 .61725 L p .707 .577 .707 r
F P
0 g
s
.40387 .61725 m .40387 .58019 L .43504 .58209 L p .707 .577 .707 r
F P
0 g
s
.40387 .55786 m .40387 .61344 L .37203 .61422 L p .707 .577 .707 r
F P
0 g
s
.37203 .59105 m .37203 .57253 L .40387 .57175 L p .707 .577 .707 r
F P
0 g
s
.37203 .58097 m .37203 .61802 L .34265 .6214 L p .707 .577 .707 r
F P
0 g
s
.37203 .61802 m .37203 .58097 L .40387 .58019 L p .707 .577 .707 r
F P
0 g
s
.40387 .57175 m .40387 .59028 L .37203 .59105 L p .707 .577 .707 r
F P
0 g
s
.40387 .58019 m .40387 .61725 L .37203 .61802 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo002;Ool<
0026Ool007moo``000EJEP03001JEUYF00AJEPT007eoo`00MWoo2@001EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01P00Mgoo001aOol50002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP06FUH4001cOol006ioo`<000MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<006moo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH2001[Ool006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00
001YOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH0001XOol006Ioo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo4P0000=JEP00FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001POol60003FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005aoo`@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`<000EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000QJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P00
00=JEP00FUH01EYF00<005YFFUH00UYF0P0000=JEP000000300015YF00<005YFFUH01EYF00<005YF
FUH00UYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001EOol20003FUH00`00FUIJEP04FUH50003FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH80004FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Aoo`8000AJEP03001JEP0000<00003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH60004FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEPD000AJEPd000AJEP03001JEP0000800003
FUH005YF009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005=oo`04001JEP00FUH200000eYF001JEP05FUH40004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P000eYF0P000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00@005YF000000=JEP<000AJEP03
001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEP000080
0006FUH00000001JEP000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001COol300001EYF001JEUYF00001UYF00<005YFFUH01EYF1@0015YF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol01000FUH0
00000eYF00<005YFFUH015YF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF0`0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000mooaX003aoo`00Dgoo0`0015YF0`0015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo1`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo00D005YF001JEP00
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000dOol005=oo`04001JEP000003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000Woo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00000P000UYF00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF5P00
0eYF00<005YFFUH00eYF0`00<7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
000015YF00H005YFFUIJEP00FUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF
1@0015YF00<005YFFUH00P00;Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUHA0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF10000UYF00<005YFFUH00UYF
00@005YFFUIJEPH000=JEPD000AJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF009JEP03
001oogoo02aoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF2000
15YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH50004FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP02FUH20003FUH2000]Ool005=oo`03001JEP0000AJ
EP03001JEP0000<0009JEPD00003FUH0000000AJEP03001JEUYF00=JEPT0009JEPH000AJEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000eYF00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH50004FUH300000eYF0000000]Ool005=oo`03001JEP0000=JEP<00003FUH00000
00MJEP04001JEUYFFUH:0004FUH00`00FUIJEP05FUH00`00FUH0000500000eYF001JEP02FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF0P0015YF00<0
05YFFUH01UYF1`000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0000AJEP00FUIJ
EP<002eoo`00Dgoo00@005YF001JEP8000EJEP04001JEUYFFUH20002FUH00`00FUIJEP05FUH50005
FUH00`00FUIJEP02FUH50005FUH30003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`0000EJEP00FUIJEP0000EJEP@000EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000=JEP8002eoo`00Dgoo00H005YF000005YF0003
FUH00`00FUH00005FUH30003FUHC0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001J
EP0000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP<00003FUH0000002eoo`00Dgoo0P000eYF00<005YFFUH00UYF0P001eYF00<005YFFUH0
1EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF00<002eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF100000=JEP00000015YF
10001UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@002EYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@0017oo00D005YFFUIJEP0000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOol80004FUH00`00FUIJEP02FUH50003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
=goo20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0`0000=JEP00FUH015YF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00AJEP03001JEUYF00=JEP03001JEUYF009JEQX000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool0039oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<0
00AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<005YFFUH01UYF00<005YFFUH00UYF2000
15YF00@005YFFUIJEP8002eoo`00<7oo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P0000=JEP00
0000300015YF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000=JEPD000EJEP<0009JEQ@000=JEP04001JEUYFFUH40000
0eYF001JEP02FUH2000]Ool002ioo`8000=JEP03001JEUYF00AJEPD000=JEP03001JEUYF00IJEP03
001JEUYF009JEPP000AJEPH000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20003FUH20007FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP02FUH70003FUH30003FUH2000]
Ool002eoo`8000AJEP03001JEP0000<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH60004FUH80004FUH00`00FUIJEP03FUH90007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00
FUIJEP02FUH40003FUH00`00FUIJEP02FUH>0003FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF
0000000]Ool002eoo`8000AJEP8000EJEP03001JEUYF00EJEPD000AJEPd000AJEP03001JEP000080
0005FUH005YFFUH00002FUH00`00FUH000090004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01`00FUIJEUYF
001JEP0000MJEP03001JEUYF00=JEPP000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJEP@000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH60003FUH20002FUH01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000UYF00<005YFFUH00UYF0P001eYF00<005YFFUH01UYF1@0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Goo000/Ool01000FUH000000eYF0`0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0000=J
EP0000000P000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH00eYF0`000UYF2P001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
00<005YF0000;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70002FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUIJEP001EYF1@001EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool50002FUH0
0`00FUIJEP04FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200001EYF001JEUYF00001EYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00<005YFFUH00UYF0P00;Woo000/Ool00`00FUH00004FUH30004FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YF
FUH00eYF1@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00;7oo
00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000035oo`00;7oo00@005YF000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH40005FUH20008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000400000eYF001JEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH5000jOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH40003FUH00`00FUH0000H000oOol002aoo`03001JEP0000AJ
EP03001JEUYF00=JEPL000MJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=JEP04001JEUYF0002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00FUIJ
EP040003FUH00`00Oomoo`1COol002aoo`03001JEP0000AJEP03001JEP0000<0009JEPD00003FUH0
000000AJEP03001JEUYF00MJEP03001JEUYF009JEPP000AJEP04001JEUYF0002FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH50004FUH20002FUH20008Ool30019
Ool002aoo`03001JEP0000=JEPH000MJEP04001JEUYFFUHC0003FUH00`00FUH0000500001EYF001J
EUYF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YF00000P0000=JEP00FUH010001goo1@00B7oo000/Ool01000FUH005YF0P001EYF00@005YFFUIJ
EP80009JEP03001JEUYF00EJEP@000IJEP03001JEUYF009JEPD000EJEP<0009JEP04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP02FUH20003FUH20007
Ool50018Ool002aoo`06001JEP00001JEP000eYF00<005YF00001EYF0`000eYF4`000eYF00<005YF
FUH015YF00<005YFFUH00`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH00eYF0`0000=JEP0000001goo1@00B7oo000/Ool20003FUH00`00FUIJ
EP02FUH20007FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH00eYF00<005YFFUH00`0027oo0`00BGoo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH01000FUIJEP001eYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00=JEP<0009J
EPT000IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
E7oo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol002eo
o`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;Woo0P0000=J
EP00FUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008000=JEP03001JEUYF00=JEP04001JEUYFFUH2001DOol0031oo`<000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001J
EP00001oo`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001`00
15YF00@005YFFUIJEP8005Aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000goo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP04001JEUYFFUH400000eYF001JEP02FUH2001DOol003Ioo`D0
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<000Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000060003FUH30003FUH2001DOol0
03]oo`P000AJEP03001JEUYF00MJEP03001JEUYF009JEPD000Yoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00E7oo
0013OolC000?Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF
00<005YFFUH015YF00@005YFFUIJEP@005Aoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<005Aoo`00B7oo0`00
6Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00MJEQD000IJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP<0
05Aoo`00Agoo1@006Goo00@005YFFUH000EJEP03001JEUYF00MJEP04001JEUYFFUH60009FUH00`00
FUIJEP09FUH<0005FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0001DOol004Moo`D001Uoo`04001JEUYF0005FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJEP02
FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol004Moo`D001Uoo`04001J
EUYF0005FUH00`00FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P00EWoo0018Ool3000JOol01000FUIJEP001EYF0`000UYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF0`0000=JEP00FUH00eYF00<005YF
00000UYF00<005YFFUH015YF00@005YF000005Qoo`00IGoo00@005YFFUH000=JEP8000EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EP000004FUH00`00FUH00002FUH00`00FUIJEP03FUH3001JOol006Eoo`05001JEUYF001JEP020007
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF00<005YF00000UYF00<005YF00000`00GGoo001UOol00`00FUIJEP02
00000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH300000eYF00000003001QOol006Eoo`03001JEP0000=J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP800003FUH007oo06Aoo`00IGoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH015YF0P0000=JEP00Ool0I7oo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01000FUH00000IGoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH0
0000IGoo001UOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP00IGoo001VOol0
0`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH0001VOol006Ioo`03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Moo`00Igoo0P000UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF0P00J7oo001YOol30007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P00JWoo001[Ool20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
0000K7oo001]Ool40002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH4001^Ool0075oo`D000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00D0079oo`00MWoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH01UYF1@00Mgoo001lOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP06001lOol008Eo
oaH0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]31\[InvisibleSpace]"     "\
\[InvisibleSpace]10.224504837396527`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 31, "     ", 10.224504837396527, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59951 .75494 m .59237 .70069 L .56136 .70221 L p .707 .577 .707 r
F P
0 g
s
.59237 .70069 m .59951 .75494 L .63106 .75016 L p .707 .577 .707 r
F P
0 g
s
.63106 .75016 m .62393 .69592 L .59237 .70069 L p .707 .577 .707 r
F P
0 g
s
.62393 .69592 m .63106 .75016 L .66006 .74259 L p .707 .577 .707 r
F P
0 g
s
.66006 .74259 m .65293 .68835 L .62393 .69592 L p .707 .577 .707 r
F P
0 g
s
.56849 .75645 m .56136 .70221 L .53391 .70032 L p .707 .577 .707 r
F P
0 g
s
.56136 .70221 m .56849 .75645 L .59951 .75494 L p .707 .577 .707 r
F P
0 g
s
.65293 .68835 m .66006 .74259 L .68367 .73297 L p .707 .577 .707 r
F P
0 g
s
.68367 .73297 m .67654 .67873 L .65293 .68835 L p .707 .577 .707 r
F P
0 g
s
.54104 .75456 m .53391 .70032 L .51272 .69521 L p .707 .577 .707 r
F P
0 g
s
.53391 .70032 m .54104 .75456 L .56849 .75645 L p .707 .577 .707 r
F P
0 g
s
.63622 .8123 m .62456 .77863 L .59425 .78876 L p .707 .577 .707 r
F P
0 g
s
.62456 .77863 m .63622 .8123 L .6641 .79907 L p .707 .577 .707 r
F P
0 g
s
.6641 .79907 m .65244 .7654 L .62456 .77863 L p .707 .577 .707 r
F P
0 g
s
.60591 .82243 m .59425 .78876 L .56448 .79478 L p .707 .577 .707 r
F P
0 g
s
.59425 .78876 m .60591 .82243 L .63622 .8123 L p .707 .577 .707 r
F P
0 g
s
.67654 .67873 m .68367 .73297 L .69957 .72225 L p .707 .577 .707 r
F P
0 g
s
.69957 .72225 m .69244 .668 L .67654 .67873 L p .707 .577 .707 r
F P
0 g
s
.65244 .7654 m .6641 .79907 L .68683 .78401 L p .707 .577 .707 r
F P
0 g
s
.68683 .78401 m .67516 .75034 L .65244 .7654 L p .707 .577 .707 r
F P
0 g
s
.57614 .82845 m .56448 .79478 L .53817 .79611 L p .707 .577 .707 r
F P
0 g
s
.56448 .79478 m .57614 .82845 L .60591 .82243 L p .707 .577 .707 r
F P
0 g
s
.62846 .85584 m .62254 .83902 L .59222 .84904 L p .707 .577 .707 r
F P
0 g
s
.62254 .83902 m .62846 .85584 L .65655 .84265 L p .707 .577 .707 r
F P
0 g
s
.65655 .84265 m .65062 .82583 L .62254 .83902 L p .707 .577 .707 r
F P
0 g
s
.51272 .69521 m .51985 .74945 L .54104 .75456 L p .707 .577 .707 r
F P
0 g
s
.59815 .86586 m .59222 .84904 L .56264 .85492 L p .707 .577 .707 r
F P
0 g
s
.59222 .84904 m .59815 .86586 L .62846 .85584 L p .707 .577 .707 r
F P
0 g
s
.51985 .74945 m .51272 .69521 L .49987 .68737 L p .707 .577 .707 r
F P
0 g
s
.65062 .82583 m .65655 .84265 L .67966 .82759 L p .707 .577 .707 r
F P
0 g
s
.67966 .82759 m .67374 .81077 L .65062 .82583 L p .707 .577 .707 r
F P
0 g
s
.67516 .75034 m .68683 .78401 L .70217 .76861 L p .707 .577 .707 r
F P
0 g
s
.70217 .76861 m .69051 .73494 L .67516 .75034 L p .707 .577 .707 r
F P
0 g
s
.56264 .85492 m .56857 .87174 L .59815 .86586 L p .707 .577 .707 r
F P
0 g
s
.53817 .79611 m .54983 .82978 L .57614 .82845 L p .707 .577 .707 r
F P
0 g
s
.56857 .87174 m .56264 .85492 L .5367 .85607 L p .707 .577 .707 r
F P
0 g
s
.54983 .82978 m .53817 .79611 L .51788 .79261 L p .707 .577 .707 r
F P
0 g
s
.69244 .668 m .69957 .72225 L .70622 .71146 L p .707 .577 .707 r
F P
0 g
s
.70622 .71146 m .69909 .65721 L .69244 .668 L p .707 .577 .707 r
F P
0 g
s
.5367 .85607 m .54263 .87289 L .56857 .87174 L p .707 .577 .707 r
F P
0 g
s
.49987 .68737 m .507 .74162 L .51985 .74945 L p .707 .577 .707 r
F P
0 g
s
.67374 .81077 m .67966 .82759 L .69554 .81212 L p .707 .577 .707 r
F P
0 g
s
.69554 .81212 m .68961 .7953 L .67374 .81077 L p .707 .577 .707 r
F P
0 g
s
.51788 .79261 m .52955 .82628 L .54983 .82978 L p .707 .577 .707 r
F P
0 g
s
.54263 .87289 m .5367 .85607 L .51694 .85239 L p .707 .577 .707 r
F P
0 g
s
.69051 .73494 m .70217 .76861 L .70864 .75437 L p .707 .577 .707 r
F P
0 g
s
.70864 .75437 m .69697 .7207 L .69051 .73494 L p .707 .577 .707 r
F P
0 g
s
.507 .74162 m .49987 .68737 L .4966 .67758 L p .707 .577 .707 r
F P
0 g
s
.52955 .82628 m .51788 .79261 L .50561 .78464 L p .707 .577 .707 r
F P
0 g
s
.51694 .85239 m .52287 .86921 L .54263 .87289 L p .707 .577 .707 r
F P
0 g
s
.69909 .65721 m .70622 .71146 L .70295 .70167 L p .707 .577 .707 r
F P
0 g
s
.70295 .70167 m .69582 .64742 L .69909 .65721 L p .707 .577 .707 r
F P
0 g
s
.68961 .7953 m .69554 .81212 L .70262 .79777 L p .707 .577 .707 r
F P
0 g
s
.70262 .79777 m .69669 .78096 L .68961 .7953 L p .707 .577 .707 r
F P
0 g
s
.50561 .78464 m .51728 .8183 L .52955 .82628 L p .707 .577 .707 r
F P
0 g
s
.4966 .67758 m .50373 .73183 L .507 .74162 L p .707 .577 .707 r
F P
0 g
s
.52287 .86921 m .51694 .85239 L .50528 .84424 L p .707 .577 .707 r
F P
0 g
s
.69697 .7207 m .70864 .75437 L .70558 .7427 L p .707 .577 .707 r
F P
0 g
s
.70558 .7427 m .69392 .70903 L .69697 .7207 L p .707 .577 .707 r
F P
0 g
s
.51038 .72104 m .50325 .6668 L .51915 .65607 L p .707 .577 .707 r
F P
0 g
s
.50902 .75872 m .52069 .79239 L .51422 .80663 L p .707 .577 .707 r
F P
0 g
s
.51915 .65607 m .52628 .71031 L .51038 .72104 L p .707 .577 .707 r
F P
0 g
s
.52628 .71031 m .51915 .65607 L .54276 .64645 L p .707 .577 .707 r
F P
0 g
s
.52069 .79239 m .50902 .75872 L .52437 .74332 L p .707 .577 .707 r
F P
0 g
s
.51728 .8183 m .50561 .78464 L .50256 .77296 L p .707 .577 .707 r
F P
0 g
s
.50256 .77296 m .51422 .80663 L .51728 .8183 L p .707 .577 .707 r
F P
0 g
s
.51588 .83488 m .50996 .81806 L .52583 .8026 L p .707 .577 .707 r
F P
0 g
s
.52583 .8026 m .53176 .81942 L .51588 .83488 L p .707 .577 .707 r
F P
0 g
s
.52047 .82153 m .52047 .31964 L .47535 .31947 L p .707 .577 .707 r
F P
0 g
s
.54276 .64645 m .54989 .70069 L .52628 .71031 L p .707 .577 .707 r
F P
0 g
s
.52437 .74332 m .53603 .77699 L .52069 .79239 L p .707 .577 .707 r
F P
0 g
s
.54989 .70069 m .54276 .64645 L .57176 .63888 L p .707 .577 .707 r
F P
0 g
s
.53603 .77699 m .52437 .74332 L .54709 .72826 L p .707 .577 .707 r
F P
0 g
s
.57176 .63888 m .57889 .69313 L .54989 .70069 L p .707 .577 .707 r
F P
0 g
s
.54709 .72826 m .55876 .76193 L .53603 .77699 L p .707 .577 .707 r
F P
0 g
s
.55876 .76193 m .54709 .72826 L .57497 .71503 L p .707 .577 .707 r
F P
0 g
s
.53176 .81942 m .52583 .8026 L .54894 .78754 L p .707 .577 .707 r
F P
0 g
s
.54894 .78754 m .55487 .80435 L .53176 .81942 L p .707 .577 .707 r
F P
0 g
s
.55487 .80435 m .54894 .78754 L .57703 .77435 L p .707 .577 .707 r
F P
0 g
s
.57703 .77435 m .58296 .79117 L .55487 .80435 L p .707 .577 .707 r
F P
0 g
s
.52047 .31964 m .52047 .82153 L .5636 .81796 L p .707 .577 .707 r
F P
0 g
s
.57497 .71503 m .58664 .7487 L .55876 .76193 L p .707 .577 .707 r
F P
0 g
s
.5636 .81796 m .5636 .31607 L .52047 .31964 L p .707 .577 .707 r
F P
0 g
s
.47535 .82135 m .47535 .31947 L .43264 .31556 L p .707 .577 .707 r
F P
0 g
s
.50373 .73183 m .4966 .67758 L .50325 .6668 L p .707 .577 .707 r
F P
0 g
s
.50325 .6668 m .51038 .72104 L .50373 .73183 L p .707 .577 .707 r
F P
0 g
s
.51422 .80663 m .50256 .77296 L .50902 .75872 L p .707 .577 .707 r
F P
0 g
s
.5088 .84923 m .50288 .83241 L .50996 .81806 L p .707 .577 .707 r
F P
0 g
s
.50996 .81806 m .51588 .83488 L .5088 .84923 L p .707 .577 .707 r
F P
0 g
s
.47535 .31947 m .47535 .82135 L .52047 .82153 L p .707 .577 .707 r
F P
0 g
s
.50528 .84424 m .51121 .86106 L .52287 .86921 L p .707 .577 .707 r
F P
0 g
s
.57889 .69313 m .57176 .63888 L .60331 .63411 L p .707 .577 .707 r
F P
0 g
s
.60331 .63411 m .61044 .68835 L .57889 .69313 L p .707 .577 .707 r
F P
0 g
s
.60528 .7049 m .61695 .73857 L .58664 .7487 L p .707 .577 .707 r
F P
0 g
s
.58664 .7487 m .57497 .71503 L .60528 .7049 L p .707 .577 .707 r
F P
0 g
s
.60735 .76432 m .61327 .78114 L .58296 .79117 L p .707 .577 .707 r
F P
0 g
s
.58296 .79117 m .57703 .77435 L .60735 .76432 L p .707 .577 .707 r
F P
0 g
s
.5636 .31607 m .5636 .81796 L .60049 .81098 L p .707 .577 .707 r
F P
0 g
s
.60049 .81098 m .60049 .3091 L .5636 .31607 L p .707 .577 .707 r
F P
0 g
s
.69669 .78096 m .70262 .79777 L .70021 .78594 L p .707 .577 .707 r
F P
0 g
s
.70021 .78594 m .69428 .76913 L .69669 .78096 L p .707 .577 .707 r
F P
0 g
s
.69582 .64742 m .70295 .70167 L .6901 .69384 L p .707 .577 .707 r
F P
0 g
s
.6901 .69384 m .68296 .63959 L .69582 .64742 L p .707 .577 .707 r
F P
0 g
s
.43264 .81744 m .43264 .31556 L .39652 .30829 L p .707 .577 .707 r
F P
0 g
s
.43264 .31556 m .43264 .81744 L .47535 .82135 L p .707 .577 .707 r
F P
0 g
s
.51121 .86106 m .50528 .84424 L .50288 .83241 L p .707 .577 .707 r
F P
0 g
s
.69392 .70903 m .70558 .7427 L .69331 .73472 L p .707 .577 .707 r
F P
0 g
s
.69331 .73472 m .68165 .70105 L .69392 .70903 L p .707 .577 .707 r
F P
0 g
s
.50288 .83241 m .5088 .84923 L .51121 .86106 L p .707 .577 .707 r
F P
0 g
s
.25554 .70109 m .25245 .64412 L .22122 .64479 L p .707 .577 .707 r
F P
0 g
s
.25245 .64412 m .25554 .70109 L .28728 .69891 L p .707 .577 .707 r
F P
0 g
s
.28728 .69891 m .2842 .64194 L .25245 .64412 L p .707 .577 .707 r
F P
0 g
s
.2842 .64194 m .28728 .69891 L .31643 .69543 L p .707 .577 .707 r
F P
0 g
s
.31643 .69543 m .31335 .63846 L .2842 .64194 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.63433 .63259 m .64146 .68683 L .61044 .68835 L p .707 .577 .707 r
F P
0 g
s
.61044 .68835 m .60331 .63411 L .63433 .63259 L p .707 .577 .707 r
F P
0 g
s
.63505 .69888 m .64671 .73255 L .61695 .73857 L p .707 .577 .707 r
F P
0 g
s
.61695 .73857 m .60528 .7049 L .63505 .69888 L p .707 .577 .707 r
F P
0 g
s
.63692 .75845 m .64285 .77527 L .61327 .78114 L p .707 .577 .707 r
F P
0 g
s
.61327 .78114 m .60735 .76432 L .63692 .75845 L p .707 .577 .707 r
F P
0 g
s
.60049 .3091 m .60049 .81098 L .62755 .80129 L p .707 .577 .707 r
F P
0 g
s
.62755 .80129 m .62755 .2994 L .60049 .3091 L p .707 .577 .707 r
F P
0 g
s
.22431 .70176 m .22122 .64479 L .19357 .64388 L p .707 .577 .707 r
F P
0 g
s
.22122 .64479 m .22431 .70176 L .25554 .70109 L p .707 .577 .707 r
F P
0 g
s
.39652 .81018 m .39652 .30829 L .37053 .29839 L p .707 .577 .707 r
F P
0 g
s
.39652 .30829 m .39652 .81018 L .43264 .81744 L p .707 .577 .707 r
F P
0 g
s
.68296 .63959 m .6901 .69384 L .66891 .68872 L p .707 .577 .707 r
F P
0 g
s
.66891 .68872 m .66178 .63448 L .68296 .63959 L p .707 .577 .707 r
F P
0 g
s
.69428 .76913 m .70021 .78594 L .68855 .77779 L p .707 .577 .707 r
F P
0 g
s
.68855 .77779 m .68263 .76097 L .69428 .76913 L p .707 .577 .707 r
F P
0 g
s
.19357 .64388 m .19665 .70085 L .22431 .70176 L p .707 .577 .707 r
F P
0 g
s
.31335 .63846 m .31643 .69543 L .34014 .69099 L p .707 .577 .707 r
F P
0 g
s
.34014 .69099 m .33705 .63401 L .31335 .63846 L p .707 .577 .707 r
F P
0 g
s
.22318 .71071 m .22834 .74881 L .2594 .74442 L p .707 .577 .707 r
F P
0 g
s
.2594 .74442 m .25423 .70632 L .22318 .71071 L p .707 .577 .707 r
F P
0 g
s
.25423 .70632 m .2594 .74442 L .29086 .74027 L p .707 .577 .707 r
F P
0 g
s
.29086 .74027 m .2857 .70217 L .25423 .70632 L p .707 .577 .707 r
F P
0 g
s
.2857 .70217 m .29086 .74027 L .31967 .73677 L p .707 .577 .707 r
F P
0 g
s
.19665 .70085 m .19357 .64388 L .17219 .64147 L p .707 .577 .707 r
F P
0 g
s
.31967 .73677 m .3145 .69867 L .2857 .70217 L p .707 .577 .707 r
F P
0 g
s
.19558 .71492 m .20074 .75302 L .22834 .74881 L p .707 .577 .707 r
F P
0 g
s
.22834 .74881 m .22318 .71071 L .19558 .71492 L p .707 .577 .707 r
F P
0 g
s
.68165 .70105 m .69331 .73472 L .67303 .73122 L p .707 .577 .707 r
F P
0 g
s
.67303 .73122 m .66136 .69755 L .68165 .70105 L p .707 .577 .707 r
F P
0 g
s
.17219 .64147 m .17527 .69845 L .19665 .70085 L p .707 .577 .707 r
F P
0 g
s
.66178 .63448 m .66891 .68872 L .64146 .68683 L p .707 .577 .707 r
F P
0 g
s
.64146 .68683 m .63433 .63259 L .66178 .63448 L p .707 .577 .707 r
F P
0 g
s
.3145 .69867 m .31967 .73677 L .34298 .73427 L p .707 .577 .707 r
F P
0 g
s
.22138 .76983 m .22399 .78887 L .25491 .78435 L p .707 .577 .707 r
F P
0 g
s
.25491 .78435 m .2523 .76531 L .22138 .76983 L p .707 .577 .707 r
F P
0 g
s
.2523 .76531 m .25491 .78435 L .28644 .78017 L p .707 .577 .707 r
F P
0 g
s
.28644 .78017 m .28383 .76113 L .2523 .76531 L p .707 .577 .707 r
F P
0 g
s
.34298 .73427 m .33782 .69617 L .3145 .69867 L p .707 .577 .707 r
F P
0 g
s
.33705 .63401 m .34014 .69099 L .35608 .68602 L p .707 .577 .707 r
F P
0 g
s
.35608 .68602 m .35299 .62904 L .33705 .63401 L p .707 .577 .707 r
F P
0 g
s
.28383 .76113 m .28644 .78017 L .31549 .77672 L p .707 .577 .707 r
F P
0 g
s
.31549 .77672 m .31288 .75769 L .28383 .76113 L p .707 .577 .707 r
F P
0 g
s
.17414 .71854 m .1793 .75664 L .20074 .75302 L p .707 .577 .707 r
F P
0 g
s
.20074 .75302 m .19558 .71492 L .17414 .71854 L p .707 .577 .707 r
F P
0 g
s
.68263 .76097 m .68855 .77779 L .66879 .77411 L p .707 .577 .707 r
F P
0 g
s
.66879 .77411 m .66286 .75729 L .68263 .76097 L p .707 .577 .707 r
F P
0 g
s
.64671 .73255 m .63505 .69888 L .66136 .69755 L p .707 .577 .707 r
F P
0 g
s
.64285 .77527 m .63692 .75845 L .66286 .75729 L p .707 .577 .707 r
F P
0 g
s
.62755 .2994 m .62755 .80129 L .64212 .78983 L p .707 .577 .707 r
F P
0 g
s
.64212 .78983 m .64212 .28794 L .62755 .2994 L p .707 .577 .707 r
F P
0 g
s
.1941 .77424 m .19671 .79327 L .22399 .78887 L p .707 .577 .707 r
F P
0 g
s
.22399 .78887 m .22138 .76983 L .1941 .77424 L p .707 .577 .707 r
F P
0 g
s
.37053 .80028 m .37053 .29839 L .35721 .28682 L p .707 .577 .707 r
F P
0 g
s
.37053 .29839 m .37053 .80028 L .39652 .81018 L p .707 .577 .707 r
F P
0 g
s
.17527 .69845 m .17219 .64147 L .15918 .63781 L p .707 .577 .707 r
F P
0 g
s
.66136 .69755 m .67303 .73122 L .64671 .73255 L p .707 .577 .707 r
F P
0 g
s
.31288 .75769 m .31549 .77672 L .33922 .77436 L p .707 .577 .707 r
F P
0 g
s
.33922 .77436 m .33661 .75532 L .31288 .75769 L p .707 .577 .707 r
F P
0 g
s
.15918 .63781 m .16227 .69479 L .17527 .69845 L p .707 .577 .707 r
F P
0 g
s
.33782 .69617 m .34298 .73427 L .35853 .73301 L p .707 .577 .707 r
F P
0 g
s
.35853 .73301 m .35337 .69491 L .33782 .69617 L p .707 .577 .707 r
F P
0 g
s
.17312 .7781 m .17573 .79714 L .19671 .79327 L p .707 .577 .707 r
F P
0 g
s
.19671 .79327 m .1941 .77424 L .17312 .7781 L p .707 .577 .707 r
F P
0 g
s
.16095 .7212 m .16611 .7593 L .1793 .75664 L p .707 .577 .707 r
F P
0 g
s
.1793 .75664 m .17414 .71854 L .16095 .7212 L p .707 .577 .707 r
F P
0 g
s
.35608 .68602 m .36269 .68101 L p .35566 .64332 L .707 .577 .707 r
F P
0 g
s
.36269 .68101 m .3596 .62404 L .35299 .62904 L p .707 .577 .707 r
F P
0 g
s
.35853 .73301 m .36479 .73311 L p .35566 .70259 L .707 .577 .707 r
F P
0 g
s
.35337 .69491 m .35554 .71093 L p .35566 .70259 L .707 .577 .707 r
F P
0 g
s
.35554 .71093 m .35853 .73301 L p .35566 .70259 L .707 .577 .707 r
F P
0 g
s
.36479 .73311 m .35963 .69501 L .35337 .69491 L p .707 .577 .707 r
F P
0 g
s
.3596 .62404 m .36269 .68101 L .35932 .67645 L p .707 .577 .707 r
F P
0 g
s
.35932 .67645 m .35647 .62369 L p .3596 .62404 L .707 .577 .707 r
F P
0 g
s
.35647 .62369 m .35624 .61948 L .35645 .61976 L p .707 .577 .707 r
F P
0 g
s
.35645 .61976 m .3596 .62404 L p .35647 .62369 L .707 .577 .707 r
F P
0 g
s
.35269 .75426 m .3553 .7733 L .35552 .77331 L p .707 .577 .707 r
F P
0 g
s
.35552 .77331 m .36217 .77366 L p .3557 .76042 L .707 .577 .707 r
F P
0 g
s
.3557 .76042 m .35269 .75426 L .35552 .77331 L .707 .577 .707 r
F
.36217 .77366 m .35956 .75462 L .35269 .75426 L p F P
0 g
s
.35963 .69501 m .36479 .73311 L .36115 .73456 L p .707 .577 .707 r
F P
0 g
s
.36115 .73456 m .35648 .7001 L p .35963 .69501 L .707 .577 .707 r
F P
0 g
s
.35648 .7001 m .35598 .69646 L .35644 .69628 L p .707 .577 .707 r
F P
0 g
s
.35644 .69628 m .35963 .69501 L p .35648 .7001 L .707 .577 .707 r
F P
0 g
s
.35299 .62904 m .35548 .67494 L p .35566 .64332 L .707 .577 .707 r
F P
0 g
s
.35548 .67494 m .35608 .68602 L p .35566 .64332 L .707 .577 .707 r
F P
0 g
s
.35624 .61948 m .35932 .67645 L .34632 .67279 L p .707 .577 .707 r
F P
0 g
s
.35956 .75462 m .36217 .77366 L .35915 .77539 L p .707 .577 .707 r
F P
0 g
s
.35915 .77539 m .35654 .75635 L .35956 .75462 L p .707 .577 .707 r
F P
0 g
s
.35598 .69646 m .36115 .73456 L .34796 .73723 L p .707 .577 .707 r
F P
0 g
s
.33661 .75532 m .33922 .77436 L .3553 .7733 L p .707 .577 .707 r
F P
0 g
s
.3553 .7733 m .35269 .75426 L .33661 .75532 L p .707 .577 .707 r
F P
0 g
s
.35654 .75635 m .35915 .77539 L .34653 .77834 L p .707 .577 .707 r
F P
0 g
s
.35721 .28682 m .35721 .78871 L .37053 .80028 L p .707 .577 .707 r
F P
0 g
s
.35787 .7766 m .35736 .78607 L p .35784 .31083 L .707 .577 .707 r
F P
0 g
s
.35736 .78607 m .35733 .78656 L p .35733 .78374 L .707 .577 .707 r
F P
0 g
s
.35733 .78374 m .35784 .31083 L .35736 .78607 L .707 .577 .707 r
F
.35724 .76915 m .3574 .64122 L .35733 .78656 L F
.3574 .64122 m .35788 .27472 L .35749 .63501 L F
.3574 .64122 m .35749 .63501 L .35733 .78656 L F
.35788 .27472 m .35788 .3123 L p .35784 .31083 L F P
0 g
s
.35788 .3123 m .35787 .7766 L p .35784 .31083 L .707 .577 .707 r
F P
0 g
s
.35733 .78656 m .35721 .78871 L p .35724 .76915 L .707 .577 .707 r
F P
0 g
s
.35748 .58162 m .35721 .36902 L .35788 .27472 L .707 .577 .707 r
F
.35721 .78871 m .35721 .59936 L p .35748 .58162 L F P
0 g
s
.35721 .59936 m .35721 .36902 L p .35748 .58162 L .707 .577 .707 r
F P
0 g
s
.35721 .36902 m .35721 .28682 L .35774 .27727 L p .707 .577 .707 r
F P
0 g
s
.35774 .27727 m .35788 .27472 L p .35721 .36902 L .707 .577 .707 r
F P
0 g
s
.66286 .75729 m .66879 .77411 L .64285 .77527 L p .707 .577 .707 r
F P
0 g
s
.16227 .69479 m .15918 .63781 L .15582 .63326 L p .707 .577 .707 r
F P
0 g
s
.16051 .78104 m .16311 .80008 L .17573 .79714 L p .707 .577 .707 r
F P
0 g
s
.17573 .79714 m .17312 .7781 L .16051 .78104 L p .707 .577 .707 r
F P
0 g
s
.64212 .28794 m .64212 .78983 L .64267 .77988 L p .707 .577 .707 r
F P
0 g
s
.64276 .75909 m .64212 .28794 L .64267 .77988 L .707 .577 .707 r
F
.64278 .77772 m .64278 .27584 L .64212 .28794 L p F P
0 g
s
.64267 .77988 m .64278 .77772 L p .64276 .75909 L .707 .577 .707 r
F P
0 g
s
.64278 .27584 m .64278 .77772 L .62947 .76615 L p .707 .577 .707 r
F P
0 g
s
.64067 .63462 m .64353 .58534 L p .6404 .56905 L .707 .577 .707 r
F P
0 g
s
.64353 .58534 m .64376 .58142 L .64355 .58065 L p .707 .577 .707 r
F P
0 g
s
.64355 .58065 m .6404 .56905 L p .64353 .58534 L .707 .577 .707 r
F P
0 g
s
.15582 .63326 m .1589 .69023 L .16227 .69479 L p .707 .577 .707 r
F P
0 g
s
.15731 .72266 m .16247 .76076 L .16611 .7593 L p .707 .577 .707 r
F P
0 g
s
.16611 .7593 m .16095 .7212 L .15731 .72266 L p .707 .577 .707 r
F P
0 g
s
.1589 .69023 m .15582 .63326 L .16243 .62825 L p .707 .577 .707 r
F P
0 g
s
.15748 .78278 m .16009 .80181 L .16311 .80008 L p .707 .577 .707 r
F P
0 g
s
.16311 .80008 m .16051 .78104 L .15748 .78278 L p .707 .577 .707 r
F P
0 g
s
.16243 .62825 m .16551 .68522 L .1589 .69023 L p .707 .577 .707 r
F P
0 g
s
.16356 .72276 m .16873 .76086 L .16247 .76076 L p .707 .577 .707 r
F P
0 g
s
.16247 .76076 m .15731 .72266 L .16356 .72276 L p .707 .577 .707 r
F P
0 g
s
.62947 .76615 m .62947 .26426 L .64278 .27584 L p .707 .577 .707 r
F P
0 g
s
.34632 .67279 m .34323 .61582 L .35624 .61948 L p .707 .577 .707 r
F P
0 g
s
.35787 .7766 m .35788 .27472 L .37245 .26325 L p .707 .577 .707 r
F P
0 g
s
.16551 .68522 m .16243 .62825 L .17837 .62328 L p .707 .577 .707 r
F P
0 g
s
.16435 .78313 m .16696 .80217 L .16009 .80181 L p .707 .577 .707 r
F P
0 g
s
.16009 .80181 m .15748 .78278 L .16435 .78313 L p .707 .577 .707 r
F P
0 g
s
.17837 .62328 m .18145 .68025 L .16551 .68522 L p .707 .577 .707 r
F P
0 g
s
.34796 .73723 m .34279 .69913 L .35598 .69646 L p .707 .577 .707 r
F P
0 g
s
.17911 .72149 m .18428 .75959 L .16873 .76086 L p .707 .577 .707 r
F P
0 g
s
.16873 .76086 m .16356 .72276 L .17911 .72149 L p .707 .577 .707 r
F P
0 g
s
.34323 .61582 m .34632 .67279 L .32494 .67039 L p .707 .577 .707 r
F P
0 g
s
.32494 .67039 m .32185 .61342 L .34323 .61582 L p .707 .577 .707 r
F P
0 g
s
.34653 .77834 m .34392 .7593 L .35654 .75635 L p .707 .577 .707 r
F P
0 g
s
.18145 .68025 m .17837 .62328 L .20207 .61884 L p .707 .577 .707 r
F P
0 g
s
.62947 .26426 m .62947 .76615 L .60348 .75625 L p .707 .577 .707 r
F P
0 g
s
.60348 .75625 m .60348 .25436 L .62947 .26426 L p .707 .577 .707 r
F P
0 g
s
.37245 .76514 m .37245 .26325 L .39951 .25356 L p .707 .577 .707 r
F P
0 g
s
.37245 .26325 m .37245 .76514 L .35787 .7766 L p .707 .577 .707 r
F P
0 g
s
.20207 .61884 m .20516 .67581 L .18145 .68025 L p .707 .577 .707 r
F P
0 g
s
.18044 .78208 m .18304 .80111 L .16696 .80217 L p .707 .577 .707 r
F P
0 g
s
.16696 .80217 m .16435 .78313 L .18044 .78208 L p .707 .577 .707 r
F P
0 g
s
.34279 .69913 m .34796 .73723 L .32651 .74084 L p .707 .577 .707 r
F P
0 g
s
.32651 .74084 m .32135 .70274 L .34279 .69913 L p .707 .577 .707 r
F P
0 g
s
.32185 .61342 m .32494 .67039 L .29728 .66948 L p .707 .577 .707 r
F P
0 g
s
.29728 .66948 m .2942 .61251 L .32185 .61342 L p .707 .577 .707 r
F P
0 g
s
.20243 .71899 m .20759 .75709 L .18428 .75959 L p .707 .577 .707 r
F P
0 g
s
.18428 .75959 m .17911 .72149 L .20243 .71899 L p .707 .577 .707 r
F P
0 g
s
.20516 .67581 m .20207 .61884 L .23122 .61536 L p .707 .577 .707 r
F P
0 g
s
.34392 .7593 m .34653 .77834 L .32555 .7822 L p .707 .577 .707 r
F P
0 g
s
.32555 .7822 m .32294 .76316 L .34392 .7593 L p .707 .577 .707 r
F P
0 g
s
.23122 .61536 m .23431 .67233 L .20516 .67581 L p .707 .577 .707 r
F P
0 g
s
.2942 .61251 m .29728 .66948 L .26605 .67015 L p .707 .577 .707 r
F P
0 g
s
.26605 .67015 m .26297 .61317 L .2942 .61251 L p .707 .577 .707 r
F P
0 g
s
.73395 .66821 m .73703 .615 L .7058 .61092 L p .707 .577 .707 r
F P
0 g
s
.73703 .615 m .73395 .66821 L .76569 .66849 L p .707 .577 .707 r
F P
0 g
s
.76569 .66849 m .76877 .61528 L .73703 .615 L p .707 .577 .707 r
F P
0 g
s
.23431 .67233 m .23122 .61536 L .26297 .61317 L p .707 .577 .707 r
F P
0 g
s
.76877 .61528 m .76569 .66849 L .79484 .66493 L p .707 .577 .707 r
F P
0 g
s
.79484 .66493 m .79792 .61172 L .76877 .61528 L p .707 .577 .707 r
F P
0 g
s
.32135 .70274 m .32651 .74084 L .29891 .74505 L p .707 .577 .707 r
F P
0 g
s
.70272 .66412 m .7058 .61092 L .67814 .60343 L p .707 .577 .707 r
F P
0 g
s
.7058 .61092 m .70272 .66412 L .73395 .66821 L p .707 .577 .707 r
F P
0 g
s
.29891 .74505 m .29375 .70695 L .32135 .70274 L p .707 .577 .707 r
F P
0 g
s
.20417 .77971 m .20677 .79875 L .18304 .80111 L p .707 .577 .707 r
F P
0 g
s
.18304 .80111 m .18044 .78208 L .20417 .77971 L p .707 .577 .707 r
F P
0 g
s
.26297 .61317 m .26605 .67015 L .23431 .67233 L p .707 .577 .707 r
F P
0 g
s
.60348 .25436 m .60348 .75625 L .56736 .74899 L p .707 .577 .707 r
F P
0 g
s
.56736 .74899 m .56736 .2471 L .60348 .25436 L p .707 .577 .707 r
F P
0 g
s
.23123 .7155 m .23639 .7536 L .20759 .75709 L p .707 .577 .707 r
F P
0 g
s
.20759 .75709 m .20243 .71899 L .23123 .7155 L p .707 .577 .707 r
F P
0 g
s
.39951 .25356 m .39951 .75545 L .37245 .76514 L p .707 .577 .707 r
F P
0 g
s
.39951 .75545 m .39951 .25356 L .4364 .24659 L p .707 .577 .707 r
F P
0 g
s
.79792 .61172 m .79484 .66493 L .81855 .65789 L p .707 .577 .707 r
F P
0 g
s
.81855 .65789 m .82163 .60468 L .79792 .61172 L p .707 .577 .707 r
F P
0 g
s
.67506 .65663 m .67814 .60343 L .65676 .59326 L p .707 .577 .707 r
F P
0 g
s
.67814 .60343 m .67506 .65663 L .70272 .66412 L p .707 .577 .707 r
F P
0 g
s
.29375 .70695 m .29891 .74505 L .26786 .74945 L p .707 .577 .707 r
F P
0 g
s
.32294 .76316 m .32555 .7822 L .29827 .7866 L p .707 .577 .707 r
F P
0 g
s
.26786 .74945 m .2627 .71135 L .29375 .70695 L p .707 .577 .707 r
F P
0 g
s
.29827 .7866 m .29566 .76756 L .32294 .76316 L p .707 .577 .707 r
F P
0 g
s
.2627 .71135 m .26786 .74945 L .23639 .7536 L p .707 .577 .707 r
F P
0 g
s
.23639 .7536 m .23123 .7155 L .2627 .71135 L p .707 .577 .707 r
F P
0 g
s
.23321 .77627 m .23582 .7953 L .20677 .79875 L p .707 .577 .707 r
F P
0 g
s
.20677 .79875 m .20417 .77971 L .23321 .77627 L p .707 .577 .707 r
F P
0 g
s
.73214 .74213 m .7373 .71012 L .70625 .70316 L p .707 .577 .707 r
F P
0 g
s
.7373 .71012 m .73214 .74213 L .7636 .74372 L p .707 .577 .707 r
F P
0 g
s
.7636 .74372 m .76877 .7117 L .7373 .71012 L p .707 .577 .707 r
F P
0 g
s
.56736 .2471 m .56736 .74899 L .52465 .74508 L p .707 .577 .707 r
F P
0 g
s
.52465 .74508 m .52465 .24319 L .56736 .2471 L p .707 .577 .707 r
F P
0 g
s
.4364 .74848 m .4364 .24659 L .47952 .24302 L p .707 .577 .707 r
F P
0 g
s
.4364 .24659 m .4364 .74848 L .39951 .75545 L p .707 .577 .707 r
F P
0 g
s
.70108 .73517 m .70625 .70316 L .67865 .6915 L p .707 .577 .707 r
F P
0 g
s
.70625 .70316 m .70108 .73517 L .73214 .74213 L p .707 .577 .707 r
F P
0 g
s
.82163 .60468 m .81855 .65789 L .83448 .64805 L p .707 .577 .707 r
F P
0 g
s
.83448 .64805 m .83757 .59484 L .82163 .60468 L p .707 .577 .707 r
F P
0 g
s
.29566 .76756 m .29827 .7866 L .26735 .79112 L p .707 .577 .707 r
F P
0 g
s
.76877 .7117 m .7636 .74372 L .79241 .73977 L p .707 .577 .707 r
F P
0 g
s
.79241 .73977 m .79757 .70776 L .76877 .7117 L p .707 .577 .707 r
F P
0 g
s
.26735 .79112 m .26474 .77208 L .29566 .76756 L p .707 .577 .707 r
F P
0 g
s
.26474 .77208 m .26735 .79112 L .23582 .7953 L p .707 .577 .707 r
F P
0 g
s
.23582 .7953 m .23321 .77627 L .26474 .77208 L p .707 .577 .707 r
F P
0 g
s
.65368 .64647 m .65676 .59326 L .64376 .58142 L p .707 .577 .707 r
F P
0 g
s
.65676 .59326 m .65368 .64647 L .67506 .65663 L p .707 .577 .707 r
F P
0 g
s
.67348 .72352 m .67865 .6915 L .6572 .6763 L p .707 .577 .707 r
F P
0 g
s
.67865 .6915 m .67348 .72352 L .70108 .73517 L p .707 .577 .707 r
F P
0 g
s
.52465 .24319 m .52465 .74508 L .47952 .74491 L p .707 .577 .707 r
F P
0 g
s
.47952 .74491 m .47952 .24302 L .52465 .24319 L p .707 .577 .707 r
F P
0 g
s
.47952 .24302 m .47952 .74491 L .4364 .74848 L p .707 .577 .707 r
F P
0 g
s
.73265 .78661 m .73526 .77072 L .70434 .76337 L p .707 .577 .707 r
F P
0 g
s
.73526 .77072 m .73265 .78661 L .76417 .78852 L p .707 .577 .707 r
F P
0 g
s
.76417 .78852 m .76678 .77264 L .73526 .77072 L p .707 .577 .707 r
F P
0 g
s
.79757 .70776 m .79241 .73977 L .81572 .73068 L p .707 .577 .707 r
F P
0 g
s
.81572 .73068 m .82089 .69867 L .79757 .70776 L p .707 .577 .707 r
F P
0 g
s
.70173 .77926 m .70434 .76337 L .67705 .75129 L p .707 .577 .707 r
F P
0 g
s
.70434 .76337 m .70173 .77926 L .73265 .78661 L p .707 .577 .707 r
F P
0 g
s
.76678 .77264 m .76417 .78852 L .79322 .78481 L p .707 .577 .707 r
F P
0 g
s
.79322 .78481 m .79583 .76892 L .76678 .77264 L p .707 .577 .707 r
F P
0 g
s
.83757 .59484 m .83448 .64805 L .8411 .63637 L p .707 .577 .707 r
F P
0 g
s
.8411 .63637 m .84418 .58317 L .83757 .59484 L p .707 .577 .707 r
F P
0 g
s
.64376 .58142 m .64067 .63462 L .65368 .64647 L p .707 .577 .707 r
F P
0 g
s
.67705 .75129 m .67445 .76718 L .70173 .77926 L p .707 .577 .707 r
F P
0 g
s
.67445 .76718 m .67705 .75129 L .65608 .73567 L p .707 .577 .707 r
F P
0 g
s
.65204 .70831 m .6572 .6763 L .64401 .65902 L p .707 .577 .707 r
F P
0 g
s
.6572 .6763 m .65204 .70831 L .67348 .72352 L p .707 .577 .707 r
F P
0 g
s
.79583 .76892 m .79322 .78481 L .81695 .77583 L p .707 .577 .707 r
F P
0 g
s
.81695 .77583 m .81956 .75994 L .79583 .76892 L p .707 .577 .707 r
F P
0 g
s
.82089 .69867 m .81572 .73068 L .83127 .71734 L p .707 .577 .707 r
F P
0 g
s
.83127 .71734 m .83643 .68532 L .82089 .69867 L p .707 .577 .707 r
F P
0 g
s
.65608 .73567 m .65347 .75156 L .67445 .76718 L p .707 .577 .707 r
F P
0 g
s
.65347 .75156 m .65608 .73567 L .64346 .71805 L p .707 .577 .707 r
F P
0 g
s
.64401 .65902 m .63885 .69104 L .65204 .70831 L p .707 .577 .707 r
F P
0 g
s
.81956 .75994 m .81695 .77583 L .83304 .76246 L p .707 .577 .707 r
F P
0 g
s
.83304 .76246 m .83565 .74657 L .81956 .75994 L p .707 .577 .707 r
F P
0 g
s
.63885 .69104 m .64401 .65902 L .64037 .64138 L p .707 .577 .707 r
F P
0 g
s
.6404 .56905 m .63731 .62226 L .64067 .63462 L p .707 .577 .707 r
F P
0 g
s
.84418 .58317 m .8411 .63637 L .83773 .62401 L p .707 .577 .707 r
F P
0 g
s
.83773 .62401 m .84082 .5708 L .84418 .58317 L p .707 .577 .707 r
F P
0 g
s
.64346 .71805 m .64085 .73394 L .65347 .75156 L p .707 .577 .707 r
F P
0 g
s
.83643 .68532 m .83127 .71734 L .83753 .70105 L p .707 .577 .707 r
F P
0 g
s
.83753 .70105 m .84269 .66903 L .83643 .68532 L p .707 .577 .707 r
F P
0 g
s
.63731 .62226 m .6404 .56905 L .64701 .55738 L p .707 .577 .707 r
F P
0 g
s
.64085 .73394 m .64346 .71805 L .64044 .70014 L p .707 .577 .707 r
F P
0 g
s
.64037 .64138 m .63521 .6734 L .63885 .69104 L p .707 .577 .707 r
F P
0 g
s
.83565 .74657 m .83304 .76246 L .83991 .74602 L p .707 .577 .707 r
F P
0 g
s
.83991 .74602 m .84252 .73013 L .83565 .74657 L p .707 .577 .707 r
F P
0 g
s
.63521 .6734 m .64037 .64138 L .64663 .62509 L p .707 .577 .707 r
F P
0 g
s
.64044 .70014 m .63783 .71602 L .64085 .73394 L p .707 .577 .707 r
F P
0 g
s
.64701 .55738 m .64392 .61058 L .63731 .62226 L p .707 .577 .707 r
F P
0 g
s
.84082 .5708 m .83773 .62401 L .82473 .61216 L p .707 .577 .707 r
F P
0 g
s
.82473 .61216 m .82781 .55896 L .84082 .5708 L p .707 .577 .707 r
F P
0 g
s
.84269 .66903 m .83753 .70105 L .83389 .6834 L p .707 .577 .707 r
F P
0 g
s
.83389 .6834 m .83905 .65138 L .84269 .66903 L p .707 .577 .707 r
F P
0 g
s
.64392 .61058 m .64701 .55738 L .66295 .54754 L p .707 .577 .707 r
F P
0 g
s
.63783 .71602 m .64044 .70014 L .64731 .68369 L p .707 .577 .707 r
F P
0 g
s
.38955 .61464 m .39669 .55873 L .36567 .55351 L p .707 .577 .707 r
F P
0 g
s
.39669 .55873 m .38955 .61464 L .42111 .61776 L p .707 .577 .707 r
F P
0 g
s
.42111 .61776 m .42824 .56186 L .39669 .55873 L p .707 .577 .707 r
F P
0 g
s
.64663 .62509 m .64147 .65711 L .63521 .6734 L p .707 .577 .707 r
F P
0 g
s
.84252 .73013 m .83991 .74602 L .83688 .72811 L p .707 .577 .707 r
F P
0 g
s
.83688 .72811 m .83949 .71222 L .84252 .73013 L p .707 .577 .707 r
F P
0 g
s
.42824 .56186 m .42111 .61776 L .45011 .61849 L p .707 .577 .707 r
F P
0 g
s
.45011 .61849 m .45724 .56259 L .42824 .56186 L p .707 .577 .707 r
F P
0 g
s
.35854 .60942 m .36567 .55351 L .33822 .54671 L p .707 .577 .707 r
F P
0 g
s
.36567 .55351 m .35854 .60942 L .38955 .61464 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64147 .65711 m .64663 .62509 L .66218 .61174 L p .707 .577 .707 r
F P
0 g
s
.64731 .68369 m .6447 .69958 L .63783 .71602 L p .707 .577 .707 r
F P
0 g
s
.82781 .55896 m .82473 .61216 L .80335 .60199 L p .707 .577 .707 r
F P
0 g
s
.80335 .60199 m .80643 .54879 L .82781 .55896 L p .707 .577 .707 r
F P
0 g
s
.66295 .54754 m .65986 .60074 L .64392 .61058 L p .707 .577 .707 r
F P
0 g
s
.83905 .65138 m .83389 .6834 L .8207 .66613 L p .707 .577 .707 r
F P
0 g
s
.8207 .66613 m .82586 .63411 L .83905 .65138 L p .707 .577 .707 r
F P
0 g
s
.45724 .56259 m .45011 .61849 L .47372 .61675 L p .707 .577 .707 r
F P
0 g
s
.47372 .61675 m .48085 .56085 L .45724 .56259 L p .707 .577 .707 r
F P
0 g
s
.33822 .54671 m .33109 .60262 L .35854 .60942 L p .707 .577 .707 r
F P
0 g
s
.65986 .60074 m .66295 .54754 L .68665 .54049 L p .707 .577 .707 r
F P
0 g
s
.38305 .66578 m .39472 .62947 L .36495 .61916 L p .707 .577 .707 r
F P
0 g
s
.39472 .62947 m .38305 .66578 L .41336 .6749 L p .707 .577 .707 r
F P
0 g
s
.41336 .6749 m .42502 .63858 L .39472 .62947 L p .707 .577 .707 r
F P
0 g
s
.33109 .60262 m .33822 .54671 L .31703 .539 L p .707 .577 .707 r
F P
0 g
s
.42502 .63858 m .41336 .6749 L .44124 .68193 L p .707 .577 .707 r
F P
0 g
s
.44124 .68193 m .45291 .64562 L .42502 .63858 L p .707 .577 .707 r
F P
0 g
s
.36495 .61916 m .35328 .65547 L .38305 .66578 L p .707 .577 .707 r
F P
0 g
s
.35328 .65547 m .36495 .61916 L .33863 .60866 L p .707 .577 .707 r
F P
0 g
s
.6447 .69958 m .64731 .68369 L .66339 .67033 L p .707 .577 .707 r
F P
0 g
s
.66218 .61174 m .65702 .64376 L .64147 .65711 L p .707 .577 .707 r
F P
0 g
s
.83949 .71222 m .83688 .72811 L .82427 .71048 L p .707 .577 .707 r
F P
0 g
s
.82427 .71048 m .82688 .69459 L .83949 .71222 L p .707 .577 .707 r
F P
0 g
s
.33863 .60866 m .32697 .64497 L .35328 .65547 L p .707 .577 .707 r
F P
0 g
s
.65702 .64376 m .66218 .61174 L .68549 .60265 L p .707 .577 .707 r
F P
0 g
s
.31703 .539 m .3099 .59491 L .33109 .60262 L p .707 .577 .707 r
F P
0 g
s
.80643 .54879 m .80335 .60199 L .77569 .5945 L p .707 .577 .707 r
F P
0 g
s
.77569 .5945 m .77877 .5413 L .80643 .54879 L p .707 .577 .707 r
F P
0 g
s
.66339 .67033 m .66078 .68621 L .6447 .69958 L p .707 .577 .707 r
F P
0 g
s
.38672 .70691 m .39265 .68879 L .36308 .67827 L p .707 .577 .707 r
F P
0 g
s
.39265 .68879 m .38672 .70691 L .41704 .71629 L p .707 .577 .707 r
F P
0 g
s
.41704 .71629 m .42297 .69817 L .39265 .68879 L p .707 .577 .707 r
F P
0 g
s
.45291 .64562 m .44124 .68193 L .46397 .68618 L p .707 .577 .707 r
F P
0 g
s
.46397 .68618 m .47563 .64987 L .45291 .64562 L p .707 .577 .707 r
F P
0 g
s
.82586 .63411 m .8207 .66613 L .79925 .65092 L p .707 .577 .707 r
F P
0 g
s
.79925 .65092 m .80442 .61891 L .82586 .63411 L p .707 .577 .707 r
F P
0 g
s
.68357 .5937 m .68665 .54049 L .7158 .53694 L p .707 .577 .707 r
F P
0 g
s
.68665 .54049 m .68357 .5937 L .65986 .60074 L p .707 .577 .707 r
F P
0 g
s
.48085 .56085 m .47372 .61675 L .48962 .61272 L p .707 .577 .707 r
F P
0 g
s
.48962 .61272 m .49675 .55681 L .48085 .56085 L p .707 .577 .707 r
F P
0 g
s
.36308 .67827 m .35715 .6964 L .38672 .70691 L p .707 .577 .707 r
F P
0 g
s
.32697 .64497 m .33863 .60866 L .31835 .59901 L p .707 .577 .707 r
F P
0 g
s
.42297 .69817 m .41704 .71629 L .44513 .72361 L p .707 .577 .707 r
F P
0 g
s
.44513 .72361 m .45106 .70549 L .42297 .69817 L p .707 .577 .707 r
F P
0 g
s
.35715 .6964 m .36308 .67827 L .33714 .66765 L p .707 .577 .707 r
F P
0 g
s
.3099 .59491 m .31703 .539 L .30418 .53113 L p .707 .577 .707 r
F P
0 g
s
.31835 .59901 m .30668 .63532 L .32697 .64497 L p .707 .577 .707 r
F P
0 g
s
.33714 .66765 m .33121 .68577 L .35715 .6964 L p .707 .577 .707 r
F P
0 g
s
.77877 .5413 m .77569 .5945 L .74446 .59042 L p .707 .577 .707 r
F P
0 g
s
.74446 .59042 m .74755 .53721 L .77877 .5413 L p .707 .577 .707 r
F P
0 g
s
.66078 .68621 m .66339 .67033 L .68712 .66134 L p .707 .577 .707 r
F P
0 g
s
.71272 .59014 m .7158 .53694 L .74755 .53721 L p .707 .577 .707 r
F P
0 g
s
.7158 .53694 m .71272 .59014 L .68357 .5937 L p .707 .577 .707 r
F P
0 g
s
.68033 .63467 m .68549 .60265 L .7143 .59871 L p .707 .577 .707 r
F P
0 g
s
.68549 .60265 m .68033 .63467 L .65702 .64376 L p .707 .577 .707 r
F P
0 g
s
.82688 .69459 m .82427 .71048 L .80329 .69486 L p .707 .577 .707 r
F P
0 g
s
.80329 .69486 m .8059 .67898 L .82688 .69459 L p .707 .577 .707 r
F P
0 g
s
.45106 .70549 m .44513 .72361 L .46824 .72815 L p .707 .577 .707 r
F P
0 g
s
.46824 .72815 m .47417 .71003 L .45106 .70549 L p .707 .577 .707 r
F P
0 g
s
.74755 .53721 m .74446 .59042 L .71272 .59014 L p .707 .577 .707 r
F P
0 g
s
.30418 .53113 m .29704 .58703 L .3099 .59491 L p .707 .577 .707 r
F P
0 g
s
.80442 .61891 m .79925 .65092 L .77165 .63927 L p .707 .577 .707 r
F P
0 g
s
.77165 .63927 m .77682 .60725 L .80442 .61891 L p .707 .577 .707 r
F P
0 g
s
.33121 .68577 m .33714 .66765 L .31737 .65795 L p .707 .577 .707 r
F P
0 g
s
.68712 .66134 m .68451 .67723 L .66078 .68621 L p .707 .577 .707 r
F P
0 g
s
.47563 .64987 m .46397 .68618 L .47931 .68725 L p .707 .577 .707 r
F P
0 g
s
.47931 .68725 m .49098 .65094 L .47563 .64987 L p .707 .577 .707 r
F P
0 g
s
.31737 .65795 m .31144 .67607 L .33121 .68577 L p .707 .577 .707 r
F P
0 g
s
.30668 .63532 m .31835 .59901 L .30608 .59115 L p .707 .577 .707 r
F P
0 g
s
.70913 .63073 m .7143 .59871 L .74576 .60029 L p .707 .577 .707 r
F P
0 g
s
.7143 .59871 m .70913 .63073 L .68033 .63467 L p .707 .577 .707 r
F P
0 g
s
.49675 .55681 m .48962 .61272 L .49627 .60678 L p .707 .577 .707 r
F P
0 g
s
.49627 .60678 m .5034 .55087 L .49675 .55681 L p .707 .577 .707 r
F P
0 g
s
.30608 .59115 m .29441 .62746 L .30668 .63532 L p .707 .577 .707 r
F P
0 g
s
.77682 .60725 m .77165 .63927 L .7406 .63231 L p .707 .577 .707 r
F P
0 g
s
.7406 .63231 m .74576 .60029 L .77682 .60725 L p .707 .577 .707 r
F P
0 g
s
.68451 .67723 m .68712 .66134 L .71617 .65763 L p .707 .577 .707 r
F P
0 g
s
.74576 .60029 m .7406 .63231 L .70913 .63073 L p .707 .577 .707 r
F P
0 g
s
.29704 .58703 m .30418 .53113 L .30091 .52387 L p .707 .577 .707 r
F P
0 g
s
.8059 .67898 m .80329 .69486 L .77601 .68279 L p .707 .577 .707 r
F P
0 g
s
.77601 .68279 m .77862 .6669 L .8059 .67898 L p .707 .577 .707 r
F P
0 g
s
.47417 .71003 m .46824 .72815 L .48411 .72948 L p .707 .577 .707 r
F P
0 g
s
.48411 .72948 m .49004 .71136 L .47417 .71003 L p .707 .577 .707 r
F P
0 g
s
.71617 .65763 m .71356 .67352 L .68451 .67723 L p .707 .577 .707 r
F P
0 g
s
.31144 .67607 m .31737 .65795 L .30571 .65013 L p .707 .577 .707 r
F P
0 g
s
.71356 .67352 m .71617 .65763 L .7477 .65954 L p .707 .577 .707 r
F P
0 g
s
.77862 .6669 m .77601 .68279 L .74509 .67543 L p .707 .577 .707 r
F P
0 g
s
.74509 .67543 m .7477 .65954 L .77862 .6669 L p .707 .577 .707 r
F P
0 g
s
.30571 .65013 m .29979 .66825 L .31144 .67607 L p .707 .577 .707 r
F P
0 g
s
.30091 .52387 m .29378 .57977 L .29704 .58703 L p .707 .577 .707 r
F P
0 g
s
.7477 .65954 m .74509 .67543 L .71356 .67352 L p .707 .577 .707 r
F P
0 g
s
.49098 .65094 m .47931 .68725 L .48577 .68502 L p .707 .577 .707 r
F P
0 g
s
.48577 .68502 m .49744 .64871 L .49098 .65094 L p .707 .577 .707 r
F P
0 g
s
.29441 .62746 m .30608 .59115 L .30303 .58584 L p .707 .577 .707 r
F P
0 g
s
.30303 .58584 m .29136 .62215 L .29441 .62746 L p .707 .577 .707 r
F P
0 g
s
.5034 .55087 m .49627 .60678 L .493 .59952 L p .707 .577 .707 r
F P
0 g
s
.493 .59952 m .50013 .54361 L .5034 .55087 L p .707 .577 .707 r
F P
0 g
s
.29378 .57977 m .30091 .52387 L .30756 .51793 L p .707 .577 .707 r
F P
0 g
s
.49004 .71136 m .48411 .72948 L .49119 .72745 L p .707 .577 .707 r
F P
0 g
s
.49119 .72745 m .49712 .70933 L .49004 .71136 L p .707 .577 .707 r
F P
0 g
s
.29979 .66825 m .30571 .65013 L .30331 .64495 L p .707 .577 .707 r
F P
0 g
s
.30331 .64495 m .29738 .66307 L .29979 .66825 L p .707 .577 .707 r
F P
0 g
s
.30756 .51793 m .30042 .57383 L .29378 .57977 L p .707 .577 .707 r
F P
0 g
s
.49744 .64871 m .48577 .68502 L .48272 .67972 L p .707 .577 .707 r
F P
0 g
s
.48272 .67972 m .49439 .6434 L .49744 .64871 L p .707 .577 .707 r
F P
0 g
s
.29136 .62215 m .30303 .58584 L .30949 .58361 L p .707 .577 .707 r
F P
0 g
s
.30949 .58361 m .29782 .61992 L .29136 .62215 L p .707 .577 .707 r
F P
0 g
s
.50013 .54361 m .493 .59952 L .48014 .59165 L p .707 .577 .707 r
F P
0 g
s
.48014 .59165 m .48728 .53574 L .50013 .54361 L p .707 .577 .707 r
F P
0 g
s
.30042 .57383 m .30756 .51793 L .32346 .51389 L p .707 .577 .707 r
F P
0 g
s
.49712 .70933 m .49119 .72745 L .48879 .72228 L p .707 .577 .707 r
F P
0 g
s
.48879 .72228 m .49471 .70416 L .49712 .70933 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29738 .66307 m .30331 .64495 L .31039 .64293 L p .707 .577 .707 r
F P
0 g
s
.31039 .64293 m .30446 .66105 L .29738 .66307 L p .707 .577 .707 r
F P
0 g
s
.32346 .51389 m .31633 .5698 L .30042 .57383 L p .707 .577 .707 r
F P
0 g
s
.49439 .6434 m .48272 .67972 L .47045 .67185 L p .707 .577 .707 r
F P
0 g
s
.47045 .67185 m .48212 .63554 L .49439 .6434 L p .707 .577 .707 r
F P
0 g
s
.29782 .61992 m .30949 .58361 L .32483 .58468 L p .707 .577 .707 r
F P
0 g
s
.48728 .53574 m .48014 .59165 L .45896 .58393 L p .707 .577 .707 r
F P
0 g
s
.45896 .58393 m .46609 .52803 L .48728 .53574 L p .707 .577 .707 r
F P
0 g
s
.32483 .58468 m .31317 .62099 L .29782 .61992 L p .707 .577 .707 r
F P
0 g
s
.31633 .5698 m .32346 .51389 L .34707 .51215 L p .707 .577 .707 r
F P
0 g
s
.49471 .70416 m .48879 .72228 L .47713 .71446 L p .707 .577 .707 r
F P
0 g
s
.47713 .71446 m .48306 .69634 L .49471 .70416 L p .707 .577 .707 r
F P
0 g
s
.30446 .66105 m .31039 .64293 L .32626 .64425 L p .707 .577 .707 r
F P
0 g
s
.34707 .51215 m .33994 .56806 L .31633 .5698 L p .707 .577 .707 r
F P
0 g
s
.32626 .64425 m .32033 .66237 L .30446 .66105 L p .707 .577 .707 r
F P
0 g
s
.46609 .52803 m .45896 .58393 L .43151 .57714 L p .707 .577 .707 r
F P
0 g
s
.43151 .57714 m .43864 .52123 L .46609 .52803 L p .707 .577 .707 r
F P
0 g
s
.48212 .63554 m .47045 .67185 L .45017 .6622 L p .707 .577 .707 r
F P
0 g
s
.45017 .6622 m .46183 .62589 L .48212 .63554 L p .707 .577 .707 r
F P
0 g
s
.31317 .62099 m .32483 .58468 L .34756 .58894 L p .707 .577 .707 r
F P
0 g
s
.33994 .56806 m .34707 .51215 L .37607 .51288 L p .707 .577 .707 r
F P
0 g
s
.34756 .58894 m .33589 .62525 L .31317 .62099 L p .707 .577 .707 r
F P
0 g
s
.43864 .52123 m .43151 .57714 L .40049 .57192 L p .707 .577 .707 r
F P
0 g
s
.40049 .57192 m .40762 .51601 L .43864 .52123 L p .707 .577 .707 r
F P
0 g
s
.48306 .69634 m .47713 .71446 L .45737 .70476 L p .707 .577 .707 r
F P
0 g
s
.45737 .70476 m .46329 .68664 L .48306 .69634 L p .707 .577 .707 r
F P
0 g
s
.37607 .51288 m .36894 .56879 L .33994 .56806 L p .707 .577 .707 r
F P
0 g
s
.36894 .56879 m .37607 .51288 L .40762 .51601 L p .707 .577 .707 r
F P
0 g
s
.40762 .51601 m .40049 .57192 L .36894 .56879 L p .707 .577 .707 r
F P
0 g
s
.32033 .66237 m .32626 .64425 L .34937 .6488 L p .707 .577 .707 r
F P
0 g
s
.46183 .62589 m .45017 .6622 L .42385 .65171 L p .707 .577 .707 r
F P
0 g
s
.42385 .65171 m .43552 .61539 L .46183 .62589 L p .707 .577 .707 r
F P
0 g
s
.34937 .6488 m .34345 .66692 L .32033 .66237 L p .707 .577 .707 r
F P
0 g
s
.33589 .62525 m .34756 .58894 L .37544 .59597 L p .707 .577 .707 r
F P
0 g
s
.37544 .59597 m .36378 .63228 L .33589 .62525 L p .707 .577 .707 r
F P
0 g
s
.43552 .61539 m .42385 .65171 L .39408 .6414 L p .707 .577 .707 r
F P
0 g
s
.39408 .6414 m .40575 .60508 L .43552 .61539 L p .707 .577 .707 r
F P
0 g
s
.46329 .68664 m .45737 .70476 L .43143 .69413 L p .707 .577 .707 r
F P
0 g
s
.43143 .69413 m .43735 .67601 L .46329 .68664 L p .707 .577 .707 r
F P
0 g
s
.36378 .63228 m .37544 .59597 L .40575 .60508 L p .707 .577 .707 r
F P
0 g
s
.34345 .66692 m .34937 .6488 L .37746 .65611 L p .707 .577 .707 r
F P
0 g
s
.40575 .60508 m .39408 .6414 L .36378 .63228 L p .707 .577 .707 r
F P
0 g
s
.37746 .65611 m .37153 .67424 L .34345 .66692 L p .707 .577 .707 r
F P
0 g
s
.43735 .67601 m .43143 .69413 L .40185 .68361 L p .707 .577 .707 r
F P
0 g
s
.40185 .68361 m .40778 .66549 L .43735 .67601 L p .707 .577 .707 r
F P
0 g
s
.37153 .67424 m .37746 .65611 L .40778 .66549 L p .707 .577 .707 r
F P
0 g
s
.40778 .66549 m .40185 .68361 L .37153 .67424 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001YOol30005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P00K7oo001XOol20007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH2001ZOol006Moo`03001JEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP8006Uoo`00IWoo00@005YF
FUH000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP00001WOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP00
06Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05
001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF0000
1eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00
IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYF
FUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05
001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D0
05YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
15YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYF
FUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001U
Ool01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJ
EP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001V
Ool006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00
FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eo
o`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF
00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Io
o`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001J
EUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo
00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH0
0007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001J
EUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo
001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0
001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol0
1@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP00
00MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJEUYF00001eYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF
FUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH0001VOol0
06Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001UOol01@00FUIJ
EUYF00001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00D005YFFUIJEP0006Ioo`00IGoo00D005YFFUIJEP0000MJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP05001JEUYFFUH0001VOol006Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001OOol@0002FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001JOol5
0003FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001GOol30000
0eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1@00FUIJEUYF0000IWoo001EOol00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUH000030006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol00`00FUH00002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01@00FUIJEUYF0000IWoo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00004Goo4@00A7oo001DOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUIJEUYF00002goo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF1P00?Woo001DOol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01@00FUIJEUYF00001goo100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YF000003aoo`00E7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJ
EP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH00005Ool2
0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`00>Goo001D
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000goo0`001UYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00=Woo001DOol00`00FUH00003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1P00FUIJEUYF001oo`80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEP00008003=oo`00E7oo00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
1000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001DOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00
FUIJEUYF001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF
FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2000`Ool005Aoo`03FUH005YF009JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP05001J
EUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P00
15YF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00<7oo001COol00`00FUH00003FUH01000FUIJEUYF400015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8000IJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH0000_
Ool005=oo`03001JEP00009JEPD0009JEP03001JEUYF00AJEP03001JEUYF00AJEPL000IJEP03001J
EUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002ioo`00Dgoo00<0
05YF00000P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1000
0UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000IJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP00;Woo
001COol20004FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH4
0006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001COol0
1000FUIJEUYF0`001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP@0009JEP03001JEUYF00=JEP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02000]Ool005Ao
o`04001JEP000002FUH60006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004
FUH01`00FUIJEUYF001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04
001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol20005FUH00`00FUIJ
EP050002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF00001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEPl000IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`8000AJEP03001JEUYF00AJEP03001JEP0000<000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP8000MJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEUYFFUH00005FUH6000?Ool4
0002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol20004FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01@00FUH00000FUH00P001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H0
05YFFUH005YF0003FUH00`00FUH00003000IOol40006FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUH000020009FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`001eYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH40008Ool?0008Ool40002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH30007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0009JEP03001JEUYF009JEPP0
00AJEP03001JEUYF00EJEP03001JEUYF00@000Qoo`<000EJEP04001JEUYFFUH2000]Ool005Aoo`03
FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP<0009JEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00AJEP05001JEUYF001JEP040003FUH300000eYF001JEP07FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30007Ool30003FUH01000FUIJEUYF0P00;Goo001COol00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00
FUIJEP00FUH0009JEP04001JEP000004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH80003FUH200000eYF001JEP02FUH2000]Ool004Ioo`d0009JEP03001JEUYF009JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP03001JEUYF00AJEP03
001JEUYF00<000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF0080
00=JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00EJEP8000=JEP8002eoo`00>7oo3P0015YF00<005YFFUH01EYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF3`0035YF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00P000UYF0P0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0P001UYF00<005YF0000
0UYF0P00;Goo000dOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH:0003FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH000030007FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF
00001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0P0015YF
00<005YFFUH01000;Goo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF0`000UYF00@005YFFUIJEP<002eoo`00;Woo0`0000=JEP00FUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<0
05YFFUH010000UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF0`000UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00H0
05YFFUH005YF0003FUH3000]Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00EJEP03001JEUYF00AJEP@000QJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF3`001UYF00<005YF
FUH01UYF00@005YFFUIJEP8000=JEP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YF
FUH01UYF00<005YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P00
2eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001J
EUYF009JEPH0009JEP03001JEUYF00IJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH015YF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF0`002EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP04001JEUYFFUH20007
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP04FUH200000eYF0000000^Ool0
02aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEPD000QJEP03001JEUYF00MJEP<000MJEP03001JEUYF00EJEP03001JEUYF
00AJEP05001JEUYFFUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00
FUIJEUYF00000eYF00H005YF000005YF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP020005FUH00`00FUIJEP04FUH00`00FUH00002000^Ool002aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEP0000800003FUH00000
00@000EJEP03001JEUYF00IJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUIJ
EP0000=JEP8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000=JEP03001JEUYF00AJEP04001JEP00000_Ool002aoo`03001JEP0000=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004FUH01000FUIJEUYF
1P0025YF00<005YFFUH00eYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF00H005YFFUH005YF0007
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF0`000eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH0
1EYF00@005YFFUH002moo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF00000`00
1EYF00<005YFFUH01UYF0`001UYF00<005YFFUH015YF00L005YFFUIJEP00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP040003FUH200000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH00`00Oomo
o`0/Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000AJEP03001JEUYF00AJEP03001JEUYF00AJEPD000QJEP04001JEUYFFUH20004
FUH00`00FUIJEP04FUH01@00FUIJEUYF00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00`001EYF10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<007ooOol0;7oo000/Ool01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00
0UYF00<005YFFUH015YF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00=JEP800003FUH0
05YF00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYFFUH20005FUH01000FUIJEUYF10000UYF40000UYF00<005YFFUH01EYF00<005YFFUH0
0UYF00@005YFFUH000AJEP03001oogoo02aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000=JEPD000=JEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00EJEP8000IJEP07001JEUYFFUH005YF000025YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YFFUH005YF008000AJEP03001JEUYF009J
EPH000=JEP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEP0000H000AJEP8002eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YFFUH00UYF1@001eYF00<005YFFUH01EYF0`0000=JEP00FUH01UYF00@0
05YF000000AJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH01@00FUH00000FUH00P0015YF1@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF
20001Woo00<005YFFUH00UYF0P00;Goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH?0003FUH00`00FUIJEP03FUH00`00FUH000050002FUH00`00FUIJEP07
FUH00`00FUH000020006FUH01000FUIJEUYF0P0000=JEP00FUH00eYF0P002EYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP00009JEP03001JEUYF008000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP<000Yoo`06001JEUYF001JEP00;Goo000]Ool0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90009FUH00`00FUIJEP02FUH30006FUH0
1000FUIJEUYF0`0000=JEP0000000P0025YF00<005YFFUH00UYF0`000eYF00<005YFFUH00eYF0P00
15YF0P002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00D005YF001JEP00009J
EP04001JEP000005FUH00`00FUIJEP02FUH80004FUH00`00FUIJEP07FUH00`00FUIJEP020009Ool0
1@00FUH005YF0000;Goo000]Ool00`00FUH00003FUH01000FUIJEUYF2@0025YF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH01EYF100000AJEP00000000AJEP03001JEUYF
00IJEP<000IJEP08001JEP00001JEP00FUH000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00AJEP05001JEP00FUH00002FUH200000eYF001JEP03FUH70007Ool70006FUH00`00FUIJEP03
FUH20007Ool01@00FUH005YF0000;Goo000]Ool00`00FUH00002FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP06FUH01000FUH000000eYF0`0000=J
EP00FUH025YF00@005YF000000AJEP04001JEUYFFUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01`00FUH005YF001JEP00009JEP04001JEUYFFUH20002FUH00`00FUIJEP02
000>Ool40002FUH00`00FUIJEP05FUH20006Ool200000eYF001oo`0/Ool002eoo`03001JEP000080
00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP06001JEP00
001JEP001eYF00<005YFFUH00UYF2@001eYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF
00002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00H005YFFUH005YF0003FUH0
1000FUH000001EYF00@005YF0000019oo`@000MJEP<000Eoo`03001JEP0002eoo`00;Goo0P000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00@005YFFUIJEP<000IJEP03001JEUYF00EJEPD00003FUH0000000EJEP03001JEUYF00AJEPP000]J
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYF001JEP000eYF0P0000=J
EP00000015YF00@005YF000001Ioo`8000AJEP05001JEUYFFUH00003Ool3000^Ool002eoo`80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH50004FUH00`00FUIJEP05FUH60002FUH300000eYF001JEP07FUH30002FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01P00FUIJEP00FUH0009J
EP03001JEUYF00=JEP<00005FUH005YFFUH0000HOol300000eYF001JEP03FUH300000eYF0000000^
Ool002ioo`800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEPh00003FUH005YF00MJEP@0009JEP<0009JEP<000MJEP03001JEUYF00<000aJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH40006FUH00`00FUH00002
0002FUH00`00Oomoo`0IOol20006FUH01000FUH00000;Woo000`Ool40003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH@0002FUH80007FUH00`00FUIJEP06FUH30002FUH20004FUH0
0`00FUIJEP03FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP00FUH01EYF00@005YFFUIJEP@001eoo`03001JEUYF00=JEP@002ioo`00=7oo8P00
0eYF1P000UYF00H005YFFUIJEP00FUH20005FUH00`00FUIJEP07FUH00`00FUH0000600000eYF001J
EP05FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH00006FUH00`00FUIJEP04FUH4000KOol00`00FUIJEP02FUH200000eYF001oo`0]Ool004Io
o`L000AJEP03001JEUYF009JEP@00003FUH005YF00AJEP05001JEUYFFUH00003FUH300000eYF001J
EP08FUH00`00FUIJEP04FUH50005FUH01@00FUIJEUYF000025YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH015YF00H005YFFUIJEP00FUH20006FUH00`00FUIJEP05FUH00`00FUIJEP04000E
Ool200001EYF000005YF00000UYF00<007ooOol0;Goo0012Ool40002FUH00`00FUIJEP04FUH70005
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH010001eYF00<005YFFUH01UYF00<0
05YFFUH00P000eYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPL000Uo
o`D000AJEP<0009JEP03001oogoo02eoo`00?7oo1P0015YF2@0015YF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP@0009JEP03001JEUYF00IJEP03001JEUYF
00=JEP<000=JEP03001JEP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF008000=JEP8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPT000=J
EP03001JEUYF00=JEP03001JEP0000=JEP03001oogoo02aoo`00=Goo1`000UYF200015YF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03
001JEUYF00@000MJEP03001JEUYF00AJEP8000=JEP8000QJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF008000EJEP04001JEUYF0008FUH00`00FUIJEP06FUH30006FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<007ooOol0;7oo000`Ool500000eYF
000000060003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00<005YF
FUH00`0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00P001UYF0`001eYF00<005YFFUH01UYF1@001EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001oogoo02aoo`00;7oo2P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03
001JEUYF00QJEP@000EJEP03001JEUYF009JEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00<000IJEP8000MJEP03001JEUYF00IJEPD000EJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEP00001oo`0200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH01000FUIJEUYF1000
00=JEP00FUH00UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00006FUH30005FUH00`00FUIJEP06FUH50005FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20003Ool200000eYF001oo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP05FUH7000:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000=JEPP000=JEP03001J
EUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo00=oo`03001JEP0002eo
o`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP05001JEUYFFUH00002FUH30005FUH500000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF0P001Woo00<005YF0000;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00@005YFFUIJEP80009JEP8000=JEP80009oo`800003FUH00000
008000IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP000008Ool00`00FUH0000]Ool002eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000Eoo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF1@00
0goo00D005YFFUH005YF00800003Ool000000080009JEP03001JEUYF00IJEP03001JEUYF009JEPD0
00]oo`03001oogoo02aoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH015YF1P0037oo00D005YFFUIJEP0000MJEP03001JEUYF00QJEP03001J
EUYF00AJEQP000IJEP03001JEUYF00MJEP03001JEUYF00AJEP06001JEUYFFUH005YF0P000eYF00D0
07ooOomoo`0000=JEP04001JEUYF0005Ool@000?Ool2000^Ool002eoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@0019oo`05001JEUYFFUH00007
FUH00`00FUIJEP06FUH90004FUH00`00FUIJEP09FUH00`00FUIJEP05FUH80008FUH00`00FUIJEP04
FUH01000FUIJEUYF100015YF0`0015YF00@005YFFUH002Aoo`8002ioo`00;Goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1`005Woo00D005YFFUIJEP0000MJEP03
001JEUYF00L000aJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00<000EJEP03001JEUYF
00AJEP05001JEUYFFUH00002Ool00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUIJEUYF00008Woo
0P00;goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8000DOol:0003FUH00`00FUIJ
EP04FUH40006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH4
00000eYF001JEP05FUH01@00FUIJEUYF00000goo00<005YFFUH00eYF0`000eYF00@005YFFUH0021o
o`@002moo`00;Woo0P000UYF3P005Goo1`000eYF1`000eYF00<005YFFUH00UYF0`002EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF0`001EYF00@005YFFUIJEPH0
00AJEP03001JEUYF00800004FUH005YF000POol01000FUIJEP00<7oo000^Ool4000JOol90003FUH0
0`00FUIJEP02FUH300000eYF001JEP02FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00MJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000UJEP03001JEUYF00@00003
FUH005YF009JEP03001JEUYF00=JEP800003FUH005YF00AJEP800003FUH007oo01eoo`8000=JEP03
001oogoo02ioo`00@goo2@0015YF00<005YFFUH01EYF1@0015YF00D005YFFUIJEP0000=JEP8000EJ
EP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00AJEP8000=JEP03001JEUYF00AJEP<000MJEP<001Yoo`<00005FUH005YFFUH0000a
Ool003eoo`H000AJEP03001JEUYF00IJEPP000=JEP03001JEUYF00=JEP05001JEUYFFUH00002FUH2
0006FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH20002FUH00`00FUIJEP04FUH01000FUH000001eYF00<005YF00000`00
47oo1P0015YF00<005YF0000<Woo000iOol400000eYF001JEP07FUH90004FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP0300000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF0000
1eYF00<005YFFUH00P0015YF00<005YFFUH015YF400015YF00<005YFFUH00eYF0P00<goo000eOol4
0005FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH030000UYF0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00=7oo000`Ool50002FUH80003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP<0009JEP@000IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH2000fOol002aoo`/000=JEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF009JEPL000Eoo`05001JEUYFFUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01@00FUIJEUYF00000eYF00<005YFFUH01UYF0`0000AJEP00Oomoo`@0009JEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEP00000hOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUIJEUYF000015YF00<005YFFUH00eYF0P000Woo0`001Woo1`0015YF00<005YFFUH0
0UYF1@00>Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH7000DOol01@00FUIJEUYF00001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YFFUIJEP0000AJEP03001JEUYF
009JEP03001oogoo009oo`<000eoo`T003moo`00;Goo0P001EYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH0100077oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0005FUH01@00
FUIJEUYF000017oo00@005YFFUH005Eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH00UYF1`008Goo0`001UYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF0`001eYF0`001Goo00@005YFFUH005Eoo`00;Goo
00<005YF00000UYF3@00:Woo0P001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH015YF0`001eYF0P001Woo0P0000=JEP00Ool0
EGoo000^Ool4000iOol20003FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH20006Ool20000
15YF001JEP00EWoo001]Ool200000eYF001JEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP07FUH00`00FUH000020005FUH00`00FUH000020007Ool00`00FUIJEP02
FUH00`00Oomoo`1EOol006moo`@000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00EJEPD000IJEP<000Uoo`03001JEUYF00=JEP03001oogoo05Eoo`00Lgoo1@000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01@0000=JEP0000000`00
0eYF0P002Woo0`0015YF00<007ooOol0EWoo001hOol90006FUH00`00FUIJEP09FUH00`00FUIJEP04
FUH90006FUH8000:Ool20003FUH01000FUIJEP00FGoo0021OolI00000eYF001JEP05FUH00`00FUIJ
EP04FUH5000;Ool20005FUH01000FUIJEP00FGoo002?Ool00`00FUH00003FUH40003FUH00`00FUIJ
EP04FUH00`00FUIJEP07000;Ool00`00FUIJEP06FUH2001JOol008ioo`04001JEUYF0002FUH00`00
Oomoo`02Ool=000@Ool30008FUH00`00Oomoo`1IOol008ioo`04001JEUYFFUH2000POol20003FUH0
0`00FUIJEP03FUH2001LOol008ioo`05001JEUYFFUH0000OOol20005FUH01000FUIJEUYF0P00GWoo
002>Ool200000eYF001oo`0LOol30008FUH3001POol008moo`03001JEP0001]oo`800003FUH005YF
00QJEP03001oogoo061oo`00Sgoo0P006Goo0`0015YF00<005YFFUH015YF0P00Hgoo002?Ool3000D
Ool40007FUH00`00FUIJEP02FUH2001UOol0091oo`03001JEP00008000eoo`@0009JEP03001JEUYF
00MJEP04001JEP00001WOol0091oo`<0009JEPd000MJEP03001JEUYF00EJEP<006Uoo`00TGoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00eYF0P00K7oo002BOol20005
FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUH00002001^Ool009=oo`8000AJEP03001JEUYF
00AJEP03001JEUYF00=JEPH0075oo`00U7oo0`000eYF00@005YFFUIJEPP007Moo`00Ugoo1`00Ogoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59263 .74335 m .5997 .68747 L .56888 .6821 L p .707 .577 .707 r
F P
0 g
s
.5997 .68747 m .59263 .74335 L .62426 .74664 L p .707 .577 .707 r
F P
0 g
s
.62426 .74664 m .63134 .69075 L .5997 .68747 L p .707 .577 .707 r
F P
0 g
s
.63134 .69075 m .62426 .74664 L .6536 .74752 L p .707 .577 .707 r
F P
0 g
s
.6536 .74752 m .66068 .69164 L .63134 .69075 L p .707 .577 .707 r
F P
0 g
s
.5618 .73798 m .56888 .6821 L .54187 .67518 L p .707 .577 .707 r
F P
0 g
s
.56888 .6821 m .5618 .73798 L .59263 .74335 L p .707 .577 .707 r
F P
0 g
s
.66068 .69164 m .6536 .74752 L .67778 .74592 L p .707 .577 .707 r
F P
0 g
s
.67778 .74592 m .68486 .69004 L .66068 .69164 L p .707 .577 .707 r
F P
0 g
s
.54187 .67518 m .53479 .73107 L .5618 .73798 L p .707 .577 .707 r
F P
0 g
s
.58549 .79432 m .59704 .75801 L .56749 .74767 L p .707 .577 .707 r
F P
0 g
s
.59704 .75801 m .58549 .79432 L .61592 .8035 L p .707 .577 .707 r
F P
0 g
s
.61592 .8035 m .62747 .7672 L .59704 .75801 L p .707 .577 .707 r
F P
0 g
s
.53479 .73107 m .54187 .67518 L .52133 .66739 L p .707 .577 .707 r
F P
0 g
s
.62747 .7672 m .61592 .8035 L .64424 .81062 L p .707 .577 .707 r
F P
0 g
s
.64424 .81062 m .65579 .77431 L .62747 .7672 L p .707 .577 .707 r
F P
0 g
s
.56749 .74767 m .55594 .78397 L .58549 .79432 L p .707 .577 .707 r
F P
0 g
s
.55594 .78397 m .56749 .74767 L .54171 .73717 L p .707 .577 .707 r
F P
0 g
s
.54171 .73717 m .53016 .77348 L .55594 .78397 L p .707 .577 .707 r
F P
0 g
s
.52133 .66739 m .51425 .72327 L .53479 .73107 L p .707 .577 .707 r
F P
0 g
s
.65579 .77431 m .64424 .81062 L .66769 .81498 L p .707 .577 .707 r
F P
0 g
s
.66769 .81498 m .67924 .77868 L .65579 .77431 L p .707 .577 .707 r
F P
0 g
s
.59315 .83582 m .59909 .8177 L .56948 .80719 L p .707 .577 .707 r
F P
0 g
s
.59909 .8177 m .59315 .83582 L .62345 .84519 L p .707 .577 .707 r
F P
0 g
s
.62345 .84519 m .62939 .82707 L .59909 .8177 L p .707 .577 .707 r
F P
0 g
s
.68486 .69004 m .67778 .74592 L .69443 .74199 L p .707 .577 .707 r
F P
0 g
s
.69443 .74199 m .70151 .68611 L .68486 .69004 L p .707 .577 .707 r
F P
0 g
s
.56948 .80719 m .56354 .82531 L .59315 .83582 L p .707 .577 .707 r
F P
0 g
s
.62939 .82707 m .62345 .84519 L .65146 .85249 L p .707 .577 .707 r
F P
0 g
s
.65146 .85249 m .65739 .83437 L .62939 .82707 L p .707 .577 .707 r
F P
0 g
s
.53016 .77348 m .54171 .73717 L .52222 .72756 L p .707 .577 .707 r
F P
0 g
s
.56354 .82531 m .56948 .80719 L .54344 .79656 L p .707 .577 .707 r
F P
0 g
s
.54344 .79656 m .5375 .81468 L .56354 .82531 L p .707 .577 .707 r
F P
0 g
s
.51425 .72327 m .52133 .66739 L .50927 .65948 L p .707 .577 .707 r
F P
0 g
s
.52222 .72756 m .51066 .76386 L .53016 .77348 L p .707 .577 .707 r
F P
0 g
s
.65739 .83437 m .65146 .85249 L .67443 .85702 L p .707 .577 .707 r
F P
0 g
s
.67443 .85702 m .68037 .8389 L .65739 .83437 L p .707 .577 .707 r
F P
0 g
s
.5375 .81468 m .54344 .79656 L .52353 .78686 L p .707 .577 .707 r
F P
0 g
s
.67924 .77868 m .66769 .81498 L .68396 .81616 L p .707 .577 .707 r
F P
0 g
s
.68396 .81616 m .69552 .77985 L .67924 .77868 L p .707 .577 .707 r
F P
0 g
s
.50927 .65948 m .50219 .71537 L .51425 .72327 L p .707 .577 .707 r
F P
0 g
s
.52353 .78686 m .51759 .80498 L .5375 .81468 L p .707 .577 .707 r
F P
0 g
s
.70151 .68611 m .69443 .74199 L .70192 .73612 L p .707 .577 .707 r
F P
0 g
s
.70192 .73612 m .709 .68023 L .70151 .68611 L p .707 .577 .707 r
F P
0 g
s
.51066 .76386 m .52222 .72756 L .51093 .71976 L p .707 .577 .707 r
F P
0 g
s
.51093 .71976 m .49937 .75606 L .51066 .76386 L p .707 .577 .707 r
F P
0 g
s
.50219 .71537 m .50927 .65948 L .50686 .65224 L p .707 .577 .707 r
F P
0 g
s
.68037 .8389 m .67443 .85702 L .69014 .85832 L p .707 .577 .707 r
F P
0 g
s
.69014 .85832 m .69607 .8402 L .68037 .8389 L p .707 .577 .707 r
F P
0 g
s
.51759 .80498 m .52353 .78686 L .51169 .77902 L p .707 .577 .707 r
F P
0 g
s
.51169 .77902 m .50575 .79715 L .51759 .80498 L p .707 .577 .707 r
F P
0 g
s
.69552 .77985 m .68396 .81616 L .69147 .81403 L p .707 .577 .707 r
F P
0 g
s
.69147 .81403 m .70303 .77773 L .69552 .77985 L p .707 .577 .707 r
F P
0 g
s
.50686 .65224 m .49979 .70812 L .50219 .71537 L p .707 .577 .707 r
F P
0 g
s
.709 .68023 m .70192 .73612 L .69952 .72887 L p .707 .577 .707 r
F P
0 g
s
.69952 .72887 m .7066 .67299 L .709 .68023 L p .707 .577 .707 r
F P
0 g
s
.49937 .75606 m .51093 .71976 L .50894 .71454 L p .707 .577 .707 r
F P
0 g
s
.50894 .71454 m .49738 .75084 L .49937 .75606 L p .707 .577 .707 r
F P
0 g
s
.49979 .70812 m .50686 .65224 L .51435 .64636 L p .707 .577 .707 r
F P
0 g
s
.50909 .77383 m .50315 .79195 L .50575 .79715 L p .707 .577 .707 r
F P
0 g
s
.51435 .64636 m .50728 .70225 L .49979 .70812 L p .707 .577 .707 r
F P
0 g
s
.49738 .75084 m .50894 .71454 L .51645 .71241 L p .707 .577 .707 r
F P
0 g
s
.51645 .71241 m .5049 .74872 L .49738 .75084 L p .707 .577 .707 r
F P
0 g
s
.50575 .79715 m .51169 .77902 L .50909 .77383 L p .707 .577 .707 r
F P
0 g
s
.50315 .79195 m .50909 .77383 L .51598 .77179 L p .707 .577 .707 r
F P
0 g
s
.51598 .77179 m .51004 .78991 L .50315 .79195 L p .707 .577 .707 r
F P
0 g
s
.5049 .74872 m .51645 .71241 L .53273 .71359 L p .707 .577 .707 r
F P
0 g
s
.53273 .71359 m .52117 .74989 L .5049 .74872 L p .707 .577 .707 r
F P
0 g
s
.50563 .82189 m .50563 .32001 L .46081 .31858 L p .707 .577 .707 r
F P
0 g
s
.50728 .70225 m .51435 .64636 L .531 .64243 L p .707 .577 .707 r
F P
0 g
s
.531 .64243 m .52393 .69832 L .50728 .70225 L p .707 .577 .707 r
F P
0 g
s
.52393 .69832 m .531 .64243 L .55518 .64083 L p .707 .577 .707 r
F P
0 g
s
.51004 .78991 m .51598 .77179 L .53168 .77309 L p .707 .577 .707 r
F P
0 g
s
.53168 .77309 m .52574 .79121 L .51004 .78991 L p .707 .577 .707 r
F P
0 g
s
.55518 .64083 m .54811 .69672 L .52393 .69832 L p .707 .577 .707 r
F P
0 g
s
.52117 .74989 m .53273 .71359 L .55617 .71795 L p .707 .577 .707 r
F P
0 g
s
.55617 .71795 m .54462 .75426 L .52117 .74989 L p .707 .577 .707 r
F P
0 g
s
.52574 .79121 m .53168 .77309 L .55466 .77762 L p .707 .577 .707 r
F P
0 g
s
.55466 .77762 m .54872 .79574 L .52574 .79121 L p .707 .577 .707 r
F P
0 g
s
.50563 .32001 m .50563 .82189 L .54989 .81953 L p .707 .577 .707 r
F P
0 g
s
.54811 .69672 m .55518 .64083 L .58453 .64172 L p .707 .577 .707 r
F P
0 g
s
.58453 .64172 m .57745 .6976 L .54811 .69672 L p .707 .577 .707 r
F P
0 g
s
.54462 .75426 m .55617 .71795 L .5845 .72507 L p .707 .577 .707 r
F P
0 g
s
.5845 .72507 m .57294 .76137 L .54462 .75426 L p .707 .577 .707 r
F P
0 g
s
.54872 .79574 m .55466 .77762 L .58266 .78492 L p .707 .577 .707 r
F P
0 g
s
.58266 .78492 m .57673 .80304 L .54872 .79574 L p .707 .577 .707 r
F P
0 g
s
.54989 .81953 m .54989 .31765 L .50563 .32001 L p .707 .577 .707 r
F P
0 g
s
.69607 .8402 m .69014 .85832 L .69702 .85628 L p .707 .577 .707 r
F P
0 g
s
.69702 .85628 m .70296 .83816 L .69607 .8402 L p .707 .577 .707 r
F P
0 g
s
.46081 .82047 m .46081 .31858 L .41983 .31351 L p .707 .577 .707 r
F P
0 g
s
.46081 .31858 m .46081 .82047 L .50563 .82189 L p .707 .577 .707 r
F P
0 g
s
.57745 .6976 m .58453 .64172 L .61616 .64501 L p .707 .577 .707 r
F P
0 g
s
.61616 .64501 m .60908 .70089 L .57745 .6976 L p .707 .577 .707 r
F P
0 g
s
.57294 .76137 m .5845 .72507 L .61492 .73425 L p .707 .577 .707 r
F P
0 g
s
.61492 .73425 m .60337 .77056 L .57294 .76137 L p .707 .577 .707 r
F P
0 g
s
.57673 .80304 m .58266 .78492 L .61296 .79429 L p .707 .577 .707 r
F P
0 g
s
.61296 .79429 m .60702 .81241 L .57673 .80304 L p .707 .577 .707 r
F P
0 g
s
.54989 .31765 m .54989 .81953 L .58927 .81362 L p .707 .577 .707 r
F P
0 g
s
.58927 .81362 m .58927 .31173 L .54989 .31765 L p .707 .577 .707 r
F P
0 g
s
.70303 .77773 m .69147 .81403 L .68949 .80881 L p .707 .577 .707 r
F P
0 g
s
.68949 .80881 m .70104 .77251 L .70303 .77773 L p .707 .577 .707 r
F P
0 g
s
.41983 .81539 m .41983 .31351 L .3867 .30528 L p .707 .577 .707 r
F P
0 g
s
.41983 .31351 m .41983 .81539 L .46081 .82047 L p .707 .577 .707 r
F P
0 g
s
.7066 .67299 m .69952 .72887 L .68746 .72097 L p .707 .577 .707 r
F P
0 g
s
.68746 .72097 m .69453 .66508 L .7066 .67299 L p .707 .577 .707 r
F P
0 g
s
.64699 .65037 m .63991 .70625 L .60908 .70089 L p .707 .577 .707 r
F P
0 g
s
.60908 .70089 m .61616 .64501 L .64699 .65037 L p .707 .577 .707 r
F P
0 g
s
.64447 .7446 m .63292 .7809 L .60337 .77056 L p .707 .577 .707 r
F P
0 g
s
.60337 .77056 m .61492 .73425 L .64447 .7446 L p .707 .577 .707 r
F P
0 g
s
.60702 .81241 m .61296 .79429 L .64257 .8048 L p .707 .577 .707 r
F P
0 g
s
.58927 .31173 m .58927 .81362 L .61992 .80473 L p .707 .577 .707 r
F P
0 g
s
.61992 .80473 m .61991 .30284 L .58927 .31173 L p .707 .577 .707 r
F P
0 g
s
.251 .72343 m .25403 .67028 L .22299 .66589 L p .707 .577 .707 r
F P
0 g
s
.25403 .67028 m .251 .72343 L .28282 .72401 L p .707 .577 .707 r
F P
0 g
s
.28282 .72401 m .28585 .67086 L .25403 .67028 L p .707 .577 .707 r
F P
0 g
s
.28585 .67086 m .28282 .72401 L .31232 .72072 L p .707 .577 .707 r
F P
0 g
s
.31232 .72072 m .31535 .66757 L .28585 .67086 L p .707 .577 .707 r
F P
0 g
s
.70296 .83816 m .69702 .85628 L .69442 .85109 L p .707 .577 .707 r
F P
0 g
s
.69442 .85109 m .70036 .83297 L .70296 .83816 L p .707 .577 .707 r
F P
0 g
s
.21996 .71905 m .22299 .66589 L .19577 .65812 L p .707 .577 .707 r
F P
0 g
s
.22299 .66589 m .21996 .71905 L .251 .72343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31535 .66757 m .31232 .72072 L .3366 .71389 L p .707 .577 .707 r
F P
0 g
s
.3366 .71389 m .33963 .66073 L .31535 .66757 L p .707 .577 .707 r
F P
0 g
s
.70104 .77251 m .68949 .80881 L .67819 .80101 L p .707 .577 .707 r
F P
0 g
s
.67819 .80101 m .68975 .76471 L .70104 .77251 L p .707 .577 .707 r
F P
0 g
s
.19274 .71128 m .19577 .65812 L .17504 .64774 L p .707 .577 .707 r
F P
0 g
s
.19577 .65812 m .19274 .71128 L .21996 .71905 L p .707 .577 .707 r
F P
0 g
s
.3867 .80717 m .3867 .30528 L .36466 .29472 L p .707 .577 .707 r
F P
0 g
s
.3867 .30528 m .3867 .80717 L .41983 .81539 L p .707 .577 .707 r
F P
0 g
s
.69453 .66508 m .68746 .72097 L .66692 .71317 L p .707 .577 .707 r
F P
0 g
s
.66692 .71317 m .674 .65729 L .69453 .66508 L p .707 .577 .707 r
F P
0 g
s
.67026 .75509 m .6587 .7914 L .63292 .7809 L p .707 .577 .707 r
F P
0 g
s
.63292 .7809 m .64447 .7446 L .67026 .75509 L p .707 .577 .707 r
F P
0 g
s
.61991 .30284 m .61992 .80473 L .63882 .79373 L p .707 .577 .707 r
F P
0 g
s
.63882 .79373 m .63882 .29184 L .61991 .30284 L p .707 .577 .707 r
F P
0 g
s
.24856 .79744 m .25361 .76557 L .22277 .75811 L p .707 .577 .707 r
F P
0 g
s
.25361 .76557 m .24856 .79744 L .28014 .79951 L p .707 .577 .707 r
F P
0 g
s
.28014 .79951 m .2852 .76764 L .25361 .76557 L p .707 .577 .707 r
F P
0 g
s
.33963 .66073 m .3366 .71389 L .35328 .70418 L p .707 .577 .707 r
F P
0 g
s
.35328 .70418 m .35631 .65102 L .33963 .66073 L p .707 .577 .707 r
F P
0 g
s
.70036 .83297 m .69442 .85109 L .68259 .84325 L p .707 .577 .707 r
F P
0 g
s
.68259 .84325 m .68852 .82513 L .70036 .83297 L p .707 .577 .707 r
F P
0 g
s
.21772 .78998 m .22277 .75811 L .19571 .74598 L p .707 .577 .707 r
F P
0 g
s
.22277 .75811 m .21772 .78998 L .24856 .79744 L p .707 .577 .707 r
F P
0 g
s
.2852 .76764 m .28014 .79951 L .30939 .79599 L p .707 .577 .707 r
F P
0 g
s
.30939 .79599 m .31444 .76412 L .2852 .76764 L p .707 .577 .707 r
F P
0 g
s
.17201 .70089 m .17504 .64774 L .16283 .63574 L p .707 .577 .707 r
F P
0 g
s
.17504 .64774 m .17201 .70089 L .19274 .71128 L p .707 .577 .707 r
F P
0 g
s
.68975 .76471 m .67819 .80101 L .6587 .7914 L p .707 .577 .707 r
F P
0 g
s
.6587 .7914 m .67026 .75509 L .68975 .76471 L p .707 .577 .707 r
F P
0 g
s
.674 .65729 m .66692 .71317 L .63991 .70625 L p .707 .577 .707 r
F P
0 g
s
.63991 .70625 m .64699 .65037 L .674 .65729 L p .707 .577 .707 r
F P
0 g
s
.19065 .77786 m .19571 .74598 L .17506 .73039 L p .707 .577 .707 r
F P
0 g
s
.19571 .74598 m .19065 .77786 L .21772 .78998 L p .707 .577 .707 r
F P
0 g
s
.25306 .84181 m .25568 .82591 L .22472 .81865 L p .707 .577 .707 r
F P
0 g
s
.25568 .82591 m .25306 .84181 L .28456 .84363 L p .707 .577 .707 r
F P
0 g
s
.28456 .84363 m .28718 .82773 L .25568 .82591 L p .707 .577 .707 r
F P
0 g
s
.31444 .76412 m .30939 .79599 L .33342 .78722 L p .707 .577 .707 r
F P
0 g
s
.33342 .78722 m .33847 .75535 L .31444 .76412 L p .707 .577 .707 r
F P
0 g
s
.2221 .83455 m .22472 .81865 L .19734 .80666 L p .707 .577 .707 r
F P
0 g
s
.22472 .81865 m .2221 .83455 L .25306 .84181 L p .707 .577 .707 r
F P
0 g
s
.28718 .82773 m .28456 .84363 L .31353 .83984 L p .707 .577 .707 r
F P
0 g
s
.31353 .83984 m .31615 .82394 L .28718 .82773 L p .707 .577 .707 r
F P
0 g
s
.35631 .65102 m .35328 .70418 L .36073 .69254 L p .707 .577 .707 r
F P
0 g
s
.36073 .69254 m .36376 .63939 L .35631 .65102 L p .707 .577 .707 r
F P
0 g
s
.36376 .63939 m .36073 .69254 L .35823 .68012 L p .707 .577 .707 r
F P
0 g
s
.35823 .68012 m .36126 .62697 L .36376 .63939 L p .707 .577 .707 r
F P
0 g
s
.36466 .79661 m .36466 .29472 L .35586 .28284 L p .707 .577 .707 r
F P
0 g
s
.36466 .29472 m .36466 .79661 L .3867 .80717 L p .707 .577 .707 r
F P
0 g
s
.19734 .80666 m .19472 .82256 L .2221 .83455 L p .707 .577 .707 r
F P
0 g
s
.19472 .82256 m .19734 .80666 L .17622 .79111 L p .707 .577 .707 r
F P
0 g
s
.68852 .82513 m .68259 .84325 L .66267 .83355 L p .707 .577 .707 r
F P
0 g
s
.66267 .83355 m .66861 .81543 L .68852 .82513 L p .707 .577 .707 r
F P
0 g
s
.16283 .63574 m .1598 .6889 L .17201 .70089 L p .707 .577 .707 r
F P
0 g
s
.17 .76227 m .17506 .73039 L .16284 .71285 L p .707 .577 .707 r
F P
0 g
s
.17506 .73039 m .17 .76227 L .19065 .77786 L p .707 .577 .707 r
F P
0 g
s
.31615 .82394 m .31353 .83984 L .33713 .8308 L p .707 .577 .707 r
F P
0 g
s
.33713 .8308 m .33975 .8149 L .31615 .82394 L p .707 .577 .707 r
F P
0 g
s
.33847 .75535 m .33342 .78722 L .3499 .77406 L p .707 .577 .707 r
F P
0 g
s
.3499 .77406 m .35495 .74218 L .33847 .75535 L p .707 .577 .707 r
F P
0 g
s
.1598 .6889 m .16283 .63574 L .16033 .62332 L p .707 .577 .707 r
F P
0 g
s
.63882 .29184 m .63882 .79373 L .64413 .78171 L p .707 .577 .707 r
F P
0 g
s
.64413 .78171 m .64413 .27982 L .63882 .29184 L p .707 .577 .707 r
F P
0 g
s
.17622 .79111 m .1736 .80702 L .19472 .82256 L p .707 .577 .707 r
F P
0 g
s
.1736 .80702 m .17622 .79111 L .16342 .77354 L p .707 .577 .707 r
F P
0 g
s
.33975 .8149 m .33713 .8308 L .35304 .8174 L p .707 .577 .707 r
F P
0 g
s
.35304 .8174 m .35566 .8015 L .33975 .8149 L p .707 .577 .707 r
F P
0 g
s
.66861 .81543 m .66267 .83355 L .63664 .82292 L p .707 .577 .707 r
F P
0 g
s
.63664 .82292 m .64257 .8048 L .66861 .81543 L p .707 .577 .707 r
F P
0 g
s
.16284 .71285 m .15779 .74472 L .17 .76227 L p .707 .577 .707 r
F P
0 g
s
.15779 .74472 m .16284 .71285 L .16026 .69507 L p .707 .577 .707 r
F P
0 g
s
.16033 .62332 m .1573 .67648 L .1598 .6889 L p .707 .577 .707 r
F P
0 g
s
.35495 .74218 m .3499 .77406 L .35721 .7578 L p .707 .577 .707 r
F P
0 g
s
.35721 .7578 m .36226 .72592 L .35495 .74218 L p .707 .577 .707 r
F P
0 g
s
.16342 .77354 m .1608 .78944 L .1736 .80702 L p .707 .577 .707 r
F P
0 g
s
.1573 .67648 m .16033 .62332 L .16779 .61169 L p .707 .577 .707 r
F P
0 g
s
.64257 .8048 m .63664 .82292 L .60702 .81241 L p .707 .577 .707 r
F P
0 g
s
.35972 .80095 m .36234 .78505 L .35566 .8015 L p .707 .577 .707 r
F P
0 g
s
.36126 .62697 m .35823 .68012 L .34602 .66813 L p .707 .577 .707 r
F P
0 g
s
.34602 .66813 m .34905 .61498 L .36126 .62697 L p .707 .577 .707 r
F P
0 g
s
.36226 .72592 m .35721 .7578 L .35463 .74003 L p .707 .577 .707 r
F P
0 g
s
.35463 .74003 m .35968 .70815 L .36226 .72592 L p .707 .577 .707 r
F P
0 g
s
.36234 .78505 m .35972 .80095 L .3565 .78306 L p .707 .577 .707 r
F P
0 g
s
.3565 .78306 m .35912 .76716 L .36234 .78505 L p .707 .577 .707 r
F P
0 g
s
.35968 .70815 m .35463 .74003 L .34242 .72248 L p .707 .577 .707 r
F P
0 g
s
.34242 .72248 m .34747 .69061 L .35968 .70815 L p .707 .577 .707 r
F P
0 g
s
.35912 .76716 m .3565 .78306 L .3437 .76549 L p .707 .577 .707 r
F P
0 g
s
.3437 .76549 m .34632 .74958 L .35912 .76716 L p .707 .577 .707 r
F P
0 g
s
.35586 .28284 m .35586 .78473 L .36466 .79661 L p .707 .577 .707 r
F P
0 g
s
.35586 .78473 m .35586 .28284 L .36118 .27081 L p .707 .577 .707 r
F P
0 g
s
.1608 .78944 m .16342 .77354 L .1602 .75565 L p .707 .577 .707 r
F P
0 g
s
.35566 .8015 m .35304 .8174 L .35972 .80095 L p .707 .577 .707 r
F P
0 g
s
.16026 .69507 m .15521 .72695 L .15779 .74472 L p .707 .577 .707 r
F P
0 g
s
.64413 .27982 m .64413 .78171 L .63534 .76983 L p .707 .577 .707 r
F P
0 g
s
.63534 .76983 m .63534 .26794 L .64413 .27982 L p .707 .577 .707 r
F P
0 g
s
.1602 .75565 m .15758 .77155 L .1608 .78944 L p .707 .577 .707 r
F P
0 g
s
.15521 .72695 m .16026 .69507 L .16757 .67881 L p .707 .577 .707 r
F P
0 g
s
.16779 .61169 m .16476 .66484 L .1573 .67648 L p .707 .577 .707 r
F P
0 g
s
.16476 .66484 m .16779 .61169 L .18447 .60198 L p .707 .577 .707 r
F P
0 g
s
.15758 .77155 m .1602 .75565 L .16687 .7392 L p .707 .577 .707 r
F P
0 g
s
.16757 .67881 m .16252 .71069 L .15521 .72695 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16687 .7392 m .16426 .7551 L .15758 .77155 L p .707 .577 .707 r
F P
0 g
s
.16252 .71069 m .16757 .67881 L .18405 .66565 L p .707 .577 .707 r
F P
0 g
s
.34905 .61498 m .34602 .66813 L .32529 .65774 L p .707 .577 .707 r
F P
0 g
s
.32529 .65774 m .32832 .60459 L .34905 .61498 L p .707 .577 .707 r
F P
0 g
s
.36118 .7727 m .36118 .27081 L .38008 .25982 L p .707 .577 .707 r
F P
0 g
s
.36118 .27081 m .36118 .7727 L .35586 .78473 L p .707 .577 .707 r
F P
0 g
s
.18447 .60198 m .18144 .65513 L .16476 .66484 L p .707 .577 .707 r
F P
0 g
s
.18144 .65513 m .18447 .60198 L .20874 .59515 L p .707 .577 .707 r
F P
0 g
s
.63534 .26794 m .63534 .76983 L .6133 .75926 L p .707 .577 .707 r
F P
0 g
s
.6133 .75926 m .6133 .25737 L .63534 .26794 L p .707 .577 .707 r
F P
0 g
s
.16426 .7551 m .16687 .7392 L .18279 .7258 L p .707 .577 .707 r
F P
0 g
s
.18405 .66565 m .179 .69753 L .16252 .71069 L p .707 .577 .707 r
F P
0 g
s
.32832 .60459 m .32529 .65774 L .29807 .64998 L p .707 .577 .707 r
F P
0 g
s
.29807 .64998 m .3011 .59682 L .32832 .60459 L p .707 .577 .707 r
F P
0 g
s
.179 .69753 m .18405 .66565 L .20809 .65688 L p .707 .577 .707 r
F P
0 g
s
.18279 .7258 m .18017 .7417 L .16426 .7551 L p .707 .577 .707 r
F P
0 g
s
.34747 .69061 m .34242 .72248 L .32177 .70689 L p .707 .577 .707 r
F P
0 g
s
.32177 .70689 m .32682 .67501 L .34747 .69061 L p .707 .577 .707 r
F P
0 g
s
.20571 .6483 m .20874 .59515 L .23824 .59186 L p .707 .577 .707 r
F P
0 g
s
.20874 .59515 m .20571 .6483 L .18144 .65513 L p .707 .577 .707 r
F P
0 g
s
.3011 .59682 m .29807 .64998 L .26703 .64559 L p .707 .577 .707 r
F P
0 g
s
.26703 .64559 m .27006 .59243 L .3011 .59682 L p .707 .577 .707 r
F P
0 g
s
.18017 .7417 m .18279 .7258 L .20638 .71676 L p .707 .577 .707 r
F P
0 g
s
.23521 .64501 m .23824 .59186 L .27006 .59243 L p .707 .577 .707 r
F P
0 g
s
.23824 .59186 m .23521 .64501 L .20571 .6483 L p .707 .577 .707 r
F P
0 g
s
.38008 .25982 m .38008 .76171 L .36118 .7727 L p .707 .577 .707 r
F P
0 g
s
.38008 .76171 m .38008 .25982 L .41072 .25093 L p .707 .577 .707 r
F P
0 g
s
.20304 .68876 m .20809 .65688 L .23733 .65336 L p .707 .577 .707 r
F P
0 g
s
.20809 .65688 m .20304 .68876 L .179 .69753 L p .707 .577 .707 r
F P
0 g
s
.34632 .74958 m .3437 .76549 L .32258 .74994 L p .707 .577 .707 r
F P
0 g
s
.32258 .74994 m .3252 .73404 L .34632 .74958 L p .707 .577 .707 r
F P
0 g
s
.32682 .67501 m .32177 .70689 L .2947 .69477 L p .707 .577 .707 r
F P
0 g
s
.2947 .69477 m .29975 .66289 L .32682 .67501 L p .707 .577 .707 r
F P
0 g
s
.27006 .59243 m .26703 .64559 L .23521 .64501 L p .707 .577 .707 r
F P
0 g
s
.20638 .71676 m .20377 .73266 L .18017 .7417 L p .707 .577 .707 r
F P
0 g
s
.6133 .25737 m .6133 .75926 L .58017 .75104 L p .707 .577 .707 r
F P
0 g
s
.58017 .75104 m .58017 .24915 L .6133 .25737 L p .707 .577 .707 r
F P
0 g
s
.23228 .68523 m .23733 .65336 L .26892 .65543 L p .707 .577 .707 r
F P
0 g
s
.23733 .65336 m .23228 .68523 L .20304 .68876 L p .707 .577 .707 r
F P
0 g
s
.29975 .66289 m .2947 .69477 L .26386 .68731 L p .707 .577 .707 r
F P
0 g
s
.26386 .68731 m .26892 .65543 L .29975 .66289 L p .707 .577 .707 r
F P
0 g
s
.73296 .64575 m .72993 .58876 L .69889 .58928 L p .707 .577 .707 r
F P
0 g
s
.72993 .58876 m .73296 .64575 L .76479 .64373 L p .707 .577 .707 r
F P
0 g
s
.76479 .64373 m .76176 .58673 L .72993 .58876 L p .707 .577 .707 r
F P
0 g
s
.20377 .73266 m .20638 .71676 L .23535 .71297 L p .707 .577 .707 r
F P
0 g
s
.76176 .58673 m .76479 .64373 L .79428 .6404 L p .707 .577 .707 r
F P
0 g
s
.79428 .6404 m .79125 .58341 L .76176 .58673 L p .707 .577 .707 r
F P
0 g
s
.26892 .65543 m .26386 .68731 L .23228 .68523 L p .707 .577 .707 r
F P
0 g
s
.3252 .73404 m .32258 .74994 L .2952 .73795 L p .707 .577 .707 r
F P
0 g
s
.2952 .73795 m .29782 .72205 L .3252 .73404 L p .707 .577 .707 r
F P
0 g
s
.70192 .64627 m .69889 .58928 L .67168 .58824 L p .707 .577 .707 r
F P
0 g
s
.69889 .58928 m .70192 .64627 L .73296 .64575 L p .707 .577 .707 r
F P
0 g
s
.23535 .71297 m .23273 .72887 L .20377 .73266 L p .707 .577 .707 r
F P
0 g
s
.23273 .72887 m .23535 .71297 L .26686 .71479 L p .707 .577 .707 r
F P
0 g
s
.79125 .58341 m .79428 .6404 L .81856 .6361 L p .707 .577 .707 r
F P
0 g
s
.81856 .6361 m .81553 .5791 L .79125 .58341 L p .707 .577 .707 r
F P
0 g
s
.29782 .72205 m .2952 .73795 L .26424 .73069 L p .707 .577 .707 r
F P
0 g
s
.26424 .73069 m .26686 .71479 L .29782 .72205 L p .707 .577 .707 r
F P
0 g
s
.67168 .58824 m .67471 .64524 L .70192 .64627 L p .707 .577 .707 r
F P
0 g
s
.41072 .75282 m .41072 .25093 L .45011 .24501 L p .707 .577 .707 r
F P
0 g
s
.41072 .25093 m .41072 .75282 L .38008 .76171 L p .707 .577 .707 r
F P
0 g
s
.70025 .65514 m .7053 .69325 L .73613 .68889 L p .707 .577 .707 r
F P
0 g
s
.73613 .68889 m .73108 .65078 L .70025 .65514 L p .707 .577 .707 r
F P
0 g
s
.73108 .65078 m .73613 .68889 L .76772 .68481 L p .707 .577 .707 r
F P
0 g
s
.26686 .71479 m .26424 .73069 L .23273 .72887 L p .707 .577 .707 r
F P
0 g
s
.76772 .68481 m .76267 .6467 L .73108 .65078 L p .707 .577 .707 r
F P
0 g
s
.76267 .6467 m .76772 .68481 L .79696 .6814 L p .707 .577 .707 r
F P
0 g
s
.79696 .6814 m .79191 .64329 L .76267 .6467 L p .707 .577 .707 r
F P
0 g
s
.58017 .24915 m .58017 .75104 L .53919 .74597 L p .707 .577 .707 r
F P
0 g
s
.53919 .74597 m .53919 .24408 L .58017 .24915 L p .707 .577 .707 r
F P
0 g
s
.67471 .64524 m .67168 .58824 L .65095 .58576 L p .707 .577 .707 r
F P
0 g
s
.67318 .65935 m .67823 .69746 L .7053 .69325 L p .707 .577 .707 r
F P
0 g
s
.7053 .69325 m .70025 .65514 L .67318 .65935 L p .707 .577 .707 r
F P
0 g
s
.65095 .58576 m .65398 .64276 L .67471 .64524 L p .707 .577 .707 r
F P
0 g
s
.79191 .64329 m .79696 .6814 L .821 .679 L p .707 .577 .707 r
F P
0 g
s
.821 .679 m .81595 .64089 L .79191 .64329 L p .707 .577 .707 r
F P
0 g
s
.81553 .5791 m .81856 .6361 L .83524 .63124 L p .707 .577 .707 r
F P
0 g
s
.83524 .63124 m .83221 .57424 L .81553 .5791 L p .707 .577 .707 r
F P
0 g
s
.70218 .71467 m .7048 .73371 L .73576 .72919 L p .707 .577 .707 r
F P
0 g
s
.73576 .72919 m .73314 .71015 L .70218 .71467 L p .707 .577 .707 r
F P
0 g
s
.73314 .71015 m .73576 .72919 L .76726 .72499 L p .707 .577 .707 r
F P
0 g
s
.76726 .72499 m .76464 .70595 L .73314 .71015 L p .707 .577 .707 r
F P
0 g
s
.45011 .7469 m .45011 .24501 L .49437 .24265 L p .707 .577 .707 r
F P
0 g
s
.45011 .24501 m .45011 .7469 L .41072 .75282 L p .707 .577 .707 r
F P
0 g
s
.76464 .70595 m .76726 .72499 L .79623 .72153 L p .707 .577 .707 r
F P
0 g
s
.79623 .72153 m .79361 .70249 L .76464 .70595 L p .707 .577 .707 r
F P
0 g
s
.53919 .24408 m .53919 .74597 L .49437 .74454 L p .707 .577 .707 r
F P
0 g
s
.49437 .74454 m .49437 .24265 L .53919 .24408 L p .707 .577 .707 r
F P
0 g
s
.65253 .663 m .65758 .70111 L .67823 .69746 L p .707 .577 .707 r
F P
0 g
s
.67823 .69746 m .67318 .65935 L .65253 .663 L p .707 .577 .707 r
F P
0 g
s
.6748 .71908 m .67742 .73811 L .7048 .73371 L p .707 .577 .707 r
F P
0 g
s
.7048 .73371 m .70218 .71467 L .6748 .71908 L p .707 .577 .707 r
F P
0 g
s
.49437 .24265 m .49437 .74454 L .45011 .7469 L p .707 .577 .707 r
F P
0 g
s
.65398 .64276 m .65095 .58576 L .63873 .58207 L p .707 .577 .707 r
F P
0 g
s
.79361 .70249 m .79623 .72153 L .81983 .71915 L p .707 .577 .707 r
F P
0 g
s
.81983 .71915 m .81721 .70011 L .79361 .70249 L p .707 .577 .707 r
F P
0 g
s
.81595 .64089 m .821 .679 L .83748 .67785 L p .707 .577 .707 r
F P
0 g
s
.83748 .67785 m .83243 .63974 L .81595 .64089 L p .707 .577 .707 r
F P
0 g
s
.63873 .58207 m .64176 .63906 L .65398 .64276 L p .707 .577 .707 r
F P
0 g
s
.65368 .72293 m .6563 .74197 L .67742 .73811 L p .707 .577 .707 r
F P
0 g
s
.67742 .73811 m .6748 .71908 L .65368 .72293 L p .707 .577 .707 r
F P
0 g
s
.83221 .57424 m .83524 .63124 L .8427 .62629 L p .707 .577 .707 r
F P
0 g
s
.8427 .62629 m .83967 .5693 L .83221 .57424 L p .707 .577 .707 r
F P
0 g
s
.64031 .66573 m .64537 .70384 L .65758 .70111 L p .707 .577 .707 r
F P
0 g
s
.65758 .70111 m .65253 .663 L .64031 .66573 L p .707 .577 .707 r
F P
0 g
s
.81721 .70011 m .81983 .71915 L .83574 .71807 L p .707 .577 .707 r
F P
0 g
s
.83574 .71807 m .83312 .69903 L .81721 .70011 L p .707 .577 .707 r
F P
0 g
s
.64176 .63906 m .63873 .58207 L .63623 .57753 L p .707 .577 .707 r
F P
0 g
s
.64088 .72586 m .6435 .7449 L .6563 .74197 L p .707 .577 .707 r
F P
0 g
s
.6563 .74197 m .65368 .72293 L .64088 .72586 L p .707 .577 .707 r
F P
0 g
s
.83243 .63974 m .83748 .67785 L .84479 .67805 L p .707 .577 .707 r
F P
0 g
s
.84479 .67805 m .83973 .63994 L .83243 .63974 L p .707 .577 .707 r
F P
0 g
s
.63623 .57753 m .63926 .63452 L .64176 .63906 L p .707 .577 .707 r
F P
0 g
s
.83967 .5693 m .8427 .62629 L .8402 .62175 L p .707 .577 .707 r
F P
0 g
s
.8402 .62175 m .83717 .56476 L .83967 .5693 L p .707 .577 .707 r
F P
0 g
s
.63774 .66727 m .64279 .70538 L .64537 .70384 L p .707 .577 .707 r
F P
0 g
s
.64537 .70384 m .64031 .66573 L .63774 .66727 L p .707 .577 .707 r
F P
0 g
s
.83312 .69903 m .83574 .71807 L .84242 .71841 L p .707 .577 .707 r
F P
0 g
s
.84242 .71841 m .8398 .69937 L .83312 .69903 L p .707 .577 .707 r
F P
0 g
s
.63926 .63452 m .63623 .57753 L .64369 .57258 L p .707 .577 .707 r
F P
0 g
s
.63766 .72758 m .64028 .74662 L .6435 .7449 L p .707 .577 .707 r
F P
0 g
s
.6435 .7449 m .64088 .72586 L .63766 .72758 L p .707 .577 .707 r
F P
0 g
s
.83973 .63994 m .84479 .67805 L .84221 .67959 L p .707 .577 .707 r
F P
0 g
s
.84221 .67959 m .83716 .64149 L .83973 .63994 L p .707 .577 .707 r
F P
0 g
s
.64369 .57258 m .64672 .62958 L .63926 .63452 L p .707 .577 .707 r
F P
0 g
s
.83717 .56476 m .8402 .62175 L .82798 .61806 L p .707 .577 .707 r
F P
0 g
s
.82798 .61806 m .82495 .56106 L .83717 .56476 L p .707 .577 .707 r
F P
0 g
s
.64504 .66747 m .6501 .70558 L .64279 .70538 L p .707 .577 .707 r
F P
0 g
s
.64279 .70538 m .63774 .66727 L .64504 .66747 L p .707 .577 .707 r
F P
0 g
s
.39091 .62613 m .38384 .57184 L .35301 .57305 L p .707 .577 .707 r
F P
0 g
s
.38384 .57184 m .39091 .62613 L .42255 .62166 L p .707 .577 .707 r
F P
0 g
s
.42255 .62166 m .41547 .56736 L .38384 .57184 L p .707 .577 .707 r
F P
0 g
s
.41547 .56736 m .42255 .62166 L .45189 .61436 L p .707 .577 .707 r
F P
0 g
s
.45189 .61436 m .44481 .56006 L .41547 .56736 L p .707 .577 .707 r
F P
0 g
s
.8398 .69937 m .84242 .71841 L .8392 .72013 L p .707 .577 .707 r
F P
0 g
s
.8392 .72013 m .83658 .70109 L .8398 .69937 L p .707 .577 .707 r
F P
0 g
s
.36008 .62735 m .35301 .57305 L .326 .57089 L p .707 .577 .707 r
F P
0 g
s
.35301 .57305 m .36008 .62735 L .39091 .62613 L p .707 .577 .707 r
F P
0 g
s
.64672 .62958 m .64369 .57258 L .66037 .56772 L p .707 .577 .707 r
F P
0 g
s
.44481 .56006 m .45189 .61436 L .47607 .60495 L p .707 .577 .707 r
F P
0 g
s
.47607 .60495 m .46899 .55065 L .44481 .56006 L p .707 .577 .707 r
F P
0 g
s
.64434 .72792 m .64696 .74695 L .64028 .74662 L p .707 .577 .707 r
F P
0 g
s
.64028 .74662 m .63766 .72758 L .64434 .72792 L p .707 .577 .707 r
F P
0 g
s
.83716 .64149 m .84221 .67959 L .83 .68232 L p .707 .577 .707 r
F P
0 g
s
.83 .68232 m .82494 .64421 L .83716 .64149 L p .707 .577 .707 r
F P
0 g
s
.66037 .56772 m .6634 .62472 L .64672 .62958 L p .707 .577 .707 r
F P
0 g
s
.82495 .56106 m .82798 .61806 L .80726 .61558 L p .707 .577 .707 r
F P
0 g
s
.80726 .61558 m .80423 .55858 L .82495 .56106 L p .707 .577 .707 r
F P
0 g
s
.42706 .68417 m .4155 .65035 L .38508 .65999 L p .707 .577 .707 r
F P
0 g
s
.4155 .65035 m .42706 .68417 L .45538 .67135 L p .707 .577 .707 r
F P
0 g
s
.45538 .67135 m .44382 .63754 L .4155 .65035 L p .707 .577 .707 r
F P
0 g
s
.33308 .62518 m .326 .57089 L .30546 .56555 L p .707 .577 .707 r
F P
0 g
s
.326 .57089 m .33308 .62518 L .36008 .62735 L p .707 .577 .707 r
F P
0 g
s
.39663 .69381 m .38508 .65999 L .35553 .66551 L p .707 .577 .707 r
F P
0 g
s
.38508 .65999 m .39663 .69381 L .42706 .68417 L p .707 .577 .707 r
F P
0 g
s
.66152 .66632 m .66658 .70443 L .6501 .70558 L p .707 .577 .707 r
F P
0 g
s
.6501 .70558 m .64504 .66747 L .66152 .66632 L p .707 .577 .707 r
F P
0 g
s
.46899 .55065 m .47607 .60495 L .49272 .59435 L p .707 .577 .707 r
F P
0 g
s
.49272 .59435 m .48564 .54006 L .46899 .55065 L p .707 .577 .707 r
F P
0 g
s
.44382 .63754 m .45538 .67135 L .47883 .65661 L p .707 .577 .707 r
F P
0 g
s
.47883 .65661 m .46727 .6228 L .44382 .63754 L p .707 .577 .707 r
F P
0 g
s
.83658 .70109 m .8392 .72013 L .8264 .72306 L p .707 .577 .707 r
F P
0 g
s
.8264 .72306 m .82378 .70402 L .83658 .70109 L p .707 .577 .707 r
F P
0 g
s
.6634 .62472 m .66037 .56772 L .68465 .56342 L p .707 .577 .707 r
F P
0 g
s
.36708 .69933 m .35553 .66551 L .32974 .66637 L p .707 .577 .707 r
F P
0 g
s
.35553 .66551 m .36708 .69933 L .39663 .69381 L p .707 .577 .707 r
F P
0 g
s
.42327 .72686 m .41733 .71005 L .38704 .72016 L p .707 .577 .707 r
F P
0 g
s
.41733 .71005 m .42327 .72686 L .45128 .71359 L p .707 .577 .707 r
F P
0 g
s
.45128 .71359 m .44534 .69678 L .41733 .71005 L p .707 .577 .707 r
F P
0 g
s
.39298 .73697 m .38704 .72016 L .35742 .72613 L p .707 .577 .707 r
F P
0 g
s
.38704 .72016 m .39298 .73697 L .42327 .72686 L p .707 .577 .707 r
F P
0 g
s
.66025 .72684 m .66287 .74588 L .64696 .74695 L p .707 .577 .707 r
F P
0 g
s
.64696 .74695 m .64434 .72792 L .66025 .72684 L p .707 .577 .707 r
F P
0 g
s
.30546 .56555 m .31254 .61985 L .33308 .62518 L p .707 .577 .707 r
F P
0 g
s
.82494 .64421 m .83 .68232 L .80934 .68597 L p .707 .577 .707 r
F P
0 g
s
.80934 .68597 m .80429 .64786 L .82494 .64421 L p .707 .577 .707 r
F P
0 g
s
.68465 .56342 m .68768 .62041 L .6634 .62472 L p .707 .577 .707 r
F P
0 g
s
.80423 .55858 m .80726 .61558 L .78004 .61454 L p .707 .577 .707 r
F P
0 g
s
.78004 .61454 m .77701 .55755 L .80423 .55858 L p .707 .577 .707 r
F P
0 g
s
.46727 .6228 m .47883 .65661 L .4951 .6414 L p .707 .577 .707 r
F P
0 g
s
.4951 .6414 m .48355 .60758 L .46727 .6228 L p .707 .577 .707 r
F P
0 g
s
.31254 .61985 m .30546 .56555 L .2934 .55757 L p .707 .577 .707 r
F P
0 g
s
.44534 .69678 m .45128 .71359 L .47426 .69847 L p .707 .577 .707 r
F P
0 g
s
.47426 .69847 m .46832 .68166 L .44534 .69678 L p .707 .577 .707 r
F P
0 g
s
.35742 .72613 m .36336 .74294 L .39298 .73697 L p .707 .577 .707 r
F P
0 g
s
.32974 .66637 m .3413 .70018 L .36708 .69933 L p .707 .577 .707 r
F P
0 g
s
.36336 .74294 m .35742 .72613 L .33139 .72738 L p .707 .577 .707 r
F P
0 g
s
.48564 .54006 m .49272 .59435 L .50021 .58361 L p .707 .577 .707 r
F P
0 g
s
.50021 .58361 m .49313 .52931 L .48564 .54006 L p .707 .577 .707 r
F P
0 g
s
.68556 .66392 m .69061 .70203 L .66658 .70443 L p .707 .577 .707 r
F P
0 g
s
.66658 .70443 m .66152 .66632 L .68556 .66392 L p .707 .577 .707 r
F P
0 g
s
.3413 .70018 m .32974 .66637 L .31025 .66249 L p .707 .577 .707 r
F P
0 g
s
.68768 .62041 m .68465 .56342 L .71414 .56009 L p .707 .577 .707 r
F P
0 g
s
.33139 .72738 m .33732 .74418 L .36336 .74294 L p .707 .577 .707 r
F P
0 g
s
.82378 .70402 m .8264 .72306 L .80528 .72691 L p .707 .577 .707 r
F P
0 g
s
.80528 .72691 m .80266 .70787 L .82378 .70402 L p .707 .577 .707 r
F P
0 g
s
.77701 .55755 m .78004 .61454 L .749 .61506 L p .707 .577 .707 r
F P
0 g
s
.749 .61506 m .74597 .55807 L .77701 .55755 L p .707 .577 .707 r
F P
0 g
s
.46832 .68166 m .47426 .69847 L .48996 .68297 L p .707 .577 .707 r
F P
0 g
s
.48996 .68297 m .48402 .66617 L .46832 .68166 L p .707 .577 .707 r
F P
0 g
s
.71414 .56009 m .71717 .61709 L .68768 .62041 L p .707 .577 .707 r
F P
0 g
s
.2934 .55757 m .30048 .61187 L .31254 .61985 L p .707 .577 .707 r
F P
0 g
s
.80429 .64786 m .80934 .68597 L .78228 .69018 L p .707 .577 .707 r
F P
0 g
s
.78228 .69018 m .77722 .65207 L .80429 .64786 L p .707 .577 .707 r
F P
0 g
s
.71717 .61709 m .71414 .56009 L .74597 .55807 L p .707 .577 .707 r
F P
0 g
s
.31025 .66249 m .3218 .6963 L .3413 .70018 L p .707 .577 .707 r
F P
0 g
s
.48355 .60758 m .4951 .6414 L .50261 .62719 L p .707 .577 .707 r
F P
0 g
s
.50261 .62719 m .49106 .59338 L .48355 .60758 L p .707 .577 .707 r
F P
0 g
s
.68385 .72445 m .68647 .74349 L .66287 .74588 L p .707 .577 .707 r
F P
0 g
s
.66287 .74588 m .66025 .72684 L .68385 .72445 L p .707 .577 .707 r
F P
0 g
s
.74597 .55807 m .749 .61506 L .71717 .61709 L p .707 .577 .707 r
F P
0 g
s
.33732 .74418 m .33139 .72738 L .31147 .72377 L p .707 .577 .707 r
F P
0 g
s
.7148 .66052 m .71986 .69862 L .69061 .70203 L p .707 .577 .707 r
F P
0 g
s
.69061 .70203 m .68556 .66392 L .7148 .66052 L p .707 .577 .707 r
F P
0 g
s
.30048 .61187 m .2934 .55757 L .291 .54773 L p .707 .577 .707 r
F P
0 g
s
.31147 .72377 m .31741 .74057 L .33732 .74418 L p .707 .577 .707 r
F P
0 g
s
.3218 .6963 m .31025 .66249 L .29896 .65424 L p .707 .577 .707 r
F P
0 g
s
.49313 .52931 m .50021 .58361 L .49781 .57376 L p .707 .577 .707 r
F P
0 g
s
.49781 .57376 m .49073 .51946 L .49313 .52931 L p .707 .577 .707 r
F P
0 g
s
.77722 .65207 m .78228 .69018 L .75144 .69454 L p .707 .577 .707 r
F P
0 g
s
.75144 .69454 m .74639 .65643 L .77722 .65207 L p .707 .577 .707 r
F P
0 g
s
.80266 .70787 m .80528 .72691 L .7779 .73132 L p .707 .577 .707 r
F P
0 g
s
.7779 .73132 m .77528 .71228 L .80266 .70787 L p .707 .577 .707 r
F P
0 g
s
.74639 .65643 m .75144 .69454 L .71986 .69862 L p .707 .577 .707 r
F P
0 g
s
.71986 .69862 m .7148 .66052 L .74639 .65643 L p .707 .577 .707 r
F P
0 g
s
.48402 .66617 m .48996 .68297 L .49685 .66862 L p .707 .577 .707 r
F P
0 g
s
.49685 .66862 m .49091 .65181 L .48402 .66617 L p .707 .577 .707 r
F P
0 g
s
.71282 .721 m .71543 .74003 L .68647 .74349 L p .707 .577 .707 r
F P
0 g
s
.68647 .74349 m .68385 .72445 L .71282 .721 L p .707 .577 .707 r
F P
0 g
s
.29896 .65424 m .31051 .68805 L .3218 .6963 L p .707 .577 .707 r
F P
0 g
s
.291 .54773 m .29807 .60202 L .30048 .61187 L p .707 .577 .707 r
F P
0 g
s
.31741 .74057 m .31147 .72377 L .29964 .71566 L p .707 .577 .707 r
F P
0 g
s
.49106 .59338 m .50261 .62719 L .50063 .61538 L p .707 .577 .707 r
F P
0 g
s
.50063 .61538 m .48907 .58157 L .49106 .59338 L p .707 .577 .707 r
F P
0 g
s
.77528 .71228 m .7779 .73132 L .74694 .73584 L p .707 .577 .707 r
F P
0 g
s
.74694 .73584 m .74432 .7168 L .77528 .71228 L p .707 .577 .707 r
F P
0 g
s
.29964 .71566 m .30558 .73247 L .31741 .74057 L p .707 .577 .707 r
F P
0 g
s
.74432 .7168 m .74694 .73584 L .71543 .74003 L p .707 .577 .707 r
F P
0 g
s
.71543 .74003 m .71282 .721 L .74432 .7168 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29807 .60202 m .291 .54773 L .29849 .53698 L p .707 .577 .707 r
F P
0 g
s
.31051 .68805 m .29896 .65424 L .29697 .64243 L p .707 .577 .707 r
F P
0 g
s
.49073 .51946 m .49781 .57376 L .48574 .56578 L p .707 .577 .707 r
F P
0 g
s
.48574 .56578 m .47867 .51148 L .49073 .51946 L p .707 .577 .707 r
F P
0 g
s
.49091 .65181 m .49685 .66862 L .49424 .65681 L p .707 .577 .707 r
F P
0 g
s
.49424 .65681 m .48831 .64001 L .49091 .65181 L p .707 .577 .707 r
F P
0 g
s
.29697 .64243 m .30852 .67625 L .31051 .68805 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30558 .73247 m .29964 .71566 L .29704 .70386 L p .707 .577 .707 r
F P
0 g
s
.29849 .53698 m .30556 .59128 L .29807 .60202 L p .707 .577 .707 r
F P
0 g
s
.48907 .58157 m .50063 .61538 L .48933 .60713 L p .707 .577 .707 r
F P
0 g
s
.48933 .60713 m .47778 .57332 L .48907 .58157 L p .707 .577 .707 r
F P
0 g
s
.29704 .70386 m .30297 .72066 L .30558 .73247 L p .707 .577 .707 r
F P
0 g
s
.30556 .59128 m .29849 .53698 L .31514 .52638 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30852 .67625 m .29697 .64243 L .30448 .62823 L p .707 .577 .707 r
F P
0 g
s
.47867 .51148 m .48574 .56578 L .4652 .56044 L p .707 .577 .707 r
F P
0 g
s
.4652 .56044 m .45813 .50615 L .47867 .51148 L p .707 .577 .707 r
F P
0 g
s
.48831 .64001 m .49424 .65681 L .48241 .64871 L p .707 .577 .707 r
F P
0 g
s
.48241 .64871 m .47647 .6319 L .48831 .64001 L p .707 .577 .707 r
F P
0 g
s
.30448 .62823 m .31604 .66204 L .30852 .67625 L p .707 .577 .707 r
F P
0 g
s
.30297 .72066 m .29704 .70386 L .30392 .6895 L p .707 .577 .707 r
F P
0 g
s
.31514 .52638 m .32221 .58068 L .30556 .59128 L p .707 .577 .707 r
F P
0 g
s
.47778 .57332 m .48933 .60713 L .46984 .60325 L p .707 .577 .707 r
F P
0 g
s
.46984 .60325 m .45829 .56944 L .47778 .57332 L p .707 .577 .707 r
F P
0 g
s
.30392 .6895 m .30986 .70631 L .30297 .72066 L p .707 .577 .707 r
F P
0 g
s
.32221 .58068 m .31514 .52638 L .33931 .51698 L p .707 .577 .707 r
F P
0 g
s
.45813 .50615 m .4652 .56044 L .4382 .55828 L p .707 .577 .707 r
F P
0 g
s
.4382 .55828 m .43112 .50398 L .45813 .50615 L p .707 .577 .707 r
F P
0 g
s
.31604 .66204 m .30448 .62823 L .32076 .61301 L p .707 .577 .707 r
F P
0 g
s
.47647 .6319 m .48241 .64871 L .4625 .6451 L p .707 .577 .707 r
F P
0 g
s
.4625 .6451 m .45656 .6283 L .47647 .6319 L p .707 .577 .707 r
F P
0 g
s
.33931 .51698 m .34639 .57127 L .32221 .58068 L p .707 .577 .707 r
F P
0 g
s
.34639 .57127 m .33931 .51698 L .36866 .50968 L p .707 .577 .707 r
F P
0 g
s
.32076 .61301 m .33231 .64682 L .31604 .66204 L p .707 .577 .707 r
F P
0 g
s
.45829 .56944 m .46984 .60325 L .44406 .60411 L p .707 .577 .707 r
F P
0 g
s
.44406 .60411 m .4325 .5703 L .45829 .56944 L p .707 .577 .707 r
F P
0 g
s
.30986 .70631 m .30392 .6895 L .31962 .67401 L p .707 .577 .707 r
F P
0 g
s
.43112 .50398 m .4382 .55828 L .40737 .55949 L p .707 .577 .707 r
F P
0 g
s
.40737 .55949 m .40029 .5052 L .43112 .50398 L p .707 .577 .707 r
F P
0 g
s
.31962 .67401 m .32556 .69081 L .30986 .70631 L p .707 .577 .707 r
F P
0 g
s
.33231 .64682 m .32076 .61301 L .3442 .59827 L p .707 .577 .707 r
F P
0 g
s
.37573 .56397 m .36866 .50968 L .40029 .5052 L p .707 .577 .707 r
F P
0 g
s
.36866 .50968 m .37573 .56397 L .34639 .57127 L p .707 .577 .707 r
F P
0 g
s
.40029 .5052 m .40737 .55949 L .37573 .56397 L p .707 .577 .707 r
F P
0 g
s
.45656 .6283 m .4625 .6451 L .43646 .64634 L p .707 .577 .707 r
F P
0 g
s
.43646 .64634 m .43052 .62954 L .45656 .6283 L p .707 .577 .707 r
F P
0 g
s
.4325 .5703 m .44406 .60411 L .41451 .60963 L p .707 .577 .707 r
F P
0 g
s
.41451 .60963 m .40295 .57582 L .4325 .5703 L p .707 .577 .707 r
F P
0 g
s
.3442 .59827 m .35576 .63208 L .33231 .64682 L p .707 .577 .707 r
F P
0 g
s
.32556 .69081 m .31962 .67401 L .3426 .65889 L p .707 .577 .707 r
F P
0 g
s
.35576 .63208 m .3442 .59827 L .37253 .58546 L p .707 .577 .707 r
F P
0 g
s
.40295 .57582 m .41451 .60963 L .38408 .61927 L p .707 .577 .707 r
F P
0 g
s
.38408 .61927 m .37253 .58546 L .40295 .57582 L p .707 .577 .707 r
F P
0 g
s
.3426 .65889 m .34854 .67569 L .32556 .69081 L p .707 .577 .707 r
F P
0 g
s
.37253 .58546 m .38408 .61927 L .35576 .63208 L p .707 .577 .707 r
F P
0 g
s
.43052 .62954 m .43646 .64634 L .40684 .65231 L p .707 .577 .707 r
F P
0 g
s
.40684 .65231 m .40091 .63551 L .43052 .62954 L p .707 .577 .707 r
F P
0 g
s
.34854 .67569 m .3426 .65889 L .37061 .64562 L p .707 .577 .707 r
F P
0 g
s
.40091 .63551 m .40684 .65231 L .37655 .66243 L p .707 .577 .707 r
F P
0 g
s
.37655 .66243 m .37061 .64562 L .40091 .63551 L p .707 .577 .707 r
F P
0 g
s
.37061 .64562 m .37655 .66243 L .34854 .67569 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP000080
07Aoo`00Kgoo100000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00UYF1000L7oo001/Ool30005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH2001^Ool006Yoo`<000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP<006aoo`00JGoo00@0
05YFFUH000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF008006Yoo`00Igoo0P000eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF
0P00J7oo001VOol00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2001WOol006Ioo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0006Ioo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00eYF00@005YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00IGoo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00
IGoo0P001EYF600025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00IGoo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH006Eoo`00IGoo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH006Eoo`00HWoo0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF0`0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF
00@005YFFUH006Eoo`00Ggoo0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YFFUH006Eoo`00Fgoo100000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00FGoo0P001EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000aJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00
000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001EOol2
0002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH0000=FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP00IGoo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0035YF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH006Eoo`00Dgoo0P0015YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol005=oo`8000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol0059oo`03001JEP0000EJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF001UOol0059oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol0059oo`04001JEUYF
0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00eYF00@005YFFUH006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00=JEP04001JEP00000;FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0067oo5`00=Woo001BOol01000
FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@001EYF2P000eYF00@0
05YF000000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000?Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05000aOol005=oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPX00003FUH005YF00=JEP@00003FUH005YF00EJEP03001J
EP0000<0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEUYF0007Ool80003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUH00000;goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP040003
FUH00`00FUH0000:0005FUH60002FUH00`00FUIJEP02FUH00`00FUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00Ool01P000eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo001C
Ool00`00FUH00005FUH00`00FUIJEP03FUHB0003FUH90003FUH00`00FUH000020004FUH4000:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP02000^Ool005=oo`03001JEP0000EJEP04001JEUYFFUH20003FUH00`00FUIJEP06
FUH00`00FUH000070003FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUH000002UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0`0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00;Woo001COol00`00FUH00005FUH01000FUH000001EYF00<005YFFUH01UYF100000=JEP00FUH0
1eYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF008000YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00
Dgoo00@005YFFUH000AJEP8000MJEP03001JEUYF00AJEP<000EJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP04001JEP000002FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=o
o`04001JEUYF0002FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=o
o`03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEP00008000UJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF008000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002ioo`00@7oo4@000goo
0UYF0P001EYF00<005YFFUH01EYF0P000eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
15YF00<005YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000^Ool003Yoo`H000=JEP03001JEUYF
00IJEP03001JEUYF009JEP<00004FUH005YF0005FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
;Woo000fOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00005FUH0
1000FUIJEUYF0P0025YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000
1EYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH00`00FUH000020009FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH<0003FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000aOol200000eYF001J
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF001JEP04FUH20003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00FUIJEP03FUH600000eYF
001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP000eYF0P0015YF00<005YFFUH01eYF00<005YF
FUH01EYF1@001eYF00<005YF00000`000UYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo000^
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEP000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH0
15YF0`001EYF00@005YFFUH0009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEQ4000AJ
EP03001JEUYF00=JEP03001JEUYF008002eoo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF100000=JEP0000001eYF00<005YFFUH01eYF00<005YF
00000P001UYF00<005YFFUH01@001UYF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF009J
EPP000UJEP03001JEUYF00EJEP`00003FUH0000002eoo`00;Goo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00P000UYF00<005YF
FUH01EYF00<005YFFUH01EYF10001UYF1@0015YF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF
FUH00P002UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF
00@005YFFUIJEPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002eoo`00;Goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00=JEP8000=JEP03
001JEUYF00@000UJEP03001JEUYF009JEP03001JEUYF00=JEP05001JEUYFFUH0000:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP02FUH50007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool002eo
o`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEP0000EJEP03001JEUYF00IJEP03001JEP0000X0009JEP03001JEUYF00MJEPL000IJEP04
001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP02
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00EJEP8000EJEP03
001JEP0000@00003FUH005YF00P000=JEP03001JEUYF00@000=JEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800004FUH000000005FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04000^Ool0
02eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF00AJEP03001JEUYF00=JEP@000EJEP03001JEP0000L000AJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF00=JEP<0009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0039oo`00;Goo0P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000EJEP04001JEUYFFUH30000
0eYF00000005FUH01P00FUH00000FUH000UJEP03001JEUYF00AJEP03001JEUYF00=JEP80009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP06001JEP00001JEP00
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0`000goo1@00;Woo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEP001UYF0`0000AJEP00FUIJEP8000AJEP<000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF3@000UYF0P0000=JEWooOol0;7oo000]Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHA0004FUH01000FUIJEP001UYF00D005YFFUIJEP00009JEP80009JEP8000MJ
EP03001JEUYF00EJEP`000=JEP@000aJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=J
EP04001JEUYF0004OolQ0004FUH00`00FUIJEP03FUH500000eYF001JEP0^Ool002eoo`8000AJEP03
001JEUYF00=JEPH0015oo`H0009JEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00D000UJ
EP03001JEUYF00@000EJEP03001JEUYF00AJEP@00003FUH0000000aJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF008001Uoo`@0009JEP03001JEUYF00IJEPL0009JEP06
001JEUYF001JEP00;Goo000/Ool00`00FUH00004FUH00`00FUH000030007Ool8000<Ool20002FUH0
1@00FUIJEUYF00001EYF00<005YFFUH00P000eYF00<005YFFUH01EYF1@0025YF00<005YFFUH01UYF
1@0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00D005YFFUH005YF00@000mo
o`H000IJEPT000=JEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJEP<0
00Aoo`H000=JEP03001JEUYF009JEPL000Eoo`80009JEP03001JEUYF008000EJEP<000EJEP03001J
EUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000aJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH30004Ool80003FUH:0003FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00002FUH20003
FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP0400000goo00000003FUH40004FUH2
0008FUH00`00FUH000020007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUH0000<
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001EYF1`000eYF2@00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;7oo
00<005YF00000`0015YF0P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1000
0UYF2@002EYF0`002EYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP04001JEUYF000<FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP060002FUH80004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P00;Goo000/
Ool00`00FUH00002FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH2000015YF001JEUYF10000eYF00<005YFFUH015YF0P000eYF00<005YFFUH01UYF00<005YF
FUH01eYF0`001EYF00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP`0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;7oo0P000eYF00@005YF000000EJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP800004FUH00000FUH20005FUH00`00FUIJEP02FUH20005
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH002aoo`00;7oo0P000eYF0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00D005YF000005YF008000QJEP04001JEP000007FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH20006FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002ao
o`80009JEP04001JEUYF0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH00P0025YF0P0000=JEP00FUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0`001UYF
00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000/Ool200000eYF001JEP02FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002
FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP06FUH30007FUH01000FUH000000UYF00<005YFFUH0
0eYF00<005YFFUH00eYF0P0035YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P00
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000]Ool30003FUH00`00FUIJEP03
FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00@005YFFUIJEP80
00IJEP03001JEUYF00AJEPD000EJEP<000AJEP04001JEUYFFUH30005FUH2000<FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000_Ool002eo
o`<000=JEP03001JEUYF009JEPH00003FUH005YF00IJEPH000IJEP05001JEUYFFUH00004FUH40007
FUH00`00FUIJEP04FUH50002FUH30007FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF0000
35YF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH003Ao
o`00;Goo00<005YF00000UYF00@005YFFUIJEP8000MJEP03001JEUYF00IJEP03001JEUYF009JEP@0
009JEP04001JEUYF0005FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF1`002UYF00<005YF0000
15YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
00=JEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH9000jOol002eoo`03001JEP00009JEP03001JEP00008000MJEP03001JEUYF00MJEP03
001JEUYF00IJEP<00003FUH0000000AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF009J
EPD0009JEP03001JEUYF00QJEP8000EJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH90013Ool002eoo`8000=JEP80009JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYFFUH2000015YF001JEUYF10000eYF00@005YFFUIJEPP000MJEP03001J
EUYF00IJEP8000MJEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH8000JOol4
000^Ool002eoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00002FUH01@00FUH005YF00000UYF2@001EYF00<005YFFUH01EYF00<005YF
FUH015YF0P0000=JEP00FUH015YF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00eYF00D005YF001JEP0000AJEP04001JEUYFFUH8000EOol=000015YF00000000
;Woo000]Ool2000015YF000000000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00D005YFFUIJEP0000=JEP800003FUH005YF00EJEP03001JEUYF008000EJEP03001JEUYF00EJEP04
001JEUYFFUH30004FUH01@00FUIJEUYF000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00002P000eYF00<005YFFUH00P0037oo2@000eYF00<005YF
FUH015YF100000=JEP000000;Woo000]Ool30003Ool200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0000=JEP0000001EYF00@005YFFUIJEP8000EJEP03
001JEUYF00EJEP@000MJEP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01000FUIJEUYF0P001Goo
1`0015YF00<005YFFUH01EYF1`000UYF00<005YFFUH00P00;Woo000/Ool00`00FUH00006Ool30006
FUH:0008FUH00`00FUIJEP02FUH01000FUH000000eYF0P000eYF00@005YFFUIJEP8000EJEP03001J
EUYF00AJEP800003FUH005YF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH40005FUH01000FUIJEUYF0P0000=oo`00
00000P000UYF00<005YFFUH01EYF2@000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo
100027oo1`000eYF00<005YFFUH00UYF1`000UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0`00
0UYF00@005YFFUIJEP8000EJEP04001JEUYFFUH30004FUH00`00FUIJEP04FUH2000<FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00@005YF
FUIJEP8000=JEPL000IJEPP000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool002aoo`@000Moo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00@000AJEPH000=o
o`<000=JEP8000EJEP@000MJEP03001JEUYF009JEP800003FUH005YF00]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP070003
FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP03000]Ool002aoo`80009JEP03001oogoo009oo`8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEPD00004FUH000000006Ool01000FUIJEUYF0P0000=JEP0000000P000UYF
00<005YFFUH01eYF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00H0009JEP03001JEUYF00EJEPH000IJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH5000`Ool002aoo`80009JEP03001oogoo0080
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00002FUH=0006
FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP03FUHC0003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF
1`00=Goo000/Ool20003FUH30005FUH00`00FUIJEP02FUH?0006FUH01000FUIJEP000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH00UYF0`0025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH0
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P00?7oo000/
Ool20003FUH00`00FUH00004FUH6000?Ool40002FUH01000FUIJEP000UYF00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000@Woo000/Ool01@00FUIJEUYF0000
0UYF00<005YF00000P006Goo0`000eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF0`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF1`00AWoo000/Ool01000FUIJEP000eYF0`007Woo0P000eYF10000UYF00<005YF
FUH01EYF00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF00<005YFFUH015YF
00<005YFFUH00UYF2000CGoo000/Ool01000FUH000000UYF00D005YFFUIJEP0001moo`8000=JEP03
001JEP0000`0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00AJEPd000IJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800003FUH005YF00=JEP04001JEUYFFUH8001E
Ool002eoo`800003FUH0000000EJEP8001moo`800003FUH005YF00AJEP03001oo`0000<000EJEP03
001JEUYF00EJEP03001JEUYF00IJEPT000UJEP04001JEUYFFUH<0005FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH>001KOol002eoo`@000IJEP04001JEP00000OOol20006FUH00`00FUH000020005FUH0
0`00FUIJEP05FUH00`00FUIJEP060005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00002
FUH80007FUH00`00FUIJEP03FUH01000FUIJEP000eYF0P00H7oo000]Ool200000eYF001JEP05FUH0
1000FUIJEUYF0`007Woo0P0015YF1@001EYF00<005YFFUH015YF1@002UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YF00002UYF1@000UYF00<005YFFUH00eYF00@005YFFUH000EJEP8005ioo`00
;Goo10001UYF00<005YFFUH015YF10006goo0P000UYF00<005YFFUH00`001EYF00<005YFFUH01000
15YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
0UYF0`001EYF00@005YFFUH000IJEP<005aoo`00;Goo00@007ooOol000IJEP03001JEUYF00EJEP03
001JEUYF00@001Eoo`80009JEP<0009JEP<000EJEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP8000=JEP04001JEUYF0005FUH01000
FUIJEUYF0P00FWoo000/Ool30002Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04FUH7
0009Ool50004FUH00`00FUH00003FUH20003FUH200000eYF001JEP08FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300001EYF001JEUYF0000
1EYF00<005YFFUH00eYF0P00F7oo000/Ool00`00FUH00003Ool01@00FUIJEUYF00001eYF00<005YF
FUH01eYF00<005YFFUH00UYF2@000eYF00<005YFFUH00eYF00@005YFFUH0009JEP800003FUH00000
00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00AJEP<005Io
o`00;7oo00<005YF000017oo0P0000=JEP00FUH01UYF00<005YFFUH01eYF0`001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00H005YFFUIJEP00FUH30005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool01000FUH000001Goo0P00
1eYF00<005YFFUH01UYF1@001EYF00<005YFFUH015YF00<005YFFUH015YF00H005YFFUIJEP00FUH3
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH01@00FUIJ
EUYF0000EGoo000/Ool01@00FUH005YF00001Goo0P001UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P0000Eoo`00001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<000AJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol002eoo`04001JEUYF0007
Ool20003FUH00`00FUIJEP07FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30004Ool00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00EGoo000]Ool01@00FUIJEUYF000027oo0P0000=JEP00FUH025YF10001EYF00<005YF
FUH01EYF00<005YFFUH00UYF0P001Woo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P001EYF00<005YFFUH00eYF00<005YFFUH00P00EWoo000]Ool00`00FUIJEP02FUH00`00Oomoo`07
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P0027oo0`001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF1@0000=JEP00FUH015YF00@005YFFUIJEP8005Ioo`00;Woo00@005YF
FUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00000;Ool20005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEP00FUH00`0015YF00@005YFFUIJEP8005Ioo`00;goo00H0
05YFFUH005YF000?Ool70004FUH00`00FUIJEP02FUH5000<Ool30005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH2000:FUH00`00FUIJEP06FUH00`00FUIJEP02
0003FUH00`00FUIJEP02FUH200000eYF001JEP02FUH2001GOol002moo`03001JEP0000=JEP8001Ao
o`T0015oo`800003Ool0000000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEPD000=JEP03001JEUYF00AJEP8000=JEP80
05Moo`00<7oo0P001EYF00<007ooOol0:Woo0`000goo0P0000=JEP00FUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P0015YF10001EYF
00<005YFFUH00`0000=JEP00Ool0EWoo000aOol00`00FUIJEP04FUH2000XOol200000eYF001oo`05
Ool40007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH30007FUH01000FUH0000015YF00<005YFFUH00UYF00<005YF0000Egoo000bOol20004
FUH01000FUH000009Goo00<005YFFUH00P002Woo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`0025YF00<005YFFUH00UYF10001EYF0P00
F7oo000dOol01000FUIJEP0015YF0P008Goo0P000eYF00<007ooOol03Woo1@0025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01UYF2@001eYF00<005YFFUH01EYF0`000UYF00<005YF0000
F7oo000eOol30006FUH4000KOol200000eYF001JEP02FUH00`00Oomoo`0COol60002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP060004FUH90002FUH00`00FUIJEP07FUH6001IOol003Mo
o`03001JEUYF00EJEP03001JEUYF00@001Eoo`8000=JEP04001JEUYF000LOolO00000eYF001JEP07
FUH50004Ool30008FUH01000FUIJEUYF0P00FWoo000hOol20005FUH00`00FUIJEP04FUH70009Ool5
0004FUH01000FUH00000?7oo0`001eYF100000AJEP00000000Aoo`8000IJEP03001JEUYF00=JEP03
001oogoo05Moo`00>Woo0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@000eYF00<005YFFUH0
0eYF0P00@Goo0P001EYF00<005YFFUH01EYF0`000goo0P0015YF00<005YFFUH00eYF0`00Egoo000l
Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20014Ool3
00000eYF001JEP08FUH00`00FUH0000300001Goo000005YF00001UYF00<005YFFUH00P00EGoo000n
Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020019Ool30008FUH00`00FUIJ
EP03FUH60004FUH00`00FUIJEP02FUH00`00Oomoo`1COol0045oo`@0009JEP03001JEUYF00IJEP03
001JEUYF009JEPH004moo`<000AJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP02FUH2
001EOol004Eooa0005Qoo`<00003FUH005YF00MJEP03001JEUYF00AJEP8000=JEP8005Eoo`00/7oo
0`001UYF00<005YFFUH015YF00@005YFFUH0009JEP8005Eoo`00/goo10000UYF00<005YFFUH015YF
00@005YFFUIJEP<005Ioo`00]goo1@000eYF00<005YFFUH00UYF0`00EWoo002lOol60002FUH00`00
FUH0001FOol00<9oo`@005Moo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]32\[InvisibleSpace]"     "\
\[InvisibleSpace]10.246105061388016`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 32, "     ", 10.246105061388016, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59627 .73299 m .60136 .67559 L .57025 .6725 L p .707 .577 .707 r
F P
0 g
s
.60136 .67559 m .59627 .73299 L .62795 .73564 L p .707 .577 .707 r
F P
0 g
s
.62795 .73564 m .63305 .67823 L .60136 .67559 L p .707 .577 .707 r
F P
0 g
s
.57025 .6725 m .56515 .72991 L .59627 .73299 L p .707 .577 .707 r
F P
0 g
s
.63305 .67823 m .62795 .73564 L .6571 .7376 L p .707 .577 .707 r
F P
0 g
s
.6571 .7376 m .66219 .68019 L .63305 .67823 L p .707 .577 .707 r
F P
0 g
s
.56515 .72991 m .57025 .6725 L .54273 .66929 L p .707 .577 .707 r
F P
0 g
s
.56855 .72864 m .56293 .76648 L .59395 .77037 L p .707 .577 .707 r
F P
0 g
s
.59395 .77037 m .59957 .73253 L .56855 .72864 L p .707 .577 .707 r
F P
0 g
s
.59957 .73253 m .59395 .77037 L .62535 .77539 L p .707 .577 .707 r
F P
0 g
s
.54273 .66929 m .53764 .7267 L .56515 .72991 L p .707 .577 .707 r
F P
0 g
s
.62535 .77539 m .63097 .73755 L .59957 .73253 L p .707 .577 .707 r
F P
0 g
s
.63097 .73755 m .62535 .77539 L .65406 .78103 L p .707 .577 .707 r
F P
0 g
s
.54094 .72624 m .53532 .76408 L .56293 .76648 L p .707 .577 .707 r
F P
0 g
s
.56293 .76648 m .56855 .72864 L .54094 .72624 L p .707 .577 .707 r
F P
0 g
s
.65406 .78103 m .65968 .74319 L .63097 .73755 L p .707 .577 .707 r
F P
0 g
s
.66219 .68019 m .6571 .7376 L .68085 .73867 L p .707 .577 .707 r
F P
0 g
s
.68085 .73867 m .68594 .68126 L .66219 .68019 L p .707 .577 .707 r
F P
0 g
s
.53764 .7267 m .54273 .66929 L .52152 .66626 L p .707 .577 .707 r
F P
0 g
s
.65968 .74319 m .65406 .78103 L .67726 .78674 L p .707 .577 .707 r
F P
0 g
s
.52152 .66626 m .51643 .72367 L .53764 .7267 L p .707 .577 .707 r
F P
0 g
s
.67726 .78674 m .68288 .7489 L .65968 .74319 L p .707 .577 .707 r
F P
0 g
s
.59666 .82766 m .59768 .80864 L .56653 .80603 L p .707 .577 .707 r
F P
0 g
s
.59768 .80864 m .59666 .82766 L .62844 .82893 L p .707 .577 .707 r
F P
0 g
s
.62844 .82893 m .62946 .80991 L .59768 .80864 L p .707 .577 .707 r
F P
0 g
s
.51945 .72558 m .51383 .76342 L .53532 .76408 L p .707 .577 .707 r
F P
0 g
s
.53532 .76408 m .54094 .72624 L .51945 .72558 L p .707 .577 .707 r
F P
0 g
s
.56653 .80603 m .5655 .82505 L .59666 .82766 L p .707 .577 .707 r
F P
0 g
s
.62946 .80991 m .62844 .82893 L .65773 .82874 L p .707 .577 .707 r
F P
0 g
s
.65773 .82874 m .65876 .80972 L .62946 .80991 L p .707 .577 .707 r
F P
0 g
s
.5655 .82505 m .56653 .80603 L .53905 .80234 L p .707 .577 .707 r
F P
0 g
s
.53905 .80234 m .53803 .82137 L .5655 .82505 L p .707 .577 .707 r
F P
0 g
s
.68594 .68126 m .68085 .73867 L .69688 .73875 L p .707 .577 .707 r
F P
0 g
s
.69688 .73875 m .70197 .68135 L .68594 .68126 L p .707 .577 .707 r
F P
0 g
s
.65876 .80972 m .65773 .82874 L .68167 .82711 L p .707 .577 .707 r
F P
0 g
s
.68167 .82711 m .6827 .80808 L .65876 .80972 L p .707 .577 .707 r
F P
0 g
s
.68288 .7489 m .67726 .78674 L .69268 .79197 L p .707 .577 .707 r
F P
0 g
s
.51643 .72367 m .52152 .66626 L .50869 .66372 L p .707 .577 .707 r
F P
0 g
s
.69268 .79197 m .6983 .75413 L .68288 .7489 L p .707 .577 .707 r
F P
0 g
s
.50869 .66372 m .5036 .72112 L .51643 .72367 L p .707 .577 .707 r
F P
0 g
s
.53803 .82137 m .53905 .80234 L .51794 .79794 L p .707 .577 .707 r
F P
0 g
s
.51794 .79794 m .51692 .81696 L .53803 .82137 L p .707 .577 .707 r
F P
0 g
s
.50618 .72671 m .50056 .76455 L .51383 .76342 L p .707 .577 .707 r
F P
0 g
s
.51383 .76342 m .51945 .72558 L .50618 .72671 L p .707 .577 .707 r
F P
0 g
s
.6827 .80808 m .68167 .82711 L .69792 .82419 L p .707 .577 .707 r
F P
0 g
s
.69792 .82419 m .69895 .80517 L .6827 .80808 L p .707 .577 .707 r
F P
0 g
s
.70197 .68135 m .69688 .73875 L .70363 .73784 L p .707 .577 .707 r
F P
0 g
s
.70363 .73784 m .70872 .68044 L .70197 .68135 L p .707 .577 .707 r
F P
0 g
s
.6983 .75413 m .69268 .79197 L .69882 .7962 L p .707 .577 .707 r
F P
0 g
s
.51692 .81696 m .51794 .79794 L .50526 .79324 L p .707 .577 .707 r
F P
0 g
s
.5036 .72112 m .50869 .66372 L .50549 .6619 L p .707 .577 .707 r
F P
0 g
s
.69882 .7962 m .70444 .75837 L .6983 .75413 L p .707 .577 .707 r
F P
0 g
s
.50526 .79324 m .50424 .81226 L .51692 .81696 L p .707 .577 .707 r
F P
0 g
s
.50549 .6619 m .5004 .7193 L .5036 .72112 L p .707 .577 .707 r
F P
0 g
s
.50243 .72954 m .49681 .76737 L .50056 .76455 L p .707 .577 .707 r
F P
0 g
s
.50056 .76455 m .50618 .72671 L .50243 .72954 L p .707 .577 .707 r
F P
0 g
s
.50857 .73377 m .50295 .77161 L .49681 .76737 L p .707 .577 .707 r
F P
0 g
s
.49681 .76737 m .50243 .72954 L .50857 .73377 L p .707 .577 .707 r
F P
0 g
s
.50093 .82507 m .48457 .33596 L .44057 .33385 L p .707 .577 .707 r
F P
0 g
s
.50424 .81226 m .50526 .79324 L .50226 .78872 L p .707 .577 .707 r
F P
0 g
s
.50226 .78872 m .50123 .80774 L .50424 .81226 L p .707 .577 .707 r
F P
0 g
s
.5004 .7193 m .50549 .6619 L .51224 .66099 L p .707 .577 .707 r
F P
0 g
s
.51224 .66099 m .50715 .71839 L .5004 .7193 L p .707 .577 .707 r
F P
0 g
s
.50123 .80774 m .50226 .78872 L .50922 .78481 L p .707 .577 .707 r
F P
0 g
s
.50922 .78481 m .50819 .80383 L .50123 .80774 L p .707 .577 .707 r
F P
0 g
s
.50715 .71839 m .51224 .66099 L .52827 .66107 L p .707 .577 .707 r
F P
0 g
s
.52827 .66107 m .52318 .71848 L .50715 .71839 L p .707 .577 .707 r
F P
0 g
s
.52399 .739 m .51837 .77684 L .50295 .77161 L p .707 .577 .707 r
F P
0 g
s
.50295 .77161 m .50857 .73377 L .52399 .739 L p .707 .577 .707 r
F P
0 g
s
.50819 .80383 m .50922 .78481 L .52546 .78189 L p .707 .577 .707 r
F P
0 g
s
.52318 .71848 m .52827 .66107 L .55202 .66214 L p .707 .577 .707 r
F P
0 g
s
.52546 .78189 m .52444 .80092 L .50819 .80383 L p .707 .577 .707 r
F P
0 g
s
.55202 .66214 m .54693 .71955 L .52318 .71848 L p .707 .577 .707 r
F P
0 g
s
.54719 .74471 m .54157 .78255 L .51837 .77684 L p .707 .577 .707 r
F P
0 g
s
.51837 .77684 m .52399 .739 L .54719 .74471 L p .707 .577 .707 r
F P
0 g
s
.5759 .75035 m .57028 .78819 L .54157 .78255 L p .707 .577 .707 r
F P
0 g
s
.54157 .78255 m .54719 .74471 L .5759 .75035 L p .707 .577 .707 r
F P
0 g
s
.52444 .80092 m .52546 .78189 L .54941 .78026 L p .707 .577 .707 r
F P
0 g
s
.54941 .78026 m .54838 .79929 L .52444 .80092 L p .707 .577 .707 r
F P
0 g
s
.48457 .33596 m .50093 .82507 L .54585 .82233 L p .707 .577 .707 r
F P
0 g
s
.54585 .82233 m .52948 .33321 L .48457 .33596 L p .707 .577 .707 r
F P
0 g
s
.54693 .71955 m .55202 .66214 L .58116 .6641 L p .707 .577 .707 r
F P
0 g
s
.58116 .6641 m .57607 .72151 L .54693 .71955 L p .707 .577 .707 r
F P
0 g
s
.57607 .72151 m .58116 .6641 L .61285 .66675 L p .707 .577 .707 r
F P
0 g
s
.61285 .66675 m .60775 .72416 L .57607 .72151 L p .707 .577 .707 r
F P
0 g
s
.6073 .75537 m .60168 .7932 L .57028 .78819 L p .707 .577 .707 r
F P
0 g
s
.57028 .78819 m .5759 .75035 L .6073 .75537 L p .707 .577 .707 r
F P
0 g
s
.54838 .79929 m .54941 .78026 L .5787 .78007 L p .707 .577 .707 r
F P
0 g
s
.5787 .78007 m .57768 .7991 L .54838 .79929 L p .707 .577 .707 r
F P
0 g
s
.60168 .7932 m .6073 .75537 L .63832 .75926 L p .707 .577 .707 r
F P
0 g
s
.57768 .7991 m .5787 .78007 L .61048 .78134 L p .707 .577 .707 r
F P
0 g
s
.63832 .75926 m .6327 .7971 L .60168 .7932 L p .707 .577 .707 r
F P
0 g
s
.61048 .78134 m .60946 .80037 L .57768 .7991 L p .707 .577 .707 r
F P
0 g
s
.52948 .33321 m .54585 .82233 L .58729 .81498 L p .707 .577 .707 r
F P
0 g
s
.58729 .81498 m .57092 .32587 L .52948 .33321 L p .707 .577 .707 r
F P
0 g
s
.69895 .80517 m .69792 .82419 L .70488 .82028 L p .707 .577 .707 r
F P
0 g
s
.70488 .82028 m .70591 .80126 L .69895 .80517 L p .707 .577 .707 r
F P
0 g
s
.45693 .82296 m .44057 .33385 L .4018 .32708 L p .707 .577 .707 r
F P
0 g
s
.44057 .33385 m .45693 .82296 L .50093 .82507 L p .707 .577 .707 r
F P
0 g
s
.70872 .68044 m .70363 .73784 L .70043 .73602 L p .707 .577 .707 r
F P
0 g
s
.70043 .73602 m .70552 .67862 L .70872 .68044 L p .707 .577 .707 r
F P
0 g
s
.64396 .66983 m .63887 .72724 L .6162 .72499 L p .707 .577 .707 r
F P
0 g
s
.6162 .72499 m .60775 .72416 L p .61677 .71063 L .707 .577 .707 r
F P
0 g
s
.61677 .71063 m .64396 .66983 L .6162 .72499 L .707 .577 .707 r
F
.67148 .67304 m .66638 .73045 L .63887 .72724 L p F P
0 g
s
.63887 .72724 m .64396 .66983 L .67148 .67304 L p .707 .577 .707 r
F P
0 g
s
.66593 .76166 m .66031 .7995 L .6327 .7971 L p .707 .577 .707 r
F P
0 g
s
.6327 .7971 m .63832 .75926 L .66593 .76166 L p .707 .577 .707 r
F P
0 g
s
.60775 .72416 m .61285 .66675 L .64396 .66983 L p .707 .577 .707 r
F P
0 g
s
.68742 .76232 m .6818 .80016 L .66031 .7995 L p .707 .577 .707 r
F P
0 g
s
.66031 .7995 m .66593 .76166 L .68742 .76232 L p .707 .577 .707 r
F P
0 g
s
.64061 .80297 m .64164 .78395 L .66911 .78763 L p .707 .577 .707 r
F P
0 g
s
.64424 .78977 m .65418 .77437 L p .63088 .3547 L .707 .577 .707 r
F P
0 g
s
.62788 .30066 m .63023 .37102 L p .63088 .3547 L .707 .577 .707 r
F P
0 g
s
.63023 .37102 m .64424 .78977 L p .63088 .3547 L .707 .577 .707 r
F P
0 g
s
.64164 .78395 m .64061 .80297 L .60946 .80037 L p .707 .577 .707 r
F P
0 g
s
.60946 .80037 m .61048 .78134 L .64164 .78395 L p .707 .577 .707 r
F P
0 g
s
.57092 .32587 m .58729 .81498 L .62119 .80377 L p .707 .577 .707 r
F P
0 g
s
.62119 .80377 m .60483 .31466 L .57092 .32587 L p .707 .577 .707 r
F P
0 g
s
.70444 .75837 m .69882 .7962 L .69507 .79903 L p .707 .577 .707 r
F P
0 g
s
.69507 .79903 m .70069 .76119 L .70444 .75837 L p .707 .577 .707 r
F P
0 g
s
.41816 .81619 m .4018 .32708 L .37204 .31632 L p .707 .577 .707 r
F P
0 g
s
.4018 .32708 m .41816 .81619 L .45693 .82296 L p .707 .577 .707 r
F P
0 g
s
.70591 .80126 m .70488 .82028 L .70188 .81576 L p .707 .577 .707 r
F P
0 g
s
.70188 .81576 m .7029 .79674 L .70591 .80126 L p .707 .577 .707 r
F P
0 g
s
.70552 .67862 m .70043 .73602 L .68759 .73348 L p .707 .577 .707 r
F P
0 g
s
.68759 .73348 m .69269 .67607 L .70552 .67862 L p .707 .577 .707 r
F P
0 g
s
.60483 .31466 m .62119 .80377 L .64424 .78977 L p .707 .577 .707 r
F P
0 g
s
.64424 .78977 m .62788 .30066 L .60483 .31466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25326 .69618 m .25836 .63877 L .22724 .63569 L p .707 .577 .707 r
F P
0 g
s
.25836 .63877 m .25326 .69618 L .28494 .69882 L p .707 .577 .707 r
F P
0 g
s
.28494 .69882 m .29004 .64142 L .25836 .63877 L p .707 .577 .707 r
F P
0 g
s
.70069 .76119 m .69507 .79903 L .6818 .80016 L p .707 .577 .707 r
F P
0 g
s
.22724 .63569 m .22214 .69309 L .25326 .69618 L p .707 .577 .707 r
F P
0 g
s
.29004 .64142 m .28494 .69882 L .31409 .70078 L p .707 .577 .707 r
F P
0 g
s
.31409 .70078 m .31918 .64338 L .29004 .64142 L p .707 .577 .707 r
F P
0 g
s
.22214 .69309 m .22724 .63569 L .19973 .63248 L p .707 .577 .707 r
F P
0 g
s
.6818 .80016 m .68742 .76232 L .70069 .76119 L p .707 .577 .707 r
F P
0 g
s
.22554 .69182 m .21992 .72966 L .25094 .73356 L p .707 .577 .707 r
F P
0 g
s
.25094 .73356 m .25656 .69572 L .22554 .69182 L p .707 .577 .707 r
F P
0 g
s
.25656 .69572 m .25094 .73356 L .28234 .73857 L p .707 .577 .707 r
F P
0 g
s
.19973 .63248 m .19463 .68988 L .22214 .69309 L p .707 .577 .707 r
F P
0 g
s
.28234 .73857 m .28796 .70073 L .25656 .69572 L p .707 .577 .707 r
F P
0 g
s
.28796 .70073 m .28234 .73857 L .31105 .74421 L p .707 .577 .707 r
F P
0 g
s
.19793 .68943 m .19231 .72726 L .21992 .72966 L p .707 .577 .707 r
F P
0 g
s
.21992 .72966 m .22554 .69182 L .19793 .68943 L p .707 .577 .707 r
F P
0 g
s
.38841 .80543 m .37204 .31632 L .35422 .30261 L p .707 .577 .707 r
F P
0 g
s
.37204 .31632 m .38841 .80543 L .41816 .81619 L p .707 .577 .707 r
F P
0 g
s
.31105 .74421 m .31667 .70637 L .28796 .70073 L p .707 .577 .707 r
F P
0 g
s
.31918 .64338 m .31409 .70078 L .33784 .70185 L p .707 .577 .707 r
F P
0 g
s
.33784 .70185 m .34293 .64445 L .31918 .64338 L p .707 .577 .707 r
F P
0 g
s
.7029 .79674 m .70188 .81576 L .6892 .81106 L p .707 .577 .707 r
F P
0 g
s
.6892 .81106 m .69022 .79204 L .7029 .79674 L p .707 .577 .707 r
F P
0 g
s
.19463 .68988 m .19973 .63248 L .17852 .62945 L p .707 .577 .707 r
F P
0 g
s
.31667 .70637 m .31105 .74421 L .33425 .74992 L p .707 .577 .707 r
F P
0 g
s
.69269 .67607 m .68759 .73348 L .66638 .73045 L p .707 .577 .707 r
F P
0 g
s
.66638 .73045 m .67148 .67304 L .69269 .67607 L p .707 .577 .707 r
F P
0 g
s
.17852 .62945 m .17342 .68685 L .19463 .68988 L p .707 .577 .707 r
F P
0 g
s
.33425 .74992 m .33987 .71209 L .31667 .70637 L p .707 .577 .707 r
F P
0 g
s
.25365 .79084 m .25468 .77182 L .22352 .76921 L p .707 .577 .707 r
F P
0 g
s
.25468 .77182 m .25365 .79084 L .28543 .79211 L p .707 .577 .707 r
F P
0 g
s
.28543 .79211 m .28645 .77309 L .25468 .77182 L p .707 .577 .707 r
F P
0 g
s
.17644 .68876 m .17082 .7266 L .19231 .72726 L p .707 .577 .707 r
F P
0 g
s
.19231 .72726 m .19793 .68943 L .17644 .68876 L p .707 .577 .707 r
F P
0 g
s
.22352 .76921 m .2225 .78824 L .25365 .79084 L p .707 .577 .707 r
F P
0 g
s
.28645 .77309 m .28543 .79211 L .31472 .79192 L p .707 .577 .707 r
F P
0 g
s
.31472 .79192 m .31575 .7729 L .28645 .77309 L p .707 .577 .707 r
F P
0 g
s
.65418 .77437 m .63782 .28526 L .62788 .30066 L p .707 .577 .707 r
F P
0 g
s
.2225 .78824 m .22352 .76921 L .19604 .76553 L p .707 .577 .707 r
F P
0 g
s
.19604 .76553 m .19502 .78455 L .2225 .78824 L p .707 .577 .707 r
F P
0 g
s
.34293 .64445 m .33784 .70185 L .35387 .70194 L p .707 .577 .707 r
F P
0 g
s
.35387 .70194 m .35896 .64453 L .34293 .64445 L p .707 .577 .707 r
F P
0 g
s
.31575 .7729 m .31472 .79192 L .33867 .79029 L p .707 .577 .707 r
F P
0 g
s
.33867 .79029 m .33969 .77127 L .31575 .7729 L p .707 .577 .707 r
F P
0 g
s
.33987 .71209 m .33425 .74992 L .34967 .75515 L p .707 .577 .707 r
F P
0 g
s
.17342 .68685 m .17852 .62945 L .16568 .6269 L p .707 .577 .707 r
F P
0 g
s
.34967 .75515 m .35529 .71732 L .33987 .71209 L p .707 .577 .707 r
F P
0 g
s
.16568 .6269 m .16059 .68431 L .17342 .68685 L p .707 .577 .707 r
F P
0 g
s
.19502 .78455 m .19604 .76553 L .17493 .76112 L p .707 .577 .707 r
F P
0 g
s
.69022 .79204 m .6892 .81106 L .66809 .80666 L p .707 .577 .707 r
F P
0 g
s
.66809 .80666 m .66911 .78763 L .69022 .79204 L p .707 .577 .707 r
F P
0 g
s
.17493 .76112 m .17391 .78014 L .19502 .78455 L p .707 .577 .707 r
F P
0 g
s
.36062 .70103 m .36571 .64362 L .35896 .64453 L p .707 .577 .707 r
F P
0 g
s
.35896 .64453 m .35387 .70194 L .36062 .70103 L p .707 .577 .707 r
F P
0 g
s
.36571 .64362 m .36062 .70103 L .35742 .69921 L p .707 .577 .707 r
F P
0 g
s
.35742 .69921 m .36251 .6418 L .36571 .64362 L p .707 .577 .707 r
F P
0 g
s
.37059 .79173 m .35422 .30261 L .35008 .28731 L p .707 .577 .707 r
F P
0 g
s
.35422 .30261 m .37059 .79173 L .38841 .80543 L p .707 .577 .707 r
F P
0 g
s
.16317 .6899 m .15755 .72774 L .17082 .7266 L p .707 .577 .707 r
F P
0 g
s
.17082 .7266 m .17644 .68876 L .16317 .6899 L p .707 .577 .707 r
F P
0 g
s
.33969 .77127 m .33867 .79029 L .35491 .78738 L p .707 .577 .707 r
F P
0 g
s
.35491 .78738 m .35594 .76836 L .33969 .77127 L p .707 .577 .707 r
F P
0 g
s
.35529 .71732 m .34967 .75515 L .35581 .75939 L p .707 .577 .707 r
F P
0 g
s
.17391 .78014 m .17493 .76112 L .16225 .75643 L p .707 .577 .707 r
F P
0 g
s
.63782 .28526 m .65222 .71586 L p .64755 .66239 L .707 .577 .707 r
F P
0 g
s
.63367 .26996 m .63782 .28526 L p .64799 .67951 L .707 .577 .707 r
F P
0 g
s
.63777 .67778 m .64769 .67693 L p .64711 .6719 L .707 .577 .707 r
F P
0 g
s
.63367 .26996 m .64618 .64373 L p .63246 .6667 L .707 .577 .707 r
F P
0 g
s
.64618 .64373 m .64712 .6719 L p .63906 .66904 L .707 .577 .707 r
F P
0 g
s
.63246 .6667 m .64618 .64373 L .63906 .66904 L .707 .577 .707 r
F
.65004 .75907 m .63222 .74537 L p .63225 .735 L F P
0 g
s
.63225 .735 m .63246 .6667 L .64334 .72388 L .707 .577 .707 r
F
.63225 .735 m .64334 .72388 L .64145 .74033 L F
.64144 .74048 m .64145 .74033 L p .64144 .74043 L F P
0 g
s
.64145 .74033 m .64144 .74048 L .64217 .74075 L p .707 .577 .707 r
F P
0 g
s
.64074 .74649 m .6471 .7436 L .65004 .75907 L .707 .577 .707 r
F
.63225 .735 m .64145 .74033 L .64074 .74649 L F
.64143 .74046 m .64144 .74048 L p .64144 .74043 L F P
0 g
s
.64145 .74033 m .6471 .7436 L .64074 .74649 L .707 .577 .707 r
F
.63946 .71693 m .63843 .73595 L .64143 .74046 L p F P
0 g
s
.64144 .74043 m .63946 .71693 L .64143 .74046 L .707 .577 .707 r
F
.64247 .72145 m .63946 .71693 L p .64144 .74043 L F P
0 g
s
.64145 .74033 m .64247 .72145 L p .64144 .74043 L .707 .577 .707 r
F P
0 g
s
.64145 .74033 m .64334 .72388 L .6471 .7436 L .707 .577 .707 r
F
.6363 .67888 m .63777 .67778 L p .63804 .67269 L F P
0 g
s
.63906 .66904 m .63777 .67778 L p .64711 .6719 L .707 .577 .707 r
F P
0 g
s
.64362 .64108 m .64338 .63994 L .64769 .67693 L .707 .577 .707 r
F
.64712 .6719 m .65004 .75907 L p .63539 .6821 L F P
0 g
s
.63246 .6667 m .63906 .66904 L .63539 .6821 L .707 .577 .707 r
F
.63777 .67778 m .63906 .66904 L p .63804 .67269 L F P
0 g
s
.63906 .66904 m .64712 .6719 L .63539 .6821 L .707 .577 .707 r
F
.64338 .63994 m .63964 .64276 L p .63804 .67269 L F P
0 g
s
.63906 .66904 m .64338 .63994 L p .63804 .67269 L .707 .577 .707 r
F P
0 g
s
.64974 .74733 m .64712 .6719 L .64799 .67951 L .707 .577 .707 r
F
.65004 .75907 m .64957 .74503 L p .64974 .74733 L F P
0 g
s
.64957 .74503 m .64712 .6719 L p .64974 .74733 L .707 .577 .707 r
F P
0 g
s
.64247 .72145 m .64145 .74033 L p .64945 .74339 L .707 .577 .707 r
F P
0 g
s
.65418 .77437 m .65079 .76185 L p .64755 .66239 L .707 .577 .707 r
F P
0 g
s
.65079 .76185 m .65004 .75907 L p .64974 .74733 L .707 .577 .707 r
F P
0 g
s
.64974 .74733 m .64755 .66239 L .65079 .76185 L .707 .577 .707 r
F
.64217 .74075 m .64945 .74344 L p .64145 .74033 L F P
0 g
s
.65222 .71586 m .65418 .77437 L p .64755 .66239 L .707 .577 .707 r
F P
0 g
s
.64945 .74344 m .65412 .74517 L p .64945 .74339 L .707 .577 .707 r
F P
0 g
s
.64945 .74339 m .64145 .74033 L .64945 .74344 L .707 .577 .707 r
F
.65412 .74517 m .64879 .73433 L .64945 .74339 L F
.64879 .73433 m .64247 .72145 L .64945 .74339 L F
.63964 .64276 m .63402 .6806 L .6363 .67888 L p F P
0 g
s
.63804 .67269 m .63964 .64276 L .6363 .67888 L .707 .577 .707 r
F
.64338 .63994 m .63906 .66904 L p .64711 .6719 L F P
0 g
s
.64712 .6719 m .63367 .26996 L p .64799 .67951 L .707 .577 .707 r
F P
0 g
s
.64769 .67693 m .65103 .67664 L p .64362 .64108 L .707 .577 .707 r
F P
0 g
s
.6459 .55841 m .64215 .60068 L p .65364 .61837 L .707 .577 .707 r
F P
0 g
s
.64215 .60068 m .6408 .61582 L .64352 .61636 L p .707 .577 .707 r
F P
0 g
s
.64352 .61636 m .65364 .61837 L p .64215 .60068 L .707 .577 .707 r
F P
0 g
s
.66911 .78763 m .66809 .80666 L .64061 .80297 L p .707 .577 .707 r
F P
0 g
s
.16059 .68431 m .16568 .6269 L .16248 .62508 L p .707 .577 .707 r
F P
0 g
s
.35581 .75939 m .36143 .72155 L .35529 .71732 L p .707 .577 .707 r
F P
0 g
s
.16225 .75643 m .16123 .77545 L .17391 .78014 L p .707 .577 .707 r
F P
0 g
s
.16248 .62508 m .15739 .68249 L .16059 .68431 L p .707 .577 .707 r
F P
0 g
s
.15942 .69272 m .1538 .73056 L .15755 .72774 L p .707 .577 .707 r
F P
0 g
s
.15755 .72774 m .16317 .6899 L .15942 .69272 L p .707 .577 .707 r
F P
0 g
s
.35594 .76836 m .35491 .78738 L .36187 .78347 L p .707 .577 .707 r
F P
0 g
s
.36187 .78347 m .3629 .76445 L .35594 .76836 L p .707 .577 .707 r
F P
0 g
s
.36251 .6418 m .35742 .69921 L .34476 .6967 L p .707 .577 .707 r
F P
0 g
s
.34476 .6967 m .34458 .69666 L p .3448 .696 L .707 .577 .707 r
F P
0 g
s
.3448 .696 m .36251 .6418 L .34476 .6967 L .707 .577 .707 r
F
.35008 .28731 m .36002 .27191 L p .36151 .38894 L F P
0 g
s
.36484 .65034 m .36645 .77643 L .37059 .79173 L p .707 .577 .707 r
F P
0 g
s
.35654 .48032 m .35733 .46571 L p .35008 .28731 L .707 .577 .707 r
F P
0 g
s
.34458 .69666 m .34968 .63925 L .36251 .6418 L p .707 .577 .707 r
F P
0 g
s
.36645 .77643 m .35654 .48032 L p .36151 .38894 L .707 .577 .707 r
F P
0 g
s
.35654 .48032 m .35008 .28731 L p .36151 .38894 L .707 .577 .707 r
F P
0 g
s
.16123 .77545 m .16225 .75643 L .15925 .7519 L p .707 .577 .707 r
F P
0 g
s
.36143 .72155 m .35581 .75939 L .35206 .76221 L p .707 .577 .707 r
F P
0 g
s
.15925 .7519 m .15822 .77093 L .16123 .77545 L p .707 .577 .707 r
F P
0 g
s
.35206 .76221 m .35768 .72437 L .36143 .72155 L p .707 .577 .707 r
F P
0 g
s
.15739 .68249 m .16248 .62508 L .16923 .62417 L p .707 .577 .707 r
F P
0 g
s
.16923 .62417 m .16414 .68158 L .15739 .68249 L p .707 .577 .707 r
F P
0 g
s
.16556 .69695 m .15994 .73479 L .1538 .73056 L p .707 .577 .707 r
F P
0 g
s
.1538 .73056 m .15942 .69272 L .16556 .69695 L p .707 .577 .707 r
F P
0 g
s
.63222 .74537 m .61585 .25626 L .63367 .26996 L p .707 .577 .707 r
F P
0 g
s
.3629 .76445 m .36187 .78347 L .35887 .77894 L p .707 .577 .707 r
F P
0 g
s
.35887 .77894 m .35989 .75992 L .3629 .76445 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15822 .77093 m .15925 .7519 L .16621 .74799 L p .707 .577 .707 r
F P
0 g
s
.35768 .72437 m .35206 .76221 L .33879 .76335 L p .707 .577 .707 r
F P
0 g
s
.37639 .76102 m .36002 .27191 L .38307 .25792 L p .707 .577 .707 r
F P
0 g
s
.36002 .27191 m .37639 .76102 L .36645 .77643 L p .707 .577 .707 r
F P
0 g
s
.16621 .74799 m .16518 .76702 L .15822 .77093 L p .707 .577 .707 r
F P
0 g
s
.16414 .68158 m .16923 .62417 L .18526 .62425 L p .707 .577 .707 r
F P
0 g
s
.33879 .76335 m .34441 .72551 L .35768 .72437 L p .707 .577 .707 r
F P
0 g
s
.18526 .62425 m .18017 .68166 L .16414 .68158 L p .707 .577 .707 r
F P
0 g
s
.18098 .70218 m .17536 .74002 L .15994 .73479 L p .707 .577 .707 r
F P
0 g
s
.15994 .73479 m .16556 .69695 L .18098 .70218 L p .707 .577 .707 r
F P
0 g
s
.35989 .75992 m .35887 .77894 L .34619 .77425 L p .707 .577 .707 r
F P
0 g
s
.34619 .77425 m .34721 .75523 L .35989 .75992 L p .707 .577 .707 r
F P
0 g
s
.61585 .25626 m .63222 .74537 L .60247 .73461 L p .707 .577 .707 r
F P
0 g
s
.60247 .73461 m .5861 .2455 L .61585 .25626 L p .707 .577 .707 r
F P
0 g
s
.34968 .63925 m .34458 .69666 L .32337 .69363 L p .707 .577 .707 r
F P
0 g
s
.32337 .69363 m .32847 .63623 L .34968 .63925 L p .707 .577 .707 r
F P
0 g
s
.34441 .72551 m .33879 .76335 L .3173 .76268 L p .707 .577 .707 r
F P
0 g
s
.16518 .76702 m .16621 .74799 L .18246 .74508 L p .707 .577 .707 r
F P
0 g
s
.18017 .68166 m .18526 .62425 L .20901 .62533 L p .707 .577 .707 r
F P
0 g
s
.18246 .74508 m .18143 .7641 L .16518 .76702 L p .707 .577 .707 r
F P
0 g
s
.3173 .76268 m .32292 .72484 L .34441 .72551 L p .707 .577 .707 r
F P
0 g
s
.20901 .62533 m .20392 .68273 L .18017 .68166 L p .707 .577 .707 r
F P
0 g
s
.20418 .7079 m .19856 .74574 L .17536 .74002 L p .707 .577 .707 r
F P
0 g
s
.17536 .74002 m .18098 .70218 L .20418 .7079 L p .707 .577 .707 r
F P
0 g
s
.38307 .25792 m .39808 .7066 L p .37639 .76102 L .707 .577 .707 r
F P
0 g
s
.39944 .74703 m .38307 .25792 L .41697 .2467 L p .707 .577 .707 r
F P
0 g
s
.39944 .74703 m .40178 .68007 L .42999 .7299 L .707 .577 .707 r
F
.42965 .62542 m .43042 .64864 L p .40178 .68007 L F P
0 g
s
.42677 .65322 m .44825 .65744 L p .44361 .64869 L .707 .577 .707 r
F P
0 g
s
.41697 .2467 m .45841 .23936 L p .43774 .64867 L .707 .577 .707 r
F P
0 g
s
.43042 .64864 m .41697 .2467 L p .43774 .64867 L .707 .577 .707 r
F P
0 g
s
.44361 .64869 m .43042 .64864 L .42677 .65322 L .707 .577 .707 r
F
.45193 .71999 m .43774 .64867 L .47005 .71829 L F
.43405 .72166 m .43627 .67786 L .45193 .71999 L F
.43627 .67786 m .43774 .64867 L .45193 .71999 L F
.45193 .71999 m .45193 .72014 L .45199 .72013 L p F P
0 g
s
.45024 .72015 m .45193 .72014 L p .45173 .72001 L .707 .577 .707 r
F P
0 g
s
.43405 .72166 m .43042 .64864 L .43774 .64867 L .707 .577 .707 r
F
.43287 .72178 m .43042 .64864 L p .43405 .72166 L F P
0 g
s
.43042 .64864 m .43287 .72178 L p .40326 .68268 L .707 .577 .707 r
F P
0 g
s
.43287 .72178 m .43334 .73581 L p .42999 .7299 L .707 .577 .707 r
F P
0 g
s
.40326 .68268 m .43287 .72178 L .42999 .7299 L .707 .577 .707 r
F
.45295 .70111 m .44016 .70119 L p .45173 .72001 L F P
0 g
s
.44016 .70119 m .42366 .7013 L p .43698 .71018 L .707 .577 .707 r
F P
0 g
s
.45173 .72001 m .44016 .70119 L .43698 .71018 L .707 .577 .707 r
F
.45193 .72014 m .45193 .71999 L p .45173 .72001 L F P
0 g
s
.45193 .71999 m .45295 .70111 L p .45173 .72001 L .707 .577 .707 r
F P
0 g
s
.43334 .73581 m .43287 .72178 L p .43405 .72166 L .707 .577 .707 r
F P
0 g
s
.43405 .72166 m .47005 .71829 L .47478 .72847 L .707 .577 .707 r
F
.45841 .23936 m .47211 .64878 L p .44955 .6487 L F P
0 g
s
.43774 .64867 m .43852 .63319 L .44955 .6487 L .707 .577 .707 r
F
.43852 .63319 m .45841 .23936 L .44955 .6487 L F
.44955 .6487 m .44825 .65744 L .45735 .65968 L p F P
0 g
s
.41697 .2467 m .42965 .62542 L p .40178 .68007 L .707 .577 .707 r
F P
0 g
s
.45387 .6196 m .42517 .61396 L p .44361 .64869 L .707 .577 .707 r
F P
0 g
s
.44825 .65744 m .44955 .6487 L p .44361 .64869 L .707 .577 .707 r
F P
0 g
s
.44955 .6487 m .45387 .6196 L p .44361 .64869 L .707 .577 .707 r
F P
0 g
s
.43774 .64867 m .44955 .6487 L .47478 .72847 L .707 .577 .707 r
F
.47211 .64878 m .47322 .682 L p .44955 .6487 L F P
0 g
s
.47322 .682 m .47478 .72847 L p .44955 .6487 L .707 .577 .707 r
F P
0 g
s
.45387 .6196 m .44955 .6487 L p .47145 .66315 L .707 .577 .707 r
F P
0 g
s
.45735 .65968 m .47145 .66315 L p .44955 .6487 L .707 .577 .707 r
F P
0 g
s
.47478 .72847 m .45841 .23936 L .50333 .23661 L p .707 .577 .707 r
F P
0 g
s
.50333 .23661 m .51969 .72572 L .47478 .72847 L p .707 .577 .707 r
F P
0 g
s
.45295 .70111 m .45193 .71999 L p .47587 .7185 L .707 .577 .707 r
F P
0 g
s
.45199 .72013 m .47587 .7185 L p .45193 .71999 L .707 .577 .707 r
F P
0 g
s
.43341 .72026 m .45024 .72015 L p .43698 .71018 L .707 .577 .707 r
F P
0 g
s
.45173 .72001 m .43698 .71018 L .45024 .72015 L .707 .577 .707 r
F
.47478 .72847 m .43334 .73581 L p .43405 .72166 L F P
0 g
s
.43833 .63874 m .42517 .61396 L .42658 .64863 L .707 .577 .707 r
F
.40178 .68007 m .43042 .64864 L .40326 .68268 L F
.43042 .64864 m .42658 .64863 L .42677 .65322 L F
.43833 .63874 m .42658 .64863 L .43042 .64864 L F
.44361 .64869 m .43833 .63874 L .43042 .64864 L F
.42517 .61396 m .41955 .6518 L .42677 .65322 L p F P
0 g
s
.42366 .7013 m .42263 .72033 L .43341 .72026 L p .707 .577 .707 r
F P
0 g
s
.43698 .71018 m .42366 .7013 L .43341 .72026 L .707 .577 .707 r
F
.43334 .73581 m .42718 .73785 L p .42999 .7299 L F P
0 g
s
.42718 .73785 m .39944 .74703 L p .42999 .7299 L .707 .577 .707 r
F P
0 g
s
.42724 .53611 m .42215 .59352 L .44513 .59506 L p .707 .577 .707 r
F P
0 g
s
.44513 .59506 m .45129 .59548 L p .44847 .58851 L .707 .577 .707 r
F P
0 g
s
.44847 .58851 m .42724 .53611 L .44513 .59506 L .707 .577 .707 r
F
.39556 .53347 m .39047 .59087 L .4152 .59294 L p F P
0 g
s
.4152 .59294 m .42215 .59352 L p .4169 .58167 L .707 .577 .707 r
F P
0 g
s
.4169 .58167 m .39556 .53347 L .4152 .59294 L .707 .577 .707 r
F
.39808 .7066 m .39944 .74703 L .39124 .752 L p F P
0 g
s
.39124 .752 m .37639 .76102 L p .39808 .7066 L .707 .577 .707 r
F P
0 g
s
.32847 .63623 m .32337 .69363 L .29586 .69042 L p .707 .577 .707 r
F P
0 g
s
.29586 .69042 m .30095 .63301 L .32847 .63623 L p .707 .577 .707 r
F P
0 g
s
.34721 .75523 m .34619 .77425 L .32508 .76984 L p .707 .577 .707 r
F P
0 g
s
.32508 .76984 m .3261 .75082 L .34721 .75523 L p .707 .577 .707 r
F P
0 g
s
.32292 .72484 m .3173 .76268 L .28969 .76028 L p .707 .577 .707 r
F P
0 g
s
.20392 .68273 m .20901 .62533 L .23815 .62729 L p .707 .577 .707 r
F P
0 g
s
.5861 .2455 m .60247 .73461 L .56369 .72784 L p .707 .577 .707 r
F P
0 g
s
.56369 .72784 m .54733 .23873 L .5861 .2455 L p .707 .577 .707 r
F P
0 g
s
.23815 .62729 m .23306 .68469 L .20392 .68273 L p .707 .577 .707 r
F P
0 g
s
.28969 .76028 m .29531 .72245 L .32292 .72484 L p .707 .577 .707 r
F P
0 g
s
.23289 .71354 m .22727 .75138 L .19856 .74574 L p .707 .577 .707 r
F P
0 g
s
.19856 .74574 m .20418 .7079 L .23289 .71354 L p .707 .577 .707 r
F P
0 g
s
.18143 .7641 m .18246 .74508 L .2064 .74345 L p .707 .577 .707 r
F P
0 g
s
.73348 .62769 m .73857 .57028 L .70745 .5672 L p .707 .577 .707 r
F P
0 g
s
.73857 .57028 m .73348 .62769 L .76516 .63034 L p .707 .577 .707 r
F P
0 g
s
.76516 .63034 m .77025 .57293 L .73857 .57028 L p .707 .577 .707 r
F P
0 g
s
.2064 .74345 m .20537 .76247 L .18143 .7641 L p .707 .577 .707 r
F P
0 g
s
.30095 .63301 m .29586 .69042 L .26474 .68734 L p .707 .577 .707 r
F P
0 g
s
.26474 .68734 m .26984 .62993 L .30095 .63301 L p .707 .577 .707 r
F P
0 g
s
.70745 .5672 m .70236 .62461 L .73348 .62769 L p .707 .577 .707 r
F P
0 g
s
.77025 .57293 m .76516 .63034 L .7943 .63229 L p .707 .577 .707 r
F P
0 g
s
.7943 .63229 m .79939 .57489 L .77025 .57293 L p .707 .577 .707 r
F P
0 g
s
.23306 .68469 m .23815 .62729 L .26984 .62993 L p .707 .577 .707 r
F P
0 g
s
.70236 .62461 m .70745 .5672 L .67994 .56399 L p .707 .577 .707 r
F P
0 g
s
.26984 .62993 m .26474 .68734 L .23306 .68469 L p .707 .577 .707 r
F P
0 g
s
.29531 .72245 m .28969 .76028 L .25867 .75639 L p .707 .577 .707 r
F P
0 g
s
.67994 .56399 m .67485 .62139 L .70236 .62461 L p .707 .577 .707 r
F P
0 g
s
.26429 .71855 m .25867 .75639 L .22727 .75138 L p .707 .577 .707 r
F P
0 g
s
.22727 .75138 m .23289 .71354 L .26429 .71855 L p .707 .577 .707 r
F P
0 g
s
.70575 .64187 m .70013 .6797 L .73116 .6836 L p .707 .577 .707 r
F P
0 g
s
.73116 .6836 m .73677 .64576 L .70575 .64187 L p .707 .577 .707 r
F P
0 g
s
.73677 .64576 m .73116 .6836 L .76256 .68861 L p .707 .577 .707 r
F P
0 g
s
.3261 .75082 m .32508 .76984 L .2976 .76616 L p .707 .577 .707 r
F P
0 g
s
.2976 .76616 m .29863 .74713 L .3261 .75082 L p .707 .577 .707 r
F P
0 g
s
.25867 .75639 m .26429 .71855 L .29531 .72245 L p .707 .577 .707 r
F P
0 g
s
.76256 .68861 m .76818 .65077 L .73677 .64576 L p .707 .577 .707 r
F P
0 g
s
.76818 .65077 m .76256 .68861 L .79126 .69425 L p .707 .577 .707 r
F P
0 g
s
.54733 .23873 m .56369 .72784 L .51969 .72572 L p .707 .577 .707 r
F P
0 g
s
.51969 .72572 m .50333 .23661 L .54733 .23873 L p .707 .577 .707 r
F P
0 g
s
.79939 .57489 m .7943 .63229 L .81805 .63337 L p .707 .577 .707 r
F P
0 g
s
.81805 .63337 m .82314 .57596 L .79939 .57489 L p .707 .577 .707 r
F P
0 g
s
.67814 .63947 m .67252 .67731 L .70013 .6797 L p .707 .577 .707 r
F P
0 g
s
.70013 .6797 m .70575 .64187 L .67814 .63947 L p .707 .577 .707 r
F P
0 g
s
.20537 .76247 m .2064 .74345 L .23569 .74326 L p .707 .577 .707 r
F P
0 g
s
.79126 .69425 m .79688 .65641 L .76818 .65077 L p .707 .577 .707 r
F P
0 g
s
.23569 .74326 m .23467 .76228 L .20537 .76247 L p .707 .577 .707 r
F P
0 g
s
.67485 .62139 m .67994 .56399 L .65873 .56096 L p .707 .577 .707 r
F P
0 g
s
.65873 .56096 m .65364 .61837 L .67485 .62139 L p .707 .577 .707 r
F P
0 g
s
.29863 .74713 m .2976 .76616 L .26645 .76355 L p .707 .577 .707 r
F P
0 g
s
.26645 .76355 m .26747 .74453 L .29863 .74713 L p .707 .577 .707 r
F P
0 g
s
.79688 .65641 m .79126 .69425 L .81446 .69997 L p .707 .577 .707 r
F P
0 g
s
.23467 .76228 m .23569 .74326 L .26747 .74453 L p .707 .577 .707 r
F P
0 g
s
.81446 .69997 m .82008 .66213 L .79688 .65641 L p .707 .577 .707 r
F P
0 g
s
.26747 .74453 m .26645 .76355 L .23467 .76228 L p .707 .577 .707 r
F P
0 g
s
.65665 .6388 m .65103 .67664 L .67252 .67731 L p .707 .577 .707 r
F P
0 g
s
.67252 .67731 m .67814 .63947 L .65665 .6388 L p .707 .577 .707 r
F P
0 g
s
.73386 .75587 m .73489 .73685 L .70374 .73424 L p .707 .577 .707 r
F P
0 g
s
.73489 .73685 m .73386 .75587 L .76564 .75714 L p .707 .577 .707 r
F P
0 g
s
.76564 .75714 m .76667 .73812 L .73489 .73685 L p .707 .577 .707 r
F P
0 g
s
.82314 .57596 m .81805 .63337 L .83408 .63345 L p .707 .577 .707 r
F P
0 g
s
.83408 .63345 m .83918 .57605 L .82314 .57596 L p .707 .577 .707 r
F P
0 g
s
.70374 .73424 m .70271 .75327 L .73386 .75587 L p .707 .577 .707 r
F P
0 g
s
.76667 .73812 m .76564 .75714 L .79494 .75695 L p .707 .577 .707 r
F P
0 g
s
.79494 .75695 m .79596 .73793 L .76667 .73812 L p .707 .577 .707 r
F P
0 g
s
.70271 .75327 m .70374 .73424 L .67626 .73055 L p .707 .577 .707 r
F P
0 g
s
.67626 .73055 m .67523 .74958 L .70271 .75327 L p .707 .577 .707 r
F P
0 g
s
.65364 .61837 m .65873 .56096 L .6459 .55841 L p .707 .577 .707 r
F P
0 g
s
.82008 .66213 m .81446 .69997 L .82989 .7052 L p .707 .577 .707 r
F P
0 g
s
.79596 .73793 m .79494 .75695 L .81888 .75532 L p .707 .577 .707 r
F P
0 g
s
.81888 .75532 m .81991 .7363 L .79596 .73793 L p .707 .577 .707 r
F P
0 g
s
.82989 .7052 m .83551 .66736 L .82008 .66213 L p .707 .577 .707 r
F P
0 g
s
.65103 .67664 m .65665 .6388 L .64338 .63994 L p .707 .577 .707 r
F P
0 g
s
.67523 .74958 m .67626 .73055 L .65515 .72615 L p .707 .577 .707 r
F P
0 g
s
.65515 .72615 m .65412 .74517 L .67523 .74958 L p .707 .577 .707 r
F P
0 g
s
.83918 .57605 m .83408 .63345 L .84083 .63254 L p .707 .577 .707 r
F P
0 g
s
.84083 .63254 m .84592 .57513 L .83918 .57605 L p .707 .577 .707 r
F P
0 g
s
.81991 .7363 m .81888 .75532 L .83513 .75241 L p .707 .577 .707 r
F P
0 g
s
.83513 .75241 m .83615 .73338 L .81991 .7363 L p .707 .577 .707 r
F P
0 g
s
.6408 .61582 m .6459 .55841 L .6427 .55659 L p .707 .577 .707 r
F P
0 g
s
.83551 .66736 m .82989 .7052 L .83602 .70943 L p .707 .577 .707 r
F P
0 g
s
.6427 .55659 m .6376 .614 L .6408 .61582 L p .707 .577 .707 r
F P
0 g
s
.83602 .70943 m .84164 .67159 L .83551 .66736 L p .707 .577 .707 r
F P
0 g
s
.65412 .74517 m .65515 .72615 L .64247 .72145 L p .707 .577 .707 r
F P
0 g
s
.84592 .57513 m .84083 .63254 L .83763 .63072 L p .707 .577 .707 r
F P
0 g
s
.83763 .63072 m .84272 .57331 L .84592 .57513 L p .707 .577 .707 r
F P
0 g
s
.83615 .73338 m .83513 .75241 L .84209 .7485 L p .707 .577 .707 r
F P
0 g
s
.84209 .7485 m .84311 .72947 L .83615 .73338 L p .707 .577 .707 r
F P
0 g
s
.6376 .614 m .6427 .55659 L .64944 .55568 L p .707 .577 .707 r
F P
0 g
s
.84164 .67159 m .83602 .70943 L .83228 .71225 L p .707 .577 .707 r
F P
0 g
s
.64944 .55568 m .64435 .61309 L .6376 .614 L p .707 .577 .707 r
F P
0 g
s
.83228 .71225 m .83789 .67441 L .84164 .67159 L p .707 .577 .707 r
F P
0 g
s
.64577 .647 m .64015 .68483 L .63402 .6806 L p .707 .577 .707 r
F P
0 g
s
.63402 .6806 m .63964 .64276 L .64577 .647 L p .707 .577 .707 r
F P
0 g
s
.84272 .57331 m .83763 .63072 L .8248 .62817 L p .707 .577 .707 r
F P
0 g
s
.8248 .62817 m .82989 .57077 L .84272 .57331 L p .707 .577 .707 r
F P
0 g
s
.39047 .59087 m .39556 .53347 L .36444 .53038 L p .707 .577 .707 r
F P
0 g
s
.42215 .59352 m .42724 .53611 L .39556 .53347 L p .707 .577 .707 r
F P
0 g
s
.84311 .72947 m .84209 .7485 L .83908 .74397 L p .707 .577 .707 r
F P
0 g
s
.83908 .74397 m .84011 .72495 L .84311 .72947 L p .707 .577 .707 r
F P
0 g
s
.36444 .53038 m .35935 .58779 L .39047 .59087 L p .707 .577 .707 r
F P
0 g
s
.45129 .59548 m .45638 .53807 L .42724 .53611 L p .707 .577 .707 r
F P
0 g
s
.64435 .61309 m .64944 .55568 L .66548 .55577 L p .707 .577 .707 r
F P
0 g
s
.35935 .58779 m .36444 .53038 L .33693 .52717 L p .707 .577 .707 r
F P
0 g
s
.83789 .67441 m .83228 .71225 L .81901 .71339 L p .707 .577 .707 r
F P
0 g
s
.66548 .55577 m .66038 .61317 L .64435 .61309 L p .707 .577 .707 r
F P
0 g
s
.33693 .52717 m .33184 .58458 L .35935 .58779 L p .707 .577 .707 r
F P
0 g
s
.63843 .73595 m .63946 .71693 L .64642 .71302 L p .707 .577 .707 r
F P
0 g
s
.81901 .71339 m .82463 .67555 L .83789 .67441 L p .707 .577 .707 r
F P
0 g
s
.36274 .60505 m .35712 .64289 L .38815 .64678 L p .707 .577 .707 r
F P
0 g
s
.38815 .64678 m .39376 .60895 L .36274 .60505 L p .707 .577 .707 r
F P
0 g
s
.39376 .60895 m .38815 .64678 L .41955 .6518 L p .707 .577 .707 r
F P
0 g
s
.64642 .71302 m .64539 .73204 L .63843 .73595 L p .707 .577 .707 r
F P
0 g
s
.41955 .6518 m .42517 .61396 L .39376 .60895 L p .707 .577 .707 r
F P
0 g
s
.45638 .53807 m .45129 .59548 L .47504 .59655 L p .707 .577 .707 r
F P
0 g
s
.47504 .59655 m .48013 .53914 L .45638 .53807 L p .707 .577 .707 r
F P
0 g
s
.6612 .65223 m .65558 .69006 L .64015 .68483 L p .707 .577 .707 r
F P
0 g
s
.64015 .68483 m .64577 .647 L .6612 .65223 L p .707 .577 .707 r
F P
0 g
s
.33513 .60265 m .32951 .64049 L .35712 .64289 L p .707 .577 .707 r
F P
0 g
s
.35712 .64289 m .36274 .60505 L .33513 .60265 L p .707 .577 .707 r
F P
0 g
s
.33184 .58458 m .33693 .52717 L .31572 .52414 L p .707 .577 .707 r
F P
0 g
s
.82989 .57077 m .8248 .62817 L .80359 .62514 L p .707 .577 .707 r
F P
0 g
s
.80359 .62514 m .80868 .56774 L .82989 .57077 L p .707 .577 .707 r
F P
0 g
s
.31572 .52414 m .31063 .58155 L .33184 .58458 L p .707 .577 .707 r
F P
0 g
s
.84011 .72495 m .83908 .74397 L .8264 .73928 L p .707 .577 .707 r
F P
0 g
s
.8264 .73928 m .82743 .72025 L .84011 .72495 L p .707 .577 .707 r
F P
0 g
s
.47145 .66315 m .47707 .62531 L .45387 .6196 L p .707 .577 .707 r
F P
0 g
s
.66038 .61317 m .66548 .55577 L .68923 .55684 L p .707 .577 .707 r
F P
0 g
s
.31364 .60199 m .30802 .63983 L .32951 .64049 L p .707 .577 .707 r
F P
0 g
s
.32951 .64049 m .33513 .60265 L .31364 .60199 L p .707 .577 .707 r
F P
0 g
s
.68923 .55684 m .68413 .61425 L .66038 .61317 L p .707 .577 .707 r
F P
0 g
s
.82463 .67555 m .81901 .71339 L .79752 .71272 L p .707 .577 .707 r
F P
0 g
s
.39085 .71906 m .39188 .70003 L .36072 .69743 L p .707 .577 .707 r
F P
0 g
s
.39188 .70003 m .39085 .71906 L .42263 .72033 L p .707 .577 .707 r
F P
0 g
s
.42263 .72033 m .42366 .7013 L .39188 .70003 L p .707 .577 .707 r
F P
0 g
s
.48013 .53914 m .47504 .59655 L .49107 .59664 L p .707 .577 .707 r
F P
0 g
s
.49107 .59664 m .49617 .53923 L .48013 .53914 L p .707 .577 .707 r
F P
0 g
s
.36072 .69743 m .3597 .71645 L .39085 .71906 L p .707 .577 .707 r
F P
0 g
s
.79752 .71272 m .80314 .67489 L .82463 .67555 L p .707 .577 .707 r
F P
0 g
s
.64539 .73204 m .64642 .71302 L .66267 .7101 L p .707 .577 .707 r
F P
0 g
s
.3597 .71645 m .36072 .69743 L .33325 .69374 L p .707 .577 .707 r
F P
0 g
s
.66267 .7101 m .66164 .72913 L .64539 .73204 L p .707 .577 .707 r
F P
0 g
s
.6844 .65794 m .67878 .69578 L .65558 .69006 L p .707 .577 .707 r
F P
0 g
s
.65558 .69006 m .6612 .65223 L .6844 .65794 L p .707 .577 .707 r
F P
0 g
s
.33325 .69374 m .33222 .71276 L .3597 .71645 L p .707 .577 .707 r
F P
0 g
s
.31063 .58155 m .31572 .52414 L .30289 .5216 L p .707 .577 .707 r
F P
0 g
s
.80868 .56774 m .80359 .62514 L .77608 .62193 L p .707 .577 .707 r
F P
0 g
s
.77608 .62193 m .78117 .56453 L .80868 .56774 L p .707 .577 .707 r
F P
0 g
s
.30289 .5216 m .29779 .579 L .31063 .58155 L p .707 .577 .707 r
F P
0 g
s
.47707 .62531 m .47145 .66315 L .48688 .66838 L p .707 .577 .707 r
F P
0 g
s
.47587 .7185 m .4769 .69948 L .45295 .70111 L p .707 .577 .707 r
F P
0 g
s
.48688 .66838 m .4925 .63054 L .47707 .62531 L p .707 .577 .707 r
F P
0 g
s
.68413 .61425 m .68923 .55684 L .71837 .5588 L p .707 .577 .707 r
F P
0 g
s
.71837 .5588 m .71328 .6162 L .68413 .61425 L p .707 .577 .707 r
F P
0 g
s
.30037 .60312 m .29476 .64096 L .30802 .63983 L p .707 .577 .707 r
F P
0 g
s
.30802 .63983 m .31364 .60199 L .30037 .60312 L p .707 .577 .707 r
F P
0 g
s
.33222 .71276 m .33325 .69374 L .31214 .68933 L p .707 .577 .707 r
F P
0 g
s
.80314 .67489 m .79752 .71272 L .76991 .71033 L p .707 .577 .707 r
F P
0 g
s
.82743 .72025 m .8264 .73928 L .80529 .73487 L p .707 .577 .707 r
F P
0 g
s
.80529 .73487 m .80632 .71585 L .82743 .72025 L p .707 .577 .707 r
F P
0 g
s
.31214 .68933 m .31111 .70836 L .33222 .71276 L p .707 .577 .707 r
F P
0 g
s
.76991 .71033 m .77553 .67249 L .80314 .67489 L p .707 .577 .707 r
F P
0 g
s
.78117 .56453 m .77608 .62193 L .74496 .61885 L p .707 .577 .707 r
F P
0 g
s
.74496 .61885 m .75005 .56145 L .78117 .56453 L p .707 .577 .707 r
F P
0 g
s
.49617 .53923 m .49107 .59664 L .49782 .59572 L p .707 .577 .707 r
F P
0 g
s
.49782 .59572 m .50291 .53832 L .49617 .53923 L p .707 .577 .707 r
F P
0 g
s
.7131 .66358 m .70748 .70142 L .67878 .69578 L p .707 .577 .707 r
F P
0 g
s
.67878 .69578 m .6844 .65794 L .7131 .66358 L p .707 .577 .707 r
F P
0 g
s
.71328 .6162 m .71837 .5588 L .75005 .56145 L p .707 .577 .707 r
F P
0 g
s
.66164 .72913 m .66267 .7101 L .68661 .70847 L p .707 .577 .707 r
F P
0 g
s
.75005 .56145 m .74496 .61885 L .71328 .6162 L p .707 .577 .707 r
F P
0 g
s
.68661 .70847 m .68559 .7275 L .66164 .72913 L p .707 .577 .707 r
F P
0 g
s
.4769 .69948 m .47587 .7185 L .49212 .71559 L p .707 .577 .707 r
F P
0 g
s
.49212 .71559 m .49314 .69657 L .4769 .69948 L p .707 .577 .707 r
F P
0 g
s
.29779 .579 m .30289 .5216 L .29969 .51978 L p .707 .577 .707 r
F P
0 g
s
.77553 .67249 m .76991 .71033 L .73889 .70643 L p .707 .577 .707 r
F P
0 g
s
.4925 .63054 m .48688 .66838 L .49301 .67261 L p .707 .577 .707 r
F P
0 g
s
.29969 .51978 m .29459 .57718 L .29779 .579 L p .707 .577 .707 r
F P
0 g
s
.7445 .66859 m .73889 .70643 L .70748 .70142 L p .707 .577 .707 r
F P
0 g
s
.70748 .70142 m .7131 .66358 L .7445 .66859 L p .707 .577 .707 r
F P
0 g
s
.73889 .70643 m .7445 .66859 L .77553 .67249 L p .707 .577 .707 r
F P
0 g
s
.49301 .67261 m .49863 .63478 L .4925 .63054 L p .707 .577 .707 r
F P
0 g
s
.31111 .70836 m .31214 .68933 L .29946 .68464 L p .707 .577 .707 r
F P
0 g
s
.80632 .71585 m .80529 .73487 L .77781 .73118 L p .707 .577 .707 r
F P
0 g
s
.77781 .73118 m .77884 .71216 L .80632 .71585 L p .707 .577 .707 r
F P
0 g
s
.29946 .68464 m .29843 .70366 L .31111 .70836 L p .707 .577 .707 r
F P
0 g
s
.29663 .60595 m .29101 .64378 L .29476 .64096 L p .707 .577 .707 r
F P
0 g
s
.29476 .64096 m .30037 .60312 L .29663 .60595 L p .707 .577 .707 r
F P
0 g
s
.68559 .7275 m .68661 .70847 L .71591 .70828 L p .707 .577 .707 r
F P
0 g
s
.71591 .70828 m .71488 .72731 L .68559 .7275 L p .707 .577 .707 r
F P
0 g
s
.50291 .53832 m .49782 .59572 L .49462 .59391 L p .707 .577 .707 r
F P
0 g
s
.49462 .59391 m .49971 .5365 L .50291 .53832 L p .707 .577 .707 r
F P
0 g
s
.77884 .71216 m .77781 .73118 L .74666 .72858 L p .707 .577 .707 r
F P
0 g
s
.74666 .72858 m .74769 .70955 L .77884 .71216 L p .707 .577 .707 r
F P
0 g
s
.49314 .69657 m .49212 .71559 L .49908 .71168 L p .707 .577 .707 r
F P
0 g
s
.49908 .71168 m .5001 .69266 L .49314 .69657 L p .707 .577 .707 r
F P
0 g
s
.71488 .72731 m .71591 .70828 L .74769 .70955 L p .707 .577 .707 r
F P
0 g
s
.74769 .70955 m .74666 .72858 L .71488 .72731 L p .707 .577 .707 r
F P
0 g
s
.29459 .57718 m .29969 .51978 L .30643 .51887 L p .707 .577 .707 r
F P
0 g
s
.49863 .63478 m .49301 .67261 L .48927 .67544 L p .707 .577 .707 r
F P
0 g
s
.30643 .51887 m .30134 .57627 L .29459 .57718 L p .707 .577 .707 r
F P
0 g
s
.29843 .70366 m .29946 .68464 L .29645 .68011 L p .707 .577 .707 r
F P
0 g
s
.48927 .67544 m .49488 .6376 L .49863 .63478 L p .707 .577 .707 r
F P
0 g
s
.29645 .68011 m .29542 .69914 L .29843 .70366 L p .707 .577 .707 r
F P
0 g
s
.30276 .61018 m .29714 .64802 L .29101 .64378 L p .707 .577 .707 r
F P
0 g
s
.29101 .64378 m .29663 .60595 L .30276 .61018 L p .707 .577 .707 r
F P
0 g
s
.49971 .5365 m .49462 .59391 L .48179 .59136 L p .707 .577 .707 r
F P
0 g
s
.48179 .59136 m .48688 .53395 L .49971 .5365 L p .707 .577 .707 r
F P
0 g
s
.5001 .69266 m .49908 .71168 L .49607 .70716 L p .707 .577 .707 r
F P
0 g
s
.49607 .70716 m .4971 .68813 L .5001 .69266 L p .707 .577 .707 r
F P
0 g
s
.30134 .57627 m .30643 .51887 L .32247 .51895 L p .707 .577 .707 r
F P
0 g
s
.49488 .6376 m .48927 .67544 L .476 .67657 L p .707 .577 .707 r
F P
0 g
s
.32247 .51895 m .31737 .57636 L .30134 .57627 L p .707 .577 .707 r
F P
0 g
s
.29542 .69914 m .29645 .68011 L .30341 .6762 L p .707 .577 .707 r
F P
0 g
s
.476 .67657 m .48162 .63873 L .49488 .6376 L p .707 .577 .707 r
F P
0 g
s
.30341 .6762 m .30238 .69523 L .29542 .69914 L p .707 .577 .707 r
F P
0 g
s
.31819 .61541 m .31257 .65325 L .29714 .64802 L p .707 .577 .707 r
F P
0 g
s
.29714 .64802 m .30276 .61018 L .31819 .61541 L p .707 .577 .707 r
F P
0 g
s
.48688 .53395 m .48179 .59136 L .46058 .58833 L p .707 .577 .707 r
F P
0 g
s
.46058 .58833 m .46567 .53092 L .48688 .53395 L p .707 .577 .707 r
F P
0 g
s
.4971 .68813 m .49607 .70716 L .48339 .70246 L p .707 .577 .707 r
F P
0 g
s
.48339 .70246 m .48442 .68344 L .4971 .68813 L p .707 .577 .707 r
F P
0 g
s
.31737 .57636 m .32247 .51895 L .34622 .52002 L p .707 .577 .707 r
F P
0 g
s
.34622 .52002 m .34112 .57743 L .31737 .57636 L p .707 .577 .707 r
F P
0 g
s
.48162 .63873 m .476 .67657 L .45451 .67591 L p .707 .577 .707 r
F P
0 g
s
.45451 .67591 m .46012 .63807 L .48162 .63873 L p .707 .577 .707 r
F P
0 g
s
.30238 .69523 m .30341 .6762 L .31966 .67329 L p .707 .577 .707 r
F P
0 g
s
.31966 .67329 m .31863 .69231 L .30238 .69523 L p .707 .577 .707 r
F P
0 g
s
.34139 .62112 m .33577 .65896 L .31257 .65325 L p .707 .577 .707 r
F P
0 g
s
.31257 .65325 m .31819 .61541 L .34139 .62112 L p .707 .577 .707 r
F P
0 g
s
.46567 .53092 m .46058 .58833 L .43307 .58512 L p .707 .577 .707 r
F P
0 g
s
.43307 .58512 m .43816 .52771 L .46567 .53092 L p .707 .577 .707 r
F P
0 g
s
.34112 .57743 m .34622 .52002 L .37536 .52198 L p .707 .577 .707 r
F P
0 g
s
.37536 .52198 m .37027 .57939 L .34112 .57743 L p .707 .577 .707 r
F P
0 g
s
.46012 .63807 m .45451 .67591 L .4269 .67351 L p .707 .577 .707 r
F P
0 g
s
.48442 .68344 m .48339 .70246 L .46228 .69805 L p .707 .577 .707 r
F P
0 g
s
.46228 .69805 m .46331 .67903 L .48442 .68344 L p .707 .577 .707 r
F P
0 g
s
.4269 .67351 m .43252 .63567 L .46012 .63807 L p .707 .577 .707 r
F P
0 g
s
.43816 .52771 m .43307 .58512 L .40195 .58204 L p .707 .577 .707 r
F P
0 g
s
.40195 .58204 m .40704 .52463 L .43816 .52771 L p .707 .577 .707 r
F P
0 g
s
.37009 .62676 m .36447 .6646 L .33577 .65896 L p .707 .577 .707 r
F P
0 g
s
.33577 .65896 m .34139 .62112 L .37009 .62676 L p .707 .577 .707 r
F P
0 g
s
.37027 .57939 m .37536 .52198 L .40704 .52463 L p .707 .577 .707 r
F P
0 g
s
.31863 .69231 m .31966 .67329 L .3436 .67166 L p .707 .577 .707 r
F P
0 g
s
.40704 .52463 m .40195 .58204 L .37027 .57939 L p .707 .577 .707 r
F P
0 g
s
.3436 .67166 m .34257 .69068 L .31863 .69231 L p .707 .577 .707 r
F P
0 g
s
.43252 .63567 m .4269 .67351 L .39588 .66962 L p .707 .577 .707 r
F P
0 g
s
.40149 .63178 m .39588 .66962 L .36447 .6646 L p .707 .577 .707 r
F P
0 g
s
.36447 .6646 m .37009 .62676 L .40149 .63178 L p .707 .577 .707 r
F P
0 g
s
.39588 .66962 m .40149 .63178 L .43252 .63567 L p .707 .577 .707 r
F P
0 g
s
.46331 .67903 m .46228 .69805 L .4348 .69437 L p .707 .577 .707 r
F P
0 g
s
.4348 .69437 m .43583 .67534 L .46331 .67903 L p .707 .577 .707 r
F P
0 g
s
.34257 .69068 m .3436 .67166 L .3729 .67147 L p .707 .577 .707 r
F P
0 g
s
.3729 .67147 m .37187 .69049 L .34257 .69068 L p .707 .577 .707 r
F P
0 g
s
.43583 .67534 m .4348 .69437 L .40365 .69176 L p .707 .577 .707 r
F P
0 g
s
.40365 .69176 m .40468 .67274 L .43583 .67534 L p .707 .577 .707 r
F P
0 g
s
.37187 .69049 m .3729 .67147 L .40468 .67274 L p .707 .577 .707 r
F P
0 g
s
.40468 .67274 m .40365 .69176 L .37187 .69049 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0029OolE001oOol0081oo`T0
00IJEP03001JEUYF00UJEP03001JEUYF00H007Uoo`00NWoo1P000UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF1000MGoo001eOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUH00002001bOol0079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF009JEP<006moo`00KWoo100015YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P00KGoo001/
Ool20008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH2001/Ool006Yoo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00001ZOol006Uoo`04001JEUYF0009FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00
FUIJEUYF0000JGoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1VOol0
06Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ioo`00IGoo0P00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IWoo001TOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001WOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8006Mo
o`00Hgoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YF
FUH000EJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJ
EP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000EJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Ioo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIgoo
001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUIJEP00FUIWOol006=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP06001JEUYFFUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJ
EP8006Moo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH2001WOol006Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUIoo`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001EOolA0002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH:0009FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009J
EPT00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00EGoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00UYF200015YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001EOol20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF30001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH000020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001J
EUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001UOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00AJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUIoo`1TOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol005Aoo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUHK001<Ool005Aoo`8000AJEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001J
EP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT004=oo`00Dgoo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH00UYF2000>goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJ
EUYF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJ
EUYF1P00=Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP05
000`Ool005=oo`03001JEP0000L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP0000<0
02aoo`00Dgoo0`000UYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP07001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo1@000eYF
00<005YFFUH01EYF00<005YFFUH01EYF2@0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00Fgoo1`0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001J
EUYF00MJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80
02aoo`00HWoo200015YF00<005YFFUH01eYF00<005YFFUH015YF1P000eYF00@005YFFUIJEP8000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00D005YFFUIJEP0002eoo`00IWoo00<005YFFUH04P001EYF00<005YFFUH00UYF2@0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF0000;Goo001VOol01000FUIJEP001EYF00<005YFFUH025YF500015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH01@00FUIJEUYF0000;Goo001VOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005Eoo`h000=oo`04001JEUYF
0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]
Ool005Aoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH80005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Aoo`<0009JEP03001JEUYF00=J
EP03001JEUYF00EJEP04001JEUYFFUH90006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH2000]Ool005Aoo`03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF014000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000]Ool005=oo`04001JEUYF0002FUH60007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEUYF1P000eYF00<005YFFUH015YF4P0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00Dgoo00<005YF000015YF00@005YFFUIJEPD000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPD00003FUH005YF00]JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=oo`L000AJEP03001JEUYF
00IJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool002iooa4001Ao
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEP0000<000QJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00@000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000Yoo`T000AJEP03001JEUYF00IJEP03001JEUYF00AJEPL000=JEP05001JEUYFFUH0
000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJEP04001JEUYFFUH9000;Ool00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80009FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000COol90004
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH50002FUH00`00Oomoo`0/Ool002ioo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT0009oo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8001aooa0000=JEP04001JEUYFFUH3000^Ool002ioo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH80002FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00;7oo2@00;goo000^Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUIJEQ0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH>001IOol002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@00D7oo000]Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00`000UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF1`00BGoo000]Ool00`00FUH00004FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUH005YF00@000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@004Eoo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
1@001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYF001JEP000UYF0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1P00
?goo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF00001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YF00000`001eYF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YFFUIJEPH003Uoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P001UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001JEUYF
00=JEPD0009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Eo
o`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF1`000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00<Woo000]Ool20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP070004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEP00008002moo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EPl000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH015YF1`0000=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Goo
000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH=0004FUH00`00FUIJEP02FUH>0004FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPl00003FUH005YF
00=JEP<002eoo`00;7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEQD000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001J
EP000004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP0600000eYF0000000]Ool002aoo`03001JEP0000L000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH8000<FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;7oo
0`000UYF00<005YFFUH00UYF4@0015YF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@00
25YF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YF000000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF008002ioo`00;goo1P000UYF00<005YFFUH01EYF00<005YFFUH01EYF2@0015YF
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YF00000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002eoo`@00004
FUH005YFFUH?0004FUH00`00FUIJEP05FUH4000015YF001JEUYF7`0015YF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP06001JEUYFFUH005YF10000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00@005YFFUIJEPT000AJEP04001JEP00FUH40002FUH70003FUH300000eYF001J
EP05FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00003FUH60006FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]
Ool00`00FUH000020006FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0:0003FUH00`00
FUIJEP03FUH01000FUIJEUYF2@001EYF00<005YFFUH025YF00@005YFFUIJEPL000=JEP04001JEUYF
FUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00AJEP03001JEUYF009JEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool002aoo`05001JEUYF001JEP040002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP02FUHI0002FUH40003FUH00`00FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00L000AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool002aoo`04001JEUYF
0003FUH00`00FUH000030006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH0
0`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP04FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00=JEP03001JEUYF009JEP03001o
ogoo00=oo`P000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002aoo`03
001JEP0000AJEP03001JEUYF00=JEPD00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF009J
EPD000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP04001JEUYFFUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEUYF001JERD000AJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002aoo`03001JEP00
00=JEP03001JEUYF00EJEP04001JEUYFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH80004
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF
001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHD000`Ool002ao
o`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000QJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEP0000P000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEP00008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP04001JEUYFFUH7000eOol002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00AJEPH0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001oo`00
009JEQD00003FUH0000000P000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04000aOol002]oo`04001JEUYF0003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF20000UYF00<005YFFUH015YF00@005YFFUIJ
EP@0009JEP03001JEUYF00AJEP03001JEUYF019JEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000_Ool002]oo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH=000015YF000000000UYF00<005YFFUH015YF00<005YFFUH04UYF00<005YFFUH015YF
5P0025YF00<005YFFUH01EYF00D005YF001JEP0000AJEP04001JEUYFFUH@0004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo000[Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0000AooeYFFUH000IJEP03001JEUYF011JEPX000aJEP03001JEUYF
00IJEPH0009JEP03001JEUYF00EJEP05001JEP00FUH00002FUH:0003FUH00`00Oomoo`06OolA0003
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P0000AooeYFFUH000IJEP03001JEUYF00YJEPH000UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP04001JEUYFFUH40006FUH01000FUH005YF10001EYF00@005YFFUIJEPP001Eoo`D000AJEP04001J
EUYFFUH2000]Ool002ioo`800003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000017ooFUIJEP001UYF00<0
05YFFUH015YF1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF0P0015YF00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00EJEP04001JEUYFFUHM0000
0eYF001JEP02FUH2000]Ool0031oo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002Ool2FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH300001EYF001JEUYF00000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`000UYF0P00;Goo000bOolN0002FUH0
0`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020002Ool2FUH00`00FUIJEP04FUH00`00FUH0
0002000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP020003FUH01000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH01000;Goo000_Ool300000eYF001JEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YFFUH00eYF00@005YFFUIJ
EP80009oo`9JEP03001JEUYF00AJEP80009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEUYF009JEP03001JEP00
00800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001JEUYF009JEP03001JEP0002eoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL00003FUH005YF009JEP80009oo`9J
EP03001JEUYF009JEP8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001JEP00009JEPD000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00@002ioo`00
;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH0100000=JEP0000000Woo0UYF00<005YFFUH00P001UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00@005YF000000MJEQ<000AJEP03001JEUYF00EJEP04001JEUYFFUH6000bOol002eo
o`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP@0009oo`9JEP<000UJEP03001JEUYF00MJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEP000006FUH0
0`00FUIJEP03FUH2000<Ool@000hOol002aoo`03001JEP0000AJEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000017ooFUIJEP000eYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH015YF00<005YF00003`00E7oo000/Ool00`00FUH00002FUH:000<OolA
0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH015YF0`000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00;7oo00<005YF00000`001EYF
00@005YFFUIJEPT001Aoo`H000AJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH30003FUH00`00FUIJEP03FUH01@00FUIJEUYF0000EGoo000/Ool20003FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHM00000eYF001JEP02FUH40004FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00EGoo000]
Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH40002FUH01000Ool0000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YF00000UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00;goo100015YF00<005YFFUH01EYF
00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP<00003Ool0
000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2
001EOol003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001J
EUYF00AJEP08001JEUYFFUH005YF001oo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<0009J
EP03001JEUYF00=JEP04001JEUYFFUH2001EOol003Ioo`D000AJEP03001JEUYF00IJEP<000IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<000=oo`03001JEUYF009JEP03001JEUYF00EJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00AJEP03001JEUYF00H0009JEP04001JEUYFFUH2001EOol003]ooa8000AJEP03001J
EUYF00EJEP04001JEUYFFUH60006Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUH000020003FUH00`00Oomoo`1DOol004eooa0000aoo`03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF009JEP@005Ioo`00JWoo00D005YF
FUIJEP0000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00800003FUH005YF00EJEP03001JEUYF00AJEP04001JEP00001EOol0
06]oo`800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF0080
05Aoo`00KGoo0P001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF0P0000=oo`0000001P000eYF00<005YFFUH00eYF00@005YFFUIJEP8005Ao
o`00KWoo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH00eYF0`002goo1P000eYF00@005YFFUIJEP8005Aoo`00L7oo0P0015YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF0000100000=JEP000000
3`0000=JEP0000000`000UYF0P00E7oo001bOol300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP06FUH400000eYF000000030004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP04001DOol007Eoo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00H000EJEPD000AJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP<005Aoo`00NGoo
1P000UYF00<005YFFUH02UYF00<005YFFUH015YF2@000UYF00<005YFFUH01UYF1@0015YF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000E7oo001oOolF0007Ool90004FUH4
0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP04001EOol00:Eooal005Uoo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59805 .76302 m .59296 .71245 L .56184 .71166 L p .707 .577 .707 r
F P
0 g
s
.59296 .71245 m .59805 .76302 L .62973 .75903 L p .707 .577 .707 r
F P
0 g
s
.62973 .75903 m .62464 .70845 L .59296 .71245 L p .707 .577 .707 r
F P
0 g
s
.62464 .70845 m .62973 .75903 L .65887 .75063 L p .707 .577 .707 r
F P
0 g
s
.65887 .75063 m .65378 .70006 L .62464 .70845 L p .707 .577 .707 r
F P
0 g
s
.56693 .76223 m .56184 .71166 L .53433 .70615 L p .707 .577 .707 r
F P
0 g
s
.56184 .71166 m .56693 .76223 L .59805 .76302 L p .707 .577 .707 r
F P
0 g
s
.65378 .70006 m .65887 .75063 L .68262 .73867 L p .707 .577 .707 r
F P
0 g
s
.68262 .73867 m .67753 .68809 L .65378 .70006 L p .707 .577 .707 r
F P
0 g
s
.53942 .75673 m .53433 .70615 L .51312 .69648 L p .707 .577 .707 r
F P
0 g
s
.53433 .70615 m .53942 .75673 L .56693 .76223 L p .707 .577 .707 r
F P
0 g
s
.67753 .68809 m .68262 .73867 L .69866 .7243 L p .707 .577 .707 r
F P
0 g
s
.69866 .7243 m .69356 .67372 L .67753 .68809 L p .707 .577 .707 r
F P
0 g
s
.60412 .84245 m .5985 .81216 L .56748 .81205 L p .707 .577 .707 r
F P
0 g
s
.5985 .81216 m .60412 .84245 L .63552 .83647 L p .707 .577 .707 r
F P
0 g
s
.63552 .83647 m .6299 .80617 L .5985 .81216 L p .707 .577 .707 r
F P
0 g
s
.6299 .80617 m .63552 .83647 L .66423 .82498 L p .707 .577 .707 r
F P
0 g
s
.66423 .82498 m .65861 .79468 L .6299 .80617 L p .707 .577 .707 r
F P
0 g
s
.51821 .74706 m .51312 .69648 L .50028 .68358 L p .707 .577 .707 r
F P
0 g
s
.51312 .69648 m .51821 .74706 L .53942 .75673 L p .707 .577 .707 r
F P
0 g
s
.59635 .87503 m .59532 .85738 L .56417 .85616 L p .707 .577 .707 r
F P
0 g
s
.59532 .85738 m .59635 .87503 L .62813 .87228 L p .707 .577 .707 r
F P
0 g
s
.62813 .87228 m .6271 .85463 L .59532 .85738 L p .707 .577 .707 r
F P
0 g
s
.6271 .85463 m .62813 .87228 L .65742 .86583 L p .707 .577 .707 r
F P
0 g
s
.65742 .86583 m .6564 .84818 L .6271 .85463 L p .707 .577 .707 r
F P
0 g
s
.5731 .84235 m .56748 .81205 L .53987 .80586 L p .707 .577 .707 r
F P
0 g
s
.56748 .81205 m .5731 .84235 L .60412 .84245 L p .707 .577 .707 r
F P
0 g
s
.65861 .79468 m .66423 .82498 L .68743 .80911 L p .707 .577 .707 r
F P
0 g
s
.68743 .80911 m .68181 .77881 L .65861 .79468 L p .707 .577 .707 r
F P
0 g
s
.69356 .67372 m .69866 .7243 L .7054 .70893 L p .707 .577 .707 r
F P
0 g
s
.7054 .70893 m .70031 .65836 L .69356 .67372 L p .707 .577 .707 r
F P
0 g
s
.56519 .87381 m .56417 .85616 L .53669 .85109 L p .707 .577 .707 r
F P
0 g
s
.56417 .85616 m .56519 .87381 L .59635 .87503 L p .707 .577 .707 r
F P
0 g
s
.6564 .84818 m .65742 .86583 L .68137 .85631 L p .707 .577 .707 r
F P
0 g
s
.68137 .85631 m .68034 .83866 L .6564 .84818 L p .707 .577 .707 r
F P
0 g
s
.53669 .85109 m .53772 .86874 L .56519 .87381 L p .707 .577 .707 r
F P
0 g
s
.54549 .83616 m .53987 .80586 L .51838 .7942 L p .707 .577 .707 r
F P
0 g
s
.53987 .80586 m .54549 .83616 L .5731 .84235 L p .707 .577 .707 r
F P
0 g
s
.68181 .77881 m .68743 .80911 L .70285 .79041 L p .707 .577 .707 r
F P
0 g
s
.70285 .79041 m .69723 .76011 L .68181 .77881 L p .707 .577 .707 r
F P
0 g
s
.53772 .86874 m .53669 .85109 L .51558 .84267 L p .707 .577 .707 r
F P
0 g
s
.50538 .73416 m .50028 .68358 L .49709 .66873 L p .707 .577 .707 r
F P
0 g
s
.50028 .68358 m .50538 .73416 L .51821 .74706 L p .707 .577 .707 r
F P
0 g
s
.51558 .84267 m .51661 .86031 L .53772 .86874 L p .707 .577 .707 r
F P
0 g
s
.68034 .83866 m .68137 .85631 L .69761 .84465 L p .707 .577 .707 r
F P
0 g
s
.69761 .84465 m .69659 .82701 L .68034 .83866 L p .707 .577 .707 r
F P
0 g
s
.70031 .65836 m .7054 .70893 L .7022 .69407 L p .707 .577 .707 r
F P
0 g
s
.7022 .69407 m .69711 .6435 L .70031 .65836 L p .707 .577 .707 r
F P
0 g
s
.524 .8245 m .51838 .7942 L .50511 .77821 L p .707 .577 .707 r
F P
0 g
s
.51838 .7942 m .524 .8245 L .54549 .83616 L p .707 .577 .707 r
F P
0 g
s
.69723 .76011 m .70285 .79041 L .70899 .77072 L p .707 .577 .707 r
F P
0 g
s
.70899 .77072 m .70337 .74042 L .69723 .76011 L p .707 .577 .707 r
F P
0 g
s
.51661 .86031 m .51558 .84267 L .5029 .83171 L p .707 .577 .707 r
F P
0 g
s
.49709 .66873 m .50218 .7193 L .50538 .73416 L p .707 .577 .707 r
F P
0 g
s
.50218 .7193 m .49709 .66873 L .50383 .65336 L p .707 .577 .707 r
F P
0 g
s
.5029 .83171 m .50393 .84936 L .51661 .86031 L p .707 .577 .707 r
F P
0 g
s
.69659 .82701 m .69761 .84465 L .70457 .832 L p .707 .577 .707 r
F P
0 g
s
.70457 .832 m .70355 .81435 L .69659 .82701 L p .707 .577 .707 r
F P
0 g
s
.69711 .6435 m .7022 .69407 L .68937 .68117 L p .707 .577 .707 r
F P
0 g
s
.68937 .68117 m .68428 .6306 L .69711 .6435 L p .707 .577 .707 r
F P
0 g
s
.50511 .77821 m .51073 .8085 L .524 .8245 L p .707 .577 .707 r
F P
0 g
s
.51073 .8085 m .50511 .77821 L .50136 .75944 L p .708 .578 .707 r
F P
0 g
s
.70337 .74042 m .70899 .77072 L .70524 .75196 L p .708 .578 .707 r
F P
0 g
s
.70524 .75196 m .69962 .72166 L .70337 .74042 L p .708 .578 .707 r
F P
0 g
s
.4803 .81656 m .49667 .30549 L .45267 .30222 L p .707 .577 .707 r
F P
0 g
s
.50892 .70393 m .50383 .65336 L .51987 .63899 L p .707 .577 .707 r
F P
0 g
s
.50383 .65336 m .50892 .70393 L .50218 .7193 L p .707 .577 .707 r
F P
0 g
s
.50136 .75944 m .50698 .78974 L .51073 .8085 L p .708 .578 .707 r
F P
0 g
s
.50698 .78974 m .50136 .75944 L .5075 .73975 L p .707 .577 .707 r
F P
0 g
s
.50393 .84936 m .5029 .83171 L .49989 .8193 L p .707 .577 .707 r
F P
0 g
s
.49989 .8193 m .50092 .83694 L .50393 .84936 L p .707 .577 .707 r
F P
0 g
s
.50092 .83694 m .49989 .8193 L .50685 .80664 L p .707 .577 .707 r
F P
0 g
s
.51987 .63899 m .52496 .68956 L .50892 .70393 L p .707 .577 .707 r
F P
0 g
s
.50685 .80664 m .50788 .82429 L .50092 .83694 L p .707 .577 .707 r
F P
0 g
s
.5075 .73975 m .51312 .77005 L .50698 .78974 L p .707 .577 .707 r
F P
0 g
s
.51312 .77005 m .5075 .73975 L .52293 .72105 L p .707 .577 .707 r
F P
0 g
s
.50788 .82429 m .50685 .80664 L .5231 .79498 L p .707 .577 .707 r
F P
0 g
s
.52293 .72105 m .52855 .75135 L .51312 .77005 L p .707 .577 .707 r
F P
0 g
s
.5231 .79498 m .52413 .81263 L .50788 .82429 L p .707 .577 .707 r
F P
0 g
s
.52413 .81263 m .5231 .79498 L .54704 .78546 L p .707 .577 .707 r
F P
0 g
s
.54704 .78546 m .54806 .80297 L p .52413 .81263 L .707 .577 .707 r
F P
0 g
s
.54369 .81619 m .56666 .81501 L p .56594 .8005 L .707 .577 .707 r
F P
0 g
s
.54704 .78546 m .55984 .78264 L p .54826 .80294 L .707 .577 .707 r
F P
0 g
s
.55984 .78264 m .57634 .77901 L p .56302 .79037 L .707 .577 .707 r
F P
0 g
s
.54826 .80294 m .55984 .78264 L .56302 .79037 L .707 .577 .707 r
F
.57785 .66921 m .57276 .61863 L .60444 .61463 L p F P
0 g
s
.57276 .61863 m .57785 .66921 L .55487 .67582 L p .707 .577 .707 r
F P
0 g
s
.55487 .67582 m .54871 .6776 L p .55153 .67068 L .707 .577 .707 r
F P
0 g
s
.55153 .67068 m .57276 .61863 L .55487 .67582 L .707 .577 .707 r
F
.56594 .8005 m .54806 .80297 L .54369 .81619 L F
.57634 .77901 m .57737 .79666 L .54976 .80274 L p F P
0 g
s
.54976 .80274 m .54807 .80311 L p .54826 .80294 L .707 .577 .707 r
F P
0 g
s
.54826 .80294 m .57634 .77901 L .54976 .80274 L .707 .577 .707 r
F
.54871 .6776 m .54362 .62702 L .57276 .61863 L p F P
0 g
s
.54613 .70518 m .57483 .69369 L p .55639 .72707 L .707 .577 .707 r
F P
0 g
s
.55045 .72849 m .54613 .70518 L p .55639 .72707 L .707 .577 .707 r
F P
0 g
s
.54806 .80297 m .54704 .78546 L p .54826 .80294 L .707 .577 .707 r
F P
0 g
s
.54801 .80313 m .52413 .81263 L p .54806 .80297 L .707 .577 .707 r
F P
0 g
s
.52496 .68956 m .51987 .63899 L .54362 .62702 L p .707 .577 .707 r
F P
0 g
s
.54362 .62702 m .54871 .6776 L .52496 .68956 L p .707 .577 .707 r
F P
0 g
s
.52855 .75135 m .52293 .72105 L .54613 .70518 L p .707 .577 .707 r
F P
0 g
s
.56373 .75559 m .56226 .72567 L .54369 .81619 L .707 .577 .707 r
F
.56226 .72567 m .55868 .72652 L .54369 .81619 L F
.57483 .69369 m .57998 .72144 L p .56958 .72392 L F P
0 g
s
.55639 .72707 m .56167 .71751 L .56958 .72392 L .707 .577 .707 r
F
.56167 .71751 m .57483 .69369 L .56958 .72392 L F
.57737 .79666 m .57634 .77901 L .60812 .77626 L p F P
0 g
s
.56958 .72392 m .56713 .80034 L p .5965 .74576 L .707 .577 .707 r
F P
0 g
s
.55868 .72652 m .54338 .74047 L .54369 .81619 L .707 .577 .707 r
F
.56148 .70981 m .55045 .72849 L .55868 .72652 L F
.55045 .72849 m .54338 .74047 L .55868 .72652 L F
.56594 .8005 m .56857 .72416 L .56226 .72567 L F
.56713 .80034 m .58302 .30394 L p .56594 .8005 L F P
0 g
s
.58045 .72399 m .55175 .73548 L p .55639 .72707 L .707 .577 .707 r
F P
0 g
s
.57998 .72144 m .58045 .72399 L p .55639 .72707 L .707 .577 .707 r
F P
0 g
s
.58045 .72399 m .57483 .69369 L .58053 .69261 L p .707 .577 .707 r
F P
0 g
s
.58053 .69261 m .60623 .68771 L p .58719 .71451 L .707 .577 .707 r
F P
0 g
s
.58045 .72399 m .58053 .69261 L .58719 .71451 L .707 .577 .707 r
F
.63556 .61543 m .64065 .666 L .60953 .66521 L p F P
0 g
s
.60953 .66521 m .60444 .61463 L .63556 .61543 L p .707 .577 .707 r
F P
0 g
s
.60444 .61463 m .60953 .66521 L .57785 .66921 L p .707 .577 .707 r
F P
0 g
s
.63726 .68781 m .64287 .71811 L .61185 .71801 L p .707 .577 .707 r
F P
0 g
s
.61185 .71801 m .60623 .68771 L .63726 .68781 L p .707 .577 .707 r
F P
0 g
s
.60623 .68771 m .61185 .71801 L .58045 .72399 L p .707 .577 .707 r
F P
0 g
s
.63927 .77748 m .6403 .79513 L .60915 .79391 L p .707 .577 .707 r
F P
0 g
s
.60915 .79391 m .60812 .77626 L .63927 .77748 L p .707 .577 .707 r
F P
0 g
s
.61693 .29927 m .60206 .76344 L p .62361 .80361 L .707 .577 .707 r
F P
0 g
s
.60812 .77626 m .60915 .79391 L .57737 .79666 L p .707 .577 .707 r
F P
0 g
s
.60206 .76344 m .60056 .81034 L .61504 .80612 L p .707 .577 .707 r
F P
0 g
s
.61504 .80612 m .62361 .80361 L p .60206 .76344 L .707 .577 .707 r
F P
0 g
s
.57035 .69966 m .56958 .72392 L p .59821 .74257 L .707 .577 .707 r
F P
0 g
s
.59821 .74257 m .56958 .72392 L .5965 .74576 L .707 .577 .707 r
F
.56226 .72567 m .56148 .70981 L .55868 .72652 L F
.54613 .70518 m .55045 .72849 L p .52855 .75135 L F P
0 g
s
.54265 .7417 m .52855 .75135 L p .55045 .72849 L .707 .577 .707 r
F P
0 g
s
.56148 .70981 m .54159 .30608 L .54338 .74047 L .707 .577 .707 r
F
.54159 .30608 m .52522 .81715 L .54369 .81619 L p F P
0 g
s
.55045 .72849 m .55175 .73548 L .54265 .7417 L p .707 .577 .707 r
F P
0 g
s
.55175 .73548 m .55045 .72849 L p .55639 .72707 L .707 .577 .707 r
F P
0 g
s
.58302 .30394 m .54159 .30608 L p .56226 .72567 L .707 .577 .707 r
F P
0 g
s
.56857 .72416 m .58302 .30394 L .56226 .72567 L .707 .577 .707 r
F
.56666 .81501 m .56713 .80034 L p .56594 .8005 L F P
0 g
s
.60056 .81034 m .59821 .74257 L .56713 .80034 L .707 .577 .707 r
F
.58302 .30394 m .57035 .69966 L p .59821 .74257 L F P
0 g
s
.56713 .80034 m .56666 .81501 L .57282 .81416 L p .707 .577 .707 r
F P
0 g
s
.57282 .81416 m .60056 .81034 L p .56713 .80034 L .707 .577 .707 r
F P
0 g
s
.56594 .8005 m .56373 .75559 L .54806 .80297 L .707 .577 .707 r
F
.54807 .80311 m .54806 .80297 L p .54826 .80294 L F P
0 g
s
.54806 .80297 m .54807 .80311 L .54801 .80313 L p .707 .577 .707 r
F P
0 g
s
.49667 .30549 m .4803 .81656 L .52522 .81715 L p .707 .577 .707 r
F P
0 g
s
.52522 .81715 m .54159 .30608 L .49667 .30549 L p .707 .577 .707 r
F P
0 g
s
.4363 .81329 m .45267 .30222 L .4139 .29661 L p .707 .577 .707 r
F P
0 g
s
.45267 .30222 m .4363 .81329 L .4803 .81656 L p .707 .577 .707 r
F P
0 g
s
.70355 .81435 m .70457 .832 L .70157 .81958 L p .707 .577 .707 r
F P
0 g
s
.70157 .81958 m .70054 .80194 L .70355 .81435 L p .707 .577 .707 r
F P
0 g
s
.25504 .72621 m .24995 .67563 L .21883 .67484 L p .707 .577 .707 r
F P
0 g
s
.24995 .67563 m .25504 .72621 L .28672 .72221 L p .707 .577 .707 r
F P
0 g
s
.28672 .72221 m .28163 .67164 L .24995 .67563 L p .707 .577 .707 r
F P
0 g
s
.28163 .67164 m .28672 .72221 L .31586 .71382 L p .707 .577 .707 r
F P
0 g
s
.31586 .71382 m .31077 .66324 L .28163 .67164 L p .707 .577 .707 r
F P
0 g
s
.68428 .6306 m .68937 .68117 L .66816 .6715 L p .707 .577 .707 r
F P
0 g
s
.66816 .6715 m .66307 .62093 L .68428 .6306 L p .707 .577 .707 r
F P
0 g
s
.69962 .72166 m .70524 .75196 L .69197 .73596 L p .707 .577 .707 r
F P
0 g
s
.69197 .73596 m .68635 .70566 L .69962 .72166 L p .707 .577 .707 r
F P
0 g
s
.60056 .81034 m .61693 .29927 L .58302 .30394 L p .707 .577 .707 r
F P
0 g
s
.22392 .72541 m .21883 .67484 L .19132 .66934 L p .707 .577 .707 r
F P
0 g
s
.21883 .67484 m .22392 .72541 L .25504 .72621 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31077 .66324 m .31586 .71382 L .33961 .70185 L p .707 .577 .707 r
F P
0 g
s
.33961 .70185 m .33452 .65128 L .31077 .66324 L p .707 .577 .707 r
F P
0 g
s
.39753 .80767 m .4139 .29661 L .38414 .28918 L p .707 .577 .707 r
F P
0 g
s
.4139 .29661 m .39753 .80767 L .4363 .81329 L p .707 .577 .707 r
F P
0 g
s
.19641 .71991 m .19132 .66934 L .17011 .65967 L p .707 .577 .707 r
F P
0 g
s
.19132 .66934 m .19641 .71991 L .22392 .72541 L p .707 .577 .707 r
F P
0 g
s
.66307 .62093 m .66816 .6715 L .64065 .666 L p .707 .577 .707 r
F P
0 g
s
.64065 .666 m .63556 .61543 L .66307 .62093 L p .707 .577 .707 r
F P
0 g
s
.68635 .70566 m .69197 .73596 L .67048 .7243 L p .707 .577 .707 r
F P
0 g
s
.67048 .7243 m .66486 .694 L .68635 .70566 L p .707 .577 .707 r
F P
0 g
s
.70054 .80194 m .70157 .81958 L .68889 .80863 L p .707 .577 .707 r
F P
0 g
s
.68889 .80863 m .68786 .79098 L .70054 .80194 L p .707 .577 .707 r
F P
0 g
s
.33452 .65128 m .33961 .70185 L .35565 .68748 L p .707 .577 .707 r
F P
0 g
s
.35565 .68748 m .35056 .63691 L .33452 .65128 L p .707 .577 .707 r
F P
0 g
s
.62361 .80361 m .63998 .29254 L .61693 .29927 L p .707 .577 .707 r
F P
0 g
s
.26111 .80564 m .25549 .77534 L .22447 .77523 L p .707 .577 .707 r
F P
0 g
s
.25549 .77534 m .26111 .80564 L .29251 .79965 L p .707 .577 .707 r
F P
0 g
s
.29251 .79965 m .28689 .76936 L .25549 .77534 L p .707 .577 .707 r
F P
0 g
s
.28689 .76936 m .29251 .79965 L .32122 .78816 L p .707 .577 .707 r
F P
0 g
s
.32122 .78816 m .3156 .75787 L .28689 .76936 L p .707 .577 .707 r
F P
0 g
s
.1752 .71024 m .17011 .65967 L .15728 .64677 L p .707 .577 .707 r
F P
0 g
s
.17011 .65967 m .1752 .71024 L .19641 .71991 L p .707 .577 .707 r
F P
0 g
s
.25334 .83822 m .25231 .82057 L .22116 .81935 L p .707 .577 .707 r
F P
0 g
s
.25231 .82057 m .25334 .83822 L .28512 .83547 L p .707 .577 .707 r
F P
0 g
s
.28512 .83547 m .28409 .81782 L .25231 .82057 L p .707 .577 .707 r
F P
0 g
s
.28409 .81782 m .28512 .83547 L .31441 .82902 L p .707 .577 .707 r
F P
0 g
s
.31441 .82902 m .31339 .81137 L .28409 .81782 L p .707 .577 .707 r
F P
0 g
s
.66486 .694 m .67048 .7243 L .64287 .71811 L p .707 .577 .707 r
F P
0 g
s
.64287 .71811 m .63726 .68781 L .66486 .694 L p .707 .577 .707 r
F P
0 g
s
.36778 .80025 m .38414 .28918 L .36632 .28068 L p .707 .577 .707 r
F P
0 g
s
.38414 .28918 m .36778 .80025 L .39753 .80767 L p .707 .577 .707 r
F P
0 g
s
.23009 .80553 m .22447 .77523 L .19686 .76905 L p .707 .577 .707 r
F P
0 g
s
.22447 .77523 m .23009 .80553 L .26111 .80564 L p .707 .577 .707 r
F P
0 g
s
.3156 .75787 m .32122 .78816 L .34442 .77229 L p .707 .577 .707 r
F P
0 g
s
.34442 .77229 m .3388 .742 L .3156 .75787 L p .707 .577 .707 r
F P
0 g
s
.35056 .63691 m .35565 .68748 L .36239 .67212 L p .707 .577 .707 r
F P
0 g
s
.36239 .67212 m .3573 .62154 L .35056 .63691 L p .707 .577 .707 r
F P
0 g
s
.22219 .83699 m .22116 .81935 L .19368 .81428 L p .707 .577 .707 r
F P
0 g
s
.22116 .81935 m .22219 .83699 L .25334 .83822 L p .707 .577 .707 r
F P
0 g
s
.68786 .79098 m .68889 .80863 L .66778 .8002 L p .707 .577 .707 r
F P
0 g
s
.66778 .8002 m .66675 .78256 L .68786 .79098 L p .707 .577 .707 r
F P
0 g
s
.31339 .81137 m .31441 .82902 L .33836 .81949 L p .707 .577 .707 r
F P
0 g
s
.33836 .81949 m .33733 .80185 L .31339 .81137 L p .707 .577 .707 r
F P
0 g
s
.19368 .81428 m .19471 .83192 L .22219 .83699 L p .707 .577 .707 r
F P
0 g
s
.20248 .79935 m .19686 .76905 L .17537 .75739 L p .707 .577 .707 r
F P
0 g
s
.19686 .76905 m .20248 .79935 L .23009 .80553 L p .707 .577 .707 r
F P
0 g
s
.3388 .742 m .34442 .77229 L .35984 .7536 L p .707 .577 .707 r
F P
0 g
s
.35984 .7536 m .35422 .7233 L .3388 .742 L p .707 .577 .707 r
F P
0 g
s
.19471 .83192 m .19368 .81428 L .17257 .80585 L p .707 .577 .707 r
F P
0 g
s
.16237 .69734 m .15728 .64677 L .15408 .63191 L p .707 .577 .707 r
F P
0 g
s
.15728 .64677 m .16237 .69734 L .1752 .71024 L p .707 .577 .707 r
F P
0 g
s
.63998 .29254 m .62361 .80361 L .63355 .79548 L p .707 .577 .707 r
F P
0 g
s
.63355 .79548 m .64992 .28441 L .63998 .29254 L p .707 .577 .707 r
F P
0 g
s
.17257 .80585 m .1736 .8235 L .19471 .83192 L p .707 .577 .707 r
F P
0 g
s
.33733 .80185 m .33836 .81949 L .3546 .80784 L p .707 .577 .707 r
F P
0 g
s
.3546 .80784 m .35358 .79019 L .33733 .80185 L p .707 .577 .707 r
F P
0 g
s
.66675 .78256 m .66778 .8002 L .6403 .79513 L p .707 .577 .707 r
F P
0 g
s
.6403 .79513 m .63927 .77748 L .66675 .78256 L p .707 .577 .707 r
F P
0 g
s
.3573 .62154 m .36239 .67212 L .35919 .65726 L p .707 .577 .707 r
F P
0 g
s
.3541 .60668 m .3573 .62154 L p .35865 .64701 L .707 .577 .707 r
F P
0 g
s
.35785 .64392 m .3541 .60668 L p .35865 .64701 L .707 .577 .707 r
F P
0 g
s
.3541 .60668 m .35785 .64392 L p .34636 .64436 L .707 .577 .707 r
F P
0 g
s
.35785 .64392 m .35919 .65726 L .35648 .65453 L p .707 .577 .707 r
F P
0 g
s
.35648 .65453 m .34636 .64436 L p .35785 .64392 L .707 .577 .707 r
F P
0 g
s
.35422 .7233 m .35984 .7536 L .36598 .7339 L p .707 .577 .707 r
F P
0 g
s
.36598 .7339 m .36036 .7036 L .35422 .7233 L p .707 .577 .707 r
F P
0 g
s
.35358 .79019 m .3546 .80784 L .36156 .79518 L p .707 .577 .707 r
F P
0 g
s
.36156 .79518 m .36054 .77754 L .35358 .79019 L p .707 .577 .707 r
F P
0 g
s
.36036 .7036 m .36598 .7339 L .3637 .7225 L p .708 .578 .707 r
F P
0 g
s
.36196 .71346 m .36036 .7036 L .3637 .7225 L .708 .578 .707 r
F
.34588 .77181 m .35121 .76875 L .35055 .7758 L .707 .577 .707 r
F
.35783 .78214 m .35054 .77584 L p .35855 .78263 L F P
0 g
s
.35054 .77584 m .34588 .77181 L p .35055 .7758 L .707 .577 .707 r
F P
0 g
s
.35055 .7758 m .35855 .78263 L .35054 .77584 L .707 .577 .707 r
F
.34334 .66885 m .35651 .68471 L p .34971 .69772 L F P
0 g
s
.34896 .69915 m .34849 .69659 L p .34971 .69772 L .707 .577 .707 r
F P
0 g
s
.34849 .69659 m .34334 .66885 L p .34971 .69772 L .707 .577 .707 r
F P
0 g
s
.34896 .69915 m .35651 .68471 L .35638 .68528 L .707 .577 .707 r
F
.34636 .64436 m .34127 .59378 L .3541 .60668 L p F P
0 g
s
.34588 .77181 m .34485 .75417 L .35753 .76512 L p .707 .577 .707 r
F P
0 g
s
.35026 .77886 m .35287 .70066 L .35201 .70446 L .707 .577 .707 r
F
.35043 .77708 m .35287 .70066 L p .35026 .77886 L F P
0 g
s
.35753 .76512 m .35855 .78263 L p .35055 .7758 L .707 .577 .707 r
F P
0 g
s
.35121 .76875 m .35753 .76512 L .35055 .7758 L .707 .577 .707 r
F
.35287 .70066 m .35043 .77708 L p .36461 .72719 L F P
0 g
s
.36094 .70815 m .35287 .70066 L .36461 .72719 L .707 .577 .707 r
F
.35661 .68484 m .36223 .71514 L .3523 .70317 L p F P
0 g
s
.3523 .70317 m .34896 .69915 L p .35638 .68528 L .707 .577 .707 r
F P
0 g
s
.35638 .68528 m .35661 .68484 L .3523 .70317 L .707 .577 .707 r
F
.34581 .783 m .3492 .79016 L p .35127 .70771 L F P
0 g
s
.34334 .66885 m .34896 .69915 L .34274 .69577 L p .707 .577 .707 r
F P
0 g
s
.34274 .69577 m .32747 .68748 L p .34012 .67264 L .707 .577 .707 r
F P
0 g
s
.34012 .67264 m .34334 .66885 L .34274 .69577 L .707 .577 .707 r
F
.36218 .27193 m .34773 .72327 L p .35127 .70771 L F P
0 g
s
.34773 .72327 m .34581 .783 L p .35127 .70771 L .707 .577 .707 r
F P
0 g
s
.35026 .77886 m .36218 .27193 L .3492 .79016 L .707 .577 .707 r
F
.35661 .68484 m .36036 .7036 L p .36196 .71346 L .708 .578 .707 r
F P
0 g
s
.36094 .70815 m .35661 .68484 L p .36196 .71346 L .708 .578 .707 r
F P
0 g
s
.35651 .68471 m .35661 .68484 L p .35638 .68528 L .707 .577 .707 r
F P
0 g
s
.35919 .65726 m .35785 .64392 L p .35865 .64701 L .707 .577 .707 r
F P
0 g
s
.36632 .28068 m .35287 .70066 L p .36754 .71428 L .707 .577 .707 r
F P
0 g
s
.36632 .28068 m .36218 .27193 L p .3538 .62827 L .707 .577 .707 r
F P
0 g
s
.35504 .63306 m .36632 .28068 L p .3538 .62827 L .707 .577 .707 r
F P
0 g
s
.36218 .27193 m .37212 .26379 L p .34792 .74143 L .707 .577 .707 r
F P
0 g
s
.34581 .783 m .34732 .7361 L p .34792 .74143 L .707 .577 .707 r
F P
0 g
s
.34732 .7361 m .36218 .27193 L p .34792 .74143 L .707 .577 .707 r
F P
0 g
s
.3492 .79016 m .34996 .79175 L p .35026 .77886 L .707 .577 .707 r
F P
0 g
s
.34996 .79175 m .35043 .77708 L p .35026 .77886 L .707 .577 .707 r
F P
0 g
s
.36054 .77754 m .36156 .79518 L .35857 .7828 L p .707 .577 .707 r
F P
0 g
s
.35856 .78276 m .36054 .77754 L .35857 .7828 L .707 .577 .707 r
F
.34996 .79175 m .35983 .79646 L p .35746 .77094 L F P
0 g
s
.35753 .76512 m .36054 .77754 L p .35856 .78276 L .707 .577 .707 r
F P
0 g
s
.35856 .78277 m .35855 .78263 L p .35856 .78276 L .707 .577 .707 r
F P
0 g
s
.35855 .78263 m .35753 .76512 L p .35856 .78276 L .707 .577 .707 r
F P
0 g
s
.36762 .7428 m .36461 .72719 L .35666 .76223 L .707 .577 .707 r
F
.35746 .77094 m .35666 .76223 L .34996 .79175 L F
.36762 .7428 m .35666 .76223 L .35746 .77094 L F
.36778 .80025 m .36762 .7428 L .35746 .77094 L F
.35983 .79646 m .36778 .80025 L p .35746 .77094 L F P
0 g
s
.35857 .7828 m .35856 .78277 L p .35856 .78276 L .707 .577 .707 r
F P
0 g
s
.35855 .78263 m .35856 .78277 L .35783 .78214 L p .707 .577 .707 r
F P
0 g
s
.35043 .77708 m .34996 .79175 L p .3529 .77877 L .707 .577 .707 r
F P
0 g
s
.36461 .72719 m .35043 .77708 L .3529 .77877 L .707 .577 .707 r
F
.36754 .71428 m .36094 .70815 L .36461 .72719 L F
.36223 .71514 m .36094 .70815 L p .36196 .71346 L .708 .578 .707 r
F P
0 g
s
.3637 .7225 m .36223 .71514 L p .36196 .71346 L .708 .578 .707 r
F P
0 g
s
.36762 .7428 m .36754 .71428 L .36461 .72719 L .707 .577 .707 r
F
.35201 .70446 m .35365 .6764 L .35245 .68568 L F
.35287 .70066 m .35365 .6764 L p .35201 .70446 L F P
0 g
s
.35245 .68568 m .35504 .63306 L .3538 .62827 L .707 .577 .707 r
F
.35365 .6764 m .35504 .63306 L p .35245 .68568 L F P
0 g
s
.18099 .78768 m .17537 .75739 L .1621 .74139 L p .707 .577 .707 r
F P
0 g
s
.17537 .75739 m .18099 .78768 L .20248 .79935 L p .707 .577 .707 r
F P
0 g
s
.1736 .8235 m .17257 .80585 L .15989 .79489 L p .707 .577 .707 r
F P
0 g
s
.15408 .63191 m .15917 .68248 L .16237 .69734 L p .707 .577 .707 r
F P
0 g
s
.15917 .68248 m .15408 .63191 L .16082 .61654 L p .707 .577 .707 r
F P
0 g
s
.15989 .79489 m .16092 .81254 L .1736 .8235 L p .707 .577 .707 r
F P
0 g
s
.1621 .74139 m .16772 .77169 L .18099 .78768 L p .707 .577 .707 r
F P
0 g
s
.16772 .77169 m .1621 .74139 L .15835 .72263 L p .708 .578 .707 r
F P
0 g
s
.64992 .28441 m .63355 .79548 L .62941 .78673 L p .707 .577 .707 r
F P
0 g
s
.62941 .78673 m .64578 .27566 L .64992 .28441 L p .707 .577 .707 r
F P
0 g
s
.16092 .81254 m .15989 .79489 L .15688 .78248 L p .707 .577 .707 r
F P
0 g
s
.16591 .66712 m .16082 .61654 L .17686 .60217 L p .707 .577 .707 r
F P
0 g
s
.16082 .61654 m .16591 .66712 L .15917 .68248 L p .707 .577 .707 r
F P
0 g
s
.15688 .78248 m .15791 .80013 L .16092 .81254 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15835 .72263 m .16397 .75293 L .16772 .77169 L p .708 .578 .707 r
F P
0 g
s
.34127 .59378 m .34636 .64436 L .32515 .63469 L p .707 .577 .707 r
F P
0 g
s
.32515 .63469 m .32006 .58411 L .34127 .59378 L p .707 .577 .707 r
F P
0 g
s
.16397 .75293 m .15835 .72263 L .16449 .70293 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15791 .80013 m .15688 .78248 L .16384 .76983 L p .707 .577 .707 r
F P
0 g
s
.17686 .60217 m .18195 .65275 L .16591 .66712 L p .707 .577 .707 r
F P
0 g
s
.18195 .65275 m .17686 .60217 L .20061 .59021 L p .707 .577 .707 r
F P
0 g
s
.16384 .76983 m .16487 .78747 L .15791 .80013 L p .707 .577 .707 r
F P
0 g
s
.32006 .58411 m .32515 .63469 L .29764 .62919 L p .707 .577 .707 r
F P
0 g
s
.29764 .62919 m .29255 .57861 L .32006 .58411 L p .707 .577 .707 r
F P
0 g
s
.16449 .70293 m .17011 .73323 L .16397 .75293 L p .707 .577 .707 r
F P
0 g
s
.17011 .73323 m .16449 .70293 L .17992 .68424 L p .707 .577 .707 r
F P
0 g
s
.32747 .68748 m .32185 .65718 L .34334 .66885 L p .707 .577 .707 r
F P
0 g
s
.64578 .27566 m .62941 .78673 L .61159 .77823 L p .707 .577 .707 r
F P
0 g
s
.61159 .77823 m .62796 .26716 L .64578 .27566 L p .707 .577 .707 r
F P
0 g
s
.2057 .64078 m .20061 .59021 L .22975 .58182 L p .707 .577 .707 r
F P
0 g
s
.20061 .59021 m .2057 .64078 L .18195 .65275 L p .707 .577 .707 r
F P
0 g
s
.29255 .57861 m .29764 .62919 L .26652 .62839 L p .707 .577 .707 r
F P
0 g
s
.26652 .62839 m .26143 .57782 L .29255 .57861 L p .707 .577 .707 r
F P
0 g
s
.16487 .78747 m .16384 .76983 L .18009 .75817 L p .707 .577 .707 r
F P
0 g
s
.35575 .77486 m .37212 .26379 L .39517 .25706 L p .707 .577 .707 r
F P
0 g
s
.37212 .26379 m .35575 .77486 L .34581 .783 L p .707 .577 .707 r
F P
0 g
s
.23484 .63239 m .22975 .58182 L .26143 .57782 L p .707 .577 .707 r
F P
0 g
s
.22975 .58182 m .23484 .63239 L .2057 .64078 L p .707 .577 .707 r
F P
0 g
s
.26143 .57782 m .26652 .62839 L .23484 .63239 L p .707 .577 .707 r
F P
0 g
s
.17992 .68424 m .18554 .71454 L .17011 .73323 L p .707 .577 .707 r
F P
0 g
s
.18554 .71454 m .17992 .68424 L .20312 .66837 L p .707 .577 .707 r
F P
0 g
s
.32185 .65718 m .32747 .68748 L .29987 .6813 L p .707 .577 .707 r
F P
0 g
s
.29987 .6813 m .29425 .651 L .32185 .65718 L p .707 .577 .707 r
F P
0 g
s
.18009 .75817 m .18112 .77581 L .16487 .78747 L p .707 .577 .707 r
F P
0 g
s
.34485 .75417 m .34588 .77181 L .32477 .76339 L p .707 .577 .707 r
F P
0 g
s
.32477 .76339 m .32374 .74574 L .34485 .75417 L p .707 .577 .707 r
F P
0 g
s
.20874 .69867 m .20312 .66837 L .23182 .65688 L p .707 .577 .707 r
F P
0 g
s
.20312 .66837 m .20874 .69867 L .18554 .71454 L p .707 .577 .707 r
F P
0 g
s
.29425 .651 m .29987 .6813 L .26884 .68119 L p .707 .577 .707 r
F P
0 g
s
.26884 .68119 m .26322 .65089 L .29425 .651 L p .707 .577 .707 r
F P
0 g
s
.18112 .77581 m .18009 .75817 L .20403 .74865 L p .707 .577 .707 r
F P
0 g
s
.73525 .68425 m .73016 .63367 L .69904 .63288 L p .707 .577 .707 r
F P
0 g
s
.73016 .63367 m .73525 .68425 L .76694 .68025 L p .707 .577 .707 r
F P
0 g
s
.76694 .68025 m .76184 .62968 L .73016 .63367 L p .707 .577 .707 r
F P
0 g
s
.62796 .26716 m .61159 .77823 L .58184 .7708 L p .707 .577 .707 r
F P
0 g
s
.58184 .7708 m .5982 .25973 L .62796 .26716 L p .707 .577 .707 r
F P
0 g
s
.76184 .62968 m .76694 .68025 L .79608 .67186 L p .707 .577 .707 r
F P
0 g
s
.79608 .67186 m .79099 .62129 L .76184 .62968 L p .707 .577 .707 r
F P
0 g
s
.23744 .68718 m .23182 .65688 L .26322 .65089 L p .707 .577 .707 r
F P
0 g
s
.23182 .65688 m .23744 .68718 L .20874 .69867 L p .707 .577 .707 r
F P
0 g
s
.26322 .65089 m .26884 .68119 L .23744 .68718 L p .707 .577 .707 r
F P
0 g
s
.20403 .74865 m .20506 .76629 L .18112 .77581 L p .707 .577 .707 r
F P
0 g
s
.70413 .68346 m .69904 .63288 L .67153 .62738 L p .707 .577 .707 r
F P
0 g
s
.69904 .63288 m .70413 .68346 L .73525 .68425 L p .707 .577 .707 r
F P
0 g
s
.32374 .74574 m .32477 .76339 L .29729 .75831 L p .707 .577 .707 r
F P
0 g
s
.29729 .75831 m .29626 .74067 L .32374 .74574 L p .707 .577 .707 r
F P
0 g
s
.79099 .62129 m .79608 .67186 L .81983 .65989 L p .707 .577 .707 r
F P
0 g
s
.81983 .65989 m .81474 .60932 L .79099 .62129 L p .707 .577 .707 r
F P
0 g
s
.39517 .25706 m .37881 .76813 L .35575 .77486 L p .707 .577 .707 r
F P
0 g
s
.37881 .76813 m .39517 .25706 L .42907 .2524 L p .707 .577 .707 r
F P
0 g
s
.20506 .76629 m .20403 .74865 L .23333 .7422 L p .707 .577 .707 r
F P
0 g
s
.67662 .67796 m .67153 .62738 L .65032 .61771 L p .707 .577 .707 r
F P
0 g
s
.67153 .62738 m .67662 .67796 L .70413 .68346 L p .707 .577 .707 r
F P
0 g
s
.29626 .74067 m .29729 .75831 L .26614 .75709 L p .707 .577 .707 r
F P
0 g
s
.26614 .75709 m .26511 .73945 L .29626 .74067 L p .707 .577 .707 r
F P
0 g
s
.23333 .7422 m .23436 .75984 L .20506 .76629 L p .707 .577 .707 r
F P
0 g
s
.81474 .60932 m .81983 .65989 L .83586 .64552 L p .707 .577 .707 r
F P
0 g
s
.83586 .64552 m .83077 .59495 L .81474 .60932 L p .707 .577 .707 r
F P
0 g
s
.23436 .75984 m .23333 .7422 L .26511 .73945 L p .707 .577 .707 r
F P
0 g
s
.26511 .73945 m .26614 .75709 L .23436 .75984 L p .707 .577 .707 r
F P
0 g
s
.5982 .25973 m .58184 .7708 L .54306 .76518 L p .707 .577 .707 r
F P
0 g
s
.54306 .76518 m .55943 .25411 L .5982 .25973 L p .707 .577 .707 r
F P
0 g
s
.76533 .75999 m .7643 .74235 L .73252 .7451 L p .707 .577 .707 r
F P
0 g
s
.74133 .74515 m .73571 .71485 L .70468 .71475 L p .707 .577 .707 r
F P
0 g
s
.73571 .71485 m .74133 .74515 L .77273 .73917 L p .707 .577 .707 r
F P
0 g
s
.77273 .73917 m .76711 .70887 L .73571 .71485 L p .707 .577 .707 r
F P
0 g
s
.73355 .76274 m .73252 .7451 L .70137 .74388 L p .707 .577 .707 r
F P
0 g
s
.73252 .7451 m .73355 .76274 L .76533 .75999 L p .707 .577 .707 r
F P
0 g
s
.76711 .70887 m .77273 .73917 L .80143 .72768 L p .707 .577 .707 r
F P
0 g
s
.80143 .72768 m .79581 .69738 L .76711 .70887 L p .707 .577 .707 r
F P
0 g
s
.7643 .74235 m .76533 .75999 L .79463 .75354 L p .707 .577 .707 r
F P
0 g
s
.79463 .75354 m .7936 .7359 L .7643 .74235 L p .707 .577 .707 r
F P
0 g
s
.41271 .76347 m .42907 .2524 L .47051 .25026 L p .707 .577 .707 r
F P
0 g
s
.42907 .2524 m .41271 .76347 L .37881 .76813 L p .707 .577 .707 r
F P
0 g
s
.7024 .76152 m .70137 .74388 L .67389 .7388 L p .707 .577 .707 r
F P
0 g
s
.70137 .74388 m .7024 .76152 L .73355 .76274 L p .707 .577 .707 r
F P
0 g
s
.65541 .66828 m .65032 .61771 L .63749 .60481 L p .707 .577 .707 r
F P
0 g
s
.65032 .61771 m .65541 .66828 L .67662 .67796 L p .707 .577 .707 r
F P
0 g
s
.7103 .74505 m .70468 .71475 L .67708 .70856 L p .707 .577 .707 r
F P
0 g
s
.70468 .71475 m .7103 .74505 L .74133 .74515 L p .707 .577 .707 r
F P
0 g
s
.79581 .69738 m .80143 .72768 L .82463 .71181 L p .707 .577 .707 r
F P
0 g
s
.82463 .71181 m .81901 .68151 L .79581 .69738 L p .707 .577 .707 r
F P
0 g
s
.7936 .7359 m .79463 .75354 L .81857 .74402 L p .707 .577 .707 r
F P
0 g
s
.81857 .74402 m .81754 .72638 L .7936 .7359 L p .707 .577 .707 r
F P
0 g
s
.67389 .7388 m .67492 .75645 L .7024 .76152 L p .707 .577 .707 r
F P
0 g
s
.83077 .59495 m .83586 .64552 L .84261 .63016 L p .707 .577 .707 r
F P
0 g
s
.84261 .63016 m .83752 .57958 L .83077 .59495 L p .707 .577 .707 r
F P
0 g
s
.55943 .25411 m .54306 .76518 L .49906 .76192 L p .707 .577 .707 r
F P
0 g
s
.49906 .76192 m .51543 .25085 L .55943 .25411 L p .707 .577 .707 r
F P
0 g
s
.6827 .73886 m .67708 .70856 L .65559 .6969 L p .707 .577 .707 r
F P
0 g
s
.67708 .70856 m .6827 .73886 L .7103 .74505 L p .707 .577 .707 r
F P
0 g
s
.67492 .75645 m .67389 .7388 L .65278 .73038 L p .707 .577 .707 r
F P
0 g
s
.81901 .68151 m .82463 .71181 L .84006 .69311 L p .707 .577 .707 r
F P
0 g
s
.84006 .69311 m .83444 .66281 L .81901 .68151 L p .707 .577 .707 r
F P
0 g
s
.45415 .76133 m .47051 .25026 L .51543 .25085 L p .707 .577 .707 r
F P
0 g
s
.47051 .25026 m .45415 .76133 L .41271 .76347 L p .707 .577 .707 r
F P
0 g
s
.51543 .25085 m .49906 .76192 L .45415 .76133 L p .707 .577 .707 r
F P
0 g
s
.65278 .73038 m .65381 .74802 L .67492 .75645 L p .707 .577 .707 r
F P
0 g
s
.81754 .72638 m .81857 .74402 L .83482 .73236 L p .707 .577 .707 r
F P
0 g
s
.83482 .73236 m .83379 .71472 L .81754 .72638 L p .707 .577 .707 r
F P
0 g
s
.64258 .65539 m .63749 .60481 L .63429 .58995 L p .707 .577 .707 r
F P
0 g
s
.63749 .60481 m .64258 .65539 L .65541 .66828 L p .707 .577 .707 r
F P
0 g
s
.83752 .57958 m .84261 .63016 L .83941 .6153 L p .707 .577 .707 r
F P
0 g
s
.83941 .6153 m .83432 .56472 L .83752 .57958 L p .707 .577 .707 r
F P
0 g
s
.66121 .7272 m .65559 .6969 L .64232 .6809 L p .707 .577 .707 r
F P
0 g
s
.65559 .6969 m .66121 .7272 L .6827 .73886 L p .707 .577 .707 r
F P
0 g
s
.83444 .66281 m .84006 .69311 L .8462 .67341 L p .707 .577 .707 r
F P
0 g
s
.8462 .67341 m .84058 .64312 L .83444 .66281 L p .707 .577 .707 r
F P
0 g
s
.65381 .74802 m .65278 .73038 L .6401 .71942 L p .707 .577 .707 r
F P
0 g
s
.6401 .71942 m .64113 .73707 L .65381 .74802 L p .707 .577 .707 r
F P
0 g
s
.83379 .71472 m .83482 .73236 L .84178 .71971 L p .707 .577 .707 r
F P
0 g
s
.84178 .71971 m .84075 .70206 L .83379 .71472 L p .707 .577 .707 r
F P
0 g
s
.63429 .58995 m .63938 .64053 L .64258 .65539 L p .707 .577 .707 r
F P
0 g
s
.63938 .64053 m .63429 .58995 L .64104 .57459 L p .707 .577 .707 r
F P
0 g
s
.64232 .6809 m .64794 .7112 L .66121 .7272 L p .707 .577 .707 r
F P
0 g
s
.64794 .7112 m .64232 .6809 L .63857 .66214 L p .708 .578 .707 r
F P
0 g
s
.84058 .64312 m .8462 .67341 L .84245 .65465 L p .708 .578 .707 r
F P
0 g
s
.84245 .65465 m .83683 .62435 L .84058 .64312 L p .708 .578 .707 r
F P
0 g
s
.83432 .56472 m .83941 .6153 L .82658 .6024 L p .707 .577 .707 r
F P
0 g
s
.82658 .6024 m .82148 .55183 L .83432 .56472 L p .707 .577 .707 r
F P
0 g
s
.64113 .73707 m .6401 .71942 L .6371 .70701 L p .707 .577 .707 r
F P
0 g
s
.6371 .70701 m .63812 .72466 L .64113 .73707 L p .707 .577 .707 r
F P
0 g
s
.84075 .70206 m .84178 .71971 L .83877 .7073 L p .707 .577 .707 r
F P
0 g
s
.83877 .7073 m .83775 .68965 L .84075 .70206 L p .707 .577 .707 r
F P
0 g
s
.64613 .62516 m .64104 .57459 L .65707 .56022 L p .707 .577 .707 r
F P
0 g
s
.64104 .57459 m .64613 .62516 L .63938 .64053 L p .707 .577 .707 r
F P
0 g
s
.63857 .66214 m .64419 .69244 L .64794 .7112 L p .708 .578 .707 r
F P
0 g
s
.64419 .69244 m .63857 .66214 L .64471 .64245 L p .707 .577 .707 r
F P
0 g
s
.83683 .62435 m .84245 .65465 L .82918 .63866 L p .707 .577 .707 r
F P
0 g
s
.82918 .63866 m .82356 .60836 L .83683 .62435 L p .707 .577 .707 r
F P
0 g
s
.39224 .64743 m .38715 .59686 L .35603 .59607 L p .707 .577 .707 r
F P
0 g
s
.38715 .59686 m .39224 .64743 L .42393 .64344 L p .707 .577 .707 r
F P
0 g
s
.42393 .64344 m .41883 .59286 L .38715 .59686 L p .707 .577 .707 r
F P
0 g
s
.41883 .59286 m .42393 .64344 L .45307 .63505 L p .707 .577 .707 r
F P
0 g
s
.45307 .63505 m .44798 .58447 L .41883 .59286 L p .707 .577 .707 r
F P
0 g
s
.82148 .55183 m .82658 .6024 L .80537 .59273 L p .707 .577 .707 r
F P
0 g
s
.80537 .59273 m .80027 .54215 L .82148 .55183 L p .707 .577 .707 r
F P
0 g
s
.63812 .72466 m .6371 .70701 L .64406 .69435 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36112 .64664 m .35603 .59607 L .32852 .59057 L p .707 .577 .707 r
F P
0 g
s
.35603 .59607 m .36112 .64664 L .39224 .64743 L p .707 .577 .707 r
F P
0 g
s
.44798 .58447 m .45307 .63505 L .47682 .62308 L p .707 .577 .707 r
F P
0 g
s
.47682 .62308 m .47173 .5725 L .44798 .58447 L p .707 .577 .707 r
F P
0 g
s
.64406 .69435 m .64509 .712 L .63812 .72466 L p .707 .577 .707 r
F P
0 g
s
.65707 .56022 m .66216 .61079 L .64613 .62516 L p .707 .577 .707 r
F P
0 g
s
.66216 .61079 m .65707 .56022 L .68082 .54825 L p .707 .577 .707 r
F P
0 g
s
.83775 .68965 m .83877 .7073 L .82609 .69634 L p .707 .577 .707 r
F P
0 g
s
.82609 .69634 m .82507 .67869 L .83775 .68965 L p .707 .577 .707 r
F P
0 g
s
.64471 .64245 m .65033 .67274 L .64419 .69244 L p .707 .577 .707 r
F P
0 g
s
.65033 .67274 m .64471 .64245 L .66013 .62375 L p .707 .577 .707 r
F P
0 g
s
.33361 .64114 m .32852 .59057 L .30731 .58089 L p .707 .577 .707 r
F P
0 g
s
.32852 .59057 m .33361 .64114 L .36112 .64664 L p .707 .577 .707 r
F P
0 g
s
.82356 .60836 m .82918 .63866 L .80769 .627 L p .707 .577 .707 r
F P
0 g
s
.80769 .627 m .80207 .5967 L .82356 .60836 L p .707 .577 .707 r
F P
0 g
s
.80027 .54215 m .80537 .59273 L .77785 .58723 L p .707 .577 .707 r
F P
0 g
s
.77785 .58723 m .77276 .53665 L .80027 .54215 L p .707 .577 .707 r
F P
0 g
s
.47173 .5725 m .47682 .62308 L .49285 .60871 L p .707 .577 .707 r
F P
0 g
s
.49285 .60871 m .48776 .55813 L .47173 .5725 L p .707 .577 .707 r
F P
0 g
s
.64509 .712 m .64406 .69435 L .66031 .6827 L p .707 .577 .707 r
F P
0 g
s
.68591 .59882 m .68082 .54825 L .70996 .53986 L p .707 .577 .707 r
F P
0 g
s
.68082 .54825 m .68591 .59882 L .66216 .61079 L p .707 .577 .707 r
F P
0 g
s
.42232 .72318 m .42129 .70553 L .38951 .70828 L p .707 .577 .707 r
F P
0 g
s
.39832 .70834 m .3927 .67804 L .36167 .67793 L p .707 .577 .707 r
F P
0 g
s
.3927 .67804 m .39832 .70834 L .42972 .70235 L p .707 .577 .707 r
F P
0 g
s
.42972 .70235 m .4241 .67205 L .3927 .67804 L p .707 .577 .707 r
F P
0 g
s
.39054 .72593 m .38951 .70828 L .35836 .70706 L p .707 .577 .707 r
F P
0 g
s
.38951 .70828 m .39054 .72593 L .42232 .72318 L p .707 .577 .707 r
F P
0 g
s
.4241 .67205 m .42972 .70235 L .45842 .69086 L p .707 .577 .707 r
F P
0 g
s
.45842 .69086 m .4528 .66056 L .4241 .67205 L p .707 .577 .707 r
F P
0 g
s
.42129 .70553 m .42232 .72318 L .45162 .71673 L p .707 .577 .707 r
F P
0 g
s
.45162 .71673 m .45059 .69908 L .42129 .70553 L p .707 .577 .707 r
F P
0 g
s
.77276 .53665 m .77785 .58723 L .74674 .58644 L p .707 .577 .707 r
F P
0 g
s
.74674 .58644 m .74164 .53586 L .77276 .53665 L p .707 .577 .707 r
F P
0 g
s
.66031 .6827 m .66133 .70034 L .64509 .712 L p .707 .577 .707 r
F P
0 g
s
.66013 .62375 m .66575 .65405 L .65033 .67274 L p .707 .577 .707 r
F P
0 g
s
.66575 .65405 m .66013 .62375 L .68333 .60788 L p .707 .577 .707 r
F P
0 g
s
.80207 .5967 m .80769 .627 L .78008 .62081 L p .707 .577 .707 r
F P
0 g
s
.78008 .62081 m .77446 .59051 L .80207 .5967 L p .707 .577 .707 r
F P
0 g
s
.35939 .72471 m .35836 .70706 L .33088 .70199 L p .707 .577 .707 r
F P
0 g
s
.35836 .70706 m .35939 .72471 L .39054 .72593 L p .707 .577 .707 r
F P
0 g
s
.3124 .63147 m .30731 .58089 L .29448 .568 L p .707 .577 .707 r
F P
0 g
s
.30731 .58089 m .3124 .63147 L .33361 .64114 L p .707 .577 .707 r
F P
0 g
s
.36729 .70823 m .36167 .67793 L .33407 .67174 L p .707 .577 .707 r
F P
0 g
s
.36167 .67793 m .36729 .70823 L .39832 .70834 L p .707 .577 .707 r
F P
0 g
s
.4528 .66056 m .45842 .69086 L .48162 .67499 L p .707 .577 .707 r
F P
0 g
s
.48162 .67499 m .476 .64469 L .4528 .66056 L p .707 .577 .707 r
F P
0 g
s
.71505 .59043 m .70996 .53986 L .74164 .53586 L p .707 .577 .707 r
F P
0 g
s
.70996 .53986 m .71505 .59043 L .68591 .59882 L p .707 .577 .707 r
F P
0 g
s
.74164 .53586 m .74674 .58644 L .71505 .59043 L p .707 .577 .707 r
F P
0 g
s
.82507 .67869 m .82609 .69634 L .80498 .68791 L p .707 .577 .707 r
F P
0 g
s
.80498 .68791 m .80395 .67027 L .82507 .67869 L p .707 .577 .707 r
F P
0 g
s
.45059 .69908 m .45162 .71673 L .47556 .70721 L p .707 .577 .707 r
F P
0 g
s
.47556 .70721 m .47453 .68956 L .45059 .69908 L p .707 .577 .707 r
F P
0 g
s
.33088 .70199 m .33191 .71963 L .35939 .72471 L p .707 .577 .707 r
F P
0 g
s
.48776 .55813 m .49285 .60871 L .4996 .59334 L p .707 .577 .707 r
F P
0 g
s
.4996 .59334 m .49451 .54277 L .48776 .55813 L p .707 .577 .707 r
F P
0 g
s
.68895 .63818 m .68333 .60788 L .71204 .59639 L p .707 .577 .707 r
F P
0 g
s
.68333 .60788 m .68895 .63818 L .66575 .65405 L p .707 .577 .707 r
F P
0 g
s
.77446 .59051 m .78008 .62081 L .74906 .6207 L p .707 .577 .707 r
F P
0 g
s
.74906 .6207 m .74344 .5904 L .77446 .59051 L p .707 .577 .707 r
F P
0 g
s
.33969 .70204 m .33407 .67174 L .31258 .66008 L p .707 .577 .707 r
F P
0 g
s
.33407 .67174 m .33969 .70204 L .36729 .70823 L p .707 .577 .707 r
F P
0 g
s
.33191 .71963 m .33088 .70199 L .30977 .69356 L p .707 .577 .707 r
F P
0 g
s
.66133 .70034 m .66031 .6827 L .68425 .67317 L p .707 .577 .707 r
F P
0 g
s
.476 .64469 m .48162 .67499 L .49705 .65629 L p .707 .577 .707 r
F P
0 g
s
.49705 .65629 m .49143 .62599 L .476 .64469 L p .707 .577 .707 r
F P
0 g
s
.71766 .62669 m .71204 .59639 L .74344 .5904 L p .707 .577 .707 r
F P
0 g
s
.71204 .59639 m .71766 .62669 L .68895 .63818 L p .707 .577 .707 r
F P
0 g
s
.74344 .5904 m .74906 .6207 L .71766 .62669 L p .707 .577 .707 r
F P
0 g
s
.30977 .69356 m .3108 .71121 L .33191 .71963 L p .707 .577 .707 r
F P
0 g
s
.68425 .67317 m .68528 .69082 L .66133 .70034 L p .707 .577 .707 r
F P
0 g
s
.47453 .68956 m .47556 .70721 L .49181 .69555 L p .707 .577 .707 r
F P
0 g
s
.49181 .69555 m .49078 .6779 L .47453 .68956 L p .707 .577 .707 r
F P
0 g
s
.80395 .67027 m .80498 .68791 L .7775 .68284 L p .707 .577 .707 r
F P
0 g
s
.7775 .68284 m .77648 .6652 L .80395 .67027 L p .707 .577 .707 r
F P
0 g
s
.29957 .61857 m .29448 .568 L .29128 .55314 L p .707 .577 .707 r
F P
0 g
s
.29448 .568 m .29957 .61857 L .3124 .63147 L p .707 .577 .707 r
F P
0 g
s
.68528 .69082 m .68425 .67317 L .71354 .66672 L p .707 .577 .707 r
F P
0 g
s
.49451 .54277 m .4996 .59334 L .4964 .57848 L p .707 .577 .707 r
F P
0 g
s
.4964 .57848 m .49131 .52791 L .49451 .54277 L p .707 .577 .707 r
F P
0 g
s
.3182 .69038 m .31258 .66008 L .29931 .64409 L p .707 .577 .707 r
F P
0 g
s
.31258 .66008 m .3182 .69038 L .33969 .70204 L p .707 .577 .707 r
F P
0 g
s
.49143 .62599 m .49705 .65629 L .50319 .6366 L p .707 .577 .707 r
F P
0 g
s
.50319 .6366 m .49757 .6063 L .49143 .62599 L p .707 .577 .707 r
F P
0 g
s
.3108 .71121 m .30977 .69356 L .29709 .68261 L p .707 .577 .707 r
F P
0 g
s
.77648 .6652 m .7775 .68284 L .74635 .68162 L p .707 .577 .707 r
F P
0 g
s
.74635 .68162 m .74532 .66397 L .77648 .6652 L p .707 .577 .707 r
F P
0 g
s
.71354 .66672 m .71457 .68437 L .68528 .69082 L p .707 .577 .707 r
F P
0 g
s
.29709 .68261 m .29812 .70025 L .3108 .71121 L p .707 .577 .707 r
F P
0 g
s
.71457 .68437 m .71354 .66672 L .74532 .66397 L p .707 .577 .707 r
F P
0 g
s
.74532 .66397 m .74635 .68162 L .71457 .68437 L p .707 .577 .707 r
F P
0 g
s
.49078 .6779 m .49181 .69555 L .49877 .68289 L p .707 .577 .707 r
F P
0 g
s
.49877 .68289 m .49774 .66525 L .49078 .6779 L p .707 .577 .707 r
F P
0 g
s
.29128 .55314 m .29637 .60371 L .29957 .61857 L p .707 .577 .707 r
F P
0 g
s
.29637 .60371 m .29128 .55314 L .29803 .53777 L p .707 .577 .707 r
F P
0 g
s
.29931 .64409 m .30493 .67439 L .3182 .69038 L p .707 .577 .707 r
F P
0 g
s
.30493 .67439 m .29931 .64409 L .29556 .62532 L p .708 .578 .707 r
F P
0 g
s
.49757 .6063 m .50319 .6366 L .49944 .61784 L p .708 .578 .707 r
F P
0 g
s
.49944 .61784 m .49382 .58754 L .49757 .6063 L p .708 .578 .707 r
F P
0 g
s
.49131 .52791 m .4964 .57848 L .48357 .56559 L p .707 .577 .707 r
F P
0 g
s
.48357 .56559 m .47847 .51501 L .49131 .52791 L p .707 .577 .707 r
F P
0 g
s
.29812 .70025 m .29709 .68261 L .29409 .67019 L p .707 .577 .707 r
F P
0 g
s
.29409 .67019 m .29511 .68784 L .29812 .70025 L p .707 .577 .707 r
F P
0 g
s
.49774 .66525 m .49877 .68289 L .49576 .67048 L p .707 .577 .707 r
F P
0 g
s
.49576 .67048 m .49474 .65283 L .49774 .66525 L p .707 .577 .707 r
F P
0 g
s
.30312 .58834 m .29803 .53777 L .31406 .5234 L p .707 .577 .707 r
F P
0 g
s
.29803 .53777 m .30312 .58834 L .29637 .60371 L p .707 .577 .707 r
F P
0 g
s
.29556 .62532 m .30118 .65562 L .30493 .67439 L p .708 .578 .707 r
F P
0 g
s
.30118 .65562 m .29556 .62532 L .3017 .60563 L p .707 .577 .707 r
F P
0 g
s
.49382 .58754 m .49944 .61784 L .48617 .60184 L p .707 .577 .707 r
F P
0 g
s
.48617 .60184 m .48055 .57154 L .49382 .58754 L p .707 .577 .707 r
F P
0 g
s
.47847 .51501 m .48357 .56559 L .46236 .55591 L p .707 .577 .707 r
F P
0 g
s
.46236 .55591 m .45726 .50534 L .47847 .51501 L p .707 .577 .707 r
F P
0 g
s
.29511 .68784 m .29409 .67019 L .30105 .65754 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30105 .65754 m .30207 .67518 L .29511 .68784 L p .707 .577 .707 r
F P
0 g
s
.31406 .5234 m .31915 .57397 L .30312 .58834 L p .707 .577 .707 r
F P
0 g
s
.31915 .57397 m .31406 .5234 L .33781 .51143 L p .707 .577 .707 r
F P
0 g
s
.49474 .65283 m .49576 .67048 L .48308 .65952 L p .707 .577 .707 r
F P
0 g
s
.48308 .65952 m .48206 .64188 L .49474 .65283 L p .707 .577 .707 r
F P
0 g
s
.3017 .60563 m .30731 .63593 L .30118 .65562 L p .707 .577 .707 r
F P
0 g
s
.30731 .63593 m .3017 .60563 L .31712 .58693 L p .707 .577 .707 r
F P
0 g
s
.48055 .57154 m .48617 .60184 L .46468 .59018 L p .707 .577 .707 r
F P
0 g
s
.46468 .59018 m .45906 .55988 L .48055 .57154 L p .707 .577 .707 r
F P
0 g
s
.45726 .50534 m .46236 .55591 L .43484 .55041 L p .707 .577 .707 r
F P
0 g
s
.43484 .55041 m .42975 .49984 L .45726 .50534 L p .707 .577 .707 r
F P
0 g
s
.30207 .67518 m .30105 .65754 L .31729 .64588 L p .707 .577 .707 r
F P
0 g
s
.3429 .56201 m .33781 .51143 L .36695 .50304 L p .707 .577 .707 r
F P
0 g
s
.33781 .51143 m .3429 .56201 L .31915 .57397 L p .707 .577 .707 r
F P
0 g
s
.42975 .49984 m .43484 .55041 L .40372 .54962 L p .707 .577 .707 r
F P
0 g
s
.40372 .54962 m .39863 .49905 L .42975 .49984 L p .707 .577 .707 r
F P
0 g
s
.31729 .64588 m .31832 .66353 L .30207 .67518 L p .707 .577 .707 r
F P
0 g
s
.31712 .58693 m .32274 .61723 L .30731 .63593 L p .707 .577 .707 r
F P
0 g
s
.32274 .61723 m .31712 .58693 L .34032 .57106 L p .707 .577 .707 r
F P
0 g
s
.45906 .55988 m .46468 .59018 L .43707 .58399 L p .707 .577 .707 r
F P
0 g
s
.43707 .58399 m .43145 .55369 L .45906 .55988 L p .707 .577 .707 r
F P
0 g
s
.37204 .55362 m .36695 .50304 L .39863 .49905 L p .707 .577 .707 r
F P
0 g
s
.36695 .50304 m .37204 .55362 L .3429 .56201 L p .707 .577 .707 r
F P
0 g
s
.39863 .49905 m .40372 .54962 L .37204 .55362 L p .707 .577 .707 r
F P
0 g
s
.48206 .64188 m .48308 .65952 L .46197 .6511 L p .707 .577 .707 r
F P
0 g
s
.46197 .6511 m .46094 .63345 L .48206 .64188 L p .707 .577 .707 r
F P
0 g
s
.34594 .60136 m .34032 .57106 L .36903 .55957 L p .707 .577 .707 r
F P
0 g
s
.34032 .57106 m .34594 .60136 L .32274 .61723 L p .707 .577 .707 r
F P
0 g
s
.43145 .55369 m .43707 .58399 L .40605 .58389 L p .707 .577 .707 r
F P
0 g
s
.40605 .58389 m .40043 .55359 L .43145 .55369 L p .707 .577 .707 r
F P
0 g
s
.31832 .66353 m .31729 .64588 L .34124 .63636 L p .707 .577 .707 r
F P
0 g
s
.37464 .58987 m .36903 .55957 L .40043 .55359 L p .707 .577 .707 r
F P
0 g
s
.36903 .55957 m .37464 .58987 L .34594 .60136 L p .707 .577 .707 r
F P
0 g
s
.40043 .55359 m .40605 .58389 L .37464 .58987 L p .707 .577 .707 r
F P
0 g
s
.34124 .63636 m .34226 .65401 L .31832 .66353 L p .707 .577 .707 r
F P
0 g
s
.46094 .63345 m .46197 .6511 L .43449 .64603 L p .707 .577 .707 r
F P
0 g
s
.43449 .64603 m .43347 .62838 L .46094 .63345 L p .707 .577 .707 r
F P
0 g
s
.34226 .65401 m .34124 .63636 L .37053 .62991 L p .707 .577 .707 r
F P
0 g
s
.43347 .62838 m .43449 .64603 L .40334 .64481 L p .707 .577 .707 r
F P
0 g
s
.40334 .64481 m .40231 .62716 L .43347 .62838 L p .707 .577 .707 r
F P
0 g
s
.37053 .62991 m .37156 .64755 L .34226 .65401 L p .707 .577 .707 r
F P
0 g
s
.37156 .64755 m .37053 .62991 L .40231 .62716 L p .707 .577 .707 r
F P
0 g
s
.40231 .62716 m .40334 .64481 L .37156 .64755 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol007Moob8008Aoo`00Lgoo10000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH015YF3000N7oo001_Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP03FUH7001aOol006]oo`@00003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001_Ool006Uoo`8000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP04001J
EUYFFUH3001/Ool006Moo`<000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP<006Uoo`00IWoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEP00001WOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P00IGoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
Hgoo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001UOol20002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEP000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aoo`80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo0P000UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IGoo001TOol01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001T
Ool01000FUH000001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001TOol01000
FUH000001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUH000001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUH000001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF2000
00=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP000eYF10000UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol00`00FUIJEP040006FUH00`00FUIJEP06FUH01000FUIJEUYF1P0035YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH000002UYF00<005YFFUH02eYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001OOol40005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001MOol200000eYF001JEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005]oo`8000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00FGoo
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001HOol20006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001VOol005Ioo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol005Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001DOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00005goo3`00@7oo001DOol00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000AOol60004
FUH00`00FUIJEP06FUH00`00FUH00003000lOol005=oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF
0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000=Ool400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000hOol005=oo`8000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000:Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00002000eOol0059oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH?0006FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000027oo0`001eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<goo001BOol01000FUIJ
EP0015YF00<005YFFUH015YF00<005YFFUH015YF1P0000=JEP0000002`0000=JEP0000000P000UYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Ioo`80009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP80039oo`00DWoo00@005YFFUH000AJEP03001J
EUYF00AJEP03001JEUYF00@000=JEP@0009JEP03001JEUYF00IJEP03001JEP0000<00003FUH00000
008000AJEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000Aoo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEP00035oo`00DWoo00@005YFFUH000AJEP03001J
EUYF00AJEP@0009JEP@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP@00006FUH00000001JEP00
0UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000goo00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUH0031oo`00DWoo00@005YFFUH000AJEP03001JEUYF009J
EP80009oo`06001JEP00001JEP002EYF00<005YFFUH01UYF00<005YFFUH015YF0`000eYF0P000UYF
0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0Woo0P001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00D005YFFUIJEP0002moo`00Dgoo00<005YF000015YF00<005YFFUH00P000goo0`00
0eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`000UYF00H005YF
FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01`00FUH007oo001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP05001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP<000=oo`8000MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH01@00FUH005YF000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP05001JEUYFFUH0000_Ool005=oo`03001JEP0000AJEP04001oogooOol30008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200001UYF00000000FUH000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYFFUH2000^Ool004Ioo`h0009JEP04001JEUYF0003Ool01000FUIJEP0025YF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00P005YF000005YF001JEP0035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
FUH00P00;Woo0010Ool60004FUH00`00FUIJEP06FUH01P00FUIJEP00FUH0009oo`8000AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<00004
FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH00`00FUIJEP02000^Ool003aoo`@00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF009JEQ4000AJEP03001JEUYF009JEP04
001JEP00FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02000^Ool003Uoo`<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00800003FUH0000000IJEP03001JEUYF00IJEPD000MJEP04001JEUYFFUH400000eYF0000
00040004FUH01@00FUIJEP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF1P0000=oo`0000003P000eYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo000gOol30007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH015YF0P000eYF00<005YFFUH00eYF1`001EYF
00<005YFFUH00eYF0P000UYF00D005YFFUH005YF008000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEP<000=oo`@0009J
EP03001JEUYF00IJEP03001JEP0000H000EJEP05001JEUYFFUH0000^Ool003Eoo`80009JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEP00FUH00002FUH00`00FUIJEP05FUH0
1000FUIJEUYF3@0015YF00<005YFFUH01EYF00<005YFFUH015YF0P000UYF00@005YF001JEP8000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEP000080009oo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP800003Ool0000000=J
EP05001JEUYFFUH0000^Ool003=oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP80009JEP04001JEUYF0007FUH01000FUH0000025YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF100000EJEP00001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP8000=oo`800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP<00005Ool00000FUH00003FUH00`00Oomoo`0/Ool0039oo`03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001J
EUYF00AJEP800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP05
001JEUYF001JEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00@005YFFUIJEP80009oo`<000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00800003Ool0000000=JEP03001oogoo02aoo`00<Goo0P001UYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P001EYF00<005YFFUH00UYF0P000eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00T005YFFUIJEP00
FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJ
EP04001JEP000002Ool20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0P0000AJEP00FUIJEP8002eoo`00;goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P001EYF00<005YFFUH00P001EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00H005YFFUIJEP00FUH2000=FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP0015YF0P000Woo0`001eYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000`00;Goo000^Ool0
1@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF0`00
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJ
EP@000aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH01@00
Oomoogoo00000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF0`0000=JEP000000;Goo000]Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YF000005YF00<0
00aJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF008000=oo`05
001JEUYFFUH00008FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH300000eYF0000000]Ool002aoo`8000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEP0000=JEP05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20003FUH3000<FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH200000eYF000000050004FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH=0006FUH00`00FUIJEP02FUH01000FUH005YF0P00;Goo000/Ool20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH010002goo1P000UYF00<005YF
FUH00UYF00H005YFFUH005YF000]Ool002]oo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEPh00005FUH005YFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH?
0003FUH01000FUIJEUYF0P001EYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF00=JEP800004FUH00000FUH20007FUH00`00FUIJEP04FUH4000<Ool30003FUH00`00FUIJ
EP030005FUH01@00FUH005YF0000;Goo000[Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YF
FUH015YF1P003Goo00<005YFFUH00P001EYF00<005YFFUH01EYF200015YF00<005YFFUH01UYF00<0
05YF00000`0000=JEP0000001UYF0P000UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0`000UYF00<005YF00001eYF00<005YFFUH00UYF0`002Goo1P001UYF00<005YFFUH0
0eYF0P000eYF00D005YF001JEP0002eoo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001J
EUYF009JEP8001=oo`05001JEUYF001oo`020003FUH00`00FUH000050003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH40004FUH00`00FUH00003FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000UYF00@005YFFUH000IJEP03001J
EP00008000=JEPT000AJEP03001JEUYF00IJEP03001JEUYF00AJEP800005FUH005YFFUH0000^Ool0
02]oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUH00002000EOol01000FUIJEP000goo0P00
00EJEP00001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00
00800005FUH005YFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01P00FUH00000FUH000=JEP03001JEUYF00AJEP800003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000002FUH00`00Oomoo`0/Ool002]oo`04
001JEUYF0004FUH00`00FUIJEP03FUH3000IOol00eYF001oo`04Ool20003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUIJ
EP002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<0
05YFFUH00eYF00D005YFFUIJEP0000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP07001JEUYFFUH005YF0000;Woo000/Ool00`00FUH00004FUH01000FUIJEUYF0P0077oo00=JEP00
Ool00Woo0P001EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF0P0000AJ
EP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00008000AJ
EP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00@005YF000001io
o`03FUH007oo00<000IJEP03001JEUYF009JEP`000AJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00=JEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001EYF00@005YF000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00800003FUH007oo02aoo`00;7oo00<005YF000015YF0P004Goo
4P000UYF00<005YFFUH00eYF1`001EYF00<005YFFUH01eYF00<005YFFUH025YF100015YF00<005YF
FUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P001EYF
0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
001oo`<002eoo`00;7oo00@005YFFUH0009JEP03001oogoo00aoo`D000AJEP03001JEUYF00IJEP03
001JEP0000AJEP04001JEUYFFUH20003FUH01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF0P000UYF0`0000AJEP00FUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00008000EJEP03001JEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP80009oo`03001JEP0002eoo`00;7oo00H005YFFUH005YF000=Ool3
0008FUH00`00FUIJEP06FUH30004FUH01P00FUH00000FUH000=JEP04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30002FUH00`00FUH0000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEUYF00000UYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00L007ooOomo
o`00FUH0000]Ool002aoo`03001JEUYF00@000Yoo`80009JEP03001JEUYF00MJEP03001JEUYF00IJ
EP8000AJEP80009JEP8000=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30007
FUH01000FUH005YF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000UYF00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEPT00003FUH005YF00MJEP03
001JEUYF009JEP8000Aoo`03001JEP0002eoo`00;7oo00<005YFFUH00P000UYF0P001Woo0P001EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF00@005YF0000009JEP800003FUH00000
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00EJEP03
001JEP0000@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009J
EP03001JEP0000EJEP03001JEUYF00AJEP03001JEP0000D000AJEP03001JEUYF009JEPP0009JEP03
001JEUYF008000Eoo`80009JEP03001oogoo02Yoo`00;7oo00<005YFFUH00P0015YF1P001eYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YF001JEP<0009JEP8000=JEP<0009JEP03001JEUYF00=J
EP03001JEUYF00MJEP04001JEUYFFUH20005FUH00`00FUIJEP04FUH20002FUH3000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40004FUH00`00FUIJEP02FUH4
00000eYF001JEP07FUH00`00FUIJEP06FUH01000FUIJEUYF1@001Woo00<005YF00000UYF00<007oo
Ool0:Woo000]Ool015YF001JEP001EYF100025YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF
0000009JEP03001JEUYF009JEPH0009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000MJEP03001J
EUYF00AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1P00FUH00000FUH000=oo`<00003FUH0000000<000EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00EJEP<000=oo`04001JEUYF0002FUH00`00Oomoo`0ZOol002eoo`04FUH005YF0005FUH0
1000FUIJEP0025YF00<005YFFUH01eYF00<005YFFUH015YF00L005YF001JEP00FUH00004FUH01000
FUIJEUYF4P0015YF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP06001JEP00001JEP001Woo0P0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`000eYF00@005YFFUH0
02aoo`00;Goo00@005YFFUH000=JEP8000AJEP03001JEUYF00IJEP03001JEUYF00AJEPd00003FUH0
000000AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000IJEP03001JEUYF00IJEP03001JEUYF009J
EP04001JEUYFFUH200000eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01P00FUH00000FUH000Aoo`8000=JEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001J
EUYF00EJEP03001JEUYF009JEP8000=JEP8002eoo`00;Goo00@005YFFUH0009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00@000IJEP03001JEUYF0080009JEP800003FUH005YF00=JEP03
001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03001JEUYF00IJEP04001JEP000002FUH200000eYF
001JEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003
Ool20005FUH00`00FUIJEP04FUH<0003Ool80004FUH00`00FUIJEP03FUH20002FUH2000]Ool002eo
o`80009JEP<000IJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00<0009JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00IJEP8000=JEP04001JEUYFFUH2
00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
00000goo00000006FUH00`00FUIJEP04000GOol50005FUH00`00FUH00003000]Ool002eoo`80009J
EP03001JEP0000IJEP03001JEUYF00=JEP8000EJEP03001JEUYF00IJEP03001JEUYF00800004FUH0
0000FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH20002FUH2
0004FUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000
FUH005YF0`0000=JEP00FUH015YF20006goo0`000eYF00D005YFFUIJEP0002ioo`00;Woo00<005YF
00000UYF00<005YFFUH01EYF00<005YF00000P001eYF00<005YFFUH01UYF00<005YFFUH00P000eYF
0P0000=JEP0000000UYF00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH00eYF0P00
00IJEP00000005YF0004FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YF001JEP0000=JEP04001JEUYFFUH20004FUH01000FUH000006Woo00@005YFFUIJ
EP800003FUH005YF009JEP03001oogoo02aoo`00;Woo0P000eYF00<005YFFUH01EYF0P0000=JEP00
FUH01eYF00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEP0000@00003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000D000AJEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020003FUH00`00
FUH000030004FUH01000FUH0000067oo0P001UYF0P000eYF00<007ooOol0;7oo000^Ool00`00FUIJ
EP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEP000eYF
00<005YFFUH00UYF1@001UYF00<005YFFUH01UYF00<005YFFUH015YF1P000UYF00<005YFFUH015YF
00<005YF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000P000eYF0P000eYF0P0015YF0`005Woo0P0000=JEP00FUH01EYF00<005YF00000UYF
00<007ooOol0;7oo000^Ool00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEP0000D0009JEP03001JEUYF
00IJEP03001JEUYF00H000IJEP03001JEUYF00AJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJEP020003FUH20002
FUH00`00FUH0000COol30003FUH00`00FUIJEP05FUH00`00FUH00002000^Ool002ioo`03001JEUYF
00=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH0
0`00FUIJEP03FUH@0003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF100015YF0`0000MJEP00
001JEP00FUH0000?Ool40006FUH00`00FUIJEP05FUH200000goo0000000^Ool002eoo`03001JEP00
00AJEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<000MJEP03001J
EUYF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF
001JEP04FUH00`00FUH00005000<Ool40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000Ool0
05YF0P00;Goo000]Ool00`00FUH00004FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH20002Ool300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH000000UYF00<005YF000015YF00<005YFFUH00eYF3P001UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000Woo00@005YFFUH002eoo`00;Goo00<005YF00000eYF00<007ooOol0
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P001goo0`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00<005YF
FUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF00<005YFFUH00P000goo0P000UYF00<0
07ooOol0:goo000]Ool00`00FUH00002FUH00`00Oomoo`04Ool40002FUH00`00FUIJEP06FUH30002
FUH6000=Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70006FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH000000eYF0P00
1EYF00<005YFFUH015YF00<005YFFUH01EYF1@001EYF00<005YFFUH01UYF0`000goo0P0000AJEP00
FUH002ioo`00;Goo00H005YFFUH005YF000:Ool@000EOol00`00FUH0000?00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
1000FUH005YF0P0000=JEP0000001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<005YF
FUH01EYF00@007ooOomoo`8000AJEP8002ioo`00;Goo00<005YFFUH00P005Goo1@005Woo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP000002FUH200000eYF00000003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP03FUH20002Ool200000eYF001JEP03
FUH00`00Oomoo`0]Ool002eoo`04001JEUYF000FOol5000FOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P0000AJEP00FUIJEP<0009JEP80009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool20003FUH00`00FUIJEP02FUH00`00Oomoo`0]
Ool002eoo`04001JEUYF000GOol3000FOol20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUH005YF00000UYF00<005YFFUH00P000UYF0`001UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF000007oo00<000EJEP03001JEUYF0080031oo`00;Woo00=JEP00Ool05Woo
3`002Woo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000UYF00<005YF000015YF20000eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH0
1EYF0`00<Woo000^Ool00eYF001oo`0>Ool80004FUH00`00FUIJEP06FUH00`00FUH000030004Ool3
00001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000eYF0P001EYF
00@005YFFUIJEQT000EJEP03001JEUYF00=JEP8003Aoo`00;Woo00=JEP00Ool027oo1P000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00<005YF00000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP8003Ioo`00;Woo
00<005YF00001Woo0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YF00000P0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000AJEP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEP00000hOol002ioo`03001JEP0000Aoo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000@000=oo`800003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP<003Yoo`00;Woo0P0000=JEP00Ool00P001EYF00<005YF
FUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH00eYF00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000Uoo`D000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00@003eoo`00;Woo0P0000AJEP00000000IJEP03001JEUYF009JEPP000moo`@0009JEP03001J
EUYF00=JEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP04FUHH0006FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000>OolI0011Ool002moo`80009JEP03001J
EUYF00=JEPH001Aoo`<000=JEPD000AJEP04001JEUYF0005FUH00`00FUIJEP03FUH<000<FUH00`00
FUIJEP08FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000@Ool20002FUH00`00
Oomoo`1AOol002ioo`03001JEUYF009JEP04001JEUYFFUH2000FOol40007FUH01000FUIJEUYF0`00
00EJEP00FUIJEP0000AJEPP000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0
009JEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000moo`03001JEP00009JEP03001oogoo
055oo`00;Goo0P0015YF00<005YF00000P0000=JEP0000000P002goo1`000UYF00<005YFFUH01UYF
00<005YFFUH015YF0P000UYF00<005YF00000P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YF00000`001UYF00<005YFFUH00UYF00<005YF00003Woo
00@005YFFUH0009JEP03001oogoo055oo`00;Goo0P0015YF0P000UYF00<005YFFUH00eYF3`001EYF
00<005YFFUH01UYF00<005YFFUH00eYF00<007oo00000UYF0P0000=JEP00FUH01eYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF10000UYF00<0
05YFFUH00UYF00<005YF00003Goo00D005YFFUIJEP00009JEP03001oogoo055oo`00;7oo00<005YF
00000UYF0P001EYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol010000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1@000eYF00<005YF0000100027oo00<005YF
FUH00eYF0P00E7oo000/Ool00`00FUH0000200000goo00000004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH50006FUH00`00FUIJEP06FUH01000FUH000000goo0P0000EJEP00001JEP0000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP8000=J
EP800003FUH005YF008000=JEPT000EJEP8005Aoo`00;7oo00<005YF000017oo00<005YFFUH00UYF
00<005YFFUH01EYF00<005YFFUH01EYF0`001eYF00<005YFFUH01UYF0P001Goo0P0015YF00<005YF
FUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF0P001EYF0P0000=JEP0000001eYF00<005YF00000P001EYF00<007ooOol0Dgoo000/Ool2
0006Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH2
0007Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH000020007FUH00`00
FUIJEP02FUH20003FUH00`00Oomoo`1COol002aoo`8000Qoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20009Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUH000020007FUH00`00FUIJEP03FUH200000eYF001oo`1EOol002aoo`8000Uoo`<000IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00008000Uoo`800006FUH00000001JEP0025YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH01@0015YF00<005YFFUH00eYF00@005YF000005Ioo`00;7oo0`00
2Woo0P001UYF00<005YFFUH01UYF00<005YFFUH015YF10002goo00@005YFFUIJEP800003Ool00000
008000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00IJEP03001JEUYF00AJEP<000=oo`P000AJEP04001JEUYF001FOol002aoo`800003FUH00000
00Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00@000eoo`8000AJEP8000Eoo`@0009JEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00AJEP<0009JEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000=oo`8000AJEP04001JEUYFFUH300000eYF001JEP02FUH00`00Oomoo`1C
Ool002aoo`8000=JEP8000aoo`h000ioo`<00003FUH005YF00=JEP03001oogoo00Qoo`D000QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00P000IJ
EP03001JEUYF00AJEP8000=JEP03001oogoo05=oo`00;Goo00H005YFFUIJEP00FUH3000QOol40004
FUH01@00FUIJEUYF000047oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH00eYF200015YF00<005YFFUH01UYF00<005YFFUH015YF0P000UYF00<007ooOol0Dgoo
000]Ool01@00FUIJEUYF000015YF1@0067oo10000UYF00<005YFFUH015YF00<005YF00005goo2000
1UYF00<005YFFUH02UYF00<005YFFUH01UYF2@000UYF1@001EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000Woo00<005YF0000EGoo000^Ool01000FUIJEP001EYF00@005YFFUIJEPP000Uoo`L000IJ
EP03001JEUYF00AJEP80021ooa`000=JEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP03001J
EUYF008000Eoo`8005Eoo`00;goo0`001EYF00<005YFFUH015YF00<005YFFUH00UYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00;Goo00<005YF000010001EYF00<005YFFUH015YF00<005YF
FUH01EYF1@001EYF00<005YFFUH01UYF0`001goo0P00EGoo000aOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003000_Ool00`00FUH00003
Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30007FUH00`00FUIJEP04FUH20008Ool01000
FUH00000E7oo000cOol300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH3000cOol20006Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2000:Ool01000FUIJEP00E7oo000fOol50004FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04000fOol20008Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00002000;Ool20002FUH00`00Oomoo`1BOol003]oo`T000AJEP03001JEUYF009J
EPL003Yoo`8000Yoo`<000EJEP03001JEUYF00IJEP03001JEUYF00AJEP@000aoo`800004FUH005YF
001EOol004Aoo`T0045oo`04001JEP00000;Ool400000eYF001JEP07FUH00`00FUIJEP04000>Ool2
0004FUH2001EOol008ioo`80009JEP03001oogoo00aoo`d0011oo`800003FUH005YF00=JEP03001o
ogoo05Aoo`00Sgoo00<005YFFUH00`009goo0P000eYF00<005YFFUH00UYF00<007ooOol0E7oo002?
Ool01000FUIJEP000UYF0P008Woo0`001EYF00<005YFFUH00P00Egoo002@Ool00`00FUH00004FUH5
000IOol400000eYF001JEP05FUH3001IOol0095oo`8000EJEP04001JEUYFFUHI0005FUH00`00FUIJ
EP03FUH2001KOol0099oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH2001MOol009=oo`8000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00001OOol009Eoo`800003FUH005YF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0065oo`00Ugoo1@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000I7oo002LOolI001XOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]33\[InvisibleSpace]"     "\
\[InvisibleSpace]10.591178425646612`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 33, "     ", 10.591178425646612, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59923 .74887 m .59019 .69311 L .55943 .69639 L p .707 .577 .707 r
F P
0 g
s
.59019 .69311 m .59923 .74887 L .63069 .74342 L p .707 .577 .707 r
F P
0 g
s
.63069 .74342 m .62164 .68766 L .59019 .69311 L p .707 .577 .707 r
F P
0 g
s
.62164 .68766 m .63069 .74342 L .65977 .73633 L p .707 .577 .707 r
F P
0 g
s
.65977 .73633 m .65072 .68058 L .62164 .68766 L p .707 .577 .707 r
F P
0 g
s
.56848 .75215 m .55943 .69639 L .5324 .69718 L p .707 .577 .707 r
F P
0 g
s
.55943 .69639 m .56848 .75215 L .59923 .74887 L p .707 .577 .707 r
F P
0 g
s
.65072 .68058 m .65977 .73633 L .68363 .7283 L p .707 .577 .707 r
F P
0 g
s
.68363 .7283 m .67458 .67255 L .65072 .68058 L p .707 .577 .707 r
F P
0 g
s
.60372 .79731 m .59173 .76112 L .56226 .76961 L p .707 .577 .707 r
F P
0 g
s
.59173 .76112 m .60372 .79731 L .63402 .78716 L p .707 .577 .707 r
F P
0 g
s
.63402 .78716 m .62203 .75097 L .59173 .76112 L p .707 .577 .707 r
F P
0 g
s
.62203 .75097 m .63402 .78716 L .66218 .77634 L p .707 .577 .707 r
F P
0 g
s
.66218 .77634 m .65019 .74014 L .62203 .75097 L p .707 .577 .707 r
F P
0 g
s
.5324 .69718 m .54144 .75294 L .56848 .75215 L p .707 .577 .707 r
F P
0 g
s
.56226 .76961 m .57425 .8058 L .60372 .79731 L p .707 .577 .707 r
F P
0 g
s
.54144 .75294 m .5324 .69718 L .51172 .6954 L p .707 .577 .707 r
F P
0 g
s
.57425 .8058 m .56226 .76961 L .5365 .77562 L p .707 .577 .707 r
F P
0 g
s
.65019 .74014 m .66218 .77634 L .68546 .76591 L p .707 .577 .707 r
F P
0 g
s
.68546 .76591 m .67346 .72972 L .65019 .74014 L p .707 .577 .707 r
F P
0 g
s
.5365 .77562 m .54849 .81181 L .57425 .8058 L p .707 .577 .707 r
F P
0 g
s
.67458 .67255 m .68363 .7283 L .69993 .72011 L p .707 .577 .707 r
F P
0 g
s
.69993 .72011 m .69088 .66436 L .67458 .67255 L p .707 .577 .707 r
F P
0 g
s
.59451 .83483 m .58896 .81663 L .55924 .82434 L p .707 .577 .707 r
F P
0 g
s
.58896 .81663 m .59451 .83483 L .62503 .82538 L p .707 .577 .707 r
F P
0 g
s
.62503 .82538 m .61948 .80718 L .58896 .81663 L p .707 .577 .707 r
F P
0 g
s
.61948 .80718 m .62503 .82538 L .65338 .81512 L p .707 .577 .707 r
F P
0 g
s
.65338 .81512 m .64782 .79691 L .61948 .80718 L p .707 .577 .707 r
F P
0 g
s
.51172 .6954 m .52077 .75116 L .54144 .75294 L p .707 .577 .707 r
F P
0 g
s
.55924 .82434 m .56479 .84255 L .59451 .83483 L p .707 .577 .707 r
F P
0 g
s
.56479 .84255 m .55924 .82434 L .53323 .82957 L p .707 .577 .707 r
F P
0 g
s
.54849 .81181 m .5365 .77562 L .51698 .77854 L p .707 .577 .707 r
F P
0 g
s
.64782 .79691 m .65338 .81512 L .67676 .80505 L p .707 .577 .707 r
F P
0 g
s
.67676 .80505 m .67121 .78684 L .64782 .79691 L p .707 .577 .707 r
F P
0 g
s
.53323 .82957 m .53879 .84777 L .56479 .84255 L p .707 .577 .707 r
F P
0 g
s
.67346 .72972 m .68546 .76591 L .70156 .75689 L p .707 .577 .707 r
F P
0 g
s
.70156 .75689 m .68956 .7207 L .67346 .72972 L p .707 .577 .707 r
F P
0 g
s
.52077 .75116 m .51172 .6954 L .49943 .69123 L p .707 .577 .707 r
F P
0 g
s
.51698 .77854 m .52897 .81473 L .54849 .81181 L p .707 .577 .707 r
F P
0 g
s
.69088 .66436 m .69993 .72011 L .70708 .71257 L p .707 .577 .707 r
F P
0 g
s
.70708 .71257 m .69803 .65681 L .69088 .66436 L p .707 .577 .707 r
F P
0 g
s
.49943 .69123 m .50847 .74698 L .52077 .75116 L p .707 .577 .707 r
F P
0 g
s
.53879 .84777 m .53323 .82957 L .51349 .83179 L p .707 .577 .707 r
F P
0 g
s
.51349 .83179 m .51904 .84999 L .53879 .84777 L p .707 .577 .707 r
F P
0 g
s
.67121 .78684 m .67676 .80505 L .6929 .79616 L p .707 .577 .707 r
F P
0 g
s
.6929 .79616 m .68735 .77795 L .67121 .78684 L p .707 .577 .707 r
F P
0 g
s
.52897 .81473 m .51698 .77854 L .50561 .7781 L p .707 .577 .707 r
F P
0 g
s
.68956 .7207 m .70156 .75689 L .70891 .75018 L p .707 .577 .707 r
F P
0 g
s
.70891 .75018 m .69692 .71399 L .68956 .7207 L p .707 .577 .707 r
F P
0 g
s
.50561 .7781 m .5176 .81429 L .52897 .81473 L p .707 .577 .707 r
F P
0 g
s
.50847 .74698 m .49943 .69123 L .49673 .68507 L p .707 .577 .707 r
F P
0 g
s
.51904 .84999 m .51349 .83179 L .50194 .83079 L p .707 .577 .707 r
F P
0 g
s
.69803 .65681 m .70708 .71257 L .70438 .70641 L p .707 .577 .707 r
F P
0 g
s
.70438 .70641 m .69533 .65065 L .69803 .65681 L p .707 .577 .707 r
F P
0 g
s
.50194 .83079 m .50749 .84899 L .51904 .84999 L p .707 .577 .707 r
F P
0 g
s
.49673 .68507 m .50577 .74082 L .50847 .74698 L p .707 .577 .707 r
F P
0 g
s
.68735 .77795 m .6929 .79616 L .70021 .78931 L p .707 .577 .707 r
F P
0 g
s
.70021 .78931 m .69466 .77111 L .68735 .77795 L p .707 .577 .707 r
F P
0 g
s
.47009 .82194 m .50205 .32458 L .45813 .31907 L p .707 .577 .707 r
F P
0 g
s
.5176 .81429 m .50561 .7781 L .50349 .77433 L p .707 .577 .707 r
F P
0 g
s
.50349 .77433 m .51548 .81052 L .5176 .81429 L p .707 .577 .707 r
F P
0 g
s
.50577 .74082 m .49673 .68507 L .50388 .67752 L p .707 .577 .707 r
F P
0 g
s
.50388 .67752 m .51292 .73328 L .50577 .74082 L p .707 .577 .707 r
F P
0 g
s
.51548 .81052 m .50349 .77433 L .51085 .76761 L p .707 .577 .707 r
F P
0 g
s
.51085 .76761 m .52284 .80381 L .51548 .81052 L p .707 .577 .707 r
F P
0 g
s
.51292 .73328 m .50388 .67752 L .52018 .66933 L p .707 .577 .707 r
F P
0 g
s
.50749 .84899 m .50194 .83079 L .49971 .82667 L p .707 .577 .707 r
F P
0 g
s
.49971 .82667 m .50527 .84487 L .50749 .84899 L p .707 .577 .707 r
F P
0 g
s
.50527 .84487 m .49971 .82667 L .50702 .81982 L p .707 .577 .707 r
F P
0 g
s
.50702 .81982 m .51258 .83803 L .50527 .84487 L p .707 .577 .707 r
F P
0 g
s
.52284 .80381 m .51085 .76761 L .52695 .7586 L p .707 .577 .707 r
F P
0 g
s
.51258 .83803 m .50702 .81982 L .52316 .81093 L p .707 .577 .707 r
F P
0 g
s
.50205 .32458 m .47009 .82194 L .51495 .8234 L p .707 .577 .707 r
F P
0 g
s
.52018 .66933 m .52922 .72509 L .51292 .73328 L p .707 .577 .707 r
F P
0 g
s
.52922 .72509 m .52018 .66933 L .54404 .6613 L p .707 .577 .707 r
F P
0 g
s
.51495 .8234 m .54691 .32603 L .50205 .32458 L p .707 .577 .707 r
F P
0 g
s
.52695 .7586 m .53894 .79479 L .52284 .80381 L p .707 .577 .707 r
F P
0 g
s
.54404 .6613 m .55308 .71706 L .52922 .72509 L p .707 .577 .707 r
F P
0 g
s
.52316 .81093 m .52872 .82914 L .51258 .83803 L p .707 .577 .707 r
F P
0 g
s
.55308 .71706 m .54404 .6613 L .57312 .65422 L p .707 .577 .707 r
F P
0 g
s
.53894 .79479 m .52695 .7586 L .55022 .74817 L p .707 .577 .707 r
F P
0 g
s
.55022 .74817 m .56221 .78436 L .53894 .79479 L p .707 .577 .707 r
F P
0 g
s
.57312 .65422 m .58216 .70997 L .55308 .71706 L p .707 .577 .707 r
F P
0 g
s
.52872 .82914 m .52316 .81093 L .54655 .80086 L p .707 .577 .707 r
F P
0 g
s
.54655 .80086 m .5521 .81907 L .52872 .82914 L p .707 .577 .707 r
F P
0 g
s
.56221 .78436 m .55022 .74817 L .57838 .73735 L p .707 .577 .707 r
F P
0 g
s
.5521 .81907 m .54655 .80086 L .57489 .7906 L p .707 .577 .707 r
F P
0 g
s
.57489 .7906 m .58044 .80881 L .5521 .81907 L p .707 .577 .707 r
F P
0 g
s
.54691 .32603 m .51495 .8234 L .55637 .82065 L p .707 .577 .707 r
F P
0 g
s
.55637 .82065 m .58832 .32329 L .54691 .32603 L p .707 .577 .707 r
F P
0 g
s
.42617 .81643 m .45813 .31907 L .41945 .31004 L p .707 .577 .707 r
F P
0 g
s
.45813 .31907 m .42617 .81643 L .47009 .82194 L p .707 .577 .707 r
F P
0 g
s
.69692 .71399 m .70891 .75018 L .70679 .74641 L p .707 .577 .707 r
F P
0 g
s
.70679 .74641 m .6948 .71022 L .69692 .71399 L p .707 .577 .707 r
F P
0 g
s
.58216 .70997 m .57312 .65422 L .60458 .64876 L p .707 .577 .707 r
F P
0 g
s
.60458 .64876 m .61362 .70452 L .58216 .70997 L p .707 .577 .707 r
F P
0 g
s
.57838 .73735 m .59037 .77354 L .56221 .78436 L p .707 .577 .707 r
F P
0 g
s
.59037 .77354 m .57838 .73735 L .60868 .7272 L p .707 .577 .707 r
F P
0 g
s
.58044 .80881 m .57489 .7906 L .60541 .78115 L p .707 .577 .707 r
F P
0 g
s
.60541 .78115 m .61097 .79935 L .58044 .80881 L p .707 .577 .707 r
F P
0 g
s
.58832 .32329 m .55637 .82065 L .59028 .81397 L p .707 .577 .707 r
F P
0 g
s
.60868 .7272 m .62067 .76339 L .59037 .77354 L p .707 .577 .707 r
F P
0 g
s
.59028 .81397 m .62224 .31661 L .58832 .32329 L p .707 .577 .707 r
F P
0 g
s
.69533 .65065 m .70438 .70641 L .69208 .70223 L p .707 .577 .707 r
F P
0 g
s
.69208 .70223 m .68304 .64648 L .69533 .65065 L p .707 .577 .707 r
F P
0 g
s
.69466 .77111 m .70021 .78931 L .69798 .78519 L p .707 .577 .707 r
F P
0 g
s
.69798 .78519 m .69243 .76699 L .69466 .77111 L p .707 .577 .707 r
F P
0 g
s
.3875 .8074 m .41945 .31004 L .38981 .29838 L p .707 .577 .707 r
F P
0 g
s
.41945 .31004 m .3875 .8074 L .42617 .81643 L p .707 .577 .707 r
F P
0 g
s
.25622 .7029 m .24718 .64715 L .21643 .65043 L p .707 .577 .707 r
F P
0 g
s
.24718 .64715 m .25622 .7029 L .28768 .69745 L p .707 .577 .707 r
F P
0 g
s
.28768 .69745 m .27863 .6417 L .24718 .64715 L p .707 .577 .707 r
F P
0 g
s
.27863 .6417 m .28768 .69745 L .31676 .69037 L p .707 .577 .707 r
F P
0 g
s
.31676 .69037 m .30771 .63461 L .27863 .6417 L p .707 .577 .707 r
F P
0 g
s
.6948 .71022 m .70679 .74641 L .69542 .74597 L p .707 .577 .707 r
F P
0 g
s
.69542 .74597 m .68343 .70978 L .6948 .71022 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22547 .70618 m .21643 .65043 L .18939 .65122 L p .707 .577 .707 r
F P
0 g
s
.21643 .65043 m .22547 .70618 L .25622 .7029 L p .707 .577 .707 r
F P
0 g
s
.30771 .63461 m .31676 .69037 L .34062 .68233 L p .707 .577 .707 r
F P
0 g
s
.34062 .68233 m .33157 .62658 L .30771 .63461 L p .707 .577 .707 r
F P
0 g
s
.63533 .64548 m .64437 .70124 L .61362 .70452 L p .707 .577 .707 r
F P
0 g
s
.61362 .70452 m .60458 .64876 L .63533 .64548 L p .707 .577 .707 r
F P
0 g
s
.62067 .76339 m .60868 .7272 L .63815 .7187 L p .707 .577 .707 r
F P
0 g
s
.63513 .77343 m .64069 .79164 L .61097 .79935 L p .707 .577 .707 r
F P
0 g
s
.61097 .79935 m .60541 .78115 L .63513 .77343 L p .707 .577 .707 r
F P
0 g
s
.62224 .31661 m .59028 .81397 L .61338 .80402 L p .707 .577 .707 r
F P
0 g
s
.61338 .80402 m .64534 .30666 L .62224 .31661 L p .707 .577 .707 r
F P
0 g
s
.18939 .65122 m .19843 .70697 L .22547 .70618 L p .707 .577 .707 r
F P
0 g
s
.68304 .64648 m .69208 .70223 L .67141 .70045 L p .707 .577 .707 r
F P
0 g
s
.67141 .70045 m .66236 .6447 L .68304 .64648 L p .707 .577 .707 r
F P
0 g
s
.26071 .76465 m .24872 .72845 L .21925 .73695 L p .707 .577 .707 r
F P
0 g
s
.24872 .72845 m .26071 .76465 L .29101 .75449 L p .707 .577 .707 r
F P
0 g
s
.29101 .75449 m .27902 .7183 L .24872 .72845 L p .707 .577 .707 r
F P
0 g
s
.27902 .7183 m .29101 .75449 L .31918 .74367 L p .707 .577 .707 r
F P
0 g
s
.31918 .74367 m .30719 .70748 L .27902 .7183 L p .707 .577 .707 r
F P
0 g
s
.69243 .76699 m .69798 .78519 L .68643 .78419 L p .707 .577 .707 r
F P
0 g
s
.68643 .78419 m .68088 .76599 L .69243 .76699 L p .707 .577 .707 r
F P
0 g
s
.19843 .70697 m .18939 .65122 L .16871 .64944 L p .707 .577 .707 r
F P
0 g
s
.21925 .73695 m .23124 .77314 L .26071 .76465 L p .707 .577 .707 r
F P
0 g
s
.34788 .61839 m .35692 .67415 L .35854 .67244 L p .707 .577 .707 r
F P
0 g
s
.35854 .67244 m .36407 .6666 L p .35838 .64965 L .707 .577 .707 r
F P
0 g
s
.35838 .64965 m .34788 .61839 L .35854 .67244 L .707 .577 .707 r
F
.3721 .28523 m .36805 .27187 L p .35711 .472 L F P
0 g
s
.33157 .62658 m .34062 .68233 L .35692 .67415 L p .707 .577 .707 r
F P
0 g
s
.35692 .67415 m .34788 .61839 L .33157 .62658 L p .707 .577 .707 r
F P
0 g
s
.33046 .69705 m .34245 .73324 L .35855 .72423 L p .707 .577 .707 r
F P
0 g
s
.35855 .72423 m .34656 .68804 L .33046 .69705 L p .707 .577 .707 r
F P
0 g
s
.36407 .6666 m .35502 .61085 L .34788 .61839 L p .707 .577 .707 r
F P
0 g
s
.3282 .76356 m .33375 .78177 L .34989 .77288 L p .707 .577 .707 r
F P
0 g
s
.34989 .77288 m .34434 .75467 L .3282 .76356 L p .707 .577 .707 r
F P
0 g
s
.34908 .65627 m .34003 .60051 L .35232 .60469 L p .707 .577 .707 r
F P
0 g
s
.34656 .68804 m .35855 .72423 L .3659 .71751 L p .707 .577 .707 r
F P
0 g
s
.3659 .71751 m .35391 .68132 L .34656 .68804 L p .707 .577 .707 r
F P
0 g
s
.35241 .7133 m .34763 .69887 L p .35179 .67756 L .707 .577 .707 r
F P
0 g
s
.34763 .69887 m .34042 .67711 L .35174 .67755 L p .707 .577 .707 r
F P
0 g
s
.35174 .67755 m .35179 .67756 L p .34763 .69887 L .707 .577 .707 r
F P
0 g
s
.34003 .60051 m .34908 .65627 L .3284 .65449 L p .707 .577 .707 r
F P
0 g
s
.34245 .73324 m .33046 .69705 L .30719 .70748 L p .707 .577 .707 r
F P
0 g
s
.34042 .67711 m .34763 .69887 L p .33289 .71623 L .707 .577 .707 r
F P
0 g
s
.34763 .69887 m .35241 .7133 L .34606 .71425 L p .707 .577 .707 r
F P
0 g
s
.34606 .71425 m .33289 .71623 L p .34763 .69887 L .707 .577 .707 r
F P
0 g
s
.30719 .70748 m .31918 .74367 L .34245 .73324 L p .707 .577 .707 r
F P
0 g
s
.34434 .75467 m .34989 .77288 L .3572 .76604 L p .707 .577 .707 r
F P
0 g
s
.3572 .76604 m .35165 .74783 L .34434 .75467 L p .707 .577 .707 r
F P
0 g
s
.34342 .76091 m .33787 .74271 L .34942 .74371 L p .707 .577 .707 r
F P
0 g
s
.33787 .74271 m .34342 .76091 L .32368 .76313 L p .707 .577 .707 r
F P
0 g
s
.32368 .76313 m .31813 .74493 L .33787 .74271 L p .707 .577 .707 r
F P
0 g
s
.36805 .27187 m .33609 .76923 L .33937 .78005 L p .707 .577 .707 r
F P
0 g
s
.33937 .78005 m .34014 .78259 L p .34133 .76078 L .707 .577 .707 r
F P
0 g
s
.34133 .76078 m .36805 .27187 L .33937 .78005 L .707 .577 .707 r
F
.34357 .7199 m .35741 .5138 L .35711 .472 L F
.34014 .78259 m .34447 .71522 L p .34357 .7199 L F P
0 g
s
.34447 .71522 m .35741 .5138 L p .34357 .7199 L .707 .577 .707 r
F P
0 g
s
.35741 .5138 m .3721 .28523 L p .35711 .472 L .707 .577 .707 r
F P
0 g
s
.35502 .61085 m .36407 .6666 L .36137 .66044 L p .707 .577 .707 r
F P
0 g
s
.35391 .68132 m .3659 .71751 L .36378 .71375 L p .707 .577 .707 r
F P
0 g
s
.36378 .71375 m .35179 .67756 L .35391 .68132 L p .707 .577 .707 r
F P
0 g
s
.35179 .67756 m .36378 .71375 L .35805 .71352 L p .707 .577 .707 r
F P
0 g
s
.35805 .71352 m .35241 .7133 L p .35222 .70253 L .707 .577 .707 r
F P
0 g
s
.35222 .70253 m .35179 .67756 L .35805 .71352 L .707 .577 .707 r
F
.35785 .79574 m .3875 .8074 L p .38767 .76935 L F P
0 g
s
.38981 .29838 m .36259 .72207 L p .38767 .76935 L .707 .577 .707 r
F P
0 g
s
.36259 .72207 m .35785 .79574 L p .38767 .76935 L .707 .577 .707 r
F P
0 g
s
.35785 .79574 m .38981 .29838 L .3721 .28523 L p .707 .577 .707 r
F P
0 g
s
.23124 .77314 m .21925 .73695 L .19349 .74295 L p .707 .577 .707 r
F P
0 g
s
.19349 .74295 m .20548 .77914 L .23124 .77314 L p .707 .577 .707 r
F P
0 g
s
.16871 .64944 m .17776 .70519 L .19843 .70697 L p .707 .577 .707 r
F P
0 g
s
.68343 .70978 m .69542 .74597 L .6759 .74889 L p .707 .577 .707 r
F P
0 g
s
.6759 .74889 m .66391 .7127 L .68343 .70978 L p .707 .577 .707 r
F P
0 g
s
.2515 .81155 m .24595 .79335 L .21623 .80106 L p .707 .577 .707 r
F P
0 g
s
.24595 .79335 m .2515 .81155 L .28203 .8021 L p .707 .577 .707 r
F P
0 g
s
.28203 .8021 m .27647 .7839 L .24595 .79335 L p .707 .577 .707 r
F P
0 g
s
.27647 .7839 m .28203 .8021 L .31037 .79184 L p .707 .577 .707 r
F P
0 g
s
.31037 .79184 m .30481 .77363 L .27647 .7839 L p .707 .577 .707 r
F P
0 g
s
.21623 .80106 m .22178 .81927 L .2515 .81155 L p .707 .577 .707 r
F P
0 g
s
.66236 .6447 m .67141 .70045 L .64437 .70124 L p .707 .577 .707 r
F P
0 g
s
.64437 .70124 m .63533 .64548 L .66236 .6447 L p .707 .577 .707 r
F P
0 g
s
.20548 .77914 m .19349 .74295 L .17397 .74587 L p .707 .577 .707 r
F P
0 g
s
.17776 .70519 m .16871 .64944 L .15642 .64526 L p .707 .577 .707 r
F P
0 g
s
.22178 .81927 m .21623 .80106 L .19023 .80629 L p .707 .577 .707 r
F P
0 g
s
.30481 .77363 m .31037 .79184 L .33375 .78177 L p .707 .577 .707 r
F P
0 g
s
.33375 .78177 m .3282 .76356 L .30481 .77363 L p .707 .577 .707 r
F P
0 g
s
.19023 .80629 m .19578 .82449 L .22178 .81927 L p .707 .577 .707 r
F P
0 g
s
.68088 .76599 m .68643 .78419 L .66669 .78641 L p .707 .577 .707 r
F P
0 g
s
.66669 .78641 m .66114 .76821 L .68088 .76599 L p .707 .577 .707 r
F P
0 g
s
.17397 .74587 m .18596 .78206 L .20548 .77914 L p .707 .577 .707 r
F P
0 g
s
.63815 .7187 m .65014 .75489 L .62067 .76339 L p .707 .577 .707 r
F P
0 g
s
.64534 .30666 m .61338 .80402 L .62339 .79176 L p .707 .577 .707 r
F P
0 g
s
.62339 .79176 m .65535 .2944 L .64534 .30666 L p .707 .577 .707 r
F P
0 g
s
.15642 .64526 m .16547 .70102 L .17776 .70519 L p .707 .577 .707 r
F P
0 g
s
.66391 .7127 m .6759 .74889 L .65014 .75489 L p .707 .577 .707 r
F P
0 g
s
.65014 .75489 m .63815 .7187 L .66391 .7127 L p .707 .577 .707 r
F P
0 g
s
.36137 .66044 m .35232 .60469 L .35502 .61085 L p .707 .577 .707 r
F P
0 g
s
.35232 .60469 m .36137 .66044 L .34908 .65627 L p .707 .577 .707 r
F P
0 g
s
.35165 .74783 m .3572 .76604 L .35498 .76191 L p .707 .577 .707 r
F P
0 g
s
.35498 .76191 m .34942 .74371 L .35165 .74783 L p .707 .577 .707 r
F P
0 g
s
.34942 .74371 m .35498 .76191 L .34342 .76091 L p .707 .577 .707 r
F P
0 g
s
.3721 .28523 m .34014 .78259 L .35785 .79574 L p .707 .577 .707 r
F P
0 g
s
.19578 .82449 m .19023 .80629 L .17048 .80851 L p .707 .577 .707 r
F P
0 g
s
.17048 .80851 m .17604 .82671 L .19578 .82449 L p .707 .577 .707 r
F P
0 g
s
.18596 .78206 m .17397 .74587 L .1626 .74543 L p .707 .577 .707 r
F P
0 g
s
.16547 .70102 m .15642 .64526 L .15372 .6391 L p .707 .577 .707 r
F P
0 g
s
.66114 .76821 m .66669 .78641 L .64069 .79164 L p .707 .577 .707 r
F P
0 g
s
.64069 .79164 m .63513 .77343 L .66114 .76821 L p .707 .577 .707 r
F P
0 g
s
.1626 .74543 m .17459 .78162 L .18596 .78206 L p .707 .577 .707 r
F P
0 g
s
.15372 .6391 m .16276 .69486 L .16547 .70102 L p .707 .577 .707 r
F P
0 g
s
.17604 .82671 m .17048 .80851 L .15893 .80751 L p .707 .577 .707 r
F P
0 g
s
.15893 .80751 m .16448 .82571 L .17604 .82671 L p .707 .577 .707 r
F P
0 g
s
.65535 .2944 m .62339 .79176 L .61934 .7784 L p .707 .577 .707 r
F P
0 g
s
.61934 .7784 m .6513 .28104 L .65535 .2944 L p .707 .577 .707 r
F P
0 g
s
.17459 .78162 m .1626 .74543 L .16048 .74167 L p .707 .577 .707 r
F P
0 g
s
.16048 .74167 m .17248 .77786 L .17459 .78162 L p .707 .577 .707 r
F P
0 g
s
.16276 .69486 m .15372 .6391 L .16087 .63156 L p .707 .577 .707 r
F P
0 g
s
.33609 .76923 m .36805 .27187 L .37806 .25961 L p .707 .577 .707 r
F P
0 g
s
.16087 .63156 m .16991 .68731 L .16276 .69486 L p .707 .577 .707 r
F P
0 g
s
.16448 .82571 m .15893 .80751 L .1567 .80339 L p .707 .577 .707 r
F P
0 g
s
.1567 .80339 m .16226 .82159 L .16448 .82571 L p .707 .577 .707 r
F P
0 g
s
.17248 .77786 m .16048 .74167 L .16784 .73495 L p .707 .577 .707 r
F P
0 g
s
.16991 .68731 m .16087 .63156 L .17717 .62337 L p .707 .577 .707 r
F P
0 g
s
.6513 .28104 m .61934 .7784 L .60163 .76525 L p .707 .577 .707 r
F P
0 g
s
.60163 .76525 m .63359 .26789 L .6513 .28104 L p .707 .577 .707 r
F P
0 g
s
.16784 .73495 m .17983 .77114 L .17248 .77786 L p .707 .577 .707 r
F P
0 g
s
.3284 .65449 m .31935 .59873 L .34003 .60051 L p .707 .577 .707 r
F P
0 g
s
.17717 .62337 m .18621 .67912 L .16991 .68731 L p .707 .577 .707 r
F P
0 g
s
.34611 .75697 m .37806 .25961 L .40116 .24966 L p .707 .577 .707 r
F P
0 g
s
.37806 .25961 m .34611 .75697 L .33609 .76923 L p .707 .577 .707 r
F P
0 g
s
.16226 .82159 m .1567 .80339 L .16401 .79654 L p .707 .577 .707 r
F P
0 g
s
.16401 .79654 m .16957 .81475 L .16226 .82159 L p .707 .577 .707 r
F P
0 g
s
.17983 .77114 m .16784 .73495 L .18394 .72594 L p .707 .577 .707 r
F P
0 g
s
.18621 .67912 m .17717 .62337 L .20103 .61534 L p .707 .577 .707 r
F P
0 g
s
.33289 .71623 m .3209 .68004 L .34042 .67711 L p .707 .577 .707 r
F P
0 g
s
.18394 .72594 m .19593 .76213 L .17983 .77114 L p .707 .577 .707 r
F P
0 g
s
.31935 .59873 m .3284 .65449 L .30136 .65527 L p .707 .577 .707 r
F P
0 g
s
.30136 .65527 m .29232 .59952 L .31935 .59873 L p .707 .577 .707 r
F P
0 g
s
.20103 .61534 m .21007 .67109 L .18621 .67912 L p .707 .577 .707 r
F P
0 g
s
.63359 .26789 m .60163 .76525 L .57199 .75359 L p .707 .577 .707 r
F P
0 g
s
.57199 .75359 m .60395 .25622 L .63359 .26789 L p .707 .577 .707 r
F P
0 g
s
.16957 .81475 m .16401 .79654 L .18015 .78765 L p .707 .577 .707 r
F P
0 g
s
.21007 .67109 m .20103 .61534 L .23011 .60825 L p .707 .577 .707 r
F P
0 g
s
.18015 .78765 m .18571 .80586 L .16957 .81475 L p .707 .577 .707 r
F P
0 g
s
.40116 .24966 m .3692 .74702 L .34611 .75697 L p .707 .577 .707 r
F P
0 g
s
.3692 .74702 m .40116 .24966 L .43507 .24298 L p .707 .577 .707 r
F P
0 g
s
.29232 .59952 m .30136 .65527 L .27061 .65855 L p .707 .577 .707 r
F P
0 g
s
.27061 .65855 m .26157 .6028 L .29232 .59952 L p .707 .577 .707 r
F P
0 g
s
.19593 .76213 m .18394 .72594 L .20721 .71551 L p .707 .577 .707 r
F P
0 g
s
.3209 .68004 m .33289 .71623 L .30713 .72223 L p .707 .577 .707 r
F P
0 g
s
.30713 .72223 m .29514 .68604 L .3209 .68004 L p .707 .577 .707 r
F P
0 g
s
.20721 .71551 m .2192 .7517 L .19593 .76213 L p .707 .577 .707 r
F P
0 g
s
.23915 .664 m .23011 .60825 L .26157 .6028 L p .707 .577 .707 r
F P
0 g
s
.23011 .60825 m .23915 .664 L .21007 .67109 L p .707 .577 .707 r
F P
0 g
s
.26157 .6028 m .27061 .65855 L .23915 .664 L p .707 .577 .707 r
F P
0 g
s
.73643 .65683 m .72739 .60108 L .69664 .60436 L p .707 .577 .707 r
F P
0 g
s
.72739 .60108 m .73643 .65683 L .76789 .65138 L p .707 .577 .707 r
F P
0 g
s
.76789 .65138 m .75885 .59563 L .72739 .60108 L p .707 .577 .707 r
F P
0 g
s
.75885 .59563 m .76789 .65138 L .79697 .64429 L p .707 .577 .707 r
F P
0 g
s
.79697 .64429 m .78793 .58854 L .75885 .59563 L p .707 .577 .707 r
F P
0 g
s
.70568 .66011 m .69664 .60436 L .6696 .60514 L p .707 .577 .707 r
F P
0 g
s
.69664 .60436 m .70568 .66011 L .73643 .65683 L p .707 .577 .707 r
F P
0 g
s
.18571 .80586 m .18015 .78765 L .20354 .77758 L p .707 .577 .707 r
F P
0 g
s
.2192 .7517 m .20721 .71551 L .23537 .70469 L p .707 .577 .707 r
F P
0 g
s
.60395 .25622 m .57199 .75359 L .53331 .74456 L p .707 .577 .707 r
F P
0 g
s
.53331 .74456 m .56527 .2472 L .60395 .25622 L p .707 .577 .707 r
F P
0 g
s
.20354 .77758 m .20909 .79579 L .18571 .80586 L p .707 .577 .707 r
F P
0 g
s
.78793 .58854 m .79697 .64429 L .82083 .63626 L p .707 .577 .707 r
F P
0 g
s
.82083 .63626 m .81179 .58051 L .78793 .58854 L p .707 .577 .707 r
F P
0 g
s
.29514 .68604 m .30713 .72223 L .27766 .73072 L p .707 .577 .707 r
F P
0 g
s
.27766 .73072 m .26567 .69453 L .29514 .68604 L p .707 .577 .707 r
F P
0 g
s
.31813 .74493 m .32368 .76313 L .29768 .76836 L p .707 .577 .707 r
F P
0 g
s
.29768 .76836 m .29212 .75015 L .31813 .74493 L p .707 .577 .707 r
F P
0 g
s
.23537 .70469 m .24736 .74088 L .2192 .7517 L p .707 .577 .707 r
F P
0 g
s
.74092 .70527 m .72893 .66908 L .69946 .67758 L p .707 .577 .707 r
F P
0 g
s
.72893 .66908 m .74092 .70527 L .77123 .69512 L p .707 .577 .707 r
F P
0 g
s
.77123 .69512 m .75923 .65893 L .72893 .66908 L p .707 .577 .707 r
F P
0 g
s
.40312 .74034 m .43507 .24298 L .47649 .24023 L p .707 .577 .707 r
F P
0 g
s
.43507 .24298 m .40488 .71293 L p .3692 .74702 L .707 .577 .707 r
F P
0 g
s
.47649 .24023 m .44453 .7376 L .40312 .74034 L p .707 .577 .707 r
F P
0 g
s
.38592 .63642 m .39791 .67261 L .41836 .66575 L p .707 .577 .707 r
F P
0 g
s
.41836 .66575 m .42822 .66245 L p .42064 .65779 L .707 .577 .707 r
F P
0 g
s
.42064 .65779 m .38592 .63642 L .41836 .66575 L .707 .577 .707 r
F
.40488 .71293 m .40312 .74034 L .39668 .74161 L p F P
0 g
s
.39668 .74161 m .3692 .74702 L p .40488 .71293 L .707 .577 .707 r
F P
0 g
s
.75923 .65893 m .77123 .69512 L .79939 .6843 L p .707 .577 .707 r
F P
0 g
s
.79939 .6843 m .7874 .64811 L .75923 .65893 L p .707 .577 .707 r
F P
0 g
s
.6696 .60514 m .67865 .6609 L .70568 .66011 L p .707 .577 .707 r
F P
0 g
s
.24736 .74088 m .23537 .70469 L .26567 .69453 L p .707 .577 .707 r
F P
0 g
s
.26567 .69453 m .27766 .73072 L .24736 .74088 L p .707 .577 .707 r
F P
0 g
s
.69946 .67758 m .71145 .71377 L .74092 .70527 L p .707 .577 .707 r
F P
0 g
s
.67865 .6609 m .6696 .60514 L .64892 .60336 L p .707 .577 .707 r
F P
0 g
s
.71145 .71377 m .69946 .67758 L .67371 .68358 L p .707 .577 .707 r
F P
0 g
s
.20909 .79579 m .20354 .77758 L .23188 .76732 L p .707 .577 .707 r
F P
0 g
s
.7874 .64811 m .79939 .6843 L .82266 .67387 L p .707 .577 .707 r
F P
0 g
s
.82266 .67387 m .81067 .63768 L .7874 .64811 L p .707 .577 .707 r
F P
0 g
s
.29212 .75015 m .29768 .76836 L .26796 .77607 L p .707 .577 .707 r
F P
0 g
s
.26796 .77607 m .2624 .75787 L .29212 .75015 L p .707 .577 .707 r
F P
0 g
s
.56527 .2472 m .53331 .74456 L .4894 .73905 L p .707 .577 .707 r
F P
0 g
s
.4894 .73905 m .52135 .24169 L .56527 .2472 L p .707 .577 .707 r
F P
0 g
s
.23188 .76732 m .23743 .78553 L .20909 .79579 L p .707 .577 .707 r
F P
0 g
s
.67371 .68358 m .6857 .71977 L .71145 .71377 L p .707 .577 .707 r
F P
0 g
s
.81179 .58051 m .82083 .63626 L .83713 .62807 L p .707 .577 .707 r
F P
0 g
s
.83713 .62807 m .82809 .57232 L .81179 .58051 L p .707 .577 .707 r
F P
0 g
s
.73172 .74279 m .72616 .72459 L .69644 .7323 L p .707 .577 .707 r
F P
0 g
s
.72616 .72459 m .73172 .74279 L .76224 .73334 L p .707 .577 .707 r
F P
0 g
s
.76224 .73334 m .75669 .71514 L .72616 .72459 L p .707 .577 .707 r
F P
0 g
s
.75669 .71514 m .76224 .73334 L .79058 .72308 L p .707 .577 .707 r
F P
0 g
s
.79058 .72308 m .78503 .70487 L .75669 .71514 L p .707 .577 .707 r
F P
0 g
s
.4506 .64323 m .47649 .24023 L p .45717 .65598 L .707 .577 .707 r
F P
0 g
s
.41584 .54966 m .42203 .58784 L p .45396 .59833 L .707 .577 .707 r
F P
0 g
s
.42203 .58784 m .42488 .60541 L .4304 .60407 L p .707 .577 .707 r
F P
0 g
s
.4304 .60407 m .45396 .59833 L p .42203 .58784 L .707 .577 .707 r
F P
0 g
s
.47649 .24023 m .52135 .24169 L p .45717 .65598 L .707 .577 .707 r
F P
0 g
s
.45508 .66954 m .4506 .64323 L .45717 .65598 L .707 .577 .707 r
F
.44927 .66392 m .4506 .64323 L p .45508 .66954 L F P
0 g
s
.41622 .62626 m .41902 .6347 L p .45638 .65163 L .707 .577 .707 r
F P
0 g
s
.41902 .6347 m .42822 .66245 L .44219 .65708 L p .707 .577 .707 r
F P
0 g
s
.44219 .65708 m .45638 .65163 L p .41902 .6347 L .707 .577 .707 r
F P
0 g
s
.44587 .72894 m .44927 .66392 L .45508 .66954 L .707 .577 .707 r
F
.44514 .72817 m .44927 .66392 L p .44587 .72894 L F P
0 g
s
.41368 .69186 m .41506 .69638 L p .44757 .6998 L .707 .577 .707 r
F P
0 g
s
.41506 .69638 m .41923 .71006 L .42576 .7077 L p .707 .577 .707 r
F P
0 g
s
.42576 .7077 m .44757 .6998 L p .41506 .69638 L .707 .577 .707 r
F P
0 g
s
.44453 .7376 m .44514 .72817 L p .44587 .72894 L .707 .577 .707 r
F P
0 g
s
.64892 .60336 m .65797 .65912 L .67865 .6609 L p .707 .577 .707 r
F P
0 g
s
.69644 .7323 m .702 .75051 L .73172 .74279 L p .707 .577 .707 r
F P
0 g
s
.23743 .78553 m .23188 .76732 L .2624 .75787 L p .707 .577 .707 r
F P
0 g
s
.52135 .24169 m .4894 .73905 L .44453 .7376 L p .707 .577 .707 r
F P
0 g
s
.2624 .75787 m .26796 .77607 L .23743 .78553 L p .707 .577 .707 r
F P
0 g
s
.702 .75051 m .69644 .7323 L .67044 .73753 L p .707 .577 .707 r
F P
0 g
s
.6857 .71977 m .67371 .68358 L .65419 .6865 L p .707 .577 .707 r
F P
0 g
s
.78503 .70487 m .79058 .72308 L .81397 .71301 L p .707 .577 .707 r
F P
0 g
s
.81397 .71301 m .80841 .6948 L .78503 .70487 L p .707 .577 .707 r
F P
0 g
s
.67044 .73753 m .67599 .75573 L .702 .75051 L p .707 .577 .707 r
F P
0 g
s
.81067 .63768 m .82266 .67387 L .83876 .66486 L p .707 .577 .707 r
F P
0 g
s
.83876 .66486 m .82677 .62866 L .81067 .63768 L p .707 .577 .707 r
F P
0 g
s
.65797 .65912 m .64892 .60336 L .63663 .59919 L p .707 .577 .707 r
F P
0 g
s
.65419 .6865 m .66618 .72269 L .6857 .71977 L p .707 .577 .707 r
F P
0 g
s
.82809 .57232 m .83713 .62807 L .84428 .62053 L p .707 .577 .707 r
F P
0 g
s
.84428 .62053 m .83524 .56477 L .82809 .57232 L p .707 .577 .707 r
F P
0 g
s
.63663 .59919 m .64568 .65494 L .65797 .65912 L p .707 .577 .707 r
F P
0 g
s
.67599 .75573 m .67044 .73753 L .65069 .73975 L p .707 .577 .707 r
F P
0 g
s
.65069 .73975 m .65625 .75795 L .67599 .75573 L p .707 .577 .707 r
F P
0 g
s
.80841 .6948 m .81397 .71301 L .8301 .70412 L p .707 .577 .707 r
F P
0 g
s
.8301 .70412 m .82455 .68591 L .80841 .6948 L p .707 .577 .707 r
F P
0 g
s
.66618 .72269 m .65419 .6865 L .64281 .68606 L p .707 .577 .707 r
F P
0 g
s
.82677 .62866 m .83876 .66486 L .84611 .65814 L p .707 .577 .707 r
F P
0 g
s
.84611 .65814 m .83412 .62195 L .82677 .62866 L p .707 .577 .707 r
F P
0 g
s
.64281 .68606 m .6548 .72225 L .66618 .72269 L p .707 .577 .707 r
F P
0 g
s
.64568 .65494 m .63663 .59919 L .63393 .59303 L p .707 .577 .707 r
F P
0 g
s
.65625 .75795 m .65069 .73975 L .63914 .73875 L p .707 .577 .707 r
F P
0 g
s
.83524 .56477 m .84428 .62053 L .84158 .61437 L p .707 .577 .707 r
F P
0 g
s
.84158 .61437 m .83254 .55861 L .83524 .56477 L p .707 .577 .707 r
F P
0 g
s
.63914 .73875 m .6447 .75695 L .65625 .75795 L p .707 .577 .707 r
F P
0 g
s
.63393 .59303 m .64298 .64878 L .64568 .65494 L p .707 .577 .707 r
F P
0 g
s
.82455 .68591 m .8301 .70412 L .83742 .69728 L p .707 .577 .707 r
F P
0 g
s
.83742 .69728 m .83186 .67907 L .82455 .68591 L p .707 .577 .707 r
F P
0 g
s
.6548 .72225 m .64281 .68606 L .6407 .68229 L p .707 .577 .707 r
F P
0 g
s
.6407 .68229 m .65269 .71849 L .6548 .72225 L p .707 .577 .707 r
F P
0 g
s
.83412 .62195 m .84611 .65814 L .844 .65437 L p .707 .577 .707 r
F P
0 g
s
.844 .65437 m .83201 .61818 L .83412 .62195 L p .707 .577 .707 r
F P
0 g
s
.64298 .64878 m .63393 .59303 L .64108 .58548 L p .707 .577 .707 r
F P
0 g
s
.6447 .75695 m .63914 .73875 L .63692 .73463 L p .707 .577 .707 r
F P
0 g
s
.63692 .73463 m .64247 .75283 L .6447 .75695 L p .707 .577 .707 r
F P
0 g
s
.83254 .55861 m .84158 .61437 L .82929 .61019 L p .707 .577 .707 r
F P
0 g
s
.82929 .61019 m .82024 .55444 L .83254 .55861 L p .707 .577 .707 r
F P
0 g
s
.64108 .58548 m .65013 .64124 L .64298 .64878 L p .707 .577 .707 r
F P
0 g
s
.83186 .67907 m .83742 .69728 L .83519 .69315 L p .707 .577 .707 r
F P
0 g
s
.83519 .69315 m .82964 .67495 L .83186 .67907 L p .707 .577 .707 r
F P
0 g
s
.39342 .61087 m .38438 .55511 L .35363 .55839 L p .707 .577 .707 r
F P
0 g
s
.38438 .55511 m .39342 .61087 L .42488 .60541 L p .707 .577 .707 r
F P
0 g
s
.42488 .60541 m .41584 .54966 L .38438 .55511 L p .707 .577 .707 r
F P
0 g
s
.45396 .59833 m .44492 .54257 L .41584 .54966 L p .707 .577 .707 r
F P
0 g
s
.65269 .71849 m .6407 .68229 L .64805 .67558 L p .707 .577 .707 r
F P
0 g
s
.64805 .67558 m .66004 .71177 L .65269 .71849 L p .707 .577 .707 r
F P
0 g
s
.83201 .61818 m .844 .65437 L .83262 .65393 L p .707 .577 .707 r
F P
0 g
s
.83262 .65393 m .82063 .61774 L .83201 .61818 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36267 .61415 m .35363 .55839 L .32659 .55918 L p .707 .577 .707 r
F P
0 g
s
.35363 .55839 m .36267 .61415 L .39342 .61087 L p .707 .577 .707 r
F P
0 g
s
.65013 .64124 m .64108 .58548 L .65738 .5773 L p .707 .577 .707 r
F P
0 g
s
.44492 .54257 m .45396 .59833 L .47782 .5903 L p .707 .577 .707 r
F P
0 g
s
.47782 .5903 m .46878 .53454 L .44492 .54257 L p .707 .577 .707 r
F P
0 g
s
.64247 .75283 m .63692 .73463 L .64423 .72779 L p .707 .577 .707 r
F P
0 g
s
.32659 .55918 m .33564 .61493 L .36267 .61415 L p .707 .577 .707 r
F P
0 g
s
.82024 .55444 m .82929 .61019 L .80861 .60841 L p .707 .577 .707 r
F P
0 g
s
.80861 .60841 m .79957 .55266 L .82024 .55444 L p .707 .577 .707 r
F P
0 g
s
.64423 .72779 m .64978 .74599 L .64247 .75283 L p .707 .577 .707 r
F P
0 g
s
.39791 .67261 m .38592 .63642 L .35645 .64491 L p .707 .577 .707 r
F P
0 g
s
.42822 .66245 m .41622 .62626 L .38592 .63642 L p .707 .577 .707 r
F P
0 g
s
.65738 .5773 m .66643 .63305 L .65013 .64124 L p .707 .577 .707 r
F P
0 g
s
.45638 .65163 m .44439 .61544 L .41622 .62626 L p .707 .577 .707 r
F P
0 g
s
.82964 .67495 m .83519 .69315 L .82364 .69215 L p .707 .577 .707 r
F P
0 g
s
.82364 .69215 m .81808 .67395 L .82964 .67495 L p .707 .577 .707 r
F P
0 g
s
.33564 .61493 m .32659 .55918 L .30591 .5574 L p .707 .577 .707 r
F P
0 g
s
.35645 .64491 m .36844 .6811 L .39791 .67261 L p .707 .577 .707 r
F P
0 g
s
.36844 .6811 m .35645 .64491 L .3307 .65091 L p .707 .577 .707 r
F P
0 g
s
.46878 .53454 m .47782 .5903 L .49412 .58211 L p .707 .577 .707 r
F P
0 g
s
.49412 .58211 m .48508 .52635 L .46878 .53454 L p .707 .577 .707 r
F P
0 g
s
.66004 .71177 m .64805 .67558 L .66415 .66656 L p .707 .577 .707 r
F P
0 g
s
.44439 .61544 m .45638 .65163 L .47965 .6412 L p .707 .577 .707 r
F P
0 g
s
.47965 .6412 m .46766 .60501 L .44439 .61544 L p .707 .577 .707 r
F P
0 g
s
.3307 .65091 m .34269 .6871 L .36844 .6811 L p .707 .577 .707 r
F P
0 g
s
.66643 .63305 m .65738 .5773 L .68124 .56926 L p .707 .577 .707 r
F P
0 g
s
.30591 .5574 m .31496 .61315 L .33564 .61493 L p .707 .577 .707 r
F P
0 g
s
.82063 .61774 m .83262 .65393 L .8131 .65685 L p .707 .577 .707 r
F P
0 g
s
.8131 .65685 m .80111 .62066 L .82063 .61774 L p .707 .577 .707 r
F P
0 g
s
.66415 .66656 m .67614 .70275 L .66004 .71177 L p .707 .577 .707 r
F P
0 g
s
.38871 .71951 m .38315 .70131 L .35343 .70903 L p .707 .577 .707 r
F P
0 g
s
.38315 .70131 m .38871 .71951 L .41923 .71006 L p .707 .577 .707 r
F P
0 g
s
.41923 .71006 m .41368 .69186 L .38315 .70131 L p .707 .577 .707 r
F P
0 g
s
.44757 .6998 m .44202 .68159 L .41368 .69186 L p .707 .577 .707 r
F P
0 g
s
.35343 .70903 m .35899 .72723 L .38871 .71951 L p .707 .577 .707 r
F P
0 g
s
.79957 .55266 m .80861 .60841 L .78158 .6092 L p .707 .577 .707 r
F P
0 g
s
.78158 .6092 m .77253 .55345 L .79957 .55266 L p .707 .577 .707 r
F P
0 g
s
.68124 .56926 m .69029 .62502 L .66643 .63305 L p .707 .577 .707 r
F P
0 g
s
.64978 .74599 m .64423 .72779 L .66037 .7189 L p .707 .577 .707 r
F P
0 g
s
.34269 .6871 m .3307 .65091 L .31118 .65384 L p .707 .577 .707 r
F P
0 g
s
.31496 .61315 m .30591 .5574 L .29362 .55322 L p .707 .577 .707 r
F P
0 g
s
.35899 .72723 m .35343 .70903 L .32743 .71425 L p .707 .577 .707 r
F P
0 g
s
.66037 .7189 m .66592 .7371 L .64978 .74599 L p .707 .577 .707 r
F P
0 g
s
.46766 .60501 m .47965 .6412 L .49575 .63219 L p .707 .577 .707 r
F P
0 g
s
.49575 .63219 m .48376 .596 L .46766 .60501 L p .707 .577 .707 r
F P
0 g
s
.44202 .68159 m .44757 .6998 L .47096 .68973 L p .707 .577 .707 r
F P
0 g
s
.47096 .68973 m .4654 .67152 L .44202 .68159 L p .707 .577 .707 r
F P
0 g
s
.32743 .71425 m .33298 .73245 L .35899 .72723 L p .707 .577 .707 r
F P
0 g
s
.81808 .67395 m .82364 .69215 L .80389 .69438 L p .707 .577 .707 r
F P
0 g
s
.80389 .69438 m .79834 .67617 L .81808 .67395 L p .707 .577 .707 r
F P
0 g
s
.31118 .65384 m .32317 .69003 L .34269 .6871 L p .707 .577 .707 r
F P
0 g
s
.69029 .62502 m .68124 .56926 L .71032 .56218 L p .707 .577 .707 r
F P
0 g
s
.67614 .70275 m .66415 .66656 L .68742 .65613 L p .707 .577 .707 r
F P
0 g
s
.48508 .52635 m .49412 .58211 L .50127 .57456 L p .707 .577 .707 r
F P
0 g
s
.50127 .57456 m .49223 .51881 L .48508 .52635 L p .707 .577 .707 r
F P
0 g
s
.29362 .55322 m .30267 .60898 L .31496 .61315 L p .707 .577 .707 r
F P
0 g
s
.77253 .55345 m .78158 .6092 L .75082 .61248 L p .707 .577 .707 r
F P
0 g
s
.75082 .61248 m .74178 .55673 L .77253 .55345 L p .707 .577 .707 r
F P
0 g
s
.80111 .62066 m .8131 .65685 L .78735 .66286 L p .707 .577 .707 r
F P
0 g
s
.78735 .66286 m .77536 .62667 L .80111 .62066 L p .707 .577 .707 r
F P
0 g
s
.68742 .65613 m .69941 .69233 L .67614 .70275 L p .707 .577 .707 r
F P
0 g
s
.71937 .61793 m .71032 .56218 L .74178 .55673 L p .707 .577 .707 r
F P
0 g
s
.71032 .56218 m .71937 .61793 L .69029 .62502 L p .707 .577 .707 r
F P
0 g
s
.33298 .73245 m .32743 .71425 L .30768 .71647 L p .707 .577 .707 r
F P
0 g
s
.74178 .55673 m .75082 .61248 L .71937 .61793 L p .707 .577 .707 r
F P
0 g
s
.30768 .71647 m .31324 .73467 L .33298 .73245 L p .707 .577 .707 r
F P
0 g
s
.4654 .67152 m .47096 .68973 L .48709 .68084 L p .707 .577 .707 r
F P
0 g
s
.48709 .68084 m .48154 .66263 L .4654 .67152 L p .707 .577 .707 r
F P
0 g
s
.32317 .69003 m .31118 .65384 L .2998 .65339 L p .707 .577 .707 r
F P
0 g
s
.66592 .7371 m .66037 .7189 L .68375 .70883 L p .707 .577 .707 r
F P
0 g
s
.68375 .70883 m .68931 .72703 L .66592 .7371 L p .707 .577 .707 r
F P
0 g
s
.69941 .69233 m .68742 .65613 L .71559 .64531 L p .707 .577 .707 r
F P
0 g
s
.30267 .60898 m .29362 .55322 L .29092 .54706 L p .707 .577 .707 r
F P
0 g
s
.48376 .596 m .49575 .63219 L .5031 .62547 L p .707 .577 .707 r
F P
0 g
s
.5031 .62547 m .49111 .58928 L .48376 .596 L p .707 .577 .707 r
F P
0 g
s
.79834 .67617 m .80389 .69438 L .77789 .6996 L p .707 .577 .707 r
F P
0 g
s
.77789 .6996 m .77234 .68139 L .79834 .67617 L p .707 .577 .707 r
F P
0 g
s
.2998 .65339 m .31179 .68958 L .32317 .69003 L p .707 .577 .707 r
F P
0 g
s
.77536 .62667 m .78735 .66286 L .75788 .67135 L p .707 .577 .707 r
F P
0 g
s
.75788 .67135 m .74589 .63516 L .77536 .62667 L p .707 .577 .707 r
F P
0 g
s
.71559 .64531 m .72758 .6815 L .69941 .69233 L p .707 .577 .707 r
F P
0 g
s
.72758 .6815 m .71559 .64531 L .74589 .63516 L p .707 .577 .707 r
F P
0 g
s
.49223 .51881 m .50127 .57456 L .49857 .5684 L p .707 .577 .707 r
F P
0 g
s
.49857 .5684 m .48953 .51265 L .49223 .51881 L p .707 .577 .707 r
F P
0 g
s
.74589 .63516 m .75788 .67135 L .72758 .6815 L p .707 .577 .707 r
F P
0 g
s
.29092 .54706 m .29997 .60282 L .30267 .60898 L p .707 .577 .707 r
F P
0 g
s
.31324 .73467 m .30768 .71647 L .29613 .71547 L p .707 .577 .707 r
F P
0 g
s
.68931 .72703 m .68375 .70883 L .71209 .69856 L p .707 .577 .707 r
F P
0 g
s
.29613 .71547 m .30169 .73367 L .31324 .73467 L p .707 .577 .707 r
F P
0 g
s
.77234 .68139 m .77789 .6996 L .74817 .70732 L p .707 .577 .707 r
F P
0 g
s
.74817 .70732 m .74262 .68911 L .77234 .68139 L p .707 .577 .707 r
F P
0 g
s
.71209 .69856 m .71765 .71677 L .68931 .72703 L p .707 .577 .707 r
F P
0 g
s
.48154 .66263 m .48709 .68084 L .49441 .674 L p .707 .577 .707 r
F P
0 g
s
.49441 .674 m .48885 .65579 L .48154 .66263 L p .707 .577 .707 r
F P
0 g
s
.31179 .68958 m .2998 .65339 L .29769 .64963 L p .707 .577 .707 r
F P
0 g
s
.71765 .71677 m .71209 .69856 L .74262 .68911 L p .707 .577 .707 r
F P
0 g
s
.74262 .68911 m .74817 .70732 L .71765 .71677 L p .707 .577 .707 r
F P
0 g
s
.29769 .64963 m .30968 .68582 L .31179 .68958 L p .707 .577 .707 r
F P
0 g
s
.49111 .58928 m .5031 .62547 L .50099 .62171 L p .707 .577 .707 r
F P
0 g
s
.50099 .62171 m .489 .58552 L .49111 .58928 L p .707 .577 .707 r
F P
0 g
s
.29997 .60282 m .29092 .54706 L .29807 .53952 L p .707 .577 .707 r
F P
0 g
s
.48953 .51265 m .49857 .5684 L .48628 .56423 L p .707 .577 .707 r
F P
0 g
s
.48628 .56423 m .47723 .50847 L .48953 .51265 L p .707 .577 .707 r
F P
0 g
s
.29807 .53952 m .30712 .59527 L .29997 .60282 L p .707 .577 .707 r
F P
0 g
s
.30169 .73367 m .29613 .71547 L .2939 .71135 L p .707 .577 .707 r
F P
0 g
s
.2939 .71135 m .29946 .72955 L .30169 .73367 L p .707 .577 .707 r
F P
0 g
s
.48885 .65579 m .49441 .674 L .49218 .66987 L p .707 .577 .707 r
F P
0 g
s
.49218 .66987 m .48663 .65167 L .48885 .65579 L p .707 .577 .707 r
F P
0 g
s
.30968 .68582 m .29769 .64963 L .30504 .64291 L p .707 .577 .707 r
F P
0 g
s
.30712 .59527 m .29807 .53952 L .31437 .53133 L p .707 .577 .707 r
F P
0 g
s
.30504 .64291 m .31703 .6791 L .30968 .68582 L p .707 .577 .707 r
F P
0 g
s
.489 .58552 m .50099 .62171 L .48961 .62127 L p .707 .577 .707 r
F P
0 g
s
.48961 .62127 m .47762 .58507 L .489 .58552 L p .707 .577 .707 r
F P
0 g
s
.47723 .50847 m .48628 .56423 L .4656 .56245 L p .707 .577 .707 r
F P
0 g
s
.4656 .56245 m .45656 .50669 L .47723 .50847 L p .707 .577 .707 r
F P
0 g
s
.31437 .53133 m .32342 .58708 L .30712 .59527 L p .707 .577 .707 r
F P
0 g
s
.29946 .72955 m .2939 .71135 L .30122 .70451 L p .707 .577 .707 r
F P
0 g
s
.30122 .70451 m .30677 .72271 L .29946 .72955 L p .707 .577 .707 r
F P
0 g
s
.48663 .65167 m .49218 .66987 L .48063 .66887 L p .707 .577 .707 r
F P
0 g
s
.48063 .66887 m .47507 .65067 L .48663 .65167 L p .707 .577 .707 r
F P
0 g
s
.31703 .6791 m .30504 .64291 L .32114 .6339 L p .707 .577 .707 r
F P
0 g
s
.32342 .58708 m .31437 .53133 L .33823 .5233 L p .707 .577 .707 r
F P
0 g
s
.47762 .58507 m .48961 .62127 L .47009 .62419 L p .707 .577 .707 r
F P
0 g
s
.47009 .62419 m .4581 .588 L .47762 .58507 L p .707 .577 .707 r
F P
0 g
s
.32114 .6339 m .33313 .67009 L .31703 .6791 L p .707 .577 .707 r
F P
0 g
s
.45656 .50669 m .4656 .56245 L .43857 .56324 L p .707 .577 .707 r
F P
0 g
s
.43857 .56324 m .42952 .50748 L .45656 .50669 L p .707 .577 .707 r
F P
0 g
s
.33823 .5233 m .34728 .57905 L .32342 .58708 L p .707 .577 .707 r
F P
0 g
s
.30677 .72271 m .30122 .70451 L .31736 .69562 L p .707 .577 .707 r
F P
0 g
s
.34728 .57905 m .33823 .5233 L .36731 .51621 L p .707 .577 .707 r
F P
0 g
s
.31736 .69562 m .32291 .71382 L .30677 .72271 L p .707 .577 .707 r
F P
0 g
s
.47507 .65067 m .48063 .66887 L .46088 .6711 L p .707 .577 .707 r
F P
0 g
s
.46088 .6711 m .45533 .65289 L .47507 .65067 L p .707 .577 .707 r
F P
0 g
s
.42952 .50748 m .43857 .56324 L .40781 .56652 L p .707 .577 .707 r
F P
0 g
s
.40781 .56652 m .39877 .51076 L .42952 .50748 L p .707 .577 .707 r
F P
0 g
s
.33313 .67009 m .32114 .6339 L .34441 .62347 L p .707 .577 .707 r
F P
0 g
s
.4581 .588 m .47009 .62419 L .44434 .63019 L p .707 .577 .707 r
F P
0 g
s
.44434 .63019 m .43235 .594 L .4581 .588 L p .707 .577 .707 r
F P
0 g
s
.34441 .62347 m .3564 .65966 L .33313 .67009 L p .707 .577 .707 r
F P
0 g
s
.37636 .57197 m .36731 .51621 L .39877 .51076 L p .707 .577 .707 r
F P
0 g
s
.36731 .51621 m .37636 .57197 L .34728 .57905 L p .707 .577 .707 r
F P
0 g
s
.39877 .51076 m .40781 .56652 L .37636 .57197 L p .707 .577 .707 r
F P
0 g
s
.32291 .71382 m .31736 .69562 L .34074 .68555 L p .707 .577 .707 r
F P
0 g
s
.3564 .65966 m .34441 .62347 L .37257 .61265 L p .707 .577 .707 r
F P
0 g
s
.34074 .68555 m .3463 .70375 L .32291 .71382 L p .707 .577 .707 r
F P
0 g
s
.43235 .594 m .44434 .63019 L .41487 .63868 L p .707 .577 .707 r
F P
0 g
s
.41487 .63868 m .40287 .60249 L .43235 .594 L p .707 .577 .707 r
F P
0 g
s
.45533 .65289 m .46088 .6711 L .43488 .67632 L p .707 .577 .707 r
F P
0 g
s
.43488 .67632 m .42933 .65811 L .45533 .65289 L p .707 .577 .707 r
F P
0 g
s
.37257 .61265 m .38457 .64884 L .3564 .65966 L p .707 .577 .707 r
F P
0 g
s
.38457 .64884 m .37257 .61265 L .40287 .60249 L p .707 .577 .707 r
F P
0 g
s
.40287 .60249 m .41487 .63868 L .38457 .64884 L p .707 .577 .707 r
F P
0 g
s
.3463 .70375 m .34074 .68555 L .36908 .67528 L p .707 .577 .707 r
F P
0 g
s
.42933 .65811 m .43488 .67632 L .40516 .68404 L p .707 .577 .707 r
F P
0 g
s
.40516 .68404 m .39961 .66583 L .42933 .65811 L p .707 .577 .707 r
F P
0 g
s
.36908 .67528 m .37464 .69349 L .3463 .70375 L p .707 .577 .707 r
F P
0 g
s
.37464 .69349 m .36908 .67528 L .39961 .66583 L p .707 .577 .707 r
F P
0 g
s
.39961 .66583 m .40516 .68404 L .37464 .69349 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00NGoo2@004UYF00<005YFFUH01P00P7oo001eOol40002FUH00`00FUIJEP0FFUH00`00FUIJEP06
FUH6001jOol0075oo`@000IJEP03001JEUYF01IJEP03001JEUYF00UJEP03001JEUYF00H007Aoo`00
KGoo100000=JEP00FUH01eYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH01UYF1000L7oo
001[Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
1000FUH00000KWoo001ZOol20006FUH00`00FUIJEP06FUH00`00FUIJEP0FFUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P00K7oo001YOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP0FFUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP03FUH2001ZOol006Uoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8006Qoo`00J7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Io
o`00J7oo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF008006Aoo`00J7oo00@005YFFUH0
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo065oo`00J7oo00@005YFFUH000EJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF009JEP03001oogoo065oo`00J7oo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1eYF00<005YFFUH00UYF00<007ooOol0HGoo001XOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH2001ROol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80069o
o`00J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HWoo001WOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00HWoo001WOol01000FUIJEP001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00eYF0P00HWoo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH025YF00=ooeYF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH015YF00<007ooOol0H7oo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<007ooOol0H7oo
001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000HWoo001WOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000HWoo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH05UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
Ool0HWoo001WOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0HWoo
001WOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0HWoo001WOol0
1000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0HWoo001WOol01000FUIJ
EP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0HWoo001WOol01000FUIJEP001EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH00UYF00<005YFOol0HWoo001WOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP02FUH2001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF
009JEP8006=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P00Hgoo001W
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001SOol006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001S
Ool006Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001SOol006Io
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1SOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001TOol006Ioo`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001TOol0
06Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH2001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001T
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001TOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF009JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2
001UOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH2001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2000;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP00
00IJEP03001JEUYF00IJEQ<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00MJEP03
001JEUYF009JEP8006Ioo`00I7oo00<005YF00001UYF2@0015YF00<005YFFUH015YF00<005YFFUH0
0eYF00<005YF00000P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH00UYF0P00IWoo001TOol00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P00IWoo001SOol400000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P00IWoo001OOol40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P00IWoo001MOol200000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00IWoo001KOol20003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJ
EUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IWoo001HOol30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001FOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IWoo001DOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IWoo001COol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001BOol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00DWoo00@005YFFUH0
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Moo`00DWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00<000]JEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP80025ooa@0039oo`00Dgoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YF
FUH00UYF0P0067oo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF0000031oo`00Dgoo
00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF1P000eYF00<005YFFUH00P002eYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH00UYF0P004Woo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0031oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@001EYF1P0000=JEP0000002eYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P003Woo100000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P00;goo001COol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90007FUH00`00FUIJEP04FUH00`00FUIJEP02FUH4000;FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2000:Ool40005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo001COol01000FUIJEP00
0eYF00<005YFFUH01EYF00<005YFFUH015YF1P0025YF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YF000000]JEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80
00Qoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000_Ool005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP04
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006Ool20003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00;goo001DOol00`00FUH00004FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH20004Ool20006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;goo001DOol00`00FUH00004FUH00`00FUH0
00030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P00
0Woo0`001eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH30007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH70002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP02000^Ool005Aoo`04001JEUYF0002FUH01@00FUIJEUYF00001eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01EYF1P000UYF00D005YFFUIJEP00009JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Woo001DOol00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUH000050003FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000^Ool005Eoo`9JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP800003FUH005YF00MJEP03001JEUYF009JEP07001JEUYFFUH005YF00002eYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00Cgoo1P0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH002ioo`00AWoo2@0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUH000020007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF
FUH002ioo`00@7oo1P0015YF00<005YFFUH01UYF00@005YF0000009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00
FUIJEUYF00001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00?Woo0P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEP<000EJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUHC0002FUH00`00Oomoo`0[Ool003]oo`<000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEQ<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008000YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009JEP<0
0003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000IJEP03001J
EUYF00EJEP04001JEUYFFUH4000]Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF00=JEP80009JEP<00003FUH005YF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00AJEP04001JEUYF000:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH60007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH700000eYF001oo`0/Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEPD000AJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYFFUH70009FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP0200000eYF001oo`0/Ool0035oo`<000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP8000MJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEPD0009JEP05001JEUYFFUH0
0009FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH300000eYF001JEP03FUH00`00
FUIJEP04FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH400000eYF001JEP05FUH00`00FUIJ
EP02000^Ool002moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH30009FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUH000030002FUH00`00FUIJEP03FUH3000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH300000eYF001JEP04FUH01000FUIJEUYF0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YF00000P001UYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000]Ool20003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40007FUH00`00FUIJEP02FUH2000;FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP02FUH01000FUH0
00001UYF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH01UYF00<005YFFUH00eYF00<0
05YFFUH00P00;Woo000/Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP040003FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF00=JEP<0009JEP04001JEUYFFUH40007FUH00`00FUIJEP06FUH00`00FUIJEP04
0006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02000^Ool002]oo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
00000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP05FUH30002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001GooFUIJ
EP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF0`0000=JEP00FUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH002ioo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH007oo0UYF
0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000[Ool01000FUIJEP0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF0P001EYF00<005YFFUH015YF00<005YFFUH0
1eYF00<005YF00000P001EYF0P001eYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0002FUH00`00FUIJEP02FUH0
0`00FUIJEP05FUH00`00FUIJEP030008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH3
0009FUH00`00FUIJEP06FUH01000FUH0000025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00@005YF001JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP80
0003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]
Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH;0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH01000FUH005YF0P000eYF00<005YFFUH00UYF00<005YFFUH00UYF0`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00Ool0;7oo000/Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUH000020005FUH00`00FUIJEP06FUH01000FUIJ
EUYF100000=JEP00FUH015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF0080009JEP03001JEUYF009JEP03001JEP000080
00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP@000=JEP@002aoo`00;7oo00<0
05YF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00@005YFFUH0
00AJEP03001JEUYF00AJEP<000UJEP03001JEUYF00EJEP@000IJEP03001JEUYF009JEP06001JEUYF
001JEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF
2@0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH010000UYF00<005YF
FUH00UYF00@005YFFUH002aoo`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00AJ
EPH000QJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP07
FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P002eYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF0`0015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF10001UYF00<005YFFUH00eYF0P00;Goo000/Ool0
1000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH010001EYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP06FUH40006FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP02000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200000eYF001JEP05FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040003
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002eoo`03001JEP0000AJEP03001JEUYF00=J
EPD000QJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0004FUH20007FUH00`00FUIJEP03
FUH300000eYF001JEP08FUH00`00FUIJEP04FUH;000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF001JEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40007
FUH00`00FUIJEP05FUH01000FUH00000<7oo000]Ool00`00FUH00004FUH01000FUIJEUYF0P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000eYF00@005YFFUH000IJ
EP03001JEUYF00<000EJEP03001JEUYF00IJEP03001JEUYF00D00003FUH005YF00=JEP04001JEUYF
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF001JEP02FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH01000
FUIJEUYF1P00<Goo000]Ool00`00FUH00004FUH01000FUH000001UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00`000eYF00<005YFFUH015YF0`0025YF00<005YFFUH0
1EYF100000=JEP0000000eYF00<005YFFUH00eYF0`002eYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P000UYF00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
00000P001UYF00<005YFFUH00eYF1`000UYF00@005YFFUH0035oo`00;Goo00@005YFFUH000=JEP<0
00QJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJ
EP0400000eYF001JEP09FUH00`00FUIJEP040002FUH30005FUH00`00FUIJEP03FUH00`00FUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH30005FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH40008FUH60003FUH00`00FUIJEP04FUH01000FUIJEP00<7oo000]Ool01@00
FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P0000=JEP0000001EYF0`001UYF00<005YFFUH01UYF100015YF0P0000=JEP00FUH01UYF00<0
05YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0P000UYF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00=J
EP@00003FUH005YF00IJEP03001JEUYF00=JEP04001JEUYF000`Ool002ioo`9JEP8000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEPD0009JEP04001JEUYF0002FUH30008FUH00`00
FUIJEP03FUH300000eYF001JEP02FUH30004FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH01000FUIJEP0015YF00<005YF
FUH01EYF00<005YF00000P001EYF00<005YF00000`001UYF00<005YFFUH015YF00<005YFFUH015YF
00@005YF000002moo`00;Woo00AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00=JEP@00003FUH005YF00=JEPH000=JEP03001JEUYF00IJEP03001JEP00008000AJEP@000MJ
EP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00=JEP80009JEP800003FUH005YF00AJEP03001JEUYF00AJEP<000IJEP<00003FUH0
05YF00MJEP03001JEUYF00EJEP04001JEUYFFUH400000eYF001oo`0^Ool002ioo`800003FUH005YF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEP0000<000IJEP03001JEUYF00=JEP8000EJ
EP03001JEUYF00EJEP<000EJEP<00003FUH005YF00MJEP03001JEUYF009JEP8000MJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000=JEP03001JEP0000EJEP03
001JEUYF009JEP80009JEP04001JEUYFFUH30004FUH00`00FUIJEP07FUH01000FUIJEUYF1`000UYF
00<005YF00000P00;Woo000^Ool20002FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH300000eYF001JEP07FUH01000FUIJEUYF0`001UYF00<005YFFUH00eYF0`0015YF0`001EYF00<0
05YFFUH01UYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP04001JEUYF0005FUH01000FUH0000015YF10001eYF00<005YF
FUH01UYF1@000Woo0`001EYF00@005YFFUH002ioo`00;goo0P0000=JEP00FUH015YF00<005YFFUH0
1EYF00@005YFFUIJEP<000EJEP03001JEUYF00IJEP<0009JEP03001JEUYF00EJEP03001JEP000080
009JEP03001JEP00008000QJEP03001JEUYF00EJEP<000]JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000@0009JEP03001JEUYF00=JEP8000EJEP80
0003FUH005YF00QJEP03001JEUYF009JEP<000Eoo`8000=JEP03001JEUYF009JEP<002moo`00<Goo
10000eYF00<005YFFUH00UYF1`0025YF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00eYF
0`000eYF100000=JEP00FUH02EYF00@005YFFUIJEP@000eJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000=JEP800004FUH005YF
FUH30003FUH00`00FUIJEP07FUH00`00FUH000020005Ool30005FUH00`00FUIJEP02FUH00`00Oomo
o`0_Ool003Eoo`P0009oo`800003FUH005YF00QJEP03001JEUYF00EJEP8000EJEP03001JEP0000<0
009JEP@000IJEP03001JEUYF00IJEPD000=JEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00<000=JEP<000MJ
EP03001JEUYF00AJEP@000Ioo`800003FUH005YF00IJEP04001JEP00000bOol003aoo`<000AJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0004FUH200000eYF0000000300000eYF001JEP07
FUH00`00FUIJEP03FUH30008FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP020002FUH200000eYF001JEP07FUH00`00
FUIJEP040007Ool30003FUH00`00FUIJEP04FUH3000dOol003Yoo`8000MJEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF0003FUH50006FUH00`00FUIJEP06FUH00`00FUH00003000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH200000eYF001JEP030003FUH00`00FUIJEP05FUH40003Ool30002Ool30007FUH01000FUIJEUYF
0P00=goo000hOol30009FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030003FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH30003FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF000000000UYF10001UYF
00<005YFFUH00UYF0P001Woo1P0000=JEP00FUH01eYF00@005YF000003Uoo`00=Woo0P000eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH010001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`001eYF00<005YF00000P00
27oo1@000UYF00<005YFFUH01EYF0`00>goo000cOol30005FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP04000015YF001JEP001EYF00<005YFFUH015YF10002EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P00
0eYF0`000eYF00<005YFFUH015YF0P0000=JEP00000017oo2@000eYF00<005YFFUH00UYF0P00?Woo
000aOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH01@00FUIJEUYF
000015YF00<005YFFUH010000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000eYF0P0015YF00<0
05YFFUH00UYF0P0000AJEP00FUIJEPD0009JEP03001JEUYF00<000AJEP03001JEP000080041oo`00
;goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH0
0UYF300000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YF00001EYF
00D005YF000005YF00H000IJEP03001JEUYF00IJEP<004=oo`00;Woo0P001EYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YF00000P001EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH01eYF00<005YFFUH015YF30001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00UYF0P000UYF00<005YF00001EYF1@000eYF00<005YFFUH0
1eYF00<005YFFUH00UYF0`00AWoo000]Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF0`002EYF00<005YFFUH01UYF00@005YF0000009oo`9JEP03001JEUYF00=JEP03001JEUYF00AJ
EPX00003FUH005YF00UJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80
009JEP04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUH000020019Ool0
02eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH70002FUH00`00FUIJEP03FUH00`00FUIJEP05000:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH80009FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP030004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH3001<Ool002ioo`03001JEP0000EJEP03001JEUYF00EJEP03
001JEP00008000EJEP03001JEUYF00IJEP04001JEUYFFUH400000eYF001JEP03FUH01000FUIJEP00
1EYF0`0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH00eYF1000
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00@005YF000000EJEP03001JEUYF00EJEP03
001JEUYF00@004moo`00;Woo00@005YFFUH000AJEP03001JEUYF00AJEP<000QJEP03001JEUYF00IJ
EP@000IJEP05001JEUYFFUH00002FUH01000FUIJEUYF0P001eYF00<005YFFUH025YF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF100000=JEP00FUH01eYF00<005YFFUH00eYF0P000eYF
0P0000=JEP00FUH01EYF00@005YFFUIJEPH005=oo`00;Woo00@005YFFUH000AJEP03001JEUYF009J
EP80009JEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH01@00FUIJEUYF0000
0UYF00<005YF00000P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YF00000P001eYF00<005YFFUH00UYF00<005YF00000eYF0P000UYF00@005YFFUIJ
EPH000=JEP8005Aoo`00;goo00@005YFFUH000AJEP04001JEP000005FUH00`00FUIJEP06FUH40006
FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF0P000UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00UYF0`0015YF00<005YF
FUH00UYF00<005YF00000UYF2@000eYF00<005YFFUH00UYF0P00EGoo000_Ool01000FUIJEP0015YF
0P001eYF00<005YFFUH00eYF0`0000=JEP00FUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP05FUH300000eYF001JEP03FUH00`00FUH000020005FUH00`00FUIJEP05FUH01000
FUH00000Egoo000`Ool00`00FUH00003FUH01000FUIJEP001UYF00<005YFFUH00`001EYF00<005YF
FUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000AJEP03001JEP0000QJ
EP04001JEUYFFUH5001IOol0031oo`03001JEUYF00<000=JEP03001JEUYF00AJEP<000QJEP03001J
EUYF00EJEPT00003FUH005YF008000EJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH30005FUH7
0002FUH01000FUH00000F7oo000`Ool01000FUIJEP001EYF00<005YFFUH00UYF0P0000=JEP00FUH0
2EYF00<005YFFUH010000Woo0`001EYF00@005YF000000EJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP800003FUH0000000H000=JEP03001JEUYF00AJEP04001JEP00001GOol0031oo`04001JEP000006
FUH40004FUH00`00FUIJEP06FUH40004Ool200000eYF001JEP06FUH00`00FUH00005FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH400000eYF001JEP06FUH00`00FUIJEP03FUH01000FUIJEP00Egoo000a
Ool01000FUIJEP000eYF0`001eYF00<005YFFUH00eYF0`001Goo0`0015YF00<005YFFUH015YF0`00
3UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00
001FOol0035oo`L00003FUH005YF00QJEP03001JEP00008000Eoo`<000MJEP03001JEUYF00AJEP03
001oo`0000eJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00IJEP03001JEUYF00=JEP04001JEP000003FUH00`00FUIJEP05FUH01000FUIJEUYF1000
00=JEP00Ool0EGoo000cOol20005FUH00`00FUIJEP05FUH30005Ool300000eYF001JEP07FUH00`00
FUIJEP02FUH20003Ool00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH0
15YF1@000UYF00<005YF00000P00EGoo000aOol30006FUH00`00FUIJEP03FUH20005Ool30005FUH0
0`00FUIJEP06FUH01000FUH000001Woo0P002UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH000AJEP03001J
EP0000H000EJEP04001JEUYF001EOol002moo`80009JEP03001JEUYF00EJEP03001JEP00008000Ao
o`<000QJEP03001JEUYF00EJEP<000Yoo`03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0002
FUH40002Ool20003FUH00`00FUIJEP02FUH3001FOol002ioo`03001JEUYF009JEP03001JEUYF00AJ
EP<000=oo`@00003FUH005YF00QJEP03001JEUYF00=JEP8000ioo`8000MJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEP0000<000=oo`<000EJEP03001JEUYF009JEP03001oogoo05Ioo`00;Goo0P001EYF00@005YF
FUIJEP80009oo`@000IJEP03001JEUYF00MJEP03001JEP000080019oo`<000AJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000Eoo`800003FUH005YF00IJEP04001JEP00001IOol002aoo`04001JEUYF0004FUH00`00FUH0
000500000eYF001JEP07FUH00`00FUIJEP05FUH4000HOol300000eYF001JEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20003Ool30003
FUH00`00FUIJEP04FUH3001KOol002aoo`04001JEUYF0004FUH40006FUH00`00FUIJEP06FUH00`00
FUIJEP04000OOol30009FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000Woo0`001eYF00@005YFFUIJEP8005ioo`00;Goo00D005YFFUH005YF
0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP@002Ioo`@000EJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP0000D00003FUH005YF00MJEP04001J
EP00001POol002eoo`03001JEUYF008000AJEP03001JEUYF00IJEP03001JEUYF00@002ioo`@00003
FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPT0009JEP03001JEUYF
00EJEP<0069oo`00;Woo00AJEP00FUH000EJEP03001JEUYF00AJEP@003Ioo`L000IJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00d000=JEP03001JEUYF009JEP8006Eoo`00;Woo00@005YF
FUH000EJEP03001JEUYF00@0045oo`d000IJEP03001JEUYF00AJEP`0009JEP03001JEP0000@000=J
EP03001JEP00008006Moo`00;Woo0P000UYF00<005YFFUH01@00DWoo3P0000=oo`00000010001UYF
00<005YFFUH00`000eYF0`00JWoo000`Ool5001IOol00`00FUH00005FUH50003FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH3001]Ool008ioo`04001JEUYF0002FUH200000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH00002001`Ool008ioo`03001JEUYF00<000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP<007=oo`00Sgoo00@005YF000000EJEP03001JEUYF00EJEP03001JEUYF00@007Ioo`00Sgoo
0P0000=JEP00FUH015YF00<005YFFUH015YF1000NWoo002?Ool20002FUH00`00FUIJEP03FUH00`00
FUH00003001nOol0091oo`/0089oo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59218 .74923 m .60123 .69542 L .57048 .68843 L p .707 .577 .707 r
F P
0 g
s
.60123 .69542 m .59218 .74923 L .62364 .75305 L p .707 .577 .707 r
F P
0 g
s
.62364 .75305 m .63268 .69923 L .60123 .69542 L p .707 .577 .707 r
F P
0 g
s
.63268 .69923 m .62364 .75305 L .65272 .75331 L p .707 .577 .707 r
F P
0 g
s
.65272 .75331 m .66176 .6995 L .63268 .69923 L p .707 .577 .707 r
F P
0 g
s
.56143 .74224 m .57048 .68843 L .54344 .67895 L p .707 .577 .707 r
F P
0 g
s
.57048 .68843 m .56143 .74224 L .59218 .74923 L p .707 .577 .707 r
F P
0 g
s
.66176 .6995 m .65272 .75331 L .67658 .75 L p .707 .577 .707 r
F P
0 g
s
.67658 .75 m .68562 .69619 L .66176 .6995 L p .707 .577 .707 r
F P
0 g
s
.53439 .73276 m .54344 .67895 L .52276 .6679 L p .707 .577 .707 r
F P
0 g
s
.54344 .67895 m .53439 .73276 L .56143 .74224 L p .707 .577 .707 r
F P
0 g
s
.58513 .81989 m .59712 .78627 L .56765 .77434 L p .707 .577 .707 r
F P
0 g
s
.59712 .78627 m .58513 .81989 L .61543 .82816 L p .707 .577 .707 r
F P
0 g
s
.61543 .82816 m .62742 .79454 L .59712 .78627 L p .707 .577 .707 r
F P
0 g
s
.55566 .80796 m .56765 .77434 L .5419 .75992 L p .707 .577 .707 r
F P
0 g
s
.56765 .77434 m .55566 .80796 L .58513 .81989 L p .707 .577 .707 r
F P
0 g
s
.62742 .79454 m .61543 .82816 L .6436 .83196 L p .707 .577 .707 r
F P
0 g
s
.6436 .83196 m .65559 .79834 L .62742 .79454 L p .707 .577 .707 r
F P
0 g
s
.52276 .6679 m .51372 .72171 L .53439 .73276 L p .707 .577 .707 r
F P
0 g
s
.68562 .69619 m .67658 .75 L .69288 .74344 L p .707 .577 .707 r
F P
0 g
s
.69288 .74344 m .70193 .68963 L .68562 .69619 L p .707 .577 .707 r
F P
0 g
s
.51372 .72171 m .52276 .6679 L .51047 .65637 L p .707 .577 .707 r
F P
0 g
s
.5299 .79354 m .5419 .75992 L .52237 .74442 L p .707 .577 .707 r
F P
0 g
s
.5419 .75992 m .5299 .79354 L .55566 .80796 L p .707 .577 .707 r
F P
0 g
s
.59484 .86732 m .60039 .85031 L .57067 .83911 L p .707 .577 .707 r
F P
0 g
s
.60039 .85031 m .59484 .86732 L .62536 .87494 L p .707 .577 .707 r
F P
0 g
s
.62536 .87494 m .63091 .85793 L .60039 .85031 L p .707 .577 .707 r
F P
0 g
s
.56512 .85612 m .57067 .83911 L .54467 .82541 L p .707 .577 .707 r
F P
0 g
s
.57067 .83911 m .56512 .85612 L .59484 .86732 L p .707 .577 .707 r
F P
0 g
s
.65559 .79834 m .6436 .83196 L .66687 .83092 L p .707 .577 .707 r
F P
0 g
s
.66687 .83092 m .67886 .7973 L .65559 .79834 L p .707 .577 .707 r
F P
0 g
s
.63091 .85793 m .62536 .87494 L .6537 .87822 L p .707 .577 .707 r
F P
0 g
s
.6537 .87822 m .65925 .86121 L .63091 .85793 L p .707 .577 .707 r
F P
0 g
s
.54467 .82541 m .53911 .84242 L .56512 .85612 L p .707 .577 .707 r
F P
0 g
s
.52237 .74442 m .51038 .77804 L .5299 .79354 L p .707 .577 .707 r
F P
0 g
s
.53911 .84242 m .54467 .82541 L .52492 .81056 L p .707 .577 .707 r
F P
0 g
s
.51047 .65637 m .50143 .71019 L .51372 .72171 L p .707 .577 .707 r
F P
0 g
s
.51038 .77804 m .52237 .74442 L .511 .72936 L p .707 .577 .707 r
F P
0 g
s
.65925 .86121 m .6537 .87822 L .67709 .87685 L p .707 .577 .707 r
F P
0 g
s
.67709 .87685 m .68264 .85983 L .65925 .86121 L p .707 .577 .707 r
F P
0 g
s
.70193 .68963 m .69288 .74344 L .70003 .73427 L p .707 .577 .707 r
F P
0 g
s
.70003 .73427 m .70908 .68046 L .70193 .68963 L p .707 .577 .707 r
F P
0 g
s
.52492 .81056 m .51937 .82757 L .53911 .84242 L p .707 .577 .707 r
F P
0 g
s
.50143 .71019 m .51047 .65637 L .50777 .64549 L p .707 .577 .707 r
F P
0 g
s
.67886 .7973 m .66687 .83092 L .68297 .82514 L p .707 .577 .707 r
F P
0 g
s
.68297 .82514 m .69496 .79152 L .67886 .7973 L p .707 .577 .707 r
F P
0 g
s
.511 .72936 m .49901 .76297 L .51038 .77804 L p .707 .577 .707 r
F P
0 g
s
.51937 .82757 m .52492 .81056 L .51337 .79602 L p .707 .577 .707 r
F P
0 g
s
.68264 .85983 m .67709 .87685 L .69322 .87095 L p .707 .577 .707 r
F P
0 g
s
.69322 .87095 m .69878 .85394 L .68264 .85983 L p .707 .577 .707 r
F P
0 g
s
.51337 .79602 m .50782 .81303 L .51937 .82757 L p .707 .577 .707 r
F P
0 g
s
.50777 .64549 m .49872 .6993 L .50143 .71019 L p .707 .577 .707 r
F P
0 g
s
.49901 .76297 m .511 .72936 L .50889 .7162 L p .707 .577 .707 r
F P
0 g
s
.70908 .68046 m .70003 .73427 L .69733 .72339 L p .707 .577 .707 r
F P
0 g
s
.69733 .72339 m .70637 .66958 L .70908 .68046 L p .707 .577 .707 r
F P
0 g
s
.69496 .79152 m .68297 .82514 L .69032 .81519 L p .707 .577 .707 r
F P
0 g
s
.69032 .81519 m .70231 .78157 L .69496 .79152 L p .707 .577 .707 r
F P
0 g
s
.49872 .6993 m .50777 .64549 L .51492 .63632 L p .707 .577 .707 r
F P
0 g
s
.50889 .7162 m .4969 .74982 L .49901 .76297 L p .707 .577 .707 r
F P
0 g
s
.50782 .81303 m .51337 .79602 L .51114 .7832 L p .707 .577 .707 r
F P
0 g
s
.51114 .7832 m .50559 .80021 L .50782 .81303 L p .707 .577 .707 r
F P
0 g
s
.51492 .63632 m .50587 .69013 L .49872 .6993 L p .707 .577 .707 r
F P
0 g
s
.4969 .74982 m .50889 .7162 L .51624 .70625 L p .707 .577 .707 r
F P
0 g
s
.51624 .70625 m .50425 .73987 L .4969 .74982 L p .707 .577 .707 r
F P
0 g
s
.50559 .80021 m .51114 .7832 L .51846 .77336 L p .707 .577 .707 r
F P
0 g
s
.51846 .77336 m .5129 .79037 L .50559 .80021 L p .707 .577 .707 r
F P
0 g
s
.50425 .73987 m .51624 .70625 L .53234 .70047 L p .707 .577 .707 r
F P
0 g
s
.53234 .70047 m .52035 .73409 L .50425 .73987 L p .707 .577 .707 r
F P
0 g
s
.5106 .82062 m .47864 .3164 L .43473 .31656 L p .707 .577 .707 r
F P
0 g
s
.50587 .69013 m .51492 .63632 L .53122 .62976 L p .707 .577 .707 r
F P
0 g
s
.53122 .62976 m .52218 .68357 L .50587 .69013 L p .707 .577 .707 r
F P
0 g
s
.52218 .68357 m .53122 .62976 L .55508 .62645 L p .707 .577 .707 r
F P
0 g
s
.5129 .79037 m .51846 .77336 L .5346 .76747 L p .707 .577 .707 r
F P
0 g
s
.5346 .76747 m .52904 .78448 L .5129 .79037 L p .707 .577 .707 r
F P
0 g
s
.55508 .62645 m .54604 .68026 L .52218 .68357 L p .707 .577 .707 r
F P
0 g
s
.52035 .73409 m .53234 .70047 L .55561 .69943 L p .707 .577 .707 r
F P
0 g
s
.55561 .69943 m .54362 .73305 L .52035 .73409 L p .707 .577 .707 r
F P
0 g
s
.52904 .78448 m .5346 .76747 L .55798 .76609 L p .707 .577 .707 r
F P
0 g
s
.55798 .76609 m .55243 .78311 L .52904 .78448 L p .707 .577 .707 r
F P
0 g
s
.47864 .3164 m .5106 .82062 L .55546 .81695 L p .707 .577 .707 r
F P
0 g
s
.54604 .68026 m .55508 .62645 L .58416 .62671 L p .707 .577 .707 r
F P
0 g
s
.58416 .62671 m .57797 .66357 L p .54604 .68026 L .707 .577 .707 r
F P
0 g
s
.57797 .66357 m .57512 .68053 L .5696 .68048 L p .707 .577 .707 r
F P
0 g
s
.5696 .68048 m .54604 .68026 L p .57797 .66357 L .707 .577 .707 r
F P
0 g
s
.52351 .31273 m .47864 .3164 L p .54282 .73458 L .707 .577 .707 r
F P
0 g
s
.54362 .73305 m .55561 .69943 L .58377 .70323 L p .707 .577 .707 r
F P
0 g
s
.58377 .70323 m .58098 .71107 L p .54362 .73305 L .707 .577 .707 r
F P
0 g
s
.58098 .71107 m .57178 .73685 L .55781 .73496 L p .707 .577 .707 r
F P
0 g
s
.55781 .73496 m .54362 .73305 L p .58098 .71107 L .707 .577 .707 r
F P
0 g
s
.54492 .74825 m .5494 .72128 L .54282 .73458 L .707 .577 .707 r
F
.55243 .78311 m .55798 .76609 L .58632 .76938 L p F P
0 g
s
.58632 .76938 m .58494 .7736 L p .55243 .78311 L .707 .577 .707 r
F P
0 g
s
.58494 .7736 m .58077 .78639 L .57423 .78563 L p .707 .577 .707 r
F P
0 g
s
.57423 .78563 m .55243 .78311 L p .58494 .7736 L .707 .577 .707 r
F P
0 g
s
.55412 .80822 m .55073 .74226 L .54492 .74825 L .707 .577 .707 r
F
.55546 .81695 m .55486 .80739 L p .55412 .80822 L F P
0 g
s
.55486 .80739 m .55073 .74226 L p .55412 .80822 L .707 .577 .707 r
F P
0 g
s
.55073 .74226 m .5494 .72128 L p .54492 .74825 L .707 .577 .707 r
F P
0 g
s
.5494 .72128 m .52351 .31273 L p .54282 .73458 L .707 .577 .707 r
F P
0 g
s
.57512 .68053 m .58416 .62671 L .61562 .63053 L p .707 .577 .707 r
F P
0 g
s
.61562 .63053 m .60657 .68434 L .57512 .68053 L p .707 .577 .707 r
F P
0 g
s
.58377 .70323 m .61407 .7115 L p .57936 .73231 L .707 .577 .707 r
F P
0 g
s
.57178 .73685 m .57657 .72344 L p .57936 .73231 L .707 .577 .707 r
F P
0 g
s
.57657 .72344 m .58377 .70323 L p .57936 .73231 L .707 .577 .707 r
F P
0 g
s
.64637 .63752 m .63732 .69133 L .60657 .68434 L p .707 .577 .707 r
F P
0 g
s
.60657 .68434 m .61562 .63053 L .64637 .63752 L p .707 .577 .707 r
F P
0 g
s
.64354 .72343 m .63155 .75705 L .60208 .74512 L p .707 .577 .707 r
F P
0 g
s
.60208 .74512 m .61407 .7115 L .64354 .72343 L p .707 .577 .707 r
F P
0 g
s
.61407 .7115 m .60208 .74512 L .57178 .73685 L p .707 .577 .707 r
F P
0 g
s
.58077 .78639 m .58632 .76938 L .61685 .77699 L p .707 .577 .707 r
F P
0 g
s
.64656 .7882 m .64101 .80521 L .61129 .794 L p .707 .577 .707 r
F P
0 g
s
.61129 .794 m .61685 .77699 L .64656 .7882 L p .707 .577 .707 r
F P
0 g
s
.61685 .77699 m .61129 .794 L .58077 .78639 L p .707 .577 .707 r
F P
0 g
s
.56492 .30592 m .59512 .78236 L p .6308 .80086 L .707 .577 .707 r
F P
0 g
s
.59512 .78236 m .59688 .81014 L .60332 .80838 L p .707 .577 .707 r
F P
0 g
s
.60332 .80838 m .6308 .80086 L p .59512 .78236 L .707 .577 .707 r
F P
0 g
s
.52351 .31273 m .55546 .81695 L .59688 .81014 L p .707 .577 .707 r
F P
0 g
s
.59688 .81014 m .56492 .30592 L .52351 .31273 L p .707 .577 .707 r
F P
0 g
s
.69878 .85394 m .69322 .87095 L .70054 .86112 L p .707 .577 .707 r
F P
0 g
s
.70054 .86112 m .70609 .8441 L .69878 .85394 L p .707 .577 .707 r
F P
0 g
s
.46668 .82078 m .43473 .31656 L .39605 .3132 L p .707 .577 .707 r
F P
0 g
s
.43473 .31656 m .46668 .82078 L .5106 .82062 L p .707 .577 .707 r
F P
0 g
s
.70637 .66958 m .69733 .72339 L .68504 .71186 L p .707 .577 .707 r
F P
0 g
s
.68504 .71186 m .69408 .65805 L .70637 .66958 L p .707 .577 .707 r
F P
0 g
s
.70231 .78157 m .69032 .81519 L .6882 .80204 L p .707 .577 .707 r
F P
0 g
s
.6882 .80204 m .70019 .76842 L .70231 .78157 L p .707 .577 .707 r
F P
0 g
s
.6308 .80086 m .59884 .29664 L .56492 .30592 L p .707 .577 .707 r
F P
0 g
s
.24917 .72157 m .25822 .66776 L .22747 .66076 L p .707 .577 .707 r
F P
0 g
s
.25822 .66776 m .24917 .72157 L .28063 .72538 L p .707 .577 .707 r
F P
0 g
s
.28063 .72538 m .28967 .67157 L .25822 .66776 L p .707 .577 .707 r
F P
0 g
s
.28967 .67157 m .28063 .72538 L .30971 .72565 L p .707 .577 .707 r
F P
0 g
s
.30971 .72565 m .31876 .67184 L .28967 .67157 L p .707 .577 .707 r
F P
0 g
s
.21842 .71458 m .22747 .66076 L .20043 .65128 L p .707 .577 .707 r
F P
0 g
s
.22747 .66076 m .21842 .71458 L .24917 .72157 L p .707 .577 .707 r
F P
0 g
s
.42801 .81743 m .39605 .3132 L .36641 .30666 L p .707 .577 .707 r
F P
0 g
s
.39605 .3132 m .42801 .81743 L .46668 .82078 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70609 .8441 m .70054 .86112 L .69831 .8483 L p .707 .577 .707 r
F P
0 g
s
.69831 .8483 m .70386 .83128 L .70609 .8441 L p .707 .577 .707 r
F P
0 g
s
.69408 .65805 m .68504 .71186 L .66436 .70082 L p .707 .577 .707 r
F P
0 g
s
.66436 .70082 m .67341 .647 L .69408 .65805 L p .707 .577 .707 r
F P
0 g
s
.31876 .67184 m .30971 .72565 L .33357 .72234 L p .707 .577 .707 r
F P
0 g
s
.33357 .72234 m .34262 .66853 L .31876 .67184 L p .707 .577 .707 r
F P
0 g
s
.19139 .7051 m .20043 .65128 L .17975 .64024 L p .707 .577 .707 r
F P
0 g
s
.20043 .65128 m .19139 .7051 L .21842 .71458 L p .707 .577 .707 r
F P
0 g
s
.70019 .76842 m .6882 .80204 L .67683 .78697 L p .707 .577 .707 r
F P
0 g
s
.67683 .78697 m .68882 .75336 L .70019 .76842 L p .707 .577 .707 r
F P
0 g
s
.67341 .647 m .66436 .70082 L .63732 .69133 L p .707 .577 .707 r
F P
0 g
s
.63732 .69133 m .64637 .63752 L .67341 .647 L p .707 .577 .707 r
F P
0 g
s
.6693 .73785 m .65731 .77147 L .63155 .75705 L p .707 .577 .707 r
F P
0 g
s
.63155 .75705 m .64354 .72343 L .6693 .73785 L p .707 .577 .707 r
F P
0 g
s
.64101 .80521 m .64656 .7882 L .67257 .80189 L p .707 .577 .707 r
F P
0 g
s
.59884 .29664 m .6308 .80086 L .65389 .79001 L p .707 .577 .707 r
F P
0 g
s
.65389 .79001 m .62193 .28579 L .59884 .29664 L p .707 .577 .707 r
F P
0 g
s
.24212 .77892 m .25411 .74531 L .22464 .73338 L p .707 .577 .707 r
F P
0 g
s
.25411 .74531 m .24212 .77892 L .27242 .78719 L p .707 .577 .707 r
F P
0 g
s
.27242 .78719 m .28441 .75358 L .25411 .74531 L p .707 .577 .707 r
F P
0 g
s
.21265 .76699 m .22464 .73338 L .19889 .71896 L p .707 .577 .707 r
F P
0 g
s
.22464 .73338 m .21265 .76699 L .24212 .77892 L p .707 .577 .707 r
F P
0 g
s
.28441 .75358 m .27242 .78719 L .30059 .791 L p .707 .577 .707 r
F P
0 g
s
.30059 .791 m .31258 .75738 L .28441 .75358 L p .707 .577 .707 r
F P
0 g
s
.70386 .83128 m .69831 .8483 L .68676 .83375 L p .707 .577 .707 r
F P
0 g
s
.68676 .83375 m .69231 .81674 L .70386 .83128 L p .707 .577 .707 r
F P
0 g
s
.25183 .81697 m .25738 .79996 L .22766 .78875 L p .707 .577 .707 r
F P
0 g
s
.25738 .79996 m .25183 .81697 L .28235 .82459 L p .707 .577 .707 r
F P
0 g
s
.28235 .82459 m .2879 .80758 L .25738 .79996 L p .707 .577 .707 r
F P
0 g
s
.17975 .64024 m .17071 .69405 L .19139 .7051 L p .707 .577 .707 r
F P
0 g
s
.34262 .66853 m .33357 .72234 L .34987 .71578 L p .707 .577 .707 r
F P
0 g
s
.34987 .71578 m .35892 .66196 L .34262 .66853 L p .707 .577 .707 r
F P
0 g
s
.1869 .75257 m .19889 .71896 L .17937 .70345 L p .707 .577 .707 r
F P
0 g
s
.19889 .71896 m .1869 .75257 L .21265 .76699 L p .707 .577 .707 r
F P
0 g
s
.39837 .81088 m .36641 .30666 L .3487 .29757 L p .707 .577 .707 r
F P
0 g
s
.36641 .30666 m .39837 .81088 L .42801 .81743 L p .707 .577 .707 r
F P
0 g
s
.22211 .80577 m .22766 .78875 L .20166 .77506 L p .707 .577 .707 r
F P
0 g
s
.22766 .78875 m .22211 .80577 L .25183 .81697 L p .707 .577 .707 r
F P
0 g
s
.17071 .69405 m .17975 .64024 L .16746 .62871 L p .707 .577 .707 r
F P
0 g
s
.2879 .80758 m .28235 .82459 L .31069 .82787 L p .707 .577 .707 r
F P
0 g
s
.31069 .82787 m .31625 .81086 L .2879 .80758 L p .707 .577 .707 r
F P
0 g
s
.31258 .75738 m .30059 .791 L .32386 .78996 L p .707 .577 .707 r
F P
0 g
s
.32386 .78996 m .33585 .75634 L .31258 .75738 L p .707 .577 .707 r
F P
0 g
s
.68882 .75336 m .67683 .78697 L .65731 .77147 L p .707 .577 .707 r
F P
0 g
s
.65731 .77147 m .6693 .73785 L .68882 .75336 L p .707 .577 .707 r
F P
0 g
s
.20166 .77506 m .1961 .79207 L .22211 .80577 L p .707 .577 .707 r
F P
0 g
s
.17937 .70345 m .16737 .73707 L .1869 .75257 L p .707 .577 .707 r
F P
0 g
s
.1961 .79207 m .20166 .77506 L .18191 .76021 L p .707 .577 .707 r
F P
0 g
s
.31625 .81086 m .31069 .82787 L .33408 .8265 L p .707 .577 .707 r
F P
0 g
s
.33408 .8265 m .33963 .80948 L .31625 .81086 L p .707 .577 .707 r
F P
0 g
s
.62193 .28579 m .65389 .79001 L .66391 .77865 L p .707 .577 .707 r
F P
0 g
s
.66391 .77865 m .63195 .27443 L .62193 .28579 L p .707 .577 .707 r
F P
0 g
s
.16746 .62871 m .15842 .68252 L .17071 .69405 L p .707 .577 .707 r
F P
0 g
s
.16737 .73707 m .17937 .70345 L .16799 .68839 L p .707 .577 .707 r
F P
0 g
s
.18191 .76021 m .17636 .77722 L .1961 .79207 L p .707 .577 .707 r
F P
0 g
s
.69231 .81674 m .68676 .83375 L .66701 .8189 L p .707 .577 .707 r
F P
0 g
s
.66701 .8189 m .67257 .80189 L .69231 .81674 L p .707 .577 .707 r
F P
0 g
s
.35892 .66196 m .34987 .71578 L .35702 .70661 L p .707 .577 .707 r
F P
0 g
s
.35702 .70661 m .36607 .65279 L .35892 .66196 L p .707 .577 .707 r
F P
0 g
s
.33585 .75634 m .32386 .78996 L .33996 .78418 L p .707 .577 .707 r
F P
0 g
s
.33996 .78418 m .35195 .75056 L .33585 .75634 L p .707 .577 .707 r
F P
0 g
s
.15842 .68252 m .16746 .62871 L .16476 .61783 L p .707 .577 .707 r
F P
0 g
s
.16799 .68839 m .156 .72201 L .16737 .73707 L p .707 .577 .707 r
F P
0 g
s
.17636 .77722 m .18191 .76021 L .17036 .74567 L p .707 .577 .707 r
F P
0 g
s
.33963 .80948 m .33408 .8265 L .35022 .8206 L p .707 .577 .707 r
F P
0 g
s
.35022 .8206 m .35577 .80359 L .33963 .80948 L p .707 .577 .707 r
F P
0 g
s
.38065 .80179 m .3487 .29757 L .34465 .28682 L p .707 .577 .707 r
F P
0 g
s
.3487 .29757 m .38065 .80179 L .39837 .81088 L p .707 .577 .707 r
F P
0 g
s
.17036 .74567 m .16481 .76268 L .17636 .77722 L p .707 .577 .707 r
F P
0 g
s
.67257 .80189 m .66701 .8189 L .64101 .80521 L p .707 .577 .707 r
F P
0 g
s
.156 .72201 m .16799 .68839 L .16588 .67524 L p .707 .577 .707 r
F P
0 g
s
.16476 .61783 m .15571 .67164 L .15842 .68252 L p .707 .577 .707 r
F P
0 g
s
.35195 .75056 m .33996 .78418 L .34731 .77422 L p .707 .577 .707 r
F P
0 g
s
.34731 .77422 m .3593 .74061 L .35195 .75056 L p .707 .577 .707 r
F P
0 g
s
.36607 .65279 m .35702 .70661 L .35432 .69572 L p .707 .577 .707 r
F P
0 g
s
.35432 .69572 m .36336 .64191 L .36607 .65279 L p .707 .577 .707 r
F P
0 g
s
.15571 .67164 m .16476 .61783 L .17191 .60866 L p .707 .577 .707 r
F P
0 g
s
.16588 .67524 m .15389 .70885 L .156 .72201 L p .707 .577 .707 r
F P
0 g
s
.16481 .76268 m .17036 .74567 L .16813 .73285 L p .707 .577 .707 r
F P
0 g
s
.66391 .77865 m .66063 .76994 L p .65756 .71699 L .707 .577 .707 r
F P
0 g
s
.63195 .27443 m .66288 .76251 L p .65756 .71699 L .707 .577 .707 r
F P
0 g
s
.66288 .76251 m .66391 .77865 L p .65756 .71699 L .707 .577 .707 r
F P
0 g
s
.6279 .26368 m .65986 .7679 L .64215 .75881 L p .707 .577 .707 r
F P
0 g
s
.64759 .686 m .65237 .67259 L p .6482 .63732 L .707 .577 .707 r
F P
0 g
s
.65867 .74682 m .63195 .27443 L .66063 .76994 L .707 .577 .707 r
F
.6279 .26368 m .63195 .27443 L p .65549 .69072 L F P
0 g
s
.65986 .7679 m .65403 .67589 L p .65549 .69072 L .707 .577 .707 r
F P
0 g
s
.65403 .67589 m .6279 .26368 L p .65549 .69072 L .707 .577 .707 r
F P
0 g
s
.64768 .56433 m .64473 .58187 L p .65092 .62968 L .707 .577 .707 r
F P
0 g
s
.64473 .58187 m .63863 .61815 L .64931 .62816 L p .707 .577 .707 r
F P
0 g
s
.64931 .62816 m .65092 .62968 L p .64473 .58187 L .707 .577 .707 r
F P
0 g
s
.65237 .67259 m .65958 .65238 L .64826 .63739 L p .707 .577 .707 r
F P
0 g
s
.64826 .63739 m .6482 .63732 L p .65237 .67259 L .707 .577 .707 r
F P
0 g
s
.65958 .65238 m .65237 .67259 L p .66711 .7015 L .707 .577 .707 r
F P
0 g
s
.65237 .67259 m .64759 .686 L .65394 .69104 L p .707 .577 .707 r
F P
0 g
s
.65394 .69104 m .66711 .7015 L p .65237 .67259 L .707 .577 .707 r
F P
0 g
s
.66063 .76994 m .65986 .7679 L p .65867 .74682 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35577 .80359 m .35022 .8206 L .35753 .81076 L p .707 .577 .707 r
F P
0 g
s
.35753 .81076 m .36308 .79375 L .35577 .80359 L p .707 .577 .707 r
F P
0 g
s
.16813 .73285 m .16258 .74986 L .16481 .76268 L p .707 .577 .707 r
F P
0 g
s
.15389 .70885 m .16588 .67524 L .17323 .66528 L p .707 .577 .707 r
F P
0 g
s
.17191 .60866 m .16286 .66247 L .15571 .67164 L p .707 .577 .707 r
F P
0 g
s
.3593 .74061 m .34731 .77422 L .34519 .76107 L p .707 .577 .707 r
F P
0 g
s
.34519 .76107 m .35719 .72745 L .3593 .74061 L p .707 .577 .707 r
F P
0 g
s
.34465 .28682 m .37661 .79104 L .38065 .80179 L p .707 .577 .707 r
F P
0 g
s
.37661 .79104 m .34465 .28682 L .35466 .27546 L p .707 .577 .707 r
F P
0 g
s
.36336 .64191 m .35432 .69572 L .34203 .6842 L p .707 .577 .707 r
F P
0 g
s
.34203 .6842 m .35107 .63038 L .36336 .64191 L p .707 .577 .707 r
F P
0 g
s
.16286 .66247 m .17191 .60866 L .18821 .60209 L p .707 .577 .707 r
F P
0 g
s
.17323 .66528 m .16124 .6989 L .15389 .70885 L p .707 .577 .707 r
F P
0 g
s
.16258 .74986 m .16813 .73285 L .17545 .72301 L p .707 .577 .707 r
F P
0 g
s
.36308 .79375 m .35753 .81076 L .3553 .79795 L p .707 .577 .707 r
F P
0 g
s
.3553 .79795 m .36085 .78093 L .36308 .79375 L p .707 .577 .707 r
F P
0 g
s
.17545 .72301 m .16989 .74002 L .16258 .74986 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16124 .6989 m .17323 .66528 L .18933 .65951 L p .707 .577 .707 r
F P
0 g
s
.64215 .75881 m .61019 .25458 L .6279 .26368 L p .707 .577 .707 r
F P
0 g
s
.18821 .60209 m .17917 .65591 L .16286 .66247 L p .707 .577 .707 r
F P
0 g
s
.35719 .72745 m .34519 .76107 L .33382 .74601 L p .707 .577 .707 r
F P
0 g
s
.33382 .74601 m .34581 .71239 L .35719 .72745 L p .707 .577 .707 r
F P
0 g
s
.35107 .63038 m .34203 .6842 L .32135 .67315 L p .707 .577 .707 r
F P
0 g
s
.32135 .67315 m .3304 .61934 L .35107 .63038 L p .707 .577 .707 r
F P
0 g
s
.17917 .65591 m .18821 .60209 L .21207 .59878 L p .707 .577 .707 r
F P
0 g
s
.18933 .65951 m .17734 .69312 L .16124 .6989 L p .707 .577 .707 r
F P
0 g
s
.16989 .74002 m .17545 .72301 L .19159 .71712 L p .707 .577 .707 r
F P
0 g
s
.36085 .78093 m .3553 .79795 L .34375 .7834 L p .707 .577 .707 r
F P
0 g
s
.34375 .7834 m .3493 .76639 L .36085 .78093 L p .707 .577 .707 r
F P
0 g
s
.19159 .71712 m .18603 .73413 L .16989 .74002 L p .707 .577 .707 r
F P
0 g
s
.38662 .77968 m .35466 .27546 L .37776 .26461 L p .707 .577 .707 r
F P
0 g
s
.35466 .27546 m .38662 .77968 L .37661 .79104 L p .707 .577 .707 r
F P
0 g
s
.17734 .69312 m .18933 .65951 L .2126 .65847 L p .707 .577 .707 r
F P
0 g
s
.21207 .59878 m .20303 .6526 L .17917 .65591 L p .707 .577 .707 r
F P
0 g
s
.3304 .61934 m .32135 .67315 L .29431 .66367 L p .707 .577 .707 r
F P
0 g
s
.29431 .66367 m .30336 .60985 L .3304 .61934 L p .707 .577 .707 r
F P
0 g
s
.20303 .6526 m .21207 .59878 L .24115 .59905 L p .707 .577 .707 r
F P
0 g
s
.34581 .71239 m .33382 .74601 L .3143 .73051 L p .707 .577 .707 r
F P
0 g
s
.3143 .73051 m .32629 .69689 L .34581 .71239 L p .707 .577 .707 r
F P
0 g
s
.61019 .25458 m .63741 .68412 L p .61233 .71506 L .707 .577 .707 r
F P
0 g
s
.6482 .63732 m .63621 .67093 L .64194 .67852 L p .707 .577 .707 r
F P
0 g
s
.64194 .67852 m .64759 .686 L p .64777 .67133 L .707 .577 .707 r
F P
0 g
s
.64777 .67133 m .6482 .63732 L .64194 .67852 L .707 .577 .707 r
F
.64215 .75881 m .6125 .75226 L p .61233 .71506 L F P
0 g
s
.63741 .68412 m .64215 .75881 L p .61233 .71506 L .707 .577 .707 r
F P
0 g
s
.6125 .75226 m .58054 .24804 L .61019 .25458 L p .707 .577 .707 r
F P
0 g
s
.2126 .65847 m .20061 .69208 L .17734 .69312 L p .707 .577 .707 r
F P
0 g
s
.18603 .73413 m .19159 .71712 L .21497 .71574 L p .707 .577 .707 r
F P
0 g
s
.30336 .60985 m .29431 .66367 L .26356 .65668 L p .707 .577 .707 r
F P
0 g
s
.26356 .65668 m .27261 .60286 L .30336 .60985 L p .707 .577 .707 r
F P
0 g
s
.23211 .65286 m .24115 .59905 L .27261 .60286 L p .707 .577 .707 r
F P
0 g
s
.24115 .59905 m .23211 .65286 L .20303 .6526 L p .707 .577 .707 r
F P
0 g
s
.3493 .76639 m .34375 .7834 L .324 .76855 L p .707 .577 .707 r
F P
0 g
s
.324 .76855 m .32956 .75154 L .3493 .76639 L p .707 .577 .707 r
F P
0 g
s
.20061 .69208 m .2126 .65847 L .24076 .66227 L p .707 .577 .707 r
F P
0 g
s
.21497 .71574 m .20942 .73275 L .18603 .73413 L p .707 .577 .707 r
F P
0 g
s
.27261 .60286 m .26356 .65668 L .23211 .65286 L p .707 .577 .707 r
F P
0 g
s
.72939 .6572 m .73843 .60338 L .70768 .59639 L p .707 .577 .707 r
F P
0 g
s
.73843 .60338 m .72939 .6572 L .76084 .66101 L p .707 .577 .707 r
F P
0 g
s
.76084 .66101 m .76989 .6072 L .73843 .60338 L p .707 .577 .707 r
F P
0 g
s
.32629 .69689 m .3143 .73051 L .28854 .71608 L p .707 .577 .707 r
F P
0 g
s
.28854 .71608 m .30053 .68247 L .32629 .69689 L p .707 .577 .707 r
F P
0 g
s
.76989 .6072 m .76084 .66101 L .78992 .66128 L p .707 .577 .707 r
F P
0 g
s
.78992 .66128 m .79897 .60746 L .76989 .6072 L p .707 .577 .707 r
F P
0 g
s
.69864 .6502 m .70768 .59639 L .68064 .58691 L p .707 .577 .707 r
F P
0 g
s
.70768 .59639 m .69864 .6502 L .72939 .6572 L p .707 .577 .707 r
F P
0 g
s
.37776 .26461 m .40971 .76883 L .38662 .77968 L p .707 .577 .707 r
F P
0 g
s
.40971 .76883 m .37776 .26461 L .41167 .25532 L p .707 .577 .707 r
F P
0 g
s
.24076 .66227 m .22877 .69588 L .20061 .69208 L p .707 .577 .707 r
F P
0 g
s
.22877 .69588 m .24076 .66227 L .27106 .67054 L p .707 .577 .707 r
F P
0 g
s
.20942 .73275 m .21497 .71574 L .24331 .71902 L p .707 .577 .707 r
F P
0 g
s
.30053 .68247 m .28854 .71608 L .25907 .70415 L p .707 .577 .707 r
F P
0 g
s
.25907 .70415 m .27106 .67054 L .30053 .68247 L p .707 .577 .707 r
F P
0 g
s
.32956 .75154 m .324 .76855 L .298 .75486 L p .707 .577 .707 r
F P
0 g
s
.298 .75486 m .30355 .73785 L .32956 .75154 L p .707 .577 .707 r
F P
0 g
s
.27106 .67054 m .25907 .70415 L .22877 .69588 L p .707 .577 .707 r
F P
0 g
s
.79897 .60746 m .78992 .66128 L .81378 .65797 L p .707 .577 .707 r
F P
0 g
s
.81378 .65797 m .82283 .60415 L .79897 .60746 L p .707 .577 .707 r
F P
0 g
s
.24331 .71902 m .23776 .73604 L .20942 .73275 L p .707 .577 .707 r
F P
0 g
s
.6716 .64072 m .68064 .58691 L .65997 .57586 L p .707 .577 .707 r
F P
0 g
s
.68064 .58691 m .6716 .64072 L .69864 .6502 L p .707 .577 .707 r
F P
0 g
s
.58054 .24804 m .6125 .75226 L .57383 .74891 L p .707 .577 .707 r
F P
0 g
s
.57383 .74891 m .54187 .24468 L .58054 .24804 L p .707 .577 .707 r
F P
0 g
s
.23776 .73604 m .24331 .71902 L .27384 .72664 L p .707 .577 .707 r
F P
0 g
s
.72234 .72785 m .73433 .69423 L .70486 .6823 L p .707 .577 .707 r
F P
0 g
s
.73433 .69423 m .72234 .72785 L .75264 .73612 L p .707 .577 .707 r
F P
0 g
s
.75264 .73612 m .76463 .7025 L .73433 .69423 L p .707 .577 .707 r
F P
0 g
s
.30355 .73785 m .298 .75486 L .26828 .74365 L p .707 .577 .707 r
F P
0 g
s
.26828 .74365 m .27384 .72664 L .30355 .73785 L p .707 .577 .707 r
F P
0 g
s
.69286 .71592 m .70486 .6823 L .6791 .66788 L p .707 .577 .707 r
F P
0 g
s
.70486 .6823 m .69286 .71592 L .72234 .72785 L p .707 .577 .707 r
F P
0 g
s
.27384 .72664 m .26828 .74365 L .23776 .73604 L p .707 .577 .707 r
F P
0 g
s
.76463 .7025 m .75264 .73612 L .7808 .73992 L p .707 .577 .707 r
F P
0 g
s
.7808 .73992 m .79279 .70631 L .76463 .7025 L p .707 .577 .707 r
F P
0 g
s
.44363 .75954 m .41167 .25532 L .45309 .24851 L p .707 .577 .707 r
F P
0 g
s
.41167 .25532 m .44363 .75954 L .40971 .76883 L p .707 .577 .707 r
F P
0 g
s
.65997 .57586 m .65092 .62968 L .6716 .64072 L p .707 .577 .707 r
F P
0 g
s
.82283 .60415 m .81378 .65797 L .83009 .6514 L p .707 .577 .707 r
F P
0 g
s
.83009 .6514 m .83913 .59759 L .82283 .60415 L p .707 .577 .707 r
F P
0 g
s
.65092 .62968 m .65997 .57586 L .64768 .56433 L p .707 .577 .707 r
F P
0 g
s
.66711 .7015 m .6791 .66788 L .65958 .65238 L p .707 .577 .707 r
F P
0 g
s
.6791 .66788 m .66711 .7015 L .69286 .71592 L p .707 .577 .707 r
F P
0 g
s
.73204 .77528 m .73759 .75827 L .70788 .74707 L p .707 .577 .707 r
F P
0 g
s
.73759 .75827 m .73204 .77528 L .76256 .7829 L p .707 .577 .707 r
F P
0 g
s
.76256 .7829 m .76812 .76589 L .73759 .75827 L p .707 .577 .707 r
F P
0 g
s
.54187 .24468 m .57383 .74891 L .52991 .74907 L p .707 .577 .707 r
F P
0 g
s
.52991 .74907 m .49795 .24485 L .54187 .24468 L p .707 .577 .707 r
F P
0 g
s
.70232 .76408 m .70788 .74707 L .68187 .73337 L p .707 .577 .707 r
F P
0 g
s
.70788 .74707 m .70232 .76408 L .73204 .77528 L p .707 .577 .707 r
F P
0 g
s
.79279 .70631 m .7808 .73992 L .80407 .73888 L p .707 .577 .707 r
F P
0 g
s
.80407 .73888 m .81606 .70527 L .79279 .70631 L p .707 .577 .707 r
F P
0 g
s
.76812 .76589 m .76256 .7829 L .79091 .78618 L p .707 .577 .707 r
F P
0 g
s
.79091 .78618 m .79646 .76917 L .76812 .76589 L p .707 .577 .707 r
F P
0 g
s
.48505 .75274 m .45309 .24851 L .49795 .24485 L p .707 .577 .707 r
F P
0 g
s
.45309 .24851 m .48505 .75274 L .44363 .75954 L p .707 .577 .707 r
F P
0 g
s
.68187 .73337 m .67632 .75038 L .70232 .76408 L p .707 .577 .707 r
F P
0 g
s
.49795 .24485 m .52991 .74907 L .48505 .75274 L p .707 .577 .707 r
F P
0 g
s
.67632 .75038 m .68187 .73337 L .66213 .71852 L p .707 .577 .707 r
F P
0 g
s
.79646 .76917 m .79091 .78618 L .81429 .78481 L p .707 .577 .707 r
F P
0 g
s
.81429 .78481 m .81984 .7678 L .79646 .76917 L p .707 .577 .707 r
F P
0 g
s
.83913 .59759 m .83009 .6514 L .83724 .64223 L p .707 .577 .707 r
F P
0 g
s
.83724 .64223 m .84628 .58842 L .83913 .59759 L p .707 .577 .707 r
F P
0 g
s
.66213 .71852 m .65657 .73554 L .67632 .75038 L p .707 .577 .707 r
F P
0 g
s
.63863 .61815 m .64768 .56433 L .64497 .55345 L p .707 .577 .707 r
F P
0 g
s
.81606 .70527 m .80407 .73888 L .82017 .7331 L p .707 .577 .707 r
F P
0 g
s
.82017 .7331 m .83216 .69949 L .81606 .70527 L p .707 .577 .707 r
F P
0 g
s
.65657 .73554 m .66213 .71852 L .65058 .70398 L p .707 .577 .707 r
F P
0 g
s
.81984 .7678 m .81429 .78481 L .83043 .77892 L p .707 .577 .707 r
F P
0 g
s
.83043 .77892 m .83598 .7619 L .81984 .7678 L p .707 .577 .707 r
F P
0 g
s
.65058 .70398 m .64502 .72099 L .65657 .73554 L p .707 .577 .707 r
F P
0 g
s
.64497 .55345 m .63593 .60727 L .63863 .61815 L p .707 .577 .707 r
F P
0 g
s
.63621 .67093 m .6482 .63732 L .64609 .62416 L p .707 .577 .707 r
F P
0 g
s
.84628 .58842 m .83724 .64223 L .83453 .63135 L p .707 .577 .707 r
F P
0 g
s
.83453 .63135 m .84358 .57754 L .84628 .58842 L p .707 .577 .707 r
F P
0 g
s
.83216 .69949 m .82017 .7331 L .82752 .72315 L p .707 .577 .707 r
F P
0 g
s
.82752 .72315 m .83951 .68953 L .83216 .69949 L p .707 .577 .707 r
F P
0 g
s
.63593 .60727 m .64497 .55345 L .65212 .54428 L p .707 .577 .707 r
F P
0 g
s
.64609 .62416 m .6341 .65778 L .63621 .67093 L p .707 .577 .707 r
F P
0 g
s
.64502 .72099 m .65058 .70398 L .64835 .69116 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83598 .7619 m .83043 .77892 L .83774 .76908 L p .707 .577 .707 r
F P
0 g
s
.83774 .76908 m .8433 .75207 L .83598 .7619 L p .707 .577 .707 r
F P
0 g
s
.64835 .69116 m .64279 .70817 L .64502 .72099 L p .707 .577 .707 r
F P
0 g
s
.65212 .54428 m .64308 .59809 L .63593 .60727 L p .707 .577 .707 r
F P
0 g
s
.6341 .65778 m .64609 .62416 L .65344 .61421 L p .707 .577 .707 r
F P
0 g
s
.84358 .57754 m .83453 .63135 L .82224 .61982 L p .707 .577 .707 r
F P
0 g
s
.82224 .61982 m .83129 .56601 L .84358 .57754 L p .707 .577 .707 r
F P
0 g
s
.83951 .68953 m .82752 .72315 L .82541 .71 L p .707 .577 .707 r
F P
0 g
s
.82541 .71 m .8374 .67638 L .83951 .68953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64308 .59809 m .65212 .54428 L .66843 .53772 L p .707 .577 .707 r
F P
0 g
s
.65344 .61421 m .64145 .64783 L .6341 .65778 L p .707 .577 .707 r
F P
0 g
s
.38638 .62953 m .39542 .57572 L .36467 .56873 L p .707 .577 .707 r
F P
0 g
s
.39542 .57572 m .38638 .62953 L .41783 .63335 L p .707 .577 .707 r
F P
0 g
s
.41783 .63335 m .42688 .57953 L .39542 .57572 L p .707 .577 .707 r
F P
0 g
s
.64279 .70817 m .64835 .69116 L .65566 .68132 L p .707 .577 .707 r
F P
0 g
s
.42688 .57953 m .41783 .63335 L .44691 .63361 L p .707 .577 .707 r
F P
0 g
s
.44691 .63361 m .45596 .5798 L .42688 .57953 L p .707 .577 .707 r
F P
0 g
s
.35563 .62254 m .36467 .56873 L .33763 .55924 L p .707 .577 .707 r
F P
0 g
s
.36467 .56873 m .35563 .62254 L .38638 .62953 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.8433 .75207 m .83774 .76908 L .83551 .75626 L p .707 .577 .707 r
F P
0 g
s
.83551 .75626 m .84107 .73925 L .8433 .75207 L p .707 .577 .707 r
F P
0 g
s
.65566 .68132 m .65011 .69833 L .64279 .70817 L p .707 .577 .707 r
F P
0 g
s
.66843 .53772 m .65938 .59153 L .64308 .59809 L p .707 .577 .707 r
F P
0 g
s
.64145 .64783 m .65344 .61421 L .66954 .60843 L p .707 .577 .707 r
F P
0 g
s
.83129 .56601 m .82224 .61982 L .80157 .60878 L p .707 .577 .707 r
F P
0 g
s
.80157 .60878 m .81061 .55496 L .83129 .56601 L p .707 .577 .707 r
F P
0 g
s
.45596 .5798 m .44691 .63361 L .47077 .6303 L p .707 .577 .707 r
F P
0 g
s
.47077 .6303 m .47982 .57649 L .45596 .5798 L p .707 .577 .707 r
F P
0 g
s
.32859 .61306 m .33763 .55924 L .31696 .5482 L p .707 .577 .707 r
F P
0 g
s
.33763 .55924 m .32859 .61306 L .35563 .62254 L p .707 .577 .707 r
F P
0 g
s
.65938 .59153 m .66843 .53772 L .69229 .53441 L p .707 .577 .707 r
F P
0 g
s
.8374 .67638 m .82541 .71 L .81403 .69493 L p .707 .577 .707 r
F P
0 g
s
.81403 .69493 m .82603 .66132 L .8374 .67638 L p .707 .577 .707 r
F P
0 g
s
.37933 .68689 m .39132 .65327 L .36185 .64134 L p .707 .577 .707 r
F P
0 g
s
.39132 .65327 m .37933 .68689 L .40963 .69516 L p .707 .577 .707 r
F P
0 g
s
.40963 .69516 m .42162 .66154 L .39132 .65327 L p .707 .577 .707 r
F P
0 g
s
.66954 .60843 m .65755 .64205 L .64145 .64783 L p .707 .577 .707 r
F P
0 g
s
.34985 .67496 m .36185 .64134 L .33609 .62692 L p .707 .577 .707 r
F P
0 g
s
.36185 .64134 m .34985 .67496 L .37933 .68689 L p .707 .577 .707 r
F P
0 g
s
.42162 .66154 m .40963 .69516 L .43779 .69896 L p .707 .577 .707 r
F P
0 g
s
.43779 .69896 m .44978 .66534 L .42162 .66154 L p .707 .577 .707 r
F P
0 g
s
.65011 .69833 m .65566 .68132 L .6718 .67543 L p .707 .577 .707 r
F P
0 g
s
.84107 .73925 m .83551 .75626 L .82396 .74171 L p .707 .577 .707 r
F P
0 g
s
.82396 .74171 m .82952 .7247 L .84107 .73925 L p .707 .577 .707 r
F P
0 g
s
.6718 .67543 m .66625 .69244 L .65011 .69833 L p .707 .577 .707 r
F P
0 g
s
.38903 .72493 m .39458 .70792 L .36487 .69672 L p .707 .577 .707 r
F P
0 g
s
.39458 .70792 m .38903 .72493 L .41955 .73255 L p .707 .577 .707 r
F P
0 g
s
.41955 .73255 m .42511 .71554 L .39458 .70792 L p .707 .577 .707 r
F P
0 g
s
.31696 .5482 m .30791 .60201 L .32859 .61306 L p .707 .577 .707 r
F P
0 g
s
.47982 .57649 m .47077 .6303 L .48708 .62374 L p .707 .577 .707 r
F P
0 g
s
.48708 .62374 m .49612 .56993 L .47982 .57649 L p .707 .577 .707 r
F P
0 g
s
.69229 .53441 m .68324 .58822 L .65938 .59153 L p .707 .577 .707 r
F P
0 g
s
.3241 .66053 m .33609 .62692 L .31657 .61142 L p .707 .577 .707 r
F P
0 g
s
.33609 .62692 m .3241 .66053 L .34985 .67496 L p .707 .577 .707 r
F P
0 g
s
.81061 .55496 m .80157 .60878 L .77453 .59929 L p .707 .577 .707 r
F P
0 g
s
.77453 .59929 m .78357 .54548 L .81061 .55496 L p .707 .577 .707 r
F P
0 g
s
.65755 .64205 m .66954 .60843 L .69281 .60739 L p .707 .577 .707 r
F P
0 g
s
.35931 .71373 m .36487 .69672 L .33886 .68302 L p .707 .577 .707 r
F P
0 g
s
.36487 .69672 m .35931 .71373 L .38903 .72493 L p .707 .577 .707 r
F P
0 g
s
.68324 .58822 m .69229 .53441 L .72137 .53468 L p .707 .577 .707 r
F P
0 g
s
.30791 .60201 m .31696 .5482 L .30467 .53667 L p .707 .577 .707 r
F P
0 g
s
.42511 .71554 m .41955 .73255 L .4479 .73583 L p .707 .577 .707 r
F P
0 g
s
.4479 .73583 m .45345 .71882 L .42511 .71554 L p .707 .577 .707 r
F P
0 g
s
.44978 .66534 m .43779 .69896 L .46106 .69792 L p .707 .577 .707 r
F P
0 g
s
.46106 .69792 m .47305 .6643 L .44978 .66534 L p .707 .577 .707 r
F P
0 g
s
.82603 .66132 m .81403 .69493 L .79451 .67943 L p .707 .577 .707 r
F P
0 g
s
.79451 .67943 m .80651 .64582 L .82603 .66132 L p .707 .577 .707 r
F P
0 g
s
.33886 .68302 m .33331 .70003 L .35931 .71373 L p .707 .577 .707 r
F P
0 g
s
.31657 .61142 m .30458 .64503 L .3241 .66053 L p .707 .577 .707 r
F P
0 g
s
.78357 .54548 m .77453 .59929 L .74378 .5923 L p .707 .577 .707 r
F P
0 g
s
.74378 .5923 m .75282 .53849 L .78357 .54548 L p .707 .577 .707 r
F P
0 g
s
.33331 .70003 m .33886 .68302 L .31912 .66817 L p .707 .577 .707 r
F P
0 g
s
.69281 .60739 m .68082 .64101 L .65755 .64205 L p .707 .577 .707 r
F P
0 g
s
.71232 .58849 m .72137 .53468 L .75282 .53849 L p .707 .577 .707 r
F P
0 g
s
.72137 .53468 m .71232 .58849 L .68324 .58822 L p .707 .577 .707 r
F P
0 g
s
.66625 .69244 m .6718 .67543 L .69519 .67405 L p .707 .577 .707 r
F P
0 g
s
.45345 .71882 m .4479 .73583 L .47128 .73446 L p .707 .577 .707 r
F P
0 g
s
.47128 .73446 m .47683 .71745 L .45345 .71882 L p .707 .577 .707 r
F P
0 g
s
.75282 .53849 m .74378 .5923 L .71232 .58849 L p .707 .577 .707 r
F P
0 g
s
.30467 .53667 m .29562 .59048 L .30791 .60201 L p .707 .577 .707 r
F P
0 g
s
.30458 .64503 m .31657 .61142 L .30519 .59635 L p .707 .577 .707 r
F P
0 g
s
.31912 .66817 m .31356 .68519 L .33331 .70003 L p .707 .577 .707 r
F P
0 g
s
.68082 .64101 m .69281 .60739 L .72098 .61119 L p .707 .577 .707 r
F P
0 g
s
.82952 .7247 m .82396 .74171 L .80422 .72687 L p .707 .577 .707 r
F P
0 g
s
.80422 .72687 m .80977 .70985 L .82952 .7247 L p .707 .577 .707 r
F P
0 g
s
.69519 .67405 m .68963 .69107 L .66625 .69244 L p .707 .577 .707 r
F P
0 g
s
.49612 .56993 m .48708 .62374 L .49423 .61457 L p .707 .577 .707 r
F P
0 g
s
.49423 .61457 m .50327 .56075 L .49612 .56993 L p .707 .577 .707 r
F P
0 g
s
.47305 .6643 m .46106 .69792 L .47716 .69214 L p .707 .577 .707 r
F P
0 g
s
.47716 .69214 m .48915 .65852 L .47305 .6643 L p .707 .577 .707 r
F P
0 g
s
.80651 .64582 m .79451 .67943 L .76876 .66501 L p .707 .577 .707 r
F P
0 g
s
.76876 .66501 m .78075 .63139 L .80651 .64582 L p .707 .577 .707 r
F P
0 g
s
.29562 .59048 m .30467 .53667 L .30196 .52579 L p .707 .577 .707 r
F P
0 g
s
.30519 .59635 m .2932 .62997 L .30458 .64503 L p .707 .577 .707 r
F P
0 g
s
.31356 .68519 m .31912 .66817 L .30757 .65363 L p .707 .577 .707 r
F P
0 g
s
.72098 .61119 m .70899 .64481 L .68082 .64101 L p .707 .577 .707 r
F P
0 g
s
.70899 .64481 m .72098 .61119 L .75128 .61946 L p .707 .577 .707 r
F P
0 g
s
.78075 .63139 m .76876 .66501 L .73929 .65308 L p .707 .577 .707 r
F P
0 g
s
.73929 .65308 m .75128 .61946 L .78075 .63139 L p .707 .577 .707 r
F P
0 g
s
.68963 .69107 m .69519 .67405 L .72353 .67734 L p .707 .577 .707 r
F P
0 g
s
.47683 .71745 m .47128 .73446 L .48742 .72856 L p .707 .577 .707 r
F P
0 g
s
.48742 .72856 m .49297 .71155 L .47683 .71745 L p .707 .577 .707 r
F P
0 g
s
.30757 .65363 m .30201 .67064 L .31356 .68519 L p .707 .577 .707 r
F P
0 g
s
.75128 .61946 m .73929 .65308 L .70899 .64481 L p .707 .577 .707 r
F P
0 g
s
.80977 .70985 m .80422 .72687 L .77822 .71317 L p .707 .577 .707 r
F P
0 g
s
.77822 .71317 m .78377 .69616 L .80977 .70985 L p .707 .577 .707 r
F P
0 g
s
.2932 .62997 m .30519 .59635 L .30308 .5832 L p .707 .577 .707 r
F P
0 g
s
.72353 .67734 m .71797 .69435 L .68963 .69107 L p .707 .577 .707 r
F P
0 g
s
.30196 .52579 m .29292 .5796 L .29562 .59048 L p .707 .577 .707 r
F P
0 g
s
.48915 .65852 m .47716 .69214 L .48451 .68219 L p .707 .577 .707 r
F P
0 g
s
.48451 .68219 m .4965 .64857 L .48915 .65852 L p .707 .577 .707 r
F P
0 g
s
.71797 .69435 m .72353 .67734 L .75405 .68495 L p .707 .577 .707 r
F P
0 g
s
.50327 .56075 m .49423 .61457 L .49152 .60369 L p .707 .577 .707 r
F P
0 g
s
.49152 .60369 m .50057 .54987 L .50327 .56075 L p .707 .577 .707 r
F P
0 g
s
.78377 .69616 m .77822 .71317 L .7485 .70197 L p .707 .577 .707 r
F P
0 g
s
.7485 .70197 m .75405 .68495 L .78377 .69616 L p .707 .577 .707 r
F P
0 g
s
.29292 .5796 m .30196 .52579 L .30911 .51662 L p .707 .577 .707 r
F P
0 g
s
.75405 .68495 m .7485 .70197 L .71797 .69435 L p .707 .577 .707 r
F P
0 g
s
.30308 .5832 m .29109 .61682 L .2932 .62997 L p .707 .577 .707 r
F P
0 g
s
.30201 .67064 m .30757 .65363 L .30534 .64081 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49297 .71155 m .48742 .72856 L .49473 .71873 L p .707 .577 .707 r
F P
0 g
s
.49473 .71873 m .50029 .70171 L .49297 .71155 L p .707 .577 .707 r
F P
0 g
s
.30534 .64081 m .29978 .65782 L .30201 .67064 L p .707 .577 .707 r
F P
0 g
s
.29109 .61682 m .30308 .5832 L .31043 .57325 L p .707 .577 .707 r
F P
0 g
s
.30911 .51662 m .30007 .57043 L .29292 .5796 L p .707 .577 .707 r
F P
0 g
s
.4965 .64857 m .48451 .68219 L .4824 .66903 L p .707 .577 .707 r
F P
0 g
s
.4824 .66903 m .49439 .63542 L .4965 .64857 L p .707 .577 .707 r
F P
0 g
s
.50057 .54987 m .49152 .60369 L .47923 .59216 L p .707 .577 .707 r
F P
0 g
s
.47923 .59216 m .48828 .53834 L .50057 .54987 L p .707 .577 .707 r
F P
0 g
s
.30007 .57043 m .30911 .51662 L .32541 .51005 L p .707 .577 .707 r
F P
0 g
s
.31043 .57325 m .29844 .60686 L .29109 .61682 L p .707 .577 .707 r
F P
0 g
s
.29978 .65782 m .30534 .64081 L .31265 .63097 L p .707 .577 .707 r
F P
0 g
s
.50029 .70171 m .49473 .71873 L .4925 .70591 L p .707 .577 .707 r
F P
0 g
s
.4925 .70591 m .49806 .6889 L .50029 .70171 L p .707 .577 .707 r
F P
0 g
s
.31265 .63097 m .3071 .64798 L .29978 .65782 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.29844 .60686 m .31043 .57325 L .32653 .56747 L p .707 .577 .707 r
F P
0 g
s
.32541 .51005 m .31637 .56387 L .30007 .57043 L p .707 .577 .707 r
F P
0 g
s
.49439 .63542 m .4824 .66903 L .47102 .65397 L p .707 .577 .707 r
F P
0 g
s
.47102 .65397 m .48302 .62035 L .49439 .63542 L p .707 .577 .707 r
F P
0 g
s
.48828 .53834 m .47923 .59216 L .45856 .58111 L p .707 .577 .707 r
F P
0 g
s
.45856 .58111 m .4676 .5273 L .48828 .53834 L p .707 .577 .707 r
F P
0 g
s
.31637 .56387 m .32541 .51005 L .34927 .50674 L p .707 .577 .707 r
F P
0 g
s
.32653 .56747 m .31454 .60108 L .29844 .60686 L p .707 .577 .707 r
F P
0 g
s
.3071 .64798 m .31265 .63097 L .32879 .62508 L p .707 .577 .707 r
F P
0 g
s
.49806 .6889 m .4925 .70591 L .48095 .69136 L p .707 .577 .707 r
F P
0 g
s
.48095 .69136 m .48651 .67435 L .49806 .6889 L p .707 .577 .707 r
F P
0 g
s
.32879 .62508 m .32324 .64209 L .3071 .64798 L p .707 .577 .707 r
F P
0 g
s
.31454 .60108 m .32653 .56747 L .3498 .56643 L p .707 .577 .707 r
F P
0 g
s
.34927 .50674 m .34023 .56056 L .31637 .56387 L p .707 .577 .707 r
F P
0 g
s
.4676 .5273 m .45856 .58111 L .43152 .57163 L p .707 .577 .707 r
F P
0 g
s
.43152 .57163 m .44056 .51782 L .4676 .5273 L p .707 .577 .707 r
F P
0 g
s
.34023 .56056 m .34927 .50674 L .37836 .50701 L p .707 .577 .707 r
F P
0 g
s
.48302 .62035 m .47102 .65397 L .4515 .63847 L p .707 .577 .707 r
F P
0 g
s
.4515 .63847 m .46349 .60485 L .48302 .62035 L p .707 .577 .707 r
F P
0 g
s
.3498 .56643 m .33781 .60004 L .31454 .60108 L p .707 .577 .707 r
F P
0 g
s
.32324 .64209 m .32879 .62508 L .35217 .6237 L p .707 .577 .707 r
F P
0 g
s
.44056 .51782 m .43152 .57163 L .40077 .56464 L p .707 .577 .707 r
F P
0 g
s
.40077 .56464 m .40981 .51082 L .44056 .51782 L p .707 .577 .707 r
F P
0 g
s
.36931 .56082 m .37836 .50701 L .40981 .51082 L p .707 .577 .707 r
F P
0 g
s
.37836 .50701 m .36931 .56082 L .34023 .56056 L p .707 .577 .707 r
F P
0 g
s
.48651 .67435 m .48095 .69136 L .46121 .67652 L p .707 .577 .707 r
F P
0 g
s
.46121 .67652 m .46676 .6595 L .48651 .67435 L p .707 .577 .707 r
F P
0 g
s
.33781 .60004 m .3498 .56643 L .37797 .57023 L p .707 .577 .707 r
F P
0 g
s
.35217 .6237 m .34662 .64072 L .32324 .64209 L p .707 .577 .707 r
F P
0 g
s
.40981 .51082 m .40077 .56464 L .36931 .56082 L p .707 .577 .707 r
F P
0 g
s
.46349 .60485 m .4515 .63847 L .42575 .62405 L p .707 .577 .707 r
F P
0 g
s
.42575 .62405 m .43774 .59043 L .46349 .60485 L p .707 .577 .707 r
F P
0 g
s
.37797 .57023 m .36598 .60385 L .33781 .60004 L p .707 .577 .707 r
F P
0 g
s
.36598 .60385 m .37797 .57023 L .40827 .5785 L p .707 .577 .707 r
F P
0 g
s
.34662 .64072 m .35217 .6237 L .38052 .62699 L p .707 .577 .707 r
F P
0 g
s
.43774 .59043 m .42575 .62405 L .39628 .61212 L p .707 .577 .707 r
F P
0 g
s
.39628 .61212 m .40827 .5785 L .43774 .59043 L p .707 .577 .707 r
F P
0 g
s
.46676 .6595 m .46121 .67652 L .4352 .66282 L p .707 .577 .707 r
F P
0 g
s
.4352 .66282 m .44076 .64581 L .46676 .6595 L p .707 .577 .707 r
F P
0 g
s
.40827 .5785 m .39628 .61212 L .36598 .60385 L p .707 .577 .707 r
F P
0 g
s
.38052 .62699 m .37496 .644 L .34662 .64072 L p .707 .577 .707 r
F P
0 g
s
.37496 .644 m .38052 .62699 L .41104 .6346 L p .707 .577 .707 r
F P
0 g
s
.44076 .64581 m .4352 .66282 L .40549 .65161 L p .707 .577 .707 r
F P
0 g
s
.40549 .65161 m .41104 .6346 L .44076 .64581 L p .707 .577 .707 r
F P
0 g
s
.41104 .6346 m .40549 .65161 L .37496 .644 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Qgoo6@00OGoo001nOol90006FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001fOol007Qoo`H0009J
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEP0000<0079oo`00M7oo1000
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH00eYF0`00Kgoo001a
Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH2001]Ool006eoo`@000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00QJEP8006]oo`00JWoo0`0025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH02UYF00<007ooOol0J7oo001XOol20000
0eYF001JEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP0;FUIZOol006Ioo`8000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00]JEP03001oogoo06Moo`00I7oo0P001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH02UYF00<007ooOol0Igoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0;FUIYOol0069oo`03001J
EP0000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000IJEP03001JEUYF
00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00=JEVUoo`00HGoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EVUoo`00HGoo00@005YFFUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEVUoo`00HGoo00@005YF
FUH000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00@005YFFUH000MJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Moo`00HGoo00D005YFFUIJEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Qoo`00HGoo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Qoo`00HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Qoo`00
HWoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFJ7oo001ROol01000FUIJEP00
1UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol0069oo`04001JEUYF0006FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEUYF001JEVQoo`00HWoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYFFUH0
05YFJ7oo001ROol01000FUIJEP001eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIXOol0069oo`04
001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEVQoo`00HWoo00@005YFFUH000MJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Ioo`00HWoo00D005YFFUIJEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Moo`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Hgoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00]JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF009JEP8006Moo`00Hgoo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJ
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01P00FUIJEUYF001JEVMoo`00Hgoo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
FUH005YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUIJEP00FUIWOol006=o
o`04001JEUYF0007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEVMoo`00Hgoo00@005YFFUH000MJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYFFUH005YFIgoo001TOol00`00FUH00007FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04
001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0;FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01000FUIJEUYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@0
05YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEVIoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFIWoo001TOol01000FUIJEP001eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00H005YFFUIJEP00FUIVOol006Eoo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH0
05YF0000IGoo001UOol00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Eoo`00
IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IGoo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00]JEP03001JEUYF00MJEP03001JEUYF
00IJEP04001JEUYFFUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF
0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8006Eoo`00H7oo4000
2UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP8006Eoo`00FWoo1P000eYF00<005YFFUH01EYF00<005YFFUH00UYF1`000eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUIJEP8006Eoo`00Egoo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00H005YFFUIJEP00FUIUOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00AJEP@000IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYFFUH005YFIGoo001FOol20003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030002FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0006Aoo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
00<005YFFUH00eYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF
FUIJEP00FUH0001TOol005Eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP07001JEUYFFUH005YF0000I7oo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP002UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001EOol20004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000
FUIJEUYF0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0017oo5000C7oo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002Ool30006FUH00`00FUIJ
EP06FUH01000FUIJEUYF1`00AGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH20006FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040011Ool005Aoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH4000mOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Goo001DOol00`00
FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH01@00FUIJEUYF00003EYF00<005YFFUH01eYF
00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00=JEP<003Ioo`00E7oo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00EJEP<003Aoo`00E7oo0P000eYF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF0080039oo`00E7oo00=JEP00FUH00UYF
10000UYF00<005YF00000`000Woo00<005YF00000eYF1`001UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80031oo`00Dgoo00@005YF001JEP<0009JEPh000AJ
EPD00003FUH000000080009JEP03001JEUYF00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
0eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH2000_Ool005=oo`04001JEP000002FUH40006FUH01000FUIJEUYF30001EYF10001UYF
00<005YFFUH015YF00@005YFFUIJEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF008000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8002moo`00Dgoo0`000UYF0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01`001UYF0`0015YF00<005YFFUH015YF00@005YFFUIJEP80
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool005=oo`04001JEUYFFUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH?00000eYF001JEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool005=oo`03001JEUYF008000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP06001JEP00001JEP001eYF0P001EYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH015YF00D005YFFUIJ
EP0002eoo`00E7oo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000IJEP04001JEP000003FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0P00;7oo001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH20004FUH01000FUIJEUYF0P0000=JEP00FUH00UYF0P001EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000=JEP04001JEUYFFUH@0004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;7oo001EOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH300000eYF001JEP05
FUH20003FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH00000
0eYF1@000UYF00@005YFFUIJEP<000Moo`L000IJEP03001JEUYF00EJEP03001JEUYF00=JEP07001J
EUYFFUH005YF0000;7oo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF00L005YF001JEP00FUH00005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00`001EYF00<005YFFUH01EYF0`00
1Woo0`000Woo10000UYF00<005YFFUH01EYF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000/Ool0
03Uooa0000]oo`80009JEP`000AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEUYF00AJEP03001JEUYF00800003FUH005YF00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEP0000<0
0003Ool0000000<000Eoo`@000IJEP03001JEUYF00=JEP06001JEUYFFUH005YF;Goo000dOol50003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70004Ool01000FUH000001EYF00<005YFFUH015YF1P00
1eYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH00UYF00<005YF00001EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF10000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH00eYF1`0027oo0P000eYF00<005YFFUH015YF00@005YFFUIJEP8002eoo`00<Woo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01P000UYF0P000eYF
00<005YFFUH01UYF00@005YFFUIJEP8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
0004FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUH000060007FUH500000eYF0000000:00000eYF001JEP05FUH01000FUIJ
EUYF0P00;Goo000`Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP04FUH300000eYF001JEP08
FUH00`00FUIJEP06FUH40004FUH20006FUH00`00FUIJEP0;FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH000050002FUH01000FUIJEUYF1P000eYF0`001UYF00<005YFFUH0
1EYF0P001UYF00@005YFFUIJEP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF0P001EYF0P0000Aoo`00000000IJEP03001JEUYF00IJEP@0
00QJEP03001JEUYF00EJEP05001JEUYFFUH00004FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH20003FUH30002FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUH00003
0008FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH2000]Ool002ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04
001JEUYF0003Ool20004FUH00`00FUIJEP06FUH01000FUIJEUYF0`001EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0P0000=JEP00000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
0P000UYF0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00<005YF
FUH01EYF00@005YFFUIJEP800003FUH005YF00=JEP03001oogoo02aoo`00;Woo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000eYF
00@005YFFUIJEP8000=oo`<00003FUH005YF00MJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03
001JEUYF00AJEP<000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEP00
FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20003FUH2000^Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP0000=JEP04001JEUYFFUH<0005FUH00`00FUIJ
EP07FUH30007FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUH000020008FUH00`00FUIJEP03FUH00`00FUH00002FUH2000^Ool002ioo`8000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH20000
0eYF001JEP05FUH01000FUIJEUYF1P0025YF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP03001J
EP0000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000IJEP03001JEUYF
00=JEP03001JEUYF00@002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<0009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEP0000<000AJEP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP04001JEUYF0008
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0015YF00<005YFFUH00eYF00@0
05YFFUIJEP<002ioo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH015YF3`001UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP<00003FUH005YF00EJEP04001JEUYFFUH2000_Ool002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
0080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000=JEP05
001JEUYFFUH00006FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP8000IJEP04001JEUYFFUH2000_Ool002eoo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP@000=JEP/0
00AJEP03001JEUYF00MJEP03001JEUYF009JEP@000AJEP03001JEUYF009JEP03001JEUYF009JEP80
00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800004FUH005YFFUH;0004FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P00;goo000]
Ool00`00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH01@00FUH00000FUH00P000UYF00<005YFFUH01UYF1`001UYF00<005YFFUH01UYF0P0015YF0P00
0UYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF0`0000AJEP000000009JEPL00003FUH0000000D000MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP800003FUH005YF009JEP80031oo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YF
FUH00eYF1P000UYF00<005YFFUH01eYF0`0015YF0P001EYF00<005YF00001UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF10000UYF00<005YFFUH00UYF0`000Woo1@000eYF10000UYF
00<005YFFUH01UYF00<005YFFUH01eYF0`000eYF0P00<7oo000]Ool20003FUH01000FUIJEUYF4000
15YF00<005YFFUH01eYF100000=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF1`001eYF
00@005YFFUIJEP8000=JEP03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH30004FUH01@00FUIJEUYF00000UYF00<007ooOol017oo10000UYF1000
25YF00<005YFFUH01UYF00@005YFFUH000=JEP03001oogoo02moo`00;Goo0P000eYF10000UYF00<0
05YF00000`0027oo1`001UYF00<005YF00000`0000AJEP00000000QJEP03001JEUYF00MJEP04001J
EP000002FUH20005FUH00`00FUIJEP03FUH20002FUH01`00FUIJEUYF001JEP0000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP@000AJEP8000Qoo`P000IJEP03001JEUYF
00IJEP04001JEUYFFUH3000bOol002aoo`04001JEP00FUH30002FUH>0004Ool500000goo00000002
0002FUH01P00FUH00000FUH000=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<0
0006FUH00000001JEP0025YF00@005YFFUH0009JEP03001JEP0000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP8000AJEP05001JEUYFFUH00006FUH00`00Oomoo`0<Ool30004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00Oomoo`0aOol002aoo`04001JEP000002FUH40006FUH0
1000FUIJEUYF30001Goo1P000UYF00@005YF001JEP8000EJEP03001JEUYF00MJEP03001JEUYF00EJ
EPH000QJEP@0009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP8000AJ
EP03001JEUYF009JEP8000AJEP80011oo`800003FUH005YF00MJEP03001JEUYF00AJEP03001oogoo
031oo`00;7oo0`000UYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01`001goo00L0
05YFFUIJEP00FUH00003FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
1UYF00<005YFFUH00`0000=JEP00FUH01eYF00<005YFFUH02eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH015YF00L005YFFUIJEP00FUH00009Ool30005Ool20008FUH0
0`00FUIJEP04FUH2000aOol002aoo`80009JEP80009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00EJEP/000AJEP8000EJEP<000UJEP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03
001JEUYF009JEP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEUYF
009JEP03001JEUYF00EJEP@000=JEP03001oogoo00Eoo`D000Ioo`8000EJEP03001JEUYF00AJEP04
001JEUYF000`Ool002aoo`05001JEUYFFUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH30002FUH01@00FUIJEUYF00000eYF0`0015YF00<005YF00002EYF00<005YFFUH01UYF
00<005YFFUH01EYF00H005YF000005YF0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00001UYF00<005YF00001P001goo1@0027oo0P000eYF
00<005YFFUH015YF00D005YFFUIJEP0002moo`00;7oo00<005YFFUH00P000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<000AJEP03001JEP0000=JEP05001JEUYF
FUH00002FUH20006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF0P001UYF0P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0P001UYF1@000eYF00@005YFFUIJEP`0
00Yoo`<000MJEP03001JEUYF009JEP03001oogoo02aoo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF0P0015YF0P0000=JEP00
FUH00UYF0`0015YF00<005YFFUH00`000eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF00<005YF00002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF0000
05YF00<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@000eoo`03001JEUYF00AJEP03
001JEUYF00=JEP03001oogoo02aoo`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH015YF0P000eYF0P0000Eoo`00001JEP00
009JEPD0009JEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001JEUYF0008FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000030002FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH4000:Ool20004FUH00`00FUIJEP02FUH2000^Ool002ioo`03001J
EUYF009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP<00003
FUH0000000EJEP<00004FUH005YF0002Ool:0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00
FUIJEP020004FUH00`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000
2Woo00D005YFFUIJEP0000AJEP8002ioo`00;Goo0P000eYF00@005YFFUIJEPL000AJEP03001JEUYF
00MJEP03001JEUYF00IJEP04001JEUYFFUH200000eYF001JEP02FUH01000FUIJEUYF0P0000MJEP00
Oomoo`00FUH00002FUH500000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH<
0004FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30008Ool30004FUH00`00FUH0000^Ool002eoo`03
001JEUYF00L000IJEPH000MJEP03001JEUYF00MJEP03001JEUYF00=JEP<0009JEP03001JEUYF00=J
EP80009oo`03001JEP0000=JEPT000AJEP03001JEUYF00AJEP05001JEP00001JEP020002FUH20007
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEP00FUH00P000UYF00<0
05YFFUH01UYF1`001eYF00<005YFFUH01EYF0P0027oo00<005YFFUH00UYF00<005YF0000;Woo000/
Ool400000eYF00000003FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF00<005YFFUH01eYF00<0
05YFFUH01EYF0`0025YF0`000UYF00<005YFFUH015YF00<005YFFUH00UYF3@000eYF0P000UYF00<0
05YF00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0000AJ
EP00000000QJEP03001JEUYF00EJEP@0009JEP03001JEUYF00MJEP<000Moo`06001JEUYF001JEP00
;goo000/Ool00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP04FUH300000eYF001JEP08
FUH00`00FUIJEP06FUH40007FUH00`00FUH000030006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
1000FUH000000UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00D005YF000005YF00@000QJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03001JEUYF008000Eo
o`06001JEUYF001JEP00;goo000[Ool20006FUH00`00Ool000020006FUH00`00FUIJEP06FUH40008
FUH00`00FUIJEP05FUH01000FUIJEUYF0`0015YF00<005YFFUH00eYF0`0015YF00<005YFFUH01eYF
00<005YFFUH025YF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP@00003FUH0000000@000EJEP03001JEUYF00MJEP03001JEUYF00AJEP<000AJ
EP03001JEUYF00=JEPP0009JEP03001oogoo02eoo`00:goo00<005YF00001EYF0P000goo0P0015YF
00<005YFFUH01UYF00@005YFFUIJEP<000EJEP03001JEUYF00EJEP03001JEUYF009JEPD00003FUH0
05YF00MJEP<00003FUH005YF00QJEP03001JEUYF00QJEP06001JEUYF001JEP001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF0P0000=JEP0000000P000eYF0`000eYF00<005YFFUH0
1eYF00<005YFFUH01UYF100000=JEP00FUH01UYF0`000UYF00<005YF0000<7oo000[Ool00`00FUH0
0004FUH00`00FUIJEP020003Ool300000eYF001JEP07FUH00`00FUIJEP04FUH300000eYF001JEP07
FUH00`00FUIJEP04FUH50009FUH00`00FUH000030007FUH00`00FUIJEP08FUH01P00FUIJEP00FUH0
00MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP800003FUH005YF008000EJEP@0
00UJEP03001JEUYF00MJEP04001JEUYFFUH20008FUH20002FUH00`00FUH0000`Ool002]oo`03001J
EP0000AJEP03001JEUYF00`000EJEP03001JEUYF00MJEP<000MJEP03001JEUYF00EJEP8000=oo`80
00IJEP03001JEUYF00AJEPH00003FUH005YF00UJEP<00003FUH005YF00MJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001JEP00008000QJEP03001J
EUYF00<000=JEP03001JEUYF00AJEP8000EJEP08001JEUYF001JEP00FUH0031oo`00;7oo00<005YF
FUH00UYF00H005YF000005YF0006FUH01000FUIJEUYF1P0025YF00@005YFFUIJEP8000EJEP03001J
EUYF00AJEP03001JEP0000Eoo`8000AJEP03001JEUYF00IJEP04001JEUYFFUH=0002FUH20008FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00004FUH00`00FUIJEP02FUH0
0`00FUIJEP050005FUH00`00FUH000040002FUH00`00FUIJEP05FUH30003FUH01000FUIJEUYF0`00
<Goo000/Ool00`00FUIJEP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH00003
0004FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH01000FUIJEP001Goo0`0000=JEP00FUH0
25YF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH01eYF00<005YFFUH0
2eYF00<005YFFUH01eYF00<005YFFUH01UYF0P0015YF0P000eYF00@005YFFUIJEP<00006Ool00000
001JEP000UYF1@000UYF00<005YFFUH01EYF00<005YFFUH00`001EYF0P00<Goo000]Ool00`00FUIJ
EP020003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04FUH?0006FUH00`00FUIJEP02
FUH00`00Oomoo`02Ool00`00FUH000040006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF00<0
05YFFUH00P0000=JEP00FUH00UYF0P001Goo0`0000=JEP0000000`0000=JEP00FUH01eYF00<005YF
FUH00UYF00<005YFFUH015YF00<007ooOol0;goo000]Ool00`00FUIJEP020002FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000020007Ool00`00FUIJEP04FUH00`00FUIJ
EP02FUH00`00Oomoo`02Ool00`00FUH00004FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP03000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002
FUH00`00FUIJEP02FUH20003FUH20008Ool50002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20004
FUH2000`Ool002ioo`<000=JEP/000AJEP03001JEUYF00MJEP03001JEUYF009JEP<000Eoo`03001J
EUYF00=JEP04001JEUYFFUH20004Ool00`00FUH00006FUH00`00FUH000050004FUH01000FUIJEUYF
1@0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0P001UYF00@005YFFUIJEP8000Yoo`<00003FUH005YF00MJEP03001JEUYF00AJEP03001JEP00009J
EP04001JEUYF000_Ool002moo`800003FUH00000009JEP03001JEUYF00IJEPL000IJEP03001JEUYF
00IJEP8000Aoo`05001JEUYFFUH00004FUH00`00FUH00003Ool00`00FUH00006FUH00`00FUIJEP05
FUH80006FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00
FUIJEUYF00001UYF1@003Woo1@0015YF00<005YFFUH015YF00<005YF000010000eYF00<007ooOol0
;7oo000_Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP07FUH30003
Ool01000FUIJEP0015YF00<005YF00000goo00<005YF00001UYF00<005YFFUH025YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP<000AJEP03001JEUYF008001=oo`d000Aoo`03001JEUYF009JEP03001oogoo02]oo`00;Woo1000
15YF00<005YFFUH01EYF00<005YFFUH01UYF1`001eYF00@005YFFUIJEP80009oo`8000AJEP04001J
EUYF0003Ool00`00FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10000UYF00<005YFFUH00eYF
0P008goo00D005YFFUIJEP0002eoo`00;Woo0`0000=oo`0000000UYF00<005YFFUH01EYF00<005YF
FUH01eYF00@005YF0000009oo`8000EJEP03001JEUYF00=JEP800003Ool005YF00=JEP03001JEP00
00Aoo`03001JEP0000MJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00AJEP`000EJEP03001JEUYF00EJEP03001JEUYF00=JEPD000MJEP<0021oo`03001JEUYF008002eo
o`00;Woo0P0000AJEP00Oomoo`8000MJEP03001JEUYF00MJEP03001JEUYF009JEP<00006Ool00000
001JEP0025YF00<007oo00000eYF00<005YF000017oo00<005YF00001eYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH015YF3@002eYF20001UYF00<005YFFUH00eYF00D005YFFUIJEP0000QJ
EP04001JEP00000OOol01000FUH00000;Goo000^Ool200000eYF001oo`02Ool00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH60008FUH40002FUH20005Ool00`00FUIJEP07FUH00`00FUIJ
EP07FUH00`00FUIJEP03FUH=000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH40002FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP02FUH3000LOol200000eYF001oo`0/Ool002io
o`05001JEUYFFUH00003Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0`00
1UYF00<005YFFUH00`0000=JEP00Ool017oo00<005YFFUH01eYF00<005YFFUH01UYF1`0035YF00<0
05YFFUH02EYF00<005YFFUH02EYF0P0025YF00<005YF00000P001EYF00<005YFFUH015YF0P000eYF
00<005YFFUH01EYF10006Goo00<005YF0000;Goo000^Ool00`00FUIJEP02FUH00`00Oomoo`02Ool2
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP02FUH2
00000eYF001oo`04Ool00`00FUIJEP07FUH00`00FUIJEP03FUH30006FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH20008FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH00`00
FUIJEP030009FUH00`00FUIJEP04000EOol2000^Ool002moo`04001JEUYFFUH30004Ool30009FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUH00000FUH000IJEP03001oogoo00Eoo`UJEP03001J
EP0000<000UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP8000QJEP03001JEUYF
00AJEP800003FUH005YF00AJEP04001JEUYFFUH30008FUH00`00FUIJEP04FUH6000=Ool4000^Ool0
031oo`04001JEUYF0002FUH00`00Oomoo`03Ool20007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P001UYF0P001Woo25YF0`000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF0P0025YF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF009J
EP03001oo`00008000AJEP03001JEUYF00MJEP04001JEUYFFUH=0002FUH2000^Ool0031oo`03001J
EP0000AJEP8000Eoo`8000EJEP03001JEUYF00<000=JEP03001JEUYF00IJEP03001JEUYF00=JEP03
001JEUYF009JEP03001JEP0000Ioo`IJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP8000QJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP03
FUH00`00Oomoo`02Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP02000_Ool0035oo`8000IJEP03001oogoo00Aoo`<00004FUH005YFFUH50002FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30002FUH01000FUIJEP001Goo15YF0P001eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF0P002EYF00<005YFFUH00eYF00@005YFFUH000AJ
EP03001JEUYF009JEP8000Moo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000_Ool0039oo`03001JEUYF00AJEP<000Moo`T0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF008000=JEP03001oogoo00=oo`9JEP8000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP8000UJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001J
EUYF009JEP8000Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080031oo`00
<goo00<005YFFUH00UYF00@005YFFUIJEP8000Uoo`D00003FUH005YF00MJEP03001JEUYF00AJEP03
001JEUYF008000AJEP03001oogoo009oo`03FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP8000UJEP03001JEUYF00=JEP03001JEP00009oo`<000AJ
EP03001JEP0000ioo`H000AJEP03001JEUYF00AJEP04001JEP00000bOol003Aoo`80009JEP03001J
EUYF00=JEP8000Qoo`T000AJEP03001JEUYF00AJEP04001JEP000002Ool01@00FUIJEUYF000017oo
00=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH00eYF0P001Goo00<005YFFUH00UYF00<005YF
000057oo3@00=7oo000fOol20008FUH2000?Ool=0005Ool01@00FUH005YF00000goo0P0015YF00<0
05YFFUH03eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH00eYF00<007ooOol01Goo00@005YFFUIJEP8005Ioo`00=goo00<005YFFUH01UYF00<005YF
00000P007goo0P0000=JEP00Ool00Woo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP<000Moo`06
001JEUYF001JEP00EWoo000hOol20006FUH00`00FUIJEP02FUH3000MOol00`00FUH00004Ool00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH01000FUH000000eYF0P000Woo1@0000AJEP00FUH005Ioo`00>Woo
0P000eYF00<005YFFUH01UYF0`006Woo0P001Goo00<005YFFUH00UYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=J
EP00FUH015YF0P000UYF00H005YF000005YF001GOol003aoo`800003FUH005YF00QJEP03001JEP00
00<001Eoo`<000Ioo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF009JEP@000=JEP8000MJEP8000=JEP03001JEP0005Mo
o`00?Woo0`001eYF00<005YFFUH015YF1P003Goo0P0000=JEP00Ool027oo0`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF00000P000UYF00<005YF
FUH015YF0P001EYF00<005YF00000UYF00<005YF0000Egoo0011Ool20005FUH00`00FUIJEP06FUH0
1000FUIJEUYF3@000UYF0P002goo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF1P000eYF00<005YFFUH01UYF0P000eYF00<005YFFUH01000F7oo0013Ool3
00000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00003Woo10000UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00@005YFFUIJEPL00003FUH0000000<0
009JEP03001JEUYF00EJEP03001JEUYF00<000EJEP8005Qoo`00AWoo10001UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP80019oo`P000EJEP03001JEUYF00YJEP03001JEUYF00AJEPT0
009oo`800004FUH005YFFUH500000eYF001JEP07FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
Oomoo`1FOol004Yoo`@0009JEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008001]ooaT0
0003FUH007oo00Yoo`<00003FUH0000000<00003FUH005YF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP8005Moo`00CWoo1P0015YF00<005YFFUH00eYF00@005YF0000031oo`8000IJEP03001oogoo
00]oo`D00003FUH005YF00MJEP03001JEUYF00AJEP8000AJEP03001JEP0005Ioo`00E7oo3000<goo
00<005YFFUH015YF0`003goo1P0015YF00<005YFFUH015YF00<005YF00000P0000=JEP00FUH00UYF
00<007ooOol0Dgoo002DOol20004FUH00`00FUIJEP02000COol=0003Ool20004FUH00`00Oomoo`1B
Ool009Ioo`04001JEUYF0005FUH2000ROol00`00FUIJEP02FUH00`00Oomoo`1BOol009Moo`<000MJ
EP<0021oo`03001JEUYF008005Aoo`00VGoo00<005YFFUH01UYF00@005YF000001ioo`03001JEUYF
008005Aoo`00VWoo0P001EYF00<005YFFUH00UYF0`0077oo0P0000=JEP00Ool0Dgoo002LOol20003
FUH00`00FUIJEP05FUH4000IOol00`00FUH0001DOol009ioo`<000UJEP03001JEUYF00@001Eoo`80
05Eoo`00X7oo0P0025YF00<005YFFUH015YF1P003Goo1000EGoo002ROol30004FUH00`00FUIJEP07
FUH01000FUIJEUYF3@000UYF0P00EGoo002UOol300000eYF001JEP07FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02001FOol00:Qoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP04
001JEUYFFUH2001FOol00:]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
05Moo`00[goo1P0015YF00<005YFFUH015YF00@005YF000005Uoo`00]Goo3@00Fgoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]34\[InvisibleSpace]"     "\
\[InvisibleSpace]10.696221996221263`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 34, "     ", 10.696221996221263, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58823 .74895 m .58755 .6933 L .55638 .69179 L p .707 .577 .707 r
F P
0 g
s
.58755 .6933 m .58823 .74895 L .62007 .74782 L p .707 .577 .707 r
F P
0 g
s
.62007 .74782 m .61938 .69217 L .58755 .6933 L p .707 .577 .707 r
F P
0 g
s
.61938 .69217 m .62007 .74782 L .64945 .74417 L p .707 .577 .707 r
F P
0 g
s
.64945 .74417 m .64876 .68852 L .61938 .69217 L p .707 .577 .707 r
F P
0 g
s
.55706 .74744 m .55638 .69179 L .52892 .68779 L p .707 .577 .707 r
F P
0 g
s
.55638 .69179 m .55706 .74744 L .58823 .74895 L p .707 .577 .707 r
F P
0 g
s
.64876 .68852 m .64945 .74417 L .6735 .73834 L p .707 .577 .707 r
F P
0 g
s
.6735 .73834 m .67281 .68269 L .64876 .68852 L p .707 .577 .707 r
F P
0 g
s
.60024 .80732 m .59774 .77009 L .56664 .77032 L p .707 .577 .707 r
F P
0 g
s
.59774 .77009 m .60024 .80732 L .63201 .80462 L p .707 .577 .707 r
F P
0 g
s
.63201 .80462 m .62951 .76739 L .59774 .77009 L p .707 .577 .707 r
F P
0 g
s
.62951 .76739 m .63201 .80462 L .66134 .79971 L p .707 .577 .707 r
F P
0 g
s
.66134 .79971 m .65884 .76248 L .62951 .76739 L p .707 .577 .707 r
F P
0 g
s
.52892 .68779 m .52961 .74344 L .55706 .74744 L p .707 .577 .707 r
F P
0 g
s
.52961 .74344 m .52892 .68779 L .50787 .68169 L p .707 .577 .707 r
F P
0 g
s
.56914 .80755 m .56664 .77032 L .53926 .76806 L p .707 .577 .707 r
F P
0 g
s
.56664 .77032 m .56914 .80755 L .60024 .80732 L p .707 .577 .707 r
F P
0 g
s
.65884 .76248 m .66134 .79971 L .68536 .79308 L p .707 .577 .707 r
F P
0 g
s
.68536 .79308 m .68286 .75585 L .65884 .76248 L p .707 .577 .707 r
F P
0 g
s
.53926 .76806 m .54175 .80529 L .56914 .80755 L p .707 .577 .707 r
F P
0 g
s
.67281 .68269 m .6735 .73834 L .68987 .73091 L p .707 .577 .707 r
F P
0 g
s
.68987 .73091 m .68918 .67526 L .67281 .68269 L p .707 .577 .707 r
F P
0 g
s
.59546 .86434 m .60388 .8489 L .57617 .83304 L p .707 .577 .707 r
F P
0 g
s
.60388 .8489 m .59546 .86434 L .62418 .87616 L p .707 .577 .707 r
F P
0 g
s
.62418 .87616 m .63259 .86072 L .60388 .8489 L p .707 .577 .707 r
F P
0 g
s
.50787 .68169 m .50856 .73734 L .52961 .74344 L p .707 .577 .707 r
F P
0 g
s
.56775 .84848 m .57617 .83304 L .55217 .81468 L p .707 .577 .707 r
F P
0 g
s
.57617 .83304 m .56775 .84848 L .59546 .86434 L p .707 .577 .707 r
F P
0 g
s
.54175 .80529 m .53926 .76806 L .51827 .76353 L p .707 .577 .707 r
F P
0 g
s
.63259 .86072 m .62418 .87616 L .65108 .88278 L p .707 .577 .707 r
F P
0 g
s
.65108 .88278 m .6595 .86734 L .63259 .86072 L p .707 .577 .707 r
F P
0 g
s
.55217 .81468 m .54375 .83012 L .56775 .84848 L p .707 .577 .707 r
F P
0 g
s
.50856 .73734 m .50787 .68169 L .49528 .67408 L p .707 .577 .707 r
F P
0 g
s
.51827 .76353 m .52076 .80076 L .54175 .80529 L p .707 .577 .707 r
F P
0 g
s
.54375 .83012 m .55217 .81468 L .53424 .79563 L p .707 .577 .707 r
F P
0 g
s
.68286 .75585 m .68536 .79308 L .70172 .78538 L p .707 .577 .707 r
F P
0 g
s
.70172 .78538 m .69922 .74814 L .68286 .75585 L p .707 .577 .707 r
F P
0 g
s
.53424 .79563 m .52582 .81107 L .54375 .83012 L p .707 .577 .707 r
F P
0 g
s
.6595 .86734 m .65108 .88278 L .67355 .88355 L p .707 .577 .707 r
F P
0 g
s
.67355 .88355 m .68196 .86811 L .6595 .86734 L p .707 .577 .707 r
F P
0 g
s
.49528 .67408 m .49596 .72973 L .50856 .73734 L p .707 .577 .707 r
F P
0 g
s
.68918 .67526 m .68987 .73091 L .69695 .72261 L p .707 .577 .707 r
F P
0 g
s
.69695 .72261 m .69627 .66695 L .68918 .67526 L p .707 .577 .707 r
F P
0 g
s
.52076 .80076 m .51827 .76353 L .50572 .75717 L p .707 .577 .707 r
F P
0 g
s
.52582 .81107 m .53424 .79563 L .52412 .77775 L p .707 .577 .707 r
F P
0 g
s
.50572 .75717 m .50822 .79441 L .52076 .80076 L p .707 .577 .707 r
F P
0 g
s
.49596 .72973 m .49528 .67408 L .49238 .66572 L p .707 .577 .707 r
F P
0 g
s
.52412 .77775 m .51571 .79319 L .52582 .81107 L p .707 .577 .707 r
F P
0 g
s
.69922 .74814 m .70172 .78538 L .70881 .77735 L p .707 .577 .707 r
F P
0 g
s
.70881 .77735 m .70632 .74012 L .69922 .74814 L p .707 .577 .707 r
F P
0 g
s
.68196 .86811 m .67355 .88355 L .68937 .87839 L p .707 .577 .707 r
F P
0 g
s
.68937 .87839 m .69778 .86295 L .68196 .86811 L p .707 .577 .707 r
F P
0 g
s
.49238 .66572 m .49307 .72137 L .49596 .72973 L p .707 .577 .707 r
F P
0 g
s
.51571 .79319 m .52412 .77775 L .52282 .76279 L p .707 .577 .707 r
F P
0 g
s
.69627 .66695 m .69695 .72261 L .69406 .71424 L p .707 .577 .707 r
F P
0 g
s
.69406 .71424 m .69337 .65859 L .69627 .66695 L p .707 .577 .707 r
F P
0 g
s
.50822 .79441 m .50572 .75717 L .50286 .74961 L p .707 .577 .707 r
F P
0 g
s
.48455 .82194 m .49322 .32106 L .44922 .31761 L p .707 .577 .707 r
F P
0 g
s
.52282 .76279 m .5144 .77823 L .51571 .79319 L p .707 .577 .707 r
F P
0 g
s
.50286 .74961 m .50536 .78684 L .50822 .79441 L p .707 .577 .707 r
F P
0 g
s
.49307 .72137 m .49238 .66572 L .49947 .65742 L p .707 .577 .707 r
F P
0 g
s
.5144 .77823 m .52282 .76279 L .53045 .75221 L p .707 .577 .707 r
F P
0 g
s
.49947 .65742 m .50015 .71307 L .49307 .72137 L p .707 .577 .707 r
F P
0 g
s
.50536 .78684 m .50286 .74961 L .50996 .74159 L p .707 .577 .707 r
F P
0 g
s
.53045 .75221 m .52203 .76765 L .5144 .77823 L p .707 .577 .707 r
F P
0 g
s
.50996 .74159 m .51245 .77882 L .50536 .78684 L p .707 .577 .707 r
F P
0 g
s
.50015 .71307 m .49947 .65742 L .51584 .64999 L p .707 .577 .707 r
F P
0 g
s
.52203 .76765 m .53045 .75221 L .54627 .74706 L p .707 .577 .707 r
F P
0 g
s
.51584 .64999 m .51652 .70564 L .50015 .71307 L p .707 .577 .707 r
F P
0 g
s
.51245 .77882 m .50996 .74159 L .52631 .73388 L p .707 .577 .707 r
F P
0 g
s
.54627 .74706 m .53785 .76249 L .52203 .76765 L p .707 .577 .707 r
F P
0 g
s
.51652 .70564 m .51584 .64999 L .53989 .64416 L p .707 .577 .707 r
F P
0 g
s
.52631 .73388 m .52881 .77111 L .51245 .77882 L p .707 .577 .707 r
F P
0 g
s
.53989 .64416 m .54057 .69981 L .51652 .70564 L p .707 .577 .707 r
F P
0 g
s
.49322 .32106 m .48455 .82194 L .52949 .82153 L p .707 .577 .707 r
F P
0 g
s
.52881 .77111 m .52631 .73388 L .55033 .72725 L p .707 .577 .707 r
F P
0 g
s
.53785 .76249 m .54627 .74706 L .56873 .74783 L p .707 .577 .707 r
F P
0 g
s
.56873 .74783 m .56031 .76326 L .53785 .76249 L p .707 .577 .707 r
F P
0 g
s
.55033 .72725 m .55283 .76448 L .52881 .77111 L p .707 .577 .707 r
F P
0 g
s
.52949 .82153 m .53816 .32066 L .49322 .32106 L p .707 .577 .707 r
F P
0 g
s
.54057 .69981 m .53989 .64416 L .56927 .6405 L p .707 .577 .707 r
F P
0 g
s
.56927 .6405 m .56995 .69615 L .54057 .69981 L p .707 .577 .707 r
F P
0 g
s
.56031 .76326 m .56873 .74783 L .59564 .75444 L p .707 .577 .707 r
F P
0 g
s
.55283 .76448 m .55033 .72725 L .57966 .72234 L p .707 .577 .707 r
F P
0 g
s
.59564 .75444 m .58722 .76988 L .56031 .76326 L p .707 .577 .707 r
F P
0 g
s
.57966 .72234 m .58216 .75958 L .55283 .76448 L p .707 .577 .707 r
F P
0 g
s
.53816 .32066 m .52949 .82153 L .57096 .81731 L p .707 .577 .707 r
F P
0 g
s
.56995 .69615 m .56927 .6405 L .6011 .63937 L p .707 .577 .707 r
F P
0 g
s
.6011 .63937 m .60179 .69502 L .56995 .69615 L p .707 .577 .707 r
F P
0 g
s
.57096 .81731 m .57964 .31644 L .53816 .32066 L p .707 .577 .707 r
F P
0 g
s
.44055 .81848 m .44922 .31761 L .41047 .31064 L p .707 .577 .707 r
F P
0 g
s
.44922 .31761 m .44055 .81848 L .48455 .82194 L p .707 .577 .707 r
F P
0 g
s
.70632 .74012 m .70881 .77735 L .70595 .76979 L p .707 .577 .707 r
F P
0 g
s
.70595 .76979 m .70345 .73256 L .70632 .74012 L p .707 .577 .707 r
F P
0 g
s
.69778 .86295 m .68937 .87839 L .697 .86781 L p .707 .577 .707 r
F P
0 g
s
.697 .86781 m .70541 .85238 L .69778 .86295 L p .707 .577 .707 r
F P
0 g
s
.58216 .75958 m .57966 .72234 L .61143 .71964 L p .707 .577 .707 r
F P
0 g
s
.58722 .76988 m .59564 .75444 L .62435 .76626 L p .707 .577 .707 r
F P
0 g
s
.61143 .71964 m .61393 .75687 L .58216 .75958 L p .707 .577 .707 r
F P
0 g
s
.62435 .76626 m .61593 .7817 L .58722 .76988 L p .707 .577 .707 r
F P
0 g
s
.57964 .31644 m .57096 .81731 L .60492 .80969 L p .707 .577 .707 r
F P
0 g
s
.63227 .64088 m .63296 .69653 L .60179 .69502 L p .707 .577 .707 r
F P
0 g
s
.60179 .69502 m .6011 .63937 L .63227 .64088 L p .707 .577 .707 r
F P
0 g
s
.60492 .80969 m .61359 .30881 L .57964 .31644 L p .707 .577 .707 r
F P
0 g
s
.69337 .65859 m .69406 .71424 L .68147 .70664 L p .707 .577 .707 r
F P
0 g
s
.68147 .70664 m .68078 .65099 L .69337 .65859 L p .707 .577 .707 r
F P
0 g
s
.40179 .81151 m .41047 .31064 L .38075 .30083 L p .707 .577 .707 r
F P
0 g
s
.41047 .31064 m .40179 .81151 L .44055 .81848 L p .707 .577 .707 r
F P
0 g
s
.24523 .71074 m .24454 .65509 L .21337 .65358 L p .707 .577 .707 r
F P
0 g
s
.24454 .65509 m .24523 .71074 L .27706 .70962 L p .707 .577 .707 r
F P
0 g
s
.27706 .70962 m .27637 .65396 L .24454 .65509 L p .707 .577 .707 r
F P
0 g
s
.27637 .65396 m .27706 .70962 L .30644 .70596 L p .707 .577 .707 r
F P
0 g
s
.30644 .70596 m .30575 .65031 L .27637 .65396 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70345 .73256 m .70595 .76979 L .69341 .76343 L p .707 .577 .707 r
F P
0 g
s
.69341 .76343 m .69091 .7262 L .70345 .73256 L p .707 .577 .707 r
F P
0 g
s
.21406 .70923 m .21337 .65358 L .18591 .64958 L p .707 .577 .707 r
F P
0 g
s
.21337 .65358 m .21406 .70923 L .24523 .71074 L p .707 .577 .707 r
F P
0 g
s
.70541 .85238 m .697 .86781 L .69569 .85285 L p .707 .577 .707 r
F P
0 g
s
.69569 .85285 m .70411 .83742 L .70541 .85238 L p .707 .577 .707 r
F P
0 g
s
.30575 .65031 m .30644 .70596 L .33049 .70013 L p .707 .577 .707 r
F P
0 g
s
.33049 .70013 m .3298 .64448 L .30575 .65031 L p .707 .577 .707 r
F P
0 g
s
.64254 .71941 m .64503 .75664 L .61393 .75687 L p .707 .577 .707 r
F P
0 g
s
.61393 .75687 m .61143 .71964 L .64254 .71941 L p .707 .577 .707 r
F P
0 g
s
.65206 .78213 m .64365 .79757 L .61593 .7817 L p .707 .577 .707 r
F P
0 g
s
.61593 .7817 m .62435 .76626 L .65206 .78213 L p .707 .577 .707 r
F P
0 g
s
.61359 .30881 m .60492 .80969 L .62803 .79941 L p .707 .577 .707 r
F P
0 g
s
.62803 .79941 m .6367 .29853 L .61359 .30881 L p .707 .577 .707 r
F P
0 g
s
.25723 .77212 m .25473 .73489 L .22363 .73512 L p .707 .577 .707 r
F P
0 g
s
.25473 .73489 m .25723 .77212 L .289 .76942 L p .707 .577 .707 r
F P
0 g
s
.289 .76942 m .28651 .73219 L .25473 .73489 L p .707 .577 .707 r
F P
0 g
s
.68078 .65099 m .68147 .70664 L .66041 .70054 L p .707 .577 .707 r
F P
0 g
s
.66041 .70054 m .65973 .64488 L .68078 .65099 L p .707 .577 .707 r
F P
0 g
s
.28651 .73219 m .289 .76942 L .31833 .76451 L p .707 .577 .707 r
F P
0 g
s
.31833 .76451 m .31584 .72728 L .28651 .73219 L p .707 .577 .707 r
F P
0 g
s
.18591 .64958 m .1866 .70523 L .21406 .70923 L p .707 .577 .707 r
F P
0 g
s
.1866 .70523 m .18591 .64958 L .16486 .64348 L p .707 .577 .707 r
F P
0 g
s
.22613 .77235 m .22363 .73512 L .19625 .73286 L p .707 .577 .707 r
F P
0 g
s
.22363 .73512 m .22613 .77235 L .25723 .77212 L p .707 .577 .707 r
F P
0 g
s
.37207 .80171 m .38075 .30083 L .36297 .28915 L p .707 .577 .707 r
F P
0 g
s
.38075 .30083 m .37207 .80171 L .40179 .81151 L p .707 .577 .707 r
F P
0 g
s
.31584 .72728 m .31833 .76451 L .34235 .75788 L p .707 .577 .707 r
F P
0 g
s
.34235 .75788 m .33986 .72065 L .31584 .72728 L p .707 .577 .707 r
F P
0 g
s
.19625 .73286 m .19874 .7701 L .22613 .77235 L p .707 .577 .707 r
F P
0 g
s
.3298 .64448 m .33049 .70013 L .34686 .6927 L p .707 .577 .707 r
F P
0 g
s
.34686 .6927 m .34617 .63705 L .3298 .64448 L p .707 .577 .707 r
F P
0 g
s
.69091 .7262 m .69341 .76343 L .67242 .7589 L p .707 .577 .707 r
F P
0 g
s
.67242 .7589 m .66992 .72167 L .69091 .7262 L p .707 .577 .707 r
F P
0 g
s
.70411 .83742 m .69569 .85285 L .68558 .83497 L p .707 .577 .707 r
F P
0 g
s
.68558 .83497 m .69399 .81954 L .70411 .83742 L p .707 .577 .707 r
F P
0 g
s
.25246 .82857 m .26087 .81313 L .23316 .79727 L p .707 .577 .707 r
F P
0 g
s
.26087 .81313 m .25246 .82857 L .28117 .84039 L p .707 .577 .707 r
F P
0 g
s
.28117 .84039 m .28959 .82495 L .26087 .81313 L p .707 .577 .707 r
F P
0 g
s
.16486 .64348 m .16555 .69913 L .1866 .70523 L p .707 .577 .707 r
F P
0 g
s
.22474 .81271 m .23316 .79727 L .20916 .77891 L p .707 .577 .707 r
F P
0 g
s
.23316 .79727 m .22474 .81271 L .25246 .82857 L p .707 .577 .707 r
F P
0 g
s
.19874 .7701 m .19625 .73286 L .17526 .72833 L p .707 .577 .707 r
F P
0 g
s
.65973 .64488 m .66041 .70054 L .63296 .69653 L p .707 .577 .707 r
F P
0 g
s
.63296 .69653 m .63227 .64088 L .65973 .64488 L p .707 .577 .707 r
F P
0 g
s
.28959 .82495 m .28117 .84039 L .30807 .84701 L p .707 .577 .707 r
F P
0 g
s
.30807 .84701 m .31649 .83157 L .28959 .82495 L p .707 .577 .707 r
F P
0 g
s
.16555 .69913 m .16486 .64348 L .15227 .63587 L p .707 .577 .707 r
F P
0 g
s
.20916 .77891 m .20075 .79435 L .22474 .81271 L p .707 .577 .707 r
F P
0 g
s
.17526 .72833 m .17775 .76557 L .19874 .7701 L p .707 .577 .707 r
F P
0 g
s
.20075 .79435 m .20916 .77891 L .19123 .75986 L p .707 .577 .707 r
F P
0 g
s
.33986 .72065 m .34235 .75788 L .35871 .75018 L p .707 .577 .707 r
F P
0 g
s
.35871 .75018 m .35621 .71295 L .33986 .72065 L p .707 .577 .707 r
F P
0 g
s
.6367 .29853 m .62803 .79941 L .63803 .78748 L p .707 .577 .707 r
F P
0 g
s
.63803 .78748 m .6467 .2866 L .6367 .29853 L p .707 .577 .707 r
F P
0 g
s
.19123 .75986 m .18281 .7753 L .20075 .79435 L p .707 .577 .707 r
F P
0 g
s
.66992 .72167 m .67242 .7589 L .64503 .75664 L p .707 .577 .707 r
F P
0 g
s
.64503 .75664 m .64254 .71941 L .66992 .72167 L p .707 .577 .707 r
F P
0 g
s
.69399 .81954 m .68558 .83497 L .66764 .81592 L p .707 .577 .707 r
F P
0 g
s
.66764 .81592 m .67606 .80048 L .69399 .81954 L p .707 .577 .707 r
F P
0 g
s
.31649 .83157 m .30807 .84701 L .33054 .84778 L p .707 .577 .707 r
F P
0 g
s
.33054 .84778 m .33895 .83234 L .31649 .83157 L p .707 .577 .707 r
F P
0 g
s
.15227 .63587 m .15296 .69152 L .16555 .69913 L p .707 .577 .707 r
F P
0 g
s
.34617 .63705 m .34686 .6927 L .35394 .6844 L p .707 .577 .707 r
F P
0 g
s
.35394 .6844 m .35326 .62875 L .34617 .63705 L p .707 .577 .707 r
F P
0 g
s
.17775 .76557 m .17526 .72833 L .16272 .72198 L p .707 .577 .707 r
F P
0 g
s
.18281 .7753 m .19123 .75986 L .18111 .74198 L p .707 .577 .707 r
F P
0 g
s
.35621 .71295 m .35871 .75018 L .3658 .74215 L p .707 .577 .707 r
F P
0 g
s
.3658 .74215 m .36331 .70492 L .35621 .71295 L p .707 .577 .707 r
F P
0 g
s
.36044 .69736 m .36294 .73459 L .3504 .72823 L p .707 .577 .707 r
F P
0 g
s
.3504 .72823 m .3479 .691 L .36044 .69736 L p .707 .577 .707 r
F P
0 g
s
.34257 .7992 m .35098 .78377 L .35764 .79553 L p .707 .577 .707 r
F P
0 g
s
.35764 .79553 m .3611 .80165 L p .35796 .80123 L .707 .577 .707 r
F P
0 g
s
.34257 .7992 m .35764 .79553 L .35796 .80123 L .707 .577 .707 r
F
.36297 .28915 m .35889 .27674 L p .35472 .74317 L F P
0 g
s
.3543 .79003 m .35502 .74853 L p .35472 .74317 L .707 .577 .707 r
F P
0 g
s
.35502 .74853 m .36297 .28915 L p .35472 .74317 L .707 .577 .707 r
F P
0 g
s
.36331 .70492 m .3658 .74215 L .36294 .73459 L p .707 .577 .707 r
F P
0 g
s
.36294 .73459 m .36044 .69736 L .36331 .70492 L p .707 .577 .707 r
F P
0 g
s
.36297 .28915 m .3543 .79003 L .37207 .80171 L p .707 .577 .707 r
F P
0 g
s
.15296 .69152 m .15227 .63587 L .14937 .62751 L p .707 .577 .707 r
F P
0 g
s
.16272 .72198 m .16521 .75921 L .17775 .76557 L p .707 .577 .707 r
F P
0 g
s
.18111 .74198 m .1727 .75742 L .18281 .7753 L p .707 .577 .707 r
F P
0 g
s
.67606 .80048 m .66764 .81592 L .64365 .79757 L p .707 .577 .707 r
F P
0 g
s
.64365 .79757 m .65206 .78213 L .67606 .80048 L p .707 .577 .707 r
F P
0 g
s
.33895 .83234 m .33054 .84778 L .34636 .84262 L p .707 .577 .707 r
F P
0 g
s
.34636 .84262 m .35477 .82719 L .33895 .83234 L p .707 .577 .707 r
F P
0 g
s
.14937 .62751 m .15006 .68316 L .15296 .69152 L p .707 .577 .707 r
F P
0 g
s
.35326 .62875 m .35394 .6844 L .35105 .67603 L p .707 .577 .707 r
F P
0 g
s
.35105 .67603 m .35036 .62038 L .35326 .62875 L p .707 .577 .707 r
F P
0 g
s
.1727 .75742 m .18111 .74198 L .17981 .72702 L p .707 .577 .707 r
F P
0 g
s
.16521 .75921 m .16272 .72198 L .15985 .71442 L p .707 .577 .707 r
F P
0 g
s
.6467 .2866 m .63803 .78748 L .63394 .77507 L p .707 .577 .707 r
F P
0 g
s
.63394 .77507 m .64262 .27419 L .6467 .2866 L p .707 .577 .707 r
F P
0 g
s
.17981 .72702 m .17139 .74246 L .1727 .75742 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15985 .71442 m .16235 .75165 L .16521 .75921 L p .707 .577 .707 r
F P
0 g
s
.15006 .68316 m .14937 .62751 L .15646 .61921 L p .707 .577 .707 r
F P
0 g
s
.35477 .82719 m .34636 .84262 L .35399 .83205 L p .707 .577 .707 r
F P
0 g
s
.35399 .83205 m .36241 .81661 L .35477 .82719 L p .707 .577 .707 r
F P
0 g
s
.35889 .27674 m .35021 .77761 L .3543 .79003 L p .707 .577 .707 r
F P
0 g
s
.35021 .77761 m .35889 .27674 L .36889 .26481 L p .707 .577 .707 r
F P
0 g
s
.17139 .74246 m .17981 .72702 L .18744 .71645 L p .707 .577 .707 r
F P
0 g
s
.15646 .61921 m .15714 .67486 L .15006 .68316 L p .707 .577 .707 r
F P
0 g
s
.35036 .62038 m .35105 .67603 L .33846 .66843 L p .707 .577 .707 r
F P
0 g
s
.33846 .66843 m .33777 .61278 L .35036 .62038 L p .707 .577 .707 r
F P
0 g
s
.16235 .75165 m .15985 .71442 L .16695 .70639 L p .707 .577 .707 r
F P
0 g
s
.18744 .71645 m .17902 .73188 L .17139 .74246 L p .707 .577 .707 r
F P
0 g
s
.16695 .70639 m .16944 .74362 L .16235 .75165 L p .707 .577 .707 r
F P
0 g
s
.15714 .67486 m .15646 .61921 L .17283 .61178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.64262 .27419 m .63394 .77507 L .61617 .76339 L p .707 .577 .707 r
F P
0 g
s
.61617 .76339 m .62484 .26251 L .64262 .27419 L p .707 .577 .707 r
F P
0 g
s
.36241 .81661 m .35399 .83205 L .35268 .81709 L p .707 .577 .707 r
F P
0 g
s
.35268 .81709 m .3611 .80165 L .36241 .81661 L p .707 .577 .707 r
F P
0 g
s
.17902 .73188 m .18744 .71645 L .20326 .71129 L p .707 .577 .707 r
F P
0 g
s
.17283 .61178 m .17351 .66743 L .15714 .67486 L p .707 .577 .707 r
F P
0 g
s
.33777 .61278 m .33846 .66843 L .3174 .66233 L p .707 .577 .707 r
F P
0 g
s
.3174 .66233 m .31672 .60667 L .33777 .61278 L p .707 .577 .707 r
F P
0 g
s
.36021 .76568 m .36889 .26481 L .392 .25453 L p .707 .577 .707 r
F P
0 g
s
.36889 .26481 m .36021 .76568 L .35021 .77761 L p .707 .577 .707 r
F P
0 g
s
.16944 .74362 m .16695 .70639 L .1833 .69868 L p .707 .577 .707 r
F P
0 g
s
.20326 .71129 m .19484 .72673 L .17902 .73188 L p .707 .577 .707 r
F P
0 g
s
.17351 .66743 m .17283 .61178 L .19688 .60595 L p .707 .577 .707 r
F P
0 g
s
.1833 .69868 m .1858 .73592 L .16944 .74362 L p .707 .577 .707 r
F P
0 g
s
.3479 .691 m .3504 .72823 L .32941 .7237 L p .707 .577 .707 r
F P
0 g
s
.32941 .7237 m .32691 .68647 L .3479 .691 L p .707 .577 .707 r
F P
0 g
s
.3611 .80165 m .35268 .81709 L .34257 .7992 L p .707 .577 .707 r
F P
0 g
s
.31672 .60667 m .3174 .66233 L .28995 .65832 L p .707 .577 .707 r
F P
0 g
s
.28995 .65832 m .28926 .60267 L .31672 .60667 L p .707 .577 .707 r
F P
0 g
s
.19484 .72673 m .20326 .71129 L .22572 .71206 L p .707 .577 .707 r
F P
0 g
s
.19688 .60595 m .19756 .6616 L .17351 .66743 L p .707 .577 .707 r
F P
0 g
s
.62484 .26251 m .61617 .76339 L .58645 .75358 L p .707 .577 .707 r
F P
0 g
s
.58645 .75358 m .59512 .2527 L .62484 .26251 L p .707 .577 .707 r
F P
0 g
s
.1858 .73592 m .1833 .69868 L .20732 .69205 L p .707 .577 .707 r
F P
0 g
s
.19756 .6616 m .19688 .60595 L .22626 .60229 L p .707 .577 .707 r
F P
0 g
s
.22572 .71206 m .2173 .7275 L .19484 .72673 L p .707 .577 .707 r
F P
0 g
s
.28926 .60267 m .28995 .65832 L .25878 .65681 L p .707 .577 .707 r
F P
0 g
s
.25878 .65681 m .25809 .60116 L .28926 .60267 L p .707 .577 .707 r
F P
0 g
s
.20732 .69205 m .20982 .72929 L .1858 .73592 L p .707 .577 .707 r
F P
0 g
s
.32691 .68647 m .32941 .7237 L .30202 .72144 L p .707 .577 .707 r
F P
0 g
s
.30202 .72144 m .29953 .68421 L .32691 .68647 L p .707 .577 .707 r
F P
0 g
s
.392 .25453 m .38332 .7554 L .36021 .76568 L p .707 .577 .707 r
F P
0 g
s
.38332 .7554 m .392 .25453 L .42595 .2469 L p .707 .577 .707 r
F P
0 g
s
.35098 .78377 m .34257 .7992 L .32463 .78015 L p .707 .577 .707 r
F P
0 g
s
.32463 .78015 m .33305 .76472 L .35098 .78377 L p .707 .577 .707 r
F P
0 g
s
.22694 .65794 m .22626 .60229 L .25809 .60116 L p .707 .577 .707 r
F P
0 g
s
.22626 .60229 m .22694 .65794 L .19756 .6616 L p .707 .577 .707 r
F P
0 g
s
.25809 .60116 m .25878 .65681 L .22694 .65794 L p .707 .577 .707 r
F P
0 g
s
.72544 .65692 m .72475 .60126 L .69358 .59975 L p .707 .577 .707 r
F P
0 g
s
.72475 .60126 m .72544 .65692 L .75727 .65579 L p .707 .577 .707 r
F P
0 g
s
.75727 .65579 m .75659 .60013 L .72475 .60126 L p .707 .577 .707 r
F P
0 g
s
.2173 .7275 m .22572 .71206 L .25263 .71868 L p .707 .577 .707 r
F P
0 g
s
.75659 .60013 m .75727 .65579 L .78665 .65213 L p .707 .577 .707 r
F P
0 g
s
.78665 .65213 m .78597 .59648 L .75659 .60013 L p .707 .577 .707 r
F P
0 g
s
.20982 .72929 m .20732 .69205 L .23665 .68715 L p .707 .577 .707 r
F P
0 g
s
.69427 .6554 m .69358 .59975 L .66613 .59575 L p .707 .577 .707 r
F P
0 g
s
.69358 .59975 m .69427 .6554 L .72544 .65692 L p .707 .577 .707 r
F P
0 g
s
.25263 .71868 m .24421 .73411 L .2173 .7275 L p .707 .577 .707 r
F P
0 g
s
.29953 .68421 m .30202 .72144 L .27092 .72168 L p .707 .577 .707 r
F P
0 g
s
.27092 .72168 m .26843 .68445 L .29953 .68421 L p .707 .577 .707 r
F P
0 g
s
.23665 .68715 m .23915 .72438 L .20982 .72929 L p .707 .577 .707 r
F P
0 g
s
.59512 .2527 m .58645 .75358 L .54769 .74661 L p .707 .577 .707 r
F P
0 g
s
.54769 .74661 m .55637 .24573 L .59512 .2527 L p .707 .577 .707 r
F P
0 g
s
.33305 .76472 m .32463 .78015 L .30064 .7618 L p .707 .577 .707 r
F P
0 g
s
.30064 .7618 m .30905 .74636 L .33305 .76472 L p .707 .577 .707 r
F P
0 g
s
.23915 .72438 m .23665 .68715 L .26843 .68445 L p .707 .577 .707 r
F P
0 g
s
.78597 .59648 m .78665 .65213 L .8107 .6463 L p .707 .577 .707 r
F P
0 g
s
.8107 .6463 m .81002 .59065 L .78597 .59648 L p .707 .577 .707 r
F P
0 g
s
.24421 .73411 m .25263 .71868 L .28134 .7305 L p .707 .577 .707 r
F P
0 g
s
.26843 .68445 m .27092 .72168 L .23915 .72438 L p .707 .577 .707 r
F P
0 g
s
.73744 .71528 m .73495 .67805 L .70385 .67828 L p .707 .577 .707 r
F P
0 g
s
.73495 .67805 m .73744 .71528 L .76921 .71258 L p .707 .577 .707 r
F P
0 g
s
.76921 .71258 m .76672 .67535 L .73495 .67805 L p .707 .577 .707 r
F P
0 g
s
.76672 .67535 m .76921 .71258 L .79855 .70767 L p .707 .577 .707 r
F P
0 g
s
.79855 .70767 m .79605 .67044 L .76672 .67535 L p .707 .577 .707 r
F P
0 g
s
.66613 .59575 m .66681 .6514 L .69427 .6554 L p .707 .577 .707 r
F P
0 g
s
.41727 .74778 m .42595 .2469 L .46743 .24268 L p .707 .577 .707 r
F P
0 g
s
.42595 .2469 m .41727 .74778 L .38332 .7554 L p .707 .577 .707 r
F P
0 g
s
.66681 .6514 m .66613 .59575 L .64507 .58965 L p .707 .577 .707 r
F P
0 g
s
.30905 .74636 m .30064 .7618 L .27292 .74593 L p .707 .577 .707 r
F P
0 g
s
.27292 .74593 m .28134 .7305 L .30905 .74636 L p .707 .577 .707 r
F P
0 g
s
.28134 .7305 m .27292 .74593 L .24421 .73411 L p .707 .577 .707 r
F P
0 g
s
.70634 .71551 m .70385 .67828 L .67646 .67602 L p .707 .577 .707 r
F P
0 g
s
.70385 .67828 m .70634 .71551 L .73744 .71528 L p .707 .577 .707 r
F P
0 g
s
.79605 .67044 m .79855 .70767 L .82257 .70104 L p .707 .577 .707 r
F P
0 g
s
.82257 .70104 m .82007 .66381 L .79605 .67044 L p .707 .577 .707 r
F P
0 g
s
.67646 .67602 m .67896 .71325 L .70634 .71551 L p .707 .577 .707 r
F P
0 g
s
.55637 .24573 m .54769 .74661 L .50369 .74316 L p .707 .577 .707 r
F P
0 g
s
.50369 .74316 m .51236 .24228 L .55637 .24573 L p .707 .577 .707 r
F P
0 g
s
.81002 .59065 m .8107 .6463 L .82707 .63887 L p .707 .577 .707 r
F P
0 g
s
.82707 .63887 m .82639 .58322 L .81002 .59065 L p .707 .577 .707 r
F P
0 g
s
.73267 .7723 m .74108 .75686 L .71337 .741 L p .707 .577 .707 r
F P
0 g
s
.74108 .75686 m .73267 .7723 L .76138 .78412 L p .707 .577 .707 r
F P
0 g
s
.76138 .78412 m .7698 .76868 L .74108 .75686 L p .707 .577 .707 r
F P
0 g
s
.64507 .58965 m .64576 .6453 L .66681 .6514 L p .707 .577 .707 r
F P
0 g
s
.70496 .75644 m .71337 .741 L .68937 .72264 L p .707 .577 .707 r
F P
0 g
s
.71337 .741 m .70496 .75644 L .73267 .7723 L p .707 .577 .707 r
F P
0 g
s
.45875 .74356 m .46743 .24268 L .51236 .24228 L p .707 .577 .707 r
F P
0 g
s
.46743 .24268 m .45875 .74356 L .41727 .74778 L p .707 .577 .707 r
F P
0 g
s
.67896 .71325 m .67646 .67602 L .65547 .67149 L p .707 .577 .707 r
F P
0 g
s
.51236 .24228 m .50369 .74316 L .45875 .74356 L p .707 .577 .707 r
F P
0 g
s
.7698 .76868 m .76138 .78412 L .78829 .79074 L p .707 .577 .707 r
F P
0 g
s
.78829 .79074 m .7967 .7753 L .7698 .76868 L p .707 .577 .707 r
F P
0 g
s
.68937 .72264 m .68096 .73808 L .70496 .75644 L p .707 .577 .707 r
F P
0 g
s
.64576 .6453 m .64507 .58965 L .63248 .58204 L p .707 .577 .707 r
F P
0 g
s
.65547 .67149 m .65797 .70873 L .67896 .71325 L p .707 .577 .707 r
F P
0 g
s
.68096 .73808 m .68937 .72264 L .67144 .70359 L p .707 .577 .707 r
F P
0 g
s
.82007 .66381 m .82257 .70104 L .83892 .69334 L p .707 .577 .707 r
F P
0 g
s
.83892 .69334 m .83643 .65611 L .82007 .66381 L p .707 .577 .707 r
F P
0 g
s
.67144 .70359 m .66302 .71903 L .68096 .73808 L p .707 .577 .707 r
F P
0 g
s
.7967 .7753 m .78829 .79074 L .81075 .79151 L p .707 .577 .707 r
F P
0 g
s
.81075 .79151 m .81917 .77607 L .7967 .7753 L p .707 .577 .707 r
F P
0 g
s
.63248 .58204 m .63317 .63769 L .64576 .6453 L p .707 .577 .707 r
F P
0 g
s
.82639 .58322 m .82707 .63887 L .83416 .63057 L p .707 .577 .707 r
F P
0 g
s
.83416 .63057 m .83347 .57492 L .82639 .58322 L p .707 .577 .707 r
F P
0 g
s
.65797 .70873 m .65547 .67149 L .64293 .66514 L p .707 .577 .707 r
F P
0 g
s
.66302 .71903 m .67144 .70359 L .66133 .68571 L p .707 .577 .707 r
F P
0 g
s
.64293 .66514 m .64542 .70237 L .65797 .70873 L p .707 .577 .707 r
F P
0 g
s
.63317 .63769 m .63248 .58204 L .62959 .57368 L p .707 .577 .707 r
F P
0 g
s
.66133 .68571 m .65291 .70115 L .66302 .71903 L p .707 .577 .707 r
F P
0 g
s
.83643 .65611 m .83892 .69334 L .84602 .68531 L p .707 .577 .707 r
F P
0 g
s
.84602 .68531 m .84352 .64808 L .83643 .65611 L p .707 .577 .707 r
F P
0 g
s
.81917 .77607 m .81075 .79151 L .82657 .78635 L p .707 .577 .707 r
F P
0 g
s
.82657 .78635 m .83499 .77091 L .81917 .77607 L p .707 .577 .707 r
F P
0 g
s
.62959 .57368 m .63027 .62933 L .63317 .63769 L p .707 .577 .707 r
F P
0 g
s
.65291 .70115 m .66133 .68571 L .66002 .67075 L p .707 .577 .707 r
F P
0 g
s
.83347 .57492 m .83416 .63057 L .83126 .6222 L p .707 .577 .707 r
F P
0 g
s
.83126 .6222 m .83058 .56655 L .83347 .57492 L p .707 .577 .707 r
F P
0 g
s
.64542 .70237 m .64293 .66514 L .64006 .65757 L p .707 .577 .707 r
F P
0 g
s
.66002 .67075 m .6516 .68619 L .65291 .70115 L p .707 .577 .707 r
F P
0 g
s
.64006 .65757 m .64256 .69481 L .64542 .70237 L p .707 .577 .707 r
F P
0 g
s
.63027 .62933 m .62959 .57368 L .63667 .56538 L p .707 .577 .707 r
F P
0 g
s
.84352 .64808 m .84602 .68531 L .84315 .67775 L p .707 .577 .707 r
F P
0 g
s
.84315 .67775 m .84066 .64052 L .84352 .64808 L p .707 .577 .707 r
F P
0 g
s
.83499 .77091 m .82657 .78635 L .8342 .77578 L p .707 .577 .707 r
F P
0 g
s
.8342 .77578 m .84262 .76034 L .83499 .77091 L p .707 .577 .707 r
F P
0 g
s
.6516 .68619 m .66002 .67075 L .66765 .66018 L p .707 .577 .707 r
F P
0 g
s
.63667 .56538 m .63736 .62103 L .63027 .62933 L p .707 .577 .707 r
F P
0 g
s
.83058 .56655 m .83126 .6222 L .81867 .6146 L p .707 .577 .707 r
F P
0 g
s
.81867 .6146 m .81798 .55895 L .83058 .56655 L p .707 .577 .707 r
F P
0 g
s
.64256 .69481 m .64006 .65757 L .64716 .64955 L p .707 .577 .707 r
F P
0 g
s
.66765 .66018 m .65923 .67561 L .6516 .68619 L p .707 .577 .707 r
F P
0 g
s
.38243 .61871 m .38174 .56305 L .35057 .56154 L p .707 .577 .707 r
F P
0 g
s
.38174 .56305 m .38243 .61871 L .41426 .61758 L p .707 .577 .707 r
F P
0 g
s
.41426 .61758 m .41358 .56193 L .38174 .56305 L p .707 .577 .707 r
F P
0 g
s
.64716 .64955 m .64966 .68678 L .64256 .69481 L p .707 .577 .707 r
F P
0 g
s
.41358 .56193 m .41426 .61758 L .44364 .61392 L p .707 .577 .707 r
F P
0 g
s
.44364 .61392 m .44296 .55827 L .41358 .56193 L p .707 .577 .707 r
F P
0 g
s
.63736 .62103 m .63667 .56538 L .65304 .55795 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84066 .64052 m .84315 .67775 L .83061 .67139 L p .707 .577 .707 r
F P
0 g
s
.83061 .67139 m .82812 .63416 L .84066 .64052 L p .707 .577 .707 r
F P
0 g
s
.35126 .6172 m .35057 .56154 L .32312 .55754 L p .707 .577 .707 r
F P
0 g
s
.35057 .56154 m .35126 .6172 L .38243 .61871 L p .707 .577 .707 r
F P
0 g
s
.84262 .76034 m .8342 .77578 L .8329 .76082 L p .707 .577 .707 r
F P
0 g
s
.8329 .76082 m .84131 .74538 L .84262 .76034 L p .707 .577 .707 r
F P
0 g
s
.44296 .55827 m .44364 .61392 L .46769 .60809 L p .707 .577 .707 r
F P
0 g
s
.46769 .60809 m .46701 .55244 L .44296 .55827 L p .707 .577 .707 r
F P
0 g
s
.65923 .67561 m .66765 .66018 L .68347 .65502 L p .707 .577 .707 r
F P
0 g
s
.39443 .68008 m .39194 .64285 L .36084 .64308 L p .707 .577 .707 r
F P
0 g
s
.39194 .64285 m .39443 .68008 L .4262 .67738 L p .707 .577 .707 r
F P
0 g
s
.4262 .67738 m .42371 .64015 L .39194 .64285 L p .707 .577 .707 r
F P
0 g
s
.65304 .55795 m .65373 .6136 L .63736 .62103 L p .707 .577 .707 r
F P
0 g
s
.81798 .55895 m .81867 .6146 L .79762 .6085 L p .707 .577 .707 r
F P
0 g
s
.79762 .6085 m .79693 .55285 L .81798 .55895 L p .707 .577 .707 r
F P
0 g
s
.42371 .64015 m .4262 .67738 L .45554 .67248 L p .707 .577 .707 r
F P
0 g
s
.45554 .67248 m .45304 .63524 L .42371 .64015 L p .707 .577 .707 r
F P
0 g
s
.32312 .55754 m .3238 .61319 L .35126 .6172 L p .707 .577 .707 r
F P
0 g
s
.64966 .68678 m .64716 .64955 L .66352 .64184 L p .707 .577 .707 r
F P
0 g
s
.3238 .61319 m .32312 .55754 L .30206 .55144 L p .707 .577 .707 r
F P
0 g
s
.68347 .65502 m .67506 .67046 L .65923 .67561 L p .707 .577 .707 r
F P
0 g
s
.36333 .68032 m .36084 .64308 L .33345 .64083 L p .707 .577 .707 r
F P
0 g
s
.36084 .64308 m .36333 .68032 L .39443 .68008 L p .707 .577 .707 r
F P
0 g
s
.65373 .6136 m .65304 .55795 L .67709 .55212 L p .707 .577 .707 r
F P
0 g
s
.66352 .64184 m .66601 .67907 L .64966 .68678 L p .707 .577 .707 r
F P
0 g
s
.45304 .63524 m .45554 .67248 L .47956 .66585 L p .707 .577 .707 r
F P
0 g
s
.47956 .66585 m .47706 .62861 L .45304 .63524 L p .707 .577 .707 r
F P
0 g
s
.33345 .64083 m .33595 .67806 L .36333 .68032 L p .707 .577 .707 r
F P
0 g
s
.46701 .55244 m .46769 .60809 L .48406 .60066 L p .707 .577 .707 r
F P
0 g
s
.48406 .60066 m .48338 .54501 L .46701 .55244 L p .707 .577 .707 r
F P
0 g
s
.82812 .63416 m .83061 .67139 L .80962 .66686 L p .707 .577 .707 r
F P
0 g
s
.80962 .66686 m .80713 .62963 L .82812 .63416 L p .707 .577 .707 r
F P
0 g
s
.84131 .74538 m .8329 .76082 L .82278 .74293 L p .707 .577 .707 r
F P
0 g
s
.82278 .74293 m .8312 .7275 L .84131 .74538 L p .707 .577 .707 r
F P
0 g
s
.38966 .73653 m .39808 .7211 L .37036 .70523 L p .707 .577 .707 r
F P
0 g
s
.39808 .7211 m .38966 .73653 L .41837 .74835 L p .707 .577 .707 r
F P
0 g
s
.41837 .74835 m .42679 .73292 L .39808 .7211 L p .707 .577 .707 r
F P
0 g
s
.30206 .55144 m .30275 .60709 L .3238 .61319 L p .707 .577 .707 r
F P
0 g
s
.36195 .72067 m .37036 .70523 L .34636 .68688 L p .707 .577 .707 r
F P
0 g
s
.37036 .70523 m .36195 .72067 L .38966 .73653 L p .707 .577 .707 r
F P
0 g
s
.33595 .67806 m .33345 .64083 L .31246 .6363 L p .707 .577 .707 r
F P
0 g
s
.79693 .55285 m .79762 .6085 L .77016 .60449 L p .707 .577 .707 r
F P
0 g
s
.77016 .60449 m .76948 .54884 L .79693 .55285 L p .707 .577 .707 r
F P
0 g
s
.67506 .67046 m .68347 .65502 L .70593 .65579 L p .707 .577 .707 r
F P
0 g
s
.42679 .73292 m .41837 .74835 L .44528 .75497 L p .707 .577 .707 r
F P
0 g
s
.44528 .75497 m .45369 .73953 L .42679 .73292 L p .707 .577 .707 r
F P
0 g
s
.67709 .55212 m .67778 .60777 L .65373 .6136 L p .707 .577 .707 r
F P
0 g
s
.30275 .60709 m .30206 .55144 L .28947 .54383 L p .707 .577 .707 r
F P
0 g
s
.34636 .68688 m .33795 .70231 L .36195 .72067 L p .707 .577 .707 r
F P
0 g
s
.66601 .67907 m .66352 .64184 L .68754 .63521 L p .707 .577 .707 r
F P
0 g
s
.31246 .6363 m .31496 .67353 L .33595 .67806 L p .707 .577 .707 r
F P
0 g
s
.33795 .70231 m .34636 .68688 L .32843 .66782 L p .707 .577 .707 r
F P
0 g
s
.67778 .60777 m .67709 .55212 L .70647 .54846 L p .707 .577 .707 r
F P
0 g
s
.47706 .62861 m .47956 .66585 L .49591 .65814 L p .707 .577 .707 r
F P
0 g
s
.49591 .65814 m .49342 .62091 L .47706 .62861 L p .707 .577 .707 r
F P
0 g
s
.70593 .65579 m .69752 .67122 L .67506 .67046 L p .707 .577 .707 r
F P
0 g
s
.32843 .66782 m .32001 .68326 L .33795 .70231 L p .707 .577 .707 r
F P
0 g
s
.76948 .54884 m .77016 .60449 L .73899 .60298 L p .707 .577 .707 r
F P
0 g
s
.73899 .60298 m .73831 .54733 L .76948 .54884 L p .707 .577 .707 r
F P
0 g
s
.68754 .63521 m .69003 .67244 L .66601 .67907 L p .707 .577 .707 r
F P
0 g
s
.80713 .62963 m .80962 .66686 L .78224 .6646 L p .707 .577 .707 r
F P
0 g
s
.78224 .6646 m .77974 .62737 L .80713 .62963 L p .707 .577 .707 r
F P
0 g
s
.8312 .7275 m .82278 .74293 L .80485 .72388 L p .707 .577 .707 r
F P
0 g
s
.80485 .72388 m .81326 .70845 L .8312 .7275 L p .707 .577 .707 r
F P
0 g
s
.45369 .73953 m .44528 .75497 L .46774 .75574 L p .707 .577 .707 r
F P
0 g
s
.46774 .75574 m .47616 .7403 L .45369 .73953 L p .707 .577 .707 r
F P
0 g
s
.28947 .54383 m .29016 .59949 L .30275 .60709 L p .707 .577 .707 r
F P
0 g
s
.48338 .54501 m .48406 .60066 L .49115 .59236 L p .707 .577 .707 r
F P
0 g
s
.49115 .59236 m .49046 .53671 L .48338 .54501 L p .707 .577 .707 r
F P
0 g
s
.70716 .60411 m .70647 .54846 L .73831 .54733 L p .707 .577 .707 r
F P
0 g
s
.70647 .54846 m .70716 .60411 L .67778 .60777 L p .707 .577 .707 r
F P
0 g
s
.73831 .54733 m .73899 .60298 L .70716 .60411 L p .707 .577 .707 r
F P
0 g
s
.31496 .67353 m .31246 .6363 L .29992 .62994 L p .707 .577 .707 r
F P
0 g
s
.69752 .67122 m .70593 .65579 L .73284 .66241 L p .707 .577 .707 r
F P
0 g
s
.32001 .68326 m .32843 .66782 L .31832 .64994 L p .707 .577 .707 r
F P
0 g
s
.69003 .67244 m .68754 .63521 L .71687 .63031 L p .707 .577 .707 r
F P
0 g
s
.29016 .59949 m .28947 .54383 L .28658 .53547 L p .707 .577 .707 r
F P
0 g
s
.29992 .62994 m .30241 .66717 L .31496 .67353 L p .707 .577 .707 r
F P
0 g
s
.73284 .66241 m .72442 .67784 L .69752 .67122 L p .707 .577 .707 r
F P
0 g
s
.31832 .64994 m .3099 .66538 L .32001 .68326 L p .707 .577 .707 r
F P
0 g
s
.77974 .62737 m .78224 .6646 L .75114 .66484 L p .707 .577 .707 r
F P
0 g
s
.75114 .66484 m .74864 .6276 L .77974 .62737 L p .707 .577 .707 r
F P
0 g
s
.71687 .63031 m .71936 .66754 L .69003 .67244 L p .707 .577 .707 r
F P
0 g
s
.49342 .62091 m .49591 .65814 L .50301 .65011 L p .707 .577 .707 r
F P
0 g
s
.50301 .65011 m .50051 .61288 L .49342 .62091 L p .707 .577 .707 r
F P
0 g
s
.81326 .70845 m .80485 .72388 L .78085 .70553 L p .707 .577 .707 r
F P
0 g
s
.78085 .70553 m .78927 .69009 L .81326 .70845 L p .707 .577 .707 r
F P
0 g
s
.71936 .66754 m .71687 .63031 L .74864 .6276 L p .707 .577 .707 r
F P
0 g
s
.72442 .67784 m .73284 .66241 L .76155 .67423 L p .707 .577 .707 r
F P
0 g
s
.74864 .6276 m .75114 .66484 L .71936 .66754 L p .707 .577 .707 r
F P
0 g
s
.47616 .7403 m .46774 .75574 L .48356 .75058 L p .707 .577 .707 r
F P
0 g
s
.48356 .75058 m .49198 .73515 L .47616 .7403 L p .707 .577 .707 r
F P
0 g
s
.78927 .69009 m .78085 .70553 L .75314 .68966 L p .707 .577 .707 r
F P
0 g
s
.75314 .68966 m .76155 .67423 L .78927 .69009 L p .707 .577 .707 r
F P
0 g
s
.28658 .53547 m .28726 .59112 L .29016 .59949 L p .707 .577 .707 r
F P
0 g
s
.76155 .67423 m .75314 .68966 L .72442 .67784 L p .707 .577 .707 r
F P
0 g
s
.49046 .53671 m .49115 .59236 L .48825 .58399 L p .707 .577 .707 r
F P
0 g
s
.48825 .58399 m .48757 .52834 L .49046 .53671 L p .707 .577 .707 r
F P
0 g
s
.3099 .66538 m .31832 .64994 L .31701 .63498 L p .707 .577 .707 r
F P
0 g
s
.30241 .66717 m .29992 .62994 L .29705 .62238 L p .707 .577 .707 r
F P
0 g
s
.31701 .63498 m .30859 .65042 L .3099 .66538 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.29705 .62238 m .29955 .65961 L .30241 .66717 L p .707 .577 .707 r
F P
0 g
s
.28726 .59112 m .28658 .53547 L .29366 .52717 L p .707 .577 .707 r
F P
0 g
s
.50051 .61288 m .50301 .65011 L .50014 .64255 L p .707 .577 .707 r
F P
0 g
s
.50014 .64255 m .49765 .60532 L .50051 .61288 L p .707 .577 .707 r
F P
0 g
s
.49198 .73515 m .48356 .75058 L .49119 .74001 L p .707 .577 .707 r
F P
0 g
s
.49119 .74001 m .49961 .72457 L .49198 .73515 L p .707 .577 .707 r
F P
0 g
s
.30859 .65042 m .31701 .63498 L .32464 .62441 L p .707 .577 .707 r
F P
0 g
s
.29366 .52717 m .29435 .58282 L .28726 .59112 L p .707 .577 .707 r
F P
0 g
s
.48757 .52834 m .48825 .58399 L .47566 .57639 L p .707 .577 .707 r
F P
0 g
s
.47566 .57639 m .47497 .52074 L .48757 .52834 L p .707 .577 .707 r
F P
0 g
s
.29955 .65961 m .29705 .62238 L .30415 .61435 L p .707 .577 .707 r
F P
0 g
s
.32464 .62441 m .31622 .63984 L .30859 .65042 L p .707 .577 .707 r
F P
0 g
s
.30415 .61435 m .30664 .65158 L .29955 .65961 L p .707 .577 .707 r
F P
0 g
s
.29435 .58282 m .29366 .52717 L .31003 .51974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49765 .60532 m .50014 .64255 L .4876 .6362 L p .707 .577 .707 r
F P
0 g
s
.4876 .6362 m .48511 .59896 L .49765 .60532 L p .707 .577 .707 r
F P
0 g
s
.49961 .72457 m .49119 .74001 L .48989 .72505 L p .707 .577 .707 r
F P
0 g
s
.48989 .72505 m .4983 .70961 L .49961 .72457 L p .707 .577 .707 r
F P
0 g
s
.31622 .63984 m .32464 .62441 L .34046 .61925 L p .707 .577 .707 r
F P
0 g
s
.31003 .51974 m .31072 .57539 L .29435 .58282 L p .707 .577 .707 r
F P
0 g
s
.47497 .52074 m .47566 .57639 L .45461 .57029 L p .707 .577 .707 r
F P
0 g
s
.45461 .57029 m .45392 .51464 L .47497 .52074 L p .707 .577 .707 r
F P
0 g
s
.30664 .65158 m .30415 .61435 L .32051 .60664 L p .707 .577 .707 r
F P
0 g
s
.34046 .61925 m .33204 .63469 L .31622 .63984 L p .707 .577 .707 r
F P
0 g
s
.31072 .57539 m .31003 .51974 L .33408 .51391 L p .707 .577 .707 r
F P
0 g
s
.32051 .60664 m .323 .64388 L .30664 .65158 L p .707 .577 .707 r
F P
0 g
s
.48511 .59896 m .4876 .6362 L .46661 .63167 L p .707 .577 .707 r
F P
0 g
s
.46661 .63167 m .46412 .59443 L .48511 .59896 L p .707 .577 .707 r
F P
0 g
s
.4983 .70961 m .48989 .72505 L .47977 .70717 L p .707 .577 .707 r
F P
0 g
s
.47977 .70717 m .48819 .69173 L .4983 .70961 L p .707 .577 .707 r
F P
0 g
s
.45392 .51464 m .45461 .57029 L .42715 .56629 L p .707 .577 .707 r
F P
0 g
s
.42715 .56629 m .42647 .51063 L .45392 .51464 L p .707 .577 .707 r
F P
0 g
s
.33204 .63469 m .34046 .61925 L .36292 .62002 L p .707 .577 .707 r
F P
0 g
s
.33408 .51391 m .33477 .56956 L .31072 .57539 L p .707 .577 .707 r
F P
0 g
s
.323 .64388 m .32051 .60664 L .34453 .60001 L p .707 .577 .707 r
F P
0 g
s
.33477 .56956 m .33408 .51391 L .36346 .51025 L p .707 .577 .707 r
F P
0 g
s
.36292 .62002 m .35451 .63546 L .33204 .63469 L p .707 .577 .707 r
F P
0 g
s
.42647 .51063 m .42715 .56629 L .39598 .56477 L p .707 .577 .707 r
F P
0 g
s
.39598 .56477 m .39529 .50912 L .42647 .51063 L p .707 .577 .707 r
F P
0 g
s
.34453 .60001 m .34702 .63725 L .323 .64388 L p .707 .577 .707 r
F P
0 g
s
.46412 .59443 m .46661 .63167 L .43923 .62941 L p .707 .577 .707 r
F P
0 g
s
.43923 .62941 m .43673 .59217 L .46412 .59443 L p .707 .577 .707 r
F P
0 g
s
.48819 .69173 m .47977 .70717 L .46184 .68812 L p .707 .577 .707 r
F P
0 g
s
.46184 .68812 m .47025 .67268 L .48819 .69173 L p .707 .577 .707 r
F P
0 g
s
.36415 .5659 m .36346 .51025 L .39529 .50912 L p .707 .577 .707 r
F P
0 g
s
.36346 .51025 m .36415 .5659 L .33477 .56956 L p .707 .577 .707 r
F P
0 g
s
.39529 .50912 m .39598 .56477 L .36415 .5659 L p .707 .577 .707 r
F P
0 g
s
.35451 .63546 m .36292 .62002 L .38983 .62664 L p .707 .577 .707 r
F P
0 g
s
.34702 .63725 m .34453 .60001 L .37386 .59511 L p .707 .577 .707 r
F P
0 g
s
.38983 .62664 m .38141 .64207 L .35451 .63546 L p .707 .577 .707 r
F P
0 g
s
.43673 .59217 m .43923 .62941 L .40812 .62964 L p .707 .577 .707 r
F P
0 g
s
.40812 .62964 m .40563 .59241 L .43673 .59217 L p .707 .577 .707 r
F P
0 g
s
.37386 .59511 m .37635 .63234 L .34702 .63725 L p .707 .577 .707 r
F P
0 g
s
.47025 .67268 m .46184 .68812 L .43784 .66976 L p .707 .577 .707 r
F P
0 g
s
.43784 .66976 m .44626 .65432 L .47025 .67268 L p .707 .577 .707 r
F P
0 g
s
.37635 .63234 m .37386 .59511 L .40563 .59241 L p .707 .577 .707 r
F P
0 g
s
.38141 .64207 m .38983 .62664 L .41854 .63846 L p .707 .577 .707 r
F P
0 g
s
.40563 .59241 m .40812 .62964 L .37635 .63234 L p .707 .577 .707 r
F P
0 g
s
.44626 .65432 m .43784 .66976 L .41013 .65389 L p .707 .577 .707 r
F P
0 g
s
.41013 .65389 m .41854 .63846 L .44626 .65432 L p .707 .577 .707 r
F P
0 g
s
.41854 .63846 m .41013 .65389 L .38141 .64207 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol008]oo`d008Eo
o`00Ogoo30001UYF00<005YFFUH015YF2@00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP06001fOol0079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00IJEP@0079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eo
o`00JWoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2001ZOol0
06Moo`8000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001XOol006Moo`8000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYFFUH0001WOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Ioo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Ioo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIo
o`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eo
o`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000AJEPT0
009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00Hgoo2@0015YF00<005YFFUH00UYF20001UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001L
Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001GOol50002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`800003
FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Ioo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001BOol20004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IWoo001BOol20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol0055oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00DGoo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IWoo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000@Ool?0017Ool0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`@00003FUH005YF
00MJEP03001JEUYF009JEPP003moo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo
1P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPL003Qoo`00DGoo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000=oo`0000000`000eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000=7oo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH300000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000cOol0055oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH00000<Goo001AOol00`00FUH00004FUH00`00FUIJEP03FUH60008FUH00`00FUH00004
0002FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<7oo001A
Ool00`00FUH00004FUH00`00FUH000030005FUH00`00FUIJEP06FUH00`00FUH000040002FUH00`00
FUIJEP05FUH70003FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<7oo001AOol00`00FUH0
0003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP030003FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH40002FUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
1@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo00@005YF001JEP80
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`06001JEP00001J
EP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH00UYF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`8000=JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP<000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEP00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<7oo001AOol20003FUH00`00
FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00031oo`00DGoo0P000eYF00<0
05YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH04@0015YF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP05001JEUYFFUH0000`Ool0055oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00AJEP03001JEUYF00T000AJEP03001JEUYF00IJEP04001JEUYFFUH60003FUH20005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP00031oo`00AGoo2@0017oo00D005YFFUIJEP0000EJEP04001JEUYFFUH60004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00002FUH01@00FUIJEUYF00001UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YF
FUIJEP00031oo`00?7oo2@0015YF00<005YFFUH00UYF1`0000=JEP00FUH015YF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP02FUHG0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<7oo000eOol70004FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP030002FUH30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEUYF
00=JEPL000MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP04001JEUYF
FUH2000_Ool0035oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000=JEP03001JEP0000<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEPH000=JEP04001JEUYFFUH2000_Ool002moo`<000EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH40003FUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000AJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF00800003FUH0000002moo`00;7oo00<005YFFUH00UYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUH005YF00<000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001J
EUYF009JEP<002moo`00:goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF0080009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
02moo`00:Woo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF009JEPL000AJEP03001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH04@001EYF00<005YFFUH00UYF00<005YF0000;goo000ZOol00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF000015YF
00<005YFFUH015YF00<005YFFUH015YF40001eYF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP080004FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00<005YF0000;goo000ZOol00`00FUH0
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0002FUH01@00FUIJEUYF00001UYF00<005YFFUH0100015YF00<005YFFUH00UYF0`000UYF00<005YF
FUH01EYF0`001EYF10000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUH000=J
EP03001JEUYF00=JEP03001JEUYF009JEPH000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00D0031oo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000UYF00D005YFFUIJEP0000EJEP@00003
FUH000000080009JEP03001JEUYF00IJEP<000=JEP@00003FUH005YF00EJEP04001JEUYFFUH20000
0eYF0000000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000eYF00<005YFFUH00eYF
1@0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF0`00;goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH00002FUH01P00FUIJEUYF001JEQ4000MJEP03001JEP0000<000EJ
EP03001JEUYF00AJEP03001JEUYF009JEP@000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP800003FUH005YF009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool002Yoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP06001JEUYF001JEP00
0eYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF0P001EYF00D005YFFUIJEP0000IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH600000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000ZOol00`00FUH00004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01`00FUIJEP00FUH005YF008000=J
EP03001JEUYF00EJEP03001JEUYF00IJEP@00003FUH005YF00AJEP8000AJEP03001JEUYF00EJEP06
001JEUYFFUH005YF0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF10000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0000=JEP0000000UYF
00<005YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEP8000MJEP80009JEP03001JEUYF00EJEP04
001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH0000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00;Goo000ZOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP03000015YF001JEP00
0UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YFFUH000IJEP04
001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH0000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002eoo`00:Woo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH00UYF2@0000=JEP0000000`000UYF20000UYF0P000UYF00<005YF00001eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P001UYF00D005YFFUIJ
EP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEP00000]Ool002Yoo`03001JEP0000AJEP04001JEUYF
FUH80008FUH00`00FUH000040002FUH00`00FUIJEP04FUH01000FUIJEP000eYF00@005YFFUH000MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00006FUH01000FUH000000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH0
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH002eoo`00:Woo00<005YF00000eYF1@001eYF00<005YFFUH0
1UYF00<005YFFUH00`000eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEP0000MJEP03001J
EUYF00IJEP03001JEUYF00IJEP@000EJEP03001JEUYF009JEP<000EJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00AJEP03
001JEUYF00AJEQh000=JEP04001JEUYF000]Ool002Yoo`04001JEP00FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30003FUH01000FUH000001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000IJEP@000QJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF009JEP03001JEUYF00AJEP03
001JEUYF00@000=JEP03001JEUYF00=JEP<000Uoo`@000EJEP@0009JEP8002aoo`00:Woo00H005YF
000005YF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
1000FUH000000UYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2
0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP03FUH400000goo000000020002FUH00`00FUIJ
EP06FUH20003Ool40002FUH00`00FUIJEP04FUH01000FUIJEUYF1000;7oo000ZOol20003FUH00`00
FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP@000AJEP03001JEUYF00IJEP03001JEUYF009JEPT00003FUH005YF00=JEP03
001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
009JEP03001JEUYF009JEP03001JEP0000l000UJEP@000IJEP03001JEUYF00AJEP03001JEUYF009J
EP<002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YF00004P0000=JEP00FUH025YF00D0
05YFFUIJEP00009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF009JEP<00003FUH005YF00IJEP03001JEUYF00AJEP8000IJ
EP05001JEUYFFUH00006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/Ool002Yoo`8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF01400003FUH005YF00EJEP80
00=JEP03001JEUYF00=JEP03001JEP0000@000=JEP03001JEUYF00QJEP<000AJEP03001JEUYF00AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00003FUH005YF
008000AJEP03001JEUYF00EJEP03001JEUYF00EJEP<000AJEP03001JEUYF009JEP8000AJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YF
FUH015YF00<005YFFUH02@0015YF00<005YFFUH01UYF00@005YFFUIJEP<000IJEP80009JEP03001J
EUYF00=JEP03001JEP0000@000=JEP03001JEUYF00UJEP8000EJEP03001JEUYF00=JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00005FUH00000FUH00004FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP06FUH20002FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH2000]Ool002]oo`05001JEUYFFUH00005FUH01000FUIJEUYF1P0015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00H005YF000005YF
0005FUH00`00FUH000040003FUH00`00FUIJEP09FUH00`00FUH00005FUH00`00FUIJEP02FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH400001EYF000005YF0000
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF0P002EYF00<005YF00001UYF00<0
05YFFUH00UYF0P00;Goo000/Ool200000eYF001JEP04FUH400000eYF001JEP07FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH01000FUIJEUYF0P001EYF00<005YFFUH00`00
15YF00<005YFFUH02EYF00@005YFFUH000AJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP@00005FUH00000FUH00003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH20006FUH01000FUH000001UYF00@005YFFUIJEP8002ioo`00;Woo0`00
0UYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00P001EYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUH000=J
EP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@00003FUH005YF009JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH0
0`00FUIJEP02FUH00`00FUIJEP03FUH01000FUH00000<7oo000aOol200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01@00FUIJEUYF00001UYF
0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00D005YFFUIJEP00009JEP04001JEUYF0002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEP00
0eYF00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00AJEP04001J
EUYFFUH3000bOol002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF00EJEP04001JEUYF0009FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH20003FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P000UYF0`000eYF00<005YF00001eYF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUH000MJEP<003Eoo`00;Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000UYF00@0
05YF000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20007FUH00`00Oomoo`0c
Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF009JEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000UYF00H005YFFUH005YF0002FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH900000goo001JEP04FUH00`00FUH0000dOol002eoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEP00FUH00005FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP020004FUH00`00FUIJEP0B000;Ool01@00FUIJEUYF00000eYF00<007ooOol0<Goo000]Ool0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0025YF0P001EYF00<005YFFUH02EYF00<005YF
FUH01EYF00@005YF001JEP8000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPH0
009JEP03001JEUYF00=JEP03001JEP00008000Uoo`D000eoo`800003FUH005YF00=JEP03001oogoo
031oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH015YF7@0015YF00<005YFFUH0
0`0025YF0P000eYF00<005YFFUH02EYF00<005YFFUH01EYF0P000UYF0P002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF10001EYF0P0000=JEP00Ool027oo1@003goo00<0
05YFFUH015YF00<007ooOol0;goo000]Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH0
100015YF00<005YFFUH00UYF0`002Woo0`0015YF0`0000EJEP00FUIJEP00009JEP03001JEUYF00AJ
EP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00IJEP03001JEUYF008000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000MJEP06001JEUYFFUH005YF0P002Woo1@0047oo
00<005YFFUH015YF00<007ooOol0;Woo000]Ool01000FUIJEP000eYF00<005YFFUH00eYF100000=o
o`0000000P000UYF00<005YFFUH01UYF0P0017oo100000=JEP00FUH01EYF00@005YF0000009JEP04
001JEUYFFUH20003FUH00`00FUIJEP03FUH3000:FUH00`00FUIJEP06FUH01@00FUH005YF00002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`001eYF0P000UYF00D005YFFUIJEP00
00Yoo`<0019oo`03001JEUYF009JEP03001JEP0002moo`00;Goo00@005YFFUH000=JEP03001JEP00
00@000Qoo`<000UJEPD000EJEP03001JEUYF00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH20000
0eYF001JEP07FUH30007FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH01000FUH000001EYF00<007ooOol077oo00<005YF
FUH00UYF00<005YF0000;goo000^Ool00`00FUH00003FUH200000eYF001JEP02FUH90002FUH20006
FUH01@00FUIJEUYF00001UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP04001J
EP000008FUH00`00FUIJEP040003FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH01000FUIJEP001UYF0P007Goo00@005YF
FUH000=JEP03001oogoo02aoo`00;Woo00@005YF001JEP8000=JEP03001JEUYF00EJEP03001JEUYF
00IJEP8000AJEP03001JEUYF009JEP8000AJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF
00=JEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH=0003FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP05FUH01@00FUIJEUYF00001eYF00<0
07ooOol06goo00<005YF00000eYF00<007ooOol0;7oo000^Ool01P00FUH00000FUH000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP06001JEP00001JEP001eYF0P000UYF00<005YFFUH01EYF00<005YF
00000UYF00<005YFFUH00eYF00<005YFFUH00eYF0`000UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP/000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00IJEP05001JEUYFFUH00006FUH3000LOol00`00FUIJEP03FUH00`00Oomoo`0[Ool002ioo`<0
0004FUH005YF0002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF0P002EYF00@005YF
FUH000IJEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00EJEP@000MJEP03001JEUYF00=J
EP04001JEUYFFUH2000:FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP06
FUH00`00FUIJEP02FUH20003FUH01@00FUIJEUYF000077oo00@005YFFUIJEP8002eoo`00;Woo00L0
05YF001JEP00FUH00002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006FUH0
0`00FUH000020006FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP050004FUH40002FUH0
0`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP02FUH2000JOol0
1000FUIJEUYF0P00;Goo000^Ool01000FUIJEP000eYF00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00AJEP8000AJEP05001JEUYFFUH00006FUH00`00FUH00002FUH00`00FUIJEP03FUH30003
FUH00`00FUIJEP07FUH;0002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH000030007FUH0
0`00FUIJEP02FUH200000eYF001JEP06FUH00`00FUIJEP03FUH01000FUH000001eYF0P006Goo00D0
05YF001JEP0002eoo`00;Woo00@005YFFUH000=JEP04001JEUYF0007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH200000eYF001JEP04FUH00`00FUIJEP02FUH40002FUH01000FUIJEUYF0P001UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH00UYF3@0015YF00@005YFFUH000UJEP8001Moo`05001JEP00FUH0000]Ool002mo
o`<000AJEP03001JEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000006FUH40003
Ool01@00FUIJEP00FUH00P0025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00FUH00eYF0P000goo100015YF0`0000AJEP00FUIJ
EP<000IJEP03001JEUYF008001Ioo`04001JEUYF000]Ool0035oo`80009JEP04001JEP000007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<007ooOol00Woo00<005YFFUH0
0P0000=JEP00FUH01eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00P0015YF1@000UYF00<005YFFUH015YF00<005YF00000P00
00AJEP00001oo`8000AJEP03001JEUYF009JEP<001=oo`03001JEP0002ioo`00<Woo00<005YF0000
0eYF100015YF00<005YFFUH01UYF00<005YFFUH00UYF2@0000=oo`00FUH00eYF00<005YF00000goo
00<005YF00000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF0P001EYF00<005YFFUH015YF
00<005YFFUH00UYF0`000goo0P0000=JEP00FUH01eYF0`0047oo00<005YF0000;Woo000cOol20004
FUH00`00Oomoo`0B000;Ool01@00FUIJEUYF00000UYF00<007ooOol00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF10001EYF00<005YFFUH015YF00<005YFFUH00UYF0`001Goo0`001eYF00<005YF
FUH010002goo0`00;goo000cOol00`00FUIJEP04FUH00`00Oomoo`0:Ool5000>Ool30004FUH01000
Ool0000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P0015YF00<005YFFUH015YF
00<005YFFUH00UYF00<005YF000027oo0P001EYF00<005YFFUH015YF2`0000=JEP000000;goo000d
Ool00`00FUIJEP04FUH00`00Oomoo`09Ool5000@Ool00`00FUIJEP03FUH20005FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH01@00FUH00000FUH00P000UYF00<005YFFUH015YF00<005YFFUH00UYF00<0
05YF00002Woo0`0000=JEP00FUH01eYF00<005YFFUH015YF00<005YFFUH00P00<7oo000eOol00`00
FUIJEP02FUH01000FUH000002Goo1@004Goo00<005YFFUH00eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YFFUH000=JEP03001JEP0000IJEP03001JEUYF009JEP8000ioo`<0
00MJEP03001JEUYF00=JEP05001JEUYFFUH0000aOol003Ioo`80009JEP05001JEUYFFUH00009Ool3
000COol00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP000UYF
00@005YF000000IJEP04001JEUYFFUH2000BOol40002FUH00`00FUIJEP04FUH01000FUIJEP00<Woo
000hOol20005FUH00`00Oomoo`0LOol01`00FUIJEUYF001JEP0000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP04001JEP00000HOol50003
FUH01000FUH00000<goo000iOol00`00FUIJEP04FUH2000MOol01@00FUIJEP00FUH00`000UYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH015YF00@005YFFUIJEP<001moo`D003Eoo`00
>Woo00<005YFFUH01EYF00<007ooOol06goo0P000eYF00<007oo00000P0025YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF
0P000UYF00<005YFFUH01EYF0`00G7oo000kOol00`00FUIJEP03FUH01000FUH0000077oo00<005YF
FUH00UYF00<007ooOol00P001eYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<007ooOol0
FWoo000lOol00`00FUIJEP02FUH01@00FUIJEUYF000077oo00D005YFFUIJEP0000Aoo`<000AJEP03
001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04
001JEUYFFUH:0006FUH00`00FUH0001KOol003eoo`04001JEUYF0005FUH2000JOol00`00FUIJEP02
0007Ool300000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH01000FUH000002Woo0P0015YF00@005YFFUH005Yoo`00?Woo00<005YF00001eYF0P00
6Goo00D005YF001JEP0000Uoo`@000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00AJEP@000ioo`04001JEUYF0003FUH00`00Oomoo`1HOol003moo`03001JEUYF00QJ
EP8001Moo`80009JEP03001oogoo00]oo`H0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00T000ioo`03001JEP0000AJEP03001oogoo05Moo`00@7oo0P001eYF00<0
05YFFUH00P005Woo00@005YFFUH001=oo`P000IJEP03001JEUYF00YJEP03001JEUYF00AJEPP000Ao
o`D000moo`03001JEUYF00AJEP03001oogoo05Ioo`00@Woo0P0015YF00<005YFFUH00eYF0`004goo
00<005YF000077oo6P000UYF00<007ooOol01goo1@0047oo00<005YFFUH015YF00<007ooOol0EGoo
0014Ool20002FUH00`00FUIJEP06FUH3000@Ool2000bOol01000FUIJEP0015YF00<007ooOol01goo
0`004Woo00<005YFFUH00UYF00<005YF0000EWoo0016Ool30008FUH00`00FUIJEP04000;Ool3000c
Ool20006FUH2000MOol01000FUIJEP000UYF00<007ooOol0E7oo0019Ool20005FUH00`00FUIJEP05
FUH=000eOol00`00FUIJEP06FUH00`00Oomoo`0KOol00`00FUH00003FUH00`00Oomoo`1COol004]o
o`<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000gOol20006FUH3000LOol0
0`00FUIJEP02FUH00`00Oomoo`1COol004ioo`<000MJEP03001JEUYF00AJEP03001JEUYF008003Uo
o`03001JEUYF009JEP05001JEUYFFUH0000LOol00`00FUIJEP02FUH00`00Oomoo`1BOol0055oo`@0
009JEP03001JEUYF00AJEP03001JEUYF008003]oo`05001JEUYFFUH00004FUH2000JOol01000FUIJ
EUYF0P00E7oo001EOol50004FUH3000nOol30007FUH2000IOol01@00FUH005YF0000E7oo001JOol5
0012Ool00`00FUIJEP07FUH2000GOol01@00FUH005YF0000E7oo002ROol20006FUH00`00FUIJEP02
000FOol01000FUIJEP00E7oo002TOol20004FUH00`00FUIJEP02FUH3000COol00`00FUH0001EOol0
0:Ioo`800003FUH005YF00MJEP<0011oo`03001JEP0005Eoo`00Z7oo0P002EYF00<005YF00000`00
2goo0`00EWoo002ZOol20006FUH00`00FUIJEP04FUH;00000eYF0000001FOol00:aoo`8000AJEP03
001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF008005Moo`00[Woo0P0000=JEP00FUH01eYF00<0
05YFFUH00eYF00D005YFFUIJEP0005Qoo`00/7oo0`001eYF00<005YFFUH00eYF00@005YFFUH005Uo
o`00/goo10000UYF00<005YFFUH00eYF00@005YF000005Yoo`00]goo2P00G7oo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60402 .75003 m .6047 .69453 L .57353 .69224 L p .707 .577 .707 r
F P
0 g
s
.6047 .69453 m .60402 .75003 L .63585 .74961 L p .707 .577 .707 r
F P
0 g
s
.63585 .74961 m .63654 .6941 L .6047 .69453 L p .707 .577 .707 r
F P
0 g
s
.63654 .6941 m .63585 .74961 L .66523 .74651 L p .707 .577 .707 r
F P
0 g
s
.66523 .74651 m .66592 .691 L .63654 .6941 L p .707 .577 .707 r
F P
0 g
s
.57285 .74774 m .57353 .69224 L .54608 .68746 L p .707 .577 .707 r
F P
0 g
s
.57353 .69224 m .57285 .74774 L .60402 .75003 L p .707 .577 .707 r
F P
0 g
s
.66592 .691 m .66523 .74651 L .68928 .74104 L p .707 .577 .707 r
F P
0 g
s
.68928 .74104 m .68997 .68553 L .66592 .691 L p .707 .577 .707 r
F P
0 g
s
.54539 .74296 m .54608 .68746 L .52502 .68065 L p .707 .577 .707 r
F P
0 g
s
.54608 .68746 m .54539 .74296 L .57285 .74774 L p .707 .577 .707 r
F P
0 g
s
.59187 .81229 m .59437 .77559 L .56327 .77158 L p .707 .577 .707 r
F P
0 g
s
.59437 .77559 m .59187 .81229 L .62364 .81342 L p .707 .577 .707 r
F P
0 g
s
.62364 .81342 m .62614 .77673 L .59437 .77559 L p .707 .577 .707 r
F P
0 g
s
.62614 .77673 m .62364 .81342 L .65297 .81156 L p .707 .577 .707 r
F P
0 g
s
.65297 .81156 m .65547 .77486 L .62614 .77673 L p .707 .577 .707 r
F P
0 g
s
.56077 .80827 m .56327 .77158 L .53588 .76507 L p .707 .577 .707 r
F P
0 g
s
.56327 .77158 m .56077 .80827 L .59187 .81229 L p .707 .577 .707 r
F P
0 g
s
.68997 .68553 m .68928 .74104 L .70565 .73373 L p .707 .577 .707 r
F P
0 g
s
.70565 .73373 m .70634 .67823 L .68997 .68553 L p .707 .577 .707 r
F P
0 g
s
.52502 .68065 m .52434 .73616 L .54539 .74296 L p .707 .577 .707 r
F P
0 g
s
.65547 .77486 m .65297 .81156 L .67699 .80688 L p .707 .577 .707 r
F P
0 g
s
.67699 .80688 m .67949 .77019 L .65547 .77486 L p .707 .577 .707 r
F P
0 g
s
.58987 .83612 m .58145 .81887 L .55374 .83168 L p .707 .577 .707 r
F P
0 g
s
.58145 .81887 m .58987 .83612 L .61858 .82207 L p .707 .577 .707 r
F P
0 g
s
.61858 .82207 m .61017 .80483 L .58145 .81887 L p .707 .577 .707 r
F P
0 g
s
.53588 .76507 m .53339 .80176 L .56077 .80827 L p .707 .577 .707 r
F P
0 g
s
.61017 .80483 m .61858 .82207 L .64549 .80816 L p .707 .577 .707 r
F P
0 g
s
.64549 .80816 m .63707 .79092 L .61017 .80483 L p .707 .577 .707 r
F P
0 g
s
.52434 .73616 m .52502 .68065 L .51243 .67249 L p .707 .577 .707 r
F P
0 g
s
.55374 .83168 m .56216 .84892 L .58987 .83612 L p .707 .577 .707 r
F P
0 g
s
.53339 .80176 m .53588 .76507 L .51489 .7567 L p .707 .577 .707 r
F P
0 g
s
.56216 .84892 m .55374 .83168 L .52974 .84199 L p .707 .577 .707 r
F P
0 g
s
.63707 .79092 m .64549 .80816 L .66795 .79575 L p .707 .577 .707 r
F P
0 g
s
.66795 .79575 m .65954 .77851 L .63707 .79092 L p .707 .577 .707 r
F P
0 g
s
.52974 .84199 m .53816 .85924 L .56216 .84892 L p .707 .577 .707 r
F P
0 g
s
.51489 .7567 m .51239 .7934 L .53339 .80176 L p .707 .577 .707 r
F P
0 g
s
.51243 .67249 m .51175 .72799 L .52434 .73616 L p .707 .577 .707 r
F P
0 g
s
.70634 .67823 m .70565 .73373 L .71273 .7253 L p .707 .577 .707 r
F P
0 g
s
.71273 .7253 m .71342 .6698 L .70634 .67823 L p .707 .577 .707 r
F P
0 g
s
.67949 .77019 m .67699 .80688 L .69335 .79985 L p .707 .577 .707 r
F P
0 g
s
.69335 .79985 m .69585 .76316 L .67949 .77019 L p .707 .577 .707 r
F P
0 g
s
.51239 .7934 m .51489 .7567 L .50235 .7473 L p .707 .577 .707 r
F P
0 g
s
.53816 .85924 m .52974 .84199 L .51181 .84881 L p .707 .577 .707 r
F P
0 g
s
.51181 .84881 m .52023 .86605 L .53816 .85924 L p .707 .577 .707 r
F P
0 g
s
.51175 .72799 m .51243 .67249 L .50954 .66377 L p .707 .577 .707 r
F P
0 g
s
.65954 .77851 m .66795 .79575 L .68377 .78606 L p .707 .577 .707 r
F P
0 g
s
.68377 .78606 m .67536 .76881 L .65954 .77851 L p .707 .577 .707 r
F P
0 g
s
.50235 .7473 m .49985 .784 L .51239 .7934 L p .707 .577 .707 r
F P
0 g
s
.50954 .66377 m .50885 .71927 L .51175 .72799 L p .707 .577 .707 r
F P
0 g
s
.69585 .76316 m .69335 .79985 L .70045 .79115 L p .707 .577 .707 r
F P
0 g
s
.70045 .79115 m .70294 .75446 L .69585 .76316 L p .707 .577 .707 r
F P
0 g
s
.71342 .6698 m .71273 .7253 L .70984 .71658 L p .707 .577 .707 r
F P
0 g
s
.70984 .71658 m .71052 .66108 L .71342 .6698 L p .707 .577 .707 r
F P
0 g
s
.52023 .86605 m .51181 .84881 L .50169 .85145 L p .707 .577 .707 r
F P
0 g
s
.49985 .784 m .50235 .7473 L .49949 .73779 L p .707 .577 .707 r
F P
0 g
s
.50169 .85145 m .51011 .86869 L .52023 .86605 L p .707 .577 .707 r
F P
0 g
s
.67536 .76881 m .68377 .78606 L .6914 .78002 L p .707 .577 .707 r
F P
0 g
s
.6914 .78002 m .68299 .76278 L .67536 .76881 L p .707 .577 .707 r
F P
0 g
s
.50885 .71927 m .50954 .66377 L .51662 .65534 L p .707 .577 .707 r
F P
0 g
s
.49631 .82166 m .48763 .31892 L .44363 .31701 L p .707 .577 .707 r
F P
0 g
s
.49949 .73779 m .49699 .77448 L .49985 .784 L p .707 .577 .707 r
F P
0 g
s
.51662 .65534 m .51593 .71085 L .50885 .71927 L p .707 .577 .707 r
F P
0 g
s
.49699 .77448 m .49949 .73779 L .50658 .72909 L p .707 .577 .707 r
F P
0 g
s
.51593 .71085 m .51662 .65534 L .53299 .64804 L p .707 .577 .707 r
F P
0 g
s
.50658 .72909 m .50408 .76578 L .49699 .77448 L p .707 .577 .707 r
F P
0 g
s
.53299 .64804 m .5323 .70354 L .51593 .71085 L p .707 .577 .707 r
F P
0 g
s
.50408 .76578 m .50658 .72909 L .52294 .72205 L p .707 .577 .707 r
F P
0 g
s
.52294 .72205 m .52044 .75875 L .50408 .76578 L p .707 .577 .707 r
F P
0 g
s
.52044 .75875 m .52294 .72205 L .54696 .71738 L p .707 .577 .707 r
F P
0 g
s
.54696 .71738 m .54446 .75407 L .52044 .75875 L p .707 .577 .707 r
F P
0 g
s
.48763 .31892 m .49631 .82166 L .54125 .81986 L p .707 .577 .707 r
F P
0 g
s
.5323 .70354 m .53299 .64804 L .55704 .64257 L p .707 .577 .707 r
F P
0 g
s
.55704 .64257 m .55635 .69807 L .5323 .70354 L p .707 .577 .707 r
F P
0 g
s
.54125 .81986 m .53257 .31713 L .48763 .31892 L p .707 .577 .707 r
F P
0 g
s
.55635 .69807 m .55704 .64257 L .58642 .63947 L p .707 .577 .707 r
F P
0 g
s
.58642 .63947 m .58574 .69497 L .55635 .69807 L p .707 .577 .707 r
F P
0 g
s
.54446 .75407 m .54696 .71738 L .57629 .71551 L p .707 .577 .707 r
F P
0 g
s
.57629 .71551 m .57379 .75221 L .54446 .75407 L p .707 .577 .707 r
F P
0 g
s
.57379 .75221 m .57629 .71551 L .60806 .71665 L p .707 .577 .707 r
F P
0 g
s
.60806 .71665 m .60556 .75334 L .57379 .75221 L p .707 .577 .707 r
F P
0 g
s
.55472 .83877 m .5463 .82153 L .57321 .80762 L p .707 .577 .707 r
F P
0 g
s
.57321 .80762 m .58162 .82486 L .55472 .83877 L p .707 .577 .707 r
F P
0 g
s
.58162 .82486 m .57321 .80762 L .60192 .79357 L p .707 .577 .707 r
F P
0 g
s
.53257 .31713 m .54125 .81986 L .58272 .81454 L p .707 .577 .707 r
F P
0 g
s
.58272 .81454 m .57405 .3118 L .53257 .31713 L p .707 .577 .707 r
F P
0 g
s
.45231 .81975 m .44363 .31701 L .40487 .31158 L p .707 .577 .707 r
F P
0 g
s
.44363 .31701 m .45231 .81975 L .49631 .82166 L p .707 .577 .707 r
F P
0 g
s
.70294 .75446 m .70045 .79115 L .69758 .78164 L p .707 .577 .707 r
F P
0 g
s
.69758 .78164 m .70008 .74494 L .70294 .75446 L p .707 .577 .707 r
F P
0 g
s
.71052 .66108 m .70984 .71658 L .69725 .70842 L p .707 .577 .707 r
F P
0 g
s
.69725 .70842 m .69793 .65292 L .71052 .66108 L p .707 .577 .707 r
F P
0 g
s
.58574 .69497 m .58642 .63947 L .61825 .63904 L p .707 .577 .707 r
F P
0 g
s
.61825 .63904 m .61757 .69454 L .58574 .69497 L p .707 .577 .707 r
F P
0 g
s
.63916 .72067 m .63666 .75736 L .60556 .75334 L p .707 .577 .707 r
F P
0 g
s
.60556 .75334 m .60806 .71665 L .63916 .72067 L p .707 .577 .707 r
F P
0 g
s
.62963 .78077 m .63805 .79801 L .61034 .81082 L p .707 .577 .707 r
F P
0 g
s
.61034 .81082 m .60192 .79357 L .62963 .78077 L p .707 .577 .707 r
F P
0 g
s
.60192 .79357 m .61034 .81082 L .58162 .82486 L p .707 .577 .707 r
F P
0 g
s
.57405 .3118 m .58272 .81454 L .61668 .80621 L p .707 .577 .707 r
F P
0 g
s
.61668 .80621 m .608 .30347 L .57405 .3118 L p .707 .577 .707 r
F P
0 g
s
.51011 .86869 m .50169 .85145 L .50039 .84967 L p .708 .578 .707 r
F P
0 g
s
.50039 .84967 m .5088 .86691 L .51011 .86869 L p .708 .578 .707 r
F P
0 g
s
.68299 .76278 m .6914 .78002 L .6901 .77824 L p .708 .578 .707 r
F P
0 g
s
.6901 .77824 m .68168 .761 L .68299 .76278 L p .708 .578 .707 r
F P
0 g
s
.26101 .71461 m .26169 .65911 L .23052 .65682 L p .707 .577 .707 r
F P
0 g
s
.26169 .65911 m .26101 .71461 L .29284 .71419 L p .707 .577 .707 r
F P
0 g
s
.29284 .71419 m .29353 .65868 L .26169 .65911 L p .707 .577 .707 r
F P
0 g
s
.29353 .65868 m .29284 .71419 L .32222 .71109 L p .707 .577 .707 r
F P
0 g
s
.32222 .71109 m .32291 .65558 L .29353 .65868 L p .707 .577 .707 r
F P
0 g
s
.41355 .81432 m .40487 .31158 L .37515 .30316 L p .707 .577 .707 r
F P
0 g
s
.40487 .31158 m .41355 .81432 L .45231 .81975 L p .707 .577 .707 r
F P
0 g
s
.22984 .71232 m .23052 .65682 L .20307 .65204 L p .707 .577 .707 r
F P
0 g
s
.23052 .65682 m .22984 .71232 L .26101 .71461 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.32291 .65558 m .32222 .71109 L .34627 .70561 L p .707 .577 .707 r
F P
0 g
s
.34627 .70561 m .34696 .65011 L .32291 .65558 L p .707 .577 .707 r
F P
0 g
s
.68168 .761 m .6901 .77824 L .67998 .78089 L p .707 .577 .707 r
F P
0 g
s
.70008 .74494 m .69758 .78164 L .68504 .77224 L p .707 .577 .707 r
F P
0 g
s
.68504 .77224 m .68754 .73554 L .70008 .74494 L p .707 .577 .707 r
F P
0 g
s
.69793 .65292 m .69725 .70842 L .67619 .70161 L p .707 .577 .707 r
F P
0 g
s
.67619 .70161 m .67688 .64611 L .69793 .65292 L p .707 .577 .707 r
F P
0 g
s
.20238 .70754 m .20307 .65204 L .18201 .64523 L p .707 .577 .707 r
F P
0 g
s
.20307 .65204 m .20238 .70754 L .22984 .71232 L p .707 .577 .707 r
F P
0 g
s
.64942 .64133 m .64874 .69683 L .61757 .69454 L p .707 .577 .707 r
F P
0 g
s
.61757 .69454 m .61825 .63904 L .64942 .64133 L p .707 .577 .707 r
F P
0 g
s
.66655 .72718 m .66405 .76387 L .63666 .75736 L p .707 .577 .707 r
F P
0 g
s
.63666 .75736 m .63916 .72067 L .66655 .72718 L p .707 .577 .707 r
F P
0 g
s
.65363 .77045 m .66205 .7877 L .63805 .79801 L p .707 .577 .707 r
F P
0 g
s
.63805 .79801 m .62963 .78077 L .65363 .77045 L p .707 .577 .707 r
F P
0 g
s
.608 .30347 m .61668 .80621 L .63979 .79569 L p .707 .577 .707 r
F P
0 g
s
.63979 .79569 m .63111 .29295 L .608 .30347 L p .707 .577 .707 r
F P
0 g
s
.24886 .77386 m .25136 .73716 L .22026 .73314 L p .707 .577 .707 r
F P
0 g
s
.25136 .73716 m .24886 .77386 L .28063 .77499 L p .707 .577 .707 r
F P
0 g
s
.28063 .77499 m .28313 .73829 L .25136 .73716 L p .707 .577 .707 r
F P
0 g
s
.5088 .86691 m .50039 .84967 L .50802 .84363 L p .707 .577 .707 r
F P
0 g
s
.50802 .84363 m .51644 .86088 L .5088 .86691 L p .707 .577 .707 r
F P
0 g
s
.28313 .73829 m .28063 .77499 L .30997 .77313 L p .707 .577 .707 r
F P
0 g
s
.30997 .77313 m .31246 .73643 L .28313 .73829 L p .707 .577 .707 r
F P
0 g
s
.67998 .78089 m .67157 .76364 L .68168 .761 L p .707 .577 .707 r
F P
0 g
s
.21776 .76984 m .22026 .73314 L .19287 .72663 L p .707 .577 .707 r
F P
0 g
s
.22026 .73314 m .21776 .76984 L .24886 .77386 L p .707 .577 .707 r
F P
0 g
s
.34696 .65011 m .34627 .70561 L .36264 .69831 L p .707 .577 .707 r
F P
0 g
s
.36264 .69831 m .36333 .6428 L .34696 .65011 L p .707 .577 .707 r
F P
0 g
s
.18201 .64523 m .18133 .70073 L .20238 .70754 L p .707 .577 .707 r
F P
0 g
s
.38383 .8059 m .37515 .30316 L .35738 .29258 L p .707 .577 .707 r
F P
0 g
s
.37515 .30316 m .38383 .8059 L .41355 .81432 L p .707 .577 .707 r
F P
0 g
s
.67688 .64611 m .67619 .70161 L .64874 .69683 L p .707 .577 .707 r
F P
0 g
s
.64874 .69683 m .64942 .64133 L .67688 .64611 L p .707 .577 .707 r
F P
0 g
s
.31246 .73643 m .30997 .77313 L .33399 .76845 L p .707 .577 .707 r
F P
0 g
s
.33399 .76845 m .33648 .73176 L .31246 .73643 L p .707 .577 .707 r
F P
0 g
s
.19287 .72663 m .19038 .76333 L .21776 .76984 L p .707 .577 .707 r
F P
0 g
s
.24686 .79825 m .23844 .78101 L .21073 .79382 L p .707 .577 .707 r
F P
0 g
s
.23844 .78101 m .24686 .79825 L .27558 .78421 L p .707 .577 .707 r
F P
0 g
s
.27558 .78421 m .26716 .76697 L .23844 .78101 L p .707 .577 .707 r
F P
0 g
s
.26716 .76697 m .27558 .78421 L .30248 .7703 L p .707 .577 .707 r
F P
0 g
s
.30248 .7703 m .29406 .75306 L .26716 .76697 L p .707 .577 .707 r
F P
0 g
s
.21073 .79382 m .21915 .81106 L .24686 .79825 L p .707 .577 .707 r
F P
0 g
s
.18133 .70073 m .18201 .64523 L .16942 .63707 L p .707 .577 .707 r
F P
0 g
s
.67157 .76364 m .67998 .78089 L .66205 .7877 L p .707 .577 .707 r
F P
0 g
s
.66205 .7877 m .65363 .77045 L .67157 .76364 L p .707 .577 .707 r
F P
0 g
s
.68754 .73554 m .68504 .77224 L .66405 .76387 L p .707 .577 .707 r
F P
0 g
s
.66405 .76387 m .66655 .72718 L .68754 .73554 L p .707 .577 .707 r
F P
0 g
s
.19038 .76333 m .19287 .72663 L .17188 .71827 L p .707 .577 .707 r
F P
0 g
s
.21915 .81106 m .21073 .79382 L .18673 .80413 L p .707 .577 .707 r
F P
0 g
s
.29406 .75306 m .30248 .7703 L .32494 .75789 L p .707 .577 .707 r
F P
0 g
s
.32494 .75789 m .31653 .74065 L .29406 .75306 L p .707 .577 .707 r
F P
0 g
s
.18673 .80413 m .19515 .82137 L .21915 .81106 L p .707 .577 .707 r
F P
0 g
s
.51644 .86088 m .50802 .84363 L .52384 .83394 L p .707 .577 .707 r
F P
0 g
s
.17188 .71827 m .16939 .75496 L .19038 .76333 L p .707 .577 .707 r
F P
0 g
s
.52384 .83394 m .53226 .85118 L .51644 .86088 L p .707 .577 .707 r
F P
0 g
s
.63111 .29295 m .63979 .79569 L .64979 .784 L p .707 .577 .707 r
F P
0 g
s
.64979 .784 m .64111 .28126 L .63111 .29295 L p .707 .577 .707 r
F P
0 g
s
.16942 .63707 m .16874 .69257 L .18133 .70073 L p .707 .577 .707 r
F P
0 g
s
.36333 .6428 m .36264 .69831 L .36972 .68988 L p .707 .577 .707 r
F P
0 g
s
.36972 .68988 m .37041 .63438 L .36333 .6428 L p .707 .577 .707 r
F P
0 g
s
.33648 .73176 m .33399 .76845 L .35034 .76142 L p .707 .577 .707 r
F P
0 g
s
.35034 .76142 m .35284 .72472 L .33648 .73176 L p .707 .577 .707 r
F P
0 g
s
.16939 .75496 m .17188 .71827 L .15934 .70887 L p .707 .577 .707 r
F P
0 g
s
.19515 .82137 m .18673 .80413 L .1688 .81094 L p .707 .577 .707 r
F P
0 g
s
.1688 .81094 m .17722 .82819 L .19515 .82137 L p .707 .577 .707 r
F P
0 g
s
.31653 .74065 m .32494 .75789 L .34076 .7482 L p .707 .577 .707 r
F P
0 g
s
.34076 .7482 m .33235 .73095 L .31653 .74065 L p .707 .577 .707 r
F P
0 g
s
.16874 .69257 m .16942 .63707 L .16653 .62835 L p .707 .577 .707 r
F P
0 g
s
.36752 .62566 m .36683 .68116 L .35424 .673 L p .707 .577 .707 r
F P
0 g
s
.35424 .673 m .35492 .61749 L .36752 .62566 L p .707 .577 .707 r
F P
0 g
s
.36606 .79532 m .35738 .29258 L .3533 .28088 L p .707 .577 .707 r
F P
0 g
s
.37041 .63438 m .36972 .68988 L .36683 .68116 L p .707 .577 .707 r
F P
0 g
s
.36683 .68116 m .36752 .62566 L .37041 .63438 L p .707 .577 .707 r
F P
0 g
s
.35738 .29258 m .36606 .79532 L .38383 .8059 L p .707 .577 .707 r
F P
0 g
s
.15934 .70887 m .15684 .74556 L .16939 .75496 L p .707 .577 .707 r
F P
0 g
s
.53226 .85118 m .52384 .83394 L .5463 .82153 L p .707 .577 .707 r
F P
0 g
s
.5463 .82153 m .55472 .83877 L .53226 .85118 L p .707 .577 .707 r
F P
0 g
s
.35284 .72472 m .35034 .76142 L .35744 .75272 L p .707 .577 .707 r
F P
0 g
s
.35744 .75272 m .35993 .71602 L .35284 .72472 L p .707 .577 .707 r
F P
0 g
s
.16653 .62835 m .16584 .68385 L .16874 .69257 L p .707 .577 .707 r
F P
0 g
s
.17722 .82819 m .1688 .81094 L .15869 .81359 L p .707 .577 .707 r
F P
0 g
s
.15684 .74556 m .15934 .70887 L .15648 .69935 L p .707 .577 .707 r
F P
0 g
s
.15869 .81359 m .1671 .83083 L .17722 .82819 L p .707 .577 .707 r
F P
0 g
s
.33235 .73095 m .34076 .7482 L .34839 .74216 L p .707 .577 .707 r
F P
0 g
s
.34839 .74216 m .33998 .72492 L .33235 .73095 L p .707 .577 .707 r
F P
0 g
s
.64111 .28126 m .64979 .784 L .6457 .7723 L p .707 .577 .707 r
F P
0 g
s
.6457 .7723 m .63702 .26956 L .64111 .28126 L p .707 .577 .707 r
F P
0 g
s
.16584 .68385 m .16653 .62835 L .17361 .61992 L p .707 .577 .707 r
F P
0 g
s
.15648 .69935 m .15398 .73605 L .15684 .74556 L p .707 .577 .707 r
F P
0 g
s
.35993 .71602 m .35744 .75272 L .35457 .7432 L p .707 .577 .707 r
F P
0 g
s
.35457 .7432 m .35707 .70651 L .35993 .71602 L p .707 .577 .707 r
F P
0 g
s
.17361 .61992 m .17292 .67542 L .16584 .68385 L p .707 .577 .707 r
F P
0 g
s
.3533 .28088 m .36197 .78362 L .36606 .79532 L p .707 .577 .707 r
F P
0 g
s
.36197 .78362 m .3533 .28088 L .3633 .26919 L p .707 .577 .707 r
F P
0 g
s
.1671 .83083 m .15869 .81359 L .15738 .81181 L p .708 .578 .707 r
F P
0 g
s
.15398 .73605 m .15648 .69935 L .16357 .69065 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15738 .81181 m .1658 .82905 L .1671 .83083 L p .708 .578 .707 r
F P
0 g
s
.33998 .72492 m .34839 .74216 L .34709 .74038 L p .708 .578 .707 r
F P
0 g
s
.34709 .74038 m .33867 .72313 L .33998 .72492 L p .708 .578 .707 r
F P
0 g
s
.17292 .67542 m .17361 .61992 L .18998 .61261 L p .707 .577 .707 r
F P
0 g
s
.16357 .69065 m .16107 .72735 L .15398 .73605 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63702 .26956 m .6457 .7723 L .62793 .76172 L p .707 .577 .707 r
F P
0 g
s
.62793 .76172 m .61925 .25898 L .63702 .26956 L p .707 .577 .707 r
F P
0 g
s
.33867 .72313 m .34709 .74038 L .33697 .74302 L p .707 .577 .707 r
F P
0 g
s
.35707 .70651 m .35457 .7432 L .34203 .7338 L p .707 .577 .707 r
F P
0 g
s
.34203 .7338 m .34453 .69711 L .35707 .70651 L p .707 .577 .707 r
F P
0 g
s
.18998 .61261 m .18929 .66812 L .17292 .67542 L p .707 .577 .707 r
F P
0 g
s
.35492 .61749 m .35424 .673 L .33318 .66619 L p .707 .577 .707 r
F P
0 g
s
.33318 .66619 m .33387 .61069 L .35492 .61749 L p .707 .577 .707 r
F P
0 g
s
.16107 .72735 m .16357 .69065 L .17993 .68362 L p .707 .577 .707 r
F P
0 g
s
.1658 .82905 m .15738 .81181 L .16501 .80577 L p .707 .577 .707 r
F P
0 g
s
.16501 .80577 m .17343 .82301 L .1658 .82905 L p .707 .577 .707 r
F P
0 g
s
.18929 .66812 m .18998 .61261 L .21403 .60714 L p .707 .577 .707 r
F P
0 g
s
.33697 .74302 m .32856 .72578 L .33867 .72313 L p .707 .577 .707 r
F P
0 g
s
.37197 .77193 m .3633 .26919 L .3864 .25867 L p .707 .577 .707 r
F P
0 g
s
.3633 .26919 m .37197 .77193 L .36197 .78362 L p .707 .577 .707 r
F P
0 g
s
.17993 .68362 m .17743 .72032 L .16107 .72735 L p .707 .577 .707 r
F P
0 g
s
.33387 .61069 m .33318 .66619 L .30573 .66141 L p .707 .577 .707 r
F P
0 g
s
.30573 .66141 m .30642 .60591 L .33387 .61069 L p .707 .577 .707 r
F P
0 g
s
.21403 .60714 m .21335 .66265 L .18929 .66812 L p .707 .577 .707 r
F P
0 g
s
.32856 .72578 m .33697 .74302 L .31904 .74984 L p .707 .577 .707 r
F P
0 g
s
.31904 .74984 m .31062 .73259 L .32856 .72578 L p .707 .577 .707 r
F P
0 g
s
.34453 .69711 m .34203 .7338 L .32104 .72544 L p .707 .577 .707 r
F P
0 g
s
.32104 .72544 m .32354 .68874 L .34453 .69711 L p .707 .577 .707 r
F P
0 g
s
.21335 .66265 m .21403 .60714 L .24341 .60404 L p .707 .577 .707 r
F P
0 g
s
.17743 .72032 m .17993 .68362 L .20395 .67894 L p .707 .577 .707 r
F P
0 g
s
.61925 .25898 m .62793 .76172 L .59821 .7533 L p .707 .577 .707 r
F P
0 g
s
.59821 .7533 m .58953 .25056 L .61925 .25898 L p .707 .577 .707 r
F P
0 g
s
.30642 .60591 m .30573 .66141 L .27456 .65912 L p .707 .577 .707 r
F P
0 g
s
.27456 .65912 m .27525 .60362 L .30642 .60591 L p .707 .577 .707 r
F P
0 g
s
.17343 .82301 m .16501 .80577 L .18083 .79607 L p .707 .577 .707 r
F P
0 g
s
.18083 .79607 m .18925 .81332 L .17343 .82301 L p .707 .577 .707 r
F P
0 g
s
.24273 .65955 m .24341 .60404 L .27525 .60362 L p .707 .577 .707 r
F P
0 g
s
.24341 .60404 m .24273 .65955 L .21335 .66265 L p .707 .577 .707 r
F P
0 g
s
.20395 .67894 m .20145 .71564 L .17743 .72032 L p .707 .577 .707 r
F P
0 g
s
.27525 .60362 m .27456 .65912 L .24273 .65955 L p .707 .577 .707 r
F P
0 g
s
.74122 .65799 m .74191 .60249 L .71074 .6002 L p .707 .577 .707 r
F P
0 g
s
.74191 .60249 m .74122 .65799 L .77305 .65757 L p .707 .577 .707 r
F P
0 g
s
.77305 .65757 m .77374 .60206 L .74191 .60249 L p .707 .577 .707 r
F P
0 g
s
.32354 .68874 m .32104 .72544 L .29366 .71893 L p .707 .577 .707 r
F P
0 g
s
.29366 .71893 m .29615 .68223 L .32354 .68874 L p .707 .577 .707 r
F P
0 g
s
.77374 .60206 m .77305 .65757 L .80243 .65447 L p .707 .577 .707 r
F P
0 g
s
.80243 .65447 m .80312 .59896 L .77374 .60206 L p .707 .577 .707 r
F P
0 g
s
.3864 .25867 m .39508 .76141 L .37197 .77193 L p .707 .577 .707 r
F P
0 g
s
.39508 .76141 m .3864 .25867 L .42036 .25034 L p .707 .577 .707 r
F P
0 g
s
.71005 .6557 m .71074 .6002 L .68328 .59542 L p .707 .577 .707 r
F P
0 g
s
.71074 .6002 m .71005 .6557 L .74122 .65799 L p .707 .577 .707 r
F P
0 g
s
.20145 .71564 m .20395 .67894 L .23328 .67708 L p .707 .577 .707 r
F P
0 g
s
.80312 .59896 m .80243 .65447 L .82649 .649 L p .707 .577 .707 r
F P
0 g
s
.82649 .649 m .82717 .59349 L .80312 .59896 L p .707 .577 .707 r
F P
0 g
s
.29615 .68223 m .29366 .71893 L .26255 .71491 L p .707 .577 .707 r
F P
0 g
s
.26255 .71491 m .26505 .67821 L .29615 .68223 L p .707 .577 .707 r
F P
0 g
s
.18925 .81332 m .18083 .79607 L .20329 .78366 L p .707 .577 .707 r
F P
0 g
s
.23328 .67708 m .23078 .71378 L .20145 .71564 L p .707 .577 .707 r
F P
0 g
s
.20329 .78366 m .21171 .80091 L .18925 .81332 L p .707 .577 .707 r
F P
0 g
s
.31062 .73259 m .31904 .74984 L .29504 .76015 L p .707 .577 .707 r
F P
0 g
s
.29504 .76015 m .28662 .74291 L .31062 .73259 L p .707 .577 .707 r
F P
0 g
s
.23078 .71378 m .23328 .67708 L .26505 .67821 L p .707 .577 .707 r
F P
0 g
s
.58953 .25056 m .59821 .7533 L .55945 .74787 L p .707 .577 .707 r
F P
0 g
s
.55945 .74787 m .55077 .24513 L .58953 .25056 L p .707 .577 .707 r
F P
0 g
s
.68259 .65092 m .68328 .59542 L .66223 .58861 L p .707 .577 .707 r
F P
0 g
s
.68328 .59542 m .68259 .65092 L .71005 .6557 L p .707 .577 .707 r
F P
0 g
s
.26505 .67821 m .26255 .71491 L .23078 .71378 L p .707 .577 .707 r
F P
0 g
s
.72908 .72025 m .73157 .68356 L .70047 .67954 L p .707 .577 .707 r
F P
0 g
s
.73157 .68356 m .72908 .72025 L .76085 .72139 L p .707 .577 .707 r
F P
0 g
s
.76085 .72139 m .76334 .68469 L .73157 .68356 L p .707 .577 .707 r
F P
0 g
s
.76334 .68469 m .76085 .72139 L .79018 .71952 L p .707 .577 .707 r
F P
0 g
s
.79018 .71952 m .79267 .68283 L .76334 .68469 L p .707 .577 .707 r
F P
0 g
s
.42903 .75307 m .42036 .25034 L .46183 .24501 L p .707 .577 .707 r
F P
0 g
s
.42036 .25034 m .42903 .75307 L .39508 .76141 L p .707 .577 .707 r
F P
0 g
s
.69798 .71623 m .70047 .67954 L .67309 .67303 L p .707 .577 .707 r
F P
0 g
s
.70047 .67954 m .69798 .71623 L .72908 .72025 L p .707 .577 .707 r
F P
0 g
s
.82717 .59349 m .82649 .649 L .84285 .64169 L p .707 .577 .707 r
F P
0 g
s
.84285 .64169 m .84354 .58619 L .82717 .59349 L p .707 .577 .707 r
F P
0 g
s
.21171 .80091 m .20329 .78366 L .2302 .76976 L p .707 .577 .707 r
F P
0 g
s
.28662 .74291 m .29504 .76015 L .26733 .77296 L p .707 .577 .707 r
F P
0 g
s
.26733 .77296 m .25891 .75571 L .28662 .74291 L p .707 .577 .707 r
F P
0 g
s
.66223 .58861 m .66154 .64412 L .68259 .65092 L p .707 .577 .707 r
F P
0 g
s
.2302 .76976 m .23861 .787 L .21171 .80091 L p .707 .577 .707 r
F P
0 g
s
.79267 .68283 m .79018 .71952 L .8142 .71485 L p .707 .577 .707 r
F P
0 g
s
.8142 .71485 m .81669 .67815 L .79267 .68283 L p .707 .577 .707 r
F P
0 g
s
.55077 .24513 m .55945 .74787 L .51545 .74596 L p .707 .577 .707 r
F P
0 g
s
.51545 .74596 m .50677 .24322 L .55077 .24513 L p .707 .577 .707 r
F P
0 g
s
.72707 .74408 m .71866 .72683 L .69095 .73964 L p .707 .577 .707 r
F P
0 g
s
.71866 .72683 m .72707 .74408 L .75579 .73003 L p .707 .577 .707 r
F P
0 g
s
.75579 .73003 m .74737 .71279 L .71866 .72683 L p .707 .577 .707 r
F P
0 g
s
.67309 .67303 m .67059 .70972 L .69798 .71623 L p .707 .577 .707 r
F P
0 g
s
.74737 .71279 m .75579 .73003 L .78269 .71613 L p .707 .577 .707 r
F P
0 g
s
.78269 .71613 m .77428 .69888 L .74737 .71279 L p .707 .577 .707 r
F P
0 g
s
.66154 .64412 m .66223 .58861 L .64964 .58045 L p .707 .577 .707 r
F P
0 g
s
.69095 .73964 m .69936 .75688 L .72707 .74408 L p .707 .577 .707 r
F P
0 g
s
.23861 .787 m .2302 .76976 L .25891 .75571 L p .707 .577 .707 r
F P
0 g
s
.25891 .75571 m .26733 .77296 L .23861 .787 L p .707 .577 .707 r
F P
0 g
s
.67059 .70972 m .67309 .67303 L .65209 .66466 L p .707 .577 .707 r
F P
0 g
s
.47051 .74775 m .46183 .24501 L .50677 .24322 L p .707 .577 .707 r
F P
0 g
s
.46183 .24501 m .47051 .74775 L .42903 .75307 L p .707 .577 .707 r
F P
0 g
s
.50677 .24322 m .51545 .74596 L .47051 .74775 L p .707 .577 .707 r
F P
0 g
s
.69936 .75688 m .69095 .73964 L .66695 .74995 L p .707 .577 .707 r
F P
0 g
s
.77428 .69888 m .78269 .71613 L .80516 .70372 L p .707 .577 .707 r
F P
0 g
s
.80516 .70372 m .79674 .68647 L .77428 .69888 L p .707 .577 .707 r
F P
0 g
s
.66695 .74995 m .67536 .7672 L .69936 .75688 L p .707 .577 .707 r
F P
0 g
s
.65209 .66466 m .6496 .70136 L .67059 .70972 L p .707 .577 .707 r
F P
0 g
s
.64964 .58045 m .64895 .63595 L .66154 .64412 L p .707 .577 .707 r
F P
0 g
s
.84354 .58619 m .84285 .64169 L .84994 .63327 L p .707 .577 .707 r
F P
0 g
s
.84994 .63327 m .85062 .57776 L .84354 .58619 L p .707 .577 .707 r
F P
0 g
s
.81669 .67815 m .8142 .71485 L .83056 .70781 L p .707 .577 .707 r
F P
0 g
s
.83056 .70781 m .83305 .67112 L .81669 .67815 L p .707 .577 .707 r
F P
0 g
s
.6496 .70136 m .65209 .66466 L .63955 .65526 L p .707 .577 .707 r
F P
0 g
s
.67536 .7672 m .66695 .74995 L .64901 .75677 L p .707 .577 .707 r
F P
0 g
s
.64901 .75677 m .65743 .77401 L .67536 .7672 L p .707 .577 .707 r
F P
0 g
s
.64895 .63595 m .64964 .58045 L .64674 .57173 L p .707 .577 .707 r
F P
0 g
s
.79674 .68647 m .80516 .70372 L .82098 .69402 L p .707 .577 .707 r
F P
0 g
s
.82098 .69402 m .81256 .67678 L .79674 .68647 L p .707 .577 .707 r
F P
0 g
s
.63955 .65526 m .63706 .69196 L .6496 .70136 L p .707 .577 .707 r
F P
0 g
s
.64674 .57173 m .64605 .62723 L .64895 .63595 L p .707 .577 .707 r
F P
0 g
s
.83305 .67112 m .83056 .70781 L .83765 .69911 L p .707 .577 .707 r
F P
0 g
s
.83765 .69911 m .84015 .66242 L .83305 .67112 L p .707 .577 .707 r
F P
0 g
s
.85062 .57776 m .84994 .63327 L .84704 .62454 L p .707 .577 .707 r
F P
0 g
s
.84704 .62454 m .84773 .56904 L .85062 .57776 L p .707 .577 .707 r
F P
0 g
s
.65743 .77401 m .64901 .75677 L .6389 .75941 L p .707 .577 .707 r
F P
0 g
s
.63706 .69196 m .63955 .65526 L .63669 .64575 L p .707 .577 .707 r
F P
0 g
s
.6389 .75941 m .64731 .77666 L .65743 .77401 L p .707 .577 .707 r
F P
0 g
s
.81256 .67678 m .82098 .69402 L .82861 .68798 L p .707 .577 .707 r
F P
0 g
s
.82861 .68798 m .82019 .67074 L .81256 .67678 L p .707 .577 .707 r
F P
0 g
s
.64605 .62723 m .64674 .57173 L .65382 .5633 L p .707 .577 .707 r
F P
0 g
s
.63669 .64575 m .63419 .68244 L .63706 .69196 L p .707 .577 .707 r
F P
0 g
s
.84015 .66242 m .83765 .69911 L .83479 .6896 L p .707 .577 .707 r
F P
0 g
s
.83479 .6896 m .83728 .6529 L .84015 .66242 L p .707 .577 .707 r
F P
0 g
s
.65382 .5633 m .65314 .61881 L .64605 .62723 L p .707 .577 .707 r
F P
0 g
s
.84773 .56904 m .84704 .62454 L .83445 .61638 L p .707 .577 .707 r
F P
0 g
s
.83445 .61638 m .83514 .56088 L .84773 .56904 L p .707 .577 .707 r
F P
0 g
s
.64731 .77666 m .6389 .75941 L .63759 .75763 L p .708 .578 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63419 .68244 m .63669 .64575 L .64378 .63705 L p .707 .577 .707 r
F P
0 g
s
.63759 .75763 m .64601 .77487 L .64731 .77666 L p .708 .578 .707 r
F P
0 g
s
.82019 .67074 m .82861 .68798 L .8273 .6862 L p .708 .578 .707 r
F P
0 g
s
.8273 .6862 m .81889 .66896 L .82019 .67074 L p .708 .578 .707 r
F P
0 g
s
.39821 .62257 m .3989 .56707 L .36773 .56478 L p .707 .577 .707 r
F P
0 g
s
.3989 .56707 m .39821 .62257 L .43004 .62215 L p .707 .577 .707 r
F P
0 g
s
.43004 .62215 m .43073 .56664 L .3989 .56707 L p .707 .577 .707 r
F P
0 g
s
.65314 .61881 m .65382 .5633 L .67019 .556 L p .707 .577 .707 r
F P
0 g
s
.43073 .56664 m .43004 .62215 L .45942 .61905 L p .707 .577 .707 r
F P
0 g
s
.45942 .61905 m .46011 .56354 L .43073 .56664 L p .707 .577 .707 r
F P
0 g
s
.36704 .62028 m .36773 .56478 L .34027 .56 L p .707 .577 .707 r
F P
0 g
s
.36773 .56478 m .36704 .62028 L .39821 .62257 L p .707 .577 .707 r
F P
0 g
s
.64378 .63705 m .64129 .67374 L .63419 .68244 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.46011 .56354 m .45942 .61905 L .48348 .61358 L p .707 .577 .707 r
F P
0 g
s
.48348 .61358 m .48416 .55807 L .46011 .56354 L p .707 .577 .707 r
F P
0 g
s
.67019 .556 m .66951 .6115 L .65314 .61881 L p .707 .577 .707 r
F P
0 g
s
.81889 .66896 m .8273 .6862 L .81719 .68885 L p .707 .577 .707 r
F P
0 g
s
.83728 .6529 m .83479 .6896 L .82225 .6802 L p .707 .577 .707 r
F P
0 g
s
.82225 .6802 m .82474 .6435 L .83728 .6529 L p .707 .577 .707 r
F P
0 g
s
.83514 .56088 m .83445 .61638 L .8134 .60958 L p .707 .577 .707 r
F P
0 g
s
.8134 .60958 m .81409 .55407 L .83514 .56088 L p .707 .577 .707 r
F P
0 g
s
.33958 .6155 m .34027 .56 L .31922 .55319 L p .707 .577 .707 r
F P
0 g
s
.34027 .56 m .33958 .6155 L .36704 .62028 L p .707 .577 .707 r
F P
0 g
s
.38607 .68182 m .38856 .64512 L .35746 .6411 L p .707 .577 .707 r
F P
0 g
s
.38856 .64512 m .38607 .68182 L .41784 .68295 L p .707 .577 .707 r
F P
0 g
s
.41784 .68295 m .42033 .64626 L .38856 .64512 L p .707 .577 .707 r
F P
0 g
s
.64129 .67374 m .64378 .63705 L .66014 .63001 L p .707 .577 .707 r
F P
0 g
s
.64601 .77487 m .63759 .75763 L .64522 .75159 L p .707 .577 .707 r
F P
0 g
s
.66951 .6115 m .67019 .556 L .69425 .55053 L p .707 .577 .707 r
F P
0 g
s
.64522 .75159 m .65364 .76884 L .64601 .77487 L p .707 .577 .707 r
F P
0 g
s
.42033 .64626 m .41784 .68295 L .44717 .68109 L p .707 .577 .707 r
F P
0 g
s
.44717 .68109 m .44966 .64439 L .42033 .64626 L p .707 .577 .707 r
F P
0 g
s
.81719 .68885 m .80877 .6716 L .81889 .66896 L p .707 .577 .707 r
F P
0 g
s
.35497 .6778 m .35746 .6411 L .33008 .63459 L p .707 .577 .707 r
F P
0 g
s
.35746 .6411 m .35497 .6778 L .38607 .68182 L p .707 .577 .707 r
F P
0 g
s
.48416 .55807 m .48348 .61358 L .49984 .60627 L p .707 .577 .707 r
F P
0 g
s
.49984 .60627 m .50053 .55077 L .48416 .55807 L p .707 .577 .707 r
F P
0 g
s
.66014 .63001 m .65765 .66671 L .64129 .67374 L p .707 .577 .707 r
F P
0 g
s
.31922 .55319 m .31853 .6087 L .33958 .6155 L p .707 .577 .707 r
F P
0 g
s
.81409 .55407 m .8134 .60958 L .78594 .60479 L p .707 .577 .707 r
F P
0 g
s
.78594 .60479 m .78663 .54929 L .81409 .55407 L p .707 .577 .707 r
F P
0 g
s
.44966 .64439 m .44717 .68109 L .47119 .67641 L p .707 .577 .707 r
F P
0 g
s
.47119 .67641 m .47368 .63972 L .44966 .64439 L p .707 .577 .707 r
F P
0 g
s
.33008 .63459 m .32758 .67129 L .35497 .6778 L p .707 .577 .707 r
F P
0 g
s
.38406 .70622 m .37565 .68897 L .34794 .70178 L p .707 .577 .707 r
F P
0 g
s
.37565 .68897 m .38406 .70622 L .41278 .69217 L p .707 .577 .707 r
F P
0 g
s
.41278 .69217 m .40436 .67493 L .37565 .68897 L p .707 .577 .707 r
F P
0 g
s
.69425 .55053 m .69356 .60603 L .66951 .6115 L p .707 .577 .707 r
F P
0 g
s
.40436 .67493 m .41278 .69217 L .43968 .67826 L p .707 .577 .707 r
F P
0 g
s
.43968 .67826 m .43127 .66102 L .40436 .67493 L p .707 .577 .707 r
F P
0 g
s
.34794 .70178 m .35635 .71902 L .38406 .70622 L p .707 .577 .707 r
F P
0 g
s
.31853 .6087 m .31922 .55319 L .30663 .54503 L p .707 .577 .707 r
F P
0 g
s
.80877 .6716 m .81719 .68885 L .79925 .69566 L p .707 .577 .707 r
F P
0 g
s
.79925 .69566 m .79084 .67842 L .80877 .6716 L p .707 .577 .707 r
F P
0 g
s
.82474 .6435 m .82225 .6802 L .80126 .67183 L p .707 .577 .707 r
F P
0 g
s
.80126 .67183 m .80375 .63514 L .82474 .6435 L p .707 .577 .707 r
F P
0 g
s
.32758 .67129 m .33008 .63459 L .30908 .62623 L p .707 .577 .707 r
F P
0 g
s
.69356 .60603 m .69425 .55053 L .72363 .54743 L p .707 .577 .707 r
F P
0 g
s
.65765 .66671 m .66014 .63001 L .68416 .62534 L p .707 .577 .707 r
F P
0 g
s
.35635 .71902 m .34794 .70178 L .32394 .71209 L p .707 .577 .707 r
F P
0 g
s
.43127 .66102 m .43968 .67826 L .46215 .66585 L p .707 .577 .707 r
F P
0 g
s
.46215 .66585 m .45373 .64861 L .43127 .66102 L p .707 .577 .707 r
F P
0 g
s
.32394 .71209 m .33235 .72934 L .35635 .71902 L p .707 .577 .707 r
F P
0 g
s
.78663 .54929 m .78594 .60479 L .75477 .6025 L p .707 .577 .707 r
F P
0 g
s
.75477 .6025 m .75546 .547 L .78663 .54929 L p .707 .577 .707 r
F P
0 g
s
.65364 .76884 m .64522 .75159 L .66104 .7419 L p .707 .577 .707 r
F P
0 g
s
.30908 .62623 m .30659 .66293 L .32758 .67129 L p .707 .577 .707 r
F P
0 g
s
.66104 .7419 m .66946 .75914 L .65364 .76884 L p .707 .577 .707 r
F P
0 g
s
.72294 .60293 m .72363 .54743 L .75546 .547 L p .707 .577 .707 r
F P
0 g
s
.72363 .54743 m .72294 .60293 L .69356 .60603 L p .707 .577 .707 r
F P
0 g
s
.30663 .54503 m .30594 .60053 L .31853 .6087 L p .707 .577 .707 r
F P
0 g
s
.50053 .55077 m .49984 .60627 L .50693 .59784 L p .707 .577 .707 r
F P
0 g
s
.50693 .59784 m .50761 .54234 L .50053 .55077 L p .707 .577 .707 r
F P
0 g
s
.47368 .63972 m .47119 .67641 L .48755 .66938 L p .707 .577 .707 r
F P
0 g
s
.48755 .66938 m .49004 .63268 L .47368 .63972 L p .707 .577 .707 r
F P
0 g
s
.75546 .547 m .75477 .6025 L .72294 .60293 L p .707 .577 .707 r
F P
0 g
s
.68416 .62534 m .68167 .66203 L .65765 .66671 L p .707 .577 .707 r
F P
0 g
s
.80375 .63514 m .80126 .67183 L .77387 .66532 L p .707 .577 .707 r
F P
0 g
s
.77387 .66532 m .77637 .62863 L .80375 .63514 L p .707 .577 .707 r
F P
0 g
s
.30659 .66293 m .30908 .62623 L .29654 .61683 L p .707 .577 .707 r
F P
0 g
s
.33235 .72934 m .32394 .71209 L .306 .7189 L p .707 .577 .707 r
F P
0 g
s
.306 .7189 m .31442 .73615 L .33235 .72934 L p .707 .577 .707 r
F P
0 g
s
.45373 .64861 m .46215 .66585 L .47797 .65616 L p .707 .577 .707 r
F P
0 g
s
.47797 .65616 m .46955 .63891 L .45373 .64861 L p .707 .577 .707 r
F P
0 g
s
.68167 .66203 m .68416 .62534 L .71349 .62348 L p .707 .577 .707 r
F P
0 g
s
.30594 .60053 m .30663 .54503 L .30373 .53631 L p .707 .577 .707 r
F P
0 g
s
.29654 .61683 m .29405 .65353 L .30659 .66293 L p .707 .577 .707 r
F P
0 g
s
.77637 .62863 m .77387 .66532 L .74277 .66131 L p .707 .577 .707 r
F P
0 g
s
.74277 .66131 m .74526 .62461 L .77637 .62863 L p .707 .577 .707 r
F P
0 g
s
.66946 .75914 m .66104 .7419 L .68351 .72949 L p .707 .577 .707 r
F P
0 g
s
.71349 .62348 m .711 .66017 L .68167 .66203 L p .707 .577 .707 r
F P
0 g
s
.68351 .72949 m .69192 .74673 L .66946 .75914 L p .707 .577 .707 r
F P
0 g
s
.79084 .67842 m .79925 .69566 L .77526 .70597 L p .707 .577 .707 r
F P
0 g
s
.77526 .70597 m .76684 .68873 L .79084 .67842 L p .707 .577 .707 r
F P
0 g
s
.711 .66017 m .71349 .62348 L .74526 .62461 L p .707 .577 .707 r
F P
0 g
s
.49004 .63268 m .48755 .66938 L .49464 .66068 L p .707 .577 .707 r
F P
0 g
s
.49464 .66068 m .49714 .62398 L .49004 .63268 L p .707 .577 .707 r
F P
0 g
s
.30373 .53631 m .30304 .59181 L .30594 .60053 L p .707 .577 .707 r
F P
0 g
s
.74526 .62461 m .74277 .66131 L .711 .66017 L p .707 .577 .707 r
F P
0 g
s
.50761 .54234 m .50693 .59784 L .50403 .58912 L p .707 .577 .707 r
F P
0 g
s
.50403 .58912 m .50472 .53362 L .50761 .54234 L p .707 .577 .707 r
F P
0 g
s
.31442 .73615 m .306 .7189 L .29589 .72155 L p .707 .577 .707 r
F P
0 g
s
.29405 .65353 m .29654 .61683 L .29368 .60731 L p .707 .577 .707 r
F P
0 g
s
.29589 .72155 m .3043 .73879 L .31442 .73615 L p .707 .577 .707 r
F P
0 g
s
.46955 .63891 m .47797 .65616 L .4856 .65012 L p .707 .577 .707 r
F P
0 g
s
.4856 .65012 m .47718 .63288 L .46955 .63891 L p .707 .577 .707 r
F P
0 g
s
.69192 .74673 m .68351 .72949 L .71041 .71558 L p .707 .577 .707 r
F P
0 g
s
.76684 .68873 m .77526 .70597 L .74754 .71878 L p .707 .577 .707 r
F P
0 g
s
.74754 .71878 m .73913 .70154 L .76684 .68873 L p .707 .577 .707 r
F P
0 g
s
.71041 .71558 m .71883 .73282 L .69192 .74673 L p .707 .577 .707 r
F P
0 g
s
.30304 .59181 m .30373 .53631 L .31081 .52788 L p .707 .577 .707 r
F P
0 g
s
.29368 .60731 m .29118 .64401 L .29405 .65353 L p .707 .577 .707 r
F P
0 g
s
.71883 .73282 m .71041 .71558 L .73913 .70154 L p .707 .577 .707 r
F P
0 g
s
.73913 .70154 m .74754 .71878 L .71883 .73282 L p .707 .577 .707 r
F P
0 g
s
.49714 .62398 m .49464 .66068 L .49178 .65117 L p .707 .577 .707 r
F P
0 g
s
.49178 .65117 m .49427 .61447 L .49714 .62398 L p .707 .577 .707 r
F P
0 g
s
.31081 .52788 m .31013 .58339 L .30304 .59181 L p .707 .577 .707 r
F P
0 g
s
.50472 .53362 m .50403 .58912 L .49144 .58096 L p .707 .577 .707 r
F P
0 g
s
.49144 .58096 m .49213 .52546 L .50472 .53362 L p .707 .577 .707 r
F P
0 g
s
.3043 .73879 m .29589 .72155 L .29458 .71977 L p .708 .578 .707 r
F P
0 g
s
.29118 .64401 m .29368 .60731 L .30077 .59861 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29458 .71977 m .303 .73701 L .3043 .73879 L p .708 .578 .707 r
F P
0 g
s
.47718 .63288 m .4856 .65012 L .48429 .64834 L p .708 .578 .707 r
F P
0 g
s
.48429 .64834 m .47588 .6311 L .47718 .63288 L p .708 .578 .707 r
F P
0 g
s
.31013 .58339 m .31081 .52788 L .32718 .52058 L p .707 .577 .707 r
F P
0 g
s
.30077 .59861 m .29828 .63531 L .29118 .64401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.47588 .6311 m .48429 .64834 L .47418 .65098 L p .707 .577 .707 r
F P
0 g
s
.49427 .61447 m .49178 .65117 L .47924 .64177 L p .707 .577 .707 r
F P
0 g
s
.47924 .64177 m .48173 .60507 L .49427 .61447 L p .707 .577 .707 r
F P
0 g
s
.32718 .52058 m .3265 .57608 L .31013 .58339 L p .707 .577 .707 r
F P
0 g
s
.49213 .52546 m .49144 .58096 L .47039 .57415 L p .707 .577 .707 r
F P
0 g
s
.47039 .57415 m .47107 .51865 L .49213 .52546 L p .707 .577 .707 r
F P
0 g
s
.29828 .63531 m .30077 .59861 L .31713 .59158 L p .707 .577 .707 r
F P
0 g
s
.303 .73701 m .29458 .71977 L .30221 .71373 L p .707 .577 .707 r
F P
0 g
s
.30221 .71373 m .31063 .73098 L .303 .73701 L p .707 .577 .707 r
F P
0 g
s
.3265 .57608 m .32718 .52058 L .35123 .5151 L p .707 .577 .707 r
F P
0 g
s
.47418 .65098 m .46576 .63374 L .47588 .6311 L p .707 .577 .707 r
F P
0 g
s
.31713 .59158 m .31464 .62828 L .29828 .63531 L p .707 .577 .707 r
F P
0 g
s
.47107 .51865 m .47039 .57415 L .44293 .56937 L p .707 .577 .707 r
F P
0 g
s
.44293 .56937 m .44362 .51387 L .47107 .51865 L p .707 .577 .707 r
F P
0 g
s
.35123 .5151 m .35055 .57061 L .3265 .57608 L p .707 .577 .707 r
F P
0 g
s
.46576 .63374 m .47418 .65098 L .45624 .6578 L p .707 .577 .707 r
F P
0 g
s
.45624 .6578 m .44783 .64055 L .46576 .63374 L p .707 .577 .707 r
F P
0 g
s
.48173 .60507 m .47924 .64177 L .45825 .6334 L p .707 .577 .707 r
F P
0 g
s
.45825 .6334 m .46074 .5967 L .48173 .60507 L p .707 .577 .707 r
F P
0 g
s
.35055 .57061 m .35123 .5151 L .38062 .512 L p .707 .577 .707 r
F P
0 g
s
.31464 .62828 m .31713 .59158 L .34115 .5869 L p .707 .577 .707 r
F P
0 g
s
.44362 .51387 m .44293 .56937 L .41176 .56708 L p .707 .577 .707 r
F P
0 g
s
.41176 .56708 m .41245 .51158 L .44362 .51387 L p .707 .577 .707 r
F P
0 g
s
.31063 .73098 m .30221 .71373 L .31803 .70404 L p .707 .577 .707 r
F P
0 g
s
.31803 .70404 m .32645 .72128 L .31063 .73098 L p .707 .577 .707 r
F P
0 g
s
.37993 .56751 m .38062 .512 L .41245 .51158 L p .707 .577 .707 r
F P
0 g
s
.38062 .512 m .37993 .56751 L .35055 .57061 L p .707 .577 .707 r
F P
0 g
s
.34115 .5869 m .33866 .6236 L .31464 .62828 L p .707 .577 .707 r
F P
0 g
s
.41245 .51158 m .41176 .56708 L .37993 .56751 L p .707 .577 .707 r
F P
0 g
s
.46074 .5967 m .45825 .6334 L .43086 .62689 L p .707 .577 .707 r
F P
0 g
s
.43086 .62689 m .43335 .59019 L .46074 .5967 L p .707 .577 .707 r
F P
0 g
s
.33866 .6236 m .34115 .5869 L .37048 .58504 L p .707 .577 .707 r
F P
0 g
s
.43335 .59019 m .43086 .62689 L .39976 .62287 L p .707 .577 .707 r
F P
0 g
s
.39976 .62287 m .40225 .58618 L .43335 .59019 L p .707 .577 .707 r
F P
0 g
s
.32645 .72128 m .31803 .70404 L .3405 .69163 L p .707 .577 .707 r
F P
0 g
s
.37048 .58504 m .36799 .62174 L .33866 .6236 L p .707 .577 .707 r
F P
0 g
s
.3405 .69163 m .34891 .70887 L .32645 .72128 L p .707 .577 .707 r
F P
0 g
s
.44783 .64055 m .45624 .6578 L .43224 .66811 L p .707 .577 .707 r
F P
0 g
s
.43224 .66811 m .42383 .65087 L .44783 .64055 L p .707 .577 .707 r
F P
0 g
s
.36799 .62174 m .37048 .58504 L .40225 .58618 L p .707 .577 .707 r
F P
0 g
s
.40225 .58618 m .39976 .62287 L .36799 .62174 L p .707 .577 .707 r
F P
0 g
s
.34891 .70887 m .3405 .69163 L .3674 .67772 L p .707 .577 .707 r
F P
0 g
s
.42383 .65087 m .43224 .66811 L .40453 .68092 L p .707 .577 .707 r
F P
0 g
s
.40453 .68092 m .39612 .66367 L .42383 .65087 L p .707 .577 .707 r
F P
0 g
s
.3674 .67772 m .37582 .69496 L .34891 .70887 L p .707 .577 .707 r
F P
0 g
s
.37582 .69496 m .3674 .67772 L .39612 .66367 L p .707 .577 .707 r
F P
0 g
s
.39612 .66367 m .40453 .68092 L .37582 .69496 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUIVOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEUYF
001JEVIoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YFIWoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol00`00
FUIJEP0B000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH2001UOol0069oo`H000AJEP03001JEUYF00IJEP03001JEUYF009JEPP0009JEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80
06Eoo`00Ggoo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD0
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00
G7oo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YF00000P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IGoo001JOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Qoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP<000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00Egoo0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH00P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IGoo001FOol00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJEUYF001J
EP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF
000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00EWoo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00EWoo00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80019ooa40049oo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000aoo`H000=JEP03001JEUYF00IJ
EP03001JEUYF009JEPP003Yoo`00EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000Qoo`@00003FUH005YF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH6000dOol005Ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20005Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00002000aOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003Ool200000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000_Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH3000<FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3000]Ool0
05Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04
001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;7oo001FOol00`00FUH00003FUH01000FUIJEUYF2@0025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF00@005YFFUIJEP<000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001J
EUYF000/Ool005Ioo`03001JEP0000=JEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEPD000AJEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`04001JEP00
FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool005Ioo`03001JEP00
008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP<000=JEP<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003
FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]oo`00EWoo0P000UYF00<005YFFUH00UYF
60000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000AJEP00000000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03
001JEUYF008002]oo`00EWoo0P000UYF00<005YF00000P0000=JEP00FUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH00UYF100035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P00:goo001FOol00`00FUIJEP030004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH0000300000eYF001JEP05FUH00`00FUIJEP02FUH4000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[
Ool005Ioo`<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00=JEP8000IJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool0
05Eoo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP<000AJEP03001JEUYF009JEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000[Ool0
045ooa800003Ool0000000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF0080009JEP03001JEUYF009JEP800003FUH005YF00]J
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF
00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002]o
o`00>goo1P0015YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF
0`000eYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=JEP00FUH00eYF00@005YFFUIJEPT000MJEP03001JEUYF00IJEPP000AJEP03001JEUYF00=J
EP03001JEUYF008002]oo`00>7oo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF1@0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF1P001eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF1P0015YF00<005YFFUH00P00:goo000eOol30004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001J
EP020005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH3000015YF001JEUYF0P00:goo000cOol200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00001JEP00
00EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00AJEP<0009JEP8002]oo`00<Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH4
000[Ool0031oo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEP8000AJEP04001JEUYFFUH90002FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`000eYF00<005YFFUH00UYF5`000eYF00<005YFFUH01UYF00<005YFFUH00eYF
00<005YFFUH00UYF0`00:goo000_Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEPD00003FUH005YF00AJEP80009JEP03001JEUYF
00AJEP<000AJEPH000IJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003FUH500000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH60006FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000[Ool002moo`03
001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP08001JEUYFFUH005YF
001JEP800004FUH000000002FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH50006FUH00`00
FUIJEP040002FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000AJEP00000000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00=JEP03001JEUYF009JEP03
001JEP0002]oo`00;goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00H005YFFUIJEP00FUH200000eYF001JEP03FUH30005FUH20002FUH00`00FUIJEP03FUH50006
FUH00`00FUIJEP04FUH40004FUH01P00FUIJEP00FUH000AJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000EJEP03001JEUYF009JEP03001JEP0002]oo`00
;goo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEP0000<00003FUH00000009JEP03001JEUYF00=JEPD000IJ
EP03001JEUYF00EJEP800006FUH00000001JEP000UYF00<005YF000015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000=JEP03001JEUYF009JEP8002ao
o`00;goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00=JEPL000EJEP<000MJEP03001JEUYF009JEP<0
00AJEP04001JEP000002FUH20005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP02FUH2000]Ool002moo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP02FUHD00000eYF001JEP04FUH01P00FUIJEUYF001JEP80
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH200000eYF0000000_Ool002moo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP03FUH00`00FUH000040005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00eYF0`00<7oo000_Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`001UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000_Ool002moo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP07FUH0
1000FUH000000UYF00<005YFFUH00`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000_Ool002moo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF009JEQ4000=JEP<000EJEP03001JEUYF00AJEP03001JEUYF00MJ
EP04001JEUYFFUH30004FUH00`00FUIJEP04FUH30003FUH01`00FUIJEUYF001JEP0000EJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02000^Ool002moo`03001JEP0000=JEP03001JEUYF00=JEPL000QJEP03001JEUYF00EJEPL000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF008000MJEP03001JEUYF00@0009JEP04001J
EP000004FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF
00000eYF00@005YFFUIJEPT0009JEP03001oogoo00=oo`P000AJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH2000^Ool002moo`03001JEP0000=JEP03001JEP0000<000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00EJEP03001JEUYF00IJEP@000UJ
EP8000IJEP800003FUH005YF00=JEP8000IJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00IJEP05001JEP00FUH00003FUH40002FUH00`00FUIJEP03FUH01000FUIJEP001goo0`000goo1P00
1UYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;goo00<005YF00000eYF0P000UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF10001EYF00<005YFFUH01EYF
0P000eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P000eYF00@005YFFUIJEP8000MJEP03001J
EUYF00YJEP03001JEUYF00MJEP03001JEUYF00IJEP06001JEP00FUH005YF0P0000AJEP000000009J
EP03001JEUYF00=JEP03001JEUYF008000Eoo`D000Qoo`@0009JEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool002moo`04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP00FUH015YF0P001EYF00<005YFFUH00UYF
0P0015YF00@005YF000000EJEP04001JEP000009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH01000FUH005YF0P0000=JEP00FUH00eYF0`001EYF00<005YFFUH00P001Goo1@0037oo
100015YF00@005YFFUIJEP8002ioo`00;goo00<005YF00000P001EYF00<005YFFUH00UYF40001EYF
00<005YFFUH01EYF00<005YFFUH015YF200025YF00@005YF000000IJEP800003FUH005YF009JEP@0
00]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJ
EP03FUH00`00FUH00003000015YF001JEUYF0P001Goo1@002Woo0`000eYF0`0000=JEP00FUH00UYF
0P00;Woo000_Ool20002FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH0100000=J
EP00FUH01UYF00<005YFFUH015YF00@005YFFUIJEP<000UJEP8000IJEPT0009JEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP000003FUH00`00FUIJEP03
FUH00`00FUIJEP03FUH60006Ool30009Ool20002FUH00`00FUIJEP03FUH30003FUH2000^Ool002mo
o`03001JEUYF00D0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEPH000=JEP03
001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP04FUH300000eYF001JEP02FUH3000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<0
05YFFUH015YF00<005YFFUH01EYF00@005YFFUIJEQ8000AJEP03001JEUYF00=JEP04001JEUYF0002
FUH2000^Ool002moo`<00003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH40006FUH20005FUH00`00FUIJEP02FUH500000eYF001JEP0200000eYF001J
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH0
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF0`001eYF
00<005YFFUH00UYF2000;Woo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH30002FUH20008FUH00`00FUH000060002FUH01@00
FUIJEUYF00002eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP800003FUH005YF00IJEP03001JEUYF00800005FUH005YF001JEP03000^Ool002eoo`8000AJEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00800003FUH005YF00MJEP8000=JEP<00003FUH0000000AJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF0000
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0P000eYF00<005YFFUH01EYF0`00
15YF00<005YFFUH00`00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH00`00FUIJEP04FUH2
0002FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P001UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF0P000eYF00<005YF
0000;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH20005FUH01000FUIJEUYF0P0015YF00<005YFFUH00P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000QJEP03001J
EUYF008000AJEP@000AJEP8002moo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P001eYF00@005YF000000MJEP80
0003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP800006FUH00000001JEP001eYF00<005YFFUH01UYF0P00
00=JEP00FUH025YF0P001UYF00@005YFFUH000AJEP8002moo`00;7oo0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00MJ
EP03001JEUYF00EJEP8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<000IJEP03001J
EUYF00AJEP8000AJEP03001JEUYF00AJEP800003FUH005YF00=JEP8000=JEP04001JEUYFFUH2000`
Ool002aoo`8000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP04001J
EP000004FUH00`00FUIJEP03FUH200000eYF001JEP03FUH20005FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20004FUH00`00FUIJEP040002FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP02FUH20004
FUH01000FUH000001EYF00@005YF0000039oo`00;7oo0P0015YF00@005YFFUIJEPP000Qoo`T000AJ
EP800003FUH005YF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP030006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH80009FUH01000FUH000001UYF0`000eYF1@00=7oo
000[Ool00`00FUH00003FUH5000IOol50002FUH00`00FUIJEP03FUH30005FUH30002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
00=JEP00FUH025YF0P001UYF2000>Goo000[Ool01000FUH005YF0P0000AJEP00000001=oo`<000Uo
o`04001JEUYF0004FUH20004FUH200000eYF00000002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH01000FUH000000eYF00<005YFFUH01EYF100015YF
0`00@7oo000[Ool01P00FUH00000FUH000AJEP<000moo`D000Qoo`04001JEUYF0002FUH20002FUH0
1000FUH000000UYF00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF0`001EYF0P001UYF00<005YFFUH00UYF1@0000=JEP00FUH00P00@goo000[Ool20003FUH0
0`00FUIJEP03FUH00`00FUH00003000;Ool50009Ool00`00FUIJEP020003FUH300001eYF001JEUYF
001JEP00009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJEP<00003FUH0
000000QJEP03001JEUYF00800004FUH000000002FUH20015Ool002]oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00=JEPL000Aoo`D000Uoo`04001JEP000002FUH200000eYF001JEP020002FUH00`00
FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH01P00FUH00000
FUH000UJEP8000IJEP8004Moo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH00UYF500000AJEP00000000=JEP06001JEUYFFUH005YF0`000UYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0015YF0P0015YF00<005YFFUH015YF0P0000=JEP00FUH00eYF0P00
BGoo000[Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP0200001EYF000005YF00001EYF00<005YF00001@000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF0P001UYF00<005YFFUH00UYF0P0015YF00@005YF0000
04]oo`00;7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF009JEP<00003FUH0000000<0009JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP800004FUH005YF0007FUH01000FUH000001UYF0P00CGoo000/Ool01@00FUIJ
EUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0P0000=JEP00FUH01eYF
00@005YF0000009JEP800003FUH000000080009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEQl000QJEP03001JEUYF00EJEP03001JEUYF009JEP<0009JEP03001JEUYF00EJEP8000IJ
EP8004moo`00;Goo0P0000=JEP00FUH015YF00<005YFFUH015YF00<005YFFUH01eYF00@005YFFUIJ
EP<000AJEP03001JEUYF00AJEP<000=JEP06001JEUYFFUH005YF0P000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00@005YFFUIJEPH000YJEP03001JEUYF00UJEP03001JEUYF00IJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEP800003FUH005YF00=JEP80
055oo`00;goo0P001EYF00<005YFFUH015YF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF
009JEP80009JEP04001JEP000004FUH01000FUH000000UYF00<005YFFUH015YF00<005YFFUH015YF
1P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH010001UYF00@0
05YFFUIJEP8000EJEP03001JEUYF008000AJEP04001JEP00001COol0035oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP<00003FUH005YF00MJEP04001JEP000005FUH00`00FUH00004FUH20000
1Goo001JEUYF00001UYF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH015YF10000UYF00@005YFFUH0009JEP03001JEUYF00=JEP8000EJEP<005Eo
o`00<goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF0P000eYF00<005YFFUH01EYF0`001EYF0P00
0UYF00@005YFFUIJEP80009oo`04001JEUYF0005FUH40002FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH40002FUH01000FUIJEP000eYF0`00
15YF0P0000=JEP000000EGoo000eOol50003FUH00`00FUIJEP03FUH20006FUH00`00FUIJEP02FUH2
0002FUH01000FUIJEUYF0P0015YF00@005YF000000Aoo`04001JEUYF0003FUH20006FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJ
EUYF0P0000AJEP00FUIJEP<000=JEP04001JEP000003FUH2001EOol003Yoo`H00003FUH0000000QJ
EP03001JEUYF008000EJEP@000=JEP@000Ioo`05001JEUYF001JEP030007FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
0002FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2001EOol003moo`<000UJEP<000IJEPP000Yo
o`03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP07001JEUYF001JEP00FUH00P00
00=JEP00FUH00P000eYF0P00EGoo000mOol20003FUH00`00FUIJEP04FUH40005FUH2000BOol00`00
FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000040004FUH01000FUIJEP000UYF
0P00EGoo000kOol20005FUH00`00FUIJEP02FUH5000015YF001JEUYF0P0057oo0`0015YF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00FUIJEP05001EOol003Uoo`8000QJ
EP03001JEP0000H0009JEP8001Ioo`03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04
001JEUYF0002FUH01000FUIJEUYF1@0000AJEP00000005Eoo`00=goo0P0000=JEP00FUH01eYF0P00
0eYF0`0000=JEP00000067oo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000eYF10000eYF00<005YFFUH00`00EGoo000fOol01@00FUIJEUYF00001UYF0P0000=JEP00FUH0
15YF0P006goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000UYF0P0000=JEP00FUH00UYF
0P000eYF00<005YF0000EGoo000dOol20005FUH01000FUIJEUYF0P0015YF00<005YFFUH00P007Goo
0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100015YF100015YF0P00EWoo000cOol00`00FUIJ
EP05FUH01000FUH000001eYF0P0087oo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
0P001UYF00@005YFFUH000AJEP8005Ioo`00<Goo0`0025YF00<005YFFUH01EYF0P008goo0P000UYF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YFFUIJEP800003FUH005YF00=JEP8000=JEP04001JEUYFFUH2001GOol0
02moo`8000=JEP03001JEUYF00=JEP800003FUH005YF00=JEP8002Moo`<000MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000004
FUH01000FUH000001EYF00@005YF000005Uoo`00;Woo00<005YFFUH00eYF00@005YFFUIJEP8000=J
EP03001JEUYF008002]oo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00EJEP@000IJEP<000=JEPD005]oo`00;7oo0P0000=JEP00FUH015YF
0`001EYF0`00;goo10000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01`001UYF2000H7oo000]Ool00`00FUH00005FUH20004FUH2000fOol50008
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH500000eYF000000040004FUH3001W
Ool002eoo`04001JEUYF0003FUH01@00FUIJEP00FUH00P00?Goo1P000UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00@005YFFUIJEPH00003FUH005YF00=JEPD00003FUH005YF008006Yoo`00;Woo00@0
05YF001JEP80009JEP<004Eooal000MJEP03001JEUYF00L00003FUH0000006aoo`00;Woo00<005YF
FUH00P0000=JEP000000Hgoo0`002EYF0P000eYF1@00KWoo000_Ool5001SOol20003FUH00`00FUIJ
EP04FUH200000eYF001JEP03FUH2001`Ool002moo`8006Aoo`8000EJEP03001JEUYF009JEP8000AJ
EP04001JEP00001bOol009Aoo`03001JEUYF00IJEP04001JEP000006FUH2001dOol0099oo`800003
FUH005YF00IJEP8000IJEP8007Ioo`00T7oo0P000eYF00<005YFFUH00eYF0P0000=JEP00FUH00eYF
0P00N7oo002?Ool20005FUH01@00FUIJEUYF000015YF00@005YF000007Yoo`00SWoo00@005YFFUH0
00AJEP04001JEP000004FUH3001lOol008ioo`04001JEUYF0004FUH20004FUH2001oOol008moo`05
001JEUYF001JEP020002FUH01000FUH00000PGoo002?Ool00`00FUIJEP020003FUH30023Ool0091o
o`05FUH005YF001JEP020026Ool0091oo`03001JEUYF008008Qoo`00TGoo0P00RWoo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]36\[InvisibleSpace]"     "\
\[InvisibleSpace]11.328523591985396`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 36, "     ", 11.328523591985396, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60426 .7488 m .60393 .69326 L .57278 .69148 L p .707 .577 .707 r
F P
0 g
s
.60393 .69326 m .60426 .7488 L .63611 .74786 L p .707 .577 .707 r
F P
0 g
s
.63611 .74786 m .63577 .69232 L .60393 .69326 L p .707 .577 .707 r
F P
0 g
s
.63577 .69232 m .63611 .74786 L .66553 .74432 L p .707 .577 .707 r
F P
0 g
s
.66553 .74432 m .66519 .68877 L .63577 .69232 L p .707 .577 .707 r
F P
0 g
s
.57311 .74703 m .57278 .69148 L .54537 .68718 L p .707 .577 .707 r
F P
0 g
s
.57278 .69148 m .57311 .74703 L .60426 .7488 L p .707 .577 .707 r
F P
0 g
s
.66519 .68877 m .66553 .74432 L .68965 .7385 L p .707 .577 .707 r
F P
0 g
s
.68965 .7385 m .68931 .68296 L .66519 .68877 L p .707 .577 .707 r
F P
0 g
s
.59165 .80712 m .59409 .76988 L .56303 .76619 L p .707 .577 .707 r
F P
0 g
s
.59409 .76988 m .59165 .80712 L .62343 .80843 L p .707 .577 .707 r
F P
0 g
s
.62343 .80843 m .62588 .77119 L .59409 .76988 L p .707 .577 .707 r
F P
0 g
s
.62588 .77119 m .62343 .80843 L .65283 .80725 L p .707 .577 .707 r
F P
0 g
s
.65283 .80725 m .65528 .77 L .62588 .77119 L p .707 .577 .707 r
F P
0 g
s
.54537 .68718 m .54571 .74273 L .57311 .74703 L p .707 .577 .707 r
F P
0 g
s
.54571 .74273 m .54537 .68718 L .5244 .68077 L p .707 .577 .707 r
F P
0 g
s
.56058 .80344 m .56303 .76619 L .53573 .7605 L p .707 .577 .707 r
F P
0 g
s
.56303 .76619 m .56058 .80344 L .59165 .80712 L p .707 .577 .707 r
F P
0 g
s
.65528 .77 m .65283 .80725 L .67696 .80368 L p .707 .577 .707 r
F P
0 g
s
.67696 .80368 m .67941 .76643 L .65528 .77 L p .707 .577 .707 r
F P
0 g
s
.53573 .7605 m .53328 .79774 L .56058 .80344 L p .707 .577 .707 r
F P
0 g
s
.68931 .68296 m .68965 .7385 L .7061 .73099 L p .707 .577 .707 r
F P
0 g
s
.7061 .73099 m .70577 .67545 L .68931 .68296 L p .707 .577 .707 r
F P
0 g
s
.62043 .85899 m .61208 .84349 L .58336 .85693 L p .707 .577 .707 r
F P
0 g
s
.61208 .84349 m .62043 .85899 L .64709 .84209 L p .707 .577 .707 r
F P
0 g
s
.64709 .84209 m .63874 .82659 L .61208 .84349 L p .707 .577 .707 r
F P
0 g
s
.5244 .68077 m .52473 .73631 L .54571 .74273 L p .707 .577 .707 r
F P
0 g
s
.53328 .79774 m .53573 .7605 L .51486 .75335 L p .707 .577 .707 r
F P
0 g
s
.59172 .87243 m .58336 .85693 L .5554 .8656 L p .707 .577 .707 r
F P
0 g
s
.58336 .85693 m .59172 .87243 L .62043 .85899 L p .707 .577 .707 r
F P
0 g
s
.63874 .82659 m .64709 .84209 L .66907 .8234 L p .707 .577 .707 r
F P
0 g
s
.66907 .8234 m .66072 .80789 L .63874 .82659 L p .707 .577 .707 r
F P
0 g
s
.52473 .73631 m .5244 .68077 L .5119 .67287 L p .707 .577 .707 r
F P
0 g
s
.5554 .8656 m .56375 .88111 L .59172 .87243 L p .707 .577 .707 r
F P
0 g
s
.51486 .75335 m .51241 .7906 L .53328 .79774 L p .707 .577 .707 r
F P
0 g
s
.56375 .88111 m .5554 .8656 L .53092 .86866 L p .707 .577 .707 r
F P
0 g
s
.67941 .76643 m .67696 .80368 L .69347 .79808 L p .707 .577 .707 r
F P
0 g
s
.69347 .79808 m .69592 .76083 L .67941 .76643 L p .707 .577 .707 r
F P
0 g
s
.66072 .80789 m .66907 .8234 L .68423 .80473 L p .707 .577 .707 r
F P
0 g
s
.68423 .80473 m .67588 .78923 L .66072 .80789 L p .707 .577 .707 r
F P
0 g
s
.53092 .86866 m .53927 .88417 L .56375 .88111 L p .707 .577 .707 r
F P
0 g
s
.70577 .67545 m .7061 .73099 L .71328 .72252 L p .707 .577 .707 r
F P
0 g
s
.71328 .72252 m .71295 .66698 L .70577 .67545 L p .707 .577 .707 r
F P
0 g
s
.5119 .67287 m .51223 .72842 L .52473 .73631 L p .707 .577 .707 r
F P
0 g
s
.51241 .7906 m .51486 .75335 L .50247 .74545 L p .707 .577 .707 r
F P
0 g
s
.50247 .74545 m .50003 .7827 L .51241 .7906 L p .707 .577 .707 r
F P
0 g
s
.53927 .88417 m .53092 .86866 L .51232 .8658 L p .707 .577 .707 r
F P
0 g
s
.51223 .72842 m .5119 .67287 L .5091 .66427 L p .707 .577 .707 r
F P
0 g
s
.67588 .78923 m .68423 .80473 L .69109 .78792 L p .707 .577 .707 r
F P
0 g
s
.69109 .78792 m .68273 .77242 L .67588 .78923 L p .707 .577 .707 r
F P
0 g
s
.69592 .76083 m .69347 .79808 L .70073 .79099 L p .707 .577 .707 r
F P
0 g
s
.70073 .79099 m .70318 .75374 L .69592 .76083 L p .707 .577 .707 r
F P
0 g
s
.51232 .8658 m .52067 .8813 L .53927 .88417 L p .707 .577 .707 r
F P
0 g
s
.5091 .66427 m .50943 .71981 L .51223 .72842 L p .707 .577 .707 r
F P
0 g
s
.50003 .7827 m .50247 .74545 L .49978 .73757 L p .707 .577 .707 r
F P
0 g
s
.71295 .66698 m .71328 .72252 L .71049 .71392 L p .707 .577 .707 r
F P
0 g
s
.71049 .71392 m .71016 .65837 L .71295 .66698 L p .707 .577 .707 r
F P
0 g
s
.49542 .8219 m .49542 .32002 L .45109 .31774 L p .707 .577 .707 r
F P
0 g
s
.49978 .73757 m .49733 .77482 L .50003 .7827 L p .707 .577 .707 r
F P
0 g
s
.50943 .71981 m .5091 .66427 L .51628 .6558 L p .707 .577 .707 r
F P
0 g
s
.51628 .6558 m .51662 .71134 L .50943 .71981 L p .707 .577 .707 r
F P
0 g
s
.49733 .77482 m .49978 .73757 L .50704 .73048 L p .707 .577 .707 r
F P
0 g
s
.50704 .73048 m .50459 .76773 L .49733 .77482 L p .707 .577 .707 r
F P
0 g
s
.51662 .71134 m .51628 .6558 L .53274 .64829 L p .707 .577 .707 r
F P
0 g
s
.53274 .64829 m .53307 .70383 L .51662 .71134 L p .707 .577 .707 r
F P
0 g
s
.50459 .76773 m .50704 .73048 L .52354 .72488 L p .707 .577 .707 r
F P
0 g
s
.52354 .72488 m .52109 .76213 L .50459 .76773 L p .707 .577 .707 r
F P
0 g
s
.52109 .76213 m .52354 .72488 L .54767 .72131 L p .707 .577 .707 r
F P
0 g
s
.51451 .84269 m .50616 .82719 L .52132 .80852 L p .707 .577 .707 r
F P
0 g
s
.54767 .72131 m .54522 .75856 L .52109 .76213 L p .707 .577 .707 r
F P
0 g
s
.52132 .80852 m .52967 .82403 L .51451 .84269 L p .707 .577 .707 r
F P
0 g
s
.52967 .82403 m .52132 .80852 L .5433 .78983 L p .707 .577 .707 r
F P
0 g
s
.5433 .78983 m .55165 .80533 L .52967 .82403 L p .707 .577 .707 r
F P
0 g
s
.49542 .32002 m .49542 .8219 L .5402 .82039 L p .707 .577 .707 r
F P
0 g
s
.53307 .70383 m .53274 .64829 L .55686 .64247 L p .707 .577 .707 r
F P
0 g
s
.55686 .64247 m .55719 .69802 L .53307 .70383 L p .707 .577 .707 r
F P
0 g
s
.5402 .82039 m .5402 .3185 L .49542 .32002 L p .707 .577 .707 r
F P
0 g
s
.52067 .8813 m .51232 .8658 L .50143 .8573 L p .707 .577 .707 r
F P
0 g
s
.68273 .77242 m .69109 .78792 L .68896 .77462 L p .707 .577 .707 r
F P
0 g
s
.68896 .77462 m .68061 .75911 L .68273 .77242 L p .707 .577 .707 r
F P
0 g
s
.55719 .69802 m .55686 .64247 L .58628 .63893 L p .707 .577 .707 r
F P
0 g
s
.58628 .63893 m .58661 .69447 L .55719 .69802 L p .707 .577 .707 r
F P
0 g
s
.54522 .75856 m .54767 .72131 L .57707 .72012 L p .707 .577 .707 r
F P
0 g
s
.57707 .72012 m .57462 .75737 L .54522 .75856 L p .707 .577 .707 r
F P
0 g
s
.57462 .75737 m .57707 .72012 L .60886 .72144 L p .707 .577 .707 r
F P
0 g
s
.60702 .77499 m .59867 .75949 L .62664 .75081 L p .707 .577 .707 r
F P
0 g
s
.60886 .72144 m .60641 .75868 L .57462 .75737 L p .707 .577 .707 r
F P
0 g
s
.55165 .80533 m .5433 .78983 L .56996 .77293 L p .707 .577 .707 r
F P
0 g
s
.59867 .75949 m .60702 .77499 L .57831 .78843 L p .707 .577 .707 r
F P
0 g
s
.57831 .78843 m .56996 .77293 L .59867 .75949 L p .707 .577 .707 r
F P
0 g
s
.56996 .77293 m .57831 .78843 L .55165 .80533 L p .707 .577 .707 r
F P
0 g
s
.5402 .3185 m .5402 .82039 L .58104 .81524 L p .707 .577 .707 r
F P
0 g
s
.58104 .81524 m .58104 .31335 L .5402 .3185 L p .707 .577 .707 r
F P
0 g
s
.45109 .81963 m .45109 .31774 L .41155 .3119 L p .707 .577 .707 r
F P
0 g
s
.45109 .31774 m .45109 .81963 L .49542 .8219 L p .707 .577 .707 r
F P
0 g
s
.50143 .8573 m .50978 .87281 L .52067 .8813 L p .707 .577 .707 r
F P
0 g
s
.70318 .75374 m .70073 .79099 L .69803 .78311 L p .707 .577 .707 r
F P
0 g
s
.69803 .78311 m .70048 .74586 L .70318 .75374 L p .707 .577 .707 r
F P
0 g
s
.25642 .71439 m .25628 .65872 L .22513 .65691 L p .707 .577 .707 r
F P
0 g
s
.25628 .65872 m .25642 .71439 L .28827 .71358 L p .707 .577 .707 r
F P
0 g
s
.28827 .71358 m .28812 .65791 L .25628 .65872 L p .707 .577 .707 r
F P
0 g
s
.58661 .69447 m .58628 .63893 L .61812 .63799 L p .707 .577 .707 r
F P
0 g
s
.61812 .63799 m .61846 .69354 L .58661 .69447 L p .707 .577 .707 r
F P
0 g
s
.62664 .75081 m .63499 .76632 L .60702 .77499 L p .707 .577 .707 r
F P
0 g
s
.63499 .76632 m .62664 .75081 L .65112 .74775 L p .707 .577 .707 r
F P
0 g
s
.63992 .72512 m .63748 .76237 L .60641 .75868 L p .707 .577 .707 r
F P
0 g
s
.60641 .75868 m .60886 .72144 L .63992 .72512 L p .707 .577 .707 r
F P
0 g
s
.58104 .31335 m .58104 .81524 L .61395 .80695 L p .707 .577 .707 r
F P
0 g
s
.61395 .80695 m .61395 .30506 L .58104 .31335 L p .707 .577 .707 r
F P
0 g
s
.71016 .65837 m .71049 .71392 L .69799 .70602 L p .707 .577 .707 r
F P
0 g
s
.69799 .70602 m .69766 .65048 L .71016 .65837 L p .707 .577 .707 r
F P
0 g
s
.28812 .65791 m .28827 .71358 L .31769 .71023 L p .707 .577 .707 r
F P
0 g
s
.31769 .71023 m .31754 .65456 L .28812 .65791 L p .707 .577 .707 r
F P
0 g
s
.41155 .81379 m .41155 .3119 L .38067 .30307 L p .707 .577 .707 r
F P
0 g
s
.41155 .3119 m .41155 .81379 L .45109 .81963 L p .707 .577 .707 r
F P
0 g
s
.50978 .87281 m .50143 .8573 L .4993 .844 L p .707 .577 .707 r
F P
0 g
s
.22527 .71258 m .22513 .65691 L .19772 .65265 L p .707 .577 .707 r
F P
0 g
s
.22513 .65691 m .22527 .71258 L .25642 .71439 L p .707 .577 .707 r
F P
0 g
s
.68061 .75911 m .68896 .77462 L .67807 .76612 L p .707 .577 .707 r
F P
0 g
s
.67807 .76612 m .66972 .75062 L .68061 .75911 L p .707 .577 .707 r
F P
0 g
s
.4993 .844 m .50766 .8595 L .50978 .87281 L p .707 .577 .707 r
F P
0 g
s
.31754 .65456 m .31769 .71023 L .34181 .70466 L p .707 .577 .707 r
F P
0 g
s
.34181 .70466 m .34166 .64899 L .31754 .65456 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.70048 .74586 m .69803 .78311 L .68564 .77521 L p .707 .577 .707 r
F P
0 g
s
.68564 .77521 m .68809 .73796 L .70048 .74586 L p .707 .577 .707 r
F P
0 g
s
.19772 .65265 m .19787 .70832 L .22527 .71258 L p .707 .577 .707 r
F P
0 g
s
.19787 .70832 m .19772 .65265 L .17674 .64636 L p .707 .577 .707 r
F P
0 g
s
.69766 .65048 m .69799 .70602 L .67701 .69961 L p .707 .577 .707 r
F P
0 g
s
.67701 .69961 m .67668 .64407 L .69766 .65048 L p .707 .577 .707 r
F P
0 g
s
.64927 .63976 m .64961 .69531 L .61846 .69354 L p .707 .577 .707 r
F P
0 g
s
.61846 .69354 m .61812 .63799 L .64927 .63976 L p .707 .577 .707 r
F P
0 g
s
.61395 .30506 m .61395 .80695 L .6357 .79634 L p .707 .577 .707 r
F P
0 g
s
.65112 .74775 m .65947 .76326 L .63499 .76632 L p .707 .577 .707 r
F P
0 g
s
.6357 .79634 m .6357 .29445 L .61395 .30506 L p .707 .577 .707 r
F P
0 g
s
.25091 .77799 m .25196 .74168 L .22083 .73849 L p .707 .577 .707 r
F P
0 g
s
.25196 .74168 m .25091 .77799 L .28275 .77791 L p .707 .577 .707 r
F P
0 g
s
.28275 .77791 m .28379 .7416 L .25196 .74168 L p .707 .577 .707 r
F P
0 g
s
.34166 .64899 m .34181 .70466 L .35826 .69742 L p .707 .577 .707 r
F P
0 g
s
.35826 .69742 m .35812 .64175 L .34166 .64899 L p .707 .577 .707 r
F P
0 g
s
.50766 .8595 m .4993 .844 L .50616 .82719 L p .707 .577 .707 r
F P
0 g
s
.28379 .7416 m .28275 .77791 L .31219 .77457 L p .707 .577 .707 r
F P
0 g
s
.31219 .77457 m .31323 .73827 L .28379 .7416 L p .707 .577 .707 r
F P
0 g
s
.38067 .80496 m .38067 .30307 L .36147 .29212 L p .707 .577 .707 r
F P
0 g
s
.38067 .30307 m .38067 .80496 L .41155 .81379 L p .707 .577 .707 r
F P
0 g
s
.17674 .64636 m .17689 .70203 L .19787 .70832 L p .707 .577 .707 r
F P
0 g
s
.66972 .75062 m .67807 .76612 L .65947 .76326 L p .707 .577 .707 r
F P
0 g
s
.65947 .76326 m .65112 .74775 L .66972 .75062 L p .707 .577 .707 r
F P
0 g
s
.21979 .7748 m .22083 .73849 L .19348 .73235 L p .707 .577 .707 r
F P
0 g
s
.22083 .73849 m .21979 .7748 L .25091 .77799 L p .707 .577 .707 r
F P
0 g
s
.50616 .82719 m .51451 .84269 L .50766 .8595 L p .707 .577 .707 r
F P
0 g
s
.17689 .70203 m .17674 .64636 L .16424 .63866 L p .707 .577 .707 r
F P
0 g
s
.31323 .73827 m .31219 .77457 L .33634 .7683 L p .707 .577 .707 r
F P
0 g
s
.33634 .7683 m .33739 .73199 L .31323 .73827 L p .707 .577 .707 r
F P
0 g
s
.68809 .73796 m .68564 .77521 L .66478 .76806 L p .707 .577 .707 r
F P
0 g
s
.66478 .76806 m .66723 .73082 L .68809 .73796 L p .707 .577 .707 r
F P
0 g
s
.19348 .73235 m .19243 .76865 L .21979 .7748 L p .707 .577 .707 r
F P
0 g
s
.67668 .64407 m .67701 .69961 L .64961 .69531 L p .707 .577 .707 r
F P
0 g
s
.64961 .69531 m .64927 .63976 L .67668 .64407 L p .707 .577 .707 r
F P
0 g
s
.21908 .7574 m .22286 .77597 L .25354 .76877 L p .707 .577 .707 r
F P
0 g
s
.25354 .76877 m .24975 .7502 L .21908 .7574 L p .707 .577 .707 r
F P
0 g
s
.24975 .7502 m .25354 .76877 L .2847 .7632 L p .707 .577 .707 r
F P
0 g
s
.19243 .76865 m .19348 .73235 L .17256 .72385 L p .707 .577 .707 r
F P
0 g
s
.2847 .7632 m .28091 .74463 L .24975 .7502 L p .707 .577 .707 r
F P
0 g
s
.28091 .74463 m .2847 .7632 L .31329 .75981 L p .707 .577 .707 r
F P
0 g
s
.19189 .76554 m .19567 .78411 L .22286 .77597 L p .707 .577 .707 r
F P
0 g
s
.22286 .77597 m .21908 .7574 L .19189 .76554 L p .707 .577 .707 r
F P
0 g
s
.31329 .75981 m .3095 .74124 L .28091 .74463 L p .707 .577 .707 r
F P
0 g
s
.16424 .63866 m .16439 .69433 L .17689 .70203 L p .707 .577 .707 r
F P
0 g
s
.35812 .64175 m .35826 .69742 L .36544 .68922 L p .707 .577 .707 r
F P
0 g
s
.36544 .68922 m .3653 .63354 L .35812 .64175 L p .707 .577 .707 r
F P
0 g
s
.17256 .72385 m .17151 .76015 L .19243 .76865 L p .707 .577 .707 r
F P
0 g
s
.33739 .73199 m .33634 .7683 L .35286 .75971 L p .707 .577 .707 r
F P
0 g
s
.35286 .75971 m .3539 .7234 L .33739 .73199 L p .707 .577 .707 r
F P
0 g
s
.66723 .73082 m .66478 .76806 L .63748 .76237 L p .707 .577 .707 r
F P
0 g
s
.63748 .76237 m .63992 .72512 L .66723 .73082 L p .707 .577 .707 r
F P
0 g
s
.6357 .29445 m .6357 .79634 L .64417 .78445 L p .707 .577 .707 r
F P
0 g
s
.64417 .78445 m .64417 .28256 L .6357 .29445 L p .707 .577 .707 r
F P
0 g
s
.3095 .74124 m .31329 .75981 L .33652 .75894 L p .707 .577 .707 r
F P
0 g
s
.17085 .7738 m .17463 .79237 L .19567 .78411 L p .707 .577 .707 r
F P
0 g
s
.19567 .78411 m .19189 .76554 L .17085 .7738 L p .707 .577 .707 r
F P
0 g
s
.33652 .75894 m .33273 .74037 L .3095 .74124 L p .707 .577 .707 r
F P
0 g
s
.16439 .69433 m .16424 .63866 L .16145 .6303 L p .707 .577 .707 r
F P
0 g
s
.36011 .74964 m .36115 .71333 L .3539 .7234 L p .707 .577 .707 r
F P
0 g
s
.36251 .62518 m .36265 .68086 L .35015 .67315 L p .707 .577 .707 r
F P
0 g
s
.35015 .67315 m .35001 .61748 L .36251 .62518 L p .707 .577 .707 r
F P
0 g
s
.3539 .7234 m .35286 .75971 L .36011 .74964 L p .707 .577 .707 r
F P
0 g
s
.36115 .71333 m .36011 .74964 L .35738 .73907 L p .707 .577 .707 r
F P
0 g
s
.35738 .73907 m .35843 .70277 L .36115 .71333 L p .707 .577 .707 r
F P
0 g
s
.36147 .794 m .36147 .29212 L .35583 .2801 L p .707 .577 .707 r
F P
0 g
s
.3653 .63354 m .36544 .68922 L .36265 .68086 L p .707 .577 .707 r
F P
0 g
s
.36265 .68086 m .36251 .62518 L .3653 .63354 L p .707 .577 .707 r
F P
0 g
s
.36147 .29212 m .36147 .794 L .38067 .80496 L p .707 .577 .707 r
F P
0 g
s
.17151 .76015 m .17256 .72385 L .16013 .71382 L p .707 .577 .707 r
F P
0 g
s
.16145 .6303 m .16159 .68597 L .16439 .69433 L p .707 .577 .707 r
F P
0 g
s
.16013 .71382 m .15908 .75013 L .17151 .76015 L p .707 .577 .707 r
F P
0 g
s
.33273 .74037 m .33652 .75894 L .35211 .76066 L p .707 .577 .707 r
F P
0 g
s
.15801 .7814 m .1618 .79997 L .17463 .79237 L p .707 .577 .707 r
F P
0 g
s
.17463 .79237 m .17085 .7738 L .15801 .7814 L p .707 .577 .707 r
F P
0 g
s
.35211 .76066 m .34832 .74209 L .33273 .74037 L p .707 .577 .707 r
F P
0 g
s
.16159 .68597 m .16145 .6303 L .16863 .6221 L p .707 .577 .707 r
F P
0 g
s
.15908 .75013 m .16013 .71382 L .15741 .70326 L p .707 .577 .707 r
F P
0 g
s
.64417 .28256 m .64417 .78445 L .63853 .77243 L p .707 .577 .707 r
F P
0 g
s
.63853 .77243 m .63853 .27054 L .64417 .28256 L p .707 .577 .707 r
F P
0 g
s
.15741 .70326 m .15636 .73957 L .15908 .75013 L p .707 .577 .707 r
F P
0 g
s
.34832 .74209 m .35211 .76066 L .35853 .76481 L p .707 .577 .707 r
F P
0 g
s
.35853 .76481 m .35475 .74624 L .34832 .74209 L p .707 .577 .707 r
F P
0 g
s
.35475 .74624 m .35853 .76481 L .35517 .77098 L p .707 .577 .707 r
F P
0 g
s
.35843 .70277 m .35738 .73907 L .34496 .72905 L p .707 .577 .707 r
F P
0 g
s
.34496 .72905 m .346 .69275 L .35843 .70277 L p .707 .577 .707 r
F P
0 g
s
.35583 .2801 m .35583 .78199 L .36147 .794 L p .707 .577 .707 r
F P
0 g
s
.35583 .78199 m .35583 .2801 L .3643 .26821 L p .707 .577 .707 r
F P
0 g
s
.16863 .6221 m .16877 .67777 L .16159 .68597 L p .707 .577 .707 r
F P
0 g
s
.15464 .78757 m .15843 .80614 L .1618 .79997 L p .707 .577 .707 r
F P
0 g
s
.1618 .79997 m .15801 .7814 L .15464 .78757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16877 .67777 m .16863 .6221 L .18509 .61486 L p .707 .577 .707 r
F P
0 g
s
.15636 .73957 m .15741 .70326 L .16466 .69319 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16466 .69319 m .16361 .7295 L .15636 .73957 L p .707 .577 .707 r
F P
0 g
s
.18509 .61486 m .18523 .67053 L .16877 .67777 L p .707 .577 .707 r
F P
0 g
s
.35001 .61748 m .35015 .67315 L .32917 .66687 L p .707 .577 .707 r
F P
0 g
s
.32917 .66687 m .32903 .6112 L .35001 .61748 L p .707 .577 .707 r
F P
0 g
s
.63853 .27054 m .63853 .77243 L .61933 .76147 L p .707 .577 .707 r
F P
0 g
s
.61933 .76147 m .61933 .25958 L .63853 .27054 L p .707 .577 .707 r
F P
0 g
s
.16107 .79172 m .16486 .81029 L .15843 .80614 L p .707 .577 .707 r
F P
0 g
s
.15843 .80614 m .15464 .78757 L .16107 .79172 L p .707 .577 .707 r
F P
0 g
s
.35517 .77098 m .35138 .75241 L .35475 .74624 L p .707 .577 .707 r
F P
0 g
s
.18523 .67053 m .18509 .61486 L .2092 .60929 L p .707 .577 .707 r
F P
0 g
s
.3643 .7701 m .3643 .26821 L .38605 .2576 L p .707 .577 .707 r
F P
0 g
s
.3643 .26821 m .3643 .7701 L .35583 .78199 L p .707 .577 .707 r
F P
0 g
s
.16361 .7295 m .16466 .69319 L .18117 .6846 L p .707 .577 .707 r
F P
0 g
s
.32903 .6112 m .32917 .66687 L .30176 .66261 L p .707 .577 .707 r
F P
0 g
s
.30176 .66261 m .30162 .60694 L .32903 .6112 L p .707 .577 .707 r
F P
0 g
s
.2092 .60929 m .20935 .66496 L .18523 .67053 L p .707 .577 .707 r
F P
0 g
s
.18117 .6846 m .18012 .7209 L .16361 .7295 L p .707 .577 .707 r
F P
0 g
s
.346 .69275 m .34496 .72905 L .32404 .72055 L p .707 .577 .707 r
F P
0 g
s
.32404 .72055 m .32509 .68425 L .346 .69275 L p .707 .577 .707 r
F P
0 g
s
.20935 .66496 m .2092 .60929 L .23863 .60594 L p .707 .577 .707 r
F P
0 g
s
.35138 .75241 m .35517 .77098 L .34233 .77858 L p .707 .577 .707 r
F P
0 g
s
.17666 .79344 m .18045 .81201 L .16486 .81029 L p .707 .577 .707 r
F P
0 g
s
.16486 .81029 m .16107 .79172 L .17666 .79344 L p .707 .577 .707 r
F P
0 g
s
.34233 .77858 m .33854 .76001 L .35138 .75241 L p .707 .577 .707 r
F P
0 g
s
.30162 .60694 m .30176 .66261 L .27061 .6608 L p .707 .577 .707 r
F P
0 g
s
.27061 .6608 m .27047 .60513 L .30162 .60694 L p .707 .577 .707 r
F P
0 g
s
.18012 .7209 m .18117 .6846 L .20533 .67833 L p .707 .577 .707 r
F P
0 g
s
.23877 .66161 m .23863 .60594 L .27047 .60513 L p .707 .577 .707 r
F P
0 g
s
.23863 .60594 m .23877 .66161 L .20935 .66496 L p .707 .577 .707 r
F P
0 g
s
.61933 .25958 m .61933 .76147 L .58845 .75264 L p .707 .577 .707 r
F P
0 g
s
.58845 .75264 m .58845 .25075 L .61933 .25958 L p .707 .577 .707 r
F P
0 g
s
.27047 .60513 m .27061 .6608 L .23877 .66161 L p .707 .577 .707 r
F P
0 g
s
.38605 .2576 m .38605 .75949 L .3643 .7701 L p .707 .577 .707 r
F P
0 g
s
.38605 .75949 m .38605 .2576 L .41896 .24931 L p .707 .577 .707 r
F P
0 g
s
.20533 .67833 m .20428 .71463 L .18012 .7209 L p .707 .577 .707 r
F P
0 g
s
.32509 .68425 m .32404 .72055 L .29668 .71441 L p .707 .577 .707 r
F P
0 g
s
.29668 .71441 m .29773 .6781 L .32509 .68425 L p .707 .577 .707 r
F P
0 g
s
.20428 .71463 m .20533 .67833 L .23477 .67499 L p .707 .577 .707 r
F P
0 g
s
.33854 .76001 m .34233 .77858 L .32129 .78684 L p .707 .577 .707 r
F P
0 g
s
.19989 .79257 m .20367 .81114 L .18045 .81201 L p .707 .577 .707 r
F P
0 g
s
.18045 .81201 m .17666 .79344 L .19989 .79257 L p .707 .577 .707 r
F P
0 g
s
.72938 .65573 m .72953 .60024 L .69838 .5982 L p .707 .577 .707 r
F P
0 g
s
.72953 .60024 m .72938 .65573 L .76123 .65504 L p .707 .577 .707 r
F P
0 g
s
.76123 .65504 m .76137 .59955 L .72953 .60024 L p .707 .577 .707 r
F P
0 g
s
.32129 .78684 m .3175 .76827 L .33854 .76001 L p .707 .577 .707 r
F P
0 g
s
.76137 .59955 m .76123 .65504 L .79065 .65169 L p .707 .577 .707 r
F P
0 g
s
.79065 .65169 m .79079 .5962 L .76137 .59955 L p .707 .577 .707 r
F P
0 g
s
.29773 .6781 m .29668 .71441 L .26556 .71122 L p .707 .577 .707 r
F P
0 g
s
.26556 .71122 m .26661 .67491 L .29773 .6781 L p .707 .577 .707 r
F P
0 g
s
.69823 .65369 m .69838 .5982 L .67097 .59363 L p .707 .577 .707 r
F P
0 g
s
.69838 .5982 m .69823 .65369 L .72938 .65573 L p .707 .577 .707 r
F P
0 g
s
.23372 .71129 m .23477 .67499 L .26661 .67491 L p .707 .577 .707 r
F P
0 g
s
.23477 .67499 m .23372 .71129 L .20428 .71463 L p .707 .577 .707 r
F P
0 g
s
.73444 .71266 m .73339 .67504 L .70227 .67437 L p .707 .577 .707 r
F P
0 g
s
.73339 .67504 m .73444 .71266 L .76628 .71125 L p .707 .577 .707 r
F P
0 g
s
.76628 .71125 m .76523 .67363 L .73339 .67504 L p .707 .577 .707 r
F P
0 g
s
.58845 .25075 m .58845 .75264 L .54891 .74681 L p .707 .577 .707 r
F P
0 g
s
.54891 .74681 m .54891 .24492 L .58845 .25075 L p .707 .577 .707 r
F P
0 g
s
.26661 .67491 m .26556 .71122 L .23372 .71129 L p .707 .577 .707 r
F P
0 g
s
.76523 .67363 m .76628 .71125 L .79572 .7079 L p .707 .577 .707 r
F P
0 g
s
.79572 .7079 m .79467 .67028 L .76523 .67363 L p .707 .577 .707 r
F P
0 g
s
.79079 .5962 m .79065 .65169 L .81477 .646 L p .707 .577 .707 r
F P
0 g
s
.81477 .646 m .81491 .59051 L .79079 .5962 L p .707 .577 .707 r
F P
0 g
s
.41896 .7512 m .41896 .24931 L .4598 .24416 L p .707 .577 .707 r
F P
0 g
s
.41896 .24931 m .41896 .7512 L .38605 .75949 L p .707 .577 .707 r
F P
0 g
s
.70332 .712 m .70227 .67437 L .67491 .6717 L p .707 .577 .707 r
F P
0 g
s
.70227 .67437 m .70332 .712 L .73444 .71266 L p .707 .577 .707 r
F P
0 g
s
.3175 .76827 m .32129 .78684 L .2941 .79498 L p .707 .577 .707 r
F P
0 g
s
.22848 .78918 m .23227 .80775 L .20367 .81114 L p .707 .577 .707 r
F P
0 g
s
.20367 .81114 m .19989 .79257 L .22848 .78918 L p .707 .577 .707 r
F P
0 g
s
.67097 .59363 m .67083 .64912 L .69823 .65369 L p .707 .577 .707 r
F P
0 g
s
.67083 .64912 m .67097 .59363 L .64999 .58697 L p .707 .577 .707 r
F P
0 g
s
.2941 .79498 m .29032 .77641 L .3175 .76827 L p .707 .577 .707 r
F P
0 g
s
.79467 .67028 m .79572 .7079 L .81988 .70295 L p .707 .577 .707 r
F P
0 g
s
.81988 .70295 m .81883 .66532 L .79467 .67028 L p .707 .577 .707 r
F P
0 g
s
.67491 .6717 m .67596 .70932 L .70332 .712 L p .707 .577 .707 r
F P
0 g
s
.54891 .24492 m .54891 .74681 L .50458 .74453 L p .707 .577 .707 r
F P
0 g
s
.50458 .74453 m .50458 .24264 L .54891 .24492 L p .707 .577 .707 r
F P
0 g
s
.29032 .77641 m .2941 .79498 L .26343 .80218 L p .707 .577 .707 r
F P
0 g
s
.67596 .70932 m .67491 .6717 L .65399 .66727 L p .707 .577 .707 r
F P
0 g
s
.81491 .59051 m .81477 .646 L .83123 .63853 L p .707 .577 .707 r
F P
0 g
s
.83123 .63853 m .83137 .58304 L .81491 .59051 L p .707 .577 .707 r
F P
0 g
s
.4598 .74605 m .4598 .24416 L .50458 .24264 L p .707 .577 .707 r
F P
0 g
s
.4598 .24416 m .4598 .74605 L .41896 .7512 L p .707 .577 .707 r
F P
0 g
s
.25964 .78361 m .26343 .80218 L .23227 .80775 L p .707 .577 .707 r
F P
0 g
s
.23227 .80775 m .22848 .78918 L .25964 .78361 L p .707 .577 .707 r
F P
0 g
s
.26343 .80218 m .25964 .78361 L .29032 .77641 L p .707 .577 .707 r
F P
0 g
s
.64999 .58697 m .64985 .64246 L .67083 .64912 L p .707 .577 .707 r
F P
0 g
s
.73657 .79856 m .74036 .78435 L .70968 .7754 L p .707 .577 .707 r
F P
0 g
s
.74036 .78435 m .73657 .79856 L .76773 .80101 L p .707 .577 .707 r
F P
0 g
s
.76773 .80101 m .77152 .7868 L .74036 .78435 L p .707 .577 .707 r
F P
0 g
s
.50458 .24264 m .50458 .74453 L .4598 .74605 L p .707 .577 .707 r
F P
0 g
s
.70589 .7896 m .70968 .7754 L .68249 .76083 L p .707 .577 .707 r
F P
0 g
s
.70968 .7754 m .70589 .7896 L .73657 .79856 L p .707 .577 .707 r
F P
0 g
s
.65399 .66727 m .65504 .7049 L .67596 .70932 L p .707 .577 .707 r
F P
0 g
s
.64985 .64246 m .64999 .58697 L .63749 .57888 L p .707 .577 .707 r
F P
0 g
s
.81883 .66532 m .81988 .70295 L .83639 .69686 L p .707 .577 .707 r
F P
0 g
s
.83639 .69686 m .83534 .65924 L .81883 .66532 L p .707 .577 .707 r
F P
0 g
s
.77152 .7868 m .76773 .80101 L .79632 .79673 L p .707 .577 .707 r
F P
0 g
s
.79632 .79673 m .80011 .78253 L .77152 .7868 L p .707 .577 .707 r
F P
0 g
s
.67871 .77503 m .68249 .76083 L .66145 .74207 L p .707 .577 .707 r
F P
0 g
s
.68249 .76083 m .67871 .77503 L .70589 .7896 L p .707 .577 .707 r
F P
0 g
s
.65504 .7049 m .65399 .66727 L .64157 .66153 L p .707 .577 .707 r
F P
0 g
s
.80011 .78253 m .79632 .79673 L .81955 .78614 L p .707 .577 .707 r
F P
0 g
s
.81955 .78614 m .82334 .77193 L .80011 .78253 L p .707 .577 .707 r
F P
0 g
s
.83137 .58304 m .83123 .63853 L .83841 .63002 L p .707 .577 .707 r
F P
0 g
s
.83841 .63002 m .83855 .57453 L .83137 .58304 L p .707 .577 .707 r
F P
0 g
s
.63749 .57888 m .63735 .63437 L .64985 .64246 L p .707 .577 .707 r
F P
0 g
s
.66145 .74207 m .65767 .75627 L .67871 .77503 L p .707 .577 .707 r
F P
0 g
s
.65767 .75627 m .66145 .74207 L .64862 .72095 L p .707 .577 .707 r
F P
0 g
s
.64483 .73516 m .64862 .72095 L .64836 .71931 L p .707 .577 .707 r
F P
0 g
s
.64157 .66153 m .64261 .69916 L .65289 .70391 L p .707 .577 .707 r
F P
0 g
s
.64836 .71931 m .64525 .69954 L p .64488 .73116 L .707 .577 .707 r
F P
0 g
s
.64483 .73516 m .64836 .71931 L .64488 .73116 L .707 .577 .707 r
F
.65289 .70391 m .65504 .7049 L p .65379 .70086 L F P
0 g
s
.65379 .70086 m .64157 .66153 L .65289 .70391 L .707 .577 .707 r
F
.83534 .65924 m .83639 .69686 L .84364 .69025 L p F P
0 g
s
.84364 .69025 m .84259 .65263 L .83534 .65924 L p .707 .577 .707 r
F P
0 g
s
.63735 .63437 m .63749 .57888 L .6347 .57015 L p .707 .577 .707 r
F P
0 g
s
.64862 .72095 m .64483 .73516 L .65767 .75627 L p .707 .577 .707 r
F P
0 g
s
.82334 .77193 m .81955 .78614 L .83514 .77026 L p .707 .577 .707 r
F P
0 g
s
.83514 .77026 m .83893 .75606 L .82334 .77193 L p .707 .577 .707 r
F P
0 g
s
.64261 .69916 m .64157 .66153 L .63884 .65504 L p .707 .577 .707 r
F P
0 g
s
.6347 .57015 m .63455 .62565 L .63735 .63437 L p .707 .577 .707 r
F P
0 g
s
.83855 .57453 m .83841 .63002 L .83561 .62129 L p .707 .577 .707 r
F P
0 g
s
.83561 .62129 m .83575 .5658 L .83855 .57453 L p .707 .577 .707 r
F P
0 g
s
.63884 .65504 m .63989 .69267 L .64261 .69916 L p .707 .577 .707 r
F P
0 g
s
.64525 .69954 m .64146 .71375 L .64483 .73516 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83893 .75606 m .83514 .77026 L .84157 .75066 L p .707 .577 .707 r
F P
0 g
s
.84157 .75066 m .84535 .73646 L .83893 .75606 L p .707 .577 .707 r
F P
0 g
s
.84259 .65263 m .84364 .69025 L .84092 .68376 L p .707 .577 .707 r
F P
0 g
s
.84092 .68376 m .83987 .64614 L .84259 .65263 L p .707 .577 .707 r
F P
0 g
s
.63455 .62565 m .6347 .57015 L .64188 .56164 L p .707 .577 .707 r
F P
0 g
s
.64146 .71375 m .64525 .69954 L .65168 .67994 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63989 .69267 m .63884 .65504 L .64609 .64843 L p .707 .577 .707 r
F P
0 g
s
.64188 .56164 m .64174 .61713 L .63455 .62565 L p .707 .577 .707 r
F P
0 g
s
.38154 .62133 m .38187 .56571 L .35072 .56362 L p .707 .577 .707 r
F P
0 g
s
.38187 .56571 m .38154 .62133 L .41338 .62076 L p .707 .577 .707 r
F P
0 g
s
.41338 .62076 m .41372 .56514 L .38187 .56571 L p .707 .577 .707 r
F P
0 g
s
.65168 .67994 m .64789 .69415 L .64146 .71375 L p .707 .577 .707 r
F P
0 g
s
.83575 .5658 m .83561 .62129 L .82311 .6132 L p .707 .577 .707 r
F P
0 g
s
.82311 .6132 m .82326 .55771 L .83575 .5658 L p .707 .577 .707 r
F P
0 g
s
.41372 .56514 m .41338 .62076 L .44281 .6176 L p .707 .577 .707 r
F P
0 g
s
.44281 .6176 m .44314 .56198 L .41372 .56514 L p .707 .577 .707 r
F P
0 g
s
.64609 .64843 m .64714 .68606 L .63989 .69267 L p .707 .577 .707 r
F P
0 g
s
.84535 .73646 m .84157 .75066 L .8382 .72926 L p .707 .577 .707 r
F P
0 g
s
.8382 .72926 m .84198 .71505 L .84535 .73646 L p .707 .577 .707 r
F P
0 g
s
.35039 .61924 m .35072 .56362 L .32332 .55909 L p .707 .577 .707 r
F P
0 g
s
.35072 .56362 m .35039 .61924 L .38154 .62133 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64789 .69415 m .65168 .67994 L .66727 .66407 L p .707 .577 .707 r
F P
0 g
s
.83987 .64614 m .84092 .68376 L .82849 .67802 L p .707 .577 .707 r
F P
0 g
s
.82849 .67802 m .82744 .6404 L .83987 .64614 L p .707 .577 .707 r
F P
0 g
s
.64174 .61713 m .64188 .56164 L .65833 .55417 L p .707 .577 .707 r
F P
0 g
s
.44314 .56198 m .44281 .6176 L .46693 .61215 L p .707 .577 .707 r
F P
0 g
s
.46693 .61215 m .46726 .55654 L .44314 .56198 L p .707 .577 .707 r
F P
0 g
s
.32332 .55909 m .32299 .61471 L .35039 .61924 L p .707 .577 .707 r
F P
0 g
s
.32299 .61471 m .32332 .55909 L .30234 .55256 L p .707 .577 .707 r
F P
0 g
s
.66727 .66407 m .66348 .67828 L .64789 .69415 L p .707 .577 .707 r
F P
0 g
s
.39359 .6836 m .39114 .64691 L .36007 .64667 L p .707 .577 .707 r
F P
0 g
s
.39114 .64691 m .39359 .6836 L .42537 .68087 L p .707 .577 .707 r
F P
0 g
s
.42537 .68087 m .42293 .64418 L .39114 .64691 L p .707 .577 .707 r
F P
0 g
s
.64714 .68606 m .64609 .64843 L .66261 .64235 L p .707 .577 .707 r
F P
0 g
s
.42293 .64418 m .42537 .68087 L .45477 .67542 L p .707 .577 .707 r
F P
0 g
s
.45477 .67542 m .45233 .63874 L .42293 .64418 L p .707 .577 .707 r
F P
0 g
s
.82326 .55771 m .82311 .6132 L .80213 .60654 L p .707 .577 .707 r
F P
0 g
s
.80213 .60654 m .80228 .55105 L .82326 .55771 L p .707 .577 .707 r
F P
0 g
s
.65833 .55417 m .65819 .60966 L .64174 .61713 L p .707 .577 .707 r
F P
0 g
s
.84198 .71505 m .8382 .72926 L .82536 .70814 L p .707 .577 .707 r
F P
0 g
s
.82536 .70814 m .82915 .69393 L .84198 .71505 L p .707 .577 .707 r
F P
0 g
s
.36252 .68335 m .36007 .64667 L .33277 .64346 L p .707 .577 .707 r
F P
0 g
s
.36007 .64667 m .36252 .68335 L .39359 .6836 L p .707 .577 .707 r
F P
0 g
s
.46726 .55654 m .46693 .61215 L .48338 .60496 L p .707 .577 .707 r
F P
0 g
s
.48338 .60496 m .48371 .54934 L .46726 .55654 L p .707 .577 .707 r
F P
0 g
s
.66348 .67828 m .66727 .66407 L .69049 .65347 L p .707 .577 .707 r
F P
0 g
s
.69049 .65347 m .68671 .66768 L .66348 .67828 L p .707 .577 .707 r
F P
0 g
s
.66261 .64235 m .66365 .67998 L .64714 .68606 L p .707 .577 .707 r
F P
0 g
s
.30234 .55256 m .30201 .60818 L .32299 .61471 L p .707 .577 .707 r
F P
0 g
s
.45233 .63874 m .45477 .67542 L .47891 .6678 L p .707 .577 .707 r
F P
0 g
s
.47891 .6678 m .47646 .63111 L .45233 .63874 L p .707 .577 .707 r
F P
0 g
s
.65819 .60966 m .65833 .55417 L .68245 .54848 L p .707 .577 .707 r
F P
0 g
s
.82744 .6404 m .82849 .67802 L .80757 .6736 L p .707 .577 .707 r
F P
0 g
s
.80757 .6736 m .80652 .63597 L .82744 .6404 L p .707 .577 .707 r
F P
0 g
s
.39297 .69852 m .40133 .68125 L .37336 .6672 L p .707 .577 .707 r
F P
0 g
s
.40133 .68125 m .39297 .69852 L .42169 .71213 L p .707 .577 .707 r
F P
0 g
s
.42169 .71213 m .43004 .69486 L .40133 .68125 L p .707 .577 .707 r
F P
0 g
s
.37336 .6672 m .36501 .68446 L .39297 .69852 L p .707 .577 .707 r
F P
0 g
s
.33277 .64346 m .33522 .68015 L .36252 .68335 L p .707 .577 .707 r
F P
0 g
s
.30201 .60818 m .30234 .55256 L .28984 .54467 L p .707 .577 .707 r
F P
0 g
s
.43004 .69486 m .42169 .71213 L .44834 .72396 L p .707 .577 .707 r
F P
0 g
s
.44834 .72396 m .4567 .7067 L .43004 .69486 L p .707 .577 .707 r
F P
0 g
s
.36501 .68446 m .37336 .6672 L .34888 .65407 L p .707 .577 .707 r
F P
0 g
s
.82915 .69393 m .82536 .70814 L .80432 .68938 L p .707 .577 .707 r
F P
0 g
s
.80432 .68938 m .80811 .67517 L .82915 .69393 L p .707 .577 .707 r
F P
0 g
s
.33522 .68015 m .33277 .64346 L .31191 .63762 L p .707 .577 .707 r
F P
0 g
s
.34888 .65407 m .34053 .67134 L .36501 .68446 L p .707 .577 .707 r
F P
0 g
s
.80228 .55105 m .80213 .60654 L .77473 .60197 L p .707 .577 .707 r
F P
0 g
s
.77473 .60197 m .77487 .54648 L .80228 .55105 L p .707 .577 .707 r
F P
0 g
s
.68671 .66768 m .69049 .65347 L .71909 .6492 L p .707 .577 .707 r
F P
0 g
s
.66365 .67998 m .66261 .64235 L .68676 .63739 L p .707 .577 .707 r
F P
0 g
s
.68245 .54848 m .68231 .60397 L .65819 .60966 L p .707 .577 .707 r
F P
0 g
s
.47646 .63111 m .47891 .6678 L .49541 .65874 L p .707 .577 .707 r
F P
0 g
s
.49541 .65874 m .49296 .62205 L .47646 .63111 L p .707 .577 .707 r
F P
0 g
s
.4567 .7067 m .44834 .72396 L .47033 .73286 L p .707 .577 .707 r
F P
0 g
s
.47033 .73286 m .47868 .71559 L .4567 .7067 L p .707 .577 .707 r
F P
0 g
s
.68231 .60397 m .68245 .54848 L .71188 .54513 L p .707 .577 .707 r
F P
0 g
s
.28984 .54467 m .28951 .60029 L .30201 .60818 L p .707 .577 .707 r
F P
0 g
s
.48371 .54934 m .48338 .60496 L .49056 .59671 L p .707 .577 .707 r
F P
0 g
s
.49056 .59671 m .4909 .54109 L .48371 .54934 L p .707 .577 .707 r
F P
0 g
s
.31191 .63762 m .31435 .67431 L .33522 .68015 L p .707 .577 .707 r
F P
0 g
s
.71909 .6492 m .7153 .6634 L .68671 .66768 L p .707 .577 .707 r
F P
0 g
s
.68676 .63739 m .68781 .67502 L .66365 .67998 L p .707 .577 .707 r
F P
0 g
s
.80811 .67517 m .80432 .68938 L .77714 .67481 L p .707 .577 .707 r
F P
0 g
s
.77714 .67481 m .78092 .6606 L .80811 .67517 L p .707 .577 .707 r
F P
0 g
s
.34053 .67134 m .34888 .65407 L .33028 .64316 L p .707 .577 .707 r
F P
0 g
s
.80652 .63597 m .80757 .6736 L .78021 .67092 L p .707 .577 .707 r
F P
0 g
s
.78092 .6606 m .77714 .67481 L .74646 .66586 L p .707 .577 .707 r
F P
0 g
s
.74646 .66586 m .75025 .65165 L .78092 .6606 L p .707 .577 .707 r
F P
0 g
s
.78021 .67092 m .77917 .6333 L .80652 .63597 L p .707 .577 .707 r
F P
0 g
s
.33028 .64316 m .32193 .66043 L .34053 .67134 L p .707 .577 .707 r
F P
0 g
s
.7153 .6634 m .71909 .6492 L .75025 .65165 L p .707 .577 .707 r
F P
0 g
s
.77487 .54648 m .77473 .60197 L .74358 .59993 L p .707 .577 .707 r
F P
0 g
s
.74358 .59993 m .74372 .54444 L .77487 .54648 L p .707 .577 .707 r
F P
0 g
s
.71173 .60062 m .71188 .54513 L .74372 .54444 L p .707 .577 .707 r
F P
0 g
s
.71188 .54513 m .71173 .60062 L .68231 .60397 L p .707 .577 .707 r
F P
0 g
s
.28951 .60029 m .28984 .54467 L .28705 .53618 L p .707 .577 .707 r
F P
0 g
s
.31435 .67431 m .31191 .63762 L .29952 .6297 L p .707 .577 .707 r
F P
0 g
s
.75025 .65165 m .74646 .66586 L .7153 .6634 L p .707 .577 .707 r
F P
0 g
s
.68781 .67502 m .68676 .63739 L .7162 .63404 L p .707 .577 .707 r
F P
0 g
s
.74372 .54444 m .74358 .59993 L .71173 .60062 L p .707 .577 .707 r
F P
0 g
s
.47868 .71559 m .47033 .73286 L .48549 .73795 L p .707 .577 .707 r
F P
0 g
s
.48549 .73795 m .49384 .72068 L .47868 .71559 L p .707 .577 .707 r
F P
0 g
s
.77917 .6333 m .78021 .67092 L .74909 .67026 L p .707 .577 .707 r
F P
0 g
s
.74909 .67026 m .74804 .63263 L .77917 .6333 L p .707 .577 .707 r
F P
0 g
s
.7162 .63404 m .71725 .67167 L .68781 .67502 L p .707 .577 .707 r
F P
0 g
s
.29952 .6297 m .30197 .66639 L .31435 .67431 L p .707 .577 .707 r
F P
0 g
s
.49296 .62205 m .49541 .65874 L .50267 .64914 L p .707 .577 .707 r
F P
0 g
s
.50267 .64914 m .50022 .61245 L .49296 .62205 L p .707 .577 .707 r
F P
0 g
s
.71725 .67167 m .7162 .63404 L .74804 .63263 L p .707 .577 .707 r
F P
0 g
s
.32193 .66043 m .33028 .64316 L .31939 .63553 L p .707 .577 .707 r
F P
0 g
s
.28705 .53618 m .28671 .5918 L .28951 .60029 L p .707 .577 .707 r
F P
0 g
s
.74804 .63263 m .74909 .67026 L .71725 .67167 L p .707 .577 .707 r
F P
0 g
s
.31939 .63553 m .31103 .6528 L .32193 .66043 L p .707 .577 .707 r
F P
0 g
s
.4909 .54109 m .49056 .59671 L .48777 .58823 L p .707 .577 .707 r
F P
0 g
s
.48777 .58823 m .4881 .53261 L .4909 .54109 L p .707 .577 .707 r
F P
0 g
s
.30197 .66639 m .29952 .6297 L .29682 .62049 L p .707 .577 .707 r
F P
0 g
s
.28671 .5918 m .28705 .53618 L .29423 .52794 L p .707 .577 .707 r
F P
0 g
s
.49384 .72068 m .48549 .73795 L .49234 .73873 L p .707 .577 .707 r
F P
0 g
s
.49234 .73873 m .50069 .72147 L .49384 .72068 L p .707 .577 .707 r
F P
0 g
s
.29682 .62049 m .29927 .65718 L .30197 .66639 L p .707 .577 .707 r
F P
0 g
s
.50022 .61245 m .50267 .64914 L .49997 .63993 L p .707 .577 .707 r
F P
0 g
s
.49997 .63993 m .49752 .60324 L .50022 .61245 L p .707 .577 .707 r
F P
0 g
s
.31103 .6528 m .31939 .63553 L .31726 .63193 L p .707 .577 .707 r
F P
0 g
s
.31726 .63193 m .30891 .6492 L .31103 .6528 L p .707 .577 .707 r
F P
0 g
s
.29423 .52794 m .29389 .58356 L .28671 .5918 L p .707 .577 .707 r
F P
0 g
s
.4881 .53261 m .48777 .58823 L .47527 .58033 L p .707 .577 .707 r
F P
0 g
s
.47527 .58033 m .4756 .52471 L .4881 .53261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29927 .65718 m .29682 .62049 L .30408 .61089 L p .707 .577 .707 r
F P
0 g
s
.29389 .58356 m .29423 .52794 L .31068 .52074 L p .707 .577 .707 r
F P
0 g
s
.50069 .72147 m .49234 .73873 L .49022 .73513 L p .707 .577 .707 r
F P
0 g
s
.49022 .73513 m .49857 .71787 L .50069 .72147 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30408 .61089 m .30653 .64758 L .29927 .65718 L p .707 .577 .707 r
F P
0 g
s
.49752 .60324 m .49997 .63993 L .48758 .63201 L p .707 .577 .707 r
F P
0 g
s
.48758 .63201 m .48514 .59533 L .49752 .60324 L p .707 .577 .707 r
F P
0 g
s
.31068 .52074 m .31035 .57636 L .29389 .58356 L p .707 .577 .707 r
F P
0 g
s
.30891 .6492 m .31726 .63193 L .32412 .63272 L p .707 .577 .707 r
F P
0 g
s
.4756 .52471 m .47527 .58033 L .45429 .5738 L p .707 .577 .707 r
F P
0 g
s
.45429 .5738 m .45462 .51818 L .4756 .52471 L p .707 .577 .707 r
F P
0 g
s
.32412 .63272 m .31576 .64999 L .30891 .6492 L p .707 .577 .707 r
F P
0 g
s
.31035 .57636 m .31068 .52074 L .3348 .5153 L p .707 .577 .707 r
F P
0 g
s
.30653 .64758 m .30408 .61089 L .32058 .60183 L p .707 .577 .707 r
F P
0 g
s
.49857 .71787 m .49022 .73513 L .47932 .72751 L p .707 .577 .707 r
F P
0 g
s
.47932 .72751 m .48768 .71024 L .49857 .71787 L p .707 .577 .707 r
F P
0 g
s
.45462 .51818 m .45429 .5738 L .42688 .56927 L p .707 .577 .707 r
F P
0 g
s
.42688 .56927 m .42722 .51365 L .45462 .51818 L p .707 .577 .707 r
F P
0 g
s
.31576 .64999 m .32412 .63272 L .33928 .63781 L p .707 .577 .707 r
F P
0 g
s
.32058 .60183 m .32303 .63852 L .30653 .64758 L p .707 .577 .707 r
F P
0 g
s
.48514 .59533 m .48758 .63201 L .46672 .62617 L p .707 .577 .707 r
F P
0 g
s
.46672 .62617 m .46427 .58948 L .48514 .59533 L p .707 .577 .707 r
F P
0 g
s
.3348 .5153 m .33447 .57092 L .31035 .57636 L p .707 .577 .707 r
F P
0 g
s
.33447 .57092 m .3348 .5153 L .36422 .51214 L p .707 .577 .707 r
F P
0 g
s
.33928 .63781 m .33092 .65508 L .31576 .64999 L p .707 .577 .707 r
F P
0 g
s
.32303 .63852 m .32058 .60183 L .34472 .59421 L p .707 .577 .707 r
F P
0 g
s
.42722 .51365 m .42688 .56927 L .39573 .56719 L p .707 .577 .707 r
F P
0 g
s
.39573 .56719 m .39607 .51157 L .42722 .51365 L p .707 .577 .707 r
F P
0 g
s
.36389 .56776 m .36422 .51214 L .39607 .51157 L p .707 .577 .707 r
F P
0 g
s
.36422 .51214 m .36389 .56776 L .33447 .57092 L p .707 .577 .707 r
F P
0 g
s
.39607 .51157 m .39573 .56719 L .36389 .56776 L p .707 .577 .707 r
F P
0 g
s
.46427 .58948 m .46672 .62617 L .43942 .62297 L p .707 .577 .707 r
F P
0 g
s
.43942 .62297 m .43697 .58628 L .46427 .58948 L p .707 .577 .707 r
F P
0 g
s
.34472 .59421 m .34716 .6309 L .32303 .63852 L p .707 .577 .707 r
F P
0 g
s
.48768 .71024 m .47932 .72751 L .46073 .7166 L p .707 .577 .707 r
F P
0 g
s
.46073 .7166 m .46908 .69933 L .48768 .71024 L p .707 .577 .707 r
F P
0 g
s
.34716 .6309 m .34472 .59421 L .37411 .58876 L p .707 .577 .707 r
F P
0 g
s
.33092 .65508 m .33928 .63781 L .36126 .6467 L p .707 .577 .707 r
F P
0 g
s
.36126 .6467 m .35291 .66397 L .33092 .65508 L p .707 .577 .707 r
F P
0 g
s
.43697 .58628 m .43942 .62297 L .40835 .62272 L p .707 .577 .707 r
F P
0 g
s
.40835 .62272 m .4059 .58603 L .43697 .58628 L p .707 .577 .707 r
F P
0 g
s
.37411 .58876 m .37656 .62545 L .34716 .6309 L p .707 .577 .707 r
F P
0 g
s
.37656 .62545 m .37411 .58876 L .4059 .58603 L p .707 .577 .707 r
F P
0 g
s
.4059 .58603 m .40835 .62272 L .37656 .62545 L p .707 .577 .707 r
F P
0 g
s
.46908 .69933 m .46073 .7166 L .43625 .70347 L p .707 .577 .707 r
F P
0 g
s
.43625 .70347 m .4446 .6862 L .46908 .69933 L p .707 .577 .707 r
F P
0 g
s
.35291 .66397 m .36126 .6467 L .38792 .65854 L p .707 .577 .707 r
F P
0 g
s
.38792 .65854 m .37956 .6758 L .35291 .66397 L p .707 .577 .707 r
F P
0 g
s
.4446 .6862 m .43625 .70347 L .40828 .68941 L p .707 .577 .707 r
F P
0 g
s
.40828 .68941 m .41663 .67215 L .4446 .6862 L p .707 .577 .707 r
F P
0 g
s
.37956 .6758 m .38792 .65854 L .41663 .67215 L p .707 .577 .707 r
F P
0 g
s
.41663 .67215 m .40828 .68941 L .37956 .6758 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8P00OWoo001fOol70005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD007=o
o`00Kgoo100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01000Kgoo001]Ool20008FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00@005YF000006Uoo`00Igoo0P0015YF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00
06Qoo`00IWoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol20005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001J
EUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Aooa40009JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00GWoo1P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001JOol400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUIJEUYF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001GOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000MJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001BOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001A
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001AOol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol0055oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0001Moo`T004Eoo`00DGoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000027oo3`00
15YF00<005YFFUH00UYF2000?Goo001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
0005Ool300000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00=goo
001AOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002Ool30004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH00000=Goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<goo001AOol00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000aOol0055oo`03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008002moo`00DGoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<005YFFUH00eYF00<005YFFUH0
0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00D005YFFUIJEP0002moo`00DGoo00<005YF000015YF00@005YFFUIJEPP000QJ
EP03001JEUYF00IJEP03001JEUYF00=JEP@0009JEP03001JEUYF00=JEP03001JEUYF008000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP8002ioo`00DGoo00<005YF00000eYF1@001eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YF00000`0015YF00<005YFFUH00P000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0P00;Woo001AOol01000FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0000AJEP00FUIJEP8000=JEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00DGoo00<005YF00000P001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000009JEP8000=JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002ioo`00DGoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH04@0015YF00@005YFFUIJEP@000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00DGoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH02@0015YF00<005YF
FUH01UYF00@005YFFUIJEPD000AJEP<000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00DGoo0P00
0UYF00<005YFFUH00eYF00<005YFFUH00eYF1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000P0000AJEP00000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
DGoo0P000UYF00<005YFFUH00eYF00@005YFFUIJEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02ioo`00DWoo00@005YFFUH000EJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009J
EQ8000AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool005=oo`<000AJEP<0
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYF
FUH005YF000015YF00<005YFFUH00UYF1`0025YF1P000eYF20000eYF00<005YFFUH00eYF00@005YF
FUIJEP8002ioo`00@7oo5`0000EJEP00001JEP0000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP07001JEUYFFUH005YF000035YF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUH000020006FUH00`00FUIJ
EP06FUH60003FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;Woo000hOol80003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0`0035YF00<005YF
FUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH300000eYF001JEP06FUH00`00FUIJ
EP06FUH00`00FUH000020004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2
000^Ool003=oo`D000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH02000FUIJEUYF
001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH30003FUH2000^Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH005YF0`001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P0000=JEP000000
;Woo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00;Woo000^Ool20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP04FUHG0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P0035YF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF
009JEP<002ioo`00;Woo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0100015YF00<005YF00000P00
1EYF00<005YFFUH01UYF1`000eYF00@005YFFUIJEP8000aJEP03001JEUYF00QJEP03001JEUYF00IJ
EP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000^Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP04
001JEUYF0003FUH00`00FUIJEP03FUH500000eYF001JEP04FUH60004FUH00`00FUIJEP08FUH01000
FUIJEUYF1@000eYF0P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEPX000MJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0002ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEP0000<0009JEP05001JEP00FUH00005
FUH60004FUH00`00FUIJEP08FUH400000eYF001JEP02FUH200000eYF0000000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP001EYF00<005YFFUH01EYF00<005YF0000
1`0015YF00<005YFFUH00UYF3`0015YF0P00;goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP000eYF0P000UYF0`0000IJ
EP00FUH005YF0005FUH60004FUH00`00FUIJEP05FUH30005FUH00`00FUIJEP02FUH4000<FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40005FUH00`00FUH000070003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000200000eYF0000000`Ool002eoo`03
001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00009JEP03001JEUYF00=JEP03001JEP0000<00003FUH005YF00AJEP03001JEP00008000EJ
EP04001JEUYFFUH400000eYF001JEP05FUH00`00FUIJEP02FUH01000FUH0000035YF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P0000=JEP0000000`000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0`00<7oo
000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH000030004FUH00`00FUIJEP03FUHF0005FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YF000002ioo`00;Goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH015YF
0`001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
000000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH2000015YF001JEUYF0P0000=JEP00FUH01EYF00@005YF
FUIJEP8000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYFFUH20000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUIJEP02000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@00004FUH000000005FUH00`00FUIJEP03
FUH20002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YFFUH00P00;Goo000]Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH90004FUH01`00FUIJEUYF001JEP0000AJEP<00003FUH005YF00MJEP<0
00QJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPT000QJEPD0
00=JEP03001JEUYF008000=JEP04001JEP000008FUH01000FUH000001eYF00<005YFFUH01UYF00<0
05YFFUH015YF00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo00<005YF
000015YF00@005YFFUIJEPT000MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP02
FUH200000eYF001JEP02FUH20006FUH01000FUIJEUYF0P001EYF00<005YFFUH01UYF00<005YFFUH0
0eYF0`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002eoo`00;Goo00<005YF00000eYF1P001eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH015YF0P001UYF0P00
0eYF00<005YFFUH015YF0P000eYF00<005YFFUH01UYF00@005YFFUIJEP8000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF009JEQ4000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0
02eoo`04001JEP00FUH20005FUH00`00FUIJEP04FUHA00000eYF001JEP05FUH30004FUH01000FUH0
00001UYF0P0000=JEP00FUH01eYF0P0000=JEP00FUH01eYF00@005YF000000YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=J
EQ/000AJEPL000=JEP05001JEUYFFUH0000]Ool002eoo`06001JEP00001JEP001EYF1`000eYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P0015YF100000=JEP00FUH00UYF0P000eYF00<005YFFUH00P00
2EYF0`0015YF1P0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF000015YF00<005YF00000`001EYF00<005YFFUH01UYF1@0015YF00@005YFFUIJEP80
00IJEP03001JEUYF00@000=JEP03001oogoo02]oo`00;Goo0P000eYF00<005YFFUH0100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF1@000UYF0P0000=JEP00
FUH00eYF0P001UYF00@005YFFUIJEP@000EJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001J
EUYF00IJEP@000EJEP03001JEUYF00=JEP03001JEUYF00=JEP800003FUH005YF009JEP800003FUH0
07oo02aoo`00;Goo0P000eYF0`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF0`0015YF00<005YF000010001UYF0`0015YF00<005YFFUH00eYF0P001EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@0
05YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP80009JEP03001JEUYF008000AJEP<002eoo`00;Goo0P000UYF0`001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00H005YFFUIJEP00FUH30004FUH5
00000eYF001JEP07FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP@000=JEP8000=JEP03001JEP0002eoo`00;Goo10000UYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00`000eYF00<005YF00000UYF0P000UYF1`002EYF00<005YF00000P0035YF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00000000AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000EJEP06
001JEUYF001JEP00;Goo000^Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUH00004
FUH2000015YF000000000eYF0P001UYF00<005YFFUH00UYF0P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100000=JEP00FUH015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUH000EJEP04001JEP00000^Ool0
02eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP@00003FUH005YF00AJEP<000MJEP8000AJEP03001JEUYF00AJ
EP8000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@00003
FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05
001JEUYFFUH00004FUH3000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001J
EP001EYF00<005YFFUH00P001eYF0P0000=JEP00FUH01UYF00@005YF000000MJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP06001JEP00001JEP001EYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJ
EP00FUH0031oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF0005FUH00`00
FUIJEP02FUH20004FUH00`00FUIJEP020007FUH01000FUIJEUYF0P001EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000000P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=oo`000000
0UYF00<007ooOol0;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000EJ
EP03001JEUYF00AJEP80009JEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000EJEPL000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000Ioo`05001JEUYFFUH0000^Ool0
02aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP06001JEUYF001JEP001EYF00<005YFFUH01UYF0`001UYF0P000UYF00<005YFFUH0
15YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00eYF00<005YFFUH00eYF6`003Goo00@005YFFUH002ioo`00;7oo00<005YF000015YF
00<005YFFUH00eYF1P001Goo2@000goo200015YF00<005YFFUH00eYF00H005YFFUH005YF0005FUH0
0`00FUIJEP07FUH01000FUH000001EYF0`001UYF00@005YFFUH0009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04
001JEUYFFUH30006Ool3000GOol01@00FUIJEUYF0000;Goo000/Ool00`00FUH00004FUH00`00FUH0
0003000OOol50005FUH01P00FUIJEP00FUH000EJEP03001JEUYF00MJEP04001JEUYFFUH300000eYF
001JEP02FUH20004FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001JEUYFFUH30005Ool5000GOol0
1000FUIJEP00;Goo000/Ool00`00FUH00003FUH3000COol3000BOol20003FUH01P00FUIJEP00FUH0
00EJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP800003FUH005YF00=JEP<000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF00AJEP07
001JEUYFFUH005YF00001Goo1@0067oo0`00;Goo000/Ool01000FUH005YF10004goo1@004goo0P00
00MJEP00FUIJEP00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20004FUH30003FUH01000
FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P000eYF
00<005YFFUH015YF00@005YFFUIJEP8000Ioo`D001Qoo`<002eoo`00;7oo00H005YF000005YF0002
FUH2000AOol5000DOol30002FUH00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH20002
FUH01000FUIJEP000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF001JEPH000EJEP05001JEUYFFUH00008Ool3000JOol00`00FUH0000/Ool002ao
o`8000=JEP03001JEUYF009JEPD000aoo`D0015oo`<000=JEP05001JEP00FUH00005FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUH000030002FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH01@00FUIJEP00FUH00`000UYF00@0
05YFFUH002Ioo`03001JEP0002aoo`00;7oo0P000eYF00<005YFFUH00eYF00@005YFFUIJEPP000Eo
o`<000Yoo`P0009JEP03001JEUYF009JEP800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00=JEPD0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEP0000AJEPD002Moo`03001JEP0002aoo`00;7oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF7P000eYF0P0000=JEP00FUH015YF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001JEP0000EJEP8002Uoo`03
001JEP0002aoo`00;7oo0P000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH015YF1P000eYF00<005YFFUH015YF00<005YFFUH01@0000=JEP00FUH015YF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH015YF3@001UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YF000000=JEP8000EJEP04001JEP00000XOol00`00Oomoo`0[Ool002eoo`04
001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP07FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH300000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH<0003FUH00`00FUIJEP07FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUH00000
0UYF00<005YF00001EYF00D005YFFUIJEP0002Moo`03001oogoo02]oo`00;Goo00@005YFFUH000EJ
EP03001JEUYF00EJEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP03001JEUYF00AJEP04001J
EUYFFUH300000eYF001JEP04FUH00`00FUIJEP05FUH80003FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01`00FUH005YF001JEP00
009JEP03001JEUYF009JEP05001JEUYFFUH0000VOol2000]Ool002ioo`03001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00@0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00@00003FUH005YF00AJEP03001JEUYF00D000]JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEPD000IJEP03001JEUYF009JEP04001JEP00FUH20004FUH01@00FUIJEUYF0000
0eYF00<007ooOol097oo0P00;Goo000_Ool20005FUH00`00FUIJEP04FUH40006FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1@0000IJEP00FUH005YF0005FUH30004FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00Oomoo`0SOol2000^
Ool0031oo`8000AJEP03001JEUYF00@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF009J
EPP0009JEP80009JEP05001JEP00FUH00003FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30004FUH00`00FUH00003FUH00`00FUIJ
EP03FUH20004FUH00`00Oomoo`0ROol00`00FUH0000^Ool0039oo`<00004FUH000000005FUH00`00
FUIJEP07FUH00`00FUIJEP02FUH80003FUH01000FUIJEUYF0`0000=JEP00FUH00UYF0P0000=JEP00
FUH00P0000=JEP00FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00P000UYF00<005YF00000`0000=JEP00FUH00eYF0`00
0UYF0P0097oo0`00;Woo000dOol30008FUH00`00FUIJEP04FUH70003FUH00`00FUIJEP05FUH40004
FUH01000FUIJEUYF0P0000=JEP0000000eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00
00001P0000=JEP00FUH00UYF10008goo00<005YF0000;goo000bOol20002FUH00`00FUIJEP06FUH0
0`00FUIJEP0400000eYF000000020005FUH00`00FUIJEP02FUH400000eYF001JEP05FUH00`00FUIJ
EP030005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF001JEUYF00000eYF0`001EYF0P00
8Goo0P000UYF00<007ooOol0;Goo000`Ool20005FUH00`00FUIJEP04FUH50004FUH50004FUH50005
FUH00`00FUIJEP04FUH300000goo00000005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001EYF
001JEUYF00001EYF00<005YFFUH01EYF0`0077oo0`000UYF00<007ooOol0;Woo000^Ool30006FUH0
0`00FUIJEP040005Ool=0002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20005FUH00`00
FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH01000FUH000000UYF00<005YFFUH015YF0P001UYF00<005YF0000
0P005goo0P000UYF0`00<Goo000/Ool20002FUH00`00FUIJEP04FUH3000=Ool50006FUH00`00FUIJ
EP06FUH00`00FUH000020005Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH00000
0UYF00<005YFFUH015YF00@005YF000000=JEP03001JEUYF00=JEP<000moo`D000=JEP8003=oo`00
:goo0P0015YF00@005YFFUIJEP8000aoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP<000Qo
o`8000EJEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH01000
FUIJEUYF0`0000=JEP00FUH01eYF3`000eYF00<005YFFUH00UYF00<007ooOol0<Woo000[Ool30003
FUH01000FUH0000027oo1P001UYF00<005YFFUH01eYF00<005YFFUH00UYF0P0037oo00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF00@005YFFUIJ
EP800004FUH000000008FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00=Goo000/
OolA0003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002000>Ool00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH20002FUH01000FUH000000goo
0`0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003Moo`00;7oo0P0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10004Woo0P000eYF00<005YF
FUH01EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YFFUH00UYF00D005YFFUH005YF00<000Mo
o`<00003FUH005YF00MJEP03001JEUYF009JEPD003Uoo`00;7oo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0100067oo0P0000=JEP00FUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJ
EP8000EJEP05001JEUYFFUH00003FUH3000<Ool?000nOol002eoo`8000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF009JEPH001ioo`<000IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP000007FUH01000FUIJEP001EYF
00<007ooOol0F7oo000]Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH9000WOol20004FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH@
0005FUH00`00Oomoo`1IOol002iooa00039oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00D000eoo`03001JEP0000AJEP03001oogoo05Uoo`00
Lgoo10002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF1@0000=oo`0000000`00
2goo00@005YFFUH000=JEP03001oogoo05Yoo`00Mgoo1P000eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00@005YFFUIJEPH000Ioo`D000Yoo`03001JEUYF009JEP03001JEP0005eoo`00OGoo800037oo
1@002Goo00<005YFFUH00eYF00<005YF0000GGoo002@Ool00`00FUIJEP03FUH00`00Oomoo`0AOol3
0009Ool00`00FUIJEP05FUH00`00Oomoo`1LOol008moo`03001JEUYF00=JEP03001oogoo01eoo`03
001JEUYF00AJEP8005moo`00SWoo00<005YF00000eYF00<007ooOol077oo0`001EYF00<007ooOol0
Ggoo002>Ool00`00FUH00003FUH00`00Oomoo`0JOol20003FUH01@00FUIJEUYF0000HWoo002=Ool0
1`00FUIJEUYF001JEP0001]oo`8000EJEP04001JEP00001SOol008eoo`03001JEUYF009JEP03001o
ogoo01Qoo`8000QJEP03001oogoo06=oo`00SGoo0P000eYF00<007ooOol05Woo0P0000=JEP00FUH0
1EYF0P00IWoo002=Ool20002FUH00`00Oomoo`0EOol20003FUH00`00FUIJEP03FUH00`00Oomoo`1V
Ool008ioo`04FUH005YF000EOol20006FUH01@00FUIJEUYF0000JGoo002>Ool3000COol30008FUH0
1000FUH00000JWoo002>Ool00`00FUH0000AOol20002FUH00`00FUIJEP07FUH00`00Oomoo`1ZOol0
08moo`03FUH007oo00eoo`<000AJEP03001JEUYF00EJEP8006eoo`00Sgoo400025YF00<005YFFUH0
0UYF0P00Kgoo002@Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02
001aOol0091oo`03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP<007=oo`00TGoo0P00
1EYF00<005YFFUH015YF00@005YFFUIJEP@007Ioo`00Tgoo100000=JEP00FUH00eYF1P00NWoo002G
Ool60020Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58799 .75019 m .58833 .69457 L .55713 .69254 L p .707 .577 .707 r
F P
0 g
s
.58833 .69457 m .58799 .75019 L .61982 .74957 L p .707 .577 .707 r
F P
0 g
s
.61982 .74957 m .62015 .69395 L .58833 .69457 L p .707 .577 .707 r
F P
0 g
s
.62015 .69395 m .61982 .74957 L .64916 .74636 L p .707 .577 .707 r
F P
0 g
s
.64916 .74636 m .64949 .69074 L .62015 .69395 L p .707 .577 .707 r
F P
0 g
s
.5568 .74816 m .55713 .69254 L .52962 .68806 L p .707 .577 .707 r
F P
0 g
s
.55713 .69254 m .5568 .74816 L .58799 .75019 L p .707 .577 .707 r
F P
0 g
s
.64949 .69074 m .64916 .74636 L .67314 .74088 L p .707 .577 .707 r
F P
0 g
s
.67314 .74088 m .67348 .68526 L .64949 .69074 L p .707 .577 .707 r
F P
0 g
s
.52962 .68806 m .52929 .74368 L .5568 .74816 L p .707 .577 .707 r
F P
0 g
s
.52929 .74368 m .52962 .68806 L .50849 .68156 L p .707 .577 .707 r
F P
0 g
s
.60057 .81246 m .59812 .77578 L .56697 .77564 L p .707 .577 .707 r
F P
0 g
s
.59812 .77578 m .60057 .81246 L .63233 .80961 L p .707 .577 .707 r
F P
0 g
s
.63233 .80961 m .62987 .77293 L .59812 .77578 L p .707 .577 .707 r
F P
0 g
s
.62987 .77293 m .63233 .80961 L .66158 .80406 L p .707 .577 .707 r
F P
0 g
s
.66158 .80406 m .65912 .76738 L .62987 .77293 L p .707 .577 .707 r
F P
0 g
s
.56943 .81232 m .56697 .77564 L .53948 .77254 L p .707 .577 .707 r
F P
0 g
s
.56697 .77564 m .56943 .81232 L .60057 .81246 L p .707 .577 .707 r
F P
0 g
s
.67348 .68526 m .67314 .74088 L .68943 .73365 L p .707 .577 .707 r
F P
0 g
s
.68943 .73365 m .68976 .67803 L .67348 .68526 L p .707 .577 .707 r
F P
0 g
s
.50849 .68156 m .50816 .73718 L .52929 .74368 L p .707 .577 .707 r
F P
0 g
s
.65912 .76738 m .66158 .80406 L .68547 .79635 L p .707 .577 .707 r
F P
0 g
s
.68547 .79635 m .68301 .75967 L .65912 .76738 L p .707 .577 .707 r
F P
0 g
s
.59864 .82736 m .60699 .81009 L .57903 .79604 L p .707 .577 .707 r
F P
0 g
s
.60699 .81009 m .59864 .82736 L .62736 .84097 L p .707 .577 .707 r
F P
0 g
s
.62736 .84097 m .63571 .8237 L .60699 .81009 L p .707 .577 .707 r
F P
0 g
s
.57903 .79604 m .57068 .8133 L .59864 .82736 L p .707 .577 .707 r
F P
0 g
s
.53948 .77254 m .54194 .80922 L .56943 .81232 L p .707 .577 .707 r
F P
0 g
s
.50816 .73718 m .50849 .68156 L .49581 .67369 L p .707 .577 .707 r
F P
0 g
s
.63571 .8237 m .62736 .84097 L .65403 .8528 L p .707 .577 .707 r
F P
0 g
s
.65403 .8528 m .66238 .83553 L .63571 .8237 L p .707 .577 .707 r
F P
0 g
s
.54194 .80922 m .53948 .77254 L .51834 .76678 L p .707 .577 .707 r
F P
0 g
s
.57068 .8133 m .57903 .79604 L .55457 .78291 L p .707 .577 .707 r
F P
0 g
s
.55457 .78291 m .54622 .80018 L .57068 .8133 L p .707 .577 .707 r
F P
0 g
s
.66238 .83553 m .65403 .8528 L .67605 .8617 L p .707 .577 .707 r
F P
0 g
s
.67605 .8617 m .6844 .84443 L .66238 .83553 L p .707 .577 .707 r
F P
0 g
s
.68301 .75967 m .68547 .79635 L .70166 .78724 L p .707 .577 .707 r
F P
0 g
s
.70166 .78724 m .6992 .75056 L .68301 .75967 L p .707 .577 .707 r
F P
0 g
s
.49581 .67369 m .49547 .72931 L .50816 .73718 L p .707 .577 .707 r
F P
0 g
s
.51834 .76678 m .52079 .80346 L .54194 .80922 L p .707 .577 .707 r
F P
0 g
s
.68976 .67803 m .68943 .73365 L .69641 .7254 L p .707 .577 .707 r
F P
0 g
s
.69641 .7254 m .69674 .66978 L .68976 .67803 L p .707 .577 .707 r
F P
0 g
s
.54622 .80018 m .55457 .78291 L .536 .77201 L p .707 .577 .707 r
F P
0 g
s
.536 .77201 m .52765 .78928 L .54622 .80018 L p .707 .577 .707 r
F P
0 g
s
.52079 .80346 m .51834 .76678 L .50561 .75891 L p .707 .577 .707 r
F P
0 g
s
.49547 .72931 m .49581 .67369 L .49281 .66521 L p .707 .577 .707 r
F P
0 g
s
.6844 .84443 m .67605 .8617 L .69125 .86679 L p .707 .577 .707 r
F P
0 g
s
.69125 .86679 m .6996 .84952 L .6844 .84443 L p .707 .577 .707 r
F P
0 g
s
.50561 .75891 m .50807 .79559 L .52079 .80346 L p .707 .577 .707 r
F P
0 g
s
.6992 .75056 m .70166 .78724 L .70855 .77762 L p .707 .577 .707 r
F P
0 g
s
.70855 .77762 m .7061 .74094 L .6992 .75056 L p .707 .577 .707 r
F P
0 g
s
.49281 .66521 m .49247 .72083 L .49547 .72931 L p .707 .577 .707 r
F P
0 g
s
.52765 .78928 m .536 .77201 L .52515 .76439 L p .707 .577 .707 r
F P
0 g
s
.52515 .76439 m .5168 .78166 L .52765 .78928 L p .707 .577 .707 r
F P
0 g
s
.69674 .66978 m .69641 .7254 L .69341 .71692 L p .707 .577 .707 r
F P
0 g
s
.69341 .71692 m .69375 .6613 L .69674 .66978 L p .707 .577 .707 r
F P
0 g
s
.50807 .79559 m .50561 .75891 L .50255 .74972 L p .707 .577 .707 r
F P
0 g
s
.49247 .72083 m .49281 .66521 L .49979 .65695 L p .707 .577 .707 r
F P
0 g
s
.48546 .82173 m .48546 .31984 L .44183 .31675 L p .707 .577 .707 r
F P
0 g
s
.50255 .74972 m .505 .7864 L .50807 .79559 L p .707 .577 .707 r
F P
0 g
s
.5168 .78166 m .52515 .76439 L .52307 .7608 L p .707 .577 .707 r
F P
0 g
s
.49979 .65695 m .49946 .71257 L .49247 .72083 L p .707 .577 .707 r
F P
0 g
s
.52307 .7608 m .51472 .77806 L .5168 .78166 L p .707 .577 .707 r
F P
0 g
s
.505 .7864 m .50255 .74972 L .50945 .7401 L p .707 .577 .707 r
F P
0 g
s
.49946 .71257 m .49979 .65695 L .51608 .64973 L p .707 .577 .707 r
F P
0 g
s
.50945 .7401 m .5119 .77678 L .505 .7864 L p .707 .577 .707 r
F P
0 g
s
.51608 .64973 m .51574 .70535 L .49946 .71257 L p .707 .577 .707 r
F P
0 g
s
.51472 .77806 m .52307 .7608 L .52997 .76159 L p .707 .577 .707 r
F P
0 g
s
.52997 .76159 m .52162 .77885 L .51472 .77806 L p .707 .577 .707 r
F P
0 g
s
.51574 .70535 m .51608 .64973 L .54006 .64424 L p .707 .577 .707 r
F P
0 g
s
.5119 .77678 m .50945 .7401 L .52563 .73099 L p .707 .577 .707 r
F P
0 g
s
.52162 .77885 m .52997 .76159 L .54517 .76668 L p .707 .577 .707 r
F P
0 g
s
.52563 .73099 m .52809 .76767 L .5119 .77678 L p .707 .577 .707 r
F P
0 g
s
.54006 .64424 m .53973 .69986 L .51574 .70535 L p .707 .577 .707 r
F P
0 g
s
.54517 .76668 m .53682 .78395 L .52162 .77885 L p .707 .577 .707 r
F P
0 g
s
.48546 .31984 m .48546 .82173 L .53052 .82105 L p .707 .577 .707 r
F P
0 g
s
.52809 .76767 m .52563 .73099 L .54952 .72328 L p .707 .577 .707 r
F P
0 g
s
.54952 .72328 m .55198 .75996 L .52809 .76767 L p .707 .577 .707 r
F P
0 g
s
.53052 .82105 m .53052 .31916 L .48546 .31984 L p .707 .577 .707 r
F P
0 g
s
.53973 .69986 m .54006 .64424 L .5694 .64103 L p .707 .577 .707 r
F P
0 g
s
.5694 .64103 m .56907 .69665 L .53973 .69986 L p .707 .577 .707 r
F P
0 g
s
.55198 .75996 m .54952 .72328 L .57877 .71773 L p .707 .577 .707 r
F P
0 g
s
.53682 .78395 m .54517 .76668 L .56718 .77558 L p .707 .577 .707 r
F P
0 g
s
.56718 .77558 m .55883 .79284 L .53682 .78395 L p .707 .577 .707 r
F P
0 g
s
.57877 .71773 m .58123 .75441 L .55198 .75996 L p .707 .577 .707 r
F P
0 g
s
.55883 .79284 m .56718 .77558 L .59386 .78741 L p .707 .577 .707 r
F P
0 g
s
.59386 .78741 m .58551 .80468 L .55883 .79284 L p .707 .577 .707 r
F P
0 g
s
.53052 .31916 m .53052 .82105 L .57259 .81666 L p .707 .577 .707 r
F P
0 g
s
.56907 .69665 m .5694 .64103 L .60123 .64041 L p .707 .577 .707 r
F P
0 g
s
.60123 .64041 m .60089 .69603 L .56907 .69665 L p .707 .577 .707 r
F P
0 g
s
.57259 .81666 m .57259 .31478 L .53052 .31916 L p .707 .577 .707 r
F P
0 g
s
.6996 .84952 m .69125 .86679 L .69814 .86758 L p .707 .577 .707 r
F P
0 g
s
.69814 .86758 m .70649 .85031 L .6996 .84952 L p .707 .577 .707 r
F P
0 g
s
.7061 .74094 m .70855 .77762 L .70549 .76843 L p .707 .577 .707 r
F P
0 g
s
.70549 .76843 m .70303 .73175 L .7061 .74094 L p .707 .577 .707 r
F P
0 g
s
.44183 .81864 m .44183 .31675 L .40389 .31019 L p .707 .577 .707 r
F P
0 g
s
.44183 .31675 m .44183 .81864 L .48546 .82173 L p .707 .577 .707 r
F P
0 g
s
.69375 .6613 m .69341 .71692 L .68073 .70904 L p .707 .577 .707 r
F P
0 g
s
.68073 .70904 m .68106 .65342 L .69375 .6613 L p .707 .577 .707 r
F P
0 g
s
.58123 .75441 m .57877 .71773 L .61053 .71488 L p .707 .577 .707 r
F P
0 g
s
.61053 .71488 m .61298 .75157 L .58123 .75441 L p .707 .577 .707 r
F P
0 g
s
.58551 .80468 m .59386 .78741 L .62258 .80102 L p .707 .577 .707 r
F P
0 g
s
.62258 .80102 m .61423 .81829 L .58551 .80468 L p .707 .577 .707 r
F P
0 g
s
.57259 .31478 m .57259 .81666 L .60756 .80901 L p .707 .577 .707 r
F P
0 g
s
.63242 .64244 m .63209 .69806 L .60089 .69603 L p .707 .577 .707 r
F P
0 g
s
.60089 .69603 m .60123 .64041 L .63242 .64244 L p .707 .577 .707 r
F P
0 g
s
.60756 .80901 m .60756 .30712 L .57259 .31478 L p .707 .577 .707 r
F P
0 g
s
.40388 .81208 m .40389 .31019 L .37535 .30081 L p .707 .577 .707 r
F P
0 g
s
.40389 .31019 m .40388 .81208 L .44183 .81864 L p .707 .577 .707 r
F P
0 g
s
.70649 .85031 m .69814 .86758 L .69607 .86399 L p .707 .577 .707 r
F P
0 g
s
.69607 .86399 m .70441 .84672 L .70649 .85031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24982 .71097 m .24996 .65548 L .21877 .65349 L p .707 .577 .707 r
F P
0 g
s
.24996 .65548 m .24982 .71097 L .28164 .71022 L p .707 .577 .707 r
F P
0 g
s
.28164 .71022 m .28179 .65473 L .24996 .65548 L p .707 .577 .707 r
F P
0 g
s
.28179 .65473 m .28164 .71022 L .31098 .70682 L p .707 .577 .707 r
F P
0 g
s
.31098 .70682 m .31113 .65133 L .28179 .65473 L p .707 .577 .707 r
F P
0 g
s
.70303 .73175 m .70549 .76843 L .69277 .76056 L p .707 .577 .707 r
F P
0 g
s
.69277 .76056 m .69031 .72388 L .70303 .73175 L p .707 .577 .707 r
F P
0 g
s
.21862 .70898 m .21877 .65349 L .19126 .64896 L p .707 .577 .707 r
F P
0 g
s
.21877 .65349 m .21862 .70898 L .24982 .71097 L p .707 .577 .707 r
F P
0 g
s
.64167 .71502 m .64413 .7517 L .61298 .75157 L p .707 .577 .707 r
F P
0 g
s
.61298 .75157 m .61053 .71488 L .64167 .71502 L p .707 .577 .707 r
F P
0 g
s
.61423 .81829 m .62258 .80102 L .65054 .81507 L p .707 .577 .707 r
F P
0 g
s
.60756 .30712 m .60756 .80901 L .63199 .79883 L p .707 .577 .707 r
F P
0 g
s
.63199 .79883 m .63199 .29694 L .60756 .30712 L p .707 .577 .707 r
F P
0 g
s
.68106 .65342 m .68073 .70904 L .6596 .70255 L p .707 .577 .707 r
F P
0 g
s
.6596 .70255 m .65993 .64693 L .68106 .65342 L p .707 .577 .707 r
F P
0 g
s
.25541 .76792 m .25435 .7303 L .22315 .72971 L p .707 .577 .707 r
F P
0 g
s
.25435 .7303 m .25541 .76792 L .28721 .76643 L p .707 .577 .707 r
F P
0 g
s
.28721 .76643 m .28616 .72881 L .25435 .7303 L p .707 .577 .707 r
F P
0 g
s
.28616 .72881 m .28721 .76643 L .31651 .763 L p .707 .577 .707 r
F P
0 g
s
.31651 .763 m .31545 .72538 L .28616 .72881 L p .707 .577 .707 r
F P
0 g
s
.31113 .65133 m .31098 .70682 L .33497 .70109 L p .707 .577 .707 r
F P
0 g
s
.33497 .70109 m .33511 .6456 L .31113 .65133 L p .707 .577 .707 r
F P
0 g
s
.2242 .76733 m .22315 .72971 L .1956 .72711 L p .707 .577 .707 r
F P
0 g
s
.22315 .72971 m .2242 .76733 L .25541 .76792 L p .707 .577 .707 r
F P
0 g
s
.19111 .70445 m .19126 .64896 L .17012 .64234 L p .707 .577 .707 r
F P
0 g
s
.19126 .64896 m .19111 .70445 L .21862 .70898 L p .707 .577 .707 r
F P
0 g
s
.1956 .72711 m .19666 .76473 L .2242 .76733 L p .707 .577 .707 r
F P
0 g
s
.31545 .72538 m .31651 .763 L .34042 .75798 L p .707 .577 .707 r
F P
0 g
s
.34042 .75798 m .33936 .72036 L .31545 .72538 L p .707 .577 .707 r
F P
0 g
s
.70441 .84672 m .69607 .86399 L .68521 .85636 L p .707 .577 .707 r
F P
0 g
s
.68521 .85636 m .69356 .8391 L .70441 .84672 L p .707 .577 .707 r
F P
0 g
s
.37535 .8027 m .37535 .30081 L .35902 .28952 L p .707 .577 .707 r
F P
0 g
s
.37535 .30081 m .37535 .8027 L .40388 .81208 L p .707 .577 .707 r
F P
0 g
s
.65993 .64693 m .6596 .70255 L .63209 .69806 L p .707 .577 .707 r
F P
0 g
s
.63209 .69806 m .63242 .64244 L .65993 .64693 L p .707 .577 .707 r
F P
0 g
s
.69031 .72388 m .69277 .76056 L .67162 .7548 L p .707 .577 .707 r
F P
0 g
s
.67162 .7548 m .66917 .71812 L .69031 .72388 L p .707 .577 .707 r
F P
0 g
s
.19666 .76473 m .1956 .72711 L .17441 .72273 L p .707 .577 .707 r
F P
0 g
s
.33511 .6456 m .33497 .70109 L .35125 .69359 L p .707 .577 .707 r
F P
0 g
s
.35125 .69359 m .3514 .6381 L .33511 .6456 L p .707 .577 .707 r
F P
0 g
s
.17012 .64234 m .16998 .69783 L .19111 .70445 L p .707 .577 .707 r
F P
0 g
s
.25621 .85379 m .26 .83958 L .22933 .83061 L p .707 .577 .707 r
F P
0 g
s
.26 .83958 m .25621 .85379 L .28738 .85626 L p .707 .577 .707 r
F P
0 g
s
.28738 .85626 m .29116 .84206 L .26 .83958 L p .707 .577 .707 r
F P
0 g
s
.22555 .84481 m .22933 .83061 L .20216 .81602 L p .707 .577 .707 r
F P
0 g
s
.22933 .83061 m .22555 .84481 L .25621 .85379 L p .707 .577 .707 r
F P
0 g
s
.17441 .72273 m .17546 .76035 L .19666 .76473 L p .707 .577 .707 r
F P
0 g
s
.64413 .7517 m .64167 .71502 L .66917 .71812 L p .707 .577 .707 r
F P
0 g
s
.63199 .29694 m .63199 .79883 L .64351 .78712 L p .707 .577 .707 r
F P
0 g
s
.64351 .78712 m .64351 .28523 L .63199 .29694 L p .707 .577 .707 r
F P
0 g
s
.16998 .69783 m .17012 .64234 L .15744 .63428 L p .707 .577 .707 r
F P
0 g
s
.33936 .72036 m .34042 .75798 L .35662 .75185 L p .707 .577 .707 r
F P
0 g
s
.35662 .75185 m .35556 .71423 L .33936 .72036 L p .707 .577 .707 r
F P
0 g
s
.29116 .84206 m .28738 .85626 L .31599 .85201 L p .707 .577 .707 r
F P
0 g
s
.31599 .85201 m .31978 .8378 L .29116 .84206 L p .707 .577 .707 r
F P
0 g
s
.19838 .83022 m .20216 .81602 L .18116 .79723 L p .707 .577 .707 r
F P
0 g
s
.20216 .81602 m .19838 .83022 L .22555 .84481 L p .707 .577 .707 r
F P
0 g
s
.66917 .71812 m .67162 .7548 L .64413 .7517 L p .707 .577 .707 r
F P
0 g
s
.17546 .76035 m .17441 .72273 L .16164 .71702 L p .707 .577 .707 r
F P
0 g
s
.69356 .8391 m .68521 .85636 L .66665 .84546 L p .707 .577 .707 r
F P
0 g
s
.66665 .84546 m .675 .82819 L .69356 .8391 L p .707 .577 .707 r
F P
0 g
s
.31978 .8378 m .31599 .85201 L .33925 .84143 L p .707 .577 .707 r
F P
0 g
s
.33925 .84143 m .34304 .82722 L .31978 .8378 L p .707 .577 .707 r
F P
0 g
s
.15744 .63428 m .15729 .68977 L .16998 .69783 L p .707 .577 .707 r
F P
0 g
s
.3514 .6381 m .35125 .69359 L .35824 .68507 L p .707 .577 .707 r
F P
0 g
s
.35824 .68507 m .35838 .62957 L .3514 .6381 L p .707 .577 .707 r
F P
0 g
s
.18116 .79723 m .17737 .81144 L .19838 .83022 L p .707 .577 .707 r
F P
0 g
s
.17737 .81144 m .18116 .79723 L .16836 .7761 L p .707 .577 .707 r
F P
0 g
s
.16458 .79031 m .16836 .7761 L .16812 .77455 L p .707 .577 .707 r
F P
0 g
s
.16164 .71702 m .1627 .75464 L .17251 .75903 L p .707 .577 .707 r
F P
0 g
s
.16812 .77455 m .16504 .75469 L p .16462 .78693 L .707 .577 .707 r
F P
0 g
s
.16458 .79031 m .16812 .77455 L .16462 .78693 L .707 .577 .707 r
F
.17251 .75903 m .17546 .76035 L p .1737 .75483 L F P
0 g
s
.1737 .75483 m .16164 .71702 L .17251 .75903 L .707 .577 .707 r
F
.35556 .71423 m .35662 .75185 L .36351 .74521 L p F P
0 g
s
.36351 .74521 m .36245 .70759 L .35556 .71423 L p .707 .577 .707 r
F P
0 g
s
.35838 .62957 m .35824 .68507 L .35524 .67634 L p .707 .577 .707 r
F P
0 g
s
.35524 .67634 m .35538 .62085 L .35838 .62957 L p .707 .577 .707 r
F P
0 g
s
.36135 .80596 m .36513 .79176 L .35867 .81136 L p .707 .577 .707 r
F P
0 g
s
.36135 .80596 m .35803 .78455 L p .36287 .78946 L .707 .577 .707 r
F P
0 g
s
.36513 .79176 m .3633 .79863 L p .36287 .78946 L .707 .577 .707 r
F P
0 g
s
.3633 .79863 m .36135 .80596 L p .36287 .78946 L .707 .577 .707 r
F P
0 g
s
.35902 .28952 m .35649 .27743 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.35803 .78455 m .36181 .77035 L .36204 .77183 L p .707 .577 .707 r
F P
0 g
s
.36204 .77183 m .36513 .79176 L p .36287 .78946 L .707 .577 .707 r
F P
0 g
s
.35803 .78455 m .36204 .77183 L .36287 .78946 L .707 .577 .707 r
F
.35936 .7011 m .36042 .73872 L .34765 .73301 L p F P
0 g
s
.34765 .73301 m .34659 .69539 L .35936 .7011 L p .707 .577 .707 r
F P
0 g
s
.36181 .77035 m .35803 .78455 L .34523 .76342 L p .707 .577 .707 r
F P
0 g
s
.34523 .76342 m .34902 .74922 L .36181 .77035 L p .707 .577 .707 r
F P
0 g
s
.35649 .77932 m .35902 .79141 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.35649 .27743 m .35649 .65404 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.35649 .65404 m .35649 .77932 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.35902 .79141 m .35902 .70775 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.35902 .70775 m .35902 .28952 L p .35856 .69799 L .707 .577 .707 r
F P
0 g
s
.36245 .70759 m .36351 .74521 L .36042 .73872 L p .707 .577 .707 r
F P
0 g
s
.36042 .73872 m .35936 .7011 L .36245 .70759 L p .707 .577 .707 r
F P
0 g
s
.35902 .28952 m .35902 .79141 L .37535 .8027 L p .707 .577 .707 r
F P
0 g
s
.15729 .68977 m .15744 .63428 L .15444 .62555 L p .707 .577 .707 r
F P
0 g
s
.16836 .7761 m .16458 .79031 L .17737 .81144 L p .707 .577 .707 r
F P
0 g
s
.34304 .82722 m .33925 .84143 L .35488 .82556 L p .707 .577 .707 r
F P
0 g
s
.35488 .82556 m .35867 .81136 L .34304 .82722 L p .707 .577 .707 r
F P
0 g
s
.675 .82819 m .66665 .84546 L .64219 .83234 L p .707 .577 .707 r
F P
0 g
s
.64219 .83234 m .65054 .81507 L .675 .82819 L p .707 .577 .707 r
F P
0 g
s
.64351 .28523 m .64351 .78712 L .64098 .77503 L p .707 .577 .707 r
F P
0 g
s
.64098 .77503 m .64098 .27314 L .64351 .28523 L p .707 .577 .707 r
F P
0 g
s
.1627 .75464 m .16164 .71702 L .15855 .71053 L p .707 .577 .707 r
F P
0 g
s
.15444 .62555 m .1543 .68104 L .15729 .68977 L p .707 .577 .707 r
F P
0 g
s
.15855 .71053 m .15961 .74815 L .1627 .75464 L p .707 .577 .707 r
F P
0 g
s
.65054 .81507 m .64219 .83234 L .61423 .81829 L p .707 .577 .707 r
F P
0 g
s
.16504 .75469 m .16126 .76889 L .16458 .79031 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35867 .81136 m .35488 .82556 L .36135 .80596 L p .707 .577 .707 r
F P
0 g
s
.1543 .68104 m .15444 .62555 L .16142 .61703 L p .707 .577 .707 r
F P
0 g
s
.16126 .76889 m .16504 .75469 L .17151 .73509 L p .707 .577 .707 r
F P
0 g
s
.35649 .77932 m .35649 .27743 L .368 .26572 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15961 .74815 m .15855 .71053 L .16544 .70389 L p .707 .577 .707 r
F P
0 g
s
.16142 .61703 m .16128 .67252 L .1543 .68104 L p .707 .577 .707 r
F P
0 g
s
.17151 .73509 m .16772 .74929 L .16126 .76889 L p .707 .577 .707 r
F P
0 g
s
.35538 .62085 m .35524 .67634 L .34255 .66828 L p .707 .577 .707 r
F P
0 g
s
.34255 .66828 m .3427 .61278 L .35538 .62085 L p .707 .577 .707 r
F P
0 g
s
.16544 .70389 m .1665 .74152 L .15961 .74815 L p .707 .577 .707 r
F P
0 g
s
.64098 .27314 m .64098 .77503 L .62465 .76374 L p .707 .577 .707 r
F P
0 g
s
.62465 .76374 m .62465 .26185 L .64098 .27314 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16772 .74929 m .17151 .73509 L .18714 .71923 L p .707 .577 .707 r
F P
0 g
s
.16128 .67252 m .16142 .61703 L .17771 .60953 L p .707 .577 .707 r
F P
0 g
s
.18714 .71923 m .18335 .73343 L .16772 .74929 L p .707 .577 .707 r
F P
0 g
s
.1665 .74152 m .16544 .70389 L .18163 .69776 L p .707 .577 .707 r
F P
0 g
s
.17771 .60953 m .17756 .66502 L .16128 .67252 L p .707 .577 .707 r
F P
0 g
s
.3427 .61278 m .34255 .66828 L .32142 .66166 L p .707 .577 .707 r
F P
0 g
s
.32142 .66166 m .32157 .60616 L .3427 .61278 L p .707 .577 .707 r
F P
0 g
s
.18163 .69776 m .18269 .73539 L .1665 .74152 L p .707 .577 .707 r
F P
0 g
s
.18335 .73343 m .18714 .71923 L .2104 .70865 L p .707 .577 .707 r
F P
0 g
s
.368 .76761 m .368 .26572 L .39244 .25554 L p .707 .577 .707 r
F P
0 g
s
.368 .26572 m .368 .76761 L .35649 .77932 L p .707 .577 .707 r
F P
0 g
s
.17756 .66502 m .17771 .60953 L .20169 .6038 L p .707 .577 .707 r
F P
0 g
s
.34659 .69539 m .34765 .73301 L .32645 .72864 L p .707 .577 .707 r
F P
0 g
s
.32645 .72864 m .3254 .69101 L .34659 .69539 L p .707 .577 .707 r
F P
0 g
s
.2104 .70865 m .20661 .72285 L .18335 .73343 L p .707 .577 .707 r
F P
0 g
s
.62465 .26185 m .62465 .76374 L .59611 .75436 L p .707 .577 .707 r
F P
0 g
s
.59611 .75436 m .59611 .25247 L .62465 .26185 L p .707 .577 .707 r
F P
0 g
s
.34902 .74922 m .34523 .76342 L .32423 .74464 L p .707 .577 .707 r
F P
0 g
s
.32423 .74464 m .32801 .73044 L .34902 .74922 L p .707 .577 .707 r
F P
0 g
s
.32157 .60616 m .32142 .66166 L .29391 .65713 L p .707 .577 .707 r
F P
0 g
s
.29391 .65713 m .29406 .60164 L .32157 .60616 L p .707 .577 .707 r
F P
0 g
s
.18269 .73539 m .18163 .69776 L .20555 .69274 L p .707 .577 .707 r
F P
0 g
s
.20661 .72285 m .2104 .70865 L .23901 .70439 L p .707 .577 .707 r
F P
0 g
s
.20169 .6038 m .20155 .65929 L .17756 .66502 L p .707 .577 .707 r
F P
0 g
s
.20155 .65929 m .20169 .6038 L .23104 .6004 L p .707 .577 .707 r
F P
0 g
s
.73728 .65918 m .73714 .60351 L .70594 .60175 L p .707 .577 .707 r
F P
0 g
s
.73714 .60351 m .73728 .65918 L .76911 .65832 L p .707 .577 .707 r
F P
0 g
s
.76911 .65832 m .76896 .60265 L .73714 .60351 L p .707 .577 .707 r
F P
0 g
s
.20555 .69274 m .20661 .73036 L .18269 .73539 L p .707 .577 .707 r
F P
0 g
s
.76896 .60265 m .76911 .65832 L .79845 .65491 L p .707 .577 .707 r
F P
0 g
s
.79845 .65491 m .7983 .59924 L .76896 .60265 L p .707 .577 .707 r
F P
0 g
s
.32801 .73044 m .32423 .74464 L .29706 .73005 L p .707 .577 .707 r
F P
0 g
s
.29706 .73005 m .30084 .71584 L .32801 .73044 L p .707 .577 .707 r
F P
0 g
s
.23901 .70439 m .23523 .71859 L .20661 .72285 L p .707 .577 .707 r
F P
0 g
s
.3254 .69101 m .32645 .72864 L .29891 .72603 L p .707 .577 .707 r
F P
0 g
s
.30084 .71584 m .29706 .73005 L .26639 .72107 L p .707 .577 .707 r
F P
0 g
s
.26639 .72107 m .27018 .70687 L .30084 .71584 L p .707 .577 .707 r
F P
0 g
s
.29891 .72603 m .29785 .68841 L .3254 .69101 L p .707 .577 .707 r
F P
0 g
s
.23523 .71859 m .23901 .70439 L .27018 .70687 L p .707 .577 .707 r
F P
0 g
s
.70609 .65742 m .70594 .60175 L .67843 .59754 L p .707 .577 .707 r
F P
0 g
s
.70594 .60175 m .70609 .65742 L .73728 .65918 L p .707 .577 .707 r
F P
0 g
s
.29406 .60164 m .29391 .65713 L .26272 .65514 L p .707 .577 .707 r
F P
0 g
s
.26272 .65514 m .26286 .59965 L .29406 .60164 L p .707 .577 .707 r
F P
0 g
s
.39244 .25554 m .39244 .75743 L .368 .76761 L p .707 .577 .707 r
F P
0 g
s
.39244 .75743 m .39244 .25554 L .42741 .24788 L p .707 .577 .707 r
F P
0 g
s
.23089 .65589 m .23104 .6004 L .26286 .59965 L p .707 .577 .707 r
F P
0 g
s
.23104 .6004 m .23089 .65589 L .20155 .65929 L p .707 .577 .707 r
F P
0 g
s
.20661 .73036 m .20555 .69274 L .23484 .68931 L p .707 .577 .707 r
F P
0 g
s
.27018 .70687 m .26639 .72107 L .23523 .71859 L p .707 .577 .707 r
F P
0 g
s
.26286 .59965 m .26272 .65514 L .23089 .65589 L p .707 .577 .707 r
F P
0 g
s
.7983 .59924 m .79845 .65491 L .82243 .6493 L p .707 .577 .707 r
F P
0 g
s
.82243 .6493 m .82229 .59363 L .7983 .59924 L p .707 .577 .707 r
F P
0 g
s
.23484 .68931 m .2359 .72694 L .20661 .73036 L p .707 .577 .707 r
F P
0 g
s
.59611 .25247 m .59611 .75436 L .55817 .7478 L p .707 .577 .707 r
F P
0 g
s
.55817 .7478 m .55817 .24591 L .59611 .25247 L p .707 .577 .707 r
F P
0 g
s
.29785 .68841 m .29891 .72603 L .2677 .72544 L p .707 .577 .707 r
F P
0 g
s
.2677 .72544 m .26665 .68782 L .29785 .68841 L p .707 .577 .707 r
F P
0 g
s
.67843 .59754 m .67858 .65321 L .70609 .65742 L p .707 .577 .707 r
F P
0 g
s
.67858 .65321 m .67843 .59754 L .6573 .59128 L p .707 .577 .707 r
F P
0 g
s
.2359 .72694 m .23484 .68931 L .26665 .68782 L p .707 .577 .707 r
F P
0 g
s
.26665 .68782 m .2677 .72544 L .2359 .72694 L p .707 .577 .707 r
F P
0 g
s
.73229 .72277 m .73335 .68646 L .70215 .68338 L p .707 .577 .707 r
F P
0 g
s
.73335 .68646 m .73229 .72277 L .7641 .72258 L p .707 .577 .707 r
F P
0 g
s
.7641 .72258 m .76515 .68627 L .73335 .68646 L p .707 .577 .707 r
F P
0 g
s
.82229 .59363 m .82243 .6493 L .83872 .64204 L p .707 .577 .707 r
F P
0 g
s
.83872 .64204 m .83857 .58636 L .82229 .59363 L p .707 .577 .707 r
F P
0 g
s
.76515 .68627 m .7641 .72258 L .79339 .71914 L p .707 .577 .707 r
F P
0 g
s
.79339 .71914 m .79445 .68283 L .76515 .68627 L p .707 .577 .707 r
F P
0 g
s
.6573 .59128 m .65744 .64696 L .67858 .65321 L p .707 .577 .707 r
F P
0 g
s
.42741 .74977 m .42741 .24788 L .46948 .2435 L p .707 .577 .707 r
F P
0 g
s
.42741 .24788 m .42741 .74977 L .39244 .75743 L p .707 .577 .707 r
F P
0 g
s
.70109 .71969 m .70215 .68338 L .6746 .67734 L p .707 .577 .707 r
F P
0 g
s
.70215 .68338 m .70109 .71969 L .73229 .72277 L p .707 .577 .707 r
F P
0 g
s
.55817 .24591 m .55817 .7478 L .51454 .74471 L p .707 .577 .707 r
F P
0 g
s
.51454 .74471 m .51454 .24282 L .55817 .24591 L p .707 .577 .707 r
F P
0 g
s
.65744 .64696 m .6573 .59128 L .64462 .58361 L p .707 .577 .707 r
F P
0 g
s
.79445 .68283 m .79339 .71914 L .81731 .71278 L p .707 .577 .707 r
F P
0 g
s
.81731 .71278 m .81836 .67647 L .79445 .68283 L p .707 .577 .707 r
F P
0 g
s
.6746 .67734 m .67354 .71365 L .70109 .71969 L p .707 .577 .707 r
F P
0 g
s
.69916 .70217 m .70294 .72074 L .73361 .71353 L p .707 .577 .707 r
F P
0 g
s
.73361 .71353 m .72982 .69496 L .69916 .70217 L p .707 .577 .707 r
F P
0 g
s
.72982 .69496 m .73361 .71353 L .76477 .70796 L p .707 .577 .707 r
F P
0 g
s
.46948 .74539 m .46948 .2435 L .51454 .24282 L p .707 .577 .707 r
F P
0 g
s
.46948 .2435 m .46948 .74539 L .42741 .74977 L p .707 .577 .707 r
F P
0 g
s
.67354 .71365 m .6746 .67734 L .6534 .66892 L p .707 .577 .707 r
F P
0 g
s
.51454 .24282 m .51454 .74471 L .46948 .74539 L p .707 .577 .707 r
F P
0 g
s
.76477 .70796 m .76099 .68939 L .72982 .69496 L p .707 .577 .707 r
F P
0 g
s
.76099 .68939 m .76477 .70796 L .79338 .70457 L p .707 .577 .707 r
F P
0 g
s
.6534 .66892 m .65235 .70523 L .67354 .71365 L p .707 .577 .707 r
F P
0 g
s
.67199 .7103 m .67577 .72887 L .70294 .72074 L p .707 .577 .707 r
F P
0 g
s
.70294 .72074 m .69916 .70217 L .67199 .7103 L p .707 .577 .707 r
F P
0 g
s
.79338 .70457 m .7896 .686 L .76099 .68939 L p .707 .577 .707 r
F P
0 g
s
.64462 .58361 m .64476 .63928 L .65744 .64696 L p .707 .577 .707 r
F P
0 g
s
.83857 .58636 m .83872 .64204 L .8457 .63382 L p .707 .577 .707 r
F P
0 g
s
.8457 .63382 m .84556 .57815 L .83857 .58636 L p .707 .577 .707 r
F P
0 g
s
.81836 .67647 m .81731 .71278 L .8335 .70414 L p .707 .577 .707 r
F P
0 g
s
.8335 .70414 m .83456 .66783 L .81836 .67647 L p .707 .577 .707 r
F P
0 g
s
.7896 .686 m .79338 .70457 L .81664 .7037 L p .707 .577 .707 r
F P
0 g
s
.65098 .71858 m .65476 .73715 L .67577 .72887 L p .707 .577 .707 r
F P
0 g
s
.67577 .72887 m .67199 .7103 L .65098 .71858 L p .707 .577 .707 r
F P
0 g
s
.64476 .63928 m .64462 .58361 L .64162 .57525 L p .707 .577 .707 r
F P
0 g
s
.81664 .7037 m .81286 .68513 L .7896 .686 L p .707 .577 .707 r
F P
0 g
s
.65235 .70523 m .6534 .66892 L .64064 .65895 L p .707 .577 .707 r
F P
0 g
s
.64162 .57525 m .64176 .63092 L .64476 .63928 L p .707 .577 .707 r
F P
0 g
s
.64064 .65895 m .63958 .69526 L .65235 .70523 L p .707 .577 .707 r
F P
0 g
s
.84556 .57815 m .8457 .63382 L .8427 .62547 L p .707 .577 .707 r
F P
0 g
s
.8427 .62547 m .84256 .5698 L .84556 .57815 L p .707 .577 .707 r
F P
0 g
s
.81286 .68513 m .81664 .7037 L .83227 .70542 L p .707 .577 .707 r
F P
0 g
s
.83456 .66783 m .8335 .70414 L .84039 .69405 L p .707 .577 .707 r
F P
0 g
s
.84039 .69405 m .84145 .65774 L .83456 .66783 L p .707 .577 .707 r
F P
0 g
s
.63819 .72618 m .64197 .74475 L .65476 .73715 L p .707 .577 .707 r
F P
0 g
s
.65476 .73715 m .65098 .71858 L .63819 .72618 L p .707 .577 .707 r
F P
0 g
s
.83227 .70542 m .82849 .68685 L .81286 .68513 L p .707 .577 .707 r
F P
0 g
s
.63958 .69526 m .64064 .65895 L .63755 .6484 L p .707 .577 .707 r
F P
0 g
s
.64176 .63092 m .64162 .57525 L .6486 .56704 L p .707 .577 .707 r
F P
0 g
s
.63755 .6484 m .63649 .68471 L .63958 .69526 L p .707 .577 .707 r
F P
0 g
s
.6486 .56704 m .64875 .62271 L .64176 .63092 L p .707 .577 .707 r
F P
0 g
s
.82849 .68685 m .83227 .70542 L .83874 .70958 L p .707 .577 .707 r
F P
0 g
s
.84256 .5698 m .8427 .62547 L .83002 .61779 L p .707 .577 .707 r
F P
0 g
s
.83002 .61779 m .82987 .56212 L .84256 .5698 L p .707 .577 .707 r
F P
0 g
s
.63486 .73236 m .63865 .75093 L .64197 .74475 L p .707 .577 .707 r
F P
0 g
s
.64197 .74475 m .63819 .72618 L .63486 .73236 L p .707 .577 .707 r
F P
0 g
s
.83874 .70958 m .83496 .69101 L .82849 .68685 L p .707 .577 .707 r
F P
0 g
s
.84145 .65774 m .84039 .69405 L .8373 .6835 L p .707 .577 .707 r
F P
0 g
s
.8373 .6835 m .83836 .64719 L .84145 .65774 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63649 .68471 m .63755 .6484 L .64444 .63831 L p .707 .577 .707 r
F P
0 g
s
.64875 .62271 m .6486 .56704 L .66488 .55977 L p .707 .577 .707 r
F P
0 g
s
.3991 .61995 m .39877 .56441 L .36757 .5627 L p .707 .577 .707 r
F P
0 g
s
.39877 .56441 m .3991 .61995 L .43093 .61897 L p .707 .577 .707 r
F P
0 g
s
.43093 .61897 m .43059 .56342 L .39877 .56441 L p .707 .577 .707 r
F P
0 g
s
.43059 .56342 m .43093 .61897 L .46027 .61537 L p .707 .577 .707 r
F P
0 g
s
.46027 .61537 m .45994 .55983 L .43059 .56342 L p .707 .577 .707 r
F P
0 g
s
.64444 .63831 m .64338 .67462 L .63649 .68471 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66488 .55977 m .66503 .61544 L .64875 .62271 L p .707 .577 .707 r
F P
0 g
s
.36791 .61824 m .36757 .5627 L .34007 .55844 L p .707 .577 .707 r
F P
0 g
s
.36757 .5627 m .36791 .61824 L .3991 .61995 L p .707 .577 .707 r
F P
0 g
s
.82987 .56212 m .83002 .61779 L .80889 .61153 L p .707 .577 .707 r
F P
0 g
s
.80889 .61153 m .80874 .55586 L .82987 .56212 L p .707 .577 .707 r
F P
0 g
s
.83496 .69101 m .83874 .70958 L .83542 .71576 L p .707 .577 .707 r
F P
0 g
s
.83836 .64719 m .8373 .6835 L .82454 .67353 L p .707 .577 .707 r
F P
0 g
s
.82454 .67353 m .82559 .63722 L .83836 .64719 L p .707 .577 .707 r
F P
0 g
s
.64133 .73651 m .64512 .75508 L .63865 .75093 L p .707 .577 .707 r
F P
0 g
s
.63865 .75093 m .63486 .73236 L .64133 .73651 L p .707 .577 .707 r
F P
0 g
s
.83542 .71576 m .83163 .69719 L .83496 .69101 L p .707 .577 .707 r
F P
0 g
s
.45994 .55983 m .46027 .61537 L .48426 .60951 L p .707 .577 .707 r
F P
0 g
s
.48426 .60951 m .48392 .55397 L .45994 .55983 L p .707 .577 .707 r
F P
0 g
s
.38701 .67831 m .38947 .64106 L .35832 .63745 L p .707 .577 .707 r
F P
0 g
s
.38947 .64106 m .38701 .67831 L .41877 .67954 L p .707 .577 .707 r
F P
0 g
s
.41877 .67954 m .42122 .64229 L .38947 .64106 L p .707 .577 .707 r
F P
0 g
s
.66503 .61544 m .66488 .55977 L .68887 .55416 L p .707 .577 .707 r
F P
0 g
s
.64338 .67462 m .64444 .63831 L .66063 .62967 L p .707 .577 .707 r
F P
0 g
s
.42122 .64229 m .41877 .67954 L .44802 .67827 L p .707 .577 .707 r
F P
0 g
s
.44802 .67827 m .45048 .64102 L .42122 .64229 L p .707 .577 .707 r
F P
0 g
s
.34007 .55844 m .3404 .61398 L .36791 .61824 L p .707 .577 .707 r
F P
0 g
s
.3404 .61398 m .34007 .55844 L .31893 .55206 L p .707 .577 .707 r
F P
0 g
s
.35587 .6747 m .35832 .63745 L .33083 .63183 L p .707 .577 .707 r
F P
0 g
s
.35832 .63745 m .35587 .6747 L .38701 .67831 L p .707 .577 .707 r
F P
0 g
s
.80874 .55586 m .80889 .61153 L .78138 .60732 L p .707 .577 .707 r
F P
0 g
s
.78138 .60732 m .78123 .55165 L .80874 .55586 L p .707 .577 .707 r
F P
0 g
s
.33083 .63183 m .32838 .66908 L .35587 .6747 L p .707 .577 .707 r
F P
0 g
s
.68887 .55416 m .68901 .60983 L .66503 .61544 L p .707 .577 .707 r
F P
0 g
s
.66063 .62967 m .65958 .66598 L .64338 .67462 L p .707 .577 .707 r
F P
0 g
s
.45048 .64102 m .44802 .67827 L .47191 .67464 L p .707 .577 .707 r
F P
0 g
s
.47191 .67464 m .47437 .63739 L .45048 .64102 L p .707 .577 .707 r
F P
0 g
s
.48392 .55397 m .48426 .60951 L .50054 .60198 L p .707 .577 .707 r
F P
0 g
s
.50054 .60198 m .5002 .54643 L .48392 .55397 L p .707 .577 .707 r
F P
0 g
s
.41449 .73017 m .40614 .71466 L .37742 .72808 L p .707 .577 .707 r
F P
0 g
s
.40614 .71466 m .41449 .73017 L .44116 .7133 L p .707 .577 .707 r
F P
0 g
s
.44116 .7133 m .43281 .69779 L .40614 .71466 L p .707 .577 .707 r
F P
0 g
s
.68901 .60983 m .68887 .55416 L .71821 .55075 L p .707 .577 .707 r
F P
0 g
s
.31893 .55206 m .31927 .60761 L .3404 .61398 L p .707 .577 .707 r
F P
0 g
s
.82559 .63722 m .82454 .67353 L .80334 .66511 L p .707 .577 .707 r
F P
0 g
s
.80334 .66511 m .8044 .6288 L .82559 .63722 L p .707 .577 .707 r
F P
0 g
s
.32838 .66908 m .33083 .63183 L .30969 .62473 L p .707 .577 .707 r
F P
0 g
s
.83163 .69719 m .83542 .71576 L .82263 .72336 L p .707 .577 .707 r
F P
0 g
s
.38577 .74359 m .37742 .72808 L .34946 .73673 L p .707 .577 .707 r
F P
0 g
s
.37742 .72808 m .38577 .74359 L .41449 .73017 L p .707 .577 .707 r
F P
0 g
s
.43281 .69779 m .44116 .7133 L .46318 .69461 L p .707 .577 .707 r
F P
0 g
s
.46318 .69461 m .45483 .6791 L .43281 .69779 L p .707 .577 .707 r
F P
0 g
s
.65696 .73824 m .66075 .75681 L .64512 .75508 L p .707 .577 .707 r
F P
0 g
s
.64512 .75508 m .64133 .73651 L .65696 .73824 L p .707 .577 .707 r
F P
0 g
s
.82263 .72336 m .81884 .70479 L .83163 .69719 L p .707 .577 .707 r
F P
0 g
s
.31927 .60761 m .31893 .55206 L .30625 .54419 L p .707 .577 .707 r
F P
0 g
s
.78123 .55165 m .78138 .60732 L .75018 .60556 L p .707 .577 .707 r
F P
0 g
s
.75018 .60556 m .75004 .54989 L .78123 .55165 L p .707 .577 .707 r
F P
0 g
s
.65958 .66598 m .66063 .62967 L .68455 .62331 L p .707 .577 .707 r
F P
0 g
s
.34946 .73673 m .35781 .75224 L .38577 .74359 L p .707 .577 .707 r
F P
0 g
s
.30969 .62473 m .30723 .66198 L .32838 .66908 L p .707 .577 .707 r
F P
0 g
s
.71836 .60643 m .71821 .55075 L .75004 .54989 L p .707 .577 .707 r
F P
0 g
s
.71821 .55075 m .71836 .60643 L .68901 .60983 L p .707 .577 .707 r
F P
0 g
s
.35781 .75224 m .34946 .73673 L .325 .73977 L p .707 .577 .707 r
F P
0 g
s
.75004 .54989 m .75018 .60556 L .71836 .60643 L p .707 .577 .707 r
F P
0 g
s
.45483 .6791 m .46318 .69461 L .47838 .67596 L p .707 .577 .707 r
F P
0 g
s
.47437 .63739 m .47191 .67464 L .4881 .66899 L p .707 .577 .707 r
F P
0 g
s
.47838 .67596 m .47003 .66045 L .45483 .6791 L p .707 .577 .707 r
F P
0 g
s
.4881 .66899 m .49055 .63174 L .47437 .63739 L p .707 .577 .707 r
F P
0 g
s
.68455 .62331 m .68349 .65963 L .65958 .66598 L p .707 .577 .707 r
F P
0 g
s
.325 .73977 m .33335 .75528 L .35781 .75224 L p .707 .577 .707 r
F P
0 g
s
.8044 .6288 m .80334 .66511 L .7758 .65907 L p .707 .577 .707 r
F P
0 g
s
.7758 .65907 m .77685 .62276 L .8044 .6288 L p .707 .577 .707 r
F P
0 g
s
.30625 .54419 m .30658 .59973 L .31927 .60761 L p .707 .577 .707 r
F P
0 g
s
.30723 .66198 m .30969 .62473 L .29696 .61686 L p .707 .577 .707 r
F P
0 g
s
.5002 .54643 m .50054 .60198 L .50752 .59349 L p .707 .577 .707 r
F P
0 g
s
.50752 .59349 m .50719 .53795 L .5002 .54643 L p .707 .577 .707 r
F P
0 g
s
.68349 .65963 m .68455 .62331 L .71384 .61987 L p .707 .577 .707 r
F P
0 g
s
.81884 .70479 m .82263 .72336 L .80162 .73163 L p .707 .577 .707 r
F P
0 g
s
.68022 .73736 m .68401 .75593 L .66075 .75681 L p .707 .577 .707 r
F P
0 g
s
.66075 .75681 m .65696 .73824 L .68022 .73736 L p .707 .577 .707 r
F P
0 g
s
.29696 .61686 m .29451 .65411 L .30723 .66198 L p .707 .577 .707 r
F P
0 g
s
.80162 .73163 m .79783 .71306 L .81884 .70479 L p .707 .577 .707 r
F P
0 g
s
.33335 .75528 m .325 .73977 L .30643 .73689 L p .707 .577 .707 r
F P
0 g
s
.30658 .59973 m .30625 .54419 L .30325 .53559 L p .707 .577 .707 r
F P
0 g
s
.47003 .66045 m .47838 .67596 L .48528 .65915 L p .707 .577 .707 r
F P
0 g
s
.48528 .65915 m .47693 .64364 L .47003 .66045 L p .707 .577 .707 r
F P
0 g
s
.77685 .62276 m .7758 .65907 L .74459 .65599 L p .707 .577 .707 r
F P
0 g
s
.74459 .65599 m .74565 .61968 L .77685 .62276 L p .707 .577 .707 r
F P
0 g
s
.71279 .65618 m .71384 .61987 L .74565 .61968 L p .707 .577 .707 r
F P
0 g
s
.71384 .61987 m .71279 .65618 L .68349 .65963 L p .707 .577 .707 r
F P
0 g
s
.30643 .73689 m .31478 .7524 L .33335 .75528 L p .707 .577 .707 r
F P
0 g
s
.49055 .63174 m .4881 .66899 L .49499 .66187 L p .707 .577 .707 r
F P
0 g
s
.49499 .66187 m .49745 .62462 L .49055 .63174 L p .707 .577 .707 r
F P
0 g
s
.74565 .61968 m .74459 .65599 L .71279 .65618 L p .707 .577 .707 r
F P
0 g
s
.30325 .53559 m .30359 .59113 L .30658 .59973 L p .707 .577 .707 r
F P
0 g
s
.29451 .65411 m .29696 .61686 L .2939 .60898 L p .707 .577 .707 r
F P
0 g
s
.79783 .71306 m .80162 .73163 L .77445 .73977 L p .707 .577 .707 r
F P
0 g
s
.50719 .53795 m .50752 .59349 L .50453 .58489 L p .707 .577 .707 r
F P
0 g
s
.50453 .58489 m .50419 .52935 L .50719 .53795 L p .707 .577 .707 r
F P
0 g
s
.70883 .73398 m .71262 .75255 L .68401 .75593 L p .707 .577 .707 r
F P
0 g
s
.68401 .75593 m .68022 .73736 L .70883 .73398 L p .707 .577 .707 r
F P
0 g
s
.77445 .73977 m .77067 .7212 L .79783 .71306 L p .707 .577 .707 r
F P
0 g
s
.31478 .7524 m .30643 .73689 L .29558 .72837 L p .707 .577 .707 r
F P
0 g
s
.2939 .60898 m .29144 .64623 L .29451 .65411 L p .707 .577 .707 r
F P
0 g
s
.47693 .64364 m .48528 .65915 L .4832 .64584 L p .707 .577 .707 r
F P
0 g
s
.4832 .64584 m .47485 .63033 L .47693 .64364 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30359 .59113 m .30325 .53559 L .31024 .52711 L p .707 .577 .707 r
F P
0 g
s
.77067 .7212 m .77445 .73977 L .74378 .74698 L p .707 .577 .707 r
F P
0 g
s
.74 .72841 m .74378 .74698 L .71262 .75255 L p .707 .577 .707 r
F P
0 g
s
.71262 .75255 m .70883 .73398 L .74 .72841 L p .707 .577 .707 r
F P
0 g
s
.29558 .72837 m .30393 .74388 L .31478 .7524 L p .707 .577 .707 r
F P
0 g
s
.74378 .74698 m .74 .72841 L .77067 .7212 L p .707 .577 .707 r
F P
0 g
s
.49745 .62462 m .49499 .66187 L .49193 .65399 L p .707 .577 .707 r
F P
0 g
s
.49193 .65399 m .49439 .61674 L .49745 .62462 L p .707 .577 .707 r
F P
0 g
s
.31024 .52711 m .31057 .58265 L .30359 .59113 L p .707 .577 .707 r
F P
0 g
s
.29144 .64623 m .2939 .60898 L .3008 .60187 L p .707 .577 .707 r
F P
0 g
s
.50419 .52935 m .50453 .58489 L .49184 .57702 L p .707 .577 .707 r
F P
0 g
s
.49184 .57702 m .49151 .52148 L .50419 .52935 L p .707 .577 .707 r
F P
0 g
s
.30393 .74388 m .29558 .72837 L .2935 .71506 L p .707 .577 .707 r
F P
0 g
s
.3008 .60187 m .29834 .63912 L .29144 .64623 L p .707 .577 .707 r
F P
0 g
s
.47485 .63033 m .4832 .64584 L .47234 .63733 L p .707 .577 .707 r
F P
0 g
s
.47234 .63733 m .46399 .62182 L .47485 .63033 L p .707 .577 .707 r
F P
0 g
s
.31057 .58265 m .31024 .52711 L .32652 .51957 L p .707 .577 .707 r
F P
0 g
s
.2935 .71506 m .30185 .73057 L .30393 .74388 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49439 .61674 m .49193 .65399 L .4792 .64612 L p .707 .577 .707 r
F P
0 g
s
.4792 .64612 m .48166 .60887 L .49439 .61674 L p .707 .577 .707 r
F P
0 g
s
.32652 .51957 m .32685 .57511 L .31057 .58265 L p .707 .577 .707 r
F P
0 g
s
.49151 .52148 m .49184 .57702 L .47071 .57064 L p .707 .577 .707 r
F P
0 g
s
.47071 .57064 m .47038 .5151 L .49151 .52148 L p .707 .577 .707 r
F P
0 g
s
.29834 .63912 m .3008 .60187 L .31698 .59621 L p .707 .577 .707 r
F P
0 g
s
.30185 .73057 m .2935 .71506 L .3004 .69826 L p .707 .577 .707 r
F P
0 g
s
.46399 .62182 m .47234 .63733 L .45378 .63445 L p .707 .577 .707 r
F P
0 g
s
.45378 .63445 m .44543 .61894 L .46399 .62182 L p .707 .577 .707 r
F P
0 g
s
.31698 .59621 m .31453 .63346 L .29834 .63912 L p .707 .577 .707 r
F P
0 g
s
.32685 .57511 m .32652 .51957 L .3505 .51371 L p .707 .577 .707 r
F P
0 g
s
.3004 .69826 m .30875 .71377 L .30185 .73057 L p .707 .577 .707 r
F P
0 g
s
.48166 .60887 m .4792 .64612 L .45806 .63902 L p .707 .577 .707 r
F P
0 g
s
.45806 .63902 m .46052 .60177 L .48166 .60887 L p .707 .577 .707 r
F P
0 g
s
.47038 .5151 m .47071 .57064 L .4432 .56639 L p .707 .577 .707 r
F P
0 g
s
.4432 .56639 m .44287 .51085 L .47038 .5151 L p .707 .577 .707 r
F P
0 g
s
.3505 .51371 m .35084 .56926 L .32685 .57511 L p .707 .577 .707 r
F P
0 g
s
.31453 .63346 m .31698 .59621 L .34087 .59258 L p .707 .577 .707 r
F P
0 g
s
.35084 .56926 m .3505 .51371 L .37985 .51012 L p .707 .577 .707 r
F P
0 g
s
.30875 .71377 m .3004 .69826 L .3156 .6796 L p .707 .577 .707 r
F P
0 g
s
.44543 .61894 m .45378 .63445 L .42932 .63748 L p .707 .577 .707 r
F P
0 g
s
.42932 .63748 m .42097 .62197 L .44543 .61894 L p .707 .577 .707 r
F P
0 g
s
.34087 .59258 m .33842 .62983 L .31453 .63346 L p .707 .577 .707 r
F P
0 g
s
.44287 .51085 m .4432 .56639 L .41201 .56467 L p .707 .577 .707 r
F P
0 g
s
.41201 .56467 m .41167 .50913 L .44287 .51085 L p .707 .577 .707 r
F P
0 g
s
.3156 .6796 m .32395 .69511 L .30875 .71377 L p .707 .577 .707 r
F P
0 g
s
.38018 .56566 m .37985 .51012 L .41167 .50913 L p .707 .577 .707 r
F P
0 g
s
.37985 .51012 m .38018 .56566 L .35084 .56926 L p .707 .577 .707 r
F P
0 g
s
.46052 .60177 m .45806 .63902 L .43057 .6334 L p .707 .577 .707 r
F P
0 g
s
.43057 .6334 m .43303 .59615 L .46052 .60177 L p .707 .577 .707 r
F P
0 g
s
.41167 .50913 m .41201 .56467 L .38018 .56566 L p .707 .577 .707 r
F P
0 g
s
.33842 .62983 m .34087 .59258 L .37013 .59131 L p .707 .577 .707 r
F P
0 g
s
.32395 .69511 m .3156 .6796 L .33761 .66092 L p .707 .577 .707 r
F P
0 g
s
.42097 .62197 m .42932 .63748 L .40136 .64613 L p .707 .577 .707 r
F P
0 g
s
.40136 .64613 m .39301 .63062 L .42097 .62197 L p .707 .577 .707 r
F P
0 g
s
.37013 .59131 m .36767 .62856 L .33842 .62983 L p .707 .577 .707 r
F P
0 g
s
.43303 .59615 m .43057 .6334 L .39942 .62979 L p .707 .577 .707 r
F P
0 g
s
.39942 .62979 m .40188 .59254 L .43303 .59615 L p .707 .577 .707 r
F P
0 g
s
.33761 .66092 m .34596 .67643 L .32395 .69511 L p .707 .577 .707 r
F P
0 g
s
.36767 .62856 m .37013 .59131 L .40188 .59254 L p .707 .577 .707 r
F P
0 g
s
.40188 .59254 m .39942 .62979 L .36767 .62856 L p .707 .577 .707 r
F P
0 g
s
.34596 .67643 m .33761 .66092 L .36429 .64404 L p .707 .577 .707 r
F P
0 g
s
.39301 .63062 m .40136 .64613 L .37264 .65955 L p .707 .577 .707 r
F P
0 g
s
.37264 .65955 m .36429 .64404 L .39301 .63062 L p .707 .577 .707 r
F P
0 g
s
.36429 .64404 m .37264 .65955 L .34596 .67643 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol0079oo`D0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00KWoo
10001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00@005YF
0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF0P00Jgoo
001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo
001UOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUIJEP001UYF00<005YF000020002eYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001UOol00`00FUIJEP090004FUH01000FUIJEUYF200015YF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001P
Ool80003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEUYF1P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001LOol40003FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020008
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool005Yoo`<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Aoo`00F7oo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001GOol20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomo
o`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0?OolH000mOol005Ioo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00Oomoo`09Ool60004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0003000iOol005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`05Ool400000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000eOol005Ioo`03001JEP00
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`03Ool20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04000aOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF009JEQ4000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000Oomoogoo
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF0P00<7oo001FOol00`00FUH00003FUH00`00FUIJEP03FUH70005FUH50006FUH80004FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@007oo0000009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEP00000^Ool005Ioo`03001J
EP0000=JEP03001JEP0000<000IJEP03001JEUYF00=JEPD000MJEP03001JEUYF00AJEPH000AJEP04
001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001FOol00`00FUH00003FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001J
EP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo001FOol01000FUH005YF0P0015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`00
0eYF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo00<005YF00000P001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P0000EJEP00001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Ioo`80009JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Ioo`80009JEP03001J
EUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP<00003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool005Ioo`80009J
EP04001JEUYFFUHI0003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01@00FUH0
05YF00002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUIJEP8002aoo`00EWoo0P0000=JEP0000000`000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF1P001EYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00?Woo4@0027oo0P0000=JEP00FUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`0000=JEP00FUH01EYF00<005YF
FUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00>7oo1P000eYF00<005YFFUH0
1UYF00<005YFFUH00UYF20000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF0`001EYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001J
EUYFFUH2000/Ool003Aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEP000080009JEP04001JEP000005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHJ0003FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000aOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40007FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP02FUH70008
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH50004FUH01000FUIJEUYF0P00;7oo000_Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUH000020006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000/Ool002eoo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000=JEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP<000=JEP8002aoo`00;7oo0P0015YF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00
FUH20004FUH00`00FUIJEP04FUHA0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
00000eYF0000000/Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH70003
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000/
Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP0400000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF0`00;7oo000[
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH00004FUH01000FUIJEUYF2@000UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<0009JEP03001JEUYF009JEP03001JEP0002aoo`00:goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0UYF1P0000=JEP00FUH0100000EJEP00FUIJEP0000AJEP800003FUH005YF00AJEPP000AJEP03001J
EUYF00=JEP06001JEUYF001JEP0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000AJEP00000000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00<000AJEP03001JEP0002aoo`00:goo00<005YF000015YF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P00
00=JEP00FUH015YF00<005YFFUH00eYF1P0000=JEP0000000eYF00<005YFFUH01UYF2`0015YF00H0
05YFFUH005YF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH2000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00=JEP03001J
EUYF00AJEP04001JEUYFFUH20006FUH01000FUIJEUYF4P0000MJEP00FUIJEP00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH200000eYF0000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEP00
0008FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30002FUH20005FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
0000;goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH30007FUH20006FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH200000eYF000000020005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP05001JEUYFFUH00005FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH20008FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH00`00FUH000040005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0
02]oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQH000=JEP03001JEUYF00=JEP04
001JEUYFFUH20005FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUIJEP050005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00:goo00<005YF000015YF00<005YFFUH00eYF1`0025YF1@0015YF
00@005YFFUIJEP800003FUH005YF00AJEP04001JEP000008FUH20003FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00FUH015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000AJEP03001JEUYF00=JEPH000Iooa4000IJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002]oo`03001JEP0000AJEP03001JEP0000<000IJ
EP03001JEUYF00IJEPD000AJEP03001JEUYF00=JEP<000AJEP800003FUH005YF00EJEP8000EJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP800003FUH005YF00AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUH000040003
FUH00`00Oomoo`0FOol40002FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000[Ool00`00FUH0
0003FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH40005FUH00`00FUIJEP05FUH400001EYF
001JEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00H005YF001JEP00FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000=JEP<000AJEP05001JEUYFFUH0000;Ool3000>Ool40004FUH01P00FUIJEP00FUH0
02eoo`00:goo00@005YF001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH01@00FUIJEUYF000025YF00<005YFFUH01UYF00<0
05YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP00008000MJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP07001JEUYF001JEP00FUH010001EYF00@005YFFUIJEP8000Uoo`D0015o
o`<00007FUH005YFFUH005YF0000;Goo000[Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYF0005FUH00`00FUH000060004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP0015YF0P002EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF00800003FUH005YF00<000=JEP04001JEUYF
FUH20009Ool5000DOol20002FUH00`00FUH0000]Ool002]oo`8000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000MJEP@0009J
EP03001JEP0000P000AJEP03001JEUYF009JEPL000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF009JEP@000=JEP8000Uo
o`D0019oo`80009JEP04001JEP00000^Ool002]oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP8000MJEP03001JEP000080009JEP03
001JEUYF00AJEP<00003FUH0000000L000EJEP03001JEUYF009JEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001J
EP0000D000Yoo`<000moo`@00003FUH005YF009JEP<002ioo`00:goo0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00001EYF
00H005YFFUH005YF0002FUH00`00FUIJEP03FUH50006FUH00`00FUIJEP04FUH20003FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH00`00
FUIJEP03FUH00`00FUIJEP03FUH7000BOol500000eYF000000030004FUH2000^Ool002aoo`05001J
EUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP06FUHA0002FUH01000FUIJEUYF0P000eYF0`00
0UYF00<005YFFUH00eYF1@001UYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF008000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF009JEQP000=JEP03001JEP0000D002ioo`00;7oo00D005YFFUIJ
EP0000EJEP03001JEUYF00h000AJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUH000020003
FUH30002FUH00`00FUIJEP03FUH50006FUH01000FUIJEUYF0P000eYF00@005YF000000aJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00003FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH01000FUIJEUYF2@000eYF00<005YFFUH015YF00@005YFFUIJ
EP@002ioo`00;Goo0P0000=JEP00FUH00eYF100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00001EYF00<005YFFUH01@0000Eoo`00FUIJEP0000IJEP<000MJEP04001JEUYF
0006FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00eYF1`0015YF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP@002ioo`00;goo0`0000=JEP0000001EYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P001EYF0P001EYF10000UYF00<005YFFUH015YF00<0
05YFFUH01eYF00<005YF00001UYF00@005YFFUH000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUH000030002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000aOol3
0006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUH00005FUH0
1000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01eYF0`001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000EJEP03001JEUYF
00=JEP@000IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEP0000800003
FUH007oo02eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YF00000UYF00@005YFFUH000EJEP04001JEUYF0002FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH01@00FUIJEUYF00000UYF0P0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YF00000`00
00=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF30000UYF00<005YF0000;Woo000^Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH0
05YF00000eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00AJEP80
00AJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP00009JEP<00003FUH0000000EJEP03001JEUYF00MJEP03001J
EUYF009JEPT000=JEP03001JEUYF00<00003FUH005YF00=JEP8002ioo`00;Goo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP00
00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20007FUH0
0`00FUIJEP05FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00004FUH30007FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP05FUH3
0004FUH00`00FUIJEP02FUH00`00Oomoo`0]Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJEP03
FUH01000FUIJEP000UYF00<005YFFUH015YF00D005YFFUIJEP0000MJEP8000QJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@00003FUH00000
009JEP03001JEUYF00EJEP03001JEUYF00@0009JEP@000EJEP03001JEUYF00=JEP800003FUH005YF
00EJEP05001JEUYFFUH0000_Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH015YF00<005YF00000P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P0015YF00<0
05YFFUH015YF1P0015YF1@0015YF00@005YFFUIJEP8000=JEP03001JEUYF00AJEP04001JEP00000`
Ool002eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH005YF00AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP04FUH2
0003FUH01000FUIJEUYF0P002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF10001UYF00@005YFFUIJEP8000Iooa4000EJEP03001JEUYF00AJ
EP80039oo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF6@0015YF00<005YF
FUH00eYF00@005YFFUH0009JEP03001JEUYF009JEP8000EJEP06001JEP00001JEP002eYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03
001JEUYF00AJEP03001JEP0000<000Yoo`T0009JEP03001JEUYF00EJEP04001JEUYFFUH2000dOol0
02eoo`03001JEP0000=JEP03001JEUYF00=JEQd0009JEPL000=JEP04001JEUYF0002FUH00`00FUH0
00020008FUH01@00FUIJEUYF00002eYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00P0015YF00<005YFFUH00UYF0`000UYF00<005YF00001goo1`00
1UYF00<005YFFUH01EYF00@005YF000003Ioo`00;Goo00<005YF00000eYF00<005YF00000`001UYF
00<005YFFUH01EYF1@001EYF00<005YFFUH00`001UYF1P000UYF1@0000=JEP00FUH01UYF0P0015YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00P0015YF00<005YF00000P001EYF00<005YF00001`0015YF00<005YFFUH01eYF00<0
05YFFUH00eYF0`00>7oo000]Ool00`00FUH00002FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH30006FUH01P00FUIJEUYF001JEP<0009JEP03001JEUYF00L000IJEP03001JEUYF009JEP8000IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF018000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<003]oo`00;Goo
00<005YF00000`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP<0009JEPH000=JEP03001JEUYF00IJEP03001JEUYF008000QJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000?goo000]Ool30000
0eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40009FUH00`00FUIJEP07FUHE0006FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01000@goo000]Ool50005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP04FUH01000FUIJEUYF1000
0eYF00<005YFFUH01eYF00@005YFFUIJEPH000IJEP03001JEUYF00YJEP03001JEP0000P000QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00UYF1`00Agoo000]Ool300000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH300000eYF001JEP03FUH70006FUH00`00FUIJEP05FUH7000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH60002FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF009JEPP004ioo`00;Woo0P001eYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01P0000AJEP00Ool0009JEP03001J
EUYF00AJEP03001JEUYF00D000IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF009JEP@000IJEP03001JEUYF009JEP<0009JEP04001JEUYFFUH800000eYF001oo`1COol0
02ioo`04001oo`000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUIJEUYF100000=JEP00FUH00P000UYF00<005YFFUH00eYF1@002UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF0P0015YF00<005YFFUH00UYF00<0
07ooOol01P0000Ioo`00000005YF0003FUH00`00Oomoo`1BOol002eoo`80009oo`<000=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000Aoo`800003FUH00000
009JEP04001JEUYFFUH20004FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH400000eYF001JEP03FUH00`00Oomoo`08Ool40003FUH2001COol0
02eoo`8000Eoo`L000AJEP03001JEUYF00IJEP03001JEUYF009JEPT000aoo`04001JEUYF0002FUH0
1000FUH000001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03001oogoo00Aoo`@00004FUH005YFFUH200000eYF
0000001COol002eoo`03001JEP0000]ooa8001Eoo`04001JEUYF0002FUH30007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20002FUH00`00Ool000040005FUH01000FUIJEUYF1000Dgoo000]Ool00`00FUH0000HOol3000H
Ool01@00FUH005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF1@000eYF00<005YFFUH015YF
00<005YFFUH00UYF0`00Dgoo000]Ool00`00FUH0000GOol5000GOol01000FUH000000eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0005=oo`00;Goo00@005YF000001Ioo`D001Qoo`<000=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJ
EP04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001COol002ioo`03001J
EP0001Ioo`D001Qoo`<000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00AJEP04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2001DOol002ioo`04001JEUYF000FOol3000JOol20003FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH00UYF00<0
07ooOol0Dgoo000^Ool01@00FUIJEUYF0000<Woo0P000eYF00<005YFFUH01EYF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF
00<005YF00001UYF00<005YFFUH00eYF00<005YFFUH00P00EWoo000_Ool01000FUIJEP00<Woo0P00
0eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH015YF0P001eYF00<005YFFUH00eYF0`00F7oo000_Ool01@00
FUIJEUYF0000<Goo00<005YF00000UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH015YF0P001eYF00<005YF
FUH00UYF0P00FWoo000`Ool00`00FUIJEP02000aOol50007FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20008FUH00`00
FUH00002001LOol0035oo`80009JEP03001oogoo02ioo`04001oogooOol20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF
10001UYF1000Ggoo000aOol20003FUH00`00Oomoo`0/Ool20005Ool40002FUH00`00FUIJEP08FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUH000000eYF
0P0000=JEP0000000P00Hgoo000bOol00`00FUIJEP02FUH00`00Oomoo`0[Ool20009Ool50008FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH400000eYF001JEP04
FUH2001VOol003=oo`03001JEUYF009JEP03001oogoo02Uoo`8000moo`H0009JEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00X000QJEP8006Aoo`00=7oo00<005YFFUH0
0UYF00<007ooOol09goo0`005Goo20001UYF00<005YFFUH02UYF00<005YFFUH015YF200015YF1P00
2EYF0`00HWoo000eOol01000FUIJEUYF0`009goo0P007Woo6P0027oo0P000UYF1@0000=JEP000000
1UYF00@005YFFUIJEP80061oo`00=Woo00<005YF00000eYF0P0097oo00<005YF0000@Woo0P0000AJ
EP00000000AJEP8000AJEP03001JEUYF00=JEP8005ioo`00=goo0P001EYF0P0087oo0P0000=JEP00
Ool0A7oo0P0025YF0P0000=JEP00FUH01eYF00<007ooOol0Fgoo000hOol00`00FUIJEP05FUH3000K
Ool200000eYF00000018Ool20006FUH01000FUH0000025YF0`00Fgoo000iOol20006FUH00`00FUH0
0003000EOol20002FUH00`00FUH0001:Ool20004FUH01000FUIJEUYF0P001EYF00@005YFFUIJEP80
05Uoo`00>goo0P000eYF00<005YFFUH015YF1`002Goo1@0015YF0P00CGoo0P0000=JEP00FUH01EYF
0P000eYF00<005YFFUH00eYF0P00Egoo000mOol200000eYF001JEP07FUH00`00FUIJEP02FUH90003
FUH00`00FUIJEP02FUH2001@Ool30007FUH30006FUH01000FUH00000EGoo000oOol30006FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EGoo0P0015YF00@005YFFUH000IJEP05001J
EUYFFUH0001DOol0049oo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEP00001IOol2
0002FUH01000FUIJEUYF0P000eYF00@005YFFUIJEP8005Aoo`00AWoo1`0015YF00<005YFFUH00UYF
1@00GGoo0`001EYF0P0000=JEP00FUH00UYF0P00E7oo001=Ool9001UOol20004FUH20003FUH2001E
Ool00;eoo`800004FUH005YFFUH200000eYF0000001EOol00;moo`<0009JEP<005Ioo`00`Woo1@00
EWoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]42\[InvisibleSpace]"     "\
\[InvisibleSpace]11.410790221356642`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 42, "     ", 11.410790221356642, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60132 .79874 m .59428 .75098 L .56321 .7506 L p .707 .577 .707 r
F P
0 g
s
.59428 .75098 m .60132 .79874 L .63286 .79357 L p .707 .577 .707 r
F P
0 g
s
.63286 .79357 m .62581 .74581 L .59428 .75098 L p .707 .577 .707 r
F P
0 g
s
.62581 .74581 m .63016 .77528 L p .649 .77001 L .707 .577 .707 r
F P
0 g
s
.63577 .77371 m .65947 .76898 L p .65794 .76751 L .707 .577 .707 r
F P
0 g
s
.65473 .73558 m .62581 .74581 L p .649 .77001 L .707 .577 .707 r
F P
0 g
s
.65947 .76898 m .65938 .76711 L p .65794 .76751 L .707 .577 .707 r
F P
0 g
s
.65947 .76898 m .68345 .76021 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.65473 .73558 m .65938 .76711 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.65938 .76711 m .65947 .76898 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.67819 .7213 m .65473 .73558 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.68345 .76021 m .68323 .75543 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.68345 .76021 m .69974 .74938 L p .69605 .74426 L .707 .577 .707 r
F P
0 g
s
.67819 .7213 m .68323 .75543 L p .6955 .74474 L .707 .577 .707 r
F P
0 g
s
.68323 .75543 m .68345 .76021 L p .69605 .74426 L .707 .577 .707 r
F P
0 g
s
.69391 .70437 m .67819 .7213 L p .6955 .74474 L .707 .577 .707 r
F P
0 g
s
.69974 .74938 m .69937 .74137 L p .69605 .74426 L .707 .577 .707 r
F P
0 g
s
.70096 .75213 m .70675 .73596 L p .70502 .72896 L .707 .577 .707 r
F P
0 g
s
.70655 .73235 m .70502 .72896 L .70675 .73596 L .707 .577 .707 r
F
.69809 .71368 m .69937 .74137 L p .70424 .73067 L F P
0 g
s
.69809 .71368 m .69639 .71481 L p .69741 .72388 L .707 .577 .707 r
F P
0 g
s
.69391 .70437 m .69937 .74137 L p .69566 .70824 L .707 .577 .707 r
F P
0 g
s
.69937 .74137 m .69391 .70437 L p .6955 .74474 L .707 .577 .707 r
F P
0 g
s
.69937 .74137 m .69809 .71368 L p .69605 .74426 L .707 .577 .707 r
F P
0 g
s
.69937 .74137 m .70096 .75213 L p .70502 .72896 L .707 .577 .707 r
F P
0 g
s
.70424 .73067 m .70469 .71561 L .69809 .71368 L .707 .577 .707 r
F
.70318 .70509 m .69809 .71368 L p .70469 .71561 L F P
0 g
s
.70622 .72632 m .70509 .70186 L p .70424 .73067 L .707 .577 .707 r
F P
0 g
s
.70622 .72632 m .70034 .68643 L p .70502 .72896 L .707 .577 .707 r
F P
0 g
s
.70739 .73419 m .70622 .72632 L p .70502 .72896 L .707 .577 .707 r
F P
0 g
s
.70674 .73756 m .70622 .72632 L p .70424 .73067 L .707 .577 .707 r
F P
0 g
s
.70034 .68643 m .69391 .70437 L p .70502 .72896 L .707 .577 .707 r
F P
0 g
s
.70502 .72896 m .69566 .70824 L .69937 .74137 L .707 .577 .707 r
F
.70674 .73756 m .70378 .7259 L p .70426 .71709 L F P
0 g
s
.70034 .68643 m .70622 .72632 L p .70348 .71345 L .707 .578 .707 r
F P
0 g
s
.70509 .70186 m .70318 .70509 L p .70469 .71561 L .707 .577 .707 r
F P
0 g
s
.70426 .71709 m .70499 .70377 L .70614 .72592 L .707 .577 .707 r
F
.70426 .71709 m .70614 .72592 L .70674 .73756 L F
.70622 .72632 m .70674 .73756 L p .70499 .70377 L F P
0 g
s
.70213 .6902 m .70509 .70186 L p .70426 .71709 L .707 .577 .707 r
F P
0 g
s
.70378 .7259 m .70312 .71175 L p .70426 .71709 L .707 .577 .707 r
F P
0 g
s
.69685 .66926 m .70034 .68643 L p .70348 .71345 L .707 .578 .707 r
F P
0 g
s
.70312 .71175 m .69685 .66926 L p .70348 .71345 L .707 .578 .707 r
F P
0 g
s
.70312 .71175 m .70213 .6902 L p .70426 .71709 L .707 .577 .707 r
F P
0 g
s
.7039 .71702 m .70312 .71175 L p .70348 .71345 L .707 .578 .707 r
F P
0 g
s
.7039 .71702 m .70348 .71345 L .70622 .72632 L .707 .578 .707 r
F
.70622 .72632 m .70739 .73419 L .70727 .73364 L p F P
0 g
s
.70727 .73364 m .7039 .71702 L p .70622 .72632 L .707 .578 .707 r
F P
0 g
s
.69605 .74426 m .69741 .72388 L .6818 .72451 L .707 .577 .707 r
F
.69639 .71481 m .6818 .72451 L p .69741 .72388 L F P
0 g
s
.70509 .70186 m .70622 .72632 L p .70499 .70377 L .707 .577 .707 r
F P
0 g
s
.70675 .73596 m .70739 .73419 L p .70655 .73235 L .707 .577 .707 r
F P
0 g
s
.70674 .73756 m .70424 .73067 L .69937 .74137 L .707 .577 .707 r
F
.69937 .74137 m .69974 .74938 L .69995 .74903 L p F P
0 g
s
.70096 .75213 m .69937 .74137 L p .7001 .75096 L .707 .577 .707 r
F P
0 g
s
.69995 .74903 m .70674 .73756 L p .69937 .74137 L .707 .577 .707 r
F P
0 g
s
.7001 .75096 m .69937 .74137 L .6955 .74474 L .707 .577 .707 r
F
.6818 .72451 m .68323 .75543 L p .69605 .74426 L F P
0 g
s
.68524 .76906 m .70096 .75213 L p .6955 .74474 L .707 .577 .707 r
F P
0 g
s
.68323 .75543 m .68524 .76906 L p .6955 .74474 L .707 .577 .707 r
F P
0 g
s
.68524 .76906 m .68323 .75543 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.68323 .75543 m .67819 .7213 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.6818 .72451 m .65782 .73328 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.68323 .75543 m .6818 .72451 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.65782 .73328 m .65938 .76711 L p .68027 .75687 L .707 .577 .707 r
F P
0 g
s
.66177 .78334 m .68524 .76906 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.65938 .76711 m .66177 .78334 L p .67603 .75895 L .707 .577 .707 r
F P
0 g
s
.66177 .78334 m .65938 .76711 L p .649 .77001 L .707 .577 .707 r
F P
0 g
s
.65938 .76711 m .65473 .73558 L p .649 .77001 L .707 .577 .707 r
F P
0 g
s
.65782 .73328 m .62849 .73913 L p .65794 .76751 L .707 .577 .707 r
F P
0 g
s
.65938 .76711 m .65782 .73328 L p .65794 .76751 L .707 .577 .707 r
F P
0 g
s
.62849 .73913 m .63014 .77483 L .63577 .77371 L p .707 .577 .707 r
F P
0 g
s
.65794 .76751 m .62849 .73913 L .63577 .77371 L .707 .577 .707 r
F
.63286 .79357 m .66177 .78334 L p .649 .77001 L F P
0 g
s
.63016 .77528 m .63286 .79357 L p .649 .77001 L .707 .577 .707 r
F P
0 g
s
.59834 .7772 m .59669 .7415 L .56553 .74015 L p .707 .577 .707 r
F P
0 g
s
.59669 .7415 m .59834 .7772 L .63014 .77483 L p .707 .577 .707 r
F P
0 g
s
.63014 .77483 m .62849 .73913 L .59669 .7415 L p .707 .577 .707 r
F P
0 g
s
.57026 .79836 m .56321 .7506 L .53565 .74469 L p .707 .577 .707 r
F P
0 g
s
.56321 .7506 m .57026 .79836 L .60132 .79874 L p .707 .577 .707 r
F P
0 g
s
.56718 .77585 m .56553 .74015 L .53806 .73521 L p .707 .577 .707 r
F P
0 g
s
.56553 .74015 m .56718 .77585 L .59834 .7772 L p .707 .577 .707 r
F P
0 g
s
.59024 .8804 m .59106 .86145 L .5599 .85899 L p .707 .577 .707 r
F P
0 g
s
.59106 .86145 m .59024 .8804 L .62204 .88126 L p .707 .577 .707 r
F P
0 g
s
.62204 .88126 m .62286 .8623 L .59106 .86145 L p .707 .577 .707 r
F P
0 g
s
.54269 .79245 m .53565 .74469 L .51429 .73384 L p .707 .577 .707 r
F P
0 g
s
.53565 .74469 m .54269 .79245 L .57026 .79836 L p .707 .577 .707 r
F P
0 g
s
.53806 .73521 m .53971 .77091 L .56718 .77585 L p .707 .577 .707 r
F P
0 g
s
.62286 .8623 m .62204 .88126 L .65136 .88041 L p .707 .577 .707 r
F P
0 g
s
.65136 .88041 m .65218 .86146 L .62286 .8623 L p .707 .577 .707 r
F P
0 g
s
.5599 .85899 m .55908 .87794 L .59024 .8804 L p .707 .577 .707 r
F P
0 g
s
.53971 .77091 m .53806 .73521 L .51697 .72716 L p .707 .577 .707 r
F P
0 g
s
.55908 .87794 m .5599 .85899 L .53243 .85516 L p .707 .577 .707 r
F P
0 g
s
.53243 .85516 m .53161 .87411 L .55908 .87794 L p .707 .577 .707 r
F P
0 g
s
.65218 .86146 m .65136 .88041 L .67535 .87796 L p .707 .577 .707 r
F P
0 g
s
.67535 .87796 m .67617 .859 L .65218 .86146 L p .707 .577 .707 r
F P
0 g
s
.51429 .73384 m .52134 .7816 L .54269 .79245 L p .707 .577 .707 r
F P
0 g
s
.51697 .72716 m .51862 .76286 L .53971 .77091 L p .707 .577 .707 r
F P
0 g
s
.51429 .73384 m .50123 .71911 L p .51396 .75866 L .707 .577 .707 r
F P
0 g
s
.51864 .76331 m .51429 .73384 L p .51396 .75866 L .707 .577 .707 r
F P
0 g
s
.50588 .75064 m .50597 .7525 L .50622 .75271 L p .707 .577 .707 r
F P
0 g
s
.50622 .75271 m .51619 .76087 L p .50588 .75064 L .707 .577 .707 r
F P
0 g
s
.50488 .74594 m .50588 .75064 L .49774 .70193 L .707 .578 .707 r
F
.50588 .75064 m .50123 .71911 L .49905 .70839 L p F P
0 g
s
.49905 .70839 m .49774 .70193 L p .50588 .75064 L .707 .578 .707 r
F P
0 g
s
.50828 .76687 m .52134 .7816 L p .50601 .73397 L .707 .577 .707 r
F P
0 g
s
.50123 .71911 m .50588 .75064 L p .50601 .73397 L .707 .577 .707 r
F P
0 g
s
.50588 .75064 m .50828 .76687 L p .50601 .73397 L .707 .577 .707 r
F P
0 g
s
.50432 .7168 m .50135 .70514 L p .50571 .74981 L .707 .577 .707 r
F P
0 g
s
.50597 .7525 m .50588 .75064 L p .50571 .74981 L .707 .577 .707 r
F P
0 g
s
.50588 .75064 m .50432 .7168 L p .50571 .74981 L .707 .577 .707 r
F P
0 g
s
.50597 .7525 m .50571 .74981 L .50278 .73606 L .707 .577 .707 r
F
.50305 .74105 m .50597 .7525 L p .50278 .73606 L F P
0 g
s
.50479 .74969 m .50828 .76687 L p .50488 .74594 L .707 .578 .707 r
F P
0 g
s
.50488 .74594 m .49898 .70956 L .50278 .73606 L .707 .578 .707 r
F
.50278 .73606 m .50479 .74969 L p .50488 .74594 L F P
0 g
s
.50135 .70514 m .50278 .73606 L p .50571 .74981 L .707 .577 .707 r
F P
0 g
s
.50432 .7168 m .50588 .75064 L p .51862 .76286 L .707 .577 .707 r
F P
0 g
s
.51862 .76286 m .51697 .72716 L .50432 .7168 L p .707 .577 .707 r
F P
0 g
s
.50135 .70514 m .50763 .69455 L p .50379 .73385 L .707 .577 .707 r
F P
0 g
s
.50663 .68136 m .51989 .66707 L p .50964 .72101 L .707 .577 .707 r
F P
0 g
s
.50763 .69455 m .50836 .69332 L p .50787 .69768 L .707 .577 .707 r
F P
0 g
s
.50379 .73385 m .50763 .69455 L .50787 .69768 L .707 .577 .707 r
F
.51306 .71802 m .50964 .72101 L .51989 .66707 L F
.5104 .72778 m .50964 .72101 L .51362 .71754 L F
.50828 .76687 m .50588 .75064 L p .50488 .74594 L .707 .578 .707 r
F P
0 g
s
.51093 .73257 m .50479 .74969 L p .50964 .72101 L .707 .577 .707 r
F P
0 g
s
.51001 .72902 m .50964 .72101 L p .5104 .72778 L .707 .577 .707 r
F P
0 g
s
.50479 .74969 m .50463 .73201 L .50964 .72101 L .707 .577 .707 r
F
.50479 .74969 m .50278 .73606 L p .50463 .73201 L F P
0 g
s
.50278 .73606 m .503 .74084 L .50305 .74105 L p .707 .577 .707 r
F P
0 g
s
.51001 .72902 m .503 .74084 L p .50379 .73385 L .707 .577 .707 r
F P
0 g
s
.50836 .69332 m .50964 .72101 L p .50379 .73385 L .707 .577 .707 r
F P
0 g
s
.50964 .72101 m .51001 .72902 L p .50379 .73385 L .707 .577 .707 r
F P
0 g
s
.50418 .684 m .50964 .72101 L p .50463 .73201 L .707 .577 .707 r
F P
0 g
s
.5263 .71819 m .51001 .72902 L p .51362 .71754 L .707 .577 .707 r
F P
0 g
s
.52578 .70695 m .5263 .71819 L p .51362 .71754 L .707 .577 .707 r
F P
0 g
s
.51989 .66707 m .54336 .65279 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.5263 .71819 m .52578 .70695 L p .53395 .70295 L .707 .577 .707 r
F P
0 g
s
.52694 .71483 m .52578 .70695 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.52578 .70695 m .51989 .66707 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.54336 .65279 m .57227 .64256 L p .55272 .69441 L .707 .577 .707 r
F P
0 g
s
.57227 .64256 m .60381 .63738 L p .58092 .68685 L .707 .577 .707 r
F P
0 g
s
.60381 .63738 m .63488 .63777 L p .6118 .68329 L .707 .577 .707 r
F P
0 g
s
.63488 .63777 m .66244 .64367 L p .64255 .68426 L .707 .577 .707 r
F P
0 g
s
.66244 .64367 m .68379 .65453 L p .67007 .68993 L .707 .577 .707 r
F P
0 g
s
.68379 .65453 m .69685 .66926 L p .69126 .69996 L .707 .577 .707 r
F P
0 g
s
.69113 .71554 m .69037 .69907 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.70378 .7259 m .69113 .71554 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.70312 .71175 m .70378 .7259 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.7039 .71702 m .69084 .70229 L p .69126 .69996 L .707 .577 .707 r
F P
0 g
s
.69685 .66926 m .70312 .71175 L p .69126 .69996 L .707 .577 .707 r
F P
0 g
s
.70312 .71175 m .7039 .71702 L p .69126 .69996 L .707 .577 .707 r
F P
0 g
s
.70213 .6902 m .70312 .71175 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.68948 .67984 m .70213 .6902 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.69082 .69952 m .68379 .65453 L .69126 .69996 L .707 .577 .707 r
F
.69037 .69907 m .68379 .65453 L p .69106 .70108 L F P
0 g
s
.69037 .69907 m .68948 .67984 L p .69589 .70456 L .707 .577 .707 r
F P
0 g
s
.69106 .70108 m .69082 .69952 L .69126 .69996 L .707 .577 .707 r
F
.69084 .70229 m .69037 .69907 L p .69106 .70108 L F P
0 g
s
.67004 .70749 m .66921 .68955 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.69113 .71554 m .67004 .70749 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.69037 .69907 m .69113 .71554 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.69084 .70229 m .66949 .69143 L p .67007 .68993 L .707 .577 .707 r
F P
0 g
s
.68379 .65453 m .69037 .69907 L p .67007 .68993 L .707 .577 .707 r
F P
0 g
s
.69037 .69907 m .69084 .70229 L p .67007 .68993 L .707 .577 .707 r
F P
0 g
s
.68948 .67984 m .69037 .69907 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.66839 .67179 m .68283 .6773 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.68283 .6773 m .68948 .67984 L p .68561 .68534 L .707 .577 .707 r
F P
0 g
s
.67942 .69414 m .68283 .6773 L .68561 .68534 L .707 .577 .707 r
F
.66967 .68976 m .66244 .64367 L .67007 .68993 L F
.66921 .68955 m .66244 .64367 L p .66981 .69061 L F P
0 g
s
.66921 .68955 m .66839 .67179 L p .67942 .69414 L .707 .577 .707 r
F P
0 g
s
.66981 .69061 m .66967 .68976 L .67007 .68993 L .707 .577 .707 r
F
.66949 .69143 m .66921 .68955 L p .66981 .69061 L F P
0 g
s
.64257 .70255 m .64171 .68409 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.67004 .70749 m .64257 .70255 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.66921 .68955 m .67004 .70749 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.66949 .69143 m .64192 .68553 L p .64255 .68426 L .707 .577 .707 r
F P
0 g
s
.66244 .64367 m .66921 .68955 L p .64255 .68426 L .707 .577 .707 r
F P
0 g
s
.66921 .68955 m .66949 .69143 L p .64255 .68426 L .707 .577 .707 r
F P
0 g
s
.66839 .67179 m .66921 .68955 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.64092 .66685 m .65818 .66996 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.65818 .66996 m .66839 .67179 L p .6629 .67834 L .707 .577 .707 r
F P
0 g
s
.65573 .68687 m .65818 .66996 L .6629 .67834 L .707 .577 .707 r
F
.64217 .68418 m .63488 .63777 L .64255 .68426 L F
.64171 .68409 m .63488 .63777 L p .64227 .68482 L F P
0 g
s
.64171 .68409 m .64092 .66685 L p .65573 .68687 L .707 .577 .707 r
F P
0 g
s
.64227 .68482 m .64217 .68418 L .64255 .68426 L .707 .577 .707 r
F
.64192 .68553 m .64171 .68409 L p .64227 .68482 L F P
0 g
s
.61141 .7012 m .61058 .68325 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.64257 .70255 m .61141 .7012 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.64171 .68409 m .64257 .70255 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.64192 .68553 m .61086 .68514 L p .6118 .68329 L .707 .577 .707 r
F P
0 g
s
.63488 .63777 m .64171 .68409 L p .6118 .68329 L .707 .577 .707 r
F P
0 g
s
.64171 .68409 m .64192 .68553 L p .6118 .68329 L .707 .577 .707 r
F P
0 g
s
.64092 .66685 m .64171 .68409 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.60976 .6655 m .62816 .6663 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.62816 .6663 m .64092 .66685 L p .63438 .67446 L .707 .577 .707 r
F P
0 g
s
.62646 .68368 m .62816 .6663 L .63438 .67446 L .707 .577 .707 r
F
.61122 .68327 m .60381 .63738 L .6118 .68329 L F
.61058 .68325 m .60381 .63738 L p .61136 .68415 L F P
0 g
s
.61058 .68325 m .60976 .6655 L p .62646 .68368 L .707 .577 .707 r
F P
0 g
s
.61136 .68415 m .61122 .68327 L .6118 .68329 L .707 .577 .707 r
F
.61086 .68514 m .61058 .68325 L p .61136 .68415 L F P
0 g
s
.57961 .70357 m .57885 .6871 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.61141 .7012 m .57961 .70357 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.61058 .68325 m .61141 .7012 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.61086 .68514 m .57932 .69032 L p .58092 .68685 L .707 .577 .707 r
F P
0 g
s
.60381 .63738 m .61058 .68325 L p .58092 .68685 L .707 .577 .707 r
F P
0 g
s
.61058 .68325 m .61086 .68514 L p .58092 .68685 L .707 .577 .707 r
F P
0 g
s
.60976 .6655 m .61058 .68325 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.57796 .66787 m .59604 .66652 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.59604 .66652 m .60976 .6655 L p .60279 .67429 L .707 .577 .707 r
F P
0 g
s
.59411 .68525 m .59604 .66652 L .60279 .67429 L .707 .577 .707 r
F
.57981 .68699 m .57227 .64256 L .58092 .68685 L F
.57885 .6871 m .57227 .64256 L p .58009 .68865 L F P
0 g
s
.57885 .6871 m .57796 .66787 L p .59411 .68525 L .707 .577 .707 r
F P
0 g
s
.58009 .68865 m .57981 .68699 L .58092 .68685 L .707 .577 .707 r
F
.57932 .69032 m .57885 .6871 L p .58009 .68865 L F P
0 g
s
.55028 .70942 m .54963 .69527 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.57961 .70357 m .55028 .70942 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.57885 .6871 m .57961 .70357 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.57932 .69032 m .5504 .70055 L p .55272 .69441 L .707 .577 .707 r
F P
0 g
s
.57227 .64256 m .57885 .6871 L p .55272 .69441 L .707 .577 .707 r
F P
0 g
s
.57885 .6871 m .57932 .69032 L p .55272 .69441 L .707 .577 .707 r
F P
0 g
s
.57796 .66787 m .57885 .6871 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.54863 .67372 m .56541 .67037 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.56541 .67037 m .57796 .66787 L p .57136 .67778 L .707 .577 .707 r
F P
0 g
s
.56201 .69181 m .56541 .67037 L .57136 .67778 L .707 .577 .707 r
F
.55071 .69497 m .54336 .65279 L .55272 .69441 L F
.54963 .69527 m .54336 .65279 L p .55128 .69824 L F P
0 g
s
.54963 .69527 m .54863 .67372 L p .56201 .69181 L .707 .577 .707 r
F P
0 g
s
.55128 .69824 m .55071 .69497 L .55272 .69441 L .707 .577 .707 r
F
.5504 .70055 m .54963 .69527 L p .55128 .69824 L F P
0 g
s
.55028 .70942 m .5263 .71819 L p .53395 .70295 L .707 .577 .707 r
F P
0 g
s
.54963 .69527 m .55028 .70942 L p .53395 .70295 L .707 .577 .707 r
F P
0 g
s
.5504 .70055 m .52694 .71483 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.54336 .65279 m .54963 .69527 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.54963 .69527 m .5504 .70055 L p .52951 .70513 L .707 .577 .707 r
F P
0 g
s
.54863 .67372 m .54963 .69527 L p .53395 .70295 L .707 .577 .707 r
F P
0 g
s
.53395 .70295 m .52578 .70695 L .54256 .68255 L .707 .577 .707 r
F
.54342 .6841 m .54256 .68255 L .54863 .67372 L F
.53395 .70295 m .54256 .68255 L .54342 .6841 L F
.52578 .70695 m .52465 .68249 L .5268 .6817 L p F P
0 g
s
.5268 .6817 m .54863 .67372 L p .52578 .70695 L .707 .577 .707 r
F P
0 g
s
.51122 .73176 m .51306 .71802 L .52544 .71517 L .707 .577 .707 r
F
.52694 .71483 m .52539 .7165 L p .52544 .71517 L F P
0 g
s
.52539 .7165 m .51122 .73176 L p .52544 .71517 L .707 .577 .707 r
F P
0 g
s
.51989 .66707 m .52578 .70695 L p .51306 .71802 L .707 .577 .707 r
F P
0 g
s
.52578 .70695 m .52694 .71483 L p .51306 .71802 L .707 .577 .707 r
F P
0 g
s
.52465 .68249 m .52578 .70695 L p .51362 .71754 L .707 .577 .707 r
F P
0 g
s
.50964 .72101 m .51122 .73176 L .51093 .73257 L p .707 .577 .707 r
F P
0 g
s
.50836 .69332 m .52465 .68249 L p .51362 .71754 L .707 .577 .707 r
F P
0 g
s
.50964 .72101 m .50836 .69332 L p .51362 .71754 L .707 .577 .707 r
F P
0 g
s
.51122 .73176 m .50964 .72101 L p .51306 .71802 L .707 .577 .707 r
F P
0 g
s
.50964 .72101 m .50418 .684 L .50663 .68136 L p .707 .577 .707 r
F P
0 g
s
.50302 .73555 m .50135 .70514 L .50379 .73385 L .707 .577 .707 r
F
.50278 .73606 m .50135 .70514 L p .50321 .73903 L F P
0 g
s
.50463 .73201 m .50278 .73606 L .50418 .684 L .707 .577 .707 r
F
.50321 .73903 m .50302 .73555 L .50379 .73385 L F
.503 .74084 m .50278 .73606 L p .50321 .73903 L F P
0 g
s
.49774 .70193 m .50278 .73606 L p .49898 .70956 L .707 .578 .707 r
F P
0 g
s
.50278 .73606 m .49774 .70193 L .50049 .69427 L p .707 .577 .707 r
F P
0 g
s
.50049 .69427 m .50418 .684 L p .50278 .73606 L .707 .577 .707 r
F P
0 g
s
.51619 .76087 m .51862 .76286 L p .50588 .75064 L .707 .577 .707 r
F P
0 g
s
.52134 .7816 m .51864 .76331 L p .51396 .75866 L .707 .577 .707 r
F P
0 g
s
.53161 .87411 m .53243 .85516 L .51134 .85033 L p .707 .577 .707 r
F P
0 g
s
.51134 .85033 m .51052 .86929 L .53161 .87411 L p .707 .577 .707 r
F P
0 g
s
.67617 .859 m .67535 .87796 L .69164 .87413 L p .707 .577 .707 r
F P
0 g
s
.69164 .87413 m .69246 .85518 L .67617 .859 L p .707 .577 .707 r
F P
0 g
s
.51052 .86929 m .51134 .85033 L .49869 .84498 L p .707 .577 .707 r
F P
0 g
s
.49869 .84498 m .49787 .86394 L .51052 .86929 L p .707 .577 .707 r
F P
0 g
s
.69246 .85518 m .69164 .87413 L .69865 .86931 L p .707 .577 .707 r
F P
0 g
s
.69865 .86931 m .69946 .85036 L .69246 .85518 L p .707 .577 .707 r
F P
0 g
s
.49378 .82166 m .49071 .32189 L .4467 .31932 L p .707 .577 .707 r
F P
0 g
s
.49071 .32189 m .49378 .82166 L .53873 .82025 L p .707 .577 .707 r
F P
0 g
s
.53873 .82025 m .53565 .32048 L .49071 .32189 L p .707 .577 .707 r
F P
0 g
s
.53565 .32048 m .53873 .82025 L .5802 .81499 L p .707 .577 .707 r
F P
0 g
s
.5802 .81499 m .57713 .31523 L .53565 .32048 L p .707 .577 .707 r
F P
0 g
s
.49787 .86394 m .49869 .84498 L .49572 .83964 L p .707 .577 .707 r
F P
0 g
s
.49572 .83964 m .4949 .85859 L .49787 .86394 L p .707 .577 .707 r
F P
0 g
s
.44977 .81908 m .4467 .31932 L .40794 .31301 L p .707 .577 .707 r
F P
0 g
s
.4467 .31932 m .44977 .81908 L .49378 .82166 L p .707 .577 .707 r
F P
0 g
s
.57713 .31523 m .5802 .81499 L .61416 .8064 L p .707 .577 .707 r
F P
0 g
s
.61416 .8064 m .61109 .30664 L .57713 .31523 L p .707 .577 .707 r
F P
0 g
s
.69946 .85036 m .69865 .86931 L .69568 .86396 L p .707 .577 .707 r
F P
0 g
s
.69568 .86396 m .6965 .84501 L .69946 .85036 L p .707 .577 .707 r
F P
0 g
s
.41101 .81277 m .40794 .31301 L .37821 .30359 L p .707 .577 .707 r
F P
0 g
s
.40794 .31301 m .41101 .81277 L .44977 .81908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.4949 .85859 m .49572 .83964 L .50273 .83481 L p .707 .577 .707 r
F P
0 g
s
.50273 .83481 m .50191 .85377 L .4949 .85859 L p .707 .577 .707 r
F P
0 g
s
.25832 .76193 m .25127 .71417 L .2202 .71378 L p .707 .577 .707 r
F P
0 g
s
.25127 .71417 m .25832 .76193 L .28985 .75675 L p .707 .577 .707 r
F P
0 g
s
.28985 .75675 m .2828 .70899 L .25127 .71417 L p .707 .577 .707 r
F P
0 g
s
.2828 .70899 m .28715 .73846 L p .30599 .7332 L .707 .577 .707 r
F P
0 g
s
.29276 .73689 m .31646 .73216 L p .31493 .7307 L .707 .577 .707 r
F P
0 g
s
.31172 .69877 m .2828 .70899 L p .30599 .7332 L .707 .577 .707 r
F P
0 g
s
.31646 .73216 m .31637 .7303 L p .31493 .7307 L .707 .577 .707 r
F P
0 g
s
.31646 .73216 m .34044 .72339 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.31172 .69877 m .31637 .7303 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.31637 .7303 m .31646 .73216 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.33518 .68449 m .31172 .69877 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.34044 .72339 m .34022 .71861 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.34044 .72339 m .35673 .71257 L p .35304 .70745 L .707 .577 .707 r
F P
0 g
s
.33518 .68449 m .34022 .71861 L p .35249 .70793 L .707 .577 .707 r
F P
0 g
s
.34022 .71861 m .34044 .72339 L p .35304 .70745 L .707 .577 .707 r
F P
0 g
s
.3509 .66755 m .33518 .68449 L p .35249 .70793 L .707 .577 .707 r
F P
0 g
s
.35673 .71257 m .35636 .70456 L p .35304 .70745 L .707 .577 .707 r
F P
0 g
s
.35795 .71531 m .36374 .69915 L p .36201 .69215 L .707 .577 .707 r
F P
0 g
s
.36355 .69554 m .36201 .69215 L .36374 .69915 L .707 .577 .707 r
F
.35508 .67687 m .35636 .70456 L p .36124 .69385 L F P
0 g
s
.35508 .67687 m .35338 .67799 L p .3544 .68706 L .707 .577 .707 r
F P
0 g
s
.3509 .66755 m .35636 .70456 L p .35265 .67142 L .707 .577 .707 r
F P
0 g
s
.35636 .70456 m .3509 .66755 L p .35249 .70793 L .707 .577 .707 r
F P
0 g
s
.35636 .70456 m .35508 .67687 L p .35304 .70745 L .707 .577 .707 r
F P
0 g
s
.35636 .70456 m .35795 .71531 L p .36201 .69215 L .707 .577 .707 r
F P
0 g
s
.36124 .69385 m .36168 .6788 L .35508 .67687 L .707 .577 .707 r
F
.36017 .66827 m .35508 .67687 L p .36168 .6788 L F P
0 g
s
.36322 .68951 m .36209 .66504 L p .36124 .69385 L .707 .577 .707 r
F P
0 g
s
.36322 .68951 m .35733 .64962 L p .36201 .69215 L .707 .577 .707 r
F P
0 g
s
.36438 .69738 m .36322 .68951 L p .36201 .69215 L .707 .577 .707 r
F P
0 g
s
.36373 .70074 m .36322 .68951 L p .36124 .69385 L .707 .577 .707 r
F P
0 g
s
.35733 .64962 m .3509 .66755 L p .36201 .69215 L .707 .577 .707 r
F P
0 g
s
.36201 .69215 m .35265 .67142 L .35636 .70456 L .707 .577 .707 r
F
.36373 .70074 m .36077 .68908 L p .36125 .68027 L F P
0 g
s
.35733 .64962 m .36322 .68951 L p .36048 .67663 L .707 .578 .707 r
F P
0 g
s
.36209 .66504 m .36017 .66827 L p .36168 .6788 L .707 .577 .707 r
F P
0 g
s
.36125 .68027 m .36198 .66695 L .36313 .68911 L .707 .577 .707 r
F
.36125 .68027 m .36313 .68911 L .36373 .70074 L F
.36322 .68951 m .36373 .70074 L p .36198 .66695 L F P
0 g
s
.35912 .65338 m .36209 .66504 L p .36125 .68027 L .707 .577 .707 r
F P
0 g
s
.36077 .68908 m .36011 .67493 L p .36125 .68027 L .707 .577 .707 r
F P
0 g
s
.35384 .63244 m .35733 .64962 L p .36048 .67663 L .707 .578 .707 r
F P
0 g
s
.36011 .67493 m .35384 .63244 L p .36048 .67663 L .707 .578 .707 r
F P
0 g
s
.36011 .67493 m .35912 .65338 L p .36125 .68027 L .707 .577 .707 r
F P
0 g
s
.36089 .6802 m .36011 .67493 L p .36048 .67663 L .707 .578 .707 r
F P
0 g
s
.36089 .6802 m .36048 .67663 L .36322 .68951 L .707 .578 .707 r
F
.36322 .68951 m .36438 .69738 L .36426 .69682 L p F P
0 g
s
.36426 .69682 m .36089 .6802 L p .36322 .68951 L .707 .578 .707 r
F P
0 g
s
.35304 .70745 m .3544 .68706 L .33879 .68769 L .707 .577 .707 r
F
.35338 .67799 m .33879 .68769 L p .3544 .68706 L F P
0 g
s
.36209 .66504 m .36322 .68951 L p .36198 .66695 L .707 .577 .707 r
F P
0 g
s
.36374 .69915 m .36438 .69738 L p .36355 .69554 L .707 .577 .707 r
F P
0 g
s
.36373 .70074 m .36124 .69385 L .35636 .70456 L .707 .577 .707 r
F
.35636 .70456 m .35673 .71257 L .35694 .71221 L p F P
0 g
s
.35795 .71531 m .35636 .70456 L p .35709 .71415 L .707 .577 .707 r
F P
0 g
s
.35694 .71221 m .36373 .70074 L p .35636 .70456 L .707 .577 .707 r
F P
0 g
s
.35709 .71415 m .35636 .70456 L .35249 .70793 L .707 .577 .707 r
F
.33879 .68769 m .34022 .71861 L p .35304 .70745 L F P
0 g
s
.34223 .73225 m .35795 .71531 L p .35249 .70793 L .707 .577 .707 r
F P
0 g
s
.34022 .71861 m .34223 .73225 L p .35249 .70793 L .707 .577 .707 r
F P
0 g
s
.34223 .73225 m .34022 .71861 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.34022 .71861 m .33518 .68449 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.33879 .68769 m .31481 .69646 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.34022 .71861 m .33879 .68769 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.31481 .69646 m .31637 .7303 L p .33727 .72006 L .707 .577 .707 r
F P
0 g
s
.31877 .74653 m .34223 .73225 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.31637 .7303 m .31877 .74653 L p .33302 .72214 L .707 .577 .707 r
F P
0 g
s
.31877 .74653 m .31637 .7303 L p .30599 .7332 L .707 .577 .707 r
F P
0 g
s
.31637 .7303 m .31172 .69877 L p .30599 .7332 L .707 .577 .707 r
F P
0 g
s
.31481 .69646 m .28548 .70232 L p .31493 .7307 L .707 .577 .707 r
F P
0 g
s
.31637 .7303 m .31481 .69646 L p .31493 .7307 L .707 .577 .707 r
F P
0 g
s
.28548 .70232 m .28713 .73802 L .29276 .73689 L p .707 .577 .707 r
F P
0 g
s
.31493 .7307 m .28548 .70232 L .29276 .73689 L .707 .577 .707 r
F
.28985 .75675 m .31877 .74653 L p .30599 .7332 L F P
0 g
s
.28715 .73846 m .28985 .75675 L p .30599 .7332 L .707 .577 .707 r
F P
0 g
s
.25533 .74039 m .25368 .70468 L .22252 .70333 L p .707 .577 .707 r
F P
0 g
s
.25368 .70468 m .25533 .74039 L .28713 .73802 L p .707 .577 .707 r
F P
0 g
s
.28713 .73802 m .28548 .70232 L .25368 .70468 L p .707 .577 .707 r
F P
0 g
s
.22725 .76154 m .2202 .71378 L .19264 .70788 L p .707 .577 .707 r
F P
0 g
s
.2202 .71378 m .22725 .76154 L .25832 .76193 L p .707 .577 .707 r
F P
0 g
s
.61109 .30664 m .61416 .8064 L .63727 .79532 L p .707 .577 .707 r
F P
0 g
s
.63727 .79532 m .6342 .29556 L .61109 .30664 L p .707 .577 .707 r
F P
0 g
s
.22417 .73903 m .22252 .70333 L .19505 .69839 L p .707 .577 .707 r
F P
0 g
s
.22252 .70333 m .22417 .73903 L .25533 .74039 L p .707 .577 .707 r
F P
0 g
s
.6965 .84501 m .69568 .86396 L .68303 .85862 L p .707 .577 .707 r
F P
0 g
s
.68303 .85862 m .68385 .83966 L .6965 .84501 L p .707 .577 .707 r
F P
0 g
s
.24723 .84359 m .24805 .82463 L .21689 .82217 L p .707 .577 .707 r
F P
0 g
s
.24805 .82463 m .24723 .84359 L .27903 .84444 L p .707 .577 .707 r
F P
0 g
s
.27903 .84444 m .27985 .82549 L .24805 .82463 L p .707 .577 .707 r
F P
0 g
s
.19969 .75564 m .19264 .70788 L .17128 .69702 L p .707 .577 .707 r
F P
0 g
s
.19264 .70788 m .19969 .75564 L .22725 .76154 L p .707 .577 .707 r
F P
0 g
s
.38128 .80335 m .37821 .30359 L .36043 .29197 L p .707 .577 .707 r
F P
0 g
s
.37821 .30359 m .38128 .80335 L .41101 .81277 L p .707 .577 .707 r
F P
0 g
s
.19505 .69839 m .1967 .73409 L .22417 .73903 L p .707 .577 .707 r
F P
0 g
s
.27985 .82549 m .27903 .84444 L .30836 .8436 L p .707 .577 .707 r
F P
0 g
s
.30836 .8436 m .30918 .82464 L .27985 .82549 L p .707 .577 .707 r
F P
0 g
s
.21689 .82217 m .21607 .84113 L .24723 .84359 L p .707 .577 .707 r
F P
0 g
s
.1967 .73409 m .19505 .69839 L .17396 .69035 L p .707 .577 .707 r
F P
0 g
s
.50191 .85377 m .50273 .83481 L .51902 .83099 L p .707 .577 .707 r
F P
0 g
s
.21607 .84113 m .21689 .82217 L .18942 .81834 L p .707 .577 .707 r
F P
0 g
s
.51902 .83099 m .5182 .84994 L .50191 .85377 L p .707 .577 .707 r
F P
0 g
s
.18942 .81834 m .1886 .8373 L .21607 .84113 L p .707 .577 .707 r
F P
0 g
s
.30918 .82464 m .30836 .8436 L .33234 .84114 L p .707 .577 .707 r
F P
0 g
s
.33234 .84114 m .33316 .82219 L .30918 .82464 L p .707 .577 .707 r
F P
0 g
s
.17128 .69702 m .17833 .74479 L .19969 .75564 L p .707 .577 .707 r
F P
0 g
s
.17396 .69035 m .17561 .72605 L .1967 .73409 L p .707 .577 .707 r
F P
0 g
s
.17128 .69702 m .15822 .68229 L p .17095 .72184 L .707 .577 .707 r
F P
0 g
s
.17563 .72649 m .17128 .69702 L p .17095 .72184 L .707 .577 .707 r
F P
0 g
s
.16287 .71382 m .16296 .71569 L .16321 .71589 L p .707 .577 .707 r
F P
0 g
s
.16321 .71589 m .17318 .72406 L p .16287 .71382 L .707 .577 .707 r
F P
0 g
s
.16187 .70912 m .16287 .71382 L .15474 .66512 L .707 .578 .707 r
F
.16287 .71382 m .15822 .68229 L .15605 .67157 L p F P
0 g
s
.15605 .67157 m .15474 .66512 L p .16287 .71382 L .707 .578 .707 r
F P
0 g
s
.16527 .73005 m .17833 .74479 L p .163 .69716 L .707 .577 .707 r
F P
0 g
s
.15822 .68229 m .16287 .71382 L p .163 .69716 L .707 .577 .707 r
F P
0 g
s
.16287 .71382 m .16527 .73005 L p .163 .69716 L .707 .577 .707 r
F P
0 g
s
.16131 .67999 m .15834 .66833 L p .1627 .71299 L .707 .577 .707 r
F P
0 g
s
.16296 .71569 m .16287 .71382 L p .1627 .71299 L .707 .577 .707 r
F P
0 g
s
.16287 .71382 m .16131 .67999 L p .1627 .71299 L .707 .577 .707 r
F P
0 g
s
.16296 .71569 m .1627 .71299 L .15977 .69925 L .707 .577 .707 r
F
.16005 .70423 m .16296 .71569 L p .15977 .69925 L F P
0 g
s
.16178 .71288 m .16527 .73005 L p .16187 .70912 L .707 .578 .707 r
F P
0 g
s
.16187 .70912 m .15597 .67275 L .15977 .69925 L .707 .578 .707 r
F
.15977 .69925 m .16178 .71288 L p .16187 .70912 L F P
0 g
s
.15834 .66833 m .15977 .69925 L p .1627 .71299 L .707 .577 .707 r
F P
0 g
s
.16131 .67999 m .16287 .71382 L p .17561 .72605 L .707 .577 .707 r
F P
0 g
s
.17561 .72605 m .17396 .69035 L .16131 .67999 L p .707 .577 .707 r
F P
0 g
s
.15834 .66833 m .16462 .65773 L p .16078 .69703 L .707 .577 .707 r
F P
0 g
s
.16362 .64454 m .17688 .63025 L p .16663 .68419 L .707 .577 .707 r
F P
0 g
s
.16462 .65773 m .16535 .6565 L p .16486 .66087 L .707 .577 .707 r
F P
0 g
s
.16078 .69703 m .16462 .65773 L .16486 .66087 L .707 .577 .707 r
F
.17006 .68121 m .16663 .68419 L .17688 .63025 L F
.16739 .69097 m .16663 .68419 L .17061 .68073 L F
.16527 .73005 m .16287 .71382 L p .16187 .70912 L .707 .578 .707 r
F P
0 g
s
.16792 .69576 m .16178 .71288 L p .16663 .68419 L .707 .577 .707 r
F P
0 g
s
.167 .6922 m .16663 .68419 L p .16739 .69097 L .707 .577 .707 r
F P
0 g
s
.16178 .71288 m .16162 .69519 L .16663 .68419 L .707 .577 .707 r
F
.16178 .71288 m .15977 .69925 L p .16162 .69519 L F P
0 g
s
.15977 .69925 m .15999 .70403 L .16005 .70423 L p .707 .577 .707 r
F P
0 g
s
.167 .6922 m .15999 .70403 L p .16078 .69703 L .707 .577 .707 r
F P
0 g
s
.16535 .6565 m .16663 .68419 L p .16078 .69703 L .707 .577 .707 r
F P
0 g
s
.16663 .68419 m .167 .6922 L p .16078 .69703 L .707 .577 .707 r
F P
0 g
s
.16117 .64719 m .16663 .68419 L p .16162 .69519 L .707 .577 .707 r
F P
0 g
s
.18329 .68138 m .167 .6922 L p .17061 .68073 L .707 .577 .707 r
F P
0 g
s
.18277 .67014 m .18329 .68138 L p .17061 .68073 L .707 .577 .707 r
F P
0 g
s
.17688 .63025 m .20035 .61597 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.18329 .68138 m .18277 .67014 L p .19094 .66613 L .707 .577 .707 r
F P
0 g
s
.18393 .67801 m .18277 .67014 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.18277 .67014 m .17688 .63025 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.20035 .61597 m .22926 .60574 L p .20971 .65759 L .707 .577 .707 r
F P
0 g
s
.22926 .60574 m .2608 .60057 L p .23791 .65004 L .707 .577 .707 r
F P
0 g
s
.2608 .60057 m .29187 .60095 L p .26879 .64647 L .707 .577 .707 r
F P
0 g
s
.29187 .60095 m .31943 .60686 L p .29954 .64744 L .707 .577 .707 r
F P
0 g
s
.31943 .60686 m .34078 .61771 L p .32706 .65312 L .707 .577 .707 r
F P
0 g
s
.34078 .61771 m .35384 .63244 L p .34825 .66315 L .707 .577 .707 r
F P
0 g
s
.34812 .67872 m .34736 .66226 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.36077 .68908 m .34812 .67872 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.36011 .67493 m .36077 .68908 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.36089 .6802 m .34783 .66547 L p .34825 .66315 L .707 .577 .707 r
F P
0 g
s
.35384 .63244 m .36011 .67493 L p .34825 .66315 L .707 .577 .707 r
F P
0 g
s
.36011 .67493 m .36089 .6802 L p .34825 .66315 L .707 .577 .707 r
F P
0 g
s
.35912 .65338 m .36011 .67493 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.34647 .64302 m .35912 .65338 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.34781 .66271 m .34078 .61771 L .34825 .66315 L .707 .577 .707 r
F
.34736 .66226 m .34078 .61771 L p .34805 .66426 L F P
0 g
s
.34736 .66226 m .34647 .64302 L p .35288 .66775 L .707 .577 .707 r
F P
0 g
s
.34805 .66426 m .34781 .66271 L .34825 .66315 L .707 .577 .707 r
F
.34783 .66547 m .34736 .66226 L p .34805 .66426 L F P
0 g
s
.32703 .67068 m .3262 .65273 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.34812 .67872 m .32703 .67068 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.34736 .66226 m .34812 .67872 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.34783 .66547 m .32648 .65462 L p .32706 .65312 L .707 .577 .707 r
F P
0 g
s
.34078 .61771 m .34736 .66226 L p .32706 .65312 L .707 .577 .707 r
F P
0 g
s
.34736 .66226 m .34783 .66547 L p .32706 .65312 L .707 .577 .707 r
F P
0 g
s
.34647 .64302 m .34736 .66226 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.32538 .63498 m .33982 .64049 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.33982 .64049 m .34647 .64302 L p .3426 .64852 L .707 .577 .707 r
F P
0 g
s
.33641 .65733 m .33982 .64049 L .3426 .64852 L .707 .577 .707 r
F
.32666 .65294 m .31943 .60686 L .32706 .65312 L F
.3262 .65273 m .31943 .60686 L p .3268 .65379 L F P
0 g
s
.3262 .65273 m .32538 .63498 L p .33641 .65733 L .707 .577 .707 r
F P
0 g
s
.3268 .65379 m .32666 .65294 L .32706 .65312 L .707 .577 .707 r
F
.32648 .65462 m .3262 .65273 L p .3268 .65379 L F P
0 g
s
.29956 .66574 m .2987 .64728 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.32703 .67068 m .29956 .66574 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.3262 .65273 m .32703 .67068 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.32648 .65462 m .29892 .64871 L p .29954 .64744 L .707 .577 .707 r
F P
0 g
s
.31943 .60686 m .3262 .65273 L p .29954 .64744 L .707 .577 .707 r
F P
0 g
s
.3262 .65273 m .32648 .65462 L p .29954 .64744 L .707 .577 .707 r
F P
0 g
s
.32538 .63498 m .3262 .65273 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.29791 .63004 m .31517 .63314 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.31517 .63314 m .32538 .63498 L p .31989 .64152 L .707 .577 .707 r
F P
0 g
s
.31272 .65006 m .31517 .63314 L .31989 .64152 L .707 .577 .707 r
F
.29916 .64737 m .29187 .60095 L .29954 .64744 L F
.2987 .64728 m .29187 .60095 L p .29926 .64801 L F P
0 g
s
.2987 .64728 m .29791 .63004 L p .31272 .65006 L .707 .577 .707 r
F P
0 g
s
.29926 .64801 m .29916 .64737 L .29954 .64744 L .707 .577 .707 r
F
.29892 .64871 m .2987 .64728 L p .29926 .64801 L F P
0 g
s
.2684 .66439 m .26757 .64644 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.29956 .66574 m .2684 .66439 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.2987 .64728 m .29956 .66574 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.29892 .64871 m .26785 .64833 L p .26879 .64647 L .707 .577 .707 r
F P
0 g
s
.29187 .60095 m .2987 .64728 L p .26879 .64647 L .707 .577 .707 r
F P
0 g
s
.2987 .64728 m .29892 .64871 L p .26879 .64647 L .707 .577 .707 r
F P
0 g
s
.29791 .63004 m .2987 .64728 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.26675 .62868 m .28515 .62948 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.28515 .62948 m .29791 .63004 L p .29137 .63765 L .707 .577 .707 r
F P
0 g
s
.28345 .64687 m .28515 .62948 L .29137 .63765 L .707 .577 .707 r
F
.26821 .64645 m .2608 .60057 L .26879 .64647 L F
.26757 .64644 m .2608 .60057 L p .26835 .64734 L F P
0 g
s
.26757 .64644 m .26675 .62868 L p .28345 .64687 L .707 .577 .707 r
F P
0 g
s
.26835 .64734 m .26821 .64645 L .26879 .64647 L .707 .577 .707 r
F
.26785 .64833 m .26757 .64644 L p .26835 .64734 L F P
0 g
s
.2366 .66675 m .23584 .65029 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.2684 .66439 m .2366 .66675 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.26757 .64644 m .2684 .66439 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.26785 .64833 m .23631 .6535 L p .23791 .65004 L .707 .577 .707 r
F P
0 g
s
.2608 .60057 m .26757 .64644 L p .23791 .65004 L .707 .577 .707 r
F P
0 g
s
.26757 .64644 m .26785 .64833 L p .23791 .65004 L .707 .577 .707 r
F P
0 g
s
.26675 .62868 m .26757 .64644 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.23495 .63105 m .25303 .62971 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.25303 .62971 m .26675 .62868 L p .25978 .63748 L .707 .577 .707 r
F P
0 g
s
.2511 .64844 m .25303 .62971 L .25978 .63748 L .707 .577 .707 r
F
.2368 .65017 m .22926 .60574 L .23791 .65004 L F
.23584 .65029 m .22926 .60574 L p .23708 .65184 L F P
0 g
s
.23584 .65029 m .23495 .63105 L p .2511 .64844 L .707 .577 .707 r
F P
0 g
s
.23708 .65184 m .2368 .65017 L .23791 .65004 L .707 .577 .707 r
F
.23631 .6535 m .23584 .65029 L p .23708 .65184 L F P
0 g
s
.20727 .67261 m .20662 .65846 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.2366 .66675 m .20727 .67261 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.23584 .65029 m .2366 .66675 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.23631 .6535 m .2074 .66373 L p .20971 .65759 L .707 .577 .707 r
F P
0 g
s
.22926 .60574 m .23584 .65029 L p .20971 .65759 L .707 .577 .707 r
F P
0 g
s
.23584 .65029 m .23631 .6535 L p .20971 .65759 L .707 .577 .707 r
F P
0 g
s
.23495 .63105 m .23584 .65029 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.20562 .63691 m .2224 .63356 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.2224 .63356 m .23495 .63105 L p .22835 .64096 L .707 .577 .707 r
F P
0 g
s
.219 .65499 m .2224 .63356 L .22835 .64096 L .707 .577 .707 r
F
.2077 .65815 m .20035 .61597 L .20971 .65759 L F
.20662 .65846 m .20035 .61597 L p .20827 .66142 L F P
0 g
s
.20662 .65846 m .20562 .63691 L p .219 .65499 L .707 .577 .707 r
F P
0 g
s
.20827 .66142 m .2077 .65815 L .20971 .65759 L .707 .577 .707 r
F
.2074 .66373 m .20662 .65846 L p .20827 .66142 L F P
0 g
s
.20727 .67261 m .18329 .68138 L p .19094 .66613 L .707 .577 .707 r
F P
0 g
s
.20662 .65846 m .20727 .67261 L p .19094 .66613 L .707 .577 .707 r
F P
0 g
s
.2074 .66373 m .18393 .67801 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.20035 .61597 m .20662 .65846 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.20662 .65846 m .2074 .66373 L p .1865 .66831 L .707 .577 .707 r
F P
0 g
s
.20562 .63691 m .20662 .65846 L p .19094 .66613 L .707 .577 .707 r
F P
0 g
s
.19094 .66613 m .18277 .67014 L .19955 .64574 L .707 .577 .707 r
F
.20041 .64729 m .19955 .64574 L .20562 .63691 L F
.19094 .66613 m .19955 .64574 L .20041 .64729 L F
.18277 .67014 m .18164 .64568 L .1838 .64489 L p F P
0 g
s
.1838 .64489 m .20562 .63691 L p .18277 .67014 L .707 .577 .707 r
F P
0 g
s
.16821 .69495 m .17006 .68121 L .18244 .67836 L .707 .577 .707 r
F
.18393 .67801 m .18238 .67968 L p .18244 .67836 L F P
0 g
s
.18238 .67968 m .16821 .69495 L p .18244 .67836 L .707 .577 .707 r
F P
0 g
s
.17688 .63025 m .18277 .67014 L p .17006 .68121 L .707 .577 .707 r
F P
0 g
s
.18277 .67014 m .18393 .67801 L p .17006 .68121 L .707 .577 .707 r
F P
0 g
s
.18164 .64568 m .18277 .67014 L p .17061 .68073 L .707 .577 .707 r
F P
0 g
s
.16663 .68419 m .16821 .69495 L .16792 .69576 L p .707 .577 .707 r
F P
0 g
s
.16535 .6565 m .18164 .64568 L p .17061 .68073 L .707 .577 .707 r
F P
0 g
s
.16663 .68419 m .16535 .6565 L p .17061 .68073 L .707 .577 .707 r
F P
0 g
s
.16821 .69495 m .16663 .68419 L p .17006 .68121 L .707 .577 .707 r
F P
0 g
s
.16663 .68419 m .16117 .64719 L .16362 .64454 L p .707 .577 .707 r
F P
0 g
s
.16001 .69873 m .15834 .66833 L .16078 .69703 L .707 .577 .707 r
F
.15977 .69925 m .15834 .66833 L p .1602 .70221 L F P
0 g
s
.16162 .69519 m .15977 .69925 L .16117 .64719 L .707 .577 .707 r
F
.1602 .70221 m .16001 .69873 L .16078 .69703 L F
.15999 .70403 m .15977 .69925 L p .1602 .70221 L F P
0 g
s
.15474 .66512 m .15977 .69925 L p .15597 .67275 L .707 .578 .707 r
F P
0 g
s
.15977 .69925 m .15474 .66512 L .15748 .65745 L p .707 .577 .707 r
F P
0 g
s
.15748 .65745 m .16117 .64719 L p .15977 .69925 L .707 .577 .707 r
F P
0 g
s
.17318 .72406 m .17561 .72605 L p .16287 .71382 L .707 .577 .707 r
F P
0 g
s
.17833 .74479 m .17563 .72649 L p .17095 .72184 L .707 .577 .707 r
F P
0 g
s
.1886 .8373 m .18942 .81834 L .16833 .81352 L p .707 .577 .707 r
F P
0 g
s
.68385 .83966 m .68303 .85862 L .66194 .85379 L p .707 .577 .707 r
F P
0 g
s
.66194 .85379 m .66276 .83483 L .68385 .83966 L p .707 .577 .707 r
F P
0 g
s
.6342 .29556 m .63727 .79532 L .64727 .78283 L p .707 .577 .707 r
F P
0 g
s
.64727 .78283 m .64419 .28307 L .6342 .29556 L p .707 .577 .707 r
F P
0 g
s
.16833 .81352 m .16751 .83247 L .1886 .8373 L p .707 .577 .707 r
F P
0 g
s
.5182 .84994 m .51902 .83099 L .543 .82853 L p .707 .577 .707 r
F P
0 g
s
.543 .82853 m .54218 .84749 L .5182 .84994 L p .707 .577 .707 r
F P
0 g
s
.33316 .82219 m .33234 .84114 L .34863 .83732 L p .707 .577 .707 r
F P
0 g
s
.34863 .83732 m .34945 .81836 L .33316 .82219 L p .707 .577 .707 r
F P
0 g
s
.3635 .79173 m .36043 .29197 L .35634 .27929 L p .707 .577 .707 r
F P
0 g
s
.36043 .29197 m .3635 .79173 L .38128 .80335 L p .707 .577 .707 r
F P
0 g
s
.16751 .83247 m .16833 .81352 L .15568 .80817 L p .707 .577 .707 r
F P
0 g
s
.66276 .83483 m .66194 .85379 L .63447 .84996 L p .707 .577 .707 r
F P
0 g
s
.63447 .84996 m .63529 .831 L .66276 .83483 L p .707 .577 .707 r
F P
0 g
s
.15568 .80817 m .15486 .82712 L .16751 .83247 L p .707 .577 .707 r
F P
0 g
s
.54218 .84749 m .543 .82853 L .57233 .82769 L p .707 .577 .707 r
F P
0 g
s
.57233 .82769 m .57151 .84665 L .54218 .84749 L p .707 .577 .707 r
F P
0 g
s
.63529 .831 m .63447 .84996 L .60331 .8475 L p .707 .577 .707 r
F P
0 g
s
.60331 .8475 m .60413 .82854 L .63529 .831 L p .707 .577 .707 r
F P
0 g
s
.34945 .81836 m .34863 .83732 L .35564 .8325 L p .707 .577 .707 r
F P
0 g
s
.35564 .8325 m .35646 .81354 L .34945 .81836 L p .707 .577 .707 r
F P
0 g
s
.6401 .27039 m .64317 .77016 L .6254 .75854 L p .707 .577 .707 r
F P
0 g
s
.63843 .58009 m .63495 .56292 L p .63674 .57397 L .707 .578 .707 r
F P
0 g
s
.64727 .78283 m .64478 .77513 L p .644 .60716 L .707 .577 .707 r
F P
0 g
s
.644 .60716 m .64476 .61063 L .64727 .78283 L .707 .577 .707 r
F
.64326 .72777 m .64367 .53557 L .64478 .77513 L F
.64561 .51412 m .64727 .78283 L p .64367 .53557 L F P
0 g
s
.64326 .72777 m .64206 .55328 L .64367 .53557 L .707 .577 .707 r
F
.64283 .71428 m .6401 .27039 L p .64326 .72777 L F P
0 g
s
.644 .60716 m .64367 .53557 L .64476 .61063 L .707 .577 .707 r
F
.64548 .62785 m .65854 .64258 L p .63936 .58297 L F P
0 g
s
.63843 .58009 m .63917 .58507 L p .63936 .58297 L .707 .577 .707 r
F P
0 g
s
.63917 .58507 m .64548 .62785 L p .63936 .58297 L .707 .577 .707 r
F P
0 g
s
.6401 .27039 m .64419 .28307 L p .64367 .53557 L .707 .577 .707 r
F P
0 g
s
.64206 .55328 m .6401 .27039 L .64367 .53557 L .707 .577 .707 r
F
.64317 .77016 m .64283 .71428 L p .64326 .72777 L F P
0 g
s
.63589 .68182 m .63507 .70077 L .6425 .70391 L p .707 .577 .707 r
F P
0 g
s
.6425 .70391 m .64772 .70612 L p .64221 .69479 L .707 .577 .707 r
F P
0 g
s
.64221 .69479 m .63589 .68182 L .6425 .70391 L .707 .577 .707 r
F
.64548 .62785 m .63917 .58507 L p .63674 .57397 L .707 .578 .707 r
F P
0 g
s
.63917 .58507 m .63843 .58009 L p .63674 .57397 L .707 .578 .707 r
F P
0 g
s
.64478 .77513 m .64317 .77016 L p .64326 .72777 L .707 .577 .707 r
F P
0 g
s
.64772 .70612 m .64854 .68716 L .64187 .68435 L p .707 .577 .707 r
F P
0 g
s
.64187 .68435 m .63589 .68182 L p .64221 .69479 L .707 .577 .707 r
F P
0 g
s
.64772 .70612 m .64187 .68435 L .64221 .69479 L .707 .577 .707 r
F
.65854 .64258 m .65149 .59482 L .63951 .58131 L p F P
0 g
s
.63951 .58131 m .63843 .58009 L p .63936 .58297 L .707 .577 .707 r
F P
0 g
s
.65854 .64258 m .63951 .58131 L .63936 .58297 L .707 .577 .707 r
F
.64419 .28307 m .64561 .51412 L p .64367 .53557 L F P
0 g
s
.57151 .84665 m .57233 .82769 L .60413 .82854 L p .707 .577 .707 r
F P
0 g
s
.60413 .82854 m .60331 .8475 L .57151 .84665 L p .707 .577 .707 r
F P
0 g
s
.15486 .82712 m .15568 .80817 L .15271 .80282 L p .707 .577 .707 r
F P
0 g
s
.15271 .80282 m .15189 .82178 L .15486 .82712 L p .707 .577 .707 r
F P
0 g
s
.35634 .27929 m .35941 .77906 L .3635 .79173 L p .707 .577 .707 r
F P
0 g
s
.35941 .77906 m .35634 .27929 L .36634 .26681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35646 .81354 m .35564 .8325 L .35267 .82715 L p .707 .577 .707 r
F P
0 g
s
.35267 .82715 m .35349 .80819 L .35646 .81354 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15189 .82178 m .15271 .80282 L .15972 .798 L p .707 .577 .707 r
F P
0 g
s
.6254 .75854 m .62232 .25878 L .6401 .27039 L p .707 .577 .707 r
F P
0 g
s
.15972 .798 m .1589 .81695 L .15189 .82178 L p .707 .577 .707 r
F P
0 g
s
.35349 .80819 m .35267 .82715 L .34002 .8218 L p .707 .577 .707 r
F P
0 g
s
.34002 .8218 m .34084 .80285 L .35349 .80819 L p .707 .577 .707 r
F P
0 g
s
.36941 .76657 m .36634 .26681 L .38945 .25572 L p .707 .577 .707 r
F P
0 g
s
.36634 .26681 m .36941 .76657 L .35941 .77906 L p .707 .577 .707 r
F P
0 g
s
.1589 .81695 m .15972 .798 L .17601 .79417 L p .707 .577 .707 r
F P
0 g
s
.17601 .79417 m .17519 .81313 L .1589 .81695 L p .707 .577 .707 r
F P
0 g
s
.62232 .25878 m .6254 .75854 L .59567 .74912 L p .707 .577 .707 r
F P
0 g
s
.59567 .74912 m .5926 .24935 L .62232 .25878 L p .707 .577 .707 r
F P
0 g
s
.34084 .80285 m .34002 .8218 L .31893 .81697 L p .707 .577 .707 r
F P
0 g
s
.31893 .81697 m .31975 .79802 L .34084 .80285 L p .707 .577 .707 r
F P
0 g
s
.73853 .65973 m .73148 .61197 L .70041 .61158 L p .707 .577 .707 r
F P
0 g
s
.73148 .61197 m .73853 .65973 L .77006 .65455 L p .707 .577 .707 r
F P
0 g
s
.77006 .65455 m .76302 .60679 L .73148 .61197 L p .707 .577 .707 r
F P
0 g
s
.76302 .60679 m .77006 .65455 L .79898 .64433 L p .707 .577 .707 r
F P
0 g
s
.79898 .64433 m .79193 .59657 L .76302 .60679 L p .707 .577 .707 r
F P
0 g
s
.39075 .46801 m .39252 .75549 L p .38257 .43117 L .707 .577 .707 r
F P
0 g
s
.39252 .75549 m .38945 .25572 L .4234 .24713 L p .707 .577 .707 r
F P
0 g
s
.39252 .75549 m .4075 .50884 L .42312 .70478 L .707 .577 .707 r
F
.42515 .53224 m .42613 .69102 L p .4075 .50884 L F P
0 g
s
.42613 .69102 m .42647 .7469 L p .42312 .70478 L .707 .577 .707 r
F P
0 g
s
.4075 .50884 m .42613 .69102 L .42312 .70478 L .707 .577 .707 r
F
.42647 .7469 m .4234 .24713 L .46488 .24188 L p F P
0 g
s
.46488 .24188 m .46795 .74164 L .42647 .7469 L p .707 .577 .707 r
F P
0 g
s
.44556 .68043 m .44638 .66148 L .43251 .66187 L p .707 .577 .707 r
F P
0 g
s
.43251 .66187 m .41705 .66232 L p .43054 .67089 L .707 .577 .707 r
F P
0 g
s
.44556 .68043 m .43251 .66187 L .43054 .67089 L .707 .577 .707 r
F
.41705 .66232 m .41623 .68127 L .42834 .68093 L p F P
0 g
s
.42834 .68093 m .44556 .68043 L p .43054 .67089 L .707 .577 .707 r
F P
0 g
s
.43054 .67089 m .41705 .66232 L .42834 .68093 L .707 .577 .707 r
F
.42647 .7469 m .41315 .75027 L p .42312 .70478 L F P
0 g
s
.41315 .75027 m .39252 .75549 L p .42312 .70478 L .707 .577 .707 r
F P
0 g
s
.4234 .24713 m .42515 .53224 L p .4075 .50884 L .707 .577 .707 r
F P
0 g
s
.45597 .60751 m .44966 .56473 L p .42001 .56998 L .707 .577 .707 r
F P
0 g
s
.44966 .56473 m .44892 .55975 L .44654 .56059 L p .707 .577 .707 r
F P
0 g
s
.44654 .56059 m .42001 .56998 L p .44966 .56473 L .707 .577 .707 r
F P
0 g
s
.38847 .57515 m .39552 .62291 L .42413 .61822 L p .707 .577 .707 r
F P
0 g
s
.42413 .61822 m .42705 .61774 L p .42304 .61331 L .707 .577 .707 r
F P
0 g
s
.42304 .61331 m .38847 .57515 L .42413 .61822 L .707 .577 .707 r
F
.39252 .75549 m .36941 .76657 L p .38257 .43117 L F P
0 g
s
.38945 .25572 m .39075 .46801 L p .38257 .43117 L .707 .577 .707 r
F P
0 g
s
.17519 .81313 m .17601 .79417 L .19999 .79172 L p .707 .577 .707 r
F P
0 g
s
.19999 .79172 m .19917 .81067 L .17519 .81313 L p .707 .577 .707 r
F P
0 g
s
.70746 .65934 m .70041 .61158 L .67285 .60568 L p .707 .577 .707 r
F P
0 g
s
.70041 .61158 m .70746 .65934 L .73853 .65973 L p .707 .577 .707 r
F P
0 g
s
.79193 .59657 m .79898 .64433 L .82244 .63004 L p .707 .577 .707 r
F P
0 g
s
.82244 .63004 m .81539 .58228 L .79193 .59657 L p .707 .577 .707 r
F P
0 g
s
.72744 .71724 m .72826 .69828 L .6971 .69582 L p .707 .577 .707 r
F P
0 g
s
.72826 .69828 m .72744 .71724 L .75924 .71809 L p .707 .577 .707 r
F P
0 g
s
.75924 .71809 m .76006 .69913 L .72826 .69828 L p .707 .577 .707 r
F P
0 g
s
.31975 .79802 m .31893 .81697 L .29146 .81314 L p .707 .577 .707 r
F P
0 g
s
.29146 .81314 m .29228 .79419 L .31975 .79802 L p .707 .577 .707 r
F P
0 g
s
.5926 .24935 m .59567 .74912 L .5569 .74281 L p .707 .577 .707 r
F P
0 g
s
.5569 .74281 m .55383 .24304 L .5926 .24935 L p .707 .577 .707 r
F P
0 g
s
.76006 .69913 m .75924 .71809 L .78857 .71725 L p .707 .577 .707 r
F P
0 g
s
.78857 .71725 m .78939 .69829 L .76006 .69913 L p .707 .577 .707 r
F P
0 g
s
.6971 .69582 m .69628 .71478 L .72744 .71724 L p .707 .577 .707 r
F P
0 g
s
.69628 .71478 m .6971 .69582 L .66963 .69199 L p .707 .577 .707 r
F P
0 g
s
.6799 .65344 m .67285 .60568 L .65149 .59482 L p .707 .577 .707 r
F P
0 g
s
.67285 .60568 m .6799 .65344 L .70746 .65934 L p .707 .577 .707 r
F P
0 g
s
.19917 .81067 m .19999 .79172 L .22932 .79088 L p .707 .577 .707 r
F P
0 g
s
.66963 .69199 m .66881 .71095 L .69628 .71478 L p .707 .577 .707 r
F P
0 g
s
.22932 .79088 m .2285 .80983 L .19917 .81067 L p .707 .577 .707 r
F P
0 g
s
.81539 .58228 m .82244 .63004 L .83816 .61311 L p .707 .577 .707 r
F P
0 g
s
.83816 .61311 m .83111 .56535 L .81539 .58228 L p .707 .577 .707 r
F P
0 g
s
.78939 .69829 m .78857 .71725 L .81255 .71479 L p .707 .577 .707 r
F P
0 g
s
.81255 .71479 m .81337 .69584 L .78939 .69829 L p .707 .577 .707 r
F P
0 g
s
.29228 .79419 m .29146 .81314 L .2603 .81068 L p .707 .577 .707 r
F P
0 g
s
.2603 .81068 m .26112 .79173 L .29228 .79419 L p .707 .577 .707 r
F P
0 g
s
.2285 .80983 m .22932 .79088 L .26112 .79173 L p .707 .577 .707 r
F P
0 g
s
.66881 .71095 m .66963 .69199 L .64854 .68716 L p .707 .577 .707 r
F P
0 g
s
.26112 .79173 m .2603 .81068 L .2285 .80983 L p .707 .577 .707 r
F P
0 g
s
.73554 .76887 m .7339 .73317 L .70274 .73182 L p .707 .577 .707 r
F P
0 g
s
.7339 .73317 m .73554 .76887 L .76734 .76651 L p .707 .577 .707 r
F P
0 g
s
.76734 .76651 m .76569 .73081 L .7339 .73317 L p .707 .577 .707 r
F P
0 g
s
.55383 .24304 m .5569 .74281 L .5129 .74023 L p .707 .577 .707 r
F P
0 g
s
.5129 .74023 m .50983 .24047 L .55383 .24304 L p .707 .577 .707 r
F P
0 g
s
.64854 .68716 m .64772 .70612 L .66881 .71095 L p .707 .577 .707 r
F P
0 g
s
.76569 .73081 m .76734 .76651 L .79667 .76065 L p .707 .577 .707 r
F P
0 g
s
.79667 .76065 m .79502 .72495 L .76569 .73081 L p .707 .577 .707 r
F P
0 g
s
.65149 .59482 m .65854 .64258 L .6799 .65344 L p .707 .577 .707 r
F P
0 g
s
.46795 .74164 m .46488 .24188 L .50983 .24047 L p .707 .577 .707 r
F P
0 g
s
.70438 .76752 m .70274 .73182 L .67526 .72688 L p .707 .577 .707 r
F P
0 g
s
.70274 .73182 m .70438 .76752 L .73554 .76887 L p .707 .577 .707 r
F P
0 g
s
.83111 .56535 m .83816 .61311 L .84459 .59518 L p .707 .577 .707 r
F P
0 g
s
.84459 .59518 m .83754 .54742 L .83111 .56535 L p .707 .577 .707 r
F P
0 g
s
.50983 .24047 m .5129 .74023 L .46795 .74164 L p .707 .577 .707 r
F P
0 g
s
.81337 .69584 m .81255 .71479 L .82884 .71097 L p .707 .577 .707 r
F P
0 g
s
.82884 .71097 m .82966 .69201 L .81337 .69584 L p .707 .577 .707 r
F P
0 g
s
.79502 .72495 m .79667 .76065 L .82065 .75188 L p .707 .577 .707 r
F P
0 g
s
.82065 .75188 m .819 .71618 L .79502 .72495 L p .707 .577 .707 r
F P
0 g
s
.67526 .72688 m .67691 .76258 L .70438 .76752 L p .707 .577 .707 r
F P
0 g
s
.67691 .76258 m .67526 .72688 L .65417 .71884 L p .707 .577 .707 r
F P
0 g
s
.819 .71618 m .82065 .75188 L .83694 .74106 L p .707 .577 .707 r
F P
0 g
s
.82966 .69201 m .82884 .71097 L .8308 .70962 L p .707 .577 .707 r
F P
0 g
s
.83694 .74106 m .83529 .70535 L .83082 .70833 L p .707 .577 .707 r
F P
0 g
s
.83694 .74106 m .83082 .70833 L .83041 .732 L .707 .577 .707 r
F
.83529 .70535 m .83694 .74106 L .84395 .72923 L p F P
0 g
s
.84395 .72923 m .8423 .69353 L .83529 .70535 L p .707 .577 .707 r
F P
0 g
s
.8308 .70962 m .83585 .70614 L p .83105 .69519 L .707 .577 .707 r
F P
0 g
s
.83105 .69519 m .82966 .69201 L .8308 .70962 L .707 .577 .707 r
F
.83082 .70833 m .819 .71618 L p .83041 .732 L F P
0 g
s
.83754 .54742 m .84459 .59518 L .84111 .578 L p .707 .578 .707 r
F P
0 g
s
.84111 .578 m .83406 .53024 L .83754 .54742 L p .707 .578 .707 r
F P
0 g
s
.65417 .71884 m .65582 .75454 L .67691 .76258 L p .707 .577 .707 r
F P
0 g
s
.83585 .70614 m .83667 .68719 L .82966 .69201 L p .707 .577 .707 r
F P
0 g
s
.65582 .75454 m .65417 .71884 L .64152 .70848 L p .707 .577 .707 r
F P
0 g
s
.63507 .70077 m .63589 .68182 L .63293 .67647 L p .707 .577 .707 r
F P
0 g
s
.63293 .67647 m .63211 .69542 L .63507 .70077 L p .707 .577 .707 r
F P
0 g
s
.63495 .56292 m .642 .61068 L .64548 .62785 L p .707 .578 .707 r
F P
0 g
s
.642 .61068 m .63495 .56292 L .64138 .54499 L p .707 .577 .707 r
F P
0 g
s
.64152 .70848 m .64317 .74418 L .65582 .75454 L p .707 .577 .707 r
F P
0 g
s
.83406 .53024 m .84111 .578 L .82805 .56327 L p .707 .577 .707 r
F P
0 g
s
.82805 .56327 m .821 .51551 L .83406 .53024 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83667 .68719 m .83585 .70614 L .83288 .7008 L p .707 .577 .707 r
F P
0 g
s
.83288 .7008 m .8337 .68184 L .83667 .68719 L p .707 .577 .707 r
F P
0 g
s
.64317 .74418 m .64152 .70848 L .63856 .69681 L p .707 .577 .707 r
F P
0 g
s
.64843 .59275 m .64138 .54499 L .6571 .52805 L p .707 .577 .707 r
F P
0 g
s
.64138 .54499 m .64843 .59275 L .642 .61068 L p .707 .577 .707 r
F P
0 g
s
.63211 .69542 m .63293 .67647 L .63993 .67165 L p .707 .577 .707 r
F P
0 g
s
.63993 .67165 m .63911 .6906 L .63211 .69542 L p .707 .577 .707 r
F P
0 g
s
.821 .51551 m .82805 .56327 L .80669 .55242 L p .707 .577 .707 r
F P
0 g
s
.80669 .55242 m .79964 .50466 L .821 .51551 L p .707 .577 .707 r
F P
0 g
s
.63856 .69681 m .64021 .73251 L .64317 .74418 L p .707 .577 .707 r
F P
0 g
s
.8423 .69353 m .84395 .72923 L .84098 .71757 L p .707 .577 .707 r
F P
0 g
s
.84098 .71757 m .83933 .68187 L .8423 .69353 L p .707 .577 .707 r
F P
0 g
s
.39552 .62291 m .38847 .57515 L .3574 .57477 L p .707 .577 .707 r
F P
0 g
s
.42705 .61774 m .42001 .56998 L .38847 .57515 L p .707 .577 .707 r
F P
0 g
s
.42001 .56998 m .42705 .61774 L .45597 .60751 L p .707 .577 .707 r
F P
0 g
s
.36445 .62253 m .3574 .57477 L .32984 .56886 L p .707 .577 .707 r
F P
0 g
s
.3574 .57477 m .36445 .62253 L .39552 .62291 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.8337 .68184 m .83288 .7008 L .82024 .69545 L p .707 .577 .707 r
F P
0 g
s
.82024 .69545 m .82106 .67649 L .8337 .68184 L p .707 .577 .707 r
F P
0 g
s
.44892 .55975 m .45597 .60751 L .47943 .59323 L p .707 .577 .707 r
F P
0 g
s
.47943 .59323 m .47238 .54547 L .44892 .55975 L p .707 .577 .707 r
F P
0 g
s
.65622 .66782 m .6554 .68678 L .64366 .68953 L p .707 .577 .707 r
F P
0 g
s
.64021 .73251 m .63856 .69681 L .64364 .68823 L p .707 .577 .707 r
F P
0 g
s
.64021 .73251 m .64364 .68823 L .64385 .70018 L .707 .577 .707 r
F
.64366 .68953 m .63911 .6906 L p .64358 .68466 L F P
0 g
s
.64358 .68466 m .65622 .66782 L .64366 .68953 L .707 .577 .707 r
F
.64364 .68823 m .64556 .68499 L p .64385 .70018 L F P
0 g
s
.6571 .52805 m .66414 .57581 L .64843 .59275 L p .707 .577 .707 r
F P
0 g
s
.66414 .57581 m .6571 .52805 L .68056 .51377 L p .707 .577 .707 r
F P
0 g
s
.79964 .50466 m .80669 .55242 L .77913 .54651 L p .707 .577 .707 r
F P
0 g
s
.77913 .54651 m .77208 .49875 L .79964 .50466 L p .707 .577 .707 r
F P
0 g
s
.38443 .68042 m .38525 .66147 L .35409 .65901 L p .707 .577 .707 r
F P
0 g
s
.38525 .66147 m .38443 .68042 L .41623 .68127 L p .707 .577 .707 r
F P
0 g
s
.41623 .68127 m .41705 .66232 L .38525 .66147 L p .707 .577 .707 r
F P
0 g
s
.35409 .65901 m .35327 .67796 L .38443 .68042 L p .707 .577 .707 r
F P
0 g
s
.63911 .6906 m .63993 .67165 L .65622 .66782 L p .707 .577 .707 r
F P
0 g
s
.35327 .67796 m .35409 .65901 L .32662 .65518 L p .707 .577 .707 r
F P
0 g
s
.33689 .61662 m .32984 .56886 L .30848 .55801 L p .707 .577 .707 r
F P
0 g
s
.32984 .56886 m .33689 .61662 L .36445 .62253 L p .707 .577 .707 r
F P
0 g
s
.64556 .68499 m .64721 .72069 L .64021 .73251 L p .707 .577 .707 r
F P
0 g
s
.83933 .68187 m .84098 .71757 L .82833 .70721 L p .707 .577 .707 r
F P
0 g
s
.82833 .70721 m .82668 .67151 L .83933 .68187 L p .707 .577 .707 r
F P
0 g
s
.32662 .65518 m .3258 .67413 L .35327 .67796 L p .707 .577 .707 r
F P
0 g
s
.47238 .54547 m .47943 .59323 L .49515 .57629 L p .707 .577 .707 r
F P
0 g
s
.49515 .57629 m .4881 .52853 L .47238 .54547 L p .707 .577 .707 r
F P
0 g
s
.68761 .56153 m .68056 .51377 L .70948 .50354 L p .707 .577 .707 r
F P
0 g
s
.68056 .51377 m .68761 .56153 L .66414 .57581 L p .707 .577 .707 r
F P
0 g
s
.77208 .49875 m .77913 .54651 L .74806 .54613 L p .707 .577 .707 r
F P
0 g
s
.74806 .54613 m .74101 .49837 L .77208 .49875 L p .707 .577 .707 r
F P
0 g
s
.44638 .66148 m .44556 .68043 L .46954 .67798 L p .707 .577 .707 r
F P
0 g
s
.46954 .67798 m .47036 .65902 L .44638 .66148 L p .707 .577 .707 r
F P
0 g
s
.71652 .5513 m .70948 .50354 L .74101 .49837 L p .707 .577 .707 r
F P
0 g
s
.70948 .50354 m .71652 .5513 L .68761 .56153 L p .707 .577 .707 r
F P
0 g
s
.74101 .49837 m .74806 .54613 L .71652 .5513 L p .707 .577 .707 r
F P
0 g
s
.3258 .67413 m .32662 .65518 L .30553 .65035 L p .707 .577 .707 r
F P
0 g
s
.82106 .67649 m .82024 .69545 L .79914 .69062 L p .707 .577 .707 r
F P
0 g
s
.79914 .69062 m .79996 .67167 L .82106 .67649 L p .707 .577 .707 r
F P
0 g
s
.6554 .68678 m .65622 .66782 L .68021 .66537 L p .707 .577 .707 r
F P
0 g
s
.68021 .66537 m .67939 .68432 L .6554 .68678 L p .707 .577 .707 r
F P
0 g
s
.64721 .72069 m .64556 .68499 L .66185 .67416 L p .707 .577 .707 r
F P
0 g
s
.39253 .73206 m .39089 .69636 L .35973 .695 L p .707 .577 .707 r
F P
0 g
s
.39089 .69636 m .39253 .73206 L .42433 .72969 L p .707 .577 .707 r
F P
0 g
s
.42433 .72969 m .42268 .69399 L .39089 .69636 L p .707 .577 .707 r
F P
0 g
s
.30553 .65035 m .30471 .6693 L .3258 .67413 L p .707 .577 .707 r
F P
0 g
s
.42268 .69399 m .42433 .72969 L .45366 .72384 L p .707 .577 .707 r
F P
0 g
s
.45366 .72384 m .45201 .68813 L .42268 .69399 L p .707 .577 .707 r
F P
0 g
s
.31553 .60577 m .30848 .55801 L .29542 .54328 L p .707 .577 .707 r
F P
0 g
s
.30848 .55801 m .31553 .60577 L .33689 .61662 L p .707 .577 .707 r
F P
0 g
s
.36137 .7307 m .35973 .695 L .33225 .69006 L p .707 .577 .707 r
F P
0 g
s
.35973 .695 m .36137 .7307 L .39253 .73206 L p .707 .577 .707 r
F P
0 g
s
.4881 .52853 m .49515 .57629 L .50158 .55836 L p .707 .577 .707 r
F P
0 g
s
.50158 .55836 m .49453 .5106 L .4881 .52853 L p .707 .577 .707 r
F P
0 g
s
.82668 .67151 m .82833 .70721 L .80724 .69917 L p .707 .577 .707 r
F P
0 g
s
.80724 .69917 m .80559 .66347 L .82668 .67151 L p .707 .577 .707 r
F P
0 g
s
.47036 .65902 m .46954 .67798 L .48583 .67415 L p .707 .577 .707 r
F P
0 g
s
.48583 .67415 m .48665 .6552 L .47036 .65902 L p .707 .577 .707 r
F P
0 g
s
.66185 .67416 m .6635 .70986 L .64721 .72069 L p .707 .577 .707 r
F P
0 g
s
.45201 .68813 m .45366 .72384 L .47764 .71507 L p .707 .577 .707 r
F P
0 g
s
.47764 .71507 m .47599 .67937 L .45201 .68813 L p .707 .577 .707 r
F P
0 g
s
.33225 .69006 m .3339 .72576 L .36137 .7307 L p .707 .577 .707 r
F P
0 g
s
.30471 .6693 m .30553 .65035 L .29288 .645 L p .707 .577 .707 r
F P
0 g
s
.79996 .67167 m .79914 .69062 L .77167 .68679 L p .707 .577 .707 r
F P
0 g
s
.77167 .68679 m .77249 .66784 L .79996 .67167 L p .707 .577 .707 r
F P
0 g
s
.3339 .72576 m .33225 .69006 L .31116 .68202 L p .707 .577 .707 r
F P
0 g
s
.67939 .68432 m .68021 .66537 L .70953 .66452 L p .707 .577 .707 r
F P
0 g
s
.6635 .70986 m .66185 .67416 L .68584 .66539 L p .707 .577 .707 r
F P
0 g
s
.29288 .645 m .29206 .66396 L .30471 .6693 L p .707 .577 .707 r
F P
0 g
s
.30247 .59104 m .29542 .54328 L .29194 .5261 L p .707 .578 .707 r
F P
0 g
s
.29542 .54328 m .30247 .59104 L .31553 .60577 L p .707 .577 .707 r
F P
0 g
s
.70953 .66452 m .70871 .68348 L .67939 .68432 L p .707 .577 .707 r
F P
0 g
s
.47599 .67937 m .47764 .71507 L .49393 .70424 L p .707 .577 .707 r
F P
0 g
s
.48665 .6552 m .48583 .67415 L .48779 .6728 L p .707 .577 .707 r
F P
0 g
s
.49393 .70424 m .49228 .66854 L .48781 .67151 L p .707 .577 .707 r
F P
0 g
s
.49393 .70424 m .48781 .67151 L .4874 .69518 L .707 .577 .707 r
F
.49228 .66854 m .49393 .70424 L .50094 .69242 L p F P
0 g
s
.50094 .69242 m .49929 .65672 L .49228 .66854 L p .707 .577 .707 r
F P
0 g
s
.48779 .6728 m .49284 .66933 L p .48804 .65837 L .707 .577 .707 r
F P
0 g
s
.48804 .65837 m .48665 .6552 L .48779 .6728 L .707 .577 .707 r
F
.48781 .67151 m .47599 .67937 L p .4874 .69518 L F P
0 g
s
.49453 .5106 m .50158 .55836 L .4981 .54119 L p .707 .578 .707 r
F P
0 g
s
.4981 .54119 m .49105 .49343 L .49453 .5106 L p .707 .578 .707 r
F P
0 g
s
.80559 .66347 m .80724 .69917 L .77977 .69423 L p .707 .577 .707 r
F P
0 g
s
.77977 .69423 m .77812 .65853 L .80559 .66347 L p .707 .577 .707 r
F P
0 g
s
.31116 .68202 m .31281 .71772 L .3339 .72576 L p .707 .577 .707 r
F P
0 g
s
.77249 .66784 m .77167 .68679 L .74051 .68433 L p .707 .577 .707 r
F P
0 g
s
.74051 .68433 m .74133 .66538 L .77249 .66784 L p .707 .577 .707 r
F P
0 g
s
.68584 .66539 m .68748 .7011 L .6635 .70986 L p .707 .577 .707 r
F P
0 g
s
.49284 .66933 m .49366 .65037 L .48665 .6552 L p .707 .577 .707 r
F P
0 g
s
.70871 .68348 m .70953 .66452 L .74133 .66538 L p .707 .577 .707 r
F P
0 g
s
.68748 .7011 m .68584 .66539 L .71516 .65954 L p .707 .577 .707 r
F P
0 g
s
.74133 .66538 m .74051 .68433 L .70871 .68348 L p .707 .577 .707 r
F P
0 g
s
.31281 .71772 m .31116 .68202 L .29851 .67166 L p .707 .577 .707 r
F P
0 g
s
.77812 .65853 m .77977 .69423 L .74861 .69287 L p .707 .577 .707 r
F P
0 g
s
.74861 .69287 m .74696 .65717 L .77812 .65853 L p .707 .577 .707 r
F P
0 g
s
.29206 .66396 m .29288 .645 L .28992 .63965 L p .707 .577 .707 r
F P
0 g
s
.28992 .63965 m .2891 .65861 L .29206 .66396 L p .707 .577 .707 r
F P
0 g
s
.71681 .69524 m .71516 .65954 L .74696 .65717 L p .707 .577 .707 r
F P
0 g
s
.71516 .65954 m .71681 .69524 L .68748 .7011 L p .707 .577 .707 r
F P
0 g
s
.29194 .5261 m .29899 .57386 L .30247 .59104 L p .707 .578 .707 r
F P
0 g
s
.29899 .57386 m .29194 .5261 L .29837 .50817 L p .707 .577 .707 r
F P
0 g
s
.74696 .65717 m .74861 .69287 L .71681 .69524 L p .707 .577 .707 r
F P
0 g
s
.29851 .67166 m .30016 .70736 L .31281 .71772 L p .707 .577 .707 r
F P
0 g
s
.49105 .49343 m .4981 .54119 L .48504 .52645 L p .707 .577 .707 r
F P
0 g
s
.48504 .52645 m .47799 .47869 L .49105 .49343 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49366 .65037 m .49284 .66933 L .48987 .66398 L p .707 .577 .707 r
F P
0 g
s
.48987 .66398 m .49069 .64503 L .49366 .65037 L p .707 .577 .707 r
F P
0 g
s
.30016 .70736 m .29851 .67166 L .29555 .66 L p .707 .577 .707 r
F P
0 g
s
.30542 .55593 m .29837 .50817 L .31409 .49123 L p .707 .577 .707 r
F P
0 g
s
.29837 .50817 m .30542 .55593 L .29899 .57386 L p .707 .577 .707 r
F P
0 g
s
.2891 .65861 m .28992 .63965 L .29692 .63483 L p .707 .577 .707 r
F P
0 g
s
.29692 .63483 m .2961 .65379 L .2891 .65861 L p .707 .577 .707 r
F P
0 g
s
.47799 .47869 m .48504 .52645 L .46368 .5156 L p .707 .577 .707 r
F P
0 g
s
.46368 .5156 m .45663 .46784 L .47799 .47869 L p .707 .577 .707 r
F P
0 g
s
.29555 .66 m .2972 .6957 L .30016 .70736 L p .707 .577 .707 r
F P
0 g
s
.49929 .65672 m .50094 .69242 L .49797 .68075 L p .707 .577 .707 r
F P
0 g
s
.49797 .68075 m .49632 .64505 L .49929 .65672 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49069 .64503 m .48987 .66398 L .47723 .65863 L p .707 .577 .707 r
F P
0 g
s
.47723 .65863 m .47805 .63968 L .49069 .64503 L p .707 .577 .707 r
F P
0 g
s
.31321 .63101 m .31239 .64996 L .30065 .65272 L p .707 .577 .707 r
F P
0 g
s
.2972 .6957 m .29555 .66 L .30063 .65142 L p .707 .577 .707 r
F P
0 g
s
.2972 .6957 m .30063 .65142 L .30084 .66336 L .707 .577 .707 r
F
.30065 .65272 m .2961 .65379 L p .30057 .64784 L F P
0 g
s
.30057 .64784 m .31321 .63101 L .30065 .65272 L .707 .577 .707 r
F
.30063 .65142 m .30255 .64817 L p .30084 .66336 L F P
0 g
s
.31409 .49123 m .32113 .53899 L .30542 .55593 L p .707 .577 .707 r
F P
0 g
s
.32113 .53899 m .31409 .49123 L .33755 .47695 L p .707 .577 .707 r
F P
0 g
s
.45663 .46784 m .46368 .5156 L .43612 .5097 L p .707 .577 .707 r
F P
0 g
s
.43612 .5097 m .42907 .46193 L .45663 .46784 L p .707 .577 .707 r
F P
0 g
s
.2961 .65379 m .29692 .63483 L .31321 .63101 L p .707 .577 .707 r
F P
0 g
s
.30255 .64817 m .3042 .68388 L .2972 .6957 L p .707 .577 .707 r
F P
0 g
s
.49632 .64505 m .49797 .68075 L .48532 .67039 L p .707 .577 .707 r
F P
0 g
s
.48532 .67039 m .48367 .63469 L .49632 .64505 L p .707 .577 .707 r
F P
0 g
s
.3446 .52471 m .33755 .47695 L .36646 .46672 L p .707 .577 .707 r
F P
0 g
s
.33755 .47695 m .3446 .52471 L .32113 .53899 L p .707 .577 .707 r
F P
0 g
s
.42907 .46193 m .43612 .5097 L .40505 .50931 L p .707 .577 .707 r
F P
0 g
s
.40505 .50931 m .398 .46155 L .42907 .46193 L p .707 .577 .707 r
F P
0 g
s
.37351 .51448 m .36646 .46672 L .398 .46155 L p .707 .577 .707 r
F P
0 g
s
.36646 .46672 m .37351 .51448 L .3446 .52471 L p .707 .577 .707 r
F P
0 g
s
.398 .46155 m .40505 .50931 L .37351 .51448 L p .707 .577 .707 r
F P
0 g
s
.47805 .63968 m .47723 .65863 L .45613 .65381 L p .707 .577 .707 r
F P
0 g
s
.45613 .65381 m .45695 .63485 L .47805 .63968 L p .707 .577 .707 r
F P
0 g
s
.31239 .64996 m .31321 .63101 L .3372 .62855 L p .707 .577 .707 r
F P
0 g
s
.3372 .62855 m .33638 .64751 L .31239 .64996 L p .707 .577 .707 r
F P
0 g
s
.3042 .68388 m .30255 .64817 L .31884 .63735 L p .707 .577 .707 r
F P
0 g
s
.48367 .63469 m .48532 .67039 L .46423 .66235 L p .707 .577 .707 r
F P
0 g
s
.46423 .66235 m .46258 .62665 L .48367 .63469 L p .707 .577 .707 r
F P
0 g
s
.31884 .63735 m .32049 .67305 L .3042 .68388 L p .707 .577 .707 r
F P
0 g
s
.45695 .63485 m .45613 .65381 L .42866 .64998 L p .707 .577 .707 r
F P
0 g
s
.42866 .64998 m .42948 .63102 L .45695 .63485 L p .707 .577 .707 r
F P
0 g
s
.33638 .64751 m .3372 .62855 L .36652 .62771 L p .707 .577 .707 r
F P
0 g
s
.32049 .67305 m .31884 .63735 L .34282 .62858 L p .707 .577 .707 r
F P
0 g
s
.36652 .62771 m .3657 .64666 L .33638 .64751 L p .707 .577 .707 r
F P
0 g
s
.46258 .62665 m .46423 .66235 L .43676 .65741 L p .707 .577 .707 r
F P
0 g
s
.43676 .65741 m .43511 .62171 L .46258 .62665 L p .707 .577 .707 r
F P
0 g
s
.42948 .63102 m .42866 .64998 L .3975 .64752 L p .707 .577 .707 r
F P
0 g
s
.3975 .64752 m .39832 .62856 L .42948 .63102 L p .707 .577 .707 r
F P
0 g
s
.34282 .62858 m .34447 .66428 L .32049 .67305 L p .707 .577 .707 r
F P
0 g
s
.3657 .64666 m .36652 .62771 L .39832 .62856 L p .707 .577 .707 r
F P
0 g
s
.34447 .66428 m .34282 .62858 L .37215 .62272 L p .707 .577 .707 r
F P
0 g
s
.39832 .62856 m .3975 .64752 L .3657 .64666 L p .707 .577 .707 r
F P
0 g
s
.43511 .62171 m .43676 .65741 L .4056 .65606 L p .707 .577 .707 r
F P
0 g
s
.4056 .65606 m .40395 .62036 L .43511 .62171 L p .707 .577 .707 r
F P
0 g
s
.3738 .65842 m .37215 .62272 L .40395 .62036 L p .707 .577 .707 r
F P
0 g
s
.37215 .62272 m .3738 .65842 L .34447 .66428 L p .707 .577 .707 r
F P
0 g
s
.40395 .62036 m .4056 .65606 L .3738 .65842 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0089ooaD008Io
o`00O7oo1P000UYF00<005YFFUH02EYF00<005YFFUH015YF3000NWoo001fOol60008FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH7001cOol0075oo`D0009JEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEP00001aOol006ioo`<000MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP04001JEUYFFUH3001^
Ool006aoo`<000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00AJEP8006aoo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001XOol20004FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02001XOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001oogoo06Eoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001VOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH2
0008FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0004FUH>0009FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000D000AJEP03001JEUYF00EJEP03001JEP0000<000EJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00I7oo0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001QOol30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH4000;FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05moo`8000MJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00GGoo0`002EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0P0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
0000IGoo001LOol01000FUIJEP002EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000IGoo001JOol20003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Uoo`03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP04
001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005Qoo`8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Moo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0005FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
000HOol=0010Ool005Ioo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH00UYF00<005YF000057oo10000UYF00<005YFFUH01UYF
00<005YF00000`00?7oo001EOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020004FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000@Ool4
0006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3000iOol005Aoo`03001JEUYF00=JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00AJEP`000IJEP03001JEUYF009JEP05001JEUYFFUH00004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000>
Ool200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000gOol005Aoo`03001JEUYF
00=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00@000MJEP8000=JEP@0009JEP03001J
EUYF009JEP05001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1`00FUIJEUYF001JEP0000]oo`<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF008003Eoo`00Dgoo0P001EYF00<005YFFUH015YF00<005YFFUH01EYF10000UYF00<0
05YFFUH01UYF0P001eYF0`001EYF00@005YFFUH000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP07001JEUYFFUH005YF00002Goo0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00UYF0P00<goo001COol20005FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH40005FUH00`00FUIJEP06FUH2000:FUH20003FUH01000FUIJEP0015YF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00007Ool30008FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol0059oo`04001JEUYF0004
FUH00`00FUIJEP04FUH00`00FUH000020003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH2000;FUH3
00001EYF001JEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF00<007ooOol00goo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000<Goo001BOol01000FUIJEP0015YF00<005YF
FUH015YF0P000Woo00D005YFFUIJEP0000EJEP03001JEUYF00IJEP8000]JEP03001JEUYF0080009J
EP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP04001o
ogooOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP00<7oo001BOol01000FUIJEP001EYF00@005YFFUIJEP8000Aoo`05
001JEUYFFUH00005FUH00`00FUIJEP06FUH2000;FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00@007ooOol000MJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000_Ool0059oo`04001JEUYF0005FUH01000FUIJEP001goo00@005YFFUH000EJEP03001J
EUYF00IJEP8000]JEP04001JEUYFFUH300000eYF001JEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000Ool000001eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00<0
05YF00001EYF0`0027oo00@005YFFUH000EJEP03001JEUYF00IJEP8000]JEP07001JEUYF001JEP00
FUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
00=JEP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00@005YFFUH002moo`00Dgoo00<005YF00001EYF00<007ooOol027oo00@005YF
FUH000EJEP03001JEUYF00IJEP8000]JEP06001JEUYF001JEP000UYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080
02ioo`00Dgoo00<005YF000015YF00<007ooOol02Goo00@005YFFUH000EJEP03001JEUYF00IJEP80
00]JEP03001JEP0000=JEP03001JEP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005=oo`04001J
EUYF0002FUH00`00Oomoo`0:Ool01000FUIJEP001EYF00<005YFFUH01UYF0P002eYF0P0015YF00@0
05YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPl000IJEP03001JEUYF
009JEP05001JEUYFFUH0000^Ool005=oo`06001JEUYF001JEP003Goo00@005YFFUH000EJEP03001J
EUYF00IJEP8000YJEP<000AJEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP04FUH6000?
Ool40002FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001COol200000eYF0000000>Ool01000
FUIJEP001EYF00<005YFFUH01UYF0P0025YF0P000UYF00<005YFFUH00UYF00@005YFFUH0009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000IOol30005FUH01000FUIJEP00;Woo001DOol01000FUH000003Woo00@0
05YFFUH000EJEP03001JEUYF00IJEP8000IJEP8000AJEP03001JEUYF009JEP04001JEUYF0002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<005YFFUH0
1EYF00<005YF00000P007Woo0P000eYF00@005YFFUH002ioo`00E7oo00<005YF00000`0037oo00@0
05YFFUH000EJEP<000IJEP8000=JEP<000MJEP05001JEUYFFUH00002FUH01000FUIJEP0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP05001JEUYFFUH00007FUH2000SOol20000
15YF001JEUYF0P00;Goo001DOol01000FUH000000UYF0P002Woo00@005YFFUH000AJEPD000EJEP80
0003FUH00000009JEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP02FUH2000W
Ool20002FUH2000]Ool005Aoo`04FUH005YF0004FUH30007Ool01000FUIJEP0015YF1@001EYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00@005YFFUH0009JEP03001JEUYF009JEP03001JEUYF008002Yoo`80009JEP03001o
ogoo02]oo`00E7oo0P000UYF00<005YFFUH00UYF00<005YF00000`000goo00@005YFFUH000AJEP/0
00IJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJEP02FUH3000[Ool01P00FUH00000FUH0
02eoo`00E7oo0P000UYF00<005YFFUH00UYF00<005YFFUH00eYF400015YF00<005YFFUH01EYF0P00
1UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP03001JEUYF009JEP03001oogoo02Yoo`05001JEUYF001JEP02000]Ool0
05Aoo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000=JEP03001oogoo02Yoo`03001JEUYF009JEP03
001JEP0002eoo`00EGoo00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUH0000/Ool00`00FUIJEP03FUH00`00
FUH0000]Ool005Eoo`04001JEUYF0005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YF0000:Woo0`001EYF00@005YF000002ao
o`00EGoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00EJEP8000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP05001JEUYFFUH00002FUH2000ZOol01000FUIJEP001EYF00@005YFFUH002aoo`00EGoo00@005YF
FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00002FUH00`00Oomoo`0WOol20003FUH00`00FUIJEP03FUH01000FUIJEP00;7oo001FOol0
1000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
0P0015YF0P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00
009JEP8001Moo`<000aoo`8000IJEP03001JEUYF009JEP04001JEUYF000/Ool004Qoo``000=oo`03
001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF008000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEP00008001Aoo`D000Qoo`<00003FUH005YF00EJEP03001JEUYF009JEP04001JEUYF000/
Ool004Aoo`@0009JEP03001JEUYF00EJEP03001JEP0000D000AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP80019oo`D000Eoo`<000AJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8002eoo`00@7oo10001UYF00<005YFFUH01EYF00<005YF
FUH00eYF0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF
0P000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUH000AJEPD000eoo`D00003Ool00000008000MJEP03001JEUYF00AJEP03001J
EUYF00=JEP8002eoo`00?Goo0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF0P00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P001EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0000AJEP04001JEUYFFUH80006Ool50002FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP03FUH00`00Oomoo`0/Ool003Yoo`<000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00AJEP06001JEP00001JEP001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP04001JEUYFFUH70006FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00Oomoo`0/Ool003Qoo`8000MJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30006FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH4000:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01@00FUIJEUYF000015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol0;Goo000fOol30009
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH50002FUH00`00
FUIJEP04FUH?0008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00<7oo000eOol01000FUIJEP00
2EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0Woo2@0015YF00<005YFFUH01UYF00<005YF00000`0015YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
0000<Goo000cOol20003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP05FUH0
0`00FUH000080003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH5000;FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH2000bOol0039oo`03001JEUYF00AJEP03001JEUYF00EJEPT00004FUH005YFFUH?00001EYF0000
05YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P002EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YF
FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<007ooOol0<Goo000aOol20006FUH01000FUIJEUYF100000=JEP00FUH01eYF0P001eYF
0`000UYF00<005YFFUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000Aoo`00FUH000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2000dOol0031oo`03001JEP0000IJEP@000EJEP03
001JEUYF00MJEP03001JEUYF00=JEP<000AJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000IJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`8000AJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYF000fOol002moo`04001JEUYF0003FUH3
00000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00003FUH30006FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000
FUH0000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1000
00=oo`00FUH015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF
0`00=goo000^Ool01000FUIJEUYF100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00<005YF00000UYF0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP8003Uoo`00;Goo00<005YFFUH00UYF0P00
1UYF00<005YFFUH01UYF00<005YFFUH01UYF1`0000AJEP00FUH000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH400000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3000k
Ool002aoo`04001JEUYFFUH200000eYF001JEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP03
FUH00`00FUH000020003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH010001UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YF00000P00?Woo000/Ool01000FUIJEP000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF0`0000=JEP00FUH00UYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00eYF00D005YFFUIJ
EP0000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF009JEPH0009JEP03001JEUYF00AJEP`0045oo`00;7oo00@005YF000000=JEP03001J
EUYF00AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF009JEPX000UJEP03001JEUYF009JEP@00003FUH005YF00AJEP05
001JEUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20005FUH00`00FUIJEP02FUH20003Ool90004FUH00`00FUIJEP02FUH8000lOol002aoo`04001J
EP000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90002FUH200000eYF001J
EP03FUH00`00FUIJEP03FUH50003FUHL0004FUH01@00FUIJEUYF00000eYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001EYF00<005YFFUH00UYF00<005YF0000
10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00;7oo00@005YF0000
00=JEP03001JEUYF009JEP<000IJEPL000Uoo`H000AJEP04001JEUYFFUH20003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH300000eYF001JEP02FUH01@00FUIJ
EUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF3`001UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF00000P00=7oo000/Ool01000FUH000000eYF
00D005YFFUIJEP00009JEP03001JEUYF00@001=oo`03001oo`0000AJEP04001JEP000005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP020003FUH0
1@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00
FUH00UYF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00<Woo000/Ool01000FUH000000eYF00@005YF0000009JEP@001Moo`03001JEP00
00AJEPD000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF00<0009JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000eYF00@005YF000000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP80035oo`00;7oo00@005YFFUH000AJEP03001JEP00008001]o
o`03001JEP00009JEP8000Aoo`X000AJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH7
0002FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004
FUH30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH01000FUH00000;goo000/Ool01000FUIJEP000eYF0`007Woo00<005YF00000P001goo
0`000eYF00<005YFFUH06@000eYF0`000eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEP00FUH00002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Woo000/Ool2000015YF001JEUYF0P0087oo00@005YF001JEP<000Aoo`03001JEP0000<00005
FUH005YFFUH00004FUH50006FUH00`00FUIJEP06FUH400000eYF001JEP02FUH01000FUH000000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF001JEP00FUH00004FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01@00FUIJEUYF0000;Woo000/Ool2000015YF001JEP008Woo0P000UYF00<005YFFUH0
1P000eYF0`000UYF00<005YFFUH00UYF1@001UYF00<005YFFUH00eYF0`001EYF00D005YFFUIJEP00
009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH005YF0`0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00D005YFFUIJEP0002ioo`00;7oo0P0000=JEP0000000P008Goo0P000UYF00<005YF
FUH00UYF1@000UYF00<005YF00000UYF00<005YFFUH00UYF1@001UYF00<005YF00000`0000=JEP00
FUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00@005YF001JEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00;Goo0`0000=J
EP00FUH00`007Woo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT000AJEP<0009JEPL000EJEP03
001JEUYF00AJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEP0000800003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00AJEQL000AJEP03
001JEUYF00=JEP03001JEUYF008002eoo`00;Goo0`0000=JEP00FUH00eYF0`006goo0P000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH080001EYF00<005YFFUH00P00
;Goo000]Ool01@00FUH005YF00001EYF00<005YF00000`0047oo2@000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00P0000=JEP00FUH00eYF00<005YFFUH00eYF1@001eYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P000eYF00D005YFFUIJEP0002eoo`00;Goo00D005YFFUIJEP0000EJEP03
001JEUYF00=JEQ0000AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP00
00AJEP03001JEP0000<000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP06001JEP00001JEP000eYF00<007ooOol0:goo000]Ool20002FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YF
FUIJEP00FUH00004FUH30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF0P000eYF00<007ooOol0:goo000^Ool01000FUIJEP001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0`001eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00L005YFFUIJEP00FUH00002FUH20000
0goo000000030003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH00`00FUIJEP040002FUH00`00Oomoo`0[Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20009FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP<000Qooa8000=JEP03001JEUYF009J
EPh000=JEP<002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP08001JEUYFFUH005YF001JEP8000Ioo`03001JEUYF00800003FUH0000000Moo``000Uoo`80
0003FUH005YF00=JEP03001JEP0002eoo`00;Woo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP<000IJEP03001JEUYF00EJEP@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUH000020002Ool01000FUH000000UYF0`001goo
1@003Woo0P000eYF00<005YFFUH00UYF00<005YF0000;Goo000^Ool00`00FUIJEP020004FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH01000FUIJEUYF1@0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF009JEP@000IJEP8000Io
o`D000Uoo`D000EJEP03001JEUYF009JEP03001JEP0002eoo`00;Woo00D005YFFUH005YF00<00003
FUH005YF00IJEP03001JEUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00EJEPX000AJEP03
001JEUYF009JEPL000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUH000030003FUH20007Ool300000goo
000000070003FUH00`00FUIJEP04FUH02000FUIJEWooFUH005YF000]Ool002moo`04001JEP000003
FUH30006FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00Oomoo`02
Ool01@00FUIJEP00FUH02@001EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00=J
EQ0000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00<7oo00<005YF
000015YF00<005YF00000`000UYF00<005YFFUH01UYF0`000UYF1@001eYF00<005YFFUH00eYF0P00
1Goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000
FUIJEUYF0P00;Woo000aOol20004FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP06FUH00`00FUIJ
EP020007Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01eYF5@001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP05001JEUYFFUH0000_Ool0
039oo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP<000Uoo`04001JEUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<005YFFUH0
2EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF000`
Ool003=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP8000]oo`04001JEUYF0005FUH00`00FUIJEP06FUH50002FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00
<Goo000eOol200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
000=Ool01000FUIJEP001EYF00@005YFFUIJEPD000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00@000IJEP03001JEUYF00=JEP@000EJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP8003=oo`00=goo0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P003goo00@005YFFUH000EJEP@00003FUH0
05YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH2000eOol003Yoo`@0009JEP03001JEUYF00IJEP03001J
EUYF009JEPH0019oo`04001JEUYF0003FUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH40005FUH01000FUIJEUYF100000=JEP00FUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000003Moo`00?Woo4000
67oo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00MJEP05001JEUYFFUH00004FUH01@00FUIJEUYF00000eYF0`001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@00>Goo001VOol00`00FUIJEP020000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001UYF10000UYF00<005YFFUH0
1UYF00<005YFFUH00UYF2@00?Woo001VOol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUH00003FUH00`00FUIJEP04FUH01000Oomoogoo4000Agoo0018Ool3000KOol20004FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH30003FUH00`00FUIJEP02FUH2001KOol004Moo`D001Yoo`80
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP05001JEUYFFUH0001MOol004Mo
o`D001Yoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000AJEP<005ioo`00Agoo
1@006Woo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000eYF0P00H7oo0018Ool3
000KOol20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000015YF00000000HWoo000mOol9000Q
Ool00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3001UOol0031oo`d000AJEP03001J
EUYF009JEQ40011oo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP03001oogoo06Eo
o`00;Goo0`000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPD000aoo`80009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00;7oo0P00
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YF00000P002goo0`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00@005YFFUIJEP8006Uoo`00:goo00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`002Woo0P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00@005YF000006]oo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00<005YF00000P002Goo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF1000KGoo000[Ool00`00FUH00003FUH01000FUIJEUYF6@00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000]oo`<00003FUH005YF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00H0071oo`00:goo00<005YF
00000UYF1@006Goo200015YF00<005YFFUH00eYF00@005YFFUIJEP8000eoo`L000EJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD0009oo`D006moo`00:goo00<005YF00000P000UYF
1`007Goo1`000eYF00@005YFFUIJEP8001Aoo``000IJEP03001JEUYF00YJEP03001JEUYF00H000Mo
o`D006moo`00:goo0P000UYF00<005YFFUH00eYF00@005YFFUIJEPT001Uoo`H000=JEP80021ooaH0
00eoo`D006moo`00:goo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH00UYF6@00
0eYF00<005YFFUH00P0000=JEP000000A7oo0`00L7oo000/Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH3000aOolI001]Ool002ioo`<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002]oo`H000=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP006Eoo`00<Goo0`0000=JEP00FUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF
0P00:Goo0`000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00@005YFFUIJEPL005ioo`00=7oo1@0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00`00:7oo0`0015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01000FWoo000iOolB0004
FUH00`00FUIJEP02FUH=000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH3001HOol004]oo`T003Qo
o`03001JEP0000AJEP04001JEUYFFUHI0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EP00Egoo002<Ool00`00FUH00002FUH6000IOol80004FUH00`00FUIJEP03FUH00`00FUIJEP02001F
Ool008aoo`03001JEP0000<00004FUH00000000ROol60004FUH00`00FUIJEP02001FOol008aoo`80
00=JEP03001JEUYF009JEPD002=oo`<00004FUH005YFFUH2001FOol008aoo`8000=JEP03001JEUYF
00=JEP04001JEUYFFUHB0009Ool>00000eYF0000001FOol008eoo`05001JEUYFFUH00005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH00`00FUIJEP04FUH01000FUIJEUYF
0`00EWoo002>Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EWoo002@Ool40003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH00`00FUH0001FOol009Aoo`L000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF00@005Moo`00Vgoo200015YF00<005YFFUH01UYF00<005YF
FUH01UYF00@005YFFUIJEPD005]oo`00Xgoo6P00H7oo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57093 .63369 m .56388 .6909 L .59495 .69446 L p .707 .577 .707 r
F P
0 g
s
.59495 .69446 m .602 .63724 L .57093 .63369 L p .707 .577 .707 r
F P
0 g
s
.602 .63724 m .59495 .69446 L .62648 .69848 L p .707 .577 .707 r
F P
0 g
s
.62648 .69848 m .63353 .64126 L .602 .63724 L p .707 .577 .707 r
F P
0 g
s
.63353 .64126 m .62648 .69848 L .6554 .70258 L p .707 .577 .707 r
F P
0 g
s
.6554 .70258 m .66245 .64536 L .63353 .64126 L p .707 .577 .707 r
F P
0 g
s
.54337 .63095 m .53632 .68817 L .56388 .6909 L p .707 .577 .707 r
F P
0 g
s
.56388 .6909 m .57093 .63369 L .54337 .63095 L p .707 .577 .707 r
F P
0 g
s
.66245 .64536 m .6554 .70258 L .67886 .70635 L p .707 .577 .707 r
F P
0 g
s
.67886 .70635 m .68591 .64913 L .66245 .64536 L p .707 .577 .707 r
F P
0 g
s
.52201 .62929 m .51496 .68651 L .53632 .68817 L p .707 .577 .707 r
F P
0 g
s
.53632 .68817 m .54337 .63095 L .52201 .62929 L p .707 .577 .707 r
F P
0 g
s
.5944 .84194 m .59605 .80403 L .56489 .80157 L p .707 .577 .707 r
F P
0 g
s
.59605 .80403 m .5944 .84194 L .6262 .8428 L p .707 .577 .707 r
F P
0 g
s
.6262 .8428 m .62785 .80489 L .59605 .80403 L p .707 .577 .707 r
F P
0 g
s
.62785 .80489 m .6262 .8428 L .65552 .84198 L p .707 .577 .707 r
F P
0 g
s
.65552 .84198 m .65717 .80406 L .62785 .80489 L p .707 .577 .707 r
F P
0 g
s
.68591 .64913 m .67886 .70635 L .69458 .70943 L p .707 .577 .707 r
F P
0 g
s
.56489 .80157 m .56324 .83948 L .5944 .84194 L p .707 .577 .707 r
F P
0 g
s
.56324 .83948 m .56489 .80157 L .53742 .79774 L p .707 .577 .707 r
F P
0 g
s
.69458 .70943 m .70163 .65221 L .68591 .64913 L p .707 .577 .707 r
F P
0 g
s
.50895 .62889 m .5019 .6861 L .51496 .68651 L p .707 .577 .707 r
F P
0 g
s
.51496 .68651 m .52201 .62929 L .50895 .62889 L p .707 .577 .707 r
F P
0 g
s
.53742 .79774 m .53577 .83565 L .56324 .83948 L p .707 .577 .707 r
F P
0 g
s
.60249 .82254 m .60167 .80468 L .57051 .80333 L p .707 .577 .707 r
F P
0 g
s
.60167 .80468 m .60249 .82254 L .63429 .82018 L p .707 .577 .707 r
F P
0 g
s
.63429 .82018 m .63347 .80233 L .60167 .80468 L p .707 .577 .707 r
F P
0 g
s
.65717 .80406 m .65552 .84198 L .6795 .83954 L p .707 .577 .707 r
F P
0 g
s
.6795 .83954 m .68115 .80163 L .65717 .80406 L p .707 .577 .707 r
F P
0 g
s
.63347 .80233 m .63429 .82018 L .66362 .81434 L p .707 .577 .707 r
F P
0 g
s
.66362 .81434 m .6628 .79649 L .63347 .80233 L p .707 .577 .707 r
F P
0 g
s
.57133 .82118 m .57051 .80333 L .54304 .79839 L p .707 .577 .707 r
F P
0 g
s
.57051 .80333 m .57133 .82118 L .60249 .82254 L p .707 .577 .707 r
F P
0 g
s
.53577 .83565 m .53742 .79774 L .51632 .79292 L p .707 .577 .707 r
F P
0 g
s
.68115 .80163 m .6795 .83954 L .6958 .83574 L p .707 .577 .707 r
F P
0 g
s
.6958 .83574 m .69744 .79782 L .68115 .80163 L p .707 .577 .707 r
F P
0 g
s
.6628 .79649 m .66362 .81434 L .6876 .80559 L p .707 .577 .707 r
F P
0 g
s
.6876 .80559 m .68678 .78773 L .6628 .79649 L p .707 .577 .707 r
F P
0 g
s
.51632 .79292 m .51468 .83083 L .53577 .83565 L p .707 .577 .707 r
F P
0 g
s
.54304 .79839 m .54386 .81625 L .57133 .82118 L p .707 .577 .707 r
F P
0 g
s
.70163 .65221 m .69458 .70943 L .70101 .7115 L p .707 .577 .707 r
F P
0 g
s
.70101 .7115 m .70806 .65429 L .70163 .65221 L p .707 .577 .707 r
F P
0 g
s
.54386 .81625 m .54304 .79839 L .52195 .79036 L p .707 .577 .707 r
F P
0 g
s
.50547 .62977 m .49842 .68698 L .5019 .6861 L p .707 .577 .707 r
F P
0 g
s
.5019 .6861 m .50895 .62889 L .50547 .62977 L p .707 .577 .707 r
F P
0 g
s
.52195 .79036 m .52277 .80821 L .54386 .81625 L p .707 .577 .707 r
F P
0 g
s
.51468 .83083 m .51632 .79292 L .50368 .78759 L p .707 .577 .707 r
F P
0 g
s
.69744 .79782 m .6958 .83574 L .69871 .83374 L p .707 .577 .707 r
F P
0 g
s
.69871 .83374 m .7028 .83094 L p .69916 .80841 L .707 .577 .707 r
F P
0 g
s
.69916 .80841 m .69744 .79782 L .69871 .83374 L .707 .577 .707 r
F
.69934 .7978 m .70389 .79478 L p .69943 .79294 L F P
0 g
s
.70389 .79478 m .70308 .77693 L .69967 .77918 L p .707 .577 .707 r
F P
0 g
s
.70389 .79478 m .69967 .77918 L .69943 .79294 L .707 .577 .707 r
F
.70308 .77693 m .70389 .79478 L .7109 .78298 L p F P
0 g
s
.7028 .83094 m .70445 .79302 L .69937 .79651 L p .707 .577 .707 r
F P
0 g
s
.69937 .79651 m .69744 .79782 L p .69916 .80841 L .707 .577 .707 r
F P
0 g
s
.7028 .83094 m .69937 .79651 L .69916 .80841 L .707 .577 .707 r
F
.69967 .77918 m .68678 .78773 L p .69943 .79294 L F P
0 g
s
.68678 .78773 m .6876 .80559 L .69934 .7978 L p .707 .577 .707 r
F P
0 g
s
.69943 .79294 m .68678 .78773 L .69934 .7978 L .707 .577 .707 r
F
.50368 .78759 m .50203 .8255 L .51468 .83083 L p F P
0 g
s
.52277 .80821 m .52195 .79036 L .5093 .78001 L p .707 .577 .707 r
F P
0 g
s
.70806 .65429 m .70101 .7115 L .69752 .71238 L p .707 .577 .707 r
F P
0 g
s
.69752 .71238 m .70457 .65517 L .70806 .65429 L p .707 .577 .707 r
F P
0 g
s
.5093 .78001 m .51012 .79787 L .52277 .80821 L p .707 .577 .707 r
F P
0 g
s
.4871 .82195 m .49017 .31806 L .44616 .31527 L p .707 .577 .707 r
F P
0 g
s
.5119 .63184 m .50485 .68906 L .49842 .68698 L p .707 .577 .707 r
F P
0 g
s
.49842 .68698 m .50547 .62977 L .5119 .63184 L p .707 .577 .707 r
F P
0 g
s
.50203 .8255 m .50368 .78759 L .50071 .78226 L p .707 .577 .707 r
F P
0 g
s
.50071 .78226 m .49906 .82017 L .50203 .8255 L p .707 .577 .707 r
F P
0 g
s
.51012 .79787 m .5093 .78001 L .50634 .76837 L p .707 .577 .707 r
F P
0 g
s
.50634 .76837 m .50716 .78622 L .51012 .79787 L p .707 .577 .707 r
F P
0 g
s
.52761 .63492 m .52056 .69214 L .50485 .68906 L p .707 .577 .707 r
F P
0 g
s
.50485 .68906 m .5119 .63184 L .52761 .63492 L p .707 .577 .707 r
F P
0 g
s
.50716 .78622 m .50634 .76837 L .51188 .75903 L p .707 .577 .707 r
F P
0 g
s
.51188 .75903 m .51334 .75656 L p .51195 .76323 L .707 .577 .707 r
F P
0 g
s
.50716 .78622 m .51188 .75903 L .51195 .76323 L .707 .577 .707 r
F
.51218 .77642 m .524 .77366 L p .5126 .80018 L F P
0 g
s
.51334 .75656 m .51416 .77442 L .50716 .78622 L p .707 .577 .707 r
F P
0 g
s
.50606 .81537 m .50771 .77746 L .51218 .77642 L p .707 .577 .707 r
F P
0 g
s
.50606 .81537 m .51218 .77642 L .5126 .80018 L .707 .577 .707 r
F
.49906 .82017 m .50071 .78226 L .50771 .77746 L p F P
0 g
s
.50771 .77746 m .50606 .81537 L .49906 .82017 L p .707 .577 .707 r
F P
0 g
s
.55108 .63869 m .54403 .69591 L .52056 .69214 L p .707 .577 .707 r
F P
0 g
s
.52056 .69214 m .52761 .63492 L .55108 .63869 L p .707 .577 .707 r
F P
0 g
s
.524 .77366 m .52235 .81157 L .50606 .81537 L p .707 .577 .707 r
F P
0 g
s
.51416 .77442 m .51334 .75656 L .52964 .74576 L p .707 .577 .707 r
F P
0 g
s
.52964 .74576 m .53046 .76361 L .51416 .77442 L p .707 .577 .707 r
F P
0 g
s
.52235 .81157 m .524 .77366 L .54799 .77122 L p .707 .577 .707 r
F P
0 g
s
.54799 .77122 m .54634 .80914 L .52235 .81157 L p .707 .577 .707 r
F P
0 g
s
.49017 .31806 m .4871 .82195 L .53204 .82116 L p .707 .577 .707 r
F P
0 g
s
.53046 .76361 m .52964 .74576 L .55362 .73701 L p .707 .577 .707 r
F P
0 g
s
.55362 .73701 m .55444 .75486 L .53046 .76361 L p .707 .577 .707 r
F P
0 g
s
.53204 .82116 m .53512 .31728 L .49017 .31806 L p .707 .577 .707 r
F P
0 g
s
.7109 .78298 m .71008 .76513 L .70308 .77693 L p .707 .577 .707 r
F P
0 g
s
.57999 .64279 m .57294 .70001 L .54403 .69591 L p .707 .577 .707 r
F P
0 g
s
.54403 .69591 m .55034 .64466 L p .57999 .64279 L .707 .577 .707 r
F P
0 g
s
.55034 .64466 m .55108 .63869 L .55346 .63903 L p .707 .577 .707 r
F P
0 g
s
.55346 .63903 m .57999 .64279 L p .55034 .64466 L .707 .577 .707 r
F P
0 g
s
.61153 .64681 m .60448 .70403 L .57586 .70038 L p .707 .577 .707 r
F P
0 g
s
.57586 .70038 m .57294 .70001 L p .57695 .69448 L .707 .577 .707 r
F P
0 g
s
.57695 .69448 m .61153 .64681 L .57586 .70038 L .707 .577 .707 r
F
.6426 .65037 m .63555 .70758 L .61031 .7047 L p F P
0 g
s
.61031 .7047 m .60448 .70403 L p .61105 .69477 L .707 .577 .707 r
F P
0 g
s
.61105 .69477 m .6426 .65037 L .61031 .7047 L .707 .577 .707 r
F
.67016 .6531 m .66311 .71032 L .63555 .70758 L p F P
0 g
s
.63555 .70758 m .6426 .65037 L .67016 .6531 L p .707 .577 .707 r
F P
0 g
s
.60448 .70403 m .61153 .64681 L .6146 .64716 L p .707 .577 .707 r
F P
0 g
s
.6146 .64716 m .6426 .65037 L p .61105 .69477 L .707 .577 .707 r
F P
0 g
s
.60448 .70403 m .6146 .64716 L .61105 .69477 L .707 .577 .707 r
F
.63862 .81163 m .64027 .77372 L .66774 .77755 L p F P
0 g
s
.64591 .73016 m .64672 .74802 L .61556 .74666 L p .707 .577 .707 r
F P
0 g
s
.61556 .74666 m .61475 .72881 L .64591 .73016 L p .707 .577 .707 r
F P
0 g
s
.64058 .78868 m .64366 .28479 L .64145 .28724 L p .707 .577 .707 r
F P
0 g
s
.64145 .28724 m .63366 .29592 L p .63479 .37655 L .707 .577 .707 r
F P
0 g
s
.64058 .78868 m .64145 .28724 L .63479 .37655 L .707 .577 .707 r
F
.64027 .77372 m .63862 .81163 L .60746 .80917 L p F P
0 g
s
.60746 .80917 m .60911 .77126 L .64027 .77372 L p .707 .577 .707 r
F P
0 g
s
.63059 .7998 m .64058 .78868 L p .63479 .37655 L .707 .577 .707 r
F P
0 g
s
.63366 .29592 m .63302 .40027 L p .63479 .37655 L .707 .577 .707 r
F P
0 g
s
.63302 .40027 m .63059 .7998 L p .63479 .37655 L .707 .577 .707 r
F P
0 g
s
.57566 .80831 m .57731 .77039 L .60911 .77126 L p .707 .577 .707 r
F P
0 g
s
.60911 .77126 m .60746 .80917 L .57566 .80831 L p .707 .577 .707 r
F P
0 g
s
.58376 .74902 m .58295 .73117 L .61475 .72881 L p .707 .577 .707 r
F P
0 g
s
.61475 .72881 m .61556 .74666 L .58376 .74902 L p .707 .577 .707 r
F P
0 g
s
.60748 .80952 m .63059 .7998 L p .61743 .47536 L .707 .577 .707 r
F P
0 g
s
.61055 .30564 m .60925 .51967 L p .61743 .47536 L .707 .577 .707 r
F P
0 g
s
.57294 .70001 m .57999 .64279 L .61153 .64681 L p .707 .577 .707 r
F P
0 g
s
.60925 .51967 m .60748 .80952 L p .61743 .47536 L .707 .577 .707 r
F P
0 g
s
.54634 .80914 m .54799 .77122 L .57731 .77039 L p .707 .577 .707 r
F P
0 g
s
.55444 .75486 m .55362 .73701 L .56748 .73425 L p .707 .577 .707 r
F P
0 g
s
.56748 .73425 m .58295 .73117 L p .56946 .74238 L .707 .577 .707 r
F P
0 g
s
.55444 .75486 m .56748 .73425 L .56946 .74238 L .707 .577 .707 r
F
.57731 .77039 m .57566 .80831 L .54634 .80914 L p F P
0 g
s
.58295 .73117 m .58376 .74902 L .57166 .75143 L p .707 .577 .707 r
F P
0 g
s
.57166 .75143 m .55444 .75486 L p .56946 .74238 L .707 .577 .707 r
F P
0 g
s
.56946 .74238 m .58295 .73117 L .57166 .75143 L .707 .577 .707 r
F
.57484 .60045 m .57387 .76054 L p .59249 .56861 L F P
0 g
s
.57387 .76054 m .57352 .81688 L p .57688 .77295 L .707 .577 .707 r
F P
0 g
s
.59249 .56861 m .57387 .76054 L .57688 .77295 L .707 .577 .707 r
F
.60748 .80952 m .59249 .56861 L .57688 .77295 L F
.57352 .81688 m .58685 .81399 L p .57688 .77295 L F P
0 g
s
.58685 .81399 m .60748 .80952 L p .57688 .77295 L .707 .577 .707 r
F P
0 g
s
.5766 .313 m .57484 .60045 L p .59249 .56861 L .707 .577 .707 r
F P
0 g
s
.53512 .31728 m .53204 .82116 L .57352 .81688 L p .707 .577 .707 r
F P
0 g
s
.57352 .81688 m .5766 .313 L .53512 .31728 L p .707 .577 .707 r
F P
0 g
s
.44309 .81915 m .44616 .31527 L .4074 .30918 L p .707 .577 .707 r
F P
0 g
s
.44616 .31527 m .44309 .81915 L .4871 .82195 L p .707 .577 .707 r
F P
0 g
s
.60748 .80952 m .61055 .30564 L .5766 .313 L p .707 .577 .707 r
F P
0 g
s
.70445 .79302 m .7028 .83094 L .69983 .82561 L p .707 .577 .707 r
F P
0 g
s
.69983 .82561 m .70148 .7877 L .70445 .79302 L p .707 .577 .707 r
F P
0 g
s
.70457 .65517 m .69752 .71238 L .68446 .71198 L p .707 .577 .707 r
F P
0 g
s
.68446 .71198 m .69151 .65476 L .70457 .65517 L p .707 .577 .707 r
F P
0 g
s
.22792 .59687 m .22087 .65409 L .25194 .65764 L p .707 .577 .707 r
F P
0 g
s
.25194 .65764 m .25899 .60043 L .22792 .59687 L p .707 .577 .707 r
F P
0 g
s
.25899 .60043 m .25194 .65764 L .28347 .66167 L p .707 .577 .707 r
F P
0 g
s
.28347 .66167 m .29052 .60445 L .25899 .60043 L p .707 .577 .707 r
F P
0 g
s
.40433 .81306 m .4074 .30918 L .37767 .30038 L p .707 .577 .707 r
F P
0 g
s
.4074 .30918 m .40433 .81306 L .44309 .81915 L p .707 .577 .707 r
F P
0 g
s
.71008 .76513 m .7109 .78298 L .70793 .77134 L p .707 .577 .707 r
F P
0 g
s
.70793 .77134 m .70711 .75348 L .71008 .76513 L p .707 .577 .707 r
F P
0 g
s
.29052 .60445 m .28347 .66167 L .31239 .66576 L p .707 .577 .707 r
F P
0 g
s
.31239 .66576 m .31944 .60855 L .29052 .60445 L p .707 .577 .707 r
F P
0 g
s
.20036 .59413 m .19331 .65135 L .22087 .65409 L p .707 .577 .707 r
F P
0 g
s
.22087 .65409 m .22792 .59687 L .20036 .59413 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31944 .60855 m .31239 .66576 L .33585 .66953 L p .707 .577 .707 r
F P
0 g
s
.33585 .66953 m .3429 .61232 L .31944 .60855 L p .707 .577 .707 r
F P
0 g
s
.63059 .7998 m .63366 .29592 L .61055 .30564 L p .707 .577 .707 r
F P
0 g
s
.179 .59248 m .17195 .6497 L .19331 .65135 L p .707 .577 .707 r
F P
0 g
s
.19331 .65135 m .20036 .59413 L .179 .59248 L p .707 .577 .707 r
F P
0 g
s
.69151 .65476 m .68446 .71198 L .66311 .71032 L p .707 .577 .707 r
F P
0 g
s
.70148 .7877 m .69983 .82561 L .68718 .82028 L p .707 .577 .707 r
F P
0 g
s
.68718 .82028 m .68883 .78236 L .70148 .7877 L p .707 .577 .707 r
F P
0 g
s
.66311 .71032 m .67016 .6531 L .69151 .65476 L p .707 .577 .707 r
F P
0 g
s
.70711 .75348 m .70793 .77134 L .69529 .76099 L p .707 .577 .707 r
F P
0 g
s
.69529 .76099 m .69447 .74314 L .70711 .75348 L p .707 .577 .707 r
F P
0 g
s
.25139 .80513 m .25304 .76722 L .22188 .76475 L p .707 .577 .707 r
F P
0 g
s
.25304 .76722 m .25139 .80513 L .28319 .80599 L p .707 .577 .707 r
F P
0 g
s
.28319 .80599 m .28484 .76808 L .25304 .76722 L p .707 .577 .707 r
F P
0 g
s
.3746 .80426 m .37767 .30038 L .35989 .28974 L p .707 .577 .707 r
F P
0 g
s
.37767 .30038 m .3746 .80426 L .40433 .81306 L p .707 .577 .707 r
F P
0 g
s
.28484 .76808 m .28319 .80599 L .31251 .80516 L p .707 .577 .707 r
F P
0 g
s
.31251 .80516 m .31416 .76725 L .28484 .76808 L p .707 .577 .707 r
F P
0 g
s
.3429 .61232 m .33585 .66953 L .35157 .67261 L p .707 .577 .707 r
F P
0 g
s
.22188 .76475 m .22023 .80266 L .25139 .80513 L p .707 .577 .707 r
F P
0 g
s
.22023 .80266 m .22188 .76475 L .19441 .76092 L p .707 .577 .707 r
F P
0 g
s
.35157 .67261 m .35862 .61539 L .3429 .61232 L p .707 .577 .707 r
F P
0 g
s
.16594 .59207 m .15889 .64929 L .17195 .6497 L p .707 .577 .707 r
F P
0 g
s
.17195 .6497 m .179 .59248 L .16594 .59207 L p .707 .577 .707 r
F P
0 g
s
.19441 .76092 m .19276 .79884 L .22023 .80266 L p .707 .577 .707 r
F P
0 g
s
.25948 .78572 m .25866 .76787 L .2275 .76651 L p .707 .577 .707 r
F P
0 g
s
.25866 .76787 m .25948 .78572 L .29128 .78337 L p .707 .577 .707 r
F P
0 g
s
.29128 .78337 m .29046 .76551 L .25866 .76787 L p .707 .577 .707 r
F P
0 g
s
.31416 .76725 m .31251 .80516 L .3365 .80273 L p .707 .577 .707 r
F P
0 g
s
.3365 .80273 m .33815 .76481 L .31416 .76725 L p .707 .577 .707 r
F P
0 g
s
.29046 .76551 m .29128 .78337 L .32061 .77753 L p .707 .577 .707 r
F P
0 g
s
.32061 .77753 m .31979 .75967 L .29046 .76551 L p .707 .577 .707 r
F P
0 g
s
.22832 .78437 m .2275 .76651 L .20003 .76158 L p .707 .577 .707 r
F P
0 g
s
.2275 .76651 m .22832 .78437 L .25948 .78572 L p .707 .577 .707 r
F P
0 g
s
.19276 .79884 m .19441 .76092 L .17332 .75611 L p .707 .577 .707 r
F P
0 g
s
.68883 .78236 m .68718 .82028 L .66609 .81546 L p .707 .577 .707 r
F P
0 g
s
.66609 .81546 m .66774 .77755 L .68883 .78236 L p .707 .577 .707 r
F P
0 g
s
.69447 .74314 m .69529 .76099 L .6742 .75296 L p .707 .577 .707 r
F P
0 g
s
.6742 .75296 m .67338 .7351 L .69447 .74314 L p .707 .577 .707 r
F P
0 g
s
.33815 .76481 m .3365 .80273 L .35279 .79892 L p .707 .577 .707 r
F P
0 g
s
.35279 .79892 m .35444 .76101 L .33815 .76481 L p .707 .577 .707 r
F P
0 g
s
.31979 .75967 m .32061 .77753 L .34459 .76877 L p .707 .577 .707 r
F P
0 g
s
.34459 .76877 m .34377 .75092 L .31979 .75967 L p .707 .577 .707 r
F P
0 g
s
.17332 .75611 m .17167 .79402 L .19276 .79884 L p .707 .577 .707 r
F P
0 g
s
.20003 .76158 m .20085 .77943 L .22832 .78437 L p .707 .577 .707 r
F P
0 g
s
.35862 .61539 m .35157 .67261 L .358 .67469 L p .707 .577 .707 r
F P
0 g
s
.358 .67469 m .36505 .61747 L .35862 .61539 L p .707 .577 .707 r
F P
0 g
s
.20085 .77943 m .20003 .76158 L .17894 .75354 L p .707 .577 .707 r
F P
0 g
s
.16246 .59295 m .15541 .65017 L .15889 .64929 L p .707 .577 .707 r
F P
0 g
s
.15889 .64929 m .16594 .59207 L .16246 .59295 L p .707 .577 .707 r
F P
0 g
s
.35444 .76101 m .35279 .79892 L .3557 .79693 L p .707 .577 .707 r
F P
0 g
s
.35615 .77159 m .35444 .76101 L .3557 .79693 L .707 .577 .707 r
F
.35634 .76099 m .36089 .75797 L p .35642 .75613 L F P
0 g
s
.36089 .75797 m .36007 .74011 L .35667 .74237 L p .707 .577 .707 r
F P
0 g
s
.36089 .75797 m .35667 .74237 L .35642 .75613 L .707 .577 .707 r
F
.36007 .74011 m .36089 .75797 L .36789 .74617 L p F P
0 g
s
.35979 .79412 m .36144 .75621 L .35636 .75969 L p .707 .577 .707 r
F P
0 g
s
.35636 .75969 m .35444 .76101 L p .35615 .77159 L .707 .577 .707 r
F P
0 g
s
.35979 .79412 m .35636 .75969 L .35615 .77159 L .707 .577 .707 r
F
.35667 .74237 m .34377 .75092 L p .35642 .75613 L F P
0 g
s
.34377 .75092 m .34459 .76877 L .35634 .76099 L p .707 .577 .707 r
F P
0 g
s
.35642 .75613 m .34377 .75092 L .35634 .76099 L .707 .577 .707 r
F
.3557 .79693 m .35979 .79412 L p .35615 .77159 L F P
0 g
s
.358 .67469 m .35451 .67557 L p .36326 .62736 L .707 .577 .707 r
F P
0 g
s
.36505 .61747 m .36375 .62799 L p .36326 .62736 L .707 .577 .707 r
F P
0 g
s
.36375 .62799 m .358 .67469 L p .36326 .62736 L .707 .577 .707 r
F P
0 g
s
.34146 .67516 m .3485 .61794 L .36049 .61832 L p .707 .577 .707 r
F P
0 g
s
.36049 .61832 m .36156 .61835 L p .36064 .62097 L .707 .577 .707 r
F P
0 g
s
.34146 .67516 m .36049 .61832 L .36064 .62097 L .707 .577 .707 r
F
.35989 .28974 m .3558 .27829 L p .35633 .54544 L F P
0 g
s
.35648 .61886 m .3571 .55891 L .35633 .54544 L .707 .577 .707 r
F
.3571 .55891 m .35989 .28974 L .35633 .54544 L F
.36156 .61835 m .36505 .61747 L p .36326 .62736 L F P
0 g
s
.35451 .67557 m .36083 .62432 L p .36326 .62736 L .707 .577 .707 r
F P
0 g
s
.36083 .62432 m .36156 .61835 L p .36326 .62736 L .707 .577 .707 r
F P
0 g
s
.36156 .61835 m .35451 .67557 L .34146 .67516 L p .707 .577 .707 r
F P
0 g
s
.35847 .75088 m .35682 .7888 L .34418 .78346 L p .707 .577 .707 r
F P
0 g
s
.34418 .78346 m .34582 .74555 L .35847 .75088 L p .707 .577 .707 r
F P
0 g
s
.36789 .74617 m .36707 .72831 L .36007 .74011 L p .707 .577 .707 r
F P
0 g
s
.36411 .71667 m .36492 .73452 L .3575 .72845 L p .707 .577 .707 r
F P
0 g
s
.3575 .72845 m .35228 .72418 L p .35779 .72068 L .707 .577 .707 r
F P
0 g
s
.35779 .72068 m .36411 .71667 L .3575 .72845 L .707 .577 .707 r
F
.35228 .72418 m .35146 .70632 L .35813 .71178 L p F P
0 g
s
.35813 .71178 m .36411 .71667 L p .35779 .72068 L .707 .577 .707 r
F P
0 g
s
.35228 .72418 m .35813 .71178 L .35779 .72068 L .707 .577 .707 r
F
.35673 .74878 m .35788 .62062 L .35648 .61886 L F
.36144 .75621 m .35979 .79412 L .35682 .7888 L p F P
0 g
s
.35682 .7888 m .35847 .75088 L .36144 .75621 L p .707 .577 .707 r
F P
0 g
s
.35682 .79362 m .35717 .73728 L p .35673 .74878 L .707 .577 .707 r
F P
0 g
s
.35717 .73728 m .35788 .62062 L p .35673 .74878 L .707 .577 .707 r
F P
0 g
s
.35273 .78218 m .35522 .78913 L p .35648 .61886 L .707 .577 .707 r
F P
0 g
s
.35522 .78913 m .35682 .79362 L p .35673 .74878 L .707 .577 .707 r
F P
0 g
s
.35673 .74878 m .35648 .61886 L .35522 .78913 L .707 .577 .707 r
F
.3558 .27829 m .35375 .61544 L p .35648 .61886 L F P
0 g
s
.35375 .61544 m .35273 .78218 L p .35648 .61886 L .707 .577 .707 r
F P
0 g
s
.35788 .62062 m .35989 .28974 L p .35648 .61886 L .707 .577 .707 r
F P
0 g
s
.36707 .72831 m .36789 .74617 L .36492 .73452 L p .707 .577 .707 r
F P
0 g
s
.36492 .73452 m .36411 .71667 L .36707 .72831 L p .707 .577 .707 r
F P
0 g
s
.35989 .28974 m .35682 .79362 L .3746 .80426 L p .707 .577 .707 r
F P
0 g
s
.17894 .75354 m .17976 .7714 L .20085 .77943 L p .707 .577 .707 r
F P
0 g
s
.17167 .79402 m .17332 .75611 L .16067 .75077 L p .707 .577 .707 r
F P
0 g
s
.66774 .77755 m .66609 .81546 L .63862 .81163 L p .707 .577 .707 r
F P
0 g
s
.67338 .7351 m .6742 .75296 L .64672 .74802 L p .707 .577 .707 r
F P
0 g
s
.64672 .74802 m .64591 .73016 L .67338 .7351 L p .707 .577 .707 r
F P
0 g
s
.16067 .75077 m .15902 .78869 L .17167 .79402 L p .707 .577 .707 r
F P
0 g
s
.17976 .7714 m .17894 .75354 L .1663 .7432 L p .707 .577 .707 r
F P
0 g
s
.1663 .7432 m .16711 .76105 L .17976 .7714 L p .707 .577 .707 r
F P
0 g
s
.64366 .28479 m .64058 .78868 L .63649 .77723 L p .707 .577 .707 r
F P
0 g
s
.63649 .77723 m .63956 .27335 L .64366 .28479 L p .707 .577 .707 r
F P
0 g
s
.16889 .59503 m .16184 .65225 L .15541 .65017 L p .707 .577 .707 r
F P
0 g
s
.15541 .65017 m .16246 .59295 L .16889 .59503 L p .707 .577 .707 r
F P
0 g
s
.15902 .78869 m .16067 .75077 L .1577 .74545 L p .707 .577 .707 r
F P
0 g
s
.1577 .74545 m .15605 .78336 L .15902 .78869 L p .707 .577 .707 r
F P
0 g
s
.35273 .78218 m .3558 .27829 L .3658 .26717 L p .707 .577 .707 r
F P
0 g
s
.16711 .76105 m .1663 .7432 L .16333 .73155 L p .707 .577 .707 r
F P
0 g
s
.16333 .73155 m .16415 .74941 L .16711 .76105 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1846 .5981 m .17755 .65532 L .16184 .65225 L p .707 .577 .707 r
F P
0 g
s
.16184 .65225 m .16889 .59503 L .1846 .5981 L p .707 .577 .707 r
F P
0 g
s
.16415 .74941 m .16333 .73155 L .16887 .72221 L p .707 .577 .707 r
F P
0 g
s
.16887 .72221 m .17033 .71975 L p .16894 .72641 L .707 .577 .707 r
F P
0 g
s
.16415 .74941 m .16887 .72221 L .16894 .72641 L .707 .577 .707 r
F
.16917 .7396 m .18099 .73684 L p .16959 .76337 L F P
0 g
s
.17033 .71975 m .17115 .7376 L .16415 .74941 L p .707 .577 .707 r
F P
0 g
s
.16305 .77856 m .1647 .74065 L .16917 .7396 L p .707 .577 .707 r
F P
0 g
s
.16305 .77856 m .16917 .7396 L .16959 .76337 L .707 .577 .707 r
F
.15605 .78336 m .1577 .74545 L .1647 .74065 L p F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.63956 .27335 m .63649 .77723 L .61871 .76659 L p .707 .577 .707 r
F P
0 g
s
.61871 .76659 m .62179 .26271 L .63956 .27335 L p .707 .577 .707 r
F P
0 g
s
.1647 .74065 m .16305 .77856 L .15605 .78336 L p .707 .577 .707 r
F P
0 g
s
.3485 .61794 m .34146 .67516 L .3201 .67351 L p .707 .577 .707 r
F P
0 g
s
.3201 .67351 m .32715 .61629 L .3485 .61794 L p .707 .577 .707 r
F P
0 g
s
.36273 .77105 m .3658 .26717 L .38891 .25745 L p .707 .577 .707 r
F P
0 g
s
.3658 .26717 m .36273 .77105 L .35273 .78218 L p .707 .577 .707 r
F P
0 g
s
.20807 .60188 m .20102 .65909 L .17755 .65532 L p .707 .577 .707 r
F P
0 g
s
.17755 .65532 m .1846 .5981 L .20807 .60188 L p .707 .577 .707 r
F P
0 g
s
.18099 .73684 m .17935 .77476 L .16305 .77856 L p .707 .577 .707 r
F P
0 g
s
.17115 .7376 m .17033 .71975 L .18663 .70894 L p .707 .577 .707 r
F P
0 g
s
.32715 .61629 m .3201 .67351 L .29254 .67077 L p .707 .577 .707 r
F P
0 g
s
.29254 .67077 m .29959 .61355 L .32715 .61629 L p .707 .577 .707 r
F P
0 g
s
.62179 .26271 m .61871 .76659 L .58899 .75779 L p .707 .577 .707 r
F P
0 g
s
.58899 .75779 m .59206 .25391 L .62179 .26271 L p .707 .577 .707 r
F P
0 g
s
.18663 .70894 m .18745 .7268 L .17115 .7376 L p .707 .577 .707 r
F P
0 g
s
.23698 .60597 m .22993 .66319 L .20102 .65909 L p .707 .577 .707 r
F P
0 g
s
.20102 .65909 m .20807 .60188 L .23698 .60597 L p .707 .577 .707 r
F P
0 g
s
.34582 .74555 m .34418 .78346 L .32308 .77865 L p .707 .577 .707 r
F P
0 g
s
.32308 .77865 m .32473 .74073 L .34582 .74555 L p .707 .577 .707 r
F P
0 g
s
.35146 .70632 m .35228 .72418 L .33119 .71614 L p .707 .577 .707 r
F P
0 g
s
.33119 .71614 m .33037 .69829 L .35146 .70632 L p .707 .577 .707 r
F P
0 g
s
.29959 .61355 m .29254 .67077 L .26147 .66721 L p .707 .577 .707 r
F P
0 g
s
.17935 .77476 m .18099 .73684 L .20498 .73441 L p .707 .577 .707 r
F P
0 g
s
.38891 .25745 m .38584 .76133 L .36273 .77105 L p .707 .577 .707 r
F P
0 g
s
.38584 .76133 m .38891 .25745 L .42286 .25009 L p .707 .577 .707 r
F P
0 g
s
.26147 .66721 m .26852 .61 L .29959 .61355 L p .707 .577 .707 r
F P
0 g
s
.26852 .61 m .26147 .66721 L .22993 .66319 L p .707 .577 .707 r
F P
0 g
s
.22993 .66319 m .23698 .60597 L .26852 .61 L p .707 .577 .707 r
F P
0 g
s
.20498 .73441 m .20333 .77232 L .17935 .77476 L p .707 .577 .707 r
F P
0 g
s
.18745 .7268 m .18663 .70894 L .21061 .70019 L p .707 .577 .707 r
F P
0 g
s
.70108 .64584 m .70227 .64598 L p .70222 .64589 L .707 .577 .707 r
F P
0 g
s
.70129 .64413 m .70108 .64584 L p .73121 .64702 L .707 .577 .707 r
F P
0 g
s
.67352 .6431 m .67474 .64323 L p .67471 .64315 L .707 .577 .707 r
F P
0 g
s
.6738 .64084 m .67352 .6431 L p .70046 .64403 L .707 .577 .707 r
F P
0 g
s
.65217 .64145 m .65343 .64155 L p .6534 .64141 L .707 .577 .707 r
F P
0 g
s
.65264 .6376 m .65217 .64145 L p .67294 .64071 L .707 .577 .707 r
F P
0 g
s
.63911 .64104 m .63992 .64107 L p .63992 .64081 L .707 .577 .707 r
F P
0 g
s
.63988 .63472 m .63911 .64104 L p .65174 .6374 L .707 .577 .707 r
F P
0 g
s
.63911 .64104 m .63952 .63446 L .63576 .64165 L .707 .577 .707 r
F
.63573 .64189 m .63911 .64104 L p .63576 .64165 L F P
0 g
s
.63875 .63391 m .63988 .63472 L .63791 .60651 L .707 .577 .707 r
F
.63988 .63472 m .64088 .61184 L .63975 .60981 L p F P
0 g
s
.63975 .60981 m .63791 .60651 L p .63988 .63472 L .707 .577 .707 r
F P
0 g
s
.64712 .63636 m .65264 .6376 L .64088 .61184 L .707 .577 .707 r
F
.64811 .61489 m .64088 .61184 L p .65264 .6376 L F P
0 g
s
.65217 .64145 m .65174 .6374 L .63992 .64081 L .707 .577 .707 r
F
.63992 .64107 m .65217 .64145 L p .63992 .64081 L F P
0 g
s
.63923 .64975 m .65188 .65509 L p .64269 .61897 L .707 .577 .707 r
F P
0 g
s
.64088 .61184 m .63988 .63472 L p .64269 .61897 L .707 .577 .707 r
F P
0 g
s
.63988 .63472 m .63923 .64975 L p .64269 .61897 L .707 .577 .707 r
F P
0 g
s
.64616 .58383 m .64267 .5847 L p .6393 .63802 L .707 .577 .707 r
F P
0 g
s
.63911 .64104 m .63988 .63472 L p .6393 .63802 L .707 .577 .707 r
F P
0 g
s
.63988 .63472 m .64616 .58383 L p .6393 .63802 L .707 .577 .707 r
F P
0 g
s
.63678 .63249 m .63562 .64192 L p .63952 .63446 L .707 .577 .707 r
F P
0 g
s
.63626 .64443 m .63923 .64975 L p .63802 .60995 L .707 .577 .707 r
F P
0 g
s
.63791 .60651 m .63678 .63249 L p .63802 .60995 L .707 .577 .707 r
F P
0 g
s
.63678 .63249 m .63626 .64443 L p .63802 .60995 L .707 .577 .707 r
F P
0 g
s
.63952 .63446 m .64008 .62565 L .63825 .63355 L .707 .577 .707 r
F
.64008 .62565 m .64267 .5847 L .63825 .63355 L F
.64267 .5847 m .63678 .63249 L p .63825 .63355 L F P
0 g
s
.65264 .6376 m .65353 .61717 L .64811 .61489 L p .707 .577 .707 r
F P
0 g
s
.64616 .58383 m .63988 .63472 L p .65174 .6374 L .707 .577 .707 r
F P
0 g
s
.66359 .63928 m .6738 .64084 L .65353 .61717 L .707 .577 .707 r
F
.66552 .61991 m .65353 .61717 L p .6738 .64084 L F P
0 g
s
.65353 .61717 m .65264 .6376 L p .65739 .62567 L .707 .577 .707 r
F P
0 g
s
.65921 .58423 m .64616 .58383 L p .65195 .63934 L .707 .577 .707 r
F P
0 g
s
.65217 .64145 m .65264 .6376 L p .65195 .63934 L .707 .577 .707 r
F P
0 g
s
.65264 .6376 m .65921 .58423 L p .65195 .63934 L .707 .577 .707 r
F P
0 g
s
.67352 .6431 m .67294 .64071 L .6534 .64141 L .707 .577 .707 r
F
.65343 .64155 m .67352 .6431 L p .6534 .64141 L F P
0 g
s
.65188 .65509 m .67297 .6599 L p .65739 .62567 L .707 .577 .707 r
F P
0 g
s
.65264 .6376 m .65188 .65509 L p .65739 .62567 L .707 .577 .707 r
F P
0 g
s
.63857 .63213 m .64728 .59461 L .64364 .63112 L .707 .577 .707 r
F
.6738 .64084 m .67462 .62199 L .66552 .61991 L p F P
0 g
s
.65921 .58423 m .65264 .6376 L p .67294 .64071 L .707 .577 .707 r
F P
0 g
s
.64661 .60132 m .66121 .59791 L p .64364 .63112 L .707 .577 .707 r
F P
0 g
s
.6491 .58678 m .64364 .63112 L p .64728 .59461 L .707 .577 .707 r
F P
0 g
s
.64696 .63104 m .64364 .63112 L .66121 .59791 L .707 .577 .707 r
F
.68728 .64245 m .70129 .64413 L .67462 .62199 L F
.69085 .62425 m .67462 .62199 L p .70129 .64413 L F P
0 g
s
.67462 .62199 m .6738 .64084 L p .68011 .63087 L .707 .577 .707 r
F P
0 g
s
.68057 .58589 m .65921 .58423 L p .6732 .64179 L .707 .577 .707 r
F P
0 g
s
.67352 .6431 m .6738 .64084 L p .6732 .64179 L .707 .577 .707 r
F P
0 g
s
.6738 .64084 m .68057 .58589 L p .6732 .64179 L .707 .577 .707 r
F P
0 g
s
.70108 .64584 m .70046 .64403 L .67471 .64315 L .707 .577 .707 r
F
.67474 .64323 m .70108 .64584 L p .67471 .64315 L F P
0 g
s
.67297 .6599 m .70044 .66373 L p .68011 .63087 L .707 .577 .707 r
F P
0 g
s
.6738 .64084 m .67297 .6599 L p .68011 .63087 L .707 .577 .707 r
F P
0 g
s
.64291 .64196 m .64364 .63112 L .64751 .63103 L .707 .577 .707 r
F
.63923 .64975 m .63988 .63472 L p .63875 .63391 L F P
0 g
s
.64306 .63977 m .63626 .64443 L p .64364 .63112 L .707 .577 .707 r
F P
0 g
s
.64205 .644 m .64364 .63112 L p .64291 .64196 L .707 .577 .707 r
F P
0 g
s
.63626 .64443 m .63678 .63249 L p .63876 .63209 L .707 .577 .707 r
F P
0 g
s
.63645 .63852 m .63799 .63225 L .63625 .64213 L .707 .577 .707 r
F
.63799 .63225 m .6491 .58678 L .63857 .63213 L F
.63799 .63225 m .63857 .63213 L .63625 .64213 L F
.63626 .64443 m .63876 .63209 L .64364 .63112 L F
.63562 .64192 m .64267 .5847 L .6491 .58678 L p F P
0 g
s
.64492 .60171 m .64364 .63112 L p .63876 .63209 L .707 .577 .707 r
F P
0 g
s
.64364 .63112 m .64327 .63963 L .64306 .63977 L p .707 .577 .707 r
F P
0 g
s
.65188 .65509 m .65264 .6376 L p .64712 .63636 L .707 .577 .707 r
F P
0 g
s
.65777 .64708 m .64205 .644 L p .64751 .63103 L .707 .577 .707 r
F P
0 g
s
.65978 .63074 m .65777 .64708 L p .64751 .63103 L .707 .577 .707 r
F P
0 g
s
.70129 .64413 m .70209 .62582 L .69085 .62425 L p .707 .577 .707 r
F P
0 g
s
.68057 .58589 m .6738 .64084 L p .70046 .64403 L .707 .577 .707 r
F P
0 g
s
.73325 .62828 m .70209 .62582 L p .71655 .6456 L .707 .577 .707 r
F P
0 g
s
.70209 .62582 m .70129 .64413 L p .70863 .63476 L .707 .577 .707 r
F P
0 g
s
.70813 .58863 m .68057 .58589 L p .70074 .64484 L .707 .577 .707 r
F P
0 g
s
.70108 .64584 m .70129 .64413 L p .70074 .64484 L .707 .577 .707 r
F P
0 g
s
.70129 .64413 m .70813 .58863 L p .70074 .64484 L .707 .577 .707 r
F P
0 g
s
.73215 .6494 m .73121 .64702 L .70222 .64589 L .707 .577 .707 r
F
.70227 .64598 m .73215 .6494 L p .70222 .64589 L F P
0 g
s
.70044 .66373 m .7316 .6662 L p .70863 .63476 L .707 .577 .707 r
F P
0 g
s
.70129 .64413 m .70044 .66373 L p .70863 .63476 L .707 .577 .707 r
F P
0 g
s
.66121 .59791 m .68519 .59547 L p .66273 .63083 L .707 .577 .707 r
F P
0 g
s
.65777 .64708 m .65978 .63074 L p .66698 .63094 L .707 .577 .707 r
F P
0 g
s
.65956 .63582 m .65978 .63074 L p .66273 .63083 L .707 .577 .707 r
F P
0 g
s
.65978 .63074 m .66121 .59791 L p .66273 .63083 L .707 .577 .707 r
F P
0 g
s
.67297 .6599 m .6738 .64084 L p .66359 .63928 L .707 .577 .707 r
F P
0 g
s
.68123 .65085 m .65777 .64708 L p .66698 .63094 L .707 .577 .707 r
F P
0 g
s
.68363 .6314 m .68123 .65085 L p .66698 .63094 L .707 .577 .707 r
F P
0 g
s
.73243 .64713 m .73325 .62828 L p .71655 .6456 L .707 .577 .707 r
F P
0 g
s
.70813 .58863 m .70129 .64413 L p .73121 .64702 L .707 .577 .707 r
F P
0 g
s
.73325 .62828 m .73243 .64713 L p .74022 .63724 L .707 .577 .707 r
F P
0 g
s
.76505 .62914 m .73325 .62828 L p .74889 .6484 L .707 .577 .707 r
F P
0 g
s
.73215 .6494 m .76369 .65342 L p .76208 .64941 L .707 .577 .707 r
F P
0 g
s
.73243 .64713 m .73215 .6494 L p .76208 .64941 L .707 .577 .707 r
F P
0 g
s
.76416 .64957 m .76505 .62914 L p .74889 .6484 L .707 .577 .707 r
F P
0 g
s
.76505 .62914 m .76416 .64957 L p .77165 .63799 L .707 .577 .707 r
F P
0 g
s
.79438 .62832 m .76505 .62914 L p .781 .65051 L .707 .577 .707 r
F P
0 g
s
.76369 .65342 m .7926 .65752 L p .79029 .65103 L .707 .577 .707 r
F P
0 g
s
.76416 .64957 m .76369 .65342 L p .79029 .65103 L .707 .577 .707 r
F P
0 g
s
.79338 .6512 m .79438 .62832 L p .781 .65051 L .707 .577 .707 r
F P
0 g
s
.79438 .62832 m .79338 .6512 L p .79959 .63659 L .707 .577 .707 r
F P
0 g
s
.81836 .62588 m .79438 .62832 L p .80905 .65163 L .707 .577 .707 r
F P
0 g
s
.7926 .65752 m .81607 .66129 L p .8135 .65176 L .707 .577 .707 r
F P
0 g
s
.79338 .6512 m .7926 .65752 L p .8135 .65176 L .707 .577 .707 r
F P
0 g
s
.81723 .65186 m .81836 .62588 L p .80905 .65163 L .707 .577 .707 r
F P
0 g
s
.81836 .62588 m .81723 .65186 L p .82122 .63254 L .707 .577 .707 r
F P
0 g
s
.83465 .62208 m .81836 .62588 L p .82939 .65158 L .707 .577 .707 r
F P
0 g
s
.81607 .66129 m .83178 .66436 L p .82994 .65156 L .707 .577 .707 r
F P
0 g
s
.81723 .65186 m .81607 .66129 L p .82994 .65156 L .707 .577 .707 r
F P
0 g
s
.83337 .65148 m .83465 .62208 L p .82939 .65158 L .707 .577 .707 r
F P
0 g
s
.83883 .60715 m .83638 .60667 L p .83509 .62583 L .707 .577 .707 r
F P
0 g
s
.83465 .62208 m .83337 .65148 L p .83514 .62512 L .707 .577 .707 r
F P
0 g
s
.83337 .65148 m .83883 .60715 L p .83509 .62583 L .707 .577 .707 r
F P
0 g
s
.83337 .65148 m .83509 .62583 L .82994 .65156 L .707 .577 .707 r
F
.83883 .60715 m .83337 .65148 L p .83838 .65048 L F P
0 g
s
.833 .65999 m .83963 .65545 L p .83922 .65031 L .707 .577 .707 r
F P
0 g
s
.8398 .65392 m .83922 .65031 L .83963 .65545 L .707 .577 .707 r
F
.83838 .65048 m .8411 .63419 L .83883 .60715 L F
.84526 .60923 m .84251 .60834 L p .8411 .63419 L F P
0 g
s
.84251 .60834 m .83883 .60715 L p .8411 .63419 L .707 .577 .707 r
F P
0 g
s
.84023 .65011 m .84526 .60923 L p .83838 .65048 L .707 .577 .707 r
F P
0 g
s
.83922 .65031 m .83514 .62512 L .83352 .65145 L .707 .577 .707 r
F
.83922 .65031 m .83352 .65145 L .833 .65999 L F
.83178 .66436 m .83821 .66644 L p .83838 .65048 L F P
0 g
s
.83337 .65148 m .833 .65999 L p .83514 .62512 L .707 .577 .707 r
F P
0 g
s
.83337 .65148 m .83178 .66436 L p .83216 .66356 L .707 .577 .707 r
F P
0 g
s
.83251 .6601 m .833 .65999 L p .83261 .65908 L .707 .577 .707 r
F P
0 g
s
.83178 .66436 m .83337 .65148 L p .82994 .65156 L .707 .577 .707 r
F P
0 g
s
.833 .65999 m .83337 .65148 L p .82939 .65158 L .707 .577 .707 r
F P
0 g
s
.83838 .65048 m .83337 .65148 L .83216 .66356 L .707 .577 .707 r
F
.81671 .66379 m .83251 .6601 L p .82939 .65158 L F P
0 g
s
.83261 .65908 m .82939 .65158 L .83251 .6601 L .707 .577 .707 r
F
.83821 .66644 m .83473 .66732 L p .83812 .6486 L F P
0 g
s
.8373 .64801 m .83802 .64292 L .83905 .64926 L .707 .577 .707 r
F
.84001 .65519 m .84023 .65011 L p .83933 .65029 L F P
0 g
s
.84001 .65519 m .83538 .62158 L .83514 .62512 L .707 .577 .707 r
F
.83821 .66644 m .84023 .65011 L p .83838 .65048 L F P
0 g
s
.84165 .61728 m .83538 .62158 L p .83933 .65029 L .707 .577 .707 r
F P
0 g
s
.84023 .65011 m .84165 .61728 L p .83933 .65029 L .707 .577 .707 r
F P
0 g
s
.83812 .6486 m .84011 .65003 L .83821 .66644 L .707 .577 .707 r
F
.83802 .64292 m .84165 .61728 L .83922 .64939 L F
.83905 .64926 m .83922 .64939 L .83917 .65003 L F
.83802 .64292 m .83922 .64939 L .83905 .64926 L F
.84023 .65011 m .83821 .66644 L p .84011 .65003 L F P
0 g
s
.83917 .65003 m .83922 .64939 L .84023 .65011 L .707 .577 .707 r
F
.84165 .61728 m .84023 .65011 L p .83922 .64939 L F P
0 g
s
.84403 .61605 m .84023 .65011 L .84011 .65003 L .707 .577 .707 r
F
.83473 .66732 m .83712 .64788 L p .83812 .6486 L F P
0 g
s
.83869 .61195 m .84165 .61728 L p .83713 .6492 L .707 .577 .707 r
F P
0 g
s
.83704 .64986 m .83712 .64788 L p .83713 .6492 L .707 .577 .707 r
F P
0 g
s
.83712 .64788 m .83869 .61195 L p .83713 .6492 L .707 .577 .707 r
F P
0 g
s
.82994 .65156 m .83509 .62583 L .82312 .60407 L .707 .577 .707 r
F
.82939 .65158 m .82122 .63254 L .81844 .65183 L F
.82939 .65158 m .81844 .65183 L .81671 .66379 L F
.81723 .65186 m .81671 .66379 L p .82122 .63254 L F P
0 g
s
.82312 .60407 m .81723 .65186 L p .82994 .65156 L .707 .577 .707 r
F P
0 g
s
.83538 .62158 m .83465 .62208 L p .83514 .62512 L .707 .577 .707 r
F P
0 g
s
.83638 .60667 m .82312 .60407 L p .83509 .62583 L .707 .577 .707 r
F P
0 g
s
.83869 .61195 m .83712 .64788 L p .82439 .64453 L .707 .577 .707 r
F P
0 g
s
.83473 .66732 m .82167 .66691 L p .82905 .64606 L .707 .577 .707 r
F P
0 g
s
.82905 .64606 m .83575 .64757 L .83473 .66732 L .707 .577 .707 r
F
.82682 .64555 m .82439 .64453 L p .83712 .64788 L F P
0 g
s
.83712 .64788 m .83473 .66732 L p .83699 .62362 L .707 .577 .707 r
F P
0 g
s
.82439 .64453 m .82604 .60662 L .83869 .61195 L p .707 .577 .707 r
F P
0 g
s
.82167 .66691 m .82872 .6097 L .84178 .6101 L p .707 .577 .707 r
F P
0 g
s
.83712 .64788 m .83704 .64986 L .82682 .64555 L p .707 .577 .707 r
F P
0 g
s
.82905 .64606 m .83699 .62362 L .83575 .64757 L .707 .577 .707 r
F
.84178 .6101 m .83712 .64788 L p .83699 .62362 L F P
0 g
s
.84178 .6101 m .84526 .60923 L p .83812 .6486 L .707 .577 .707 r
F P
0 g
s
.83712 .64788 m .84178 .6101 L p .83812 .6486 L .707 .577 .707 r
F P
0 g
s
.83812 .6486 m .84403 .61605 L .84011 .65003 L .707 .577 .707 r
F
.83704 .64986 m .8373 .64801 L .83917 .65003 L F
.8373 .64801 m .83905 .64926 L .83917 .65003 L F
.84023 .65011 m .84001 .65519 L .83995 .6551 L p F P
0 g
s
.83963 .65545 m .84001 .65519 L p .8398 .65392 L .707 .577 .707 r
F P
0 g
s
.83995 .6551 m .83704 .64986 L p .84023 .65011 L .707 .577 .707 r
F P
0 g
s
.84526 .60923 m .84023 .65011 L p .84403 .61605 L .707 .577 .707 r
F P
0 g
s
.82312 .60407 m .79965 .6003 L p .81562 .65964 L .707 .577 .707 r
F P
0 g
s
.81607 .66129 m .81723 .65186 L p .81562 .65964 L .707 .577 .707 r
F P
0 g
s
.81723 .65186 m .82312 .60407 L p .81562 .65964 L .707 .577 .707 r
F P
0 g
s
.81671 .66379 m .81723 .65186 L p .80905 .65163 L .707 .577 .707 r
F P
0 g
s
.79273 .66623 m .81671 .66379 L p .79959 .63659 L .707 .577 .707 r
F P
0 g
s
.79338 .6512 m .79273 .66623 L p .79959 .63659 L .707 .577 .707 r
F P
0 g
s
.79965 .6003 m .79338 .6512 L p .8135 .65176 L .707 .577 .707 r
F P
0 g
s
.79965 .6003 m .77074 .5962 L p .79173 .65508 L .707 .577 .707 r
F P
0 g
s
.7926 .65752 m .79338 .6512 L p .79173 .65508 L .707 .577 .707 r
F P
0 g
s
.79338 .6512 m .79965 .6003 L p .79173 .65508 L .707 .577 .707 r
F P
0 g
s
.79273 .66623 m .79338 .6512 L p .781 .65051 L .707 .577 .707 r
F P
0 g
s
.7634 .66706 m .79273 .66623 L p .77165 .63799 L .707 .577 .707 r
F P
0 g
s
.76416 .64957 m .7634 .66706 L p .77165 .63799 L .707 .577 .707 r
F P
0 g
s
.77074 .5962 m .76416 .64957 L p .79029 .65103 L .707 .577 .707 r
F P
0 g
s
.77074 .5962 m .7392 .59218 L p .76292 .6515 L .707 .577 .707 r
F P
0 g
s
.76369 .65342 m .76416 .64957 L p .76292 .6515 L .707 .577 .707 r
F P
0 g
s
.76416 .64957 m .77074 .5962 L p .76292 .6515 L .707 .577 .707 r
F P
0 g
s
.7634 .66706 m .76416 .64957 L p .74889 .6484 L .707 .577 .707 r
F P
0 g
s
.7316 .6662 m .7634 .66706 L p .74022 .63724 L .707 .577 .707 r
F P
0 g
s
.73243 .64713 m .7316 .6662 L p .74022 .63724 L .707 .577 .707 r
F P
0 g
s
.7392 .59218 m .73243 .64713 L p .76208 .64941 L .707 .577 .707 r
F P
0 g
s
.7392 .59218 m .70813 .58863 L p .73165 .64813 L .707 .577 .707 r
F P
0 g
s
.73215 .6494 m .73243 .64713 L p .73165 .64813 L .707 .577 .707 r
F P
0 g
s
.73243 .64713 m .7392 .59218 L p .73165 .64813 L .707 .577 .707 r
F P
0 g
s
.68519 .59547 m .71452 .59465 L p .68506 .63148 L .707 .577 .707 r
F P
0 g
s
.68123 .65085 m .68363 .6314 L p .69401 .63198 L .707 .577 .707 r
F P
0 g
s
.68354 .63339 m .68363 .6314 L p .68506 .63148 L .707 .577 .707 r
F P
0 g
s
.68363 .6314 m .68519 .59547 L p .68506 .63148 L .707 .577 .707 r
F P
0 g
s
.71452 .59465 m .71287 .63256 L .70723 .63272 L p .707 .577 .707 r
F P
0 g
s
.70044 .66373 m .70129 .64413 L p .68728 .64245 L .707 .577 .707 r
F P
0 g
s
.71015 .65494 m .68123 .65085 L p .69401 .63198 L .707 .577 .707 r
F P
0 g
s
.71285 .63303 m .71015 .65494 L p .69401 .63198 L .707 .577 .707 r
F P
0 g
s
.70723 .63272 m .68354 .63339 L p .68506 .63148 L .707 .577 .707 r
F P
0 g
s
.68506 .63148 m .71452 .59465 L .70723 .63272 L .707 .577 .707 r
F
.71287 .63256 m .71452 .59465 L .74632 .59551 L p F P
0 g
s
.74632 .59551 m .74467 .63342 L .71287 .63256 L p .707 .577 .707 r
F P
0 g
s
.7172 .59773 m .71285 .63303 L p .69401 .63198 L .707 .577 .707 r
F P
0 g
s
.69401 .63198 m .68363 .6314 L .7172 .59773 L .707 .577 .707 r
F
.68363 .6314 m .68828 .59363 L .69904 .59515 L p F P
0 g
s
.69904 .59515 m .7172 .59773 L p .68363 .6314 L .707 .577 .707 r
F P
0 g
s
.65956 .63582 m .66273 .63083 L .68282 .6333 L .707 .577 .707 r
F
.68354 .63339 m .68275 .63347 L p .68282 .6333 L F P
0 g
s
.68275 .63347 m .65956 .63582 L p .68282 .6333 L .707 .577 .707 r
F P
0 g
s
.68519 .59547 m .68363 .6314 L p .66273 .63083 L .707 .577 .707 r
F P
0 g
s
.68363 .6314 m .68354 .63339 L p .66273 .63083 L .707 .577 .707 r
F P
0 g
s
.68828 .59363 m .68363 .6314 L p .66698 .63094 L .707 .577 .707 r
F P
0 g
s
.66698 .63094 m .65978 .63074 L .68828 .59363 L .707 .577 .707 r
F
.65978 .63074 m .66482 .58986 L .66812 .59039 L p F P
0 g
s
.66812 .59039 m .68828 .59363 L p .65978 .63074 L .707 .577 .707 r
F P
0 g
s
.64327 .63963 m .64696 .63104 L .65879 .63553 L .707 .577 .707 r
F
.65956 .63582 m .65869 .63602 L p .65879 .63553 L F P
0 g
s
.65869 .63602 m .64327 .63963 L p .65879 .63553 L .707 .577 .707 r
F P
0 g
s
.66121 .59791 m .65978 .63074 L p .64696 .63104 L .707 .577 .707 r
F P
0 g
s
.65978 .63074 m .65956 .63582 L p .64696 .63104 L .707 .577 .707 r
F P
0 g
s
.66482 .58986 m .65978 .63074 L p .64751 .63103 L .707 .577 .707 r
F P
0 g
s
.6491 .58678 m .66482 .58986 L p .64751 .63103 L .707 .577 .707 r
F P
0 g
s
.64364 .63112 m .6491 .58678 L p .64751 .63103 L .707 .577 .707 r
F P
0 g
s
.64327 .63963 m .64364 .63112 L p .64696 .63104 L .707 .577 .707 r
F P
0 g
s
.64364 .63112 m .64492 .60171 L .64661 .60132 L p .707 .577 .707 r
F P
0 g
s
.63876 .63209 m .63678 .63249 L .64492 .60171 L .707 .577 .707 r
F
.64205 .644 m .63625 .64213 L p .63857 .63213 L F P
0 g
s
.64364 .63112 m .64205 .644 L p .63857 .63213 L .707 .577 .707 r
F P
0 g
s
.63562 .64192 m .63573 .64189 L p .63576 .64165 L .707 .577 .707 r
F P
0 g
s
.63625 .64213 m .63562 .64192 L p .63645 .63852 L .707 .577 .707 r
F P
0 g
s
.63678 .63249 m .63791 .60651 L .63983 .6052 L p .707 .577 .707 r
F P
0 g
s
.63983 .6052 m .64492 .60171 L p .63678 .63249 L .707 .577 .707 r
F P
0 g
s
.7316 .6662 m .73243 .64713 L p .71655 .6456 L .707 .577 .707 r
F P
0 g
s
.21061 .70019 m .21143 .71805 L .18745 .7268 L p .707 .577 .707 r
F P
0 g
s
.32473 .74073 m .32308 .77865 L .29561 .77482 L p .707 .577 .707 r
F P
0 g
s
.29561 .77482 m .29726 .73691 L .32473 .74073 L p .707 .577 .707 r
F P
0 g
s
.33037 .69829 m .33119 .71614 L .30372 .7112 L p .707 .577 .707 r
F P
0 g
s
.30372 .7112 m .3029 .69335 L .33037 .69829 L p .707 .577 .707 r
F P
0 g
s
.59206 .25391 m .58899 .75779 L .55022 .7517 L p .707 .577 .707 r
F P
0 g
s
.55022 .7517 m .55329 .24781 L .59206 .25391 L p .707 .577 .707 r
F P
0 g
s
.20333 .77232 m .20498 .73441 L .2343 .73358 L p .707 .577 .707 r
F P
0 g
s
.21143 .71805 m .21061 .70019 L .23994 .69435 L p .707 .577 .707 r
F P
0 g
s
.2343 .73358 m .23265 .77149 L .20333 .77232 L p .707 .577 .707 r
F P
0 g
s
.29726 .73691 m .29561 .77482 L .26445 .77235 L p .707 .577 .707 r
F P
0 g
s
.26445 .77235 m .2661 .73444 L .29726 .73691 L p .707 .577 .707 r
F P
0 g
s
.41979 .75397 m .42286 .25009 L .46434 .24581 L p .707 .577 .707 r
F P
0 g
s
.42286 .25009 m .41979 .75397 L .38584 .76133 L p .707 .577 .707 r
F P
0 g
s
.3029 .69335 m .30372 .7112 L .27256 .70985 L p .707 .577 .707 r
F P
0 g
s
.27256 .70985 m .27174 .69199 L .3029 .69335 L p .707 .577 .707 r
F P
0 g
s
.23994 .69435 m .24076 .71221 L .21143 .71805 L p .707 .577 .707 r
F P
0 g
s
.23265 .77149 m .2343 .73358 L .2661 .73444 L p .707 .577 .707 r
F P
0 g
s
.2661 .73444 m .26445 .77235 L .23265 .77149 L p .707 .577 .707 r
F P
0 g
s
.24076 .71221 m .23994 .69435 L .27174 .69199 L p .707 .577 .707 r
F P
0 g
s
.27174 .69199 m .27256 .70985 L .24076 .71221 L p .707 .577 .707 r
F P
0 g
s
.55329 .24781 m .55022 .7517 L .50622 .74891 L p .707 .577 .707 r
F P
0 g
s
.50622 .74891 m .50929 .24502 L .55329 .24781 L p .707 .577 .707 r
F P
0 g
s
.46127 .74969 m .46434 .24581 L .50929 .24502 L p .707 .577 .707 r
F P
0 g
s
.46434 .24581 m .46127 .74969 L .41979 .75397 L p .707 .577 .707 r
F P
0 g
s
.50929 .24502 m .50622 .74891 L .46127 .74969 L p .707 .577 .707 r
F P
0 g
s
.7397 .80163 m .73888 .78377 L .70772 .78242 L p .707 .577 .707 r
F P
0 g
s
.73888 .78377 m .7397 .80163 L .7715 .79927 L p .707 .577 .707 r
F P
0 g
s
.7715 .79927 m .77068 .78142 L .73888 .78377 L p .707 .577 .707 r
F P
0 g
s
.77068 .78142 m .7715 .79927 L .80082 .79343 L p .707 .577 .707 r
F P
0 g
s
.80082 .79343 m .80001 .77558 L .77068 .78142 L p .707 .577 .707 r
F P
0 g
s
.70854 .80027 m .70772 .78242 L .68025 .77748 L p .707 .577 .707 r
F P
0 g
s
.70772 .78242 m .70854 .80027 L .7397 .80163 L p .707 .577 .707 r
F P
0 g
s
.80001 .77558 m .80082 .79343 L .82481 .78468 L p .707 .577 .707 r
F P
0 g
s
.82481 .78468 m .82399 .76682 L .80001 .77558 L p .707 .577 .707 r
F P
0 g
s
.68025 .77748 m .68107 .79534 L .70854 .80027 L p .707 .577 .707 r
F P
0 g
s
.68107 .79534 m .68025 .77748 L .65916 .76945 L p .707 .577 .707 r
F P
0 g
s
.65916 .76945 m .65998 .7873 L .68107 .79534 L p .707 .577 .707 r
F P
0 g
s
.82399 .76682 m .82481 .78468 L .8411 .77387 L p .707 .577 .707 r
F P
0 g
s
.8411 .77387 m .84028 .75602 L .82399 .76682 L p .707 .577 .707 r
F P
0 g
s
.65998 .7873 m .65916 .76945 L .64651 .7591 L p .707 .577 .707 r
F P
0 g
s
.64651 .7591 m .64733 .77696 L .65998 .7873 L p .707 .577 .707 r
F P
0 g
s
.84028 .75602 m .8411 .77387 L .84811 .76207 L p .707 .577 .707 r
F P
0 g
s
.84811 .76207 m .84729 .74422 L .84028 .75602 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64733 .77696 m .64651 .7591 L .64354 .74746 L p .707 .577 .707 r
F P
0 g
s
.35807 .60903 m .35926 .60916 L p .35921 .60907 L .707 .577 .707 r
F P
0 g
s
.35828 .60731 m .35807 .60903 L p .3882 .6102 L .707 .577 .707 r
F P
0 g
s
.33051 .60629 m .33173 .60641 L p .3317 .60633 L .707 .577 .707 r
F P
0 g
s
.33079 .60403 m .33051 .60629 L p .35745 .60721 L .707 .577 .707 r
F P
0 g
s
.30916 .60464 m .31042 .60473 L p .31039 .60459 L .707 .577 .707 r
F P
0 g
s
.30963 .60079 m .30916 .60464 L p .32993 .60389 L .707 .577 .707 r
F P
0 g
s
.2961 .60423 m .29691 .60425 L p .29691 .60399 L .707 .577 .707 r
F P
0 g
s
.29687 .59791 m .2961 .60423 L p .30873 .60058 L .707 .577 .707 r
F P
0 g
s
.2961 .60423 m .29651 .59765 L .29275 .60484 L .707 .577 .707 r
F
.29272 .60508 m .2961 .60423 L p .29275 .60484 L F P
0 g
s
.29574 .59709 m .29687 .59791 L .2949 .5697 L .707 .577 .707 r
F
.29687 .59791 m .29787 .57502 L .29674 .573 L p F P
0 g
s
.29674 .573 m .2949 .5697 L p .29687 .59791 L .707 .577 .707 r
F P
0 g
s
.30411 .59954 m .30963 .60079 L .29787 .57502 L .707 .577 .707 r
F
.3051 .57807 m .29787 .57502 L p .30963 .60079 L F P
0 g
s
.30916 .60464 m .30873 .60058 L .29691 .60399 L .707 .577 .707 r
F
.29691 .60425 m .30916 .60464 L p .29691 .60399 L F P
0 g
s
.29622 .61294 m .30887 .61827 L p .29968 .58215 L .707 .577 .707 r
F P
0 g
s
.29787 .57502 m .29687 .59791 L p .29968 .58215 L .707 .577 .707 r
F P
0 g
s
.29687 .59791 m .29622 .61294 L p .29968 .58215 L .707 .577 .707 r
F P
0 g
s
.30314 .54701 m .29966 .54789 L p .29629 .6012 L .707 .577 .707 r
F P
0 g
s
.2961 .60423 m .29687 .59791 L p .29629 .6012 L .707 .577 .707 r
F P
0 g
s
.29687 .59791 m .30314 .54701 L p .29629 .6012 L .707 .577 .707 r
F P
0 g
s
.29377 .59568 m .29261 .60511 L p .29651 .59765 L .707 .577 .707 r
F P
0 g
s
.29325 .60761 m .29622 .61294 L p .29501 .57313 L .707 .577 .707 r
F P
0 g
s
.2949 .5697 m .29377 .59568 L p .29501 .57313 L .707 .577 .707 r
F P
0 g
s
.29377 .59568 m .29325 .60761 L p .29501 .57313 L .707 .577 .707 r
F P
0 g
s
.29651 .59765 m .29707 .58883 L .29524 .59673 L .707 .577 .707 r
F
.29707 .58883 m .29966 .54789 L .29524 .59673 L F
.29966 .54789 m .29377 .59568 L p .29524 .59673 L F P
0 g
s
.30963 .60079 m .31052 .58036 L .3051 .57807 L p .707 .577 .707 r
F P
0 g
s
.30314 .54701 m .29687 .59791 L p .30873 .60058 L .707 .577 .707 r
F P
0 g
s
.32058 .60246 m .33079 .60403 L .31052 .58036 L .707 .577 .707 r
F
.32251 .5831 m .31052 .58036 L p .33079 .60403 L F P
0 g
s
.31052 .58036 m .30963 .60079 L p .31438 .58885 L .707 .577 .707 r
F P
0 g
s
.3162 .54742 m .30314 .54701 L p .30894 .60253 L .707 .577 .707 r
F P
0 g
s
.30916 .60464 m .30963 .60079 L p .30894 .60253 L .707 .577 .707 r
F P
0 g
s
.30963 .60079 m .3162 .54742 L p .30894 .60253 L .707 .577 .707 r
F P
0 g
s
.33051 .60629 m .32993 .60389 L .31039 .60459 L .707 .577 .707 r
F
.31042 .60473 m .33051 .60629 L p .31039 .60459 L F P
0 g
s
.30887 .61827 m .32996 .62309 L p .31438 .58885 L .707 .577 .707 r
F P
0 g
s
.30963 .60079 m .30887 .61827 L p .31438 .58885 L .707 .577 .707 r
F P
0 g
s
.29556 .59532 m .30427 .5578 L .30063 .5943 L .707 .577 .707 r
F
.33079 .60403 m .33161 .58517 L .32251 .5831 L p F P
0 g
s
.3162 .54742 m .30963 .60079 L p .32993 .60389 L .707 .577 .707 r
F P
0 g
s
.3036 .5645 m .3182 .56109 L p .30063 .5943 L .707 .577 .707 r
F P
0 g
s
.30609 .54997 m .30063 .5943 L p .30427 .5578 L .707 .577 .707 r
F P
0 g
s
.30395 .59423 m .30063 .5943 L .3182 .56109 L .707 .577 .707 r
F
.34427 .60564 m .35828 .60731 L .33161 .58517 L F
.34784 .58743 m .33161 .58517 L p .35828 .60731 L F P
0 g
s
.33161 .58517 m .33079 .60403 L p .3371 .59405 L .707 .577 .707 r
F P
0 g
s
.33756 .54907 m .3162 .54742 L p .33019 .60497 L .707 .577 .707 r
F P
0 g
s
.33051 .60629 m .33079 .60403 L p .33019 .60497 L .707 .577 .707 r
F P
0 g
s
.33079 .60403 m .33756 .54907 L p .33019 .60497 L .707 .577 .707 r
F P
0 g
s
.35807 .60903 m .35745 .60721 L .3317 .60633 L .707 .577 .707 r
F
.33173 .60641 m .35807 .60903 L p .3317 .60633 L F P
0 g
s
.32996 .62309 m .35743 .62691 L p .3371 .59405 L .707 .577 .707 r
F P
0 g
s
.33079 .60403 m .32996 .62309 L p .3371 .59405 L .707 .577 .707 r
F P
0 g
s
.2999 .60514 m .30063 .5943 L .30449 .59421 L .707 .577 .707 r
F
.29622 .61294 m .29687 .59791 L p .29574 .59709 L F P
0 g
s
.30005 .60295 m .29325 .60761 L p .30063 .5943 L .707 .577 .707 r
F P
0 g
s
.29904 .60719 m .30063 .5943 L p .2999 .60514 L .707 .577 .707 r
F P
0 g
s
.29325 .60761 m .29377 .59568 L p .29575 .59528 L .707 .577 .707 r
F P
0 g
s
.29344 .6017 m .29497 .59543 L .29324 .60531 L .707 .577 .707 r
F
.29497 .59543 m .30609 .54997 L .29556 .59532 L F
.29497 .59543 m .29556 .59532 L .29324 .60531 L F
.29325 .60761 m .29575 .59528 L .30063 .5943 L F
.29261 .60511 m .29966 .54789 L .30609 .54997 L p F P
0 g
s
.30191 .5649 m .30063 .5943 L p .29575 .59528 L .707 .577 .707 r
F P
0 g
s
.30063 .5943 m .30026 .60281 L .30005 .60295 L p .707 .577 .707 r
F P
0 g
s
.30887 .61827 m .30963 .60079 L p .30411 .59954 L .707 .577 .707 r
F P
0 g
s
.31476 .61026 m .29904 .60719 L p .30449 .59421 L .707 .577 .707 r
F P
0 g
s
.31677 .59393 m .31476 .61026 L p .30449 .59421 L .707 .577 .707 r
F P
0 g
s
.35828 .60731 m .35908 .589 L .34784 .58743 L p .707 .577 .707 r
F P
0 g
s
.33756 .54907 m .33079 .60403 L p .35745 .60721 L .707 .577 .707 r
F P
0 g
s
.39024 .59147 m .35908 .589 L p .37354 .60878 L .707 .577 .707 r
F P
0 g
s
.35908 .589 m .35828 .60731 L p .36562 .59795 L .707 .577 .707 r
F P
0 g
s
.36512 .55181 m .33756 .54907 L p .35773 .60802 L .707 .577 .707 r
F P
0 g
s
.35807 .60903 m .35828 .60731 L p .35773 .60802 L .707 .577 .707 r
F P
0 g
s
.35828 .60731 m .36512 .55181 L p .35773 .60802 L .707 .577 .707 r
F P
0 g
s
.38914 .61258 m .3882 .6102 L .35921 .60907 L .707 .577 .707 r
F
.35926 .60916 m .38914 .61258 L p .35921 .60907 L F P
0 g
s
.35743 .62691 m .38859 .62938 L p .36562 .59795 L .707 .577 .707 r
F P
0 g
s
.35828 .60731 m .35743 .62691 L p .36562 .59795 L .707 .577 .707 r
F P
0 g
s
.3182 .56109 m .34218 .55866 L p .31972 .59401 L .707 .577 .707 r
F P
0 g
s
.31476 .61026 m .31677 .59393 L p .32397 .59413 L .707 .577 .707 r
F P
0 g
s
.31655 .59901 m .31677 .59393 L p .31972 .59401 L .707 .577 .707 r
F P
0 g
s
.31677 .59393 m .3182 .56109 L p .31972 .59401 L .707 .577 .707 r
F P
0 g
s
.32996 .62309 m .33079 .60403 L p .32058 .60246 L .707 .577 .707 r
F P
0 g
s
.33822 .61403 m .31476 .61026 L p .32397 .59413 L .707 .577 .707 r
F P
0 g
s
.34062 .59459 m .33822 .61403 L p .32397 .59413 L .707 .577 .707 r
F P
0 g
s
.38942 .61032 m .39024 .59147 L p .37354 .60878 L .707 .577 .707 r
F P
0 g
s
.36512 .55181 m .35828 .60731 L p .3882 .6102 L .707 .577 .707 r
F P
0 g
s
.39024 .59147 m .38942 .61032 L p .39721 .60042 L .707 .577 .707 r
F P
0 g
s
.42204 .59233 m .39024 .59147 L p .40588 .61158 L .707 .577 .707 r
F P
0 g
s
.38914 .61258 m .42068 .61661 L p .41907 .6126 L .707 .577 .707 r
F P
0 g
s
.38942 .61032 m .38914 .61258 L p .41907 .6126 L .707 .577 .707 r
F P
0 g
s
.42115 .61276 m .42204 .59233 L p .40588 .61158 L .707 .577 .707 r
F P
0 g
s
.42204 .59233 m .42115 .61276 L p .42864 .60117 L .707 .577 .707 r
F P
0 g
s
.45137 .5915 m .42204 .59233 L p .43799 .61369 L .707 .577 .707 r
F P
0 g
s
.42068 .61661 m .44959 .6207 L p .44728 .61421 L .707 .577 .707 r
F P
0 g
s
.42115 .61276 m .42068 .61661 L p .44728 .61421 L .707 .577 .707 r
F P
0 g
s
.45037 .61438 m .45137 .5915 L p .43799 .61369 L .707 .577 .707 r
F P
0 g
s
.45137 .5915 m .45037 .61438 L p .45658 .59978 L .707 .577 .707 r
F P
0 g
s
.47535 .58906 m .45137 .5915 L p .46604 .61482 L .707 .577 .707 r
F P
0 g
s
.44959 .6207 m .47306 .62447 L p .47049 .61494 L .707 .577 .707 r
F P
0 g
s
.45037 .61438 m .44959 .6207 L p .47049 .61494 L .707 .577 .707 r
F P
0 g
s
.47422 .61504 m .47535 .58906 L p .46604 .61482 L .707 .577 .707 r
F P
0 g
s
.47535 .58906 m .47422 .61504 L p .47821 .59573 L .707 .577 .707 r
F P
0 g
s
.49164 .58526 m .47535 .58906 L p .48638 .61476 L .707 .577 .707 r
F P
0 g
s
.47306 .62447 m .48877 .62755 L p .48693 .61475 L .707 .577 .707 r
F P
0 g
s
.47422 .61504 m .47306 .62447 L p .48693 .61475 L .707 .577 .707 r
F P
0 g
s
.49036 .61467 m .49164 .58526 L p .48638 .61476 L .707 .577 .707 r
F P
0 g
s
.49582 .57033 m .49337 .56985 L p .49208 .58901 L .707 .577 .707 r
F P
0 g
s
.49164 .58526 m .49036 .61467 L p .49213 .5883 L .707 .577 .707 r
F P
0 g
s
.49036 .61467 m .49582 .57033 L p .49208 .58901 L .707 .577 .707 r
F P
0 g
s
.49036 .61467 m .49208 .58901 L .48693 .61475 L .707 .577 .707 r
F
.49582 .57033 m .49036 .61467 L p .49537 .61367 L F P
0 g
s
.48999 .62317 m .49662 .61863 L p .49621 .6135 L .707 .577 .707 r
F P
0 g
s
.49679 .61711 m .49621 .6135 L .49662 .61863 L .707 .577 .707 r
F
.49537 .61367 m .49809 .59738 L .49582 .57033 L F
.50225 .57241 m .4995 .57152 L p .49809 .59738 L F P
0 g
s
.4995 .57152 m .49582 .57033 L p .49809 .59738 L .707 .577 .707 r
F P
0 g
s
.49722 .6133 m .50225 .57241 L p .49537 .61367 L .707 .577 .707 r
F P
0 g
s
.49621 .6135 m .49213 .5883 L .49051 .61464 L .707 .577 .707 r
F
.49621 .6135 m .49051 .61464 L .48999 .62317 L F
.48877 .62755 m .4952 .62963 L p .49537 .61367 L F P
0 g
s
.49036 .61467 m .48999 .62317 L p .49213 .5883 L .707 .577 .707 r
F P
0 g
s
.49036 .61467 m .48877 .62755 L p .48915 .62675 L .707 .577 .707 r
F P
0 g
s
.4895 .62329 m .48999 .62317 L p .4896 .62227 L .707 .577 .707 r
F P
0 g
s
.48877 .62755 m .49036 .61467 L p .48693 .61475 L .707 .577 .707 r
F P
0 g
s
.48999 .62317 m .49036 .61467 L p .48638 .61476 L .707 .577 .707 r
F P
0 g
s
.49537 .61367 m .49036 .61467 L .48915 .62675 L .707 .577 .707 r
F
.4737 .62698 m .4895 .62329 L p .48638 .61476 L F P
0 g
s
.4896 .62227 m .48638 .61476 L .4895 .62329 L .707 .577 .707 r
F
.4952 .62963 m .49172 .63051 L p .49511 .61178 L F P
0 g
s
.49429 .61119 m .49501 .60611 L .49604 .61245 L .707 .577 .707 r
F
.497 .61837 m .49722 .6133 L p .49632 .61348 L F P
0 g
s
.497 .61837 m .49237 .58476 L .49213 .5883 L .707 .577 .707 r
F
.4952 .62963 m .49722 .6133 L p .49537 .61367 L F P
0 g
s
.49864 .58046 m .49237 .58476 L p .49632 .61348 L .707 .577 .707 r
F P
0 g
s
.49722 .6133 m .49864 .58046 L p .49632 .61348 L .707 .577 .707 r
F P
0 g
s
.49511 .61178 m .4971 .61321 L .4952 .62963 L .707 .577 .707 r
F
.49501 .60611 m .49864 .58046 L .49621 .61257 L F
.49604 .61245 m .49621 .61257 L .49616 .61321 L F
.49501 .60611 m .49621 .61257 L .49604 .61245 L F
.49722 .6133 m .4952 .62963 L p .4971 .61321 L F P
0 g
s
.49616 .61321 m .49621 .61257 L .49722 .6133 L .707 .577 .707 r
F
.49864 .58046 m .49722 .6133 L p .49621 .61257 L F P
0 g
s
.50101 .57924 m .49722 .6133 L .4971 .61321 L .707 .577 .707 r
F
.49172 .63051 m .49411 .61106 L p .49511 .61178 L F P
0 g
s
.49568 .57513 m .49864 .58046 L p .49412 .61239 L .707 .577 .707 r
F P
0 g
s
.49403 .61305 m .49411 .61106 L p .49412 .61239 L .707 .577 .707 r
F P
0 g
s
.49411 .61106 m .49568 .57513 L p .49412 .61239 L .707 .577 .707 r
F P
0 g
s
.48693 .61475 m .49208 .58901 L .48011 .56726 L .707 .577 .707 r
F
.48638 .61476 m .47821 .59573 L .47543 .61501 L F
.48638 .61476 m .47543 .61501 L .4737 .62698 L F
.47422 .61504 m .4737 .62698 L p .47821 .59573 L F P
0 g
s
.48011 .56726 m .47422 .61504 L p .48693 .61475 L .707 .577 .707 r
F P
0 g
s
.49237 .58476 m .49164 .58526 L p .49213 .5883 L .707 .577 .707 r
F P
0 g
s
.49337 .56985 m .48011 .56726 L p .49208 .58901 L .707 .577 .707 r
F P
0 g
s
.49568 .57513 m .49411 .61106 L p .48138 .60771 L .707 .577 .707 r
F P
0 g
s
.49172 .63051 m .47866 .6301 L p .48604 .60924 L .707 .577 .707 r
F P
0 g
s
.48604 .60924 m .49274 .61075 L .49172 .63051 L .707 .577 .707 r
F
.48381 .60874 m .48138 .60771 L p .49411 .61106 L F P
0 g
s
.49411 .61106 m .49172 .63051 L p .49398 .5868 L .707 .577 .707 r
F P
0 g
s
.48138 .60771 m .48303 .5698 L .49568 .57513 L p .707 .577 .707 r
F P
0 g
s
.47866 .6301 m .48571 .57288 L .49877 .57329 L p .707 .577 .707 r
F P
0 g
s
.49411 .61106 m .49403 .61305 L .48381 .60874 L p .707 .577 .707 r
F P
0 g
s
.48604 .60924 m .49398 .5868 L .49274 .61075 L .707 .577 .707 r
F
.49877 .57329 m .49411 .61106 L p .49398 .5868 L F P
0 g
s
.49877 .57329 m .50225 .57241 L p .49511 .61178 L .707 .577 .707 r
F P
0 g
s
.49411 .61106 m .49877 .57329 L p .49511 .61178 L .707 .577 .707 r
F P
0 g
s
.49511 .61178 m .50101 .57924 L .4971 .61321 L .707 .577 .707 r
F
.49403 .61305 m .49429 .61119 L .49616 .61321 L F
.49429 .61119 m .49604 .61245 L .49616 .61321 L F
.49722 .6133 m .497 .61837 L .49694 .61828 L p F P
0 g
s
.49662 .61863 m .497 .61837 L p .49679 .61711 L .707 .577 .707 r
F P
0 g
s
.49694 .61828 m .49403 .61305 L p .49722 .6133 L .707 .577 .707 r
F P
0 g
s
.50225 .57241 m .49722 .6133 L p .50101 .57924 L .707 .577 .707 r
F P
0 g
s
.48011 .56726 m .45664 .56349 L p .47261 .62282 L .707 .577 .707 r
F P
0 g
s
.47306 .62447 m .47422 .61504 L p .47261 .62282 L .707 .577 .707 r
F P
0 g
s
.47422 .61504 m .48011 .56726 L p .47261 .62282 L .707 .577 .707 r
F P
0 g
s
.4737 .62698 m .47422 .61504 L p .46604 .61482 L .707 .577 .707 r
F P
0 g
s
.44972 .62941 m .4737 .62698 L p .45658 .59978 L .707 .577 .707 r
F P
0 g
s
.45037 .61438 m .44972 .62941 L p .45658 .59978 L .707 .577 .707 r
F P
0 g
s
.45664 .56349 m .45037 .61438 L p .47049 .61494 L .707 .577 .707 r
F P
0 g
s
.45664 .56349 m .42773 .55939 L p .44872 .61826 L .707 .577 .707 r
F P
0 g
s
.44959 .6207 m .45037 .61438 L p .44872 .61826 L .707 .577 .707 r
F P
0 g
s
.45037 .61438 m .45664 .56349 L p .44872 .61826 L .707 .577 .707 r
F P
0 g
s
.44972 .62941 m .45037 .61438 L p .43799 .61369 L .707 .577 .707 r
F P
0 g
s
.42039 .63024 m .44972 .62941 L p .42864 .60117 L .707 .577 .707 r
F P
0 g
s
.42115 .61276 m .42039 .63024 L p .42864 .60117 L .707 .577 .707 r
F P
0 g
s
.42773 .55939 m .42115 .61276 L p .44728 .61421 L .707 .577 .707 r
F P
0 g
s
.42773 .55939 m .39619 .55536 L p .41991 .61468 L .707 .577 .707 r
F P
0 g
s
.42068 .61661 m .42115 .61276 L p .41991 .61468 L .707 .577 .707 r
F P
0 g
s
.42115 .61276 m .42773 .55939 L p .41991 .61468 L .707 .577 .707 r
F P
0 g
s
.42039 .63024 m .42115 .61276 L p .40588 .61158 L .707 .577 .707 r
F P
0 g
s
.38859 .62938 m .42039 .63024 L p .39721 .60042 L .707 .577 .707 r
F P
0 g
s
.38942 .61032 m .38859 .62938 L p .39721 .60042 L .707 .577 .707 r
F P
0 g
s
.39619 .55536 m .38942 .61032 L p .41907 .6126 L .707 .577 .707 r
F P
0 g
s
.39619 .55536 m .36512 .55181 L p .38864 .61131 L .707 .577 .707 r
F P
0 g
s
.38914 .61258 m .38942 .61032 L p .38864 .61131 L .707 .577 .707 r
F P
0 g
s
.38942 .61032 m .39619 .55536 L p .38864 .61131 L .707 .577 .707 r
F P
0 g
s
.34218 .55866 m .37151 .55783 L p .34205 .59467 L .707 .577 .707 r
F P
0 g
s
.33822 .61403 m .34062 .59459 L p .35099 .59517 L .707 .577 .707 r
F P
0 g
s
.34053 .59657 m .34062 .59459 L p .34205 .59467 L .707 .577 .707 r
F P
0 g
s
.34062 .59459 m .34218 .55866 L p .34205 .59467 L .707 .577 .707 r
F P
0 g
s
.37151 .55783 m .36986 .59574 L .36422 .5959 L p .707 .577 .707 r
F P
0 g
s
.35743 .62691 m .35828 .60731 L p .34427 .60564 L .707 .577 .707 r
F P
0 g
s
.36714 .61813 m .33822 .61403 L p .35099 .59517 L .707 .577 .707 r
F P
0 g
s
.36984 .59622 m .36714 .61813 L p .35099 .59517 L .707 .577 .707 r
F P
0 g
s
.36422 .5959 m .34053 .59657 L p .34205 .59467 L .707 .577 .707 r
F P
0 g
s
.34205 .59467 m .37151 .55783 L .36422 .5959 L .707 .577 .707 r
F
.36986 .59574 m .37151 .55783 L .40331 .55869 L p F P
0 g
s
.40331 .55869 m .40166 .5966 L .36986 .59574 L p .707 .577 .707 r
F P
0 g
s
.37419 .56091 m .36984 .59622 L p .35099 .59517 L .707 .577 .707 r
F P
0 g
s
.35099 .59517 m .34062 .59459 L .37419 .56091 L .707 .577 .707 r
F
.34062 .59459 m .34527 .55681 L .35602 .55834 L p F P
0 g
s
.35602 .55834 m .37419 .56091 L p .34062 .59459 L .707 .577 .707 r
F P
0 g
s
.31655 .59901 m .31972 .59401 L .33981 .59648 L .707 .577 .707 r
F
.34053 .59657 m .33974 .59665 L p .33981 .59648 L F P
0 g
s
.33974 .59665 m .31655 .59901 L p .33981 .59648 L .707 .577 .707 r
F P
0 g
s
.34218 .55866 m .34062 .59459 L p .31972 .59401 L .707 .577 .707 r
F P
0 g
s
.34062 .59459 m .34053 .59657 L p .31972 .59401 L .707 .577 .707 r
F P
0 g
s
.34527 .55681 m .34062 .59459 L p .32397 .59413 L .707 .577 .707 r
F P
0 g
s
.32397 .59413 m .31677 .59393 L .34527 .55681 L .707 .577 .707 r
F
.31677 .59393 m .32181 .55304 L .32511 .55357 L p F P
0 g
s
.32511 .55357 m .34527 .55681 L p .31677 .59393 L .707 .577 .707 r
F P
0 g
s
.30026 .60281 m .30395 .59423 L .31578 .59871 L .707 .577 .707 r
F
.31655 .59901 m .31568 .59921 L p .31578 .59871 L F P
0 g
s
.31568 .59921 m .30026 .60281 L p .31578 .59871 L .707 .577 .707 r
F P
0 g
s
.3182 .56109 m .31677 .59393 L p .30395 .59423 L .707 .577 .707 r
F P
0 g
s
.31677 .59393 m .31655 .59901 L p .30395 .59423 L .707 .577 .707 r
F P
0 g
s
.32181 .55304 m .31677 .59393 L p .30449 .59421 L .707 .577 .707 r
F P
0 g
s
.30609 .54997 m .32181 .55304 L p .30449 .59421 L .707 .577 .707 r
F P
0 g
s
.30063 .5943 m .30609 .54997 L p .30449 .59421 L .707 .577 .707 r
F P
0 g
s
.30026 .60281 m .30063 .5943 L p .30395 .59423 L .707 .577 .707 r
F P
0 g
s
.30063 .5943 m .30191 .5649 L .3036 .5645 L p .707 .577 .707 r
F P
0 g
s
.29575 .59528 m .29377 .59568 L .30191 .5649 L .707 .577 .707 r
F
.29904 .60719 m .29324 .60531 L p .29556 .59532 L F P
0 g
s
.30063 .5943 m .29904 .60719 L p .29556 .59532 L .707 .577 .707 r
F P
0 g
s
.29261 .60511 m .29272 .60508 L p .29275 .60484 L .707 .577 .707 r
F P
0 g
s
.29324 .60531 m .29261 .60511 L p .29344 .6017 L .707 .577 .707 r
F P
0 g
s
.29377 .59568 m .2949 .5697 L .29682 .56839 L p .707 .577 .707 r
F P
0 g
s
.29682 .56839 m .30191 .5649 L p .29377 .59568 L .707 .577 .707 r
F P
0 g
s
.38859 .62938 m .38942 .61032 L p .37354 .60878 L .707 .577 .707 r
F P
0 g
s
.64354 .74746 m .64436 .76531 L .64733 .77696 L p .707 .577 .707 r
F P
0 g
s
.84729 .74422 m .84811 .76207 L .84514 .75043 L p .707 .577 .707 r
F P
0 g
s
.84514 .75043 m .84432 .73257 L .84729 .74422 L p .707 .577 .707 r
F P
0 g
s
.82604 .60662 m .82439 .64453 L .8033 .63971 L p .707 .577 .707 r
F P
0 g
s
.8033 .63971 m .80495 .6018 L .82604 .60662 L p .707 .577 .707 r
F P
0 g
s
.64436 .76531 m .64354 .74746 L .65055 .73565 L p .707 .577 .707 r
F P
0 g
s
.82872 .6097 m .82167 .66691 L .80031 .66526 L p .707 .577 .707 r
F P
0 g
s
.80031 .66526 m .80736 .60804 L .82872 .6097 L p .707 .577 .707 r
F P
0 g
s
.65055 .73565 m .65137 .75351 L .64436 .76531 L p .707 .577 .707 r
F P
0 g
s
.84432 .73257 m .84514 .75043 L .83249 .74008 L p .707 .577 .707 r
F P
0 g
s
.83249 .74008 m .83167 .72223 L .84432 .73257 L p .707 .577 .707 r
F P
0 g
s
.80495 .6018 m .8033 .63971 L .77583 .63588 L p .707 .577 .707 r
F P
0 g
s
.77583 .63588 m .77748 .59797 L .80495 .6018 L p .707 .577 .707 r
F P
0 g
s
.80736 .60804 m .80031 .66526 L .77275 .66252 L p .707 .577 .707 r
F P
0 g
s
.77275 .66252 m .7798 .6053 L .80736 .60804 L p .707 .577 .707 r
F P
0 g
s
.65137 .75351 m .65055 .73565 L .66684 .72485 L p .707 .577 .707 r
F P
0 g
s
.39669 .76481 m .39587 .74696 L .36471 .7456 L p .707 .577 .707 r
F P
0 g
s
.39587 .74696 m .39669 .76481 L .42849 .76246 L p .707 .577 .707 r
F P
0 g
s
.42849 .76246 m .42767 .7446 L .39587 .74696 L p .707 .577 .707 r
F P
0 g
s
.42767 .7446 m .42849 .76246 L .45781 .75662 L p .707 .577 .707 r
F P
0 g
s
.45781 .75662 m .457 .73876 L .42767 .7446 L p .707 .577 .707 r
F P
0 g
s
.77748 .59797 m .77583 .63588 L .74467 .63342 L p .707 .577 .707 r
F P
0 g
s
.74467 .63342 m .74632 .59551 L .77748 .59797 L p .707 .577 .707 r
F P
0 g
s
.66684 .72485 m .66766 .7427 L .65137 .75351 L p .707 .577 .707 r
F P
0 g
s
.36553 .76346 m .36471 .7456 L .33724 .74067 L p .707 .577 .707 r
F P
0 g
s
.36471 .7456 m .36553 .76346 L .39669 .76481 L p .707 .577 .707 r
F P
0 g
s
.7798 .6053 m .77275 .66252 L .74168 .65897 L p .707 .577 .707 r
F P
0 g
s
.83167 .72223 m .83249 .74008 L .8114 .73205 L p .707 .577 .707 r
F P
0 g
s
.8114 .73205 m .81058 .71419 L .83167 .72223 L p .707 .577 .707 r
F P
0 g
s
.74168 .65897 m .74873 .60175 L .7798 .6053 L p .707 .577 .707 r
F P
0 g
s
.74873 .60175 m .74168 .65897 L .71015 .65494 L p .707 .577 .707 r
F P
0 g
s
.71015 .65494 m .7172 .59773 L .74873 .60175 L p .707 .577 .707 r
F P
0 g
s
.457 .73876 m .45781 .75662 L .4818 .74786 L p .707 .577 .707 r
F P
0 g
s
.4818 .74786 m .48098 .73001 L .457 .73876 L p .707 .577 .707 r
F P
0 g
s
.33724 .74067 m .33806 .75852 L .36553 .76346 L p .707 .577 .707 r
F P
0 g
s
.33806 .75852 m .33724 .74067 L .31615 .73263 L p .707 .577 .707 r
F P
0 g
s
.66766 .7427 m .66684 .72485 L .69082 .7161 L p .707 .577 .707 r
F P
0 g
s
.31615 .73263 m .31697 .75049 L .33806 .75852 L p .707 .577 .707 r
F P
0 g
s
.69082 .7161 m .69164 .73395 L .66766 .7427 L p .707 .577 .707 r
F P
0 g
s
.48098 .73001 m .4818 .74786 L .49809 .73706 L p .707 .577 .707 r
F P
0 g
s
.49809 .73706 m .49727 .7192 L .48098 .73001 L p .707 .577 .707 r
F P
0 g
s
.81058 .71419 m .8114 .73205 L .78393 .72711 L p .707 .577 .707 r
F P
0 g
s
.78393 .72711 m .78311 .70925 L .81058 .71419 L p .707 .577 .707 r
F P
0 g
s
.69164 .73395 m .69082 .7161 L .72015 .71026 L p .707 .577 .707 r
F P
0 g
s
.31697 .75049 m .31615 .73263 L .3035 .72229 L p .707 .577 .707 r
F P
0 g
s
.78311 .70925 m .78393 .72711 L .75277 .72575 L p .707 .577 .707 r
F P
0 g
s
.75277 .72575 m .75195 .7079 L .78311 .70925 L p .707 .577 .707 r
F P
0 g
s
.72015 .71026 m .72097 .72811 L .69164 .73395 L p .707 .577 .707 r
F P
0 g
s
.3035 .72229 m .30432 .74014 L .31697 .75049 L p .707 .577 .707 r
F P
0 g
s
.72097 .72811 m .72015 .71026 L .75195 .7079 L p .707 .577 .707 r
F P
0 g
s
.75195 .7079 m .75277 .72575 L .72097 .72811 L p .707 .577 .707 r
F P
0 g
s
.49727 .7192 m .49809 .73706 L .5051 .72526 L p .707 .577 .707 r
F P
0 g
s
.5051 .72526 m .50428 .7074 L .49727 .7192 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30432 .74014 m .3035 .72229 L .30053 .71064 L p .707 .577 .707 r
F P
0 g
s
.30053 .71064 m .30135 .7285 L .30432 .74014 L p .707 .577 .707 r
F P
0 g
s
.50428 .7074 m .5051 .72526 L .50213 .71361 L p .707 .577 .707 r
F P
0 g
s
.50213 .71361 m .50131 .69576 L .50428 .7074 L p .707 .577 .707 r
F P
0 g
s
.48303 .5698 m .48138 .60771 L .46029 .6029 L p .707 .577 .707 r
F P
0 g
s
.46029 .6029 m .46194 .56498 L .48303 .5698 L p .707 .577 .707 r
F P
0 g
s
.30135 .7285 m .30053 .71064 L .30754 .69884 L p .707 .577 .707 r
F P
0 g
s
.48571 .57288 m .47866 .6301 L .4573 .62845 L p .707 .577 .707 r
F P
0 g
s
.4573 .62845 m .46435 .57123 L .48571 .57288 L p .707 .577 .707 r
F P
0 g
s
.30754 .69884 m .30836 .71669 L .30135 .7285 L p .707 .577 .707 r
F P
0 g
s
.50131 .69576 m .50213 .71361 L .48948 .70327 L p .707 .577 .707 r
F P
0 g
s
.48948 .70327 m .48866 .68541 L .50131 .69576 L p .707 .577 .707 r
F P
0 g
s
.46194 .56498 m .46029 .6029 L .43282 .59907 L p .707 .577 .707 r
F P
0 g
s
.43282 .59907 m .43447 .56116 L .46194 .56498 L p .707 .577 .707 r
F P
0 g
s
.46435 .57123 m .4573 .62845 L .42974 .62571 L p .707 .577 .707 r
F P
0 g
s
.42974 .62571 m .43679 .56849 L .46435 .57123 L p .707 .577 .707 r
F P
0 g
s
.30836 .71669 m .30754 .69884 L .32383 .68803 L p .707 .577 .707 r
F P
0 g
s
.43447 .56116 m .43282 .59907 L .40166 .5966 L p .707 .577 .707 r
F P
0 g
s
.40166 .5966 m .40331 .55869 L .43447 .56116 L p .707 .577 .707 r
F P
0 g
s
.32383 .68803 m .32465 .70589 L .30836 .71669 L p .707 .577 .707 r
F P
0 g
s
.43679 .56849 m .42974 .62571 L .39867 .62215 L p .707 .577 .707 r
F P
0 g
s
.48866 .68541 m .48948 .70327 L .46839 .69523 L p .707 .577 .707 r
F P
0 g
s
.46839 .69523 m .46757 .67738 L .48866 .68541 L p .707 .577 .707 r
F P
0 g
s
.39867 .62215 m .40572 .56493 L .43679 .56849 L p .707 .577 .707 r
F P
0 g
s
.40572 .56493 m .39867 .62215 L .36714 .61813 L p .707 .577 .707 r
F P
0 g
s
.36714 .61813 m .37419 .56091 L .40572 .56493 L p .707 .577 .707 r
F P
0 g
s
.32465 .70589 m .32383 .68803 L .34781 .67928 L p .707 .577 .707 r
F P
0 g
s
.34781 .67928 m .34863 .69714 L .32465 .70589 L p .707 .577 .707 r
F P
0 g
s
.46757 .67738 m .46839 .69523 L .44092 .69029 L p .707 .577 .707 r
F P
0 g
s
.44092 .69029 m .4401 .67244 L .46757 .67738 L p .707 .577 .707 r
F P
0 g
s
.34863 .69714 m .34781 .67928 L .37714 .67344 L p .707 .577 .707 r
F P
0 g
s
.4401 .67244 m .44092 .69029 L .40976 .68894 L p .707 .577 .707 r
F P
0 g
s
.40976 .68894 m .40894 .67108 L .4401 .67244 L p .707 .577 .707 r
F P
0 g
s
.37714 .67344 m .37796 .6913 L .34863 .69714 L p .707 .577 .707 r
F P
0 g
s
.37796 .6913 m .37714 .67344 L .40894 .67108 L p .707 .577 .707 r
F P
0 g
s
.40894 .67108 m .40976 .68894 L .37796 .6913 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo5P00QWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH9001mOol007Ioo`D000QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00H007Moo`00LGoo1@000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01UYF1000Lgoo001]Ool40007FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH00003001_Ool0
06]oo`800003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP<006aoo`00JGoo0P000eYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF0`00JWoo001WOol2
0005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02001XOol006Ioo`8000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001oogoo06Eoo`00IWoo0P001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo
Ool0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol0
0`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001J
EP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF00001UYF00<0
05YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Io
o`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF
001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00=JEP8006Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol200000eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH2001VOol006Aoo`800003FUH005YF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Ioo`00I7oo0P0000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol70008Ool01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001EOol50002FUH@00000eYF001JEP08
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eoo`04001JEP00FUH70007FUH00`00FUIJEP02FUH7
0004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Eoo`03001JEP0000=JEP04001JEUYFFUHI000;
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001VOol005Aoo`800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00=JEPL0
00=JEP03001JEUYF009JEPP000AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0`0015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH00UYF2@000eYF00@005YFFUIJEPH000YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo0`0015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YF00001000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001COol01000FUH0000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEQ0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Ioo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEP0000<000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00@005YF0000
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00AJEP03001JEUYF00AJEP03001JEUYF00<000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0006Ioo`00Dgoo00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Dgoo00<0
05YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH00`0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00003P00F7oo001COol00`00FUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000
FUIJEUYF0`0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00H005YF001JEP00
FUH600000eYF001JEP02FUH9001?Ool002ioo`h001Moo`03001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03
001JEUYF00800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEP00FUH00003FUH01000FUIJEUYF1@0015YF00<005YFFUH00UYF2@00AWoo000^Ool50005FUH0
1000FUIJEUYF2@003Woo00<005YF00000eYF00@005YFFUIJEP@000QJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00800003FUH005YF00]JEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUH0000I000nOol002ioo`04001JEP00FUH70007FUH00`00FUIJEP02FUH90005Ool00`00FUH0
0002FUH50003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP04FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP04
0002FUH01000FUIJEUYF3P00=goo000^Ool00`00FUH00003FUH01000FUIJEUYF1`0000=JEP00FUH0
1eYF00<005YFFUH00UYF1@000UYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH00P0000=JEP00FUH02eYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH015YF1`000eYF00@005YFFUIJEP/0039oo`00;Goo00@005YF
FUH000=JEP03001JEUYF00AJEP04001JEUYFFUH900000eYF001JEP07FUH50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04
FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUHF000^
Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT00004
FUH000000002FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP09000/Ool002eoo`03001JEP0000=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPD00003FUH005YF00AJ
EPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EP0000800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001J
EUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000]Ool00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004FUH00`00FUIJEP04FUH9
0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF009JEP03001oogoo02Yoo`00;Goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00IJ
EP03001JEUYF00EJEPT000AJEP03001JEUYF00AJEP03001JEUYF00AJEP08001JEUYF001JEP00FUH0
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF008002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF1@0015YF00<005YFFUH01UYF00<005YF
FUH01EYF20000eYF00<005YFFUH015YF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEQ8000AJEP03001JEUYF009JEPT000=JEP03
001JEUYF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002eoo`03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP80009JEP03001JEUYF00=JEPl000MJEP03001JEP0000L0009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000]Ool002aoo`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH0
0`00FUIJEP03FUH60004FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP03FUH60004FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00FUH000020005FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@0009JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF1P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF
00000P00;Woo000]Ool30002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH01P00FUH00000FUH000AJEPL000AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYFFUH005YF;Woo000`Ool60003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF1000
0eYF00<005YFFUH00eYF2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00=Woo1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH015YF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00001EYF1`0015YF00<005YFFUH015YF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00?Goo2@0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
00MJEP03001JEUYF009JEPP000AJEP03001JEUYF00EJEPP000AJEP03001JEUYF00=JEP04001JEUYF
FUH2000^Ool004Ioo`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP04FUH01000
FUIJEUYF0P0000=oo`0000008P00;Woo001?Ool80004FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00<005YFFUH00eYF00<005YFFUH02@002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00H005YFFUIJ
EP00FUH7Ool50018Ool005Moo`L000=JEP04001JEUYF0002FUH00`00FUH000060004FUH00`00FUIJ
EP02FUH80002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEPMoo`D004Qoo`00
GWoo2`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD000UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00=J
EP04001JEUYFFUH20007Ool50018Ool0065oo`@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEP00008000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool30019Ool0
05ioo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000IJEP03001JEUYF00=JEP04001JEUYFFUH2001DOol005aoo`8000AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF
00=JEP04001JEUYFFUH2001DOol004Uoo`T000Qoo`<000IJEP03001JEUYF00AJEPH000MJEP03001J
EP0000L000AJEP03001JEUYF009JEP06001JEP00001JEP0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00001UYF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00@Woo
1`0015YF00<005YFFUH00UYF20000UYF00<005YFFUH015YF00<005YFFUH010000eYF00<005YFFUH0
1eYF00<005YFFUH01eYF1P0015YF00<005YFFUH00P0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF00@005YFFUIJEP8005Aoo`00?Woo1000
0UYF00<005YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH00eYF100000=JEP00FUH015YF
00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP<00004FUH005YFFUH2000<FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00EGoo000jOol40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20004FUH00`00FUH00003
0002Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH015YF0P000UYF
0P0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH00eYF00@005YFFUIJEP8005Eoo`00=goo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF0P0015YF0P0015YF0`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH01UYF00@005YF000000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol003Eoo`8000AJEP03001JEUYF
00IJEP03001JEUYF009JEPT000=JEP03001JEP00009JEP80009JEP03001JEUYF009JEP80009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00MJEP<000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000P000=JEP04001JEUYFFUH20003OolE
000mOol003=oo`<000IJEP03001JEUYF00AJEPH000Uoo`@00004FUH000000004FUH00`00FUIJEP02
FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP08FUH2000<
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00008Ool<00000eYF001J
EP07FUH00`00FUIJEP06FUH00`00FUH00003000iOol0035oo`80009JEP03001JEUYF00AJEP03001J
EUYF00@0019oo`03001JEP00009oo`H000AJEP04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0000<Ool40005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000eOol0
031oo`03001JEUYF009JEP03001JEUYF00=JEP@001Ioo`8000Uoo`<00005FUH005YFFUH00005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH3000<FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000:Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002000bOol0031oo`03001JEUYF009JEP03001JEP00
00<000eoo`<000Yoo`8000aoo`80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00EJEP<00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000Qoo`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF009JEP80031oo`00;goo0P0015YF0P0047oo1@002Goo0`0037oo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP80009JEP03001JEP00
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Ioo`8000EJEP03
001JEUYF00EJEP03001JEUYF009JEPl000IJEP03001JEUYF00=JEP8002moo`00;goo0P000UYF0P00
4Woo1@002Goo0P0000=JEP00Ool02Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP04001JEUYFFUH20004FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH000020002Ool30006FUH00`00FUIJEP02FUH8000?Ool40002FUH00`00FUIJEP03FUH00`00
FUH0000^Ool002ioo`03001JEP00008000AooaT000Eoo`80009JEP8000Uoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH01P00FUH00000FUH000AJEP<000aJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEP00001JEP020002FUH00`00FUIJEP03FUH6000KOol4
0004FUH01000FUIJEP00;Goo000^Ool01000FUH007oo1@000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`000UYF00<005YF00000P001Woo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP8000=JEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP04001JEUYFFUH2000UOol300001EYF001J
EUYF0000;Goo000^Ool400000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUH00002FUH00`00FUIJEP02FUH30003Ool01000FUIJEP001EYF00<005YFFUH01eYF
00<005YFFUH015YF1@001EYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF00<005YF000010009goo0P000UYF0P00
;7oo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YF00000`000UYF00<005YFFUH00eYF00<005YF
FUH01EYF2@000eYF00<005YFFUH015YF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00000P0015YF0`0015YF0P009goo00@005YFFUH002aoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUIJEP<000AJEP03001JEUYF00=JEQ0000AJEP03001JEUYF00EJEP03001JEUYF00AJ
EP03001JEP0000/000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
009JEP04001JEUYF0002FUH00`00FUIJEP03FUH2000WOol3000/Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF
FUH5000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH40002FUH00`00
FUIJEP03FUH00`00FUH0000WOol2000/Ool002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP0:FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000Oomo
ogoo100015YF00@005YFFUH002Eoo`04001JEP00000[Ool002aoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEP0000<000IJEP03001JEUYF009JEP03001JEP00008000Qoo`<00005
FUH005YFFUH0000TOol20002FUH00`00Oomoo`0YOol002aoo`03001JEP0000=JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJ
EP@00003FUH005YF00MJEP03001JEUYF009JEPT000aJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00=JEP@0009JEP03001JEUYF009JEP03001JEP00008000]oo`80009JEP80029oo`03001J
EP00009JEP03001oogoo02Uoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUH005YF
00l000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@000AJ
EP05001JEP00001JEP02000;Ool01000FUIJEP008Goo00H005YFFUH005YF000/Ool002aoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUH000001eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00D005YFFUIJEP0000=J
EP04001JEP000003FUH00`00Oomoo`09Ool3000OOol20004FUH2000/Ool002aoo`03001JEP0000=J
EP04001JEUYFFUHJ0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P0000=J
EP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00FUH00P000eYF0`002Woo0P006goo100000=JEP00
FUH00eYF00<007ooOol0:goo000/Ool00`00FUH00002FUH700000eYF001JEP05FUH00`00FUIJEP04
FUH50004FUH80003FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP800003FUH0000000=JEP03001JEUYF008000Moo`04001JEP00000GOol30005FUH00`00
FUIJEP02FUH00`00Oomoo`0[Ool002aoo`03001JEP00008000IJEP@000EJEP03001JEUYF00AJEPD0
00IJEP03001JEUYF009JEPL000=JEP03001JEUYF008000AJEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJ
EP800004FUH005YF0002FUH00`00FUIJEP02FUH500000goo00000002FUH00`00Oomoo`0AOol40000
0eYF001JEP05FUH00`00FUIJEP02000^Ool002aoo`80009JEP03001JEUYF00=JEP03001JEUYF009J
EP@00003FUH005YF00EJEPD0009JEPT0009JEP03001JEUYF009JEP@0009JEP8000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEP000002FUH30005FUH01000FUIJEUYF6@001EYF00<005YFFUH0
15YF0`00<7oo000/Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH@0002FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP040004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUH0
000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF0P00<Woo000]Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP001EYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00=7oo000_Ool30004FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00007FUH300000eYF
001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH3000hOol0039oo`<00003
FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03
001JEUYF009JEP@0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP<000MJEP03001JEUYF00D000AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003]oo`00=Goo1@0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`000goo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH00eYF00<005YF00006000?goo000jOolB
0004FUH00`00FUIJEP02FUH=0008Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF0P000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP8005Aoo`00C7oo2@005goo0P0015YF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF000000EJEP03001J
EUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP00E7oo001^Ool300000eYF001JEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH?0004FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH005Aoo`00LGoo1`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YF000020001UYF00<005YFFUH00UYF1P0015YF00<005YFFUH00P00EGoo001hOol<
0006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004FUH50006FUH00`00FUIJEP040004FUH30000
15YF001JEUYF0P00EGoo0024Oolc0003FUH00`00FUIJEP04FUH400000eYF0000001EOol008ioo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`00EGoo002?Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00EGoo002AOol40003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0005Eoo`00UGoo1`0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0000=JEWooOol0
E7oo002LOol80004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P00FGoo002TOolJ
001OOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]47\[InvisibleSpace]"     "\
\[InvisibleSpace]12.859254392790367`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 47, "     ", 12.859254392790367, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59891 .71718 m .58573 .6619 L .55546 .66758 L p .707 .577 .707 r
F P
0 g
s
.58573 .6619 m .59891 .71718 L .62994 .70956 L p .707 .577 .707 r
F P
0 g
s
.62994 .70956 m .61675 .65428 L .58573 .6619 L p .707 .577 .707 r
F P
0 g
s
.61675 .65428 m .62994 .70956 L .65867 .70076 L p .707 .577 .707 r
F P
0 g
s
.65867 .70076 m .64549 .64547 L .61675 .65428 L p .707 .577 .707 r
F P
0 g
s
.56864 .72287 m .55546 .66758 L .5289 .67077 L p .707 .577 .707 r
F P
0 g
s
.55546 .66758 m .56864 .72287 L .59891 .71718 L p .707 .577 .707 r
F P
0 g
s
.64549 .64547 m .65867 .70076 L .68231 .69162 L p .707 .577 .707 r
F P
0 g
s
.68231 .69162 m .66912 .63633 L .64549 .64547 L p .707 .577 .707 r
F P
0 g
s
.5289 .67077 m .54209 .72606 L .56864 .72287 L p .707 .577 .707 r
F P
0 g
s
.54209 .72606 m .5289 .67077 L .50866 .67116 L p .707 .577 .707 r
F P
0 g
s
.66912 .63633 m .68231 .69162 L .69854 .68305 L p .707 .577 .707 r
F P
0 g
s
.69854 .68305 m .68535 .62776 L .66912 .63633 L p .707 .577 .707 r
F P
0 g
s
.50866 .67116 m .52185 .72644 L .54209 .72606 L p .707 .577 .707 r
F P
0 g
s
.60232 .84756 m .59507 .8105 L .56451 .81484 L p .707 .577 .707 r
F P
0 g
s
.59507 .8105 m .60232 .84756 L .6336 .84116 L p .707 .577 .707 r
F P
0 g
s
.6336 .84116 m .62635 .80409 L .59507 .8105 L p .707 .577 .707 r
F P
0 g
s
.58443 .81725 m .5874 .7993 L .55663 .79239 L p .707 .577 .707 r
F P
0 g
s
.5874 .7993 m .58443 .81725 L .6159 .82099 L p .707 .577 .707 r
F P
0 g
s
.6159 .82099 m .61887 .80304 L .5874 .7993 L p .707 .577 .707 r
F P
0 g
s
.62635 .80409 m .6336 .84116 L .66255 .83331 L p .707 .577 .707 r
F P
0 g
s
.66255 .83331 m .6553 .79625 L .62635 .80409 L p .707 .577 .707 r
F P
0 g
s
.61887 .80304 m .6159 .82099 L .64499 .82119 L p .707 .577 .707 r
F P
0 g
s
.64499 .82119 m .64796 .80324 L .61887 .80304 L p .707 .577 .707 r
F P
0 g
s
.55367 .81034 m .55663 .79239 L .52958 .78299 L p .707 .577 .707 r
F P
0 g
s
.55663 .79239 m .55367 .81034 L .58443 .81725 L p .707 .577 .707 r
F P
0 g
s
.56451 .81484 m .57176 .8519 L .60232 .84756 L p .707 .577 .707 r
F P
0 g
s
.57176 .8519 m .56451 .81484 L .53766 .81668 L p .707 .577 .707 r
F P
0 g
s
.52958 .78299 m .52662 .80094 L .55367 .81034 L p .707 .577 .707 r
F P
0 g
s
.6553 .79625 m .66255 .83331 L .68632 .82479 L p .707 .577 .707 r
F P
0 g
s
.68632 .82479 m .67907 .78773 L .6553 .79625 L p .707 .577 .707 r
F P
0 g
s
.52185 .72644 m .50866 .67116 L .49671 .6687 L p .707 .577 .707 r
F P
0 g
s
.53766 .81668 m .54491 .85375 L .57176 .8519 L p .707 .577 .707 r
F P
0 g
s
.64796 .80324 m .64499 .82119 L .66886 .81785 L p .707 .577 .707 r
F P
0 g
s
.66886 .81785 m .67182 .79989 L .64796 .80324 L p .707 .577 .707 r
F P
0 g
s
.52662 .80094 m .52958 .78299 L .5089 .77202 L p .707 .577 .707 r
F P
0 g
s
.68535 .62776 m .69854 .68305 L .70576 .67589 L p .707 .577 .707 r
F P
0 g
s
.70576 .67589 m .69258 .6206 L .68535 .62776 L p .707 .577 .707 r
F P
0 g
s
.49671 .6687 m .5099 .72399 L .52185 .72644 L p .707 .577 .707 r
F P
0 g
s
.54491 .85375 m .53766 .81668 L .51715 .81586 L p .707 .577 .707 r
F P
0 g
s
.5089 .77202 m .50593 .78997 L .52662 .80094 L p .707 .577 .707 r
F P
0 g
s
.67907 .78773 m .68632 .82479 L .70259 .81644 L p .707 .577 .707 r
F P
0 g
s
.70259 .81644 m .69534 .77938 L .67907 .78773 L p .707 .577 .707 r
F P
0 g
s
.51715 .81586 m .5244 .85292 L .54491 .85375 L p .707 .577 .707 r
F P
0 g
s
.67182 .79989 m .66886 .81785 L .68516 .81127 L p .707 .577 .707 r
F P
0 g
s
.68516 .81127 m .68813 .79332 L .67182 .79989 L p .707 .577 .707 r
F P
0 g
s
.50593 .78997 m .5089 .77202 L .49659 .76055 L p .707 .577 .707 r
F P
0 g
s
.5099 .72399 m .49671 .6687 L .49423 .66364 L p .707 .577 .707 r
F P
0 g
s
.49659 .76055 m .49363 .7785 L .50593 .78997 L p .707 .577 .707 r
F P
0 g
s
.5244 .85292 m .51715 .81586 L .505 .81244 L p .707 .577 .707 r
F P
0 g
s
.69258 .6206 m .70576 .67589 L .70328 .67083 L p .707 .577 .707 r
F P
0 g
s
.70328 .67083 m .69009 .61555 L .69258 .6206 L p .707 .577 .707 r
F P
0 g
s
.49423 .66364 m .50742 .71893 L .5099 .72399 L p .707 .577 .707 r
F P
0 g
s
.505 .81244 m .51225 .8495 L .5244 .85292 L p .707 .577 .707 r
F P
0 g
s
.69534 .77938 m .70259 .81644 L .70977 .80906 L p .707 .577 .707 r
F P
0 g
s
.70977 .80906 m .70252 .772 L .69534 .77938 L p .707 .577 .707 r
F P
0 g
s
.68813 .79332 m .68516 .81127 L .69231 .80211 L p .707 .577 .707 r
F P
0 g
s
.69231 .80211 m .69528 .78416 L .68813 .79332 L p .707 .577 .707 r
F P
0 g
s
.49388 .74971 m .49092 .76766 L .49363 .7785 L p .707 .577 .707 r
F P
0 g
s
.49363 .7785 m .49659 .76055 L .49388 .74971 L p .707 .577 .707 r
F P
0 g
s
.49092 .76766 m .49388 .74971 L .50103 .74055 L p .707 .577 .707 r
F P
0 g
s
.50103 .74055 m .49807 .7585 L .49092 .76766 L p .707 .577 .707 r
F P
0 g
s
.49037 .82227 m .49551 .32096 L .4515 .31783 L p .707 .577 .707 r
F P
0 g
s
.50742 .71893 m .49423 .66364 L .50146 .65648 L p .707 .577 .707 r
F P
0 g
s
.51225 .8495 m .505 .81244 L .50238 .80676 L p .707 .577 .707 r
F P
0 g
s
.50146 .65648 m .51464 .71177 L .50742 .71893 L p .707 .577 .707 r
F P
0 g
s
.50238 .80676 m .50963 .84383 L .51225 .8495 L p .707 .577 .707 r
F P
0 g
s
.51464 .71177 m .50146 .65648 L .51768 .64791 L p .707 .577 .707 r
F P
0 g
s
.50963 .84383 m .50238 .80676 L .50956 .79939 L p .707 .577 .707 r
F P
0 g
s
.51768 .64791 m .53087 .7032 L .51464 .71177 L p .707 .577 .707 r
F P
0 g
s
.50956 .79939 m .51681 .83645 L .50963 .84383 L p .707 .577 .707 r
F P
0 g
s
.49807 .7585 m .50103 .74055 L .51734 .73397 L p .707 .577 .707 r
F P
0 g
s
.53087 .7032 m .51768 .64791 L .54132 .63878 L p .707 .577 .707 r
F P
0 g
s
.51734 .73397 m .51437 .75193 L .49807 .7585 L p .707 .577 .707 r
F P
0 g
s
.51681 .83645 m .50956 .79939 L .52583 .79103 L p .707 .577 .707 r
F P
0 g
s
.52583 .79103 m .53308 .82809 L .51681 .83645 L p .707 .577 .707 r
F P
0 g
s
.51437 .75193 m .51734 .73397 L .5412 .73063 L p .707 .577 .707 r
F P
0 g
s
.5412 .73063 m .53824 .74858 L .51437 .75193 L p .707 .577 .707 r
F P
0 g
s
.53308 .82809 m .52583 .79103 L .54961 .78252 L p .707 .577 .707 r
F P
0 g
s
.49551 .32096 m .49037 .82227 L .53531 .82159 L p .707 .577 .707 r
F P
0 g
s
.54132 .63878 m .55451 .69406 L .53087 .7032 L p .707 .577 .707 r
F P
0 g
s
.53531 .82159 m .54045 .32028 L .49551 .32096 L p .707 .577 .707 r
F P
0 g
s
.55451 .69406 m .54132 .63878 L .57006 .62997 L p .707 .577 .707 r
F P
0 g
s
.57006 .62997 m .58324 .68526 L .55451 .69406 L p .707 .577 .707 r
F P
0 g
s
.54961 .78252 m .55686 .81958 L .53308 .82809 L p .707 .577 .707 r
F P
0 g
s
.53824 .74858 m .5412 .73063 L .57029 .73083 L p .707 .577 .707 r
F P
0 g
s
.57029 .73083 m .56733 .74878 L .53824 .74858 L p .707 .577 .707 r
F P
0 g
s
.55686 .81958 m .54961 .78252 L .57855 .77467 L p .707 .577 .707 r
F P
0 g
s
.56733 .74878 m .57029 .73083 L .60176 .73457 L p .707 .577 .707 r
F P
0 g
s
.60176 .73457 m .5988 .75252 L .56733 .74878 L p .707 .577 .707 r
F P
0 g
s
.57855 .77467 m .5858 .81173 L .55686 .81958 L p .707 .577 .707 r
F P
0 g
s
.54045 .32028 m .53531 .82159 L .57679 .81714 L p .707 .577 .707 r
F P
0 g
s
.58324 .68526 m .57006 .62997 L .60108 .62235 L p .707 .577 .707 r
F P
0 g
s
.57679 .81714 m .58193 .31584 L .54045 .32028 L p .707 .577 .707 r
F P
0 g
s
.44636 .81913 m .4515 .31783 L .41274 .31117 L p .707 .577 .707 r
F P
0 g
s
.4515 .31783 m .44636 .81913 L .49037 .82227 L p .707 .577 .707 r
F P
0 g
s
.69009 .61555 m .70328 .67083 L .69133 .66838 L p .707 .577 .707 r
F P
0 g
s
.69133 .66838 m .67815 .61309 L .69009 .61555 L p .707 .577 .707 r
F P
0 g
s
.60108 .62235 m .61427 .67764 L .58324 .68526 L p .707 .577 .707 r
F P
0 g
s
.63253 .74148 m .62956 .75943 L .5988 .75252 L p .707 .577 .707 r
F P
0 g
s
.5988 .75252 m .60176 .73457 L .63253 .74148 L p .707 .577 .707 r
F P
0 g
s
.5858 .81173 m .57855 .77467 L .60984 .76827 L p .707 .577 .707 r
F P
0 g
s
.60984 .76827 m .61709 .80533 L .5858 .81173 L p .707 .577 .707 r
F P
0 g
s
.58193 .31584 m .57679 .81714 L .61075 .80938 L p .707 .577 .707 r
F P
0 g
s
.61427 .67764 m .60108 .62235 L .63135 .61667 L p .707 .577 .707 r
F P
0 g
s
.61709 .80533 m .60984 .76827 L .6404 .76393 L p .707 .577 .707 r
F P
0 g
s
.61075 .80938 m .61589 .30807 L .58193 .31584 L p .707 .577 .707 r
F P
0 g
s
.70252 .772 m .70977 .80906 L .70716 .80339 L p .707 .577 .707 r
F P
0 g
s
.70716 .80339 m .69991 .76633 L .70252 .772 L p .707 .577 .707 r
F P
0 g
s
.69528 .78416 m .69231 .80211 L .6896 .79127 L p .707 .577 .707 r
F P
0 g
s
.6896 .79127 m .69257 .77332 L .69528 .78416 L p .707 .577 .707 r
F P
0 g
s
.4076 .81248 m .41274 .31117 L .38302 .30165 L p .707 .577 .707 r
F P
0 g
s
.41274 .31117 m .4076 .81248 L .44636 .81913 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25931 .72355 m .25206 .68649 L .2215 .69083 L p .707 .577 .707 r
F P
0 g
s
.25206 .68649 m .25931 .72355 L .29059 .71715 L p .707 .577 .707 r
F P
0 g
s
.29059 .71715 m .28335 .68008 L .25206 .68649 L p .707 .577 .707 r
F P
0 g
s
.2215 .69083 m .22875 .72789 L .25931 .72355 L p .707 .577 .707 r
F P
0 g
s
.25591 .72891 m .24272 .67362 L .21245 .6793 L p .707 .577 .707 r
F P
0 g
s
.24272 .67362 m .25591 .72891 L .28693 .72129 L p .707 .577 .707 r
F P
0 g
s
.28693 .72129 m .27374 .666 L .24272 .67362 L p .707 .577 .707 r
F P
0 g
s
.28335 .68008 m .29059 .71715 L .31954 .7093 L p .707 .577 .707 r
F P
0 g
s
.31954 .7093 m .31229 .67224 L .28335 .68008 L p .707 .577 .707 r
F P
0 g
s
.27374 .666 m .28693 .72129 L .31566 .71248 L p .707 .577 .707 r
F P
0 g
s
.31566 .71248 m .30248 .65719 L .27374 .666 L p .707 .577 .707 r
F P
0 g
s
.67815 .61309 m .69133 .66838 L .67109 .66876 L p .707 .577 .707 r
F P
0 g
s
.67109 .66876 m .65791 .61348 L .67815 .61309 L p .707 .577 .707 r
F P
0 g
s
.22563 .73459 m .21245 .6793 L .18589 .6825 L p .707 .577 .707 r
F P
0 g
s
.21245 .6793 m .22563 .73459 L .22792 .73416 L p .707 .577 .707 r
F P
0 g
s
.22875 .72789 m .2215 .69083 L .21863 .69102 L p .707 .577 .707 r
F P
0 g
s
.22875 .72789 m .21863 .69102 L .22594 .725 L .707 .577 .707 r
F
.21729 .68483 m .21245 .6793 L .22792 .73416 L F
.18589 .6825 m .19908 .73778 L .22563 .73459 L p F P
0 g
s
.19465 .69267 m .2019 .72974 L .22875 .72789 L p .707 .577 .707 r
F P
0 g
s
.22792 .73416 m .25591 .72891 L p .21729 .68483 L .707 .577 .707 r
F P
0 g
s
.21863 .69102 m .19465 .69267 L p .22594 .725 L .707 .577 .707 r
F P
0 g
s
.63135 .61667 m .64454 .67196 L .61427 .67764 L p .707 .577 .707 r
F P
0 g
s
.65958 .75088 m .65661 .76883 L .62956 .75943 L p .707 .577 .707 r
F P
0 g
s
.62956 .75943 m .63253 .74148 L .65958 .75088 L p .707 .577 .707 r
F P
0 g
s
.6404 .76393 m .64765 .80099 L .61709 .80533 L p .707 .577 .707 r
F P
0 g
s
.61589 .30807 m .61075 .80938 L .63385 .79905 L p .707 .577 .707 r
F P
0 g
s
.64454 .67196 m .63135 .61667 L .65791 .61348 L p .707 .577 .707 r
F P
0 g
s
.63385 .79905 m .639 .29774 L .61589 .30807 L p .707 .577 .707 r
F P
0 g
s
.69991 .76633 m .70716 .80339 L .695 .79997 L p .707 .577 .707 r
F P
0 g
s
.69257 .77332 m .6896 .79127 L .6773 .7798 L p .707 .577 .707 r
F P
0 g
s
.6773 .7798 m .68027 .76185 L .69257 .77332 L p .707 .577 .707 r
F P
0 g
s
.695 .79997 m .68775 .76291 L .69991 .76633 L p .707 .577 .707 r
F P
0 g
s
.31229 .67224 m .31954 .7093 L .34331 .70078 L p .707 .577 .707 r
F P
0 g
s
.34331 .70078 m .33606 .66372 L .31229 .67224 L p .707 .577 .707 r
F P
0 g
s
.30248 .65719 m .31566 .71248 L .3393 .70335 L p .707 .577 .707 r
F P
0 g
s
.3393 .70335 m .32612 .64806 L .30248 .65719 L p .707 .577 .707 r
F P
0 g
s
.37788 .80295 m .38302 .30165 L .36524 .29019 L p .707 .577 .707 r
F P
0 g
s
.38302 .30165 m .37788 .80295 L .4076 .81248 L p .707 .577 .707 r
F P
0 g
s
.19908 .73778 m .18589 .6825 L .16565 .68288 L p .707 .577 .707 r
F P
0 g
s
.2019 .72974 m .19465 .69267 L .17414 .69185 L p .707 .577 .707 r
F P
0 g
s
.65791 .61348 m .67109 .66876 L .64454 .67196 L p .707 .577 .707 r
F P
0 g
s
.33606 .66372 m .34331 .70078 L .35958 .69243 L p .707 .577 .707 r
F P
0 g
s
.32612 .64806 m .3393 .70335 L .35553 .69478 L p .707 .577 .707 r
F P
0 g
s
.35958 .69243 m .35234 .65537 L .33606 .66372 L p .707 .577 .707 r
F P
0 g
s
.35553 .69478 m .34234 .63949 L .32612 .64806 L p .707 .577 .707 r
F P
0 g
s
.16565 .68288 m .17884 .73817 L .19908 .73778 L p .707 .577 .707 r
F P
0 g
s
.17414 .69185 m .18139 .72891 L .2019 .72974 L p .707 .577 .707 r
F P
0 g
s
.68775 .76291 m .695 .79997 L .6745 .79914 L p .707 .577 .707 r
F P
0 g
s
.68027 .76185 m .6773 .7798 L .65661 .76883 L p .707 .577 .707 r
F P
0 g
s
.65661 .76883 m .65958 .75088 L .68027 .76185 L p .707 .577 .707 r
F P
0 g
s
.6745 .79914 m .66725 .76208 L .68775 .76291 L p .707 .577 .707 r
F P
0 g
s
.24143 .85666 m .24439 .8387 L .21363 .8318 L p .707 .577 .707 r
F P
0 g
s
.24439 .8387 m .24143 .85666 L .27289 .8604 L p .707 .577 .707 r
F P
0 g
s
.27289 .8604 m .27586 .84244 L .24439 .8387 L p .707 .577 .707 r
F P
0 g
s
.64765 .80099 m .6404 .76393 L .66725 .76208 L p .707 .577 .707 r
F P
0 g
s
.639 .29774 m .63385 .79905 L .64385 .78717 L p .707 .577 .707 r
F P
0 g
s
.64385 .78717 m .649 .28586 L .639 .29774 L p .707 .577 .707 r
F P
0 g
s
.27586 .84244 m .27289 .8604 L .30198 .8606 L p .707 .577 .707 r
F P
0 g
s
.30198 .8606 m .30495 .84265 L .27586 .84244 L p .707 .577 .707 r
F P
0 g
s
.17884 .73817 m .16565 .68288 L .1537 .68043 L p .707 .577 .707 r
F P
0 g
s
.18139 .72891 m .17414 .69185 L .16199 .68843 L p .707 .577 .707 r
F P
0 g
s
.21066 .84975 m .21363 .8318 L .18657 .8224 L p .707 .577 .707 r
F P
0 g
s
.21363 .8318 m .21066 .84975 L .24143 .85666 L p .707 .577 .707 r
F P
0 g
s
.18657 .8224 m .18361 .84035 L .21066 .84975 L p .707 .577 .707 r
F P
0 g
s
.1537 .68043 m .16689 .73571 L .17884 .73817 L p .707 .577 .707 r
F P
0 g
s
.16199 .68843 m .16924 .72549 L .18139 .72891 L p .707 .577 .707 r
F P
0 g
s
.35234 .65537 m .35958 .69243 L .36676 .68505 L p .707 .577 .707 r
F P
0 g
s
.34234 .63949 m .35553 .69478 L .36275 .68761 L p .707 .577 .707 r
F P
0 g
s
.36676 .68505 m .35952 .64799 L .35234 .65537 L p .707 .577 .707 r
F P
0 g
s
.36275 .68761 m .34957 .63233 L .34234 .63949 L p .707 .577 .707 r
F P
0 g
s
.34957 .63233 m .36275 .68761 L .36027 .68256 L p .707 .577 .707 r
F P
0 g
s
.35952 .64799 m .36676 .68505 L .36415 .67938 L p .707 .577 .707 r
F P
0 g
s
.36415 .67938 m .3569 .64232 L .35952 .64799 L p .707 .577 .707 r
F P
0 g
s
.36027 .68256 m .34709 .62727 L .34957 .63233 L p .707 .577 .707 r
F P
0 g
s
.34709 .62727 m .36027 .68256 L .34833 .6801 L p .707 .577 .707 r
F P
0 g
s
.3569 .64232 m .36415 .67938 L .35199 .67596 L p .707 .577 .707 r
F P
0 g
s
.3601 .7915 m .36524 .29019 L .36115 .27792 L p .707 .577 .707 r
F P
0 g
s
.36524 .29019 m .3601 .7915 L .37788 .80295 L p .707 .577 .707 r
F P
0 g
s
.30495 .84265 m .30198 .8606 L .32585 .85725 L p .707 .577 .707 r
F P
0 g
s
.32585 .85725 m .32882 .8393 L .30495 .84265 L p .707 .577 .707 r
F P
0 g
s
.18361 .84035 m .18657 .8224 L .16589 .81143 L p .707 .577 .707 r
F P
0 g
s
.66725 .76208 m .6745 .79914 L .64765 .80099 L p .707 .577 .707 r
F P
0 g
s
.16589 .81143 m .16292 .82938 L .18361 .84035 L p .707 .577 .707 r
F P
0 g
s
.16924 .72549 m .16199 .68843 L .15937 .68275 L p .707 .577 .707 r
F P
0 g
s
.16689 .73571 m .1537 .68043 L .15122 .67537 L p .707 .577 .707 r
F P
0 g
s
.32882 .8393 m .32585 .85725 L .34216 .85068 L p .707 .577 .707 r
F P
0 g
s
.34216 .85068 m .34512 .83273 L .32882 .8393 L p .707 .577 .707 r
F P
0 g
s
.15937 .68275 m .16662 .71982 L .16924 .72549 L p .707 .577 .707 r
F P
0 g
s
.16292 .82938 m .16589 .81143 L .15358 .79996 L p .707 .577 .707 r
F P
0 g
s
.64385 .78717 m .63977 .7749 L p .64298 .60455 L .707 .577 .707 r
F P
0 g
s
.64298 .60455 m .64514 .49037 L .64463 .60843 L .707 .577 .707 r
F
.64298 .60455 m .64463 .60843 L .64385 .78717 L F
.64491 .27359 m .63977 .7749 L .62199 .76344 L p F P
0 g
s
.63392 .57666 m .63144 .57161 L p .63527 .58636 L .707 .577 .707 r
F P
0 g
s
.64717 .46348 m .64385 .78717 L p .64514 .49037 L .707 .577 .707 r
F P
0 g
s
.64491 .27359 m .649 .28586 L p .64514 .49037 L .707 .577 .707 r
F P
0 g
s
.63977 .7749 m .6423 .52778 L p .64514 .49037 L .707 .577 .707 r
F P
0 g
s
.6423 .52778 m .64491 .27359 L p .64514 .49037 L .707 .577 .707 r
F P
0 g
s
.6471 .63195 m .65905 .63441 L p .6379 .58582 L .707 .577 .707 r
F P
0 g
s
.63392 .57666 m .63747 .59155 L p .6379 .58582 L .707 .577 .707 r
F P
0 g
s
.63747 .59155 m .6471 .63195 L p .6379 .58582 L .707 .577 .707 r
F P
0 g
s
.6471 .63195 m .63747 .59155 L p .63527 .58636 L .707 .577 .707 r
F P
0 g
s
.63747 .59155 m .63392 .57666 L p .63527 .58636 L .707 .577 .707 r
F P
0 g
s
.65905 .63441 m .64586 .57912 L .63852 .57761 L p .707 .577 .707 r
F P
0 g
s
.63852 .57761 m .63392 .57666 L p .6379 .58582 L .707 .577 .707 r
F P
0 g
s
.65905 .63441 m .63852 .57761 L .6379 .58582 L .707 .577 .707 r
F
.649 .28586 m .64717 .46348 L p .64514 .49037 L F P
0 g
s
.15122 .67537 m .16441 .73066 L .16689 .73571 L p .707 .577 .707 r
F P
0 g
s
.15358 .79996 m .15062 .81791 L .16292 .82938 L p .707 .577 .707 r
F P
0 g
s
.36115 .27792 m .35601 .77923 L .3601 .7915 L p .707 .577 .707 r
F P
0 g
s
.35601 .77923 m .36115 .27792 L .37115 .26604 L p .707 .577 .707 r
F P
0 g
s
.34512 .83273 m .34216 .85068 L .3493 .84152 L p .707 .577 .707 r
F P
0 g
s
.3493 .84152 m .35227 .82357 L .34512 .83273 L p .707 .577 .707 r
F P
0 g
s
.16662 .71982 m .15937 .68275 L .16655 .67538 L p .707 .577 .707 r
F P
0 g
s
.16441 .73066 m .15122 .67537 L .15845 .66821 L p .707 .577 .707 r
F P
0 g
s
.15062 .81791 m .15358 .79996 L .15088 .78911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16655 .67538 m .1738 .71244 L .16662 .71982 L p .707 .577 .707 r
F P
0 g
s
.34833 .6801 m .33514 .62482 L .34709 .62727 L p .707 .577 .707 r
F P
0 g
s
.35199 .67596 m .34474 .6389 L .3569 .64232 L p .707 .577 .707 r
F P
0 g
s
.15088 .78911 m .14791 .80707 L .15062 .81791 L p .707 .577 .707 r
F P
0 g
s
.15845 .66821 m .17163 .72349 L .16441 .73066 L p .707 .577 .707 r
F P
0 g
s
.62199 .76344 m .62713 .26213 L .64491 .27359 L p .707 .577 .707 r
F P
0 g
s
.35227 .82357 m .3493 .84152 L .34659 .83068 L p .707 .577 .707 r
F P
0 g
s
.34659 .83068 m .34956 .81273 L .35227 .82357 L p .707 .577 .707 r
F P
0 g
s
.1738 .71244 m .16655 .67538 L .18282 .66702 L p .707 .577 .707 r
F P
0 g
s
.17163 .72349 m .15845 .66821 L .17467 .65964 L p .707 .577 .707 r
F P
0 g
s
.14791 .80707 m .15088 .78911 L .15802 .77996 L p .707 .577 .707 r
F P
0 g
s
.18282 .66702 m .19007 .70408 L .1738 .71244 L p .707 .577 .707 r
F P
0 g
s
.36601 .76735 m .37115 .26604 L .39426 .25571 L p .707 .577 .707 r
F P
0 g
s
.37115 .26604 m .36601 .76735 L .35601 .77923 L p .707 .577 .707 r
F P
0 g
s
.33514 .62482 m .34833 .6801 L .32808 .68049 L p .707 .577 .707 r
F P
0 g
s
.34474 .6389 m .35199 .67596 L .33149 .67513 L p .707 .577 .707 r
F P
0 g
s
.32808 .68049 m .3149 .6252 L .33514 .62482 L p .707 .577 .707 r
F P
0 g
s
.33149 .67513 m .32424 .63807 L .34474 .6389 L p .707 .577 .707 r
F P
0 g
s
.15802 .77996 m .15506 .79791 L .14791 .80707 L p .707 .577 .707 r
F P
0 g
s
.17467 .65964 m .18786 .71493 L .17163 .72349 L p .707 .577 .707 r
F P
0 g
s
.19007 .70408 m .18282 .66702 L .2066 .65851 L p .707 .577 .707 r
F P
0 g
s
.18786 .71493 m .17467 .65964 L .19831 .6505 L p .707 .577 .707 r
F P
0 g
s
.34956 .81273 m .34659 .83068 L .33429 .81921 L p .707 .577 .707 r
F P
0 g
s
.33429 .81921 m .33726 .80126 L .34956 .81273 L p .707 .577 .707 r
F P
0 g
s
.62713 .26213 m .62199 .76344 L .59227 .75392 L p .707 .577 .707 r
F P
0 g
s
.59227 .75392 m .59741 .25261 L .62713 .26213 L p .707 .577 .707 r
F P
0 g
s
.15506 .79791 m .15802 .77996 L .17433 .77338 L p .707 .577 .707 r
F P
0 g
s
.3149 .6252 m .32808 .68049 L .30353 .68344 L p .707 .577 .707 r
F P
0 g
s
.30353 .68344 m .30153 .68368 L p .30258 .67908 L .707 .577 .707 r
F P
0 g
s
.30258 .67908 m .3149 .6252 L .30353 .68344 L .707 .577 .707 r
F
.3022 .67733 m .27408 .68132 L p .29496 .64423 L F P
0 g
s
.27408 .68132 m .26683 .64426 L .29412 .64038 L p .707 .577 .707 r
F P
0 g
s
.27408 .68132 m .29412 .64038 L .29496 .64423 L .707 .577 .707 r
F
.30153 .68368 m .28834 .62839 L .29142 .62802 L p F P
0 g
s
.29142 .62802 m .3149 .6252 L p .30258 .67908 L .707 .577 .707 r
F P
0 g
s
.30153 .68368 m .29142 .62802 L .30258 .67908 L .707 .577 .707 r
F
.29412 .64038 m .29739 .63992 L p .29496 .64423 L F P
0 g
s
.29739 .63992 m .30464 .67698 L .3022 .67733 L p .707 .577 .707 r
F P
0 g
s
.29496 .64423 m .29739 .63992 L .3022 .67733 L .707 .577 .707 r
F
.32424 .63807 m .33149 .67513 L .30464 .67698 L p F P
0 g
s
.30464 .67698 m .29739 .63992 L .32424 .63807 L p .707 .577 .707 r
F P
0 g
s
.2066 .65851 m .21385 .69557 L .19007 .70408 L p .707 .577 .707 r
F P
0 g
s
.19831 .6505 m .2115 .70579 L .18786 .71493 L p .707 .577 .707 r
F P
0 g
s
.17433 .77338 m .17136 .79133 L .15506 .79791 L p .707 .577 .707 r
F P
0 g
s
.73612 .62514 m .72293 .56986 L .69266 .57554 L p .707 .577 .707 r
F P
0 g
s
.72293 .56986 m .73612 .62514 L .76714 .61753 L p .707 .577 .707 r
F P
0 g
s
.76714 .61753 m .75395 .56224 L .72293 .56986 L p .707 .577 .707 r
F P
0 g
s
.39426 .25571 m .38912 .75702 L .36601 .76735 L p .707 .577 .707 r
F P
0 g
s
.38912 .75702 m .39426 .25571 L .42822 .24794 L p .707 .577 .707 r
F P
0 g
s
.75395 .56224 m .76714 .61753 L .79588 .60872 L p .707 .577 .707 r
F P
0 g
s
.79588 .60872 m .78269 .55343 L .75395 .56224 L p .707 .577 .707 r
F P
0 g
s
.21385 .69557 m .2066 .65851 L .23554 .65066 L p .707 .577 .707 r
F P
0 g
s
.23554 .65066 m .24279 .68772 L .21385 .69557 L p .707 .577 .707 r
F P
0 g
s
.2115 .70579 m .19831 .6505 L .22705 .6417 L p .707 .577 .707 r
F P
0 g
s
.26683 .64426 m .27408 .68132 L .24279 .68772 L p .707 .577 .707 r
F P
0 g
s
.28834 .62839 m .30153 .68368 L .27126 .68936 L p .707 .577 .707 r
F P
0 g
s
.24279 .68772 m .23554 .65066 L .26683 .64426 L p .707 .577 .707 r
F P
0 g
s
.27126 .68936 m .25807 .63408 L .28834 .62839 L p .707 .577 .707 r
F P
0 g
s
.70585 .63083 m .69266 .57554 L .66611 .57873 L p .707 .577 .707 r
F P
0 g
s
.69266 .57554 m .70585 .63083 L .73612 .62514 L p .707 .577 .707 r
F P
0 g
s
.78269 .55343 m .79588 .60872 L .81952 .59958 L p .707 .577 .707 r
F P
0 g
s
.81952 .59958 m .80633 .5443 L .78269 .55343 L p .707 .577 .707 r
F P
0 g
s
.33726 .80126 m .33429 .81921 L .3136 .80824 L p .707 .577 .707 r
F P
0 g
s
.3136 .80824 m .31657 .79029 L .33726 .80126 L p .707 .577 .707 r
F P
0 g
s
.22705 .6417 m .24023 .69698 L .2115 .70579 L p .707 .577 .707 r
F P
0 g
s
.24023 .69698 m .22705 .6417 L .25807 .63408 L p .707 .577 .707 r
F P
0 g
s
.25807 .63408 m .27126 .68936 L .24023 .69698 L p .707 .577 .707 r
F P
0 g
s
.17136 .79133 m .17433 .77338 L .19819 .77003 L p .707 .577 .707 r
F P
0 g
s
.66611 .57873 m .67929 .63402 L .70585 .63083 L p .707 .577 .707 r
F P
0 g
s
.59741 .25261 m .59227 .75392 L .55351 .74726 L p .707 .577 .707 r
F P
0 g
s
.55351 .74726 m .55865 .24595 L .59741 .25261 L p .707 .577 .707 r
F P
0 g
s
.19819 .77003 m .19523 .78799 L .17136 .79133 L p .707 .577 .707 r
F P
0 g
s
.67929 .63402 m .66611 .57873 L .64586 .57912 L p .707 .577 .707 r
F P
0 g
s
.42308 .74925 m .42822 .24794 L .4697 .2435 L p .707 .577 .707 r
F P
0 g
s
.42822 .24794 m .42308 .74925 L .38912 .75702 L p .707 .577 .707 r
F P
0 g
s
.80633 .5443 m .81952 .59958 L .83574 .59101 L p .707 .577 .707 r
F P
0 g
s
.83574 .59101 m .82256 .53573 L .80633 .5443 L p .707 .577 .707 r
F P
0 g
s
.31657 .79029 m .3136 .80824 L .28655 .79884 L p .707 .577 .707 r
F P
0 g
s
.28655 .79884 m .28952 .78089 L .31657 .79029 L p .707 .577 .707 r
F P
0 g
s
.64586 .57912 m .65905 .63441 L .67929 .63402 L p .707 .577 .707 r
F P
0 g
s
.19523 .78799 m .19819 .77003 L .22728 .77024 L p .707 .577 .707 r
F P
0 g
s
.73952 .75552 m .73227 .71846 L .70171 .7228 L p .707 .577 .707 r
F P
0 g
s
.73227 .71846 m .73952 .75552 L .77081 .74912 L p .707 .577 .707 r
F P
0 g
s
.77081 .74912 m .76356 .71206 L .73227 .71846 L p .707 .577 .707 r
F P
0 g
s
.72164 .72521 m .7246 .70726 L .69384 .70035 L p .707 .577 .707 r
F P
0 g
s
.7246 .70726 m .72164 .72521 L .75311 .72895 L p .707 .577 .707 r
F P
0 g
s
.75311 .72895 m .75607 .711 L .7246 .70726 L p .707 .577 .707 r
F P
0 g
s
.76356 .71206 m .77081 .74912 L .79975 .74127 L p .707 .577 .707 r
F P
0 g
s
.79975 .74127 m .7925 .70421 L .76356 .71206 L p .707 .577 .707 r
F P
0 g
s
.55865 .24595 m .55351 .74726 L .5095 .74412 L p .707 .577 .707 r
F P
0 g
s
.5095 .74412 m .51464 .24281 L .55865 .24595 L p .707 .577 .707 r
F P
0 g
s
.75607 .711 m .75311 .72895 L .7822 .72916 L p .707 .577 .707 r
F P
0 g
s
.7822 .72916 m .78516 .7112 L .75607 .711 L p .707 .577 .707 r
F P
0 g
s
.22728 .77024 m .22432 .78819 L .19523 .78799 L p .707 .577 .707 r
F P
0 g
s
.69087 .7183 m .69384 .70035 L .66679 .69095 L p .707 .577 .707 r
F P
0 g
s
.69384 .70035 m .69087 .7183 L .72164 .72521 L p .707 .577 .707 r
F P
0 g
s
.70171 .7228 m .70896 .75986 L .73952 .75552 L p .707 .577 .707 r
F P
0 g
s
.70896 .75986 m .70171 .7228 L .67486 .72465 L p .707 .577 .707 r
F P
0 g
s
.46456 .74481 m .4697 .2435 L .51464 .24281 L p .707 .577 .707 r
F P
0 g
s
.4697 .2435 m .46456 .74481 L .42308 .74925 L p .707 .577 .707 r
F P
0 g
s
.28952 .78089 m .28655 .79884 L .25579 .79193 L p .707 .577 .707 r
F P
0 g
s
.25579 .79193 m .25875 .77398 L .28952 .78089 L p .707 .577 .707 r
F P
0 g
s
.66679 .69095 m .66382 .7089 L .69087 .7183 L p .707 .577 .707 r
F P
0 g
s
.22432 .78819 m .22728 .77024 L .25875 .77398 L p .707 .577 .707 r
F P
0 g
s
.7925 .70421 m .79975 .74127 L .82353 .73276 L p .707 .577 .707 r
F P
0 g
s
.82353 .73276 m .81628 .69569 L .7925 .70421 L p .707 .577 .707 r
F P
0 g
s
.51464 .24281 m .5095 .74412 L .46456 .74481 L p .707 .577 .707 r
F P
0 g
s
.67486 .72465 m .68211 .76171 L .70896 .75986 L p .707 .577 .707 r
F P
0 g
s
.25875 .77398 m .25579 .79193 L .22432 .78819 L p .707 .577 .707 r
F P
0 g
s
.78516 .7112 m .7822 .72916 L .80606 .72581 L p .707 .577 .707 r
F P
0 g
s
.80606 .72581 m .80903 .70786 L .78516 .7112 L p .707 .577 .707 r
F P
0 g
s
.66382 .7089 m .66679 .69095 L .6461 .67998 L p .707 .577 .707 r
F P
0 g
s
.82256 .53573 m .83574 .59101 L .84297 .58385 L p .707 .577 .707 r
F P
0 g
s
.84297 .58385 m .82978 .52856 L .82256 .53573 L p .707 .577 .707 r
F P
0 g
s
.68211 .76171 m .67486 .72465 L .65436 .72382 L p .707 .577 .707 r
F P
0 g
s
.6461 .67998 m .64313 .69793 L .66382 .7089 L p .707 .577 .707 r
F P
0 g
s
.81628 .69569 m .82353 .73276 L .8398 .7244 L p .707 .577 .707 r
F P
0 g
s
.8398 .7244 m .83255 .68734 L .81628 .69569 L p .707 .577 .707 r
F P
0 g
s
.65436 .72382 m .66161 .76088 L .68211 .76171 L p .707 .577 .707 r
F P
0 g
s
.80903 .70786 m .80606 .72581 L .82237 .71923 L p .707 .577 .707 r
F P
0 g
s
.82237 .71923 m .82533 .70128 L .80903 .70786 L p .707 .577 .707 r
F P
0 g
s
.64313 .69793 m .6461 .67998 L .6338 .66851 L p .707 .577 .707 r
F P
0 g
s
.6338 .66851 m .63083 .68646 L .64313 .69793 L p .707 .577 .707 r
F P
0 g
s
.66161 .76088 m .65436 .72382 L .6422 .7204 L p .707 .577 .707 r
F P
0 g
s
.82978 .52856 m .84297 .58385 L .84049 .57879 L p .707 .577 .707 r
F P
0 g
s
.84049 .57879 m .8273 .52351 L .82978 .52856 L p .707 .577 .707 r
F P
0 g
s
.63144 .57161 m .64462 .62689 L .6471 .63195 L p .707 .577 .707 r
F P
0 g
s
.6422 .7204 m .64945 .75746 L .66161 .76088 L p .707 .577 .707 r
F P
0 g
s
.83255 .68734 m .8398 .7244 L .84698 .71702 L p .707 .577 .707 r
F P
0 g
s
.84698 .71702 m .83973 .67996 L .83255 .68734 L p .707 .577 .707 r
F P
0 g
s
.82533 .70128 m .82237 .71923 L .82952 .71008 L p .707 .577 .707 r
F P
0 g
s
.82952 .71008 m .83248 .69212 L .82533 .70128 L p .707 .577 .707 r
F P
0 g
s
.63083 .68646 m .6338 .66851 L .63109 .65767 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64462 .62689 m .63144 .57161 L .63866 .56444 L p .707 .577 .707 r
F P
0 g
s
.63109 .65767 m .62812 .67562 L .63083 .68646 L p .707 .577 .707 r
F P
0 g
s
.64945 .75746 m .6422 .7204 L .63959 .71473 L p .707 .577 .707 r
F P
0 g
s
.8273 .52351 m .84049 .57879 L .82854 .57634 L p .707 .577 .707 r
F P
0 g
s
.82854 .57634 m .81535 .52105 L .8273 .52351 L p .707 .577 .707 r
F P
0 g
s
.63866 .56444 m .65185 .61973 L .64462 .62689 L p .707 .577 .707 r
F P
0 g
s
.63959 .71473 m .64683 .75179 L .64945 .75746 L p .707 .577 .707 r
F P
0 g
s
.83973 .67996 m .84698 .71702 L .84436 .71135 L p .707 .577 .707 r
F P
0 g
s
.84436 .71135 m .83711 .67429 L .83973 .67996 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83248 .69212 m .82952 .71008 L .82681 .69923 L p .707 .577 .707 r
F P
0 g
s
.82681 .69923 m .82977 .68128 L .83248 .69212 L p .707 .577 .707 r
F P
0 g
s
.62812 .67562 m .63109 .65767 L .63824 .64851 L p .707 .577 .707 r
F P
0 g
s
.65185 .61973 m .63866 .56444 L .65489 .55587 L p .707 .577 .707 r
F P
0 g
s
.63824 .64851 m .63527 .66646 L .62812 .67562 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39651 .63151 m .38926 .59445 L .3587 .59879 L p .707 .577 .707 r
F P
0 g
s
.38926 .59445 m .39651 .63151 L .4278 .62511 L p .707 .577 .707 r
F P
0 g
s
.4278 .62511 m .42055 .58805 L .38926 .59445 L p .707 .577 .707 r
F P
0 g
s
.3587 .59879 m .36595 .63585 L .39651 .63151 L p .707 .577 .707 r
F P
0 g
s
.39311 .63687 m .37992 .58158 L .34965 .58727 L p .707 .577 .707 r
F P
0 g
s
.37992 .58158 m .39311 .63687 L .42413 .62925 L p .707 .577 .707 r
F P
0 g
s
.42413 .62925 m .41094 .57396 L .37992 .58158 L p .707 .577 .707 r
F P
0 g
s
.42055 .58805 m .4278 .62511 L .45674 .61726 L p .707 .577 .707 r
F P
0 g
s
.45674 .61726 m .44949 .5802 L .42055 .58805 L p .707 .577 .707 r
F P
0 g
s
.41094 .57396 m .42413 .62925 L .45287 .62044 L p .707 .577 .707 r
F P
0 g
s
.45287 .62044 m .43968 .56516 L .41094 .57396 L p .707 .577 .707 r
F P
0 g
s
.64683 .75179 m .63959 .71473 L .64677 .70735 L p .707 .577 .707 r
F P
0 g
s
.81535 .52105 m .82854 .57634 L .8083 .57673 L p .707 .577 .707 r
F P
0 g
s
.8083 .57673 m .79511 .52144 L .81535 .52105 L p .707 .577 .707 r
F P
0 g
s
.65489 .55587 m .66807 .61116 L .65185 .61973 L p .707 .577 .707 r
F P
0 g
s
.36284 .64255 m .34965 .58727 L .3231 .59046 L p .707 .577 .707 r
F P
0 g
s
.34965 .58727 m .36284 .64255 L .36512 .64212 L p .707 .577 .707 r
F P
0 g
s
.36595 .63585 m .3587 .59879 L .35583 .59899 L p .707 .577 .707 r
F P
0 g
s
.36595 .63585 m .35583 .59899 L .36315 .63296 L .707 .577 .707 r
F
.3545 .59279 m .34965 .58727 L .36512 .64212 L F
.3231 .59046 m .33628 .64574 L .36284 .64255 L p F P
0 g
s
.33185 .60063 m .3391 .6377 L .36595 .63585 L p .707 .577 .707 r
F P
0 g
s
.36512 .64212 m .39311 .63687 L p .3545 .59279 L .707 .577 .707 r
F P
0 g
s
.35583 .59899 m .33185 .60063 L p .36315 .63296 L .707 .577 .707 r
F P
0 g
s
.64677 .70735 m .65401 .74441 L .64683 .75179 L p .707 .577 .707 r
F P
0 g
s
.83711 .67429 m .84436 .71135 L .83221 .70793 L p .707 .577 .707 r
F P
0 g
s
.82977 .68128 m .82681 .69923 L .81451 .68776 L p .707 .577 .707 r
F P
0 g
s
.81451 .68776 m .81747 .66981 L .82977 .68128 L p .707 .577 .707 r
F P
0 g
s
.83221 .70793 m .82496 .67087 L .83711 .67429 L p .707 .577 .707 r
F P
0 g
s
.44949 .5802 m .45674 .61726 L .48052 .60875 L p .707 .577 .707 r
F P
0 g
s
.48052 .60875 m .47327 .57168 L .44949 .5802 L p .707 .577 .707 r
F P
0 g
s
.43968 .56516 m .45287 .62044 L .47651 .61131 L p .707 .577 .707 r
F P
0 g
s
.47651 .61131 m .46332 .55602 L .43968 .56516 L p .707 .577 .707 r
F P
0 g
s
.63527 .66646 m .63824 .64851 L .65454 .64194 L p .707 .577 .707 r
F P
0 g
s
.66807 .61116 m .65489 .55587 L .67853 .54674 L p .707 .577 .707 r
F P
0 g
s
.33628 .64574 m .3231 .59046 L .30285 .59084 L p .707 .577 .707 r
F P
0 g
s
.3391 .6377 m .33185 .60063 L .31135 .59981 L p .707 .577 .707 r
F P
0 g
s
.65454 .64194 m .65158 .65989 L .63527 .66646 L p .707 .577 .707 r
F P
0 g
s
.79511 .52144 m .8083 .57673 L .78174 .57992 L p .707 .577 .707 r
F P
0 g
s
.78174 .57992 m .76856 .52463 L .79511 .52144 L p .707 .577 .707 r
F P
0 g
s
.47327 .57168 m .48052 .60875 L .49679 .60039 L p .707 .577 .707 r
F P
0 g
s
.46332 .55602 m .47651 .61131 L .49273 .60274 L p .707 .577 .707 r
F P
0 g
s
.49679 .60039 m .48954 .56333 L .47327 .57168 L p .707 .577 .707 r
F P
0 g
s
.49273 .60274 m .47955 .54745 L .46332 .55602 L p .707 .577 .707 r
F P
0 g
s
.67853 .54674 m .69171 .60203 L .66807 .61116 L p .707 .577 .707 r
F P
0 g
s
.30285 .59084 m .31604 .64613 L .33628 .64574 L p .707 .577 .707 r
F P
0 g
s
.31135 .59981 m .3186 .63687 L .3391 .6377 L p .707 .577 .707 r
F P
0 g
s
.65401 .74441 m .64677 .70735 L .66304 .69899 L p .707 .577 .707 r
F P
0 g
s
.66304 .69899 m .67029 .73606 L .65401 .74441 L p .707 .577 .707 r
F P
0 g
s
.82496 .67087 m .83221 .70793 L .8117 .70711 L p .707 .577 .707 r
F P
0 g
s
.81747 .66981 m .81451 .68776 L .79382 .67679 L p .707 .577 .707 r
F P
0 g
s
.79382 .67679 m .79678 .65884 L .81747 .66981 L p .707 .577 .707 r
F P
0 g
s
.8117 .70711 m .80445 .67004 L .82496 .67087 L p .707 .577 .707 r
F P
0 g
s
.69171 .60203 m .67853 .54674 L .70726 .53793 L p .707 .577 .707 r
F P
0 g
s
.37863 .76462 m .38159 .74667 L .35083 .73976 L p .707 .577 .707 r
F P
0 g
s
.38159 .74667 m .37863 .76462 L .4101 .76836 L p .707 .577 .707 r
F P
0 g
s
.4101 .76836 m .41306 .75041 L .38159 .74667 L p .707 .577 .707 r
F P
0 g
s
.76856 .52463 m .78174 .57992 L .75147 .5856 L p .707 .577 .707 r
F P
0 g
s
.75147 .5856 m .73828 .53031 L .76856 .52463 L p .707 .577 .707 r
F P
0 g
s
.65158 .65989 m .65454 .64194 L .67841 .63859 L p .707 .577 .707 r
F P
0 g
s
.41306 .75041 m .4101 .76836 L .43919 .76856 L p .707 .577 .707 r
F P
0 g
s
.43919 .76856 m .44215 .75061 L .41306 .75041 L p .707 .577 .707 r
F P
0 g
s
.31604 .64613 m .30285 .59084 L .29091 .58839 L p .707 .577 .707 r
F P
0 g
s
.3186 .63687 m .31135 .59981 L .29919 .59639 L p .707 .577 .707 r
F P
0 g
s
.34786 .75771 m .35083 .73976 L .32378 .73036 L p .707 .577 .707 r
F P
0 g
s
.35083 .73976 m .34786 .75771 L .37863 .76462 L p .707 .577 .707 r
F P
0 g
s
.70726 .53793 m .72045 .59322 L .69171 .60203 L p .707 .577 .707 r
F P
0 g
s
.67841 .63859 m .67544 .65654 L .65158 .65989 L p .707 .577 .707 r
F P
0 g
s
.72045 .59322 m .70726 .53793 L .73828 .53031 L p .707 .577 .707 r
F P
0 g
s
.73828 .53031 m .75147 .5856 L .72045 .59322 L p .707 .577 .707 r
F P
0 g
s
.32378 .73036 m .32081 .74831 L .34786 .75771 L p .707 .577 .707 r
F P
0 g
s
.29091 .58839 m .30409 .64368 L .31604 .64613 L p .707 .577 .707 r
F P
0 g
s
.29919 .59639 m .30644 .63345 L .3186 .63687 L p .707 .577 .707 r
F P
0 g
s
.48954 .56333 m .49679 .60039 L .50397 .59301 L p .707 .577 .707 r
F P
0 g
s
.47955 .54745 m .49273 .60274 L .49996 .59558 L p .707 .577 .707 r
F P
0 g
s
.50397 .59301 m .49672 .55595 L .48954 .56333 L p .707 .577 .707 r
F P
0 g
s
.49996 .59558 m .48677 .54029 L .47955 .54745 L p .707 .577 .707 r
F P
0 g
s
.67029 .73606 m .66304 .69899 L .68681 .69048 L p .707 .577 .707 r
F P
0 g
s
.44215 .75061 m .43919 .76856 L .46305 .76522 L p .707 .577 .707 r
F P
0 g
s
.46305 .76522 m .46602 .74726 L .44215 .75061 L p .707 .577 .707 r
F P
0 g
s
.32081 .74831 m .32378 .73036 L .30309 .71939 L p .707 .577 .707 r
F P
0 g
s
.80445 .67004 m .8117 .70711 L .78485 .70895 L p .707 .577 .707 r
F P
0 g
s
.79678 .65884 m .79382 .67679 L .76677 .66739 L p .707 .577 .707 r
F P
0 g
s
.78485 .70895 m .7776 .67189 L .80445 .67004 L p .707 .577 .707 r
F P
0 g
s
.76677 .66739 m .76973 .64944 L .79678 .65884 L p .707 .577 .707 r
F P
0 g
s
.68681 .69048 m .69406 .72754 L .67029 .73606 L p .707 .577 .707 r
F P
0 g
s
.67544 .65654 m .67841 .63859 L .7075 .63879 L p .707 .577 .707 r
F P
0 g
s
.30309 .71939 m .30012 .73734 L .32081 .74831 L p .707 .577 .707 r
F P
0 g
s
.7075 .63879 m .70453 .65675 L .67544 .65654 L p .707 .577 .707 r
F P
0 g
s
.69406 .72754 m .68681 .69048 L .71576 .68263 L p .707 .577 .707 r
F P
0 g
s
.30644 .63345 m .29919 .59639 L .29658 .59072 L p .707 .577 .707 r
F P
0 g
s
.76973 .64944 m .76677 .66739 L .736 .66049 L p .707 .577 .707 r
F P
0 g
s
.736 .66049 m .73897 .64253 L .76973 .64944 L p .707 .577 .707 r
F P
0 g
s
.30409 .64368 m .29091 .58839 L .28842 .58333 L p .707 .577 .707 r
F P
0 g
s
.70453 .65675 m .7075 .63879 L .73897 .64253 L p .707 .577 .707 r
F P
0 g
s
.7776 .67189 m .78485 .70895 L .75429 .71329 L p .707 .577 .707 r
F P
0 g
s
.75429 .71329 m .74704 .67623 L .7776 .67189 L p .707 .577 .707 r
F P
0 g
s
.46602 .74726 m .46305 .76522 L .47936 .75864 L p .707 .577 .707 r
F P
0 g
s
.47936 .75864 m .48232 .74069 L .46602 .74726 L p .707 .577 .707 r
F P
0 g
s
.73897 .64253 m .736 .66049 L .70453 .65675 L p .707 .577 .707 r
F P
0 g
s
.71576 .68263 m .72301 .71969 L .69406 .72754 L p .707 .577 .707 r
F P
0 g
s
.29658 .59072 m .30382 .62778 L .30644 .63345 L p .707 .577 .707 r
F P
0 g
s
.30012 .73734 m .30309 .71939 L .29079 .70792 L p .707 .577 .707 r
F P
0 g
s
.48677 .54029 m .49996 .59558 L .49748 .59052 L p .707 .577 .707 r
F P
0 g
s
.49748 .59052 m .48429 .53523 L .48677 .54029 L p .707 .577 .707 r
F P
0 g
s
.49672 .55595 m .50397 .59301 L .50135 .58734 L p .707 .577 .707 r
F P
0 g
s
.50135 .58734 m .4941 .55028 L .49672 .55595 L p .707 .577 .707 r
F P
0 g
s
.72301 .71969 m .71576 .68263 L .74704 .67623 L p .707 .577 .707 r
F P
0 g
s
.28842 .58333 m .30161 .63862 L .30409 .64368 L p .707 .577 .707 r
F P
0 g
s
.74704 .67623 m .75429 .71329 L .72301 .71969 L p .707 .577 .707 r
F P
0 g
s
.29079 .70792 m .28782 .72587 L .30012 .73734 L p .707 .577 .707 r
F P
0 g
s
.48232 .74069 m .47936 .75864 L .48651 .74948 L p .707 .577 .707 r
F P
0 g
s
.48651 .74948 m .48947 .73153 L .48232 .74069 L p .707 .577 .707 r
F P
0 g
s
.30382 .62778 m .29658 .59072 L .30376 .58334 L p .707 .577 .707 r
F P
0 g
s
.30161 .63862 m .28842 .58333 L .29565 .57617 L p .707 .577 .707 r
F P
0 g
s
.28782 .72587 m .29079 .70792 L .28808 .69708 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30376 .58334 m .311 .6204 L .30382 .62778 L p .707 .577 .707 r
F P
0 g
s
.48429 .53523 m .49748 .59052 L .48553 .58806 L p .707 .577 .707 r
F P
0 g
s
.48553 .58806 m .47234 .53278 L .48429 .53523 L p .707 .577 .707 r
F P
0 g
s
.4941 .55028 m .50135 .58734 L .4892 .58392 L p .707 .577 .707 r
F P
0 g
s
.4892 .58392 m .48195 .54686 L .4941 .55028 L p .707 .577 .707 r
F P
0 g
s
.28808 .69708 m .28511 .71503 L .28782 .72587 L p .707 .577 .707 r
F P
0 g
s
.29565 .57617 m .30884 .63146 L .30161 .63862 L p .707 .577 .707 r
F P
0 g
s
.48947 .73153 m .48651 .74948 L .4838 .73864 L p .707 .577 .707 r
F P
0 g
s
.4838 .73864 m .48676 .72069 L .48947 .73153 L p .707 .577 .707 r
F P
0 g
s
.311 .6204 m .30376 .58334 L .32003 .57498 L p .707 .577 .707 r
F P
0 g
s
.30884 .63146 m .29565 .57617 L .31188 .5676 L p .707 .577 .707 r
F P
0 g
s
.28511 .71503 m .28808 .69708 L .29523 .68792 L p .707 .577 .707 r
F P
0 g
s
.32003 .57498 m .32728 .61205 L .311 .6204 L p .707 .577 .707 r
F P
0 g
s
.47234 .53278 m .48553 .58806 L .46529 .58845 L p .707 .577 .707 r
F P
0 g
s
.48195 .54686 m .4892 .58392 L .46869 .58309 L p .707 .577 .707 r
F P
0 g
s
.46529 .58845 m .4521 .53316 L .47234 .53278 L p .707 .577 .707 r
F P
0 g
s
.46869 .58309 m .46144 .54603 L .48195 .54686 L p .707 .577 .707 r
F P
0 g
s
.29523 .68792 m .29226 .70587 L .28511 .71503 L p .707 .577 .707 r
F P
0 g
s
.31188 .5676 m .32506 .62289 L .30884 .63146 L p .707 .577 .707 r
F P
0 g
s
.32728 .61205 m .32003 .57498 L .3438 .56647 L p .707 .577 .707 r
F P
0 g
s
.32506 .62289 m .31188 .5676 L .33552 .55846 L p .707 .577 .707 r
F P
0 g
s
.48676 .72069 m .4838 .73864 L .4715 .72717 L p .707 .577 .707 r
F P
0 g
s
.4715 .72717 m .47446 .70922 L .48676 .72069 L p .707 .577 .707 r
F P
0 g
s
.29226 .70587 m .29523 .68792 L .31153 .68134 L p .707 .577 .707 r
F P
0 g
s
.4521 .53316 m .46529 .58845 L .44074 .5914 L p .707 .577 .707 r
F P
0 g
s
.44074 .5914 m .43873 .59164 L p .43978 .58704 L .707 .577 .707 r
F P
0 g
s
.43978 .58704 m .4521 .53316 L .44074 .5914 L .707 .577 .707 r
F
.4394 .58529 m .41128 .58928 L p .43217 .55219 L F P
0 g
s
.41128 .58928 m .40403 .55222 L .43133 .54834 L p .707 .577 .707 r
F P
0 g
s
.41128 .58928 m .43133 .54834 L .43217 .55219 L .707 .577 .707 r
F
.43873 .59164 m .42554 .53635 L .42862 .53598 L p F P
0 g
s
.42862 .53598 m .4521 .53316 L p .43978 .58704 L .707 .577 .707 r
F P
0 g
s
.43873 .59164 m .42862 .53598 L .43978 .58704 L .707 .577 .707 r
F
.43133 .54834 m .43459 .54788 L p .43217 .55219 L F P
0 g
s
.43459 .54788 m .44184 .58494 L .4394 .58529 L p .707 .577 .707 r
F P
0 g
s
.43217 .55219 m .43459 .54788 L .4394 .58529 L .707 .577 .707 r
F
.46144 .54603 m .46869 .58309 L .44184 .58494 L p F P
0 g
s
.44184 .58494 m .43459 .54788 L .46144 .54603 L p .707 .577 .707 r
F P
0 g
s
.3438 .56647 m .35105 .60353 L .32728 .61205 L p .707 .577 .707 r
F P
0 g
s
.33552 .55846 m .3487 .61375 L .32506 .62289 L p .707 .577 .707 r
F P
0 g
s
.31153 .68134 m .30857 .6993 L .29226 .70587 L p .707 .577 .707 r
F P
0 g
s
.35105 .60353 m .3438 .56647 L .37275 .55862 L p .707 .577 .707 r
F P
0 g
s
.37275 .55862 m .37999 .59568 L .35105 .60353 L p .707 .577 .707 r
F P
0 g
s
.3487 .61375 m .33552 .55846 L .36425 .54966 L p .707 .577 .707 r
F P
0 g
s
.40403 .55222 m .41128 .58928 L .37999 .59568 L p .707 .577 .707 r
F P
0 g
s
.42554 .53635 m .43873 .59164 L .40846 .59733 L p .707 .577 .707 r
F P
0 g
s
.37999 .59568 m .37275 .55862 L .40403 .55222 L p .707 .577 .707 r
F P
0 g
s
.40846 .59733 m .39527 .54204 L .42554 .53635 L p .707 .577 .707 r
F P
0 g
s
.47446 .70922 m .4715 .72717 L .45081 .7162 L p .707 .577 .707 r
F P
0 g
s
.45081 .7162 m .45377 .69825 L .47446 .70922 L p .707 .577 .707 r
F P
0 g
s
.36425 .54966 m .37744 .60494 L .3487 .61375 L p .707 .577 .707 r
F P
0 g
s
.37744 .60494 m .36425 .54966 L .39527 .54204 L p .707 .577 .707 r
F P
0 g
s
.39527 .54204 m .40846 .59733 L .37744 .60494 L p .707 .577 .707 r
F P
0 g
s
.30857 .6993 m .31153 .68134 L .3354 .678 L p .707 .577 .707 r
F P
0 g
s
.3354 .678 m .33243 .69595 L .30857 .6993 L p .707 .577 .707 r
F P
0 g
s
.45377 .69825 m .45081 .7162 L .42376 .7068 L p .707 .577 .707 r
F P
0 g
s
.42376 .7068 m .42672 .68885 L .45377 .69825 L p .707 .577 .707 r
F P
0 g
s
.33243 .69595 m .3354 .678 L .36449 .6782 L p .707 .577 .707 r
F P
0 g
s
.36449 .6782 m .36152 .69615 L .33243 .69595 L p .707 .577 .707 r
F P
0 g
s
.42672 .68885 m .42376 .7068 L .39299 .69989 L p .707 .577 .707 r
F P
0 g
s
.39299 .69989 m .39596 .68194 L .42672 .68885 L p .707 .577 .707 r
F P
0 g
s
.36152 .69615 m .36449 .6782 L .39596 .68194 L p .707 .577 .707 r
F P
0 g
s
.39596 .68194 m .39299 .69989 L .36152 .69615 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
P7oo6000QGoo001gOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH<001iOol007=oo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL0079oo`00Kgoo
10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
00000P00Kgoo001]Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001/Ool006]oo`8000=JEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
06Yoo`00JGoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF0`00J7oo001XOol20006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02001VOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo
06=oo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001V
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Hgoo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF0P00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0`00I7oo001V
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP00
1EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`00I7oo001VOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3001TOol006Io
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<002Eoo`h0035oo`00IWoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`007Goo20000eYF00<005YFFUH00eYF00D005YF
FUIJEP00035oo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<001Moo`H0
00AJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000aOol006Eoo`04001JEUYF0006FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH;0009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH3000EOol200000eYF001JEP08FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01@00FUIJEUYF0000<7oo001UOol01000FUIJEP001UYF00<005YFFUH01EYF1P000eYF00<005YF
FUH00eYF00@005YF000000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8001=oo`<000=JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001J
EUYFFUH0000`Ool006Eoo`04001JEUYF0006FUH01000FUIJEUYF100000=JEP00FUH01UYF00<005YF
FUH00eYF00D005YFFUIJEP0000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000moo`@000MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05
001JEUYFFUH0000`Ool006Eoo`04001JEUYF0005FUH50005FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH01000FUIJEP001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P002goo10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
15YF00@005YFFUH0031oo`00IGoo00D005YFFUH005YF00@0009JEP03001JEUYF00IJEQ8000IJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`<000IJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000`Ool0
06Eoo`D000MJEP03001JEUYF00EJEP03001JEP0000MJEP03001JEUYF009JEP03001JEP00008000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<000UJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000`
Ool0069oo`@00003FUH005YF00QJEP03001JEUYF00EJEP03001JEP0000MJEP03001JEUYF00=JEP04
001JEUYF0004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
0004Ool20002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01@00FUIJEUYF0000;goo001NOol40005FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH01000FUIJEP001eYF00<005YFFUH00UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Aoo`00000000EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000_Ool0
05aoo`800003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001J
EUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP00;goo001JOol20003FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00FUIJEP02FUH01@00FUIJEUYF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYF000_Ool005Qoo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000MJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF
008002ioo`00EWoo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00001eYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00D005YF001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP04001JEUYF000^Ool005Aoo`80009J
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000QJEP03001J
EUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEUYF00AJEP04001JEUYFFUH400000eYF001oo`0]Ool0059oo`<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000MJEP03
001JEUYF009JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEPd000=JEP<002ioo`00DGoo00@005YFFUH000AJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000AJEPH000=JEP04001JEUYF0002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00FUIJEP00FUH000AJEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEP00000]Ool0055oo`05001JEUYFFUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH70002FUH01000FUIJEUYF1@0000EJEP00001J
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1P001eYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
FUH002eoo`00DGoo00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPl00003FUH005YF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP040005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH2000^Ool0059oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH8
0005FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF1@0025YF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEP8002moo`00DWoo00@005YFFUH000AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEPH000EJEP03001JEUYF00EJEP03001JEUYF
009JEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00=JEP8000AJEP03001JEP00008000AJEP03
001JEUYF00IJEP03001JEUYF00AJEP04001JEP00000aOol0059oo`04001JEUYF0004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJ
EUYF001JEP0000AJEP03001JEUYF00EJEP03001JEP00008000IJEPH000AJEP03001JEUYF00EJEP03
001JEUYF00AJEP8003=oo`00DWoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEP00008000IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP8000AJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH40008FUH60004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000eOol005=oo`04
001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH40008FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH01000FUH000001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF
FUIJEP00009JEP03001JEUYF009JEP03001JEP0000<000=JEP03001JEUYF00MJEPD000AJEP03001J
EUYF00IJEP04001JEP00000gOol005=oo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04
0003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH30006FUH00`00FUIJ
EP07FUH40005FUH00`00FUIJEP05FUH3000iOol005=oo`04001JEUYF0004FUH00`00FUIJEP04FUH4
0008FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01000?7oo001COol01000FUIJEP0015YF00<0
05YFFUH00UYF0P0035YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0035YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`0015YF00<0
05YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1@00@7oo001DOol00`00FUH00005FUH01000
FUH000003UYF00<005YFFUH01UYF00<005YFFUH01EYF0`000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00P001EYF00<005YF
FUH015YF00<005YFFUH01eYF00<005YFFUH01000AGoo001DOol01000FUIJEP000eYF0`0000=JEP00
FUH03EYF00<005YFFUH01eYF00<005YFFUH010001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001JEUYF00AJ
EP03001JEUYF00EJEPD004Uoo`00D7oo1@000UYF00@005YF000000AJEP03001JEUYF00aJEP@000EJ
EP@000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00@004ioo`00C7oo1000
00EJEP00FUIJEP00009JEP800003FUH005YF00AJEP03001JEUYF00]JEPD00006FUH00000001JEP00
2eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000UYF00<005YFFUH00eYF00@005YFFUIJEPH0059oo`00Agoo1@001EYF00<005YFFUH00UYF
0`0000=JEP00FUH015YF00<005YFFUH00UYF0P001eYF1P0015YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
00002`00Egoo0013Ool40002FUH00`00FUIJEP06FUH01000FUH000000eYF30001eYF1`001EYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0015YF00<005YF00003`00Cgoo000oOol40006FUH00`00FUIJEP06FUH50002FUH0
0`00FUIJEP03FUH00`00FUIJEP02FUH80002FUH40006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF00000003
0002FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60019Ool003]oo`@00003FUH005YF00QJEP03001J
EUYF00EJEP04001JEP00FUH>00001EYF001JEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0`0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00AGoo000gOol4
0005FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP001eYF00<005YFFUH00eYF00<005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00UYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF1000@Goo000eOol200000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00007FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003moo`00<goo0P000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00001eYF00<005YFFUH00eYF00<005YF
00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP8000=JEP04001JEUYFFUH@0004
FUH00`00FUIJEP06FUH01000FUIJEUYF0`00?7oo000aOol20006FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUH00007FUH00`00FUIJEP03FUH00`00FUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP020003FUH60005FUH00`00FUIJEP020005Ool60006FUH0
0`00FUIJEP05FUH2000jOol0031oo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEP0000MJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00=JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF00800003FUH0000000IJEP03001JEUYF009JEP05001JEUYFFUH0000;Ool40002
FUH00`00FUIJEP06FUH3000hOol002ioo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP8000QJEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00=JEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00<00003FUH005YF00EJEP03001JEUYF00=JEP04001JEUYF0009Ool3
0003Ool40007FUH00`00FUIJEP02000fOol002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000MJEP03001JEUYF00=JEP80009J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000<00003FUH005YF009JEPd000Qoo`D000Io
o`8000AJEP/0035oo`00;7oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YF000015YF1P000eYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YF00000`0000=JEP0000000P001EYF00<005YFFUH00UYF00@005YF000000Moo`D000Aoo`P0
00=JEP03001JEUYF00=JEP04001JEP00000_Ool002]oo`03001JEP0000AJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEPL00003FUH0000000h0009JEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP06001JEP00FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH00UYF00@005YFFUH000Moo`T0
00AJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000_Ool002]oo`04001JEUYF0003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000040003
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH70005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000eYF00<005YF00001UYF00<0
05YFFUH00eYF0P001Woo10000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YF000002ioo`00:goo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00@00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP04001JEUYF0003FUH40006FUH01000FUIJEUYF0P000goo10001UYF00<005YFFUH01eYF
00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH002ioo`00:goo0P0000=JEP00FUH00eYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01@000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF10002EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF008000EJEP05
001JEP00001oo`0400000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEP00;Woo000/Ool00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50002FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH01000FUH000001eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00L005YFFUIJEP00FUH00005FUH30002FUH50005FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`03001JEP0000AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000AJEP03001JEUYF008000=JEP04001J
EUYFFUH>0006FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF1@0000=JEP00FUH01eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00
;Goo000/Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01EYF100025YF00D005YF001J
EP0000=JEP@000AJEP04001JEUYFFUH30002FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2
0003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20005FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`04001JEUYF0004FUH00`00FUIJEP05
FUH00`00FUIJEP040003FUH00`00FUIJEP06FUH01P00FUH005YF001JEP800003FUH005YF00IJEP<0
009oo`04001JEUYF0004FUH70004FUH00`00FUIJEP05FUH300000eYF001JEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUH00000FUH00`001eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YF000002eoo`00;Goo00<005YF000015YF00<005YFFUH015YF100025YF00<005YFFUH01UYF0P00
00=JEP0000000eYF00<005YFFUH015YF0P0017oo00@005YFFUH000EJEP03001JEUYF00=JEPH000IJ
EP03001JEUYF008000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP000080009JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF000]Ool002eoo`03001JEP0000AJ
EP03001JEUYF009JEP8000aJEP03001JEUYF00IJEP<000IJEP03001JEP0000<000Ioo`04001JEUYF
0005FUH00`00FUIJEP07FUH01000FUH0000015YF00<005YFFUH00UYF0P002EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF4`0000=JEP000000;7oo000]Ool00`00
FUH00005FUH01000FUH000003UYF00<005YFFUH01UYF100015YF0`002Woo00@005YFFUH000EJEP03
001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP04FUH20008FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH?0002FUH01000FUIJEUYF0P000UYF1000;7oo000]Ool01000FUIJEP000eYF0`00
00=JEP00FUH03EYF00<005YFFUH01UYF0`0000=JEP0000000P003Goo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00AJEP8000EJEP04001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<0
05YF0000;7oo000]Ool01@00FUIJEP00FUH00P0015YF00<005YFFUH035YF00<005YFFUH01eYF00<0
05YFFUH00UYF00<007ooOol037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00IJEP80
00=JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH015YF2@0000=JEP00FUH01eYF
00<005YFFUH00eYF00D005YFFUIJEP0000AJEP8002eoo`00;Woo0UYF0P0000=JEP00FUH015YF00<0
05YFFUH035YF0`0015YF0`0015YF0`0037oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00QJEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04000015YF
001JEUYF1@0000=JEP00FUH01UYF00<005YFFUH015YF00<005YF00000P0015YF00<007ooOol0;7oo
000^Ool01UYF00000000FUH000EJEP03001JEUYF009JEP8000MJEPP0009oo`03001JEUYF009JEP03
001JEUYF008000Yoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH30003FUH00`00
FUIJEP03FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP03FUH00`00FUIJEP04FUH40003FUH:00000eYF001JEP06FUH01000FUIJEUYF1@000eYF
00@005YFFUH002moo`00;Woo00@005YFFUIJEP`000MJEPL000Ioo`04001JEUYF0005FUH30007Ool0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00P005YFFUH005YF001JEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00MJEQ8000MJEP<0031oo`00;Woo0P000UYF00<005YFFUH0
0eYF00<005YFFUH00UYF20000Woo1@001goo0`001UYF00@005YF000000Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH02000FUIJEP00FUH005YF0004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP04FUH01000FUH000001UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P00<Woo000_Ool>
000;Ool3000:Ool00`00FUIJEP04FUH01000FUIJEUYF0P000goo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH01000FUIJEUYF10001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00=7oo001FOol20003FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH01000FUIJEUYF0P00
00=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P000UYF00@005YF000000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP<003Qoo`00F7oo0P0000=JEP00FUH01UYF00<005YFFUH0100015YF00<005YFFUH01eYF
00<005YFFUH01eYF1P0000=JEP00000030001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF009JEP8003]oo`00FWoo0`001UYF00<005YFFUH015YF1`001eYF00@005YFFUIJEPX000=J
EP<000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00002000mOol005eoo`80
00=JEP03001JEUYF00MJEP03001JEUYF009JEQ0000=JEP06001JEUYFFUH005YF0P0035YF00<005YF
FUH01EYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF0000009JEP03001JEUYF009J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPH0041oo`00Ggoo0P0000=JEP00FUH0
25YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH005YF
00]JEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009JEP04001JEP000002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70016Ool0065oo`@000IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH000020002FUH00`00FUIJEP02
FUH00`00FUIJEP05FUH00`00FUIJEP04001=Ool006Eoo`@0009JEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEP000004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH300000eYF001JEP03FUH00`00FUH00002FUHB001AOol006Eoo`03001JEUYF00P000AJEP03
001JEUYF00EJEP04001JEUYFFUH50006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH01000FUH0000015YF00<005YF00000P000eYF00<005YFFUH00eYF00@005YF000005Ioo`00=Goo
1`00:Goo00<005YFFUH00P0000=JEP00FUH00eYF40002eYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00@005YFFUIJEP80009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYF
001FOol0031oo`D000=JEP04001JEUYFFUH9000POol00`00FUH00003FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH300000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000^Ool200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH7000IOol20004FUH00`00FUIJEP05FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEP00EGoo000/Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000EOol20004FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00eYF00@005YFFUH005Eoo`00
:goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1000
4Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000IJEP03001JEUYF00=JEP03
001JEUYF008005Aoo`00:goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YF00000`003Goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@0
05YFFUH000IJEP03001JEUYF00=JEP05001JEUYFFUH0001DOol002Yoo`03001JEP0000=JEP04001J
EUYFFUH@0004FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000<Ool00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH00`00FUIJEP04FUH01000FUH000001UYF00<005YFFUH00eYF00D005YFFUIJEP0005Aoo`00
:Woo00<005YF00000UYF1@0047oo1`001UYF00<005YFFUH01EYF0`002Woo00<005YFFUH00UYF00<0
05YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH0
05Aoo`00:Woo00<005YF00000P0077oo10000UYF00<005YFFUH01EYF00<005YFFUH00P002Goo0P00
0UYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH015YF0P000UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH005Aoo`00:Woo0P008goo10001UYF00<005YFFUH00UYF0P002Goo0`001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH0
0eYF50000UYF00<007ooOol0DGoo000ZOol3000VOol40002FUH00`00FUIJEP03FUH2000:Ool20006
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH01000FUIJEUYF2`000UYF00P005YFFUIJEP00FUH005YF1000Dgoo000ZOol200000eYF0000000X
Ool30005FUH00`00FUH0000;Ool20004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH000001eYF00<005YFFUH00eYF00@005YFFUIJ
EP80009JEP04001JEUYF001COol002Yoo`03001JEUYF009JEP03001oogoo02Qoo`8000=JEP04001J
EUYF000<Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUH60008FUH00`00FUIJEP03FUH01@00FUIJEUYF000015YF00<005YF0000Dgoo000Z
Ool00`00FUIJEP02FUH3000ZOol200000eYF001JEP02FUH00`00Oomoo`0<Ool70005FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP0800000eYF001JEP06FUH00`00FUIJ
EP04FUH00`00FUH000020004FUH2001DOol002Yoo`03001JEUYF009JEP03001JEUYF008002Yoo`80
00=JEP03001oogoo01=oo``000IJEP03001JEUYF00YJEP03001JEUYF00=JEQ000003FUH005YF00IJ
EP04001JEUYFFUH50003FUH01@00FUIJEUYF0000EGoo000[Ool01000FUIJEP001EYF0`00:Goo00<0
05YFFUH00P0087oo700025YF4`001eYF00@005YF000005Ioo`00;7oo0`001UYF00@005YF000002Mo
o`05001JEP00FUH0000ZOol00`00FUH00005FUH00`00FUH000030004FUH00`00FUIJEP06FUH30006
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH3001HOol002ioo`03001JEUYF00AJEP04001JEUYFFUH2
000VOol200000eYF001oo`0YOol01000FUIJEP000eYF10001eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000`00Fgoo000_Ool20003FUH00`00FUIJEP04FUH4000ROol2
00000eYF001oo`0YOol01@00FUIJEP00FUH00P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF0`00Ggoo000aOol200000eYF001JEP06FUH00`00FUIJEP04000L
Ool200000eYF0000000/Ool2FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP02FUH2001ROol003=oo`<000IJEP03001JEUYF00AJEPL0011oo`D000=JEP8002ao
o`05FUH005YFFUH00004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH0
0002001TOol003Ioo`8000=JEP03001JEUYF00MJEP03001JEUYF009JEQ0000=JEP07001JEUYFFUH0
05YF0000;7oo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
0UYF1P00Igoo000hOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEUYF0P00;Goo0P000eYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
15YF1`00KGoo000jOol40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;goo0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01000M7oo000n
Ool40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<goo4P00
N7oo0012Ool70004FUH00`00FUIJEP05FUH01000FUIJEUYF1@00_goo0019Ool@0034Ool00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59154 .7799 m .60472 .72745 L .57445 .71816 L p .707 .577 .707 r
F P
0 g
s
.60472 .72745 m .59154 .7799 L .62256 .78579 L p .707 .577 .707 r
F P
0 g
s
.62256 .78579 m .63574 .73334 L .60472 .72745 L p .707 .577 .707 r
F P
0 g
s
.56127 .77061 m .57445 .71816 L .57137 .71679 L p .707 .577 .707 r
F P
0 g
s
.56127 .77061 m .57137 .71679 L .56021 .76556 L .707 .577 .707 r
F
.57445 .71816 m .56127 .77061 L .59154 .7799 L p F P
0 g
s
.58872 .77125 m .59597 .73575 L .56867 .7286 L p .707 .577 .707 r
F P
0 g
s
.56867 .7286 m .5654 .72774 L p .56783 .73227 L .707 .577 .707 r
F P
0 g
s
.58872 .77125 m .56867 .7286 L .56783 .73227 L .707 .577 .707 r
F
.55815 .76324 m .5654 .72774 L .53856 .71724 L p F P
0 g
s
.5654 .72774 m .55815 .76324 L .5606 .76388 L p .707 .577 .707 r
F P
0 g
s
.5606 .76388 m .58872 .77125 L p .56783 .73227 L .707 .577 .707 r
F P
0 g
s
.56783 .73227 m .5654 .72774 L .5606 .76388 L .707 .577 .707 r
F
.53856 .71724 m .53131 .75274 L .55815 .76324 L p F P
0 g
s
.5479 .70638 m .53471 .75883 L .55926 .76973 L p .707 .577 .707 r
F P
0 g
s
.55926 .76973 m .56127 .77061 L p .56021 .76556 L .707 .577 .707 r
F P
0 g
s
.56021 .76556 m .5479 .70638 L .55926 .76973 L .707 .577 .707 r
F
.57137 .71679 m .5479 .70638 L p .56021 .76556 L F P
0 g
s
.63574 .73334 m .62256 .78579 L .65129 .78771 L p .707 .577 .707 r
F P
0 g
s
.65129 .78771 m .66448 .73525 L .63574 .73334 L p .707 .577 .707 r
F P
0 g
s
.59597 .73575 m .58872 .77125 L .62 .77598 L p .707 .577 .707 r
F P
0 g
s
.62 .77598 m .62725 .74048 L .59597 .73575 L p .707 .577 .707 r
F P
0 g
s
.62725 .74048 m .62 .77598 L .64895 .77698 L p .707 .577 .707 r
F P
0 g
s
.64895 .77698 m .6562 .74147 L .62725 .74048 L p .707 .577 .707 r
F P
0 g
s
.53131 .75274 m .53856 .71724 L .51805 .70528 L p .707 .577 .707 r
F P
0 g
s
.53471 .75883 m .5479 .70638 L .52765 .69326 L p .707 .577 .707 r
F P
0 g
s
.66448 .73525 m .65129 .78771 L .67493 .78545 L p .707 .577 .707 r
F P
0 g
s
.67493 .78545 m .68812 .733 L .66448 .73525 L p .707 .577 .707 r
F P
0 g
s
.6562 .74147 m .64895 .77698 L .67272 .77414 L p .707 .577 .707 r
F P
0 g
s
.67272 .77414 m .67997 .73863 L .6562 .74147 L p .707 .577 .707 r
F P
0 g
s
.51805 .70528 m .5108 .74078 L .53131 .75274 L p .707 .577 .707 r
F P
0 g
s
.52765 .69326 m .51447 .74571 L .53471 .75883 L p .707 .577 .707 r
F P
0 g
s
.5108 .74078 m .51805 .70528 L .50589 .69302 L p .707 .577 .707 r
F P
0 g
s
.51447 .74571 m .52765 .69326 L .51571 .68008 L p .707 .577 .707 r
F P
0 g
s
.60701 .88579 m .60404 .8672 L .57328 .8704 L p .707 .577 .707 r
F P
0 g
s
.60404 .8672 m .60701 .88579 L .63847 .88042 L p .707 .577 .707 r
F P
0 g
s
.63847 .88042 m .63551 .86183 L .60404 .8672 L p .707 .577 .707 r
F P
0 g
s
.68812 .733 m .67493 .78545 L .69116 .77926 L p .707 .577 .707 r
F P
0 g
s
.69116 .77926 m .70435 .7268 L .68812 .733 L p .707 .577 .707 r
F P
0 g
s
.63551 .86183 m .63847 .88042 L .66757 .87339 L p .707 .577 .707 r
F P
0 g
s
.66757 .87339 m .6646 .85481 L .63551 .86183 L p .707 .577 .707 r
F P
0 g
s
.57328 .8704 m .57624 .88899 L .60701 .88579 L p .707 .577 .707 r
F P
0 g
s
.67997 .73863 m .67272 .77414 L .68899 .76774 L p .707 .577 .707 r
F P
0 g
s
.68899 .76774 m .69624 .73223 L .67997 .73863 L p .707 .577 .707 r
F P
0 g
s
.57624 .88899 m .57328 .8704 L .54622 .8711 L p .707 .577 .707 r
F P
0 g
s
.54622 .8711 m .54919 .88969 L .57624 .88899 L p .707 .577 .707 r
F P
0 g
s
.6646 .85481 m .66757 .87339 L .69143 .8654 L p .707 .577 .707 r
F P
0 g
s
.69143 .8654 m .68847 .84681 L .6646 .85481 L p .707 .577 .707 r
F P
0 g
s
.50589 .69302 m .49865 .72852 L .5108 .74078 L p .707 .577 .707 r
F P
0 g
s
.51571 .68008 m .50252 .73254 L .51447 .74571 L p .707 .577 .707 r
F P
0 g
s
.54919 .88969 m .54622 .8711 L .52554 .86924 L p .707 .577 .707 r
F P
0 g
s
.50252 .73254 m .51571 .68008 L .51323 .66814 L p .707 .577 .707 r
F P
0 g
s
.70435 .7268 m .69116 .77926 L .69839 .76972 L p .707 .577 .707 r
F P
0 g
s
.69839 .76972 m .71157 .71726 L .70435 .7268 L p .707 .577 .707 r
F P
0 g
s
.52554 .86924 m .5285 .88783 L .54919 .88969 L p .707 .577 .707 r
F P
0 g
s
.68847 .84681 m .69143 .8654 L .70774 .85723 L p .707 .577 .707 r
F P
0 g
s
.70774 .85723 m .70477 .83864 L .68847 .84681 L p .707 .577 .707 r
F P
0 g
s
.69624 .73223 m .68899 .76774 L .69617 .7584 L p .707 .577 .707 r
F P
0 g
s
.69617 .7584 m .70342 .7229 L .69624 .73223 L p .707 .577 .707 r
F P
0 g
s
.49865 .72852 m .50589 .69302 L .50328 .68167 L p .707 .577 .707 r
F P
0 g
s
.51323 .66814 m .50004 .7206 L .50252 .73254 L p .707 .577 .707 r
F P
0 g
s
.50328 .68167 m .49603 .71718 L .49865 .72852 L p .707 .577 .707 r
F P
0 g
s
.5285 .88783 m .52554 .86924 L .51324 .865 L p .707 .577 .707 r
F P
0 g
s
.51324 .865 m .5162 .88359 L .5285 .88783 L p .707 .577 .707 r
F P
0 g
s
.50004 .7206 m .51323 .66814 L .52045 .65861 L p .707 .577 .707 r
F P
0 g
s
.70342 .7229 m .69617 .7584 L .69356 .74705 L p .707 .577 .707 r
F P
0 g
s
.71157 .71726 m .69839 .76972 L .6959 .75778 L p .707 .577 .707 r
F P
0 g
s
.6959 .75778 m .70909 .70533 L .71157 .71726 L p .707 .577 .707 r
F P
0 g
s
.4905 .82137 m .48536 .31896 L .44135 .31674 L p .707 .577 .707 r
F P
0 g
s
.49603 .71718 m .50328 .68167 L .51046 .67234 L p .707 .577 .707 r
F P
0 g
s
.52045 .65861 m .50727 .71106 L .50004 .7206 L p .707 .577 .707 r
F P
0 g
s
.51046 .67234 m .50321 .70784 L .49603 .71718 L p .707 .577 .707 r
F P
0 g
s
.50727 .71106 m .52045 .65861 L .53668 .65241 L p .707 .577 .707 r
F P
0 g
s
.50321 .70784 m .51046 .67234 L .52673 .66594 L p .707 .577 .707 r
F P
0 g
s
.53668 .65241 m .52349 .70487 L .50727 .71106 L p .707 .577 .707 r
F P
0 g
s
.52673 .66594 m .51948 .70144 L .50321 .70784 L p .707 .577 .707 r
F P
0 g
s
.52349 .70487 m .53668 .65241 L .56032 .65016 L p .707 .577 .707 r
F P
0 g
s
.51948 .70144 m .52673 .66594 L .5505 .6631 L p .707 .577 .707 r
F P
0 g
s
.56032 .65016 m .54713 .70261 L .52349 .70487 L p .707 .577 .707 r
F P
0 g
s
.5505 .6631 m .54325 .6986 L .51948 .70144 L p .707 .577 .707 r
F P
0 g
s
.48536 .31896 m .4905 .82137 L .53544 .81986 L p .707 .577 .707 r
F P
0 g
s
.53544 .81986 m .5303 .31745 L .48536 .31896 L p .707 .577 .707 r
F P
0 g
s
.70477 .83864 m .70774 .85723 L .71488 .84967 L p .707 .577 .707 r
F P
0 g
s
.71488 .84967 m .71192 .83108 L .70477 .83864 L p .707 .577 .707 r
F P
0 g
s
.54713 .70261 m .56032 .65016 L .58905 .65207 L p .707 .577 .707 r
F P
0 g
s
.58905 .65207 m .57587 .70453 L .54713 .70261 L p .707 .577 .707 r
F P
0 g
s
.54325 .6986 m .5505 .6631 L .57945 .66409 L p .707 .577 .707 r
F P
0 g
s
.57945 .66409 m .5722 .69959 L .54325 .6986 L p .707 .577 .707 r
F P
0 g
s
.5303 .31745 m .53544 .81986 L .57692 .81477 L p .707 .577 .707 r
F P
0 g
s
.57587 .70453 m .58905 .65207 L .62007 .65796 L p .707 .577 .707 r
F P
0 g
s
.62007 .65796 m .60689 .71041 L .57587 .70453 L p .707 .577 .707 r
F P
0 g
s
.5722 .69959 m .57945 .66409 L .61073 .66882 L p .707 .577 .707 r
F P
0 g
s
.61073 .66882 m .60349 .70433 L .5722 .69959 L p .707 .577 .707 r
F P
0 g
s
.57692 .81477 m .57178 .31236 L .5303 .31745 L p .707 .577 .707 r
F P
0 g
s
.69356 .74705 m .7008 .71155 L .70342 .7229 L p .707 .577 .707 r
F P
0 g
s
.44649 .81915 m .44135 .31674 L .40259 .31099 L p .707 .577 .707 r
F P
0 g
s
.44135 .31674 m .44649 .81915 L .4905 .82137 L p .707 .577 .707 r
F P
0 g
s
.5162 .88359 m .51324 .865 L .51053 .8588 L p .707 .577 .707 r
F P
0 g
s
.57178 .31236 m .57692 .81477 L .61088 .80658 L p .707 .577 .707 r
F P
0 g
s
.66814 .68733 m .6609 .72283 L .63619 .71317 L p .707 .577 .707 r
F P
0 g
s
.63685 .71028 m .66814 .68733 L .63619 .71317 L .707 .577 .707 r
F
.63487 .719 m .60689 .71041 L p .6455 .67206 L F P
0 g
s
.63405 .71233 m .6413 .67683 L .66814 .68733 L p .707 .577 .707 r
F P
0 g
s
.65035 .66725 m .63716 .7197 L .63487 .719 L p .707 .577 .707 r
F P
0 g
s
.6455 .67206 m .65035 .66725 L .63487 .719 L .707 .577 .707 r
F
.63619 .71317 m .63405 .71233 L p .63685 .71028 L F P
0 g
s
.60689 .71041 m .62007 .65796 L .65035 .66725 L p .707 .577 .707 r
F P
0 g
s
.6413 .67683 m .63405 .71233 L .60349 .70433 L p .707 .577 .707 r
F P
0 g
s
.60349 .70433 m .61073 .66882 L .6413 .67683 L p .707 .577 .707 r
F P
0 g
s
.61088 .80658 m .60573 .30417 L .57178 .31236 L p .707 .577 .707 r
F P
0 g
s
.24853 .69455 m .26171 .64209 L .23144 .6328 L p .707 .577 .707 r
F P
0 g
s
.26171 .64209 m .24853 .69455 L .27955 .70044 L p .707 .577 .707 r
F P
0 g
s
.27955 .70044 m .29274 .64798 L .26171 .64209 L p .707 .577 .707 r
F P
0 g
s
.51053 .8588 m .51349 .87739 L .5162 .88359 L p .707 .577 .707 r
F P
0 g
s
.21826 .68526 m .23144 .6328 L .20489 .62102 L p .707 .577 .707 r
F P
0 g
s
.23144 .6328 m .21826 .68526 L .24853 .69455 L p .707 .577 .707 r
F P
0 g
s
.29274 .64798 m .27955 .70044 L .30829 .70235 L p .707 .577 .707 r
F P
0 g
s
.30829 .70235 m .32147 .64989 L .29274 .64798 L p .707 .577 .707 r
F P
0 g
s
.7008 .71155 m .69356 .74705 L .6814 .7348 L p .707 .577 .707 r
F P
0 g
s
.70909 .70533 m .6959 .75778 L .68396 .74461 L p .707 .577 .707 r
F P
0 g
s
.6814 .7348 m .68865 .69929 L .7008 .71155 L p .707 .577 .707 r
F P
0 g
s
.68396 .74461 m .69714 .69215 L .70909 .70533 L p .707 .577 .707 r
F P
0 g
s
.71192 .83108 m .71488 .84967 L .71217 .84347 L p .707 .577 .707 r
F P
0 g
s
.71217 .84347 m .70921 .82488 L .71192 .83108 L p .707 .577 .707 r
F P
0 g
s
.40773 .8134 m .40259 .31099 L .37287 .30229 L p .707 .577 .707 r
F P
0 g
s
.40259 .31099 m .40773 .8134 L .44649 .81915 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.1917 .67348 m .20489 .62102 L .18465 .6079 L p .707 .577 .707 r
F P
0 g
s
.20489 .62102 m .1917 .67348 L .21826 .68526 L p .707 .577 .707 r
F P
0 g
s
.32147 .64989 m .30829 .70235 L .33192 .7001 L p .707 .577 .707 r
F P
0 g
s
.33192 .7001 m .34511 .64764 L .32147 .64989 L p .707 .577 .707 r
F P
0 g
s
.60573 .30417 m .61088 .80658 L .63398 .79611 L p .707 .577 .707 r
F P
0 g
s
.63398 .79611 m .62884 .2937 L .60573 .30417 L p .707 .577 .707 r
F P
0 g
s
.51349 .87739 m .51053 .8588 L .51767 .85125 L p .707 .577 .707 r
F P
0 g
s
.264 .77275 m .26103 .75417 L .23027 .75736 L p .707 .577 .707 r
F P
0 g
s
.26103 .75417 m .264 .77275 L .29547 .76738 L p .707 .577 .707 r
F P
0 g
s
.29547 .76738 m .2925 .74879 L .26103 .75417 L p .707 .577 .707 r
F P
0 g
s
.2925 .74879 m .29547 .76738 L .32456 .76036 L p .707 .577 .707 r
F P
0 g
s
.32456 .76036 m .32159 .74177 L .2925 .74879 L p .707 .577 .707 r
F P
0 g
s
.68865 .69929 m .6814 .7348 L .6609 .72283 L p .707 .577 .707 r
F P
0 g
s
.69714 .69215 m .68396 .74461 L .66372 .73149 L p .707 .577 .707 r
F P
0 g
s
.6609 .72283 m .66814 .68733 L .68865 .69929 L p .707 .577 .707 r
F P
0 g
s
.66372 .73149 m .6769 .67903 L .69714 .69215 L p .707 .577 .707 r
F P
0 g
s
.51767 .85125 m .52064 .86984 L .51349 .87739 L p .707 .577 .707 r
F P
0 g
s
.23027 .75736 m .23323 .77595 L .264 .77275 L p .707 .577 .707 r
F P
0 g
s
.18465 .6079 m .17146 .66036 L .1917 .67348 L p .707 .577 .707 r
F P
0 g
s
.17146 .66036 m .18465 .6079 L .1727 .59472 L p .707 .577 .707 r
F P
0 g
s
.23323 .77595 m .23027 .75736 L .20322 .75806 L p .707 .577 .707 r
F P
0 g
s
.34511 .64764 m .33192 .7001 L .34815 .6939 L p .707 .577 .707 r
F P
0 g
s
.34815 .6939 m .36134 .64144 L .34511 .64764 L p .707 .577 .707 r
F P
0 g
s
.70921 .82488 m .71217 .84347 L .69987 .83923 L p .707 .577 .707 r
F P
0 g
s
.69987 .83923 m .69691 .82064 L .70921 .82488 L p .707 .577 .707 r
F P
0 g
s
.21515 .81362 m .22239 .77812 L .19555 .76762 L p .707 .577 .707 r
F P
0 g
s
.20322 .75806 m .20618 .77665 L .23323 .77595 L p .707 .577 .707 r
F P
0 g
s
.24571 .82163 m .25296 .78613 L .22239 .77812 L p .707 .577 .707 r
F P
0 g
s
.25296 .78613 m .24571 .82163 L .27699 .82636 L p .707 .577 .707 r
F P
0 g
s
.27699 .82636 m .28424 .79086 L .25296 .78613 L p .707 .577 .707 r
F P
0 g
s
.37801 .8047 m .37287 .30229 L .35509 .29149 L p .707 .577 .707 r
F P
0 g
s
.37287 .30229 m .37801 .8047 L .40773 .8134 L p .707 .577 .707 r
F P
0 g
s
.32159 .74177 m .32456 .76036 L .34842 .75236 L p .707 .577 .707 r
F P
0 g
s
.34842 .75236 m .34546 .73378 L .32159 .74177 L p .707 .577 .707 r
F P
0 g
s
.28424 .79086 m .27699 .82636 L .30594 .82736 L p .707 .577 .707 r
F P
0 g
s
.30594 .82736 m .31319 .79185 L .28424 .79086 L p .707 .577 .707 r
F P
0 g
s
.22239 .77812 m .21515 .81362 L .24571 .82163 L p .707 .577 .707 r
F P
0 g
s
.6769 .67903 m .66372 .73149 L .63716 .7197 L p .707 .577 .707 r
F P
0 g
s
.63716 .7197 m .65035 .66725 L .6769 .67903 L p .707 .577 .707 r
F P
0 g
s
.20618 .77665 m .20322 .75806 L .18253 .7562 L p .707 .577 .707 r
F P
0 g
s
.1727 .59472 m .15951 .64718 L .17146 .66036 L p .707 .577 .707 r
F P
0 g
s
.19555 .76762 m .1883 .80312 L .21515 .81362 L p .707 .577 .707 r
F P
0 g
s
.1883 .80312 m .19555 .76762 L .17504 .75566 L p .707 .577 .707 r
F P
0 g
s
.18253 .7562 m .18549 .77479 L .20618 .77665 L p .707 .577 .707 r
F P
0 g
s
.52064 .86984 m .51767 .85125 L .53398 .84307 L p .707 .577 .707 r
F P
0 g
s
.31319 .79185 m .30594 .82736 L .32971 .82452 L p .707 .577 .707 r
F P
0 g
s
.32971 .82452 m .33696 .78901 L .31319 .79185 L p .707 .577 .707 r
F P
0 g
s
.34546 .73378 m .34842 .75236 L .36473 .74419 L p .707 .577 .707 r
F P
0 g
s
.36473 .74419 m .36176 .7256 L .34546 .73378 L p .707 .577 .707 r
F P
0 g
s
.53398 .84307 m .53694 .86166 L .52064 .86984 L p .707 .577 .707 r
F P
0 g
s
.15951 .64718 m .1727 .59472 L .17022 .58279 L p .707 .577 .707 r
F P
0 g
s
.62884 .2937 m .63398 .79611 L .64398 .78437 L p .707 .577 .707 r
F P
0 g
s
.64398 .78437 m .63884 .28196 L .62884 .2937 L p .707 .577 .707 r
F P
0 g
s
.36134 .64144 m .34815 .6939 L .35538 .68436 L p .707 .577 .707 r
F P
0 g
s
.35538 .68436 m .36544 .64431 L p .36134 .64144 L .707 .577 .707 r
F P
0 g
s
.36632 .63487 m .36134 .64144 L p .36544 .64431 L .707 .577 .707 r
F P
0 g
s
.35538 .68436 m .35289 .67243 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.36544 .64431 m .36856 .63191 L .36632 .63487 L p .707 .577 .707 r
F P
0 g
s
.36856 .63191 m .36544 .64431 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.36544 .64431 m .35538 .68436 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.35509 .29149 m .351 .27964 L p .35486 .4947 L .707 .577 .707 r
F P
0 g
s
.35648 .52404 m .35509 .29149 L .35486 .4947 L .707 .577 .707 r
F
.35413 .60679 m .36147 .61489 L p .3417 .65762 L F P
0 g
s
.35797 .61811 m .35509 .29149 L .35702 .61476 L .707 .577 .707 r
F
.34168 .65811 m .36147 .61489 L .3621 .6262 L F
.34095 .65925 m .3417 .65762 L .34168 .65811 L F
.3417 .65762 m .36147 .61489 L .34168 .65811 L F
.35805 .58051 m .35509 .29149 L p .35784 .60294 L F P
0 g
s
.36608 .61997 m .36856 .63191 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.35289 .67243 m .36253 .6341 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.36253 .6341 m .36608 .61997 L p .36473 .64182 L .707 .577 .707 r
F P
0 g
s
.35316 .80878 m .36041 .77328 L .35323 .78261 L p .707 .577 .707 r
F P
0 g
s
.36608 .61997 m .35289 .67243 L .34095 .65925 L p .707 .577 .707 r
F P
0 g
s
.35323 .78261 m .34598 .81812 L .35316 .80878 L p .707 .577 .707 r
F P
0 g
s
.36041 .77328 m .35316 .80878 L .35055 .79743 L p .707 .577 .707 r
F P
0 g
s
.35055 .79743 m .3578 .76193 L .36041 .77328 L p .707 .577 .707 r
F P
0 g
s
.36176 .7256 m .36473 .74419 L .37187 .73663 L p .707 .577 .707 r
F P
0 g
s
.37187 .73663 m .36891 .71804 L .36176 .7256 L p .707 .577 .707 r
F P
0 g
s
.3662 .71184 m .36916 .73043 L .35686 .72619 L p .707 .577 .707 r
F P
0 g
s
.35686 .72619 m .3539 .70761 L .3662 .71184 L p .707 .577 .707 r
F P
0 g
s
.34598 .81812 m .35323 .78261 L .33696 .78901 L p .707 .577 .707 r
F P
0 g
s
.3578 .76193 m .35055 .79743 L .34174 .78856 L p .707 .577 .707 r
F P
0 g
s
.34174 .78856 m .33839 .78518 L p .3421 .78074 L .707 .577 .707 r
F P
0 g
s
.3421 .78074 m .3578 .76193 L .34174 .78856 L .707 .577 .707 r
F
.34564 .74967 m .3578 .76193 L p .3421 .78074 L F P
0 g
s
.33839 .78518 m .3429 .7631 L p .3421 .78074 L .707 .577 .707 r
F P
0 g
s
.3429 .7631 m .34564 .74967 L p .3421 .78074 L .707 .577 .707 r
F P
0 g
s
.351 .27964 m .35434 .60536 L p .35702 .61476 L .707 .577 .707 r
F P
0 g
s
.36147 .61489 m .36608 .61997 L p .3621 .6262 L .707 .577 .707 r
F P
0 g
s
.36891 .71804 m .37187 .73663 L .36916 .73043 L p .707 .577 .707 r
F P
0 g
s
.36916 .73043 m .3662 .71184 L .36891 .71804 L p .707 .577 .707 r
F P
0 g
s
.35509 .29149 m .36023 .7939 L .37801 .8047 L p .707 .577 .707 r
F P
0 g
s
.35985 .38929 m .35282 .45765 L .36052 .31932 L .707 .577 .707 r
F
.3539 .70761 m .35686 .72619 L .33618 .72434 L p F P
0 g
s
.35748 .64059 m .35702 .61476 L .35614 .78205 L .707 .577 .707 r
F
.35614 .78205 m .36023 .7939 L p .35748 .64059 L F P
0 g
s
.35434 .60536 m .35614 .78205 L p .35702 .61476 L .707 .577 .707 r
F P
0 g
s
.35702 .61476 m .35648 .52404 L .35486 .4947 L .707 .577 .707 r
F
.35883 .71592 m .35797 .61811 L .35702 .61476 L F
.35614 .78205 m .35355 .52835 L p .35985 .38929 L F P
0 g
s
.35355 .52835 m .35282 .45765 L p .35985 .38929 L .707 .577 .707 r
F P
0 g
s
.35805 .58051 m .35784 .60294 L .35883 .71592 L .707 .577 .707 r
F
.35937 .71006 m .35805 .58051 L p .35883 .71592 L F P
0 g
s
.36023 .7939 m .35937 .71006 L p .35883 .71592 L .707 .577 .707 r
F P
0 g
s
.36614 .77031 m .35614 .78205 L p .35985 .38929 L .707 .577 .707 r
F P
0 g
s
.35985 .38929 m .36052 .31932 L .36106 .36276 L .707 .577 .707 r
F
.35985 .38929 m .36106 .36276 L .36614 .77031 L F
.361 .2679 m .36137 .30395 L p .36052 .31932 L F P
0 g
s
.36137 .30395 m .36614 .77031 L p .36052 .31932 L .707 .577 .707 r
F P
0 g
s
.351 .27964 m .361 .2679 L p .36052 .31932 L .707 .577 .707 r
F P
0 g
s
.35282 .45765 m .351 .27964 L p .36052 .31932 L .707 .577 .707 r
F P
0 g
s
.34095 .65925 m .3418 .65586 L p .3417 .65762 L .707 .577 .707 r
F P
0 g
s
.3418 .65586 m .35413 .60679 L p .3417 .65762 L .707 .577 .707 r
F P
0 g
s
.69691 .82064 m .69987 .83923 L .67918 .83737 L p .707 .577 .707 r
F P
0 g
s
.67918 .83737 m .67622 .81879 L .69691 .82064 L p .707 .577 .707 r
F P
0 g
s
.17504 .75566 m .16779 .79116 L .1883 .80312 L p .707 .577 .707 r
F P
0 g
s
.16779 .79116 m .17504 .75566 L .16289 .7434 L p .707 .577 .707 r
F P
0 g
s
.18549 .77479 m .18253 .7562 L .17023 .75197 L p .707 .577 .707 r
F P
0 g
s
.33696 .78901 m .32971 .82452 L .34598 .81812 L p .707 .577 .707 r
F P
0 g
s
.17023 .75197 m .17319 .77056 L .18549 .77479 L p .707 .577 .707 r
F P
0 g
s
.17022 .58279 m .15703 .63524 L .15951 .64718 L p .707 .577 .707 r
F P
0 g
s
.53694 .86166 m .53398 .84307 L .55784 .83508 L p .707 .577 .707 r
F P
0 g
s
.55784 .83508 m .56081 .85367 L .53694 .86166 L p .707 .577 .707 r
F P
0 g
s
.67622 .81879 m .67918 .83737 L .65213 .83808 L p .707 .577 .707 r
F P
0 g
s
.65213 .83808 m .64917 .81949 L .67622 .81879 L p .707 .577 .707 r
F P
0 g
s
.15703 .63524 m .17022 .58279 L .17744 .57325 L p .707 .577 .707 r
F P
0 g
s
.16289 .7434 m .15564 .7789 L .16779 .79116 L p .707 .577 .707 r
F P
0 g
s
.56081 .85367 m .55784 .83508 L .58693 .82805 L p .707 .577 .707 r
F P
0 g
s
.63884 .28196 m .64398 .78437 L .6399 .77252 L p .707 .577 .707 r
F P
0 g
s
.6399 .77252 m .63476 .27011 L .63884 .28196 L p .707 .577 .707 r
F P
0 g
s
.17319 .77056 m .17023 .75197 L .16752 .74577 L p .707 .577 .707 r
F P
0 g
s
.58693 .82805 m .5899 .84664 L .56081 .85367 L p .707 .577 .707 r
F P
0 g
s
.15564 .7789 m .16289 .7434 L .16027 .73205 L p .707 .577 .707 r
F P
0 g
s
.64917 .81949 m .65213 .83808 L .62137 .84127 L p .707 .577 .707 r
F P
0 g
s
.62137 .84127 m .6184 .82268 L .64917 .81949 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16752 .74577 m .17048 .76435 L .17319 .77056 L p .707 .577 .707 r
F P
0 g
s
.17744 .57325 m .16426 .62571 L .15703 .63524 L p .707 .577 .707 r
F P
0 g
s
.5899 .84664 m .58693 .82805 L .6184 .82268 L p .707 .577 .707 r
F P
0 g
s
.6184 .82268 m .62137 .84127 L .5899 .84664 L p .707 .577 .707 r
F P
0 g
s
.16027 .73205 m .15302 .76756 L .15564 .7789 L p .707 .577 .707 r
F P
0 g
s
.16426 .62571 m .17744 .57325 L .19367 .56705 L p .707 .577 .707 r
F P
0 g
s
.15302 .76756 m .16027 .73205 L .16745 .72272 L p .707 .577 .707 r
F P
0 g
s
.17048 .76435 m .16752 .74577 L .17466 .73821 L p .707 .577 .707 r
F P
0 g
s
.19367 .56705 m .18048 .61951 L .16426 .62571 L p .707 .577 .707 r
F P
0 g
s
.17466 .73821 m .17763 .7568 L .17048 .76435 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18048 .61951 m .19367 .56705 L .21731 .5648 L p .707 .577 .707 r
F P
0 g
s
.63476 .27011 m .6399 .77252 L .62212 .76172 L p .707 .577 .707 r
F P
0 g
s
.62212 .76172 m .61698 .25931 L .63476 .27011 L p .707 .577 .707 r
F P
0 g
s
.35413 .60679 m .34095 .65925 L .32071 .64613 L p .707 .577 .707 r
F P
0 g
s
.32071 .64613 m .33389 .59367 L .35413 .60679 L p .707 .577 .707 r
F P
0 g
s
.16745 .72272 m .1602 .75822 L .15302 .76756 L p .707 .577 .707 r
F P
0 g
s
.36614 .77031 m .361 .2679 L .38411 .25743 L p .707 .577 .707 r
F P
0 g
s
.1602 .75822 m .16745 .72272 L .18372 .71632 L p .707 .577 .707 r
F P
0 g
s
.21731 .5648 m .20412 .61726 L .18048 .61951 L p .707 .577 .707 r
F P
0 g
s
.17763 .7568 m .17466 .73821 L .19097 .73003 L p .707 .577 .707 r
F P
0 g
s
.20412 .61726 m .21731 .5648 L .24604 .56671 L p .707 .577 .707 r
F P
0 g
s
.33389 .59367 m .32071 .64613 L .29415 .63435 L p .707 .577 .707 r
F P
0 g
s
.29415 .63435 m .30734 .58189 L .33389 .59367 L p .707 .577 .707 r
F P
0 g
s
.19097 .73003 m .19393 .74862 L .17763 .7568 L p .707 .577 .707 r
F P
0 g
s
.33618 .72434 m .33321 .70575 L .3539 .70761 L p .707 .577 .707 r
F P
0 g
s
.18372 .71632 m .17647 .75182 L .1602 .75822 L p .707 .577 .707 r
F P
0 g
s
.23286 .61917 m .24604 .56671 L .27707 .5726 L p .707 .577 .707 r
F P
0 g
s
.24604 .56671 m .23286 .61917 L .20412 .61726 L p .707 .577 .707 r
F P
0 g
s
.30734 .58189 m .29415 .63435 L .26388 .62506 L p .707 .577 .707 r
F P
0 g
s
.26388 .62506 m .27707 .5726 L .30734 .58189 L p .707 .577 .707 r
F P
0 g
s
.61698 .25931 m .62212 .76172 L .5924 .75302 L p .707 .577 .707 r
F P
0 g
s
.5924 .75302 m .58726 .25061 L .61698 .25931 L p .707 .577 .707 r
F P
0 g
s
.27707 .5726 m .26388 .62506 L .23286 .61917 L p .707 .577 .707 r
F P
0 g
s
.34564 .74967 m .33839 .78518 L .31789 .77321 L p .707 .577 .707 r
F P
0 g
s
.31789 .77321 m .32513 .73771 L .34564 .74967 L p .707 .577 .707 r
F P
0 g
s
.19393 .74862 m .19097 .73003 L .21483 .72204 L p .707 .577 .707 r
F P
0 g
s
.17647 .75182 m .18372 .71632 L .20749 .71347 L p .707 .577 .707 r
F P
0 g
s
.21483 .72204 m .2178 .74063 L .19393 .74862 L p .707 .577 .707 r
F P
0 g
s
.33321 .70575 m .33618 .72434 L .30912 .72504 L p .707 .577 .707 r
F P
0 g
s
.30912 .72504 m .30616 .70645 L .33321 .70575 L p .707 .577 .707 r
F P
0 g
s
.38411 .25743 m .38925 .75984 L .36614 .77031 L p .707 .577 .707 r
F P
0 g
s
.38925 .75984 m .38411 .25743 L .41807 .24924 L p .707 .577 .707 r
F P
0 g
s
.20749 .71347 m .20025 .74898 L .17647 .75182 L p .707 .577 .707 r
F P
0 g
s
.72874 .68787 m .74193 .63541 L .71166 .62612 L p .707 .577 .707 r
F P
0 g
s
.74193 .63541 m .72874 .68787 L .75976 .69376 L p .707 .577 .707 r
F P
0 g
s
.75976 .69376 m .77295 .6413 L .74193 .63541 L p .707 .577 .707 r
F P
0 g
s
.69847 .67858 m .71166 .62612 L .70858 .62475 L p .707 .577 .707 r
F P
0 g
s
.69847 .67858 m .70858 .62475 L .69742 .67352 L .707 .577 .707 r
F
.71166 .62612 m .69847 .67858 L .72874 .68787 L p F P
0 g
s
.72592 .67921 m .73317 .64371 L .70588 .63656 L p .707 .577 .707 r
F P
0 g
s
.70588 .63656 m .70261 .6357 L p .70504 .64023 L .707 .577 .707 r
F P
0 g
s
.72592 .67921 m .70588 .63656 L .70504 .64023 L .707 .577 .707 r
F
.69536 .67121 m .70261 .6357 L .67576 .6252 L p F P
0 g
s
.70261 .6357 m .69536 .67121 L .6978 .67185 L p .707 .577 .707 r
F P
0 g
s
.6978 .67185 m .72592 .67921 L p .70504 .64023 L .707 .577 .707 r
F P
0 g
s
.70504 .64023 m .70261 .6357 L .6978 .67185 L .707 .577 .707 r
F
.67576 .6252 m .66851 .66071 L .69536 .67121 L p F P
0 g
s
.6851 .61434 m .67191 .66679 L .69647 .67769 L p .707 .577 .707 r
F P
0 g
s
.69647 .67769 m .69847 .67858 L p .69742 .67352 L .707 .577 .707 r
F P
0 g
s
.69742 .67352 m .6851 .61434 L .69647 .67769 L .707 .577 .707 r
F
.70858 .62475 m .6851 .61434 L p .69742 .67352 L F P
0 g
s
.77295 .6413 m .75976 .69376 L .7885 .69567 L p .707 .577 .707 r
F P
0 g
s
.7885 .69567 m .80169 .64321 L .77295 .6413 L p .707 .577 .707 r
F P
0 g
s
.2178 .74063 m .21483 .72204 L .24393 .71502 L p .707 .577 .707 r
F P
0 g
s
.32513 .73771 m .31789 .77321 L .29104 .76271 L p .707 .577 .707 r
F P
0 g
s
.29104 .76271 m .29829 .72721 L .32513 .73771 L p .707 .577 .707 r
F P
0 g
s
.73317 .64371 m .72592 .67921 L .75721 .68395 L p .707 .577 .707 r
F P
0 g
s
.75721 .68395 m .76445 .64844 L .73317 .64371 L p .707 .577 .707 r
F P
0 g
s
.20025 .74898 m .20749 .71347 L .23644 .71447 L p .707 .577 .707 r
F P
0 g
s
.24393 .71502 m .24689 .7336 L .2178 .74063 L p .707 .577 .707 r
F P
0 g
s
.76445 .64844 m .75721 .68395 L .78615 .68494 L p .707 .577 .707 r
F P
0 g
s
.78615 .68494 m .7934 .64943 L .76445 .64844 L p .707 .577 .707 r
F P
0 g
s
.30616 .70645 m .30912 .72504 L .27836 .72823 L p .707 .577 .707 r
F P
0 g
s
.27836 .72823 m .27539 .70964 L .30616 .70645 L p .707 .577 .707 r
F P
0 g
s
.58726 .25061 m .5924 .75302 L .55364 .74727 L p .707 .577 .707 r
F P
0 g
s
.55364 .74727 m .54849 .24486 L .58726 .25061 L p .707 .577 .707 r
F P
0 g
s
.24689 .7336 m .24393 .71502 L .27539 .70964 L p .707 .577 .707 r
F P
0 g
s
.66851 .66071 m .67576 .6252 L .65525 .61324 L p .707 .577 .707 r
F P
0 g
s
.67191 .66679 m .6851 .61434 L .66486 .60122 L p .707 .577 .707 r
F P
0 g
s
.27539 .70964 m .27836 .72823 L .24689 .7336 L p .707 .577 .707 r
F P
0 g
s
.80169 .64321 m .7885 .69567 L .81214 .69341 L p .707 .577 .707 r
F P
0 g
s
.81214 .69341 m .82532 .64096 L .80169 .64321 L p .707 .577 .707 r
F P
0 g
s
.23644 .71447 m .22919 .74997 L .20025 .74898 L p .707 .577 .707 r
F P
0 g
s
.29829 .72721 m .29104 .76271 L .26048 .75471 L p .707 .577 .707 r
F P
0 g
s
.26048 .75471 m .26772 .7192 L .29829 .72721 L p .707 .577 .707 r
F P
0 g
s
.22919 .74997 m .23644 .71447 L .26772 .7192 L p .707 .577 .707 r
F P
0 g
s
.42321 .75165 m .41807 .24924 L .45955 .24414 L p .707 .577 .707 r
F P
0 g
s
.41807 .24924 m .42321 .75165 L .38925 .75984 L p .707 .577 .707 r
F P
0 g
s
.7934 .64943 m .78615 .68494 L .80992 .6821 L p .707 .577 .707 r
F P
0 g
s
.80992 .6821 m .81717 .64659 L .7934 .64943 L p .707 .577 .707 r
F P
0 g
s
.26772 .7192 m .26048 .75471 L .22919 .74997 L p .707 .577 .707 r
F P
0 g
s
.54849 .24486 m .55364 .74727 L .50963 .74505 L p .707 .577 .707 r
F P
0 g
s
.50963 .74505 m .50449 .24264 L .54849 .24486 L p .707 .577 .707 r
F P
0 g
s
.65525 .61324 m .64801 .64874 L .66851 .66071 L p .707 .577 .707 r
F P
0 g
s
.66486 .60122 m .65167 .65367 L .67191 .66679 L p .707 .577 .707 r
F P
0 g
s
.64801 .64874 m .65525 .61324 L .6431 .60098 L p .707 .577 .707 r
F P
0 g
s
.65167 .65367 m .66486 .60122 L .65291 .58804 L p .707 .577 .707 r
F P
0 g
s
.74421 .79375 m .74125 .77517 L .71048 .77836 L p .707 .577 .707 r
F P
0 g
s
.74125 .77517 m .74421 .79375 L .77568 .78838 L p .707 .577 .707 r
F P
0 g
s
.77568 .78838 m .77271 .76979 L .74125 .77517 L p .707 .577 .707 r
F P
0 g
s
.82532 .64096 m .81214 .69341 L .82836 .68722 L p .707 .577 .707 r
F P
0 g
s
.82836 .68722 m .84155 .63476 L .82532 .64096 L p .707 .577 .707 r
F P
0 g
s
.46469 .74656 m .45955 .24414 L .50449 .24264 L p .707 .577 .707 r
F P
0 g
s
.45955 .24414 m .46469 .74656 L .42321 .75165 L p .707 .577 .707 r
F P
0 g
s
.77271 .76979 m .77568 .78838 L .80477 .78136 L p .707 .577 .707 r
F P
0 g
s
.80477 .78136 m .8018 .76277 L .77271 .76979 L p .707 .577 .707 r
F P
0 g
s
.71048 .77836 m .71345 .79695 L .74421 .79375 L p .707 .577 .707 r
F P
0 g
s
.50449 .24264 m .50963 .74505 L .46469 .74656 L p .707 .577 .707 r
F P
0 g
s
.81717 .64659 m .80992 .6821 L .8262 .6757 L p .707 .577 .707 r
F P
0 g
s
.8262 .6757 m .83345 .64019 L .81717 .64659 L p .707 .577 .707 r
F P
0 g
s
.71345 .79695 m .71048 .77836 L .68343 .77906 L p .707 .577 .707 r
F P
0 g
s
.68343 .77906 m .68639 .79765 L .71345 .79695 L p .707 .577 .707 r
F P
0 g
s
.8018 .76277 m .80477 .78136 L .82864 .77336 L p .707 .577 .707 r
F P
0 g
s
.82864 .77336 m .82567 .75478 L .8018 .76277 L p .707 .577 .707 r
F P
0 g
s
.6431 .60098 m .63585 .63649 L .64801 .64874 L p .707 .577 .707 r
F P
0 g
s
.65291 .58804 m .63973 .6405 L .65167 .65367 L p .707 .577 .707 r
F P
0 g
s
.68639 .79765 m .68343 .77906 L .66274 .7772 L p .707 .577 .707 r
F P
0 g
s
.63973 .6405 m .65291 .58804 L .65043 .5761 L p .707 .577 .707 r
F P
0 g
s
.84155 .63476 m .82836 .68722 L .83559 .67768 L p .707 .577 .707 r
F P
0 g
s
.83559 .67768 m .84878 .62523 L .84155 .63476 L p .707 .577 .707 r
F P
0 g
s
.66274 .7772 m .66571 .79579 L .68639 .79765 L p .707 .577 .707 r
F P
0 g
s
.82567 .75478 m .82864 .77336 L .84494 .76519 L p .707 .577 .707 r
F P
0 g
s
.84494 .76519 m .84198 .7466 L .82567 .75478 L p .707 .577 .707 r
F P
0 g
s
.83345 .64019 m .8262 .6757 L .83338 .66637 L p .707 .577 .707 r
F P
0 g
s
.83338 .66637 m .84063 .63086 L .83345 .64019 L p .707 .577 .707 r
F P
0 g
s
.63585 .63649 m .6431 .60098 L .64048 .58963 L p .707 .577 .707 r
F P
0 g
s
.65043 .5761 m .63724 .62856 L .63973 .6405 L p .707 .577 .707 r
F P
0 g
s
.64048 .58963 m .63323 .62514 L .63585 .63649 L p .707 .577 .707 r
F P
0 g
s
.66571 .79579 m .66274 .7772 L .65044 .77297 L p .707 .577 .707 r
F P
0 g
s
.65044 .77297 m .6534 .79156 L .66571 .79579 L p .707 .577 .707 r
F P
0 g
s
.63724 .62856 m .65043 .5761 L .65766 .56657 L p .707 .577 .707 r
F P
0 g
s
.84063 .63086 m .83338 .66637 L .83076 .65502 L p .707 .577 .707 r
F P
0 g
s
.84878 .62523 m .83559 .67768 L .83311 .66574 L p .707 .577 .707 r
F P
0 g
s
.83311 .66574 m .84629 .61329 L .84878 .62523 L p .707 .577 .707 r
F P
0 g
s
.84198 .7466 m .84494 .76519 L .85209 .75763 L p .707 .577 .707 r
F P
0 g
s
.85209 .75763 m .84912 .73904 L .84198 .7466 L p .707 .577 .707 r
F P
0 g
s
.83076 .65502 m .83801 .61951 L .84063 .63086 L p .707 .577 .707 r
F P
0 g
s
.63323 .62514 m .64048 .58963 L .64766 .5803 L p .707 .577 .707 r
F P
0 g
s
.65766 .56657 m .64447 .61903 L .63724 .62856 L p .707 .577 .707 r
F P
0 g
s
.64766 .5803 m .64041 .61581 L .63323 .62514 L p .707 .577 .707 r
F P
0 g
s
.6534 .79156 m .65044 .77297 L .64773 .76677 L p .707 .577 .707 r
F P
0 g
s
.38573 .60251 m .39892 .55005 L .36865 .54076 L p .707 .577 .707 r
F P
0 g
s
.39892 .55005 m .38573 .60251 L .41675 .6084 L p .707 .577 .707 r
F P
0 g
s
.41675 .6084 m .42994 .55594 L .39892 .55005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64773 .76677 m .6507 .78535 L .6534 .79156 L p .707 .577 .707 r
F P
0 g
s
.35546 .59322 m .36865 .54076 L .34209 .52898 L p .707 .577 .707 r
F P
0 g
s
.36865 .54076 m .35546 .59322 L .38573 .60251 L p .707 .577 .707 r
F P
0 g
s
.42994 .55594 m .41675 .6084 L .44549 .61031 L p .707 .577 .707 r
F P
0 g
s
.44549 .61031 m .45868 .55785 L .42994 .55594 L p .707 .577 .707 r
F P
0 g
s
.64447 .61903 m .65766 .56657 L .67388 .56037 L p .707 .577 .707 r
F P
0 g
s
.83801 .61951 m .83076 .65502 L .81861 .64276 L p .707 .577 .707 r
F P
0 g
s
.84629 .61329 m .83311 .66574 L .82116 .65257 L p .707 .577 .707 r
F P
0 g
s
.81861 .64276 m .82585 .60725 L .83801 .61951 L p .707 .577 .707 r
F P
0 g
s
.82116 .65257 m .83435 .60011 L .84629 .61329 L p .707 .577 .707 r
F P
0 g
s
.84912 .73904 m .85209 .75763 L .84938 .75143 L p .707 .577 .707 r
F P
0 g
s
.84938 .75143 m .84641 .73284 L .84912 .73904 L p .707 .577 .707 r
F P
0 g
s
.64041 .61581 m .64766 .5803 L .66393 .5739 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.3289 .58144 m .34209 .52898 L .32185 .51586 L p .707 .577 .707 r
F P
0 g
s
.34209 .52898 m .3289 .58144 L .35546 .59322 L p .707 .577 .707 r
F P
0 g
s
.45868 .55785 m .44549 .61031 L .46913 .60806 L p .707 .577 .707 r
F P
0 g
s
.46913 .60806 m .48231 .5556 L .45868 .55785 L p .707 .577 .707 r
F P
0 g
s
.67388 .56037 m .6607 .61283 L .64447 .61903 L p .707 .577 .707 r
F P
0 g
s
.66393 .5739 m .65669 .6094 L .64041 .61581 L p .707 .577 .707 r
F P
0 g
s
.6507 .78535 m .64773 .76677 L .65488 .75921 L p .707 .577 .707 r
F P
0 g
s
.4012 .68072 m .39824 .66213 L .36747 .66532 L p .707 .577 .707 r
F P
0 g
s
.39824 .66213 m .4012 .68072 L .43267 .67534 L p .707 .577 .707 r
F P
0 g
s
.43267 .67534 m .4297 .65675 L .39824 .66213 L p .707 .577 .707 r
F P
0 g
s
.6607 .61283 m .67388 .56037 L .69752 .55812 L p .707 .577 .707 r
F P
0 g
s
.4297 .65675 m .43267 .67534 L .46176 .66832 L p .707 .577 .707 r
F P
0 g
s
.46176 .66832 m .45879 .64973 L .4297 .65675 L p .707 .577 .707 r
F P
0 g
s
.82585 .60725 m .81861 .64276 L .7981 .6308 L p .707 .577 .707 r
F P
0 g
s
.83435 .60011 m .82116 .65257 L .80092 .63945 L p .707 .577 .707 r
F P
0 g
s
.7981 .6308 m .80535 .59529 L .82585 .60725 L p .707 .577 .707 r
F P
0 g
s
.80092 .63945 m .81411 .58699 L .83435 .60011 L p .707 .577 .707 r
F P
0 g
s
.65488 .75921 m .65784 .7778 L .6507 .78535 L p .707 .577 .707 r
F P
0 g
s
.36747 .66532 m .37044 .68391 L .4012 .68072 L p .707 .577 .707 r
F P
0 g
s
.32185 .51586 m .30866 .56832 L .3289 .58144 L p .707 .577 .707 r
F P
0 g
s
.30866 .56832 m .32185 .51586 L .3099 .50269 L p .707 .577 .707 r
F P
0 g
s
.37044 .68391 m .36747 .66532 L .34042 .66602 L p .707 .577 .707 r
F P
0 g
s
.48231 .5556 m .46913 .60806 L .48535 .60186 L p .707 .577 .707 r
F P
0 g
s
.48535 .60186 m .49854 .5494 L .48231 .5556 L p .707 .577 .707 r
F P
0 g
s
.65669 .6094 m .66393 .5739 L .68771 .57106 L p .707 .577 .707 r
F P
0 g
s
.84641 .73284 m .84938 .75143 L .83708 .74719 L p .707 .577 .707 r
F P
0 g
s
.83708 .74719 m .83411 .72861 L .84641 .73284 L p .707 .577 .707 r
F P
0 g
s
.35235 .72159 m .3596 .68608 L .33275 .67558 L p .707 .577 .707 r
F P
0 g
s
.34042 .66602 m .34338 .68461 L .37044 .68391 L p .707 .577 .707 r
F P
0 g
s
.38291 .72959 m .39016 .69409 L .3596 .68608 L p .707 .577 .707 r
F P
0 g
s
.39016 .69409 m .38291 .72959 L .4142 .73433 L p .707 .577 .707 r
F P
0 g
s
.4142 .73433 m .42144 .69882 L .39016 .69409 L p .707 .577 .707 r
F P
0 g
s
.45879 .64973 m .46176 .66832 L .48563 .66033 L p .707 .577 .707 r
F P
0 g
s
.48563 .66033 m .48266 .64174 L .45879 .64973 L p .707 .577 .707 r
F P
0 g
s
.42144 .69882 m .4142 .73433 L .44314 .73532 L p .707 .577 .707 r
F P
0 g
s
.44314 .73532 m .45039 .69981 L .42144 .69882 L p .707 .577 .707 r
F P
0 g
s
.3596 .68608 m .35235 .72159 L .38291 .72959 L p .707 .577 .707 r
F P
0 g
s
.69752 .55812 m .68433 .61058 L .6607 .61283 L p .707 .577 .707 r
F P
0 g
s
.68771 .57106 m .68046 .60656 L .65669 .6094 L p .707 .577 .707 r
F P
0 g
s
.68433 .61058 m .69752 .55812 L .72626 .56003 L p .707 .577 .707 r
F P
0 g
s
.80535 .59529 m .7981 .6308 L .7734 .62114 L p .707 .577 .707 r
F P
0 g
s
.77208 .62697 m .74409 .61838 L p .78271 .58002 L .707 .577 .707 r
F P
0 g
s
.7734 .62114 m .77125 .6203 L p .77405 .61824 L .707 .577 .707 r
F P
0 g
s
.77405 .61824 m .80535 .59529 L .7734 .62114 L .707 .577 .707 r
F
.77125 .6203 m .7785 .58479 L .80535 .59529 L p F P
0 g
s
.78755 .57521 m .77436 .62767 L .77208 .62697 L p .707 .577 .707 r
F P
0 g
s
.78271 .58002 m .78755 .57521 L .77208 .62697 L .707 .577 .707 r
F
.81411 .58699 m .80092 .63945 L .77436 .62767 L p F P
0 g
s
.77436 .62767 m .78755 .57521 L .81411 .58699 L p .707 .577 .707 r
F P
0 g
s
.34338 .68461 m .34042 .66602 L .31973 .66417 L p .707 .577 .707 r
F P
0 g
s
.3099 .50269 m .29672 .55514 L .30866 .56832 L p .707 .577 .707 r
F P
0 g
s
.33275 .67558 m .3255 .71109 L .35235 .72159 L p .707 .577 .707 r
F P
0 g
s
.3255 .71109 m .33275 .67558 L .31224 .66362 L p .707 .577 .707 r
F P
0 g
s
.31973 .66417 m .3227 .68275 L .34338 .68461 L p .707 .577 .707 r
F P
0 g
s
.65784 .7778 m .65488 .75921 L .67118 .75103 L p .707 .577 .707 r
F P
0 g
s
.72626 .56003 m .71307 .61249 L .68433 .61058 L p .707 .577 .707 r
F P
0 g
s
.68046 .60656 m .68771 .57106 L .71665 .57205 L p .707 .577 .707 r
F P
0 g
s
.45039 .69981 m .44314 .73532 L .46691 .73248 L p .707 .577 .707 r
F P
0 g
s
.46691 .73248 m .47416 .69697 L .45039 .69981 L p .707 .577 .707 r
F P
0 g
s
.48266 .64174 m .48563 .66033 L .50193 .65215 L p .707 .577 .707 r
F P
0 g
s
.50193 .65215 m .49897 .63356 L .48266 .64174 L p .707 .577 .707 r
F P
0 g
s
.67118 .75103 m .67415 .76962 L .65784 .7778 L p .707 .577 .707 r
F P
0 g
s
.29672 .55514 m .3099 .50269 L .30742 .49075 L p .707 .577 .707 r
F P
0 g
s
.49854 .5494 m .48535 .60186 L .49258 .59233 L p .707 .577 .707 r
F P
0 g
s
.49258 .59233 m .50577 .53987 L .49854 .5494 L p .707 .577 .707 r
F P
0 g
s
.71307 .61249 m .72626 .56003 L .75728 .56592 L p .707 .577 .707 r
F P
0 g
s
.74409 .61838 m .75728 .56592 L .78755 .57521 L p .707 .577 .707 r
F P
0 g
s
.83411 .72861 m .83708 .74719 L .81639 .74534 L p .707 .577 .707 r
F P
0 g
s
.81639 .74534 m .81342 .72675 L .83411 .72861 L p .707 .577 .707 r
F P
0 g
s
.75728 .56592 m .74409 .61838 L .71307 .61249 L p .707 .577 .707 r
F P
0 g
s
.71665 .57205 m .7094 .60756 L .68046 .60656 L p .707 .577 .707 r
F P
0 g
s
.7785 .58479 m .77125 .6203 L .74069 .61229 L p .707 .577 .707 r
F P
0 g
s
.74069 .61229 m .74794 .57678 L .7785 .58479 L p .707 .577 .707 r
F P
0 g
s
.7094 .60756 m .71665 .57205 L .74794 .57678 L p .707 .577 .707 r
F P
0 g
s
.31224 .66362 m .305 .69912 L .3255 .71109 L p .707 .577 .707 r
F P
0 g
s
.74794 .57678 m .74069 .61229 L .7094 .60756 L p .707 .577 .707 r
F P
0 g
s
.305 .69912 m .31224 .66362 L .30009 .65136 L p .707 .577 .707 r
F P
0 g
s
.3227 .68275 m .31973 .66417 L .30743 .65993 L p .707 .577 .707 r
F P
0 g
s
.47416 .69697 m .46691 .73248 L .48319 .72608 L p .707 .577 .707 r
F P
0 g
s
.48319 .72608 m .49044 .69057 L .47416 .69697 L p .707 .577 .707 r
F P
0 g
s
.30743 .65993 m .31039 .67852 L .3227 .68275 L p .707 .577 .707 r
F P
0 g
s
.30742 .49075 m .29423 .5432 L .29672 .55514 L p .707 .577 .707 r
F P
0 g
s
.67415 .76962 m .67118 .75103 L .69505 .74304 L p .707 .577 .707 r
F P
0 g
s
.49897 .63356 m .50193 .65215 L .50908 .64459 L p .707 .577 .707 r
F P
0 g
s
.50908 .64459 m .50611 .62601 L .49897 .63356 L p .707 .577 .707 r
F P
0 g
s
.69505 .74304 m .69801 .76163 L .67415 .76962 L p .707 .577 .707 r
F P
0 g
s
.81342 .72675 m .81639 .74534 L .78934 .74604 L p .707 .577 .707 r
F P
0 g
s
.78934 .74604 m .78637 .72745 L .81342 .72675 L p .707 .577 .707 r
F P
0 g
s
.29423 .5432 m .30742 .49075 L .31465 .48121 L p .707 .577 .707 r
F P
0 g
s
.50577 .53987 m .49258 .59233 L .4901 .58039 L p .707 .577 .707 r
F P
0 g
s
.4901 .58039 m .50328 .52793 L .50577 .53987 L p .707 .577 .707 r
F P
0 g
s
.30009 .65136 m .29284 .68687 L .305 .69912 L p .707 .577 .707 r
F P
0 g
s
.69801 .76163 m .69505 .74304 L .72414 .73602 L p .707 .577 .707 r
F P
0 g
s
.49044 .69057 m .48319 .72608 L .49037 .71675 L p .707 .577 .707 r
F P
0 g
s
.49037 .71675 m .49762 .68124 L .49044 .69057 L p .707 .577 .707 r
F P
0 g
s
.31039 .67852 m .30743 .65993 L .30472 .65373 L p .707 .577 .707 r
F P
0 g
s
.72414 .73602 m .7271 .75461 L .69801 .76163 L p .707 .577 .707 r
F P
0 g
s
.29284 .68687 m .30009 .65136 L .29747 .64001 L p .707 .577 .707 r
F P
0 g
s
.78637 .72745 m .78934 .74604 L .75857 .74923 L p .707 .577 .707 r
F P
0 g
s
.75857 .74923 m .75561 .73064 L .78637 .72745 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30472 .65373 m .30768 .67232 L .31039 .67852 L p .707 .577 .707 r
F P
0 g
s
.31465 .48121 m .30146 .53367 L .29423 .5432 L p .707 .577 .707 r
F P
0 g
s
.7271 .75461 m .72414 .73602 L .75561 .73064 L p .707 .577 .707 r
F P
0 g
s
.75561 .73064 m .75857 .74923 L .7271 .75461 L p .707 .577 .707 r
F P
0 g
s
.50611 .62601 m .50908 .64459 L .50637 .63839 L p .707 .577 .707 r
F P
0 g
s
.50637 .63839 m .5034 .6198 L .50611 .62601 L p .707 .577 .707 r
F P
0 g
s
.29747 .64001 m .29022 .67552 L .29284 .68687 L p .707 .577 .707 r
F P
0 g
s
.30146 .53367 m .31465 .48121 L .33087 .47501 L p .707 .577 .707 r
F P
0 g
s
.50328 .52793 m .4901 .58039 L .47815 .56721 L p .707 .577 .707 r
F P
0 g
s
.47815 .56721 m .49134 .51476 L .50328 .52793 L p .707 .577 .707 r
F P
0 g
s
.49762 .68124 m .49037 .71675 L .48775 .7054 L p .707 .577 .707 r
F P
0 g
s
.48775 .7054 m .495 .66989 L .49762 .68124 L p .707 .577 .707 r
F P
0 g
s
.29022 .67552 m .29747 .64001 L .30465 .63068 L p .707 .577 .707 r
F P
0 g
s
.30768 .67232 m .30472 .65373 L .31187 .64617 L p .707 .577 .707 r
F P
0 g
s
.33087 .47501 m .31769 .52747 L .30146 .53367 L p .707 .577 .707 r
F P
0 g
s
.31187 .64617 m .31483 .66476 L .30768 .67232 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31769 .52747 m .33087 .47501 L .35451 .47276 L p .707 .577 .707 r
F P
0 g
s
.5034 .6198 m .50637 .63839 L .49407 .63416 L p .707 .577 .707 r
F P
0 g
s
.49407 .63416 m .4911 .61557 L .5034 .6198 L p .707 .577 .707 r
F P
0 g
s
.49134 .51476 m .47815 .56721 L .45791 .55409 L p .707 .577 .707 r
F P
0 g
s
.45791 .55409 m .4711 .50163 L .49134 .51476 L p .707 .577 .707 r
F P
0 g
s
.30465 .63068 m .2974 .66618 L .29022 .67552 L p .707 .577 .707 r
F P
0 g
s
.495 .66989 m .48775 .7054 L .4756 .69314 L p .707 .577 .707 r
F P
0 g
s
.4756 .69314 m .48284 .65763 L .495 .66989 L p .707 .577 .707 r
F P
0 g
s
.2974 .66618 m .30465 .63068 L .32092 .62428 L p .707 .577 .707 r
F P
0 g
s
.35451 .47276 m .34132 .52522 L .31769 .52747 L p .707 .577 .707 r
F P
0 g
s
.31483 .66476 m .31187 .64617 L .32817 .638 L p .707 .577 .707 r
F P
0 g
s
.34132 .52522 m .35451 .47276 L .38325 .47467 L p .707 .577 .707 r
F P
0 g
s
.4711 .50163 m .45791 .55409 L .43135 .54231 L p .707 .577 .707 r
F P
0 g
s
.43135 .54231 m .44454 .48985 L .4711 .50163 L p .707 .577 .707 r
F P
0 g
s
.32817 .638 m .33114 .65658 L .31483 .66476 L p .707 .577 .707 r
F P
0 g
s
.4911 .61557 m .49407 .63416 L .47338 .6323 L p .707 .577 .707 r
F P
0 g
s
.47338 .6323 m .47041 .61371 L .4911 .61557 L p .707 .577 .707 r
F P
0 g
s
.32092 .62428 m .31368 .65978 L .2974 .66618 L p .707 .577 .707 r
F P
0 g
s
.37006 .52713 m .38325 .47467 L .41427 .48056 L p .707 .577 .707 r
F P
0 g
s
.38325 .47467 m .37006 .52713 L .34132 .52522 L p .707 .577 .707 r
F P
0 g
s
.44454 .48985 m .43135 .54231 L .40108 .53302 L p .707 .577 .707 r
F P
0 g
s
.40108 .53302 m .41427 .48056 L .44454 .48985 L p .707 .577 .707 r
F P
0 g
s
.41427 .48056 m .40108 .53302 L .37006 .52713 L p .707 .577 .707 r
F P
0 g
s
.48284 .65763 m .4756 .69314 L .45509 .68118 L p .707 .577 .707 r
F P
0 g
s
.45509 .68118 m .46234 .64567 L .48284 .65763 L p .707 .577 .707 r
F P
0 g
s
.33114 .65658 m .32817 .638 L .35204 .63 L p .707 .577 .707 r
F P
0 g
s
.31368 .65978 m .32092 .62428 L .3447 .62144 L p .707 .577 .707 r
F P
0 g
s
.35204 .63 m .355 .64859 L .33114 .65658 L p .707 .577 .707 r
F P
0 g
s
.47041 .61371 m .47338 .6323 L .44633 .633 L p .707 .577 .707 r
F P
0 g
s
.44633 .633 m .44336 .61441 L .47041 .61371 L p .707 .577 .707 r
F P
0 g
s
.3447 .62144 m .33745 .65694 L .31368 .65978 L p .707 .577 .707 r
F P
0 g
s
.355 .64859 m .35204 .63 L .38113 .62298 L p .707 .577 .707 r
F P
0 g
s
.46234 .64567 m .45509 .68118 L .42824 .67068 L p .707 .577 .707 r
F P
0 g
s
.42824 .67068 m .43549 .63517 L .46234 .64567 L p .707 .577 .707 r
F P
0 g
s
.33745 .65694 m .3447 .62144 L .37364 .62243 L p .707 .577 .707 r
F P
0 g
s
.38113 .62298 m .38409 .64157 L .355 .64859 L p .707 .577 .707 r
F P
0 g
s
.44336 .61441 m .44633 .633 L .41556 .63619 L p .707 .577 .707 r
F P
0 g
s
.41556 .63619 m .4126 .6176 L .44336 .61441 L p .707 .577 .707 r
F P
0 g
s
.38409 .64157 m .38113 .62298 L .4126 .6176 L p .707 .577 .707 r
F P
0 g
s
.4126 .6176 m .41556 .63619 L .38409 .64157 L p .707 .577 .707 r
F P
0 g
s
.37364 .62243 m .36639 .65794 L .33745 .65694 L p .707 .577 .707 r
F P
0 g
s
.43549 .63517 m .42824 .67068 L .39768 .66267 L p .707 .577 .707 r
F P
0 g
s
.39768 .66267 m .40493 .62716 L .43549 .63517 L p .707 .577 .707 r
F P
0 g
s
.36639 .65794 m .37364 .62243 L .40493 .62716 L p .707 .577 .707 r
F P
0 g
s
.40493 .62716 m .39768 .66267 L .36639 .65794 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001eOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001iOol0
079oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007Ao
o`00Kgoo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01000L7oo001/Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH3001]Ool006Yoo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006]oo`00
J7oo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P00JGoo001VOol20005FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00Oomoo`1VOol006Eoo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001oogoo06Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH005YF00EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00Hgoo0P0000=JEP00FUH01EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006=oo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Hgoo0P0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00Igoo001SOol20000
0eYF001JEP05FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`800003FUH0000000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Moo`00Hgoo0P0000=JEP0000001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00Igoo001SOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001WOol006=oo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Mo
o`00Hgoo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001S
Ool200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006=oo`80
0003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo0P0000=J
EP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001SOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006=oo`80009JEP03001J
EUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo0P000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001SOol20002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol006=oo`80009JEP03001JEUYF
00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Hgoo0P000UYF00<005YFFUH0
0eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF0000IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001ROol60005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005aoo`H0009JEP04001JEUYFFUH9
0006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Uoo`<0009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF009JEPL000]JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00F7oo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00000P002EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo001HOol00`00FUIJ
EP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP02FUH30006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001VOol005Moo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Ioo`00Egoo0P0015YF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00H005YF000005YF000;FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009J
EP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Ioo`00EWoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH015YF0P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF0000IWoo001FOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Ioo`8000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
0007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Eoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF0000IWoo001EOol20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001J
EP0006Ioo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH0001VOol005Eoo`03FUH005YF00=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH2001VOol005Aoo`03001JEP0000=JEP04001JEUYFFUH>0006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Ioo`00E7oo0P000UYF1P000eYF0P0000Eoo`00FUIJEP0000AJEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo00AJEP000000009JEP03001J
EUYF00AJEP04001JEP000002FUH00`00FUIJEP04FUH00`00FUH000030007FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF009JEP<000IJEP03001JEUYF
00=JEP8000EJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Dgoo0`000eYF00<005YFFUH015YF00<0
05YFFUH015YF0`0015YF00<005YFFUH01EYF0`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YF
FUH00UYF0`002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001COol0
0`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUH0000200000eYF001JEP07FUH0
0`00FUH000020007FUH00`00FUIJEP03FUH00`00FUIJEP02FUH3000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03001J
EUYF009JEP<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00E7oo
00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJEP@000=JEP03001JEUYF00AJEP<0
0003FUH005YF00AJEP03001JEUYF009JEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00E7oo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00@000UJEP8000EJEP03001JEUYF009JEP800003FUH005YF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo00@005YFFUH000IJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP`000AJEP03001JEUYF009JEP800003FUH005YF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000aoo`L005=oo`00EGoo00@0
05YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00EJEP<000QJEP03001JEUYF00EJEP04001JEP00
0002FUH00`00FUIJEP02FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH20007Ool50003FUH01000FUIJEUYF2@00BWoo000kOol6000EOol00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
1@00FUH005YF00002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Goo0P00
00=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1P00A7oo000fOol50002FUH01000FUIJ
EUYF2@003Goo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P000goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00@005YF0000049oo`00=7oo0P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF1P0027oo0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF1@001UYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009oo`8000=JEP03001JEP0000d000QJEP03001JEUYF009JEP<003mo
o`00<Woo0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00
1goo00D005YFFUIJEP0000MJEP03001JEUYF00IJEP<000MJEP03001JEUYF00EJEP03001JEUYF00AJ
EP80009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP800005Ool005YF001JEP040003FUH00`00FUIJEP05FUH00`00FUIJEP040004FUH00`00FUIJEP05
FUH3000lOol0035oo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001J
EUYF009JEP<000Eoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00800005FUH005YFFUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000goo000000030006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH0
1000FUH00000>Woo000`Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH30004Ool20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003Ool00000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00@000AJEP04001JEUYFFUH3000gOol0031oo`8000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP000004Ool20004FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP030003
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40002FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40007FUH2000eOol002mo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF009JEP8000Aoo`<00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP07001JEUYFFUH005YF00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00MJEP8000QJEP<003=oo`00;goo00<005YF00000eYF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0P001Goo0`001eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20007FUH01@00FUIJEUYF0000<Woo000_Ool2
0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH30003Ool200000eYF00000005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00001eYF00<005YFFUH00UYF0P00<7oo000_Ool20004FUH00`00FUIJEP03FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000Woo
0P0000=JEP00FUH00`0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH0
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
00001eYF00<005YFFUH015YF00<007ooOol0;Goo000^Ool00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH4
00000eYF001JEP03FUH40007FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020006FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00002FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20008FUH00`00FUIJ
EP04FUH2000^Ool002ioo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP800003FUH005YF00EJEP03001JEP0000<0
009JEP03001JEUYF00EJEP04001JEUYFFUH60008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01@00FUIJEUYF00000UYF00@005YFFUH000=JEPh000IJEP03001JEUYF00MJEP8000MJ
EP03001JEUYF00AJEP03001JEP0002ioo`00;Woo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P0000=JEP00FUH0
1EYF00<005YFFUH00eYF3P0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00L005YFFUIJEP00FUH00003FUH400000eYF000000050004FUH00`00FUH000030002FUH0
0`00FUIJEP07FUH20007FUH00`00FUIJEP04FUH01000FUIJEP00;Goo000^Ool20004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH300000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP0>0008FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH02000FUIJEUYF001JEP00FUH200000eYF000000020003FUH2
0002Ool900000eYF000000030006FUH00`00FUH00007FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
;7oo000]Ool00`00FUH00003FUH01000FUIJEUYF1`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH00UYF1`0015YF00<0
05YFFUH015YF00<005YFFUH01@000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00eYF0P0000AJEP00000000IJEP04001JEP000009Ool:0002FUH00`00FUH00007FUH0
0`00FUIJEP04FUH01@00FUIJEUYF0000;7oo000]Ool20002FUH60003FUH20002Ool90004FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP0700000eYF001JEP05FUH50002FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUH00003000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP0300000eYF00000002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000=Ool2
0002FUH40007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0002]oo`00;Goo10000UYF00<005YF
FUH015YF00@005YF000000Uoo`H000MJEP03001JEUYF00=JEPD0009JEP03001JEUYF009JEPT000IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH2000<FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH01@00FUIJEP00FUH00P0015YF00<005YFFUH00eYF00<005YFFUH015YF
0P003Goo0`000UYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000[Ool002eo
o`03001JEP00009JEP03001JEUYF00AJEP03001JEUYF009JEP8000eoo`8000EJEP04001JEUYFFUH2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH600000eYF001JEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00
FUIJEP00FUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF0P003Woo10001UYF00<005YFFUH0
15YF00L005YFFUIJEP00FUH0000[Ool002aoo`<000=JEP03001JEUYF00AJEP03001JEUYF00AJEP<0
00aoo`<00004FUH005YFFUH20003FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUH000030005FUH00`00FUIJEP02FUH60003FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH01@00FUIJEP00FUH00P000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
00000`003Woo0P0015YF00<005YFFUH015YF00H005YFFUIJEP00FUH/Ool002aoo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEP00008000aoo`D000=JEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEPX00003FUH005YF00=JEPD00003FUH00000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30003FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH5000;Ool200000eYF001JEP05FUH01`00FUIJEUYF001JEP0002ao
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF0`0037oo
0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
000000EJEP03001JEUYF00AJEPH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2
0004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20006
FUH01`00FUIJEUYF001JEP0002aoo`00;7oo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF10001goo0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP<0009JEP04001JEUYFFUH30002FUH01000FUH0000035YF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01eYF100015YF00<005YFFUH015YF3@0015YF00L005YFFUIJEP00FUH0000/Ool002eo
o`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040003Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH600000eYF001JEP03FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP0;FUH70006FUH00`00FUIJEP05FUH01000FUH0
00000eYF00@005YFFUIJEP8002eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEPD000AJEP03001JEUYF009JEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP<000=JEP03001JEUYF009JEP<000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEPD000EJEP03001JEUYF00iJEP03001JEUYF009JEQ00009J
EP<000=JEP03001JEP0002eoo`00;Woo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00EJ
EP<000QJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00EJEP03001JEUYF00IJEP04001JEUYF0003FUH01`00FUIJEUYF001JEP0000aJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`03001JEUYF00=JEP03001JEUYF00iJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP8000=JEP03001JEP0002eoo`00;goo00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@001UYF0P0000=JEP00FUH00UYF00@005YF
FUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80
0003FUH005YF0080009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8000=oo`03001JEUYF009JEP03001JEUYF00eJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUH0000]Ool0031oo`03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00EJEPD000IJEP<000=JEPH0009JEP04001JEUYFFUH90004FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20004Ool200000eYF0000000?FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH01000FUIJEP000UYF0P00;Woo000aOol20004FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH50006FUH3000015YF000005YF100015YF00<005YFFUH00P000UYF00<005YFFUH0
0UYF1P001UYF00<005YFFUH01UYF00<005YFFUH015YF0P001EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001Goo0P0045YF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP800003FUH007oo02eoo`00<goo00D005YFFUIJ
EP0000MJEP03001JEUYF00IJEP<000MJEP07001JEP00001JEP00FUH00P000UYF400015YF00<005YF
00000`000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000015YF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000Eoo`8000mJEP03001JEP00
008000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH200000eYF001oo`0]Ool003Ao
o`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00=JEP@000MJEP03001JEUYF00=JEP05001JEUYFFUH00003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00003
0005Ool2000=FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0300000eYF001o
o`0]Ool003Ioo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP@0009JEP800003FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP<000AJEP03001JEUYF00AJEP05001J
EUYFFUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUH000000UYF0P001Goo0P000UYF0P001UYF00<005YF000010000eYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUIJEP@002moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF
0P0000AJEP00FUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF009JEPT00003FUH005YF00EJEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH20005Ool80002FUH00`00FUH00004
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0200000eYF0000000_Ool003Yoo`<0
0003FUH005YF00MJEP03001JEUYF00MJEP8000AJEP03001JEP00008000EJEP03001JEUYF00EJEP03
001JEUYF009JEPT00003FUH005YF00IJEP8000IJEP06001JEUYF001JEP000UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF0P001goo0`0000=J
EP0000001P000eYF00<005YFFUH01EYF00@005YFFUIJEPH000=JEP03001oogoo02ioo`00?Goo0`00
1eYF00<005YFFUH01UYF00@005YFFUH000=JEP04001JEUYFFUHH0005FUH00`00FUIJEP07FUH20004
FUH01P00FUIJEP00FUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000QJEP<000Qoo`<00003FUH005YF009JEQ0000AJEP04001JEUYFFUH2000`
Ool0041oo`8000EJEP03001JEUYF00IJEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH40005FUH50005FUH00`00FUIJEP09FUH01000FUIJEP000eYF00<005YF00000UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00@005YFFUIJ
EP8000Uoo`<000MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080035oo`00@Woo0`00
00=JEP00FUH025YF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP06FUH00`00FUH000030002FUH5
0005FUH00`00FUIJEP09FUH40003FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJEP03FUH2000:Ool40002FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUH00000<goo0015Ool40007FUH00`00FUIJEP02FUH20006FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH70005FUH00`00FUIJEP09FUH01000FUIJEP000eYF0P000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF
00<005YFFUH015YF0P003Goo4`00=Goo0019Ool40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90008FUH5000015YF001JEP000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<0
05YFFUH00eYF00<005YF0000EGoo001=Ool<0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP0200000eYF001JEP02FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00006FUH00`00FUIJEP04
FUH01000FUIJEP00E7oo001COol70002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05
001JEUYFFUH0001COol004aoo`L000AJEP03001JEUYF00<000QJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000IJEP03001JEUYF00AJEP05
001JEUYFFUH0001COol003Qoo`L000Uoo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8000MJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009J
EP8000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000IJEP03001JEUYF00=JEP07001JEUYFFUH005YF0000DWoo000cOol50002FUH00`00FUIJEP02
FUH90006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP04FUH01`00
FUIJEUYF001JEP0000Ioo`<004Uoo`00<Goo0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YF
FUH00UYF1`0025YF00<005YFFUH01EYF100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP07001JEUYFFUH005YF0000
1Goo1@00B7oo000_Ool20003FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUH000030005FUH00`00FUIJEP02FUH6000015YF000000001UYF00<005YFFUH01eYF00<005YFFUH0
1EYF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00AJEP06001JEUYFFUH005YF1Woo
1@00B7oo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH:0006Ool80002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P000eYF00<005YFFUH00eYF00L005YFFUIJEP00FUH00006Ool50006Ool?000cOol002io
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001J
EP00000<Ool20002FUH00`00FUH000060004FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUH0
000025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000Woo0`001UYF00L005YFFUIJEP00FUH00007Ool:0004FUH00`00FUIJEP05FUH00`00FUIJEP05
000^Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP04001JEUYFFUH30006Ool300001EYF001JEUYF00001EYF00<005YFFUH0200015YF00@005YF
FUIJEPD000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0000Aoo`03001JEUYF00AJEP07001JEUYFFUH005YF00001Woo10000UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000002aoo`00;Goo0P0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF1P0000EJEP00FUIJ
EP00009JEP03001JEUYF00=JEP03001JEUYF00MJEPT000=JEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000L000AJEP04001JEUYF
FUH20003Ool40006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP00
;7oo000]Ool20004FUH00`00FUIJEP02FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH30003FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00002@0000=JEP00FUH00UYF00<005YF00000`0000=JEP00FUH01eYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P00:goo000/Ool00`00FUH0
0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH01000FUIJEP000eYF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH015YF30001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00000UYF00<005YFFUH015YF0P0000=JEP0000000P001EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF1P000UYF00D005YFFUIJEP0002]oo`00;7oo00<005YF00000eYF00@0
05YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP800004FUH005YF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH=000;FUH9
0008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH400000eYF
001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006Ool40002FUH00`00Oomoo`0YOol002ao
o`8000=JEPH000Ioo`T000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009J
EP03001JEUYF00=JEP03001JEUYF00IJEPP000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009J
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00004FUH20005FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH9000@Ool200000eYF00000002000ZOol002aoo`800004FUH00000FUH3000AOol6
0006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200001Goo001JEUYF00001EYF00<005YFFUH00eYF
0`001eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH010001UYF00<0
05YFFUH00UYF00D005YF001JEP00009JEP<000MJEP03001JEUYF00AJEPH001Ioo`<000=JEP04001J
EP00000ZOol002aoo`06FUH00000FUH005YF500015YF00<005YF00000`000UYF00<005YFFUH01UYF
00<005YFFUH015YF00@005YF0000009JEP03001JEUYF00=JEP03001JEP0000<000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00AJEP@0009JEP03001JEUYF009JEP04
001JEP00FUH30002FUH00`00FUIJEP05FUH00`00FUIJEP04000HOol400000eYF001JEP04FUH00`00
FUH0000ZOol002]oo`<0009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00=JEP@000MJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH20003
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH40004FUH01000FUH005YF0P0015YF00<005YFFUH00eYF10006Goo0`001EYF00<005YFFUH00eYF
0P00:goo000[Ool30002FUH200001EYF001JEUYF00000UYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00D005YFFUIJEP00009JEP04001JEUYFFUH20005
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH01000FUIJEUYF0P000UYF00@005YF001JEP8000AJEP03001JEP0000D001Moo`@00003FUH005YF
00IJEP04001JEUYFFUH2000/Ool002]oo`03001JEP00009JEP80009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPT00003FUH005YF00EJEP05001JEUYFFUH00002
FUH01000FUH000001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01eYF00<005YFFUH00eYF0`0000EJEP00001JEP0000AJEP80009JEP04001JEP00
000BOol50005FUH00`00FUIJEP05FUH01000FUH00000;Woo000[Ool00`00FUIJEP02FUH300000eYF
001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH90009Ool20006FUH00`00FUIJEP020002FUH2
00000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200001EYF000005YF00000UYF0`0000=JEP0000000UYF
00<007ooOol03Goo10000UYF00<005YFFUH01EYF00<005YFFUH015YF0`00<7oo000/Ool01@00FUIJ
EUYF00000UYF6@003goo0P0015YF00<005YFFUH00P0000=JEP00FUH00UYF00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<0
05YFFUH015YF0P0000AJEP00001JEPL000=JEP8000Qoo`L000IJEP03001JEUYF00IJEP04001JEUYF
FUH2000cOol002aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH30006Ool5000AOol01000FUIJ
EP000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YF00000P0000=JEP0000004P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Eoo`00;Goo00<005YF00001UYF00<0
05YFFUH01UYF00<005YF00000`000Woo1@004Woo0`000eYF0`0015YF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
FUH015YF00<005YF00000`000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH015YF0`00=goo000^Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH7000DOol01000FUIJEUYF0`0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00`00
0UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
1000>Woo000_Ool00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH9
0008Ool500000eYF000000020004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH007oo0P00
0eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF1`00?Woo000`
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80002
FUH00`00FUIJEP0200000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH20003Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90015Ool0039oo`04001JEUYF0008
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP03FUH02000FUIJEUYF
001JEP00Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20006OolD001>Ool003=oo`<000QJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009J
EP8000Aoo`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP04001JEUYFFUH2001ZOol003Eoo`8000MJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF009JEP8000Ioo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP00
001/Ool003Moo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEUYF009JEP8000Qoo`8000AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP@006ioo`00>Goo0`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000]oo`<00003FUH005YF00UJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00L0071oo`00?7oo0`00
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000ioo`L000EJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD000=oo`D006moo`00?goo10000UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8001Ioo``000IJEP03
001JEUYF00YJEP03001JEUYF00H000Qoo`D000moo`H005Yoo`00@goo1`0015YF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YF000002AooaH000iooa@000=JEP03001JEUYF00D005Eoo`00BWoo2000
15YF00@005YFFUIJEPD004Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEP00001COol0059oo`P004]oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF001COol00:5oo`@00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEUYF0080059oo`00WGoo10001EYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP00059oo`00VGoo100000=JEP00
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF4`000UYF00<007ooOol0D7oo002GOol20005FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH9000@Ool200000eYF00000002001AOol009Ioo`8000MJEP03
001JEUYF00AJEPH001Ioo`<000=JEP04001JEP00001AOol009Aoo`800003FUH005YF00IJEP03001J
EUYF00@001Yoo`800003FUH005YF00AJEP03001JEP00055oo`00Tgoo00D005YFFUIJEP0000IJEP@0
01aoo`8000=JEP03001JEUYF00=JEP80059oo`00TWoo0P0015YF00@005YFFUIJEP8001eoo`<000EJ
EP03001JEUYF00=JEP03001oogoo055oo`00TGoo00<005YF000015YF00@005YF000001]oo`@00003
FUH005YF00IJEP03001JEUYF008005Aoo`00TGoo00<005YF00000eYF0`005Woo1`001EYF00<005YF
FUH01EYF0`00EWoo002AOol01000FUH005YF0P0047oo2@0015YF00<005YFFUH01UYF00<005YFFUH0
0eYF0P00F7oo002AOol00`00FUH0000C0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
0003001JOol0095oo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP<005ioo`00TGoo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01000HGoo002AOol20003FUH00`00FUIJEP03
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7001UOol0099oo`80009JEP03001J
EUYF00=JEP03001JEUYF00AJEP03001JEUYF009JEPT006aoo`00U7oo5000MGoo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]48\[InvisibleSpace]"     "\
\[InvisibleSpace]12.883764565444826`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 48, "     ", 12.883764565444826, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .71549 m .59613 .65991 L .56496 .65801 L p .707 .577 .707 r
F P
0 g
s
.59613 .65991 m .59613 .71549 L .62796 .71471 L p .707 .577 .707 r
F P
0 g
s
.62796 .71471 m .62796 .65913 L .59613 .65991 L p .707 .577 .707 r
F P
0 g
s
.62796 .65913 m .62796 .71471 L .65734 .71133 L p .707 .577 .707 r
F P
0 g
s
.65734 .71133 m .65734 .65575 L .62796 .65913 L p .707 .577 .707 r
F P
0 g
s
.56496 .71359 m .56496 .65801 L .5375 .65361 L p .707 .577 .707 r
F P
0 g
s
.56496 .65801 m .56496 .71359 L .59613 .71549 L p .707 .577 .707 r
F P
0 g
s
.65734 .65575 m .65734 .71133 L .6814 .70568 L p .707 .577 .707 r
F P
0 g
s
.6814 .70568 m .6814 .6501 L .65734 .65575 L p .707 .577 .707 r
F P
0 g
s
.5375 .65361 m .5375 .7092 L .56496 .71359 L p .707 .577 .707 r
F P
0 g
s
.5375 .7092 m .5375 .65361 L .51644 .64716 L p .707 .577 .707 r
F P
0 g
s
.59613 .79275 m .59613 .77422 L .56496 .77232 L p .707 .577 .707 r
F P
0 g
s
.59613 .77422 m .59613 .79275 L .62796 .79197 L p .707 .577 .707 r
F P
0 g
s
.62796 .79197 m .62796 .77345 L .59613 .77422 L p .707 .577 .707 r
F P
0 g
s
.62796 .77345 m .62796 .79197 L .65735 .78859 L p .707 .577 .707 r
F P
0 g
s
.65735 .78859 m .65735 .77007 L .62796 .77345 L p .707 .577 .707 r
F P
0 g
s
.6814 .6501 m .6814 .70568 L .69777 .69832 L p .707 .577 .707 r
F P
0 g
s
.69777 .69832 m .69777 .64273 L .6814 .6501 L p .707 .577 .707 r
F P
0 g
s
.56496 .77232 m .56496 .79085 L .59613 .79275 L p .707 .577 .707 r
F P
0 g
s
.51644 .64716 m .51644 .70274 L .5375 .7092 L p .707 .577 .707 r
F P
0 g
s
.56496 .79085 m .56496 .77232 L .5375 .76793 L p .707 .577 .707 r
F P
0 g
s
.5375 .76793 m .5375 .78646 L .56496 .79085 L p .707 .577 .707 r
F P
0 g
s
.51644 .70274 m .51644 .64716 L .50385 .63928 L p .707 .577 .707 r
F P
0 g
s
.65735 .77007 m .65735 .78859 L .6814 .78294 L p .707 .577 .707 r
F P
0 g
s
.6814 .78294 m .6814 .76442 L .65735 .77007 L p .707 .577 .707 r
F P
0 g
s
.59613 .87246 m .59613 .83541 L .56496 .83351 L p .707 .577 .707 r
F P
0 g
s
.59613 .83541 m .59613 .87246 L .62796 .87168 L p .707 .577 .707 r
F P
0 g
s
.62796 .87168 m .62796 .83463 L .59613 .83541 L p .707 .577 .707 r
F P
0 g
s
.62796 .83463 m .62796 .87168 L .65735 .8683 L p .707 .577 .707 r
F P
0 g
s
.65735 .8683 m .65735 .83125 L .62796 .83463 L p .707 .577 .707 r
F P
0 g
s
.5375 .78646 m .5375 .76793 L .51644 .76148 L p .707 .577 .707 r
F P
0 g
s
.56496 .87056 m .56496 .83351 L .5375 .82911 L p .707 .577 .707 r
F P
0 g
s
.56496 .83351 m .56496 .87056 L .59613 .87246 L p .707 .577 .707 r
F P
0 g
s
.51644 .76148 m .51644 .78 L .5375 .78646 L p .707 .577 .707 r
F P
0 g
s
.50385 .63928 m .50385 .69486 L .51644 .70274 L p .707 .577 .707 r
F P
0 g
s
.69777 .64273 m .69777 .69832 L .70485 .68995 L p .707 .577 .707 r
F P
0 g
s
.70485 .68995 m .70485 .63437 L .69777 .64273 L p .707 .577 .707 r
F P
0 g
s
.65735 .83125 m .65735 .8683 L .6814 .86265 L p .707 .577 .707 r
F P
0 g
s
.6814 .86265 m .6814 .8256 L .65735 .83125 L p .707 .577 .707 r
F P
0 g
s
.5375 .82911 m .5375 .86617 L .56496 .87056 L p .707 .577 .707 r
F P
0 g
s
.6814 .76442 m .6814 .78294 L .69777 .77558 L p .707 .577 .707 r
F P
0 g
s
.69777 .77558 m .69777 .75705 L .6814 .76442 L p .707 .577 .707 r
F P
0 g
s
.5375 .86617 m .5375 .82911 L .51644 .82266 L p .707 .577 .707 r
F P
0 g
s
.50385 .69486 m .50385 .63928 L .50095 .63073 L p .707 .577 .707 r
F P
0 g
s
.51644 .78 m .51644 .76148 L .50385 .75359 L p .707 .577 .707 r
F P
0 g
s
.51644 .82266 m .51644 .85971 L .5375 .86617 L p .707 .577 .707 r
F P
0 g
s
.50385 .75359 m .50385 .77212 L .51644 .78 L p .707 .577 .707 r
F P
0 g
s
.6814 .8256 m .6814 .86265 L .69777 .85529 L p .707 .577 .707 r
F P
0 g
s
.69777 .85529 m .69777 .81823 L .6814 .8256 L p .707 .577 .707 r
F P
0 g
s
.50095 .63073 m .50095 .68632 L .50385 .69486 L p .707 .577 .707 r
F P
0 g
s
.70485 .63437 m .70485 .68995 L .70195 .68141 L p .707 .577 .707 r
F P
0 g
s
.70195 .68141 m .70195 .62583 L .70485 .63437 L p .707 .577 .707 r
F P
0 g
s
.69777 .75705 m .69777 .77558 L .70485 .76721 L p .707 .577 .707 r
F P
0 g
s
.70485 .76721 m .70485 .74869 L .69777 .75705 L p .707 .577 .707 r
F P
0 g
s
.51644 .85971 m .51644 .82266 L .50385 .81477 L p .707 .577 .707 r
F P
0 g
s
.50095 .68632 m .50095 .63073 L .50804 .62237 L p .707 .577 .707 r
F P
0 g
s
.50385 .81477 m .50385 .85183 L .51644 .85971 L p .707 .577 .707 r
F P
0 g
s
.50385 .77212 m .50385 .75359 L .50095 .74505 L p .707 .577 .707 r
F P
0 g
s
.69777 .81823 m .69777 .85529 L .70485 .84692 L p .707 .577 .707 r
F P
0 g
s
.70485 .84692 m .70485 .80987 L .69777 .81823 L p .707 .577 .707 r
F P
0 g
s
.50095 .74505 m .50095 .76358 L .50385 .77212 L p .707 .577 .707 r
F P
0 g
s
.49044 .83307 m .49044 .33118 L .44643 .3285 L p .707 .577 .707 r
F P
0 g
s
.50804 .62237 m .50804 .67795 L .50095 .68632 L p .707 .577 .707 r
F P
0 g
s
.50385 .85183 m .50385 .81477 L .50095 .80623 L p .707 .577 .707 r
F P
0 g
s
.50095 .80623 m .50095 .84329 L .50385 .85183 L p .707 .577 .707 r
F P
0 g
s
.50804 .67795 m .50804 .62237 L .5244 .615 L p .707 .577 .707 r
F P
0 g
s
.50095 .76358 m .50095 .74505 L .50804 .73669 L p .707 .577 .707 r
F P
0 g
s
.50804 .73669 m .50804 .75521 L .50095 .76358 L p .707 .577 .707 r
F P
0 g
s
.5244 .615 m .5244 .67058 L .50804 .67795 L p .707 .577 .707 r
F P
0 g
s
.50095 .84329 m .50095 .80623 L .50804 .79787 L p .707 .577 .707 r
F P
0 g
s
.50804 .79787 m .50804 .83492 L .50095 .84329 L p .707 .577 .707 r
F P
0 g
s
.50804 .75521 m .50804 .73669 L .5244 .72932 L p .707 .577 .707 r
F P
0 g
s
.5244 .72932 m .5244 .74785 L .50804 .75521 L p .707 .577 .707 r
F P
0 g
s
.50804 .83492 m .50804 .79787 L .5244 .7905 L p .707 .577 .707 r
F P
0 g
s
.5244 .74785 m .5244 .72932 L .54846 .72367 L p .707 .577 .707 r
F P
0 g
s
.5244 .7905 m .5244 .82756 L .50804 .83492 L p .707 .577 .707 r
F P
0 g
s
.54846 .72367 m .54846 .7422 L .5244 .74785 L p .707 .577 .707 r
F P
0 g
s
.5244 .82756 m .5244 .7905 L .54846 .78485 L p .707 .577 .707 r
F P
0 g
s
.54846 .78485 m .54846 .82191 L .5244 .82756 L p .707 .577 .707 r
F P
0 g
s
.49044 .33118 m .49044 .83307 L .53538 .83197 L p .707 .577 .707 r
F P
0 g
s
.5244 .67058 m .5244 .615 L .54846 .60935 L p .707 .577 .707 r
F P
0 g
s
.54846 .60935 m .54846 .66493 L .5244 .67058 L p .707 .577 .707 r
F P
0 g
s
.53538 .83197 m .53538 .33008 L .49044 .33118 L p .707 .577 .707 r
F P
0 g
s
.54846 .66493 m .54846 .60935 L .57784 .60597 L p .707 .577 .707 r
F P
0 g
s
.57784 .60597 m .57784 .66156 L .54846 .66493 L p .707 .577 .707 r
F P
0 g
s
.54846 .7422 m .54846 .72367 L .57784 .72029 L p .707 .577 .707 r
F P
0 g
s
.57784 .72029 m .57784 .73882 L .54846 .7422 L p .707 .577 .707 r
F P
0 g
s
.54846 .82191 m .54846 .78485 L .57784 .78147 L p .707 .577 .707 r
F P
0 g
s
.57784 .78147 m .57784 .81853 L .54846 .82191 L p .707 .577 .707 r
F P
0 g
s
.53538 .33008 m .53538 .83197 L .57686 .8272 L p .707 .577 .707 r
F P
0 g
s
.57686 .8272 m .57686 .32531 L .53538 .33008 L p .707 .577 .707 r
F P
0 g
s
.70195 .62583 m .70195 .68141 L .68936 .67353 L p .707 .577 .707 r
F P
0 g
s
.68936 .67353 m .68936 .61794 L .70195 .62583 L p .707 .577 .707 r
F P
0 g
s
.70485 .74869 m .70485 .76721 L .70195 .75867 L p .707 .577 .707 r
F P
0 g
s
.70195 .75867 m .70195 .74014 L .70485 .74869 L p .707 .577 .707 r
F P
0 g
s
.44643 .83039 m .44643 .3285 L .40766 .3223 L p .707 .577 .707 r
F P
0 g
s
.44643 .3285 m .44643 .83039 L .49044 .83307 L p .707 .577 .707 r
F P
0 g
s
.25312 .67867 m .25312 .62309 L .22195 .62119 L p .707 .577 .707 r
F P
0 g
s
.25312 .62309 m .25312 .67867 L .28495 .6779 L p .707 .577 .707 r
F P
0 g
s
.28495 .6779 m .28495 .62232 L .25312 .62309 L p .707 .577 .707 r
F P
0 g
s
.28495 .62232 m .28495 .6779 L .31434 .67452 L p .707 .577 .707 r
F P
0 g
s
.31434 .67452 m .31434 .61894 L .28495 .62232 L p .707 .577 .707 r
F P
0 g
s
.57784 .66156 m .57784 .60597 L .60968 .6052 L p .707 .577 .707 r
F P
0 g
s
.60968 .6052 m .60968 .66078 L .57784 .66156 L p .707 .577 .707 r
F P
0 g
s
.57784 .73882 m .57784 .72029 L .60968 .71951 L p .707 .577 .707 r
F P
0 g
s
.60968 .71951 m .60968 .73804 L .57784 .73882 L p .707 .577 .707 r
F P
0 g
s
.64085 .7826 m .64085 .81965 L .60968 .81775 L p .707 .577 .707 r
F P
0 g
s
.60968 .81775 m .60968 .78069 L .64085 .7826 L p .707 .577 .707 r
F P
0 g
s
.57784 .81853 m .57784 .78147 L .60968 .78069 L p .707 .577 .707 r
F P
0 g
s
.60968 .78069 m .60968 .81775 L .57784 .81853 L p .707 .577 .707 r
F P
0 g
s
.57686 .32531 m .57686 .8272 L .61082 .81923 L p .707 .577 .707 r
F P
0 g
s
.64085 .6071 m .64085 .66268 L .60968 .66078 L p .707 .577 .707 r
F P
0 g
s
.60968 .66078 m .60968 .6052 L .64085 .6071 L p .707 .577 .707 r
F P
0 g
s
.64085 .72141 m .64085 .73994 L .60968 .73804 L p .707 .577 .707 r
F P
0 g
s
.60968 .73804 m .60968 .71951 L .64085 .72141 L p .707 .577 .707 r
F P
0 g
s
.61082 .81923 m .61082 .31734 L .57686 .32531 L p .707 .577 .707 r
F P
0 g
s
.22195 .67677 m .22195 .62119 L .19449 .6168 L p .707 .577 .707 r
F P
0 g
s
.22195 .62119 m .22195 .67677 L .25312 .67867 L p .707 .577 .707 r
F P
0 g
s
.70485 .80987 m .70485 .84692 L .70195 .83838 L p .707 .577 .707 r
F P
0 g
s
.70195 .83838 m .70195 .80133 L .70485 .80987 L p .707 .577 .707 r
F P
0 g
s
.40766 .82419 m .40766 .3223 L .37794 .31319 L p .707 .577 .707 r
F P
0 g
s
.40766 .3223 m .40766 .82419 L .44643 .83039 L p .707 .577 .707 r
F P
0 g
s
.31434 .61894 m .31434 .67452 L .33839 .66887 L p .707 .577 .707 r
F P
0 g
s
.33839 .66887 m .33839 .61329 L .31434 .61894 L p .707 .577 .707 r
F P
0 g
s
.68936 .61794 m .68936 .67353 L .66831 .66707 L p .707 .577 .707 r
F P
0 g
s
.66831 .66707 m .66831 .61149 L .68936 .61794 L p .707 .577 .707 r
F P
0 g
s
.70195 .74014 m .70195 .75867 L .68936 .75079 L p .707 .577 .707 r
F P
0 g
s
.68936 .75079 m .68936 .73226 L .70195 .74014 L p .707 .577 .707 r
F P
0 g
s
.19449 .6168 m .19449 .67238 L .22195 .67677 L p .707 .577 .707 r
F P
0 g
s
.19449 .67238 m .19449 .6168 L .17343 .61035 L p .707 .577 .707 r
F P
0 g
s
.61082 .31734 m .61082 .81923 L .63393 .80883 L p .707 .577 .707 r
F P
0 g
s
.63393 .80883 m .63393 .30694 L .61082 .31734 L p .707 .577 .707 r
F P
0 g
s
.25312 .75594 m .25312 .73741 L .22195 .73551 L p .707 .577 .707 r
F P
0 g
s
.25312 .73741 m .25312 .75594 L .28495 .75516 L p .707 .577 .707 r
F P
0 g
s
.28495 .75516 m .28495 .73663 L .25312 .73741 L p .707 .577 .707 r
F P
0 g
s
.28495 .73663 m .28495 .75516 L .31434 .75178 L p .707 .577 .707 r
F P
0 g
s
.31434 .75178 m .31434 .73325 L .28495 .73663 L p .707 .577 .707 r
F P
0 g
s
.33839 .61329 m .33839 .66887 L .35476 .6615 L p .707 .577 .707 r
F P
0 g
s
.35476 .6615 m .35476 .60592 L .33839 .61329 L p .707 .577 .707 r
F P
0 g
s
.22195 .73551 m .22195 .75403 L .25312 .75594 L p .707 .577 .707 r
F P
0 g
s
.17343 .61035 m .17343 .66593 L .19449 .67238 L p .707 .577 .707 r
F P
0 g
s
.22195 .75403 m .22195 .73551 L .19449 .73112 L p .707 .577 .707 r
F P
0 g
s
.70195 .80133 m .70195 .83838 L .68936 .8305 L p .707 .577 .707 r
F P
0 g
s
.68936 .8305 m .68936 .79344 L .70195 .80133 L p .707 .577 .707 r
F P
0 g
s
.66831 .61149 m .66831 .66707 L .64085 .66268 L p .707 .577 .707 r
F P
0 g
s
.64085 .66268 m .64085 .6071 L .66831 .61149 L p .707 .577 .707 r
F P
0 g
s
.19449 .73112 m .19449 .74964 L .22195 .75403 L p .707 .577 .707 r
F P
0 g
s
.17343 .66593 m .17343 .61035 L .16084 .60246 L p .707 .577 .707 r
F P
0 g
s
.37794 .81507 m .37794 .31319 L .36016 .30206 L p .707 .577 .707 r
F P
0 g
s
.37794 .31319 m .37794 .81507 L .40766 .82419 L p .707 .577 .707 r
F P
0 g
s
.31434 .73325 m .31434 .75178 L .33839 .74613 L p .707 .577 .707 r
F P
0 g
s
.33839 .74613 m .33839 .7276 L .31434 .73325 L p .707 .577 .707 r
F P
0 g
s
.25312 .83565 m .25312 .79859 L .22195 .79669 L p .707 .577 .707 r
F P
0 g
s
.25312 .79859 m .25312 .83565 L .28495 .83487 L p .707 .577 .707 r
F P
0 g
s
.28495 .83487 m .28495 .79781 L .25312 .79859 L p .707 .577 .707 r
F P
0 g
s
.68936 .73226 m .68936 .75079 L .66831 .74433 L p .707 .577 .707 r
F P
0 g
s
.66831 .74433 m .66831 .72581 L .68936 .73226 L p .707 .577 .707 r
F P
0 g
s
.28495 .79781 m .28495 .83487 L .31434 .83149 L p .707 .577 .707 r
F P
0 g
s
.31434 .83149 m .31434 .79443 L .28495 .79781 L p .707 .577 .707 r
F P
0 g
s
.19449 .74964 m .19449 .73112 L .17343 .72466 L p .707 .577 .707 r
F P
0 g
s
.22195 .83374 m .22195 .79669 L .19449 .7923 L p .707 .577 .707 r
F P
0 g
s
.22195 .79669 m .22195 .83374 L .25312 .83565 L p .707 .577 .707 r
F P
0 g
s
.17343 .72466 m .17343 .74319 L .19449 .74964 L p .707 .577 .707 r
F P
0 g
s
.16084 .60246 m .16084 .65804 L .17343 .66593 L p .707 .577 .707 r
F P
0 g
s
.35476 .60592 m .35476 .6615 L .36184 .65314 L p .707 .577 .707 r
F P
0 g
s
.36184 .65314 m .36184 .59755 L .35476 .60592 L p .707 .577 .707 r
F P
0 g
s
.31434 .79443 m .31434 .83149 L .33839 .82584 L p .707 .577 .707 r
F P
0 g
s
.33839 .82584 m .33839 .78878 L .31434 .79443 L p .707 .577 .707 r
F P
0 g
s
.19449 .7923 m .19449 .82935 L .22195 .83374 L p .707 .577 .707 r
F P
0 g
s
.33839 .7276 m .33839 .74613 L .35476 .73876 L p .707 .577 .707 r
F P
0 g
s
.35476 .73876 m .35476 .72023 L .33839 .7276 L p .707 .577 .707 r
F P
0 g
s
.68936 .79344 m .68936 .8305 L .66831 .82404 L p .707 .577 .707 r
F P
0 g
s
.66831 .82404 m .66831 .78699 L .68936 .79344 L p .707 .577 .707 r
F P
0 g
s
.66831 .72581 m .66831 .74433 L .64085 .73994 L p .707 .577 .707 r
F P
0 g
s
.64085 .73994 m .64085 .72141 L .66831 .72581 L p .707 .577 .707 r
F P
0 g
s
.64085 .81965 m .64085 .7826 L .66831 .78699 L p .707 .577 .707 r
F P
0 g
s
.63393 .30694 m .63393 .80883 L .64393 .79702 L p .707 .577 .707 r
F P
0 g
s
.64393 .79702 m .64393 .29513 L .63393 .30694 L p .707 .577 .707 r
F P
0 g
s
.19449 .82935 m .19449 .7923 L .17343 .78584 L p .707 .577 .707 r
F P
0 g
s
.16084 .65804 m .16084 .60246 L .15794 .59392 L p .707 .577 .707 r
F P
0 g
s
.17343 .74319 m .17343 .72466 L .16084 .71678 L p .707 .577 .707 r
F P
0 g
s
.17343 .78584 m .17343 .8229 L .19449 .82935 L p .707 .577 .707 r
F P
0 g
s
.16084 .71678 m .16084 .7353 L .17343 .74319 L p .707 .577 .707 r
F P
0 g
s
.33839 .78878 m .33839 .82584 L .35476 .81847 L p .707 .577 .707 r
F P
0 g
s
.35476 .81847 m .35476 .78142 L .33839 .78878 L p .707 .577 .707 r
F P
0 g
s
.36184 .59755 m .36184 .65314 L .35894 .64459 L p .707 .577 .707 r
F P
0 g
s
.35894 .64459 m .35894 .58901 L .36184 .59755 L p .707 .577 .707 r
F P
0 g
s
.35476 .72023 m .35476 .73876 L .36184 .7304 L p .707 .577 .707 r
F P
0 g
s
.36184 .7304 m .36184 .71187 L .35476 .72023 L p .707 .577 .707 r
F P
0 g
s
.35476 .78142 m .35476 .81847 L .36184 .81011 L p .707 .577 .707 r
F P
0 g
s
.36184 .81011 m .36184 .77305 L .35476 .78142 L p .707 .577 .707 r
F P
0 g
s
.35894 .58901 m .35894 .64459 L .34635 .63671 L p .707 .577 .707 r
F P
0 g
s
.34635 .63671 m .34635 .58113 L .35894 .58901 L p .707 .577 .707 r
F P
0 g
s
.36184 .71187 m .36184 .7304 L .35894 .72186 L p .707 .577 .707 r
F P
0 g
s
.35894 .72186 m .35894 .70333 L .36184 .71187 L p .707 .577 .707 r
F P
0 g
s
.36184 .77305 m .36184 .81011 L .35894 .80157 L p .707 .577 .707 r
F P
0 g
s
.35894 .80157 m .35894 .76451 L .36184 .77305 L p .707 .577 .707 r
F P
0 g
s
.36016 .80394 m .36016 .30206 L .35607 .29 L p .707 .577 .707 r
F P
0 g
s
.36016 .30206 m .36016 .80394 L .37794 .81507 L p .707 .577 .707 r
F P
0 g
s
.15794 .59392 m .15794 .6495 L .16084 .65804 L p .707 .577 .707 r
F P
0 g
s
.66831 .78699 m .66831 .82404 L .64085 .81965 L p .707 .577 .707 r
F P
0 g
s
.17343 .8229 m .17343 .78584 L .16084 .77796 L p .707 .577 .707 r
F P
0 g
s
.15794 .6495 m .15794 .59392 L .16503 .58555 L p .707 .577 .707 r
F P
0 g
s
.16084 .77796 m .16084 .81501 L .17343 .8229 L p .707 .577 .707 r
F P
0 g
s
.16084 .7353 m .16084 .71678 L .15794 .70823 L p .707 .577 .707 r
F P
0 g
s
.15794 .70823 m .15794 .72676 L .16084 .7353 L p .707 .577 .707 r
F P
0 g
s
.64393 .29513 m .64393 .79702 L .63984 .78496 L p .707 .577 .707 r
F P
0 g
s
.63984 .78496 m .63984 .28307 L .64393 .29513 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16503 .58555 m .16503 .64114 L .15794 .6495 L p .707 .577 .707 r
F P
0 g
s
.16084 .81501 m .16084 .77796 L .15794 .76942 L p .707 .577 .707 r
F P
0 g
s
.35894 .70333 m .35894 .72186 L .34635 .71397 L p .707 .577 .707 r
F P
0 g
s
.34635 .71397 m .34635 .69544 L .35894 .70333 L p .707 .577 .707 r
F P
0 g
s
.35894 .76451 m .35894 .80157 L .34635 .79368 L p .707 .577 .707 r
F P
0 g
s
.34635 .79368 m .34635 .75663 L .35894 .76451 L p .707 .577 .707 r
F P
0 g
s
.35607 .29 m .35607 .79188 L .36016 .80394 L p .707 .577 .707 r
F P
0 g
s
.35607 .79188 m .35607 .29 L .36607 .27819 L p .707 .577 .707 r
F P
0 g
s
.15794 .76942 m .15794 .80647 L .16084 .81501 L p .707 .577 .707 r
F P
0 g
s
.16503 .64114 m .16503 .58555 L .1814 .57819 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15794 .72676 m .15794 .70823 L .16503 .69987 L p .707 .577 .707 r
F P
0 g
s
.16503 .69987 m .16503 .7184 L .15794 .72676 L p .707 .577 .707 r
F P
0 g
s
.1814 .57819 m .1814 .63377 L .16503 .64114 L p .707 .577 .707 r
F P
0 g
s
.34635 .58113 m .34635 .63671 L .3253 .63026 L p .707 .577 .707 r
F P
0 g
s
.3253 .63026 m .3253 .57467 L .34635 .58113 L p .707 .577 .707 r
F P
0 g
s
.15794 .80647 m .15794 .76942 L .16503 .76105 L p .707 .577 .707 r
F P
0 g
s
.63984 .28307 m .63984 .78496 L .62206 .77383 L p .707 .577 .707 r
F P
0 g
s
.62206 .77383 m .62206 .27194 L .63984 .28307 L p .707 .577 .707 r
F P
0 g
s
.1814 .63377 m .1814 .57819 L .20545 .57254 L p .707 .577 .707 r
F P
0 g
s
.16503 .76105 m .16503 .79811 L .15794 .80647 L p .707 .577 .707 r
F P
0 g
s
.16503 .7184 m .16503 .69987 L .1814 .6925 L p .707 .577 .707 r
F P
0 g
s
.1814 .6925 m .1814 .71103 L .16503 .7184 L p .707 .577 .707 r
F P
0 g
s
.36607 .78008 m .36607 .27819 L .38918 .26779 L p .707 .577 .707 r
F P
0 g
s
.36607 .27819 m .36607 .78008 L .35607 .79188 L p .707 .577 .707 r
F P
0 g
s
.3253 .57467 m .3253 .63026 L .29784 .62586 L p .707 .577 .707 r
F P
0 g
s
.29784 .62586 m .29784 .57028 L .3253 .57467 L p .707 .577 .707 r
F P
0 g
s
.20545 .57254 m .20545 .62812 L .1814 .63377 L p .707 .577 .707 r
F P
0 g
s
.20545 .62812 m .20545 .57254 L .23483 .56916 L p .707 .577 .707 r
F P
0 g
s
.34635 .69544 m .34635 .71397 L .3253 .70752 L p .707 .577 .707 r
F P
0 g
s
.3253 .70752 m .3253 .68899 L .34635 .69544 L p .707 .577 .707 r
F P
0 g
s
.16503 .79811 m .16503 .76105 L .1814 .75369 L p .707 .577 .707 r
F P
0 g
s
.29784 .57028 m .29784 .62586 L .26667 .62396 L p .707 .577 .707 r
F P
0 g
s
.26667 .62396 m .26667 .56838 L .29784 .57028 L p .707 .577 .707 r
F P
0 g
s
.1814 .71103 m .1814 .6925 L .20545 .68685 L p .707 .577 .707 r
F P
0 g
s
.23483 .62474 m .23483 .56916 L .26667 .56838 L p .707 .577 .707 r
F P
0 g
s
.23483 .56916 m .23483 .62474 L .20545 .62812 L p .707 .577 .707 r
F P
0 g
s
.1814 .75369 m .1814 .79074 L .16503 .79811 L p .707 .577 .707 r
F P
0 g
s
.62206 .27194 m .62206 .77383 L .59233 .76472 L p .707 .577 .707 r
F P
0 g
s
.59233 .76472 m .59233 .26283 L .62206 .27194 L p .707 .577 .707 r
F P
0 g
s
.26667 .56838 m .26667 .62396 L .23483 .62474 L p .707 .577 .707 r
F P
0 g
s
.20545 .68685 m .20545 .70538 L .1814 .71103 L p .707 .577 .707 r
F P
0 g
s
.73333 .62345 m .73333 .56787 L .70216 .56597 L p .707 .577 .707 r
F P
0 g
s
.73333 .56787 m .73333 .62345 L .76517 .62267 L p .707 .577 .707 r
F P
0 g
s
.76517 .62267 m .76517 .56709 L .73333 .56787 L p .707 .577 .707 r
F P
0 g
s
.34635 .75663 m .34635 .79368 L .3253 .78723 L p .707 .577 .707 r
F P
0 g
s
.3253 .78723 m .3253 .75017 L .34635 .75663 L p .707 .577 .707 r
F P
0 g
s
.76517 .56709 m .76517 .62267 L .79455 .6193 L p .707 .577 .707 r
F P
0 g
s
.79455 .6193 m .79455 .56371 L .76517 .56709 L p .707 .577 .707 r
F P
0 g
s
.70216 .62155 m .70216 .56597 L .6747 .56158 L p .707 .577 .707 r
F P
0 g
s
.70216 .56597 m .70216 .62155 L .73333 .62345 L p .707 .577 .707 r
F P
0 g
s
.3253 .68899 m .3253 .70752 L .29784 .70312 L p .707 .577 .707 r
F P
0 g
s
.29784 .70312 m .29784 .6846 L .3253 .68899 L p .707 .577 .707 r
F P
0 g
s
.38918 .26779 m .38918 .76967 L .36607 .78008 L p .707 .577 .707 r
F P
0 g
s
.38918 .76967 m .38918 .26779 L .42314 .25981 L p .707 .577 .707 r
F P
0 g
s
.1814 .79074 m .1814 .75369 L .20545 .74804 L p .707 .577 .707 r
F P
0 g
s
.79455 .56371 m .79455 .6193 L .8186 .61365 L p .707 .577 .707 r
F P
0 g
s
.8186 .61365 m .8186 .55806 L .79455 .56371 L p .707 .577 .707 r
F P
0 g
s
.20545 .70538 m .20545 .68685 L .23483 .68347 L p .707 .577 .707 r
F P
0 g
s
.23483 .68347 m .23483 .702 L .20545 .70538 L p .707 .577 .707 r
F P
0 g
s
.20545 .74804 m .20545 .78509 L .1814 .79074 L p .707 .577 .707 r
F P
0 g
s
.6747 .56158 m .6747 .61716 L .70216 .62155 L p .707 .577 .707 r
F P
0 g
s
.6747 .61716 m .6747 .56158 L .65365 .55512 L p .707 .577 .707 r
F P
0 g
s
.29784 .6846 m .29784 .70312 L .26667 .70122 L p .707 .577 .707 r
F P
0 g
s
.26667 .70122 m .26667 .6827 L .29784 .6846 L p .707 .577 .707 r
F P
0 g
s
.3253 .75017 m .3253 .78723 L .29784 .78284 L p .707 .577 .707 r
F P
0 g
s
.29784 .78284 m .29784 .74578 L .3253 .75017 L p .707 .577 .707 r
F P
0 g
s
.23483 .702 m .23483 .68347 L .26667 .6827 L p .707 .577 .707 r
F P
0 g
s
.59233 .26283 m .59233 .76472 L .55357 .75851 L p .707 .577 .707 r
F P
0 g
s
.55357 .75851 m .55357 .25662 L .59233 .26283 L p .707 .577 .707 r
F P
0 g
s
.26667 .6827 m .26667 .70122 L .23483 .702 L p .707 .577 .707 r
F P
0 g
s
.73333 .70071 m .73333 .68219 L .70216 .68028 L p .707 .577 .707 r
F P
0 g
s
.73333 .68219 m .73333 .70071 L .76517 .69994 L p .707 .577 .707 r
F P
0 g
s
.76517 .69994 m .76517 .68141 L .73333 .68219 L p .707 .577 .707 r
F P
0 g
s
.20545 .78509 m .20545 .74804 L .23483 .74466 L p .707 .577 .707 r
F P
0 g
s
.76517 .68141 m .76517 .69994 L .79455 .69656 L p .707 .577 .707 r
F P
0 g
s
.79455 .69656 m .79455 .67803 L .76517 .68141 L p .707 .577 .707 r
F P
0 g
s
.8186 .55806 m .8186 .61365 L .83497 .60628 L p .707 .577 .707 r
F P
0 g
s
.83497 .60628 m .83497 .5507 L .8186 .55806 L p .707 .577 .707 r
F P
0 g
s
.70216 .68028 m .70216 .69881 L .73333 .70071 L p .707 .577 .707 r
F P
0 g
s
.65365 .55512 m .65365 .6107 L .6747 .61716 L p .707 .577 .707 r
F P
0 g
s
.70216 .69881 m .70216 .68028 L .6747 .67589 L p .707 .577 .707 r
F P
0 g
s
.42314 .7617 m .42314 .25981 L .46462 .25504 L p .707 .577 .707 r
F P
0 g
s
.42314 .25981 m .42314 .7617 L .38918 .76967 L p .707 .577 .707 r
F P
0 g
s
.29784 .74578 m .29784 .78284 L .26667 .78093 L p .707 .577 .707 r
F P
0 g
s
.26667 .78093 m .26667 .74388 L .29784 .74578 L p .707 .577 .707 r
F P
0 g
s
.23483 .74466 m .23483 .78171 L .20545 .78509 L p .707 .577 .707 r
F P
0 g
s
.6747 .67589 m .6747 .69442 L .70216 .69881 L p .707 .577 .707 r
F P
0 g
s
.23483 .78171 m .23483 .74466 L .26667 .74388 L p .707 .577 .707 r
F P
0 g
s
.65365 .6107 m .65365 .55512 L .64105 .54724 L p .707 .577 .707 r
F P
0 g
s
.79455 .67803 m .79455 .69656 L .8186 .69091 L p .707 .577 .707 r
F P
0 g
s
.8186 .69091 m .8186 .67238 L .79455 .67803 L p .707 .577 .707 r
F P
0 g
s
.26667 .74388 m .26667 .78093 L .23483 .78171 L p .707 .577 .707 r
F P
0 g
s
.73333 .78042 m .73333 .74337 L .70216 .74147 L p .707 .577 .707 r
F P
0 g
s
.73333 .74337 m .73333 .78042 L .76517 .77965 L p .707 .577 .707 r
F P
0 g
s
.76517 .77965 m .76517 .74259 L .73333 .74337 L p .707 .577 .707 r
F P
0 g
s
.55357 .25662 m .55357 .75851 L .50956 .75583 L p .707 .577 .707 r
F P
0 g
s
.50956 .75583 m .50956 .25394 L .55357 .25662 L p .707 .577 .707 r
F P
0 g
s
.76517 .74259 m .76517 .77965 L .79455 .77627 L p .707 .577 .707 r
F P
0 g
s
.79455 .77627 m .79455 .73921 L .76517 .74259 L p .707 .577 .707 r
F P
0 g
s
.6747 .69442 m .6747 .67589 L .65365 .66944 L p .707 .577 .707 r
F P
0 g
s
.70216 .77852 m .70216 .74147 L .6747 .73707 L p .707 .577 .707 r
F P
0 g
s
.70216 .74147 m .70216 .77852 L .73333 .78042 L p .707 .577 .707 r
F P
0 g
s
.46462 .75693 m .46462 .25504 L .50956 .25394 L p .707 .577 .707 r
F P
0 g
s
.46462 .25504 m .46462 .75693 L .42314 .7617 L p .707 .577 .707 r
F P
0 g
s
.65365 .66944 m .65365 .68797 L .6747 .69442 L p .707 .577 .707 r
F P
0 g
s
.50956 .25394 m .50956 .75583 L .46462 .75693 L p .707 .577 .707 r
F P
0 g
s
.64105 .54724 m .64105 .60282 L .65365 .6107 L p .707 .577 .707 r
F P
0 g
s
.83497 .5507 m .83497 .60628 L .84205 .59791 L p .707 .577 .707 r
F P
0 g
s
.84205 .59791 m .84205 .54233 L .83497 .5507 L p .707 .577 .707 r
F P
0 g
s
.79455 .73921 m .79455 .77627 L .8186 .77062 L p .707 .577 .707 r
F P
0 g
s
.8186 .77062 m .8186 .73356 L .79455 .73921 L p .707 .577 .707 r
F P
0 g
s
.6747 .73707 m .6747 .77413 L .70216 .77852 L p .707 .577 .707 r
F P
0 g
s
.8186 .67238 m .8186 .69091 L .83497 .68354 L p .707 .577 .707 r
F P
0 g
s
.83497 .68354 m .83497 .66501 L .8186 .67238 L p .707 .577 .707 r
F P
0 g
s
.6747 .77413 m .6747 .73707 L .65365 .73062 L p .707 .577 .707 r
F P
0 g
s
.64105 .60282 m .64105 .54724 L .63816 .5387 L p .707 .577 .707 r
F P
0 g
s
.65365 .68797 m .65365 .66944 L .64105 .66155 L p .707 .577 .707 r
F P
0 g
s
.65365 .73062 m .65365 .76768 L .6747 .77413 L p .707 .577 .707 r
F P
0 g
s
.64105 .66155 m .64105 .68008 L .65365 .68797 L p .707 .577 .707 r
F P
0 g
s
.8186 .73356 m .8186 .77062 L .83497 .76325 L p .707 .577 .707 r
F P
0 g
s
.83497 .76325 m .83497 .72619 L .8186 .73356 L p .707 .577 .707 r
F P
0 g
s
.63816 .5387 m .63816 .59428 L .64105 .60282 L p .707 .577 .707 r
F P
0 g
s
.84205 .54233 m .84205 .59791 L .83916 .58937 L p .707 .577 .707 r
F P
0 g
s
.83916 .58937 m .83916 .53379 L .84205 .54233 L p .707 .577 .707 r
F P
0 g
s
.83497 .66501 m .83497 .68354 L .84206 .67517 L p .707 .577 .707 r
F P
0 g
s
.84206 .67517 m .84205 .65665 L .83497 .66501 L p .707 .577 .707 r
F P
0 g
s
.65365 .76768 m .65365 .73062 L .64105 .72274 L p .707 .577 .707 r
F P
0 g
s
.63816 .59428 m .63816 .5387 L .64524 .53033 L p .707 .577 .707 r
F P
0 g
s
.64105 .72274 m .64105 .75979 L .65365 .76768 L p .707 .577 .707 r
F P
0 g
s
.64105 .68008 m .64105 .66155 L .63816 .65301 L p .707 .577 .707 r
F P
0 g
s
.83497 .72619 m .83497 .76325 L .84206 .75488 L p .707 .577 .707 r
F P
0 g
s
.84206 .75488 m .84206 .71783 L .83497 .72619 L p .707 .577 .707 r
F P
0 g
s
.63816 .65301 m .63816 .67154 L .64105 .68008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64524 .53033 m .64524 .58591 L .63816 .59428 L p .707 .577 .707 r
F P
0 g
s
.83916 .53379 m .83916 .58937 L .82657 .58149 L p .707 .577 .707 r
F P
0 g
s
.82657 .58149 m .82657 .5259 L .83916 .53379 L p .707 .577 .707 r
F P
0 g
s
.64105 .75979 m .64105 .72274 L .63816 .71419 L p .707 .577 .707 r
F P
0 g
s
.84205 .65665 m .84206 .67517 L .83916 .66663 L p .707 .577 .707 r
F P
0 g
s
.83916 .66663 m .83916 .6481 L .84205 .65665 L p .707 .577 .707 r
F P
0 g
s
.39032 .58664 m .39032 .53105 L .35915 .52915 L p .707 .577 .707 r
F P
0 g
s
.39032 .53105 m .39032 .58664 L .42216 .58586 L p .707 .577 .707 r
F P
0 g
s
.42216 .58586 m .42216 .53028 L .39032 .53105 L p .707 .577 .707 r
F P
0 g
s
.63816 .71419 m .63816 .75125 L .64105 .75979 L p .707 .577 .707 r
F P
0 g
s
.64524 .58591 m .64524 .53033 L .66161 .52296 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.42216 .53028 m .42216 .58586 L .45154 .58248 L p .707 .577 .707 r
F P
0 g
s
.45154 .58248 m .45154 .5269 L .42216 .53028 L p .707 .577 .707 r
F P
0 g
s
.63816 .67154 m .63816 .65301 L .64524 .64465 L p .707 .577 .707 r
F P
0 g
s
.35915 .58474 m .35915 .52915 L .33169 .52476 L p .707 .577 .707 r
F P
0 g
s
.35915 .52915 m .35915 .58474 L .39032 .58664 L p .707 .577 .707 r
F P
0 g
s
.84206 .71783 m .84206 .75488 L .83916 .74634 L p .707 .577 .707 r
F P
0 g
s
.83916 .74634 m .83916 .70929 L .84206 .71783 L p .707 .577 .707 r
F P
0 g
s
.64524 .64465 m .64524 .66317 L .63816 .67154 L p .707 .577 .707 r
F P
0 g
s
.45154 .5269 m .45154 .58248 L .47559 .57683 L p .707 .577 .707 r
F P
0 g
s
.47559 .57683 m .47559 .52125 L .45154 .5269 L p .707 .577 .707 r
F P
0 g
s
.66161 .52296 m .66161 .57855 L .64524 .58591 L p .707 .577 .707 r
F P
0 g
s
.82657 .5259 m .82657 .58149 L .80551 .57503 L p .707 .577 .707 r
F P
0 g
s
.80551 .57503 m .80551 .51945 L .82657 .5259 L p .707 .577 .707 r
F P
0 g
s
.63816 .75125 m .63816 .71419 L .64524 .70583 L p .707 .577 .707 r
F P
0 g
s
.83916 .6481 m .83916 .66663 L .82657 .65875 L p .707 .577 .707 r
F P
0 g
s
.82657 .65875 m .82657 .64022 L .83916 .6481 L p .707 .577 .707 r
F P
0 g
s
.33169 .52476 m .33169 .58034 L .35915 .58474 L p .707 .577 .707 r
F P
0 g
s
.33169 .58034 m .33169 .52476 L .31064 .51831 L p .707 .577 .707 r
F P
0 g
s
.66161 .57855 m .66161 .52296 L .68566 .51731 L p .707 .577 .707 r
F P
0 g
s
.64524 .70583 m .64524 .74289 L .63816 .75125 L p .707 .577 .707 r
F P
0 g
s
.39032 .6639 m .39032 .64537 L .35915 .64347 L p .707 .577 .707 r
F P
0 g
s
.39032 .64537 m .39032 .6639 L .42216 .66312 L p .707 .577 .707 r
F P
0 g
s
.42216 .66312 m .42216 .64459 L .39032 .64537 L p .707 .577 .707 r
F P
0 g
s
.64524 .66317 m .64524 .64465 L .66161 .63728 L p .707 .577 .707 r
F P
0 g
s
.42216 .64459 m .42216 .66312 L .45154 .65974 L p .707 .577 .707 r
F P
0 g
s
.45154 .65974 m .45154 .64121 L .42216 .64459 L p .707 .577 .707 r
F P
0 g
s
.47559 .52125 m .47559 .57683 L .49196 .56946 L p .707 .577 .707 r
F P
0 g
s
.49196 .56946 m .49196 .51388 L .47559 .52125 L p .707 .577 .707 r
F P
0 g
s
.35915 .64347 m .35915 .662 L .39032 .6639 L p .707 .577 .707 r
F P
0 g
s
.31064 .51831 m .31064 .57389 L .33169 .58034 L p .707 .577 .707 r
F P
0 g
s
.35915 .662 m .35915 .64347 L .33169 .63908 L p .707 .577 .707 r
F P
0 g
s
.83916 .70929 m .83916 .74634 L .82657 .73846 L p .707 .577 .707 r
F P
0 g
s
.82657 .73846 m .82657 .7014 L .83916 .70929 L p .707 .577 .707 r
F P
0 g
s
.66161 .63728 m .66161 .65581 L .64524 .66317 L p .707 .577 .707 r
F P
0 g
s
.80551 .51945 m .80551 .57503 L .77805 .57064 L p .707 .577 .707 r
F P
0 g
s
.77805 .57064 m .77805 .51506 L .80551 .51945 L p .707 .577 .707 r
F P
0 g
s
.33169 .63908 m .33169 .6576 L .35915 .662 L p .707 .577 .707 r
F P
0 g
s
.68566 .51731 m .68566 .5729 L .66161 .57855 L p .707 .577 .707 r
F P
0 g
s
.31064 .57389 m .31064 .51831 L .29804 .51042 L p .707 .577 .707 r
F P
0 g
s
.45154 .64121 m .45154 .65974 L .47559 .65409 L p .707 .577 .707 r
F P
0 g
s
.47559 .65409 m .47559 .63556 L .45154 .64121 L p .707 .577 .707 r
F P
0 g
s
.39032 .74361 m .39032 .70655 L .35915 .70465 L p .707 .577 .707 r
F P
0 g
s
.39032 .70655 m .39032 .74361 L .42216 .74283 L p .707 .577 .707 r
F P
0 g
s
.42216 .74283 m .42216 .70578 L .39032 .70655 L p .707 .577 .707 r
F P
0 g
s
.68566 .5729 m .68566 .51731 L .71504 .51393 L p .707 .577 .707 r
F P
0 g
s
.82657 .64022 m .82657 .65875 L .80551 .65229 L p .707 .577 .707 r
F P
0 g
s
.80551 .65229 m .80551 .63377 L .82657 .64022 L p .707 .577 .707 r
F P
0 g
s
.64524 .74289 m .64524 .70583 L .66161 .69846 L p .707 .577 .707 r
F P
0 g
s
.42216 .70578 m .42216 .74283 L .45154 .73945 L p .707 .577 .707 r
F P
0 g
s
.45154 .73945 m .45154 .7024 L .42216 .70578 L p .707 .577 .707 r
F P
0 g
s
.33169 .6576 m .33169 .63908 L .31064 .63262 L p .707 .577 .707 r
F P
0 g
s
.35915 .74171 m .35915 .70465 L .33169 .70026 L p .707 .577 .707 r
F P
0 g
s
.35915 .70465 m .35915 .74171 L .39032 .74361 L p .707 .577 .707 r
F P
0 g
s
.77805 .51506 m .77805 .57064 L .74688 .56874 L p .707 .577 .707 r
F P
0 g
s
.74688 .56874 m .74688 .51316 L .77805 .51506 L p .707 .577 .707 r
F P
0 g
s
.31064 .63262 m .31064 .65115 L .33169 .6576 L p .707 .577 .707 r
F P
0 g
s
.66161 .65581 m .66161 .63728 L .68566 .63163 L p .707 .577 .707 r
F P
0 g
s
.29804 .51042 m .29804 .566 L .31064 .57389 L p .707 .577 .707 r
F P
0 g
s
.71504 .56952 m .71504 .51393 L .74688 .51316 L p .707 .577 .707 r
F P
0 g
s
.71504 .51393 m .71504 .56952 L .68566 .5729 L p .707 .577 .707 r
F P
0 g
s
.49196 .51388 m .49196 .56946 L .49904 .5611 L p .707 .577 .707 r
F P
0 g
s
.49904 .5611 m .49904 .50552 L .49196 .51388 L p .707 .577 .707 r
F P
0 g
s
.66161 .69846 m .66161 .73552 L .64524 .74289 L p .707 .577 .707 r
F P
0 g
s
.45154 .7024 m .45154 .73945 L .47559 .7338 L p .707 .577 .707 r
F P
0 g
s
.47559 .7338 m .47559 .69675 L .45154 .7024 L p .707 .577 .707 r
F P
0 g
s
.74688 .51316 m .74688 .56874 L .71504 .56952 L p .707 .577 .707 r
F P
0 g
s
.33169 .70026 m .33169 .73731 L .35915 .74171 L p .707 .577 .707 r
F P
0 g
s
.68566 .63163 m .68566 .65016 L .66161 .65581 L p .707 .577 .707 r
F P
0 g
s
.47559 .63556 m .47559 .65409 L .49196 .64672 L p .707 .577 .707 r
F P
0 g
s
.49196 .64672 m .49196 .6282 L .47559 .63556 L p .707 .577 .707 r
F P
0 g
s
.82657 .7014 m .82657 .73846 L .80551 .732 L p .707 .577 .707 r
F P
0 g
s
.80551 .732 m .80551 .69495 L .82657 .7014 L p .707 .577 .707 r
F P
0 g
s
.33169 .73731 m .33169 .70026 L .31064 .69381 L p .707 .577 .707 r
F P
0 g
s
.80551 .63377 m .80551 .65229 L .77805 .6479 L p .707 .577 .707 r
F P
0 g
s
.77805 .6479 m .77805 .62937 L .80551 .63377 L p .707 .577 .707 r
F P
0 g
s
.29804 .566 m .29804 .51042 L .29515 .50188 L p .707 .577 .707 r
F P
0 g
s
.31064 .65115 m .31064 .63262 L .29804 .62474 L p .707 .577 .707 r
F P
0 g
s
.66161 .73552 m .66161 .69846 L .68566 .69281 L p .707 .577 .707 r
F P
0 g
s
.68566 .65016 m .68566 .63163 L .71504 .62825 L p .707 .577 .707 r
F P
0 g
s
.31064 .69381 m .31064 .73086 L .33169 .73731 L p .707 .577 .707 r
F P
0 g
s
.29804 .62474 m .29804 .64327 L .31064 .65115 L p .707 .577 .707 r
F P
0 g
s
.47559 .69675 m .47559 .7338 L .49196 .72643 L p .707 .577 .707 r
F P
0 g
s
.49196 .72643 m .49196 .68938 L .47559 .69675 L p .707 .577 .707 r
F P
0 g
s
.71504 .62825 m .71504 .64678 L .68566 .65016 L p .707 .577 .707 r
F P
0 g
s
.68566 .69281 m .68566 .72987 L .66161 .73552 L p .707 .577 .707 r
F P
0 g
s
.77805 .62937 m .77805 .6479 L .74688 .646 L p .707 .577 .707 r
F P
0 g
s
.74688 .646 m .74688 .62747 L .77805 .62937 L p .707 .577 .707 r
F P
0 g
s
.29515 .50188 m .29515 .55746 L .29804 .566 L p .707 .577 .707 r
F P
0 g
s
.80551 .69495 m .80551 .732 L .77805 .72761 L p .707 .577 .707 r
F P
0 g
s
.77805 .72761 m .77805 .69056 L .80551 .69495 L p .707 .577 .707 r
F P
0 g
s
.49904 .50552 m .49904 .5611 L .49615 .55256 L p .707 .577 .707 r
F P
0 g
s
.49615 .55256 m .49615 .49697 L .49904 .50552 L p .707 .577 .707 r
F P
0 g
s
.71504 .64678 m .71504 .62825 L .74688 .62747 L p .707 .577 .707 r
F P
0 g
s
.49196 .6282 m .49196 .64672 L .49904 .63836 L p .707 .577 .707 r
F P
0 g
s
.49904 .63836 m .49904 .61983 L .49196 .6282 L p .707 .577 .707 r
F P
0 g
s
.31064 .73086 m .31064 .69381 L .29804 .68592 L p .707 .577 .707 r
F P
0 g
s
.74688 .62747 m .74688 .646 L .71504 .64678 L p .707 .577 .707 r
F P
0 g
s
.68566 .72987 m .68566 .69281 L .71504 .68943 L p .707 .577 .707 r
F P
0 g
s
.29515 .55746 m .29515 .50188 L .30223 .49352 L p .707 .577 .707 r
F P
0 g
s
.29804 .68592 m .29804 .72298 L .31064 .73086 L p .707 .577 .707 r
F P
0 g
s
.29804 .64327 m .29804 .62474 L .29515 .6162 L p .707 .577 .707 r
F P
0 g
s
.77805 .69056 m .77805 .72761 L .74688 .72571 L p .707 .577 .707 r
F P
0 g
s
.74688 .72571 m .74688 .68866 L .77805 .69056 L p .707 .577 .707 r
F P
0 g
s
.71504 .68943 m .71504 .72649 L .68566 .72987 L p .707 .577 .707 r
F P
0 g
s
.71504 .72649 m .71504 .68943 L .74688 .68866 L p .707 .577 .707 r
F P
0 g
s
.49196 .68938 m .49196 .72643 L .49904 .71807 L p .707 .577 .707 r
F P
0 g
s
.49904 .71807 m .49904 .68101 L .49196 .68938 L p .707 .577 .707 r
F P
0 g
s
.29515 .6162 m .29515 .63472 L .29804 .64327 L p .707 .577 .707 r
F P
0 g
s
.74688 .68866 m .74688 .72571 L .71504 .72649 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.30223 .49352 m .30223 .5491 L .29515 .55746 L p .707 .577 .707 r
F P
0 g
s
.49615 .49697 m .49615 .55256 L .48356 .54467 L p .707 .577 .707 r
F P
0 g
s
.48356 .54467 m .48356 .48909 L .49615 .49697 L p .707 .577 .707 r
F P
0 g
s
.29804 .72298 m .29804 .68592 L .29515 .67738 L p .707 .577 .707 r
F P
0 g
s
.49904 .61983 m .49904 .63836 L .49615 .62982 L p .707 .577 .707 r
F P
0 g
s
.49615 .62982 m .49615 .61129 L .49904 .61983 L p .707 .577 .707 r
F P
0 g
s
.29515 .67738 m .29515 .71443 L .29804 .72298 L p .707 .577 .707 r
F P
0 g
s
.30223 .5491 m .30223 .49352 L .3186 .48615 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29515 .63472 m .29515 .6162 L .30223 .60783 L p .707 .577 .707 r
F P
0 g
s
.49904 .68101 m .49904 .71807 L .49615 .70953 L p .707 .577 .707 r
F P
0 g
s
.49615 .70953 m .49615 .67247 L .49904 .68101 L p .707 .577 .707 r
F P
0 g
s
.30223 .60783 m .30223 .62636 L .29515 .63472 L p .707 .577 .707 r
F P
0 g
s
.3186 .48615 m .3186 .54173 L .30223 .5491 L p .707 .577 .707 r
F P
0 g
s
.48356 .48909 m .48356 .54467 L .4625 .53822 L p .707 .577 .707 r
F P
0 g
s
.4625 .53822 m .4625 .48263 L .48356 .48909 L p .707 .577 .707 r
F P
0 g
s
.29515 .71443 m .29515 .67738 L .30223 .66901 L p .707 .577 .707 r
F P
0 g
s
.49615 .61129 m .49615 .62982 L .48356 .62193 L p .707 .577 .707 r
F P
0 g
s
.48356 .62193 m .48356 .60341 L .49615 .61129 L p .707 .577 .707 r
F P
0 g
s
.3186 .54173 m .3186 .48615 L .34265 .4805 L p .707 .577 .707 r
F P
0 g
s
.30223 .66901 m .30223 .70607 L .29515 .71443 L p .707 .577 .707 r
F P
0 g
s
.30223 .62636 m .30223 .60783 L .3186 .60046 L p .707 .577 .707 r
F P
0 g
s
.49615 .67247 m .49615 .70953 L .48356 .70164 L p .707 .577 .707 r
F P
0 g
s
.48356 .70164 m .48356 .66459 L .49615 .67247 L p .707 .577 .707 r
F P
0 g
s
.3186 .60046 m .3186 .61899 L .30223 .62636 L p .707 .577 .707 r
F P
0 g
s
.4625 .48263 m .4625 .53822 L .43504 .53382 L p .707 .577 .707 r
F P
0 g
s
.43504 .53382 m .43504 .47824 L .4625 .48263 L p .707 .577 .707 r
F P
0 g
s
.34265 .4805 m .34265 .53608 L .3186 .54173 L p .707 .577 .707 r
F P
0 g
s
.34265 .53608 m .34265 .4805 L .37203 .47712 L p .707 .577 .707 r
F P
0 g
s
.48356 .60341 m .48356 .62193 L .4625 .61548 L p .707 .577 .707 r
F P
0 g
s
.4625 .61548 m .4625 .59695 L .48356 .60341 L p .707 .577 .707 r
F P
0 g
s
.30223 .70607 m .30223 .66901 L .3186 .66165 L p .707 .577 .707 r
F P
0 g
s
.43504 .47824 m .43504 .53382 L .40387 .53192 L p .707 .577 .707 r
F P
0 g
s
.40387 .53192 m .40387 .47634 L .43504 .47824 L p .707 .577 .707 r
F P
0 g
s
.3186 .61899 m .3186 .60046 L .34265 .59481 L p .707 .577 .707 r
F P
0 g
s
.37203 .5327 m .37203 .47712 L .40387 .47634 L p .707 .577 .707 r
F P
0 g
s
.37203 .47712 m .37203 .5327 L .34265 .53608 L p .707 .577 .707 r
F P
0 g
s
.3186 .66165 m .3186 .6987 L .30223 .70607 L p .707 .577 .707 r
F P
0 g
s
.40387 .47634 m .40387 .53192 L .37203 .5327 L p .707 .577 .707 r
F P
0 g
s
.34265 .59481 m .34265 .61334 L .3186 .61899 L p .707 .577 .707 r
F P
0 g
s
.48356 .66459 m .48356 .70164 L .4625 .69519 L p .707 .577 .707 r
F P
0 g
s
.4625 .69519 m .4625 .65813 L .48356 .66459 L p .707 .577 .707 r
F P
0 g
s
.4625 .59695 m .4625 .61548 L .43504 .61109 L p .707 .577 .707 r
F P
0 g
s
.43504 .61109 m .43504 .59256 L .4625 .59695 L p .707 .577 .707 r
F P
0 g
s
.3186 .6987 m .3186 .66165 L .34265 .656 L p .707 .577 .707 r
F P
0 g
s
.34265 .61334 m .34265 .59481 L .37203 .59144 L p .707 .577 .707 r
F P
0 g
s
.37203 .59144 m .37203 .60996 L .34265 .61334 L p .707 .577 .707 r
F P
0 g
s
.34265 .656 m .34265 .69305 L .3186 .6987 L p .707 .577 .707 r
F P
0 g
s
.43504 .59256 m .43504 .61109 L .40387 .60919 L p .707 .577 .707 r
F P
0 g
s
.40387 .60919 m .40387 .59066 L .43504 .59256 L p .707 .577 .707 r
F P
0 g
s
.4625 .65813 m .4625 .69519 L .43504 .6908 L p .707 .577 .707 r
F P
0 g
s
.43504 .6908 m .43504 .65374 L .4625 .65813 L p .707 .577 .707 r
F P
0 g
s
.37203 .60996 m .37203 .59144 L .40387 .59066 L p .707 .577 .707 r
F P
0 g
s
.40387 .59066 m .40387 .60919 L .37203 .60996 L p .707 .577 .707 r
F P
0 g
s
.34265 .69305 m .34265 .656 L .37203 .65262 L p .707 .577 .707 r
F P
0 g
s
.43504 .65374 m .43504 .6908 L .40387 .6889 L p .707 .577 .707 r
F P
0 g
s
.40387 .6889 m .40387 .65184 L .43504 .65374 L p .707 .577 .707 r
F P
0 g
s
.37203 .65262 m .37203 .68967 L .34265 .69305 L p .707 .577 .707 r
F P
0 g
s
.37203 .68967 m .37203 .65262 L .40387 .65184 L p .707 .577 .707 r
F P
0 g
s
.40387 .65184 m .40387 .6889 L .37203 .68967 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00Ogoo6000QWoo001gOol80005FUH00`00FUIJEP09FUH00`00
FUIJEP04FUH<001jOol007Aoo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00=JEPL007=oo`00L7oo100015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00@005YF0000075oo`00KWoo0P0025YF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006ioo`00K7oo0`002EYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo
001ZOol20002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Qoo`8000AJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
008006Qoo`00Igoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001VOol0
0`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eooa800003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00H7oo1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001LOol400000eYF001JEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001IOol30005FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000020008FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005Mo
o`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00EGoo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001DOol20004
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol0
05=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0000HOol90014Ool005=oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0000?Ool90004FUH00`00FUIJEP02FUH8000lOol005=oo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH00008Ool70004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
1000FUIJEUYF1@00=goo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000goo
1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
00000P00=7oo001COol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001oo`800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF009JEP80039oo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH3000`Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQL0
00IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool005=oo`03
001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03
001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001COol00`00FUH0
0004FUH00`00FUH000030006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH60003
FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF0000
0eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH00eYF10000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`04001JEP00FUH2
0005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUIJEP000UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`06001JEP00
001JEP001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH015YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005=oo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00EJEP03001JEUYF00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP80
02eoo`00Dgoo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;Goo001COol20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool005Aoo`05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00?goo4@001Goo00@005YFFUH000EJEP03001JEUYF00EJEP03001J
EUYF00EJEPD000EJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP02FUHB0004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000iOol60003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90005FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0UYF1`0025YF00<005YFFUH01UYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=Goo
100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000IJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001J
EP00008000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPD000AJEP04001JEUYF
FUH2000]Ool0039oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00=JEP<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYFFUH40008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH300000eYF001JEP02FUH2000]Ool0031oo`800003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002ioo`8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEQ/000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00800003FUH0000002eoo`00
;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEPT00003FUH005YF00YJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH02@0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF0`00;Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH000070003FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF1000
1EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00<005YF0000;Goo000/Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH50003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUH000020008FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000]Ool002aoo`03001JEP0000AJEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF0`00
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF1@0015YF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUIJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0015YF00<005YFFUH015YF00<005YFFUH00UYF5`001UYF00<0
05YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YF001JEP8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000aOol002aoo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEPH0
009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF009JEP@0009JEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00003FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH3000cOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEP0000<0009JEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP06FUH50003FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00001EYF1P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000`00
=Woo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUH00003FUH40005FUH01000FUIJEP000UYF00<005YFFUH00eYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YF00000`000eYF00@005YFFUH000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEPT000AJEP03001JEUYF00IJ
EP03001JEUYF009JEPD003Yoo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF
5@0000=JEP00FUH00P000eYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00
FUIJEP020004OolB000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPL000MJEP03001JEUYF
00MJEP04001JEP00FUH50002FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF1000
1UYF00<005YFFUH02EYF00<005YFFUH015YF0`000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUIJEQP003io
o`00;7oo00<005YF000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00@0
05YF0000009JEPL000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH0
0`00FUIJEP02FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF00001EYF00@005YFFUIJEPH000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP0000<003Yoo`00;7oo00<005YF00000eYF0`000UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00@005YF000000=JEP03001JEP0000800006FUH00000001JEP000UYF00@005YF
FUH000EJEPD000EJEP03001JEUYF00UJEP03001JEP000080009JEP03001JEP00009JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP@00003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<003Moo`00;7oo00@005YF
001JEP8000EJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH0
0`00FUIJEP02FUH60002FUH01000FUIJEP001EYF1@001EYF00<005YFFUH01eYF100000=JEP00FUH0
0UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000P00=7oo000/Ool01P00FUH00000FUH000EJEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUIJEP03FUH01000FUIJEUYF2000
15YF10001UYF00<005YFFUH00UYF1@001EYF00@005YFFUIJEP8000=JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00FUH200000eYF001JEP04FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000b
Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000FUIJEUYF4`000eYF00<0
05YFFUH015YF00D005YFFUIJEP0000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02FUHB0004FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH3000`Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP03001JEUYF00EJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF0005FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP02
FUH8000@Ool80003FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool002aoo`8000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00AJEP8000AJEP03001JEUYF
00EJEQL000=JEP03001JEUYF00AJEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP000080009JEP04001JEUYFFUH2000HOol5
0004FUH01@00FUIJEUYF0000;Woo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YF
FUH01EYF1@001EYF00<005YFFUH01EYF100000=JEP00FUH01P000eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YF00000`000eYF100025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<005YF00000eYF0`001EYF00@005YFFUIJEP8001eoo`<00003FUH005YF
009JEP8002eoo`00;Goo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJ
EP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEPD000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP00FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF0P0087oo0P000eYF0P00
;Goo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP05FUH30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP040006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH000020003FUH00`00FUIJEP03FUH01000FUIJEUYF0P008Woo0P0000=JEP000000;Goo
000`Ool30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP03FUH200000eYF
001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH400000eYF000000030004FUH01000FUIJEUYF0P0027oo0`0067oo1000;Goo000cOol300000eYF
001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YF000000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP8000AJEP<00003FUH005YF009JEP8000Moo`D001Eoo`800004FUH00000000]Ool003Io
o`D000AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF008000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05
001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20002FUH00`00FUH000020003FUH30003FUH20007Ool5000@Ool50003FUH00`00FUH0000]Ool0
03]ooaT00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH5000015YF
000005YF0P001goo1@002Goo1`000eYF00<005YFFUH00UYF00<005YF0000;Goo001COol00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00@005YFFUIJEQ/000=JEP03001J
EUYF00AJEP03001JEUYF009JEP8002ioo`00?goo5@0000=JEP00FUH00eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool003Moo`P000=JEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00<005YFFUH01EYF00<0
05YFFUH01UYF2P001eYF00<005YFFUH015YF00@005YF0000035oo`00<goo10000eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF2@0025YF200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00009JEP@00003FUH005YF00IJEPT0
00AJEP03001JEUYF009JEPT000EJEP<003=oo`00<Goo0`001UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YF000015YF00@005YFFUIJEPP0009JEP03001JEUYF00=JEP03001J
EUYF00MJEP03001JEUYF00AJEPH000AJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH01000FUIJEUYF2@0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH003Ioo`00;goo0P000UYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000eYF1@0015YF0P0000Eo
o`00FUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP@00003FUH005YF009JEP04001JEUYF
000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00002FUH60002FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002000d
Ool002ioo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEQD00003FUH005YF008000AJ
EPH00003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF009JEPL000=JEP<0
00=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH0
05YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YFFUH00UYF0P00<Woo000]Ool20004FUH00`00FUIJEP03FUH6000DOol01P00FUH0
0000FUH000EJEP04001JEUYFFUHK0003FUH00`00FUIJEP04FUH00`00FUIJEP0200001EYF001JEUYF
000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000=JEP03001J
EUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00=JEP<0031oo`00;7oo00<005YF000015YF00<005YF00000`006Woo0P000eYF00<005YFFUH0
0eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00@005YFFUIJEP<0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF00000eYF0`00
7Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000/Ool01000FUH005YF0P008Goo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00L005YFFUIJEP00FUH00002
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004
FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool01000FUH000008goo0P000eYF00<005YF
FUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000/Ool2
00000eYF0000000GOol30009Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP8000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP04001JEUYFFUH2000]Ool002aoo`8000=JEP<001=oo`D000Uoo`800003FUH005YF00AJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP05
001JEUYFFUH00004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP02FUHH0005FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo000/Ool20003FUH00`00FUIJEP05000>Ool5000;Ool30004FUH00`00FUIJEP05
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
1EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
15YF00<005YFFUH00UYF1P0067oo100000=JEP00FUH015YF00@005YFFUIJEP8002eoo`00;Goo00D0
05YFFUIJEP0000EJEP03001JEP0000<000Yoo`D000Yoo`L00003FUH005YF00IJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP<000MJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEP0000800003FUH0
000001moo`@000=JEP04001JEUYFFUH2000]Ool002eoo`05001JEUYFFUH00005FUH00`00FUIJEP03
FUHI0003FUH01000FUIJEUYF1@0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YF00000`002UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF2`007Goo20000eYF0P00;Goo000^Ool200000eYF001JEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH0
00070004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50002FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH005YF0P0015YF00@005YF
FUIJEPT0019oo`D000EJEP04001JEUYF0002FUH2000]Ool0031oo`<000AJEP03001JEUYF00EJEQ40
0003FUH005YF00IJEP03001JEUYF00AJEP06001JEP00001oo`000UYF00<005YF00004P001eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000P001EYF00<005YFFUH01EYF00<005YFFUH00UYF4P000eYF00<005YFFUH015YF00@005YF
FUIJEP@002eoo`00<goo0`0000=JEP00FUH01P000eYF00<005YFFUH01UYF00<005YFFUH00UYF2000
00=JEP00FUH00UYF1@000goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00=Goo100000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEPH000Moo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3000]Ool0039oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP00008000Aoo`04
001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP04FUH<0006FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00FUH0000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH=000;FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP@0009JEP03001J
EUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001J
EUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Goo
0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00D000QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00@000IJEP03001JEUYF009J
EP03001JEP00008000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH2000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP02FUH00`00FUH00003
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF
00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP<00003FUH005YF00=JEP03001JEP00009JEP@00003FUH005YF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH01000FUH000001eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@005YF000000AJEP03
001JEP00009JEP04001JEUYFFUH50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH7000hOol002aoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001J
EP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P000UYF00<005YF00000UYF00<005YFFUH015YF00<005YF00006P00?goo
000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUHI0004FUH00`00FUIJEP03FUH0
1P00FUIJEP00FUH000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP<00003FUH00000008000EJEP<0
05Yoo`00;7oo00<005YF000015YF00@005YFFUIJEPP001Uoo`H000AJEP03001JEUYF008000AJEP03
001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00MJEP03001JEUYF00AJEP800004FUH005YFFUH6001MOol002aoo`03001JEP0000=JEPD0
02Ioo`@00004FUH005YFFUH20004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000001EYF
00<005YF00000P00Fgoo000/Ool01000FUH005YF0P0015YF1@006goo1`000eYF0`000UYF0P0015YF
00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF009JEP8005Uoo`00;7oo
00H005YF000005YF0005FUH01000FUIJEUYF20002Woo2@000eYF00<005YFFUH015YF00<005YFFUH0
100015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH000EJEP03001JEUYF00=JEP<005Mo
o`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001JEUYF
00EJEP03001JEUYF00AJEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00
FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol002aoo`8000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP07
001JEUYFFUH005YF000015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0`001UYF00<005YFFUH00eYF
00D005YFFUIJEP0005Eoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH30002FUH0
0`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00E7oo000/Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009oo`<000MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001J
EUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000]Ool01@00
FUIJEUYF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH015YF00@005YFFUIJEP8000Eoo`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEP000005FUH00`00FUIJEP04FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000^Ool200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
27oo0P0015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF1P0015YF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8005Aoo`00<7oo
0`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YF000000]oo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00=JEP<000Ioo`P000=JEP03001JEUYF00=JEP04001JEUYFFUH2001D
Ool003=oo`<00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03
001JEUYF00=JEP<0011oo`@000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEP0000<0015oo`D000AJEP04001JEUYFFUH2001DOol003Ioo`<000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000<001Moo`H0009JEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00=JEPL001Moo`H00003FUH005YF009JEP8005Aoo`00>Goo10000UYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1@008Goo8P006Goo1@001EYF0`000eYF0P00
E7oo000mOolI000hOol00`00FUH000020005FUH00`00FUIJEP03FUHI0003FUH00`00FUIJEP04FUH0
0`00FUIJEP0200000eYF0000001DOol008ioo`80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<0
05Aoo`00SWoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF0`00E7oo002>Ool20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0001DOol008moo`04001JEUYF0005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH2001EOol008moo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001EOol0091oo`<000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001J
EUYFFUH2001FOol0099oo`8000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEP00001HOol009Aoo`<00003FUH005YF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5001JOol009Moo`D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL005moo`00W7oo2@0015YF00<005YFFUH0
0UYF2@00IWoo002UOol9001_Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59613 .74726 m .59613 .7102 L .56496 .7083 L p .707 .577 .707 r
F P
0 g
s
.59613 .7102 m .59613 .74726 L .62796 .74648 L p .707 .577 .707 r
F P
0 g
s
.62796 .74648 m .62796 .70942 L .59613 .7102 L p .707 .577 .707 r
F P
0 g
s
.62796 .70942 m .62796 .74648 L .65735 .7431 L p .707 .577 .707 r
F P
0 g
s
.65735 .7431 m .65734 .70604 L .62796 .70942 L p .707 .577 .707 r
F P
0 g
s
.59613 .7835 m .59613 .72792 L .56496 .72602 L p .707 .577 .707 r
F P
0 g
s
.59613 .72792 m .59613 .7835 L .62796 .78272 L p .707 .577 .707 r
F P
0 g
s
.62796 .78272 m .62796 .72714 L .59613 .72792 L p .707 .577 .707 r
F P
0 g
s
.56496 .74535 m .56496 .7083 L .5375 .70391 L p .707 .577 .707 r
F P
0 g
s
.56496 .7083 m .56496 .74535 L .59613 .74726 L p .707 .577 .707 r
F P
0 g
s
.62796 .72714 m .62796 .78272 L .65735 .77935 L p .707 .577 .707 r
F P
0 g
s
.65735 .77935 m .65734 .72376 L .62796 .72714 L p .707 .577 .707 r
F P
0 g
s
.56496 .7816 m .56496 .72602 L .5375 .72163 L p .707 .577 .707 r
F P
0 g
s
.56496 .72602 m .56496 .7816 L .59613 .7835 L p .707 .577 .707 r
F P
0 g
s
.65734 .70604 m .65735 .7431 L .6814 .73745 L p .707 .577 .707 r
F P
0 g
s
.6814 .73745 m .6814 .70039 L .65734 .70604 L p .707 .577 .707 r
F P
0 g
s
.5375 .70391 m .5375 .74096 L .56496 .74535 L p .707 .577 .707 r
F P
0 g
s
.65734 .72376 m .65735 .77935 L .6814 .7737 L p .707 .577 .707 r
F P
0 g
s
.6814 .7737 m .6814 .71811 L .65734 .72376 L p .707 .577 .707 r
F P
0 g
s
.5375 .74096 m .5375 .70391 L .51644 .69745 L p .707 .577 .707 r
F P
0 g
s
.5375 .72163 m .5375 .77721 L .56496 .7816 L p .707 .577 .707 r
F P
0 g
s
.5375 .77721 m .5375 .72163 L .51644 .71517 L p .707 .577 .707 r
F P
0 g
s
.51644 .69745 m .51644 .73451 L .5375 .74096 L p .707 .577 .707 r
F P
0 g
s
.6814 .70039 m .6814 .73745 L .69777 .73008 L p .707 .577 .707 r
F P
0 g
s
.69777 .73008 m .69777 .69303 L .6814 .70039 L p .707 .577 .707 r
F P
0 g
s
.6814 .71811 m .6814 .7737 L .69777 .76633 L p .707 .577 .707 r
F P
0 g
s
.69777 .76633 m .69777 .71075 L .6814 .71811 L p .707 .577 .707 r
F P
0 g
s
.51644 .71517 m .51644 .77075 L .5375 .77721 L p .707 .577 .707 r
F P
0 g
s
.51644 .73451 m .51644 .69745 L .50385 .68957 L p .707 .577 .707 r
F P
0 g
s
.59613 .91063 m .59613 .89211 L .56496 .89021 L p .707 .577 .707 r
F P
0 g
s
.59613 .89211 m .59613 .91063 L .62796 .90986 L p .707 .577 .707 r
F P
0 g
s
.62796 .90986 m .62796 .89133 L .59613 .89211 L p .707 .577 .707 r
F P
0 g
s
.51644 .77075 m .51644 .71517 L .50385 .70729 L p .707 .577 .707 r
F P
0 g
s
.62796 .89133 m .62796 .90986 L .65735 .90648 L p .707 .577 .707 r
F P
0 g
s
.65735 .90648 m .65735 .88795 L .62796 .89133 L p .707 .577 .707 r
F P
0 g
s
.56496 .89021 m .56496 .90873 L .59613 .91063 L p .707 .577 .707 r
F P
0 g
s
.50385 .68957 m .50385 .72662 L .51644 .73451 L p .707 .577 .707 r
F P
0 g
s
.56496 .90873 m .56496 .89021 L .5375 .88581 L p .707 .577 .707 r
F P
0 g
s
.69777 .69303 m .69777 .73008 L .70485 .72172 L p .707 .577 .707 r
F P
0 g
s
.70485 .72172 m .70485 .68466 L .69777 .69303 L p .707 .577 .707 r
F P
0 g
s
.5375 .88581 m .5375 .90434 L .56496 .90873 L p .707 .577 .707 r
F P
0 g
s
.65735 .88795 m .65735 .90648 L .6814 .90083 L p .707 .577 .707 r
F P
0 g
s
.6814 .90083 m .6814 .8823 L .65735 .88795 L p .707 .577 .707 r
F P
0 g
s
.50385 .70729 m .50385 .76287 L .51644 .77075 L p .707 .577 .707 r
F P
0 g
s
.69777 .71075 m .69777 .76633 L .70485 .75796 L p .707 .577 .707 r
F P
0 g
s
.70485 .75796 m .70485 .70238 L .69777 .71075 L p .707 .577 .707 r
F P
0 g
s
.5375 .90434 m .5375 .88581 L .51644 .87936 L p .707 .577 .707 r
F P
0 g
s
.50385 .72662 m .50385 .68957 L .50095 .68103 L p .707 .577 .707 r
F P
0 g
s
.51644 .87936 m .51644 .89789 L .5375 .90434 L p .707 .577 .707 r
F P
0 g
s
.50385 .76287 m .50385 .70729 L .50095 .69875 L p .707 .577 .707 r
F P
0 g
s
.50095 .68103 m .50095 .71808 L .50385 .72662 L p .707 .577 .707 r
F P
0 g
s
.6814 .8823 m .6814 .90083 L .69777 .89346 L p .707 .577 .707 r
F P
0 g
s
.69777 .89346 m .69777 .87493 L .6814 .8823 L p .707 .577 .707 r
F P
0 g
s
.70485 .68466 m .70485 .72172 L .70195 .71318 L p .707 .577 .707 r
F P
0 g
s
.70195 .71318 m .70195 .67612 L .70485 .68466 L p .707 .577 .707 r
F P
0 g
s
.49044 .81061 m .49044 .30872 L .44643 .30603 L p .707 .577 .707 r
F P
0 g
s
.50095 .69875 m .50095 .75433 L .50385 .76287 L p .707 .577 .707 r
F P
0 g
s
.50095 .71808 m .50095 .68103 L .50804 .67266 L p .707 .577 .707 r
F P
0 g
s
.50095 .75433 m .50095 .69875 L .50804 .69038 L p .707 .577 .707 r
F P
0 g
s
.50804 .67266 m .50804 .70972 L .50095 .71808 L p .707 .577 .707 r
F P
0 g
s
.50804 .69038 m .50804 .74596 L .50095 .75433 L p .707 .577 .707 r
F P
0 g
s
.50804 .70972 m .50804 .67266 L .5244 .6653 L p .707 .577 .707 r
F P
0 g
s
.50804 .74596 m .50804 .69038 L .5244 .68301 L p .707 .577 .707 r
F P
0 g
s
.5244 .6653 m .5244 .70235 L .50804 .70972 L p .707 .577 .707 r
F P
0 g
s
.5244 .68301 m .5244 .7386 L .50804 .74596 L p .707 .577 .707 r
F P
0 g
s
.5244 .70235 m .5244 .6653 L .54846 .65965 L p .707 .577 .707 r
F P
0 g
s
.5244 .7386 m .5244 .68301 L .54846 .67736 L p .707 .577 .707 r
F P
0 g
s
.54846 .65965 m .54846 .6967 L .5244 .70235 L p .707 .577 .707 r
F P
0 g
s
.54846 .67736 m .54846 .73295 L .5244 .7386 L p .707 .577 .707 r
F P
0 g
s
.49044 .30872 m .49044 .81061 L .53538 .80951 L p .707 .577 .707 r
F P
0 g
s
.53538 .80951 m .53538 .30762 L .49044 .30872 L p .707 .577 .707 r
F P
0 g
s
.51644 .89789 m .51644 .87936 L .50385 .87148 L p .707 .577 .707 r
F P
0 g
s
.70485 .70238 m .70485 .75796 L .70195 .74942 L p .707 .577 .707 r
F P
0 g
s
.70195 .74942 m .70195 .69384 L .70485 .70238 L p .707 .577 .707 r
F P
0 g
s
.54846 .6967 m .54846 .65965 L .57784 .65627 L p .707 .577 .707 r
F P
0 g
s
.54846 .73295 m .54846 .67736 L .57784 .67399 L p .707 .577 .707 r
F P
0 g
s
.57784 .65627 m .57784 .69332 L .54846 .6967 L p .707 .577 .707 r
F P
0 g
s
.57784 .67399 m .57784 .72957 L .54846 .73295 L p .707 .577 .707 r
F P
0 g
s
.53538 .30762 m .53538 .80951 L .57686 .80474 L p .707 .577 .707 r
F P
0 g
s
.57686 .80474 m .57686 .30285 L .53538 .30762 L p .707 .577 .707 r
F P
0 g
s
.50385 .87148 m .50385 .89 L .51644 .89789 L p .707 .577 .707 r
F P
0 g
s
.44643 .80792 m .44643 .30603 L .40766 .29983 L p .707 .577 .707 r
F P
0 g
s
.44643 .30603 m .44643 .80792 L .49044 .81061 L p .707 .577 .707 r
F P
0 g
s
.69777 .87493 m .69777 .89346 L .70485 .8851 L p .707 .577 .707 r
F P
0 g
s
.70485 .8851 m .70485 .86657 L .69777 .87493 L p .707 .577 .707 r
F P
0 g
s
.57784 .69332 m .57784 .65627 L .60968 .65549 L p .707 .577 .707 r
F P
0 g
s
.60968 .65549 m .60968 .69254 L .57784 .69332 L p .707 .577 .707 r
F P
0 g
s
.57784 .72957 m .57784 .67399 L .60968 .67321 L p .707 .577 .707 r
F P
0 g
s
.60968 .67321 m .60968 .72879 L .57784 .72957 L p .707 .577 .707 r
F P
0 g
s
.57686 .30285 m .57686 .80474 L .61082 .79676 L p .707 .577 .707 r
F P
0 g
s
.64085 .65739 m .64085 .69444 L .60968 .69254 L p .707 .577 .707 r
F P
0 g
s
.60968 .69254 m .60968 .65549 L .64085 .65739 L p .707 .577 .707 r
F P
0 g
s
.64085 .67511 m .64085 .73069 L .60968 .72879 L p .707 .577 .707 r
F P
0 g
s
.60968 .72879 m .60968 .67321 L .64085 .67511 L p .707 .577 .707 r
F P
0 g
s
.61082 .79676 m .61082 .29487 L .57686 .30285 L p .707 .577 .707 r
F P
0 g
s
.70195 .67612 m .70195 .71318 L .68936 .70529 L p .707 .577 .707 r
F P
0 g
s
.68936 .70529 m .68936 .66824 L .70195 .67612 L p .707 .577 .707 r
F P
0 g
s
.50385 .89 m .50385 .87148 L .50095 .86293 L p .707 .577 .707 r
F P
0 g
s
.40766 .80172 m .40766 .29983 L .37794 .29072 L p .707 .577 .707 r
F P
0 g
s
.40766 .29983 m .40766 .80172 L .44643 .80792 L p .707 .577 .707 r
F P
0 g
s
.70195 .69384 m .70195 .74942 L .68936 .74154 L p .707 .577 .707 r
F P
0 g
s
.68936 .74154 m .68936 .68596 L .70195 .69384 L p .707 .577 .707 r
F P
0 g
s
.50095 .86293 m .50095 .88146 L .50385 .89 L p .707 .577 .707 r
F P
0 g
s
.25312 .71044 m .25312 .67339 L .22195 .67148 L p .707 .577 .707 r
F P
0 g
s
.25312 .67339 m .25312 .71044 L .28495 .70966 L p .707 .577 .707 r
F P
0 g
s
.28495 .70966 m .28495 .67261 L .25312 .67339 L p .707 .577 .707 r
F P
0 g
s
.28495 .67261 m .28495 .70966 L .31434 .70628 L p .707 .577 .707 r
F P
0 g
s
.31434 .70628 m .31434 .66923 L .28495 .67261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.25312 .74669 m .25312 .6911 L .22195 .6892 L p .707 .577 .707 r
F P
0 g
s
.25312 .6911 m .25312 .74669 L .28495 .74591 L p .707 .577 .707 r
F P
0 g
s
.28495 .74591 m .28495 .69033 L .25312 .6911 L p .707 .577 .707 r
F P
0 g
s
.22195 .70854 m .22195 .67148 L .19449 .66709 L p .707 .577 .707 r
F P
0 g
s
.22195 .67148 m .22195 .70854 L .25312 .71044 L p .707 .577 .707 r
F P
0 g
s
.28495 .69033 m .28495 .74591 L .31434 .74253 L p .707 .577 .707 r
F P
0 g
s
.31434 .74253 m .31434 .68695 L .28495 .69033 L p .707 .577 .707 r
F P
0 g
s
.70485 .86657 m .70485 .8851 L .70195 .87655 L p .707 .577 .707 r
F P
0 g
s
.70195 .87655 m .70195 .85803 L .70485 .86657 L p .707 .577 .707 r
F P
0 g
s
.61082 .29487 m .61082 .79676 L .63393 .78636 L p .707 .577 .707 r
F P
0 g
s
.63393 .78636 m .63393 .28447 L .61082 .29487 L p .707 .577 .707 r
F P
0 g
s
.22195 .74479 m .22195 .6892 L .19449 .68481 L p .707 .577 .707 r
F P
0 g
s
.22195 .6892 m .22195 .74479 L .25312 .74669 L p .707 .577 .707 r
F P
0 g
s
.31434 .66923 m .31434 .70628 L .33839 .70063 L p .707 .577 .707 r
F P
0 g
s
.33839 .70063 m .33839 .66358 L .31434 .66923 L p .707 .577 .707 r
F P
0 g
s
.19449 .66709 m .19449 .70415 L .22195 .70854 L p .707 .577 .707 r
F P
0 g
s
.68936 .66824 m .68936 .70529 L .66831 .69884 L p .707 .577 .707 r
F P
0 g
s
.66831 .69884 m .66831 .66178 L .68936 .66824 L p .707 .577 .707 r
F P
0 g
s
.31434 .68695 m .31434 .74253 L .33839 .73688 L p .707 .577 .707 r
F P
0 g
s
.33839 .73688 m .33839 .6813 L .31434 .68695 L p .707 .577 .707 r
F P
0 g
s
.19449 .70415 m .19449 .66709 L .17343 .66064 L p .707 .577 .707 r
F P
0 g
s
.50095 .88146 m .50095 .86293 L .50804 .85457 L p .707 .577 .707 r
F P
0 g
s
.68936 .68596 m .68936 .74154 L .66831 .73508 L p .707 .577 .707 r
F P
0 g
s
.66831 .73508 m .66831 .6795 L .68936 .68596 L p .707 .577 .707 r
F P
0 g
s
.37794 .79261 m .37794 .29072 L .36016 .27959 L p .707 .577 .707 r
F P
0 g
s
.37794 .29072 m .37794 .79261 L .40766 .80172 L p .707 .577 .707 r
F P
0 g
s
.19449 .68481 m .19449 .74039 L .22195 .74479 L p .707 .577 .707 r
F P
0 g
s
.19449 .74039 m .19449 .68481 L .17343 .67836 L p .707 .577 .707 r
F P
0 g
s
.50804 .85457 m .50804 .8731 L .50095 .88146 L p .707 .577 .707 r
F P
0 g
s
.17343 .66064 m .17343 .69769 L .19449 .70415 L p .707 .577 .707 r
F P
0 g
s
.33839 .66358 m .33839 .70063 L .35476 .69327 L p .707 .577 .707 r
F P
0 g
s
.35476 .69327 m .35476 .65621 L .33839 .66358 L p .707 .577 .707 r
F P
0 g
s
.33839 .6813 m .33839 .73688 L .35476 .72951 L p .707 .577 .707 r
F P
0 g
s
.35476 .72951 m .35476 .67393 L .33839 .6813 L p .707 .577 .707 r
F P
0 g
s
.70195 .85803 m .70195 .87655 L .68936 .86867 L p .707 .577 .707 r
F P
0 g
s
.68936 .86867 m .68936 .85014 L .70195 .85803 L p .707 .577 .707 r
F P
0 g
s
.66831 .66178 m .66831 .69884 L .64085 .69444 L p .707 .577 .707 r
F P
0 g
s
.64085 .69444 m .64085 .65739 L .66831 .66178 L p .707 .577 .707 r
F P
0 g
s
.17343 .67836 m .17343 .73394 L .19449 .74039 L p .707 .577 .707 r
F P
0 g
s
.17343 .69769 m .17343 .66064 L .16084 .65275 L p .707 .577 .707 r
F P
0 g
s
.66831 .6795 m .66831 .73508 L .64085 .73069 L p .707 .577 .707 r
F P
0 g
s
.64085 .73069 m .64085 .67511 L .66831 .6795 L p .707 .577 .707 r
F P
0 g
s
.63393 .28447 m .63393 .78636 L .64393 .77455 L p .707 .577 .707 r
F P
0 g
s
.64393 .77455 m .64393 .27266 L .63393 .28447 L p .707 .577 .707 r
F P
0 g
s
.25312 .87382 m .25312 .85529 L .22195 .85339 L p .707 .577 .707 r
F P
0 g
s
.25312 .85529 m .25312 .87382 L .28495 .87304 L p .707 .577 .707 r
F P
0 g
s
.28495 .87304 m .28495 .85452 L .25312 .85529 L p .707 .577 .707 r
F P
0 g
s
.17343 .73394 m .17343 .67836 L .16084 .67047 L p .707 .577 .707 r
F P
0 g
s
.50804 .8731 m .50804 .85457 L .5244 .8472 L p .707 .577 .707 r
F P
0 g
s
.28495 .85452 m .28495 .87304 L .31434 .86966 L p .707 .577 .707 r
F P
0 g
s
.31434 .86966 m .31434 .85114 L .28495 .85452 L p .707 .577 .707 r
F P
0 g
s
.22195 .85339 m .22195 .87192 L .25312 .87382 L p .707 .577 .707 r
F P
0 g
s
.16084 .65275 m .16084 .68981 L .17343 .69769 L p .707 .577 .707 r
F P
0 g
s
.22195 .87192 m .22195 .85339 L .19449 .849 L p .707 .577 .707 r
F P
0 g
s
.5244 .8472 m .5244 .86573 L .50804 .8731 L p .707 .577 .707 r
F P
0 g
s
.35476 .65621 m .35476 .69327 L .36184 .6849 L p .707 .577 .707 r
F P
0 g
s
.36184 .6849 m .36184 .64785 L .35476 .65621 L p .707 .577 .707 r
F P
0 g
s
.19449 .849 m .19449 .86753 L .22195 .87192 L p .707 .577 .707 r
F P
0 g
s
.31434 .85114 m .31434 .86966 L .33839 .86401 L p .707 .577 .707 r
F P
0 g
s
.33839 .86401 m .33839 .84549 L .31434 .85114 L p .707 .577 .707 r
F P
0 g
s
.16084 .67047 m .16084 .72606 L .17343 .73394 L p .707 .577 .707 r
F P
0 g
s
.35476 .67393 m .35476 .72951 L .36184 .72115 L p .707 .577 .707 r
F P
0 g
s
.36184 .72115 m .36184 .66557 L .35476 .67393 L p .707 .577 .707 r
F P
0 g
s
.36184 .64785 m .36184 .6849 L .35894 .67636 L p .707 .577 .707 r
F P
0 g
s
.35894 .67636 m .35894 .63931 L .36184 .64785 L p .707 .577 .707 r
F P
0 g
s
.36184 .66557 m .36184 .72115 L .35894 .71261 L p .707 .577 .707 r
F P
0 g
s
.35894 .71261 m .35894 .65702 L .36184 .66557 L p .707 .577 .707 r
F P
0 g
s
.36016 .78148 m .36016 .27959 L .35607 .26753 L p .707 .577 .707 r
F P
0 g
s
.36016 .27959 m .36016 .78148 L .37794 .79261 L p .707 .577 .707 r
F P
0 g
s
.68936 .85014 m .68936 .86867 L .66831 .86222 L p .707 .577 .707 r
F P
0 g
s
.66831 .86222 m .66831 .84369 L .68936 .85014 L p .707 .577 .707 r
F P
0 g
s
.19449 .86753 m .19449 .849 L .17343 .84255 L p .707 .577 .707 r
F P
0 g
s
.16084 .68981 m .16084 .65275 L .15794 .64421 L p .707 .577 .707 r
F P
0 g
s
.17343 .84255 m .17343 .86107 L .19449 .86753 L p .707 .577 .707 r
F P
0 g
s
.16084 .72606 m .16084 .67047 L .15794 .66193 L p .707 .577 .707 r
F P
0 g
s
.5244 .86573 m .5244 .8472 L .54846 .84155 L p .707 .577 .707 r
F P
0 g
s
.15794 .64421 m .15794 .68127 L .16084 .68981 L p .707 .577 .707 r
F P
0 g
s
.54846 .84155 m .54846 .86008 L .5244 .86573 L p .707 .577 .707 r
F P
0 g
s
.33839 .84549 m .33839 .86401 L .35476 .85665 L p .707 .577 .707 r
F P
0 g
s
.35476 .85665 m .35476 .83812 L .33839 .84549 L p .707 .577 .707 r
F P
0 g
s
.64393 .27266 m .64393 .77455 L .63984 .76249 L p .707 .577 .707 r
F P
0 g
s
.63984 .76249 m .63984 .2606 L .64393 .27266 L p .707 .577 .707 r
F P
0 g
s
.66831 .84369 m .66831 .86222 L .64085 .85782 L p .707 .577 .707 r
F P
0 g
s
.64085 .85782 m .64085 .8393 L .66831 .84369 L p .707 .577 .707 r
F P
0 g
s
.15794 .66193 m .15794 .71751 L .16084 .72606 L p .707 .577 .707 r
F P
0 g
s
.17343 .86107 m .17343 .84255 L .16084 .83466 L p .707 .577 .707 r
F P
0 g
s
.54846 .86008 m .54846 .84155 L .57784 .83817 L p .707 .577 .707 r
F P
0 g
s
.16084 .83466 m .16084 .85319 L .17343 .86107 L p .707 .577 .707 r
F P
0 g
s
.15794 .68127 m .15794 .64421 L .16503 .63585 L p .707 .577 .707 r
F P
0 g
s
.57784 .83817 m .57784 .8567 L .54846 .86008 L p .707 .577 .707 r
F P
0 g
s
.64085 .8393 m .64085 .85782 L .60968 .85592 L p .707 .577 .707 r
F P
0 g
s
.60968 .85592 m .60968 .8374 L .64085 .8393 L p .707 .577 .707 r
F P
0 g
s
.35894 .63931 m .35894 .67636 L .34635 .66848 L p .707 .577 .707 r
F P
0 g
s
.34635 .66848 m .34635 .63142 L .35894 .63931 L p .707 .577 .707 r
F P
0 g
s
.35894 .65702 m .35894 .71261 L .34635 .70472 L p .707 .577 .707 r
F P
0 g
s
.34635 .70472 m .34635 .64914 L .35894 .65702 L p .707 .577 .707 r
F P
0 g
s
.35607 .26753 m .35607 .76942 L .36016 .78148 L p .707 .577 .707 r
F P
0 g
s
.35607 .76942 m .35607 .26753 L .36607 .25572 L p .707 .577 .707 r
F P
0 g
s
.15794 .71751 m .15794 .66193 L .16503 .65357 L p .707 .577 .707 r
F P
0 g
s
.57784 .8567 m .57784 .83817 L .60968 .8374 L p .707 .577 .707 r
F P
0 g
s
.35476 .83812 m .35476 .85665 L .36184 .84828 L p .707 .577 .707 r
F P
0 g
s
.36184 .84828 m .36184 .82975 L .35476 .83812 L p .707 .577 .707 r
F P
0 g
s
.60968 .8374 m .60968 .85592 L .57784 .8567 L p .707 .577 .707 r
F P
0 g
s
.16503 .63585 m .16503 .6729 L .15794 .68127 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16084 .85319 m .16084 .83466 L .15794 .82612 L p .707 .577 .707 r
F P
0 g
s
.16503 .65357 m .16503 .70915 L .15794 .71751 L p .707 .577 .707 r
F P
0 g
s
.15794 .82612 m .15794 .84465 L .16084 .85319 L p .707 .577 .707 r
F P
0 g
s
.63984 .2606 m .63984 .76249 L .62206 .75136 L p .707 .577 .707 r
F P
0 g
s
.62206 .75136 m .62206 .24947 L .63984 .2606 L p .707 .577 .707 r
F P
0 g
s
.16503 .6729 m .16503 .63585 L .1814 .62848 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16503 .70915 m .16503 .65357 L .1814 .6462 L p .707 .577 .707 r
F P
0 g
s
.36184 .82975 m .36184 .84828 L .35894 .83974 L p .707 .577 .707 r
F P
0 g
s
.35894 .83974 m .35894 .82121 L .36184 .82975 L p .707 .577 .707 r
F P
0 g
s
.1814 .62848 m .1814 .66553 L .16503 .6729 L p .707 .577 .707 r
F P
0 g
s
.34635 .63142 m .34635 .66848 L .3253 .66202 L p .707 .577 .707 r
F P
0 g
s
.3253 .66202 m .3253 .62497 L .34635 .63142 L p .707 .577 .707 r
F P
0 g
s
.36607 .75761 m .36607 .25572 L .38918 .24532 L p .707 .577 .707 r
F P
0 g
s
.36607 .25572 m .36607 .75761 L .35607 .76942 L p .707 .577 .707 r
F P
0 g
s
.1814 .6462 m .1814 .70178 L .16503 .70915 L p .707 .577 .707 r
F P
0 g
s
.15794 .84465 m .15794 .82612 L .16503 .81775 L p .707 .577 .707 r
F P
0 g
s
.34635 .64914 m .34635 .70472 L .3253 .69827 L p .707 .577 .707 r
F P
0 g
s
.3253 .69827 m .3253 .64269 L .34635 .64914 L p .707 .577 .707 r
F P
0 g
s
.16503 .81775 m .16503 .83628 L .15794 .84465 L p .707 .577 .707 r
F P
0 g
s
.1814 .66553 m .1814 .62848 L .20545 .62283 L p .707 .577 .707 r
F P
0 g
s
.1814 .70178 m .1814 .6462 L .20545 .64055 L p .707 .577 .707 r
F P
0 g
s
.20545 .62283 m .20545 .65989 L .1814 .66553 L p .707 .577 .707 r
F P
0 g
s
.35894 .82121 m .35894 .83974 L .34635 .83186 L p .707 .577 .707 r
F P
0 g
s
.34635 .83186 m .34635 .81333 L .35894 .82121 L p .707 .577 .707 r
F P
0 g
s
.3253 .62497 m .3253 .66202 L .29784 .65763 L p .707 .577 .707 r
F P
0 g
s
.29784 .65763 m .29784 .62057 L .3253 .62497 L p .707 .577 .707 r
F P
0 g
s
.62206 .24947 m .62206 .75136 L .59233 .74225 L p .707 .577 .707 r
F P
0 g
s
.59233 .74225 m .59233 .24036 L .62206 .24947 L p .707 .577 .707 r
F P
0 g
s
.3253 .64269 m .3253 .69827 L .29784 .69388 L p .707 .577 .707 r
F P
0 g
s
.29784 .69388 m .29784 .63829 L .3253 .64269 L p .707 .577 .707 r
F P
0 g
s
.20545 .65989 m .20545 .62283 L .23483 .61945 L p .707 .577 .707 r
F P
0 g
s
.20545 .64055 m .20545 .69613 L .1814 .70178 L p .707 .577 .707 r
F P
0 g
s
.16503 .83628 m .16503 .81775 L .1814 .81039 L p .707 .577 .707 r
F P
0 g
s
.20545 .69613 m .20545 .64055 L .23483 .63717 L p .707 .577 .707 r
F P
0 g
s
.38918 .24532 m .38918 .74721 L .36607 .75761 L p .707 .577 .707 r
F P
0 g
s
.38918 .74721 m .38918 .24532 L .42314 .23734 L p .707 .577 .707 r
F P
0 g
s
.29784 .62057 m .29784 .65763 L .26667 .65573 L p .707 .577 .707 r
F P
0 g
s
.26667 .65573 m .26667 .61867 L .29784 .62057 L p .707 .577 .707 r
F P
0 g
s
.1814 .81039 m .1814 .82891 L .16503 .83628 L p .707 .577 .707 r
F P
0 g
s
.23483 .61945 m .23483 .65651 L .20545 .65989 L p .707 .577 .707 r
F P
0 g
s
.23483 .65651 m .23483 .61945 L .26667 .61867 L p .707 .577 .707 r
F P
0 g
s
.29784 .63829 m .29784 .69388 L .26667 .69198 L p .707 .577 .707 r
F P
0 g
s
.26667 .69198 m .26667 .63639 L .29784 .63829 L p .707 .577 .707 r
F P
0 g
s
.26667 .61867 m .26667 .65573 L .23483 .65651 L p .707 .577 .707 r
F P
0 g
s
.73333 .65522 m .73333 .61816 L .70216 .61626 L p .707 .577 .707 r
F P
0 g
s
.73333 .61816 m .73333 .65522 L .76517 .65444 L p .707 .577 .707 r
F P
0 g
s
.76517 .65444 m .76517 .61739 L .73333 .61816 L p .707 .577 .707 r
F P
0 g
s
.23483 .69275 m .23483 .63717 L .26667 .63639 L p .707 .577 .707 r
F P
0 g
s
.23483 .63717 m .23483 .69275 L .20545 .69613 L p .707 .577 .707 r
F P
0 g
s
.76517 .61739 m .76517 .65444 L .79455 .65106 L p .707 .577 .707 r
F P
0 g
s
.79455 .65106 m .79455 .61401 L .76517 .61739 L p .707 .577 .707 r
F P
0 g
s
.34635 .81333 m .34635 .83186 L .3253 .8254 L p .707 .577 .707 r
F P
0 g
s
.3253 .8254 m .3253 .80687 L .34635 .81333 L p .707 .577 .707 r
F P
0 g
s
.26667 .63639 m .26667 .69198 L .23483 .69275 L p .707 .577 .707 r
F P
0 g
s
.73333 .69146 m .73333 .63588 L .70216 .63398 L p .707 .577 .707 r
F P
0 g
s
.73333 .63588 m .73333 .69146 L .76517 .69069 L p .707 .577 .707 r
F P
0 g
s
.76517 .69069 m .76517 .6351 L .73333 .63588 L p .707 .577 .707 r
F P
0 g
s
.70216 .65332 m .70216 .61626 L .6747 .61187 L p .707 .577 .707 r
F P
0 g
s
.70216 .61626 m .70216 .65332 L .73333 .65522 L p .707 .577 .707 r
F P
0 g
s
.76517 .6351 m .76517 .69069 L .79455 .68731 L p .707 .577 .707 r
F P
0 g
s
.79455 .68731 m .79455 .63173 L .76517 .6351 L p .707 .577 .707 r
F P
0 g
s
.59233 .24036 m .59233 .74225 L .55357 .73605 L p .707 .577 .707 r
F P
0 g
s
.55357 .73605 m .55357 .23416 L .59233 .24036 L p .707 .577 .707 r
F P
0 g
s
.70216 .68956 m .70216 .63398 L .6747 .62959 L p .707 .577 .707 r
F P
0 g
s
.70216 .63398 m .70216 .68956 L .73333 .69146 L p .707 .577 .707 r
F P
0 g
s
.1814 .82891 m .1814 .81039 L .20545 .80474 L p .707 .577 .707 r
F P
0 g
s
.79455 .61401 m .79455 .65106 L .8186 .64541 L p .707 .577 .707 r
F P
0 g
s
.8186 .64541 m .8186 .60836 L .79455 .61401 L p .707 .577 .707 r
F P
0 g
s
.6747 .61187 m .6747 .64892 L .70216 .65332 L p .707 .577 .707 r
F P
0 g
s
.20545 .80474 m .20545 .82326 L .1814 .82891 L p .707 .577 .707 r
F P
0 g
s
.42314 .73923 m .42314 .23734 L .46462 .23257 L p .707 .577 .707 r
F P
0 g
s
.42314 .23734 m .42314 .73923 L .38918 .74721 L p .707 .577 .707 r
F P
0 g
s
.79455 .63173 m .79455 .68731 L .8186 .68166 L p .707 .577 .707 r
F P
0 g
s
.8186 .68166 m .8186 .62608 L .79455 .63173 L p .707 .577 .707 r
F P
0 g
s
.6747 .64892 m .6747 .61187 L .65365 .60542 L p .707 .577 .707 r
F P
0 g
s
.3253 .80687 m .3253 .8254 L .29784 .82101 L p .707 .577 .707 r
F P
0 g
s
.29784 .82101 m .29784 .80248 L .3253 .80687 L p .707 .577 .707 r
F P
0 g
s
.6747 .62959 m .6747 .68517 L .70216 .68956 L p .707 .577 .707 r
F P
0 g
s
.6747 .68517 m .6747 .62959 L .65365 .62313 L p .707 .577 .707 r
F P
0 g
s
.55357 .23416 m .55357 .73605 L .50956 .73337 L p .707 .577 .707 r
F P
0 g
s
.50956 .73337 m .50956 .23148 L .55357 .23416 L p .707 .577 .707 r
F P
0 g
s
.65365 .60542 m .65365 .64247 L .6747 .64892 L p .707 .577 .707 r
F P
0 g
s
.20545 .82326 m .20545 .80474 L .23483 .80136 L p .707 .577 .707 r
F P
0 g
s
.8186 .60836 m .8186 .64541 L .83497 .63804 L p .707 .577 .707 r
F P
0 g
s
.83497 .63804 m .83497 .60099 L .8186 .60836 L p .707 .577 .707 r
F P
0 g
s
.46462 .73446 m .46462 .23257 L .50956 .23148 L p .707 .577 .707 r
F P
0 g
s
.46462 .23257 m .46462 .73446 L .42314 .73923 L p .707 .577 .707 r
F P
0 g
s
.23483 .80136 m .23483 .81989 L .20545 .82326 L p .707 .577 .707 r
F P
0 g
s
.8186 .62608 m .8186 .68166 L .83497 .67429 L p .707 .577 .707 r
F P
0 g
s
.83497 .67429 m .83497 .61871 L .8186 .62608 L p .707 .577 .707 r
F P
0 g
s
.50956 .23148 m .50956 .73337 L .46462 .73446 L p .707 .577 .707 r
F P
0 g
s
.29784 .80248 m .29784 .82101 L .26667 .81911 L p .707 .577 .707 r
F P
0 g
s
.26667 .81911 m .26667 .80058 L .29784 .80248 L p .707 .577 .707 r
F P
0 g
s
.65365 .62313 m .65365 .67872 L .6747 .68517 L p .707 .577 .707 r
F P
0 g
s
.65365 .64247 m .65365 .60542 L .64105 .59753 L p .707 .577 .707 r
F P
0 g
s
.23483 .81989 m .23483 .80136 L .26667 .80058 L p .707 .577 .707 r
F P
0 g
s
.26667 .80058 m .26667 .81911 L .23483 .81989 L p .707 .577 .707 r
F P
0 g
s
.73333 .8186 m .73333 .80007 L .70216 .79817 L p .707 .577 .707 r
F P
0 g
s
.73333 .80007 m .73333 .8186 L .76517 .81782 L p .707 .577 .707 r
F P
0 g
s
.76517 .81782 m .76517 .79929 L .73333 .80007 L p .707 .577 .707 r
F P
0 g
s
.65365 .67872 m .65365 .62313 L .64105 .61525 L p .707 .577 .707 r
F P
0 g
s
.76517 .79929 m .76517 .81782 L .79455 .81444 L p .707 .577 .707 r
F P
0 g
s
.79455 .81444 m .79455 .79591 L .76517 .79929 L p .707 .577 .707 r
F P
0 g
s
.70216 .79817 m .70216 .8167 L .73333 .8186 L p .707 .577 .707 r
F P
0 g
s
.64105 .59753 m .64105 .63459 L .65365 .64247 L p .707 .577 .707 r
F P
0 g
s
.70216 .8167 m .70216 .79817 L .6747 .79378 L p .707 .577 .707 r
F P
0 g
s
.83497 .60099 m .83497 .63804 L .84205 .62968 L p .707 .577 .707 r
F P
0 g
s
.84205 .62968 m .84205 .59262 L .83497 .60099 L p .707 .577 .707 r
F P
0 g
s
.6747 .79378 m .6747 .8123 L .70216 .8167 L p .707 .577 .707 r
F P
0 g
s
.79455 .79591 m .79455 .81444 L .8186 .80879 L p .707 .577 .707 r
F P
0 g
s
.8186 .80879 m .8186 .79026 L .79455 .79591 L p .707 .577 .707 r
F P
0 g
s
.64105 .61525 m .64105 .67083 L .65365 .67872 L p .707 .577 .707 r
F P
0 g
s
.83497 .61871 m .83497 .67429 L .84205 .66593 L p .707 .577 .707 r
F P
0 g
s
.84205 .66593 m .84205 .61034 L .83497 .61871 L p .707 .577 .707 r
F P
0 g
s
.6747 .8123 m .6747 .79378 L .65365 .78732 L p .707 .577 .707 r
F P
0 g
s
.64105 .63459 m .64105 .59753 L .63816 .58899 L p .707 .577 .707 r
F P
0 g
s
.65365 .78732 m .65365 .80585 L .6747 .8123 L p .707 .577 .707 r
F P
0 g
s
.64105 .67083 m .64105 .61525 L .63816 .60671 L p .707 .577 .707 r
F P
0 g
s
.63816 .58899 m .63816 .62604 L .64105 .63459 L p .707 .577 .707 r
F P
0 g
s
.8186 .79026 m .8186 .80879 L .83497 .80142 L p .707 .577 .707 r
F P
0 g
s
.83497 .80142 m .83497 .7829 L .8186 .79026 L p .707 .577 .707 r
F P
0 g
s
.84205 .59262 m .84205 .62968 L .83916 .62114 L p .707 .577 .707 r
F P
0 g
s
.83916 .62114 m .83916 .58408 L .84205 .59262 L p .707 .577 .707 r
F P
0 g
s
.63816 .60671 m .63816 .66229 L .64105 .67083 L p .707 .577 .707 r
F P
0 g
s
.65365 .80585 m .65365 .78732 L .64105 .77944 L p .707 .577 .707 r
F P
0 g
s
.84205 .61034 m .84205 .66593 L .83916 .65738 L p .707 .577 .707 r
F P
0 g
s
.83916 .65738 m .83916 .6018 L .84205 .61034 L p .707 .577 .707 r
F P
0 g
s
.64105 .77944 m .64105 .79797 L .65365 .80585 L p .707 .577 .707 r
F P
0 g
s
.63816 .62604 m .63816 .58899 L .64524 .58062 L p .707 .577 .707 r
F P
0 g
s
.63816 .66229 m .63816 .60671 L .64524 .59834 L p .707 .577 .707 r
F P
0 g
s
.83497 .7829 m .83497 .80142 L .84206 .79306 L p .707 .577 .707 r
F P
0 g
s
.84206 .79306 m .84206 .77453 L .83497 .7829 L p .707 .577 .707 r
F P
0 g
s
.64524 .58062 m .64524 .61768 L .63816 .62604 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83916 .58408 m .83916 .62114 L .82657 .61325 L p .707 .577 .707 r
F P
0 g
s
.82657 .61325 m .82657 .5762 L .83916 .58408 L p .707 .577 .707 r
F P
0 g
s
.64105 .79797 m .64105 .77944 L .63816 .7709 L p .707 .577 .707 r
F P
0 g
s
.64524 .59834 m .64524 .65393 L .63816 .66229 L p .707 .577 .707 r
F P
0 g
s
.83916 .6018 m .83916 .65738 L .82657 .6495 L p .707 .577 .707 r
F P
0 g
s
.82657 .6495 m .82657 .59392 L .83916 .6018 L p .707 .577 .707 r
F P
0 g
s
.63816 .7709 m .63816 .78942 L .64105 .79797 L p .707 .577 .707 r
F P
0 g
s
.39032 .6184 m .39032 .58135 L .35915 .57945 L p .707 .577 .707 r
F P
0 g
s
.39032 .58135 m .39032 .6184 L .42216 .61762 L p .707 .577 .707 r
F P
0 g
s
.42216 .61762 m .42216 .58057 L .39032 .58135 L p .707 .577 .707 r
F P
0 g
s
.64524 .61768 m .64524 .58062 L .66161 .57326 L p .707 .577 .707 r
F P
0 g
s
.42216 .58057 m .42216 .61762 L .45154 .61425 L p .707 .577 .707 r
F P
0 g
s
.45154 .61425 m .45154 .57719 L .42216 .58057 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.39032 .65465 m .39032 .59907 L .35915 .59717 L p .707 .577 .707 r
F P
0 g
s
.39032 .59907 m .39032 .65465 L .42216 .65387 L p .707 .577 .707 r
F P
0 g
s
.42216 .65387 m .42216 .59829 L .39032 .59907 L p .707 .577 .707 r
F P
0 g
s
.35915 .6165 m .35915 .57945 L .33169 .57505 L p .707 .577 .707 r
F P
0 g
s
.35915 .57945 m .35915 .6165 L .39032 .6184 L p .707 .577 .707 r
F P
0 g
s
.64524 .65393 m .64524 .59834 L .66161 .59098 L p .707 .577 .707 r
F P
0 g
s
.42216 .59829 m .42216 .65387 L .45154 .65049 L p .707 .577 .707 r
F P
0 g
s
.45154 .65049 m .45154 .59491 L .42216 .59829 L p .707 .577 .707 r
F P
0 g
s
.84206 .77453 m .84206 .79306 L .83916 .78452 L p .707 .577 .707 r
F P
0 g
s
.83916 .78452 m .83916 .76599 L .84206 .77453 L p .707 .577 .707 r
F P
0 g
s
.35915 .65275 m .35915 .59717 L .33169 .59277 L p .707 .577 .707 r
F P
0 g
s
.35915 .59717 m .35915 .65275 L .39032 .65465 L p .707 .577 .707 r
F P
0 g
s
.66161 .57326 m .66161 .61031 L .64524 .61768 L p .707 .577 .707 r
F P
0 g
s
.45154 .57719 m .45154 .61425 L .47559 .6086 L p .707 .577 .707 r
F P
0 g
s
.47559 .6086 m .47559 .57154 L .45154 .57719 L p .707 .577 .707 r
F P
0 g
s
.33169 .57505 m .33169 .61211 L .35915 .6165 L p .707 .577 .707 r
F P
0 g
s
.82657 .5762 m .82657 .61325 L .80551 .6068 L p .707 .577 .707 r
F P
0 g
s
.80551 .6068 m .80551 .56974 L .82657 .5762 L p .707 .577 .707 r
F P
0 g
s
.45154 .59491 m .45154 .65049 L .47559 .64484 L p .707 .577 .707 r
F P
0 g
s
.47559 .64484 m .47559 .58926 L .45154 .59491 L p .707 .577 .707 r
F P
0 g
s
.33169 .61211 m .33169 .57505 L .31064 .5686 L p .707 .577 .707 r
F P
0 g
s
.66161 .59098 m .66161 .64656 L .64524 .65393 L p .707 .577 .707 r
F P
0 g
s
.63816 .78942 m .63816 .7709 L .64524 .76253 L p .707 .577 .707 r
F P
0 g
s
.82657 .59392 m .82657 .6495 L .80551 .64305 L p .707 .577 .707 r
F P
0 g
s
.80551 .64305 m .80551 .58746 L .82657 .59392 L p .707 .577 .707 r
F P
0 g
s
.33169 .59277 m .33169 .64836 L .35915 .65275 L p .707 .577 .707 r
F P
0 g
s
.33169 .64836 m .33169 .59277 L .31064 .58632 L p .707 .577 .707 r
F P
0 g
s
.64524 .76253 m .64524 .78106 L .63816 .78942 L p .707 .577 .707 r
F P
0 g
s
.66161 .61031 m .66161 .57326 L .68566 .56761 L p .707 .577 .707 r
F P
0 g
s
.31064 .5686 m .31064 .60565 L .33169 .61211 L p .707 .577 .707 r
F P
0 g
s
.66161 .64656 m .66161 .59098 L .68566 .58533 L p .707 .577 .707 r
F P
0 g
s
.47559 .57154 m .47559 .6086 L .49196 .60123 L p .707 .577 .707 r
F P
0 g
s
.49196 .60123 m .49196 .56417 L .47559 .57154 L p .707 .577 .707 r
F P
0 g
s
.68566 .56761 m .68566 .60466 L .66161 .61031 L p .707 .577 .707 r
F P
0 g
s
.47559 .58926 m .47559 .64484 L .49196 .63747 L p .707 .577 .707 r
F P
0 g
s
.49196 .63747 m .49196 .58189 L .47559 .58926 L p .707 .577 .707 r
F P
0 g
s
.83916 .76599 m .83916 .78452 L .82657 .77663 L p .707 .577 .707 r
F P
0 g
s
.82657 .77663 m .82657 .75811 L .83916 .76599 L p .707 .577 .707 r
F P
0 g
s
.80551 .56974 m .80551 .6068 L .77805 .60241 L p .707 .577 .707 r
F P
0 g
s
.77805 .60241 m .77805 .56535 L .80551 .56974 L p .707 .577 .707 r
F P
0 g
s
.31064 .58632 m .31064 .6419 L .33169 .64836 L p .707 .577 .707 r
F P
0 g
s
.31064 .60565 m .31064 .5686 L .29804 .56072 L p .707 .577 .707 r
F P
0 g
s
.80551 .58746 m .80551 .64305 L .77805 .63865 L p .707 .577 .707 r
F P
0 g
s
.77805 .63865 m .77805 .58307 L .80551 .58746 L p .707 .577 .707 r
F P
0 g
s
.68566 .60466 m .68566 .56761 L .71504 .56423 L p .707 .577 .707 r
F P
0 g
s
.68566 .58533 m .68566 .64091 L .66161 .64656 L p .707 .577 .707 r
F P
0 g
s
.39032 .78178 m .39032 .76325 L .35915 .76135 L p .707 .577 .707 r
F P
0 g
s
.39032 .76325 m .39032 .78178 L .42216 .781 L p .707 .577 .707 r
F P
0 g
s
.42216 .781 m .42216 .76248 L .39032 .76325 L p .707 .577 .707 r
F P
0 g
s
.31064 .6419 m .31064 .58632 L .29804 .57843 L p .707 .577 .707 r
F P
0 g
s
.64524 .78106 m .64524 .76253 L .66161 .75516 L p .707 .577 .707 r
F P
0 g
s
.42216 .76248 m .42216 .781 L .45154 .77763 L p .707 .577 .707 r
F P
0 g
s
.45154 .77763 m .45154 .7591 L .42216 .76248 L p .707 .577 .707 r
F P
0 g
s
.68566 .64091 m .68566 .58533 L .71504 .58195 L p .707 .577 .707 r
F P
0 g
s
.35915 .76135 m .35915 .77988 L .39032 .78178 L p .707 .577 .707 r
F P
0 g
s
.29804 .56072 m .29804 .59777 L .31064 .60565 L p .707 .577 .707 r
F P
0 g
s
.77805 .56535 m .77805 .60241 L .74688 .60051 L p .707 .577 .707 r
F P
0 g
s
.74688 .60051 m .74688 .56345 L .77805 .56535 L p .707 .577 .707 r
F P
0 g
s
.35915 .77988 m .35915 .76135 L .33169 .75696 L p .707 .577 .707 r
F P
0 g
s
.66161 .75516 m .66161 .77369 L .64524 .78106 L p .707 .577 .707 r
F P
0 g
s
.71504 .56423 m .71504 .60128 L .68566 .60466 L p .707 .577 .707 r
F P
0 g
s
.71504 .60128 m .71504 .56423 L .74688 .56345 L p .707 .577 .707 r
F P
0 g
s
.49196 .56417 m .49196 .60123 L .49904 .59286 L p .707 .577 .707 r
F P
0 g
s
.49904 .59286 m .49904 .55581 L .49196 .56417 L p .707 .577 .707 r
F P
0 g
s
.77805 .58307 m .77805 .63865 L .74688 .63675 L p .707 .577 .707 r
F P
0 g
s
.74688 .63675 m .74688 .58117 L .77805 .58307 L p .707 .577 .707 r
F P
0 g
s
.33169 .75696 m .33169 .77549 L .35915 .77988 L p .707 .577 .707 r
F P
0 g
s
.74688 .56345 m .74688 .60051 L .71504 .60128 L p .707 .577 .707 r
F P
0 g
s
.45154 .7591 m .45154 .77763 L .47559 .77198 L p .707 .577 .707 r
F P
0 g
s
.47559 .77198 m .47559 .75345 L .45154 .7591 L p .707 .577 .707 r
F P
0 g
s
.29804 .57843 m .29804 .63402 L .31064 .6419 L p .707 .577 .707 r
F P
0 g
s
.71504 .63753 m .71504 .58195 L .74688 .58117 L p .707 .577 .707 r
F P
0 g
s
.71504 .58195 m .71504 .63753 L .68566 .64091 L p .707 .577 .707 r
F P
0 g
s
.49196 .58189 m .49196 .63747 L .49904 .62911 L p .707 .577 .707 r
F P
0 g
s
.49904 .62911 m .49904 .57353 L .49196 .58189 L p .707 .577 .707 r
F P
0 g
s
.82657 .75811 m .82657 .77663 L .80551 .77018 L p .707 .577 .707 r
F P
0 g
s
.80551 .77018 m .80551 .75165 L .82657 .75811 L p .707 .577 .707 r
F P
0 g
s
.74688 .58117 m .74688 .63675 L .71504 .63753 L p .707 .577 .707 r
F P
0 g
s
.33169 .77549 m .33169 .75696 L .31064 .75051 L p .707 .577 .707 r
F P
0 g
s
.29804 .59777 m .29804 .56072 L .29515 .55217 L p .707 .577 .707 r
F P
0 g
s
.31064 .75051 m .31064 .76903 L .33169 .77549 L p .707 .577 .707 r
F P
0 g
s
.29804 .63402 m .29804 .57843 L .29515 .56989 L p .707 .577 .707 r
F P
0 g
s
.66161 .77369 m .66161 .75516 L .68566 .74951 L p .707 .577 .707 r
F P
0 g
s
.29515 .55217 m .29515 .58923 L .29804 .59777 L p .707 .577 .707 r
F P
0 g
s
.68566 .74951 m .68566 .76804 L .66161 .77369 L p .707 .577 .707 r
F P
0 g
s
.47559 .75345 m .47559 .77198 L .49196 .76461 L p .707 .577 .707 r
F P
0 g
s
.49196 .76461 m .49196 .74608 L .47559 .75345 L p .707 .577 .707 r
F P
0 g
s
.49904 .55581 m .49904 .59286 L .49615 .58432 L p .707 .577 .707 r
F P
0 g
s
.49615 .58432 m .49615 .54727 L .49904 .55581 L p .707 .577 .707 r
F P
0 g
s
.80551 .75165 m .80551 .77018 L .77805 .76579 L p .707 .577 .707 r
F P
0 g
s
.77805 .76579 m .77805 .74726 L .80551 .75165 L p .707 .577 .707 r
F P
0 g
s
.29515 .56989 m .29515 .62547 L .29804 .63402 L p .707 .577 .707 r
F P
0 g
s
.31064 .76903 m .31064 .75051 L .29804 .74262 L p .707 .577 .707 r
F P
0 g
s
.49904 .57353 m .49904 .62911 L .49615 .62057 L p .707 .577 .707 r
F P
0 g
s
.49615 .62057 m .49615 .56499 L .49904 .57353 L p .707 .577 .707 r
F P
0 g
s
.68566 .76804 m .68566 .74951 L .71504 .74614 L p .707 .577 .707 r
F P
0 g
s
.29804 .74262 m .29804 .76115 L .31064 .76903 L p .707 .577 .707 r
F P
0 g
s
.29515 .58923 m .29515 .55217 L .30223 .54381 L p .707 .577 .707 r
F P
0 g
s
.71504 .74614 m .71504 .76466 L .68566 .76804 L p .707 .577 .707 r
F P
0 g
s
.77805 .74726 m .77805 .76579 L .74688 .76389 L p .707 .577 .707 r
F P
0 g
s
.74688 .76389 m .74688 .74536 L .77805 .74726 L p .707 .577 .707 r
F P
0 g
s
.29515 .62547 m .29515 .56989 L .30223 .56153 L p .707 .577 .707 r
F P
0 g
s
.71504 .76466 m .71504 .74614 L .74688 .74536 L p .707 .577 .707 r
F P
0 g
s
.49196 .74608 m .49196 .76461 L .49904 .75624 L p .707 .577 .707 r
F P
0 g
s
.49904 .75624 m .49904 .73772 L .49196 .74608 L p .707 .577 .707 r
F P
0 g
s
.74688 .74536 m .74688 .76389 L .71504 .76466 L p .707 .577 .707 r
F P
0 g
s
.30223 .54381 m .30223 .58086 L .29515 .58923 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49615 .54727 m .49615 .58432 L .48356 .57644 L p .707 .577 .707 r
F P
0 g
s
.48356 .57644 m .48356 .53938 L .49615 .54727 L p .707 .577 .707 r
F P
0 g
s
.29804 .76115 m .29804 .74262 L .29515 .73408 L p .707 .577 .707 r
F P
0 g
s
.30223 .56153 m .30223 .61711 L .29515 .62547 L p .707 .577 .707 r
F P
0 g
s
.49615 .56499 m .49615 .62057 L .48356 .61268 L p .707 .577 .707 r
F P
0 g
s
.48356 .61268 m .48356 .5571 L .49615 .56499 L p .707 .577 .707 r
F P
0 g
s
.29515 .73408 m .29515 .75261 L .29804 .76115 L p .707 .577 .707 r
F P
0 g
s
.30223 .58086 m .30223 .54381 L .3186 .53644 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30223 .61711 m .30223 .56153 L .3186 .55416 L p .707 .577 .707 r
F P
0 g
s
.49904 .73772 m .49904 .75624 L .49615 .7477 L p .707 .577 .707 r
F P
0 g
s
.49615 .7477 m .49615 .72917 L .49904 .73772 L p .707 .577 .707 r
F P
0 g
s
.3186 .53644 m .3186 .5735 L .30223 .58086 L p .707 .577 .707 r
F P
0 g
s
.48356 .53938 m .48356 .57644 L .4625 .56998 L p .707 .577 .707 r
F P
0 g
s
.4625 .56998 m .4625 .53293 L .48356 .53938 L p .707 .577 .707 r
F P
0 g
s
.3186 .55416 m .3186 .60974 L .30223 .61711 L p .707 .577 .707 r
F P
0 g
s
.29515 .75261 m .29515 .73408 L .30223 .72572 L p .707 .577 .707 r
F P
0 g
s
.48356 .5571 m .48356 .61268 L .4625 .60623 L p .707 .577 .707 r
F P
0 g
s
.4625 .60623 m .4625 .55065 L .48356 .5571 L p .707 .577 .707 r
F P
0 g
s
.30223 .72572 m .30223 .74424 L .29515 .75261 L p .707 .577 .707 r
F P
0 g
s
.3186 .5735 m .3186 .53644 L .34265 .53079 L p .707 .577 .707 r
F P
0 g
s
.3186 .60974 m .3186 .55416 L .34265 .54851 L p .707 .577 .707 r
F P
0 g
s
.34265 .53079 m .34265 .56785 L .3186 .5735 L p .707 .577 .707 r
F P
0 g
s
.49615 .72917 m .49615 .7477 L .48356 .73982 L p .707 .577 .707 r
F P
0 g
s
.48356 .73982 m .48356 .72129 L .49615 .72917 L p .707 .577 .707 r
F P
0 g
s
.4625 .53293 m .4625 .56998 L .43504 .56559 L p .707 .577 .707 r
F P
0 g
s
.43504 .56559 m .43504 .52854 L .4625 .53293 L p .707 .577 .707 r
F P
0 g
s
.4625 .55065 m .4625 .60623 L .43504 .60184 L p .707 .577 .707 r
F P
0 g
s
.43504 .60184 m .43504 .54625 L .4625 .55065 L p .707 .577 .707 r
F P
0 g
s
.34265 .56785 m .34265 .53079 L .37203 .52741 L p .707 .577 .707 r
F P
0 g
s
.34265 .54851 m .34265 .60409 L .3186 .60974 L p .707 .577 .707 r
F P
0 g
s
.30223 .74424 m .30223 .72572 L .3186 .71835 L p .707 .577 .707 r
F P
0 g
s
.34265 .60409 m .34265 .54851 L .37203 .54513 L p .707 .577 .707 r
F P
0 g
s
.43504 .52854 m .43504 .56559 L .40387 .56369 L p .707 .577 .707 r
F P
0 g
s
.40387 .56369 m .40387 .52664 L .43504 .52854 L p .707 .577 .707 r
F P
0 g
s
.3186 .71835 m .3186 .73688 L .30223 .74424 L p .707 .577 .707 r
F P
0 g
s
.37203 .52741 m .37203 .56447 L .34265 .56785 L p .707 .577 .707 r
F P
0 g
s
.37203 .56447 m .37203 .52741 L .40387 .52664 L p .707 .577 .707 r
F P
0 g
s
.43504 .54625 m .43504 .60184 L .40387 .59994 L p .707 .577 .707 r
F P
0 g
s
.40387 .59994 m .40387 .54435 L .43504 .54625 L p .707 .577 .707 r
F P
0 g
s
.40387 .52664 m .40387 .56369 L .37203 .56447 L p .707 .577 .707 r
F P
0 g
s
.37203 .60071 m .37203 .54513 L .40387 .54435 L p .707 .577 .707 r
F P
0 g
s
.37203 .54513 m .37203 .60071 L .34265 .60409 L p .707 .577 .707 r
F P
0 g
s
.48356 .72129 m .48356 .73982 L .4625 .73336 L p .707 .577 .707 r
F P
0 g
s
.4625 .73336 m .4625 .71484 L .48356 .72129 L p .707 .577 .707 r
F P
0 g
s
.40387 .54435 m .40387 .59994 L .37203 .60071 L p .707 .577 .707 r
F P
0 g
s
.3186 .73688 m .3186 .71835 L .34265 .7127 L p .707 .577 .707 r
F P
0 g
s
.34265 .7127 m .34265 .73123 L .3186 .73688 L p .707 .577 .707 r
F P
0 g
s
.4625 .71484 m .4625 .73336 L .43504 .72897 L p .707 .577 .707 r
F P
0 g
s
.43504 .72897 m .43504 .71044 L .4625 .71484 L p .707 .577 .707 r
F P
0 g
s
.34265 .73123 m .34265 .7127 L .37203 .70932 L p .707 .577 .707 r
F P
0 g
s
.37203 .70932 m .37203 .72785 L .34265 .73123 L p .707 .577 .707 r
F P
0 g
s
.43504 .71044 m .43504 .72897 L .40387 .72707 L p .707 .577 .707 r
F P
0 g
s
.40387 .72707 m .40387 .70854 L .43504 .71044 L p .707 .577 .707 r
F P
0 g
s
.37203 .72785 m .37203 .70932 L .40387 .70854 L p .707 .577 .707 r
F P
0 g
s
.40387 .70854 m .40387 .72707 L .37203 .72785 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol008]oo``008Ioo`00Ogoo30001EYF00<005YFFUH015YF
2@00OGoo001fOol90005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001gOol0075o
o`D0009JEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007=o
o`00KWoo0`001eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00@005YF0000075oo`00K7oo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00@005YFFUIJEP<006ioo`00JWoo0P000UYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH015YF0P00K7oo001X
Ool20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH3001ZOol006Moo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF0080
06Qoo`00IWoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0IGoo001V
Ool00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001J
EUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005
FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`04001JEUYF0005FUH900000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol0061oo`h000AJEP03001JEUYF009JEPP000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00G7oo100000=JEP00
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0`001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF00000P0025YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo
001GOol200000eYF001JEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP<000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00E7oo0P0015YF
00<005YFFUH015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF200015YF00<005YFFUH00eYF
00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF0000IGoo001DOol20004FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUIJEUYF1P0015YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00Dgoo00<005YF000015YF1000
0eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF0000
0P0000=JEP00FUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00Dgoo00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP04001J
EUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol005=o
o`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300001EYF001JEUYF000035YF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001COol30004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH01000FUIJEP0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<0
05YFFUH00P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF00003goo6000?Woo001COol00`00FUH00004FUH00`00FUIJEP04FUH50003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00002Goo1P00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`00>Woo001COol00`00FUH00004FUH0
0`00FUH000020002FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF00001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH00eYF1000=Woo001COol00`00FUH00004FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
00000goo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH01000<Woo001COol01000FUH005YF0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP00Ool2
00000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH2000aOol005=oo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEUYF00IJEQ@000EJEP03001JEUYF00=JEP04001JEP00000_
Ool005=oo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUH0000300000eYF001JEP04FUH01@00FUIJEUYF0000;Woo001C
Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YF00000eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF10000eYF00D005YFFUIJEP00
02ioo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP8000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00@000=JEP80
02eoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00002FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH20002FUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF009JEQ40
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000000eYF00<005YFFUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YF00000`00;Goo001COol00`00FUH00004FUH00`00FUIJEP03FUH70007FUH00`00FUIJEP06FUH8
0004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF1P000eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00<005YF
000015YF00<005YF00000`001UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF1P00
15YF00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000AJEP04001JEP000002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001COol00`00FUH0
0003FUH400000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH300000eYF001JEP02FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF0P0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Dgoo00@005YF001J
EP8000AJEP80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00AJEP<000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH005YF0P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00Agoo2@000goo
00H005YF000005YF0005FUH01000FUIJEUYF1@000UYF1P002EYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P0000EJEP00FUIJEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000oOol80004FUH0
0`00FUIJEP02FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00=goo20000eYF00<005YFFUH01UYF00<005YFFUH01EYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF
00L005YFFUIJEP00FUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000bOol50003FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJ
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0031oo`800003FUH005YF00EJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH00UYF2@0015YF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000EJEP03
001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50004FUH00`00FUIJEP02FUH7
00000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH00UYF6P000eYF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00;Goo0P0015YF00D005YFFUIJEP00009JEP@000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00EJEP@0
00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00004FUH01000FUIJEUYF200025YF00<0
05YFFUH01UYF00<005YFFUH01EYF1@0015YF00@005YFFUIJEP8002eoo`00;7oo00<005YF000015YF
10000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=J
EP00FUH01UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUIJEPD000MJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=J
EPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<00003
FUH005YF009JEP8002eoo`00;7oo00D005YF001JEP00009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH000AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEPP000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEP00FUH20003FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30003FUH2000]Ool002aoo`04001JEP00
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH80004FUH00`00FUIJEP03FUH90007FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH01000
FUIJEUYF1@000UYF0P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YF
FUH00P0000=JEP000000;Goo000/Ool30004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJ
EP0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001J
EP0000T000AJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF
009JEPD000QJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<0
05YF000015YF00<005YFFUH015YF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP<002eoo`00;7oo00<005YF000015YF00<0
05YF00000P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP80009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00<005YF000015YF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009J
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEP0002eoo`00;7oo00@005YF001JEP800003FUH005YF00EJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH2000^Ool002aoo`04001JEP000003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF001JEP0000EJEP03001J
EUYF00EJEP03001JEUYF00IJEPD000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH2
000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJ
EP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH50004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000<Goo000/Ool00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF001J
EP<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=J
EP<003=oo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00=J
EPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP0000AJEPD000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEP0000<003Ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00=JEPD000EJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000EJEP04001JEUYF
FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000jOol002aoo`03001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000AJEP03001JEUYF00EJ
EP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
FUH00005FUH00`00FUIJEP03FUHK000oOol002aoo`03001JEP0000AJEP03001JEUYF00=JEPl000QJ
EPP000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP03001DOol002aoo`03001JEP0000AJEP03
001JEP0000<000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPH000AJEP04001J
EUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00
FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool00`00FUH00003FUH400000eYF001JEP06FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300001EYF001JEUYF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH0
0eYF00@005YFFUIJEP8005Aoo`00;7oo00@005YF001JEP8000AJEP80009JEP03001JEUYF009JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP<0009JEP04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00E7oo000/Ool01P00FUH00000FUH000EJEP04001JEUYFFUH50002FUH00`00FUIJEP02FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP0D00000eYF001JEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
0`00FUH00005FUH00`00FUIJEP03FUH01000FUIJEUYF0P00E7oo000/Ool20003FUH00`00FUIJEP03
FUH00`00FUIJEP05FUH01000FUIJEUYF1@002EYF00<005YFFUH01EYF00<005YFFUH015YF1P000eYF
00<005YFFUH01UYF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YFFUH00eYF00@005YF
FUIJEP8005Aoo`00;7oo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0100000=JEP00FUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00@005YFFUIJEPH000]JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH20008Ool30019Ool0
02aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEP00008000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH20007Ool50018Ool002aoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP80
0003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00=JEP04001JEUYFFUH20007Ool50018Ool002eoo`05
001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50005FUH01000FUIJEUYF0P000eYF
00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF0`0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D004Qoo`00;Woo0P0000=JEP00FUH015YF00<005YF
FUH01EYF00<005YFFUH01EYF1@001EYF00<005YFFUH00P0015YF00<005YFFUH00eYF1P000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF200015YF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001EYF00<005YF
FUH00eYF00@005YFFUIJEP8000Qoo`<004Uoo`00<7oo0`0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF1@001EYF00D005YF001JEP0000AJEP03001JEP0000@00005FUH00000Ool00002FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60004FUH01000FUIJEUYF2P001UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000100000=JEP00FUH015YF00@005YFFUIJ
EP8005Aoo`00<goo0`0000=JEP00FUH01UYF00<005YFFUH01EYF10001UYF00D005YF001JEP0000=J
EP<000=JEP<000=oo`04001JEUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P000eYF0`0000=J
EP00FUH00UYF00<005YFFUH01eYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000
0UYF00<005YF00000`000eYF00@005YFFUIJEP8005Aoo`00=Woo1@0015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00H005YF001JEP00FUH300000eYF000000020006Ool01000FUIJEP001EYF00<005YF
FUH01EYF1P000UYF00<005YFFUH01eYF0P000eYF00<005YFFUH025YF00<005YFFUH01EYF1P000UYF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00eYF10000eYF0P00E7oo
000kOol80004FUH00`00FUIJEP07FUH01000FUH005YF1P002Woo00@005YFFUH000EJEP03001JEUYF
00D000QJEP03001JEUYF00UJEP800003FUH005YF00UJEP03001JEUYF00QJEP03001JEUYF00@000IJ
EP03001JEUYF009JEP03001JEP00009JEP03001JEUYF00AJEP04001JEUYF0002FUH20007Ool90014
Ool004=ooa@000ioo`04001JEUYF0005FUH30002FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH3000:
FUH00`00FUIJEP08FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH00`00FUH00002FUH00`00
FUIJEP04FUH01000FUIJEUYF2`0015YF00<005YFFUH00UYF2000?7oo001COol20002FUH3000;Ool0
1000FUIJEP000eYF0P001EYF00<005YFFUH025YF00<005YFFUH025YF0`0000=JEP00FUH02EYF00<0
05YFFUH025YF00<005YFFUH01eYF100015YF00<005YF00000UYF00<005YFFUH00eYF1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD003Moo`00Dgoo0P000eYF00<005YF00000P00
27oo00D005YFFUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00=JEPD0009JEP03001JEP00
00YJEP03001JEUYF00QJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH00`00FUH00002FUH60002
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00002
000dOol005=oo`8000=JEP03001JEUYF009JEPD000=oo`03001JEUYF00800003FUH005YF00IJEP03
001JEUYF00MJEPL000=JEP07001JEUYFFUH005YF00002UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00eYF0`0000=JEP00FUH00P0000=JEP00FUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo001DOol01@00FUIJEUYF
00001EYF00@005YFFUIJEPP00003FUH005YF00IJEPX000=JEP03001JEUYF00AJEP04001JEUYFFUH2
000;FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF00000003FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH3000`Ool005Eoo`800003FUH005YF00AJEP03001JEUYF00EJEP04001JEUYFFUH:0004
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YF
FUH01eYF00<005YFFUH015YF100015YF00<005YFFUH00eYF00<005YFFUH00UYF60001EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001GOol30004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002000<FUH00`00FUIJEP08FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH0000015YF00<005YFFUH00UYF1P0067oo100000=J
EP00FUH015YF00D005YFFUIJEP0002ioo`00B7oo0`003goo0`0000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF0`000UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00eYF00<005YF00001@00
7goo10000eYF00@005YFFUIJEP8002eoo`00Agoo1@004Goo1@0015YF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH015YF0P0000=JEP00FUH00UYF1`009Goo10000eYF0P00;Goo0017Ool5
000FOol80004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH50009FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF001JEP05000]Ool00`00FUIJEP02000]
Ool004Moo`D001Yoo`04001JEUYFFUHC00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH200000eYF0000000cOol4000]Ool004Qoo`<001aoo`80
009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP8002moo`800004FUH00000000]Ool006Uo
o`<000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEUYFFUH20002Ool20002FUH00`00FUH00002000YOol30003FUH3000]Ool006]o
o`8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00MJEP04001JEP000004Ool20002FUH00`00FUIJEP02FUH5000POol400000eYF001JEP03FUH0
0`00FUH0000]Ool006eoo`@0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP@000Moo`04001JEUYF0005FUH01000FUIJEUYF2@004Woo1@00
1EYF00<005YFFUH00UYF0P00;Woo000oOolA000QOol50008FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05000<Ool00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUHB0003FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;goo000iOol60003FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH8000NOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06
FUH5000BOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUH00000<Goo000eOol400000eYF001JEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF1P007Woo2@001UYF00<005YFFUH02UYF00<005YFFUH01P0067oo
0`000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF0`00<goo000bOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH00002000TOolF000?Ool3000?Ool50006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00003000fOol0031oo`800003FUH005YF00EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8004Io
o`D001=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPD003Yoo`00;Woo
0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF
00<005YFFUH00eYF0`00A7oo1@005goo6@00?goo000]Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH80009Ool80004FUH00`00FUIJEP03FUH00`00FUIJEP020012Ool5001_Ool002aoo`03001J
EP0000AJEP04001JEUYFFUH8000IOol60004FUH01@00FUIJEUYF0000@goo0`00L7oo000/Ool00`00
FUH00003FUH5000WOol300000eYF001JEP02FUH00`00Oomoo`2dOol002aoo`04001JEP00FUH2000_
Ool20003FUH00`00Oomoo`2dOol002aoo`04001JEP00000cOol200000eYF001oo`2eOol002aoo`@0
03Aoo`<003UooaX006=oo`00;7oo0P000UYF0`00;goo0`0000=JEP00Ool0<Goo1`0015YF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPD005ioo`00;7oo0P000eYF00<005YF00000P00:Goo
0`000UYF00<005YF0000;Goo1@000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00000P00Fgoo000/Ool20003FUH00`00FUIJEP02FUH5000POol40000
0eYF001JEP02FUH00`00FUH0000[Ool200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2001IOol002eoo`05001JEUYFFUH0
0005FUH01000FUIJEUYF20002Woo3P001EYF00@005YFFUIJEP8002Yoo`8000=JEP03001JEUYF00=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=J
EP<005Moo`00;Woo0P0000=JEP00FUH015YF00<005YFFUH01EYF00@005YFFUIJEPX000AJEP03001J
EUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH0000ZOol20004FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUHH0005FUH00`00FUIJEP03FUH00`00FUIJEP02001EOol0031oo`<000AJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP00000[
Ool20004FUH00`00FUIJEP02FUH6000HOol400000eYF001JEP04FUH01@00FUIJEUYF0000EGoo000c
Ool300000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH3000/Ool00`00FUH00004FUH00`00FUH00002000ROol40003FUH01000FUIJEUYF0P00E7oo
000fOol50004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003000_
Ool00`00FUH00003FUH3000YOol40003FUH2001DOol003]oo`P000AJEP03001JEUYF00MJEP03001J
EUYF009JEPD003=oo`04001JEP00FUH2000`Ool00`00FUIJEP02001DOol004=ooa<003Qoo`04001J
EP00000cOol4001DOol008ioo`800003FUH007oo031oo`800004FUH00000001DOol008ioo`80009J
EP<002]oo`<000=JEP<005Aoo`00SWoo0P000UYF00<005YFFUH01@008Woo100000=JEP00FUH00eYF
00<005YF0000E7oo002?Ool01000FUIJEP001EYF00<005YF00000`006Goo1@001EYF00<005YFFUH0
0UYF0P00EGoo002?Ool01000FUIJEP001EYF00<005YFFUH00eYF6@000eYF00<005YFFUH015YF00<0
05YFFUH00UYF0P00EGoo002@Ool30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00EWoo002BOol20004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH0
0000F7oo002DOol300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH01000FUIJEUYF1@00FWoo002GOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH7001OOol009aooa/006Ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]55\[InvisibleSpace]"     "\
\[InvisibleSpace]12.948298795553866`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 55, "     ", 12.948298795553866, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63569 .77323 m .62635 .72946 L .59506 .73597 L p .707 .577 .707 r
F P
0 g
s
.62635 .72946 m .63569 .77323 L .66423 .76093 L p .707 .577 .707 r
F P
0 g
s
.66423 .76093 m .6549 .71716 L .62635 .72946 L p .707 .577 .707 r
F P
0 g
s
.62831 .81127 m .62875 .77394 L .59691 .77429 L p .707 .577 .707 r
F P
0 g
s
.60439 .77974 m .59506 .73597 L .56407 .73604 L p .707 .577 .707 r
F P
0 g
s
.62875 .77394 m .62831 .81127 L .65769 .80856 L p .707 .577 .707 r
F P
0 g
s
.65769 .80856 m .65813 .77123 L .62875 .77394 L p .707 .577 .707 r
F P
0 g
s
.59506 .73597 m .60439 .77974 L .63569 .77323 L p .707 .577 .707 r
F P
0 g
s
.6549 .71716 m .66423 .76093 L .68723 .74403 L p .707 .577 .707 r
F P
0 g
s
.68723 .74403 m .67789 .70026 L .6549 .71716 L p .707 .577 .707 r
F P
0 g
s
.59648 .81162 m .59691 .77429 L .56574 .77224 L p .707 .577 .707 r
F P
0 g
s
.5734 .77981 m .56407 .73604 L .53643 .72967 L p .707 .577 .707 r
F P
0 g
s
.59691 .77429 m .59648 .81162 L .62831 .81127 L p .707 .577 .707 r
F P
0 g
s
.56407 .73604 m .5734 .77981 L .60439 .77974 L p .707 .577 .707 r
F P
0 g
s
.58893 .83277 m .59017 .81369 L .55903 .81094 L p .707 .577 .707 r
F P
0 g
s
.59017 .81369 m .58893 .83277 L .62069 .83447 L p .707 .577 .707 r
F P
0 g
s
.62069 .83447 m .62193 .81539 L .59017 .81369 L p .707 .577 .707 r
F P
0 g
s
.55903 .81094 m .55779 .83002 L .58893 .83277 L p .707 .577 .707 r
F P
0 g
s
.62193 .81539 m .62069 .83447 L .64994 .83495 L p .707 .577 .707 r
F P
0 g
s
.64994 .83495 m .65118 .81588 L .62193 .81539 L p .707 .577 .707 r
F P
0 g
s
.55779 .83002 m .55903 .81094 L .53154 .8074 L p .707 .577 .707 r
F P
0 g
s
.53154 .8074 m .5303 .82648 L .55779 .83002 L p .707 .577 .707 r
F P
0 g
s
.67789 .70026 m .68723 .74403 L .70243 .7242 L p .707 .577 .707 r
F P
0 g
s
.70243 .7242 m .69309 .68043 L .67789 .70026 L p .707 .577 .707 r
F P
0 g
s
.56531 .80957 m .56574 .77224 L .53828 .768 L p .707 .577 .707 r
F P
0 g
s
.56574 .77224 m .56531 .80957 L .59648 .81162 L p .707 .577 .707 r
F P
0 g
s
.54576 .77344 m .53643 .72967 L .51483 .71749 L p .707 .577 .707 r
F P
0 g
s
.53643 .72967 m .54576 .77344 L .5734 .77981 L p .707 .577 .707 r
F P
0 g
s
.65118 .81588 m .64994 .83495 L .67384 .83417 L p .707 .577 .707 r
F P
0 g
s
.67384 .83417 m .67507 .81509 L .65118 .81588 L p .707 .577 .707 r
F P
0 g
s
.65813 .77123 m .65769 .80856 L .68174 .80376 L p .707 .577 .707 r
F P
0 g
s
.68174 .80376 m .68217 .76643 L .65813 .77123 L p .707 .577 .707 r
F P
0 g
s
.53828 .768 m .53785 .80533 L .56531 .80957 L p .707 .577 .707 r
F P
0 g
s
.5303 .82648 m .53154 .8074 L .5104 .80343 L p .707 .577 .707 r
F P
0 g
s
.5104 .80343 m .50917 .8225 L .5303 .82648 L p .707 .577 .707 r
F P
0 g
s
.53785 .80533 m .53828 .768 L .51723 .76197 L p .707 .577 .707 r
F P
0 g
s
.69309 .68043 m .70243 .7242 L .70834 .70337 L p .707 .577 .707 r
F P
0 g
s
.70834 .70337 m .699 .6596 L .69309 .68043 L p .707 .577 .707 r
F P
0 g
s
.52417 .76126 m .51483 .71749 L .5014 .70068 L p .707 .577 .707 r
F P
0 g
s
.51483 .71749 m .52417 .76126 L .54576 .77344 L p .707 .577 .707 r
F P
0 g
s
.67507 .81509 m .67384 .83417 L .69003 .83219 L p .707 .577 .707 r
F P
0 g
s
.69003 .83219 m .69127 .81311 L .67507 .81509 L p .707 .577 .707 r
F P
0 g
s
.51723 .76197 m .51679 .7993 L .53785 .80533 L p .707 .577 .707 r
F P
0 g
s
.68217 .76643 m .68174 .80376 L .6981 .79732 L p .707 .577 .707 r
F P
0 g
s
.6981 .79732 m .69854 .75999 L .68217 .76643 L p .707 .577 .707 r
F P
0 g
s
.50917 .8225 m .5104 .80343 L .49768 .7994 L p .707 .577 .707 r
F P
0 g
s
.49768 .7994 m .49645 .81848 L .50917 .8225 L p .707 .577 .707 r
F P
0 g
s
.51679 .7993 m .51723 .76197 L .50463 .75476 L p .707 .577 .707 r
F P
0 g
s
.699 .6596 m .70834 .70337 L .70439 .68359 L p .706 .577 .707 r
F P
0 g
s
.70439 .68359 m .69505 .63982 L .699 .6596 L p .706 .577 .707 r
F P
0 g
s
.5014 .70068 m .51074 .74445 L .52417 .76126 L p .707 .577 .707 r
F P
0 g
s
.51074 .74445 m .5014 .70068 L .49745 .6809 L p .706 .577 .707 r
F P
0 g
s
.50463 .75476 m .50419 .79209 L .51679 .7993 L p .707 .577 .707 r
F P
0 g
s
.69127 .81311 m .69003 .83219 L .69693 .82922 L p .707 .577 .707 r
F P
0 g
s
.69693 .82922 m .69817 .81014 L .69127 .81311 L p .707 .577 .707 r
F P
0 g
s
.69854 .75999 m .6981 .79732 L .70518 .78989 L p .707 .577 .707 r
F P
0 g
s
.70518 .78989 m .70561 .75256 L .69854 .75999 L p .707 .577 .707 r
F P
0 g
s
.50678 .72467 m .49745 .6809 L .50336 .66007 L p .707 .577 .707 r
F P
0 g
s
.49745 .6809 m .50678 .72467 L .51074 .74445 L p .706 .577 .707 r
F P
0 g
s
.50173 .74706 m .50129 .78439 L .50419 .79209 L p .707 .577 .707 r
F P
0 g
s
.49645 .81848 m .49768 .7994 L .49463 .79572 L p .707 .577 .707 r
F P
0 g
s
.49463 .79572 m .49339 .8148 L .49645 .81848 L p .707 .577 .707 r
F P
0 g
s
.49339 .8148 m .49463 .79572 L .50153 .79275 L p .707 .577 .707 r
F P
0 g
s
.50153 .79275 m .5003 .81183 L .49339 .8148 L p .707 .577 .707 r
F P
0 g
s
.50419 .79209 m .50463 .75476 L .50173 .74706 L p .707 .577 .707 r
F P
0 g
s
.50129 .78439 m .50173 .74706 L .50881 .73963 L p .707 .577 .707 r
F P
0 g
s
.50881 .73963 m .50837 .77696 L .50129 .78439 L p .707 .577 .707 r
F P
0 g
s
.5003 .81183 m .50153 .79275 L .51773 .79077 L p .707 .577 .707 r
F P
0 g
s
.51773 .79077 m .51649 .80985 L .5003 .81183 L p .707 .577 .707 r
F P
0 g
s
.50319 .825 m .48426 .33822 L .44027 .3362 L p .707 .577 .707 r
F P
0 g
s
.5127 .70384 m .50336 .66007 L .51856 .64024 L p .707 .577 .707 r
F P
0 g
s
.50336 .66007 m .5127 .70384 L .50678 .72467 L p .707 .577 .707 r
F P
0 g
s
.51856 .64024 m .52789 .68401 L .5127 .70384 L p .707 .577 .707 r
F P
0 g
s
.52789 .68401 m .51856 .64024 L .54156 .62334 L p .707 .577 .707 r
F P
0 g
s
.54156 .62334 m .55089 .66711 L .52789 .68401 L p .707 .577 .707 r
F P
0 g
s
.50837 .77696 m .50881 .73963 L .52517 .7332 L p .707 .577 .707 r
F P
0 g
s
.52517 .7332 m .52473 .77053 L .50837 .77696 L p .707 .577 .707 r
F P
0 g
s
.51649 .80985 m .51773 .79077 L .54162 .78999 L p .707 .577 .707 r
F P
0 g
s
.54162 .78999 m .54038 .80906 L .51649 .80985 L p .707 .577 .707 r
F P
0 g
s
.52473 .77053 m .52517 .7332 L .54922 .72839 L p .707 .577 .707 r
F P
0 g
s
.54922 .72839 m .54878 .76572 L .52473 .77053 L p .707 .577 .707 r
F P
0 g
s
.54038 .80906 m .54162 .78999 L .57087 .79047 L p .707 .577 .707 r
F P
0 g
s
.57087 .79047 m .56964 .80954 L .54038 .80906 L p .707 .577 .707 r
F P
0 g
s
.48426 .33822 m .50319 .825 L .5481 .822 L p .707 .577 .707 r
F P
0 g
s
.5481 .822 m .52917 .33522 L .48426 .33822 L p .707 .577 .707 r
F P
0 g
s
.55089 .66711 m .54156 .62334 L .5701 .61104 L p .707 .577 .707 r
F P
0 g
s
.5701 .61104 m .57943 .65481 L .55089 .66711 L p .707 .577 .707 r
F P
0 g
s
.54878 .76572 m .54922 .72839 L .5786 .72568 L p .707 .577 .707 r
F P
0 g
s
.5786 .72568 m .57816 .76301 L .54878 .76572 L p .707 .577 .707 r
F P
0 g
s
.56964 .80954 m .57087 .79047 L .60263 .79217 L p .707 .577 .707 r
F P
0 g
s
.57816 .76301 m .5786 .72568 L .61043 .72533 L p .707 .577 .707 r
F P
0 g
s
.60263 .79217 m .60139 .81124 L .56964 .80954 L p .707 .577 .707 r
F P
0 g
s
.61043 .72533 m .60999 .76266 L .57816 .76301 L p .707 .577 .707 r
F P
0 g
s
.52917 .33522 m .5481 .822 L .58953 .81426 L p .707 .577 .707 r
F P
0 g
s
.6014 .60453 m .61073 .6483 L .57943 .65481 L p .707 .577 .707 r
F P
0 g
s
.57943 .65481 m .5701 .61104 L .6014 .60453 L p .707 .577 .707 r
F P
0 g
s
.58953 .81426 m .5706 .32748 L .52917 .33522 L p .707 .577 .707 r
F P
0 g
s
.69505 .63982 m .70439 .68359 L .69096 .66678 L p .707 .577 .707 r
F P
0 g
s
.69096 .66678 m .68162 .62301 L .69505 .63982 L p .707 .577 .707 r
F P
0 g
s
.4592 .82298 m .44027 .3362 L .40149 .32934 L p .707 .577 .707 r
F P
0 g
s
.44027 .3362 m .4592 .82298 L .50319 .825 L p .707 .577 .707 r
F P
0 g
s
.61073 .6483 m .6014 .60453 L .63238 .60446 L p .707 .577 .707 r
F P
0 g
s
.63377 .79492 m .63253 .814 L .60139 .81124 L p .707 .577 .707 r
F P
0 g
s
.60139 .81124 m .60263 .79217 L .63377 .79492 L p .707 .577 .707 r
F P
0 g
s
.6416 .72738 m .64116 .76471 L .60999 .76266 L p .707 .577 .707 r
F P
0 g
s
.60999 .76266 m .61043 .72533 L .6416 .72738 L p .707 .577 .707 r
F P
0 g
s
.5706 .32748 m .58953 .81426 L .62341 .80254 L p .707 .577 .707 r
F P
0 g
s
.63238 .60446 m .64172 .64823 L .61073 .6483 L p .707 .577 .707 r
F P
0 g
s
.62341 .80254 m .60448 .31576 L .5706 .32748 L p .707 .577 .707 r
F P
0 g
s
.69817 .81014 m .69693 .82922 L .69388 .82554 L p .707 .577 .707 r
F P
0 g
s
.69388 .82554 m .69511 .80646 L .69817 .81014 L p .707 .577 .707 r
F P
0 g
s
.70561 .75256 m .70518 .78989 L .70228 .78219 L p .707 .577 .707 r
F P
0 g
s
.70228 .78219 m .70271 .74486 L .70561 .75256 L p .707 .577 .707 r
F P
0 g
s
.42042 .81612 m .40149 .32934 L .37173 .31832 L p .707 .577 .707 r
F P
0 g
s
.40149 .32934 m .42042 .81612 L .4592 .82298 L p .707 .577 .707 r
F P
0 g
s
.68162 .62301 m .69096 .66678 L .66936 .6546 L p .707 .577 .707 r
F P
0 g
s
.66936 .6546 m .66003 .61083 L .68162 .62301 L p .707 .577 .707 r
F P
0 g
s
.63253 .814 m .63377 .79492 L .66126 .79846 L p .707 .577 .707 r
F P
0 g
s
.66906 .73162 m .66862 .76896 L .64116 .76471 L p .707 .577 .707 r
F P
0 g
s
.64116 .76471 m .6416 .72738 L .66906 .73162 L p .707 .577 .707 r
F P
0 g
s
.60448 .31576 m .62341 .80254 L .64644 .78799 L p .707 .577 .707 r
F P
0 g
s
.64172 .64823 m .63238 .60446 L .66003 .61083 L p .707 .577 .707 r
F P
0 g
s
.64644 .78799 m .62751 .30121 L .60448 .31576 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29268 .73641 m .28335 .69264 L .25205 .69915 L p .707 .577 .707 r
F P
0 g
s
.28335 .69264 m .29268 .73641 L .32122 .72411 L p .707 .577 .707 r
F P
0 g
s
.32122 .72411 m .31189 .68034 L .28335 .69264 L p .707 .577 .707 r
F P
0 g
s
.2853 .77446 m .28574 .73713 L .25391 .73747 L p .707 .577 .707 r
F P
0 g
s
.26138 .74292 m .25205 .69915 L .22106 .69922 L p .707 .577 .707 r
F P
0 g
s
.28574 .73713 m .2853 .77446 L .31468 .77175 L p .707 .577 .707 r
F P
0 g
s
.31468 .77175 m .31512 .73442 L .28574 .73713 L p .707 .577 .707 r
F P
0 g
s
.25205 .69915 m .26138 .74292 L .29268 .73641 L p .707 .577 .707 r
F P
0 g
s
.66003 .61083 m .66936 .6546 L .64172 .64823 L p .707 .577 .707 r
F P
0 g
s
.69511 .80646 m .69388 .82554 L .68116 .82151 L p .707 .577 .707 r
F P
0 g
s
.68116 .82151 m .68239 .80244 L .69511 .80646 L p .707 .577 .707 r
F P
0 g
s
.70271 .74486 m .70228 .78219 L .68968 .77498 L p .707 .577 .707 r
F P
0 g
s
.68968 .77498 m .69012 .73765 L .70271 .74486 L p .707 .577 .707 r
F P
0 g
s
.31189 .68034 m .32122 .72411 L .34422 .70722 L p .707 .577 .707 r
F P
0 g
s
.34422 .70722 m .33489 .66345 L .31189 .68034 L p .707 .577 .707 r
F P
0 g
s
.25347 .7748 m .25391 .73747 L .22273 .73543 L p .707 .577 .707 r
F P
0 g
s
.2304 .74299 m .22106 .69922 L .19342 .69286 L p .707 .577 .707 r
F P
0 g
s
.25391 .73747 m .25347 .7748 L .2853 .77446 L p .707 .577 .707 r
F P
0 g
s
.22106 .69922 m .2304 .74299 L .26138 .74292 L p .707 .577 .707 r
F P
0 g
s
.24592 .79596 m .24716 .77688 L .21602 .77412 L p .707 .577 .707 r
F P
0 g
s
.24716 .77688 m .24592 .79596 L .27768 .79766 L p .707 .577 .707 r
F P
0 g
s
.27768 .79766 m .27892 .77858 L .24716 .77688 L p .707 .577 .707 r
F P
0 g
s
.21602 .77412 m .21478 .7932 L .24592 .79596 L p .707 .577 .707 r
F P
0 g
s
.27892 .77858 m .27768 .79766 L .30693 .79814 L p .707 .577 .707 r
F P
0 g
s
.30693 .79814 m .30817 .77906 L .27892 .77858 L p .707 .577 .707 r
F P
0 g
s
.39066 .8051 m .37173 .31832 L .35389 .30422 L p .707 .577 .707 r
F P
0 g
s
.37173 .31832 m .39066 .8051 L .42042 .81612 L p .707 .577 .707 r
F P
0 g
s
.21478 .7932 m .21602 .77412 L .18853 .77059 L p .707 .577 .707 r
F P
0 g
s
.18853 .77059 m .18729 .78966 L .21478 .7932 L p .707 .577 .707 r
F P
0 g
s
.33489 .66345 m .34422 .70722 L .35942 .68739 L p .707 .577 .707 r
F P
0 g
s
.35942 .68739 m .35008 .64362 L .33489 .66345 L p .707 .577 .707 r
F P
0 g
s
.2223 .77276 m .22273 .73543 L .19528 .73118 L p .707 .577 .707 r
F P
0 g
s
.22273 .73543 m .2223 .77276 L .25347 .7748 L p .707 .577 .707 r
F P
0 g
s
.20275 .73663 m .19342 .69286 L .17182 .68067 L p .707 .577 .707 r
F P
0 g
s
.19342 .69286 m .20275 .73663 L .2304 .74299 L p .707 .577 .707 r
F P
0 g
s
.30817 .77906 m .30693 .79814 L .33083 .79735 L p .707 .577 .707 r
F P
0 g
s
.33083 .79735 m .33206 .77827 L .30817 .77906 L p .707 .577 .707 r
F P
0 g
s
.31512 .73442 m .31468 .77175 L .33873 .76694 L p .707 .577 .707 r
F P
0 g
s
.33873 .76694 m .33916 .72961 L .31512 .73442 L p .707 .577 .707 r
F P
0 g
s
.19528 .73118 m .19484 .76851 L .2223 .77276 L p .707 .577 .707 r
F P
0 g
s
.18729 .78966 m .18853 .77059 L .1674 .76661 L p .707 .577 .707 r
F P
0 g
s
.66751 .7492 m .66875 .73013 L .65615 .72776 L p .707 .577 .707 r
F P
0 g
s
.62751 .30121 m .64644 .78799 L .65474 .77465 L p .707 .577 .707 r
F P
0 g
s
.65533 .75514 m .62751 .30121 L .65474 .77465 L .707 .577 .707 r
F
.63743 .28526 m .62751 .30121 L p .65533 .75514 L F P
0 g
s
.65636 .77204 m .65549 .74966 L p .65533 .75514 L .707 .577 .707 r
F P
0 g
s
.65549 .74966 m .63743 .28526 L p .65533 .75514 L .707 .577 .707 r
F P
0 g
s
.64761 .72615 m .64637 .74523 L .6553 .74691 L p .707 .577 .707 r
F P
0 g
s
.65524 .74609 m .64761 .72615 L .6553 .74691 L .707 .577 .707 r
F
.64915 .65908 m .64771 .61317 L .65549 .74966 L F
.63743 .28526 m .64935 .5917 L p .64771 .61317 L F P
0 g
s
.64935 .5917 m .65549 .74966 L p .64771 .61317 L .707 .577 .707 r
F P
0 g
s
.65591 .73577 m .6544 .73401 L .65557 .74696 L .707 .577 .707 r
F
.6544 .73401 m .64761 .72615 L .65524 .74609 L F
.6544 .73401 m .65524 .74609 L .65557 .74696 L F
.63327 .26945 m .63743 .28526 L p .64915 .65908 L F P
0 g
s
.65615 .72776 m .64761 .72615 L p .65591 .73577 L .707 .577 .707 r
F P
0 g
s
.65064 .7064 m .64751 .63554 L .64915 .65908 L .707 .577 .707 r
F
.64962 .68978 m .64751 .63554 L p .65064 .7064 L F P
0 g
s
.64751 .63554 m .63327 .26945 L p .64915 .65908 L .707 .577 .707 r
F P
0 g
s
.65474 .77465 m .65636 .77204 L p .65533 .75514 L .707 .577 .707 r
F P
0 g
s
.65636 .77204 m .65416 .76367 L p .64915 .65908 L .707 .577 .707 r
F P
0 g
s
.65416 .76367 m .6522 .75624 L p .65064 .7064 L .707 .577 .707 r
F P
0 g
s
.65064 .7064 m .64915 .65908 L .65416 .76367 L .707 .577 .707 r
F
.64637 .74523 m .64761 .72615 L .63489 .72213 L p F P
0 g
s
.63489 .72213 m .63365 .7412 L .64637 .74523 L p .707 .577 .707 r
F P
0 g
s
.63365 .7412 m .63489 .72213 L .63183 .71845 L p .707 .577 .707 r
F P
0 g
s
.6522 .75624 m .63437 .74214 L p .63422 .67922 L .707 .577 .707 r
F P
0 g
s
.63406 .60861 m .63872 .61364 L .64962 .68978 L .707 .577 .707 r
F
.647 .62254 m .64848 .66066 L p .63872 .61364 L F P
0 g
s
.64848 .66066 m .64962 .68978 L p .63872 .61364 L .707 .577 .707 r
F P
0 g
s
.64104 .61613 m .63861 .61308 L p .63888 .6138 L .707 .577 .707 r
F P
0 g
s
.64619 .63325 m .64104 .61613 L .63888 .6138 L .707 .577 .707 r
F
.65549 .74966 m .65636 .77204 L p .64915 .65908 L F P
0 g
s
.65399 .69752 m .65411 .68772 L p .64756 .65625 L .707 .577 .707 r
F P
0 g
s
.65411 .68772 m .65443 .66019 L .64763 .6563 L p .707 .577 .707 r
F P
0 g
s
.64763 .6563 m .64756 .65625 L p .65411 .68772 L .707 .577 .707 r
F P
0 g
s
.67505 .70355 m .67532 .68087 L p .65443 .66019 L .707 .577 .707 r
F P
0 g
s
.67532 .68087 m .67549 .66622 L .66606 .66352 L p .707 .577 .707 r
F P
0 g
s
.66606 .66352 m .65443 .66019 L p .67532 .68087 L .707 .577 .707 r
F P
0 g
s
.65204 .62989 m .64693 .6235 L p .64952 .63251 L .707 .577 .707 r
F P
0 g
s
.66137 .67366 m .65464 .6421 L p .64952 .63251 L .707 .577 .707 r
F P
0 g
s
.65464 .6421 m .65204 .62989 L p .64952 .63251 L .707 .577 .707 r
F P
0 g
s
.65443 .66019 m .65399 .69752 L .67505 .70355 L p .707 .577 .707 r
F P
0 g
s
.63902 .61418 m .64794 .65685 L .66137 .67366 L p .707 .577 .707 r
F P
0 g
s
.64211 .62951 m .63887 .61379 L p .63861 .61308 L .707 .577 .707 r
F P
0 g
s
.63327 .26945 m .647 .62254 L p .63872 .61364 L .707 .577 .707 r
F P
0 g
s
.63872 .61364 m .63861 .61308 L .63852 .61267 L p .706 .577 .707 r
F P
0 g
s
.63406 .60861 m .63402 .59095 L .63872 .61364 L .707 .577 .707 r
F
.63402 .59095 m .63327 .26945 L .63872 .61364 L F
.64794 .65685 m .64211 .62951 L p .63465 .5933 L .706 .577 .707 r
F P
0 g
s
.64211 .62951 m .63872 .61364 L p .63493 .59469 L .706 .577 .707 r
F P
0 g
s
.64211 .62951 m .63493 .59469 L .63465 .5933 L .706 .577 .707 r
F
.63852 .61267 m .63465 .5933 L p .63872 .61364 L F P
0 g
s
.64693 .6235 m .64104 .61613 L p .64619 .63325 L .707 .577 .707 r
F P
0 g
s
.63422 .67922 m .63406 .60861 L .64276 .65401 L .707 .577 .707 r
F
.63422 .67922 m .64276 .65401 L .64147 .68419 L F
.6414 .69031 m .64147 .68419 L p .64129 .68836 L F P
0 g
s
.6414 .69031 m .64995 .69521 L p .6488 .68922 L .707 .577 .707 r
F P
0 g
s
.64147 .68419 m .6414 .69031 L p .6488 .68922 L .707 .577 .707 r
F P
0 g
s
.64147 .68419 m .64276 .65401 L .64962 .68978 L .707 .577 .707 r
F
.64896 .67908 m .64183 .65298 L .64995 .69521 L F
.64962 .68978 m .6522 .75624 L p .64053 .70622 L F P
0 g
s
.63422 .67922 m .64147 .68419 L .64053 .70622 L .707 .577 .707 r
F
.64123 .68985 m .6414 .69031 L p .64129 .68836 L F P
0 g
s
.64147 .68419 m .64962 .68978 L .64053 .70622 L .707 .577 .707 r
F
.63893 .64528 m .6385 .68261 L .64123 .68985 L p F P
0 g
s
.64129 .68836 m .63893 .64528 L .64123 .68985 L .707 .577 .707 r
F
.64183 .65298 m .63893 .64528 L p .64129 .68836 L F P
0 g
s
.64147 .68419 m .64183 .65298 L p .64129 .68836 L .707 .577 .707 r
F P
0 g
s
.64183 .65298 m .64147 .68419 L p .6488 .68922 L .707 .577 .707 r
F P
0 g
s
.64995 .69521 m .65399 .69752 L p .64896 .67908 L .707 .577 .707 r
F P
0 g
s
.64756 .65625 m .64183 .65298 L p .64896 .67908 L .707 .577 .707 r
F P
0 g
s
.65399 .69752 m .64756 .65625 L .64896 .67908 L .707 .577 .707 r
F
.6522 .75624 m .64962 .68978 L p .65064 .7064 L F P
0 g
s
.66137 .67366 m .64693 .6235 L .64619 .63325 L .707 .577 .707 r
F
.6553 .74691 m .65557 .74696 L p .65524 .74609 L F P
0 g
s
.65557 .74696 m .66751 .7492 L p .65591 .73577 L .707 .577 .707 r
F P
0 g
s
.66751 .7492 m .65615 .72776 L .65591 .73577 L .707 .577 .707 r
F
.68239 .80244 m .68116 .82151 L .66002 .81754 L p F P
0 g
s
.66002 .81754 m .66126 .79846 L .68239 .80244 L p .707 .577 .707 r
F P
0 g
s
.1674 .76661 m .16616 .78569 L .18729 .78966 L p .707 .577 .707 r
F P
0 g
s
.69012 .73765 m .68968 .77498 L .66862 .76896 L p .707 .577 .707 r
F P
0 g
s
.66862 .76896 m .66906 .73162 L .69012 .73765 L p .707 .577 .707 r
F P
0 g
s
.19484 .76851 m .19528 .73118 L .17422 .72516 L p .707 .577 .707 r
F P
0 g
s
.35008 .64362 m .35942 .68739 L .36533 .66656 L p .707 .577 .707 r
F P
0 g
s
.36533 .66656 m .356 .62279 L .35008 .64362 L p .707 .577 .707 r
F P
0 g
s
.18116 .72444 m .17182 .68067 L .15839 .66387 L p .707 .577 .707 r
F P
0 g
s
.17182 .68067 m .18116 .72444 L .20275 .73663 L p .707 .577 .707 r
F P
0 g
s
.33206 .77827 m .33083 .79735 L .34702 .79537 L p .707 .577 .707 r
F P
0 g
s
.34702 .79537 m .34826 .7763 L .33206 .77827 L p .707 .577 .707 r
F P
0 g
s
.17422 .72516 m .17378 .76249 L .19484 .76851 L p .707 .577 .707 r
F P
0 g
s
.33916 .72961 m .33873 .76694 L .35509 .76051 L p .707 .577 .707 r
F P
0 g
s
.35509 .76051 m .35553 .72318 L .33916 .72961 L p .707 .577 .707 r
F P
0 g
s
.37282 .791 m .35389 .30422 L .34973 .28842 L p .707 .577 .707 r
F P
0 g
s
.35389 .30422 m .37282 .791 L .39066 .8051 L p .707 .577 .707 r
F P
0 g
s
.16616 .78569 m .1674 .76661 L .15468 .76259 L p .707 .577 .707 r
F P
0 g
s
.66126 .79846 m .66002 .81754 L .63253 .814 L p .707 .577 .707 r
F P
0 g
s
.15468 .76259 m .15344 .78166 L .16616 .78569 L p .707 .577 .707 r
F P
0 g
s
.17378 .76249 m .17422 .72516 L .16162 .71794 L p .707 .577 .707 r
F P
0 g
s
.356 .62279 m .36533 .66656 L .36138 .64677 L p .706 .577 .707 r
F P
0 g
s
.36138 .64677 m .35204 .603 L .356 .62279 L p .706 .577 .707 r
F P
0 g
s
.15839 .66387 m .16773 .70764 L .18116 .72444 L p .707 .577 .707 r
F P
0 g
s
.16773 .70764 m .15839 .66387 L .15444 .64408 L p .706 .577 .707 r
F P
0 g
s
.16162 .71794 m .16118 .75527 L .17378 .76249 L p .707 .577 .707 r
F P
0 g
s
.34826 .7763 m .34702 .79537 L .35392 .7924 L p .707 .577 .707 r
F P
0 g
s
.35392 .7924 m .35516 .77332 L .34826 .7763 L p .707 .577 .707 r
F P
0 g
s
.35553 .72318 m .35509 .76051 L .36217 .75308 L p .707 .577 .707 r
F P
0 g
s
.36217 .75308 m .36261 .71575 L .35553 .72318 L p .707 .577 .707 r
F P
0 g
s
.15344 .78166 m .15468 .76259 L .15162 .75891 L p .707 .577 .707 r
F P
0 g
s
.15162 .75891 m .15038 .77798 L .15344 .78166 L p .707 .577 .707 r
F P
0 g
s
.16118 .75527 m .16162 .71794 L .15872 .71024 L p .707 .577 .707 r
F P
0 g
s
.35204 .603 m .36138 .64677 L .34795 .62996 L p .707 .577 .707 r
F P
0 g
s
.34795 .62996 m .33861 .5862 L .35204 .603 L p .707 .577 .707 r
F P
0 g
s
.16377 .68785 m .15444 .64408 L .16035 .62325 L p .707 .577 .707 r
F P
0 g
s
.15444 .64408 m .16377 .68785 L .16773 .70764 L p .706 .577 .707 r
F P
0 g
s
.34973 .28842 m .36866 .7752 L .37282 .791 L p .707 .577 .707 r
F P
0 g
s
.36866 .7752 m .34973 .28842 L .35965 .27246 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15872 .71024 m .15828 .74757 L .16118 .75527 L p .707 .577 .707 r
F P
0 g
s
.35516 .77332 m .35392 .7924 L .35087 .78872 L p .707 .577 .707 r
F P
0 g
s
.35087 .78872 m .35211 .76964 L .35516 .77332 L p .707 .577 .707 r
F P
0 g
s
.36261 .71575 m .36217 .75308 L .35927 .74538 L p .707 .577 .707 r
F P
0 g
s
.35927 .74538 m .3597 .70805 L .36261 .71575 L p .707 .577 .707 r
F P
0 g
s
.33861 .5862 m .34795 .62996 L .32635 .61778 L p .707 .577 .707 r
F P
0 g
s
.32635 .61778 m .31702 .57401 L .33861 .5862 L p .707 .577 .707 r
F P
0 g
s
.16969 .66702 m .16035 .62325 L .17555 .60342 L p .707 .577 .707 r
F P
0 g
s
.16035 .62325 m .16969 .66702 L .16377 .68785 L p .707 .577 .707 r
F P
0 g
s
.63183 .71845 m .63059 .73752 L .63365 .7412 L p .707 .577 .707 r
F P
0 g
s
.63059 .73752 m .63183 .71845 L .63404 .7175 L p .707 .577 .707 r
F P
0 g
s
.63437 .74214 m .63423 .73858 L p .63327 .26945 L .707 .577 .707 r
F P
0 g
s
.62996 .26684 m .63327 .26945 L p .63423 .73858 L .707 .577 .707 r
F P
0 g
s
.63404 .7175 m .63874 .71547 L p .63413 .72794 L .707 .577 .707 r
F P
0 g
s
.63059 .73752 m .63404 .7175 L .63413 .72794 L .707 .577 .707 r
F
.63874 .71547 m .6375 .73455 L .63422 .73596 L p F P
0 g
s
.63422 .73596 m .63059 .73752 L p .6342 .72775 L .707 .577 .707 r
F P
0 g
s
.6342 .72775 m .63874 .71547 L .63422 .73596 L .707 .577 .707 r
F
.61544 .25535 m .63423 .73858 L p .6046 .73112 L F P
0 g
s
.63423 .73858 m .63437 .74214 L .63424 .74209 L p .707 .577 .707 r
F P
0 g
s
.63424 .74209 m .6046 .73112 L p .63423 .73858 L .707 .577 .707 r
F P
0 g
s
.63423 .73858 m .61544 .25535 L .62996 .26684 L p .707 .577 .707 r
F P
0 g
s
.15038 .77798 m .15162 .75891 L .15852 .75593 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15852 .75593 m .15729 .77501 L .15038 .77798 L p .707 .577 .707 r
F P
0 g
s
.15828 .74757 m .15872 .71024 L .1658 .70281 L p .707 .577 .707 r
F P
0 g
s
.1658 .70281 m .16536 .74014 L .15828 .74757 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.31702 .57401 m .32635 .61778 L .29871 .61142 L p .707 .577 .707 r
F P
0 g
s
.29871 .61142 m .28937 .56765 L .31702 .57401 L p .707 .577 .707 r
F P
0 g
s
.17555 .60342 m .18488 .64719 L .16969 .66702 L p .707 .577 .707 r
F P
0 g
s
.18488 .64719 m .17555 .60342 L .19855 .58653 L p .707 .577 .707 r
F P
0 g
s
.37858 .75925 m .35965 .27246 L .38268 .25791 L p .707 .577 .707 r
F P
0 g
s
.35965 .27246 m .37858 .75925 L .36866 .7752 L p .707 .577 .707 r
F P
0 g
s
.35211 .76964 m .35087 .78872 L .33815 .7847 L p .707 .577 .707 r
F P
0 g
s
.33815 .7847 m .33939 .76562 L .35211 .76964 L p .707 .577 .707 r
F P
0 g
s
.3597 .70805 m .35927 .74538 L .34667 .73816 L p .707 .577 .707 r
F P
0 g
s
.34667 .73816 m .34711 .70083 L .3597 .70805 L p .707 .577 .707 r
F P
0 g
s
.15729 .77501 m .15852 .75593 L .17472 .75396 L p .707 .577 .707 r
F P
0 g
s
.28937 .56765 m .29871 .61142 L .26772 .61149 L p .707 .577 .707 r
F P
0 g
s
.26772 .61149 m .25839 .56772 L .28937 .56765 L p .707 .577 .707 r
F P
0 g
s
.17472 .75396 m .17348 .77303 L .15729 .77501 L p .707 .577 .707 r
F P
0 g
s
.20788 .6303 m .19855 .58653 L .22709 .57423 L p .707 .577 .707 r
F P
0 g
s
.19855 .58653 m .20788 .6303 L .18488 .64719 L p .707 .577 .707 r
F P
0 g
s
.16536 .74014 m .1658 .70281 L .18216 .69638 L p .707 .577 .707 r
F P
0 g
s
.6046 .73112 m .58567 .24434 L .61544 .25535 L p .707 .577 .707 r
F P
0 g
s
.25839 .56772 m .26772 .61149 L .23642 .61799 L p .707 .577 .707 r
F P
0 g
s
.23642 .61799 m .22709 .57423 L .25839 .56772 L p .707 .577 .707 r
F P
0 g
s
.22709 .57423 m .23642 .61799 L .20788 .6303 L p .707 .577 .707 r
F P
0 g
s
.18216 .69638 m .18172 .73371 L .16536 .74014 L p .707 .577 .707 r
F P
0 g
s
.33939 .76562 m .33815 .7847 L .31701 .78072 L p .707 .577 .707 r
F P
0 g
s
.31701 .78072 m .31825 .76164 L .33939 .76562 L p .707 .577 .707 r
F P
0 g
s
.34711 .70083 m .34667 .73816 L .32561 .73214 L p .707 .577 .707 r
F P
0 g
s
.32561 .73214 m .32605 .69481 L .34711 .70083 L p .707 .577 .707 r
F P
0 g
s
.37858 .75925 m .38067 .50411 L .40013 .7276 L .707 .577 .707 r
F
.40161 .7447 m .39784 .74708 L p .40013 .7276 L F P
0 g
s
.39784 .74708 m .37858 .75925 L p .40013 .7276 L .707 .577 .707 r
F P
0 g
s
.39395 .54774 m .40074 .72232 L p .38067 .50411 L .707 .577 .707 r
F P
0 g
s
.40074 .72232 m .40161 .7447 L p .40013 .7276 L .707 .577 .707 r
F P
0 g
s
.38067 .50411 m .40074 .72232 L .40013 .7276 L .707 .577 .707 r
F
.40248 .71598 m .40667 .57617 L .42035 .65056 L F
.40147 .71966 m .41488 .72038 L p .40341 .71257 L F P
0 g
s
.38268 .25791 m .41657 .2462 L p .40248 .71598 L .707 .577 .707 r
F P
0 g
s
.40161 .7447 m .40074 .72232 L p .40248 .71598 L .707 .577 .707 r
F P
0 g
s
.40074 .72232 m .38268 .25791 L p .40248 .71598 L .707 .577 .707 r
F P
0 g
s
.41488 .72038 m .41612 .7013 L .40662 .7008 L p .707 .577 .707 r
F P
0 g
s
.40662 .7008 m .38437 .6996 L p .40341 .71257 L .707 .577 .707 r
F P
0 g
s
.41488 .72038 m .40662 .7008 L .40341 .71257 L .707 .577 .707 r
F
.40341 .71257 m .402 .71161 L .40147 .71966 L F
.402 .71161 m .38437 .6996 L .4011 .71924 L F
.402 .71161 m .4011 .71924 L .40147 .71966 L F
.38437 .6996 m .38313 .71868 L .40106 .71964 L p F P
0 g
s
.40106 .71964 m .40147 .71966 L p .4011 .71924 L .707 .577 .707 r
F P
0 g
s
.4011 .71924 m .38437 .6996 L .40106 .71964 L .707 .577 .707 r
F
.4355 .73298 m .40161 .7447 L p .40248 .71598 L F P
0 g
s
.41612 .7013 m .41488 .72038 L .44414 .72086 L p .707 .577 .707 r
F P
0 g
s
.44414 .72086 m .44538 .70178 L .41612 .7013 L p .707 .577 .707 r
F P
0 g
s
.40248 .71598 m .42035 .65056 L .42808 .6926 L .707 .577 .707 r
F
.43193 .67181 m .45188 .66997 L p .44731 .6645 L F P
0 g
s
.41657 .2462 m .45799 .23846 L p .44175 .59566 L .707 .577 .707 r
F P
0 g
s
.43856 .66573 m .435 .5978 L .44175 .59566 L .707 .577 .707 r
F
.435 .5978 m .41657 .2462 L .44175 .59566 L F
.43292 .66652 m .41657 .2462 L p .43856 .66573 L F P
0 g
s
.44921 .5933 m .44909 .59274 L .44391 .59497 L p .707 .577 .707 r
F P
0 g
s
.44731 .6645 m .43292 .66652 L .43193 .67181 L .707 .577 .707 r
F
.45195 .66385 m .4409 .61434 L .45676 .66318 L F
.43856 .66573 m .44084 .61559 L .45195 .66385 L F
.44084 .61559 m .4409 .61434 L .45195 .66385 L F
.45195 .66385 m .45188 .66997 L .4533 .66968 L p F P
0 g
s
.45188 .66997 m .45195 .66385 L p .44731 .6645 L .707 .577 .707 r
F P
0 g
s
.46803 .72008 m .46927 .701 L .44538 .70178 L p .707 .577 .707 r
F P
0 g
s
.46927 .701 m .46803 .72008 L .4765 .71904 L p .707 .577 .707 r
F P
0 g
s
.46977 .54127 m .47679 .72168 L p .45972 .56671 L .707 .577 .707 r
F P
0 g
s
.47699 .7239 m .46984 .54099 L .49161 .44828 L .707 .577 .707 r
F
.47679 .72168 m .46977 .54127 L p .47699 .7239 L F P
0 g
s
.46977 .54127 m .45799 .23846 L p .46984 .54099 L .707 .577 .707 r
F P
0 g
s
.46977 .54127 m .46984 .54099 L .47699 .7239 L .707 .577 .707 r
F
.47526 .70785 m .46927 .701 L .4765 .71904 L F
.5029 .23545 m .52183 .72223 L .47712 .72523 L p F P
0 g
s
.47699 .7239 m .5029 .23545 L .47712 .72523 L .707 .577 .707 r
F
.48422 .7181 m .48546 .69902 L .47477 .70033 L p F P
0 g
s
.47477 .70033 m .46927 .701 L p .47551 .70813 L .707 .577 .707 r
F P
0 g
s
.48422 .7181 m .47477 .70033 L .47551 .70813 L .707 .577 .707 r
F
.47712 .72523 m .47692 .72524 L p .47699 .7239 L F P
0 g
s
.4409 .61434 m .45972 .56671 L .47692 .72524 L .707 .577 .707 r
F
.47679 .72168 m .47692 .72524 L p .45972 .56671 L F P
0 g
s
.48142 .61962 m .47209 .57585 L .45947 .58512 L p .707 .577 .707 r
F P
0 g
s
.45947 .58512 m .44909 .59274 L p .45628 .59871 L .707 .577 .707 r
F P
0 g
s
.48142 .61962 m .45947 .58512 L .45628 .59871 L .707 .577 .707 r
F
.47593 .66516 m .47637 .62783 L .45232 .63264 L p F P
0 g
s
.45843 .63651 m .48142 .61962 L p .45628 .59871 L .707 .577 .707 r
F P
0 g
s
.45628 .59871 m .44935 .59295 L .45324 .61163 L .707 .577 .707 r
F
.45628 .59871 m .45324 .61163 L .45843 .63651 L F
.45799 .23846 m .5029 .23545 L p .49161 .44828 L F P
0 g
s
.46984 .54099 m .45799 .23846 L .49161 .44828 L .707 .577 .707 r
F
.47692 .72524 m .47679 .72168 L p .47699 .7239 L F P
0 g
s
.4765 .71904 m .47654 .71904 L p .47526 .70785 L .707 .577 .707 r
F P
0 g
s
.47654 .71904 m .48422 .7181 L p .47551 .70813 L .707 .577 .707 r
F P
0 g
s
.47551 .70813 m .47526 .70785 L .47654 .71904 L .707 .577 .707 r
F
.43856 .66573 m .45676 .66318 L .47692 .72524 L F
.45232 .63264 m .45195 .66385 L p .47593 .66516 L F P
0 g
s
.4533 .66968 m .47593 .66516 L p .45195 .66385 L .707 .577 .707 r
F P
0 g
s
.4303 .59929 m .43292 .66652 L p .40667 .57617 L .707 .577 .707 r
F P
0 g
s
.43292 .66652 m .4355 .73298 L p .42808 .6926 L .707 .577 .707 r
F P
0 g
s
.40667 .57617 m .43292 .66652 L .42808 .6926 L .707 .577 .707 r
F
.45232 .63264 m .43898 .63387 L p .44731 .6645 L F P
0 g
s
.43898 .63387 m .42294 .63535 L p .43584 .65077 L .707 .577 .707 r
F P
0 g
s
.44731 .6645 m .43898 .63387 L .43584 .65077 L .707 .577 .707 r
F
.45195 .66385 m .45232 .63264 L p .44731 .6645 L F P
0 g
s
.44538 .70178 m .44414 .72086 L .46803 .72008 L p .707 .577 .707 r
F P
0 g
s
.47692 .72524 m .4355 .73298 L p .43856 .66573 L .707 .577 .707 r
F P
0 g
s
.44909 .59274 m .44921 .5933 L p .44935 .59295 L .707 .577 .707 r
F P
0 g
s
.45799 .23846 m .46977 .54127 L p .4409 .61434 L .707 .577 .707 r
F P
0 g
s
.44921 .5933 m .45843 .63651 L p .44935 .59295 L .707 .577 .707 r
F P
0 g
s
.45581 .62424 m .44921 .5933 L p .4314 .60037 L .707 .577 .707 r
F P
0 g
s
.44391 .59497 m .4314 .60037 L p .44921 .5933 L .707 .577 .707 r
F P
0 g
s
.44731 .6645 m .43584 .65077 L .43292 .66652 L .707 .577 .707 r
F
.4355 .73298 m .43292 .66652 L p .43856 .66573 L F P
0 g
s
.42294 .63535 m .4225 .67268 L .43193 .67181 L p .707 .577 .707 r
F P
0 g
s
.43584 .65077 m .42294 .63535 L .43193 .67181 L .707 .577 .707 r
F
.42188 .72597 m .42808 .6926 L .4355 .73298 L F
.40248 .71598 m .42808 .6926 L .42188 .72597 L F
.41657 .2462 m .4303 .59929 L p .40667 .57617 L F P
0 g
s
.45843 .63651 m .45581 .62424 L p .42055 .60504 L .707 .577 .707 r
F P
0 g
s
.4314 .60037 m .42055 .60504 L p .45581 .62424 L .707 .577 .707 r
F P
0 g
s
.42988 .64881 m .42055 .60504 L .41194 .60683 L p .707 .577 .707 r
F P
0 g
s
.4225 .67268 m .42291 .63822 L p .39111 .63569 L .707 .577 .707 r
F P
0 g
s
.42291 .63822 m .42294 .63535 L .41771 .6354 L p .707 .577 .707 r
F P
0 g
s
.41771 .6354 m .39111 .63569 L p .42291 .63822 L .707 .577 .707 r
F P
0 g
s
.39067 .67302 m .39103 .64203 L p .35994 .63365 L .707 .577 .707 r
F P
0 g
s
.39103 .64203 m .39111 .63569 L .38112 .63504 L p .707 .577 .707 r
F P
0 g
s
.38112 .63504 m .35994 .63365 L p .39103 .64203 L .707 .577 .707 r
F P
0 g
s
.3595 .67098 m .35982 .64345 L p .33248 .6294 L .707 .577 .707 r
F P
0 g
s
.35982 .64345 m .35994 .63365 L .34892 .63194 L p .707 .577 .707 r
F P
0 g
s
.34892 .63194 m .33248 .6294 L p .35982 .64345 L .707 .577 .707 r
F P
0 g
s
.33248 .6294 m .33204 .66673 L .3595 .67098 L p .707 .577 .707 r
F P
0 g
s
.33204 .66673 m .33231 .64406 L p .31142 .62338 L .707 .577 .707 r
F P
0 g
s
.33231 .64406 m .33248 .6294 L .32305 .6267 L p .707 .577 .707 r
F P
0 g
s
.32305 .6267 m .31142 .62338 L p .33231 .64406 L .707 .577 .707 r
F P
0 g
s
.31836 .63684 m .31163 .60529 L p .2956 .57627 L .707 .577 .707 r
F P
0 g
s
.31163 .60529 m .30903 .59307 L .29727 .57837 L p .707 .577 .707 r
F P
0 g
s
.29727 .57837 m .2956 .57627 L p .31163 .60529 L .707 .577 .707 r
F P
0 g
s
.33996 .64903 m .33265 .61477 L p .30903 .59307 L .707 .577 .707 r
F P
0 g
s
.33265 .61477 m .33062 .60526 L .31561 .59679 L p .707 .577 .707 r
F P
0 g
s
.31561 .59679 m .30903 .59307 L p .33265 .61477 L .707 .577 .707 r
F P
0 g
s
.35994 .63365 m .3595 .67098 L .39067 .67302 L p .707 .577 .707 r
F P
0 g
s
.3676 .65539 m .36009 .62021 L p .33062 .60526 L .707 .577 .707 r
F P
0 g
s
.36009 .62021 m .35826 .61162 L .34292 .60809 L p .707 .577 .707 r
F P
0 g
s
.34292 .60809 m .33062 .60526 L p .36009 .62021 L .707 .577 .707 r
F P
0 g
s
.39111 .63569 m .39067 .67302 L .4225 .67268 L p .707 .577 .707 r
F P
0 g
s
.39859 .65532 m .39128 .62106 L p .35826 .61162 L .707 .577 .707 r
F P
0 g
s
.39128 .62106 m .38925 .61155 L .37382 .61159 L p .707 .577 .707 r
F P
0 g
s
.37382 .61159 m .35826 .61162 L p .39128 .62106 L .707 .577 .707 r
F P
0 g
s
.41194 .60683 m .38925 .61155 L p .42273 .64225 L .707 .577 .707 r
F P
0 g
s
.42988 .64881 m .41194 .60683 L .42273 .64225 L .707 .577 .707 r
F
.38268 .25791 m .39395 .54774 L p .38067 .50411 L F P
0 g
s
.17348 .77303 m .17472 .75396 L .19861 .75317 L p .707 .577 .707 r
F P
0 g
s
.19861 .75317 m .19737 .77225 L .17348 .77303 L p .707 .577 .707 r
F P
0 g
s
.18172 .73371 m .18216 .69638 L .20621 .69157 L p .707 .577 .707 r
F P
0 g
s
.58567 .24434 m .6046 .73112 L .56583 .72426 L p .707 .577 .707 r
F P
0 g
s
.56583 .72426 m .5469 .23748 L .58567 .24434 L p .707 .577 .707 r
F P
0 g
s
.20621 .69157 m .20577 .7289 L .18172 .73371 L p .707 .577 .707 r
F P
0 g
s
.31825 .76164 m .31701 .78072 L .28952 .77718 L p .707 .577 .707 r
F P
0 g
s
.28952 .77718 m .29076 .75811 L .31825 .76164 L p .707 .577 .707 r
F P
0 g
s
.32605 .69481 m .32561 .73214 L .29815 .7279 L p .707 .577 .707 r
F P
0 g
s
.29815 .7279 m .29859 .69057 L .32605 .69481 L p .707 .577 .707 r
F P
0 g
s
.19737 .77225 m .19861 .75317 L .22786 .75365 L p .707 .577 .707 r
F P
0 g
s
.22786 .75365 m .22663 .77273 L .19737 .77225 L p .707 .577 .707 r
F P
0 g
s
.20577 .7289 m .20621 .69157 L .23559 .68886 L p .707 .577 .707 r
F P
0 g
s
.76551 .70949 m .76592 .67504 L p .73412 .67251 L .707 .577 .707 r
F P
0 g
s
.76592 .67504 m .76595 .67216 L .76072 .67222 L p .707 .577 .707 r
F P
0 g
s
.76072 .67222 m .73412 .67251 L p .76592 .67504 L .707 .577 .707 r
F P
0 g
s
.73368 .70984 m .73404 .67884 L p .70295 .67046 L .707 .577 .707 r
F P
0 g
s
.73404 .67884 m .73412 .67251 L .72413 .67185 L p .707 .577 .707 r
F P
0 g
s
.72413 .67185 m .70295 .67046 L p .73404 .67884 L .707 .577 .707 r
F P
0 g
s
.70251 .70779 m .70283 .68026 L p .67549 .66622 L .707 .577 .707 r
F P
0 g
s
.70283 .68026 m .70295 .67046 L .69193 .66876 L p .707 .577 .707 r
F P
0 g
s
.69193 .66876 m .67549 .66622 L p .70283 .68026 L .707 .577 .707 r
F P
0 g
s
.67549 .66622 m .67505 .70355 L .70251 .70779 L p .707 .577 .707 r
F P
0 g
s
.68297 .68584 m .67566 .65159 L p .65204 .62989 L .707 .577 .707 r
F P
0 g
s
.67566 .65159 m .67363 .64207 L .65862 .6336 L p .707 .577 .707 r
F P
0 g
s
.65862 .6336 m .65204 .62989 L p .67566 .65159 L .707 .577 .707 r
F P
0 g
s
.70295 .67046 m .70251 .70779 L .73368 .70984 L p .707 .577 .707 r
F P
0 g
s
.71061 .69221 m .7031 .65702 L p .67363 .64207 L .707 .577 .707 r
F P
0 g
s
.7031 .65702 m .70127 .64844 L .68593 .6449 L p .707 .577 .707 r
F P
0 g
s
.68593 .6449 m .67363 .64207 L p .7031 .65702 L .707 .577 .707 r
F P
0 g
s
.73412 .67251 m .73368 .70984 L .76551 .70949 L p .707 .577 .707 r
F P
0 g
s
.7416 .69214 m .73429 .65788 L p .70127 .64844 L .707 .577 .707 r
F P
0 g
s
.73429 .65788 m .73226 .64837 L .71683 .6484 L p .707 .577 .707 r
F P
0 g
s
.71683 .6484 m .70127 .64844 L p .73429 .65788 L .707 .577 .707 r
F P
0 g
s
.76595 .67216 m .76551 .70949 L .79489 .70678 L p .707 .577 .707 r
F P
0 g
s
.79489 .70678 m .79533 .66945 L .76595 .67216 L p .707 .577 .707 r
F P
0 g
s
.77289 .68563 m .76356 .64186 L .73226 .64837 L p .707 .577 .707 r
F P
0 g
s
.79533 .66945 m .79489 .70678 L .81894 .70198 L p .707 .577 .707 r
F P
0 g
s
.81894 .70198 m .81938 .66465 L .79533 .66945 L p .707 .577 .707 r
F P
0 g
s
.76356 .64186 m .77289 .68563 L .80144 .67333 L p .707 .577 .707 r
F P
0 g
s
.80144 .67333 m .7921 .62956 L .76356 .64186 L p .707 .577 .707 r
F P
0 g
s
.73226 .64837 m .7416 .69214 L .77289 .68563 L p .707 .577 .707 r
F P
0 g
s
.29076 .75811 m .28952 .77718 L .25838 .77443 L p .707 .577 .707 r
F P
0 g
s
.25838 .77443 m .25962 .75535 L .29076 .75811 L p .707 .577 .707 r
F P
0 g
s
.29859 .69057 m .29815 .7279 L .26698 .72585 L p .707 .577 .707 r
F P
0 g
s
.26698 .72585 m .26742 .68852 L .29859 .69057 L p .707 .577 .707 r
F P
0 g
s
.7921 .62956 m .80144 .67333 L .82443 .65643 L p .707 .577 .707 r
F P
0 g
s
.82443 .65643 m .8151 .61266 L .7921 .62956 L p .707 .577 .707 r
F P
0 g
s
.70127 .64844 m .71061 .69221 L .7416 .69214 L p .707 .577 .707 r
F P
0 g
s
.23559 .68886 m .23515 .72619 L .20577 .7289 L p .707 .577 .707 r
F P
0 g
s
.22663 .77273 m .22786 .75365 L .25962 .75535 L p .707 .577 .707 r
F P
0 g
s
.5469 .23748 m .56583 .72426 L .52183 .72223 L p .707 .577 .707 r
F P
0 g
s
.52183 .72223 m .5029 .23545 L .5469 .23748 L p .707 .577 .707 r
F P
0 g
s
.23515 .72619 m .23559 .68886 L .26742 .68852 L p .707 .577 .707 r
F P
0 g
s
.25962 .75535 m .25838 .77443 L .22663 .77273 L p .707 .577 .707 r
F P
0 g
s
.72614 .7555 m .72738 .73642 L .69623 .73366 L p .707 .577 .707 r
F P
0 g
s
.72738 .73642 m .72614 .7555 L .75789 .7572 L p .707 .577 .707 r
F P
0 g
s
.75789 .7572 m .75913 .73812 L .72738 .73642 L p .707 .577 .707 r
F P
0 g
s
.26742 .68852 m .26698 .72585 L .23515 .72619 L p .707 .577 .707 r
F P
0 g
s
.69623 .73366 m .69499 .75274 L .72614 .7555 L p .707 .577 .707 r
F P
0 g
s
.75913 .73812 m .75789 .7572 L .78715 .75768 L p .707 .577 .707 r
F P
0 g
s
.78715 .75768 m .78839 .7386 L .75913 .73812 L p .707 .577 .707 r
F P
0 g
s
.69499 .75274 m .69623 .73366 L .66875 .73013 L p .707 .577 .707 r
F P
0 g
s
.66875 .73013 m .66751 .7492 L .69499 .75274 L p .707 .577 .707 r
F P
0 g
s
.8151 .61266 m .82443 .65643 L .83963 .6366 L p .707 .577 .707 r
F P
0 g
s
.83963 .6366 m .8303 .59283 L .8151 .61266 L p .707 .577 .707 r
F P
0 g
s
.67363 .64207 m .68297 .68584 L .71061 .69221 L p .707 .577 .707 r
F P
0 g
s
.78839 .7386 m .78715 .75768 L .81104 .75689 L p .707 .577 .707 r
F P
0 g
s
.81104 .75689 m .81228 .73781 L .78839 .7386 L p .707 .577 .707 r
F P
0 g
s
.8303 .59283 m .83963 .6366 L .84554 .61577 L p .707 .577 .707 r
F P
0 g
s
.84554 .61577 m .83621 .572 L .8303 .59283 L p .707 .577 .707 r
F P
0 g
s
.65204 .62989 m .66137 .67366 L .68297 .68584 L p .707 .577 .707 r
F P
0 g
s
.81938 .66465 m .81894 .70198 L .8353 .69554 L p .707 .577 .707 r
F P
0 g
s
.8353 .69554 m .83574 .65821 L .81938 .66465 L p .707 .577 .707 r
F P
0 g
s
.81228 .73781 m .81104 .75689 L .82723 .75491 L p .707 .577 .707 r
F P
0 g
s
.82723 .75491 m .82847 .73584 L .81228 .73781 L p .707 .577 .707 r
F P
0 g
s
.83621 .572 m .84554 .61577 L .84159 .59599 L p .706 .577 .707 r
F P
0 g
s
.84159 .59599 m .83226 .55222 L .83621 .572 L p .706 .577 .707 r
F P
0 g
s
.83574 .65821 m .8353 .69554 L .84238 .68811 L p .707 .577 .707 r
F P
0 g
s
.84238 .68811 m .84282 .65078 L .83574 .65821 L p .707 .577 .707 r
F P
0 g
s
.82847 .73584 m .82723 .75491 L .83414 .75194 L p .707 .577 .707 r
F P
0 g
s
.83414 .75194 m .83538 .73286 L .82847 .73584 L p .707 .577 .707 r
F P
0 g
s
.83226 .55222 m .84159 .59599 L .82816 .57918 L p .707 .577 .707 r
F P
0 g
s
.82816 .57918 m .81883 .53541 L .83226 .55222 L p .707 .577 .707 r
F P
0 g
s
.64399 .63707 m .63465 .5933 L .64057 .57247 L p .707 .577 .707 r
F P
0 g
s
.64399 .63707 m .64794 .65685 L p .63655 .60235 L .706 .577 .707 r
F P
0 g
s
.6385 .68261 m .63893 .64528 L .64455 .63938 L p .707 .577 .707 r
F P
0 g
s
.64455 .63938 m .64601 .63785 L p .64523 .6425 L .707 .577 .707 r
F P
0 g
s
.6385 .68261 m .64455 .63938 L .64523 .6425 L .707 .577 .707 r
F
.63465 .5933 m .63929 .61502 L p .63655 .60235 L .706 .577 .707 r
F P
0 g
s
.63929 .61502 m .64399 .63707 L p .63655 .60235 L .706 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.84282 .65078 m .84238 .68811 L .83948 .68041 L p .707 .577 .707 r
F P
0 g
s
.83948 .68041 m .83992 .64308 L .84282 .65078 L p .707 .577 .707 r
F P
0 g
s
.83538 .73286 m .83414 .75194 L .83108 .74826 L p .707 .577 .707 r
F P
0 g
s
.83108 .74826 m .83232 .72918 L .83538 .73286 L p .707 .577 .707 r
F P
0 g
s
.81883 .53541 m .82816 .57918 L .80657 .567 L p .707 .577 .707 r
F P
0 g
s
.80657 .567 m .79723 .52323 L .81883 .53541 L p .707 .577 .707 r
F P
0 g
s
.6499 .61624 m .64057 .57247 L .65576 .55264 L p .707 .577 .707 r
F P
0 g
s
.64057 .57247 m .6499 .61624 L .64399 .63707 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64601 .63785 m .64557 .67518 L .6385 .68261 L p .707 .577 .707 r
F P
0 g
s
.42055 .60504 m .42988 .64881 L .45843 .63651 L p .707 .577 .707 r
F P
0 g
s
.38925 .61155 m .39859 .65532 L .42988 .64881 L p .707 .577 .707 r
F P
0 g
s
.79723 .52323 m .80657 .567 L .77892 .56063 L p .707 .577 .707 r
F P
0 g
s
.77892 .56063 m .76959 .51686 L .79723 .52323 L p .707 .577 .707 r
F P
0 g
s
.65576 .55264 m .6651 .59641 L .6499 .61624 L p .707 .577 .707 r
F P
0 g
s
.6651 .59641 m .65576 .55264 L .67876 .53574 L p .707 .577 .707 r
F P
0 g
s
.83992 .64308 m .83948 .68041 L .82688 .6732 L p .707 .577 .707 r
F P
0 g
s
.82688 .6732 m .82732 .63587 L .83992 .64308 L p .707 .577 .707 r
F P
0 g
s
.83232 .72918 m .83108 .74826 L .81836 .74424 L p .707 .577 .707 r
F P
0 g
s
.81836 .74424 m .8196 .72516 L .83232 .72918 L p .707 .577 .707 r
F P
0 g
s
.35826 .61162 m .3676 .65539 L .39859 .65532 L p .707 .577 .707 r
F P
0 g
s
.38313 .71868 m .38437 .6996 L .35322 .69685 L p .707 .577 .707 r
F P
0 g
s
.35322 .69685 m .35198 .71593 L .38313 .71868 L p .707 .577 .707 r
F P
0 g
s
.64557 .67518 m .64601 .63785 L .66237 .63142 L p .707 .577 .707 r
F P
0 g
s
.76959 .51686 m .77892 .56063 L .74794 .5607 L p .707 .577 .707 r
F P
0 g
s
.74794 .5607 m .7386 .51693 L .76959 .51686 L p .707 .577 .707 r
F P
0 g
s
.68809 .57951 m .67876 .53574 L .7073 .52344 L p .707 .577 .707 r
F P
0 g
s
.67876 .53574 m .68809 .57951 L .6651 .59641 L p .707 .577 .707 r
F P
0 g
s
.6375 .73455 m .63874 .71547 L .65493 .7135 L p .707 .577 .707 r
F P
0 g
s
.35198 .71593 m .35322 .69685 L .32574 .69331 L p .707 .577 .707 r
F P
0 g
s
.65493 .7135 m .65369 .73257 L .6375 .73455 L p .707 .577 .707 r
F P
0 g
s
.32574 .69331 m .3245 .71239 L .35198 .71593 L p .707 .577 .707 r
F P
0 g
s
.47209 .57585 m .48142 .61962 L .49662 .59979 L p .707 .577 .707 r
F P
0 g
s
.49662 .59979 m .48729 .55602 L .47209 .57585 L p .707 .577 .707 r
F P
0 g
s
.33062 .60526 m .33996 .64903 L .3676 .65539 L p .707 .577 .707 r
F P
0 g
s
.66237 .63142 m .66194 .66875 L .64557 .67518 L p .707 .577 .707 r
F P
0 g
s
.7386 .51693 m .74794 .5607 L .71664 .56721 L p .707 .577 .707 r
F P
0 g
s
.71664 .56721 m .7073 .52344 L .7386 .51693 L p .707 .577 .707 r
F P
0 g
s
.7073 .52344 m .71664 .56721 L .68809 .57951 L p .707 .577 .707 r
F P
0 g
s
.82732 .63587 m .82688 .6732 L .80583 .66718 L p .707 .577 .707 r
F P
0 g
s
.80583 .66718 m .80626 .62984 L .82732 .63587 L p .707 .577 .707 r
F P
0 g
s
.3245 .71239 m .32574 .69331 L .3046 .68933 L p .707 .577 .707 r
F P
0 g
s
.8196 .72516 m .81836 .74424 L .79722 .74026 L p .707 .577 .707 r
F P
0 g
s
.79722 .74026 m .79846 .72118 L .8196 .72516 L p .707 .577 .707 r
F P
0 g
s
.3046 .68933 m .30336 .70841 L .3245 .71239 L p .707 .577 .707 r
F P
0 g
s
.66194 .66875 m .66237 .63142 L .68642 .62661 L p .707 .577 .707 r
F P
0 g
s
.48729 .55602 m .49662 .59979 L .50253 .57896 L p .707 .577 .707 r
F P
0 g
s
.50253 .57896 m .4932 .53519 L .48729 .55602 L p .707 .577 .707 r
F P
0 g
s
.30903 .59307 m .31836 .63684 L .33996 .64903 L p .707 .577 .707 r
F P
0 g
s
.31142 .62338 m .31098 .66071 L .33204 .66673 L p .707 .577 .707 r
F P
0 g
s
.65369 .73257 m .65493 .7135 L .67882 .71271 L p .707 .577 .707 r
F P
0 g
s
.67882 .71271 m .67758 .73179 L .65369 .73257 L p .707 .577 .707 r
F P
0 g
s
.47637 .62783 m .47593 .66516 L .49229 .65873 L p .707 .577 .707 r
F P
0 g
s
.49229 .65873 m .49273 .6214 L .47637 .62783 L p .707 .577 .707 r
F P
0 g
s
.68642 .62661 m .68598 .66394 L .66194 .66875 L p .707 .577 .707 r
F P
0 g
s
.80626 .62984 m .80583 .66718 L .77837 .66293 L p .707 .577 .707 r
F P
0 g
s
.77837 .66293 m .77881 .6256 L .80626 .62984 L p .707 .577 .707 r
F P
0 g
s
.3111 .6509 m .31142 .62338 L .30462 .61948 L p .707 .577 .707 r
F P
0 g
s
.2956 .57627 m .30493 .62004 L .31836 .63684 L p .707 .577 .707 r
F P
0 g
s
.30493 .62004 m .2991 .59269 L p .29164 .55648 L .706 .577 .707 r
F P
0 g
s
.2991 .59269 m .2956 .57627 L .2919 .55779 L p .706 .577 .707 r
F P
0 g
s
.2919 .55779 m .29164 .55648 L p .2991 .59269 L .706 .577 .707 r
F P
0 g
s
.31098 .66071 m .3111 .6509 L p .29882 .61616 L .707 .577 .707 r
F P
0 g
s
.30462 .61948 m .29882 .61616 L p .3111 .6509 L .707 .577 .707 r
F P
0 g
s
.30336 .70841 m .3046 .68933 L .29188 .68531 L p .707 .577 .707 r
F P
0 g
s
.79846 .72118 m .79722 .74026 L .76974 .73672 L p .707 .577 .707 r
F P
0 g
s
.76974 .73672 m .77098 .71765 L .79846 .72118 L p .707 .577 .707 r
F P
0 g
s
.29188 .68531 m .29064 .70439 L .30336 .70841 L p .707 .577 .707 r
F P
0 g
s
.68598 .66394 m .68642 .62661 L .7158 .6239 L p .707 .577 .707 r
F P
0 g
s
.4932 .53519 m .50253 .57896 L .49858 .55917 L p .706 .577 .707 r
F P
0 g
s
.49858 .55917 m .48925 .5154 L .4932 .53519 L p .706 .577 .707 r
F P
0 g
s
.67758 .73179 m .67882 .71271 L .70808 .71319 L p .707 .577 .707 r
F P
0 g
s
.29882 .61616 m .29839 .65349 L .31098 .66071 L p .707 .577 .707 r
F P
0 g
s
.70808 .71319 m .70684 .73227 L .67758 .73179 L p .707 .577 .707 r
F P
0 g
s
.77881 .6256 m .77837 .66293 L .7472 .66088 L p .707 .577 .707 r
F P
0 g
s
.7472 .66088 m .74763 .62355 L .77881 .6256 L p .707 .577 .707 r
F P
0 g
s
.7158 .6239 m .71536 .66123 L .68598 .66394 L p .707 .577 .707 r
F P
0 g
s
.49273 .6214 m .49229 .65873 L .49937 .6513 L p .707 .577 .707 r
F P
0 g
s
.49937 .6513 m .49981 .61397 L .49273 .6214 L p .707 .577 .707 r
F P
0 g
s
.71536 .66123 m .7158 .6239 L .74763 .62355 L p .707 .577 .707 r
F P
0 g
s
.77098 .71765 m .76974 .73672 L .73859 .73397 L p .707 .577 .707 r
F P
0 g
s
.73859 .73397 m .73983 .71489 L .77098 .71765 L p .707 .577 .707 r
F P
0 g
s
.48546 .69902 m .48422 .7181 L .49113 .71513 L p .707 .577 .707 r
F P
0 g
s
.49113 .71513 m .49237 .69605 L .48546 .69902 L p .707 .577 .707 r
F P
0 g
s
.74763 .62355 m .7472 .66088 L .71536 .66123 L p .707 .577 .707 r
F P
0 g
s
.70684 .73227 m .70808 .71319 L .73983 .71489 L p .707 .577 .707 r
F P
0 g
s
.73983 .71489 m .73859 .73397 L .70684 .73227 L p .707 .577 .707 r
F P
0 g
s
.29839 .65349 m .29882 .61616 L .29592 .60846 L p .707 .577 .707 r
F P
0 g
s
.29064 .70439 m .29188 .68531 L .28882 .68163 L p .707 .577 .707 r
F P
0 g
s
.28882 .68163 m .28758 .70071 L .29064 .70439 L p .707 .577 .707 r
F P
0 g
s
.48925 .5154 m .49858 .55917 L .48515 .54236 L p .707 .577 .707 r
F P
0 g
s
.48515 .54236 m .47582 .49859 L .48925 .5154 L p .707 .577 .707 r
F P
0 g
s
.30098 .60025 m .29164 .55648 L .29755 .53565 L p .707 .577 .707 r
F P
0 g
s
.30098 .60025 m .30493 .62004 L p .29354 .56553 L .706 .577 .707 r
F P
0 g
s
.29592 .60846 m .29548 .64579 L .29839 .65349 L p .707 .577 .707 r
F P
0 g
s
.29548 .64579 m .29592 .60846 L .30154 .60256 L p .707 .577 .707 r
F P
0 g
s
.30154 .60256 m .303 .60103 L p .30222 .60568 L .707 .577 .707 r
F P
0 g
s
.29548 .64579 m .30154 .60256 L .30222 .60568 L .707 .577 .707 r
F
.29164 .55648 m .29628 .57821 L p .29354 .56553 L .706 .577 .707 r
F P
0 g
s
.29628 .57821 m .30098 .60025 L p .29354 .56553 L .706 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49981 .61397 m .49937 .6513 L .49647 .6436 L p .707 .577 .707 r
F P
0 g
s
.49647 .6436 m .49691 .60627 L .49981 .61397 L p .707 .577 .707 r
F P
0 g
s
.49237 .69605 m .49113 .71513 L .48807 .71145 L p .707 .577 .707 r
F P
0 g
s
.48807 .71145 m .48931 .69237 L .49237 .69605 L p .707 .577 .707 r
F P
0 g
s
.47582 .49859 m .48515 .54236 L .46356 .53018 L p .707 .577 .707 r
F P
0 g
s
.46356 .53018 m .45422 .48641 L .47582 .49859 L p .707 .577 .707 r
F P
0 g
s
.30689 .57942 m .29755 .53565 L .31275 .51582 L p .707 .577 .707 r
F P
0 g
s
.29755 .53565 m .30689 .57942 L .30098 .60025 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28758 .70071 m .28882 .68163 L .29573 .67866 L p .707 .577 .707 r
F P
0 g
s
.29573 .67866 m .29449 .69774 L .28758 .70071 L p .707 .577 .707 r
F P
0 g
s
.303 .60103 m .30256 .63836 L .29548 .64579 L p .707 .577 .707 r
F P
0 g
s
.45422 .48641 m .46356 .53018 L .43591 .52381 L p .707 .577 .707 r
F P
0 g
s
.43591 .52381 m .42658 .48004 L .45422 .48641 L p .707 .577 .707 r
F P
0 g
s
.31275 .51582 m .32209 .55959 L .30689 .57942 L p .707 .577 .707 r
F P
0 g
s
.32209 .55959 m .31275 .51582 L .33575 .49893 L p .707 .577 .707 r
F P
0 g
s
.49691 .60627 m .49647 .6436 L .48387 .63638 L p .707 .577 .707 r
F P
0 g
s
.48387 .63638 m .48431 .59905 L .49691 .60627 L p .707 .577 .707 r
F P
0 g
s
.48931 .69237 m .48807 .71145 L .47535 .70742 L p .707 .577 .707 r
F P
0 g
s
.47535 .70742 m .47659 .68834 L .48931 .69237 L p .707 .577 .707 r
F P
0 g
s
.30256 .63836 m .303 .60103 L .31936 .5946 L p .707 .577 .707 r
F P
0 g
s
.42658 .48004 m .43591 .52381 L .40493 .52389 L p .707 .577 .707 r
F P
0 g
s
.40493 .52389 m .39559 .48012 L .42658 .48004 L p .707 .577 .707 r
F P
0 g
s
.34508 .5427 m .33575 .49893 L .36429 .48662 L p .707 .577 .707 r
F P
0 g
s
.33575 .49893 m .34508 .5427 L .32209 .55959 L p .707 .577 .707 r
F P
0 g
s
.29449 .69774 m .29573 .67866 L .31192 .67668 L p .707 .577 .707 r
F P
0 g
s
.31192 .67668 m .31068 .69576 L .29449 .69774 L p .707 .577 .707 r
F P
0 g
s
.31936 .5946 m .31893 .63193 L .30256 .63836 L p .707 .577 .707 r
F P
0 g
s
.39559 .48012 m .40493 .52389 L .37363 .53039 L p .707 .577 .707 r
F P
0 g
s
.37363 .53039 m .36429 .48662 L .39559 .48012 L p .707 .577 .707 r
F P
0 g
s
.36429 .48662 m .37363 .53039 L .34508 .5427 L p .707 .577 .707 r
F P
0 g
s
.48431 .59905 m .48387 .63638 L .46282 .63036 L p .707 .577 .707 r
F P
0 g
s
.46282 .63036 m .46325 .59303 L .48431 .59905 L p .707 .577 .707 r
F P
0 g
s
.47659 .68834 m .47535 .70742 L .45421 .70345 L p .707 .577 .707 r
F P
0 g
s
.45421 .70345 m .45545 .68437 L .47659 .68834 L p .707 .577 .707 r
F P
0 g
s
.31893 .63193 m .31936 .5946 L .34341 .58979 L p .707 .577 .707 r
F P
0 g
s
.31068 .69576 m .31192 .67668 L .33581 .67589 L p .707 .577 .707 r
F P
0 g
s
.33581 .67589 m .33457 .69497 L .31068 .69576 L p .707 .577 .707 r
F P
0 g
s
.34341 .58979 m .34297 .62712 L .31893 .63193 L p .707 .577 .707 r
F P
0 g
s
.46325 .59303 m .46282 .63036 L .43536 .62612 L p .707 .577 .707 r
F P
0 g
s
.43536 .62612 m .43579 .58878 L .46325 .59303 L p .707 .577 .707 r
F P
0 g
s
.45545 .68437 m .45421 .70345 L .42673 .69991 L p .707 .577 .707 r
F P
0 g
s
.42673 .69991 m .42797 .68083 L .45545 .68437 L p .707 .577 .707 r
F P
0 g
s
.34297 .62712 m .34341 .58979 L .37279 .58708 L p .707 .577 .707 r
F P
0 g
s
.33457 .69497 m .33581 .67589 L .36507 .67637 L p .707 .577 .707 r
F P
0 g
s
.36507 .67637 m .36383 .69545 L .33457 .69497 L p .707 .577 .707 r
F P
0 g
s
.43579 .58878 m .43536 .62612 L .40419 .62407 L p .707 .577 .707 r
F P
0 g
s
.40419 .62407 m .40462 .58674 L .43579 .58878 L p .707 .577 .707 r
F P
0 g
s
.37279 .58708 m .37235 .62441 L .34297 .62712 L p .707 .577 .707 r
F P
0 g
s
.37235 .62441 m .37279 .58708 L .40462 .58674 L p .707 .577 .707 r
F P
0 g
s
.42797 .68083 m .42673 .69991 L .39558 .69715 L p .707 .577 .707 r
F P
0 g
s
.39558 .69715 m .39682 .67808 L .42797 .68083 L p .707 .577 .707 r
F P
0 g
s
.40462 .58674 m .40419 .62407 L .37235 .62441 L p .707 .577 .707 r
F P
0 g
s
.36383 .69545 m .36507 .67637 L .39682 .67808 L p .707 .577 .707 r
F P
0 g
s
.39682 .67808 m .39558 .69715 L .36383 .69545 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo0021OolM001oOol007eoo`@0
0003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00H007Uoo`00NGoo10001EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01UYF1000MGoo001eOol40009FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000Lgoo001bOol300000eYF001JEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUIJEUYF0`00L7oo001^Ool40004FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP04FUH2001^
Ool006aoo`8000QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP<006aoo`00JWoo0`002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P00JWoo001YOol01000FUIJEP00
2EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF00<007ooOol0Igoo001WOol20003FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00Oomoo`1VOol006Ioo`03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00AJEVQoo`00
IGoo0P001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFJ7oo001UOol20005FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00Oomoo`1UOol006Aoo`03001JEP0000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
00AJEP03001oogoo06Eoo`00I7oo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<0
07ooOol0IGoo001SOol01000FUIJEP001EYF00<005YFFUH01eYF0P002eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYFIgoo001SOol01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH015YF00<005YFFUH01EYFIgoo001SOol01000FUIJEP001EYF00<005YFFUH0
25YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
Igoo001SOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH0
1eYF00<005YFFUH01eYF00=ooeYF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH015YFIgoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH015YF
Igoo001SOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001S
Ool01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001SOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001SOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001SOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0IGoo001SOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo
001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH01eYF0P002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00eYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF0P002UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YF
FUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01eYF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001EYF0P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF
0P002EYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJ
EP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol01000FUIJEP001EYF00<0
05YFFUH01eYF0P002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF0P002UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF0P002UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH025YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH025YF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF3@002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01@00FUIJEP00FUH01000
0UYF00<005YFFUH01UYF00<005YF00000`001EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol50006FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH30002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Aoo`800003FUH005YF00QJEP03001JEUYF00EJEP03001J
EUYF00EJEP<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP8006Eoo`00HGoo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00P002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001OOol20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001UOol005eoo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Eoo`00G7oo00@005YFFUH000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Eoo`00Fgoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001IOol20005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUH00006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001U
Ool005Qoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001UOol005Moo`8000MJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000FOol@000oOol005Moo`8000QJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPD000IJEP03001JEUYF009JEP04001J
EUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000?
Ool60003FUH00`00FUIJEP06FUH01000FUIJEUYF1@00>Woo001FOol01000FUIJEP001eYF00<005YF
FUH01UYF00<005YFFUH00UYF2@0000=JEP00FUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUH0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000eoo`80
0003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Qoo`00EGoo00D005YFFUIJEP00
00MJEP03001JEUYF00IJEPH000UJEP03001JEUYF00EJEP<000AJEP05001JEUYFFUH00005FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000;Ool20003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP00=goo001EOol01@00FUIJEUYF
00001eYF00<005YFFUH015YF0P001EYF00<005YFFUH01eYF00<005YFFUH025YF0P000eYF00@005YF
FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000Uo
o`8000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008003Eoo`00
E7oo00<005YFFUH00UYF00<005YFFUH01UYF00@005YFFUIJEP800003FUH005YF00AJEP03001JEUYF
00MJEP03001JEUYF00UJEP80009JEP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH30007Ool20008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0bOol005Aoo`03001JEUYF00=JEP03001JEUYF
00EJEP03001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EP000080009JEP03001JEUYF00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH30006Ool20009FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2000cOol005=oo`8000EJEP03001JEUYF00EJEP80009oo`04001JEUYF0005FUH00`00
FUIJEP07FUH2000:FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00@005YFFUIJEP<000Eoo`03001JEP0000UJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00039oo`00Dgoo00<005YF0000
15YF00<005YFFUH00eYF0P0017oo00@005YFFUH000EJEP03001JEUYF00MJEP8000YJEP03001JEUYF
009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH30003Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000AJEP03001JEUYF009JEP03001oogoo00Ao
o`04001JEUYF0005FUH00`00FUIJEP07FUH2000:FUH00`00FUIJEP03FUH00`00FUH00004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000Woo00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000<Goo001BOol01000FUIJEP001EYF00@005YFFUH000Moo`04001JEUYF0005FUH00`00
FUIJEP07FUH2000:FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=oo`00FUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0031oo`00DWoo
00@005YFFUH000EJEP<000Qoo`04001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP08FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@0
05YFFUIJEPD000IJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF009JEP04001JEUYF000`Ool0059oo`05001JEUYFFUH00004FUH00`00Oomoo`08Ool0
1000FUIJEP001EYF0`0025YF00<005YFFUH025YF00@005YFFUIJEP80009JEP03001JEUYF009JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH=0006FUH00`00FUIJEP02FUH00`00FUH0000`Ool0059oo`80
009JEP05001JEUYFFUH0000;Ool01000FUIJEP0015YF1@001eYF00<005YFFUH025YF00H005YFFUH0
05YF0002FUH00`00FUIJEP02FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010003Goo10000UYF00<0
05YFFUH00UYF00@005YFFUH002moo`00Agoo3@000UYF00@005YFFUH000aoo`04001JEUYF0004FUH5
0007FUH00`00FUIJEP08FUH01000FUIJEP000UYF00<005YF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEP@0
01Eoo`<000AJEP04001JEUYF000_Ool004=oo`@0009JEP03001JEUYF00IJEP80009JEP04001JEUYF
000<Ool01000FUIJEP0015YF1@001eYF00<005YFFUH025YF00<005YF00000eYF00@005YFFUH000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH2000LOol20002FUH01000FUIJEP00;goo000oOol40006FUH00`00FUIJ
EP06FUH30002FUH4000;Ool01000FUIJEP001EYF0`0025YF00<005YFFUH025YF0P0015YF00@005YF
FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00004FUH0
0`00FUIJEP05FUH00`00FUH00002000POol2000015YF001JEP00;goo000mOol200000eYF001JEP08
FUH00`00FUIJEP05FUH30002FUH00`00FUIJEP030009Ool01000FUIJEP001EYF00<005YFFUH025YF
00<005YFFUH025YF0P0015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF008000EJEP03001JEUYF00AJEP8002Eoo`80009JEP03001oogoo02aoo`00
>Woo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P000UYF00@005YFFUH0009JEP8000Moo`04
001JEUYF0005FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP04FUH00`00FUH00003
FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP020005FUH00`00FUIJ
EP03FUH00`00Oomoo`0WOol00`00FUH0000^Ool003Qoo`8000MJEP03001JEUYF00IJEP03001JEUYF
00IJEP800003FUH005YF009JEP03001JEUYF009JEP8000Eooa4000=JEP03001JEUYF00EJEP05001J
EUYFFUH00005FUH00`00FUH00003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000AJEP03001JEUYF009JEP03001oogoo02Qoo`<002ioo`00=Woo0`0025YF00<0
05YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00eYF00<005YFFUH00UYF1P000eYF00<005YF
FUH01eYF00@005YFFUIJEPP00003FUH0000000EJEP03001JEUYF009JEP8000AJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF0080
02Yoo`04001JEP00000^Ool003Eoo`04001JEUYF0008FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2
00000eYF00000003FUH500000eYF001JEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJ
EUYF1P000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YF00000UYF00<005YFFUH00eYF0P00;7oo00<005YFFUH00P00;Goo000dOol00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH005YF1@001EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF00000P001EYF
00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000UYF
00<005YFFUH00eYF00<007ooOol04Goo0`005Woo0P000eYF00<007ooOol0:goo000bOol20005FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH0000300000eYF001JEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0002FUH00`00FUIJEP02FUH00`00Oomoo`0AOol5000EOol20003FUH00`00Oomoo`0[Ool0035oo`03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP@000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEP00001JEP00
0eYF00<007ooOol04Woo1@0057oo00@005YFFUH0009JEP03001oogoo02]oo`00<7oo0P001eYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0`000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH0
0P001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP03001J
EP0001Eoo`D001=oo`05001JEUYFFUH00002FUH00`00Oomoo`0[Ool0031oo`8000QJEP03001JEUYF
00EJEP03001JEUYF00EJEPd000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP000UYF00@005YF000001Eoo`<001Aoo`05
001JEUYFFUH00003FUH00`00Oomoo`0ZOol002moo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00
FUIJEP04000:Ool00`00Ool00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0015YF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH0009JEP800004FUH00000000YOol00`00
FUIJEP02FUH01@00FUIJEUYF0000;7oo000^Ool01@00FUIJEUYF00001eYF00<005YFFUH01UYF0`00
3Woo00<007oo00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00800005FUH00000FUH00002FUH00`00Oomoo`0UOol2
0005FUH01000FUIJEP00;7oo000^Ool01@00FUIJEUYF00001eYF00<005YFFUH015YF0P004Goo0`00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP05001JEP00001JEP020002FUH00`00FUIJEP02000TOol00`00FUH00005FUH01000FUIJ
EP00;7oo000]Ool00`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF0P004goo00<005YF0000
0eYF00<005YFFUH015YF00<005YFFUH00UYF4@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF001J
EP020002FUH00`00FUIJEP02FUH00`00Oomoo`04OolG0004Ool20003FUH00`00FUIJEP02FUH00`00
FUH0000]Ool002eoo`03001JEUYF00=JEP03001JEUYF00EJEP04001JEP00000EOol00`00FUH00003
FUH01000FUIJEUYF2@0025YF0`001EYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8000AJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00@0009JEP04001JEUYFFUH8
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH000030005FUH00`00FUIJEP02FUH00`00
FUH0000]Ool002aoo`8000EJEP03001JEUYF00EJEP8001Moo`03001JEP0000=JEP@00003FUH005YF
00EJEP03001JEUYF00EJEPD000IJEP03001JEUYF00=JEPL000=JEP04001JEUYFFUH20004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001JEP050003FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60005FUH2000]Ool0
02aoo`03001JEP0000AJEP03001JEUYF00=JEP8001Uoo`04001JEP00FUH30004FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP06FUH20002FUH40003FUH00`00FUIJEP03FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP0500000eYF001JEP05FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH0
0`00Oomoo`0/Ool002aoo`03001JEP0000AJEP03001JEUYF009JEP03001oogoo01Uoo`03001JEP00
00800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPD000IJEP03001JEUYF00EJEP80
00AJEP04001JEUYF0002FUH00`00FUIJEP03FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH01000FUIJEUYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF1000;Woo000[Ool01000FUIJEP001EYF00@0
05YFFUH001aoo`80009JEP03001JEUYF0080009JEP03001JEUYF00EJEP03001JEUYF00EJEP<000MJ
EP03001JEUYF00=JEP8000IJEP04001JEUYFFUH30005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;Woo000[Ool01000
FUIJEP001EYF0`007Goo00D005YFFUIJEP0000AJEP800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00MJEP03001JEP0000800003FUH005YF00EJEP07001JEUYFFUH005YF00001EYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000^Ool002]oo`05001JEUYFFUH00004FUH00`00Oomoo`0MOol01@00FUIJEUYF00001EYF
10001UYF00<005YFFUH01UYF00<005YFFUH015YF100015YF00<005YFFUH015YF00L005YFFUIJEP00
FUH00005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo000[Ool01@00FUIJEUYF00000eYF00<007ooOol04Woo
0`002Goo00D005YFFUIJEP0000EJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05
0007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002ao
o`04001JEUYF0002FUH00`00Oomoo`0BOol50009Ool200000eYF001JEP04FUH00`00FUIJEP05FUH>
0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P001UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF0080
02eoo`00;7oo00@005YFFUH0009JEP03001oogoo019oo`D000]oo`<000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUH005YF000015YF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000/Ool01000FUIJEUYF0P005Goo1@003Woo0`0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF000000QJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEP00FUH00004FUH00`00FUIJEP02
FUHA0007FUH80004FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002aoo`05001JEUYFFUH0000G
Ool3000BOol50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEP0025YF1@002UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001JEP0000AJEP03001JEP0000<0
00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00AJEPH000AJEP03001JEUYF008002eoo`00;Goo
00@005YFFUH002]oo`04001JEUYF0002FUH90004FUH00`00FUIJEP06FUH01000FUIJEP0015YF1000
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YF001J
EP0000=JEP<000=JEP03001JEUYF00AJEP03001JEUYF00EJEPD000EJEP03001JEUYF00IJEP<00006
FUH00000001JEP000UYF0P00;Goo000]Ool00`00FUH0000[Ool01@00FUIJEUYF00001EYF00<005YF
00000UYF4P002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YF001JEP00FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH50005FUH00`00FUIJEP05
FUH20004FUH01000FUH000000UYF0P00;Goo000]Ool00`00FUH0000TOolQ0006FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUH005YF
100000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01EYF1@001UYF00<005YFFUH00UYF0`00
1EYF00@005YFFUIJEP@002eoo`00;Goo00@005YF0000025oo`<000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP02FUH20002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH30007FUH00`00FUH000020002FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH3000]Ool002ioo`03001JEP00008001moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH70003FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH00eYF
10001UYF00<005YFFUH01UYF00<005YFFUH015YF10001EYF00<005YFFUH00eYF00<005YFFUH00UYF
0`00;Goo000^Ool00`00FUH00002FUH00`00Oomoo`09OolA0002Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05000;
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00003FUH00`00FUIJEP03
FUH00`00FUIJEP040003FUH00`00FUIJEP06FUH00`00FUIJEP050007FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH00`00FUH0000]Ool002ioo`04001JEUYF0002FUH20003Ool60003FUH00`00FUIJEP07
FUH01000FUIJEUYF0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00000P0025YF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUH005YF008000EJEP03001JEUYF00AJ
EPl000AJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP8002ioo`00;Woo00@005YF
FUH000=JEP@00003FUH005YF00IJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00009JEQH0
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF
0P00;goo000^Ool200000eYF000000020005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJ
EP02FUH00`00FUH000030005FUH01000FUIJEUYF5@0015YF00<005YFFUH01EYF00<005YFFUH00eYF
00D005YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP04001JEP00000aOol002moo`<00003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00@00003FUH0000000H000AJEP03001JEUYF00=JEP03001JEUYF008000QJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001Woo00000000FUH000MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH5000cOol002ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00]JEP03001JEP0000H000=J
EP03001JEUYF008000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF
FUH30003Ool50004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH7000hOol002eo
o`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EPD000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00aJEP03001JEUYF00IJEPD00003
FUH0000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEP00FUH005YF
00000Woo00@005YFFUH0009JEQ/003moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1`0015YF00<005YFFUH01EYF
00<005YFFUH035YF00<005YFFUH02eYF0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00@005YFFUIJEQH004moo`00;Goo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPP000AJEP03001J
EUYF00aJEP03001JEUYF00]JEP03001JEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP@0009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF009JEPT004Ioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP`000UJEP03001JEUYF00YJEP<000UJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEPP003ioo`00;Goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8000=JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00AJEQD000QJEP03001JEUYF00IJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH6000hOol002eoo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF009JEQL000IJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP07FUH00`00FUIJEP07FUH:000;FUH00`00FUIJEP06FUH60002FUH00`00FUIJEP06
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP05000cOol002eoo`03001JEP0000=JEP04001JEUYFFUH800000eYF001J
EP05FUH50007FUH00`00FUIJEP040002FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YF
FUH00eYF00<005YFFUH01eYF00@005YFFUIJEPH000UJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00@000MJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP000080031oo`00;Goo00<005YF0000
0eYF1@0000=JEP00FUH01EYF00<005YFFUH015YF1@001eYF00<005YF00002@000eYF00@005YFFUIJ
EP8000=JEP03001JEUYF00=JEP03001JEUYF00IJEPD0009JEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00AJEP8000EJER8000AJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH2000_Ool002eoo`04001JEP00FUH20004FUH40006FUH00`00FUIJEP04FUH30006
FUH50003FUH00`00FUIJEP03FUH40003FUH00`00OomJEP02FUH00`00FUIJEP09FUH30007FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP02
FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJEP02FUHD0004FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;goo000]Ool00`00FUH000020005FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF
00<005YFFUH01@001eYF00<005YFFUH015YF00<005YFFUH00P0000=JEP00Ool00eYF00<005YFFUH0
1UYF0`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF0`00
00=JEP00FUH00eYF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
009JEPT000=JEP04001JEUYFFUH2000_Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00EJ
EPh000AJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH300001GooFUIJEUYF00001UYF
0P000UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00P0015YF00D005YFFUIJEP0000MJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF009JEPD0009JEP8002moo`00;Goo00D005YFFUIJEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP08
001JEUYFFUH005YF001oo`=JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP04001J
EUYFFUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH01000FUIJEUYF1000;goo000]Ool01@00FUIJEUYF00001EYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00P005YFFUIJEP00FUH0
07oo0eYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP800004FUH00000FUH50004FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0
000_Ool002eoob4000=JEP03001JEUYF00EJEP03001JEUYF00AJEP08001JEUYFFUH005YF001oo`=J
EP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40003FUH00`00FUIJEP0B0004FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH00`00FUIJEP04000`Ool002]oo`<000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF00AJEP04001JEUYFFUH20002Ool3
FUH200000eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH000000eYF00<005YFFUH00eYF00<005YF
FUH00P002Woo5P00=7oo000[Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00D005YFFUIJEP0000=oo`9JEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00AJEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol0
02]oo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00L000Aoo`9JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00=JEP04001JEP000003FUH00`00FUIJEP03FUH00`00FUIJEP02001DOol002Yoo`03001JEP0000AJ
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP00008000=oo`03FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000H000AJEP03001JEUYF008005Aoo`00:Woo00<005YF00000UYF5P0015YF00<0
05YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000=oo`03FUH005YF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF00<000=JEP<00004FUH005YFFUH2001DOol0
02Yoo`03001JEP0000<000EJEP04001JEUYFFUHK0006FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
0goo0P001EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P001EYF00@005YF0000009J
EP8005Aoo`00:Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF4P000UYF
00<005YFFUH00eYF00<005YFFUH00P000goo0P001EYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00D0
05YF001JEP0000EJEP04001JEUYFFUH4001DOol002]oo`80009JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEPH000=JEP03001JEUYF00EJEPH000=JEP03001JEUYF008000=oo`8000EJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP<005Ao
o`00;Goo1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00`0015YF00<005YFFUH0
1EYF00<005YFFUH00eYF1@0000=JEP00000017oo00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P000UYF00<005YFFUH00eYF00<005YFFUH00UYF0`00E7oo000bOol70004FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0`0017oo00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000IJEP03001JEUYF009JEP03
001JEP0005Aoo`00>Goo200015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00L0
05YFFUIJEP00FUH00005Ool20003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0P000eYF00<005YFFUH0
15YF00<005YFFUH00UYF0P00EGoo0011OolS0008Ool01000FUIJEP001eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH010000UYF
00<005YFFUH015YF00@005YFFUIJEP8005Ioo`00KGoo0`001eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF10000eYF1P000eYF00@005YF0000
05Qoo`00Kgoo00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01@00FWoo001`Ool2
0005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP03FUH30003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002001GOol0079oo`8000=J
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP0000D0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001FOol007Aoo`800003FUH005YF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEQ8000AJEP03001JEUYF00=JEP04
001JEUYFFUH2001FOol007Ioo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH6
0002FUH00`00FUH000040002FUH00`00FUIJEP04FUH70003FUH01000FUIJEUYF0P00EWoo001jOol6
0002FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH90008FUH00`00FUH000040002FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH50002FUH2001FOol0081ooaL000MJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4001FOol009Eoo`D000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP03001J
EP0005Ioo`00VWoo4P0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH01000Egoo002/
OolF001KOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.57342 .64845 m .56408 .70475 L .59507 .70887 L p .707 .577 .707 r
F P
0 g
s
.59507 .70887 m .60441 .65258 L .57342 .64845 L p .707 .577 .707 r
F P
0 g
s
.60441 .65258 m .59507 .70887 L .62637 .71454 L p .707 .577 .707 r
F P
0 g
s
.62637 .71454 m .6357 .65825 L .60441 .65258 L p .707 .577 .707 r
F P
0 g
s
.6357 .65825 m .62637 .71454 L .65491 .72121 L p .707 .577 .707 r
F P
0 g
s
.54578 .64628 m .53644 .70258 L .56408 .70475 L p .707 .577 .707 r
F P
0 g
s
.56408 .70475 m .57342 .64845 L .54578 .64628 L p .707 .577 .707 r
F P
0 g
s
.65491 .72121 m .66425 .66492 L .6357 .65825 L p .707 .577 .707 r
F P
0 g
s
.66425 .66492 m .65491 .72121 L .67791 .72822 L p .707 .577 .707 r
F P
0 g
s
.59581 .80806 m .59537 .77131 L .5642 .76956 L p .707 .577 .707 r
F P
0 g
s
.59537 .77131 m .59581 .80806 L .62764 .80685 L p .707 .577 .707 r
F P
0 g
s
.62764 .80685 m .62721 .77011 L .59537 .77131 L p .707 .577 .707 r
F P
0 g
s
.62721 .77011 m .62764 .80685 L .65702 .80281 L p .707 .577 .707 r
F P
0 g
s
.65702 .80281 m .65659 .76607 L .62721 .77011 L p .707 .577 .707 r
F P
0 g
s
.52418 .64628 m .51485 .70257 L .53644 .70258 L p .707 .577 .707 r
F P
0 g
s
.53644 .70258 m .54578 .64628 L .52418 .64628 L p .707 .577 .707 r
F P
0 g
s
.67791 .72822 m .68724 .67193 L .66425 .66492 L p .707 .577 .707 r
F P
0 g
s
.56464 .8063 m .5642 .76956 L .53674 .76502 L p .707 .577 .707 r
F P
0 g
s
.5642 .76956 m .56464 .8063 L .59581 .80806 L p .707 .577 .707 r
F P
0 g
s
.65659 .76607 m .65702 .80281 L .68107 .79632 L p .707 .577 .707 r
F P
0 g
s
.68107 .79632 m .68063 .75958 L .65659 .76607 L p .707 .577 .707 r
F P
0 g
s
.53674 .76502 m .53718 .80176 L .56464 .8063 L p .707 .577 .707 r
F P
0 g
s
.68724 .67193 m .67791 .72822 L .69311 .73489 L p .707 .577 .707 r
F P
0 g
s
.53718 .80176 m .53674 .76502 L .51569 .75814 L p .707 .577 .707 r
F P
0 g
s
.69311 .73489 m .70244 .6786 L .68724 .67193 L p .707 .577 .707 r
F P
0 g
s
.51075 .64845 m .50142 .70474 L .51485 .70257 L p .707 .577 .707 r
F P
0 g
s
.51485 .70257 m .52418 .64628 L .51075 .64845 L p .707 .577 .707 r
F P
0 g
s
.51569 .75814 m .51612 .79488 L .53718 .80176 L p .707 .577 .707 r
F P
0 g
s
.68063 .75958 m .68107 .79632 L .69743 .78803 L p .707 .577 .707 r
F P
0 g
s
.69743 .78803 m .697 .75128 L .68063 .75958 L p .707 .577 .707 r
F P
0 g
s
.60441 .8696 m .60318 .85218 L .57203 .8511 L p .707 .577 .707 r
F P
0 g
s
.60318 .85218 m .60441 .8696 L .63617 .86645 L p .707 .577 .707 r
F P
0 g
s
.63617 .86645 m .63493 .84904 L .60318 .85218 L p .707 .577 .707 r
F P
0 g
s
.63493 .84904 m .63617 .86645 L .66542 .85939 L p .707 .577 .707 r
F P
0 g
s
.66542 .85939 m .66418 .84197 L .63493 .84904 L p .707 .577 .707 r
F P
0 g
s
.51612 .79488 m .51569 .75814 L .50309 .74959 L p .707 .577 .707 r
F P
0 g
s
.70244 .6786 m .69311 .73489 L .69902 .74056 L p .707 .577 .707 r
F P
0 g
s
.57327 .86852 m .57203 .8511 L .54455 .84589 L p .707 .577 .707 r
F P
0 g
s
.57203 .8511 m .57327 .86852 L .60441 .8696 L p .707 .577 .707 r
F P
0 g
s
.69902 .74056 m .70835 .68427 L .70244 .6786 L p .707 .577 .707 r
F P
0 g
s
.66418 .84197 m .66542 .85939 L .68932 .84909 L p .707 .577 .707 r
F P
0 g
s
.68932 .84909 m .68808 .83167 L .66418 .84197 L p .707 .577 .707 r
F P
0 g
s
.5068 .65256 m .49746 .70886 L .50142 .70474 L p .707 .577 .707 r
F P
0 g
s
.50142 .70474 m .51075 .64845 L .5068 .65256 L p .707 .577 .707 r
F P
0 g
s
.50309 .74959 m .50353 .78633 L .51612 .79488 L p .707 .577 .707 r
F P
0 g
s
.54455 .84589 m .54578 .86331 L .57327 .86852 L p .707 .577 .707 r
F P
0 g
s
.697 .75128 m .69743 .78803 L .70451 .77874 L p .707 .577 .707 r
F P
0 g
s
.70451 .77874 m .70407 .74199 L .697 .75128 L p .707 .577 .707 r
F P
0 g
s
.54578 .86331 m .54455 .84589 L .52341 .83707 L p .707 .577 .707 r
F P
0 g
s
.52341 .83707 m .52465 .85449 L .54578 .86331 L p .707 .577 .707 r
F P
0 g
s
.50353 .78633 m .50309 .74959 L .50019 .74021 L p .707 .577 .707 r
F P
0 g
s
.68808 .83167 m .68932 .84909 L .70551 .83657 L p .707 .577 .707 r
F P
0 g
s
.70551 .83657 m .70427 .81915 L .68808 .83167 L p .707 .577 .707 r
F P
0 g
s
.70835 .68427 m .69902 .74056 L .69507 .74468 L p .707 .577 .707 r
F P
0 g
s
.50019 .74021 m .50063 .77696 L .50353 .78633 L p .707 .577 .707 r
F P
0 g
s
.69507 .74468 m .7044 .68839 L .70835 .68427 L p .707 .577 .707 r
F P
0 g
s
.52465 .85449 m .52341 .83707 L .51069 .8255 L p .707 .577 .707 r
F P
0 g
s
.51271 .65824 m .50338 .71453 L .49746 .70886 L p .707 .577 .707 r
F P
0 g
s
.49746 .70886 m .5068 .65256 L .51271 .65824 L p .707 .577 .707 r
F P
0 g
s
.70407 .74199 m .70451 .77874 L .70161 .76936 L p .707 .577 .707 r
F P
0 g
s
.70161 .76936 m .70117 .73261 L .70407 .74199 L p .707 .577 .707 r
F P
0 g
s
.47817 .81593 m .4971 .30376 L .4531 .3004 L p .707 .577 .707 r
F P
0 g
s
.50063 .77696 m .50019 .74021 L .50727 .73092 L p .707 .577 .707 r
F P
0 g
s
.51193 .84291 m .51069 .8255 L .50763 .81231 L p .707 .577 .707 r
F P
0 g
s
.50727 .73092 m .5077 .76766 L .50063 .77696 L p .707 .577 .707 r
F P
0 g
s
.52791 .6649 m .51857 .7212 L .50338 .71453 L p .707 .577 .707 r
F P
0 g
s
.50338 .71453 m .51271 .65824 L .52791 .6649 L p .707 .577 .707 r
F P
0 g
s
.50763 .81231 m .50887 .82972 L .51193 .84291 L p .707 .577 .707 r
F P
0 g
s
.54157 .72821 m .51857 .7212 L p .54372 .68286 L .707 .577 .707 r
F P
0 g
s
.57945 .67858 m .57011 .73488 L .54157 .72821 L p .707 .577 .707 r
F P
0 g
s
.61075 .68426 m .60141 .74055 L .57496 .73576 L p .707 .577 .707 r
F P
0 g
s
.57496 .73576 m .57011 .73488 L p .57727 .72596 L .707 .577 .707 r
F P
0 g
s
.57727 .72596 m .61075 .68426 L .57496 .73576 L .707 .577 .707 r
F
.64173 .68838 m .6324 .74467 L .60568 .74112 L p F P
0 g
s
.60568 .74112 m .60141 .74055 L p .60647 .73401 L .707 .577 .707 r
F P
0 g
s
.60647 .73401 m .64173 .68838 L .60568 .74112 L .707 .577 .707 r
F
.60141 .74055 m .60872 .69649 L p .60983 .69584 L F P
0 g
s
.60141 .74055 m .61199 .68442 L .60647 .73401 L .707 .577 .707 r
F
.57011 .73488 m .57945 .67858 L .61075 .68426 L p F P
0 g
s
.57749 .74884 m .57709 .71493 L p .60889 .71089 L .707 .577 .707 r
F P
0 g
s
.57709 .71493 m .57706 .7121 L .58229 .7119 L p .707 .577 .707 r
F P
0 g
s
.58229 .7119 m .60889 .71089 L p .57709 .71493 L .707 .577 .707 r
F P
0 g
s
.61075 .68426 m .61199 .68442 L p .60983 .69584 L .707 .577 .707 r
F P
0 g
s
.60872 .69649 m .61075 .68426 L p .60983 .69584 L .707 .577 .707 r
F P
0 g
s
.61199 .68442 m .64173 .68838 L p .60647 .73401 L .707 .577 .707 r
F P
0 g
s
.65026 .28505 m .64034 .2926 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.66938 .69055 m .66004 .74684 L .6324 .74467 L p .707 .577 .707 r
F P
0 g
s
.6324 .74467 m .64173 .68838 L .66938 .69055 L p .707 .577 .707 r
F P
0 g
s
.64006 .71265 m .6405 .74939 L .60933 .74764 L p .707 .577 .707 r
F P
0 g
s
.60933 .74764 m .60889 .71089 L .64006 .71265 L p .707 .577 .707 r
F P
0 g
s
.64678 .76684 m .64801 .78426 L .61687 .78317 L p .707 .577 .707 r
F P
0 g
s
.61687 .78317 m .61563 .76576 L .64678 .76684 L p .707 .577 .707 r
F P
0 g
s
.63133 .79723 m .6472 .36787 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.6472 .36787 m .65026 .28505 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.62141 .80478 m .63133 .79723 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.64034 .2926 m .63277 .49765 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.63277 .49765 m .62141 .80478 L p .63743 .4557 L .707 .577 .707 r
F P
0 g
s
.60889 .71089 m .60933 .74764 L .57749 .74884 L p .707 .577 .707 r
F P
0 g
s
.5645 .81507 m .59838 .81093 L p .59752 .78166 L .707 .577 .707 r
F P
0 g
s
.59337 .76796 m .59671 .76763 L p .5944 .77135 L .707 .577 .707 r
F P
0 g
s
.59671 .76763 m .61563 .76576 L p .598 .77764 L .707 .577 .707 r
F P
0 g
s
.57706 .7121 m .57749 .74884 L .56806 .75014 L p .707 .577 .707 r
F P
0 g
s
.56708 .74514 m .5645 .81507 L p .57192 .76977 L .707 .577 .707 r
F P
0 g
s
.52307 .81679 m .5645 .81507 L p .56144 .74565 L .707 .577 .707 r
F P
0 g
s
.55268 .74644 m .56416 .73027 L .56708 .74514 L .707 .577 .707 r
F
.54157 .72821 m .54419 .71243 L p .57945 .67858 L F P
0 g
s
.54419 .71243 m .56843 .67629 L .57945 .67858 L .707 .577 .707 r
F
.54682 .69655 m .54157 .72821 L p .54372 .68286 L F P
0 g
s
.54768 .71614 m .54804 .74686 L p .52407 .75937 L .707 .577 .707 r
F P
0 g
s
.5467 .75326 m .52407 .75937 L p .54804 .74686 L .707 .577 .707 r
F P
0 g
s
.56144 .74565 m .54324 .74729 L .52307 .81679 L .707 .577 .707 r
F
.54804 .74686 m .54811 .75288 L .5467 .75326 L p F P
0 g
s
.54768 .71614 m .57706 .7121 L p .55268 .74644 L .707 .577 .707 r
F P
0 g
s
.54811 .75288 m .54804 .74686 L p .55268 .74644 L .707 .577 .707 r
F P
0 g
s
.54804 .74686 m .54768 .71614 L p .55268 .74644 L .707 .577 .707 r
F P
0 g
s
.54419 .71243 m .55079 .67263 L p .56843 .67629 L .707 .577 .707 r
F P
0 g
s
.54372 .68286 m .55065 .6723 L .54682 .69655 L .707 .577 .707 r
F
.55079 .67263 m .54682 .69655 L p .55065 .6723 L F P
0 g
s
.542 .30461 m .53023 .62322 L p .55079 .67263 L .707 .577 .707 r
F P
0 g
s
.55825 .67333 m .542 .30461 L .55079 .67263 L .707 .577 .707 r
F
.51857 .7212 m .52791 .6649 L .5509 .67191 L p F P
0 g
s
.52407 .75937 m .52363 .72263 L .54768 .71614 L p .707 .577 .707 r
F P
0 g
s
.53023 .62322 m .52558 .74889 L p .5591 .69261 L .707 .577 .707 r
F P
0 g
s
.51578 .8162 m .51454 .79879 L .52523 .79052 L p .707 .577 .707 r
F P
0 g
s
.51578 .8162 m .52523 .79052 L .52516 .79134 L .707 .577 .707 r
F
.52449 .79876 m .52556 .79027 L .52473 .79827 L F
.51578 .8162 m .52516 .79134 L .52449 .79876 L F
.52516 .79134 m .52556 .79027 L .52449 .79876 L F
.51828 .72534 m .52363 .72263 L p .51883 .7362 L F P
0 g
s
.5077 .76766 m .51828 .72534 L .51883 .7362 L .707 .577 .707 r
F
.5077 .76766 m .50727 .73092 L .51828 .72534 L p F P
0 g
s
.50887 .82972 m .50763 .81231 L .51454 .79879 L p .707 .577 .707 r
F P
0 g
s
.52363 .72263 m .52407 .75937 L .5077 .76766 L p .707 .577 .707 r
F P
0 g
s
.51069 .8255 m .51193 .84291 L .52465 .85449 L p .707 .577 .707 r
F P
0 g
s
.51454 .79879 m .51578 .8162 L .50887 .82972 L p .707 .577 .707 r
F P
0 g
s
.54324 .74729 m .52986 .7485 L .52307 .81679 L .707 .577 .707 r
F
.52321 .81305 m .52307 .81679 L p .52986 .7485 L F P
0 g
s
.53073 .78627 m .53197 .80368 L .51578 .8162 L p .707 .577 .707 r
F P
0 g
s
.4971 .30376 m .47817 .81593 L .52288 .81679 L p .707 .577 .707 r
F P
0 g
s
.52288 .81679 m .52307 .81679 L p .523 .81539 L .707 .577 .707 r
F P
0 g
s
.523 .81539 m .4971 .30376 L .52288 .81679 L .707 .577 .707 r
F
.523 .81539 m .53023 .62322 L .50838 .52669 L F
.52307 .81679 m .52321 .81305 L p .523 .81539 L F P
0 g
s
.52321 .81305 m .53023 .62322 L p .523 .81539 L .707 .577 .707 r
F P
0 g
s
.52523 .79052 m .52556 .79027 L p .52516 .79134 L .707 .577 .707 r
F P
0 g
s
.52556 .79027 m .53073 .78627 L p .52473 .79827 L .707 .577 .707 r
F P
0 g
s
.52558 .74889 m .52321 .81305 L p .52986 .7485 L .707 .577 .707 r
F P
0 g
s
.5591 .69261 m .52558 .74889 L .54324 .74729 L .707 .577 .707 r
F
.54804 .74686 m .5591 .69261 L .54324 .74729 L F
.56144 .74565 m .55916 .6939 L .54804 .74686 L F
.55916 .6939 m .5591 .69261 L .54804 .74686 L F
.55608 .67312 m .57945 .67858 L p .55079 .67263 L F P
0 g
s
.58343 .30289 m .542 .30461 L p .56144 .74565 L .707 .577 .707 r
F P
0 g
s
.5645 .81507 m .56708 .74514 L p .56144 .74565 L .707 .577 .707 r
F P
0 g
s
.56416 .73027 m .57706 .7121 L .56929 .74494 L .707 .577 .707 r
F
.56416 .73027 m .56929 .74494 L .56708 .74514 L F
.56708 .74514 m .58343 .30289 L p .56144 .74565 L F P
0 g
s
.56708 .74514 m .56929 .74494 L .56806 .75014 L .707 .577 .707 r
F
.56806 .75014 m .54811 .75288 L p .55268 .74644 L F P
0 g
s
.55268 .74644 m .56708 .74514 L .56806 .75014 L .707 .577 .707 r
F
.5697 .6744 m .56708 .74514 L p .59333 .63917 L F P
0 g
s
.59333 .63917 m .56708 .74514 L .57192 .76977 L .707 .577 .707 r
F
.59752 .78166 m .57965 .72262 L .5645 .81507 L F
.59659 .77859 m .59671 .76763 L .598 .77764 L F
.58512 .78632 m .5944 .77135 L .59659 .77859 L F
.5944 .77135 m .59671 .76763 L .59659 .77859 L F
.59838 .81093 m .59925 .78738 L p .59752 .78166 L F P
0 g
s
.61563 .76576 m .61687 .78317 L .59894 .78495 L p .707 .577 .707 r
F P
0 g
s
.59894 .78495 m .58512 .78632 L p .598 .77764 L .707 .577 .707 r
F P
0 g
s
.598 .77764 m .61563 .76576 L .59894 .78495 L .707 .577 .707 r
F
.60604 .6037 m .59925 .78738 L p .61933 .54725 L F P
0 g
s
.59925 .78738 m .59838 .81093 L p .59987 .79219 L .707 .577 .707 r
F P
0 g
s
.61933 .54725 m .59925 .78738 L .59987 .79219 L .707 .577 .707 r
F
.61731 .29875 m .58343 .30289 L p .59752 .78166 L F P
0 g
s
.59925 .78738 m .61731 .29875 L p .59752 .78166 L .707 .577 .707 r
F P
0 g
s
.59752 .78166 m .59333 .63917 L .57965 .72262 L .707 .577 .707 r
F
.58512 .78632 m .58388 .7689 L .59337 .76796 L p F P
0 g
s
.58512 .78632 m .59337 .76796 L .5944 .77135 L .707 .577 .707 r
F
.62141 .80478 m .61933 .54725 L .59987 .79219 L F
.59838 .81093 m .60215 .80992 L p .59987 .79219 L F P
0 g
s
.60215 .80992 m .62141 .80478 L p .59987 .79219 L .707 .577 .707 r
F P
0 g
s
.61731 .29875 m .60604 .6037 L p .61933 .54725 L .707 .577 .707 r
F P
0 g
s
.58343 .30289 m .5697 .6744 L p .59333 .63917 L .707 .577 .707 r
F P
0 g
s
.55079 .67263 m .5509 .67191 L .55608 .67312 L p .707 .577 .707 r
F P
0 g
s
.5591 .69261 m .55825 .67333 L .55079 .67263 L .707 .577 .707 r
F
.5509 .67191 m .55079 .67263 L p .55065 .6723 L F P
0 g
s
.542 .30461 m .4971 .30376 L p .50838 .52669 L .707 .577 .707 r
F P
0 g
s
.53023 .62322 m .542 .30461 L p .50838 .52669 L .707 .577 .707 r
F P
0 g
s
.70427 .81915 m .70551 .83657 L .71241 .82305 L p .707 .577 .707 r
F P
0 g
s
.71241 .82305 m .71117 .80563 L .70427 .81915 L p .707 .577 .707 r
F P
0 g
s
.43417 .81258 m .4531 .3004 L .41432 .29487 L p .707 .577 .707 r
F P
0 g
s
.4531 .3004 m .43417 .81258 L .47817 .81593 L p .707 .577 .707 r
F P
0 g
s
.7044 .68839 m .69507 .74468 L .68164 .74685 L p .707 .577 .707 r
F P
0 g
s
.23041 .61164 m .22108 .66793 L .25206 .67205 L p .707 .577 .707 r
F P
0 g
s
.25206 .67205 m .2614 .61576 L .23041 .61164 L p .707 .577 .707 r
F P
0 g
s
.2614 .61576 m .25206 .67205 L .28336 .67773 L p .707 .577 .707 r
F P
0 g
s
.68164 .74685 m .69097 .69055 L .7044 .68839 L p .707 .577 .707 r
F P
0 g
s
.28336 .67773 m .29269 .62144 L .2614 .61576 L p .707 .577 .707 r
F P
0 g
s
.29269 .62144 m .28336 .67773 L .3119 .6844 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.20277 .60947 m .19343 .66576 L .22108 .66793 L p .707 .577 .707 r
F P
0 g
s
.22108 .66793 m .23041 .61164 L .20277 .60947 L p .707 .577 .707 r
F P
0 g
s
.70117 .73261 m .70161 .76936 L .68901 .76081 L p .707 .577 .707 r
F P
0 g
s
.68901 .76081 m .68858 .72407 L .70117 .73261 L p .707 .577 .707 r
F P
0 g
s
.3119 .6844 m .32124 .6281 L .29269 .62144 L p .707 .577 .707 r
F P
0 g
s
.39539 .80705 m .41432 .29487 L .38456 .28772 L p .707 .577 .707 r
F P
0 g
s
.41432 .29487 m .39539 .80705 L .43417 .81258 L p .707 .577 .707 r
F P
0 g
s
.71117 .80563 m .71241 .82305 L .70936 .80986 L p .707 .577 .707 r
F P
0 g
s
.70936 .80986 m .70812 .79244 L .71117 .80563 L p .707 .577 .707 r
F P
0 g
s
.32124 .6281 m .3119 .6844 L .3349 .69141 L p .707 .577 .707 r
F P
0 g
s
.2528 .77124 m .25237 .7345 L .22119 .73274 L p .707 .577 .707 r
F P
0 g
s
.25237 .7345 m .2528 .77124 L .28464 .77004 L p .707 .577 .707 r
F P
0 g
s
.28464 .77004 m .2842 .73329 L .25237 .7345 L p .707 .577 .707 r
F P
0 g
s
.2842 .73329 m .28464 .77004 L .31401 .76599 L p .707 .577 .707 r
F P
0 g
s
.31401 .76599 m .31358 .72925 L .2842 .73329 L p .707 .577 .707 r
F P
0 g
s
.18117 .60947 m .17184 .66576 L .19343 .66576 L p .707 .577 .707 r
F P
0 g
s
.19343 .66576 m .20277 .60947 L .18117 .60947 L p .707 .577 .707 r
F P
0 g
s
.69097 .69055 m .68164 .74685 L .66004 .74684 L p .707 .577 .707 r
F P
0 g
s
.3349 .69141 m .34423 .63512 L .32124 .6281 L p .707 .577 .707 r
F P
0 g
s
.22163 .76949 m .22119 .73274 L .19373 .7282 L p .707 .577 .707 r
F P
0 g
s
.22119 .73274 m .22163 .76949 L .2528 .77124 L p .707 .577 .707 r
F P
0 g
s
.66004 .74684 m .66938 .69055 L .69097 .69055 L p .707 .577 .707 r
F P
0 g
s
.62141 .80478 m .64034 .2926 L .61731 .29875 L p .707 .577 .707 r
F P
0 g
s
.31358 .72925 m .31401 .76599 L .33806 .75951 L p .707 .577 .707 r
F P
0 g
s
.33806 .75951 m .33762 .72276 L .31358 .72925 L p .707 .577 .707 r
F P
0 g
s
.68858 .72407 m .68901 .76081 L .66796 .75393 L p .707 .577 .707 r
F P
0 g
s
.66796 .75393 m .66752 .71719 L .68858 .72407 L p .707 .577 .707 r
F P
0 g
s
.19373 .7282 m .19417 .76495 L .22163 .76949 L p .707 .577 .707 r
F P
0 g
s
.34423 .63512 m .3349 .69141 L .3501 .69808 L p .707 .577 .707 r
F P
0 g
s
.19417 .76495 m .19373 .7282 L .17268 .72132 L p .707 .577 .707 r
F P
0 g
s
.70812 .79244 m .70936 .80986 L .69664 .79829 L p .707 .577 .707 r
F P
0 g
s
.69664 .79829 m .6954 .78087 L .70812 .79244 L p .707 .577 .707 r
F P
0 g
s
.3501 .69808 m .35943 .64178 L .34423 .63512 L p .707 .577 .707 r
F P
0 g
s
.36126 .78234 m .3625 .79975 L .36579 .7933 L p .707 .577 .707 r
F P
0 g
s
.36577 .79615 m .38456 .28772 L .37004 .28113 L p .707 .577 .707 r
F P
0 g
s
.38456 .28772 m .36577 .79615 L p .39539 .80705 L .707 .577 .707 r
F P
0 g
s
.36577 .79615 m .36563 .7999 L .36576 .79993 L p .707 .577 .707 r
F P
0 g
s
.36576 .79993 m .39539 .80705 L p .36577 .79615 L .707 .577 .707 r
F P
0 g
s
.3694 .78624 m .36817 .76882 L .36582 .77341 L p .707 .577 .707 r
F P
0 g
s
.36582 .77341 m .36126 .78234 L p .3658 .78451 L .707 .577 .707 r
F P
0 g
s
.3694 .78624 m .36582 .77341 L .3658 .78451 L .707 .577 .707 r
F
.36579 .7933 m .3694 .78624 L p .36587 .78454 L F P
0 g
s
.36587 .78454 m .36126 .78234 L .36579 .7933 L .707 .577 .707 r
F
.36563 .7999 m .36577 .79615 L p .36673 .27963 L F P
0 g
s
.37004 .28113 m .36673 .27963 L p .36577 .79615 L .707 .577 .707 r
F P
0 g
s
.16774 .61163 m .15841 .66792 L .17184 .66576 L p .707 .577 .707 r
F P
0 g
s
.17184 .66576 m .18117 .60947 L .16774 .61163 L p .707 .577 .707 r
F P
0 g
s
.17268 .72132 m .17311 .75807 L .19417 .76495 L p .707 .577 .707 r
F P
0 g
s
.33762 .72276 m .33806 .75951 L .35443 .75121 L p .707 .577 .707 r
F P
0 g
s
.35443 .75121 m .35399 .71447 L .33762 .72276 L p .707 .577 .707 r
F P
0 g
s
.66752 .71719 m .66796 .75393 L .6405 .74939 L p .707 .577 .707 r
F P
0 g
s
.6405 .74939 m .64006 .71265 L .66752 .71719 L p .707 .577 .707 r
F P
0 g
s
.2614 .83279 m .26017 .81537 L .22902 .81428 L p .707 .577 .707 r
F P
0 g
s
.26017 .81537 m .2614 .83279 L .29316 .82964 L p .707 .577 .707 r
F P
0 g
s
.29316 .82964 m .29192 .81222 L .26017 .81537 L p .707 .577 .707 r
F P
0 g
s
.29192 .81222 m .29316 .82964 L .32241 .82257 L p .707 .577 .707 r
F P
0 g
s
.32241 .82257 m .32118 .80516 L .29192 .81222 L p .707 .577 .707 r
F P
0 g
s
.17311 .75807 m .17268 .72132 L .16008 .71278 L p .707 .577 .707 r
F P
0 g
s
.35943 .64178 m .3501 .69808 L .35601 .70375 L p .707 .577 .707 r
F P
0 g
s
.23026 .8317 m .22902 .81428 L .20154 .80908 L p .707 .577 .707 r
F P
0 g
s
.22902 .81428 m .23026 .8317 L .2614 .83279 L p .707 .577 .707 r
F P
0 g
s
.6954 .78087 m .69664 .79829 L .6755 .78946 L p .707 .577 .707 r
F P
0 g
s
.6755 .78946 m .67426 .77205 L .6954 .78087 L p .707 .577 .707 r
F P
0 g
s
.35601 .70375 m .36534 .64745 L .35943 .64178 L p .707 .577 .707 r
F P
0 g
s
.32118 .80516 m .32241 .82257 L .34631 .81227 L p .707 .577 .707 r
F P
0 g
s
.34631 .81227 m .34507 .79486 L .32118 .80516 L p .707 .577 .707 r
F P
0 g
s
.16379 .61575 m .15445 .67204 L .15841 .66792 L p .707 .577 .707 r
F P
0 g
s
.15841 .66792 m .16774 .61163 L .16379 .61575 L p .707 .577 .707 r
F P
0 g
s
.16008 .71278 m .16052 .74952 L .17311 .75807 L p .707 .577 .707 r
F P
0 g
s
.20154 .80908 m .20277 .82649 L .23026 .8317 L p .707 .577 .707 r
F P
0 g
s
.35399 .71447 m .35443 .75121 L .3615 .74192 L p .707 .577 .707 r
F P
0 g
s
.3615 .74192 m .36107 .70518 L .35399 .71447 L p .707 .577 .707 r
F P
0 g
s
.53197 .80368 m .53073 .78627 L .55462 .77597 L p .707 .577 .707 r
F P
0 g
s
.20277 .82649 m .20154 .80908 L .1804 .80025 L p .707 .577 .707 r
F P
0 g
s
.35206 .70787 m .33863 .71003 L p .35381 .67104 L .707 .577 .707 r
F P
0 g
s
.3625 .79975 m .36126 .78234 L .34507 .79486 L p .707 .577 .707 r
F P
0 g
s
.36107 .70518 m .3615 .74192 L .35877 .73309 L p .707 .577 .707 r
F P
0 g
s
.3478 .79181 m .36116 .79787 L p .35853 .72652 L .707 .577 .707 r
F P
0 g
s
.36534 .64745 m .35601 .70375 L .35206 .70787 L p .707 .577 .707 r
F P
0 g
s
.35816 .6958 m .35853 .72652 L p .35038 .72188 L .707 .577 .707 r
F P
0 g
s
.3476 .7203 m .35104 .71232 L .35038 .72188 L .707 .577 .707 r
F
.35104 .71232 m .35816 .6958 L .35038 .72188 L F
.3478 .79181 m .35038 .72188 L p .34936 .73674 L F P
0 g
s
.35853 .72652 m .35648 .72535 L .3478 .79181 L .707 .577 .707 r
F
.35381 .67104 m .36112 .65227 L .35467 .69209 L F
.36127 .65229 m .35467 .69209 L p .36112 .65227 L F P
0 g
s
.35467 .69209 m .35206 .70787 L p .35381 .67104 L .707 .577 .707 r
F P
0 g
s
.35206 .70787 m .36127 .65229 L p .36534 .64745 L .707 .577 .707 r
F P
0 g
s
.35816 .6958 m .36107 .70518 L p .35871 .73136 L .707 .577 .707 r
F P
0 g
s
.3586 .73254 m .35853 .72652 L p .35871 .73136 L .707 .577 .707 r
F P
0 g
s
.35853 .72652 m .35816 .6958 L p .35871 .73136 L .707 .577 .707 r
F P
0 g
s
.36594 .65293 m .36127 .65229 L .35731 .69336 L .707 .577 .707 r
F
.33863 .71003 m .34796 .65374 L .35307 .65291 L p F P
0 g
s
.36147 .65149 m .36534 .64745 L p .36127 .65229 L .707 .577 .707 r
F P
0 g
s
.36673 .27963 m .353 .65114 L p .36594 .65293 L .707 .577 .707 r
F P
0 g
s
.35307 .65291 m .36139 .65157 L p .35381 .67104 L .707 .577 .707 r
F P
0 g
s
.33863 .71003 m .35307 .65291 L .35381 .67104 L .707 .577 .707 r
F
.3476 .7203 m .34701 .71066 L .34813 .71718 L F
.34701 .71066 m .34557 .68725 L .34813 .71718 L F
.34557 .68725 m .35244 .69192 L p .34813 .71718 L F P
0 g
s
.3476 .7203 m .35244 .69192 L .35104 .71232 L .707 .577 .707 r
F
.346 .72399 m .34595 .71936 L p .3476 .7203 L F P
0 g
s
.34595 .71936 m .34557 .68725 L p .3476 .7203 L .707 .577 .707 r
F P
0 g
s
.346 .72399 m .3476 .7203 L .35028 .72329 L .707 .577 .707 r
F
.35648 .72535 m .35433 .72413 L .3478 .79181 L F
.35244 .69192 m .35816 .6958 L p .35104 .71232 L F P
0 g
s
.35151 .69125 m .3478 .79181 L p .36127 .65229 L .707 .577 .707 r
F P
0 g
s
.3586 .73254 m .35005 .72674 L p .35028 .72329 L .707 .577 .707 r
F P
0 g
s
.35005 .72674 m .346 .72399 L p .35028 .72329 L .707 .577 .707 r
F P
0 g
s
.35853 .72652 m .3586 .73254 L p .3476 .7203 L .707 .577 .707 r
F P
0 g
s
.34364 .78359 m .34584 .78794 L p .34815 .71658 L .707 .577 .707 r
F P
0 g
s
.34815 .71658 m .34499 .75426 L .34364 .78359 L .707 .577 .707 r
F
.3447 .75775 m .34442 .75763 L p .3456 .74699 L F P
0 g
s
.34442 .75763 m .33249 .75265 L p .34409 .74764 L .707 .577 .707 r
F P
0 g
s
.34409 .74764 m .3456 .74699 L .34442 .75763 L .707 .577 .707 r
F
.34584 .78794 m .3478 .79181 L p .34936 .73674 L F P
0 g
s
.34936 .73674 m .36257 .27141 L .34584 .78794 L .707 .577 .707 r
F
.34607 .74142 m .35239 .74406 L p .3456 .74699 L F P
0 g
s
.34451 .76004 m .34364 .78359 L p .34499 .75426 L .707 .577 .707 r
F P
0 g
s
.35239 .74406 m .35363 .76147 L .3447 .75775 L p .707 .577 .707 r
F P
0 g
s
.3456 .74699 m .35239 .74406 L .3447 .75775 L .707 .577 .707 r
F
.35804 .71337 m .35731 .69336 L .35433 .72413 L F
.35804 .71337 m .35433 .72413 L .35648 .72535 L F
.353 .65114 m .35151 .69125 L p .36127 .65229 L F P
0 g
s
.34936 .73674 m .353 .65114 L .35228 .63374 L .707 .577 .707 r
F
.35038 .72188 m .353 .65114 L p .34936 .73674 L F P
0 g
s
.353 .65114 m .36673 .27963 L p .35228 .63374 L .707 .577 .707 r
F P
0 g
s
.35871 .73136 m .36107 .70518 L .35877 .73309 L .707 .577 .707 r
F
.36563 .7999 m .36594 .65293 L .35804 .71337 L F
.36116 .79787 m .36563 .7999 L p .35804 .71337 L F P
0 g
s
.36511 .75563 m .36635 .77305 L .35363 .76147 L p .707 .577 .707 r
F P
0 g
s
.35363 .76147 m .35239 .74406 L .36511 .75563 L p .707 .577 .707 r
F P
0 g
s
.37249 .26385 m .35356 .77603 L .34526 .78235 L p .707 .577 .707 r
F P
0 g
s
.34526 .78235 m .34364 .78359 L p .34467 .76493 L .707 .577 .707 r
F P
0 g
s
.34385 .74049 m .34607 .74142 L p .34394 .74318 L .707 .577 .707 r
F P
0 g
s
.33249 .75265 m .34607 .74142 L .3456 .74699 L .707 .577 .707 r
F
.34815 .71658 m .35147 .61396 L .34499 .75426 L F
.36673 .27963 m .36257 .27141 L p .35228 .63374 L F P
0 g
s
.34467 .76493 m .37249 .26385 L .34526 .78235 L .707 .577 .707 r
F
.33249 .75265 m .33125 .73523 L .34385 .74049 L p F P
0 g
s
.33249 .75265 m .34385 .74049 L .34394 .74318 L .707 .577 .707 r
F
.34796 .65374 m .33863 .71003 L .31703 .71003 L p F P
0 g
s
.34557 .68725 m .346 .72399 L .32495 .71711 L p .707 .577 .707 r
F P
0 g
s
.35065 .59384 m .34451 .76004 L p .3453 .74748 L .707 .577 .707 r
F P
0 g
s
.3453 .74748 m .34451 .76004 L .34499 .75426 L .707 .577 .707 r
F
.35147 .61396 m .35077 .59677 L .3453 .74748 L F
.35077 .59677 m .35065 .59384 L .3453 .74748 L F
.36257 .27141 m .35065 .59384 L p .35147 .61396 L F P
0 g
s
.36257 .27141 m .37249 .26385 L p .34467 .76493 L .707 .577 .707 r
F P
0 g
s
.34364 .78359 m .34451 .76004 L p .34467 .76493 L .707 .577 .707 r
F P
0 g
s
.34451 .76004 m .36257 .27141 L p .34467 .76493 L .707 .577 .707 r
F P
0 g
s
.36594 .65293 m .35731 .69336 L .35804 .71337 L .707 .577 .707 r
F
.36127 .65229 m .36139 .65157 L .36147 .65149 L p F P
0 g
s
.35853 .72652 m .35804 .71337 L .35648 .72535 L .707 .577 .707 r
F
.35877 .73309 m .3586 .73254 L p .35871 .73136 L F P
0 g
s
.36139 .65157 m .36127 .65229 L p .36112 .65227 L .707 .577 .707 r
F P
0 g
s
.55462 .77597 m .55586 .79339 L .53197 .80368 L p .707 .577 .707 r
F P
0 g
s
.67426 .77205 m .6755 .78946 L .64801 .78426 L p .707 .577 .707 r
F P
0 g
s
.64801 .78426 m .64678 .76684 L .67426 .77205 L p .707 .577 .707 r
F P
0 g
s
.1804 .80025 m .18164 .81767 L .20277 .82649 L p .707 .577 .707 r
F P
0 g
s
.16052 .74952 m .16008 .71278 L .15718 .7034 L p .707 .577 .707 r
F P
0 g
s
.34507 .79486 m .34631 .81227 L .3625 .79975 L p .707 .577 .707 r
F P
0 g
s
.55586 .79339 m .55462 .77597 L .58388 .7689 L p .707 .577 .707 r
F P
0 g
s
.15718 .7034 m .15762 .74014 L .16052 .74952 L p .707 .577 .707 r
F P
0 g
s
.18164 .81767 m .1804 .80025 L .16768 .78868 L p .707 .577 .707 r
F P
0 g
s
.1697 .62142 m .16037 .67771 L .15445 .67204 L p .707 .577 .707 r
F P
0 g
s
.15445 .67204 m .16379 .61575 L .1697 .62142 L p .707 .577 .707 r
F P
0 g
s
.58388 .7689 m .58512 .78632 L .55586 .79339 L p .707 .577 .707 r
F P
0 g
s
.16768 .78868 m .16892 .8061 L .18164 .81767 L p .707 .577 .707 r
F P
0 g
s
.65026 .28505 m .63133 .79723 L .62717 .78901 L p .707 .577 .707 r
F P
0 g
s
.62717 .78901 m .6461 .27683 L .65026 .28505 L p .707 .577 .707 r
F P
0 g
s
.15762 .74014 m .15718 .7034 L .16426 .69411 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16892 .8061 m .16768 .78868 L .16462 .77549 L p .707 .577 .707 r
F P
0 g
s
.16426 .69411 m .16469 .73085 L .15762 .74014 L p .707 .577 .707 r
F P
0 g
s
.1849 .62809 m .17556 .68438 L .16037 .67771 L p .707 .577 .707 r
F P
0 g
s
.16037 .67771 m .1697 .62142 L .1849 .62809 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16462 .77549 m .16586 .79291 L .16892 .8061 L p .707 .577 .707 r
F P
0 g
s
.36817 .76882 m .3694 .78624 L .36635 .77305 L p .707 .577 .707 r
F P
0 g
s
.36635 .77305 m .36511 .75563 L .36817 .76882 L p .707 .577 .707 r
F P
0 g
s
.2079 .6351 m .19856 .69139 L .17556 .68438 L p .707 .577 .707 r
F P
0 g
s
.16469 .73085 m .16426 .69411 L .18062 .68581 L p .707 .577 .707 r
F P
0 g
s
.6461 .27683 m .62717 .78901 L .60934 .78092 L p .707 .577 .707 r
F P
0 g
s
.60934 .78092 m .62827 .26874 L .6461 .27683 L p .707 .577 .707 r
F P
0 g
s
.16586 .79291 m .16462 .77549 L .17153 .76197 L p .707 .577 .707 r
F P
0 g
s
.18062 .68581 m .18106 .72255 L .16469 .73085 L p .707 .577 .707 r
F P
0 g
s
.31703 .71003 m .32637 .65373 L .34796 .65374 L p .707 .577 .707 r
F P
0 g
s
.17556 .68438 m .1849 .62809 L .2079 .6351 L p .707 .577 .707 r
F P
0 g
s
.32495 .71711 m .32451 .68037 L .34557 .68725 L p .707 .577 .707 r
F P
0 g
s
.17153 .76197 m .17277 .77939 L .16586 .79291 L p .707 .577 .707 r
F P
0 g
s
.35356 .77603 m .37249 .26385 L .39552 .25771 L p .707 .577 .707 r
F P
0 g
s
.19856 .69139 m .2079 .6351 L .23644 .64177 L p .707 .577 .707 r
F P
0 g
s
.18106 .72255 m .18062 .68581 L .20467 .67932 L p .707 .577 .707 r
F P
0 g
s
.32637 .65373 m .31703 .71003 L .28939 .70786 L p .707 .577 .707 r
F P
0 g
s
.23644 .64177 m .2271 .69806 L .19856 .69139 L p .707 .577 .707 r
F P
0 g
s
.28939 .70786 m .29872 .65157 L .32637 .65373 L p .707 .577 .707 r
F P
0 g
s
.20467 .67932 m .2051 .71607 L .18106 .72255 L p .707 .577 .707 r
F P
0 g
s
.17277 .77939 m .17153 .76197 L .18772 .74945 L p .707 .577 .707 r
F P
0 g
s
.32451 .68037 m .32495 .71711 L .29749 .71258 L p .707 .577 .707 r
F P
0 g
s
.29749 .71258 m .29705 .67583 L .32451 .68037 L p .707 .577 .707 r
F P
0 g
s
.29872 .65157 m .28939 .70786 L .2584 .70373 L p .707 .577 .707 r
F P
0 g
s
.71062 .55198 m .70129 .60827 L .73228 .61239 L p .707 .577 .707 r
F P
0 g
s
.73228 .61239 m .74161 .5561 L .71062 .55198 L p .707 .577 .707 r
F P
0 g
s
.74161 .5561 m .73228 .61239 L .76357 .61807 L p .707 .577 .707 r
F P
0 g
s
.18772 .74945 m .18896 .76687 L .17277 .77939 L p .707 .577 .707 r
F P
0 g
s
.2271 .69806 m .23644 .64177 L .26774 .64744 L p .707 .577 .707 r
F P
0 g
s
.2051 .71607 m .20467 .67932 L .23405 .67528 L p .707 .577 .707 r
F P
0 g
s
.26774 .64744 m .2584 .70373 L .2271 .69806 L p .707 .577 .707 r
F P
0 g
s
.62827 .26874 m .60934 .78092 L .57958 .77377 L p .707 .577 .707 r
F P
0 g
s
.57958 .77377 m .59851 .26159 L .62827 .26874 L p .707 .577 .707 r
F P
0 g
s
.76357 .61807 m .77291 .56177 L .74161 .5561 L p .707 .577 .707 r
F P
0 g
s
.77291 .56177 m .76357 .61807 L .79212 .62474 L p .707 .577 .707 r
F P
0 g
s
.2584 .70373 m .26571 .65968 L p .29872 .65157 L .707 .577 .707 r
F P
0 g
s
.23448 .71202 m .23408 .67811 L p .26588 .67408 L .707 .577 .707 r
F P
0 g
s
.23408 .67811 m .23405 .67528 L .23928 .67508 L p .707 .577 .707 r
F P
0 g
s
.23928 .67508 m .26588 .67408 L p .23408 .67811 L .707 .577 .707 r
F P
0 g
s
.26571 .65968 m .26774 .64744 L .28317 .6495 L p .707 .577 .707 r
F P
0 g
s
.28317 .6495 m .29872 .65157 L p .26571 .65968 L .707 .577 .707 r
F P
0 g
s
.68298 .54981 m .67365 .6061 L .70129 .60827 L p .707 .577 .707 r
F P
0 g
s
.70129 .60827 m .71062 .55198 L .68298 .54981 L p .707 .577 .707 r
F P
0 g
s
.29705 .67583 m .29749 .71258 L .26632 .71082 L p .707 .577 .707 r
F P
0 g
s
.26632 .71082 m .26588 .67408 L .29705 .67583 L p .707 .577 .707 r
F P
0 g
s
.79212 .62474 m .80145 .56844 L .77291 .56177 L p .707 .577 .707 r
F P
0 g
s
.23405 .67528 m .23448 .71202 L .2051 .71607 L p .707 .577 .707 r
F P
0 g
s
.39552 .25771 m .37659 .76989 L .35356 .77603 L p .707 .577 .707 r
F P
0 g
s
.37659 .76989 m .39552 .25771 L .4294 .25357 L p .707 .577 .707 r
F P
0 g
s
.26588 .67408 m .26632 .71082 L .23448 .71202 L p .707 .577 .707 r
F P
0 g
s
.80145 .56844 m .79212 .62474 L .81511 .63175 L p .707 .577 .707 r
F P
0 g
s
.18896 .76687 m .18772 .74945 L .21161 .73915 L p .707 .577 .707 r
F P
0 g
s
.73302 .72576 m .73258 .68902 L .70141 .68726 L p .707 .577 .707 r
F P
0 g
s
.73258 .68902 m .73302 .72576 L .76485 .72456 L p .707 .577 .707 r
F P
0 g
s
.76485 .72456 m .76441 .68781 L .73258 .68902 L p .707 .577 .707 r
F P
0 g
s
.66139 .5498 m .65205 .6061 L .67365 .6061 L p .707 .577 .707 r
F P
0 g
s
.67365 .6061 m .68298 .54981 L .66139 .5498 L p .707 .577 .707 r
F P
0 g
s
.81511 .63175 m .82445 .57545 L .80145 .56844 L p .707 .577 .707 r
F P
0 g
s
.76441 .68781 m .76485 .72456 L .79423 .72051 L p .707 .577 .707 r
F P
0 g
s
.79423 .72051 m .79379 .68377 L .76441 .68781 L p .707 .577 .707 r
F P
0 g
s
.21161 .73915 m .21285 .75657 L .18896 .76687 L p .707 .577 .707 r
F P
0 g
s
.33125 .73523 m .33249 .75265 L .305 .74744 L p .707 .577 .707 r
F P
0 g
s
.305 .74744 m .30377 .73002 L .33125 .73523 L p .707 .577 .707 r
F P
0 g
s
.70184 .72401 m .70141 .68726 L .67395 .68272 L p .707 .577 .707 r
F P
0 g
s
.70141 .68726 m .70184 .72401 L .73302 .72576 L p .707 .577 .707 r
F P
0 g
s
.59851 .26159 m .57958 .77377 L .5408 .76824 L p .707 .577 .707 r
F P
0 g
s
.5408 .76824 m .55973 .25606 L .59851 .26159 L p .707 .577 .707 r
F P
0 g
s
.21285 .75657 m .21161 .73915 L .24087 .73209 L p .707 .577 .707 r
F P
0 g
s
.79379 .68377 m .79423 .72051 L .81828 .71403 L p .707 .577 .707 r
F P
0 g
s
.81828 .71403 m .81784 .67728 L .79379 .68377 L p .707 .577 .707 r
F P
0 g
s
.82445 .57545 m .81511 .63175 L .83031 .63842 L p .707 .577 .707 r
F P
0 g
s
.67395 .68272 m .67439 .71947 L .70184 .72401 L p .707 .577 .707 r
F P
0 g
s
.30377 .73002 m .305 .74744 L .27386 .74636 L p .707 .577 .707 r
F P
0 g
s
.27386 .74636 m .27262 .72894 L .30377 .73002 L p .707 .577 .707 r
F P
0 g
s
.24087 .73209 m .24211 .7495 L .21285 .75657 L p .707 .577 .707 r
F P
0 g
s
.67439 .71947 m .67395 .68272 L .65289 .67584 L p .707 .577 .707 r
F P
0 g
s
.41047 .76575 m .4294 .25357 L .47083 .25184 L p .707 .577 .707 r
F P
0 g
s
.4294 .25357 m .41047 .76575 L .37659 .76989 L p .707 .577 .707 r
F P
0 g
s
.83031 .63842 m .83965 .58212 L .82445 .57545 L p .707 .577 .707 r
F P
0 g
s
.64796 .55197 m .63862 .60826 L .65205 .6061 L p .707 .577 .707 r
F P
0 g
s
.65205 .6061 m .66139 .5498 L .64796 .55197 L p .707 .577 .707 r
F P
0 g
s
.24211 .7495 m .24087 .73209 L .27262 .72894 L p .707 .577 .707 r
F P
0 g
s
.27262 .72894 m .27386 .74636 L .24211 .7495 L p .707 .577 .707 r
F P
0 g
s
.65289 .67584 m .65333 .71259 L .67439 .71947 L p .707 .577 .707 r
F P
0 g
s
.81784 .67728 m .81828 .71403 L .83464 .70573 L p .707 .577 .707 r
F P
0 g
s
.83464 .70573 m .8342 .66899 L .81784 .67728 L p .707 .577 .707 r
F P
0 g
s
.55973 .25606 m .5408 .76824 L .4968 .76488 L p .707 .577 .707 r
F P
0 g
s
.4968 .76488 m .51573 .2527 L .55973 .25606 L p .707 .577 .707 r
F P
0 g
s
.74162 .7628 m .74038 .74538 L .70924 .7443 L p .707 .577 .707 r
F P
0 g
s
.74038 .74538 m .74162 .7628 L .77337 .75965 L p .707 .577 .707 r
F P
0 g
s
.77337 .75965 m .77213 .74224 L .74038 .74538 L p .707 .577 .707 r
F P
0 g
s
.77213 .74224 m .77337 .75965 L .80263 .75259 L p .707 .577 .707 r
F P
0 g
s
.80263 .75259 m .80139 .73517 L .77213 .74224 L p .707 .577 .707 r
F P
0 g
s
.4519 .76402 m .47083 .25184 L .51573 .2527 L p .707 .577 .707 r
F P
0 g
s
.47083 .25184 m .4519 .76402 L .41047 .76575 L p .707 .577 .707 r
F P
0 g
s
.83965 .58212 m .83031 .63842 L .83622 .64409 L p .707 .577 .707 r
F P
0 g
s
.71047 .76172 m .70924 .7443 L .68175 .73909 L p .707 .577 .707 r
F P
0 g
s
.70924 .7443 m .71047 .76172 L .74162 .7628 L p .707 .577 .707 r
F P
0 g
s
.51573 .2527 m .4968 .76488 L .4519 .76402 L p .707 .577 .707 r
F P
0 g
s
.65333 .71259 m .65289 .67584 L .64029 .66729 L p .707 .577 .707 r
F P
0 g
s
.80139 .73517 m .80263 .75259 L .82652 .74229 L p .707 .577 .707 r
F P
0 g
s
.82652 .74229 m .82528 .72487 L .80139 .73517 L p .707 .577 .707 r
F P
0 g
s
.83622 .64409 m .84556 .58779 L .83965 .58212 L p .707 .577 .707 r
F P
0 g
s
.68175 .73909 m .68299 .75651 L .71047 .76172 L p .707 .577 .707 r
F P
0 g
s
.644 .55609 m .63467 .61238 L .63862 .60826 L p .707 .577 .707 r
F P
0 g
s
.63862 .60826 m .64796 .55197 L .644 .55609 L p .707 .577 .707 r
F P
0 g
s
.64029 .66729 m .64073 .70404 L .65333 .71259 L p .707 .577 .707 r
F P
0 g
s
.68299 .75651 m .68175 .73909 L .66061 .73027 L p .707 .577 .707 r
F P
0 g
s
.8342 .66899 m .83464 .70573 L .84172 .69644 L p .707 .577 .707 r
F P
0 g
s
.84172 .69644 m .84128 .6597 L .8342 .66899 L p .707 .577 .707 r
F P
0 g
s
.66061 .73027 m .66185 .74768 L .68299 .75651 L p .707 .577 .707 r
F P
0 g
s
.82528 .72487 m .82652 .74229 L .84271 .72977 L p .707 .577 .707 r
F P
0 g
s
.84271 .72977 m .84147 .71235 L .82528 .72487 L p .707 .577 .707 r
F P
0 g
s
.84556 .58779 m .83622 .64409 L .83227 .64821 L p .707 .577 .707 r
F P
0 g
s
.64073 .70404 m .64029 .66729 L .63739 .65792 L p .707 .577 .707 r
F P
0 g
s
.66185 .74768 m .66061 .73027 L .64789 .71869 L p .707 .577 .707 r
F P
0 g
s
.83227 .64821 m .84161 .59191 L .84556 .58779 L p .707 .577 .707 r
F P
0 g
s
.64991 .56176 m .64058 .61805 L .63467 .61238 L p .707 .577 .707 r
F P
0 g
s
.63467 .61238 m .644 .55609 L .64991 .56176 L p .707 .577 .707 r
F P
0 g
s
.63739 .65792 m .63783 .69466 L .64073 .70404 L p .707 .577 .707 r
F P
0 g
s
.64789 .71869 m .64913 .73611 L .66185 .74768 L p .707 .577 .707 r
F P
0 g
s
.84128 .6597 m .84172 .69644 L .83882 .68706 L p .707 .577 .707 r
F P
0 g
s
.83882 .68706 m .83838 .65032 L .84128 .6597 L p .707 .577 .707 r
F P
0 g
s
.84147 .71235 m .84271 .72977 L .84962 .71625 L p .707 .577 .707 r
F P
0 g
s
.84962 .71625 m .84838 .69883 L .84147 .71235 L p .707 .577 .707 r
F P
0 g
s
.63783 .69466 m .63739 .65792 L .64447 .64862 L p .707 .577 .707 r
F P
0 g
s
.84161 .59191 m .83227 .64821 L .81884 .65037 L p .707 .577 .707 r
F P
0 g
s
.64913 .73611 m .64789 .71869 L .64484 .7055 L p .707 .577 .707 r
F P
0 g
s
.36761 .51516 m .35828 .57145 L .38927 .57558 L p .707 .577 .707 r
F P
0 g
s
.38927 .57558 m .3986 .51928 L .36761 .51516 L p .707 .577 .707 r
F P
0 g
s
.3986 .51928 m .38927 .57558 L .42056 .58125 L p .707 .577 .707 r
F P
0 g
s
.81884 .65037 m .82817 .59408 L .84161 .59191 L p .707 .577 .707 r
F P
0 g
s
.42056 .58125 m .4299 .52496 L .3986 .51928 L p .707 .577 .707 r
F P
0 g
s
.4299 .52496 m .42056 .58125 L .44911 .58792 L p .707 .577 .707 r
F P
0 g
s
.66511 .56843 m .65578 .62472 L .64058 .61805 L p .707 .577 .707 r
F P
0 g
s
.64058 .61805 m .64991 .56176 L .66511 .56843 L p .707 .577 .707 r
F P
0 g
s
.64447 .64862 m .64491 .68537 L .63783 .69466 L p .707 .577 .707 r
F P
0 g
s
.64484 .7055 m .64607 .72292 L .64913 .73611 L p .707 .577 .707 r
F P
0 g
s
.33997 .51299 m .33064 .56929 L .35828 .57145 L p .707 .577 .707 r
F P
0 g
s
.35828 .57145 m .36761 .51516 L .33997 .51299 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.84838 .69883 m .84962 .71625 L .84656 .70306 L p .707 .577 .707 r
F P
0 g
s
.84656 .70306 m .84532 .68564 L .84838 .69883 L p .707 .577 .707 r
F P
0 g
s
.83838 .65032 m .83882 .68706 L .82622 .67851 L p .707 .577 .707 r
F P
0 g
s
.82622 .67851 m .82578 .64177 L .83838 .65032 L p .707 .577 .707 r
F P
0 g
s
.44911 .58792 m .45844 .53163 L .4299 .52496 L p .707 .577 .707 r
F P
0 g
s
.45844 .53163 m .44911 .58792 L .4721 .59493 L p .707 .577 .707 r
F P
0 g
s
.39001 .68894 m .38957 .6522 L .3584 .65045 L p .707 .577 .707 r
F P
0 g
s
.38957 .6522 m .39001 .68894 L .42184 .68774 L p .707 .577 .707 r
F P
0 g
s
.42184 .68774 m .4214 .651 L .38957 .6522 L p .707 .577 .707 r
F P
0 g
s
.31838 .51299 m .30904 .56928 L .33064 .56929 L p .707 .577 .707 r
F P
0 g
s
.33064 .56929 m .33997 .51299 L .31838 .51299 L p .707 .577 .707 r
F P
0 g
s
.82817 .59408 m .81884 .65037 L .79725 .65037 L p .707 .577 .707 r
F P
0 g
s
.64491 .68537 m .64447 .64862 L .66083 .64033 L p .707 .577 .707 r
F P
0 g
s
.4721 .59493 m .48144 .53864 L .45844 .53163 L p .707 .577 .707 r
F P
0 g
s
.4214 .651 m .42184 .68774 L .45122 .6837 L p .707 .577 .707 r
F P
0 g
s
.45122 .6837 m .45078 .64695 L .4214 .651 L p .707 .577 .707 r
F P
0 g
s
.64607 .72292 m .64484 .7055 L .65174 .69199 L p .707 .577 .707 r
F P
0 g
s
.35883 .68719 m .3584 .65045 L .33094 .64591 L p .707 .577 .707 r
F P
0 g
s
.3584 .65045 m .35883 .68719 L .39001 .68894 L p .707 .577 .707 r
F P
0 g
s
.79725 .65037 m .80658 .59407 L .82817 .59408 L p .707 .577 .707 r
F P
0 g
s
.68811 .57544 m .67877 .63173 L .65578 .62472 L p .707 .577 .707 r
F P
0 g
s
.65578 .62472 m .66511 .56843 L .68811 .57544 L p .707 .577 .707 r
F P
0 g
s
.65174 .69199 m .65298 .7094 L .64607 .72292 L p .707 .577 .707 r
F P
0 g
s
.66083 .64033 m .66127 .67707 L .64491 .68537 L p .707 .577 .707 r
F P
0 g
s
.45078 .64695 m .45122 .6837 L .47527 .67721 L p .707 .577 .707 r
F P
0 g
s
.47527 .67721 m .47483 .64047 L .45078 .64695 L p .707 .577 .707 r
F P
0 g
s
.48144 .53864 m .4721 .59493 L .4873 .6016 L p .707 .577 .707 r
F P
0 g
s
.84532 .68564 m .84656 .70306 L .83384 .69149 L p .707 .577 .707 r
F P
0 g
s
.83384 .69149 m .8326 .67407 L .84532 .68564 L p .707 .577 .707 r
F P
0 g
s
.82578 .64177 m .82622 .67851 L .80516 .67163 L p .707 .577 .707 r
F P
0 g
s
.80516 .67163 m .80472 .63489 L .82578 .64177 L p .707 .577 .707 r
F P
0 g
s
.33094 .64591 m .33138 .68265 L .35883 .68719 L p .707 .577 .707 r
F P
0 g
s
.33138 .68265 m .33094 .64591 L .30988 .63903 L p .707 .577 .707 r
F P
0 g
s
.4873 .6016 m .49664 .54531 L .48144 .53864 L p .707 .577 .707 r
F P
0 g
s
.30494 .51515 m .29561 .57145 L .30904 .56928 L p .707 .577 .707 r
F P
0 g
s
.30904 .56928 m .31838 .51299 L .30494 .51515 L p .707 .577 .707 r
F P
0 g
s
.80658 .59407 m .79725 .65037 L .7696 .6482 L p .707 .577 .707 r
F P
0 g
s
.66127 .67707 m .66083 .64033 L .68488 .63384 L p .707 .577 .707 r
F P
0 g
s
.71665 .58211 m .70732 .6384 L .67877 .63173 L p .707 .577 .707 r
F P
0 g
s
.67877 .63173 m .68811 .57544 L .71665 .58211 L p .707 .577 .707 r
F P
0 g
s
.65298 .7094 m .65174 .69199 L .66793 .67947 L p .707 .577 .707 r
F P
0 g
s
.7696 .6482 m .77894 .5919 L .80658 .59407 L p .707 .577 .707 r
F P
0 g
s
.30988 .63903 m .31032 .67577 L .33138 .68265 L p .707 .577 .707 r
F P
0 g
s
.47483 .64047 m .47527 .67721 L .49163 .66892 L p .707 .577 .707 r
F P
0 g
s
.49163 .66892 m .49119 .63217 L .47483 .64047 L p .707 .577 .707 r
F P
0 g
s
.39861 .72598 m .39737 .70857 L .36623 .70748 L p .707 .577 .707 r
F P
0 g
s
.39737 .70857 m .39861 .72598 L .43036 .72284 L p .707 .577 .707 r
F P
0 g
s
.43036 .72284 m .42912 .70542 L .39737 .70857 L p .707 .577 .707 r
F P
0 g
s
.42912 .70542 m .43036 .72284 L .45962 .71577 L p .707 .577 .707 r
F P
0 g
s
.45962 .71577 m .45838 .69835 L .42912 .70542 L p .707 .577 .707 r
F P
0 g
s
.68488 .63384 m .68532 .67059 L .66127 .67707 L p .707 .577 .707 r
F P
0 g
s
.80472 .63489 m .80516 .67163 L .7777 .66709 L p .707 .577 .707 r
F P
0 g
s
.7777 .66709 m .77726 .63035 L .80472 .63489 L p .707 .577 .707 r
F P
0 g
s
.66793 .67947 m .66917 .69688 L .65298 .7094 L p .707 .577 .707 r
F P
0 g
s
.77894 .5919 m .7696 .6482 L .73862 .64407 L p .707 .577 .707 r
F P
0 g
s
.49664 .54531 m .4873 .6016 L .49321 .60727 L p .707 .577 .707 r
F P
0 g
s
.36746 .7249 m .36623 .70748 L .33874 .70228 L p .707 .577 .707 r
F P
0 g
s
.36623 .70748 m .36746 .7249 L .39861 .72598 L p .707 .577 .707 r
F P
0 g
s
.8326 .67407 m .83384 .69149 L .8127 .68266 L p .707 .577 .707 r
F P
0 g
s
.8127 .68266 m .81147 .66525 L .8326 .67407 L p .707 .577 .707 r
F P
0 g
s
.74795 .58778 m .73862 .64407 L .70732 .6384 L p .707 .577 .707 r
F P
0 g
s
.70732 .6384 m .71665 .58211 L .74795 .58778 L p .707 .577 .707 r
F P
0 g
s
.31032 .67577 m .30988 .63903 L .29728 .63048 L p .707 .577 .707 r
F P
0 g
s
.73862 .64407 m .74795 .58778 L .77894 .5919 L p .707 .577 .707 r
F P
0 g
s
.68532 .67059 m .68488 .63384 L .71426 .6298 L p .707 .577 .707 r
F P
0 g
s
.45838 .69835 m .45962 .71577 L .48351 .70547 L p .707 .577 .707 r
F P
0 g
s
.48351 .70547 m .48227 .68806 L .45838 .69835 L p .707 .577 .707 r
F P
0 g
s
.49321 .60727 m .50255 .55098 L .49664 .54531 L p .707 .577 .707 r
F P
0 g
s
.33874 .70228 m .33998 .71969 L .36746 .7249 L p .707 .577 .707 r
F P
0 g
s
.30099 .51927 m .29166 .57557 L .29561 .57145 L p .707 .577 .707 r
F P
0 g
s
.29561 .57145 m .30494 .51515 L .30099 .51927 L p .707 .577 .707 r
F P
0 g
s
.77726 .63035 m .7777 .66709 L .74653 .66534 L p .707 .577 .707 r
F P
0 g
s
.74653 .66534 m .74609 .6286 L .77726 .63035 L p .707 .577 .707 r
F P
0 g
s
.29728 .63048 m .29772 .66722 L .31032 .67577 L p .707 .577 .707 r
F P
0 g
s
.71426 .6298 m .7147 .66654 L .68532 .67059 L p .707 .577 .707 r
F P
0 g
s
.66917 .69688 m .66793 .67947 L .69183 .66917 L p .707 .577 .707 r
F P
0 g
s
.33998 .71969 m .33874 .70228 L .3176 .69345 L p .707 .577 .707 r
F P
0 g
s
.7147 .66654 m .71426 .6298 L .74609 .6286 L p .707 .577 .707 r
F P
0 g
s
.49119 .63217 m .49163 .66892 L .49871 .65962 L p .707 .577 .707 r
F P
0 g
s
.49871 .65962 m .49827 .62288 L .49119 .63217 L p .707 .577 .707 r
F P
0 g
s
.74609 .6286 m .74653 .66534 L .7147 .66654 L p .707 .577 .707 r
F P
0 g
s
.69183 .66917 m .69306 .68658 L .66917 .69688 L p .707 .577 .707 r
F P
0 g
s
.81147 .66525 m .8127 .68266 L .78522 .67746 L p .707 .577 .707 r
F P
0 g
s
.78522 .67746 m .78398 .66004 L .81147 .66525 L p .707 .577 .707 r
F P
0 g
s
.3176 .69345 m .31884 .71087 L .33998 .71969 L p .707 .577 .707 r
F P
0 g
s
.48227 .68806 m .48351 .70547 L .4997 .69295 L p .707 .577 .707 r
F P
0 g
s
.4997 .69295 m .49846 .67554 L .48227 .68806 L p .707 .577 .707 r
F P
0 g
s
.50255 .55098 m .49321 .60727 L .48926 .61139 L p .707 .577 .707 r
F P
0 g
s
.29772 .66722 m .29728 .63048 L .29438 .6211 L p .707 .577 .707 r
F P
0 g
s
.69306 .68658 m .69183 .66917 L .72108 .6621 L p .707 .577 .707 r
F P
0 g
s
.31884 .71087 m .3176 .69345 L .30488 .68188 L p .707 .577 .707 r
F P
0 g
s
.78398 .66004 m .78522 .67746 L .75407 .67637 L p .707 .577 .707 r
F P
0 g
s
.75407 .67637 m .75284 .65895 L .78398 .66004 L p .707 .577 .707 r
F P
0 g
s
.48926 .61139 m .4986 .5551 L .50255 .55098 L p .707 .577 .707 r
F P
0 g
s
.72108 .6621 m .72232 .67952 L .69306 .68658 L p .707 .577 .707 r
F P
0 g
s
.3069 .52494 m .29757 .58124 L .29166 .57557 L p .707 .577 .707 r
F P
0 g
s
.29166 .57557 m .30099 .51927 L .3069 .52494 L p .707 .577 .707 r
F P
0 g
s
.29438 .6211 m .29482 .65784 L .29772 .66722 L p .707 .577 .707 r
F P
0 g
s
.72232 .67952 m .72108 .6621 L .75284 .65895 L p .707 .577 .707 r
F P
0 g
s
.75284 .65895 m .75407 .67637 L .72232 .67952 L p .707 .577 .707 r
F P
0 g
s
.30488 .68188 m .30612 .6993 L .31884 .71087 L p .707 .577 .707 r
F P
0 g
s
.49827 .62288 m .49871 .65962 L .49581 .65025 L p .707 .577 .707 r
F P
0 g
s
.49581 .65025 m .49537 .6135 L .49827 .62288 L p .707 .577 .707 r
F P
0 g
s
.49846 .67554 m .4997 .69295 L .50661 .67943 L p .707 .577 .707 r
F P
0 g
s
.50661 .67943 m .50537 .66202 L .49846 .67554 L p .707 .577 .707 r
F P
0 g
s
.29482 .65784 m .29438 .6211 L .30146 .61181 L p .707 .577 .707 r
F P
0 g
s
.4986 .5551 m .48926 .61139 L .47583 .61355 L p .707 .577 .707 r
F P
0 g
s
.30612 .6993 m .30488 .68188 L .30183 .66869 L p .707 .577 .707 r
F P
0 g
s
.47583 .61355 m .48516 .55726 L .4986 .5551 L p .707 .577 .707 r
F P
0 g
s
.3221 .53161 m .31277 .5879 L .29757 .58124 L p .707 .577 .707 r
F P
0 g
s
.29757 .58124 m .3069 .52494 L .3221 .53161 L p .707 .577 .707 r
F P
0 g
s
.30146 .61181 m .3019 .64855 L .29482 .65784 L p .707 .577 .707 r
F P
0 g
s
.30183 .66869 m .30306 .68611 L .30612 .6993 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.50537 .66202 m .50661 .67943 L .50355 .66624 L p .707 .577 .707 r
F P
0 g
s
.50355 .66624 m .50231 .64883 L .50537 .66202 L p .707 .577 .707 r
F P
0 g
s
.49537 .6135 m .49581 .65025 L .48321 .6417 L p .707 .577 .707 r
F P
0 g
s
.48321 .6417 m .48277 .60495 L .49537 .6135 L p .707 .577 .707 r
F P
0 g
s
.48516 .55726 m .47583 .61355 L .45424 .61355 L p .707 .577 .707 r
F P
0 g
s
.3019 .64855 m .30146 .61181 L .31782 .60351 L p .707 .577 .707 r
F P
0 g
s
.30306 .68611 m .30183 .66869 L .30873 .65517 L p .707 .577 .707 r
F P
0 g
s
.45424 .61355 m .46357 .55726 L .48516 .55726 L p .707 .577 .707 r
F P
0 g
s
.3451 .53862 m .33576 .59491 L .31277 .5879 L p .707 .577 .707 r
F P
0 g
s
.31277 .5879 m .3221 .53161 L .3451 .53862 L p .707 .577 .707 r
F P
0 g
s
.30873 .65517 m .30997 .67259 L .30306 .68611 L p .707 .577 .707 r
F P
0 g
s
.31782 .60351 m .31826 .64026 L .3019 .64855 L p .707 .577 .707 r
F P
0 g
s
.50231 .64883 m .50355 .66624 L .49083 .65467 L p .707 .577 .707 r
F P
0 g
s
.49083 .65467 m .48959 .63725 L .50231 .64883 L p .707 .577 .707 r
F P
0 g
s
.48277 .60495 m .48321 .6417 L .46215 .63482 L p .707 .577 .707 r
F P
0 g
s
.46215 .63482 m .46171 .59807 L .48277 .60495 L p .707 .577 .707 r
F P
0 g
s
.46357 .55726 m .45424 .61355 L .42659 .61138 L p .707 .577 .707 r
F P
0 g
s
.31826 .64026 m .31782 .60351 L .34187 .59703 L p .707 .577 .707 r
F P
0 g
s
.37364 .54529 m .36431 .60158 L .33576 .59491 L p .707 .577 .707 r
F P
0 g
s
.33576 .59491 m .3451 .53862 L .37364 .54529 L p .707 .577 .707 r
F P
0 g
s
.30997 .67259 m .30873 .65517 L .32492 .64265 L p .707 .577 .707 r
F P
0 g
s
.42659 .61138 m .43593 .55509 L .46357 .55726 L p .707 .577 .707 r
F P
0 g
s
.34187 .59703 m .34231 .63377 L .31826 .64026 L p .707 .577 .707 r
F P
0 g
s
.46171 .59807 m .46215 .63482 L .43469 .63028 L p .707 .577 .707 r
F P
0 g
s
.43469 .63028 m .43425 .59353 L .46171 .59807 L p .707 .577 .707 r
F P
0 g
s
.32492 .64265 m .32616 .66007 L .30997 .67259 L p .707 .577 .707 r
F P
0 g
s
.43593 .55509 m .42659 .61138 L .39561 .60726 L p .707 .577 .707 r
F P
0 g
s
.48959 .63725 m .49083 .65467 L .46969 .64585 L p .707 .577 .707 r
F P
0 g
s
.46969 .64585 m .46846 .62843 L .48959 .63725 L p .707 .577 .707 r
F P
0 g
s
.40494 .55096 m .39561 .60726 L .36431 .60158 L p .707 .577 .707 r
F P
0 g
s
.36431 .60158 m .37364 .54529 L .40494 .55096 L p .707 .577 .707 r
F P
0 g
s
.39561 .60726 m .40494 .55096 L .43593 .55509 L p .707 .577 .707 r
F P
0 g
s
.34231 .63377 m .34187 .59703 L .37125 .59298 L p .707 .577 .707 r
F P
0 g
s
.43425 .59353 m .43469 .63028 L .40352 .62852 L p .707 .577 .707 r
F P
0 g
s
.40352 .62852 m .40308 .59178 L .43425 .59353 L p .707 .577 .707 r
F P
0 g
s
.37125 .59298 m .37169 .62973 L .34231 .63377 L p .707 .577 .707 r
F P
0 g
s
.32616 .66007 m .32492 .64265 L .34882 .63235 L p .707 .577 .707 r
F P
0 g
s
.37169 .62973 m .37125 .59298 L .40308 .59178 L p .707 .577 .707 r
F P
0 g
s
.40308 .59178 m .40352 .62852 L .37169 .62973 L p .707 .577 .707 r
F P
0 g
s
.34882 .63235 m .35005 .64977 L .32616 .66007 L p .707 .577 .707 r
F P
0 g
s
.46846 .62843 m .46969 .64585 L .44221 .64064 L p .707 .577 .707 r
F P
0 g
s
.44221 .64064 m .44097 .62322 L .46846 .62843 L p .707 .577 .707 r
F P
0 g
s
.35005 .64977 m .34882 .63235 L .37807 .62528 L p .707 .577 .707 r
F P
0 g
s
.44097 .62322 m .44221 .64064 L .41106 .63956 L p .707 .577 .707 r
F P
0 g
s
.41106 .63956 m .40983 .62214 L .44097 .62322 L p .707 .577 .707 r
F P
0 g
s
.37807 .62528 m .37931 .6427 L .35005 .64977 L p .707 .577 .707 r
F P
0 g
s
.37931 .6427 m .37807 .62528 L .40983 .62214 L p .707 .577 .707 r
F P
0 g
s
.40983 .62214 m .41106 .63956 L .37931 .6427 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol0081ooaT008Aoo`00MWoo2P001EYF00<005YFFUH02UYF00<005YFFUH015YF
2@00Ngoo001_Ool70004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06001eOol006]oo`@00003FUH005YF00QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00IJEP@0075oo`00JGoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00KGoo001XOol20006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP03FUH4001YOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEP00001WOol0
06Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH2001UOol006Moo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06=oo`00Igoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH2001TOol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Aoo`00
Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001WOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001TOol006Moo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Aoo`00Igoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
0P00I7oo001WOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Moo`03
001JEP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001T
Ool006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000I7oo001VOol00`00FUH00006FUH0
0`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001TOol006Ioo`03001JEP0000IJEP03001JEUYF
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo
001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0I7oo001VOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Ioo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Eoo`00IWoo00<005YF0000
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001VOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH2001UOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Eoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol0
1000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00
FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUIoo`1UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YFOol0IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001T
Ool200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
06Aoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Uoo``0009JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EWoo0`0000=JEP00FUH015YF
00@005YFFUIJEPX000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00EGoo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH00UYF1`000eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol20002FUH00`00
FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Eoo`05
001JEP00FUH00005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40006FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001V
Ool005Aoo`03001JEUYF00<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEP0000<0009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Ioo`00E7oo00@005YFFUH0009JEP<0009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP@000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Ioo`00E7oo00<005YF000015YF00<005YF
00000`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0025YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IWoo
001DOol00`00FUH00004FUH00`00FUIJEP03FUH30003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00FUH0001VOol005Aoo`03001JEP0000=JEP03001JEUYF00EJEP03
001JEP0000<000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol005=o
o`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP03FUH80009FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00Igoo001COol01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH00UYF20000UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF0P0035YF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo5000DGoo001COol00`00FUH00004
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000UYF00<005YF
FUH00eYF00<005YFFUH00UYF100035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P0000=oo`0000000UYF00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01000CGoo001COol0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
1000FUIJEUYF3@0000AJEP00000000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009J
EP800003Ool00000009JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00AJEPL004Ioo`00
Dgoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000]JEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF009JEP800006Ool00000001JEP001EYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P00@7oo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004Ool00000FUH2
0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUH00003000lOol0059o
o`04001JEUYF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF0`000UYF00<005YFFUH015YF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00eYF1000>7oo001BOol01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF
00<005YFFUH00eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<00003FUH005YF00=JEP03001JEP00008000IJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEP0000<003Aoo`00DWoo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP@000EJEP03001JEUYF009JEP<000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP80039oo`00Dgoo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP800003
FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJEP03001JEUYF
00AJEP03001JEP0000<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<0031o
o`00E7oo00D005YFFUIJEP0000MJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH50003FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02000^Ool005Eoo`800003
FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04
0008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00Oomoo`0[Ool005Moo`<0
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYFFUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70000
0eYF001JEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00Oomoo`0ZOol005Yoo`@00003FUH0
05YF00EJEQL000EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH00`00FUIJEP03FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUHH000/Ool005ioo`P000=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEP0000<00003FUH005YF00AJEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYFFUH2000/Ool005aoo`@00003FUH005YF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP@0009JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00
FUIJEUYF0000;Goo001IOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUH000020003FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEReoo`00Egoo
0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P0000=JEP0000000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
;goo5@004Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0`000eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH0100037oo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo000^Ool20003FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP04FUH70005Ool20004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01P00FUIJ
EP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00=JEP05001JEUYFFUH0000^Ool002ioo`<00003FUH005YF00EJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEUYF009JEPD00003FUH005YF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00AJEPT0009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00<000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005Ool00000FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Woo000^Ool00`00FUH000020005FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH70004FUH00`00FUIJEP02FUH80002FUH0
0`00FUIJEP03FUH00`00FUIJEP03000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20003Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo000]Ool01000FUIJEP000UYF0`000UYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF000015YF00<005YFFUH015YF00<005YF
FUH00UYF100000=JEP00FUH01eYF00<005YFFUH01UYF00@005YFFUIJEPD000=JEP03001JEUYF00<0
00aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`<00003FUH005YF00MJ
EP03001JEUYF00AJEPP000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool0
02eoo`03001JEP0000AJEP03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003
FUH005YF00=JEP03001JEUYF00AJEPD000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP<00004FUH005YFFUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0009Ool40004FUH90004FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00@005YFFUIJEP8002io
o`00;Goo00<005YF000015YF00<005YFFUH00eYF0`000eYF00<005YFFUH01UYF00<005YFFUH01UYF
0P0000=JEP00FUH00eYF00<005YFFUH00eYF0P0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00P000UYF0`0035YF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P002goo1P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJ
EPH000=JEP04001JEUYFFUH2000^Ool002eoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEP00
00<000QJEP03001JEUYF00IJEP800003FUH005YF00=JEP03001JEP0000<000=JEP03001JEUYF00EJ
EP03001JEUYF009JEPT000AJEP03001JEUYF00EJEP03001JEUYF009JEPD000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Moo`@00003FUH005YF00MJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEP0000<000=JEP03001oogoo02eoo`00;Goo
00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH00eYF1@000eYF00<005YFFUH01UYF0P0000=J
EP00FUH00UYF1@001EYF00<005YFFUH015YF1P001EYF00@005YFFUIJEPP000AJEP03001JEUYF00=J
EP@000]JEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000Eoo`8000EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009J
EP800003FUH0000002moo`00;7oo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03
001JEUYF00@000QJEP800003FUH005YF0080009JEP8000IJEP03001JEUYF00@0009JEP03001JEUYF
00IJEP03001JEUYF00IJEPP000EJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20004Ool30006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH4000_Ool002aoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00AJEPP00003FUH005YF00800006FUH00000001JEP001EYF20000UYF
00<005YFFUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00eYF0P000eYF00@005YFFUH000]J
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009oo`80009JEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0`000eYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF009J
EQ0000IJEP03001JEUYF00=JEP06001JEP00001JEP000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`0000000eYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002ioo`00;7oo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01EYF0P000UYF00<005YFFUH00UYF00@005YF000000EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo00000003FUH00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH200000eYF00000004FUH30006FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP08
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP02FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH?0004FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH200000eYF00000003FUH01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUIJEPD000YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00IJEPH000AJ
EP03001JEUYF00IJEP03001JEP0000@000EJEP04001JEUYFFUH2000]Ool002]oo`04001JEUYF0003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30002FUH00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH01000FUIJEUYF0P0000=JEP0000002UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH00UYF100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH00eYF10000UYF00@005YFFUIJEP8002eoo`00:goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YF
00000UYF0P0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00D005YFFUIJEP00009JEP8000YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP<00003FUH005YF009JEP03001JEUYF00=JEPH000EJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEP00008000=JEP8002eoo`00:goo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH030000eYF00<005YF00000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF
00@005YF0000009JEP04001JEP000009FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH300000eYF001JEP02FUH00`00FUH0000500000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH200000eYF0000000]Ool002aoo`8000=JEP03001J
EUYF00EJEP03001JEUYF00=JEPD000MJEP03001JEUYF009JEPH00004FUH000000004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30004FUH0
1000FUIJEP002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH0
0UYF0P000UYF0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF3`001EYF00<005YFFUH00eYF1000
;Goo000^Ool200000eYF001JEP06FUH60003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0
000600000eYF001JEP06FUH00`00FUIJEP05FUH40005FUH00`00FUIJEP06FUH00`00FUH000030006
FUH20002FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30000
0eYF001JEP060005FUH00`00FUIJEP04FUH7000?Ool400000eYF001JEP04FUH01000FUH00000;Goo
000`Ool30002FUH400000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUH00000
15YF1P0015YF00<005YFFUH01EYF1@0015YF00<005YFFUH00UYF1P0025YF0P0000AJEP00FUH000YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<00004FUH000000002FUH20006FUH0
0`00FUIJEP04000COol50002FUH30005FUH01000FUIJEP00;7oo000bOol30005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUH005YF00000eYF00<005YFFUH00UYF6`001EYF
00<005YFFUH015YF0P0015YF0P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
10000UYF0`0000=JEP00FUH01EYF6P000eYF00<005YFFUH015YF100000EJEP00FUIJEP0002aoo`00
<7oo0P0000=JEP00FUH00eYF00<005YF00001eYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YF
000005YF0002FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YF000010000UYF00<005YFFUH0
2EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF10000UYF00<005YFFUH00UYF00@005YFFUIJEP8000=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20002FUH00`00
Oomoo`0ZOol002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYF0002FUH30005FUH01000FUIJEP001UYF00<005YFFUH00`000eYF00<005YF
FUH02EYF00<005YFFUH00P000eYF00<005YFFUH00UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF100000=JEP00000015YF00@005YF000000EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF009JEP800003FUH00000
02]oo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00@005YFFUH0009JEP03001JEP00008000=JEP04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH40005FUH00`00FUIJEP03000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH400000eYF00000004FUH20007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00002000[Ool002eoo`8000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH015YF10000UYF00<005YFFUH015YF
0`000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@0000AJ
EP00FUIJEP800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP03001JEUYF009JEP800003Ool0000002]oo`00;7oo00<005YF000015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00L005YFFUIJEP00FUH00005
FUH00`00FUH000030006FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP03FUH20004FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000015YF000000000eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF00<007ooOol00P00:goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP03FUH?
0004FUH00`00FUIJEP06FUH01000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0`0000AJEP00FUH000EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF0080009oo`<002]oo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF6@000UYF0P0015YF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000QJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPP000AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP<000Aoo`03001JEP00
02]oo`00;7oo00<005YF000015YF00<005YFFUH00eYF1P006Goo1`0000=JEP00FUH01UYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`002EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP0000001@0000=JEP00FUH01UYF00<005YFFUH0
1UYF10001EYF00<005YFFUH01EYF00@005YFFUIJEP@000Eoo`800003FUH007oo02Yoo`00;7oo00<0
05YF000015YF00<005YF00000`009Goo10001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH0100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00
00=JEP00000015YF1P0015YF00<005YFFUH01UYF1@0015YF00<005YFFUH015YF1@001goo0P0000=J
EP000000;7oo000/Ool00`00FUH00003FUH3000COol3000COol80002FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH70003FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH3000015YF000000000eYF00<005YFFUH00UYF2P0015YF1@0015YF00<005YF
FUH010002goo00@005YFFUIJEP8002aoo`00;7oo00@005YF001JEP800004FUH00000000AOol5000?
Ool3000015YF001JEP000UYF00<005YF00003`002UYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0`0000EJEP00001JEP00009JEP03001JEUYF
00=JEP800003FUH0000000Aooa0000eoo`8000AJEP03001oogoo02]oo`00;7oo00H005YF000005YF
0004FUH5000<OolD0004FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH300000eYF00000002FUH00`00FUH00005FUH00`00FUH000020009Ool3000COol200000eYF
001JEP03FUH00`00Oomoo`0[Ool002aoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH>0004FUH0
0`00FUIJEP06FUH00`00FUH000030003FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000015YF001JEP000UYF0`001EYF00D005YFFUIJEP0001eoo`8000=JEP05
001JEUYFFUH0000^Ool002aoo`8000=JEP03001JEUYF00=JEP03001JEUYF00AJEPD00003FUH005YF
00MJEP03001JEUYF00IJEP03001JEUYF00=JEP@00005FUH005YFFUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH2000015YF001JEP000UYF00<005YFFUH00P000eYF00D005YFFUIJEP0001Yoo`<0
00EJEP04001JEP00000_Ool002aoo`8000=JEP03001JEUYF00=JEP04001JEUYFFUH40005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUH000000UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP00009JEP04001JEUYF0003FUH50002FUH2000E
Ool400000eYF001JEP05FUH2000aOol002aoo`8000=JEP03001JEUYF00=JEP06001JEP00001JEP00
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00FUH00003FUH30004FUH01000FUIJEUYF
6@001EYF00<005YFFUH015YF00<007ooOol0<7oo000]Ool01@00FUIJEUYF00001EYF0P000eYF00<0
05YFFUH01EYF00<005YFFUH00UYF3`001UYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP80009JEP03001JEUYF00=JEP03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002eoo`05001J
EUYFFUH00003FUH20005FUH00`00FUIJEP04FUH60007FUH00`00FUIJEP05FUH40002FUH01000FUIJ
EP000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF20000eYF0P000eYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003Eoo`00;Woo
0P0000=JEP00FUH00`001UYF00<005YFFUH0100015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH0100000EJEP00FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Ioo`L00003
FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Moo`00<7oo0`00
0UYF00<005YFFUH00eYF1@001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0`00
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P002goo1`000eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01000>goo000`Ool00`00FUIJEP02FUH01000FUIJEUYF0P00
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000`000Woo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Qoo`@00004FUH000000002FUHH000oOol0
02moo`8000AJEP03001JEP0000<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009J
EPH000Ioo`04001JEUYF0006FUH00`00FUIJEP02FUHS0006FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003Ool50005FUH00`00FUIJEP0200000eYF0000001DOol002moo`8000AJ
EP8000Aoo`P000AJEP03001JEUYF009JEPT000aoo`04001JEUYF0005FUH7000:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90006FUH00`00FUIJEP02
FUH3001DOol002ioo`04001JEUYF0002FUH00`00Oomoo`0<Ool9000EOol01@00FUIJEP00FUH01000
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF0P001UYF1P000UYF00<005YFFUH0
1UYF00<005YFFUH00UYF0P000eYF00@005YFFUIJEPD00003FUH005YF00=JEP<005Aoo`00;Woo00<0
05YFFUH00`004goo1@005Goo00<005YFFUH00P000UYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF0P001UYF10000UYF1@001UYF00<005YFFUH00UYF0P000eYF00<0
05YFFUH01EYF0`0015YF00<005YF0000E7oo000^Ool01000FUIJEP005Goo1@005Goo00<005YF0000
15YF0P001UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF0P0015YF0P0000=JEP00
FUH01eYF1@000UYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF00<005YFFUH00P000UYF00<0
05YF0000E7oo000^Ool00`00FUH0000FOol5000EOol20006FUH00`00FUIJEP04FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH01000FUIJEUYF0P000eYF00<005YFFUH01UYF00@005YF
FUIJEPD000=JEP8000AJEP03001JEUYF00EJEP04001JEUYFFUH4001EOol002moo`8001Moo`<001Io
o`8000IJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP04001J
EP000006FUH00`00FUIJEP04FUH60004FUH200000eYF000000080004FUH00`00FUIJEP02FUH3001E
Ool002moo`03001oogoo031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP<000MJEP03001JEUYF00@000]JEP@000IJEP03001JEP0000D000=J
EP04001JEP00001DOol002moo`80035oo`8000aJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEP0000IJEP@000mJEP04001JEP000006FUH00`00FUIJEP04FUH400001EYF001J
EUYF0000Dgoo000_Ool01000FUH00000;Woo0P0000AJEP00000000UJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP04001JEUYF0003FUH20003FUH00`00FUIJEP0=FUH01000FUIJEP00
1UYF00<005YFFUH00eYF0`000Woo0P000UYF00<007ooOol0DGoo000_Ool20002FUH00`00Oomoo`0W
Ool400000eYF001JEP03FUH30006FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
1@00FUIJEP00FUH00P001EYF00<005YFFUH03EYF0`001eYF00<005YF00000`001goo00<005YF0000
Dgoo000`Ool00`00FUIJEP03000SOol40005FUH00`00FUIJEP020003Ool40002FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP020007FUH00`00FUIJEP0<FUH200000eYF
001JEP03FUH5000;Ool01000FUH00000DWoo000`Ool01000FUIJEP000UYF0P007Goo10000UYF00<0
05YFFUH015YF0`002Goo1@0025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF00002EYF00<0
05YFFUH02UYF2P004Goo0`00DWoo000aOol00`00FUH00004FUH5000AOol70006FUH00`00FUIJEP03
FUH2000@Ool60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH2000:FUH00`00FUIJEP03FUH7000L
Ool2001BOol0039oo`8000EJEP04001JEUYFFUHA0004FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
67oo20001UYF00<005YFFUH02UYF00<005YFFUH015YF2`000goo1@006goo0P00DWoo000cOol00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000
FUH000008Woo6P003Woo1@006Woo0`00DWoo000dOol20003FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000cOol2000GOol5000IOol200000eYF001oo`1AOol0
03Ioo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00@003Ioo`80
01Qoo`<001Qoo`800004FUH005YF001BOol003Qoo`D000AJEP03001JEUYF00IJEP03001JEUYF009J
EPL003Yoo`<0035oo`04001JEUYFFUH2001COol003eooa80045oo`<002moo`8000AJEP8005=oo`00
T7oo0P0000=JEP00Ool0:goo0P0000=JEP00FUH00eYF00<007ooOol0DWoo002AOol00`00FUIJEP02
000XOol20003FUH01@00FUIJEUYF0000EGoo002AOol01@00FUIJEP00FUH00`008Woo0`001EYF00@0
05YF000005Ioo`00TWoo00<005YF000015YF0`006goo100000=JEP00FUH01EYF0P00F7oo002COol3
0004FUH00`00FUH00003000@Ool70005FUH00`00FUIJEP04FUH00`00Oomoo`1GOol009Eoo`03001J
EUYF009JEP03001JEUYF00=JEQ0000AJEP03001JEUYF00IJEP04001JEUYFFUH2001JOol009Ioo`80
00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
001LOol009Qoo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@005ioo`00VWoo1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01000HWoo002O
Ool80004FUH00`00FUIJEP02FUH7001VOol00:Moo`T006eoo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]56\[InvisibleSpace]"     "\
\[InvisibleSpace]13.54821250631116`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 56, "     ", 13.54821250631116, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58611 .73134 m .60495 .6773 L .57576 .6662 L p .707 .577 .707 r
F P
0 g
s
.60495 .6773 m .58611 .73134 L .61628 .74144 L p .707 .577 .707 r
F P
0 g
s
.61628 .74144 m .63512 .6874 L .60495 .6773 L p .707 .577 .707 r
F P
0 g
s
.63512 .6874 m .61628 .74144 L .64449 .74954 L p .707 .577 .707 r
F P
0 g
s
.64449 .74954 m .66333 .69551 L .63512 .6874 L p .707 .577 .707 r
F P
0 g
s
.55692 .72023 m .57576 .6662 L .55041 .65517 L p .707 .577 .707 r
F P
0 g
s
.57576 .6662 m .55692 .72023 L .58611 .73134 L p .707 .577 .707 r
F P
0 g
s
.55041 .65517 m .53158 .70921 L .55692 .72023 L p .707 .577 .707 r
F P
0 g
s
.66333 .69551 m .64449 .74954 L .66796 .75486 L p .707 .577 .707 r
F P
0 g
s
.66796 .75486 m .6868 .70082 L .66333 .69551 L p .707 .577 .707 r
F P
0 g
s
.58994 .80201 m .59628 .76483 L .56558 .75835 L p .707 .577 .707 r
F P
0 g
s
.59628 .76483 m .58994 .80201 L .62136 .80661 L p .707 .577 .707 r
F P
0 g
s
.62136 .80661 m .6277 .76944 L .59628 .76483 L p .707 .577 .707 r
F P
0 g
s
.6277 .76944 m .62136 .80661 L .65043 .80889 L p .707 .577 .707 r
F P
0 g
s
.65043 .80889 m .65676 .77172 L .6277 .76944 L p .707 .577 .707 r
F P
0 g
s
.53158 .70921 m .55041 .65517 L .53139 .64531 L p .707 .577 .707 r
F P
0 g
s
.55924 .79553 m .56558 .75835 L .53861 .75063 L p .707 .577 .707 r
F P
0 g
s
.56558 .75835 m .55924 .79553 L .58994 .80201 L p .707 .577 .707 r
F P
0 g
s
.53139 .64531 m .51255 .69934 L .53158 .70921 L p .707 .577 .707 r
F P
0 g
s
.53861 .75063 m .53227 .78781 L .55924 .79553 L p .707 .577 .707 r
F P
0 g
s
.65676 .77172 m .65043 .80889 L .67429 .80862 L p .707 .577 .707 r
F P
0 g
s
.67429 .80862 m .68063 .77144 L .65676 .77172 L p .707 .577 .707 r
F P
0 g
s
.6868 .70082 m .66796 .75486 L .68441 .75687 L p .707 .577 .707 r
F P
0 g
s
.68441 .75687 m .70325 .70283 L .6868 .70082 L p .707 .577 .707 r
F P
0 g
s
.53227 .78781 m .53861 .75063 L .518 .74242 L p .707 .577 .707 r
F P
0 g
s
.61773 .86082 m .61304 .84352 L .58255 .84847 L p .707 .577 .707 r
F P
0 g
s
.61304 .84352 m .61773 .86082 L .64846 .85208 L p .707 .577 .707 r
F P
0 g
s
.64846 .85208 m .64377 .83478 L .61304 .84352 L p .707 .577 .707 r
F P
0 g
s
.64377 .83478 m .64846 .85208 L .67642 .84039 L p .707 .577 .707 r
F P
0 g
s
.67642 .84039 m .67173 .82309 L .64377 .83478 L p .707 .577 .707 r
F P
0 g
s
.51255 .69934 m .53139 .64531 L .52056 .63757 L p .707 .577 .707 r
F P
0 g
s
.518 .74242 m .51166 .7796 L .53227 .78781 L p .707 .577 .707 r
F P
0 g
s
.58255 .84847 m .58724 .86576 L .61773 .86082 L p .707 .577 .707 r
F P
0 g
s
.58724 .86576 m .58255 .84847 L .55528 .84913 L p .707 .577 .707 r
F P
0 g
s
.52056 .63757 m .50172 .6916 L .51255 .69934 L p .707 .577 .707 r
F P
0 g
s
.68063 .77144 m .67429 .80862 L .69062 .80582 L p .707 .577 .707 r
F P
0 g
s
.69062 .80582 m .69695 .76865 L .68063 .77144 L p .707 .577 .707 r
F P
0 g
s
.67173 .82309 m .67642 .84039 L .69888 .8269 L p .707 .577 .707 r
F P
0 g
s
.69888 .8269 m .69419 .80961 L .67173 .82309 L p .707 .577 .707 r
F P
0 g
s
.55528 .84913 m .55997 .86642 L .58724 .86576 L p .707 .577 .707 r
F P
0 g
s
.51166 .7796 m .518 .74242 L .50578 .73453 L p .707 .577 .707 r
F P
0 g
s
.70325 .70283 m .68441 .75687 L .69222 .75537 L p .707 .577 .707 r
F P
0 g
s
.69222 .75537 m .71106 .70133 L .70325 .70283 L p .707 .577 .707 r
F P
0 g
s
.50578 .73453 m .49944 .77171 L .51166 .7796 L p .707 .577 .707 r
F P
0 g
s
.55997 .86642 m .55528 .84913 L .53391 .84544 L p .707 .577 .707 r
F P
0 g
s
.69419 .80961 m .69888 .8269 L .71363 .81294 L p .707 .577 .707 r
F P
0 g
s
.71363 .81294 m .70894 .79564 L .69419 .80961 L p .707 .577 .707 r
F P
0 g
s
.50172 .6916 m .52056 .63757 L .51896 .63271 L p .707 .577 .707 r
F P
0 g
s
.53391 .84544 m .5386 .86273 L .55997 .86642 L p .707 .577 .707 r
F P
0 g
s
.51896 .63271 m .50013 .68674 L .50172 .6916 L p .707 .577 .707 r
F P
0 g
s
.69695 .76865 m .69062 .80582 L .69781 .80078 L p .707 .577 .707 r
F P
0 g
s
.69781 .80078 m .70415 .7636 L .69695 .76865 L p .707 .577 .707 r
F P
0 g
s
.49944 .77171 m .50578 .73453 L .50313 .72773 L p .707 .577 .707 r
F P
0 g
s
.5386 .86273 m .53391 .84544 L .52052 .83776 L p .707 .577 .707 r
F P
0 g
s
.71106 .70133 m .69222 .75537 L .69063 .75051 L p .707 .577 .707 r
F P
0 g
s
.69063 .75051 m .70947 .69648 L .71106 .70133 L p .707 .577 .707 r
F P
0 g
s
.50313 .72773 m .4968 .76491 L .49944 .77171 L p .707 .577 .707 r
F P
0 g
s
.70894 .79564 m .71363 .81294 L .71924 .79986 L p .707 .577 .707 r
F P
0 g
s
.71924 .79986 m .71455 .78256 L .70894 .79564 L p .707 .577 .707 r
F P
0 g
s
.50013 .68674 m .51896 .63271 L .52678 .63121 L p .707 .577 .707 r
F P
0 g
s
.52678 .63121 m .50794 .68525 L .50013 .68674 L p .707 .577 .707 r
F P
0 g
s
.4968 .76491 m .50313 .72773 L .51033 .72269 L p .707 .577 .707 r
F P
0 g
s
.51033 .72269 m .50399 .75986 L .4968 .76491 L p .707 .577 .707 r
F P
0 g
s
.50794 .68525 m .52678 .63121 L .54322 .63322 L p .707 .577 .707 r
F P
0 g
s
.54322 .63322 m .52438 .68725 L .50794 .68525 L p .707 .577 .707 r
F P
0 g
s
.52052 .83776 m .52521 .85506 L .5386 .86273 L p .707 .577 .707 r
F P
0 g
s
.52521 .85506 m .52052 .83776 L .51643 .82685 L p .707 .577 .707 r
F P
0 g
s
.51643 .82685 m .52111 .84415 L .52521 .85506 L p .707 .577 .707 r
F P
0 g
s
.52111 .84415 m .51643 .82685 L .52203 .81378 L p .707 .577 .707 r
F P
0 g
s
.50399 .75986 m .51033 .72269 L .52665 .71989 L p .707 .577 .707 r
F P
0 g
s
.52665 .71989 m .52032 .75706 L .50399 .75986 L p .707 .577 .707 r
F P
0 g
s
.51909 .82158 m .51909 .31969 L .47398 .3194 L p .707 .577 .707 r
F P
0 g
s
.52203 .81378 m .52672 .83107 L .52111 .84415 L p .707 .577 .707 r
F P
0 g
s
.52438 .68725 m .54322 .63322 L .5667 .63854 L p .707 .577 .707 r
F P
0 g
s
.5667 .63854 m .54786 .69257 L .52438 .68725 L p .707 .577 .707 r
F P
0 g
s
.52672 .83107 m .52203 .81378 L .53678 .79981 L p .707 .577 .707 r
F P
0 g
s
.52032 .75706 m .52665 .71989 L .55052 .71962 L p .707 .577 .707 r
F P
0 g
s
.54786 .69257 m .5667 .63854 L .5949 .64664 L p .707 .577 .707 r
F P
0 g
s
.53678 .79981 m .54147 .81711 L .52672 .83107 L p .707 .577 .707 r
F P
0 g
s
.55052 .71962 m .54418 .75679 L .52032 .75706 L p .707 .577 .707 r
F P
0 g
s
.5949 .64664 m .57606 .70068 L .54786 .69257 L p .707 .577 .707 r
F P
0 g
s
.54418 .75679 m .55052 .71962 L .57958 .7219 L p .707 .577 .707 r
F P
0 g
s
.54147 .81711 m .53678 .79981 L .55924 .78632 L p .707 .577 .707 r
F P
0 g
s
.57958 .7219 m .57325 .75907 L .54418 .75679 L p .707 .577 .707 r
F P
0 g
s
.55924 .78632 m .56393 .80362 L .54147 .81711 L p .707 .577 .707 r
F P
0 g
s
.56393 .80362 m .55924 .78632 L .5872 .77464 L p .707 .577 .707 r
F P
0 g
s
.51909 .31969 m .51909 .82158 L .56234 .81812 L p .707 .577 .707 r
F P
0 g
s
.56234 .81812 m .56234 .31623 L .51909 .31969 L p .707 .577 .707 r
F P
0 g
s
.47398 .82129 m .47398 .3194 L .43141 .31538 L p .707 .577 .707 r
F P
0 g
s
.47398 .3194 m .47398 .82129 L .51909 .82158 L p .707 .577 .707 r
F P
0 g
s
.57606 .70068 m .5949 .64664 L .62508 .65674 L p .707 .577 .707 r
F P
0 g
s
.62508 .65674 m .60624 .71078 L .57606 .70068 L p .707 .577 .707 r
F P
0 g
s
.57325 .75907 m .57958 .7219 L .611 .7265 L p .707 .577 .707 r
F P
0 g
s
.611 .7265 m .60467 .76367 L .57325 .75907 L p .707 .577 .707 r
F P
0 g
s
.5872 .77464 m .59189 .79193 L .56393 .80362 L p .707 .577 .707 r
F P
0 g
s
.6417 .73298 m .63537 .77015 L .60467 .76367 L p .707 .577 .707 r
F P
0 g
s
.59189 .79193 m .5872 .77464 L .61793 .76589 L p .707 .577 .707 r
F P
0 g
s
.61793 .76589 m .62262 .78319 L .59189 .79193 L p .707 .577 .707 r
F P
0 g
s
.56234 .31623 m .56234 .81812 L .59948 .81124 L p .707 .577 .707 r
F P
0 g
s
.59948 .81124 m .59948 .30936 L .56234 .31623 L p .707 .577 .707 r
F P
0 g
s
.70415 .7636 m .69781 .80078 L .69517 .79398 L p .707 .577 .707 r
F P
0 g
s
.69517 .79398 m .7015 .7568 L .70415 .7636 L p .707 .577 .707 r
F P
0 g
s
.43141 .81727 m .43141 .31538 L .39555 .30802 L p .707 .577 .707 r
F P
0 g
s
.43141 .31538 m .43141 .81727 L .47398 .82129 L p .707 .577 .707 r
F P
0 g
s
.70947 .69648 m .69063 .75051 L .67979 .74277 L p .707 .577 .707 r
F P
0 g
s
.67979 .74277 m .69863 .68874 L .70947 .69648 L p .707 .577 .707 r
F P
0 g
s
.71455 .78256 m .71924 .79986 L .71514 .78895 L p .707 .577 .707 r
F P
0 g
s
.71514 .78895 m .71046 .77165 L .71455 .78256 L p .707 .577 .707 r
F P
0 g
s
.24839 .73912 m .25664 .69239 L .22592 .68436 L p .707 .577 .707 r
F P
0 g
s
.25664 .69239 m .24839 .73912 L .27995 .74152 L p .707 .577 .707 r
F P
0 g
s
.27995 .74152 m .28819 .69478 L .25664 .69239 L p .707 .577 .707 r
F P
0 g
s
.21767 .7311 m .22592 .68436 L .19904 .67149 L p .707 .577 .707 r
F P
0 g
s
.22592 .68436 m .21767 .7311 L .24839 .73912 L p .707 .577 .707 r
F P
0 g
s
.65426 .66785 m .63543 .72188 L .60624 .71078 L p .707 .577 .707 r
F P
0 g
s
.60624 .71078 m .62508 .65674 L .65426 .66785 L p .707 .577 .707 r
F P
0 g
s
.60467 .76367 m .611 .7265 L .6417 .73298 L p .707 .577 .707 r
F P
0 g
s
.66867 .7407 m .66234 .77788 L .63537 .77015 L p .707 .577 .707 r
F P
0 g
s
.64843 .76095 m .65311 .77825 L .62262 .78319 L p .707 .577 .707 r
F P
0 g
s
.63537 .77015 m .6417 .73298 L .66867 .7407 L p .707 .577 .707 r
F P
0 g
s
.62262 .78319 m .61793 .76589 L .64843 .76095 L p .707 .577 .707 r
F P
0 g
s
.59948 .30936 m .59948 .81124 L .62689 .80162 L p .707 .577 .707 r
F P
0 g
s
.62689 .80162 m .62689 .29973 L .59948 .30936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28819 .69478 m .27995 .74152 L .30925 .73805 L p .707 .577 .707 r
F P
0 g
s
.30925 .73805 m .3175 .69132 L .28819 .69478 L p .707 .577 .707 r
F P
0 g
s
.39555 .80991 m .39555 .30802 L .36992 .29806 L p .707 .577 .707 r
F P
0 g
s
.39555 .30802 m .39555 .80991 L .43141 .81727 L p .707 .577 .707 r
F P
0 g
s
.7015 .7568 m .69517 .79398 L .68295 .78609 L p .707 .577 .707 r
F P
0 g
s
.68295 .78609 m .68928 .74891 L .7015 .7568 L p .707 .577 .707 r
F P
0 g
s
.19079 .71823 m .19904 .67149 L .17864 .65504 L p .707 .577 .707 r
F P
0 g
s
.19904 .67149 m .19079 .71823 L .21767 .7311 L p .707 .577 .707 r
F P
0 g
s
.3175 .69132 m .30925 .73805 L .33343 .72906 L p .707 .577 .707 r
F P
0 g
s
.33343 .72906 m .34167 .68233 L .3175 .69132 L p .707 .577 .707 r
F P
0 g
s
.26569 .79576 m .26362 .77665 L .23232 .77984 L p .707 .577 .707 r
F P
0 g
s
.26362 .77665 m .26569 .79576 L .29716 .79218 L p .707 .577 .707 r
F P
0 g
s
.29716 .79218 m .29509 .77308 L .26362 .77665 L p .707 .577 .707 r
F P
0 g
s
.23232 .77984 m .23439 .79895 L .26569 .79576 L p .707 .577 .707 r
F P
0 g
s
.69863 .68874 m .67979 .74277 L .66077 .73291 L p .707 .577 .707 r
F P
0 g
s
.66077 .73291 m .67961 .67887 L .69863 .68874 L p .707 .577 .707 r
F P
0 g
s
.2505 .78664 m .25323 .75189 L .22216 .74685 L p .707 .577 .707 r
F P
0 g
s
.25323 .75189 m .2505 .78664 L .28226 .78749 L p .707 .577 .707 r
F P
0 g
s
.28226 .78749 m .285 .75274 L .25323 .75189 L p .707 .577 .707 r
F P
0 g
s
.29509 .77308 m .29716 .79218 L .3257 .78857 L p .707 .577 .707 r
F P
0 g
s
.3257 .78857 m .32363 .76946 L .29509 .77308 L p .707 .577 .707 r
F P
0 g
s
.71046 .77165 m .71514 .78895 L .70176 .78127 L p .707 .577 .707 r
F P
0 g
s
.70176 .78127 m .69707 .76398 L .71046 .77165 L p .707 .577 .707 r
F P
0 g
s
.23439 .79895 m .23232 .77984 L .20423 .78234 L p .707 .577 .707 r
F P
0 g
s
.20423 .78234 m .20631 .80144 L .23439 .79895 L p .707 .577 .707 r
F P
0 g
s
.285 .75274 m .28226 .78749 L .3116 .78407 L p .707 .577 .707 r
F P
0 g
s
.3116 .78407 m .31433 .74932 L .285 .75274 L p .707 .577 .707 r
F P
0 g
s
.21942 .7816 m .22216 .74685 L .1948 .73812 L p .707 .577 .707 r
F P
0 g
s
.22216 .74685 m .21942 .7816 L .2505 .78664 L p .707 .577 .707 r
F P
0 g
s
.17039 .70178 m .17864 .65504 L .1667 .63662 L p .707 .577 .707 r
F P
0 g
s
.17864 .65504 m .17039 .70178 L .19079 .71823 L p .707 .577 .707 r
F P
0 g
s
.34167 .68233 m .33343 .72906 L .35012 .71543 L p .707 .577 .707 r
F P
0 g
s
.35012 .71543 m .35837 .6687 L .34167 .68233 L p .707 .577 .707 r
F P
0 g
s
.32363 .76946 m .3257 .78857 L .34854 .78528 L p .707 .577 .707 r
F P
0 g
s
.34854 .78528 m .34646 .76617 L .32363 .76946 L p .707 .577 .707 r
F P
0 g
s
.67961 .67887 m .66077 .73291 L .63543 .72188 L p .707 .577 .707 r
F P
0 g
s
.63543 .72188 m .65426 .66785 L .67961 .67887 L p .707 .577 .707 r
F P
0 g
s
.62689 .29973 m .62689 .80162 L .64188 .7902 L p .707 .577 .707 r
F P
0 g
s
.64188 .7902 m .64188 .28831 L .62689 .29973 L p .707 .577 .707 r
F P
0 g
s
.31433 .74932 m .3116 .78407 L .33564 .77672 L p .707 .577 .707 r
F P
0 g
s
.33564 .77672 m .33837 .74197 L .31433 .74932 L p .707 .577 .707 r
F P
0 g
s
.20631 .80144 m .20423 .78234 L .18213 .78389 L p .707 .577 .707 r
F P
0 g
s
.68928 .74891 m .68295 .78609 L .66234 .77788 L p .707 .577 .707 r
F P
0 g
s
.66234 .77788 m .66867 .7407 L .68928 .74891 L p .707 .577 .707 r
F P
0 g
s
.18213 .78389 m .1842 .803 L .20631 .80144 L p .707 .577 .707 r
F P
0 g
s
.19207 .77287 m .1948 .73812 L .17385 .72656 L p .707 .577 .707 r
F P
0 g
s
.1948 .73812 m .19207 .77287 L .21942 .7816 L p .707 .577 .707 r
F P
0 g
s
.36992 .79995 m .36992 .29806 L .35702 .28645 L p .707 .577 .707 r
F P
0 g
s
.36992 .29806 m .36992 .79995 L .39555 .80991 L p .707 .577 .707 r
F P
0 g
s
.69707 .76398 m .70176 .78127 L .68038 .77759 L p .707 .577 .707 r
F P
0 g
s
.68038 .77759 m .67569 .76029 L .69707 .76398 L p .707 .577 .707 r
F P
0 g
s
.15845 .68335 m .1667 .63662 L .16441 .61802 L p .707 .577 .707 r
F P
0 g
s
.1667 .63662 m .15845 .68335 L .17039 .70178 L p .707 .577 .707 r
F P
0 g
s
.35837 .6687 m .35412 .69272 L p .35769 .69849 L .707 .577 .707 r
F P
0 g
s
.3548 .70496 m .35769 .69849 L p .35412 .69272 L .707 .577 .707 r
F P
0 g
s
.36342 .78262 m .36134 .76351 L .34646 .76617 L p .707 .577 .707 r
F P
0 g
s
.35476 .7314 m .35203 .76615 L .35916 .75341 L p .707 .577 .707 r
F P
0 g
s
.35916 .75341 m .36189 .71866 L .35476 .7314 L p .707 .577 .707 r
F P
0 g
s
.35769 .69849 m .36593 .65175 L .35837 .6687 L p .707 .577 .707 r
F P
0 g
s
.36593 .65175 m .35769 .69849 L .3557 .68241 L p .707 .577 .707 r
F P
0 g
s
.3557 .68241 m .35539 .6799 L p .35576 .67891 L .707 .577 .707 r
F P
0 g
s
.35576 .67891 m .36593 .65175 L .3557 .68241 L .707 .577 .707 r
F
.34646 .76617 m .34854 .78528 L .36342 .78262 L p F P
0 g
s
.36364 .63316 m .36593 .65175 L p .35576 .67891 L .707 .577 .707 r
F P
0 g
s
.35539 .6799 m .35578 .6777 L p .35576 .67891 L .707 .577 .707 r
F P
0 g
s
.35578 .6777 m .36364 .63316 L p .35576 .67891 L .707 .577 .707 r
F P
0 g
s
.36134 .76351 m .36342 .78262 L .36889 .78087 L p .707 .577 .707 r
F P
0 g
s
.36889 .78087 m .36682 .76176 L .36134 .76351 L p .707 .577 .707 r
F P
0 g
s
.36364 .63316 m .35539 .6799 L .34346 .66147 L p .707 .577 .707 r
F P
0 g
s
.34346 .66147 m .3517 .61474 L .36364 .63316 L p .707 .577 .707 r
F P
0 g
s
.36189 .71866 m .35916 .75341 L .35634 .73973 L p .707 .577 .707 r
F P
0 g
s
.35634 .73973 m .35907 .70498 L .36189 .71866 L p .707 .577 .707 r
F P
0 g
s
.36682 .76176 m .36889 .78087 L .36443 .78018 L p .707 .577 .707 r
F P
0 g
s
.36443 .78018 m .36235 .76108 L .36682 .76176 L p .707 .577 .707 r
F P
0 g
s
.35203 .76615 m .35476 .7314 L .33837 .74197 L p .707 .577 .707 r
F P
0 g
s
.35907 .70498 m .35634 .73973 L .34385 .72646 L p .707 .577 .707 r
F P
0 g
s
.35412 .69272 m .35012 .71543 L .3548 .70496 L p .707 .577 .707 r
F P
0 g
s
.34385 .72646 m .34658 .69171 L .35907 .70498 L p .707 .577 .707 r
F P
0 g
s
.36235 .76108 m .36443 .78018 L .35046 .78064 L p .707 .577 .707 r
F P
0 g
s
.33837 .74197 m .33564 .77672 L .35203 .76615 L p .707 .577 .707 r
F P
0 g
s
.35046 .78064 m .34838 .76153 L .36235 .76108 L p .707 .577 .707 r
F P
0 g
s
.35702 .28645 m .35702 .78834 L .36992 .79995 L p .707 .577 .707 r
F P
0 g
s
.35702 .74556 m .35702 .6013 L .35711 .74716 L .707 .577 .707 r
F
.35702 .6013 m .35702 .28645 L p .35708 .59765 L F P
0 g
s
.35702 .6013 m .35708 .59765 L .35711 .74716 L .707 .577 .707 r
F
.35702 .28645 m .35812 .27435 L p .35748 .57309 L F P
0 g
s
.35711 .74716 m .35708 .59765 L .35748 .57309 L .707 .577 .707 r
F
.35708 .59765 m .35702 .28645 L .35748 .57309 L F
.35702 .78834 m .35702 .74556 L p .35711 .74716 L F P
0 g
s
.17385 .72656 m .17112 .76131 L .19207 .77287 L p .707 .577 .707 r
F P
0 g
s
.1842 .803 m .18213 .78389 L .16816 .78434 L p .707 .577 .707 r
F P
0 g
s
.16816 .78434 m .17023 .80345 L .1842 .803 L p .707 .577 .707 r
F P
0 g
s
.17112 .76131 m .17385 .72656 L .16136 .71329 L p .707 .577 .707 r
F P
0 g
s
.67569 .76029 m .68038 .77759 L .65311 .77825 L p .707 .577 .707 r
F P
0 g
s
.65311 .77825 m .64843 .76095 L .67569 .76029 L p .707 .577 .707 r
F P
0 g
s
.64188 .28831 m .64188 .7902 L .64298 .7781 L p .707 .577 .707 r
F P
0 g
s
.64298 .7781 m .64297 .27621 L .64188 .28831 L p .707 .577 .707 r
F P
0 g
s
.16136 .71329 m .15863 .74804 L .17112 .76131 L p .707 .577 .707 r
F P
0 g
s
.16441 .61802 m .15616 .66476 L .15845 .68335 L p .707 .577 .707 r
F P
0 g
s
.15616 .66476 m .16441 .61802 L .17197 .60108 L p .707 .577 .707 r
F P
0 g
s
.15863 .74804 m .16136 .71329 L .15854 .69961 L p .707 .577 .707 r
F P
0 g
s
.17023 .80345 m .16816 .78434 L .16369 .78366 L p .707 .577 .707 r
F P
0 g
s
.16369 .78366 m .16576 .80277 L .17023 .80345 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.15854 .69961 m .15581 .73436 L .15863 .74804 L p .707 .577 .707 r
F P
0 g
s
.16373 .64782 m .17197 .60108 L .18867 .58745 L p .707 .577 .707 r
F P
0 g
s
.17197 .60108 m .16373 .64782 L .15616 .66476 L p .707 .577 .707 r
F P
0 g
s
.15581 .73436 m .15854 .69961 L .16567 .68686 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.64297 .27621 m .64298 .7781 L .63008 .76649 L p .707 .577 .707 r
F P
0 g
s
.63008 .76649 m .63008 .2646 L .64297 .27621 L p .707 .577 .707 r
F P
0 g
s
.16576 .80277 m .16369 .78366 L .16916 .78191 L p .707 .577 .707 r
F P
0 g
s
.16916 .78191 m .17124 .80102 L .16576 .80277 L p .707 .577 .707 r
F P
0 g
s
.35812 .77624 m .35812 .27435 L .37311 .26292 L p .707 .577 .707 r
F P
0 g
s
.35812 .27435 m .35812 .77624 L .35702 .78834 L p .707 .577 .707 r
F P
0 g
s
.18867 .58745 m .18042 .63418 L .16373 .64782 L p .707 .577 .707 r
F P
0 g
s
.18042 .63418 m .18867 .58745 L .21284 .57846 L p .707 .577 .707 r
F P
0 g
s
.3517 .61474 m .34346 .66147 L .32305 .64502 L p .707 .577 .707 r
F P
0 g
s
.32305 .64502 m .3313 .59829 L .3517 .61474 L p .707 .577 .707 r
F P
0 g
s
.16567 .68686 m .16294 .72161 L .15581 .73436 L p .707 .577 .707 r
F P
0 g
s
.16294 .72161 m .16567 .68686 L .18206 .6763 L p .707 .577 .707 r
F P
0 g
s
.2046 .62519 m .21284 .57846 L .24215 .57499 L p .707 .577 .707 r
F P
0 g
s
.21284 .57846 m .2046 .62519 L .18042 .63418 L p .707 .577 .707 r
F P
0 g
s
.3313 .59829 m .32305 .64502 L .29617 .63215 L p .707 .577 .707 r
F P
0 g
s
.29617 .63215 m .30442 .58542 L .3313 .59829 L p .707 .577 .707 r
F P
0 g
s
.17124 .80102 m .16916 .78191 L .18405 .77925 L p .707 .577 .707 r
F P
0 g
s
.18405 .77925 m .18612 .79836 L .17124 .80102 L p .707 .577 .707 r
F P
0 g
s
.2339 .62173 m .24215 .57499 L .2737 .57739 L p .707 .577 .707 r
F P
0 g
s
.24215 .57499 m .2339 .62173 L .2046 .62519 L p .707 .577 .707 r
F P
0 g
s
.30442 .58542 m .29617 .63215 L .26545 .62413 L p .707 .577 .707 r
F P
0 g
s
.26545 .62413 m .2737 .57739 L .30442 .58542 L p .707 .577 .707 r
F P
0 g
s
.18206 .6763 m .17933 .71105 L .16294 .72161 L p .707 .577 .707 r
F P
0 g
s
.63008 .2646 m .63008 .76649 L .60445 .75652 L p .707 .577 .707 r
F P
0 g
s
.60445 .75652 m .60445 .25463 L .63008 .2646 L p .707 .577 .707 r
F P
0 g
s
.2737 .57739 m .26545 .62413 L .2339 .62173 L p .707 .577 .707 r
F P
0 g
s
.34658 .69171 m .34385 .72646 L .3229 .71489 L p .707 .577 .707 r
F P
0 g
s
.3229 .71489 m .32563 .68014 L .34658 .69171 L p .707 .577 .707 r
F P
0 g
s
.37311 .76481 m .37311 .26292 L .40051 .2533 L p .707 .577 .707 r
F P
0 g
s
.37311 .26292 m .37311 .76481 L .35812 .77624 L p .707 .577 .707 r
F P
0 g
s
.17933 .71105 m .18206 .6763 L .2061 .66895 L p .707 .577 .707 r
F P
0 g
s
.34838 .76153 m .35046 .78064 L .32835 .78219 L p .707 .577 .707 r
F P
0 g
s
.32835 .78219 m .32627 .76308 L .34838 .76153 L p .707 .577 .707 r
F P
0 g
s
.18612 .79836 m .18405 .77925 L .20688 .77596 L p .707 .577 .707 r
F P
0 g
s
.20688 .77596 m .20895 .79507 L .18612 .79836 L p .707 .577 .707 r
F P
0 g
s
.32563 .68014 m .3229 .71489 L .29555 .70617 L p .707 .577 .707 r
F P
0 g
s
.29555 .70617 m .29828 .67141 L .32563 .68014 L p .707 .577 .707 r
F P
0 g
s
.2061 .66895 m .20337 .7037 L .17933 .71105 L p .707 .577 .707 r
F P
0 g
s
.20337 .7037 m .2061 .66895 L .23544 .66553 L p .707 .577 .707 r
F P
0 g
s
.69558 .57228 m .70382 .62925 L .73454 .6243 L p .707 .577 .707 r
F P
0 g
s
.73454 .6243 m .7263 .56733 L .69558 .57228 L p .707 .577 .707 r
F P
0 g
s
.7263 .56733 m .73454 .6243 L .7661 .61991 L p .707 .577 .707 r
F P
0 g
s
.60445 .25463 m .60445 .75652 L .56859 .74917 L p .707 .577 .707 r
F P
0 g
s
.56859 .74917 m .56859 .24728 L .60445 .25463 L p .707 .577 .707 r
F P
0 g
s
.7661 .61991 m .75785 .56294 L .7263 .56733 L p .707 .577 .707 r
F P
0 g
s
.75785 .56294 m .7661 .61991 L .7954 .61652 L p .707 .577 .707 r
F P
0 g
s
.32627 .76308 m .32835 .78219 L .30027 .78468 L p .707 .577 .707 r
F P
0 g
s
.30027 .78468 m .29819 .76558 L .32627 .76308 L p .707 .577 .707 r
F P
0 g
s
.29828 .67141 m .29555 .70617 L .26447 .70113 L p .707 .577 .707 r
F P
0 g
s
.26447 .70113 m .2672 .66638 L .29828 .67141 L p .707 .577 .707 r
F P
0 g
s
.23271 .70028 m .23544 .66553 L .2672 .66638 L p .707 .577 .707 r
F P
0 g
s
.23544 .66553 m .23271 .70028 L .20337 .7037 L p .707 .577 .707 r
F P
0 g
s
.40051 .2533 m .40051 .75519 L .37311 .76481 L p .707 .577 .707 r
F P
0 g
s
.40051 .75519 m .40051 .2533 L .43766 .24643 L p .707 .577 .707 r
F P
0 g
s
.20895 .79507 m .20688 .77596 L .23542 .77235 L p .707 .577 .707 r
F P
0 g
s
.23542 .77235 m .2375 .79145 L .20895 .79507 L p .707 .577 .707 r
F P
0 g
s
.7954 .61652 m .78715 .55955 L .75785 .56294 L p .707 .577 .707 r
F P
0 g
s
.6687 .57731 m .67695 .63428 L .70382 .62925 L p .707 .577 .707 r
F P
0 g
s
.70382 .62925 m .69558 .57228 L .6687 .57731 L p .707 .577 .707 r
F P
0 g
s
.2672 .66638 m .26447 .70113 L .23271 .70028 L p .707 .577 .707 r
F P
0 g
s
.73553 .70291 m .7328 .66475 L .70172 .6662 L p .707 .577 .707 r
F P
0 g
s
.7328 .66475 m .73553 .70291 L .76729 .70036 L p .707 .577 .707 r
F P
0 g
s
.76729 .70036 m .76456 .66221 L .7328 .66475 L p .707 .577 .707 r
F P
0 g
s
.78715 .55955 m .7954 .61652 L .81958 .61445 L p .707 .577 .707 r
F P
0 g
s
.76456 .66221 m .76729 .70036 L .79663 .69696 L p .707 .577 .707 r
F P
0 g
s
.79663 .69696 m .7939 .65881 L .76456 .66221 L p .707 .577 .707 r
F P
0 g
s
.29819 .76558 m .30027 .78468 L .26896 .78788 L p .707 .577 .707 r
F P
0 g
s
.26896 .78788 m .26689 .76877 L .29819 .76558 L p .707 .577 .707 r
F P
0 g
s
.70172 .6662 m .70445 .70435 L .73553 .70291 L p .707 .577 .707 r
F P
0 g
s
.81958 .61445 m .81133 .55748 L .78715 .55955 L p .707 .577 .707 r
F P
0 g
s
.2375 .79145 m .23542 .77235 L .26689 .76877 L p .707 .577 .707 r
F P
0 g
s
.26689 .76877 m .26896 .78788 L .2375 .79145 L p .707 .577 .707 r
F P
0 g
s
.70445 .70435 m .70172 .6662 L .67437 .6664 L p .707 .577 .707 r
F P
0 g
s
.64829 .58193 m .65654 .6389 L .67695 .63428 L p .707 .577 .707 r
F P
0 g
s
.67695 .63428 m .6687 .57731 L .64829 .58193 L p .707 .577 .707 r
F P
0 g
s
.67437 .6664 m .6771 .70456 L .70445 .70435 L p .707 .577 .707 r
F P
0 g
s
.56859 .24728 m .56859 .74917 L .52602 .74515 L p .707 .577 .707 r
F P
0 g
s
.52602 .74515 m .52602 .24326 L .56859 .24728 L p .707 .577 .707 r
F P
0 g
s
.7939 .65881 m .79663 .69696 L .82067 .69305 L p .707 .577 .707 r
F P
0 g
s
.82067 .69305 m .81793 .65489 L .7939 .65881 L p .707 .577 .707 r
F P
0 g
s
.43766 .74831 m .43766 .24643 L .48091 .24296 L p .707 .577 .707 r
F P
0 g
s
.43766 .24643 m .43766 .74831 L .40051 .75519 L p .707 .577 .707 r
F P
0 g
s
.81133 .55748 m .81958 .61445 L .83627 .61391 L p .707 .577 .707 r
F P
0 g
s
.6771 .70456 m .67437 .6664 L .65342 .66534 L p .707 .577 .707 r
F P
0 g
s
.83627 .61391 m .82802 .55694 L .81133 .55748 L p .707 .577 .707 r
F P
0 g
s
.52602 .24326 m .52602 .74515 L .48091 .74485 L p .707 .577 .707 r
F P
0 g
s
.48091 .74485 m .48091 .24296 L .52602 .24326 L p .707 .577 .707 r
F P
0 g
s
.48091 .24296 m .48091 .74485 L .43766 .74831 L p .707 .577 .707 r
F P
0 g
s
.65342 .66534 m .65615 .7035 L .6771 .70456 L p .707 .577 .707 r
F P
0 g
s
.63636 .58569 m .64461 .64266 L .65654 .6389 L p .707 .577 .707 r
F P
0 g
s
.65654 .6389 m .64829 .58193 L .63636 .58569 L p .707 .577 .707 r
F P
0 g
s
.81793 .65489 m .82067 .69305 L .83705 .689 L p .707 .577 .707 r
F P
0 g
s
.83705 .689 m .83432 .65084 L .81793 .65489 L p .707 .577 .707 r
F P
0 g
s
.73104 .77679 m .73311 .76007 L .70181 .75443 L p .707 .577 .707 r
F P
0 g
s
.73311 .76007 m .73104 .77679 L .7625 .7776 L p .707 .577 .707 r
F P
0 g
s
.7625 .7776 m .76458 .76088 L .73311 .76007 L p .707 .577 .707 r
F P
0 g
s
.69973 .77115 m .70181 .75443 L .67372 .7445 L p .707 .577 .707 r
F P
0 g
s
.70181 .75443 m .69973 .77115 L .73104 .77679 L p .707 .577 .707 r
F P
0 g
s
.76458 .76088 m .7625 .7776 L .79105 .77349 L p .707 .577 .707 r
F P
0 g
s
.79105 .77349 m .79312 .75677 L .76458 .76088 L p .707 .577 .707 r
F P
0 g
s
.65615 .7035 m .65342 .66534 L .64092 .66313 L p .707 .577 .707 r
F P
0 g
s
.82802 .55694 m .83627 .61391 L .84384 .61496 L p .707 .577 .707 r
F P
0 g
s
.64092 .66313 m .64365 .70128 L .65615 .7035 L p .707 .577 .707 r
F P
0 g
s
.84384 .61496 m .83559 .55799 L .82802 .55694 L p .707 .577 .707 r
F P
0 g
s
.67372 .7445 m .67165 .76122 L .69973 .77115 L p .707 .577 .707 r
F P
0 g
s
.67165 .76122 m .67372 .7445 L .65162 .73127 L p .707 .577 .707 r
F P
0 g
s
.79312 .75677 m .79105 .77349 L .81388 .76487 L p .707 .577 .707 r
F P
0 g
s
.81388 .76487 m .81595 .74815 L .79312 .75677 L p .707 .577 .707 r
F P
0 g
s
.83432 .65084 m .83705 .689 L .84419 .68521 L p .707 .577 .707 r
F P
0 g
s
.84419 .68521 m .84146 .64705 L .83432 .65084 L p .707 .577 .707 r
F P
0 g
s
.63406 .58822 m .64231 .64519 L .64461 .64266 L p .707 .577 .707 r
F P
0 g
s
.64461 .64266 m .63636 .58569 L .63406 .58822 L p .707 .577 .707 r
F P
0 g
s
.65162 .73127 m .64954 .74799 L .67165 .76122 L p .707 .577 .707 r
F P
0 g
s
.64954 .74799 m .65162 .73127 L .63765 .71601 L p .707 .577 .707 r
F P
0 g
s
.64365 .70128 m .64092 .66313 L .6381 .65997 L p .707 .577 .707 r
F P
0 g
s
.83559 .55799 m .84384 .61496 L .84155 .61749 L p .707 .577 .707 r
F P
0 g
s
.81595 .74815 m .81388 .76487 L .82876 .75258 L p .707 .577 .707 r
F P
0 g
s
.82876 .75258 m .83083 .73586 L .81595 .74815 L p .707 .577 .707 r
F P
0 g
s
.6381 .65997 m .64084 .69813 L .64365 .70128 L p .707 .577 .707 r
F P
0 g
s
.63765 .71601 m .63557 .73273 L .64954 .74799 L p .707 .577 .707 r
F P
0 g
s
.84155 .61749 m .8333 .56052 L .83559 .55799 L p .707 .577 .707 r
F P
0 g
s
.84146 .64705 m .84419 .68521 L .84137 .68205 L p .707 .577 .707 r
F P
0 g
s
.84137 .68205 m .83864 .64389 L .84146 .64705 L p .707 .577 .707 r
F P
0 g
s
.64163 .58926 m .64988 .64623 L .64231 .64519 L p .707 .577 .707 r
F P
0 g
s
.64231 .64519 m .63406 .58822 L .64163 .58926 L p .707 .577 .707 r
F P
0 g
s
.63557 .73273 m .63765 .71601 L .63318 .70024 L p .707 .577 .707 r
F P
0 g
s
.83083 .73586 m .82876 .75258 L .83423 .73782 L p .707 .577 .707 r
F P
0 g
s
.83423 .73782 m .83631 .7211 L .83083 .73586 L p .707 .577 .707 r
F P
0 g
s
.63318 .70024 m .63111 .71696 L .63557 .73273 L p .707 .577 .707 r
F P
0 g
s
.64084 .69813 m .6381 .65997 L .64524 .65618 L p .707 .577 .707 r
F P
0 g
s
.8333 .56052 m .84155 .61749 L .82961 .62124 L p .707 .577 .707 r
F P
0 g
s
.42393 .62409 m .40509 .57403 L .37492 .58427 L p .707 .577 .707 r
F P
0 g
s
.40509 .57403 m .42393 .62409 L .45214 .6106 L p .707 .577 .707 r
F P
0 g
s
.45214 .6106 m .4333 .56054 L .40509 .57403 L p .707 .577 .707 r
F P
0 g
s
.64524 .65618 m .64797 .69434 L .64084 .69813 L p .707 .577 .707 r
F P
0 g
s
.39376 .63433 m .37492 .58427 L .34573 .59025 L p .707 .577 .707 r
F P
0 g
s
.37492 .58427 m .39376 .63433 L .42393 .62409 L p .707 .577 .707 r
F P
0 g
s
.82961 .62124 m .82136 .56427 L .8333 .56052 L p .707 .577 .707 r
F P
0 g
s
.4333 .56054 m .45214 .6106 L .47561 .59518 L p .707 .577 .707 r
F P
0 g
s
.47561 .59518 m .45677 .54511 L .4333 .56054 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.83864 .64389 m .84137 .68205 L .82888 .67983 L p .707 .577 .707 r
F P
0 g
s
.82888 .67983 m .82614 .64168 L .83864 .64389 L p .707 .577 .707 r
F P
0 g
s
.65832 .58873 m .66657 .6457 L .64988 .64623 L p .707 .577 .707 r
F P
0 g
s
.64988 .64623 m .64163 .58926 L .65832 .58873 L p .707 .577 .707 r
F P
0 g
s
.63111 .71696 m .63318 .70024 L .63866 .68548 L p .707 .577 .707 r
F P
0 g
s
.36457 .64031 m .34573 .59025 L .32039 .59138 L p .707 .577 .707 r
F P
0 g
s
.34573 .59025 m .36457 .64031 L .39376 .63433 L p .707 .577 .707 r
F P
0 g
s
.83631 .7211 m .83423 .73782 L .82977 .72205 L p .707 .577 .707 r
F P
0 g
s
.82977 .72205 m .83184 .70533 L .83631 .7211 L p .707 .577 .707 r
F P
0 g
s
.45677 .54511 m .47561 .59518 L .49206 .57933 L p .707 .577 .707 r
F P
0 g
s
.49206 .57933 m .47322 .52926 L .45677 .54511 L p .707 .577 .707 r
F P
0 g
s
.63866 .68548 m .63658 .7022 L .63111 .71696 L p .707 .577 .707 r
F P
0 g
s
.39533 .68805 m .38899 .65231 L .3583 .65469 L p .707 .577 .707 r
F P
0 g
s
.38899 .65231 m .39533 .68805 L .42675 .68221 L p .707 .577 .707 r
F P
0 g
s
.42675 .68221 m .42041 .64647 L .38899 .65231 L p .707 .577 .707 r
F P
0 g
s
.42041 .64647 m .42675 .68221 L .45581 .67348 L p .707 .577 .707 r
F P
0 g
s
.45581 .67348 m .44948 .63774 L .42041 .64647 L p .707 .577 .707 r
F P
0 g
s
.64797 .69434 m .64524 .65618 L .66163 .65213 L p .707 .577 .707 r
F P
0 g
s
.82136 .56427 m .82961 .62124 L .80921 .62586 L p .707 .577 .707 r
F P
0 g
s
.37737 .71276 m .38206 .69435 L .35157 .68586 L p .707 .577 .707 r
F P
0 g
s
.38206 .69435 m .37737 .71276 L .40811 .71972 L p .707 .577 .707 r
F P
0 g
s
.40811 .71972 m .41279 .7013 L .38206 .69435 L p .707 .577 .707 r
F P
0 g
s
.66163 .65213 m .66436 .69028 L .64797 .69434 L p .707 .577 .707 r
F P
0 g
s
.80921 .62586 m .80096 .56889 L .82136 .56427 L p .707 .577 .707 r
F P
0 g
s
.36463 .69043 m .3583 .65469 L .33132 .65338 L p .707 .577 .707 r
F P
0 g
s
.3583 .65469 m .36463 .69043 L .39533 .68805 L p .707 .577 .707 r
F P
0 g
s
.33923 .64144 m .32039 .59138 L .30136 .58756 L p .707 .577 .707 r
F P
0 g
s
.32039 .59138 m .33923 .64144 L .36457 .64031 L p .707 .577 .707 r
F P
0 g
s
.35157 .68586 m .34688 .70428 L .37737 .71276 L p .707 .577 .707 r
F P
0 g
s
.44948 .63774 m .45581 .67348 L .47968 .66272 L p .707 .577 .707 r
F P
0 g
s
.47968 .66272 m .47334 .62698 L .44948 .63774 L p .707 .577 .707 r
F P
0 g
s
.34688 .70428 m .35157 .68586 L .3243 .67668 L p .707 .577 .707 r
F P
0 g
s
.41279 .7013 m .40811 .71972 L .43607 .72447 L p .707 .577 .707 r
F P
0 g
s
.43607 .72447 m .44076 .70605 L .41279 .7013 L p .707 .577 .707 r
F P
0 g
s
.3243 .67668 m .31962 .69509 L .34688 .70428 L p .707 .577 .707 r
F P
0 g
s
.6825 .58666 m .69075 .64363 L .66657 .6457 L p .707 .577 .707 r
F P
0 g
s
.66657 .6457 m .65832 .58873 L .6825 .58666 L p .707 .577 .707 r
F P
0 g
s
.63658 .7022 m .63866 .68548 L .65354 .67319 L p .707 .577 .707 r
F P
0 g
s
.82614 .64168 m .82888 .67983 L .80793 .67877 L p .707 .577 .707 r
F P
0 g
s
.80793 .67877 m .80519 .64062 L .82614 .64168 L p .707 .577 .707 r
F P
0 g
s
.47322 .52926 m .49206 .57933 L .49987 .5646 L p .707 .577 .707 r
F P
0 g
s
.49987 .5646 m .48103 .51454 L .47322 .52926 L p .707 .577 .707 r
F P
0 g
s
.33132 .65338 m .33766 .68912 L .36463 .69043 L p .707 .577 .707 r
F P
0 g
s
.83184 .70533 m .82977 .72205 L .8158 .70679 L p .707 .577 .707 r
F P
0 g
s
.8158 .70679 m .81787 .69007 L .83184 .70533 L p .707 .577 .707 r
F P
0 g
s
.31962 .69509 m .3243 .67668 L .30293 .6677 L p .707 .577 .707 r
F P
0 g
s
.33766 .68912 m .33132 .65338 L .31072 .64851 L p .707 .577 .707 r
F P
0 g
s
.65354 .67319 m .65146 .68991 L .63658 .7022 L p .707 .577 .707 r
F P
0 g
s
.44076 .70605 m .43607 .72447 L .45853 .72654 L p .707 .577 .707 r
F P
0 g
s
.45853 .72654 m .46321 .70812 L .44076 .70605 L p .707 .577 .707 r
F P
0 g
s
.80096 .56889 m .80921 .62586 L .78233 .6309 L p .707 .577 .707 r
F P
0 g
s
.30293 .6677 m .29824 .68611 L .31962 .69509 L p .707 .577 .707 r
F P
0 g
s
.47334 .62698 m .47968 .66272 L .49601 .65098 L p .707 .577 .707 r
F P
0 g
s
.49601 .65098 m .48967 .61523 L .47334 .62698 L p .707 .577 .707 r
F P
0 g
s
.66436 .69028 m .66163 .65213 L .68567 .64821 L p .707 .577 .707 r
F P
0 g
s
.30136 .58756 m .3202 .63763 L .33923 .64144 L p .707 .577 .707 r
F P
0 g
s
.78233 .6309 m .77408 .57393 L .80096 .56889 L p .707 .577 .707 r
F P
0 g
s
.3202 .63763 m .30136 .58756 L .29053 .57916 L p .707 .577 .707 r
F P
0 g
s
.68567 .64821 m .6884 .68637 L .66436 .69028 L p .707 .577 .707 r
F P
0 g
s
.7118 .58327 m .72005 .64024 L .69075 .64363 L p .707 .577 .707 r
F P
0 g
s
.69075 .64363 m .6825 .58666 L .7118 .58327 L p .707 .577 .707 r
F P
0 g
s
.31072 .64851 m .31705 .68425 L .33766 .68912 L p .707 .577 .707 r
F P
0 g
s
.80519 .64062 m .80793 .67877 L .78057 .67898 L p .707 .577 .707 r
F P
0 g
s
.78057 .67898 m .77784 .64082 L .80519 .64062 L p .707 .577 .707 r
F P
0 g
s
.65146 .68991 m .65354 .67319 L .67637 .66457 L p .707 .577 .707 r
F P
0 g
s
.77408 .57393 m .78233 .6309 L .75161 .63585 L p .707 .577 .707 r
F P
0 g
s
.48103 .51454 m .49987 .5646 L .49828 .55244 L p .707 .577 .707 r
F P
0 g
s
.49828 .55244 m .47944 .50238 L .48103 .51454 L p .707 .577 .707 r
F P
0 g
s
.29824 .68611 m .30293 .6677 L .28954 .65979 L p .707 .577 .707 r
F P
0 g
s
.75161 .63585 m .74336 .57888 L .77408 .57393 L p .707 .577 .707 r
F P
0 g
s
.81787 .69007 m .8158 .70679 L .79369 .69356 L p .707 .577 .707 r
F P
0 g
s
.79369 .69356 m .79576 .67684 L .81787 .69007 L p .707 .577 .707 r
F P
0 g
s
.74336 .57888 m .75161 .63585 L .72005 .64024 L p .707 .577 .707 r
F P
0 g
s
.72005 .64024 m .7118 .58327 L .74336 .57888 L p .707 .577 .707 r
F P
0 g
s
.46321 .70812 m .45853 .72654 L .47328 .72573 L p .707 .577 .707 r
F P
0 g
s
.47328 .72573 m .47797 .70732 L .46321 .70812 L p .707 .577 .707 r
F P
0 g
s
.31705 .68425 m .31072 .64851 L .29849 .64055 L p .707 .577 .707 r
F P
0 g
s
.28954 .65979 m .28485 .67821 L .29824 .68611 L p .707 .577 .707 r
F P
0 g
s
.6884 .68637 m .68567 .64821 L .715 .64482 L p .707 .577 .707 r
F P
0 g
s
.67637 .66457 m .67429 .68129 L .65146 .68991 L p .707 .577 .707 r
F P
0 g
s
.48967 .61523 m .49601 .65098 L .5032 .63941 L p .707 .577 .707 r
F P
0 g
s
.5032 .63941 m .49687 .60366 L .48967 .61523 L p .707 .577 .707 r
F P
0 g
s
.715 .64482 m .71773 .68297 L .6884 .68637 L p .707 .577 .707 r
F P
0 g
s
.29053 .57916 m .30937 .62923 L .3202 .63763 L p .707 .577 .707 r
F P
0 g
s
.77784 .64082 m .78057 .67898 L .7495 .68042 L p .707 .577 .707 r
F P
0 g
s
.7495 .68042 m .74676 .64227 L .77784 .64082 L p .707 .577 .707 r
F P
0 g
s
.29849 .64055 m .30483 .67629 L .31705 .68425 L p .707 .577 .707 r
F P
0 g
s
.67429 .68129 m .67637 .66457 L .70491 .66046 L p .707 .577 .707 r
F P
0 g
s
.30937 .62923 m .29053 .57916 L .28894 .56701 L p .707 .577 .707 r
F P
0 g
s
.71773 .68297 m .715 .64482 L .74676 .64227 L p .707 .577 .707 r
F P
0 g
s
.74676 .64227 m .7495 .68042 L .71773 .68297 L p .707 .577 .707 r
F P
0 g
s
.79576 .67684 m .79369 .69356 L .76561 .68363 L p .707 .577 .707 r
F P
0 g
s
.76561 .68363 m .76768 .66691 L .79576 .67684 L p .707 .577 .707 r
F P
0 g
s
.70491 .66046 m .70284 .67718 L .67429 .68129 L p .707 .577 .707 r
F P
0 g
s
.28485 .67821 m .28954 .65979 L .28545 .65374 L p .707 .577 .707 r
F P
0 g
s
.47944 .50238 m .49828 .55244 L .48744 .54405 L p .707 .577 .707 r
F P
0 g
s
.48744 .54405 m .4686 .49398 L .47944 .50238 L p .707 .577 .707 r
F P
0 g
s
.70284 .67718 m .70491 .66046 L .73638 .66127 L p .707 .577 .707 r
F P
0 g
s
.47797 .70732 m .47328 .72573 L .47888 .72213 L p .707 .577 .707 r
F P
0 g
s
.47888 .72213 m .48357 .70371 L .47797 .70732 L p .707 .577 .707 r
F P
0 g
s
.28545 .65374 m .28076 .67216 L .28485 .67821 L p .707 .577 .707 r
F P
0 g
s
.30483 .67629 m .29849 .64055 L .29585 .63028 L p .707 .578 .707 r
F P
0 g
s
.76768 .66691 m .76561 .68363 L .7343 .67799 L p .707 .577 .707 r
F P
0 g
s
.7343 .67799 m .73638 .66127 L .76768 .66691 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.73638 .66127 m .7343 .67799 L .70284 .67718 L p .707 .577 .707 r
F P
0 g
s
.49687 .60366 m .5032 .63941 L .50056 .62914 L p .707 .578 .707 r
F P
0 g
s
.50056 .62914 m .49422 .5934 L .49687 .60366 L p .707 .578 .707 r
F P
0 g
s
.28894 .56701 m .30777 .61707 L .30937 .62923 L p .707 .577 .707 r
F P
0 g
s
.29585 .63028 m .30218 .66602 L .30483 .67629 L p .707 .578 .707 r
F P
0 g
s
.30777 .61707 m .28894 .56701 L .29675 .55228 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.4686 .49398 m .48744 .54405 L .46842 .54023 L p .707 .577 .707 r
F P
0 g
s
.46842 .54023 m .44958 .49016 L .4686 .49398 L p .707 .577 .707 r
F P
0 g
s
.28076 .67216 m .28545 .65374 L .29105 .65014 L p .707 .577 .707 r
F P
0 g
s
.30218 .66602 m .29585 .63028 L .30304 .61871 L p .707 .577 .707 r
F P
0 g
s
.48357 .70371 m .47888 .72213 L .47479 .71608 L p .707 .577 .707 r
F P
0 g
s
.47479 .71608 m .47948 .69767 L .48357 .70371 L p .707 .577 .707 r
F P
0 g
s
.29105 .65014 m .28636 .66856 L .28076 .67216 L p .707 .577 .707 r
F P
0 g
s
.49422 .5934 m .50056 .62914 L .48833 .62118 L p .707 .577 .707 r
F P
0 g
s
.48833 .62118 m .482 .58544 L .49422 .5934 L p .707 .577 .707 r
F P
0 g
s
.29675 .55228 m .31559 .60235 L .30777 .61707 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31559 .60235 m .29675 .55228 L .31319 .53643 L p .707 .577 .707 r
F P
0 g
s
.30304 .61871 m .30938 .65445 L .30218 .66602 L p .707 .577 .707 r
F P
0 g
s
.44958 .49016 m .46842 .54023 L .44308 .54136 L p .707 .577 .707 r
F P
0 g
s
.44308 .54136 m .42424 .4913 L .44958 .49016 L p .707 .577 .707 r
F P
0 g
s
.30938 .65445 m .30304 .61871 L .31937 .60697 L p .707 .577 .707 r
F P
0 g
s
.28636 .66856 m .29105 .65014 L .30581 .64933 L p .707 .577 .707 r
F P
0 g
s
.47948 .69767 m .47479 .71608 L .4614 .70818 L p .707 .577 .707 r
F P
0 g
s
.4614 .70818 m .46609 .68976 L .47948 .69767 L p .707 .577 .707 r
F P
0 g
s
.30581 .64933 m .30112 .66775 L .28636 .66856 L p .707 .577 .707 r
F P
0 g
s
.31319 .53643 m .33203 .5865 L .31559 .60235 L p .707 .577 .707 r
F P
0 g
s
.482 .58544 m .48833 .62118 L .46773 .6163 L p .707 .577 .707 r
F P
0 g
s
.46773 .6163 m .46139 .58056 L .482 .58544 L p .707 .577 .707 r
F P
0 g
s
.33203 .5865 m .31319 .53643 L .33667 .52101 L p .707 .577 .707 r
F P
0 g
s
.31937 .60697 m .32571 .64271 L .30938 .65445 L p .707 .577 .707 r
F P
0 g
s
.42424 .4913 m .44308 .54136 L .41389 .54734 L p .707 .577 .707 r
F P
0 g
s
.41389 .54734 m .39505 .49728 L .42424 .4913 L p .707 .577 .707 r
F P
0 g
s
.35551 .57107 m .33667 .52101 L .36488 .50751 L p .707 .577 .707 r
F P
0 g
s
.33667 .52101 m .35551 .57107 L .33203 .5865 L p .707 .577 .707 r
F P
0 g
s
.39505 .49728 m .41389 .54734 L .38371 .55758 L p .707 .577 .707 r
F P
0 g
s
.38371 .55758 m .36488 .50751 L .39505 .49728 L p .707 .577 .707 r
F P
0 g
s
.32571 .64271 m .31937 .60697 L .34324 .5962 L p .707 .577 .707 r
F P
0 g
s
.36488 .50751 m .38371 .55758 L .35551 .57107 L p .707 .577 .707 r
F P
0 g
s
.46139 .58056 m .46773 .6163 L .44075 .61499 L p .707 .577 .707 r
F P
0 g
s
.44075 .61499 m .43442 .57925 L .46139 .58056 L p .707 .577 .707 r
F P
0 g
s
.30112 .66775 m .30581 .64933 L .32826 .65141 L p .707 .577 .707 r
F P
0 g
s
.46609 .68976 m .4614 .70818 L .44003 .69919 L p .707 .577 .707 r
F P
0 g
s
.44003 .69919 m .44472 .68078 L .46609 .68976 L p .707 .577 .707 r
F P
0 g
s
.32826 .65141 m .32357 .66982 L .30112 .66775 L p .707 .577 .707 r
F P
0 g
s
.34324 .5962 m .34957 .63195 L .32571 .64271 L p .707 .577 .707 r
F P
0 g
s
.34957 .63195 m .34324 .5962 L .3723 .58748 L p .707 .577 .707 r
F P
0 g
s
.43442 .57925 m .44075 .61499 L .41005 .61738 L p .707 .577 .707 r
F P
0 g
s
.41005 .61738 m .40372 .58163 L .43442 .57925 L p .707 .577 .707 r
F P
0 g
s
.32357 .66982 m .32826 .65141 L .35623 .65615 L p .707 .577 .707 r
F P
0 g
s
.44472 .68078 m .44003 .69919 L .41276 .69001 L p .707 .577 .707 r
F P
0 g
s
.41276 .69001 m .41745 .6716 L .44472 .68078 L p .707 .577 .707 r
F P
0 g
s
.37863 .62322 m .3723 .58748 L .40372 .58163 L p .707 .577 .707 r
F P
0 g
s
.3723 .58748 m .37863 .62322 L .34957 .63195 L p .707 .577 .707 r
F P
0 g
s
.40372 .58163 m .41005 .61738 L .37863 .62322 L p .707 .577 .707 r
F P
0 g
s
.35623 .65615 m .35154 .67457 L .32357 .66982 L p .707 .577 .707 r
F P
0 g
s
.35154 .67457 m .35623 .65615 L .38696 .66311 L p .707 .577 .707 r
F P
0 g
s
.41745 .6716 m .41276 .69001 L .38227 .68153 L p .707 .577 .707 r
F P
0 g
s
.38227 .68153 m .38696 .66311 L .41745 .6716 L p .707 .577 .707 r
F P
0 g
s
.38696 .66311 m .38227 .68153 L .35154 .67457 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Pgoo6000PWoo001jOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP03FUH9001iOol007Aoo`H0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00D007Aoo`00L7oo1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF1000L7oo001/
Ool400000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH01000FUH00000KWoo001ZOol20005FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH01000FUIJEUYF0`00Jgoo001YOol20006FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH2001YOol006Moo`800003FUH005YF00EJEP03001JEUYF00QJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8006Qoo`00IWoo00D0
05YFFUIJEP0000IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0006Moo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YF
FUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Io
o`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF
00<005YFFUH00eYF2`001UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH015YF00<005YF00000`00
00=JEP00FUH01EYF00<005YFFUH010000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YFFUH00UYF1000
1UYF00<005YFFUH015YF00<005YFFUH00UYF100035YF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00@005YFFUH006Ioo`00IGoo00<005YFFUH00UYF00<005YF00000P0000=JEP00FUH0
1eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF000035YF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH01EYF00@005YFFUH006Ioo`00IGoo00@005YFFUIJEP<000EJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00aJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00EJEP04001JEUYF001VOol006Eoo`04001JEP000008FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<0
05YFFUH01EYF00@005YFFUH006Ioo`00IGoo0`002EYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH006Ioo`00Hgoo0P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH00UYF00<005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00@0
05YFFUH006Ioo`00HGoo0P001EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYF001VOol005moo`8000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYF001VOol005eoo`<000UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP03001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04
001JEUYF001VOol005aoo`05001JEUYFFUH00009FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEP00IWoo001JOol20004FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH00009FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP00IWoo001IOol00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000UJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001VOol005Qoo`8000MJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP`0009JEP03001JEP0000QJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF001VOol005Moo`04001JEUYF0007FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP050005FUH00`00FUIJEP02FUH400000eYF001J
EP07FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP00IWoo001FOol0
1@00FUIJEUYF00001eYF00<005YFFUH01eYF00<005YFFUH01EYF100015YF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH006Ioo`00EGoo00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00eYF0P0025YF00<005YFFUH00`001UYF00@005YFFUIJEP8000MJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP04001JEUYF001VOol005Aoo`03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEP00008000YJEP03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
001VOol005=oo`8000IJEP03001JEUYF00EJEP03001JEUYF00MJEP80009JEP03001JEUYF00QJEP80
00AJEP03001JEUYF00AJEP05001JEUYFFUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH01000FUIJEP00;7oo2`00;goo001COol00`00FUH00005FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20002FUH30009FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP009Goo1`00
0eYF00<005YFFUH00UYF0P0000=JEWooOol0;Goo001BOol01000FUIJEP001UYF00<005YFFUH01EYF
00<005YFFUH00UYF0P000eYF1@001UYF0`001eYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF000LOol90003FUH00`00FUIJ
EP04FUH500000eYF001JEP0_Ool0059oo`04001JEUYF0006FUH00`00FUIJEP06FUH01P00FUH00000
FUH000=JEPD000AJEP8000=JEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0007FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP004goo2@0015YF00<005YFFUH0
1EYF00<005YFFUH01@000UYF00D005YFFUH005YF02moo`00DWoo00D005YFFUIJEP0000IJEP03001J
EUYF00EJEP8000=JEP04001JEUYFFUH50002FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUH00008FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP003Goo
1P0015YF00<005YFFUH01UYF00<005YFFUH015YF100000=JEP00FUH015YF00D005YFFUIJEP0002mo
o`00@Goo20002Goo0P000UYF00<005YFFUH015YF00<005YFFUH00eYF0`0015YF00<005YFFUH00UYF
1P001eYF00<005YFFUH01EYF00<005YFFUH015YF0P0025YF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00@005YFFUH000Uoo`@00003FUH005YF00MJEP03001JEUYF00IJEPL000EJEP03
001JEUYF00=JEP04001JEUYFFUH2000^Ool003]oo`H000=JEP03001JEUYF009JEPL0009oo`80009J
EP03001JEUYF00AJEP04001JEUYFFUH20002Ool00`00FUIJEP02FUH00`00FUIJEP02FUH300000eYF
001JEP02FUH80006FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH01000FUIJEP001Goo10001EYF00<005YFFUH01UYF2P0015YF00<005YFFUH0
1EYF00<005YFFUH00UYF00@005YFFUIJEP8002ioo`00>Goo0P0000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH010000eYF00<005YFFUH015YF0`0017oo00<005YFFUH00UYF00<005YF00000P00
00=JEP0000001@0015YF00@005YFFUIJEPL000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF00H0009JEP03001JEUYF00EJEPT000AJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00=goo0P000eYF00<005YF
FUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<007ooOol017oo
00<005YF000020000UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH010002eYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF100000=JEP00FUH015YF200015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000eOol2
0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH0
0`00Ool0000700000eYF000000020006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH<0002FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEP00
FUH0;Woo000cOol30005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH0
1000FUIJEUYF0`000eYF00<005YF00000`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP800003FUH005YF00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool0035oo`80009JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP04001JEUYF
0004FUH40005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEP0025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP00FUH0
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00<7oo00<005YFFUH00UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0P0015YF00@005YF001JEP800003FUH0
05YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF008000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEUYFFUH0000^Ool0031oo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUH00002FUH00`00FUIJEP020003FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJ
EUYF00001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF0P0000=JEP00FUH00eYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00@005YFFUIJEP8002eoo`00;goo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF0P0000=JEP00FUH00P001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH01000FUIJEUYF0P00;Goo000_Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH2000015YF000000001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF
0000;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP07FUH01P00FUH00000FUH000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP0
00=JEP03001JEUYF00=JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00EJEP05001JEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Goo000^Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70003FUH20003FUH60003FUH00`00FUIJEP02
0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFFUH00P00;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH8
0004FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040006
FUH00`00FUH00002000:FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01@00;goo000^Ool20003FUH00`00FUIJ
EP03FUH60008Ool70006FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH50008FUH30002FUH0
0`00FUIJEP08FUH01000FUIJEUYF0P0000=JEP00FUH01EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01EYF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP03001JEUYF00IJEP03001JEUYF00AJEP@003Aoo`00;Woo0P000eYF00@005YFFUIJEP8001Eo
o`@0009JEP03001JEP0000AJEP03001JEUYF00EJEP03001JEUYF00@000AJEP@0009JEP<000EJEP03
001JEUYF00IJEP8000AJEP04001JEP000006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01000>7oo000]Ool00`00FUH00003FUH01000FUH000006goo0`0000=J
EP00FUH00eYF00<005YFFUH015YF1@001eYF1P0025YF00<005YFFUH015YF0P0000=JEP00FUH00eYF
00<005YFFUH00P001EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001J
EP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL003ao
o`00;Goo00<005YF00000eYF0P007goo00<005YF00001EYF00@005YFFUIJEP8000AJEP03001JEUYF
00EJEPD000UJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYF0005FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000AJEP03001JEUYF00=JEP03
001JEUYF00IJEP03001JEUYF00AJEPL004=oo`00;Goo0P000eYF00<007ooOol07goo00@005YFFUH0
00AJEP03001JEP00008000IJEP03001JEUYF00T000UJEP03001JEP00008000IJEP03001JEUYF009J
EP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00FUIJEP00
FUH000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@004Yoo`00;Goo0P0000=JEP00
00008Woo00@005YFFUH000AJEPl000AJEP<000QJEP@00003FUH005YF00IJEP03001JEUYF009JEP03
001JEP0000IJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP06001JEUYF001JEP00
15YF00<005YFFUH015YF00<005YFFUH00UYF1P0000=oo`0000006P00<Goo000]Ool4000SOol01000
FUIJEP000eYF00<005YFFUH015YF00@005YFFUH000AJEP03001JEUYF00AJEP04001JEUYFFUH50005
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP0J0004FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUH00002000^Ool002eoo`<00003FUH007oo01moo`T00003Ool005YF00AJEP04001JEUYF0004
FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP002Goo1`0015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;Goo00EJEP00FUIJEP0001Ioo`<000Ioo`8000=JEP04001JEUYFFUH80003FUH00`00FUIJEP02
FUH70006FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUIJEP000goo1P000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJ
EP8002eoo`00;7oo0`000eYF00<007ooOol04Woo1@001Goo0P000eYF00<005YFFUH015YF00@005YF
FUIJEPT000AJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP04001JEUYF0009FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool30003FUH3000BOol50004Ool20003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP040002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH3000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH000020004FUH0
0`00FUIJEP03FUH00`00FUIJEP080007FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Goo000/Ool00`00FUH00003FUH01000FUIJEP004Goo1@0017oo0P000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF100025YF00<005YFFUH01EYF00<005YF
FUH015YF0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF00D005YF001JEP00
00AJEP03001JEUYF00H000=JEP03001JEUYF009JEPT000MJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00;7oo00<005YF00000eYF00@005YFFUIJEP8000Mooa400004FUH005YF
FUH40003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000030004FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000AJEP<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH00003
FUH005YF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`03001JEP00009JEP03001J
EUYF00AJEPL000=JEP03001JEUYF00IJEP06001JEUYFFUH005YF0`0000AJEP00001JEPL000AJEP03
001JEUYF00MJEP03001JEUYF00AJEPD000QJEP04001JEP000003FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF0P000eYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01eYF00@005YF000000MJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002aoo`03001JEUYF009JEP04001JEUYFFUH400000eYF001JEP06FUH00`00FUIJEP06
FUH01000FUIJEUYF0P0015YF0P000UYF00<005YFFUH00eYF1`001eYF00<005YFFUH01UYF00@005YF
000000IJEP<000EJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP06001JEP00FUH005YF0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YFFUIJEP<000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`06001JEUYFFUH005YF
0P001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF0P000eYF
00<005YFFUH00UYF00<005YFFUH015YF10000UYF00<005YFFUH01eYF00@005YFFUIJEP<00003FUH0
000000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EP00009JEP8000EJEP03001JEUYF009JEPl000IJEP03001JEUYF00EJEP80009JEP03001JEUYF00=J
EP05001JEUYFFUH0000]Ool002eoo`04001JEUYFFUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP800003FUH005YF00=JEP03001JEUYF00AJEP04001J
EUYFFUH40007FUH00`00FUIJEP05FUH20009FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP0200000eYF001JEP04FUH50008FUH00`00FUIJEP02FUH6
0002FUH00`00FUIJEP06FUH>000]Ool002eoo`03001JEUYF00800003FUH005YF00EJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP@0009JEP03001JEUYF00EJEP03001JEUYF
00AJEP<000AJEP03001JEUYF00IJEP<000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEP0000=JEP04001JEUYFFUH20004FUH00`00FUIJEP02FUH90006
FUH40007FUH01000FUIJEP000eYF00L005YFFUIJEP00FUH0000]Ool002ioo`8000=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP8000EJEP03001JEP0000D000AJ
EP03001JEUYF009JEPP00003FUH005YF00MJEP03001JEUYF008000EJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000=JEP04001JEP000003FUH90008
FUH00`00FUIJEP06FUH30004FUH00`00FUIJEP02FUH200000eYF001JEP02FUH2000^Ool002ioo`80
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00800003FUH005YF00MJEPT0009JEPD00004FUH000000006FUH00`00FUIJEP03FUH20003FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30003FUH80007FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0300000eYF001JEP05FUH200000eYF0000000`Ool0
02ioo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<000MJEP03001JEUYF00AJEPP000EJEP@0009JEP03001JEUYF00AJEP<00003FUH0
05YF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP80009JEP@000EJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000IJEP<0039oo`00;Goo
00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0`0015YF00<005YFFUH01eYF00<005YFFUH0100025YF0`001UYF00<005YFFUH0
0P0035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF1@000UYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1@000eYF00@005YF
FUH0039oo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH00UYF4P0015YF00<005YF
FUH015YF00<005YFFUH00`0000=JEP00FUH025YF00<005YFFUH015YF1P000eYF00@005YF000000=J
EP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJ
EP800003FUH00000009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEQ8000Eoo`80
0003FUH005YF009JEP03001oogoo02moo`00;Goo0P000eYF00<005YFFUH00eYF1P0000=JEP00FUH0
1UYF00<005YFFUH01UYF1P001EYF00<005YFFUH00eYF10001UYF00<005YFFUH01eYF00@005YFFUIJ
EPT00003FUH005YF009JEP03001JEP0000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00EJEP800003FUH005YF01D001Uoo`8000AJEP03001oogoo02ioo`00;Goo0P000eYF00<005YF0000
0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH00eYF
00@005YFFUIJEP@0009JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001J
EP0000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00IJEP03
001JEUYF00=JEP06001JEUYFFUH005YF7Woo00D005YFFUIJEP00031oo`00;Goo0P000eYF0`0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH015YF
00D005YFFUIJEP0000=JEPD000IJEP03001JEUYF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH005YF00EJEP03001J
EUYF00AJEP04001JEUYFFUH2000OOol01000FUIJEP00<7oo000/Ool00`00FUH00002FUH01000Oomo
ogoo0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000EJEP05
001JEUYFFUH00004FUH01000FUIJEUYF10000UYF00<005YFFUH01EYF00<005YFFUH015YF00H005YF
FUH005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001UYF
00<005YFFUH00eYF00H005YFFUIJEP00FUH8Ool3000EOol01@00FUH005YF0000;goo000/Ool00`00
FUH000020005Ool20006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJ
EUYF0P000eYF00D005YFFUIJEP0000AJEP03001JEUYF00AJEPD000IJEP03001JEUYF00=JEP04001J
EUYFFUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01000FUH000001UYF
00<005YFFUH00eYF00@005YFFUIJEP8000Moo`D001Eoo`800003FUH007oo02ioo`00;7oo00D005YF
001JEP0000Moo`8000=JEP03001JEUYF00MJEP@000EJEP03001JEUYF00EJEP03001JEUYF00=JEP80
0003FUH005YF009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF009JEP@00003FUH005YF
00EJEP07001JEUYFFUH005YF000035YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01EYF
00D005YF001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH20007Ool5000FOol00`00FUH0000_
Ool002aoo`8000=JEP03001oogoo00Ioo`800003FUH005YF00QJEPD000AJEP03001JEUYF00EJEP03
001JEUYF00=JEP@000=JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEPl000aJEP03
001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00EJEP8000=JEP05001JEUYFFUH00006FUH00`00
FUIJEP020008Ool5000FOol00`00FUH0000_Ool002aoo`8000=JEP<000Qoo`<000MJEPH000=JEP03
001JEUYF00EJEP03001JEUYF00=JEP8000=oo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJ
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH20004FUH00`00FUH00006FUH01000FUIJEUYF0P002Goo0`0067oo0P00;goo000/Ool20003
FUH00`00FUIJEP020009Ool30004FUH60003FUH00`00FUIJEP05FUH00`00FUH000030006Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH20004FUH30006FUH01@00FUIJEUYF00009Goo
0P00;goo000/Ool20003FUH00`00FUIJEP02FUH30009Ool300000eYF001JEP030004FUH00`00FUIJ
EP02FUH50008Ool200000eYF00000004FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUH00003
FUH00`00FUIJEP020004FUH00`00FUIJEP02000UOol2000_Ool002aoo`8000=JEP03001JEUYF00=J
EP04001JEP00000:Ool?000;Ool20003FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP05FUH01P00
FUIJEP00FUH000AJEP<00003FUH005YF009JEP8002=oo`@002moo`00;Goo00@005YFFUH000IJEP04
001JEUYFFUH3000OOol200000eYF001JEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJEP08FUH0
0`00FUIJEP04FUHE0009FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP030006FUH30003
FUH00`00Oomoo`0POol20002FUH00`00Oomoo`0^Ool002eoo`04001JEUYF0006FUH00`00FUIJEP04
FUH5000HOol20003FUH01000FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01UYF2@000eYF
00<005YFFUH02UYF00<005YFFUH00UYF1P000eYF00<005YFFUH01eYF00<005YFFUH01EYF00H005YF
FUH005YF0006FUH00`00FUH00004000QOol01000FUIJEUYF0P00<7oo000^Ool00`00FUH00006FUH0
0`00FUIJEP05FUH01000FUIJEUYF2@002Woo1@001EYF00@005YFFUIJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00L000]JEP03001JEUYF00YJEP03001JEUYF00QJEPH000MJEP03001JEUYF00EJEP04
001JEUYF0002FUH20004FUH01000FUIJEUYF0`007goo0`000eYF00<007ooOol0;goo000^Ool00`00
FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH:0003FUH00`00FUIJEP04
FUH01000FUIJEUYF0P0015YF00<005YFFUH00eYF10001UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH00UYF1@000UYF00<005YFFUH01EYF00@005YFFUH000AJEP04001J
EUYF0007FUH4000IOol20002FUH01@00FUIJEUYF0000<Goo000_Ool20005FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2
0004FUH01000FUIJEUYF0`002EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF10001UYF00@005YFFUH000EJEP<000QJEP03001JEUYF00@0011oo`D000AJEP04001J
EUYF000bOol0031oo`03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00EJEPd000AJEP04001JEP000002FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP040002FUH00`00FUIJEP0:0007
FUH00`00FUIJEP04FUH@0003FUH00`00FUIJEP03FUH3000cOol0035oo`8000=JEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEPT000=JEP03001JEUYF00AJEP03001JEP0000AJEP8000AJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00AJEP<0009JEP03001JEP0000MJEP8000AJEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP8003Eoo`00<goo0P0000=JEP00FUH01UYF00<005YFFUH0
1UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00<005YF00000UYF0P001UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF00L005YF001JEP00FUH00007FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUH00003000gOol003Eoo`<000IJEPT000AJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00AJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EP00FUH00002FUH00`00FUIJEP05FUH01000FUIJEUYF1P0015YF00<005YFFUH01UYF00<005YFFUH0
15YF0`00>goo000hOol70003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP020002FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0000:0004FUH00`00FUIJEP04000nOol003=oo`D0
009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH50003FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF3P000eYF00@005YFFUH000Uo
o`L0049oo`00;Woo1@0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH00UYF1`000UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP00009JEP03001JEUYF009JEP<00003FUH005YF00@0009JEP80055oo`00;Woo00<005YF
00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF2@000UYF
00@005YFFUIJEPH000=JEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00
FUIJEP04FUH30002FUH00`00FUH0000200000eYF001oo`1@Ool002ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPT000=JEP03001JEUYF009JEPL000Eoo`05001J
EUYFFUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH0
0`0000AJEP00Oomoo`80055oo`00;Woo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF
20000eYF00<005YFFUH00UYF2@003Goo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0003
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002Ool01000FUH00000D7oo000_Ool20003FUH01000
FUIJEUYF20000UYF00<005YFFUH00UYF2@005goo0`001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0015YF00<005YF
FUH015YF00<005YFFUH00UYF0P000Woo00@005YFFUH0051oo`00;goo60008Woo0P001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH015YF0P001UYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001oo`80009JEP03001oogoo
04ioo`00;goo2@00<goo0P000eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P001eYF00<005YFFUH015YF00<005YFFUH0
0UYF0P0000Ioo`00FUH005YF001AOol006eoo`800003FUH005YF00QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP0000L000AJEP04001JEUYFFUH90000
0goo001JEP02FUH2001AOol006moo`@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00IJEPD000Moo`P000Uoo`03001JEUYF009JEP03001oogoo051oo`00Lgoo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01P0000=oo`000000
0`005Goo0`0015YF00<007ooOol0D7oo001hOol80006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH8
0007Ool5000COol20002FUH01@00FUIJEUYF0000Dgoo0020OolJ000?Ool5000AOol20005FUH00`00
FUH0001DOol0099oo`06001JEUYF001JEP004Woo0`0047oo0P001eYF0P00EGoo002BOol00`00FUIJ
EP02000TOol200000eYF001JEP06FUH00`00Oomoo`1DOol0099oo`04001JEUYF000ROol30004FUH0
0`00FUIJEP02FUH2001GOol009=oo`03001JEP0001moo`<000MJEP03001JEUYF008005Uoo`00Tgoo
0P0077oo100000=JEP00FUH025YF0P00Fgoo002COol3000FOol50006FUH00`00FUIJEP04FUH2001M
Ool009Aoo`03001JEP0000<000ioo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEP8005moo`00
U7oo00@005YFFUH0009JEPh000IJEP03001JEUYF00MJEP04001JEP00001QOol009Eoo`04001JEUYF
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH4001SOol009Eoo`04001JEUYF
0005FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04001WOol009Ioo`800003FUH005YF
00=JEP03001JEUYF00EJEP03001JEUYF00AJEPD006]oo`00V7oo10000eYF00<005YFFUH015YF00<0
05YFFUH01000L7oo002LOol=001dOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63519 .75166 m .61606 .70199 L .58608 .71303 L p .707 .577 .707 r
F P
0 g
s
.61606 .70199 m .63519 .75166 L .66268 .73747 L p .707 .577 .707 r
F P
0 g
s
.66268 .73747 m .64355 .6878 L .61606 .70199 L p .707 .577 .707 r
F P
0 g
s
.60521 .76271 m .58608 .71303 L .55655 .71985 L p .707 .577 .707 r
F P
0 g
s
.58608 .71303 m .60521 .76271 L .63519 .75166 L p .707 .577 .707 r
F P
0 g
s
.64355 .6878 m .66268 .73747 L .68499 .72152 L p .707 .577 .707 r
F P
0 g
s
.68499 .72152 m .66586 .67185 L .64355 .6878 L p .707 .577 .707 r
F P
0 g
s
.57568 .76952 m .55655 .71985 L .53036 .72177 L p .707 .577 .707 r
F P
0 g
s
.55655 .71985 m .57568 .76952 L .60521 .76271 L p .707 .577 .707 r
F P
0 g
s
.60205 .81688 m .5957 .78115 L .56494 .78364 L p .707 .577 .707 r
F P
0 g
s
.5957 .78115 m .60205 .81688 L .63344 .81093 L p .707 .577 .707 r
F P
0 g
s
.63344 .81093 m .62709 .7752 L .5957 .78115 L p .707 .577 .707 r
F P
0 g
s
.66586 .67185 m .68499 .72152 L .69994 .70537 L p .707 .577 .707 r
F P
0 g
s
.69994 .70537 m .68081 .6557 L .66586 .67185 L p .707 .577 .707 r
F P
0 g
s
.62709 .7752 m .63344 .81093 L .66239 .80211 L p .707 .577 .707 r
F P
0 g
s
.66239 .80211 m .65604 .76638 L .62709 .7752 L p .707 .577 .707 r
F P
0 g
s
.54949 .77144 m .53036 .72177 L .51007 .7186 L p .707 .577 .707 r
F P
0 g
s
.53036 .72177 m .54949 .77144 L .57568 .76952 L p .707 .577 .707 r
F P
0 g
s
.57402 .84091 m .57859 .82252 L .54871 .8138 L p .707 .577 .707 r
F P
0 g
s
.57859 .82252 m .57402 .84091 L .60505 .84817 L p .707 .577 .707 r
F P
0 g
s
.60505 .84817 m .60962 .82977 L .57859 .82252 L p .707 .577 .707 r
F P
0 g
s
.57129 .81937 m .56494 .78364 L .53782 .78243 L p .707 .577 .707 r
F P
0 g
s
.56494 .78364 m .57129 .81937 L .60205 .81688 L p .707 .577 .707 r
F P
0 g
s
.60962 .82977 m .60505 .84817 L .63418 .85325 L p .707 .577 .707 r
F P
0 g
s
.63418 .85325 m .63875 .83485 L .60962 .82977 L p .707 .577 .707 r
F P
0 g
s
.54871 .8138 m .54414 .8322 L .57402 .84091 L p .707 .577 .707 r
F P
0 g
s
.65604 .76638 m .66239 .80211 L .68607 .79127 L p .707 .577 .707 r
F P
0 g
s
.68607 .79127 m .67972 .75555 L .65604 .76638 L p .707 .577 .707 r
F P
0 g
s
.54414 .8322 m .54871 .8138 L .52289 .80448 L p .707 .577 .707 r
F P
0 g
s
.52289 .80448 m .51832 .82287 L .54414 .8322 L p .707 .577 .707 r
F P
0 g
s
.53782 .78243 m .54417 .81816 L .57129 .81937 L p .707 .577 .707 r
F P
0 g
s
.63875 .83485 m .63418 .85325 L .65857 .85566 L p .707 .577 .707 r
F P
0 g
s
.65857 .85566 m .66314 .83727 L .63875 .83485 L p .707 .577 .707 r
F P
0 g
s
.68081 .6557 m .69994 .70537 L .70606 .6906 L p .707 .577 .707 r
F P
0 g
s
.70606 .6906 m .68693 .64093 L .68081 .6557 L p .707 .577 .707 r
F P
0 g
s
.54417 .81816 m .53782 .78243 L .517 .77764 L p .707 .577 .707 r
F P
0 g
s
.51007 .7186 m .52919 .76827 L .54949 .77144 L p .707 .577 .707 r
F P
0 g
s
.52919 .76827 m .51007 .7186 L .49766 .71066 L p .707 .577 .707 r
F P
0 g
s
.67972 .75555 m .68607 .79127 L .70215 .77949 L p .707 .577 .707 r
F P
0 g
s
.70215 .77949 m .6958 .74376 L .67972 .75555 L p .707 .577 .707 r
F P
0 g
s
.51832 .82287 m .52289 .80448 L .50366 .79546 L p .707 .577 .707 r
F P
0 g
s
.50366 .79546 m .49909 .81386 L .51832 .82287 L p .707 .577 .707 r
F P
0 g
s
.517 .77764 m .52335 .81336 L .54417 .81816 L p .707 .577 .707 r
F P
0 g
s
.66314 .83727 m .65857 .85566 L .67582 .85517 L p .707 .577 .707 r
F P
0 g
s
.67582 .85517 m .68039 .83678 L .66314 .83727 L p .707 .577 .707 r
F P
0 g
s
.52335 .81336 m .517 .77764 L .50452 .76973 L p .707 .577 .707 r
F P
0 g
s
.68693 .64093 m .70606 .6906 L .70276 .67866 L p .707 .577 .707 r
F P
0 g
s
.70276 .67866 m .68363 .62899 L .68693 .64093 L p .707 .577 .707 r
F P
0 g
s
.49766 .71066 m .51679 .76033 L .52919 .76827 L p .707 .577 .707 r
F P
0 g
s
.49909 .81386 m .50366 .79546 L .49292 .78763 L p .707 .577 .707 r
F P
0 g
s
.6958 .74376 m .70215 .77949 L .70907 .76791 L p .707 .577 .707 r
F P
0 g
s
.70907 .76791 m .70272 .73218 L .6958 .74376 L p .707 .577 .707 r
F P
0 g
s
.49292 .78763 m .48835 .80603 L .49909 .81386 L p .707 .577 .707 r
F P
0 g
s
.51679 .76033 m .49766 .71066 L .49436 .69872 L p .707 .577 .707 r
F P
0 g
s
.50452 .76973 m .51087 .80546 L .52335 .81336 L p .707 .577 .707 r
F P
0 g
s
.68039 .83678 m .67582 .85517 L .68425 .85183 L p .707 .577 .707 r
F P
0 g
s
.68425 .85183 m .68882 .83343 L .68039 .83678 L p .707 .577 .707 r
F P
0 g
s
.51087 .80546 m .50452 .76973 L .50159 .75949 L p .707 .577 .707 r
F P
0 g
s
.49436 .69872 m .51349 .74839 L .51679 .76033 L p .707 .577 .707 r
F P
0 g
s
.51349 .74839 m .49436 .69872 L .50048 .68395 L p .707 .577 .707 r
F P
0 g
s
.50159 .75949 m .50794 .79521 L .51087 .80546 L p .707 .577 .707 r
F P
0 g
s
.50794 .79521 m .50159 .75949 L .50851 .7479 L p .707 .577 .707 r
F P
0 g
s
.50048 .68395 m .51961 .73362 L .51349 .74839 L p .707 .577 .707 r
F P
0 g
s
.51961 .73362 m .50048 .68395 L .51543 .6678 L p .707 .577 .707 r
F P
0 g
s
.50851 .7479 m .51486 .78363 L .50794 .79521 L p .707 .577 .707 r
F P
0 g
s
.51486 .78363 m .50851 .7479 L .52459 .73612 L p .707 .577 .707 r
F P
0 g
s
.52459 .73612 m .53094 .77184 L .51486 .78363 L p .707 .577 .707 r
F P
0 g
s
.49556 .7968 m .50013 .77841 L .51738 .77792 L p .707 .577 .707 r
F P
0 g
s
.51738 .77792 m .51281 .79631 L .49556 .7968 L p .707 .577 .707 r
F P
0 g
s
.50702 .82188 m .50702 .31999 L .46216 .31868 L p .707 .577 .707 r
F P
0 g
s
.51543 .6678 m .53456 .71747 L .51961 .73362 L p .707 .577 .707 r
F P
0 g
s
.53456 .71747 m .51543 .6678 L .53774 .65185 L p .707 .577 .707 r
F P
0 g
s
.53774 .65185 m .55687 .70152 L .53456 .71747 L p .707 .577 .707 r
F P
0 g
s
.53094 .77184 m .52459 .73612 L .54827 .72528 L p .707 .577 .707 r
F P
0 g
s
.51281 .79631 m .51738 .77792 L .54176 .78033 L p .707 .577 .707 r
F P
0 g
s
.54827 .72528 m .55462 .76101 L .53094 .77184 L p .707 .577 .707 r
F P
0 g
s
.54176 .78033 m .53719 .79873 L .51281 .79631 L p .707 .577 .707 r
F P
0 g
s
.53719 .79873 m .54176 .78033 L .57089 .78542 L p .707 .577 .707 r
F P
0 g
s
.57089 .78542 m .56632 .80381 L .53719 .79873 L p .707 .577 .707 r
F P
0 g
s
.50702 .31999 m .50702 .82188 L .5512 .8194 L p .707 .577 .707 r
F P
0 g
s
.55687 .70152 m .53774 .65185 L .56523 .63765 L p .707 .577 .707 r
F P
0 g
s
.55462 .76101 m .54827 .72528 L .57722 .71646 L p .707 .577 .707 r
F P
0 g
s
.5512 .8194 m .5512 .31751 L .50702 .31999 L p .707 .577 .707 r
F P
0 g
s
.68363 .62899 m .70276 .67866 L .69035 .67072 L p .707 .577 .707 r
F P
0 g
s
.69035 .67072 m .67123 .62105 L .68363 .62899 L p .707 .577 .707 r
F P
0 g
s
.46216 .82057 m .46216 .31868 L .421 .31371 L p .707 .577 .707 r
F P
0 g
s
.48835 .80603 m .49292 .78763 L .4917 .78176 L p .707 .577 .707 r
F P
0 g
s
.4917 .78176 m .48713 .80015 L .48835 .80603 L p .707 .577 .707 r
F P
0 g
s
.48713 .80015 m .4917 .78176 L .50013 .77841 L p .707 .577 .707 r
F P
0 g
s
.50013 .77841 m .49556 .7968 L .48713 .80015 L p .707 .577 .707 r
F P
0 g
s
.46216 .31868 m .46216 .82057 L .50702 .82188 L p .707 .577 .707 r
F P
0 g
s
.70272 .73218 m .70907 .76791 L .70614 .75766 L p .707 .577 .707 r
F P
0 g
s
.70614 .75766 m .69979 .72193 L .70272 .73218 L p .707 .577 .707 r
F P
0 g
s
.58436 .68733 m .56523 .63765 L .59521 .62661 L p .707 .577 .707 r
F P
0 g
s
.56523 .63765 m .58436 .68733 L .55687 .70152 L p .707 .577 .707 r
F P
0 g
s
.58357 .75219 m .57722 .71646 L .60861 .71051 L p .707 .577 .707 r
F P
0 g
s
.57722 .71646 m .58357 .75219 L .55462 .76101 L p .707 .577 .707 r
F P
0 g
s
.60861 .71051 m .61496 .74624 L .58357 .75219 L p .707 .577 .707 r
F P
0 g
s
.56632 .80381 m .57089 .78542 L .60192 .79267 L p .707 .577 .707 r
F P
0 g
s
.60192 .79267 m .59735 .81106 L .56632 .80381 L p .707 .577 .707 r
F P
0 g
s
.5512 .31751 m .5512 .8194 L .59037 .81339 L p .707 .577 .707 r
F P
0 g
s
.59521 .62661 m .61433 .67628 L .58436 .68733 L p .707 .577 .707 r
F P
0 g
s
.59037 .81339 m .59037 .3115 L .5512 .31751 L p .707 .577 .707 r
F P
0 g
s
.421 .8156 m .421 .31371 L .38757 .30558 L p .707 .577 .707 r
F P
0 g
s
.421 .31371 m .421 .8156 L .46216 .82057 L p .707 .577 .707 r
F P
0 g
s
.68882 .83343 m .68425 .85183 L .68303 .84595 L p .707 .577 .707 r
F P
0 g
s
.68303 .84595 m .6876 .82755 L .68882 .83343 L p .707 .577 .707 r
F P
0 g
s
.61433 .67628 m .59521 .62661 L .62474 .6198 L p .707 .577 .707 r
F P
0 g
s
.63937 .70802 m .64572 .74375 L .61496 .74624 L p .707 .577 .707 r
F P
0 g
s
.61496 .74624 m .60861 .71051 L .63937 .70802 L p .707 .577 .707 r
F P
0 g
s
.63181 .80138 m .62724 .81978 L .59735 .81106 L p .707 .577 .707 r
F P
0 g
s
.59735 .81106 m .60192 .79267 L .63181 .80138 L p .707 .577 .707 r
F P
0 g
s
.59037 .3115 m .59037 .81339 L .62069 .80442 L p .707 .577 .707 r
F P
0 g
s
.62474 .6198 m .64387 .66947 L .61433 .67628 L p .707 .577 .707 r
F P
0 g
s
.62069 .80442 m .62069 .30253 L .59037 .3115 L p .707 .577 .707 r
F P
0 g
s
.67123 .62105 m .69035 .67072 L .67006 .66755 L p .707 .577 .707 r
F P
0 g
s
.67006 .66755 m .65093 .61788 L .67123 .62105 L p .707 .577 .707 r
F P
0 g
s
.22038 .62805 m .22891 .68503 L .25998 .68006 L p .707 .577 .707 r
F P
0 g
s
.25998 .68006 m .25144 .62308 L .22038 .62805 L p .707 .577 .707 r
F P
0 g
s
.25144 .62308 m .25998 .68006 L .29134 .6756 L p .707 .577 .707 r
F P
0 g
s
.69979 .72193 m .70614 .75766 L .69366 .74975 L p .707 .577 .707 r
F P
0 g
s
.69366 .74975 m .68731 .71403 L .69979 .72193 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.29134 .6756 m .2828 .61862 L .25144 .62308 L p .707 .577 .707 r
F P
0 g
s
.2828 .61862 m .29134 .6756 L .31993 .67209 L p .707 .577 .707 r
F P
0 g
s
.19265 .63305 m .20119 .69003 L .22891 .68503 L p .707 .577 .707 r
F P
0 g
s
.22891 .68503 m .22038 .62805 L .19265 .63305 L p .707 .577 .707 r
F P
0 g
s
.31993 .67209 m .31139 .61512 L .2828 .61862 L p .707 .577 .707 r
F P
0 g
s
.25623 .75818 m .25348 .72003 L .22234 .72151 L p .707 .577 .707 r
F P
0 g
s
.25348 .72003 m .25623 .75818 L .28797 .75559 L p .707 .577 .707 r
F P
0 g
s
.28797 .75559 m .28522 .71744 L .25348 .72003 L p .707 .577 .707 r
F P
0 g
s
.38757 .80747 m .38757 .30558 L .36515 .29507 L p .707 .577 .707 r
F P
0 g
s
.38757 .30558 m .38757 .80747 L .421 .8156 L p .707 .577 .707 r
F P
0 g
s
.28522 .71744 m .28797 .75559 L .31719 .75215 L p .707 .577 .707 r
F P
0 g
s
.31719 .75215 m .31444 .714 L .28522 .71744 L p .707 .577 .707 r
F P
0 g
s
.31139 .61512 m .31993 .67209 L .34294 .66987 L p .707 .577 .707 r
F P
0 g
s
.6876 .82755 m .68303 .84595 L .67228 .83812 L p .707 .577 .707 r
F P
0 g
s
.67228 .83812 m .67685 .81972 L .6876 .82755 L p .707 .577 .707 r
F P
0 g
s
.22234 .72151 m .22509 .75966 L .25623 .75818 L p .707 .577 .707 r
F P
0 g
s
.65093 .61788 m .67006 .66755 L .64387 .66947 L p .707 .577 .707 r
F P
0 g
s
.64387 .66947 m .62474 .6198 L .65093 .61788 L p .707 .577 .707 r
F P
0 g
s
.17098 .63759 m .17951 .69456 L .20119 .69003 L p .707 .577 .707 r
F P
0 g
s
.20119 .69003 m .19265 .63305 L .17098 .63759 L p .707 .577 .707 r
F P
0 g
s
.34294 .66987 m .3344 .6129 L .31139 .61512 L p .707 .577 .707 r
F P
0 g
s
.22509 .75966 m .22234 .72151 L .19485 .72175 L p .707 .577 .707 r
F P
0 g
s
.19485 .72175 m .1976 .7599 L .22509 .75966 L p .707 .577 .707 r
F P
0 g
s
.62069 .30253 m .62069 .80442 L .63919 .79337 L p .707 .577 .707 r
F P
0 g
s
.63919 .79337 m .63919 .29148 L .62069 .30253 L p .707 .577 .707 r
F P
0 g
s
.68731 .71403 m .69366 .74975 L .67284 .74496 L p .707 .577 .707 r
F P
0 g
s
.67284 .74496 m .66649 .70923 L .68731 .71403 L p .707 .577 .707 r
F P
0 g
s
.31444 .714 m .31719 .75215 L .34104 .74819 L p .707 .577 .707 r
F P
0 g
s
.34104 .74819 m .33829 .71004 L .31444 .714 L p .707 .577 .707 r
F P
0 g
s
.1976 .7599 m .19485 .72175 L .17369 .72071 L p .707 .577 .707 r
F P
0 g
s
.3344 .6129 m .34294 .66987 L .35813 .66917 L p .707 .577 .707 r
F P
0 g
s
.17369 .72071 m .17643 .75886 L .1976 .7599 L p .707 .577 .707 r
F P
0 g
s
.35813 .66917 m .34959 .61219 L .3344 .6129 L p .707 .577 .707 r
F P
0 g
s
.15747 .64121 m .16601 .69819 L .17951 .69456 L p .707 .577 .707 r
F P
0 g
s
.17951 .69456 m .17098 .63759 L .15747 .64121 L p .707 .577 .707 r
F P
0 g
s
.67685 .81972 m .67228 .83812 L .65305 .8291 L p .707 .577 .707 r
F P
0 g
s
.65305 .8291 m .65762 .81071 L .67685 .81972 L p .707 .577 .707 r
F P
0 g
s
.33829 .71004 m .34104 .74819 L .35718 .7441 L p .707 .577 .707 r
F P
0 g
s
.35718 .7441 m .35443 .70595 L .33829 .71004 L p .707 .577 .707 r
F P
0 g
s
.66649 .70923 m .67284 .74496 L .64572 .74375 L p .707 .577 .707 r
F P
0 g
s
.64572 .74375 m .63937 .70802 L .66649 .70923 L p .707 .577 .707 r
F P
0 g
s
.34959 .61219 m .35813 .66917 L .36401 .67004 L p .707 .577 .707 r
F P
0 g
s
.36401 .67004 m .35547 .61307 L .34959 .61219 L p .707 .577 .707 r
F P
0 g
s
.35547 .61307 m .36401 .67004 L .36 .67241 L p .707 .577 .707 r
F P
0 g
s
.36515 .79696 m .36515 .29507 L .35592 .28321 L p .707 .577 .707 r
F P
0 g
s
.36515 .29507 m .36515 .79696 L .38757 .80747 L p .707 .577 .707 r
F P
0 g
s
.24167 .83226 m .24362 .81568 L .21292 .8088 L p .707 .577 .707 r
F P
0 g
s
.24362 .81568 m .24167 .83226 L .27343 .83427 L p .707 .577 .707 r
F P
0 g
s
.27343 .83427 m .27538 .81769 L .24362 .81568 L p .707 .577 .707 r
F P
0 g
s
.27538 .81769 m .27343 .83427 L .30314 .83123 L p .707 .577 .707 r
F P
0 g
s
.30314 .83123 m .3051 .81464 L .27538 .81769 L p .707 .577 .707 r
F P
0 g
s
.21097 .82538 m .21292 .8088 L .18629 .79772 L p .707 .577 .707 r
F P
0 g
s
.21292 .8088 m .21097 .82538 L .24167 .83226 L p .707 .577 .707 r
F P
0 g
s
.17643 .75886 m .17369 .72071 L .16093 .7185 L p .707 .577 .707 r
F P
0 g
s
.16093 .7185 m .16368 .75665 L .17643 .75886 L p .707 .577 .707 r
F P
0 g
s
.63919 .29148 m .63919 .79337 L .64407 .78133 L p .707 .577 .707 r
F P
0 g
s
.64407 .78133 m .64407 .27944 L .63919 .29148 L p .707 .577 .707 r
F P
0 g
s
.3051 .81464 m .30314 .83123 L .3279 .82341 L p .707 .577 .707 r
F P
0 g
s
.3279 .82341 m .32986 .80683 L .3051 .81464 L p .707 .577 .707 r
F P
0 g
s
.18629 .79772 m .18433 .8143 L .21097 .82538 L p .707 .577 .707 r
F P
0 g
s
.65762 .81071 m .65305 .8291 L .62724 .81978 L p .707 .577 .707 r
F P
0 g
s
.62724 .81978 m .63181 .80138 L .65762 .81071 L p .707 .577 .707 r
F P
0 g
s
.15347 .64358 m .162 .70056 L .16601 .69819 L p .707 .577 .707 r
F P
0 g
s
.16601 .69819 m .15747 .64121 L .15347 .64358 L p .707 .577 .707 r
F P
0 g
s
.18433 .8143 m .18629 .79772 L .16633 .78354 L p .707 .577 .707 r
F P
0 g
s
.35443 .70595 m .35718 .7441 L .36404 .74029 L p .707 .577 .707 r
F P
0 g
s
.36404 .74029 m .36129 .70214 L .35443 .70595 L p .707 .577 .707 r
F P
0 g
s
.16633 .78354 m .16438 .80012 L .18433 .8143 L p .707 .577 .707 r
F P
0 g
s
.32986 .80683 m .3279 .82341 L .34528 .8116 L p .707 .577 .707 r
F P
0 g
s
.34528 .8116 m .34724 .79501 L .32986 .80683 L p .707 .577 .707 r
F P
0 g
s
.16368 .75665 m .16093 .7185 L .15783 .71533 L p .707 .577 .707 r
F P
0 g
s
.15783 .71533 m .16058 .75348 L .16368 .75665 L p .707 .577 .707 r
F P
0 g
s
.16438 .80012 m .16633 .78354 L .155 .76763 L p .707 .577 .707 r
F P
0 g
s
.36 .67241 m .35147 .61543 L .35547 .61307 L p .707 .577 .707 r
F P
0 g
s
.36129 .70214 m .36404 .74029 L .36094 .73712 L p .707 .577 .707 r
F P
0 g
s
.36094 .73712 m .35819 .69898 L .36129 .70214 L p .707 .577 .707 r
F P
0 g
s
.35147 .61543 m .36 .67241 L .3465 .67604 L p .707 .577 .707 r
F P
0 g
s
.35819 .69898 m .36094 .73712 L .34818 .73491 L p .707 .577 .707 r
F P
0 g
s
.34818 .73491 m .34543 .69676 L .35819 .69898 L p .707 .577 .707 r
F P
0 g
s
.35592 .28321 m .35592 .7851 L .36515 .79696 L p .707 .577 .707 r
F P
0 g
s
.35592 .7851 m .35592 .28321 L .36081 .27118 L p .707 .577 .707 r
F P
0 g
s
.15935 .64445 m .16788 .70143 L .162 .70056 L p .707 .577 .707 r
F P
0 g
s
.162 .70056 m .15347 .64358 L .15935 .64445 L p .707 .577 .707 r
F P
0 g
s
.155 .76763 m .15305 .78422 L .16438 .80012 L p .707 .577 .707 r
F P
0 g
s
.64407 .27944 m .64407 .78133 L .63485 .76948 L p .707 .577 .707 r
F P
0 g
s
.63485 .76948 m .63485 .26759 L .64407 .27944 L p .707 .577 .707 r
F P
0 g
s
.34724 .79501 m .34528 .8116 L .35358 .79694 L p .707 .577 .707 r
F P
0 g
s
.35358 .79694 m .35553 .78036 L .34724 .79501 L p .707 .577 .707 r
F P
0 g
s
.15305 .78422 m .155 .76763 L .15341 .75157 L p .707 .577 .707 r
F P
0 g
s
.16058 .75348 m .15783 .71533 L .16468 .71152 L p .707 .577 .707 r
F P
0 g
s
.16468 .71152 m .16743 .74967 L .16058 .75348 L p .707 .577 .707 r
F P
0 g
s
.15341 .75157 m .15145 .76815 L .15305 .78422 L p .707 .577 .707 r
F P
0 g
s
.3465 .67604 m .33796 .61906 L .35147 .61543 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17454 .64375 m .18307 .70072 L .16788 .70143 L p .707 .577 .707 r
F P
0 g
s
.16788 .70143 m .15935 .64445 L .17454 .64375 L p .707 .577 .707 r
F P
0 g
s
.36081 .77306 m .36081 .27118 L .37931 .26013 L p .707 .577 .707 r
F P
0 g
s
.36081 .27118 m .36081 .77306 L .35592 .7851 L p .707 .577 .707 r
F P
0 g
s
.35553 .78036 m .35358 .79694 L .35199 .78087 L p .707 .577 .707 r
F P
0 g
s
.35199 .78087 m .35394 .76429 L .35553 .78036 L p .707 .577 .707 r
F P
0 g
s
.15145 .76815 m .15341 .75157 L .16171 .73691 L p .707 .577 .707 r
F P
0 g
s
.63485 .26759 m .63485 .76948 L .61243 .75897 L p .707 .577 .707 r
F P
0 g
s
.61243 .75897 m .61243 .25708 L .63485 .26759 L p .707 .577 .707 r
F P
0 g
s
.16743 .74967 m .16468 .71152 L .18083 .70744 L p .707 .577 .707 r
F P
0 g
s
.18083 .70744 m .18358 .74558 L .16743 .74967 L p .707 .577 .707 r
F P
0 g
s
.16171 .73691 m .15975 .75349 L .15145 .76815 L p .707 .577 .707 r
F P
0 g
s
.33796 .61906 m .3465 .67604 L .32483 .68057 L p .707 .577 .707 r
F P
0 g
s
.32483 .68057 m .31629 .6236 L .33796 .61906 L p .707 .577 .707 r
F P
0 g
s
.19755 .64153 m .20609 .69851 L .18307 .70072 L p .707 .577 .707 r
F P
0 g
s
.18307 .70072 m .17454 .64375 L .19755 .64153 L p .707 .577 .707 r
F P
0 g
s
.35394 .76429 m .35199 .78087 L .34066 .76497 L p .707 .577 .707 r
F P
0 g
s
.34066 .76497 m .34261 .74838 L .35394 .76429 L p .707 .577 .707 r
F P
0 g
s
.34543 .69676 m .34818 .73491 L .32702 .73387 L p .707 .577 .707 r
F P
0 g
s
.32702 .73387 m .32427 .69572 L .34543 .69676 L p .707 .577 .707 r
F P
0 g
s
.15975 .75349 m .16171 .73691 L .17909 .72509 L p .707 .577 .707 r
F P
0 g
s
.37931 .26013 m .37931 .76202 L .36081 .77306 L p .707 .577 .707 r
F P
0 g
s
.37931 .76202 m .37931 .26013 L .40963 .25116 L p .707 .577 .707 r
F P
0 g
s
.18358 .74558 m .18083 .70744 L .20468 .70348 L p .707 .577 .707 r
F P
0 g
s
.31629 .6236 m .32483 .68057 L .2971 .68557 L p .707 .577 .707 r
F P
0 g
s
.20468 .70348 m .20743 .74163 L .18358 .74558 L p .707 .577 .707 r
F P
0 g
s
.17909 .72509 m .17713 .74168 L .15975 .75349 L p .707 .577 .707 r
F P
0 g
s
.22614 .63803 m .23468 .695 L .20609 .69851 L p .707 .577 .707 r
F P
0 g
s
.20609 .69851 m .19755 .64153 L .22614 .63803 L p .707 .577 .707 r
F P
0 g
s
.2971 .68557 m .28856 .6286 L .31629 .6236 L p .707 .577 .707 r
F P
0 g
s
.61243 .25708 m .61243 .75897 L .579 .75083 L p .707 .577 .707 r
F P
0 g
s
.579 .75083 m .579 .24895 L .61243 .25708 L p .707 .577 .707 r
F P
0 g
s
.34261 .74838 m .34066 .76497 L .3207 .75078 L p .707 .577 .707 r
F P
0 g
s
.3207 .75078 m .32265 .7342 L .34261 .74838 L p .707 .577 .707 r
F P
0 g
s
.32427 .69572 m .32702 .73387 L .29952 .73411 L p .707 .577 .707 r
F P
0 g
s
.29952 .73411 m .29677 .69596 L .32427 .69572 L p .707 .577 .707 r
F P
0 g
s
.73396 .68381 m .7425 .63669 L .71143 .6295 L p .707 .577 .707 r
F P
0 g
s
.7425 .63669 m .73396 .68381 L .76532 .6854 L p .707 .577 .707 r
F P
0 g
s
.76532 .6854 m .77386 .63828 L .7425 .63669 L p .707 .577 .707 r
F P
0 g
s
.7029 .67662 m .71143 .6295 L .68371 .61741 L p .707 .577 .707 r
F P
0 g
s
.71143 .6295 m .7029 .67662 L .73396 .68381 L p .707 .577 .707 r
F P
0 g
s
.28856 .6286 m .2971 .68557 L .26604 .69054 L p .707 .577 .707 r
F P
0 g
s
.2575 .63357 m .26604 .69054 L .23468 .695 L p .707 .577 .707 r
F P
0 g
s
.23468 .695 m .22614 .63803 L .2575 .63357 L p .707 .577 .707 r
F P
0 g
s
.17713 .74168 m .17909 .72509 L .20385 .71728 L p .707 .577 .707 r
F P
0 g
s
.26604 .69054 m .2575 .63357 L .28856 .6286 L p .707 .577 .707 r
F P
0 g
s
.77386 .63828 m .76532 .6854 L .79391 .68123 L p .707 .577 .707 r
F P
0 g
s
.79391 .68123 m .80245 .63411 L .77386 .63828 L p .707 .577 .707 r
F P
0 g
s
.20743 .74163 m .20468 .70348 L .2339 .70004 L p .707 .577 .707 r
F P
0 g
s
.2339 .70004 m .23665 .73818 L .20743 .74163 L p .707 .577 .707 r
F P
0 g
s
.67517 .66453 m .68371 .61741 L .66203 .60161 L p .707 .577 .707 r
F P
0 g
s
.68371 .61741 m .67517 .66453 L .7029 .67662 L p .707 .577 .707 r
F P
0 g
s
.20385 .71728 m .20189 .73386 L .17713 .74168 L p .707 .577 .707 r
F P
0 g
s
.29677 .69596 m .29952 .73411 L .26838 .73559 L p .707 .577 .707 r
F P
0 g
s
.26838 .73559 m .26563 .69744 L .29677 .69596 L p .707 .577 .707 r
F P
0 g
s
.40963 .75305 m .40963 .25116 L .4488 .24514 L p .707 .577 .707 r
F P
0 g
s
.40963 .25116 m .40963 .75305 L .37931 .76202 L p .707 .577 .707 r
F P
0 g
s
.32265 .7342 m .3207 .75078 L .29406 .73971 L p .707 .577 .707 r
F P
0 g
s
.29406 .73971 m .29602 .72313 L .32265 .7342 L p .707 .577 .707 r
F P
0 g
s
.23665 .73818 m .2339 .70004 L .26563 .69744 L p .707 .577 .707 r
F P
0 g
s
.80245 .63411 m .79391 .68123 L .81692 .67172 L p .707 .577 .707 r
F P
0 g
s
.81692 .67172 m .82546 .62459 L .80245 .63411 L p .707 .577 .707 r
F P
0 g
s
.73663 .73985 m .73468 .72072 L .70398 .72369 L p .707 .577 .707 r
F P
0 g
s
.73468 .72072 m .73663 .73985 L .76839 .73657 L p .707 .577 .707 r
F P
0 g
s
.76839 .73657 m .76644 .71744 L .73468 .72072 L p .707 .577 .707 r
F P
0 g
s
.70398 .72369 m .70593 .74282 L .73663 .73985 L p .707 .577 .707 r
F P
0 g
s
.26563 .69744 m .26838 .73559 L .23665 .73818 L p .707 .577 .707 r
F P
0 g
s
.76644 .71744 m .76839 .73657 L .79811 .7333 L p .707 .577 .707 r
F P
0 g
s
.79811 .7333 m .79615 .71417 L .76644 .71744 L p .707 .577 .707 r
F P
0 g
s
.20189 .73386 m .20385 .71728 L .23356 .71423 L p .707 .577 .707 r
F P
0 g
s
.579 .24895 m .579 .75083 L .53784 .74587 L p .707 .577 .707 r
F P
0 g
s
.53784 .74587 m .53784 .24398 L .579 .24895 L p .707 .577 .707 r
F P
0 g
s
.73162 .73141 m .73436 .69664 L .70322 .69171 L p .707 .577 .707 r
F P
0 g
s
.73436 .69664 m .73162 .73141 L .76335 .73215 L p .707 .577 .707 r
F P
0 g
s
.76335 .73215 m .7661 .69738 L .73436 .69664 L p .707 .577 .707 r
F P
0 g
s
.7661 .69738 m .76335 .73215 L .79257 .72864 L p .707 .577 .707 r
F P
0 g
s
.79257 .72864 m .79532 .69387 L .7661 .69738 L p .707 .577 .707 r
F P
0 g
s
.70593 .74282 m .70398 .72369 L .67734 .72604 L p .707 .577 .707 r
F P
0 g
s
.70048 .72648 m .70322 .69171 L .67573 .68308 L p .707 .577 .707 r
F P
0 g
s
.70322 .69171 m .70048 .72648 L .73162 .73141 L p .707 .577 .707 r
F P
0 g
s
.67734 .72604 m .6793 .74517 L .70593 .74282 L p .707 .577 .707 r
F P
0 g
s
.6535 .64873 m .66203 .60161 L .64853 .58364 L p .707 .577 .707 r
F P
0 g
s
.66203 .60161 m .6535 .64873 L .67517 .66453 L p .707 .577 .707 r
F P
0 g
s
.29602 .72313 m .29406 .73971 L .26337 .73283 L p .707 .577 .707 r
F P
0 g
s
.26337 .73283 m .26532 .71625 L .29602 .72313 L p .707 .577 .707 r
F P
0 g
s
.23356 .71423 m .2316 .73081 L .20189 .73386 L p .707 .577 .707 r
F P
0 g
s
.79615 .71417 m .79811 .7333 L .82287 .73034 L p .707 .577 .707 r
F P
0 g
s
.82287 .73034 m .82091 .71121 L .79615 .71417 L p .707 .577 .707 r
F P
0 g
s
.2316 .73081 m .23356 .71423 L .26532 .71625 L p .707 .577 .707 r
F P
0 g
s
.26532 .71625 m .26337 .73283 L .2316 .73081 L p .707 .577 .707 r
F P
0 g
s
.4488 .74703 m .4488 .24514 L .49298 .24267 L p .707 .577 .707 r
F P
0 g
s
.4488 .24514 m .4488 .74703 L .40963 .75305 L p .707 .577 .707 r
F P
0 g
s
.82546 .62459 m .81692 .67172 L .83212 .65779 L p .707 .577 .707 r
F P
0 g
s
.83212 .65779 m .84065 .61066 L .82546 .62459 L p .707 .577 .707 r
F P
0 g
s
.79532 .69387 m .79257 .72864 L .81642 .72121 L p .707 .577 .707 r
F P
0 g
s
.81642 .72121 m .81917 .68645 L .79532 .69387 L p .707 .577 .707 r
F P
0 g
s
.53784 .24398 m .53784 .74587 L .49298 .74456 L p .707 .577 .707 r
F P
0 g
s
.49298 .74456 m .49298 .24267 L .53784 .24398 L p .707 .577 .707 r
F P
0 g
s
.67298 .71785 m .67573 .68308 L .65456 .6716 L p .707 .577 .707 r
F P
0 g
s
.67573 .68308 m .67298 .71785 L .70048 .72648 L p .707 .577 .707 r
F P
0 g
s
.49298 .24267 m .49298 .74456 L .4488 .74703 L p .707 .577 .707 r
F P
0 g
s
.6793 .74517 m .67734 .72604 L .65739 .72756 L p .707 .577 .707 r
F P
0 g
s
.65739 .72756 m .65934 .74669 L .6793 .74517 L p .707 .577 .707 r
F P
0 g
s
.63999 .63077 m .64853 .58364 L .64452 .56526 L p .707 .577 .707 r
F P
0 g
s
.64853 .58364 m .63999 .63077 L .6535 .64873 L p .707 .577 .707 r
F P
0 g
s
.82091 .71121 m .82287 .73034 L .84025 .728 L p .707 .577 .707 r
F P
0 g
s
.84025 .728 m .83829 .70887 L .82091 .71121 L p .707 .577 .707 r
F P
0 g
s
.65456 .6716 m .65182 .70636 L .67298 .71785 L p .707 .577 .707 r
F P
0 g
s
.81917 .68645 m .81642 .72121 L .83257 .7106 L p .707 .577 .707 r
F P
0 g
s
.83257 .7106 m .83531 .67584 L .81917 .68645 L p .707 .577 .707 r
F P
0 g
s
.84065 .61066 m .83212 .65779 L .838 .6408 L p .707 .577 .707 r
F P
0 g
s
.838 .6408 m .84653 .59368 L .84065 .61066 L p .707 .577 .707 r
F P
0 g
s
.65182 .70636 m .65456 .6716 L .64181 .65838 L p .707 .577 .707 r
F P
0 g
s
.65934 .74669 m .65739 .72756 L .64606 .72809 L p .707 .577 .707 r
F P
0 g
s
.64606 .72809 m .64801 .74722 L .65934 .74669 L p .707 .577 .707 r
F P
0 g
s
.64452 .56526 m .63599 .61239 L .63999 .63077 L p .707 .577 .707 r
F P
0 g
s
.63599 .61239 m .64452 .56526 L .6504 .54828 L p .707 .577 .707 r
F P
0 g
s
.83829 .70887 m .84025 .728 L .84855 .72651 L p .707 .577 .707 r
F P
0 g
s
.84855 .72651 m .84659 .70738 L .83829 .70887 L p .707 .577 .707 r
F P
0 g
s
.64181 .65838 m .63906 .69315 L .65182 .70636 L p .707 .577 .707 r
F P
0 g
s
.83531 .67584 m .83257 .7106 L .83942 .69785 L p .707 .577 .707 r
F P
0 g
s
.83942 .69785 m .84217 .66308 L .83531 .67584 L p .707 .577 .707 r
F P
0 g
s
.84653 .59368 m .838 .6408 L .83399 .62243 L p .707 .577 .707 r
F P
0 g
s
.83399 .62243 m .84252 .5753 L .84653 .59368 L p .707 .577 .707 r
F P
0 g
s
.63906 .69315 m .64181 .65838 L .63871 .64472 L p .707 .577 .707 r
F P
0 g
s
.64801 .74722 m .64606 .72809 L .64446 .72758 L p .707 .577 .707 r
F P
0 g
s
.64446 .72758 m .64642 .74671 L .64801 .74722 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.64187 .5954 m .6504 .54828 L .66559 .53435 L p .707 .577 .707 r
F P
0 g
s
.6504 .54828 m .64187 .5954 L .63599 .61239 L p .707 .577 .707 r
F P
0 g
s
.63871 .64472 m .63596 .67949 L .63906 .69315 L p .707 .577 .707 r
F P
0 g
s
.84659 .70738 m .84855 .72651 L .84695 .726 L p .707 .577 .707 r
F P
0 g
s
.84695 .726 m .845 .70687 L .84659 .70738 L p .707 .577 .707 r
F P
0 g
s
.84217 .66308 m .83942 .69785 L .83632 .68419 L p .707 .577 .707 r
F P
0 g
s
.83632 .68419 m .83907 .64942 L .84217 .66308 L p .707 .577 .707 r
F P
0 g
s
.84252 .5753 m .83399 .62243 L .82049 .60446 L p .707 .577 .707 r
F P
0 g
s
.82049 .60446 m .82902 .55733 L .84252 .5753 L p .707 .577 .707 r
F P
0 g
s
.63596 .67949 m .63871 .64472 L .64556 .63197 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.66559 .53435 m .65706 .58147 L .64187 .5954 L p .707 .577 .707 r
F P
0 g
s
.65706 .58147 m .66559 .53435 L .68861 .52483 L p .707 .577 .707 r
F P
0 g
s
.38566 .60302 m .40479 .54899 L .37526 .5379 L p .707 .577 .707 r
F P
0 g
s
.40479 .54899 m .38566 .60302 L .41564 .61305 L p .707 .577 .707 r
F P
0 g
s
.41564 .61305 m .43477 .55902 L .40479 .54899 L p .707 .577 .707 r
F P
0 g
s
.64642 .74671 m .64446 .72758 L .65276 .72608 L p .707 .577 .707 r
F P
0 g
s
.65276 .72608 m .65472 .74521 L .64642 .74671 L p .707 .577 .707 r
F P
0 g
s
.64556 .63197 m .64282 .66673 L .63596 .67949 L p .707 .577 .707 r
F P
0 g
s
.43477 .55902 m .41564 .61305 L .44313 .62104 L p .707 .577 .707 r
F P
0 g
s
.44313 .62104 m .46226 .56701 L .43477 .55902 L p .707 .577 .707 r
F P
0 g
s
.35613 .59193 m .37526 .5379 L .34906 .52684 L p .707 .577 .707 r
F P
0 g
s
.37526 .5379 m .35613 .59193 L .38566 .60302 L p .707 .577 .707 r
F P
0 g
s
.82902 .55733 m .82049 .60446 L .79881 .58866 L p .707 .577 .707 r
F P
0 g
s
.79881 .58866 m .80735 .54153 L .82902 .55733 L p .707 .577 .707 r
F P
0 g
s
.845 .70687 m .84695 .726 L .83562 .72653 L p .707 .577 .707 r
F P
0 g
s
.83562 .72653 m .83367 .7074 L .845 .70687 L p .707 .577 .707 r
F P
0 g
s
.83907 .64942 m .83632 .68419 L .82357 .67097 L p .707 .577 .707 r
F P
0 g
s
.82357 .67097 m .82631 .63621 L .83907 .64942 L p .707 .577 .707 r
F P
0 g
s
.34906 .52684 m .32994 .58087 L .35613 .59193 L p .707 .577 .707 r
F P
0 g
s
.64282 .66673 m .64556 .63197 L .66171 .62136 L p .707 .577 .707 r
F P
0 g
s
.68007 .57196 m .68861 .52483 L .7172 .52066 L p .707 .577 .707 r
F P
0 g
s
.68861 .52483 m .68007 .57196 L .65706 .58147 L p .707 .577 .707 r
F P
0 g
s
.38504 .67321 m .39139 .63603 L .36063 .62959 L p .707 .577 .707 r
F P
0 g
s
.39139 .63603 m .38504 .67321 L .41643 .67777 L p .707 .577 .707 r
F P
0 g
s
.41643 .67777 m .42278 .64059 L .39139 .63603 L p .707 .577 .707 r
F P
0 g
s
.46226 .56701 m .44313 .62104 L .46544 .6262 L p .707 .577 .707 r
F P
0 g
s
.46544 .6262 m .48457 .57217 L .46226 .56701 L p .707 .577 .707 r
F P
0 g
s
.32994 .58087 m .34906 .52684 L .32877 .51688 L p .707 .577 .707 r
F P
0 g
s
.42278 .64059 m .41643 .67777 L .44538 .68 L p .707 .577 .707 r
F P
0 g
s
.44538 .68 m .45173 .64282 L .42278 .64059 L p .707 .577 .707 r
F P
0 g
s
.35428 .66677 m .36063 .62959 L .33351 .6219 L p .707 .577 .707 r
F P
0 g
s
.36063 .62959 m .35428 .66677 L .38504 .67321 L p .707 .577 .707 r
F P
0 g
s
.80735 .54153 m .79881 .58866 L .77108 .57657 L p .707 .577 .707 r
F P
0 g
s
.77108 .57657 m .77962 .52944 L .80735 .54153 L p .707 .577 .707 r
F P
0 g
s
.32877 .51688 m .30964 .57092 L .32994 .58087 L p .707 .577 .707 r
F P
0 g
s
.70866 .56779 m .7172 .52066 L .74856 .52225 L p .707 .577 .707 r
F P
0 g
s
.7172 .52066 m .70866 .56779 L .68007 .57196 L p .707 .577 .707 r
F P
0 g
s
.33351 .6219 m .32716 .65908 L .35428 .66677 L p .707 .577 .707 r
F P
0 g
s
.66171 .62136 m .65896 .65612 L .64282 .66673 L p .707 .577 .707 r
F P
0 g
s
.65472 .74521 m .65276 .72608 L .67014 .72374 L p .707 .577 .707 r
F P
0 g
s
.67014 .72374 m .6721 .74287 L .65472 .74521 L p .707 .577 .707 r
F P
0 g
s
.77962 .52944 m .77108 .57657 L .74002 .56938 L p .707 .577 .707 r
F P
0 g
s
.74002 .56938 m .74856 .52225 L .77962 .52944 L p .707 .577 .707 r
F P
0 g
s
.45173 .64282 m .44538 .68 L .46906 .67969 L p .707 .577 .707 r
F P
0 g
s
.46906 .67969 m .47541 .64251 L .45173 .64282 L p .707 .577 .707 r
F P
0 g
s
.74856 .52225 m .74002 .56938 L .70866 .56779 L p .707 .577 .707 r
F P
0 g
s
.82631 .63621 m .82357 .67097 L .8024 .65949 L p .707 .577 .707 r
F P
0 g
s
.8024 .65949 m .80515 .62472 L .82631 .63621 L p .707 .577 .707 r
F P
0 g
s
.32716 .65908 m .33351 .6219 L .31269 .61371 L p .707 .577 .707 r
F P
0 g
s
.83367 .7074 m .83562 .72653 L .81566 .72804 L p .707 .577 .707 r
F P
0 g
s
.81566 .72804 m .81371 .70891 L .83367 .7074 L p .707 .577 .707 r
F P
0 g
s
.48457 .57217 m .46544 .6262 L .48039 .62804 L p .707 .577 .707 r
F P
0 g
s
.48039 .62804 m .49952 .57401 L .48457 .57217 L p .707 .577 .707 r
F P
0 g
s
.65896 .65612 m .66171 .62136 L .68556 .61393 L p .707 .577 .707 r
F P
0 g
s
.30964 .57092 m .32877 .51688 L .31637 .50902 L p .707 .577 .707 r
F P
0 g
s
.43367 .72482 m .4291 .70738 L .39808 .71492 L p .707 .577 .707 r
F P
0 g
s
.4291 .70738 m .43367 .72482 L .46281 .71419 L p .707 .577 .707 r
F P
0 g
s
.46281 .71419 m .45824 .69676 L .4291 .70738 L p .707 .577 .707 r
F P
0 g
s
.40265 .73235 m .39808 .71492 L .36819 .71862 L p .707 .577 .707 r
F P
0 g
s
.39808 .71492 m .40265 .73235 L .43367 .72482 L p .707 .577 .707 r
F P
0 g
s
.31269 .61371 m .30634 .65089 L .32716 .65908 L p .707 .577 .707 r
F P
0 g
s
.31637 .50902 m .29724 .56305 L .30964 .57092 L p .707 .577 .707 r
F P
0 g
s
.45824 .69676 m .46281 .71419 L .48719 .70151 L p .707 .577 .707 r
F P
0 g
s
.48719 .70151 m .48262 .68408 L .45824 .69676 L p .707 .577 .707 r
F P
0 g
s
.36819 .71862 m .37276 .73605 L .40265 .73235 L p .707 .577 .707 r
F P
0 g
s
.47541 .64251 m .46906 .67969 L .48514 .67686 L p .707 .577 .707 r
F P
0 g
s
.48514 .67686 m .49149 .63968 L .47541 .64251 L p .707 .577 .707 r
F P
0 g
s
.37276 .73605 m .36819 .71862 L .34237 .71813 L p .707 .577 .707 r
F P
0 g
s
.68556 .61393 m .68281 .6487 L .65896 .65612 L p .707 .577 .707 r
F P
0 g
s
.80515 .62472 m .8024 .65949 L .77491 .65086 L p .707 .577 .707 r
F P
0 g
s
.77491 .65086 m .77765 .61609 L .80515 .62472 L p .707 .577 .707 r
F P
0 g
s
.6721 .74287 m .67014 .72374 L .6949 .72079 L p .707 .577 .707 r
F P
0 g
s
.6949 .72079 m .69686 .73992 L .6721 .74287 L p .707 .577 .707 r
F P
0 g
s
.68281 .6487 m .68556 .61393 L .71478 .61042 L p .707 .577 .707 r
F P
0 g
s
.30634 .65089 m .31269 .61371 L .3002 .60582 L p .707 .577 .707 r
F P
0 g
s
.34237 .71813 m .34694 .73557 L .37276 .73605 L p .707 .577 .707 r
F P
0 g
s
.81371 .70891 m .81566 .72804 L .78903 .7304 L p .707 .577 .707 r
F P
0 g
s
.78903 .7304 m .78708 .71127 L .81371 .70891 L p .707 .577 .707 r
F P
0 g
s
.48262 .68408 m .48719 .70151 L .50444 .68802 L p .707 .577 .707 r
F P
0 g
s
.50444 .68802 m .49987 .67058 L .48262 .68408 L p .707 .577 .707 r
F P
0 g
s
.3002 .60582 m .29385 .643 L .30634 .65089 L p .707 .577 .707 r
F P
0 g
s
.49952 .57401 m .48039 .62804 L .48651 .62637 L p .707 .577 .707 r
F P
0 g
s
.48651 .62637 m .50564 .57234 L .49952 .57401 L p .707 .577 .707 r
F P
0 g
s
.29724 .56305 m .31637 .50902 L .31306 .504 L p .707 .577 .707 r
F P
0 g
s
.77765 .61609 m .77491 .65086 L .74377 .64593 L p .707 .577 .707 r
F P
0 g
s
.74377 .64593 m .74651 .61116 L .77765 .61609 L p .707 .577 .707 r
F P
0 g
s
.71203 .64519 m .71478 .61042 L .74651 .61116 L p .707 .577 .707 r
F P
0 g
s
.71478 .61042 m .71203 .64519 L .68281 .6487 L p .707 .577 .707 r
F P
0 g
s
.34694 .73557 m .34237 .71813 L .32315 .7135 L p .707 .577 .707 r
F P
0 g
s
.31306 .504 m .29393 .55803 L .29724 .56305 L p .707 .577 .707 r
F P
0 g
s
.74651 .61116 m .74377 .64593 L .71203 .64519 L p .707 .577 .707 r
F P
0 g
s
.69686 .73992 m .6949 .72079 L .72462 .71751 L p .707 .577 .707 r
F P
0 g
s
.72462 .71751 m .72657 .73664 L .69686 .73992 L p .707 .577 .707 r
F P
0 g
s
.32315 .7135 m .32772 .73093 L .34694 .73557 L p .707 .577 .707 r
F P
0 g
s
.78708 .71127 m .78903 .7304 L .75833 .73336 L p .707 .577 .707 r
F P
0 g
s
.75833 .73336 m .75638 .71423 L .78708 .71127 L p .707 .577 .707 r
F P
0 g
s
.49149 .63968 m .48514 .67686 L .49206 .67179 L p .707 .577 .707 r
F P
0 g
s
.49206 .67179 m .49841 .63461 L .49149 .63968 L p .707 .577 .707 r
F P
0 g
s
.29385 .643 m .3002 .60582 L .29728 .59901 L p .707 .577 .707 r
F P
0 g
s
.72657 .73664 m .72462 .71751 L .75638 .71423 L p .707 .577 .707 r
F P
0 g
s
.75638 .71423 m .75833 .73336 L .72657 .73664 L p .707 .577 .707 r
F P
0 g
s
.49987 .67058 m .50444 .68802 L .51287 .67504 L p .707 .577 .707 r
F P
0 g
s
.51287 .67504 m .5083 .6576 L .49987 .67058 L p .707 .577 .707 r
F P
0 g
s
.29728 .59901 m .29093 .63619 L .29385 .643 L p .707 .577 .707 r
F P
0 g
s
.50564 .57234 m .48651 .62637 L .48321 .62136 L p .707 .577 .707 r
F P
0 g
s
.48321 .62136 m .50234 .56732 L .50564 .57234 L p .707 .577 .707 r
F P
0 g
s
.32772 .73093 m .32315 .7135 L .3124 .70517 L p .707 .577 .707 r
F P
0 g
s
.29393 .55803 m .31306 .504 L .31918 .50233 L p .707 .577 .707 r
F P
0 g
s
.3124 .70517 m .31697 .72261 L .32772 .73093 L p .707 .577 .707 r
F P
0 g
s
.31918 .50233 m .30006 .55636 L .29393 .55803 L p .707 .577 .707 r
F P
0 g
s
.49841 .63461 m .49206 .67179 L .48913 .66498 L p .707 .577 .707 r
F P
0 g
s
.48913 .66498 m .49548 .6278 L .49841 .63461 L p .707 .577 .707 r
F P
0 g
s
.5083 .6576 m .51287 .67504 L .51165 .66383 L p .707 .577 .707 r
F P
0 g
s
.51165 .66383 m .50708 .6464 L .5083 .6576 L p .707 .577 .707 r
F P
0 g
s
.29093 .63619 m .29728 .59901 L .30419 .59394 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30419 .59394 m .29784 .63112 L .29093 .63619 L p .707 .577 .707 r
F P
0 g
s
.31697 .72261 m .3124 .70517 L .31118 .69397 L p .707 .577 .707 r
F P
0 g
s
.50234 .56732 m .48321 .62136 L .4708 .61349 L p .707 .577 .707 r
F P
0 g
s
.4708 .61349 m .48993 .55945 L .50234 .56732 L p .707 .577 .707 r
F P
0 g
s
.30006 .55636 m .31918 .50233 L .33413 .50417 L p .707 .577 .707 r
F P
0 g
s
.31118 .69397 m .31575 .7114 L .31697 .72261 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.33413 .50417 m .31501 .5582 L .30006 .55636 L p .707 .577 .707 r
F P
0 g
s
.49548 .6278 m .48913 .66498 L .47664 .65709 L p .707 .577 .707 r
F P
0 g
s
.47664 .65709 m .48299 .61992 L .49548 .6278 L p .707 .577 .707 r
F P
0 g
s
.50708 .6464 m .51165 .66383 L .5009 .65551 L p .707 .577 .707 r
F P
0 g
s
.5009 .65551 m .49633 .63808 L .50708 .6464 L p .707 .577 .707 r
F P
0 g
s
.29784 .63112 m .30419 .59394 L .32028 .59111 L p .707 .577 .707 r
F P
0 g
s
.32028 .59111 m .31393 .62829 L .29784 .63112 L p .707 .577 .707 r
F P
0 g
s
.31575 .7114 m .31118 .69397 L .31961 .68099 L p .707 .577 .707 r
F P
0 g
s
.48993 .55945 m .4708 .61349 L .45051 .60353 L p .707 .577 .707 r
F P
0 g
s
.45051 .60353 m .46964 .5495 L .48993 .55945 L p .707 .577 .707 r
F P
0 g
s
.31501 .5582 m .33413 .50417 L .35644 .50933 L p .707 .577 .707 r
F P
0 g
s
.31961 .68099 m .32418 .69842 L .31575 .7114 L p .707 .577 .707 r
F P
0 g
s
.35644 .50933 m .33732 .56337 L .31501 .5582 L p .707 .577 .707 r
F P
0 g
s
.48299 .61992 m .47664 .65709 L .45582 .6489 L p .707 .577 .707 r
F P
0 g
s
.45582 .6489 m .46217 .61172 L .48299 .61992 L p .707 .577 .707 r
F P
0 g
s
.49633 .63808 m .5009 .65551 L .48168 .65087 L p .707 .577 .707 r
F P
0 g
s
.48168 .65087 m .47711 .63344 L .49633 .63808 L p .707 .577 .707 r
F P
0 g
s
.31393 .62829 m .32028 .59111 L .34395 .5908 L p .707 .577 .707 r
F P
0 g
s
.46964 .5495 m .45051 .60353 L .42432 .59247 L p .707 .577 .707 r
F P
0 g
s
.42432 .59247 m .44344 .53844 L .46964 .5495 L p .707 .577 .707 r
F P
0 g
s
.33732 .56337 m .35644 .50933 L .38393 .51732 L p .707 .577 .707 r
F P
0 g
s
.34395 .5908 m .3376 .62798 L .31393 .62829 L p .707 .577 .707 r
F P
0 g
s
.32418 .69842 m .31961 .68099 L .33686 .6675 L p .707 .577 .707 r
F P
0 g
s
.38393 .51732 m .36481 .57135 L .33732 .56337 L p .707 .577 .707 r
F P
0 g
s
.33686 .6675 m .34143 .68493 L .32418 .69842 L p .707 .577 .707 r
F P
0 g
s
.46217 .61172 m .45582 .6489 L .42871 .64121 L p .707 .577 .707 r
F P
0 g
s
.42871 .64121 m .43506 .60403 L .46217 .61172 L p .707 .577 .707 r
F P
0 g
s
.44344 .53844 m .42432 .59247 L .39479 .58138 L p .707 .577 .707 r
F P
0 g
s
.39479 .58138 m .41391 .52735 L .44344 .53844 L p .707 .577 .707 r
F P
0 g
s
.36481 .57135 m .38393 .51732 L .41391 .52735 L p .707 .577 .707 r
F P
0 g
s
.3376 .62798 m .34395 .5908 L .3729 .59303 L p .707 .577 .707 r
F P
0 g
s
.41391 .52735 m .39479 .58138 L .36481 .57135 L p .707 .577 .707 r
F P
0 g
s
.47711 .63344 m .48168 .65087 L .45586 .65039 L p .707 .577 .707 r
F P
0 g
s
.45586 .65039 m .45129 .63295 L .47711 .63344 L p .707 .577 .707 r
F P
0 g
s
.3729 .59303 m .36655 .63021 L .3376 .62798 L p .707 .577 .707 r
F P
0 g
s
.34143 .68493 m .33686 .6675 L .36124 .65482 L p .707 .577 .707 r
F P
0 g
s
.43506 .60403 m .42871 .64121 L .39795 .63477 L p .707 .577 .707 r
F P
0 g
s
.39795 .63477 m .4043 .59759 L .43506 .60403 L p .707 .577 .707 r
F P
0 g
s
.36655 .63021 m .3729 .59303 L .4043 .59759 L p .707 .577 .707 r
F P
0 g
s
.36124 .65482 m .36581 .67225 L .34143 .68493 L p .707 .577 .707 r
F P
0 g
s
.4043 .59759 m .39795 .63477 L .36655 .63021 L p .707 .577 .707 r
F P
0 g
s
.45129 .63295 m .45586 .65039 L .42597 .65409 L p .707 .577 .707 r
F P
0 g
s
.42597 .65409 m .4214 .63666 L .45129 .63295 L p .707 .577 .707 r
F P
0 g
s
.36581 .67225 m .36124 .65482 L .39038 .64419 L p .707 .577 .707 r
F P
0 g
s
.4214 .63666 m .42597 .65409 L .39495 .66162 L p .707 .577 .707 r
F P
0 g
s
.39495 .66162 m .39038 .64419 L .4214 .63666 L p .707 .577 .707 r
F P
0 g
s
.39038 .64419 m .39495 .66162 L .36581 .67225 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OGoo8@00Ogoo001gOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001g
Ool007=oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEP000080
07Aoo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH00UYF1000L7oo001]Ool30004FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP06FUH2001^Ool006]oo`8000MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP<006aoo`00JGoo0`00
25YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1eYF00<005YFFUH00P00JWoo001WOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH2001XOol0
06Ioo`03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8006Moo`00IWoo00<005YFFUH0
0UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF0000IWoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004
FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP00IGoo001UOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001JOol20009Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00IGoo001H
Ool300000eYF000000040003Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP00
IGoo001HOol20004FUH01000FUIJEUYF1@0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF
FUH006Eoo`00Egoo00<005YF00000eYF00<005YFFUH01EYF00@005YF0000009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJ
EP03001JEUYF00=JEP04001JEUYF001UOol005Moo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF009JEP<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Moo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP<000EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF001UOol005Ioo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF000@
Ool?0016Ool005Ioo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJ
EP@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00=JEP04001JEUYF000:Ool60003FUH00`00FUIJEP06FUH00`00FUIJEP040012Ool005Ioo`80
00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP000006FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJ
EP001goo0`0000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF0`00?goo001EOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUIJEP001Goo0P0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00
?Goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP0017oo0P001EYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH00P00>goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3000<FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000Woo0P0000=JEP00FUH00eYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00UYF0P00>Goo001DOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP08FUH01000FUH00000
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00H005YFFUH0
07oo0002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH2000gOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP<003Eoo`00E7oo0UYF00D005YF
FUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP80
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF
008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYF000dOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000=JEP03001JEUYF00=JEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH2000b
Ool005=oo`P000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJ
EP04001JEUYFFUH20002FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00Oomoo`0_Ool005=oo`03001JEUYF00=J
EP03001JEP0000800003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00=JEP<000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP04FUH2000`Ool005Aoo`03001JEUYF009JEP03001JEUYF009JEP<000MJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000YJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUH0000_Ool005Eoo`8000MJEP03001JEUYF00@0009JEP03001JEUYF00MJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEUYF00AJEP05001JEUYFFUH00009FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH00eYF00<005YFFUH00UYF3`001UYF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YF0000;goo001GOol20005FUH00`00FUIJEP04FUH40008
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEUYF0P0025YF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF009JEPH000mo
o`@0009JEP03001JEUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Uoo`8000=JEP03
001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF000025YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YF0000009JEP04001JEUYFFUH2000IOol30008FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
Oomoo`0[Ool005]oo`<000QJEP03001JEUYF00=JEP<00003FUH005YF00QJEP03001JEUYF00EJEP03
001JEUYF00AJEP05001JEUYFFUH0000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH01000FUH000000UYF00@005YF000001ioo`8000EJEP03001JEUYF00AJEP03001JEUYF009JEP03
001oogoo02]oo`00GGoo0P001eYF00<005YFFUH01UYF0`001eYF00<005YFFUH01UYF00<005YFFUH0
15YF00@005YFFUIJEP8000UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001J
EUYF0002FUH2000ROol20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0[Ool005mo
o`8000EJEP03001JEUYF00IJEP03001JEUYF008000EJEP03001JEUYF00IJEP03001JEUYF00=JEP07
001JEUYFFUH005YF00002EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
00000UYF00<007ooOol097oo0P0000=JEP00FUH01EYF00<005YFFUH00UYF0P00;7oo001QOol30000
0eYF001JEP08FUH00`00FUIJEP02FUH300000eYF001JEP07FUH00`00FUIJEP04FUH01000FUIJEUYF
0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`0000=JEP000000:7oo0P00
1UYF00L005YFFUIJEP00FUH0000/Ool005IooaT000QJEP<000MJEP03001JEUYF00=JEP03001JEUYF
009JEP8000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@0009JEP03001oogoo
02Moo`8000=JEP03001JEUYF009JEP03001JEP0002aoo`00EGoo0P0015YF00<005YFFUH00eYF00<0
05YFFUH01UYF00@005YFFUIJEPL000=JEP04001JEP000005FUH00`00FUIJEP03FUH01`00FUIJEUYF
001JEP0000YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP@000=JEP03001oogoo
01=oo`<0019oo`04001JEUYF0004FUH00`00FUH0000/Ool005Aoo`03001JEP0000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP<00003FUH005YF00EJEP04
001JEUYFFUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH00000
0eYF00<007ooOol04Woo1@004Woo0`0015YF00<005YF0000;7oo001DOol20004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH40002FUH20005FUH00`00FUIJEP02
FUH2000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP03FUH0
0`00Oomoo`0AOol5000DOol00`00FUIJEP02FUH00`00FUH0000/Ool005Aoo`8000AJEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000D000=JEP07001J
EUYFFUH005YF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001EYF0`00
4Goo1@005Goo00@005YFFUIJEP8002eoo`00Dgoo00<005YF000015YF00<005YFFUH00eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF1@0015YF00<005YF00002eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001EYF00@005YFFUH000Mo
oa0001=oo`04001JEUYFFUH2000]Ool005=oo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP<000AJEP<000]JEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000AJEP03001JEUYF009JEPL000AJEP03
001JEUYF00IJEP03001JEUYF00@0011oo`05001JEP00FUH0000]Ool004ioo`H00003FUH005YF00=J
EP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00800003FUH005YF008000]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP03001JEP0000AJEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF
00AJEP@000eoo`800003FUH007oo02aoo`00BWoo10000UYF00H005YFFUH005YF0003FUH00`00FUIJ
EP03FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH200000eYF0000000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00
FUH00004FUH30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00003
0008Ool300000eYF001oo`0/Ool004=oo`L000IJEP05001JEUYFFUH00004FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH4
000;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH30005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool01P00FUIJEP00FUH0
02eoo`00?Goo1P0015YF00<005YFFUH01UYF0`0000AJEP00FUIJEPd000AJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20002FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH3000017oo000000000UYF00<005YF0000
;Goo000iOol400000eYF001JEP07FUH00`00FUIJEP02FUH40002FUH00`00FUH0000200000eYF001J
EP04FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1@00FUIJEUYF00002eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YF
FUH015YF00<005YFFUH00P0000AJEP00FUIJEP8002ioo`00=7oo1@001EYF00<005YFFUH015YF1`00
1UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF20001UYF00<005YFFUH0
3P000UYF0P002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000AJ
EP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP8002ioo`00;goo1@000UYF00<005YFFUH015YF200015YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF3P0015YF
00<005YFFUH015YF00<005YFFUH010002UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00@005YF000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP800003FUH0000002ioo`00;7oo0`0000=JEP00FUH0
0eYF20000eYF00<005YFFUH01UYF00<005YFFUH01UYF0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF1P000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0`00
25YF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YF00000P00;Woo000[Ool:0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40007FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP001eYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH00UYF
3`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Woo000[Ool00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002
0005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH200000eYF001JEP08FUH00`00FUIJEP05FUH50003
FUH00`00FUIJEP03FUH00`00FUH00007FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH30004FUH00`00FUIJEP03FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YF
FUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00:goo00<005YF00000eYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP03001J
EUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00MJEP03001JEUYF00@000=JEPP000=JEP03001J
EP0000MJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<000AJEP03001JEP0000<0
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP@000IJEP03001JEUYF00=JEP05001JEUYFFUH0000^
Ool002aoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<00003FUH005YF00IJEP<000MJEP03001JEUYF00EJEPD000=JEP03001JEUYF
00AJEP8000=JEP@0009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP<000AJEP80009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP04001JEUYF
FUH40002FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000/Ool20004FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH40004FUH200000eYF
001JEP08FUH00`00FUIJEP050007FUH00`00FUIJEP04FUH00`00FUH00002FUH20002FUH30006FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30002FUH20002FUH30008FUH00`00FUIJ
EP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30005FUH01000FUIJEUYF0P00;Goo000/Ool00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH01000FUIJEUYF10000eYF00<005YFFUH01UYF100015YF00<005YFFUH01EYF00<005YF
FUH015YF00<005YFFUH010000UYF0`001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YF00000P001EYF0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00P000eYF00@005YFFUIJEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP80
00IJEP03001JEUYF009JEP<000QJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH30002
FUH30006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUH005YF0P0000=J
EP0000001@001UYF00<005YFFUH01UYF0`001UYF00<005YFFUH01EYF00<005YFFUH00UYF0P0000MJ
EP00FUIJEP00FUH0000]Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000MJEP03001JEP000080
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP05001JEUYF001JEP0200001EYF001J
EUYF00001UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`000eYF00D007ooOomo
o`00009JEP<000=JEP03001JEUYF00IJEPD000EJEP03001JEUYF00EJEP03001JEUYF00=JEP<0009J
EP03001JEP0002eoo`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF0P000UYF00<005YFFUH015YF0P000UYF1`0015YF
00<005YFFUH01EYF00<005YFFUH015YF00H005YFFUIJEP00FUH40002FUH00`00FUIJEP04FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH30003FUH40005FUH300000eYF001JEP07FUH5
0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002Ool01@00FUH005YF0000;Goo000]Ool20004
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH80004FUH00`00FUIJEP04
FUH00`00FUIJEP05000015YF001JEP001eYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH0
0eYF0P0015YF00@005YFFUH000EJEP03001JEUYF00@000IJEPD000AJEP03001JEUYF00EJEP03001J
EP0000<000Aoo`05001JEP00FUH0000]Ool002eoo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJEP03001JEP0000<000AJEP04
001JEUYFFUH30002FUH00`00FUIJEP03FUH>0002FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH01000FUIJEUYF0P000eYF00D005YFFUIJEP00
009oo`@0009JEP@000EJEP03001JEUYF009JEPD000Qoo`@002ioo`00;Goo0P0015YF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF2@001UYF0P000Woo0P0015YF00<0
05YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0015YF00<005YFFUH00eYF0P000UYF00@0
05YFFUH000Iooa0000]oo`80009JEP8002ioo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH010001goo00<005YF000015YF00<007ooOol00Woo0P0015YF
00<005YFFUH01@0000=JEP00FUH02EYF00<005YFFUH01EYF0`001EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YF00000`00
0UYF00<007ooOol077oo0P0015YF0P00;Woo000]Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH7000:Ool01000FUIJEP000UYF0P001Goo0P0015YF00<005YFFUH0
1@0000=JEP00FUH02EYF00<005YFFUH00eYF0P000UYF00<005YFFUH00UYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF00<005YFFUH0
0eYF10006Woo0`0000=JEP00FUH00eYF0P00;Woo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH80009Ool90003FUH30006Ool20004FUH01000FUIJEUYF0`000UYF00<005YFFUH025YF00@0
05YFFUIJEP8000EJEP04001JEP00000:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP04000@Ool60004FUH01`00FUIJ
EUYF001JEP0002ioo`00;Woo0P0015YF00@005YFFUIJEPL000Qoo`T000AJEP05001JEUYFFUH00003
FUH00`00FUIJEP080004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH01000FUH000001eYF0`002eYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000UYF00<005YFFUH015YF
00<005YFFUH015YF00<005YFFUH015YF400015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000^
Ool002ioo`X000Moo`P000AJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH20005FUH00`00FUIJ
EP020004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH300000eYF001JEP06FUH00`00FUH0000;FUH0
0`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP030005FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;goo000gOol80003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF0`0000=JEP00
FUH015YF00<005YFFUH00P0015YF00<005YFFUH01UYF00<005YFFUH015YF0`0015YF00<005YFFUH0
0eYF0P000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH00`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00eYF00@005YFFUIJEP8002moo`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00@005YFFUIJEP<00003FUH005YF00AJEP03001JEUYF008000AJEP03001J
EUYF00IJEP04001JEUYFFUH30008FUH00`00FUIJEP020004FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUIJEP050003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUH0000<000/Ool002ioo`<0009JEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP000005FUH00`00FUIJEP020004FUH00`00FUIJEP06FUH400000eYF001JEP08FUH30006FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000P000=JEP03001JEUYF009J
EP05001JEUYFFUH0000/Ool002aoo`<000AJEP03001JEUYF009JEQH000MJEP08001JEUYFFUH005YF
001JEP<0009JEP03001JEUYF008000AJEP03001JEP0000H000IJEP03001JEUYF00EJEP8000QJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF0005FUH3
0007FUH00`00FUIJEP05FUH00`00FUIJEP090004FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00
FUIJEUYF0000;7oo000/Ool00`00FUH00004FUH00`00FUIJEP0200000eYF001JEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP040003FUH00`00FUIJEP02FUH00`00FUH00003FUH=0004FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH2000:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH01000FUIJEP001UYF0`0000=JEP0000003P0015YF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00eYF00<005YFFUH00P00:goo000/Ool00`00FUH00004FUH30003FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40004FUH00`00FUH00004FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH00002000<FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP0015YF1P000eYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00:goo
000/Ool00`00FUH00003FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUH000000eYF0`000eYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH015YF10000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF
00<005YFFUH01@000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF00@005YFFUIJEPL002]oo`00;7oo00@005YF001JEP<000IJEP03001JEUYF
009JEPP000AJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30003FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP040006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEQ@002eoo`00;7oo00@005YF0000009JEP03001JEUYF
00=JEPH000EJEP03001JEUYF00L000IJEP03001JEUYF00AJEPL00003FUH005YF00EJEP03001JEUYF
009JEPL000YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP06001JEUYF001JEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0UYF2P000UYF1`00=goo000]Ool00`00FUIJEP02FUH00`00FUH000030002FUH00`00FUIJEP02FUHB
0002FUH00`00FUIJEP05FUH30002FUH>0006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YF
FUH00UYF00<005YFFUH015YF00<005YFFUH00UYF20000eYF2@00?Woo000/Ool20004FUH30004FUH7
0008FUH00`00FUIJEP06FUH40006FUH01P00FUIJEP00FUH000AJEP8000AJEP03001JEUYF00IJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP02FUH01000FUIJEUYF20000UYF2@00Agoo000/
Ool20003FUH01@00FUIJEP00FUH00`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJ
EP8000AJEP04001JEUYFFUH20002FUH40004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJ
EP04FUH<0006FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0
5000D7oo000[Ool01000FUH005YF0P0000=JEP0000000P000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00FUH015YF0P000Woo0P0015YF00<005YF
FUH01UYF00<005YFFUH01UYF2@002UYF00<005YF00002`001UYF00<005YFFUH01eYF00<005YFFUH0
0eYF00<005YFFUH020000Woo0`0000=JEP00FUH00P00E7oo000[Ool00`00FUH000050005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60005FUH20002Ool20004
FUH00`00FUIJEP06FUH00`00FUIJEP060006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00080007FUH00`00FUIJEP03FUH01000FUIJEP002Woo10000UYF00<007ooOol0DWoo000[Ool01000
FUH000000eYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH00UYF2@00
1Woo00<005YFFUH00UYF0P000Woo0P0015YF00<005YFFUH015YF1P002eYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF1@000UYF00<005YFFUH00eYF00@005YFFUH000Qoo`8000AJEP<0
05Aoo`00:goo0P0000=oo`0000001@000eYF00<005YFFUH015YF00<005YFFUH00UYF2@0047oo0P00
00IJEP00FUIJEP00Ool20004FUH00`00FUIJEP040005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH30005FUH01000FUIJEP001Woo0P0000=J
EP00FUH00eYF00<005YF0000E7oo000[Ool20008Ool?000KOol20002FUH01000Ool0000015YF1000
25YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0P000eYF00@005YFFUH000Aoo`8000=JEP03001JEUYF009JEP04001JEP00001COol002]oo`80
03=oo`04001JEUYFFUH30002FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH300001UYF001JEUYF001oo`<000IJ
EP05001JEUYFFUH00002FUH00`00Oomoo`1AOol002]oo`8003Aoo`03001JEUYF00D000EJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF0080009JEP800003FUH005YF00IJEP05001JEUYFFUH00002FUH00`00Oomo
o`1AOol002]oo`<001Yoo`<001Moo`03001JEP0000<000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP00009JEP03001JEUYF00EJEP03001JEUYF009JEP8005Aoo`00:goo00<005YF00006Goo
1@005Woo00<005YF00000`001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<0
05YFFUH015YF00<005YFFUH00UYF0P00E7oo000[Ool01000FUIJEP0067oo1@005goo0`0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH00UYF
00<007ooOol0Dgoo000[Ool01@00FUIJEUYF00005goo1@0067oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF00000eYF00<005YFFUH01EYF00@005YFFUH005Ioo`00;7oo
00<005YFFUH00P005goo0`006Goo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0015YF00<005YFFUH01EYF0`00Egoo000/Ool01@00FUIJEP00FUH00P00<7oo0P0000=oo`000000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<007ooOol0Egoo000]
Ool20004FUH00`00Oomoo`0]Ool200000goo00000006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH2001JOol002eoo`8000EJEP8002aoo`03001JEP00009oo`80
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF008000MJEP03001JEUYF008005aoo`00;Woo00<005YFFUH0
0eYF00@005YF000002Qoo`@000Eoo`8000=JEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEPD000MJEP<005ioo`00;goo0P00
0eYF00@005YFFUIJEP<002=oo`80009JEP8000Moo`800003FUH005YF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80009JEP04001JEP00
0004FUH2001POol0035oo`04001JEUYF0006FUH4000MOol20004FUH00`00Oomoo`08Ool40006FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3
0004FUH01000FUIJEUYF1000HWoo000bOol30007FUH00`00FUIJEP04000EOol400000eYF001JEP03
FUH00`00Oomoo`0<Ool40002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUH000030005FUH00`00FUIJEP04FUH2001ROol003Aoo`8000IJEP03001JEUYF
00AJEPL000Uoo`D000EJEP05001JEUYFFUH0000COol50009FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP03FUH<0004FUH00`00FUIJEP05FUH3001POol003Ioo`8000=JEP03001JEUYF00MJ
EP03001JEUYF009JEPT000=JEP03001JEUYF00AJEP04001JEP00000IOol60003FUH00`00FUIJEP0:
FUH00`00FUIJEP04FUHJ00000eYF001JEP06FUH00`00FUIJEP02001NOol003Qoo`800003FUH005YF
00QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP80025ooaL000AJEP03001JEUYF
00AJEPD0009oo`D000=oo`<000EJEP03001JEUYF00=JEP8005aoo`00>Woo10001UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH00eYF0P00=goo0P000eYF00<005YFFUH01eYF00<005YFFUH0
1P001goo100000=JEP00FUH01EYF0`00FWoo000nOol40002FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUH00003000kOol200000eYF001JEP08FUH00`00FUIJEP04FUH40009Ool20006FUH01000
FUIJEP00FGoo0012Ool70004FUH00`00FUIJEP02FUH60011Ool30007FUH00`00FUIJEP07FUH00`00
FUH000030007Ool20003FUH01@00FUIJEUYF0000FGoo0019Ool9001:Ool30004FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH60003Ool200000eYF001JEP02FUH00`00Oomoo`1GOol009moo`<00003FUH0
05YF00MJEP03001JEUYF00IJEP04001JEUYFFUH70002FUH2001IOol00:9oo`<000MJEP03001JEUYF
00IJEP03001JEUYF00AJEP04001JEUYFFUH3001JOol00:Eoo`@0009JEP03001JEUYF00IJEP03001J
EUYF00EJEP07001JEUYFFUH005YF0000FWoo002YOol70004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH00`00FUH0001JOol00;1oo`P000=JEP03001JEUYF009JEP03001JEP0005Yoo`00^7oo2P00Fgoo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]57\[InvisibleSpace]"     "\
\[InvisibleSpace]13.645329329759143`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 57, "     ", 13.645329329759143, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58587 .75686 m .60634 .7077 L .57739 .69441 L p .707 .577 .707 r
F P
0 g
s
.60634 .7077 m .58587 .75686 L .6157 .76635 L p .707 .577 .707 r
F P
0 g
s
.6157 .76635 m .63617 .71719 L .60634 .7077 L p .707 .577 .707 r
F P
0 g
s
.55692 .74358 m .57739 .69441 L .55216 .67864 L p .707 .577 .707 r
F P
0 g
s
.57739 .69441 m .55692 .74358 L .58587 .75686 L p .707 .577 .707 r
F P
0 g
s
.63617 .71719 m .6157 .76635 L .64349 .77112 L p .707 .577 .707 r
F P
0 g
s
.64349 .77112 m .66396 .72196 L .63617 .71719 L p .707 .577 .707 r
F P
0 g
s
.53169 .72781 m .55216 .67864 L .53311 .66192 L p .707 .577 .707 r
F P
0 g
s
.55216 .67864 m .53169 .72781 L .55692 .74358 L p .707 .577 .707 r
F P
0 g
s
.66396 .72196 m .64349 .77112 L .66652 .77071 L p .707 .577 .707 r
F P
0 g
s
.66652 .77071 m .68699 .72154 L .66396 .72196 L p .707 .577 .707 r
F P
0 g
s
.59211 .81543 m .59625 .77907 L .56528 .77366 L p .707 .577 .707 r
F P
0 g
s
.59625 .77907 m .59211 .81543 L .62377 .81782 L p .707 .577 .707 r
F P
0 g
s
.62377 .81782 m .62791 .78146 L .59625 .77907 L p .707 .577 .707 r
F P
0 g
s
.64378 .8322 m .63904 .81383 L .60815 .822 L p .707 .577 .707 r
F P
0 g
s
.63904 .81383 m .64378 .8322 L .67241 .82296 L p .707 .577 .707 r
F P
0 g
s
.67241 .82296 m .66767 .80459 L .63904 .81383 L p .707 .577 .707 r
F P
0 g
s
.62791 .78146 m .62377 .81782 L .65301 .81695 L p .707 .577 .707 r
F P
0 g
s
.65301 .81695 m .65715 .78059 L .62791 .78146 L p .707 .577 .707 r
F P
0 g
s
.56114 .81002 m .56528 .77366 L .53802 .76577 L p .707 .577 .707 r
F P
0 g
s
.56528 .77366 m .56114 .81002 L .59211 .81543 L p .707 .577 .707 r
F P
0 g
s
.61289 .84037 m .60815 .822 L .57803 .82829 L p .707 .577 .707 r
F P
0 g
s
.60815 .822 m .61289 .84037 L .64378 .8322 L p .707 .577 .707 r
F P
0 g
s
.51264 .71109 m .53311 .66192 L .52211 .64589 L p .707 .577 .707 r
F P
0 g
s
.53311 .66192 m .51264 .71109 L .53169 .72781 L p .707 .577 .707 r
F P
0 g
s
.57803 .82829 m .58277 .84666 L .61289 .84037 L p .707 .577 .707 r
F P
0 g
s
.58277 .84666 m .57803 .82829 L .55163 .83208 L p .707 .577 .707 r
F P
0 g
s
.66767 .80459 m .67241 .82296 L .69598 .81355 L p .707 .577 .707 r
F P
0 g
s
.69598 .81355 m .69124 .79518 L .66767 .80459 L p .707 .577 .707 r
F P
0 g
s
.65715 .78059 m .65301 .81695 L .67697 .81291 L p .707 .577 .707 r
F P
0 g
s
.67697 .81291 m .68111 .77655 L .65715 .78059 L p .707 .577 .707 r
F P
0 g
s
.53802 .76577 m .53388 .80213 L .56114 .81002 L p .707 .577 .707 r
F P
0 g
s
.55163 .83208 m .55637 .85046 L .58277 .84666 L p .707 .577 .707 r
F P
0 g
s
.68699 .72154 m .66652 .77071 L .68254 .76514 L p .707 .577 .707 r
F P
0 g
s
.68254 .76514 m .70301 .71597 L .68699 .72154 L p .707 .577 .707 r
F P
0 g
s
.53388 .80213 m .53802 .76577 L .51714 .75615 L p .707 .577 .707 r
F P
0 g
s
.52211 .64589 m .50164 .69506 L .51264 .71109 L p .707 .577 .707 r
F P
0 g
s
.51714 .75615 m .513 .79251 L .53388 .80213 L p .707 .577 .707 r
F P
0 g
s
.55637 .85046 m .55163 .83208 L .53152 .83302 L p .707 .577 .707 r
F P
0 g
s
.50164 .69506 m .52211 .64589 L .52023 .63211 L p .707 .577 .707 r
F P
0 g
s
.53152 .83302 m .53626 .85139 L .55637 .85046 L p .707 .577 .707 r
F P
0 g
s
.68111 .77655 m .67697 .81291 L .69331 .8061 L p .707 .577 .707 r
F P
0 g
s
.69124 .79518 m .69598 .81355 L .71218 .80488 L p .707 .577 .707 r
F P
0 g
s
.71218 .80488 m .70744 .78651 L .69124 .79518 L p .707 .577 .707 r
F P
0 g
s
.69331 .8061 m .69745 .76974 L .68111 .77655 L p .707 .577 .707 r
F P
0 g
s
.513 .79251 m .51714 .75615 L .50469 .74576 L p .707 .577 .707 r
F P
0 g
s
.70301 .71597 m .68254 .76514 L .68997 .75497 L p .707 .577 .707 r
F P
0 g
s
.68997 .75497 m .71044 .7058 L .70301 .71597 L p .707 .577 .707 r
F P
0 g
s
.50469 .74576 m .50055 .78212 L .513 .79251 L p .707 .577 .707 r
F P
0 g
s
.52023 .63211 m .49976 .68128 L .50164 .69506 L p .707 .577 .707 r
F P
0 g
s
.53626 .85139 m .53152 .83302 L .51968 .831 L p .707 .577 .707 r
F P
0 g
s
.51968 .831 m .52442 .84937 L .53626 .85139 L p .707 .577 .707 r
F P
0 g
s
.49976 .68128 m .52023 .63211 L .52767 .62195 L p .707 .577 .707 r
F P
0 g
s
.69745 .76974 m .69331 .8061 L .70042 .79718 L p .707 .577 .707 r
F P
0 g
s
.70042 .79718 m .70457 .76082 L .69745 .76974 L p .707 .577 .707 r
F P
0 g
s
.70744 .78651 m .71218 .80488 L .71943 .79782 L p .707 .577 .707 r
F P
0 g
s
.71943 .79782 m .71469 .77945 L .70744 .78651 L p .707 .577 .707 r
F P
0 g
s
.50055 .78212 m .50469 .74576 L .50189 .7356 L p .707 .577 .707 r
F P
0 g
s
.46426 .82168 m .50346 .32565 L .45959 .3195 L p .707 .577 .707 r
F P
0 g
s
.50189 .7356 m .49774 .77196 L .50055 .78212 L p .707 .577 .707 r
F P
0 g
s
.52767 .62195 m .5072 .67111 L .49976 .68128 L p .707 .577 .707 r
F P
0 g
s
.5072 .67111 m .52767 .62195 L .54368 .61638 L p .707 .577 .707 r
F P
0 g
s
.49774 .77196 m .50189 .7356 L .509 .72668 L p .707 .577 .707 r
F P
0 g
s
.509 .72668 m .50486 .76304 L .49774 .77196 L p .707 .577 .707 r
F P
0 g
s
.54368 .61638 m .52322 .66555 L .5072 .67111 L p .707 .577 .707 r
F P
0 g
s
.50486 .76304 m .509 .72668 L .52534 .71987 L p .707 .577 .707 r
F P
0 g
s
.52534 .71987 m .5212 .75623 L .50486 .76304 L p .707 .577 .707 r
F P
0 g
s
.50346 .32565 m .46426 .82168 L .50908 .82371 L p .707 .577 .707 r
F P
0 g
s
.50908 .82371 m .54828 .32768 L .50346 .32565 L p .707 .577 .707 r
F P
0 g
s
.71044 .7058 m .68997 .75497 L .6881 .7412 L p .707 .577 .707 r
F P
0 g
s
.6881 .7412 m .70857 .69203 L .71044 .7058 L p .707 .577 .707 r
F P
0 g
s
.52442 .84937 m .51968 .831 L .51727 .82622 L p .707 .577 .707 r
F P
0 g
s
.51727 .82622 m .52201 .84459 L .52442 .84937 L p .707 .577 .707 r
F P
0 g
s
.52201 .84459 m .51727 .82622 L .52452 .81915 L p .707 .577 .707 r
F P
0 g
s
.52322 .66555 m .54368 .61638 L .56671 .61596 L p .707 .577 .707 r
F P
0 g
s
.52452 .81915 m .52926 .83752 L .52201 .84459 L p .707 .577 .707 r
F P
0 g
s
.54625 .66513 m .56671 .61596 L .5945 .62073 L p .707 .577 .707 r
F P
0 g
s
.56671 .61596 m .54625 .66513 L .52322 .66555 L p .707 .577 .707 r
F P
0 g
s
.52926 .83752 m .52452 .81915 L .54072 .81049 L p .707 .577 .707 r
F P
0 g
s
.54072 .81049 m .54546 .82886 L .52926 .83752 L p .707 .577 .707 r
F P
0 g
s
.5212 .75623 m .52534 .71987 L .5493 .71583 L p .707 .577 .707 r
F P
0 g
s
.5945 .62073 m .57404 .6699 L .54625 .66513 L p .707 .577 .707 r
F P
0 g
s
.5493 .71583 m .54516 .75219 L .5212 .75623 L p .707 .577 .707 r
F P
0 g
s
.54546 .82886 m .54072 .81049 L .56429 .80107 L p .707 .577 .707 r
F P
0 g
s
.54516 .75219 m .5493 .71583 L .57854 .71496 L p .707 .577 .707 r
F P
0 g
s
.57854 .71496 m .5744 .75132 L .54516 .75219 L p .707 .577 .707 r
F P
0 g
s
.54828 .32768 m .50908 .82371 L .55046 .82142 L p .707 .577 .707 r
F P
0 g
s
.55046 .82142 m .58967 .32539 L .54828 .32768 L p .707 .577 .707 r
F P
0 g
s
.42039 .81553 m .45959 .3195 L .42096 .30984 L p .707 .577 .707 r
F P
0 g
s
.45959 .3195 m .42039 .81553 L .46426 .82168 L p .707 .577 .707 r
F P
0 g
s
.70457 .76082 m .70042 .79718 L .69762 .78702 L p .707 .577 .707 r
F P
0 g
s
.69762 .78702 m .70176 .75066 L .70457 .76082 L p .707 .577 .707 r
F P
0 g
s
.71469 .77945 m .71943 .79782 L .71702 .79304 L p .707 .577 .707 r
F P
0 g
s
.71702 .79304 m .71228 .77467 L .71469 .77945 L p .707 .577 .707 r
F P
0 g
s
.57404 .6699 m .5945 .62073 L .62433 .63022 L p .707 .577 .707 r
F P
0 g
s
.62433 .63022 m .60387 .67939 L .57404 .6699 L p .707 .577 .707 r
F P
0 g
s
.56429 .80107 m .56903 .81944 L .54546 .82886 L p .707 .577 .707 r
F P
0 g
s
.5744 .75132 m .57854 .71496 L .6102 .71735 L p .707 .577 .707 r
F P
0 g
s
.6102 .71735 m .60606 .75371 L .5744 .75132 L p .707 .577 .707 r
F P
0 g
s
.56903 .81944 m .56429 .80107 L .59292 .79183 L p .707 .577 .707 r
F P
0 g
s
.59292 .79183 m .59766 .8102 L .56903 .81944 L p .707 .577 .707 r
F P
0 g
s
.58967 .32539 m .55046 .82142 L .58436 .81504 L p .707 .577 .707 r
F P
0 g
s
.58436 .81504 m .62356 .31901 L .58967 .32539 L p .707 .577 .707 r
F P
0 g
s
.38176 .80587 m .42096 .30984 L .39136 .2976 L p .707 .577 .707 r
F P
0 g
s
.42096 .30984 m .38176 .80587 L .42039 .81553 L p .707 .577 .707 r
F P
0 g
s
.70857 .69203 m .6881 .7412 L .6771 .72517 L p .707 .577 .707 r
F P
0 g
s
.6771 .72517 m .69757 .676 L .70857 .69203 L p .707 .577 .707 r
F P
0 g
s
.24286 .72213 m .26333 .67296 L .23438 .65968 L p .707 .577 .707 r
F P
0 g
s
.26333 .67296 m .24286 .72213 L .27269 .73162 L p .707 .577 .707 r
F P
0 g
s
.27269 .73162 m .29316 .68245 L .26333 .67296 L p .707 .577 .707 r
F P
0 g
s
.21391 .70885 m .23438 .65968 L .20915 .64391 L p .707 .577 .707 r
F P
0 g
s
.23438 .65968 m .21391 .70885 L .24286 .72213 L p .707 .577 .707 r
F P
0 g
s
.29316 .68245 m .27269 .73162 L .30048 .73639 L p .707 .577 .707 r
F P
0 g
s
.30048 .73639 m .32095 .68722 L .29316 .68245 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.18868 .69308 m .20915 .64391 L .1901 .62719 L p .707 .577 .707 r
F P
0 g
s
.20915 .64391 m .18868 .69308 L .21391 .70885 L p .707 .577 .707 r
F P
0 g
s
.70176 .75066 m .69762 .78702 L .68517 .77663 L p .707 .577 .707 r
F P
0 g
s
.68517 .77663 m .68931 .74027 L .70176 .75066 L p .707 .577 .707 r
F P
0 g
s
.65328 .6435 m .63282 .69267 L .60387 .67939 L p .707 .577 .707 r
F P
0 g
s
.60387 .67939 m .62433 .63022 L .65328 .6435 L p .707 .577 .707 r
F P
0 g
s
.64117 .72275 m .63703 .75911 L .60606 .75371 L p .707 .577 .707 r
F P
0 g
s
.60606 .75371 m .6102 .71735 L .64117 .72275 L p .707 .577 .707 r
F P
0 g
s
.59766 .8102 m .59292 .79183 L .62381 .78367 L p .707 .577 .707 r
F P
0 g
s
.62381 .78367 m .62855 .80204 L .59766 .8102 L p .707 .577 .707 r
F P
0 g
s
.62356 .31901 m .58436 .81504 L .60745 .80519 L p .707 .577 .707 r
F P
0 g
s
.60745 .80519 m .64665 .30916 L .62356 .31901 L p .707 .577 .707 r
F P
0 g
s
.71228 .77467 m .71702 .79304 L .70518 .79102 L p .707 .577 .707 r
F P
0 g
s
.70518 .79102 m .70044 .77265 L .71228 .77467 L p .707 .577 .707 r
F P
0 g
s
.32095 .68722 m .30048 .73639 L .32351 .73598 L p .707 .577 .707 r
F P
0 g
s
.32351 .73598 m .34398 .68681 L .32095 .68722 L p .707 .577 .707 r
F P
0 g
s
.69757 .676 m .6771 .72517 L .65805 .70845 L p .707 .577 .707 r
F P
0 g
s
.65805 .70845 m .67852 .65928 L .69757 .676 L p .707 .577 .707 r
F P
0 g
s
.2491 .77341 m .25324 .73705 L .22227 .73165 L p .707 .577 .707 r
F P
0 g
s
.25324 .73705 m .2491 .77341 L .28076 .7758 L p .707 .577 .707 r
F P
0 g
s
.28076 .7758 m .2849 .73944 L .25324 .73705 L p .707 .577 .707 r
F P
0 g
s
.2849 .73944 m .28076 .7758 L .31 .77493 L p .707 .577 .707 r
F P
0 g
s
.31 .77493 m .31414 .73857 L .2849 .73944 L p .707 .577 .707 r
F P
0 g
s
.33953 .73041 m .36 .68124 L .34398 .68681 L p .707 .577 .707 r
F P
0 g
s
.32466 .7772 m .3294 .79557 L .35297 .78616 L p .707 .577 .707 r
F P
0 g
s
.34823 .76779 m .32466 .7772 L p .35099 .78553 L .707 .577 .707 r
F P
0 g
s
.35297 .78616 m .35122 .77939 L p .35099 .78553 L .707 .577 .707 r
F P
0 g
s
.35122 .77939 m .34823 .76779 L p .35099 .78553 L .707 .577 .707 r
F P
0 g
s
.33396 .77089 m .3381 .73453 L .31414 .73857 L p .707 .577 .707 r
F P
0 g
s
.34398 .68681 m .32351 .73598 L .33953 .73041 L p .707 .577 .707 r
F P
0 g
s
.3381 .73453 m .33396 .77089 L .3503 .76408 L p .707 .577 .707 r
F P
0 g
s
.34509 .70647 m .33409 .69044 L p .34579 .67812 L .707 .577 .707 r
F P
0 g
s
.36556 .6573 m .34541 .70569 L p .34579 .67812 L .707 .577 .707 r
F P
0 g
s
.34541 .70569 m .34509 .70647 L p .34579 .67812 L .707 .577 .707 r
F P
0 g
s
.34685 .60079 m .36658 .37382 L .36965 .27034 L .707 .577 .707 r
F
.33409 .69044 m .33949 .67746 L p .34587 .67253 L F P
0 g
s
.33409 .69044 m .34587 .67253 L .34579 .67812 L .707 .577 .707 r
F
.33949 .67746 m .35456 .64127 L .36081 .65039 L p F P
0 g
s
.36081 .65039 m .36556 .6573 L p .33949 .67746 L .707 .577 .707 r
F P
0 g
s
.31414 .73857 m .31 .77493 L .33396 .77089 L p .707 .577 .707 r
F P
0 g
s
.35456 .64127 m .33409 .69044 L .32649 .68377 L p .707 .577 .707 r
F P
0 g
s
.32649 .68377 m .31504 .67372 L p .32892 .66232 L .707 .577 .707 r
F P
0 g
s
.32892 .66232 m .35456 .64127 L .32649 .68377 L .707 .577 .707 r
F
.36965 .27034 m .34754 .55016 L p .34685 .60079 L F P
0 g
s
.31504 .67372 m .33551 .62455 L .35456 .64127 L p .707 .577 .707 r
F P
0 g
s
.3503 .76408 m .35444 .72772 L .3381 .73453 L p .707 .577 .707 r
F P
0 g
s
.36 .68124 m .33953 .73041 L .34696 .72024 L p .707 .577 .707 r
F P
0 g
s
.34696 .72024 m .36743 .67107 L .36 .68124 L p .707 .577 .707 r
F P
0 g
s
.36743 .67107 m .34696 .72024 L .34509 .70647 L p .707 .577 .707 r
F P
0 g
s
.34509 .70647 m .36556 .6573 L .36743 .67107 L p .707 .577 .707 r
F P
0 g
s
.3463 .69825 m .34216 .73461 L .32128 .72499 L p .707 .577 .707 r
F P
0 g
s
.32128 .72499 m .32542 .68863 L .3463 .69825 L p .707 .577 .707 r
F P
0 g
s
.33732 .74619 m .33843 .75049 L p .31566 .76836 L .707 .577 .707 r
F P
0 g
s
.34579 .67812 m .34587 .67253 L .36556 .6573 L .707 .577 .707 r
F
.34823 .76779 m .35297 .78616 L .36917 .7775 L p F P
0 g
s
.36917 .7775 m .36443 .75912 L .34823 .76779 L p .707 .577 .707 r
F P
0 g
s
.35444 .72772 m .3503 .76408 L .35742 .75516 L p .707 .577 .707 r
F P
0 g
s
.35742 .75516 m .36156 .7188 L .35444 .72772 L p .707 .577 .707 r
F P
0 g
s
.35875 .70864 m .35461 .745 L .34216 .73461 L p .707 .577 .707 r
F P
0 g
s
.34216 .73461 m .3463 .69825 L .35875 .70864 L p .707 .577 .707 r
F P
0 g
s
.33486 .78032 m .35216 .79363 L p .35632 .69499 L .707 .577 .707 r
F P
0 g
s
.33843 .75049 m .33732 .74619 L .33985 .74607 L p .707 .577 .707 r
F P
0 g
s
.35632 .69499 m .36247 .54945 L .33843 .75049 L .707 .577 .707 r
F
.35632 .69499 m .33843 .75049 L .33486 .78032 L F
.36156 .7188 m .35742 .75516 L .35461 .745 L p F P
0 g
s
.35461 .745 m .35875 .70864 L .36156 .7188 L p .707 .577 .707 r
F P
0 g
s
.36377 .64663 m .35216 .79363 L p .38528 .61932 L .707 .577 .707 r
F P
0 g
s
.35216 .79363 m .39136 .2976 L .37368 .28399 L p .707 .577 .707 r
F P
0 g
s
.34206 .76456 m .33843 .75049 L p .35743 .74526 L .707 .577 .707 r
F P
0 g
s
.33985 .74607 m .35743 .74526 L p .33843 .75049 L .707 .577 .707 r
F P
0 g
s
.33843 .75049 m .34206 .76456 L .33666 .76534 L p .707 .577 .707 r
F P
0 g
s
.33666 .76534 m .31566 .76836 L p .33843 .75049 L .707 .577 .707 r
F P
0 g
s
.31566 .76836 m .31092 .74999 L .33732 .74619 L p .707 .577 .707 r
F P
0 g
s
.37368 .28399 m .33448 .78002 L .33486 .78032 L p .707 .577 .707 r
F P
0 g
s
.36247 .54945 m .37368 .28399 L .33486 .78032 L .707 .577 .707 r
F
.34754 .55016 m .33045 .76637 L p .34685 .60079 L F P
0 g
s
.34647 .62825 m .36658 .37382 L p .34685 .60079 L .707 .577 .707 r
F P
0 g
s
.36658 .37382 m .37368 .28399 L .3704 .27288 L p .707 .577 .707 r
F P
0 g
s
.3704 .27288 m .36965 .27034 L p .36658 .37382 L .707 .577 .707 r
F P
0 g
s
.33045 .76637 m .36115 .37794 L p .37967 .25798 L .707 .577 .707 r
F P
0 g
s
.36115 .37794 m .36965 .27034 L .37394 .26505 L p .707 .577 .707 r
F P
0 g
s
.37394 .26505 m .37967 .25798 L p .36115 .37794 L .707 .577 .707 r
F P
0 g
s
.33045 .76637 m .33448 .78002 L p .34685 .60079 L .707 .577 .707 r
F P
0 g
s
.36443 .75912 m .36917 .7775 L .37642 .77043 L p .707 .577 .707 r
F P
0 g
s
.37642 .77043 m .37168 .75206 L .36443 .75912 L p .707 .577 .707 r
F P
0 g
s
.37168 .75206 m .37642 .77043 L .37448 .76658 L p .707 .577 .707 r
F P
0 g
s
.38197 .79457 m .36443 .72905 L .35216 .79363 L .707 .577 .707 r
F
.37448 .76658 m .37401 .76565 L p .37361 .76335 L F P
0 g
s
.37361 .76335 m .37168 .75206 L .37448 .76658 L .707 .577 .707 r
F
.35216 .79363 m .38176 .80587 L p .38197 .79457 L F P
0 g
s
.37401 .76565 m .36927 .74728 L .37168 .75206 L p .707 .577 .707 r
F P
0 g
s
.38197 .79457 m .38528 .61932 L .36443 .72905 L .707 .577 .707 r
F
.39136 .2976 m .36377 .64663 L p .38528 .61932 L F P
0 g
s
.33448 .78002 m .34647 .62825 L p .34685 .60079 L .707 .577 .707 r
F P
0 g
s
.21813 .76801 m .22227 .73165 L .19501 .72375 L p .707 .577 .707 r
F P
0 g
s
.22227 .73165 m .21813 .76801 L .2491 .77341 L p .707 .577 .707 r
F P
0 g
s
.26989 .81298 m .26514 .79461 L .23502 .8009 L p .707 .577 .707 r
F P
0 g
s
.26514 .79461 m .26989 .81298 L .30077 .80482 L p .707 .577 .707 r
F P
0 g
s
.30077 .80482 m .29603 .78645 L .26514 .79461 L p .707 .577 .707 r
F P
0 g
s
.16963 .67636 m .1901 .62719 L .1791 .61116 L p .707 .577 .707 r
F P
0 g
s
.1901 .62719 m .16963 .67636 L .18868 .69308 L p .707 .577 .707 r
F P
0 g
s
.29603 .78645 m .30077 .80482 L .3294 .79557 L p .707 .577 .707 r
F P
0 g
s
.3294 .79557 m .32466 .7772 L .29603 .78645 L p .707 .577 .707 r
F P
0 g
s
.23502 .8009 m .23977 .81927 L .26989 .81298 L p .707 .577 .707 r
F P
0 g
s
.19501 .72375 m .19087 .76011 L .21813 .76801 L p .707 .577 .707 r
F P
0 g
s
.67852 .65928 m .65805 .70845 L .63282 .69267 L p .707 .577 .707 r
F P
0 g
s
.63282 .69267 m .65328 .6435 L .67852 .65928 L p .707 .577 .707 r
F P
0 g
s
.23977 .81927 m .23502 .8009 L .20862 .8047 L p .707 .577 .707 r
F P
0 g
s
.19087 .76011 m .19501 .72375 L .17413 .71413 L p .707 .577 .707 r
F P
0 g
s
.68931 .74027 m .68517 .77663 L .66429 .76701 L p .707 .577 .707 r
F P
0 g
s
.66429 .76701 m .66843 .73065 L .68931 .74027 L p .707 .577 .707 r
F P
0 g
s
.20862 .8047 m .21336 .82307 L .23977 .81927 L p .707 .577 .707 r
F P
0 g
s
.70044 .77265 m .70518 .79102 L .68507 .79195 L p .707 .577 .707 r
F P
0 g
s
.68507 .79195 m .68033 .77358 L .70044 .77265 L p .707 .577 .707 r
F P
0 g
s
.17413 .71413 m .16999 .75049 L .19087 .76011 L p .707 .577 .707 r
F P
0 g
s
.64665 .30916 m .60745 .80519 L .61747 .79283 L p .707 .577 .707 r
F P
0 g
s
.61747 .79283 m .65667 .2968 L .64665 .30916 L p .707 .577 .707 r
F P
0 g
s
.1791 .61116 m .15863 .66032 L .16963 .67636 L p .707 .577 .707 r
F P
0 g
s
.15863 .66032 m .1791 .61116 L .17722 .59738 L p .707 .577 .707 r
F P
0 g
s
.21336 .82307 m .20862 .8047 L .18851 .80563 L p .707 .577 .707 r
F P
0 g
s
.18851 .80563 m .19325 .824 L .21336 .82307 L p .707 .577 .707 r
F P
0 g
s
.16999 .75049 m .17413 .71413 L .16168 .70374 L p .707 .577 .707 r
F P
0 g
s
.66843 .73065 m .66429 .76701 L .63703 .75911 L p .707 .577 .707 r
F P
0 g
s
.63703 .75911 m .64117 .72275 L .66843 .73065 L p .707 .577 .707 r
F P
0 g
s
.68033 .77358 m .68507 .79195 L .65867 .79575 L p .707 .577 .707 r
F P
0 g
s
.65867 .79575 m .65393 .77738 L .68033 .77358 L p .707 .577 .707 r
F P
0 g
s
.16168 .70374 m .15754 .7401 L .16999 .75049 L p .707 .577 .707 r
F P
0 g
s
.17722 .59738 m .15676 .64655 L .15863 .66032 L p .707 .577 .707 r
F P
0 g
s
.19325 .824 m .18851 .80563 L .17667 .80361 L p .707 .577 .707 r
F P
0 g
s
.17667 .80361 m .18141 .82198 L .19325 .824 L p .707 .577 .707 r
F P
0 g
s
.15676 .64655 m .17722 .59738 L .18466 .58721 L p .707 .577 .707 r
F P
0 g
s
.65393 .77738 m .65867 .79575 L .62855 .80204 L p .707 .577 .707 r
F P
0 g
s
.62855 .80204 m .62381 .78367 L .65393 .77738 L p .707 .577 .707 r
F P
0 g
s
.15754 .7401 m .16168 .70374 L .15888 .69358 L p .707 .577 .707 r
F P
0 g
s
.65667 .2968 m .61747 .79283 L .61344 .77918 L p .707 .577 .707 r
F P
0 g
s
.61344 .77918 m .65264 .28315 L .65667 .2968 L p .707 .577 .707 r
F P
0 g
s
.15888 .69358 m .15473 .72994 L .15754 .7401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.18466 .58721 m .16419 .63638 L .15676 .64655 L p .707 .577 .707 r
F P
0 g
s
.18141 .82198 m .17667 .80361 L .17426 .79883 L p .707 .577 .707 r
F P
0 g
s
.17426 .79883 m .179 .8172 L .18141 .82198 L p .707 .577 .707 r
F P
0 g
s
.16419 .63638 m .18466 .58721 L .20067 .58165 L p .707 .577 .707 r
F P
0 g
s
.15473 .72994 m .15888 .69358 L .16599 .68466 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16599 .68466 m .16185 .72102 L .15473 .72994 L p .707 .577 .707 r
F P
0 g
s
.20067 .58165 m .18021 .63082 L .16419 .63638 L p .707 .577 .707 r
F P
0 g
s
.65264 .28315 m .61344 .77918 L .59576 .76557 L p .707 .577 .707 r
F P
0 g
s
.59576 .76557 m .63496 .26953 L .65264 .28315 L p .707 .577 .707 r
F P
0 g
s
.18021 .63082 m .20067 .58165 L .2237 .58123 L p .707 .577 .707 r
F P
0 g
s
.179 .8172 m .17426 .79883 L .18151 .79176 L p .707 .577 .707 r
F P
0 g
s
.18151 .79176 m .18625 .81014 L .179 .8172 L p .707 .577 .707 r
F P
0 g
s
.34047 .75401 m .37967 .25798 L .40276 .24813 L p .707 .577 .707 r
F P
0 g
s
.37967 .25798 m .34047 .75401 L .33045 .76637 L p .707 .577 .707 r
F P
0 g
s
.16185 .72102 m .16599 .68466 L .18233 .67785 L p .707 .577 .707 r
F P
0 g
s
.36927 .74728 m .37401 .76565 L .36217 .76363 L p .707 .577 .707 r
F P
0 g
s
.36217 .76363 m .35743 .74526 L .36927 .74728 L p .707 .577 .707 r
F P
0 g
s
.18233 .67785 m .17819 .71421 L .16185 .72102 L p .707 .577 .707 r
F P
0 g
s
.20324 .6304 m .2237 .58123 L .25149 .586 L p .707 .577 .707 r
F P
0 g
s
.2237 .58123 m .20324 .6304 L .18021 .63082 L p .707 .577 .707 r
F P
0 g
s
.33551 .62455 m .31504 .67372 L .28981 .65794 L p .707 .577 .707 r
F P
0 g
s
.28981 .65794 m .31027 .60877 L .33551 .62455 L p .707 .577 .707 r
F P
0 g
s
.18625 .81014 m .18151 .79176 L .19771 .7831 L p .707 .577 .707 r
F P
0 g
s
.19771 .7831 m .20245 .80147 L .18625 .81014 L p .707 .577 .707 r
F P
0 g
s
.17819 .71421 m .18233 .67785 L .20629 .67381 L p .707 .577 .707 r
F P
0 g
s
.63496 .26953 m .59576 .76557 L .56616 .75333 L p .707 .577 .707 r
F P
0 g
s
.56616 .75333 m .60536 .2573 L .63496 .26953 L p .707 .577 .707 r
F P
0 g
s
.23103 .63517 m .25149 .586 L .28132 .59549 L p .707 .577 .707 r
F P
0 g
s
.25149 .586 m .23103 .63517 L .20324 .6304 L p .707 .577 .707 r
F P
0 g
s
.35743 .74526 m .36217 .76363 L .34206 .76456 L p .707 .577 .707 r
F P
0 g
s
.31027 .60877 m .28981 .65794 L .26086 .64466 L p .707 .577 .707 r
F P
0 g
s
.26086 .64466 m .28132 .59549 L .31027 .60877 L p .707 .577 .707 r
F P
0 g
s
.28132 .59549 m .26086 .64466 L .23103 .63517 L p .707 .577 .707 r
F P
0 g
s
.40276 .24813 m .36356 .74416 L .34047 .75401 L p .707 .577 .707 r
F P
0 g
s
.36356 .74416 m .40276 .24813 L .43665 .24174 L p .707 .577 .707 r
F P
0 g
s
.20629 .67381 m .20215 .71017 L .17819 .71421 L p .707 .577 .707 r
F P
0 g
s
.32542 .68863 m .32128 .72499 L .29402 .7171 L p .707 .577 .707 r
F P
0 g
s
.29402 .7171 m .29816 .68074 L .32542 .68863 L p .707 .577 .707 r
F P
0 g
s
.72308 .66483 m .74354 .61566 L .71459 .60238 L p .707 .577 .707 r
F P
0 g
s
.74354 .61566 m .72308 .66483 L .75291 .67432 L p .707 .577 .707 r
F P
0 g
s
.75291 .67432 m .77337 .62515 L .74354 .61566 L p .707 .577 .707 r
F P
0 g
s
.20215 .71017 m .20629 .67381 L .23553 .67294 L p .707 .577 .707 r
F P
0 g
s
.69413 .65154 m .71459 .60238 L .68936 .5866 L p .707 .577 .707 r
F P
0 g
s
.71459 .60238 m .69413 .65154 L .72308 .66483 L p .707 .577 .707 r
F P
0 g
s
.20245 .80147 m .19771 .7831 L .22128 .77369 L p .707 .577 .707 r
F P
0 g
s
.77337 .62515 m .75291 .67432 L .7807 .67909 L p .707 .577 .707 r
F P
0 g
s
.7807 .67909 m .80116 .62992 L .77337 .62515 L p .707 .577 .707 r
F P
0 g
s
.22128 .77369 m .22602 .79206 L .20245 .80147 L p .707 .577 .707 r
F P
0 g
s
.29816 .68074 m .29402 .7171 L .26305 .71169 L p .707 .577 .707 r
F P
0 g
s
.26305 .71169 m .26719 .67533 L .29816 .68074 L p .707 .577 .707 r
F P
0 g
s
.60536 .2573 m .56616 .75333 L .52753 .74366 L p .707 .577 .707 r
F P
0 g
s
.52753 .74366 m .56673 .24763 L .60536 .2573 L p .707 .577 .707 r
F P
0 g
s
.23553 .67294 m .23139 .7093 L .20215 .71017 L p .707 .577 .707 r
F P
0 g
s
.66889 .63577 m .68936 .5866 L .67031 .56988 L p .707 .577 .707 r
F P
0 g
s
.68936 .5866 m .66889 .63577 L .69413 .65154 L p .707 .577 .707 r
F P
0 g
s
.23139 .7093 m .23553 .67294 L .26719 .67533 L p .707 .577 .707 r
F P
0 g
s
.26719 .67533 m .26305 .71169 L .23139 .7093 L p .707 .577 .707 r
F P
0 g
s
.40709 .72094 m .43797 .71278 L p .40526 .70341 L .707 .577 .707 r
F P
0 g
s
.43665 .24174 m .47804 .23945 L p .402 .70966 L .707 .577 .707 r
F P
0 g
s
.39926 .71491 m .43665 .24174 L p .402 .70966 L .707 .577 .707 r
F P
0 g
s
.40346 .70687 m .40709 .72094 L p .40526 .70341 L .707 .577 .707 r
F P
0 g
s
.43797 .71278 m .43323 .69441 L .40624 .70154 L p .707 .577 .707 r
F P
0 g
s
.47804 .23945 m .47565 .2696 L p .40222 .70924 L .707 .577 .707 r
F P
0 g
s
.402 .70966 m .47804 .23945 L .40222 .70924 L .707 .577 .707 r
F
.43797 .71278 m .40624 .70154 L .40526 .70341 L F
.40709 .72094 m .40346 .70687 L p .40146 .71899 L F P
0 g
s
.43323 .69441 m .43797 .71278 L .4666 .70354 L p .707 .577 .707 r
F P
0 g
s
.4666 .70354 m .46186 .68517 L .43323 .69441 L p .707 .577 .707 r
F P
0 g
s
.39745 .73777 m .402 .70966 L .40222 .70924 L .707 .577 .707 r
F
.39836 .73772 m .39745 .73777 L p .47565 .2696 L F P
0 g
s
.39745 .73777 m .39926 .71491 L p .402 .70966 L .707 .577 .707 r
F P
0 g
s
.39745 .73777 m .36356 .74416 L p .40525 .45757 L .707 .577 .707 r
F P
0 g
s
.43665 .24174 m .41354 .53426 L p .40525 .45757 L .707 .577 .707 r
F P
0 g
s
.41354 .53426 m .39745 .73777 L p .40525 .45757 L .707 .577 .707 r
F P
0 g
s
.37223 .70886 m .37697 .72723 L .40092 .72223 L p .707 .577 .707 r
F P
0 g
s
.40092 .72223 m .40709 .72094 L p .40146 .71899 L .707 .577 .707 r
F P
0 g
s
.40146 .71899 m .37223 .70886 L .40092 .72223 L .707 .577 .707 r
F
.43884 .73548 m .39836 .73772 L p .42595 .57065 L F P
0 g
s
.47565 .2696 m .44699 .63234 L p .42595 .57065 L .707 .577 .707 r
F P
0 g
s
.44699 .63234 m .43884 .73548 L p .42595 .57065 L .707 .577 .707 r
F P
0 g
s
.4099 .63959 m .42182 .61094 L p .40053 .58093 L .707 .577 .707 r
F P
0 g
s
.42182 .61094 m .43036 .59042 L .41922 .58687 L p .707 .577 .707 r
F P
0 g
s
.41922 .58687 m .40053 .58093 L p .42182 .61094 L .707 .577 .707 r
F P
0 g
s
.40624 .70154 m .40235 .70257 L p .40526 .70341 L .707 .577 .707 r
F P
0 g
s
.40235 .70257 m .37223 .70886 L p .40146 .71899 L .707 .577 .707 r
F P
0 g
s
.40346 .70687 m .40235 .70257 L p .40146 .71899 L .707 .577 .707 r
F P
0 g
s
.40235 .70257 m .40346 .70687 L p .40526 .70341 L .707 .577 .707 r
F P
0 g
s
.80116 .62992 m .7807 .67909 L .80373 .67867 L p .707 .577 .707 r
F P
0 g
s
.80373 .67867 m .82419 .6295 L .80116 .62992 L p .707 .577 .707 r
F P
0 g
s
.22602 .79206 m .22128 .77369 L .24991 .76444 L p .707 .577 .707 r
F P
0 g
s
.72932 .72339 m .73346 .68703 L .70248 .68163 L p .707 .577 .707 r
F P
0 g
s
.73346 .68703 m .72932 .72339 L .76097 .72578 L p .707 .577 .707 r
F P
0 g
s
.76097 .72578 m .76512 .68942 L .73346 .68703 L p .707 .577 .707 r
F P
0 g
s
.24991 .76444 m .25465 .78281 L .22602 .79206 L p .707 .577 .707 r
F P
0 g
s
.31092 .74999 m .31566 .76836 L .28554 .77465 L p .707 .577 .707 r
F P
0 g
s
.28554 .77465 m .2808 .75628 L .31092 .74999 L p .707 .577 .707 r
F P
0 g
s
.78098 .74017 m .77624 .7218 L .74536 .72996 L p .707 .577 .707 r
F P
0 g
s
.77624 .7218 m .78098 .74017 L .80961 .73093 L p .707 .577 .707 r
F P
0 g
s
.80961 .73093 m .80487 .71255 L .77624 .7218 L p .707 .577 .707 r
F P
0 g
s
.76512 .68942 m .76097 .72578 L .79021 .72491 L p .707 .577 .707 r
F P
0 g
s
.79021 .72491 m .79436 .68855 L .76512 .68942 L p .707 .577 .707 r
F P
0 g
s
.69834 .71799 m .70248 .68163 L .67522 .67373 L p .707 .577 .707 r
F P
0 g
s
.70248 .68163 m .69834 .71799 L .72932 .72339 L p .707 .577 .707 r
F P
0 g
s
.7501 .74833 m .74536 .72996 L .71524 .73625 L p .707 .577 .707 r
F P
0 g
s
.74536 .72996 m .7501 .74833 L .78098 .74017 L p .707 .577 .707 r
F P
0 g
s
.64984 .61905 m .67031 .56988 L .65931 .55385 L p .707 .577 .707 r
F P
0 g
s
.67031 .56988 m .64984 .61905 L .66889 .63577 L p .707 .577 .707 r
F P
0 g
s
.71524 .73625 m .71998 .75462 L .7501 .74833 L p .707 .577 .707 r
F P
0 g
s
.56673 .24763 m .52753 .74366 L .48366 .73751 L p .707 .577 .707 r
F P
0 g
s
.46186 .68517 m .4666 .70354 L .47121 .7017 L p .707 .577 .707 r
F P
0 g
s
.48366 .73751 m .43884 .73548 L p .45136 .66184 L .707 .577 .707 r
F P
0 g
s
.52286 .24148 m .4844 .72818 L p .45136 .66184 L .707 .577 .707 r
F P
0 g
s
.46429 .6878 m .46186 .68517 L .47121 .7017 L .707 .577 .707 r
F
.47182 .68832 m .46186 .68517 L .4755 .69998 L F
.52286 .24148 m .56673 .24763 L p .48495 .72992 L F P
0 g
s
.4844 .72818 m .52286 .24148 L p .48495 .72992 L .707 .577 .707 r
F P
0 g
s
.49017 .69412 m .48543 .67575 L .46186 .68517 L p .707 .577 .707 r
F P
0 g
s
.4844 .72818 m .48366 .73751 L p .45136 .66184 L .707 .577 .707 r
F P
0 g
s
.47121 .7017 m .4755 .69998 L p .46429 .6878 L .707 .577 .707 r
F P
0 g
s
.4755 .69998 m .49017 .69412 L p .47182 .68832 L .707 .577 .707 r
F P
0 g
s
.48366 .73751 m .4844 .72818 L p .48495 .72992 L .707 .577 .707 r
F P
0 g
s
.25465 .78281 m .24991 .76444 L .2808 .75628 L p .707 .577 .707 r
F P
0 g
s
.2808 .75628 m .28554 .77465 L .25465 .78281 L p .707 .577 .707 r
F P
0 g
s
.43884 .73548 m .45045 .58848 L p .46687 .57068 L .707 .577 .707 r
F P
0 g
s
.43769 .64435 m .45815 .59519 L .44617 .59313 L p .707 .577 .707 r
F P
0 g
s
.44617 .59313 m .43036 .59042 L p .43271 .60772 L .707 .577 .707 r
F P
0 g
s
.43769 .64435 m .44617 .59313 L .43271 .60772 L .707 .577 .707 r
F
.47804 .23945 m .52286 .24148 L p .46687 .57068 L F P
0 g
s
.45045 .58848 m .47804 .23945 L p .46687 .57068 L .707 .577 .707 r
F P
0 g
s
.71998 .75462 m .71524 .73625 L .68883 .74005 L p .707 .577 .707 r
F P
0 g
s
.80487 .71255 m .80961 .73093 L .83318 .72151 L p .707 .577 .707 r
F P
0 g
s
.83318 .72151 m .82844 .70314 L .80487 .71255 L p .707 .577 .707 r
F P
0 g
s
.79436 .68855 m .79021 .72491 L .81418 .72087 L p .707 .577 .707 r
F P
0 g
s
.81418 .72087 m .81832 .68451 L .79436 .68855 L p .707 .577 .707 r
F P
0 g
s
.67522 .67373 m .67108 .71009 L .69834 .71799 L p .707 .577 .707 r
F P
0 g
s
.68883 .74005 m .69357 .75842 L .71998 .75462 L p .707 .577 .707 r
F P
0 g
s
.82419 .6295 m .80373 .67867 L .81974 .6731 L p .707 .577 .707 r
F P
0 g
s
.81974 .6731 m .84021 .62393 L .82419 .6295 L p .707 .577 .707 r
F P
0 g
s
.67108 .71009 m .67522 .67373 L .65435 .66411 L p .707 .577 .707 r
F P
0 g
s
.65931 .55385 m .63884 .60302 L .64984 .61905 L p .707 .577 .707 r
F P
0 g
s
.65435 .66411 m .6502 .70047 L .67108 .71009 L p .707 .577 .707 r
F P
0 g
s
.69357 .75842 m .68883 .74005 L .66872 .74098 L p .707 .577 .707 r
F P
0 g
s
.63884 .60302 m .65931 .55385 L .65744 .54007 L p .707 .577 .707 r
F P
0 g
s
.66872 .74098 m .67347 .75935 L .69357 .75842 L p .707 .577 .707 r
F P
0 g
s
.81832 .68451 m .81418 .72087 L .83051 .71406 L p .707 .577 .707 r
F P
0 g
s
.82844 .70314 m .83318 .72151 L .84939 .71285 L p .707 .577 .707 r
F P
0 g
s
.84939 .71285 m .84464 .69447 L .82844 .70314 L p .707 .577 .707 r
F P
0 g
s
.83051 .71406 m .83466 .6777 L .81832 .68451 L p .707 .577 .707 r
F P
0 g
s
.6502 .70047 m .65435 .66411 L .64189 .65372 L p .707 .577 .707 r
F P
0 g
s
.84021 .62393 m .81974 .6731 L .82718 .66294 L p .707 .577 .707 r
F P
0 g
s
.82718 .66294 m .84765 .61377 L .84021 .62393 L p .707 .577 .707 r
F P
0 g
s
.64189 .65372 m .63775 .69008 L .6502 .70047 L p .707 .577 .707 r
F P
0 g
s
.65744 .54007 m .63697 .58924 L .63884 .60302 L p .707 .577 .707 r
F P
0 g
s
.67347 .75935 m .66872 .74098 L .65689 .73896 L p .707 .577 .707 r
F P
0 g
s
.65689 .73896 m .66163 .75733 L .67347 .75935 L p .707 .577 .707 r
F P
0 g
s
.63697 .58924 m .65744 .54007 L .66487 .52991 L p .707 .577 .707 r
F P
0 g
s
.83466 .6777 m .83051 .71406 L .83763 .70514 L p .707 .577 .707 r
F P
0 g
s
.83763 .70514 m .84177 .66878 L .83466 .6777 L p .707 .577 .707 r
F P
0 g
s
.84464 .69447 m .84939 .71285 L .85664 .70578 L p .707 .577 .707 r
F P
0 g
s
.85664 .70578 m .85189 .68741 L .84464 .69447 L p .707 .577 .707 r
F P
0 g
s
.63775 .69008 m .64189 .65372 L .63909 .64356 L p .707 .577 .707 r
F P
0 g
s
.84765 .61377 m .82718 .66294 L .8253 .64916 L p .707 .577 .707 r
F P
0 g
s
.8253 .64916 m .84577 .59999 L .84765 .61377 L p .707 .577 .707 r
F P
0 g
s
.63909 .64356 m .63495 .67992 L .63775 .69008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.66487 .52991 m .6444 .57908 L .63697 .58924 L p .707 .577 .707 r
F P
0 g
s
.66163 .75733 m .65689 .73896 L .65447 .73418 L p .707 .577 .707 r
F P
0 g
s
.65447 .73418 m .65921 .75255 L .66163 .75733 L p .707 .577 .707 r
F P
0 g
s
.6444 .57908 m .66487 .52991 L .68089 .52434 L p .707 .577 .707 r
F P
0 g
s
.84177 .66878 m .83763 .70514 L .83482 .69498 L p .707 .577 .707 r
F P
0 g
s
.83482 .69498 m .83897 .65862 L .84177 .66878 L p .707 .577 .707 r
F P
0 g
s
.85189 .68741 m .85664 .70578 L .85422 .701 L p .707 .577 .707 r
F P
0 g
s
.85422 .701 m .84948 .68263 L .85189 .68741 L p .707 .577 .707 r
F P
0 g
s
.63495 .67992 m .63909 .64356 L .6462 .63464 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84577 .59999 m .8253 .64916 L .8143 .63313 L p .707 .577 .707 r
F P
0 g
s
.8143 .63313 m .83477 .58396 L .84577 .59999 L p .707 .577 .707 r
F P
0 g
s
.38007 .6301 m .40053 .58093 L .37158 .56764 L p .707 .577 .707 r
F P
0 g
s
.40053 .58093 m .38007 .6301 L .4099 .63959 L p .707 .577 .707 r
F P
0 g
s
.35112 .61681 m .37158 .56764 L .34635 .55187 L p .707 .577 .707 r
F P
0 g
s
.37158 .56764 m .35112 .61681 L .38007 .6301 L p .707 .577 .707 r
F P
0 g
s
.6462 .63464 m .64206 .671 L .63495 .67992 L p .707 .577 .707 r
F P
0 g
s
.43036 .59042 m .4099 .63959 L .43769 .64435 L p .707 .577 .707 r
F P
0 g
s
.68089 .52434 m .66042 .57351 L .6444 .57908 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65921 .75255 m .65447 .73418 L .66172 .72711 L p .707 .577 .707 r
F P
0 g
s
.66042 .57351 m .68089 .52434 L .70392 .52392 L p .707 .577 .707 r
F P
0 g
s
.66172 .72711 m .66646 .74549 L .65921 .75255 L p .707 .577 .707 r
F P
0 g
s
.32588 .60104 m .34635 .55187 L .3273 .53515 L p .707 .577 .707 r
F P
0 g
s
.34635 .55187 m .32588 .60104 L .35112 .61681 L p .707 .577 .707 r
F P
0 g
s
.83897 .65862 m .83482 .69498 L .82237 .68459 L p .707 .577 .707 r
F P
0 g
s
.82237 .68459 m .82651 .64823 L .83897 .65862 L p .707 .577 .707 r
F P
0 g
s
.84948 .68263 m .85422 .701 L .84238 .69898 L p .707 .577 .707 r
F P
0 g
s
.84238 .69898 m .83764 .68061 L .84948 .68263 L p .707 .577 .707 r
F P
0 g
s
.45815 .59519 m .43769 .64435 L .46072 .64394 L p .707 .577 .707 r
F P
0 g
s
.46072 .64394 m .48118 .59477 L .45815 .59519 L p .707 .577 .707 r
F P
0 g
s
.64206 .671 m .6462 .63464 L .66254 .62783 L p .707 .577 .707 r
F P
0 g
s
.83477 .58396 m .8143 .63313 L .79525 .61641 L p .707 .577 .707 r
F P
0 g
s
.79525 .61641 m .81572 .56724 L .83477 .58396 L p .707 .577 .707 r
F P
0 g
s
.38631 .68137 m .39045 .64501 L .35947 .63961 L p .707 .577 .707 r
F P
0 g
s
.39045 .64501 m .38631 .68137 L .41796 .68376 L p .707 .577 .707 r
F P
0 g
s
.41796 .68376 m .42211 .6474 L .39045 .64501 L p .707 .577 .707 r
F P
0 g
s
.42211 .6474 m .41796 .68376 L .4472 .68289 L p .707 .577 .707 r
F P
0 g
s
.4472 .68289 m .45135 .64653 L .42211 .6474 L p .707 .577 .707 r
F P
0 g
s
.35533 .67597 m .35947 .63961 L .33221 .63171 L p .707 .577 .707 r
F P
0 g
s
.35947 .63961 m .35533 .67597 L .38631 .68137 L p .707 .577 .707 r
F P
0 g
s
.66254 .62783 m .6584 .66419 L .64206 .671 L p .707 .577 .707 r
F P
0 g
s
.30683 .58432 m .3273 .53515 L .3163 .51912 L p .707 .577 .707 r
F P
0 g
s
.3273 .53515 m .30683 .58432 L .32588 .60104 L p .707 .577 .707 r
F P
0 g
s
.68345 .57309 m .70392 .52392 L .73171 .52869 L p .707 .577 .707 r
F P
0 g
s
.70392 .52392 m .68345 .57309 L .66042 .57351 L p .707 .577 .707 r
F P
0 g
s
.45135 .64653 m .4472 .68289 L .47117 .67885 L p .707 .577 .707 r
F P
0 g
s
.47117 .67885 m .47531 .64249 L .45135 .64653 L p .707 .577 .707 r
F P
0 g
s
.33221 .63171 m .32807 .66807 L .35533 .67597 L p .707 .577 .707 r
F P
0 g
s
.66646 .74549 m .66172 .72711 L .67793 .71845 L p .707 .577 .707 r
F P
0 g
s
.81572 .56724 m .79525 .61641 L .77002 .60063 L p .707 .577 .707 r
F P
0 g
s
.77002 .60063 m .79049 .55146 L .81572 .56724 L p .707 .577 .707 r
F P
0 g
s
.37697 .72723 m .37223 .70886 L .34582 .71266 L p .707 .577 .707 r
F P
0 g
s
.32807 .66807 m .33221 .63171 L .31134 .62209 L p .707 .577 .707 r
F P
0 g
s
.82651 .64823 m .82237 .68459 L .8015 .67497 L p .707 .577 .707 r
F P
0 g
s
.8015 .67497 m .80564 .63861 L .82651 .64823 L p .707 .577 .707 r
F P
0 g
s
.48118 .59477 m .46072 .64394 L .47673 .63837 L p .707 .577 .707 r
F P
0 g
s
.47673 .63837 m .4972 .5892 L .48118 .59477 L p .707 .577 .707 r
F P
0 g
s
.67793 .71845 m .68267 .73682 L .66646 .74549 L p .707 .577 .707 r
F P
0 g
s
.34582 .71266 m .35056 .73103 L .37697 .72723 L p .707 .577 .707 r
F P
0 g
s
.83764 .68061 m .84238 .69898 L .82228 .69991 L p .707 .577 .707 r
F P
0 g
s
.82228 .69991 m .81754 .68154 L .83764 .68061 L p .707 .577 .707 r
F P
0 g
s
.6584 .66419 m .66254 .62783 L .6865 .62379 L p .707 .577 .707 r
F P
0 g
s
.71124 .57786 m .73171 .52869 L .76154 .53818 L p .707 .577 .707 r
F P
0 g
s
.73171 .52869 m .71124 .57786 L .68345 .57309 L p .707 .577 .707 r
F P
0 g
s
.79049 .55146 m .77002 .60063 L .74107 .58735 L p .707 .577 .707 r
F P
0 g
s
.74107 .58735 m .76154 .53818 L .79049 .55146 L p .707 .577 .707 r
F P
0 g
s
.31134 .62209 m .30719 .65845 L .32807 .66807 L p .707 .577 .707 r
F P
0 g
s
.76154 .53818 m .74107 .58735 L .71124 .57786 L p .707 .577 .707 r
F P
0 g
s
.3163 .51912 m .29583 .56829 L .30683 .58432 L p .707 .577 .707 r
F P
0 g
s
.29583 .56829 m .3163 .51912 L .31443 .50534 L p .707 .577 .707 r
F P
0 g
s
.35056 .73103 m .34582 .71266 L .32571 .71359 L p .707 .577 .707 r
F P
0 g
s
.47531 .64249 m .47117 .67885 L .4875 .67204 L p .707 .577 .707 r
F P
0 g
s
.4875 .67204 m .49165 .63568 L .47531 .64249 L p .707 .577 .707 r
F P
0 g
s
.6865 .62379 m .68236 .66015 L .6584 .66419 L p .707 .577 .707 r
F P
0 g
s
.32571 .71359 m .33046 .73196 L .35056 .73103 L p .707 .577 .707 r
F P
0 g
s
.48543 .67575 m .49017 .69412 L .50638 .68546 L p .707 .577 .707 r
F P
0 g
s
.50638 .68546 m .50163 .66709 L .48543 .67575 L p .707 .577 .707 r
F P
0 g
s
.30719 .65845 m .31134 .62209 L .29888 .6117 L p .707 .577 .707 r
F P
0 g
s
.80564 .63861 m .8015 .67497 L .77424 .66708 L p .707 .577 .707 r
F P
0 g
s
.77424 .66708 m .77838 .63072 L .80564 .63861 L p .707 .577 .707 r
F P
0 g
s
.68267 .73682 m .67793 .71845 L .70149 .70903 L p .707 .577 .707 r
F P
0 g
s
.68236 .66015 m .6865 .62379 L .71574 .62292 L p .707 .577 .707 r
F P
0 g
s
.70149 .70903 m .70624 .72741 L .68267 .73682 L p .707 .577 .707 r
F P
0 g
s
.4972 .5892 m .47673 .63837 L .48417 .6282 L p .707 .577 .707 r
F P
0 g
s
.48417 .6282 m .50464 .57904 L .4972 .5892 L p .707 .577 .707 r
F P
0 g
s
.81754 .68154 m .82228 .69991 L .79587 .70371 L p .707 .577 .707 r
F P
0 g
s
.79587 .70371 m .79113 .68534 L .81754 .68154 L p .707 .577 .707 r
F P
0 g
s
.29888 .6117 m .29474 .64806 L .30719 .65845 L p .707 .577 .707 r
F P
0 g
s
.77838 .63072 m .77424 .66708 L .74326 .66167 L p .707 .577 .707 r
F P
0 g
s
.74326 .66167 m .7474 .62531 L .77838 .63072 L p .707 .577 .707 r
F P
0 g
s
.71574 .62292 m .7116 .65928 L .68236 .66015 L p .707 .577 .707 r
F P
0 g
s
.31443 .50534 m .29396 .55451 L .29583 .56829 L p .707 .577 .707 r
F P
0 g
s
.7116 .65928 m .71574 .62292 L .7474 .62531 L p .707 .577 .707 r
F P
0 g
s
.33046 .73196 m .32571 .71359 L .31388 .71157 L p .707 .577 .707 r
F P
0 g
s
.7474 .62531 m .74326 .66167 L .7116 .65928 L p .707 .577 .707 r
F P
0 g
s
.49165 .63568 m .4875 .67204 L .49462 .66312 L p .707 .577 .707 r
F P
0 g
s
.49462 .66312 m .49876 .62676 L .49165 .63568 L p .707 .577 .707 r
F P
0 g
s
.70624 .72741 m .70149 .70903 L .73012 .69979 L p .707 .577 .707 r
F P
0 g
s
.31388 .71157 m .31862 .72994 L .33046 .73196 L p .707 .577 .707 r
F P
0 g
s
.29396 .55451 m .31443 .50534 L .32186 .49518 L p .707 .577 .707 r
F P
0 g
s
.73012 .69979 m .73487 .71816 L .70624 .72741 L p .707 .577 .707 r
F P
0 g
s
.79113 .68534 m .79587 .70371 L .76575 .71 L p .707 .577 .707 r
F P
0 g
s
.76575 .71 m .76101 .69163 L .79113 .68534 L p .707 .577 .707 r
F P
0 g
s
.50163 .66709 m .50638 .68546 L .51363 .67839 L p .707 .577 .707 r
F P
0 g
s
.51363 .67839 m .50888 .66002 L .50163 .66709 L p .707 .577 .707 r
F P
0 g
s
.29474 .64806 m .29888 .6117 L .29608 .60154 L p .707 .577 .707 r
F P
0 g
s
.73487 .71816 m .73012 .69979 L .76101 .69163 L p .707 .577 .707 r
F P
0 g
s
.76101 .69163 m .76575 .71 L .73487 .71816 L p .707 .577 .707 r
F P
0 g
s
.50464 .57904 m .48417 .6282 L .48229 .61443 L p .707 .577 .707 r
F P
0 g
s
.48229 .61443 m .50276 .56526 L .50464 .57904 L p .707 .577 .707 r
F P
0 g
s
.29608 .60154 m .29194 .63791 L .29474 .64806 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.32186 .49518 m .30139 .54434 L .29396 .55451 L p .707 .577 .707 r
F P
0 g
s
.31862 .72994 m .31388 .71157 L .31146 .70679 L p .707 .577 .707 r
F P
0 g
s
.49876 .62676 m .49462 .66312 L .49181 .65297 L p .707 .577 .707 r
F P
0 g
s
.49181 .65297 m .49595 .6166 L .49876 .62676 L p .707 .577 .707 r
F P
0 g
s
.31146 .70679 m .3162 .72516 L .31862 .72994 L p .707 .577 .707 r
F P
0 g
s
.30139 .54434 m .32186 .49518 L .33788 .48961 L p .707 .577 .707 r
F P
0 g
s
.50888 .66002 m .51363 .67839 L .51121 .67361 L p .707 .577 .707 r
F P
0 g
s
.51121 .67361 m .50647 .65524 L .50888 .66002 L p .707 .577 .707 r
F P
0 g
s
.29194 .63791 m .29608 .60154 L .30319 .59263 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.50276 .56526 m .48229 .61443 L .47129 .5984 L p .707 .577 .707 r
F P
0 g
s
.47129 .5984 m .49176 .54923 L .50276 .56526 L p .707 .577 .707 r
F P
0 g
s
.30319 .59263 m .29905 .62899 L .29194 .63791 L p .707 .577 .707 r
F P
0 g
s
.33788 .48961 m .31741 .53878 L .30139 .54434 L p .707 .577 .707 r
F P
0 g
s
.31741 .53878 m .33788 .48961 L .36091 .48919 L p .707 .577 .707 r
F P
0 g
s
.3162 .72516 m .31146 .70679 L .31871 .69973 L p .707 .577 .707 r
F P
0 g
s
.49595 .6166 m .49181 .65297 L .47936 .64257 L p .707 .577 .707 r
F P
0 g
s
.47936 .64257 m .4835 .60621 L .49595 .6166 L p .707 .577 .707 r
F P
0 g
s
.31871 .69973 m .32345 .7181 L .3162 .72516 L p .707 .577 .707 r
F P
0 g
s
.29905 .62899 m .30319 .59263 L .31953 .58581 L p .707 .577 .707 r
F P
0 g
s
.50647 .65524 m .51121 .67361 L .49937 .67159 L p .707 .577 .707 r
F P
0 g
s
.49937 .67159 m .49463 .65322 L .50647 .65524 L p .707 .577 .707 r
F P
0 g
s
.49176 .54923 m .47129 .5984 L .45224 .58168 L p .707 .577 .707 r
F P
0 g
s
.45224 .58168 m .47271 .53251 L .49176 .54923 L p .707 .577 .707 r
F P
0 g
s
.31953 .58581 m .31539 .62217 L .29905 .62899 L p .707 .577 .707 r
F P
0 g
s
.34044 .53836 m .36091 .48919 L .3887 .49396 L p .707 .577 .707 r
F P
0 g
s
.36091 .48919 m .34044 .53836 L .31741 .53878 L p .707 .577 .707 r
F P
0 g
s
.4835 .60621 m .47936 .64257 L .45849 .63296 L p .707 .577 .707 r
F P
0 g
s
.45849 .63296 m .46263 .59659 L .4835 .60621 L p .707 .577 .707 r
F P
0 g
s
.47271 .53251 m .45224 .58168 L .42701 .5659 L p .707 .577 .707 r
F P
0 g
s
.42701 .5659 m .44748 .51673 L .47271 .53251 L p .707 .577 .707 r
F P
0 g
s
.32345 .7181 m .31871 .69973 L .33491 .69106 L p .707 .577 .707 r
F P
0 g
s
.33491 .69106 m .33966 .70943 L .32345 .7181 L p .707 .577 .707 r
F P
0 g
s
.31539 .62217 m .31953 .58581 L .34349 .58177 L p .707 .577 .707 r
F P
0 g
s
.36823 .54313 m .3887 .49396 L .41853 .50345 L p .707 .577 .707 r
F P
0 g
s
.3887 .49396 m .36823 .54313 L .34044 .53836 L p .707 .577 .707 r
F P
0 g
s
.49463 .65322 m .49937 .67159 L .47927 .67253 L p .707 .577 .707 r
F P
0 g
s
.47927 .67253 m .47453 .65415 L .49463 .65322 L p .707 .577 .707 r
F P
0 g
s
.44748 .51673 m .42701 .5659 L .39806 .55262 L p .707 .577 .707 r
F P
0 g
s
.39806 .55262 m .41853 .50345 L .44748 .51673 L p .707 .577 .707 r
F P
0 g
s
.41853 .50345 m .39806 .55262 L .36823 .54313 L p .707 .577 .707 r
F P
0 g
s
.34349 .58177 m .33935 .61813 L .31539 .62217 L p .707 .577 .707 r
F P
0 g
s
.46263 .59659 m .45849 .63296 L .43122 .62506 L p .707 .577 .707 r
F P
0 g
s
.43122 .62506 m .43537 .5887 L .46263 .59659 L p .707 .577 .707 r
F P
0 g
s
.33935 .61813 m .34349 .58177 L .37273 .5809 L p .707 .577 .707 r
F P
0 g
s
.33966 .70943 m .33491 .69106 L .35848 .68165 L p .707 .577 .707 r
F P
0 g
s
.35848 .68165 m .36323 .70002 L .33966 .70943 L p .707 .577 .707 r
F P
0 g
s
.47453 .65415 m .47927 .67253 L .45286 .67632 L p .707 .577 .707 r
F P
0 g
s
.45286 .67632 m .44812 .65795 L .47453 .65415 L p .707 .577 .707 r
F P
0 g
s
.43537 .5887 m .43122 .62506 L .40025 .61965 L p .707 .577 .707 r
F P
0 g
s
.40025 .61965 m .40439 .58329 L .43537 .5887 L p .707 .577 .707 r
F P
0 g
s
.37273 .5809 m .36859 .61727 L .33935 .61813 L p .707 .577 .707 r
F P
0 g
s
.36859 .61727 m .37273 .5809 L .40439 .58329 L p .707 .577 .707 r
F P
0 g
s
.40439 .58329 m .40025 .61965 L .36859 .61727 L p .707 .577 .707 r
F P
0 g
s
.36323 .70002 m .35848 .68165 L .38711 .6724 L p .707 .577 .707 r
F P
0 g
s
.38711 .6724 m .39185 .69078 L .36323 .70002 L p .707 .577 .707 r
F P
0 g
s
.44812 .65795 m .45286 .67632 L .42274 .68261 L p .707 .577 .707 r
F P
0 g
s
.42274 .68261 m .418 .66424 L .44812 .65795 L p .707 .577 .707 r
F P
0 g
s
.39185 .69078 m .38711 .6724 L .418 .66424 L p .707 .577 .707 r
F P
0 g
s
.418 .66424 m .42274 .68261 L .39185 .69078 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol007Yooah008Eo
o`00MGoo1@000UYF00<005YFFUH025YF00<005YFFUH02UYF00@005YFFUIJEPH007moo`00LGoo1000
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH01eYF1@00NWoo001_Ool200000eYF001J
EP08FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUH00003001fOol006eo
o`8000=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00=JEP@0079oo`00Jgoo0P001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH01eYF0`00Kgoo001ZOol20006FUH00`00FUIJEP06FUH2000:FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH01000FUH00000KGoo001ZOol20006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH0
1000FUIJEUYF0`00JWoo001YOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH2001XOol006Uoo`03001J
EP0000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00EJEP8006Moo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00@005YF
000006Eoo`00JGoo00<005YF00001EYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Aoo`00JGoo0P00
1UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0HGoo001YOol20006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00Oomoo`1QOol006Qoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001oogoo065oo`00J7oo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00HWoo001XOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001ROol006Qoo`03
001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP80069oo`00J7oo00<005YF00001UYF00<0
05YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00HWoo001XOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH00`00Oomoo`1POol006Qoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00AJEP03001o
ogoo061oo`00J7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000HWoo
001XOol00`00FUH00005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0001ROol006Qoo`9J
EP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo069oo`00Igoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo069oo`00Igoo00<005YF00001UYF
00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00002UYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0HWoo001WOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIoo`1ROol006Moo`03001JEP0000IJEP03001JEUYF00MJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo069oo`00Igoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00Hgoo001WOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001SOol006Mo
o`03001JEP0000IJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006=oo`00Igoo0UYF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00eYF0P00Hgoo001WOol2FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH00`00FUH0001SOol006Moo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006=oo`00IWoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06=oo`00IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00
IWoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06=oo`00IWoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0Hgoo001VOol00`00FUH00006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001TOol006Ioo`03001JEP0000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF
0P00I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00002UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00I7oo001VOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001TOol006Ioo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00EJEP03001JEUYF00=JEP8006Aoo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YF0000I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000I7oo001UOol01000FUIJEP001EYF00<005YFFUH015YF00@005YFFUH000]JEP03001JEUYF00UJ
EP03001JEUYF00IJEP05001JEUYFFUH0000:FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001TOol006Eoo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1TOol0
06Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Aoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP03FUH00`00FUIJEP02000:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH01EYF00D005YFFUIJEP0000]JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IWoo001TOol0
0`00FUH00006FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001VOol006Aoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8006Ioo`00I7oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH0
0eYF0P00IWoo001SOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IWoo001NOol<0003FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005]oo`<0009J
EP03001JEUYF00=JEP04001JEUYFFUH60006FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001VOol005Yoo`80
00=JEP03001JEUYF00=JEP03001JEUYF00IJEP04001JEP000004FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001VOol005Yoo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEP<0
0003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Moo`00FGoo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YF
FUH01EYF0`002UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00Igoo001IOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUH000020007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol005Qoo`8000=JEP03001JEUYF00=JEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<000AJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Moo`00F7oo00<005YFFUH00UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF0P0000=JEP00FUH0
2eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00Igoo001G
Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000<
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001WOol005Mo
o`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP05001J
EUYFFUH0000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
001WOol005Ioo`8000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00MJEP03001JEUYF009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF00=JEP8000Uoo`d0055oo`00EWoo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0P0025YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P001Woo0`000UYF00<005YFFUH015YF00@0
05YFFUIJEPD004aoo`00EWoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001Goo0P000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YF00000P00BGoo001EOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP07FUH20005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00005Ool00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH00`00FUIJEP03FUH30016Ool005Eoo`03001JEUYF00`000AJEP03
001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30013Ool005Aoo`@000AJEP03001JEUYF00800003
Ool005YF00H000QJEP03001JEUYF00MJEP03001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004Ool20003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH00000@Goo001DOol00`00FUH0
0005FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0017oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH00UYF0`00?Woo001COol200000eYF001JEP03FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<0
05YF00000P0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YF000035YF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF0P00?7oo001COol00`00FUIJEP05FUH00`00
FUIJEP04FUH30006FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP05FUH3000<
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool00`00FUIJEP02FUH00`00
FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP07FUH3000jOol005=oo`03001J
EP0000AJEP03001JEUYF00AJEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH20005FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH01000FUH0000035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P000goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH01UYF00D005YFFUIJEP0003Uoo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
0UYF00<005YFFUH00UYF00@005YFFUIJEP<0009JEP@00003FUH005YF00QJEP03001JEUYF00AJEP04
001JEUYF000;FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003Ool20003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH0
0`00Oomoo`0fOol005Aoo`03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF00AJEP80009JEP03
001JEUYF00D00003FUH00000009JEP8000QJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00EJEP03001JEUYF00=JEP80009oo`8000=JEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8003Ioo`00
E7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF00000UYF1@0000=JEP00
FUH015YF0P001UYF00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH01EYF00<005YFFUH00eYF0P000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<007ooOol0<goo001EOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF0`000UYF1@0000=JEP00FUH01UYF00<005YFFUH00UYF00<005YF
FUH015YF00<005YFFUH00UYF0P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF
0P000Woo0P000UYF00@005YFFUIJEPD000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00MJEP8003Aoo`00EGoo00@005YFFUH000IJEP03001JEUYF00IJEP04001JEUYFFUH2000015YF0000
00000UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEP03001JEP0000UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP800003Ool00000009JEPH000Aoo`@0009J
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000cOol005Ioo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00=JEP8000AJEP03001JEUYF00MJEP<000MJEP03001J
EUYF009JEP03001JEP0000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00Ool40003FUH00`00FUIJEP020006Ool40007FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00<Goo000hOol;000COol00`00FUIJEP05FUHG000;FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH01000FUIJEP002EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00L005YF
001oo`00FUH00004FUH00`00FUIJEP02FUH00`00Oomoo`07Ool20005FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP03FUH00`00Oomoo`0^Ool003Ioo`800003FUH005YF00AJEP04001JEUYF
FUH6000>Ool00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP040007
FUH20005FUH00`00FUIJEP02FUH00`00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH000030004FUH00`00FUIJEP04FUH00`00Oomoo`08Ool300000eYF001JEP08
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00Oomoo`0]Ool003Aoo`80009JEP03001JEUYF00=J
EP03001JEUYF00IJEP04001JEP00000=Ool30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP04FUH40003FUH00`00FUH00003FUH00`00FUIJEP02FUH01000FUIJEP002UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0004FUH00`00FUIJEP04FUH3000;
Ool30007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH2000^Ool003=oo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF009JEP<000Qoo`80009JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009JEP04001JEUYF0004FUH00`00FUH0
000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000goo00000004FUH00`00
FUIJEP04FUH01@00FUIJEUYF00003Goo0P001EYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
0000;Woo000bOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30004Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH50005FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
00000goo00000004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20008Ool30002Ool300000eYF001J
EP08FUH00`00FUIJEP05FUH01000FUIJEP00;Goo000bOol20003FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH01000FUH000000Woo0P000eYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YF00002eYF00<005YF
FUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=oo`00FUH015YF00<005YFFUH015YF00<0
05YFFUH015YF0P001Goo1@0017oo0P002EYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0
:Woo000aOol20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH200001EYF001JEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00P000UYF00<005YF00002eYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0000=oo`00FUH00eYF00<005YFFUH015YF00<005YFFUH01eYF00<007ooOol0
0Woo1@001Woo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0:Woo000aOol20003
FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH00002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH300000eYF001JEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002Ool01@00FUIJEUYF00001UYF00<005YFFUH01eYF0`000Woo1@0027oo00<005YFFUH0
0eYF00<005YFFUH015YF00<005YFFUH00UYF0P00;7oo000`Ool20004FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH4000;FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20002Ool01000FUIJEP001UYF00<005YFFUH0
1eYF00@005YFFUIJEP800004Ool00000000:Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2
000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00=JEP03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20003Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2
000>Ool30007FUH01`00FUIJEUYF001JEP0002aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000eYF00@005YFFUIJEQ0000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYF000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20003Ool00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH3000=Ool00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH0000/Ool002moo`8000=JEP03
001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000=JEPH0
0006Ool005YFFUH005YF0P001UYF2@0015YF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUH0
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00=JEP8000Aoo`03001JEUYF00AJEP03
001JEUYF00MJEP03001JEUYF00MJEP03001JEP0000<000Yoo`03001JEUYF00=JEP07001JEUYFFUH0
05YF0000;Goo000_Ool00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH01000FUH005YF100015YF0P000UYF00@005YFFUIJEP8000AJEP03001JEUYF
00EJEPL000IJEP03001JEUYF00=JEP04001JEUYFFUH2000:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00005Ool20004FUHH0002FUH40007Ool01@00FUIJEUYF000015YF
00<005YF0000;Goo000^Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH2000015YF001JEUYF0P000UYF0P000UYF00<005YFFUH00eYF0P0000AJEP00FUIJ
EP<000=JEP03001JEUYF00AJEP8000AJEP03001JEUYF00=JEP04001JEUYFFUH2000:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00007Ool50003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP0500000eYF000000020004Ool01000FUIJEP0015YF00<005YF0000
;Goo000^Ool00`00FUIJEP0<0004FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUH00003FUH0
0`00FUIJEP02FUH40002FUH00`00FUIJEP03FUH00`00FUH000070002FUH00`00FUIJEP06FUH30000
0eYF001JEP04FUH01000FUIJEUYF0P002UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00001Goo0P0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF10000UYF1`0015YF00<005YF0000;Woo000]Ool40004FUH01000FUIJEP0017oo1P0025YF
00<005YFFUH015YF0P0015YF00<005YFFUH00eYF00<005YF00000`001EYF00<005YFFUH00UYF1@00
00=JEP00FUH01eYF00@005YFFUIJEP<000AJEP06001JEUYF001JEP002UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000goo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF000010000eYF00<005YFFUH00UYF00<005YF
0000;Woo000]Ool00`00FUH00005FUH01@00FUIJEUYF00002Goo0`001EYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00eYF00<005YFFUH00eYF100000=JEP00FUH00eYF20001eYF00<005YF
FUH00eYF100000MJEP00FUIJEP00FUH0000:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH200000eYF000000020004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP03FUH20003FUH01P00FUIJEP00FUH002moo`00;7oo0P0000=JEP00
FUH00eYF00<005YFFUH00eYF00<007ooOol02Goo0`0000=JEP00FUH01UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YF00000`000eYF1@000UYF10000UYF00<005YFFUH00eYF
00<005YF000010000UYF00<005YF00002EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000eYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH015YF0`0000MJEP00FUIJEP00FUH0000_Ool002aoo`03001JEUYF00EJEP03001J
EUYF00AJEP03001oogoo00]oo`8000QJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH80006FUH:0003FUH01000FUH005YF0P002UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH010000UYF00<007ooOol0;Goo000/Ool0
0`00FUH00004FUH00`00FUIJEP05FUH3000=Ool20006FUH01@00FUIJEUYF00001EYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF2@0015YF00<005YFFUH015YF00<005YFFUH00`002UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000=JEP00Ool0;goo000/Ool00`00FUH00004FUH00`00FUIJEP04FUH01000FUIJEUYF
0P0027oo0`000Woo0P0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP@000UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP8000AJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<0031oo`00
;Goo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00eYF0P001Goo1@000goo0P0000AJEP00
FUIJEP<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00L0009JEP04001JEP000007FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH20002FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUH00000;goo000]Ool00`00FUIJEP02FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00Oomoo`02Ool50005Ool20004FUH20004FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF20000eYF00<005YFFUH00eYF00<005YF
FUH00P001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF0P0015YF00@0
05YFFUIJEQ0000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00AJEP05001JEUYFFUH0
000^Ool002ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH30002Ool50007Ool20004FUH30000
0eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH60004FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01000FUIJEP001UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00eYF0P0000AJ
EP00FUH000=JEPD00003FUH0000000Qoo`800003FUH005YF00T000AJEP03001JEUYF00AJEP03001J
EUYF00AJEP05001JEUYFFUH0000^Ool002ioo`04001JEUYF0006FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P0000Aoo`00000000Yoo`8000=JEP03001JEP00008000IJEP03001JEUYF00EJEP03001JEUYF
00=JEP800003FUH005YF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008000EJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP08001JEP00FUH005YF001JEP@000=JEP04
001JEUYF0009Ool4000015YF000000000eYF1`001EYF00<005YFFUH00eYF00<005YFFUH00UYF0P00
;Goo000_Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH2000>Ool30005FUH20004
FUH00`00FUIJEP05FUH00`00FUIJEP030004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP040002FUH00`00FUIJEP03FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01P00
FUH005YF001JEP800004FUH005YFFUH200000eYF001JEP02FUH2000;Ool500000eYF001JEP06FUH4
00000eYF001JEP04FUH00`00FUIJEP02FUH2000]Ool002moo`03001JEUYF00EJEQ00009JEP<000eo
o`03001JEUYF00=JEP03001JEP0000800003FUH005YF00EJEP@000MJEP03001JEUYF00IJEP03001J
EUYF009JEPL0009JEPD000AJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001J
EP00FUH20003FUH00`00FUIJEP02FUH30004FUH00`00Oomoo`08Ool80006FUH01000FUIJEUYF0P00
1EYF00<005YFFUH00UYF0P00;Goo000`Ool00`00FUIJEP040003FUH00`00FUIJEP05FUH00`00FUIJ
EP02FUH9000:Ool00`00FUIJEP02FUH01@00FUIJEP00FUH020000UYF00<005YFFUH01UYF00<005YF
FUH01EYF1`0000AJEP00000000EJEP04001JEUYF0004FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01000FUH005YF0P000eYF00<005YFFUH00eYF00<005YF00000`0000=JEP00Ool0
27oo1@000goo100000=JEP00FUH00UYF1@000eYF00L005YFFUIJEP00FUH0000]Ool0035oo`<000IJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPH000Eoo`05001JEUYFFUH00002FUH0
0`00FUIJEP030006FUH00`00FUIJEP07FUH00`00FUIJEP050003FUH500000eYF001JEP04FUH30005
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20003FUH00`00FUIJEP03
FUH00`00FUIJEP03FUH50007Ool30008Ool50004Ool;000]Ool002moo`80009JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000<0009oo`04001JEUYF
0002FUH40009FUH00`00FUIJEP04FUH?0005FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUIJ
EP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH20002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP04000AOol60003FUH00`00FUIJEP03FUH01000FUH00000:goo000^Ool20003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03
FUH600000eYF00000003FUH00`00FUIJEP06FUH00`00FUIJEP040007FUH00`00FUIJEP0:FUH01@00
FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH0
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00AJEPL000Ioo`@00003FUH005YF00IJ
EP03001JEUYF00=JEP03001JEUYF008002Yoo`00;Woo0P000eYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF1@001EYF00<005YFFUH01EYF1@00
2UYF00<005YFFUH02eYF0`0025YF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF1000
00EJEP00FUIJEP0000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPH000IJEP03
001JEUYF00AJEP03001JEUYF00AJEP04001JEP00000ZOol002eoo`03001JEP0000=JEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP800003FUH0
05YF00EJEP03001JEUYF00=JEP8000=JEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00QJ
EP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF009JEP80009oo`<00003FUH005YF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEP00:Woo000]Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20003FUH00`00FUIJEP05FUH0
0`00FUH000020005FUH00`00FUIJEP09FUH00`00FUIJEP09FUH2000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH20004Ool30005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH40004
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP000000:Goo000]Ool00`00
FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP03FUH30007FUH40009FUH00`00FUIJEP05FUH400000eYF001J
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20005Ool30004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH30008FUH00`00FUIJEP06FUH01000FUIJEUYF1`0000=JEP00FUH01000
:Goo000]Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH00005FUH00`00FUH000030002FUH01000FUIJEUYF10000UYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00eYF0P001goo100000=JEP00FUH01UYF00@005YFFUIJEP@00003FUH005YF00QJEP03001J
EUYF009JEPP00003FUH005YF00=JEP03001JEP00009JEP03001JEP0002Uoo`00;Goo0P000eYF00<0
05YFFUH00eYF3P0015YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00001EYF0P0015YF1P00
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00eYF0P002Goo00<005YF00000P001UYF10001EYF00<005YFFUH01UYF1P000UYF
00<005YFFUH015YF00@005YFFUIJEP<000=JEP8002Yoo`00;7oo00<005YF00000eYF00<005YF0000
0`001Woo0P001UYF2@0015YF00<005YFFUH00UYF00@005YFFUH0009JEPP000=JEP03001JEUYF015J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000Yoo`04001JEUYFFUH20002FUH200000eYF001JEP07FUH00`00FUIJEP02FUH40007
FUH00`00FUIJEP04FUH01000FUIJEUYF0`000eYF00<007ooOol0:Goo000/Ool00`00FUH00003FUH2
000<Ool20004FUH00`00FUIJEP06FUH60003FUH00`00FUIJEP030004FUH00`00FUIJEP05FUH00`00
FUIJEP0@FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH000040007Ool01000FUIJEUYF0`000eYF00<005YFFUH01UYF00<005YF0000
0P000eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00`000UYF0P00;7oo000/Ool01000
FUH005YF0P0000AJEP00000000aoo`800003FUH005YF00QJEP03001JEUYF00=JEP80009JEP04001J
EP000005FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000300000eYF000000020004Ool0
1000FUH000001UYF00<005YFFUH015YF1P000eYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF
0`00;Woo000/Ool01P00FUH00000FUH000AJEP<000]oo`<00004FUH000000003FUH00`00FUIJEP06
FUH400000eYF001JEP05FUH00`00FUIJEP05FUH01000FUIJEUYF0`002UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF1000
0UYF1`001eYF00<005YFFUH02P000eYF00<005YFFUH01EYF00<005YF00000`001EYF0P00<7oo000/
Ool20003FUH00`00FUIJEP03FUH01000FUH0000037oo1@000UYF00<005YFFUH01EYF00<005YFFUH0
0P000UYF00<005YFFUH00eYF00<005YFFUH00UYF1`0000=JEP00FUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF00<005YF0000
1@000eYF00<005YFFUH015YF0`001Goo4P0015YF00<005YF00000P00<Woo000/Ool00`00FUIJEP02
FUH00`00FUIJEP03FUH01000FUIJEUYF0`002Goo1@0000=JEP00FUH01eYF00@005YFFUIJEP800003
FUH005YF009JEPL000QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEUYF009JEP8000AJEP03001JEUYF
009JEP8000Uoo`D000IJEP03001JEUYF00IJEP<003Eoo`00;7oo00D005YFFUIJEP0000IJEP03001J
EUYF00AJEPD000Aoo`X000AJEP03001JEUYF00=JEPH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF009J
EP8000EJEP07001JEUYFFUH005YF00001EYF00<005YF00000P001goo100000=JEP00FUH025YF00<0
05YFFUH00UYF0`00>7oo000/Ool01@00FUIJEUYF00001UYF00<005YFFUH01EYF00@005YFFUIJEPT0
00Eoo`d0009JEP03001JEUYF00AJEP03001JEUYF00AJEQh000UJEP03001JEUYF00QJEP03001JEUYF
00MJEP03001JEUYF009JEP8000EJEP05001JEUYFFUH00002FUH01000FUIJEUYF0`000UYF00<007oo
00001@001UYF00<005YFFUH01UYF00<005YF00000P00>goo000/Ool01@00FUIJEUYF00001UYF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF3`001EYF00<005YFFUH015YF00<005YFFUH0
10002eYF00<005YFFUH02EYF00<005YFFUH015YF1P000eYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF00D005YFFUH005YF00T000=JEP03001JEUYF00IJ
EP03001JEUYF00EJEP<003ioo`00;Goo00@005YFFUH000EJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH40003FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH50009FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH20004FUH00`00FUIJEP02FUH200000eYF00000004FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP040011Ool002ioo`<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF0080009JEP04001JEUYFFUH200000eYF00000004FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP02FUH40005FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP03FUH200000eYF001JEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP04FUH50015Ool0031oo`03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00=JEPH00006FUH005YFFUH005YF0P0000EJEP00FUIJEP0000AJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@00003FUH005YF00MJ
EP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP05001JEUYFFUH00004FUH00`00FUIJEP05FUH0
0`00FUIJEP04001:Ool0035oo`8000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEP0000<0009JEP03001JEUYF009JEP03001JEUYF008000=JEP05001JEUYFFUH00003FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUH000020007
FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP03FUH01000FUIJEUYF
1P00CWoo000cOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH40006FUH00`00
FUIJEP02FUH01000FUH000001EYF00@005YFFUH000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF009JEP<000AJEP03001JEUYF009JEP03001JEP00
00H000EJEPd005Aoo`00=Goo0`001UYF00<005YFFUH01EYF00@005YFFUIJEP@00003FUH005YF00QJ
EP04001JEUYFFUH300000eYF001JEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<0
05YF00001UYF0P000eYF00<005YFFUH00eYF00<005YFFUH00UYF0P00E7oo000hOol40002FUH00`00
FUIJEP05FUH40006FUH00`00FUIJEP06FUH01P00FUIJEUYF001JEP`0009JEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP<000AJEP03001JEP00
00IJEP06001JEP00001JEP001EYF00<005YFFUH00UYF0P00E7oo000lOol600001UYF00000000FUH0
00QJEP03001JEUYF00EJEPH00003FUH005YF00=JEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF0003FUH00`00FUH00004
00000eYF001JEP03FUH30004FUH01`00FUIJEUYF001JEP0005Aoo`00@7oo0`0015YF00<005YFFUH0
1eYF00<005YFFUH01@000eYF100015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP800003FUH0000000Eo
oa@005Aoo`00?Goo0`0025YF00<005YFFUH015YF3@000Woo0P0015YF00<005YFFUH01UYF00<005YF
FUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YF
FUH00eYF0`0037oo100000=JEP00FUH015YF00@005YF0000059oo`00>Woo0`0000=JEP00FUH025YF
00<005YFFUH0100037oo0`0000=JEP00FUH00eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0`001Woo
1P001EYF00<005YFFUH00eYF00<005YFFUH00P00DGoo000hOol20005FUH00`00FUIJEP05FUH4000<
Ool400000eYF001JEP02FUH01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00<005YF00001`000eYF
00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000055oo`00=Woo0`001UYF00<005YFFUH00eYF
0P002goo1@001EYF00<005YFFUH00UYF0P0000=JEP00FUH04UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00H005YF000005YF0008FUH00`00
FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00DGoo000dOol20002FUH00`00FUIJEP05FUH00`00
FUH000020009Ool40002FUH00`00FUIJEP06FUH01000FUIJEUYF10004eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF00H005YFFUH005YF0008
FUH00`00FUIJEP05FUH01000FUIJEUYF100000=JEP000000D7oo000cOol00`00FUIJEP03FUH00`00
FUIJEP03FUH30007Ool50006FUH00`00FUIJEP06FUH01000FUH000000goo00<005YFFUH01EYF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00H005YFFUH005YF0009FUH01000FUIJEUYF1`0000=JEP00FUH01000D7oo000bOol2
0005FUH00`00FUH000030006Ool40002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH30006Ool20005
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH00`00FUH00003FUH00`00FUIJEP04FUH600000eYF001JEP03FUH00`00FUH0
0002FUH00`00FUH0001@Ool0035oo`03001JEP0000EJEP8000Aoo`H000IJEP03001JEUYF00MJEP03
001JEUYF00@000]oo`8000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00D000IJEP04001JEUYF
FUH30003FUH2001AOol0035oo`04001JEUYF0002FUH80003FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH4000AOol200000eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEUYF1@0015YF00<005YFFUH015YF00@005YFFUIJ
EP<000=JEP03001oogoo051oo`00<Goo00<005YFFUH01@000UYF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF0`005goo100025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00@005YFFUIJEPH00003FUH005YF00IJEP03001JEUYF00AJEP04001JEUYF
FUH20002FUH2001COol0039oo`04001JEP000005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUH00002000NOol60002FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP07FUH00`00FUH000040004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUH00000FUH00`00
EGoo000bOol200000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH5000WOol50009FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH:0003FUH00`00FUIJEP05FUH01000FUIJ
EUYF1@000eYF00<007ooOol0EGoo000bOol20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH6000a
Ool60003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP070003OolD00000eYF001JEP03
FUH2001HOol003=oo`800003FUH005YF00AJEP03001JEUYF00@003eoo`X000IJEP03001JEUYF00AJ
EPP00004FUH000000006Ool60006FUH00`00FUIJEP07FUH01000FUH00000FWoo000eOol:001;Ool=
0004FUH00`00FUH000020007Ool60009FUH00`00FUIJEP04FUH4001LOol009=oo`03001JEP0000EJ
EP8000Aoo`H000IJEP03001JEUYF00IJEP03001JEUYF00@0061oo`00Tgoo00@005YFFUH0009JEPP0
00=JEP03001JEUYF00IJEP03001JEUYF00EJEP@006Aoo`00Tgoo00<005YFFUH00`000eYF00<005YF
FUH01EYF00<005YFFUH01eYF00<005YFFUH01000J7oo002DOol01000FUH000001EYF00<005YFFUH0
1EYF00<005YFFUH015YF1@00K7oo002DOol200000eYF001JEP04FUH00`00FUIJEP05FUH00`00FUIJ
EP04001aOol009Aoo`80009JEP03001JEUYF00=JEP04001JEUYFFUH6001eOol009Eoo`800003FUH0
05YF009JEPH007]oo`00Ugoo1@00PGoo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60194 .73743 m .58147 .68387 L .55252 .69383 L p .707 .577 .707 r
F P
0 g
s
.58147 .68387 m .60194 .73743 L .63177 .72596 L p .707 .577 .707 r
F P
0 g
s
.63177 .72596 m .6113 .6724 L .58147 .68387 L p .707 .577 .707 r
F P
0 g
s
.6113 .6724 m .63177 .72596 L .65956 .71409 L p .707 .577 .707 r
F P
0 g
s
.65956 .71409 m .63909 .66053 L .6113 .6724 L p .707 .577 .707 r
F P
0 g
s
.55252 .69383 m .57299 .74739 L .60194 .73743 L p .707 .577 .707 r
F P
0 g
s
.57299 .74739 m .55252 .69383 L .52729 .7013 L p .707 .577 .707 r
F P
0 g
s
.63909 .66053 m .65956 .71409 L .68259 .70299 L p .707 .577 .707 r
F P
0 g
s
.68259 .70299 m .66212 .64943 L .63909 .66053 L p .707 .577 .707 r
F P
0 g
s
.52729 .7013 m .54775 .75486 L .57299 .74739 L p .707 .577 .707 r
F P
0 g
s
.59975 .80399 m .59561 .76674 L .56463 .76839 L p .707 .577 .707 r
F P
0 g
s
.59561 .76674 m .59975 .80399 L .6314 .80001 L p .707 .577 .707 r
F P
0 g
s
.6314 .80001 m .62726 .76277 L .59561 .76674 L p .707 .577 .707 r
F P
0 g
s
.62726 .76277 m .6314 .80001 L .66064 .7941 L p .707 .577 .707 r
F P
0 g
s
.66064 .7941 m .6565 .75685 L .62726 .76277 L p .707 .577 .707 r
F P
0 g
s
.56877 .80564 m .56463 .76839 L .53737 .76755 L p .707 .577 .707 r
F P
0 g
s
.56463 .76839 m .56877 .80564 L .59975 .80399 L p .707 .577 .707 r
F P
0 g
s
.54775 .75486 m .52729 .7013 L .50824 .70554 L p .707 .577 .707 r
F P
0 g
s
.66212 .64943 m .68259 .70299 L .6986 .69374 L p .707 .577 .707 r
F P
0 g
s
.6986 .69374 m .67814 .64018 L .66212 .64943 L p .707 .577 .707 r
F P
0 g
s
.6565 .75685 m .66064 .7941 L .68461 .78681 L p .707 .577 .707 r
F P
0 g
s
.68461 .78681 m .68047 .74957 L .6565 .75685 L p .707 .577 .707 r
F P
0 g
s
.53737 .76755 m .54151 .8048 L .56877 .80564 L p .707 .577 .707 r
F P
0 g
s
.50824 .70554 m .5287 .7591 L .54775 .75486 L p .707 .577 .707 r
F P
0 g
s
.54151 .8048 m .53737 .76755 L .51649 .76429 L p .707 .577 .707 r
F P
0 g
s
.57726 .86212 m .582 .84477 L .55188 .83491 L p .707 .577 .707 r
F P
0 g
s
.582 .84477 m .57726 .86212 L .60814 .86853 L p .707 .577 .707 r
F P
0 g
s
.60814 .86853 m .61288 .85118 L .582 .84477 L p .707 .577 .707 r
F P
0 g
s
.54714 .85226 m .55188 .83491 L .52547 .82255 L p .707 .577 .707 r
F P
0 g
s
.55188 .83491 m .54714 .85226 L .57726 .86212 L p .707 .577 .707 r
F P
0 g
s
.61288 .85118 m .60814 .86853 L .63677 .87085 L p .707 .577 .707 r
F P
0 g
s
.63677 .87085 m .64151 .8535 L .61288 .85118 L p .707 .577 .707 r
F P
0 g
s
.51649 .76429 m .52063 .80154 L .54151 .8048 L p .707 .577 .707 r
F P
0 g
s
.68047 .74957 m .68461 .78681 L .70094 .77889 L p .707 .577 .707 r
F P
0 g
s
.70094 .77889 m .6968 .74164 L .68047 .74957 L p .707 .577 .707 r
F P
0 g
s
.5287 .7591 m .50824 .70554 L .49724 .70615 L p .707 .577 .707 r
F P
0 g
s
.52547 .82255 m .52073 .8399 L .54714 .85226 L p .707 .577 .707 r
F P
0 g
s
.67814 .64018 m .6986 .69374 L .70604 .68726 L p .707 .577 .707 r
F P
0 g
s
.70604 .68726 m .68557 .63369 L .67814 .64018 L p .707 .577 .707 r
F P
0 g
s
.49724 .70615 m .5177 .75971 L .5287 .7591 L p .707 .577 .707 r
F P
0 g
s
.52073 .8399 m .52547 .82255 L .50537 .80891 L p .707 .577 .707 r
F P
0 g
s
.64151 .8535 m .63677 .87085 L .66034 .86886 L p .707 .577 .707 r
F P
0 g
s
.66034 .86886 m .66508 .85151 L .64151 .8535 L p .707 .577 .707 r
F P
0 g
s
.52063 .80154 m .51649 .76429 L .50404 .75895 L p .707 .577 .707 r
F P
0 g
s
.50537 .80891 m .50062 .82627 L .52073 .8399 L p .707 .577 .707 r
F P
0 g
s
.50404 .75895 m .50818 .7962 L .52063 .80154 L p .707 .577 .707 r
F P
0 g
s
.6968 .74164 m .70094 .77889 L .70806 .77108 L p .707 .577 .707 r
F P
0 g
s
.70806 .77108 m .70392 .73383 L .6968 .74164 L p .707 .577 .707 r
F P
0 g
s
.50062 .82627 m .50537 .80891 L .49353 .79533 L p .707 .577 .707 r
F P
0 g
s
.5177 .75971 m .49724 .70615 L .49536 .70305 L p .707 .577 .707 r
F P
0 g
s
.66508 .85151 m .66034 .86886 L .67654 .86276 L p .707 .577 .707 r
F P
0 g
s
.67654 .86276 m .68128 .8454 L .66508 .85151 L p .707 .577 .707 r
F P
0 g
s
.68557 .63369 m .70604 .68726 L .70416 .68416 L p .707 .577 .707 r
F P
0 g
s
.70416 .68416 m .6837 .6306 L .68557 .63369 L p .707 .577 .707 r
F P
0 g
s
.49536 .70305 m .51583 .75662 L .5177 .75971 L p .707 .577 .707 r
F P
0 g
s
.49353 .79533 m .48879 .81268 L .50062 .82627 L p .707 .577 .707 r
F P
0 g
s
.50818 .7962 m .50404 .75895 L .50124 .75204 L p .707 .577 .707 r
F P
0 g
s
.51583 .75662 m .49536 .70305 L .5028 .69657 L p .707 .577 .707 r
F P
0 g
s
.5028 .69657 m .52326 .75013 L .51583 .75662 L p .707 .577 .707 r
F P
0 g
s
.50124 .75204 m .50538 .78929 L .50818 .7962 L p .707 .577 .707 r
F P
0 g
s
.50538 .78929 m .50124 .75204 L .50835 .74424 L p .707 .577 .707 r
F P
0 g
s
.50835 .74424 m .51249 .78149 L .50538 .78929 L p .707 .577 .707 r
F P
0 g
s
.52326 .75013 m .5028 .69657 L .51881 .68732 L p .707 .577 .707 r
F P
0 g
s
.51881 .68732 m .53928 .74088 L .52326 .75013 L p .707 .577 .707 r
F P
0 g
s
.51249 .78149 m .50835 .74424 L .52469 .73631 L p .707 .577 .707 r
F P
0 g
s
.52469 .73631 m .52883 .77356 L .51249 .78149 L p .707 .577 .707 r
F P
0 g
s
.49362 .79085 m .49836 .7735 L .51457 .76739 L p .707 .577 .707 r
F P
0 g
s
.51457 .76739 m .50982 .78475 L .49362 .79085 L p .707 .577 .707 r
F P
0 g
s
.53928 .74088 m .51881 .68732 L .54185 .67622 L p .707 .577 .707 r
F P
0 g
s
.54185 .67622 m .56231 .72978 L .53928 .74088 L p .707 .577 .707 r
F P
0 g
s
.52883 .77356 m .52469 .73631 L .54865 .72903 L p .707 .577 .707 r
F P
0 g
s
.50982 .78475 m .51457 .76739 L .53017 .76608 L p .707 .577 .707 r
F P
0 g
s
.54865 .72903 m .55279 .76627 L .52883 .77356 L p .707 .577 .707 r
F P
0 g
s
.56231 .72978 m .54185 .67622 L .55383 .6711 L p .707 .577 .707 r
F P
0 g
s
.55383 .6711 m .56964 .66435 L p .56729 .68534 L .707 .577 .707 r
F P
0 g
s
.56231 .72978 m .55383 .6711 L .56729 .68534 L .707 .577 .707 r
F
.53313 .64919 m .54328 .58598 L .47714 .31587 L F
.56964 .66435 m .5901 .71791 L .56231 .72978 L p F P
0 g
s
.55279 .76627 m .54865 .72903 L .56581 .72555 L p .707 .577 .707 r
F P
0 g
s
.55279 .76627 m .56581 .72555 L .56813 .7399 L .707 .577 .707 r
F
.57789 .72311 m .58203 .76036 L .55279 .76627 L p F P
0 g
s
.56116 .81606 m .54954 .66656 L p .53313 .64919 L .707 .577 .707 r
F P
0 g
s
.54954 .66656 m .54328 .58598 L p .53313 .64919 L .707 .577 .707 r
F P
0 g
s
.56581 .72555 m .57789 .72311 L p .56813 .7399 L .707 .577 .707 r
F P
0 g
s
.54328 .58598 m .52196 .31162 L .49934 .31376 L p .707 .577 .707 r
F P
0 g
s
.49934 .31376 m .47714 .31587 L p .54328 .58598 L .707 .577 .707 r
F P
0 g
s
.51634 .82031 m .56116 .81606 L p .54864 .7415 L .707 .577 .707 r
F P
0 g
s
.53017 .76608 m .53721 .76548 L p .52817 .77221 L .707 .577 .707 r
F P
0 g
s
.52817 .77221 m .53721 .76548 L .53681 .76631 L .707 .577 .707 r
F
.50982 .78475 m .53017 .76608 L .52817 .77221 L F
.5156 .81082 m .51634 .82031 L p .54864 .7415 L F P
0 g
s
.53814 .7654 m .53339 .78276 L .52449 .78351 L p .707 .577 .707 r
F P
0 g
s
.52449 .78351 m .50982 .78475 L p .52817 .77221 L .707 .577 .707 r
F P
0 g
s
.52817 .77221 m .53814 .7654 L .52449 .78351 L .707 .577 .707 r
F
.48879 .81268 m .49353 .79533 L .49111 .78313 L p F P
0 g
s
.49111 .78313 m .48637 .80048 L .48879 .81268 L p .707 .577 .707 r
F P
0 g
s
.48637 .80048 m .49111 .78313 L .49836 .7735 L p .707 .577 .707 r
F P
0 g
s
.49836 .7735 m .49362 .79085 L .48637 .80048 L p .707 .577 .707 r
F P
0 g
s
.43327 .31668 m .47247 .82112 L .51249 .82038 L p .707 .577 .707 r
F P
0 g
s
.51249 .82038 m .51634 .82031 L p .51505 .81251 L .707 .577 .707 r
F P
0 g
s
.51505 .81251 m .43327 .31668 L .51249 .82038 L .707 .577 .707 r
F
.47714 .31587 m .5156 .81082 L p .54864 .7415 L F P
0 g
s
.53721 .76548 m .53814 .7654 L p .53681 .76631 L .707 .577 .707 r
F P
0 g
s
.47714 .31587 m .43327 .31668 L p .51505 .81251 L .707 .577 .707 r
F P
0 g
s
.51634 .82031 m .5156 .81082 L p .51505 .81251 L .707 .577 .707 r
F P
0 g
s
.5156 .81082 m .47714 .31587 L p .51505 .81251 L .707 .577 .707 r
F P
0 g
s
.5901 .71791 m .57818 .68671 L p .59946 .65288 L .707 .577 .707 r
F P
0 g
s
.57818 .68671 m .56964 .66435 L .58078 .66007 L p .707 .577 .707 r
F P
0 g
s
.58078 .66007 m .59946 .65288 L p .57818 .68671 L .707 .577 .707 r
F P
0 g
s
.62841 .64292 m .64888 .69648 L .61993 .70644 L p .707 .577 .707 r
F P
0 g
s
.61993 .70644 m .59946 .65288 L .62841 .64292 L p .707 .577 .707 r
F P
0 g
s
.59946 .65288 m .61993 .70644 L .5901 .71791 L p .707 .577 .707 r
F P
0 g
s
.64052 .71748 m .64467 .75473 L .61369 .75638 L p .707 .577 .707 r
F P
0 g
s
.61369 .75638 m .60955 .71913 L .64052 .71748 L p .707 .577 .707 r
F P
0 g
s
.58203 .76036 m .57789 .72311 L .60955 .71913 L p .707 .577 .707 r
F P
0 g
s
.60955 .71913 m .61369 .75638 L .58203 .76036 L p .707 .577 .707 r
F P
0 g
s
.65418 .79635 m .64943 .81371 L .62303 .80135 L p .707 .577 .707 r
F P
0 g
s
.62303 .80135 m .62777 .784 L .65418 .79635 L p .707 .577 .707 r
F P
0 g
s
.62777 .784 m .62303 .80135 L .59908 .79351 L p .707 .577 .707 r
F P
0 g
s
.56116 .81606 m .60164 .80895 L p .59654 .77819 L .707 .577 .707 r
F P
0 g
s
.59376 .77333 m .59765 .77413 L p .59473 .77503 L .707 .577 .707 r
F P
0 g
s
.55219 .70058 m .56116 .81606 L p .59654 .77819 L .707 .577 .707 r
F P
0 g
s
.59291 .79149 m .56202 .78508 L p .59473 .77503 L .707 .577 .707 r
F P
0 g
s
.59765 .77413 m .59654 .77819 L p .59473 .77503 L .707 .577 .707 r
F P
0 g
s
.59654 .77819 m .59291 .79149 L p .59473 .77503 L .707 .577 .707 r
F P
0 g
s
.59291 .79149 m .59765 .77413 L .62777 .784 L p .707 .577 .707 r
F P
0 g
s
.52196 .31162 m .52434 .34228 L p .59778 .78036 L .707 .577 .707 r
F P
0 g
s
.59854 .79028 m .62777 .784 L .59908 .79351 L .707 .577 .707 r
F
.60254 .80879 m .598 .78074 L .59778 .78036 L F
.598 .78074 m .52196 .31162 L .59778 .78036 L F
.52434 .34228 m .55219 .70058 L p .59654 .77819 L F P
0 g
s
.56202 .78508 m .56676 .76773 L .59376 .77333 L p .707 .577 .707 r
F P
0 g
s
.56202 .78508 m .59376 .77333 L .59473 .77503 L .707 .577 .707 r
F
.59908 .79351 m .59291 .79149 L p .59854 .79028 L F P
0 g
s
.60164 .80895 m .60254 .80879 L p .52434 .34228 L .707 .577 .707 r
F P
0 g
s
.60254 .80879 m .63644 .79921 L p .59474 .51693 L .707 .577 .707 r
F P
0 g
s
.56334 .30435 m .58646 .60183 L p .59474 .51693 L .707 .577 .707 r
F P
0 g
s
.58646 .60183 m .60254 .80879 L p .59474 .51693 L .707 .577 .707 r
F P
0 g
s
.60254 .80879 m .56334 .30435 L .52196 .31162 L p .707 .577 .707 r
F P
0 g
s
.70392 .73383 m .70806 .77108 L .70525 .76417 L p .707 .577 .707 r
F P
0 g
s
.70525 .76417 m .70111 .72692 L .70392 .73383 L p .707 .577 .707 r
F P
0 g
s
.68128 .8454 m .67654 .86276 L .68379 .85313 L p .707 .577 .707 r
F P
0 g
s
.68379 .85313 m .68853 .83578 L .68128 .8454 L p .707 .577 .707 r
F P
0 g
s
.47247 .82112 m .43327 .31668 L .39464 .31397 L p .707 .577 .707 r
F P
0 g
s
.6837 .6306 m .70416 .68416 L .69316 .68477 L p .707 .577 .707 r
F P
0 g
s
.69316 .68477 m .6727 .63121 L .6837 .6306 L p .707 .577 .707 r
F P
0 g
s
.63644 .79921 m .59724 .29476 L .56334 .30435 L p .707 .577 .707 r
F P
0 g
s
.25893 .69853 m .23846 .64497 L .20951 .65493 L p .707 .577 .707 r
F P
0 g
s
.23846 .64497 m .25893 .69853 L .28876 .68706 L p .707 .577 .707 r
F P
0 g
s
.28876 .68706 m .26829 .6335 L .23846 .64497 L p .707 .577 .707 r
F P
0 g
s
.26829 .6335 m .28876 .68706 L .31655 .67519 L p .707 .577 .707 r
F P
0 g
s
.31655 .67519 m .29608 .62163 L .26829 .6335 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.43384 .81842 m .39464 .31397 L .36504 .30801 L p .707 .577 .707 r
F P
0 g
s
.39464 .31397 m .43384 .81842 L .47247 .82112 L p .707 .577 .707 r
F P
0 g
s
.20951 .65493 m .22998 .70849 L .25893 .69853 L p .707 .577 .707 r
F P
0 g
s
.70111 .72692 m .70525 .76417 L .6928 .75883 L p .707 .577 .707 r
F P
0 g
s
.6928 .75883 m .68866 .72158 L .70111 .72692 L p .707 .577 .707 r
F P
0 g
s
.22998 .70849 m .20951 .65493 L .18428 .6624 L p .707 .577 .707 r
F P
0 g
s
.68853 .83578 m .68379 .85313 L .68138 .84093 L p .707 .577 .707 r
F P
0 g
s
.68138 .84093 m .68612 .82358 L .68853 .83578 L p .707 .577 .707 r
F P
0 g
s
.29608 .62163 m .31655 .67519 L .33958 .66409 L p .707 .577 .707 r
F P
0 g
s
.33958 .66409 m .31911 .61053 L .29608 .62163 L p .707 .577 .707 r
F P
0 g
s
.18428 .6624 m .20474 .71596 L .22998 .70849 L p .707 .577 .707 r
F P
0 g
s
.6727 .63121 m .69316 .68477 L .67411 .68901 L p .707 .577 .707 r
F P
0 g
s
.67411 .68901 m .65365 .63545 L .6727 .63121 L p .707 .577 .707 r
F P
0 g
s
.64888 .69648 m .62841 .64292 L .65365 .63545 L p .707 .577 .707 r
F P
0 g
s
.66778 .71833 m .67193 .75557 L .64467 .75473 L p .707 .577 .707 r
F P
0 g
s
.64467 .75473 m .64052 .71748 L .66778 .71833 L p .707 .577 .707 r
F P
0 g
s
.59724 .29476 m .63644 .79921 L .65953 .78825 L p .707 .577 .707 r
F P
0 g
s
.65365 .63545 m .67411 .68901 L .64888 .69648 L p .707 .577 .707 r
F P
0 g
s
.65953 .78825 m .62033 .28381 L .59724 .29476 L p .707 .577 .707 r
F P
0 g
s
.25674 .77238 m .2526 .73513 L .22162 .73678 L p .707 .577 .707 r
F P
0 g
s
.2526 .73513 m .25674 .77238 L .2884 .7684 L p .707 .577 .707 r
F P
0 g
s
.2884 .7684 m .28425 .73115 L .2526 .73513 L p .707 .577 .707 r
F P
0 g
s
.28425 .73115 m .2884 .7684 L .31764 .76248 L p .707 .577 .707 r
F P
0 g
s
.31764 .76248 m .31349 .72523 L .28425 .73115 L p .707 .577 .707 r
F P
0 g
s
.22576 .77403 m .22162 .73678 L .19436 .73594 L p .707 .577 .707 r
F P
0 g
s
.22162 .73678 m .22576 .77403 L .25674 .77238 L p .707 .577 .707 r
F P
0 g
s
.20474 .71596 m .18428 .6624 L .16523 .66664 L p .707 .577 .707 r
F P
0 g
s
.31911 .61053 m .33958 .66409 L .35559 .65484 L p .707 .577 .707 r
F P
0 g
s
.35559 .65484 m .33513 .60128 L .31911 .61053 L p .707 .577 .707 r
F P
0 g
s
.31349 .72523 m .31764 .76248 L .3416 .7552 L p .707 .577 .707 r
F P
0 g
s
.3416 .7552 m .33746 .71795 L .31349 .72523 L p .707 .577 .707 r
F P
0 g
s
.16523 .66664 m .18569 .7202 L .20474 .71596 L p .707 .577 .707 r
F P
0 g
s
.68866 .72158 m .6928 .75883 L .67193 .75557 L p .707 .577 .707 r
F P
0 g
s
.67193 .75557 m .66778 .71833 L .68866 .72158 L p .707 .577 .707 r
F P
0 g
s
.19436 .73594 m .1985 .77318 L .22576 .77403 L p .707 .577 .707 r
F P
0 g
s
.40424 .81246 m .36504 .30801 L .34736 .29938 L p .707 .577 .707 r
F P
0 g
s
.36504 .30801 m .40424 .81246 L .43384 .81842 L p .707 .577 .707 r
F P
0 g
s
.68612 .82358 m .68138 .84093 L .66954 .82734 L p .707 .577 .707 r
F P
0 g
s
.66954 .82734 m .67428 .80999 L .68612 .82358 L p .707 .577 .707 r
F P
0 g
s
.23425 .81588 m .23899 .79853 L .20887 .78867 L p .707 .577 .707 r
F P
0 g
s
.23899 .79853 m .23425 .81588 L .26513 .82229 L p .707 .577 .707 r
F P
0 g
s
.26513 .82229 m .26987 .80494 L .23899 .79853 L p .707 .577 .707 r
F P
0 g
s
.1985 .77318 m .19436 .73594 L .17348 .73268 L p .707 .577 .707 r
F P
0 g
s
.20413 .80602 m .20887 .78867 L .18246 .77631 L p .707 .577 .707 r
F P
0 g
s
.20887 .78867 m .20413 .80602 L .23425 .81588 L p .707 .577 .707 r
F P
0 g
s
.26987 .80494 m .26513 .82229 L .29376 .82461 L p .707 .577 .707 r
F P
0 g
s
.29376 .82461 m .2985 .80726 L .26987 .80494 L p .707 .577 .707 r
F P
0 g
s
.17348 .73268 m .17763 .76993 L .1985 .77318 L p .707 .577 .707 r
F P
0 g
s
.33746 .71795 m .3416 .7552 L .35794 .74727 L p .707 .577 .707 r
F P
0 g
s
.35794 .74727 m .35379 .71002 L .33746 .71795 L p .707 .577 .707 r
F P
0 g
s
.18569 .7202 m .16523 .66664 L .15423 .66725 L p .707 .577 .707 r
F P
0 g
s
.18246 .77631 m .17772 .79366 L .20413 .80602 L p .707 .577 .707 r
F P
0 g
s
.62033 .28381 m .65953 .78825 L .66955 .777 L p .707 .577 .707 r
F P
0 g
s
.66955 .777 m .63035 .27255 L .62033 .28381 L p .707 .577 .707 r
F P
0 g
s
.33513 .60128 m .35559 .65484 L .36303 .64836 L p .707 .577 .707 r
F P
0 g
s
.36303 .64836 m .34256 .59479 L .33513 .60128 L p .707 .577 .707 r
F P
0 g
s
.15423 .66725 m .17469 .72081 L .18569 .7202 L p .707 .577 .707 r
F P
0 g
s
.17772 .79366 m .18246 .77631 L .16236 .76267 L p .707 .577 .707 r
F P
0 g
s
.2985 .80726 m .29376 .82461 L .31733 .82262 L p .707 .577 .707 r
F P
0 g
s
.31733 .82262 m .32207 .80527 L .2985 .80726 L p .707 .577 .707 r
F P
0 g
s
.67428 .80999 m .66954 .82734 L .64943 .81371 L p .707 .577 .707 r
F P
0 g
s
.64943 .81371 m .65418 .79635 L .67428 .80999 L p .707 .577 .707 r
F P
0 g
s
.16236 .76267 m .15761 .78002 L .17772 .79366 L p .707 .577 .707 r
F P
0 g
s
.17763 .76993 m .17348 .73268 L .16103 .72734 L p .707 .577 .707 r
F P
0 g
s
.16103 .72734 m .16517 .76459 L .17763 .76993 L p .707 .577 .707 r
F P
0 g
s
.35379 .71002 m .35794 .74727 L .36505 .73947 L p .707 .577 .707 r
F P
0 g
s
.36505 .73947 m .36091 .70222 L .35379 .71002 L p .707 .577 .707 r
F P
0 g
s
.38656 .80383 m .34736 .29938 L .34333 .28893 L p .707 .577 .707 r
F P
0 g
s
.34736 .29938 m .38656 .80383 L .40424 .81246 L p .707 .577 .707 r
F P
0 g
s
.15761 .78002 m .16236 .76267 L .15052 .74909 L p .707 .577 .707 r
F P
0 g
s
.17469 .72081 m .15423 .66725 L .15235 .66415 L p .707 .577 .707 r
F P
0 g
s
.32207 .80527 m .31733 .82262 L .33353 .81652 L p .707 .577 .707 r
F P
0 g
s
.33353 .81652 m .33828 .79916 L .32207 .80527 L p .707 .577 .707 r
F P
0 g
s
.53339 .78276 m .53814 .7654 L .56676 .76773 L p .707 .577 .707 r
F P
0 g
s
.34256 .59479 m .36303 .64836 L .36116 .64527 L p .707 .577 .707 r
F P
0 g
s
.36116 .64527 m .34069 .5917 L .34256 .59479 L p .707 .577 .707 r
F P
0 g
s
.15052 .74909 m .14578 .76644 L .15761 .78002 L p .707 .577 .707 r
F P
0 g
s
.15235 .66415 m .17282 .71772 L .17469 .72081 L p .707 .577 .707 r
F P
0 g
s
.56676 .76773 m .56202 .78508 L .53339 .78276 L p .707 .577 .707 r
F P
0 g
s
.16517 .76459 m .16103 .72734 L .15823 .72043 L p .707 .577 .707 r
F P
0 g
s
.66955 .777 m .66552 .76655 L p .65315 .59284 L .707 .577 .707 r
F P
0 g
s
.65315 .59284 m .64251 .44341 L .65269 .569 L .707 .577 .707 r
F
.65315 .59284 m .65269 .569 L .66955 .777 L F
.65793 .74787 m .66157 .73457 L p .64257 .71688 L F P
0 g
s
.62632 .2621 m .66371 .74329 L p .6632 .74119 L .707 .577 .707 r
F P
0 g
s
.66014 .7288 m .64257 .71688 L p .66157 .73457 L .707 .577 .707 r
F P
0 g
s
.66157 .73457 m .65793 .74787 L .66334 .7504 L p .707 .577 .707 r
F P
0 g
s
.64257 .71688 m .63783 .73423 L .65793 .74787 L p .707 .577 .707 r
F P
0 g
s
.66513 .76636 m .64784 .75792 L p .63753 .52036 L .707 .577 .707 r
F P
0 g
s
.63753 .52036 m .62632 .2621 L .66513 .76636 L .707 .577 .707 r
F
.66157 .73457 m .66268 .73051 L .66014 .7288 L p F P
0 g
s
.66552 .76655 m .66513 .76636 L p .6632 .74119 L .707 .577 .707 r
F P
0 g
s
.66371 .74329 m .66552 .76655 L p .6632 .74119 L .707 .577 .707 r
F P
0 g
s
.63885 .38199 m .66955 .777 L p .64251 .44341 L .707 .577 .707 r
F P
0 g
s
.62632 .2621 m .63035 .27255 L p .64251 .44341 L .707 .577 .707 r
F P
0 g
s
.66552 .76655 m .65353 .6122 L p .65315 .59284 L .707 .577 .707 r
F P
0 g
s
.65491 .66767 m .66591 .66706 L p .65421 .64737 L .707 .577 .707 r
F P
0 g
s
.64784 .75792 m .60864 .25347 L .62632 .2621 L p .707 .577 .707 r
F P
0 g
s
.63783 .73423 m .64257 .71688 L .63073 .70329 L p .707 .577 .707 r
F P
0 g
s
.63073 .70329 m .62599 .72064 L .63783 .73423 L p .707 .577 .707 r
F P
0 g
s
.62599 .72064 m .63073 .70329 L .63064 .70281 L p .707 .577 .707 r
F P
0 g
s
.61802 .74088 m .61472 .56899 L .63557 .68792 L .707 .577 .707 r
F
.63064 .70281 m .62832 .69109 L p .62638 .71565 L F P
0 g
s
.62599 .72064 m .63064 .70281 L .62638 .71565 L .707 .577 .707 r
F
.64784 .75792 m .61824 .75196 L p .61802 .74088 L F P
0 g
s
.62832 .69109 m .62358 .70844 L .62599 .72064 L p .707 .577 .707 r
F P
0 g
s
.61802 .74088 m .63557 .68792 L .64784 .75792 L .707 .577 .707 r
F
.60864 .25347 m .63622 .60842 L p .61472 .56899 L F P
0 g
s
.63622 .60842 m .64784 .75792 L p .61472 .56899 L .707 .577 .707 r
F P
0 g
s
.65421 .64737 m .65126 .63597 L .63444 .61411 L .707 .577 .707 r
F
.64544 .6135 m .63918 .61385 L p .65126 .63597 L F P
0 g
s
.63918 .61385 m .63444 .61411 L p .65126 .63597 L .707 .577 .707 r
F P
0 g
s
.63444 .61411 m .65458 .66683 L p .65421 .64737 L .707 .577 .707 r
F P
0 g
s
.65458 .66683 m .65491 .66767 L p .65421 .64737 L .707 .577 .707 r
F P
0 g
s
.65315 .59284 m .64944 .55958 L .64251 .44341 L .707 .577 .707 r
F
.65353 .6122 m .64944 .55958 L p .65315 .59284 L F P
0 g
s
.64944 .55958 m .62632 .2621 L p .64251 .44341 L .707 .577 .707 r
F P
0 g
s
.66591 .66706 m .68496 .66282 L p .65323 .62322 L .707 .577 .707 r
F P
0 g
s
.64544 .6135 m .65399 .63586 L p .65323 .62322 L .707 .577 .707 r
F P
0 g
s
.65399 .63586 m .66591 .66706 L p .65323 .62322 L .707 .577 .707 r
F P
0 g
s
.66268 .73051 m .66157 .73457 L p .68434 .76022 L .707 .577 .707 r
F P
0 g
s
.66334 .7504 m .68434 .76022 L p .66157 .73457 L .707 .577 .707 r
F P
0 g
s
.66591 .66706 m .65399 .63586 L p .65421 .64737 L .707 .577 .707 r
F P
0 g
s
.65399 .63586 m .64544 .6135 L p .65421 .64737 L .707 .577 .707 r
F P
0 g
s
.68496 .66282 m .66449 .60926 L .65256 .61192 L p .707 .577 .707 r
F P
0 g
s
.65256 .61192 m .64544 .6135 L p .65323 .62322 L .707 .577 .707 r
F P
0 g
s
.68496 .66282 m .65256 .61192 L .65323 .62322 L .707 .577 .707 r
F
.63035 .27255 m .63885 .38199 L p .64251 .44341 L F P
0 g
s
.15823 .72043 m .16237 .75768 L .16517 .76459 L p .707 .577 .707 r
F P
0 g
s
.14578 .76644 m .15052 .74909 L .1481 .73688 L p .707 .577 .707 r
F P
0 g
s
.36091 .70222 m .36505 .73947 L .36224 .73256 L p .707 .577 .707 r
F P
0 g
s
.36224 .73256 m .3581 .69531 L .36091 .70222 L p .707 .577 .707 r
F P
0 g
s
.33828 .79916 m .33353 .81652 L .34078 .80689 L p .707 .577 .707 r
F P
0 g
s
.34078 .80689 m .34552 .78954 L .33828 .79916 L p .707 .577 .707 r
F P
0 g
s
.1481 .73688 m .14336 .75424 L .14578 .76644 L p .707 .577 .707 r
F P
0 g
s
.17282 .71772 m .15235 .66415 L .15979 .65767 L p .707 .577 .707 r
F P
0 g
s
.34069 .5917 m .36116 .64527 L .35015 .64587 L p .707 .577 .707 r
F P
0 g
s
.35015 .64587 m .32969 .59231 L .34069 .5917 L p .707 .577 .707 r
F P
0 g
s
.15979 .65767 m .18025 .71123 L .17282 .71772 L p .707 .577 .707 r
F P
0 g
s
.34333 .28893 m .38253 .79338 L .38656 .80383 L p .707 .577 .707 r
F P
0 g
s
.38253 .79338 m .34333 .28893 L .35335 .27768 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16237 .75768 m .15823 .72043 L .16534 .71262 L p .707 .577 .707 r
F P
0 g
s
.16534 .71262 m .16948 .74987 L .16237 .75768 L p .707 .577 .707 r
F P
0 g
s
.14336 .75424 m .1481 .73688 L .15535 .72726 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34552 .78954 m .34078 .80689 L .33837 .79469 L p .707 .577 .707 r
F P
0 g
s
.33837 .79469 m .34311 .77733 L .34552 .78954 L p .707 .577 .707 r
F P
0 g
s
.3581 .69531 m .36224 .73256 L .34979 .72722 L p .707 .577 .707 r
F P
0 g
s
.34979 .72722 m .34565 .68997 L .3581 .69531 L p .707 .577 .707 r
F P
0 g
s
.15535 .72726 m .15061 .74461 L .14336 .75424 L p .707 .577 .707 r
F P
0 g
s
.18025 .71123 m .15979 .65767 L .1758 .64842 L p .707 .577 .707 r
F P
0 g
s
.32969 .59231 m .35015 .64587 L .3311 .65012 L p .707 .577 .707 r
F P
0 g
s
.3311 .65012 m .31064 .59655 L .32969 .59231 L p .707 .577 .707 r
F P
0 g
s
.1758 .64842 m .19627 .70198 L .18025 .71123 L p .707 .577 .707 r
F P
0 g
s
.16948 .74987 m .16534 .71262 L .18168 .70469 L p .707 .577 .707 r
F P
0 g
s
.39255 .78212 m .35335 .27768 L .37644 .26672 L p .707 .577 .707 r
F P
0 g
s
.35335 .27768 m .39255 .78212 L .38253 .79338 L p .707 .577 .707 r
F P
0 g
s
.15061 .74461 m .15535 .72726 L .17156 .72115 L p .707 .577 .707 r
F P
0 g
s
.18168 .70469 m .18582 .74194 L .16948 .74987 L p .707 .577 .707 r
F P
0 g
s
.34565 .68997 m .34979 .72722 L .32892 .72396 L p .707 .577 .707 r
F P
0 g
s
.32892 .72396 m .32477 .68671 L .34565 .68997 L p .707 .577 .707 r
F P
0 g
s
.34311 .77733 m .33837 .79469 L .32653 .7811 L p .707 .577 .707 r
F P
0 g
s
.32653 .7811 m .33127 .76375 L .34311 .77733 L p .707 .577 .707 r
F P
0 g
s
.19627 .70198 m .1758 .64842 L .19884 .63732 L p .707 .577 .707 r
F P
0 g
s
.17156 .72115 m .16681 .7385 L .15061 .74461 L p .707 .577 .707 r
F P
0 g
s
.31064 .59655 m .3311 .65012 L .30587 .65758 L p .707 .577 .707 r
F P
0 g
s
.30587 .65758 m .2854 .60402 L .31064 .59655 L p .707 .577 .707 r
F P
0 g
s
.19884 .63732 m .2193 .69088 L .19627 .70198 L p .707 .577 .707 r
F P
0 g
s
.61824 .75196 m .57904 .24751 L .60864 .25347 L p .707 .577 .707 r
F P
0 g
s
.18582 .74194 m .18168 .70469 L .20564 .69741 L p .707 .577 .707 r
F P
0 g
s
.2193 .69088 m .19884 .63732 L .22663 .62545 L p .707 .577 .707 r
F P
0 g
s
.2854 .60402 m .30587 .65758 L .27692 .66754 L p .707 .577 .707 r
F P
0 g
s
.27692 .66754 m .25646 .61398 L .2854 .60402 L p .707 .577 .707 r
F P
0 g
s
.20564 .69741 m .20978 .73466 L .18582 .74194 L p .707 .577 .707 r
F P
0 g
s
.16681 .7385 m .17156 .72115 L .19513 .71916 L p .707 .577 .707 r
F P
0 g
s
.32477 .68671 m .32892 .72396 L .30166 .72312 L p .707 .577 .707 r
F P
0 g
s
.30166 .72312 m .29751 .68587 L .32477 .68671 L p .707 .577 .707 r
F P
0 g
s
.33127 .76375 m .32653 .7811 L .30642 .76746 L p .707 .577 .707 r
F P
0 g
s
.30642 .76746 m .31117 .75011 L .33127 .76375 L p .707 .577 .707 r
F P
0 g
s
.22663 .62545 m .24709 .67902 L .2193 .69088 L p .707 .577 .707 r
F P
0 g
s
.73914 .64539 m .71867 .59183 L .68972 .60179 L p .707 .577 .707 r
F P
0 g
s
.71867 .59183 m .73914 .64539 L .76897 .63392 L p .707 .577 .707 r
F P
0 g
s
.76897 .63392 m .7485 .58036 L .71867 .59183 L p .707 .577 .707 r
F P
0 g
s
.7485 .58036 m .76897 .63392 L .79676 .62205 L p .707 .577 .707 r
F P
0 g
s
.79676 .62205 m .77629 .56849 L .7485 .58036 L p .707 .577 .707 r
F P
0 g
s
.19513 .71916 m .19038 .73652 L .16681 .7385 L p .707 .577 .707 r
F P
0 g
s
.24709 .67902 m .22663 .62545 L .25646 .61398 L p .707 .577 .707 r
F P
0 g
s
.25646 .61398 m .27692 .66754 L .24709 .67902 L p .707 .577 .707 r
F P
0 g
s
.37644 .26672 m .41564 .77117 L .39255 .78212 L p .707 .577 .707 r
F P
0 g
s
.41564 .77117 m .37644 .26672 L .41033 .25714 L p .707 .577 .707 r
F P
0 g
s
.20978 .73466 m .20564 .69741 L .23488 .69149 L p .707 .577 .707 r
F P
0 g
s
.68972 .60179 m .71019 .65535 L .73914 .64539 L p .707 .577 .707 r
F P
0 g
s
.71019 .65535 m .68972 .60179 L .66449 .60926 L p .707 .577 .707 r
F P
0 g
s
.29751 .68587 m .30166 .72312 L .27068 .72477 L p .707 .577 .707 r
F P
0 g
s
.27068 .72477 m .26654 .68752 L .29751 .68587 L p .707 .577 .707 r
F P
0 g
s
.77629 .56849 m .79676 .62205 L .81979 .61095 L p .707 .577 .707 r
F P
0 g
s
.81979 .61095 m .79932 .55739 L .77629 .56849 L p .707 .577 .707 r
F P
0 g
s
.23488 .69149 m .23902 .72874 L .20978 .73466 L p .707 .577 .707 r
F P
0 g
s
.19038 .73652 m .19513 .71916 L .22375 .72148 L p .707 .577 .707 r
F P
0 g
s
.66449 .60926 m .68496 .66282 L .71019 .65535 L p .707 .577 .707 r
F P
0 g
s
.23902 .72874 m .23488 .69149 L .26654 .68752 L p .707 .577 .707 r
F P
0 g
s
.73695 .71195 m .73281 .67471 L .70184 .67635 L p .707 .577 .707 r
F P
0 g
s
.73281 .67471 m .73695 .71195 L .76861 .70798 L p .707 .577 .707 r
F P
0 g
s
.76861 .70798 m .76447 .67073 L .73281 .67471 L p .707 .577 .707 r
F P
0 g
s
.31117 .75011 m .30642 .76746 L .28002 .75511 L p .707 .577 .707 r
F P
0 g
s
.28002 .75511 m .28476 .73776 L .31117 .75011 L p .707 .577 .707 r
F P
0 g
s
.57904 .24751 m .61824 .75196 L .57961 .74925 L p .707 .577 .707 r
F P
0 g
s
.57961 .74925 m .54041 .24481 L .57904 .24751 L p .707 .577 .707 r
F P
0 g
s
.26654 .68752 m .27068 .72477 L .23902 .72874 L p .707 .577 .707 r
F P
0 g
s
.76447 .67073 m .76861 .70798 L .79785 .70206 L p .707 .577 .707 r
F P
0 g
s
.79785 .70206 m .79371 .66481 L .76447 .67073 L p .707 .577 .707 r
F P
0 g
s
.22375 .72148 m .21901 .73884 L .19038 .73652 L p .707 .577 .707 r
F P
0 g
s
.70598 .7136 m .70184 .67635 L .67457 .67551 L p .707 .577 .707 r
F P
0 g
s
.70184 .67635 m .70598 .7136 L .73695 .71195 L p .707 .577 .707 r
F P
0 g
s
.21901 .73884 m .22375 .72148 L .25464 .72789 L p .707 .577 .707 r
F P
0 g
s
.79932 .55739 m .81979 .61095 L .83581 .6017 L p .707 .577 .707 r
F P
0 g
s
.83581 .6017 m .81534 .54814 L .79932 .55739 L p .707 .577 .707 r
F P
0 g
s
.28476 .73776 m .28002 .75511 L .2499 .74524 L p .707 .577 .707 r
F P
0 g
s
.2499 .74524 m .25464 .72789 L .28476 .73776 L p .707 .577 .707 r
F P
0 g
s
.79371 .66481 m .79785 .70206 L .82181 .69478 L p .707 .577 .707 r
F P
0 g
s
.82181 .69478 m .81767 .65753 L .79371 .66481 L p .707 .577 .707 r
F P
0 g
s
.44953 .76158 m .41033 .25714 L .45172 .24987 L p .707 .577 .707 r
F P
0 g
s
.41033 .25714 m .44953 .76158 L .41564 .77117 L p .707 .577 .707 r
F P
0 g
s
.67457 .67551 m .67872 .71276 L .70598 .7136 L p .707 .577 .707 r
F P
0 g
s
.25464 .72789 m .2499 .74524 L .21901 .73884 L p .707 .577 .707 r
F P
0 g
s
.54041 .24481 m .57961 .74925 L .53574 .75006 L p .707 .577 .707 r
F P
0 g
s
.53574 .75006 m .49654 .24562 L .54041 .24481 L p .707 .577 .707 r
F P
0 g
s
.67872 .71276 m .67457 .67551 L .6537 .67226 L p .707 .577 .707 r
F P
0 g
s
.71446 .77009 m .7192 .75273 L .68908 .74287 L p .707 .577 .707 r
F P
0 g
s
.7192 .75273 m .71446 .77009 L .74535 .77649 L p .707 .577 .707 r
F P
0 g
s
.74535 .77649 m .75009 .75914 L .7192 .75273 L p .707 .577 .707 r
F P
0 g
s
.49092 .75431 m .45172 .24987 L .49654 .24562 L p .707 .577 .707 r
F P
0 g
s
.45172 .24987 m .49092 .75431 L .44953 .76158 L p .707 .577 .707 r
F P
0 g
s
.68434 .76022 m .68908 .74287 L .66268 .73051 L p .707 .577 .707 r
F P
0 g
s
.68908 .74287 m .68434 .76022 L .71446 .77009 L p .707 .577 .707 r
F P
0 g
s
.75009 .75914 m .74535 .77649 L .77398 .77882 L p .707 .577 .707 r
F P
0 g
s
.77398 .77882 m .77872 .76146 L .75009 .75914 L p .707 .577 .707 r
F P
0 g
s
.6537 .67226 m .65784 .7095 L .67872 .71276 L p .707 .577 .707 r
F P
0 g
s
.81767 .65753 m .82181 .69478 L .83815 .68685 L p .707 .577 .707 r
F P
0 g
s
.83815 .68685 m .83401 .6496 L .81767 .65753 L p .707 .577 .707 r
F P
0 g
s
.49654 .24562 m .53574 .75006 L .49092 .75431 L p .707 .577 .707 r
F P
0 g
s
.81534 .54814 m .83581 .6017 L .84324 .59522 L p .707 .577 .707 r
F P
0 g
s
.84324 .59522 m .82278 .54165 L .81534 .54814 L p .707 .577 .707 r
F P
0 g
s
.77872 .76146 m .77398 .77882 L .79754 .77683 L p .707 .577 .707 r
F P
0 g
s
.79754 .77683 m .80229 .75947 L .77872 .76146 L p .707 .577 .707 r
F P
0 g
s
.65784 .7095 m .6537 .67226 L .64125 .66691 L p .707 .577 .707 r
F P
0 g
s
.64125 .66691 m .64539 .70416 L .65784 .7095 L p .707 .577 .707 r
F P
0 g
s
.83401 .6496 m .83815 .68685 L .84526 .67904 L p .707 .577 .707 r
F P
0 g
s
.84526 .67904 m .84112 .6418 L .83401 .6496 L p .707 .577 .707 r
F P
0 g
s
.65491 .66767 m .63444 .61411 L .63257 .61102 L p .707 .577 .707 r
F P
0 g
s
.80229 .75947 m .79754 .77683 L .81375 .77072 L p .707 .577 .707 r
F P
0 g
s
.81375 .77072 m .81849 .75337 L .80229 .75947 L p .707 .577 .707 r
F P
0 g
s
.82278 .54165 m .84324 .59522 L .84137 .59213 L p .707 .577 .707 r
F P
0 g
s
.84137 .59213 m .8209 .53856 L .82278 .54165 L p .707 .577 .707 r
F P
0 g
s
.63257 .61102 m .65303 .66458 L .65491 .66767 L p .707 .577 .707 r
F P
0 g
s
.64539 .70416 m .64125 .66691 L .63844 .66 L p .707 .577 .707 r
F P
0 g
s
.63844 .66 m .64258 .69725 L .64539 .70416 L p .707 .577 .707 r
F P
0 g
s
.84112 .6418 m .84526 .67904 L .84246 .67213 L p .707 .577 .707 r
F P
0 g
s
.84246 .67213 m .83832 .63488 L .84112 .6418 L p .707 .577 .707 r
F P
0 g
s
.81849 .75337 m .81375 .77072 L .821 .76109 L p .707 .577 .707 r
F P
0 g
s
.821 .76109 m .82574 .74374 L .81849 .75337 L p .707 .577 .707 r
F P
0 g
s
.65303 .66458 m .63257 .61102 L .64 .60453 L p .707 .577 .707 r
F P
0 g
s
.8209 .53856 m .84137 .59213 L .83037 .59273 L p .707 .577 .707 r
F P
0 g
s
.83037 .59273 m .8099 .53917 L .8209 .53856 L p .707 .577 .707 r
F P
0 g
s
.64 .60453 m .66047 .65809 L .65303 .66458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64258 .69725 m .63844 .66 L .64556 .6522 L p .707 .577 .707 r
F P
0 g
s
.39613 .60649 m .37566 .55293 L .34671 .56289 L p .707 .577 .707 r
F P
0 g
s
.37566 .55293 m .39613 .60649 L .42596 .59502 L p .707 .577 .707 r
F P
0 g
s
.42596 .59502 m .40549 .54146 L .37566 .55293 L p .707 .577 .707 r
F P
0 g
s
.40549 .54146 m .42596 .59502 L .45375 .58315 L p .707 .577 .707 r
F P
0 g
s
.45375 .58315 m .43328 .52959 L .40549 .54146 L p .707 .577 .707 r
F P
0 g
s
.64556 .6522 m .6497 .68945 L .64258 .69725 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.34671 .56289 m .36718 .61645 L .39613 .60649 L p .707 .577 .707 r
F P
0 g
s
.83832 .63488 m .84246 .67213 L .83001 .66679 L p .707 .577 .707 r
F P
0 g
s
.83001 .66679 m .82587 .62954 L .83832 .63488 L p .707 .577 .707 r
F P
0 g
s
.62358 .70844 m .62832 .69109 L .63557 .68146 L p .707 .577 .707 r
F P
0 g
s
.36718 .61645 m .34671 .56289 L .32148 .57036 L p .707 .577 .707 r
F P
0 g
s
.82574 .74374 m .821 .76109 L .81858 .74889 L p .707 .577 .707 r
F P
0 g
s
.81858 .74889 m .82333 .73154 L .82574 .74374 L p .707 .577 .707 r
F P
0 g
s
.43328 .52959 m .45375 .58315 L .47678 .57205 L p .707 .577 .707 r
F P
0 g
s
.47678 .57205 m .45631 .51849 L .43328 .52959 L p .707 .577 .707 r
F P
0 g
s
.66047 .65809 m .64 .60453 L .65602 .59528 L p .707 .577 .707 r
F P
0 g
s
.63557 .68146 m .63083 .69882 L .62358 .70844 L p .707 .577 .707 r
F P
0 g
s
.32148 .57036 m .34195 .62392 L .36718 .61645 L p .707 .577 .707 r
F P
0 g
s
.8099 .53917 m .83037 .59273 L .81132 .59698 L p .707 .577 .707 r
F P
0 g
s
.81132 .59698 m .79085 .54341 L .8099 .53917 L p .707 .577 .707 r
F P
0 g
s
.39394 .68034 m .3898 .64309 L .35883 .64474 L p .707 .577 .707 r
F P
0 g
s
.3898 .64309 m .39394 .68034 L .4256 .67636 L p .707 .577 .707 r
F P
0 g
s
.4256 .67636 m .42146 .63912 L .3898 .64309 L p .707 .577 .707 r
F P
0 g
s
.65602 .59528 m .67649 .64885 L .66047 .65809 L p .707 .577 .707 r
F P
0 g
s
.42146 .63912 m .4256 .67636 L .45484 .67045 L p .707 .577 .707 r
F P
0 g
s
.45484 .67045 m .4507 .6332 L .42146 .63912 L p .707 .577 .707 r
F P
0 g
s
.6497 .68945 m .64556 .6522 L .66189 .64427 L p .707 .577 .707 r
F P
0 g
s
.36297 .68199 m .35883 .64474 L .33156 .6439 L p .707 .577 .707 r
F P
0 g
s
.35883 .64474 m .36297 .68199 L .39394 .68034 L p .707 .577 .707 r
F P
0 g
s
.34195 .62392 m .32148 .57036 L .30243 .5746 L p .707 .577 .707 r
F P
0 g
s
.45631 .51849 m .47678 .57205 L .4928 .5628 L p .707 .577 .707 r
F P
0 g
s
.4928 .5628 m .47233 .50924 L .45631 .51849 L p .707 .577 .707 r
F P
0 g
s
.4507 .6332 m .45484 .67045 L .4788 .66317 L p .707 .577 .707 r
F P
0 g
s
.4788 .66317 m .47466 .62592 L .4507 .6332 L p .707 .577 .707 r
F P
0 g
s
.66189 .64427 m .66603 .68152 L .6497 .68945 L p .707 .577 .707 r
F P
0 g
s
.30243 .5746 m .3229 .62816 L .34195 .62392 L p .707 .577 .707 r
F P
0 g
s
.82587 .62954 m .83001 .66679 L .80913 .66354 L p .707 .577 .707 r
F P
0 g
s
.80913 .66354 m .80499 .62629 L .82587 .62954 L p .707 .577 .707 r
F P
0 g
s
.33156 .6439 m .33571 .68115 L .36297 .68199 L p .707 .577 .707 r
F P
0 g
s
.63083 .69882 m .63557 .68146 L .65177 .67536 L p .707 .577 .707 r
F P
0 g
s
.67649 .64885 m .65602 .59528 L .67905 .58418 L p .707 .577 .707 r
F P
0 g
s
.82333 .73154 m .81858 .74889 L .80675 .73531 L p .707 .577 .707 r
F P
0 g
s
.80675 .73531 m .81149 .71795 L .82333 .73154 L p .707 .577 .707 r
F P
0 g
s
.79085 .54341 m .81132 .59698 L .78608 .60444 L p .707 .577 .707 r
F P
0 g
s
.78608 .60444 m .76562 .55088 L .79085 .54341 L p .707 .577 .707 r
F P
0 g
s
.37145 .72384 m .37619 .70649 L .34607 .69663 L p .707 .577 .707 r
F P
0 g
s
.37619 .70649 m .37145 .72384 L .40234 .73025 L p .707 .577 .707 r
F P
0 g
s
.40234 .73025 m .40708 .7129 L .37619 .70649 L p .707 .577 .707 r
F P
0 g
s
.65177 .67536 m .64703 .69271 L .63083 .69882 L p .707 .577 .707 r
F P
0 g
s
.33571 .68115 m .33156 .6439 L .31069 .64064 L p .707 .577 .707 r
F P
0 g
s
.67905 .58418 m .69952 .63775 L .67649 .64885 L p .707 .577 .707 r
F P
0 g
s
.34133 .71398 m .34607 .69663 L .31967 .68427 L p .707 .577 .707 r
F P
0 g
s
.34607 .69663 m .34133 .71398 L .37145 .72384 L p .707 .577 .707 r
F P
0 g
s
.40708 .7129 m .40234 .73025 L .43097 .73257 L p .707 .577 .707 r
F P
0 g
s
.43097 .73257 m .43571 .71522 L .40708 .7129 L p .707 .577 .707 r
F P
0 g
s
.66603 .68152 m .66189 .64427 L .68586 .63699 L p .707 .577 .707 r
F P
0 g
s
.31069 .64064 m .31483 .67789 L .33571 .68115 L p .707 .577 .707 r
F P
0 g
s
.47466 .62592 m .4788 .66317 L .49514 .65524 L p .707 .577 .707 r
F P
0 g
s
.49514 .65524 m .491 .61799 L .47466 .62592 L p .707 .577 .707 r
F P
0 g
s
.3229 .62816 m .30243 .5746 L .29143 .57521 L p .707 .577 .707 r
F P
0 g
s
.31967 .68427 m .31492 .70162 L .34133 .71398 L p .707 .577 .707 r
F P
0 g
s
.47233 .50924 m .4928 .5628 L .50023 .55632 L p .707 .577 .707 r
F P
0 g
s
.50023 .55632 m .47977 .50276 L .47233 .50924 L p .707 .577 .707 r
F P
0 g
s
.69952 .63775 m .67905 .58418 L .70684 .57231 L p .707 .577 .707 r
F P
0 g
s
.29143 .57521 m .3119 .62877 L .3229 .62816 L p .707 .577 .707 r
F P
0 g
s
.68586 .63699 m .69 .67424 L .66603 .68152 L p .707 .577 .707 r
F P
0 g
s
.80499 .62629 m .80913 .66354 L .78187 .66269 L p .707 .577 .707 r
F P
0 g
s
.78187 .66269 m .77773 .62544 L .80499 .62629 L p .707 .577 .707 r
F P
0 g
s
.31492 .70162 m .31967 .68427 L .29956 .67063 L p .707 .577 .707 r
F P
0 g
s
.76562 .55088 m .78608 .60444 L .75714 .6144 L p .707 .577 .707 r
F P
0 g
s
.75714 .6144 m .73667 .56084 L .76562 .55088 L p .707 .577 .707 r
F P
0 g
s
.43571 .71522 m .43097 .73257 L .45453 .73058 L p .707 .577 .707 r
F P
0 g
s
.45453 .73058 m .45928 .71323 L .43571 .71522 L p .707 .577 .707 r
F P
0 g
s
.64703 .69271 m .65177 .67536 L .67534 .67337 L p .707 .577 .707 r
F P
0 g
s
.70684 .57231 m .72731 .62588 L .69952 .63775 L p .707 .577 .707 r
F P
0 g
s
.81149 .71795 m .80675 .73531 L .78664 .72167 L p .707 .577 .707 r
F P
0 g
s
.78664 .72167 m .79138 .70431 L .81149 .71795 L p .707 .577 .707 r
F P
0 g
s
.29956 .67063 m .29482 .68799 L .31492 .70162 L p .707 .577 .707 r
F P
0 g
s
.31483 .67789 m .31069 .64064 L .29824 .6353 L p .707 .577 .707 r
F P
0 g
s
.72731 .62588 m .70684 .57231 L .73667 .56084 L p .707 .577 .707 r
F P
0 g
s
.73667 .56084 m .75714 .6144 L .72731 .62588 L p .707 .577 .707 r
F P
0 g
s
.67534 .67337 m .6706 .69072 L .64703 .69271 L p .707 .577 .707 r
F P
0 g
s
.69 .67424 m .68586 .63699 L .7151 .63107 L p .707 .577 .707 r
F P
0 g
s
.77773 .62544 m .78187 .66269 L .7509 .66434 L p .707 .577 .707 r
F P
0 g
s
.7509 .66434 m .74675 .62709 L .77773 .62544 L p .707 .577 .707 r
F P
0 g
s
.29824 .6353 m .30238 .67255 L .31483 .67789 L p .707 .577 .707 r
F P
0 g
s
.491 .61799 m .49514 .65524 L .50225 .64743 L p .707 .577 .707 r
F P
0 g
s
.50225 .64743 m .49811 .61018 L .491 .61799 L p .707 .577 .707 r
F P
0 g
s
.7151 .63107 m .71924 .66832 L .69 .67424 L p .707 .577 .707 r
F P
0 g
s
.29482 .68799 m .29956 .67063 L .28772 .65705 L p .707 .577 .707 r
F P
0 g
s
.71924 .66832 m .7151 .63107 L .74675 .62709 L p .707 .577 .707 r
F P
0 g
s
.3119 .62877 m .29143 .57521 L .28956 .57212 L p .707 .577 .707 r
F P
0 g
s
.45928 .71323 m .45453 .73058 L .47074 .72448 L p .707 .577 .707 r
F P
0 g
s
.47074 .72448 m .47548 .70712 L .45928 .71323 L p .707 .577 .707 r
F P
0 g
s
.74675 .62709 m .7509 .66434 L .71924 .66832 L p .707 .577 .707 r
F P
0 g
s
.6706 .69072 m .67534 .67337 L .70397 .67569 L p .707 .577 .707 r
F P
0 g
s
.47977 .50276 m .50023 .55632 L .49836 .55323 L p .707 .577 .707 r
F P
0 g
s
.49836 .55323 m .47789 .49966 L .47977 .50276 L p .707 .577 .707 r
F P
0 g
s
.79138 .70431 m .78664 .72167 L .76023 .70931 L p .707 .577 .707 r
F P
0 g
s
.76023 .70931 m .76498 .69196 L .79138 .70431 L p .707 .577 .707 r
F P
0 g
s
.28772 .65705 m .28298 .6744 L .29482 .68799 L p .707 .577 .707 r
F P
0 g
s
.28956 .57212 m .31002 .62568 L .3119 .62877 L p .707 .577 .707 r
F P
0 g
s
.70397 .67569 m .69923 .69304 L .6706 .69072 L p .707 .577 .707 r
F P
0 g
s
.30238 .67255 m .29824 .6353 L .29543 .62839 L p .707 .577 .707 r
F P
0 g
s
.69923 .69304 m .70397 .67569 L .73486 .6821 L p .707 .577 .707 r
F P
0 g
s
.76498 .69196 m .76023 .70931 L .73011 .69945 L p .707 .577 .707 r
F P
0 g
s
.73011 .69945 m .73486 .6821 L .76498 .69196 L p .707 .577 .707 r
F P
0 g
s
.73486 .6821 m .73011 .69945 L .69923 .69304 L p .707 .577 .707 r
F P
0 g
s
.29543 .62839 m .29957 .66564 L .30238 .67255 L p .707 .577 .707 r
F P
0 g
s
.28298 .6744 m .28772 .65705 L .28531 .64484 L p .707 .577 .707 r
F P
0 g
s
.49811 .61018 m .50225 .64743 L .49945 .64052 L p .707 .577 .707 r
F P
0 g
s
.49945 .64052 m .49531 .60327 L .49811 .61018 L p .707 .577 .707 r
F P
0 g
s
.47548 .70712 m .47074 .72448 L .47799 .71485 L p .707 .577 .707 r
F P
0 g
s
.47799 .71485 m .48273 .6975 L .47548 .70712 L p .707 .577 .707 r
F P
0 g
s
.28531 .64484 m .28057 .6622 L .28298 .6744 L p .707 .577 .707 r
F P
0 g
s
.31002 .62568 m .28956 .57212 L .29699 .56563 L p .707 .577 .707 r
F P
0 g
s
.47789 .49966 m .49836 .55323 L .48736 .55383 L p .707 .577 .707 r
F P
0 g
s
.48736 .55383 m .46689 .50027 L .47789 .49966 L p .707 .577 .707 r
F P
0 g
s
.29699 .56563 m .31746 .61919 L .31002 .62568 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.29957 .66564 m .29543 .62839 L .30255 .62059 L p .707 .577 .707 r
F P
0 g
s
.30255 .62059 m .30669 .65784 L .29957 .66564 L p .707 .577 .707 r
F P
0 g
s
.28057 .6622 m .28531 .64484 L .29256 .63522 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48273 .6975 m .47799 .71485 L .47557 .70265 L p .707 .577 .707 r
F P
0 g
s
.47557 .70265 m .48032 .6853 L .48273 .6975 L p .707 .577 .707 r
F P
0 g
s
.49531 .60327 m .49945 .64052 L .487 .63518 L p .707 .577 .707 r
F P
0 g
s
.487 .63518 m .48286 .59793 L .49531 .60327 L p .707 .577 .707 r
F P
0 g
s
.29256 .63522 m .28782 .65257 L .28057 .6622 L p .707 .577 .707 r
F P
0 g
s
.31746 .61919 m .29699 .56563 L .31301 .55638 L p .707 .577 .707 r
F P
0 g
s
.46689 .50027 m .48736 .55383 L .46831 .55808 L p .707 .577 .707 r
F P
0 g
s
.46831 .55808 m .44784 .50451 L .46689 .50027 L p .707 .577 .707 r
F P
0 g
s
.31301 .55638 m .33347 .60995 L .31746 .61919 L p .707 .577 .707 r
F P
0 g
s
.30669 .65784 m .30255 .62059 L .31888 .61266 L p .707 .577 .707 r
F P
0 g
s
.28782 .65257 m .29256 .63522 L .30876 .62911 L p .707 .577 .707 r
F P
0 g
s
.31888 .61266 m .32302 .64991 L .30669 .65784 L p .707 .577 .707 r
F P
0 g
s
.48286 .59793 m .487 .63518 L .46612 .63192 L p .707 .577 .707 r
F P
0 g
s
.46612 .63192 m .46198 .59467 L .48286 .59793 L p .707 .577 .707 r
F P
0 g
s
.48032 .6853 m .47557 .70265 L .46373 .68906 L p .707 .577 .707 r
F P
0 g
s
.46373 .68906 m .46848 .67171 L .48032 .6853 L p .707 .577 .707 r
F P
0 g
s
.33347 .60995 m .31301 .55638 L .33604 .54528 L p .707 .577 .707 r
F P
0 g
s
.30876 .62911 m .30402 .64647 L .28782 .65257 L p .707 .577 .707 r
F P
0 g
s
.44784 .50451 m .46831 .55808 L .44307 .56554 L p .707 .577 .707 r
F P
0 g
s
.44307 .56554 m .42261 .51198 L .44784 .50451 L p .707 .577 .707 r
F P
0 g
s
.33604 .54528 m .35651 .59885 L .33347 .60995 L p .707 .577 .707 r
F P
0 g
s
.32302 .64991 m .31888 .61266 L .34285 .60538 L p .707 .577 .707 r
F P
0 g
s
.35651 .59885 m .33604 .54528 L .36383 .53341 L p .707 .577 .707 r
F P
0 g
s
.42261 .51198 m .44307 .56554 L .41413 .5755 L p .707 .577 .707 r
F P
0 g
s
.41413 .5755 m .39366 .52194 L .42261 .51198 L p .707 .577 .707 r
F P
0 g
s
.34285 .60538 m .34699 .64262 L .32302 .64991 L p .707 .577 .707 r
F P
0 g
s
.30402 .64647 m .30876 .62911 L .33233 .62712 L p .707 .577 .707 r
F P
0 g
s
.46198 .59467 m .46612 .63192 L .43886 .63108 L p .707 .577 .707 r
F P
0 g
s
.43886 .63108 m .43472 .59383 L .46198 .59467 L p .707 .577 .707 r
F P
0 g
s
.46848 .67171 m .46373 .68906 L .44363 .67543 L p .707 .577 .707 r
F P
0 g
s
.44363 .67543 m .44837 .65807 L .46848 .67171 L p .707 .577 .707 r
F P
0 g
s
.36383 .53341 m .3843 .58698 L .35651 .59885 L p .707 .577 .707 r
F P
0 g
s
.33233 .62712 m .32759 .64448 L .30402 .64647 L p .707 .577 .707 r
F P
0 g
s
.3843 .58698 m .36383 .53341 L .39366 .52194 L p .707 .577 .707 r
F P
0 g
s
.39366 .52194 m .41413 .5755 L .3843 .58698 L p .707 .577 .707 r
F P
0 g
s
.34699 .64262 m .34285 .60538 L .37209 .59946 L p .707 .577 .707 r
F P
0 g
s
.43472 .59383 m .43886 .63108 L .40788 .63273 L p .707 .577 .707 r
F P
0 g
s
.40788 .63273 m .40374 .59548 L .43472 .59383 L p .707 .577 .707 r
F P
0 g
s
.37209 .59946 m .37623 .63671 L .34699 .64262 L p .707 .577 .707 r
F P
0 g
s
.32759 .64448 m .33233 .62712 L .36096 .62945 L p .707 .577 .707 r
F P
0 g
s
.37623 .63671 m .37209 .59946 L .40374 .59548 L p .707 .577 .707 r
F P
0 g
s
.44837 .65807 m .44363 .67543 L .41722 .66307 L p .707 .577 .707 r
F P
0 g
s
.41722 .66307 m .42196 .64572 L .44837 .65807 L p .707 .577 .707 r
F P
0 g
s
.40374 .59548 m .40788 .63273 L .37623 .63671 L p .707 .577 .707 r
F P
0 g
s
.36096 .62945 m .35622 .6468 L .32759 .64448 L p .707 .577 .707 r
F P
0 g
s
.35622 .6468 m .36096 .62945 L .39184 .63585 L p .707 .577 .707 r
F P
0 g
s
.42196 .64572 m .41722 .66307 L .3871 .65321 L p .707 .577 .707 r
F P
0 g
s
.3871 .65321 m .39184 .63585 L .42196 .64572 L p .707 .577 .707 r
F P
0 g
s
.39184 .63585 m .3871 .65321 L .35622 .6468 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
RWoo5@00OWoo0024Ool60003FUH00`00FUIJEP09FUH00`00FUIJEP03FUH8001fOol007ioo`H000UJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00@0079oo`00N7oo1P000UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF1000KWoo001bOol60008FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP08FUH2001/Ool006ioo`@0009J
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00YJ
EP8006Yoo`00Jgoo0`001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH02eYF00<007ooOol0J7oo001YOol30008FUH00`00FUIJEP09FUH00`00FUIJ
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP0;FUH2001YOol006Moo`80009JEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00YJEP8006Uoo`00IGoo0P0015YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH02UYF0P00JGoo001TOol00`00FUIJEP04
FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001SOol20006FUH00`00FUIJEP07FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EUYF0P00JGoo001ROol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P00JGoo001QOol0
1000FUIJEP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo001QOol01000FUIJ
EP001eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0Igoo001QOol01000FUIJEP001eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo001QOol01000FUIJEP001eYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00J7oo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00J7oo001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo
001QOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo001ROol01000
FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P00J7oo001ROol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0P00J7oo001R
Ool01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0P00J7oo001ROol01000FUIJEP001UYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YFFUIJEP8006Qoo`00HWoo00@005YFFUH000MJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH2001XOol0069oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1VOol0069oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0069oo`04
001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0069oo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001WOol0069oo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001WOol0069oo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0;FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001WOol006=oo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH20003FUH2001WOol006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2001W
Ool006=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2001WOol006=oo`04001JEUYF0007
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH20003FUH2001WOol006=oo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01P00
FUIJEUYF001JEVMoo`00Hgoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Io
o`00Hgoo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Hgoo00D005YF
FUIJEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Hgoo00D005YFFUIJEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00Hgoo00D005YFFUIJEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00]JEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00]JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP8000=JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP80
00=JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000=JEP8006Ioo`00I7oo00@0
05YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP8000=JEP8006Ioo`00I7oo00@005YFFUH000MJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00EJEP8000=JEP8006Ioo`00I7oo00@005YFFUH000MJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH3001U
Ool006Aoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001J
EUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol006Aoo`05001JEUYFFUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0;FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol0
06Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001UOol006Eoo`04001JEUYF
0006FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH20003FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH2
0003FUH2001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2001UOol006Eoo`04
001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2001UOol006Eoo`04001JEUYF0007FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH20003FUH2001UOol006Eoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH3001TOol0
06Eoo`04001JEUYF0007FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00I7oo001UOol01@00FUIJEUYF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00I7oo001UOol01@00FUIJEUYF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00I7oo001UOol01@00FUIJEUYF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00I7oo001VOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH01UYF1P002eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJ
EP001UYF00<005YFFUH01UYF00<005YFFUH00UYF10001UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00I7oo001VOol01000FUIJEP001UYF
00<005YFFUH01UYF1@0000=JEP00FUH015YF00@005YFFUH000YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00EJEP8000=JEP8006Aoo`00IWoo00@005YFFUH000IJEP03001JEUYF00AJEP<0
00IJEP03001JEUYF009JEP03001JEUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8000=JEP8006Aoo`00IWoo00@005YFFUH000IJEP04001JEUYFFUH300000eYF001JEP06
FUH00`00FUIJEP03FUH01000FUIJEP002EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF0P000eYF0P00I7oo001VOol01000FUIJEP001UYF10001EYF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YFFUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF
0P00I7oo001VOol01000FUIJEP0015YF0`0025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0P00I7oo001V
Ool01000FUIJEP000UYF0P0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF
FUH000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000=JEP<006=oo`00IWoo
00<005YFFUH00`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH0
0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0`00Hgoo001VOol3
0007FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0`00Hgoo001UOol30009FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001SOol006=oo`8000=JEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8002Yoo`H003=oo`00HGoo0P00
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8002Eoo`D0
009JEP04001JEUYFFUHcOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEUYF008000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP80025oo`@00003FUH005YF00EJEP04001JEUYF000bOol005aoo`80
0003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYF0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH2000NOol30006FUH00`00FUIJEP03FUH01000FUIJEP00<Woo001JOol20004FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP070005FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20003FUH2000LOol200000eYF001JEP06FUH00`00
FUIJEP04FUH01000FUIJEP00<Goo001HOol20006FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH40003FUH01000FUIJEP001EYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF0P000eYF0P006Goo0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUH0035oo`00EWoo0`0025YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH010000UYF00<005YFFUH00eYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01EYF0P000eYF0P005Woo0`001eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0035o
o`00E7oo0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF
10001UYF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF
0P000eYF0P004goo0`0000=JEP00FUH025YF00<005YFFUH015YF00<005YFFUH015YF00@005YFFUH0
031oo`00Dgoo0P0015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH0
0eYF0P000eYF00<005YFFUH01EYF00@005YF000000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP8000=JEP80011oo`<000EJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF
00=JEP04001JEUYF000`Ool0059oo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH00`00FUH000020005FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH20003FUH3000=Ool20008FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH01000FUIJEP00;goo001BOol01000FUIJEP0015YF00<005YFFUH01EYF00<0
05YFFUH01eYF00<005YFFUH01EYF10001eYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0P000eYF0`002goo0`002UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002moo`00DWoo0P0000=JEP00FUH00eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00@005YF0000
00=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8000=JEP<0
00Uoo`8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF000_Ool005=oo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH0
00020005FUH00`00FUIJEP06FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH20003FUH30007Ool20005FUH00`00FUIJEP07FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00;Woo001COol200000eYF001JEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH20009FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000Eoo`8000QJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000^Ool005Ao
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH200000eYF001JEP08FUH01000FUIJ
EUYF0P002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P000goo0P0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH015YF00@005YFFUH002eoo`00E7oo00@005YFFUH000AJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000=JEP03001JEUYF00IJEPP000QJEP03001JEUYF00]JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000AJEP03001JEUYF
00EJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP04001JEUYFFUH6000]Ool005Ao
o`800003FUH005YF00=JEP03001JEUYF00IJEP04001JEP000005FUH90004FUH01000FUIJEUYF1`00
0UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0`001UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1@00
0UYF00@005YFFUH002eoo`00Dgoo0`000UYF00<005YFFUH00UYF00<005YFFUH015YF0`0000=JEP00
0000100015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01@002UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01EYF0P0000EJEP00001JEP0000MJEP03001JEUYF00IJEP03001J
EUYF00MJEP03001JEUYF00MJEP03001JEP0000<000=JEP03001JEUYF009JEP8002ioo`00D7oo0`00
0UYF0P0000=JEP00FUH00eYF00<005YFFUH00UYF1P0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF000000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP<000AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00EJEP<000MJEP03001JEUYF009JEP03001oogoo02eoo`00CGoo0`0000=JEP00FUH00eYF00<005YF
00001EYF00<005YF00000`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<0
05YFFUH00eYF00@005YFFUH000QJEP03001JEUYF00UJEP03001JEUYF00QJEP05001JEUYFFUH00003
FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP06FUH01000FUH00000<7oo001:Ool30005FUH01@00FUIJEUYF00000UYF00<005YF
FUH0100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH015YF00@0
05YFFUH000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEP00008000EJ
EP03001JEUYF00AJEP<0039oo`00Agoo0`0025YF00@005YFFUIJEP800004FUH000000005FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00
FUIJEP020007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04FUH01000FUIJEP001EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`0025YF00<005YFFUH00UYF0P00=Goo
0015Ool200000eYF001JEP08FUH00`00FUIJEP02FUH40006FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP020007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH30002FUH00`00FUIJEP07FUH01000FUH00000=goo0012Ool30004FUH0
0`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000001eYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUH000EJEP03001JEUYF00AJEP03001JEUYF
00MJEP03001JEP00008000EJEP03001JEUYF00MJEP8003Uoo`00@7oo0P001eYF00<005YFFUH01eYF
10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP<000QJEPT003]oo`00
?Woo0`002EYF00<005YFFUH01UYF00<005YFFUH03@001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000MJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00EJEP80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00AJEP80009J
EPT000AJEP04001JEUYFFUH6000fOol003aoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEP00008000IJEP04001JEUYFFUH90006FUHF0003FUH00`00FUIJEP020006FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP001EYF00<005YFFUH015YF00@005YFFUIJ
EPL000AJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00D0035oo`00>Woo0P001EYF00<0
05YFFUH01UYF00<005YFFUH01UYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
0UYF2@0025YF1P0015YF1@000UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF0P0000=JEP00FUH015YF00<005YFFUH015YF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YFFUH00eYF00<005YF00000P00;Woo000gOol30007FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUH0000:0004FUH00`00FUIJEP04FUH01000FUIJEUYF10001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF0P000UYF00<005YFFUH00eYF00<005YF00000`001UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00=Goo0P00
00=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00D005YFFUIJEP0000IJEP03001JEUYF
00EJEP03001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP02FUH30007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF0000
15YF0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUIJEP8002eoo`00<goo0P0015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00UYF0P000UYF4`001UYF00<005YFFUH01EYF0P0025YF00<005YFFUH015YF00<005YFFUH0
0UYF0`001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF0`0000=JEP00FUH00`00
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH0
0eYF00@005YFFUIJEP8002eoo`00<Goo0P001UYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YF
FUH00UYF00@005YF0000009JEP04001JEUYFFUH200000eYF001JEP06FUH00`00FUH000030002FUH0
0`00FUIJEP06FUH30006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUH00007FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH300001EYF000005YF00001UYF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUIJEP80
02eoo`00<7oo0P0025YF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP<00005FUH005YF
FUH00002FUH01@00FUIJEUYF00001eYF00<005YFFUH00eYF10001eYF00<005YFFUH00P0015YF00<0
05YFFUH015YF00<005YFFUH00UYF0P0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1EYF10000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P00;Goo000^Ool20002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP020002FUH00`00FUIJEP030004FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH01000FUH0000015YF00<005YFFUH00eYF0P000eYF00<005YFFUH015YF
00D005YFFUIJEP0000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP05001JEUYFFUH0000]Ool002eoo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00IJEP03001JEP0000<0009JEP04001JEP000005FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH01000FUIJEUYF0`0000=JEP00FUH01UYF0P0000=JEP00FUH01EYF00@005YF0000
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP05001JEUYFFUH0000]Ool002]oo`<000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00MJEP800003FUH005YF00@0009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000QJEP<000EJEP<000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00AJEQD000=J
EP04001JEUYFFUH2000/Ool002]oo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP07FUH20004FUH20003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH20006FUH00`00FUIJEP050002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP05000:Ool50005FUH40003FUH2000/Ool002]oo`800003FUH005YF00=JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP80009JEP03001JEUYF009JEP05001JEUYFFUH00005FUH0
0`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH30003FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00005FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH600000goo0000000<0003FUH00`00FUIJEP04FUH01000FUIJ
EUYF0P0000=JEP000000;7oo000/Ool01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00P0000=JEP00FUH01EYF00D005YFFUIJEP00
00aJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH<0003Ool9
0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP03FUH3000/Ool002aoo`04001JEUYF
0004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000001eYF00@005YFFUH0009JEPD000=J
EP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEPL0009JEP8000EJEP03001JEP00009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEP0000D0
009JEP03001JEUYF009JEPP000AJEPD000AJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
009JEP<002aoo`00;Goo00<005YF00001EYF00<005YFFUH01EYF00<005YFFUH01EYF0`002EYF00@0
05YFFUH000AJEP03001oogoo01T000QJEP04001JEP000003FUH01P00FUIJEP00FUH000aJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00AJEP<00003FUH005YF00EJEP03001JEUYF00IJEP04
001JEUYFFUH80005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0000/
Ool002eoo`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP08
FUH20006FUH00`00Oomoo`0=Ool00`00FUIJEP0600000eYF001JEP07FUH01000FUIJEUYF0`0015YF
0P003EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0015YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00;Goo000]Ool200000eYF001JEP03FUH00`00FUIJEP06FUH00`00FUH0
00020004FUH=0006FUH5000;Ool00`00FUIJEP0600000eYF001JEP07FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH20002
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001J
EP07FUH00`00FUIJEP04FUH01000FUIJEUYF0P00;Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
15YF0`0000=JEP000000100015YF00<005YFFUH01UYF0P0015YF00<005YFFUH01`001Woo00<005YF
FUH01P0000=JEP00FUH01eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH01000FUIJEUYF0P000eYF2`0015YF00<005YFFUH01UYF00<005YFFUH01UYF
0`001eYF00<005YFFUH015YF00@005YF0000031oo`00;Woo00@005YFFUH000AJEP03001JEUYF009J
EPH00003FUH005YF00MJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF00=JEP800003FUH0
05YF008000Aoo`05001JEUYF001JEP030002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUH0
05YF0P0035YF00<005YFFUH02EYF00<005YFFUH025YF00@005YFFUIJEP800004FUH000000002FUH0
0`00FUIJEP02FUH00`00FUIJEP090004FUH00`00FUIJEP07FUH30006FUH00`00FUIJEP03FUH3000b
Ool002moo`03001JEP0000EJEP03001JEP0000<000EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00<000MJEP<00003FUH007oo00=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH200000eYF0000000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEUYF0`0000=J
EP0000000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01P0025YF00<005YFFUH00P00
15YF00<005YF00000`00=Goo000_Ool01000FUIJEP000UYF100000=JEP00FUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF00<005YF00000`000Woo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP00000<FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP020003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH30004FUH00`00FUIJEP03FUH2000015YF00000000>Goo000_Ool00`00FUIJEP030005FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20006FUH00`00FUIJ
EP03FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH200000eYF001JEP0;FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP020004FUH200000eYF001JEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP0300000eYF001JEP06FUH00`00Oomoo`0jOol0031oo`@000IJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=JEP03001JEUYF00IJ
EP03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF00]JEP03001J
EUYF00UJEP03001JEUYF00QJEP04001JEUYF0005FUH00`00FUH000030003FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH30007FUH3000jOol002moo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00MJ
EP03001JEUYF00AJEPH000MJEPL0009JEP04001JEUYF000<FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH01000FUIJEP001EYF00<005YFFUH00UYF6P000goo0P001EYF00@005YFFUH003Uoo`00;Goo0`00
0eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF00<005YFFUH00`001UYF00<005YFFUH01eYF00@005YFFUIJEPP000=JEP04001JEUYFFUH20002
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH01000FUIJEP001EYF00<005YFFUH0
0UYF0P004goo0`001goo0P000UYF00<005YFFUH00UYF0P00=goo000/Ool01000FUIJEP000eYF2@00
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF10000UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@0011oo`D000Qo
o`<000IJEP03001oogoo03Aoo`00;7oo00<005YFFUH01@000eYF00@005YFFUIJEPT000QJEP03001J
EUYF009JEPl000=JEP03001JEUYF00H000IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF
FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20004
FUH20002FUH5000;Ool5000:Ool00`00FUIJEP04FUH2000eOol002aoo`<00003FUH005YF00EJEP03
001JEUYF00EJEP03001JEUYF009JEPd000Aoo`H000AJEPD0009JEP8000=oo`03FUH000000080009J
EP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000AJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000EJEP03001JEP00008000Qo
o`D000]oo`8000AJEP03001JEP0003Aoo`00:goo0P000eYF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YF0000009oo`L000AJEP03001JEUYF00AJEP04001JEUYFFUH40003Ool0
1@00FUIJEP00FUH01P0015YF00@005YFFUIJEPH000IJEP03001JEUYF00]JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH30005FUH01@00FUIJEUYF00002Goo0`003Woo
00@005YFFUH000=JEP03001oogoo035oo`00:goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03
001JEUYF00MJEP04001JEUYFFUH300000eYF001JEP07FUH00`00FUIJEP04FUH00`00FUIJEP02FUH3
0003Ool01000FUIJEP001UYF2P0035YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0`0015YF00@005YFFUIJEP8001Yoo`<000AJEP03001oogoo
031oo`00:Woo0P000eYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00EJEP8000QJ
EP03001JEUYF00AJEP03001JEUYF009JEP<000=oo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH20006
FUH20002FUH01000FUIJEUYF0P0077oo00@005YFFUIJEP80039oo`00:Woo00<005YFFUH01P0000EJ
EP00001JEP00009JEPT000AJEP03001JEUYF00IJEP<000IJEP03001JEUYF00AJEP03001JEUYF009J
EP03001JEP0000=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30003FUH2000M
Ool00`00FUIJEP02000bOol002Uoo`D0009JEP04001JEUYF0003FUH00`00FUIJEP05FUH01000FUIJ
EUYF1P001eYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH00UYF0P0017oo00@005YF
FUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF00QJEP80009JEP8001ioo`800003FUH007oo035oo`00
:Goo0P000Woo00<005YFFUH00`0015YF00<005YFFUH01EYF00<005YFFUH01EYF00@005YF000000AJ
EP03001JEUYF00=JEP8000=JEP03001JEUYF00AJEP05001JEUYFFUH00005Ool01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH025YF00<005YF00000`007goo00<005YF0000<Woo000XOol30003
Ool01000FUH000001EYF00<005YFFUH01EYF00<005YFFUH01EYF00@005YFFUIJEP<00003FUH005YF
00IJEP800003FUH005YF00EJEP04001JEP000006Ool01000FUIJEP0045YF00<005YFFUH02EYF00<0
05YFFUH015YF80001UYF00D005YFFUIJEP0000IJEP03001JEUYF009JEP<001eoo`03001JEP00039o
o`00:7oo00@005YF0000009oo`80009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00AJEP8000QJEP<000EJEP<000Qoo`04001JEUYF000@FUH00`00FUIJEP07FUH9000;
FUH00`00FUIJEP0:FUH00`00FUIJEP05FUH40002FUH01000FUIJEUYF0`000eYF00<005YFFUH01UYF
1P005Woo0`00<goo000XOol01000FUIJEUYF0`000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01EYF0P001UYF00<005YFFUH01@002goo00@005YFFUH0011JEP04001J
EUYFFUH60008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06FUH00`00FUIJEP040003
FUH400000eYF001JEP08FUH00`00FUIJEP02FUH80008Ool600000eYF0000000cOol002Uoo`03001J
EUYF009JEP05001JEUYFFUH00005FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH3
0003FUH00`00FUIJEP02FUH2000=Ool00`00FUIJEP0@FUH50002FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF00000002FUH40006
FUH00`00FUIJEP07FUH01000FUIJEUYF20000eYF00@005YFFUIJEP8003=oo`00:Goo00<005YFFUH0
0UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00P0000=JEP00FUH01EYF00<007ooOol02Woo00<005YFFUH03EYF0`001eYF00<005YFFUH0
2EYF00<005YFFUH015YF1@0000=JEP00FUH02EYF00=oo`00FUH01eYF00<005YFFUH015YF00<005YF
00000P000UYF00@005YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEUYFFUH2000dOol002Yoo`04001JEUYF0002FUH50003FUH00`00FUIJEP05FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH70002Ool20006FUH2000;Ool00`00FUIJEP0:FUH3000:FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80004FUH20008FUH00`00FUIJEP05FUH01000FUH0
00000UYF00<005YFFUH00eYF1P001eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YFFUIJEP80
03Aoo`00:Woo00@005YFFUH000AJEP03001oogoo00L000AJEP03001JEUYF009JEPP000]oo`03001J
EUYF009JEP03001JEP0000aoo`UJEP<0009JEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF
00AJEP03001JEUYF00IJEP04001JEUYFFUH60008FUH00`00FUIJEP05FUH01000FUIJEP000eYF00<0
05YFFUH00UYF00<005YF00000goo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0`00=Goo000[Ool20006FUH00`00Oomoo`06Ool90002Ool5000=Ool20002FUH01000FUIJEP002goo
1eYF0P001EYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH01UYF0P0025YF00<005YFFUH01EYF00@005YFFUH000=JEP03001JEUYF009JEP8000Qoo`H0
00AJEP04001JEUYFFUH6000hOol002aoo`03001JEUYF00AJEP<0015oo`D000moo`8000AJEP03001o
ogoo00Qoo`EJEP8000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP8000UJEP03001JEUYF00AJEP03001JEP0000AJEP04001JEUYFFUH2000?
Ool8000nOol002eoo`8000AJEP03001JEUYF008000moo`D0011oo`03001JEUYF009JEP03001oogoo
00Qoo`=JEP8000UJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF009JEPD000AJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000EJEP04001JEP00001GOol002moo`04001J
EUYF0005FUH2000>Ool3000BOol01P00FUIJEP00FUH000Uoo`9JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00MJEPL000IJEP04001JEP000008FUH00`00FUIJEP04FUH2
0004FUH3001IOol0031oo`<000MJEP<0025oo`<00003FUH007oo00Qoo`03FUH005YF00]JEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH40002FUH01000FUIJEP0025YF
00<005YFFUH00eYF0P0000=JEP0000000P00G7oo000bOol00`00FUIJEP06FUH01000FUH000008Goo
00<005YF00002Goo0P0015YF00<005YFFUH045YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01EYF1P0025YF00@005YFFUIJEPD0061oo`00<goo0P001UYF00@005YFFUIJEP<001ioo`8000Yo
o`8000AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00IJEP06001JEP00001JEP00Hgoo000eOol20003FUH00`00FUIJEP05FUH6
000FOol4000;Ool00`00FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40003FUH3001QOol003Moo`800003FUH0
05YF00MJEP03001JEUYF009JEPP000Qoo`H0009JEP03001oogoo00Yoo`03001JEUYF009JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00H000EJEP04001JEUYF001POol003Uoo`<000IJEP03001JEUYF00MJEP04001JEUYFFUH80003
FUH01000FUIJEUYF0P003Goo0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF0`001Woo0P000UYF00<005YFFUH00UYF0P00GWoo000lOol4
0002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000047oo0`00
25YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH01eYF10002Goo0`00
1UYF00<007ooOol0Fgoo0010Ool50006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF
0P004Woo1@0015YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEP/0
00Yoo`03001JEUYF00AJEP8005aoo`00AGoo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00P0067oo2P001EYF00<005YFFUH02EYF00<005YFFUH015YF2P001Woo1@002goo0P0015YF
00<005YF0000Fgoo0019Ool60004FUH01000FUIJEUYF1P0097oo600047oo1@003Goo00@005YFFUH0
00=JEP03001oogoo05Qoo`00Cgoo2000=goo00<005YFFUH015YF0`004Woo0`003goo0`0015YF00<0
07ooOol0Egoo002?Ool20004FUH00`00FUIJEP02000TOol00`00FUIJEP02FUH00`00Oomoo`1GOol0
095oo`04001JEUYF0005FUH2000SOol00`00FUIJEP02001IOol0099oo`<000MJEP80025oo`03001J
EUYF008005Uoo`00U7oo00<005YFFUH01EYF00<005YF00000P007goo0P0000=JEP00Ool0F7oo002E
Ool20005FUH00`00FUIJEP02FUH3000MOol00`00FUH0001IOol009Moo`80009JEP03001JEUYF00IJ
EP@001Uoo`8005Yoo`00VGoo0`002EYF00<005YFFUH010004goo1000FWoo002KOol20008FUH00`00
FUIJEP04FUHC0002FUH2001JOol009eoo`<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF008005]oo`00X7oo0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP8005]oo`00Xgoo1@0015YF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00P00G7oo002XOol80004FUH00`00FUIJEP04FUH01000FUH00000GWoo002`Ool=001POol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]58\[InvisibleSpace]"     "\
\[InvisibleSpace]13.825563588829256`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 58, "     ", 13.825563588829256, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.60771 .74253 m .59467 .68722 L .56438 .69282 L p .707 .577 .707 r
F P
0 g
s
.59467 .68722 m .60771 .74253 L .63875 .73499 L p .707 .577 .707 r
F P
0 g
s
.63875 .73499 m .62571 .67968 L .59467 .68722 L p .707 .577 .707 r
F P
0 g
s
.62571 .67968 m .63875 .73499 L .6675 .72624 L p .707 .577 .707 r
F P
0 g
s
.6675 .72624 m .65446 .67093 L .62571 .67968 L p .707 .577 .707 r
F P
0 g
s
.57742 .74813 m .56438 .69282 L .53781 .69593 L p .707 .577 .707 r
F P
0 g
s
.56438 .69282 m .57742 .74813 L .60771 .74253 L p .707 .577 .707 r
F P
0 g
s
.65446 .67093 m .6675 .72624 L .69115 .71715 L p .707 .577 .707 r
F P
0 g
s
.69115 .71715 m .67811 .66184 L .65446 .67093 L p .707 .577 .707 r
F P
0 g
s
.53781 .69593 m .55085 .75124 L .57742 .74813 L p .707 .577 .707 r
F P
0 g
s
.55085 .75124 m .53781 .69593 L .51755 .69624 L p .707 .577 .707 r
F P
0 g
s
.58608 .80093 m .57742 .76406 L .54712 .76963 L p .707 .577 .707 r
F P
0 g
s
.57742 .76406 m .58608 .80093 L .61713 .79341 L p .707 .577 .707 r
F P
0 g
s
.61713 .79341 m .60846 .75653 L .57742 .76406 L p .707 .577 .707 r
F P
0 g
s
.60846 .75653 m .61713 .79341 L .64588 .78468 L p .707 .577 .707 r
F P
0 g
s
.64588 .78468 m .63721 .7478 L .60846 .75653 L p .707 .577 .707 r
F P
0 g
s
.67811 .66184 m .69115 .71715 L .70738 .70859 L p .707 .577 .707 r
F P
0 g
s
.70738 .70859 m .69434 .65328 L .67811 .66184 L p .707 .577 .707 r
F P
0 g
s
.54712 .76963 m .55579 .80651 L .58608 .80093 L p .707 .577 .707 r
F P
0 g
s
.51755 .69624 m .53059 .75155 L .55085 .75124 L p .707 .577 .707 r
F P
0 g
s
.55579 .80651 m .54712 .76963 L .52054 .77272 L p .707 .577 .707 r
F P
0 g
s
.60002 .86152 m .60609 .84475 L .57666 .8327 L p .707 .577 .707 r
F P
0 g
s
.60609 .84475 m .60002 .86152 L .63029 .8699 L p .707 .577 .707 r
F P
0 g
s
.63029 .8699 m .63635 .85312 L .60609 .84475 L p .707 .577 .707 r
F P
0 g
s
.63721 .7478 m .64588 .78468 L .66953 .77559 L p .707 .577 .707 r
F P
0 g
s
.66953 .77559 m .66086 .73872 L .63721 .7478 L p .707 .577 .707 r
F P
0 g
s
.5706 .84947 m .57666 .8327 L .55095 .81816 L p .707 .577 .707 r
F P
0 g
s
.57666 .8327 m .5706 .84947 L .60002 .86152 L p .707 .577 .707 r
F P
0 g
s
.52054 .77272 m .52921 .80959 L .55579 .80651 L p .707 .577 .707 r
F P
0 g
s
.63635 .85312 m .63029 .8699 L .65842 .87378 L p .707 .577 .707 r
F P
0 g
s
.65842 .87378 m .66449 .85701 L .63635 .85312 L p .707 .577 .707 r
F P
0 g
s
.55095 .81816 m .54488 .83493 L .5706 .84947 L p .707 .577 .707 r
F P
0 g
s
.53059 .75155 m .51755 .69624 L .50558 .69372 L p .707 .577 .707 r
F P
0 g
s
.52921 .80959 m .52054 .77272 L .50027 .77301 L p .707 .577 .707 r
F P
0 g
s
.54488 .83493 m .55095 .81816 L .53147 .80255 L p .707 .577 .707 r
F P
0 g
s
.69434 .65328 m .70738 .70859 L .7146 .70141 L p .707 .577 .707 r
F P
0 g
s
.7146 .70141 m .70156 .6461 L .69434 .65328 L p .707 .577 .707 r
F P
0 g
s
.66449 .85701 m .65842 .87378 L .68167 .8728 L p .707 .577 .707 r
F P
0 g
s
.68167 .8728 m .68774 .85602 L .66449 .85701 L p .707 .577 .707 r
F P
0 g
s
.66086 .73872 m .66953 .77559 L .68576 .76704 L p .707 .577 .707 r
F P
0 g
s
.68576 .76704 m .67709 .73016 L .66086 .73872 L p .707 .577 .707 r
F P
0 g
s
.50558 .69372 m .51863 .74903 L .53059 .75155 L p .707 .577 .707 r
F P
0 g
s
.50027 .77301 m .50894 .80988 L .52921 .80959 L p .707 .577 .707 r
F P
0 g
s
.53147 .80255 m .5254 .81932 L .54488 .83493 L p .707 .577 .707 r
F P
0 g
s
.5254 .81932 m .53147 .80255 L .52012 .7874 L p .707 .577 .707 r
F P
0 g
s
.50894 .80988 m .50027 .77301 L .48831 .77048 L p .707 .577 .707 r
F P
0 g
s
.51863 .74903 m .50558 .69372 L .50309 .68862 L p .707 .577 .707 r
F P
0 g
s
.68774 .85602 m .68167 .8728 L .69776 .86704 L p .707 .577 .707 r
F P
0 g
s
.69776 .86704 m .70383 .85026 L .68774 .85602 L p .707 .577 .707 r
F P
0 g
s
.52012 .7874 m .51406 .80418 L .5254 .81932 L p .707 .577 .707 r
F P
0 g
s
.48831 .77048 m .49698 .80735 L .50894 .80988 L p .707 .577 .707 r
F P
0 g
s
.67709 .73016 m .68576 .76704 L .69299 .75986 L p .707 .577 .707 r
F P
0 g
s
.69299 .75986 m .68432 .72298 L .67709 .73016 L p .707 .577 .707 r
F P
0 g
s
.70156 .6461 m .7146 .70141 L .71211 .69632 L p .707 .577 .707 r
F P
0 g
s
.71211 .69632 m .69907 .64101 L .70156 .6461 L p .707 .577 .707 r
F P
0 g
s
.50309 .68862 m .51613 .74393 L .51863 .74903 L p .707 .577 .707 r
F P
0 g
s
.51406 .80418 m .52012 .7874 L .51803 .7742 L p .707 .577 .707 r
F P
0 g
s
.49698 .80735 m .48831 .77048 L .48582 .76537 L p .707 .577 .707 r
F P
0 g
s
.48582 .76537 m .49448 .80225 L .49698 .80735 L p .707 .577 .707 r
F P
0 g
s
.49448 .80225 m .48582 .76537 L .49304 .75819 L p .707 .577 .707 r
F P
0 g
s
.48617 .82191 m .49241 .32074 L .4484 .3175 L p .707 .577 .707 r
F P
0 g
s
.51803 .7742 m .51196 .79097 L .51406 .80418 L p .707 .577 .707 r
F P
0 g
s
.51613 .74393 m .50309 .68862 L .51032 .68145 L p .707 .577 .707 r
F P
0 g
s
.51032 .68145 m .52336 .73676 L .51613 .74393 L p .707 .577 .707 r
F P
0 g
s
.51196 .79097 m .51803 .7742 L .52539 .76422 L p .707 .577 .707 r
F P
0 g
s
.52539 .76422 m .51932 .781 L .51196 .79097 L p .707 .577 .707 r
F P
0 g
s
.52336 .73676 m .51032 .68145 L .52655 .67289 L p .707 .577 .707 r
F P
0 g
s
.49304 .75819 m .50171 .79507 L .49448 .80225 L p .707 .577 .707 r
F P
0 g
s
.52655 .67289 m .53959 .7282 L .52336 .73676 L p .707 .577 .707 r
F P
0 g
s
.51932 .781 m .52539 .76422 L .54148 .75846 L p .707 .577 .707 r
F P
0 g
s
.54148 .75846 m .53541 .77524 L .51932 .781 L p .707 .577 .707 r
F P
0 g
s
.50171 .79507 m .49304 .75819 L .50927 .74964 L p .707 .577 .707 r
F P
0 g
s
.50927 .74964 m .51794 .78651 L .50171 .79507 L p .707 .577 .707 r
F P
0 g
s
.51794 .78651 m .50927 .74964 L .53292 .74055 L p .707 .577 .707 r
F P
0 g
s
.53541 .77524 m .54148 .75846 L .56473 .75748 L p .707 .577 .707 r
F P
0 g
s
.56473 .75748 m .55866 .77425 L .53541 .77524 L p .707 .577 .707 r
F P
0 g
s
.53292 .74055 m .54159 .77743 L .51794 .78651 L p .707 .577 .707 r
F P
0 g
s
.49241 .32074 m .48617 .82191 L .53111 .82131 L p .707 .577 .707 r
F P
0 g
s
.53959 .7282 m .52655 .67289 L .55019 .6638 L p .707 .577 .707 r
F P
0 g
s
.53111 .82131 m .53735 .32014 L .49241 .32074 L p .707 .577 .707 r
F P
0 g
s
.55019 .6638 m .56323 .71911 L .53959 .7282 L p .707 .577 .707 r
F P
0 g
s
.56323 .71911 m .55019 .6638 L .57894 .65505 L p .707 .577 .707 r
F P
0 g
s
.57894 .65505 m .59199 .71036 L .56323 .71911 L p .707 .577 .707 r
F P
0 g
s
.55866 .77425 m .56473 .75748 L .59287 .76136 L p .707 .577 .707 r
F P
0 g
s
.59287 .76136 m .5868 .77814 L .55866 .77425 L p .707 .577 .707 r
F P
0 g
s
.54159 .77743 m .53292 .74055 L .56167 .73182 L p .707 .577 .707 r
F P
0 g
s
.56167 .73182 m .57034 .7687 L .54159 .77743 L p .707 .577 .707 r
F P
0 g
s
.57034 .7687 m .56167 .73182 L .59272 .7243 L p .707 .577 .707 r
F P
0 g
s
.53735 .32014 m .53111 .82131 L .57259 .81694 L p .707 .577 .707 r
F P
0 g
s
.5868 .77814 m .59287 .76136 L .62313 .76974 L p .707 .577 .707 r
F P
0 g
s
.59272 .7243 m .60139 .76117 L .57034 .7687 L p .707 .577 .707 r
F P
0 g
s
.57259 .81694 m .57883 .31576 L .53735 .32014 L p .707 .577 .707 r
F P
0 g
s
.70383 .85026 m .69776 .86704 L .70512 .85706 L p .707 .577 .707 r
F P
0 g
s
.70512 .85706 m .71119 .84029 L .70383 .85026 L p .707 .577 .707 r
F P
0 g
s
.44217 .81868 m .4484 .3175 L .40964 .31075 L p .707 .577 .707 r
F P
0 g
s
.4484 .3175 m .44217 .81868 L .48617 .82191 L p .707 .577 .707 r
F P
0 g
s
.68432 .72298 m .69299 .75986 L .69049 .75476 L p .707 .577 .707 r
F P
0 g
s
.69049 .75476 m .68182 .71788 L .68432 .72298 L p .707 .577 .707 r
F P
0 g
s
.69907 .64101 m .71211 .69632 L .70015 .6938 L p .707 .577 .707 r
F P
0 g
s
.70015 .6938 m .68711 .63849 L .69907 .64101 L p .707 .577 .707 r
F P
0 g
s
.59199 .71036 m .57894 .65505 L .60998 .64751 L p .707 .577 .707 r
F P
0 g
s
.60998 .64751 m .62303 .70282 L .59199 .71036 L p .707 .577 .707 r
F P
0 g
s
.62301 .71872 m .63168 .7556 L .60139 .76117 L p .707 .577 .707 r
F P
0 g
s
.60139 .76117 m .59272 .7243 L .62301 .71872 L p .707 .577 .707 r
F P
0 g
s
.62313 .76974 m .61706 .78651 L .5868 .77814 L p .707 .577 .707 r
F P
0 g
s
.57883 .31576 m .57259 .81694 L .60655 .80922 L p .707 .577 .707 r
F P
0 g
s
.60655 .80922 m .61278 .30804 L .57883 .31576 L p .707 .577 .707 r
F P
0 g
s
.2647 .70565 m .25166 .65034 L .22137 .65594 L p .707 .577 .707 r
F P
0 g
s
.25166 .65034 m .2647 .70565 L .29574 .69811 L p .707 .577 .707 r
F P
0 g
s
.29574 .69811 m .2827 .6428 L .25166 .65034 L p .707 .577 .707 r
F P
0 g
s
.2827 .6428 m .29574 .69811 L .3245 .68936 L p .707 .577 .707 r
F P
0 g
s
.3245 .68936 m .31145 .63405 L .2827 .6428 L p .707 .577 .707 r
F P
0 g
s
.40341 .81192 m .40964 .31075 L .37992 .30113 L p .707 .577 .707 r
F P
0 g
s
.40964 .31075 m .40341 .81192 L .44217 .81868 L p .707 .577 .707 r
F P
0 g
s
.71119 .84029 m .70512 .85706 L .70303 .84386 L p .707 .577 .707 r
F P
0 g
s
.70303 .84386 m .7091 .82708 L .71119 .84029 L p .707 .577 .707 r
F P
0 g
s
.23441 .71125 m .22137 .65594 L .1948 .65905 L p .707 .577 .707 r
F P
0 g
s
.22137 .65594 m .23441 .71125 L .2647 .70565 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.31145 .63405 m .3245 .68936 L .34814 .68027 L p .707 .577 .707 r
F P
0 g
s
.34814 .68027 m .3351 .62496 L .31145 .63405 L p .707 .577 .707 r
F P
0 g
s
.68182 .71788 m .69049 .75476 L .67853 .75222 L p .707 .577 .707 r
F P
0 g
s
.67853 .75222 m .66986 .71535 L .68182 .71788 L p .707 .577 .707 r
F P
0 g
s
.68711 .63849 m .70015 .6938 L .67989 .69411 L p .707 .577 .707 r
F P
0 g
s
.67989 .69411 m .66685 .6388 L .68711 .63849 L p .707 .577 .707 r
F P
0 g
s
.1948 .65905 m .20784 .71436 L .23441 .71125 L p .707 .577 .707 r
F P
0 g
s
.64027 .64191 m .65332 .69722 L .62303 .70282 L p .707 .577 .707 r
F P
0 g
s
.62303 .70282 m .60998 .64751 L .64027 .64191 L p .707 .577 .707 r
F P
0 g
s
.63168 .7556 m .62301 .71872 L .64959 .71564 L p .707 .577 .707 r
F P
0 g
s
.65256 .78179 m .64649 .79856 L .61706 .78651 L p .707 .577 .707 r
F P
0 g
s
.61706 .78651 m .62313 .76974 L .65256 .78179 L p .707 .577 .707 r
F P
0 g
s
.61278 .30804 m .60655 .80922 L .62966 .79891 L p .707 .577 .707 r
F P
0 g
s
.62966 .79891 m .63589 .29773 L .61278 .30804 L p .707 .577 .707 r
F P
0 g
s
.20784 .71436 m .1948 .65905 L .17454 .65936 L p .707 .577 .707 r
F P
0 g
s
.24307 .76394 m .23441 .72706 L .20411 .73264 L p .707 .577 .707 r
F P
0 g
s
.23441 .72706 m .24307 .76394 L .27412 .75642 L p .707 .577 .707 r
F P
0 g
s
.27412 .75642 m .26545 .71954 L .23441 .72706 L p .707 .577 .707 r
F P
0 g
s
.26545 .71954 m .27412 .75642 L .30287 .74769 L p .707 .577 .707 r
F P
0 g
s
.30287 .74769 m .29421 .71081 L .26545 .71954 L p .707 .577 .707 r
F P
0 g
s
.3351 .62496 m .34814 .68027 L .36437 .67171 L p .707 .577 .707 r
F P
0 g
s
.36437 .67171 m .35133 .6164 L .3351 .62496 L p .707 .577 .707 r
F P
0 g
s
.35133 .6164 m .36437 .67171 L .36683 .66927 L p .707 .577 .707 r
F P
0 g
s
.36683 .66927 m .37159 .66453 L p .36581 .65079 L .707 .577 .707 r
F P
0 g
s
.36581 .65079 m .35133 .6164 L .36683 .66927 L .707 .577 .707 r
F
.36215 .28961 m .35806 .27729 L p .35715 .49355 L F P
0 g
s
.37159 .66453 m .35855 .60922 L .35133 .6164 L p .707 .577 .707 r
F P
0 g
s
.35606 .60413 m .35855 .60922 L p .36363 .63339 L .707 .577 .707 r
F P
0 g
s
.3691 .65944 m .36212 .62981 L p .36363 .63339 L .707 .577 .707 r
F P
0 g
s
.36212 .62981 m .35606 .60413 L p .36363 .63339 L .707 .577 .707 r
F P
0 g
s
.35606 .60413 m .36212 .62981 L p .35714 .65692 L .707 .577 .707 r
F P
0 g
s
.36212 .62981 m .3691 .65944 L .35995 .65751 L p .707 .577 .707 r
F P
0 g
s
.35995 .65751 m .35714 .65692 L p .36212 .62981 L .707 .577 .707 r
F P
0 g
s
.35714 .65692 m .3441 .60161 L .35606 .60413 L p .707 .577 .707 r
F P
0 g
s
.3441 .60161 m .35714 .65692 L .33688 .65723 L p .707 .577 .707 r
F P
0 g
s
.35627 .70448 m .35916 .52991 L .35715 .49355 L .707 .577 .707 r
F
.34868 .79264 m .35474 .77587 L .35868 .78112 L p F P
0 g
s
.35868 .78112 m .36609 .79102 L p .35915 .79167 L .707 .577 .707 r
F P
0 g
s
.34868 .79264 m .35868 .78112 L .35915 .79167 L .707 .577 .707 r
F
.35618 .72591 m .35712 .69365 L .35627 .70448 L F
.35591 .79079 m .3566 .7352 L p .35618 .72591 L F P
0 g
s
.3566 .7352 m .35712 .69365 L p .35618 .72591 L .707 .577 .707 r
F P
0 g
s
.35712 .69365 m .35916 .52991 L p .35627 .70448 L .707 .577 .707 r
F P
0 g
s
.35474 .77587 m .34868 .79264 L .34039 .786 L p .707 .577 .707 r
F P
0 g
s
.34039 .786 m .32919 .77704 L p .34088 .7765 L .707 .577 .707 r
F P
0 g
s
.34088 .7765 m .35474 .77587 L .34039 .786 L .707 .577 .707 r
F
.32919 .77704 m .33526 .76026 L .35474 .77587 L p F P
0 g
s
.35182 .77847 m .35591 .79079 L p .35664 .61684 L .707 .577 .707 r
F P
0 g
s
.35806 .27729 m .35391 .61039 L p .35664 .61684 L .707 .577 .707 r
F P
0 g
s
.35391 .61039 m .35182 .77847 L p .35664 .61684 L .707 .577 .707 r
F P
0 g
s
.35916 .52991 m .36215 .28961 L p .35715 .49355 L .707 .577 .707 r
F P
0 g
s
.35855 .60922 m .37159 .66453 L .3691 .65944 L p .707 .577 .707 r
F P
0 g
s
.37368 .80231 m .37992 .30113 L .36215 .28961 L p .707 .577 .707 r
F P
0 g
s
.36002 .80779 m .36609 .79102 L .36818 .80423 L p .707 .577 .707 r
F P
0 g
s
.36609 .79102 m .36002 .80779 L .34868 .79264 L p .707 .577 .707 r
F P
0 g
s
.36215 .28961 m .35591 .79079 L .37368 .80231 L p .707 .577 .707 r
F P
0 g
s
.35182 .77847 m .3553 .49919 L p .36806 .2654 L .707 .577 .707 r
F P
0 g
s
.3553 .49919 m .35806 .27729 L .36741 .26617 L p .707 .577 .707 r
F P
0 g
s
.36741 .26617 m .36806 .2654 L p .3553 .49919 L .707 .577 .707 r
F P
0 g
s
.37992 .30113 m .37368 .80231 L .40341 .81192 L p .707 .577 .707 r
F P
0 g
s
.7091 .82708 m .70303 .84386 L .69168 .82871 L p .707 .577 .707 r
F P
0 g
s
.69168 .82871 m .69775 .81194 L .7091 .82708 L p .707 .577 .707 r
F P
0 g
s
.20411 .73264 m .21278 .76952 L .24307 .76394 L p .707 .577 .707 r
F P
0 g
s
.17454 .65936 m .18758 .71467 L .20784 .71436 L p .707 .577 .707 r
F P
0 g
s
.21278 .76952 m .20411 .73264 L .17753 .73572 L p .707 .577 .707 r
F P
0 g
s
.25702 .82545 m .26308 .80868 L .23365 .79663 L p .707 .577 .707 r
F P
0 g
s
.26308 .80868 m .25702 .82545 L .28728 .83383 L p .707 .577 .707 r
F P
0 g
s
.28728 .83383 m .29334 .81706 L .26308 .80868 L p .707 .577 .707 r
F P
0 g
s
.29421 .71081 m .30287 .74769 L .32652 .7386 L p .707 .577 .707 r
F P
0 g
s
.32652 .7386 m .31786 .70172 L .29421 .71081 L p .707 .577 .707 r
F P
0 g
s
.66685 .6388 m .67989 .69411 L .65332 .69722 L p .707 .577 .707 r
F P
0 g
s
.65332 .69722 m .64027 .64191 L .66685 .6388 L p .707 .577 .707 r
F P
0 g
s
.22759 .81341 m .23365 .79663 L .20794 .78209 L p .707 .577 .707 r
F P
0 g
s
.23365 .79663 m .22759 .81341 L .25702 .82545 L p .707 .577 .707 r
F P
0 g
s
.17753 .73572 m .1862 .7726 L .21278 .76952 L p .707 .577 .707 r
F P
0 g
s
.29334 .81706 m .28728 .83383 L .31541 .83772 L p .707 .577 .707 r
F P
0 g
s
.31541 .83772 m .32148 .82094 L .29334 .81706 L p .707 .577 .707 r
F P
0 g
s
.66986 .71535 m .67853 .75222 L .65826 .75251 L p .707 .577 .707 r
F P
0 g
s
.65826 .75251 m .64959 .71564 L .66986 .71535 L p .707 .577 .707 r
F P
0 g
s
.20794 .78209 m .20187 .79887 L .22759 .81341 L p .707 .577 .707 r
F P
0 g
s
.18758 .71467 m .17454 .65936 L .16258 .65684 L p .707 .577 .707 r
F P
0 g
s
.1862 .7726 m .17753 .73572 L .15726 .73601 L p .707 .577 .707 r
F P
0 g
s
.20187 .79887 m .20794 .78209 L .18846 .76649 L p .707 .577 .707 r
F P
0 g
s
.64959 .71564 m .65826 .75251 L .63168 .7556 L p .707 .577 .707 r
F P
0 g
s
.63589 .29773 m .62966 .79891 L .63966 .78701 L p .707 .577 .707 r
F P
0 g
s
.63966 .78701 m .64589 .28583 L .63589 .29773 L p .707 .577 .707 r
F P
0 g
s
.32148 .82094 m .31541 .83772 L .33866 .83673 L p .707 .577 .707 r
F P
0 g
s
.33866 .83673 m .34473 .81996 L .32148 .82094 L p .707 .577 .707 r
F P
0 g
s
.31786 .70172 m .32652 .7386 L .34275 .73005 L p .707 .577 .707 r
F P
0 g
s
.34275 .73005 m .33409 .69317 L .31786 .70172 L p .707 .577 .707 r
F P
0 g
s
.16258 .65684 m .17562 .71215 L .18758 .71467 L p .707 .577 .707 r
F P
0 g
s
.69775 .81194 m .69168 .82871 L .6722 .8131 L p .707 .577 .707 r
F P
0 g
s
.6722 .8131 m .67827 .79633 L .69775 .81194 L p .707 .577 .707 r
F P
0 g
s
.15726 .73601 m .16593 .77289 L .1862 .7726 L p .707 .577 .707 r
F P
0 g
s
.18846 .76649 m .18239 .78326 L .20187 .79887 L p .707 .577 .707 r
F P
0 g
s
.18239 .78326 m .18846 .76649 L .17711 .75134 L p .707 .577 .707 r
F P
0 g
s
.16593 .77289 m .15726 .73601 L .1453 .73348 L p .707 .577 .707 r
F P
0 g
s
.17562 .71215 m .16258 .65684 L .16008 .65175 L p .707 .577 .707 r
F P
0 g
s
.67827 .79633 m .6722 .8131 L .64649 .79856 L p .707 .577 .707 r
F P
0 g
s
.64649 .79856 m .65256 .78179 L .67827 .79633 L p .707 .577 .707 r
F P
0 g
s
.34473 .81996 m .33866 .83673 L .35476 .83097 L p .707 .577 .707 r
F P
0 g
s
.35476 .83097 m .36082 .8142 L .34473 .81996 L p .707 .577 .707 r
F P
0 g
s
.17711 .75134 m .17105 .76811 L .18239 .78326 L p .707 .577 .707 r
F P
0 g
s
.1453 .73348 m .15397 .77036 L .16593 .77289 L p .707 .577 .707 r
F P
0 g
s
.33409 .69317 m .34275 .73005 L .34998 .72287 L p .707 .577 .707 r
F P
0 g
s
.34998 .72287 m .34131 .68599 L .33409 .69317 L p .707 .577 .707 r
F P
0 g
s
.16008 .65175 m .17313 .70706 L .17562 .71215 L p .707 .577 .707 r
F P
0 g
s
.63966 .78701 m .63557 .7747 L p .63878 .6228 L .707 .577 .707 r
F P
0 g
s
.64225 .57829 m .63966 .78701 L p .63878 .6228 L .707 .577 .707 r
F P
0 g
s
.64181 .27352 m .64589 .28583 L p .63878 .6228 L .707 .577 .707 r
F P
0 g
s
.63557 .7747 m .63721 .64287 L p .63878 .6228 L .707 .577 .707 r
F P
0 g
s
.63721 .64287 m .64181 .27352 L p .63878 .6228 L .707 .577 .707 r
F P
0 g
s
.64181 .27352 m .63557 .7747 L .61779 .76317 L p .707 .577 .707 r
F P
0 g
s
.63418 .71531 m .64615 .71785 L p .63327 .69326 L .707 .577 .707 r
F P
0 g
s
.62551 .67844 m .63221 .70691 L p .63327 .69326 L .707 .577 .707 r
F P
0 g
s
.63221 .70691 m .63418 .71531 L p .63327 .69326 L .707 .577 .707 r
F P
0 g
s
.64615 .71785 m .63748 .68097 L .63429 .68029 L p .707 .577 .707 r
F P
0 g
s
.63429 .68029 m .62551 .67844 L p .63327 .69326 L .707 .577 .707 r
F P
0 g
s
.64615 .71785 m .63429 .68029 L .63327 .69326 L .707 .577 .707 r
F
.64589 .28583 m .64225 .57829 L p .63878 .6228 L F P
0 g
s
.17105 .76811 m .17711 .75134 L .17502 .73813 L p .707 .577 .707 r
F P
0 g
s
.17502 .73813 m .16895 .7549 L .17105 .76811 L p .707 .577 .707 r
F P
0 g
s
.15397 .77036 m .1453 .73348 L .14281 .72838 L p .707 .577 .707 r
F P
0 g
s
.36082 .8142 m .35476 .83097 L .36211 .821 L p .707 .577 .707 r
F P
0 g
s
.36211 .821 m .36818 .80423 L .36082 .8142 L p .707 .577 .707 r
F P
0 g
s
.17313 .70706 m .16008 .65175 L .16731 .64457 L p .707 .577 .707 r
F P
0 g
s
.14281 .72838 m .15147 .76525 L .15397 .77036 L p .707 .577 .707 r
F P
0 g
s
.34131 .68599 m .34998 .72287 L .34748 .71776 L p .707 .577 .707 r
F P
0 g
s
.34748 .71776 m .33881 .68088 L .34131 .68599 L p .707 .577 .707 r
F P
0 g
s
.16731 .64457 m .18035 .69988 L .17313 .70706 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.16895 .7549 m .17502 .73813 L .18238 .72816 L p .707 .577 .707 r
F P
0 g
s
.18238 .72816 m .17631 .74493 L .16895 .7549 L p .707 .577 .707 r
F P
0 g
s
.36818 .80423 m .36211 .821 L .36002 .80779 L p .707 .577 .707 r
F P
0 g
s
.15147 .76525 m .14281 .72838 L .15003 .7212 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.18035 .69988 m .16731 .64457 L .18354 .63601 L p .707 .577 .707 r
F P
0 g
s
.61779 .76317 m .62403 .26199 L .64181 .27352 L p .707 .577 .707 r
F P
0 g
s
.15003 .7212 m .1587 .75807 L .15147 .76525 L p .707 .577 .707 r
F P
0 g
s
.33881 .68088 m .34748 .71776 L .33552 .71523 L p .707 .577 .707 r
F P
0 g
s
.33552 .71523 m .32685 .67835 L .33881 .68088 L p .707 .577 .707 r
F P
0 g
s
.33688 .65723 m .32384 .60192 L .3441 .60161 L p .707 .577 .707 r
F P
0 g
s
.18354 .63601 m .19658 .69132 L .18035 .69988 L p .707 .577 .707 r
F P
0 g
s
.17631 .74493 m .18238 .72816 L .19847 .7224 L p .707 .577 .707 r
F P
0 g
s
.36182 .76657 m .36806 .2654 L .39117 .25508 L p .707 .577 .707 r
F P
0 g
s
.36806 .2654 m .36182 .76657 L .35182 .77847 L p .707 .577 .707 r
F P
0 g
s
.19847 .7224 m .1924 .73917 L .17631 .74493 L p .707 .577 .707 r
F P
0 g
s
.19658 .69132 m .18354 .63601 L .20718 .62692 L p .707 .577 .707 r
F P
0 g
s
.1587 .75807 m .15003 .7212 L .16626 .71264 L p .707 .577 .707 r
F P
0 g
s
.32384 .60192 m .33688 .65723 L .31031 .66034 L p .707 .577 .707 r
F P
0 g
s
.31031 .66034 m .29727 .60503 L .32384 .60192 L p .707 .577 .707 r
F P
0 g
s
.16626 .71264 m .17493 .74952 L .1587 .75807 L p .707 .577 .707 r
F P
0 g
s
.32685 .67835 m .33552 .71523 L .31525 .71552 L p .707 .577 .707 r
F P
0 g
s
.31525 .71552 m .30658 .67864 L .32685 .67835 L p .707 .577 .707 r
F P
0 g
s
.20718 .62692 m .22022 .68223 L .19658 .69132 L p .707 .577 .707 r
F P
0 g
s
.62403 .26199 m .61779 .76317 L .58807 .75356 L p .707 .577 .707 r
F P
0 g
s
.58807 .75356 m .59431 .25238 L .62403 .26199 L p .707 .577 .707 r
F P
0 g
s
.1924 .73917 m .19847 .7224 L .22172 .72141 L p .707 .577 .707 r
F P
0 g
s
.22022 .68223 m .20718 .62692 L .23593 .61817 L p .707 .577 .707 r
F P
0 g
s
.29727 .60503 m .31031 .66034 L .28002 .66594 L p .707 .577 .707 r
F P
0 g
s
.28002 .66594 m .26697 .61063 L .29727 .60503 L p .707 .577 .707 r
F P
0 g
s
.22172 .72141 m .21565 .73819 L .1924 .73917 L p .707 .577 .707 r
F P
0 g
s
.17493 .74952 m .16626 .71264 L .18991 .70356 L p .707 .577 .707 r
F P
0 g
s
.39117 .25508 m .38493 .75626 L .36182 .76657 L p .707 .577 .707 r
F P
0 g
s
.38493 .75626 m .39117 .25508 L .42512 .24736 L p .707 .577 .707 r
F P
0 g
s
.23593 .61817 m .24898 .67348 L .22022 .68223 L p .707 .577 .707 r
F P
0 g
s
.74492 .65049 m .73188 .59518 L .70159 .60078 L p .707 .577 .707 r
F P
0 g
s
.73188 .59518 m .74492 .65049 L .77596 .64295 L p .707 .577 .707 r
F P
0 g
s
.77596 .64295 m .76292 .58764 L .73188 .59518 L p .707 .577 .707 r
F P
0 g
s
.24898 .67348 m .23593 .61817 L .26697 .61063 L p .707 .577 .707 r
F P
0 g
s
.76292 .58764 m .77596 .64295 L .80471 .6342 L p .707 .577 .707 r
F P
0 g
s
.80471 .6342 m .79167 .57889 L .76292 .58764 L p .707 .577 .707 r
F P
0 g
s
.26697 .61063 m .28002 .66594 L .24898 .67348 L p .707 .577 .707 r
F P
0 g
s
.30658 .67864 m .31525 .71552 L .28867 .71861 L p .707 .577 .707 r
F P
0 g
s
.28867 .71861 m .28 .68173 L .30658 .67864 L p .707 .577 .707 r
F P
0 g
s
.18991 .70356 m .19858 .74043 L .17493 .74952 L p .707 .577 .707 r
F P
0 g
s
.71463 .65609 m .70159 .60078 L .67501 .60389 L p .707 .577 .707 r
F P
0 g
s
.70159 .60078 m .71463 .65609 L .74492 .65049 L p .707 .577 .707 r
F P
0 g
s
.21565 .73819 m .22172 .72141 L .24986 .7253 L p .707 .577 .707 r
F P
0 g
s
.79167 .57889 m .80471 .6342 L .82836 .62511 L p .707 .577 .707 r
F P
0 g
s
.82836 .62511 m .81532 .5698 L .79167 .57889 L p .707 .577 .707 r
F P
0 g
s
.33526 .76026 m .32919 .77704 L .30348 .7625 L p .707 .577 .707 r
F P
0 g
s
.30348 .7625 m .30955 .74572 L .33526 .76026 L p .707 .577 .707 r
F P
0 g
s
.24986 .7253 m .24379 .74207 L .21565 .73819 L p .707 .577 .707 r
F P
0 g
s
.59431 .25238 m .58807 .75356 L .54931 .7468 L p .707 .577 .707 r
F P
0 g
s
.54931 .7468 m .55555 .24563 L .59431 .25238 L p .707 .577 .707 r
F P
0 g
s
.19858 .74043 m .18991 .70356 L .21866 .69483 L p .707 .577 .707 r
F P
0 g
s
.67501 .60389 m .68805 .6592 L .71463 .65609 L p .707 .577 .707 r
F P
0 g
s
.28 .68173 m .28867 .71861 L .25838 .72418 L p .707 .577 .707 r
F P
0 g
s
.25838 .72418 m .24971 .6873 L .28 .68173 L p .707 .577 .707 r
F P
0 g
s
.24379 .74207 m .24986 .7253 L .28012 .73367 L p .707 .577 .707 r
F P
0 g
s
.21866 .69483 m .22733 .7317 L .19858 .74043 L p .707 .577 .707 r
F P
0 g
s
.68805 .6592 m .67501 .60389 L .65475 .6042 L p .707 .577 .707 r
F P
0 g
s
.30955 .74572 m .30348 .7625 L .27405 .75045 L p .707 .577 .707 r
F P
0 g
s
.27405 .75045 m .28012 .73367 L .30955 .74572 L p .707 .577 .707 r
F P
0 g
s
.41888 .74854 m .42512 .24736 L .4666 .24299 L p .707 .577 .707 r
F P
0 g
s
.42512 .24736 m .42009 .65141 L p .38686 .73177 L .707 .577 .707 r
F P
0 g
s
.4666 .24299 m .46036 .74417 L .41888 .74854 L p .707 .577 .707 r
F P
0 g
s
.41991 .55076 m .43295 .60607 L .43969 .60402 L p .707 .577 .707 r
F P
0 g
s
.43969 .60402 m .4617 .59732 L p .44853 .58265 L .707 .577 .707 r
F P
0 g
s
.44853 .58265 m .41991 .55076 L .43969 .60402 L .707 .577 .707 r
F
.41888 .74854 m .38493 .75626 L p .38686 .73177 L F P
0 g
s
.42009 .65141 m .41888 .74854 L p .38686 .73177 L .707 .577 .707 r
F P
0 g
s
.72329 .70889 m .71462 .67202 L .68432 .67759 L p .707 .577 .707 r
F P
0 g
s
.71462 .67202 m .72329 .70889 L .75433 .70137 L p .707 .577 .707 r
F P
0 g
s
.75433 .70137 m .74566 .6645 L .71462 .67202 L p .707 .577 .707 r
F P
0 g
s
.22733 .7317 m .21866 .69483 L .24971 .6873 L p .707 .577 .707 r
F P
0 g
s
.74566 .6645 m .75433 .70137 L .78309 .69264 L p .707 .577 .707 r
F P
0 g
s
.78309 .69264 m .77442 .65576 L .74566 .6645 L p .707 .577 .707 r
F P
0 g
s
.24971 .6873 m .25838 .72418 L .22733 .7317 L p .707 .577 .707 r
F P
0 g
s
.28012 .73367 m .27405 .75045 L .24379 .74207 L p .707 .577 .707 r
F P
0 g
s
.81532 .5698 m .82836 .62511 L .84459 .61655 L p .707 .577 .707 r
F P
0 g
s
.84459 .61655 m .83155 .56124 L .81532 .5698 L p .707 .577 .707 r
F P
0 g
s
.68432 .67759 m .69299 .71447 L .72329 .70889 L p .707 .577 .707 r
F P
0 g
s
.65475 .6042 m .66779 .65951 L .68805 .6592 L p .707 .577 .707 r
F P
0 g
s
.69299 .71447 m .68432 .67759 L .65774 .68068 L p .707 .577 .707 r
F P
0 g
s
.73723 .76948 m .7433 .75271 L .71387 .74066 L p .707 .577 .707 r
F P
0 g
s
.7433 .75271 m .73723 .76948 L .76749 .77786 L p .707 .577 .707 r
F P
0 g
s
.76749 .77786 m .77356 .76108 L .7433 .75271 L p .707 .577 .707 r
F P
0 g
s
.55555 .24563 m .54931 .7468 L .5053 .74357 L p .707 .577 .707 r
F P
0 g
s
.5053 .74357 m .51154 .24239 L .55555 .24563 L p .707 .577 .707 r
F P
0 g
s
.77442 .65576 m .78309 .69264 L .80674 .68355 L p .707 .577 .707 r
F P
0 g
s
.80674 .68355 m .79807 .64668 L .77442 .65576 L p .707 .577 .707 r
F P
0 g
s
.7078 .75743 m .71387 .74066 L .68815 .72612 L p .707 .577 .707 r
F P
0 g
s
.71387 .74066 m .7078 .75743 L .73723 .76948 L p .707 .577 .707 r
F P
0 g
s
.65774 .68068 m .66641 .71755 L .69299 .71447 L p .707 .577 .707 r
F P
0 g
s
.46036 .74417 m .4666 .24299 L .51154 .24239 L p .707 .577 .707 r
F P
0 g
s
.77356 .76108 m .76749 .77786 L .79562 .78174 L p .707 .577 .707 r
F P
0 g
s
.79562 .78174 m .80169 .76497 L .77356 .76108 L p .707 .577 .707 r
F P
0 g
s
.51154 .24239 m .5053 .74357 L .46036 .74417 L p .707 .577 .707 r
F P
0 g
s
.68815 .72612 m .68209 .74289 L .7078 .75743 L p .707 .577 .707 r
F P
0 g
s
.66779 .65951 m .65475 .6042 L .64279 .60168 L p .707 .577 .707 r
F P
0 g
s
.66641 .71755 m .65774 .68068 L .63748 .68097 L p .707 .577 .707 r
F P
0 g
s
.68209 .74289 m .68815 .72612 L .66867 .71051 L p .707 .577 .707 r
F P
0 g
s
.83155 .56124 m .84459 .61655 L .85181 .60937 L p .707 .577 .707 r
F P
0 g
s
.85181 .60937 m .83877 .55406 L .83155 .56124 L p .707 .577 .707 r
F P
0 g
s
.80169 .76497 m .79562 .78174 L .81888 .78076 L p .707 .577 .707 r
F P
0 g
s
.81888 .78076 m .82494 .76398 L .80169 .76497 L p .707 .577 .707 r
F P
0 g
s
.79807 .64668 m .80674 .68355 L .82297 .675 L p .707 .577 .707 r
F P
0 g
s
.82297 .675 m .8143 .63813 L .79807 .64668 L p .707 .577 .707 r
F P
0 g
s
.64279 .60168 m .65583 .65699 L .66779 .65951 L p .707 .577 .707 r
F P
0 g
s
.63748 .68097 m .64615 .71785 L .66641 .71755 L p .707 .577 .707 r
F P
0 g
s
.66867 .71051 m .6626 .72729 L .68209 .74289 L p .707 .577 .707 r
F P
0 g
s
.6626 .72729 m .66867 .71051 L .65733 .69536 L p .707 .577 .707 r
F P
0 g
s
.65583 .65699 m .64279 .60168 L .6403 .59659 L p .707 .577 .707 r
F P
0 g
s
.82494 .76398 m .81888 .78076 L .83497 .775 L p .707 .577 .707 r
F P
0 g
s
.83497 .775 m .84104 .75822 L .82494 .76398 L p .707 .577 .707 r
F P
0 g
s
.65733 .69536 m .65126 .71214 L .6626 .72729 L p .707 .577 .707 r
F P
0 g
s
.8143 .63813 m .82297 .675 L .83019 .66782 L p .707 .577 .707 r
F P
0 g
s
.83019 .66782 m .82152 .63095 L .8143 .63813 L p .707 .577 .707 r
F P
0 g
s
.83877 .55406 m .85181 .60937 L .84932 .60428 L p .707 .577 .707 r
F P
0 g
s
.84932 .60428 m .83628 .54897 L .83877 .55406 L p .707 .577 .707 r
F P
0 g
s
.6403 .59659 m .65334 .6519 L .65583 .65699 L p .707 .577 .707 r
F P
0 g
s
.65126 .71214 m .65733 .69536 L .65523 .68216 L p .707 .577 .707 r
F P
0 g
s
.65523 .68216 m .64917 .69893 L .65126 .71214 L p .707 .577 .707 r
F P
0 g
s
.84104 .75822 m .83497 .775 L .84233 .76503 L p .707 .577 .707 r
F P
0 g
s
.84233 .76503 m .8484 .74825 L .84104 .75822 L p .707 .577 .707 r
F P
0 g
s
.63418 .71531 m .62551 .67844 L .62302 .67333 L p .707 .577 .707 r
F P
0 g
s
.65334 .6519 m .6403 .59659 L .64752 .58941 L p .707 .577 .707 r
F P
0 g
s
.62302 .67333 m .63169 .71021 L .63418 .71531 L p .707 .577 .707 r
F P
0 g
s
.82152 .63095 m .83019 .66782 L .8277 .66272 L p .707 .577 .707 r
F P
0 g
s
.8277 .66272 m .81903 .62584 L .82152 .63095 L p .707 .577 .707 r
F P
0 g
s
.83628 .54897 m .84932 .60428 L .83736 .60176 L p .707 .577 .707 r
F P
0 g
s
.83736 .60176 m .82432 .54645 L .83628 .54897 L p .707 .577 .707 r
F P
0 g
s
.64752 .58941 m .66056 .64472 L .65334 .6519 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64917 .69893 m .65523 .68216 L .66259 .67219 L p .707 .577 .707 r
F P
0 g
s
.40191 .61361 m .38887 .5583 L .35858 .5639 L p .707 .577 .707 r
F P
0 g
s
.38887 .5583 m .40191 .61361 L .43295 .60607 L p .707 .577 .707 r
F P
0 g
s
.43295 .60607 m .41991 .55076 L .38887 .5583 L p .707 .577 .707 r
F P
0 g
s
.4617 .59732 m .44866 .54201 L .41991 .55076 L p .707 .577 .707 r
F P
0 g
s
.66259 .67219 m .65652 .68896 L .64917 .69893 L p .707 .577 .707 r
F P
0 g
s
.8484 .74825 m .84233 .76503 L .84023 .75182 L p .707 .577 .707 r
F P
0 g
s
.84023 .75182 m .8463 .73505 L .8484 .74825 L p .707 .577 .707 r
F P
0 g
s
.63169 .71021 m .62302 .67333 L .63024 .66615 L p .707 .577 .707 r
F P
0 g
s
.37162 .61921 m .35858 .5639 L .332 .56701 L p .707 .577 .707 r
F P
0 g
s
.35858 .5639 m .37162 .61921 L .40191 .61361 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.66056 .64472 m .64752 .58941 L .66375 .58085 L p .707 .577 .707 r
F P
0 g
s
.44866 .54201 m .4617 .59732 L .48535 .58823 L p .707 .577 .707 r
F P
0 g
s
.48535 .58823 m .47231 .53292 L .44866 .54201 L p .707 .577 .707 r
F P
0 g
s
.63024 .66615 m .63891 .70303 L .63169 .71021 L p .707 .577 .707 r
F P
0 g
s
.81903 .62584 m .8277 .66272 L .81573 .66019 L p .707 .577 .707 r
F P
0 g
s
.81573 .66019 m .80706 .62331 L .81903 .62584 L p .707 .577 .707 r
F P
0 g
s
.82432 .54645 m .83736 .60176 L .8171 .60207 L p .707 .577 .707 r
F P
0 g
s
.8171 .60207 m .80406 .54676 L .82432 .54645 L p .707 .577 .707 r
F P
0 g
s
.332 .56701 m .34504 .62232 L .37162 .61921 L p .707 .577 .707 r
F P
0 g
s
.66375 .58085 m .67679 .63616 L .66056 .64472 L p .707 .577 .707 r
F P
0 g
s
.34504 .62232 m .332 .56701 L .31174 .56732 L p .707 .577 .707 r
F P
0 g
s
.65652 .68896 m .66259 .67219 L .67868 .66642 L p .707 .577 .707 r
F P
0 g
s
.38028 .6719 m .37161 .63502 L .34131 .6406 L p .707 .577 .707 r
F P
0 g
s
.37161 .63502 m .38028 .6719 L .41132 .66438 L p .707 .577 .707 r
F P
0 g
s
.41132 .66438 m .40265 .6275 L .37161 .63502 L p .707 .577 .707 r
F P
0 g
s
.40265 .6275 m .41132 .66438 L .44008 .65565 L p .707 .577 .707 r
F P
0 g
s
.44008 .65565 m .43141 .61877 L .40265 .6275 L p .707 .577 .707 r
F P
0 g
s
.47231 .53292 m .48535 .58823 L .50158 .57967 L p .707 .577 .707 r
F P
0 g
s
.50158 .57967 m .48854 .52436 L .47231 .53292 L p .707 .577 .707 r
F P
0 g
s
.67868 .66642 m .67262 .6832 L .65652 .68896 L p .707 .577 .707 r
F P
0 g
s
.8463 .73505 m .84023 .75182 L .82889 .73667 L p .707 .577 .707 r
F P
0 g
s
.82889 .73667 m .83496 .7199 L .8463 .73505 L p .707 .577 .707 r
F P
0 g
s
.34131 .6406 m .34998 .67748 L .38028 .6719 L p .707 .577 .707 r
F P
0 g
s
.31174 .56732 m .32478 .62263 L .34504 .62232 L p .707 .577 .707 r
F P
0 g
s
.67679 .63616 m .66375 .58085 L .6874 .57176 L p .707 .577 .707 r
F P
0 g
s
.34998 .67748 m .34131 .6406 L .31473 .64368 L p .707 .577 .707 r
F P
0 g
s
.63891 .70303 m .63024 .66615 L .64647 .6576 L p .707 .577 .707 r
F P
0 g
s
.39422 .73342 m .40029 .71664 L .37086 .70459 L p .707 .577 .707 r
F P
0 g
s
.40029 .71664 m .39422 .73342 L .42448 .74179 L p .707 .577 .707 r
F P
0 g
s
.42448 .74179 m .43055 .72502 L .40029 .71664 L p .707 .577 .707 r
F P
0 g
s
.43141 .61877 m .44008 .65565 L .46373 .64656 L p .707 .577 .707 r
F P
0 g
s
.46373 .64656 m .45506 .60968 L .43141 .61877 L p .707 .577 .707 r
F P
0 g
s
.80406 .54676 m .8171 .60207 L .79052 .60518 L p .707 .577 .707 r
F P
0 g
s
.79052 .60518 m .77748 .54987 L .80406 .54676 L p .707 .577 .707 r
F P
0 g
s
.36479 .72137 m .37086 .70459 L .34514 .69005 L p .707 .577 .707 r
F P
0 g
s
.37086 .70459 m .36479 .72137 L .39422 .73342 L p .707 .577 .707 r
F P
0 g
s
.31473 .64368 m .3234 .68056 L .34998 .67748 L p .707 .577 .707 r
F P
0 g
s
.64647 .6576 m .65514 .69448 L .63891 .70303 L p .707 .577 .707 r
F P
0 g
s
.43055 .72502 m .42448 .74179 L .45261 .74568 L p .707 .577 .707 r
F P
0 g
s
.45261 .74568 m .45868 .7289 L .43055 .72502 L p .707 .577 .707 r
F P
0 g
s
.80706 .62331 m .81573 .66019 L .79547 .66048 L p .707 .577 .707 r
F P
0 g
s
.79547 .66048 m .7868 .6236 L .80706 .62331 L p .707 .577 .707 r
F P
0 g
s
.6874 .57176 m .70044 .62707 L .67679 .63616 L p .707 .577 .707 r
F P
0 g
s
.34514 .69005 m .33908 .70683 L .36479 .72137 L p .707 .577 .707 r
F P
0 g
s
.32478 .62263 m .31174 .56732 L .29978 .5648 L p .707 .577 .707 r
F P
0 g
s
.67262 .6832 m .67868 .66642 L .70194 .66544 L p .707 .577 .707 r
F P
0 g
s
.3234 .68056 m .31473 .64368 L .29447 .64397 L p .707 .577 .707 r
F P
0 g
s
.33908 .70683 m .34514 .69005 L .32566 .67445 L p .707 .577 .707 r
F P
0 g
s
.70044 .62707 m .6874 .57176 L .71615 .56301 L p .707 .577 .707 r
F P
0 g
s
.48854 .52436 m .50158 .57967 L .5088 .5725 L p .707 .577 .707 r
F P
0 g
s
.5088 .5725 m .49576 .51719 L .48854 .52436 L p .707 .577 .707 r
F P
0 g
s
.77748 .54987 m .79052 .60518 L .76023 .61078 L p .707 .577 .707 r
F P
0 g
s
.76023 .61078 m .74719 .55547 L .77748 .54987 L p .707 .577 .707 r
F P
0 g
s
.45868 .7289 m .45261 .74568 L .47587 .74469 L p .707 .577 .707 r
F P
0 g
s
.47587 .74469 m .48193 .72792 L .45868 .7289 L p .707 .577 .707 r
F P
0 g
s
.45506 .60968 m .46373 .64656 L .47996 .63801 L p .707 .577 .707 r
F P
0 g
s
.47996 .63801 m .47129 .60113 L .45506 .60968 L p .707 .577 .707 r
F P
0 g
s
.29978 .5648 m .31282 .62011 L .32478 .62263 L p .707 .577 .707 r
F P
0 g
s
.83496 .7199 m .82889 .73667 L .80941 .72106 L p .707 .577 .707 r
F P
0 g
s
.80941 .72106 m .81547 .70429 L .83496 .7199 L p .707 .577 .707 r
F P
0 g
s
.70194 .66544 m .69587 .68221 L .67262 .6832 L p .707 .577 .707 r
F P
0 g
s
.29447 .64397 m .30314 .68085 L .3234 .68056 L p .707 .577 .707 r
F P
0 g
s
.32566 .67445 m .31959 .69122 L .33908 .70683 L p .707 .577 .707 r
F P
0 g
s
.65514 .69448 m .64647 .6576 L .67012 .64851 L p .707 .577 .707 r
F P
0 g
s
.71615 .56301 m .72919 .61832 L .70044 .62707 L p .707 .577 .707 r
F P
0 g
s
.72919 .61832 m .71615 .56301 L .74719 .55547 L p .707 .577 .707 r
F P
0 g
s
.74719 .55547 m .76023 .61078 L .72919 .61832 L p .707 .577 .707 r
F P
0 g
s
.7868 .6236 m .79547 .66048 L .76889 .66356 L p .707 .577 .707 r
F P
0 g
s
.76889 .66356 m .76022 .62668 L .7868 .6236 L p .707 .577 .707 r
F P
0 g
s
.67012 .64851 m .67879 .68539 L .65514 .69448 L p .707 .577 .707 r
F P
0 g
s
.31959 .69122 m .32566 .67445 L .31432 .6593 L p .707 .577 .707 r
F P
0 g
s
.69587 .68221 m .70194 .66544 L .73007 .66932 L p .707 .577 .707 r
F P
0 g
s
.30314 .68085 m .29447 .64397 L .2825 .64144 L p .707 .577 .707 r
F P
0 g
s
.31282 .62011 m .29978 .5648 L .29729 .55971 L p .707 .577 .707 r
F P
0 g
s
.81547 .70429 m .80941 .72106 L .78369 .70652 L p .707 .577 .707 r
F P
0 g
s
.78369 .70652 m .78976 .68975 L .81547 .70429 L p .707 .577 .707 r
F P
0 g
s
.48193 .72792 m .47587 .74469 L .49196 .73893 L p .707 .577 .707 r
F P
0 g
s
.49196 .73893 m .49803 .72216 L .48193 .72792 L p .707 .577 .707 r
F P
0 g
s
.31432 .6593 m .30825 .67607 L .31959 .69122 L p .707 .577 .707 r
F P
0 g
s
.73007 .66932 m .724 .6861 L .69587 .68221 L p .707 .577 .707 r
F P
0 g
s
.67879 .68539 m .67012 .64851 L .69888 .63978 L p .707 .577 .707 r
F P
0 g
s
.2825 .64144 m .29117 .67832 L .30314 .68085 L p .707 .577 .707 r
F P
0 g
s
.47129 .60113 m .47996 .63801 L .48718 .63083 L p .707 .577 .707 r
F P
0 g
s
.48718 .63083 m .47851 .59395 L .47129 .60113 L p .707 .577 .707 r
F P
0 g
s
.76022 .62668 m .76889 .66356 L .73859 .66914 L p .707 .577 .707 r
F P
0 g
s
.73859 .66914 m .72992 .63226 L .76022 .62668 L p .707 .577 .707 r
F P
0 g
s
.49576 .51719 m .5088 .5725 L .50631 .5674 L p .707 .577 .707 r
F P
0 g
s
.50631 .5674 m .49327 .51209 L .49576 .51719 L p .707 .577 .707 r
F P
0 g
s
.29729 .55971 m .31033 .61502 L .31282 .62011 L p .707 .577 .707 r
F P
0 g
s
.724 .6861 m .73007 .66932 L .76033 .6777 L p .707 .577 .707 r
F P
0 g
s
.69888 .63978 m .70754 .67666 L .67879 .68539 L p .707 .577 .707 r
F P
0 g
s
.78976 .68975 m .78369 .70652 L .75427 .69448 L p .707 .577 .707 r
F P
0 g
s
.75427 .69448 m .76033 .6777 L .78976 .68975 L p .707 .577 .707 r
F P
0 g
s
.70754 .67666 m .69888 .63978 L .72992 .63226 L p .707 .577 .707 r
F P
0 g
s
.72992 .63226 m .73859 .66914 L .70754 .67666 L p .707 .577 .707 r
F P
0 g
s
.76033 .6777 m .75427 .69448 L .724 .6861 L p .707 .577 .707 r
F P
0 g
s
.30825 .67607 m .31432 .6593 L .31222 .64609 L p .707 .577 .707 r
F P
0 g
s
.31222 .64609 m .30615 .66287 L .30825 .67607 L p .707 .577 .707 r
F P
0 g
s
.29117 .67832 m .2825 .64144 L .28001 .63634 L p .707 .577 .707 r
F P
0 g
s
.49803 .72216 m .49196 .73893 L .49932 .72896 L p .707 .577 .707 r
F P
0 g
s
.49932 .72896 m .50539 .71219 L .49803 .72216 L p .707 .577 .707 r
F P
0 g
s
.31033 .61502 m .29729 .55971 L .30451 .55253 L p .707 .577 .707 r
F P
0 g
s
.28001 .63634 m .28868 .67321 L .29117 .67832 L p .707 .577 .707 r
F P
0 g
s
.47851 .59395 m .48718 .63083 L .48469 .62572 L p .707 .577 .707 r
F P
0 g
s
.48469 .62572 m .47602 .58885 L .47851 .59395 L p .707 .577 .707 r
F P
0 g
s
.49327 .51209 m .50631 .5674 L .49435 .56488 L p .707 .577 .707 r
F P
0 g
s
.49435 .56488 m .48131 .50957 L .49327 .51209 L p .707 .577 .707 r
F P
0 g
s
.30451 .55253 m .31755 .60784 L .31033 .61502 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.30615 .66287 m .31222 .64609 L .31958 .63612 L p .707 .577 .707 r
F P
0 g
s
.31958 .63612 m .31351 .65289 L .30615 .66287 L p .707 .577 .707 r
F P
0 g
s
.50539 .71219 m .49932 .72896 L .49722 .71575 L p .707 .577 .707 r
F P
0 g
s
.49722 .71575 m .50329 .69898 L .50539 .71219 L p .707 .577 .707 r
F P
0 g
s
.28868 .67321 m .28001 .63634 L .28723 .62916 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31755 .60784 m .30451 .55253 L .32074 .54398 L p .707 .577 .707 r
F P
0 g
s
.28723 .62916 m .2959 .66603 L .28868 .67321 L p .707 .577 .707 r
F P
0 g
s
.47602 .58885 m .48469 .62572 L .47272 .62319 L p .707 .577 .707 r
F P
0 g
s
.47272 .62319 m .46405 .58631 L .47602 .58885 L p .707 .577 .707 r
F P
0 g
s
.48131 .50957 m .49435 .56488 L .47409 .5652 L p .707 .577 .707 r
F P
0 g
s
.47409 .5652 m .46105 .50989 L .48131 .50957 L p .707 .577 .707 r
F P
0 g
s
.32074 .54398 m .33378 .59929 L .31755 .60784 L p .707 .577 .707 r
F P
0 g
s
.31351 .65289 m .31958 .63612 L .33567 .63036 L p .707 .577 .707 r
F P
0 g
s
.33567 .63036 m .32961 .64713 L .31351 .65289 L p .707 .577 .707 r
F P
0 g
s
.50329 .69898 m .49722 .71575 L .48588 .70061 L p .707 .577 .707 r
F P
0 g
s
.48588 .70061 m .49195 .68383 L .50329 .69898 L p .707 .577 .707 r
F P
0 g
s
.33378 .59929 m .32074 .54398 L .34439 .53488 L p .707 .577 .707 r
F P
0 g
s
.2959 .66603 m .28723 .62916 L .30346 .62061 L p .707 .577 .707 r
F P
0 g
s
.46105 .50989 m .47409 .5652 L .44751 .5683 L p .707 .577 .707 r
F P
0 g
s
.44751 .5683 m .43447 .51299 L .46105 .50989 L p .707 .577 .707 r
F P
0 g
s
.30346 .62061 m .31213 .65748 L .2959 .66603 L p .707 .577 .707 r
F P
0 g
s
.46405 .58631 m .47272 .62319 L .45246 .62348 L p .707 .577 .707 r
F P
0 g
s
.45246 .62348 m .44379 .5866 L .46405 .58631 L p .707 .577 .707 r
F P
0 g
s
.34439 .53488 m .35743 .59019 L .33378 .59929 L p .707 .577 .707 r
F P
0 g
s
.32961 .64713 m .33567 .63036 L .35893 .62937 L p .707 .577 .707 r
F P
0 g
s
.35743 .59019 m .34439 .53488 L .37314 .52613 L p .707 .577 .707 r
F P
0 g
s
.43447 .51299 m .44751 .5683 L .41722 .5739 L p .707 .577 .707 r
F P
0 g
s
.41722 .5739 m .40418 .51859 L .43447 .51299 L p .707 .577 .707 r
F P
0 g
s
.49195 .68383 m .48588 .70061 L .4664 .685 L p .707 .577 .707 r
F P
0 g
s
.4664 .685 m .47246 .66822 L .49195 .68383 L p .707 .577 .707 r
F P
0 g
s
.35893 .62937 m .35286 .64615 L .32961 .64713 L p .707 .577 .707 r
F P
0 g
s
.31213 .65748 m .30346 .62061 L .32711 .61152 L p .707 .577 .707 r
F P
0 g
s
.37314 .52613 m .38618 .58144 L .35743 .59019 L p .707 .577 .707 r
F P
0 g
s
.38618 .58144 m .37314 .52613 L .40418 .51859 L p .707 .577 .707 r
F P
0 g
s
.40418 .51859 m .41722 .5739 L .38618 .58144 L p .707 .577 .707 r
F P
0 g
s
.44379 .5866 m .45246 .62348 L .42587 .62657 L p .707 .577 .707 r
F P
0 g
s
.42587 .62657 m .41721 .58969 L .44379 .5866 L p .707 .577 .707 r
F P
0 g
s
.32711 .61152 m .33578 .6484 L .31213 .65748 L p .707 .577 .707 r
F P
0 g
s
.35286 .64615 m .35893 .62937 L .38706 .63326 L p .707 .577 .707 r
F P
0 g
s
.47246 .66822 m .4664 .685 L .44068 .67046 L p .707 .577 .707 r
F P
0 g
s
.44068 .67046 m .44675 .65368 L .47246 .66822 L p .707 .577 .707 r
F P
0 g
s
.38706 .63326 m .38099 .65003 L .35286 .64615 L p .707 .577 .707 r
F P
0 g
s
.33578 .6484 m .32711 .61152 L .35587 .60279 L p .707 .577 .707 r
F P
0 g
s
.41721 .58969 m .42587 .62657 L .39558 .63214 L p .707 .577 .707 r
F P
0 g
s
.39558 .63214 m .38691 .59527 L .41721 .58969 L p .707 .577 .707 r
F P
0 g
s
.38099 .65003 m .38706 .63326 L .41732 .64164 L p .707 .577 .707 r
F P
0 g
s
.35587 .60279 m .36453 .63966 L .33578 .6484 L p .707 .577 .707 r
F P
0 g
s
.44675 .65368 m .44068 .67046 L .41125 .65841 L p .707 .577 .707 r
F P
0 g
s
.41125 .65841 m .41732 .64164 L .44675 .65368 L p .707 .577 .707 r
F P
0 g
s
.36453 .63966 m .35587 .60279 L .38691 .59527 L p .707 .577 .707 r
F P
0 g
s
.38691 .59527 m .39558 .63214 L .36453 .63966 L p .707 .577 .707 r
F P
0 g
s
.41732 .64164 m .41125 .65841 L .38099 .65003 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8@00OGoo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001gOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@0
07=oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YF00000P00L7oo001/Ool200000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001]Ool006Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00EJEP8006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Ao
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YF
FUH000IJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00IGoo001UOol00`00FUH00006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH3001UOol006Eoo`03001JEP0000IJEP03001JEUYF00MJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP<006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo
001UOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP00
00IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05
FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP80
00YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol2
00000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03
001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF0P002UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003
FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YF
FUH01UYF0P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH2000:FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001V
Ool006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00
FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH010001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IWoo001TOol200000eYF001JEP05FUH00`00FUIJEP06FUH00`00FUH0000<0002FUH00`00
FUH000020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2
001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00EJEP03001J
EUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00EJEP03001JEUYF00@000IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00AJEP@00003FUH005YF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00@000EJEP03001J
EUYF00MJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006Aoo`D00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH00002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol006=oo`<000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0061oo`<0
00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol0
05eoo`<00003FUH005YF00QJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEUYF00800003FUH005YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Ioo`00Fgoo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Uoo`<000IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00:Woo2`00<Goo001GOol20002FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJ
EP03FUH01P00FUIJEP00FUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80
029oo`P000=JEP03001JEUYF00=JEP04001JEP00000_Ool005Ioo`03001JEUYF00=JEP03001JEUYF
00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF
00=JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001ao
o`H000=JEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005Eoo`8000EJEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEUYF00<000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8001Uoo`<00003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001JEUYF000^Ool0
05Aoo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000;FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2000FOol30004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH01000FUIJEP00;Woo001DOol01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/00003FUH0000000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8001=oo`<000QJEP03001JEUYF00EJEP03001JEUYF
00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00EGoo00<005YF000015YF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF10002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P003goo100000=JEP00FUH025YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00;Goo001EOol00`00FUH0
0004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP040004FUH00`00
FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P002goo10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUH002eoo`00EGoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00AJEPH000MJEP03001JEUYF00AJEP03001JEUYF00=JEP<000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Uoo`800003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF000]Ool005Eoo`04001J
EUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH20007Ool20003FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000/Ool005Ioo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEPD000QJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF0080
009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000Eoo`80
00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF
00=JEP03001JEUYF008002aoo`00EWoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH01000
15YF00<005YFFUH01UYF00<005YF00002@0015YF0`0015YF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P000goo0`001eYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH002aoo`00EWoo00@005YF
FUH000=JEP03001JEUYF00AJEP@000QJEP04001JEUYFFUH70003FUH00`00FUIJEP02FUH00`00FUH0
00040006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0goo00000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00;7oo001FOol01000FUIJEP0015YF00@005YF
FUIJEP8000=JEP03001JEUYF00IJEP@0009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF
008000MJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP@000AJ
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEUYF008002]oo`00Egoo00<005YF000015YF00@005YF000000EJEP03
001JEUYF009JEP@000MJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0008FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP0015YF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00:goo001GOol00`00FUH00004FUH30006FUH500000eYF001JEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYF000[Ool005Moo`05001JEUYF001JEP020003FUH00`00FUH000040006FUH00`00FUIJEP06FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEUYF0P001UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPd002]oo`00D7oo20000UYF
0P000eYF10000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH00UYF20001EYF00<005YFFUH00UYF00@005YF000002Yoo`00BWoo1P0015YF00L005YFFUH0
05YF001JEP040006FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUIJEP020006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH20002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH7
0006FUH00`00FUIJEP04FUH00`00FUIJEP02FUH01000FUIJEP00:Woo0016Ool400000eYF001JEP08
FUH01@00FUIJEP00FUH00`002EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH0100015YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P00:goo0012Ool40005
FUH00`00FUIJEP07FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF00001UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH01EYF100025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0P00
;7oo000oOol300000eYF001JEP07FUH00`00FUIJEP06FUH30005FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH00eYF0P000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00@005YF000002ioo`00?7oo0`0015YF00<005YFFUH01UYF00<005YFFUH015YF0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEPh000AJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<0009JEP03001J
EUYF009JEP03001JEUYF00EJEP03001JEP00008000IJEP03001JEUYF00IJEPh00004FUH00000000`
Ool003Uoo`<000QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEP04001JEP000004
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30002FUH00`00
FUIJEP02FUH00`00FUIJEP04FUH40008FUH00`00FUH000070003FUH00`00FUIJEP03FUH00`00FUIJ
EP02000cOol003Ioo`<00003FUH005YF00QJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH01000FUIJEP0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0`000UYF00<005YFFUH00eYF00<005YF00000`000eYF00@005YFFUIJEPL000AJEP03001JEUYF
00EJEP03001JEUYF009JEP05001JEUYFFUH0000cOol003Aoo`8000AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001J
EUYF00T000QJEP03001JEUYF00AJEP03001JEUYF00=JEP8000EJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP800004Ool005YF0005FUH20007FUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00<goo000bOol30006FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00002FUH00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH40003FUH00`00FUIJEP040008FUH00`00FUIJEP04FUH01000FUIJEUYF0P001UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000Eoo`00FUIJEP00
009JEP800003FUH005YF009JEP@000IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP04001JEUYF000cOol0031oo`80009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH00eYF0P001eYF00<005YFFUH015YF
100015YF00<005YFFUH015YF00@005YF000000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF00=JEP@0009JEP<000AJEP<00003FUH005YF00QJEP03001JEUYF00IJEP03
001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080039oo`00;goo00<005YFFUH00eYF00<005YF
FUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP05FUH0
0`00FUH000060004FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH015YF0P002UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000AJEP00FUIJEP80
00=JEP<000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05
001JEUYFFUH0000bOol002ioo`8000EJEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00IJ
EP03001JEP00009JEP03001JEUYF009JEP03001JEUYF00=JEP@000IJEPH000MJEP03001JEUYF009J
EP<000AJEP8000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8000=JEP03001JEP0000<000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH0000bOol002eoo`03001JEP0000EJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP00009JEP03001JEUYF009JEP03001JEP0000<000AJEP03
001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP05FUH400000eYF001JEP0;FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH400000eYF001JEP07
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP00
<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00H0
05YFFUH005YF0004FUH30007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH300000eYF001JEP08FUH3
00000eYF001JEP0;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH30002FUH20003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH01000FUIJEP00<Woo000]Ool01000FUIJEP0015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH01UYF00H005YFFUH005YF0003FUH40007FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH30008FUH00`00FUIJEP02000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP02FUH:0002FUH00`00Oomoo`0_Ool002ioo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEP00009JEP@00003FUH0000000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEPH000AJEP03001JEUYF009JEP8000]JEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP@000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00AJEPL000AJEP03001JEUYF009JEP@0035oo`00;Woo00<005YF00001EYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH015YF1@000UYF0P0000EJEP00001JEP0000MJEP03001JEUYF00IJ
EP03001JEUYF00=JEP8000AJEP03001JEP0000800003FUH005YF00EJEP8000UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00
FUH0000aOol002ioo`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP04
0006FUH01000FUH005YF0P000UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF00000P001UYF
00<005YFFUH00UYF0P0025YF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01EYF1@00
25YF00<005YFFUH015YF00<005YFFUH00UYF0P00<Woo000^Ool01000FUIJEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF1@0025YF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP02
FUH60009FUH00`00FUIJEP04FUH20005FUH00`00FUH00007FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01@00FUH005YF000015YF00<005YFFUH015YF00<005YFFUH01eYF00<005YF
FUH010000UYF10001eYF00<005YFFUH015YF00<005YFFUH00UYF00<007ooOol0<Goo000_Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP06FUH20002FUH20004
FUH20002FUH80005FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20003FUH00`00FUIJEP020005FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH00002FUH01@00FUIJEUYF0000
1eYF00<005YFFUH015YF1@000UYF00<005YFFUH01EYF0`0015YF00<005YFFUH015YF00D005YFFUIJ
EP0003Aoo`00;goo00<005YF000015YF00<005YFFUH01EYF00<005YF00000P001UYF00@005YFFUIJ
EP`0009JEP03001JEUYF00<00006FUH00000001JEP001UYF00<005YF00000P001EYF00<005YFFUH0
25YF0`001EYF00<005YFFUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YF00000UYF00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH010001eYF00<005YFFUH01eYF
0`000UYF00<005YFFUH01EYF0`00=Goo000_Ool01000FUIJEP0015YF00<005YFFUH00eYF100025YF
10000UYF00<005YFFUH01EYF0P000UYF00@005YFFUIJEP<0009oo`03001JEP0000IJEPH000AJEP03
001JEUYF00QJEP03001JEP0000IJEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUH00000FUH000AJEP03001JEUYF00AJEPT000AJEP03001JEUYF00MJEP04001JEUYFFUH2
00000eYF001JEP04FUH2000gOol002moo`04001JEUYF0004FUH00`00FUH000030003FUH00`00FUIJ
EP02FUH40007FUH00`00FUIJEP05FUH30006FUH01P00Oomoo`00FUH000IJEPH000AJEP03001JEUYF
00QJEP04001JEUYF0005FUH20002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1P00FUIJEP00FUH000AJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEPL000MJEP03001JEUYF
00=JEP800003FUH00000008003Uoo`00<7oo00<005YF000015YF0`001UYF1@0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YF00001eYF00D007oo001JEP0000IJEPH000AJEP03001JEUYF00QJEP05
001JEUYFFUH00004FUH01@00FUH005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0005FUH01000FUH000001EYF00<005YFFUH01UYF00@005YFFUIJEP@0009JEP03001JEUYF
00IJEP8003aoo`00<7oo00<005YF00000eYF00@005YFFUH000=JEP@000IJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYF0006FUH300000eYF001JEP05FUH00`00FUH000020005FUH00`00FUIJ
EP08FUH00`00FUIJEP02FUH200000eYF001JEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEP000UYF00@005YFFUIJEP<000MJEP03001JEUYF00IJEP03001JEUYF00EJEP@000MJ
EP04001JEP00000jOol0031oo`03001JEUYF00<000AJEP<00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP05001JEUYFFUH00004FUH01000FUIJEUYF0P001UYF00<005YFFUH01eYF00<0
05YFFUH025YF00<005YFFUH015YF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUH0009JEP05001JEP00001JEP020007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
1000FUH000001EYF00@005YFFUIJEP8003Qoo`00<7oo00<005YFFUH00P000eYF0`000eYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF
0P0015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P0000IJEP00FUH005YF0006
FUH00`00FUIJEP07FUH00`00FUIJEP04FUH40002Ool300000eYF001JEP05FUH2000fOol0035oo`03
FUH005YF00@000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=J
EP<000QJEP80009JEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF0080
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEP00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`0cOol0035oo`@0
0003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000QJEP03001JEP00008000UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
008000aJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH01000FUIJEP000eYF
00<005YFFUH015YF00<005YFFUH015YF1@003goo0P001UYF0`00<goo000_Ool20005FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH0
00001EYF00<005YFFUH00UYF0`001eYF00<005YFFUH025YF00<005YFFUH01eYF0P0000=JEP00FUH0
2eYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP03001JEP0000AJEP03001J
EUYF00=JEP03001JEUYF00@001Ioo`03001JEUYF00=JEP04001JEUYF000bOol002eoo`<000MJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH;000015YF000000000eYF
00<005YFFUH01EYF0`0015YF00<005YFFUH025YF00<005YFFUH025YF00<005YF000035YF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00FUIJEP00009JEP04001JEP00FUH6
000:Ool3000>Ool20002FUH00`00FUIJEP02FUH2000`Ool002]oo`80009JEP03001JEUYF00EJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPP000EJEP03001JEUYF009JEPP000UJEP03
001JEP0000800003FUH005YF00UJEP03001JEUYF00QJEP<000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEPL0009JEP03001JEUYF00<000eoo`D000moo`<000IJEP03001oogoo02eo
o`00:Woo00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF1P001UYF
00<005YFFUH015YF00<005YFFUH00UYF00<005YFFUH00P0000AJEP00000000QJEP03001JEUYF009J
EP<000UJEP03001JEUYF00IJEPD000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8000=JEP04001JEP000005FUH00`00Oomoo`0;Ool5000AOol00`00FUIJEP04FUH2000^Ool002Uo
o`8000EJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF009JEPL000QJEP03001JEUYF00AJ
EP03001JEUYF00=JEP800004Ool005YF0002FUH30004FUH00`00FUIJEP06FUH50004FUH01000FUIJ
EUYF1@000UYF00<005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
0eYF00@005YFFUH000IJEP03001oogoo00Yoo`D0019oo`03001JEUYF009JEP03001JEP0002ioo`00
:7oo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEP000080009JEP03001J
EP0000<000MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001oogoo001JEP001EYF0`0000=JEP00
FUH01eYF00<005YFFUH00UYF20000UYF00@005YFFUIJEP800003FUH005YF00]JEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP05001JEUYFFUH00005FUH3000;Ool3000DOol2
0002FUH01000FUIJEP00;Goo000XOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH015YF
0`0015YF00<005YFFUH015YF100015YF00<005YFFUH015YF00<005YFFUH00P000goo00<005YF0000
25YF0`001eYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEUYF009JEP05001J
EUYFFUH00003FUH2000ROol20003FUH00`00Oomoo`0[Ool002Uoo`03001JEP0000AJEP03001JEUYF
00EJEP03001JEUYF00@000MJEP03001JEUYF00IJEP04001JEP000002FUH00`00FUIJEP04FUH30005
Ool00`00FUH0000;FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YF
FUH00UYF00@005YFFUH000EJEP80025oo`03001JEUYF009JEP03001oogoo02Yoo`00:Goo00<005YF
000015YF00<005YFFUH015YF100015YF10000UYF00<005YFFUH01UYF00<005YFFUH00UYF0`001EYF
0P001goo00<005YF00003eYF10001eYF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00UYF0`00
25YF0P0087oo00<005YFFUH00P00;7oo000YOol01000FUIJEP0015YF00@005YFFUIJEP8000AJEP03
001JEUYF00EJEP@000MJEP03001JEUYF00AJEP800004FUH000000009Ool00`00FUH0000@FUH00`00
FUIJEP040002FUH01000FUIJEUYF4P001UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P0015YF00<005YFFUH00eYF0P0025YF00@005YF000001ioo`06001JEUYF001JEP00:goo000Y
Ool01000FUIJEP0015YF00@005YF000000IJEP03001JEUYF00IJEP03001JEUYF00@0009JEP03001J
EUYF00MJEP8000]oo`03001JEP0000mJEPh000IJEP03001JEUYF00UJEPT000QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000EJEP03001JEUYF009JEP04001JEP000006FUH01000FUIJEUYF0P007Goo
0P000UYF00<007ooOol0:Goo000ZOol00`00FUH00004FUH30007FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH40008FUH01000FUH000002Goo00<005YF000035YF0`001eYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01UYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF2P000UYF
0P000eYF00<005YFFUH015YF0P0077oo00@005YFFUH002]oo`00:Woo00D005YFFUH005YF00800003
FUH0000000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000EJEP04001JEUYFFUH2
0007Ool00`00FUH00008FUH4000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP040006FUH00`00FUIJEP02FUH40004FUH00`00FUIJEP02FUH400001Goo000005YF0000
25YF0`006Goo00<005YF0000;7oo000ZOol00`00FUIJEP0200001EYF000005YF00001eYF00<005YF
FUH01UYF00<005YFFUH01EYF0`000goo0`0000=JEP00FUH01EYF0P001Goo00<005YF00001EYF0`00
0eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
15YF0P0015YF00<005YFFUH00UYF0`001EYF00<005YFFUH00UYF00@005YFFUH000=oo`<000MJEP03
001JEUYF00@001Eoo`03001JEP0002aoo`00:Woo00H005YF001JEP00FUH20002FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool20008FUH00`00Oomoo`02Ool01000FUH005YF1000
1UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
1UYF0`0000=JEP00FUH00eYF0`001UYF00<005YFFUH00UYF00<005YF00001Woo0P001EYF00<005YF
FUH015YF1P003Goo0P0000=JEP00Ool0;7oo000[Ool01P00FUIJEP00FUH000AJEP03001JEUYF00AJ
EP03001JEUYF009JEPL000moo`8000EJEP03001JEP0000=oo`04001JEP000002FUH00`00FUIJEP05
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07
FUH01000FUH0000015YF0`001UYF00<005YFFUH00UYF0P002Goo0`0000=JEP00FUH025YF00@005YF
FUIJEPd0009JEP8002eoo`00:goo00@005YFFUIJEP8000AJEP80009JEPP001Qoo`8000=JEP03001J
EUYF00800003Ool0000000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH30006FUH00`00FUIJ
EP02FUH00`00Oomoo`0;Ool30008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000
;Woo000[Ool70002FUH00`00FUIJEP02000?Ool3000@Ool30005FUH30004FUH00`00FUIJEP05FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH50007FUH01000FUH000004Goo0`0015YF00<005YFFUH01UYF00<005YFFUH00eYF
00@005YFFUIJEP8002ioo`00<Goo00@005YFFUH000=JEP8000eoo`D0015oo`03001JEUYF00AJEP80
00AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP00008000IJEP<001Ioo`<00003FUH005YF
00IJEP03001JEUYF00AJEP03001JEUYF008002moo`00<Woo0P001UYF00<007ooOol02Woo1@004Woo
00<005YFFUH00eYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00000`000eYF0P00
77oo1@0015YF00<005YFFUH00eYF00@005YF0000035oo`00<goo00<005YFFUH01EYF00<007ooOol0
2Goo1@004goo00<005YFFUH00UYF0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YFFUH0
009JEP<002=oo``003=oo`00=7oo00<005YFFUH015YF0`002Woo0`005Goo00H005YFFUH005YF0004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP000eYF0`00HGoo000eOol00`00FUIJEP02
FUH01000FUIJEUYF0P008Goo0`0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YF00000eYF00@005YFFUIJEP8005moo`00=Woo0P000UYF00<005YFFUH00eYF0P008Goo00@005YF
FUH000=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF00=JEP8005eoo`00>7oo
0P0025YF0P0087oo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF100000=JEP00FUH0
1eYF00<007ooOol0FWoo000iOol00`00FUIJEP06FUH01000FUH000007Woo00<005YFFUH010001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF00@007ooOomoo`8000QJEP<005Yoo`00>Woo0P001EYF00<005YFFUH00UYF0`00
77oo0P0000=JEP00Ool00P001UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH01eYF00@005YFFUIJEP8000Ioo`8000IJEP04001JEUYF001IOol003ao
o`8000=JEP03001JEUYF00EJEP<001Yoo`03001JEP0000=oo`@0009JEP03001JEUYF00QJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP00000:Ool20003
FUH00`00FUIJEP02FUH2001GOol003ioo`<000UJEP03001JEP00008001Moo`8000Qoo`D000QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJEP@000ioo`800003FUH0
05YF00EJEP03001oogoo05Aoo`00@7oo0P0025YF00<005YFFUH00UYF0`004goo0`003Goo1P000UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02@0047oo0P001UYF0P00
EGoo0012Ool30004FUH00`00FUIJEP06FUH5000<Ool200000eYF001oo`0COol90006FUH00`00FUIJ
EP09FUH00`00FUIJEP04FUH80004Ool5000BOol00`00FUIJEP02FUH00`00FUH0001EOol004Eoo`<0
0003FUH005YF00QJEP04001JEUYFFUH<0002FUH2000MOolK000:Ool5000COol20002FUH01000FUIJ
EP00E7oo0018Ool30007FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000<Goo00D0
05YFFUIJEP0000=JEP8000Uoo`<001Ioo`8000=JEP03001oogoo059oo`00Bgoo0P001EYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80039oo`04001JEUYF0005FUH2000QOol00`00FUIJ
EP02FUH00`00Oomoo`1AOol004eoo`<00003FUH005YF00MJEP03001JEUYF00=JEP03001JEUYF0080
03Aoo`8000QJEP80021oo`03001JEUYF008005=oo`00D7oo1@0015YF00@005YFFUIJEPH003Moo`03
001JEUYF00IJEP04001JEP00000NOol01P00FUIJEP00FUH0059oo`00EGoo2000?Woo0P001UYF00@0
05YFFUIJEP8001eoo`80009JEP03001oogoo051oo`00WGoo0P000eYF00<005YFFUH015YF0P0077oo
00@005YFFUH0059oo`00Wgoo0P0000=JEP00FUH01eYF0`006Goo00<005YF0000Dgoo002QOol30007
FUH00`00FUIJEP04000EOol00`00FUH0001COol00:Aoo`8000EJEP03001JEUYF00AJEPH000eoo`80
0003FUH007oo05=oo`00YWoo0`0000=JEP00FUH025YF00@005YFFUIJEPd0009JEP8005Aoo`00ZGoo
0`0025YF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0005Eoo`00[7oo0`0015YF00<0
05YFFUH01UYF00<005YFFUH00eYF00@005YFFUIJEP8005Eoo`00[goo0`0000=JEP00FUH01UYF00<0
05YFFUH015YF00<005YFFUH00P00EWoo002bOol50004FUH00`00FUIJEP03FUH01000FUH00000F7oo
002gOol<001JOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58278 .7546 m .59582 .70209 L .56553 .69288 L p .707 .577 .707 r
F P
0 g
s
.59582 .70209 m .58278 .7546 L .61382 .76042 L p .707 .577 .707 r
F P
0 g
s
.61382 .76042 m .62686 .70791 L .59582 .70209 L p .707 .577 .707 r
F P
0 g
s
.55249 .74539 m .56553 .69288 L .53895 .68118 L p .707 .577 .707 r
F P
0 g
s
.56553 .69288 m .55249 .74539 L .58278 .7546 L p .707 .577 .707 r
F P
0 g
s
.62686 .70791 m .61382 .76042 L .64257 .76227 L p .707 .577 .707 r
F P
0 g
s
.64257 .76227 m .65561 .70976 L .62686 .70791 L p .707 .577 .707 r
F P
0 g
s
.60442 .81749 m .61309 .78247 L .58279 .77328 L p .707 .577 .707 r
F P
0 g
s
.61309 .78247 m .60442 .81749 L .63546 .82328 L p .707 .577 .707 r
F P
0 g
s
.63546 .82328 m .64413 .78827 L .61309 .78247 L p .707 .577 .707 r
F P
0 g
s
.52591 .73369 m .53895 .68118 L .51869 .66813 L p .707 .577 .707 r
F P
0 g
s
.53895 .68118 m .52591 .73369 L .55249 .74539 L p .707 .577 .707 r
F P
0 g
s
.65561 .70976 m .64257 .76227 L .66622 .75998 L p .707 .577 .707 r
F P
0 g
s
.66622 .75998 m .67926 .70747 L .65561 .70976 L p .707 .577 .707 r
F P
0 g
s
.57412 .8083 m .58279 .77328 L .55621 .7616 L p .707 .577 .707 r
F P
0 g
s
.58279 .77328 m .57412 .8083 L .60442 .81749 L p .707 .577 .707 r
F P
0 g
s
.64413 .78827 m .63546 .82328 L .66422 .82512 L p .707 .577 .707 r
F P
0 g
s
.66422 .82512 m .67289 .79011 L .64413 .78827 L p .707 .577 .707 r
F P
0 g
s
.55621 .7616 m .54754 .79662 L .57412 .8083 L p .707 .577 .707 r
F P
0 g
s
.54754 .79662 m .55621 .7616 L .53594 .74857 L p .707 .577 .707 r
F P
0 g
s
.67289 .79011 m .66422 .82512 L .68787 .82282 L p .707 .577 .707 r
F P
0 g
s
.68787 .82282 m .69654 .78781 L .67289 .79011 L p .707 .577 .707 r
F P
0 g
s
.51869 .66813 m .50565 .72064 L .52591 .73369 L p .707 .577 .707 r
F P
0 g
s
.50565 .72064 m .51869 .66813 L .50673 .65501 L p .707 .577 .707 r
F P
0 g
s
.58874 .84039 m .58268 .82231 L .55325 .83093 L p .707 .577 .707 r
F P
0 g
s
.58268 .82231 m .58874 .84039 L .619 .83012 L p .707 .577 .707 r
F P
0 g
s
.619 .83012 m .61294 .81204 L .58268 .82231 L p .707 .577 .707 r
F P
0 g
s
.61294 .81204 m .619 .83012 L .64714 .81921 L p .707 .577 .707 r
F P
0 g
s
.64714 .81921 m .64107 .80113 L .61294 .81204 L p .707 .577 .707 r
F P
0 g
s
.67926 .70747 m .66622 .75998 L .68245 .75377 L p .707 .577 .707 r
F P
0 g
s
.68245 .75377 m .69549 .70126 L .67926 .70747 L p .707 .577 .707 r
F P
0 g
s
.55325 .83093 m .55931 .84901 L .58874 .84039 L p .707 .577 .707 r
F P
0 g
s
.53594 .74857 m .52728 .78359 L .54754 .79662 L p .707 .577 .707 r
F P
0 g
s
.55931 .84901 m .55325 .83093 L .52753 .83706 L p .707 .577 .707 r
F P
0 g
s
.64107 .80113 m .64714 .81921 L .67039 .80872 L p .707 .577 .707 r
F P
0 g
s
.67039 .80872 m .66432 .79065 L .64107 .80113 L p .707 .577 .707 r
F P
0 g
s
.52753 .83706 m .5336 .85514 L .55931 .84901 L p .707 .577 .707 r
F P
0 g
s
.52728 .78359 m .53594 .74857 L .52398 .73547 L p .707 .577 .707 r
F P
0 g
s
.69654 .78781 m .68787 .82282 L .7041 .81661 L p .707 .577 .707 r
F P
0 g
s
.7041 .81661 m .71277 .78159 L .69654 .78781 L p .707 .577 .707 r
F P
0 g
s
.50673 .65501 m .49369 .70752 L .50565 .72064 L p .707 .577 .707 r
F P
0 g
s
.49369 .70752 m .50673 .65501 L .50424 .64311 L p .707 .577 .707 r
F P
0 g
s
.5336 .85514 m .52753 .83706 L .50805 .8401 L p .707 .577 .707 r
F P
0 g
s
.69549 .70126 m .68245 .75377 L .68967 .74425 L p .707 .577 .707 r
F P
0 g
s
.68967 .74425 m .70271 .69174 L .69549 .70126 L p .707 .577 .707 r
F P
0 g
s
.52398 .73547 m .51531 .77049 L .52728 .78359 L p .707 .577 .707 r
F P
0 g
s
.50805 .8401 m .51412 .85818 L .5336 .85514 L p .707 .577 .707 r
F P
0 g
s
.66432 .79065 m .67039 .80872 L .68648 .79969 L p .707 .577 .707 r
F P
0 g
s
.68648 .79969 m .68042 .78161 L .66432 .79065 L p .707 .577 .707 r
F P
0 g
s
.51531 .77049 m .52398 .73547 L .52149 .72358 L p .707 .577 .707 r
F P
0 g
s
.71277 .78159 m .7041 .81661 L .71132 .80709 L p .707 .577 .707 r
F P
0 g
s
.71132 .80709 m .71999 .77208 L .71277 .78159 L p .707 .577 .707 r
F P
0 g
s
.50424 .64311 m .4912 .69562 L .49369 .70752 L p .707 .577 .707 r
F P
0 g
s
.51412 .85818 m .50805 .8401 L .49671 .83975 L p .707 .577 .707 r
F P
0 g
s
.49671 .83975 m .50277 .85783 L .51412 .85818 L p .707 .577 .707 r
F P
0 g
s
.52149 .72358 m .51282 .75859 L .51531 .77049 L p .707 .577 .707 r
F P
0 g
s
.4912 .69562 m .50424 .64311 L .51146 .63359 L p .707 .577 .707 r
F P
0 g
s
.68042 .78161 m .68648 .79969 L .69384 .79299 L p .707 .577 .707 r
F P
0 g
s
.69384 .79299 m .68777 .77491 L .68042 .78161 L p .707 .577 .707 r
F P
0 g
s
.70271 .69174 m .68967 .74425 L .68718 .73235 L p .707 .577 .707 r
F P
0 g
s
.68718 .73235 m .70022 .67984 L .70271 .69174 L p .707 .577 .707 r
F P
0 g
s
.51146 .63359 m .49842 .6861 L .4912 .69562 L p .707 .577 .707 r
F P
0 g
s
.49469 .82172 m .48846 .3192 L .44445 .31708 L p .707 .577 .707 r
F P
0 g
s
.51282 .75859 m .52149 .72358 L .52871 .71406 L p .707 .577 .707 r
F P
0 g
s
.52871 .71406 m .52004 .74908 L .51282 .75859 L p .707 .577 .707 r
F P
0 g
s
.49842 .6861 m .51146 .63359 L .52769 .62738 L p .707 .577 .707 r
F P
0 g
s
.52004 .74908 m .52871 .71406 L .54494 .70785 L p .707 .577 .707 r
F P
0 g
s
.52769 .62738 m .51465 .67989 L .49842 .6861 L p .707 .577 .707 r
F P
0 g
s
.51465 .67989 m .52769 .62738 L .55134 .62509 L p .707 .577 .707 r
F P
0 g
s
.54494 .70785 m .53627 .74286 L .52004 .74908 L p .707 .577 .707 r
F P
0 g
s
.55134 .62509 m .5383 .6776 L .51465 .67989 L p .707 .577 .707 r
F P
0 g
s
.50804 .84742 m .50197 .82935 L .51806 .82031 L p .707 .577 .707 r
F P
0 g
s
.51806 .82031 m .52413 .83839 L .50804 .84742 L p .707 .577 .707 r
F P
0 g
s
.52413 .83839 m .51806 .82031 L .54132 .80983 L p .707 .577 .707 r
F P
0 g
s
.54132 .80983 m .54738 .8279 L .52413 .83839 L p .707 .577 .707 r
F P
0 g
s
.48846 .3192 m .49469 .82172 L .53963 .82012 L p .707 .577 .707 r
F P
0 g
s
.53627 .74286 m .54494 .70785 L .56859 .70555 L p .707 .577 .707 r
F P
0 g
s
.56859 .70555 m .55992 .74056 L .53627 .74286 L p .707 .577 .707 r
F P
0 g
s
.53963 .82012 m .5334 .31761 L .48846 .3192 L p .707 .577 .707 r
F P
0 g
s
.55134 .62509 m .58009 .62694 L p .55147 .66163 L .707 .577 .707 r
F P
0 g
s
.5383 .6776 m .54529 .64947 L p .55147 .66163 L .707 .577 .707 r
F P
0 g
s
.54529 .64947 m .55134 .62509 L p .55147 .66163 L .707 .577 .707 r
F P
0 g
s
.62914 .78002 m .63521 .7981 L .60578 .80672 L p .707 .577 .707 r
F P
0 g
s
.60578 .80672 m .59971 .78865 L .62914 .78002 L p .707 .577 .707 r
F P
0 g
s
.59971 .78865 m .60578 .80672 L .57552 .81699 L p .707 .577 .707 r
F P
0 g
s
.58111 .81496 m .61507 .80673 L p .61313 .78294 L .707 .577 .707 r
F P
0 g
s
.56705 .67945 m .58009 .62694 L .61113 .63276 L p .707 .577 .707 r
F P
0 g
s
.58009 .62694 m .56705 .67945 L .5383 .6776 L p .707 .577 .707 r
F P
0 g
s
.64142 .64197 m .62838 .69448 L .59809 .68527 L p .707 .577 .707 r
F P
0 g
s
.59809 .68527 m .61113 .63276 L .64142 .64197 L p .707 .577 .707 r
F P
0 g
s
.55992 .74056 m .56859 .70555 L .59734 .70739 L p .707 .577 .707 r
F P
0 g
s
.61113 .63276 m .59809 .68527 L .56705 .67945 L p .707 .577 .707 r
F P
0 g
s
.59734 .70739 m .58867 .7424 L .55992 .74056 L p .707 .577 .707 r
F P
0 g
s
.58867 .7424 m .59734 .70739 L .62839 .71318 L p .707 .577 .707 r
F P
0 g
s
.62839 .71318 m .61972 .7482 L .58867 .7424 L p .707 .577 .707 r
F P
0 g
s
.57487 .31244 m .5799 .71757 L p .61313 .78294 L .707 .577 .707 r
F P
0 g
s
.57552 .81699 m .56945 .79891 L .59971 .78865 L p .707 .577 .707 r
F P
0 g
s
.5799 .71757 m .58111 .81496 L p .61313 .78294 L .707 .577 .707 r
F P
0 g
s
.54738 .8279 m .54132 .80983 L .56945 .79891 L p .707 .577 .707 r
F P
0 g
s
.56945 .79891 m .57552 .81699 L .54738 .8279 L p .707 .577 .707 r
F P
0 g
s
.5334 .31761 m .53963 .82012 L .58111 .81496 L p .707 .577 .707 r
F P
0 g
s
.58111 .81496 m .57487 .31244 L .5334 .31761 L p .707 .577 .707 r
F P
0 g
s
.45069 .81959 m .44445 .31708 L .40569 .31143 L p .707 .577 .707 r
F P
0 g
s
.44445 .31708 m .45069 .81959 L .49469 .82172 L p .707 .577 .707 r
F P
0 g
s
.71999 .77208 m .71132 .80709 L .70883 .7952 L p .707 .577 .707 r
F P
0 g
s
.70883 .7952 m .71749 .76018 L .71999 .77208 L p .707 .577 .707 r
F P
0 g
s
.61507 .80673 m .60883 .30421 L .57487 .31244 L p .707 .577 .707 r
F P
0 g
s
.50277 .85783 m .49671 .83975 L .49461 .83604 L p .707 .577 .707 r
F P
0 g
s
.49461 .83604 m .50068 .85412 L .50277 .85783 L p .707 .577 .707 r
F P
0 g
s
.68777 .77491 m .69384 .79299 L .69175 .78929 L p .707 .577 .707 r
F P
0 g
s
.69175 .78929 m .68568 .77121 L .68777 .77491 L p .707 .577 .707 r
F P
0 g
s
.70022 .67984 m .68718 .73235 L .67522 .71923 L p .707 .577 .707 r
F P
0 g
s
.67522 .71923 m .68826 .66672 L .70022 .67984 L p .707 .577 .707 r
F P
0 g
s
.41193 .81394 m .40569 .31143 L .37597 .30282 L p .707 .577 .707 r
F P
0 g
s
.40569 .31143 m .41193 .81394 L .45069 .81959 L p .707 .577 .707 r
F P
0 g
s
.23977 .71785 m .25281 .66534 L .22252 .65613 L p .707 .577 .707 r
F P
0 g
s
.25281 .66534 m .23977 .71785 L .27081 .72366 L p .707 .577 .707 r
F P
0 g
s
.27081 .72366 m .28385 .67115 L .25281 .66534 L p .707 .577 .707 r
F P
0 g
s
.20948 .70864 m .22252 .65613 L .19594 .64443 L p .707 .577 .707 r
F P
0 g
s
.22252 .65613 m .20948 .70864 L .23977 .71785 L p .707 .577 .707 r
F P
0 g
s
.28385 .67115 m .27081 .72366 L .29956 .72552 L p .707 .577 .707 r
F P
0 g
s
.29956 .72552 m .3126 .67301 L .28385 .67115 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.71749 .76018 m .70883 .7952 L .69686 .7821 L p .707 .577 .707 r
F P
0 g
s
.69686 .7821 m .70553 .74708 L .71749 .76018 L p .707 .577 .707 r
F P
0 g
s
.26141 .78085 m .27008 .74583 L .23978 .73664 L p .707 .577 .707 r
F P
0 g
s
.27008 .74583 m .26141 .78085 L .29245 .78665 L p .707 .577 .707 r
F P
0 g
s
.29245 .78665 m .30112 .75163 L .27008 .74583 L p .707 .577 .707 r
F P
0 g
s
.668 .65367 m .65496 .70618 L .62838 .69448 L p .707 .577 .707 r
F P
0 g
s
.62838 .69448 m .64142 .64197 L .668 .65367 L p .707 .577 .707 r
F P
0 g
s
.65868 .72237 m .65001 .75739 L .61972 .7482 L p .707 .577 .707 r
F P
0 g
s
.61972 .7482 m .62839 .71318 L .65868 .72237 L p .707 .577 .707 r
F P
0 g
s
.65485 .7739 m .66092 .79197 L .63521 .7981 L p .707 .577 .707 r
F P
0 g
s
.63521 .7981 m .62914 .78002 L .65485 .7739 L p .707 .577 .707 r
F P
0 g
s
.60883 .30421 m .61507 .80673 L .63818 .79624 L p .707 .577 .707 r
F P
0 g
s
.63818 .79624 m .63194 .29372 L .60883 .30421 L p .707 .577 .707 r
F P
0 g
s
.1829 .69694 m .19594 .64443 L .17568 .63138 L p .707 .577 .707 r
F P
0 g
s
.19594 .64443 m .1829 .69694 L .20948 .70864 L p .707 .577 .707 r
F P
0 g
s
.3126 .67301 m .29956 .72552 L .32321 .72323 L p .707 .577 .707 r
F P
0 g
s
.32321 .72323 m .33625 .67072 L .3126 .67301 L p .707 .577 .707 r
F P
0 g
s
.23111 .77166 m .23978 .73664 L .2132 .72496 L p .707 .577 .707 r
F P
0 g
s
.23978 .73664 m .23111 .77166 L .26141 .78085 L p .707 .577 .707 r
F P
0 g
s
.30112 .75163 m .29245 .78665 L .32121 .78849 L p .707 .577 .707 r
F P
0 g
s
.32121 .78849 m .32988 .75347 L .30112 .75163 L p .707 .577 .707 r
F P
0 g
s
.50068 .85412 m .49461 .83604 L .50197 .82935 L p .707 .577 .707 r
F P
0 g
s
.68826 .66672 m .67522 .71923 L .65496 .70618 L p .707 .577 .707 r
F P
0 g
s
.65496 .70618 m .668 .65367 L .68826 .66672 L p .707 .577 .707 r
F P
0 g
s
.50197 .82935 m .50804 .84742 L .50068 .85412 L p .707 .577 .707 r
F P
0 g
s
.68568 .77121 m .69175 .78929 L .6804 .78893 L p .707 .577 .707 r
F P
0 g
s
.6804 .78893 m .67434 .77086 L .68568 .77121 L p .707 .577 .707 r
F P
0 g
s
.3822 .80533 m .37597 .30282 L .35819 .29208 L p .707 .577 .707 r
F P
0 g
s
.37597 .30282 m .3822 .80533 L .41193 .81394 L p .707 .577 .707 r
F P
0 g
s
.2132 .72496 m .20453 .75998 L .23111 .77166 L p .707 .577 .707 r
F P
0 g
s
.20453 .75998 m .2132 .72496 L .19294 .71194 L p .707 .577 .707 r
F P
0 g
s
.32988 .75347 m .32121 .78849 L .34486 .78619 L p .707 .577 .707 r
F P
0 g
s
.34486 .78619 m .35353 .75117 L .32988 .75347 L p .707 .577 .707 r
F P
0 g
s
.70553 .74708 m .69686 .7821 L .6766 .76907 L p .707 .577 .707 r
F P
0 g
s
.6766 .76907 m .68526 .73405 L .70553 .74708 L p .707 .577 .707 r
F P
0 g
s
.17568 .63138 m .16264 .68389 L .1829 .69694 L p .707 .577 .707 r
F P
0 g
s
.24573 .80282 m .23967 .78475 L .21024 .79337 L p .707 .577 .707 r
F P
0 g
s
.23967 .78475 m .24573 .80282 L .276 .79256 L p .707 .577 .707 r
F P
0 g
s
.276 .79256 m .26993 .77448 L .23967 .78475 L p .707 .577 .707 r
F P
0 g
s
.16264 .68389 m .17568 .63138 L .16372 .61826 L p .707 .577 .707 r
F P
0 g
s
.26993 .77448 m .276 .79256 L .30413 .78164 L p .707 .577 .707 r
F P
0 g
s
.30413 .78164 m .29806 .76357 L .26993 .77448 L p .707 .577 .707 r
F P
0 g
s
.33625 .67072 m .32321 .72323 L .33944 .71702 L p .707 .577 .707 r
F P
0 g
s
.33944 .71702 m .35248 .66451 L .33625 .67072 L p .707 .577 .707 r
F P
0 g
s
.21024 .79337 m .21631 .81145 L .24573 .80282 L p .707 .577 .707 r
F P
0 g
s
.19294 .71194 m .18427 .74695 L .20453 .75998 L p .707 .577 .707 r
F P
0 g
s
.21631 .81145 m .21024 .79337 L .18452 .7995 L p .707 .577 .707 r
F P
0 g
s
.29806 .76357 m .30413 .78164 L .32738 .77116 L p .707 .577 .707 r
F P
0 g
s
.32738 .77116 m .32131 .75308 L .29806 .76357 L p .707 .577 .707 r
F P
0 g
s
.18452 .7995 m .19059 .81757 L .21631 .81145 L p .707 .577 .707 r
F P
0 g
s
.18427 .74695 m .19294 .71194 L .18097 .69883 L p .707 .577 .707 r
F P
0 g
s
.63194 .29372 m .63818 .79624 L .64818 .78452 L p .707 .577 .707 r
F P
0 g
s
.64818 .78452 m .64194 .282 L .63194 .29372 L p .707 .577 .707 r
F P
0 g
s
.67434 .77086 m .6804 .78893 L .66092 .79197 L p .707 .577 .707 r
F P
0 g
s
.66092 .79197 m .65485 .7739 L .67434 .77086 L p .707 .577 .707 r
F P
0 g
s
.35353 .75117 m .34486 .78619 L .36109 .77997 L p .707 .577 .707 r
F P
0 g
s
.36109 .77997 m .36976 .74496 L .35353 .75117 L p .707 .577 .707 r
F P
0 g
s
.68526 .73405 m .6766 .76907 L .65001 .75739 L p .707 .577 .707 r
F P
0 g
s
.65001 .75739 m .65868 .72237 L .68526 .73405 L p .707 .577 .707 r
F P
0 g
s
.16372 .61826 m .15068 .67077 L .16264 .68389 L p .707 .577 .707 r
F P
0 g
s
.15068 .67077 m .16372 .61826 L .16123 .60636 L p .707 .577 .707 r
F P
0 g
s
.19059 .81757 m .18452 .7995 L .16504 .80254 L p .707 .577 .707 r
F P
0 g
s
.35248 .66451 m .33944 .71702 L .34666 .7075 L p .707 .577 .707 r
F P
0 g
s
.34666 .7075 m .3597 .65499 L .35248 .66451 L p .707 .577 .707 r
F P
0 g
s
.18097 .69883 m .1723 .73385 L .18427 .74695 L p .707 .577 .707 r
F P
0 g
s
.16504 .80254 m .17111 .82061 L .19059 .81757 L p .707 .577 .707 r
F P
0 g
s
.32131 .75308 m .32738 .77116 L .34347 .76212 L p .707 .577 .707 r
F P
0 g
s
.34347 .76212 m .33741 .74405 L .32131 .75308 L p .707 .577 .707 r
F P
0 g
s
.36976 .74496 m .36109 .77997 L .36831 .77046 L p .707 .577 .707 r
F P
0 g
s
.36582 .75856 m .35385 .74546 L p .36672 .73179 L .707 .577 .707 r
F P
0 g
s
.37449 .72355 m .36779 .75059 L p .36672 .73179 L .707 .577 .707 r
F P
0 g
s
.36779 .75059 m .36582 .75856 L p .36672 .73179 L .707 .577 .707 r
F P
0 g
s
.35819 .29208 m .3541 .28028 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.35385 .74546 m .36252 .71044 L .36571 .71394 L p .707 .577 .707 r
F P
0 g
s
.36571 .71394 m .37449 .72355 L p .36672 .73179 L .707 .577 .707 r
F P
0 g
s
.35385 .74546 m .36571 .71394 L .36672 .73179 L .707 .577 .707 r
F
.35083 .75543 m .34477 .73735 L .33741 .74405 L p F P
0 g
s
.36252 .71044 m .35385 .74546 L .34774 .74153 L p .707 .577 .707 r
F P
0 g
s
.34477 .73735 m .35083 .75543 L .34874 .75172 L p .707 .577 .707 r
F P
0 g
s
.34874 .75172 m .34267 .73364 L .34477 .73735 L p .707 .577 .707 r
F P
0 g
s
.33741 .74405 m .34347 .76212 L .35083 .75543 L p .707 .577 .707 r
F P
0 g
s
.34267 .73364 m .34874 .75172 L .33739 .75137 L p .707 .577 .707 r
F P
0 g
s
.33739 .75137 m .33133 .73329 L .34267 .73364 L p .707 .577 .707 r
F P
0 g
s
.34774 .74153 m .33359 .73243 L p .34814 .72137 L .707 .577 .707 r
F P
0 g
s
.34814 .72137 m .36252 .71044 L .34774 .74153 L .707 .577 .707 r
F
.3597 .65499 m .34666 .7075 L .34417 .69559 L p F P
0 g
s
.33359 .73243 m .34226 .69742 L .36252 .71044 L p .707 .577 .707 r
F P
0 g
s
.36034 .78279 m .36443 .7946 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.3541 .28028 m .35774 .57351 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.34417 .69559 m .35721 .64308 L .3597 .65499 L p .707 .577 .707 r
F P
0 g
s
.35774 .57351 m .36034 .78279 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.36443 .7946 m .36279 .66242 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.36279 .66242 m .35819 .29208 L p .36122 .6348 L .707 .577 .707 r
F P
0 g
s
.36831 .77046 m .37698 .73544 L .36976 .74496 L p .707 .577 .707 r
F P
0 g
s
.37698 .73544 m .36831 .77046 L .36582 .75856 L p .707 .577 .707 r
F P
0 g
s
.36582 .75856 m .37449 .72355 L .37698 .73544 L p .707 .577 .707 r
F P
0 g
s
.35819 .29208 m .36443 .7946 L .3822 .80533 L p .707 .577 .707 r
F P
0 g
s
.36034 .78279 m .35515 .36439 L p .3641 .26856 L .707 .577 .707 r
F P
0 g
s
.35515 .36439 m .3541 .28028 L .35686 .27704 L p .707 .577 .707 r
F P
0 g
s
.35686 .27704 m .3641 .26856 L p .35515 .36439 L .707 .577 .707 r
F P
0 g
s
.1723 .73385 m .18097 .69883 L .17848 .68694 L p .707 .577 .707 r
F P
0 g
s
.16123 .60636 m .14819 .65887 L .15068 .67077 L p .707 .577 .707 r
F P
0 g
s
.17111 .82061 m .16504 .80254 L .1537 .80218 L p .707 .577 .707 r
F P
0 g
s
.1537 .80218 m .15977 .82026 L .17111 .82061 L p .707 .577 .707 r
F P
0 g
s
.17848 .68694 m .16981 .72196 L .1723 .73385 L p .707 .577 .707 r
F P
0 g
s
.14819 .65887 m .16123 .60636 L .16845 .59684 L p .707 .577 .707 r
F P
0 g
s
.64194 .282 m .64792 .76403 L p .64373 .69023 L .707 .577 .707 r
F P
0 g
s
.63785 .27019 m .64194 .282 L p .64336 .60648 L .707 .577 .707 r
F P
0 g
s
.64409 .77271 m .64197 .60161 L p .64336 .60648 L .707 .577 .707 r
F P
0 g
s
.64197 .60161 m .63785 .27019 L p .64336 .60648 L .707 .577 .707 r
F P
0 g
s
.63785 .27019 m .64409 .77271 L .62631 .76198 L p .707 .577 .707 r
F P
0 g
s
.64393 .56297 m .64144 .55107 L p .63637 .58207 L .707 .577 .707 r
F P
0 g
s
.63089 .61548 m .63788 .58735 L p .63637 .58207 L .707 .577 .707 r
F P
0 g
s
.63788 .58735 m .64393 .56297 L p .63637 .58207 L .707 .577 .707 r
F P
0 g
s
.64393 .56297 m .63788 .58735 L p .64286 .6286 L .707 .577 .707 r
F P
0 g
s
.63788 .58735 m .63089 .61548 L .64005 .62553 L p .707 .577 .707 r
F P
0 g
s
.64005 .62553 m .64286 .6286 L p .63788 .58735 L .707 .577 .707 r
F P
0 g
s
.64818 .78452 m .64409 .77271 L p .64373 .69023 L .707 .577 .707 r
F P
0 g
s
.64792 .76403 m .64818 .78452 L p .64373 .69023 L .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16981 .72196 m .17848 .68694 L .1857 .67742 L p .707 .577 .707 r
F P
0 g
s
.16845 .59684 m .15541 .64935 L .14819 .65887 L p .707 .577 .707 r
F P
0 g
s
.15977 .82026 m .1537 .80218 L .1516 .79848 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.1516 .79848 m .15767 .81656 L .15977 .82026 L p .707 .577 .707 r
F P
0 g
s
.1857 .67742 m .17703 .71244 L .16981 .72196 L p .707 .577 .707 r
F P
0 g
s
.15541 .64935 m .16845 .59684 L .18468 .59063 L p .707 .577 .707 r
F P
0 g
s
.35721 .64308 m .34417 .69559 L .33221 .68248 L p .707 .577 .707 r
F P
0 g
s
.33221 .68248 m .34525 .62997 L .35721 .64308 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.17703 .71244 m .1857 .67742 L .20193 .67121 L p .707 .577 .707 r
F P
0 g
s
.62631 .76198 m .62008 .25946 L .63785 .27019 L p .707 .577 .707 r
F P
0 g
s
.18468 .59063 m .17164 .64314 L .15541 .64935 L p .707 .577 .707 r
F P
0 g
s
.17164 .64314 m .18468 .59063 L .20833 .58834 L p .707 .577 .707 r
F P
0 g
s
.15767 .81656 m .1516 .79848 L .15896 .79178 L p .707 .577 .707 r
F P
0 g
s
.34525 .62997 m .33221 .68248 L .31195 .66943 L p .707 .577 .707 r
F P
0 g
s
.31195 .66943 m .32499 .61692 L .34525 .62997 L p .707 .577 .707 r
F P
0 g
s
.20193 .67121 m .19326 .70623 L .17703 .71244 L p .707 .577 .707 r
F P
0 g
s
.15896 .79178 m .16503 .80986 L .15767 .81656 L p .707 .577 .707 r
F P
0 g
s
.37034 .77107 m .3641 .26856 L .38721 .25807 L p .707 .577 .707 r
F P
0 g
s
.3641 .26856 m .37034 .77107 L .36034 .78279 L p .707 .577 .707 r
F P
0 g
s
.19326 .70623 m .20193 .67121 L .22558 .66891 L p .707 .577 .707 r
F P
0 g
s
.20833 .58834 m .19529 .64085 L .17164 .64314 L p .707 .577 .707 r
F P
0 g
s
.19529 .64085 m .20833 .58834 L .23708 .59019 L p .707 .577 .707 r
F P
0 g
s
.32499 .61692 m .31195 .66943 L .28537 .65773 L p .707 .577 .707 r
F P
0 g
s
.28537 .65773 m .29841 .60522 L .32499 .61692 L p .707 .577 .707 r
F P
0 g
s
.22558 .66891 m .21691 .70393 L .19326 .70623 L p .707 .577 .707 r
F P
0 g
s
.62008 .25946 m .62631 .76198 L .59659 .75337 L p .707 .577 .707 r
F P
0 g
s
.59659 .75337 m .59035 .25085 L .62008 .25946 L p .707 .577 .707 r
F P
0 g
s
.16503 .80986 m .15896 .79178 L .17505 .78275 L p .707 .577 .707 r
F P
0 g
s
.17505 .78275 m .18112 .80082 L .16503 .80986 L p .707 .577 .707 r
F P
0 g
s
.22404 .6427 m .23708 .59019 L .26812 .59601 L p .707 .577 .707 r
F P
0 g
s
.23708 .59019 m .22404 .6427 L .19529 .64085 L p .707 .577 .707 r
F P
0 g
s
.29841 .60522 m .28537 .65773 L .25508 .64852 L p .707 .577 .707 r
F P
0 g
s
.25508 .64852 m .26812 .59601 L .29841 .60522 L p .707 .577 .707 r
F P
0 g
s
.33133 .73329 m .33739 .75137 L .31791 .75441 L p .707 .577 .707 r
F P
0 g
s
.31791 .75441 m .31184 .73633 L .33133 .73329 L p .707 .577 .707 r
F P
0 g
s
.21691 .70393 m .22558 .66891 L .25433 .67075 L p .707 .577 .707 r
F P
0 g
s
.34226 .69742 m .33359 .73243 L .30701 .72075 L p .707 .577 .707 r
F P
0 g
s
.30701 .72075 m .31567 .68573 L .34226 .69742 L p .707 .577 .707 r
F P
0 g
s
.26812 .59601 m .25508 .64852 L .22404 .6427 L p .707 .577 .707 r
F P
0 g
s
.38721 .25807 m .39345 .76058 L .37034 .77107 L p .707 .577 .707 r
F P
0 g
s
.39345 .76058 m .38721 .25807 L .42117 .24984 L p .707 .577 .707 r
F P
0 g
s
.71998 .66256 m .73302 .61005 L .70273 .60084 L p .707 .577 .707 r
F P
0 g
s
.73302 .61005 m .71998 .66256 L .75102 .66838 L p .707 .577 .707 r
F P
0 g
s
.75102 .66838 m .76406 .61587 L .73302 .61005 L p .707 .577 .707 r
F P
0 g
s
.25433 .67075 m .24566 .70576 L .21691 .70393 L p .707 .577 .707 r
F P
0 g
s
.24566 .70576 m .25433 .67075 L .28538 .67655 L p .707 .577 .707 r
F P
0 g
s
.31567 .68573 m .30701 .72075 L .27671 .71156 L p .707 .577 .707 r
F P
0 g
s
.27671 .71156 m .28538 .67655 L .31567 .68573 L p .707 .577 .707 r
F P
0 g
s
.68969 .65335 m .70273 .60084 L .67616 .58914 L p .707 .577 .707 r
F P
0 g
s
.70273 .60084 m .68969 .65335 L .71998 .66256 L p .707 .577 .707 r
F P
0 g
s
.76406 .61587 m .75102 .66838 L .77977 .67023 L p .707 .577 .707 r
F P
0 g
s
.77977 .67023 m .79281 .61772 L .76406 .61587 L p .707 .577 .707 r
F P
0 g
s
.28538 .67655 m .27671 .71156 L .24566 .70576 L p .707 .577 .707 r
F P
0 g
s
.18112 .80082 m .17505 .78275 L .19831 .77226 L p .707 .577 .707 r
F P
0 g
s
.19831 .77226 m .20437 .79034 L .18112 .80082 L p .707 .577 .707 r
F P
0 g
s
.31184 .73633 m .31791 .75441 L .2922 .76054 L p .707 .577 .707 r
F P
0 g
s
.2922 .76054 m .28613 .74246 L .31184 .73633 L p .707 .577 .707 r
F P
0 g
s
.59035 .25085 m .59659 .75337 L .55783 .74772 L p .707 .577 .707 r
F P
0 g
s
.55783 .74772 m .55159 .2452 L .59035 .25085 L p .707 .577 .707 r
F P
0 g
s
.74162 .72545 m .75029 .69043 L .71999 .68124 L p .707 .577 .707 r
F P
0 g
s
.75029 .69043 m .74162 .72545 L .77267 .73125 L p .707 .577 .707 r
F P
0 g
s
.77267 .73125 m .78134 .69623 L .75029 .69043 L p .707 .577 .707 r
F P
0 g
s
.66312 .64165 m .67616 .58914 L .6559 .57609 L p .707 .577 .707 r
F P
0 g
s
.67616 .58914 m .66312 .64165 L .68969 .65335 L p .707 .577 .707 r
F P
0 g
s
.79281 .61772 m .77977 .67023 L .80342 .66794 L p .707 .577 .707 r
F P
0 g
s
.80342 .66794 m .81646 .61543 L .79281 .61772 L p .707 .577 .707 r
F P
0 g
s
.71133 .71626 m .71999 .68124 L .69341 .66956 L p .707 .577 .707 r
F P
0 g
s
.71999 .68124 m .71133 .71626 L .74162 .72545 L p .707 .577 .707 r
F P
0 g
s
.78134 .69623 m .77267 .73125 L .80142 .73309 L p .707 .577 .707 r
F P
0 g
s
.80142 .73309 m .81009 .69807 L .78134 .69623 L p .707 .577 .707 r
F P
0 g
s
.42741 .75235 m .42117 .24984 L .46265 .24467 L p .707 .577 .707 r
F P
0 g
s
.42117 .24984 m .42741 .75235 L .39345 .76058 L p .707 .577 .707 r
F P
0 g
s
.20437 .79034 m .19831 .77226 L .22644 .76135 L p .707 .577 .707 r
F P
0 g
s
.28613 .74246 m .2922 .76054 L .26277 .76916 L p .707 .577 .707 r
F P
0 g
s
.26277 .76916 m .2567 .75108 L .28613 .74246 L p .707 .577 .707 r
F P
0 g
s
.22644 .76135 m .23251 .77943 L .20437 .79034 L p .707 .577 .707 r
F P
0 g
s
.69341 .66956 m .68474 .70458 L .71133 .71626 L p .707 .577 .707 r
F P
0 g
s
.68474 .70458 m .69341 .66956 L .67315 .65653 L p .707 .577 .707 r
F P
0 g
s
.81009 .69807 m .80142 .73309 L .82507 .73079 L p .707 .577 .707 r
F P
0 g
s
.82507 .73079 m .83374 .69577 L .81009 .69807 L p .707 .577 .707 r
F P
0 g
s
.55159 .2452 m .55783 .74772 L .51383 .74559 L p .707 .577 .707 r
F P
0 g
s
.51383 .74559 m .50759 .24307 L .55159 .2452 L p .707 .577 .707 r
F P
0 g
s
.6559 .57609 m .64286 .6286 L .66312 .64165 L p .707 .577 .707 r
F P
0 g
s
.64286 .6286 m .6559 .57609 L .64393 .56297 L p .707 .577 .707 r
F P
0 g
s
.72595 .74835 m .71988 .73028 L .69045 .7389 L p .707 .577 .707 r
F P
0 g
s
.71988 .73028 m .72595 .74835 L .75621 .73808 L p .707 .577 .707 r
F P
0 g
s
.75621 .73808 m .75014 .72001 L .71988 .73028 L p .707 .577 .707 r
F P
0 g
s
.75014 .72001 m .75621 .73808 L .78434 .72717 L p .707 .577 .707 r
F P
0 g
s
.78434 .72717 m .77828 .70909 L .75014 .72001 L p .707 .577 .707 r
F P
0 g
s
.81646 .61543 m .80342 .66794 L .81965 .66173 L p .707 .577 .707 r
F P
0 g
s
.81965 .66173 m .83269 .60922 L .81646 .61543 L p .707 .577 .707 r
F P
0 g
s
.23251 .77943 m .22644 .76135 L .2567 .75108 L p .707 .577 .707 r
F P
0 g
s
.2567 .75108 m .26277 .76916 L .23251 .77943 L p .707 .577 .707 r
F P
0 g
s
.69045 .7389 m .69652 .75697 L .72595 .74835 L p .707 .577 .707 r
F P
0 g
s
.46889 .74719 m .46265 .24467 L .50759 .24307 L p .707 .577 .707 r
F P
0 g
s
.46265 .24467 m .46889 .74719 L .42741 .75235 L p .707 .577 .707 r
F P
0 g
s
.67315 .65653 m .66448 .69155 L .68474 .70458 L p .707 .577 .707 r
F P
0 g
s
.50759 .24307 m .51383 .74559 L .46889 .74719 L p .707 .577 .707 r
F P
0 g
s
.69652 .75697 m .69045 .7389 L .66474 .74503 L p .707 .577 .707 r
F P
0 g
s
.77828 .70909 m .78434 .72717 L .80759 .71669 L p .707 .577 .707 r
F P
0 g
s
.80759 .71669 m .80153 .69861 L .77828 .70909 L p .707 .577 .707 r
F P
0 g
s
.66474 .74503 m .6708 .7631 L .69652 .75697 L p .707 .577 .707 r
F P
0 g
s
.66448 .69155 m .67315 .65653 L .66118 .64343 L p .707 .577 .707 r
F P
0 g
s
.83374 .69577 m .82507 .73079 L .8413 .72457 L p .707 .577 .707 r
F P
0 g
s
.8413 .72457 m .84997 .68956 L .83374 .69577 L p .707 .577 .707 r
F P
0 g
s
.6708 .7631 m .66474 .74503 L .64525 .74806 L p .707 .577 .707 r
F P
0 g
s
.83269 .60922 m .81965 .66173 L .82687 .65221 L p .707 .577 .707 r
F P
0 g
s
.82687 .65221 m .83991 .5997 L .83269 .60922 L p .707 .577 .707 r
F P
0 g
s
.66118 .64343 m .65252 .67845 L .66448 .69155 L p .707 .577 .707 r
F P
0 g
s
.64525 .74806 m .65132 .76614 L .6708 .7631 L p .707 .577 .707 r
F P
0 g
s
.80153 .69861 m .80759 .71669 L .82369 .70765 L p .707 .577 .707 r
F P
0 g
s
.82369 .70765 m .81762 .68957 L .80153 .69861 L p .707 .577 .707 r
F P
0 g
s
.65252 .67845 m .66118 .64343 L .65869 .63154 L p .707 .577 .707 r
F P
0 g
s
.84997 .68956 m .8413 .72457 L .84852 .71505 L p .707 .577 .707 r
F P
0 g
s
.84852 .71505 m .85719 .68004 L .84997 .68956 L p .707 .577 .707 r
F P
0 g
s
.64144 .55107 m .6284 .60358 L .63089 .61548 L p .707 .577 .707 r
F P
0 g
s
.65132 .76614 m .64525 .74806 L .63391 .74771 L p .707 .577 .707 r
F P
0 g
s
.63391 .74771 m .63998 .76579 L .65132 .76614 L p .707 .577 .707 r
F P
0 g
s
.65869 .63154 m .65002 .66656 L .65252 .67845 L p .707 .577 .707 r
F P
0 g
s
.6284 .60358 m .64144 .55107 L .64867 .54155 L p .707 .577 .707 r
F P
0 g
s
.81762 .68957 m .82369 .70765 L .83105 .70095 L p .707 .577 .707 r
F P
0 g
s
.83105 .70095 m .82498 .68288 L .81762 .68957 L p .707 .577 .707 r
F P
0 g
s
.83991 .5997 m .82687 .65221 L .82438 .64031 L p .707 .577 .707 r
F P
0 g
s
.82438 .64031 m .83742 .5878 L .83991 .5997 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.65002 .66656 m .65869 .63154 L .66591 .62202 L p .707 .577 .707 r
F P
0 g
s
.85719 .68004 m .84852 .71505 L .84603 .70316 L p .707 .577 .707 r
F P
0 g
s
.84603 .70316 m .8547 .66815 L .85719 .68004 L p .707 .577 .707 r
F P
0 g
s
.64867 .54155 m .63563 .59406 L .6284 .60358 L p .707 .577 .707 r
F P
0 g
s
.63998 .76579 m .63391 .74771 L .63182 .74401 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.63182 .74401 m .63788 .76208 L .63998 .76579 L p .707 .577 .707 r
F P
0 g
s
.66591 .62202 m .65724 .65704 L .65002 .66656 L p .707 .577 .707 r
F P
0 g
s
.63563 .59406 m .64867 .54155 L .6649 .53534 L p .707 .577 .707 r
F P
0 g
s
.82498 .68288 m .83105 .70095 L .82895 .69725 L p .707 .577 .707 r
F P
0 g
s
.82895 .69725 m .82288 .67917 L .82498 .68288 L p .707 .577 .707 r
F P
0 g
s
.83742 .5878 m .82438 .64031 L .81242 .62719 L p .707 .577 .707 r
F P
0 g
s
.81242 .62719 m .82546 .57468 L .83742 .5878 L p .707 .577 .707 r
F P
0 g
s
.37697 .62581 m .39001 .5733 L .35972 .56409 L p .707 .577 .707 r
F P
0 g
s
.39001 .5733 m .37697 .62581 L .40801 .63163 L p .707 .577 .707 r
F P
0 g
s
.40801 .63163 m .42105 .57911 L .39001 .5733 L p .707 .577 .707 r
F P
0 g
s
.34668 .6166 m .35972 .56409 L .33315 .55239 L p .707 .577 .707 r
F P
0 g
s
.35972 .56409 m .34668 .6166 L .37697 .62581 L p .707 .577 .707 r
F P
0 g
s
.42105 .57911 m .40801 .63163 L .43676 .63348 L p .707 .577 .707 r
F P
0 g
s
.43676 .63348 m .4498 .58097 L .42105 .57911 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.65724 .65704 m .66591 .62202 L .68214 .61581 L p .707 .577 .707 r
F P
0 g
s
.8547 .66815 m .84603 .70316 L .83407 .69006 L p .707 .577 .707 r
F P
0 g
s
.83407 .69006 m .84273 .65504 L .8547 .66815 L p .707 .577 .707 r
F P
0 g
s
.6649 .53534 m .65186 .58785 L .63563 .59406 L p .707 .577 .707 r
F P
0 g
s
.39861 .68881 m .40728 .6538 L .37698 .64461 L p .707 .577 .707 r
F P
0 g
s
.40728 .6538 m .39861 .68881 L .42966 .69461 L p .707 .577 .707 r
F P
0 g
s
.42966 .69461 m .43833 .65959 L .40728 .6538 L p .707 .577 .707 r
F P
0 g
s
.32011 .6049 m .33315 .55239 L .31289 .53934 L p .707 .577 .707 r
F P
0 g
s
.33315 .55239 m .32011 .6049 L .34668 .6166 L p .707 .577 .707 r
F P
0 g
s
.4498 .58097 m .43676 .63348 L .46041 .63119 L p .707 .577 .707 r
F P
0 g
s
.46041 .63119 m .47345 .57868 L .4498 .58097 L p .707 .577 .707 r
F P
0 g
s
.65186 .58785 m .6649 .53534 L .68854 .53305 L p .707 .577 .707 r
F P
0 g
s
.36832 .67962 m .37698 .64461 L .3504 .63293 L p .707 .577 .707 r
F P
0 g
s
.37698 .64461 m .36832 .67962 L .39861 .68881 L p .707 .577 .707 r
F P
0 g
s
.43833 .65959 m .42966 .69461 L .45841 .69645 L p .707 .577 .707 r
F P
0 g
s
.45841 .69645 m .46708 .66143 L .43833 .65959 L p .707 .577 .707 r
F P
0 g
s
.63788 .76208 m .63182 .74401 L .63918 .73731 L p .707 .577 .707 r
F P
0 g
s
.82546 .57468 m .81242 .62719 L .79216 .61414 L p .707 .577 .707 r
F P
0 g
s
.79216 .61414 m .8052 .56163 L .82546 .57468 L p .707 .577 .707 r
F P
0 g
s
.68214 .61581 m .67347 .65082 L .65724 .65704 L p .707 .577 .707 r
F P
0 g
s
.63918 .73731 m .64524 .75538 L .63788 .76208 L p .707 .577 .707 r
F P
0 g
s
.82288 .67917 m .82895 .69725 L .81761 .6969 L p .707 .577 .707 r
F P
0 g
s
.81761 .6969 m .81154 .67882 L .82288 .67917 L p .707 .577 .707 r
F P
0 g
s
.3504 .63293 m .34173 .66794 L .36832 .67962 L p .707 .577 .707 r
F P
0 g
s
.34173 .66794 m .3504 .63293 L .33014 .6199 L p .707 .577 .707 r
F P
0 g
s
.46708 .66143 m .45841 .69645 L .48206 .69415 L p .707 .577 .707 r
F P
0 g
s
.48206 .69415 m .49073 .65913 L .46708 .66143 L p .707 .577 .707 r
F P
0 g
s
.67347 .65082 m .68214 .61581 L .70579 .61351 L p .707 .577 .707 r
F P
0 g
s
.84273 .65504 m .83407 .69006 L .8138 .67703 L p .707 .577 .707 r
F P
0 g
s
.8138 .67703 m .82247 .64201 L .84273 .65504 L p .707 .577 .707 r
F P
0 g
s
.31289 .53934 m .29984 .59185 L .32011 .6049 L p .707 .577 .707 r
F P
0 g
s
.38294 .71079 m .37687 .69271 L .34744 .70133 L p .707 .577 .707 r
F P
0 g
s
.37687 .69271 m .38294 .71079 L .4132 .70052 L p .707 .577 .707 r
F P
0 g
s
.4132 .70052 m .40713 .68244 L .37687 .69271 L p .707 .577 .707 r
F P
0 g
s
.29984 .59185 m .31289 .53934 L .30092 .52622 L p .707 .577 .707 r
F P
0 g
s
.68854 .53305 m .6755 .58556 L .65186 .58785 L p .707 .577 .707 r
F P
0 g
s
.40713 .68244 m .4132 .70052 L .44133 .68961 L p .707 .577 .707 r
F P
0 g
s
.44133 .68961 m .43527 .67153 L .40713 .68244 L p .707 .577 .707 r
F P
0 g
s
.47345 .57868 m .46041 .63119 L .47664 .62498 L p .707 .577 .707 r
F P
0 g
s
.47664 .62498 m .48968 .57247 L .47345 .57868 L p .707 .577 .707 r
F P
0 g
s
.6755 .58556 m .68854 .53305 L .71729 .5349 L p .707 .577 .707 r
F P
0 g
s
.34744 .70133 m .35351 .71941 L .38294 .71079 L p .707 .577 .707 r
F P
0 g
s
.8052 .56163 m .79216 .61414 L .76558 .60244 L p .707 .577 .707 r
F P
0 g
s
.76558 .60244 m .77863 .54993 L .8052 .56163 L p .707 .577 .707 r
F P
0 g
s
.33014 .6199 m .32147 .65491 L .34173 .66794 L p .707 .577 .707 r
F P
0 g
s
.35351 .71941 m .34744 .70133 L .32173 .70746 L p .707 .577 .707 r
F P
0 g
s
.70579 .61351 m .69712 .64852 L .67347 .65082 L p .707 .577 .707 r
F P
0 g
s
.43527 .67153 m .44133 .68961 L .46458 .67912 L p .707 .577 .707 r
F P
0 g
s
.46458 .67912 m .45852 .66104 L .43527 .67153 L p .707 .577 .707 r
F P
0 g
s
.32173 .70746 m .32779 .72554 L .35351 .71941 L p .707 .577 .707 r
F P
0 g
s
.64524 .75538 m .63918 .73731 L .65527 .72827 L p .707 .577 .707 r
F P
0 g
s
.65527 .72827 m .66134 .74635 L .64524 .75538 L p .707 .577 .707 r
F P
0 g
s
.32147 .65491 m .33014 .6199 L .31817 .60679 L p .707 .577 .707 r
F P
0 g
s
.70425 .58741 m .71729 .5349 L .74833 .54072 L p .707 .577 .707 r
F P
0 g
s
.71729 .5349 m .70425 .58741 L .6755 .58556 L p .707 .577 .707 r
F P
0 g
s
.77863 .54993 m .76558 .60244 L .73529 .59323 L p .707 .577 .707 r
F P
0 g
s
.73529 .59323 m .74833 .54072 L .77863 .54993 L p .707 .577 .707 r
F P
0 g
s
.81154 .67882 m .81761 .6969 L .79813 .69993 L p .707 .577 .707 r
F P
0 g
s
.79813 .69993 m .79206 .68186 L .81154 .67882 L p .707 .577 .707 r
F P
0 g
s
.49073 .65913 m .48206 .69415 L .49829 .68794 L p .707 .577 .707 r
F P
0 g
s
.49829 .68794 m .50696 .65292 L .49073 .65913 L p .707 .577 .707 r
F P
0 g
s
.69712 .64852 m .70579 .61351 L .73455 .61535 L p .707 .577 .707 r
F P
0 g
s
.82247 .64201 m .8138 .67703 L .78722 .66535 L p .707 .577 .707 r
F P
0 g
s
.78722 .66535 m .79589 .63033 L .82247 .64201 L p .707 .577 .707 r
F P
0 g
s
.30092 .52622 m .28788 .57873 L .29984 .59185 L p .707 .577 .707 r
F P
0 g
s
.74833 .54072 m .73529 .59323 L .70425 .58741 L p .707 .577 .707 r
F P
0 g
s
.28788 .57873 m .30092 .52622 L .29843 .51432 L p .707 .577 .707 r
F P
0 g
s
.32779 .72554 m .32173 .70746 L .30224 .7105 L p .707 .577 .707 r
F P
0 g
s
.48968 .57247 m .47664 .62498 L .48386 .61546 L p .707 .577 .707 r
F P
0 g
s
.48386 .61546 m .4969 .56295 L .48968 .57247 L p .707 .577 .707 r
F P
0 g
s
.31817 .60679 m .3095 .64181 L .32147 .65491 L p .707 .577 .707 r
F P
0 g
s
.30224 .7105 m .30831 .72857 L .32779 .72554 L p .707 .577 .707 r
F P
0 g
s
.73455 .61535 m .72588 .65036 L .69712 .64852 L p .707 .577 .707 r
F P
0 g
s
.45852 .66104 m .46458 .67912 L .48068 .67009 L p .707 .577 .707 r
F P
0 g
s
.48068 .67009 m .47461 .65201 L .45852 .66104 L p .707 .577 .707 r
F P
0 g
s
.72588 .65036 m .73455 .61535 L .76559 .62114 L p .707 .577 .707 r
F P
0 g
s
.79589 .63033 m .78722 .66535 L .75692 .65616 L p .707 .577 .707 r
F P
0 g
s
.75692 .65616 m .76559 .62114 L .79589 .63033 L p .707 .577 .707 r
F P
0 g
s
.76559 .62114 m .75692 .65616 L .72588 .65036 L p .707 .577 .707 r
F P
0 g
s
.66134 .74635 m .65527 .72827 L .67852 .71779 L p .707 .577 .707 r
F P
0 g
s
.67852 .71779 m .68459 .73586 L .66134 .74635 L p .707 .577 .707 r
F P
0 g
s
.79206 .68186 m .79813 .69993 L .77241 .70606 L p .707 .577 .707 r
F P
0 g
s
.77241 .70606 m .76634 .68799 L .79206 .68186 L p .707 .577 .707 r
F P
0 g
s
.3095 .64181 m .31817 .60679 L .31568 .5949 L p .707 .577 .707 r
F P
0 g
s
.50696 .65292 m .49829 .68794 L .50551 .67842 L p .707 .577 .707 r
F P
0 g
s
.50551 .67842 m .51418 .6434 L .50696 .65292 L p .707 .577 .707 r
F P
0 g
s
.29843 .51432 m .28539 .56683 L .28788 .57873 L p .707 .577 .707 r
F P
0 g
s
.30831 .72857 m .30224 .7105 L .2909 .71015 L p .707 .577 .707 r
F P
0 g
s
.2909 .71015 m .29697 .72822 L .30831 .72857 L p .707 .577 .707 r
F P
0 g
s
.31568 .5949 m .30701 .62992 L .3095 .64181 L p .707 .577 .707 r
F P
0 g
s
.28539 .56683 m .29843 .51432 L .30566 .5048 L p .707 .577 .707 r
F P
0 g
s
.47461 .65201 m .48068 .67009 L .48804 .66339 L p .707 .577 .707 r
F P
0 g
s
.48804 .66339 m .48197 .64531 L .47461 .65201 L p .707 .577 .707 r
F P
0 g
s
.68459 .73586 m .67852 .71779 L .70665 .70688 L p .707 .577 .707 r
F P
0 g
s
.4969 .56295 m .48386 .61546 L .48137 .60356 L p .707 .577 .707 r
F P
0 g
s
.48137 .60356 m .49441 .55104 L .4969 .56295 L p .707 .577 .707 r
F P
0 g
s
.76634 .68799 m .77241 .70606 L .74298 .71468 L p .707 .577 .707 r
F P
0 g
s
.74298 .71468 m .73692 .69661 L .76634 .68799 L p .707 .577 .707 r
F P
0 g
s
.70665 .70688 m .71272 .72495 L .68459 .73586 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.71272 .72495 m .70665 .70688 L .73692 .69661 L p .707 .577 .707 r
F P
0 g
s
.73692 .69661 m .74298 .71468 L .71272 .72495 L p .707 .577 .707 r
F P
0 g
s
.30701 .62992 m .31568 .5949 L .3229 .58538 L p .707 .577 .707 r
F P
0 g
s
.51418 .6434 m .50551 .67842 L .50302 .66652 L p .707 .577 .707 r
F P
0 g
s
.50302 .66652 m .51169 .63151 L .51418 .6434 L p .707 .577 .707 r
F P
0 g
s
.30566 .5048 m .29262 .55731 L .28539 .56683 L p .707 .577 .707 r
F P
0 g
s
.29697 .72822 m .2909 .71015 L .28881 .70644 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.28881 .70644 m .29487 .72452 L .29697 .72822 L p .707 .577 .707 r
F P
0 g
s
.3229 .58538 m .31423 .6204 L .30701 .62992 L p .707 .577 .707 r
F P
0 g
s
.29262 .55731 m .30566 .5048 L .32189 .49859 L p .707 .577 .707 r
F P
0 g
s
.48197 .64531 m .48804 .66339 L .48594 .65968 L p .707 .577 .707 r
F P
0 g
s
.48594 .65968 m .47987 .64161 L .48197 .64531 L p .707 .577 .707 r
F P
0 g
s
.49441 .55104 m .48137 .60356 L .46941 .59044 L p .707 .577 .707 r
F P
0 g
s
.46941 .59044 m .48245 .53793 L .49441 .55104 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.31423 .6204 m .3229 .58538 L .33913 .57917 L p .707 .577 .707 r
F P
0 g
s
.51169 .63151 m .50302 .66652 L .49106 .65342 L p .707 .577 .707 r
F P
0 g
s
.49106 .65342 m .49972 .61841 L .51169 .63151 L p .707 .577 .707 r
F P
0 g
s
.32189 .49859 m .30884 .5511 L .29262 .55731 L p .707 .577 .707 r
F P
0 g
s
.30884 .5511 m .32189 .49859 L .34553 .4963 L p .707 .577 .707 r
F P
0 g
s
.29487 .72452 m .28881 .70644 L .29616 .69974 L p .707 .577 .707 r
F P
0 g
s
.48245 .53793 m .46941 .59044 L .44915 .57739 L p .707 .577 .707 r
F P
0 g
s
.44915 .57739 m .46219 .52488 L .48245 .53793 L p .707 .577 .707 r
F P
0 g
s
.33913 .57917 m .33046 .61419 L .31423 .6204 L p .707 .577 .707 r
F P
0 g
s
.29616 .69974 m .30223 .71782 L .29487 .72452 L p .707 .577 .707 r
F P
0 g
s
.47987 .64161 m .48594 .65968 L .4746 .65933 L p .707 .577 .707 r
F P
0 g
s
.4746 .65933 m .46853 .64125 L .47987 .64161 L p .707 .577 .707 r
F P
0 g
s
.33046 .61419 m .33913 .57917 L .36278 .57687 L p .707 .577 .707 r
F P
0 g
s
.49972 .61841 m .49106 .65342 L .47079 .64039 L p .707 .577 .707 r
F P
0 g
s
.47079 .64039 m .47946 .60538 L .49972 .61841 L p .707 .577 .707 r
F P
0 g
s
.34553 .4963 m .33249 .54881 L .30884 .5511 L p .707 .577 .707 r
F P
0 g
s
.33249 .54881 m .34553 .4963 L .37428 .49815 L p .707 .577 .707 r
F P
0 g
s
.46219 .52488 m .44915 .57739 L .42257 .56569 L p .707 .577 .707 r
F P
0 g
s
.42257 .56569 m .43562 .51318 L .46219 .52488 L p .707 .577 .707 r
F P
0 g
s
.36278 .57687 m .35411 .61189 L .33046 .61419 L p .707 .577 .707 r
F P
0 g
s
.30223 .71782 m .29616 .69974 L .31226 .69071 L p .707 .577 .707 r
F P
0 g
s
.31226 .69071 m .31833 .70878 L .30223 .71782 L p .707 .577 .707 r
F P
0 g
s
.36124 .55066 m .37428 .49815 L .40532 .50397 L p .707 .577 .707 r
F P
0 g
s
.37428 .49815 m .36124 .55066 L .33249 .54881 L p .707 .577 .707 r
F P
0 g
s
.43562 .51318 m .42257 .56569 L .39228 .55648 L p .707 .577 .707 r
F P
0 g
s
.39228 .55648 m .40532 .50397 L .43562 .51318 L p .707 .577 .707 r
F P
0 g
s
.46853 .64125 m .4746 .65933 L .45512 .66237 L p .707 .577 .707 r
F P
0 g
s
.45512 .66237 m .44905 .64429 L .46853 .64125 L p .707 .577 .707 r
F P
0 g
s
.35411 .61189 m .36278 .57687 L .39154 .57871 L p .707 .577 .707 r
F P
0 g
s
.47946 .60538 m .47079 .64039 L .44421 .62871 L p .707 .577 .707 r
F P
0 g
s
.44421 .62871 m .45288 .5937 L .47946 .60538 L p .707 .577 .707 r
F P
0 g
s
.40532 .50397 m .39228 .55648 L .36124 .55066 L p .707 .577 .707 r
F P
0 g
s
.39154 .57871 m .38287 .61373 L .35411 .61189 L p .707 .577 .707 r
F P
0 g
s
.38287 .61373 m .39154 .57871 L .42258 .58451 L p .707 .577 .707 r
F P
0 g
s
.45288 .5937 m .44421 .62871 L .41391 .61952 L p .707 .577 .707 r
F P
0 g
s
.41391 .61952 m .42258 .58451 L .45288 .5937 L p .707 .577 .707 r
F P
0 g
s
.42258 .58451 m .41391 .61952 L .38287 .61373 L p .707 .577 .707 r
F P
0 g
s
.31833 .70878 m .31226 .69071 L .33551 .68022 L p .707 .577 .707 r
F P
0 g
s
.33551 .68022 m .34158 .6983 L .31833 .70878 L p .707 .577 .707 r
F P
0 g
s
.44905 .64429 m .45512 .66237 L .4294 .6685 L p .707 .577 .707 r
F P
0 g
s
.4294 .6685 m .42333 .65042 L .44905 .64429 L p .707 .577 .707 r
F P
0 g
s
.34158 .6983 m .33551 .68022 L .36364 .66931 L p .707 .577 .707 r
F P
0 g
s
.42333 .65042 m .4294 .6685 L .39997 .67712 L p .707 .577 .707 r
F P
0 g
s
.39997 .67712 m .39391 .65904 L .42333 .65042 L p .707 .577 .707 r
F P
0 g
s
.36364 .66931 m .36971 .68739 L .34158 .6983 L p .707 .577 .707 r
F P
0 g
s
.36971 .68739 m .36364 .66931 L .39391 .65904 L p .707 .577 .707 r
F P
0 g
s
.39391 .65904 m .39997 .67712 L .36971 .68739 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00LGoo1000
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool40006FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000eYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00P00J7oo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00Oomoo`1UOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP8006Ioo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH2001VOol006Aoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P00IWoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
07ooOol0I7oo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007oo
Ool0I7oo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0
I7oo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol0
1@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00
FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF0000
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001T
Ool01@00FUIJEUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJ
EUYF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001TOol01@00FUIJEUYF00001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001JOolC00000eYF001J
EP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH2001UOol005Qoo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00@000MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo0P000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01EYF10000eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001EOol20003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUH00003000;FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Eoo`8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<000QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00
E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF0`00
1UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001DOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Dgoo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol005=oo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP05001JEUYFFUH0000:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20008Ool7001FOol005=oo`80
00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF009JEP8000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8000Aoo`@000=JEP04001JEUYFFUH9001=Ool005=oo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP80009oo`<000IJEP03001JEUYF00EJEP03001JEUYF009JEPH004Moo`00DWoo00<005YF00000eYF
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF10000UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P00
A7oo001BOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEP001EYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH00eYF0`00@Goo001BOol20003FUHB0007FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF0`00?Woo001BOol2000015YF000000001UYF0P001Goo00<0
05YFFUH01@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP00
00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEP00000lOol0
059oo`03FUH00000009JEP03001JEUYF00AJEP04001JEP000003Ool01000FUIJEP0015YF1@001UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00P0015YF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000jOol0055oo`8000AJEP03001JEUYF
00AJEP04001JEUYFFUH40002FUH00`00FUIJEP04FUH70002FUH00`00FUIJEP05FUH00`00FUIJEP04
FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH015YF0P00>7oo001AOol20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH4
0005FUH50003FUH30007FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH3000fOol0055oo`8000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP04001JEP000004FUH50005FUH30005FUH00`00FUIJEP04FUH0
1`00FUIJEUYF001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001J
EUYFFUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP05FUH01000FUIJEP00=Goo001AOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH300000eYF000000030005FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH01@00
FUIJEUYF00001UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2000cOol0055oo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00EJEPH000EJEP03001JEUYF009JEP<000IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
15YF00<007ooOol0<7oo001AOol00`00FUIJEP02FUH00`00FUIJEP04FUH00`00FUH0000B00000eYF
000000060004FUH00`00FUIJEP04FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF008000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP80035oo`00DWoo00D0
05YFFUIJEP0000EJEP<00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00@00003FUH005YF
009JEPL000AJEP07001JEUYFFUH005YF000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0031oo`00Dgoo00<005YF0000
1EYF0P000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10001EYF00<005YFFUH0
0P0000=JEP00FUH00UYF00<005YF00001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YF00001EYF00@005YFFUIJEPL000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00=JEP05001JEUYFFUH0000_Ool003=ooa<000ioo`8000AJEP8000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<00003FUH005YF00=JEP80
00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP00
0002FUH60003FUH20002Ool80004FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`0/Ool0035oo`800003FUH005YF00EJEP03001JEUYF00EJEP03001J
EUYF00@000]oo`03001JEUYF009JEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00AJEP<000AJEP80009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEP0000<0009JEP03001JEUYF00AJEP04001JEP000008Ool60008
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002moo`80009J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00EJEP@000Qoo`800003FUH0000000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP<0009JEP80009JEP03
001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000003FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH2000;Ool40005FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00MJEP04001JEP000008Ool30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP020002FUH200000eYF001JEP05FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH30007Ool800000eYF
001JEP07FUH00`00FUIJEP03FUH00`00FUIJEP02FUH2000^Ool002ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEP<000Ioo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP800004FUH005YF
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH200000eYF001JEP02FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUH000020004Ool50003Ool30007FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2000^Ool002eoo`8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00EJEP<0009oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP800003FUH005YF00EJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP<00003Ool0000000<000Ioo`8000AJEP03001JEUYF00AJEP03001JEUYF
009JEP8002ioo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YF00000P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEPD000Uoo`<00003
FUH005YF00AJEP03001JEUYF009JEP8002moo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEQ8000MJEP03001JEUYF00IJ
EP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70004FUH00`00FUIJEP040009
Ool20005FUH00`00FUIJEP02FUH2000_Ool002aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0000000Aoo`@0
00IJEP04001JEUYFFUH40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUH000040003FUH01000FUIJEUYF2@000UYF300015YF00<005YFFUH00UYF0P00;goo000/
Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP03FUH20002FUH20006Ool40002FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH200000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJ
EP000UYF00<005YFFUH00eYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF1P00
1UYF00@005YF0000009JEP03001JEUYF009JEP8002moo`00;7oo0P000eYF00<005YFFUH015YF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00@005YFFUIJEP8000AJEP<000Eoo`03001J
EUYF00D000MJEP04001JEUYFFUH40002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUH00002
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P001EYF0P000eYF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P000UYF00<005YFFUH0
0UYF0P0015YF00<005YF0000;goo000/Ool20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH01000FUIJEUYF0P0015YF00<005YFFUH00P000goo00@005YFFUH0
00AJEPD00003FUH005YF00MJEP<000MJEP03001JEUYF00AJEP06001JEUYF001JEP002eYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00D005YFFUIJEP0000IJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEP<000EJEP03001JEUYF009JEP80031oo`00
;7oo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YFFUIJEP8000=JEP03001JEUYF009JEP80009oo`04001JEUYF0005FUH:0004FUH00`00FUIJEP02
0005FUH00`00FUIJEP04FUH01000FUIJEUYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH01UYF0`000eYF00@005YFFUIJEP80031oo`00:goo00<005YF00000eYF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF0P000eYF00<005YF
FUH015YF0`000UYF00<005YFFUH00eYF1@001EYF200000=JEP0000000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000=oo`00
FUH00P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00D0
05YF000005YF0080009JEP80031oo`00:goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00UYF00<005YFFUH0
15YF00H005YF000005YF0005FUH50006FUH00`00FUIJEP07FUH30006FUH01`00FUIJEUYF001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH20002Ool20004FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200001EYF0000
05YF0000<7oo000[Ool20003FUHB0007FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02
FUH00`00FUIJEP04FUH01000FUIJEUYF0`001EYF0`001eYF00<005YFFUH01eYF0`001UYF00L005YF
FUIJEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0P000Woo0P0015YF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF
0`0000=JEP00Ool0;goo000[Ool2000015YF000000001UYF0P002Goo10000UYF00<005YFFUH01eYF
00<005YFFUH00eYF00D005YFFUIJEP0000EJEP03001JEUYF00EJEP<0009JEP03001JEUYF00MJEP03
001JEUYF00L0009JEP<000AJEP07001JEUYFFUH005YF00002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00H005YFFUIJEP00FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH3000aOol002]oo`03FUH00000009JEP03001JEUYF00AJEP04
001JEP00000;Ool40008FUH00`00FUIJEP04FUH00`00FUH00006FUH00`00FUIJEP06FUH00`00FUH0
00030006FUH50003FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP02FUH01000FUH00000
2eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH00UYF00@005YF
FUIJEPh000IJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF000`Ool002Yoo`8000AJEP03
001JEUYF00AJEP04001JEUYFFUH3000:Ool50004FUH00`00FUIJEP05FUH30006FUH00`00FUIJEP05
FUH00`00FUIJEP04FUH600000eYF001JEP06FUH00`00FUIJEP03FUH00`00FUIJEP030003FUH01000
FUH000002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF2@001eYF00@0
05YFFUIJEP@0009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP8002ioo`00:Woo
0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF0`001Woo1@0000Ioo`00000005YF0007FUH00`00
FUH00006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01`00FUIJEUYF001JEP00009JEP04001JEP00000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH60002FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH40007FUH00`00FUIJ
EP05FUH00`00FUIJEP04FUH00`00Oomoo`0[Ool002Yoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP04001JEP000004Ool50004Ool30006FUH00`00FUIJEP020003FUH00`00FUIJEP06FUH01000
FUIJEUYF0`0025YF00<005YFFUH01EYF00<005YFFUH02@000UYF0P0000=JEP00FUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF0`001Woo0`0000=JEP00FUH025YF00<0
05YFFUH00P001EYF00<005YFFUH01EYF00<005YFFUH015YF0P00;7oo000ZOol20003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH300000goo000000030007Ool20004FUH00`00FUIJ
EP02FUH200000eYF001JEP06FUH00`00FUIJEP0200000eYF001JEP08FUH00`00FUIJEP04FUH40003
FUH00`00FUIJEP0200001eYF000005YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP@000=JEP05001JEUYFFUH00008Ool40007FUH00`00FUIJEP02FUH300000eYF001J
EP07FUH00`00FUIJEP04FUH2000/Ool002Yoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00EJEPH000Uoo`800003FUH005YF00EJEP<000MJEP<000AJEP03001JEUYF00MJ
EP03001JEP0000<000=JEP03001JEUYF009JEP800009FUH005YFFUH005YF001JEP0000]JEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF009JEP80
00Yoo`D00003FUH005YF00IJEP@000MJEP03001JEUYF00=JEP04001JEUYF000[Ool002Yoo`03001J
EUYF009JEP03001JEUYF00AJEP03001JEP0001800003FUH0000000H000=oo`8000IJEP03001JEUYF
0080009JEP<000MJEP03001JEUYF00EJEPD000IJEP03001JEUYF009JEP03001JEP0000=JEP05001J
EP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20005FUH00`00FUIJ
EP04FUH20009OolC0004FUH00`00FUIJEP04FUH01@00FUIJEUYF0000:Woo000[Ool01@00FUIJEUYF
00001EYF0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH0100000=JEP00FUH00UYF1`00
15YF00@005YFFUIJEP<00003FUH005YF00QJEP03001JEUYF00@00004FUH000000007FUH01@00FUIJ
EUYF00000UYF00@005YFFUIJEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP<000=JEP03001JEUYF00EJEP04001JEP000007Ool5000>Ool300000eYF001J
EP05FUH01@00FUIJEUYF0000:Woo000/Ool00`00FUH00005FUH20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH40005FUH01000FUIJEP000eYF00<005YF00000P0015YF00<005YF
FUH01EYF10000eYF0P000eYF00<005YFFUH01EYF0`000eYF00@005YFFUIJEP80009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03
001JEUYF009JEP8000Eoo`D0015oo`8000IJEP04001JEUYFFUH2000YOol002eoo`8000AJEP8000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEP000003FUH01000FUIJEUYF
1@001eYF00<005YFFUH00eYF10000eYF0P001EYF00<005YFFUH015YF0P001EYF00D005YFFUIJEP00
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH0
05YFFUH00006FUH00`00FUIJEP04FUH30003Ool3000<Ool:0004FUH01P00FUIJEP00FUH002Uoo`00
;Woo00<005YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00UYF0`0015YF0P0000=JEP00FUH025YF00<005YF00002@001eYF00<005YFFUH00UYF0`00
1UYF00<005YFFUH00P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00EJEP03001JEP00008000]oo`@00003FUH0
05YF00=JEP03001JEUYF0080009JEP07001JEUYFFUH005YF0000:Goo000_Ool200000eYF00000003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH40004FUH00`00
FUIJEP05FUH30003FUH60009FUH01000FUH000000UYF00<005YFFUH00eYF00D005YFFUIJEP0000AJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP8000IJ
EP03001JEUYF00IJEP03001JEUYF009JEP<000Aoo`@000EJEP03001JEUYF00=JEP03001JEUYF00@0
00=JEP03001JEP0002Uoo`00<Goo0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01EYF0P001UYF00<005YFFUH00eYF0P0000=JEP000000200000=JEP00FUH01UYF
0`000eYF00<005YFFUH015YF00@005YF000000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP80009JEP8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP@00003
FUH005YF00IJEP03001JEUYF00=JEP03001JEUYF00800003Ool005YF009JEP8002Yoo`00<Woo0P00
0eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF0`0025YF00<0
05YF00001P0000=JEP00FUH00UYF0`000UYF00<005YFFUH00eYF100015YF00@005YFFUIJEPD000MJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP80009JEP04001J
EP000004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH30004FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH00`00FUIJEP04000015YF001JEP00:Woo000aOol00`00FUH00003FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH70004FUH00`00
FUIJEP07FUH00`00FUH000020004FUH8000<FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH200000eYF001JEP03FUH01@00FUIJEUYF00001eYF00<005YFFUH00UYF
0`001eYF00<005YFFUH01EYF00@005YFFUIJEPL0009JEP800003FUH007oo02Uoo`00<Goo00<005YF
00000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJEP8000AJEP03
001JEUYF009JEP800004FUH000000007FUH00`00FUIJEP06FUH30002FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH30008FUH00`00FUH0000200000eYF001JEP08FUH01000FUIJEUYF1`000eYF00@0
05YFFUH000=JEP03001JEP0002Yoo`00<Goo0P000eYF4P001eYF00H005YFFUH005YF0005FUH00`00
FUH0000400000eYF001JEP08FUH00`00FUIJEP02FUH30005FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40005FUH01000
FUH000001UYF0`001EYF00<005YFFUH01EYF1`000eYF00<005YFFUH00eYF0P0015YF00<005YF0000
:Woo000aOol200000eYF00000004Ool30008FUH00`00FUIJEP040002FUH01`00FUIJEUYF001JEP00
00EJEP<000IJEP03001JEUYF00IJEP03001JEP00008000QJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEPD000AJEP04001J
EUYFFUH2000015YF0000000025YF00<005YFFUH00eYF0P000UYF0`001EYF00<005YFFUH00UYF0`00
15YF0P00:goo000aOol00eYF00000002FUH00`00Oomoo`04Ool30004FUH00`00FUIJEP05FUH50000
1EYF001JEUYF00000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`0000=JEP00FUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000=JEP00FUH00P000UYF00<005YFFUH00UYF0P0000=JEP00FUH02EYF00<005YF
00000P000UYF0P0000=JEP00FUH01UYF00@005YF0000009JEP03001JEUYF009JEP8002]oo`00<7oo
0P0015YF0`001goo0`0000=JEP00FUH01eYF00@005YFFUIJEP80009JEP<000AJEP03001JEUYF00EJ
EP03001JEUYF00@000AJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP<000AJEP80009JEP<000AJEP03
001JEUYF00IJEP<0009JEP<000=JEP03001JEUYF00AJEP<000AJEP03001JEUYF009JEP8002]oo`00
<7oo0P0015YF00@005YFFUH000Uoo`D000AJEP03001JEUYF00AJEP04001JEP000005FUH00`00FUIJ
EP04FUH40002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30005FUH30007FUH0
0`00FUIJEP03FUH80007FUH01000FUIJEUYF0`001UYF00@005YFFUIJEP8002aoo`00<7oo0P000eYF
00<005YFFUH00UYF0P0037oo2@000UYF0P0000=JEP00FUH01EYF00<005YF00000`000eYF00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800005FUH00000001JEP030009FUH00`00FUH0
00090008FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00;7oo000`Ool20003
FUH00`00FUIJEP04FUH20009Ool50005Ool40002FUH01000FUIJEUYF1@001UYF00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP80009JEP<000=JEP03001JEUYF00EJEP<0009oo`P000MJ
EP<000AJEP03001JEUYF00=JEP03001JEUYF00<002eoo`00<7oo00<005YFFUH00UYF00<005YFFUH0
15YF00@005YF000000Moo`D000Qoo`L00004Ool000000006FUH20002FUH00`00FUIJEP03FUH00`00
FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP03FUH40005FUH00`00FUIJEP03FUH20002Ool30003FUH30002FUH00`00
FUIJEP02FUH40004FUH01000FUIJEUYF1P00<7oo000`Ool00`00FUIJEP02FUH00`00FUIJEP04FUH0
1000FUIJEUYF0`0017oo1@0047oo0`001UYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0P0000=JEP00FUH01UYF00<005YF00000P000Woo0P0000=JEP00FUH025YF00<005YF
00000P0017oo2000=Woo000aOol01@00FUIJEUYF00001EYF00<005YFFUH01EYF0`000Woo0`0037oo
1@000UYF0`0015YF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<0
05YFFUH015YF100000Aoo`00000000AJEP03001JEUYF00EJEP<004Eoo`00<Woo00<005YF00001UYF
00<005YFFUH01UYF00@005YF000000]oo`@00003FUH005YF00AJEP03001JEUYF00800004FUH005YF
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUH000001EYF00@005YFFUIJEPL000MJEP03
001JEUYF00=JEP8004Qoo`00<goo0P001UYF00<005YFFUH01EYF00<005YFFUH00UYF0`0017oo1000
1UYF00<005YFFUH00eYF00<005YFFUH00`0000EJEP00FUIJEP0000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP80009J
EP03001JEUYF009JEP03001JEP0000<000=JEP03001JEUYF00MJEP03001JEP00008004Yoo`00=7oo
00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF10000UYF00<005YFFUH01EYF00<005YF
FUH00eYF00H005YFFUIJEP00Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP04
FUHQ0008FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP06FUH3001=
Ool003Eoo`8000AJEP03001JEUYF00EJEP04001JEUYFFUH40007FUH00`00FUIJEP05FUH00`00FUIJ
EP0:0002FUH00`00FUIJEP03FUH00`00FUIJEP06FUH9000;FUH00`00FUIJEP0:FUH00`00FUIJEP05
FUH60002FUH00`00FUIJEP06FUH00`00FUH00002FUH01000FUH000000UYF00<005YFFUH01EYF00<0
05YFFUH00UYF0`00D7oo000gOol01000FUIJEP001eYF00<005YFFUH00P0000=JEP00FUH025YF00<0
05YFFUH015YF10000eYF00<005YFFUH00P0000EJEP00FUIJEP0000EJEP03001JEUYF00=JEP<000QJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000@000IJEP03001JEP00
009JEP8000AJEP03001JEUYF00EJEP03001JEP00008005=oo`00>7oo0`001eYF0`0015YF00<005YF
FUH01eYF00<005YF0000100000=JEP00FUH015YF0P0000AJEP00FUH0009JEP03001JEUYF00=JEP03
001JEP0000@000YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJ
EP@0009JEP07001JEUYFFUH005YF00001EYF00@005YFFUIJEPH0009JEP03001oogoo051oo`00>Woo
0P000eYF0`001eYF00<005YFFUH01EYF100000=JEP00000015YF00<005YFFUH00UYF00<005YF0000
0UYF00@005YFFUH000EJEP8000AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEP000080009JEP05001JEUYFFUH00002FUH60005FUH0
1@00FUIJEUYF0000DGoo000lOol300000eYF001JEP08FUH00`00FUIJEP040002FUH30006FUH01@00
FUIJEUYF00000UYF00@005YFFUH0009JEP04001JEUYFFUH20006FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02FUH<00000eYF
001JEP05FUH01@00FUIJEUYF0000DGoo000jOol30004FUH00`00FUIJEP05FUH40004FUH200000eYF
001JEP07FUH30003FUH01000FUIJEP000UYF00@005YF000000QJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP800003FUH0
07oo00Eoo`8000IJEP04001JEUYFFUH2001@Ool003Moo`<000MJEP03001JEUYF00=JEPD0009JEP<0
00AJEP03001JEUYF00AJEP8000EJEP04001JEUYF0002FUH200000eYF001JEP07FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH01000FUH0000017oo1P0015YF00H005YFFUH005YF001@Ool003Eoo`800003FUH005YF00QJEP03
001JEP0000T000MJEP03001JEUYF009JEP<000IJEP06001JEUYF001JEP000eYF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF00001@000UYF00<005YFFUH00P000UYF00L005YFFUIJEP00FUH0001@
Ool003=oo`8000AJEP03001JEUYF00EJEP<0009oo`L000UJEP04001JEP000002FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YF000005YF0005FUH0
0`00FUIJEP040003FUH00`00FUH0001@Ool0035oo`8000IJEP03001JEUYF00=JEP8000Eoo`H00003
FUH005YF00IJEP<000=JEP03001JEUYF00AJEP03001JEP0000<000AJEP03001JEUYF00IJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP06001JEUYF001JEP001EYF00<005YFFUH00P0000=oo`00FUH00UYF0P00DGoo000`Ool2
0008FUH00`00FUH000020003Ool40002FUH30002FUH00`00FUIJEP03FUH40004FUH01000FUIJEUYF
1@000Woo0P0015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=J
EP04001JEUYF0002Ool00`00FUIJEP02001AOol002ioo`80009JEP03001JEUYF00AJEP<0009oo`@0
009JEP03001JEUYF00MJEP03001JEP00008000Aoo`P000Qoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEP0000=JEP04001JEUYFFUH9000015YF001JEP00DGoo000]Ool00`00
FUIJEP02FUH00`00FUIJEP02FUH200000goo000000020006FUH00`00FUIJEP06FUH3000GOol00`00
FUIJEP02FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF000000050003FUH01000FUIJEP00
0UYF0P0000=JEP00Ool0D7oo000/Ool20005FUH00`00FUH0000400000eYF001JEP08FUH00`00FUIJ
EP02FUH3000KOol20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH60003FUH00`00FUIJEP03FUH3
0003FUH00`00FUH0001AOol002]oo`03001JEP0000EJEP<000IJEP03001JEUYF00IJEP03001JEP00
0080021oo`<000QJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00IJEP04001JEUYFFUH2000015YF000000001EYF00<005YFFUH00UYF0`0015YF0P00
DWoo000[Ool01000FUIJEP000UYF0P0000=JEP00FUH01UYF00<005YFFUH01EYF0`009Goo0P001eYF
00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF
00D005YF000005YF00800003FUH005YF00IJEP04001JEP000002FUH00`00FUIJEP02FUH2001BOol0
02]oo`03001JEUYF00<000AJEP03001JEUYF00EJEP03001JEUYF00@002Yoo`<000AJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEPL000=JEP03
001JEUYF00AJEP<000AJEP03001JEUYF009JEP80059oo`00;7oo00@005YF000000EJEP03001JEUYF
00AJEP@0035oo`<00003FUH005YF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00P000MJEP04001JEUYFFUH30006FUH01000FUIJEUYF0P00Dgoo000/Ool200000eYF
001JEP05FUH00`00FUH00003000hOol40008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP07FUH<0008FUH01000FUH000000UYF00<005YFFUH00eYF00<005YFFUH00UYF0P00Dgoo000/Ool2
0002FUH01000FUIJEUYF1000@7oo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJ
EPP0009oo`P000QJEP8000AJEP03001JEUYF00=JEP03001JEUYF00<005Aoo`00;Goo1`00BWoo7`00
0eYF0P000Woo0`000UYF1P001UYF0P001EYF00@005YFFUIJEPH005Moo`00T7oo0P0000=JEP00FUH0
1UYF00<005YF00000P000Woo0P0000=JEP00FUH00eYF0`000UYF00@005YFFUIJEPd005eoo`00SWoo
0P000eYF00<005YFFUH015YF0`000Woo0`0015YF00<005YFFUH01UYF00@005YF000006Yoo`00SGoo
0P001EYF00@005YFFUIJEP80009oo`<000MJEP03001JEUYF00EJEP<006aoo`00S7oo00@005YFFUH0
00AJEP03001JEP0000D00003FUH005YF00QJEP03001JEUYF00@006moo`00S7oo00@005YFFUH000AJ
EP@000EJEP03001JEUYF00IJEP@007=oo`00SGoo00D005YFFUH005YF00800003FUH005YF00MJEP03
001JEUYF009JEP<007Moo`00SGoo00<005YFFUH00P0015YF00<005YFFUH01EYF00<005YF00000P00
NWoo002>Ool015YF001JEP0015YF00<005YFFUH015YF0`00OGoo002>Ool01000FUIJEP001EYF00<0
05YF00000`00P7oo002>Ool20002FUH00`00FUIJEP040024Ool0091oo`D008Qoo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]65\[InvisibleSpace]"     "\
\[InvisibleSpace]15.278382473820768`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 65, "     ", 15.278382473820768, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63924 .75057 m .62578 .6983 L .5948 .7062 L p .707 .577 .707 r
F P
0 g
s
.62578 .6983 m .63924 .75057 L .6679 .73966 L p .707 .577 .707 r
F P
0 g
s
.6679 .73966 m .65443 .68739 L .62578 .6983 L p .707 .577 .707 r
F P
0 g
s
.60827 .75847 m .5948 .7062 L .56454 .71032 L p .707 .577 .707 r
F P
0 g
s
.5948 .7062 m .60827 .75847 L .63924 .75057 L p .707 .577 .707 r
F P
0 g
s
.65443 .68739 m .6679 .73966 L .69142 .7268 L p .707 .577 .707 r
F P
0 g
s
.69142 .7268 m .67796 .67454 L .65443 .68739 L p .707 .577 .707 r
F P
0 g
s
.57801 .76259 m .56454 .71032 L .53795 .71025 L p .707 .577 .707 r
F P
0 g
s
.56454 .71032 m .57801 .76259 L .60827 .75847 L p .707 .577 .707 r
F P
0 g
s
.58665 .82077 m .57843 .78566 L .548 .78933 L p .707 .577 .707 r
F P
0 g
s
.57843 .78566 m .58665 .82077 L .61776 .81341 L p .707 .577 .707 r
F P
0 g
s
.61776 .81341 m .60953 .7783 L .57843 .78566 L p .707 .577 .707 r
F P
0 g
s
.60953 .7783 m .61776 .81341 L .6465 .80308 L p .707 .577 .707 r
F P
0 g
s
.6465 .80308 m .63827 .76797 L .60953 .7783 L p .707 .577 .707 r
F P
0 g
s
.55622 .82444 m .548 .78933 L .52122 .78895 L p .707 .577 .707 r
F P
0 g
s
.548 .78933 m .55622 .82444 L .58665 .82077 L p .707 .577 .707 r
F P
0 g
s
.63827 .76797 m .6465 .80308 L .67006 .7908 L p .707 .577 .707 r
F P
0 g
s
.67006 .7908 m .66183 .75568 L .63827 .76797 L p .707 .577 .707 r
F P
0 g
s
.67796 .67454 m .69142 .7268 L .70752 .71326 L p .707 .577 .707 r
F P
0 g
s
.70752 .71326 m .69406 .661 L .67796 .67454 L p .707 .577 .707 r
F P
0 g
s
.55141 .76251 m .53795 .71025 L .51763 .70599 L p .707 .577 .707 r
F P
0 g
s
.53795 .71025 m .55141 .76251 L .57801 .76259 L p .707 .577 .707 r
F P
0 g
s
.60146 .83464 m .60747 .81654 L .5779 .80592 L p .707 .577 .707 r
F P
0 g
s
.60747 .81654 m .60146 .83464 L .63172 .84414 L p .707 .577 .707 r
F P
0 g
s
.63172 .84414 m .63773 .82604 L .60747 .81654 L p .707 .577 .707 r
F P
0 g
s
.52122 .78895 m .52945 .82406 L .55622 .82444 L p .707 .577 .707 r
F P
0 g
s
.5779 .80592 m .57189 .82402 L .60146 .83464 L p .707 .577 .707 r
F P
0 g
s
.63773 .82604 m .63172 .84414 L .6597 .85158 L p .707 .577 .707 r
F P
0 g
s
.6597 .85158 m .66571 .83347 L .63773 .82604 L p .707 .577 .707 r
F P
0 g
s
.52945 .82406 m .52122 .78895 L .50072 .78456 L p .707 .577 .707 r
F P
0 g
s
.66183 .75568 m .67006 .7908 L .68613 .77776 L p .707 .577 .707 r
F P
0 g
s
.68613 .77776 m .67791 .74264 L .66183 .75568 L p .707 .577 .707 r
F P
0 g
s
.57189 .82402 m .5779 .80592 L .5519 .79522 L p .707 .577 .707 r
F P
0 g
s
.5519 .79522 m .54589 .81332 L .57189 .82402 L p .707 .577 .707 r
F P
0 g
s
.51763 .70599 m .5311 .75826 L .55141 .76251 L p .707 .577 .707 r
F P
0 g
s
.69406 .661 m .70752 .71326 L .71461 .70036 L p .707 .577 .707 r
F P
0 g
s
.71461 .70036 m .70115 .6481 L .69406 .661 L p .707 .577 .707 r
F P
0 g
s
.5311 .75826 m .51763 .70599 L .50558 .69798 L p .707 .577 .707 r
F P
0 g
s
.66571 .83347 m .6597 .85158 L .68265 .85623 L p .707 .577 .707 r
F P
0 g
s
.68265 .85623 m .68866 .83813 L .66571 .83347 L p .707 .577 .707 r
F P
0 g
s
.50072 .78456 m .50895 .81967 L .52945 .82406 L p .707 .577 .707 r
F P
0 g
s
.54589 .81332 m .5519 .79522 L .53203 .78547 L p .707 .577 .707 r
F P
0 g
s
.53203 .78547 m .52602 .80357 L .54589 .81332 L p .707 .577 .707 r
F P
0 g
s
.50895 .81967 m .50072 .78456 L .48851 .77658 L p .707 .577 .707 r
F P
0 g
s
.67791 .74264 m .68613 .77776 L .69314 .76523 L p .707 .577 .707 r
F P
0 g
s
.69314 .76523 m .68492 .73012 L .67791 .74264 L p .707 .577 .707 r
F P
0 g
s
.50558 .69798 m .51905 .75024 L .5311 .75826 L p .707 .577 .707 r
F P
0 g
s
.68866 .83813 m .68265 .85623 L .69835 .85765 L p .707 .577 .707 r
F P
0 g
s
.69835 .85765 m .70436 .83955 L .68866 .83813 L p .707 .577 .707 r
F P
0 g
s
.48851 .77658 m .49673 .8117 L .50895 .81967 L p .707 .577 .707 r
F P
0 g
s
.70115 .6481 m .71461 .70036 L .71201 .68937 L p .706 .577 .707 r
F P
0 g
s
.71201 .68937 m .69854 .6371 L .70115 .6481 L p .706 .577 .707 r
F P
0 g
s
.51905 .75024 m .50558 .69798 L .50297 .68698 L p .706 .577 .707 r
F P
0 g
s
.52602 .80357 m .53203 .78547 L .52022 .77764 L p .707 .577 .707 r
F P
0 g
s
.52022 .77764 m .51421 .79574 L .52602 .80357 L p .707 .577 .707 r
F P
0 g
s
.49673 .8117 m .48851 .77658 L .48577 .76581 L p .708 .578 .707 r
F P
0 g
s
.68492 .73012 m .69314 .76523 L .69041 .75446 L p .708 .578 .707 r
F P
0 g
s
.69041 .75446 m .68218 .71934 L .68492 .73012 L p .708 .578 .707 r
F P
0 g
s
.48577 .76581 m .494 .80092 L .49673 .8117 L p .708 .578 .707 r
F P
0 g
s
.494 .80092 m .48577 .76581 L .49279 .75329 L p .707 .577 .707 r
F P
0 g
s
.48737 .82177 m .48737 .31989 L .44358 .31695 L p .707 .577 .707 r
F P
0 g
s
.50297 .68698 m .51644 .73925 L .51905 .75024 L p .706 .577 .707 r
F P
0 g
s
.51421 .79574 m .52022 .77764 L .51764 .7725 L p .707 .577 .707 r
F P
0 g
s
.51644 .73925 m .50297 .68698 L .51007 .67408 L p .707 .577 .707 r
F P
0 g
s
.51764 .7725 m .51163 .7906 L .51421 .79574 L p .707 .577 .707 r
F P
0 g
s
.51007 .67408 m .52353 .72635 L .51644 .73925 L p .707 .577 .707 r
F P
0 g
s
.49279 .75329 m .50101 .7884 L .494 .80092 L p .707 .577 .707 r
F P
0 g
s
.52353 .72635 m .51007 .67408 L .52616 .66054 L p .707 .577 .707 r
F P
0 g
s
.51163 .7906 m .51764 .7725 L .52453 .77054 L p .707 .577 .707 r
F P
0 g
s
.52453 .77054 m .51852 .78864 L .51163 .7906 L p .707 .577 .707 r
F P
0 g
s
.50101 .7884 m .49279 .75329 L .50886 .74024 L p .707 .577 .707 r
F P
0 g
s
.52616 .66054 m .53963 .71281 L .52353 .72635 L p .707 .577 .707 r
F P
0 g
s
.50886 .74024 m .51708 .77536 L .50101 .7884 L p .707 .577 .707 r
F P
0 g
s
.51852 .78864 m .52453 .77054 L .54022 .77195 L p .707 .577 .707 r
F P
0 g
s
.54022 .77195 m .53421 .79005 L .51852 .78864 L p .707 .577 .707 r
F P
0 g
s
.51708 .77536 m .50886 .74024 L .53242 .72796 L p .707 .577 .707 r
F P
0 g
s
.53242 .72796 m .54064 .76307 L .51708 .77536 L p .707 .577 .707 r
F P
0 g
s
.48737 .31989 m .48737 .82177 L .53239 .82093 L p .707 .577 .707 r
F P
0 g
s
.53963 .71281 m .52616 .66054 L .54969 .64769 L p .707 .577 .707 r
F P
0 g
s
.53239 .82093 m .53239 .31905 L .48737 .31989 L p .707 .577 .707 r
F P
0 g
s
.56315 .69995 m .54969 .64769 L .57834 .63677 L p .707 .577 .707 r
F P
0 g
s
.54969 .64769 m .56315 .69995 L .53963 .71281 L p .707 .577 .707 r
F P
0 g
s
.57834 .63677 m .59181 .68904 L .56315 .69995 L p .707 .577 .707 r
F P
0 g
s
.54064 .76307 m .53242 .72796 L .56116 .71763 L p .707 .577 .707 r
F P
0 g
s
.53421 .79005 m .54022 .77195 L .56318 .77661 L p .707 .577 .707 r
F P
0 g
s
.56318 .77661 m .55717 .79471 L .53421 .79005 L p .707 .577 .707 r
F P
0 g
s
.56938 .75274 m .56116 .71763 L .59226 .71027 L p .707 .577 .707 r
F P
0 g
s
.56116 .71763 m .56938 .75274 L .54064 .76307 L p .707 .577 .707 r
F P
0 g
s
.55717 .79471 m .56318 .77661 L .59115 .78405 L p .707 .577 .707 r
F P
0 g
s
.59115 .78405 m .58514 .80215 L .55717 .79471 L p .707 .577 .707 r
F P
0 g
s
.53239 .31905 m .53239 .82093 L .57424 .8164 L p .707 .577 .707 r
F P
0 g
s
.59226 .71027 m .60049 .74539 L .56938 .75274 L p .707 .577 .707 r
F P
0 g
s
.57424 .8164 m .57424 .31451 L .53239 .31905 L p .707 .577 .707 r
F P
0 g
s
.70436 .83955 m .69835 .85765 L .70524 .85569 L p .707 .577 .707 r
F P
0 g
s
.70524 .85569 m .71125 .83759 L .70436 .83955 L p .707 .577 .707 r
F P
0 g
s
.44358 .81884 m .44358 .31695 L .40532 .31053 L p .707 .577 .707 r
F P
0 g
s
.44358 .31695 m .44358 .81884 L .48737 .82177 L p .707 .577 .707 r
F P
0 g
s
.69854 .6371 m .71201 .68937 L .69995 .68135 L p .707 .577 .707 r
F P
0 g
s
.69995 .68135 m .68649 .62908 L .69854 .6371 L p .707 .577 .707 r
F P
0 g
s
.60932 .62887 m .62278 .68114 L .59181 .68904 L p .707 .577 .707 r
F P
0 g
s
.59181 .68904 m .57834 .63677 L .60932 .62887 L p .707 .577 .707 r
F P
0 g
s
.6227 .7066 m .63092 .74172 L .60049 .74539 L p .707 .577 .707 r
F P
0 g
s
.60049 .74539 m .59226 .71027 L .6227 .7066 L p .707 .577 .707 r
F P
0 g
s
.58514 .80215 m .59115 .78405 L .62141 .79354 L p .707 .577 .707 r
F P
0 g
s
.62141 .79354 m .6154 .81164 L .58514 .80215 L p .707 .577 .707 r
F P
0 g
s
.57424 .31451 m .57424 .8164 L .60882 .80862 L p .707 .577 .707 r
F P
0 g
s
.60882 .80862 m .60882 .30673 L .57424 .31451 L p .707 .577 .707 r
F P
0 g
s
.68218 .71934 m .69041 .75446 L .67819 .74649 L p .707 .577 .707 r
F P
0 g
s
.67819 .74649 m .66997 .71137 L .68218 .71934 L p .707 .577 .707 r
F P
0 g
s
.25885 .69214 m .253 .63477 L .22197 .63768 L p .707 .577 .707 r
F P
0 g
s
.253 .63477 m .25885 .69214 L .29052 .6888 L p .707 .577 .707 r
F P
0 g
s
.29052 .6888 m .28466 .63144 L .253 .63477 L p .707 .577 .707 r
F P
0 g
s
.22197 .63768 m .22783 .69505 L .25885 .69214 L p .707 .577 .707 r
F P
0 g
s
.28466 .63144 m .29052 .6888 L .31972 .68536 L p .707 .577 .707 r
F P
0 g
s
.31972 .68536 m .31386 .628 L .28466 .63144 L p .707 .577 .707 r
F P
0 g
s
.40532 .81242 m .40532 .31053 L .37633 .30125 L p .707 .577 .707 r
F P
0 g
s
.40532 .31053 m .40532 .81242 L .44358 .81884 L p .707 .577 .707 r
F P
0 g
s
.22783 .69505 m .22197 .63768 L .19461 .63989 L p .707 .577 .707 r
F P
0 g
s
.19461 .63989 m .20047 .69725 L .22783 .69505 L p .707 .577 .707 r
F P
0 g
s
.71125 .83759 m .70524 .85569 L .70265 .85054 L p .707 .577 .707 r
F P
0 g
s
.70265 .85054 m .70866 .83244 L .71125 .83759 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68649 .62908 m .69995 .68135 L .67964 .6771 L p .707 .577 .707 r
F P
0 g
s
.67964 .6771 m .66617 .62483 L .68649 .62908 L p .707 .577 .707 r
F P
0 g
s
.31386 .628 m .31972 .68536 L .3436 .68217 L p .707 .577 .707 r
F P
0 g
s
.3436 .68217 m .33774 .62481 L .31386 .628 L p .707 .577 .707 r
F P
0 g
s
.63092 .74172 m .6227 .7066 L .64947 .70698 L p .707 .577 .707 r
F P
0 g
s
.63958 .62476 m .65305 .67702 L .62278 .68114 L p .707 .577 .707 r
F P
0 g
s
.62278 .68114 m .60932 .62887 L .63958 .62476 L p .707 .577 .707 r
F P
0 g
s
.6154 .81164 m .62141 .79354 L .65098 .80416 L p .707 .577 .707 r
F P
0 g
s
.60882 .30673 m .60882 .80862 L .63275 .79836 L p .707 .577 .707 r
F P
0 g
s
.64947 .70698 m .65769 .7421 L .63092 .74172 L p .707 .577 .707 r
F P
0 g
s
.63275 .79836 m .63275 .29647 L .60882 .30673 L p .707 .577 .707 r
F P
0 g
s
.20047 .69725 m .19461 .63989 L .17361 .64116 L p .707 .577 .707 r
F P
0 g
s
.17361 .64116 m .17947 .69852 L .20047 .69725 L p .707 .577 .707 r
F P
0 g
s
.66997 .71137 m .67819 .74649 L .65769 .7421 L p .707 .577 .707 r
F P
0 g
s
.65769 .7421 m .64947 .70698 L .66997 .71137 L p .707 .577 .707 r
F P
0 g
s
.66617 .62483 m .67964 .6771 L .65305 .67702 L p .707 .577 .707 r
F P
0 g
s
.65305 .67702 m .63958 .62476 L .66617 .62483 L p .707 .577 .707 r
F P
0 g
s
.33774 .62481 m .3436 .68217 L .35981 .67952 L p .707 .577 .707 r
F P
0 g
s
.35981 .67952 m .35396 .62216 L .33774 .62481 L p .707 .577 .707 r
F P
0 g
s
.24964 .74904 m .24607 .7108 L .215 .7133 L p .707 .577 .707 r
F P
0 g
s
.24607 .7108 m .24964 .74904 L .28132 .74591 L p .707 .577 .707 r
F P
0 g
s
.28132 .74591 m .27775 .70768 L .24607 .7108 L p .707 .577 .707 r
F P
0 g
s
.37633 .80314 m .37633 .30125 L .35944 .29002 L p .707 .577 .707 r
F P
0 g
s
.37633 .30125 m .37633 .80314 L .40532 .81242 L p .707 .577 .707 r
F P
0 g
s
.215 .7133 m .21857 .75154 L .24964 .74904 L p .707 .577 .707 r
F P
0 g
s
.70866 .83244 m .70265 .85054 L .69084 .84271 L p .707 .577 .707 r
F P
0 g
s
.69084 .84271 m .69685 .82461 L .70866 .83244 L p .707 .577 .707 r
F P
0 g
s
.27775 .70768 m .28132 .74591 L .31052 .74247 L p .707 .577 .707 r
F P
0 g
s
.31052 .74247 m .30695 .70424 L .27775 .70768 L p .707 .577 .707 r
F P
0 g
s
.25663 .84437 m .25929 .82851 L .22834 .82119 L p .707 .577 .707 r
F P
0 g
s
.25929 .82851 m .25663 .84437 L .28813 .84622 L p .707 .577 .707 r
F P
0 g
s
.28813 .84622 m .29078 .83036 L .25929 .82851 L p .707 .577 .707 r
F P
0 g
s
.21857 .75154 m .215 .7133 L .18758 .71493 L p .707 .577 .707 r
F P
0 g
s
.22568 .83705 m .22834 .82119 L .20096 .80912 L p .707 .577 .707 r
F P
0 g
s
.22834 .82119 m .22568 .83705 L .25663 .84437 L p .707 .577 .707 r
F P
0 g
s
.18758 .71493 m .19115 .75317 L .21857 .75154 L p .707 .577 .707 r
F P
0 g
s
.17947 .69852 m .17361 .64116 L .16101 .64139 L p .707 .577 .707 r
F P
0 g
s
.29078 .83036 m .28813 .84622 L .31709 .84242 L p .707 .577 .707 r
F P
0 g
s
.31709 .84242 m .31975 .82656 L .29078 .83036 L p .707 .577 .707 r
F P
0 g
s
.16101 .64139 m .16687 .69875 L .17947 .69852 L p .707 .577 .707 r
F P
0 g
s
.30695 .70424 m .31052 .74247 L .33437 .73905 L p .707 .577 .707 r
F P
0 g
s
.33437 .73905 m .3308 .70082 L .30695 .70424 L p .707 .577 .707 r
F P
0 g
s
.63275 .29647 m .63275 .79836 L .64369 .78661 L p .707 .577 .707 r
F P
0 g
s
.64369 .78661 m .64369 .28472 L .63275 .29647 L p .707 .577 .707 r
F P
0 g
s
.20096 .80912 m .19831 .82497 L .22568 .83705 L p .707 .577 .707 r
F P
0 g
s
.19831 .82497 m .20096 .80912 L .17984 .79347 L p .707 .577 .707 r
F P
0 g
s
.31975 .82656 m .31709 .84242 L .34068 .83333 L p .707 .577 .707 r
F P
0 g
s
.34068 .83333 m .34334 .81748 L .31975 .82656 L p .707 .577 .707 r
F P
0 g
s
.19115 .75317 m .18758 .71493 L .16651 .71553 L p .707 .577 .707 r
F P
0 g
s
.16651 .71553 m .17008 .75377 L .19115 .75317 L p .707 .577 .707 r
F P
0 g
s
.35944 .29002 m .35631 .27794 L p .35729 .43951 L .707 .577 .707 r
F P
0 g
s
.35396 .62216 m .35981 .67952 L .36579 .67795 L p .707 .577 .707 r
F P
0 g
s
.3656 .67255 m .35396 .62216 L .36579 .67795 L .707 .577 .707 r
F
.36678 .67769 m .36093 .62032 L .35396 .62216 L p F P
0 g
s
.35797 .61948 m .36093 .62032 L p .36348 .67017 L .707 .577 .707 r
F P
0 g
s
.36383 .67684 m .36325 .67119 L p .36348 .67017 L .707 .577 .707 r
F P
0 g
s
.36325 .67119 m .35797 .61948 L p .36348 .67017 L .707 .577 .707 r
F P
0 g
s
.3627 .76946 m .36005 .78532 L .34726 .76763 L p .707 .577 .707 r
F P
0 g
s
.34726 .76763 m .34991 .75177 L .3627 .76946 L p .707 .577 .707 r
F P
0 g
s
.35631 .77983 m .35944 .79191 L p .35882 .69034 L .707 .577 .707 r
F P
0 g
s
.35797 .61948 m .36383 .67684 L .35123 .67707 L p .707 .577 .707 r
F P
0 g
s
.35123 .67707 m .34537 .6197 L .35797 .61948 L p .707 .577 .707 r
F P
0 g
s
.35631 .27794 m .35631 .7012 L p .35882 .69034 L .707 .577 .707 r
F P
0 g
s
.34697 .69775 m .35054 .73599 L .35745 .73357 L p .707 .577 .707 r
F P
0 g
s
.35745 .73357 m .35388 .69534 L .34697 .69775 L p .707 .577 .707 r
F P
0 g
s
.35388 .69534 m .35745 .73357 L .35443 .73205 L p .707 .577 .707 r
F P
0 g
s
.35631 .7012 m .35631 .77983 L p .35882 .69034 L .707 .577 .707 r
F P
0 g
s
.35944 .79191 m .35944 .49971 L p .35729 .43951 L .707 .577 .707 r
F P
0 g
s
.35944 .49971 m .35944 .29002 L p .35729 .43951 L .707 .577 .707 r
F P
0 g
s
.36579 .67795 m .36678 .67769 L p .3656 .67255 L .707 .577 .707 r
F P
0 g
s
.17984 .79347 m .17719 .80933 L .19831 .82497 L p .707 .577 .707 r
F P
0 g
s
.69685 .82461 m .69084 .84271 L .67097 .83297 L p .707 .577 .707 r
F P
0 g
s
.67097 .83297 m .67698 .81487 L .69685 .82461 L p .707 .577 .707 r
F P
0 g
s
.3308 .70082 m .33437 .73905 L .35054 .73599 L p .707 .577 .707 r
F P
0 g
s
.35054 .73599 m .34697 .69775 L .3308 .70082 L p .707 .577 .707 r
F P
0 g
s
.17719 .80933 m .17984 .79347 L .16705 .77578 L p .707 .577 .707 r
F P
0 g
s
.16687 .69875 m .16101 .64139 L .15805 .64054 L p .707 .577 .707 r
F P
0 g
s
.15805 .64054 m .16391 .6979 L .16687 .69875 L p .707 .577 .707 r
F P
0 g
s
.36093 .62032 m .36678 .67769 L .36383 .67684 L p .707 .577 .707 r
F P
0 g
s
.36327 .80331 m .36592 .78746 L .35925 .804 L p .707 .577 .707 r
F P
0 g
s
.36592 .78746 m .36327 .80331 L .36005 .78532 L p .707 .577 .707 r
F P
0 g
s
.36005 .78532 m .3627 .76946 L .36592 .78746 L p .707 .577 .707 r
F P
0 g
s
.35944 .29002 m .35944 .79191 L .37633 .80314 L p .707 .577 .707 r
F P
0 g
s
.34334 .81748 m .34068 .83333 L .35659 .81986 L p .707 .577 .707 r
F P
0 g
s
.35659 .81986 m .35925 .804 L .34334 .81748 L p .707 .577 .707 r
F P
0 g
s
.17008 .75377 m .16651 .71553 L .15384 .71505 L p .707 .577 .707 r
F P
0 g
s
.16705 .77578 m .1644 .79164 L .17719 .80933 L p .707 .577 .707 r
F P
0 g
s
.15384 .71505 m .15741 .75329 L .17008 .75377 L p .707 .577 .707 r
F P
0 g
s
.67698 .81487 m .67097 .83297 L .64497 .82226 L p .707 .577 .707 r
F P
0 g
s
.64497 .82226 m .65098 .80416 L .67698 .81487 L p .707 .577 .707 r
F P
0 g
s
.64369 .28472 m .64369 .70797 L p .64118 .67773 L .707 .577 .707 r
F P
0 g
s
.64056 .77453 m .64056 .27264 L .64369 .28472 L p .707 .577 .707 r
F P
0 g
s
.64056 .27264 m .64056 .77453 L .62367 .7633 L p .707 .577 .707 r
F P
0 g
s
.64203 .57915 m .63907 .56343 L p .63651 .62155 L .707 .577 .707 r
F P
0 g
s
.63617 .62932 m .63675 .62438 L p .63651 .62155 L .707 .577 .707 r
F P
0 g
s
.63675 .62438 m .64203 .57915 L p .63651 .62155 L .707 .577 .707 r
F P
0 g
s
.64369 .78661 m .64056 .77453 L p .64118 .67773 L .707 .577 .707 r
F P
0 g
s
.64369 .70797 m .64369 .78661 L p .64118 .67773 L .707 .577 .707 r
F P
0 g
s
.1644 .79164 m .16705 .77578 L .16383 .75778 L p .707 .577 .707 r
F P
0 g
s
.35925 .804 m .35659 .81986 L .36327 .80331 L p .707 .577 .707 r
F P
0 g
s
.65098 .80416 m .64497 .82226 L .6154 .81164 L p .707 .577 .707 r
F P
0 g
s
.16391 .6979 m .15805 .64054 L .16502 .63871 L p .707 .577 .707 r
F P
0 g
s
.16383 .75778 m .16118 .77364 L .1644 .79164 L p .707 .577 .707 r
F P
0 g
s
.16502 .63871 m .17088 .69607 L .16391 .6979 L p .707 .577 .707 r
F P
0 g
s
.15741 .75329 m .15384 .71505 L .15081 .71353 L p .707 .577 .707 r
F P
0 g
s
.15081 .71353 m .15438 .75177 L .15741 .75329 L p .707 .577 .707 r
F P
0 g
s
.35631 .77983 m .35631 .27794 L .36724 .26619 L p .707 .577 .707 r
F P
0 g
s
.16118 .77364 m .16383 .75778 L .17051 .74124 L p .707 .577 .707 r
F P
0 g
s
.35443 .73205 m .35085 .69382 L .35388 .69534 L p .707 .577 .707 r
F P
0 g
s
.17051 .74124 m .16785 .75709 L .16118 .77364 L p .707 .577 .707 r
F P
0 g
s
.17088 .69607 m .16502 .63871 L .18124 .63606 L p .707 .577 .707 r
F P
0 g
s
.62367 .7633 m .62367 .26141 L .64056 .27264 L p .707 .577 .707 r
F P
0 g
s
.18124 .63606 m .1871 .69342 L .17088 .69607 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15438 .75177 m .15081 .71353 L .15772 .71112 L p .707 .577 .707 r
F P
0 g
s
.15772 .71112 m .16129 .74936 L .15438 .75177 L p .707 .577 .707 r
F P
0 g
s
.16785 .75709 m .17051 .74124 L .18642 .72776 L p .707 .577 .707 r
F P
0 g
s
.34537 .6197 m .35123 .67707 L .33022 .67834 L p .707 .577 .707 r
F P
0 g
s
.33022 .67834 m .32436 .62098 L .34537 .6197 L p .707 .577 .707 r
F P
0 g
s
.18642 .72776 m .18376 .74362 L .16785 .75709 L p .707 .577 .707 r
F P
0 g
s
.35085 .69382 m .35443 .73205 L .34175 .73157 L p .707 .577 .707 r
F P
0 g
s
.34175 .73157 m .33818 .69333 L .35085 .69382 L p .707 .577 .707 r
F P
0 g
s
.36724 .76808 m .36724 .26619 L .39118 .25592 L p .707 .577 .707 r
F P
0 g
s
.36724 .26619 m .36724 .76808 L .35631 .77983 L p .707 .577 .707 r
F P
0 g
s
.1871 .69342 m .18124 .63606 L .20512 .63286 L p .707 .577 .707 r
F P
0 g
s
.20512 .63286 m .21097 .69023 L .1871 .69342 L p .707 .577 .707 r
F P
0 g
s
.18376 .74362 m .18642 .72776 L .21001 .71868 L p .707 .577 .707 r
F P
0 g
s
.16129 .74936 m .15772 .71112 L .17389 .70805 L p .707 .577 .707 r
F P
0 g
s
.17389 .70805 m .17746 .74629 L .16129 .74936 L p .707 .577 .707 r
F P
0 g
s
.32436 .62098 m .33022 .67834 L .30287 .68055 L p .707 .577 .707 r
F P
0 g
s
.30287 .68055 m .29701 .62318 L .32436 .62098 L p .707 .577 .707 r
F P
0 g
s
.34991 .75177 m .34726 .76763 L .32614 .75198 L p .707 .577 .707 r
F P
0 g
s
.32614 .75198 m .32879 .73612 L .34991 .75177 L p .707 .577 .707 r
F P
0 g
s
.62367 .26141 m .62367 .7633 L .59468 .75402 L p .707 .577 .707 r
F P
0 g
s
.59468 .75402 m .59468 .25213 L .62367 .26141 L p .707 .577 .707 r
F P
0 g
s
.21001 .71868 m .20736 .73454 L .18376 .74362 L p .707 .577 .707 r
F P
0 g
s
.21097 .69023 m .20512 .63286 L .23432 .62943 L p .707 .577 .707 r
F P
0 g
s
.23432 .62943 m .24017 .68679 L .21097 .69023 L p .707 .577 .707 r
F P
0 g
s
.33818 .69333 m .34175 .73157 L .32068 .73217 L p .707 .577 .707 r
F P
0 g
s
.32068 .73217 m .31711 .69394 L .33818 .69333 L p .707 .577 .707 r
F P
0 g
s
.20736 .73454 m .21001 .71868 L .23897 .71488 L p .707 .577 .707 r
F P
0 g
s
.29701 .62318 m .30287 .68055 L .27184 .68346 L p .707 .577 .707 r
F P
0 g
s
.27184 .68346 m .26598 .62609 L .29701 .62318 L p .707 .577 .707 r
F P
0 g
s
.32879 .73612 m .32614 .75198 L .29876 .7399 L p .707 .577 .707 r
F P
0 g
s
.29876 .7399 m .30142 .72405 L .32879 .73612 L p .707 .577 .707 r
F P
0 g
s
.24017 .68679 m .23432 .62943 L .26598 .62609 L p .707 .577 .707 r
F P
0 g
s
.39118 .25592 m .39117 .75781 L .36724 .76808 L p .707 .577 .707 r
F P
0 g
s
.39117 .75781 m .39118 .25592 L .42576 .24814 L p .707 .577 .707 r
F P
0 g
s
.26598 .62609 m .27184 .68346 L .24017 .68679 L p .707 .577 .707 r
F P
0 g
s
.17746 .74629 m .17389 .70805 L .19774 .70463 L p .707 .577 .707 r
F P
0 g
s
.23897 .71488 m .23632 .73073 L .20736 .73454 L p .707 .577 .707 r
F P
0 g
s
.19774 .70463 m .20131 .74287 L .17746 .74629 L p .707 .577 .707 r
F P
0 g
s
.23632 .73073 m .23897 .71488 L .27047 .71673 L p .707 .577 .707 r
F P
0 g
s
.72816 .67477 m .73402 .6246 L .70299 .61842 L p .707 .577 .707 r
F P
0 g
s
.73402 .6246 m .72816 .67477 L .75982 .67615 L p .707 .577 .707 r
F P
0 g
s
.75982 .67615 m .76568 .62598 L .73402 .6246 L p .707 .577 .707 r
F P
0 g
s
.30142 .72405 m .29876 .7399 L .26781 .73258 L p .707 .577 .707 r
F P
0 g
s
.26781 .73258 m .27047 .71673 L .30142 .72405 L p .707 .577 .707 r
F P
0 g
s
.76568 .62598 m .75982 .67615 L .78902 .6726 L p .707 .577 .707 r
F P
0 g
s
.78902 .6726 m .79488 .62243 L .76568 .62598 L p .707 .577 .707 r
F P
0 g
s
.69713 .6686 m .70299 .61842 L .67563 .60807 L p .707 .577 .707 r
F P
0 g
s
.70299 .61842 m .69713 .6686 L .72816 .67477 L p .707 .577 .707 r
F P
0 g
s
.7378 .73964 m .74137 .70579 L .7103 .69998 L p .707 .577 .707 r
F P
0 g
s
.74137 .70579 m .7378 .73964 L .76949 .74083 L p .707 .577 .707 r
F P
0 g
s
.76949 .74083 m .77306 .70698 L .74137 .70579 L p .707 .577 .707 r
F P
0 g
s
.27047 .71673 m .26781 .73258 L .23632 .73073 L p .707 .577 .707 r
F P
0 g
s
.59468 .25213 m .59468 .75402 L .55642 .7476 L p .707 .577 .707 r
F P
0 g
s
.55642 .7476 m .55642 .24571 L .59468 .25213 L p .707 .577 .707 r
F P
0 g
s
.77306 .70698 m .76949 .74083 L .79868 .73729 L p .707 .577 .707 r
F P
0 g
s
.79868 .73729 m .80226 .70343 L .77306 .70698 L p .707 .577 .707 r
F P
0 g
s
.31711 .69394 m .32068 .73217 L .29327 .73381 L p .707 .577 .707 r
F P
0 g
s
.29327 .73381 m .28969 .69557 L .31711 .69394 L p .707 .577 .707 r
F P
0 g
s
.70673 .73383 m .7103 .69998 L .68289 .69012 L p .707 .577 .707 r
F P
0 g
s
.7103 .69998 m .70673 .73383 L .7378 .73964 L p .707 .577 .707 r
F P
0 g
s
.79488 .62243 m .78902 .6726 L .8129 .66447 L p .707 .577 .707 r
F P
0 g
s
.8129 .66447 m .81876 .6143 L .79488 .62243 L p .707 .577 .707 r
F P
0 g
s
.20131 .74287 m .19774 .70463 L .22694 .70119 L p .707 .577 .707 r
F P
0 g
s
.66978 .65824 m .67563 .60807 L .65463 .59453 L p .707 .577 .707 r
F P
0 g
s
.67563 .60807 m .66978 .65824 L .69713 .6686 L p .707 .577 .707 r
F P
0 g
s
.22694 .70119 m .23051 .73943 L .20131 .74287 L p .707 .577 .707 r
F P
0 g
s
.42576 .75003 m .42576 .24814 L .46761 .24361 L p .707 .577 .707 r
F P
0 g
s
.42576 .24814 m .42576 .75003 L .39117 .75781 L p .707 .577 .707 r
F P
0 g
s
.80226 .70343 m .79868 .73729 L .82254 .72935 L p .707 .577 .707 r
F P
0 g
s
.82254 .72935 m .82611 .6955 L .80226 .70343 L p .707 .577 .707 r
F P
0 g
s
.67932 .72398 m .68289 .69012 L .66182 .67718 L p .707 .577 .707 r
F P
0 g
s
.68289 .69012 m .67932 .72398 L .70673 .73383 L p .707 .577 .707 r
F P
0 g
s
.28969 .69557 m .29327 .73381 L .2622 .73631 L p .707 .577 .707 r
F P
0 g
s
.2622 .73631 m .25862 .69807 L .28969 .69557 L p .707 .577 .707 r
F P
0 g
s
.55642 .24571 m .55642 .7476 L .51263 .74466 L p .707 .577 .707 r
F P
0 g
s
.51263 .74466 m .51263 .24277 L .55642 .24571 L p .707 .577 .707 r
F P
0 g
s
.23051 .73943 m .22694 .70119 L .25862 .69807 L p .707 .577 .707 r
F P
0 g
s
.25862 .69807 m .2622 .73631 L .23051 .73943 L p .707 .577 .707 r
F P
0 g
s
.81876 .6143 m .8129 .66447 L .82912 .65256 L p .707 .577 .707 r
F P
0 g
s
.82912 .65256 m .83498 .60239 L .81876 .6143 L p .707 .577 .707 r
F P
0 g
s
.46761 .7455 m .46761 .24361 L .51263 .24277 L p .707 .577 .707 r
F P
0 g
s
.46761 .24361 m .46761 .7455 L .42576 .75003 L p .707 .577 .707 r
F P
0 g
s
.69858 .71211 m .70123 .73114 L .73218 .72654 L p .707 .577 .707 r
F P
0 g
s
.73218 .72654 m .72953 .70751 L .69858 .71211 L p .707 .577 .707 r
F P
0 g
s
.72953 .70751 m .73218 .72654 L .76368 .7223 L p .707 .577 .707 r
F P
0 g
s
.64877 .64471 m .65463 .59453 L .64203 .57915 L p .707 .577 .707 r
F P
0 g
s
.65463 .59453 m .64877 .64471 L .66978 .65824 L p .707 .577 .707 r
F P
0 g
s
.76368 .7223 m .76103 .70327 L .72953 .70751 L p .707 .577 .707 r
F P
0 g
s
.51263 .24277 m .51263 .74466 L .46761 .7455 L p .707 .577 .707 r
F P
0 g
s
.76103 .70327 m .76368 .7223 L .79264 .71884 L p .707 .577 .707 r
F P
0 g
s
.66182 .67718 m .65824 .71104 L .67932 .72398 L p .707 .577 .707 r
F P
0 g
s
.82611 .6955 m .82254 .72935 L .83871 .71781 L p .707 .577 .707 r
F P
0 g
s
.83871 .71781 m .84228 .68396 L .82611 .6955 L p .707 .577 .707 r
F P
0 g
s
.79264 .71884 m .78999 .69981 L .76103 .70327 L p .707 .577 .707 r
F P
0 g
s
.65824 .71104 m .66182 .67718 L .64914 .66243 L p .707 .577 .707 r
F P
0 g
s
.67121 .71663 m .67386 .73566 L .70123 .73114 L p .707 .577 .707 r
F P
0 g
s
.70123 .73114 m .69858 .71211 L .67121 .71663 L p .707 .577 .707 r
F P
0 g
s
.78999 .69981 m .79264 .71884 L .81623 .7165 L p .707 .577 .707 r
F P
0 g
s
.81623 .7165 m .81358 .69747 L .78999 .69981 L p .707 .577 .707 r
F P
0 g
s
.65009 .72061 m .65274 .73964 L .67386 .73566 L p .707 .577 .707 r
F P
0 g
s
.67386 .73566 m .67121 .71663 L .65009 .72061 L p .707 .577 .707 r
F P
0 g
s
.64914 .66243 m .64557 .69628 L .65824 .71104 L p .707 .577 .707 r
F P
0 g
s
.83498 .60239 m .82912 .65256 L .83609 .63803 L p .707 .577 .707 r
F P
0 g
s
.83609 .63803 m .84195 .58786 L .83498 .60239 L p .707 .577 .707 r
F P
0 g
s
.64203 .57915 m .63617 .62932 L .64877 .64471 L p .707 .577 .707 r
F P
0 g
s
.84228 .68396 m .83871 .71781 L .84562 .70379 L p .707 .577 .707 r
F P
0 g
s
.84562 .70379 m .84919 .66994 L .84228 .68396 L p .707 .577 .707 r
F P
0 g
s
.64557 .69628 m .64914 .66243 L .64611 .6473 L p .707 .577 .707 r
F P
0 g
s
.81358 .69747 m .81623 .7165 L .83214 .71551 L p .707 .577 .707 r
F P
0 g
s
.83214 .71551 m .82949 .69648 L .81358 .69747 L p .707 .577 .707 r
F P
0 g
s
.6373 .72368 m .63995 .74271 L .65274 .73964 L p .707 .577 .707 r
F P
0 g
s
.65274 .73964 m .65009 .72061 L .6373 .72368 L p .707 .577 .707 r
F P
0 g
s
.64611 .6473 m .64254 .68115 L .64557 .69628 L p .707 .577 .707 r
F P
0 g
s
.84195 .58786 m .83609 .63803 L .83313 .62231 L p .707 .577 .707 r
F P
0 g
s
.83313 .62231 m .83899 .57214 L .84195 .58786 L p .707 .577 .707 r
F P
0 g
s
.63907 .56343 m .63321 .6136 L .63617 .62932 L p .707 .577 .707 r
F P
0 g
s
.63321 .6136 m .63907 .56343 L .64604 .5489 L p .707 .577 .707 r
F P
0 g
s
.84919 .66994 m .84562 .70379 L .84259 .68866 L p .707 .577 .707 r
F P
0 g
s
.84259 .68866 m .84616 .65481 L .84919 .66994 L p .707 .577 .707 r
F P
0 g
s
.64254 .68115 m .64611 .6473 L .65302 .63328 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.82949 .69648 m .83214 .71551 L .83882 .71596 L p .707 .577 .707 r
F P
0 g
s
.83882 .71596 m .83617 .69693 L .82949 .69648 L p .707 .577 .707 r
F P
0 g
s
.63408 .72553 m .63673 .74456 L .63995 .74271 L p .707 .577 .707 r
F P
0 g
s
.63995 .74271 m .6373 .72368 L .63408 .72553 L p .707 .577 .707 r
F P
0 g
s
.65302 .63328 m .64945 .66713 L .64254 .68115 L p .707 .577 .707 r
F P
0 g
s
.83899 .57214 m .83313 .62231 L .82053 .60693 L p .707 .577 .707 r
F P
0 g
s
.82053 .60693 m .82639 .55675 L .83899 .57214 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.64018 .59907 m .64604 .5489 L .66226 .53699 L p .707 .577 .707 r
F P
0 g
s
.64604 .5489 m .64018 .59907 L .63321 .6136 L p .707 .577 .707 r
F P
0 g
s
.37722 .60947 m .39068 .55418 L .36042 .54578 L p .707 .577 .707 r
F P
0 g
s
.39068 .55418 m .37722 .60947 L .40819 .61633 L p .707 .577 .707 r
F P
0 g
s
.40819 .61633 m .42166 .56105 L .39068 .55418 L p .707 .577 .707 r
F P
0 g
s
.84616 .65481 m .84259 .68866 L .82992 .6739 L p .707 .577 .707 r
F P
0 g
s
.82992 .6739 m .83349 .64005 L .84616 .65481 L p .707 .577 .707 r
F P
0 g
s
.64945 .66713 m .65302 .63328 L .6692 .62173 L p .707 .577 .707 r
F P
0 g
s
.42166 .56105 m .40819 .61633 L .43684 .621 L p .707 .577 .707 r
F P
0 g
s
.43684 .621 m .45031 .56571 L .42166 .56105 L p .707 .577 .707 r
F P
0 g
s
.34695 .60107 m .36042 .54578 L .33382 .53667 L p .707 .577 .707 r
F P
0 g
s
.36042 .54578 m .34695 .60107 L .37722 .60947 L p .707 .577 .707 r
F P
0 g
s
.83617 .69693 m .83882 .71596 L .8356 .71781 L p .707 .577 .707 r
F P
0 g
s
.8356 .71781 m .83295 .69878 L .83617 .69693 L p .707 .577 .707 r
F P
0 g
s
.33382 .53667 m .32036 .59196 L .34695 .60107 L p .707 .577 .707 r
F P
0 g
s
.45031 .56571 m .43684 .621 L .46037 .623 L p .707 .577 .707 r
F P
0 g
s
.46037 .623 m .47384 .56772 L .45031 .56571 L p .707 .577 .707 r
F P
0 g
s
.82639 .55675 m .82053 .60693 L .79953 .59339 L p .707 .577 .707 r
F P
0 g
s
.79953 .59339 m .80539 .54322 L .82639 .55675 L p .707 .577 .707 r
F P
0 g
s
.6692 .62173 m .66563 .65559 L .64945 .66713 L p .707 .577 .707 r
F P
0 g
s
.66226 .53699 m .6564 .58716 L .64018 .59907 L p .707 .577 .707 r
F P
0 g
s
.6564 .58716 m .66226 .53699 L .68614 .52886 L p .707 .577 .707 r
F P
0 g
s
.32036 .59196 m .33382 .53667 L .31351 .52774 L p .707 .577 .707 r
F P
0 g
s
.64075 .72598 m .6434 .74501 L .63673 .74456 L p .707 .577 .707 r
F P
0 g
s
.63673 .74456 m .63408 .72553 L .64075 .72598 L p .707 .577 .707 r
F P
0 g
s
.83349 .64005 m .82992 .6739 L .80884 .66096 L p .707 .577 .707 r
F P
0 g
s
.80884 .66096 m .81242 .62711 L .83349 .64005 L p .707 .577 .707 r
F P
0 g
s
.66563 .65559 m .6692 .62173 L .69305 .6138 L p .707 .577 .707 r
F P
0 g
s
.39951 .66876 m .40773 .63179 L .3773 .62395 L p .707 .577 .707 r
F P
0 g
s
.40773 .63179 m .39951 .66876 L .43062 .67496 L p .707 .577 .707 r
F P
0 g
s
.43062 .67496 m .43884 .63799 L .40773 .63179 L p .707 .577 .707 r
F P
0 g
s
.31351 .52774 m .30004 .58303 L .32036 .59196 L p .707 .577 .707 r
F P
0 g
s
.43884 .63799 m .43062 .67496 L .45936 .67892 L p .707 .577 .707 r
F P
0 g
s
.45936 .67892 m .46758 .64194 L .43884 .63799 L p .707 .577 .707 r
F P
0 g
s
.36908 .66093 m .3773 .62395 L .35053 .61525 L p .707 .577 .707 r
F P
0 g
s
.3773 .62395 m .36908 .66093 L .39951 .66876 L p .707 .577 .707 r
F P
0 g
s
.47384 .56772 m .46037 .623 L .47647 .62215 L p .707 .577 .707 r
F P
0 g
s
.47647 .62215 m .48993 .56686 L .47384 .56772 L p .707 .577 .707 r
F P
0 g
s
.80539 .54322 m .79953 .59339 L .77217 .58304 L p .707 .577 .707 r
F P
0 g
s
.77217 .58304 m .77803 .53286 L .80539 .54322 L p .707 .577 .707 r
F P
0 g
s
.68028 .57903 m .68614 .52886 L .71534 .52531 L p .707 .577 .707 r
F P
0 g
s
.68614 .52886 m .68028 .57903 L .6564 .58716 L p .707 .577 .707 r
F P
0 g
s
.41485 .72789 m .40884 .71112 L .37859 .72133 L p .707 .577 .707 r
F P
0 g
s
.40884 .71112 m .41485 .72789 L .44283 .71451 L p .707 .577 .707 r
F P
0 g
s
.44283 .71451 m .43682 .69774 L .40884 .71112 L p .707 .577 .707 r
F P
0 g
s
.35053 .61525 m .3423 .65223 L .36908 .66093 L p .707 .577 .707 r
F P
0 g
s
.3846 .73811 m .37859 .72133 L .34901 .72739 L p .707 .577 .707 r
F P
0 g
s
.37859 .72133 m .3846 .73811 L .41485 .72789 L p .707 .577 .707 r
F P
0 g
s
.83295 .69878 m .8356 .71781 L .82281 .72088 L p .707 .577 .707 r
F P
0 g
s
.30004 .58303 m .31351 .52774 L .30146 .51987 L p .707 .577 .707 r
F P
0 g
s
.82281 .72088 m .82015 .70185 L .83295 .69878 L p .707 .577 .707 r
F P
0 g
s
.69305 .6138 m .68948 .64766 L .66563 .65559 L p .707 .577 .707 r
F P
0 g
s
.81242 .62711 m .80884 .66096 L .78143 .65111 L p .707 .577 .707 r
F P
0 g
s
.78143 .65111 m .785 .61725 L .81242 .62711 L p .707 .577 .707 r
F P
0 g
s
.46758 .64194 m .45936 .67892 L .48292 .68025 L p .707 .577 .707 r
F P
0 g
s
.48292 .68025 m .49114 .64327 L .46758 .64194 L p .707 .577 .707 r
F P
0 g
s
.68948 .64766 m .69305 .6138 L .72225 .61026 L p .707 .577 .707 r
F P
0 g
s
.43682 .69774 m .44283 .71451 L .46579 .69928 L p .707 .577 .707 r
F P
0 g
s
.46579 .69928 m .45978 .68251 L .43682 .69774 L p .707 .577 .707 r
F P
0 g
s
.34901 .72739 m .35502 .74416 L .3846 .73811 L p .707 .577 .707 r
F P
0 g
s
.3423 .65223 m .35053 .61525 L .33003 .60653 L p .707 .577 .707 r
F P
0 g
s
.35502 .74416 m .34901 .72739 L .32302 .72869 L p .707 .577 .707 r
F P
0 g
s
.77803 .53286 m .77217 .58304 L .74114 .57686 L p .707 .577 .707 r
F P
0 g
s
.74114 .57686 m .747 .52669 L .77803 .53286 L p .707 .577 .707 r
F P
0 g
s
.70948 .57548 m .71534 .52531 L .747 .52669 L p .707 .577 .707 r
F P
0 g
s
.71534 .52531 m .70948 .57548 L .68028 .57903 L p .707 .577 .707 r
F P
0 g
s
.65666 .72499 m .65931 .74402 L .6434 .74501 L p .707 .577 .707 r
F P
0 g
s
.6434 .74501 m .64075 .72598 L .65666 .72499 L p .707 .577 .707 r
F P
0 g
s
.30146 .51987 m .28799 .57516 L .30004 .58303 L p .707 .577 .707 r
F P
0 g
s
.33003 .60653 m .32181 .64351 L .3423 .65223 L p .707 .577 .707 r
F P
0 g
s
.747 .52669 m .74114 .57686 L .70948 .57548 L p .707 .577 .707 r
F P
0 g
s
.785 .61725 m .78143 .65111 L .75036 .6453 L p .707 .577 .707 r
F P
0 g
s
.75036 .6453 m .75393 .61145 L .785 .61725 L p .707 .577 .707 r
F P
0 g
s
.32302 .72869 m .32903 .74546 L .35502 .74416 L p .707 .577 .707 r
F P
0 g
s
.71868 .64411 m .72225 .61026 L .75393 .61145 L p .707 .577 .707 r
F P
0 g
s
.72225 .61026 m .71868 .64411 L .68948 .64766 L p .707 .577 .707 r
F P
0 g
s
.75393 .61145 m .75036 .6453 L .71868 .64411 L p .707 .577 .707 r
F P
0 g
s
.45978 .68251 m .46579 .69928 L .48148 .68369 L p .707 .577 .707 r
F P
0 g
s
.48148 .68369 m .47547 .66692 L .45978 .68251 L p .707 .577 .707 r
F P
0 g
s
.48993 .56686 m .47647 .62215 L .48356 .61852 L p .707 .577 .707 r
F P
0 g
s
.48356 .61852 m .49702 .56324 L .48993 .56686 L p .707 .577 .707 r
F P
0 g
s
.49114 .64327 m .48292 .68025 L .49899 .67882 L p .707 .577 .707 r
F P
0 g
s
.49899 .67882 m .50721 .64184 L .49114 .64327 L p .707 .577 .707 r
F P
0 g
s
.32903 .74546 m .32302 .72869 L .30314 .72511 L p .707 .577 .707 r
F P
0 g
s
.28799 .57516 m .30146 .51987 L .29885 .51383 L p .707 .577 .707 r
F P
0 g
s
.32181 .64351 m .33003 .60653 L .31782 .59865 L p .707 .577 .707 r
F P
0 g
s
.82015 .70185 m .82281 .72088 L .80169 .72486 L p .707 .577 .707 r
F P
0 g
s
.80169 .72486 m .79904 .70583 L .82015 .70185 L p .707 .577 .707 r
F P
0 g
s
.30314 .72511 m .30915 .74188 L .32903 .74546 L p .707 .577 .707 r
F P
0 g
s
.31782 .59865 m .30959 .63563 L .32181 .64351 L p .707 .577 .707 r
F P
0 g
s
.68025 .72265 m .68291 .74168 L .65931 .74402 L p .707 .577 .707 r
F P
0 g
s
.65931 .74402 m .65666 .72499 L .68025 .72265 L p .707 .577 .707 r
F P
0 g
s
.29885 .51383 m .28538 .56911 L .28799 .57516 L p .707 .577 .707 r
F P
0 g
s
.47547 .66692 m .48148 .68369 L .48837 .66926 L p .707 .577 .707 r
F P
0 g
s
.48837 .66926 m .48236 .65249 L .47547 .66692 L p .707 .577 .707 r
F P
0 g
s
.50721 .64184 m .49899 .67882 L .506 .67477 L p .707 .577 .707 r
F P
0 g
s
.506 .67477 m .51422 .6378 L .50721 .64184 L p .707 .577 .707 r
F P
0 g
s
.30915 .74188 m .30314 .72511 L .29133 .71699 L p .707 .577 .707 r
F P
0 g
s
.79904 .70583 m .80169 .72486 L .77432 .72938 L p .707 .577 .707 r
F P
0 g
s
.49702 .56324 m .48356 .61852 L .48095 .61247 L p .707 .577 .707 r
F P
0 g
s
.48095 .61247 m .49442 .55719 L .49702 .56324 L p .707 .577 .707 r
F P
0 g
s
.77432 .72938 m .77166 .71035 L .79904 .70583 L p .707 .577 .707 r
F P
0 g
s
.30959 .63563 m .31782 .59865 L .31508 .59238 L p .707 .577 .707 r
F P
0 g
s
.70921 .71919 m .71187 .73822 L .68291 .74168 L p .707 .577 .707 r
F P
0 g
s
.68291 .74168 m .68025 .72265 L .70921 .71919 L p .707 .577 .707 r
F P
0 g
s
.29133 .71699 m .29734 .73376 L .30915 .74188 L p .707 .577 .707 r
F P
0 g
s
.28538 .56911 m .29885 .51383 L .30594 .5102 L p .707 .577 .707 r
F P
0 g
s
.31508 .59238 m .30686 .62936 L .30959 .63563 L p .707 .577 .707 r
F P
0 g
s
.77166 .71035 m .77432 .72938 L .74336 .73398 L p .707 .577 .707 r
F P
0 g
s
.74336 .73398 m .74071 .71495 L .77166 .71035 L p .707 .577 .707 r
F P
0 g
s
.30594 .5102 m .29248 .56548 L .28538 .56911 L p .707 .577 .707 r
F P
0 g
s
.48236 .65249 m .48837 .66926 L .48579 .65741 L p .707 .577 .707 r
F P
0 g
s
.48579 .65741 m .47978 .64064 L .48236 .65249 L p .707 .577 .707 r
F P
0 g
s
.74071 .71495 m .74336 .73398 L .71187 .73822 L p .707 .577 .707 r
F P
0 g
s
.71187 .73822 m .70921 .71919 L .74071 .71495 L p .707 .577 .707 r
F P
0 g
s
.29734 .73376 m .29133 .71699 L .28875 .70514 L p .707 .577 .707 r
F P
0 g
s
.51422 .6378 m .506 .67477 L .50326 .6685 L p .707 .577 .707 r
F P
0 g
s
.50326 .6685 m .51149 .63152 L .51422 .6378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49442 .55719 m .48095 .61247 L .4689 .6046 L p .707 .577 .707 r
F P
0 g
s
.4689 .6046 m .48236 .54932 L .49442 .55719 L p .707 .577 .707 r
F P
0 g
s
.28875 .70514 m .29476 .72191 L .29734 .73376 L p .707 .577 .707 r
F P
0 g
s
.30686 .62936 m .31508 .59238 L .32209 .58833 L p .707 .577 .707 r
F P
0 g
s
.29248 .56548 m .30594 .5102 L .32204 .50934 L p .707 .577 .707 r
F P
0 g
s
.32209 .58833 m .31387 .62531 L .30686 .62936 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.32204 .50934 m .30857 .56463 L .29248 .56548 L p .707 .577 .707 r
F P
0 g
s
.47978 .64064 m .48579 .65741 L .47398 .6493 L p .707 .577 .707 r
F P
0 g
s
.47398 .6493 m .46797 .63253 L .47978 .64064 L p .707 .577 .707 r
F P
0 g
s
.29476 .72191 m .28875 .70514 L .29564 .69072 L p .707 .577 .707 r
F P
0 g
s
.48236 .54932 m .4689 .6046 L .44858 .59567 L p .707 .577 .707 r
F P
0 g
s
.44858 .59567 m .46205 .54039 L .48236 .54932 L p .707 .577 .707 r
F P
0 g
s
.51149 .63152 m .50326 .6685 L .49105 .66062 L p .707 .577 .707 r
F P
0 g
s
.49105 .66062 m .49927 .62364 L .51149 .63152 L p .707 .577 .707 r
F P
0 g
s
.29564 .69072 m .30165 .70749 L .29476 .72191 L p .707 .577 .707 r
F P
0 g
s
.30857 .56463 m .32204 .50934 L .34556 .51135 L p .707 .577 .707 r
F P
0 g
s
.31387 .62531 m .32209 .58833 L .33816 .5869 L p .707 .577 .707 r
F P
0 g
s
.33816 .5869 m .32994 .62388 L .31387 .62531 L p .707 .577 .707 r
F P
0 g
s
.34556 .51135 m .3321 .56663 L .30857 .56463 L p .707 .577 .707 r
F P
0 g
s
.46797 .63253 m .47398 .6493 L .4541 .64572 L p .707 .577 .707 r
F P
0 g
s
.4541 .64572 m .44809 .62894 L .46797 .63253 L p .707 .577 .707 r
F P
0 g
s
.46205 .54039 m .44858 .59567 L .42199 .58656 L p .707 .577 .707 r
F P
0 g
s
.42199 .58656 m .43546 .53128 L .46205 .54039 L p .707 .577 .707 r
F P
0 g
s
.30165 .70749 m .29564 .69072 L .31133 .67512 L p .707 .577 .707 r
F P
0 g
s
.3321 .56663 m .34556 .51135 L .37422 .51601 L p .707 .577 .707 r
F P
0 g
s
.49927 .62364 m .49105 .66062 L .47055 .6519 L p .707 .577 .707 r
F P
0 g
s
.47055 .6519 m .47878 .61493 L .49927 .62364 L p .707 .577 .707 r
F P
0 g
s
.31133 .67512 m .31734 .69189 L .30165 .70749 L p .707 .577 .707 r
F P
0 g
s
.32994 .62388 m .33816 .5869 L .36172 .58823 L p .707 .577 .707 r
F P
0 g
s
.37422 .51601 m .36075 .5713 L .3321 .56663 L p .707 .577 .707 r
F P
0 g
s
.43546 .53128 m .42199 .58656 L .39173 .57816 L p .707 .577 .707 r
F P
0 g
s
.39173 .57816 m .40519 .52288 L .43546 .53128 L p .707 .577 .707 r
F P
0 g
s
.36075 .5713 m .37422 .51601 L .40519 .52288 L p .707 .577 .707 r
F P
0 g
s
.36172 .58823 m .3535 .62521 L .32994 .62388 L p .707 .577 .707 r
F P
0 g
s
.44809 .62894 m .4541 .64572 L .42811 .64702 L p .707 .577 .707 r
F P
0 g
s
.42811 .64702 m .4221 .63024 L .44809 .62894 L p .707 .577 .707 r
F P
0 g
s
.40519 .52288 m .39173 .57816 L .36075 .5713 L p .707 .577 .707 r
F P
0 g
s
.31734 .69189 m .31133 .67512 L .33429 .65989 L p .707 .577 .707 r
F P
0 g
s
.47878 .61493 m .47055 .6519 L .44378 .6432 L p .707 .577 .707 r
F P
0 g
s
.44378 .6432 m .452 .60622 L .47878 .61493 L p .707 .577 .707 r
F P
0 g
s
.33429 .65989 m .3403 .67666 L .31734 .69189 L p .707 .577 .707 r
F P
0 g
s
.3535 .62521 m .36172 .58823 L .39046 .59219 L p .707 .577 .707 r
F P
0 g
s
.4221 .63024 m .42811 .64702 L .39853 .65307 L p .707 .577 .707 r
F P
0 g
s
.39853 .65307 m .39252 .6363 L .4221 .63024 L p .707 .577 .707 r
F P
0 g
s
.39046 .59219 m .38224 .62916 L .3535 .62521 L p .707 .577 .707 r
F P
0 g
s
.3403 .67666 m .33429 .65989 L .36227 .64651 L p .707 .577 .707 r
F P
0 g
s
.452 .60622 m .44378 .6432 L .41335 .63536 L p .707 .577 .707 r
F P
0 g
s
.41335 .63536 m .42157 .59839 L .452 .60622 L p .707 .577 .707 r
F P
0 g
s
.38224 .62916 m .39046 .59219 L .42157 .59839 L p .707 .577 .707 r
F P
0 g
s
.39252 .6363 m .39853 .65307 L .36828 .66329 L p .707 .577 .707 r
F P
0 g
s
.36828 .66329 m .36227 .64651 L .39252 .6363 L p .707 .577 .707 r
F P
0 g
s
.36227 .64651 m .36828 .66329 L .3403 .67666 L p .707 .577 .707 r
F P
0 g
s
.42157 .59839 m .41335 .63536 L .38224 .62916 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001gOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`D0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH025YF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00MJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01eYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Uoo`H000Ioo`04001JEUYF0006FUH00`00
FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`<0009JEP04001JEUYFFUH70002FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Aoo`<000=JEP03
001JEUYF00EJEP04001JEUYFFUH70002FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000QJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo06Aoo`00E7oo0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<0
05YFFUH01EYF100015YF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001COol00`00FUH00004FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH01000FUH000000UYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol03goo3`00AWoo001COol00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH3000:FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`09Ool60003FUH00`00FUIJEP06FUH00`00
FUIJEP040012Ool005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP<000MJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP@003ioo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01eYF00<005YFFUH01UYF00<005YF00000`000eYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol00goo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000003aoo`00Dgoo0P0015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF1000
35YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
0Woo0P001UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00@005YFFUIJEP8003Yo
o`00DWoo00<005YF00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF0`002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<007ooOol00P0000=JEP00FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01eYF00<005YFFUH00eYF0P00>7oo001BOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007oo0000
0eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1EYF0`00=Woo001BOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20007FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEP00=Goo001BOol00`00
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH30005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH01000FUIJEUYF0P00<goo001BOol00eYF001JEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0<7oo001AOol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH01@00FUIJEUYF000015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2000aOol0055oo`03001JEP0000L000=JEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00AJEP06
001JEUYF001JEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJ
EP8000AJEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00EJEP03001JEUYF00=JEP03001JEP00031oo`00DGoo0P000eYF00<005YFFUH00UYF1`0015YF
00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUH005YF
0003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF0P0015YF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<0
05YFFUH015YF00@005YFFUH002moo`00DGoo00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH0
0eYF1`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00D005YFFUIJEP0000EJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH00`00FUIJ
EP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP04FUH01@00FUIJEUYF0000;Woo001AOol00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000
FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80
00=JEP03001JEUYF00AJEP03001JEUYF009JEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF00AJEP05001JEUYFFUH0000^Ool0059oo`800003FUH005YF00EJEP03001JEUYF00EJEP03
001JEUYF00IJEP@000MJEP03001JEUYF00EJEP03001JEUYF00AJEP06001JEUYF001JEP0015YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP03
FUH60008Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF0000;Woo001DOol2
0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH01000FUIJEUYF10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00H005YFFUH005YF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01P00FUIJEP00FUH000=JEP03001JEP0000<001Moo`H000IJEP03001JEUYF00=JEP03001JEUYF
009JEP8002eoo`00EWoo0P000eYF00<005YFFUH01P002EYF00<005YFFUH01EYF10001eYF00<005YF
FUH00eYF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06
001JEUYF001JEP000eYF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0000]Ool0
05Qoo`800004FUH000000002FUH00`00FUIJEP070002FUH00`00FUIJEP06FUH01000FUIJEUYF0P00
15YF00<005YFFUH015YF00@005YFFUIJEP8000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF008000=JEP03001oogoo02=oo`<00003FUH005YF00AJEP07001JEUYFFUH0
05YF0000;Goo001IOol30003FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YFFUH00eYF
0`0000=JEP00FUH01EYF00H005YFFUH005YF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02000015YF00000000:7oo0P001EYF00L005YFFUIJEP00FUH0000]Ool0
05Uoo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00D000QJEP<000EJ
EP06001JEUYF001JEP001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00`000eYF00<007ooOol057oo0`0047oo0P000eYF00L005YFFUIJEP00FUH0000]Ool005Uoo`80
00AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00AJEPD000=JEP04001JEUYFFUH30000
0eYF001JEP02FUH20006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJ
EUYF000015YF0`004goo1@004Goo00@005YFFUH000=JEP03001JEP0002eoo`00F7oo00<005YF0000
15YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH010001EYF0`000eYF
0P001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF00000P0015YF00<0
05YFFUH00P004Goo1@004Woo0`000eYF0P00;Woo001HOol00`00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH400002EYF001JEUYF001JEP00FUH00006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH000020004FUH00`00FUIJ
EP02FUH3000>Ool5000DOol01000FUIJEUYF0P00;Woo001HOol00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH0000300001EYF000005YF
00001UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YF001JEP0000=JEP03
001JEUYF00AJEP04001JEP000005Ool@000@Ool2000015YF001JEP00;Woo001HOol00`00FUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH40007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUH005YF00000eYF
00<005YFFUH015YF00<005YFFUH01P0015YF00<005YFFUH01UYF00<005YFFUH010002Woo0P0000IJ
EP00FUH005YF000^Ool005Qoo`8000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEP0000EJEP03001JEUYF00AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00AJEP@000Aoo`800004FUH005YFFUH200000eYF001oo`0]Ool005Moo`03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJ
EP04001JEUYFFUH20004FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUH0
0005FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUH000030003FUH01`00FUIJEUYF001JEP0002ioo`00D7oo200000=JEP0000003@0015YF00<0
05YFFUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0000aJ
EP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0004FUH01000FUIJEUYF0P001EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YFFUIJEP8000=JEP07001JEUYFFUH005YF
0000;Woo0017Ool90004FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP03FUH70006
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH300000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH01000FUIJEP0015YF00H005YF000005YF0005FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP03FUH200000eYF001JEP02FUH2000_Ool003Mo
oa0000AJEP03001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH01000
FUIJEUYF1@000UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P00
35YF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP0000=JEP8000=JEP03001JEUYF009J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP8002mo
o`00<Goo1P000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP00
00=JEP03001JEUYF00=JEP03001JEUYF00EJEP04001JEUYFFUH:0006FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH01000FUH0000015YF00<005YFFUH00UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01EYF00@005YFFUH0009JEP8002moo`00;Woo0`000UYF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1UYF00<005YFFUH01EYF100000=JEP00FUH01eYF10000UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00UYF0P002eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF
000000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00EJEP04001JEUYFFUH4000_Ool002aoo`<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEP8000IJEP03001JEUYF00=JEP<000EJEP03
001JEUYF00EJEP04001JEUYFFUH40006FUH00`00FUIJEP03FUH01`00FUIJEUYF001JEP0000]JEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP@000=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001oogoo
02ioo`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF0P0025YF00<005YFFUH01UYF00<0
05YFFUH00UYF100015YF00<005YFFUH00eYF00D005YFFUIJEP0000eJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00=JEP03001JEUYF009JEQ00
00IJEP03001JEUYF00AJEP03001JEUYF00AJEP8002moo`00;7oo00<005YF000015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF100000AJEP00
FUIJEP<000YJEP03001JEUYF009JEPP000AJEP800003FUH005YF00EJEP04001JEUYFFUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP02
FUH60007FUH00`00FUIJEP06FUH40002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH00`00FUH0000^
Ool002aoo`03001JEP0000EJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00@000=JEP03001JEUYF00IJEPH000EJEP03001JEUYF
00EJEP@000AJEP03001JEUYF009JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP<000AJEP03001JEP00008000AJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH4
0005FUH00`00FUIJEP04FUH01000FUIJEP00;Goo000/Ool01000FUIJEP0015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P00
1EYF00<005YFFUH00eYF0`000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEP<00003
FUH005YF00=JEP8000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP80
00MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP@00003FUH005YF00EJEP05001J
EUYFFUH0000/Ool002eoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000QJEP03001JEP00008000EJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP@000AJEP8000aJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP<0009JEP800003FUH0000000IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP04001JEUYFFUH20005FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol002eo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP<000QJEPD000AJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH0
0002FUH00`00FUH00002FUH3000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH5
0005FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2
0003FUH00`00FUIJEP02FUH00`00Oomoo`0ZOol002eoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80009JEP03001JEUYF
00AJEP<000AJEP<00003FUH005YF00MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUIJ
EP05000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUH000001UYF00<0
05YF00000P0000=JEP00FUH01UYF00<005YFFUH00`000eYF00<005YFFUH01UYF00@005YFFUIJEP80
009oo`04001JEUYF0004FUH2000[Ool002eoo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF008000EJEP04001JEUYFFUH20002FUH0
0`00FUIJEP04FUH70004FUH00`00FUIJEP06FUH00`00FUIJEP020002FUH01000FUIJEUYF0P0000=J
EP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF
00<005YFFUH00UYF1@0015YF00<005YF000010000UYF00<005YFFUH01UYF00@005YF000000Eoo`<0
00AJEP8002]oo`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01UYF00<005YF00001eYF00H005YF000005YF0002FUH00`00FUIJEP04FUH00`00
FUIJEP04FUH60006FUH02000FUIJEP00FUH005YF0004FUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJEP03FUH00`00FUIJEP02FUH00`00
FUIJEP0<0002FUH00`00FUIJEP02FUH60009Ool01`00FUIJEUYF001JEP0002]oo`00;Goo00<005YF
000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`001eYF
1P000UYF00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH010000UYF00<005YF00000eYF0P00
0eYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
05YF00000eYF20000UYF00@005YFFUH000Ioo``0011oo`06001JEUYF001JEP00:goo000]Ool00`00
FUH00005FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH50002
FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP04FUH30007FUH00`00FUIJEP04FUH40004FUH60003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH30002
FUH00`00FUIJEP030002FUH00`00Oomoo`05Ool3000IOol01@00FUH005YF0000:goo000]Ool01000
FUIJEP0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2P000eYF00@005YFFUH0
00=JEP03001oogoo00Eoo`04001JEUYF0005FUH50006FUH00`00FUIJEP06FUH00`00FUIJEP03FUH0
0`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
0004FUH01P00FUIJEP00FUH000EJEP04001JEP00000SOol200000eYF001oo`0ZOol002ioo`9JEP03
001JEUYF009JEP03001JEUYF00=JEP03001JEUYF009JEPX000AJEPP000AJEP<000Qoo`04001JEUYF
0005FUH50006FUH00`00FUIJEP04FUH30004FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF0P001EYF10008Woo1000
;7oo000^Ool2FUH00`00FUIJEP02FUH01000FUIJEUYF200015YF2@001Woo00<005YFFUH00eYF00<0
07ooOol027oo00@005YFFUH000EJEPD000IJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02FUH00`00FUIJEP03FUH20003FUH01000FUIJEP0087oo0P000UYF0P00;7oo000^Ool2FUH:
0003FUH80009Ool70004FUH=0002FUH00`00FUIJEP04FUH30007FUH01000FUIJEUYF0P0015YF00<0
05YF00002eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF00D0
05YFFUIJEP0000IJEP04001JEP000002FUH00`00FUH0000OOol00`00FUIJEP02FUH2000/Ool002io
o`l000Qoo`T000AJEP<000=JEP03001JEP0000EJEP03001JEUYF00<0009JEP03001JEUYF00AJEP03
001JEUYF00MJEP04001JEUYF0007FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF00001UYF00@005YFFUIJEP<0009JEP03001o
ogoo01Ioo`X00003FUH0000002aoo`00?Goo200015YF00<005YFFUH01UYF00H005YFFUH005YF0002
FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04FUH00`00FUIJEP07FUH40005FUH3
000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJ
EP001UYF00<005YFFUH00eYF1P0027oo3P000eYF100000IJEP00000005YF000/Ool003Eoo`P000=J
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF008000=JEP03001JEUYF00=JEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEUYF00IJEP80009JEP03001JEUYF009JEP04001JEUYF000<
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUH00006
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH80002FUH00`00FUIJEP05FUH00`00FUH000040002FUH0
0`00FUIJEP0300000eYF001oo`0[Ool002moo`H000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP04001JEUYF0004FUH00`00FUIJEP03FUH00`00FUIJEP030002FUH00`00FUIJEP04
FUH00`00FUIJEP04FUH20005FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001EYF00<005YFFUH01EYF00<005YF0000
1P001UYF00<005YFFUH00eYF100000=JEP00FUH015YF00D005YFFUH005YF008002eoo`00:Woo1@00
0UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
1EYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH015YF00@005YFFUIJEP<000MJEP<0
00AJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP00009JEP03001JEUYF00=JEP03001JEP0000L000AJEP03001JEUYF00EJEPL000EJ
EP03001JEUYF00=JEP04001JEUYFFUH3000]Ool002Yoo`03001JEP0000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000IJEP03001JEUYF00=JEP03001JEUYF
0080009JEP03001JEUYF00AJEP@00003FUH005YF00IJEP8000IJEP03001JEUYF00YJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000=JEPL000=JEP03
001JEUYF00EJEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000^Ool002Yo
o`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP8000MJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF009JEP<000AJEP03001JEUYF
00=JEP8000QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEPH0009JEP03001JEUYF00EJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEPL002ioo`00:Woo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF0`001EYF00<005YFFUH00eYF00<005YFFUH00P000UYF1@0025YF
00<005YF00000P002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00@005YFFUIJEP800003FUH005YF00AJEPP000=JEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEP0000800004FUH005YFFUH2000_Ool002Yoo`03001JEP0000AJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00<0009JEP03
001JEUYF009JEPP000=JEP03001JEUYF00IJEP<0009JEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00X000=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYFFUH50004FUH3000aOol002Yoo`03001JEP00
00EJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP800004FUH0
05YFFUH70003FUH00`00FUIJEP06FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP08FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03
001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001JEUYF
009JEP8003=oo`00:goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH00UYF1P0000=JEP00FUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH00`001eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH90002FUH00`00FUIJEP06FUH00`00FUH00002000eOol002]oo`03001JEP0000AJEP03001JEUYF
00AJEP03001JEUYF00EJEP03001JEUYF009JEP`0009JEP@000AJEP03001JEUYF00EJEP03001JEUYF
00AJEPD000UJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH00UYF20000UYF00<0
05YFFUH01UYF00<005YFFUH00UYF1P00>7oo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00
FUIJEP02FUH90008FUH00`00FUIJEP04000015YF000000000UYF00<005YFFUH01EYF00<005YFFUH0
100015YF00<005YFFUH01eYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00H005YFFUH005YF0004FUH01000FUIJEUYF200027oo4000?Woo000[
Ool00`00FUH00004FUH01000FUIJEUYF2@001eYF00<005YFFUH01UYF00<005YFFUH00UYF10000UYF
3@0000=JEP00FUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF5P001UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH02`0000EJEP00FUIJEP0005Uoo`00:goo00<005YF00000UYF1`001eYF
00<005YFFUH00UYF4@0017oo0`0000=JEP00FUH00eYF0P000Woo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00H000QJEP03001JEUYF00YJEPX000QJEP03001JEUYF00EJEP03001JEUYF009J
EP@000=oo`@0009JEP03001oogoo05Moo`00:goo1@0000=JEP0000000eYF00<005YFFUH00UYF2000
67oo0P001UYF00<007oo00000UYF00<005YFFUH015YF00<005YFFUH01EYF1@000UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH01eYF1P000UYF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol017oo0P000UYF0P0000=JEP00Ool0Egoo000/Ool?000ROol00`00FUIJEP03FUH30002FUH0
0`00FUIJEP04FUH00`00FUIJEP050007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP07
FUH00`00FUH00003FUH40006FUH00`00FUIJEP02FUH00`00Oomoo`03Ool00`00FUIJEP02FUH01000
FUH00000F7oo000^Ool2000^Ool00`00FUIJEP02FUH00`00FUH00002FUH00`00FUIJEP03FUH40000
0eYF001JEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP05FUH2
0004FUH00`00FUIJEP02FUH01000Oomoogoo0`0015YF00@005YFFUH005Qoo`00;Woo00<007ooOol0
;Woo0P0000EJEP00FUIJEP00009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH300000eYF001JEP03FUH01000Ool0
00000UYF00<005YFFUH00UYF00D005YFFUIJEP0005Moo`00;Goo0P00<Woo0P000UYF00D005YFFUH0
05YF008000MJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00MJEP03001JEUYF008000AJEP8000EJEP03001JEUYF009JEP04001JEUYF001GOol002eo
o`03001JEP00039oo`04001JEUYF0002FUH30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP04
FUH00`00FUIJEP02FUH00`00FUH0001HOol002eoo`03001JEP0001Qoo`<001Qoo`05001JEP00FUH0
0002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH40006FUH00`00FUIJEP02FUH00`00FUH0001HOol0
02eoo`03001JEP0001Moo`D001Qoo`<000=JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP04001JEUYF
0006FUH00`00FUIJEP03FUH00`00Oomoo`1GOol002eoo`04001JEP00000FOol5000HOol30003FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH01000FUIJEP001UYF00<005YFFUH00eYF00<007ooOol0Egoo
000]Ool01@00FUH005YF00005Goo1@006Goo0P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00@0
05YFFUH000MJEP03001JEUYF008005Yoo`00;Woo00@005YFFUH001Ioo`<001Yoo`8000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP04001JEUYF0007FUH3001LOol002ioo`05001JEUYFFUH0000cOol0
1@00FUIJEUYF000025YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000MJEP03001oogoo05aoo`00;Woo00<0
05YFFUH00UYF00<007ooOol0<7oo00D005YFFUIJEP0000QJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP800003FUH005YF
00AJEP8005moo`00;goo00@005YFFUIJEP80039oo`04001JEUYF0008FUH00`00FUIJEP08FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20002
FUH00`00FUIJEP02001QOol0031oo`06001JEUYF001JEP00<7oo1@0025YF00<005YFFUH025YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00UYF0P00
00=JEP0000000`00Hgoo000`Ool00`00FUH00003FUH2000^Ool20002Ool20007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH00002
0006FUH3001ROol0035oo`8000EJEP03001oogoo02Yoo`<000Aoo`<000AJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP<000YJEP04001JEP00
001POol0039oo`03001JEUYF00AJEP8002Qoo`800003FUH007oo00Moo`<00003FUH005YF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEPL000QJEP03001JEUYF
009JEP8005ioo`00<goo0P0015YF00@005YF000002Eoo`03001JEUYF008000]oo`L000EJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEP0000d000EJEP03001JEUYF00AJEP80
05aoo`00=Goo00@005YFFUH000AJEP80025oo`8000=JEP03001oogoo015oo`/000IJEP03001JEUYF
00YJEP03001JEUYF00AJEPL000AJEPH000Aoo`<00003FUH005YF00MJEP<005Yoo`00=Woo0`001UYF
10006goo0P0000=JEP00FUH00UYF00<007ooOol077oo7@0000=JEP00FUH01EYF1@0000=JEP000000
0P000goo0`001UYF00@005YFFUIJEP8005Qoo`00>7oo00<005YFFUH01EYF00<005YFFUH010005Goo
0P000UYF00<005YFFUH00P00;Woo4@001UYF0`001UYF10000Woo0P0015YF00<005YFFUH00eYF0P00
EWoo000iOol20005FUH00`00FUIJEP04FUH70009Ool50004FUH30011Ool20005FUH00`00FUIJEP07
FUH00`00FUH0000500000eYF001JEP06FUH3001DOol003]oo`8000=JEP03001JEUYF00IJEP03001J
EUYF009JEPT000=JEP03001JEUYF00=JEP03001oogoo04=oo`<00003FUH005YF00QJEP03001JEUYF
00AJEP@000IJEP05001JEUYFFUH0001COol003eoo`800003FUH005YF00MJEP03001JEUYF00IJEP03
001JEUYF00EJEP04001JEUYFFUH20019Ool30008FUH00`00FUIJEP06FUH01000FUH0000015YF00D0
05YFFUIJEP0005=oo`00?goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000004io
o`<000EJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEP00059oo`00
@Woo10000UYF00<005YFFUH01UYF00<005YFFUH00UYF1P00Dgoo0`0000=JEP00FUH01eYF00<005YF
FUH015YF0P000eYF00<005YF0000DWoo0016Ool@001LOol30007FUH00`00FUIJEP04FUH00`00FUH0
000200000eYF001oo`1BOol00;Eoo`@0009JEP03001JEUYF00AJEP03001JEUYF009JEP03001JEP00
05=oo`00^Goo1P000eYF00@005YFFUIJEP<005Aoo`00_goo2P00E7oo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58344 .73835 m .59692 .68307 L .56662 .67468 L p .707 .577 .707 r
F P
0 g
s
.59692 .68307 m .58344 .73835 L .6144 .74521 L p .707 .577 .707 r
F P
0 g
s
.6144 .74521 m .62788 .68992 L .59692 .68307 L p .707 .577 .707 r
F P
0 g
s
.62788 .68992 m .6144 .74521 L .643 .74985 L p .707 .577 .707 r
F P
0 g
s
.643 .74985 m .65648 .69457 L .62788 .68992 L p .707 .577 .707 r
F P
0 g
s
.55314 .72996 m .56662 .67468 L .53997 .66557 L p .707 .577 .707 r
F P
0 g
s
.56662 .67468 m .55314 .72996 L .58344 .73835 L p .707 .577 .707 r
F P
0 g
s
.53997 .66557 m .52648 .72086 L .55314 .72996 L p .707 .577 .707 r
F P
0 g
s
.65648 .69457 m .643 .74985 L .66643 .75184 L p .707 .577 .707 r
F P
0 g
s
.66643 .75184 m .67992 .69655 L .65648 .69457 L p .707 .577 .707 r
F P
0 g
s
.52648 .72086 m .53997 .66557 L .51955 .65665 L p .707 .577 .707 r
F P
0 g
s
.60515 .7976 m .61337 .76063 L .58295 .75279 L p .707 .577 .707 r
F P
0 g
s
.61337 .76063 m .60515 .7976 L .63627 .80381 L p .707 .577 .707 r
F P
0 g
s
.63627 .80381 m .64449 .76684 L .61337 .76063 L p .707 .577 .707 r
F P
0 g
s
.51955 .65665 m .50607 .71193 L .52648 .72086 L p .707 .577 .707 r
F P
0 g
s
.64449 .76684 m .63627 .80381 L .66503 .80777 L p .707 .577 .707 r
F P
0 g
s
.66503 .80777 m .67325 .7708 L .64449 .76684 L p .707 .577 .707 r
F P
0 g
s
.57473 .78976 m .58295 .75279 L .5562 .74409 L p .707 .577 .707 r
F P
0 g
s
.58295 .75279 m .57473 .78976 L .60515 .7976 L p .707 .577 .707 r
F P
0 g
s
.67992 .69655 m .66643 .75184 L .68242 .75097 L p .707 .577 .707 r
F P
0 g
s
.68242 .75097 m .6959 .69569 L .67992 .69655 L p .707 .577 .707 r
F P
0 g
s
.62009 .85686 m .61409 .84008 L .58381 .85021 L p .707 .577 .707 r
F P
0 g
s
.61409 .84008 m .62009 .85686 L .64814 .84356 L p .707 .577 .707 r
F P
0 g
s
.64814 .84356 m .64214 .82677 L .61409 .84008 L p .707 .577 .707 r
F P
0 g
s
.5562 .74409 m .54798 .78106 L .57473 .78976 L p .707 .577 .707 r
F P
0 g
s
.58981 .86699 m .58381 .85021 L .55428 .85618 L p .707 .577 .707 r
F P
0 g
s
.58381 .85021 m .58981 .86699 L .62009 .85686 L p .707 .577 .707 r
F P
0 g
s
.50607 .71193 m .51955 .65665 L .50738 .64877 L p .707 .577 .707 r
F P
0 g
s
.67325 .7708 m .66503 .80777 L .68862 .80911 L p .707 .577 .707 r
F P
0 g
s
.68862 .80911 m .69684 .77214 L .67325 .7708 L p .707 .577 .707 r
F P
0 g
s
.64214 .82677 m .64814 .84356 L .67122 .82838 L p .707 .577 .707 r
F P
0 g
s
.67122 .82838 m .66522 .8116 L .64214 .82677 L p .707 .577 .707 r
F P
0 g
s
.55428 .85618 m .56028 .87296 L .58981 .86699 L p .707 .577 .707 r
F P
0 g
s
.54798 .78106 m .5562 .74409 L .53574 .73537 L p .707 .577 .707 r
F P
0 g
s
.56028 .87296 m .55428 .85618 L .52837 .85739 L p .707 .577 .707 r
F P
0 g
s
.50738 .64877 m .4939 .70406 L .50607 .71193 L p .707 .577 .707 r
F P
0 g
s
.53574 .73537 m .52752 .77234 L .54798 .78106 L p .707 .577 .707 r
F P
0 g
s
.52837 .85739 m .53437 .87418 L .56028 .87296 L p .707 .577 .707 r
F P
0 g
s
.66522 .8116 m .67122 .82838 L .68707 .81282 L p .707 .577 .707 r
F P
0 g
s
.68707 .81282 m .68107 .79604 L .66522 .8116 L p .707 .577 .707 r
F P
0 g
s
.6959 .69569 m .68242 .75097 L .68938 .74733 L p .707 .577 .707 r
F P
0 g
s
.68938 .74733 m .70286 .69205 L .6959 .69569 L p .707 .577 .707 r
F P
0 g
s
.69684 .77214 m .68862 .80911 L .70474 .80768 L p .707 .577 .707 r
F P
0 g
s
.70474 .80768 m .71296 .77071 L .69684 .77214 L p .707 .577 .707 r
F P
0 g
s
.53437 .87418 m .52837 .85739 L .50863 .85374 L p .707 .577 .707 r
F P
0 g
s
.4939 .70406 m .50738 .64877 L .50464 .64272 L p .707 .577 .707 r
F P
0 g
s
.52752 .77234 m .53574 .73537 L .52358 .72749 L p .707 .577 .707 r
F P
0 g
s
.50863 .85374 m .51463 .87053 L .53437 .87418 L p .707 .577 .707 r
F P
0 g
s
.52358 .72749 m .51536 .76446 L .52752 .77234 L p .707 .577 .707 r
F P
0 g
s
.50464 .64272 m .49116 .69801 L .4939 .70406 L p .707 .577 .707 r
F P
0 g
s
.68107 .79604 m .68707 .81282 L .69415 .7984 L p .707 .577 .707 r
F P
0 g
s
.69415 .7984 m .68815 .78161 L .68107 .79604 L p .707 .577 .707 r
F P
0 g
s
.71296 .77071 m .70474 .80768 L .7118 .80364 L p .707 .577 .707 r
F P
0 g
s
.7118 .80364 m .72002 .76667 L .71296 .77071 L p .707 .577 .707 r
F P
0 g
s
.51463 .87053 m .50863 .85374 L .49699 .84558 L p .707 .577 .707 r
F P
0 g
s
.70286 .69205 m .68938 .74733 L .68664 .74128 L p .707 .577 .707 r
F P
0 g
s
.68664 .74128 m .70012 .68599 L .70286 .69205 L p .707 .577 .707 r
F P
0 g
s
.51536 .76446 m .52358 .72749 L .52089 .72122 L p .707 .577 .707 r
F P
0 g
s
.49699 .84558 m .50299 .86237 L .51463 .87053 L p .707 .577 .707 r
F P
0 g
s
.49116 .69801 m .50464 .64272 L .5116 .63908 L p .707 .577 .707 r
F P
0 g
s
.5116 .63908 m .49812 .69437 L .49116 .69801 L p .707 .577 .707 r
F P
0 g
s
.49351 .82188 m .49351 .32 L .4493 .31756 L p .707 .577 .707 r
F P
0 g
s
.52089 .72122 m .51267 .75819 L .51536 .76446 L p .707 .577 .707 r
F P
0 g
s
.51267 .75819 m .52089 .72122 L .52795 .71717 L p .707 .577 .707 r
F P
0 g
s
.49812 .69437 m .5116 .63908 L .52759 .63821 L p .707 .577 .707 r
F P
0 g
s
.52795 .71717 m .51973 .75415 L .51267 .75819 L p .707 .577 .707 r
F P
0 g
s
.52759 .63821 m .5141 .6935 L .49812 .69437 L p .707 .577 .707 r
F P
0 g
s
.50059 .8505 m .49459 .83371 L .50166 .81929 L p .707 .577 .707 r
F P
0 g
s
.50166 .81929 m .50766 .83607 L .50059 .8505 L p .707 .577 .707 r
F P
0 g
s
.5141 .6935 m .52759 .63821 L .55102 .6402 L p .707 .577 .707 r
F P
0 g
s
.51973 .75415 m .52795 .71717 L .54407 .71575 L p .707 .577 .707 r
F P
0 g
s
.54407 .71575 m .53585 .75272 L .51973 .75415 L p .707 .577 .707 r
F P
0 g
s
.55102 .6402 m .53754 .69549 L .5141 .6935 L p .707 .577 .707 r
F P
0 g
s
.50766 .83607 m .50166 .81929 L .51751 .80373 L p .707 .577 .707 r
F P
0 g
s
.51751 .80373 m .52351 .82051 L .50766 .83607 L p .707 .577 .707 r
F P
0 g
s
.52351 .82051 m .51751 .80373 L .54059 .78855 L p .707 .577 .707 r
F P
0 g
s
.54059 .78855 m .54659 .80534 L .52351 .82051 L p .707 .577 .707 r
F P
0 g
s
.49351 .32 m .49351 .82188 L .53836 .82053 L p .707 .577 .707 r
F P
0 g
s
.53754 .69549 m .55102 .6402 L .57962 .64485 L p .707 .577 .707 r
F P
0 g
s
.53585 .75272 m .54407 .71575 L .56766 .71709 L p .707 .577 .707 r
F P
0 g
s
.57962 .64485 m .56614 .70013 L .53754 .69549 L p .707 .577 .707 r
F P
0 g
s
.56766 .71709 m .55944 .75406 L .53585 .75272 L p .707 .577 .707 r
F P
0 g
s
.53836 .82053 m .53836 .31864 L .49351 .32 L p .707 .577 .707 r
F P
0 g
s
.56614 .70013 m .57962 .64485 L .61058 .6517 L p .707 .577 .707 r
F P
0 g
s
.61058 .6517 m .5971 .70699 L .56614 .70013 L p .707 .577 .707 r
F P
0 g
s
.55944 .75406 m .56766 .71709 L .59642 .72105 L p .707 .577 .707 r
F P
0 g
s
.59642 .72105 m .5882 .75802 L .55944 .75406 L p .707 .577 .707 r
F P
0 g
s
.54659 .80534 m .54059 .78855 L .56864 .77525 L p .707 .577 .707 r
F P
0 g
s
.59892 .76512 m .60492 .7819 L .57464 .79203 L p .707 .577 .707 r
F P
0 g
s
.57464 .79203 m .56864 .77525 L .59892 .76512 L p .707 .577 .707 r
F P
0 g
s
.56864 .77525 m .57464 .79203 L .54659 .80534 L p .707 .577 .707 r
F P
0 g
s
.53836 .31864 m .53836 .82053 L .57945 .81552 L p .707 .577 .707 r
F P
0 g
s
.57945 .81552 m .57945 .31363 L .53836 .31864 L p .707 .577 .707 r
F P
0 g
s
.4493 .81945 m .4493 .31756 L .41005 .31159 L p .707 .577 .707 r
F P
0 g
s
.4493 .31756 m .4493 .81945 L .49351 .82188 L p .707 .577 .707 r
F P
0 g
s
.68815 .78161 m .69415 .7984 L .69174 .78653 L p .707 .577 .707 r
F P
0 g
s
.69174 .78653 m .68574 .76974 L .68815 .78161 L p .707 .577 .707 r
F P
0 g
s
.50299 .86237 m .49699 .84558 L .49459 .83371 L p .707 .577 .707 r
F P
0 g
s
.64088 .66009 m .6274 .71538 L .5971 .70699 L p .707 .577 .707 r
F P
0 g
s
.5971 .70699 m .61058 .6517 L .64088 .66009 L p .707 .577 .707 r
F P
0 g
s
.62846 .75915 m .63446 .77593 L .60492 .7819 L p .707 .577 .707 r
F P
0 g
s
.60492 .7819 m .59892 .76512 L .62846 .75915 L p .707 .577 .707 r
F P
0 g
s
.5882 .75802 m .59642 .72105 L .62754 .72726 L p .707 .577 .707 r
F P
0 g
s
.62754 .72726 m .61932 .76423 L .5882 .75802 L p .707 .577 .707 r
F P
0 g
s
.57945 .31363 m .57945 .81552 L .61276 .80735 L p .707 .577 .707 r
F P
0 g
s
.61276 .80735 m .61276 .30547 L .57945 .31363 L p .707 .577 .707 r
F P
0 g
s
.72002 .76667 m .7118 .80364 L .70911 .79737 L p .707 .577 .707 r
F P
0 g
s
.70911 .79737 m .71733 .7604 L .72002 .76667 L p .707 .577 .707 r
F P
0 g
s
.70012 .68599 m .68664 .74128 L .67447 .73341 L p .707 .577 .707 r
F P
0 g
s
.67447 .73341 m .68795 .67812 L .70012 .68599 L p .707 .577 .707 r
F P
0 g
s
.49459 .83371 m .50059 .8505 L .50299 .86237 L p .707 .577 .707 r
F P
0 g
s
.41005 .81348 m .41005 .31159 L .37961 .30265 L p .707 .577 .707 r
F P
0 g
s
.41005 .31159 m .41005 .81348 L .4493 .81945 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.24836 .72999 m .25423 .6798 L .22318 .67368 L p .707 .577 .707 r
F P
0 g
s
.25423 .6798 m .24836 .72999 L .28001 .73131 L p .707 .577 .707 r
F P
0 g
s
.28001 .73131 m .28588 .68112 L .25423 .6798 L p .707 .577 .707 r
F P
0 g
s
.68574 .76974 m .69174 .78653 L .6801 .77837 L p .707 .577 .707 r
F P
0 g
s
.6801 .77837 m .6741 .76158 L .68574 .76974 L p .707 .577 .707 r
F P
0 g
s
.28588 .68112 m .28001 .73131 L .30916 .72772 L p .707 .577 .707 r
F P
0 g
s
.30916 .72772 m .31503 .67753 L .28588 .68112 L p .707 .577 .707 r
F P
0 g
s
.2173 .72387 m .22318 .67368 L .19576 .66337 L p .707 .577 .707 r
F P
0 g
s
.22318 .67368 m .2173 .72387 L .24836 .72999 L p .707 .577 .707 r
F P
0 g
s
.25743 .79487 m .26099 .76102 L .22994 .75519 L p .707 .577 .707 r
F P
0 g
s
.26099 .76102 m .25743 .79487 L .28912 .79608 L p .707 .577 .707 r
F P
0 g
s
.28912 .79608 m .29268 .76223 L .26099 .76102 L p .707 .577 .707 r
F P
0 g
s
.29268 .76223 m .28912 .79608 L .31833 .79255 L p .707 .577 .707 r
F P
0 g
s
.31833 .79255 m .3219 .7587 L .29268 .76223 L p .707 .577 .707 r
F P
0 g
s
.22637 .78904 m .22994 .75519 L .20255 .74531 L p .707 .577 .707 r
F P
0 g
s
.22994 .75519 m .22637 .78904 L .25743 .79487 L p .707 .577 .707 r
F P
0 g
s
.66753 .66919 m .65405 .72448 L .6274 .71538 L p .707 .577 .707 r
F P
0 g
s
.6274 .71538 m .64088 .66009 L .66753 .66919 L p .707 .577 .707 r
F P
0 g
s
.63446 .77593 m .62846 .75915 L .65436 .75793 L p .707 .577 .707 r
F P
0 g
s
.65436 .75793 m .66036 .77472 L .63446 .77593 L p .707 .577 .707 r
F P
0 g
s
.65796 .73509 m .64974 .77207 L .61932 .76423 L p .707 .577 .707 r
F P
0 g
s
.61932 .76423 m .62754 .72726 L .65796 .73509 L p .707 .577 .707 r
F P
0 g
s
.61276 .30547 m .61276 .80735 L .63504 .79682 L p .707 .577 .707 r
F P
0 g
s
.63504 .79682 m .63504 .29493 L .61276 .30547 L p .707 .577 .707 r
F P
0 g
s
.71733 .7604 m .70911 .79737 L .69695 .78949 L p .707 .577 .707 r
F P
0 g
s
.69695 .78949 m .70517 .75252 L .71733 .7604 L p .707 .577 .707 r
F P
0 g
s
.68795 .67812 m .67447 .73341 L .65405 .72448 L p .707 .577 .707 r
F P
0 g
s
.65405 .72448 m .66753 .66919 L .68795 .67812 L p .707 .577 .707 r
F P
0 g
s
.31503 .67753 m .30916 .72772 L .33295 .71955 L p .707 .577 .707 r
F P
0 g
s
.33295 .71955 m .33882 .66936 L .31503 .67753 L p .707 .577 .707 r
F P
0 g
s
.18988 .71356 m .19576 .66337 L .17465 .64988 L p .707 .577 .707 r
F P
0 g
s
.19576 .66337 m .18988 .71356 L .2173 .72387 L p .707 .577 .707 r
F P
0 g
s
.3219 .7587 m .31833 .79255 L .34222 .78463 L p .707 .577 .707 r
F P
0 g
s
.34222 .78463 m .34579 .75078 L .3219 .7587 L p .707 .577 .707 r
F P
0 g
s
.19898 .77916 m .20255 .74531 L .18151 .73236 L p .707 .577 .707 r
F P
0 g
s
.20255 .74531 m .19898 .77916 L .22637 .78904 L p .707 .577 .707 r
F P
0 g
s
.37961 .80454 m .37961 .30265 L .36095 .29162 L p .707 .577 .707 r
F P
0 g
s
.37961 .30265 m .37961 .80454 L .41005 .81348 L p .707 .577 .707 r
F P
0 g
s
.6741 .76158 m .6801 .77837 L .66036 .77472 L p .707 .577 .707 r
F P
0 g
s
.66036 .77472 m .65436 .75793 L .6741 .76158 L p .707 .577 .707 r
F P
0 g
s
.33882 .66936 m .33295 .71955 L .34905 .70762 L p .707 .577 .707 r
F P
0 g
s
.34905 .70762 m .35492 .65743 L .33882 .66936 L p .707 .577 .707 r
F P
0 g
s
.16878 .70007 m .17465 .64988 L .16193 .63453 L p .707 .577 .707 r
F P
0 g
s
.17465 .64988 m .16878 .70007 L .18988 .71356 L p .707 .577 .707 r
F P
0 g
s
.21782 .76727 m .22047 .7863 L .25138 .78171 L p .707 .577 .707 r
F P
0 g
s
.25138 .78171 m .24874 .76268 L .21782 .76727 L p .707 .577 .707 r
F P
0 g
s
.24874 .76268 m .25138 .78171 L .2829 .77748 L p .707 .577 .707 r
F P
0 g
s
.2829 .77748 m .28025 .75845 L .24874 .76268 L p .707 .577 .707 r
F P
0 g
s
.28025 .75845 m .2829 .77748 L .31193 .77403 L p .707 .577 .707 r
F P
0 g
s
.18151 .73236 m .17794 .76621 L .19898 .77916 L p .707 .577 .707 r
F P
0 g
s
.34579 .75078 m .34222 .78463 L .35844 .7731 L p .707 .577 .707 r
F P
0 g
s
.35844 .7731 m .36201 .73925 L .34579 .75078 L p .707 .577 .707 r
F P
0 g
s
.31193 .77403 m .30929 .755 L .28025 .75845 L p .707 .577 .707 r
F P
0 g
s
.17794 .76621 m .18151 .73236 L .16889 .71759 L p .707 .577 .707 r
F P
0 g
s
.70517 .75252 m .69695 .78949 L .67649 .78077 L p .707 .577 .707 r
F P
0 g
s
.67649 .78077 m .68471 .7438 L .70517 .75252 L p .707 .577 .707 r
F P
0 g
s
.19054 .77179 m .19318 .79082 L .22047 .7863 L p .707 .577 .707 r
F P
0 g
s
.22047 .7863 m .21782 .76727 L .19054 .77179 L p .707 .577 .707 r
F P
0 g
s
.63504 .29493 m .63504 .79682 L .6441 .78496 L p .707 .577 .707 r
F P
0 g
s
.6441 .78496 m .6441 .28307 L .63504 .29493 L p .707 .577 .707 r
F P
0 g
s
.30929 .755 m .31193 .77403 L .33565 .77171 L p .707 .577 .707 r
F P
0 g
s
.33565 .77171 m .33301 .75268 L .30929 .755 L p .707 .577 .707 r
F P
0 g
s
.16956 .77579 m .1722 .79482 L .19318 .79082 L p .707 .577 .707 r
F P
0 g
s
.19318 .79082 m .19054 .77179 L .16956 .77579 L p .707 .577 .707 r
F P
0 g
s
.16889 .71759 m .16532 .75144 L .17794 .76621 L p .707 .577 .707 r
F P
0 g
s
.35492 .65743 m .34905 .70762 L .35589 .69309 L p .707 .577 .707 r
F P
0 g
s
.35589 .69309 m .36177 .6429 L .35492 .65743 L p .707 .577 .707 r
F P
0 g
s
.15606 .68472 m .16193 .63453 L .15884 .61882 L p .707 .577 .707 r
F P
0 g
s
.16193 .63453 m .15606 .68472 L .16878 .70007 L p .707 .577 .707 r
F P
0 g
s
.36201 .73925 m .35844 .7731 L .3654 .75908 L p .707 .577 .707 r
F P
0 g
s
.36177 .6429 m .35589 .69309 L .3528 .67737 L p .707 .577 .707 r
F P
0 g
s
.3528 .67737 m .35868 .62718 L .36177 .6429 L p .707 .577 .707 r
F P
0 g
s
.3654 .75908 m .36897 .72523 L .36201 .73925 L p .707 .577 .707 r
F P
0 g
s
.36599 .71009 m .36242 .74394 L .3498 .72918 L p .707 .577 .707 r
F P
0 g
s
.3498 .72918 m .35336 .69533 L .36599 .71009 L p .707 .577 .707 r
F P
0 g
s
.36095 .79351 m .36095 .29162 L .3559 .27959 L p .707 .577 .707 r
F P
0 g
s
.36897 .72523 m .3654 .75908 L .36242 .74394 L p .707 .577 .707 r
F P
0 g
s
.36242 .74394 m .36599 .71009 L .36897 .72523 L p .707 .577 .707 r
F P
0 g
s
.36095 .29162 m .36095 .79351 L .37961 .80454 L p .707 .577 .707 r
F P
0 g
s
.68471 .7438 m .67649 .78077 L .64974 .77207 L p .707 .577 .707 r
F P
0 g
s
.64974 .77207 m .65796 .73509 L .68471 .7438 L p .707 .577 .707 r
F P
0 g
s
.16532 .75144 m .16889 .71759 L .16591 .70246 L p .707 .577 .707 r
F P
0 g
s
.33301 .75268 m .33565 .77171 L .35172 .77073 L p .707 .577 .707 r
F P
0 g
s
.35172 .77073 m .34908 .7517 L .33301 .75268 L p .707 .577 .707 r
F P
0 g
s
.15693 .77887 m .15957 .7979 L .1722 .79482 L p .707 .577 .707 r
F P
0 g
s
.1722 .79482 m .16956 .77579 L .15693 .77887 L p .707 .577 .707 r
F P
0 g
s
.16591 .70246 m .16234 .7363 L .16532 .75144 L p .707 .577 .707 r
F P
0 g
s
.15884 .61882 m .15297 .66901 L .15606 .68472 L p .707 .577 .707 r
F P
0 g
s
.15297 .66901 m .15884 .61882 L .16568 .60429 L p .707 .577 .707 r
F P
0 g
s
.6441 .28307 m .6441 .78496 L .63905 .77293 L p .707 .577 .707 r
F P
0 g
s
.63905 .77293 m .63905 .27104 L .6441 .28307 L p .707 .577 .707 r
F P
0 g
s
.16234 .7363 m .16591 .70246 L .17287 .68843 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.34908 .7517 m .35172 .77073 L .35857 .7712 L p .707 .577 .707 r
F P
0 g
s
.35857 .7712 m .35593 .75217 L .34908 .7517 L p .707 .577 .707 r
F P
0 g
s
.35868 .62718 m .3528 .67737 L .34008 .66202 L p .707 .577 .707 r
F P
0 g
s
.34008 .66202 m .34596 .61183 L .35868 .62718 L p .707 .577 .707 r
F P
0 g
s
.35593 .75217 m .35857 .7712 L .35554 .77307 L p .707 .577 .707 r
F P
0 g
s
.35554 .77307 m .35289 .75404 L .35593 .75217 L p .707 .577 .707 r
F P
0 g
s
.3559 .27959 m .3559 .78148 L .36095 .79351 L p .707 .577 .707 r
F P
0 g
s
.3559 .78148 m .3559 .27959 L .36496 .26772 L p .707 .577 .707 r
F P
0 g
s
.1539 .78073 m .15654 .79976 L .15957 .7979 L p .707 .577 .707 r
F P
0 g
s
.15957 .7979 m .15693 .77887 L .1539 .78073 L p .707 .577 .707 r
F P
0 g
s
.17287 .68843 m .1693 .72228 L .16234 .7363 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.15981 .65448 m .16568 .60429 L .18179 .59235 L p .707 .577 .707 r
F P
0 g
s
.16568 .60429 m .15981 .65448 L .15297 .66901 L p .707 .577 .707 r
F P
0 g
s
.1693 .72228 m .17287 .68843 L .18909 .6769 L p .707 .577 .707 r
F P
0 g
s
.63905 .27104 m .63905 .77293 L .62039 .7619 L p .707 .577 .707 r
F P
0 g
s
.62039 .7619 m .62039 .26001 L .63905 .27104 L p .707 .577 .707 r
F P
0 g
s
.34596 .61183 m .34008 .66202 L .31898 .64853 L p .707 .577 .707 r
F P
0 g
s
.31898 .64853 m .32485 .59834 L .34596 .61183 L p .707 .577 .707 r
F P
0 g
s
.18909 .6769 m .18552 .71075 L .1693 .72228 L p .707 .577 .707 r
F P
0 g
s
.18179 .59235 m .17591 .64254 L .15981 .65448 L p .707 .577 .707 r
F P
0 g
s
.17591 .64254 m .18179 .59235 L .20558 .58419 L p .707 .577 .707 r
F P
0 g
s
.16075 .7812 m .16339 .80023 L .15654 .79976 L p .707 .577 .707 r
F P
0 g
s
.15654 .79976 m .1539 .78073 L .16075 .7812 L p .707 .577 .707 r
F P
0 g
s
.35336 .69533 m .3498 .72918 L .32876 .71622 L p .707 .577 .707 r
F P
0 g
s
.32876 .71622 m .33233 .68237 L .35336 .69533 L p .707 .577 .707 r
F P
0 g
s
.36496 .76961 m .36496 .26772 L .38723 .25719 L p .707 .577 .707 r
F P
0 g
s
.36496 .26772 m .36496 .76961 L .3559 .78148 L p .707 .577 .707 r
F P
0 g
s
.18552 .71075 m .18909 .6769 L .21297 .66898 L p .707 .577 .707 r
F P
0 g
s
.32485 .59834 m .31898 .64853 L .29156 .63823 L p .707 .577 .707 r
F P
0 g
s
.29156 .63823 m .29743 .58803 L .32485 .59834 L p .707 .577 .707 r
F P
0 g
s
.1997 .63438 m .20558 .58419 L .23472 .58059 L p .707 .577 .707 r
F P
0 g
s
.20558 .58419 m .1997 .63438 L .17591 .64254 L p .707 .577 .707 r
F P
0 g
s
.35289 .75404 m .35554 .77307 L .34291 .77615 L p .707 .577 .707 r
F P
0 g
s
.34291 .77615 m .34027 .75712 L .35289 .75404 L p .707 .577 .707 r
F P
0 g
s
.21297 .66898 m .20941 .70283 L .18552 .71075 L p .707 .577 .707 r
F P
0 g
s
.33233 .68237 m .32876 .71622 L .30137 .70635 L p .707 .577 .707 r
F P
0 g
s
.30137 .70635 m .30494 .6725 L .33233 .68237 L p .707 .577 .707 r
F P
0 g
s
.20941 .70283 m .21297 .66898 L .24219 .66546 L p .707 .577 .707 r
F P
0 g
s
.29743 .58803 m .29156 .63823 L .2605 .63211 L p .707 .577 .707 r
F P
0 g
s
.2605 .63211 m .26637 .58192 L .29743 .58803 L p .707 .577 .707 r
F P
0 g
s
.22885 .63079 m .23472 .58059 L .26637 .58192 L p .707 .577 .707 r
F P
0 g
s
.23472 .58059 m .22885 .63079 L .1997 .63438 L p .707 .577 .707 r
F P
0 g
s
.17682 .78023 m .17946 .79926 L .16339 .80023 L p .707 .577 .707 r
F P
0 g
s
.16339 .80023 m .16075 .7812 L .17682 .78023 L p .707 .577 .707 r
F P
0 g
s
.62039 .26001 m .62039 .7619 L .58995 .75296 L p .707 .577 .707 r
F P
0 g
s
.58995 .75296 m .58995 .25107 L .62039 .26001 L p .707 .577 .707 r
F P
0 g
s
.26637 .58192 m .2605 .63211 L .22885 .63079 L p .707 .577 .707 r
F P
0 g
s
.30494 .6725 m .30137 .70635 L .27031 .70052 L p .707 .577 .707 r
F P
0 g
s
.27031 .70052 m .27388 .66667 L .30494 .6725 L p .707 .577 .707 r
F P
0 g
s
.23862 .69931 m .24219 .66546 L .27388 .66667 L p .707 .577 .707 r
F P
0 g
s
.24219 .66546 m .23862 .69931 L .20941 .70283 L p .707 .577 .707 r
F P
0 g
s
.27388 .66667 m .27031 .70052 L .23862 .69931 L p .707 .577 .707 r
F P
0 g
s
.38723 .25719 m .38723 .75908 L .36496 .76961 L p .707 .577 .707 r
F P
0 g
s
.38723 .75908 m .38723 .25719 L .42055 .24902 L p .707 .577 .707 r
F P
0 g
s
.7395 .63694 m .73362 .57958 L .70257 .5825 L p .707 .577 .707 r
F P
0 g
s
.73362 .57958 m .7395 .63694 L .77115 .63359 L p .707 .577 .707 r
F P
0 g
s
.77115 .63359 m .76527 .57623 L .73362 .57958 L p .707 .577 .707 r
F P
0 g
s
.70257 .5825 m .70844 .63986 L .7395 .63694 L p .707 .577 .707 r
F P
0 g
s
.76527 .57623 m .77115 .63359 L .80029 .63014 L p .707 .577 .707 r
F P
0 g
s
.80029 .63014 m .79442 .57278 L .76527 .57623 L p .707 .577 .707 r
F P
0 g
s
.70844 .63986 m .70257 .5825 L .67515 .58471 L p .707 .577 .707 r
F P
0 g
s
.34027 .75712 m .34291 .77615 L .32193 .78015 L p .707 .577 .707 r
F P
0 g
s
.32193 .78015 m .31929 .76111 L .34027 .75712 L p .707 .577 .707 r
F P
0 g
s
.67515 .58471 m .68102 .64207 L .70844 .63986 L p .707 .577 .707 r
F P
0 g
s
.79442 .57278 m .80029 .63014 L .82408 .62693 L p .707 .577 .707 r
F P
0 g
s
.82408 .62693 m .81821 .56957 L .79442 .57278 L p .707 .577 .707 r
F P
0 g
s
.20053 .7779 m .20318 .79693 L .17946 .79926 L p .707 .577 .707 r
F P
0 g
s
.17946 .79926 m .17682 .78023 L .20053 .7779 L p .707 .577 .707 r
F P
0 g
s
.58995 .25107 m .58995 .75296 L .5507 .74698 L p .707 .577 .707 r
F P
0 g
s
.5507 .74698 m .5507 .24509 L .58995 .25107 L p .707 .577 .707 r
F P
0 g
s
.68102 .64207 m .67515 .58471 L .65404 .58599 L p .707 .577 .707 r
F P
0 g
s
.65404 .58599 m .65992 .64335 L .68102 .64207 L p .707 .577 .707 r
F P
0 g
s
.42055 .75091 m .42055 .24902 L .46164 .24402 L p .707 .577 .707 r
F P
0 g
s
.42055 .24902 m .42055 .75091 L .38723 .75908 L p .707 .577 .707 r
F P
0 g
s
.31929 .76111 m .32193 .78015 L .29465 .78466 L p .707 .577 .707 r
F P
0 g
s
.29465 .78466 m .292 .76563 L .31929 .76111 L p .707 .577 .707 r
F P
0 g
s
.81821 .56957 m .82408 .62693 L .84019 .62427 L p .707 .577 .707 r
F P
0 g
s
.84019 .62427 m .83431 .56691 L .81821 .56957 L p .707 .577 .707 r
F P
0 g
s
.22957 .77446 m .23221 .79349 L .20318 .79693 L p .707 .577 .707 r
F P
0 g
s
.20318 .79693 m .20053 .7779 L .22957 .77446 L p .707 .577 .707 r
F P
0 g
s
.72968 .6938 m .72612 .65556 L .69506 .65806 L p .707 .577 .707 r
F P
0 g
s
.72612 .65556 m .72968 .6938 L .76137 .69069 L p .707 .577 .707 r
F P
0 g
s
.76137 .69069 m .75781 .65245 L .72612 .65556 L p .707 .577 .707 r
F P
0 g
s
.69506 .65806 m .69863 .6963 L .72968 .6938 L p .707 .577 .707 r
F P
0 g
s
.75781 .65245 m .76137 .69069 L .79059 .68725 L p .707 .577 .707 r
F P
0 g
s
.79059 .68725 m .78702 .64901 L .75781 .65245 L p .707 .577 .707 r
F P
0 g
s
.5507 .24509 m .5507 .74698 L .50649 .74455 L p .707 .577 .707 r
F P
0 g
s
.50649 .74455 m .50649 .24266 L .5507 .24509 L p .707 .577 .707 r
F P
0 g
s
.73627 .78917 m .73891 .77333 L .70799 .76592 L p .707 .577 .707 r
F P
0 g
s
.73891 .77333 m .73627 .78917 L .76778 .7911 L p .707 .577 .707 r
F P
0 g
s
.76778 .7911 m .77043 .77526 L .73891 .77333 L p .707 .577 .707 r
F P
0 g
s
.69863 .6963 m .69506 .65806 L .66767 .65969 L p .707 .577 .707 r
F P
0 g
s
.46164 .74591 m .46164 .24402 L .50649 .24266 L p .707 .577 .707 r
F P
0 g
s
.46164 .24402 m .46164 .74591 L .42055 .75091 L p .707 .577 .707 r
F P
0 g
s
.70535 .78176 m .70799 .76592 L .68071 .75376 L p .707 .577 .707 r
F P
0 g
s
.70799 .76592 m .70535 .78176 L .73627 .78917 L p .707 .577 .707 r
F P
0 g
s
.292 .76563 m .29465 .78466 L .26373 .78926 L p .707 .577 .707 r
F P
0 g
s
.65992 .64335 m .65404 .58599 L .64132 .58622 L p .707 .577 .707 r
F P
0 g
s
.66767 .65969 m .67124 .69793 L .69863 .6963 L p .707 .577 .707 r
F P
0 g
s
.26373 .78926 m .26109 .77023 L .292 .76563 L p .707 .577 .707 r
F P
0 g
s
.77043 .77526 m .76778 .7911 L .79682 .78737 L p .707 .577 .707 r
F P
0 g
s
.79682 .78737 m .79946 .77153 L .77043 .77526 L p .707 .577 .707 r
F P
0 g
s
.64132 .58622 m .6472 .64358 L .65992 .64335 L p .707 .577 .707 r
F P
0 g
s
.26109 .77023 m .26373 .78926 L .23221 .79349 L p .707 .577 .707 r
F P
0 g
s
.23221 .79349 m .22957 .77446 L .26109 .77023 L p .707 .577 .707 r
F P
0 g
s
.50649 .24266 m .50649 .74455 L .46164 .74591 L p .707 .577 .707 r
F P
0 g
s
.78702 .64901 m .79059 .68725 L .81448 .68384 L p .707 .577 .707 r
F P
0 g
s
.81448 .68384 m .81091 .6456 L .78702 .64901 L p .707 .577 .707 r
F P
0 g
s
.68071 .75376 m .67807 .7696 L .70535 .78176 L p .707 .577 .707 r
F P
0 g
s
.67807 .7696 m .68071 .75376 L .65973 .73804 L p .707 .577 .707 r
F P
0 g
s
.79946 .77153 m .79682 .78737 L .82054 .77835 L p .707 .577 .707 r
F P
0 g
s
.82054 .77835 m .82318 .7625 L .79946 .77153 L p .707 .577 .707 r
F P
0 g
s
.67124 .69793 m .66767 .65969 L .64663 .66029 L p .707 .577 .707 r
F P
0 g
s
.64663 .66029 m .6502 .69853 L .67124 .69793 L p .707 .577 .707 r
F P
0 g
s
.83431 .56691 m .84019 .62427 L .84703 .62242 L p .707 .577 .707 r
F P
0 g
s
.84703 .62242 m .84116 .56506 L .83431 .56691 L p .707 .577 .707 r
F P
0 g
s
.65973 .73804 m .65709 .75389 L .67807 .7696 L p .707 .577 .707 r
F P
0 g
s
.81091 .6456 m .81448 .68384 L .8307 .68078 L p .707 .577 .707 r
F P
0 g
s
.8307 .68078 m .82713 .64254 L .81091 .6456 L p .707 .577 .707 r
F P
0 g
s
.65709 .75389 m .65973 .73804 L .6471 .72031 L p .707 .577 .707 r
F P
0 g
s
.6472 .64358 m .64132 .58622 L .63823 .58536 L p .707 .577 .707 r
F P
0 g
s
.63823 .58536 m .64411 .64272 L .6472 .64358 L p .707 .577 .707 r
F P
0 g
s
.82318 .7625 m .82054 .77835 L .83661 .7649 L p .707 .577 .707 r
F P
0 g
s
.83661 .7649 m .83925 .74906 L .82318 .7625 L p .707 .577 .707 r
F P
0 g
s
.6502 .69853 m .64663 .66029 L .63401 .65981 L p .707 .577 .707 r
F P
0 g
s
.6471 .72031 m .64446 .73615 L .65709 .75389 L p .707 .577 .707 r
F P
0 g
s
.63401 .65981 m .63758 .69805 L .6502 .69853 L p .707 .577 .707 r
F P
0 g
s
.84116 .56506 m .84703 .62242 L .84394 .62157 L p .707 .577 .707 r
F P
0 g
s
.84394 .62157 m .83807 .56421 L .84116 .56506 L p .707 .577 .707 r
F P
0 g
s
.64446 .73615 m .6471 .72031 L .64407 .70229 L p .707 .577 .707 r
F P
0 g
s
.82713 .64254 m .8307 .68078 L .83766 .67837 L p .707 .577 .707 r
F P
0 g
s
.83766 .67837 m .83409 .64013 L .82713 .64254 L p .707 .577 .707 r
F P
0 g
s
.83925 .74906 m .83661 .7649 L .84346 .74836 L p .707 .577 .707 r
F P
0 g
s
.84346 .74836 m .8461 .73252 L .83925 .74906 L p .707 .577 .707 r
F P
0 g
s
.64411 .64272 m .63823 .58536 L .64507 .58351 L p .707 .577 .707 r
F P
0 g
s
.64507 .58351 m .65095 .64087 L .64411 .64272 L p .707 .577 .707 r
F P
0 g
s
.64407 .70229 m .64143 .71813 L .64446 .73615 L p .707 .577 .707 r
F P
0 g
s
.63758 .69805 m .63401 .65981 L .63103 .65829 L p .707 .577 .707 r
F P
0 g
s
.63103 .65829 m .6346 .69653 L .63758 .69805 L p .707 .577 .707 r
F P
0 g
s
.64143 .71813 m .64407 .70229 L .65092 .68575 L p .707 .577 .707 r
F P
0 g
s
.83807 .56421 m .84394 .62157 L .83122 .62179 L p .707 .577 .707 r
F P
0 g
s
.83122 .62179 m .82535 .56443 L .83807 .56421 L p .707 .577 .707 r
F P
0 g
s
.8461 .73252 m .84346 .74836 L .84042 .73034 L p .707 .577 .707 r
F P
0 g
s
.84042 .73034 m .84307 .7145 L .8461 .73252 L p .707 .577 .707 r
F P
0 g
s
.83409 .64013 m .83766 .67837 L .83468 .67685 L p .707 .577 .707 r
F P
0 g
s
.83468 .67685 m .83111 .63861 L .83409 .64013 L p .707 .577 .707 r
F P
0 g
s
.65092 .68575 m .64828 .70159 L .64143 .71813 L p .707 .577 .707 r
F P
0 g
s
.43386 .62164 m .42037 .56939 L .38941 .57735 L p .707 .577 .707 r
F P
0 g
s
.42037 .56939 m .43386 .62164 L .46246 .61068 L p .707 .577 .707 r
F P
0 g
s
.46246 .61068 m .44897 .55843 L .42037 .56939 L p .707 .577 .707 r
F P
0 g
s
.40289 .62959 m .38941 .57735 L .35912 .58152 L p .707 .577 .707 r
F P
0 g
s
.38941 .57735 m .40289 .62959 L .43386 .62164 L p .707 .577 .707 r
F P
0 g
s
.65095 .64087 m .64507 .58351 L .66118 .58085 L p .707 .577 .707 r
F P
0 g
s
.66118 .58085 m .66705 .63821 L .65095 .64087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.6346 .69653 m .63103 .65829 L .63799 .65588 L p .707 .577 .707 r
F P
0 g
s
.44897 .55843 m .46246 .61068 L .48589 .59779 L p .707 .577 .707 r
F P
0 g
s
.48589 .59779 m .47241 .54554 L .44897 .55843 L p .707 .577 .707 r
F P
0 g
s
.3726 .63377 m .35912 .58152 L .33246 .5815 L p .707 .577 .707 r
F P
0 g
s
.35912 .58152 m .3726 .63377 L .40289 .62959 L p .707 .577 .707 r
F P
0 g
s
.63799 .65588 m .64156 .69412 L .6346 .69653 L p .707 .577 .707 r
F P
0 g
s
.64828 .70159 m .65092 .68575 L .66699 .67231 L p .707 .577 .707 r
F P
0 g
s
.38068 .69193 m .37246 .65681 L .34204 .66045 L p .707 .577 .707 r
F P
0 g
s
.37246 .65681 m .38068 .69193 L .41179 .68459 L p .707 .577 .707 r
F P
0 g
s
.41179 .68459 m .40357 .64947 L .37246 .65681 L p .707 .577 .707 r
F P
0 g
s
.40357 .64947 m .41179 .68459 L .44055 .67428 L p .707 .577 .707 r
F P
0 g
s
.44055 .67428 m .43233 .63916 L .40357 .64947 L p .707 .577 .707 r
F P
0 g
s
.82535 .56443 m .83122 .62179 L .81012 .62307 L p .707 .577 .707 r
F P
0 g
s
.81012 .62307 m .80424 .56571 L .82535 .56443 L p .707 .577 .707 r
F P
0 g
s
.84307 .7145 m .84042 .73034 L .8278 .71261 L p .707 .577 .707 r
F P
0 g
s
.8278 .71261 m .83044 .69676 L .84307 .7145 L p .707 .577 .707 r
F P
0 g
s
.35026 .69557 m .34204 .66045 L .31529 .66006 L p .707 .577 .707 r
F P
0 g
s
.34204 .66045 m .35026 .69557 L .38068 .69193 L p .707 .577 .707 r
F P
0 g
s
.43233 .63916 m .44055 .67428 L .46415 .662 L p .707 .577 .707 r
F P
0 g
s
.46415 .662 m .45593 .62688 L .43233 .63916 L p .707 .577 .707 r
F P
0 g
s
.66699 .67231 m .66435 .68815 L .64828 .70159 L p .707 .577 .707 r
F P
0 g
s
.83111 .63861 m .83468 .67685 L .82205 .67637 L p .707 .577 .707 r
F P
0 g
s
.82205 .67637 m .81849 .63813 L .83111 .63861 L p .707 .577 .707 r
F P
0 g
s
.47241 .54554 m .48589 .59779 L .50188 .58423 L p .707 .577 .707 r
F P
0 g
s
.50188 .58423 m .48839 .53198 L .47241 .54554 L p .707 .577 .707 r
F P
0 g
s
.34594 .63374 m .33246 .5815 L .31205 .57729 L p .707 .577 .707 r
F P
0 g
s
.33246 .5815 m .34594 .63374 L .3726 .63377 L p .707 .577 .707 r
F P
0 g
s
.66705 .63821 m .66118 .58085 L .68497 .57764 L p .707 .577 .707 r
F P
0 g
s
.68497 .57764 m .69084 .635 L .66705 .63821 L p .707 .577 .707 r
F P
0 g
s
.39508 .70573 m .40108 .68763 L .37154 .67701 L p .707 .577 .707 r
F P
0 g
s
.40108 .68763 m .39508 .70573 L .42535 .71524 L p .707 .577 .707 r
F P
0 g
s
.42535 .71524 m .43135 .69714 L .40108 .68763 L p .707 .577 .707 r
F P
0 g
s
.31529 .66006 m .32351 .69517 L .35026 .69557 L p .707 .577 .707 r
F P
0 g
s
.66435 .68815 m .66699 .67231 L .69071 .66328 L p .707 .577 .707 r
F P
0 g
s
.37154 .67701 m .36554 .69511 L .39508 .70573 L p .707 .577 .707 r
F P
0 g
s
.64156 .69412 m .63799 .65588 L .65421 .65282 L p .707 .577 .707 r
F P
0 g
s
.43135 .69714 m .42535 .71524 L .45341 .72269 L p .707 .577 .707 r
F P
0 g
s
.45341 .72269 m .45941 .70459 L .43135 .69714 L p .707 .577 .707 r
F P
0 g
s
.32351 .69517 m .31529 .66006 L .29483 .65565 L p .707 .577 .707 r
F P
0 g
s
.65421 .65282 m .65778 .69106 L .64156 .69412 L p .707 .577 .707 r
F P
0 g
s
.80424 .56571 m .81012 .62307 L .78269 .62528 L p .707 .577 .707 r
F P
0 g
s
.78269 .62528 m .77682 .56792 L .80424 .56571 L p .707 .577 .707 r
F P
0 g
s
.45593 .62688 m .46415 .662 L .48026 .64897 L p .707 .577 .707 r
F P
0 g
s
.48026 .64897 m .47204 .61385 L .45593 .62688 L p .707 .577 .707 r
F P
0 g
s
.83044 .69676 m .8278 .71261 L .80682 .69689 L p .707 .577 .707 r
F P
0 g
s
.80682 .69689 m .80946 .68105 L .83044 .69676 L p .707 .577 .707 r
F P
0 g
s
.36554 .69511 m .37154 .67701 L .34563 .6663 L p .707 .577 .707 r
F P
0 g
s
.34563 .6663 m .33963 .68441 L .36554 .69511 L p .707 .577 .707 r
F P
0 g
s
.31205 .57729 m .32553 .62953 L .34594 .63374 L p .707 .577 .707 r
F P
0 g
s
.69071 .66328 m .68806 .67912 L .66435 .68815 L p .707 .577 .707 r
F P
0 g
s
.69084 .635 m .68497 .57764 L .71411 .57419 L p .707 .577 .707 r
F P
0 g
s
.48839 .53198 m .50188 .58423 L .50884 .57132 L p .707 .577 .707 r
F P
0 g
s
.50884 .57132 m .49536 .51907 L .48839 .53198 L p .707 .577 .707 r
F P
0 g
s
.32553 .62953 m .31205 .57729 L .29988 .5693 L p .707 .577 .707 r
F P
0 g
s
.71411 .57419 m .71999 .63155 L .69084 .635 L p .707 .577 .707 r
F P
0 g
s
.45941 .70459 m .45341 .72269 L .47649 .72736 L p .707 .577 .707 r
F P
0 g
s
.47649 .72736 m .48249 .70926 L .45941 .70459 L p .707 .577 .707 r
F P
0 g
s
.29483 .65565 m .30305 .69077 L .32351 .69517 L p .707 .577 .707 r
F P
0 g
s
.81849 .63813 m .82205 .67637 L .80102 .67697 L p .707 .577 .707 r
F P
0 g
s
.80102 .67697 m .79745 .63873 L .81849 .63813 L p .707 .577 .707 r
F P
0 g
s
.68806 .67912 m .69071 .66328 L .71974 .65955 L p .707 .577 .707 r
F P
0 g
s
.77682 .56792 m .78269 .62528 L .75164 .6282 L p .707 .577 .707 r
F P
0 g
s
.75164 .6282 m .74576 .57084 L .77682 .56792 L p .707 .577 .707 r
F P
0 g
s
.33963 .68441 m .34563 .6663 L .32589 .65657 L p .707 .577 .707 r
F P
0 g
s
.80946 .68105 m .80682 .69689 L .77953 .68473 L p .707 .577 .707 r
F P
0 g
s
.77953 .68473 m .78218 .66889 L .80946 .68105 L p .707 .577 .707 r
F P
0 g
s
.32589 .65657 m .31989 .67467 L .33963 .68441 L p .707 .577 .707 r
F P
0 g
s
.71999 .63155 m .71411 .57419 L .74576 .57084 L p .707 .577 .707 r
F P
0 g
s
.74576 .57084 m .75164 .6282 L .71999 .63155 L p .707 .577 .707 r
F P
0 g
s
.30305 .69077 m .29483 .65565 L .28266 .64766 L p .707 .577 .707 r
F P
0 g
s
.47204 .61385 m .48026 .64897 L .48732 .63645 L p .707 .577 .707 r
F P
0 g
s
.48732 .63645 m .4791 .60133 L .47204 .61385 L p .707 .577 .707 r
F P
0 g
s
.65778 .69106 m .65421 .65282 L .6781 .64941 L p .707 .577 .707 r
F P
0 g
s
.71974 .65955 m .7171 .67539 L .68806 .67912 L p .707 .577 .707 r
F P
0 g
s
.6781 .64941 m .68166 .68764 L .65778 .69106 L p .707 .577 .707 r
F P
0 g
s
.7171 .67539 m .71974 .65955 L .75126 .66148 L p .707 .577 .707 r
F P
0 g
s
.29988 .5693 m .31336 .62155 L .32553 .62953 L p .707 .577 .707 r
F P
0 g
s
.78218 .66889 m .77953 .68473 L .74862 .67733 L p .707 .577 .707 r
F P
0 g
s
.74862 .67733 m .75126 .66148 L .78218 .66889 L p .707 .577 .707 r
F P
0 g
s
.75126 .66148 m .74862 .67733 L .7171 .67539 L p .707 .577 .707 r
F P
0 g
s
.48249 .70926 m .47649 .72736 L .49234 .7288 L p .707 .577 .707 r
F P
0 g
s
.49234 .7288 m .49834 .7107 L .48249 .70926 L p .707 .577 .707 r
F P
0 g
s
.28266 .64766 m .29088 .68278 L .30305 .69077 L p .707 .577 .707 r
F P
0 g
s
.49536 .51907 m .50884 .57132 L .5061 .56034 L p .705 .576 .708 r
F P
0 g
s
.5061 .56034 m .49262 .50809 L .49536 .51907 L p .705 .576 .708 r
F P
0 g
s
.79745 .63873 m .80102 .67697 L .77363 .6786 L p .707 .577 .707 r
F P
0 g
s
.77363 .6786 m .77006 .64036 L .79745 .63873 L p .707 .577 .707 r
F P
0 g
s
.31336 .62155 m .29988 .5693 L .29714 .55831 L p .705 .576 .708 r
F P
0 g
s
.31989 .67467 m .32589 .65657 L .31425 .64875 L p .707 .577 .707 r
F P
0 g
s
.31425 .64875 m .30825 .66685 L .31989 .67467 L p .707 .577 .707 r
F P
0 g
s
.68166 .68764 m .6781 .64941 L .70731 .64597 L p .707 .577 .707 r
F P
0 g
s
.70731 .64597 m .71088 .68421 L .68166 .68764 L p .707 .577 .707 r
F P
0 g
s
.29088 .68278 m .28266 .64766 L .27998 .63688 L p .708 .578 .707 r
F P
0 g
s
.4791 .60133 m .48732 .63645 L .48464 .62567 L p .708 .578 .707 r
F P
0 g
s
.48464 .62567 m .47642 .59055 L .4791 .60133 L p .708 .578 .707 r
F P
0 g
s
.77006 .64036 m .77363 .6786 L .74257 .68109 L p .707 .577 .707 r
F P
0 g
s
.74257 .68109 m .739 .64286 L .77006 .64036 L p .707 .577 .707 r
F P
0 g
s
.29714 .55831 m .31062 .61056 L .31336 .62155 L p .705 .576 .708 r
F P
0 g
s
.71088 .68421 m .70731 .64597 L .739 .64286 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.739 .64286 m .74257 .68109 L .71088 .68421 L p .707 .577 .707 r
F P
0 g
s
.49834 .7107 m .49234 .7288 L .49941 .72686 L p .707 .577 .707 r
F P
0 g
s
.49941 .72686 m .50541 .70876 L .49834 .7107 L p .707 .577 .707 r
F P
0 g
s
.27998 .63688 m .2882 .672 L .29088 .68278 L p .708 .578 .707 r
F P
0 g
s
.49262 .50809 m .5061 .56034 L .49393 .55235 L p .707 .577 .707 r
F P
0 g
s
.49393 .55235 m .48045 .5001 L .49262 .50809 L p .707 .577 .707 r
F P
0 g
s
.31062 .61056 m .29714 .55831 L .3041 .54541 L p .707 .577 .707 r
F P
0 g
s
.30825 .66685 m .31425 .64875 L .31185 .64362 L p .707 .577 .707 r
F P
0 g
s
.31185 .64362 m .30585 .66172 L .30825 .66685 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.2882 .672 m .27998 .63688 L .28704 .62436 L p .707 .577 .707 r
F P
0 g
s
.47642 .59055 m .48464 .62567 L .47247 .61769 L p .707 .577 .707 r
F P
0 g
s
.47247 .61769 m .46425 .58257 L .47642 .59055 L p .707 .577 .707 r
F P
0 g
s
.3041 .54541 m .31758 .59766 L .31062 .61056 L p .707 .577 .707 r
F P
0 g
s
.50541 .70876 m .49941 .72686 L .49701 .72173 L p .707 .577 .707 r
F P
0 g
s
.49701 .72173 m .50301 .70362 L .50541 .70876 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.28704 .62436 m .29526 .65948 L .2882 .672 L p .707 .577 .707 r
F P
0 g
s
.48045 .5001 m .49393 .55235 L .47351 .54814 L p .707 .577 .707 r
F P
0 g
s
.47351 .54814 m .46003 .49589 L .48045 .5001 L p .707 .577 .707 r
F P
0 g
s
.31758 .59766 m .3041 .54541 L .32008 .53185 L p .707 .577 .707 r
F P
0 g
s
.30585 .66172 m .31185 .64362 L .31892 .64168 L p .707 .577 .707 r
F P
0 g
s
.31892 .64168 m .31292 .65978 L .30585 .66172 L p .707 .577 .707 r
F P
0 g
s
.29526 .65948 m .28704 .62436 L .30316 .61133 L p .707 .577 .707 r
F P
0 g
s
.46425 .58257 m .47247 .61769 L .45201 .61328 L p .707 .577 .707 r
F P
0 g
s
.45201 .61328 m .44379 .57816 L .46425 .58257 L p .707 .577 .707 r
F P
0 g
s
.32008 .53185 m .33356 .5841 L .31758 .59766 L p .707 .577 .707 r
F P
0 g
s
.46003 .49589 m .47351 .54814 L .44685 .54812 L p .707 .577 .707 r
F P
0 g
s
.44685 .54812 m .43337 .49587 L .46003 .49589 L p .707 .577 .707 r
F P
0 g
s
.33356 .5841 m .32008 .53185 L .34352 .51896 L p .707 .577 .707 r
F P
0 g
s
.30316 .61133 m .31138 .64645 L .29526 .65948 L p .707 .577 .707 r
F P
0 g
s
.50301 .70362 m .49701 .72173 L .48537 .71391 L p .707 .577 .707 r
F P
0 g
s
.48537 .71391 m .49137 .69581 L .50301 .70362 L p .707 .577 .707 r
F P
0 g
s
.31292 .65978 m .31892 .64168 L .33477 .64311 L p .707 .577 .707 r
F P
0 g
s
.33477 .64311 m .32877 .66121 L .31292 .65978 L p .707 .577 .707 r
F P
0 g
s
.31138 .64645 m .30316 .61133 L .32675 .59906 L p .707 .577 .707 r
F P
0 g
s
.44379 .57816 m .45201 .61328 L .42526 .61288 L p .707 .577 .707 r
F P
0 g
s
.42526 .61288 m .41704 .57776 L .44379 .57816 L p .707 .577 .707 r
F P
0 g
s
.43337 .49587 m .44685 .54812 L .41656 .55229 L p .707 .577 .707 r
F P
0 g
s
.41656 .55229 m .40308 .50004 L .43337 .49587 L p .707 .577 .707 r
F P
0 g
s
.357 .5712 m .34352 .51896 L .37212 .508 L p .707 .577 .707 r
F P
0 g
s
.34352 .51896 m .357 .5712 L .33356 .5841 L p .707 .577 .707 r
F P
0 g
s
.40308 .50004 m .41656 .55229 L .3856 .56024 L p .707 .577 .707 r
F P
0 g
s
.3856 .56024 m .37212 .508 L .40308 .50004 L p .707 .577 .707 r
F P
0 g
s
.37212 .508 m .3856 .56024 L .357 .5712 L p .707 .577 .707 r
F P
0 g
s
.32675 .59906 m .33497 .63418 L .31138 .64645 L p .707 .577 .707 r
F P
0 g
s
.33497 .63418 m .32675 .59906 L .35551 .58875 L p .707 .577 .707 r
F P
0 g
s
.49137 .69581 m .48537 .71391 L .46563 .70417 L p .707 .577 .707 r
F P
0 g
s
.46563 .70417 m .47163 .68607 L .49137 .69581 L p .707 .577 .707 r
F P
0 g
s
.41704 .57776 m .42526 .61288 L .39484 .61653 L p .707 .577 .707 r
F P
0 g
s
.39484 .61653 m .38662 .58141 L .41704 .57776 L p .707 .577 .707 r
F P
0 g
s
.32877 .66121 m .33477 .64311 L .35786 .64779 L p .707 .577 .707 r
F P
0 g
s
.35786 .64779 m .35186 .66589 L .32877 .66121 L p .707 .577 .707 r
F P
0 g
s
.36373 .62387 m .35551 .58875 L .38662 .58141 L p .707 .577 .707 r
F P
0 g
s
.35551 .58875 m .36373 .62387 L .33497 .63418 L p .707 .577 .707 r
F P
0 g
s
.38662 .58141 m .39484 .61653 L .36373 .62387 L p .707 .577 .707 r
F P
0 g
s
.47163 .68607 m .46563 .70417 L .43972 .69347 L p .707 .577 .707 r
F P
0 g
s
.43972 .69347 m .44572 .67537 L .47163 .68607 L p .707 .577 .707 r
F P
0 g
s
.35186 .66589 m .35786 .64779 L .38591 .65524 L p .707 .577 .707 r
F P
0 g
s
.38591 .65524 m .37991 .67334 L .35186 .66589 L p .707 .577 .707 r
F P
0 g
s
.44572 .67537 m .43972 .69347 L .41018 .68284 L p .707 .577 .707 r
F P
0 g
s
.41018 .68284 m .41618 .66474 L .44572 .67537 L p .707 .577 .707 r
F P
0 g
s
.37991 .67334 m .38591 .65524 L .41618 .66474 L p .707 .577 .707 r
F P
0 g
s
.41618 .66474 m .41018 .68284 L .37991 .67334 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF3P002UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUH000060004FUH00`00FUIJEP04FUH00`00FUIJEP040006FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00AJEP@0009JEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF009JEP<000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF000010001eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo0`0000=JEP00FUH025YF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@0
05YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00Hgoo0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00HGoo0P001eYF00<005YFFUH01UYF00<005YFFUH01eYF00<0
05YFFUH015YF00<005YFFUH00UYF00L005YFFUIJEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005moo`<000QJEP03001JEUYF00MJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001MOol20003FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01P00FUIJEP00FUH000aJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00UYF
00H005YFFUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol005Yoo`03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00MJEP03
001JEUYF00AJEP03001JEUYF009JEP06001JEUYF001JEP0035YF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001IOol20007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP02000<FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005Qoo`04001JEUYF0007FUH0
0`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
0`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005Moo`05001JEUYFFUH00007FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUIJEP02FUH00`00FUIJEP02000<FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol005Ioo`03001JEUYF009JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP/000=JEP03001JEUYF008000aJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo0P0015YF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH010001UYF0P0000=JEP00FUH00`0000=J
EP00FUH00P0035YF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001EOol00`00FUH00004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP05FUH50008FUH2
0004FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH010000eYF00<005YFFUH015YF0`001UYF00<005YFFUH00UYF100035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001DOol01000FUIJEP0015YF
00<005YFFUH01EYF00<005YFFUH01EYF1P001EYF00<005YFFUH00UYF0P0000=JEP00FUH01UYF00<0
05YFFUH00UYF00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00EGoo00<005YF000015YF00<005YFFUH01EYF00<005YFFUH00eYF0P000UYF1@00
15YF00<005YF00000P0015YF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH000aJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0002Uoo`l002eoo`00EGoo00@005YF
FUH000AJEP03001JEUYF00EJEP03001JEP00008000AJEPD000=JEP<000MJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0000POol90003FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001EOol01000FUIJEP00
15YF00<005YFFUH01EYF0`001UYF200000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0001Mo
o`T000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool005Eoo`04001JEUYF
0004FUH00`00FUIJEP03FUH300000eYF001JEP05FUH50005FUH00`00FUIJEP05FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0000?Ool80004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000
FUIJEUYF0P00;Goo001FOol01000FUIJEP000eYF00@005YFFUIJEP80009oo`03001JEP0000=JEPD0
009JEQ0000IJEP03001JEUYF009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0000Moo`P000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool003moo`l000Qoo`04001JEUYF0004FUH=0000
0eYF000000040004FUH00`00FUIJEP05FUH00`00FUIJEP030005FUH00`00FUIJEP02FUH2000<FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH000070003FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003Uoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@000Aoo`04001JEUYF0004FUH00`00
FUIJEP05FUH00`00FUH0000300000eYF001JEP07FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP02FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool003Eoo`@00003FUH005YF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEPD0009JEP07001JEUYFFUH005YF000015YF10001UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00UYF00H005YF000005YF0003FUH00`00FUH0000<FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02
000]Ool003=oo`8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEP00
0003FUH20002FUH00`00FUH0000200000eYF001JEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01P00FUIJEP00FUH0009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool0039o
o`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYF0002FUH01000
FUIJEUYF0`0015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00@005YFFUH0009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool0031oo`800003FUH0
05YF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP05001JEUYF001JEP020000
0eYF00000008FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH0
1000FUIJEUYF0`0015YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000/Ool002moo`05001JEUYFFUH0
0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH01P00FUIJEUYF001JEP@000UJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0006
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001J
EP02FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;7oo000^Ool20003FUH00`00FUIJEP03FUH00`00
FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP00
1UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=JEP00
FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002aoo`00;Woo0P000eYF00<005YFFUH00eYF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00P001EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000IJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00=JEP03001JEUYF008002aoo`00;Goo00<005YF00000eYF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF000000IJEP03001JEUYF00IJ
EP03001JEUYF00MJEP03001JEUYF009JEPh000=JEP04001JEP000005FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00FUIJEP04FUH0
0`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
0`00FUIJEP02000/Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00AJEPL000IJEP03
001JEP00008000=JEP@0009JEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ao
o`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010000eYF00<005YFFUH0
1UYF0`001UYF0P0000=JEP0000000P001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YFFUIJEPL002aoo`00;Goo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<0
05YFFUH015YF00<005YFFUH01EYF10001eYF00<005YFFUH00eYF0`0025YF00<005YFFUH00UYF00<0
05YF00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00
00=JEP00FUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH00UYF
4@000UYF1000;7oo000]Ool20003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP03FUH20005FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP03FUH4
00000eYF000000020008FUH20005FUH00`00FUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<0
05YFFUH00UYF2@0000=JEP00FUH01UYF00@005YFFUIJEPH0031oo`00;7oo00<005YF00000eYF00<0
05YFFUH00eYF00<005YFFUH00UYF3`0015YF0P001EYF00<005YFFUH01EYF00<005YF00000P001EYF
00<005YFFUH00UYF1P000eYF00<005YFFUH015YF0P0000=JEP00FUH015YF00@005YF000000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEUYFFUH00003
FUH00`00FUIJEP04FUH00`00FUIJEP02FUH800000eYF001JEP07FUH00`00FUIJEP02FUH7000fOol0
02aoo`03001JEP0000=JEP03001JEUYF009JEPH000moo`@0009JEP03001JEUYF009JEP03001JEUYF
00AJEQD000AJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYF0004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000eYF00@0
05YFFUIJEPT000QJEP03001JEUYF009JEPT003eoo`00;7oo00<005YF00000eYF00<005YF00000P00
67oo00@005YFFUH000EJEP04001JEUYFFUH20003FUH01`00FUIJEUYF001JEP0000IJEPD000AJEP03
001JEP00008000IJEP03001JEUYF009JEP04001JEUYF0004FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUIJEUYF00000UYF1P0015YF4@0027oo3P00<7oo
000/Ool00`00FUH00003FUH2000KOol01000FUIJEP001EYF00<005YF00001`000eYF00<005YF0000
1UYF10001EYF0P0000=JEP00FUH01UYF00<005YFFUH00eYF0P001EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00003P0027oo4@000eYF00<005YFFUH0
0eYF00@005YFFUIJEP8002moo`00;7oo0P000eYF00<007ooOol06goo00@005YFFUH000EJEP<000AJ
EP03001JEP0000800004FUH005YF0006FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH20005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH00002000;Ool90004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH0
1000FUIJEUYF0P00;goo000/Ool2000015YF000000007Woo00<005YF000015YF0`0015YF00<005YF
FUH00eYF10001UYF00<005YF00000`001eYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH0
15YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
1Goo200015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002moo`00;7oo0`000UYF0`0057oo0`001Goo00D005YFFUH005YF00<00003FUH005YF
00=JEP03001JEUYF00AJEP03001JEP0000<00003FUH000000080009JEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000D000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000_Ool002aoo`03FUH0
05YF009JEP04001JEUYF000BOol50004Ool00`00FUIJEP0300000goo00000005FUH00`00FUIJEP04
FUH00`00FUIJEP03FUH40004FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000FUH0000025YF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002moo`00:goo0`000eYF00@005YFFUIJEP80011oo`D000Aoo`04001JEUYF0002
FUH00`00FUH000020002FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUH0000200000eYF001J
EP07FUH00`00FUIJEP04FUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP030003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;goo000[Ool30002FUH00`00FUIJ
EP04FUH2000>Ool50004Ool01P00FUH005YF001JEP8000=JEPH000=JEP03001JEUYF00EJEP03001J
EUYF00=JEP<000MJEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YF
FUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00
:goo00<005YF00000UYF00<005YFFUH015YF00@005YF000000Ioo`l00005OomJEP00FUH00002FUH0
1@00FUIJEUYF00001EYF1@001UYF00<005YFFUH01UYF0`0015YF00<005YFFUH00UYF0`002eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP04
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P00;Woo000[Ool00`00FUH00002FUH00`00FUIJEP04FUH01000FUIJEUYF1P00
0eYF00<005YFFUH01UYF00<005YFFUH00P000UYF00@005YFFUIJEP<000MJEP03001JEP0000D00003
FUH005YF00UJEP04001JEP000003FUH01000FUH000000UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJEP05FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Woo000[Ool00`00FUIJEP02FUH00`00FUIJEP04FUH400000eYF001JEP06FUH00`00FUIJ
EP06FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH00UYF0P00
0UYF0`0025YF00<005YFFUH00UYF1@0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00;Woo
000[Ool00`00FUIJEP02FUH00`00FUIJEP02FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P000UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF100000AJEP00000000EJ
EP03001JEUYF00EJEP<000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00IJEP04001JEUYF0002FUH01@00FUIJEUYF00001UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH00UYF5`00;Woo000/Ool01@00FUIJEUYF00000eYF0P001UYF00<005YFFUH01EYF00<0
05YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00800003FUH005YF00MJEP03
001JEP0000800003FUH0000000800003FUH005YF00QJEP06001JEP00001JEP002eYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00003FUH00`00FUIJEP04FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH<0002FUH00`00FUIJEP05FUH30002FUH4000_Ool002aoo`06
001JEUYFFUH005YF0P0000=JEP00FUH01EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUH000AJEP03001JEUYF009JEP<000IJEP03001JEUYF00=JEPP000MJEP03001JEUYF
009JEP<000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF2P0025YF00<005YFFUH00`0025YF1000<goo000]
Ool00`00FUIJEP020003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH200000eYF001JEP03FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP03FUH60002FUH20005
FUH00`00FUIJEP05FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00
FUIJEUYF001JEP0000=JEP04001JEUYFFUH90008FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30006
FUH00`00FUH0000dOol002eoo`03001JEP00008000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00IJEP03001JEUYF00IJEP@0009JEP03001JEUYF00EJEP<00003FUH005YF00EJEPD00004
FUH00000FUH400000eYF001JEP08FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH90003Ool20003FUH01000FUIJEUYF0P00<Woo000^Ool40002FUH00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01000FUIJEUYF40001UYF0`0015YF0`000UYF0`00
1eYF00<005YFFUH00UYF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00H0
05YFFUIJEP00FUH300000eYF001JEP02FUH00`00FUIJEP05FUH00`00FUIJEP02FUH9000>Ool20000
0eYF001JEP04FUH00`00Oomoo`0_Ool002ioo`800005FUH005YFFUH00006FUH00`00FUIJEP02FUH8
0004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200000eYF001JEP030005FUH0
0`00FUIJEP05FUH30002FUH20005FUH00`00FUIJEP03FUH20002FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH01000FUIJEUYF5`006Goo0P001UYF00<007ooOol0;Woo000_Ool00`00
FUH00002FUH00`00FUIJEP03FUH60007FUH:0004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20000
0eYF001JEP03FUH300000eYF001JEP08FUH00`00FUH0000600000eYF001JEP04FUH01P00FUIJEP00
FUH000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP000002FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0MOol20004FUH2000_Ool002moo`8000=JEP04001J
EUYFFUH20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH70006FUH00`00FUIJEP04FUH200000eYF
001JEP05FUH40007FUH00`00FUIJEP04FUH50005FUH01000FUIJEUYF0P0035YF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00H005YF000005YF0006FUH00`00FUIJEP02FUH00`00Oomo
o`0OOol01P00FUIJEP00FUH002moo`00;goo0P000eYF00@005YF000000IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00AJEP8000AJEP03001JEUYF00AJEP800003FUH005YF00EJEP04001J
EUYFFUH20005FUH00`00FUIJEP06FUH00`00FUIJEP020003FUH01000FUIJEUYF0P0035YF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH015YF00@005YF
FUIJEP80029oo`<0009JEP03001oogoo02aoo`00;goo0P000eYF0`001UYF00<005YFFUH01eYF00<0
05YFFUH01UYF00<005YFFUH01EYF100000=JEP00FUH015YF00D005YF001JEP0000IJEP03001JEUYF
00=JEP<00003FUH005YF00MJEP03001JEUYF00=JEP<000AJEP8000aJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP<0009JEP03001JEUYF00=JEP03001JEUYF009JEP03001oogoo02=o
o`04001JEUYF000^Ool002moo`80009JEP04001oogooOol20004FUH00`00FUIJEP07FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20005FUH01@00FUH005YF00001UYF00<005YFFUH0
1UYF0`001eYF00<005YFFUH015YF0P000eYF0`0035YF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH00UYF00<007ooOol02Goo0`0067oo00@0
05YFFUH002eoo`00;Woo00<005YF00000P001Woo0`0000=JEP00FUH01eYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`000eYF00D005YF001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00@0009JEP03001JEUYF00EJEP05001JEP00001JEP03000<FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH300000eYF001JEP05FUH00`00FUIJEP02FUH00`00Oomoo`08Ool5000G
Ool01000FUIJEP00;Goo000^Ool01000FUH000002Woo10001UYF00<005YF00000P0015YF00<005YF
FUH01EYF00<005YF00000`000goo00P005YFFUH005YF001JEP001UYF00<005YFFUH01UYF00<005YF
FUH015YF1P000eYF00<005YFFUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF1@001UYF00@005YFFUIJEP8000Yoo`D001Qoo`<002eoo`00;Woo10003Woo
10000UYF1P000eYF00<005YFFUH00UYF1@0027oo0`0000AJEP00FUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEPH0009JEP05001JEP00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH300000eYF00000004FUH00`00FUIJEP02FUH00`00Oomoo`09Ool5000HOol200000eYF
001oo`0[Ool002ioo`<00003FUH007oo011ooa0000moo`05001JEP00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP03FUH40002FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH01P00FUH005YF001JEP<00003FUH005YF00=JEP03001oogoo00Yo
o`<001Yoo`03001JEP0002aoo`00;Woo00<005YF00000UYF00<007ooOol04Goo1@0067oo0P0000=J
EP00FUH01EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF00@005YFFUIJEP8000AJ
EP03001oogoo02Moo`03001JEP0002aoo`00;Woo0P000eYF0`004Woo0`006Woo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000eYF0P0000=JEP00FUH00P0000=JEP000000
:Goo00<005YF0000;7oo000^Ool20003FUH00`00FUIJEP02000]Ool00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH01000FUH000000UYF1P0000=JEP000000:goo00<007ooOol0:goo000^
Ool20003FUH00`00FUIJEP02FUH3000ZOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP04FUH<0006FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000
FUH000000UYF00<005YF00000eYF0`00:goo00<007ooOol0:goo000_Ool01@00FUIJEUYF00001EYF
00@005YF000002Ioo`<00003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP`0009JEP03
001JEUYF00MJEPT000QJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEP00FUH20003FUH20002
FUH00`00FUH00002000WOol2000]Ool002moo`04001JEUYF0006FUH01000FUIJEUYF0`008Goo1@00
00=JEP00FUH01EYF00<005YFFUH015YF2@0000=JEP00FUH02eYF00<005YFFUH02UYF00<005YFFUH0
0eYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF00@005YF001JEP8000EJEP03001JEP0000AJ
EP8002Eoo`8002eoo`00<7oo00<005YF00001UYF00<005YFFUH015YF100047oo3@000UYF0`0000=J
EP00FUH01EYF00<005YFFUH010002UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
1P001UYF00<005YFFUH00UYF00@005YF001JEP8000IJEP8000EJEP80029oo`<002ioo`00<7oo00<0
05YF00001UYF00<005YFFUH01EYF00<005YFFUH010000goo2@000eYF00<005YFFUH015YF1@0000EJ
EP00001JEP0000EJEP@000=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00=JEP@0009JEP03001JEUYF009JEP06001JEP00FUH005YF0P0015YF00@0
05YF000000=JEP03001JEP0001moo`800003FUH0000002ioo`00<Goo0P001EYF00<005YFFUH01UYF
00<005YFFUH01`0015YF00<005YFFUH01EYF1`000UYF00@005YFFUIJEP800003FUH005YF009JEP80
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00MJEP<000AJEP05001JEP00FUH00003FUH01000FUIJEP0015YF0`000eYF00<007ooOol06goo00D0
05YFFUIJEP0002moo`00<Woo00<005YFFUH00eYF00<005YFFUH01EYF10000UYF00<005YFFUH01UYF
00<005YF00001@000eYF00<005YFFUH00eYF00<005YFFUH00UYF00@005YF001JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF0080009JEP05001JEP00FUH00004FUH30007FUH4000KOol30003FUH00`00Oomoo`0]Ool003=o
o`8000=JEP03001JEP0000D000IJEP03001JEUYF00AJEP@0009JEP03001JEUYF00AJEP03001JEUYF
00AJEP06001JEUYFFUH005YF0P000UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YFFUH00UYF0`0000=JEP000000
1eYF00<005YFFUH01UYF00<005YFFUH010005Goo0P000UYF00@005YFFUH0031oo`00=7oo1P000eYF
00<005YFFUH01UYF1`001UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00`0015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01eYF00<005YFFUH00eYF0P0000AJEP00000000MJEP8000IJEP03001JEUYF00AJEPH000Uo
o`H000AJEP03001JEP00035oo`00;goo1@000UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF
00<005YFFUH01EYF00@005YFFUIJEPP000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00=JEP800003FUH0
000000<000AJEP03001JEUYF008000=JEP03001JEUYF00MJEP04001JEUYFFUH90004FUH00`00FUIJ
EP03FUH2000bOol002aoo`<00003FUH0000000`000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00AJEPD0009JEP04001JEP00Ool20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01000
FUH0000015YF0`0000=JEP00FUH00eYF0P0000=JEP00FUH025YF00<005YFFUH01EYF00<005YFFUH0
1EYF00<005YFFUH00eYF0P00<goo000[Ool50002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP050006FUH20002Ool20004FUH00`00FUIJEP06FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH01000FUH000001UYF100015YF1@001UYF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YF00000`00=Goo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH70004FUH00`00FUIJEP03FUH20003Ool20004FUH00`00FUIJEP06
FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07
FUH00`00FUIJEP03FUH01000FUIJEP001UYF00@005YFFUIJEP<00003FUH005YF009JEPD0009JEP03
001JEUYF00IJEP03001JEUYF009JEPD003Uoo`00:goo00<005YF000015YF00<005YFFUH015YF00<0
05YFFUH01UYF00<005YFFUH00UYF20000eYF00<005YFFUH01EYF00<005YF00000`001Woo00<005YF
FUH00UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF00001eYF00H005YFFUIJEP00FUH30002
FUH00`00FUH00003Ool@000nOol002aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF009J
EPT0009JEP03001JEUYF00IJEP03001JEUYF009JEPD000Yoo`03001JEUYF009JEP03001JEUYF00IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000QJEP04001JEUYF0002FUH00`00FUIJEP0300000eYF001oo`1@Ool002ao
o`03001JEP0000AJEP04001JEUYFFUH70009Ool@000@Ool20002FUH00`00FUIJEP06FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH20008FUH01000FUIJEP000eYF00@005YFFUIJEP80059oo`00;7oo2`00<Woo0`0025YF00<0
05YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00@0
05YFFUIJEP<000QJEP03001JEUYF008000=JEP03001JEUYF00<0059oo`00Jgoo0P001eYF00<005YF
FUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF00<005YF
0000200015YF00<005YF00000UYF00<005YF00000eYF00<005YF0000DWoo001]Ool30004FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH40009
Ool60003FUH01000FUH005YF1000Dgoo001`Ool300000eYF001JEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06000@Ool00`00FUIJEP03FUH3001GOol007=oo`@0
00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEPD0009oo`D000eoo`<000EJEP03
001oogoo05Moo`00Mgoo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH01P001goo
1@0037oo00@005YFFUH000AJEP03001oogoo05Qoo`00OGoo7`003Goo1@002goo00<005YFFUH00UYF
00@005YF000005]oo`00SGoo00<005YF00000eYF00<007ooOol057oo0`002Woo0P001EYF0P00GGoo
002=Ool00`00FUH00002FUH00`00Oomoo`0POol20007FUH00`00Oomoo`1LOol008aoo`04001JEUYF
FUH2000QOol200000eYF001JEP04FUH2001OOol008aoo`05001JEUYFFUH0000OOol30004FUH01@00
FUIJEUYF0000HGoo002<Ool01000FUIJEP007Goo0`001eYF00@005YF0000069oo`00SGoo00<005YF
00006Woo0`0000=JEP00FUH025YF00<007ooOol0HWoo002=Ool2000HOol30005FUH00`00FUIJEP04
FUH2001UOol008eoo`03FUH0000001Aoo`<000QJEP03001JEUYF009JEP8006Moo`00SGoo0P0000AJ
EP00000000eoo`@00003FUH005YF00UJEP04001JEP00001YOol008ioo`03001JEP00009JEPd000IJ
EP03001JEUYF00IJEP<006]oo`00SWoo00@005YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJ
EP03001JEUYF00=JEP<006ioo`00SWoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEP000080075oo`00Sgoo0P0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF
0`00M7oo002AOol40002FUH00`00FUIJEP05FUH00`00FUIJEP04001gOol009Eoo`d007]oo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]66\[InvisibleSpace]"     "\
\[InvisibleSpace]15.278805936283119`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 66, "     ", 15.278805936283119, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59543 .71229 m .56429 .71127 L p .58824 .74739 L .707 .577 .707 r
F P
0 g
s
.59818 .74815 m .59543 .71229 L p .58824 .74739 L .707 .577 .707 r
F P
0 g
s
.59457 .77261 m .62597 .77759 L p .61428 .75819 L .707 .577 .707 r
F P
0 g
s
.61428 .75819 m .60835 .74835 L .60577 .75289 L .707 .577 .707 r
F
.61428 .75819 m .60577 .75289 L .59457 .77261 L F
.59818 .74815 m .59457 .77261 L p .60835 .74835 L F P
0 g
s
.59457 .77261 m .59818 .74815 L p .57875 .74666 L .707 .577 .707 r
F P
0 g
s
.56429 .71127 m .53679 .706 L p .55347 .7363 L .707 .577 .707 r
F P
0 g
s
.58663 .75959 m .57532 .75164 L .56354 .76873 L .707 .577 .707 r
F
.56693 .74576 m .56354 .76873 L p .57532 .75164 L F P
0 g
s
.57875 .74666 m .56693 .74576 L .57532 .75164 L .707 .577 .707 r
F
.53594 .76632 m .56354 .76873 L p .54963 .74329 L F P
0 g
s
.55797 .74448 m .55347 .7363 L .54939 .74326 L .707 .577 .707 r
F
.53955 .74186 m .53594 .76632 L p .54651 .74855 L F P
0 g
s
.54963 .74329 m .53955 .74186 L .54651 .74855 L .707 .577 .707 r
F
.53679 .706 m .51565 .69701 L p .5306 .73325 L F P
0 g
s
.53355 .74041 m .53955 .74186 L .5306 .73325 L .707 .577 .707 r
F
.53955 .74186 m .53679 .706 L p .5306 .73325 L F P
0 g
s
.55347 .7363 m .55188 .73519 L .54804 .74307 L .707 .577 .707 r
F
.55347 .7363 m .54804 .74307 L .54939 .74326 L F
.5383 .72565 m .53955 .74186 L p .55188 .73519 L F P
0 g
s
.53955 .74186 m .54078 .75794 L p .55188 .73519 L .707 .577 .707 r
F P
0 g
s
.53679 .706 m .5383 .72565 L p .55347 .7363 L .707 .577 .707 r
F P
0 g
s
.56354 .76873 m .56693 .74576 L p .54963 .74329 L .707 .577 .707 r
F P
0 g
s
.56827 .7632 m .56693 .74576 L p .55347 .7363 L .707 .577 .707 r
F P
0 g
s
.56693 .74576 m .56429 .71127 L p .55347 .7363 L .707 .577 .707 r
F P
0 g
s
.56555 .7278 m .56827 .7632 L p .58209 .73811 L .707 .577 .707 r
F P
0 g
s
.56913 .73088 m .54152 .72847 L p .54963 .74329 L .707 .577 .707 r
F P
0 g
s
.56693 .74576 m .56913 .73088 L p .54963 .74329 L .707 .577 .707 r
F P
0 g
s
.54939 .74326 m .54804 .74307 L .54078 .75794 L .707 .577 .707 r
F
.53594 .76632 m .53955 .74186 L p .52433 .73819 L F P
0 g
s
.51445 .76562 m .53594 .76632 L p .52433 .73819 L .707 .577 .707 r
F P
0 g
s
.5187 .73683 m .51445 .76562 L p .52247 .74335 L .707 .577 .707 r
F P
0 g
s
.52433 .73819 m .5187 .73683 L .52247 .74335 L .707 .577 .707 r
F
.51565 .69701 m .50291 .68517 L p .51458 .72969 L F P
0 g
s
.5187 .73683 m .51565 .69701 L p .51458 .72969 L .707 .577 .707 r
F P
0 g
s
.51565 .69701 m .5187 .73683 L p .53355 .74041 L .707 .577 .707 r
F P
0 g
s
.51445 .76562 m .5187 .73683 L p .50735 .73158 L .707 .577 .707 r
F P
0 g
s
.51445 .76562 m .50735 .73158 L .50689 .7342 L .707 .577 .707 r
F
.50119 .7667 m .5116 .76585 L p .50689 .7342 L F P
0 g
s
.5116 .76585 m .51445 .76562 L p .50689 .7342 L .707 .577 .707 r
F P
0 g
s
.50291 .68517 m .49982 .67164 L p .50576 .72661 L .707 .577 .707 r
F P
0 g
s
.50644 .73116 m .50119 .7667 L p .50735 .73158 L .707 .577 .707 r
F P
0 g
s
.50119 .7667 m .50644 .73116 L p .50304 .73161 L .707 .577 .707 r
F P
0 g
s
.50619 .73059 m .50644 .73116 L .50576 .72661 L .707 .577 .707 r
F
.50644 .73116 m .50291 .68517 L p .50576 .72661 L F P
0 g
s
.50291 .68517 m .50644 .73116 L p .51615 .73564 L .707 .577 .707 r
F P
0 g
s
.50576 .7296 m .50304 .73161 L p .50644 .73116 L .707 .577 .707 r
F P
0 g
s
.49982 .67164 m .50381 .72358 L .50386 .72381 L p .707 .577 .707 r
F P
0 g
s
.50386 .72381 m .50689 .73711 L p .50217 .69337 L .707 .577 .707 r
F P
0 g
s
.50217 .69337 m .49982 .67164 L .50386 .72381 L .707 .577 .707 r
F
.50304 .73161 m .49745 .76946 L .50119 .7667 L p F P
0 g
s
.49745 .76946 m .50304 .73161 L .50435 .73249 L p .707 .577 .707 r
F P
0 g
s
.50689 .73711 m .50644 .73116 L p .50619 .73059 L .707 .577 .707 r
F P
0 g
s
.50689 .73711 m .51963 .74894 L p .51615 .73564 L .707 .577 .707 r
F P
0 g
s
.50644 .73116 m .50689 .73711 L p .51615 .73564 L .707 .577 .707 r
F P
0 g
s
.50435 .73249 m .50919 .73577 L p .50517 .7473 L .707 .577 .707 r
F P
0 g
s
.49745 .76946 m .50435 .73249 L .50517 .7473 L .707 .577 .707 r
F
.50644 .73116 m .50678 .72885 L .50576 .7296 L p F P
0 g
s
.50678 .72885 m .50644 .73116 L p .50735 .73158 L .707 .577 .707 r
F P
0 g
s
.52004 .72777 m .50678 .72885 L p .50735 .73158 L .707 .577 .707 r
F P
0 g
s
.51615 .73564 m .5187 .73683 L .51458 .72969 L .707 .577 .707 r
F
.5187 .73683 m .52004 .72777 L p .50735 .73158 L F P
0 g
s
.51963 .74894 m .5187 .73683 L p .51615 .73564 L .707 .577 .707 r
F P
0 g
s
.51963 .74894 m .54078 .75794 L p .53355 .74041 L .707 .577 .707 r
F P
0 g
s
.5187 .73683 m .51963 .74894 L p .53355 .74041 L .707 .577 .707 r
F P
0 g
s
.52004 .72777 m .5187 .73683 L p .52433 .73819 L .707 .577 .707 r
F P
0 g
s
.54152 .72847 m .52004 .72777 L p .52433 .73819 L .707 .577 .707 r
F P
0 g
s
.53955 .74186 m .54152 .72847 L p .52433 .73819 L .707 .577 .707 r
F P
0 g
s
.54078 .75794 m .53955 .74186 L p .53355 .74041 L .707 .577 .707 r
F P
0 g
s
.54152 .72847 m .53955 .74186 L p .54963 .74329 L .707 .577 .707 r
F P
0 g
s
.54078 .75794 m .56827 .7632 L p .55797 .74448 L .707 .577 .707 r
F P
0 g
s
.55797 .74448 m .54939 .74326 L .54078 .75794 L .707 .577 .707 r
F
.56354 .76873 m .59457 .77261 L p .58663 .75959 L F P
0 g
s
.58663 .75959 m .57875 .74666 L .57532 .75164 L .707 .577 .707 r
F
.58824 .74739 m .58209 .73811 L .57744 .74656 L F
.56913 .73088 m .56693 .74576 L p .57875 .74666 L F P
0 g
s
.56827 .7632 m .59941 .76423 L p .58824 .74739 L .707 .577 .707 r
F P
0 g
s
.58824 .74739 m .57744 .74656 L .56827 .7632 L .707 .577 .707 r
F
.56429 .71127 m .56555 .7278 L p .58209 .73811 L F P
0 g
s
.59543 .71229 m .59818 .74815 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.62717 .70898 m .59543 .71229 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.63022 .7488 m .62717 .70898 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.62597 .77759 m .65469 .78318 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.63022 .7488 m .62597 .77759 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.62717 .70898 m .63022 .7488 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.6564 .70164 m .62717 .70898 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.65993 .74763 m .6564 .70164 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.6564 .70164 m .65993 .74763 L p .68426 .74295 L .707 .577 .707 r
F P
0 g
s
.65469 .78318 m .6779 .78883 L p .66115 .74749 L .707 .577 .707 r
F P
0 g
s
.65993 .74763 m .65469 .78318 L p .66115 .74749 L .707 .577 .707 r
F P
0 g
s
.67864 .74545 m .68426 .74295 L p .65993 .74763 L .707 .577 .707 r
F P
0 g
s
.6779 .78883 m .68348 .75097 L .66027 .74533 L p .707 .577 .707 r
F P
0 g
s
.65993 .74763 m .66039 .75358 L .67864 .74545 L p .707 .577 .707 r
F P
0 g
s
.66027 .74533 m .65993 .74763 L p .66115 .74749 L .707 .577 .707 r
F P
0 g
s
.66027 .74533 m .63156 .73974 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.65469 .78318 m .65993 .74763 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.65993 .74763 m .66027 .74533 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.66039 .75358 m .65993 .74763 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.63115 .76091 m .66039 .75358 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.63022 .7488 m .63115 .76091 L p .65607 .74779 L .707 .577 .707 r
F P
0 g
s
.63156 .73974 m .63022 .7488 L p .63626 .74856 L .707 .577 .707 r
F P
0 g
s
.63156 .73974 m .60015 .73476 L p .60835 .74835 L .707 .577 .707 r
F P
0 g
s
.62597 .77759 m .63022 .7488 L p .60835 .74835 L .707 .577 .707 r
F P
0 g
s
.63022 .7488 m .63156 .73974 L p .60835 .74835 L .707 .577 .707 r
F P
0 g
s
.63115 .76091 m .63022 .7488 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.59941 .76423 m .63115 .76091 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.59818 .74815 m .59941 .76423 L p .62213 .74863 L .707 .577 .707 r
F P
0 g
s
.60015 .73476 m .59818 .74815 L p .60835 .74835 L .707 .577 .707 r
F P
0 g
s
.60015 .73476 m .56913 .73088 L p .57875 .74666 L .707 .577 .707 r
F P
0 g
s
.59818 .74815 m .60015 .73476 L p .57875 .74666 L .707 .577 .707 r
F P
0 g
s
.59941 .76423 m .59818 .74815 L p .58824 .74739 L .707 .577 .707 r
F P
0 g
s
.68426 .74295 m .68027 .69101 L .6564 .70164 L p .707 .577 .707 r
F P
0 g
s
.68027 .69101 m .68426 .74295 L .70042 .73006 L p .707 .577 .707 r
F P
0 g
s
.70042 .73006 m .69643 .67812 L .68027 .69101 L p .707 .577 .707 r
F P
0 g
s
.60104 .86974 m .59945 .85274 L .56832 .85188 L p .707 .577 .707 r
F P
0 g
s
.59945 .85274 m .60104 .86974 L .63274 .86595 L p .707 .577 .707 r
F P
0 g
s
.63274 .86595 m .63115 .84895 L .59945 .85274 L p .707 .577 .707 r
F P
0 g
s
.63115 .84895 m .63274 .86595 L .66191 .85787 L p .707 .577 .707 r
F P
0 g
s
.66191 .85787 m .66032 .84087 L .63115 .84895 L p .707 .577 .707 r
F P
0 g
s
.68348 .75097 m .6779 .78883 L .69333 .79398 L p .707 .577 .707 r
F P
0 g
s
.69643 .67812 m .70042 .73006 L .7073 .71617 L p .707 .577 .707 r
F P
0 g
s
.7073 .71617 m .70331 .66423 L .69643 .67812 L p .707 .577 .707 r
F P
0 g
s
.69333 .79398 m .69892 .75613 L .68348 .75097 L p .707 .577 .707 r
F P
0 g
s
.56991 .86888 m .56832 .85188 L .54082 .84645 L p .707 .577 .707 r
F P
0 g
s
.56832 .85188 m .56991 .86888 L .60104 .86974 L p .707 .577 .707 r
F P
0 g
s
.66032 .84087 m .66191 .85787 L .6857 .8463 L p .707 .577 .707 r
F P
0 g
s
.6857 .8463 m .68411 .8293 L .66032 .84087 L p .707 .577 .707 r
F P
0 g
s
.54082 .84645 m .54241 .86345 L .56991 .86888 L p .707 .577 .707 r
F P
0 g
s
.54241 .86345 m .54082 .84645 L .51963 .83698 L p .707 .577 .707 r
F P
0 g
s
.68411 .8293 m .6857 .8463 L .70177 .83238 L p .707 .577 .707 r
F P
0 g
s
.70177 .83238 m .70019 .81538 L .68411 .8293 L p .707 .577 .707 r
F P
0 g
s
.69892 .75613 m .69333 .79398 L .69948 .79814 L p .707 .577 .707 r
F P
0 g
s
.51963 .83698 m .52121 .85398 L .54241 .86345 L p .707 .577 .707 r
F P
0 g
s
.70331 .66423 m .7073 .71617 L .70422 .70264 L p .707 .577 .707 r
F P
0 g
s
.70422 .70264 m .70023 .65071 L .70331 .66423 L p .707 .577 .707 r
F P
0 g
s
.69948 .79814 m .70507 .76029 L .69892 .75613 L p .707 .577 .707 r
F P
0 g
s
.52121 .85398 m .51963 .83698 L .50683 .8244 L p .707 .577 .707 r
F P
0 g
s
.50381 .72358 m .49982 .67164 L .5067 .65776 L p .707 .577 .707 r
F P
0 g
s
.48679 .82046 m .49225 .31511 L .44824 .31223 L p .707 .577 .707 r
F P
0 g
s
.50841 .8414 m .50683 .8244 L .50367 .80994 L p .707 .577 .707 r
F P
0 g
s
.50919 .73577 m .5036 .77362 L .49745 .76946 L p .707 .577 .707 r
F P
0 g
s
.5067 .65776 m .51069 .70969 L .50381 .72358 L p .707 .577 .707 r
F P
0 g
s
.51069 .70969 m .5067 .65776 L .52287 .64487 L p .707 .577 .707 r
F P
0 g
s
.50367 .80994 m .50525 .82694 L .50841 .8414 L p .707 .577 .707 r
F P
0 g
s
.50525 .82694 m .50367 .80994 L .51046 .79501 L p .707 .577 .707 r
F P
0 g
s
.52462 .74092 m .51904 .77877 L .5036 .77362 L p .707 .577 .707 r
F P
0 g
s
.5036 .77362 m .50919 .73577 L .52462 .74092 L p .707 .577 .707 r
F P
0 g
s
.52287 .64487 m .52686 .6968 L .51069 .70969 L p .707 .577 .707 r
F P
0 g
s
.51046 .79501 m .51204 .81201 L .50525 .82694 L p .707 .577 .707 r
F P
0 g
s
.51204 .81201 m .51046 .79501 L .52653 .78108 L p .707 .577 .707 r
F P
0 g
s
.54783 .74657 m .54225 .78442 L .51904 .77877 L p .707 .577 .707 r
F P
0 g
s
.51904 .77877 m .52462 .74092 L .54783 .74657 L p .707 .577 .707 r
F P
0 g
s
.52653 .78108 m .52812 .79808 L .51204 .81201 L p .707 .577 .707 r
F P
0 g
s
.54225 .78442 m .54783 .74657 L .57655 .75216 L p .707 .577 .707 r
F P
0 g
s
.52812 .79808 m .52653 .78108 L .55032 .76952 L p .707 .577 .707 r
F P
0 g
s
.57655 .75216 m .57096 .79001 L .54225 .78442 L p .707 .577 .707 r
F P
0 g
s
.55032 .76952 m .55191 .78652 L .52812 .79808 L p .707 .577 .707 r
F P
0 g
s
.49225 .31511 m .48679 .82046 L .53173 .81992 L p .707 .577 .707 r
F P
0 g
s
.52686 .6968 m .52287 .64487 L .54674 .63423 L p .707 .577 .707 r
F P
0 g
s
.54674 .63423 m .55072 .68617 L .52686 .6968 L p .707 .577 .707 r
F P
0 g
s
.53173 .81992 m .53719 .31457 L .49225 .31511 L p .707 .577 .707 r
F P
0 g
s
.50683 .8244 m .50841 .8414 L .52121 .85398 L p .707 .577 .707 r
F P
0 g
s
.70019 .81538 m .70177 .83238 L .70856 .81745 L p .707 .577 .707 r
F P
0 g
s
.70856 .81745 m .70698 .80045 L .70019 .81538 L p .707 .577 .707 r
F P
0 g
s
.54674 .63423 m .57597 .6269 L p .55136 .68467 L .707 .577 .707 r
F P
0 g
s
.55072 .68617 m .55044 .68249 L p .55136 .68467 L .707 .577 .707 r
F P
0 g
s
.55044 .68249 m .54674 .63423 L p .55136 .68467 L .707 .577 .707 r
F P
0 g
s
.57996 .67883 m .57597 .6269 L .60771 .62358 L p .707 .577 .707 r
F P
0 g
s
.57597 .6269 m .57996 .67883 L .55072 .68617 L p .707 .577 .707 r
F P
0 g
s
.60771 .62358 m .6117 .67552 L .57996 .67883 L p .707 .577 .707 r
F P
0 g
s
.63898 .76102 m .63339 .79887 L .60876 .79579 L p .707 .577 .707 r
F P
0 g
s
.60876 .79579 m .60237 .79499 L p .60942 .78844 L .707 .577 .707 r
F P
0 g
s
.60942 .78844 m .63898 .76102 L .60876 .79579 L .707 .577 .707 r
F
.63885 .62461 m .64284 .67654 L .6117 .67552 L p F P
0 g
s
.6117 .67552 m .60771 .62358 L .63885 .62461 L p .707 .577 .707 r
F P
0 g
s
.63339 .79887 m .63898 .76102 L .66658 .76343 L p .707 .577 .707 r
F P
0 g
s
.60237 .79499 m .60795 .75714 L .63898 .76102 L p .707 .577 .707 r
F P
0 g
s
.64232 .75851 m .64391 .77551 L .61278 .77465 L p .707 .577 .707 r
F P
0 g
s
.61278 .77465 m .61119 .75765 L .64232 .75851 L p .707 .577 .707 r
F P
0 g
s
.63026 .79995 m .64025 .78936 L p .63741 .47938 L .707 .577 .707 r
F P
0 g
s
.63572 .2946 m .63322 .52563 L p .63741 .47938 L .707 .577 .707 r
F P
0 g
s
.63322 .52563 m .63026 .79995 L p .63741 .47938 L .707 .577 .707 r
F P
0 g
s
.60795 .75714 m .60237 .79499 L .57321 .79036 L p .707 .577 .707 r
F P
0 g
s
.57321 .79036 m .57096 .79001 L p .57386 .78743 L .707 .577 .707 r
F P
0 g
s
.57386 .78743 m .60795 .75714 L .57321 .79036 L .707 .577 .707 r
F
.57096 .79001 m .57655 .75216 L .60795 .75714 L p F P
0 g
s
.58108 .77844 m .57949 .76144 L .61119 .75765 L p .707 .577 .707 r
F P
0 g
s
.61119 .75765 m .61278 .77465 L .58108 .77844 L p .707 .577 .707 r
F P
0 g
s
.60716 .80914 m .63026 .79995 L p .62203 .56858 L .707 .577 .707 r
F P
0 g
s
.61261 .30379 m .60912 .62723 L p .62203 .56858 L .707 .577 .707 r
F P
0 g
s
.60912 .62723 m .60716 .80914 L p .62203 .56858 L .707 .577 .707 r
F P
0 g
s
.57866 .31067 m .57404 .73851 L p .60716 .80914 L .707 .577 .707 r
F P
0 g
s
.55191 .78652 m .55032 .76952 L .57949 .76144 L p .707 .577 .707 r
F P
0 g
s
.57949 .76144 m .58108 .77844 L .56102 .784 L p .707 .577 .707 r
F P
0 g
s
.56102 .784 m .55191 .78652 L p .55901 .78006 L .707 .577 .707 r
F P
0 g
s
.55901 .78006 m .57949 .76144 L .56102 .784 L .707 .577 .707 r
F
.57404 .73851 m .57329 .80799 L p .60406 .80977 L F P
0 g
s
.57329 .80799 m .57321 .81602 L .57701 .81525 L p .707 .577 .707 r
F P
0 g
s
.57701 .81525 m .60406 .80977 L p .57329 .80799 L .707 .577 .707 r
F P
0 g
s
.60406 .80977 m .60716 .80914 L p .57404 .73851 L .707 .577 .707 r
F P
0 g
s
.53719 .31457 m .53173 .81992 L .57321 .81602 L p .707 .577 .707 r
F P
0 g
s
.57321 .81602 m .57866 .31067 L .53719 .31457 L p .707 .577 .707 r
F P
0 g
s
.70507 .76029 m .69948 .79814 L .69574 .8009 L p .707 .577 .707 r
F P
0 g
s
.44278 .81758 m .44824 .31223 L .40947 .30622 L p .707 .577 .707 r
F P
0 g
s
.44824 .31223 m .44278 .81758 L .48679 .82046 L p .707 .577 .707 r
F P
0 g
s
.70023 .65071 m .70422 .70264 L .69148 .6908 L p .707 .577 .707 r
F P
0 g
s
.69148 .6908 m .68749 .63887 L .70023 .65071 L p .707 .577 .707 r
F P
0 g
s
.69574 .8009 m .70133 .76304 L .70507 .76029 L p .707 .577 .707 r
F P
0 g
s
.60716 .80914 m .61261 .30379 L .57866 .31067 L p .707 .577 .707 r
F P
0 g
s
.70698 .80045 m .70856 .81745 L .7054 .80299 L p .707 .577 .707 r
F P
0 g
s
.7054 .80299 m .70382 .78599 L .70698 .80045 L p .707 .577 .707 r
F P
0 g
s
.25242 .67548 m .22128 .67445 L p .24523 .71057 L .707 .577 .707 r
F P
0 g
s
.25517 .71133 m .25242 .67548 L p .24523 .71057 L .707 .577 .707 r
F P
0 g
s
.25156 .7358 m .28296 .74078 L p .27127 .72138 L .707 .577 .707 r
F P
0 g
s
.27127 .72138 m .26534 .71154 L .26276 .71607 L .707 .577 .707 r
F
.27127 .72138 m .26276 .71607 L .25156 .7358 L F
.25517 .71133 m .25156 .7358 L p .26534 .71154 L F P
0 g
s
.25156 .7358 m .25517 .71133 L p .23574 .70985 L .707 .577 .707 r
F P
0 g
s
.22128 .67445 m .19379 .66919 L p .21046 .69949 L .707 .577 .707 r
F P
0 g
s
.24362 .72277 m .23231 .71483 L .22053 .73191 L .707 .577 .707 r
F
.22393 .70894 m .22053 .73191 L p .23231 .71483 L F P
0 g
s
.23574 .70985 m .22393 .70894 L .23231 .71483 L .707 .577 .707 r
F
.19293 .7295 m .22053 .73191 L p .20662 .70648 L F P
0 g
s
.21496 .70767 m .21046 .69949 L .20638 .70644 L .707 .577 .707 r
F
.19654 .70504 m .19293 .7295 L p .2035 .71173 L F P
0 g
s
.20662 .70648 m .19654 .70504 L .2035 .71173 L .707 .577 .707 r
F
.19379 .66919 m .17264 .66019 L p .18759 .69644 L F P
0 g
s
.19054 .70359 m .19654 .70504 L .18759 .69644 L .707 .577 .707 r
F
.19654 .70504 m .19379 .66919 L p .18759 .69644 L F P
0 g
s
.21046 .69949 m .20887 .69837 L .20503 .70625 L .707 .577 .707 r
F
.21046 .69949 m .20503 .70625 L .20638 .70644 L F
.1953 .68884 m .19654 .70504 L p .20887 .69837 L F P
0 g
s
.19654 .70504 m .19777 .72112 L p .20887 .69837 L .707 .577 .707 r
F P
0 g
s
.19379 .66919 m .1953 .68884 L p .21046 .69949 L .707 .577 .707 r
F P
0 g
s
.22053 .73191 m .22393 .70894 L p .20662 .70648 L .707 .577 .707 r
F P
0 g
s
.22526 .72639 m .22393 .70894 L p .21046 .69949 L .707 .577 .707 r
F P
0 g
s
.22393 .70894 m .22128 .67445 L p .21046 .69949 L .707 .577 .707 r
F P
0 g
s
.22255 .69098 m .22526 .72639 L p .23908 .7013 L .707 .577 .707 r
F P
0 g
s
.22612 .69406 m .19852 .69165 L p .20662 .70648 L .707 .577 .707 r
F P
0 g
s
.22393 .70894 m .22612 .69406 L p .20662 .70648 L .707 .577 .707 r
F P
0 g
s
.20638 .70644 m .20503 .70625 L .19777 .72112 L .707 .577 .707 r
F
.19293 .7295 m .19654 .70504 L p .18133 .70137 L F P
0 g
s
.17144 .72881 m .19293 .7295 L p .18133 .70137 L .707 .577 .707 r
F P
0 g
s
.17569 .70001 m .17144 .72881 L p .17946 .70654 L .707 .577 .707 r
F P
0 g
s
.18133 .70137 m .17569 .70001 L .17946 .70654 L .707 .577 .707 r
F
.17264 .66019 m .1599 .64835 L p .17158 .69288 L F P
0 g
s
.17569 .70001 m .17264 .66019 L p .17158 .69288 L .707 .577 .707 r
F P
0 g
s
.17264 .66019 m .17569 .70001 L p .19054 .70359 L .707 .577 .707 r
F P
0 g
s
.17144 .72881 m .17569 .70001 L p .16434 .69477 L .707 .577 .707 r
F P
0 g
s
.17144 .72881 m .16434 .69477 L .16388 .69738 L .707 .577 .707 r
F
.15818 .72989 m .16859 .72904 L p .16388 .69738 L F P
0 g
s
.16859 .72904 m .17144 .72881 L p .16388 .69738 L .707 .577 .707 r
F P
0 g
s
.1599 .64835 m .15682 .63483 L p .16275 .68979 L .707 .577 .707 r
F P
0 g
s
.16343 .69434 m .15818 .72989 L p .16434 .69477 L .707 .577 .707 r
F P
0 g
s
.15818 .72989 m .16343 .69434 L p .16003 .69479 L .707 .577 .707 r
F P
0 g
s
.16318 .69377 m .16343 .69434 L .16275 .68979 L .707 .577 .707 r
F
.16343 .69434 m .1599 .64835 L p .16275 .68979 L F P
0 g
s
.1599 .64835 m .16343 .69434 L p .17314 .69883 L .707 .577 .707 r
F P
0 g
s
.16275 .69278 m .16003 .69479 L p .16343 .69434 L .707 .577 .707 r
F P
0 g
s
.15682 .63483 m .1608 .68676 L .16086 .68699 L p .707 .577 .707 r
F P
0 g
s
.16086 .68699 m .16389 .70029 L p .15916 .65655 L .707 .577 .707 r
F P
0 g
s
.15916 .65655 m .15682 .63483 L .16086 .68699 L .707 .577 .707 r
F
.16003 .69479 m .15444 .73264 L .15818 .72989 L p F P
0 g
s
.15444 .73264 m .16003 .69479 L .16134 .69568 L p .707 .577 .707 r
F P
0 g
s
.16389 .70029 m .16343 .69434 L p .16318 .69377 L .707 .577 .707 r
F P
0 g
s
.16389 .70029 m .17662 .71213 L p .17314 .69883 L .707 .577 .707 r
F P
0 g
s
.16343 .69434 m .16389 .70029 L p .17314 .69883 L .707 .577 .707 r
F P
0 g
s
.16134 .69568 m .16618 .69895 L p .16216 .71048 L .707 .577 .707 r
F P
0 g
s
.15444 .73264 m .16134 .69568 L .16216 .71048 L .707 .577 .707 r
F
.16343 .69434 m .16377 .69204 L .16275 .69278 L p F P
0 g
s
.16377 .69204 m .16343 .69434 L p .16434 .69477 L .707 .577 .707 r
F P
0 g
s
.17703 .69096 m .16377 .69204 L p .16434 .69477 L .707 .577 .707 r
F P
0 g
s
.17314 .69883 m .17569 .70001 L .17158 .69288 L .707 .577 .707 r
F
.17569 .70001 m .17703 .69096 L p .16434 .69477 L F P
0 g
s
.17662 .71213 m .17569 .70001 L p .17314 .69883 L .707 .577 .707 r
F P
0 g
s
.17662 .71213 m .19777 .72112 L p .19054 .70359 L .707 .577 .707 r
F P
0 g
s
.17569 .70001 m .17662 .71213 L p .19054 .70359 L .707 .577 .707 r
F P
0 g
s
.17703 .69096 m .17569 .70001 L p .18133 .70137 L .707 .577 .707 r
F P
0 g
s
.19852 .69165 m .17703 .69096 L p .18133 .70137 L .707 .577 .707 r
F P
0 g
s
.19654 .70504 m .19852 .69165 L p .18133 .70137 L .707 .577 .707 r
F P
0 g
s
.19777 .72112 m .19654 .70504 L p .19054 .70359 L .707 .577 .707 r
F P
0 g
s
.19852 .69165 m .19654 .70504 L p .20662 .70648 L .707 .577 .707 r
F P
0 g
s
.19777 .72112 m .22526 .72639 L p .21496 .70767 L .707 .577 .707 r
F P
0 g
s
.21496 .70767 m .20638 .70644 L .19777 .72112 L .707 .577 .707 r
F
.22053 .73191 m .25156 .7358 L p .24362 .72277 L F P
0 g
s
.24362 .72277 m .23574 .70985 L .23231 .71483 L .707 .577 .707 r
F
.24523 .71057 m .23908 .7013 L .23443 .70975 L F
.22612 .69406 m .22393 .70894 L p .23574 .70985 L F P
0 g
s
.22526 .72639 m .2564 .72741 L p .24523 .71057 L .707 .577 .707 r
F P
0 g
s
.24523 .71057 m .23443 .70975 L .22526 .72639 L .707 .577 .707 r
F
.22128 .67445 m .22255 .69098 L p .23908 .7013 L F P
0 g
s
.25242 .67548 m .25517 .71133 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.28416 .67216 m .25242 .67548 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.28722 .71198 m .28416 .67216 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.28296 .74078 m .31168 .74636 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.28722 .71198 m .28296 .74078 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.28416 .67216 m .28722 .71198 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.31339 .66483 m .28416 .67216 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.31692 .71082 m .31339 .66483 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.31339 .66483 m .31692 .71082 L p .34125 .70613 L .707 .577 .707 r
F P
0 g
s
.31168 .74636 m .33489 .75201 L p .31814 .71068 L .707 .577 .707 r
F P
0 g
s
.31692 .71082 m .31168 .74636 L p .31814 .71068 L .707 .577 .707 r
F P
0 g
s
.33563 .70864 m .34125 .70613 L p .31692 .71082 L .707 .577 .707 r
F P
0 g
s
.33489 .75201 m .34048 .71416 L .31727 .70851 L p .707 .577 .707 r
F P
0 g
s
.31692 .71082 m .31738 .71676 L .33563 .70864 L p .707 .577 .707 r
F P
0 g
s
.31727 .70851 m .31692 .71082 L p .31814 .71068 L .707 .577 .707 r
F P
0 g
s
.31727 .70851 m .28855 .70293 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.31168 .74636 m .31692 .71082 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.31692 .71082 m .31727 .70851 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.31738 .71676 m .31692 .71082 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.28815 .7241 m .31738 .71676 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.28722 .71198 m .28815 .7241 L p .31307 .71097 L .707 .577 .707 r
F P
0 g
s
.28855 .70293 m .28722 .71198 L p .29325 .71174 L .707 .577 .707 r
F P
0 g
s
.28855 .70293 m .25715 .69795 L p .26534 .71154 L .707 .577 .707 r
F P
0 g
s
.28296 .74078 m .28722 .71198 L p .26534 .71154 L .707 .577 .707 r
F P
0 g
s
.28722 .71198 m .28855 .70293 L p .26534 .71154 L .707 .577 .707 r
F P
0 g
s
.28815 .7241 m .28722 .71198 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.2564 .72741 m .28815 .7241 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.25517 .71133 m .2564 .72741 L p .27912 .71182 L .707 .577 .707 r
F P
0 g
s
.25715 .69795 m .25517 .71133 L p .26534 .71154 L .707 .577 .707 r
F P
0 g
s
.25715 .69795 m .22612 .69406 L p .23574 .70985 L .707 .577 .707 r
F P
0 g
s
.25517 .71133 m .25715 .69795 L p .23574 .70985 L .707 .577 .707 r
F P
0 g
s
.2564 .72741 m .25517 .71133 L p .24523 .71057 L .707 .577 .707 r
F P
0 g
s
.40402 .81157 m .40947 .30622 L .37975 .29767 L p .707 .577 .707 r
F P
0 g
s
.40947 .30622 m .40402 .81157 L .44278 .81758 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.68749 .63887 m .69148 .6908 L .67033 .68181 L p .707 .577 .707 r
F P
0 g
s
.67033 .68181 m .66634 .62988 L .68749 .63887 L p .707 .577 .707 r
F P
0 g
s
.70133 .76304 m .69574 .8009 L .68248 .80198 L p .707 .577 .707 r
F P
0 g
s
.34125 .70613 m .33726 .6542 L .31339 .66483 L p .707 .577 .707 r
F P
0 g
s
.68248 .80198 m .68807 .76413 L .70133 .76304 L p .707 .577 .707 r
F P
0 g
s
.63026 .79995 m .63572 .2946 L .61261 .30379 L p .707 .577 .707 r
F P
0 g
s
.70382 .78599 m .7054 .80299 L .6926 .79041 L p .707 .577 .707 r
F P
0 g
s
.6926 .79041 m .69101 .77341 L .70382 .78599 L p .707 .577 .707 r
F P
0 g
s
.66634 .62988 m .67033 .68181 L .64284 .67654 L p .707 .577 .707 r
F P
0 g
s
.64284 .67654 m .63885 .62461 L .66634 .62988 L p .707 .577 .707 r
F P
0 g
s
.33726 .6542 m .34125 .70613 L .35741 .69324 L p .707 .577 .707 r
F P
0 g
s
.35741 .69324 m .35343 .64131 L .33726 .6542 L p .707 .577 .707 r
F P
0 g
s
.37429 .80302 m .37975 .29767 L .36196 .28741 L p .707 .577 .707 r
F P
0 g
s
.37975 .29767 m .37429 .80302 L .40402 .81157 L p .707 .577 .707 r
F P
0 g
s
.68807 .76413 m .68248 .80198 L .661 .80128 L p .707 .577 .707 r
F P
0 g
s
.661 .80128 m .66658 .76343 L .68807 .76413 L p .707 .577 .707 r
F P
0 g
s
.25803 .83292 m .25644 .81592 L .22531 .81506 L p .707 .577 .707 r
F P
0 g
s
.25644 .81592 m .25803 .83292 L .28973 .82913 L p .707 .577 .707 r
F P
0 g
s
.28973 .82913 m .28814 .81213 L .25644 .81592 L p .707 .577 .707 r
F P
0 g
s
.28814 .81213 m .28973 .82913 L .3189 .82106 L p .707 .577 .707 r
F P
0 g
s
.3189 .82106 m .31731 .80406 L .28814 .81213 L p .707 .577 .707 r
F P
0 g
s
.34048 .71416 m .33489 .75201 L .35032 .75717 L p .707 .577 .707 r
F P
0 g
s
.69101 .77341 m .6926 .79041 L .67141 .78094 L p .707 .577 .707 r
F P
0 g
s
.67141 .78094 m .66982 .76394 L .69101 .77341 L p .707 .577 .707 r
F P
0 g
s
.35343 .64131 m .35741 .69324 L .36429 .67935 L p .707 .577 .707 r
F P
0 g
s
.36429 .67935 m .3603 .62742 L .35343 .64131 L p .707 .577 .707 r
F P
0 g
s
.35032 .75717 m .35591 .71932 L .34048 .71416 L p .707 .577 .707 r
F P
0 g
s
.2269 .83206 m .22531 .81506 L .19781 .80963 L p .707 .577 .707 r
F P
0 g
s
.22531 .81506 m .2269 .83206 L .25803 .83292 L p .707 .577 .707 r
F P
0 g
s
.64025 .78936 m .64571 .28401 L .63572 .2946 L p .707 .577 .707 r
F P
0 g
s
.31731 .80406 m .3189 .82106 L .34269 .80949 L p .707 .577 .707 r
F P
0 g
s
.34269 .80949 m .3411 .79249 L .31731 .80406 L p .707 .577 .707 r
F P
0 g
s
.66658 .76343 m .661 .80128 L .63339 .79887 L p .707 .577 .707 r
F P
0 g
s
.19781 .80963 m .1994 .82663 L .2269 .83206 L p .707 .577 .707 r
F P
0 g
s
.1994 .82663 m .19781 .80963 L .17662 .80016 L p .707 .577 .707 r
F P
0 g
s
.35876 .79556 m .35718 .77856 L .3411 .79249 L p .707 .577 .707 r
F P
0 g
s
.35722 .61389 m .3603 .62742 L p .36114 .66295 L .707 .577 .707 r
F P
0 g
s
.36121 .66583 m .36093 .66215 L p .36114 .66295 L .707 .577 .707 r
F P
0 g
s
.36093 .66215 m .35722 .61389 L p .36114 .66295 L .707 .577 .707 r
F P
0 g
s
.35722 .61389 m .36093 .66215 L p .34847 .65399 L .707 .577 .707 r
F P
0 g
s
.36093 .66215 m .36121 .66583 L .36071 .66536 L p .707 .577 .707 r
F P
0 g
s
.36071 .66536 m .34847 .65399 L p .36093 .66215 L .707 .577 .707 r
F P
0 g
s
.35591 .71932 m .35032 .75717 L .35647 .76132 L p .707 .577 .707 r
F P
0 g
s
.35647 .76132 m .36206 .72347 L .35591 .71932 L p .707 .577 .707 r
F P
0 g
s
.36206 .72347 m .35647 .76132 L .35273 .76408 L p .707 .577 .707 r
F P
0 g
s
.34847 .65399 m .34448 .60205 L .35722 .61389 L p .707 .577 .707 r
F P
0 g
s
.35273 .76408 m .35832 .72623 L .36206 .72347 L p .707 .577 .707 r
F P
0 g
s
.35832 .72623 m .35273 .76408 L .33947 .76516 L p .707 .577 .707 r
F P
0 g
s
.33947 .76516 m .34506 .72731 L .35832 .72623 L p .707 .577 .707 r
F P
0 g
s
.36081 .74918 m .36239 .76618 L .3584 .76225 L p .707 .577 .707 r
F P
0 g
s
.3584 .76225 m .34959 .7536 L p .3594 .74973 L .707 .577 .707 r
F P
0 g
s
.3594 .74973 m .36081 .74918 L .3584 .76225 L .707 .577 .707 r
F
.34959 .7536 m .348 .7366 L .35954 .74793 L p F P
0 g
s
.35954 .74793 m .36081 .74918 L p .3594 .74973 L .707 .577 .707 r
F P
0 g
s
.34959 .7536 m .35954 .74793 L .3594 .74973 L .707 .577 .707 r
F
.35653 .78557 m .35803 .6513 L .35689 .64701 L F
.35651 .79276 m .35659 .78473 L p .35653 .78557 L F P
0 g
s
.35659 .78473 m .35803 .6513 L p .35653 .78557 L .707 .577 .707 r
F P
0 g
s
.35278 .7828 m .35605 .79153 L p .35669 .725 L .707 .577 .707 r
F P
0 g
s
.35605 .79153 m .35651 .79276 L p .35653 .78557 L .707 .577 .707 r
F P
0 g
s
.35653 .78557 m .35669 .725 L .35605 .79153 L .707 .577 .707 r
F
.35787 .27645 m .35241 .7818 L .35278 .7828 L p F P
0 g
s
.35669 .725 m .35787 .27645 L .35278 .7828 L .707 .577 .707 r
F
.36196 .28741 m .35787 .27645 L p .35689 .64701 L F P
0 g
s
.35803 .6513 m .36196 .28741 L p .35689 .64701 L .707 .577 .707 r
F P
0 g
s
.3603 .62742 m .36429 .67935 L .36121 .66583 L p .707 .577 .707 r
F P
0 g
s
.35718 .77856 m .35876 .79556 L .36555 .78064 L p .707 .577 .707 r
F P
0 g
s
.36555 .78064 m .36397 .76364 L .35718 .77856 L p .707 .577 .707 r
F P
0 g
s
.36397 .76364 m .36555 .78064 L .36239 .76618 L p .707 .577 .707 r
F P
0 g
s
.36239 .76618 m .36081 .74918 L .36397 .76364 L p .707 .577 .707 r
F P
0 g
s
.36196 .28741 m .35651 .79276 L .37429 .80302 L p .707 .577 .707 r
F P
0 g
s
.66982 .76394 m .67141 .78094 L .64391 .77551 L p .707 .577 .707 r
F P
0 g
s
.64391 .77551 m .64232 .75851 L .66982 .76394 L p .707 .577 .707 r
F P
0 g
s
.3411 .79249 m .34269 .80949 L .35876 .79556 L p .707 .577 .707 r
F P
0 g
s
.17662 .80016 m .17821 .81716 L .1994 .82663 L p .707 .577 .707 r
F P
0 g
s
.17821 .81716 m .17662 .80016 L .16382 .78758 L p .707 .577 .707 r
F P
0 g
s
.64571 .28401 m .64025 .78936 L .63616 .7784 L p .707 .577 .707 r
F P
0 g
s
.63616 .7784 m .64162 .27305 L .64571 .28401 L p .707 .577 .707 r
F P
0 g
s
.1608 .68676 m .15682 .63483 L .16369 .62094 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.16382 .78758 m .1654 .80458 L .17821 .81716 L p .707 .577 .707 r
F P
0 g
s
.35241 .7818 m .35787 .27645 L .36786 .26585 L p .707 .577 .707 r
F P
0 g
s
.1654 .80458 m .16382 .78758 L .16066 .77312 L p .707 .577 .707 r
F P
0 g
s
.16618 .69895 m .16059 .7368 L .15444 .73264 L p .707 .577 .707 r
F P
0 g
s
.16369 .62094 m .16768 .67288 L .1608 .68676 L p .707 .577 .707 r
F P
0 g
s
.16768 .67288 m .16369 .62094 L .17986 .60805 L p .707 .577 .707 r
F P
0 g
s
.16066 .77312 m .16224 .79012 L .1654 .80458 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.34448 .60205 m .34847 .65399 L .32732 .645 L p .707 .577 .707 r
F P
0 g
s
.32732 .645 m .32333 .59306 L .34448 .60205 L p .707 .577 .707 r
F P
0 g
s
.64162 .27305 m .63616 .7784 L .61838 .76813 L p .707 .577 .707 r
F P
0 g
s
.61838 .76813 m .62383 .26279 L .64162 .27305 L p .707 .577 .707 r
F P
0 g
s
.16224 .79012 m .16066 .77312 L .16745 .7582 L p .707 .577 .707 r
F P
0 g
s
.18161 .70411 m .17603 .74196 L .16059 .7368 L p .707 .577 .707 r
F P
0 g
s
.16059 .7368 m .16618 .69895 L .18161 .70411 L p .707 .577 .707 r
F P
0 g
s
.17986 .60805 m .18385 .65999 L .16768 .67288 L p .707 .577 .707 r
F P
0 g
s
.18385 .65999 m .17986 .60805 L .20373 .59742 L p .707 .577 .707 r
F P
0 g
s
.16745 .7582 m .16903 .7752 L .16224 .79012 L p .707 .577 .707 r
F P
0 g
s
.3624 .7712 m .36786 .26585 L .39096 .25667 L p .707 .577 .707 r
F P
0 g
s
.36786 .26585 m .3624 .7712 L .35241 .7818 L p .707 .577 .707 r
F P
0 g
s
.32333 .59306 m .32732 .645 L .29983 .63973 L p .707 .577 .707 r
F P
0 g
s
.29983 .63973 m .29584 .58779 L .32333 .59306 L p .707 .577 .707 r
F P
0 g
s
.20771 .64935 m .20373 .59742 L .23296 .59008 L p .707 .577 .707 r
F P
0 g
s
.20373 .59742 m .20771 .64935 L .18385 .65999 L p .707 .577 .707 r
F P
0 g
s
.34506 .72731 m .33947 .76516 L .31799 .76446 L p .707 .577 .707 r
F P
0 g
s
.31799 .76446 m .32357 .72661 L .34506 .72731 L p .707 .577 .707 r
F P
0 g
s
.16903 .7752 m .16745 .7582 L .18352 .74427 L p .707 .577 .707 r
F P
0 g
s
.29584 .58779 m .29983 .63973 L .26869 .6387 L p .707 .577 .707 r
F P
0 g
s
.26869 .6387 m .2647 .58677 L .29584 .58779 L p .707 .577 .707 r
F P
0 g
s
.20482 .70975 m .19924 .74761 L .17603 .74196 L p .707 .577 .707 r
F P
0 g
s
.17603 .74196 m .18161 .70411 L .20482 .70975 L p .707 .577 .707 r
F P
0 g
s
.23695 .64202 m .23296 .59008 L .2647 .58677 L p .707 .577 .707 r
F P
0 g
s
.23296 .59008 m .23695 .64202 L .20771 .64935 L p .707 .577 .707 r
F P
0 g
s
.2647 .58677 m .26869 .6387 L .23695 .64202 L p .707 .577 .707 r
F P
0 g
s
.62383 .26279 m .61838 .76813 L .58865 .75958 L p .707 .577 .707 r
F P
0 g
s
.58865 .75958 m .5941 .25423 L .62383 .26279 L p .707 .577 .707 r
F P
0 g
s
.18352 .74427 m .18511 .76127 L .16903 .7752 L p .707 .577 .707 r
F P
0 g
s
.348 .7366 m .34959 .7536 L .3284 .74413 L p .707 .577 .707 r
F P
0 g
s
.3284 .74413 m .32681 .72713 L .348 .7366 L p .707 .577 .707 r
F P
0 g
s
.32357 .72661 m .31799 .76446 L .29038 .76206 L p .707 .577 .707 r
F P
0 g
s
.73263 .62025 m .70149 .61923 L p .72563 .65563 L .707 .577 .707 r
F P
0 g
s
.7354 .65638 m .73263 .62025 L p .72563 .65563 L .707 .577 .707 r
F P
0 g
s
.73177 .68098 m .76318 .68596 L p .74547 .65658 L .707 .577 .707 r
F P
0 g
s
.7354 .65638 m .73177 .68098 L p .74294 .66108 L .707 .577 .707 r
F P
0 g
s
.74547 .65658 m .7354 .65638 L .74294 .66108 L .707 .577 .707 r
F
.73177 .68098 m .7354 .65638 L p .71587 .65488 L F P
0 g
s
.70149 .61923 m .674 .61396 L p .6909 .64468 L .707 .577 .707 r
F P
0 g
s
.72367 .66769 m .71249 .65984 L .70075 .67709 L .707 .577 .707 r
F
.70416 .65399 m .70075 .67709 L p .71249 .65984 L F P
0 g
s
.71587 .65488 m .70416 .65399 L .71249 .65984 L .707 .577 .707 r
F
.67314 .67469 m .70075 .67709 L p .68675 .65151 L F P
0 g
s
.69533 .65273 m .6909 .64468 L .68675 .6515 L .707 .577 .707 r
F
.67677 .65008 m .67314 .67469 L p .68369 .65673 L F P
0 g
s
.68675 .65151 m .67677 .65008 L .68369 .65673 L .707 .577 .707 r
F
.674 .61396 m .65285 .60497 L p .66797 .64162 L F P
0 g
s
.67088 .64866 m .67677 .65008 L .66797 .64162 L .707 .577 .707 r
F
.67677 .65008 m .674 .61396 L p .66797 .64162 L F P
0 g
s
.6909 .64468 m .68911 .64342 L .68521 .65129 L .707 .577 .707 r
F
.6909 .64468 m .68521 .65129 L .68675 .6515 L F
.67553 .63388 m .67677 .65008 L p .68911 .64342 L F P
0 g
s
.67677 .65008 m .67799 .6659 L p .68911 .64342 L .707 .577 .707 r
F P
0 g
s
.674 .61396 m .67553 .63388 L p .6909 .64468 L .707 .577 .707 r
F P
0 g
s
.70075 .67709 m .70416 .65399 L p .68675 .65151 L .707 .577 .707 r
F P
0 g
s
.70548 .67116 m .70416 .65399 L p .6909 .64468 L .707 .577 .707 r
F P
0 g
s
.70416 .65399 m .70149 .61923 L p .6909 .64468 L .707 .577 .707 r
F P
0 g
s
.70278 .63602 m .70548 .67116 L p .71958 .64651 L .707 .577 .707 r
F P
0 g
s
.70633 .63924 m .67873 .63683 L p .68675 .65151 L .707 .577 .707 r
F P
0 g
s
.70416 .65399 m .70633 .63924 L p .68675 .65151 L .707 .577 .707 r
F P
0 g
s
.68675 .6515 m .68521 .65129 L .67799 .6659 L .707 .577 .707 r
F
.67314 .67469 m .67677 .65008 L p .66147 .64639 L F P
0 g
s
.65166 .67399 m .67314 .67469 L p .66147 .64639 L .707 .577 .707 r
F P
0 g
s
.65593 .64505 m .65166 .67399 L p .65965 .65151 L .707 .577 .707 r
F P
0 g
s
.66147 .64639 m .65593 .64505 L .65965 .65151 L .707 .577 .707 r
F
.65285 .60497 m .64011 .59313 L p .6519 .63808 L F P
0 g
s
.65593 .64505 m .65285 .60497 L p .6519 .63808 L .707 .577 .707 r
F P
0 g
s
.65285 .60497 m .65593 .64505 L p .67088 .64866 L .707 .577 .707 r
F P
0 g
s
.65166 .67399 m .65593 .64505 L p .64452 .63978 L .707 .577 .707 r
F P
0 g
s
.65166 .67399 m .64452 .63978 L .64409 .64225 L .707 .577 .707 r
F
.63839 .67507 m .64884 .67422 L p .64409 .64225 L F P
0 g
s
.64884 .67422 m .65166 .67399 L p .64409 .64225 L .707 .577 .707 r
F P
0 g
s
.64011 .59313 m .63703 .5796 L p .64302 .63504 L .707 .577 .707 r
F P
0 g
s
.64366 .63939 m .63839 .67507 L p .64452 .63978 L .707 .577 .707 r
F P
0 g
s
.63839 .67507 m .64366 .63939 L p .64024 .63997 L .707 .577 .707 r
F P
0 g
s
.64343 .63884 m .64366 .63939 L .64302 .63504 L .707 .577 .707 r
F
.64366 .63939 m .64011 .59313 L p .64302 .63504 L F P
0 g
s
.64011 .59313 m .64366 .63939 L p .65343 .6439 L .707 .577 .707 r
F P
0 g
s
.64303 .63792 m .64024 .63997 L p .64366 .63939 L .707 .577 .707 r
F P
0 g
s
.63703 .5796 m .64102 .63154 L .64108 .6318 L p .707 .577 .707 r
F P
0 g
s
.64108 .6318 m .6441 .64507 L p .63939 .60144 L .707 .577 .707 r
F P
0 g
s
.63939 .60144 m .63703 .5796 L .64108 .6318 L .707 .577 .707 r
F
.64024 .63997 m .63466 .67782 L .63839 .67507 L p F P
0 g
s
.63466 .67782 m .64024 .63997 L .64158 .64088 L p .707 .577 .707 r
F P
0 g
s
.6441 .64507 m .64366 .63939 L p .64343 .63884 L .707 .577 .707 r
F P
0 g
s
.6441 .64507 m .65684 .6569 L p .65343 .6439 L .707 .577 .707 r
F P
0 g
s
.64366 .63939 m .6441 .64507 L p .65343 .6439 L .707 .577 .707 r
F P
0 g
s
.64158 .64088 m .64639 .64413 L p .6424 .65559 L .707 .577 .707 r
F P
0 g
s
.63466 .67782 m .64158 .64088 L .6424 .65559 L .707 .577 .707 r
F
.64366 .63939 m .64398 .63722 L .64303 .63792 L p F P
0 g
s
.64398 .63722 m .64366 .63939 L p .64452 .63978 L .707 .577 .707 r
F P
0 g
s
.65724 .63614 m .64398 .63722 L p .64452 .63978 L .707 .577 .707 r
F P
0 g
s
.65343 .6439 m .65593 .64505 L .6519 .63808 L .707 .577 .707 r
F
.65593 .64505 m .65724 .63614 L p .64452 .63978 L F P
0 g
s
.65684 .6569 m .65593 .64505 L p .65343 .6439 L .707 .577 .707 r
F P
0 g
s
.65684 .6569 m .67799 .6659 L p .67088 .64866 L .707 .577 .707 r
F P
0 g
s
.65593 .64505 m .65684 .6569 L p .67088 .64866 L .707 .577 .707 r
F P
0 g
s
.65724 .63614 m .65593 .64505 L p .66147 .64639 L .707 .577 .707 r
F P
0 g
s
.67873 .63683 m .65724 .63614 L p .66147 .64639 L .707 .577 .707 r
F P
0 g
s
.67677 .65008 m .67873 .63683 L p .66147 .64639 L .707 .577 .707 r
F P
0 g
s
.67799 .6659 m .67677 .65008 L p .67088 .64866 L .707 .577 .707 r
F P
0 g
s
.67873 .63683 m .67677 .65008 L p .68675 .65151 L .707 .577 .707 r
F P
0 g
s
.67799 .6659 m .70548 .67116 L p .69533 .65273 L .707 .577 .707 r
F P
0 g
s
.69533 .65273 m .68675 .6515 L .67799 .6659 L .707 .577 .707 r
F
.70075 .67709 m .73177 .68098 L p .72367 .66769 L F P
0 g
s
.72367 .66769 m .71587 .65488 L .71249 .65984 L .707 .577 .707 r
F
.72563 .65563 m .71958 .64651 L .71484 .6548 L F
.70633 .63924 m .70416 .65399 L p .71587 .65488 L F P
0 g
s
.70548 .67116 m .73662 .67219 L p .72563 .65563 L .707 .577 .707 r
F P
0 g
s
.72563 .65563 m .71484 .6548 L .70548 .67116 L .707 .577 .707 r
F
.70149 .61923 m .70278 .63602 L p .71958 .64651 L F P
0 g
s
.73263 .62025 m .7354 .65638 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.76437 .61694 m .73263 .62025 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.76745 .65702 m .76437 .61694 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.76318 .68596 m .79189 .69154 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.76745 .65702 m .76318 .68596 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.76437 .61694 m .76745 .65702 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.79361 .6096 m .76437 .61694 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.79716 .65586 m .79361 .6096 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.79361 .6096 m .79716 .65586 L p .82146 .65091 L .707 .577 .707 r
F P
0 g
s
.79189 .69154 m .8151 .69719 L p .7983 .65573 L .707 .577 .707 r
F P
0 g
s
.79716 .65586 m .79189 .69154 L p .7983 .65573 L .707 .577 .707 r
F P
0 g
s
.81502 .65378 m .82146 .65091 L p .79716 .65586 L .707 .577 .707 r
F P
0 g
s
.8151 .69719 m .82069 .65934 L .79748 .65369 L p .707 .577 .707 r
F P
0 g
s
.79716 .65586 m .79759 .66154 L .81502 .65378 L p .707 .577 .707 r
F P
0 g
s
.79748 .65369 m .79716 .65586 L p .7983 .65573 L .707 .577 .707 r
F P
0 g
s
.79748 .65369 m .76877 .64811 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.79189 .69154 m .79716 .65586 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.79716 .65586 m .79748 .65369 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.79759 .66154 m .79716 .65586 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.76836 .66887 m .79759 .66154 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.76745 .65702 m .76836 .66887 L p .79347 .65601 L .707 .577 .707 r
F P
0 g
s
.76877 .64811 m .76745 .65702 L p .77339 .65679 L .707 .577 .707 r
F P
0 g
s
.76877 .64811 m .73736 .64313 L p .74547 .65658 L .707 .577 .707 r
F P
0 g
s
.76318 .68596 m .76745 .65702 L p .74547 .65658 L .707 .577 .707 r
F P
0 g
s
.76745 .65702 m .76877 .64811 L p .74547 .65658 L .707 .577 .707 r
F P
0 g
s
.76836 .66887 m .76745 .65702 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.73662 .67219 m .76836 .66887 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.7354 .65638 m .73662 .67219 L p .75953 .65686 L .707 .577 .707 r
F P
0 g
s
.73736 .64313 m .7354 .65638 L p .74547 .65658 L .707 .577 .707 r
F P
0 g
s
.73736 .64313 m .70633 .63924 L p .71587 .65488 L .707 .577 .707 r
F P
0 g
s
.7354 .65638 m .73736 .64313 L p .71587 .65488 L .707 .577 .707 r
F P
0 g
s
.73662 .67219 m .7354 .65638 L p .72563 .65563 L .707 .577 .707 r
F P
0 g
s
.39096 .25667 m .38551 .76202 L .3624 .7712 L p .707 .577 .707 r
F P
0 g
s
.38551 .76202 m .39096 .25667 L .42491 .24979 L p .707 .577 .707 r
F P
0 g
s
.29038 .76206 m .29597 .7242 L .32357 .72661 L p .707 .577 .707 r
F P
0 g
s
.19924 .74761 m .20482 .70975 L .23354 .71534 L p .707 .577 .707 r
F P
0 g
s
.18511 .76127 m .18352 .74427 L .20731 .7327 L p .707 .577 .707 r
F P
0 g
s
.23354 .71534 m .22795 .75319 L .19924 .74761 L p .707 .577 .707 r
F P
0 g
s
.32681 .72713 m .3284 .74413 L .3009 .7387 L p .707 .577 .707 r
F P
0 g
s
.3009 .7387 m .29931 .7217 L .32681 .72713 L p .707 .577 .707 r
F P
0 g
s
.20731 .7327 m .2089 .7497 L .18511 .76127 L p .707 .577 .707 r
F P
0 g
s
.82146 .65091 m .81747 .59897 L .79361 .6096 L p .707 .577 .707 r
F P
0 g
s
.29597 .7242 m .29038 .76206 L .25936 .75817 L p .707 .577 .707 r
F P
0 g
s
.26494 .72032 m .25936 .75817 L .22795 .75319 L p .707 .577 .707 r
F P
0 g
s
.22795 .75319 m .23354 .71534 L .26494 .72032 L p .707 .577 .707 r
F P
0 g
s
.25936 .75817 m .26494 .72032 L .29597 .7242 L p .707 .577 .707 r
F P
0 g
s
.5941 .25423 m .58865 .75958 L .54988 .75357 L p .707 .577 .707 r
F P
0 g
s
.54988 .75357 m .55534 .24822 L .5941 .25423 L p .707 .577 .707 r
F P
0 g
s
.2089 .7497 m .20731 .7327 L .23648 .72463 L p .707 .577 .707 r
F P
0 g
s
.29931 .7217 m .3009 .7387 L .26977 .73783 L p .707 .577 .707 r
F P
0 g
s
.26977 .73783 m .26818 .72083 L .29931 .7217 L p .707 .577 .707 r
F P
0 g
s
.23648 .72463 m .23807 .74163 L .2089 .7497 L p .707 .577 .707 r
F P
0 g
s
.41946 .75514 m .42491 .24979 L .46639 .24589 L p .707 .577 .707 r
F P
0 g
s
.42491 .24979 m .41946 .75514 L .38551 .76202 L p .707 .577 .707 r
F P
0 g
s
.23807 .74163 m .23648 .72463 L .26818 .72083 L p .707 .577 .707 r
F P
0 g
s
.81747 .59897 m .82146 .65091 L .83763 .63802 L p .707 .577 .707 r
F P
0 g
s
.83763 .63802 m .83364 .58608 L .81747 .59897 L p .707 .577 .707 r
F P
0 g
s
.26818 .72083 m .26977 .73783 L .23807 .74163 L p .707 .577 .707 r
F P
0 g
s
.55534 .24822 m .54988 .75357 L .50588 .7507 L p .707 .577 .707 r
F P
0 g
s
.50588 .7507 m .51133 .24535 L .55534 .24822 L p .707 .577 .707 r
F P
0 g
s
.46093 .75124 m .46639 .24589 L .51133 .24535 L p .707 .577 .707 r
F P
0 g
s
.46639 .24589 m .46093 .75124 L .41946 .75514 L p .707 .577 .707 r
F P
0 g
s
.73824 .77615 m .73665 .75915 L .70553 .75829 L p .707 .577 .707 r
F P
0 g
s
.73665 .75915 m .73824 .77615 L .76994 .77236 L p .707 .577 .707 r
F P
0 g
s
.76994 .77236 m .76835 .75536 L .73665 .75915 L p .707 .577 .707 r
F P
0 g
s
.51133 .24535 m .50588 .7507 L .46093 .75124 L p .707 .577 .707 r
F P
0 g
s
.76835 .75536 m .76994 .77236 L .79911 .76428 L p .707 .577 .707 r
F P
0 g
s
.79911 .76428 m .79753 .74728 L .76835 .75536 L p .707 .577 .707 r
F P
0 g
s
.82069 .65934 m .8151 .69719 L .83054 .70235 L p .707 .577 .707 r
F P
0 g
s
.83364 .58608 m .83763 .63802 L .84451 .62413 L p .707 .577 .707 r
F P
0 g
s
.84451 .62413 m .84052 .57219 L .83364 .58608 L p .707 .577 .707 r
F P
0 g
s
.83054 .70235 m .83612 .6645 L .82069 .65934 L p .707 .577 .707 r
F P
0 g
s
.70711 .77529 m .70553 .75829 L .67802 .75286 L p .707 .577 .707 r
F P
0 g
s
.70553 .75829 m .70711 .77529 L .73824 .77615 L p .707 .577 .707 r
F P
0 g
s
.79753 .74728 m .79911 .76428 L .8229 .75271 L p .707 .577 .707 r
F P
0 g
s
.8229 .75271 m .82132 .73571 L .79753 .74728 L p .707 .577 .707 r
F P
0 g
s
.67802 .75286 m .67961 .76986 L .70711 .77529 L p .707 .577 .707 r
F P
0 g
s
.67961 .76986 m .67802 .75286 L .65683 .74339 L p .707 .577 .707 r
F P
0 g
s
.82132 .73571 m .8229 .75271 L .83898 .73879 L p .707 .577 .707 r
F P
0 g
s
.83898 .73879 m .83739 .72179 L .82132 .73571 L p .707 .577 .707 r
F P
0 g
s
.83612 .6645 m .83054 .70235 L .83669 .70651 L p .707 .577 .707 r
F P
0 g
s
.65683 .74339 m .65842 .76039 L .67961 .76986 L p .707 .577 .707 r
F P
0 g
s
.84052 .57219 m .84451 .62413 L .84142 .6106 L p .707 .577 .707 r
F P
0 g
s
.84142 .6106 m .83744 .55867 L .84052 .57219 L p .707 .577 .707 r
F P
0 g
s
.83669 .70651 m .84227 .66866 L .83612 .6645 L p .707 .577 .707 r
F P
0 g
s
.65842 .76039 m .65683 .74339 L .64403 .73081 L p .707 .577 .707 r
F P
0 g
s
.64102 .63154 m .63703 .5796 L .64391 .56572 L p .707 .577 .707 r
F P
0 g
s
.64403 .73081 m .64562 .74781 L .65842 .76039 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83739 .72179 m .83898 .73879 L .84577 .72386 L p .707 .577 .707 r
F P
0 g
s
.84577 .72386 m .84418 .70686 L .83739 .72179 L p .707 .577 .707 r
F P
0 g
s
.84227 .66866 m .83669 .70651 L .83295 .70926 L p .707 .577 .707 r
F P
0 g
s
.83744 .55867 m .84142 .6106 L .82869 .59876 L p .707 .577 .707 r
F P
0 g
s
.82869 .59876 m .8247 .54683 L .83744 .55867 L p .707 .577 .707 r
F P
0 g
s
.83295 .70926 m .83853 .67141 L .84227 .66866 L p .707 .577 .707 r
F P
0 g
s
.64562 .74781 m .64403 .73081 L .64087 .71635 L p .707 .577 .707 r
F P
0 g
s
.64639 .64413 m .6408 .68198 L .63466 .67782 L p .707 .577 .707 r
F P
0 g
s
.64391 .56572 m .6479 .61765 L .64102 .63154 L p .707 .577 .707 r
F P
0 g
s
.6479 .61765 m .64391 .56572 L .66007 .55282 L p .707 .577 .707 r
F P
0 g
s
.64087 .71635 m .64246 .73335 L .64562 .74781 L p .707 .577 .707 r
F P
0 g
s
.84418 .70686 m .84577 .72386 L .84261 .7094 L p .707 .577 .707 r
F P
0 g
s
.84261 .7094 m .84102 .6924 L .84418 .70686 L p .707 .577 .707 r
F P
0 g
s
.38962 .58344 m .35848 .58241 L p .38262 .61881 L .707 .577 .707 r
F P
0 g
s
.39239 .61956 m .38962 .58344 L p .38262 .61881 L .707 .577 .707 r
F P
0 g
s
.38876 .64416 m .42017 .64914 L p .40246 .61976 L .707 .577 .707 r
F P
0 g
s
.39239 .61956 m .38876 .64416 L p .39993 .62426 L .707 .577 .707 r
F P
0 g
s
.40246 .61976 m .39239 .61956 L .39993 .62426 L .707 .577 .707 r
F
.38876 .64416 m .39239 .61956 L p .37286 .61807 L F P
0 g
s
.35848 .58241 m .33099 .57715 L p .34789 .60786 L .707 .577 .707 r
F P
0 g
s
.38066 .63087 m .36948 .62302 L .35774 .64028 L .707 .577 .707 r
F
.36115 .61717 m .35774 .64028 L p .36948 .62302 L F P
0 g
s
.37286 .61807 m .36115 .61717 L .36948 .62302 L .707 .577 .707 r
F
.33013 .63787 m .35774 .64028 L p .34374 .61469 L F P
0 g
s
.35232 .61591 m .34789 .60786 L .34374 .61469 L .707 .577 .707 r
F
.33376 .61327 m .33013 .63787 L p .34068 .61991 L F P
0 g
s
.34374 .61469 m .33376 .61327 L .34068 .61991 L .707 .577 .707 r
F
.33099 .57715 m .30984 .56815 L p .32496 .60481 L F P
0 g
s
.32787 .61185 m .33376 .61327 L .32496 .60481 L .707 .577 .707 r
F
.33376 .61327 m .33099 .57715 L p .32496 .60481 L F P
0 g
s
.34789 .60786 m .3461 .6066 L .3422 .61447 L .707 .577 .707 r
F
.34789 .60786 m .3422 .61447 L .34374 .61469 L F
.33252 .59706 m .33376 .61327 L p .3461 .6066 L F P
0 g
s
.33376 .61327 m .33498 .62908 L p .3461 .6066 L .707 .577 .707 r
F P
0 g
s
.33099 .57715 m .33252 .59706 L p .34789 .60786 L .707 .577 .707 r
F P
0 g
s
.35774 .64028 m .36115 .61717 L p .34374 .61469 L .707 .577 .707 r
F P
0 g
s
.36247 .63435 m .36115 .61717 L p .34789 .60786 L .707 .577 .707 r
F P
0 g
s
.36115 .61717 m .35848 .58241 L p .34789 .60786 L .707 .577 .707 r
F P
0 g
s
.35977 .59921 m .36247 .63435 L p .37657 .60969 L .707 .577 .707 r
F P
0 g
s
.36332 .60243 m .33572 .60002 L p .34374 .61469 L .707 .577 .707 r
F P
0 g
s
.36115 .61717 m .36332 .60243 L p .34374 .61469 L .707 .577 .707 r
F P
0 g
s
.34374 .61469 m .3422 .61447 L .33498 .62908 L .707 .577 .707 r
F
.33013 .63787 m .33376 .61327 L p .31846 .60958 L F P
0 g
s
.30865 .63717 m .33013 .63787 L p .31846 .60958 L .707 .577 .707 r
F P
0 g
s
.31292 .60824 m .30865 .63717 L p .31664 .61469 L .707 .577 .707 r
F P
0 g
s
.31846 .60958 m .31292 .60824 L .31664 .61469 L .707 .577 .707 r
F
.30984 .56815 m .2971 .55631 L p .30889 .60126 L F P
0 g
s
.31292 .60824 m .30984 .56815 L p .30889 .60126 L .707 .577 .707 r
F P
0 g
s
.30984 .56815 m .31292 .60824 L p .32787 .61185 L .707 .577 .707 r
F P
0 g
s
.30865 .63717 m .31292 .60824 L p .30151 .60297 L .707 .577 .707 r
F P
0 g
s
.30865 .63717 m .30151 .60297 L .30108 .60544 L .707 .577 .707 r
F
.29538 .63825 m .30583 .6374 L p .30108 .60544 L F P
0 g
s
.30583 .6374 m .30865 .63717 L p .30108 .60544 L .707 .577 .707 r
F P
0 g
s
.2971 .55631 m .29402 .54279 L p .30001 .59823 L .707 .577 .707 r
F P
0 g
s
.30065 .60257 m .29538 .63825 L p .30151 .60297 L .707 .577 .707 r
F P
0 g
s
.29538 .63825 m .30065 .60257 L p .29723 .60316 L .707 .577 .707 r
F P
0 g
s
.30042 .60203 m .30065 .60257 L .30001 .59823 L .707 .577 .707 r
F
.30065 .60257 m .2971 .55631 L p .30001 .59823 L F P
0 g
s
.2971 .55631 m .30065 .60257 L p .31042 .60708 L .707 .577 .707 r
F P
0 g
s
.30002 .60111 m .29723 .60316 L p .30065 .60257 L .707 .577 .707 r
F P
0 g
s
.29402 .54279 m .29801 .59472 L .29807 .59498 L p .707 .577 .707 r
F P
0 g
s
.29807 .59498 m .30109 .60825 L p .29638 .56462 L .707 .577 .707 r
F P
0 g
s
.29638 .56462 m .29402 .54279 L .29807 .59498 L .707 .577 .707 r
F
.29723 .60316 m .29165 .64101 L .29538 .63825 L p F P
0 g
s
.29165 .64101 m .29723 .60316 L .29857 .60406 L p .707 .577 .707 r
F P
0 g
s
.30109 .60825 m .30065 .60257 L p .30042 .60203 L .707 .577 .707 r
F P
0 g
s
.30109 .60825 m .31383 .62009 L p .31042 .60708 L .707 .577 .707 r
F P
0 g
s
.30065 .60257 m .30109 .60825 L p .31042 .60708 L .707 .577 .707 r
F P
0 g
s
.29857 .60406 m .30338 .60732 L p .29939 .61878 L .707 .577 .707 r
F P
0 g
s
.29165 .64101 m .29857 .60406 L .29939 .61878 L .707 .577 .707 r
F
.30065 .60257 m .30097 .6004 L .30002 .60111 L p F P
0 g
s
.30097 .6004 m .30065 .60257 L p .30151 .60297 L .707 .577 .707 r
F P
0 g
s
.31423 .59932 m .30097 .6004 L p .30151 .60297 L .707 .577 .707 r
F P
0 g
s
.31042 .60708 m .31292 .60824 L .30889 .60126 L .707 .577 .707 r
F
.31292 .60824 m .31423 .59932 L p .30151 .60297 L F P
0 g
s
.31383 .62009 m .31292 .60824 L p .31042 .60708 L .707 .577 .707 r
F P
0 g
s
.31383 .62009 m .33498 .62908 L p .32787 .61185 L .707 .577 .707 r
F P
0 g
s
.31292 .60824 m .31383 .62009 L p .32787 .61185 L .707 .577 .707 r
F P
0 g
s
.31423 .59932 m .31292 .60824 L p .31846 .60958 L .707 .577 .707 r
F P
0 g
s
.33572 .60002 m .31423 .59932 L p .31846 .60958 L .707 .577 .707 r
F P
0 g
s
.33376 .61327 m .33572 .60002 L p .31846 .60958 L .707 .577 .707 r
F P
0 g
s
.33498 .62908 m .33376 .61327 L p .32787 .61185 L .707 .577 .707 r
F P
0 g
s
.33572 .60002 m .33376 .61327 L p .34374 .61469 L .707 .577 .707 r
F P
0 g
s
.33498 .62908 m .36247 .63435 L p .35232 .61591 L .707 .577 .707 r
F P
0 g
s
.35232 .61591 m .34374 .61469 L .33498 .62908 L .707 .577 .707 r
F
.35774 .64028 m .38876 .64416 L p .38066 .63087 L F P
0 g
s
.38066 .63087 m .37286 .61807 L .36948 .62302 L .707 .577 .707 r
F
.38262 .61881 m .37657 .60969 L .37183 .61799 L F
.36332 .60243 m .36115 .61717 L p .37286 .61807 L F P
0 g
s
.36247 .63435 m .39361 .63537 L p .38262 .61881 L .707 .577 .707 r
F P
0 g
s
.38262 .61881 m .37183 .61799 L .36247 .63435 L .707 .577 .707 r
F
.35848 .58241 m .35977 .59921 L p .37657 .60969 L F P
0 g
s
.38962 .58344 m .39239 .61956 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.42136 .58012 m .38962 .58344 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.42444 .62021 m .42136 .58012 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.42017 .64914 m .44888 .65473 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.42444 .62021 m .42017 .64914 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.42136 .58012 m .42444 .62021 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.4506 .57279 m .42136 .58012 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.45415 .61905 m .4506 .57279 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.4506 .57279 m .45415 .61905 L p .47845 .61409 L .707 .577 .707 r
F P
0 g
s
.44888 .65473 m .47209 .66038 L p .45529 .61891 L .707 .577 .707 r
F P
0 g
s
.45415 .61905 m .44888 .65473 L p .45529 .61891 L .707 .577 .707 r
F P
0 g
s
.47201 .61696 m .47845 .61409 L p .45415 .61905 L .707 .577 .707 r
F P
0 g
s
.47209 .66038 m .47768 .62253 L .45447 .61688 L p .707 .577 .707 r
F P
0 g
s
.45415 .61905 m .45458 .62472 L .47201 .61696 L p .707 .577 .707 r
F P
0 g
s
.45447 .61688 m .45415 .61905 L p .45529 .61891 L .707 .577 .707 r
F P
0 g
s
.45447 .61688 m .42576 .61129 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.44888 .65473 m .45415 .61905 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.45415 .61905 m .45447 .61688 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.45458 .62472 m .45415 .61905 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.42535 .63206 m .45458 .62472 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.42444 .62021 m .42535 .63206 L p .45046 .61919 L .707 .577 .707 r
F P
0 g
s
.42576 .61129 m .42444 .62021 L p .43038 .61998 L .707 .577 .707 r
F P
0 g
s
.42576 .61129 m .39435 .60631 L p .40246 .61976 L .707 .577 .707 r
F P
0 g
s
.42017 .64914 m .42444 .62021 L p .40246 .61976 L .707 .577 .707 r
F P
0 g
s
.42444 .62021 m .42576 .61129 L p .40246 .61976 L .707 .577 .707 r
F P
0 g
s
.42535 .63206 m .42444 .62021 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.39361 .63537 m .42535 .63206 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.39239 .61956 m .39361 .63537 L p .41652 .62005 L .707 .577 .707 r
F P
0 g
s
.39435 .60631 m .39239 .61956 L p .40246 .61976 L .707 .577 .707 r
F P
0 g
s
.39435 .60631 m .36332 .60243 L p .37286 .61807 L .707 .577 .707 r
F P
0 g
s
.39239 .61956 m .39435 .60631 L p .37286 .61807 L .707 .577 .707 r
F P
0 g
s
.39361 .63537 m .39239 .61956 L p .38262 .61881 L .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.8247 .54683 m .82869 .59876 L .80754 .58977 L p .707 .577 .707 r
F P
0 g
s
.80754 .58977 m .80355 .53784 L .8247 .54683 L p .707 .577 .707 r
F P
0 g
s
.83853 .67141 m .83295 .70926 L .81969 .71034 L p .707 .577 .707 r
F P
0 g
s
.47845 .61409 m .47446 .56216 L .4506 .57279 L p .707 .577 .707 r
F P
0 g
s
.81969 .71034 m .82527 .67249 L .83853 .67141 L p .707 .577 .707 r
F P
0 g
s
.64246 .73335 m .64087 .71635 L .64766 .70142 L p .707 .577 .707 r
F P
0 g
s
.66183 .64929 m .65624 .68714 L .6408 .68198 L p .707 .577 .707 r
F P
0 g
s
.6408 .68198 m .64639 .64413 L .66183 .64929 L p .707 .577 .707 r
F P
0 g
s
.66007 .55282 m .66406 .60476 L .6479 .61765 L p .707 .577 .707 r
F P
0 g
s
.66406 .60476 m .66007 .55282 L .68394 .54219 L p .707 .577 .707 r
F P
0 g
s
.64766 .70142 m .64925 .71842 L .64246 .73335 L p .707 .577 .707 r
F P
0 g
s
.84102 .6924 m .84261 .7094 L .82981 .69682 L p .707 .577 .707 r
F P
0 g
s
.82981 .69682 m .82822 .67982 L .84102 .6924 L p .707 .577 .707 r
F P
0 g
s
.80355 .53784 m .80754 .58977 L .78005 .5845 L p .707 .577 .707 r
F P
0 g
s
.78005 .5845 m .77606 .53257 L .80355 .53784 L p .707 .577 .707 r
F P
0 g
s
.47446 .56216 m .47845 .61409 L .49462 .6012 L p .707 .577 .707 r
F P
0 g
s
.49462 .6012 m .49063 .54926 L .47446 .56216 L p .707 .577 .707 r
F P
0 g
s
.68793 .59413 m .68394 .54219 L .71318 .53486 L p .707 .577 .707 r
F P
0 g
s
.68394 .54219 m .68793 .59413 L .66406 .60476 L p .707 .577 .707 r
F P
0 g
s
.82527 .67249 m .81969 .71034 L .7982 .70965 L p .707 .577 .707 r
F P
0 g
s
.7982 .70965 m .80379 .67179 L .82527 .67249 L p .707 .577 .707 r
F P
0 g
s
.68504 .65494 m .67945 .69279 L .65624 .68714 L p .707 .577 .707 r
F P
0 g
s
.64925 .71842 m .64766 .70142 L .66374 .68749 L p .707 .577 .707 r
F P
0 g
s
.77606 .53257 m .78005 .5845 L .74891 .58348 L p .707 .577 .707 r
F P
0 g
s
.74891 .58348 m .74492 .53154 L .77606 .53257 L p .707 .577 .707 r
F P
0 g
s
.65624 .68714 m .66183 .64929 L .68504 .65494 L p .707 .577 .707 r
F P
0 g
s
.39523 .73933 m .39364 .72233 L .36252 .72147 L p .707 .577 .707 r
F P
0 g
s
.39364 .72233 m .39523 .73933 L .42693 .73554 L p .707 .577 .707 r
F P
0 g
s
.42693 .73554 m .42534 .71854 L .39364 .72233 L p .707 .577 .707 r
F P
0 g
s
.71716 .58679 m .71318 .53486 L .74492 .53154 L p .707 .577 .707 r
F P
0 g
s
.71318 .53486 m .71716 .58679 L .68793 .59413 L p .707 .577 .707 r
F P
0 g
s
.42534 .71854 m .42693 .73554 L .4561 .72747 L p .707 .577 .707 r
F P
0 g
s
.4561 .72747 m .45452 .71047 L .42534 .71854 L p .707 .577 .707 r
F P
0 g
s
.74492 .53154 m .74891 .58348 L .71716 .58679 L p .707 .577 .707 r
F P
0 g
s
.47768 .62253 m .47209 .66038 L .48753 .66553 L p .707 .577 .707 r
F P
0 g
s
.66374 .68749 m .66532 .70449 L .64925 .71842 L p .707 .577 .707 r
F P
0 g
s
.82822 .67982 m .82981 .69682 L .80862 .68735 L p .707 .577 .707 r
F P
0 g
s
.80862 .68735 m .80703 .67035 L .82822 .67982 L p .707 .577 .707 r
F P
0 g
s
.49063 .54926 m .49462 .6012 L .5015 .58731 L p .707 .577 .707 r
F P
0 g
s
.5015 .58731 m .49751 .53538 L .49063 .54926 L p .707 .577 .707 r
F P
0 g
s
.48753 .66553 m .49311 .62768 L .47768 .62253 L p .707 .577 .707 r
F P
0 g
s
.3641 .73847 m .36252 .72147 L .33501 .71604 L p .707 .577 .707 r
F P
0 g
s
.36252 .72147 m .3641 .73847 L .39523 .73933 L p .707 .577 .707 r
F P
0 g
s
.45452 .71047 m .4561 .72747 L .47989 .7159 L p .707 .577 .707 r
F P
0 g
s
.47989 .7159 m .47831 .6989 L .45452 .71047 L p .707 .577 .707 r
F P
0 g
s
.80379 .67179 m .7982 .70965 L .77059 .70724 L p .707 .577 .707 r
F P
0 g
s
.33501 .71604 m .3366 .73304 L .3641 .73847 L p .707 .577 .707 r
F P
0 g
s
.77059 .70724 m .77618 .66939 L .80379 .67179 L p .707 .577 .707 r
F P
0 g
s
.67945 .69279 m .68504 .65494 L .71375 .66052 L p .707 .577 .707 r
F P
0 g
s
.66532 .70449 m .66374 .68749 L .68752 .67593 L p .707 .577 .707 r
F P
0 g
s
.71375 .66052 m .70816 .69837 L .67945 .69279 L p .707 .577 .707 r
F P
0 g
s
.3366 .73304 m .33501 .71604 L .31382 .70657 L p .707 .577 .707 r
F P
0 g
s
.80703 .67035 m .80862 .68735 L .78111 .68192 L p .707 .577 .707 r
F P
0 g
s
.78111 .68192 m .77952 .66492 L .80703 .67035 L p .707 .577 .707 r
F P
0 g
s
.68752 .67593 m .68911 .69293 L .66532 .70449 L p .707 .577 .707 r
F P
0 g
s
.77618 .66939 m .77059 .70724 L .73957 .70335 L p .707 .577 .707 r
F P
0 g
s
.47831 .6989 m .47989 .7159 L .49597 .70197 L p .707 .577 .707 r
F P
0 g
s
.49597 .70197 m .49438 .68497 L .47831 .6989 L p .707 .577 .707 r
F P
0 g
s
.49311 .62768 m .48753 .66553 L .49368 .66969 L p .707 .577 .707 r
F P
0 g
s
.31382 .70657 m .31541 .72357 L .3366 .73304 L p .707 .577 .707 r
F P
0 g
s
.74516 .6655 m .73957 .70335 L .70816 .69837 L p .707 .577 .707 r
F P
0 g
s
.70816 .69837 m .71375 .66052 L .74516 .6655 L p .707 .577 .707 r
F P
0 g
s
.73957 .70335 m .74516 .6655 L .77618 .66939 L p .707 .577 .707 r
F P
0 g
s
.49751 .53538 m .5015 .58731 L .49841 .57379 L p .707 .577 .707 r
F P
0 g
s
.49841 .57379 m .49443 .52185 L .49751 .53538 L p .707 .577 .707 r
F P
0 g
s
.49368 .66969 m .49926 .63184 L .49311 .62768 L p .707 .577 .707 r
F P
0 g
s
.68911 .69293 m .68752 .67593 L .7167 .66785 L p .707 .577 .707 r
F P
0 g
s
.77952 .66492 m .78111 .68192 L .74998 .68106 L p .707 .577 .707 r
F P
0 g
s
.74998 .68106 m .7484 .66406 L .77952 .66492 L p .707 .577 .707 r
F P
0 g
s
.31541 .72357 m .31382 .70657 L .30102 .69399 L p .707 .577 .707 r
F P
0 g
s
.7167 .66785 m .71828 .68485 L .68911 .69293 L p .707 .577 .707 r
F P
0 g
s
.71828 .68485 m .7167 .66785 L .7484 .66406 L p .707 .577 .707 r
F P
0 g
s
.7484 .66406 m .74998 .68106 L .71828 .68485 L p .707 .577 .707 r
F P
0 g
s
.29801 .59472 m .29402 .54279 L .3009 .5289 L p .707 .577 .707 r
F P
0 g
s
.30102 .69399 m .30261 .71099 L .31541 .72357 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.49438 .68497 m .49597 .70197 L .50276 .68705 L p .707 .577 .707 r
F P
0 g
s
.50276 .68705 m .50117 .67005 L .49438 .68497 L p .707 .577 .707 r
F P
0 g
s
.49926 .63184 m .49368 .66969 L .48994 .67245 L p .707 .577 .707 r
F P
0 g
s
.49443 .52185 m .49841 .57379 L .48568 .56195 L p .707 .577 .707 r
F P
0 g
s
.48568 .56195 m .48169 .51001 L .49443 .52185 L p .707 .577 .707 r
F P
0 g
s
.48994 .67245 m .49552 .6346 L .49926 .63184 L p .707 .577 .707 r
F P
0 g
s
.30261 .71099 m .30102 .69399 L .29786 .67953 L p .707 .577 .707 r
F P
0 g
s
.30338 .60732 m .29779 .64517 L .29165 .64101 L p .707 .577 .707 r
F P
0 g
s
.3009 .5289 m .30488 .58084 L .29801 .59472 L p .707 .577 .707 r
F P
0 g
s
.30488 .58084 m .3009 .5289 L .31706 .51601 L p .707 .577 .707 r
F P
0 g
s
.29786 .67953 m .29945 .69653 L .30261 .71099 L p .707 .577 .707 r
F P
0 g
s
.50117 .67005 m .50276 .68705 L .4996 .67259 L p .707 .577 .707 r
F P
0 g
s
.4996 .67259 m .49801 .65559 L .50117 .67005 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.48169 .51001 m .48568 .56195 L .46453 .55296 L p .707 .577 .707 r
F P
0 g
s
.46453 .55296 m .46054 .50102 L .48169 .51001 L p .707 .577 .707 r
F P
0 g
s
.49552 .6346 m .48994 .67245 L .47668 .67353 L p .707 .577 .707 r
F P
0 g
s
.47668 .67353 m .48226 .63568 L .49552 .6346 L p .707 .577 .707 r
F P
0 g
s
.29945 .69653 m .29786 .67953 L .30465 .66461 L p .707 .577 .707 r
F P
0 g
s
.31882 .61247 m .31323 .65032 L .29779 .64517 L p .707 .577 .707 r
F P
0 g
s
.29779 .64517 m .30338 .60732 L .31882 .61247 L p .707 .577 .707 r
F P
0 g
s
.31706 .51601 m .32105 .56794 L .30488 .58084 L p .707 .577 .707 r
F P
0 g
s
.32105 .56794 m .31706 .51601 L .34093 .50538 L p .707 .577 .707 r
F P
0 g
s
.30465 .66461 m .30624 .68161 L .29945 .69653 L p .707 .577 .707 r
F P
0 g
s
.49801 .65559 m .4996 .67259 L .4868 .66001 L p .707 .577 .707 r
F P
0 g
s
.4868 .66001 m .48521 .64301 L .49801 .65559 L p .707 .577 .707 r
F P
0 g
s
.46054 .50102 m .46453 .55296 L .43703 .54769 L p .707 .577 .707 r
F P
0 g
s
.43703 .54769 m .43305 .49575 L .46054 .50102 L p .707 .577 .707 r
F P
0 g
s
.34492 .55731 m .34093 .50538 L .37016 .49804 L p .707 .577 .707 r
F P
0 g
s
.34093 .50538 m .34492 .55731 L .32105 .56794 L p .707 .577 .707 r
F P
0 g
s
.48226 .63568 m .47668 .67353 L .45519 .67283 L p .707 .577 .707 r
F P
0 g
s
.45519 .67283 m .46078 .63498 L .48226 .63568 L p .707 .577 .707 r
F P
0 g
s
.34203 .61812 m .33644 .65597 L .31323 .65032 L p .707 .577 .707 r
F P
0 g
s
.30624 .68161 m .30465 .66461 L .32072 .65068 L p .707 .577 .707 r
F P
0 g
s
.43305 .49575 m .43703 .54769 L .40589 .54666 L p .707 .577 .707 r
F P
0 g
s
.40589 .54666 m .40191 .49473 L .43305 .49575 L p .707 .577 .707 r
F P
0 g
s
.31323 .65032 m .31882 .61247 L .34203 .61812 L p .707 .577 .707 r
F P
0 g
s
.37415 .54998 m .37016 .49804 L .40191 .49473 L p .707 .577 .707 r
F P
0 g
s
.37016 .49804 m .37415 .54998 L .34492 .55731 L p .707 .577 .707 r
F P
0 g
s
.40191 .49473 m .40589 .54666 L .37415 .54998 L p .707 .577 .707 r
F P
0 g
s
.32072 .65068 m .32231 .66768 L .30624 .68161 L p .707 .577 .707 r
F P
0 g
s
.48521 .64301 m .4868 .66001 L .4656 .65054 L p .707 .577 .707 r
F P
0 g
s
.4656 .65054 m .46402 .63354 L .48521 .64301 L p .707 .577 .707 r
F P
0 g
s
.46078 .63498 m .45519 .67283 L .42758 .67042 L p .707 .577 .707 r
F P
0 g
s
.42758 .67042 m .43317 .63257 L .46078 .63498 L p .707 .577 .707 r
F P
0 g
s
.33644 .65597 m .34203 .61812 L .37074 .62371 L p .707 .577 .707 r
F P
0 g
s
.32231 .66768 m .32072 .65068 L .34451 .63911 L p .707 .577 .707 r
F P
0 g
s
.37074 .62371 m .36515 .66156 L .33644 .65597 L p .707 .577 .707 r
F P
0 g
s
.46402 .63354 m .4656 .65054 L .4381 .64511 L p .707 .577 .707 r
F P
0 g
s
.4381 .64511 m .43651 .6281 L .46402 .63354 L p .707 .577 .707 r
F P
0 g
s
.34451 .63911 m .3461 .65611 L .32231 .66768 L p .707 .577 .707 r
F P
0 g
s
.43317 .63257 m .42758 .67042 L .39656 .66654 L p .707 .577 .707 r
F P
0 g
s
.40215 .62869 m .39656 .66654 L .36515 .66156 L p .707 .577 .707 r
F P
0 g
s
.36515 .66156 m .37074 .62371 L .40215 .62869 L p .707 .577 .707 r
F P
0 g
s
.39656 .66654 m .40215 .62869 L .43317 .63257 L p .707 .577 .707 r
F P
0 g
s
.3461 .65611 m .34451 .63911 L .37369 .63104 L p .707 .577 .707 r
F P
0 g
s
.43651 .6281 m .4381 .64511 L .40697 .64424 L p .707 .577 .707 r
F P
0 g
s
.40697 .64424 m .40539 .62724 L .43651 .6281 L p .707 .577 .707 r
F P
0 g
s
.37369 .63104 m .37527 .64804 L .3461 .65611 L p .707 .577 .707 r
F P
0 g
s
.37527 .64804 m .37369 .63104 L .40539 .62724 L p .707 .577 .707 r
F P
0 g
s
.40539 .62724 m .40697 .64424 L .37527 .64804 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Rgoo3000QWoo001oOol<0006FUH00`00FUIJEP03FUH9001mOol007Ioo`T000EJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00H007Moo`00LWoo10000UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01UYF1@00LWoo001^Ool40006FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP04001^Ool006Yoo`@00003FUH0
05YF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00AJEP<006]oo`00J7oo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF0`00JGoo001WOol20006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02001WOol006Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001oogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001o
ogoo06Aoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP8006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YF
FUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo
00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJ
EP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJ
EP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00IGoo00@005YFFUH000EJEPT00003FUH005YF00YJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00
IGoo00<005YF00001P0015YF00<005YFFUH00UYF20001EYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001SOol40002FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH01000FUIJEUYF1@0035YF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01EYF00<005YFFUH00UYF0P00IWoo001POol30006FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH3000;FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH2001VOol005ioo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF008000UJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8006Ioo`00G7oo0P000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00UYF0P001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Uoo`8000IJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEP000004FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001VOol005Moo`800003
FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol005Ioo`05001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001EOol00`00FUIJ
EP02FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IWoo001DOol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020002
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000HOolA000m
Ool005Aoo`8000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP80019oo`H000AJEP03001JEUYF00IJEP04001JEUYF
FUH5000hOol005=oo`03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF0080009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000ioo`@00003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP<003Ioo`00Dgoo00<005YF00001EYF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFFUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P002Woo10001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
0P00=7oo001COol00`00FUH00005FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH?
0006FUH00`00FUIJEP02FUH00`00FUIJEP020002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH20008Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000bOol005=oo`03001JEP0000EJEP03001JEUYF
00AJEP03001JEUYF00AJEPH000QJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP04001JEUYF
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006Ool2
0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH2000aOol005=oo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00@000EJEP03001J
EUYF00IJEP03001JEUYF00QJEP@000AJEP04001JEUYF0002FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20004Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH00000;goo001COol01000
FUIJEP0015YF00<005YFFUH00eYF10000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH00`0000EJEP00FUIJEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP8000=oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF
0004FUH01000FUIJEUYF0P000goo00@005YFFUH000IJEP@000EJEP03001JEUYF00UJEP04001JEUYF
0002FUH20002FUH01000FUIJEP002eYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000Eoo`00001JEP0000IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000^Ool005=oo`04001JEUYF0004FUH01000FUH0
00001Goo00@005YFFUH000IJEPD000AJEP03001JEUYF00UJEP@000AJEP06001JEP00001JEP002eYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YF
FUIJEP0002ioo`00Dgoo00@005YFFUH000AJEP8000Moo`04001JEUYF0006FUH50004FUH00`00FUIJ
EP08FUH20002FUH00`00FUIJEP02FUH01P00FUH00000FUH000]JEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP<000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool005Aoo`03001J
EP0000=JEP03001oogoo00Moo`04001JEUYF0006FUH50004FUH00`00FUIJEP04FUH40004FUH00`00
FUIJEP02FUH400000eYF001JEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH3
0003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol01000FUH005YF0P0000=JEP000000
1goo00@005YFFUH000IJEP@000EJEP03001JEUYF00@0009JEP03001JEUYF00AJEP06001JEUYFFUH0
05YF0P0000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00E7oo00<005YF00000P0015YF1@000Woo00@0
05YFFUH000IJEP03001JEUYF009JEPL000IJEP03001JEUYF00AJEP03001JEUYF009JEP<00003FUH0
05YF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=JEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool005Aoo`05001JEP00FUH00005FUH01000FUIJEUYF4@0015YF00<0
05YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF0`0000=JEP00FUH02UYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH00UYF2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002ioo`00Agoo
2@0017oo0P000UYF00<005YFFUH00eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00UYF00D005YF001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00AJEPH000Uoo`P000AJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool0041oo`L000AJEP03001J
EUYF009JEPH0009JEP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP05001JEP00FUH0000;FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJ
EP04000GOol50005FUH01@00FUIJEUYF0000;Goo000lOol40002FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF100087oo0P000eYF
00D005YFFUIJEP0002eoo`00>Goo0`001UYF00<005YFFUH01UYF00<005YFFUH01UYF0P000UYF00<0
05YFFUH00eYF00<005YFFUH015YF0P001eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
15YF00<005YFFUH00UYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00@005YFFUH000=JEP04001JEUYFFUH2000?Ool3000DOol200000eYF001JEP02FUH0
0`00Oomoo`0[Ool003Moo`<000QJEP03001JEUYF00IJEP03001JEUYF00IJEPl0009JEP8000MJEP03
001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF009JEP05001JEUYFFUH0000;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01000FUIJEP000eYF00@005YF0000
011oo`D0019oo`800003FUH0000000=JEP03001oogoo02]oo`00=Goo0P000UYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF00D005YFFUIJEP0000IJEP04001JEUYFFUH90003FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000FUIJEP0015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP80019oo`D0011oo`80
0003FUH005YF009JEP04001JEUYF000]Ool003=oo`8000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00MJEP800003FUH005YF00AJEP03001JEUYF00IJEP03001JEUYF009JEPT000=JEP03
001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP800005FUH005YFFUH0000DOol5000>Ool20003FUH00`00FUIJ
EP02FUH3000]Ool0039oo`8000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00QJEP<0
00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF009JEPH000IJEP03001JEUYF00AJEP80
00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
05YF00@001=oo`<000aoo`<000EJEP03001JEUYF009JEP03001JEP0002eoo`00<7oo0P0000=JEP00
FUH01EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF00@005YFFUH0009JEPH000MJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP0000<0009JEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH0
000000AJEP<001]oo`@00003FUH005YF00EJEP03001JEUYF009JEP04001JEP00000/Ool002moo`05
001JEUYFFUH00006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004
FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF10000UYF
0`0025YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000=J
EP0000001EYF00<005YF00000`0047oo1`001EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YF
000002aoo`00;Woo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH015YF00<005YF000015YF00<005YFFUH015YF00<005YF000010001eYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YF00000P002UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YFFUH00eYF400015YF00<005YFFUH0
1EYF00<005YFFUH015YF00<005YFFUH00UYF00@005YFFUH002aoo`00;Goo0P0015YF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH0
15YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YFFUH015YF10000eYF10001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<0
05YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<0
05YFFUH00UYF00@005YFFUH002aoo`00;Goo0P0015YF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<0
05YFFUH00UYF4@000UYF00<005YFFUH00eYF00<005YFFUH00`000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P0000AJEP00FUH000AJEP8000IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00
;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00D005YFFUIJEP0000IJEP03001JEUYF00EJEPL000AJEP03001JEUYF00IJEP03001JEP0000<0
00EJEP03001JEUYF00=JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP8000=JEP03001JEUYF009JEP8000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEP03001JEUYF009JEP8002eoo`00;7oo00<005YF00001EYF00<005YFFUH0
0eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00@005YFFUH000=JEP03001JEUYF
00AJEP04001JEUYFFUH40002FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH<0000
0eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH40003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH0
0`00FUIJEP02FUH00`00Oomoo`0/Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF009JEP/00003FUH005YF00=JEP03001JEUYF00AJEP@000IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000800004FUH005YFFUH200000eYF001JEP0;
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP0@0003FUH0
0`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool0
02aoo`03001JEP0000EJEP03001JEUYF00AJEP03001JEUYF00AJEPH000Yoo`03001JEP0000AJEP03
001JEUYF00=JEP<000QJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
009JEP80009JEP800003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00=J
EP8000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF009JEPL000IJEP03001JEUYF00EJ
EP03001JEUYF00AJEP05001JEUYFFUH0000_Ool002aoo`03001JEP0000EJEP03001JEUYF00AJEP03
001JEUYF00@0015oo`@0009JEP03001JEUYF009JEP04001JEUYF0008FUH00`00FUIJEP02FUH?0006
FUH00`00FUIJEP02FUH200001EYF000005YF000035YF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00eYF00<005YF00000`001EYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01000
0UYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF0000031oo`00;7oo00@005YFFUH000AJEP03
001JEUYF00=JEP@001Uoo`@00003FUH0000000AJEP03001JEUYF00AJEPH0009JEP03001JEUYF00IJ
EP04001JEUYFFUH40002FUH00`00FUIJEP02FUH00`00FUH0000200000eYF001JEP0;FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH00002FUH40002FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH60004FUH00`00FUIJEP04FUH2000bOol002aoo`04001JEUYF
0004FUH01000FUIJEUYF0P003Woo0`0047oo00<005YFFUH015YF00<005YFFUH0100025YF00<005YF
FUH01UYF00<005YFFUH01EYF100015YF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP00FUH00eYF00<005YF00000P001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00@005YFFUIJEPH000=JEP<003=oo`00;7oo00@005YFFUH000AJEP04
001JEP00000?Ool5000>Ool20005FUH40002FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH00`00FUIJEP02FUH300001eYF001JEUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF00=JEP03001JEUYF009JEPD0009JEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00<003Eoo`00;7oo00@005YFFUH000AJEP80
015oo`D000aoo`800003FUH005YF009JEPH0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001J
EUYF00AJEP03001JEUYF00AJEP<0009JEP03001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJEP04FUH01000FUIJEUYF1`0015YF00<005YF
FUH01UYF00<005YFFUH01EYF0`000eYF0`00<Woo000]Ool00`00FUH00003FUH00`00Oomoo`0AOol5
000;Ool01P00FUIJEUYF001JEP<000AJEPP000AJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00AJEP08001JEUYF001JEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00`00003FUH005YF
00EJEP800003OomJEUYF00=JEP03001JEP00008002moo`00;Goo00@005YF001JEP800003FUH00000
019oo`<000]oo`03001JEUYF009JEP80009JEP03001JEUYF009JEP04001JEUYF0004FUH90004FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P0000=JEP00000035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF
1P0015YF00<005YFFUH00UYF200000=JEP00FUH01EYF00<005YFFUH00UYF00<007ooOol0;7oo000]
Ool00`00FUH000020004FUH5000HOol40003FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<0
05YFFUH00eYF00<005YFFUH01EYF200015YF00<005YFFUH00eYF00@005YFFUIJEPD000aJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00AJEP03001J
EUYF00=JEP800003FUH005YF00MJEP03001JEUYF00IJEP04001JEUYFFUH50002FUH00`00FUIJEP02
FUH3000]Ool002eoo`05001JEP00FUH00005FUH01000FUIJEUYF20002Goo1`000UYF0P000UYF00<0
05YFFUH015YF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00=J
EPl00004FUH00000000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
0004FUH00`00FUIJEP04FUH00`00FUIJEP030003FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00
FUIJEP05FUH800000eYF0000000]Ool002eoo`80009JEP03001JEUYF00=JEP03001JEUYF00AJEP03
001JEUYF009JEPT000AJEP05001JEUYFFUH00002FUH30006FUH01@00FUIJEUYF00000UYF00<005YF
FUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH01eYF0`0035YF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF10001eYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00`000eYF0P00;Goo000]Ool20002
FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH01@00FUIJEUYF
00000UYF00<005YF00001UYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00UJEP03001JEUYF00IJEP04001JEP00000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP03FUH200000eYF001JEP07FUH00`00FUIJEP02FUH?
0005FUH00`00FUIJEP02FUH200000eYF001JEP0^Ool002eoo`80009JEP03001JEUYF00=JEP03001J
EUYF00AJEP8000MJEP03001JEUYF00IJEP05001JEUYFFUH00002FUH00`00FUH00006FUH01@00FUIJ
EUYF00000UYF00<005YFFUH00eYF1P0015YF00<005YFFUH02EYF00<005YFFUH01UYF00@005YF0000
00aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800005Ool00000FUH00003FUH2
0003FUH00`00FUIJEP05FUH60002FUH00`00FUIJEP06FUH01000FUIJEUYF100000=JEP00FUH015YF
1000;Woo000]Ool20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP06FUH0
1`00FUIJEUYF001JEP00009JEP03001JEUYF00AJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH6
0004FUH00`00FUIJEP09FUH00`00FUIJEP05FUH200000eYF0000000<FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003Ool50005FUH00`00FUIJEP02FUH30007FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH30005FUH01000FUH00000;Woo000]Ool?0002FUH20007FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP03FUH01@00FUIJEUYF00000UYF00<005YFFUH00eYF
1P0015YF00<005YFFUH02EYF00<005YFFUH00eYF0P0000EJEP00001JEP0000aJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP8000Eoo`8000IJEP03001JEP0000800003FUH005YF00MJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF008000=JEP05001JEUYFFUH0000]Ool002eo
o`03001JEUYF009JEP03001JEUYF00=JEP04001JEUYFFUH90002FUH00`00FUIJEP07FUH01@00FUIJ
EUYF000015YF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEP00008000EJ
EP03001JEUYF00UJEP03001JEUYF009JEP04001JEUYFFUH200000eYF001JEP0;FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004Ool00`00FUH00006FUH20004FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH00`00Oomo
o`0[Ool002eoo`05FUH00000FUH00005FUH00`00FUIJEP06FUH00`00FUIJEP02FUH90003FUH01000
FUIJEUYF0P000eYF00<005YFFUH015YF00@005YFFUH0009JEP03001JEUYF00=JEP03001JEUYF00MJ
EP03001JEUYF00UJEP05001JEUYFFUH00004FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P000goo00D005YFFUIJEP0000=JEP80009JEPL000IJEP03001JEUYF
00IJEP03001JEUYF00EJEP03001JEUYF00=JEP<000=JEP03001oogoo02]oo`00;Goo0UYF0`001EYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF1P0000=JEP00FUH00P0000=JEP00FUH0
1EYF10000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF00000P0015YF
00@005YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009oo`03001J
EUYF009JEP03001JEP00008000AJEP03001JEP0000=oo`@0009JEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00Oomoo`0[Ool002aoo`04001JEUYF0002
FUH60007FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000020002FUH20006FUH01000Oomo
o`000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0P000UYF00D005YFFUIJEP00
00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD000AJEP80
009JEP03001JEUYF009JEP04001JEP000006Ool70004FUH00`00FUIJEP04FUH00`00FUIJEP03FUH0
1000FUIJEUYF1000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF1@000eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YFFUH00`000UYF0`000goo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00QJEP8000AJEP03001JEP0000AJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0000000=JEP03001JEUYF009JEP03001J
EUYF009JEP04001JEP00000=OolF0002Ool00`00Oomoo`0[Ool002aoo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEP0000@000MJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0002FUH3
0005Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH01EYF0`001UYF0P001EYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH00P001EYF
00<005YFFUH00UYF00@005YFFUH002Eoo`03001oogoo02]oo`00;7oo0UYF00<005YFFUH00UYF00<0
05YFFUH015YF00<005YFFUH00eYF1`0000=JEP00FUH01eYF00<005YFFUH00eYF00<005YF000015YF
1@0000Eoo`00FUIJEP0000EJEP03001JEUYF00MJEP04001JEUYFFUH40002FUH00`00FUIJEP03FUH2
0006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH3000015YF
000000001UYF00<005YFFUH00UYF00@005YFFUH000Moo`<001Yoo`8002eoo`00;7oo0UYF00<005YF
FUH00UYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH00UYF2`000UYF1P001EYF00<005YF
00000`000UYF00<005YFFUH00eYF00<005YFFUH015YF1`001UYF00@005YFFUIJEP8000QJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<00004FUH005YF0007FUH0
0`00FUIJEP02FUH20007Ool5000IOol00`00FUH0000/Ool002aoo`9JEP05001JEUYFFUH00006FUH0
0`00FUIJEP06FUH01000FUIJEUYF10000UYF00<005YFFUH00UYF2@001EYF00<005YFFUH00eYF3`00
15YF00<005YFFUH01UYF00@005YF000000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP@0009JEP03001JEUYF00EJEP03001JEUYF009JEP8000Moo`D001Uoo`03
001JEP0002aoo`00:goo00@005YFFUH000=JEP03001JEUYF00AJEP03001JEUYF00EJEPD000IJEP03
001JEUYF00IJEP04001JEUYFFUH30003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH4000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`06Ool5000HOol20000
0eYF001oo`0[Ool002]oo`03001JEP0000AJEP03001JEUYF00AJEP04001JEUYFFUH40002FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001JEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH00`00FUIJEP02FUH0
0`00Oomoo`07Ool3000GOol200000eYF0000000]Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP@000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEP0000@000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEP00008000EJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEPD0009JEP03001JEUYF00AJEP05001J
EUYFFUH0000SOol01000FUIJEUYF0P00;Goo000/Ool40002FUH00`00FUIJEP03FUH30008FUH00`00
FUIJEP02FUH90004FUH00`00FUIJEP05FUH01000FUIJEUYF2`0015YF00<005YFFUH00UYF1P0025YF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
1@000UYF00<005YFFUH015YF00@005YF0000029oo`8000AJEP03001oogoo02aoo`00<7oo10000UYF
0P000UYF00<005YFFUH01EYF1P000UYF00<005YFFUH015YF200015YF00<005YFFUH00UYF0`000UYF
00<005YFFUH00UYF2@000UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000AJEP00FUH000IJEP80029oo`800003FUH0
05YF00=JEP03001oogoo02aoo`00=7oo0P001EYF00<005YFFUH00UYF0P0025YF00<005YFFUH01UYF
00<005YFFUH00eYF1@0015YF00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0P0000AJEP00FUIJEP<000=JEP<0025oo`8000=JEP05001JEUYFFUH0000_Ool003=oo`80
00IJEP03001JEP0000<000UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEUYFFUH20003FUH2
0002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000015YF001JEUYF0`0000AJ
EP000000021oo`<000EJEP04001JEP00000`Ool0035oo`800003FUH005YF00AJEP@0009JEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00=JEP800003FUH00000009JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00AJEQP000IJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP80009JEP03001JEP00009JEP80009JEP8001Yoo`@00003FUH005YF00EJ
EP80039oo`00<7oo00D005YFFUIJEP0000=JEP8000Aoo`L000AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00AJEP@0009JEP03001JEUYF00=JEP03001JEUYF00EJEPT000aJEP03001JEUYF
00UJEP`000EJEP03001JEUYF00EJEP03001JEUYF009JEP8000=JEP03001JEP0000=JEPH0015oo`L0
00EJEP03001JEUYF00AJEP03001oogoo035oo`00;goo00<005YFFUH00UYF00@005YF000000eoo`T0
00AJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00
FUIJEP050008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH70006FUH00`00FUIJ
EP02FUH80004FUH01000FUIJEUYF4P0015YF00<005YFFUH01UYF00@005YFFUIJEP8003Aoo`00;Woo
0P0015YF0P0067oo200015YF00<005YFFUH00eYF00D005YFFUIJEP00009JEP03001JEUYF00=JEP<0
009JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP8000EJEP80
00AJEP03001JEUYF009JEP<00003FUH0000000<000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP04001JEP00000fOol002ioo`8000=JEP03001oogoo021oo`l0
009JEP04001JEUYFFUH20005FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH20007FUH300000eYF001JEP03FUH30005FUH400000eYF001JEP05FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH4000hOol002eoo`06001JEUYF001JEP00<Goo00D005YF
FUH005YF008000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP8000QJEP04001JEP000004FUH200000eYF001JEP05FUH00`00FUH000020005FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP04000lOol002eoo`03001JEUYF008001Ioo`<001Uoo`03001J
EUYF00800003FUH005YF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP8000QJEP04001JEUYFFUH20002FUH200000eYF001JEP05FUH00`00FUIJEP02FUH40000
0eYF001JEP07FUH00`00FUIJEP02FUH70010Ool002eoo`04001JEUYF000FOol5000HOol00`00FUH0
0003FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP07FUH00`00FUIJEP03FUH70005FUH00`00FUIJEP03FUHB0017Ool002eoo`03
001JEP0001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP<000=JEP@00003FUH0
05YF00AJEP04001JEP00001EOol002ioo`8001Moo`D001Qoo`8000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001J
EUYF00AJEP<000IJEP@000AJEP04001JEUYF001EOol002ioo`03001oogoo01Moo`<001Moo`@000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000IJEP04001JEUYFFUH300000eYF001JEP02
FUH00`00Oomoo`1BOol002ioo`80035oo`05001JEUYFFUH00004FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH00`00FUIJ
EP04FUH00`00FUH00006FUH00`00FUIJEP03FUH30003FUH00`00Oomoo`1BOol002ioo`03001JEP00
02moo`03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03
001JEUYF00AJEP04001JEUYF0002FUH00`00Oomoo`1BOol002ioo`800003FUH007oo02]oo`<000AJ
EP<0009JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00MJEP03001JEUYF00AJEP8000IJEP03001JEUYF00=JEP04001JEUYFFUH2
00000eYF001oo`1COol002moo`04001JEUYF000YOol20002FUH01@00FUIJEUYF00000goo0`001eYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01eYF
00<005YFFUH00eYF30000eYF00<005YFFUH00P0000=oo`000000E7oo000_Ool00`00FUIJEP03000S
Ool40005FUH00`00FUH00006Ool20006FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUIJEUYF0P0037oo1P0017oo00<007ooOol0DWoo
000`Ool00`00FUH00002FUH2000MOol40002FUH00`00FUIJEP04FUH20009Ool40002FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP07FUH01000FUH0
00005goo0P00E7oo000`Ool00`00FUH00004FUH5000COol50006FUH00`00FUIJEP03FUH2000>Ool5
0008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP03FUH6000IOol3
001COol0035oo`8000EJEP04001JEUYFFUH80007Ool40002FUH00`00FUIJEP06FUH01000FUIJEUYF
0P005Goo1P000UYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF00000`00
00=oo`0000000`006Goo00<005YF0000Dgoo000bOol00`00FUIJEP03FUH00`00FUIJEP05FUH01000
FUIJEUYF1`001UYF00<005YFFUH01UYF00@005YF000001eoo`T000IJEP03001JEUYF00YJEP03001J
EUYF00=JEPL000Eoo`D001Qoo`800003FUH007oo059oo`00<goo0P000eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF0`00:7oo6@0037oo1@005Woo0P0000=JEP00
0000E7oo000eOol200000eYF001JEP06FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04
000fOol2000IOol3000FOol01000FUIJEUYF0P00E7oo000gOol50004FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH7000jOol3000`Ool00`00FUIJEP02FUH00`00Oomoo`1COol003aooa80045oo`800003
FUH007oo02aoo`<000AJEP03001oogoo05=oo`00Sgoo0P000UYF00<007ooOol0:7oo0P000UYF00D0
05YFFUIJEP0005Ioo`00T7oo00<005YFFUH00`009Woo0P0015YF00@005YF000005Moo`00T7oo00@0
05YFFUH0009JEP80029oo`8000IJEP8005Uoo`00TGoo00@005YFFUH000=JEP<001]oo`@00003FUH0
05YF00EJEP03001oogoo05Qoo`00TWoo0`0015YF00<005YF00000`0047oo1`001EYF00<005YFFUH0
0UYF0P00Fgoo002DOol00`00FUIJEP02FUH00`00FUIJEP03FUH@0004FUH00`00FUIJEP06FUH01000
FUH00000GGoo002EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH3001OOol009Moo`800003FUH005YF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF009JEP<0069oo`00VGoo0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF0000
0P00IGoo002LOol400000eYF001JEP07FUH00`00FUIJEP02FUH6001XOol00:1oo`l006ioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.5941 .73294 m .59809 .67566 L .56695 .67284 L p .707 .577 .707 r
F P
0 g
s
.59809 .67566 m .5941 .73294 L .62584 .73483 L p .707 .577 .707 r
F P
0 g
s
.62584 .73483 m .62983 .67755 L .59809 .67566 L p .707 .577 .707 r
F P
0 g
s
.62983 .67755 m .62584 .73483 L .65508 .73561 L p .707 .577 .707 r
F P
0 g
s
.65508 .73561 m .65907 .67832 L .62983 .67755 L p .707 .577 .707 r
F P
0 g
s
.56695 .67284 m .56296 .73013 L .5941 .73294 L p .707 .577 .707 r
F P
0 g
s
.56296 .73013 m .56695 .67284 L .53946 .66937 L p .707 .577 .707 r
F P
0 g
s
.53946 .66937 m .53547 .72665 L .56296 .73013 L p .707 .577 .707 r
F P
0 g
s
.65907 .67832 m .65508 .73561 L .67895 .73519 L p .707 .577 .707 r
F P
0 g
s
.67895 .73519 m .68294 .6779 L .65907 .67832 L p .707 .577 .707 r
F P
0 g
s
.53547 .72665 m .53946 .66937 L .51831 .66558 L p .707 .577 .707 r
F P
0 g
s
.51831 .66558 m .51432 .72286 L .53547 .72665 L p .707 .577 .707 r
F P
0 g
s
.59302 .83197 m .59461 .81284 L .56348 .80984 L p .707 .577 .707 r
F P
0 g
s
.59461 .81284 m .59302 .83197 L .62472 .83439 L p .707 .577 .707 r
F P
0 g
s
.62472 .83439 m .62631 .81526 L .59461 .81284 L p .707 .577 .707 r
F P
0 g
s
.56348 .80984 m .5619 .82897 L .59302 .83197 L p .707 .577 .707 r
F P
0 g
s
.62631 .81526 m .62472 .83439 L .6539 .83599 L p .707 .577 .707 r
F P
0 g
s
.6539 .83599 m .65548 .81686 L .62631 .81526 L p .707 .577 .707 r
F P
0 g
s
.5619 .82897 m .56348 .80984 L .53598 .80655 L p .707 .577 .707 r
F P
0 g
s
.60344 .84029 m .59785 .80994 L .56683 .80982 L p .707 .577 .707 r
F P
0 g
s
.59785 .80994 m .60344 .84029 L .63484 .83434 L p .707 .577 .707 r
F P
0 g
s
.63484 .83434 m .62926 .80398 L .59785 .80994 L p .707 .577 .707 r
F P
0 g
s
.65548 .81686 m .6539 .83599 L .67768 .83661 L p .707 .577 .707 r
F P
0 g
s
.67768 .83661 m .67927 .81748 L .65548 .81686 L p .707 .577 .707 r
F P
0 g
s
.62926 .80398 m .63484 .83434 L .66356 .82289 L p .707 .577 .707 r
F P
0 g
s
.66356 .82289 m .65797 .79254 L .62926 .80398 L p .707 .577 .707 r
F P
0 g
s
.53598 .80655 m .53439 .82568 L .5619 .82897 L p .707 .577 .707 r
F P
0 g
s
.68294 .6779 m .67895 .73519 L .69511 .73362 L p .707 .577 .707 r
F P
0 g
s
.69511 .73362 m .6991 .67633 L .68294 .6779 L p .707 .577 .707 r
F P
0 g
s
.57241 .84018 m .56683 .80982 L .53922 .80365 L p .707 .577 .707 r
F P
0 g
s
.56683 .80982 m .57241 .84018 L .60344 .84029 L p .707 .577 .707 r
F P
0 g
s
.65797 .79254 m .66356 .82289 L .68677 .80707 L p .707 .577 .707 r
F P
0 g
s
.68677 .80707 m .68118 .77672 L .65797 .79254 L p .707 .577 .707 r
F P
0 g
s
.51432 .72286 m .51831 .66558 L .50557 .66184 L p .707 .577 .707 r
F P
0 g
s
.53439 .82568 m .53598 .80655 L .51479 .80329 L p .707 .577 .707 r
F P
0 g
s
.50557 .66184 m .50158 .71913 L .51432 .72286 L p .707 .577 .707 r
F P
0 g
s
.51479 .80329 m .5132 .82242 L .53439 .82568 L p .707 .577 .707 r
F P
0 g
s
.54481 .834 m .53922 .80365 L .51773 .79201 L p .707 .577 .707 r
F P
0 g
s
.53922 .80365 m .54481 .834 L .57241 .84018 L p .707 .577 .707 r
F P
0 g
s
.68118 .77672 m .68677 .80707 L .7022 .78844 L p .707 .577 .707 r
F P
0 g
s
.7022 .78844 m .69661 .75808 L .68118 .77672 L p .707 .577 .707 r
F P
0 g
s
.6991 .67633 m .69511 .73362 L .70199 .73105 L p .707 .577 .707 r
F P
0 g
s
.70199 .73105 m .70598 .67377 L .6991 .67633 L p .707 .577 .707 r
F P
0 g
s
.67927 .81748 m .67768 .83661 L .69376 .8362 L p .707 .577 .707 r
F P
0 g
s
.69376 .8362 m .69535 .81707 L .67927 .81748 L p .707 .577 .707 r
F P
0 g
s
.50158 .71913 m .50557 .66184 L .50249 .65853 L p .707 .577 .707 r
F P
0 g
s
.5132 .82242 m .51479 .80329 L .50199 .80039 L p .707 .577 .707 r
F P
0 g
s
.50199 .80039 m .5004 .81952 L .5132 .82242 L p .707 .577 .707 r
F P
0 g
s
.52332 .82237 m .51773 .79201 L .50447 .77606 L p .707 .577 .707 r
F P
0 g
s
.51773 .79201 m .52332 .82237 L .54481 .834 L p .707 .577 .707 r
F P
0 g
s
.50249 .65853 m .4985 .71582 L .50158 .71913 L p .707 .577 .707 r
F P
0 g
s
.69661 .75808 m .7022 .78844 L .70835 .7688 L p .707 .577 .707 r
F P
0 g
s
.70835 .7688 m .70276 .73845 L .69661 .75808 L p .707 .577 .707 r
F P
0 g
s
.69535 .81707 m .69376 .8362 L .70055 .83479 L p .707 .577 .707 r
F P
0 g
s
.70055 .83479 m .70214 .81566 L .69535 .81707 L p .707 .577 .707 r
F P
0 g
s
.70116 .73016 m .69891 .72774 L p .69958 .72261 L .707 .577 .707 r
F P
0 g
s
.69934 .72148 m .69902 .71974 L .69998 .72451 L p .708 .578 .707 r
F P
0 g
s
.7029 .67045 m .70598 .67377 L p .69999 .71947 L .707 .577 .707 r
F P
0 g
s
.69891 .72774 m .69934 .72148 L p .69999 .71947 L .707 .577 .707 r
F P
0 g
s
.69934 .72148 m .7029 .67045 L p .69999 .71947 L .707 .577 .707 r
F P
0 g
s
.69891 .72774 m .68617 .72401 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.69902 .71974 m .69934 .72148 L p .69849 .72074 L .707 .577 .707 r
F P
0 g
s
.69934 .72148 m .69891 .72774 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.68576 .70379 m .69902 .71974 L p .69849 .72074 L .707 .577 .707 r
F P
0 g
s
.68617 .72401 m .68708 .71094 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.69135 .73414 m .68708 .71094 L p .69849 .72074 L .707 .577 .707 r
F P
0 g
s
.68708 .71094 m .68576 .70379 L p .69849 .72074 L .707 .577 .707 r
F P
0 g
s
.69016 .66672 m .7029 .67045 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.68708 .71094 m .69016 .66672 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.7029 .67045 m .69934 .72148 L p .68958 .71309 L .707 .577 .707 r
F P
0 g
s
.69135 .73414 m .69849 .72074 L .69934 .72148 L .707 .577 .707 r
F
.69934 .72148 m .70461 .75009 L .69416 .73752 L p F P
0 g
s
.69416 .73752 m .69135 .73414 L p .69934 .72148 L .707 .577 .707 r
F P
0 g
s
.70461 .75009 m .69934 .72148 L p .70276 .73845 L .708 .578 .707 r
F P
0 g
s
.69998 .72451 m .70276 .73845 L p .69934 .72148 L .708 .578 .707 r
F P
0 g
s
.70598 .67377 m .70199 .73105 L .70116 .73016 L p .707 .577 .707 r
F P
0 g
s
.69958 .72261 m .70598 .67377 L .70116 .73016 L .707 .577 .707 r
F
.49412 .82299 m .48867 .32496 L .44466 .32247 L p F P
0 g
s
.50447 .77606 m .51006 .80641 L .52332 .82237 L p .707 .577 .707 r
F P
0 g
s
.51006 .80641 m .50447 .77606 L .50073 .75735 L p .708 .578 .707 r
F P
0 g
s
.5004 .81952 m .50199 .80039 L .49883 .79812 L p .707 .577 .707 r
F P
0 g
s
.49883 .79812 m .49724 .81725 L .5004 .81952 L p .707 .577 .707 r
F P
0 g
s
.4985 .71582 m .50249 .65853 L .50937 .65597 L p .707 .577 .707 r
F P
0 g
s
.50937 .65597 m .50538 .71325 L .4985 .71582 L p .707 .577 .707 r
F P
0 g
s
.50073 .75735 m .50632 .78771 L .51006 .80641 L p .708 .578 .707 r
F P
0 g
s
.50632 .78771 m .50073 .75735 L .50688 .73772 L p .707 .577 .707 r
F P
0 g
s
.49724 .81725 m .49883 .79812 L .50562 .79671 L p .707 .577 .707 r
F P
0 g
s
.50562 .79671 m .50403 .81584 L .49724 .81725 L p .707 .577 .707 r
F P
0 g
s
.50538 .71325 m .50937 .65597 L .52553 .6544 L p .707 .577 .707 r
F P
0 g
s
.52553 .6544 m .52154 .71168 L .50538 .71325 L p .707 .577 .707 r
F P
0 g
s
.50688 .73772 m .51247 .76807 L .50632 .78771 L p .707 .577 .707 r
F P
0 g
s
.51247 .76807 m .50688 .73772 L .52232 .71908 L p .707 .577 .707 r
F P
0 g
s
.52154 .71168 m .52553 .6544 L .5494 .65398 L p .707 .577 .707 r
F P
0 g
s
.50403 .81584 m .50562 .79671 L .52169 .79629 L p .707 .577 .707 r
F P
0 g
s
.52169 .79629 m .52011 .81542 L .50403 .81584 L p .707 .577 .707 r
F P
0 g
s
.53961 .7073 m .54553 .70326 L p .5447 .70542 L .707 .577 .707 r
F P
0 g
s
.54553 .70326 m .57424 .69182 L p .56962 .70017 L .707 .577 .707 r
F P
0 g
s
.54733 .7047 m .54553 .70326 L .56962 .70017 L .707 .577 .707 r
F
.5494 .65398 m .57864 .65475 L p .54953 .70425 L F P
0 g
s
.54541 .71127 m .54585 .705 L p .54953 .70425 L .707 .577 .707 r
F P
0 g
s
.54585 .705 m .54553 .70326 L p .54733 .7047 L .707 .577 .707 r
F P
0 g
s
.57465 .71204 m .54541 .71127 L p .54953 .70425 L .707 .577 .707 r
F P
0 g
s
.54585 .705 m .54733 .7047 L .56104 .71568 L .707 .577 .707 r
F
.57424 .69182 m .60565 .68586 L p .59754 .69726 L F P
0 g
s
.58186 .69848 m .57424 .69182 L .59754 .69726 L .707 .577 .707 r
F
.57864 .65475 m .61038 .65664 L p .58347 .69835 L F P
0 g
s
.57465 .71204 m .57556 .69897 L p .58347 .69835 L .707 .577 .707 r
F P
0 g
s
.57556 .69897 m .57424 .69182 L p .58186 .69848 L .707 .577 .707 r
F P
0 g
s
.60639 .71393 m .57465 .71204 L p .58347 .69835 L .707 .577 .707 r
F P
0 g
s
.57556 .69897 m .58186 .69848 L .59099 .70647 L .707 .577 .707 r
F
.63753 .71674 m .60639 .71393 L p .61737 .69689 L F P
0 g
s
.60565 .68586 m .63667 .68597 L p .62714 .6973 L .707 .577 .707 r
F P
0 g
s
.61566 .69682 m .60565 .68586 L .62714 .6973 L .707 .577 .707 r
F
.66502 .72022 m .63753 .71674 L p .64767 .6994 L F P
0 g
s
.63667 .68597 m .66428 .69215 L p .65625 .70096 L .707 .577 .707 r
F P
0 g
s
.64658 .6992 m .63667 .68597 L .65625 .70096 L .707 .577 .707 r
F
.68617 .72401 m .66502 .72022 L p .67213 .70508 L F P
0 g
s
.66428 .69215 m .68576 .70379 L p .68153 .70877 L .707 .577 .707 r
F P
0 g
s
.67233 .70516 m .66428 .69215 L .68153 .70877 L .707 .577 .707 r
F
.68708 .71094 m .68617 .72401 L p .67213 .70508 L F P
0 g
s
.66623 .70278 m .66428 .69215 L p .67233 .70516 L .707 .577 .707 r
F P
0 g
s
.66502 .72022 m .66623 .70278 L p .67213 .70508 L .707 .577 .707 r
F P
0 g
s
.66623 .70278 m .67233 .70516 L .6775 .71352 L .707 .577 .707 r
F
.66901 .66293 m .69016 .66672 L p .67213 .70508 L F P
0 g
s
.66623 .70278 m .66901 .66293 L p .67213 .70508 L .707 .577 .707 r
F P
0 g
s
.68576 .70379 m .69135 .73414 L .66987 .72251 L p .707 .577 .707 r
F P
0 g
s
.69016 .66672 m .68708 .71094 L p .67213 .70508 L .707 .577 .707 r
F P
0 g
s
.6775 .71352 m .67233 .70516 L .68153 .70877 L .707 .577 .707 r
F
.66987 .72251 m .66623 .70278 L p .6775 .71352 L F P
0 g
s
.66623 .70278 m .66502 .72022 L p .64767 .6994 L .707 .577 .707 r
F P
0 g
s
.66428 .69215 m .66987 .72251 L .64226 .71633 L p .707 .577 .707 r
F P
0 g
s
.64767 .6994 m .65305 .69021 L .66623 .70278 L .707 .577 .707 r
F
.66901 .66293 m .66623 .70278 L p .65305 .69021 L F P
0 g
s
.64152 .65946 m .66901 .66293 L p .64767 .6994 L .707 .577 .707 r
F P
0 g
s
.63753 .71674 m .63885 .6978 L p .64767 .6994 L .707 .577 .707 r
F P
0 g
s
.63885 .6978 m .63667 .68597 L p .64658 .6992 L .707 .577 .707 r
F P
0 g
s
.63885 .6978 m .64152 .65946 L p .64767 .6994 L .707 .577 .707 r
F P
0 g
s
.63885 .6978 m .64658 .6992 L .65167 .706 L .707 .577 .707 r
F
.65167 .706 m .64658 .6992 L .65625 .70096 L F
.64226 .71633 m .63885 .6978 L p .65167 .706 L F P
0 g
s
.63885 .6978 m .63753 .71674 L p .61737 .69689 L .707 .577 .707 r
F P
0 g
s
.63667 .68597 m .64226 .71633 L .61124 .71621 L p .707 .577 .707 r
F P
0 g
s
.61737 .69689 m .62323 .68781 L .63885 .6978 L .707 .577 .707 r
F
.64152 .65946 m .63885 .6978 L p .62323 .68781 L F P
0 g
s
.61038 .65664 m .64152 .65946 L p .61737 .69689 L .707 .577 .707 r
F P
0 g
s
.60639 .71393 m .6076 .69648 L p .61737 .69689 L .707 .577 .707 r
F P
0 g
s
.6076 .69648 m .60565 .68586 L p .61566 .69682 L .707 .577 .707 r
F P
0 g
s
.6076 .69648 m .61038 .65664 L p .61737 .69689 L .707 .577 .707 r
F P
0 g
s
.6076 .69648 m .61566 .69682 L .62185 .7036 L .707 .577 .707 r
F
.62185 .7036 m .61566 .69682 L .62714 .6973 L F
.61124 .71621 m .6076 .69648 L p .62185 .7036 L F P
0 g
s
.6076 .69648 m .60639 .71393 L p .58347 .69835 L .707 .577 .707 r
F P
0 g
s
.60565 .68586 m .61124 .71621 L .57983 .72217 L p .707 .577 .707 r
F P
0 g
s
.58347 .69835 m .59027 .68782 L .6076 .69648 L .707 .577 .707 r
F
.61038 .65664 m .6076 .69648 L p .59027 .68782 L F P
0 g
s
.57556 .69897 m .57864 .65475 L p .58347 .69835 L .707 .577 .707 r
F P
0 g
s
.59099 .70647 m .58186 .69848 L .59754 .69726 L .707 .577 .707 r
F
.57983 .72217 m .57556 .69897 L p .59099 .70647 L F P
0 g
s
.57556 .69897 m .57465 .71204 L p .54953 .70425 L .707 .577 .707 r
F P
0 g
s
.57424 .69182 m .57983 .72217 L .55112 .73362 L p .707 .577 .707 r
F P
0 g
s
.54953 .70425 m .55774 .6903 L .57556 .69897 L .707 .577 .707 r
F
.57864 .65475 m .57556 .69897 L p .55774 .6903 L F P
0 g
s
.54585 .705 m .5494 .65398 L p .54953 .70425 L .707 .577 .707 r
F P
0 g
s
.56104 .71568 m .54733 .7047 L .56962 .70017 L .707 .577 .707 r
F
.55112 .73362 m .54585 .705 L p .56104 .71568 L F P
0 g
s
.54585 .705 m .54541 .71127 L .52799 .71157 L p .707 .577 .707 r
F P
0 g
s
.54553 .70326 m .55112 .73362 L .52791 .74943 L p .707 .577 .707 r
F P
0 g
s
.52154 .71168 m .53011 .69394 L .54585 .705 L .707 .577 .707 r
F
.5494 .65398 m .54585 .705 L p .53011 .69394 L F P
0 g
s
.52799 .71157 m .52154 .71168 L p .54585 .705 L .707 .577 .707 r
F P
0 g
s
.52791 .74943 m .52232 .71908 L .53961 .7073 L p .707 .577 .707 r
F P
0 g
s
.52791 .74943 m .53961 .7073 L .5447 .70542 L .707 .577 .707 r
F
.52232 .71908 m .52791 .74943 L .51247 .76807 L p F P
0 g
s
.52011 .81542 m .52169 .79629 L .54548 .79691 L p .707 .577 .707 r
F P
0 g
s
.54548 .79691 m .54389 .81604 L .52011 .81542 L p .707 .577 .707 r
F P
0 g
s
.48867 .32496 m .49412 .82299 L .53906 .82134 L p .707 .577 .707 r
F P
0 g
s
.53906 .82134 m .53361 .32331 L .48867 .32496 L p .707 .577 .707 r
F P
0 g
s
.54389 .81604 m .54548 .79691 L .57465 .79851 L p .707 .577 .707 r
F P
0 g
s
.57465 .79851 m .57307 .81764 L .54389 .81604 L p .707 .577 .707 r
F P
0 g
s
.57307 .81764 m .57465 .79851 L .60635 .80093 L p .707 .577 .707 r
F P
0 g
s
.60635 .80093 m .60477 .82006 L .57307 .81764 L p .707 .577 .707 r
F P
0 g
s
.53361 .32331 m .53906 .82134 L .58054 .81571 L p .707 .577 .707 r
F P
0 g
s
.58054 .81571 m .57508 .31768 L .53361 .32331 L p .707 .577 .707 r
F P
0 g
s
.70276 .73845 m .70835 .7688 L .70461 .75009 L p .708 .578 .707 r
F P
0 g
s
.45011 .8205 m .44466 .32247 L .40589 .31608 L p .707 .577 .707 r
F P
0 g
s
.44466 .32247 m .45011 .8205 L .49412 .82299 L p .707 .577 .707 r
F P
0 g
s
.60477 .82006 m .60635 .80093 L .63748 .80393 L p .707 .577 .707 r
F P
0 g
s
.57508 .31768 m .58054 .81571 L .61449 .80664 L p .707 .577 .707 r
F P
0 g
s
.61449 .80664 m .60903 .30861 L .57508 .31768 L p .707 .577 .707 r
F P
0 g
s
.70214 .81566 m .70055 .83479 L .69739 .83252 L p .707 .577 .707 r
F P
0 g
s
.69739 .83252 m .69898 .81339 L .70214 .81566 L p .707 .577 .707 r
F P
0 g
s
.41135 .81411 m .40589 .31608 L .37616 .30641 L p .707 .577 .707 r
F P
0 g
s
.40589 .31608 m .41135 .81411 L .45011 .8205 L p .707 .577 .707 r
F P
0 g
s
.25109 .69613 m .25508 .63884 L .22394 .63602 L p .707 .577 .707 r
F P
0 g
s
.25508 .63884 m .25109 .69613 L .28283 .69802 L p .707 .577 .707 r
F P
0 g
s
.28283 .69802 m .28682 .64073 L .25508 .63884 L p .707 .577 .707 r
F P
0 g
s
.28682 .64073 m .28283 .69802 L .31207 .69879 L p .707 .577 .707 r
F P
0 g
s
.31207 .69879 m .31606 .6415 L .28682 .64073 L p .707 .577 .707 r
F P
0 g
s
.22394 .63602 m .21995 .69331 L .25109 .69613 L p .707 .577 .707 r
F P
0 g
s
.21995 .69331 m .22394 .63602 L .19645 .63255 L p .707 .577 .707 r
F P
0 g
s
.19645 .63255 m .19246 .68984 L .21995 .69331 L p .707 .577 .707 r
F P
0 g
s
.60903 .30861 m .61449 .80664 L .63759 .79503 L p .707 .577 .707 r
F P
0 g
s
.63759 .79503 m .63214 .297 L .60903 .30861 L p .707 .577 .707 r
F P
0 g
s
.31606 .6415 m .31207 .69879 L .33594 .69837 L p .707 .577 .707 r
F P
0 g
s
.33594 .69837 m .33993 .64108 L .31606 .6415 L p .707 .577 .707 r
F P
0 g
s
.19246 .68984 m .19645 .63255 L .1753 .62876 L p .707 .577 .707 r
F P
0 g
s
.69898 .81339 m .69739 .83252 L .68459 .82961 L p .707 .577 .707 r
F P
0 g
s
.68459 .82961 m .68618 .81048 L .69898 .81339 L p .707 .577 .707 r
F P
0 g
s
.1753 .62876 m .17131 .68605 L .19246 .68984 L p .707 .577 .707 r
F P
0 g
s
.25001 .79516 m .2516 .77603 L .22047 .77303 L p .707 .577 .707 r
F P
0 g
s
.2516 .77603 m .25001 .79516 L .28171 .79758 L p .707 .577 .707 r
F P
0 g
s
.28171 .79758 m .2833 .77845 L .2516 .77603 L p .707 .577 .707 r
F P
0 g
s
.22047 .77303 m .21889 .79216 L .25001 .79516 L p .707 .577 .707 r
F P
0 g
s
.38162 .80444 m .37616 .30641 L .35838 .29442 L p .707 .577 .707 r
F P
0 g
s
.37616 .30641 m .38162 .80444 L .41135 .81411 L p .707 .577 .707 r
F P
0 g
s
.2833 .77845 m .28171 .79758 L .31089 .79918 L p .707 .577 .707 r
F P
0 g
s
.31089 .79918 m .31247 .78005 L .2833 .77845 L p .707 .577 .707 r
F P
0 g
s
.21889 .79216 m .22047 .77303 L .19297 .76974 L p .707 .577 .707 r
F P
0 g
s
.26043 .80348 m .25484 .77312 L .22382 .77301 L p .707 .577 .707 r
F P
0 g
s
.25484 .77312 m .26043 .80348 L .29183 .79752 L p .707 .577 .707 r
F P
0 g
s
.29183 .79752 m .28625 .76717 L .25484 .77312 L p .707 .577 .707 r
F P
0 g
s
.31247 .78005 m .31089 .79918 L .33468 .7998 L p .707 .577 .707 r
F P
0 g
s
.33468 .7998 m .33626 .78067 L .31247 .78005 L p .707 .577 .707 r
F P
0 g
s
.28625 .76717 m .29183 .79752 L .32055 .78607 L p .707 .577 .707 r
F P
0 g
s
.32055 .78607 m .31496 .75572 L .28625 .76717 L p .707 .577 .707 r
F P
0 g
s
.19297 .76974 m .19138 .78887 L .21889 .79216 L p .707 .577 .707 r
F P
0 g
s
.33993 .64108 m .33594 .69837 L .3521 .6968 L p .707 .577 .707 r
F P
0 g
s
.3521 .6968 m .35609 .63952 L .33993 .64108 L p .707 .577 .707 r
F P
0 g
s
.2294 .80336 m .22382 .77301 L .19621 .76683 L p .707 .577 .707 r
F P
0 g
s
.22382 .77301 m .2294 .80336 L .26043 .80348 L p .707 .577 .707 r
F P
0 g
s
.31496 .75572 m .32055 .78607 L .34376 .77026 L p .707 .577 .707 r
F P
0 g
s
.34376 .77026 m .33817 .7399 L .31496 .75572 L p .707 .577 .707 r
F P
0 g
s
.17131 .68605 m .1753 .62876 L .16256 .62503 L p .707 .577 .707 r
F P
0 g
s
.19138 .78887 m .19297 .76974 L .17178 .76648 L p .707 .577 .707 r
F P
0 g
s
.16256 .62503 m .15857 .68232 L .17131 .68605 L p .707 .577 .707 r
F P
0 g
s
.63214 .297 m .63759 .79503 L .64759 .78202 L p .707 .577 .707 r
F P
0 g
s
.64759 .78202 m .64213 .28399 L .63214 .297 L p .707 .577 .707 r
F P
0 g
s
.17178 .76648 m .17019 .78561 L .19138 .78887 L p .707 .577 .707 r
F P
0 g
s
.68618 .81048 m .68459 .82961 L .6634 .82635 L p .707 .577 .707 r
F P
0 g
s
.6634 .82635 m .66498 .80723 L .68618 .81048 L p .707 .577 .707 r
F P
0 g
s
.2018 .79719 m .19621 .76683 L .17473 .7552 L p .707 .577 .707 r
F P
0 g
s
.19621 .76683 m .2018 .79719 L .2294 .80336 L p .707 .577 .707 r
F P
0 g
s
.33817 .7399 m .34376 .77026 L .35919 .75162 L p .707 .577 .707 r
F P
0 g
s
.35919 .75162 m .35361 .72127 L .33817 .7399 L p .707 .577 .707 r
F P
0 g
s
.35609 .63952 m .3521 .6968 L .35898 .69424 L p .707 .577 .707 r
F P
0 g
s
.35898 .69424 m .36297 .63695 L .35609 .63952 L p .707 .577 .707 r
F P
0 g
s
.33626 .78067 m .33468 .7998 L .35075 .79938 L p .707 .577 .707 r
F P
0 g
s
.35075 .79938 m .35234 .78026 L .33626 .78067 L p .707 .577 .707 r
F P
0 g
s
.35361 .72127 m .35919 .75162 L .36534 .73199 L p .707 .577 .707 r
F P
0 g
s
.36534 .73199 m .35975 .70163 L .35361 .72127 L p .707 .577 .707 r
F P
0 g
s
.36297 .63695 m .35898 .69424 L .35815 .69334 L p .707 .577 .707 r
F P
0 g
s
.35815 .69334 m .3559 .69092 L p .35657 .68579 L .707 .577 .707 r
F P
0 g
s
.35634 .68466 m .35602 .68292 L .35697 .68769 L p .708 .578 .707 r
F P
0 g
s
.35657 .68579 m .36297 .63695 L .35815 .69334 L .707 .577 .707 r
F
.35989 .63364 m .36297 .63695 L p .35698 .68266 L F P
0 g
s
.3559 .69092 m .35634 .68466 L p .35698 .68266 L .707 .577 .707 r
F P
0 g
s
.35634 .68466 m .35989 .63364 L p .35698 .68266 L .707 .577 .707 r
F P
0 g
s
.3559 .69092 m .34316 .68719 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.35602 .68292 m .35634 .68466 L p .35548 .68393 L .707 .577 .707 r
F P
0 g
s
.35634 .68466 m .3559 .69092 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.34275 .66697 m .35602 .68292 L p .35548 .68393 L .707 .577 .707 r
F P
0 g
s
.34316 .68719 m .34407 .67412 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.34834 .69732 m .34407 .67412 L p .35548 .68393 L .707 .577 .707 r
F P
0 g
s
.34407 .67412 m .34275 .66697 L p .35548 .68393 L .707 .577 .707 r
F P
0 g
s
.34715 .62991 m .35989 .63364 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.34407 .67412 m .34715 .62991 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.35989 .63364 m .35634 .68466 L p .34657 .67627 L .707 .577 .707 r
F P
0 g
s
.34834 .69732 m .35548 .68393 L .35634 .68466 L .707 .577 .707 r
F
.35634 .68466 m .3616 .71328 L .35115 .70071 L p F P
0 g
s
.35115 .70071 m .34834 .69732 L p .35634 .68466 L .707 .577 .707 r
F P
0 g
s
.3616 .71328 m .35634 .68466 L p .35975 .70163 L .708 .578 .707 r
F P
0 g
s
.35697 .68769 m .35975 .70163 L p .35634 .68466 L .708 .578 .707 r
F P
0 g
s
.35975 .70163 m .36534 .73199 L .3616 .71328 L p .708 .578 .707 r
F P
0 g
s
.36384 .79245 m .35838 .29442 L .35429 .28127 L p .707 .577 .707 r
F P
0 g
s
.35838 .29442 m .36384 .79245 L .38162 .80444 L p .707 .577 .707 r
F P
0 g
s
.15857 .68232 m .16256 .62503 L .15948 .62172 L p .707 .577 .707 r
F P
0 g
s
.17019 .78561 m .17178 .76648 L .15898 .76357 L p .707 .577 .707 r
F P
0 g
s
.15898 .76357 m .15739 .7827 L .17019 .78561 L p .707 .577 .707 r
F P
0 g
s
.66498 .80723 m .6634 .82635 L .63589 .82306 L p .707 .577 .707 r
F P
0 g
s
.63589 .82306 m .63748 .80393 L .66498 .80723 L p .707 .577 .707 r
F P
0 g
s
.18031 .78555 m .17473 .7552 L .16146 .73925 L p .707 .577 .707 r
F P
0 g
s
.17473 .7552 m .18031 .78555 L .2018 .79719 L p .707 .577 .707 r
F P
0 g
s
.15948 .62172 m .15549 .679 L .15857 .68232 L p .707 .577 .707 r
F P
0 g
s
.63748 .80393 m .63589 .82306 L .60477 .82006 L p .707 .577 .707 r
F P
0 g
s
.64213 .28399 m .64759 .78202 L .64721 .78082 L p .707 .577 .707 r
F P
0 g
s
.64331 .70524 m .64213 .28399 L .64721 .78082 L .707 .577 .707 r
F
.63803 .27084 m .64213 .28399 L p .64311 .632 L F P
0 g
s
.64347 .76212 m .64196 .62946 L .64311 .632 L .707 .577 .707 r
F
.6434 .76096 m .64196 .62946 L p .64347 .76212 L F P
0 g
s
.64721 .78082 m .64395 .77034 L p .64331 .70524 L .707 .577 .707 r
F P
0 g
s
.64395 .77034 m .64349 .76887 L p .64347 .76212 L .707 .577 .707 r
F P
0 g
s
.64347 .76212 m .64331 .70524 L .64395 .77034 L .707 .577 .707 r
F
.63803 .27084 m .64349 .76887 L .62571 .75688 L p F P
0 g
s
.63919 .7099 m .6376 .72903 L .6416 .72994 L p .707 .577 .707 r
F P
0 g
s
.6416 .72994 m .65041 .73194 L p .6406 .71267 L .707 .577 .707 r
F P
0 g
s
.6406 .71267 m .63919 .7099 L .6416 .72994 L .707 .577 .707 r
F
.65041 .73194 m .65199 .71281 L .64046 .71019 L p F P
0 g
s
.64046 .71019 m .63919 .7099 L p .6406 .71267 L .707 .577 .707 r
F P
0 g
s
.65041 .73194 m .64046 .71019 L .6406 .71267 L .707 .577 .707 r
F
.64349 .76887 m .6434 .76096 L p .64347 .76212 L F P
0 g
s
.64196 .62946 m .63803 .27084 L p .64311 .632 L .707 .577 .707 r
F P
0 g
s
.64278 .56981 m .63969 .5665 L p .63886 .62256 L .707 .577 .707 r
F P
0 g
s
.63879 .62709 m .63907 .62303 L p .63886 .62256 L .707 .577 .707 r
F P
0 g
s
.63907 .62303 m .64278 .56981 L p .63886 .62256 L .707 .577 .707 r
F P
0 g
s
.64278 .56981 m .63907 .62303 L p .65153 .63083 L .707 .577 .707 r
F P
0 g
s
.63907 .62303 m .63879 .62709 L .63929 .62724 L p .707 .577 .707 r
F P
0 g
s
.63929 .62724 m .65153 .63083 L p .63907 .62303 L .707 .577 .707 r
F P
0 g
s
.35234 .78026 m .35075 .79938 L .35754 .79797 L p .707 .577 .707 r
F P
0 g
s
.35754 .79797 m .35913 .77884 L .35234 .78026 L p .707 .577 .707 r
F P
0 g
s
.16146 .73925 m .16705 .7696 L .18031 .78555 L p .707 .577 .707 r
F P
0 g
s
.16705 .7696 m .16146 .73925 L .15773 .72054 L p .708 .578 .707 r
F P
0 g
s
.15739 .7827 m .15898 .76357 L .15582 .7613 L p .707 .577 .707 r
F P
0 g
s
.15582 .7613 m .15423 .78043 L .15739 .7827 L p .707 .577 .707 r
F P
0 g
s
.15549 .679 m .15948 .62172 L .16636 .61915 L p .707 .577 .707 r
F P
0 g
s
.16636 .61915 m .16237 .67644 L .15549 .679 L p .707 .577 .707 r
F P
0 g
s
.35429 .28127 m .35974 .7793 L .36384 .79245 L p .707 .577 .707 r
F P
0 g
s
.35974 .7793 m .35429 .28127 L .36428 .26826 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.35913 .77884 m .35754 .79797 L .35438 .7957 L p .707 .577 .707 r
F P
0 g
s
.35438 .7957 m .35597 .77657 L .35913 .77884 L p .707 .577 .707 r
F P
0 g
s
.15773 .72054 m .16331 .75089 L .16705 .7696 L p .708 .578 .707 r
F P
0 g
s
.16331 .75089 m .15773 .72054 L .16387 .7009 L p .707 .577 .707 r
F P
0 g
s
.15423 .78043 m .15582 .7613 L .16261 .75989 L p .707 .577 .707 r
F P
0 g
s
.62571 .75688 m .62025 .25885 L .63803 .27084 L p .707 .577 .707 r
F P
0 g
s
.16261 .75989 m .16102 .77902 L .15423 .78043 L p .707 .577 .707 r
F P
0 g
s
.16237 .67644 m .16636 .61915 L .18252 .61758 L p .707 .577 .707 r
F P
0 g
s
.18252 .61758 m .17853 .67487 L .16237 .67644 L p .707 .577 .707 r
F P
0 g
s
.16387 .7009 m .16946 .73126 L .16331 .75089 L p .707 .577 .707 r
F P
0 g
s
.16946 .73126 m .16387 .7009 L .17931 .68226 L p .707 .577 .707 r
F P
0 g
s
.36974 .76628 m .36428 .26826 L .38738 .25665 L p .707 .577 .707 r
F P
0 g
s
.36428 .26826 m .36974 .76628 L .35974 .7793 L p .707 .577 .707 r
F P
0 g
s
.34316 .68719 m .32201 .6834 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.34275 .66697 m .34407 .67412 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.34407 .67412 m .34316 .68719 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.32127 .65534 m .34275 .66697 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.32201 .6834 m .32322 .66596 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.32686 .68569 m .32322 .66596 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.32322 .66596 m .32127 .65534 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.326 .62612 m .34715 .62991 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.32322 .66596 m .326 .62612 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.34715 .62991 m .34407 .67412 L p .32912 .66827 L .707 .577 .707 r
F P
0 g
s
.34834 .69732 m .32686 .68569 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.34407 .67412 m .34834 .69732 L p .33853 .67195 L .707 .577 .707 r
F P
0 g
s
.35597 .77657 m .35438 .7957 L .34158 .7928 L p .707 .577 .707 r
F P
0 g
s
.34158 .7928 m .34317 .77367 L .35597 .77657 L p .707 .577 .707 r
F P
0 g
s
.17853 .67487 m .18252 .61758 L .20639 .61716 L p .707 .577 .707 r
F P
0 g
s
.16102 .77902 m .16261 .75989 L .17868 .75948 L p .707 .577 .707 r
F P
0 g
s
.17868 .75948 m .1771 .77861 L .16102 .77902 L p .707 .577 .707 r
F P
0 g
s
.20284 .66819 m .2024 .67445 L .18498 .67476 L p .707 .577 .707 r
F P
0 g
s
.1849 .71262 m .17931 .68226 L .1966 .67048 L p .707 .577 .707 r
F P
0 g
s
.1966 .67048 m .20252 .66645 L p .20169 .66861 L .707 .577 .707 r
F P
0 g
s
.1849 .71262 m .1966 .67048 L .20169 .66861 L .707 .577 .707 r
F
.20252 .66645 m .23123 .655 L p .22661 .66336 L F P
0 g
s
.20432 .66789 m .20252 .66645 L .22661 .66336 L .707 .577 .707 r
F
.20639 .61716 m .23563 .61794 L p .20653 .66744 L F P
0 g
s
.2024 .67445 m .20284 .66819 L p .20653 .66744 L .707 .577 .707 r
F P
0 g
s
.20284 .66819 m .20252 .66645 L p .20432 .66789 L .707 .577 .707 r
F P
0 g
s
.23164 .67522 m .2024 .67445 L p .20653 .66744 L .707 .577 .707 r
F P
0 g
s
.20284 .66819 m .20432 .66789 L .21803 .67886 L .707 .577 .707 r
F
.23123 .655 m .26264 .64904 L p .25453 .66045 L F P
0 g
s
.23885 .66166 m .23123 .655 L .25453 .66045 L .707 .577 .707 r
F
.23563 .61794 m .26737 .61982 L p .24046 .66154 L F P
0 g
s
.23164 .67522 m .23255 .66215 L p .24046 .66154 L .707 .577 .707 r
F P
0 g
s
.23255 .66215 m .23123 .655 L p .23885 .66166 L .707 .577 .707 r
F P
0 g
s
.26338 .67711 m .23164 .67522 L p .24046 .66154 L .707 .577 .707 r
F P
0 g
s
.23255 .66215 m .23885 .66166 L .24798 .66966 L .707 .577 .707 r
F
.29452 .67993 m .26338 .67711 L p .27436 .66008 L F P
0 g
s
.26264 .64904 m .29366 .64916 L p .28413 .66049 L .707 .577 .707 r
F P
0 g
s
.27265 .66001 m .26264 .64904 L .28413 .66049 L .707 .577 .707 r
F
.32201 .6834 m .29452 .67993 L p .30467 .66259 L F P
0 g
s
.29366 .64916 m .32127 .65534 L p .31325 .66415 L .707 .577 .707 r
F P
0 g
s
.30357 .66239 m .29366 .64916 L .31325 .66415 L .707 .577 .707 r
F
.32322 .66596 m .32201 .6834 L p .30467 .66259 L F P
0 g
s
.32127 .65534 m .32686 .68569 L .29925 .67951 L p .707 .577 .707 r
F P
0 g
s
.326 .62612 m .32322 .66596 L p .30467 .66259 L .707 .577 .707 r
F P
0 g
s
.29851 .62264 m .326 .62612 L p .30467 .66259 L .707 .577 .707 r
F P
0 g
s
.29452 .67993 m .29584 .66098 L p .30467 .66259 L .707 .577 .707 r
F P
0 g
s
.29584 .66098 m .29366 .64916 L p .30357 .66239 L .707 .577 .707 r
F P
0 g
s
.29584 .66098 m .29851 .62264 L p .30467 .66259 L .707 .577 .707 r
F P
0 g
s
.29584 .66098 m .30357 .66239 L .30866 .66918 L .707 .577 .707 r
F
.30866 .66918 m .30357 .66239 L .31325 .66415 L F
.29925 .67951 m .29584 .66098 L p .30866 .66918 L F P
0 g
s
.29584 .66098 m .29452 .67993 L p .27436 .66008 L .707 .577 .707 r
F P
0 g
s
.29366 .64916 m .29925 .67951 L .26823 .6794 L p .707 .577 .707 r
F P
0 g
s
.27436 .66008 m .28022 .65099 L .29584 .66098 L .707 .577 .707 r
F
.29851 .62264 m .29584 .66098 L p .28022 .65099 L F P
0 g
s
.26737 .61982 m .29851 .62264 L p .27436 .66008 L .707 .577 .707 r
F P
0 g
s
.26338 .67711 m .26459 .65967 L p .27436 .66008 L .707 .577 .707 r
F P
0 g
s
.26459 .65967 m .26264 .64904 L p .27265 .66001 L .707 .577 .707 r
F P
0 g
s
.26459 .65967 m .26737 .61982 L p .27436 .66008 L .707 .577 .707 r
F P
0 g
s
.26459 .65967 m .27265 .66001 L .27884 .66678 L .707 .577 .707 r
F
.27884 .66678 m .27265 .66001 L .28413 .66049 L F
.26823 .6794 m .26459 .65967 L p .27884 .66678 L F P
0 g
s
.26459 .65967 m .26338 .67711 L p .24046 .66154 L .707 .577 .707 r
F P
0 g
s
.26264 .64904 m .26823 .6794 L .23682 .68535 L p .707 .577 .707 r
F P
0 g
s
.24046 .66154 m .24726 .65101 L .26459 .65967 L .707 .577 .707 r
F
.26737 .61982 m .26459 .65967 L p .24726 .65101 L F P
0 g
s
.23255 .66215 m .23563 .61794 L p .24046 .66154 L .707 .577 .707 r
F P
0 g
s
.24798 .66966 m .23885 .66166 L .25453 .66045 L .707 .577 .707 r
F
.23682 .68535 m .23255 .66215 L p .24798 .66966 L F P
0 g
s
.23255 .66215 m .23164 .67522 L p .20653 .66744 L .707 .577 .707 r
F P
0 g
s
.23123 .655 m .23682 .68535 L .20811 .6968 L p .707 .577 .707 r
F P
0 g
s
.20653 .66744 m .21473 .65349 L .23255 .66215 L .707 .577 .707 r
F
.23563 .61794 m .23255 .66215 L p .21473 .65349 L F P
0 g
s
.20284 .66819 m .20639 .61716 L p .20653 .66744 L .707 .577 .707 r
F P
0 g
s
.21803 .67886 m .20432 .66789 L .22661 .66336 L .707 .577 .707 r
F
.20811 .6968 m .20284 .66819 L p .21803 .67886 L F P
0 g
s
.20252 .66645 m .20811 .6968 L .1849 .71262 L p .707 .577 .707 r
F P
0 g
s
.17853 .67487 m .1871 .65713 L .20284 .66819 L .707 .577 .707 r
F
.20639 .61716 m .20284 .66819 L p .1871 .65713 L F P
0 g
s
.18498 .67476 m .17853 .67487 L p .20284 .66819 L .707 .577 .707 r
F P
0 g
s
.17931 .68226 m .1849 .71262 L .16946 .73126 L p .707 .577 .707 r
F P
0 g
s
.62025 .25885 m .62571 .75688 L .59598 .74721 L p .707 .577 .707 r
F P
0 g
s
.59598 .74721 m .59052 .24918 L .62025 .25885 L p .707 .577 .707 r
F P
0 g
s
.34317 .77367 m .34158 .7928 L .32039 .78954 L p .707 .577 .707 r
F P
0 g
s
.32039 .78954 m .32198 .77041 L .34317 .77367 L p .707 .577 .707 r
F P
0 g
s
.38738 .25665 m .39284 .75468 L .36974 .76628 L p .707 .577 .707 r
F P
0 g
s
.39284 .75468 m .38738 .25665 L .42133 .24758 L p .707 .577 .707 r
F P
0 g
s
.1771 .77861 m .17868 .75948 L .20247 .7601 L p .707 .577 .707 r
F P
0 g
s
.20247 .7601 m .20088 .77923 L .1771 .77861 L p .707 .577 .707 r
F P
0 g
s
.73131 .64091 m .7353 .58362 L .70416 .5808 L p .707 .577 .707 r
F P
0 g
s
.7353 .58362 m .73131 .64091 L .76305 .6428 L p .707 .577 .707 r
F P
0 g
s
.76305 .6428 m .76704 .58551 L .7353 .58362 L p .707 .577 .707 r
F P
0 g
s
.76704 .58551 m .76305 .6428 L .79228 .64357 L p .707 .577 .707 r
F P
0 g
s
.79228 .64357 m .79627 .58628 L .76704 .58551 L p .707 .577 .707 r
F P
0 g
s
.70416 .5808 m .70017 .63809 L .73131 .64091 L p .707 .577 .707 r
F P
0 g
s
.70017 .63809 m .70416 .5808 L .67666 .57733 L p .707 .577 .707 r
F P
0 g
s
.59052 .24918 m .59598 .74721 L .55721 .74082 L p .707 .577 .707 r
F P
0 g
s
.55721 .74082 m .55176 .24279 L .59052 .24918 L p .707 .577 .707 r
F P
0 g
s
.32198 .77041 m .32039 .78954 L .29288 .78625 L p .707 .577 .707 r
F P
0 g
s
.29288 .78625 m .29447 .76712 L .32198 .77041 L p .707 .577 .707 r
F P
0 g
s
.67666 .57733 m .67268 .63462 L .70017 .63809 L p .707 .577 .707 r
F P
0 g
s
.79627 .58628 m .79228 .64357 L .81615 .64315 L p .707 .577 .707 r
F P
0 g
s
.81615 .64315 m .82014 .58586 L .79627 .58628 L p .707 .577 .707 r
F P
0 g
s
.20088 .77923 m .20247 .7601 L .23164 .7617 L p .707 .577 .707 r
F P
0 g
s
.23164 .7617 m .23006 .78083 L .20088 .77923 L p .707 .577 .707 r
F P
0 g
s
.42679 .74561 m .42133 .24758 L .46281 .24195 L p .707 .577 .707 r
F P
0 g
s
.42133 .24758 m .42595 .66923 L p .39284 .75468 L .707 .577 .707 r
F P
0 g
s
.46281 .24195 m .46827 .73998 L .42679 .74561 L p .707 .577 .707 r
F P
0 g
s
.42403 .54869 m .42004 .60598 L .44813 .60672 L p .707 .577 .707 r
F P
0 g
s
.44813 .60672 m .44927 .60675 L p .44864 .60529 L .707 .577 .707 r
F P
0 g
s
.44864 .60529 m .42403 .54869 L .44813 .60672 L .707 .577 .707 r
F
.42595 .66923 m .4267 .7377 L p .39593 .75385 L F P
0 g
s
.42051 .68796 m .41892 .70709 L .43898 .70819 L p .707 .577 .707 r
F P
0 g
s
.43898 .70819 m .44809 .70869 L p .44099 .70336 L .707 .577 .707 r
F P
0 g
s
.44099 .70336 m .42051 .68796 L .43898 .70819 L .707 .577 .707 r
F
.4267 .7377 m .42679 .74561 L .42299 .74663 L p F P
0 g
s
.42299 .74663 m .39593 .75385 L p .4267 .7377 L .707 .577 .707 r
F P
0 g
s
.39593 .75385 m .39284 .75468 L p .42595 .66923 L .707 .577 .707 r
F P
0 g
s
.67268 .63462 m .67666 .57733 L .65551 .57354 L p .707 .577 .707 r
F P
0 g
s
.29447 .76712 m .29288 .78625 L .26176 .78325 L p .707 .577 .707 r
F P
0 g
s
.26176 .78325 m .26334 .76412 L .29447 .76712 L p .707 .577 .707 r
F P
0 g
s
.65551 .57354 m .65153 .63083 L .67268 .63462 L p .707 .577 .707 r
F P
0 g
s
.73023 .74149 m .73181 .72236 L .70069 .71936 L p .707 .577 .707 r
F P
0 g
s
.73181 .72236 m .73023 .74149 L .76193 .74391 L p .707 .577 .707 r
F P
0 g
s
.76193 .74391 m .76351 .72478 L .73181 .72236 L p .707 .577 .707 r
F P
0 g
s
.70069 .71936 m .6991 .73849 L .73023 .74149 L p .707 .577 .707 r
F P
0 g
s
.23006 .78083 m .23164 .7617 L .26334 .76412 L p .707 .577 .707 r
F P
0 g
s
.26334 .76412 m .26176 .78325 L .23006 .78083 L p .707 .577 .707 r
F P
0 g
s
.76351 .72478 m .76193 .74391 L .7911 .7455 L p .707 .577 .707 r
F P
0 g
s
.7911 .7455 m .79269 .72638 L .76351 .72478 L p .707 .577 .707 r
F P
0 g
s
.55176 .24279 m .55721 .74082 L .51321 .73833 L p .707 .577 .707 r
F P
0 g
s
.51321 .73833 m .50775 .2403 L .55176 .24279 L p .707 .577 .707 r
F P
0 g
s
.6991 .73849 m .70069 .71936 L .67318 .71607 L p .707 .577 .707 r
F P
0 g
s
.74064 .74785 m .73505 .7175 L .70403 .71738 L p .707 .577 .707 r
F P
0 g
s
.73505 .7175 m .74064 .74785 L .77205 .74189 L p .707 .577 .707 r
F P
0 g
s
.77205 .74189 m .76646 .71154 L .73505 .7175 L p .707 .577 .707 r
F P
0 g
s
.79269 .72638 m .7911 .7455 L .81489 .74613 L p .707 .577 .707 r
F P
0 g
s
.81489 .74613 m .81648 .727 L .79269 .72638 L p .707 .577 .707 r
F P
0 g
s
.76646 .71154 m .77205 .74189 L .80076 .73045 L p .707 .577 .707 r
F P
0 g
s
.80076 .73045 m .79517 .70009 L .76646 .71154 L p .707 .577 .707 r
F P
0 g
s
.82014 .58586 m .81615 .64315 L .83232 .64158 L p .707 .577 .707 r
F P
0 g
s
.83232 .64158 m .8363 .58429 L .82014 .58586 L p .707 .577 .707 r
F P
0 g
s
.67318 .71607 m .6716 .73519 L .6991 .73849 L p .707 .577 .707 r
F P
0 g
s
.46827 .73998 m .46281 .24195 L .50775 .2403 L p .707 .577 .707 r
F P
0 g
s
.50775 .2403 m .51321 .73833 L .46827 .73998 L p .707 .577 .707 r
F P
0 g
s
.70962 .74774 m .70403 .71738 L .67642 .7112 L p .707 .577 .707 r
F P
0 g
s
.70403 .71738 m .70962 .74774 L .74064 .74785 L p .707 .577 .707 r
F P
0 g
s
.79517 .70009 m .80076 .73045 L .82397 .71463 L p .707 .577 .707 r
F P
0 g
s
.82397 .71463 m .81838 .68428 L .79517 .70009 L p .707 .577 .707 r
F P
0 g
s
.65153 .63083 m .65551 .57354 L .64278 .56981 L p .707 .577 .707 r
F P
0 g
s
.6716 .73519 m .67318 .71607 L .65199 .71281 L p .707 .577 .707 r
F P
0 g
s
.65199 .71281 m .65041 .73194 L .6716 .73519 L p .707 .577 .707 r
F P
0 g
s
.68201 .74156 m .67642 .7112 L .65494 .69957 L p .707 .577 .707 r
F P
0 g
s
.67642 .7112 m .68201 .74156 L .70962 .74774 L p .707 .577 .707 r
F P
0 g
s
.81838 .68428 m .82397 .71463 L .83941 .69599 L p .707 .577 .707 r
F P
0 g
s
.83941 .69599 m .83382 .66564 L .81838 .68428 L p .707 .577 .707 r
F P
0 g
s
.8363 .58429 m .83232 .64158 L .83919 .63901 L p .707 .577 .707 r
F P
0 g
s
.83919 .63901 m .84318 .58173 L .8363 .58429 L p .707 .577 .707 r
F P
0 g
s
.81648 .727 m .81489 .74613 L .83097 .74571 L p .707 .577 .707 r
F P
0 g
s
.83097 .74571 m .83255 .72658 L .81648 .727 L p .707 .577 .707 r
F P
0 g
s
.66053 .72992 m .65494 .69957 L .64168 .68362 L p .707 .577 .707 r
F P
0 g
s
.65494 .69957 m .66053 .72992 L .68201 .74156 L p .707 .577 .707 r
F P
0 g
s
.63969 .5665 m .63571 .62378 L .63879 .62709 L p .707 .577 .707 r
F P
0 g
s
.83382 .66564 m .83941 .69599 L .84556 .67636 L p .707 .577 .707 r
F P
0 g
s
.84556 .67636 m .83997 .646 L .83382 .66564 L p .707 .577 .707 r
F P
0 g
s
.83255 .72658 m .83097 .74571 L .83776 .7443 L p .707 .577 .707 r
F P
0 g
s
.83776 .7443 m .83934 .72517 L .83255 .72658 L p .707 .577 .707 r
F P
0 g
s
.83847 .63823 m .83611 .6357 L p .83682 .63033 L .707 .577 .707 r
F P
0 g
s
.83657 .62915 m .83623 .62729 L .83724 .63237 L p .708 .578 .707 r
F P
0 g
s
.8401 .57842 m .84318 .58173 L p .83725 .62705 L .707 .577 .707 r
F P
0 g
s
.83611 .6357 m .83657 .62915 L p .83725 .62705 L .707 .577 .707 r
F P
0 g
s
.83657 .62915 m .8401 .57842 L p .83725 .62705 L .707 .577 .707 r
F P
0 g
s
.83611 .6357 m .82337 .63197 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.83623 .62729 m .83657 .62915 L p .83566 .62836 L .707 .577 .707 r
F P
0 g
s
.83657 .62915 m .83611 .6357 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.82297 .61134 m .83623 .62729 L p .83566 .62836 L .707 .577 .707 r
F P
0 g
s
.82337 .63197 m .8243 .6186 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.82856 .6417 m .8243 .6186 L p .83566 .62836 L .707 .577 .707 r
F P
0 g
s
.8243 .6186 m .82297 .61134 L p .83566 .62836 L .707 .577 .707 r
F P
0 g
s
.82736 .57468 m .8401 .57842 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.8243 .6186 m .82736 .57468 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.8401 .57842 m .83657 .62915 L p .82686 .6208 L .707 .577 .707 r
F P
0 g
s
.82856 .6417 m .83566 .62836 L .83657 .62915 L .707 .577 .707 r
F
.83657 .62915 m .84182 .65765 L .83141 .64513 L p F P
0 g
s
.83141 .64513 m .82856 .6417 L p .83657 .62915 L .707 .577 .707 r
F P
0 g
s
.84182 .65765 m .83657 .62915 L p .83997 .646 L .708 .578 .707 r
F P
0 g
s
.83724 .63237 m .83997 .646 L p .83657 .62915 L .708 .578 .707 r
F P
0 g
s
.84318 .58173 m .83919 .63901 L .83847 .63823 L p .707 .577 .707 r
F P
0 g
s
.83682 .63033 m .84318 .58173 L .83847 .63823 L .707 .577 .707 r
F
.64168 .68362 m .64727 .71397 L .66053 .72992 L p F P
0 g
s
.64727 .71397 m .64168 .68362 L .63794 .66491 L p .708 .578 .707 r
F P
0 g
s
.6376 .72903 m .63919 .7099 L .63603 .70763 L p .707 .577 .707 r
F P
0 g
s
.83997 .646 m .84556 .67636 L .84182 .65765 L p .708 .578 .707 r
F P
0 g
s
.63603 .70763 m .63444 .72676 L .6376 .72903 L p .707 .577 .707 r
F P
0 g
s
.63571 .62378 m .63969 .5665 L .64657 .56393 L p .707 .577 .707 r
F P
0 g
s
.64657 .56393 m .64258 .62122 L .63571 .62378 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.83934 .72517 m .83776 .7443 L .8346 .74203 L p .707 .577 .707 r
F P
0 g
s
.8346 .74203 m .83618 .7229 L .83934 .72517 L p .707 .577 .707 r
F P
0 g
s
.63794 .66491 m .64353 .69526 L .64727 .71397 L p .708 .578 .707 r
F P
0 g
s
.64353 .69526 m .63794 .66491 L .64409 .64527 L p .707 .577 .707 r
F P
0 g
s
.3883 .60409 m .39229 .54681 L .36115 .54399 L p .707 .577 .707 r
F P
0 g
s
.39229 .54681 m .3883 .60409 L .42004 .60598 L p .707 .577 .707 r
F P
0 g
s
.42004 .60598 m .42403 .54869 L .39229 .54681 L p .707 .577 .707 r
F P
0 g
s
.44927 .60675 m .45326 .54947 L .42403 .54869 L p .707 .577 .707 r
F P
0 g
s
.63444 .72676 m .63603 .70763 L .64282 .70622 L p .707 .577 .707 r
F P
0 g
s
.36115 .54399 m .35716 .60127 L .3883 .60409 L p .707 .577 .707 r
F P
0 g
s
.64282 .70622 m .64123 .72535 L .63444 .72676 L p .707 .577 .707 r
F P
0 g
s
.64258 .62122 m .64657 .56393 L .66274 .56236 L p .707 .577 .707 r
F P
0 g
s
.35716 .60127 m .36115 .54399 L .33365 .54051 L p .707 .577 .707 r
F P
0 g
s
.66274 .56236 m .65875 .61965 L .64258 .62122 L p .707 .577 .707 r
F P
0 g
s
.33365 .54051 m .32967 .5978 L .35716 .60127 L p .707 .577 .707 r
F P
0 g
s
.45326 .54947 m .44927 .60675 L .47314 .60633 L p .707 .577 .707 r
F P
0 g
s
.47314 .60633 m .47713 .54905 L .45326 .54947 L p .707 .577 .707 r
F P
0 g
s
.64409 .64527 m .64968 .67563 L .64353 .69526 L p .707 .577 .707 r
F P
0 g
s
.64968 .67563 m .64409 .64527 L .65952 .62664 L p .707 .577 .707 r
F P
0 g
s
.32967 .5978 m .33365 .54051 L .3125 .53672 L p .707 .577 .707 r
F P
0 g
s
.82337 .63197 m .80222 .62818 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.82297 .61134 m .8243 .6186 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.8243 .6186 m .82337 .63197 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.80148 .59971 m .82297 .61134 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.80222 .62818 m .80346 .61044 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.80707 .63006 m .80346 .61044 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.80346 .61044 m .80148 .59971 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.80621 .5709 m .82736 .57468 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.80346 .61044 m .80621 .5709 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.82736 .57468 m .8243 .6186 L p .80946 .61279 L .707 .577 .707 r
F P
0 g
s
.82856 .6417 m .80707 .63006 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.8243 .6186 m .82856 .6417 L p .81867 .6164 L .707 .577 .707 r
F P
0 g
s
.83618 .7229 m .8346 .74203 L .82179 .73913 L p .707 .577 .707 r
F P
0 g
s
.82179 .73913 m .82338 .72 L .83618 .7229 L p .707 .577 .707 r
F P
0 g
s
.3125 .53672 m .30852 .59401 L .32967 .5978 L p .707 .577 .707 r
F P
0 g
s
.38722 .70467 m .3888 .68554 L .35768 .68254 L p .707 .577 .707 r
F P
0 g
s
.3888 .68554 m .38722 .70467 L .41892 .70709 L p .707 .577 .707 r
F P
0 g
s
.41892 .70709 m .42051 .68796 L .3888 .68554 L p .707 .577 .707 r
F P
0 g
s
.35768 .68254 m .35609 .70167 L .38722 .70467 L p .707 .577 .707 r
F P
0 g
s
.44809 .70869 m .44968 .68956 L .42051 .68796 L p .707 .577 .707 r
F P
0 g
s
.65875 .61965 m .66274 .56236 L .68661 .56194 L p .707 .577 .707 r
F P
0 g
s
.64123 .72535 m .64282 .70622 L .6589 .70581 L p .707 .577 .707 r
F P
0 g
s
.35609 .70167 m .35768 .68254 L .33017 .67925 L p .707 .577 .707 r
F P
0 g
s
.39763 .71104 m .39204 .68068 L .36102 .68057 L p .707 .577 .707 r
F P
0 g
s
.39204 .68068 m .39763 .71104 L .42904 .70508 L p .707 .577 .707 r
F P
0 g
s
.42904 .70508 m .42345 .67472 L .39204 .68068 L p .707 .577 .707 r
F P
0 g
s
.44968 .68956 m .44809 .70869 L .47188 .70931 L p .707 .577 .707 r
F P
0 g
s
.47188 .70931 m .47347 .69018 L .44968 .68956 L p .707 .577 .707 r
F P
0 g
s
.42345 .67472 m .42904 .70508 L .45775 .69363 L p .707 .577 .707 r
F P
0 g
s
.45775 .69363 m .45216 .66328 L .42345 .67472 L p .707 .577 .707 r
F P
0 g
s
.6589 .70581 m .65731 .72493 L .64123 .72535 L p .707 .577 .707 r
F P
0 g
s
.47713 .54905 m .47314 .60633 L .48931 .60476 L p .707 .577 .707 r
F P
0 g
s
.48931 .60476 m .49329 .54748 L .47713 .54905 L p .707 .577 .707 r
F P
0 g
s
.33017 .67925 m .32859 .69838 L .35609 .70167 L p .707 .577 .707 r
F P
0 g
s
.68307 .61267 m .68262 .61923 L .66437 .61955 L p .707 .577 .707 r
F P
0 g
s
.66511 .65699 m .65952 .62664 L .67643 .61511 L p .707 .577 .707 r
F P
0 g
s
.67643 .61511 m .68273 .61082 L p .68186 .61312 L .707 .577 .707 r
F P
0 g
s
.66511 .65699 m .67643 .61511 L .68186 .61312 L .707 .577 .707 r
F
.68273 .61082 m .71145 .59937 L p .70675 .60786 L F P
0 g
s
.68463 .61235 m .68273 .61082 L .70675 .60786 L .707 .577 .707 r
F
.68661 .56194 m .71584 .56271 L p .68693 .61189 L F P
0 g
s
.68262 .61923 m .68307 .61267 L p .68693 .61189 L .707 .577 .707 r
F P
0 g
s
.68307 .61267 m .68273 .61082 L p .68463 .61235 L .707 .577 .707 r
F P
0 g
s
.71185 .62 m .68262 .61923 L p .68693 .61189 L .707 .577 .707 r
F P
0 g
s
.68307 .61267 m .68463 .61235 L .69821 .6233 L .707 .577 .707 r
F
.71145 .59937 m .74285 .59342 L p .73466 .60494 L F P
0 g
s
.71912 .60614 m .71145 .59937 L .73466 .60494 L .707 .577 .707 r
F
.71584 .56271 m .74758 .5646 L p .72088 .60601 L F P
0 g
s
.71185 .62 m .71278 .60663 L p .72088 .60601 L .707 .577 .707 r
F P
0 g
s
.71278 .60663 m .71145 .59937 L p .71912 .60614 L .707 .577 .707 r
F P
0 g
s
.74359 .62189 m .71185 .62 L p .72088 .60601 L .707 .577 .707 r
F P
0 g
s
.71278 .60663 m .71912 .60614 L .72814 .6141 L .707 .577 .707 r
F
.77473 .62471 m .74359 .62189 L p .75476 .60457 L F P
0 g
s
.74285 .59342 m .77388 .59353 L p .76426 .60497 L .707 .577 .707 r
F P
0 g
s
.75289 .60449 m .74285 .59342 L .76426 .60497 L .707 .577 .707 r
F
.80222 .62818 m .77473 .62471 L p .78504 .60709 L F P
0 g
s
.77388 .59353 m .80148 .59971 L p .79338 .60861 L .707 .577 .707 r
F P
0 g
s
.7838 .60687 m .77388 .59353 L .79338 .60861 L .707 .577 .707 r
F
.80346 .61044 m .80222 .62818 L p .78504 .60709 L F P
0 g
s
.80148 .59971 m .80707 .63006 L .77946 .62389 L p .707 .577 .707 r
F P
0 g
s
.80621 .5709 m .80346 .61044 L p .78504 .60709 L .707 .577 .707 r
F P
0 g
s
.77872 .56742 m .80621 .5709 L p .78504 .60709 L .707 .577 .707 r
F P
0 g
s
.77473 .62471 m .77607 .60546 L p .78504 .60709 L .707 .577 .707 r
F P
0 g
s
.77607 .60546 m .77388 .59353 L p .7838 .60687 L .707 .577 .707 r
F P
0 g
s
.77607 .60546 m .77872 .56742 L p .78504 .60709 L .707 .577 .707 r
F P
0 g
s
.77607 .60546 m .7838 .60687 L .78882 .61361 L .707 .577 .707 r
F
.78882 .61361 m .7838 .60687 L .79338 .60861 L F
.77946 .62389 m .77607 .60546 L p .78882 .61361 L F P
0 g
s
.77607 .60546 m .77473 .62471 L p .75476 .60457 L .707 .577 .707 r
F P
0 g
s
.77388 .59353 m .77946 .62389 L .74844 .62377 L p .707 .577 .707 r
F P
0 g
s
.75476 .60457 m .76058 .59555 L .77607 .60546 L .707 .577 .707 r
F
.77872 .56742 m .77607 .60546 L p .76058 .59555 L F P
0 g
s
.74758 .5646 m .77872 .56742 L p .75476 .60457 L .707 .577 .707 r
F P
0 g
s
.74359 .62189 m .74483 .60415 L p .75476 .60457 L .707 .577 .707 r
F P
0 g
s
.74483 .60415 m .74285 .59342 L p .75289 .60449 L .707 .577 .707 r
F P
0 g
s
.74483 .60415 m .74758 .5646 L p .75476 .60457 L .707 .577 .707 r
F P
0 g
s
.74483 .60415 m .75289 .60449 L .75899 .61123 L .707 .577 .707 r
F
.75899 .61123 m .75289 .60449 L .76426 .60497 L F
.74844 .62377 m .74483 .60415 L p .75899 .61123 L F P
0 g
s
.74483 .60415 m .74359 .62189 L p .72088 .60601 L .707 .577 .707 r
F P
0 g
s
.74285 .59342 m .74844 .62377 L .71703 .62973 L p .707 .577 .707 r
F P
0 g
s
.72088 .60601 m .72762 .59555 L .74483 .60415 L .707 .577 .707 r
F
.74758 .5646 m .74483 .60415 L p .72762 .59555 L F P
0 g
s
.71278 .60663 m .71584 .56271 L p .72088 .60601 L .707 .577 .707 r
F P
0 g
s
.72814 .6141 m .71912 .60614 L .73466 .60494 L .707 .577 .707 r
F
.71703 .62973 m .71278 .60663 L p .72814 .6141 L F P
0 g
s
.71278 .60663 m .71185 .62 L p .68693 .61189 L .707 .577 .707 r
F P
0 g
s
.71145 .59937 m .71703 .62973 L .68832 .64117 L p .707 .577 .707 r
F P
0 g
s
.68693 .61189 m .69508 .59803 L .71278 .60663 L .707 .577 .707 r
F
.71584 .56271 m .71278 .60663 L p .69508 .59803 L F P
0 g
s
.68307 .61267 m .68661 .56194 L p .68693 .61189 L .707 .577 .707 r
F P
0 g
s
.69821 .6233 m .68463 .61235 L .70675 .60786 L .707 .577 .707 r
F
.68832 .64117 m .68307 .61267 L p .69821 .6233 L F P
0 g
s
.68273 .61082 m .68832 .64117 L .66511 .65699 L p .707 .577 .707 r
F P
0 g
s
.65875 .61965 m .66742 .60168 L .68307 .61267 L .707 .577 .707 r
F
.68661 .56194 m .68307 .61267 L p .66742 .60168 L F P
0 g
s
.66437 .61955 m .65875 .61965 L p .68307 .61267 L .707 .577 .707 r
F P
0 g
s
.65952 .62664 m .66511 .65699 L .64968 .67563 L p .707 .577 .707 r
F P
0 g
s
.36661 .71092 m .36102 .68057 L .33341 .67439 L p .707 .577 .707 r
F P
0 g
s
.36102 .68057 m .36661 .71092 L .39763 .71104 L p .707 .577 .707 r
F P
0 g
s
.45216 .66328 m .45775 .69363 L .48096 .67781 L p .707 .577 .707 r
F P
0 g
s
.48096 .67781 m .47537 .64746 L .45216 .66328 L p .707 .577 .707 r
F P
0 g
s
.30852 .59401 m .3125 .53672 L .29977 .53299 L p .707 .577 .707 r
F P
0 g
s
.29977 .53299 m .29578 .59028 L .30852 .59401 L p .707 .577 .707 r
F P
0 g
s
.32859 .69838 m .33017 .67925 L .30898 .67599 L p .707 .577 .707 r
F P
0 g
s
.30898 .67599 m .3074 .69512 L .32859 .69838 L p .707 .577 .707 r
F P
0 g
s
.82338 .72 m .82179 .73913 L .8006 .73587 L p .707 .577 .707 r
F P
0 g
s
.8006 .73587 m .80219 .71674 L .82338 .72 L p .707 .577 .707 r
F P
0 g
s
.339 .70474 m .33341 .67439 L .31193 .66275 L p .707 .577 .707 r
F P
0 g
s
.33341 .67439 m .339 .70474 L .36661 .71092 L p .707 .577 .707 r
F P
0 g
s
.47537 .64746 m .48096 .67781 L .4964 .65918 L p .707 .577 .707 r
F P
0 g
s
.4964 .65918 m .49081 .62882 L .47537 .64746 L p .707 .577 .707 r
F P
0 g
s
.65731 .72493 m .6589 .70581 L .68269 .70643 L p .707 .577 .707 r
F P
0 g
s
.68269 .70643 m .6811 .72556 L .65731 .72493 L p .707 .577 .707 r
F P
0 g
s
.49329 .54748 m .48931 .60476 L .49618 .6022 L p .707 .577 .707 r
F P
0 g
s
.49618 .6022 m .50017 .54491 L .49329 .54748 L p .707 .577 .707 r
F P
0 g
s
.47347 .69018 m .47188 .70931 L .48796 .7089 L p .707 .577 .707 r
F P
0 g
s
.48796 .7089 m .48954 .68977 L .47347 .69018 L p .707 .577 .707 r
F P
0 g
s
.29578 .59028 m .29977 .53299 L .29668 .52968 L p .707 .577 .707 r
F P
0 g
s
.3074 .69512 m .30898 .67599 L .29618 .67309 L p .707 .577 .707 r
F P
0 g
s
.29618 .67309 m .29459 .69221 L .3074 .69512 L p .707 .577 .707 r
F P
0 g
s
.80219 .71674 m .8006 .73587 L .7731 .73258 L p .707 .577 .707 r
F P
0 g
s
.7731 .73258 m .77469 .71345 L .80219 .71674 L p .707 .577 .707 r
F P
0 g
s
.31752 .69311 m .31193 .66275 L .29867 .6468 L p .707 .577 .707 r
F P
0 g
s
.31193 .66275 m .31752 .69311 L .339 .70474 L p .707 .577 .707 r
F P
0 g
s
.29668 .52968 m .2927 .58697 L .29578 .59028 L p .707 .577 .707 r
F P
0 g
s
.49081 .62882 m .4964 .65918 L .50255 .63954 L p .707 .577 .707 r
F P
0 g
s
.50255 .63954 m .49696 .60919 L .49081 .62882 L p .707 .577 .707 r
F P
0 g
s
.6811 .72556 m .68269 .70643 L .71186 .70803 L p .707 .577 .707 r
F P
0 g
s
.71186 .70803 m .71027 .72716 L .6811 .72556 L p .707 .577 .707 r
F P
0 g
s
.77469 .71345 m .7731 .73258 L .74197 .72958 L p .707 .577 .707 r
F P
0 g
s
.74197 .72958 m .74356 .71045 L .77469 .71345 L p .707 .577 .707 r
F P
0 g
s
.48954 .68977 m .48796 .7089 L .49475 .70749 L p .707 .577 .707 r
F P
0 g
s
.49475 .70749 m .49633 .68836 L .48954 .68977 L p .707 .577 .707 r
F P
0 g
s
.49546 .60142 m .4931 .59889 L p .49381 .59351 L .707 .577 .707 r
F P
0 g
s
.49356 .59233 m .49322 .59048 L .49423 .59556 L p .708 .578 .707 r
F P
0 g
s
.49709 .5416 m .50017 .54491 L p .49424 .59023 L .707 .577 .707 r
F P
0 g
s
.4931 .59889 m .49356 .59233 L p .49424 .59023 L .707 .577 .707 r
F P
0 g
s
.49356 .59233 m .49709 .5416 L p .49424 .59023 L .707 .577 .707 r
F P
0 g
s
.4931 .59889 m .48036 .59515 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.49322 .59048 m .49356 .59233 L p .49265 .59155 L .707 .577 .707 r
F P
0 g
s
.49356 .59233 m .4931 .59889 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.47996 .57453 m .49322 .59048 L p .49265 .59155 L .707 .577 .707 r
F P
0 g
s
.48036 .59515 m .48129 .58179 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.48555 .60488 m .48129 .58179 L p .49265 .59155 L .707 .577 .707 r
F P
0 g
s
.48129 .58179 m .47996 .57453 L p .49265 .59155 L .707 .577 .707 r
F P
0 g
s
.48435 .53787 m .49709 .5416 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.48129 .58179 m .48435 .53787 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.49709 .5416 m .49356 .59233 L p .48385 .58399 L .707 .577 .707 r
F P
0 g
s
.48555 .60488 m .49265 .59155 L .49356 .59233 L .707 .577 .707 r
F
.49356 .59233 m .49881 .62083 L .4884 .60831 L p F P
0 g
s
.4884 .60831 m .48555 .60488 L p .49356 .59233 L .707 .577 .707 r
F P
0 g
s
.49881 .62083 m .49356 .59233 L p .49696 .60919 L .708 .578 .707 r
F P
0 g
s
.49423 .59556 m .49696 .60919 L p .49356 .59233 L .708 .578 .707 r
F P
0 g
s
.50017 .54491 m .49618 .6022 L .49546 .60142 L p .707 .577 .707 r
F P
0 g
s
.49381 .59351 m .50017 .54491 L .49546 .60142 L .707 .577 .707 r
F
.71027 .72716 m .71186 .70803 L .74356 .71045 L p F P
0 g
s
.74356 .71045 m .74197 .72958 L .71027 .72716 L p .707 .577 .707 r
F P
0 g
s
.29867 .6468 m .30425 .67716 L .31752 .69311 L p .707 .577 .707 r
F P
0 g
s
.30425 .67716 m .29867 .6468 L .29493 .62809 L p .708 .578 .707 r
F P
0 g
s
.29459 .69221 m .29618 .67309 L .29302 .67082 L p .707 .577 .707 r
F P
0 g
s
.49696 .60919 m .50255 .63954 L .49881 .62083 L p .708 .578 .707 r
F P
0 g
s
.29302 .67082 m .29143 .68994 L .29459 .69221 L p .707 .577 .707 r
F P
0 g
s
.2927 .58697 m .29668 .52968 L .30356 .52711 L p .707 .577 .707 r
F P
0 g
s
.30356 .52711 m .29957 .5844 L .2927 .58697 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49633 .68836 m .49475 .70749 L .49159 .70522 L p .707 .577 .707 r
F P
0 g
s
.49159 .70522 m .49317 .68609 L .49633 .68836 L p .707 .577 .707 r
F P
0 g
s
.29493 .62809 m .30052 .65845 L .30425 .67716 L p .708 .578 .707 r
F P
0 g
s
.30052 .65845 m .29493 .62809 L .30108 .60846 L p .707 .577 .707 r
F P
0 g
s
.29143 .68994 m .29302 .67082 L .29981 .6694 L p .707 .577 .707 r
F P
0 g
s
.29981 .6694 m .29822 .68853 L .29143 .68994 L p .707 .577 .707 r
F P
0 g
s
.29957 .5844 m .30356 .52711 L .31973 .52554 L p .707 .577 .707 r
F P
0 g
s
.31973 .52554 m .31574 .58283 L .29957 .5844 L p .707 .577 .707 r
F P
0 g
s
.30108 .60846 m .30666 .63881 L .30052 .65845 L p .707 .577 .707 r
F P
0 g
s
.30666 .63881 m .30108 .60846 L .31651 .58982 L p .707 .577 .707 r
F P
0 g
s
.48036 .59515 m .45921 .59137 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.47996 .57453 m .48129 .58179 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.48129 .58179 m .48036 .59515 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.45847 .56289 m .47996 .57453 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.45921 .59137 m .46045 .57363 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.46406 .59325 m .46045 .57363 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.46045 .57363 m .45847 .56289 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.4632 .53408 m .48435 .53787 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.46045 .57363 m .4632 .53408 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.48435 .53787 m .48129 .58179 L p .46645 .57598 L .707 .577 .707 r
F P
0 g
s
.48555 .60488 m .46406 .59325 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.48129 .58179 m .48555 .60488 L p .47566 .57958 L .707 .577 .707 r
F P
0 g
s
.49317 .68609 m .49159 .70522 L .47878 .70231 L p .707 .577 .707 r
F P
0 g
s
.47878 .70231 m .48037 .68318 L .49317 .68609 L p .707 .577 .707 r
F P
0 g
s
.31574 .58283 m .31973 .52554 L .34359 .52513 L p .707 .577 .707 r
F P
0 g
s
.29822 .68853 m .29981 .6694 L .31589 .66899 L p .707 .577 .707 r
F P
0 g
s
.31589 .66899 m .3143 .68812 L .29822 .68853 L p .707 .577 .707 r
F P
0 g
s
.34006 .57585 m .33961 .58241 L .32136 .58273 L p .707 .577 .707 r
F P
0 g
s
.3221 .62018 m .31651 .58982 L .33342 .5783 L p .707 .577 .707 r
F P
0 g
s
.33342 .5783 m .33972 .574 L p .33884 .5763 L .707 .577 .707 r
F P
0 g
s
.3221 .62018 m .33342 .5783 L .33884 .5763 L .707 .577 .707 r
F
.33972 .574 m .36844 .56256 L p .36374 .57104 L F P
0 g
s
.34162 .57554 m .33972 .574 L .36374 .57104 L .707 .577 .707 r
F
.34359 .52513 m .37283 .5259 L p .34392 .57507 L F P
0 g
s
.33961 .58241 m .34006 .57585 L p .34392 .57507 L .707 .577 .707 r
F P
0 g
s
.34006 .57585 m .33972 .574 L p .34162 .57554 L .707 .577 .707 r
F P
0 g
s
.36884 .58319 m .33961 .58241 L p .34392 .57507 L .707 .577 .707 r
F P
0 g
s
.34006 .57585 m .34162 .57554 L .3552 .58649 L .707 .577 .707 r
F
.36844 .56256 m .39984 .5566 L p .39165 .56812 L F P
0 g
s
.37611 .56933 m .36844 .56256 L .39165 .56812 L .707 .577 .707 r
F
.37283 .5259 m .40457 .52779 L p .37787 .56919 L F P
0 g
s
.36884 .58319 m .36977 .56982 L p .37787 .56919 L .707 .577 .707 r
F P
0 g
s
.36977 .56982 m .36844 .56256 L p .37611 .56933 L .707 .577 .707 r
F P
0 g
s
.40058 .58507 m .36884 .58319 L p .37787 .56919 L .707 .577 .707 r
F P
0 g
s
.36977 .56982 m .37611 .56933 L .38513 .57729 L .707 .577 .707 r
F
.43172 .58789 m .40058 .58507 L p .41175 .56775 L F P
0 g
s
.39984 .5566 m .43087 .55672 L p .42125 .56815 L .707 .577 .707 r
F P
0 g
s
.40988 .56767 m .39984 .5566 L .42125 .56815 L .707 .577 .707 r
F
.45921 .59137 m .43172 .58789 L p .44203 .57028 L F P
0 g
s
.43087 .55672 m .45847 .56289 L p .45036 .57179 L .707 .577 .707 r
F P
0 g
s
.44079 .57005 m .43087 .55672 L .45036 .57179 L .707 .577 .707 r
F
.46045 .57363 m .45921 .59137 L p .44203 .57028 L F P
0 g
s
.45847 .56289 m .46406 .59325 L .43645 .58707 L p .707 .577 .707 r
F P
0 g
s
.4632 .53408 m .46045 .57363 L p .44203 .57028 L .707 .577 .707 r
F P
0 g
s
.43571 .53061 m .4632 .53408 L p .44203 .57028 L .707 .577 .707 r
F P
0 g
s
.43172 .58789 m .43306 .56865 L p .44203 .57028 L .707 .577 .707 r
F P
0 g
s
.43306 .56865 m .43087 .55672 L p .44079 .57005 L .707 .577 .707 r
F P
0 g
s
.43306 .56865 m .43571 .53061 L p .44203 .57028 L .707 .577 .707 r
F P
0 g
s
.43306 .56865 m .44079 .57005 L .44581 .5768 L .707 .577 .707 r
F
.44581 .5768 m .44079 .57005 L .45036 .57179 L F
.43645 .58707 m .43306 .56865 L p .44581 .5768 L F P
0 g
s
.43306 .56865 m .43172 .58789 L p .41175 .56775 L .707 .577 .707 r
F P
0 g
s
.43087 .55672 m .43645 .58707 L .40543 .58695 L p .707 .577 .707 r
F P
0 g
s
.41175 .56775 m .41757 .55874 L .43306 .56865 L .707 .577 .707 r
F
.43571 .53061 m .43306 .56865 L p .41757 .55874 L F P
0 g
s
.40457 .52779 m .43571 .53061 L p .41175 .56775 L .707 .577 .707 r
F P
0 g
s
.40058 .58507 m .40182 .56734 L p .41175 .56775 L .707 .577 .707 r
F P
0 g
s
.40182 .56734 m .39984 .5566 L p .40988 .56767 L .707 .577 .707 r
F P
0 g
s
.40182 .56734 m .40457 .52779 L p .41175 .56775 L .707 .577 .707 r
F P
0 g
s
.40182 .56734 m .40988 .56767 L .41598 .57441 L .707 .577 .707 r
F
.41598 .57441 m .40988 .56767 L .42125 .56815 L F
.40543 .58695 m .40182 .56734 L p .41598 .57441 L F P
0 g
s
.40182 .56734 m .40058 .58507 L p .37787 .56919 L .707 .577 .707 r
F P
0 g
s
.39984 .5566 m .40543 .58695 L .37402 .59291 L p .707 .577 .707 r
F P
0 g
s
.37787 .56919 m .38461 .55874 L .40182 .56734 L .707 .577 .707 r
F
.40457 .52779 m .40182 .56734 L p .38461 .55874 L F P
0 g
s
.36977 .56982 m .37283 .5259 L p .37787 .56919 L .707 .577 .707 r
F P
0 g
s
.38513 .57729 m .37611 .56933 L .39165 .56812 L .707 .577 .707 r
F
.37402 .59291 m .36977 .56982 L p .38513 .57729 L F P
0 g
s
.36977 .56982 m .36884 .58319 L p .34392 .57507 L .707 .577 .707 r
F P
0 g
s
.36844 .56256 m .37402 .59291 L .34531 .60436 L p .707 .577 .707 r
F P
0 g
s
.34392 .57507 m .35207 .56121 L .36977 .56982 L .707 .577 .707 r
F
.37283 .5259 m .36977 .56982 L p .35207 .56121 L F P
0 g
s
.34006 .57585 m .34359 .52513 L p .34392 .57507 L .707 .577 .707 r
F P
0 g
s
.3552 .58649 m .34162 .57554 L .36374 .57104 L .707 .577 .707 r
F
.34531 .60436 m .34006 .57585 L p .3552 .58649 L F P
0 g
s
.33972 .574 m .34531 .60436 L .3221 .62018 L p .707 .577 .707 r
F P
0 g
s
.31574 .58283 m .32441 .56486 L .34006 .57585 L .707 .577 .707 r
F
.34359 .52513 m .34006 .57585 L p .32441 .56486 L F P
0 g
s
.32136 .58273 m .31574 .58283 L p .34006 .57585 L .707 .577 .707 r
F P
0 g
s
.31651 .58982 m .3221 .62018 L .30666 .63881 L p .707 .577 .707 r
F P
0 g
s
.48037 .68318 m .47878 .70231 L .45759 .69905 L p .707 .577 .707 r
F P
0 g
s
.45759 .69905 m .45918 .67992 L .48037 .68318 L p .707 .577 .707 r
F P
0 g
s
.3143 .68812 m .31589 .66899 L .33967 .66961 L p .707 .577 .707 r
F P
0 g
s
.33967 .66961 m .33809 .68874 L .3143 .68812 L p .707 .577 .707 r
F P
0 g
s
.45918 .67992 m .45759 .69905 L .43009 .69576 L p .707 .577 .707 r
F P
0 g
s
.43009 .69576 m .43167 .67663 L .45918 .67992 L p .707 .577 .707 r
F P
0 g
s
.33809 .68874 m .33967 .66961 L .36885 .67121 L p .707 .577 .707 r
F P
0 g
s
.36885 .67121 m .36726 .69034 L .33809 .68874 L p .707 .577 .707 r
F P
0 g
s
.43167 .67663 m .43009 .69576 L .39896 .69276 L p .707 .577 .707 r
F P
0 g
s
.39896 .69276 m .40055 .67363 L .43167 .67663 L p .707 .577 .707 r
F P
0 g
s
.36726 .69034 m .36885 .67121 L .40055 .67363 L p .707 .577 .707 r
F P
0 g
s
.40055 .67363 m .39896 .69276 L .36726 .69034 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0085ooaD008Mo
o`00Ngoo1P000UYF00<005YFFUH02UYF00<005YFFUH00eYF3000Ngoo001fOol50008FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP03FUH7001dOol007=oo`<00003FUH005YF00YJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEP000080075oo`00L7oo0`0015YF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH00UYF0`00
KWoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH2001/Ool006]oo`800003FUH005YF00MJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP8006]oo`00JGoo0P000eYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00@005YF000006Uoo`00Igoo0P001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP0006Qo
o`00IWoo0P001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00
I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH0
00IJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEWoo06Eoo`00I7oo00@005YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EWoo06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo
06Eoo`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eo
o`00I7oo00D005YFFUIJEP0000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF
00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH0
00EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03
001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
06Eoo`00IGoo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@0
05YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP<006Eoo`00IGoo00@005YFFUH000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04
001JEUYFFUH3001UOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`00IGoo
001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEP<006Eoo`00IGoo00@005YFFUH0
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo600000=JEP00FUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001DOol30003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUHA
0005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00=JEP03Ool005YF00IJEP03001JEUYF
00MJEP03001JEUYF00EJEP04001JEUYFFUH7000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Aoo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@000MJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00E7oo00<0
05YF00000eYF00<005YFFUH00UYF00<005YF00001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<0
05YFFUH01EYF00<005YFFUH00eYF0`001EYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP03
0002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol0
05Aoo`03001JEP0000=JEP05001JEUYFFUH00002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001DOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF
0P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001COol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEUYF0P000UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001COol00`00FUH00003FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00
FUIJEP03FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20002Ool=001FOol005=oo`03001JEP0000=JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001J
EUYF009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@0009JEP03001JEUYF00AJEP04001JEUYFFUHB0014Ool005=oo`03001JEP0000=JEP03001JEUYF
00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF
00=JEP07001JEUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00@005YFFUIJEP<000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
009JEPP003aoo`00Dgoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH00002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP04001JEUYFFUH7000eOol0
05=oo`03001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00AJEP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D0031oo`00Dgoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF0P001eYF0P001EYF
00<005YFFUH00eYF00@005YFFUIJEP8000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP07001JEUYFFUH005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH015YF00=ooeYF00001eYF00<005YFFUH00eYF00@005YF000002ioo`00Dgoo00<005YF
00000UYF1P000UYF00<005YFFUH00UYF00D005YFFUIJEP0000UJEP03001JEUYF00IJEP03001JEUYF
00AJEP03001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH01`00FUIJEUYF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00Dgoo
1@000UYF0P001EYF00<005YFFUH01EYF0P001UYF3@001EYF00<005YFFUH00UYF00@005YFFUIJEP80
00=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF000015YF
00<005YFFUH015YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YFFUH00P00;Goo001DOol2000015YF001JEP001eYF00<005YFFUH01UYF
00<005YFFUH010001EYF300000=JEP00FUH015YF00<005YFFUH00P000eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00004FUH00`00FUIJEP03FUH00`00FUIJ
EP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJ
EP02000]Ool005Ioo`@000MJEP03001JEUYF00EJEP@00003FUH005YF00MJEP03001JEUYF00AJEPH0
00EJEP05001JEUYFFUH00003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000
FUIJEUYF0P0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00;Goo001HOol20007FUH00`00FUIJEP03
FUH20005FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH01@00FUIJEUYF
00000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01000FUIJEUYF0P00;Goo001GOol01000FUIJEP001eYF00<005YF00000P001eYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF0P0000=JEP00FUH00UYF00D005YFFUIJ
EP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUIJEP8002eoo`00EWoo00D005YFFUIJEP0000MJEQ4000AJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEP0000800003FUH0000000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00H005YFFUH005YF000]Ool005Ioo`05
001JEUYFFUH00005FUH20003Ool01000FUIJEP001UYF00@005YFFUIJEQH00003FUH005YF008000=J
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00H005YFFUH005YF000]Ool005Eoo`03001JEUYF009JEP03001JEUYF009JEP03001oogoo
00=oo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP08FUH00`00FUIJEP03FUH01000FUIJ
EP000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP03FUH01@00FUIJEP00FUH0;Woo001EOol00`00FUIJEP03FUH01000FUIJEP001Woo00@0
05YFFUH000IJEP03001JEUYF00MJEP03001JEUYF00QJEP03001JEUYF00AJEP03001JEP0000=JEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYF001JEP0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00D005YFFUH005YF02ioo`00<Woo5@003Goo0P001EYF0`001goo00@005YFFUH000IJEP03001J
EUYF00MJEP03001JEUYF00UJEP03001JEUYF00AJEP8000=JEP03001JEUYF00YJEP03001JEUYF00MJ
EP03001JEUYF00IJEP06001JEUYF001JEP0015YF00D005YFFUIJEP00009JEP03001JEUYF00IJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYF001JEP0^
Ool002eoo`D00003FUH005YF00EJEP03001JEUYF00EJEP03001JEUYF009JEPT000Aoo`03001JEP00
00AJEP03001oogoo00Moo`04001JEUYF0006FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP04FUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH00`00FUIJEP06FUH01@00FUIJEP00FUH0
2@000eYF00<005YFFUH01UYF00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YF
FUH00eYF00D005YFFUH005YF02ioo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00=oo`00FUH0
1UYF00<005YFFUH01eYF00@005YFFUIJEP@0009JEP05001JEUYFFUH0000:Ool01000FUIJEP001UYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH00eYF00<005YF00000eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00P000eYF00@005YFFUH000EJEP03001JEUYF
00IJEP03001JEUYF00AJEPd000IJEP03001JEUYF009JEP05001JEUYF001JEP0^Ool002eoo`03001J
EP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP04001J
EUYF0002FUH60006Ool01000FUIJEP001UYF0`001eYF00<005YFFUH02EYF00<005YFFUH00eYF00@0
05YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20002
FUH00`00FUH00007FUH00`00FUIJEP05FUH00`00FUIJEP040006FUH00`00FUIJEP04FUH40002FUH0
0`00FUIJEP02FUH01@00FUIJEP00FUH0;Woo000]Ool00`00FUH00003FUH00`00FUIJEP02FUH00`00
FUH00007FUH00`00FUIJEP07FUH00`00FUIJEP04FUH01000FUIJEP000UYF00@005YFFUH0009JEPD0
0005Ool005YFFUH00005FUH50006FUH00`00FUIJEP09FUH00`00FUIJEP02FUH20002FUH01000FUIJ
EP0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF1P001eYF00<005YFFUH015YF
100000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF00000P001EYF00@005YFFUIJERioo`00;Goo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH015YF
00@005YFFUIJEP8000=JEP03001JEUYF00=JEP04001JEP000002FUH00`00FUIJEP03FUH50006FUH0
0`00FUIJEP09FUH00`00FUIJEP02FUH20002FUH01000FUIJEP0035YF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0000Aoo`00FUH000=JEP05001JEUYFFUH00004FUH20005FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20003FUH01000FUH005YF;Woo000]Ool00`00
FUH00003FUH01@00FUIJEUYF00000UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00@005YFFUH000AJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP03FUH50006FUH00`00
FUIJEP09FUH01@00FUIJEUYF00000UYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000Eoo`00FUIJEP0000IJEP03001JEP0000D000AJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP<00003FUH005YF008002ioo`00;Goo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@0
05YFFUH000AJEP03001JEUYF00=JEP04001JEUYF0003FUH00`00FUIJEP03FUH30007FUH00`00FUIJ
EP09FUH01000FUIJEP000eYF00<005YF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0P001Woo4P0015YF00@005YFFUIJEPL0
009JEP03001oogoo02aoo`00;Goo00<005YF00000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YF00001EYF00<005YFFUH00eYF00@005YFFUH000=JEP03
001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJEP04001JEUYF0003FUH00`00FUH00002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIo
o`02FUH2000JOol80007Ool00`00FUH0000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP0000AJEP03001JEUYF00AJEP04001JEUYF
0003FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUH00004FUH20003FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH01@00FUIJ
EUYF0000;7oo0P00;Woo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUH00004FUH00`00FUIJEP03FUH01@00FUIJEUYF00000eYF
00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF0`001EYF00D005YFFUIJEP0000aJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000EJEP<002eoo`<002eoo`00;7oo00<0
05YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF0`00
15YF00<005YFFUH00eYF00<005YFFUH00UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00MJEP80009JEP03001JEUYF00=JEP05001JEUYFFUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20005FUH00`00Oomoo`0]Ool3000]Ool002aoo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP800003FUH005YF009JEP03
001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP05
FUH20004FUH00`00FUIJEP03FUH01@00FUIJEUYF000035YF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0015YF00<007ooOol0;Woo00<005YF0000;Goo000/Ool00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH01000FUIJ
EP001EYF00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00=JEP80
00IJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00002FUH00`00FUIJEP06000[Ool01000FUIJEP00;Goo000/Ool00`00FUH0
0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20002FUH4
0005FUH01000FUIJEUYF0P000UYF00<005YFFUH00eYF00<005YFFUH01eYF00@005YFFUIJEP800003
FUH005YF00IJEP04001JEUYF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
1@00FUIJEUYF00000UYF00<005YF00000eYF00<005YFFUH01@002goo0`0067oo00@005YFFUH002eo
o`00;7oo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01EYF6P000UYF00<005YFFUH01eYF10000eYF00<005YFFUH01EYF00<005YF00001UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D005YFFUIJEP00009JEP03001JEP0000=JEP03
001JEUYF00=JEP04001JEP000008Ool5000FOol20003FUH00`00Oomoo`0ZOol002aoo`03001JEP00
009JEPH0009JEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEP0000=JEP03
001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF009JEPd000MJEP03001JEUYF00AJEP8000MJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH20004FUH00`00
FUIJEP03FUH00`00FUIJEP020007Ool5000EOol00`00FUH00003FUH00`00Oomoo`0ZOol002aoo`03
001JEP00008000=JEP8000AJEP03001JEUYF00EJEP8000QJEP03001JEUYF00AJEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF009JEPP000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001J
EUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUIJEP020007Ool5000EOol01000
FUIJEP000UYF00<007ooOol0:Woo000/Ool20002FUH01000FUIJEP001UYF00<005YFFUH01UYF00<0
05YFFUH00UYF2`0000=JEP00FUH00eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00@005YFFUIJEPL0009JEP03001JEUYF00MJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00
FUIJEP020008Ool3000EOol01@00FUIJEUYF00000UYF00<007ooOol0:Woo000]Ool2000015YF001J
EP001eYF00<005YFFUH01UYF1@0025YF00D005YF001JEP0000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00D000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJ
EP03001JEUYF008001moo`03001JEUYF009JEP03001JEP0002eoo`00;goo10001eYF00<005YFFUH0
15YF0P0015YF00<005YFFUH01UYF00@005YF001JEQ0000AJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP0000<000=JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000AJEP03001JEUYF00AJEP03001JEUYF008001io
o`8000AJEP03001JEP0002eoo`00<7oo00<005YF000025YF00@005YFFUIJEP8000IJEP03001JEUYF
00IJEP03001JEP000080009JEP04001JEP000004FUH00`00FUIJEP02FUH90004FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P000eYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF00@005YF
FUIJEP8001eoo`03001JEP0000EJEP03001oogoo02aoo`00<7oo00@005YFFUH000MJEP03001JEP00
00h000AJEP03001JEUYF009JEPH000AJEP03001JEUYF00EJEP03001JEUYF00=JEQ4000AJEP03001J
EUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH01000FUIJEP000eYF00<005YFFUH00eYF00@005YFFUIJEP8001]oo`8000=JEP03
001JEUYF009JEP03001oogoo02aoo`00;goo00D005YFFUIJEP0000MJEP8000mooa4000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF009JEPL000=JEP03001JEUYF0080
00AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYF
FUH00002FUH00`00FUIJEP03FUH01P00FUIJEP00FUH001Yoo`03001JEUYF00=JEP05001JEUYFFUH0
000_Ool002ioo`03001JEUYF009JEP03001JEUYF00=JEP80029oo`800003FUH005YF00EJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEP0000800003FUH005YF00AJEPD00003FUH0000000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP80009JEP@000EJEP05
001JEUYF001JEP0IOol20006FUH01@00FUIJEUYF0000;goo000^Ool00`00FUIJEP02FUH01000FUIJ
EUYF0P009Woo0`001UYF00<005YFFUH01UYF00<005YFFUH015YF0`0015YF00<005YFFUH015YF00@0
05YFFUIJEP<000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EQ400003FUIoogoo01Aoo`<00003FUH005YF00EJEP04001JEUYF000`Ool002eoo`8000EJEP<002]o
o`@0009JEP03001JEUYF00IJEP03001JEUYF01T000AJEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF00<000AJEP03001JEUYF00AJEP04001JEUYFFUH9000<Ool30004FUH0
0`00FUIJEP05FUH2000aOol002eoo`03001JEP0000AJEP03001oogoo02ioo`l000EJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF
001JEP0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH00UYF4@000UYF00<005YFFUH0
1EYF0P00<Goo000/Ool01000FUIJEP000eYF00<007ooOol0;goo0P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUH005YF0003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH01000FUIJEUYF1`000eYF00<007ooOol0<7oo000/Ool01000FUIJEP000UYF
00<007ooOol0;goo00<005YF00000UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YFFUH005YF
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP05000aOol002aoo`04001JEUYF0002FUH00`00Oomoo`0COol3000IOol00`00
FUH00002FUH00`00FUIJEP03FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=J
EP04001JEP00000_Ool002aoo`04001JEUYFFUH2000EOol5000GOol200001EYF001JEUYF00001EYF
00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH06P0015YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH0
15YF00<005YFFUH00P00;Woo000/Ool20002FUH00`00Oomoo`0DOol5000FOol01@00FUH005YF0000
0UYF00<005YFFUH00eYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP800005FUH005YFFUH00005FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH90004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF
0P00;Woo000]Ool01000FUIJEP005Woo1@005Woo00<005YFFUH00P000UYF00<005YFFUH00eYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF1@0000=JEP0000000eYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH00eYF200015YF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00;Goo00<005YF0000
67oo0`005Woo00@005YFFUIJEP80009JEP03001JEUYF00=JEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001J
EP0000L00003FUH005YF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000P000=JEP04
001JEUYFFUH2000^Ool002eoo`03001JEP00031oo`03001JEUYF009JEP80009JEP03001JEUYF00=J
EP03001JEUYF00MJEP03001JEUYF00MJEPX000]JEPT000QJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0000Moo`<000IJEP03001JEUYF00EJEP03001JEUYF00EJEP@000=JEP03001JEUYF00=J
EPD0009JEP8002ioo`00;Goo00<005YF0000;Woo0`0015YF0P000UYF00<005YFFUH00eYF00<005YF
FUH01eYF00@005YFFUIJEPH000UJEP03001JEUYF00YJEP03001JEUYF00EJEPH0009JEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEP0000Yoo`@0009JEP03001JEUYF00IJEP03001JEUYF00l000=J
EP04001JEUYFFUH4000^Ool002eoo`<002aoo`80009JEP03001JEUYF00=JEP04001JEUYF0005FUH0
0`00FUIJEP05FUH60002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUH0
00030006FUH00`00FUIJEP02FUH00`00FUH0000=Ool?000?Ool:000_Ool002ioo`03001JEP0002Uo
o`8000AJEP03001JEUYF00=JEP04001JEUYF0005FUH01000FUIJEUYF100025YF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH00eYF0P0015YF00<005YFFUH00UYF00<005YF
00003Goo00<005YF0000E7oo000^Ool01000FUIJEP009goo00<005YFFUH015YF00<005YFFUH00UYF
0P000UYF00<005YFFUH00eYF100000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01EYF0`0000=JEP00FUH00eYF00<005YF00003Goo00<005YF0000E7oo
000^Ool00`00FUIJEP05000QOol30007FUH01P00FUIJEP00Ool0009JEP04001JEUYFFUH20005FUH0
0`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
1000FUH0000015YF00<005YF00003Goo00<005YF0000E7oo000/Ool500000eYF001JEP02FUH@000?
Ool20002FUH00`00FUIJEP05FUH00`00FUH00002Ool01@00FUIJEP00FUH00P001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00@005YFFUIJ
EP80009JEP03001JEP0000aoo`80009JEP03001oogoo055oo`00;7oo00<005YF00000eYF00<005YF
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF2@0017oo0P001EYF00<005YFFUH015YF00<005YF
00000Woo00<005YFFUH00P0000=JEP00FUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH00eYF0`0000=JEP00Ool02Woo00<0
05YF00000UYF00<007ooOol0DGoo000/Ool00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003FUH00`00FUIJEP04FUH20003Ool00`00FUH00003
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH200000eYF001oo`09Ool01000FUIJEP000UYF00<007oo
Ool0DGoo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH01000FUIJEUYF30000goo0P0015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@0
05YF000000Uoo`05001JEUYFFUH00002FUH00`00Oomoo`1AOol002]oo`03001JEP0000AJEP03001J
EUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEP0000@000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP04001JEP000008Ool0
0`00FUIJEP03FUH2001DOol002]ooa8000AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00=JEP04001JEUYFFUH30004FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH01000
FUH000001goo0P001EYF0P00E7oo000/Ool20002FUH01000FUH0000015YF00<005YFFUH00UYF4P00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP<000AJEP03001JEUYF00EJEP03001J
EUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001J
EUYF00AJEP04001JEP000006Ool00`00FUH00005FUH2001DOol002ioo`H000AJEP03001JEUYF00EJ
EP03001JEUYF00IJEP03001JEUYF00=JEPP000AJEP03001JEUYF00=JEP05001JEUYF001JEP020004
FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00005Ool20003FUH00`00FUIJEP02FUH00`00
Oomoo`1COol003=oo`<0009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF009JEPL000=JEP03001JEUYF00800003Ool005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJ
EP8000Eoo`03001JEUYF00=JEP03001JEUYF009JEP03001oogoo05=oo`00=Woo0P0000=JEP00FUH0
1EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0000=JEP00FUH015YF1@0000EJEP00
001oo`0000AJEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP8000=oo`8000IJEP05001JEUYFFUH0001F
Ool003Qoo`<000IJEP03001JEUYF00IJEP03001JEUYF00AJEP<000AJEP03001JEUYF00AJEP04001J
EUYFFUH30002Ool20002FUH00`00FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP03FUH200001Woo00000000FUH000IJ
EP04001JEUYF001GOol003]oo`@0009JEP03001JEUYF00IJEP03001JEUYF00@000=ooa4000Eoo`<0
00MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00IJEP04001JEUYFFUH50004FUH00`00FUIJEP05FUH00`00FUH0001GOol003moo`h001moo`8000IJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJ
EP03001JEP0000P0009JEP03001JEUYF00EJEP8005Qoo`00KWoo0P0015YF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH015YF10001EYF00@005YFFUIJ
EPL000=JEP03001oogoo05Moo`00L7oo0`0000=JEP00FUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH010002EYF00<005YFFUH01EYF00<005YFFUH01@00F7oo001c
Ool40008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH50003FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUH00002001EOol007Moo`H0009JEP03001JEUYF
00YJEP03001JEUYF00YJEP04001JEUYFFUH:0004FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00
FUIJEP04FUH00`00FUIJEP02001EOol007eoo`T000IJEP03001JEUYF00AJEPX000AJEP03001JEUYF
00=JEPT000AJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2001EOol008Ioo`d00004
Ool000000003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP03FUH?0003FUH01000FUIJ
EUYF0P00EGoo002GOol01000FUIJEP001eYF00<005YFFUH01EYF00<005YFFUH01eYF00@005YFFUIJ
EP8000EJEPD0009JEP8005Eoo`00V7oo0`001eYF00<005YFFUH01EYF00<005YFFUH01eYF00H005YF
000005YF0006FUH01000FUIJEUYF1000EGoo002JOol40004FUH00`00FUIJEP06FUH00`00FUIJEP02
FUHH001EOol009iooa8006eoo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol0
0?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo
7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]67\[InvisibleSpace]"     "\
\[InvisibleSpace]15.548494759603141`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 67, "     ", 15.548494759603141, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59064 .7556 m .6039 .70317 L .57364 .69384 L p .707 .577 .707 r
F P
0 g
s
.6039 .70317 m .59064 .7556 L .61817 .76086 L p .707 .577 .707 r
F P
0 g
s
.62138 .76061 m .62123 .76012 L .61817 .76086 L .707 .577 .707 r
F
.62123 .76012 m .6039 .70317 L .61733 .75745 L F
.62123 .76012 m .61733 .75745 L .61817 .76086 L F
.60875 .77349 m .6219 .76057 L .59029 .763 L F
.63153 .78643 m .6219 .76057 L p .60875 .77349 L F P
0 g
s
.65939 .77476 m .63236 .75893 L .6219 .76057 L .707 .577 .707 r
F
.64838 .75641 m .64352 .73933 L .62272 .76044 L F
.63492 .7091 m .6219 .76057 L p .64352 .73933 L F P
0 g
s
.6219 .76057 m .63153 .78643 L .64904 .7791 L p .707 .577 .707 r
F P
0 g
s
.64904 .7791 m .65939 .77476 L p .6219 .76057 L .707 .577 .707 r
F P
0 g
s
.6219 .76057 m .62166 .76153 L p .62272 .76044 L .707 .577 .707 r
F P
0 g
s
.64352 .73933 m .6219 .76057 L .62272 .76044 L .707 .577 .707 r
F
.63492 .7091 m .6039 .70317 L p .62123 .76012 L F P
0 g
s
.62166 .76153 m .6219 .76057 L p .62123 .76012 L .707 .577 .707 r
F P
0 g
s
.6219 .76057 m .63492 .7091 L p .62123 .76012 L .707 .577 .707 r
F P
0 g
s
.64254 .76489 m .65233 .75579 L .63236 .75893 L .707 .577 .707 r
F
.65939 .77476 m .65233 .75579 L p .64254 .76489 L F P
0 g
s
.65939 .77476 m .68247 .76379 L p .67123 .75612 L .707 .577 .707 r
F P
0 g
s
.67183 .75062 m .66958 .73976 L .65777 .75435 L .707 .577 .707 r
F
.66365 .71104 m .65233 .75579 L p .66958 .73976 L F P
0 g
s
.66958 .73976 m .65233 .75579 L .65777 .75435 L .707 .577 .707 r
F
.66365 .71104 m .63492 .7091 L p .64757 .75356 L F P
0 g
s
.65039 .76347 m .65233 .75579 L p .64757 .75356 L .707 .577 .707 r
F P
0 g
s
.65233 .75579 m .66365 .71104 L p .64757 .75356 L .707 .577 .707 r
F P
0 g
s
.68247 .76379 m .67705 .74924 L p .66559 .75228 L .707 .577 .707 r
F P
0 g
s
.68728 .7088 m .66365 .71104 L p .67101 .74668 L .707 .577 .707 r
F P
0 g
s
.67402 .76123 m .67705 .74924 L p .67101 .74668 L .707 .577 .707 r
F P
0 g
s
.67705 .74924 m .68728 .7088 L p .67101 .74668 L .707 .577 .707 r
F P
0 g
s
.68879 .75217 m .68735 .74448 L .67705 .74924 L .707 .577 .707 r
F
.6985 .75459 m .69086 .74766 L .68879 .75217 L F
.69086 .74766 m .68735 .74448 L .68879 .75217 L F
.67705 .74924 m .68247 .76379 L .69476 .75673 L p F P
0 g
s
.69476 .75673 m .6985 .75459 L p .67705 .74924 L .707 .577 .707 r
F P
0 g
s
.6895 .74348 m .68897 .73515 L .68228 .74682 L .707 .577 .707 r
F
.68728 .7088 m .67705 .74924 L p .68897 .73515 L F P
0 g
s
.68897 .73515 m .67705 .74924 L .68228 .74682 L .707 .577 .707 r
F
.68517 .71878 m .66914 .72798 L p .68735 .74448 L F P
0 g
s
.6985 .75459 m .69365 .74156 L p .68735 .74448 L .707 .577 .707 r
F P
0 g
s
.7035 .70261 m .68728 .7088 L p .68921 .73887 L .707 .577 .707 r
F P
0 g
s
.69024 .75504 m .69365 .74156 L p .68921 .73887 L .707 .577 .707 r
F P
0 g
s
.69365 .74156 m .7035 .70261 L p .68921 .73887 L .707 .577 .707 r
F P
0 g
s
.70035 .7451 m .69784 .73665 L .69365 .74156 L .707 .577 .707 r
F
.70592 .74806 m .70041 .74028 L .70035 .7451 L F
.70041 .74028 m .69784 .73665 L .70035 .7451 L F
.69365 .74156 m .6985 .75459 L .7053 .7486 L p F P
0 g
s
.7053 .7486 m .70592 .74806 L p .69365 .74156 L .707 .577 .707 r
F P
0 g
s
.69889 .7354 m .69996 .7278 L .69606 .73873 L .707 .577 .707 r
F
.7035 .70261 m .69365 .74156 L p .69996 .7278 L F P
0 g
s
.69996 .7278 m .69365 .74156 L .69606 .73873 L .707 .577 .707 r
F
.69259 .71225 m .68517 .71878 L p .69784 .73665 L F P
0 g
s
.70592 .74806 m .70051 .73351 L p .69784 .73665 L .707 .577 .707 r
F P
0 g
s
.71073 .69307 m .7035 .70261 L p .69961 .73033 L .707 .577 .707 r
F P
0 g
s
.69747 .7455 m .70051 .73351 L p .69961 .73033 L .707 .577 .707 r
F P
0 g
s
.70051 .73351 m .71073 .69307 L p .69961 .73033 L .707 .577 .707 r
F P
0 g
s
.70592 .74806 m .704 .74484 L p .7025 .74054 L .707 .577 .707 r
F P
0 g
s
.70051 .73351 m .69259 .71225 L p .69784 .73665 L .707 .577 .707 r
F P
0 g
s
.69748 .7386 m .69747 .7455 L p .69889 .7354 L .707 .577 .707 r
F P
0 g
s
.69747 .7455 m .6965 .74083 L .69024 .75504 L .707 .577 .707 r
F
.69889 .7354 m .69606 .73873 L .69024 .75504 L F
.68517 .71878 m .69365 .74156 L p .69784 .73665 L F P
0 g
s
.69747 .7455 m .69499 .73354 L p .69751 .72709 L .707 .577 .707 r
F P
0 g
s
.69259 .71225 m .70051 .73351 L p .69862 .72947 L .707 .577 .707 r
F P
0 g
s
.69751 .72709 m .69925 .73083 L .69747 .7455 L .707 .577 .707 r
F
.69067 .70903 m .69259 .71225 L p .69862 .72947 L F P
0 g
s
.70051 .73351 m .69747 .7455 L p .69925 .73083 L .707 .577 .707 r
F P
0 g
s
.69694 .72587 m .69067 .70903 L p .69862 .72947 L .707 .577 .707 r
F P
0 g
s
.70825 .68111 m .71073 .69307 L p .69953 .72188 L .707 .577 .707 r
F P
0 g
s
.69499 .73354 m .69694 .72587 L p .69953 .72188 L .707 .577 .707 r
F P
0 g
s
.69694 .72587 m .70825 .68111 L p .69953 .72188 L .707 .577 .707 r
F P
0 g
s
.69365 .74156 m .69024 .75504 L p .69606 .73873 L .707 .577 .707 r
F P
0 g
s
.69365 .74156 m .68517 .71878 L p .68735 .74448 L .707 .577 .707 r
F P
0 g
s
.704 .74484 m .69293 .74525 L p .69217 .73318 L .707 .577 .707 r
F P
0 g
s
.69499 .73354 m .68306 .72034 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.69067 .70903 m .69694 .72587 L p .69156 .72331 L .707 .577 .707 r
F P
0 g
s
.69694 .72587 m .69499 .73354 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.67959 .70944 m .69067 .70903 L p .69156 .72331 L .707 .577 .707 r
F P
0 g
s
.68306 .72034 m .6833 .71939 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.69293 .74525 m .6833 .71939 L p .69156 .72331 L .707 .577 .707 r
F P
0 g
s
.6833 .71939 m .67959 .70944 L p .69156 .72331 L .707 .577 .707 r
F P
0 g
s
.69632 .66791 m .70825 .68111 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.6833 .71939 m .69632 .66791 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.70825 .68111 m .69694 .72587 L p .68358 .71952 L .707 .577 .707 r
F P
0 g
s
.69217 .73318 m .69156 .72331 L .69694 .72587 L .707 .577 .707 r
F
.69694 .72587 m .704 .74484 L p .69217 .73318 L F P
0 g
s
.704 .74484 m .69694 .72587 L p .69862 .72947 L .707 .577 .707 r
F P
0 g
s
.70071 .71885 m .70051 .73351 L .69925 .73083 L .707 .577 .707 r
F
.69751 .72709 m .70071 .71885 L .69925 .73083 L F
.7025 .74054 m .69862 .72947 L .70051 .73351 L F
.70051 .73351 m .70592 .74806 L p .7025 .74054 L F P
0 g
s
.71073 .69307 m .70051 .73351 L p .70071 .71885 L .707 .577 .707 r
F P
0 g
s
.67705 .74924 m .67402 .76123 L p .68228 .74682 L .707 .577 .707 r
F P
0 g
s
.67402 .76123 m .69024 .75504 L p .6895 .74348 L .707 .577 .707 r
F P
0 g
s
.6895 .74348 m .68228 .74682 L .67402 .76123 L .707 .577 .707 r
F
.66914 .72798 m .67705 .74924 L p .68735 .74448 L F P
0 g
s
.66914 .72798 m .64606 .73896 L p .66559 .75228 L .707 .577 .707 r
F P
0 g
s
.67705 .74924 m .66914 .72798 L p .66559 .75228 L .707 .577 .707 r
F P
0 g
s
.65233 .75579 m .65939 .77476 L p .66559 .75228 L .707 .577 .707 r
F P
0 g
s
.65233 .75579 m .65039 .76347 L p .65777 .75435 L .707 .577 .707 r
F P
0 g
s
.67123 .75612 m .66559 .75228 L .66129 .76787 L .707 .577 .707 r
F
.67123 .75612 m .66129 .76787 L .65939 .77476 L F
.64606 .73896 m .65233 .75579 L p .66559 .75228 L F P
0 g
s
.65039 .76347 m .67402 .76123 L p .67183 .75062 L .707 .577 .707 r
F P
0 g
s
.67183 .75062 m .65777 .75435 L .65039 .76347 L .707 .577 .707 r
F
.64606 .73896 m .61819 .75063 L p .63236 .75893 L F P
0 g
s
.65233 .75579 m .64606 .73896 L p .63236 .75893 L .707 .577 .707 r
F P
0 g
s
.61819 .75063 m .6219 .76057 L p .63236 .75893 L .707 .577 .707 r
F P
0 g
s
.62166 .76153 m .65039 .76347 L p .64838 .75641 L .707 .577 .707 r
F P
0 g
s
.64838 .75641 m .62272 .76044 L .62166 .76153 L .707 .577 .707 r
F
.61819 .75063 m .58827 .76185 L p .59029 .763 L F P
0 g
s
.6219 .76057 m .61819 .75063 L p .59029 .763 L .707 .577 .707 r
F P
0 g
s
.61817 .76086 m .62166 .76153 L p .62138 .76061 L .707 .577 .707 r
F P
0 g
s
.56038 .74627 m .57364 .69384 L .5471 .68202 L p .707 .577 .707 r
F P
0 g
s
.57364 .69384 m .56038 .74627 L .59064 .7556 L p .707 .577 .707 r
F P
0 g
s
.53384 .73445 m .5471 .68202 L .52687 .66886 L p .707 .577 .707 r
F P
0 g
s
.5471 .68202 m .53384 .73445 L .56038 .74627 L p .707 .577 .707 r
F P
0 g
s
.60161 .79766 m .58827 .76185 L .55922 .77154 L p .707 .577 .707 r
F P
0 g
s
.58827 .76185 m .60161 .79766 L .63153 .78643 L p .707 .577 .707 r
F P
0 g
s
.55922 .77154 m .57255 .80734 L .60161 .79766 L p .707 .577 .707 r
F P
0 g
s
.57255 .80734 m .55922 .77154 L .53388 .77873 L p .707 .577 .707 r
F P
0 g
s
.53388 .77873 m .54721 .81454 L .57255 .80734 L p .707 .577 .707 r
F P
0 g
s
.52687 .66886 m .51361 .72129 L .53384 .73445 L p .707 .577 .707 r
F P
0 g
s
.51361 .72129 m .52687 .66886 L .51493 .65566 L p .707 .577 .707 r
F P
0 g
s
.58975 .85723 m .59331 .83946 L .56273 .83155 L p .707 .577 .707 r
F P
0 g
s
.59331 .83946 m .58975 .85723 L .62106 .86187 L p .707 .577 .707 r
F P
0 g
s
.62106 .86187 m .62462 .84409 L .59331 .83946 L p .707 .577 .707 r
F P
0 g
s
.62462 .84409 m .62106 .86187 L .65002 .86279 L p .707 .577 .707 r
F P
0 g
s
.65002 .86279 m .65358 .84501 L .62462 .84409 L p .707 .577 .707 r
F P
0 g
s
.55917 .84933 m .56273 .83155 L .53586 .82116 L p .707 .577 .707 r
F P
0 g
s
.56273 .83155 m .55917 .84933 L .58975 .85723 L p .707 .577 .707 r
F P
0 g
s
.54721 .81454 m .53388 .77873 L .51474 .78272 L p .707 .577 .707 r
F P
0 g
s
.53586 .82116 m .5323 .83893 L .55917 .84933 L p .707 .577 .707 r
F P
0 g
s
.5323 .83893 m .53586 .82116 L .51534 .80929 L p .707 .577 .707 r
F P
0 g
s
.51474 .78272 m .52807 .81853 L .54721 .81454 L p .707 .577 .707 r
F P
0 g
s
.51493 .65566 m .50167 .70809 L .51361 .72129 L p .707 .577 .707 r
F P
0 g
s
.65358 .84501 m .65002 .86279 L .6738 .85989 L p .707 .577 .707 r
F P
0 g
s
.6738 .85989 m .67736 .84212 L .65358 .84501 L p .707 .577 .707 r
F P
0 g
s
.50167 .70809 m .51493 .65566 L .51245 .6437 L p .707 .577 .707 r
F P
0 g
s
.51534 .80929 m .51178 .82706 L .5323 .83893 L p .707 .577 .707 r
F P
0 g
s
.52807 .81853 m .51474 .78272 L .50366 .78313 L p .707 .577 .707 r
F P
0 g
s
.51178 .82706 m .51486 .81166 L p .50317 .79711 L .707 .577 .707 r
F P
0 g
s
.51486 .81166 m .51534 .80929 L .513 .80695 L p .707 .577 .707 r
F P
0 g
s
.513 .80695 m .50317 .79711 L p .51486 .81166 L .707 .577 .707 r
F P
0 g
s
.517 .81894 m .50516 .78715 L p .50174 .77992 L .707 .577 .707 r
F P
0 g
s
.50516 .78715 m .50366 .78313 L .50338 .78267 L p .707 .577 .707 r
F P
0 g
s
.50338 .78267 m .50174 .77992 L p .50516 .78715 L .707 .577 .707 r
F P
0 g
s
.50366 .78313 m .517 .81894 L .52807 .81853 L p .707 .577 .707 r
F P
0 g
s
.67736 .84212 m .6738 .85989 L .69008 .85348 L p .707 .577 .707 r
F P
0 g
s
.69008 .85348 m .69364 .8357 L .67736 .84212 L p .707 .577 .707 r
F P
0 g
s
.51245 .6437 m .49919 .69613 L .50167 .70809 L p .707 .577 .707 r
F P
0 g
s
.50317 .79711 m .4996 .81488 L .51178 .82706 L p .707 .577 .707 r
F P
0 g
s
.49919 .69613 m .51245 .6437 L .51968 .63416 L p .707 .577 .707 r
F P
0 g
s
.49516 .82169 m .48813 .3191 L .44412 .31705 L p .707 .577 .707 r
F P
0 g
s
.4996 .81488 m .50317 .79711 L .50054 .78581 L p .707 .577 .707 r
F P
0 g
s
.50174 .77992 m .51507 .81572 L .517 .81894 L p .707 .577 .707 r
F P
0 g
s
.51968 .63416 m .50642 .68659 L .49919 .69613 L p .707 .577 .707 r
F P
0 g
s
.50054 .78581 m .49698 .80358 L .4996 .81488 L p .707 .577 .707 r
F P
0 g
s
.50642 .68659 m .51968 .63416 L .5359 .62797 L p .707 .577 .707 r
F P
0 g
s
.51507 .81572 m .50174 .77992 L .50916 .77339 L p .707 .577 .707 r
F P
0 g
s
.49698 .80358 m .50054 .78581 L .50772 .7765 L p .707 .577 .707 r
F P
0 g
s
.50916 .77339 m .52249 .80919 L .51507 .81572 L p .707 .577 .707 r
F P
0 g
s
.5359 .62797 m .52264 .6804 L .50642 .68659 L p .707 .577 .707 r
F P
0 g
s
.50772 .7765 m .50415 .79427 L .49698 .80358 L p .707 .577 .707 r
F P
0 g
s
.52264 .6804 m .5359 .62797 L .55953 .62573 L p .707 .577 .707 r
F P
0 g
s
.52249 .80919 m .50916 .77339 L .52519 .76418 L p .707 .577 .707 r
F P
0 g
s
.50415 .79427 m .50772 .7765 L .52399 .77008 L p .707 .577 .707 r
F P
0 g
s
.55953 .62573 m .54627 .67816 L .52264 .6804 L p .707 .577 .707 r
F P
0 g
s
.52519 .76418 m .53853 .79999 L .52249 .80919 L p .707 .577 .707 r
F P
0 g
s
.52399 .77008 m .52043 .78785 L .50415 .79427 L p .707 .577 .707 r
F P
0 g
s
.53853 .79999 m .52519 .76418 L .54827 .75321 L p .707 .577 .707 r
F P
0 g
s
.56161 .78902 m .53853 .79999 L p .54765 .75617 L .707 .577 .707 r
F P
0 g
s
.54827 .75321 m .54977 .75723 L p .54765 .75617 L .707 .577 .707 r
F P
0 g
s
.54977 .75723 m .56161 .78902 L p .54765 .75617 L .707 .577 .707 r
F P
0 g
s
.56161 .78902 m .54827 .75321 L .57614 .74154 L p .707 .577 .707 r
F P
0 g
s
.57614 .74154 m .58947 .77734 L .56161 .78902 L p .707 .577 .707 r
F P
0 g
s
.54421 .78496 m .54777 .76719 L .57117 .76793 L p .707 .577 .707 r
F P
0 g
s
.57117 .76793 m .57673 .76811 L p .57417 .76943 L .707 .577 .707 r
F P
0 g
s
.54421 .78496 m .57117 .76793 L .57417 .76943 L .707 .577 .707 r
F
.52043 .78785 m .52399 .77008 L .54777 .76719 L p F P
0 g
s
.54777 .76719 m .54421 .78496 L .52043 .78785 L p .707 .577 .707 r
F P
0 g
s
.48813 .3191 m .49516 .82169 L .5401 .82003 L p .707 .577 .707 r
F P
0 g
s
.5401 .82003 m .53307 .31744 L .48813 .3191 L p .707 .577 .707 r
F P
0 g
s
.54627 .67816 m .55953 .62573 L .58826 .62767 L p .707 .577 .707 r
F P
0 g
s
.58826 .62767 m .575 .6801 L .54627 .67816 L p .707 .577 .707 r
F P
0 g
s
.57673 .76811 m .57317 .78588 L .54421 .78496 L p .707 .577 .707 r
F P
0 g
s
.58947 .77734 m .57614 .74154 L .60606 .73031 L p .707 .577 .707 r
F P
0 g
s
.60606 .73031 m .61939 .76612 L .58947 .77734 L p .707 .577 .707 r
F P
0 g
s
.57317 .78588 m .57673 .76811 L .60804 .77274 L p .707 .577 .707 r
F P
0 g
s
.60804 .77274 m .60448 .79052 L .57317 .78588 L p .707 .577 .707 r
F P
0 g
s
.53307 .31744 m .5401 .82003 L .58157 .81482 L p .707 .577 .707 r
F P
0 g
s
.575 .6801 m .58826 .62767 L .61928 .6336 L p .707 .577 .707 r
F P
0 g
s
.61928 .6336 m .60602 .68603 L .575 .6801 L p .707 .577 .707 r
F P
0 g
s
.58157 .81482 m .57454 .31223 L .53307 .31744 L p .707 .577 .707 r
F P
0 g
s
.69364 .8357 m .69008 .85348 L .69725 .84416 L p .707 .577 .707 r
F P
0 g
s
.69725 .84416 m .70081 .82639 L .69364 .8357 L p .707 .577 .707 r
F P
0 g
s
.45115 .81964 m .44412 .31705 L .40536 .31147 L p .707 .577 .707 r
F P
0 g
s
.44412 .31705 m .45115 .81964 L .49516 .82169 L p .707 .577 .707 r
F P
0 g
s
.61939 .76612 m .60606 .73031 L .63511 .72063 L p .707 .577 .707 r
F P
0 g
s
.63862 .78064 m .63506 .79842 L .60448 .79052 L p .707 .577 .707 r
F P
0 g
s
.60448 .79052 m .60804 .77274 L .63862 .78064 L p .707 .577 .707 r
F P
0 g
s
.57454 .31223 m .58157 .81482 L .61553 .80655 L p .707 .577 .707 r
F P
0 g
s
.64954 .64293 m .63628 .69536 L .60602 .68603 L p .707 .577 .707 r
F P
0 g
s
.60602 .68603 m .61928 .6336 L .64954 .64293 L p .707 .577 .707 r
F P
0 g
s
.61553 .80655 m .6085 .30396 L .57454 .31223 L p .707 .577 .707 r
F P
0 g
s
.24764 .71872 m .2609 .6663 L .23063 .65696 L p .707 .577 .707 r
F P
0 g
s
.2609 .6663 m .24764 .71872 L .27568 .72408 L p .707 .577 .707 r
F P
0 g
s
.27841 .72387 m .27828 .72345 L .27568 .72408 L .707 .577 .707 r
F
.27828 .72345 m .2609 .6663 L .27494 .72117 L F
.27828 .72345 m .27494 .72117 L .27568 .72408 L F
.26566 .73681 m .27885 .72384 L .24713 .72628 L F
.28852 .7498 m .27885 .72384 L p .26566 .73681 L F P
0 g
s
.31638 .73813 m .28922 .72221 L .27885 .72384 L .707 .577 .707 r
F
.30541 .71967 m .30053 .70253 L .27956 .72373 L F
.29191 .67222 m .27885 .72384 L p .30053 .70253 L F P
0 g
s
.27885 .72384 m .28852 .7498 L .3061 .74243 L p .707 .577 .707 r
F P
0 g
s
.3061 .74243 m .31638 .73813 L p .27885 .72384 L .707 .577 .707 r
F P
0 g
s
.27885 .72384 m .27865 .72465 L p .27956 .72373 L .707 .577 .707 r
F P
0 g
s
.30053 .70253 m .27885 .72384 L .27956 .72373 L .707 .577 .707 r
F
.29191 .67222 m .2609 .6663 L p .27828 .72345 L F P
0 g
s
.27865 .72465 m .27885 .72384 L p .27828 .72345 L .707 .577 .707 r
F P
0 g
s
.27885 .72384 m .29191 .67222 L p .27828 .72345 L .707 .577 .707 r
F P
0 g
s
.29944 .7282 m .30928 .71906 L .28922 .72221 L .707 .577 .707 r
F
.31638 .73813 m .30928 .71906 L p .29944 .7282 L F P
0 g
s
.31638 .73813 m .33946 .72715 L p .32815 .71943 L .707 .577 .707 r
F P
0 g
s
.32884 .71387 m .32659 .70297 L .31467 .71763 L .707 .577 .707 r
F
.32064 .67416 m .30928 .71906 L p .32659 .70297 L F P
0 g
s
.32659 .70297 m .30928 .71906 L .31467 .71763 L .707 .577 .707 r
F
.32064 .67416 m .29191 .67222 L p .30461 .71686 L F P
0 g
s
.30738 .72659 m .30928 .71906 L p .30461 .71686 L .707 .577 .707 r
F P
0 g
s
.30928 .71906 m .32064 .67416 L p .30461 .71686 L .707 .577 .707 r
F P
0 g
s
.33946 .72715 m .33401 .7125 L p .32247 .71556 L .707 .577 .707 r
F P
0 g
s
.34427 .67193 m .32064 .67416 L p .32804 .70998 L .707 .577 .707 r
F P
0 g
s
.33101 .72436 m .33401 .7125 L p .32804 .70998 L .707 .577 .707 r
F P
0 g
s
.33401 .7125 m .34427 .67193 L p .32804 .70998 L .707 .577 .707 r
F P
0 g
s
.34573 .71547 m .34425 .70777 L .33401 .7125 L .707 .577 .707 r
F
.3555 .71795 m .34779 .71097 L .34573 .71547 L F
.34779 .71097 m .34425 .70777 L .34573 .71547 L F
.33401 .7125 m .33946 .72715 L .35184 .72005 L p F P
0 g
s
.35184 .72005 m .3555 .71795 L p .33401 .7125 L .707 .577 .707 r
F P
0 g
s
.3465 .70673 m .34597 .69837 L .33922 .71009 L .707 .577 .707 r
F
.34427 .67193 m .33401 .7125 L p .34597 .69837 L F P
0 g
s
.34597 .69837 m .33401 .7125 L .33922 .71009 L .707 .577 .707 r
F
.34216 .68214 m .32613 .69135 L p .34425 .70777 L F P
0 g
s
.3555 .71795 m .35061 .70483 L p .34425 .70777 L .707 .577 .707 r
F P
0 g
s
.3605 .66574 m .34427 .67193 L p .34621 .70217 L .707 .577 .707 r
F P
0 g
s
.34724 .71817 m .35061 .70483 L p .34621 .70217 L .707 .577 .707 r
F P
0 g
s
.35061 .70483 m .3605 .66574 L p .34621 .70217 L .707 .577 .707 r
F P
0 g
s
.3573 .70841 m .35477 .69993 L .35061 .70483 L .707 .577 .707 r
F
.36291 .71142 m .35737 .70359 L .3573 .70841 L F
.35737 .70359 m .35477 .69993 L .3573 .70841 L F
.35061 .70483 m .3555 .71795 L .36234 .71192 L p F P
0 g
s
.36234 .71192 m .36291 .71142 L p .35061 .70483 L .707 .577 .707 r
F P
0 g
s
.35587 .69865 m .35694 .69102 L .35301 .702 L .707 .577 .707 r
F
.3605 .66574 m .35061 .70483 L p .35694 .69102 L F P
0 g
s
.35694 .69102 m .35061 .70483 L .35301 .702 L .707 .577 .707 r
F
.34958 .67561 m .34216 .68214 L p .35477 .69993 L F P
0 g
s
.36291 .71142 m .35746 .69677 L p .35477 .69993 L .707 .577 .707 r
F P
0 g
s
.36772 .65619 m .3605 .66574 L p .35657 .69363 L .707 .577 .707 r
F P
0 g
s
.35446 .70862 m .35746 .69677 L p .35657 .69363 L .707 .577 .707 r
F P
0 g
s
.35746 .69677 m .36772 .65619 L p .35657 .69363 L .707 .577 .707 r
F P
0 g
s
.36291 .71142 m .36099 .7082 L p .35944 .70378 L .707 .577 .707 r
F P
0 g
s
.35746 .69677 m .34958 .67561 L p .35477 .69993 L .707 .577 .707 r
F P
0 g
s
.35446 .70183 m .35446 .70862 L p .35587 .69865 L .707 .577 .707 r
F P
0 g
s
.35446 .70862 m .3535 .70399 L .34724 .71817 L .707 .577 .707 r
F
.35587 .69865 m .35301 .702 L .34724 .71817 L F
.34216 .68214 m .35061 .70483 L p .35477 .69993 L F P
0 g
s
.35446 .70862 m .35199 .69667 L p .35445 .69033 L .707 .577 .707 r
F P
0 g
s
.34958 .67561 m .35746 .69677 L p .35558 .69275 L .707 .577 .707 r
F P
0 g
s
.35445 .69033 m .35621 .6941 L .35446 .70862 L .707 .577 .707 r
F
.34766 .6724 m .34958 .67561 L p .35558 .69275 L F P
0 g
s
.35746 .69677 m .35446 .70862 L p .35621 .6941 L .707 .577 .707 r
F P
0 g
s
.35389 .68913 m .34766 .6724 L p .35558 .69275 L .707 .577 .707 r
F P
0 g
s
.36525 .64424 m .36772 .65619 L p .35644 .68522 L .707 .577 .707 r
F P
0 g
s
.35199 .69667 m .35389 .68913 L p .35644 .68522 L .707 .577 .707 r
F P
0 g
s
.35389 .68913 m .36525 .64424 L p .35644 .68522 L .707 .577 .707 r
F P
0 g
s
.35061 .70483 m .34724 .71817 L p .35301 .702 L .707 .577 .707 r
F P
0 g
s
.35061 .70483 m .34216 .68214 L p .34425 .70777 L .707 .577 .707 r
F P
0 g
s
.36099 .7082 m .34992 .70861 L p .34916 .69641 L .707 .577 .707 r
F P
0 g
s
.35199 .69667 m .34005 .68346 L p .34049 .68277 L .707 .577 .707 r
F P
0 g
s
.34766 .6724 m .35389 .68913 L p .34854 .68659 L .707 .577 .707 r
F P
0 g
s
.38267 .80551 m .37564 .30292 L .35787 .29224 L p .707 .577 .707 r
F P
0 g
s
.35389 .68913 m .35199 .69667 L p .34049 .68277 L .707 .577 .707 r
F P
0 g
s
.33658 .6728 m .34766 .6724 L p .34854 .68659 L .707 .577 .707 r
F P
0 g
s
.34005 .68346 m .34025 .68265 L p .34049 .68277 L .707 .577 .707 r
F P
0 g
s
.34992 .70861 m .34025 .68265 L p .34854 .68659 L .707 .577 .707 r
F P
0 g
s
.34025 .68265 m .33658 .6728 L p .34854 .68659 L .707 .577 .707 r
F P
0 g
s
.35331 .63103 m .36525 .64424 L p .34515 .67551 L .707 .577 .707 r
F P
0 g
s
.36525 .64424 m .36153 .65895 L p .36157 .65147 L .707 .577 .707 r
F P
0 g
s
.36153 .65895 m .35389 .68913 L p .36157 .65147 L .707 .577 .707 r
F P
0 g
s
.34466 .68475 m .36157 .65147 L .35389 .68913 L .707 .577 .707 r
F
.3649 .79483 m .36467 .77854 L p .36455 .77868 L F P
0 g
s
.34515 .67551 m .36525 .64424 L .34466 .68475 L .707 .577 .707 r
F
.36772 .65619 m .35746 .69677 L p .35766 .68207 L F P
0 g
s
.36467 .77854 m .35787 .29224 L p .36455 .77868 L .707 .577 .707 r
F P
0 g
s
.35787 .29224 m .35378 .28046 L p .36455 .77868 L .707 .577 .707 r
F P
0 g
s
.35746 .69677 m .36291 .71142 L p .35944 .70378 L .707 .577 .707 r
F P
0 g
s
.35787 .29224 m .3649 .79483 L .38267 .80551 L p .707 .577 .707 r
F P
0 g
s
.35389 .68913 m .36099 .7082 L p .34916 .69641 L .707 .577 .707 r
F P
0 g
s
.36099 .7082 m .35389 .68913 L p .35558 .69275 L .707 .577 .707 r
F P
0 g
s
.35378 .28046 m .36081 .78305 L .3649 .79483 L p .707 .577 .707 r
F P
0 g
s
.37081 .77135 m .36081 .78305 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.36378 .26875 m .36442 .31434 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.36442 .31434 m .37081 .77135 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.34049 .68277 m .34594 .66078 L .34515 .67551 L .707 .577 .707 r
F
.34594 .66078 m .35331 .63103 L .34515 .67551 L F
.34025 .68265 m .35331 .63103 L p .34049 .68277 L F P
0 g
s
.35378 .28046 m .36378 .26875 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.36081 .78305 m .35636 .46531 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.35636 .46531 m .35378 .28046 L p .36341 .33328 L .707 .577 .707 r
F P
0 g
s
.34049 .68277 m .34515 .67551 L .34466 .68475 L .707 .577 .707 r
F
.34916 .69641 m .34854 .68659 L .35389 .68913 L F
.35766 .68207 m .35746 .69677 L .35621 .6941 L F
.35445 .69033 m .35766 .68207 L .35621 .6941 L F
.35944 .70378 m .35558 .69275 L .35746 .69677 L F
.33401 .7125 m .33101 .72436 L p .33922 .71009 L F P
0 g
s
.33101 .72436 m .34724 .71817 L p .3465 .70673 L .707 .577 .707 r
F P
0 g
s
.3465 .70673 m .33922 .71009 L .33101 .72436 L .707 .577 .707 r
F
.32613 .69135 m .33401 .7125 L p .34425 .70777 L F P
0 g
s
.32613 .69135 m .30305 .70232 L p .32247 .71556 L .707 .577 .707 r
F P
0 g
s
.33401 .7125 m .32613 .69135 L p .32247 .71556 L .707 .577 .707 r
F P
0 g
s
.30928 .71906 m .31638 .73813 L p .32247 .71556 L .707 .577 .707 r
F P
0 g
s
.30928 .71906 m .30738 .72659 L p .31467 .71763 L .707 .577 .707 r
F P
0 g
s
.32815 .71943 m .32247 .71556 L .31828 .7311 L .707 .577 .707 r
F
.32815 .71943 m .31828 .7311 L .31638 .73813 L F
.30305 .70232 m .30928 .71906 L p .32247 .71556 L F P
0 g
s
.30738 .72659 m .33101 .72436 L p .32884 .71387 L .707 .577 .707 r
F P
0 g
s
.32884 .71387 m .31467 .71763 L .30738 .72659 L .707 .577 .707 r
F
.30305 .70232 m .27519 .71399 L p .28922 .72221 L F P
0 g
s
.30928 .71906 m .30305 .70232 L p .28922 .72221 L .707 .577 .707 r
F P
0 g
s
.27519 .71399 m .27885 .72384 L p .28922 .72221 L .707 .577 .707 r
F P
0 g
s
.27865 .72465 m .30738 .72659 L p .30541 .71967 L .707 .577 .707 r
F P
0 g
s
.30541 .71967 m .27956 .72373 L .27865 .72465 L .707 .577 .707 r
F
.27519 .71399 m .24526 .72522 L p .24713 .72628 L F P
0 g
s
.27885 .72384 m .27519 .71399 L p .24713 .72628 L .707 .577 .707 r
F P
0 g
s
.27568 .72408 m .27865 .72465 L p .27841 .72387 L .707 .577 .707 r
F P
0 g
s
.41239 .81406 m .40536 .31147 L .37564 .30292 L p .707 .577 .707 r
F P
0 g
s
.40536 .31147 m .41239 .81406 L .45115 .81964 L p .707 .577 .707 r
F P
0 g
s
.21738 .70939 m .23063 .65696 L .20409 .64514 L p .707 .577 .707 r
F P
0 g
s
.23063 .65696 m .21738 .70939 L .24764 .71872 L p .707 .577 .707 r
F P
0 g
s
.70081 .82639 m .69725 .84416 L .69463 .83286 L p .707 .577 .707 r
F P
0 g
s
.69463 .83286 m .69819 .81509 L .70081 .82639 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.19083 .69757 m .20409 .64514 L .18386 .63198 L p .707 .577 .707 r
F P
0 g
s
.20409 .64514 m .19083 .69757 L .21738 .70939 L p .707 .577 .707 r
F P
0 g
s
.63511 .72063 m .64845 .75643 L .61939 .76612 L p .707 .577 .707 r
F P
0 g
s
.63506 .79842 m .63862 .78064 L .66549 .79104 L p .707 .577 .707 r
F P
0 g
s
.6085 .30396 m .61553 .80655 L .63864 .79605 L p .707 .577 .707 r
F P
0 g
s
.67608 .65475 m .66282 .70718 L .63628 .69536 L p .707 .577 .707 r
F P
0 g
s
.63628 .69536 m .64954 .64293 L .67608 .65475 L p .707 .577 .707 r
F P
0 g
s
.64845 .75643 m .63511 .72063 L .66045 .71344 L p .707 .577 .707 r
F P
0 g
s
.63864 .79605 m .63161 .29346 L .6085 .30396 L p .707 .577 .707 r
F P
0 g
s
.69293 .74525 m .67378 .74924 L p .67829 .71834 L .707 .577 .707 r
F P
0 g
s
.67959 .70944 m .6833 .71939 L p .67829 .71834 L .707 .577 .707 r
F P
0 g
s
.6833 .71939 m .68306 .72034 L .68078 .71886 L p .707 .577 .707 r
F P
0 g
s
.6833 .71939 m .69293 .74525 L p .67829 .71834 L .707 .577 .707 r
F P
0 g
s
.67378 .74924 m .66045 .71344 L .67959 .70944 L p .707 .577 .707 r
F P
0 g
s
.69632 .66791 m .6833 .71939 L p .66282 .70718 L .707 .577 .707 r
F P
0 g
s
.68078 .71886 m .66282 .70718 L p .6833 .71939 L .707 .577 .707 r
F P
0 g
s
.66282 .70718 m .67608 .65475 L .69632 .66791 L p .707 .577 .707 r
F P
0 g
s
.2586 .76102 m .24526 .72522 L .21621 .7349 L p .707 .577 .707 r
F P
0 g
s
.24526 .72522 m .2586 .76102 L .28852 .7498 L p .707 .577 .707 r
F P
0 g
s
.21621 .7349 m .22954 .77071 L .2586 .76102 L p .707 .577 .707 r
F P
0 g
s
.22954 .77071 m .21621 .7349 L .19087 .74209 L p .707 .577 .707 r
F P
0 g
s
.69819 .81509 m .69463 .83286 L .68246 .82068 L p .707 .577 .707 r
F P
0 g
s
.68246 .82068 m .68602 .80291 L .69819 .81509 L p .707 .577 .707 r
F P
0 g
s
.37564 .30292 m .38267 .80551 L .41239 .81406 L p .707 .577 .707 r
F P
0 g
s
.19087 .74209 m .20421 .7779 L .22954 .77071 L p .707 .577 .707 r
F P
0 g
s
.18386 .63198 m .1706 .68441 L .19083 .69757 L p .707 .577 .707 r
F P
0 g
s
.1706 .68441 m .18386 .63198 L .17192 .61878 L p .707 .577 .707 r
F P
0 g
s
.24674 .81973 m .2503 .80196 L .21972 .79405 L p .707 .577 .707 r
F P
0 g
s
.2503 .80196 m .24674 .81973 L .27805 .82437 L p .707 .577 .707 r
F P
0 g
s
.27805 .82437 m .28161 .80659 L .2503 .80196 L p .707 .577 .707 r
F P
0 g
s
.28161 .80659 m .27805 .82437 L .30701 .82529 L p .707 .577 .707 r
F P
0 g
s
.30701 .82529 m .31057 .80751 L .28161 .80659 L p .707 .577 .707 r
F P
0 g
s
.21616 .81183 m .21972 .79405 L .19285 .78366 L p .707 .577 .707 r
F P
0 g
s
.21972 .79405 m .21616 .81183 L .24674 .81973 L p .707 .577 .707 r
F P
0 g
s
.20421 .7779 m .19087 .74209 L .17173 .74609 L p .707 .577 .707 r
F P
0 g
s
.19285 .78366 m .18929 .80143 L .21616 .81183 L p .707 .577 .707 r
F P
0 g
s
.18929 .80143 m .19285 .78366 L .17233 .77179 L p .707 .577 .707 r
F P
0 g
s
.17173 .74609 m .18506 .78189 L .20421 .7779 L p .707 .577 .707 r
F P
0 g
s
.63161 .29346 m .63864 .79605 L .64864 .78434 L p .707 .577 .707 r
F P
0 g
s
.64864 .78434 m .64161 .28175 L .63161 .29346 L p .707 .577 .707 r
F P
0 g
s
.17192 .61878 m .15866 .67121 L .1706 .68441 L p .707 .577 .707 r
F P
0 g
s
.31057 .80751 m .30701 .82529 L .33079 .82239 L p .707 .577 .707 r
F P
0 g
s
.33079 .82239 m .33435 .80462 L .31057 .80751 L p .707 .577 .707 r
F P
0 g
s
.68602 .80291 m .68246 .82068 L .66193 .80881 L p .707 .577 .707 r
F P
0 g
s
.66193 .80881 m .66549 .79104 L .68602 .80291 L p .707 .577 .707 r
F P
0 g
s
.66045 .71344 m .67378 .74924 L .64845 .75643 L p .707 .577 .707 r
F P
0 g
s
.15866 .67121 m .17192 .61878 L .16944 .60682 L p .707 .577 .707 r
F P
0 g
s
.17233 .77179 m .16877 .78956 L .18929 .80143 L p .707 .577 .707 r
F P
0 g
s
.18506 .78189 m .17173 .74609 L .16065 .7465 L p .707 .577 .707 r
F P
0 g
s
.16877 .78956 m .17174 .77472 L p .16016 .75961 L .707 .577 .707 r
F P
0 g
s
.17174 .77472 m .17233 .77179 L .16943 .76889 L p .707 .577 .707 r
F P
0 g
s
.16943 .76889 m .16016 .75961 L p .17174 .77472 L .707 .577 .707 r
F P
0 g
s
.17399 .7823 m .16204 .75022 L p .15873 .74328 L .707 .577 .707 r
F P
0 g
s
.16204 .75022 m .16065 .7465 L .16039 .74606 L p .707 .577 .707 r
F P
0 g
s
.16039 .74606 m .15873 .74328 L p .16204 .75022 L .707 .577 .707 r
F P
0 g
s
.16065 .7465 m .17399 .7823 L .18506 .78189 L p .707 .577 .707 r
F P
0 g
s
.33435 .80462 m .33079 .82239 L .34707 .81598 L p .707 .577 .707 r
F P
0 g
s
.34707 .81598 m .35063 .7982 L .33435 .80462 L p .707 .577 .707 r
F P
0 g
s
.66549 .79104 m .66193 .80881 L .63506 .79842 L p .707 .577 .707 r
F P
0 g
s
.16944 .60682 m .15618 .65925 L .15866 .67121 L p .707 .577 .707 r
F P
0 g
s
.16016 .75961 m .15659 .77738 L .16877 .78956 L p .707 .577 .707 r
F P
0 g
s
.15618 .65925 m .16944 .60682 L .17667 .59728 L p .707 .577 .707 r
F P
0 g
s
.64161 .28175 m .64864 .78434 L .64455 .77257 L p .707 .577 .707 r
F P
0 g
s
.64455 .77257 m .63752 .26998 L .64161 .28175 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35063 .7982 m .34707 .81598 L .35424 .80666 L p .707 .577 .707 r
F P
0 g
s
.35424 .80666 m .3578 .78889 L .35063 .7982 L p .707 .577 .707 r
F P
0 g
s
.15659 .77738 m .16016 .75961 L .15753 .74831 L p .707 .577 .707 r
F P
0 g
s
.15873 .74328 m .17207 .77908 L .17399 .7823 L p .707 .577 .707 r
F P
0 g
s
.17667 .59728 m .16341 .64971 L .15618 .65925 L p .707 .577 .707 r
F P
0 g
s
.15753 .74831 m .15397 .76608 L .15659 .77738 L p .707 .577 .707 r
F P
0 g
s
.16341 .64971 m .17667 .59728 L .19289 .59109 L p .707 .577 .707 r
F P
0 g
s
.17207 .77908 m .15873 .74328 L .16615 .73675 L p .707 .577 .707 r
F P
0 g
s
.3578 .78889 m .35424 .80666 L .35162 .79536 L p .707 .577 .707 r
F P
0 g
s
.35162 .79536 m .35518 .77759 L .3578 .78889 L p .707 .577 .707 r
F P
0 g
s
.15397 .76608 m .15753 .74831 L .16471 .73899 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.16615 .73675 m .17948 .77255 L .17207 .77908 L p .707 .577 .707 r
F P
0 g
s
.63752 .26998 m .64455 .77257 L .62678 .76189 L p .707 .577 .707 r
F P
0 g
s
.62678 .76189 m .61975 .2593 L .63752 .26998 L p .707 .577 .707 r
F P
0 g
s
.19289 .59109 m .17963 .64352 L .16341 .64971 L p .707 .577 .707 r
F P
0 g
s
.16471 .73899 m .16115 .75677 L .15397 .76608 L p .707 .577 .707 r
F P
0 g
s
.17963 .64352 m .19289 .59109 L .21652 .58886 L p .707 .577 .707 r
F P
0 g
s
.34992 .70861 m .33077 .71261 L p .3353 .68162 L .707 .577 .707 r
F P
0 g
s
.33658 .6728 m .34025 .68265 L p .3353 .68162 L .707 .577 .707 r
F P
0 g
s
.34025 .68265 m .34005 .68346 L .33811 .6822 L p .707 .577 .707 r
F P
0 g
s
.34025 .68265 m .34992 .70861 L p .3353 .68162 L .707 .577 .707 r
F P
0 g
s
.33077 .71261 m .31744 .6768 L .33658 .6728 L p .707 .577 .707 r
F P
0 g
s
.35331 .63103 m .34025 .68265 L p .31981 .67031 L .707 .577 .707 r
F P
0 g
s
.33811 .6822 m .31981 .67031 L p .34025 .68265 L .707 .577 .707 r
F P
0 g
s
.31981 .67031 m .33307 .61788 L .35331 .63103 L p .707 .577 .707 r
F P
0 g
s
.37081 .77135 m .36378 .26875 L .38689 .25825 L p .707 .577 .707 r
F P
0 g
s
.17948 .77255 m .16615 .73675 L .18218 .72755 L p .707 .577 .707 r
F P
0 g
s
.35518 .77759 m .35162 .79536 L .33945 .78318 L p .707 .577 .707 r
F P
0 g
s
.33945 .78318 m .34301 .76541 L .35518 .77759 L p .707 .577 .707 r
F P
0 g
s
.16115 .75677 m .16471 .73899 L .18098 .73258 L p .707 .577 .707 r
F P
0 g
s
.21652 .58886 m .20327 .64129 L .17963 .64352 L p .707 .577 .707 r
F P
0 g
s
.18218 .72755 m .19552 .76335 L .17948 .77255 L p .707 .577 .707 r
F P
0 g
s
.20327 .64129 m .21652 .58886 L .24525 .5908 L p .707 .577 .707 r
F P
0 g
s
.33307 .61788 m .31981 .67031 L .29327 .65848 L p .707 .577 .707 r
F P
0 g
s
.29327 .65848 m .30653 .60605 L .33307 .61788 L p .707 .577 .707 r
F P
0 g
s
.18098 .73258 m .17742 .75035 L .16115 .75677 L p .707 .577 .707 r
F P
0 g
s
.61975 .2593 m .62678 .76189 L .59705 .75334 L p .707 .577 .707 r
F P
0 g
s
.59705 .75334 m .59002 .25075 L .61975 .2593 L p .707 .577 .707 r
F P
0 g
s
.23199 .64323 m .24525 .5908 L .27627 .59672 L p .707 .577 .707 r
F P
0 g
s
.24525 .5908 m .23199 .64323 L .20327 .64129 L p .707 .577 .707 r
F P
0 g
s
.30653 .60605 m .29327 .65848 L .26301 .64915 L p .707 .577 .707 r
F P
0 g
s
.26301 .64915 m .27627 .59672 L .30653 .60605 L p .707 .577 .707 r
F P
0 g
s
.27627 .59672 m .26301 .64915 L .23199 .64323 L p .707 .577 .707 r
F P
0 g
s
.19552 .76335 m .18218 .72755 L .20526 .71657 L p .707 .577 .707 r
F P
0 g
s
.34301 .76541 m .33945 .78318 L .31892 .77131 L p .707 .577 .707 r
F P
0 g
s
.31892 .77131 m .32248 .75354 L .34301 .76541 L p .707 .577 .707 r
F P
0 g
s
.2186 .75238 m .19552 .76335 L p .20469 .71931 L .707 .577 .707 r
F P
0 g
s
.20526 .71657 m .20665 .72029 L p .20469 .71931 L .707 .577 .707 r
F P
0 g
s
.20665 .72029 m .2186 .75238 L p .20469 .71931 L .707 .577 .707 r
F P
0 g
s
.2186 .75238 m .20526 .71657 L .23313 .7049 L p .707 .577 .707 r
F P
0 g
s
.23313 .7049 m .24646 .74071 L .2186 .75238 L p .707 .577 .707 r
F P
0 g
s
.2012 .74746 m .20476 .72969 L .22684 .73039 L p .707 .577 .707 r
F P
0 g
s
.22684 .73039 m .23372 .7306 L p .23056 .73225 L .707 .577 .707 r
F P
0 g
s
.2012 .74746 m .22684 .73039 L .23056 .73225 L .707 .577 .707 r
F
.17742 .75035 m .18098 .73258 L .20476 .72969 L p F P
0 g
s
.31744 .6768 m .33077 .71261 L .30544 .7198 L p .707 .577 .707 r
F P
0 g
s
.30544 .7198 m .2921 .68399 L .31744 .6768 L p .707 .577 .707 r
F P
0 g
s
.72785 .66356 m .74111 .61113 L .71085 .6018 L p .707 .577 .707 r
F P
0 g
s
.74111 .61113 m .72785 .66356 L .75537 .66882 L p .707 .577 .707 r
F P
0 g
s
.75858 .66858 m .75843 .66808 L .75537 .66882 L .707 .577 .707 r
F
.75843 .66808 m .74111 .61113 L .75453 .66542 L F
.75843 .66808 m .75453 .66542 L .75537 .66882 L F
.74596 .68145 m .7591 .66854 L .72749 .67096 L F
.76873 .6944 m .7591 .66854 L p .74596 .68145 L F P
0 g
s
.7966 .68272 m .76957 .66689 L .7591 .66854 L .707 .577 .707 r
F
.78558 .66437 m .78072 .64729 L .75993 .66841 L F
.77212 .61706 m .7591 .66854 L p .78072 .64729 L F P
0 g
s
.7591 .66854 m .76873 .6944 L .78625 .68706 L p .707 .577 .707 r
F P
0 g
s
.78625 .68706 m .7966 .68272 L p .7591 .66854 L .707 .577 .707 r
F P
0 g
s
.7591 .66854 m .75886 .66949 L p .75993 .66841 L .707 .577 .707 r
F P
0 g
s
.78072 .64729 m .7591 .66854 L .75993 .66841 L .707 .577 .707 r
F
.77212 .61706 m .74111 .61113 L p .75843 .66808 L F P
0 g
s
.75886 .66949 m .7591 .66854 L p .75843 .66808 L .707 .577 .707 r
F P
0 g
s
.7591 .66854 m .77212 .61706 L p .75843 .66808 L .707 .577 .707 r
F P
0 g
s
.77974 .67285 m .78953 .66375 L .76957 .66689 L .707 .577 .707 r
F
.7966 .68272 m .78953 .66375 L p .77974 .67285 L F P
0 g
s
.7966 .68272 m .81968 .67175 L p .80843 .66408 L .707 .577 .707 r
F P
0 g
s
.80903 .65859 m .80679 .64772 L .79497 .66231 L .707 .577 .707 r
F
.80085 .619 m .78953 .66375 L p .80679 .64772 L F P
0 g
s
.80679 .64772 m .78953 .66375 L .79497 .66231 L .707 .577 .707 r
F
.80085 .619 m .77212 .61706 L p .78477 .66152 L F P
0 g
s
.78759 .67143 m .78953 .66375 L p .78477 .66152 L .707 .577 .707 r
F P
0 g
s
.78953 .66375 m .80085 .619 L p .78477 .66152 L .707 .577 .707 r
F P
0 g
s
.81968 .67175 m .81426 .6572 L p .8028 .66024 L .707 .577 .707 r
F P
0 g
s
.82448 .61677 m .80085 .619 L p .80822 .65464 L .707 .577 .707 r
F P
0 g
s
.81122 .6692 m .81426 .6572 L p .80822 .65464 L .707 .577 .707 r
F P
0 g
s
.81426 .6572 m .82448 .61677 L p .80822 .65464 L .707 .577 .707 r
F P
0 g
s
.826 .66013 m .82455 .65244 L .81426 .6572 L .707 .577 .707 r
F
.83571 .66255 m .82806 .65562 L .826 .66013 L F
.82806 .65562 m .82455 .65244 L .826 .66013 L F
.81426 .6572 m .81968 .67175 L .83197 .66469 L p F P
0 g
s
.83197 .66469 m .83571 .66255 L p .81426 .6572 L .707 .577 .707 r
F P
0 g
s
.82671 .65144 m .82617 .64312 L .81949 .65478 L .707 .577 .707 r
F
.82448 .61677 m .81426 .6572 L p .82617 .64312 L F P
0 g
s
.82617 .64312 m .81426 .6572 L .81949 .65478 L .707 .577 .707 r
F
.82238 .62674 m .80634 .63594 L p .82455 .65244 L F P
0 g
s
.83571 .66255 m .83086 .64952 L p .82455 .65244 L .707 .577 .707 r
F P
0 g
s
.84071 .61057 m .82448 .61677 L p .82641 .64683 L .707 .577 .707 r
F P
0 g
s
.82745 .663 m .83086 .64952 L p .82641 .64683 L .707 .577 .707 r
F P
0 g
s
.83086 .64952 m .84071 .61057 L p .82641 .64683 L .707 .577 .707 r
F P
0 g
s
.83755 .65306 m .83504 .64461 L .83086 .64952 L .707 .577 .707 r
F
.84313 .65602 m .83762 .64824 L .83755 .65306 L F
.83762 .64824 m .83504 .64461 L .83755 .65306 L F
.83086 .64952 m .83571 .66255 L .84251 .65657 L p F P
0 g
s
.84251 .65657 m .84313 .65602 L p .83086 .64952 L .707 .577 .707 r
F P
0 g
s
.8361 .64336 m .83717 .63577 L .83327 .64669 L .707 .577 .707 r
F
.84071 .61057 m .83086 .64952 L p .83717 .63577 L F P
0 g
s
.83717 .63577 m .83086 .64952 L .83327 .64669 L .707 .577 .707 r
F
.82979 .62021 m .82238 .62674 L p .83504 .64461 L F P
0 g
s
.84313 .65602 m .83771 .64147 L p .83504 .64461 L .707 .577 .707 r
F P
0 g
s
.84794 .60103 m .84071 .61057 L p .83681 .63829 L .707 .577 .707 r
F P
0 g
s
.83468 .65346 m .83771 .64147 L p .83681 .63829 L .707 .577 .707 r
F P
0 g
s
.83771 .64147 m .84794 .60103 L p .83681 .63829 L .707 .577 .707 r
F P
0 g
s
.84313 .65602 m .84121 .6528 L p .8397 .6485 L .707 .577 .707 r
F P
0 g
s
.83771 .64147 m .82979 .62021 L p .83504 .64461 L .707 .577 .707 r
F P
0 g
s
.83469 .64656 m .83468 .65346 L p .8361 .64336 L .707 .577 .707 r
F P
0 g
s
.83468 .65346 m .83371 .64879 L .82745 .663 L .707 .577 .707 r
F
.8361 .64336 m .83327 .64669 L .82745 .663 L F
.82238 .62674 m .83086 .64952 L p .83504 .64461 L F P
0 g
s
.83468 .65346 m .8322 .64151 L p .83471 .63505 L .707 .577 .707 r
F P
0 g
s
.82979 .62021 m .83771 .64147 L p .83582 .63743 L .707 .577 .707 r
F P
0 g
s
.83471 .63505 m .83646 .63879 L .83468 .65346 L .707 .577 .707 r
F
.82787 .61699 m .82979 .62021 L p .83582 .63743 L F P
0 g
s
.83771 .64147 m .83468 .65346 L p .83646 .63879 L .707 .577 .707 r
F P
0 g
s
.83414 .63383 m .82787 .61699 L p .83582 .63743 L .707 .577 .707 r
F P
0 g
s
.84546 .58908 m .84794 .60103 L p .83673 .62984 L .707 .577 .707 r
F P
0 g
s
.8322 .64151 m .83414 .63383 L p .83673 .62984 L .707 .577 .707 r
F P
0 g
s
.83414 .63383 m .84546 .58908 L p .83673 .62984 L .707 .577 .707 r
F P
0 g
s
.83086 .64952 m .82745 .663 L p .83327 .64669 L .707 .577 .707 r
F P
0 g
s
.83086 .64952 m .82238 .62674 L p .82455 .65244 L .707 .577 .707 r
F P
0 g
s
.84121 .6528 m .83013 .65321 L p .82938 .64115 L .707 .577 .707 r
F P
0 g
s
.8322 .64151 m .82026 .6283 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.82787 .61699 m .83414 .63383 L p .82876 .63127 L .707 .577 .707 r
F P
0 g
s
.83414 .63383 m .8322 .64151 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.8168 .6174 m .82787 .61699 L p .82876 .63127 L .707 .577 .707 r
F P
0 g
s
.82026 .6283 m .8205 .62735 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.83013 .65321 m .8205 .62735 L p .82876 .63127 L .707 .577 .707 r
F P
0 g
s
.8205 .62735 m .8168 .6174 L p .82876 .63127 L .707 .577 .707 r
F P
0 g
s
.83352 .57587 m .84546 .58908 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.8205 .62735 m .83352 .57587 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.84546 .58908 m .83414 .63383 L p .82079 .62748 L .707 .577 .707 r
F P
0 g
s
.82938 .64115 m .82876 .63127 L .83414 .63383 L .707 .577 .707 r
F
.83414 .63383 m .84121 .6528 L p .82938 .64115 L F P
0 g
s
.84121 .6528 m .83414 .63383 L p .83582 .63743 L .707 .577 .707 r
F P
0 g
s
.83791 .62681 m .83771 .64147 L .83646 .63879 L .707 .577 .707 r
F
.83471 .63505 m .83791 .62681 L .83646 .63879 L F
.8397 .6485 m .83582 .63743 L .83771 .64147 L F
.83771 .64147 m .84313 .65602 L p .8397 .6485 L F P
0 g
s
.84794 .60103 m .83771 .64147 L p .83791 .62681 L .707 .577 .707 r
F P
0 g
s
.81426 .6572 m .81122 .6692 L p .81949 .65478 L .707 .577 .707 r
F P
0 g
s
.81122 .6692 m .82745 .663 L p .82671 .65144 L .707 .577 .707 r
F P
0 g
s
.82671 .65144 m .81949 .65478 L .81122 .6692 L .707 .577 .707 r
F
.80634 .63594 m .81426 .6572 L p .82455 .65244 L F P
0 g
s
.80634 .63594 m .78326 .64692 L p .8028 .66024 L .707 .577 .707 r
F P
0 g
s
.81426 .6572 m .80634 .63594 L p .8028 .66024 L .707 .577 .707 r
F P
0 g
s
.78953 .66375 m .7966 .68272 L p .8028 .66024 L .707 .577 .707 r
F P
0 g
s
.78953 .66375 m .78759 .67143 L p .79497 .66231 L .707 .577 .707 r
F P
0 g
s
.80843 .66408 m .8028 .66024 L .7985 .67583 L .707 .577 .707 r
F
.80843 .66408 m .7985 .67583 L .7966 .68272 L F
.78326 .64692 m .78953 .66375 L p .8028 .66024 L F P
0 g
s
.78759 .67143 m .81122 .6692 L p .80903 .65859 L .707 .577 .707 r
F P
0 g
s
.80903 .65859 m .79497 .66231 L .78759 .67143 L .707 .577 .707 r
F
.78326 .64692 m .7554 .65859 L p .76957 .66689 L F P
0 g
s
.78953 .66375 m .78326 .64692 L p .76957 .66689 L .707 .577 .707 r
F P
0 g
s
.7554 .65859 m .7591 .66854 L p .76957 .66689 L .707 .577 .707 r
F P
0 g
s
.75886 .66949 m .78759 .67143 L p .78558 .66437 L .707 .577 .707 r
F P
0 g
s
.78558 .66437 m .75993 .66841 L .75886 .66949 L .707 .577 .707 r
F
.7554 .65859 m .72548 .66982 L p .72749 .67096 L F P
0 g
s
.7591 .66854 m .7554 .65859 L p .72749 .67096 L .707 .577 .707 r
F P
0 g
s
.75537 .66882 m .75886 .66949 L p .75858 .66858 L .707 .577 .707 r
F P
0 g
s
.38689 .25825 m .39392 .76085 L .37081 .77135 L p .707 .577 .707 r
F P
0 g
s
.39392 .76085 m .38689 .25825 L .42084 .24999 L p .707 .577 .707 r
F P
0 g
s
.20476 .72969 m .2012 .74746 L .17742 .75035 L p .707 .577 .707 r
F P
0 g
s
.69759 .65423 m .71085 .6018 L .6843 .58998 L p .707 .577 .707 r
F P
0 g
s
.71085 .6018 m .69759 .65423 L .72785 .66356 L p .707 .577 .707 r
F P
0 g
s
.2921 .68399 m .30544 .7198 L .27638 .72948 L p .707 .577 .707 r
F P
0 g
s
.27638 .72948 m .26305 .69367 L .2921 .68399 L p .707 .577 .707 r
F P
0 g
s
.67104 .64241 m .6843 .58998 L .66407 .57682 L p .707 .577 .707 r
F P
0 g
s
.6843 .58998 m .67104 .64241 L .69759 .65423 L p .707 .577 .707 r
F P
0 g
s
.32248 .75354 m .31892 .77131 L .29205 .76092 L p .707 .577 .707 r
F P
0 g
s
.29205 .76092 m .29561 .74314 L .32248 .75354 L p .707 .577 .707 r
F P
0 g
s
.59002 .25075 m .59705 .75334 L .55829 .74776 L p .707 .577 .707 r
F P
0 g
s
.55829 .74776 m .55126 .24517 L .59002 .25075 L p .707 .577 .707 r
F P
0 g
s
.73881 .70562 m .72548 .66982 L .69642 .6795 L p .707 .577 .707 r
F P
0 g
s
.72548 .66982 m .73881 .70562 L .76873 .6944 L p .707 .577 .707 r
F P
0 g
s
.23372 .7306 m .23016 .74838 L .2012 .74746 L p .707 .577 .707 r
F P
0 g
s
.24646 .74071 m .23313 .7049 L .26305 .69367 L p .707 .577 .707 r
F P
0 g
s
.26305 .69367 m .27638 .72948 L .24646 .74071 L p .707 .577 .707 r
F P
0 g
s
.69642 .6795 m .70976 .71531 L .73881 .70562 L p .707 .577 .707 r
F P
0 g
s
.42787 .75258 m .42084 .24999 L .46232 .24477 L p .707 .577 .707 r
F P
0 g
s
.42084 .24999 m .42787 .75258 L .39392 .76085 L p .707 .577 .707 r
F P
0 g
s
.29561 .74314 m .29205 .76092 L .26147 .75302 L p .707 .577 .707 r
F P
0 g
s
.26147 .75302 m .26503 .73524 L .29561 .74314 L p .707 .577 .707 r
F P
0 g
s
.23016 .74838 m .23372 .7306 L .26503 .73524 L p .707 .577 .707 r
F P
0 g
s
.70976 .71531 m .69642 .6795 L .67108 .68669 L p .707 .577 .707 r
F P
0 g
s
.67108 .68669 m .68442 .7225 L .70976 .71531 L p .707 .577 .707 r
F P
0 g
s
.26503 .73524 m .26147 .75302 L .23016 .74838 L p .707 .577 .707 r
F P
0 g
s
.66407 .57682 m .65081 .62925 L .67104 .64241 L p .707 .577 .707 r
F P
0 g
s
.65081 .62925 m .66407 .57682 L .65213 .56362 L p .707 .577 .707 r
F P
0 g
s
.55126 .24517 m .55829 .74776 L .51429 .7457 L p .707 .577 .707 r
F P
0 g
s
.51429 .7457 m .50726 .24311 L .55126 .24517 L p .707 .577 .707 r
F P
0 g
s
.72696 .76519 m .73052 .74742 L .69993 .73952 L p .707 .577 .707 r
F P
0 g
s
.73052 .74742 m .72696 .76519 L .75826 .76983 L p .707 .577 .707 r
F P
0 g
s
.75826 .76983 m .76182 .75206 L .73052 .74742 L p .707 .577 .707 r
F P
0 g
s
.46935 .74736 m .46232 .24477 L .50726 .24311 L p .707 .577 .707 r
F P
0 g
s
.46232 .24477 m .46935 .74736 L .42787 .75258 L p .707 .577 .707 r
F P
0 g
s
.76182 .75206 m .75826 .76983 L .78722 .77075 L p .707 .577 .707 r
F P
0 g
s
.78722 .77075 m .79078 .75297 L .76182 .75206 L p .707 .577 .707 r
F P
0 g
s
.69637 .75729 m .69993 .73952 L .67306 .72912 L p .707 .577 .707 r
F P
0 g
s
.69993 .73952 m .69637 .75729 L .72696 .76519 L p .707 .577 .707 r
F P
0 g
s
.50726 .24311 m .51429 .7457 L .46935 .74736 L p .707 .577 .707 r
F P
0 g
s
.68442 .7225 m .67108 .68669 L .65194 .69069 L p .707 .577 .707 r
F P
0 g
s
.67306 .72912 m .6695 .7469 L .69637 .75729 L p .707 .577 .707 r
F P
0 g
s
.6695 .7469 m .67306 .72912 L .65254 .71725 L p .707 .577 .707 r
F P
0 g
s
.65194 .69069 m .66528 .72649 L .68442 .7225 L p .707 .577 .707 r
F P
0 g
s
.65213 .56362 m .63887 .61605 L .65081 .62925 L p .707 .577 .707 r
F P
0 g
s
.79078 .75297 m .78722 .77075 L .811 .76786 L p .707 .577 .707 r
F P
0 g
s
.811 .76786 m .81457 .75008 L .79078 .75297 L p .707 .577 .707 r
F P
0 g
s
.63887 .61605 m .65213 .56362 L .64965 .55166 L p .707 .577 .707 r
F P
0 g
s
.65254 .71725 m .64898 .73503 L .6695 .7469 L p .707 .577 .707 r
F P
0 g
s
.66528 .72649 m .65194 .69069 L .64087 .69109 L p .707 .577 .707 r
F P
0 g
s
.64898 .73503 m .65207 .71962 L p .64037 .70507 L .707 .577 .707 r
F P
0 g
s
.65207 .71962 m .65254 .71725 L .6502 .71491 L p .707 .577 .707 r
F P
0 g
s
.6502 .71491 m .64037 .70507 L p .65207 .71962 L .707 .577 .707 r
F P
0 g
s
.6542 .7269 m .64236 .69512 L p .63894 .68788 L .707 .577 .707 r
F P
0 g
s
.64236 .69512 m .64087 .69109 L .64059 .69063 L p .707 .577 .707 r
F P
0 g
s
.64059 .69063 m .63894 .68788 L p .64236 .69512 L .707 .577 .707 r
F P
0 g
s
.64087 .69109 m .6542 .7269 L .66528 .72649 L p .707 .577 .707 r
F P
0 g
s
.81457 .75008 m .811 .76786 L .82728 .76144 L p .707 .577 .707 r
F P
0 g
s
.82728 .76144 m .83084 .74367 L .81457 .75008 L p .707 .577 .707 r
F P
0 g
s
.64965 .55166 m .63639 .60409 L .63887 .61605 L p .707 .577 .707 r
F P
0 g
s
.64037 .70507 m .63681 .72285 L .64898 .73503 L p .707 .577 .707 r
F P
0 g
s
.63639 .60409 m .64965 .55166 L .65688 .54212 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83084 .74367 m .82728 .76144 L .83446 .75212 L p .707 .577 .707 r
F P
0 g
s
.83446 .75212 m .83802 .73435 L .83084 .74367 L p .707 .577 .707 r
F P
0 g
s
.63681 .72285 m .64037 .70507 L .63774 .69377 L p .707 .577 .707 r
F P
0 g
s
.63894 .68788 m .65228 .72368 L .6542 .7269 L p .707 .577 .707 r
F P
0 g
s
.65688 .54212 m .64362 .59455 L .63639 .60409 L p .707 .577 .707 r
F P
0 g
s
.63774 .69377 m .63418 .71154 L .63681 .72285 L p .707 .577 .707 r
F P
0 g
s
.64362 .59455 m .65688 .54212 L .6731 .53593 L p .707 .577 .707 r
F P
0 g
s
.38484 .62669 m .3981 .57426 L .36784 .56493 L p .707 .577 .707 r
F P
0 g
s
.3981 .57426 m .38484 .62669 L .41289 .63205 L p .707 .577 .707 r
F P
0 g
s
.41562 .63184 m .41549 .63141 L .41289 .63205 L .707 .577 .707 r
F
.41549 .63141 m .3981 .57426 L .41214 .62913 L F
.41549 .63141 m .41214 .62913 L .41289 .63205 L F
.40286 .64477 m .41606 .6318 L .38433 .63424 L F
.42572 .65776 m .41606 .6318 L p .40286 .64477 L F P
0 g
s
.45359 .64609 m .42642 .63017 L .41606 .6318 L .707 .577 .707 r
F
.44261 .62763 m .43774 .61049 L .41676 .63169 L F
.42911 .58018 m .41606 .6318 L p .43774 .61049 L F P
0 g
s
.41606 .6318 m .42572 .65776 L .4433 .65039 L p .707 .577 .707 r
F P
0 g
s
.4433 .65039 m .45359 .64609 L p .41606 .6318 L .707 .577 .707 r
F P
0 g
s
.41606 .6318 m .41585 .63261 L p .41676 .63169 L .707 .577 .707 r
F P
0 g
s
.43774 .61049 m .41606 .6318 L .41676 .63169 L .707 .577 .707 r
F
.42911 .58018 m .3981 .57426 L p .41549 .63141 L F P
0 g
s
.41585 .63261 m .41606 .6318 L p .41549 .63141 L .707 .577 .707 r
F P
0 g
s
.41606 .6318 m .42911 .58018 L p .41549 .63141 L .707 .577 .707 r
F P
0 g
s
.43665 .63616 m .44649 .62702 L .42642 .63017 L .707 .577 .707 r
F
.45359 .64609 m .44649 .62702 L p .43665 .63616 L F P
0 g
s
.45359 .64609 m .47667 .63511 L p .46535 .6274 L .707 .577 .707 r
F P
0 g
s
.46605 .62183 m .4638 .61094 L .45187 .62559 L .707 .577 .707 r
F
.45784 .58212 m .44649 .62702 L p .4638 .61094 L F P
0 g
s
.4638 .61094 m .44649 .62702 L .45187 .62559 L .707 .577 .707 r
F
.45784 .58212 m .42911 .58018 L p .44181 .62483 L F P
0 g
s
.44458 .63455 m .44649 .62702 L p .44181 .62483 L .707 .577 .707 r
F P
0 g
s
.44649 .62702 m .45784 .58212 L p .44181 .62483 L .707 .577 .707 r
F P
0 g
s
.47667 .63511 m .47121 .62047 L p .45967 .62352 L .707 .577 .707 r
F P
0 g
s
.48147 .57989 m .45784 .58212 L p .46524 .61794 L .707 .577 .707 r
F P
0 g
s
.46821 .63232 m .47121 .62047 L p .46524 .61794 L .707 .577 .707 r
F P
0 g
s
.47121 .62047 m .48147 .57989 L p .46524 .61794 L .707 .577 .707 r
F P
0 g
s
.48293 .62344 m .48146 .61573 L .47121 .62047 L .707 .577 .707 r
F
.4927 .62591 m .485 .61893 L .48293 .62344 L F
.485 .61893 m .48146 .61573 L .48293 .62344 L F
.47121 .62047 m .47667 .63511 L .48904 .62801 L p F P
0 g
s
.48904 .62801 m .4927 .62591 L p .47121 .62047 L .707 .577 .707 r
F P
0 g
s
.48371 .61469 m .48317 .60633 L .47642 .61806 L .707 .577 .707 r
F
.48147 .57989 m .47121 .62047 L p .48317 .60633 L F P
0 g
s
.48317 .60633 m .47121 .62047 L .47642 .61806 L .707 .577 .707 r
F
.47937 .5901 m .46333 .59931 L p .48146 .61573 L F P
0 g
s
.4927 .62591 m .48781 .61279 L p .48146 .61573 L .707 .577 .707 r
F P
0 g
s
.4977 .5737 m .48147 .57989 L p .48341 .61013 L .707 .577 .707 r
F P
0 g
s
.48444 .62613 m .48781 .61279 L p .48341 .61013 L .707 .577 .707 r
F P
0 g
s
.48781 .61279 m .4977 .5737 L p .48341 .61013 L .707 .577 .707 r
F P
0 g
s
.4945 .61637 m .49198 .60789 L .48781 .61279 L .707 .577 .707 r
F
.50012 .61938 m .49457 .61155 L .4945 .61637 L F
.49457 .61155 m .49198 .60789 L .4945 .61637 L F
.48781 .61279 m .4927 .62591 L .49955 .61988 L p F P
0 g
s
.49955 .61988 m .50012 .61938 L p .48781 .61279 L .707 .577 .707 r
F P
0 g
s
.49307 .60661 m .49414 .59898 L .49022 .60996 L .707 .577 .707 r
F
.4977 .5737 m .48781 .61279 L p .49414 .59898 L F P
0 g
s
.49414 .59898 m .48781 .61279 L .49022 .60996 L .707 .577 .707 r
F
.48678 .58357 m .47937 .5901 L p .49198 .60789 L F P
0 g
s
.50012 .61938 m .49466 .60473 L p .49198 .60789 L .707 .577 .707 r
F P
0 g
s
.50493 .56416 m .4977 .5737 L p .49378 .60159 L .707 .577 .707 r
F P
0 g
s
.49167 .61659 m .49466 .60473 L p .49378 .60159 L .707 .577 .707 r
F P
0 g
s
.49466 .60473 m .50493 .56416 L p .49378 .60159 L .707 .577 .707 r
F P
0 g
s
.50012 .61938 m .4982 .61616 L p .49665 .61174 L .707 .577 .707 r
F P
0 g
s
.49466 .60473 m .48678 .58357 L p .49198 .60789 L .707 .577 .707 r
F P
0 g
s
.49166 .60979 m .49167 .61659 L p .49307 .60661 L .707 .577 .707 r
F P
0 g
s
.49167 .61659 m .49071 .61195 L .48444 .62613 L .707 .577 .707 r
F
.49307 .60661 m .49022 .60996 L .48444 .62613 L F
.47937 .5901 m .48781 .61279 L p .49198 .60789 L F P
0 g
s
.49167 .61659 m .48919 .60463 L p .49165 .59829 L .707 .577 .707 r
F P
0 g
s
.48678 .58357 m .49466 .60473 L p .49279 .60072 L .707 .577 .707 r
F P
0 g
s
.49165 .59829 m .49342 .60206 L .49167 .61659 L .707 .577 .707 r
F
.48486 .58036 m .48678 .58357 L p .49279 .60072 L F P
0 g
s
.49466 .60473 m .49167 .61659 L p .49342 .60206 L .707 .577 .707 r
F P
0 g
s
.4911 .59709 m .48486 .58036 L p .49279 .60072 L .707 .577 .707 r
F P
0 g
s
.50245 .5522 m .50493 .56416 L p .49364 .59318 L .707 .577 .707 r
F P
0 g
s
.48919 .60463 m .4911 .59709 L p .49364 .59318 L .707 .577 .707 r
F P
0 g
s
.4911 .59709 m .50245 .5522 L p .49364 .59318 L .707 .577 .707 r
F P
0 g
s
.48781 .61279 m .48444 .62613 L p .49022 .60996 L .707 .577 .707 r
F P
0 g
s
.48781 .61279 m .47937 .5901 L p .48146 .61573 L .707 .577 .707 r
F P
0 g
s
.4982 .61616 m .48712 .61657 L p .48636 .60437 L .707 .577 .707 r
F P
0 g
s
.48919 .60463 m .47725 .59142 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.48486 .58036 m .4911 .59709 L p .48575 .59455 L .707 .577 .707 r
F P
0 g
s
.4911 .59709 m .48919 .60463 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.47379 .58077 m .48486 .58036 L p .48575 .59455 L .707 .577 .707 r
F P
0 g
s
.47725 .59142 m .47746 .59061 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.48712 .61657 m .47746 .59061 L p .48575 .59455 L .707 .577 .707 r
F P
0 g
s
.47746 .59061 m .47379 .58077 L p .48575 .59455 L .707 .577 .707 r
F P
0 g
s
.49051 .53899 m .50245 .5522 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.47746 .59061 m .49051 .53899 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.50245 .5522 m .4911 .59709 L p .4777 .59073 L .707 .577 .707 r
F P
0 g
s
.48636 .60437 m .48575 .59455 L .4911 .59709 L .707 .577 .707 r
F
.4911 .59709 m .4982 .61616 L p .48636 .60437 L F P
0 g
s
.4982 .61616 m .4911 .59709 L p .49279 .60072 L .707 .577 .707 r
F P
0 g
s
.49487 .59003 m .49466 .60473 L .49342 .60206 L .707 .577 .707 r
F
.49165 .59829 m .49487 .59003 L .49342 .60206 L F
.49665 .61174 m .49279 .60072 L .49466 .60473 L F
.49466 .60473 m .50012 .61938 L p .49665 .61174 L F P
0 g
s
.50493 .56416 m .49466 .60473 L p .49487 .59003 L .707 .577 .707 r
F P
0 g
s
.47121 .62047 m .46821 .63232 L p .47642 .61806 L .707 .577 .707 r
F P
0 g
s
.46821 .63232 m .48444 .62613 L p .48371 .61469 L .707 .577 .707 r
F P
0 g
s
.48371 .61469 m .47642 .61806 L .46821 .63232 L .707 .577 .707 r
F
.46333 .59931 m .47121 .62047 L p .48146 .61573 L F P
0 g
s
.46333 .59931 m .44025 .61028 L p .45967 .62352 L .707 .577 .707 r
F P
0 g
s
.47121 .62047 m .46333 .59931 L p .45967 .62352 L .707 .577 .707 r
F P
0 g
s
.44649 .62702 m .45359 .64609 L p .45967 .62352 L .707 .577 .707 r
F P
0 g
s
.44649 .62702 m .44458 .63455 L p .45187 .62559 L .707 .577 .707 r
F P
0 g
s
.46535 .6274 m .45967 .62352 L .45548 .63906 L .707 .577 .707 r
F
.46535 .6274 m .45548 .63906 L .45359 .64609 L F
.44025 .61028 m .44649 .62702 L p .45967 .62352 L F P
0 g
s
.44458 .63455 m .46821 .63232 L p .46605 .62183 L .707 .577 .707 r
F P
0 g
s
.46605 .62183 m .45187 .62559 L .44458 .63455 L .707 .577 .707 r
F
.44025 .61028 m .41239 .62195 L p .42642 .63017 L F P
0 g
s
.44649 .62702 m .44025 .61028 L p .42642 .63017 L .707 .577 .707 r
F P
0 g
s
.41239 .62195 m .41606 .6318 L p .42642 .63017 L .707 .577 .707 r
F P
0 g
s
.41585 .63261 m .44458 .63455 L p .44261 .62763 L .707 .577 .707 r
F P
0 g
s
.44261 .62763 m .41676 .63169 L .41585 .63261 L .707 .577 .707 r
F
.41239 .62195 m .38247 .63318 L p .38433 .63424 L F P
0 g
s
.41606 .6318 m .41239 .62195 L p .38433 .63424 L .707 .577 .707 r
F P
0 g
s
.41289 .63205 m .41585 .63261 L p .41562 .63184 L .707 .577 .707 r
F P
0 g
s
.35458 .61736 m .36784 .56493 L .34129 .5531 L p .707 .577 .707 r
F P
0 g
s
.36784 .56493 m .35458 .61736 L .38484 .62669 L p .707 .577 .707 r
F P
0 g
s
.65228 .72368 m .63894 .68788 L .64636 .68135 L p .707 .577 .707 r
F P
0 g
s
.83802 .73435 m .83446 .75212 L .83183 .74082 L p .707 .577 .707 r
F P
0 g
s
.83183 .74082 m .83539 .72305 L .83802 .73435 L p .707 .577 .707 r
F P
0 g
s
.63418 .71154 m .63774 .69377 L .64492 .68446 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.64636 .68135 m .6597 .71715 L .65228 .72368 L p .707 .577 .707 r
F P
0 g
s
.6731 .53593 m .65985 .58836 L .64362 .59455 L p .707 .577 .707 r
F P
0 g
s
.64492 .68446 m .64136 .70223 L .63418 .71154 L p .707 .577 .707 r
F P
0 g
s
.32803 .60553 m .34129 .5531 L .32106 .53995 L p .707 .577 .707 r
F P
0 g
s
.34129 .5531 m .32803 .60553 L .35458 .61736 L p .707 .577 .707 r
F P
0 g
s
.65985 .58836 m .6731 .53593 L .69674 .5337 L p .707 .577 .707 r
F P
0 g
s
.83013 .65321 m .81099 .6572 L p .8155 .6263 L .707 .577 .707 r
F P
0 g
s
.8168 .6174 m .8205 .62735 L p .8155 .6263 L .707 .577 .707 r
F P
0 g
s
.8205 .62735 m .82026 .6283 L .81798 .62682 L p .707 .577 .707 r
F P
0 g
s
.8205 .62735 m .83013 .65321 L p .8155 .6263 L .707 .577 .707 r
F P
0 g
s
.81099 .6572 m .79765 .6214 L .8168 .6174 L p .707 .577 .707 r
F P
0 g
s
.83352 .57587 m .8205 .62735 L p .80003 .61514 L .707 .577 .707 r
F P
0 g
s
.81798 .62682 m .80003 .61514 L p .8205 .62735 L .707 .577 .707 r
F P
0 g
s
.80003 .61514 m .81329 .56271 L .83352 .57587 L p .707 .577 .707 r
F P
0 g
s
.3958 .66899 m .38247 .63318 L .35341 .64286 L p .707 .577 .707 r
F P
0 g
s
.38247 .63318 m .3958 .66899 L .42572 .65776 L p .707 .577 .707 r
F P
0 g
s
.35341 .64286 m .36675 .67867 L .3958 .66899 L p .707 .577 .707 r
F P
0 g
s
.36675 .67867 m .35341 .64286 L .32807 .65005 L p .707 .577 .707 r
F P
0 g
s
.6597 .71715 m .64636 .68135 L .6624 .67214 L p .707 .577 .707 r
F P
0 g
s
.83539 .72305 m .83183 .74082 L .81966 .72864 L p .707 .577 .707 r
F P
0 g
s
.81966 .72864 m .82322 .71087 L .83539 .72305 L p .707 .577 .707 r
F P
0 g
s
.32807 .65005 m .34141 .68586 L .36675 .67867 L p .707 .577 .707 r
F P
0 g
s
.64136 .70223 m .64492 .68446 L .6612 .67804 L p .707 .577 .707 r
F P
0 g
s
.32106 .53995 m .3078 .59238 L .32803 .60553 L p .707 .577 .707 r
F P
0 g
s
.3078 .59238 m .32106 .53995 L .30912 .52674 L p .707 .577 .707 r
F P
0 g
s
.69674 .5337 m .68348 .58612 L .65985 .58836 L p .707 .577 .707 r
F P
0 g
s
.6624 .67214 m .67573 .70795 L .6597 .71715 L p .707 .577 .707 r
F P
0 g
s
.68348 .58612 m .69674 .5337 L .72547 .53564 L p .707 .577 .707 r
F P
0 g
s
.81329 .56271 m .80003 .61514 L .77348 .60332 L p .707 .577 .707 r
F P
0 g
s
.77348 .60332 m .78674 .55089 L .81329 .56271 L p .707 .577 .707 r
F P
0 g
s
.38395 .72769 m .38751 .70992 L .35692 .70202 L p .707 .577 .707 r
F P
0 g
s
.38751 .70992 m .38395 .72769 L .41525 .73233 L p .707 .577 .707 r
F P
0 g
s
.41525 .73233 m .41881 .71456 L .38751 .70992 L p .707 .577 .707 r
F P
0 g
s
.6612 .67804 m .65763 .69581 L .64136 .70223 L p .707 .577 .707 r
F P
0 g
s
.41881 .71456 m .41525 .73233 L .44421 .73325 L p .707 .577 .707 r
F P
0 g
s
.44421 .73325 m .44777 .71547 L .41881 .71456 L p .707 .577 .707 r
F P
0 g
s
.35336 .71979 m .35692 .70202 L .33005 .69162 L p .707 .577 .707 r
F P
0 g
s
.35692 .70202 m .35336 .71979 L .38395 .72769 L p .707 .577 .707 r
F P
0 g
s
.34141 .68586 m .32807 .65005 L .30893 .65405 L p .707 .577 .707 r
F P
0 g
s
.33005 .69162 m .32649 .70939 L .35336 .71979 L p .707 .577 .707 r
F P
0 g
s
.71221 .58807 m .72547 .53564 L .75648 .54156 L p .707 .577 .707 r
F P
0 g
s
.72547 .53564 m .71221 .58807 L .68348 .58612 L p .707 .577 .707 r
F P
0 g
s
.32649 .70939 m .33005 .69162 L .30953 .67975 L p .707 .577 .707 r
F P
0 g
s
.30893 .65405 m .32227 .68986 L .34141 .68586 L p .707 .577 .707 r
F P
0 g
s
.78674 .55089 m .77348 .60332 L .74322 .59399 L p .707 .577 .707 r
F P
0 g
s
.74322 .59399 m .75648 .54156 L .78674 .55089 L p .707 .577 .707 r
F P
0 g
s
.30912 .52674 m .29586 .57917 L .3078 .59238 L p .707 .577 .707 r
F P
0 g
s
.75648 .54156 m .74322 .59399 L .71221 .58807 L p .707 .577 .707 r
F P
0 g
s
.44777 .71547 m .44421 .73325 L .46799 .73036 L p .707 .577 .707 r
F P
0 g
s
.46799 .73036 m .47156 .71258 L .44777 .71547 L p .707 .577 .707 r
F P
0 g
s
.67573 .70795 m .6624 .67214 L .68548 .66117 L p .707 .577 .707 r
F P
0 g
s
.82322 .71087 m .81966 .72864 L .79914 .71677 L p .707 .577 .707 r
F P
0 g
s
.79914 .71677 m .8027 .699 L .82322 .71087 L p .707 .577 .707 r
F P
0 g
s
.69881 .69698 m .67573 .70795 L p .68486 .66413 L .707 .577 .707 r
F P
0 g
s
.68548 .66117 m .68697 .66519 L p .68486 .66413 L .707 .577 .707 r
F P
0 g
s
.68697 .66519 m .69881 .69698 L p .68486 .66413 L .707 .577 .707 r
F P
0 g
s
.69881 .69698 m .68548 .66117 L .71334 .6495 L p .707 .577 .707 r
F P
0 g
s
.71334 .6495 m .72667 .68531 L .69881 .69698 L p .707 .577 .707 r
F P
0 g
s
.68142 .69292 m .68498 .67515 L .70837 .67589 L p .707 .577 .707 r
F P
0 g
s
.70837 .67589 m .71394 .67607 L p .71138 .67739 L .707 .577 .707 r
F P
0 g
s
.68142 .69292 m .70837 .67589 L .71138 .67739 L .707 .577 .707 r
F
.65763 .69581 m .6612 .67804 L .68498 .67515 L p F P
0 g
s
.79765 .6214 m .81099 .6572 L .78565 .6644 L p .707 .577 .707 r
F P
0 g
s
.78565 .6644 m .77232 .62859 L .79765 .6214 L p .707 .577 .707 r
F P
0 g
s
.29586 .57917 m .30912 .52674 L .30664 .51478 L p .707 .577 .707 r
F P
0 g
s
.30953 .67975 m .30597 .69753 L .32649 .70939 L p .707 .577 .707 r
F P
0 g
s
.68498 .67515 m .68142 .69292 L .65763 .69581 L p .707 .577 .707 r
F P
0 g
s
.32227 .68986 m .30893 .65405 L .29786 .65446 L p .707 .577 .707 r
F P
0 g
s
.30597 .69753 m .30894 .68268 L p .29736 .66757 L .707 .577 .707 r
F P
0 g
s
.30894 .68268 m .30953 .67975 L .30664 .67686 L p .707 .577 .707 r
F P
0 g
s
.30664 .67686 m .29736 .66757 L p .30894 .68268 L .707 .577 .707 r
F P
0 g
s
.31119 .69026 m .29924 .65818 L p .29593 .65124 L .707 .577 .707 r
F P
0 g
s
.29924 .65818 m .29786 .65446 L .2976 .65403 L p .707 .577 .707 r
F P
0 g
s
.2976 .65403 m .29593 .65124 L p .29924 .65818 L .707 .577 .707 r
F P
0 g
s
.29786 .65446 m .31119 .69026 L .32227 .68986 L p .707 .577 .707 r
F P
0 g
s
.47156 .71258 m .46799 .73036 L .48427 .72394 L p .707 .577 .707 r
F P
0 g
s
.48427 .72394 m .48783 .70617 L .47156 .71258 L p .707 .577 .707 r
F P
0 g
s
.77232 .62859 m .78565 .6644 L .7566 .67408 L p .707 .577 .707 r
F P
0 g
s
.7566 .67408 m .74326 .63827 L .77232 .62859 L p .707 .577 .707 r
F P
0 g
s
.8027 .699 m .79914 .71677 L .77227 .70638 L p .707 .577 .707 r
F P
0 g
s
.77227 .70638 m .77583 .68861 L .8027 .699 L p .707 .577 .707 r
F P
0 g
s
.30664 .51478 m .29338 .56721 L .29586 .57917 L p .707 .577 .707 r
F P
0 g
s
.29736 .66757 m .2938 .68535 L .30597 .69753 L p .707 .577 .707 r
F P
0 g
s
.72667 .68531 m .71334 .6495 L .74326 .63827 L p .707 .577 .707 r
F P
0 g
s
.71394 .67607 m .71038 .69384 L .68142 .69292 L p .707 .577 .707 r
F P
0 g
s
.74326 .63827 m .7566 .67408 L .72667 .68531 L p .707 .577 .707 r
F P
0 g
s
.29338 .56721 m .30664 .51478 L .31387 .50524 L p .707 .577 .707 r
F P
0 g
s
.77583 .68861 m .77227 .70638 L .74168 .69848 L p .707 .577 .707 r
F P
0 g
s
.74168 .69848 m .74524 .6807 L .77583 .68861 L p .707 .577 .707 r
F P
0 g
s
.71038 .69384 m .71394 .67607 L .74524 .6807 L p .707 .577 .707 r
F P
0 g
s
.74524 .6807 m .74168 .69848 L .71038 .69384 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.48783 .70617 m .48427 .72394 L .49145 .71462 L p .707 .577 .707 r
F P
0 g
s
.49145 .71462 m .49501 .69685 L .48783 .70617 L p .707 .577 .707 r
F P
0 g
s
.2938 .68535 m .29736 .66757 L .29473 .65627 L p .707 .577 .707 r
F P
0 g
s
.29593 .65124 m .30927 .68705 L .31119 .69026 L p .707 .577 .707 r
F P
0 g
s
.31387 .50524 m .30061 .55767 L .29338 .56721 L p .707 .577 .707 r
F P
0 g
s
.29473 .65627 m .29117 .67404 L .2938 .68535 L p .707 .577 .707 r
F P
0 g
s
.30061 .55767 m .31387 .50524 L .33009 .49905 L p .707 .577 .707 r
F P
0 g
s
.30927 .68705 m .29593 .65124 L .30335 .64471 L p .707 .577 .707 r
F P
0 g
s
.49501 .69685 m .49145 .71462 L .48882 .70332 L p .707 .577 .707 r
F P
0 g
s
.48882 .70332 m .49238 .68555 L .49501 .69685 L p .707 .577 .707 r
F P
0 g
s
.29117 .67404 m .29473 .65627 L .30191 .64696 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30335 .64471 m .31669 .68052 L .30927 .68705 L p .707 .577 .707 r
F P
0 g
s
.33009 .49905 m .31683 .55148 L .30061 .55767 L p .707 .577 .707 r
F P
0 g
s
.30191 .64696 m .29835 .66473 L .29117 .67404 L p .707 .577 .707 r
F P
0 g
s
.31683 .55148 m .33009 .49905 L .35373 .49682 L p .707 .577 .707 r
F P
0 g
s
.48712 .61657 m .46798 .62057 L p .4725 .58958 L .707 .577 .707 r
F P
0 g
s
.47379 .58077 m .47746 .59061 L p .4725 .58958 L .707 .577 .707 r
F P
0 g
s
.47746 .59061 m .47725 .59142 L .47531 .59017 L p .707 .577 .707 r
F P
0 g
s
.47746 .59061 m .48712 .61657 L p .4725 .58958 L .707 .577 .707 r
F P
0 g
s
.46798 .62057 m .45464 .58476 L .47379 .58077 L p .707 .577 .707 r
F P
0 g
s
.49051 .53899 m .47746 .59061 L p .45702 .57827 L .707 .577 .707 r
F P
0 g
s
.47531 .59017 m .45702 .57827 L p .47746 .59061 L .707 .577 .707 r
F P
0 g
s
.45702 .57827 m .47028 .52584 L .49051 .53899 L p .707 .577 .707 r
F P
0 g
s
.31669 .68052 m .30335 .64471 L .31939 .63551 L p .707 .577 .707 r
F P
0 g
s
.49238 .68555 m .48882 .70332 L .47665 .69114 L p .707 .577 .707 r
F P
0 g
s
.47665 .69114 m .48021 .67337 L .49238 .68555 L p .707 .577 .707 r
F P
0 g
s
.29835 .66473 m .30191 .64696 L .31818 .64054 L p .707 .577 .707 r
F P
0 g
s
.35373 .49682 m .34047 .54925 L .31683 .55148 L p .707 .577 .707 r
F P
0 g
s
.31939 .63551 m .33272 .67131 L .31669 .68052 L p .707 .577 .707 r
F P
0 g
s
.34047 .54925 m .35373 .49682 L .38246 .49876 L p .707 .577 .707 r
F P
0 g
s
.47028 .52584 m .45702 .57827 L .43047 .56644 L p .707 .577 .707 r
F P
0 g
s
.43047 .56644 m .44373 .51402 L .47028 .52584 L p .707 .577 .707 r
F P
0 g
s
.31818 .64054 m .31462 .65831 L .29835 .66473 L p .707 .577 .707 r
F P
0 g
s
.3692 .55119 m .38246 .49876 L .41347 .50468 L p .707 .577 .707 r
F P
0 g
s
.38246 .49876 m .3692 .55119 L .34047 .54925 L p .707 .577 .707 r
F P
0 g
s
.44373 .51402 m .43047 .56644 L .40021 .55711 L p .707 .577 .707 r
F P
0 g
s
.40021 .55711 m .41347 .50468 L .44373 .51402 L p .707 .577 .707 r
F P
0 g
s
.41347 .50468 m .40021 .55711 L .3692 .55119 L p .707 .577 .707 r
F P
0 g
s
.33272 .67131 m .31939 .63551 L .34246 .62453 L p .707 .577 .707 r
F P
0 g
s
.48021 .67337 m .47665 .69114 L .45613 .67927 L p .707 .577 .707 r
F P
0 g
s
.45613 .67927 m .45969 .6615 L .48021 .67337 L p .707 .577 .707 r
F P
0 g
s
.3558 .66034 m .33272 .67131 L p .34189 .62727 L .707 .577 .707 r
F P
0 g
s
.34246 .62453 m .34385 .62825 L p .34189 .62727 L .707 .577 .707 r
F P
0 g
s
.34385 .62825 m .3558 .66034 L p .34189 .62727 L .707 .577 .707 r
F P
0 g
s
.3558 .66034 m .34246 .62453 L .37033 .61286 L p .707 .577 .707 r
F P
0 g
s
.37033 .61286 m .38366 .64867 L .3558 .66034 L p .707 .577 .707 r
F P
0 g
s
.33841 .65542 m .34197 .63765 L .36404 .63835 L p .707 .577 .707 r
F P
0 g
s
.36404 .63835 m .37093 .63857 L p .36776 .64021 L .707 .577 .707 r
F P
0 g
s
.33841 .65542 m .36404 .63835 L .36776 .64021 L .707 .577 .707 r
F
.31462 .65831 m .31818 .64054 L .34197 .63765 L p F P
0 g
s
.45464 .58476 m .46798 .62057 L .44264 .62776 L p .707 .577 .707 r
F P
0 g
s
.44264 .62776 m .42931 .59195 L .45464 .58476 L p .707 .577 .707 r
F P
0 g
s
.34197 .63765 m .33841 .65542 L .31462 .65831 L p .707 .577 .707 r
F P
0 g
s
.42931 .59195 m .44264 .62776 L .41359 .63744 L p .707 .577 .707 r
F P
0 g
s
.41359 .63744 m .40025 .60163 L .42931 .59195 L p .707 .577 .707 r
F P
0 g
s
.45969 .6615 m .45613 .67927 L .42926 .66888 L p .707 .577 .707 r
F P
0 g
s
.42926 .66888 m .43282 .65111 L .45969 .6615 L p .707 .577 .707 r
F P
0 g
s
.37093 .63857 m .36737 .65634 L .33841 .65542 L p .707 .577 .707 r
F P
0 g
s
.38366 .64867 m .37033 .61286 L .40025 .60163 L p .707 .577 .707 r
F P
0 g
s
.40025 .60163 m .41359 .63744 L .38366 .64867 L p .707 .577 .707 r
F P
0 g
s
.43282 .65111 m .42926 .66888 L .39867 .66098 L p .707 .577 .707 r
F P
0 g
s
.39867 .66098 m .40223 .6432 L .43282 .65111 L p .707 .577 .707 r
F P
0 g
s
.36737 .65634 m .37093 .63857 L .40223 .6432 L p .707 .577 .707 r
F P
0 g
s
.40223 .6432 m .39867 .66098 L .36737 .65634 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
PGoo7P00OWoo001kOol60002FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07Eoo`H000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEPD007=oo`00L7oo1@00
0UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1000Kgoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP04FUH3001/Ool006]oo`<000UJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP<006Yoo`00JGoo0P000UYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00P00J7oo001WOol20004FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomo
o`1UOol006Ioo`8000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IGoo00<0
05YF00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000
FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP00
1EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<0
05YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH0
1eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YFOol0IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0
IGoo001TOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001T
Ool01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol20000
0eYF001JEP04FUH00`00FUIJEP07FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH0
05YF00AJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH0
15YF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH0
0`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEUYF001JEVIoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01eYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00H005YFFUIJEP00FUIVOol006Aoo`800003FUH005YF00EJEP03001JEUYF00MJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP06001JEUYFFUH0
05YFIWoo001TOol200000eYF00000005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Aoo`800003FUH0000000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Aoo`00
I7oo0P0000=JEP0000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol0
1000FUH000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<007ooOol0I7oo001UOol01000FUH0
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUH000001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUH000001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUH000001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUH0
00001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJ
EP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YF
FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo
001UOol01000FUIJEP001EYF00<005YFFUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001MOolB0009FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH2001UOol005]oo`<000IJEP03001JEUYF00EJEP03001JEUYF00@000EJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP8006Eoo`00FGoo0P000UYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01EYF
100000=JEP00FUH02UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001HOol20002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP07FUH00`00FUH00002000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Qoo`05001JEUYFFUH00006FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Moo`8000=JEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP<000AJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00Egoo0P000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YF0000009J
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8006Eoo`00EWoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01UYF00<005YFFUH00UYF0`0035YF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF0P00IGoo001FOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH0
0`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH2000;FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2001UOol005Ioo`8000=JEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP<000UJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8006Eoo`00EWoo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00D0
05YFFUIJEP0000QJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP8000]oo`L005=oo`00EGoo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF0P001UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001Woo1@000eYF00@005YFFUIJEPL0
04aoo`00EGoo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P0017oo0P0000=JEP00FUH015YF00<005YFFUH01UYF
00<005YFFUH01000B7oo001EOol20003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06
FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH20004FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002Ool20002FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP05FUH40014Ool005Eoo`03FUH005YF009JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00AJEP03001J
EP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003
Ool0000000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP0000<0041o
o`00E7oo00<005YFFUH00UYF4P001eYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF
00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP@000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEP<003eo
o`00E7oo0P0000EJEP00001JEP0000IJEP80009oo`04001JEUYF0002FUH40002FUH00`00FUIJEP07
FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00FUIJEUYF00000UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF100015YF00<005YFFUH00eYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01UYF0`00>goo001DOol00eYF00000003FUH00`00FUIJEP04FUH0
0`00FUH000020002FUH00`00FUIJEP03FUH50008FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01@00
FUIJEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
0P0000=JEP00FUH00UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1EYF00@005YFFUIJEP8003Uoo`00E7oo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF0P0000=J
EP00FUH015YF100000AJEP00000000EJEP03001JEUYF00AJEP03001JEUYF00AJEP09001JEUYFFUH0
05YF001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP800003FUH005YF
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF
00=JEP8003Moo`00Dgoo0`000eYF00<005YFFUH015YF00<005YFFUH015YF0`0015YF1@000eYF0`00
00=JEP00FUH01UYF00<005YFFUH015YF00T005YFFUIJEP00FUH005YF00002eYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P00=Goo001COol00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUH0000200000eYF000000030005FUH40006FUH00`00FUIJEP04
FUH02@00FUIJEUYF001JEP00FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH30004FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH3000cOol005=oo`03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001J
EUYF00=JEPH000EJEP04001JEUYFFUH20004FUH00`00FUIJEP03FUH00`00FUIJEP02FUH20002FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH0
0`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP06FUH0
1000FUIJEUYF0P00<Goo001DOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF00<005YFFUH01EYF
10001EYF00<005YFFUH00eYF0P0000=JEP00FUH01EYF00L005YFFUIJEP00FUH00002FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH00003FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP03FUH00`00Oomoo`0^Ool005Aoo`05001JEUYFFUH00006FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUH0000300000eYF001JEP06FUH20006FUH01`00FUIJEUYF001JEP00009JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP80
02moo`00EGoo00@005YFFUH000IJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPd0
00AJEP07001JEUYFFUH005YF00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YF0000;Woo001EOol01000FUIJEP001UYF
00<005YFFUH015YF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF1P0000=JEP00FUH0
0eYF0P000eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH0
0003FUH01000FUIJEUYF1`0015YF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01UYF00<0
05YFFUH00eYF00D005YFFUIJEP0002eoo`00>Woo1`005Goo0P001UYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01UYF00<005YFFUH0100000=JEP00FUH00eYF0P000eYF00<005YF00000eYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00L005YFFUIJEP00FUH00002FUH50002
FUH20003Ool90004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH00`00Oomoo`0ZOol003Eoo`D000=JEP04001JEUYFFUH9000=Ool00`00FUIJEP04FUH00`00FUIJ
EP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH40006FUH00`00FUIJEP02FUH01`00FUIJEUYF001J
EP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYFFUH200001EYF
000005YF00001UYF0`002Woo1P001eYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH00UYF
00<007ooOol0:Woo000bOol300000eYF001JEP04FUH00`00FUIJEP06FUH00`00FUIJEP02FUH60008
Ool20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF001JEP06FUH0
0`00FUIJEP03FUH01P00FUIJEP00FUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP8000=JEP03001JEUYF00=JEP04001JEUYFFUH2000:Ool300000goo0000
0005FUH00`00FUIJEP05FUH00`00FUIJEP04FUH00`00FUIJEP02FUH2000[Ool0035oo`8000=JEP03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000Moo`05001JEUYFFUH0
0006FUH00`00FUIJEP07FUH01000FUIJEUYF0`001EYF00<005YFFUH01EYF00<005YFFUH00UYF00D0
05YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
00=JEP03001JEUYF00AJEP03001JEUYF00=JEP8000Moo`D0009oo`<00003FUH005YF00MJEP03001J
EUYF00AJEP07001JEUYFFUH005YF0000:goo000aOol01@00FUIJEUYF00001UYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH00eYF0`001Goo0`001eYF00<005YFFUH01eYF100025YF00<005YF
FUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP06001JEUYF001JEP000eYF00<005YFFUH015YF00<005YFFUH01EYF0`0017oo1@00
1Goo0`001eYF00<005YFFUH00eYF00<005YFFUH00UYF00<005YF0000:goo000`Ool20003FUH00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30004Ool20006FUH00`00
FUIJEP06FUH200000eYF001JEP08FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEP0015YF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00H005YFFUH005YF0003FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUH000080008Ool20005FUH00`00FUIJEP03FUH00`00FUIJEP02
FUH2000/Ool0031oo`8000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00MJEP04001JEP000004Ool20004FUH00`00FUIJEP03FUH30004FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP020003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01P00FUIJEP00FUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00AJEPD000Yoo`<00003FUH005YF00EJEP03001JEUYF009JEP8002aoo`00;goo00<005YF00000eYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH00UYF
0P0017oo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUH000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYF
FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP040009Ool2
0006FUH01`00FUIJEUYF001JEP0002aoo`00;goo0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0P0017oo1@0000=JEP00FUH025YF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01`000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00D005YFFUIJEP0000=JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF
00EJEP03001JEUYF00EJEPH000Eoo`03001JEUYF00=JEP07001JEUYFFUH005YF0000;7oo000_Ool2
0003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJ
EP05FUH30002Ool30004FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH400001EYF
001JEP00FUH00P000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00@005YFFUH000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00MJEP04001JEUYF
FUH80002FUH00`00FUIJEP02FUH2000]Ool002moo`8000=JEP03001JEUYF00=JEP03001JEUYF00EJ
EP03001JEUYF00MJEP03001JEUYF00MJEP03001JEUYF00AJEP03001JEUYF00<000MJEP03001JEUYF
00IJEP03001JEUYF00MJEP03001JEUYF00@00003FUH005YF009JEP04001JEP000005FUH00`00FUIJ
EP09FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20007FUH00`00FUIJEP06FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP0400000eYF001JEP03FUH00`00FUH00004FUH2
000]Ool002ioo`03001JEP0000=JEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP03001JEUYF00EJEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJ
EP@000EJEP03001JEUYF00800003FUH0000000EJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF009JEP<000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP<000IJEP03001JEUYF009JEP8000=JEP03001JEP0002eoo`00;Woo0P0015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH015YF0P000eYF0P0025YF
00<005YFFUH01UYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEPH00003FUH0000000MJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003Ool0000000AJEP03
001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP800003FUH005YF00IJEP03001JEUYF00=J
EP07001JEUYFFUH005YF0000;Goo000^Ool20004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20006FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUH0000:0004FUH30009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH20003Ool01@00FUIJEUYF000025YF00<005YFFUH01EYF00<005YFFUH00UYF0`00
15YF00<005YFFUH01EYF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Woo00=JEP00FUH00UYF
00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01eYF00@005YFFUIJEP80
00=JEQ0000IJEP@000MJEP03001JEUYF009JEP8000aJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP04001JEUYFFUH20004Ool30008FUH00`00FUIJEP06FUH00`00FUH000020007FUH0
0`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo000]Ool00`00FUIJEP03FUH01000
FUIJEUYF3@001eYF00<005YFFUH01UYF00<005YFFUH01`000eYF00<005YFFUH01EYF00<005YFFUH0
0UYF1P000eYF00<005YFFUH01UYF00H005YF000005YF000<FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01000FUIJEUYF0`001Goo00<005YFFUH01UYF00<005YFFUH01EYF0`0000=J
EP00FUH025YF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJEP0002ioo`00;Goo0P000UYF
1P000eYF0P0027oo10000UYF00<005YFFUH01eYF10000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YF00000`0025YF0P000eYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00@005YFFUIJEPD000Aoo`8000IJEP03001JEUYF009JEP<000EJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000^Ool002eoo`04
FUH000000002FUH00`00FUIJEP04FUH01000FUH000002Woo100025YF0P0015YF00<005YFFUH00eYF
00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH00UYF0`0015YF0P001EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUIJEP80
00Aoo`8000AJEP03001JEUYF008000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=J
EP03001JEUYF008002eoo`00;Goo0P000eYF00<005YFFUH015YF00<005YFFUH00UYF0P0027oo0`00
00Aoo`00000000EJEP8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001J
EUYF00IJEP@000MJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEUYF00=JEP8000Aoo`800003FUH005YF00<000YJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00L002eoo`00;7oo0`000eYF00<005YFFUH015YF00<005YFFUH0
15YF0`0017oo1@000goo0`0000=JEP00000015YF00@005YFFUIJEQ0000AJEP03001JEUYF00MJEP04
001JEP000006FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUIJEP05FUH20004Ool30003FUH00`00FUIJEP07FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH40002FUH01@00FUIJEUYF0000;Goo000/Ool00`00FUH00003FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUH0000200000goo000000030006Ool30003FUH60006FUH30006FUH6
0008FUH01000FUIJEUYF0P0015YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YFFUH01UYF0`0000=oo`0000001EYF00<005YFFUH01eYF
00<005YFFUH01eYF00<005YF00000`000UYF00H005YFFUIJEP00FUH2000^Ool002aoo`03001JEUYF
00=JEP03001JEUYF00AJEP03001JEUYF00AJEP03001JEUYF00=JEPH000Moo`800004FUH000000004
FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP06FUH01000FUIJEUYF0`0015YF00<005YFFUH015YF
0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P001UYF00<005YFFUH00P0025YF00<005YFFUH01eYF00<005YFFUH01EYF0`001EYF00@0
05YFFUIJEP800003FUH007oo02ioo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF00EJEP03001J
EUYF00EJEP@000Ioo`04001JEP000002FUH00`00FUIJEP03FUH01000FUH000001EYF00<005YFFUH0
1UYF00<005YF00000P0000IJEP00000005YF0007FUH4000<FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20006FUH40009FUH00`00FUIJEP07FUH00`00FUIJEP03
FUH200000eYF001JEP05FUH01000FUH000000UYF00<007ooOol0;Woo000]Ool01@00FUIJEUYF0000
1UYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF00000`000Woo10000eYF00<005YFFUH00UYF
0P001eYF00<005YFFUH01EYF0`001eYF0`001UYF00<005YFFUH00P002eYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF0P000eYF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YF00003`0000=JEP000000<Goo000^Ool01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH01UYF00<005YFFUH015YF0`0000AJEP00FUH0009JEP05001JEUYFFUH00002FUH0
0`00FUIJEP05FUH00`00FUIJEP050009FUH00`00FUIJEP020003FUH00`00FUIJEP03FUH20009FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH300000eYF
000000050007FUH00`00FUIJEP06FUH30008FUH00`00FUIJEP04FUH2000cOol002ioo`04001JEUYF
0006FUH00`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH00`00FUIJEP02FUH2
0003FUH00`00FUIJEP04FUH40004FUH00`00FUIJEP07FUH00`00FUIJEP02FUH200000eYF001JEP05
FUH20008FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH80003
FUH01000FUIJEUYF2@0015YF0`000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P00=Goo000_Ool2
0006FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH01@00FUIJEUYF0000
1EYF00<005YFFUH00UYF0P000UYF00<005YFFUH00eYF0`001eYF00<005YFFUH015YF0P001UYF00<0
05YF00001eYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@00
1UYF00<005YFFUH01EYF00<005YFFUH00UYF1`000UYF00<005YFFUH02EYF0P00=goo000`Ool00`00
FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30004FUH30006FUH01P00
FUH00000FUH0009JEP03001JEUYF009JEPD000IJEP03001JEUYF00IJEP8000=JEP05001JEUYFFUH0
0006FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEUYF0`000UYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH010001eYF0`00>Goo000aOol2
0004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH300000eYF00000002FUH20002
FUH01000FUIJEUYF100000AJEP00FUH0009JEP03001JEUYF009JEPD000IJEP03001JEUYF00QJEP80
0003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF00<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00AJEPL003aoo`00<goo00D005YFFUIJEP0000IJEP03001JEUYF00MJEP04001JEUYFFUH30005FUH0
1000FUH005YF1`000UYF00<005YFFUH00UYF00@005YFFUH000AJEPD000IJEP03001JEUYF00UJEP<0
00=JEP03001JEUYF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
00<0009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP04001J
EP00000mOol003Aoo`<000MJEP03001JEUYF00MJEP@000QJEP<000IJEP03001JEP00008000AJEP04
001JEUYF0005FUH30007FUH00`00FUIJEP09FUH02000FUIJEP00FUH005YF0005FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP020003FUHD0004FUH00`00FUIJEP07FUH0
1000FUIJEUYF0`00>Woo000fOol20006FUH00`00FUIJEP06FUH200000eYF001JEP08FUH00`00FUH0
0006FUH01000FUIJEUYF0`000UYF00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP08
001JEUYF001JEP00FUH000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF00800003FUH0000000EJEP03001JEUYF00AJEP8000IJEPL000IJEP03001JEUYF00EJEP8003Qo
o`00>7oo0P0015YF00<005YFFUH00eYF0`0015YF00<005YFFUH01UYF00<005YFFUH00P000eYF00<0
05YFFUH01EYF100000=JEP00FUH015YF00<005YFFUH01eYF00<005YFFUH02EYF00@005YFFUIJEP80
0003FUH005YF00AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF00<0
0003FUH005YF00AJEP03001JEUYF009JEP800003FUH005YF00QJEP03001JEP0000D0009JEP03001J
EUYF00IJEP8003Moo`00>Woo0P0000=JEP00FUH00UYF0`001eYF00<005YFFUH01eYF00@005YFFUIJ
EP800003FUH005YF00MJEP03001JEUYF00@000=JEP03001JEUYF00MJEP03001JEUYF00UJEP03001J
EUYF009JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EP0000<0009JEP03001JEUYF00=JEP04001JEP000004FUH00`00FUIJEP05FUH30006Ool40007FUH0
1000FUH00000=Goo000lOol500000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUIJEP03FUH30007
FUH00`00FUIJEP04FUH50008FUH00`00FUIJEP09FUH00`00FUIJEP040006FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUH000030002FUH00`00FUIJEP02FUH30006FUH00`00
FUIJEP03FUH2000=Ool20004FUH00`00FUIJEP02FUH00`00Oomoo`0bOol003aoo`<000AJEP03001J
EUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001JEUYF00MJEP03001JEUYF00@0
00AJEP03001JEUYF00MJEPD0009JEP8000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP04001JEP00FUH30002FUH01000FUH000000UYF00<005YFFUH01EYF00<005YF00000P004Goo
0`0000=JEP00FUH015YF00<007ooOol0<Goo000iOol30007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH00`00FUIJEP0400000eYF001JEP0300000eYF001JEP08FUH00`00FUIJEP04FUH>0003FUH01P00
FUIJEP00FUH000IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP04001JEP000002
FUH00`00FUIJEP020004FUH00`00FUIJEP04FUH30006Ool3000>Ool20005FUH2000bOol003Moo`80
0003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00EJEP@000EJEP03001JEUYF00H000IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP03001JEUYF008000MJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP04001JEUYF0002FUH01@00FUH005YF00001EYF00<005YF
000010001goo1@003goo00<005YFFUH00UYF00@005YF0000031oo`00=Goo0P000eYF0P0025YF00<0
05YFFUH01UYF00<005YFFUH00eYF0P000UYF00@005YFFUIJEPH00003FUH00000009oo`D0009JEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH00008FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01000FUIJEP000eYF00D005YFFUIJEP00009JEP@0009J
EP03001JEP0000Moo`D0011oo`800003FUH005YF00=JEP03001oogoo02eoo`00<goo0P001UYF00<0
05YFFUH01UYF00<005YFFUH01eYF00<005YF00002P0015YF0`0017oo00D005YFFUH005YF00D000IJ
EP03001JEUYF00EJEP03001JEUYF00AJEP04001JEP000009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH01@00FUIJEUYF00000UYF1`000eYF00<005YFFUH00UYF00<007ooOol01Goo
1@004Woo0P0015YF00<007ooOol0;Goo000bOol20003FUH?0007FUH40007FUH00`00FUIJEP02FUH2
0007Ool01000FUIJEP001EYF1@000UYF00<005YFFUH01EYF00@005YFFUIJEPD000]JEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00001UYF0P000UYF00D005YF
FUIJEP0000Uoo`<001Aoo`03001JEUYF009JEP8002ioo`00<7oo1`000eYF00<005YFFUH01EYF00<0
05YFFUH010000UYF0P000eYF00<005YFFUH01UYF00@005YF000000Uoo`04001JEUYF0005FUH00`00
FUIJEP02FUH>0003FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH20006FUH00`00FUH000020003FUH00`00Oomoo`0OOol01P00FUIJEP00FUH0
02ioo`00;goo0`0000=JEP00FUH01EYF00<005YFFUH01EYF00<005YFFUH015YF1@000UYF00<005YF
FUH01UYF0P002goo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP8000IJEP04001J
EUYFFUH20002FUH00`00Oomoo`0POol300000eYF001oo`0]Ool002ioo`8000=JEP03001JEUYF00=J
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000IJEP03001oogoo00]oo`04001JEUYF
0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH40003FUH00`00FUIJEP04FUH4000SOol00`00FUH0
000^Ool002eoo`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF
00AJEPH000ioo`04001JEUYF0005FUH00`00FUIJEP07FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH20002FUH200000eYF
001JEP06FUH00`00FUIJEP04000NOol3000_Ool002aoo`03001JEP0000=JEP04001JEUYFFUH>0006
FUH00`00FUIJEP07FUH01000FUH000003Woo00@005YFFUH000EJEP03001JEUYF00MJEP03001JEUYF
00MJEQh000QJEP03001JEUYF00IJEP03001JEUYF009JEP8000AJEP<000IJEP03001JEUYF00AJEPL0
01Eoo`800003FUH0000002moo`00;7oo0P000eYF1P001eYF0P0015YF10000UYF00<005YFFUH01eYF
00@005YFFUIJEP8000aoo`04001JEUYF0005FUH00`00FUIJEP07FUH01000FUIJEUYF1P002EYF00<0
05YFFUH02UYF00<005YFFUH01EYF1P000UYF00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF1000
0eYF00<005YFFUH01eYF00<005YFFUH00UYF200027oo1@000eYF0P00;goo000/Ool2000015YF0000
000015YF00<005YFFUH00eYF0P0000=JEP00FUH01eYF1@001UYF00<005YFFUH015YF0P002Woo00@0
05YFFUH000EJEP03001JEUYF00EJEPH000=JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEP0000@000IJEP03001JEUYF009JEP800003FUH00000008000AJEP800003FUH005YF
00QJEP03001JEUYF00IJEP04001JEUYFFUH80003FUH01000FUIJEUYF0P00<7oo000[Ool01000FUH0
00000UYF00<005YFFUH00UYF00@005YFFUIJEP8000AJEP03001JEUYF00IJEP03001JEP0000D0009J
EP03001JEUYF00EJEP<000Qoo`04001JEUYF0005FUH00`00FUIJEP050009FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP04FUH40002FUH00`00FUIJEP02FUH30005FUH0
1@00FUH00000FUH010001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00@005YF
FUIJEP80031oo`00:goo10000eYF00<005YFFUH00UYF0`001UYF00<005YFFUH01EYF0`001Woo1000
1UYF00<005YFFUH00P001Woo00@005YFFUH000EJEP<000=JEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEP00008000AJEP8000=JEPH0
0003FUH0000000=oo`@0009JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00=JEP04001J
EUYFFUH2000aOol002]oo`03001JEP000080009JEP03001JEUYF009JEP8000MJEP03001JEUYF00=J
EP8000eoo`8000=JEP03001JEUYF00=JEP8000Aoo`04001JEUYF0003FUH20006FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH20002FUH50005FUH20009Ool70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000
<goo000[Ool01@00FUH005YF00001EYF0P000UYF00<005YFFUH01EYF00<005YF00000P004Goo0P00
00=JEP00FUH01EYF0P000goo00D005YFFUH005YF008000QJEP03001JEUYF00QJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP@00003FUH005YF
00=JEP80019oo`P000AJEP04001JEUYFFUH5000eOol002]oo`80009JEP04001JEUYFFUH20004FUH0
0`00FUIJEP04FUH30005Ool3000>Ool20006FUH20003Ool00`00FUIJEP0200000eYF001JEP07FUH0
0`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH01000FUH0000015YF0P0077oo2000>Woo000/Ool00`00FUIJEP02FUH30006FUH0
0`00FUH000030007Ool5000?Ool20003FUH01000FUIJEP000Woo00<005YF00000eYF00<005YFFUH0
1UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1UYF00<005YFFUH015YF00D005YF000005YF00<0061oo`00;7oo00@005YFFUIJEP80009JEP04001J
EUYFFUH4000;Ool5000AOol200000eYF001JEP02FUH01000Ool0000015YF00<005YFFUH01UYF00<0
05YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YF00000P00Hgoo000]Ool00`00FUH00008000?Ool5000COol20003FUH01000
Ool0000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH01UYF00<005YFFUH015YF00@005YFFUH006Aoo`00;Woo0P001UYF00@0
05YF000000ioo`<001Ioo`03001JEUYF00@000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP03001JEUYF00AJEP03001J
EUYF00@0065oo`00;goo00<005YFFUH015YF00@005YFFUIJEP<002Aoo`04001JEP00FUH30004FUH0
0`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUH00004FUH2001OOol0031oo`8000=JEP03001JEUYF
00EJEP<0029oo`800004FUH007oo0004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20006FUH2001N
Ool0039oo`800003FUH005YF00MJEP03001JEP000080021oo`05001JEP00Ool00004FUH00`00FUIJ
EP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP06FUH00`00FUIJEP03FUH20007FUH01000FUH00000G7oo000dOol30007FUH00`00FUIJEP02FUH3
000KOol40003Ool20002FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000FUIJEUYF10001UYF00<005YFFUH00UYF00<0
07ooOol0FGoo000gOol20004FUH00`00FUIJEP06FUH6000@Ool50002FUH20005Ool30008FUH00`00
FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH01000
FUH0000017oo10000UYF00<005YFFUH00eYF00<007ooOol0F7oo000iOol300000eYF001JEP08FUH0
0`00FUIJEP02FUH@0003FUH01P00FUIJEP00FUH000Moo`<000IJEP03001JEUYF00QJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00AJEP@000Yoo`<000EJEP8005Uoo`00
?7oo0`0025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P002goo
10000UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH01@0047oo00<005YFFUH00UYF00@005YF000005Moo`00?goo0`0015YF00<005YFFUH01eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8000moo`D000QJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00MJEPD00003Ool0000000<0011oo`800003FUH005YF00=JEP03001oogoo
05Aoo`00@Woo0`0000=JEP00FUH01eYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00P00
5Goo1P000UYF00<005YFFUH02EYF00<005YFFUH02UYF00@005YFFUIJEPH000Ioo`D0019oo`8000AJ
EP03001oogoo05Aoo`00AGoo1P0015YF00<005YFFUH01EYF00@005YFFUIJEPH001eooal000aoo`D0
01=oo`03001JEUYF009JEP8005Eoo`00Bgoo4000=Goo0P001UYF00@005YF000000ioo`<001Eoo`06
001JEUYF001JEP00EGoo002AOol00`00FUIJEP04FUH01000FUIJEUYF0P009Goo0`0000=JEP00Ool0
E7oo002BOol20003FUH00`00FUIJEP04FUH4000SOol00`00FUH0001EOol009Aoo`800003FUH005YF
00IJEP03001JEUYF00@001ioo`<005Ioo`00UWoo0`001UYF00<005YFFUH015YF1@005goo0P0000=J
EP000000EWoo002IOol20003FUH00`00FUIJEP07FUH00`00FUIJEP04000>Ool50003FUH2001FOol0
09]oo`800003FUH005YF00QJEP03001JEUYF00AJEPh000=JEP07001JEUYFFUH005YF0000EWoo002M
Ool40006FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P00Egoo
002QOol40002FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJEUYF0P00
F7oo002UOol50006FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUH00000FWoo002ZOol40002
FUH00`00FUIJEP05FUH01000FUIJEUYF1@00G7oo002^Ool>001QOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59979 .74146 m .58653 .68619 L .55627 .69191 L p .707 .577 .707 r
F P
0 g
s
.58653 .68619 m .59979 .74146 L .6308 .73381 L p .707 .577 .707 r
F P
0 g
s
.6308 .73381 m .61754 .67853 L .58653 .68619 L p .707 .577 .707 r
F P
0 g
s
.61754 .67853 m .6308 .73381 L .65953 .72497 L p .707 .577 .707 r
F P
0 g
s
.65953 .72497 m .64627 .66969 L .61754 .67853 L p .707 .577 .707 r
F P
0 g
s
.56953 .74719 m .55627 .69191 L .52972 .69515 L p .707 .577 .707 r
F P
0 g
s
.55627 .69191 m .56953 .74719 L .59979 .74146 L p .707 .577 .707 r
F P
0 g
s
.64627 .66969 m .65953 .72497 L .68316 .71581 L p .707 .577 .707 r
F P
0 g
s
.68316 .71581 m .6699 .66054 L .64627 .66969 L p .707 .577 .707 r
F P
0 g
s
.52972 .69515 m .54298 .75042 L .56953 .74719 L p .707 .577 .707 r
F P
0 g
s
.58641 .81892 m .59974 .78598 L .57069 .77295 L p .707 .577 .707 r
F P
0 g
s
.63263 .83935 m .62907 .82081 L .59776 .82712 L p .707 .577 .707 r
F P
0 g
s
.59974 .78598 m .58641 .81892 L .61633 .82818 L p .707 .577 .707 r
F P
0 g
s
.61633 .82818 m .62967 .79524 L .59974 .78598 L p .707 .577 .707 r
F P
0 g
s
.55736 .80589 m .57069 .77295 L .54535 .75743 L p .707 .577 .707 r
F P
0 g
s
.57069 .77295 m .55736 .80589 L .58641 .81892 L p .707 .577 .707 r
F P
0 g
s
.54298 .75042 m .52972 .69515 L .50949 .69557 L p .707 .577 .707 r
F P
0 g
s
.63263 .83935 m .66159 .83158 L p .63224 .82186 L .707 .577 .707 r
F P
0 g
s
.62907 .82081 m .62966 .82387 L p .63224 .82186 L .707 .577 .707 r
F P
0 g
s
.62966 .82387 m .63263 .83935 L p .63224 .82186 L .707 .577 .707 r
F P
0 g
s
.66159 .83158 m .65803 .81305 L .62907 .82081 L p .707 .577 .707 r
F P
0 g
s
.65803 .81305 m .66159 .83158 L .68537 .82312 L p .707 .577 .707 r
F P
0 g
s
.68537 .82312 m .68181 .80458 L .65803 .81305 L p .707 .577 .707 r
F P
0 g
s
.6442 .83277 m .66728 .83224 L p .6581 .80173 L .707 .577 .707 r
F P
0 g
s
.65753 .79983 m .65615 .80325 L p .6581 .80173 L .707 .577 .707 r
F P
0 g
s
.65615 .80325 m .6442 .83277 L p .6581 .80173 L .707 .577 .707 r
F P
0 g
s
.62967 .79524 m .61633 .82818 L .6442 .83277 L p .707 .577 .707 r
F P
0 g
s
.6442 .83277 m .65753 .79983 L .62967 .79524 L p .707 .577 .707 r
F P
0 g
s
.6699 .66054 m .68316 .71581 L .69939 .70724 L p .707 .577 .707 r
F P
0 g
s
.69939 .70724 m .68613 .65196 L .6699 .66054 L p .707 .577 .707 r
F P
0 g
s
.60132 .84566 m .59776 .82712 L .56718 .83135 L p .707 .577 .707 r
F P
0 g
s
.59776 .82712 m .60132 .84566 L .63263 .83935 L p .707 .577 .707 r
F P
0 g
s
.54298 .75042 m .53591 .73885 L .52254 .75 L .707 .577 .707 r
F
.50949 .69557 m .52254 .75 L p .53591 .73885 L F P
0 g
s
.50949 .69557 m .49755 .69315 L p .5223 .74983 L .707 .577 .707 r
F P
0 g
s
.51288 .77388 m .52254 .75 L p .51364 .75742 L .707 .577 .707 r
F P
0 g
s
.52254 .75 m .50949 .69557 L p .5223 .74983 L .707 .577 .707 r
F P
0 g
s
.5223 .74983 m .51558 .73444 L .5089 .74048 L .707 .577 .707 r
F
.49755 .69315 m .5089 .74048 L p .51558 .73444 L F P
0 g
s
.50834 .73898 m .50505 .725 L .50513 .72667 L .707 .577 .707 r
F
.5089 .74048 m .49755 .69315 L p .50834 .73898 L F P
0 g
s
.5053 .74374 m .50812 .73839 L .50721 .73594 L .707 .577 .707 r
F
.5018 .75803 m .5089 .74048 L p .5053 .74374 L F P
0 g
s
.5089 .74048 m .50812 .73839 L .5053 .74374 L .707 .577 .707 r
F
.51514 .72508 m .5018 .75803 L .51288 .77388 L p F P
0 g
s
.50833 .74339 m .51081 .74843 L p .50834 .73898 L .707 .577 .707 r
F P
0 g
s
.49507 .68811 m .50533 .73089 L p .50834 .73898 L .707 .577 .707 r
F P
0 g
s
.49988 .74437 m .5018 .75803 L p .50335 .7517 L .707 .577 .707 r
F P
0 g
s
.51321 .71143 m .50533 .73089 L p .50335 .7517 L .707 .577 .707 r
F P
0 g
s
.50533 .73089 m .49988 .74437 L p .50335 .7517 L .707 .577 .707 r
F P
0 g
s
.49755 .69315 m .49507 .68811 L p .50513 .72667 L .707 .577 .707 r
F P
0 g
s
.50505 .725 m .49755 .69315 L .50513 .72667 L .707 .577 .707 r
F
.49507 .68811 m .5023 .68096 L p .50622 .72157 L F P
0 g
s
.50533 .73089 m .50833 .74339 L p .50834 .73898 L .707 .577 .707 r
F P
0 g
s
.50721 .73594 m .50756 .73545 L .5075 .73477 L .707 .577 .707 r
F
.50756 .73545 m .51514 .72508 L .5075 .73477 L F
.51514 .72508 m .51321 .71143 L p .5075 .73477 L F P
0 g
s
.51321 .71143 m .52063 .7013 L p .50802 .72747 L .707 .577 .707 r
F P
0 g
s
.50812 .73839 m .51514 .72508 L .50721 .73594 L .707 .577 .707 r
F
.50833 .74339 m .50533 .73089 L p .50693 .72886 L F P
0 g
s
.50683 .72898 m .51321 .71143 L .50802 .72747 L .707 .577 .707 r
F
.5089 .74048 m .51514 .72508 L p .50812 .73839 L F P
0 g
s
.51081 .74843 m .5089 .74048 L p .50834 .73898 L .707 .577 .707 r
F P
0 g
s
.52254 .75 m .52043 .74852 L .51364 .75742 L .707 .577 .707 r
F
.51364 .75742 m .52043 .74852 L .51425 .74421 L F
.5089 .74048 m .51081 .74843 L p .5223 .74983 L F P
0 g
s
.52621 .74093 m .51514 .72508 L p .51425 .74421 L .707 .577 .707 r
F P
0 g
s
.51556 .73623 m .50833 .74339 L p .50693 .72886 L .707 .577 .707 r
F P
0 g
s
.50533 .73089 m .51321 .71143 L p .50683 .72898 L .707 .577 .707 r
F P
0 g
s
.51218 .72217 m .51556 .73623 L p .50693 .72886 L .707 .577 .707 r
F P
0 g
s
.52063 .7013 m .51218 .72217 L p .49988 .74437 L .707 .577 .707 r
F P
0 g
s
.51218 .72217 m .5073 .73424 L .50045 .74359 L p .707 .577 .707 r
F P
0 g
s
.50045 .74359 m .49988 .74437 L p .51218 .72217 L .707 .577 .707 r
F P
0 g
s
.52063 .7013 m .53667 .69569 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.51556 .73623 m .51218 .72217 L p .51629 .72043 L .707 .577 .707 r
F P
0 g
s
.51218 .72217 m .52063 .7013 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.53178 .72766 m .51556 .73623 L p .51629 .72043 L .707 .577 .707 r
F P
0 g
s
.53667 .69569 m .52879 .71516 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.51852 .67238 m .52879 .71516 L p .51629 .72043 L .707 .577 .707 r
F P
0 g
s
.52879 .71516 m .53178 .72766 L p .51629 .72043 L .707 .577 .707 r
F P
0 g
s
.52333 .72864 m .5073 .73424 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.52879 .71516 m .52333 .72864 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.5073 .73424 m .51218 .72217 L p .51854 .71949 L .707 .577 .707 r
F P
0 g
s
.51629 .72043 m .51218 .72217 L .51658 .71414 L .707 .577 .707 r
F
.5023 .68096 m .51852 .67238 L p .51658 .71414 L F P
0 g
s
.51218 .72217 m .5023 .68096 L p .51658 .71414 L .707 .577 .707 r
F P
0 g
s
.5023 .68096 m .51218 .72217 L p .50693 .72886 L .707 .577 .707 r
F P
0 g
s
.50533 .73089 m .50683 .72898 L .50543 .73285 L .707 .577 .707 r
F
.50543 .73285 m .50683 .72898 L .50802 .72747 L F
.50693 .72886 m .50533 .73089 L .50622 .72157 L F
.50533 .73089 m .49507 .68811 L p .50622 .72157 L F P
0 g
s
.49988 .74437 m .50533 .73089 L p .50543 .73285 L .707 .577 .707 r
F P
0 g
s
.52254 .75 m .52621 .74093 L p .52043 .74852 L .707 .577 .707 r
F P
0 g
s
.52468 .75081 m .54298 .75042 L p .52254 .75 L .707 .577 .707 r
F P
0 g
s
.52621 .74093 m .51288 .77388 L .53202 .79037 L p .707 .577 .707 r
F P
0 g
s
.51081 .74843 m .52275 .75085 L p .5223 .74983 L .707 .577 .707 r
F P
0 g
s
.52275 .75085 m .52254 .75 L p .5223 .74983 L .707 .577 .707 r
F P
0 g
s
.52043 .74852 m .52621 .74093 L .51425 .74421 L .707 .577 .707 r
F
.54535 .75743 m .52621 .74093 L p .5275 .75188 L F P
0 g
s
.53202 .79037 m .54492 .7585 L p .5275 .75188 L .707 .577 .707 r
F P
0 g
s
.54492 .7585 m .54535 .75743 L p .5275 .75188 L .707 .577 .707 r
F P
0 g
s
.52254 .75 m .52275 .75085 L .52468 .75081 L p .707 .577 .707 r
F P
0 g
s
.54535 .75743 m .53202 .79037 L .55736 .80589 L p .707 .577 .707 r
F P
0 g
s
.56718 .83135 m .57074 .84988 L .60132 .84566 L p .707 .577 .707 r
F P
0 g
s
.57074 .84988 m .56718 .83135 L .54031 .83308 L p .707 .577 .707 r
F P
0 g
s
.66728 .83224 m .68061 .79929 L .65753 .79983 L p .707 .577 .707 r
F P
0 g
s
.54031 .83308 m .54387 .85162 L .57074 .84988 L p .707 .577 .707 r
F P
0 g
s
.68613 .65196 m .69939 .70724 L .70661 .70008 L p .707 .577 .707 r
F P
0 g
s
.70661 .70008 m .69335 .64481 L .68613 .65196 L p .707 .577 .707 r
F P
0 g
s
.54387 .85162 m .54031 .83308 L .51979 .83216 L p .707 .577 .707 r
F P
0 g
s
.51979 .83216 m .52335 .8507 L .54387 .85162 L p .707 .577 .707 r
F P
0 g
s
.68061 .79929 m .66728 .83224 L .68331 .82663 L p .707 .577 .707 r
F P
0 g
s
.68181 .80458 m .68537 .82312 L .70165 .81478 L p .707 .577 .707 r
F P
0 g
s
.70165 .81478 m .69809 .79624 L .68181 .80458 L p .707 .577 .707 r
F P
0 g
s
.68331 .82663 m .69664 .79369 L .68061 .79929 L p .707 .577 .707 r
F P
0 g
s
.52335 .8507 m .51979 .83216 L .50762 .82866 L p .707 .577 .707 r
F P
0 g
s
.69335 .64481 m .70661 .70008 L .70414 .69505 L p .707 .577 .707 r
F P
0 g
s
.70414 .69505 m .69088 .63977 L .69335 .64481 L p .707 .577 .707 r
F P
0 g
s
.50762 .82866 m .51118 .8472 L .52335 .8507 L p .707 .577 .707 r
F P
0 g
s
.69664 .79369 m .68331 .82663 L .69073 .8165 L p .707 .577 .707 r
F P
0 g
s
.69809 .79624 m .70165 .81478 L .70882 .80739 L p .707 .577 .707 r
F P
0 g
s
.70882 .80739 m .70526 .78885 L .69809 .79624 L p .707 .577 .707 r
F P
0 g
s
.69073 .8165 m .70406 .78356 L .69664 .79369 L p .707 .577 .707 r
F P
0 g
s
.48571 .82193 m .49274 .32085 L .44873 .31754 L p .707 .577 .707 r
F P
0 g
s
.51118 .8472 m .50762 .82866 L .50499 .82294 L p .707 .577 .707 r
F P
0 g
s
.50499 .82294 m .50855 .84147 L .51118 .8472 L p .707 .577 .707 r
F P
0 g
s
.50855 .84147 m .50499 .82294 L .51217 .81554 L p .707 .577 .707 r
F P
0 g
s
.51217 .81554 m .51573 .83408 L .50855 .84147 L p .707 .577 .707 r
F P
0 g
s
.53667 .69569 m .55974 .69516 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.53178 .72766 m .52879 .71516 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.52879 .71516 m .53667 .69569 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.55542 .7185 m .53178 .72766 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.55974 .69516 m .55351 .71056 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.54216 .66323 m .55351 .71056 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.55351 .71056 m .55542 .7185 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.54641 .7281 m .52333 .72864 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.55351 .71056 m .54641 .7281 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.52333 .72864 m .52879 .71516 L p .54032 .71301 L .707 .577 .707 r
F P
0 g
s
.51852 .67238 m .54216 .66323 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.52879 .71516 m .51852 .67238 L p .53395 .7142 L .707 .577 .707 r
F P
0 g
s
.51573 .83408 m .51217 .81554 L .52844 .8072 L p .707 .577 .707 r
F P
0 g
s
.52844 .8072 m .532 .82574 L .51573 .83408 L p .707 .577 .707 r
F P
0 g
s
.532 .82574 m .52844 .8072 L .55222 .79874 L p .707 .577 .707 r
F P
0 g
s
.49274 .32085 m .48571 .82193 L .53065 .82139 L p .707 .577 .707 r
F P
0 g
s
.53065 .82139 m .53768 .32031 L .49274 .32085 L p .707 .577 .707 r
F P
0 g
s
.55974 .69516 m .58761 .69975 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.55351 .71056 m .55974 .69516 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.54216 .66323 m .57089 .65439 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.55542 .7185 m .55351 .71056 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.55351 .71056 m .54216 .66323 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.58415 .70966 m .55542 .7185 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.58761 .69975 m .58394 .70881 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.57089 .65439 m .58394 .70881 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.58394 .70881 m .58415 .70966 L p .55739 .71033 L .707 .577 .707 r
F P
0 g
s
.57427 .73269 m .54641 .7281 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.58394 .70881 m .57427 .73269 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.54641 .7281 m .55351 .71056 L p .57358 .7094 L .707 .577 .707 r
F P
0 g
s
.55222 .79874 m .55579 .81727 L .532 .82574 L p .707 .577 .707 r
F P
0 g
s
.55579 .81727 m .55222 .79874 L .58119 .79097 L p .707 .577 .707 r
F P
0 g
s
.58119 .79097 m .58475 .80951 L .55579 .81727 L p .707 .577 .707 r
F P
0 g
s
.53768 .32031 m .53065 .82139 L .57212 .81707 L p .707 .577 .707 r
F P
0 g
s
.58394 .70881 m .58761 .69975 L p .61567 .71003 L .707 .577 .707 r
F P
0 g
s
.57089 .65439 m .6019 .64673 L p .58438 .70883 L .707 .577 .707 r
F P
0 g
s
.58415 .70966 m .58394 .70881 L p .58438 .70883 L .707 .577 .707 r
F P
0 g
s
.58394 .70881 m .57089 .65439 L p .58438 .70883 L .707 .577 .707 r
F P
0 g
s
.58761 .69975 m .61753 .70901 L p .61567 .71003 L .707 .577 .707 r
F P
0 g
s
.6019 .64673 m .61516 .70201 L .58415 .70966 L p .707 .577 .707 r
F P
0 g
s
.57427 .73269 m .58394 .70881 L p .61567 .71003 L .707 .577 .707 r
F P
0 g
s
.57212 .81707 m .57916 .31599 L .53768 .32031 L p .707 .577 .707 r
F P
0 g
s
.4417 .81862 m .44873 .31754 L .40997 .31072 L p .707 .577 .707 r
F P
0 g
s
.44873 .31754 m .4417 .81862 L .48571 .82193 L p .707 .577 .707 r
F P
0 g
s
.69088 .63977 m .70414 .69505 L .6922 .69262 L p .707 .577 .707 r
F P
0 g
s
.6922 .69262 m .67894 .63735 L .69088 .63977 L p .707 .577 .707 r
F P
0 g
s
.61753 .70901 m .6042 .74195 L .57427 .73269 L p .707 .577 .707 r
F P
0 g
s
.58475 .80951 m .58119 .79097 L .61249 .78467 L p .707 .577 .707 r
F P
0 g
s
.61249 .78467 m .61605 .8032 L .58475 .80951 L p .707 .577 .707 r
F P
0 g
s
.57916 .31599 m .57212 .81707 L .60608 .80938 L p .707 .577 .707 r
F P
0 g
s
.61516 .70201 m .6019 .64673 L .63216 .641 L p .707 .577 .707 r
F P
0 g
s
.64658 .72204 m .63325 .75498 L .6042 .74195 L p .707 .577 .707 r
F P
0 g
s
.6042 .74195 m .61753 .70901 L .64658 .72204 L p .707 .577 .707 r
F P
0 g
s
.60608 .80938 m .61311 .3083 L .57916 .31599 L p .707 .577 .707 r
F P
0 g
s
.70406 .78356 m .69073 .8165 L .68881 .80285 L p .707 .577 .707 r
F P
0 g
s
.68881 .80285 m .70076 .77332 L p .70406 .78356 L .707 .577 .707 r
F P
0 g
s
.70214 .7699 m .68881 .80285 L .67773 .787 L p .707 .577 .707 r
F P
0 g
s
.69403 .79816 m .69105 .78268 L p .70264 .78312 L .707 .577 .707 r
F P
0 g
s
.69105 .78268 m .69047 .77963 L .69336 .78046 L p .707 .577 .707 r
F P
0 g
s
.69336 .78046 m .70264 .78312 L p .69105 .78268 L .707 .577 .707 r
F P
0 g
s
.70076 .77332 m .70214 .7699 L .7024 .77174 L p .707 .577 .707 r
F P
0 g
s
.7024 .77174 m .70406 .78356 L p .70076 .77332 L .707 .577 .707 r
F P
0 g
s
.70526 .78885 m .70882 .80739 L .7062 .80166 L p .707 .577 .707 r
F P
0 g
s
.7062 .80166 m .70264 .78312 L .70526 .78885 L p .707 .577 .707 r
F P
0 g
s
.40294 .8118 m .40997 .31072 L .38025 .30104 L p .707 .577 .707 r
F P
0 g
s
.40997 .31072 m .40294 .8118 L .4417 .81862 L p .707 .577 .707 r
F P
0 g
s
.25678 .70471 m .24352 .64944 L .21326 .65516 L p .707 .577 .707 r
F P
0 g
s
.24352 .64944 m .25678 .70471 L .28779 .69705 L p .707 .577 .707 r
F P
0 g
s
.28779 .69705 m .27453 .64178 L .24352 .64944 L p .707 .577 .707 r
F P
0 g
s
.27453 .64178 m .28779 .69705 L .31652 .68822 L p .707 .577 .707 r
F P
0 g
s
.31652 .68822 m .30326 .63294 L .27453 .64178 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.22652 .71044 m .21326 .65516 L .18671 .65839 L p .707 .577 .707 r
F P
0 g
s
.21326 .65516 m .22652 .71044 L .25678 .70471 L p .707 .577 .707 r
F P
0 g
s
.30326 .63294 m .31652 .68822 L .34015 .67906 L p .707 .577 .707 r
F P
0 g
s
.34015 .67906 m .32689 .62378 L .30326 .63294 L p .707 .577 .707 r
F P
0 g
s
.63216 .641 m .64542 .69628 L .61516 .70201 L p .707 .577 .707 r
F P
0 g
s
.64307 .78044 m .64663 .79897 L .61605 .8032 L p .707 .577 .707 r
F P
0 g
s
.61605 .8032 m .61249 .78467 L .64307 .78044 L p .707 .577 .707 r
F P
0 g
s
.61311 .3083 m .60608 .80938 L .62919 .79908 L p .707 .577 .707 r
F P
0 g
s
.62919 .79908 m .63622 .298 L .61311 .3083 L p .707 .577 .707 r
F P
0 g
s
.67894 .63735 m .6922 .69262 L .67196 .69305 L p .707 .577 .707 r
F P
0 g
s
.67196 .69305 m .65871 .63777 L .67894 .63735 L p .707 .577 .707 r
F P
0 g
s
.18671 .65839 m .19997 .71367 L .22652 .71044 L p .707 .577 .707 r
F P
0 g
s
.67773 .787 m .69107 .75405 L .70214 .7699 L p .707 .577 .707 r
F P
0 g
s
.2434 .78193 m .25674 .74898 L .22768 .73595 L p .707 .577 .707 r
F P
0 g
s
.28962 .80322 m .28606 .78468 L .25476 .79099 L p .707 .577 .707 r
F P
0 g
s
.25674 .74898 m .2434 .78193 L .27332 .79119 L p .707 .577 .707 r
F P
0 g
s
.27332 .79119 m .28666 .75824 L .25674 .74898 L p .707 .577 .707 r
F P
0 g
s
.70264 .78312 m .7062 .80166 L .69403 .79816 L p .707 .577 .707 r
F P
0 g
s
.21435 .7689 m .22768 .73595 L .20234 .72043 L p .707 .577 .707 r
F P
0 g
s
.22768 .73595 m .21435 .7689 L .2434 .78193 L p .707 .577 .707 r
F P
0 g
s
.19997 .71367 m .18671 .65839 L .16648 .65882 L p .707 .577 .707 r
F P
0 g
s
.28962 .80322 m .31858 .79545 L p .28862 .78553 L .707 .577 .707 r
F P
0 g
s
.28606 .78468 m .28653 .78716 L p .28862 .78553 L .707 .577 .707 r
F P
0 g
s
.28653 .78716 m .28962 .80322 L p .28862 .78553 L .707 .577 .707 r
F P
0 g
s
.31858 .79545 m .31502 .77692 L .28606 .78468 L p .707 .577 .707 r
F P
0 g
s
.31502 .77692 m .31858 .79545 L .34236 .78699 L p .707 .577 .707 r
F P
0 g
s
.34236 .78699 m .3388 .76845 L .31502 .77692 L p .707 .577 .707 r
F P
0 g
s
.30119 .79578 m .32427 .79524 L p .31514 .76489 L .707 .577 .707 r
F P
0 g
s
.31452 .76283 m .31303 .76653 L p .31514 .76489 L .707 .577 .707 r
F P
0 g
s
.31303 .76653 m .30119 .79578 L p .31514 .76489 L .707 .577 .707 r
F P
0 g
s
.28666 .75824 m .27332 .79119 L .30119 .79578 L p .707 .577 .707 r
F P
0 g
s
.30119 .79578 m .31452 .76283 L .28666 .75824 L p .707 .577 .707 r
F P
0 g
s
.37322 .80212 m .38025 .30104 L .36248 .28946 L p .707 .577 .707 r
F P
0 g
s
.38025 .30104 m .37322 .80212 L .40294 .8118 L p .707 .577 .707 r
F P
0 g
s
.32689 .62378 m .34015 .67906 L .35638 .67049 L p .707 .577 .707 r
F P
0 g
s
.35638 .67049 m .34312 .61521 L .32689 .62378 L p .707 .577 .707 r
F P
0 g
s
.25832 .80953 m .25476 .79099 L .22417 .79522 L p .707 .577 .707 r
F P
0 g
s
.25476 .79099 m .25832 .80953 L .28962 .80322 L p .707 .577 .707 r
F P
0 g
s
.19997 .71367 m .19283 .70198 L .1795 .71309 L .707 .577 .707 r
F
.16648 .65882 m .1795 .71309 L p .19283 .70198 L F P
0 g
s
.16648 .65882 m .15454 .6564 L p .17921 .71289 L .707 .577 .707 r
F P
0 g
s
.16987 .73688 m .1795 .71309 L p .17063 .72048 L .707 .577 .707 r
F P
0 g
s
.1795 .71309 m .16648 .65882 L p .17921 .71289 L .707 .577 .707 r
F P
0 g
s
.17921 .71289 m .17251 .69755 L .16586 .70358 L .707 .577 .707 r
F
.15454 .6564 m .16586 .70358 L p .17251 .69755 L F P
0 g
s
.16529 .70205 m .16201 .68811 L .16209 .68978 L .707 .577 .707 r
F
.16586 .70358 m .15454 .6564 L p .16529 .70205 L F P
0 g
s
.16227 .70682 m .16508 .70149 L .16417 .69906 L .707 .577 .707 r
F
.15879 .72103 m .16586 .70358 L p .16227 .70682 L F P
0 g
s
.16586 .70358 m .16508 .70149 L .16227 .70682 L .707 .577 .707 r
F
.17213 .68809 m .15879 .72103 L .16987 .73688 L p F P
0 g
s
.16532 .70663 m .1678 .71167 L p .16529 .70205 L .707 .577 .707 r
F P
0 g
s
.15206 .65136 m .16229 .69399 L p .16529 .70205 L .707 .577 .707 r
F P
0 g
s
.15687 .70738 m .15879 .72103 L p .1603 .71489 L .707 .577 .707 r
F P
0 g
s
.1702 .67443 m .16229 .69399 L p .1603 .71489 L .707 .577 .707 r
F P
0 g
s
.16229 .69399 m .15687 .70738 L p .1603 .71489 L .707 .577 .707 r
F P
0 g
s
.15454 .6564 m .15206 .65136 L p .16209 .68978 L .707 .577 .707 r
F P
0 g
s
.16201 .68811 m .15454 .6564 L .16209 .68978 L .707 .577 .707 r
F
.15206 .65136 m .15929 .6442 L p .16319 .68455 L F P
0 g
s
.16229 .69399 m .16532 .70663 L p .16529 .70205 L .707 .577 .707 r
F P
0 g
s
.16417 .69906 m .16454 .69855 L .16447 .69784 L .707 .577 .707 r
F
.16454 .69855 m .17213 .68809 L .16447 .69784 L F
.17213 .68809 m .1702 .67443 L p .16447 .69784 L F P
0 g
s
.1702 .67443 m .17762 .6643 L p .16496 .69059 L .707 .577 .707 r
F P
0 g
s
.16508 .70149 m .17213 .68809 L .16417 .69906 L .707 .577 .707 r
F
.16532 .70663 m .16229 .69399 L p .1639 .69193 L F P
0 g
s
.16378 .69209 m .1702 .67443 L .16496 .69059 L .707 .577 .707 r
F
.16586 .70358 m .17213 .68809 L p .16508 .70149 L F P
0 g
s
.1678 .71167 m .16586 .70358 L p .16529 .70205 L .707 .577 .707 r
F P
0 g
s
.1795 .71309 m .17737 .71161 L .17063 .72048 L .707 .577 .707 r
F
.17063 .72048 m .17737 .71161 L .17124 .70733 L F
.16586 .70358 m .1678 .71167 L p .17921 .71289 L F P
0 g
s
.1832 .70394 m .17213 .68809 L p .17124 .70733 L .707 .577 .707 r
F P
0 g
s
.17255 .69948 m .16532 .70663 L p .1639 .69193 L .707 .577 .707 r
F P
0 g
s
.16229 .69399 m .1702 .67443 L p .16378 .69209 L .707 .577 .707 r
F P
0 g
s
.16914 .68526 m .17255 .69948 L p .1639 .69193 L .707 .577 .707 r
F P
0 g
s
.17762 .6643 m .16914 .68526 L p .15687 .70738 L .707 .577 .707 r
F P
0 g
s
.16914 .68526 m .16429 .69725 L .15749 .70653 L p .707 .577 .707 r
F P
0 g
s
.15749 .70653 m .15687 .70738 L p .16914 .68526 L .707 .577 .707 r
F P
0 g
s
.17762 .6643 m .19366 .6587 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.17255 .69948 m .16914 .68526 L p .17329 .68351 L .707 .577 .707 r
F P
0 g
s
.16914 .68526 m .17762 .6643 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.18877 .6909 m .17255 .69948 L p .17329 .68351 L .707 .577 .707 r
F P
0 g
s
.19366 .6587 m .18574 .67826 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.17551 .63563 m .18574 .67826 L p .17329 .68351 L .707 .577 .707 r
F P
0 g
s
.18574 .67826 m .18877 .6909 L p .17329 .68351 L .707 .577 .707 r
F P
0 g
s
.18032 .69164 m .16429 .69725 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.18574 .67826 m .18032 .69164 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.16429 .69725 m .16914 .68526 L p .17545 .6826 L .707 .577 .707 r
F P
0 g
s
.17329 .68351 m .16914 .68526 L .17359 .67715 L .707 .577 .707 r
F
.15929 .6442 m .17551 .63563 L p .17359 .67715 L F P
0 g
s
.16914 .68526 m .15929 .6442 L p .17359 .67715 L .707 .577 .707 r
F P
0 g
s
.15929 .6442 m .16914 .68526 L p .1639 .69193 L .707 .577 .707 r
F P
0 g
s
.16229 .69399 m .16378 .69209 L .16238 .69594 L .707 .577 .707 r
F
.16238 .69594 m .16378 .69209 L .16496 .69059 L F
.1639 .69193 m .16229 .69399 L .16319 .68455 L F
.16229 .69399 m .15206 .65136 L p .16319 .68455 L F P
0 g
s
.15687 .70738 m .16229 .69399 L p .16238 .69594 L .707 .577 .707 r
F P
0 g
s
.1795 .71309 m .1832 .70394 L p .17737 .71161 L .707 .577 .707 r
F P
0 g
s
.18201 .71405 m .19997 .71367 L p .1795 .71309 L .707 .577 .707 r
F P
0 g
s
.1832 .70394 m .16987 .73688 L .18901 .75338 L p .707 .577 .707 r
F P
0 g
s
.1678 .71167 m .17974 .7141 L p .17921 .71289 L .707 .577 .707 r
F P
0 g
s
.17974 .7141 m .1795 .71309 L p .17921 .71289 L .707 .577 .707 r
F P
0 g
s
.17737 .71161 m .1832 .70394 L .17124 .70733 L .707 .577 .707 r
F
.20234 .72043 m .1832 .70394 L p .1845 .71499 L F P
0 g
s
.18901 .75338 m .20187 .7216 L p .1845 .71499 L .707 .577 .707 r
F P
0 g
s
.20187 .7216 m .20234 .72043 L p .1845 .71499 L .707 .577 .707 r
F P
0 g
s
.1795 .71309 m .17974 .7141 L .18201 .71405 L p .707 .577 .707 r
F P
0 g
s
.20234 .72043 m .18901 .75338 L .21435 .7689 L p .707 .577 .707 r
F P
0 g
s
.22417 .79522 m .22773 .81375 L .25832 .80953 L p .707 .577 .707 r
F P
0 g
s
.65871 .63777 m .67196 .69305 L .64542 .69628 L p .707 .577 .707 r
F P
0 g
s
.64542 .69628 m .63216 .641 L .65871 .63777 L p .707 .577 .707 r
F P
0 g
s
.22773 .81375 m .22417 .79522 L .1973 .79695 L p .707 .577 .707 r
F P
0 g
s
.32427 .79524 m .3376 .7623 L .31452 .76283 L p .707 .577 .707 r
F P
0 g
s
.69107 .75405 m .67773 .787 L .65859 .7705 L p .707 .577 .707 r
F P
0 g
s
.65859 .7705 m .67192 .73756 L .69107 .75405 L p .707 .577 .707 r
F P
0 g
s
.1973 .79695 m .20086 .81549 L .22773 .81375 L p .707 .577 .707 r
F P
0 g
s
.69047 .77963 m .69403 .79816 L .6735 .79724 L p .707 .577 .707 r
F P
0 g
s
.6735 .79724 m .66994 .7787 L .69047 .77963 L p .707 .577 .707 r
F P
0 g
s
.67192 .73756 m .65859 .7705 L .63325 .75498 L p .707 .577 .707 r
F P
0 g
s
.63325 .75498 m .64658 .72204 L .67192 .73756 L p .707 .577 .707 r
F P
0 g
s
.63622 .298 m .62919 .79908 L .63919 .78717 L p .707 .577 .707 r
F P
0 g
s
.63919 .78717 m .64622 .28609 L .63622 .298 L p .707 .577 .707 r
F P
0 g
s
.34312 .61521 m .35638 .67049 L .3636 .66333 L p .707 .577 .707 r
F P
0 g
s
.3636 .66333 m .35035 .60805 L .34312 .61521 L p .707 .577 .707 r
F P
0 g
s
.20086 .81549 m .1973 .79695 L .17678 .79603 L p .707 .577 .707 r
F P
0 g
s
.17678 .79603 m .18034 .81457 L .20086 .81549 L p .707 .577 .707 r
F P
0 g
s
.3376 .7623 m .32427 .79524 L .3403 .78964 L p .707 .577 .707 r
F P
0 g
s
.3388 .76845 m .34236 .78699 L .35864 .77865 L p .707 .577 .707 r
F P
0 g
s
.35864 .77865 m .35508 .76011 L .3388 .76845 L p .707 .577 .707 r
F P
0 g
s
.3403 .78964 m .35363 .75669 L .3376 .7623 L p .707 .577 .707 r
F P
0 g
s
.35035 .60805 m .3636 .66333 L .36113 .65829 L p .707 .577 .707 r
F P
0 g
s
.36113 .65829 m .34787 .60302 L .35035 .60805 L p .707 .577 .707 r
F P
0 g
s
.35508 .76011 m .35864 .77865 L .36385 .77328 L p .707 .577 .707 r
F P
0 g
s
.36385 .77328 m .36582 .77126 L p .36366 .76902 L .707 .577 .707 r
F P
0 g
s
.36366 .76902 m .35508 .76011 L .36385 .77328 L .707 .577 .707 r
F
.36248 .28946 m .35839 .27712 L p .35651 .60536 L F P
0 g
s
.36225 .75272 m .35508 .76011 L p .36366 .76902 L .707 .577 .707 r
F P
0 g
s
.36582 .77126 m .36315 .7574 L p .36366 .76902 L .707 .577 .707 r
F P
0 g
s
.36315 .7574 m .36225 .75272 L p .36366 .76902 L .707 .577 .707 r
F P
0 g
s
.34772 .77951 m .36105 .74657 L .35363 .75669 L p .707 .577 .707 r
F P
0 g
s
.35363 .75669 m .3403 .78964 L .34772 .77951 L p .707 .577 .707 r
F P
0 g
s
.34787 .60302 m .36113 .65829 L .34919 .65587 L p .707 .577 .707 r
F P
0 g
s
.36105 .74657 m .34772 .77951 L .3458 .76585 L p .707 .577 .707 r
F P
0 g
s
.3458 .76585 m .35763 .73661 L p .36105 .74657 L .707 .577 .707 r
F P
0 g
s
.35763 .73661 m .35913 .73291 L .35941 .73489 L p .707 .577 .707 r
F P
0 g
s
.35941 .73489 m .36105 .74657 L p .35763 .73661 L .707 .577 .707 r
F P
0 g
s
.35913 .73291 m .3458 .76585 L .33768 .75424 L p .707 .577 .707 r
F P
0 g
s
.33768 .75424 m .33472 .75 L p .33837 .74745 L .707 .577 .707 r
F P
0 g
s
.33837 .74745 m .35913 .73291 L .33768 .75424 L .707 .577 .707 r
F
.35767 .63197 m .36248 .28946 L p .35651 .60536 L F P
0 g
s
.35102 .76203 m .34793 .74597 L p .35963 .74699 L .707 .577 .707 r
F P
0 g
s
.3498 .74417 m .35963 .74699 L p .34793 .74597 L .707 .577 .707 r
F P
0 g
s
.36225 .75272 m .36582 .77126 L .36319 .76553 L p .707 .577 .707 r
F P
0 g
s
.36319 .76553 m .35963 .74699 L .36225 .75272 L p .707 .577 .707 r
F P
0 g
s
.34806 .71706 m .35913 .73291 L p .33837 .74745 L .707 .577 .707 r
F P
0 g
s
.33472 .75 m .33923 .73886 L p .33837 .74745 L .707 .577 .707 r
F P
0 g
s
.33923 .73886 m .34806 .71706 L p .33837 .74745 L .707 .577 .707 r
F P
0 g
s
.35963 .74699 m .36319 .76553 L .35102 .76203 L p .707 .577 .707 r
F P
0 g
s
.36248 .28946 m .35545 .79055 L .37322 .80212 L p .707 .577 .707 r
F P
0 g
s
.35136 .7782 m .35545 .79055 L p .35651 .60536 L .707 .577 .707 r
F P
0 g
s
.35552 .77825 m .35767 .63197 L .35651 .60536 L .707 .577 .707 r
F
.35563 .77773 m .35767 .63197 L p .35552 .77825 L F P
0 g
s
.35569 .77304 m .35136 .7782 L p .35874 .55593 L .707 .577 .707 r
F P
0 g
s
.35874 .55593 m .35927 .53987 L .35569 .77304 L .707 .577 .707 r
F
.36136 .76629 m .35569 .77304 L p .35927 .53987 L F P
0 g
s
.36839 .26521 m .36539 .47913 L p .35927 .53987 L .707 .577 .707 r
F P
0 g
s
.36539 .47913 m .36136 .76629 L p .35927 .53987 L .707 .577 .707 r
F P
0 g
s
.35839 .27712 m .36839 .26521 L p .35927 .53987 L .707 .577 .707 r
F P
0 g
s
.35839 .27712 m .35445 .55819 L p .35651 .60536 L .707 .577 .707 r
F P
0 g
s
.35445 .55819 m .35136 .7782 L p .35651 .60536 L .707 .577 .707 r
F P
0 g
s
.35136 .7782 m .35396 .59257 L p .35927 .53987 L .707 .577 .707 r
F P
0 g
s
.35396 .59257 m .35839 .27712 L p .35927 .53987 L .707 .577 .707 r
F P
0 g
s
.34793 .74597 m .34746 .7435 L .3498 .74417 L p .707 .577 .707 r
F P
0 g
s
.35545 .79055 m .35563 .77773 L p .35552 .77825 L .707 .577 .707 r
F P
0 g
s
.66994 .7787 m .6735 .79724 L .64663 .79897 L p .707 .577 .707 r
F P
0 g
s
.64663 .79897 m .64307 .78044 L .66994 .7787 L p .707 .577 .707 r
F P
0 g
s
.18034 .81457 m .17678 .79603 L .16461 .79253 L p .707 .577 .707 r
F P
0 g
s
.16461 .79253 m .16817 .81107 L .18034 .81457 L p .707 .577 .707 r
F P
0 g
s
.64622 .28609 m .63919 .78717 L .6351 .77482 L p .707 .577 .707 r
F P
0 g
s
.6351 .77482 m .64213 .27374 L .64622 .28609 L p .707 .577 .707 r
F P
0 g
s
.16817 .81107 m .16461 .79253 L .16198 .78681 L p .707 .577 .707 r
F P
0 g
s
.16198 .78681 m .16554 .80534 L .16817 .81107 L p .707 .577 .707 r
F P
0 g
s
.34919 .65587 m .33593 .60059 L .34787 .60302 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.25989 .77826 Mdot
.5 Mabswid
.64213 .27374 m .6351 .77482 L .61733 .76325 L p .707 .577 .707 r
F P
0 g
s
.61733 .76325 m .62436 .26217 L .64213 .27374 L p .707 .577 .707 r
F P
0 g
s
.16554 .80534 m .16198 .78681 L .16916 .77941 L p .707 .577 .707 r
F P
0 g
s
.33593 .60059 m .34919 .65587 L .32896 .65629 L p .707 .577 .707 r
F P
0 g
s
.32896 .65629 m .3157 .60102 L .33593 .60059 L p .707 .577 .707 r
F P
0 g
s
.16916 .77941 m .17272 .79795 L .16554 .80534 L p .707 .577 .707 r
F P
0 g
s
.36136 .76629 m .36839 .26521 L .3915 .25491 L p .707 .577 .707 r
F P
0 g
s
.19366 .6587 m .21673 .65816 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.18574 .67826 m .19366 .6587 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.17551 .63563 m .19915 .62647 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.18877 .6909 m .18574 .67826 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.18574 .67826 m .17551 .63563 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.21241 .68175 m .18877 .6909 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.21673 .65816 m .21047 .67365 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.19915 .62647 m .21047 .67365 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.21047 .67365 m .21241 .68175 L p .19097 .67728 L .707 .577 .707 r
F P
0 g
s
.2034 .69111 m .18032 .69164 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.21047 .67365 m .2034 .69111 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.18032 .69164 m .18574 .67826 L p .1972 .67612 L .707 .577 .707 r
F P
0 g
s
.3157 .60102 m .32896 .65629 L .30241 .65953 L p .707 .577 .707 r
F P
0 g
s
.30241 .65953 m .28915 .60425 L .3157 .60102 L p .707 .577 .707 r
F P
0 g
s
.17272 .79795 m .16916 .77941 L .18543 .77107 L p .707 .577 .707 r
F P
0 g
s
.34806 .71706 m .33472 .75 L .31558 .73351 L p .707 .577 .707 r
F P
0 g
s
.31558 .73351 m .32891 .70056 L .34806 .71706 L p .707 .577 .707 r
F P
0 g
s
.18543 .77107 m .18899 .78961 L .17272 .79795 L p .707 .577 .707 r
F P
0 g
s
.62436 .26217 m .61733 .76325 L .58761 .75357 L p .707 .577 .707 r
F P
0 g
s
.58761 .75357 m .59464 .25249 L .62436 .26217 L p .707 .577 .707 r
F P
0 g
s
.34746 .7435 m .35102 .76203 L .33049 .76111 L p .707 .577 .707 r
F P
0 g
s
.33049 .76111 m .32693 .74257 L .34746 .7435 L p .707 .577 .707 r
F P
0 g
s
.21673 .65816 m .2446 .66275 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.21241 .68175 m .21047 .67365 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.21047 .67365 m .21673 .65816 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.24114 .67291 m .21241 .68175 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.2446 .66275 m .2409 .6719 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.22788 .61763 m .2409 .6719 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.2409 .6719 m .24114 .67291 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.23126 .6957 m .2034 .69111 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.2409 .6719 m .23126 .6957 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.2034 .69111 m .21047 .67365 L p .23043 .67251 L .707 .577 .707 r
F P
0 g
s
.19915 .62647 m .22788 .61763 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.21047 .67365 m .19915 .62647 L p .21441 .67343 L .707 .577 .707 r
F P
0 g
s
.28915 .60425 m .30241 .65953 L .27215 .66525 L p .707 .577 .707 r
F P
0 g
s
.27215 .66525 m .25889 .60998 L .28915 .60425 L p .707 .577 .707 r
F P
0 g
s
.3915 .25491 m .38447 .75599 L .36136 .76629 L p .707 .577 .707 r
F P
0 g
s
.38447 .75599 m .3915 .25491 L .42545 .24722 L p .707 .577 .707 r
F P
0 g
s
.32891 .70056 m .31558 .73351 L .29024 .71799 L p .707 .577 .707 r
F P
0 g
s
.29024 .71799 m .30357 .68504 L .32891 .70056 L p .707 .577 .707 r
F P
0 g
s
.73699 .64943 m .72373 .59415 L .69347 .59988 L p .707 .577 .707 r
F P
0 g
s
.72373 .59415 m .73699 .64943 L .768 .64177 L p .707 .577 .707 r
F P
0 g
s
.768 .64177 m .75474 .58649 L .72373 .59415 L p .707 .577 .707 r
F P
0 g
s
.2446 .66275 m .27452 .67201 L p .2725 .67312 L .707 .577 .707 r
F P
0 g
s
.24114 .67291 m .2409 .6719 L p .24141 .67192 L .707 .577 .707 r
F P
0 g
s
.2409 .6719 m .2446 .66275 L p .2725 .67312 L .707 .577 .707 r
F P
0 g
s
.25889 .60998 m .27215 .66525 L .24114 .67291 L p .707 .577 .707 r
F P
0 g
s
.23126 .6957 m .2409 .6719 L p .2725 .67312 L .707 .577 .707 r
F P
0 g
s
.22788 .61763 m .25889 .60998 L p .24141 .67192 L .707 .577 .707 r
F P
0 g
s
.2409 .6719 m .22788 .61763 L p .24141 .67192 L .707 .577 .707 r
F P
0 g
s
.75474 .58649 m .768 .64177 L .79673 .63293 L p .707 .577 .707 r
F P
0 g
s
.79673 .63293 m .78347 .57766 L .75474 .58649 L p .707 .577 .707 r
F P
0 g
s
.18899 .78961 m .18543 .77107 L .20921 .76261 L p .707 .577 .707 r
F P
0 g
s
.20921 .76261 m .21278 .78114 L .18899 .78961 L p .707 .577 .707 r
F P
0 g
s
.70673 .65515 m .69347 .59988 L .66692 .60311 L p .707 .577 .707 r
F P
0 g
s
.69347 .59988 m .70673 .65515 L .73699 .64943 L p .707 .577 .707 r
F P
0 g
s
.30357 .68504 m .29024 .71799 L .26119 .70496 L p .707 .577 .707 r
F P
0 g
s
.26119 .70496 m .27452 .67201 L .30357 .68504 L p .707 .577 .707 r
F P
0 g
s
.32693 .74257 m .33049 .76111 L .30362 .76284 L p .707 .577 .707 r
F P
0 g
s
.30362 .76284 m .30006 .74431 L .32693 .74257 L p .707 .577 .707 r
F P
0 g
s
.78347 .57766 m .79673 .63293 L .82037 .62378 L p .707 .577 .707 r
F P
0 g
s
.82037 .62378 m .80711 .5685 L .78347 .57766 L p .707 .577 .707 r
F P
0 g
s
.27452 .67201 m .26119 .70496 L .23126 .6957 L p .707 .577 .707 r
F P
0 g
s
.59464 .25249 m .58761 .75357 L .54885 .74675 L p .707 .577 .707 r
F P
0 g
s
.54885 .74675 m .55588 .24567 L .59464 .25249 L p .707 .577 .707 r
F P
0 g
s
.66692 .60311 m .68018 .65839 L .70673 .65515 L p .707 .577 .707 r
F P
0 g
s
.72361 .72688 m .73695 .69394 L .7079 .68091 L p .707 .577 .707 r
F P
0 g
s
.76983 .74731 m .76627 .72878 L .73497 .73508 L p .707 .577 .707 r
F P
0 g
s
.73695 .69394 m .72361 .72688 L .75354 .73614 L p .707 .577 .707 r
F P
0 g
s
.75354 .73614 m .76687 .7032 L .73695 .69394 L p .707 .577 .707 r
F P
0 g
s
.21278 .78114 m .20921 .76261 L .23818 .75484 L p .707 .577 .707 r
F P
0 g
s
.41842 .7483 m .42545 .24722 L .46693 .24289 L p .707 .577 .707 r
F P
0 g
s
.42545 .24722 m .41842 .7483 L .38447 .75599 L p .707 .577 .707 r
F P
0 g
s
.69456 .71385 m .7079 .68091 L .68256 .66539 L p .707 .577 .707 r
F P
0 g
s
.7079 .68091 m .69456 .71385 L .72361 .72688 L p .707 .577 .707 r
F P
0 g
s
.68018 .65839 m .66692 .60311 L .64669 .60354 L p .707 .577 .707 r
F P
0 g
s
.23818 .75484 m .24174 .77338 L .21278 .78114 L p .707 .577 .707 r
F P
0 g
s
.30006 .74431 m .30362 .76284 L .27304 .76707 L p .707 .577 .707 r
F P
0 g
s
.27304 .76707 m .26948 .74853 L .30006 .74431 L p .707 .577 .707 r
F P
0 g
s
.76983 .74731 m .79879 .73955 L p .76944 .72982 L .707 .577 .707 r
F P
0 g
s
.76627 .72878 m .76686 .73183 L p .76944 .72982 L .707 .577 .707 r
F P
0 g
s
.76686 .73183 m .76983 .74731 L p .76944 .72982 L .707 .577 .707 r
F P
0 g
s
.79879 .73955 m .79523 .72101 L .76627 .72878 L p .707 .577 .707 r
F P
0 g
s
.79523 .72101 m .79879 .73955 L .82258 .73108 L p .707 .577 .707 r
F P
0 g
s
.82258 .73108 m .81902 .71254 L .79523 .72101 L p .707 .577 .707 r
F P
0 g
s
.7814 .74073 m .80448 .7402 L p .79531 .70969 L .707 .577 .707 r
F P
0 g
s
.79474 .70779 m .79335 .71121 L p .79531 .70969 L .707 .577 .707 r
F P
0 g
s
.79335 .71121 m .7814 .74073 L p .79531 .70969 L .707 .577 .707 r
F P
0 g
s
.76687 .7032 m .75354 .73614 L .7814 .74073 L p .707 .577 .707 r
F P
0 g
s
.7814 .74073 m .79474 .70779 L .76687 .7032 L p .707 .577 .707 r
F P
0 g
s
.80711 .5685 m .82037 .62378 L .83659 .6152 L p .707 .577 .707 r
F P
0 g
s
.83659 .6152 m .82333 .55992 L .80711 .5685 L p .707 .577 .707 r
F P
0 g
s
.24174 .77338 m .23818 .75484 L .26948 .74853 L p .707 .577 .707 r
F P
0 g
s
.73853 .75362 m .73497 .73508 L .70438 .73931 L p .707 .577 .707 r
F P
0 g
s
.73497 .73508 m .73853 .75362 L .76983 .74731 L p .707 .577 .707 r
F P
0 g
s
.26948 .74853 m .27304 .76707 L .24174 .77338 L p .707 .577 .707 r
F P
0 g
s
.68018 .65839 m .67312 .64681 L .65975 .65796 L .707 .577 .707 r
F
.64669 .60354 m .65975 .65796 L p .67312 .64681 L F P
0 g
s
.64669 .60354 m .63475 .60111 L p .6595 .65779 L .707 .577 .707 r
F P
0 g
s
.65008 .68184 m .65975 .65796 L p .65084 .66538 L .707 .577 .707 r
F P
0 g
s
.65975 .65796 m .64669 .60354 L p .6595 .65779 L .707 .577 .707 r
F P
0 g
s
.6595 .65779 m .65278 .6424 L .64611 .64844 L .707 .577 .707 r
F
.63475 .60111 m .64611 .64844 L p .65278 .6424 L F P
0 g
s
.64555 .64694 m .64225 .63296 L .64233 .63463 L .707 .577 .707 r
F
.64611 .64844 m .63475 .60111 L p .64555 .64694 L F P
0 g
s
.6425 .65171 m .64533 .64635 L .64441 .6439 L .707 .577 .707 r
F
.63901 .66599 m .64611 .64844 L p .6425 .65171 L F P
0 g
s
.64611 .64844 m .64533 .64635 L .6425 .65171 L .707 .577 .707 r
F
.65234 .63304 m .63901 .66599 L .65008 .68184 L p F P
0 g
s
.64553 .65135 m .64801 .65639 L p .64555 .64694 L .707 .577 .707 r
F P
0 g
s
.63228 .59607 m .64254 .63885 L p .64555 .64694 L .707 .577 .707 r
F P
0 g
s
.63708 .65233 m .63901 .66599 L p .64056 .65966 L .707 .577 .707 r
F P
0 g
s
.65042 .61939 m .64254 .63885 L p .64056 .65966 L .707 .577 .707 r
F P
0 g
s
.64254 .63885 m .63708 .65233 L p .64056 .65966 L .707 .577 .707 r
F P
0 g
s
.63475 .60111 m .63228 .59607 L p .64233 .63463 L .707 .577 .707 r
F P
0 g
s
.64225 .63296 m .63475 .60111 L .64233 .63463 L .707 .577 .707 r
F
.63228 .59607 m .6395 .58892 L p .64343 .62953 L F P
0 g
s
.64254 .63885 m .64553 .65135 L p .64555 .64694 L .707 .577 .707 r
F P
0 g
s
.64441 .6439 m .64477 .64341 L .6447 .64273 L .707 .577 .707 r
F
.64477 .64341 m .65234 .63304 L .6447 .64273 L F
.65234 .63304 m .65042 .61939 L p .6447 .64273 L F P
0 g
s
.65042 .61939 m .65784 .60926 L p .64523 .63543 L .707 .577 .707 r
F P
0 g
s
.64533 .64635 m .65234 .63304 L .64441 .6439 L .707 .577 .707 r
F
.64553 .65135 m .64254 .63885 L p .64413 .63683 L F P
0 g
s
.64404 .63694 m .65042 .61939 L .64523 .63543 L .707 .577 .707 r
F
.64611 .64844 m .65234 .63304 L p .64533 .64635 L F P
0 g
s
.64801 .65639 m .64611 .64844 L p .64555 .64694 L .707 .577 .707 r
F P
0 g
s
.65975 .65796 m .65763 .65648 L .65084 .66538 L .707 .577 .707 r
F
.65084 .66538 m .65763 .65648 L .65145 .65217 L F
.64611 .64844 m .64801 .65639 L p .6595 .65779 L F P
0 g
s
.66341 .6489 m .65234 .63304 L p .65145 .65217 L .707 .577 .707 r
F P
0 g
s
.65276 .64419 m .64553 .65135 L p .64413 .63683 L .707 .577 .707 r
F P
0 g
s
.64254 .63885 m .65042 .61939 L p .64404 .63694 L .707 .577 .707 r
F P
0 g
s
.64939 .63013 m .65276 .64419 L p .64413 .63683 L .707 .577 .707 r
F P
0 g
s
.65784 .60926 m .64939 .63013 L p .63708 .65233 L .707 .577 .707 r
F P
0 g
s
.64939 .63013 m .6445 .6422 L .63766 .65155 L p .707 .577 .707 r
F P
0 g
s
.63766 .65155 m .63708 .65233 L p .64939 .63013 L .707 .577 .707 r
F P
0 g
s
.65784 .60926 m .67387 .60365 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.65276 .64419 m .64939 .63013 L p .6535 .6284 L .707 .577 .707 r
F P
0 g
s
.64939 .63013 m .65784 .60926 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.66899 .63562 m .65276 .64419 L p .6535 .6284 L .707 .577 .707 r
F P
0 g
s
.67387 .60365 m .66599 .62312 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.65573 .58034 m .66599 .62312 L p .6535 .6284 L .707 .577 .707 r
F P
0 g
s
.66599 .62312 m .66899 .63562 L p .6535 .6284 L .707 .577 .707 r
F P
0 g
s
.66054 .6366 m .6445 .6422 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.66599 .62312 m .66054 .6366 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.6445 .6422 m .64939 .63013 L p .65574 .62745 L .707 .577 .707 r
F P
0 g
s
.6535 .6284 m .64939 .63013 L .65379 .6221 L .707 .577 .707 r
F
.6395 .58892 m .65573 .58034 L p .65379 .6221 L F P
0 g
s
.64939 .63013 m .6395 .58892 L p .65379 .6221 L .707 .577 .707 r
F P
0 g
s
.6395 .58892 m .64939 .63013 L p .64413 .63683 L .707 .577 .707 r
F P
0 g
s
.64254 .63885 m .64404 .63694 L .64263 .64082 L .707 .577 .707 r
F
.64263 .64082 m .64404 .63694 L .64523 .63543 L F
.64413 .63683 m .64254 .63885 L .64343 .62953 L F
.64254 .63885 m .63228 .59607 L p .64343 .62953 L F P
0 g
s
.63708 .65233 m .64254 .63885 L p .64263 .64082 L .707 .577 .707 r
F P
0 g
s
.65975 .65796 m .66341 .6489 L p .65763 .65648 L .707 .577 .707 r
F P
0 g
s
.66189 .65877 m .68018 .65839 L p .65975 .65796 L .707 .577 .707 r
F P
0 g
s
.66341 .6489 m .65008 .68184 L .66922 .69833 L p .707 .577 .707 r
F P
0 g
s
.64801 .65639 m .65995 .65881 L p .6595 .65779 L .707 .577 .707 r
F P
0 g
s
.65995 .65881 m .65975 .65796 L p .6595 .65779 L .707 .577 .707 r
F P
0 g
s
.65763 .65648 m .66341 .6489 L .65145 .65217 L .707 .577 .707 r
F
.68256 .66539 m .66341 .6489 L p .6647 .65984 L F P
0 g
s
.66922 .69833 m .68212 .66646 L p .6647 .65984 L .707 .577 .707 r
F P
0 g
s
.68212 .66646 m .68256 .66539 L p .6647 .65984 L .707 .577 .707 r
F P
0 g
s
.65975 .65796 m .65995 .65881 L .66189 .65877 L p .707 .577 .707 r
F P
0 g
s
.55588 .24567 m .54885 .74675 L .50484 .74344 L p .707 .577 .707 r
F P
0 g
s
.50484 .74344 m .51187 .24236 L .55588 .24567 L p .707 .577 .707 r
F P
0 g
s
.68256 .66539 m .66922 .69833 L .69456 .71385 L p .707 .577 .707 r
F P
0 g
s
.70438 .73931 m .70795 .75785 L .73853 .75362 L p .707 .577 .707 r
F P
0 g
s
.4599 .74398 m .46693 .24289 L .51187 .24236 L p .707 .577 .707 r
F P
0 g
s
.46693 .24289 m .4599 .74398 L .41842 .7483 L p .707 .577 .707 r
F P
0 g
s
.70795 .75785 m .70438 .73931 L .67752 .74105 L p .707 .577 .707 r
F P
0 g
s
.80448 .7402 m .81781 .70725 L .79474 .70779 L p .707 .577 .707 r
F P
0 g
s
.51187 .24236 m .50484 .74344 L .4599 .74398 L p .707 .577 .707 r
F P
0 g
s
.67752 .74105 m .68108 .75958 L .70795 .75785 L p .707 .577 .707 r
F P
0 g
s
.82333 .55992 m .83659 .6152 L .84382 .60804 L p .707 .577 .707 r
F P
0 g
s
.84382 .60804 m .83056 .55277 L .82333 .55992 L p .707 .577 .707 r
F P
0 g
s
.68108 .75958 m .67752 .74105 L .65699 .74012 L p .707 .577 .707 r
F P
0 g
s
.65699 .74012 m .66055 .75866 L .68108 .75958 L p .707 .577 .707 r
F P
0 g
s
.81781 .70725 m .80448 .7402 L .82051 .73459 L p .707 .577 .707 r
F P
0 g
s
.81902 .71254 m .82258 .73108 L .83885 .72274 L p .707 .577 .707 r
F P
0 g
s
.83885 .72274 m .83529 .7042 L .81902 .71254 L p .707 .577 .707 r
F P
0 g
s
.82051 .73459 m .83385 .70165 L .81781 .70725 L p .707 .577 .707 r
F P
0 g
s
.66055 .75866 m .65699 .74012 L .64482 .73662 L p .707 .577 .707 r
F P
0 g
s
.83056 .55277 m .84382 .60804 L .84134 .60301 L p .707 .577 .707 r
F P
0 g
s
.84134 .60301 m .82808 .54773 L .83056 .55277 L p .707 .577 .707 r
F P
0 g
s
.64482 .73662 m .64838 .75516 L .66055 .75866 L p .707 .577 .707 r
F P
0 g
s
.83385 .70165 m .82051 .73459 L .82793 .72447 L p .707 .577 .707 r
F P
0 g
s
.83529 .7042 m .83885 .72274 L .84603 .71535 L p .707 .577 .707 r
F P
0 g
s
.84603 .71535 m .84247 .69681 L .83529 .7042 L p .707 .577 .707 r
F P
0 g
s
.82793 .72447 m .84127 .69152 L .83385 .70165 L p .707 .577 .707 r
F P
0 g
s
.64838 .75516 m .64482 .73662 L .64219 .7309 L p .707 .577 .707 r
F P
0 g
s
.64219 .7309 m .64576 .74944 L .64838 .75516 L p .707 .577 .707 r
F P
0 g
s
.82808 .54773 m .84134 .60301 L .8294 .60058 L p .707 .577 .707 r
F P
0 g
s
.8294 .60058 m .81614 .54531 L .82808 .54773 L p .707 .577 .707 r
F P
0 g
s
.84127 .69152 m .82793 .72447 L .82601 .71081 L p .707 .577 .707 r
F P
0 g
s
.82601 .71081 m .83796 .68129 L p .84127 .69152 L .707 .577 .707 r
F P
0 g
s
.83935 .67786 m .82601 .71081 L .81494 .69496 L p .707 .577 .707 r
F P
0 g
s
.83123 .70613 m .82826 .69065 L p .83984 .69109 L .707 .577 .707 r
F P
0 g
s
.82826 .69065 m .82767 .68759 L .83057 .68842 L p .707 .577 .707 r
F P
0 g
s
.83057 .68842 m .83984 .69109 L p .82826 .69065 L .707 .577 .707 r
F P
0 g
s
.83796 .68129 m .83935 .67786 L .8396 .6797 L p .707 .577 .707 r
F P
0 g
s
.8396 .6797 m .84127 .69152 L p .83796 .68129 L .707 .577 .707 r
F P
0 g
s
.84247 .69681 m .84603 .71535 L .8434 .70962 L p .707 .577 .707 r
F P
0 g
s
.8434 .70962 m .83984 .69109 L .84247 .69681 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.39398 .61267 m .38072 .5574 L .35046 .56312 L p .707 .577 .707 r
F P
0 g
s
.38072 .5574 m .39398 .61267 L .42499 .60502 L p .707 .577 .707 r
F P
0 g
s
.42499 .60502 m .41173 .54974 L .38072 .5574 L p .707 .577 .707 r
F P
0 g
s
.41173 .54974 m .42499 .60502 L .45372 .59618 L p .707 .577 .707 r
F P
0 g
s
.45372 .59618 m .44046 .5409 L .41173 .54974 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.36372 .6184 m .35046 .56312 L .32391 .56636 L p .707 .577 .707 r
F P
0 g
s
.35046 .56312 m .36372 .6184 L .39398 .61267 L p .707 .577 .707 r
F P
0 g
s
.44046 .5409 m .45372 .59618 L .47736 .58702 L p .707 .577 .707 r
F P
0 g
s
.47736 .58702 m .4641 .53175 L .44046 .5409 L p .707 .577 .707 r
F P
0 g
s
.64576 .74944 m .64219 .7309 L .64937 .7235 L p .707 .577 .707 r
F P
0 g
s
.64937 .7235 m .65293 .74204 L .64576 .74944 L p .707 .577 .707 r
F P
0 g
s
.81614 .54531 m .8294 .60058 L .80917 .60101 L p .707 .577 .707 r
F P
0 g
s
.80917 .60101 m .79591 .54573 L .81614 .54531 L p .707 .577 .707 r
F P
0 g
s
.32391 .56636 m .33717 .62163 L .36372 .6184 L p .707 .577 .707 r
F P
0 g
s
.81494 .69496 m .82827 .66201 L .83935 .67786 L p .707 .577 .707 r
F P
0 g
s
.3806 .68989 m .39394 .65694 L .36489 .64392 L p .707 .577 .707 r
F P
0 g
s
.42682 .71118 m .42326 .69265 L .39196 .69895 L p .707 .577 .707 r
F P
0 g
s
.39394 .65694 m .3806 .68989 L .41053 .69915 L p .707 .577 .707 r
F P
0 g
s
.41053 .69915 m .42386 .66621 L .39394 .65694 L p .707 .577 .707 r
F P
0 g
s
.83984 .69109 m .8434 .70962 L .83123 .70613 L p .707 .577 .707 r
F P
0 g
s
.35155 .67686 m .36489 .64392 L .33955 .62839 L p .707 .577 .707 r
F P
0 g
s
.36489 .64392 m .35155 .67686 L .3806 .68989 L p .707 .577 .707 r
F P
0 g
s
.33717 .62163 m .32391 .56636 L .30368 .56678 L p .707 .577 .707 r
F P
0 g
s
.42682 .71118 m .45578 .70342 L p .42582 .69349 L .707 .577 .707 r
F P
0 g
s
.42326 .69265 m .42374 .69512 L p .42582 .69349 L .707 .577 .707 r
F P
0 g
s
.42374 .69512 m .42682 .71118 L p .42582 .69349 L .707 .577 .707 r
F P
0 g
s
.45578 .70342 m .45222 .68488 L .42326 .69265 L p .707 .577 .707 r
F P
0 g
s
.45222 .68488 m .45578 .70342 L .47957 .69495 L p .707 .577 .707 r
F P
0 g
s
.47957 .69495 m .47601 .67641 L .45222 .68488 L p .707 .577 .707 r
F P
0 g
s
.43839 .70374 m .46147 .7032 L p .45234 .67285 L .707 .577 .707 r
F P
0 g
s
.45173 .67079 m .45023 .67449 L p .45234 .67285 L .707 .577 .707 r
F P
0 g
s
.45023 .67449 m .43839 .70374 L p .45234 .67285 L .707 .577 .707 r
F P
0 g
s
.42386 .66621 m .41053 .69915 L .43839 .70374 L p .707 .577 .707 r
F P
0 g
s
.43839 .70374 m .45173 .67079 L .42386 .66621 L p .707 .577 .707 r
F P
0 g
s
.4641 .53175 m .47736 .58702 L .49358 .57845 L p .707 .577 .707 r
F P
0 g
s
.49358 .57845 m .48032 .52317 L .4641 .53175 L p .707 .577 .707 r
F P
0 g
s
.39552 .71749 m .39196 .69895 L .36137 .70318 L p .707 .577 .707 r
F P
0 g
s
.39196 .69895 m .39552 .71749 L .42682 .71118 L p .707 .577 .707 r
F P
0 g
s
.67387 .60365 m .69695 .60312 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.66599 .62312 m .67387 .60365 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.65573 .58034 m .67936 .57119 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.66899 .63562 m .66599 .62312 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.66599 .62312 m .65573 .58034 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.69262 .62646 m .66899 .63562 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.69695 .60312 m .69072 .61852 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.67936 .57119 m .69072 .61852 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.69072 .61852 m .69262 .62646 L p .67115 .62216 L .707 .577 .707 r
F P
0 g
s
.68361 .63606 m .66054 .6366 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.69072 .61852 m .68361 .63606 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.66054 .6366 m .66599 .62312 L p .67753 .62097 L .707 .577 .707 r
F P
0 g
s
.33717 .62163 m .33003 .60994 L .3167 .62105 L .707 .577 .707 r
F
.30368 .56678 m .3167 .62105 L p .33003 .60994 L F P
0 g
s
.30368 .56678 m .29174 .56436 L p .31642 .62085 L .707 .577 .707 r
F P
0 g
s
.30707 .64485 m .3167 .62105 L p .30783 .62845 L .707 .577 .707 r
F P
0 g
s
.3167 .62105 m .30368 .56678 L p .31642 .62085 L .707 .577 .707 r
F P
0 g
s
.31642 .62085 m .30972 .60551 L .30306 .61154 L .707 .577 .707 r
F
.29174 .56436 m .30306 .61154 L p .30972 .60551 L F P
0 g
s
.30249 .61001 m .29921 .59607 L .29929 .59774 L .707 .577 .707 r
F
.30306 .61154 m .29174 .56436 L p .30249 .61001 L F P
0 g
s
.29947 .61478 m .30228 .60945 L .30138 .60702 L .707 .577 .707 r
F
.29599 .62899 m .30306 .61154 L p .29947 .61478 L F P
0 g
s
.30306 .61154 m .30228 .60945 L .29947 .61478 L .707 .577 .707 r
F
.30933 .59605 m .29599 .62899 L .30707 .64485 L p F P
0 g
s
.30252 .6146 m .305 .61963 L p .30249 .61001 L .707 .577 .707 r
F P
0 g
s
.28926 .55932 m .29949 .60195 L p .30249 .61001 L .707 .577 .707 r
F P
0 g
s
.29407 .61534 m .29599 .62899 L p .2975 .62285 L .707 .577 .707 r
F P
0 g
s
.30741 .58239 m .29949 .60195 L p .2975 .62285 L .707 .577 .707 r
F P
0 g
s
.29949 .60195 m .29407 .61534 L p .2975 .62285 L .707 .577 .707 r
F P
0 g
s
.29174 .56436 m .28926 .55932 L p .29929 .59774 L .707 .577 .707 r
F P
0 g
s
.29921 .59607 m .29174 .56436 L .29929 .59774 L .707 .577 .707 r
F
.28926 .55932 m .29649 .55216 L p .30039 .59251 L F P
0 g
s
.29949 .60195 m .30252 .6146 L p .30249 .61001 L .707 .577 .707 r
F P
0 g
s
.30138 .60702 m .30174 .60651 L .30167 .6058 L .707 .577 .707 r
F
.30174 .60651 m .30933 .59605 L .30167 .6058 L F
.30933 .59605 m .30741 .58239 L p .30167 .6058 L F P
0 g
s
.30741 .58239 m .31483 .57227 L p .30216 .59855 L .707 .577 .707 r
F P
0 g
s
.30228 .60945 m .30933 .59605 L .30138 .60702 L .707 .577 .707 r
F
.30252 .6146 m .29949 .60195 L p .3011 .5999 L F P
0 g
s
.30098 .60005 m .30741 .58239 L .30216 .59855 L .707 .577 .707 r
F
.30306 .61154 m .30933 .59605 L p .30228 .60945 L F P
0 g
s
.305 .61963 m .30306 .61154 L p .30249 .61001 L .707 .577 .707 r
F P
0 g
s
.3167 .62105 m .31458 .61957 L .30783 .62845 L .707 .577 .707 r
F
.30783 .62845 m .31458 .61957 L .30844 .61529 L F
.30306 .61154 m .305 .61963 L p .31642 .62085 L F P
0 g
s
.3204 .6119 m .30933 .59605 L p .30844 .61529 L .707 .577 .707 r
F P
0 g
s
.30975 .60744 m .30252 .6146 L p .3011 .5999 L .707 .577 .707 r
F P
0 g
s
.29949 .60195 m .30741 .58239 L p .30098 .60005 L .707 .577 .707 r
F P
0 g
s
.30634 .59323 m .30975 .60744 L p .3011 .5999 L .707 .577 .707 r
F P
0 g
s
.31483 .57227 m .30634 .59323 L p .29407 .61534 L .707 .577 .707 r
F P
0 g
s
.30634 .59323 m .30149 .60521 L .2947 .61449 L p .707 .577 .707 r
F P
0 g
s
.2947 .61449 m .29407 .61534 L p .30634 .59323 L .707 .577 .707 r
F P
0 g
s
.31483 .57227 m .33086 .56666 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.30975 .60744 m .30634 .59323 L p .31049 .59147 L .707 .577 .707 r
F P
0 g
s
.30634 .59323 m .31483 .57227 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.32598 .59886 m .30975 .60744 L p .31049 .59147 L .707 .577 .707 r
F P
0 g
s
.33086 .56666 m .32294 .58622 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.31272 .54359 m .32294 .58622 L p .31049 .59147 L .707 .577 .707 r
F P
0 g
s
.32294 .58622 m .32598 .59886 L p .31049 .59147 L .707 .577 .707 r
F P
0 g
s
.31752 .5996 m .30149 .60521 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.32294 .58622 m .31752 .5996 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.30149 .60521 m .30634 .59323 L p .31265 .59056 L .707 .577 .707 r
F P
0 g
s
.31049 .59147 m .30634 .59323 L .31079 .58511 L .707 .577 .707 r
F
.29649 .55216 m .31272 .54359 L p .31079 .58511 L F P
0 g
s
.30634 .59323 m .29649 .55216 L p .31079 .58511 L .707 .577 .707 r
F P
0 g
s
.29649 .55216 m .30634 .59323 L p .3011 .5999 L .707 .577 .707 r
F P
0 g
s
.29949 .60195 m .30098 .60005 L .29958 .6039 L .707 .577 .707 r
F
.29958 .6039 m .30098 .60005 L .30216 .59855 L F
.3011 .5999 m .29949 .60195 L .30039 .59251 L F
.29949 .60195 m .28926 .55932 L p .30039 .59251 L F P
0 g
s
.29407 .61534 m .29949 .60195 L p .29958 .6039 L .707 .577 .707 r
F P
0 g
s
.3167 .62105 m .3204 .6119 L p .31458 .61957 L .707 .577 .707 r
F P
0 g
s
.31922 .62201 m .33717 .62163 L p .3167 .62105 L .707 .577 .707 r
F P
0 g
s
.3204 .6119 m .30707 .64485 L .32621 .66134 L p .707 .577 .707 r
F P
0 g
s
.305 .61963 m .31694 .62206 L p .31642 .62085 L .707 .577 .707 r
F P
0 g
s
.31694 .62206 m .3167 .62105 L p .31642 .62085 L .707 .577 .707 r
F P
0 g
s
.31458 .61957 m .3204 .6119 L .30844 .61529 L .707 .577 .707 r
F
.33955 .62839 m .3204 .6119 L p .3217 .62295 L F P
0 g
s
.32621 .66134 m .33908 .62956 L p .3217 .62295 L .707 .577 .707 r
F P
0 g
s
.33908 .62956 m .33955 .62839 L p .3217 .62295 L .707 .577 .707 r
F P
0 g
s
.3167 .62105 m .31694 .62206 L .31922 .62201 L p .707 .577 .707 r
F P
0 g
s
.33955 .62839 m .32621 .66134 L .35155 .67686 L p .707 .577 .707 r
F P
0 g
s
.36137 .70318 m .36494 .72172 L .39552 .71749 L p .707 .577 .707 r
F P
0 g
s
.79591 .54573 m .80917 .60101 L .78262 .60424 L p .707 .577 .707 r
F P
0 g
s
.78262 .60424 m .76936 .54897 L .79591 .54573 L p .707 .577 .707 r
F P
0 g
s
.36494 .72172 m .36137 .70318 L .33451 .70491 L p .707 .577 .707 r
F P
0 g
s
.65293 .74204 m .64937 .7235 L .66565 .71517 L p .707 .577 .707 r
F P
0 g
s
.46147 .7032 m .4748 .67026 L .45173 .67079 L p .707 .577 .707 r
F P
0 g
s
.82827 .66201 m .81494 .69496 L .79579 .67846 L p .707 .577 .707 r
F P
0 g
s
.79579 .67846 m .80913 .64552 L .82827 .66201 L p .707 .577 .707 r
F P
0 g
s
.33451 .70491 m .33807 .72345 L .36494 .72172 L p .707 .577 .707 r
F P
0 g
s
.66565 .71517 m .66921 .7337 L .65293 .74204 L p .707 .577 .707 r
F P
0 g
s
.82767 .68759 m .83123 .70613 L .81071 .7052 L p .707 .577 .707 r
F P
0 g
s
.81071 .7052 m .80715 .68666 L .82767 .68759 L p .707 .577 .707 r
F P
0 g
s
.69695 .60312 m .72481 .60771 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.69262 .62646 m .69072 .61852 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.69072 .61852 m .69695 .60312 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.72135 .61762 m .69262 .62646 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.72481 .60771 m .72115 .61677 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.70809 .56235 m .72115 .61677 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.72115 .61677 m .72135 .61762 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.71148 .64065 m .68361 .63606 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.72115 .61677 m .71148 .64065 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.68361 .63606 m .69072 .61852 L p .71078 .61737 L .707 .577 .707 r
F P
0 g
s
.67936 .57119 m .70809 .56235 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.69072 .61852 m .67936 .57119 L p .69459 .6183 L .707 .577 .707 r
F P
0 g
s
.48032 .52317 m .49358 .57845 L .50081 .57129 L p .707 .577 .707 r
F P
0 g
s
.50081 .57129 m .48755 .51601 L .48032 .52317 L p .707 .577 .707 r
F P
0 g
s
.76936 .54897 m .78262 .60424 L .75236 .60997 L p .707 .577 .707 r
F P
0 g
s
.75236 .60997 m .7391 .55469 L .76936 .54897 L p .707 .577 .707 r
F P
0 g
s
.33807 .72345 m .33451 .70491 L .31398 .70399 L p .707 .577 .707 r
F P
0 g
s
.80913 .64552 m .79579 .67846 L .77045 .66294 L p .707 .577 .707 r
F P
0 g
s
.77045 .66294 m .78379 .63 L .80913 .64552 L p .707 .577 .707 r
F P
0 g
s
.31398 .70399 m .31754 .72253 L .33807 .72345 L p .707 .577 .707 r
F P
0 g
s
.4748 .67026 m .46147 .7032 L .4775 .6976 L p .707 .577 .707 r
F P
0 g
s
.47601 .67641 m .47957 .69495 L .49584 .68661 L p .707 .577 .707 r
F P
0 g
s
.49584 .68661 m .49228 .66807 L .47601 .67641 L p .707 .577 .707 r
F P
0 g
s
.4775 .6976 m .49084 .66465 L .4748 .67026 L p .707 .577 .707 r
F P
0 g
s
.72481 .60771 m .75474 .61697 L p .75287 .61799 L .707 .577 .707 r
F P
0 g
s
.72135 .61762 m .72115 .61677 L p .72159 .61679 L .707 .577 .707 r
F P
0 g
s
.72115 .61677 m .72481 .60771 L p .75287 .61799 L .707 .577 .707 r
F P
0 g
s
.7391 .55469 m .75236 .60997 L .72135 .61762 L p .707 .577 .707 r
F P
0 g
s
.71148 .64065 m .72115 .61677 L p .75287 .61799 L .707 .577 .707 r
F P
0 g
s
.70809 .56235 m .7391 .55469 L p .72159 .61679 L .707 .577 .707 r
F P
0 g
s
.72115 .61677 m .70809 .56235 L p .72159 .61679 L .707 .577 .707 r
F P
0 g
s
.66921 .7337 m .66565 .71517 L .68943 .7067 L p .707 .577 .707 r
F P
0 g
s
.68943 .7067 m .69299 .72524 L .66921 .7337 L p .707 .577 .707 r
F P
0 g
s
.78379 .63 m .77045 .66294 L .7414 .64991 L p .707 .577 .707 r
F P
0 g
s
.7414 .64991 m .75474 .61697 L .78379 .63 L p .707 .577 .707 r
F P
0 g
s
.80715 .68666 m .81071 .7052 L .78384 .70694 L p .707 .577 .707 r
F P
0 g
s
.78384 .70694 m .78028 .6884 L .80715 .68666 L p .707 .577 .707 r
F P
0 g
s
.75474 .61697 m .7414 .64991 L .71148 .64065 L p .707 .577 .707 r
F P
0 g
s
.31754 .72253 m .31398 .70399 L .30181 .70049 L p .707 .577 .707 r
F P
0 g
s
.48755 .51601 m .50081 .57129 L .49833 .56625 L p .707 .577 .707 r
F P
0 g
s
.49833 .56625 m .48507 .51098 L .48755 .51601 L p .707 .577 .707 r
F P
0 g
s
.30181 .70049 m .30537 .71903 L .31754 .72253 L p .707 .577 .707 r
F P
0 g
s
.69299 .72524 m .68943 .7067 L .71839 .69893 L p .707 .577 .707 r
F P
0 g
s
.49084 .66465 m .4775 .6976 L .48492 .68747 L p .707 .577 .707 r
F P
0 g
s
.49228 .66807 m .49584 .68661 L .50302 .67922 L p .707 .577 .707 r
F P
0 g
s
.50302 .67922 m .49946 .66068 L .49228 .66807 L p .707 .577 .707 r
F P
0 g
s
.48492 .68747 m .49826 .65453 L .49084 .66465 L p .707 .577 .707 r
F P
0 g
s
.71839 .69893 m .72195 .71747 L .69299 .72524 L p .707 .577 .707 r
F P
0 g
s
.78028 .6884 m .78384 .70694 L .75326 .71116 L p .707 .577 .707 r
F P
0 g
s
.75326 .71116 m .74969 .69263 L .78028 .6884 L p .707 .577 .707 r
F P
0 g
s
.72195 .71747 m .71839 .69893 L .74969 .69263 L p .707 .577 .707 r
F P
0 g
s
.74969 .69263 m .75326 .71116 L .72195 .71747 L p .707 .577 .707 r
F P
0 g
s
.30537 .71903 m .30181 .70049 L .29918 .69477 L p .707 .577 .707 r
F P
0 g
s
.29918 .69477 m .30274 .7133 L .30537 .71903 L p .707 .577 .707 r
F P
0 g
s
.48507 .51098 m .49833 .56625 L .48639 .56383 L p .707 .577 .707 r
F P
0 g
s
.48639 .56383 m .47313 .50855 L .48507 .51098 L p .707 .577 .707 r
F P
0 g
s
.49826 .65453 m .48492 .68747 L .483 .67381 L p .707 .577 .707 r
F P
0 g
s
.483 .67381 m .49484 .64457 L p .49826 .65453 L .707 .577 .707 r
F P
0 g
s
.49634 .64087 m .483 .67381 L .47193 .65796 L p .707 .577 .707 r
F P
0 g
s
.48822 .67 m .48514 .65393 L p .49683 .65495 L .707 .577 .707 r
F P
0 g
s
.48514 .65393 m .48466 .65146 L .487 .65213 L p .707 .577 .707 r
F P
0 g
s
.487 .65213 m .49683 .65495 L p .48514 .65393 L .707 .577 .707 r
F P
0 g
s
.49484 .64457 m .49634 .64087 L .49661 .64286 L p .707 .577 .707 r
F P
0 g
s
.49661 .64286 m .49826 .65453 L p .49484 .64457 L .707 .577 .707 r
F P
0 g
s
.49946 .66068 m .50302 .67922 L .50039 .67349 L p .707 .577 .707 r
F P
0 g
s
.50039 .67349 m .49683 .65495 L .49946 .66068 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .63512 Mdot
.3971 .68622 Mdot
.5 Mabswid
.30274 .7133 m .29918 .69477 L .30636 .68737 L p .707 .577 .707 r
F P
0 g
s
.47313 .50855 m .48639 .56383 L .46616 .56425 L p .707 .577 .707 r
F P
0 g
s
.46616 .56425 m .4529 .50898 L .47313 .50855 L p .707 .577 .707 r
F P
0 g
s
.30636 .68737 m .30992 .70591 L .30274 .7133 L p .707 .577 .707 r
F P
0 g
s
.47193 .65796 m .48526 .62502 L .49634 .64087 L p .707 .577 .707 r
F P
0 g
s
.49683 .65495 m .50039 .67349 L .48822 .67 L p .707 .577 .707 r
F P
0 g
s
.33086 .56666 m .35394 .56613 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.32294 .58622 m .33086 .56666 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.31272 .54359 m .33635 .53443 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.32598 .59886 m .32294 .58622 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.32294 .58622 m .31272 .54359 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.34961 .58971 m .32598 .59886 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.35394 .56613 m .34767 .58161 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.33635 .53443 m .34767 .58161 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.34767 .58161 m .34961 .58971 L p .32817 .58525 L .707 .577 .707 r
F P
0 g
s
.3406 .59907 m .31752 .5996 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.34767 .58161 m .3406 .59907 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.31752 .5996 m .32294 .58622 L p .33441 .58408 L .707 .577 .707 r
F P
0 g
s
.4529 .50898 m .46616 .56425 L .43961 .56749 L p .707 .577 .707 r
F P
0 g
s
.43961 .56749 m .42635 .51221 L .4529 .50898 L p .707 .577 .707 r
F P
0 g
s
.30992 .70591 m .30636 .68737 L .32264 .67904 L p .707 .577 .707 r
F P
0 g
s
.48526 .62502 m .47193 .65796 L .45278 .64147 L p .707 .577 .707 r
F P
0 g
s
.45278 .64147 m .46612 .60853 L .48526 .62502 L p .707 .577 .707 r
F P
0 g
s
.32264 .67904 m .3262 .69757 L .30992 .70591 L p .707 .577 .707 r
F P
0 g
s
.48466 .65146 m .48822 .67 L .4677 .66907 L p .707 .577 .707 r
F P
0 g
s
.4677 .66907 m .46414 .65053 L .48466 .65146 L p .707 .577 .707 r
F P
0 g
s
.35394 .56613 m .3818 .57071 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.34961 .58971 m .34767 .58161 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.34767 .58161 m .35394 .56613 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.37834 .58087 m .34961 .58971 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.3818 .57071 m .3781 .57987 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.36508 .52559 m .3781 .57987 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.3781 .57987 m .37834 .58087 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.36847 .60366 m .3406 .59907 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.3781 .57987 m .36847 .60366 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.3406 .59907 m .34767 .58161 L p .36763 .58047 L .707 .577 .707 r
F P
0 g
s
.33635 .53443 m .36508 .52559 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.34767 .58161 m .33635 .53443 L p .35162 .58139 L .707 .577 .707 r
F P
0 g
s
.42635 .51221 m .43961 .56749 L .40935 .57321 L p .707 .577 .707 r
F P
0 g
s
.40935 .57321 m .39609 .51794 L .42635 .51221 L p .707 .577 .707 r
F P
0 g
s
.46612 .60853 m .45278 .64147 L .42744 .62595 L p .707 .577 .707 r
F P
0 g
s
.42744 .62595 m .44078 .593 L .46612 .60853 L p .707 .577 .707 r
F P
0 g
s
.3818 .57071 m .41173 .57998 L p .40971 .58108 L .707 .577 .707 r
F P
0 g
s
.37834 .58087 m .3781 .57987 L p .37862 .57989 L .707 .577 .707 r
F P
0 g
s
.3781 .57987 m .3818 .57071 L p .40971 .58108 L .707 .577 .707 r
F P
0 g
s
.39609 .51794 m .40935 .57321 L .37834 .58087 L p .707 .577 .707 r
F P
0 g
s
.36847 .60366 m .3781 .57987 L p .40971 .58108 L .707 .577 .707 r
F P
0 g
s
.36508 .52559 m .39609 .51794 L p .37862 .57989 L .707 .577 .707 r
F P
0 g
s
.3781 .57987 m .36508 .52559 L p .37862 .57989 L .707 .577 .707 r
F P
0 g
s
.3262 .69757 m .32264 .67904 L .34642 .67057 L p .707 .577 .707 r
F P
0 g
s
.34642 .67057 m .34998 .68911 L .3262 .69757 L p .707 .577 .707 r
F P
0 g
s
.44078 .593 m .42744 .62595 L .39839 .61292 L p .707 .577 .707 r
F P
0 g
s
.39839 .61292 m .41173 .57998 L .44078 .593 L p .707 .577 .707 r
F P
0 g
s
.46414 .65053 m .4677 .66907 L .44083 .67081 L p .707 .577 .707 r
F P
0 g
s
.44083 .67081 m .43727 .65227 L .46414 .65053 L p .707 .577 .707 r
F P
0 g
s
.41173 .57998 m .39839 .61292 L .36847 .60366 L p .707 .577 .707 r
F P
0 g
s
.34998 .68911 m .34642 .67057 L .37538 .6628 L p .707 .577 .707 r
F P
0 g
s
.37538 .6628 m .37894 .68134 L .34998 .68911 L p .707 .577 .707 r
F P
0 g
s
.43727 .65227 m .44083 .67081 L .41024 .67503 L p .707 .577 .707 r
F P
0 g
s
.41024 .67503 m .40668 .6565 L .43727 .65227 L p .707 .577 .707 r
F P
0 g
s
.37894 .68134 m .37538 .6628 L .40668 .6565 L p .707 .577 .707 r
F P
0 g
s
.40668 .6565 m .41024 .67503 L .37894 .68134 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0
I7oo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0I7oo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP00
1UYF00<005YFFUH01EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH01EYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001UYF00<005YFFUH0
1EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF0P00IGoo001UOol01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IGoo001U
Ool01000FUIJEP001EYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP03FUH2001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF00=JEP8006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF
00EJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol200000eYF001JEP05FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00FUIoo`1UOol006Aoo`800003FUH005YF00EJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP03001JEUYF009JEP03001JEWoo06Eoo`00I7oo0P0000=JEP00FUH01EYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00<005YFOol0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
Ool0IGoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo
001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFOol0IGoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol0
1000FUIJEP001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF
00<005YFFUH01UYF00<005YFFUH00eYF2`0025YF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P00IWoo001TOol01000FUIJEP001UYF00<005YFFUH01UYF1P000eYF
00<005YFFUH00eYF00@005YF000000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8006Ioo`00I7oo00@005YFFUH000IJEP03001JEUYF009JEP@0009JEP03001J
EUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH00005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0006FUH50006FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH2001VOol006Aoo`04001JEUYF0002FUH40002FUH00`00FUIJEP07FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH01000FUIJEP001EYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001TOol00`00FUH000030006FUH00`00FUIJEP07
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP020004FUH00`00FUIJEP0:FUH00`00FUIJ
EP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2001VOol006Aoo`800003FUH005YF00QJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF008000AJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00HGoo0`0015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00GWoo0`001eYF00<0
05YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH000AJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8006Ioo`00FWoo1000
00=JEP00FUH01eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF0P00IWoo001HOol20005FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01@00FUIJEUYF000025YF
00<005YFFUH015YF00<005YFFUH00eYF00<005YFFUH00P000eYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0P00IWoo001GOol20007FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUH000000eYF00<0
05YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00:7oo3@00<Goo001E
Ool200000eYF001JEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUIJEP000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0087oo20000eYF00<005YFFUH00UYF00D005YFFUIJEP00035oo`00
E7oo00<005YFFUH00UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YFFUH00P000UYF00<005YFFUH02UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P006Goo1`000eYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00<7oo001COol20004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00
FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH0
0`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2000EOol40002FUH0
0`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000<7oo001BOol01000
FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<0
05YFFUH01EYF00<005YFFUH00eYF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00QJEP03
001JEUYF00EJEP03001JEUYF009JEP80015oo`@000IJEP03001JEUYF00IJEP03001JEUYF00EJEP03
001JEUYF009JEP05001JEUYFFUH0000`Ool0059oo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP02FUH;00001EYF001JEUYF0000
35YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P003goo0P0000=JEP00FUH025YF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUIJEP8002moo`00DWoo00@0
05YFFUH000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEPH0
00EJEP03001JEUYF009JEP@00003FUH005YF00]JEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEP8000aoo`<000=JEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJEP03001J
EUYF00=JEP03001JEUYF008002moo`00Dgoo00<005YF000015YF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH015YF00<005YFFUH00UYF00H005YF
FUH005YF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20009Ool30007FUH0
0`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;goo001COol01000FUIJEP000eYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH015YF1@00
25YF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P001goo0P0000=JEP00FUH01eYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00D005YFFUIJEP0002moo`00Dgoo00@005YFFUH0
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@00003FUH00000008000QJEP03001J
EUYF00AJEP03001JEUYF009JEP8000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP8000Eoo`8000=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF009JEP05001JEUYFFUH0000_Ool005=oo`04001JEUYF0004FUH0
0`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH30007FUH00`00FUIJEP05FUH01000FUH0
00001EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P000Woo
0`001UYF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YF
FUH00eYF00<005YFFUH00P00;Woo001DOol00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05
FUH00`00FUIJEP07FUH01000FUIJEUYF0P001EYF00<005YFFUH015YF0`001eYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF100000=JEP00FUH01UYF00<005YFFUH0
1EYF00<005YFFUH01eYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00D005YFFUIJ
EP0002ioo`00E7oo00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF00=JEP8000AJEP04001JEUYFFUH2000:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF0000;Woo001D
Ool01000FUIJEP000UYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF0P000UYF00@005YF000000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04
001JEUYFFUH20005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01@00FUIJEUYF0000;Woo001DOol00`00FUH00003FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP07FUH500000eYF001JEP0;
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJEP00FUH000EJEP03001J
EUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP04001JEUYF000^Ool005Eoo`80009JEP/000AJEP03001JEUYF00QJEP03001JEUYF00IJ
EP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEP000UYF00<005YFFUH00UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01eYF00@005YFFUIJEP/0009JEP03001oogoo02]oo`00D7oo1P0000AJEP00
001JEP80009JEP03001JEUYF00=JEPH000QJEP03001JEUYF00MJEP03001JEUYF009JEP03001JEP00
00aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYF0002FUH00`00FUIJ
EP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP04FUH60005FUH0
0`00FUIJEP02FUH4000]Ool004aoo`@0009JEP03001JEP0000800003FUH0000000AJEP03001JEUYF
00EJEP04001JEUYFFUH30005FUH00`00FUIJEP06FUH00`00FUIJEP04FUH2000<FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01`00FUIJEUYF001JEP0000EJEP03001JEUYF00AJEP03
001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00@000AJEP03001JEUYF00EJEP03001JEUYF009J
EP03001JEP0002eoo`00Agoo1@001UYF00<005YF00000UYF00@005YFFUH000=JEP03001JEUYF00EJ
EP03001JEUYF00AJEP<00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00001EYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH01EYF1@001eYF00<005YFFUH01EYF00<005YFFUH00UYF0P00;Woo
0013Ool40002FUH00`00FUIJEP07FUH01000FUH0000015YF00D005YFFUIJEP0000MJEP03001JEUYF
009JEPH000UJEP03001JEUYF00IJEP8000YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJEP05FUH00`00FUIJEP05FUH01000
FUIJEUYF1@000eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<007ooOol0;Goo
000oOol40006FUH00`00FUIJEP07FUH01000FUH000000eYF00<005YF00000UYF00<005YFFUH00UYF
20000UYF00@005YFFUIJEP8000IJEP03001JEUYF00IJEP03001JEUYF008000QJEP03001JEUYF00YJ
EP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00002FUH00`00FUIJEP02FUH00`00FUIJ
EP05FUH00`00FUIJEP05FUH40005FUH200000eYF001JEP07FUH00`00FUIJEP04FUH01@00FUIJEUYF
0000<7oo000mOol200000eYF001JEP08FUH00`00FUIJEP06FUH00`00FUH00003000015YF001JEUYF
20000UYF00<005YFFUH015YF00<005YFFUH00eYF0P0015YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YFFUH015YF00<005YFFUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF
00D005YF001JEP0000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP<000QJEP03
001JEUYF00EJEP<0035oo`00>Woo0`000eYF00<005YFFUH01eYF00<005YFFUH01UYF0P001EYF00<0
05YFFUH00UYF00@005YF001JEP800003FUH0000000IJEP03001JEUYF00EJEP800003FUH005YF00MJ
EP03001JEUYF00AJEP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00EJ
EP03001JEUYF009JEP05001JEP00FUH00003FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH01000FUIJEUYF0P001UYF00<005YFFUH015YF0P00<goo000gOol30007FUH00`00FUIJEP06
FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP04FUH20002FUH01000FUH000001UYF100015YF00@0
05YF000000QJEP03001JEUYF00AJEP8000AJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00EJEP03001JEUYF009JEP800003FUH005YF009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001J
EUYF00MJEP03001JEUYF00=JEP8000AJEP03001JEUYF009JEP8003Eoo`00<goo100000=JEP00FUH0
1eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000eYF00<005YFFUH015YF0`0000=JEP00
FUH00P001EYF1P000eYF00@005YFFUIJEP8000EJEP03001JEUYF00AJEP04001JEUYF0003FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH200000eYF001JEP02FUH0
0`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP06FUH20003FUH01000FUH0
0000=goo000aOol20005FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP06FUH20002FUH0
0`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP0000001EYF1P000eYF00<005YFFUH00eYF0P000eYF
00<005YFFUH015YF00@005YFFUH000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP800005FUH005YFFUH00003FUH50007FUH00`00FUIJEP06FUH00`00FUIJEP07
FUH6000iOol0031oo`8000MJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP05001J
EP00FUH00006FUH00`00FUIJEP02FUH01000FUH000001EYF1P000eYF00<005YFFUH01EYF0`001eYF
00D005YFFUIJEP00009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP<0009JEPH000AJEP@0009JEP03001JEUYF00IJEP03001JEUYF00MJEP04001JEUYFFUH2000j
Ool002ioo`800003FUH005YF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP04
001JEP000006FUH00`00FUIJEP04FUH20006FUH00`00FUH000020004FUH00`00FUIJEP07FUH00`00
FUIJEP04FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP03FUH70004FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP07FUH00`00FUIJEP03FUH2000h
Ool002eoo`03001JEUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EUYF00IJEP04001JEUYF0006FUH00`00FUIJEP06FUH20004FUH00`00FUIJEP06FUH00`00FUIJEP08
FUH00`00FUIJEP03FUH00`00FUIJEP03FUH00`00FUH0000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH20002FUH00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH40002
FUH00`00FUIJEP07FUH00`00FUIJEP06FUH00`00Oomoo`0eOol002aoo`8000AJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP05001JEUYFFUH00005FUH00`00FUIJ
EP06FUH01000FUH000000UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH00UYF00<005YF
FUH00UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00eYF0P00
00=JEP00FUH00UYF00D005YFFUIJEP0000MJEP03001JEUYF00AJEP@000UJEP03001JEUYF00IJEP80
03Ioo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00IJEP05001JEUYFFUH00003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30008FUH00`00
FUH0000E00000eYF001JEP0;FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20000
0eYF001JEP04FUH01000FUIJEP001eYF00<005YFFUH0100017oo0P001UYF00<005YFFUH01UYF00@0
05YFFUH003Eoo`00:goo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF009JEP04001JEUYF0008FUH00`00FUIJEP05FUH:0004FUH0
0`00FUIJEP04FUH00`00FUIJEP03FUH00`00FUIJEP0200000eYF001JEP0;FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH20002FUH200001EYF001JEUYF00000UYF00@005YFFUIJEPH0
00Yoo`8000AJEP03001JEUYF00IJEP04001JEUYFFUH2000cOol002]oo`04001JEUYF0004FUH00`00
FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH600000eYF00000008FUH0
0`00FUIJEP05FUH40002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01`00FUIJ
EUYF001JEP0000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<000=JEP<0009J
EPP0011oo`800003FUH005YF00QJEP03001JEUYF00=JEP03001oogoo031oo`00;7oo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0100015YF00D005YF
FUIJEP0000QJEP04001JEUYFFUH40006FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH01P00FUIJEP00FUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP8000AJ
EP03001JEUYF00AJEP8000=JEP03001oogoo011oo`8000QJEP03001JEUYF00EJEP03001oogoo02mo
o`00;7oo00@005YFFUH000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00EJEPD000QJ
EP03001JEUYF009JEP8000EJEPD00003FUH005YF00QJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF00=JEP04001JEUYFFUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH20004FUH00`00FUIJEP04FUH20003FUH00`00Oomoo`08Ool30007Ool20006FUH00`00FUIJEP05
FUH2000`Ool002aoo`04001JEUYF0003FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06
0002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH60005FUH00`00FUIJEP07FUH00`00FUIJEP02FUHC
0002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH30002FUH00`00FUIJ
EP05FUH400000eYF001oo`08Ool50008Ool20004FUH00`00FUIJEP04FUH00`00FUH0000`Ool002ao
o`04001JEUYF0004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH30006FUH40007FUH00`00FUIJEP04
FUH200000eYF001JEP07FUH00`00FUIJEP04FUH70007FUH00`00FUIJEP03FUH01@00FUIJEP00FUH0
1@0035YF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF00<005YFFUH015YF
0P000eYF0P002Goo1@002Woo0P0000=JEP00FUH01UYF00@005YFFUH002moo`00;Goo00<005YF0000
15YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH025YF00@005YF000000IJEP03001JEUYF
009JEP8000=JEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00EJEP03001JEUYF00=J
EP04001JEUYFFUH30002FUH2000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
00000eYF00000007FUH20005FUH20007Ool5000<Ool20006FUH00`00FUIJEP02FUH00`00Oomoo`0/
Ool002eoo`04001JEUYF0003FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUIJEP02FUH30004FUH01000FUH000001UYF00<005YFFUH015YF100000AJEP00000000AJEP03001J
EUYF00IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP02000<FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH300000eYF001JEP06FUH00`00FUIJEP06FUH00`00Oomoo`05
Ool3000?Ool00`00FUIJEP03FUH00`00FUIJEP02FUH00`00Oomoo`0/Ool002eoo`04001JEUYF0002
FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH20002FUH30007FUH00`00FUIJEP040003FUH60003FUH00`00FUIJEP05FUH00`00FUIJEP04FUH0
1@00FUIJEUYF00000UYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF0`000UYF00<005YFFUH00eYF0P0025YF0`0067oo00D005YFFUIJEP0000AJEP8002ioo`00
;Goo00<005YF00000eYF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01eYF00<005YFFUH0
1eYF0`000UYF00<005YFFUH015YF1@000UYF0P0000=JEP00FUH01@000UYF00<005YFFUH01UYF00<0
05YFFUH00eYF00@005YFFUIJEP80009JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH30003FUH00`00FUIJEP02FUH00`00FUIJEP06FUH01000FUIJEUYF0P0037oo
500000=JEP00Ool0;7oo000^Ool20002FUH;0004FUH00`00FUIJEP08FUH00`00FUIJEP06FUH30004
FUH01000FUIJEUYF0P0000Eoo`00FUIJEP0000AJEPP0009JEP03001JEUYF00IJEP03001JEUYF00=J
EP06001JEUYFFUH005YF0P000eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`0015YF0P000UYF00<005YFFUH01UYF00<005YFFUH00eYF0P000goo1`000eYF00<0
05YFFUH01EYF00<005YFFUH00eYF00<005YF00000P00;Goo000^Ool01@00FUH00000FUH00P000UYF
00<005YFFUH00eYF1P0025YF00<005YFFUH01eYF00<005YF000015YF00@005YF000000=oo`04001J
EUYF0006FUH50002FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP030005FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH200000eYF001JEP02FUH40008
FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00
FUIJEP02000]Ool002eoo`<00003FUH0000000AJEP03001JEUYF00EJEP04001JEUYFFUH30005FUH0
0`00FUIJEP06FUH20002FUH01000FUIJEUYF0P001Goo00@005YFFUH000AJEP/000MJEP03001JEUYF
00=JEP03001JEUYF008000MJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001J
EUYF009JEPL000=JEP03001JEUYF00IJEP03001JEUYF00D000IJEP03001JEUYF00EJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEP00000]Ool002eoo`04001JEUYF0002FUH01@00FUIJEWoo0000
1eYF00<005YFFUH015YF0`0000=JEP00FUH025YF0P000UYF00H005YF000005YF0005Ool80004FUH0
0`00FUIJEP04FUH40002FUH01000FUIJEUYF1P002EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0P000eYF00<005YFFUH00eYF0P001EYF10000UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH002eoo`00;7oo00@0
05YF000000AJEP05001JEUYFFUH00006FUH00`00FUIJEP05FUH40009FUH300000eYF000000090003
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH:000<FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH20003FUH00`00FUIJEP05FUH50006FUH00`00FUIJEP07FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH;00000eYF001oo`0/Ool002aoo`04001JEP000003FUH00`00FUH0
0002FUH00`00FUIJEP05FUH00`00FUIJEP040004Ool20006FUH00`00FUH0000200000eYF001JEP04
FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP040002FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH0
0`00FUIJEP04FUH30008FUH00`00FUIJEP07FUH00`00FUIJEP02FUH@0002FUH4000/Ool002aoo`03
001JEP000080009JEP03001JEUYF00d000Yoo`8000AJEP04001JEUYF0002FUH00`00FUIJEP03FUH0
0`00FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50006FUH00`00FUIJEP0:FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP02FUH2
0002FUH00`00FUIJEP07FUH00`00FUIJEP04FUH70006FUH00`00FUIJEP04FUH00`00FUH00002FUH0
1000FUH00000;7oo000/Ool00`00Ool00002FUH30004FUH00`00Oomoo`0DOol200000eYF001JEP02
FUH01@00FUIJEUYF00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH010002eYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P00
15YF00<005YF00000P0015YF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH01EYF0P00
1EYF0P0000QJEP00FUH005YF001JEP00;7oo000]Ool00`00FUIJEP02FUH00`00FUIJEP04FUH00`00
Oomoo`0EOol20003FUH20002FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP02FUH70003
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH20004FUH200000eYF001JEP05FUH00`00FUIJEP04FUH:0002FUH00`00FUIJ
EP06FUH00`00FUIJEP04FUH200001EYF001JEP00FUH00P00;Goo000]Ool00`00FUIJEP02FUH00`00
FUIJEP04FUH3000<Ool30008Ool20003FUHD00000eYF001JEP07FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH60003FUH0
0`00FUIJEP04FUH00`00FUIJEP05000015YF001JEUYF1@000UYF00<005YFFUH01UYF00<005YFFUH0
0eYF00@005YFFUIJEP800003FUH0000002ioo`00;Woo00@005YFFUH000IJEP05001JEUYFFUH0000:
Ool50009Ool20003FUH00`00FUIJEP04FUH00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH200000eYF00000005FUH00`00FUIJEP02FUH40005Ool300000eYF00000003
0002FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0`00<7oo000^Ool01000FUIJEP00
1UYF00<005YFFUH00UYF00<007ooOol01goo1@002goo0`001eYF00<005YF00000UYF00<005YFFUH0
15YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00<005YFFUH01EYF00<005YFFUH00UYF0`0000=JEP00FUH015YF00<005YF00000P0037oo1@00
0eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP80039oo`00;goo0P001UYF00<005YF
FUH015YF0P001goo1@003Goo00<005YFFUH015YF0P0000EJEP00FUIJEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF009JEP<00003FUH005YF00AJEP80019oo`<00003FUH005YF00MJEP03001JEUYF00=J
EP03001JEUYF008003=oo`00<7oo00<005YFFUH015YF00<005YFFUH01UYF0P001Woo0`003goo00<0
05YFFUH00eYF00@005YFFUH0009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP<0
009JEP03001JEUYF00<000ioo`H0009JEPD000AJEP03001JEUYF00=JEP04001JEP00000eOol0035o
o`03001JEUYF00=JEP03001JEUYF00IJEP04001JEP00000GOol00`00FUIJEP02FUH01000FUIJEP00
0UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0`000UYF50000eYF00<005YFFUH0
1UYF3@00=goo000bOol01@00FUIJEUYF000025YF00<005YFFUH00UYF0`002Woo4`000UYF00<005YF
FUH015YF00<005YFFUH01UYF00<005YFFUH015YF6@001UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00P001EYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YF
FUH01eYF00<005YFFUH01000?7oo000cOol01000FUIJEP0025YF00<005YFFUH01EYF2P0015YF00<0
05YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH015YF00<005YFFUH015YF2P0035YF00<0
05YFFUH02EYF2@0025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0000EJEP00001JEP0000EJEP03
001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00AJEPD0041oo`00=7oo0P0025YF00<005YFFUH0
1EYF10000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF0P000UYF00<005YFFUH0
15YF00<005YFFUH010002EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01UYF1P000UYF
00<005YFFUH01EYF00<005YFFUH00UYF0P0000=JEP0000000UYF00<005YFFUH00eYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01000AGoo000eOol00`00FUIJEP06FUH01000FUIJEUYF1000
1UYF00<005YFFUH01eYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUH000EJEP@0009JEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00@000IJ
EP03001JEUYF009JEP80009JEP800003FUH005YF00AJEP03001JEUYF00EJEP03001JEUYF009JEPH0
04Uoo`00=Woo0P001EYF1@0000=JEP00FUH01eYF00<005YFFUH01eYF00<005YFFUH015YF00<005YF
FUH00eYF00@005YFFUH000=JEP8000IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00AJEP8000AJEP03001JEUYF009JEP8000AJEQ@004moo`00>7oo
1P001EYF00<005YFFUH01eYF00<005YFFUH015YF40000UYF00<005YF00000P001eYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01UYF0`0000=JEP00
FUH00eYF0`001EYF00<005YFFUH015YF00<005YF0000Egoo000hOol200000eYF001JEP07FUH00`00
FUIJEP06FUH00`00FUIJEP040005FUH00`00FUIJEP03FUH00`00FUIJEP020002FUH20002FUH00`00
FUIJEP05FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00
FUIJEP07FUH01000FUH0000015YF0P0000=oo`0000000eYF00<005YFFUH015YF00@005YFFUH005Io
o`00=Woo0P000eYF00<005YFFUH01UYF00<005YFFUH00UYF20001eYF00<005YFFUH00eYF00@005YF
FUIJEP800003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYFFUH20002FUH20003Ool30006FUH0
0`00FUIJEP02FUH00`00Oomoo`1COol003Aoo`8000EJEP03001JEUYF00EJEPP000AJEP03001JEUYF
00IJEP03001JEUYF00=JEP04001JEUYFFUH200000eYF001JEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJ
EP03FUH40005Ool00`00FUIJEP04FUH00`00FUIJEP02FUH00`00Oomoo`1COol0039oo`<000MJEP03
001JEUYF009JEP8000=JEPH000=JEP03001JEUYF00EJEP04001JEUYF0003FUH01000FUIJEUYF1000
15YF00<005YFFUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
2EYF00<005YFFUH01eYF00<005YFFUH00eYF00@005YF000000Ioo`03001JEUYF009JEP03001JEUYF
009JEP8005Eoo`00<7oo0P000UYF00<005YFFUH01EYF00<005YF00000P0000Ioo`00001JEP00FUH5
0002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000FUIJEUYF0`0000=JEP00FUH00eYF00<005YF
FUH01EYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YF
FUH01eYF00<005YFFUH00eYF00<005YF00004P0000=JEP00Ool0Dgoo000_Ool20004FUH00`00FUIJ
EP03FUH30006Ool80002FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01P00FUIJEUYF001JEP<000AJ
EP03001JEUYF00EJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEUYF008000MJEP03001JEUYF00=JEP03001JEP00
008005Aoo`00;Woo00<005YF000015YF00<005YF00000`0037oo10000UYF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00`0000=oo`00000015YF00<005YFFUH01EYF00<005YFFUH025YF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<0
05YFFUH00P001eYF00<005YFFUH00eYF00<005YFFUH00P00E7oo000^Ool01000FUIJEP000eYF0P00
3goo2@001eYF00<005YFFUH015YF00@005YFFUH000Aoo`03001JEUYF009JEP03001JEUYF00EJEP03
001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03
001JEUYF00=JEP05001JEP00FUH00008FUH00`00FUIJEP03FUH01000FUH00000E7oo000^Ool01@00
FUIJEP00FUH00P003Goo10000UYF00<005YFFUH015YF10000UYF00<005YFFUH015YF00@005YF0000
00Ioo`05001JEUYFFUH00007FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEP00E7oo000^Ool200000eYF0000000?0006FUH00`00FUIJEP07FUH<0009Ool20000
0eYF001JEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20003FUH00`00FUIJEP02FUH;00000eYF001oo`1COol002io
o`<00003FUH005YF00AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF
00@0011oo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJ
EP03001JEUYF00MJEP03001JEUYF00=JEP03001JEP0000l0009JEP@005=oo`00;goo00@005YFFUH0
00EJEP03001JEUYF00AJEP03001JEUYF00MJEP03001JEUYF00AJEPD001Eoo`8000IJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEUYF
FUH40006FUH00`00FUIJEP04FUH00`00FUH00002FUH01000FUH00000Dgoo000_Ool01@00FUIJEUYF
00001EYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH0100077oo10000UYF00<005YFFUH0
25YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF00H005YF0000
05YF0007FUH20005FUH2000025YF001JEP00FUH005YF001COol002moo`80009JEP03001JEUYF00=J
EP03001JEUYF00AJEP03001JEUYF009JEPL002Aoo`D000QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00EJEP@000=JEP03001JEUYF00EJEP03001JEUYF00AJEP800005
FUH005YF001JEP02001DOol0035ooa@0031oo`H0009JEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00UJEP03001JEUYF00T0009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEP00009J
EP04001JEUYF001EOol007]oo`T000IJEP03001JEUYF00UJEP03001JEUYF00AJEP/00003FUH00000
00<0009JEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH4001FOol008AooaT000]oo`H0
009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF009JEP8005Qoo`00Sgoo00<005YF0000
1EYF0P004Goo100000=JEP00FUH01eYF00<005YFFUH00eYF00@005YFFUIJEP8005Uoo`00Sgoo00@0
05YFFUH0009JEP8000moo`H0009JEPD000AJEP03001JEUYF00=JEP03001JEUYF00<005Yoo`00Sgoo
00<005YFFUH050000eYF00<005YFFUH01UYF3P00GGoo002@Ool01000FUH000001EYF00<005YFFUH0
1EYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01000Hgoo002@Ool200000eYF001JEP04
FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP04FUH5001WOol0091oo`80009JEP03001J
EUYF009JEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00@006aoo`00TGoo0P0000=JEP00
FUH015YF00<005YFFUH01EYF00<005YFFUH00UYF1P00L7oo002COol40003FUH00`00FUIJEP02FUH8
001fOol009Moo`P007ioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00001\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {262.625, 33.375}} -> {-0.291303, \
0.145578, 0.00348964, 0.00348964}}]
}, Open  ]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]68\[InvisibleSpace]"     "\
\[InvisibleSpace]16.224616979580794`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 68, "     ", 16.224616979580794, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.63095 .75155 m .6174 .69931 L .58643 .70724 L p .707 .577 .707 r
F P
0 g
s
.6174 .69931 m .63095 .75155 L .6596 .74061 L p .707 .577 .707 r
F P
0 g
s
.6596 .74061 m .64606 .68837 L .6174 .69931 L p .707 .577 .707 r
F P
0 g
s
.59998 .75948 m .58643 .70724 L .55619 .71138 L p .707 .577 .707 r
F P
0 g
s
.58643 .70724 m .59998 .75948 L .63095 .75155 L p .707 .577 .707 r
F P
0 g
s
.64606 .68837 m .6596 .74061 L .68315 .72772 L p .707 .577 .707 r
F P
0 g
s
.68315 .72772 m .6696 .67548 L .64606 .68837 L p .707 .577 .707 r
F P
0 g
s
.55978 .78044 m .58905 .79191 L p .5819 .77087 L .707 .577 .707 r
F P
0 g
s
.56783 .75856 m .55619 .71138 L .56186 .75335 L .707 .577 .707 r
F
.5686 .75924 m .56845 .75868 L p .56783 .75856 L F P
0 g
s
.56845 .75868 m .55619 .71138 L p .56783 .75856 L .707 .577 .707 r
F P
0 g
s
.55619 .71138 m .52963 .71131 L p .56186 .75335 L .707 .577 .707 r
F P
0 g
s
.55619 .71138 m .5686 .75924 L p .59998 .75948 L .707 .577 .707 r
F P
0 g
s
.5819 .77087 m .57825 .7601 L .5686 .75924 L .707 .577 .707 r
F
.56783 .75856 m .55978 .78044 L p .5819 .77087 L F P
0 g
s
.58863 .76103 m .59998 .75948 L p .5686 .75924 L .707 .577 .707 r
F P
0 g
s
.58905 .79191 m .60224 .75604 L .57297 .74457 L p .707 .577 .707 r
F P
0 g
s
.5686 .75924 m .56973 .76361 L .58863 .76103 L p .707 .577 .707 r
F P
0 g
s
.57297 .74457 m .56783 .75856 L p .5686 .75924 L .707 .577 .707 r
F P
0 g
s
.57825 .7601 m .57297 .74457 L .5686 .75924 L .707 .577 .707 r
F
.55978 .78044 m .56783 .75856 L p .55323 .75588 L F P
0 g
s
.53401 .76913 m .55978 .78044 L p .55684 .76942 L .707 .577 .707 r
F P
0 g
s
.55684 .76942 m .55323 .75588 L .54722 .76003 L .707 .577 .707 r
F
.55684 .76942 m .54722 .76003 L .53401 .76913 L F
.52963 .71131 m .50935 .70706 L p .53243 .74561 L F P
0 g
s
.53996 .75295 m .52963 .71131 L .53243 .74561 L .707 .577 .707 r
F
.54058 .75356 m .54047 .75311 L p .53996 .75295 L F P
0 g
s
.54047 .75311 m .52963 .71131 L p .53996 .75295 L .707 .577 .707 r
F P
0 g
s
.53401 .76913 m .53996 .75295 L p .53131 .75018 L .707 .577 .707 r
F P
0 g
s
.52963 .71131 m .54058 .75356 L p .56554 .75814 L .707 .577 .707 r
F P
0 g
s
.5472 .73326 m .53996 .75295 L p .55323 .75588 L .707 .577 .707 r
F P
0 g
s
.53996 .75295 m .53979 .75341 L p .54058 .75356 L .707 .577 .707 r
F P
0 g
s
.55323 .75588 m .53996 .75295 L .54058 .75356 L .707 .577 .707 r
F
.53979 .75341 m .53401 .76913 L p .55323 .75588 L F P
0 g
s
.54317 .76355 m .54058 .75356 L p .53243 .74561 L .707 .577 .707 r
F P
0 g
s
.51427 .75907 m .53401 .76913 L p .53372 .76706 L .707 .577 .707 r
F P
0 g
s
.53372 .76706 m .53131 .75018 L .52456 .7537 L .707 .577 .707 r
F
.53372 .76706 m .52456 .7537 L .51427 .75907 L F
.50935 .70706 m .49734 .69903 L p .51399 .73829 L F P
0 g
s
.51914 .74581 m .50935 .70706 L .51399 .73829 L .707 .577 .707 r
F
.51955 .74641 m .51945 .746 L p .51914 .74581 L F P
0 g
s
.51945 .746 m .50935 .70706 L p .51914 .74581 L .707 .577 .707 r
F P
0 g
s
.51427 .75907 m .51914 .74581 L p .51478 .74304 L .707 .577 .707 r
F P
0 g
s
.50935 .70706 m .51955 .74641 L p .53608 .75171 L .707 .577 .707 r
F P
0 g
s
.52746 .7232 m .51914 .74581 L p .53131 .75018 L .707 .577 .707 r
F P
0 g
s
.51914 .74581 m .51899 .74623 L p .51955 .74641 L .707 .577 .707 r
F P
0 g
s
.53131 .75018 m .51914 .74581 L .51955 .74641 L .707 .577 .707 r
F
.51899 .74623 m .51427 .75907 L p .53131 .75018 L F P
0 g
s
.51427 .75907 m .51478 .74304 L .50955 .74653 L .707 .577 .707 r
F
.51233 .75779 m .51427 .75907 L p .50955 .74653 L F P
0 g
s
.50726 .73826 m .50248 .75126 L p .51478 .74304 L .707 .577 .707 r
F P
0 g
s
.51089 .75127 m .5229 .7593 L p .51187 .7333 L .707 .577 .707 r
F P
0 g
s
.49734 .69903 m .50746 .73805 L p .51187 .7333 L .707 .577 .707 r
F P
0 g
s
.50746 .73805 m .51089 .75127 L p .51187 .7333 L .707 .577 .707 r
F P
0 g
s
.50741 .73784 m .49734 .69903 L .5058 .7313 L .706 .577 .707 r
F
.50756 .73845 m .50746 .73805 L p .50741 .73784 L F P
0 g
s
.50746 .73805 m .49734 .69903 L p .50741 .73784 L .706 .577 .707 r
F P
0 g
s
.50726 .73826 m .50741 .73784 L p .50529 .74037 L .707 .577 .707 r
F P
0 g
s
.50741 .73784 m .51567 .71539 L p .50704 .73616 L .707 .577 .707 r
F P
0 g
s
.50706 .73625 m .50741 .73784 L .5058 .7313 L .706 .577 .707 r
F
.51645 .7441 m .51914 .74581 L .51399 .73829 L .707 .577 .707 r
F
.51567 .71539 m .50741 .73784 L p .51478 .74304 L F P
0 g
s
.50741 .73784 m .50726 .73826 L p .50756 .73845 L .707 .577 .707 r
F P
0 g
s
.51478 .74304 m .50741 .73784 L .50756 .73845 L .707 .577 .707 r
F
.51567 .71539 m .513 .71059 L p .50674 .73479 L F P
0 g
s
.50704 .73616 m .51567 .71539 L .50674 .73479 L .707 .577 .707 r
F
.50706 .73625 m .5058 .7313 L .50658 .73406 L .706 .577 .707 r
F
.4998 .74646 m .50248 .75126 L p .50674 .73479 L .707 .577 .707 r
F P
0 g
s
.49478 .68801 m .50191 .67509 L p .50685 .72524 L .707 .577 .707 r
F P
0 g
s
.513 .71059 m .50592 .72983 L p .50674 .73479 L .707 .577 .707 r
F P
0 g
s
.50674 .73479 m .50592 .72983 L .50579 .73048 L .707 .577 .707 r
F
.52746 .7232 m .51567 .71539 L p .51478 .74304 L F P
0 g
s
.513 .71059 m .51969 .70926 L p .51065 .72617 L .707 .577 .707 r
F P
0 g
s
.50832 .74025 m .50579 .73048 L p .50592 .72983 L .707 .577 .707 r
F P
0 g
s
.50832 .74025 m .50592 .72983 L .5072 .72884 L .707 .577 .707 r
F
.50579 .73048 m .49478 .68801 L p .50685 .72524 L F P
0 g
s
.50592 .72983 m .50575 .73029 L p .50579 .73048 L .707 .577 .707 r
F P
0 g
s
.49478 .68801 m .50198 .71581 L p .5058 .7313 L .706 .577 .707 r
F P
0 g
s
.5058 .7313 m .50432 .72529 L .50832 .74025 L .706 .577 .707 r
F
.50198 .71581 m .50567 .73002 L p .50432 .72529 L F P
0 g
s
.50567 .73002 m .50832 .74025 L p .50432 .72529 L .706 .577 .707 r
F P
0 g
s
.50592 .72983 m .513 .71059 L p .51065 .72617 L .707 .577 .707 r
F P
0 g
s
.51545 .72733 m .50832 .74025 L p .5072 .72884 L .707 .577 .707 r
F P
0 g
s
.51969 .70926 m .51481 .72253 L p .51065 .72617 L .707 .577 .707 r
F P
0 g
s
.51545 .72733 m .5144 .72327 L p .51481 .72253 L .707 .577 .707 r
F P
0 g
s
.51481 .72253 m .51969 .70926 L p .52915 .71854 L .707 .577 .707 r
F P
0 g
s
.51565 .7223 m .51481 .72253 L .5157 .72093 L .707 .577 .707 r
F
.51545 .72733 m .51481 .72253 L .51565 .7223 L F
.51969 .70926 m .53511 .71155 L p .52915 .71854 L F P
0 g
s
.5144 .72327 m .51545 .72733 L p .5072 .72884 L .707 .577 .707 r
F P
0 g
s
.50832 .74025 m .51089 .75127 L p .50706 .73625 L .706 .577 .707 r
F P
0 g
s
.50706 .73625 m .50658 .73406 L .50832 .74025 L .706 .577 .707 r
F
.51089 .75127 m .50756 .73845 L p .50741 .73784 L F P
0 g
s
.51089 .75127 m .50741 .73784 L .50706 .73625 L .706 .577 .707 r
F
.51803 .66151 m .53158 .71375 L .51545 .72733 L p .707 .577 .707 r
F P
0 g
s
.5065 .74513 m .51481 .72253 L p .52915 .71854 L .707 .577 .707 r
F P
0 g
s
.51481 .72253 m .5146 .72312 L p .5144 .72327 L .707 .577 .707 r
F P
0 g
s
.51065 .72617 m .51481 .72253 L .5144 .72327 L .707 .577 .707 r
F
.50191 .67509 m .51803 .66151 L p .5157 .72093 L F P
0 g
s
.5144 .72327 m .50191 .67509 L p .5157 .72093 L .707 .577 .707 r
F P
0 g
s
.50191 .67509 m .5144 .72327 L p .5072 .72884 L .707 .577 .707 r
F P
0 g
s
.50674 .73479 m .50654 .73387 L .4998 .74646 L .707 .577 .707 r
F
.49734 .69903 m .49478 .68801 L p .5058 .7313 L .706 .577 .707 r
F P
0 g
s
.50654 .73387 m .50575 .73029 L .4998 .74646 L .707 .577 .707 r
F
.50741 .73784 m .50704 .73616 L .50529 .74037 L F
.50529 .74037 m .50704 .73616 L .50674 .73479 L F
.50248 .75126 m .50726 .73826 L p .50529 .74037 L F P
0 g
s
.5065 .74513 m .4998 .74646 L p .51065 .72617 L .707 .577 .707 r
F P
0 g
s
.5146 .72312 m .5065 .74513 L p .51065 .72617 L .707 .577 .707 r
F P
0 g
s
.50669 .73359 m .50592 .72983 L .51065 .72617 L .707 .577 .707 r
F
.4998 .74646 m .50575 .73029 L p .50669 .73359 L F P
0 g
s
.50575 .73029 m .50592 .72983 L p .50669 .73359 L .707 .577 .707 r
F P
0 g
s
.5072 .72884 m .50592 .72983 L .50685 .72524 L .707 .577 .707 r
F
.50248 .75126 m .51233 .75779 L p .50955 .74653 L F P
0 g
s
.5229 .7593 m .51955 .74641 L p .51914 .74581 L .707 .577 .707 r
F P
0 g
s
.5229 .7593 m .51914 .74581 L .51645 .7441 L .707 .577 .707 r
F
.51914 .74581 m .52746 .7232 L p .51478 .74304 L F P
0 g
s
.5229 .7593 m .54317 .76355 L p .53608 .75171 L .707 .577 .707 r
F P
0 g
s
.51955 .74641 m .5229 .7593 L p .53608 .75171 L .707 .577 .707 r
F P
0 g
s
.5472 .73326 m .52746 .7232 L p .53131 .75018 L .707 .577 .707 r
F P
0 g
s
.53996 .75295 m .5472 .73326 L p .53131 .75018 L .707 .577 .707 r
F P
0 g
s
.54317 .76355 m .56973 .76361 L p .56554 .75814 L .707 .577 .707 r
F P
0 g
s
.54058 .75356 m .54317 .76355 L p .56554 .75814 L .707 .577 .707 r
F P
0 g
s
.57297 .74457 m .5472 .73326 L p .55323 .75588 L .707 .577 .707 r
F P
0 g
s
.56973 .76361 m .5686 .75924 L p .56186 .75335 L .707 .577 .707 r
F P
0 g
s
.56783 .75856 m .57297 .74457 L p .55323 .75588 L .707 .577 .707 r
F P
0 g
s
.60224 .75604 m .58905 .79191 L .61896 .80241 L p .707 .577 .707 r
F P
0 g
s
.61896 .80241 m .63215 .76654 L .60224 .75604 L p .707 .577 .707 r
F P
0 g
s
.63215 .76654 m .61896 .80241 L .64658 .81091 L p .707 .577 .707 r
F P
0 g
s
.64658 .81091 m .65977 .77504 L .63215 .76654 L p .707 .577 .707 r
F P
0 g
s
.6696 .67548 m .68315 .72772 L .69928 .71414 L p .707 .577 .707 r
F P
0 g
s
.69928 .71414 m .68573 .6619 L .6696 .67548 L p .707 .577 .707 r
F P
0 g
s
.65977 .77504 m .64658 .81091 L .6692 .81657 L p .707 .577 .707 r
F P
0 g
s
.6692 .81657 m .68239 .7807 L .65977 .77504 L p .707 .577 .707 r
F P
0 g
s
.6008 .85949 m .5974 .84169 L .56677 .84438 L p .707 .577 .707 r
F P
0 g
s
.5974 .84169 m .6008 .85949 L .63216 .85328 L p .707 .577 .707 r
F P
0 g
s
.63216 .85328 m .62876 .83548 L .5974 .84169 L p .707 .577 .707 r
F P
0 g
s
.62876 .83548 m .63216 .85328 L .66116 .84416 L p .707 .577 .707 r
F P
0 g
s
.66116 .84416 m .65776 .82636 L .62876 .83548 L p .707 .577 .707 r
F P
0 g
s
.56677 .84438 m .57017 .86218 L .6008 .85949 L p .707 .577 .707 r
F P
0 g
s
.68573 .6619 m .69928 .71414 L .70641 .70121 L p .707 .577 .707 r
F P
0 g
s
.70641 .70121 m .69286 .64898 L .68573 .6619 L p .707 .577 .707 r
F P
0 g
s
.57017 .86218 m .56677 .84438 L .53985 .84329 L p .707 .577 .707 r
F P
0 g
s
.65776 .82636 m .66116 .84416 L .68497 .83303 L p .707 .577 .707 r
F P
0 g
s
.68497 .83303 m .68157 .81523 L .65776 .82636 L p .707 .577 .707 r
F P
0 g
s
.53985 .84329 m .54325 .86109 L .57017 .86218 L p .707 .577 .707 r
F P
0 g
s
.68497 .83303 m .70126 .82097 L p .68167 .81526 L .707 .577 .707 r
F P
0 g
s
.68157 .81523 m .6816 .81538 L p .68167 .81526 L .707 .577 .707 r
F P
0 g
s
.6816 .81538 m .68497 .83303 L p .68167 .81526 L .707 .577 .707 r
F P
0 g
s
.70126 .82097 m .69786 .80317 L .68176 .81509 L p .707 .577 .707 r
F P
0 g
s
.68176 .81509 m .68157 .81523 L p .68167 .81526 L .707 .577 .707 r
F P
0 g
s
.70126 .82097 m .68176 .81509 L .68167 .81526 L .707 .577 .707 r
F
.69132 .81754 m .70451 .78167 L .69959 .78264 L p F P
0 g
s
.69959 .78264 m .69781 .78299 L p .69699 .78737 L .707 .577 .707 r
F P
0 g
s
.69132 .81754 m .69959 .78264 L .69699 .78737 L .707 .577 .707 r
F
.68462 .81886 m .69132 .81754 L p .69699 .78737 L F P
0 g
s
.69781 .78299 m .6946 .79171 L p .69699 .78737 L .707 .577 .707 r
F P
0 g
s
.6946 .79171 m .68462 .81886 L p .69699 .78737 L .707 .577 .707 r
F P
0 g
s
.68239 .7807 m .6692 .81657 L .68462 .81886 L p .707 .577 .707 r
F P
0 g
s
.68462 .81886 m .69781 .78299 L .68239 .7807 L p .707 .577 .707 r
F P
0 g
s
.54325 .86109 m .53985 .84329 L .51929 .83853 L p .707 .577 .707 r
F P
0 g
s
.51929 .83853 m .52269 .85633 L .54325 .86109 L p .707 .577 .707 r
F P
0 g
s
.69286 .64898 m .70641 .70121 L .70384 .6902 L p .706 .577 .707 r
F P
0 g
s
.70384 .6902 m .69029 .63796 L .69286 .64898 L p .706 .577 .707 r
F P
0 g
s
.52269 .85633 m .51929 .83853 L .50709 .83056 L p .707 .577 .707 r
F P
0 g
s
.69786 .80317 m .70126 .82097 L .70844 .80917 L p .707 .577 .707 r
F P
0 g
s
.70844 .80917 m .70504 .79137 L .69786 .80317 L p .707 .577 .707 r
F P
0 g
s
.50709 .83056 m .51049 .84836 L .52269 .85633 L p .707 .577 .707 r
F P
0 g
s
.4875 .82178 m .4875 .31989 L .4437 .31697 L p .707 .577 .707 r
F P
0 g
s
.51049 .84836 m .50709 .83056 L .50445 .82017 L p .707 .578 .707 r
F P
0 g
s
.50445 .82017 m .50785 .83797 L .51049 .84836 L p .707 .578 .707 r
F P
0 g
s
.50785 .83797 m .50445 .82017 L .51163 .80836 L p .707 .577 .707 r
F P
0 g
s
.51163 .80836 m .51503 .82616 L .50785 .83797 L p .707 .577 .707 r
F P
0 g
s
.53511 .71155 m .53328 .71652 L p .5065 .74513 L .707 .577 .707 r
F P
0 g
s
.53328 .71652 m .52192 .74742 L .51371 .7462 L p .707 .577 .707 r
F P
0 g
s
.51371 .7462 m .5065 .74513 L p .53328 .71652 L .707 .577 .707 r
F P
0 g
s
.54158 .64862 m .55187 .68832 L p .53158 .71375 L .707 .577 .707 r
F P
0 g
s
.55187 .68832 m .55513 .70086 L .5371 .71073 L p .707 .577 .707 r
F P
0 g
s
.52192 .74742 m .53511 .71155 L .55773 .71722 L p .707 .577 .707 r
F P
0 g
s
.5371 .71073 m .53158 .71375 L p .55187 .68832 L .707 .577 .707 r
F P
0 g
s
.53158 .71375 m .51803 .66151 L .54158 .64862 L p .707 .577 .707 r
F P
0 g
s
.51503 .82616 m .51163 .80836 L .52792 .7963 L p .707 .577 .707 r
F P
0 g
s
.52792 .7963 m .53132 .8141 L .51503 .82616 L p .707 .577 .707 r
F P
0 g
s
.55773 .71722 m .54454 .75309 L .52192 .74742 L p .707 .577 .707 r
F P
0 g
s
.53132 .8141 m .52792 .7963 L .55173 .78517 L p .707 .577 .707 r
F P
0 g
s
.55173 .78517 m .55513 .80297 L .53132 .8141 L p .707 .577 .707 r
F P
0 g
s
.4875 .31989 m .4875 .82178 L .53251 .82093 L p .707 .577 .707 r
F P
0 g
s
.53251 .82093 m .53251 .31904 L .4875 .31989 L p .707 .577 .707 r
F P
0 g
s
.55513 .70086 m .54158 .64862 L .57024 .63768 L p .707 .577 .707 r
F P
0 g
s
.57024 .63768 m .58379 .68992 L .55513 .70086 L p .707 .577 .707 r
F P
0 g
s
.54454 .75309 m .55773 .71722 L .58535 .72572 L p .707 .577 .707 r
F P
0 g
s
.58535 .72572 m .57216 .76158 L .54454 .75309 L p .707 .577 .707 r
F P
0 g
s
.55513 .80297 m .55173 .78517 L .58074 .77605 L p .707 .577 .707 r
F P
0 g
s
.58074 .77605 m .58414 .79385 L .55513 .80297 L p .707 .577 .707 r
F P
0 g
s
.53251 .31904 m .53251 .82093 L .57435 .81638 L p .707 .577 .707 r
F P
0 g
s
.58379 .68992 m .57024 .63768 L .6012 .62975 L p .707 .577 .707 r
F P
0 g
s
.58535 .72572 m .61526 .73621 L p .57876 .7577 L .707 .577 .707 r
F P
0 g
s
.57216 .76158 m .58019 .73975 L p .57876 .7577 L .707 .577 .707 r
F P
0 g
s
.58019 .73975 m .58535 .72572 L p .57876 .7577 L .707 .577 .707 r
F P
0 g
s
.63145 .62562 m .645 .67785 L .61475 .68199 L p .707 .577 .707 r
F P
0 g
s
.61475 .68199 m .6012 .62975 L .63145 .62562 L p .707 .577 .707 r
F P
0 g
s
.6012 .62975 m .61475 .68199 L .58379 .68992 L p .707 .577 .707 r
F P
0 g
s
.6703 .759 m .65711 .79487 L .63134 .78355 L p .707 .577 .707 r
F P
0 g
s
.63134 .78355 m .64453 .74768 L .6703 .759 L p .707 .577 .707 r
F P
0 g
s
.64453 .74768 m .63134 .78355 L .61067 .77545 L p .707 .577 .707 r
F P
0 g
s
.61067 .77545 m .60207 .77208 L p .61113 .76688 L .707 .577 .707 r
F P
0 g
s
.61113 .76688 m .64453 .74768 L .61067 .77545 L .707 .577 .707 r
F
.645 .67785 m .63145 .62562 L .65801 .62568 L p F P
0 g
s
.65711 .79487 m .66964 .76079 L p .69005 .76905 L .707 .577 .707 r
F P
0 g
s
.64612 .78495 m .64397 .7737 L p .66964 .76824 L .707 .577 .707 r
F P
0 g
s
.64397 .7737 m .64272 .76715 L .65593 .76769 L p .707 .577 .707 r
F P
0 g
s
.65593 .76769 m .66964 .76824 L p .64397 .7737 L .707 .577 .707 r
F P
0 g
s
.66964 .76079 m .6703 .759 L .67175 .75973 L p .707 .577 .707 r
F P
0 g
s
.67175 .75973 m .69005 .76905 L p .66964 .76079 L .707 .577 .707 r
F P
0 g
s
.61526 .73621 m .64453 .74768 L p .61113 .76688 L .707 .577 .707 r
F P
0 g
s
.60207 .77208 m .61235 .74412 L p .61113 .76688 L .707 .577 .707 r
F P
0 g
s
.61235 .74412 m .61526 .73621 L p .61113 .76688 L .707 .577 .707 r
F P
0 g
s
.64272 .76715 m .64612 .78495 L .61549 .78765 L p .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .6437 .28468 L .63668 .29226 L p .707 .577 .707 r
F P
0 g
s
.63668 .29226 m .6328 .29644 L p .63387 .34443 L .707 .577 .707 r
F P
0 g
s
.6437 .78657 m .63668 .29226 L .63387 .34443 L .707 .577 .707 r
F
.61549 .78765 m .61209 .76985 L .64272 .76715 L p F P
0 g
s
.6328 .79832 m .6437 .78657 L p .63387 .34443 L .707 .577 .707 r
F P
0 g
s
.6328 .29644 m .6328 .36425 L p .63387 .34443 L .707 .577 .707 r
F P
0 g
s
.6328 .36425 m .6328 .79832 L p .63387 .34443 L .707 .577 .707 r
F P
0 g
s
.61526 .73621 m .60207 .77208 L .57216 .76158 L p .707 .577 .707 r
F P
0 g
s
.58414 .79385 m .58074 .77605 L .61209 .76985 L p .707 .577 .707 r
F P
0 g
s
.61209 .76985 m .61549 .78765 L .58414 .79385 L p .707 .577 .707 r
F P
0 g
s
.60891 .8086 m .6328 .79832 L p .61113 .35236 L .707 .577 .707 r
F P
0 g
s
.60891 .30671 m .60891 .38015 L p .61113 .35236 L .707 .577 .707 r
F P
0 g
s
.60891 .38015 m .60891 .8086 L p .61113 .35236 L .707 .577 .707 r
F P
0 g
s
.57435 .81638 m .57435 .3145 L .53251 .31904 L p .707 .577 .707 r
F P
0 g
s
.69029 .63796 m .70384 .6902 L .69183 .68217 L p .707 .577 .707 r
F P
0 g
s
.69183 .68217 m .67829 .62993 L .69029 .63796 L p .707 .577 .707 r
F P
0 g
s
.4437 .81885 m .4437 .31697 L .40542 .31055 L p .707 .577 .707 r
F P
0 g
s
.4437 .31697 m .4437 .81885 L .4875 .82178 L p .707 .577 .707 r
F P
0 g
s
.70451 .78167 m .69132 .81754 L .68864 .81273 L p .707 .577 .707 r
F P
0 g
s
.68864 .81273 m .70183 .77686 L .70451 .78167 L p .707 .577 .707 r
F P
0 g
s
.57435 .3145 m .57435 .81638 L .60891 .8086 L p .707 .577 .707 r
F P
0 g
s
.60891 .8086 m .60891 .30671 L .57435 .3145 L p .707 .577 .707 r
F P
0 g
s
.70504 .79137 m .70844 .80917 L .7058 .79877 L p .707 .578 .707 r
F P
0 g
s
.7058 .79877 m .7024 .78097 L .70504 .79137 L p .707 .578 .707 r
F P
0 g
s
.40542 .81244 m .40542 .31055 L .37639 .30128 L p .707 .577 .707 r
F P
0 g
s
.40542 .31055 m .40542 .81244 L .4437 .81885 L p .707 .577 .707 r
F P
0 g
s
.67829 .62993 m .69183 .68217 L .67156 .67792 L p .707 .577 .707 r
F P
0 g
s
.67156 .67792 m .65801 .62568 L .67829 .62993 L p .707 .577 .707 r
F P
0 g
s
.25524 .68977 m .24934 .63241 L .21833 .63535 L p .707 .577 .707 r
F P
0 g
s
.24934 .63241 m .25524 .68977 L .2869 .68642 L p .707 .577 .707 r
F P
0 g
s
.2869 .68642 m .28101 .62906 L .24934 .63241 L p .707 .577 .707 r
F P
0 g
s
.21833 .63535 m .22422 .69271 L .25524 .68977 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.28101 .62906 m .2869 .68642 L .31611 .68299 L p .707 .577 .707 r
F P
0 g
s
.31611 .68299 m .31022 .62563 L .28101 .62906 L p .707 .577 .707 r
F P
0 g
s
.22422 .69271 m .21833 .63535 L .19099 .63759 L p .707 .577 .707 r
F P
0 g
s
.19099 .63759 m .19688 .69495 L .22422 .69271 L p .707 .577 .707 r
F P
0 g
s
.6328 .79832 m .6328 .29644 L .60891 .30671 L p .707 .577 .707 r
F P
0 g
s
.70183 .77686 m .68864 .81273 L .67686 .80492 L p .707 .577 .707 r
F P
0 g
s
.67686 .80492 m .69005 .76905 L .70183 .77686 L p .707 .577 .707 r
F P
0 g
s
.31022 .62563 m .31611 .68299 L .34001 .67982 L p .707 .577 .707 r
F P
0 g
s
.34001 .67982 m .33412 .62245 L .31022 .62563 L p .707 .577 .707 r
F P
0 g
s
.7024 .78097 m .7058 .79877 L .6936 .7908 L p .707 .577 .707 r
F P
0 g
s
.6936 .7908 m .6902 .773 L .7024 .78097 L p .707 .577 .707 r
F P
0 g
s
.19688 .69495 m .19099 .63759 L .17002 .63892 L p .707 .577 .707 r
F P
0 g
s
.65801 .62568 m .67156 .67792 L .645 .67785 L p .707 .577 .707 r
F P
0 g
s
.17002 .63892 m .17591 .69628 L .19688 .69495 L p .707 .577 .707 r
F P
0 g
s
.25524 .79879 m .25377 .7797 L .24088 .7804 L p .707 .577 .707 r
F P
0 g
s
.23129 .78599 m .23873 .78166 L .2227 .7814 L .707 .577 .707 r
F
.23753 .78059 m .2227 .7814 L p .23873 .78166 L F P
0 g
s
.2227 .7814 m .22417 .80049 L .25524 .79879 L p .707 .577 .707 r
F P
0 g
s
.22417 .80049 m .2227 .7814 L .20385 .78178 L p .707 .577 .707 r
F P
0 g
s
.20385 .78178 m .19535 .78196 L p .19958 .78468 L .707 .577 .707 r
F P
0 g
s
.22417 .80049 m .20385 .78178 L .19958 .78468 L .707 .577 .707 r
F
.24088 .7804 m .23753 .78059 L p .23873 .78166 L F P
0 g
s
.25524 .79879 m .24088 .7804 L .23129 .78599 L .707 .577 .707 r
F
.22086 .79326 m .25179 .80092 L p .22853 .76504 L F P
0 g
s
.22673 .76226 m .22586 .76685 L p .22853 .76504 L .707 .577 .707 r
F P
0 g
s
.22586 .76685 m .22086 .79326 L p .22853 .76504 L .707 .577 .707 r
F P
0 g
s
.22086 .79326 m .22531 .76971 L p .1993 .74963 L .707 .577 .707 r
F P
0 g
s
.22531 .76971 m .22673 .76226 L .20646 .75292 L p .707 .577 .707 r
F P
0 g
s
.20646 .75292 m .1993 .74963 L p .22531 .76971 L .707 .577 .707 r
F P
0 g
s
.25377 .7797 m .25524 .79879 L .28699 .79611 L p .707 .577 .707 r
F P
0 g
s
.28699 .79611 m .28652 .79009 L p .25377 .7797 L .707 .577 .707 r
F P
0 g
s
.28652 .79009 m .28552 .77701 L .26682 .77859 L p .707 .577 .707 r
F P
0 g
s
.26682 .77859 m .25377 .7797 L p .28652 .79009 L .707 .577 .707 r
F P
0 g
s
.25179 .80092 m .25709 .77292 L p .22673 .76226 L .707 .577 .707 r
F P
0 g
s
.25709 .77292 m .25766 .76992 L .24774 .76746 L p .707 .577 .707 r
F P
0 g
s
.24774 .76746 m .22673 .76226 L p .25709 .77292 L .707 .577 .707 r
F P
0 g
s
.25179 .80092 m .28319 .80286 L p .25803 .77041 L .707 .577 .707 r
F P
0 g
s
.25766 .76992 m .25751 .77071 L p .25803 .77041 L .707 .577 .707 r
F P
0 g
s
.25751 .77071 m .25179 .80092 L p .25803 .77041 L .707 .577 .707 r
F P
0 g
s
.28552 .77701 m .28699 .79611 L .3163 .7927 L p .707 .577 .707 r
F P
0 g
s
.3163 .7927 m .31565 .78423 L p .28552 .77701 L .707 .577 .707 r
F P
0 g
s
.31565 .78423 m .31483 .77361 L .29613 .77578 L p .707 .577 .707 r
F P
0 g
s
.29613 .77578 m .28552 .77701 L p .31565 .78423 L .707 .577 .707 r
F P
0 g
s
.28319 .80286 m .28891 .77266 L p .25766 .76992 L .707 .577 .707 r
F P
0 g
s
.28891 .77266 m .28906 .77186 L .28673 .77172 L p .707 .577 .707 r
F P
0 g
s
.28673 .77172 m .25766 .76992 L p .28891 .77266 L .707 .577 .707 r
F P
0 g
s
.37639 .80317 m .37639 .30128 L .35947 .29005 L p .707 .577 .707 r
F P
0 g
s
.37639 .30128 m .37639 .80317 L .40542 .81244 L p .707 .577 .707 r
F P
0 g
s
.28906 .77186 m .28319 .80286 L .312 .79889 L p .707 .577 .707 r
F P
0 g
s
.31483 .77361 m .3163 .7927 L .31918 .79225 L p .707 .577 .707 r
F P
0 g
s
.31918 .79225 m .34032 .78891 L p .32687 .78084 L .707 .577 .707 r
F P
0 g
s
.32687 .78084 m .31483 .77361 L .31918 .79225 L .707 .577 .707 r
F
.34032 .78891 m .3394 .77701 L p .31483 .77361 L F P
0 g
s
.3394 .77701 m .33885 .76982 L .32567 .7719 L p .707 .577 .707 r
F P
0 g
s
.32567 .7719 m .31483 .77361 L p .3394 .77701 L .707 .577 .707 r
F P
0 g
s
.312 .79889 m .31767 .76892 L p .28906 .77186 L .707 .577 .707 r
F P
0 g
s
.31767 .76892 m .31787 .76789 L .3157 .76818 L p .707 .577 .707 r
F P
0 g
s
.3157 .76818 m .28906 .77186 L p .31767 .76892 L .707 .577 .707 r
F P
0 g
s
.33885 .76982 m .34032 .78891 L .35668 .7851 L p .707 .577 .707 r
F P
0 g
s
.35668 .7851 m .35542 .76869 L p .35036 .76904 L .707 .577 .707 r
F P
0 g
s
.35668 .7851 m .35036 .76904 L .34789 .77757 L .707 .577 .707 r
F
.35542 .76869 m .35521 .76601 L .35139 .7669 L p F P
0 g
s
.35139 .7669 m .33885 .76982 L p .35542 .76869 L .707 .577 .707 r
F P
0 g
s
.35107 .7753 m .3575 .75799 L p .35701 .7461 L .707 .577 .707 r
F P
0 g
s
.35693 .7443 m .35581 .75024 L p .35701 .7461 L .707 .577 .707 r
F P
0 g
s
.35581 .75024 m .35107 .7753 L p .35701 .7461 L .707 .577 .707 r
F P
0 g
s
.34789 .77757 m .35036 .76904 L .33885 .76982 L .707 .577 .707 r
F
.33539 .78939 m .34056 .76208 L p .31787 .76789 L F P
0 g
s
.34056 .76208 m .34125 .75839 L .33655 .7603 L p .707 .577 .707 r
F P
0 g
s
.33655 .7603 m .31787 .76789 L p .34056 .76208 L .707 .577 .707 r
F P
0 g
s
.33539 .78939 m .35107 .7753 L p .3416 .75899 L .707 .577 .707 r
F P
0 g
s
.34125 .75839 m .34096 .75994 L p .3416 .75899 L .707 .577 .707 r
F P
0 g
s
.34096 .75994 m .33539 .78939 L p .3416 .75899 L .707 .577 .707 r
F P
0 g
s
.33412 .62245 m .34001 .67982 L .35626 .67721 L p .707 .577 .707 r
F P
0 g
s
.35626 .67721 m .35037 .61984 L .33412 .62245 L p .707 .577 .707 r
F P
0 g
s
.19535 .78196 m .19682 .80105 L .22417 .80049 L p .707 .577 .707 r
F P
0 g
s
.19343 .78063 m .1993 .74963 L .17806 .73326 L p .707 .577 .707 r
F P
0 g
s
.1993 .74963 m .19343 .78063 L .22086 .79326 L p .707 .577 .707 r
F P
0 g
s
.69005 .76905 m .67686 .80492 L .65711 .79487 L p .707 .577 .707 r
F P
0 g
s
.31787 .76789 m .312 .79889 L .33539 .78939 L p .707 .577 .707 r
F P
0 g
s
.6902 .773 m .6936 .7908 L .67304 .78604 L p .707 .577 .707 r
F P
0 g
s
.67304 .78604 m .66964 .76824 L .6902 .773 L p .707 .577 .707 r
F P
0 g
s
.17591 .69628 m .17002 .63892 L .15745 .6392 L p .707 .577 .707 r
F P
0 g
s
.15745 .6392 m .16334 .69656 L .17591 .69628 L p .707 .577 .707 r
F P
0 g
s
.19682 .80105 m .19535 .78196 L .17439 .78131 L p .707 .577 .707 r
F P
0 g
s
.17439 .78131 m .17586 .8004 L .19682 .80105 L p .707 .577 .707 r
F P
0 g
s
.17219 .76426 m .17806 .73326 L .16508 .71475 L p .707 .577 .707 r
F P
0 g
s
.17806 .73326 m .17219 .76426 L .19343 .78063 L p .707 .577 .707 r
F P
0 g
s
.35037 .61984 m .35626 .67721 L .36327 .67542 L p .707 .577 .707 r
F P
0 g
s
.36327 .67542 m .35738 .61806 L .35037 .61984 L p .707 .577 .707 r
F P
0 g
s
.35107 .7753 m .35693 .7443 L .34125 .75839 L p .707 .577 .707 r
F P
0 g
s
.66964 .76824 m .67304 .78604 L .64612 .78495 L p .707 .577 .707 r
F P
0 g
s
.3575 .75799 m .36337 .72699 L .35693 .7443 L p .707 .577 .707 r
F P
0 g
s
.35521 .76601 m .35668 .7851 L .36379 .78166 L p .707 .577 .707 r
F P
0 g
s
.36379 .78166 m .36232 .76256 L .35521 .76601 L p .707 .577 .707 r
F P
0 g
s
.35738 .61806 m .36327 .67542 L .36035 .67463 L p .707 .577 .707 r
F P
0 g
s
.36035 .67463 m .35446 .61726 L .35738 .61806 L p .707 .577 .707 r
F P
0 g
s
.36337 .72699 m .3575 .75799 L .35406 .73917 L p .707 .577 .707 r
F P
0 g
s
.35406 .73917 m .35993 .70817 L .36337 .72699 L p .707 .577 .707 r
F P
0 g
s
.35446 .61726 m .36035 .67463 L .34779 .67491 L p .707 .577 .707 r
F P
0 g
s
.35993 .70817 m .35406 .73917 L .34109 .72066 L p .707 .577 .707 r
F P
0 g
s
.34109 .72066 m .34696 .68966 L .35993 .70817 L p .707 .577 .707 r
F P
0 g
s
.35948 .75981 m .36095 .7789 L .34843 .77711 L p .707 .577 .707 r
F P
0 g
s
.34843 .77711 m .34697 .75802 L .35948 .75981 L p .707 .577 .707 r
F P
0 g
s
.35947 .79194 m .35947 .29005 L .3563 .27797 L p .707 .577 .707 r
F P
0 g
s
.36232 .76256 m .36379 .78166 L .36095 .7789 L p .707 .577 .707 r
F P
0 g
s
.36095 .7789 m .35948 .75981 L .36232 .76256 L p .707 .577 .707 r
F P
0 g
s
.35947 .29005 m .35947 .79194 L .37639 .80317 L p .707 .577 .707 r
F P
0 g
s
.17586 .8004 m .17439 .78131 L .16188 .77952 L p .707 .577 .707 r
F P
0 g
s
.16334 .69656 m .16217 .68513 L p .16198 .68756 L .707 .577 .707 r
F P
0 g
s
.15453 .63841 m .16042 .69577 L .16334 .69656 L p .707 .577 .707 r
F P
0 g
s
.15922 .74575 m .16508 .71475 L .16164 .69593 L p .707 .577 .707 r
F P
0 g
s
.16164 .69593 m .15578 .72693 L .15922 .74575 L p .707 .577 .707 r
F P
0 g
s
.16164 .69593 m .16808 .67862 L p .16447 .69279 L .707 .577 .707 r
F P
0 g
s
.15745 .6392 m .15453 .63841 L p .16198 .68756 L .707 .577 .707 r
F P
0 g
s
.16217 .68513 m .15745 .6392 L p .16198 .68756 L .707 .577 .707 r
F P
0 g
s
.16743 .69398 m .16351 .69499 L p .1661 .68906 L .707 .577 .707 r
F P
0 g
s
.1661 .68906 m .16808 .67862 L p .16938 .68838 L .707 .577 .707 r
F P
0 g
s
.16743 .69398 m .16703 .69005 L p .16826 .68917 L .707 .577 .707 r
F P
0 g
s
.1661 .68906 m .16938 .68838 L .16703 .69005 L .707 .577 .707 r
F
.18368 .69138 m .16743 .69398 L p .16826 .68917 L F P
0 g
s
.16808 .67862 m .18376 .66453 L p .17389 .68518 L .707 .577 .707 r
F P
0 g
s
.16938 .68838 m .16808 .67862 L .17389 .68518 L .707 .577 .707 r
F
.16826 .68917 m .18077 .6803 L .18368 .69138 L F
.18077 .6803 m .18376 .66453 L p .18647 .67972 L F P
0 g
s
.18368 .69138 m .18262 .68107 L p .18723 .67945 L .707 .577 .707 r
F P
0 g
s
.20758 .6882 m .18368 .69138 L p .18723 .67945 L .707 .577 .707 r
F P
0 g
s
.18376 .66453 m .20715 .65503 L p .19029 .67837 L .707 .577 .707 r
F P
0 g
s
.18647 .67972 m .18376 .66453 L .19029 .67837 L .707 .577 .707 r
F
.20715 .65503 m .23595 .65106 L p .21403 .67318 L F P
0 g
s
.21058 .67379 m .20715 .65503 L .21403 .67318 L .707 .577 .707 r
F
.20169 .63084 m .2309 .62741 L p .2133 .6733 L F P
0 g
s
.20758 .6882 m .20618 .67456 L p .2133 .6733 L .707 .577 .707 r
F P
0 g
s
.20361 .67369 m .20715 .65503 L p .21102 .67621 L .707 .577 .707 r
F P
0 g
s
.18723 .67945 m .20361 .67369 L .20758 .6882 L .707 .577 .707 r
F
.20601 .67285 m .20618 .67456 L p .20361 .67369 L F P
0 g
s
.20618 .67456 m .20758 .6882 L p .20361 .67369 L .707 .577 .707 r
F P
0 g
s
.2368 .68477 m .20758 .6882 L p .2133 .6733 L .707 .577 .707 r
F P
0 g
s
.23595 .65106 m .23238 .66993 L p .23157 .67007 L .707 .577 .707 r
F P
0 g
s
.2133 .6733 m .23238 .66993 L .2368 .68477 L .707 .577 .707 r
F
.23238 .66993 m .23595 .65106 L p .24059 .6708 L F P
0 g
s
.2368 .68477 m .23539 .67111 L p .24278 .67067 L .707 .577 .707 r
F P
0 g
s
.23539 .67111 m .24059 .6708 L .24119 .6734 L .707 .577 .707 r
F
.23238 .66993 m .24059 .6708 L .23539 .67111 L F
.23595 .65106 m .26736 .653 L p .24485 .67055 L F P
0 g
s
.26846 .68142 m .2368 .68477 L p .24278 .67067 L .707 .577 .707 r
F P
0 g
s
.24278 .67067 m .26426 .66939 L .26846 .68142 L .707 .577 .707 r
F
.2674 .67105 m .26846 .68142 L p .26426 .66939 L F P
0 g
s
.29948 .67848 m .26846 .68142 L p .2727 .67124 L .707 .577 .707 r
F P
0 g
s
.26736 .653 m .29829 .66066 L p .28113 .67154 L .707 .577 .707 r
F P
0 g
s
.27388 .67128 m .26736 .653 L .28113 .67154 L .707 .577 .707 r
F
.2727 .67124 m .29613 .67208 L .29948 .67848 L F
.29613 .67208 m .29829 .66066 L p .30545 .67522 L F P
0 g
s
.31907 .67687 m .29948 .67848 L p .30085 .67467 L .707 .577 .707 r
F P
0 g
s
.29613 .67208 m .30545 .67522 L .29907 .67445 L .707 .577 .707 r
F
.29829 .66066 m .32572 .67329 L p .3192 .67689 L F P
0 g
s
.30545 .67522 m .29829 .66066 L .3192 .67689 L .707 .577 .707 r
F
.29359 .62112 m .32092 .61887 L p .30085 .67467 L F P
0 g
s
.29948 .67848 m .29907 .67445 L p .30085 .67467 L .707 .577 .707 r
F P
0 g
s
.29829 .66066 m .29575 .67405 L p .2753 .67524 L .707 .577 .707 r
F P
0 g
s
.29575 .67405 m .29368 .68499 L p .28519 .68049 L .707 .577 .707 r
F P
0 g
s
.2753 .67524 m .29575 .67405 L .28519 .68049 L .707 .577 .707 r
F
.29907 .67445 m .29883 .67217 L p .30085 .67467 L F P
0 g
s
.29883 .67217 m .29359 .62112 L p .30038 .67123 L .707 .577 .707 r
F P
0 g
s
.29883 .67217 m .30038 .67123 L .30085 .67467 L .707 .577 .707 r
F
.30903 .6825 m .30545 .67522 L .3192 .67689 L F
.29907 .67445 m .30545 .67522 L .30903 .6825 L F
.32572 .67329 m .34696 .68966 L p .33643 .69534 L F P
0 g
s
.31985 .70429 m .3249 .67758 L p .33643 .69534 L .707 .577 .707 r
F P
0 g
s
.3249 .67758 m .32572 .67329 L p .33643 .69534 L .707 .577 .707 r
F P
0 g
s
.32572 .67329 m .31985 .70429 L .29242 .69166 L p .707 .577 .707 r
F P
0 g
s
.32092 .61887 m .32681 .67624 L .32417 .67645 L p .707 .577 .707 r
F P
0 g
s
.32417 .67645 m .31907 .67687 L p .31932 .66898 L .707 .577 .707 r
F P
0 g
s
.31932 .66898 m .32092 .61887 L .32417 .67645 L .707 .577 .707 r
F
.30085 .67467 m .32092 .61887 L .31907 .67687 L F
.29883 .67217 m .29907 .67445 L p .29613 .67208 L F P
0 g
s
.29907 .67445 m .29948 .67848 L p .29613 .67208 L .707 .577 .707 r
F P
0 g
s
.29242 .69166 m .29613 .67208 L p .30903 .6825 L .707 .577 .707 r
F P
0 g
s
.26426 .66939 m .26736 .653 L p .27388 .67128 L .707 .577 .707 r
F P
0 g
s
.26846 .68142 m .2674 .67105 L p .2727 .67124 L .707 .577 .707 r
F P
0 g
s
.2674 .67105 m .27388 .67128 L .2753 .67524 L .707 .577 .707 r
F
.26426 .66939 m .27388 .67128 L .2674 .67105 L F
.26257 .62406 m .29359 .62112 L p .2727 .67124 L F P
0 g
s
.23539 .67111 m .2368 .68477 L p .23238 .66993 L .707 .577 .707 r
F P
0 g
s
.26736 .653 m .26396 .67093 L p .23008 .68206 L .707 .577 .707 r
F P
0 g
s
.26396 .67093 m .26149 .684 L .24163 .68277 L p .707 .577 .707 r
F P
0 g
s
.24163 .68277 m .23008 .68206 L p .26396 .67093 L .707 .577 .707 r
F P
0 g
s
.2674 .67105 m .26721 .66921 L p .2727 .67124 L .707 .577 .707 r
F P
0 g
s
.26721 .66921 m .26257 .62406 L p .27175 .6668 L .707 .577 .707 r
F P
0 g
s
.26721 .66921 m .27175 .6668 L .2727 .67124 L .707 .577 .707 r
F
.29359 .62112 m .29883 .67217 L p .2727 .67124 L F P
0 g
s
.2753 .67524 m .27388 .67128 L .28113 .67154 L .707 .577 .707 r
F
.26149 .684 m .26426 .66939 L p .2753 .67524 L F P
0 g
s
.26257 .62406 m .26721 .66921 L p .26426 .66939 L .707 .577 .707 r
F P
0 g
s
.24059 .6708 m .23595 .65106 L .24485 .67055 L .707 .577 .707 r
F
.24278 .67067 m .24717 .66033 L .26426 .66939 L F
.24717 .66033 m .26257 .62406 L .26426 .66939 L F
.26721 .66921 m .2674 .67105 L p .26426 .66939 L F P
0 g
s
.29242 .69166 m .26149 .684 L p .2753 .67524 L .707 .577 .707 r
F P
0 g
s
.29368 .68499 m .29242 .69166 L p .2753 .67524 L .707 .577 .707 r
F P
0 g
s
.24119 .6734 m .24059 .6708 L .24485 .67055 L .707 .577 .707 r
F
.2309 .62741 m .26257 .62406 L p .24278 .67067 L F P
0 g
s
.21102 .67621 m .23595 .65106 L .23115 .6719 L .707 .577 .707 r
F
.21938 .67905 m .23115 .6719 L .22877 .68224 L F
.21102 .67621 m .23115 .6719 L .21938 .67905 L F
.23539 .67111 m .23522 .66943 L p .24278 .67067 L F P
0 g
s
.23522 .66943 m .2309 .62741 L p .24141 .66567 L .707 .577 .707 r
F P
0 g
s
.23522 .66943 m .24141 .66567 L .24278 .67067 L .707 .577 .707 r
F
.23522 .66943 m .23539 .67111 L p .23238 .66993 L F P
0 g
s
.23008 .68206 m .23238 .66993 L p .24119 .6734 L .707 .577 .707 r
F P
0 g
s
.2309 .62741 m .23522 .66943 L p .2133 .6733 L .707 .577 .707 r
F P
0 g
s
.23008 .68206 m .22877 .68224 L p .23157 .67007 L .707 .577 .707 r
F P
0 g
s
.23238 .66993 m .23008 .68206 L p .23157 .67007 L .707 .577 .707 r
F P
0 g
s
.22877 .68224 m .20128 .68603 L p .21102 .67621 L .707 .577 .707 r
F P
0 g
s
.18262 .68107 m .18368 .69138 L p .18077 .6803 L .707 .577 .707 r
F P
0 g
s
.20715 .65503 m .20335 .67506 L p .17789 .69553 L .707 .577 .707 r
F P
0 g
s
.20335 .67506 m .20128 .68603 L .17973 .69478 L p .707 .577 .707 r
F P
0 g
s
.17973 .69478 m .17789 .69553 L p .20335 .67506 L .707 .577 .707 r
F P
0 g
s
.20618 .67456 m .20601 .67285 L p .2133 .6733 L .707 .577 .707 r
F P
0 g
s
.20601 .67285 m .20169 .63084 L p .21184 .66798 L .707 .577 .707 r
F P
0 g
s
.20601 .67285 m .21184 .66798 L .2133 .6733 L .707 .577 .707 r
F
.21102 .67621 m .21058 .67379 L .21403 .67318 L F
.20128 .68603 m .20361 .67369 L p .21102 .67621 L F P
0 g
s
.20169 .63084 m .20601 .67285 L p .20361 .67369 L .707 .577 .707 r
F P
0 g
s
.18723 .67945 m .19029 .66916 L .20361 .67369 L .707 .577 .707 r
F
.19029 .66916 m .20169 .63084 L .20361 .67369 L F
.18703 .68288 m .18647 .67972 L .19029 .67837 L F
.18262 .68107 m .18647 .67972 L .18703 .68288 L F
.18077 .6803 m .18647 .67972 L .18262 .68107 L F
.17779 .63401 m .20169 .63084 L p .18723 .67945 L F P
0 g
s
.17789 .69553 m .16221 .70962 L p .16574 .70223 L .707 .577 .707 r
F P
0 g
s
.18376 .66453 m .18049 .68182 L p .16574 .70223 L .707 .577 .707 r
F P
0 g
s
.18049 .68182 m .17789 .69553 L p .16574 .70223 L .707 .577 .707 r
F P
0 g
s
.18262 .68107 m .18242 .67913 L p .18723 .67945 L .707 .577 .707 r
F P
0 g
s
.18242 .67913 m .17779 .63401 L p .18611 .67404 L .707 .577 .707 r
F P
0 g
s
.18242 .67913 m .18611 .67404 L .18723 .67945 L .707 .577 .707 r
F
.18242 .67913 m .18262 .68107 L p .18077 .6803 L F P
0 g
s
.17789 .69553 m .18077 .6803 L p .18703 .68288 L .707 .577 .707 r
F P
0 g
s
.17779 .63401 m .18242 .67913 L p .16826 .68917 L .707 .577 .707 r
F P
0 g
s
.17003 .69325 m .16938 .68838 L .17389 .68518 L .707 .577 .707 r
F
.16703 .69005 m .16938 .68838 L .17003 .69325 L F
.16221 .70962 m .15578 .72693 L p .16041 .70873 L F P
0 g
s
.16808 .67862 m .16575 .69096 L p .16041 .70873 L .707 .577 .707 r
F P
0 g
s
.16575 .69096 m .16221 .70962 L p .16041 .70873 L .707 .577 .707 r
F P
0 g
s
.16154 .63662 m .17779 .63401 L p .17095 .67362 L .707 .577 .707 r
F P
0 g
s
.16826 .68917 m .16767 .68454 L .17095 .67362 L .707 .577 .707 r
F
.16767 .68454 m .16154 .63662 L .17095 .67362 L F
.16703 .69005 m .16154 .63662 L p .16826 .68917 L F P
0 g
s
.16677 .68754 m .16703 .69005 L p .1661 .68906 L .707 .577 .707 r
F P
0 g
s
.16703 .69005 m .16743 .69398 L p .1661 .68906 L .707 .577 .707 r
F P
0 g
s
.16221 .70962 m .1661 .68906 L p .17003 .69325 L .707 .577 .707 r
F P
0 g
s
.16154 .63662 m .16677 .68754 L p .16042 .69577 L .707 .577 .707 r
F P
0 g
s
.1612 .70025 m .16164 .69593 L .16447 .69279 L .707 .577 .707 r
F
.16351 .69499 m .16042 .69577 L p .16677 .68754 L F P
0 g
s
.16029 .7092 m .1612 .70025 L .16447 .69279 L .707 .577 .707 r
F
.15578 .72693 m .16111 .69877 L p .16029 .7092 L F P
0 g
s
.16111 .69877 m .16164 .69593 L p .16029 .7092 L .707 .577 .707 r
F P
0 g
s
.16188 .77952 m .16334 .79861 L .17586 .8004 L p .707 .577 .707 r
F P
0 g
s
.16508 .71475 m .15922 .74575 L .17219 .76426 L p .707 .577 .707 r
F P
0 g
s
.6437 .28468 m .6437 .78657 L .64053 .77449 L p .707 .577 .707 r
F P
0 g
s
.64053 .77449 m .64053 .2726 L .6437 .28468 L p .707 .577 .707 r
F P
0 g
s
.16334 .79861 m .16188 .77952 L .15904 .77676 L p .707 .577 .707 r
F P
0 g
s
.15904 .77676 m .1605 .79586 L .16334 .79861 L p .707 .577 .707 r
F P
0 g
s
.16042 .69577 m .15453 .63841 L .16154 .63662 L p .707 .577 .707 r
F P
0 g
s
.3563 .27797 m .3563 .77986 L .35947 .79194 L p .707 .577 .707 r
F P
0 g
s
.3563 .77986 m .3563 .27797 L .36719 .26622 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .72716 Mdot
.5 Mabswid
.34779 .67491 m .3419 .61755 L .35446 .61726 L p .707 .577 .707 r
F P
0 g
s
.64053 .2726 m .64053 .77449 L .62361 .76327 L p .707 .577 .707 r
F P
0 g
s
.62361 .76327 m .62361 .26138 L .64053 .2726 L p .707 .577 .707 r
F P
0 g
s
.1605 .79586 m .15904 .77676 L .16614 .77331 L p .707 .577 .707 r
F P
0 g
s
.16614 .77331 m .16761 .79241 L .1605 .79586 L p .707 .577 .707 r
F P
0 g
s
.3419 .61755 m .34779 .67491 L .32681 .67624 L p .707 .577 .707 r
F P
0 g
s
.32681 .67624 m .32092 .61887 L .3419 .61755 L p .707 .577 .707 r
F P
0 g
s
.36719 .76811 m .36719 .26622 L .39109 .25595 L p .707 .577 .707 r
F P
0 g
s
.36719 .26622 m .36719 .76811 L .3563 .77986 L p .707 .577 .707 r
F P
0 g
s
.34696 .68966 m .34109 .72066 L .31985 .70429 L p .707 .577 .707 r
F P
0 g
s
.16761 .79241 m .16614 .77331 L .18251 .76951 L p .707 .577 .707 r
F P
0 g
s
.18251 .76951 m .18397 .7886 L .16761 .79241 L p .707 .577 .707 r
F P
0 g
s
.62361 .26138 m .62361 .76327 L .59458 .754 L p .707 .577 .707 r
F P
0 g
s
.59458 .754 m .59458 .25211 L .62361 .26138 L p .707 .577 .707 r
F P
0 g
s
.34697 .75802 m .34843 .77711 L .32748 .77646 L p .707 .577 .707 r
F P
0 g
s
.32748 .77646 m .32601 .75737 L .34697 .75802 L p .707 .577 .707 r
F P
0 g
s
.73743 .62696 m .70641 .62075 L p .7273 .66758 L .707 .577 .707 r
F P
0 g
s
.7326 .66803 m .73279 .66642 L p .7273 .66758 L .707 .577 .707 r
F P
0 g
s
.73279 .66642 m .73743 .62696 L p .72825 .66376 L .707 .577 .707 r
F P
0 g
s
.73279 .66642 m .72825 .66376 L .7273 .66758 L .707 .577 .707 r
F
.75186 .67364 m .75515 .66652 L .73603 .66832 L F
.76991 .67972 m .7588 .66978 L .75186 .67364 L F
.7588 .66978 m .75515 .66652 L .75186 .67364 L F
.75837 .6814 m .76991 .67972 L p .73603 .66832 L F P
0 g
s
.76909 .62837 m .76478 .66509 L p .78307 .65629 L .707 .577 .707 r
F P
0 g
s
.76478 .66509 m .7646 .66656 L p .76762 .66489 L .707 .577 .707 r
F P
0 g
s
.78307 .65629 m .76478 .66509 L .76762 .66489 L .707 .577 .707 r
F
.77123 .67956 m .79872 .67626 L p .78898 .66658 L F P
0 g
s
.79831 .62484 m .79399 .66154 L p .80971 .65141 L .707 .577 .707 r
F P
0 g
s
.79399 .66154 m .79382 .66304 L p .79638 .66116 L .707 .577 .707 r
F P
0 g
s
.80971 .65141 m .79399 .66154 L .79638 .66116 L .707 .577 .707 r
F
.79872 .67626 m .82211 .67425 L p .80971 .65904 L F P
0 g
s
.79638 .66116 m .79872 .67626 L p .80971 .65904 L .707 .577 .707 r
F P
0 g
s
.78898 .66658 m .78942 .66335 L .78597 .66359 L .707 .577 .707 r
F
.76991 .67972 m .77123 .67956 L p .78597 .66359 L F P
0 g
s
.78898 .66658 m .78597 .66359 L .77123 .67956 L .707 .577 .707 r
F
.76762 .66489 m .76991 .67972 L p .78597 .66359 L F P
0 g
s
.73743 .62696 m .73279 .66642 L p .73574 .66643 L .707 .577 .707 r
F P
0 g
s
.75722 .66653 m .75283 .65775 L .73574 .66643 L .707 .577 .707 r
F
.75283 .65775 m .73743 .62696 L .73574 .66643 L F
.73851 .6843 m .73603 .66832 L p .7326 .66803 L F P
0 g
s
.7247 .67204 m .7326 .66803 L .71887 .66686 L .707 .577 .707 r
F
.73851 .6843 m .7326 .66803 L .7247 .67204 L F
.73603 .66832 m .73574 .66643 L p .7326 .66803 L F P
0 g
s
.76909 .62837 m .73743 .62696 L p .75722 .66653 L .707 .577 .707 r
F P
0 g
s
.76405 .64181 m .73264 .64639 L p .75515 .66652 L .707 .577 .707 r
F P
0 g
s
.7588 .66978 m .75941 .66654 L .75515 .66652 L .707 .577 .707 r
F
.7646 .66656 m .76909 .62837 L p .75722 .66653 L F P
0 g
s
.75941 .66654 m .76405 .64181 L .75515 .66652 L .707 .577 .707 r
F
.76991 .67972 m .76762 .66489 L p .7588 .66978 L F P
0 g
s
.76762 .66489 m .76405 .64181 L p .7588 .66978 L .707 .577 .707 r
F P
0 g
s
.7632 .67849 m .7646 .66656 L p .75722 .66653 L .707 .577 .707 r
F P
0 g
s
.73574 .66643 m .73603 .66832 L p .75515 .66652 L .707 .577 .707 r
F P
0 g
s
.73603 .66832 m .73851 .6843 L .75837 .6814 L p .707 .577 .707 r
F P
0 g
s
.75722 .66653 m .73574 .66643 L .73154 .67708 L .707 .577 .707 r
F
.73279 .66642 m .7326 .66803 L p .73574 .66643 L F P
0 g
s
.7326 .66803 m .73154 .67708 L p .73574 .66643 L .707 .577 .707 r
F P
0 g
s
.70758 .68954 m .73851 .6843 L p .71887 .66686 L .707 .577 .707 r
F P
0 g
s
.70387 .66559 m .70758 .68954 L p .71887 .66686 L .707 .577 .707 r
F P
0 g
s
.70641 .62075 m .67908 .61034 L p .69915 .667 L .707 .577 .707 r
F P
0 g
s
.70758 .68954 m .70424 .668 L p .69097 .67332 L .707 .577 .707 r
F P
0 g
s
.70424 .668 m .70387 .66559 L p .70093 .66735 L .707 .577 .707 r
F P
0 g
s
.70424 .668 m .70093 .66735 L .69097 .67332 L .707 .577 .707 r
F
.67908 .61034 m .67318 .66046 L .67582 .66147 L p F P
0 g
s
.67318 .66046 m .67908 .61034 L .6581 .59675 L p .707 .577 .707 r
F P
0 g
s
.6581 .59675 m .65221 .64687 L .67318 .66046 L p .707 .577 .707 r
F P
0 g
s
.67428 .65702 m .65304 .66204 L p .66356 .67481 L .707 .577 .707 r
F P
0 g
s
.68015 .69493 m .67509 .66226 L p .66356 .67481 L .707 .577 .707 r
F P
0 g
s
.67509 .66226 m .67428 .65702 L p .66356 .67481 L .707 .577 .707 r
F P
0 g
s
.67582 .66147 m .68093 .66341 L p .68068 .65618 L .707 .577 .707 r
F P
0 g
s
.68068 .65618 m .67908 .61034 L .67582 .66147 L .707 .577 .707 r
F
.69097 .67332 m .69455 .66609 L .6808 .66338 L F
.69915 .667 m .67908 .61034 L .68093 .66341 L F
.70093 .66735 m .70641 .62075 L p .69915 .667 L F P
0 g
s
.70641 .62075 m .70117 .66536 L p .70387 .66559 L .707 .577 .707 r
F P
0 g
s
.70117 .66536 m .70052 .67087 L p .7273 .66758 L .707 .577 .707 r
F P
0 g
s
.70387 .66559 m .70171 .65163 L p .69097 .67332 L .707 .577 .707 r
F P
0 g
s
.68093 .66341 m .70052 .67087 L p .69915 .667 L .707 .577 .707 r
F P
0 g
s
.70052 .67087 m .70093 .66735 L p .69915 .667 L .707 .577 .707 r
F P
0 g
s
.70171 .65163 m .67428 .65702 L p .6808 .66338 L .707 .577 .707 r
F P
0 g
s
.69455 .66609 m .70171 .65163 L .6808 .66338 L .707 .577 .707 r
F
.7273 .66758 m .72166 .65493 L .70387 .66559 L F
.72166 .65493 m .70641 .62075 L .70387 .66559 L F
.70052 .67087 m .73154 .67708 L p .7273 .66758 L F P
0 g
s
.70171 .65163 m .70387 .66559 L p .71887 .66686 L .707 .577 .707 r
F P
0 g
s
.7326 .66803 m .73264 .64639 L .71887 .66686 L .707 .577 .707 r
F
.73574 .66643 m .73264 .64639 L p .7326 .66803 L F P
0 g
s
.7632 .67849 m .79242 .67496 L p .7867 .66354 L .707 .577 .707 r
F P
0 g
s
.7867 .66354 m .78307 .65629 L .7759 .6643 L .707 .577 .707 r
F
.7867 .66354 m .7759 .6643 L .7632 .67849 L F
.7646 .66656 m .7632 .67849 L p .78307 .65629 L F P
0 g
s
.79831 .62484 m .76909 .62837 L p .7867 .66354 L .707 .577 .707 r
F P
0 g
s
.79872 .67626 m .79664 .66284 L p .78898 .66658 L .707 .577 .707 r
F P
0 g
s
.79664 .66284 m .79382 .66304 L .78898 .66658 L .707 .577 .707 r
F
.79382 .66304 m .79831 .62484 L p .7867 .66354 L F P
0 g
s
.79638 .66116 m .79285 .63835 L p .78898 .66658 L .707 .577 .707 r
F P
0 g
s
.79242 .67496 m .79382 .66304 L p .7867 .66354 L .707 .577 .707 r
F P
0 g
s
.79664 .66284 m .79638 .66116 L p .79382 .66304 L .707 .577 .707 r
F P
0 g
s
.79285 .63835 m .76405 .64181 L p .78597 .66359 L .707 .577 .707 r
F P
0 g
s
.78942 .66335 m .79285 .63835 L .78597 .66359 L .707 .577 .707 r
F
.81277 .65855 m .80971 .65141 L .80337 .66005 L F
.79382 .66304 m .79242 .67496 L p .80971 .65141 L F P
0 g
s
.82211 .67425 m .81951 .65747 L p .81738 .65782 L .707 .577 .707 r
F P
0 g
s
.81297 .66303 m .81738 .65782 L .80971 .65904 L .707 .577 .707 r
F
.82211 .67425 m .81738 .65782 L .81297 .66303 L F
.82211 .67425 m .83778 .67389 L p .82611 .65354 L F P
0 g
s
.83174 .65183 m .82947 .64349 L .82334 .65438 L .707 .577 .707 r
F
.82221 .6167 m .81757 .65613 L p .82947 .64349 L F P
0 g
s
.81757 .65613 m .81738 .65782 L p .81922 .65563 L .707 .577 .707 r
F P
0 g
s
.82947 .64349 m .81757 .65613 L .81922 .65563 L .707 .577 .707 r
F
.81922 .65563 m .82211 .67425 L p .82611 .65354 L F P
0 g
s
.82221 .6167 m .79831 .62484 L p .81277 .65855 L .707 .577 .707 r
F P
0 g
s
.81632 .66682 m .81738 .65782 L p .81277 .65855 L .707 .577 .707 r
F P
0 g
s
.81738 .65782 m .82221 .6167 L p .81277 .65855 L .707 .577 .707 r
F P
0 g
s
.81951 .65747 m .81624 .63634 L p .80971 .65904 L .707 .577 .707 r
F P
0 g
s
.81738 .65782 m .81632 .66682 L p .82947 .64349 L .707 .577 .707 r
F P
0 g
s
.83778 .67389 m .83425 .65106 L p .83297 .65145 L .707 .577 .707 r
F P
0 g
s
.82996 .66026 m .83297 .65145 L .82611 .65354 L .707 .577 .707 r
F
.83778 .67389 m .83297 .65145 L .82996 .66026 L F
.83846 .60477 m .83323 .64926 L p .83934 .6328 L F P
0 g
s
.83323 .64926 m .83297 .65145 L p .83389 .64875 L .707 .577 .707 r
F P
0 g
s
.83934 .6328 m .83323 .64926 L .83389 .64875 L .707 .577 .707 r
F
.83778 .67389 m .84422 .67521 L p .83553 .64748 L F P
0 g
s
.83389 .64875 m .83778 .67389 L p .83553 .64748 L .707 .577 .707 r
F P
0 g
s
.83846 .60477 m .82221 .6167 L p .83174 .65183 L .707 .577 .707 r
F P
0 g
s
.83257 .65489 m .83297 .65145 L p .83174 .65183 L .707 .577 .707 r
F P
0 g
s
.83297 .65145 m .83846 .60477 L p .83174 .65183 L .707 .577 .707 r
F P
0 g
s
.83297 .65145 m .83192 .63597 L .82611 .65354 L .707 .577 .707 r
F
.83425 .65106 m .83389 .64875 L p .83297 .65145 L F P
0 g
s
.83389 .64875 m .83192 .63597 L p .83297 .65145 L .707 .577 .707 r
F P
0 g
s
.83957 .64032 m .83934 .6328 L .83462 .64818 L .707 .577 .707 r
F
.83649 .64674 m .83957 .64032 L p .83462 .64818 L F P
0 g
s
.83297 .65145 m .83257 .65489 L p .83934 .6328 L .707 .577 .707 r
F P
0 g
s
.83835 .6373 m .83192 .63597 L p .83553 .64748 L .707 .577 .707 r
F P
0 g
s
.84422 .67521 m .83946 .64444 L p .83553 .64748 L .707 .577 .707 r
F P
0 g
s
.83946 .64444 m .83835 .6373 L p .83553 .64748 L .707 .577 .707 r
F P
0 g
s
.83257 .65489 m .83649 .64674 L p .83462 .64818 L .707 .577 .707 r
F P
0 g
s
.83192 .63597 m .83389 .64875 L p .83553 .64748 L .707 .577 .707 r
F P
0 g
s
.83192 .63597 m .81624 .63634 L p .82611 .65354 L .707 .577 .707 r
F P
0 g
s
.81624 .63634 m .81922 .65563 L p .82611 .65354 L .707 .577 .707 r
F P
0 g
s
.81632 .66682 m .83257 .65489 L p .83174 .65183 L .707 .577 .707 r
F P
0 g
s
.83174 .65183 m .82334 .65438 L .81632 .66682 L .707 .577 .707 r
F
.81624 .63634 m .79285 .63835 L p .80971 .65904 L F P
0 g
s
.79242 .67496 m .81632 .66682 L p .81277 .65855 L .707 .577 .707 r
F P
0 g
s
.81277 .65855 m .80337 .66005 L .79242 .67496 L .707 .577 .707 r
F
.79285 .63835 m .79638 .66116 L p .80971 .65904 L F P
0 g
s
.76405 .64181 m .76762 .66489 L p .78597 .66359 L .707 .577 .707 r
F P
0 g
s
.73154 .67708 m .7632 .67849 L p .75722 .66653 L .707 .577 .707 r
F P
0 g
s
.73264 .64639 m .73574 .66643 L p .75515 .66652 L .707 .577 .707 r
F P
0 g
s
.73264 .64639 m .70171 .65163 L p .71887 .66686 L .707 .577 .707 r
F P
0 g
s
.73154 .67708 m .7326 .66803 L p .7273 .66758 L .707 .577 .707 r
F P
0 g
s
.39109 .25595 m .39109 .75784 L .36719 .76811 L p .707 .577 .707 r
F P
0 g
s
.39109 .75784 m .39109 .25595 L .42565 .24816 L p .707 .577 .707 r
F P
0 g
s
.18397 .7886 m .18251 .76951 L .20652 .76572 L p .707 .577 .707 r
F P
0 g
s
.20652 .76572 m .20799 .78481 L .18397 .7886 L p .707 .577 .707 r
F P
0 g
s
.32601 .75737 m .32748 .77646 L .30012 .77702 L p .707 .577 .707 r
F P
0 g
s
.30012 .77702 m .29865 .75792 L .32601 .75737 L p .707 .577 .707 r
F P
0 g
s
.59458 .25211 m .59458 .754 L .5563 .74758 L p .707 .577 .707 r
F P
0 g
s
.5563 .74758 m .5563 .24569 L .59458 .25211 L p .707 .577 .707 r
F P
0 g
s
.20799 .78481 m .20652 .76572 L .23584 .76231 L p .707 .577 .707 r
F P
0 g
s
.23584 .76231 m .2373 .78141 L .20799 .78481 L p .707 .577 .707 r
F P
0 g
s
.67428 .65702 m .68015 .69493 L .70758 .68954 L p .707 .577 .707 r
F P
0 g
s
.42565 .75005 m .42565 .24816 L .46748 .24362 L p .707 .577 .707 r
F P
0 g
s
.42565 .24816 m .42565 .75005 L .39109 .75784 L p .707 .577 .707 r
F P
0 g
s
.29865 .75792 m .30012 .77702 L .26905 .77872 L p .707 .577 .707 r
F P
0 g
s
.26905 .77872 m .26758 .75963 L .29865 .75792 L p .707 .577 .707 r
F P
0 g
s
.2373 .78141 m .23584 .76231 L .26758 .75963 L p .707 .577 .707 r
F P
0 g
s
.26758 .75963 m .26905 .77872 L .2373 .78141 L p .707 .577 .707 r
F P
0 g
s
.5563 .24569 m .5563 .74758 L .5125 .74466 L p .707 .577 .707 r
F P
0 g
s
.5125 .74466 m .5125 .24277 L .5563 .24569 L p .707 .577 .707 r
F P
0 g
s
.65221 .64687 m .6581 .59675 L .64554 .58131 L p .707 .577 .707 r
F P
0 g
s
.65304 .66204 m .65891 .69995 L .68015 .69493 L p .707 .577 .707 r
F P
0 g
s
.46748 .74551 m .46748 .24362 L .5125 .24277 L p .707 .577 .707 r
F P
0 g
s
.46748 .24362 m .46748 .74551 L .42565 .75005 L p .707 .577 .707 r
F P
0 g
s
.73095 .77457 m .73241 .7573 L .70134 .75206 L p .707 .577 .707 r
F P
0 g
s
.73241 .7573 m .73095 .77457 L .76269 .77552 L p .707 .577 .707 r
F P
0 g
s
.76269 .77552 m .76416 .75825 L .73241 .7573 L p .707 .577 .707 r
F P
0 g
s
.5125 .24277 m .5125 .74466 L .46748 .74551 L p .707 .577 .707 r
F P
0 g
s
.76416 .75825 m .76269 .77552 L .79201 .77209 L p .707 .577 .707 r
F P
0 g
s
.79201 .77209 m .79348 .75482 L .76416 .75825 L p .707 .577 .707 r
F P
0 g
s
.69988 .76933 m .70134 .75206 L .67399 .74304 L p .707 .577 .707 r
F P
0 g
s
.70134 .75206 m .69988 .76933 L .73095 .77457 L p .707 .577 .707 r
F P
0 g
s
.67399 .74304 m .67252 .76031 L .69988 .76933 L p .707 .577 .707 r
F P
0 g
s
.83957 .64032 m .84547 .5902 L .83846 .60477 L p .707 .577 .707 r
F P
0 g
s
.79348 .75482 m .79201 .77209 L .81602 .7646 L p .707 .577 .707 r
F P
0 g
s
.81602 .7646 m .81749 .74733 L .79348 .75482 L p .707 .577 .707 r
F P
0 g
s
.63965 .63143 m .64554 .58131 L .64262 .56554 L p .707 .577 .707 r
F P
0 g
s
.64554 .58131 m .63965 .63143 L .65221 .64687 L p .707 .577 .707 r
F P
0 g
s
.67252 .76031 m .67399 .74304 L .65303 .73112 L p .707 .577 .707 r
F P
0 g
s
.64007 .66619 m .64593 .7041 L .65891 .69995 L p .707 .577 .707 r
F P
0 g
s
.65891 .69995 m .65304 .66204 L .64007 .66619 L p .707 .577 .707 r
F P
0 g
s
.65303 .73112 m .65156 .74839 L .67252 .76031 L p .707 .577 .707 r
F P
0 g
s
.81749 .74733 m .81602 .7646 L .83239 .7538 L p .707 .577 .707 r
F P
0 g
s
.83239 .7538 m .83385 .73653 L .81749 .74733 L p .707 .577 .707 r
F P
0 g
s
.65156 .74839 m .65303 .73112 L .64052 .71747 L p .707 .577 .707 r
F P
0 g
s
.84547 .5902 m .83957 .64032 L .83665 .62455 L p .707 .577 .707 r
F P
0 g
s
.83665 .62455 m .84255 .57443 L .84547 .5902 L p .707 .577 .707 r
F P
0 g
s
.64262 .56554 m .63673 .61566 L .63965 .63143 L p .707 .577 .707 r
F P
0 g
s
.63673 .61566 m .64262 .56554 L .64963 .55097 L p .707 .577 .707 r
F P
0 g
s
.63663 .66907 m .6425 .70698 L .64593 .7041 L p .707 .577 .707 r
F P
0 g
s
.64593 .7041 m .64007 .66619 L .63663 .66907 L p .707 .577 .707 r
F P
0 g
s
.64052 .71747 m .63905 .73474 L .65156 .74839 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .60231 Mdot
.5 Mabswid
.83385 .73653 m .83239 .7538 L .83949 .74074 L p .707 .577 .707 r
F P
0 g
s
.83949 .74074 m .84096 .72347 L .83385 .73653 L p .707 .577 .707 r
F P
0 g
s
.63905 .73474 m .64052 .71747 L .63768 .70343 L p .707 .577 .707 r
F P
0 g
s
.84255 .57443 m .83665 .62455 L .82409 .60911 L p .707 .577 .707 r
F P
0 g
s
.82409 .60911 m .82998 .55899 L .84255 .57443 L p .707 .577 .707 r
F P
0 g
s
.64373 .60109 m .64963 .55097 L .66588 .53904 L p .707 .577 .707 r
F P
0 g
s
.64963 .55097 m .64373 .60109 L .63673 .61566 L p .707 .577 .707 r
F P
0 g
s
.83835 .6373 m .84422 .67521 L .84078 .67808 L p .707 .577 .707 r
F P
0 g
s
.63768 .70343 m .63621 .7207 L .63905 .73474 L p .707 .577 .707 r
F P
0 g
s
.84078 .67808 m .83492 .64017 L .83835 .6373 L p .707 .577 .707 r
F P
0 g
s
.64307 .67039 m .64893 .7083 L .6425 .70698 L p .707 .577 .707 r
F P
0 g
s
.6425 .70698 m .63663 .66907 L .64307 .67039 L p .707 .577 .707 r
F P
0 g
s
.38524 .60843 m .39879 .55316 L .36855 .54471 L p .707 .577 .707 r
F P
0 g
s
.39879 .55316 m .38524 .60843 L .41621 .61535 L p .707 .577 .707 r
F P
0 g
s
.41621 .61535 m .42976 .56008 L .39879 .55316 L p .707 .577 .707 r
F P
0 g
s
.84096 .72347 m .83949 .74074 L .83665 .72669 L p .707 .577 .707 r
F P
0 g
s
.83665 .72669 m .83812 .70943 L .84096 .72347 L p .707 .577 .707 r
F P
0 g
s
.42976 .56008 m .41621 .61535 L .44487 .62007 L p .707 .577 .707 r
F P
0 g
s
.44487 .62007 m .45842 .5648 L .42976 .56008 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .72304 Mdot
.5 Mabswid
.355 .59998 m .36855 .54471 L .34199 .53557 L p .707 .577 .707 r
F P
0 g
s
.36855 .54471 m .355 .59998 L .38524 .60843 L p .707 .577 .707 r
F P
0 g
s
.82998 .55899 m .82409 .60911 L .80312 .59552 L p .707 .577 .707 r
F P
0 g
s
.80312 .59552 m .80901 .5454 L .82998 .55899 L p .707 .577 .707 r
F P
0 g
s
.63621 .7207 m .63768 .70343 L .64479 .69037 L p .707 .577 .707 r
F P
0 g
s
.66588 .53904 m .65998 .58916 L .64373 .60109 L p .707 .577 .707 r
F P
0 g
s
.65998 .58916 m .66588 .53904 L .68978 .53091 L p .707 .577 .707 r
F P
0 g
s
.34199 .53557 m .32844 .59084 L .355 .59998 L p .707 .577 .707 r
F P
0 g
s
.64479 .69037 m .64332 .70764 L .63621 .7207 L p .707 .577 .707 r
F P
0 g
s
.4629 .62165 m .46842 .62213 L p .44812 .6068 L .707 .577 .707 r
F P
0 g
s
.46489 .62091 m .46671 .62548 L p .49349 .63748 L .707 .577 .707 r
F P
0 g
s
.46671 .62548 m .47808 .65387 L .48629 .64514 L p .707 .577 .707 r
F P
0 g
s
.48629 .64514 m .49349 .63748 L p .46671 .62548 L .707 .577 .707 r
F P
0 g
s
.45842 .5648 m .44812 .6068 L p .46842 .62213 L .707 .577 .707 r
F P
0 g
s
.44812 .6068 m .44487 .62007 L .4629 .62165 L p .707 .577 .707 r
F P
0 g
s
.46842 .62213 m .48196 .56686 L .45842 .5648 L p .707 .577 .707 r
F P
0 g
s
.83492 .64017 m .84078 .67808 L .82781 .68224 L p .707 .577 .707 r
F P
0 g
s
.82781 .68224 m .82194 .64432 L .83492 .64017 L p .707 .577 .707 r
F P
0 g
s
.32844 .59084 m .34199 .53557 L .32171 .52662 L p .707 .577 .707 r
F P
0 g
s
.42784 .68436 m .41464 .65141 L .38474 .66254 L p .707 .577 .707 r
F P
0 g
s
.41464 .65141 m .42784 .68436 L .45545 .67002 L p .707 .577 .707 r
F P
0 g
s
.45545 .67002 m .44226 .63707 L .41464 .65141 L p .707 .577 .707 r
F P
0 g
s
.65874 .67003 m .66461 .70794 L .64893 .7083 L p .707 .577 .707 r
F P
0 g
s
.64893 .7083 m .64307 .67039 L .65874 .67003 L p .707 .577 .707 r
F P
0 g
s
.39793 .69549 m .38474 .66254 L .35546 .66936 L p .707 .577 .707 r
F P
0 g
s
.38474 .66254 m .39793 .69549 L .42784 .68436 L p .707 .577 .707 r
F P
0 g
s
.80901 .5454 m .80312 .59552 L .77578 .58511 L p .707 .577 .707 r
F P
0 g
s
.77578 .58511 m .78167 .53499 L .80901 .5454 L p .707 .577 .707 r
F P
0 g
s
.68388 .58103 m .68978 .53091 L .71899 .52737 L p .707 .577 .707 r
F P
0 g
s
.68978 .53091 m .68388 .58103 L .65998 .58916 L p .707 .577 .707 r
F P
0 g
s
.44226 .63707 m .45545 .67002 L .47808 .65387 L p .707 .577 .707 r
F P
0 g
s
.47808 .65387 m .46489 .62091 L .44226 .63707 L p .707 .577 .707 r
F P
0 g
s
.32171 .52662 m .30816 .58189 L .32844 .59084 L p .707 .577 .707 r
F P
0 g
s
.83812 .70943 m .83665 .72669 L .82414 .71305 L p .707 .577 .707 r
F P
0 g
s
.82414 .71305 m .82561 .69578 L .83812 .70943 L p .707 .577 .707 r
F P
0 g
s
.38451 .71447 m .3874 .69869 L p .35727 .68908 L .707 .577 .707 r
F P
0 g
s
.38226 .69464 m .35727 .68908 L p .3874 .69869 L .707 .577 .707 r
F P
0 g
s
.35727 .68908 m .35387 .70765 L .38451 .71447 L p .707 .577 .707 r
F P
0 g
s
.35387 .70765 m .35602 .69591 L p .33036 .68112 L .707 .577 .707 r
F P
0 g
s
.35602 .69591 m .35727 .68908 L .34407 .68517 L p .707 .577 .707 r
F P
0 g
s
.34407 .68517 m .33036 .68112 L p .35602 .69591 L .707 .577 .707 r
F P
0 g
s
.33036 .68112 m .32696 .69968 L .35387 .70765 L p .707 .577 .707 r
F P
0 g
s
.32696 .69968 m .33036 .68112 L .30979 .67278 L p .707 .577 .707 r
F P
0 g
s
.34289 .70416 m .33035 .67286 L p .30995 .6679 L .707 .577 .707 r
F P
0 g
s
.33035 .67286 m .32969 .67121 L .32825 .67097 L p .707 .577 .707 r
F P
0 g
s
.32825 .67097 m .30995 .6679 L p .33035 .67286 L .707 .577 .707 r
F P
0 g
s
.36865 .70231 m .3579 .67545 L p .32969 .67121 L .707 .577 .707 r
F P
0 g
s
.3579 .67545 m .35546 .66936 L .35061 .66971 L p .707 .577 .707 r
F P
0 g
s
.35061 .66971 m .32969 .67121 L p .3579 .67545 L .707 .577 .707 r
F P
0 g
s
.3874 .69869 m .38791 .6959 L .38226 .69464 L p .707 .577 .707 r
F P
0 g
s
.38791 .6959 m .38451 .71447 L .41586 .71947 L p .707 .577 .707 r
F P
0 g
s
.41586 .71947 m .41926 .7009 L .38791 .6959 L p .707 .577 .707 r
F P
0 g
s
.35546 .66936 m .36865 .70231 L .39793 .69549 L p .707 .577 .707 r
F P
0 g
s
.66461 .70794 m .65944 .67454 L p .68213 .66802 L .707 .577 .707 r
F P
0 g
s
.65944 .67454 m .65874 .67003 L .66345 .66962 L p .707 .577 .707 r
F P
0 g
s
.66345 .66962 m .68213 .66802 L p .65944 .67454 L .707 .577 .707 r
F P
0 g
s
.64332 .70764 m .64458 .6928 L p .66115 .67957 L .707 .577 .707 r
F P
0 g
s
.64458 .6928 m .64479 .69037 L .64861 .68785 L p .707 .577 .707 r
F P
0 g
s
.64861 .68785 m .66115 .67957 L p .64458 .6928 L .707 .577 .707 r
F P
0 g
s
.41926 .7009 m .41586 .71947 L .44486 .72216 L p .707 .577 .707 r
F P
0 g
s
.44486 .72216 m .44826 .7036 L .41926 .7009 L p .707 .577 .707 r
F P
0 g
s
.48196 .56686 m .46842 .62213 L .47572 .62177 L p .707 .577 .707 r
F P
0 g
s
.48435 .61716 m .48429 .61603 L .47572 .62177 L .707 .577 .707 r
F
.48429 .61603 m .48196 .56686 L .47701 .6104 L F
.48429 .61603 m .47701 .6104 L .47572 .62177 L F
.49349 .63748 m .49825 .62683 L p .48559 .61704 L F P
0 g
s
.48518 .61672 m .4854 .61726 L p .48559 .61704 L .707 .577 .707 r
F P
0 g
s
.4854 .61726 m .49349 .63748 L p .48559 .61704 L .707 .577 .707 r
F P
0 g
s
.4928 .60868 m .49315 .60583 L .48559 .61704 L .707 .577 .707 r
F
.49809 .56606 m .48962 .6006 L p .49315 .60583 L F P
0 g
s
.48962 .6006 m .48559 .61704 L p .49315 .60583 L .707 .577 .707 r
F P
0 g
s
.49809 .56606 m .48196 .56686 L p .48287 .58592 L .707 .577 .707 r
F P
0 g
s
.49349 .63748 m .48518 .61672 L p .47084 .62436 L .707 .577 .707 r
F P
0 g
s
.48454 .62133 m .48962 .6006 L p .48287 .58592 L .707 .577 .707 r
F P
0 g
s
.48962 .6006 m .49809 .56606 L p .48287 .58592 L .707 .577 .707 r
F P
0 g
s
.50019 .62247 m .49817 .61325 L p .49421 .60739 L .707 .577 .707 r
F P
0 g
s
.49408 .6072 m .49425 .60762 L p .49421 .60739 L .707 .577 .707 r
F P
0 g
s
.49425 .60762 m .50019 .62247 L p .49421 .60739 L .707 .577 .707 r
F P
0 g
s
.4803 .60453 m .48518 .61672 L p .4857 .61692 L .707 .577 .707 r
F P
0 g
s
.50019 .62247 m .48935 .61269 L .4857 .61692 L .707 .577 .707 r
F
.48935 .61269 m .4803 .60453 L .4857 .61692 L F
.49416 .6071 m .49348 .60318 L p .4928 .60868 L F P
0 g
s
.487 .58952 m .4803 .60453 L p .49331 .61626 L .707 .577 .707 r
F P
0 g
s
.50019 .62247 m .49425 .60762 L p .49331 .61626 L .707 .577 .707 r
F P
0 g
s
.49425 .60762 m .487 .58952 L p .49331 .61626 L .707 .577 .707 r
F P
0 g
s
.49445 .59539 m .50522 .56246 L .49809 .56606 L p .707 .577 .707 r
F P
0 g
s
.50266 .55644 m .50522 .56246 L p .49614 .59022 L .707 .577 .707 r
F P
0 g
s
.49421 .60739 m .49416 .6071 L p .49167 .61773 L .707 .577 .707 r
F P
0 g
s
.49167 .61773 m .49416 .6071 L .4928 .60868 L .707 .577 .707 r
F
.487 .58952 m .49408 .6072 L p .49419 .6073 L F P
0 g
s
.49294 .60001 m .49419 .59616 L .49421 .60739 L .707 .577 .707 r
F
.50522 .56246 m .49801 .59187 L p .49419 .59616 L F P
0 g
s
.49801 .59187 m .49421 .60739 L p .49419 .59616 L .707 .577 .707 r
F P
0 g
s
.49326 .60188 m .487 .58952 L .49419 .6073 L .707 .577 .707 r
F
.49294 .60001 m .49755 .57729 L .49614 .59022 L F
.49254 .59772 m .49755 .57729 L p .49294 .60001 L F P
0 g
s
.48433 .57735 m .487 .58952 L p .4947 .60474 L .707 .577 .707 r
F P
0 g
s
.49752 .6103 m .49274 .59836 L p .4947 .60474 L .707 .577 .707 r
F P
0 g
s
.49274 .59836 m .48433 .57735 L p .4947 .60474 L .707 .577 .707 r
F P
0 g
s
.48433 .57735 m .49258 .59798 L p .49237 .5981 L .707 .577 .707 r
F P
0 g
s
.4803 .60453 m .46489 .62091 L p .47084 .62436 L .707 .577 .707 r
F P
0 g
s
.48518 .61672 m .4803 .60453 L p .47084 .62436 L .707 .577 .707 r
F P
0 g
s
.48911 .61171 m .4771 .60384 L p .48355 .59188 L .707 .577 .707 r
F P
0 g
s
.48355 .59188 m .48854 .5954 L .48911 .61171 L .707 .577 .707 r
F
.48522 .59306 m .48433 .57735 L .49237 .5981 L F
.49243 .59815 m .48911 .61171 L p .48854 .5954 L F P
0 g
s
.48767 .60351 m .48573 .60217 L p .49258 .59798 L .707 .577 .707 r
F P
0 g
s
.49254 .59772 m .49243 .59815 L p .48812 .58339 L .707 .577 .707 r
F P
0 g
s
.48812 .58339 m .49243 .59815 L .48854 .5954 L .707 .577 .707 r
F
.49752 .6103 m .49326 .60188 L .49419 .6073 L F
.48911 .61171 m .49254 .59772 L p .49294 .60001 L F P
0 g
s
.49825 .62683 m .50019 .62247 L p .48518 .61672 L .707 .577 .707 r
F P
0 g
s
.48454 .62133 m .49167 .61773 L p .4928 .60868 L .707 .577 .707 r
F P
0 g
s
.48559 .61704 m .48454 .62133 L p .4928 .60868 L .707 .577 .707 r
F P
0 g
s
.49167 .61773 m .48911 .61171 L p .49294 .60001 L .707 .577 .707 r
F P
0 g
s
.49817 .61325 m .49752 .6103 L p .49408 .6072 L .707 .577 .707 r
F P
0 g
s
.49421 .60739 m .49167 .61773 L p .49294 .60001 L .707 .577 .707 r
F P
0 g
s
.49752 .6103 m .48767 .60351 L p .49243 .59815 L .707 .577 .707 r
F P
0 g
s
.49258 .59798 m .49274 .59836 L p .49243 .59815 L .707 .577 .707 r
F P
0 g
s
.49274 .59836 m .49752 .6103 L p .49243 .59815 L .707 .577 .707 r
F P
0 g
s
.48573 .60217 m .48522 .59306 L .49237 .5981 L .707 .577 .707 r
F
.47254 .56921 m .48433 .57735 L p .48522 .59306 L F P
0 g
s
.4771 .60384 m .48044 .5902 L p .48355 .59188 L .707 .577 .707 r
F P
0 g
s
.47254 .56921 m .48085 .58998 L p .48044 .5902 L .707 .577 .707 r
F P
0 g
s
.4771 .60384 m .45682 .59489 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.48044 .5902 m .4771 .60384 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.46628 .59753 m .46869 .58663 L .48044 .5902 L .707 .577 .707 r
F
.46869 .58663 m .47254 .56921 L .48044 .5902 L F
.48085 .58998 m .47254 .56921 L p .48522 .59306 L F P
0 g
s
.4528 .56591 m .47254 .56921 L p .46869 .58663 L .707 .577 .707 r
F P
0 g
s
.45682 .59489 m .45942 .58432 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.4528 .56591 m .46004 .584 L p .45942 .58432 L .707 .577 .707 r
F P
0 g
s
.45682 .59489 m .43026 .58575 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.45942 .58432 m .45682 .59489 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.44316 .59258 m .44676 .5826 L .45942 .58432 L .707 .577 .707 r
F
.44676 .5826 m .4528 .56591 L .45942 .58432 L F
.46004 .584 m .4528 .56591 L p .46869 .58663 L F P
0 g
s
.42703 .56776 m .4528 .56591 L p .44676 .5826 L .707 .577 .707 r
F P
0 g
s
.43026 .58575 m .4314 .58112 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.42703 .56776 m .43217 .58061 L p .4314 .58112 L .707 .577 .707 r
F P
0 g
s
.4314 .58112 m .43026 .58575 L .41137 .58047 L p .707 .577 .707 r
F P
0 g
s
.41809 .58985 m .42175 .58081 L .4314 .58112 L .707 .577 .707 r
F
.42175 .58081 m .42703 .56776 L .4314 .58112 L F
.43217 .58061 m .42703 .56776 L p .44676 .5826 L F P
0 g
s
.39775 .57458 m .42703 .56776 L p .41589 .5953 L .707 .577 .707 r
F P
0 g
s
.41095 .60753 m .40032 .58098 L p .41589 .5953 L .707 .577 .707 r
F P
0 g
s
.40032 .58098 m .39775 .57458 L p .41589 .5953 L .707 .577 .707 r
F P
0 g
s
.39775 .57458 m .41095 .60753 L .38104 .61866 L p .707 .577 .707 r
F P
0 g
s
.38104 .61866 m .36784 .58571 L .39775 .57458 L p .707 .577 .707 r
F P
0 g
s
.41357 .52203 m .40002 .5773 L .39512 .57621 L p .707 .577 .707 r
F P
0 g
s
.39512 .57621 m .36905 .57038 L p .3781 .56056 L .707 .577 .707 r
F P
0 g
s
.3781 .56056 m .41357 .52203 L .39512 .57621 L .707 .577 .707 r
F
.44381 .53048 m .4314 .58112 L p .40002 .5773 L F P
0 g
s
.41137 .58047 m .40002 .5773 L p .4314 .58112 L .707 .577 .707 r
F P
0 g
s
.4314 .58112 m .43154 .58053 L p .43217 .58061 L .707 .577 .707 r
F P
0 g
s
.4314 .58112 m .43217 .58061 L .43446 .58092 L .707 .577 .707 r
F
.44022 .60071 m .41095 .60753 L p .41809 .58985 L F P
0 g
s
.43217 .58061 m .44022 .60071 L p .41809 .58985 L .707 .577 .707 r
F P
0 g
s
.44022 .60071 m .43217 .58061 L p .44676 .5826 L .707 .577 .707 r
F P
0 g
s
.44381 .53048 m .47037 .53962 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.43154 .58053 m .44381 .53048 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.47037 .53962 m .45942 .58432 L p .43446 .58092 L .707 .577 .707 r
F P
0 g
s
.45942 .58432 m .45953 .58385 L p .46004 .584 L .707 .577 .707 r
F P
0 g
s
.45942 .58432 m .46004 .584 L .46392 .58518 L .707 .577 .707 r
F
.46599 .59886 m .44022 .60071 L p .44316 .59258 L F P
0 g
s
.46004 .584 m .46599 .59886 L p .44316 .59258 L .707 .577 .707 r
F P
0 g
s
.46599 .59886 m .46004 .584 L p .46869 .58663 L .707 .577 .707 r
F P
0 g
s
.47037 .53962 m .49065 .54857 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.45953 .58385 m .47037 .53962 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.49065 .54857 m .48044 .5902 L p .46392 .58518 L .707 .577 .707 r
F P
0 g
s
.48044 .5902 m .48055 .58977 L p .48085 .58998 L .707 .577 .707 r
F P
0 g
s
.48044 .5902 m .48085 .58998 L .48355 .59188 L .707 .577 .707 r
F
.48573 .60217 m .46599 .59886 L p .46628 .59753 L F P
0 g
s
.48085 .58998 m .48573 .60217 L p .46628 .59753 L .707 .577 .707 r
F P
0 g
s
.48573 .60217 m .48085 .58998 L p .48522 .59306 L .707 .577 .707 r
F P
0 g
s
.49065 .54857 m .50266 .55644 L p .48355 .59188 L .707 .577 .707 r
F P
0 g
s
.48055 .58977 m .49065 .54857 L p .48355 .59188 L .707 .577 .707 r
F P
0 g
s
.48355 .59188 m .48812 .58339 L .48854 .5954 L .707 .577 .707 r
F
.50266 .55644 m .49254 .59772 L p .48812 .58339 L F P
0 g
s
.49755 .57729 m .50266 .55644 L p .49614 .59022 L .707 .577 .707 r
F P
0 g
s
.47572 .62177 m .48454 .62133 L p .48435 .61716 L .707 .577 .707 r
F P
0 g
s
.78167 .53499 m .77578 .58511 L .74476 .5789 L p .707 .577 .707 r
F P
0 g
s
.74476 .5789 m .75066 .52878 L .78167 .53499 L p .707 .577 .707 r
F P
0 g
s
.7131 .57749 m .71899 .52737 L .75066 .52878 L p .707 .577 .707 r
F P
0 g
s
.71899 .52737 m .7131 .57749 L .68388 .58103 L p .707 .577 .707 r
F P
0 g
s
.30816 .58189 m .32171 .52662 L .3097 .51875 L p .707 .577 .707 r
F P
0 g
s
.66115 .67957 m .65968 .69684 L .64332 .70764 L p .707 .577 .707 r
F P
0 g
s
.75066 .52878 m .74476 .5789 L .7131 .57749 L p .707 .577 .707 r
F P
0 g
s
.82194 .64432 m .82781 .68224 L .80657 .68725 L p .707 .577 .707 r
F P
0 g
s
.80657 .68725 m .8007 .64934 L .82194 .64432 L p .707 .577 .707 r
F P
0 g
s
.32969 .67121 m .34289 .70416 L .36865 .70231 L p .707 .577 .707 r
F P
0 g
s
.44826 .7036 m .44486 .72216 L .46868 .72229 L p .707 .577 .707 r
F P
0 g
s
.46868 .72229 m .47208 .70372 L .44826 .7036 L p .707 .577 .707 r
F P
0 g
s
.68213 .66802 m .688 .70593 L .66461 .70794 L p .707 .577 .707 r
F P
0 g
s
.3097 .51875 m .29615 .57402 L .30816 .58189 L p .707 .577 .707 r
F P
0 g
s
.82561 .69578 m .82414 .71305 L .80318 .70113 L p .707 .577 .707 r
F P
0 g
s
.80657 .68725 m .77914 .69265 L p .79861 .65354 L .707 .577 .707 r
F P
0 g
s
.8007 .64934 m .8024 .66031 L p .79861 .65354 L .707 .577 .707 r
F P
0 g
s
.8024 .66031 m .80657 .68725 L p .79861 .65354 L .707 .577 .707 r
F P
0 g
s
.80318 .70113 m .80465 .68386 L .82069 .69298 L p .707 .577 .707 r
F P
0 g
s
.82069 .69298 m .82561 .69578 L p .82265 .69648 L .707 .577 .707 r
F P
0 g
s
.80318 .70113 m .82069 .69298 L .82265 .69648 L .707 .577 .707 r
F
.30979 .67278 m .30639 .69135 L .32696 .69968 L p F P
0 g
s
.688 .70593 m .68233 .66928 L p .71094 .66455 L .707 .577 .707 r
F P
0 g
s
.68233 .66928 m .68213 .66802 L .68429 .66776 L p .707 .577 .707 r
F P
0 g
s
.68429 .66776 m .71094 .66455 L p .68233 .66928 L .707 .577 .707 r
F P
0 g
s
.65968 .69684 m .6606 .68607 L p .68516 .67208 L .707 .577 .707 r
F P
0 g
s
.6606 .68607 m .66115 .67957 L .67433 .67546 L p .707 .577 .707 r
F P
0 g
s
.67433 .67546 m .68516 .67208 L p .6606 .68607 L .707 .577 .707 r
F P
0 g
s
.30995 .6679 m .32314 .70086 L .34289 .70416 L p .707 .577 .707 r
F P
0 g
s
.68516 .67208 m .6837 .68935 L .65968 .69684 L p .707 .577 .707 r
F P
0 g
s
.77914 .69265 m .77327 .65473 L .8007 .64934 L p .707 .577 .707 r
F P
0 g
s
.29615 .57402 m .3097 .51875 L .30714 .51273 L p .707 .577 .707 r
F P
0 g
s
.47208 .70372 m .46868 .72229 L .48497 .71983 L p .707 .577 .707 r
F P
0 g
s
.48497 .71983 m .48837 .70126 L .47208 .70372 L p .707 .577 .707 r
F P
0 g
s
.71094 .66455 m .7168 .70246 L .688 .70593 L p .707 .577 .707 r
F P
0 g
s
.77914 .69265 m .74821 .69789 L p .77147 .65783 L .707 .577 .707 r
F P
0 g
s
.77327 .65473 m .77414 .66035 L p .77147 .65783 L .707 .577 .707 r
F P
0 g
s
.77414 .66035 m .77914 .69265 L p .77147 .65783 L .707 .577 .707 r
F P
0 g
s
.80318 .70113 m .77583 .69211 L p .80042 .68507 L .707 .577 .707 r
F P
0 g
s
.80465 .68386 m .80424 .68867 L p .80042 .68507 L .707 .577 .707 r
F P
0 g
s
.80424 .68867 m .80318 .70113 L p .80042 .68507 L .707 .577 .707 r
F P
0 g
s
.77583 .69211 m .7773 .67484 L .80465 .68386 L p .707 .577 .707 r
F P
0 g
s
.30639 .69135 m .30979 .67278 L .29759 .66489 L p .707 .577 .707 r
F P
0 g
s
.32314 .70086 m .30995 .6679 L .29816 .65977 L p .707 .577 .707 r
F P
0 g
s
.7168 .70246 m .71109 .66553 L p .74234 .65998 L .707 .577 .707 r
F P
0 g
s
.71109 .66553 m .71094 .66455 L .71326 .66421 L p .707 .577 .707 r
F P
0 g
s
.71326 .66421 m .74234 .65998 L p .71109 .66553 L .707 .577 .707 r
F P
0 g
s
.6837 .68935 m .68435 .68169 L p .71448 .66865 L .707 .577 .707 r
F P
0 g
s
.68435 .68169 m .68516 .67208 L .70387 .66989 L p .707 .577 .707 r
F P
0 g
s
.70387 .66989 m .71448 .66865 L p .68435 .68169 L .707 .577 .707 r
F P
0 g
s
.30714 .51273 m .29359 .56799 L .29615 .57402 L p .707 .577 .707 r
F P
0 g
s
.29759 .66489 m .29419 .68346 L .30639 .69135 L p .707 .577 .707 r
F P
0 g
s
.74821 .69789 m .7168 .70246 L p .74197 .6606 L .707 .577 .707 r
F P
0 g
s
.74249 .66094 m .74821 .69789 L p .74197 .6606 L .707 .577 .707 r
F P
0 g
s
.74821 .69789 m .74291 .66364 L p .77327 .65473 L .707 .577 .707 r
F P
0 g
s
.74291 .66364 m .74234 .65998 L .75226 .6583 L p .707 .577 .707 r
F P
0 g
s
.75226 .6583 m .77327 .65473 L p .74291 .66364 L .707 .577 .707 r
F P
0 g
s
.71301 .68592 m .71347 .68047 L p .74623 .6696 L .707 .577 .707 r
F P
0 g
s
.71347 .68047 m .71448 .66865 L .73318 .66921 L p .707 .577 .707 r
F P
0 g
s
.73318 .66921 m .74623 .6696 L p .71347 .68047 L .707 .577 .707 r
F P
0 g
s
.77583 .69211 m .74476 .68686 L p .7687 .67801 L .707 .577 .707 r
F P
0 g
s
.7773 .67484 m .77659 .68315 L p .7687 .67801 L .707 .577 .707 r
F P
0 g
s
.77659 .68315 m .77583 .69211 L p .7687 .67801 L .707 .577 .707 r
F P
0 g
s
.74234 .65998 m .74249 .66094 L p .74197 .6606 L .707 .577 .707 r
F P
0 g
s
.71448 .66865 m .71301 .68592 L .6837 .68935 L p .707 .577 .707 r
F P
0 g
s
.74476 .68686 m .74623 .6696 L .7773 .67484 L p .707 .577 .707 r
F P
0 g
s
.29816 .65977 m .31135 .69272 L .32314 .70086 L p .707 .577 .707 r
F P
0 g
s
.74623 .6696 m .74476 .68686 L .71301 .68592 L p .707 .577 .707 r
F P
0 g
s
.48837 .70126 m .48497 .71983 L .49215 .71503 L p .707 .577 .707 r
F P
0 g
s
.49215 .71503 m .49555 .69647 L .48837 .70126 L p .707 .577 .707 r
F P
0 g
s
.29359 .56799 m .30714 .51273 L .31427 .50913 L p .707 .577 .707 r
F P
0 g
s
.29419 .68346 m .29759 .66489 L .29495 .65822 L p .707 .577 .707 r
F P
0 g
s
.31135 .69272 m .29816 .65977 L .29549 .6476 L p .707 .577 .707 r
F P
0 g
s
.29495 .65822 m .29155 .67679 L .29419 .68346 L p .707 .577 .707 r
F P
0 g
s
.31427 .50913 m .30072 .5644 L .29359 .56799 L p .707 .577 .707 r
F P
0 g
s
.30868 .68055 m .31135 .69272 L p .29637 .6501 L .707 .577 .707 r
F P
0 g
s
.29669 .65059 m .30868 .68055 L p .29637 .6501 L .707 .577 .707 r
F P
0 g
s
.30868 .68055 m .29549 .6476 L .30219 .63259 L p .707 .577 .707 r
F P
0 g
s
.29155 .67679 m .29495 .65822 L .29961 .65511 L p .707 .577 .707 r
F P
0 g
s
.29961 .65511 m .30213 .65342 L p .30065 .65671 L .707 .577 .707 r
F P
0 g
s
.29155 .67679 m .29961 .65511 L .30065 .65671 L .707 .577 .707 r
F
.29549 .6476 m .29669 .65059 L p .29637 .6501 L F P
0 g
s
.02 w
.3971 .63512 Mdot
.5 Mabswid
.49555 .69647 m .49215 .71503 L .48951 .70836 L p .707 .577 .707 r
F P
0 g
s
.48951 .70836 m .49291 .6898 L .49555 .69647 L p .707 .577 .707 r
F P
0 g
s
.30072 .5644 m .31427 .50913 L .3304 .50833 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.30213 .65342 m .29873 .67199 L .29155 .67679 L p .707 .577 .707 r
F P
0 g
s
.3304 .50833 m .31685 .5636 L .30072 .5644 L p .707 .577 .707 r
F P
0 g
s
.31538 .66554 m .30868 .68055 L p .30301 .63867 L .707 .577 .707 r
F P
0 g
s
.30539 .6406 m .31538 .66554 L p .30301 .63867 L .707 .577 .707 r
F P
0 g
s
.31538 .66554 m .30219 .63259 L .3176 .6162 L p .707 .577 .707 r
F P
0 g
s
.3176 .6162 m .33079 .64916 L .31538 .66554 L p .707 .577 .707 r
F P
0 g
s
.29873 .67199 m .30213 .65342 L .31823 .651 L p .707 .577 .707 r
F P
0 g
s
.31823 .651 m .31842 .65097 L p .31833 .65107 L .707 .577 .707 r
F P
0 g
s
.29873 .67199 m .31823 .651 L .31833 .65107 L .707 .577 .707 r
F
.30219 .63259 m .30539 .6406 L p .30301 .63867 L F P
0 g
s
.49291 .6898 m .48951 .70836 L .47731 .70047 L p .707 .577 .707 r
F P
0 g
s
.47731 .70047 m .48071 .68191 L .49291 .6898 L p .707 .577 .707 r
F P
0 g
s
.31685 .5636 m .3304 .50833 L .35394 .51039 L p .707 .577 .707 r
F P
0 g
s
.35394 .51039 m .34039 .56566 L .31685 .5636 L p .707 .577 .707 r
F P
0 g
s
.31842 .65097 m .31502 .66954 L .29873 .67199 L p .707 .577 .707 r
F P
0 g
s
.34039 .56566 m .35394 .51039 L .3826 .51511 L p .707 .577 .707 r
F P
0 g
s
.33079 .64916 m .3176 .6162 L .34023 .60005 L p .707 .577 .707 r
F P
0 g
s
.48071 .68191 m .47731 .70047 L .45674 .69214 L p .707 .577 .707 r
F P
0 g
s
.45674 .69214 m .46014 .67357 L .48071 .68191 L p .707 .577 .707 r
F P
0 g
s
.3826 .51511 m .36905 .57038 L .34039 .56566 L p .707 .577 .707 r
F P
0 g
s
.40002 .5773 m .41357 .52203 L .44381 .53048 L p .707 .577 .707 r
F P
0 g
s
.31502 .66954 m .31842 .65097 L .34224 .65109 L p .707 .577 .707 r
F P
0 g
s
.36905 .57038 m .3826 .51511 L .41357 .52203 L p .707 .577 .707 r
F P
0 g
s
.34224 .65109 m .33884 .66966 L .31502 .66954 L p .707 .577 .707 r
F P
0 g
s
.34023 .60005 m .35342 .633 L .33079 .64916 L p .707 .577 .707 r
F P
0 g
s
.35342 .633 m .34023 .60005 L .36784 .58571 L p .707 .577 .707 r
F P
0 g
s
.36784 .58571 m .38104 .61866 L .35342 .633 L p .707 .577 .707 r
F P
0 g
s
.46014 .67357 m .45674 .69214 L .42983 .68417 L p .707 .577 .707 r
F P
0 g
s
.42983 .68417 m .43323 .66561 L .46014 .67357 L p .707 .577 .707 r
F P
0 g
s
.33884 .66966 m .34224 .65109 L .37124 .65379 L p .707 .577 .707 r
F P
0 g
s
.37124 .65379 m .36784 .67236 L .33884 .66966 L p .707 .577 .707 r
F P
0 g
s
.43323 .66561 m .42983 .68417 L .39919 .67736 L p .707 .577 .707 r
F P
0 g
s
.39919 .67736 m .40259 .65879 L .43323 .66561 L p .707 .577 .707 r
F P
0 g
s
.36784 .67236 m .37124 .65379 L .40259 .65879 L p .707 .577 .707 r
F P
0 g
s
.40259 .65879 m .39919 .67736 L .36784 .67236 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
Ogoo8P00O7oo001fOol90005FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP06001fOol0
079oo`@0009JEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00IJEP@0
079oo`00KWoo10001UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH0
25YF00@005YF0000071oo`00K7oo0P0000=JEP00FUH01eYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02UYF00<005YFFUH025YF00@005YFFUIJEP<006eoo`00JWoo0P000eYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
15YF0P00Jgoo001XOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH3001YOol006Moo`8000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJ
EP03001JEUYF008006Moo`00IWoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001VOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02
FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1T
Ool006Eoo`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eo
o`04001JEUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001J
EUYF0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol006Eoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Uoo`P000Aoo`04001JEUYF0006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`<000=JEP04001JEUYFFUH80006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Moo`8000AJEP03001JEUYF00AJEP04
001JEUYFFUH80008FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`03001JEP0000=JEP03001J
EUYF00AJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo06Aoo`00
EWoo00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF1P002eYF00<0
05YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<0
07ooOol0I7oo001FOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07
FUH00`00FUIJEP040008FUH00`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH00`00FUIJEP02FUH00`00Oomoo`1TOol005Ioo`8000AJEP03001JEUYF00AJEP03001JEUYF
00EJEP03001JEUYF00IJEP03001JEUYF00EJEP@000AJEP03001JEUYF00YJEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo011oo`l004Eoo`00EGoo00<0
05YF000015YF00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01eYF00@0
05YF0000009JEP03001JEUYF00YJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP03001oogoo00Yoo`H000=JEP03001JEUYF00IJEP03001JEUYF00@0045oo`00EGoo
00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01UYF
00<005YFFUH00UYF0`0035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<007ooOol01Woo100000=JEP00FUH01UYF00<005YFFUH01UYF00<005YFFUH015YF1000
?Goo001EOol00`00FUH00003FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00
FUIJEP06FUH00`00FUIJEP04FUH2000;FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH00`00FUIJEP02FUH00`00Oomoo`04Ool20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00
FUIJEP06FUH01000FUH00000>goo001EOol20004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH30009FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`02Ool30006FUH00`00FUIJEP04FUH00`00
FUIJEP06FUH00`00FUIJEP07FUH01000FUIJEUYF0P00>Goo001DOol00`00FUH00004FUH00`00FUIJ
EP03FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP020007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH00`00
Oomoo`020002FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH0
0`00FUIJEP03FUH2000gOol005Aoo`03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03
001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP8000EJEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP03001oo`0000AJEP03001JEUYF
00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<003Eoo`00
E7oo00<005YF000015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH015YF0`000eYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00P00<goo001DOol20004FUH00`00FUIJ
EP04FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJ
EP03FUH01@00FUIJEUYF00000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<0
05YFFUH00UYF0`000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00UYF0P00<Goo001COol00`00FUH00004FUH00`00FUIJEP03
FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUIJEUYF0P0000=JEP00FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH0
0UYF00<005YF00000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01EYF00<005YFFUH00eYF0P00<7oo001COol00`00FUH0000<0006FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000FUIJEUYF0P0000=JEP00
FUH02eYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH015YF
00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YF0000;goo001COol20003FUH00`00FUIJEP04FUH00`00FUIJEP040002FUH00`00FUIJEP07
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP04FUH02000FUIJEP00FUH005YF000<FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP04FUH00`00FUIJ
EP04FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUH0
000_Ool005=oo`03001JEUYF009JEP03001JEUYF00=JEP03001JEUYF00EJEPH000EJEP03001JEUYF
00MJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH20002FUH00`00FUIJEP0:FUH00`00
FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH20004FUH00`00FUIJEP03FUH00`00FUIJEP05
FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUIJEP04FUH00`00FUIJEP04FUH01000FUIJEP00
;Woo001DOol00`00FUIJEP07FUH00`00FUIJEP05FUH00`00FUIJEP03FUH60009FUH00`00FUIJEP05
FUH00`00FUIJEP03FUH01000FUIJEUYF0P000UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YF
FUH01EYF00<005YFFUH00UYF0P0015YF00<005YFFUH00eYF00<005YFFUH01EYF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00EGoo0P00
1eYF00<005YFFUH015YF00<005YFFUH01EYF0`0000=JEP0000001eYF00<005YFFUH01EYF00<005YF
FUH015YF00@005YFFUIJEP80009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07
001JEUYFFUH005YF00000eYF00<005YFFUH015YF00<005YFFUH00UYF3`001UYF00<005YFFUH01EYF
00<005YFFUH015YF00D005YFFUIJEP0002eoo`00Egoo00<005YFFUH015YF00<005YFFUH015YF00<0
05YFFUH00UYF0`001EYF0`001EYF00<005YFFUH01EYF00<005YFFUH015YF00<005YFFUH00UYF00@0
05YFFUH000aJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYFFUH005YF00000eYF00<005YF
FUH00eYF1P003goo10000UYF00<005YFFUH01EYF00<005YFFUH015YF00D005YFFUIJEP0002eoo`00
F7oo0P000eYF00<005YFFUH01EYF00<005YFFUH00P0025YF00<005YFFUH01UYF00<005YFFUH015YF
00<005YFFUH00eYF00<005YFFUH01UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00L005YFFUIJEP00FUH00003FUH00`00FUH00003000IOol40006FUH00`00FUIJEP03FUH00`00FUIJ
EP02FUH2000/Ool005Yoo`800003FUH005YF00IJEP@000UJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00=JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJ
EP05FUH01000FUIJEUYF0P0015YF0P008Goo0P0015YF00<005YFFUH00eYF00L005YFFUIJEP00FUH0
000/Ool005aoo`<000EJEP8000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03
001JEUYF009JEP04001JEUYFFUH20003FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05
FUH01000FUIJEUYF0P000UYF0P009Goo0`0000=JEP00FUH015YF00L005YFFUIJEP00FUH0000/Ool0
05moo`D000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP03
001JEUYF008000=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH4
0002FUH00`00Oomoo`0COol3000?Ool20005FUH01`00FUIJEUYF001JEP0002aoo`00H7oo0P0025YF
00<005YFFUH01UYF00<005YFFUH01EYF30000UYF00@005YFFUH000AJEP03001JEUYF00YJEP03001J
EUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH20004FUH3000BOol5000@Ool20003FUH01`00FUIJ
EUYF001JEP0002aoo`00Ggoo0P002EYF00<005YFFUH01eYF00<005YFFUH0100015YF00<005YFFUH0
15YF1@0000=JEP00FUH00eYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YF
FUH00UYF00<005YFFUH00UYF00@005YFFUH0015oo`D0019oo`04001JEUYF0003FUH2000]Ool005io
o`04001JEUYF0009FUH00`00FUIJEP05FUH50007FUH00`00FUIJEP04FUH4000015YF000000000eYF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00`0015YF00@005YFFUIJ
EP8000moo`D001=oo`<000=JEP8002eoo`00G7oo0P000eYF00<005YFFUH01eYF00<005YFFUH00eYF
0P000eYF00<005YFFUH01UYF00<005YFFUH015YF00@005YF001JEP@000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<000=JEP03001JEUYF00AJEP8000ioo`<001Io
o`04001JEUYFFUH2000]Ool005]oo`03001JEUYF00AJEP03001JEUYF00MJEP03001JEP0000D0009J
EP03001JEUYF00EJEP03001JEUYF00EJEP08001JEUYF001JEP00FUH000=JEP03001JEUYF00YJEP03
001JEUYF00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH01UYF0P009Goo0P00
00AJEP00FUH002eoo`00FWoo00<005YFFUH01EYF00<005YFFUH01eYF0P0000=JEP00FUH00eYF1P00
15YF00<005YFFUH015YF00@005YFFUIJEP<00003FUH005YF009JEP03001JEUYF00YJEP03001JEUYF
00QJEP03001JEUYF00EJEP06001JEUYF001JEP000eYF00<005YFFUH025YF0P008Goo0P0000IJEP00
FUH005YF000]Ool004moo``000MJEP03001JEUYF00EJEP8000=JEP03001JEUYF00IJEP03001JEP00
00X0009JEP@000=JEP04001JEUYF000<FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEP00
1EYF00<005YFFUH02UYF10006Goo100000AJEP00FUIJEP800003FUH007oo02aoo`00AWoo2@0015YF
00@005YFFUIJEP80009JEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF00=JEP03001JEUYF
00IJEP03001JEUYF00MJEP<000EJEP05001JEUYFFUH00002FUH00`00FUIJEP0:FUH00`00FUIJEP08
FUH00`00FUIJEP05FUH01000FUIJEP001EYF00<005YFFUH00eYF00<005YFFUH025YF100047oo1@00
1EYF00L005YFFUIJEP00FUH0000]Ool003ioo`P000eJEP04001JEUYF0004FUH00`00FUIJEP05FUH0
1000FUIJEUYF0P001UYF0`001UYF00<005YFFUH01UYF00D005YFFUIJEP0000AJEP04001JEUYF0003
FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01@00FUIJEUYF000015YF00<005YF
FUH00eYF00<005YFFUH035YF40000eYF00<005YFFUH015YF00L005YFFUIJEP00FUH0000]Ool003Io
o`P000=JEP03001JEUYF00mJEP03001JEP0000IJEP03001JEUYF00EJEP<00003FUH005YF00AJEPD0
00EJEP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00=JEP03001JEP0000=JEP03001JEUYF
00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05001JEUYFFUH00004FUH00`00FUIJEP03FUH00`00
FUIJEP0GFUH00`00FUIJEP05FUH00`00FUIJEP04FUH01000OomJEUYF0P00;Woo000`Ool60003FUH0
0`00FUIJEP05FUH00`00FUIJEP0?FUH00`00FUH00006FUH00`00FUIJEP05FUH20002FUH00`00FUIJ
EP03FUH50005FUH00`00FUIJEP03FUH20005FUH00`00FUIJEP03FUH20004FUH00`00FUIJEP0:FUH0
0`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP02FUH01000FUIJEP001UYF00<005YFFUH03eYF
00=ooeYFFUH01EYF00<005YFFUH01EYF00<005YFFUH02P00;Woo000[Ool50002FUH00`00FUIJEP04
FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH01000FUH000001UYF00<005YFFUH00UYF0P0000EJEP00
FUIJEP0000EJEPD000EJEP03001JEUYF009JEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP800003FUH0
05YF00EJEP03001JEUYF01MJEP04001JEUYFFUH70003FUH01000FUIJEUYF0`00;Woo000[Ool00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0?FUH200000eYF001JEP05FUH0
1@00FUIJEUYF00000eYF00@005YFFUH000IJEP<000IJEP03001JEUYF00<000QJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEP000006FUH00`00FUIJEP0@FUH00gooFUH000080003FUH00`00FUIJEP04FUH01000FUIJ
EUYF0`00;Woo000[Ool00`00FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00FUIJEP0?
FUH200000eYF00000006FUH40003FUH01000FUIJEP001UYF00<005YFFUH01UYF0`000eYF00<005YF
FUH01EYF00D005YFFUIJEP0000IJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03
001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP04FUH00`00FUIJEP04FUH70004FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH500000eYF0000000^Ool002]oo`03001JEP0000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEUYF0006FUH01@00FUIJEUYF
00000UYF00@005YFFUH000IJEP03001JEUYF00EJEP8000EJEP03001JEUYF00IJEP<000MJEP03001J
EUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYFFUH20003FUH0
0`00FUIJEP05FUH00`00FUIJEP040002FUH00`00FUIJEP06FUH00`00FUIJEP05FUH60002FUH01000
FUIJEUYF0P00;Woo000[Ool01000FUIJEP000eYF00<005YFFUH015YF00<005YFFUH01UYF0P001eYF
0P001eYF60000eYF00<005YFFUH00UYF0`0025YF00<005YFFUH01EYF00<005YFFUH01eYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00eYF00@005YF
FUH000AJEPH000IJEP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH005YF00AJEP04001JEUYF
FUH2000^Ool002aoo`03001JEP0000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00IJ
EP03001JEUYF00IJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00@0009JEP80
0003FUH005YF00QJEP03001JEUYF00AJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP03001JEUYF009JEP03001JEUYF00AJEPL000=JEP03001JEUYF00IJEP03001J
EUYF00IJEPD000IJEP03001JEUYF00=JEP03001JEUYF008002ioo`00;7oo00<005YF000015YF00<0
05YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01EYF0`0015YF00<005YFFUH0
15YF00<005YFFUH01EYF00<005YFFUH015YF1@0000=JEP00FUH025YF00<005YFFUH00UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00<005YF
FUH00UYF0`0000=JEP00FUH01UYF00<005YFFUH01EYF2P000eYF00<005YFFUH01EYF00<005YFFUH0
0eYF00H005YFFUH005YF000]Ool002aoo`03001JEP0000AJEP8000EJEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJ
EP03001JEUYF00@000MJEP03001JEUYF008000aJEP03001JEUYF00YJEP03001JEUYF00QJEP03001J
EUYF00EJEP03001JEUYF009JEP03001JEP00008000AJEP03001JEUYF00EJEPP000AJEP03001JEUYF
00AJEP03001JEP0000MJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool002aoo`03001JEP0000AJ
EP8000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP8000AJEP03001JEUYF00AJ
EP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00AJEP@000AJEP800003FUH005YF00]JEP03
001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP04001JEUYFFUH300000eYF001JEP04FUH8
0003FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01000FUIJ
EUYF0P00;Goo000/Ool00`00FUH00004FUH20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH20005
FUH00`00FUH00002FUH=0004FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00FUH000040002FUH0
0`00FUIJEP0:FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP0;0002
FUH00`00FUIJEP02FUHB00001EYF001JEUYF00001eYF00<005YFFUH00eYF00@005YFFUIJEP8002eo
o`00;7oo00<005YF000015YF00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YF
FUH015YF00<005YF00000P0000=JEP0000000eYF00<005YFFUH015YF2@0015YF00<005YFFUH01eYF
00<005YFFUH00eYF100035YF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00H005YF
FUH005YF0004FUH00`00FUIJEP03FUH50005FUH00`00FUIJEP06FUH01000FUIJEUYF1P001UYF00<0
05YFFUH00eYF00@005YFFUIJEP8002eoo`00;7oo00@005YFFUH000=JEP03001JEUYF00=JEP03001J
EUYF00EJEP03001JEUYF00IJEP03001JEUYF00EJEP80009JEP800003FUH005YF009JEP8000IJEP80
00IJEPL000IJEP03001JEUYF00EJEP03001JEP00008000YJEP03001JEUYF00YJEP03001JEUYF00QJ
EP03001JEUYF00EJEP06001JEUYF001JEP0015YF00<005YFFUH00`0000=JEP00FUH01eYF00<005YF
FUH01UYF00<005YFFUH01EYF00@005YF000000EJEP03001JEUYF00=JEP03001JEUYF008002eoo`00
;7oo00@005YFFUH000=JEP03001JEUYF00=JEP03001JEUYF00EJEP8000MJEP03001JEUYF00EJEP80
00=JEP03001JEP0000AJEP03001JEUYF00AJEP8000QJEP<0009JEP@0009JEP03001JEUYF00EJEP03
001JEUYF009JEP8000QJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP07001JEUYF
FUH005YF00000eYF0`0015YF00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00@005YF
FUIJEP<0009JEP03001JEUYF00=JEP<002moo`00;Goo00<005YF00000eYF00<005YFFUH00eYF00<0
05YFFUH00UYF3`001UYF00L005YFFUIJEP00FUH00004FUH20006FUH00`00FUIJEP05FUH50005FUH4
0005FUH00`00FUIJEP04FUH20007FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH0
2000FUIJEUYF001JEP00FUH30006FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP06FUH0
0`00FUIJEP04FUH30003FUH3000aOol002eoo`03001JEP00009JEP03001JEUYF00=JEPP000QJEP03
001JEUYF009JEP@0009JEP<00005FUH00000FUH00004FUH00`00FUIJEP04FUH20006FUH50003FUH3
0003FUH400000eYF001JEP05FUH01000FUH000001EYF00<005YFFUH02UYF00<005YFFUH025YF00<0
05YFFUH01EYF00H005YFFUIJEP00FUH20002FUH00`00FUIJEP04FUH00`00FUIJEP02FUHA0004FUH0
0`00FUIJEP05FUH5000dOol002eoo`03001JEP00009JEP03001JEUYF00<000AJEQ4000Aoo`<0009J
EP<00003FUH005YF00=JEP03001JEUYF00EJEP03001JEUYF00AJEPP0009JEP03001JEUYF00EJEP80
00EJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF
00EJEP07001JEUYFFUH005YF00000eYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00@005YF
FUIJEPH000IJEP03001JEUYF008003Aoo`00;Goo0`000UYF2P0067oo0P000eYF0P001EYF00<005YF
FUH015YF00<005YFFUH01EYF10001EYF00<005YFFUH01eYF0P000eYF00<005YFFUH00UYF00<005YF
FUH00UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP03
001JEP0000<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00@000=oo`8000AJEP03001J
EUYF009JEP80039oo`00;Goo0P000UYF10008Goo0P000UYF0P0015YF00<005YFFUH01EYF00<005YF
FUH010000UYF10000eYF00<005YFFUH02EYF0P0000=JEP00FUH00eYF00<005YFFUH00UYF00<005YF
FUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP<000=JEP8000IJEP03001JEUYF
00EJEP03001JEUYF009JEPL000Uoo`<00003FUH005YF00AJEP80035oo`00;Goo00AJEP00FUH002Mo
o`H000=JEP04001JEUYFFUH60003FUH00`00FUIJEP04FUH60009FUH01000FUH000000eYF0P0015YF
00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00@005YFFUIJEP80009JEP800003FUH0
05YF00EJEP03001JEUYF009JEPP001=oo`8000EJEP03001JEP00031oo`00;Goo00=JEP000000:Woo
00@005YFFUIJEPL000QJEP03001JEUYF00MJEP04001JEUYFFUH?00000eYF00000004FUH00`00FUIJ
EP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF10000eYF00@005YFFUIJEPP001eo
o`8000=JEP04001JEUYF000_Ool002eoo`03FUH007oo02]oo`8000AJEP03001JEP0000<000IJEP03
001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00AJEP04001JEUYFFUH20005FUH00`00FUIJEP0:
FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01000FUIJEUYF2`0000=JEP00FUH00UYF00<005YF0000
7goo0P0000=JEP00FUH00UYF00<007ooOol0;7oo000/Ool00`00FUH0000^Ool01000FUIJEP0015YF
00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH015YF00H005YFFUH0
05YF0005FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH00`00FUIJEP030002FUH0
0`00FUIJEP05FUH00`00FUIJEP02FUH00`00Oomoo`0POol20003FUH00`00Oomoo`0/Ool002aoo`<0
02moo`<000AJEP04001JEUYF0002FUH70004FUH00`00FUIJEP05FUH00`00FUIJEP04FUH01`00FUIJ
EUYF001JEP0000EJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP03001JEUYF00<0
009JEP03001JEUYF00EJEP03001JEUYF009JEP03001oogoo00Qoo`<001Moo`04001JEUYF000^Ool0
02aoo`@0031oo`03001JEUYF009JEP04001JEUYF0006FUH00`00FUIJEP080004FUH00`00FUIJEP04
FUH00`00FUIJEP030006FUH00`00FUIJEP0:FUH00`00FUIJEP08FUH00`00FUIJEP05FUH01P00FUIJ
EP00FUH0009JEP03001JEUYF00EJEP05001JEUYFFUH0000:Ool5000FOol01@00FUH005YF0000;Goo
000/Ool01@00FUH005YF00005goo0`005Woo00D005YFFUIJEP00009JEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEP0000d000UJEP03001JEUYF00YJEP03001JEUYF00QJEP03001JEUYF00EJEP05
001JEUYF001JEP020002FUH00`00FUIJEP05FUH3000;Ool5000GOol200000eYF001oo`0/Ool002ao
o`05001JEP00FUH0000FOol5000EOol01@00FUIJEUYF00000UYF00<005YFFUH015YF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH0
1EYF00<005YFFUH00P000UYF00<005YF00001eYF00<007ooOol02goo1@0067oo00<005YF0000;Goo
000/Ool00`00FUH00002FUH00`00Oomoo`0COol5000FOol01000FUIJEP000UYF00<005YFFUH015YF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF
00<005YFFUH01EYF00D005YFFUIJEP0000=JEP8000EJEP8000moo`<001Uoo`03001JEP0002eoo`00
;7oo0P0015YF00<007ooOol04Woo1@005goo0`000UYF00<005YFFUH015YF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF00D0
05YFFUIJEP0000=JEP<0009JEP8002eoo`8002ioo`00;7oo0P0015YF0P0057oo0`0067oo0`000UYF
00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF
00<005YFFUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH0009JEP8002moo`8002io
o`00;Goo00<005YFFUH00UYF00<005YF0000;goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02UYF00<005YFFUH025YF00<005YFFUH01EYF
00<005YFFUH00UYF0P0000=JEP00FUH00UYF0P00;7oo1000;Woo000]Ool01@00FUIJEUYF00000eYF
0P00;Goo0P000UYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01eYF5P001UYF00<005YF
FUH025YF00<005YFFUH01EYF00<005YFFUH00UYF00@005YF000000EJEP8002Qoo`80009JEP03001o
ogoo02eoo`00;Goo00D005YFFUIJEP0000EJEP03001oogoo02Yoo`80009JEP03001JEUYF00AJEP03
001JEUYF00IJEP04001JEUYFFUH60008FUH00`00FUIJEP0:FUH:0008FUH00`00FUIJEP05FUH00`00
FUIJEP02FUH40005FUH00`00FUH00003000ROol20003FUH2000_Ool002ioo`04001JEUYF0006FUH0
0`00Oomoo`0XOol00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP04FUH60002FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP07FUH60002FUH00`00FUIJEP05FUH00`00FUIJEP02FUH2
000015YF000000000eYF00<005YFFUH00eYF1@006Goo100000=JEP00FUH00UYF00<007ooOol0;Woo
000^Ool01000FUIJEP001UYF10009Woo00@005YF0000009JEP03001JEUYF00AJEP03001JEUYF00@0
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP04001JEUYFFUH40006FUH00`00
FUIJEP02FUH00`00FUIJEP02FUH20002FUH00`00FUIJEP05FUH00`00FUIJEP04000@Ool50005FUH0
1@00FUIJEUYF0000<7oo000_Ool20007FUH01000FUIJEUYF0`004Woo5@000UYF00<005YFFUH00eYF
100000=JEP00FUH02EYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
1EYF0P0015YF00<005YFFUH00UYF00<005YFFUH015YF0`001eYF00<005YFFUH015YF40000eYF00<0
05YFFUH00eYF00<005YFFUH00P00<Goo000_Ool20007FUH00`00FUIJEP04FUHB0003FUH00`00FUIJ
EP05FUH00`00FUIJEP03FUH01000FUH000000UYF00@005YFFUIJEP8000EJEP03001JEUYF00QJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP<00003FUH005YF00=J
EP03001JEUYF00EJEP<000EJEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001J
EUYF00=JEP<003=oo`00<7oo00<005YFFUH015YF200015YF00<005YFFUH01UYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUH0009JEP04001JEP000007FUH00`00FUIJEP08
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02
0004FUH00`00FUIJEP04FUH200000eYF0000000300000eYF001JEP08FUH00`00FUIJEP06FUH00`00
FUIJEP05FUH00`00FUIJEP02FUH2000eOol0035oo`H000=JEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP03001JEP00009JEP<000QJEP03001J
EUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001J
EUYF009JEP80009JEP/0009JEPH000IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP000080
03Moo`00;goo0`0000=JEP00FUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00eYF00D005YF001JEP00009JEP03001JEUYF00IJEP03001JEUYF
00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
00=JEP@000MJEP03001JEUYF00H0009oo`@0009JEP03001JEUYF00IJEP03001JEUYF009JEPH003Yo
o`00;Goo0`000eYF00<005YFFUH015YF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF
5P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P001UYF00<005YFFUH00eYF0P00
00=JEP00Ool017oo4000@7oo000]Ool00`00FUH00003FUH00`00FUIJEP05FUH00`00FUIJEP05FUH0
0`00FUIJEP02FUH900000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF0P000eYF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF00<005YFFUH00P001eYF00<005YFFUH00UYF00@005YF000005Eo
o`00;Goo00<005YF000015YF00<005YFFUH015YF00<005YFFUH00UYF2@0025YF00<005YFFUH01EYF
00<005YFFUH00eYF00<005YF00000eYF0P000eYF00<005YFFUH01UYF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF00<005YF
FUH00P001eYF00<005YFFUH00eYF00@005YF000005Aoo`00;Goo00<005YF000015YF00@005YFFUIJ
EPP000QJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80009JEP@000=JEP03001J
EUYF00IJEP03001JEUYF00QJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00MJEP03001JEUYF00=JEP03001JEUYF00`000=JEP04001JEP00001DOol002eoo`03001JEP00
009JEPH000AJEP<000UJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEPD000=oo`05
001JEUYFFUH00008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP07FUH00`00FUIJEP03FUH00`00FUH000020003FUH00`00FUIJEP04FUH400000eYF
0000001DOol002eoo`03001JEP0000<000AJEP03001JEUYF00AJEP<000IJEP03001JEUYF00MJEP03
001JEUYF00AJEP04001JEUYFFUH20008Ool01@00FUIJEUYF000025YF00<005YFFUH025YF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P000eYF
0`001UYF00@005YFFUIJEP800003FUH007oo05=oo`00;Goo0P000eYF00<005YFFUH00UYF00<005YF
FUH01EYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01EYF00@005YF000000]oo`04
001JEUYF0008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP07FUH00`00FUIJEP03FUH20004FUH30005FUH01000FUIJEUYF1000E7oo000^OolN0004
FUH00`00FUIJEP02FUH5000>Ool30008FUH00`00FUIJEP08FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP02FUH20004FUH01000FUIJEUYF0`0000=J
EP00FUH00UYF00<005YF00000P00E7oo001<Ool9000EOol20007FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUH000020006FUH00`00
FUIJEP04FUH20003FUH01000FUH005YF0P00Dgoo001/Ool30004FUH00`00FUIJEP08FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06FUH30002Ool40002FUH00`00FUIJ
EP05FUH00`00FUH00002FUH30002FUH00`00Oomoo`1AOol006moo`<00003FUH005YF00UJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00=JEP@000Qoo`@000IJEP03001J
EUYF00800003FUH00000009JEP03001oogoo055oo`00LWoo1`001EYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YF000020002goo100000=JEP00FUH00UYF0`000UYF0P00E7oo
001iOol;0006FUH00`00FUIJEP0:FUH00`00FUIJEP04FUH70004Ool5000?Ool80002FUH2001DOol0
08AooaX000]oo`D000ioo`8000=JEP03001JEUYF00=JEP03001oogoo05=oo`00Sgoo00@005YFFUH0
01Moo`<000aoo`<000IJEP03001JEUYF008005Ioo`00Sgoo00<005YF00009Goo0P0000=JEP00FUH0
1UYF0`00F7oo002@Ool2000ROol30003FUH00`00FUIJEP05FUH00`00Oomoo`1HOol0091oo`<001eo
o`@000IJEP03001JEUYF00=JEP8005]oo`00T7oo00<005YFFUH00`005Woo10000UYF00<005YFFUH0
1UYF00<005YFFUH00P00GGoo002@Ool2000015YF001JEUYF1`002Goo1P001UYF00<005YFFUH01UYF
0`00Ggoo002AOol00`00FUH00005FUH01000FUIJEUYF2@000eYF00<005YFFUH01eYF00<005YFFUH0
15YF0P00HGoo002AOol01000FUIJEP0015YF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH0
1eYF00<005YFFUH01000Hgoo002BOol30005FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP04FUH5001WOol009Aoo`<000=JEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00@006ao
o`00Ugoo1`0015YF00<005YFFUH00UYF1P00L7oo002NOol9001fOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003o
OolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaio
o`00ogoo7Woo0000\
\>"],
  ImageRangeCache->{{{67.8125, 295}, {519.25, 290}} -> {-0.291303, 1.26499, \
0.00348964, 0.00348964}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00942 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0047153 1.00943 1.11022e-016 1.00943 [
[ 0 0 0 0 ]
[ 1 1.00942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00942 L
0 1.00942 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.59172 .73733 m .60529 .68206 L .575 .67363 L p .707 .577 .707 r
F P
0 g
s
.60529 .68206 m .59172 .73733 L .62266 .74423 L p .707 .577 .707 r
F P
0 g
s
.62266 .74423 m .63623 .68896 L .60529 .68206 L p .707 .577 .707 r
F P
0 g
s
.63623 .68896 m .62266 .74423 L .65123 .74893 L p .707 .577 .707 r
F P
0 g
s
.65123 .74893 m .66481 .69366 L .63623 .68896 L p .707 .577 .707 r
F P
0 g
s
.56143 .7289 m .575 .67363 L .54833 .6645 L p .707 .577 .707 r
F P
0 g
s
.575 .67363 m .56143 .7289 L .59172 .73733 L p .707 .577 .707 r
F P
0 g
s
.54833 .6645 m .53476 .71977 L .56143 .7289 L p .707 .577 .707 r
F P
0 g
s
.66745 .75034 m .67464 .75096 L p .65394 .73791 L .707 .577 .707 r
F P
0 g
s
.66967 .75045 m .67087 .75349 L p .69868 .7672 L .707 .577 .707 r
F P
0 g
s
.67087 .75349 m .6828 .78349 L .69258 .77346 L p .707 .577 .707 r
F P
0 g
s
.69258 .77346 m .69868 .7672 L p .67087 .75349 L .707 .577 .707 r
F P
0 g
s
.66481 .69366 m .65394 .73791 L p .67464 .75096 L .707 .577 .707 r
F P
0 g
s
.65394 .73791 m .65123 .74893 L .66745 .75034 L p .707 .577 .707 r
F P
0 g
s
.67464 .75096 m .68821 .69569 L .66481 .69366 L p .707 .577 .707 r
F P
0 g
s
.53476 .71977 m .54833 .6645 L .5279 .65556 L p .707 .577 .707 r
F P
0 g
s
.63197 .8136 m .61884 .78057 L .58887 .79144 L p .707 .577 .707 r
F P
0 g
s
.61884 .78057 m .63197 .8136 L .65981 .79948 L p .707 .577 .707 r
F P
0 g
s
.65981 .79948 m .64668 .76644 L .61884 .78057 L p .707 .577 .707 r
F P
0 g
s
.602 .82448 m .58887 .79144 L .55971 .798 L p .707 .577 .707 r
F P
0 g
s
.58887 .79144 m .602 .82448 L .63197 .8136 L p .707 .577 .707 r
F P
0 g
s
.64668 .76644 m .65981 .79948 L .6828 .78349 L p .707 .577 .707 r
F P
0 g
s
.6828 .78349 m .66967 .75045 L .64668 .76644 L p .707 .577 .707 r
F P
0 g
s
.5279 .65556 m .51432 .71083 L .53476 .71977 L p .707 .577 .707 r
F P
0 g
s
.59114 .84337 m .5936 .82997 L p .56386 .81802 L .707 .577 .707 r
F P
0 g
s
.58501 .82269 m .56386 .81802 L p .5936 .82997 L .707 .577 .707 r
F P
0 g
s
.56386 .81802 m .56045 .83659 L .59114 .84337 L p .707 .577 .707 r
F P
0 g
s
.56045 .83659 m .56386 .81802 L .53681 .81008 L p .707 .577 .707 r
F P
0 g
s
.57284 .83104 m .56165 .80289 L p .5342 .7996 L .707 .577 .707 r
F P
0 g
s
.56165 .80289 m .55971 .798 L .55615 .79822 L p .707 .577 .707 r
F P
0 g
s
.55615 .79822 m .5342 .7996 L p .56165 .80289 L .707 .577 .707 r
F P
0 g
s
.5936 .82997 m .59454 .8248 L .58501 .82269 L p .707 .577 .707 r
F P
0 g
s
.59454 .8248 m .59114 .84337 L .62246 .84833 L p .707 .577 .707 r
F P
0 g
s
.62246 .84833 m .62587 .82976 L .59454 .8248 L p .707 .577 .707 r
F P
0 g
s
.55971 .798 m .57284 .83104 L .602 .82448 L p .707 .577 .707 r
F P
0 g
s
.62587 .82976 m .62246 .84833 L .65136 .85099 L p .707 .577 .707 r
F P
0 g
s
.65136 .85099 m .65477 .83242 L .62587 .82976 L p .707 .577 .707 r
F P
0 g
s
.68821 .69569 m .67464 .75096 L .68166 .7506 L p .707 .577 .707 r
F P
0 g
s
.69036 .74504 m .68821 .69569 L .68287 .74045 L .707 .577 .707 r
F
.68997 .74529 m .68287 .74045 L .68166 .7506 L F
.69036 .74504 m .68287 .74045 L .68997 .74529 L F
.69868 .7672 m .70447 .75517 L p .69151 .74634 L F P
0 g
s
.68997 .74529 m .69077 .74731 L p .69151 .74634 L .707 .577 .707 r
F P
0 g
s
.69077 .74731 m .69868 .7672 L p .69151 .74634 L .707 .577 .707 r
F P
0 g
s
.69874 .73689 m .69894 .73535 L .69151 .74634 L .707 .577 .707 r
F
.70415 .69486 m .69532 .73084 L p .69894 .73535 L F P
0 g
s
.69532 .73084 m .69151 .74634 L p .69894 .73535 L .707 .577 .707 r
F P
0 g
s
.69868 .7672 m .68997 .74529 L p .67608 .75416 L .707 .577 .707 r
F P
0 g
s
.69058 .75013 m .70415 .69486 L .68821 .69569 L p .707 .577 .707 r
F P
0 g
s
.7059 .7522 m .70405 .7417 L p .69994 .73659 L .707 .577 .707 r
F P
0 g
s
.69945 .73597 m .70009 .73758 L p .69994 .73659 L .707 .577 .707 r
F P
0 g
s
.70009 .73758 m .7059 .7522 L p .69994 .73659 L .707 .577 .707 r
F P
0 g
s
.68166 .7506 m .69058 .75013 L p .69038 .74557 L .707 .577 .707 r
F P
0 g
s
.69038 .74557 m .69036 .74504 L .68997 .74529 L .707 .577 .707 r
F
.69038 .74557 m .68997 .74529 L .68166 .7506 L F
.68555 .73416 m .68997 .74529 L p .69173 .74606 L F P
0 g
s
.7059 .7522 m .69465 .74224 L .69173 .74606 L .707 .577 .707 r
F
.69465 .74224 m .68555 .73416 L .69173 .74606 L F
.69979 .73553 m .69933 .73236 L p .69874 .73689 L F P
0 g
s
.69277 .71916 m .68555 .73416 L p .69914 .74621 L .707 .577 .707 r
F P
0 g
s
.7059 .7522 m .70009 .73758 L p .69914 .74621 L .707 .577 .707 r
F P
0 g
s
.70009 .73758 m .69277 .71916 L p .69914 .74621 L .707 .577 .707 r
F P
0 g
s
.70053 .72301 m .71108 .69125 L .70415 .69486 L p .707 .577 .707 r
F P
0 g
s
.7083 .68521 m .71108 .69125 L p .70225 .71784 L .707 .577 .707 r
F P
0 g
s
.69994 .73659 m .69979 .73553 L p .6975 .74652 L .707 .577 .707 r
F P
0 g
s
.6975 .74652 m .69979 .73553 L .69874 .73689 L .707 .577 .707 r
F
.69277 .71916 m .69945 .73597 L p .69992 .73641 L F P
0 g
s
.69875 .72837 m .69961 .72578 L .69994 .73659 L .707 .577 .707 r
F
.71108 .69125 m .7035 .7221 L p .69961 .72578 L F P
0 g
s
.7035 .7221 m .69994 .73659 L p .69961 .72578 L .707 .577 .707 r
F P
0 g
s
.69917 .7313 m .69277 .71916 L .69992 .73641 L .707 .577 .707 r
F
.69875 .72837 m .70382 .70345 L .70225 .71784 L F
.69836 .72569 m .70382 .70345 L p .69875 .72837 L F P
0 g
s
.69062 .70693 m .69277 .71916 L p .70094 .73465 L .707 .577 .707 r
F P
0 g
s
.70375 .73996 m .6991 .72827 L p .70094 .73465 L .707 .577 .707 r
F P
0 g
s
.6991 .72827 m .69062 .70693 L p .70094 .73465 L .707 .577 .707 r
F P
0 g
s
.69062 .70693 m .69852 .72681 L p .6979 .7273 L .707 .577 .707 r
F P
0 g
s
.68922 .7203 m .69443 .7245 L .69473 .74049 L .707 .577 .707 r
F
.69176 .72235 m .69062 .70693 L .6979 .7273 L F
.69795 .72734 m .69473 .74049 L p .69443 .7245 L F P
0 g
s
.69296 .73206 m .69245 .73169 L p .69852 .72681 L .707 .577 .707 r
F P
0 g
s
.69836 .72569 m .69795 .72734 L p .69418 .71119 L .707 .577 .707 r
F P
0 g
s
.69418 .71119 m .69795 .72734 L .69443 .7245 L .707 .577 .707 r
F
.70375 .73996 m .69917 .7313 L .69992 .73641 L F
.69473 .74049 m .69836 .72569 L p .69875 .72837 L F P
0 g
s
.70447 .75517 m .7059 .7522 L p .68997 .74529 L .707 .577 .707 r
F P
0 g
s
.69058 .75013 m .6975 .74652 L p .69874 .73689 L .707 .577 .707 r
F P
0 g
s
.69151 .74634 m .69058 .75013 L p .69874 .73689 L .707 .577 .707 r
F P
0 g
s
.6975 .74652 m .69473 .74049 L p .69875 .72837 L .707 .577 .707 r
F P
0 g
s
.70405 .7417 m .70375 .73996 L p .69945 .73597 L .707 .577 .707 r
F P
0 g
s
.69994 .73659 m .6975 .74652 L p .69875 .72837 L .707 .577 .707 r
F P
0 g
s
.70375 .73996 m .69296 .73206 L p .69795 .72734 L .707 .577 .707 r
F P
0 g
s
.69852 .72681 m .6991 .72827 L p .69795 .72734 L .707 .577 .707 r
F P
0 g
s
.6991 .72827 m .70375 .73996 L p .69795 .72734 L .707 .577 .707 r
F P
0 g
s
.69245 .73169 m .69176 .72235 L .6979 .7273 L .707 .577 .707 r
F
.68555 .73416 m .66967 .75045 L p .67608 .75416 L F P
0 g
s
.68997 .74529 m .68555 .73416 L p .67608 .75416 L .707 .577 .707 r
F P
0 g
s
.69473 .74049 m .68252 .73261 L p .68922 .7203 L .707 .577 .707 r
F P
0 g
s
.67932 .69865 m .69062 .70693 L p .69176 .72235 L .707 .577 .707 r
F P
0 g
s
.68252 .73261 m .68576 .71945 L p .68922 .7203 L .707 .577 .707 r
F P
0 g
s
.67932 .69865 m .68731 .71876 L p .68576 .71945 L .707 .577 .707 r
F P
0 g
s
.68252 .73261 m .66209 .72367 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.68576 .71945 m .68252 .73261 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.67381 .72481 m .6757 .7158 L .68576 .71945 L .707 .577 .707 r
F
.6757 .7158 m .67932 .69865 L .68576 .71945 L F
.68731 .71876 m .67932 .69865 L p .69176 .72235 L F P
0 g
s
.65996 .69514 m .67932 .69865 L p .6757 .7158 L .707 .577 .707 r
F P
0 g
s
.66209 .72367 m .66454 .71368 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.65996 .69514 m .66691 .71261 L p .66454 .71368 L .707 .577 .707 r
F P
0 g
s
.66209 .72367 m .63542 .71454 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.66454 .71368 m .66209 .72367 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.65117 .71976 m .65405 .7117 L .66454 .71368 L .707 .577 .707 r
F
.65405 .7117 m .65996 .69514 L .66454 .71368 L F
.66691 .71261 m .65996 .69514 L p .6757 .7158 L F P
0 g
s
.63446 .69674 m .65996 .69514 L p .65405 .7117 L .707 .577 .707 r
F P
0 g
s
.63542 .71454 m .63638 .71065 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.63446 .69674 m .63929 .70891 L p .63638 .71065 L .707 .577 .707 r
F P
0 g
s
.63638 .71065 m .63542 .71454 L .61371 .7085 L p .707 .577 .707 r
F P
0 g
s
.6264 .71662 m .6291 .70996 L .63638 .71065 L .707 .577 .707 r
F
.6291 .70996 m .63446 .69674 L .63638 .71065 L F
.63929 .70891 m .63446 .69674 L p .65405 .7117 L F P
0 g
s
.60529 .7033 m .63446 .69674 L p .6228 .72553 L .707 .577 .707 r
F P
0 g
s
.61842 .73634 m .60848 .71134 L p .6228 .72553 L .707 .577 .707 r
F P
0 g
s
.60848 .71134 m .60529 .7033 L p .6228 .72553 L .707 .577 .707 r
F P
0 g
s
.61842 .73634 m .58845 .74721 L p .60135 .71356 L .707 .577 .707 r
F P
0 g
s
.60529 .7033 m .6071 .70787 L p .60135 .71356 L .707 .577 .707 r
F P
0 g
s
.6071 .70787 m .61842 .73634 L p .60135 .71356 L .707 .577 .707 r
F P
0 g
s
.649 .65926 m .64669 .66866 L p .60513 .70611 L .707 .577 .707 r
F P
0 g
s
.64669 .66866 m .63638 .71065 L p .6084 .70658 L .707 .577 .707 r
F P
0 g
s
.60513 .70611 m .64669 .66866 L .6084 .70658 L .707 .577 .707 r
F
.58845 .74721 m .57532 .71417 L .60529 .7033 L p F P
0 g
s
.61871 .65084 m .60513 .70611 L .60265 .70555 L p .707 .577 .707 r
F P
0 g
s
.60265 .70555 m .57419 .69921 L p .58471 .68777 L .707 .577 .707 r
F P
0 g
s
.58471 .68777 m .61871 .65084 L .60265 .70555 L .707 .577 .707 r
F
.61371 .7085 m .60513 .70611 L p .63638 .71065 L F P
0 g
s
.63638 .71065 m .63692 .70846 L p .63929 .70891 L .707 .577 .707 r
F P
0 g
s
.63638 .71065 m .63929 .70891 L .64018 .70908 L .707 .577 .707 r
F
.64759 .72978 m .61842 .73634 L p .6264 .71662 L F P
0 g
s
.63929 .70891 m .64759 .72978 L p .6264 .71662 L .707 .577 .707 r
F P
0 g
s
.64759 .72978 m .63929 .70891 L p .65405 .7117 L .707 .577 .707 r
F P
0 g
s
.649 .65926 m .67566 .6684 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.63692 .70846 m .649 .65926 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.67566 .6684 m .66454 .71368 L p .64018 .70908 L .707 .577 .707 r
F P
0 g
s
.66454 .71368 m .66498 .7119 L p .66691 .71261 L .707 .577 .707 r
F P
0 g
s
.66454 .71368 m .66691 .71261 L .66952 .71355 L .707 .577 .707 r
F
.67309 .72818 m .64759 .72978 L p .65117 .71976 L F P
0 g
s
.66691 .71261 m .67309 .72818 L p .65117 .71976 L .707 .577 .707 r
F P
0 g
s
.67309 .72818 m .66691 .71261 L p .6757 .7158 L .707 .577 .707 r
F P
0 g
s
.67566 .6684 m .6961 .67734 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.66498 .7119 m .67566 .6684 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.6961 .67734 m .68576 .71945 L p .66952 .71355 L .707 .577 .707 r
F P
0 g
s
.68576 .71945 m .68616 .71783 L p .68731 .71876 L .707 .577 .707 r
F P
0 g
s
.68576 .71945 m .68731 .71876 L .68922 .7203 L .707 .577 .707 r
F
.69245 .73169 m .67309 .72818 L p .67381 .72481 L F P
0 g
s
.68731 .71876 m .69245 .73169 L p .67381 .72481 L .707 .577 .707 r
F P
0 g
s
.69245 .73169 m .68731 .71876 L p .69176 .72235 L .707 .577 .707 r
F P
0 g
s
.6961 .67734 m .7083 .68521 L p .68922 .7203 L .707 .577 .707 r
F P
0 g
s
.68616 .71783 m .6961 .67734 L p .68922 .7203 L .707 .577 .707 r
F P
0 g
s
.68922 .7203 m .69418 .71119 L .69443 .7245 L .707 .577 .707 r
F
.7083 .68521 m .69836 .72569 L p .69418 .71119 L F P
0 g
s
.70382 .70345 m .7083 .68521 L p .70225 .71784 L .707 .577 .707 r
F P
0 g
s
.51432 .71083 m .5279 .65556 L .5157 .64768 L p .707 .577 .707 r
F P
0 g
s
.53681 .81008 m .5334 .82865 L .56045 .83659 L p .707 .577 .707 r
F P
0 g
s
.5342 .7996 m .54733 .83264 L .57284 .83104 L p .707 .577 .707 r
F P
0 g
s
.65477 .83242 m .65136 .85099 L .675 .85108 L p .707 .577 .707 r
F P
0 g
s
.675 .85108 m .67841 .83251 L .65477 .83242 L p .707 .577 .707 r
F P
0 g
s
.5157 .64768 m .50212 .70295 L .51432 .71083 L p .707 .577 .707 r
F P
0 g
s
.5334 .82865 m .53681 .81008 L .51605 .80176 L p .707 .577 .707 r
F P
0 g
s
.54733 .83264 m .5342 .7996 L .51485 .79609 L p .707 .577 .707 r
F P
0 g
s
.51605 .80176 m .51264 .82033 L .5334 .82865 L p .707 .577 .707 r
F P
0 g
s
.51485 .79609 m .52798 .82913 L .54733 .83264 L p .707 .577 .707 r
F P
0 g
s
.50212 .70295 m .5157 .64768 L .51292 .64164 L p .707 .577 .707 r
F P
0 g
s
.67841 .83251 m .675 .85108 L .69107 .84859 L p .707 .577 .707 r
F P
0 g
s
.69107 .84859 m .69448 .83002 L .67841 .83251 L p .707 .577 .707 r
F P
0 g
s
.51264 .82033 m .51605 .80176 L .50361 .79387 L p .707 .577 .707 r
F P
0 g
s
.52798 .82913 m .51485 .79609 L .50354 .78781 L p .707 .577 .707 r
F P
0 g
s
.51292 .64164 m .49935 .69692 L .50212 .70295 L p .707 .577 .707 r
F P
0 g
s
.50361 .79387 m .5002 .81244 L .51264 .82033 L p .707 .577 .707 r
F P
0 g
s
.50354 .78781 m .51667 .82085 L .52798 .82913 L p .707 .577 .707 r
F P
0 g
s
.49338 .82188 m .49338 .31999 L .44918 .31755 L p .707 .577 .707 r
F P
0 g
s
.49935 .69692 m .51292 .64164 L .51984 .63803 L p .707 .577 .707 r
F P
0 g
s
.5002 .81244 m .50361 .79387 L .50071 .78719 L p .707 .577 .707 r
F P
0 g
s
.51667 .82085 m .50354 .78781 L .50183 .77804 L p .707 .577 .707 r
F P
0 g
s
.50183 .77804 m .5014 .77558 L p .50254 .77896 L .707 .577 .707 r
F P
0 g
s
.51667 .82085 m .50183 .77804 L .50254 .77896 L .707 .577 .707 r
F
.50071 .78719 m .49731 .80576 L .5002 .81244 L p F P
0 g
s
.51453 .80862 m .51667 .82085 L p .50254 .77896 L .707 .577 .707 r
F P
0 g
s
.5014 .77558 m .50296 .77951 L p .50254 .77896 L .707 .577 .707 r
F P
0 g
s
.50296 .77951 m .51453 .80862 L p .50254 .77896 L .707 .577 .707 r
F P
0 g
s
.51453 .80862 m .5014 .77558 L .50862 .76058 L p .707 .577 .707 r
F P
0 g
s
.50423 .80094 m .49731 .80576 L p .50673 .78442 L .707 .577 .707 r
F P
0 g
s
.50764 .78237 m .50716 .78498 L p .50673 .78442 L .707 .577 .707 r
F P
0 g
s
.50716 .78498 m .50423 .80094 L p .50673 .78442 L .707 .577 .707 r
F P
0 g
s
.49731 .80576 m .50071 .78719 L .50602 .7835 L p .707 .577 .707 r
F P
0 g
s
.50602 .7835 m .50764 .78237 L p .50673 .78442 L .707 .577 .707 r
F P
0 g
s
.49731 .80576 m .50602 .7835 L .50673 .78442 L .707 .577 .707 r
F
.51984 .63803 m .50627 .69331 L .49935 .69692 L p F P
0 g
s
.50627 .69331 m .51984 .63803 L .53579 .6372 L p .707 .577 .707 r
F P
0 g
s
.53579 .6372 m .52221 .69248 L .50627 .69331 L p .707 .577 .707 r
F P
0 g
s
.50862 .76058 m .52175 .79362 L .51453 .80862 L p .707 .577 .707 r
F P
0 g
s
.52221 .69248 m .53579 .6372 L .55919 .63924 L p .707 .577 .707 r
F P
0 g
s
.52175 .79362 m .50862 .76058 L .5245 .74429 L p .707 .577 .707 r
F P
0 g
s
.5245 .74429 m .53763 .77733 L .52175 .79362 L p .707 .577 .707 r
F P
0 g
s
.50423 .80094 m .50764 .78237 L .52371 .77988 L p .707 .577 .707 r
F P
0 g
s
.55919 .63924 m .54562 .69451 L .52221 .69248 L p .707 .577 .707 r
F P
0 g
s
.52371 .77988 m .5203 .79845 L .50423 .80094 L p .707 .577 .707 r
F P
0 g
s
.53763 .77733 m .5245 .74429 L .54748 .7283 L p .707 .577 .707 r
F P
0 g
s
.5203 .79845 m .52371 .77988 L .54735 .77997 L p .707 .577 .707 r
F P
0 g
s
.54735 .77997 m .54394 .79854 L .5203 .79845 L p .707 .577 .707 r
F P
0 g
s
.49338 .31999 m .49338 .82188 L .53823 .82054 L p .707 .577 .707 r
F P
0 g
s
.54748 .7283 m .56061 .76134 L .53763 .77733 L p .707 .577 .707 r
F P
0 g
s
.53823 .82054 m .53823 .31865 L .49338 .31999 L p .707 .577 .707 r
F P
0 g
s
.69448 .83002 m .69107 .84859 L .698 .84377 L p .707 .577 .707 r
F P
0 g
s
.698 .84377 m .70141 .8252 L .69448 .83002 L p .707 .577 .707 r
F P
0 g
s
.54562 .69451 m .55919 .63924 L .58776 .64393 L p .707 .577 .707 r
F P
0 g
s
.58776 .64393 m .57419 .69921 L .54562 .69451 L p .707 .577 .707 r
F P
0 g
s
.56061 .76134 m .54748 .7283 L .57532 .71417 L p .707 .577 .707 r
F P
0 g
s
.57532 .71417 m .58845 .74721 L .56061 .76134 L p .707 .577 .707 r
F P
0 g
s
.54394 .79854 m .54735 .77997 L .57625 .78263 L p .707 .577 .707 r
F P
0 g
s
.57625 .78263 m .57284 .8012 L .54394 .79854 L p .707 .577 .707 r
F P
0 g
s
.57284 .8012 m .57625 .78263 L .60758 .78759 L p .707 .577 .707 r
F P
0 g
s
.60758 .78759 m .60417 .80616 L .57284 .8012 L p .707 .577 .707 r
F P
0 g
s
.53823 .31865 m .53823 .82054 L .57934 .81554 L p .707 .577 .707 r
F P
0 g
s
.57419 .69921 m .58776 .64393 L .61871 .65084 L p .707 .577 .707 r
F P
0 g
s
.57934 .81554 m .57934 .31365 L .53823 .31865 L p .707 .577 .707 r
F P
0 g
s
.44918 .81944 m .44918 .31755 L .40995 .31157 L p .707 .577 .707 r
F P
0 g
s
.44918 .31755 m .44918 .81944 L .49338 .82188 L p .707 .577 .707 r
F P
0 g
s
.60513 .70611 m .61871 .65084 L .649 .65926 L p .707 .577 .707 r
F P
0 g
s
.63827 .79438 m .63486 .81295 L .60417 .80616 L p .707 .577 .707 r
F P
0 g
s
.60417 .80616 m .60758 .78759 L .63827 .79438 L p .707 .577 .707 r
F P
0 g
s
.57934 .31365 m .57934 .81554 L .61268 .80738 L p .707 .577 .707 r
F P
0 g
s
.61268 .80738 m .61268 .30549 L .57934 .31365 L p .707 .577 .707 r
F P
0 g
s
.40995 .81345 m .40995 .31157 L .37953 .30262 L p .707 .577 .707 r
F P
0 g
s
.40995 .31157 m .40995 .81345 L .44918 .81944 L p .707 .577 .707 r
F P
0 g
s
.25791 .68215 m .22684 .67603 L p .24569 .7182 L .707 .577 .707 r
F P
0 g
s
.2476 .72249 m .24833 .71964 L .24569 .7182 L .707 .577 .707 r
F
.24833 .71964 m .25791 .68215 L .24569 .7182 L F
.25312 .72271 m .25791 .68215 L p .2476 .72249 L F P
0 g
s
.27187 .72906 m .27332 .72162 L .25402 .72274 L .707 .577 .707 r
F
.28803 .73479 m .27775 .72559 L .27187 .72906 L F
.27775 .72559 m .27332 .72162 L .27187 .72906 L F
.27862 .73615 m .28803 .73479 L p .25402 .72274 L F P
0 g
s
.28955 .68347 m .28514 .72085 L p .30308 .7106 L .707 .577 .707 r
F P
0 g
s
.28514 .72085 m .28509 .72124 L p .28588 .72077 L .707 .577 .707 r
F P
0 g
s
.30308 .7106 m .28514 .72085 L .28588 .72077 L .707 .577 .707 r
F
.2928 .73422 m .31706 .73136 L p .30806 .72245 L F P
0 g
s
.31868 .67986 m .31426 .71731 L p .32969 .70575 L .707 .577 .707 r
F P
0 g
s
.31426 .71731 m .31421 .7177 L p .31489 .71718 L .707 .577 .707 r
F P
0 g
s
.32969 .70575 m .31426 .71731 L .31489 .71718 L .707 .577 .707 r
F
.31706 .73136 m .34081 .72939 L p .32844 .71435 L F P
0 g
s
.31489 .71718 m .31706 .73136 L p .32844 .71435 L .707 .577 .707 r
F P
0 g
s
.30806 .72245 m .30851 .71832 L .30434 .71877 L .707 .577 .707 r
F
.31706 .73136 m .31495 .71762 L p .30806 .72245 L F P
0 g
s
.31495 .71762 m .31489 .71718 L p .31421 .7177 L .707 .577 .707 r
F P
0 g
s
.31495 .71762 m .31421 .7177 L .30806 .72245 L .707 .577 .707 r
F
.31868 .67986 m .28955 .68347 L p .30701 .71848 L F P
0 g
s
.31421 .7177 m .31868 .67986 L p .30701 .71848 L .707 .577 .707 r
F P
0 g
s
.31489 .71718 m .31125 .69345 L p .30806 .72245 L .707 .577 .707 r
F P
0 g
s
.31276 .73001 m .31421 .7177 L p .30701 .71848 L .707 .577 .707 r
F P
0 g
s
.28803 .73479 m .2928 .73422 L p .30434 .71877 L .707 .577 .707 r
F P
0 g
s
.30806 .72245 m .30434 .71877 L .2928 .73422 L .707 .577 .707 r
F
.28588 .72077 m .28803 .73479 L p .30434 .71877 L F P
0 g
s
.25791 .68215 m .25317 .72228 L p .25395 .72225 L .707 .577 .707 r
F P
0 g
s
.27757 .72149 m .27279 .71193 L .25395 .72225 L .707 .577 .707 r
F
.27279 .71193 m .25791 .68215 L .25395 .72225 L F
.25656 .73935 m .25402 .72274 L p .25312 .72271 L F P
0 g
s
.2437 .72787 m .25312 .72271 L .23719 .72207 L .707 .577 .707 r
F
.25656 .73935 m .25312 .72271 L .2437 .72787 L F
.25402 .72274 m .25395 .72225 L p .25312 .72271 L F P
0 g
s
.28955 .68347 m .25791 .68215 L p .27757 .72149 L .707 .577 .707 r
F P
0 g
s
.28223 .69688 m .25076 .70144 L p .27332 .72162 L .707 .577 .707 r
F P
0 g
s
.27775 .72559 m .27839 .72146 L .27332 .72162 L .707 .577 .707 r
F
.28509 .72124 m .28955 .68347 L p .27757 .72149 L F P
0 g
s
.27839 .72146 m .28223 .69688 L .27332 .72162 L .707 .577 .707 r
F
.28803 .73479 m .28588 .72077 L p .27775 .72559 L F P
0 g
s
.28588 .72077 m .28223 .69688 L p .27775 .72559 L .707 .577 .707 r
F P
0 g
s
.28363 .73362 m .28509 .72124 L p .27757 .72149 L .707 .577 .707 r
F P
0 g
s
.25395 .72225 m .25402 .72274 L p .27332 .72162 L .707 .577 .707 r
F P
0 g
s
.25402 .72274 m .25656 .73935 L .27862 .73615 L p .707 .577 .707 r
F P
0 g
s
.27757 .72149 m .25395 .72225 L .25199 .7323 L .707 .577 .707 r
F
.25317 .72228 m .25312 .72271 L p .25395 .72225 L F P
0 g
s
.25312 .72271 m .25199 .7323 L p .25395 .72225 L .707 .577 .707 r
F P
0 g
s
.22574 .74459 m .25656 .73935 L p .23719 .72207 L .707 .577 .707 r
F P
0 g
s
.2222 .72147 m .22574 .74459 L p .23719 .72207 L .707 .577 .707 r
F P
0 g
s
.22684 .67603 m .1994 .6657 L p .21934 .72171 L .707 .577 .707 r
F P
0 g
s
.22574 .74459 m .22229 .72209 L p .21024 .72931 L .707 .577 .707 r
F P
0 g
s
.22229 .72209 m .2222 .72147 L p .22142 .72198 L .707 .577 .707 r
F P
0 g
s
.22229 .72209 m .22142 .72198 L .21024 .72931 L .707 .577 .707 r
F
.1994 .6657 m .19348 .71585 L .20378 .71972 L p F P
0 g
s
.21024 .72931 m .2138 .721 L .20003 .71924 L .707 .577 .707 r
F
.21934 .72171 m .1994 .6657 L .20378 .71972 L F
.22142 .72198 m .22684 .67603 L p .21934 .72171 L F P
0 g
s
.22684 .67603 m .22149 .72144 L p .2222 .72147 L .707 .577 .707 r
F P
0 g
s
.22149 .72144 m .22093 .72618 L p .2476 .72249 L .707 .577 .707 r
F P
0 g
s
.2222 .72147 m .21993 .70668 L p .21024 .72931 L .707 .577 .707 r
F P
0 g
s
.20378 .71972 m .22093 .72618 L p .21934 .72171 L .707 .577 .707 r
F P
0 g
s
.22093 .72618 m .22142 .72198 L p .21934 .72171 L .707 .577 .707 r
F P
0 g
s
.19348 .71585 m .1994 .6657 L .17827 .65218 L p .707 .577 .707 r
F P
0 g
s
.21993 .70668 m .19277 .71209 L p .20003 .71924 L .707 .577 .707 r
F P
0 g
s
.2138 .721 m .21993 .70668 L .20003 .71924 L .707 .577 .707 r
F
.2476 .72249 m .24149 .7088 L .2222 .72147 L F
.24149 .7088 m .22684 .67603 L .2222 .72147 L F
.22093 .72618 m .25199 .7323 L p .2476 .72249 L F P
0 g
s
.21993 .70668 m .2222 .72147 L p .23719 .72207 L .707 .577 .707 r
F P
0 g
s
.25312 .72271 m .25076 .70144 L .23719 .72207 L .707 .577 .707 r
F
.25395 .72225 m .25076 .70144 L p .25312 .72271 L F P
0 g
s
.28363 .73362 m .31276 .73001 L p .30701 .71848 L .707 .577 .707 r
F P
0 g
s
.30701 .71848 m .30308 .7106 L .29535 .71975 L .707 .577 .707 r
F
.30701 .71848 m .29535 .71975 L .28363 .73362 L F
.28509 .72124 m .28363 .73362 L p .30308 .7106 L F P
0 g
s
.31125 .69345 m .28223 .69688 L p .30434 .71877 L .707 .577 .707 r
F P
0 g
s
.30851 .71832 m .31125 .69345 L .30434 .71877 L .707 .577 .707 r
F
.33294 .71341 m .32969 .70575 L .32288 .71551 L F
.31421 .7177 m .31276 .73001 L p .32969 .70575 L F P
0 g
s
.34081 .72939 m .33819 .71231 L p .33763 .71243 L .707 .577 .707 r
F P
0 g
s
.33231 .71905 m .33763 .71243 L .32844 .71435 L .707 .577 .707 r
F
.34081 .72939 m .33763 .71243 L .33231 .71905 L F
.34081 .72939 m .35695 .72908 L p .34524 .70902 L F P
0 g
s
.35169 .70649 m .34938 .69779 L .34287 .70995 L .707 .577 .707 r
F
.34244 .67166 m .33768 .71199 L p .34938 .69779 L F P
0 g
s
.33768 .71199 m .33763 .71243 L p .33812 .71182 L .707 .577 .707 r
F P
0 g
s
.34938 .69779 m .33768 .71199 L .33812 .71182 L .707 .577 .707 r
F
.33812 .71182 m .34081 .72939 L p .34524 .70902 L F P
0 g
s
.34244 .67166 m .31868 .67986 L p .33294 .71341 L .707 .577 .707 r
F P
0 g
s
.33652 .72181 m .33763 .71243 L p .33294 .71341 L .707 .577 .707 r
F P
0 g
s
.33763 .71243 m .34244 .67166 L p .33294 .71341 L .707 .577 .707 r
F P
0 g
s
.33819 .71231 m .335 .69148 L p .32844 .71435 L .707 .577 .707 r
F P
0 g
s
.33763 .71243 m .33652 .72181 L p .34938 .69779 L .707 .577 .707 r
F P
0 g
s
.35695 .72908 m .35339 .70582 L p .35304 .70595 L .707 .577 .707 r
F P
0 g
s
.34962 .71653 m .35304 .70595 L .34524 .70902 L .707 .577 .707 r
F
.35695 .72908 m .35304 .70595 L .34962 .71653 L F
.35695 .72908 m .3639 .73046 L p .35506 .70324 L F P
0 g
s
.35939 .69527 m .35918 .687 L .35423 .70416 L .707 .577 .707 r
F
.35631 .70187 m .35939 .69527 L p .35423 .70416 L F P
0 g
s
.3585 .6597 m .35311 .70539 L p .35918 .687 L .707 .577 .707 r
F P
0 g
s
.35311 .70539 m .35304 .70595 L p .35329 .70519 L .707 .577 .707 r
F P
0 g
s
.35918 .687 m .35311 .70539 L .35329 .70519 L .707 .577 .707 r
F
.35329 .70519 m .35695 .72908 L p .35506 .70324 L F P
0 g
s
.3585 .6597 m .34244 .67166 L p .35169 .70649 L .707 .577 .707 r
F P
0 g
s
.35259 .70984 m .35304 .70595 L p .35169 .70649 L .707 .577 .707 r
F P
0 g
s
.35304 .70595 m .3585 .6597 L p .35169 .70649 L .707 .577 .707 r
F P
0 g
s
.35339 .70582 m .35114 .69117 L p .34524 .70902 L .707 .577 .707 r
F P
0 g
s
.35304 .70595 m .35259 .70984 L p .35918 .687 L .707 .577 .707 r
F P
0 g
s
.3581 .69255 m .35114 .69117 L p .35506 .70324 L .707 .577 .707 r
F P
0 g
s
.3639 .73046 m .35906 .69883 L p .35506 .70324 L .707 .577 .707 r
F P
0 g
s
.35906 .69883 m .3581 .69255 L p .35506 .70324 L .707 .577 .707 r
F P
0 g
s
.35114 .69117 m .35329 .70519 L p .35506 .70324 L .707 .577 .707 r
F P
0 g
s
.35259 .70984 m .35631 .70187 L p .35423 .70416 L .707 .577 .707 r
F P
0 g
s
.35114 .69117 m .335 .69148 L p .34524 .70902 L .707 .577 .707 r
F P
0 g
s
.335 .69148 m .33812 .71182 L p .34524 .70902 L .707 .577 .707 r
F P
0 g
s
.33652 .72181 m .35259 .70984 L p .35169 .70649 L .707 .577 .707 r
F P
0 g
s
.35169 .70649 m .34287 .70995 L .33652 .72181 L .707 .577 .707 r
F
.335 .69148 m .31125 .69345 L p .32844 .71435 L F P
0 g
s
.31276 .73001 m .33652 .72181 L p .33294 .71341 L .707 .577 .707 r
F P
0 g
s
.33294 .71341 m .32288 .71551 L .31276 .73001 L .707 .577 .707 r
F
.31125 .69345 m .31489 .71718 L p .32844 .71435 L F P
0 g
s
.28223 .69688 m .28588 .72077 L p .30434 .71877 L .707 .577 .707 r
F P
0 g
s
.25199 .7323 m .28363 .73362 L p .27757 .72149 L .707 .577 .707 r
F P
0 g
s
.25076 .70144 m .25395 .72225 L p .27332 .72162 L .707 .577 .707 r
F P
0 g
s
.25076 .70144 m .21993 .70668 L p .23719 .72207 L .707 .577 .707 r
F P
0 g
s
.25199 .7323 m .25312 .72271 L p .2476 .72249 L .707 .577 .707 r
F P
0 g
s
.70141 .8252 m .698 .84377 L .6951 .83709 L p .707 .577 .707 r
F P
0 g
s
.6951 .83709 m .69851 .81852 L .70141 .8252 L p .707 .577 .707 r
F P
0 g
s
.02 w
.6029 .81507 Mdot
.5 Mabswid
.61268 .30549 m .61268 .80738 L .63499 .79686 L p .707 .577 .707 r
F P
0 g
s
.63499 .79686 m .63499 .29497 L .61268 .30549 L p .707 .577 .707 r
F P
0 g
s
.17827 .65218 m .17394 .6889 L p .19348 .71585 L .707 .577 .707 r
F P
0 g
s
.17394 .6889 m .17235 .70233 L .19014 .71371 L p .707 .577 .707 r
F P
0 g
s
.19014 .71371 m .19348 .71585 L p .17394 .6889 L .707 .577 .707 r
F P
0 g
s
.19277 .71209 m .19389 .71945 L p .22574 .74459 L .707 .577 .707 r
F P
0 g
s
.19389 .71945 m .19857 .75 L .21209 .74731 L p .707 .577 .707 r
F P
0 g
s
.21209 .74731 m .22574 .74459 L p .19389 .71945 L .707 .577 .707 r
F P
0 g
s
.37953 .80451 m .37953 .30262 L .36091 .29159 L p .707 .577 .707 r
F P
0 g
s
.37953 .30262 m .37953 .80451 L .40995 .81345 L p .707 .577 .707 r
F P
0 g
s
.69851 .81852 m .6951 .83709 L .68266 .82921 L p .707 .577 .707 r
F P
0 g
s
.68266 .82921 m .68607 .81064 L .69851 .81852 L p .707 .577 .707 r
F P
0 g
s
.17235 .70233 m .17827 .65218 L .16551 .63679 L p .707 .577 .707 r
F P
0 g
s
.17192 .71714 m .17772 .75505 L .19857 .75 L p .707 .577 .707 r
F P
0 g
s
.19857 .75 m .19277 .71209 L .17192 .71714 L p .707 .577 .707 r
F P
0 g
s
.25156 .82978 m .25303 .81251 L .22191 .80736 L p .707 .577 .707 r
F P
0 g
s
.25303 .81251 m .25156 .82978 L .28328 .83063 L p .707 .577 .707 r
F P
0 g
s
.28328 .83063 m .28475 .81336 L .25303 .81251 L p .707 .577 .707 r
F P
0 g
s
.28475 .81336 m .28328 .83063 L .31249 .82711 L p .707 .577 .707 r
F P
0 g
s
.31249 .82711 m .31397 .80983 L .28475 .81336 L p .707 .577 .707 r
F P
0 g
s
.22043 .82464 m .22191 .80736 L .19442 .79843 L p .707 .577 .707 r
F P
0 g
s
.22191 .80736 m .22043 .82464 L .25156 .82978 L p .707 .577 .707 r
F P
0 g
s
.63499 .29497 m .63499 .79686 L .64409 .78499 L p .707 .577 .707 r
F P
0 g
s
.64409 .78499 m .64409 .28311 L .63499 .29497 L p .707 .577 .707 r
F P
0 g
s
.19442 .79843 m .19295 .81571 L .22043 .82464 L p .707 .577 .707 r
F P
0 g
s
.68607 .81064 m .68266 .82921 L .66191 .82089 L p .707 .577 .707 r
F P
0 g
s
.66191 .82089 m .66531 .80232 L .68607 .81064 L p .707 .577 .707 r
F P
0 g
s
.35939 .69527 m .3653 .64512 L .3585 .6597 L p .707 .577 .707 r
F P
0 g
s
.15959 .68694 m .16551 .63679 L .16238 .62104 L p .707 .577 .707 r
F P
0 g
s
.16551 .63679 m .15959 .68694 L .17235 .70233 L p .707 .577 .707 r
F P
0 g
s
.31397 .80983 m .31249 .82711 L .33633 .81956 L p .707 .577 .707 r
F P
0 g
s
.33633 .81956 m .33781 .80228 L .31397 .80983 L p .707 .577 .707 r
F P
0 g
s
.19295 .81571 m .19442 .79843 L .17327 .78659 L p .707 .577 .707 r
F P
0 g
s
.15943 .72133 m .16523 .75924 L .17772 .75505 L p .707 .577 .707 r
F P
0 g
s
.17772 .75505 m .17192 .71714 L .15943 .72133 L p .707 .577 .707 r
F P
0 g
s
.3653 .64512 m .35939 .69527 L .35625 .67952 L p .707 .577 .707 r
F P
0 g
s
.35625 .67952 m .36217 .62937 L .3653 .64512 L p .707 .577 .707 r
F P
0 g
s
.35933 .79564 m .3608 .77836 L .35395 .79144 L p .707 .577 .707 r
F P
0 g
s
.36217 .62937 m .35625 .67952 L .3435 .66413 L p .707 .577 .707 r
F P
0 g
s
.3435 .66413 m .34941 .61398 L .36217 .62937 L p .707 .577 .707 r
F P
0 g
s
.3581 .69255 m .3639 .73046 L .361 .73339 L p .707 .577 .707 r
F P
0 g
s
.361 .73339 m .35519 .69548 L .3581 .69255 L p .707 .577 .707 r
F P
0 g
s
.3608 .77836 m .35933 .79564 L .35623 .78162 L p .707 .577 .707 r
F P
0 g
s
.35623 .78162 m .3577 .76434 L .3608 .77836 L p .707 .577 .707 r
F P
0 g
s
.35519 .69548 m .361 .73339 L .34851 .73758 L p .707 .577 .707 r
F P
0 g
s
.36091 .79348 m .36091 .29159 L .35591 .27955 L p .707 .577 .707 r
F P
0 g
s
.36091 .29159 m .36091 .79348 L .37953 .80451 L p .707 .577 .707 r
F P
0 g
s
.17327 .78659 m .17179 .80387 L .19295 .81571 L p .707 .577 .707 r
F P
0 g
s
.33781 .80228 m .33633 .81956 L .35247 .80871 L p .707 .577 .707 r
F P
0 g
s
.35247 .80871 m .35395 .79144 L .33781 .80228 L p .707 .577 .707 r
F P
0 g
s
.66531 .80232 m .66191 .82089 L .63486 .81295 L p .707 .577 .707 r
F P
0 g
s
.63486 .81295 m .63827 .79438 L .66531 .80232 L p .707 .577 .707 r
F P
0 g
s
.17179 .80387 m .17327 .78659 L .16052 .77299 L p .707 .577 .707 r
F P
0 g
s
.16238 .62104 m .15646 .67119 L .15959 .68694 L p .707 .577 .707 r
F P
0 g
s
.15646 .67119 m .16238 .62104 L .16918 .60646 L p .707 .577 .707 r
F P
0 g
s
.16052 .77299 m .15904 .79027 L .17179 .80387 L p .707 .577 .707 r
F P
0 g
s
.15652 .72426 m .16232 .76217 L .16523 .75924 L p .707 .577 .707 r
F P
0 g
s
.16523 .75924 m .15943 .72133 L .15652 .72426 L p .707 .577 .707 r
F P
0 g
s
.64409 .28311 m .64409 .78499 L .63909 .77296 L p .707 .577 .707 r
F P
0 g
s
.63909 .77296 m .63909 .27107 L .64409 .28311 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .65753 Mdot
.5 Mabswid
.35395 .79144 m .35247 .80871 L .35933 .79564 L p .707 .577 .707 r
F P
0 g
s
.15904 .79027 m .16052 .77299 L .15742 .75897 L p .707 .577 .707 r
F P
0 g
s
.3577 .76434 m .35623 .78162 L .34348 .76802 L p .707 .577 .707 r
F P
0 g
s
.34348 .76802 m .34495 .75075 L .3577 .76434 L p .707 .577 .707 r
F P
0 g
s
.35591 .27955 m .35591 .78144 L .36091 .79348 L p .707 .577 .707 r
F P
0 g
s
.35591 .78144 m .35591 .27955 L .365 .26769 L p .707 .577 .707 r
F P
0 g
s
.16326 .65661 m .16918 .60646 L .18525 .59449 L p .707 .577 .707 r
F P
0 g
s
.16918 .60646 m .16326 .65661 L .15646 .67119 L p .707 .577 .707 r
F P
0 g
s
.15742 .75897 m .15594 .77625 L .15904 .79027 L p .707 .577 .707 r
F P
0 g
s
.16348 .72564 m .16928 .76355 L .16232 .76217 L p .707 .577 .707 r
F P
0 g
s
.16232 .76217 m .15652 .72426 L .16348 .72564 L p .707 .577 .707 r
F P
0 g
s
.02 w
.25989 .77826 Mdot
.5 Mabswid
.15594 .77625 m .15742 .75897 L .16428 .7459 L p .707 .577 .707 r
F P
0 g
s
.34941 .61398 m .3435 .66413 L .32236 .65061 L p .707 .577 .707 r
F P
0 g
s
.32236 .65061 m .32828 .60046 L .34941 .61398 L p .707 .577 .707 r
F P
0 g
s
.18525 .59449 m .17933 .64464 L .16326 .65661 L p .707 .577 .707 r
F P
0 g
s
.17933 .64464 m .18525 .59449 L .209 .5863 L p .707 .577 .707 r
F P
0 g
s
.63909 .27107 m .63909 .77296 L .62046 .76193 L p .707 .577 .707 r
F P
0 g
s
.62046 .76193 m .62046 .26004 L .63909 .27107 L p .707 .577 .707 r
F P
0 g
s
.16428 .7459 m .1628 .76318 L .15594 .77625 L p .707 .577 .707 r
F P
0 g
s
.34851 .73758 m .3427 .69967 L .35519 .69548 L p .707 .577 .707 r
F P
0 g
s
.365 .76958 m .365 .26769 L .38732 .25717 L p .707 .577 .707 r
F P
0 g
s
.365 .26769 m .365 .76958 L .35591 .78144 L p .707 .577 .707 r
F P
0 g
s
.17962 .72533 m .18542 .76324 L .16928 .76355 L p .707 .577 .707 r
F P
0 g
s
.16928 .76355 m .16348 .72564 L .17962 .72533 L p .707 .577 .707 r
F P
0 g
s
.32828 .60046 m .32236 .65061 L .29492 .64028 L p .707 .577 .707 r
F P
0 g
s
.29492 .64028 m .30084 .59013 L .32828 .60046 L p .707 .577 .707 r
F P
0 g
s
.20309 .63645 m .209 .5863 L .23813 .58269 L p .707 .577 .707 r
F P
0 g
s
.209 .5863 m .20309 .63645 L .17933 .64464 L p .707 .577 .707 r
F P
0 g
s
.1628 .76318 m .16428 .7459 L .18041 .73506 L p .707 .577 .707 r
F P
0 g
s
.30084 .59013 m .29492 .64028 L .26386 .63416 L p .707 .577 .707 r
F P
0 g
s
.26386 .63416 m .26978 .58401 L .30084 .59013 L p .707 .577 .707 r
F P
0 g
s
.23221 .63284 m .23813 .58269 L .26978 .58401 L p .707 .577 .707 r
F P
0 g
s
.23813 .58269 m .23221 .63284 L .20309 .63645 L p .707 .577 .707 r
F P
0 g
s
.18041 .73506 m .17894 .75233 L .1628 .76318 L p .707 .577 .707 r
F P
0 g
s
.3427 .69967 m .34851 .73758 L .32766 .74263 L p .707 .577 .707 r
F P
0 g
s
.26978 .58401 m .26386 .63416 L .23221 .63284 L p .707 .577 .707 r
F P
0 g
s
.32766 .74263 m .32185 .70472 L .3427 .69967 L p .707 .577 .707 r
F P
0 g
s
.62046 .26004 m .62046 .76193 L .59005 .75298 L p .707 .577 .707 r
F P
0 g
s
.59005 .75298 m .59005 .25109 L .62046 .26004 L p .707 .577 .707 r
F P
0 g
s
.20336 .72336 m .20917 .76127 L .18542 .76324 L p .707 .577 .707 r
F P
0 g
s
.18542 .76324 m .17962 .72533 L .20336 .72336 L p .707 .577 .707 r
F P
0 g
s
.34495 .75075 m .34348 .76802 L .32232 .75618 L p .707 .577 .707 r
F P
0 g
s
.32766 .74263 m .30049 .74804 L p .31908 .71034 L .707 .577 .707 r
F P
0 g
s
.32185 .70472 m .32395 .71844 L p .31908 .71034 L .707 .577 .707 r
F P
0 g
s
.32395 .71844 m .32766 .74263 L p .31908 .71034 L .707 .577 .707 r
F P
0 g
s
.32232 .75618 m .3238 .7389 L .34257 .74941 L p .707 .577 .707 r
F P
0 g
s
.34257 .74941 m .34495 .75075 L p .34357 .75108 L .707 .577 .707 r
F P
0 g
s
.32232 .75618 m .34257 .74941 L .34357 .75108 L .707 .577 .707 r
F
.20917 .76127 m .20342 .72371 L p .23239 .71993 L F P
0 g
s
.20342 .72371 m .20336 .72336 L .20392 .7233 L p .707 .577 .707 r
F P
0 g
s
.20392 .7233 m .23239 .71993 L p .20342 .72371 L .707 .577 .707 r
F P
0 g
s
.17894 .75233 m .17972 .74321 L p .20426 .72751 L .707 .577 .707 r
F P
0 g
s
.17972 .74321 m .18041 .73506 L .19539 .73031 L p .707 .577 .707 r
F P
0 g
s
.19539 .73031 m .20426 .72751 L p .17972 .74321 L .707 .577 .707 r
F P
0 g
s
.38732 .25717 m .38732 .75906 L .365 .76958 L p .707 .577 .707 r
F P
0 g
s
.38732 .75906 m .38732 .25717 L .42066 .249 L p .707 .577 .707 r
F P
0 g
s
.20426 .72751 m .20278 .74478 L .17894 .75233 L p .707 .577 .707 r
F P
0 g
s
.73614 .63459 m .73022 .57724 L .69916 .58019 L p .707 .577 .707 r
F P
0 g
s
.73022 .57724 m .73614 .63459 L .76778 .63122 L p .707 .577 .707 r
F P
0 g
s
.76778 .63122 m .76187 .57386 L .73022 .57724 L p .707 .577 .707 r
F P
0 g
s
.30049 .74804 m .29468 .71013 L .32185 .70472 L p .707 .577 .707 r
F P
0 g
s
.69916 .58019 m .70508 .63755 L .73614 .63459 L p .707 .577 .707 r
F P
0 g
s
.76187 .57386 m .76778 .63122 L .79691 .62777 L p .707 .577 .707 r
F P
0 g
s
.79691 .62777 m .79099 .57041 L .76187 .57386 L p .707 .577 .707 r
F P
0 g
s
.23239 .71993 m .2382 .75784 L .20917 .76127 L p .707 .577 .707 r
F P
0 g
s
.70508 .63755 m .69916 .58019 L .67172 .58245 L p .707 .577 .707 r
F P
0 g
s
.30049 .74804 m .26966 .75328 L p .29235 .71416 L .707 .577 .707 r
F P
0 g
s
.29468 .71013 m .29576 .71714 L p .29235 .71416 L .707 .577 .707 r
F P
0 g
s
.29576 .71714 m .30049 .74804 L p .29235 .71416 L .707 .577 .707 r
F P
0 g
s
.32232 .75618 m .29484 .74725 L p .3214 .73959 L .707 .577 .707 r
F P
0 g
s
.3238 .7389 m .32358 .7415 L p .3214 .73959 L .707 .577 .707 r
F P
0 g
s
.32358 .7415 m .32232 .75618 L p .3214 .73959 L .707 .577 .707 r
F P
0 g
s
.29484 .74725 m .29632 .72997 L .3238 .7389 L p .707 .577 .707 r
F P
0 g
s
.67172 .58245 m .67764 .63981 L .70508 .63755 L p .707 .577 .707 r
F P
0 g
s
.2382 .75784 m .23242 .7201 L p .26386 .71537 L .707 .577 .707 r
F P
0 g
s
.23242 .7201 m .23239 .71993 L .23276 .71988 L p .707 .577 .707 r
F P
0 g
s
.23276 .71988 m .26386 .71537 L p .23242 .7201 L .707 .577 .707 r
F P
0 g
s
.20278 .74478 m .20328 .73898 L p .23347 .72398 L .707 .577 .707 r
F P
0 g
s
.20328 .73898 m .20426 .72751 L .22481 .72503 L p .707 .577 .707 r
F P
0 g
s
.22481 .72503 m .23347 .72398 L p .20328 .73898 L .707 .577 .707 r
F P
0 g
s
.59005 .25109 m .59005 .75298 L .55082 .747 L p .707 .577 .707 r
F P
0 g
s
.55082 .747 m .55082 .24511 L .59005 .25109 L p .707 .577 .707 r
F P
0 g
s
.79099 .57041 m .79691 .62777 L .82067 .62457 L p .707 .577 .707 r
F P
0 g
s
.82067 .62457 m .81475 .56721 L .79099 .57041 L p .707 .577 .707 r
F P
0 g
s
.26966 .75328 m .26386 .71537 L .29468 .71013 L p .707 .577 .707 r
F P
0 g
s
.26966 .75328 m .2382 .75784 L p .2631 .71663 L .707 .577 .707 r
F P
0 g
s
.26415 .71727 m .26966 .75328 L p .2631 .71663 L .707 .577 .707 r
F P
0 g
s
.29484 .74725 m .26371 .74211 L p .28946 .73253 L .707 .577 .707 r
F P
0 g
s
.29632 .72997 m .29577 .73633 L p .28946 .73253 L .707 .577 .707 r
F P
0 g
s
.29577 .73633 m .29484 .74725 L p .28946 .73253 L .707 .577 .707 r
F P
0 g
s
.26386 .71537 m .26415 .71727 L p .2631 .71663 L .707 .577 .707 r
F P
0 g
s
.23347 .72398 m .23199 .74126 L .20278 .74478 L p .707 .577 .707 r
F P
0 g
s
.42066 .75089 m .42066 .249 L .46177 .24401 L p .707 .577 .707 r
F P
0 g
s
.42066 .249 m .42066 .75089 L .38732 .75906 L p .707 .577 .707 r
F P
0 g
s
.26371 .74211 m .26519 .72483 L .29632 .72997 L p .707 .577 .707 r
F P
0 g
s
.67764 .63981 m .67172 .58245 L .65058 .58378 L p .707 .577 .707 r
F P
0 g
s
.23199 .74126 m .23347 .72398 L .26519 .72483 L p .707 .577 .707 r
F P
0 g
s
.65058 .58378 m .6565 .64114 L .67764 .63981 L p .707 .577 .707 r
F P
0 g
s
.73628 .74362 m .73481 .72453 L .71896 .72541 L p .707 .577 .707 r
F P
0 g
s
.71896 .72541 m .70368 .72626 L p .71054 .72991 L .707 .577 .707 r
F P
0 g
s
.73628 .74362 m .71896 .72541 L .71054 .72991 L .707 .577 .707 r
F
.73481 .72453 m .73628 .74362 L .76801 .74089 L p F P
0 g
s
.76801 .74089 m .76653 .7218 L .73481 .72453 L p .707 .577 .707 r
F P
0 g
s
.70368 .72626 m .70516 .74535 L .73628 .74362 L p .707 .577 .707 r
F P
0 g
s
.73033 .74575 m .7618 .74794 L p .7369 .71582 L .707 .577 .707 r
F P
0 g
s
.73614 .71483 m .73585 .71638 L p .7369 .71582 L .707 .577 .707 r
F P
0 g
s
.73585 .71638 m .73033 .74575 L p .7369 .71582 L .707 .577 .707 r
F P
0 g
s
.73033 .74575 m .73614 .71483 L .70531 .70691 L p .707 .577 .707 r
F P
0 g
s
.76653 .7218 m .76801 .74089 L .79722 .73745 L p .707 .577 .707 r
F P
0 g
s
.79722 .73745 m .79672 .73104 L p .76653 .7218 L .707 .577 .707 r
F P
0 g
s
.79672 .73104 m .79574 .71836 L .77518 .72078 L p .707 .577 .707 r
F P
0 g
s
.77518 .72078 m .76653 .7218 L p .79672 .73104 L .707 .577 .707 r
F P
0 g
s
.7618 .74794 m .76758 .71716 L p .73614 .71483 L .707 .577 .707 r
F P
0 g
s
.76758 .71716 m .76761 .71702 L .76724 .717 L p .707 .577 .707 r
F P
0 g
s
.76724 .717 m .73614 .71483 L p .76758 .71716 L .707 .577 .707 r
F P
0 g
s
.26519 .72483 m .26371 .74211 L .23199 .74126 L p .707 .577 .707 r
F P
0 g
s
.70516 .74535 m .70368 .72626 L .68126 .72673 L p .707 .577 .707 r
F P
0 g
s
.68126 .72673 m .6762 .72684 L p .6786 .72837 L .707 .577 .707 r
F P
0 g
s
.70516 .74535 m .68126 .72673 L .6786 .72837 L .707 .577 .707 r
F
.69951 .73782 m .73033 .74575 L p .70765 .71053 L F P
0 g
s
.70531 .70691 m .70424 .71263 L p .70765 .71053 L .707 .577 .707 r
F P
0 g
s
.70424 .71263 m .69951 .73782 L p .70765 .71053 L .707 .577 .707 r
F P
0 g
s
.69951 .73782 m .70531 .70691 L .67815 .69403 L p .707 .577 .707 r
F P
0 g
s
.76761 .71702 m .7618 .74794 L .79083 .74418 L p .707 .577 .707 r
F P
0 g
s
.79083 .74418 m .79663 .71327 L .76761 .71702 L p .707 .577 .707 r
F P
0 g
s
.55082 .24511 m .55082 .747 L .50662 .74455 L p .707 .577 .707 r
F P
0 g
s
.50662 .74455 m .50662 .24266 L .55082 .24511 L p .707 .577 .707 r
F P
0 g
s
.81475 .56721 m .82067 .62457 L .83674 .62193 L p .707 .577 .707 r
F P
0 g
s
.83674 .62193 m .83082 .56458 L .81475 .56721 L p .707 .577 .707 r
F P
0 g
s
.6762 .72684 m .67767 .74593 L .70516 .74535 L p .707 .577 .707 r
F P
0 g
s
.46177 .7459 m .46177 .24401 L .50662 .24266 L p .707 .577 .707 r
F P
0 g
s
.46177 .24401 m .46177 .7459 L .42066 .75089 L p .707 .577 .707 r
F P
0 g
s
.67234 .72494 m .67815 .69403 L .6573 .67745 L p .707 .577 .707 r
F P
0 g
s
.67815 .69403 m .67234 .72494 L .69951 .73782 L p .707 .577 .707 r
F P
0 g
s
.50662 .24266 m .50662 .74455 L .46177 .7459 L p .707 .577 .707 r
F P
0 g
s
.79745 .73741 m .82106 .73362 L p .80647 .72483 L .707 .577 .707 r
F P
0 g
s
.82106 .73362 m .81958 .71453 L .79574 .71836 L p .707 .577 .707 r
F P
0 g
s
.81958 .71453 m .82106 .73362 L .8372 .72979 L p .707 .577 .707 r
F P
0 g
s
.8372 .72979 m .83572 .7107 L .83047 .71194 L p .707 .577 .707 r
F P
0 g
s
.83047 .71194 m .81958 .71453 L p .82753 .72141 L .707 .577 .707 r
F P
0 g
s
.8372 .72979 m .83047 .71194 L .82753 .72141 L .707 .577 .707 r
F
.83072 .72085 m .83768 .70356 L p .83669 .69196 L F P
0 g
s
.83652 .68994 m .83531 .69641 L p .83669 .69196 L .707 .577 .707 r
F P
0 g
s
.83531 .69641 m .83072 .72085 L p .83669 .69196 L .707 .577 .707 r
F P
0 g
s
.81458 .73485 m .83072 .72085 L p .82086 .70473 L .707 .577 .707 r
F P
0 g
s
.82038 .70394 m .82001 .70593 L p .82086 .70473 L .707 .577 .707 r
F P
0 g
s
.82001 .70593 m .81458 .73485 L p .82086 .70473 L .707 .577 .707 r
F P
0 g
s
.79574 .71836 m .79722 .73745 L .79745 .73741 L p .707 .577 .707 r
F P
0 g
s
.80647 .72483 m .79574 .71836 L .79745 .73741 L .707 .577 .707 r
F
.79663 .71327 m .79083 .74418 L .81458 .73485 L p F P
0 g
s
.81458 .73485 m .82038 .70394 L .79663 .71327 L p .707 .577 .707 r
F P
0 g
s
.6565 .64114 m .65058 .58378 L .63783 .58406 L p .707 .577 .707 r
F P
0 g
s
.63783 .58406 m .64374 .64142 L .6565 .64114 L p .707 .577 .707 r
F P
0 g
s
.67767 .74593 m .6762 .72684 L .65504 .72621 L p .707 .577 .707 r
F P
0 g
s
.65504 .72621 m .65652 .7453 L .67767 .74593 L p .707 .577 .707 r
F P
0 g
s
.65149 .70837 m .6573 .67745 L .64481 .65881 L p .707 .577 .707 r
F P
0 g
s
.6573 .67745 m .65149 .70837 L .67234 .72494 L p .707 .577 .707 r
F P
0 g
s
.83072 .72085 m .83652 .68994 L .82038 .70394 L p .707 .577 .707 r
F P
0 g
s
.83082 .56458 m .83674 .62193 L .84354 .62013 L p .707 .577 .707 r
F P
0 g
s
.84354 .62013 m .83762 .56277 L .83082 .56458 L p .707 .577 .707 r
F P
0 g
s
.65652 .7453 m .65504 .72621 L .64229 .72442 L p .707 .577 .707 r
F P
0 g
s
.64374 .64142 m .64232 .62765 L p .64209 .63079 L .707 .577 .707 r
F P
0 g
s
.6347 .58325 m .64061 .64061 L .64374 .64142 L p .707 .577 .707 r
F P
0 g
s
.639 .68972 m .64481 .65881 L .6419 .63991 L p .707 .577 .707 r
F P
0 g
s
.63609 .67083 m .639 .68972 L p .64094 .65639 L .707 .577 .707 r
F P
0 g
s
.6419 .63991 m .64094 .64503 L p .64094 .65639 L .707 .577 .707 r
F P
0 g
s
.64094 .64503 m .63609 .67083 L p .64094 .65639 L .707 .577 .707 r
F P
0 g
s
.6419 .63991 m .64886 .62262 L p .64493 .63743 L .707 .577 .707 r
F P
0 g
s
.64741 .63881 m .64369 .63979 L p .64671 .63406 L .707 .577 .707 r
F P
0 g
s
.64671 .63406 m .64886 .62262 L p .64981 .63261 L .707 .577 .707 r
F P
0 g
s
.64741 .63881 m .64695 .63436 L p .64831 .63353 L .707 .577 .707 r
F P
0 g
s
.64671 .63406 m .64981 .63261 L .64695 .63436 L .707 .577 .707 r
F
.66348 .63617 m .64741 .63881 L p .64831 .63353 L F P
0 g
s
.64886 .62262 m .665 .60862 L p .65476 .62957 L .707 .577 .707 r
F P
0 g
s
.64981 .63261 m .64886 .62262 L .65476 .62957 L .707 .577 .707 r
F
.64831 .63353 m .66188 .62521 L .66348 .63617 L F
.66188 .62521 m .665 .60862 L p .66714 .62401 L F P
0 g
s
.66348 .63617 m .66237 .62544 L p .66705 .62404 L .707 .577 .707 r
F P
0 g
s
.66188 .62521 m .66714 .62401 L .66237 .62544 L .707 .577 .707 r
F
.68724 .63297 m .66348 .63617 L p .66705 .62404 L F P
0 g
s
.665 .60862 m .68874 .59929 L p .67156 .62269 L .707 .577 .707 r
F P
0 g
s
.66714 .62401 m .665 .60862 L .67156 .62269 L .707 .577 .707 r
F
.68874 .59929 m .71777 .59554 L p .69566 .61755 L F P
0 g
s
.69148 .61812 m .68874 .59929 L .69566 .61755 L .707 .577 .707 r
F
.68724 .63297 m .68579 .6189 L p .69299 .61791 L F P
0 g
s
.68511 .61864 m .68874 .59929 L p .69148 .61812 L .707 .577 .707 r
F P
0 g
s
.71637 .62952 m .68724 .63297 L p .69299 .61791 L .707 .577 .707 r
F P
0 g
s
.68579 .6189 m .69148 .61812 L .69194 .62125 L .707 .577 .707 r
F
.68511 .61864 m .69148 .61812 L .68579 .6189 L F
.71777 .59554 m .74924 .59773 L p .72668 .61511 L F P
0 g
s
.72161 .61522 m .71777 .59554 L .72668 .61511 L .707 .577 .707 r
F
.71637 .62952 m .71491 .61536 L p .72243 .6152 L F P
0 g
s
.71411 .61502 m .71777 .59554 L p .72161 .61522 L .707 .577 .707 r
F P
0 g
s
.74801 .62615 m .71637 .62952 L p .72243 .6152 L .707 .577 .707 r
F P
0 g
s
.71491 .61536 m .72161 .61522 L .72225 .61852 L .707 .577 .707 r
F
.71411 .61502 m .72161 .61522 L .71491 .61536 L F
.77907 .62319 m .74801 .62615 L p .75239 .61563 L F P
0 g
s
.74924 .59773 m .78007 .60565 L p .76281 .61648 L .707 .577 .707 r
F P
0 g
s
.75484 .61583 m .74924 .59773 L .76281 .61648 L .707 .577 .707 r
F
.75239 .61563 m .7778 .61771 L .77907 .62319 L F
.7778 .61771 m .78007 .60565 L p .7862 .61985 L F P
0 g
s
.79622 .62178 m .77907 .62319 L p .78066 .61878 L .707 .577 .707 r
F P
0 g
s
.7778 .61771 m .7862 .61985 L .77858 .61838 L .707 .577 .707 r
F
.78007 .60565 m .80723 .61853 L p .79997 .6225 L F P
0 g
s
.7862 .61985 m .78007 .60565 L .79997 .6225 L .707 .577 .707 r
F
.72243 .6152 m .74605 .6147 L .74801 .62615 L F
.74605 .6147 m .74924 .59773 L p .75484 .61583 L F P
0 g
s
.74605 .6147 m .75484 .61583 L .74688 .61517 L .707 .577 .707 r
F
.69299 .61791 m .71411 .61502 L .71637 .62952 L F
.71486 .61492 m .71491 .61536 L p .71411 .61502 L F P
0 g
s
.71491 .61536 m .71637 .62952 L p .71411 .61502 L .707 .577 .707 r
F P
0 g
s
.74924 .59773 m .74598 .6151 L p .72813 .62106 L .707 .577 .707 r
F P
0 g
s
.71197 .62645 m .72225 .61852 L .72813 .62106 L .707 .577 .707 r
F
.72225 .61852 m .74924 .59773 L .72813 .62106 L F
.74598 .6151 m .74343 .62864 L .72138 .62711 L p F P
0 g
s
.72138 .62711 m .71197 .62645 L p .74598 .6151 L .707 .577 .707 r
F P
0 g
s
.74209 .56879 m .77316 .56583 L p .75431 .61103 L .707 .577 .707 r
F P
0 g
s
.75239 .61563 m .75167 .61232 L .75431 .61103 L .707 .577 .707 r
F
.75167 .61232 m .74209 .56879 L .75431 .61103 L F
.74801 .62615 m .74688 .61517 L p .75239 .61563 L F P
0 g
s
.74688 .61517 m .74209 .56879 L p .75239 .61563 L .707 .577 .707 r
F P
0 g
s
.74688 .61517 m .75484 .61583 L .7563 .62056 L .707 .577 .707 r
F
.74683 .61469 m .74688 .61517 L p .74605 .6147 L F P
0 g
s
.74688 .61517 m .74801 .62615 L p .74605 .6147 L .707 .577 .707 r
F P
0 g
s
.78007 .60565 m .77771 .61821 L p .76105 .62328 L .707 .577 .707 r
F P
0 g
s
.74343 .62864 m .7563 .62056 L .76105 .62328 L .707 .577 .707 r
F
.7563 .62056 m .78007 .60565 L .76105 .62328 L F
.77771 .61821 m .77426 .63657 L .754 .63136 L p F P
0 g
s
.754 .63136 m .74343 .62864 L p .77771 .61821 L .707 .577 .707 r
F P
0 g
s
.77316 .56583 m .8006 .56357 L p .78166 .61602 L .707 .577 .707 r
F P
0 g
s
.78066 .61878 m .78037 .61674 L .78166 .61602 L .707 .577 .707 r
F
.78037 .61674 m .77316 .56583 L .78166 .61602 L F
.77907 .62319 m .77858 .61838 L p .78066 .61878 L F P
0 g
s
.77858 .61838 m .77316 .56583 L p .78066 .61878 L .707 .577 .707 r
F P
0 g
s
.78976 .62809 m .7862 .61985 L .79997 .6225 L .707 .577 .707 r
F
.77858 .61838 m .7862 .61985 L .78976 .62809 L F
.80723 .61853 m .8061 .62454 L p .77426 .63657 L F P
0 g
s
.8061 .62454 m .80143 .64945 L .78791 .64304 L p .707 .577 .707 r
F P
0 g
s
.78791 .64304 m .77426 .63657 L p .8061 .62454 L .707 .577 .707 r
F P
0 g
s
.80143 .64945 m .80723 .61853 L .82808 .63511 L p .707 .577 .707 r
F P
0 g
s
.82173 .56224 m .82606 .60424 L p .80651 .62093 L .707 .577 .707 r
F P
0 g
s
.82606 .60424 m .82765 .6196 L .80986 .62072 L p .707 .577 .707 r
F P
0 g
s
.80986 .62072 m .80651 .62093 L p .82606 .60424 L .707 .577 .707 r
F P
0 g
s
.8006 .56357 m .80651 .62093 L .79622 .62178 L p .707 .577 .707 r
F P
0 g
s
.78066 .61878 m .8006 .56357 L .79622 .62178 L .707 .577 .707 r
F
.77851 .61777 m .77858 .61838 L p .7778 .61771 L F P
0 g
s
.77858 .61838 m .77907 .62319 L p .7778 .61771 L .707 .577 .707 r
F P
0 g
s
.77426 .63657 m .7778 .61771 L p .78976 .62809 L .707 .577 .707 r
F P
0 g
s
.77316 .56583 m .77851 .61777 L p .75239 .61563 L .707 .577 .707 r
F P
0 g
s
.7563 .62056 m .75484 .61583 L .76281 .61648 L .707 .577 .707 r
F
.74343 .62864 m .74605 .6147 L p .7563 .62056 L F P
0 g
s
.74209 .56879 m .74683 .61469 L p .74605 .6147 L .707 .577 .707 r
F P
0 g
s
.72243 .6152 m .72721 .60392 L .74605 .6147 L .707 .577 .707 r
F
.72721 .60392 m .74209 .56879 L .74605 .6147 L F
.66705 .62404 m .68511 .61864 L .68724 .63297 L F
.68574 .61845 m .68579 .6189 L p .68511 .61864 L F P
0 g
s
.68579 .6189 m .68724 .63297 L p .68511 .61864 L .707 .577 .707 r
F P
0 g
s
.71777 .59554 m .71405 .61538 L p .69738 .62332 L .707 .577 .707 r
F P
0 g
s
.68294 .6302 m .69194 .62125 L .69738 .62332 L .707 .577 .707 r
F
.69194 .62125 m .71777 .59554 L .69738 .62332 L F
.71405 .61538 m .71197 .62645 L .68937 .62937 L p F P
0 g
s
.68937 .62937 m .68294 .6302 L p .71405 .61538 L .707 .577 .707 r
F P
0 g
s
.71045 .57216 m .74209 .56879 L p .72498 .60918 L .707 .577 .707 r
F P
0 g
s
.72243 .6152 m .72133 .61125 L .72498 .60918 L .707 .577 .707 r
F
.72133 .61125 m .71045 .57216 L .72498 .60918 L F
.71491 .61536 m .71045 .57216 L p .72243 .6152 L F P
0 g
s
.72225 .61852 m .72161 .61522 L .72668 .61511 L .707 .577 .707 r
F
.71197 .62645 m .71411 .61502 L p .72225 .61852 L F P
0 g
s
.71045 .57216 m .71486 .61492 L p .71411 .61502 L .707 .577 .707 r
F P
0 g
s
.69299 .61791 m .69692 .60761 L .71411 .61502 L .707 .577 .707 r
F
.69692 .60761 m .71045 .57216 L .71411 .61502 L F
.68294 .6302 m .65919 .63954 L p .65958 .63901 L F P
0 g
s
.66237 .62544 m .66348 .63617 L p .66188 .62521 L .707 .577 .707 r
F P
0 g
s
.68874 .59929 m .68504 .619 L p .65958 .63901 L .707 .577 .707 r
F P
0 g
s
.68504 .619 m .68294 .6302 L p .65958 .63901 L .707 .577 .707 r
F P
0 g
s
.68132 .57561 m .71045 .57216 L p .6958 .61055 L .707 .577 .707 r
F P
0 g
s
.69299 .61791 m .69182 .61368 L .6958 .61055 L .707 .577 .707 r
F
.69182 .61368 m .68132 .57561 L .6958 .61055 L F
.68579 .6189 m .68132 .57561 L p .69299 .61791 L F P
0 g
s
.69194 .62125 m .69148 .61812 L .69566 .61755 L .707 .577 .707 r
F
.68294 .6302 m .68511 .61864 L p .69194 .62125 L F P
0 g
s
.68132 .57561 m .68574 .61845 L p .68511 .61864 L .707 .577 .707 r
F P
0 g
s
.66705 .62404 m .67031 .61299 L .68511 .61864 L .707 .577 .707 r
F
.67031 .61299 m .68132 .57561 L .68511 .61864 L F
.66769 .62796 m .66714 .62401 L .67156 .62269 L F
.66237 .62544 m .66714 .62401 L .66769 .62796 L F
.65919 .63954 m .64305 .65353 L p .64772 .64398 L F P
0 g
s
.665 .60862 m .66181 .62561 L p .64772 .64398 L .707 .577 .707 r
F P
0 g
s
.66181 .62561 m .65919 .63954 L p .64772 .64398 L .707 .577 .707 r
F P
0 g
s
.65756 .57882 m .68132 .57561 L p .66958 .61548 L .707 .577 .707 r
F P
0 g
s
.66705 .62404 m .66618 .6199 L .66958 .61548 L .707 .577 .707 r
F
.66618 .6199 m .65756 .57882 L .66958 .61548 L F
.66237 .62544 m .65756 .57882 L p .66705 .62404 L F P
0 g
s
.66232 .62494 m .66237 .62544 L p .66188 .62521 L .707 .577 .707 r
F P
0 g
s
.65919 .63954 m .66188 .62521 L p .66769 .62796 L .707 .577 .707 r
F P
0 g
s
.65756 .57882 m .66232 .62494 L p .64831 .63353 L .707 .577 .707 r
F P
0 g
s
.65038 .63854 m .64981 .63261 L .65476 .62957 L .707 .577 .707 r
F
.64695 .63436 m .64981 .63261 L .65038 .63854 L F
.64305 .65353 m .63609 .67083 L p .64154 .65026 L F P
0 g
s
.64886 .62262 m .64661 .63457 L p .64154 .65026 L .707 .577 .707 r
F P
0 g
s
.64661 .63457 m .64305 .65353 L p .64154 .65026 L .707 .577 .707 r
F P
0 g
s
.6415 .58145 m .65756 .57882 L p .6498 .62472 L .707 .577 .707 r
F P
0 g
s
.64831 .63353 m .64791 .63054 L .6498 .62472 L .707 .577 .707 r
F
.64791 .63054 m .6415 .58145 L .6498 .62472 L F
.64695 .63436 m .6415 .58145 L p .64831 .63353 L F P
0 g
s
.64689 .63371 m .64695 .63436 L p .64671 .63406 L .707 .577 .707 r
F P
0 g
s
.64695 .63436 m .64741 .63881 L p .64671 .63406 L .707 .577 .707 r
F P
0 g
s
.64305 .65353 m .64671 .63406 L p .65038 .63854 L .707 .577 .707 r
F P
0 g
s
.64029 .65496 m .64146 .64404 L .64493 .63743 L .707 .577 .707 r
F
.64146 .64404 m .6419 .63991 L .64493 .63743 L F
.63783 .58406 m .6347 .58325 L p .64209 .63079 L F P
0 g
s
.64232 .62765 m .63783 .58406 L p .64209 .63079 L .707 .577 .707 r
F P
0 g
s
.6415 .58145 m .64689 .63371 L p .64093 .64053 L .707 .577 .707 r
F P
0 g
s
.64109 .64419 m .6419 .63991 L p .64029 .65496 L .707 .577 .707 r
F P
0 g
s
.64369 .63979 m .64093 .64053 L p .64689 .63371 L .707 .577 .707 r
F P
0 g
s
.64093 .64053 m .64061 .64061 L p .64093 .61951 L .707 .577 .707 r
F P
0 g
s
.64093 .61951 m .6415 .58145 L .64093 .64053 L .707 .577 .707 r
F
.63609 .67083 m .64109 .64419 L p .64029 .65496 L F P
0 g
s
.64229 .72442 m .64377 .74351 L .65652 .7453 L p .707 .577 .707 r
F P
0 g
s
.64481 .65881 m .639 .68972 L .65149 .70837 L p .707 .577 .707 r
F P
0 g
s
.83768 .70356 m .84348 .67265 L .83652 .68994 L p .707 .577 .707 r
F P
0 g
s
.83572 .7107 m .8372 .72979 L .84405 .72632 L p .707 .577 .707 r
F P
0 g
s
.84405 .72632 m .84258 .70723 L .83572 .7107 L p .707 .577 .707 r
F P
0 g
s
.83762 .56277 m .84354 .62013 L .8404 .61932 L p .707 .577 .707 r
F P
0 g
s
.8404 .61932 m .83449 .56196 L .83762 .56277 L p .707 .577 .707 r
F P
0 g
s
.64377 .74351 m .64229 .72442 L .6392 .72166 L p .707 .577 .707 r
F P
0 g
s
.6392 .72166 m .64067 .74075 L .64377 .74351 L p .707 .577 .707 r
F P
0 g
s
.64061 .64061 m .6347 .58325 L .6415 .58145 L p .707 .577 .707 r
F P
0 g
s
.84348 .67265 m .83768 .70356 L .83477 .68467 L p .707 .577 .707 r
F P
0 g
s
.83477 .68467 m .84057 .65375 L .84348 .67265 L p .707 .577 .707 r
F P
0 g
s
.02 w
.74011 .67194 Mdot
.5 Mabswid
.84258 .70723 m .84405 .72632 L .84096 .72355 L p .707 .577 .707 r
F P
0 g
s
.84096 .72355 m .83948 .70446 L .84258 .70723 L p .707 .577 .707 r
F P
0 g
s
.42581 .62257 m .41223 .57036 L .38129 .57838 L p .707 .577 .707 r
F P
0 g
s
.41223 .57036 m .42581 .62257 L .45438 .61155 L p .707 .577 .707 r
F P
0 g
s
.45438 .61155 m .44081 .55934 L .41223 .57036 L p .707 .577 .707 r
F P
0 g
s
.39486 .63059 m .38129 .57838 L .351 .5826 L p .707 .577 .707 r
F P
0 g
s
.38129 .57838 m .39486 .63059 L .42581 .62257 L p .707 .577 .707 r
F P
0 g
s
.83449 .56196 m .8404 .61932 L .82765 .6196 L p .707 .577 .707 r
F P
0 g
s
.82765 .6196 m .82173 .56224 L .83449 .56196 L p .707 .577 .707 r
F P
0 g
s
.44081 .55934 m .45438 .61155 L .47779 .5986 L p .707 .577 .707 r
F P
0 g
s
.47779 .5986 m .46421 .54639 L .44081 .55934 L p .707 .577 .707 r
F P
0 g
s
.35241 .65142 m .38158 .66289 L p .37359 .63932 L .707 .577 .707 r
F P
0 g
s
.36071 .62876 m .351 .5826 L .35853 .62697 L .707 .577 .707 r
F
.36362 .63115 m .36308 .62907 L p .36071 .62876 L F P
0 g
s
.36308 .62907 m .351 .5826 L p .36071 .62876 L .707 .577 .707 r
F P
0 g
s
.351 .5826 m .32433 .58263 L p .35853 .62697 L .707 .577 .707 r
F P
0 g
s
.38158 .66289 m .41155 .6734 L p .39864 .63785 L .707 .577 .707 r
F P
0 g
s
.351 .5826 m .35331 .59148 L p .39486 .63059 L .707 .577 .707 r
F P
0 g
s
.39486 .63059 m .35331 .59148 L .3916 .63065 L .707 .577 .707 r
F
.38628 .63178 m .39486 .63059 L p .36362 .63115 L F P
0 g
s
.39471 .62701 m .39289 .63197 L p .39864 .63785 L .707 .577 .707 r
F P
0 g
s
.39289 .63197 m .38158 .66289 L p .39864 .63785 L .707 .577 .707 r
F P
0 g
s
.35331 .59148 m .36362 .63115 L p .3916 .63065 L .707 .577 .707 r
F P
0 g
s
.37359 .63932 m .37089 .63135 L .36362 .63115 L .707 .577 .707 r
F
.36071 .62876 m .35241 .65142 L p .37359 .63932 L F P
0 g
s
.38158 .66289 m .39471 .62701 L .36554 .61555 L p .707 .577 .707 r
F P
0 g
s
.36362 .63115 m .36457 .63481 L .38628 .63178 L p .707 .577 .707 r
F P
0 g
s
.36554 .61555 m .36071 .62876 L p .36362 .63115 L .707 .577 .707 r
F P
0 g
s
.37089 .63135 m .36554 .61555 L .36362 .63115 L .707 .577 .707 r
F
.35241 .65142 m .36071 .62876 L p .34595 .62679 L F P
0 g
s
.3269 .64012 m .35241 .65142 L p .34883 .63777 L .707 .577 .707 r
F P
0 g
s
.34883 .63777 m .34595 .62679 L .34083 .63037 L .707 .577 .707 r
F
.34883 .63777 m .34083 .63037 L .3269 .64012 L F
.32433 .58263 m .3039 .57844 L p .32813 .61862 L F P
0 g
s
.33309 .62321 m .32433 .58263 L .32813 .61862 L .707 .577 .707 r
F
.33545 .6254 m .33502 .62372 L p .33309 .62321 L F P
0 g
s
.33502 .62372 m .32433 .58263 L p .33309 .62321 L .707 .577 .707 r
F P
0 g
s
.32433 .58263 m .33545 .6254 L p .35981 .62864 L .707 .577 .707 r
F P
0 g
s
.3269 .64012 m .33309 .62321 L p .32429 .62088 L .707 .577 .707 r
F P
0 g
s
.33244 .625 m .3269 .64012 L p .34595 .62679 L .707 .577 .707 r
F P
0 g
s
.30755 .6301 m .3269 .64012 L p .32619 .63488 L .707 .577 .707 r
F P
0 g
s
.32619 .63488 m .32429 .62088 L .31846 .6241 L .707 .577 .707 r
F
.32619 .63488 m .31846 .6241 L .30755 .6301 L F
.3039 .57844 m .2917 .57046 L p .30905 .61099 L F P
0 g
s
.31269 .61606 m .3039 .57844 L .30905 .61099 L .707 .577 .707 r
F
.31424 .61822 m .31384 .61669 L p .31269 .61606 L F P
0 g
s
.31384 .61669 m .3039 .57844 L p .31269 .61606 L .707 .577 .707 r
F P
0 g
s
.30755 .6301 m .31269 .61606 L p .30824 .61363 L .707 .577 .707 r
F P
0 g
s
.3039 .57844 m .31424 .61822 L p .33048 .62252 L .707 .577 .707 r
F P
0 g
s
.32068 .59422 m .31269 .61606 L p .32429 .62088 L .707 .577 .707 r
F P
0 g
s
.31269 .61606 m .3121 .61766 L p .31424 .61822 L .707 .577 .707 r
F P
0 g
s
.32429 .62088 m .31269 .61606 L .31424 .61822 L .707 .577 .707 r
F
.3121 .61766 m .30755 .6301 L p .32429 .62088 L F P
0 g
s
.31747 .63065 m .31424 .61822 L p .30905 .61099 L .707 .577 .707 r
F P
0 g
s
.30755 .6301 m .30824 .61363 L .30374 .61689 L .707 .577 .707 r
F
.29625 .62233 m .30703 .62974 L p .30374 .61689 L F P
0 g
s
.30703 .62974 m .30755 .6301 L p .30374 .61689 L .707 .577 .707 r
F P
0 g
s
.31078 .61502 m .30582 .60345 L .30204 .61026 L .707 .577 .707 r
F
.2917 .57046 m .30164 .6087 L p .30582 .60345 L F P
0 g
s
.30164 .6087 m .30204 .61026 L p .30582 .60345 L .707 .577 .707 r
F P
0 g
s
.30089 .60963 m .29625 .62233 L p .30824 .61363 L .707 .577 .707 r
F P
0 g
s
.30204 .61026 m .30527 .62267 L p .31078 .61502 L .707 .577 .707 r
F P
0 g
s
.30147 .60804 m .2917 .57046 L .30039 .60379 L .704 .576 .708 r
F
.30204 .61026 m .30164 .6087 L p .30147 .60804 L F P
0 g
s
.30164 .6087 m .2917 .57046 L p .30147 .60804 L .704 .576 .708 r
F P
0 g
s
.30089 .60963 m .30147 .60804 L p .29906 .61194 L .707 .577 .707 r
F P
0 g
s
.30147 .60804 m .30938 .58645 L p .30116 .60675 L .707 .577 .707 r
F P
0 g
s
.30938 .58645 m .30147 .60804 L p .30824 .61363 L .707 .577 .707 r
F P
0 g
s
.30147 .60804 m .30089 .60963 L p .30204 .61026 L .707 .577 .707 r
F P
0 g
s
.30824 .61363 m .30147 .60804 L .30204 .61026 L .707 .577 .707 r
F
.30116 .60675 m .30938 .58645 L .30082 .6054 L F
.30125 .60712 m .30039 .60379 L .3009 .6057 L .704 .576 .708 r
F
.30723 .5817 m .30055 .59996 L p .30082 .6054 L .707 .577 .707 r
F P
0 g
s
.30055 .59996 m .28892 .55946 L .30105 .59758 L .707 .577 .707 r
F
.30005 .60229 m .2996 .60053 L p .30055 .59996 L F P
0 g
s
.2996 .60053 m .28892 .55946 L p .30055 .59996 L .707 .577 .707 r
F P
0 g
s
.30938 .58645 m .30723 .5817 L p .30082 .6054 L .707 .577 .707 r
F P
0 g
s
.32068 .59422 m .30938 .58645 L p .30824 .61363 L .707 .577 .707 r
F P
0 g
s
.30723 .5817 m .31445 .58043 L p .30534 .59706 L .707 .577 .707 r
F P
0 g
s
.30055 .59996 m .29991 .60171 L p .30005 .60229 L .707 .577 .707 r
F P
0 g
s
.30082 .6054 m .30055 .59996 L .30005 .60229 L .707 .577 .707 r
F
.30055 .59996 m .30723 .5817 L p .30534 .59706 L F P
0 g
s
.30249 .61167 m .30005 .60229 L p .30055 .59996 L .707 .577 .707 r
F P
0 g
s
.30125 .59953 m .30055 .59996 L .30105 .59758 L .707 .577 .707 r
F
.30249 .61167 m .30055 .59996 L .30125 .59953 L F
.30039 .60379 m .29841 .59609 L .30249 .61167 L .704 .576 .708 r
F
.29649 .5886 m .2996 .60053 L p .29841 .59609 L F P
0 g
s
.2996 .60053 m .30249 .61167 L p .29841 .59609 L .704 .576 .708 r
F P
0 g
s
.30125 .60712 m .30147 .60804 L .30039 .60379 L .704 .576 .708 r
F
.2941 .61758 m .29625 .62233 L p .30082 .6054 L .707 .577 .707 r
F P
0 g
s
.28892 .55946 m .29649 .5886 L p .30039 .60379 L .704 .576 .708 r
F P
0 g
s
.2917 .57046 m .28892 .55946 L p .30039 .60379 L .704 .576 .708 r
F P
0 g
s
.29991 .60171 m .2941 .61758 L p .30082 .6054 L .707 .577 .707 r
F P
0 g
s
.30147 .60804 m .30116 .60675 L .29906 .61194 L .707 .577 .707 r
F
.29906 .61194 m .30116 .60675 L .30082 .6054 L F
.29625 .62233 m .30089 .60963 L p .29906 .61194 L F P
0 g
s
.30132 .61631 m .2941 .61758 L p .30085 .60525 L .707 .577 .707 r
F P
0 g
s
.31445 .58043 m .31003 .59252 L p .30534 .59706 L .707 .577 .707 r
F P
0 g
s
.30942 .59874 m .30848 .59516 L p .30961 .59322 L .707 .577 .707 r
F P
0 g
s
.30534 .59706 m .31003 .59252 L .30848 .59516 L .707 .577 .707 r
F
.31445 .58043 m .33033 .58277 L p .32391 .59019 L F P
0 g
s
.31003 .59252 m .31445 .58043 L p .32391 .59019 L .707 .577 .707 r
F P
0 g
s
.31178 .53292 m .32536 .58513 L .31834 .59112 L p .707 .577 .707 r
F P
0 g
s
.31834 .59112 m .30942 .59874 L p .30964 .59258 L .707 .577 .707 r
F P
0 g
s
.30964 .59258 m .31178 .53292 L .31834 .59112 L .707 .577 .707 r
F
.30942 .59874 m .30249 .61167 L p .29938 .58117 L F P
0 g
s
.29584 .54653 m .30789 .59288 L p .29938 .58117 L .707 .577 .707 r
F P
0 g
s
.30789 .59288 m .30942 .59874 L p .29938 .58117 L .707 .577 .707 r
F P
0 g
s
.31415 .60148 m .31003 .59252 L .32391 .59019 L .707 .577 .707 r
F
.30249 .61167 m .30527 .62267 L p .30125 .60712 L .704 .576 .708 r
F P
0 g
s
.30527 .62267 m .30204 .61026 L p .30147 .60804 L .704 .576 .708 r
F P
0 g
s
.30527 .62267 m .30147 .60804 L .30125 .60712 L .704 .576 .708 r
F
.30132 .61631 m .30922 .59471 L p .31415 .60148 L .707 .577 .707 r
F P
0 g
s
.30922 .59471 m .31003 .59252 L p .31415 .60148 L .707 .577 .707 r
F P
0 g
s
.31003 .59252 m .30922 .59471 L p .30848 .59516 L .707 .577 .707 r
F P
0 g
s
.29584 .54653 m .31178 .53292 L p .30961 .59322 L .707 .577 .707 r
F P
0 g
s
.30848 .59516 m .29584 .54653 L p .30961 .59322 L .707 .577 .707 r
F P
0 g
s
.30085 .60525 m .30534 .59706 L .30241 .61109 L .707 .577 .707 r
F
.30125 .60712 m .3009 .6057 L .30249 .61167 L .704 .576 .708 r
F
.30085 .60525 m .30241 .61109 L .30132 .61631 L .707 .577 .707 r
F
.30922 .59471 m .30132 .61631 L p .30534 .59706 L F P
0 g
s
.2941 .61758 m .30055 .59996 L p .30534 .59706 L .707 .577 .707 r
F P
0 g
s
.28892 .55946 m .29584 .54653 L p .30105 .59758 L .707 .577 .707 r
F P
0 g
s
.30527 .62267 m .31747 .63065 L p .31078 .61502 L .707 .577 .707 r
F P
0 g
s
.31269 .61606 m .32068 .59422 L p .30824 .61363 L .707 .577 .707 r
F P
0 g
s
.31747 .63065 m .33791 .63484 L p .33048 .62252 L .707 .577 .707 r
F P
0 g
s
.31424 .61822 m .31747 .63065 L p .33048 .62252 L .707 .577 .707 r
F P
0 g
s
.34003 .60425 m .32068 .59422 L p .32429 .62088 L .707 .577 .707 r
F P
0 g
s
.34003 .60425 m .33309 .62321 L p .34595 .62679 L .707 .577 .707 r
F P
0 g
s
.33309 .62321 m .33244 .625 L p .33545 .6254 L .707 .577 .707 r
F P
0 g
s
.34595 .62679 m .33309 .62321 L .33545 .6254 L .707 .577 .707 r
F
.33791 .63484 m .33545 .6254 L p .32813 .61862 L F P
0 g
s
.33309 .62321 m .34003 .60425 L p .32429 .62088 L .707 .577 .707 r
F P
0 g
s
.33791 .63484 m .36457 .63481 L p .35981 .62864 L .707 .577 .707 r
F P
0 g
s
.33545 .6254 m .33791 .63484 L p .35981 .62864 L .707 .577 .707 r
F P
0 g
s
.36554 .61555 m .34003 .60425 L p .34595 .62679 L .707 .577 .707 r
F P
0 g
s
.36457 .63481 m .36362 .63115 L p .35853 .62697 L .707 .577 .707 r
F P
0 g
s
.36071 .62876 m .36554 .61555 L p .34595 .62679 L .707 .577 .707 r
F P
0 g
s
.64067 .74075 m .6392 .72166 L .64605 .71819 L p .707 .577 .707 r
F P
0 g
s
.64605 .71819 m .64753 .73728 L .64067 .74075 L p .707 .577 .707 r
F P
0 g
s
.84057 .65375 m .83477 .68467 L .82228 .66602 L p .707 .577 .707 r
F P
0 g
s
.82228 .66602 m .82808 .63511 L .84057 .65375 L p .707 .577 .707 r
F P
0 g
s
.41155 .6734 m .42468 .63753 L .39471 .62701 L p .707 .577 .707 r
F P
0 g
s
.42468 .63753 m .41155 .6734 L .43939 .68193 L p .707 .577 .707 r
F P
0 g
s
.43939 .68193 m .45252 .64606 L .42468 .63753 L p .707 .577 .707 r
F P
0 g
s
.46421 .54639 m .47779 .5986 L .49373 .58499 L p .707 .577 .707 r
F P
0 g
s
.49373 .58499 m .48016 .53278 L .46421 .54639 L p .707 .577 .707 r
F P
0 g
s
.83948 .70446 m .84096 .72355 L .82821 .72177 L p .707 .577 .707 r
F P
0 g
s
.82821 .72177 m .82673 .70268 L .83948 .70446 L p .707 .577 .707 r
F P
0 g
s
.80651 .62093 m .8006 .56357 L .82173 .56224 L p .707 .577 .707 r
F P
0 g
s
.82808 .63511 m .82228 .66602 L .80143 .64945 L p .707 .577 .707 r
F P
0 g
s
.45252 .64606 m .43939 .68193 L .46237 .68764 L p .707 .577 .707 r
F P
0 g
s
.46237 .68764 m .4755 .65177 L .45252 .64606 L p .707 .577 .707 r
F P
0 g
s
.64753 .73728 m .64605 .71819 L .66219 .71435 L p .707 .577 .707 r
F P
0 g
s
.39583 .73061 m .39242 .71282 L .36173 .71561 L p .707 .577 .707 r
F P
0 g
s
.39242 .71282 m .39583 .73061 L .42716 .72431 L p .707 .577 .707 r
F P
0 g
s
.42716 .72431 m .42375 .70651 L .39242 .71282 L p .707 .577 .707 r
F P
0 g
s
.66219 .71435 m .66367 .73344 L .64753 .73728 L p .707 .577 .707 r
F P
0 g
s
.42375 .70651 m .42716 .72431 L .45606 .7151 L p .707 .577 .707 r
F P
0 g
s
.45606 .7151 m .45265 .69731 L .42375 .70651 L p .707 .577 .707 r
F P
0 g
s
.36173 .71561 m .36514 .7334 L .39583 .73061 L p .707 .577 .707 r
F P
0 g
s
.36514 .7334 m .36173 .71561 L .33468 .71462 L p .707 .577 .707 r
F P
0 g
s
.48016 .53278 m .49373 .58499 L .50065 .57206 L p .707 .577 .707 r
F P
0 g
s
.50065 .57206 m .48708 .51985 L .48016 .53278 L p .707 .577 .707 r
F P
0 g
s
.45265 .69731 m .45606 .7151 L .4797 .7039 L p .707 .577 .707 r
F P
0 g
s
.4797 .7039 m .47629 .68611 L .45265 .69731 L p .707 .577 .707 r
F P
0 g
s
.82673 .70268 m .82821 .72177 L .80705 .72113 L p .707 .577 .707 r
F P
0 g
s
.80705 .72113 m .80558 .70204 L .82673 .70268 L p .707 .577 .707 r
F P
0 g
s
.33468 .71462 m .33809 .73241 L .36514 .7334 L p .707 .577 .707 r
F P
0 g
s
.47629 .68611 m .4797 .7039 L .49577 .6918 L p .707 .577 .707 r
F P
0 g
s
.49577 .6918 m .49236 .67401 L .47629 .68611 L p .707 .577 .707 r
F P
0 g
s
.4755 .65177 m .46237 .68764 L .47825 .68998 L p .707 .577 .707 r
F P
0 g
s
.47825 .68998 m .49138 .65411 L .4755 .65177 L p .707 .577 .707 r
F P
0 g
s
.33809 .73241 m .33468 .71462 L .31393 .70993 L p .707 .577 .707 r
F P
0 g
s
.66367 .73344 m .66219 .71435 L .68603 .71052 L p .707 .577 .707 r
F P
0 g
s
.68603 .71052 m .68751 .72961 L .66367 .73344 L p .707 .577 .707 r
F P
0 g
s
.31393 .70993 m .31733 .72772 L .33809 .73241 L p .707 .577 .707 r
F P
0 g
s
.48708 .51985 m .50065 .57206 L .49788 .56106 L p .704 .576 .708 r
F P
0 g
s
.49788 .56106 m .4843 .50885 L .48708 .51985 L p .704 .576 .708 r
F P
0 g
s
.80558 .70204 m .80705 .72113 L .77957 .72171 L p .707 .577 .707 r
F P
0 g
s
.77957 .72171 m .77809 .70262 L .80558 .70204 L p .707 .577 .707 r
F P
0 g
s
.49138 .65411 m .47825 .68998 L .48547 .68871 L p .707 .577 .707 r
F P
0 g
s
.48547 .68871 m .4986 .65284 L .49138 .65411 L p .707 .577 .707 r
F P
0 g
s
.68751 .72961 m .68603 .71052 L .71524 .70708 L p .707 .577 .707 r
F P
0 g
s
.71524 .70708 m .71672 .72617 L .68751 .72961 L p .707 .577 .707 r
F P
0 g
s
.31733 .72772 m .31393 .70993 L .30149 .70201 L p .707 .577 .707 r
F P
0 g
s
.49236 .67401 m .49577 .6918 L .50269 .67999 L p .707 .577 .707 r
F P
0 g
s
.50269 .67999 m .49928 .6622 L .49236 .67401 L p .707 .577 .707 r
F P
0 g
s
.77809 .70262 m .77957 .72171 L .74844 .72345 L p .707 .577 .707 r
F P
0 g
s
.74844 .72345 m .74697 .70436 L .77809 .70262 L p .707 .577 .707 r
F P
0 g
s
.30149 .70201 m .3049 .7198 L .31733 .72772 L p .707 .577 .707 r
F P
0 g
s
.71672 .72617 m .71524 .70708 L .74697 .70436 L p .707 .577 .707 r
F P
0 g
s
.74697 .70436 m .74844 .72345 L .71672 .72617 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .5655 Mdot
.5 Mabswid
.4843 .50885 m .49788 .56106 L .48567 .55308 L p .707 .577 .707 r
F P
0 g
s
.48567 .55308 m .4721 .50087 L .4843 .50885 L p .707 .577 .707 r
F P
0 g
s
.4986 .65284 m .48547 .68871 L .48333 .68396 L p .707 .577 .707 r
F P
0 g
s
.48333 .68396 m .49646 .64809 L .4986 .65284 L p .707 .577 .707 r
F P
0 g
s
.3049 .7198 m .30149 .70201 L .29859 .69164 L p .707 .578 .707 r
F P
0 g
s
.49928 .6622 m .50269 .67999 L .49979 .66961 L p .707 .578 .707 r
F P
0 g
s
.49979 .66961 m .49639 .65182 L .49928 .6622 L p .707 .578 .707 r
F P
0 g
s
.29859 .69164 m .302 .70943 L .3049 .7198 L p .707 .578 .707 r
F P
0 g
s
.4721 .50087 m .48567 .55308 L .46524 .5489 L p .707 .577 .707 r
F P
0 g
s
.46524 .5489 m .45166 .49669 L .4721 .50087 L p .707 .577 .707 r
F P
0 g
s
.02 w
.3971 .68622 Mdot
.5 Mabswid
.49646 .64809 m .48333 .68396 L .47202 .67619 L p .707 .577 .707 r
F P
0 g
s
.47202 .67619 m .48515 .64032 L .49646 .64809 L p .707 .577 .707 r
F P
0 g
s
.302 .70943 m .29859 .69164 L .30552 .67982 L p .707 .577 .707 r
F P
0 g
s
.49639 .65182 m .49979 .66961 L .48736 .6617 L p .707 .577 .707 r
F P
0 g
s
.48736 .6617 m .48395 .6439 L .49639 .65182 L p .707 .577 .707 r
F P
0 g
s
.30552 .67982 m .30892 .69761 L .302 .70943 L p .707 .577 .707 r
F P
0 g
s
.45166 .49669 m .46524 .5489 L .43857 .54892 L p .707 .577 .707 r
F P
0 g
s
.43857 .54892 m .425 .49671 L .45166 .49669 L p .707 .577 .707 r
F P
0 g
s
.32536 .58513 m .31178 .53292 L .33519 .51997 L p .707 .577 .707 r
F P
0 g
s
.33033 .58277 m .3172 .61864 L .30132 .61631 L p .707 .577 .707 r
F P
0 g
s
.48515 .64032 m .47202 .67619 L .45267 .66617 L p .707 .577 .707 r
F P
0 g
s
.45267 .66617 m .4658 .63029 L .48515 .64032 L p .707 .577 .707 r
F P
0 g
s
.30892 .69761 m .30552 .67982 L .32158 .66772 L p .707 .577 .707 r
F P
0 g
s
.425 .49671 m .43857 .54892 L .40828 .55314 L p .707 .577 .707 r
F P
0 g
s
.40828 .55314 m .39471 .50093 L .425 .49671 L p .707 .577 .707 r
F P
0 g
s
.34876 .57218 m .33519 .51997 L .36376 .50895 L p .707 .577 .707 r
F P
0 g
s
.33519 .51997 m .34876 .57218 L .32536 .58513 L p .707 .577 .707 r
F P
0 g
s
.48395 .6439 m .48736 .6617 L .4666 .65701 L p .707 .577 .707 r
F P
0 g
s
.4666 .65701 m .46319 .63922 L .48395 .6439 L p .707 .577 .707 r
F P
0 g
s
.32158 .66772 m .32499 .68551 L .30892 .69761 L p .707 .577 .707 r
F P
0 g
s
.3172 .61864 m .33033 .58277 L .35331 .58848 L p .707 .577 .707 r
F P
0 g
s
.39471 .50093 m .40828 .55314 L .37734 .56116 L p .707 .577 .707 r
F P
0 g
s
.37734 .56116 m .36376 .50895 L .39471 .50093 L p .707 .577 .707 r
F P
0 g
s
.36376 .50895 m .37734 .56116 L .34876 .57218 L p .707 .577 .707 r
F P
0 g
s
.35331 .58848 m .34018 .62436 L .3172 .61864 L p .707 .577 .707 r
F P
0 g
s
.4658 .63029 m .45267 .66617 L .42716 .65487 L p .707 .577 .707 r
F P
0 g
s
.42716 .65487 m .44029 .619 L .4658 .63029 L p .707 .577 .707 r
F P
0 g
s
.32499 .68551 m .32158 .66772 L .34523 .65652 L p .707 .577 .707 r
F P
0 g
s
.34018 .62436 m .35331 .58848 L .38115 .59701 L p .707 .577 .707 r
F P
0 g
s
.46319 .63922 m .4666 .65701 L .43955 .65601 L p .707 .577 .707 r
F P
0 g
s
.43955 .65601 m .43614 .63822 L .46319 .63922 L p .707 .577 .707 r
F P
0 g
s
.34523 .65652 m .34863 .67431 L .32499 .68551 L p .707 .577 .707 r
F P
0 g
s
.38115 .59701 m .36802 .63289 L .34018 .62436 L p .707 .577 .707 r
F P
0 g
s
.44029 .619 m .42716 .65487 L .39799 .6434 L p .707 .577 .707 r
F P
0 g
s
.39799 .6434 m .41112 .60753 L .44029 .619 L p .707 .577 .707 r
F P
0 g
s
.36802 .63289 m .38115 .59701 L .41112 .60753 L p .707 .577 .707 r
F P
0 g
s
.34863 .67431 m .34523 .65652 L .37412 .64732 L p .707 .577 .707 r
F P
0 g
s
.41112 .60753 m .39799 .6434 L .36802 .63289 L p .707 .577 .707 r
F P
0 g
s
.43614 .63822 m .43955 .65601 L .40886 .65881 L p .707 .577 .707 r
F P
0 g
s
.40886 .65881 m .40545 .64101 L .43614 .63822 L p .707 .577 .707 r
F P
0 g
s
.37412 .64732 m .37753 .66511 L .34863 .67431 L p .707 .577 .707 r
F P
0 g
s
.37753 .66511 m .37412 .64732 L .40545 .64101 L p .707 .577 .707 r
F P
0 g
s
.40545 .64101 m .40886 .65881 L .37753 .66511 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->PaperWidth,
  ImageSize->{285.25, 287.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00017a000`40O003h00Oogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolN
Ool00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00
OWoo8@00OWoo001fOol80005FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP06001hOol0
07=oo`<00003FUH005YF00YJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00IJEP@007Ao
o`00L7oo0`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YF00000P00LGoo001]Ool30007FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP02FUH3001^Ool006]oo`800003FUH005YF00MJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00EJEP8006aoo`00
JGoo0P000eYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF0`00JWoo001WOol20005FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
001XOol006Ioo`8000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001oogoo06Eoo`00IWoo0P00
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF0P00IWoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH2001VOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YF
FUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0
06Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<0
05YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001J
EUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF
00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF
00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJ
EP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJ
EP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH0
2UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000
IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00
FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eo
o`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF
00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH0
0`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF
00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF
00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<0
05YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<0
05YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001J
EUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001J
EP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF
00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo
001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03
001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF0000
1UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00
FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00
FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJ
EP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF
00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00
06Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<0
05YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001U
Ool00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001J
EP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF
00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJ
EP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03
001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03
001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH0
2EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eo
o`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YF
FUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol0
0`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH0
0`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00
00IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<0
05YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06
FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06
FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF
00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF
00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJ
EP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0
001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03
001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00
IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH0
2EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00
FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YF
FUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YF
FUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH0
0`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF
00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<0
05YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<0
05YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo
00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03
001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH00006FUH00`00FUIJEP06FUH00`00
FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00
FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP0000IJEP03001JEUYF00IJEP03001JEUYF00UJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00IGoo00<005YF00001UYF00<005YFFUH015YF3`0035YF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001UOol00`00FUH0
0006FUH70003FUH00`00FUIJEP05FUH00`00FUIJEP040009FUH00`00FUIJEP09FUH00`00FUIJEP08
FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol006Eoo`03001JEP00009JEP@0009J
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00IGoo1@001eYF00<005YF
FUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF00001UYF00<005YFFUH02EYF00<005YF
FUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF0000IGoo001TOol200000eYF001JEP08
FUH00`00FUIJEP05FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP06FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol0065oo`<000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYF0005
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001U
Ool005moo`8000MJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009J
EP04001JEUYF0005FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH00`00FUH0001UOol005eoo`<000QJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEUYF00EJ
EP03001JEUYF00=JEP03001JEP0000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJ
EP03001JEUYF009JEP03001JEP0006Eoo`00Fgoo0P000eYF00<005YFFUH01EYF00<005YFFUH01eYF
00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000AJEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00FGoo0P001EYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF
00@005YFFUH000AJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0006Eoo`00F7oo00<005YFFUH01EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF
FUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF00@005YFFUH000AJEP03001JEUYF00UJEP03001J
EUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00Egoo0P001eYF00<005YF
FUH01UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00<005YF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
0000IGoo001FOol01000FUIJEP001eYF00<005YFFUH01EYF00<005YFFUH01eYF00<005YFFUH01EYF
00<005YFFUH01EYF00<005YFFUH00eYF00@005YF000000=JEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00EGoo00D005YFFUIJEP0000MJEP03
001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00EJEP03001JEUYF00=JEP04
001JEUYF0003FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH0001UOol005Aoo`03001JEUYF009JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF009JEP04001JEUYF0003FUH00`00FUIJ
EP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0001UOol005=oo`03
001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF009JEPh0
00=JEP03001JEP0000=JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEP0006Eoo`00Dgoo00<005YFFUH015YF00<005YFFUH01EYF00<005YFFUH01EYF00<0
05YFFUH01EYF1`001eYF00D005YFFUIJEP00009JEP@00003FUH00000009JEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0006Eoo`00DWoo00@005YFFUH0
00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00@000EJEP03001JEUYF00AJEP8000AJ
EP03001JEUYF00=JEP@0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001J
EUYF009JEP03001JEP0006Eoo`00DWoo00@005YFFUH000AJEP03001JEUYF00EJEP03001JEUYF00EJ
EPP000EJEP03001JEUYF009JEP8000IJEP03001JEUYF00=JEP04001JEUYF0002FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUH0000_Ool7000_Ool0059o
o`04001JEUYF0004FUH00`00FUIJEP05FUH00`00FUIJEP03FUH20004FUH50004FUH00`00FUIJEP02
00000eYF001JEP05FUH00`00FUIJEP03FUH01000FUIJEP000UYF00<005YFFUH02EYF00<005YFFUH0
25YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00007goo40000UYF00@005YFFUIJEP8002io
o`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP03001JEP00008000IJEPD000AJEP<000AJEP03
001JEUYF00AJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF00<005YF00005Woo2@0015YF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002ioo`00DWoo00@005YFFUH000EJEP03001JEUYF00EJEP<00003FUH005YF00EJEPT0
00MJEP03001JEUYF00AJEP03001JEUYF00=JEP06001JEUYF001JEP002eYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00003Woo20003EYF00<005YFFUH01EYF00<005YFFUH0
0eYF00@005YFFUIJEP8002ioo`00DWoo0P000UYF00<005YFFUH00UYF00<005YFFUH00eYF0P000Woo
00<005YF00001UYF1@000UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00<005YF
00000UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF
00001Woo20005EYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002ioo`00Dgoo0eYF
00<005YFFUH00UYF00@005YFFUIJEP8000Aoo`03001JEP0000L000MJEP03001JEUYF00EJEP03001J
EUYF00AJEP03001JEUYF00=JEP03001JEP00009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP04001JEP00Ool5000NFUH00`00FUIJEP04FUH00`00FUIJEP03FUH2
0002FUH2000^Ool0041oo`P000]oo`=JEP03001JEUYF00=JEP`000AJEP03001JEUYF00MJEP03001J
EUYF00IJEP03001JEUYF00AJEP03001JEUYF00=JEP05001JEUYFFUH0000;FUH00`00FUIJEP08FUH0
0`00FUIJEP06FUH01000FUIJEUYF1@0000=JEP00FUH035YF00<005YF000025YF00<005YFFUH01UYF
00<005YFFUH01EYF00<005YFFUH00UYF0P000UYF0P00;Woo000jOol60003FUH00`00FUIJEP02FUH9
0002Ool200000eYF001JEP04FUH200000eYF000000030009FUH00`00FUIJEP06FUH00`00FUIJEP06
FUH00`00FUIJEP04FUH00`00FUIJEP03FUH01@00FUIJEUYF00002eYF00<005YFFUH025YF00<005YF
FUH01UYF00D005YFFUIJEP0000EJEP03001JEUYF00eJEP03001JEUYF00IJEP03001JEUYF00IJEP03
001JEUYF00EJEP03001JEUYF00=JEP03001JEUYF008002ioo`00>7oo0P0000=JEP00FUH01UYF00<0
05YFFUH01UYF00<005YFFUH00UYF10000UYF00@005YFFUIJEP8000IJEP<000MJEP03001JEUYF00IJ
EP03001JEUYF00IJEP03001JEUYF00AJEP03001JEUYF009JEP03001JEUYF009JEP03001JEUYF00UJ
EP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00005FUH00`00FUIJEP0=FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000^Ool003Io
o`8000=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00QJEP8000=JEP03001JEUYF00EJ
EP03001JEP0000<000=JEP03001JEUYF00MJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
008000EJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP05001JEUYFFUH00006FUH0
0`00FUIJEP0<FUH00`00FUIJEP0?FUH00`00FUIJEP05FUH00`00FUIJEP03FUH01@00FUIJEUYF0000
;Woo000dOol20005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP02
FUH00`00FUIJEP04FUH00`00FUIJEP04FUH40009FUH00`00FUIJEP06FUH00`00FUIJEP04FUH20007
FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01@00FUIJEUYF00001UYF00<005YF
FUH035YF00<005YFFUH03eYF00<005YFFUH01EYF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00
<goo0P001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF0P0000=JEP00FUH00UYF
00<005YFFUH01EYF00<005YFFUH01UYF00@005YF000000MJEP03001JEUYF00IJEP03001JEUYF00AJ
EP03001JEUYF00IJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEUYF00=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00EJ
EP03001JEUYF00EJEP03001JEUYF00=JEP04001JEUYFFUH2000]Ool0035oo`800003FUH005YF00AJ
EP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP<000AJEP03001JEUYF00AJEP03001J
EUYF00IJEP03001JEUYF009JEP<000AJEP03001JEUYF00IJEP03001JEUYF009JEP8000UJEP03001J
EUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP07001JEUYFFUH005YF0000
1UYF0P001UYF00<005YFFUH01eYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00eYF00@0
05YFFUIJEP8002eoo`00<7oo00D005YFFUIJEP0000EJEP03001JEUYF00EJEP03001JEUYF00MJEP03
001JEUYF00EJEP03001JEP0000AJEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00EJEP<0
009JEP03001JEUYF00IJEP04001JEP00000;FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUIJEP03FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJ
EP06FUH00`00FUIJEP06FUH00`00FUIJEP04FUH00`00FUIJEP03FUH20002FUH2000]Ool002moo`80
009JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEP00
00AJEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEP00008000QJEP<000aJ
EP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP0000=J
EP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJ
EP03001JEUYF009JEP80009JEP8002eoo`00;goo0P000UYF00<005YFFUH015YF00<005YFFUH01EYF
00<005YFFUH01UYF00<005YFFUH01EYF00<005YF000015YF00<005YFFUH015YF00<005YFFUH01UYF
00<005YFFUH01UYF00<005YFFUH00UYF0P001EYF0P000UYF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF000015YF00<005YFFUH00eYF
00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00eYF
00<005YFFUH00P00;Goo000^Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP05FUH00`00
FUIJEP06FUH00`00FUIJEP05FUH90005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP04
FUH200000eYF00000004FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJ
EP06FUH00`00FUIJEP02FUH00`00FUH00004FUH00`00FUIJEP03FUH00`00FUIJEP05FUH00`00FUIJ
EP07FUH00`00FUIJEP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH00`00FUIJEP02000]Ool002io
o`8000=JEP03001JEUYF00AJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00IJEP03001J
EP00009JEP03001JEUYF00<00003FUH005YF00MJEP03001JEUYF00MJEP03001JEUYF00IJEP<000AJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJ
EP03001JEUYF009JEPh002eoo`00;Woo0P000eYF00<005YFFUH015YF00<005YFFUH01EYF00<005YF
FUH01UYF00<005YFFUH01UYF0`000UYF00<005YFFUH00UYF10001eYF00<005YFFUH01UYF00<005YF
FUH025YF00@005YF0000009JEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001J
EUYF00IJEP03001JEUYF009JEP03001JEP0000AJEP03001JEUYF00=JEP03001JEUYF00EJEP03001J
EUYF00IJEP03001JEUYF00MJEP03001JEUYF00EJEP03001JEP0000@0035oo`00;Woo0P000eYF00<0
05YFFUH00eYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YF00000P0000=J
EP00FUH00UYF0P000UYF10000UYF00<005YFFUH01eYF00<005YFFUH01eYF00<005YFFUH00UYF0`00
35YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`0015YF00<0
05YFFUH00eYF4`001eYF00D005YFFUIJEP0000=JEP04001JEUYFFUH2000cOol002ioo`8000=JEP03
001JEUYF00=JEP03001JEUYF00AJEPL000AJEP03001JEUYF00EJEP06001JEUYFFUH005YF10000eYF
00<005YFFUH00eYF100025YF00<005YFFUH01eYF00<005YFFUH015YF0P002eYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`000eYF00<005YFFUH015YF0P0015YF
200000=JEP00FUH00UYF0`0015YF00<005YFFUH01EYF00<005YFFUH00eYF00<007ooOol0<7oo000]
Ool00`00FUH00002FUH00`00FUIJEP04FUH00`00FUIJEP040007Ool60006FUH00`00FUIJEP02FUH2
0003FUH@0005FUH00`00FUIJEP06FUH00`00FUIJEP06FUH30009FUH00`00FUIJEP09FUH00`00FUIJ
EP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30003FUH01000FUIJEUYF2P0015YF2@000Woo0`00
00=JEP00FUH01UYF00<005YFFUH015YF00<007ooOol0;goo000]Ool00`00FUH00002FUH00`00FUIJ
EP03FUH4000AOol40002FUH00`00FUIJEP04FUH30008FUH00`00FUIJEP05FUH300000eYF001JEP05
FUH=0002FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02
FUH40002FUH200000eYF0000000=000>Ool30006FUH00`00FUIJEP04FUH2000`Ool002eoo`03001J
EP00009JEP03001JEP0000<001Uoo`@000IJEP<000MJEP03001JEUYF00IJEP03001JEP0000L000=J
EP03001JEUYF00EJEP03001JEP0000800003FUH005YF00EJEP03001JEUYF00UJEP03001JEUYF00QJ
EP03001JEUYF00IJEP03001JEUYF009JEP@00003FUH000000080021oo`8000=JEP03001JEUYF00EJ
EP80031oo`00;Goo0P000eYF0P008Goo0P0015YF00<005YFFUH00P001EYF00<005YFFUH01EYF1000
0UYF00<005YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF100015YF00<005YFFUH02EYF00<0
05YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF1@009Woo0P0000=JEP00FUH01EYF00@005YF
FUH002moo`00;Goo0P000UYF00<007ooOol08goo0`0000=JEP00FUH00eYF0`0000=JEP00FUH00eYF
10001UYF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1@000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00:Woo0P001UYF00@005YFFUH002mo
o`00;Goo100000=JEP00Ool057oo0`003goo0P001EYF00<005YF00001@0000=JEP00FUH025YF00<0
05YFFUH01EYF00<005YFFUH01EYF00<005YFFUH00UYF00<005YFFUH00P000UYF00<005YFFUH02EYF
00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0`00;7oo00<005YFFUH00eYF00D005YF
FUIJEP0002ioo`00;Goo00=JEP00FUH00UYF0`004Woo1@0047oo0P000eYF10001EYF00<005YFFUH0
1eYF00<005YFFUH00UYF3@0015YF00@005YFFUH0009JEP03001JEUYF00UJEP03001JEUYF00QJEP03
001JEUYF00IJEP03001JEUYF009JEP<002eoo`03001JEUYF009JEP05001JEUYFFUH0000^Ool002ao
o`<000=JEP04001JEUYF000AOol5000BOol300000eYF001JEP07FUH00`00FUIJEP04FUH70002FUH2
0004FUH00`00FUIJEP02FUH300001EYF001JEUYF00000UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000P00;7oo0P0000=JEP00FUH00eYF00<007oo
Ool0;7oo000/Ool30003FUH01000FUIJEUYF0P003goo1@004Goo0P000eYF00<005YFFUH01UYF00<0
05YFFUH010000eYF00<005YFFUH01EYF0P0000=JEP00FUH01EYF00@005YF000000=JEP03001JEP00
00]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP05001JEP00001JEP02000/Ool2
0004FUH00`00Oomoo`0/Ool002aoo`03001JEP0000=JEP03001JEUYF00=JEP8000ioo`<0011oo`80
00IJEP03001JEUYF00AJEPH000EJEP03001JEUYF00IJEP<000IJEP04001JEUYFFUH2000015YF001J
EP002eYF00<005YFFUH025YF00<005YFFUH01UYF00D005YFFUIJEP00009JEP8000=JEP<0019oo`<0
01Eoo`03001JEUYF009JEP8002eoo`00;7oo00<005YF00000eYF00<005YFFUH00eYF00@005YF0000
01ioo`8000MJEP03001JEUYF00@000AJEP03001JEP0000800003FUH005YF00MJEP04001JEUYFFUH2
0004FUH01000FUIJEUYF100000=JEP00FUH02UYF00<005YFFUH025YF00<005YFFUH01UYF00L005YF
FUIJEP00FUH00002FUH00`00FUIJEP03FUH3000>Ool5000EOol01P00FUIJEP00FUH002eoo`00;7oo
00<005YF00000eYF00<005YFFUH00eYF00@005YFFUIJEP<001Uoo`800003FUH005YF00EJEP@00003
FUH005YF00EJEP03001JEUYF009JEP<000MJEP03001JEUYF00=JEP800003FUH005YF009JEP80009J
EP03001JEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000UYF00<0
05YFFUH015YF00@005YF000000aoo`D001Ioo`05001JEP00FUH0000]Ool002aoo`03001JEUYF009J
EP03001JEUYF00AJEP03001JEUYF00AJEPH0019oo`03001JEUYF009JEP04001JEUYFFUH20002FUH2
00000eYF001JEP05FUH00`00FUIJEP05FUH40002FUH00`00FUIJEP05FUH30003FUH20002FUH00`00
FUH0000;FUH00`00FUIJEP08FUH00`00FUIJEP06FUH01`00FUIJEUYF001JEP0000=JEP03001JEUYF
009JEP03001JEUYF009JEP8000Yoo`D001Ioo`05001JEP00FUH0000]Ool002eoo`05001JEUYFFUH0
0006FUH00`00FUIJEP0:FUH90008Ool00`00FUIJEP03FUH01P00FUH00000FUH000=JEP03001JEP00
00IJEP@000EJEP03001JEUYF00@000IJEP03001JEUYF00D0009JEP03001JEP0000]JEP03001JEUYF
00QJEP03001JEUYF00IJEP07001JEUYFFUH005YF00000eYF0P000eYF00<005YFFUH00eYF0`002Goo
0`0067oo0P0000=JEP00Ool0;7oo000]Ool01@00FUIJEUYF00001UYF00<005YFFUH04eYF2@001EYF
0P000UYF00@005YFFUIJEP800003FUH005YF00EJEPD000AJEP03001JEUYF00AJEP@00003FUH005YF
00=JEP80009JEP80009JEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF
009JEP03001JEUYF009JEP03001JEP00009JEP03001JEUYF009JEP80009JEP8002=oo`03001JEP00
02eoo`00;Goo00D005YFFUIJEP0000IJEP03001JEUYF01MJEP03001JEUYF008000AJEP03001JEUYF
009JEP04001JEUYFFUH200000eYF001JEP05FUH50004FUH00`00FUIJEP08FUH30002FUH00`00FUH0
0002FUH20002FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUIJEP02FUH00`00FUIJEP030004FUH00`00FUIJEP02FUH00`00Oomoo`0QOol00`00FUH0000]
Ool002ioo`04001JEUYF0005FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP07FUH00`00
FUH00002FUH01@00FUH00000FUH02P0000=JEP00FUH01EYF1@0015YF00<005YFFUH02EYF1P000eYF
00D005YFFUIJEP0000]JEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEUYF
009JEP03001JEUYF009JEP03001JEUYF009JEP04001JEUYFFUH3000ROol2000^Ool002moo`03001J
EP0000EJEP03001JEUYF00EJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEP00009JEPD000=J
EP04001JEUYFFUH300000eYF001JEP05FUH40005FUH00`00FUIJEP08FUH20003FUH01@00FUIJEUYF
000015YF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YFFUH00UYF0P000UYF
00<005YFFUH015YF00D005YFFUIJEP0000=JEP03001JEP00025oo`<002ioo`00<7oo0P001EYF00<0
05YFFUH01EYF00<005YFFUH01UYF00@005YFFUIJEPT0009JEP8000IJEP@00005FUH00000FUH00006
FUH00`00FUIJEP06FUH00`00FUIJEP05FUH30006FUH00`00FUH00005FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH01@00FUH005YF00001UYF1@000eYF0P008Goo
00@005YF000002ioo`00<Goo00<005YFFUH00eYF00<005YFFUH01EYF00@005YFFUIJEPT000AJEP03
001JEUYF009JEP800003FUH005YF00=JEP<00004FUH005YFFUH200000eYF001JEP05FUH00`00FUIJ
EP06FUH01000FUIJEUYF100000=JEP00FUH01UYF0P001UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00D005YF001JEP0000IJEP03001JEUYF008000=JEP8000mo
oa<00003FUH0000002ioo`00<Woo0P000eYF00<005YFFUH00eYF1P0015YF00<005YFFUH01UYF00<0
05YFFUH00UYF200015YF00L005YFFUIJEP00FUH00006FUH00`00FUIJEP05FUH50005FUH00`00FUIJ
EP04FUH20007FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH0
0`00FUH000020006FUH00`00FUIJEP02FUH50006Ool90004FUH00`00FUIJEP04FUH00`00FUIJEP03
FUH00`00FUH00002000^Ool003Aoo`800003FUH005YF00@00003FUH005YF00MJEP03001JEUYF00IJ
EP03001JEP0000<0009JEP@000IJEP06001JEUYF001JEP001UYF00@005YFFUIJEP@0009JEP03001J
EUYF00IJEP04001JEUYFFUH20009FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH0
0`00FUIJEP02FUH01@00FUH005YF00001UYF00<005YFFUH015YF2@0015YF00<005YFFUH01UYF00<0
05YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00=7oo1@001EYF00<005YFFUH01UYF
00<005YFFUH015YF100000=JEP00FUH00P000UYF00<005YF00000P0015YF00H005YFFUH005YF0003
FUH70006FUH00`00FUIJEP06FUH01000FUH000002eYF00<005YFFUH02EYF00<005YFFUH025YF00<0
05YFFUH01UYF00<005YFFUH00UYF00<005YF00000UYF00<005YFFUH00UYF200015YF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH015YF00<005YFFUH00eYF00@005YFFUIJEP8002eoo`00<7oo
10000UYF00<005YFFUH01UYF00<005YFFUH01EYF0`0000AJEP00000000IJEP03001JEP00009JEP03
001JEUYF009JEPd000AJEP03001JEUYF00MJEP03001JEUYF00AJEP@000aJEP03001JEUYF00UJEP03
001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03001JEP00009JEPH0009JEP03001JEUYF
00IJEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYF
FUH0000]Ool002ioo`<000EJEP8000IJEPT000AJEP03001JEUYF00IJEP03001JEP0000=JEP03001J
EUYF009JEP03001JEUYF00AJEP03001JEUYF00IJEP03001JEUYF00MJEP03001JEUYF00@000=JEP03
001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009JEP03
001JEP000080009JEP03001JEUYF00=JEP03001JEUYF00IJEP03001JEUYF00IJEP03001JEUYF00IJ
EP03001JEUYF00EJEP03001JEUYF00=JEP05001JEUYFFUH0000]Ool002aoo`80009JEP03001JEUYF
00AJEPL000=JEPH000AJEP03001JEUYF00=JEP04001JEUYF0002FUH200000eYF001JEP03FUH00`00
FUIJEP04FUH00`00FUIJEP07FUH00`00FUIJEP04FUH50007FUH00`00FUIJEP0:FUH00`00FUIJEP09
FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH30004FUH00`00FUIJEP04FUH00`00
FUIJEP05FUH00`00FUIJEP02FUHP000]Ool002aoo`/0009JEPP00003FUH005YF00=JEPT00005FUH0
05YFFUH00004FUH30004FUH00`00FUIJEP04FUH00`00FUIJEP06FUH00`00FUIJEP05000;FUH00`00
FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00
FUH00004FUH00`00FUIJEP04FUH00`00FUIJEP02FUH90008FUH00`00FUIJEP05FUH00`00FUIJEP03
FUH01000FUH000000UYF00<005YF0000;Goo000/Ool00`00FUH00004FUH01000FUIJEUYF0P0000=J
EP00FUH01UYF00<005YFFUH01UYF00<005YFFUH00UYF1P001UYF0`0000=JEP00FUH01EYF00<005YF
FUH00UYF1`0015YF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF
00<005YFFUH01UYF00<005YFFUH00UYF00@005YFFUH000=JEP04001JEUYFFUH80008FUH00`00FUIJ
EP06FUH00`00FUIJEP05FUH00`00FUIJEP03FUH30002FUH3000^Ool002eoo`8000AJEP03001JEP00
00=JEP03001JEUYF00EJEP03001JEUYF00MJEP03001JEUYF00IJEP04001JEP000005FUH00`00FUH0
000<0002FUH00`00FUIJEP06FUH00`00FUIJEP09FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00
FUIJEP08FUH00`00FUIJEP06FUH00`00FUIJEP02FUH2000015YF001JEUYF1P000UYF0P0000=JEP00
FUH025YF00<005YFFUH01UYF00<005YFFUH01EYF00<005YFFUH00UYF1P00<Goo000]Ool00`00FUH0
0003FUH20004FUH00`00FUIJEP05FUH00`00FUIJEP06FUH00`00FUIJEP02FUH00`00FUIJEP02FUH0
1000FUIJEUYF0`000UYF00<005YFFUH00UYF100000=JEP00FUH01EYF00<005YFFUH01UYF00<005YF
FUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH01UYF00<005YF
FUH00UYF0P0000AJEP00000000EJEP03001JEUYF009JEP<000QJEP03001JEUYF00IJEP03001JEUYF
00AJEP04001JEUYFFUH2000gOol002eoo`04001JEP00FUH30005FUH00`00FUIJEP02FUH80004FUH0
0`00FUIJEP07FUH00`00FUIJEP04FUH3000015YF000000000goo00<005YF00001UYF00<005YFFUH0
1UYF00<005YFFUH02EYF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH025YF00<005YFFUH0
1UYF00<005YFFUH00UYF0`000UYF00<005YFFUH00eYF00<005YFFUH01EYF0`0015YF00<005YFFUH0
1UYF00<005YFFUH01EYF00@005YF000003Uoo`00;Goo00D005YF000005YF008000AJEPH000EJEP03
001JEUYF00T000AJEP03001JEUYF00EJEP@000Ioo`03001JEP0000IJEP03001JEUYF00IJEP03001J
EUYF00UJEP03001JEUYF00AJEP`000IJEP03001JEUYF00QJEP03001JEUYF00IJEP03001JEUYF009J
EPP000=JEP03001JEUYF009JEPT00003FUH005YF00MJEP03001JEUYF009JEPD003]oo`00;Goo0P00
0eYF00<005YF00000`000UYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH01P001UYF0P00
0UYF0P0017oo00<005YF00001UYF00<005YFFUH01UYF00<005YFFUH015YF30000UYF00<005YFFUH0
1eYF2@0025YF00<005YFFUH01UYF00<005YFFUH00UYF00<005YF00000`000UYF200000AJEP000000
00Eoo`l0041oo`00;Goo0P000eYF0`001EYF00<005YFFUH01UYF00<005YFFUH01UYF00<005YFFUH0
10000Woo0P0015YF00<005YFFUH00eYF0P000Woo00<005YF00001UYF00<005YFFUH015YF2@0000=J
EP00FUH02eYF00<005YFFUH02EYF00<005YFFUH015YF1P000UYF00<005YFFUH01UYF00<005YFFUH0
0UYF00<005YF00000goo10000eYF100000=ooeYF0000E7oo000]Ool20002FUH01000FUIJEP001UYF
00<005YFFUH01EYF00<005YFFUH00UYF1`0027oo0`0000EJEP00FUIJEWoo00=JEP800004Ool005YF
0006FUH00`00FUIJEP04000:FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH60006
FUH00`00FUIJEP02FUH00`00FUH00004Ool30006FUH01000FUIJEP00E7oo000/Ool01@00FUH005YF
00000eYF00<005YFFUH015YF00<005YFFUH00UYF20004Woo0P001UYF0P0000Aoo`00FUH000EJEP@0
00=JEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF
00=JEP@0009JEP03001JEUYF009JEP03001JEP00009oo`8000=JEP03001JEUYF00=JEP03001JEP00
05Eoo`00;7oo00<005YF00000P000eYF00@005YFFUIJEPP001aoo`8000=JEP03001JEUYF00800003
FUH005YF009JEP8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF
00UJEP03001JEUYF00MJEP<000AJEP03001JEP00008000EJEP03001JEUYF00=JEP03001JEP0005Eo
o`00;7oo00<005YF00002@009Woo0P0000=JEP00FUH00UYF00@005YF001JEP<000QJEP03001JEUYF
00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF
0080009JEP03001JEP0000QJEP03001JEUYF00=JEP03001oogoo05Aoo`00;7oo0P00<Woo0P000eYF
00@005YF0000009JEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJ
EP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF009JEP<00003FUH005YF00MJEP03001JEUYF
00=JEP03001oogoo05Aoo`00;7oo0P006Woo0`005goo00<005YFFUH00P0015YF00<005YFFUH01UYF
00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<005YFFUH01eYF
00<005YFFUH00eYF0P0000=JEP00000025YF00<005YFFUH00P00Egoo000/Ool3000HOol5000GOol0
1000FUH0000015YF00<005YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF
00<005YFFUH02EYF00<005YFFUH01eYF00<005YFFUH00eYF0P0000=JEP00000025YF00<005YF0000
FGoo000/Ool200000eYF001oo`0FOol5000HOol30004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH0
0`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
1P00FUH00000FUH000QJEP8005Uoo`00;7oo0P000UYF00<007ooOol057oo1@006Goo0P0015YF00<0
05YFFUH01UYF00<005YFFUH025YF00<005YFFUH02UYF00<005YFFUH02EYF00<005YFFUH02EYF00<0
05YFFUH01eYF00<005YFFUH00eYF00H005YF000005YF0008FUH00`00Oomoo`1HOol002eoo`05001J
EUYFFUH0000FOol3000JOol20004FUH00`00FUIJEP06FUH00`00FUIJEP08FUH00`00FUIJEP0:FUH0
0`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00FUIJEP03FUH01P00FUIJEP00FUH0
00IJEP8005]oo`00;Goo00@005YFFUIJEP<0031oo`<000AJEP03001JEUYF00IJEP03001JEUYF00QJ
EP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=J
EP03001JEP0000=JEP03001JEUYF009JEP03001oogoo05]oo`00;Woo00@005YFFUH0009JEP03001o
ogoo02eoo`03001JEP0000AJEP03001JEUYF00IJEP03001JEUYF00QJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00MJEP03001JEUYF00=JEP<000=JEP05001JEUYFFUH0
001NOol002ioo`03001JEP0000AJEP8002aoo`800004FUH000000002FUH00`00FUIJEP06FUH00`00
FUIJEP08FUH00`00FUIJEP0:FUH00`00FUIJEP09FUH00`00FUIJEP09FUH00`00FUIJEP07FUH00`00
FUIJEP03FUH200000eYF00000002FUH3001OOol002moo`8000IJEP8002Qoo`800003FUH0000000=o
o`<000QJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001J
EUYF00MJEP04001JEUYFFUH200000eYF001JEP02FUH3001QOol0031oo`03001JEUYF00AJEP03001J
EP0000<0029oo`8000=JEP8000Eoo`8000MJEP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF
00UJEP03001JEUYF00UJEP03001JEUYF00MJEP04001JEP000002FUH00`00FUIJEP05FUH3001NOol0
035oo`8000=JEP03001JEUYF00AJEP@001Yoo`@00003FUH005YF009JEP03001oogoo00Ioo`<000AJ
EP03001JEUYF00QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00UJEP03001JEUYF00EJ
EP@000AJEP03001JEUYF00IJEP03001JEP00008005]oo`00<goo0P0000=JEP00FUH01eYF00<005YF
00000`0047oo1P001EYF00@005YFFUH000aoo`<00003FUH005YF00UJEP03001JEUYF00YJEP03001J
EUYF00UJEP03001JEUYF00UJEP03001JEUYF00H00003FUH000000080009JEP03001JEUYF00IJEP03
001JEUYF009JEP8005Uoo`00=Goo0`001eYF00<005YFFUH00eYF400015YF00<005YFFUH00eYF00@0
05YF0000011oo`@000QJEP03001JEUYF00YJEP03001JEUYF00UJEP03001JEUYF00MJEPD0009JEPD0
00AJEP@000IJEP03001JEUYF00AJEP<005Moo`00>7oo0P0015YF00<005YFFUH01UYF00<005YFFUH0
1UYF00<005YFFUH01UYF00<005YFFUH00eYF0P005Woo1P000UYF00<005YFFUH02UYF00<005YFFUH0
2EYF00@005YFFUIJEPH000MJEPD0009JEP8000Aoo`@0009JEP03001JEUYF00AJEP04001JEUYF001F
Ool003Yoo`<00003FUH005YF00MJEP03001JEUYF00IJEP03001JEUYF00EJEP03001JEUYF00=JEP80
01eooal000EJEP03001JEUYF00EJEPL000Yoo`@000AJEP05001JEUYFFUH0001FOol003eoo`H000AJ
EP03001JEUYF00IJEP03001JEUYF00EJEP03001JEP0000<003Eoo`800003FUH005YF009JEP03001J
EUYF00AJEP03001JEUYF00EJEP@0015oo`<00003FUH005YF009JEP8005Eoo`00@goo2@0015YF00<0
05YFFUH00UYF1@00>goo10000UYF00<005YFFUH015YF00<005YFFUH0100015YF2@002goo0P000UYF
00<005YF0000EGoo001<Ool90014Ool<0003FUH00`00FUIJEP06FUH00`00FUIJEP02FUH>000015YF
001JEP00EGoo002MOol50006FUH00`00FUIJEP06FUH00`00FUIJEP06FUH00`00FUIJEP03FUH01000
FUIJEUYF0`00EWoo002ROol40002FUH00`00FUIJEP05FUH00`00FUIJEP07FUH00`00FUIJEP03FUH0
0`00FUIJEP02FUH2001FOol00:Ioo`@000IJEP03001JEUYF00IJEP03001JEUYF00=JEP03001JEUYF
009JEP03001JEP0005Ioo`00ZWoo10000UYF00<005YFFUH01UYF00<005YFFUH00eYF00<005YFFUH0
0UYF0P00Egoo002^OolG001HOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo
003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mooaioo`00ogoo7Woo003oOolNOol00?mo
oaioo`00ogoo7Woo003oOolNOol00001\
\>"],
  ImageRangeCache->{{{0, 284.25}, {286.875, 0}} -> {0.00457541, -5*^-06, \
0.00348584, 0.00348584}}]
}, Closed]],

Cell[BoxData[
    InterpretationBox[\("Mode # "\[InvisibleSpace]69\[InvisibleSpace]"     "\
\[InvisibleSpace]16.263096237724497`\[InvisibleSpace]" Hz"\),
      SequenceForm[ "Mode # ", 69, "     ", 16.263096237724497, " Hz"],
      Editable->False]], "Print",
  PageWidth->PaperWidth]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
  Inherited, Inherited, Inherited}, {
    Inherited, 
      "Vibration Modes of the BSC Seismic Isolation System, T020046-00-D", 
      Inherited}},
PrintingOptions->{"PrintingMargins"->{{43.1875, 43.1875}, {43.125, 43.125}},
"PrintCellBrackets"->True,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 358, 12, 170, "Title"],
Cell[2088, 66, 2926, 58, 394, "Text"],

Cell[CellGroupData[{
Cell[5039, 128, 62, 1, 47, "Subsection"],

Cell[CellGroupData[{
Cell[5126, 133, 59, 1, 43, "Subsubsection"],
Cell[5188, 136, 516, 9, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5741, 150, 59, 1, 43, "Subsubsection"],
Cell[5803, 153, 843, 15, 166, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6695, 174, 61, 1, 47, "Subsection"],
Cell[6759, 177, 154, 4, 50, "Input"],
Cell[6916, 183, 95, 2, 30, "Input"],
Cell[7014, 187, 121, 3, 30, "Input"],
Cell[7138, 192, 116, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[7279, 199, 99, 2, 30, "Input"],
Cell[7381, 203, 447, 8, 70, "Output"]
}, Open  ]],
Cell[7843, 214, 281, 7, 33, "Text",
  Evaluatable->False],
Cell[8127, 223, 113, 3, 30, "Input"],
Cell[8243, 228, 84, 2, 30, "Input"],
Cell[8330, 232, 94, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8461, 239, 85, 1, 31, "Subsection"],
Cell[8549, 242, 222, 5, 33, "Text"],
Cell[8774, 249, 373, 10, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9184, 264, 83, 1, 39, "Section"],
Cell[9270, 267, 369, 7, 90, "Input"],

Cell[CellGroupData[{
Cell[9664, 278, 77, 2, 30, "Input"],
Cell[9744, 282, 66, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9847, 289, 76, 2, 30, "Input"],
Cell[9926, 293, 1209, 25, 70, "Output"]
}, Open  ]],
Cell[11150, 321, 219, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[11394, 329, 90, 2, 30, "Input"],
Cell[11487, 333, 1334, 20, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12858, 358, 63, 2, 30, "Input"],
Cell[12924, 362, 77, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13038, 369, 80, 2, 30, "Input"],
Cell[13121, 373, 77, 2, 70, "Output"]
}, Open  ]],
Cell[13213, 378, 152, 3, 50, "Input"],
Cell[13368, 383, 77, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13482, 390, 117, 3, 39, "Section"],

Cell[CellGroupData[{
Cell[13624, 397, 75, 2, 30, "Input"],
Cell[13702, 401, 61, 2, 29, "Output"]
}, Open  ]],
Cell[13778, 406, 110, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[13913, 413, 107, 2, 30, "Input"],
Cell[14023, 417, 63, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14123, 424, 184, 3, 50, "Input"],
Cell[14310, 429, 63, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14410, 436, 111, 2, 43, "Subsubsection"],
Cell[14524, 440, 522, 11, 71, "Text"],
Cell[15049, 453, 207, 5, 50, "Input"],

Cell[CellGroupData[{
Cell[15281, 462, 243, 6, 50, "Input"],
Cell[15527, 470, 350, 5, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15914, 480, 120, 3, 50, "Input"],
Cell[16037, 485, 82, 2, 29, "Output"],
Cell[16122, 489, 87, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16246, 496, 101, 2, 30, "Input"],
Cell[16350, 500, 2105, 32, 200, "Output"]
}, Open  ]],
Cell[18470, 535, 94, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[18589, 541, 88, 2, 30, "Input"],
Cell[18680, 545, 59503, 862, 1475, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[78220, 1412, 127, 3, 27, "Input"],
Cell[78350, 1417, 154, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78541, 1425, 68, 2, 30, "Input"],
Cell[78612, 1429, 78, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78727, 1436, 63, 2, 30, "Input"],
Cell[78793, 1440, 77, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78907, 1447, 114, 2, 30, "Input"],
Cell[79024, 1451, 2088, 32, 200, "Output"]
}, Open  ]],
Cell[81127, 1486, 83, 2, 30, "Input"],
Cell[81213, 1490, 130, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[81368, 1497, 428, 9, 170, "Input"],
Cell[81799, 1508, 188, 3, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[82024, 1516, 624, 14, 190, "Input"],
Cell[82651, 1532, 9032, 147, 1461, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[91720, 1684, 108, 2, 30, "Input"],
Cell[91831, 1688, 79, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[91971, 1697, 118, 3, 59, "Section"],

Cell[CellGroupData[{
Cell[92114, 1704, 455, 9, 110, "Input"],
Cell[92572, 1715, 260, 5, 70, "Output"]
}, Open  ]],
Cell[92847, 1723, 335, 6, 110, "Input"],
Cell[93185, 1731, 489, 11, 90, "Input"],
Cell[93677, 1744, 627, 12, 130, "Input"],
Cell[94307, 1758, 77, 2, 30, "Input"],
Cell[94387, 1762, 275, 8, 30, "Input",
  InitializationCell->True],
Cell[94665, 1772, 295, 7, 50, "Input"],

Cell[CellGroupData[{
Cell[94985, 1783, 779, 15, 230, "Input"],
Cell[95767, 1800, 99990, 2862, 70, 40169, 2118, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[195772, 4665, 145, 3, 50, "Input"],
Cell[195920, 4670, 361, 6, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[196318, 4681, 115, 3, 39, "Section"],
Cell[196436, 4686, 89, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[196550, 4692, 102, 2, 30, "Input"],
Cell[196655, 4696, 61, 2, 29, "Output"]
}, Open  ]],
Cell[196731, 4701, 113, 2, 30, "Input"],
Cell[196847, 4705, 135, 3, 30, "Input"],
Cell[196985, 4710, 131, 3, 30, "Input"],
Cell[197119, 4715, 179, 4, 70, "Input"],

Cell[CellGroupData[{
Cell[197323, 4723, 66, 1, 47, "Subsection"],
Cell[197392, 4726, 2746, 51, 610, "Input"],

Cell[CellGroupData[{
Cell[200163, 4781, 146, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[200334, 4789, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[280826, 7428, 84347, 2848, 296, 45572, 2364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[365176, 10278, 84766, 2882, 296, 46416, 2403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[449945, 13162, 84766, 2882, 296, 46416, 2403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[534714, 16046, 84347, 2848, 296, 45572, 2364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[619064, 18896, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[699556, 21535, 86372, 2921, 296, 47366, 2434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[785931, 24458, 85225, 2957, 296, 48738, 2501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[871159, 27417, 85225, 2957, 296, 48738, 2501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[956387, 30376, 86372, 2921, 296, 47366, 2434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1042762, 33299, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1123254, 35938, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1203746, 38577, 84347, 2848, 296, 45572, 2364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1288096, 41427, 84766, 2882, 296, 46416, 2403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1372865, 44311, 84766, 2882, 296, 46416, 2403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1457634, 47195, 84347, 2848, 296, 45572, 2364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1541984, 50045, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1622476, 52684, 86372, 2921, 296, 47366, 2434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1708851, 55607, 85225, 2957, 296, 48738, 2501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1794079, 58566, 85225, 2957, 296, 48738, 2501, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1879307, 61525, 86372, 2921, 296, 47366, 2434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1965682, 64448, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[2046186, 67088, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[2046493, 67097, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2126985, 69736, 85696, 2903, 296, 46646, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2212684, 72641, 85647, 2947, 296, 47739, 2474, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2298334, 75590, 85647, 2947, 296, 47739, 2474, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2383984, 78539, 85696, 2903, 296, 46646, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2469683, 81444, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2550175, 84083, 84776, 2861, 296, 45953, 2377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2634954, 86946, 86777, 2982, 296, 48751, 2507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2721734, 89930, 86777, 2982, 296, 48751, 2507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2808514, 92914, 84776, 2861, 296, 45953, 2377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2893293, 95777, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2973785, 98416, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3054277, 101055, 85696, 2903, 296, 46646, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3139976, 103960, 85647, 2947, 296, 47739, 2474, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3225626, 106909, 85647, 2947, 296, 47739, 2474, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3311276, 109858, 85696, 2903, 296, 46646, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3396975, 112763, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3477467, 115402, 84776, 2861, 296, 45953, 2377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3562246, 118265, 86777, 2982, 296, 48751, 2507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3649026, 121249, 86777, 2982, 296, 48751, 2507, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3735806, 124233, 84776, 2861, 296, 45953, 2377, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3820585, 127096, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[3901089, 129736, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[3901396, 129745, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3981888, 132384, 79371, 2615, 296, 40483, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4061262, 135001, 79129, 2618, 296, 40792, 2140, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4140394, 137621, 79129, 2618, 296, 40792, 2140, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4219526, 140241, 79371, 2615, 296, 40483, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4298900, 142858, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4379392, 145497, 79796, 2626, 296, 40555, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4459191, 148125, 78985, 2610, 296, 40514, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4538179, 150737, 78985, 2610, 296, 40514, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4617167, 153349, 79796, 2626, 296, 40555, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4696966, 155977, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4777458, 158616, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4857950, 161255, 79371, 2615, 296, 40483, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4937324, 163872, 79129, 2618, 296, 40792, 2140, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5016456, 166492, 79129, 2618, 296, 40792, 2140, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5095588, 169112, 79371, 2615, 296, 40483, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5174962, 171729, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5255454, 174368, 79796, 2626, 296, 40555, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5335253, 176996, 78985, 2610, 296, 40514, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5414241, 179608, 78985, 2610, 296, 40514, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5493229, 182220, 79796, 2626, 296, 40555, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5573028, 184848, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[5653532, 187488, 281, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[5653838, 187497, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5734330, 190136, 79686, 2648, 296, 41284, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5814019, 192786, 78833, 2685, 296, 43209, 2240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5892855, 195473, 78833, 2685, 296, 43209, 2240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5971691, 198160, 79686, 2648, 296, 41284, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6051380, 200810, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6131872, 203449, 80979, 2667, 296, 41212, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6212854, 206118, 82901, 2732, 296, 42713, 2231, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6295758, 208852, 82901, 2732, 296, 42713, 2231, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6378662, 211586, 80979, 2667, 296, 41212, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6459644, 214255, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6540136, 216894, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6620628, 219533, 79686, 2648, 296, 41284, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6700317, 222183, 78833, 2685, 296, 43209, 2240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6779153, 224870, 78833, 2685, 296, 43209, 2240, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6857989, 227557, 79686, 2648, 296, 41284, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6937678, 230207, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7018170, 232846, 80979, 2667, 296, 41212, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7099152, 235515, 82901, 2732, 296, 42713, 2231, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7182056, 238249, 82901, 2732, 296, 42713, 2231, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7264960, 240983, 80979, 2667, 296, 41212, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7345942, 243652, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[7426446, 246292, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[7426753, 246301, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7507245, 248940, 80236, 2667, 296, 41522, 2184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7587484, 251609, 81267, 2690, 296, 41723, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7668754, 254301, 81267, 2690, 296, 41723, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7750024, 256993, 80236, 2667, 296, 41522, 2184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7830263, 259662, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7910755, 262301, 79291, 2626, 296, 40812, 2146, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7990049, 264929, 79835, 2657, 296, 41538, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8069887, 267588, 79835, 2657, 296, 41538, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8149725, 270247, 79291, 2626, 296, 40812, 2146, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8229019, 272875, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8309511, 275514, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8390003, 278153, 80236, 2667, 296, 41522, 2184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8470242, 280822, 81267, 2690, 296, 41723, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8551512, 283514, 81267, 2690, 296, 41723, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8632782, 286206, 80236, 2667, 296, 41522, 2184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8713021, 288875, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8793513, 291514, 79291, 2626, 296, 40812, 2146, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8872807, 294142, 79835, 2657, 296, 41538, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8952645, 296801, 79835, 2657, 296, 41538, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9032483, 299460, 79291, 2626, 296, 40812, 2146, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9111777, 302088, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[9192281, 304728, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[9192588, 304737, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9273080, 307376, 79977, 2641, 296, 40728, 2151, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9353060, 310019, 79759, 2630, 296, 40616, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9432822, 312651, 79759, 2630, 296, 40616, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9512584, 315283, 79977, 2641, 296, 40728, 2151, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9592564, 317926, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9673056, 320565, 81807, 2643, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9754866, 323210, 82580, 2652, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9837449, 325864, 82580, 2652, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9920032, 328518, 81807, 2643, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10001842, 331163, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10082334, 333802, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10162826, 336441, 79977, 2641, 296, 40728, 2151, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10242806, 339084, 79759, 2630, 296, 40616, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10322568, 341716, 79759, 2630, 296, 40616, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10402330, 344348, 79977, 2641, 296, 40728, 2151, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10482310, 346991, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10562802, 349630, 81807, 2643, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10644612, 352275, 82580, 2652, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10727195, 354929, 82580, 2652, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10809778, 357583, 81807, 2643, 296, 40436, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10891588, 360228, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[10972092, 362868, 280, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[10972397, 362877, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11052889, 365516, 81623, 2732, 296, 43395, 2255, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11134515, 368250, 90837, 3176, 296, 53269, 2707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11225355, 371428, 90837, 3176, 296, 53269, 2707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11316195, 374606, 81623, 2732, 296, 43395, 2255, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11397821, 377340, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11478313, 379979, 82826, 2715, 296, 42212, 2208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11561142, 382696, 93889, 3205, 296, 53527, 2702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11655034, 385903, 93889, 3205, 296, 53527, 2702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11748926, 389110, 82826, 2715, 296, 42212, 2208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11831755, 391827, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11912247, 394466, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11992739, 397105, 81623, 2732, 296, 43395, 2255, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12074365, 399839, 90837, 3176, 296, 53269, 2707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12165205, 403017, 90837, 3176, 296, 53269, 2707, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12256045, 406195, 81623, 2732, 296, 43395, 2255, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12337671, 408929, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12418163, 411568, 82826, 2715, 296, 42212, 2208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12500992, 414285, 93889, 3205, 296, 53527, 2702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12594884, 417492, 93889, 3205, 296, 53527, 2702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12688776, 420699, 82826, 2715, 296, 42212, 2208, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12771605, 423416, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[12852109, 426056, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[12852417, 426065, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12932909, 428704, 79922, 2636, 296, 40989, 2150, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13012834, 431342, 92460, 3230, 296, 54313, 2754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13105297, 434574, 92460, 3230, 296, 54313, 2754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13197760, 437806, 79922, 2636, 296, 40989, 2150, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13277685, 440444, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13358177, 443083, 80256, 2662, 296, 41586, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13438436, 445747, 92460, 3209, 296, 53446, 2722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13530899, 448958, 92460, 3209, 296, 53446, 2722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13623362, 452169, 80256, 2662, 296, 41586, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13703621, 454833, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13784113, 457472, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13864605, 460111, 79922, 2636, 296, 40989, 2150, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13944530, 462749, 92460, 3230, 296, 54313, 2754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14036993, 465981, 92460, 3230, 296, 54313, 2754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14129456, 469213, 79922, 2636, 296, 40989, 2150, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14209381, 471851, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14289873, 474490, 80256, 2662, 296, 41586, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14370132, 477154, 92460, 3209, 296, 53446, 2722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14462595, 480365, 92460, 3209, 296, 53446, 2722, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14555058, 483576, 80256, 2662, 296, 41586, 2179, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14635317, 486240, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[14715821, 488880, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[14716129, 488889, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14796621, 491528, 80319, 2640, 296, 40629, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14876943, 494170, 80256, 2639, 296, 40627, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14957202, 496811, 80256, 2639, 296, 40627, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15037461, 499452, 80319, 2640, 296, 40629, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15117783, 502094, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15198275, 504733, 80532, 2640, 296, 40623, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15278810, 507375, 80501, 2634, 296, 40584, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15359314, 510011, 80501, 2634, 296, 40584, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15439818, 512647, 80532, 2640, 296, 40623, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15520353, 515289, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15600845, 517928, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15681337, 520567, 80319, 2640, 296, 40629, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15761659, 523209, 80256, 2639, 296, 40627, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15841918, 525850, 80256, 2639, 296, 40627, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15922177, 528491, 80319, 2640, 296, 40629, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16002499, 531133, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16082991, 533772, 80532, 2640, 296, 40623, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16163526, 536414, 80501, 2634, 296, 40584, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16244030, 539050, 80501, 2634, 296, 40584, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16324534, 541686, 80532, 2640, 296, 40623, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16405069, 544328, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[16485573, 546968, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[16485881, 546977, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16566373, 549616, 80165, 2622, 296, 40451, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16646541, 552240, 79909, 2627, 296, 40563, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16726453, 554869, 79909, 2627, 296, 40563, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16806365, 557498, 80165, 2622, 296, 40451, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16886533, 560122, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16967025, 562761, 82702, 2656, 296, 40513, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17049730, 565419, 82442, 2653, 296, 40468, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17132175, 568074, 82442, 2653, 296, 40468, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17214620, 570729, 82702, 2656, 296, 40513, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17297325, 573387, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17377817, 576026, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17458309, 578665, 80165, 2622, 296, 40451, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17538477, 581289, 79909, 2627, 296, 40563, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17618389, 583918, 79909, 2627, 296, 40563, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17698301, 586547, 80165, 2622, 296, 40451, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17778469, 589171, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17858961, 591810, 82702, 2656, 296, 40513, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17941666, 594468, 82442, 2653, 296, 40468, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18024111, 597123, 82442, 2653, 296, 40468, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18106556, 599778, 82702, 2656, 296, 40513, 2130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18189261, 602436, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[18269765, 605076, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[18270073, 605085, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18350565, 607724, 79753, 2661, 296, 41590, 2185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18430321, 610387, 84472, 2820, 296, 44855, 2326, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18514796, 613209, 84472, 2820, 296, 44855, 2326, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18599271, 616031, 79753, 2661, 296, 41590, 2185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18679027, 618694, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18759519, 621333, 80838, 2663, 296, 41245, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18840360, 623998, 82759, 2778, 296, 44102, 2296, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18923122, 626778, 82759, 2778, 296, 44102, 2296, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19005884, 629558, 80838, 2663, 296, 41245, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19086725, 632223, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19167217, 634862, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19247709, 637501, 79753, 2661, 296, 41590, 2185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19327465, 640164, 84472, 2820, 296, 44855, 2326, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19411940, 642986, 84472, 2820, 296, 44855, 2326, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19496415, 645808, 79753, 2661, 296, 41590, 2185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19576171, 648471, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19656663, 651110, 80838, 2663, 296, 41245, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19737504, 653775, 82759, 2778, 296, 44102, 2296, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19820266, 656555, 82759, 2778, 296, 44102, 2296, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19903028, 659335, 80838, 2663, 296, 41245, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19983869, 662000, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[20064373, 664640, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[20064681, 664649, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20145173, 667288, 81379, 2690, 296, 41908, 2198, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20226555, 669980, 85785, 2904, 296, 46654, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20312343, 672886, 85785, 2904, 296, 46654, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20398131, 675792, 81379, 2690, 296, 41908, 2198, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20479513, 678484, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20560005, 681123, 80578, 2662, 296, 41192, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20640586, 683787, 81468, 2719, 296, 42888, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20722057, 686508, 81468, 2719, 296, 42888, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20803528, 689229, 80578, 2662, 296, 41192, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20884109, 691893, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20964601, 694532, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21045093, 697171, 81379, 2690, 296, 41908, 2198, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21126475, 699863, 85785, 2904, 296, 46654, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21212263, 702769, 85785, 2904, 296, 46654, 2416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21298051, 705675, 81379, 2690, 296, 41908, 2198, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21379433, 708367, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21459925, 711006, 80578, 2662, 296, 41192, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21540506, 713670, 81468, 2719, 296, 42888, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21621977, 716391, 81468, 2719, 296, 42888, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21703448, 719112, 80578, 2662, 296, 41192, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21784029, 721776, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[21864533, 724416, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[21864840, 724425, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21945332, 727064, 81218, 2678, 296, 41390, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22026553, 729744, 80312, 2649, 296, 41027, 2159, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22106868, 732395, 80312, 2649, 296, 41027, 2159, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22187183, 735046, 81218, 2678, 296, 41390, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22268404, 737726, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22348896, 740365, 80180, 2633, 296, 40603, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22429079, 743000, 80775, 2663, 296, 41182, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22509857, 745665, 80775, 2663, 296, 41182, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22590635, 748330, 80180, 2633, 296, 40603, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22670818, 750965, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22751310, 753604, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22831802, 756243, 81218, 2678, 296, 41390, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22913023, 758923, 80312, 2649, 296, 41027, 2159, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22993338, 761574, 80312, 2649, 296, 41027, 2159, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23073653, 764225, 81218, 2678, 296, 41390, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23154874, 766905, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23235366, 769544, 80180, 2633, 296, 40603, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23315549, 772179, 80775, 2663, 296, 41182, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23396327, 774844, 80775, 2663, 296, 41182, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23477105, 777509, 80180, 2633, 296, 40603, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23557288, 780144, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[23637792, 782784, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[23638100, 782793, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23718592, 785432, 80019, 2647, 296, 41204, 2163, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23798614, 788081, 81431, 2778, 296, 44770, 2320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23880048, 790861, 81431, 2778, 296, 44770, 2320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23961482, 793641, 80019, 2647, 296, 41204, 2163, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24041504, 796290, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24121996, 798929, 80900, 2669, 296, 41230, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24202899, 801600, 86681, 2917, 296, 46707, 2418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24289583, 804519, 86681, 2917, 296, 46707, 2418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24376267, 807438, 80900, 2669, 296, 41230, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24457170, 810109, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24537662, 812748, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24618154, 815387, 80019, 2647, 296, 41204, 2163, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24698176, 818036, 81431, 2778, 296, 44770, 2320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24779610, 820816, 81431, 2778, 296, 44770, 2320, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24861044, 823596, 80019, 2647, 296, 41204, 2163, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24941066, 826245, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25021558, 828884, 80900, 2669, 296, 41230, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25102461, 831555, 86681, 2917, 296, 46707, 2418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25189145, 834474, 86681, 2917, 296, 46707, 2418, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25275829, 837393, 80900, 2669, 296, 41230, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25356732, 840064, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[25437236, 842704, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[25437544, 842713, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25518036, 845352, 81031, 2668, 296, 41187, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25599070, 848022, 85349, 2877, 296, 45663, 2382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25684422, 850901, 85349, 2877, 296, 45663, 2382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25769774, 853780, 81031, 2668, 296, 41187, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25850808, 856450, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25931300, 859089, 80787, 2676, 296, 41676, 2188, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26012090, 861767, 82186, 2736, 296, 43391, 2252, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26094279, 864505, 82186, 2736, 296, 43391, 2252, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26176468, 867243, 80787, 2676, 296, 41676, 2188, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26257258, 869921, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26337750, 872560, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26418242, 875199, 81031, 2668, 296, 41187, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26499276, 877869, 85349, 2877, 296, 45663, 2382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26584628, 880748, 85349, 2877, 296, 45663, 2382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26669980, 883627, 81031, 2668, 296, 41187, 2171, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26751014, 886297, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26831506, 888936, 80787, 2676, 296, 41676, 2188, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26912296, 891614, 82186, 2736, 296, 43391, 2252, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26994485, 894352, 82186, 2736, 296, 43391, 2252, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27076674, 897090, 80787, 2676, 296, 41676, 2188, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27157464, 899768, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[27237968, 902408, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[27238276, 902417, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27318768, 905056, 83954, 2687, 296, 40684, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27402725, 907745, 85157, 2702, 296, 40696, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27487885, 910449, 85157, 2702, 296, 40696, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27573045, 913153, 83954, 2687, 296, 40684, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27657002, 915842, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27737494, 918481, 76511, 2585, 296, 40543, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27814008, 921068, 75012, 2566, 296, 40591, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27889023, 923636, 75012, 2566, 296, 40591, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27964038, 926204, 76511, 2585, 296, 40543, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28040552, 928791, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28121044, 931430, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28201536, 934069, 83954, 2687, 296, 40684, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28285493, 936758, 85157, 2702, 296, 40696, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28370653, 939462, 85157, 2702, 296, 40696, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28455813, 942166, 83954, 2687, 296, 40684, 2148, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28539770, 944855, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28620262, 947494, 76511, 2585, 296, 40543, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28696776, 950081, 75012, 2566, 296, 40591, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28771791, 952649, 75012, 2566, 296, 40591, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28846806, 955217, 76511, 2585, 296, 40543, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28923320, 957804, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[29003824, 960444, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[29004133, 960453, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29084625, 963092, 80441, 2658, 296, 41302, 2170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29165069, 965752, 80724, 2681, 296, 41933, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29245796, 968435, 80724, 2681, 296, 41933, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29326523, 971118, 80441, 2658, 296, 41302, 2170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29406967, 973778, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29487459, 976417, 79587, 2624, 296, 40456, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29567049, 979043, 78472, 2608, 296, 40450, 2133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29645524, 981653, 78472, 2608, 296, 40450, 2133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29723999, 984263, 79587, 2624, 296, 40456, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29803589, 986889, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29884081, 989528, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29964573, 992167, 80441, 2658, 296, 41302, 2170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30045017, 994827, 80724, 2681, 296, 41933, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30125744, 997510, 80724, 2681, 296, 41933, 2197, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30206471, 1000193, 80441, 2658, 296, 41302, 2170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30286915, 1002853, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30367407, 1005492, 79587, 2624, 296, 40456, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30446997, 1008118, 78472, 2608, 296, 40450, 2133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30525472, 1010728, 78472, 2608, 296, 40450, 2133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30603947, 1013338, 79587, 2624, 296, 40456, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30683537, 1015964, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[30764041, 1018604, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[30764350, 1018613, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30844842, 1021252, 79829, 2650, 296, 41289, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30924674, 1023904, 81967, 2782, 296, 44784, 2318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31006644, 1026688, 81967, 2782, 296, 44784, 2318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31088614, 1029472, 79829, 2650, 296, 41289, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31168446, 1032124, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31248938, 1034763, 81281, 2679, 296, 41315, 2180, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31330222, 1037444, 84916, 2820, 296, 44780, 2319, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31415141, 1040266, 84916, 2820, 296, 44780, 2319, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31500060, 1043088, 81281, 2679, 296, 41315, 2180, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31581344, 1045769, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31661836, 1048408, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31742328, 1051047, 79829, 2650, 296, 41289, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31822160, 1053699, 81967, 2782, 296, 44784, 2318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31904130, 1056483, 81967, 2782, 296, 44784, 2318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31986100, 1059267, 79829, 2650, 296, 41289, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32065932, 1061919, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32146424, 1064558, 81281, 2679, 296, 41315, 2180, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32227708, 1067239, 84916, 2820, 296, 44780, 2319, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32312627, 1070061, 84916, 2820, 296, 44780, 2319, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32397546, 1072883, 81281, 2679, 296, 41315, 2180, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32478830, 1075564, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[32559334, 1078204, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[32559643, 1078213, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32640135, 1080852, 80422, 2659, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32720560, 1083513, 81029, 2697, 296, 42064, 2211, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32801592, 1086212, 81029, 2697, 296, 42064, 2211, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32882624, 1088911, 80422, 2659, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[32963049, 1091572, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33043541, 1094211, 81173, 2684, 296, 41544, 2190, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33124717, 1096897, 82615, 2744, 296, 42605, 2245, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33207335, 1099643, 82615, 2744, 296, 42605, 2245, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33289953, 1102389, 81173, 2684, 296, 41544, 2190, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33371129, 1105075, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33451621, 1107714, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33532113, 1110353, 80422, 2659, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33612538, 1113014, 81029, 2697, 296, 42064, 2211, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33693570, 1115713, 81029, 2697, 296, 42064, 2211, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33774602, 1118412, 80422, 2659, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33855027, 1121073, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[33935519, 1123712, 81173, 2684, 296, 41544, 2190, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34016695, 1126398, 82615, 2744, 296, 42605, 2245, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34099313, 1129144, 82615, 2744, 296, 42605, 2245, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34181931, 1131890, 81173, 2684, 296, 41544, 2190, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34263107, 1134576, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[34343611, 1137216, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[34343920, 1137225, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34424412, 1139864, 81219, 2674, 296, 41144, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34505634, 1142540, 81496, 2656, 296, 40806, 2149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34587133, 1145198, 81496, 2656, 296, 40806, 2149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34668632, 1147856, 81219, 2674, 296, 41144, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34749854, 1150532, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34830346, 1153171, 79812, 2629, 296, 40551, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34910161, 1155802, 79235, 2622, 296, 40533, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[34989399, 1158426, 79235, 2622, 296, 40533, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35068637, 1161050, 79812, 2629, 296, 40551, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35148452, 1163681, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35228944, 1166320, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35309436, 1168959, 81219, 2674, 296, 41144, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35390658, 1171635, 81496, 2656, 296, 40806, 2149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35472157, 1174293, 81496, 2656, 296, 40806, 2149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35553656, 1176951, 81219, 2674, 296, 41144, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35634878, 1179627, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35715370, 1182266, 79812, 2629, 296, 40551, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35795185, 1184897, 79235, 2622, 296, 40533, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35874423, 1187521, 79235, 2622, 296, 40533, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[35953661, 1190145, 79812, 2629, 296, 40551, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36033476, 1192776, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[36113980, 1195416, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[36114289, 1195425, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36194781, 1198064, 80102, 2630, 296, 40533, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36274886, 1200696, 80881, 2651, 296, 40911, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36355770, 1203349, 80881, 2651, 296, 40911, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36436654, 1206002, 80102, 2630, 296, 40533, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36516759, 1208634, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36597251, 1211273, 80310, 2644, 296, 40863, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36677564, 1213919, 81089, 2675, 296, 41460, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36758656, 1216596, 81089, 2675, 296, 41460, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36839748, 1219273, 80310, 2644, 296, 40863, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[36920061, 1221919, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37000553, 1224558, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37081045, 1227197, 80102, 2630, 296, 40533, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37161150, 1229829, 80881, 2651, 296, 40911, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37242034, 1232482, 80881, 2651, 296, 40911, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37322918, 1235135, 80102, 2630, 296, 40533, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37403023, 1237767, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37483515, 1240406, 80310, 2644, 296, 40863, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37563828, 1243052, 81089, 2675, 296, 41460, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37644920, 1245729, 81089, 2675, 296, 41460, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37726012, 1248406, 80310, 2644, 296, 40863, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37806325, 1251052, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[37886829, 1253692, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[37887138, 1253701, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[37967630, 1256340, 90174, 3059, 296, 49990, 2558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38057807, 1259401, 118671, 4364, 296, 78823, 3867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38176481, 1263767, 118671, 4364, 296, 78823, 3867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38295155, 1268133, 90174, 3059, 296, 49990, 2558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38385332, 1271194, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38465824, 1273833, 86010, 3010, 296, 50042, 2561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38551837, 1276845, 111271, 4229, 296, 75566, 3783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38663111, 1281076, 111271, 4229, 296, 75566, 3783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38774385, 1285307, 86010, 3010, 296, 50042, 2561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38860398, 1288319, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[38940890, 1290958, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39021382, 1293597, 90174, 3059, 296, 49990, 2558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39111559, 1296658, 118671, 4364, 296, 78823, 3867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39230233, 1301024, 118671, 4364, 296, 78823, 3867, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39348907, 1305390, 90174, 3059, 296, 49990, 2558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39439084, 1308451, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39519576, 1311090, 86010, 3010, 296, 50042, 2561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39605589, 1314102, 111271, 4229, 296, 75566, 3783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39716863, 1318333, 111271, 4229, 296, 75566, 3783, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39828137, 1322564, 86010, 3010, 296, 50042, 2561, "GraphicsData", \
"PostScript", "Graphics"],
Cell[39914150, 1325576, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[39994654, 1328216, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[39994963, 1328225, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40075455, 1330864, 87628, 3034, 296, 49995, 2564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40163086, 1333900, 81222, 2741, 296, 43893, 2275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40244311, 1336643, 81222, 2741, 296, 43893, 2275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40325536, 1339386, 87628, 3034, 296, 49995, 2564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40413167, 1342422, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40493659, 1345061, 90642, 3106, 296, 51296, 2615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40584304, 1348169, 85554, 2848, 296, 45665, 2350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40669861, 1351019, 85554, 2848, 296, 45665, 2350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40755418, 1353869, 90642, 3106, 296, 51296, 2615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40846063, 1356977, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[40926555, 1359616, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41007047, 1362255, 87628, 3034, 296, 49995, 2564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41094678, 1365291, 81222, 2741, 296, 43893, 2275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41175903, 1368034, 81222, 2741, 296, 43893, 2275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41257128, 1370777, 87628, 3034, 296, 49995, 2564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41344759, 1373813, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41425251, 1376452, 90642, 3106, 296, 51296, 2615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41515896, 1379560, 85554, 2848, 296, 45665, 2350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41601453, 1382410, 85554, 2848, 296, 45665, 2350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41687010, 1385260, 90642, 3106, 296, 51296, 2615, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41777655, 1388368, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[41858159, 1391008, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[41858468, 1391017, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[41938960, 1393656, 81823, 2651, 296, 40557, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42020786, 1396309, 83575, 2680, 296, 40649, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42104364, 1398991, 83575, 2680, 296, 40649, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42187942, 1401673, 81823, 2651, 296, 40557, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42269768, 1404326, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42350260, 1406965, 78938, 2608, 296, 40430, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42429201, 1409575, 79917, 2630, 296, 40587, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42509121, 1412207, 79917, 2630, 296, 40587, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42589041, 1414839, 78938, 2608, 296, 40430, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42667982, 1417449, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42748474, 1420088, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42828966, 1422727, 81823, 2651, 296, 40557, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42910792, 1425380, 83575, 2680, 296, 40649, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[42994370, 1428062, 83575, 2680, 296, 40649, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43077948, 1430744, 81823, 2651, 296, 40557, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43159774, 1433397, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43240266, 1436036, 78938, 2608, 296, 40430, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43319207, 1438646, 79917, 2630, 296, 40587, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43399127, 1441278, 79917, 2630, 296, 40587, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43479047, 1443910, 78938, 2608, 296, 40430, 2127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43557988, 1446520, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[43638492, 1449160, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[43638801, 1449169, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43719293, 1451808, 86461, 2949, 296, 47176, 2459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43805757, 1454759, 86909, 2986, 296, 48624, 2508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43892669, 1457747, 86909, 2986, 296, 48624, 2508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[43979581, 1460735, 86461, 2949, 296, 47176, 2459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44066045, 1463686, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44146537, 1466325, 82414, 2782, 296, 44299, 2306, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44228954, 1469109, 84236, 2844, 296, 45992, 2367, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44313193, 1471955, 84236, 2844, 296, 45992, 2367, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44397432, 1474801, 82414, 2782, 296, 44299, 2306, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44479849, 1477585, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44560341, 1480224, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44640833, 1482863, 86461, 2949, 296, 47176, 2459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44727297, 1485814, 86909, 2986, 296, 48624, 2508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44814209, 1488802, 86909, 2986, 296, 48624, 2508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44901121, 1491790, 86461, 2949, 296, 47176, 2459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[44987585, 1494741, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45068077, 1497380, 82414, 2782, 296, 44299, 2306, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45150494, 1500164, 84236, 2844, 296, 45992, 2367, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45234733, 1503010, 84236, 2844, 296, 45992, 2367, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45318972, 1505856, 82414, 2782, 296, 44299, 2306, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45401389, 1508640, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[45481893, 1511280, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[45482200, 1511289, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45562692, 1513928, 79445, 2651, 296, 41237, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45642140, 1516581, 79288, 2645, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45721431, 1519228, 79288, 2645, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45800722, 1521875, 79445, 2651, 296, 41237, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45880170, 1524528, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[45960662, 1527167, 79284, 2621, 296, 40623, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46039949, 1529790, 78226, 2607, 296, 40512, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46118178, 1532399, 78226, 2607, 296, 40512, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46196407, 1535008, 79284, 2621, 296, 40623, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46275694, 1537631, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46356186, 1540270, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46436678, 1542909, 79445, 2651, 296, 41237, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46516126, 1545562, 79288, 2645, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46595417, 1548209, 79288, 2645, 296, 41404, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46674708, 1550856, 79445, 2651, 296, 41237, 2174, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46754156, 1553509, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46834648, 1556148, 79284, 2621, 296, 40623, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46913935, 1558771, 78226, 2607, 296, 40512, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[46992164, 1561380, 78226, 2607, 296, 40512, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47070393, 1563989, 79284, 2621, 296, 40623, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47149680, 1566612, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[47230184, 1569252, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[47230493, 1569261, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47310985, 1571900, 83317, 2790, 296, 44202, 2302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47394305, 1574692, 84510, 2840, 296, 44966, 2347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47478818, 1577534, 84510, 2840, 296, 44966, 2347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47563331, 1580376, 83317, 2790, 296, 44202, 2302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47646651, 1583168, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47727143, 1585807, 81926, 2761, 296, 43864, 2286, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47809072, 1588570, 82638, 2819, 296, 45175, 2351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47891713, 1591391, 82638, 2819, 296, 45175, 2351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[47974354, 1594212, 81926, 2761, 296, 43864, 2286, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48056283, 1596975, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48136775, 1599614, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48217267, 1602253, 83317, 2790, 296, 44202, 2302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48300587, 1605045, 84510, 2840, 296, 44966, 2347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48385100, 1607887, 84510, 2840, 296, 44966, 2347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48469613, 1610729, 83317, 2790, 296, 44202, 2302, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48552933, 1613521, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48633425, 1616160, 81926, 2761, 296, 43864, 2286, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48715354, 1618923, 82638, 2819, 296, 45175, 2351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48797995, 1621744, 82638, 2819, 296, 45175, 2351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48880636, 1624565, 81926, 2761, 296, 43864, 2286, "GraphicsData", \
"PostScript", "Graphics"],
Cell[48962565, 1627328, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[49043069, 1629968, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[49043378, 1629977, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49123870, 1632616, 81761, 2729, 296, 42796, 2243, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49205634, 1635347, 80994, 2727, 296, 43029, 2253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49286631, 1638076, 80994, 2727, 296, 43029, 2253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49367628, 1640805, 81761, 2729, 296, 42796, 2243, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49449392, 1643536, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49529884, 1646175, 81898, 2727, 296, 42451, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49611785, 1648904, 81806, 2730, 296, 42351, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49693594, 1651636, 81806, 2730, 296, 42351, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49775403, 1654368, 81898, 2727, 296, 42451, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49857304, 1657097, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[49937796, 1659736, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50018288, 1662375, 81761, 2729, 296, 42796, 2243, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50100052, 1665106, 80994, 2727, 296, 43029, 2253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50181049, 1667835, 80994, 2727, 296, 43029, 2253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50262046, 1670564, 81761, 2729, 296, 42796, 2243, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50343810, 1673295, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50424302, 1675934, 81898, 2727, 296, 42451, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50506203, 1678663, 81806, 2730, 296, 42351, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50588012, 1681395, 81806, 2730, 296, 42351, 2238, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50669821, 1684127, 81898, 2727, 296, 42451, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50751722, 1686856, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[50832226, 1689496, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[50832535, 1689505, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50913027, 1692144, 78510, 2613, 296, 40557, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[50991540, 1694759, 79676, 2658, 296, 41488, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51071219, 1697419, 79676, 2658, 296, 41488, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51150898, 1700079, 78510, 2613, 296, 40557, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51229411, 1702694, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51309903, 1705333, 79337, 2625, 296, 40615, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51389243, 1707960, 78936, 2617, 296, 40615, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51468182, 1710579, 78936, 2617, 296, 40615, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51547121, 1713198, 79337, 2625, 296, 40615, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51626461, 1715825, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51706953, 1718464, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51787445, 1721103, 78510, 2613, 296, 40557, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51865958, 1723718, 79676, 2658, 296, 41488, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[51945637, 1726378, 79676, 2658, 296, 41488, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52025316, 1729038, 78510, 2613, 296, 40557, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52103829, 1731653, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52184321, 1734292, 79337, 2625, 296, 40615, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52263661, 1736919, 78936, 2617, 296, 40615, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52342600, 1739538, 78936, 2617, 296, 40615, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52421539, 1742157, 79337, 2625, 296, 40615, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52500879, 1744784, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[52581383, 1747424, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[52581692, 1747433, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52662184, 1750072, 92309, 3224, 296, 53619, 2741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52754496, 1753298, 103219, 3750, 296, 63889, 3259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52857718, 1757050, 103219, 3750, 296, 63889, 3259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[52960940, 1760802, 92309, 3224, 296, 53619, 2741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53053252, 1764028, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53133744, 1766667, 94227, 3370, 296, 56550, 2900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53227974, 1770039, 97677, 3505, 296, 60587, 3042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53325654, 1773546, 97677, 3505, 296, 60587, 3042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53423334, 1777053, 94227, 3370, 296, 56550, 2900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53517564, 1780425, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53598056, 1783064, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53678548, 1785703, 92309, 3224, 296, 53619, 2741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53770860, 1788929, 103219, 3750, 296, 63889, 3259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53874082, 1792681, 103219, 3750, 296, 63889, 3259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[53977304, 1796433, 92309, 3224, 296, 53619, 2741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54069616, 1799659, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54150108, 1802298, 94227, 3370, 296, 56550, 2900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54244338, 1805670, 97677, 3505, 296, 60587, 3042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54342018, 1809177, 97677, 3505, 296, 60587, 3042, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54439698, 1812684, 94227, 3370, 296, 56550, 2900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54533928, 1816056, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[54614432, 1818696, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[54614741, 1818705, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54695233, 1821344, 94904, 3298, 296, 55740, 2809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54790140, 1824644, 109869, 3992, 296, 71102, 3508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[54900012, 1828638, 109869, 3992, 296, 71102, 3508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55009884, 1832632, 94904, 3298, 296, 55740, 2809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55104791, 1835932, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55185283, 1838571, 96017, 3420, 296, 57562, 2940, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55281303, 1841993, 111119, 4164, 296, 72883, 3687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55392425, 1846159, 111119, 4164, 296, 72883, 3687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55503547, 1850325, 96017, 3420, 296, 57562, 2940, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55599567, 1853747, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55680059, 1856386, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55760551, 1859025, 94904, 3298, 296, 55740, 2809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55855458, 1862325, 109869, 3992, 296, 71102, 3508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[55965330, 1866319, 109869, 3992, 296, 71102, 3508, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56075202, 1870313, 94904, 3298, 296, 55740, 2809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56170109, 1873613, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56250601, 1876252, 96017, 3420, 296, 57562, 2940, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56346621, 1879674, 111119, 4164, 296, 72883, 3687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56457743, 1883840, 111119, 4164, 296, 72883, 3687, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56568865, 1888006, 96017, 3420, 296, 57562, 2940, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56664885, 1891428, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[56745389, 1894068, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[56745698, 1894077, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56826190, 1896716, 97114, 3482, 296, 59854, 3017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[56923307, 1900200, 114757, 4291, 296, 77659, 3828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57038067, 1904493, 114757, 4291, 296, 77659, 3828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57152827, 1908786, 97114, 3482, 296, 59854, 3017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57249944, 1912270, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57330436, 1914909, 96898, 3458, 296, 58783, 2982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57427337, 1918369, 109056, 4001, 296, 72124, 3540, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57536396, 1922372, 109056, 4001, 296, 72124, 3540, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57645455, 1926375, 96898, 3458, 296, 58783, 2982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57742356, 1929835, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57822848, 1932474, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[57903340, 1935113, 97114, 3482, 296, 59854, 3017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58000457, 1938597, 114757, 4291, 296, 77659, 3828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58115217, 1942890, 114757, 4291, 296, 77659, 3828, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58229977, 1947183, 97114, 3482, 296, 59854, 3017, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58327094, 1950667, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58407586, 1953306, 96898, 3458, 296, 58783, 2982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58504487, 1956766, 109056, 4001, 296, 72124, 3540, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58613546, 1960769, 109056, 4001, 296, 72124, 3540, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58722605, 1964772, 96898, 3458, 296, 58783, 2982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58819506, 1968232, 80489, 2637, 296, 40584, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[58900010, 1970872, 284, 5, 25, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[58900343, 1970883, 64, 1, 31, "Subsection"],
Cell[58900410, 1970886, 2618, 46, 630, "Input"],

Cell[CellGroupData[{
Cell[58903053, 1970936, 145, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[58903223, 1970944, 85755, 2914, 296, 46863, 2429, "GraphicsData", \
"PostScript", "Graphics"],
Cell[58988981, 1973860, 85255, 2966, 296, 49146, 2515, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59074251, 1976829, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59074558, 1976838, 85886, 2949, 296, 47816, 2474, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59160447, 1979789, 86353, 2974, 236, 48616, 2503, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59246815, 1982766, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59247122, 1982775, 78635, 2612, 296, 40638, 2138, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59325760, 1985389, 79438, 2621, 296, 40535, 2136, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59405213, 1988013, 281, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59405519, 1988022, 78905, 2693, 296, 43423, 2250, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59484427, 1990717, 83280, 2748, 296, 42902, 2244, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59567722, 1993468, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59568029, 1993477, 81687, 2705, 296, 41997, 2210, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59649719, 1996184, 80159, 2676, 296, 41960, 2199, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59729893, 1998863, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59730200, 1998872, 79772, 2630, 296, 40637, 2142, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59809975, 2001504, 84004, 2731, 296, 41990, 2207, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[59893994, 2004238, 280, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[59894299, 2004247, 92141, 3221, 296, 54516, 2751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[59986443, 2007470, 94321, 3217, 296, 53753, 2711, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60080779, 2010690, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60081087, 2010699, 93648, 3261, 296, 54813, 2777, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60174738, 2013962, 94560, 3299, 296, 55373, 2810, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60269313, 2017264, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60269621, 2017273, 80320, 2640, 296, 40654, 2145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60349944, 2019915, 80651, 2636, 296, 40545, 2136, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60430610, 2022554, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60430918, 2022563, 79958, 2628, 296, 40539, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60510879, 2025193, 82451, 2653, 296, 40462, 2130, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60593345, 2027849, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60593653, 2027858, 86649, 2909, 296, 46894, 2413, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60680305, 2030769, 87196, 2959, 296, 48042, 2471, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60767516, 2033731, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60767824, 2033740, 90786, 3113, 296, 50606, 2612, "GraphicsData", \
"PostScript", "Graphics"],
Cell[60858613, 2036855, 82814, 2793, 296, 44409, 2314, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[60941442, 2039651, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[60941749, 2039660, 80395, 2658, 296, 41223, 2169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61022147, 2042320, 80930, 2667, 296, 41261, 2172, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[61103092, 2044990, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61103400, 2044999, 81594, 2790, 296, 45014, 2333, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61184997, 2047791, 87324, 2944, 296, 47270, 2444, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[61272336, 2050738, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61272644, 2050747, 86827, 2937, 296, 47036, 2441, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61359474, 2053686, 83769, 2805, 296, 44971, 2321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[61443258, 2056494, 283, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61443566, 2056503, 85232, 2695, 296, 40601, 2139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61528801, 2059200, 74917, 2566, 296, 40528, 2136, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[61603733, 2061769, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61604042, 2061778, 81159, 2695, 296, 42316, 2210, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61685204, 2064475, 78664, 2609, 296, 40477, 2133, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[61763883, 2067087, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61764192, 2067096, 84036, 2857, 296, 46761, 2392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[61848231, 2069955, 87410, 2902, 296, 46716, 2395, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[61935656, 2072860, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[61935965, 2072869, 81139, 2711, 296, 42677, 2231, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62017107, 2075582, 82596, 2752, 296, 42959, 2258, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62099718, 2078337, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62100027, 2078346, 81658, 2657, 296, 40920, 2149, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62181688, 2081005, 79315, 2622, 296, 40629, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62261018, 2083630, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62261327, 2083639, 80983, 2652, 296, 40865, 2152, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62342313, 2086293, 81159, 2676, 296, 41473, 2181, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62423487, 2088972, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62423796, 2088981, 109290, 3961, 296, 68884, 3457, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62533089, 2092944, 106184, 3941, 296, 70066, 3490, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62639288, 2096888, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62639597, 2096897, 80361, 2703, 296, 42859, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62719961, 2099602, 84564, 2802, 296, 44315, 2300, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62804540, 2102407, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62804849, 2102416, 83757, 2675, 296, 40512, 2136, "GraphicsData", \
"PostScript", "Graphics"],
Cell[62888609, 2105093, 80426, 2636, 296, 40602, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[62969050, 2107732, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[62969359, 2107741, 90806, 3154, 296, 52644, 2678, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63060168, 2110897, 88866, 3036, 296, 50606, 2559, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63149049, 2113936, 282, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63149356, 2113945, 79542, 2648, 296, 41376, 2172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63228901, 2116595, 78114, 2605, 296, 40506, 2136, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63307030, 2119203, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63307339, 2119212, 84714, 2842, 296, 45045, 2347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63392056, 2122056, 82016, 2810, 296, 45262, 2351, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63474087, 2124869, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63474396, 2124878, 80882, 2721, 296, 42833, 2246, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63555281, 2127601, 82073, 2731, 296, 42549, 2238, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63637369, 2130335, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63637678, 2130344, 79608, 2657, 296, 41462, 2181, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63717289, 2133003, 78859, 2617, 296, 40582, 2139, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63796163, 2135623, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63796472, 2135632, 104104, 3768, 296, 65095, 3281, "GraphicsData", \
"PostScript", "Graphics"],
Cell[63900579, 2139402, 97422, 3502, 296, 60547, 3042, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[63998016, 2142907, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[63998325, 2142916, 106221, 3812, 296, 67451, 3328, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64104549, 2146730, 102322, 3739, 296, 64195, 3263, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[64206886, 2150472, 284, 5, 25, "Print"],

Cell[CellGroupData[{
Cell[64207195, 2150481, 112839, 4204, 296, 75851, 3742, "GraphicsData", \
"PostScript", "Graphics"],
Cell[64320037, 2154687, 109866, 4031, 296, 72784, 3568, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[64429918, 2158721, 284, 5, 25, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

